{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "5ce2eb98",
   "metadata": {},
   "source": [
    "# Public health benefits of clean household energy in India\n",
    "\n",
    "---\n",
    "\n",
    "An interactive plot visualising how a complete transition to clean household energy in India can save one-quarter of the healthy life lost to *total* particulate matter pollution exposure in India.\n",
    "\n",
    "For more information, see the paper [here](https://doi.org/10.1088/1748-9326/ab8e8a).  \n",
    "\n",
    "This plot is also an app [here](https://bag.leeds.ac.uk/projects/air-quality-in-asia/household-energy-and-air-quality-in-india/).  \n",
    "\n",
    "**Acronyms**  \n",
    "- BASELINE = Present-day emissions.  \n",
    "- ALLLPG = Complete household transition from solid fuels to liquefied petroleum gas (LPG).  \n",
    "- PM₂.₅ = Fine particulate matter (annual-mean).  \n",
    "- MORT = Premature mortalities (annual number).  \n",
    "\n",
    "---\n",
    "\n",
    "*Click on the different tabs to explore the results.*  \n",
    "*Hover over a state to see the values there.*  \n",
    "\n",
    "---"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 91,
   "id": "4ac9e560",
   "metadata": {
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "    <div class=\"bk-root\">\n",
       "        <a href=\"https://bokeh.org\" target=\"_blank\" class=\"bk-logo bk-logo-small bk-logo-notebook\"></a>\n",
       "        <span id=\"10187\">Loading BokehJS ...</span>\n",
       "    </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "\n",
       "(function(root) {\n",
       "  function now() {\n",
       "    return new Date();\n",
       "  }\n",
       "\n",
       "  var force = true;\n",
       "\n",
       "  if (typeof root._bokeh_onload_callbacks === \"undefined\" || force === true) {\n",
       "    root._bokeh_onload_callbacks = [];\n",
       "    root._bokeh_is_loading = undefined;\n",
       "  }\n",
       "\n",
       "  var JS_MIME_TYPE = 'application/javascript';\n",
       "  var HTML_MIME_TYPE = 'text/html';\n",
       "  var EXEC_MIME_TYPE = 'application/vnd.bokehjs_exec.v0+json';\n",
       "  var CLASS_NAME = 'output_bokeh rendered_html';\n",
       "\n",
       "  /**\n",
       "   * Render data to the DOM node\n",
       "   */\n",
       "  function render(props, node) {\n",
       "    var script = document.createElement(\"script\");\n",
       "    node.appendChild(script);\n",
       "  }\n",
       "\n",
       "  /**\n",
       "   * Handle when an output is cleared or removed\n",
       "   */\n",
       "  function handleClearOutput(event, handle) {\n",
       "    var cell = handle.cell;\n",
       "\n",
       "    var id = cell.output_area._bokeh_element_id;\n",
       "    var server_id = cell.output_area._bokeh_server_id;\n",
       "    // Clean up Bokeh references\n",
       "    if (id != null && id in Bokeh.index) {\n",
       "      Bokeh.index[id].model.document.clear();\n",
       "      delete Bokeh.index[id];\n",
       "    }\n",
       "\n",
       "    if (server_id !== undefined) {\n",
       "      // Clean up Bokeh references\n",
       "      var cmd = \"from bokeh.io.state import curstate; print(curstate().uuid_to_server['\" + server_id + \"'].get_sessions()[0].document.roots[0]._id)\";\n",
       "      cell.notebook.kernel.execute(cmd, {\n",
       "        iopub: {\n",
       "          output: function(msg) {\n",
       "            var id = msg.content.text.trim();\n",
       "            if (id in Bokeh.index) {\n",
       "              Bokeh.index[id].model.document.clear();\n",
       "              delete Bokeh.index[id];\n",
       "            }\n",
       "          }\n",
       "        }\n",
       "      });\n",
       "      // Destroy server and session\n",
       "      var cmd = \"import bokeh.io.notebook as ion; ion.destroy_server('\" + server_id + \"')\";\n",
       "      cell.notebook.kernel.execute(cmd);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  /**\n",
       "   * Handle when a new output is added\n",
       "   */\n",
       "  function handleAddOutput(event, handle) {\n",
       "    var output_area = handle.output_area;\n",
       "    var output = handle.output;\n",
       "\n",
       "    // limit handleAddOutput to display_data with EXEC_MIME_TYPE content only\n",
       "    if ((output.output_type != \"display_data\") || (!Object.prototype.hasOwnProperty.call(output.data, EXEC_MIME_TYPE))) {\n",
       "      return\n",
       "    }\n",
       "\n",
       "    var toinsert = output_area.element.find(\".\" + CLASS_NAME.split(' ')[0]);\n",
       "\n",
       "    if (output.metadata[EXEC_MIME_TYPE][\"id\"] !== undefined) {\n",
       "      toinsert[toinsert.length - 1].firstChild.textContent = output.data[JS_MIME_TYPE];\n",
       "      // store reference to embed id on output_area\n",
       "      output_area._bokeh_element_id = output.metadata[EXEC_MIME_TYPE][\"id\"];\n",
       "    }\n",
       "    if (output.metadata[EXEC_MIME_TYPE][\"server_id\"] !== undefined) {\n",
       "      var bk_div = document.createElement(\"div\");\n",
       "      bk_div.innerHTML = output.data[HTML_MIME_TYPE];\n",
       "      var script_attrs = bk_div.children[0].attributes;\n",
       "      for (var i = 0; i < script_attrs.length; i++) {\n",
       "        toinsert[toinsert.length - 1].firstChild.setAttribute(script_attrs[i].name, script_attrs[i].value);\n",
       "        toinsert[toinsert.length - 1].firstChild.textContent = bk_div.children[0].textContent\n",
       "      }\n",
       "      // store reference to server id on output_area\n",
       "      output_area._bokeh_server_id = output.metadata[EXEC_MIME_TYPE][\"server_id\"];\n",
       "    }\n",
       "  }\n",
       "\n",
       "  function register_renderer(events, OutputArea) {\n",
       "\n",
       "    function append_mime(data, metadata, element) {\n",
       "      // create a DOM node to render to\n",
       "      var toinsert = this.create_output_subarea(\n",
       "        metadata,\n",
       "        CLASS_NAME,\n",
       "        EXEC_MIME_TYPE\n",
       "      );\n",
       "      this.keyboard_manager.register_events(toinsert);\n",
       "      // Render to node\n",
       "      var props = {data: data, metadata: metadata[EXEC_MIME_TYPE]};\n",
       "      render(props, toinsert[toinsert.length - 1]);\n",
       "      element.append(toinsert);\n",
       "      return toinsert\n",
       "    }\n",
       "\n",
       "    /* Handle when an output is cleared or removed */\n",
       "    events.on('clear_output.CodeCell', handleClearOutput);\n",
       "    events.on('delete.Cell', handleClearOutput);\n",
       "\n",
       "    /* Handle when a new output is added */\n",
       "    events.on('output_added.OutputArea', handleAddOutput);\n",
       "\n",
       "    /**\n",
       "     * Register the mime type and append_mime function with output_area\n",
       "     */\n",
       "    OutputArea.prototype.register_mime_type(EXEC_MIME_TYPE, append_mime, {\n",
       "      /* Is output safe? */\n",
       "      safe: true,\n",
       "      /* Index of renderer in `output_area.display_order` */\n",
       "      index: 0\n",
       "    });\n",
       "  }\n",
       "\n",
       "  // register the mime type if in Jupyter Notebook environment and previously unregistered\n",
       "  if (root.Jupyter !== undefined) {\n",
       "    var events = require('base/js/events');\n",
       "    var OutputArea = require('notebook/js/outputarea').OutputArea;\n",
       "\n",
       "    if (OutputArea.prototype.mime_types().indexOf(EXEC_MIME_TYPE) == -1) {\n",
       "      register_renderer(events, OutputArea);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  \n",
       "  if (typeof (root._bokeh_timeout) === \"undefined\" || force === true) {\n",
       "    root._bokeh_timeout = Date.now() + 5000;\n",
       "    root._bokeh_failed_load = false;\n",
       "  }\n",
       "\n",
       "  var NB_LOAD_WARNING = {'data': {'text/html':\n",
       "     \"<div style='background-color: #fdd'>\\n\"+\n",
       "     \"<p>\\n\"+\n",
       "     \"BokehJS does not appear to have successfully loaded. If loading BokehJS from CDN, this \\n\"+\n",
       "     \"may be due to a slow or bad network connection. Possible fixes:\\n\"+\n",
       "     \"</p>\\n\"+\n",
       "     \"<ul>\\n\"+\n",
       "     \"<li>re-rerun `output_notebook()` to attempt to load from CDN again, or</li>\\n\"+\n",
       "     \"<li>use INLINE resources instead, as so:</li>\\n\"+\n",
       "     \"</ul>\\n\"+\n",
       "     \"<code>\\n\"+\n",
       "     \"from bokeh.resources import INLINE\\n\"+\n",
       "     \"output_notebook(resources=INLINE)\\n\"+\n",
       "     \"</code>\\n\"+\n",
       "     \"</div>\"}};\n",
       "\n",
       "  function display_loaded() {\n",
       "    var el = document.getElementById(\"10187\");\n",
       "    if (el != null) {\n",
       "      el.textContent = \"BokehJS is loading...\";\n",
       "    }\n",
       "    if (root.Bokeh !== undefined) {\n",
       "      if (el != null) {\n",
       "        el.textContent = \"BokehJS \" + root.Bokeh.version + \" successfully loaded.\";\n",
       "      }\n",
       "    } else if (Date.now() < root._bokeh_timeout) {\n",
       "      setTimeout(display_loaded, 100)\n",
       "    }\n",
       "  }\n",
       "\n",
       "\n",
       "  function run_callbacks() {\n",
       "    try {\n",
       "      root._bokeh_onload_callbacks.forEach(function(callback) {\n",
       "        if (callback != null)\n",
       "          callback();\n",
       "      });\n",
       "    } finally {\n",
       "      delete root._bokeh_onload_callbacks\n",
       "    }\n",
       "    console.debug(\"Bokeh: all callbacks have finished\");\n",
       "  }\n",
       "\n",
       "  function load_libs(css_urls, js_urls, callback) {\n",
       "    if (css_urls == null) css_urls = [];\n",
       "    if (js_urls == null) js_urls = [];\n",
       "\n",
       "    root._bokeh_onload_callbacks.push(callback);\n",
       "    if (root._bokeh_is_loading > 0) {\n",
       "      console.debug(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n",
       "      return null;\n",
       "    }\n",
       "    if (js_urls == null || js_urls.length === 0) {\n",
       "      run_callbacks();\n",
       "      return null;\n",
       "    }\n",
       "    console.debug(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n",
       "    root._bokeh_is_loading = css_urls.length + js_urls.length;\n",
       "\n",
       "    function on_load() {\n",
       "      root._bokeh_is_loading--;\n",
       "      if (root._bokeh_is_loading === 0) {\n",
       "        console.debug(\"Bokeh: all BokehJS libraries/stylesheets loaded\");\n",
       "        run_callbacks()\n",
       "      }\n",
       "    }\n",
       "\n",
       "    function on_error(url) {\n",
       "      console.error(\"failed to load \" + url);\n",
       "    }\n",
       "\n",
       "    for (let i = 0; i < css_urls.length; i++) {\n",
       "      const url = css_urls[i];\n",
       "      const element = document.createElement(\"link\");\n",
       "      element.onload = on_load;\n",
       "      element.onerror = on_error.bind(null, url);\n",
       "      element.rel = \"stylesheet\";\n",
       "      element.type = \"text/css\";\n",
       "      element.href = url;\n",
       "      console.debug(\"Bokeh: injecting link tag for BokehJS stylesheet: \", url);\n",
       "      document.body.appendChild(element);\n",
       "    }\n",
       "\n",
       "    const hashes = {\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.0.min.js\": \"HjagQp6T0/7bxYTAXbLotF1MLAGWmhkY5siA1Gc/pcEgvgRPtMsRn0gQtMwGKiw1\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.0.min.js\": \"ZEPPTjL+mdyqgIq+/pl9KTwzji8Kow2NnI3zWY8+sFinWP/SYJ80BnfeJsa45iYj\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.0.min.js\": \"exLqv2ACDRIaV7ZK1iL8aGzGYQvKVuT3U2CT7FsQREBxRah6JrkVCoFy0koY1YqV\"};\n",
       "\n",
       "    for (let i = 0; i < js_urls.length; i++) {\n",
       "      const url = js_urls[i];\n",
       "      const element = document.createElement('script');\n",
       "      element.onload = on_load;\n",
       "      element.onerror = on_error.bind(null, url);\n",
       "      element.async = false;\n",
       "      element.src = url;\n",
       "      if (url in hashes) {\n",
       "        element.crossOrigin = \"anonymous\";\n",
       "        element.integrity = \"sha384-\" + hashes[url];\n",
       "      }\n",
       "      console.debug(\"Bokeh: injecting script tag for BokehJS library: \", url);\n",
       "      document.head.appendChild(element);\n",
       "    }\n",
       "  };\n",
       "\n",
       "  function inject_raw_css(css) {\n",
       "    const element = document.createElement(\"style\");\n",
       "    element.appendChild(document.createTextNode(css));\n",
       "    document.body.appendChild(element);\n",
       "  }\n",
       "\n",
       "  \n",
       "  var js_urls = [\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.0.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.0.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.0.min.js\"];\n",
       "  var css_urls = [];\n",
       "  \n",
       "\n",
       "  var inline_js = [\n",
       "    function(Bokeh) {\n",
       "      Bokeh.set_log_level(\"info\");\n",
       "    },\n",
       "    function(Bokeh) {\n",
       "    \n",
       "    \n",
       "    }\n",
       "  ];\n",
       "\n",
       "  function run_inline_js() {\n",
       "    \n",
       "    if (root.Bokeh !== undefined || force === true) {\n",
       "      \n",
       "    for (var i = 0; i < inline_js.length; i++) {\n",
       "      inline_js[i].call(root, root.Bokeh);\n",
       "    }\n",
       "    if (force === true) {\n",
       "        display_loaded();\n",
       "      }} else if (Date.now() < root._bokeh_timeout) {\n",
       "      setTimeout(run_inline_js, 100);\n",
       "    } else if (!root._bokeh_failed_load) {\n",
       "      console.log(\"Bokeh: BokehJS failed to load within specified timeout.\");\n",
       "      root._bokeh_failed_load = true;\n",
       "    } else if (force !== true) {\n",
       "      var cell = $(document.getElementById(\"10187\")).parents('.cell').data().cell;\n",
       "      cell.output_area.append_execute_result(NB_LOAD_WARNING)\n",
       "    }\n",
       "\n",
       "  }\n",
       "\n",
       "  if (root._bokeh_is_loading === 0) {\n",
       "    console.debug(\"Bokeh: BokehJS loaded, going straight to plotting\");\n",
       "    run_inline_js();\n",
       "  } else {\n",
       "    load_libs(css_urls, js_urls, function() {\n",
       "      console.debug(\"Bokeh: BokehJS plotting callback run at\", now());\n",
       "      run_inline_js();\n",
       "    });\n",
       "  }\n",
       "}(window));"
      ],
      "application/vnd.bokehjs_load.v0+json": "\n(function(root) {\n  function now() {\n    return new Date();\n  }\n\n  var force = true;\n\n  if (typeof root._bokeh_onload_callbacks === \"undefined\" || force === true) {\n    root._bokeh_onload_callbacks = [];\n    root._bokeh_is_loading = undefined;\n  }\n\n  \n\n  \n  if (typeof (root._bokeh_timeout) === \"undefined\" || force === true) {\n    root._bokeh_timeout = Date.now() + 5000;\n    root._bokeh_failed_load = false;\n  }\n\n  var NB_LOAD_WARNING = {'data': {'text/html':\n     \"<div style='background-color: #fdd'>\\n\"+\n     \"<p>\\n\"+\n     \"BokehJS does not appear to have successfully loaded. If loading BokehJS from CDN, this \\n\"+\n     \"may be due to a slow or bad network connection. Possible fixes:\\n\"+\n     \"</p>\\n\"+\n     \"<ul>\\n\"+\n     \"<li>re-rerun `output_notebook()` to attempt to load from CDN again, or</li>\\n\"+\n     \"<li>use INLINE resources instead, as so:</li>\\n\"+\n     \"</ul>\\n\"+\n     \"<code>\\n\"+\n     \"from bokeh.resources import INLINE\\n\"+\n     \"output_notebook(resources=INLINE)\\n\"+\n     \"</code>\\n\"+\n     \"</div>\"}};\n\n  function display_loaded() {\n    var el = document.getElementById(\"10187\");\n    if (el != null) {\n      el.textContent = \"BokehJS is loading...\";\n    }\n    if (root.Bokeh !== undefined) {\n      if (el != null) {\n        el.textContent = \"BokehJS \" + root.Bokeh.version + \" successfully loaded.\";\n      }\n    } else if (Date.now() < root._bokeh_timeout) {\n      setTimeout(display_loaded, 100)\n    }\n  }\n\n\n  function run_callbacks() {\n    try {\n      root._bokeh_onload_callbacks.forEach(function(callback) {\n        if (callback != null)\n          callback();\n      });\n    } finally {\n      delete root._bokeh_onload_callbacks\n    }\n    console.debug(\"Bokeh: all callbacks have finished\");\n  }\n\n  function load_libs(css_urls, js_urls, callback) {\n    if (css_urls == null) css_urls = [];\n    if (js_urls == null) js_urls = [];\n\n    root._bokeh_onload_callbacks.push(callback);\n    if (root._bokeh_is_loading > 0) {\n      console.debug(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n      return null;\n    }\n    if (js_urls == null || js_urls.length === 0) {\n      run_callbacks();\n      return null;\n    }\n    console.debug(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n    root._bokeh_is_loading = css_urls.length + js_urls.length;\n\n    function on_load() {\n      root._bokeh_is_loading--;\n      if (root._bokeh_is_loading === 0) {\n        console.debug(\"Bokeh: all BokehJS libraries/stylesheets loaded\");\n        run_callbacks()\n      }\n    }\n\n    function on_error(url) {\n      console.error(\"failed to load \" + url);\n    }\n\n    for (let i = 0; i < css_urls.length; i++) {\n      const url = css_urls[i];\n      const element = document.createElement(\"link\");\n      element.onload = on_load;\n      element.onerror = on_error.bind(null, url);\n      element.rel = \"stylesheet\";\n      element.type = \"text/css\";\n      element.href = url;\n      console.debug(\"Bokeh: injecting link tag for BokehJS stylesheet: \", url);\n      document.body.appendChild(element);\n    }\n\n    const hashes = {\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.0.min.js\": \"HjagQp6T0/7bxYTAXbLotF1MLAGWmhkY5siA1Gc/pcEgvgRPtMsRn0gQtMwGKiw1\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.0.min.js\": \"ZEPPTjL+mdyqgIq+/pl9KTwzji8Kow2NnI3zWY8+sFinWP/SYJ80BnfeJsa45iYj\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.0.min.js\": \"exLqv2ACDRIaV7ZK1iL8aGzGYQvKVuT3U2CT7FsQREBxRah6JrkVCoFy0koY1YqV\"};\n\n    for (let i = 0; i < js_urls.length; i++) {\n      const url = js_urls[i];\n      const element = document.createElement('script');\n      element.onload = on_load;\n      element.onerror = on_error.bind(null, url);\n      element.async = false;\n      element.src = url;\n      if (url in hashes) {\n        element.crossOrigin = \"anonymous\";\n        element.integrity = \"sha384-\" + hashes[url];\n      }\n      console.debug(\"Bokeh: injecting script tag for BokehJS library: \", url);\n      document.head.appendChild(element);\n    }\n  };\n\n  function inject_raw_css(css) {\n    const element = document.createElement(\"style\");\n    element.appendChild(document.createTextNode(css));\n    document.body.appendChild(element);\n  }\n\n  \n  var js_urls = [\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.0.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.0.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.0.min.js\"];\n  var css_urls = [];\n  \n\n  var inline_js = [\n    function(Bokeh) {\n      Bokeh.set_log_level(\"info\");\n    },\n    function(Bokeh) {\n    \n    \n    }\n  ];\n\n  function run_inline_js() {\n    \n    if (root.Bokeh !== undefined || force === true) {\n      \n    for (var i = 0; i < inline_js.length; i++) {\n      inline_js[i].call(root, root.Bokeh);\n    }\n    if (force === true) {\n        display_loaded();\n      }} else if (Date.now() < root._bokeh_timeout) {\n      setTimeout(run_inline_js, 100);\n    } else if (!root._bokeh_failed_load) {\n      console.log(\"Bokeh: BokehJS failed to load within specified timeout.\");\n      root._bokeh_failed_load = true;\n    } else if (force !== true) {\n      var cell = $(document.getElementById(\"10187\")).parents('.cell').data().cell;\n      cell.output_area.append_execute_result(NB_LOAD_WARNING)\n    }\n\n  }\n\n  if (root._bokeh_is_loading === 0) {\n    console.debug(\"Bokeh: BokehJS loaded, going straight to plotting\");\n    run_inline_js();\n  } else {\n    load_libs(css_urls, js_urls, function() {\n      console.debug(\"Bokeh: BokehJS plotting callback run at\", now());\n      run_inline_js();\n    });\n  }\n}(window));"
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "  <div class=\"bk-root\" id=\"52176f4a-25f4-47a5-b925-b7ef3911841a\" data-root-id=\"10356\"></div>\n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "(function(root) {\n",
       "  function embed_document(root) {\n",
       "    \n",
       "  var docs_json = {\"933e862f-4847-4fcb-955c-b9f3426cff09\":{\"defs\":[{\"extends\":null,\"module\":null,\"name\":\"DataModel\",\"overrides\":[],\"properties\":[]}],\"roots\":{\"references\":[{\"attributes\":{\"children\":[{\"id\":\"10354\"},{\"id\":\"10355\"}]},\"id\":\"10356\",\"type\":\"Row\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.7},\"fill_color\":{\"field\":\"mort_tpm25_6cod_mean_total\",\"transform\":{\"id\":\"10272\"}},\"line_color\":{\"value\":\"grey\"},\"line_width\":{\"value\":0.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"10305\",\"type\":\"Patches\"},{\"attributes\":{},\"id\":\"10755\",\"type\":\"AllLabels\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.1},\"fill_color\":{\"field\":\"apm25_popweighted\",\"transform\":{\"id\":\"10190\"}},\"line_alpha\":{\"value\":0.1},\"line_color\":{\"value\":\"grey\"},\"line_width\":{\"value\":0.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"10224\",\"type\":\"Patches\"},{\"attributes\":{},\"id\":\"10756\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{},\"id\":\"10210\",\"type\":\"PanTool\"},{\"attributes\":{\"formatter\":{\"id\":\"10745\"},\"major_label_policy\":{\"id\":\"10744\"},\"ticker\":{\"id\":\"10248\"}},\"id\":\"10247\",\"type\":\"LinearAxis\"},{\"attributes\":{},\"id\":\"10758\",\"type\":\"AllLabels\"},{\"attributes\":{\"source\":{\"id\":\"10189\"}},\"id\":\"10267\",\"type\":\"CDSView\"},{\"attributes\":{\"high\":150000,\"low\":0,\"palette\":[\"#440154\",\"#472777\",\"#3E4989\",\"#30678D\",\"#25828E\",\"#1E9C89\",\"#35B778\",\"#6BCD59\",\"#B2DD2C\",\"#FDE724\"]},\"id\":\"10272\",\"type\":\"LinearColorMapper\"},{\"attributes\":{},\"id\":\"10759\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"formatter\":{\"id\":\"10742\"},\"major_label_policy\":{\"id\":\"10741\"},\"ticker\":{\"id\":\"10244\"}},\"id\":\"10243\",\"type\":\"LinearAxis\"},{\"attributes\":{},\"id\":\"10207\",\"type\":\"BasicTicker\"},{\"attributes\":{},\"id\":\"10196\",\"type\":\"DataRange1d\"},{\"attributes\":{},\"id\":\"10198\",\"type\":\"LinearScale\"},{\"attributes\":{\"axis\":{\"id\":\"10202\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"10205\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"10239\",\"type\":\"LinearScale\"},{\"attributes\":{\"tabs\":[{\"id\":\"10230\"},{\"id\":\"10271\"}]},\"id\":\"10354\",\"type\":\"Tabs\"},{\"attributes\":{\"center\":[{\"id\":\"10287\"},{\"id\":\"10291\"}],\"height\":400,\"renderers\":[{\"id\":\"10307\"}],\"title\":{\"id\":\"10274\"},\"toolbar\":{\"id\":\"10297\"},\"toolbar_location\":null,\"width\":400,\"x_range\":{\"id\":\"10276\"},\"x_scale\":{\"id\":\"10280\"},\"y_range\":{\"id\":\"10278\"},\"y_scale\":{\"id\":\"10282\"}},\"id\":\"10273\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{\"high\":100,\"low\":0,\"palette\":[\"#440154\",\"#472777\",\"#3E4989\",\"#30678D\",\"#25828E\",\"#1E9C89\",\"#35B778\",\"#6BCD59\",\"#B2DD2C\",\"#FDE724\"]},\"id\":\"10190\",\"type\":\"LinearColorMapper\"},{\"attributes\":{\"text\":\"Ambient PM\\u2082.\\u2085 concentration (India = 75.4 \\u03bcg/m\\u00b3)\"},\"id\":\"10192\",\"type\":\"Title\"},{\"attributes\":{\"data_source\":{\"id\":\"10189\"},\"glyph\":{\"id\":\"10264\"},\"hover_glyph\":null,\"muted_glyph\":null,\"nonselection_glyph\":{\"id\":\"10265\"},\"view\":{\"id\":\"10267\"}},\"id\":\"10266\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"active_multi\":null,\"logo\":null,\"tools\":[{\"id\":\"10251\"},{\"id\":\"10252\"},{\"id\":\"10253\"},{\"id\":\"10254\"},{\"id\":\"10255\"}]},\"id\":\"10256\",\"type\":\"Toolbar\"},{\"attributes\":{\"center\":[{\"id\":\"10205\"},{\"id\":\"10209\"}],\"height\":400,\"renderers\":[{\"id\":\"10225\"}],\"title\":{\"id\":\"10192\"},\"toolbar\":{\"id\":\"10215\"},\"toolbar_location\":null,\"width\":400,\"x_range\":{\"id\":\"10194\"},\"x_scale\":{\"id\":\"10198\"},\"y_range\":{\"id\":\"10196\"},\"y_scale\":{\"id\":\"10200\"}},\"id\":\"10191\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{},\"id\":\"10194\",\"type\":\"DataRange1d\"},{\"attributes\":{\"child\":{\"id\":\"10273\"},\"title\":\"BASELINE\"},\"id\":\"10312\",\"type\":\"Panel\"},{\"attributes\":{},\"id\":\"10211\",\"type\":\"WheelZoomTool\"},{\"attributes\":{\"child\":{\"id\":\"10191\"},\"title\":\"BASELINE\"},\"id\":\"10230\",\"type\":\"Panel\"},{\"attributes\":{},\"id\":\"10200\",\"type\":\"LinearScale\"},{\"attributes\":{\"high\":50000,\"low\":-50000,\"palette\":[\"#003c30\",\"#01665e\",\"#35978f\",\"#80cdc1\",\"#c7eae5\",\"#f6e8c3\",\"#dfc27d\",\"#bf812d\",\"#8c510a\",\"#543005\"]},\"id\":\"10313\",\"type\":\"LinearColorMapper\"},{\"attributes\":{\"high\":50,\"low\":-50,\"palette\":[\"#003c30\",\"#01665e\",\"#35978f\",\"#80cdc1\",\"#c7eae5\",\"#f6e8c3\",\"#dfc27d\",\"#bf812d\",\"#8c510a\",\"#543005\"]},\"id\":\"10231\",\"type\":\"LinearColorMapper\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.7},\"fill_color\":{\"field\":\"apm25_popweighted\",\"transform\":{\"id\":\"10231\"}},\"line_color\":{\"value\":\"grey\"},\"line_width\":{\"value\":0.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"10264\",\"type\":\"Patches\"},{\"attributes\":{\"source\":{\"id\":\"10188\"}},\"id\":\"10226\",\"type\":\"CDSView\"},{\"attributes\":{\"tabs\":[{\"id\":\"10312\"},{\"id\":\"10353\"}]},\"id\":\"10355\",\"type\":\"Tabs\"},{\"attributes\":{\"text\":\"Ambient PM\\u2082.\\u2085 concentration (India = -19.0 \\u03bcg/m\\u00b3, -25%)\"},\"id\":\"10233\",\"type\":\"Title\"},{\"attributes\":{},\"id\":\"10237\",\"type\":\"DataRange1d\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.7},\"fill_color\":{\"field\":\"apm25_popweighted\",\"transform\":{\"id\":\"10190\"}},\"line_color\":{\"value\":\"grey\"},\"line_width\":{\"value\":0.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"10223\",\"type\":\"Patches\"},{\"attributes\":{},\"id\":\"10244\",\"type\":\"BasicTicker\"},{\"attributes\":{\"center\":[{\"id\":\"10246\"},{\"id\":\"10250\"}],\"height\":400,\"renderers\":[{\"id\":\"10266\"}],\"title\":{\"id\":\"10233\"},\"toolbar\":{\"id\":\"10256\"},\"toolbar_location\":null,\"width\":400,\"x_range\":{\"id\":\"10235\"},\"x_scale\":{\"id\":\"10239\"},\"y_range\":{\"id\":\"10237\"},\"y_scale\":{\"id\":\"10241\"}},\"id\":\"10232\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{\"child\":{\"id\":\"10314\"},\"title\":\"ALLLPG\"},\"id\":\"10353\",\"type\":\"Panel\"},{\"attributes\":{},\"id\":\"10235\",\"type\":\"DataRange1d\"},{\"attributes\":{\"data_source\":{\"id\":\"10188\"},\"glyph\":{\"id\":\"10223\"},\"hover_glyph\":null,\"muted_glyph\":null,\"nonselection_glyph\":{\"id\":\"10224\"},\"view\":{\"id\":\"10226\"}},\"id\":\"10225\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"10241\",\"type\":\"LinearScale\"},{\"attributes\":{\"child\":{\"id\":\"10232\"},\"title\":\"ALLLPG\"},\"id\":\"10271\",\"type\":\"Panel\"},{\"attributes\":{},\"id\":\"10214\",\"type\":\"SaveTool\"},{\"attributes\":{},\"id\":\"10335\",\"type\":\"ResetTool\"},{\"attributes\":{},\"id\":\"10330\",\"type\":\"BasicTicker\"},{\"attributes\":{\"text\":\"MORT from total PM\\u2082.\\u2085 exposure (India = 1,190,000 deaths)\"},\"id\":\"10274\",\"type\":\"Title\"},{\"attributes\":{\"axis\":{\"id\":\"10329\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"10332\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"10203\",\"type\":\"BasicTicker\"},{\"attributes\":{},\"id\":\"10276\",\"type\":\"DataRange1d\"},{\"attributes\":{},\"id\":\"10282\",\"type\":\"LinearScale\"},{\"attributes\":{},\"id\":\"10334\",\"type\":\"WheelZoomTool\"},{\"attributes\":{\"formatter\":{\"id\":\"10753\"},\"major_label_policy\":{\"id\":\"10752\"},\"ticker\":{\"id\":\"10289\"}},\"id\":\"10288\",\"type\":\"LinearAxis\"},{\"attributes\":{},\"id\":\"10278\",\"type\":\"DataRange1d\"},{\"attributes\":{},\"id\":\"10333\",\"type\":\"PanTool\"},{\"attributes\":{\"formatter\":{\"id\":\"10734\"},\"major_label_policy\":{\"id\":\"10733\"},\"ticker\":{\"id\":\"10203\"}},\"id\":\"10202\",\"type\":\"LinearAxis\"},{\"attributes\":{},\"id\":\"10280\",\"type\":\"LinearScale\"},{\"attributes\":{\"formatter\":{\"id\":\"10750\"},\"major_label_policy\":{\"id\":\"10749\"},\"ticker\":{\"id\":\"10285\"}},\"id\":\"10284\",\"type\":\"LinearAxis\"},{\"attributes\":{},\"id\":\"10733\",\"type\":\"AllLabels\"},{\"attributes\":{},\"id\":\"10285\",\"type\":\"BasicTicker\"},{\"attributes\":{\"axis\":{\"id\":\"10284\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"10287\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"10734\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"axis\":{\"id\":\"10288\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"10291\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"10293\",\"type\":\"WheelZoomTool\"},{\"attributes\":{\"source\":{\"id\":\"10189\"}},\"id\":\"10349\",\"type\":\"CDSView\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.1},\"fill_color\":{\"field\":\"mort_tpm25_6cod_mean_total\",\"transform\":{\"id\":\"10272\"}},\"line_alpha\":{\"value\":0.1},\"line_color\":{\"value\":\"grey\"},\"line_width\":{\"value\":0.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"10306\",\"type\":\"Patches\"},{\"attributes\":{},\"id\":\"10736\",\"type\":\"AllLabels\"},{\"attributes\":{},\"id\":\"10737\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{},\"id\":\"10289\",\"type\":\"BasicTicker\"},{\"attributes\":{\"active_multi\":null,\"logo\":null,\"tools\":[{\"id\":\"10333\"},{\"id\":\"10334\"},{\"id\":\"10335\"},{\"id\":\"10336\"},{\"id\":\"10337\"}]},\"id\":\"10338\",\"type\":\"Toolbar\"},{\"attributes\":{},\"id\":\"10296\",\"type\":\"SaveTool\"},{\"attributes\":{\"data_source\":{\"id\":\"10189\"},\"glyph\":{\"id\":\"10346\"},\"hover_glyph\":null,\"muted_glyph\":null,\"nonselection_glyph\":{\"id\":\"10347\"},\"view\":{\"id\":\"10349\"}},\"id\":\"10348\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"10292\",\"type\":\"PanTool\"},{\"attributes\":{},\"id\":\"10294\",\"type\":\"ResetTool\"},{\"attributes\":{\"callback\":null,\"point_policy\":\"follow_mouse\",\"tooltips\":[[\"Scenario\",\"BASELINE\"],[\"State\",\"@NAME_1\"],[\"MORT from total PM\\u2082.\\u2085 exposure\",\"@mort_tpm25_6cod_mean_total deaths\"],[\"(Lon, Lat)\",\"($x, $y)\"]]},\"id\":\"10295\",\"type\":\"HoverTool\"},{\"attributes\":{},\"id\":\"10739\",\"type\":\"Selection\"},{\"attributes\":{},\"id\":\"10740\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"10337\",\"type\":\"SaveTool\"},{\"attributes\":{\"callback\":null,\"point_policy\":\"follow_mouse\",\"tooltips\":[[\"Scenario\",\"ALLLPG\"],[\"State\",\"@NAME_1\"],[\"MORT from total PM\\u2082.\\u2085 exposure\",\"@mort_tpm25_6cod_mean_total deaths\"],[\"(Lon, Lat)\",\"($x, $y)\"]]},\"id\":\"10336\",\"type\":\"HoverTool\"},{\"attributes\":{},\"id\":\"10741\",\"type\":\"AllLabels\"},{\"attributes\":{\"callback\":null,\"point_policy\":\"follow_mouse\",\"tooltips\":[[\"Scenario\",\"ALLLPG\"],[\"State\",\"@NAME_1\"],[\"Ambient PM\\u2082.\\u2085 concentration\",\"@apm25_popweighted \\u03bcg/m\\u00b3\"],[\"(Lon, Lat)\",\"($x, $y)\"]]},\"id\":\"10254\",\"type\":\"HoverTool\"},{\"attributes\":{},\"id\":\"10742\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.1},\"fill_color\":{\"field\":\"mort_tpm25_6cod_mean_total\",\"transform\":{\"id\":\"10313\"}},\"line_alpha\":{\"value\":0.1},\"line_color\":{\"value\":\"grey\"},\"line_width\":{\"value\":0.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"10347\",\"type\":\"Patches\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.1},\"fill_color\":{\"field\":\"apm25_popweighted\",\"transform\":{\"id\":\"10231\"}},\"line_alpha\":{\"value\":0.1},\"line_color\":{\"value\":\"grey\"},\"line_width\":{\"value\":0.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"10265\",\"type\":\"Patches\"},{\"attributes\":{\"geojson\":\"{\\\"type\\\": \\\"FeatureCollection\\\", \\\"features\\\": [{\\\"id\\\": \\\"0\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.1_1\\\", \\\"HASC_1\\\": \\\"IN.AN\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Andaman and Nicobar\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": \\\"Andaman & Nicobar Islands|Andaman et Nicobar|Iihas de Andama e Nicobar|Inseln Andamanen und Nikobare\\\", \\\"apm25_popweighted\\\": -1.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 769.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1897.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1128.0, \\\"geo-id\\\": 0, \\\"hpm25_child_popweighted\\\": -260.0, \\\"hpm25_female_popweighted\\\": -299.0, \\\"hpm25_male_popweighted\\\": -215.0, \\\"location\\\": \\\"Andaman and Nicobar\\\", \\\"mort_apm25_6cod_mean_total\\\": 36.0, \\\"mort_hpm25_6cod_mean_total\\\": -85.0, \\\"mort_tpm25_6cod_mean_total\\\": -49.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[93.78772736, 6.85264015], [93.7884903, 6.85257101], [93.78904724, 6.85257101], [93.78904724, 6.85229111], [93.78967285, 6.85229111], [93.78987885, 6.85201311], [93.7901535, 6.85194492], [93.79064178, 6.85166693], [93.79077911, 6.85138893], [93.79091644, 6.85104179], [93.79050446, 6.85062504], [93.79029083, 6.85034704], [93.79000092, 6.85027885], [93.78948212, 6.84990311], [93.78900146, 6.84948492], [93.78837585, 6.84913683], [93.78801727, 6.84872007], [93.78778076, 6.84805584], [93.7875061, 6.84806108], [93.78721619, 6.84778118], [93.78639221, 6.84778118], [93.78610992, 6.84806108], [93.78527832, 6.84806108], [93.78443909, 6.84889984], [93.78444672, 6.84916592], [93.78549194, 6.84992981], [93.78625488, 6.85062504], [93.78676605, 6.85117197], [93.78694153, 6.85167122], [93.7873764, 6.85166693], [93.7873764, 6.85208416], [93.78730774, 6.85235882], [93.7873764, 6.85257101], [93.78772736, 6.85264015]]], [[[93.84874725, 7.28986883], [93.84867859, 7.28945684], [93.84784698, 7.28883219], [93.84694672, 7.28813887], [93.84666443, 7.28723717], [93.84632111, 7.28689003], [93.84625244, 7.28613091], [93.84590149, 7.28564119], [93.84500122, 7.28555489], [93.84471893, 7.28583288], [93.84471893, 7.28694487], [93.84415436, 7.28760815], [93.84415436, 7.28809404], [93.84422302, 7.28844023], [93.84432983, 7.28849316], [93.84464264, 7.28865004], [93.8449173, 7.28844023], [93.84554291, 7.28837204], [93.84583282, 7.28947878], [93.84630585, 7.28969097], [93.84700012, 7.28962088], [93.84720612, 7.28983021], [93.84755707, 7.29017878], [93.8483429, 7.29043007], [93.84874725, 7.28986883]]], [[[93.7195816, 7.20750093], [93.7195816, 7.20687008], [93.71930695, 7.20646], [93.71881866, 7.20639086], [93.71826172, 7.20653009], [93.71749878, 7.20695019], [93.71583557, 7.20694494], [93.71555328, 7.20722294], [93.71499634, 7.20722294], [93.71472168, 7.20694494], [93.71360779, 7.20694494], [93.71333313, 7.20722294], [93.71305847, 7.20722103], [93.71221924, 7.20805502], [93.71221924, 7.20888901], [93.71166992, 7.20944118], [93.71166992, 7.21527815], [93.71138763, 7.21555614], [93.71138763, 7.2158308], [93.71098328, 7.21702099], [93.71021271, 7.21813107], [93.7097168, 7.21889019], [93.70861053, 7.21999979], [93.70861053, 7.22249985], [93.70833588, 7.22277784], [93.70833588, 7.22360992], [93.70805359, 7.22388792], [93.70805359, 7.22416592], [93.70749664, 7.22472191], [93.70749664, 7.2249999], [93.70666504, 7.22583485], [93.70666504, 7.22610998], [93.70639038, 7.22638798], [93.70639038, 7.22694397], [93.70667267, 7.22722006], [93.70667267, 7.22750092], [93.70694733, 7.22777891], [93.70694733, 7.22805405], [93.70722198, 7.22833204], [93.70722198, 7.22861099], [93.70804596, 7.22944021], [93.70804596, 7.23000097], [93.70852661, 7.23090076], [93.70909119, 7.23124981], [93.7097168, 7.23124981], [93.71013641, 7.23062086], [93.71062469, 7.23041296], [93.71083069, 7.2299962], [93.71076202, 7.22923279], [93.71076202, 7.22840118], [93.71131897, 7.22770596], [93.71179962, 7.22729111], [93.7122879, 7.2270112], [93.7122879, 7.22659588], [93.71221924, 7.22617912], [93.71263885, 7.2257638], [93.71311951, 7.22534704], [93.71353912, 7.22486115], [93.71367645, 7.22382021], [93.71360779, 7.22194386], [93.71611023, 7.2194438], [93.71611023, 7.2191658], [93.71639252, 7.21888781], [93.71639252, 7.21832895], [93.71666718, 7.2180562], [93.71666718, 7.21777821], [93.71721649, 7.21721888], [93.71722412, 7.21694422], [93.71833038, 7.2158308], [93.71909332, 7.21569204], [93.71937561, 7.21534395], [93.71986389, 7.21458197], [93.72041321, 7.21409512], [93.72090149, 7.21402597], [93.72117615, 7.21360922], [93.7215271, 7.21312189], [93.72138977, 7.21270704], [93.72103882, 7.21222115], [93.72055817, 7.21166706], [93.72027588, 7.21138906], [93.72027588, 7.21110916], [93.72000122, 7.21083307], [93.72000122, 7.21027708], [93.71971893, 7.20999908], [93.71971893, 7.209167], [93.71971893, 7.20798397], [93.7195816, 7.20750093]]], [[[93.66369629, 7.38403177], [93.66373444, 7.38379717], [93.66410828, 7.38380098], [93.66423035, 7.38376713], [93.66426086, 7.38403177], [93.6653595, 7.38403177], [93.66534424, 7.38376713], [93.66622162, 7.38372612], [93.6661911, 7.38353014], [93.6656189, 7.38351917], [93.6656189, 7.38324118], [93.66538239, 7.38324118], [93.66537476, 7.38349104], [93.66526031, 7.38348913], [93.66424561, 7.38347816], [93.66424561, 7.38321304], [93.66409302, 7.38324118], [93.66370392, 7.38322687], [93.66370392, 7.38350487], [93.66342926, 7.38349104], [93.663414, 7.38321304], [93.66203308, 7.38321114], [93.66202545, 7.38347816], [93.66233063, 7.38351917], [93.66233063, 7.38378286], [93.66339874, 7.38378096], [93.66340637, 7.38404989], [93.66369629, 7.38403177]]], [[[93.76860809, 7.40221882], [93.77111053, 7.39972115], [93.77166748, 7.39972115], [93.77194214, 7.39944506], [93.77194214, 7.39888906], [93.77249908, 7.39833307], [93.77249908, 7.39805508], [93.77222443, 7.39777708], [93.7722168, 7.39750099], [93.77194214, 7.39722109], [93.77194214, 7.39611101], [93.77222443, 7.39583302], [93.77222443, 7.39527702], [93.77111053, 7.39416695], [93.77083588, 7.39416885], [93.77054596, 7.39389086], [93.77027893, 7.39389086], [93.76999664, 7.39362001], [93.76832581, 7.39362001], [93.76805878, 7.39389086], [93.76777649, 7.39389086], [93.76750183, 7.39416885], [93.76721954, 7.39416885], [93.76693726, 7.39389086], [93.76611328, 7.39388895], [93.76555634, 7.39444494], [93.76526642, 7.39444017], [93.7647171, 7.39500093], [93.76444244, 7.39500093], [93.76416779, 7.39528084], [93.7638855, 7.39527702], [93.76277924, 7.39638901], [93.76277924, 7.396667], [93.76249695, 7.39694118], [93.76249695, 7.39777708], [93.76222229, 7.39805508], [93.76249695, 7.39833307], [93.76249695, 7.39861107], [93.7664032, 7.4024992], [93.76638794, 7.40277815], [93.76667023, 7.40305614], [93.76667023, 7.4033308], [93.76721954, 7.40389013], [93.76777649, 7.40389013], [93.76832581, 7.4033308], [93.76833344, 7.40305614], [93.76860809, 7.40277815], [93.76860809, 7.40221882]]], [[[93.6894455, 7.40972185], [93.68972015, 7.40944386], [93.69000244, 7.40944386], [93.6902771, 7.40916586], [93.69055176, 7.40916586], [93.69083405, 7.40944386], [93.6911087, 7.40944386], [93.69139099, 7.40916586], [93.69139099, 7.40888786], [93.69167328, 7.40860081], [93.69194794, 7.40861177], [93.6922226, 7.40833378], [93.6922226, 7.40805578], [93.69166565, 7.40749979], [93.69167328, 7.40722179], [93.69139099, 7.4069438], [93.69139099, 7.40638781], [93.6911087, 7.40611219], [93.6911087, 7.40500021], [93.69139099, 7.40472221], [93.69139099, 7.40416813], [93.69166565, 7.40389013], [93.69167328, 7.4036088], [93.69249725, 7.40277815], [93.69277954, 7.40279102], [93.6938858, 7.40166998], [93.6938858, 7.40139008], [93.69416046, 7.40110922], [93.69416809, 7.40083313], [93.69444275, 7.40055513], [93.69444275, 7.40027714], [93.69473267, 7.39999914], [93.69472504, 7.39972115], [93.69499969, 7.39944506], [93.69499969, 7.39888906], [93.69416809, 7.39805508], [93.69361115, 7.39805984], [93.69333649, 7.39777899], [93.69277954, 7.39777899], [93.69249725, 7.39750099], [93.6922226, 7.39750099], [93.69194794, 7.39722109], [93.69166565, 7.39722109], [93.69139099, 7.396945], [93.6911087, 7.396945], [93.69083405, 7.396667], [93.6894455, 7.396667], [93.68916321, 7.396945], [93.68805695, 7.396945], [93.68777466, 7.39722109], [93.6875, 7.39722109], [93.68444824, 7.40027714], [93.68444824, 7.40055513], [93.68416595, 7.40083313], [93.68416595, 7.40111113], [93.6838913, 7.40139008], [93.6838913, 7.40194607], [93.68360901, 7.4022212], [93.68360901, 7.4036088], [93.68333435, 7.40389013], [93.68360901, 7.40416813], [93.68360901, 7.40472221], [93.68305206, 7.40527821], [93.68307495, 7.40613699], [93.68332672, 7.40639019], [93.68360901, 7.40638781], [93.68444824, 7.40722179], [93.6847229, 7.40722179], [93.68554688, 7.40806103], [93.68583679, 7.40805578], [93.68611145, 7.40833378], [93.6866684, 7.40832901], [93.6875, 7.40917015], [93.6883316, 7.40916586], [93.68888855, 7.40972185], [93.6894455, 7.40972185]]], [[[93.77706146, 6.88065004], [93.77781677, 6.88065004], [93.77813721, 6.88032913], [93.77841949, 6.88040209], [93.77870178, 6.88068008], [93.77916718, 6.88055515], [93.77923584, 6.88096905], [93.77937317, 6.88118076], [93.77972412, 6.8815279], [93.77965546, 6.88173485], [93.7795105, 6.88180399], [93.77972412, 6.88201284], [93.77972412, 6.88284683], [93.77993011, 6.88312483], [93.78013611, 6.8836112], [93.77993774, 6.88382101], [93.77971649, 6.88389111], [93.77944183, 6.88417196], [93.77805328, 6.88416719], [93.77777863, 6.88444519], [93.77749634, 6.88444519], [93.77722168, 6.88472319], [93.77722168, 6.88500118], [93.77833557, 6.88611078], [93.77833557, 6.88638878], [93.77999878, 6.88805485], [93.77999878, 6.88833094], [93.78055573, 6.88888884], [93.78055573, 6.88916683], [93.78083038, 6.88944292], [93.78083038, 6.89027691], [93.77999878, 6.89111185], [93.77971649, 6.89111185], [93.77944183, 6.89138985], [93.77916718, 6.89138985], [93.77896118, 6.89118004], [93.77888489, 6.89116383], [93.77861023, 6.89111185], [93.77833557, 6.89083385], [93.77805328, 6.89083385], [93.77785492, 6.8906312], [93.77777863, 6.8905549], [93.77694702, 6.8905549], [93.77666473, 6.89083385], [93.77639008, 6.89083385], [93.77500153, 6.89222097], [93.77471924, 6.89222097], [93.77388763, 6.89306021], [93.77305603, 6.89305592], [93.77249908, 6.89361191], [93.77166748, 6.89360905], [93.77138519, 6.8938899], [93.77138519, 6.89527798], [93.77173615, 6.89583397], [93.77166748, 6.89611006], [93.77166748, 6.89638996], [93.77111053, 6.8969512], [93.77027893, 6.8969512], [93.76953888, 6.89621878], [93.76940155, 6.89586115], [93.76912689, 6.89515877], [93.76850128, 6.89488602], [93.76808167, 6.89509487], [93.76794434, 6.89537096], [93.76787567, 6.89564896], [93.76787567, 6.89606619], [93.76759338, 6.89662313], [93.76759338, 6.89717913], [93.76731873, 6.89780283], [93.76711273, 6.89822006], [93.76689911, 6.89870787], [93.76689911, 6.89925909], [93.7669754, 6.8997488], [93.7671814, 6.90009594], [93.76745605, 6.90037394], [93.76766968, 6.90065193], [93.76805878, 6.90111017], [93.76805878, 6.90166616], [93.76777649, 6.90194416], [93.76777649, 6.90221977], [93.76721954, 6.90277815], [93.76708221, 6.90298605], [93.76694489, 6.90319586], [93.76667023, 6.90333223], [93.76638794, 6.90333223], [93.76611328, 6.90361023], [93.76583099, 6.90361023], [93.76555634, 6.90389109], [93.76499939, 6.90417099], [93.7647171, 6.90500116], [93.76472473, 6.90527916], [93.76444244, 6.90555716], [93.76423645, 6.90582991], [93.76416779, 6.90611982], [93.76361084, 6.90660095], [93.76277924, 6.90777922], [93.76361084, 6.90861082], [93.76444244, 6.90861082], [93.7647171, 6.9088912], [93.76527405, 6.90888882], [93.76555634, 6.90916681], [93.76555634, 6.90944481], [93.76583099, 6.9097209], [93.76583099, 6.91027689], [93.76611328, 6.91055489], [93.76611328, 6.91111088], [93.7664032, 6.91166878], [93.7664566, 6.91271114], [93.7664032, 6.91306019], [93.76638794, 6.91388893], [93.76611328, 6.91416693], [93.76611328, 6.91444492], [93.76583099, 6.91472292], [93.76583099, 6.91498995], [93.76444244, 6.91638899], [93.76277924, 6.91638899], [93.76261139, 6.91622305], [93.76222229, 6.91583109], [93.76194763, 6.915833], [93.75971985, 6.91361094], [93.7591629, 6.91361094], [93.75888824, 6.91333294], [93.7583313, 6.91333294], [93.75694275, 6.91194487], [93.75694275, 6.91138887], [93.75666809, 6.91111088], [93.75666809, 6.90972281], [93.7563858, 6.90944481], [93.7563858, 6.90916681], [93.75416565, 6.90694523], [93.75367737, 6.90708399], [93.7527771, 6.90722322], [93.75222015, 6.90742111], [93.75187683, 6.90758085], [93.75166321, 6.90778112], [93.75111389, 6.90805483], [93.75076294, 6.90812492], [93.75055695, 6.90832996], [93.75, 6.90888882], [93.75, 6.90916681], [93.74972534, 6.90944481], [93.74973297, 6.9097209], [93.74888611, 6.91055489], [93.74854279, 6.91152811], [93.74833679, 6.91222286], [93.74833679, 6.91277695], [93.74777985, 6.91333294], [93.74777985, 6.91361094], [93.74749756, 6.91388893], [93.74749756, 6.91444492], [93.7472229, 6.91472292], [93.74708557, 6.91534805], [93.74694824, 6.915833], [93.7472229, 6.91611099], [93.7472229, 6.91638899], [93.74694824, 6.91666985], [93.74694824, 6.91777706], [93.74666595, 6.91805601], [93.74666595, 6.91833401], [93.7444458, 6.92055607], [93.7444458, 6.92082882], [93.74388885, 6.92139006], [93.74388885, 6.92166615], [93.74333191, 6.92222214], [93.74333191, 6.92250013], [93.74277496, 6.92305613], [93.74276733, 6.92361021], [93.74250031, 6.92388821], [93.74250031, 6.9241662], [93.74222565, 6.9244442], [93.74222565, 6.92472219], [93.74194336, 6.92500019], [93.74194336, 6.92666578], [93.74187469, 6.92701483], [93.74190521, 6.92739296], [93.74195099, 6.92798805], [93.7425766, 6.92847109], [93.7427063, 6.9289608], [93.74305725, 6.92917109], [93.74333954, 6.92917109], [93.74375153, 6.92889118], [93.74410248, 6.9289608], [93.74430847, 6.92902994], [93.74460602, 6.92954922], [93.74495697, 6.92954922], [93.74565125, 6.9294219], [93.74607086, 6.92925978], [93.7468338, 6.92888784], [93.7472229, 6.92889118], [93.7480011, 6.92870092], [93.74820709, 6.92848921], [93.74848938, 6.92842102], [93.74917603, 6.92855978], [93.74980164, 6.92870092], [93.75028992, 6.9286952], [93.75064087, 6.92889977], [93.7507782, 6.92938995], [93.75125885, 6.92974091], [93.75138855, 6.92999983], [93.75138855, 6.93055391], [93.75110626, 6.93083], [93.75111389, 6.9313879], [93.75138855, 6.9316659], [93.75139618, 6.93221998], [93.75111389, 6.93250084], [93.75111389, 6.93277884], [93.75096893, 6.93347216], [93.75110626, 6.93449879], [93.75166321, 6.93527889], [93.75166321, 6.93638897], [93.75222015, 6.93694496], [93.75222015, 6.93888903], [93.75138855, 6.93972111], [93.75138855, 6.9399991], [93.74944305, 6.94194508], [93.74944305, 6.94222116], [93.74972534, 6.94249916], [93.74993134, 6.94284582], [93.75027466, 6.94319201], [93.75055695, 6.94381905], [93.75055695, 6.94444323], [93.75069427, 6.94492912], [93.75055695, 6.94611216], [93.75027466, 6.94639015], [93.75027466, 6.94722223], [93.74972534, 6.94777822], [93.74972534, 6.94861221], [93.74861145, 6.94972181], [93.74832916, 6.94971991], [93.74804688, 6.94999981], [93.74777985, 6.94999981], [93.74749756, 6.95028019], [93.7472229, 6.95027781], [93.74666595, 6.9508338], [93.74666595, 6.95166588], [93.7463913, 6.95194387], [93.7463913, 6.95222187], [93.74666595, 6.95249987], [93.74666595, 6.95333385], [93.74694824, 6.95360994], [93.74742889, 6.95401096], [93.74812317, 6.95436716], [93.74840546, 6.95464516], [93.74861145, 6.95520115], [93.74861145, 6.95562887], [93.74832916, 6.95686913], [93.74812317, 6.95700979], [93.7472229, 6.95722198], [93.74666595, 6.95777893], [93.74666595, 6.95833206], [93.7463913, 6.95861006], [93.7463913, 6.959445], [93.74610901, 6.95972013], [93.74610901, 6.96000099], [93.74583435, 6.96027613], [93.74583435, 6.96083307], [93.74555206, 6.96111107], [93.74555206, 6.96138906], [93.7452774, 6.96166706], [93.7452774, 6.96194506], [93.74472046, 6.96250105], [93.7444458, 6.96250105], [93.74388885, 6.96305895], [93.7436142, 6.96305513], [93.74333191, 6.96333313], [93.74250031, 6.96333313], [93.74222565, 6.96305513], [93.74194336, 6.96305895], [93.73916626, 6.96028996], [93.7388916, 6.96028996], [93.73860931, 6.96000099], [93.73860931, 6.95972013], [93.73805237, 6.959167], [93.73638916, 6.959167], [93.7361145, 6.959445], [93.73583221, 6.95944023], [93.7352829, 6.96000099], [93.73527527, 6.96027613], [93.73500061, 6.96055508], [93.73527527, 6.96083307], [93.73527527, 6.96111107], [93.73500061, 6.96235991], [93.73500061, 6.96292019], [93.73500061, 6.96388912], [93.73527527, 6.96416712], [93.7352829, 6.9658308], [93.73443604, 6.96666908], [93.73305511, 6.96666718], [93.73200989, 6.96763992], [93.7317276, 6.96820116], [93.73132324, 6.96917009], [93.73117065, 6.96955919], [93.73123932, 6.97108889], [93.73165894, 6.97164297], [93.73165894, 6.97199106], [93.73179626, 6.97254705], [93.73228455, 6.97303295], [93.73239136, 6.9742341], [93.73253632, 6.97448206], [93.73278046, 6.97472191], [93.73278046, 6.9749999], [93.73305511, 6.9752779], [93.73305511, 6.97583389], [93.73332977, 6.97611189], [93.73332977, 6.97694397], [93.73361206, 6.97722006], [93.73332977, 6.97749996], [93.73332977, 6.97777796], [93.73305511, 6.97805595], [93.73305511, 6.97833395], [93.73278046, 6.97861004], [93.73278046, 6.97916603], [93.7325592, 6.97972012], [93.73242188, 6.98006916], [93.73200989, 6.98048592], [93.7317276, 6.98069286], [93.73145294, 6.98103905], [93.73132324, 6.9813199], [93.73110199, 6.98188019], [93.73082733, 6.98236084], [93.73033905, 6.98250008], [93.73006439, 6.98291683], [93.72999573, 6.98361301], [93.72972107, 6.98423719], [93.72943878, 6.9845829], [93.72903442, 6.98497486], [93.72875977, 6.98539305], [93.72834015, 6.98552895], [93.72785187, 6.98595095], [93.72743988, 6.9860878], [93.72721863, 6.98666716], [93.72647858, 6.98770618], [93.72612762, 6.98805189], [93.72564697, 6.98860788], [93.72515869, 6.98902607], [93.72480774, 6.98943996], [93.72418976, 6.99006701], [93.72390747, 6.99076223], [93.72349548, 6.99117708], [93.7230072, 6.99194288], [93.72203827, 6.99194288], [93.72138977, 6.99222517], [93.72093201, 6.99254704], [93.7201004, 6.99289083], [93.71871185, 6.99324179], [93.71814728, 6.99351978], [93.71746063, 6.99380016], [93.71684265, 6.99387121], [93.71621704, 6.99380016], [93.71579742, 6.99359083], [93.71510315, 6.99339914], [93.71482086, 6.99312305], [93.71412659, 6.99277687], [93.71356964, 6.99249887], [93.71231842, 6.99277687], [93.71183777, 6.99298382], [93.71148682, 6.9929142], [93.71079254, 6.99228907], [93.71038055, 6.99187183], [93.71009827, 6.99117708], [93.70954895, 6.9908309], [93.70857239, 6.990345], [93.70822906, 6.99020576], [93.70746613, 6.98978901], [93.70670319, 6.98971796], [93.7062149, 6.9898572], [93.70526123, 6.9903698], [93.70463562, 6.99071884], [93.70373535, 6.99162102], [93.7033844, 6.99266291], [93.7033844, 6.99467802], [93.70374298, 6.9955802], [93.70407867, 6.99599695], [93.70456696, 6.99627495], [93.70506287, 6.9966898], [93.70568085, 6.99710989], [93.70588684, 6.99738503], [93.70602417, 6.99773407], [93.70602417, 6.99947119], [93.70609283, 6.99971914], [93.70639038, 7.0], [93.70610046, 7.0002799], [93.70555878, 7.00055981], [93.70555878, 7.00138998], [93.70527649, 7.00166607], [93.70527649, 7.00221014], [93.70500183, 7.00250006], [93.70500183, 7.00277805], [93.70471954, 7.00305605], [93.70471954, 7.00333405], [93.70443726, 7.00361013], [93.70444489, 7.00389004], [93.70417023, 7.00416613], [93.70417023, 7.00444412], [93.70388794, 7.00472212], [93.70388794, 7.00500011], [93.70361328, 7.00527811], [93.70361328, 7.00555611], [93.70333099, 7.0058341], [93.70333099, 7.00611019], [93.70305634, 7.00639009], [93.70305634, 7.00667095], [93.70166779, 7.00805616], [93.70166779, 7.00833416], [93.70139313, 7.00860977], [93.7013855, 7.00888777], [93.70111084, 7.00916576], [93.70111084, 7.00943995], [93.70054626, 7.01000023], [93.70027924, 7.01013899], [93.69958496, 7.01055717], [93.69958496, 7.01083183], [93.69958496, 7.01097107], [93.69930267, 7.01152706], [93.6986084, 7.01194382], [93.69833374, 7.01222277], [93.69805908, 7.012362], [93.69791412, 7.01250076], [93.69695282, 7.01332998], [93.69625092, 7.01361084], [93.69568634, 7.01389122], [93.69541931, 7.01389122], [93.69526672, 7.01417112], [93.69499969, 7.01416683], [93.69458008, 7.01472282], [93.69403076, 7.01471996], [93.6938858, 7.01514006], [93.69333649, 7.0152812], [93.6922226, 7.0155592], [93.6911087, 7.01617908], [93.68993378, 7.01645708], [93.68888855, 7.01722288], [93.6883316, 7.01722097], [93.68805695, 7.01750994], [93.68776703, 7.01750994], [93.6875, 7.01778078], [93.68694305, 7.01778078], [93.6866684, 7.01805878], [93.68638611, 7.01805496], [93.68611145, 7.01833296], [93.68583679, 7.01833296], [93.6855545, 7.01805496], [93.68444824, 7.01805878], [93.68305206, 7.01778078], [93.6819458, 7.01778078], [93.68165588, 7.01750994], [93.68110657, 7.01750994], [93.6808548, 7.01724815], [93.68027496, 7.01722288], [93.68011475, 7.01705885], [93.68000031, 7.01694489], [93.6791687, 7.01694489], [93.67861176, 7.01638889], [93.67749786, 7.0163908], [93.67694092, 7.01583004], [93.67666626, 7.01451492], [93.67666626, 7.01312685], [93.67646027, 7.01216078], [93.67582703, 7.01105118], [93.67547607, 7.00984097], [93.67492676, 7.00893784], [93.67458344, 7.007967], [93.6745224, 7.00719881], [93.67462921, 7.00532579], [93.67428589, 7.00442314], [93.67303467, 7.00345182], [93.67157745, 7.00303793], [93.66754913, 7.00303984], [93.66680145, 7.00339079], [93.66574097, 7.0039382], [93.66511536, 7.00421619], [93.66442108, 7.00470114], [93.66358948, 7.00588179], [93.66303253, 7.00664616], [93.66278076, 7.00750017], [93.66305542, 7.00777817], [93.66305542, 7.00860977], [93.66333008, 7.00888777], [93.66333008, 7.00971985], [93.66388702, 7.01027822], [93.66388702, 7.01055717], [93.66416931, 7.01083183], [93.66527557, 7.01083183], [93.66555786, 7.01110983], [93.66722107, 7.01110983], [93.66750336, 7.01138783], [93.66860962, 7.01166582], [93.66889191, 7.01194382], [93.66916656, 7.01194382], [93.67028046, 7.01305389], [93.67028046, 7.01471996], [93.66999817, 7.01500082], [93.66999817, 7.0155549], [93.67028046, 7.01583004], [93.67028046, 7.0163908], [93.67042542, 7.01778793], [93.67028809, 7.01869106], [93.66986847, 7.01945019], [93.67028046, 7.02000093], [93.67082977, 7.02057123], [93.67166901, 7.02055502], [93.67194366, 7.02083302], [93.67305756, 7.02083302], [93.67388916, 7.021667], [93.67388916, 7.021945], [93.67415619, 7.02222109], [93.67415619, 7.02388906], [93.6727829, 7.02528], [93.67250061, 7.02528], [93.67222595, 7.0255599], [93.67194366, 7.02555513], [93.67166901, 7.02583408], [93.67138672, 7.02583122], [93.66972351, 7.02750015], [93.66972351, 7.02805614], [93.66916656, 7.02861214], [93.66916656, 7.02944422], [93.66944122, 7.02972221], [93.66944122, 7.0305562], [93.66999817, 7.03111219], [93.67028046, 7.03146076], [93.6709671, 7.03174114], [93.67194366, 7.03229523], [93.6727066, 7.03340483], [93.67305756, 7.03493214], [93.67305756, 7.03632021], [93.67250061, 7.03722], [93.67082977, 7.03889084], [93.67056274, 7.03889084], [93.67028046, 7.03917122], [93.66999817, 7.03916597], [93.66972351, 7.03944492], [93.66944122, 7.03944492], [93.66916656, 7.03916597], [93.66860962, 7.03972292], [93.66805267, 7.03972006], [93.66777802, 7.04000092], [93.66750336, 7.04000092], [93.66722107, 7.04028082], [93.66694641, 7.04027891], [93.66527557, 7.04194498], [93.66527557, 7.04250097], [93.66472626, 7.04409218], [93.66493225, 7.04534101], [93.66479492, 7.04665995], [93.6644516, 7.04763079], [93.66437531, 7.04853392], [93.66514587, 7.04977989], [93.66578674, 7.05061007], [93.66617584, 7.05097914], [93.66629791, 7.05143976], [93.66664886, 7.05247402], [93.66720581, 7.05337715], [93.6676178, 7.05511093], [93.66748047, 7.05740213], [93.66750336, 7.05888796], [93.66750336, 7.05972004], [93.66722107, 7.05999994], [93.66722107, 7.06027794], [93.66750336, 7.06055593], [93.66750336, 7.06083393], [93.66777802, 7.06111002], [93.66777802, 7.06166601], [93.66805267, 7.06194401], [93.66805267, 7.06361008], [93.66833496, 7.06388807], [93.66858673, 7.06518078], [93.66858673, 7.06608486], [93.66833496, 7.06666708], [93.66805267, 7.06694508], [93.66333008, 7.06693983], [93.66249847, 7.06777906], [93.66249847, 7.06916714], [93.66222382, 7.06944513], [93.66222382, 7.06972313], [93.66249847, 7.07000113], [93.66249847, 7.07027721], [93.66278076, 7.07055521], [93.66278076, 7.07083321], [93.66305542, 7.0711112], [93.66305542, 7.07250118], [93.66388702, 7.07333279], [93.66388702, 7.07361078], [93.66500092, 7.07472277], [93.6652832, 7.07472086], [93.66583252, 7.07527685], [93.66583252, 7.07555485], [93.66611481, 7.07583284], [93.66611481, 7.07638884], [93.66664886, 7.07692719], [93.66722107, 7.07749891], [93.66750336, 7.07748985], [93.66805267, 7.07806015], [93.66832733, 7.07806015], [93.66916656, 7.07888985], [93.66916656, 7.07916784], [93.66971588, 7.07972097], [93.66972351, 7.07999897], [93.66999817, 7.08027792], [93.66999817, 7.08083391], [93.67028046, 7.08111191], [93.67028046, 7.08166599], [93.66999817, 7.08194399], [93.66999817, 7.08305597], [93.66972351, 7.08333397], [93.66972351, 7.08388996], [93.66777802, 7.08583403], [93.66750336, 7.08583021], [93.66694641, 7.08639002], [93.66666412, 7.08639002], [93.66638947, 7.08666611], [93.66583252, 7.08666611], [93.66555023, 7.08643293], [93.6652832, 7.08639002], [93.66500092, 7.08611012], [93.66471863, 7.08611202], [93.66444397, 7.08583403], [93.66416931, 7.08583403], [93.66388702, 7.08555603], [93.66361237, 7.0855608], [93.66333008, 7.08527994], [93.66306305, 7.08527994], [93.66280365, 7.08502483], [93.66139221, 7.08500004], [93.66055298, 7.08583403], [93.66055298, 7.08611202], [93.66027832, 7.08639002], [93.66014099, 7.0872221], [93.66014099, 7.08819103], [93.66000366, 7.09000015], [93.65919495, 7.09077787], [93.65865326, 7.09126091], [93.65828705, 7.0920949], [93.6578064, 7.09320688], [93.6576004, 7.09391785], [93.65719604, 7.09461117], [93.65719604, 7.09557676], [93.65744019, 7.09774494], [93.65727997, 7.09836006], [93.65721893, 7.09895992], [93.65727234, 7.09962082], [93.65750122, 7.10027695], [93.65750122, 7.10055494], [93.65777588, 7.10083294], [93.65777588, 7.10111094], [93.65833282, 7.10166693], [93.65860748, 7.10166693], [93.65916443, 7.10222292], [93.65944672, 7.10222101], [93.65966797, 7.10244417], [93.65972137, 7.10250092], [93.66194153, 7.10250092], [93.66221619, 7.10278177], [93.66249847, 7.10278177], [93.66278076, 7.10305977], [93.66333008, 7.103055], [93.66361237, 7.103333], [93.66388702, 7.103333], [93.66416931, 7.103055], [93.66443634, 7.10305977], [93.66471863, 7.10278177], [93.66555786, 7.102777], [93.66638947, 7.10361099], [93.66638947, 7.10416698], [93.66666412, 7.10444498], [93.66666412, 7.10472107], [93.66889191, 7.10694313], [93.66916656, 7.10694122], [93.66971588, 7.10750008], [93.66999054, 7.10750008], [93.67028046, 7.10779095], [93.67055511, 7.10777807], [93.67082977, 7.10805607], [93.67153168, 7.10832882], [93.67197418, 7.1085372], [93.67211151, 7.10860682], [93.67246246, 7.10888481], [93.67312622, 7.10916615], [93.67354584, 7.10965109], [93.67403412, 7.11027622], [93.67416382, 7.11055613], [93.67444611, 7.11083412], [93.67444611, 7.1116662], [93.67472076, 7.1119442], [93.67472076, 7.11250019], [93.67444611, 7.11277819], [93.67444611, 7.11305618], [93.67416382, 7.11333418], [93.67415619, 7.11360121], [93.6727829, 7.11499977], [93.67250061, 7.11499977], [93.67222595, 7.11528111], [93.67193604, 7.11528111], [93.67166901, 7.11556101], [93.67138672, 7.11527777], [93.67082977, 7.11583424], [93.67056274, 7.11582994], [93.66971588, 7.11667109], [93.66944122, 7.11666584], [93.66916656, 7.11694384], [93.66889191, 7.11694384], [93.66860962, 7.11722183], [93.66805267, 7.11721992], [93.66777802, 7.11749983], [93.66750336, 7.11749983], [93.66638947, 7.11638784], [93.66587067, 7.11507082], [93.6654129, 7.11486101], [93.66500092, 7.11465406], [93.66416931, 7.11361217], [93.66416931, 7.11305618], [93.66278076, 7.1116662], [93.66249847, 7.11167002], [93.66221619, 7.11139011], [93.66110992, 7.11139011], [93.6608429, 7.11167002], [93.66055298, 7.1116662], [93.66027832, 7.1119442], [93.65972137, 7.1119442], [93.65916443, 7.11180878], [93.65860748, 7.1119442], [93.65833282, 7.1119442], [93.65805817, 7.11222219], [93.65805817, 7.11305618], [93.65666962, 7.11444378], [93.65666962, 7.11472178], [93.65611267, 7.11527777], [93.65611267, 7.11555576], [93.65638733, 7.11583424], [93.65611267, 7.11610985], [93.65611267, 7.11638784], [93.65638733, 7.11666584], [93.65638733, 7.11721992], [93.65611267, 7.11749983], [93.65611267, 7.11972284], [93.65583038, 7.12000084], [93.65583038, 7.12111092], [93.65611267, 7.12138891], [93.65611267, 7.1222229], [93.65583038, 7.1225009], [93.65583038, 7.12472105], [93.65556335, 7.12500095], [93.65556335, 7.12528086], [93.65583038, 7.12555885], [93.65583038, 7.12638903], [93.65611267, 7.12666702], [93.65611267, 7.12694502], [93.65638733, 7.12722111], [93.65638733, 7.12750101], [93.65666962, 7.12778187], [93.65666962, 7.12806177], [93.65777588, 7.12916994], [93.65805817, 7.12916708], [93.65833282, 7.12944508], [93.65916443, 7.12944508], [93.6593399, 7.12961578], [93.65944672, 7.12972116], [93.66194153, 7.12972116], [93.66298676, 7.12985992], [93.66340637, 7.12985992], [93.66395569, 7.13007021], [93.66451263, 7.13069391], [93.66500092, 7.131248], [93.66555786, 7.13194323], [93.66596985, 7.13277483], [93.66638947, 7.13298512], [93.66680908, 7.1344409], [93.66708374, 7.13659286], [93.66708374, 7.13860512], [93.66750336, 7.13916111], [93.66838837, 7.13951015], [93.66916656, 7.13948011], [93.66966248, 7.13955116], [93.66972351, 7.13937616], [93.67010498, 7.13827705], [93.67077637, 7.13837004], [93.67182159, 7.13785982], [93.6727829, 7.13749981], [93.67305756, 7.13777781], [93.67333221, 7.13777113], [93.67360687, 7.13806009], [93.67388916, 7.1380558], [93.67527771, 7.13944387], [93.67527771, 7.13972187], [93.67582703, 7.13992882], [93.67590332, 7.14048481], [93.67630005, 7.14108896], [93.67685699, 7.14268017], [93.67694092, 7.143888], [93.67722321, 7.14416599], [93.67722321, 7.14472008], [93.67749786, 7.14499998], [93.67749786, 7.14528084], [93.67722321, 7.14527798], [93.67722321, 7.14555693], [93.67749786, 7.14583015], [93.67749786, 7.14638805], [93.67763519, 7.14659786], [93.67749786, 7.14687395], [93.67764282, 7.1470108], [93.67784882, 7.14750099], [93.67771149, 7.14874983], [93.67778015, 7.14916706], [93.67798615, 7.1496501], [93.67791748, 7.15021086], [93.67805481, 7.15055513], [93.67819214, 7.15124989], [93.67814636, 7.15166187], [93.67821503, 7.1523571], [93.67847443, 7.15277719], [93.6783371, 7.15472078], [93.6783371, 7.15527916], [93.67805481, 7.15555477], [93.67805481, 7.15583277], [93.67778015, 7.15611076], [93.67778015, 7.15694094], [93.67666626, 7.15806007], [93.6763916, 7.15805483], [93.67472076, 7.1597209], [93.67472076, 7.15999889], [93.67444611, 7.16028023], [93.67444611, 7.16055584], [93.67430878, 7.1618681], [93.67430878, 7.16339302], [93.67444611, 7.16555595], [93.67472076, 7.16582918], [93.67472076, 7.16750002], [93.67500305, 7.16777802], [93.67500305, 7.16805601], [93.67527771, 7.16833019], [93.67527771, 7.17055607], [93.67555237, 7.17083216], [93.67555237, 7.17111015], [93.67582703, 7.17139101], [93.67583466, 7.17277908], [93.67555237, 7.17305708], [93.67555237, 7.17361021], [93.67444611, 7.17472315], [93.67388916, 7.17472315], [93.67305756, 7.17555714], [93.67305756, 7.17583323], [93.67333221, 7.17582989], [93.67388916, 7.17638922], [93.67490387, 7.17649794], [93.67527771, 7.17694521], [93.67527771, 7.17722321], [93.6763916, 7.17833281], [93.6763916, 7.1788888], [93.67694092, 7.17944479], [93.67722321, 7.17944479], [93.67749786, 7.17972279], [93.67804718, 7.17972088], [93.67888641, 7.18056011], [93.67917633, 7.18056011], [93.68110657, 7.18250084], [93.68187714, 7.18277884], [93.68222046, 7.18277693], [93.68250275, 7.18284798], [93.68361664, 7.18347216], [93.68361664, 7.183887], [93.68360901, 7.1844449], [93.6838913, 7.18555498], [93.68416595, 7.18583298], [93.68416595, 7.18611097], [93.68444824, 7.18638992], [93.68444824, 7.18721914], [93.6847229, 7.18749905], [93.68444824, 7.187778], [93.6847229, 7.18805599], [93.6847229, 7.18833399], [93.68499756, 7.18861198], [93.68498993, 7.18888092], [93.68574524, 7.18963289], [93.68611145, 7.19000006], [93.68638611, 7.19000006], [93.68673706, 7.19013882], [93.68701172, 7.19027996], [93.68722534, 7.19027805], [93.68785095, 7.190485], [93.6883316, 7.190763], [93.6894455, 7.19083405], [93.68972015, 7.19069481], [93.69055176, 7.1908288], [93.69167328, 7.19139004], [93.69194794, 7.19188023], [93.69249725, 7.19166994], [93.69255829, 7.19131899], [93.69284821, 7.1909709], [93.6930542, 7.190485], [93.69333649, 7.19027805], [93.69381714, 7.19013882], [93.69526672, 7.19000006], [93.69555664, 7.18993092], [93.69604492, 7.18986082], [93.69645691, 7.18965101], [93.6966629, 7.18958282], [93.69694519, 7.18951416], [93.69728851, 7.18943214], [93.69779205, 7.18928385], [93.69911194, 7.18872786], [93.69988251, 7.188591], [93.70056915, 7.18866014], [93.70111084, 7.18860912], [93.7013855, 7.18861198], [93.70166779, 7.18888998], [93.70222473, 7.18888998], [93.70305634, 7.18972206], [93.70333099, 7.1897192], [93.70417023, 7.19055986], [93.70471954, 7.19055605], [93.70500183, 7.19083405], [93.70527649, 7.19083405], [93.70555878, 7.19111204], [93.70582581, 7.19111013], [93.70610046, 7.19139004], [93.70639038, 7.19145823], [93.70652771, 7.19156313], [93.70667267, 7.19166994], [93.70777893, 7.19166994], [93.70819092, 7.19159985], [93.70915985, 7.19139004], [93.70944214, 7.19131899], [93.7097168, 7.19139004], [93.70999908, 7.19139004], [93.71055603, 7.19139004], [93.71083069, 7.19166994], [93.71125031, 7.19187498], [93.71166992, 7.19194412], [93.71173859, 7.19208288], [93.71221924, 7.19222212], [93.71305847, 7.19222212], [93.71333313, 7.19215298], [93.71389008, 7.19194412], [93.7142334, 7.19187498], [93.71499634, 7.19166994], [93.71528625, 7.19139004], [93.7158432, 7.19139004], [93.71611023, 7.19111013], [93.71639252, 7.19111204], [93.71666718, 7.19083405], [93.71694183, 7.19083405], [93.71789551, 7.19044399], [93.71854401, 7.19000196], [93.71833038, 7.18888998], [93.71861267, 7.18861198], [93.71861267, 7.18833399], [93.71916962, 7.187778], [93.71943665, 7.1877799], [93.71971893, 7.18749905], [93.72000122, 7.1877799], [93.72138977, 7.1877799], [93.7216568, 7.18749905], [93.72222137, 7.18749905], [93.72249603, 7.18721914], [93.72277832, 7.18722105], [93.72305298, 7.18694305], [93.72333527, 7.18694305], [93.72360992, 7.18666792], [93.72389221, 7.18666983], [93.72416687, 7.18638992], [93.72471619, 7.18638992], [93.72499847, 7.18611097], [93.72528076, 7.18611097], [93.72555542, 7.18583298], [93.72611237, 7.18583298], [93.72638702, 7.18611097], [93.72693634, 7.18611097], [93.72722626, 7.18638992], [93.72750092, 7.18638992], [93.72805786, 7.18694305], [93.72833252, 7.18694115], [93.72888947, 7.18749905], [93.72944641, 7.18749905], [93.72972107, 7.18721914], [93.73027802, 7.18722105], [93.73055267, 7.18694305], [93.73222351, 7.18694305], [93.73249817, 7.18722105], [93.73361206, 7.18722105], [93.73388672, 7.18749905], [93.73486328, 7.18812418], [93.73562622, 7.18902588], [93.7363205, 7.18951178], [93.7371521, 7.19007015], [93.73860931, 7.19139004], [93.73972321, 7.19250011], [93.73972321, 7.19305611], [93.7408371, 7.19416618], [93.7408371, 7.19444418], [93.7444458, 7.19805622], [93.7444458, 7.19832993], [93.74500275, 7.19889116], [93.74500275, 7.19916582], [93.74610901, 7.20027924], [93.74654388, 7.20057297], [93.74772644, 7.20057011], [93.74793243, 7.20112896], [93.74862671, 7.20133591], [93.74918365, 7.20168304], [93.74946594, 7.2023778], [93.75001526, 7.20279217], [93.75092316, 7.20314121], [93.75119781, 7.20321178], [93.75196075, 7.20300007], [93.75231934, 7.20232296], [93.7527771, 7.20222282], [93.75305176, 7.20194483], [93.75332642, 7.20194006], [93.7538147, 7.2022891], [93.75444794, 7.2030549], [93.75416565, 7.20339394], [93.75444794, 7.2036109], [93.75376129, 7.20436478], [93.75337219, 7.20447016], [93.75263977, 7.20568895], [93.75166321, 7.20639086], [93.75166321, 7.20695019], [93.75222015, 7.20749903], [93.75222015, 7.20777702], [93.7527771, 7.20833302], [93.7527771, 7.20861101], [93.75389099, 7.20972109], [93.75389099, 7.20999002], [93.75417328, 7.21027899], [93.75417328, 7.21055984], [93.75499725, 7.21138906], [93.75583649, 7.21138906], [93.75611115, 7.21166992], [93.75666809, 7.21166706], [93.75749969, 7.21249914], [93.75888824, 7.21333313], [93.7591629, 7.21333122], [93.75952148, 7.21369123], [93.76000214, 7.21416998], [93.76027679, 7.21416807], [93.76042938, 7.21431589], [93.76055908, 7.21444607], [93.76139069, 7.21444607], [93.76166534, 7.21416807], [93.76194763, 7.21416998], [93.76222229, 7.21389008], [93.76249695, 7.21389008], [93.76277924, 7.21360922], [93.76305389, 7.21361208], [93.76333618, 7.21333313], [93.76416779, 7.21333313], [93.76444244, 7.21361208], [93.7647171, 7.21360922], [93.76499939, 7.21389008], [93.76555634, 7.21389008], [93.76583099, 7.21416998], [93.76611328, 7.21416998], [93.76667023, 7.21360922], [93.76582336, 7.21290684], [93.7647934, 7.21215296], [93.76472473, 7.21194506], [93.76444244, 7.21166706], [93.76423645, 7.21124983], [93.76423645, 7.2104888], [93.76451874, 7.20973015], [93.76513672, 7.20923996], [93.76590729, 7.20882082], [93.76667023, 7.20840597], [93.76722717, 7.20812798], [93.76819611, 7.20771122], [93.76882172, 7.20743513], [93.76951599, 7.20729589], [93.7701416, 7.2071619], [93.77139282, 7.20695019], [93.77305603, 7.20695019], [93.77333069, 7.20686102], [93.77397156, 7.20695019], [93.77444458, 7.20694494], [93.77493286, 7.20708418], [93.77527618, 7.20722103], [93.77583313, 7.20743084], [93.77749634, 7.20888901], [93.77749634, 7.209445], [93.77777863, 7.20972109], [93.77777863, 7.20999002], [93.77749634, 7.21027708], [93.77749634, 7.21055508], [93.77694702, 7.21111107], [93.77694702, 7.21138906], [93.77708435, 7.21194506], [93.77805328, 7.21194506], [93.77867889, 7.21208191], [93.77965546, 7.21221924], [93.78006744, 7.21229219], [93.78187561, 7.21235991], [93.78250122, 7.21249914], [93.78256989, 7.2126379], [93.78360748, 7.21333313], [93.78423309, 7.21346998], [93.78492737, 7.21326303], [93.78534698, 7.21235991], [93.78555298, 7.21194315], [93.78610992, 7.21159697], [93.78742981, 7.21097183], [93.78894806, 7.21110916], [93.78971863, 7.21138906], [93.790802, 7.21180582], [93.79156494, 7.21208191], [93.79219055, 7.21256781], [93.79260254, 7.21305323], [93.79322815, 7.2128458], [93.7935791, 7.21249914], [93.79379272, 7.21160984], [93.79392242, 7.21124983], [93.79427338, 7.21041584], [93.79515076, 7.2098918], [93.7957077, 7.20970106], [93.79676819, 7.20963383], [93.79725647, 7.20914888], [93.79774475, 7.20887089], [93.79795074, 7.20859098], [93.79808807, 7.20838499], [93.79857635, 7.207829], [93.79901123, 7.20683289], [93.79930115, 7.20655107], [93.79964447, 7.20634794], [93.80062103, 7.20627308], [93.8015213, 7.20613384], [93.80194092, 7.20592594], [93.80200958, 7.20571709], [93.80185699, 7.20482111], [93.80158997, 7.20405102], [93.80138397, 7.20349693], [93.8013916, 7.20277882], [93.8013916, 7.20250082], [93.80251312, 7.20139122], [93.80278015, 7.20166683], [93.80278015, 7.20194006], [93.8033371, 7.20250082], [93.8033371, 7.2030549], [93.80361176, 7.2033329], [93.80361176, 7.2036109], [93.80388641, 7.20388889], [93.80388641, 7.20416689], [93.8041687, 7.20444012], [93.8041687, 7.20527887], [93.80444336, 7.20555496], [93.80444336, 7.20722103], [93.8041687, 7.20750093], [93.8041687, 7.20777702], [93.80278015, 7.209167], [93.80256653, 7.20985985], [93.80271149, 7.21027708], [93.80249786, 7.21048689], [93.80249786, 7.21111107], [93.8033371, 7.21194506], [93.80361176, 7.21194506], [93.80388641, 7.21222115], [93.80500031, 7.21222115], [93.80555725, 7.21166706], [93.80555725, 7.21138906], [93.80606079, 7.21068096], [93.8069458, 7.20999002], [93.80722046, 7.20999908], [93.80805206, 7.21083307], [93.80784607, 7.21118021], [93.80805206, 7.21138906], [93.80819702, 7.21187496], [93.80860901, 7.21194506], [93.80882263, 7.2120142], [93.80944824, 7.21194506], [93.8097229, 7.21222115], [93.81027985, 7.21222115], [93.81054688, 7.21249914], [93.81083679, 7.21249914], [93.81159973, 7.21326303], [93.81163025, 7.21336794], [93.81194305, 7.21361208], [93.81149292, 7.21440887], [93.81083679, 7.2147212], [93.8105545, 7.2147212], [93.81027985, 7.21500015], [93.80860901, 7.2147212], [93.80805206, 7.2147212], [93.80770874, 7.21486092], [93.80750275, 7.21528006], [93.80735779, 7.21555996], [93.8069458, 7.21611214], [93.80659485, 7.21666622], [93.80666351, 7.21694422], [93.80659485, 7.21770716], [93.80632019, 7.2183342], [93.80638885, 7.21861219], [93.80596924, 7.21909714], [93.80626678, 7.21935701], [93.80652618, 7.21958303], [93.80750275, 7.2194438], [93.8077774, 7.2191658], [93.80805206, 7.21917915], [93.80854034, 7.21875095], [93.80930328, 7.21875095], [93.81005096, 7.21958113], [93.81041718, 7.21978998], [93.81027985, 7.22028017], [93.81025696, 7.22061777], [93.80999756, 7.22111177], [93.80999756, 7.22138786], [93.8097229, 7.22166586], [93.8097229, 7.22194386], [93.80944824, 7.22221994], [93.80916595, 7.22271013], [93.80895996, 7.22305584], [93.80882263, 7.22441912], [93.80874634, 7.22499084], [93.80854034, 7.2252779], [93.80847168, 7.22596884], [93.80867767, 7.22694397], [93.80902863, 7.22735882], [93.80916595, 7.22750092], [93.80922699, 7.22785187], [93.80899811, 7.22837114], [93.80831909, 7.2288909], [93.80750275, 7.2288909], [93.80665588, 7.22846889], [93.8061142, 7.22750092], [93.80590057, 7.22722292], [93.80548859, 7.22722292], [93.80527496, 7.2275691], [93.8052597, 7.22861099], [93.80583191, 7.2291708], [93.80583191, 7.23000097], [93.80554962, 7.23028088], [93.80555725, 7.23055506], [93.80565643, 7.23190784], [93.80593872, 7.23239422], [93.80638885, 7.23305511], [93.8069458, 7.23361111], [93.80722046, 7.23361111], [93.8077774, 7.23305511], [93.8077774, 7.23250103], [93.80847931, 7.23222113], [93.8088913, 7.23194504], [93.80916595, 7.23201323], [93.80944824, 7.23166704], [93.80979156, 7.23167086], [93.80999756, 7.23153019], [93.81021118, 7.23145914], [93.81048584, 7.23145914], [93.81083679, 7.23139095], [93.81104279, 7.23167086], [93.8116684, 7.23166704], [93.8125, 7.23173523], [93.81277466, 7.23194504], [93.8133316, 7.23235989], [93.81388855, 7.23256922], [93.8152771, 7.23250103], [93.81583405, 7.23250103], [93.816185, 7.23298597], [93.81639099, 7.23354006], [93.81624603, 7.2343812], [93.81639099, 7.23493099], [93.81681061, 7.2352109], [93.81729889, 7.23527718], [93.81777954, 7.23541594], [93.81841278, 7.23597002], [93.8189621, 7.23624802], [93.8197937, 7.23645496], [93.82111359, 7.23694515], [93.82221985, 7.23694515], [93.82250214, 7.23666716], [93.82305908, 7.23666716], [93.82333374, 7.23694515], [93.8236084, 7.23694515], [93.82389069, 7.23722076], [93.82444763, 7.23722076], [93.82472229, 7.23722076], [93.82514191, 7.23763418], [93.82611084, 7.23805094], [93.82707977, 7.2381258], [93.82777405, 7.23777723], [93.82944489, 7.23611116], [93.82971954, 7.23611116], [93.83013916, 7.23604107], [93.8309021, 7.23604107], [93.83139038, 7.23611116], [93.83207703, 7.23701096], [93.83249664, 7.23749924], [93.8328476, 7.23805523], [93.83354187, 7.23833323], [93.8345871, 7.23861122], [93.83535004, 7.23916483], [93.83597565, 7.23937321], [93.83694458, 7.23937321], [93.8373642, 7.23923588], [93.83805847, 7.23861122], [93.83833313, 7.23888922], [93.83833313, 7.23972082], [93.83777618, 7.24028015], [93.83750153, 7.24028015], [93.83721924, 7.24056005], [93.83694458, 7.24055481], [93.83638763, 7.24111223], [93.83638763, 7.24166822], [93.83694458, 7.24222183], [93.83721924, 7.24194288], [93.83777618, 7.24194288], [93.83805847, 7.24166822], [93.83833313, 7.24167013], [93.83862305, 7.24139023], [93.8391571, 7.24139023], [93.83944702, 7.24110889], [93.83972168, 7.24110889], [93.84041595, 7.24125099], [93.84057617, 7.24119806], [93.84104156, 7.24104118], [93.84222412, 7.23999882], [93.84249878, 7.23999882], [93.84278107, 7.23972082], [93.84333038, 7.23972082], [93.84352112, 7.23990822], [93.84361267, 7.23999882], [93.84471893, 7.23999882], [93.84500122, 7.24028015], [93.84519196, 7.24021578], [93.84616089, 7.2409091], [93.8467865, 7.24160385], [93.84692383, 7.24285316], [93.84687805, 7.24359989], [93.84722137, 7.24417019], [93.84777832, 7.24360991], [93.84777832, 7.24249983], [93.84805298, 7.24222183], [93.84805298, 7.24194288], [93.84833527, 7.24166822], [93.84833527, 7.24055481], [93.84805298, 7.24028015], [93.84805298, 7.23972082], [93.84777832, 7.23944283], [93.84777832, 7.23749924], [93.84750366, 7.23722076], [93.84750366, 7.23583317], [93.84777832, 7.23555517], [93.84777832, 7.23527718], [93.84805298, 7.23500109], [93.84805298, 7.2341671], [93.8483429, 7.23389101], [93.8483429, 7.23361111], [93.84805298, 7.23333311], [93.84805298, 7.23305511], [93.84750366, 7.23250103], [93.84722137, 7.23250103], [93.84716797, 7.23244381], [93.84694672, 7.23222113], [93.84638977, 7.23222303], [93.84610748, 7.23194504], [93.84583282, 7.23194504], [93.84527588, 7.23138905], [93.84500122, 7.23139095], [93.84479523, 7.23118401], [93.84305573, 7.22944498], [93.84305573, 7.22916698], [93.84249878, 7.22861099], [93.84249878, 7.22750092], [93.84278107, 7.22722292], [93.84278107, 7.22666597], [93.84305573, 7.22638798], [93.84306335, 7.22610998], [93.84333038, 7.22583485], [93.84333038, 7.2255559], [93.84305573, 7.2252779], [93.84333038, 7.22499084], [93.84333038, 7.22444391], [93.84361267, 7.22416592], [93.84361267, 7.22388792], [93.84388733, 7.22360992], [93.84388733, 7.22305584], [93.84416962, 7.22277784], [93.84416962, 7.22111177], [93.84471893, 7.22055578], [93.84471893, 7.22028017], [93.84527588, 7.21972179], [93.84527588, 7.2194438], [93.84555817, 7.2191658], [93.84555817, 7.21888781], [93.84610748, 7.21832895], [93.84610748, 7.2180562], [93.84805298, 7.21611214], [93.8483429, 7.2161212], [93.84889221, 7.21555996], [93.84916687, 7.21555996], [93.84999847, 7.21471882], [93.85028076, 7.2147212], [93.85083008, 7.21416807], [93.85111237, 7.21416998], [93.85138702, 7.21389008], [93.85221863, 7.21389008], [93.85250092, 7.21360922], [93.85415649, 7.21360922], [93.85444641, 7.21389008], [93.85610962, 7.21389008], [93.85639191, 7.21416998], [93.85666656, 7.21416807], [93.85694122, 7.21444607], [93.85722351, 7.21444607], [93.85749817, 7.2147212], [93.85778046, 7.21471882], [93.85832977, 7.21527815], [93.85832977, 7.21555614], [93.85861206, 7.2158308], [93.85861206, 7.2161212], [93.85888672, 7.21639013], [93.85888672, 7.21666622], [93.85863495, 7.21673393], [93.85916901, 7.21722221], [93.85972595, 7.21722221], [93.86027527, 7.21694422], [93.86076355, 7.21687508], [93.8611145, 7.21694422], [93.86222076, 7.21694422], [93.86250305, 7.21666622], [93.86279297, 7.21667004], [93.86305237, 7.21639013], [93.86333466, 7.21639013], [93.86443329, 7.21648121], [93.86521149, 7.21687508], [93.86566925, 7.21688414], [93.86631775, 7.21721888], [93.86728668, 7.21750021], [93.86840057, 7.21736097], [93.86916351, 7.21694422], [93.8702774, 7.21583414], [93.8702774, 7.21555614], [93.87055206, 7.21527815], [93.87055206, 7.21500015], [93.87083435, 7.2147212], [93.87083435, 7.21416807], [93.87110901, 7.21389008], [93.87110901, 7.21333122], [93.8713913, 7.21277714], [93.87194824, 7.21222115], [93.8741684, 7.21082878], [93.87444305, 7.21048212], [93.87471771, 7.20937014], [93.87548828, 7.20791388], [93.87596893, 7.20666504], [93.87618256, 7.20583105], [93.87631989, 7.20527697], [93.87652588, 7.20479107], [93.87687683, 7.20388889], [93.87770844, 7.203403], [93.87854004, 7.20326424], [93.87916565, 7.20326424], [93.88041687, 7.20347214], [93.88075256, 7.20369005], [93.88159943, 7.20423985], [93.88230133, 7.20410109], [93.88276672, 7.2036109], [93.88277435, 7.2033329], [93.88243103, 7.20257616], [93.8822937, 7.20160484], [93.88230133, 7.2008419], [93.88222504, 7.20035601], [93.88243103, 7.19938517], [93.88222504, 7.19876099], [93.88194275, 7.19751215], [93.88145447, 7.19577503], [93.88111115, 7.19522095], [93.8805542, 7.19444418], [93.88002014, 7.19344807], [93.88079071, 7.19268513], [93.8812027, 7.19212818], [93.88182831, 7.19136715], [93.88252258, 7.19060087], [93.8829422, 7.18970108], [93.88335419, 7.18914509], [93.88363647, 7.18845177], [93.88363647, 7.18810606], [93.88368225, 7.18714809], [93.88326263, 7.18626881], [93.88331604, 7.18507004], [93.88305664, 7.18472099], [93.88361359, 7.18375015], [93.8833313, 7.18250084], [93.8833313, 7.18166924], [93.88305664, 7.18139076], [93.88305664, 7.18083096], [93.88277435, 7.18055487], [93.88277435, 7.17972279], [93.88249969, 7.17944479], [93.88249969, 7.17916679], [93.88222504, 7.1788888], [93.88201141, 7.1786108], [93.88153076, 7.1781249], [93.88097382, 7.17784691], [93.88027954, 7.17639112], [93.88027954, 7.17500114], [93.87999725, 7.17472315], [93.87999725, 7.17277908], [93.88027954, 7.17250013], [93.88027954, 7.17194414], [93.8805542, 7.17166615], [93.88142395, 7.17065907], [93.88143158, 7.1694808], [93.88166809, 7.1686101], [93.88249969, 7.1686101], [93.88346863, 7.16819715], [93.8841095, 7.1670599], [93.8849411, 7.16664314], [93.88521576, 7.16608906], [93.88510132, 7.16518688], [93.88456726, 7.16400194], [93.88437653, 7.16368008], [93.88411713, 7.1632719], [93.88388062, 7.1626091], [93.88402557, 7.16194391], [93.8842392, 7.16130495], [93.88471985, 7.1606102], [93.88504791, 7.1595459], [93.88525391, 7.15815783], [93.88553619, 7.15739012], [93.88594818, 7.15718508], [93.88629913, 7.15593576], [93.88656616, 7.15511084], [93.88665009, 7.15380001], [93.88698578, 7.15309095], [93.88761902, 7.15218878], [93.88789368, 7.15114689], [93.8875885, 7.14959097], [93.88685608, 7.14809608], [93.88671875, 7.14622211], [93.88651276, 7.14546108], [93.88671875, 7.14456081], [93.88656616, 7.14345121], [93.88672638, 7.1425209], [93.88687134, 7.14189911], [93.88687134, 7.14120579], [93.88694763, 7.14027786], [93.88694763, 7.13972187], [93.88666534, 7.13944387], [93.88666534, 7.13861179], [93.88639069, 7.1383338], [93.88639069, 7.1380558], [93.8861084, 7.13777781], [93.8861084, 7.13749981], [93.88583374, 7.13722181], [93.88583374, 7.13694382], [93.88555908, 7.13666821], [93.88555908, 7.13639021], [93.88527679, 7.13610983], [93.88527679, 7.13583422], [93.88500214, 7.13555622], [93.88471985, 7.13478088], [93.88444519, 7.13443422], [93.88451385, 7.13401699], [93.88417053, 7.13270378], [93.88424683, 7.13145113], [93.88430786, 7.12977982], [93.88467407, 7.12888908], [93.88492584, 7.12825823], [93.88511658, 7.12728024], [93.88527679, 7.12673092], [93.88569641, 7.12582779], [93.88677979, 7.12524319], [93.88812256, 7.12478685], [93.88874817, 7.12437201], [93.88923645, 7.12423277], [93.88986206, 7.12388706], [93.89027405, 7.12333012], [93.89076233, 7.12284517], [93.89104462, 7.12222004], [93.89138794, 7.12111092], [93.89116669, 7.12007093], [93.89083099, 7.11972904], [93.89055634, 7.11757088], [93.89055634, 7.11721992], [93.89055634, 7.11666584], [93.89027405, 7.11638784], [93.89026642, 7.11610985], [93.8888855, 7.11472178], [93.8888855, 7.11416578], [93.88854218, 7.11333418], [93.88847351, 7.11215401], [93.88881683, 7.11152887], [93.88896179, 7.11082888], [93.88861084, 7.10972214], [93.88805389, 7.10916615], [93.88805389, 7.10889006], [93.88722229, 7.10805988], [93.88722229, 7.10779095], [93.88696289, 7.10750008], [93.88696289, 7.10721922], [93.88639069, 7.106668], [93.88639069, 7.10639], [93.8861084, 7.10610914], [93.8861084, 7.10583305], [93.88583374, 7.10555506], [93.88583374, 7.10527706], [93.88555908, 7.10500193], [93.88555908, 7.10416985], [93.88548279, 7.10255194], [93.88548279, 7.10088778], [93.88576508, 7.09991503], [93.8859024, 7.09922218], [93.88603973, 7.09859705], [93.88694763, 7.09748697], [93.88749695, 7.09644985], [93.88777924, 7.09528112], [93.88777924, 7.09360981], [93.88805389, 7.09333181], [93.88805389, 7.08833218], [93.88777924, 7.08805609], [93.88777924, 7.08639002], [93.88833618, 7.08583021], [93.88833618, 7.08555603], [93.88861084, 7.08527803], [93.88861084, 7.08472013], [93.88951111, 7.08367777], [93.88993073, 7.08298302], [93.89027405, 7.08207989], [93.89048767, 7.0809021], [93.89141083, 7.08031893], [93.89173126, 7.08006811], [93.89250183, 7.07944107], [93.8931427, 7.07877588], [93.89402771, 7.0785408], [93.89527893, 7.07902908], [93.8970108, 7.07909679], [93.89778137, 7.07888985], [93.89861298, 7.07888985], [93.89890289, 7.0786109], [93.89944458, 7.0786109], [93.89971924, 7.0783329], [93.90000153, 7.0783329], [93.90027618, 7.0780549], [93.90055847, 7.07806015], [93.90083313, 7.07777977], [93.90110779, 7.07777977], [93.90139008, 7.07748985], [93.90166473, 7.07749891], [93.90222168, 7.07694483], [93.90222168, 7.07638884], [93.90277863, 7.07583284], [93.90277863, 7.07555485], [93.90326691, 7.07485819], [93.90374756, 7.0741601], [93.90409851, 7.07340097], [93.90465546, 7.07277679], [93.90513611, 7.07180595], [93.90583038, 7.07083082], [93.90611267, 7.07055521], [93.90618134, 7.07027721], [93.90638733, 7.07000113], [93.90638733, 7.06965208], [93.90666962, 7.06777906], [93.90638733, 7.06750107], [93.90638733, 7.06666708], [93.90611267, 7.06639099], [93.90611267, 7.06472015], [93.90583038, 7.06444407], [93.90583038, 7.06416607], [93.90555573, 7.06388807], [93.90556335, 7.06278086], [93.90611267, 7.0622201], [93.90583038, 7.06194401], [93.90611267, 7.06166601], [93.90638733, 7.06167078], [93.90693665, 7.06111002], [93.90721893, 7.06111002], [93.90777588, 7.06055593], [93.90805817, 7.06055784], [93.90888977, 7.05972004], [93.90888977, 7.05944395], [93.90916443, 7.05916595], [93.9091568, 7.05889177], [93.90944672, 7.05860996], [93.90944672, 7.05833387], [93.91027832, 7.05749989], [93.91027832, 7.05722189], [93.91083527, 7.0566678], [93.91083527, 7.05638981], [93.91110992, 7.05610991], [93.91110992, 7.05583382], [93.91134644, 7.05498409], [93.9114151, 7.05345678], [93.91183472, 7.05248308], [93.91280365, 7.0518589], [93.91371155, 7.0515132], [93.91405487, 7.05102682], [93.91419983, 7.05019522], [93.91433716, 7.04957104], [93.91503143, 7.04929304], [93.91555786, 7.04916716], [93.91666412, 7.04840422], [93.91694641, 7.04729414], [93.91673279, 7.04583502], [93.91659546, 7.04465723], [93.91590118, 7.04374981], [93.91508484, 7.04353094], [93.91278076, 7.04138899], [93.91278076, 7.04111099], [93.91249847, 7.04111099], [93.91249847, 7.04055405], [93.91222382, 7.04027891], [93.91221619, 7.03917122], [93.91242981, 7.03889084], [93.91256714, 7.0384798], [93.91306305, 7.03806114], [93.91348267, 7.03792], [93.91396332, 7.0374999], [93.91430664, 7.03701019], [93.91416931, 7.03666592], [93.91416931, 7.03583384], [93.91374969, 7.03521013], [93.91372681, 7.03455782], [93.91416931, 7.03391504], [93.91471863, 7.03357077], [93.91483307, 7.03324986], [93.9152832, 7.03308105], [93.91625214, 7.03211308], [93.91666412, 7.0308342], [93.91666412, 7.02916622], [93.91611481, 7.02861214], [93.91596985, 7.02805614], [93.91583252, 7.02777815], [93.91555786, 7.02750015], [93.91583252, 7.02722216], [93.91583252, 7.02583408], [93.91611481, 7.02555513], [93.91611481, 7.02527714], [93.91750336, 7.02388906], [93.91777802, 7.02388906], [93.91832733, 7.0233202], [93.92055511, 7.02333307], [93.92082977, 7.02360916], [93.92151642, 7.02388906], [93.92193604, 7.02388906], [93.92229462, 7.02402782], [93.92277527, 7.02437496], [93.92333221, 7.02472115], [93.9236145, 7.02472115], [93.92388916, 7.02499914], [93.92415619, 7.02499914], [93.92472076, 7.0255599], [93.92500305, 7.02555513], [93.92583466, 7.02639008], [93.92610931, 7.02639008], [93.92666626, 7.02694082], [93.92727661, 7.02729177], [93.92811584, 7.02736092], [93.92868042, 7.02715111], [93.92896271, 7.02651978], [93.93090057, 7.02471924], [93.93132019, 7.02395582], [93.93173218, 7.02305079], [93.93235779, 7.02235985], [93.9329834, 7.02194309], [93.93395996, 7.02145815], [93.93444824, 7.02055502], [93.93444824, 7.02028179], [93.9347229, 7.02000093], [93.93492889, 7.01818895], [93.93499756, 7.01777697], [93.93499756, 7.01638889], [93.93527985, 7.0161109], [93.93527985, 7.0158329], [93.93548584, 7.01541615], [93.93583679, 7.01472282], [93.93624878, 7.01402807], [93.93653107, 7.01333189], [93.93805695, 7.01173496], [93.9383316, 7.01166582], [93.93888855, 7.01124907], [93.93916321, 7.01110983], [93.93972015, 7.01055717], [93.94000244, 7.01056099], [93.9402771, 7.01028109], [93.94139099, 7.01028109], [93.94167328, 7.01000023], [93.9430542, 7.01000023], [93.94403076, 7.00993013], [93.94548035, 7.0094099], [93.9457016, 7.00870991], [93.94619751, 7.0078721], [93.94625092, 7.00746584], [93.94659424, 7.00618315], [93.94667053, 7.00586796], [93.9469223, 7.0049839], [93.94695282, 7.00416994], [93.94721985, 7.00389004], [93.94721985, 7.0033288], [93.94750214, 7.00305605], [93.94750214, 7.00277805], [93.94777679, 7.00250006], [93.94777679, 7.0], [93.94766235, 6.99914885], [93.94780731, 6.99887419], [93.94773102, 6.99845695], [93.94766235, 6.99817896], [93.9471817, 6.99782991], [93.94696808, 6.99748278], [93.94676208, 6.99706602], [93.94662476, 6.99658108], [93.94648743, 6.99595594], [93.9462738, 6.99553919], [93.94618988, 6.99548912], [93.94557953, 6.99512005], [93.94537354, 6.9949832], [93.94496155, 6.99449778], [93.94481659, 6.99428797], [93.94472504, 6.99402618], [93.94457245, 6.99308014], [93.94422913, 6.99258995], [93.94374084, 6.99252176], [93.9431839, 6.99259186], [93.94291687, 6.99265385], [93.94256592, 6.99300003], [93.94243622, 6.99342012], [93.94219208, 6.99385023], [93.94204712, 6.99398899], [93.94184113, 6.99407196], [93.94163513, 6.99412823], [93.94139099, 6.99416685], [93.9411087, 6.99444103], [93.9411087, 6.99555492], [93.9411087, 6.99620914], [93.94090271, 6.99649], [93.94062805, 6.99676514], [93.94041443, 6.99683619], [93.94020844, 6.99694586], [93.94000244, 6.99722099], [93.93945313, 6.99777985], [93.93916321, 6.99777985], [93.93881989, 6.99791622], [93.93805695, 6.99805498], [93.93777466, 6.99833298], [93.9375, 6.99833298], [93.93722534, 6.99861193], [93.93694305, 6.99861193], [93.93638611, 6.99896002], [93.93554688, 6.99916983], [93.9347229, 7.0], [93.93373108, 7.00099087], [93.93296051, 7.00216913], [93.93247986, 7.00426197], [93.93151093, 7.00674582], [93.93039703, 7.00855112], [93.92956543, 7.01007605], [93.92845917, 7.01070023], [93.92727661, 7.01126099], [93.92603302, 7.01126099], [93.9249115, 7.01111889], [93.92344666, 7.01041079], [93.92205811, 7.00985718], [93.92108917, 7.00902319], [93.92024994, 7.0084691], [93.91921234, 7.00749779], [93.91671753, 7.00528908], [93.91559601, 7.00403976], [93.91475677, 7.00265884], [93.91390228, 7.0], [93.91390228, 6.99694109], [93.91394043, 6.9963212], [93.91408539, 6.99597216], [93.91408539, 6.99534798], [93.91436005, 6.99500084], [93.91436005, 6.99457979], [93.9146347, 6.99437523], [93.91498566, 6.99416685], [93.91519165, 6.99382114], [93.91561127, 6.99353981], [93.91595459, 6.99326515], [93.91635895, 6.99325991], [93.91722107, 6.99334002], [93.91832733, 6.99334002], [93.91860962, 6.99306011], [93.91916656, 6.99306011], [93.92111206, 6.9911108], [93.92141724, 6.99076414], [93.92162323, 6.99048615], [93.92197418, 6.99034691], [93.92196655, 6.9900012], [93.92266846, 6.98965216], [93.9232254, 6.98895884], [93.92384338, 6.98854208], [93.92460632, 6.98826408], [93.92523193, 6.98805523], [93.92565155, 6.98798609], [93.92585754, 6.98778105], [93.92666626, 6.98778105], [93.92804718, 6.98639107], [93.92804718, 6.98582983], [93.9283371, 6.98555708], [93.9283371, 6.98527908], [93.92861176, 6.98500109], [93.92861176, 6.98472214], [93.92944336, 6.98388815], [93.92944336, 6.98333216], [93.9291687, 6.98305607], [93.9291687, 6.98250008], [93.92944336, 6.98222017], [93.92944336, 6.98166609], [93.9291687, 6.98138809], [93.9291687, 6.9811101], [93.92861176, 6.98055601], [93.92861176, 6.98000002], [93.9283371, 6.97972012], [93.9283371, 6.97861004], [93.92805481, 6.97833395], [93.92805481, 6.97777796], [93.9283371, 6.97749996], [93.9283371, 6.9769392], [93.92805481, 6.97666597], [93.92805481, 6.9755559], [93.9283371, 6.97527122], [93.9283371, 6.97416782], [93.92861176, 6.97388983], [93.92861176, 6.97360897], [93.9291687, 6.97305584], [93.92944336, 6.97306013], [93.93083191, 6.97167015], [93.93110657, 6.97167015], [93.93164825, 6.97111082], [93.93208313, 6.97111082], [93.93250275, 6.97090197], [93.93291473, 6.97062588], [93.93312073, 6.97048521], [93.93327332, 6.96986008], [93.93333435, 6.96944284], [93.9338913, 6.96888924], [93.9338913, 6.96861076], [93.93444824, 6.96805477], [93.93444824, 6.96777678], [93.9347229, 6.96750116], [93.9347229, 6.96722317], [93.93499756, 6.96694517], [93.93499756, 6.96611118], [93.9347229, 6.96583319], [93.9347229, 6.96500111], [93.93497467, 6.96402121], [93.93497467, 6.96353579], [93.93524933, 6.96332598], [93.93560028, 6.96318722], [93.93601227, 6.96284103], [93.93622589, 6.96256208], [93.93656921, 6.96235514], [93.93722534, 6.96222305], [93.93805695, 6.96222305], [93.93888855, 6.96138906], [93.93945313, 6.96139097], [93.93972015, 6.96111107], [93.94000244, 6.96111107], [93.9402771, 6.96083307], [93.9411087, 6.96083307], [93.94139099, 6.96055508], [93.94167328, 6.9605608], [93.94194794, 6.96028996], [93.94246674, 6.95992994], [93.94288635, 6.95979118], [93.94410706, 6.95986414], [93.94418335, 6.95963097], [93.94445801, 6.95882177], [93.94473267, 6.95798779], [93.94487, 6.95722914], [93.94528961, 6.95653009], [93.94550323, 6.9558301], [93.94535828, 6.95451498], [93.94508362, 6.95395899], [93.94459534, 6.95333385], [93.94410706, 6.95298576], [93.9438324, 6.9526391], [93.9436264, 6.95181179], [93.94328308, 6.95117998], [93.94272614, 6.95069504], [93.94203186, 6.95034599], [93.94126129, 6.95035124], [93.94064331, 6.95049], [93.94008636, 6.95042181], [93.93925476, 6.95013905], [93.93883514, 6.9505558], [93.93835449, 6.95069504], [93.93744659, 6.95076323], [93.93688965, 6.95103884], [93.93662262, 6.95126009], [93.93592072, 6.95138788], [93.93544006, 6.95159817], [93.9347229, 6.95222187], [93.93444824, 6.95221996], [93.93416595, 6.95250177], [93.9338913, 6.95250177], [93.93360901, 6.95277977], [93.93332672, 6.95277977], [93.93305206, 6.9530611], [93.9327774, 6.95305586], [93.93250275, 6.95333385], [93.93222046, 6.95333385], [93.9319458, 6.95360994], [93.93164825, 6.95360994], [93.93138885, 6.95388985], [93.9311142, 6.95388794], [93.93055725, 6.95444393], [93.93026733, 6.95444012], [93.92973328, 6.95499992], [93.92778015, 6.95499992], [93.92749786, 6.95472002], [93.92722321, 6.95472193], [93.92694092, 6.95444393], [93.92666626, 6.95444393], [93.92583466, 6.95360994], [93.92583466, 6.95333385], [93.92555237, 6.95305586], [93.92555237, 6.95277786], [93.92415619, 6.95138979], [93.92388916, 6.95138979], [93.92360687, 6.95110083], [93.92333221, 6.95111179], [93.92277527, 6.9505558], [93.92250061, 6.95056105], [93.92222595, 6.95028019], [93.92166901, 6.95028019], [93.92138672, 6.94999981], [93.92111206, 6.94999981], [93.92028046, 6.94917011], [93.92028046, 6.94889021], [93.91970825, 6.94833183], [93.91944122, 6.94833422], [93.91914368, 6.94803095], [93.91889191, 6.94777822], [93.91889191, 6.94750023], [93.91860962, 6.94722223], [93.91833496, 6.94722223], [93.91816711, 6.94705486], [93.91805267, 6.94694424], [93.91833496, 6.94666815], [93.91833496, 6.94639015], [93.91805267, 6.94610882], [93.91764069, 6.94521093], [93.91722107, 6.94451618], [93.91708374, 6.94368219], [93.91707611, 6.94327021], [93.9173584, 6.94285011], [93.9173584, 6.94215107], [93.91750336, 6.94138908], [93.91777802, 6.94111109], [93.91777802, 6.94083309], [93.91750336, 6.9405551], [93.91750336, 6.93944502], [93.91722107, 6.93916702], [93.91722107, 6.93805504], [93.91694641, 6.93777704], [93.91722107, 6.93750095], [93.91722107, 6.93722105], [93.91750336, 6.93694496], [93.91750336, 6.93638897], [93.91722107, 6.93611097], [93.91722107, 6.9344449], [93.91750336, 6.93416691], [93.91723633, 6.93253708], [93.91705322, 6.93242979], [93.91628265, 6.93242979], [93.91551971, 6.93229103], [93.91510773, 6.93208122], [93.91479492, 6.93222284], [93.91464996, 6.93242979], [93.91438293, 6.93278122], [93.91403198, 6.93305922], [93.91333008, 6.93305922], [93.91320038, 6.93292713], [93.91305542, 6.93277884], [93.91278076, 6.93278122], [93.91249847, 6.93250084], [93.91221619, 6.93250084], [93.91194153, 6.93221998], [93.91166687, 6.93222284], [93.91139221, 6.93194485], [93.91110992, 6.93194485], [93.91083527, 6.9316659], [93.91083527, 6.9313879], [93.90999603, 6.93056107], [93.90999603, 6.93028116], [93.90972137, 6.92999983], [93.90972137, 6.92944002], [93.90944672, 6.92916584], [93.90944672, 6.92777777], [93.9091568, 6.92749977], [93.9091568, 6.92692995], [93.90944672, 6.92666578], [93.90944672, 6.92583418], [93.90972137, 6.92555618], [93.90972137, 6.92500019], [93.91000366, 6.92472219], [93.91000366, 6.9241662], [93.91027832, 6.92388821], [93.91027832, 6.92332888], [93.91055298, 6.92305613], [93.91055298, 6.92277813], [93.91110992, 6.9222188], [93.91110992, 6.92194414], [93.91194153, 6.92111206], [93.91194153, 6.92083406], [93.91305542, 6.91972208], [93.91305542, 6.91944313], [93.91333008, 6.91916513], [93.91361237, 6.9191699], [93.91443634, 6.91833115], [93.91471863, 6.91833401], [93.9150238, 6.91805792], [93.91564941, 6.91708708], [93.91564941, 6.91638899], [93.91571808, 6.91576719], [93.91599274, 6.91514015], [93.9160614, 6.91459084], [93.91633606, 6.91375017], [93.91648102, 6.91291809], [93.9161377, 6.9120841], [93.91571808, 6.91166878], [93.9152298, 6.91097021], [93.91481781, 6.91069603], [93.91412354, 6.91048622], [93.9133606, 6.9100008], [93.91294098, 6.90944481], [93.91280365, 6.90868092], [93.91280365, 6.90777922], [93.91252899, 6.90701485], [93.91204071, 6.90673685], [93.91162109, 6.906528], [93.91110992, 6.90611982], [93.91055298, 6.90556097], [93.90999603, 6.90556097], [93.90944672, 6.90500116], [93.9091568, 6.90500116], [93.90894318, 6.90477514], [93.90888977, 6.90471983], [93.90860748, 6.90472317], [93.90833282, 6.90500116], [93.90805817, 6.90500116], [93.90750122, 6.90556097], [93.90721893, 6.90556097], [93.90666962, 6.90611982], [93.90611267, 6.90611982], [93.90583038, 6.90639114], [93.90556335, 6.90639114], [93.90528107, 6.90667105], [93.90499878, 6.90666723], [93.90472412, 6.90694523], [93.90333557, 6.90694523], [93.90305328, 6.90722322], [93.90222168, 6.90722322], [93.90188599, 6.90688801], [93.90139008, 6.90638924], [93.90083313, 6.90639114], [93.90027618, 6.90582991], [93.89971924, 6.90556097], [93.89923859, 6.90521479], [93.8989563, 6.90452003], [93.89854431, 6.90403223], [93.89785004, 6.90347815], [93.89722443, 6.90215588], [93.89730072, 6.90167093], [93.89749908, 6.90097618], [93.89770508, 6.90035105], [93.89805603, 6.8994441], [93.89916992, 6.89833403], [93.89944458, 6.89833403], [93.90000153, 6.89777803], [93.90000153, 6.89750004], [93.90027618, 6.89722013], [93.90027618, 6.89583397], [93.89992523, 6.89507294], [93.89958191, 6.89472389], [93.8989563, 6.89437819], [93.89777374, 6.89396], [93.89686584, 6.89340019], [93.89646149, 6.89270878], [93.89646149, 6.89173794], [93.89666748, 6.89056015], [93.89694214, 6.89027977], [93.89694214, 6.89000177], [93.8972168, 6.88972092], [93.89722443, 6.88916683], [93.89749908, 6.88888884], [93.89749908, 6.88861084], [93.89833069, 6.88777685], [93.89833069, 6.88750076], [93.89861298, 6.88750076], [93.89890289, 6.88722086], [93.89963531, 6.88696623], [93.89984131, 6.88661718], [93.9001236, 6.88613176], [93.90026093, 6.88536596], [93.89990997, 6.88446283], [93.89977264, 6.88349199], [93.89984131, 6.883214], [93.9001236, 6.88272715], [93.90053558, 6.88203382], [93.90109253, 6.88161707], [93.90159607, 6.8810792], [93.90167236, 6.88025093], [93.9017334, 6.87954998], [93.90194702, 6.878057], [93.90194702, 6.87666607], [93.90183258, 6.87580013], [93.90183258, 6.87468815], [93.90155792, 6.87343884], [93.90113831, 6.87226105], [93.90085602, 6.87169981], [93.90010071, 6.87100697], [93.89898682, 6.87059021], [93.89739227, 6.8695488], [93.89694214, 6.8691659], [93.89666748, 6.86888981], [93.89639282, 6.86888981], [93.89611053, 6.86860991], [93.89583588, 6.86861181], [93.89555359, 6.86833382], [93.89527893, 6.86833382], [93.89472198, 6.86777782], [93.89444733, 6.86778021], [93.89412689, 6.86745596], [93.89360809, 6.86694098], [93.89360809, 6.86666822], [93.89333344, 6.86639023], [93.89332581, 6.8658309], [93.89305878, 6.86555576], [93.89305878, 6.86277723], [93.89325714, 6.86187887], [93.89347076, 6.8607688], [93.89360809, 6.85972118], [93.89389038, 6.8594451], [93.89389038, 6.85861111], [93.89416504, 6.85833311], [93.89416504, 6.85750103], [93.89444733, 6.85722303], [93.89444733, 6.85555506], [93.89472198, 6.85527897], [93.89472198, 6.85500097], [93.89444733, 6.85472107], [93.89444733, 6.85444498], [93.89416504, 6.85416698], [93.89416504, 6.853055], [93.89389038, 6.85278082], [93.89389038, 6.85194016], [93.89360809, 6.85166693], [93.89360809, 6.85083199], [93.89333344, 6.85055399], [93.89333344, 6.84888792], [93.89360809, 6.84860992], [93.89360809, 6.84694386], [93.89389038, 6.84666586], [93.89389038, 6.84583378], [93.89417267, 6.84556103], [93.89417267, 6.84528017], [93.89527893, 6.84417009], [93.89527893, 6.84306097], [93.89553833, 6.84277105], [93.89555359, 6.84222221], [93.89638519, 6.84138823], [93.89666748, 6.84139013], [93.89694214, 6.84111023], [93.89861298, 6.84111214], [93.89888763, 6.84083414], [93.90000153, 6.84083414], [93.90027618, 6.84055614], [93.90083313, 6.84055996], [93.90110779, 6.84028006], [93.90305328, 6.84028006], [93.9033432, 6.84055996], [93.90368652, 6.84042978], [93.90453339, 6.84042978], [93.90563202, 6.84022093], [93.90646362, 6.83987379], [93.90722656, 6.83959579], [93.90792084, 6.83897209], [93.90875244, 6.8382082], [93.90903473, 6.83779097], [93.90953064, 6.83695889], [93.90994263, 6.83625984], [93.91020966, 6.83563709], [93.91035461, 6.8348031], [93.91014099, 6.83355188], [93.91000366, 6.83216381], [93.909729, 6.83084393], [93.90930939, 6.82994223], [93.90875244, 6.82882977], [93.90778351, 6.82757807], [93.90660095, 6.82654095], [93.90576935, 6.82555914], [93.90472412, 6.82416677], [93.90472412, 6.82388783], [93.90416718, 6.82332993], [93.90416718, 6.82305717], [93.90361023, 6.82250023], [93.90336609, 6.82203102], [93.90267181, 6.82126713], [93.9021759, 6.82081604], [93.90159607, 6.82015991], [93.9015274, 6.81967878], [93.9015274, 6.81912279], [93.90166473, 6.8183589], [93.90200806, 6.81752491], [93.90234375, 6.81722879], [93.90268707, 6.81604815], [93.90268707, 6.81512117], [93.90242004, 6.81442499], [93.90220642, 6.81366014], [93.90213776, 6.81296682], [93.90110016, 6.81255007], [93.9005127, 6.81210089], [93.90009308, 6.81168079], [93.89984131, 6.81104612], [93.89942932, 6.81049204], [93.8990097, 6.80979681], [93.89880371, 6.80903292], [93.8981781, 6.80798912], [93.89790344, 6.80715704], [93.89724731, 6.8061409], [93.896698, 6.8054409], [93.8962326, 6.80486488], [93.89568329, 6.80444717], [93.89505768, 6.80416918], [93.89331818, 6.80367899], [93.89234924, 6.80361319], [93.89172363, 6.80368423], [93.89102936, 6.80361319], [93.88978577, 6.80389118], [93.88922882, 6.80389118], [93.8888092, 6.803545], [93.88853455, 6.8027792], [93.88846588, 6.80215502], [93.88846588, 6.80104017], [93.88811493, 6.79972506], [93.88809967, 6.79908514], [93.88788605, 6.79866791], [93.88761139, 6.79790401], [93.88705444, 6.79686022], [93.8862915, 6.79602814], [93.88566589, 6.79540205], [93.88513184, 6.79500008], [93.88409424, 6.79493189], [93.8833313, 6.79479122], [93.88284302, 6.79444408], [93.88270569, 6.79374886], [93.88291168, 6.7933321], [93.88291168, 6.79298592], [93.88256836, 6.79277802], [93.88194275, 6.79284716], [93.88159943, 6.7930541], [93.88111115, 6.79319477], [93.88062286, 6.79339981], [93.87999725, 6.79416609], [93.87985992, 6.7945261], [93.87979126, 6.79515123], [93.87979126, 6.79556799], [93.87958527, 6.79591417], [93.87930298, 6.79619217], [93.87909698, 6.79633093], [93.87909698, 6.79702711], [93.87902832, 6.79751205], [93.87902832, 6.79792023], [93.87882233, 6.79827785], [93.87882233, 6.79910994], [93.87889099, 6.79944515], [93.87889099, 6.80055523], [93.87916565, 6.80083323], [93.87916565, 6.80166721], [93.87889099, 6.80194521], [93.87889099, 6.80222082], [93.8786087, 6.80249882], [93.8786087, 6.80277681], [93.87805176, 6.80333281], [93.87805176, 6.8036108], [93.8769455, 6.80472279], [93.87666321, 6.80472088], [93.87638855, 6.80500078], [93.87611389, 6.80499887], [93.87527466, 6.80583286], [93.87527466, 6.80611086], [93.87277985, 6.80861092], [93.87277985, 6.80916786], [93.87249756, 6.809443], [93.87249756, 6.80972099], [93.8713913, 6.81083393], [93.87110901, 6.81083393], [93.86972046, 6.812222], [93.86972046, 6.8125], [93.8694458, 6.81277084], [93.8694458, 6.81305981], [93.86883545, 6.81365108], [93.86876678, 6.81399679], [93.86876678, 6.81434298], [93.86856079, 6.81462097], [93.8682785, 6.81503916], [93.86765289, 6.81510019], [93.86627197, 6.81539011], [93.86529541, 6.81538677], [93.86349487, 6.81559515], [93.86244965, 6.815804], [93.86190033, 6.81587315], [93.86058044, 6.815804], [93.85939789, 6.81573391], [93.85863495, 6.81573391], [93.85759735, 6.815804], [93.8562088, 6.81566477], [93.85583496, 6.81557894], [93.8548584, 6.81545591], [93.85430145, 6.81538486], [93.85402679, 6.81559515], [93.8537674, 6.81549692], [93.85346985, 6.81538486], [93.85320282, 6.81539011], [93.85311127, 6.81592989], [93.8527832, 6.81625795], [93.8529892, 6.81653595], [93.8527832, 6.8167429], [93.85236359, 6.81639719], [93.85118866, 6.8161869], [93.85090637, 6.81605101], [93.85043335, 6.81555986], [93.85042572, 6.81500721], [93.85105133, 6.81472921], [93.85138702, 6.81390095], [93.85125732, 6.81305981], [93.85083771, 6.8125062], [93.85035706, 6.81202078], [93.8500061, 6.81160402], [93.849617, 6.81087017], [93.84906006, 6.80954981], [93.84836578, 6.80802298], [93.84822845, 6.80691099], [93.84802246, 6.80580091], [93.84780884, 6.80441093], [93.84746552, 6.80309105], [93.84719086, 6.80225706], [93.84638977, 6.80111122], [93.84638977, 6.80083323], [93.84610748, 6.80055523], [93.84610748, 6.79944515], [93.84638977, 6.79916716], [93.84638977, 6.79888916], [93.84707642, 6.79840994], [93.84749603, 6.79784918], [93.84750366, 6.79708576], [93.84742737, 6.79618311], [93.84742737, 6.79521179], [93.84749603, 6.79438019], [93.84777832, 6.79389], [93.8483429, 6.79333019], [93.84833527, 6.79305601], [93.84860992, 6.79277802], [93.84860992, 6.79250002], [93.84889221, 6.79222012], [93.84889221, 6.79194403], [93.84895325, 6.79131985], [93.84874725, 6.7901392], [93.8484726, 6.78965378], [93.84798431, 6.78923607], [93.84757233, 6.78868008], [93.84729004, 6.78819513], [93.84694672, 6.78743076], [93.84687805, 6.78687477], [93.84694672, 6.78611183], [93.84666443, 6.78583384], [93.84666443, 6.78499985], [93.84711456, 6.78434086], [93.84725189, 6.78385496], [93.84738922, 6.78357697], [93.84741974, 6.78258085], [93.84749603, 6.78208923], [93.8474884, 6.78133011], [93.84735107, 6.78056717], [93.84728241, 6.77980089], [93.84679413, 6.778759], [93.84635162, 6.77808905], [93.84578705, 6.7774601], [93.84538269, 6.77642107], [93.84461975, 6.77572823], [93.8442688, 6.77523994], [93.84350586, 6.7745471], [93.84294891, 6.77419901], [93.84211731, 6.77364016], [93.84184265, 6.77336502], [93.8414917, 6.77295017], [93.8406601, 6.77212], [93.84002686, 6.77155876], [93.8397522, 6.77114916], [93.83905792, 6.77031088], [93.83878326, 6.76982689], [93.8387146, 6.76920319], [93.8387146, 6.7687149], [93.83856964, 6.76795197], [93.83836365, 6.76691008], [93.83808899, 6.76572895], [93.8379364, 6.76476097], [93.83746338, 6.7631588], [93.83732605, 6.76252985], [93.83711243, 6.76170015], [93.83683777, 6.76072693], [93.83666992, 6.75971889], [93.83666992, 6.75889015], [93.83638763, 6.75861216], [93.83638763, 6.75778008], [93.8358078, 6.75703001], [93.83531952, 6.75647783], [93.83490753, 6.75557613], [93.8338623, 6.75509024], [93.83324432, 6.75508785], [93.83248138, 6.75529814], [93.83185577, 6.75578308], [93.83109283, 6.75592184], [93.83060455, 6.75571489], [93.82997894, 6.75522709], [93.82914734, 6.75474215], [93.82831573, 6.75425577], [93.82692719, 6.75432491], [93.82602692, 6.75460005], [93.82483673, 6.75502014], [93.82415009, 6.75529814], [93.82331848, 6.7554369], [93.82213593, 6.75564384], [93.82039642, 6.75591993], [93.81902313, 6.75648117], [93.81721497, 6.75689602], [93.81575775, 6.75779819], [93.81485748, 6.7583499], [93.8135376, 6.75891018], [93.81263733, 6.75911808], [93.81151581, 6.75974178], [93.8107605, 6.76009083], [93.81020355, 6.76064682], [93.80999756, 6.761271], [93.80986023, 6.76168919], [93.8097229, 6.76210594], [93.80957794, 6.76217413], [93.80840302, 6.76245213], [93.8069458, 6.76245213], [93.80665588, 6.76251984], [93.80638885, 6.76277781], [93.8061142, 6.7630558], [93.80579376, 6.76342106], [93.80544281, 6.76397514], [93.80488586, 6.76453114], [93.80447388, 6.76564312], [93.80426788, 6.76626682], [93.80405426, 6.76716995], [93.8039856, 6.76786518], [93.80384827, 6.76848984], [93.80391693, 6.76911592], [93.80419159, 6.77001905], [93.80454254, 6.77064323], [93.80503082, 6.77133799], [93.80516815, 6.77196121], [93.80544281, 6.77237988], [93.80571747, 6.77286816], [93.80634308, 6.77342415], [93.80683136, 6.77397823], [93.80731964, 6.77404785], [93.80752563, 6.77404785], [93.80808258, 6.77411699], [93.80932617, 6.77501917], [93.80988312, 6.77572107], [93.81099701, 6.7766881], [93.81154633, 6.77703619], [93.8116684, 6.77722311], [93.8125, 6.77805519], [93.8125, 6.77833319], [93.81276703, 6.77861118], [93.81276703, 6.77888918], [93.81305695, 6.77916718], [93.81305695, 6.77999878], [93.81222534, 6.78083277], [93.81194305, 6.78083277], [93.8116684, 6.78111076], [93.81111145, 6.78111076], [93.81083679, 6.78138924], [93.80979156, 6.78164482], [93.80958557, 6.78185177], [93.80916595, 6.78261805], [93.80895996, 6.7830348], [93.80860901, 6.78352022], [93.80812836, 6.78359079], [93.80770874, 6.78388977], [93.80771637, 6.78436613], [93.80779266, 6.78554916], [93.80764771, 6.7863121], [93.80764771, 6.78700686], [93.80771637, 6.78749084], [93.80813599, 6.78790998], [93.80862427, 6.78825617], [93.80862427, 6.78867388], [93.80860901, 6.78972197], [93.80860901, 6.78999996], [93.80944824, 6.79083395], [93.8097229, 6.79083395], [93.80999756, 6.79111004], [93.8102951, 6.79112387], [93.81054688, 6.79138994], [93.81083679, 6.79138803], [93.81167603, 6.79222012], [93.81167603, 6.79278088], [93.81194305, 6.79305601], [93.81194305, 6.79416609], [93.81167603, 6.79443979], [93.81167603, 6.79472923], [93.81083679, 6.79556084], [93.8105545, 6.79555702], [93.81027985, 6.79583216], [93.80999756, 6.79583216], [93.8097229, 6.79611015], [93.80944824, 6.79611015], [93.80916595, 6.79639101], [93.8088913, 6.79638815], [93.8077774, 6.79750109], [93.8077774, 6.79861116], [93.80805206, 6.79888916], [93.80805206, 6.79944515], [93.80831909, 6.79971981], [93.80833435, 6.80027723], [93.80882263, 6.80124521], [93.80923462, 6.80284309], [93.80930328, 6.80367708], [93.80909729, 6.80402088], [93.80860901, 6.80500078], [93.80831909, 6.80527878], [93.80831909, 6.80638885], [93.80860901, 6.80667019], [93.8088913, 6.80666685], [93.80916595, 6.80694485], [93.80999756, 6.80694485], [93.81027985, 6.80666685], [93.81138611, 6.80666685], [93.8116684, 6.80694485], [93.81222534, 6.80694485], [93.8125, 6.80722284], [93.81276703, 6.80722094], [93.8133316, 6.80777693], [93.8133316, 6.80805492], [93.81361389, 6.80833292], [93.81361389, 6.80861092], [93.81416321, 6.80916786], [93.81416321, 6.809443], [93.8152771, 6.81055593], [93.8152771, 6.81083393], [93.81555176, 6.81111193], [93.81555176, 6.81138992], [93.81583405, 6.81166506], [93.81583405, 6.81361198], [93.81555176, 6.81388998], [93.81555176, 6.81611013], [93.8152771, 6.81639004], [93.8152771, 6.81666994], [93.81416321, 6.81778002], [93.81388855, 6.81778002], [93.81360626, 6.81806087], [93.81305695, 6.81805611], [93.81277466, 6.8183341], [93.81138611, 6.8183341], [93.81111145, 6.81805611], [93.81054688, 6.81806087], [93.80916595, 6.81666994], [93.80916595, 6.81639004], [93.8088913, 6.81611013], [93.8088913, 6.81583405], [93.80860901, 6.81555605], [93.80860901, 6.81500006], [93.80805206, 6.81443882], [93.80805206, 6.81416607], [93.80638885, 6.8125], [93.80610657, 6.8125], [93.80583191, 6.81221914], [93.80527496, 6.812222], [93.80500031, 6.81194401], [93.8041687, 6.81194401], [93.80388641, 6.812222], [93.80361176, 6.81221914], [93.8033371, 6.8125], [93.80305481, 6.8125], [93.80222321, 6.81333399], [93.80166626, 6.81333399], [93.8013916, 6.81361198], [93.80110931, 6.81361198], [93.7986145, 6.81611204], [93.7986145, 6.81639004], [93.79666901, 6.8183341], [93.79638672, 6.81847095], [93.79618073, 6.81902695], [93.79618073, 6.81986094], [93.79645538, 6.82041693], [93.79645538, 6.82090282], [93.79638672, 6.82139111], [93.7960434, 6.82201481], [93.79528046, 6.82277918], [93.79528046, 6.82333183], [93.79499817, 6.82360983], [93.79499817, 6.82389116], [93.7933197, 6.82555914], [93.79277802, 6.82555485], [93.79250336, 6.82583284], [93.79222107, 6.82583284], [93.79146576, 6.82660723], [93.7911911, 6.82702494], [93.79098511, 6.82737112], [93.79070282, 6.82785892], [93.79022217, 6.82834387], [93.78931427, 6.82862186], [93.78807068, 6.8290391], [93.78744507, 6.82973385], [93.78661346, 6.83098316], [93.78612518, 6.8323741], [93.78591919, 6.83383179], [93.7857132, 6.83584881], [93.78605652, 6.83717108], [93.78688812, 6.83855486], [93.78749847, 6.83916807], [93.78749847, 6.83944416], [93.78778076, 6.83971024], [93.78778076, 6.84027815], [93.78749847, 6.84055614], [93.7875061, 6.8408289], [93.78742981, 6.8412509], [93.78778076, 6.84166622], [93.78778076, 6.84194422], [93.78805542, 6.84222221], [93.78805542, 6.84277821], [93.78833008, 6.84306097], [93.78888702, 6.84306097], [93.78937531, 6.84298515], [93.78979492, 6.84312391], [93.79006958, 6.84326315], [93.79027557, 6.84361219], [93.79138947, 6.84472179], [93.79138947, 6.84499979], [93.79165649, 6.84528017], [93.79165649, 6.84556103], [93.79360962, 6.84749985], [93.79360962, 6.84777784], [93.79416656, 6.84833384], [93.79416656, 6.84860992], [93.79444122, 6.84889984], [93.79444122, 6.85027885], [93.79416656, 6.85055399], [93.79416656, 6.85083008], [93.79360962, 6.85139084], [93.79305267, 6.85139084], [93.79277802, 6.85167122], [93.79250336, 6.85166693], [93.79222107, 6.85194492], [93.79194641, 6.85194492], [93.79166412, 6.85222292], [93.79138947, 6.85222006], [93.79083252, 6.85277891], [93.79083252, 6.853055], [93.79055786, 6.853333], [93.79055786, 6.85444498], [93.7902832, 6.85472107], [93.7902832, 6.85528088], [93.78888702, 6.85666895], [93.78833008, 6.85666704], [93.78805542, 6.85694504], [93.78778076, 6.85694504], [93.78749847, 6.85666704], [93.78721619, 6.85666895], [93.78627777, 6.85571718], [93.7858429, 6.85528088], [93.78527832, 6.85528088], [93.78499603, 6.85500097], [93.78443909, 6.85500097], [93.7841568, 6.85472107], [93.78349304, 6.85463381], [93.78314209, 6.8545661], [93.78265381, 6.8545661], [93.78221893, 6.85444021], [93.7813797, 6.85528088], [93.78111267, 6.85527897], [93.78022003, 6.85624981], [93.7792511, 6.85729122], [93.77876282, 6.85798693], [93.77820587, 6.85868216], [93.77793121, 6.85923815], [93.77793121, 6.8599329], [93.77771759, 6.86048698], [93.7773056, 6.86097479], [93.77709961, 6.86124992], [93.77674866, 6.86160088], [93.77641296, 6.86174011], [93.77612305, 6.86215496], [93.77584839, 6.86278009], [93.77515411, 6.86333609], [93.77487946, 6.8634038], [93.77416992, 6.86389017], [93.77375031, 6.86409712], [93.77361298, 6.86472082], [93.77361298, 6.86499977], [93.77333069, 6.86527777], [93.77333069, 6.86583424], [93.77305603, 6.86610889], [93.77333069, 6.86639023], [93.77333069, 6.86666822], [93.77500153, 6.86833382], [93.77500153, 6.86861181], [93.77527618, 6.86888981], [93.77527618, 6.86944389], [93.7755661, 6.86971998], [93.77555847, 6.86999989], [93.77527618, 6.87027788], [93.77527618, 6.87083387], [93.7752533, 6.87141991], [93.77503204, 6.8716979], [93.77441406, 6.87211514], [93.77406311, 6.87274218], [93.77388763, 6.87333393], [93.77361298, 6.87361002], [93.77361298, 6.87388802], [93.77305603, 6.87444401], [93.77305603, 6.8747201], [93.77249908, 6.87528086], [93.77249908, 6.87556124], [93.77166748, 6.87638807], [93.77159882, 6.87673712], [93.77194977, 6.87721586], [93.77199554, 6.87727499], [93.7722168, 6.87750101], [93.77333069, 6.87750101], [93.77361298, 6.87778091], [93.77388763, 6.87777901], [93.77444458, 6.87833214], [93.77471924, 6.87833023], [93.7755661, 6.87917089], [93.77583313, 6.87916708], [93.77610779, 6.87944508], [93.77639008, 6.87944508], [93.77666473, 6.87972307], [93.77694702, 6.87972021], [93.77706146, 6.88065004]]], [[[93.71305847, 7.44361115], [93.71305847, 7.44262981], [93.71334076, 7.44179916], [93.71334076, 7.44089603], [93.71327209, 7.44026899], [93.71416473, 7.43888807], [93.71458435, 7.43784714], [93.71499634, 7.43638992], [93.71499634, 7.43611002], [93.71555328, 7.43555593], [93.71583557, 7.43416595], [93.71666718, 7.43360996], [93.71694183, 7.43333387], [93.71778107, 7.43333387], [93.71916962, 7.43194389], [93.71916962, 7.43138981], [93.71944427, 7.43111181], [93.72000122, 7.43048], [93.72034454, 7.42944098], [93.72034454, 7.42846823], [93.72041321, 7.42743111], [93.72075653, 7.42618179], [93.72075653, 7.42493105], [93.72055817, 7.4236002], [93.72055817, 7.42277718], [93.72222137, 7.42111111], [93.72222137, 7.42055511], [93.72194672, 7.42027712], [93.72194672, 7.42000103], [93.7216568, 7.41972113], [93.72166443, 7.41944504], [93.72138977, 7.41916704], [93.72138977, 7.41750097], [93.72109985, 7.41722012], [93.72110748, 7.41638899], [93.72138977, 7.41611004], [93.72138977, 7.41527891], [93.72166443, 7.41500092], [93.7216568, 7.41306114], [93.7215271, 7.41096878], [93.72118378, 7.40923405], [93.72138977, 7.40749979], [93.72138977, 7.40221882], [93.72222137, 7.40139008], [93.72222137, 7.40111113], [93.72277832, 7.40055513], [93.72277832, 7.39999914], [93.72333527, 7.39944506], [93.72333527, 7.39916706], [93.72389221, 7.39861107], [93.72389221, 7.39833307], [93.72472382, 7.39749908], [93.72472382, 7.39722109], [93.72611237, 7.39583302], [93.72638702, 7.39583302], [93.72750092, 7.39472294], [93.72833252, 7.39472294], [93.72861481, 7.39444494], [93.72888947, 7.39444494], [93.72916412, 7.39472294], [93.73000336, 7.39388895], [93.73000336, 7.39361095], [93.73139191, 7.39222097], [93.73166656, 7.39222288], [93.73332977, 7.3905549], [93.73361206, 7.3905592], [93.73443604, 7.38971996], [93.73472595, 7.38972282], [93.73500061, 7.38944483], [93.73527527, 7.38944483], [93.73555756, 7.38916683], [93.73583221, 7.38917112], [93.73610687, 7.38889122], [93.73638916, 7.38889122], [93.73665619, 7.38860989], [93.73694611, 7.38860989], [93.73916626, 7.38638783], [93.73944092, 7.38639116], [93.74111176, 7.38471985], [93.74138641, 7.38472223], [93.7416687, 7.38444424], [93.74194336, 7.38444424], [93.74222565, 7.38416576], [93.74276733, 7.38417101], [93.74360657, 7.38333178], [93.74388885, 7.38333416], [93.7444458, 7.38277817], [93.74472046, 7.38278008], [93.74500275, 7.38250017], [93.74610901, 7.38250017], [93.7463913, 7.38278008], [93.74666595, 7.38250017], [93.7472229, 7.38250017], [93.74749756, 7.38222218], [93.74777985, 7.38222218], [93.7480545, 7.38194418], [93.74833679, 7.38194418], [93.74972534, 7.38055611], [93.74972534, 7.38027811], [93.75, 7.38000011], [93.75, 7.37972212], [93.75027466, 7.37944412], [93.75027466, 7.37916613], [93.75055695, 7.37889004], [93.75055695, 7.3786211], [93.7508316, 7.3783288], [93.7508316, 7.37777805], [93.7519455, 7.37666512], [93.75340271, 7.37674093], [93.75389099, 7.37702084], [93.7544632, 7.37667179], [93.7544632, 7.37638998], [93.7547226, 7.37610912], [93.75583649, 7.37506294], [93.7564621, 7.37436819], [93.75624847, 7.37353611], [93.75631714, 7.37262917], [93.75653076, 7.37145519], [93.75653076, 7.37034321], [93.75701141, 7.36888695], [93.75722504, 7.36763811], [93.75701141, 7.36674023], [93.75666809, 7.3661108], [93.7563858, 7.36583281], [93.7563858, 7.36555481], [93.75583649, 7.3650012], [93.75583649, 7.36472082], [93.75527954, 7.36416721], [93.75527954, 7.36361122], [93.75499725, 7.36333323], [93.75499725, 7.36277914], [93.75527954, 7.36250114], [93.75527954, 7.36222315], [93.75553894, 7.36164618], [93.75567627, 7.36081409], [93.75574493, 7.35984278], [93.7555542, 7.35972214], [93.7547226, 7.35888815], [93.75417328, 7.35889006], [93.75389099, 7.35861015], [93.75333405, 7.35861015], [93.75305176, 7.35833216], [93.7527771, 7.35833216], [93.75250244, 7.35805607], [93.75222015, 7.35806084], [93.7520752, 7.35791016], [93.7519455, 7.35777807], [93.75166321, 7.35778093], [93.75139618, 7.35750914], [93.74973297, 7.35750914], [93.74952698, 7.3573041], [93.7491684, 7.35694408], [93.74888611, 7.35694408], [93.74861145, 7.35666609], [93.74861145, 7.35638809], [93.74832916, 7.3561101], [93.74833679, 7.35583401], [93.7480545, 7.35555601], [93.7480545, 7.35527802], [93.74777985, 7.35500002], [93.74777985, 7.35472012], [93.7480545, 7.35444403], [93.7480545, 7.35416603], [93.74832916, 7.35388994], [93.74832916, 7.35332918], [93.74861145, 7.35305595], [93.74861145, 7.35277796], [93.74888611, 7.35249996], [93.74888611, 7.3522191], [93.74749756, 7.35083389], [93.7472229, 7.35083389], [93.74694824, 7.3505559], [93.74666595, 7.35056019], [93.7463913, 7.35027981], [93.74582672, 7.35027981], [93.74524689, 7.34969187], [93.74500275, 7.34944296], [93.74472046, 7.34944296], [93.74277496, 7.34749889], [93.74277496, 7.3472209], [93.74222565, 7.34666681], [93.74222565, 7.34638882], [93.74194336, 7.34611082], [93.74194336, 7.34583282], [93.74138641, 7.34527683], [93.74138641, 7.34499884], [93.7408371, 7.34444094], [93.7408371, 7.34416723], [93.73999786, 7.34333277], [93.73999786, 7.34305477], [93.73972321, 7.34277678], [93.73972321, 7.34251022], [93.73916626, 7.34194088], [93.73916626, 7.34166718], [93.73860931, 7.34111118], [93.73860931, 7.34083319], [93.73805237, 7.34027719], [93.73805237, 7.34000111], [93.73777771, 7.33972311], [93.73777771, 7.33944511], [93.73750305, 7.33916712], [93.73750305, 7.33889103], [93.73722076, 7.33861113], [93.73722076, 7.33694506], [93.73694611, 7.33666706], [93.73694611, 7.33444405], [93.73666382, 7.33416605], [93.73666382, 7.33333492], [93.73638916, 7.33305597], [93.73638916, 7.33249998], [93.73610687, 7.33222008], [93.7361145, 7.33111], [93.73583221, 7.33083391], [93.73583221, 7.33027792], [93.73527527, 7.32972193], [93.73527527, 7.32833385], [93.73500061, 7.32805586], [93.73500061, 7.32777786], [93.73472595, 7.32751083], [93.73472595, 7.32694197], [93.73444366, 7.32666588], [93.73444366, 7.32638788], [93.73416901, 7.32611179], [93.73416901, 7.3258338], [93.73388672, 7.3255558], [93.73388672, 7.32527781], [93.73361206, 7.32499981], [93.73361206, 7.32471895], [93.73332977, 7.32444382], [93.73332977, 7.32416821], [93.73305511, 7.32389021], [93.73306274, 7.32360888], [93.73194122, 7.32250023], [93.73082733, 7.32250023], [93.73060608, 7.32227612], [93.73055267, 7.3222208], [93.73027802, 7.3222208], [93.72916412, 7.32111216], [93.72916412, 7.32083321], [93.72888947, 7.32055521], [93.72888947, 7.31999922], [93.72861481, 7.31972122], [93.72861481, 7.31888914], [93.72833252, 7.31861115], [93.72833252, 7.31833315], [93.72805786, 7.31805515], [93.72805786, 7.31777906], [93.7277832, 7.31749916], [93.72777557, 7.31722116], [93.72721863, 7.31666708], [93.72721863, 7.31638908], [93.72693634, 7.31611109], [93.72694397, 7.31583309], [93.72666931, 7.3155551], [93.72666931, 7.3152771], [93.72638702, 7.31500101], [93.72638702, 7.31443977], [93.72611237, 7.31416702], [93.72611237, 7.31361103], [93.72583008, 7.31333303], [93.72583008, 7.31250095], [93.72555542, 7.31222296], [93.72555542, 7.31166697], [93.72528076, 7.31138897], [93.72528076, 7.31083012], [93.72499847, 7.31055498], [93.72499847, 7.3100009], [93.7233429, 7.30833006], [93.72305298, 7.30833197], [93.72277832, 7.30805397], [93.72249603, 7.30806112], [93.72222137, 7.30778122], [93.72194672, 7.30778122], [93.7216568, 7.30750084], [93.72138977, 7.30750084], [93.72083282, 7.30694008], [93.72055817, 7.30694389], [93.71948242, 7.30587101], [93.71888733, 7.30527782], [93.71861267, 7.30528116], [93.71833038, 7.30499983], [93.71806335, 7.30499983], [93.71666718, 7.30639982], [93.71639252, 7.30639982], [93.71611023, 7.30667114], [93.71583557, 7.3066659], [93.71555328, 7.30694389], [93.71527863, 7.30694389], [93.71498871, 7.30671692], [93.71472168, 7.30667114], [93.71333313, 7.30528116], [93.71305847, 7.30528116], [93.71277618, 7.30499983], [93.71166992, 7.30499983], [93.71161652, 7.30494595], [93.71138763, 7.30471992], [93.71083069, 7.30472183], [93.71055603, 7.30444384], [93.71028137, 7.30444384], [93.70999908, 7.30416584], [93.70916748, 7.30416584], [93.70888519, 7.30444384], [93.70777893, 7.30444384], [93.70762634, 7.30429602], [93.70749664, 7.30416584], [93.70722198, 7.30417109], [93.70610046, 7.30306101], [93.70610046, 7.30222178], [93.70583344, 7.30194378], [93.70583344, 7.30027819], [93.70555878, 7.30000019], [93.70555878, 7.2994442], [93.70471954, 7.29861212], [93.70444489, 7.29861212], [93.70424652, 7.29841089], [93.70417023, 7.29833412], [93.70388794, 7.29833412], [93.70333099, 7.29777813], [93.70305634, 7.29778004], [93.70276642, 7.29750013], [93.70249939, 7.29750013], [93.70222473, 7.29722214], [93.70194244, 7.29722214], [93.69962311, 7.29490089], [93.69833374, 7.29361105], [93.69805908, 7.29361105], [93.69777679, 7.29333305], [93.69750214, 7.29333305], [93.6973877, 7.29321909], [93.69721985, 7.29305506], [93.6966629, 7.29305983], [93.69638824, 7.29277992], [93.69610596, 7.29277992], [93.6958313, 7.29250193], [93.69555664, 7.29250193], [93.69526672, 7.29277992], [93.69473267, 7.29277992], [93.69444275, 7.29305983], [93.69416046, 7.29305983], [93.6938858, 7.29277992], [93.69361115, 7.29277992], [93.69304657, 7.29222107], [93.69277954, 7.29222107], [93.69249725, 7.29194498], [93.6922226, 7.29194498], [93.69194794, 7.29166698], [93.69139099, 7.29166985], [93.69111633, 7.29140091], [93.69055176, 7.29140091], [93.69028473, 7.29112291], [93.68972015, 7.29111099], [93.6894455, 7.290833], [93.68722534, 7.290833], [93.68701935, 7.29062986], [93.68694305, 7.290555], [93.6866684, 7.29055977], [93.68638611, 7.29028177], [93.68611145, 7.29028177], [93.68554688, 7.28972101], [93.6855545, 7.28916693], [93.68527985, 7.28888893], [93.68527985, 7.28861094], [93.68499756, 7.28833294], [93.68499756, 7.28805494], [93.68416595, 7.28722286], [93.68416595, 7.28666687], [93.68333435, 7.28583288], [93.68250275, 7.28583288], [93.68222046, 7.28555489], [93.68165588, 7.28555918], [93.68148804, 7.28537893], [93.68138885, 7.28527021], [93.68083191, 7.2852788], [93.68055725, 7.2850008], [93.68000031, 7.2850008], [93.67973328, 7.2847209], [93.67944336, 7.28472281], [93.6783371, 7.28361082], [93.6783371, 7.28333282], [93.67805481, 7.28305721], [93.67805481, 7.28277922], [93.67778015, 7.28250122], [93.67778015, 7.28222895], [93.67749786, 7.28193998], [93.67749786, 7.28166723], [93.67722321, 7.28138781], [93.67722321, 7.28082991], [93.67694092, 7.28055716], [93.67722321, 7.28027916], [93.67722321, 7.27943993], [93.67749786, 7.27916622], [93.67749786, 7.27861023], [93.67778015, 7.27833223], [93.67778015, 7.27750015], [93.67722321, 7.27694416], [93.67694092, 7.27694416], [93.67666626, 7.27666616], [93.6763916, 7.27667093], [93.67527771, 7.27556086], [93.67527771, 7.27528], [93.67500305, 7.2750001], [93.67500305, 7.2747221], [93.67472076, 7.2744441], [93.67472076, 7.27389002], [93.67444611, 7.27361202], [93.67444611, 7.27305603], [93.67416382, 7.27277803], [93.67415619, 7.27222013], [93.67388916, 7.27194405], [93.67388916, 7.27166605], [93.6736145, 7.27138996], [93.67360687, 7.27111006], [93.67166901, 7.26916504], [93.67166901, 7.2688899], [93.67111206, 7.26832914], [93.67111206, 7.26777697], [93.67082977, 7.26749897], [93.67082977, 7.26583099], [93.67055511, 7.2655549], [93.67055511, 7.26499891], [93.67028046, 7.26472092], [93.67028046, 7.26277685], [93.66999817, 7.26249886], [93.66999054, 7.26138878], [93.66971588, 7.26109982], [93.66972351, 7.25972319], [93.66944122, 7.25944519], [93.66944122, 7.2588892], [93.66916656, 7.2586112], [93.66916656, 7.25833321], [93.66889191, 7.25805521], [93.66889191, 7.25777721], [93.66722107, 7.25611115], [93.66638947, 7.25611115], [93.66583252, 7.25555706], [93.66443634, 7.25556087], [93.66417694, 7.25529003], [93.66361237, 7.25529003], [93.66306305, 7.25472021], [93.66278076, 7.25472307], [93.66166687, 7.25361013], [93.66139221, 7.25361013], [93.66083527, 7.253057], [93.66055298, 7.25306082], [93.66027832, 7.25278091], [93.66027832, 7.25250006], [93.65972137, 7.25193977], [93.65972137, 7.25166607], [93.65944672, 7.25138807], [93.65944672, 7.25083017], [93.65777588, 7.24916601], [93.65666962, 7.24840307], [93.65590668, 7.24784613], [93.65528107, 7.24694395], [93.65451813, 7.24610996], [93.65354919, 7.24520683], [93.65292358, 7.24444389], [93.65083313, 7.24444389], [93.65000153, 7.24361181], [93.64971924, 7.24361181], [93.64897919, 7.2428689], [93.64861298, 7.24249983], [93.64833069, 7.24249983], [93.64778137, 7.24306011], [93.6472168, 7.24306011], [93.64638519, 7.24388981], [93.64638519, 7.2441678], [93.64583588, 7.24472189], [93.64554596, 7.24471903], [93.64527893, 7.24500179], [93.64499664, 7.24500179], [93.64360809, 7.24638796], [93.64360809, 7.24666595], [93.64333344, 7.24694395], [93.64333344, 7.24749994], [93.64221954, 7.24861002], [93.64167023, 7.24861002], [93.64055634, 7.2497201], [93.64055634, 7.25], [93.64026642, 7.25028086], [93.64026642, 7.25056124], [93.63999939, 7.25055599], [93.63972473, 7.25083399], [93.6397171, 7.25111008], [93.63944244, 7.25138998], [93.63944244, 7.25166607], [93.63805389, 7.253057], [93.63861084, 7.25361013], [93.63861084, 7.25444508], [93.63889313, 7.25472021], [93.63889313, 7.25529003], [93.63861084, 7.25555706], [93.63861084, 7.25666714], [93.63833618, 7.25694513], [93.63833618, 7.25722122], [93.63805389, 7.25750113], [93.63805389, 7.25777721], [93.63722229, 7.2586112], [93.63722229, 7.2588892], [93.63666534, 7.25944519], [93.63667297, 7.2597208], [93.63500214, 7.26138878], [93.63445282, 7.26138878], [93.6341629, 7.26166916], [93.63388824, 7.26166677], [93.63360596, 7.26194096], [93.63360596, 7.26277924], [93.63277435, 7.26361084], [93.6313858, 7.26361084], [93.63111115, 7.26333284], [93.63027954, 7.26333284], [93.62999725, 7.26361084], [93.62999725, 7.26416683], [93.6297226, 7.26416683], [93.62916565, 7.26472282], [93.62889862, 7.26577902], [93.62876129, 7.26730299], [93.62876129, 7.26855183], [93.62916565, 7.26972198], [93.63083649, 7.27138996], [93.63083649, 7.2719388], [93.6313324, 7.2724452], [93.63166809, 7.27277994], [93.63194275, 7.27277803], [93.63249969, 7.27333403], [93.63277435, 7.27333403], [93.63361359, 7.27416611], [93.63361359, 7.2744441], [93.63388062, 7.27472019], [93.63388062, 7.2750001], [93.6341629, 7.27528], [93.6341629, 7.27638817], [93.63388824, 7.27666616], [93.63388062, 7.27694178], [93.63276672, 7.27806091], [93.63223267, 7.27806091], [93.63194275, 7.27777815], [93.63111115, 7.27861023], [93.63111115, 7.28027916], [93.63194275, 7.28110981], [93.63223267, 7.28110981], [93.63388824, 7.28277922], [93.63388824, 7.28305721], [93.6341629, 7.28333282], [93.6341629, 7.28583288], [93.63444519, 7.28611088], [93.63444519, 7.28638887], [93.63388824, 7.28694487], [93.63388824, 7.28722286], [93.63361359, 7.28749895], [93.63360596, 7.28861094], [93.6333313, 7.28889084], [93.6333313, 7.29000092], [93.63305664, 7.290277], [93.63305664, 7.290555], [93.63277435, 7.290833], [93.63276672, 7.29111099], [93.63249969, 7.29138899], [93.63249969, 7.29166698], [93.63223267, 7.29194117], [93.63223267, 7.29250193], [93.63194275, 7.29277706], [93.63194275, 7.29305506], [93.63166809, 7.29333305], [93.63166809, 7.29361105], [93.6313858, 7.29389], [93.6313858, 7.29471922], [93.63111115, 7.29499912], [93.63111115, 7.29527998], [93.63083649, 7.29555607], [93.63083649, 7.29666615], [93.63054657, 7.2969408], [93.6305542, 7.29777813], [93.63027954, 7.29805613], [93.63027954, 7.29832888], [93.6297226, 7.29888821], [93.6297226, 7.2991662], [93.62944794, 7.2994442], [93.62944794, 7.30027103], [93.62916565, 7.30055618], [93.62909698, 7.30152893], [93.62921906, 7.30222178], [93.62923431, 7.30284882], [93.62875366, 7.3031249], [93.62805176, 7.30360985], [93.62805176, 7.30388784], [93.6277771, 7.30416584], [93.6277771, 7.30444384], [93.62638855, 7.30583382], [93.6230545, 7.30583382], [93.62277985, 7.30610991], [93.62249756, 7.30610991], [93.62166595, 7.30694389], [93.62166595, 7.30721998], [93.6213913, 7.30750084], [93.6213913, 7.30805397], [93.62110901, 7.30833197], [93.62110901, 7.3094449], [93.6213913, 7.3097229], [93.6213913, 7.31083012], [93.62194061, 7.31139088], [93.6222229, 7.31139088], [93.62249756, 7.31167078], [93.62333679, 7.31167078], [93.62361145, 7.31139088], [93.62472534, 7.31138897], [93.62527466, 7.31194496], [93.62555695, 7.31194496], [93.6269455, 7.31333303], [93.62750244, 7.31333303], [93.6277771, 7.31361103], [93.62832642, 7.31361103], [93.6286087, 7.31389093], [93.62889099, 7.31388903], [93.62898254, 7.31398201], [93.62917328, 7.31417179], [93.62944794, 7.31416702], [93.63027954, 7.31500101], [93.63027954, 7.31583309], [93.63166809, 7.31722116], [93.63222504, 7.31722116], [93.63279724, 7.31779814], [93.63305664, 7.31805992], [93.6333313, 7.31805992], [93.63555908, 7.32027721], [93.63555908, 7.32055521], [93.63583374, 7.32083321], [93.63583374, 7.32111216], [93.6361084, 7.32139015], [93.6361084, 7.32416821], [93.63639069, 7.32444096], [93.63639069, 7.32499981], [93.63667297, 7.32528019], [93.63667297, 7.32638979], [93.63639069, 7.32666588], [93.63639069, 7.32805586], [93.63666534, 7.32833385], [93.63666534, 7.32860994], [93.63639069, 7.32888794], [93.63639069, 7.33083391], [93.63666534, 7.33111], [93.63666534, 7.33194399], [93.63639069, 7.33222008], [93.63639069, 7.33249998], [93.6361084, 7.33278084], [93.6361084, 7.33306122], [93.63500214, 7.33417082], [93.63471985, 7.33416605], [93.63444519, 7.33444405], [93.6341629, 7.33444405], [93.63277435, 7.33583212], [93.63277435, 7.33611107], [93.63249969, 7.33638906], [93.63249969, 7.33694506], [93.63222504, 7.33722305], [93.63223267, 7.33750105], [93.63249969, 7.33778095], [93.63249969, 7.33916712], [93.63277435, 7.33944511], [93.63276672, 7.34111118], [93.63249969, 7.34138918], [93.63277435, 7.34499884], [93.63277435, 7.34555483], [93.63305664, 7.34583282], [93.63305664, 7.34638882], [93.63360596, 7.34694099], [93.63361359, 7.34777689], [93.6333313, 7.34805489], [93.6333313, 7.34832001], [93.63277435, 7.34888983], [93.63277435, 7.34916782], [93.63249969, 7.34944296], [93.63249969, 7.34972191], [93.63222504, 7.3499999], [93.63194275, 7.35139704], [93.63181305, 7.35298109], [93.63159943, 7.35680723], [93.63124847, 7.35909796], [93.63111115, 7.36055708], [93.63111115, 7.3616662], [93.6313858, 7.36194515], [93.6313858, 7.36250114], [93.63166809, 7.36277914], [93.63166809, 7.36333323], [93.63194275, 7.3661108], [93.63194275, 7.36694479], [93.63223267, 7.36722088], [93.63223267, 7.36777878], [93.63249969, 7.36805487], [93.63249969, 7.37055492], [93.63277435, 7.37083292], [93.63276672, 7.37111092], [93.63305664, 7.37139177], [93.63305664, 7.37166977], [93.6341629, 7.37277985], [93.63445282, 7.37277985], [93.63459015, 7.37292814], [93.63471985, 7.37306023], [93.63527679, 7.37305498], [93.63583374, 7.37361097], [93.63667297, 7.37361097], [93.63694763, 7.37388897], [93.63722229, 7.37388897], [93.63749695, 7.37361097], [93.63861084, 7.37361097], [93.63889313, 7.37388897], [93.6397171, 7.37388897], [93.64000702, 7.37361097], [93.64111328, 7.37361097], [93.64138794, 7.37333298], [93.64167023, 7.37333298], [93.64194489, 7.37305498], [93.64221954, 7.37306023], [93.64360809, 7.37166977], [93.64389038, 7.37166977], [93.64417267, 7.37139177], [93.64444733, 7.37139177], [93.64472198, 7.37111092], [93.64499664, 7.37111092], [93.64527893, 7.37083292], [93.64555359, 7.37083292], [93.64583588, 7.37055492], [93.64611053, 7.37056017], [93.64749908, 7.36916924], [93.64778137, 7.36916924], [93.64805603, 7.36889076], [93.64833069, 7.36889076], [93.64861298, 7.36861086], [93.64943695, 7.36861086], [93.64971924, 7.36889076], [93.65000153, 7.36889076], [93.65027618, 7.36916924], [93.65055847, 7.36916685], [93.65110779, 7.36972284], [93.65194702, 7.36972284], [93.65218353, 7.36995983], [93.65277863, 7.37056017], [93.65305328, 7.37056017], [93.65528107, 7.37277985], [93.65556335, 7.37277985], [93.65666962, 7.37388897], [93.65666962, 7.37416792], [93.65721893, 7.37471914], [93.65721893, 7.37499905], [93.65750122, 7.37527704], [93.65750122, 7.37555599], [93.65777588, 7.37583399], [93.65777588, 7.37611198], [93.65999603, 7.3783288], [93.65999603, 7.3786211], [93.66027832, 7.37889004], [93.66027832, 7.37916613], [93.66194153, 7.3808341], [93.66305542, 7.3808341], [93.66333008, 7.3811121], [93.66500092, 7.3811121], [93.66527557, 7.3808341], [93.66583252, 7.3808341], [93.66722107, 7.37944412], [93.66722107, 7.37889004], [93.66750336, 7.37861204], [93.66750336, 7.37805986], [93.66777802, 7.37777996], [93.66777802, 7.37750006], [93.67166901, 7.37361097], [93.67194366, 7.37361097], [93.67222595, 7.37333298], [93.67250061, 7.37333298], [93.67277527, 7.37305498], [93.67305756, 7.37333298], [93.67444611, 7.37333298], [93.67472076, 7.37361097], [93.67500305, 7.37361097], [93.67527771, 7.37388897], [93.67555237, 7.37388897], [93.67582703, 7.37416983], [93.67610931, 7.37416792], [93.67666626, 7.37472105], [93.67694092, 7.37471914], [93.67749786, 7.3752799], [93.67778015, 7.37527704], [93.67805481, 7.37555599], [93.6783371, 7.37555599], [93.67861176, 7.37583399], [93.6791687, 7.37583399], [93.67944336, 7.37611198], [93.67972565, 7.37611198], [93.68027496, 7.37666512], [93.68027496, 7.37694407], [93.68055725, 7.3772192], [93.68055725, 7.37750006], [93.68083191, 7.37777805], [93.68083191, 7.37805605], [93.6811142, 7.37833405], [93.6811142, 7.37944412], [93.68138885, 7.37972212], [93.68138885, 7.3808341], [93.68166351, 7.3811121], [93.68166351, 7.38416576], [93.6819458, 7.38444424], [93.6819458, 7.38472223], [93.68305206, 7.38583183], [93.68305206, 7.38610983], [93.68360901, 7.38666582], [93.68360901, 7.38694382], [93.68416595, 7.38749981], [93.6847229, 7.38749123], [93.68498993, 7.38778114], [93.68723297, 7.38778114], [93.6875, 7.38806105], [93.68777466, 7.38805389], [93.68805695, 7.38833189], [93.6883316, 7.38832998], [93.68860626, 7.38860989], [93.68888855, 7.38860989], [93.68916321, 7.38889122], [93.68945313, 7.38889122], [93.69055176, 7.39000082], [93.69167328, 7.39000082], [93.69187164, 7.39020109], [93.69194794, 7.3902812], [93.6922226, 7.3902812], [93.69249725, 7.39000082], [93.69304657, 7.39000082], [93.69333649, 7.38971996], [93.69361115, 7.38972282], [93.6958313, 7.39194489], [93.69611359, 7.39194489], [93.69628906, 7.39211988], [93.69638824, 7.39222288], [93.6966629, 7.39222097], [93.69689941, 7.39245319], [93.69805908, 7.39362001], [93.6986084, 7.39362001], [93.69889069, 7.39389086], [93.69917297, 7.39389086], [93.70054626, 7.39250088], [93.70194244, 7.39250088], [93.7022171, 7.39278078], [93.70361328, 7.39278078], [93.70388794, 7.39250088], [93.70417023, 7.39250088], [93.70443726, 7.39278078], [93.70500183, 7.39277887], [93.70555878, 7.39333296], [93.70610046, 7.3933301], [93.70639038, 7.39362001], [93.70694733, 7.39362001], [93.70722198, 7.39389086], [93.70749664, 7.39389086], [93.70777893, 7.39362001], [93.70804596, 7.39362001], [93.70889282, 7.39278078], [93.70944214, 7.39278078], [93.7097168, 7.39250088], [93.71333313, 7.39250088], [93.71360779, 7.39278078], [93.71389008, 7.39277887], [93.71444702, 7.39333296], [93.71444702, 7.39472103], [93.7141571, 7.39500093], [93.7141571, 7.39555883], [93.71263885, 7.39673996], [93.71166992, 7.3968792], [93.71092224, 7.39673996], [93.71028137, 7.39638901], [93.70944214, 7.39722109], [93.70888519, 7.39722109], [93.70833588, 7.39777708], [93.70833588, 7.39861107], [93.70861053, 7.39888906], [93.70861053, 7.39972115], [93.70833588, 7.39999914], [93.70749664, 7.39999914], [93.70722198, 7.40028], [93.70694733, 7.40028], [93.70667267, 7.4005599], [93.70500183, 7.40055513], [93.70471954, 7.40083313], [93.70444489, 7.40090418], [93.70375061, 7.40090418], [93.70333099, 7.40139008], [93.70333099, 7.4022212], [93.70582581, 7.40471888], [93.70582581, 7.40500021], [93.70610809, 7.40527821], [93.70610809, 7.4066658], [93.70639038, 7.40694094], [93.70639038, 7.40749979], [93.70666504, 7.40777779], [93.70666504, 7.40916586], [93.70694733, 7.40944386], [93.70694733, 7.40972185], [93.70666504, 7.40999985], [93.70666504, 7.41083384], [93.70610809, 7.41138792], [93.70610809, 7.41166592], [93.70652771, 7.41284704], [93.70694733, 7.41360998], [93.70722198, 7.41388798], [93.70722198, 7.41416597], [93.70749664, 7.41444016], [93.70749664, 7.41473198], [93.70777893, 7.41500092], [93.70777893, 7.41555405], [93.70869446, 7.41694689], [93.70903778, 7.41757107], [93.70910645, 7.41840315], [93.70896912, 7.41923523], [93.7086792, 7.4199419], [93.70861053, 7.42111111], [93.70861053, 7.4213891], [93.70888519, 7.4216671], [93.70888519, 7.42250109], [93.70916748, 7.42277718], [93.70916748, 7.42333317], [93.70944214, 7.4236002], [93.70916748, 7.42388916], [93.70944214, 7.42416716], [93.70916748, 7.42444515], [93.70915985, 7.42472076], [93.70861053, 7.42527914], [93.70833588, 7.42527723], [93.70666504, 7.42694283], [93.70666504, 7.42805481], [93.70639038, 7.42833281], [93.70639038, 7.42860889], [93.70694733, 7.42916822], [93.70694733, 7.43055582], [93.70722198, 7.43083096], [93.70722198, 7.43138981], [93.70749664, 7.4316678], [93.70722198, 7.43194389], [93.70722198, 7.43222189], [93.70749664, 7.43249989], [93.70722198, 7.43277788], [93.70722198, 7.43333387], [93.70694733, 7.43360996], [93.70694733, 7.43389177], [93.70667267, 7.43416977], [93.70667267, 7.43638992], [93.70694733, 7.43667078], [93.70694733, 7.437778], [93.70666504, 7.43805599], [93.70667267, 7.43833017], [93.70610809, 7.43888807], [93.70610809, 7.43916607], [93.70555878, 7.43972015], [93.70555878, 7.44000006], [93.70527649, 7.44027805], [93.70527649, 7.44055605], [93.70471954, 7.44111013], [93.70471954, 7.44305706], [93.70500183, 7.44332981], [93.70500183, 7.44417095], [93.70582581, 7.44500113], [93.70610046, 7.44500113], [93.70639038, 7.44471121], [93.70639038, 7.44444513], [93.70666504, 7.44416714], [93.70694733, 7.44417095], [93.70749664, 7.44361115], [93.70777893, 7.44361115], [93.70805359, 7.4433322], [93.70833588, 7.4433322], [93.70861053, 7.44361115], [93.70979309, 7.44424009], [93.71026611, 7.44479084], [93.71089935, 7.44506884], [93.71180725, 7.44514179], [93.71270752, 7.44471121], [93.71333313, 7.44388914], [93.71305847, 7.44361115]]], [[[93.64778137, 7.47666883], [93.64805603, 7.47639084], [93.64888763, 7.47639084], [93.64916992, 7.47611094], [93.65000153, 7.47611094], [93.65249634, 7.47361088], [93.65249634, 7.47305489], [93.65277863, 7.4727788], [93.65277863, 7.4725008], [93.65249634, 7.47221994], [93.65249634, 7.47138882], [93.65277863, 7.47111082], [93.65194702, 7.47027922], [93.6516571, 7.47028112], [93.65139008, 7.47000122], [93.65110779, 7.47028112], [93.65083313, 7.47028112], [93.65055847, 7.47000122], [93.64943695, 7.47000122], [93.64916992, 7.47028112], [93.64833069, 7.47028112], [93.64805603, 7.47056103], [93.64722443, 7.47055721], [93.64694214, 7.47083282], [93.64666748, 7.47083282], [93.64638519, 7.47111082], [93.64611053, 7.47111082], [93.64555359, 7.47055721], [93.64527893, 7.47056103], [93.64499664, 7.47028112], [93.64472198, 7.47027922], [93.64416504, 7.47083282], [93.64417267, 7.47111082], [93.64389038, 7.4713912], [93.64417267, 7.4716711], [93.64417267, 7.47278118], [93.64389038, 7.47305918], [93.64389038, 7.47388887], [93.64416504, 7.47416687], [93.64417267, 7.4744401], [93.64485931, 7.47514009], [93.64499664, 7.47528076], [93.64527893, 7.47528076], [93.64562225, 7.47562599], [93.64639282, 7.47639084], [93.64694214, 7.47639084], [93.6472168, 7.47666883], [93.64778137, 7.47666883]]], [[[93.63445282, 7.47778177], [93.63471985, 7.47750092], [93.63445282, 7.47722101], [93.63444519, 7.47666693], [93.63440704, 7.47593784], [93.63385773, 7.47558022], [93.63314819, 7.47552109], [93.6326828, 7.47580099], [93.63223267, 7.47639084], [93.63083649, 7.47778177], [93.6305542, 7.477777], [93.62999725, 7.478333], [93.62999725, 7.47861099], [93.63027954, 7.47888899], [93.63027954, 7.47972107], [93.63054657, 7.48000097], [93.63249969, 7.48000097], [93.63445282, 7.47807121], [93.63445282, 7.47778177]]], [[[93.54360199, 7.52500105], [93.54582977, 7.5227809], [93.54582977, 7.52250099], [93.54693604, 7.52139091], [93.54693604, 7.52111006], [93.54833221, 7.51972198], [93.5486145, 7.51972198], [93.54944611, 7.518888], [93.54944611, 7.51861], [93.55027771, 7.51777792], [93.55029297, 7.51702595], [93.5501709, 7.51612091], [93.54953003, 7.51528883], [93.54890442, 7.5142498], [93.54856873, 7.51306915], [93.54779053, 7.51210117], [93.54662323, 7.51133013], [93.54499817, 7.51055622], [93.54332733, 7.51056004], [93.54305267, 7.51028013], [93.54277802, 7.51028013], [93.54250336, 7.5099988], [93.54194641, 7.51055622], [93.54194641, 7.51221895], [93.54138947, 7.51278019], [93.54110718, 7.51278019], [93.54083252, 7.51306009], [93.54055786, 7.5130558], [93.54000092, 7.51361179], [93.54000092, 7.51388979], [93.5402832, 7.51417923], [93.54027557, 7.51499987], [93.54055786, 7.51527786], [93.54055786, 7.51582909], [93.54166412, 7.51694393], [93.54166412, 7.51777792], [93.54083252, 7.51861], [93.54055786, 7.51861], [93.53971863, 7.51944399], [93.53971863, 7.51999998], [93.54000092, 7.52027798], [93.54000092, 7.52083397], [93.5402832, 7.52111006], [93.5402832, 7.52139091], [93.54055786, 7.52167082], [93.54055786, 7.52250099], [93.54083252, 7.52277899], [93.54083252, 7.52305698], [93.54055786, 7.52333498], [93.54055786, 7.52388906], [93.54111481, 7.52444506], [93.54129028, 7.52462006], [93.54138947, 7.52472305], [93.54194641, 7.52416706], [93.54222107, 7.52416706], [93.54250336, 7.52444506], [93.54277802, 7.52443981], [93.54332733, 7.52500105], [93.54360199, 7.52500105]]], [[[93.33963013, 7.91114998], [93.33965302, 7.91087008], [93.34018707, 7.91087198], [93.3401947, 7.90973186], [93.34046173, 7.90973186], [93.34046173, 7.90951109], [93.3401947, 7.90946817], [93.34018707, 7.90894222], [93.33990479, 7.90892792], [93.33987427, 7.90864992], [93.33937836, 7.90864992], [93.3393631, 7.90892982], [93.33908844, 7.90892792], [93.33908844, 7.90917921], [93.33880615, 7.90919209], [93.33878326, 7.91058016], [93.33933258, 7.91059399], [93.3393631, 7.91112995], [93.33963013, 7.91114998]]], [[[93.34156036, 7.90645981], [93.34159851, 7.90592003], [93.34215546, 7.90594482], [93.3421402, 7.90562487], [93.34243011, 7.90559578], [93.34240723, 7.905056], [93.34269714, 7.90505981], [93.3427124, 7.90470886], [93.34243011, 7.90470886], [93.34243011, 7.90413904], [93.34211731, 7.90413904], [93.34208679, 7.90469599], [93.34043121, 7.90472078], [93.34043121, 7.90505981], [93.34069824, 7.90506887], [93.34069824, 7.90535021], [93.34070587, 7.90588999], [93.3409729, 7.90588999], [93.3409729, 7.90616083], [93.34126282, 7.90616989], [93.34127808, 7.90645981], [93.34156036, 7.90645981]]], [[[93.18805695, 8.19250011], [93.1875, 8.19306087], [93.18722534, 8.1930542], [93.1866684, 8.19361019], [93.1866684, 8.19388771], [93.18611145, 8.1944437], [93.18583679, 8.1944437], [93.1855545, 8.19472218], [93.1847229, 8.19472027], [93.18444824, 8.19500065], [93.18360901, 8.19500065], [93.18332672, 8.19528103], [93.1827774, 8.19528103], [93.18251038, 8.19556141], [93.18222046, 8.19555664], [93.1819458, 8.19583225], [93.18000031, 8.19583225], [93.17972565, 8.19610977], [93.17944336, 8.19610977], [93.1791687, 8.19583035], [93.17861176, 8.1963892], [93.17861176, 8.19722271], [93.17858124, 8.19760323], [93.1786499, 8.19780159], [93.17851257, 8.19815731], [93.17837524, 8.19829559], [93.17795563, 8.19843292], [93.1778183, 8.19836521], [93.17722321, 8.19806099], [93.17694092, 8.19805527], [93.1763916, 8.19861126], [93.17687225, 8.19895267], [93.17707825, 8.19915962], [93.17673492, 8.19950867], [93.17624664, 8.19971561], [93.17575836, 8.19997978], [93.1753006, 8.20024872], [93.17505646, 8.20048046], [93.17430115, 8.20034122], [93.17410278, 8.20028973], [93.1738205, 8.19972134], [93.17360687, 8.19923973], [93.17326355, 8.19889069], [93.1727066, 8.19923973], [93.17249298, 8.20014], [93.17251587, 8.20075989], [93.17246246, 8.2009697], [93.17217255, 8.20125008], [93.17175293, 8.20146179], [93.17160797, 8.20125008], [93.17086029, 8.2009697], [93.17057037, 8.20068932], [93.16925049, 8.20069218], [93.16889954, 8.20041561], [93.16847992, 8.20020771], [93.16806793, 8.20006943], [93.16751099, 8.19979095], [93.16722107, 8.19972324], [93.16638947, 8.19972324], [93.16611481, 8.20000076], [93.16555786, 8.19999886], [93.16500092, 8.20056152], [93.16444397, 8.20055485], [93.16416931, 8.20083332], [93.16333008, 8.20083332], [93.16305542, 8.20111084], [93.16194153, 8.20111084], [93.16166687, 8.20083332], [93.16110992, 8.20083332], [93.1608429, 8.20111084], [93.16088104, 8.20216179], [93.16068268, 8.20251274], [93.16018677, 8.20264721], [93.15969849, 8.20312977], [93.15976715, 8.20389366], [93.15962982, 8.20410061], [93.1594162, 8.20472622], [93.15949249, 8.20493317], [93.15914154, 8.20527935], [93.15879059, 8.20555687], [93.15816498, 8.20590401], [93.15768433, 8.20611095], [93.15712738, 8.20631886], [93.15657043, 8.20638943], [93.15608215, 8.20666981], [93.15538788, 8.20666981], [93.15476227, 8.20674038], [93.15455627, 8.20660114], [93.15406799, 8.20631886], [93.15329742, 8.20659733], [93.15288544, 8.20701408], [93.15267181, 8.20756817], [93.15274811, 8.20820141], [93.15274811, 8.20868683], [93.15288544, 8.20896244], [93.15267181, 8.20917225], [93.15232849, 8.20917225], [93.15190887, 8.20889378], [93.15156555, 8.20889378], [93.1512146, 8.20896244], [93.15079498, 8.20903301], [93.15045166, 8.20924091], [93.15010071, 8.2095871], [93.14961243, 8.20986462], [93.14933777, 8.21007156], [93.14891815, 8.21014118], [93.14821625, 8.21028042], [93.14766693, 8.21006966], [93.14710999, 8.21035004], [93.14648438, 8.21062565], [93.14592743, 8.21076488], [93.14572144, 8.21090412], [93.14499664, 8.21166801], [93.14472198, 8.21194363], [93.14444733, 8.21193886], [93.14409637, 8.21228981], [93.1434021, 8.21263885], [93.14221954, 8.21333408], [93.14167023, 8.21333408], [93.14138794, 8.2136097], [93.14111328, 8.2136097], [93.14083099, 8.21389008], [93.14083099, 8.21416569], [93.14055634, 8.21444416], [93.13999939, 8.21444416], [93.13972473, 8.21472168], [93.13944244, 8.21472168], [93.13916779, 8.21500015], [93.1388855, 8.21500015], [93.13861084, 8.21527767], [93.13722229, 8.21527767], [93.13694763, 8.21500015], [93.13666534, 8.21500015], [93.1361084, 8.21444416], [93.13527679, 8.215271], [93.13527679, 8.21667099], [93.13446045, 8.21749973], [93.13388824, 8.21749973], [93.1333313, 8.21806145], [93.13305664, 8.21805573], [93.13277435, 8.2183342], [93.13277435, 8.21860981], [93.13194275, 8.21944427], [93.12944794, 8.21944427], [93.12916565, 8.2191658], [93.12889099, 8.2191658], [93.12833405, 8.21972179], [93.12805176, 8.21972179], [93.1277771, 8.22000027], [93.12666321, 8.22000027], [93.12611389, 8.22055435], [93.12610626, 8.22082996], [93.12526703, 8.2216711], [93.125, 8.22140026], [93.12473297, 8.22140026], [93.12441254, 8.2210741], [93.1241684, 8.22082996], [93.12333679, 8.22083473], [93.12194824, 8.22222328], [93.12166595, 8.22222328], [93.1213913, 8.2225008], [93.12083435, 8.2225008], [93.11972046, 8.22361088], [93.11972046, 8.22416687], [93.1194458, 8.22444534], [93.11946106, 8.22472], [93.11860657, 8.22555923], [93.11833191, 8.22555923], [93.11815643, 8.22606087], [93.11760712, 8.22626972], [93.1173172, 8.2259903], [93.11677551, 8.22585106], [93.11656189, 8.22605801], [93.11611176, 8.22611141], [93.11528015, 8.22694492], [93.11528015, 8.2272234], [93.11499786, 8.22750092], [93.11499786, 8.22944069], [93.11555481, 8.22999859], [93.11577606, 8.23042965], [93.11605835, 8.23104954], [93.11612701, 8.2318182], [93.1157074, 8.23243999], [93.11521912, 8.23272038], [93.11487579, 8.23271847], [93.11425018, 8.23313522], [93.11389923, 8.23285675], [93.11333466, 8.23277664], [93.11303711, 8.23250103], [93.11194611, 8.23249912], [93.11027527, 8.2341671], [93.11027527, 8.23444557], [93.11000061, 8.23472118], [93.11000061, 8.2349987], [93.10944366, 8.2355547], [93.10943604, 8.23583126], [93.10888672, 8.2364006], [93.10861206, 8.23639011], [93.10749817, 8.23750019], [93.10701752, 8.2379303], [93.10666656, 8.23821068], [93.10624695, 8.23897171], [93.10597992, 8.23918247], [93.10507202, 8.24007988], [93.10444641, 8.24104977], [93.10410309, 8.24174118], [93.10361481, 8.24222946], [93.10347748, 8.24243641], [93.10325623, 8.24292183], [93.1029892, 8.24313068], [93.10292053, 8.24409962], [93.1027832, 8.24451923], [93.10222626, 8.24520969], [93.10187531, 8.24534893], [93.10138702, 8.24555588], [93.10138702, 8.24582958], [93.10111237, 8.24610996], [93.10111237, 8.24713993], [93.10090637, 8.24776268], [93.10090637, 8.24838734], [93.10069275, 8.2488718], [93.10062408, 8.24929047], [93.10034943, 8.24984264], [93.09999847, 8.25012112], [93.09999847, 8.25060463], [93.09972382, 8.25074577], [93.09972382, 8.25166702], [93.09999847, 8.25194454], [93.09999847, 8.25222015], [93.10028076, 8.25250053], [93.10028076, 8.25278091], [93.10054779, 8.25311184], [93.10047913, 8.25358963], [93.09999084, 8.25366116], [93.09942627, 8.25352192], [93.09900665, 8.25352192], [93.09896088, 8.25334167], [93.09854126, 8.2532711], [93.09806061, 8.25347614], [93.09770966, 8.25458622], [93.09694672, 8.25583267], [93.09694672, 8.25611115], [93.09638977, 8.25666714], [93.09638977, 8.25694466], [93.09610748, 8.25722122], [93.09610748, 8.25751019], [93.09583282, 8.25777912], [93.09583282, 8.25805473], [93.09555817, 8.25833321], [93.09555817, 8.25861073], [93.09527588, 8.2588892], [93.09527588, 8.25916672], [93.09373474, 8.26070786], [93.09313202, 8.26176834], [93.09278107, 8.26211357], [93.09229279, 8.26253128], [93.09208679, 8.26329327], [93.09194946, 8.26350021], [93.09166718, 8.26371002], [93.09146118, 8.26398468], [93.09126282, 8.26433182], [93.09126282, 8.26468086], [93.09111786, 8.26474857], [93.09076691, 8.26495647], [93.09027863, 8.26523018], [93.08994293, 8.26578999], [93.08972168, 8.26607132], [93.08958435, 8.2660656], [93.08937836, 8.26641273], [93.08909607, 8.26682663], [93.08860779, 8.26721859], [93.08833313, 8.26749992], [93.08833313, 8.2677784], [93.08805847, 8.26805592], [93.08805847, 8.26833153], [93.08750153, 8.26889038], [93.08750153, 8.26917267], [93.08721924, 8.26944447], [93.08721924, 8.27000046], [93.08694458, 8.27027798], [93.08694458, 8.27055645], [93.08666992, 8.27083206], [93.08666992, 8.27111244], [93.08638763, 8.27138805], [93.08638763, 8.27194405], [93.08609772, 8.27221966], [93.08609772, 8.27251244], [93.08583069, 8.27277756], [93.08583069, 8.27305603], [93.08555603, 8.27333355], [93.08555603, 8.27361012], [93.08528137, 8.27388763], [93.08528137, 8.2747221], [93.08506012, 8.27493668], [93.08493042, 8.27577305], [93.08493042, 8.27605057], [93.08478546, 8.27639771], [93.0847168, 8.27701092], [93.08486176, 8.27750778], [93.08493042, 8.27812958], [93.08479309, 8.27833939], [93.0845108, 8.27854729], [93.08444214, 8.27916718], [93.08416748, 8.27943993], [93.08416748, 8.28027916], [93.08388519, 8.28055477], [93.08388519, 8.28194523], [93.08361053, 8.28222084], [93.08361053, 8.28333282], [93.08381653, 8.28447723], [93.08388519, 8.28482437], [93.08429718, 8.28510189], [93.08444214, 8.28531075], [93.08465576, 8.28565502], [93.08486176, 8.28621197], [93.08486176, 8.28669739], [93.08479309, 8.28725147], [93.0845871, 8.28787136], [93.08444214, 8.28878021], [93.08436584, 8.28947067], [93.08409882, 8.28975105], [93.08416748, 8.29051018], [93.08381653, 8.2907896], [93.08388519, 8.2913866], [93.08388519, 8.29166794], [93.08361053, 8.29194355], [93.08361053, 8.29416561], [93.08333588, 8.29444408], [93.08333588, 8.29555607], [93.08361053, 8.29583359], [93.08378601, 8.29663944], [93.08406067, 8.29719162], [93.08413696, 8.29760933], [93.083992, 8.29809284], [93.08406067, 8.29843903], [93.083992, 8.29885578], [93.083992, 8.29913044], [93.08406067, 8.29989529], [93.08406067, 8.30044937], [93.08441162, 8.30079556], [93.0848999, 8.30121326], [93.08503723, 8.30211067], [93.08483124, 8.30245876], [93.0848999, 8.30273819], [93.0848999, 8.30301571], [93.08454895, 8.30336189], [93.08448029, 8.30363846], [93.08448029, 8.30412292], [93.08476257, 8.30467701], [93.0848999, 8.305233], [93.08461761, 8.30537224], [93.08472443, 8.30583286], [93.08499908, 8.30611134], [93.08499908, 8.30667114], [93.08528137, 8.30786991], [93.08563232, 8.30821419], [93.08583069, 8.30888939], [93.08609772, 8.30994034], [93.08708191, 8.31146717], [93.08735657, 8.31243801], [93.08784485, 8.31292343], [93.08853912, 8.31354523], [93.08874512, 8.31403065], [93.08895874, 8.31507206], [93.08972168, 8.31583309], [93.08999634, 8.31611156], [93.08999634, 8.31694317], [93.09027863, 8.31722355], [93.09027863, 8.31749916], [93.09083557, 8.31805611], [93.0908432, 8.31832886], [93.09166718, 8.31917], [93.09166718, 8.31999969], [93.09194183, 8.32027817], [93.09194183, 8.32083416], [93.09223175, 8.32110977], [93.09222412, 8.32139015], [93.09249878, 8.32166576], [93.09249878, 8.32194233], [93.09361267, 8.32306099], [93.09361267, 8.32361221], [93.09388733, 8.32388783], [93.09388733, 8.32444382], [93.09416962, 8.32472229], [93.09416962, 8.32527828], [93.09471893, 8.32583046], [93.09471893, 8.3288908], [93.09443665, 8.32917118], [93.09443665, 8.33000088], [93.09416962, 8.33027554], [93.09416962, 8.33166695], [93.09375763, 8.3330431], [93.09375763, 8.3338747], [93.09388733, 8.334445], [93.09388733, 8.3358326], [93.09416962, 8.33611107], [93.09416962, 8.33722115], [93.09444427, 8.33749866], [93.09444427, 8.33805466], [93.09471893, 8.33833313], [93.09471893, 8.33916664], [93.09500122, 8.33944511], [93.09500122, 8.33972263], [93.09527588, 8.3399992], [93.09527588, 8.34027672], [93.09564972, 8.34028625], [93.09604645, 8.34029293], [93.09660339, 8.34029293], [93.09689331, 8.3405714], [93.09736633, 8.34085178], [93.09771729, 8.34105682], [93.09819794, 8.34112453], [93.0991745, 8.34140301], [93.09938049, 8.34154224], [93.09945679, 8.34195709], [93.09993744, 8.34195709], [93.10021973, 8.34216404], [93.10049438, 8.34251308], [93.10083008, 8.34333324], [93.10083008, 8.34360886], [93.10109711, 8.34389019], [93.10111237, 8.34500027], [93.10083008, 8.34527779], [93.10250092, 8.34694576], [93.10277557, 8.34666634], [93.10388947, 8.34666634], [93.10472107, 8.34749985], [93.10472107, 8.34777832], [93.10500336, 8.34805584], [93.10500336, 8.34944153], [93.10582733, 8.35028267], [93.10666656, 8.35028267], [93.10694122, 8.35000038], [93.10736084, 8.3495903], [93.10861206, 8.34897041], [93.11026764, 8.34832859], [93.11055756, 8.34805584], [93.11055756, 8.34777832], [93.11083221, 8.34749985], [93.11166382, 8.34749985], [93.11194611, 8.34721947], [93.11277771, 8.34721947], [93.11360931, 8.34805965], [93.11416626, 8.34805584], [93.11472321, 8.34861183], [93.11499786, 8.34861183], [93.11528015, 8.3488903], [93.11528015, 8.34916592], [93.11444092, 8.35000038], [93.11444092, 8.3502779], [93.11499786, 8.35083199], [93.11528015, 8.35083199], [93.11604309, 8.35007095], [93.1166687, 8.34965611], [93.11743927, 8.34947109], [93.11764526, 8.34940147], [93.11791992, 8.34919262], [93.11813354, 8.34919262], [93.11847687, 8.34933186], [93.11902618, 8.34932995], [93.1193161, 8.34961033], [93.11965942, 8.34988594], [93.11987305, 8.35009098], [93.12000275, 8.35056114], [93.12050629, 8.35105991], [93.1210022, 8.35112095], [93.12149048, 8.35111713], [93.12197876, 8.35139275], [93.12197876, 8.35174084], [93.12176514, 8.35188007], [93.12190247, 8.35215569], [93.12218475, 8.35243416], [93.12239075, 8.35250473], [93.12260437, 8.35271168], [93.12281036, 8.3527813], [93.12281036, 8.35306072], [93.12287903, 8.35319805], [93.12315369, 8.353405], [93.12329865, 8.35368061], [93.12364197, 8.35368061], [93.12399292, 8.35381985], [93.12419891, 8.3540287], [93.12419891, 8.35437584], [93.1244812, 8.35458279], [93.12481689, 8.35451031], [93.12545013, 8.35529709], [93.12545013, 8.35564327], [93.12611389, 8.35582066], [93.12627411, 8.35586357], [93.12676239, 8.35565662], [93.12787628, 8.35566139], [93.12835693, 8.35531044], [93.12885284, 8.35489082], [93.12884521, 8.35447788], [93.12863922, 8.35406113], [93.12863922, 8.35288334], [93.12891388, 8.35212231], [93.12926483, 8.3517046], [93.12975311, 8.35156631], [93.1305542, 8.35083199], [93.13083649, 8.35055637], [93.13083649, 8.3502779], [93.13111115, 8.35000038], [93.13111115, 8.34916592], [93.13194275, 8.34832859], [93.13249969, 8.34832859], [93.13276672, 8.34861183], [93.13388824, 8.34861183], [93.13414764, 8.3488903], [93.13582611, 8.3488903], [93.1361084, 8.34861183], [93.13639069, 8.34861183], [93.13666534, 8.34833431], [93.13777924, 8.34833431], [93.13805389, 8.34805584], [93.13916779, 8.34805965], [93.13944244, 8.34779072], [93.14250183, 8.34779072], [93.14277649, 8.34727192], [93.14290619, 8.3470602], [93.14334106, 8.34671116], [93.1434021, 8.34650421], [93.14333344, 8.34555626], [93.14333344, 8.34444332], [93.14305878, 8.34416771], [93.14305878, 8.34111118], [93.14277649, 8.34083271], [93.14277649, 8.34055519], [93.14194489, 8.33972263], [93.14194489, 8.33944511], [93.14167023, 8.33916664], [93.14167023, 8.33888912], [93.14138794, 8.33860016], [93.14138794, 8.33833313], [93.14111328, 8.33805466], [93.14111328, 8.33749866], [93.14083099, 8.33722115], [93.14083099, 8.33638859], [93.14111328, 8.33611107], [93.14111328, 8.3358326], [93.14083099, 8.33555698], [93.14083099, 8.33500099], [93.14111328, 8.33472061], [93.14111328, 8.33388901], [93.14138794, 8.33361053], [93.14138794, 8.33055687], [93.14111328, 8.33027554], [93.14111328, 8.32943058], [93.14083099, 8.32916641], [93.14083099, 8.32888794], [93.14055634, 8.32861042], [93.14055634, 8.32805634], [93.14027405, 8.32777786], [93.14028168, 8.32750034], [93.13999939, 8.32722187], [93.13999939, 8.32666588], [93.13972473, 8.32639027], [93.13972473, 8.32610989], [93.13944244, 8.32583046], [93.13944244, 8.3255558], [93.13722229, 8.32333374], [93.13722229, 8.32305622], [93.13694763, 8.32277775], [93.13694763, 8.32250023], [93.13639069, 8.32194424], [93.13639069, 8.32166576], [93.1361084, 8.32139015], [93.1361084, 8.32110977], [93.13583374, 8.32083416], [93.13583374, 8.32055569], [93.13527679, 8.31999969], [93.13527679, 8.31971931], [93.13500214, 8.3194437], [93.13500214, 8.31916809], [93.13471985, 8.31888962], [93.13471985, 8.31860924], [93.1341629, 8.31805611], [93.1341629, 8.31777763], [93.13388824, 8.31748962], [93.13388824, 8.31694317], [93.1333313, 8.31639004], [93.1333313, 8.31555462], [93.13305664, 8.31528187], [93.13305664, 8.31442928], [93.13277435, 8.31416702], [93.13277435, 8.31333256], [93.13249969, 8.31305504], [93.13249969, 8.31249905], [93.13223267, 8.31222057], [93.1319809, 8.31135654], [93.13142395, 8.31024742], [93.13111115, 8.30977058], [93.1313858, 8.30921745], [93.1315918, 8.30914879], [93.13181305, 8.30810928], [93.13214874, 8.30755138], [93.13246918, 8.30698967], [93.13295746, 8.30669022], [93.13316345, 8.30620575], [93.13302612, 8.30585957], [93.13288879, 8.30558014], [93.13253784, 8.30498028], [93.13246918, 8.30414772], [93.13273621, 8.30332088], [93.13326263, 8.30244064], [93.13354492, 8.30230236], [93.13388824, 8.30166626], [93.13361359, 8.30138779], [93.13360596, 8.30111027], [93.13277435, 8.30027771], [93.13277435, 8.30000019], [93.13249969, 8.29972172], [93.13249969, 8.2994442], [93.13222504, 8.29916573], [93.13223267, 8.29833031], [93.13194275, 8.29805565], [93.13222504, 8.29777813], [93.13223267, 8.29722023], [93.13194275, 8.29694366], [93.13194275, 8.29666805], [93.13166809, 8.29638767], [93.13166809, 8.29583168], [93.1313858, 8.29555607], [93.1313858, 8.29500008], [93.13111115, 8.2947197], [93.13111115, 8.29416561], [93.13083649, 8.29389], [93.13083649, 8.2930603], [93.13054657, 8.29277992], [93.13083649, 8.29249954], [93.13083649, 8.29222202], [93.1305542, 8.29194355], [93.1305542, 8.29166794], [93.12999725, 8.29111195], [93.12999725, 8.29083443], [93.12944794, 8.29027653], [93.12944794, 8.28999901], [93.12889099, 8.28944111], [93.12889099, 8.28916836], [93.1286087, 8.28888988], [93.12737274, 8.28638935], [93.12695313, 8.28493118], [93.12638855, 8.28333282], [93.12638855, 8.28194523], [93.12611389, 8.28166676], [93.12611389, 8.28083324], [93.1258316, 8.28055477], [93.1258316, 8.27972317], [93.12611389, 8.27944469], [93.12611389, 8.27722263], [93.12638855, 8.27694511], [93.12638855, 8.27638817], [93.12666321, 8.2761097], [93.12666321, 8.27583218], [93.1269455, 8.27555656], [93.1269455, 8.27527905], [93.12805176, 8.27417088], [93.12805176, 8.27389145], [93.12832642, 8.27361012], [93.12832642, 8.27278137], [93.1286087, 8.27251244], [93.1286087, 8.27221966], [93.12889099, 8.27194405], [93.12889099, 8.27138805], [93.12944794, 8.27083206], [93.12944794, 8.27055645], [93.1297226, 8.27027798], [93.1297226, 8.27000046], [93.12999725, 8.26972198], [93.12999725, 8.26944447], [93.13027954, 8.26916599], [93.13027954, 8.26889038], [93.13054657, 8.26861191], [93.13054657, 8.26833153], [93.13083649, 8.26805592], [93.13083649, 8.2677784], [93.13140106, 8.26721859], [93.1313858, 8.26694584], [93.13194275, 8.26638985], [93.13194275, 8.26611233], [93.13249969, 8.26555634], [93.13249969, 8.26527786], [93.1333313, 8.26444054], [93.1333313, 8.26416779], [93.13583374, 8.26166534], [93.13582611, 8.26139164], [93.13667297, 8.26057053], [93.13667297, 8.26027966], [93.13804626, 8.2588892], [93.13833618, 8.2588892], [93.14138794, 8.2558279], [93.14167023, 8.25583267], [93.14250183, 8.25500107], [93.14345551, 8.25437737], [93.14428711, 8.25312996], [93.14483643, 8.25284004], [93.14498901, 8.2525053], [93.145401, 8.25174236], [93.14568329, 8.25153446], [93.14624023, 8.25125599], [93.14679718, 8.25098133], [93.14805603, 8.25000095], [93.14805603, 8.24971962], [93.14833069, 8.24944496], [93.14833069, 8.24916553], [93.14888763, 8.24860954], [93.14888763, 8.24833202], [93.14944458, 8.24777794], [93.14971924, 8.2477808], [93.15222168, 8.24528122], [93.15222168, 8.24499989], [93.1533432, 8.24389267], [93.15361023, 8.24389267], [93.15429688, 8.24304008], [93.15479279, 8.2427597], [93.15541077, 8.24234009], [93.15569305, 8.24206734], [93.15625, 8.24186039], [93.15625, 8.24172115], [93.15660095, 8.24144173], [93.1571579, 8.24137402], [93.15743256, 8.24116421], [93.15834045, 8.24095726], [93.15910339, 8.24089146], [93.15994263, 8.24061966], [93.16079712, 8.24038029], [93.16127777, 8.23988628], [93.16149139, 8.23967838], [93.16190338, 8.23968124], [93.16239166, 8.23939991], [93.16266632, 8.23939991], [93.16368103, 8.23896027], [93.16500092, 8.23806], [93.1652832, 8.23806], [93.16583252, 8.23750019], [93.16638947, 8.23750019], [93.16666412, 8.23722363], [93.16694641, 8.23722363], [93.16722107, 8.23694324], [93.16750336, 8.23694324], [93.16806793, 8.2367363], [93.16869354, 8.23652935], [93.16903687, 8.23645973], [93.16945648, 8.2364006], [93.16973114, 8.23611164], [93.17008209, 8.23590374], [93.17077637, 8.23562622], [93.17105865, 8.23507214], [93.17175293, 8.23486519], [93.17224121, 8.23458672], [93.17251587, 8.23466015], [93.17307281, 8.23438168], [93.17334747, 8.2343111], [93.17369843, 8.23423958], [93.17404938, 8.23389435], [93.17501831, 8.23341084], [93.17536926, 8.23306179], [93.17543793, 8.23285484], [93.17564392, 8.23264694], [93.17649841, 8.23221874], [93.17677307, 8.23180199], [93.17684174, 8.23131943], [93.17749786, 8.23111057], [93.17778015, 8.23111057], [93.1783371, 8.23055458], [93.17871857, 8.23016834], [93.17913818, 8.22989178], [93.17942047, 8.22996044], [93.18027496, 8.22972298], [93.18055725, 8.22972298], [93.18083191, 8.22944546], [93.1811142, 8.22944546], [93.18166351, 8.22888947], [93.1819458, 8.22889137], [93.18222046, 8.22861099], [93.18250275, 8.22861099], [93.1827774, 8.22833347], [93.18305206, 8.22833347], [93.18333435, 8.228055], [93.18416595, 8.22806168], [93.18444824, 8.2277813], [93.18596649, 8.22771072], [93.18631744, 8.22737122], [93.18666077, 8.22714996], [93.18721771, 8.22715473], [93.18763733, 8.22687721], [93.18791962, 8.22688103], [93.18902588, 8.22679043], [93.18972015, 8.22667122], [93.1902771, 8.22667122], [93.19055176, 8.22639084], [93.19082642, 8.22639084], [93.1911087, 8.22611141], [93.19166565, 8.22611141], [93.19194794, 8.22583294], [93.1922226, 8.22583294], [93.19249725, 8.22555542], [93.19348145, 8.22519684], [93.1937561, 8.2249918], [93.19431305, 8.2249918], [93.19465637, 8.22457027], [93.19499969, 8.22416687], [93.19555664, 8.22361088], [93.19555664, 8.22333241], [93.19638824, 8.2225008], [93.19638824, 8.22194386], [93.1966629, 8.22166634], [93.1966629, 8.22138786], [93.19695282, 8.22111034], [93.19694519, 8.22083473], [93.19805908, 8.21972179], [93.19833374, 8.21972179], [93.19889069, 8.2191658], [93.19917297, 8.21917057], [93.19972229, 8.21861172], [93.20027924, 8.21861172], [93.20054626, 8.21833038], [93.2013855, 8.2183342], [93.20166779, 8.21805573], [93.2022171, 8.21806145], [93.20471954, 8.21556091], [93.20471954, 8.21500015], [93.20500183, 8.21472168], [93.20500183, 8.21389008], [93.20555878, 8.21333408], [93.20555878, 8.21305561], [93.20500183, 8.21249962], [93.20527649, 8.21223068], [93.20527649, 8.21138954], [93.20471954, 8.21083069], [93.20471954, 8.21027756], [93.20444489, 8.21000004], [93.20443726, 8.20944118], [93.20417023, 8.20916843], [93.20417023, 8.20888996], [93.20388794, 8.20861244], [93.20417023, 8.20833302], [93.20417023, 8.20777702], [93.20388794, 8.20750237], [93.20388794, 8.20583344], [93.20417023, 8.20555496], [93.20417023, 8.20472336], [93.20388794, 8.20444489], [93.20388794, 8.2033329], [93.20361328, 8.20305538], [93.20361328, 8.20166683], [93.20333099, 8.20139122], [93.20333099, 8.20083141], [93.20305634, 8.20055485], [93.20305634, 8.19972324], [93.20277405, 8.19944477], [93.20277405, 8.19888878], [93.20249939, 8.19861126], [93.20249939, 8.19805527], [93.20222473, 8.1977787], [93.2022171, 8.19694042], [93.20194244, 8.19666672], [93.20194244, 8.1963892], [93.19944763, 8.19389057], [93.19916534, 8.19388771], [93.19876862, 8.19428539], [93.1986084, 8.1944437], [93.19833374, 8.19416618], [93.19694519, 8.19416618], [93.1966629, 8.19388771], [93.19638824, 8.19389057], [93.19555664, 8.19306087], [93.19527435, 8.1930542], [93.19499969, 8.19333363], [93.19472504, 8.19333363], [93.19444275, 8.19361019], [93.19333649, 8.19361019], [93.19304657, 8.19389057], [93.1911087, 8.19389057], [93.19082642, 8.19361019], [93.1902771, 8.19361019], [93.1894455, 8.19277763], [93.18916321, 8.19278145], [93.18888855, 8.19306087], [93.18860626, 8.19278145], [93.18831635, 8.19278145], [93.18805695, 8.19250011]]], [[[93.65249634, 8.39444542], [93.65305328, 8.39388943], [93.65305328, 8.39361095], [93.65333557, 8.39333344], [93.65333557, 8.39305496], [93.65361023, 8.39277744], [93.65361023, 8.39250088], [93.65471649, 8.39194107], [93.65528107, 8.39194489], [93.65583038, 8.39138889], [93.65638733, 8.39138889], [93.65666962, 8.39111137], [93.65694427, 8.39111137], [93.65721893, 8.3908329], [93.65694427, 8.39055538], [93.65694427, 8.3900013], [93.65638733, 8.38943958], [93.65528107, 8.3894453], [93.65499878, 8.38916683], [93.65471649, 8.38917065], [93.65374756, 8.38819122], [93.65333557, 8.38777733], [93.65305328, 8.38778114], [93.65277863, 8.38806152], [93.65249634, 8.38805485], [93.65194702, 8.38861084], [93.6516571, 8.38861084], [93.65139008, 8.38888931], [93.65139008, 8.38916683], [93.65110779, 8.3894453], [93.65110779, 8.38970947], [93.65055847, 8.39028072], [93.65000153, 8.39028072], [93.64971924, 8.3900013], [93.64916992, 8.3900013], [93.64888763, 8.38972092], [93.64861298, 8.38972092], [93.64833069, 8.3894453], [93.64742279, 8.38970947], [93.64707947, 8.38992977], [93.6470108, 8.39041996], [93.64680481, 8.3908987], [93.64638519, 8.39117718], [93.64624786, 8.39152145], [93.6461792, 8.39194107], [93.64604187, 8.39207745], [93.64575958, 8.39256287], [93.64533997, 8.39277267], [93.64444733, 8.39277935], [93.64402771, 8.39284992], [93.64367676, 8.39340401], [93.64367676, 8.39388943], [93.64395905, 8.39430618], [93.6442337, 8.39438438], [93.64444733, 8.39444542], [93.64499664, 8.39444542], [93.64527893, 8.39472103], [93.64583588, 8.39472103], [93.64611053, 8.39444542], [93.64638519, 8.39444542], [93.64666748, 8.39416695], [93.64805603, 8.39416695], [93.64833069, 8.39444542], [93.64888763, 8.39444542], [93.64916992, 8.39416695], [93.65055847, 8.39416695], [93.65080261, 8.39465141], [93.65171814, 8.39472103], [93.65249634, 8.39444542]]], [[[93.2352829, 8.26556015], [93.23583221, 8.26500034], [93.23638916, 8.26500034], [93.23750305, 8.26389027], [93.23750305, 8.26361179], [93.23805237, 8.2630558], [93.23805237, 8.26249886], [93.23944092, 8.26111126], [93.23944092, 8.26055527], [93.23972321, 8.26027679], [93.23972321, 8.25999928], [93.23999786, 8.2597208], [93.23999786, 8.25944519], [93.24028015, 8.25916672], [93.24028015, 8.2588892], [93.24054718, 8.25861073], [93.24054718, 8.25751019], [93.2408371, 8.25722122], [93.2408371, 8.25694466], [93.24111176, 8.25666714], [93.24111176, 8.25638866], [93.24138641, 8.25611115], [93.24138641, 8.25583267], [93.2416687, 8.25555515], [93.2416687, 8.25500107], [93.24194336, 8.25472069], [93.24194336, 8.25444508], [93.24277496, 8.25361061], [93.24277496, 8.25277901], [93.24305725, 8.25249863], [93.24305725, 8.25222015], [93.24333191, 8.25194454], [93.24333191, 8.25166702], [93.24416351, 8.2508316], [93.24416351, 8.25027561], [93.2444458, 8.25000095], [93.2444458, 8.24971962], [93.24583435, 8.24833202], [93.24583435, 8.24805737], [93.2463913, 8.24750042], [93.2463913, 8.24694443], [93.24666595, 8.24666595], [93.24666595, 8.24583435], [93.24694824, 8.24555588], [93.24694824, 8.24472237], [93.2472229, 8.24444389], [93.2472229, 8.24416637], [93.2480545, 8.24333191], [93.2480545, 8.24277782], [93.24833679, 8.24250031], [93.24833679, 8.24222183], [93.24944305, 8.24110985], [93.24965668, 8.24061108], [93.24942017, 8.23978329], [93.24942017, 8.2392292], [93.24977112, 8.23867607], [93.24957275, 8.23812199], [93.24928284, 8.23784065], [93.24900818, 8.23756599], [93.24907684, 8.23728848], [93.2493515, 8.23707962], [93.25, 8.23659229], [93.25055695, 8.23583412], [93.25111389, 8.23527718], [93.25111389, 8.23472118], [93.25138855, 8.23444557], [93.25138855, 8.23388863], [93.25170898, 8.23343372], [93.25156403, 8.23308659], [93.25093842, 8.2329483], [93.25060272, 8.23295021], [93.25060272, 8.23259926], [93.2508316, 8.23222256], [93.2508316, 8.23138905], [93.25111389, 8.23111057], [93.25111389, 8.23083305], [93.25138855, 8.23055458], [93.25138855, 8.22972298], [93.25166321, 8.22944546], [93.25166321, 8.22916698], [93.2519455, 8.22888947], [93.25166321, 8.22861099], [93.25166321, 8.228055], [93.25138855, 8.2277813], [93.25138855, 8.22694016], [93.2508316, 8.22638893], [93.25056458, 8.22583008], [93.25028229, 8.22533989], [93.24993896, 8.22534466], [93.24965668, 8.22555161], [93.24924469, 8.22555161], [93.24909973, 8.22520638], [93.24909973, 8.22451305], [93.24882507, 8.22416687], [93.24840546, 8.22402763], [93.24819946, 8.22402763], [93.24798584, 8.22444153], [93.24771118, 8.22458076], [93.24743652, 8.22416687], [93.24749756, 8.22388935], [93.24694824, 8.22389126], [93.24666595, 8.22361088], [93.2463913, 8.22361088], [93.24610901, 8.22333241], [93.24583435, 8.22333241], [93.24555206, 8.22305679], [93.24500275, 8.22306061], [93.24472046, 8.22278118], [93.24305725, 8.22278118], [93.24276733, 8.2225008], [93.24250031, 8.2225008], [93.24222565, 8.22277641], [93.24180603, 8.22299671], [93.2416687, 8.22327328], [93.24124908, 8.22327328], [93.24091339, 8.22340965], [93.24061584, 8.2237606], [93.24021149, 8.2237606], [93.23996735, 8.22362041], [93.23972321, 8.22348309], [93.23944092, 8.22292709], [93.23958588, 8.22244072], [93.23999786, 8.22188663], [93.23999786, 8.22138786], [93.23944092, 8.22082996], [93.2388916, 8.22083473], [93.23750305, 8.22222328], [93.23722076, 8.22222328], [93.23694611, 8.2225008], [93.23666382, 8.2225008], [93.23583221, 8.22333241], [93.23555756, 8.22333241], [93.23527527, 8.22361088], [93.23500061, 8.22361088], [93.23416901, 8.22444534], [93.23472595, 8.22500134], [93.23472595, 8.22555542], [93.23416901, 8.22611141], [93.23416901, 8.22638893], [93.2335968, 8.22694016], [93.23361206, 8.22750092], [93.23332977, 8.22777653], [93.23332977, 8.22833347], [93.23348236, 8.22945023], [93.23348236, 8.22993469], [93.23306274, 8.23034954], [93.23257446, 8.23083782], [93.23208618, 8.23139095], [93.23152924, 8.23173809], [93.23125458, 8.23208427], [93.23069763, 8.23215485], [93.23027802, 8.23236179], [93.23018646, 8.2324543], [93.23000336, 8.23264027], [93.22944641, 8.23250103], [93.22915649, 8.23250103], [93.22860718, 8.23306179], [93.22833252, 8.23306179], [93.22611237, 8.23528194], [93.22583008, 8.23528194], [93.22472382, 8.23639011], [93.22472382, 8.23666763], [93.22444153, 8.23694324], [93.22444153, 8.23722363], [93.22368622, 8.2382679], [93.22368622, 8.23875141], [93.2234726, 8.23938179], [93.22312927, 8.2399292], [93.22291565, 8.24041462], [93.22244263, 8.24075031], [93.22222137, 8.2413168], [93.22138977, 8.24166584], [93.22138977, 8.24222183], [93.22129822, 8.24263], [93.22123718, 8.24312019], [93.2208786, 8.24368095], [93.22052765, 8.24444199], [93.22012329, 8.24506187], [93.22012329, 8.24617195], [93.2199707, 8.24713802], [93.21990204, 8.24790192], [93.21990204, 8.2488699], [93.220047, 8.24943066], [93.22052765, 8.25032711], [93.22052765, 8.25095081], [93.22067261, 8.25171471], [93.22083282, 8.25277901], [93.22083282, 8.25361061], [93.22110748, 8.25388908], [93.22110748, 8.25444508], [93.22138977, 8.25472069], [93.22138977, 8.25500107], [93.22166443, 8.25527668], [93.2216568, 8.25694084], [93.22257233, 8.25766468], [93.22298431, 8.25849724], [93.22375488, 8.25905132], [93.22424316, 8.25953674], [93.22507477, 8.25988293], [93.22556305, 8.2601614], [93.22618866, 8.26050663], [93.22653198, 8.26113224], [93.22737122, 8.26147842], [93.22812653, 8.26181984], [93.22944641, 8.26244926], [93.23084259, 8.26334953], [93.23202515, 8.26348877], [93.23286438, 8.26376438], [93.23369598, 8.2640419], [93.23460388, 8.26444626], [93.23480988, 8.26472187], [93.23474121, 8.26514053], [93.23500061, 8.26556015], [93.2352829, 8.26556015]]], [[[93.04389191, 8.47333336], [93.04389191, 8.47305489], [93.04418182, 8.47305965], [93.04556274, 8.4716692], [93.04556274, 8.47139072], [93.04833221, 8.4686079], [93.0486145, 8.46861076], [93.04888916, 8.46833324], [93.04964447, 8.46769905], [93.05096436, 8.46679878], [93.05214691, 8.46576023], [93.05354309, 8.46437168], [93.05472565, 8.46333218], [93.05583191, 8.4622221], [93.05583191, 8.46194363], [93.0561142, 8.46166611], [93.0561142, 8.46138763], [93.05638885, 8.46111012], [93.05638885, 8.46083355], [93.05666351, 8.46055603], [93.05666351, 8.46027756], [93.0569458, 8.46000004], [93.0569458, 8.45944023], [93.05722046, 8.45916557], [93.05722046, 8.45805645], [93.05750275, 8.45778275], [93.05750275, 8.45583153], [93.0569458, 8.4552784], [93.0569458, 8.4547224], [93.05666351, 8.45444584], [93.05666351, 8.45361233], [93.05638885, 8.45333385], [93.05638885, 8.44999886], [93.05666351, 8.44972134], [93.05666351, 8.44888878], [93.05638885, 8.44861126], [93.05638885, 8.44805527], [93.05666351, 8.44777679], [93.05665588, 8.44749928], [93.0577774, 8.4463892], [93.05860901, 8.4463892], [93.0588913, 8.44611073], [93.0588913, 8.44583321], [93.0597229, 8.44499874], [93.0597229, 8.44444466], [93.05999756, 8.44416714], [93.05999756, 8.44388866], [93.06083679, 8.44306183], [93.06054688, 8.44278145], [93.06054688, 8.44250107], [93.0597229, 8.44167137], [93.0597229, 8.44139099], [93.05944824, 8.44111061], [93.05750275, 8.43916702], [93.05722046, 8.43916702], [93.0569458, 8.43944454], [93.05388641, 8.43944454], [93.05361176, 8.43916702], [93.0533371, 8.43917084], [93.05304718, 8.43889141], [93.05278015, 8.43889141], [93.05249786, 8.43861008], [93.05194092, 8.43861008], [93.05166626, 8.4383316], [93.0513916, 8.4383316], [93.05110931, 8.43861008], [93.05027771, 8.43861008], [93.04998779, 8.43889141], [93.04972076, 8.43889141], [93.04944611, 8.43917084], [93.04916382, 8.43916702], [93.04888916, 8.43944454], [93.04805756, 8.43944454], [93.04777527, 8.43972301], [93.04695129, 8.43972015], [93.04666901, 8.44000053], [93.04611206, 8.44000053], [93.04582977, 8.44028091], [93.04418182, 8.44028091], [93.04389191, 8.44056129], [93.04305267, 8.44055462], [93.04277802, 8.44083309], [93.04250336, 8.44083309], [93.04138947, 8.44194508], [93.04110718, 8.44194031], [93.04000092, 8.44306183], [93.03971863, 8.44306183], [93.03778076, 8.44499874], [93.03778076, 8.44555473], [93.03749847, 8.44583321], [93.03749847, 8.44611073], [93.03694153, 8.44666672], [93.03694153, 8.44694519], [93.03527832, 8.44861126], [93.03527832, 8.44944477], [93.03500366, 8.44972134], [93.03500366, 8.44999886], [93.03472137, 8.45027733], [93.03472137, 8.45083332], [93.03444672, 8.45111179], [93.03444672, 8.45277786], [93.03472137, 8.45305634], [93.03472137, 8.45555592], [93.03501129, 8.45583153], [93.03501129, 8.45612144], [93.03527832, 8.45638847], [93.03527832, 8.4566679], [93.03555298, 8.45694447], [93.03555298, 8.45722198], [93.03527832, 8.45750046], [93.03527832, 8.45805645], [93.03555298, 8.45833015], [93.03555298, 8.45888996], [93.0358429, 8.45918179], [93.0358429, 8.46000004], [93.03610992, 8.46027756], [93.03610992, 8.46055603], [93.03639221, 8.46083355], [93.03639221, 8.46111012], [93.03666687, 8.46138763], [93.03666687, 8.46194363], [93.03694153, 8.46222019], [93.03694153, 8.46249962], [93.03722382, 8.46277809], [93.03722382, 8.46333218], [93.03749847, 8.4636097], [93.03749847, 8.46416569], [93.03778076, 8.46444416], [93.03778076, 8.46472263], [93.03805542, 8.46500111], [93.03805542, 8.46555424], [93.03833008, 8.46583462], [93.03833008, 8.46611118], [93.03888702, 8.46666718], [93.03888702, 8.46694469], [93.03916931, 8.46722031], [93.03916931, 8.46777916], [93.03944397, 8.46805477], [93.03944397, 8.46833324], [93.03971863, 8.4686079], [93.03971863, 8.46888924], [93.04000092, 8.46916676], [93.04000092, 8.46944523], [93.04055786, 8.47000122], [93.04055786, 8.47028065], [93.04166412, 8.47138882], [93.04166412, 8.47166729], [93.04222107, 8.47222328], [93.04222107, 8.47249889], [93.04332733, 8.47361088], [93.04360962, 8.47361088], [93.04389191, 8.47333336]]], [[[93.61187744, 8.48454189], [93.61147308, 8.48447132], [93.61083221, 8.48499966], [93.61083221, 8.48527813], [93.6111145, 8.48555565], [93.6111145, 8.48583412], [93.61154175, 8.48605537], [93.61194611, 8.48633099], [93.61257935, 8.48641109], [93.61308289, 8.48633766], [93.61348724, 8.48605537], [93.61369324, 8.48556995], [93.61360931, 8.48527813], [93.61305237, 8.48499966], [93.61250305, 8.4847517], [93.61187744, 8.48454189]]], [[[93.61599731, 8.57362556], [93.61711121, 8.57244968], [93.61794281, 8.57113075], [93.61801147, 8.56946659], [93.61749268, 8.56799889], [93.61804962, 8.56735039], [93.61868286, 8.56735039], [93.61915588, 8.56728077], [93.61936951, 8.56672096], [93.61972046, 8.56589317], [93.6202774, 8.56485176], [93.62034607, 8.56409073], [93.6204834, 8.56311989], [93.62055206, 8.56215096], [93.6202774, 8.5616703], [93.62055206, 8.55944061], [93.62055206, 8.55888653], [93.62020874, 8.55708218], [93.62000275, 8.55583286], [93.61981201, 8.55557346], [93.61951447, 8.55533218], [93.61925507, 8.55506706], [93.61901855, 8.55472565], [93.61881256, 8.55436325], [93.61862946, 8.55397606], [93.61850739, 8.55352211], [93.61837006, 8.55305481], [93.61820984, 8.55197906], [93.61842346, 8.55177212], [93.61876678, 8.55135727], [93.61890411, 8.55093956], [93.61911774, 8.55066013], [93.61911774, 8.55017567], [93.6191864, 8.54983234], [93.61946106, 8.54927635], [93.62007141, 8.54913044], [93.62037659, 8.54866123], [93.62033081, 8.54817963], [93.62005615, 8.54775143], [93.61976624, 8.54735947], [93.61952209, 8.54701996], [93.61934662, 8.54672432], [93.61871338, 8.54630947], [93.61857605, 8.54610062], [93.61863708, 8.54574966], [93.61899567, 8.54554844], [93.61948395, 8.54547691], [93.61988831, 8.54521942], [93.62003326, 8.54474545], [93.61988831, 8.54426193], [93.61968231, 8.54377747], [93.61981964, 8.54314995], [93.61928558, 8.54278278], [93.61956787, 8.54250526], [93.61991119, 8.54236603], [93.6207962, 8.54247093], [93.62120819, 8.54190063], [93.62149048, 8.54114246], [93.62160492, 8.54038525], [93.62152863, 8.53964233], [93.621315, 8.53936672], [93.62117767, 8.53908825], [93.62117767, 8.5388813], [93.6213913, 8.53874207], [93.62194824, 8.5377779], [93.6222229, 8.53750038], [93.6222229, 8.53666592], [93.62194061, 8.5363903], [93.62194061, 8.53528023], [93.6222229, 8.53499985], [93.6222229, 8.53472233], [93.6230545, 8.53388977], [93.6230545, 8.53333378], [93.62333679, 8.53305626], [93.62277985, 8.53249931], [93.62249756, 8.53249931], [93.6222229, 8.53222084], [93.6222229, 8.53194332], [93.62194824, 8.53166771], [93.6222229, 8.53139019], [93.6222229, 8.53110886], [93.62249756, 8.53083324], [93.62249756, 8.53055477], [93.6230545, 8.52999878], [93.62304687, 8.52944088], [93.62333679, 8.52916527], [93.62388611, 8.52917194], [93.62473297, 8.5283308], [93.625, 8.52833271], [93.62611389, 8.52722263], [93.62638855, 8.52722263], [93.62666321, 8.52694511], [93.6269455, 8.52694511], [93.62722015, 8.52666664], [93.62889099, 8.52666855], [93.62917328, 8.52639103], [93.62944794, 8.52639103], [93.6297226, 8.52611065], [93.63027954, 8.52611065], [93.6305542, 8.52583313], [93.63111115, 8.52583313], [93.63166809, 8.52527905], [93.63166809, 8.52499866], [93.63194275, 8.52472305], [93.63194275, 8.52416706], [93.6322937, 8.52378178], [93.63285065, 8.52378178], [93.63326263, 8.52413273], [93.63381958, 8.52412796], [93.63471985, 8.52444458], [93.63527679, 8.52388859], [93.63527679, 8.52361107], [93.63555908, 8.5233326], [93.63555908, 8.52305698], [93.63583374, 8.5227766], [93.63582611, 8.52250099], [93.6361084, 8.52223015], [93.6361084, 8.52194023], [93.63527679, 8.52111053], [93.63500214, 8.52111053], [93.63382721, 8.51992798], [93.63347626, 8.5194416], [93.63340759, 8.51861], [93.63334656, 8.51816368], [93.63334656, 8.51760769], [93.63349152, 8.51739788], [93.63382721, 8.51684189], [93.63418579, 8.51670456], [93.63460541, 8.51663685], [93.63466644, 8.51643181], [93.63453674, 8.51594162], [93.63488007, 8.51546097], [93.63529205, 8.51476765], [93.63571167, 8.51442146], [93.63626862, 8.51400375], [93.6367569, 8.51338005], [93.63749695, 8.51222229], [93.63749695, 8.51194382], [93.63726807, 8.51054001], [93.63699341, 8.50991631], [93.63668823, 8.50976086], [93.63642883, 8.50950527], [93.63608551, 8.5092411], [93.63568878, 8.50898647], [93.63521576, 8.50890064], [93.63478851, 8.50888824], [93.6344223, 8.50887394], [93.63407135, 8.50881195], [93.63365173, 8.50863457], [93.63331604, 8.50830936], [93.63311005, 8.50796032], [93.6325531, 8.50692272], [93.63227844, 8.50643826], [93.63185883, 8.50595188], [93.63192749, 8.50525856], [93.63234711, 8.50470543], [93.63289642, 8.5040102], [93.6333847, 8.5033884], [93.63394165, 8.50262737], [93.63471222, 8.50179005], [93.63494873, 8.5009861], [93.63536072, 8.50029278], [93.63598633, 8.49918461], [93.6367569, 8.49786758], [93.63698578, 8.4971571], [93.63765717, 8.49200153], [93.63786316, 8.49075699], [93.63751984, 8.48978615], [93.63765717, 8.48886967], [93.63779449, 8.48742962], [93.63835144, 8.48590469], [93.63897705, 8.484519], [93.63939667, 8.48368454], [93.63947296, 8.48265266], [93.63947296, 8.48176956], [93.63905334, 8.4813509], [93.63883209, 8.48073101], [93.63857269, 8.48031044], [93.63912201, 8.47989464], [93.63925934, 8.47947979], [93.63973999, 8.47890282], [93.64029694, 8.47779274], [93.64089203, 8.47547817], [93.64109802, 8.47464561], [93.64109802, 8.47375011], [93.64138031, 8.47276974], [93.64138031, 8.47220707], [93.64121246, 8.47106075], [93.64142609, 8.47085285], [93.64142609, 8.47029972], [93.64183807, 8.47009182], [93.64183807, 8.46939945], [93.64234161, 8.4688406], [93.64242554, 8.46853638], [93.64242554, 8.4674263], [93.64205933, 8.46677399], [93.64212799, 8.46642685], [93.64177704, 8.46587372], [93.64150238, 8.46546078], [93.64122009, 8.46497059], [93.64128876, 8.46455574], [93.64027405, 8.46472263], [93.63972473, 8.46472263], [93.63944244, 8.46500111], [93.6388855, 8.46500111], [93.63805389, 8.46583462], [93.63804626, 8.46611118], [93.63777924, 8.4663887], [93.63777924, 8.46666718], [93.63749695, 8.46693993], [93.63749695, 8.46777916], [93.63722229, 8.46805477], [93.63722229, 8.46833324], [93.63583374, 8.46972084], [93.63555908, 8.46972084], [93.63527679, 8.46944523], [93.63500214, 8.46972084], [93.63471985, 8.46972084], [93.63388062, 8.47056198], [93.6333313, 8.47056198], [93.63305664, 8.47028065], [93.63276672, 8.47028065], [93.63249969, 8.47000122], [93.63111115, 8.47000122], [93.63083649, 8.46972084], [93.63027954, 8.46972084], [93.62999725, 8.46944523], [93.6297226, 8.46944523], [93.62944794, 8.46916676], [93.62917328, 8.46917057], [93.62867737, 8.46867943], [93.62805176, 8.46806145], [93.62750244, 8.46806145], [93.62689972, 8.46745968], [93.62666321, 8.46722031], [93.62666321, 8.46500111], [93.62638855, 8.46472263], [93.62638855, 8.46444416], [93.62611389, 8.46416569], [93.62611389, 8.46333218], [93.6258316, 8.46305561], [93.6258316, 8.46277809], [93.62555695, 8.46249962], [93.62555695, 8.46082973], [93.62527466, 8.46055603], [93.62527466, 8.46000004], [93.6258316, 8.45944023], [93.62555695, 8.45916557], [93.62555695, 8.45805645], [93.62526703, 8.45778275], [93.62526703, 8.45750046], [93.62500763, 8.45722198], [93.62527466, 8.45694447], [93.62527466, 8.4566679], [93.62555695, 8.45638847], [93.62555695, 8.45583153], [93.625, 8.4552784], [93.625, 8.4547224], [93.62472534, 8.45444584], [93.62472534, 8.45333385], [93.62444305, 8.45305634], [93.62444305, 8.45277786], [93.62388611, 8.45222092], [93.62388611, 8.4519434], [93.62333679, 8.45139027], [93.62324524, 8.45025921], [93.6230545, 8.44944477], [93.62277985, 8.44916534], [93.62277985, 8.44888878], [93.62304687, 8.44861126], [93.6230545, 8.44777679], [93.62333679, 8.44749928], [93.62333679, 8.4472208], [93.6241684, 8.4463892], [93.62388611, 8.44611073], [93.6241684, 8.44583321], [93.6241684, 8.44555473], [93.62444305, 8.44527912], [93.62444305, 8.44500065], [93.62500763, 8.44444084], [93.625, 8.44416714], [93.6258316, 8.44333267], [93.62631989, 8.44269943], [93.62750244, 8.44152069], [93.62750244, 8.44055462], [93.62722015, 8.44028091], [93.62666321, 8.44028091], [93.62638855, 8.44000053], [93.62638855, 8.43964958], [93.62666321, 8.43958092], [93.62687683, 8.43958092], [93.62728882, 8.43935966], [93.62743378, 8.43916416], [93.62750244, 8.43847084], [93.6277771, 8.43777943], [93.6277771, 8.43694019], [93.62750244, 8.43666553], [93.62750244, 8.43638802], [93.62722778, 8.43472004], [93.62715912, 8.4330492], [93.62709045, 8.43222046], [93.62709045, 8.43118095], [93.62652588, 8.43064022], [93.62639618, 8.42978954], [93.62639618, 8.4289608], [93.6258316, 8.42805576], [93.62555695, 8.42805958], [93.62526703, 8.42778015], [93.62526703, 8.42694092], [93.625, 8.42666626], [93.625, 8.4258337], [93.62472534, 8.42555618], [93.62472534, 8.42416763], [93.62444305, 8.42389202], [93.62341309, 8.4226017], [93.62285614, 8.42162037], [93.62243652, 8.42162037], [93.62181091, 8.42218018], [93.6213913, 8.42328835], [93.6213913, 8.4243269], [93.62159729, 8.42481327], [93.62174225, 8.42550468], [93.62152863, 8.42675018], [93.62132263, 8.42759132], [93.62083435, 8.42862606], [93.62062836, 8.42924786], [93.62020874, 8.42980194], [93.61958313, 8.43064022], [93.61958313, 8.43153572], [93.6194458, 8.43236828], [93.6185379, 8.43278503], [93.61743164, 8.43333912], [93.61672974, 8.43410015], [93.61638641, 8.43486404], [93.61701202, 8.43534946], [93.61784363, 8.43583393], [93.61888885, 8.43611336], [93.6194458, 8.43610954], [93.61972046, 8.43639088], [93.62006378, 8.4366188], [93.62021637, 8.43690777], [93.62030792, 8.43730545], [93.62043762, 8.43777943], [93.6205368, 8.43831158], [93.62057495, 8.43885708], [93.62018585, 8.44023132], [93.61976624, 8.44092846], [93.61916351, 8.4416666], [93.61888885, 8.44194508], [93.61888885, 8.4422226], [93.61833191, 8.44222069], [93.61805725, 8.44250107], [93.61750031, 8.44250107], [93.61694336, 8.44305515], [93.61694336, 8.44333267], [93.61722565, 8.44361115], [93.61722565, 8.44388866], [93.61805725, 8.44472313], [93.61833191, 8.44472313], [93.61916351, 8.44555473], [93.61985779, 8.44653034], [93.62000275, 8.44805527], [93.61980438, 8.4491396], [93.61965942, 8.44983292], [93.61980438, 8.45066547], [93.62036133, 8.45142841], [93.62049866, 8.45198154], [93.62042999, 8.45253563], [93.6194458, 8.45333385], [93.6194458, 8.45361233], [93.6186142, 8.45444584], [93.61833191, 8.45444584], [93.61805725, 8.4547224], [93.61776733, 8.45471859], [93.61750031, 8.45499992], [93.61723328, 8.45499992], [93.61694336, 8.4552803], [93.6166687, 8.4552803], [93.61638641, 8.45555973], [93.61611176, 8.45555973], [93.61554718, 8.45612144], [93.61555481, 8.45638847], [93.6158371, 8.4566679], [93.6158371, 8.45694447], [93.61694336, 8.45694447], [93.61750031, 8.45638847], [93.61776733, 8.45639038], [93.61805725, 8.45612144], [93.61888123, 8.45612144], [93.61915588, 8.45639038], [93.6194458, 8.45638847], [93.6194458, 8.4566679], [93.62000275, 8.45722198], [93.61972046, 8.45750046], [93.61972046, 8.45888805], [93.6202774, 8.45944405], [93.62110901, 8.45944405], [93.62277985, 8.46111012], [93.62249756, 8.46138763], [93.62249756, 8.46166611], [93.6222229, 8.46194363], [93.62249756, 8.46222019], [93.62249756, 8.46249962], [93.62277985, 8.46277809], [93.62277985, 8.4636097], [93.62249756, 8.46388817], [93.62249756, 8.46416569], [93.6222229, 8.46444416], [93.6222229, 8.46472263], [93.62166595, 8.46527863], [93.62166595, 8.46611118], [93.62110901, 8.46667099], [93.62110901, 8.46750069], [93.6213913, 8.46777916], [93.6213913, 8.46833324], [93.62083435, 8.46888924], [93.6202774, 8.46944523], [93.62032318, 8.46976852], [93.62082672, 8.47028065], [93.62110901, 8.47028065], [93.6213913, 8.47056198], [93.6222229, 8.47055531], [93.62249756, 8.47083092], [93.62249756, 8.4711113], [93.62277985, 8.47138882], [93.62271881, 8.47195435], [93.62291718, 8.47215939], [93.62291718, 8.47236919], [93.62278748, 8.47236919], [93.62258911, 8.47257042], [93.62223816, 8.47257042], [93.62216949, 8.47284794], [93.62203217, 8.47326469], [93.62174988, 8.47326469], [93.62161255, 8.47298717], [93.62111664, 8.47292137], [93.62055206, 8.47305965], [93.61972046, 8.47305965], [93.61915588, 8.47361088], [93.61888885, 8.47361088], [93.6186142, 8.47388935], [93.61890411, 8.47478294], [93.61932373, 8.47533607], [93.61959839, 8.47561455], [93.61994934, 8.47575378], [93.62036133, 8.47589016], [93.62029266, 8.47637558], [93.61994934, 8.47679329], [93.61994934, 8.4776926], [93.61973572, 8.47790146], [93.6194458, 8.47778034], [93.6186142, 8.47861195], [93.61888885, 8.47937965], [93.6185379, 8.47986126], [93.61840057, 8.48041916], [93.61888885, 8.48069477], [93.61923218, 8.48090172], [93.6194458, 8.48139], [93.61972046, 8.48167038], [93.62000275, 8.48166561], [93.62000275, 8.48194408], [93.62249756, 8.48194408], [93.62277985, 8.4822216], [93.62304687, 8.4822216], [93.62333679, 8.48250198], [93.62361145, 8.48250198], [93.62388611, 8.4822216], [93.62444305, 8.4822216], [93.625, 8.4827776], [93.625, 8.48305607], [93.62555695, 8.48361015], [93.62555695, 8.48416996], [93.62666321, 8.48528004], [93.6269455, 8.48527813], [93.62713623, 8.48546982], [93.62722015, 8.48556137], [93.62750244, 8.48555565], [93.6277771, 8.48583031], [93.6277771, 8.48639011], [93.62805176, 8.48666573], [93.62805176, 8.48750019], [93.62833405, 8.48777771], [93.62833405, 8.48861027], [93.6277771, 8.48915863], [93.62779999, 8.48965931], [93.62766266, 8.48986626], [93.62752533, 8.49000454], [93.62696838, 8.49042034], [93.62696838, 8.4908371], [93.62675476, 8.49118328], [93.62641144, 8.49139118], [93.62627411, 8.49173737], [93.62619781, 8.49194527], [93.62592316, 8.49215412], [93.62571716, 8.49229145], [93.6256485, 8.49263954], [93.62571716, 8.49304962], [93.62584686, 8.49346924], [93.6256485, 8.49388599], [93.62536621, 8.49395466], [93.62529755, 8.49423313], [93.62522888, 8.49457932], [93.62509155, 8.49505997], [93.62509155, 8.49555016], [93.62502289, 8.49589729], [93.62480927, 8.49617481], [93.6247406, 8.49644089], [93.62467194, 8.4967308], [93.62404633, 8.49679661], [93.62425232, 8.49749184], [93.62425232, 8.49797535], [93.62453461, 8.49832153], [93.62487793, 8.49860001], [93.62522888, 8.49908543], [93.62516022, 8.49950027], [93.62522888, 8.50005627], [93.62536621, 8.50047112], [93.62536621, 8.50123215], [93.62543488, 8.5016489], [93.6256485, 8.50206375], [93.6256485, 8.50261974], [93.62571716, 8.50323963], [93.62584686, 8.50359058], [93.62542725, 8.50345039], [93.62529755, 8.5034523], [93.62502289, 8.50352001], [93.62502289, 8.5040102], [93.62529755, 8.50400639], [93.62549591, 8.50434971], [93.62542725, 8.5048399], [93.62528992, 8.50519085], [93.62516785, 8.50539589], [93.62513733, 8.50595856], [93.62520599, 8.50679111], [93.62519836, 8.50731659], [93.62532806, 8.50859356], [93.62539673, 8.50956535], [93.62511444, 8.51053333], [93.62500763, 8.51111031], [93.62500763, 8.51138973], [93.62472534, 8.5116663], [93.62458801, 8.51223087], [93.62430573, 8.51313114], [93.62451172, 8.51362419], [93.62472534, 8.51390171], [93.62479401, 8.51418018], [93.62479401, 8.51466465], [93.62484741, 8.51486969], [93.62493134, 8.51514816], [93.62472534, 8.51549721], [93.62451172, 8.51577282], [93.6241684, 8.51605129], [93.62388611, 8.51633072], [93.62388611, 8.51743889], [93.62361145, 8.51749992], [93.62333679, 8.51777935], [93.62333679, 8.51833153], [93.62284088, 8.51910019], [93.62262726, 8.51938057], [93.62242889, 8.51958847], [93.62207794, 8.51986408], [93.62180328, 8.51993465], [93.6213913, 8.51972294], [93.62110901, 8.51972008], [93.6202774, 8.52055454], [93.6202774, 8.52138901], [93.62076569, 8.5218811], [93.62097931, 8.5218811], [93.62104797, 8.52215862], [93.62083435, 8.5224371], [93.6211853, 8.52292347], [93.62210083, 8.52291965], [93.62216187, 8.52327061], [93.62167358, 8.52354527], [93.62187958, 8.52409172], [93.62211609, 8.52466202], [93.62211609, 8.5250082], [93.62204742, 8.52542496], [93.62155914, 8.5256319], [93.62110901, 8.52556038], [93.62110901, 8.52602673], [93.62146759, 8.52658081], [93.62153625, 8.52692699], [93.62125397, 8.52734184], [93.62091064, 8.52741241], [93.62062836, 8.52748108], [93.62042236, 8.52762032], [93.62000275, 8.52762032], [93.61959076, 8.52734184], [93.61923981, 8.52741241], [93.61882019, 8.52741241], [93.61847687, 8.52762032], [93.6184082, 8.52789783], [93.61875153, 8.5281744], [93.61904144, 8.5282402], [93.61917114, 8.52873039], [93.61897278, 8.52893925], [93.61860657, 8.52880001], [93.61818695, 8.52873039], [93.61791992, 8.52915096], [93.61819458, 8.52995777], [93.61847687, 8.53037262], [93.61855316, 8.53065109], [93.6184082, 8.5309267], [93.61819458, 8.53120518], [93.61812592, 8.53141212], [93.61785126, 8.53168964], [93.61756897, 8.53176117], [93.61750031, 8.53224373], [93.61750031, 8.53259087], [93.61727905, 8.53266144], [93.61694336, 8.53259277], [93.61638641, 8.53277779], [93.61638641, 8.53333378], [93.61668396, 8.53363228], [93.61699677, 8.53349113], [93.61720276, 8.53339672], [93.61747742, 8.53339672], [93.61740875, 8.53395081], [93.61720276, 8.53402042], [93.61712646, 8.53457642], [93.61698914, 8.53512955], [93.61664581, 8.53582001], [93.61472321, 8.53778267], [93.6138916, 8.5377779], [93.61360931, 8.53805637], [93.61360931, 8.53833389], [93.61332703, 8.53861046], [93.61333466, 8.53888798], [93.61305237, 8.53916645], [93.61305237, 8.53944397], [93.61277771, 8.53972244], [93.61277771, 8.5402689], [93.61250305, 8.54055595], [93.61250305, 8.54111004], [93.61222076, 8.54139042], [93.61222076, 8.5416708], [93.61055756, 8.5433321], [93.61013794, 8.54432583], [93.6102829, 8.54481125], [93.61048126, 8.54502106], [93.61076355, 8.54515839], [93.61118317, 8.54529667], [93.61152649, 8.54571247], [93.61152649, 8.54619694], [93.61174011, 8.54654408], [93.61180878, 8.54675102], [93.61138916, 8.54722309], [93.61138916, 8.54944515], [93.6111145, 8.54972267], [93.6111145, 8.55027676], [93.6102829, 8.55111122], [93.61027527, 8.55138874], [93.61000061, 8.55166721], [93.61000061, 8.55194473], [93.60972595, 8.5522089], [93.60972595, 8.5527792], [93.61000061, 8.55305481], [93.61000061, 8.55360889], [93.61027527, 8.55388927], [93.61027527, 8.55416679], [93.61055756, 8.55444527], [93.61055756, 8.55472088], [93.61083221, 8.55500126], [93.61083221, 8.55527687], [93.61027527, 8.55583286], [93.61027527, 8.55611134], [93.61055756, 8.5570116], [93.61083221, 8.5575676], [93.61138916, 8.55798244], [93.61200714, 8.55852032], [93.61200714, 8.55900097], [93.61186981, 8.55949116], [93.61138153, 8.55948925], [93.6111145, 8.55972099], [93.61083221, 8.56000042], [93.61055756, 8.56000042], [93.61055756, 8.56056023], [93.61051941, 8.56073093], [93.61093903, 8.56100464], [93.61167145, 8.56104088], [93.61201477, 8.56138802], [93.61236572, 8.56145573], [93.61342621, 8.56228638], [93.61342621, 8.56311512], [93.61339569, 8.56391144], [93.61373901, 8.5643959], [93.61417389, 8.56446171], [93.61444855, 8.56453037], [93.61444855, 8.56494999], [93.61424255, 8.56516171], [93.61368561, 8.56515503], [93.61340332, 8.56536007], [93.61332703, 8.56578159], [93.61347198, 8.56591797], [93.61361694, 8.56619644], [93.61361694, 8.56640434], [93.61312866, 8.56633282], [93.61284637, 8.56633282], [93.61264038, 8.56647015], [93.61264038, 8.56695843], [93.61284637, 8.56723595], [93.61312866, 8.56729984], [93.61332703, 8.56772137], [93.61299133, 8.56807041], [93.61250305, 8.56806755], [93.61228943, 8.56855106], [93.61250305, 8.56890202], [93.61273193, 8.5696106], [93.61258698, 8.5698204], [93.61238098, 8.56996155], [93.61223602, 8.57044029], [93.61210632, 8.57072067], [93.61190796, 8.57092953], [93.61154938, 8.57106495], [93.6111145, 8.57166576], [93.61138916, 8.57194424], [93.61138916, 8.57250118], [93.61194611, 8.57306099], [93.61244202, 8.57286072], [93.61277771, 8.57268143], [93.61297607, 8.57268143], [93.61340332, 8.5731678], [93.61340332, 8.57351494], [93.61347198, 8.57393169], [93.61360931, 8.57434177], [93.61360931, 8.57450199], [93.61284637, 8.57462502], [93.61250305, 8.57527733], [93.61250305, 8.57583332], [93.61314392, 8.57612228], [93.61349487, 8.57591248], [93.61391449, 8.57549763], [93.61467743, 8.57494164], [93.61523438, 8.57459736], [93.61599731, 8.57362556]]], [[[93.63491821, 8.39464378], [93.63464355, 8.39464378], [93.63394928, 8.39492226], [93.63387299, 8.39561462], [93.63366699, 8.39616776], [93.63324738, 8.39665413], [93.63297272, 8.39727783], [93.63297272, 8.39783001], [93.63324738, 8.39804173], [93.63387299, 8.39804173], [93.63421631, 8.39797115], [93.63457489, 8.39762497], [93.63471222, 8.39734745], [93.63506317, 8.39699078], [93.63540649, 8.39679337], [93.63568115, 8.39610004], [93.63561249, 8.39547634], [93.63540649, 8.39498997], [93.63491821, 8.39464378]]], [[[93.60944366, 8.58166695], [93.60944366, 8.58138943], [93.60916901, 8.58111095], [93.60916901, 8.57999897], [93.60943604, 8.57972145], [93.60944366, 8.57944489], [93.60888672, 8.57888889], [93.60888672, 8.57861137], [93.60832977, 8.5780592], [93.60721588, 8.57916927], [93.60652161, 8.5796566], [93.60652161, 8.58090401], [93.60659027, 8.58125019], [93.60680389, 8.58146], [93.60694122, 8.58173561], [93.60729218, 8.58187485], [93.60756683, 8.58171654], [93.60777283, 8.58159733], [93.60832977, 8.58166695], [93.60874939, 8.58201408], [93.60916901, 8.58201408], [93.60944366, 8.58166695]]], [[[92.85916901, 8.8201313], [92.85888672, 8.81993008], [92.85832977, 8.81972313], [92.85736084, 8.81923485], [92.85687256, 8.8190279], [92.85650635, 8.81898022], [92.85595703, 8.81919193], [92.85546112, 8.81940174], [92.8549118, 8.81947041], [92.85415649, 8.81943989], [92.85360718, 8.82000065], [92.85333252, 8.81999874], [92.85277557, 8.82055473], [92.85243225, 8.82090378], [92.85201263, 8.82159615], [92.85194397, 8.8222208], [92.85221863, 8.82250118], [92.85221863, 8.82305527], [92.85250092, 8.82333279], [92.85250092, 8.82444477], [92.85277557, 8.82472324], [92.85277557, 8.82722092], [92.85250092, 8.82749939], [92.85250092, 8.82833385], [92.85277557, 8.82861233], [92.85277557, 8.83055592], [92.85305786, 8.83083439], [92.85305786, 8.83111191], [92.85333252, 8.83138847], [92.85333252, 8.83194065], [92.85361481, 8.83222198], [92.85361481, 8.83250046], [92.85444641, 8.83333397], [92.85444641, 8.83361244], [92.85527802, 8.83444405], [92.85541534, 8.83479023], [92.85778046, 8.83708286], [92.85805511, 8.8372221], [92.85861206, 8.83743191], [92.85944366, 8.83729267], [92.86006927, 8.83666611], [92.86027527, 8.83638763], [92.86194611, 8.83471966], [92.86194611, 8.83444405], [92.86222076, 8.83416557], [92.86222076, 8.83388996], [92.86242676, 8.83360958], [92.86250305, 8.83305645], [92.86250305, 8.83270741], [92.86250305, 8.83215141], [92.86284637, 8.83145809], [92.8629837, 8.83083439], [92.86319733, 8.8302784], [92.86326599, 8.82993126], [92.86326599, 8.82881927], [92.86312866, 8.82806015], [92.86305237, 8.82722092], [92.86305237, 8.8269434], [92.86305237, 8.82638931], [92.86305237, 8.82630539], [92.86306, 8.82588959], [92.86297607, 8.82513142], [92.86284637, 8.82451057], [92.86264038, 8.82380867], [92.86250305, 8.8229208], [92.86110687, 8.82186985], [92.8605423, 8.82173347], [92.86019135, 8.82124996], [92.86012268, 8.82048702], [92.85978699, 8.82034969], [92.85943604, 8.82028961], [92.85916901, 8.8201313]]], [[[92.47972107, 10.52056026], [92.47944641, 10.52056026], [92.47860718, 10.52139187], [92.47833252, 10.52139187], [92.47805786, 10.52167034], [92.47750092, 10.52166843], [92.47694397, 10.52222443], [92.47666931, 10.52222061], [92.47611237, 10.52278042], [92.47583008, 10.52278042], [92.47556305, 10.52305984], [92.47528076, 10.52305603], [92.47499847, 10.52333355], [92.47499847, 10.52361202], [92.47472382, 10.52361202], [92.47389221, 10.52444363], [92.47360992, 10.52444363], [92.47222137, 10.52555561], [92.47166443, 10.52583408], [92.47138977, 10.5261097], [92.47110748, 10.5261097], [92.47055817, 10.52666569], [92.47027588, 10.52673626], [92.46971893, 10.52729034], [92.46923828, 10.5277071], [92.46868134, 10.52821064], [92.46805573, 10.52909756], [92.46583557, 10.53111458], [92.46498871, 10.53234959], [92.46477509, 10.5327673], [92.46401215, 10.53352642], [92.46360779, 10.53444386], [92.46305847, 10.53499985], [92.46305847, 10.53527641], [92.46221924, 10.53610992], [92.46193695, 10.53610992], [92.46166992, 10.53639126], [92.46138763, 10.5363884], [92.46083069, 10.53694534], [92.46028137, 10.53694534], [92.45888519, 10.53833294], [92.45861053, 10.53833294], [92.45722198, 10.5397234], [92.45694733, 10.53972054], [92.45667267, 10.54000092], [92.45610809, 10.54000092], [92.45582581, 10.5402813], [92.45527649, 10.5402813], [92.45500183, 10.54056168], [92.45444489, 10.54055691], [92.45313263, 10.54139137], [92.45305634, 10.54277706], [92.45277405, 10.54305458], [92.45277405, 10.54333305], [92.45249939, 10.54361057], [92.45249939, 10.54416656], [92.45194244, 10.54472256], [92.45166779, 10.54472256], [92.45027924, 10.54333305], [92.44999695, 10.54333305], [92.44937134, 10.54347038], [92.44882202, 10.54382133], [92.44847107, 10.54389095], [92.44777679, 10.54402828], [92.44728851, 10.54409885], [92.4465332, 10.54437923], [92.44576263, 10.54445171], [92.44541931, 10.54437733], [92.44493103, 10.54465485], [92.44431305, 10.54471016], [92.44381714, 10.54486179], [92.44312286, 10.54506969], [92.44277954, 10.54521084], [92.44194794, 10.54521084], [92.44152832, 10.54535007], [92.44132233, 10.54549122], [92.44097137, 10.54563046], [92.44055176, 10.54569626], [92.44020844, 10.54583454], [92.43972015, 10.5460434], [92.4394455, 10.5462532], [92.4383316, 10.5466671], [92.43805695, 10.54694462], [92.43777466, 10.54694462], [92.4375, 10.54722118], [92.43723297, 10.54722118], [92.43694305, 10.54750156], [92.43638611, 10.5474987], [92.43611145, 10.54777718], [92.43554688, 10.54776955], [92.43527985, 10.54806042], [92.43499756, 10.5480547], [92.4347229, 10.54833317], [92.43416595, 10.54833317], [92.43318939, 10.54831505], [92.43249512, 10.54838562], [92.43158722, 10.54852486], [92.43081665, 10.54852009], [92.42928314, 10.54887104], [92.42774963, 10.54914856], [92.42698669, 10.54914856], [92.42642975, 10.54895115], [92.42572784, 10.54879189], [92.424263, 10.5487299], [92.42314911, 10.5487299], [92.42134094, 10.54824734], [92.42119598, 10.54824924], [92.41993713, 10.5479002], [92.41903687, 10.54755592], [92.41861725, 10.54720974], [92.41819763, 10.54645061], [92.41792297, 10.54582882], [92.41743469, 10.54534531], [92.41694641, 10.54472256], [92.41555786, 10.54333305], [92.41555786, 10.54305458], [92.41500092, 10.54249859], [92.41500854, 10.54222107], [92.41333008, 10.54055691], [92.41333008, 10.54027653], [92.41306305, 10.54000092], [92.41306305, 10.53972054], [92.41249847, 10.5391674], [92.41249847, 10.53888893], [92.40833282, 10.53472042], [92.40805817, 10.53472233], [92.40750122, 10.53416634], [92.40721893, 10.5341711], [92.40677643, 10.53372192], [92.40666962, 10.53361034], [92.40638733, 10.53361034], [92.40583038, 10.53305626], [92.40528107, 10.53306103], [92.40499878, 10.5327692], [92.40472412, 10.53277779], [92.40444183, 10.53250027], [92.40416718, 10.53250027], [92.40389252, 10.53222179], [92.40333557, 10.53222179], [92.40305328, 10.53194427], [92.40277863, 10.53194427], [92.40249634, 10.5316658], [92.40194702, 10.53167057], [92.4016571, 10.53139019], [92.40000916, 10.53139019], [92.39975739, 10.53114605], [92.39499664, 10.53111172], [92.39492798, 10.5310421], [92.39472198, 10.53083038], [92.39111328, 10.53083038], [92.39082336, 10.53111172], [92.3897171, 10.53111172], [92.38944244, 10.53139019], [92.38916779, 10.53139019], [92.38861084, 10.53152943], [92.38694763, 10.5316658], [92.38666534, 10.53194427], [92.38639069, 10.53194427], [92.3861084, 10.53222179], [92.38583374, 10.53222179], [92.38555908, 10.53229332], [92.38527679, 10.53222179], [92.38361359, 10.53388786], [92.38361359, 10.53444386], [92.3833313, 10.53472042], [92.3833313, 10.53527641], [92.38305664, 10.53555679], [92.38305664, 10.53582954], [92.38277435, 10.53610992], [92.38249969, 10.53610992], [92.3813858, 10.53722], [92.38131714, 10.53756905], [92.3813858, 10.53889084], [92.38159943, 10.53965187], [92.38194275, 10.54083347], [92.3822937, 10.54139137], [92.38298798, 10.54222298], [92.38305664, 10.54249859], [92.3841629, 10.54361057], [92.3841629, 10.54389095], [92.38527679, 10.54500103], [92.38555908, 10.54500103], [92.38582611, 10.54527855], [92.3861084, 10.54527664], [92.38666534, 10.54583263], [92.38694763, 10.54583263], [92.38944244, 10.54833317], [92.38944244, 10.54861069], [92.38972473, 10.54889011], [92.38972473, 10.54916763], [92.39026642, 10.54971886], [92.39026642, 10.54999924], [92.39083099, 10.55055618], [92.39083099, 10.5508337], [92.39360809, 10.55361176], [92.39360809, 10.55472183], [92.39305878, 10.55527973], [92.39305878, 10.5555563], [92.39221954, 10.5563879], [92.39214325, 10.55682278], [92.39212799, 10.55751228], [92.39248657, 10.55814266], [92.3927002, 10.5588274], [92.39311981, 10.55937958], [92.39332581, 10.56014156], [92.39367676, 10.56076431], [92.39381409, 10.56103992], [92.39472198, 10.56194401], [92.39472198, 10.56221962], [92.39499664, 10.56250095], [92.39499664, 10.56278133], [92.39527893, 10.56305695], [92.39527893, 10.56361008], [92.39583588, 10.56416702], [92.39583588, 10.56472015], [92.39607239, 10.56495953], [92.39666748, 10.56556129], [92.39694977, 10.56556129], [92.39888763, 10.56750107], [92.39888763, 10.56805515], [92.39916992, 10.5683279], [92.39916992, 10.56888866], [92.39944458, 10.56916714], [92.39944458, 10.56972313], [92.39971924, 10.56999874], [92.39971924, 10.5708313], [92.40027618, 10.5713892], [92.40027618, 10.57166672], [92.40055847, 10.57194519], [92.40055847, 10.57249928], [92.40222168, 10.57417202], [92.40249634, 10.57416725], [92.40333557, 10.57499886], [92.40361023, 10.57499886], [92.40367889, 10.57507038], [92.40389252, 10.57528019], [92.40416718, 10.57528019], [92.40499878, 10.57611179], [92.40499878, 10.57639027], [92.40528107, 10.57666779], [92.40528107, 10.57694054], [92.40575409, 10.57742023], [92.40611267, 10.57777977], [92.40638733, 10.57777786], [92.40638733, 10.57805634], [92.40666962, 10.57833385], [92.40666962, 10.57861233], [92.40721893, 10.57916641], [92.40721893, 10.57971859], [92.40750122, 10.57999992], [92.40750122, 10.5802803], [92.40777588, 10.58055592], [92.40777588, 10.58083439], [92.4091568, 10.58222198], [92.4091568, 10.58250046], [92.40944672, 10.58277798], [92.40944672, 10.58305645], [92.40972137, 10.58333397], [92.40944672, 10.58361244], [92.40944672, 10.58388138], [92.40972137, 10.5841713], [92.40972137, 10.58749962], [92.41000366, 10.58777809], [92.41000366, 10.58916569], [92.40972137, 10.58944416], [92.40972137, 10.59166718], [92.41000366, 10.59194469], [92.41000366, 10.59305477], [92.41027832, 10.59333324], [92.41027832, 10.59416676], [92.41055298, 10.59444523], [92.41055298, 10.59555531], [92.41083527, 10.59583282], [92.4108429, 10.5961113], [92.41110992, 10.59638882], [92.41110992, 10.59666729], [92.41166687, 10.59722328], [92.41166687, 10.59749889], [92.41222382, 10.59805489], [92.41222382, 10.60055542], [92.41249847, 10.60083103], [92.41249847, 10.60138893], [92.41278076, 10.6016674], [92.41278076, 10.60222054], [92.41305542, 10.60249901], [92.41306305, 10.60472202], [92.41278076, 10.60501099], [92.41278076, 10.6055603], [92.4127121, 10.60610962], [92.41333008, 10.60666561], [92.41333008, 10.60694408], [92.41444397, 10.60805607], [92.41443634, 10.60833168], [92.41500092, 10.60888767], [92.41500092, 10.60916805], [92.41527557, 10.60944366], [92.41546631, 10.60960102], [92.41553497, 10.60987854], [92.41602325, 10.61015511], [92.41637421, 10.61043262], [92.41769409, 10.61112404], [92.41832733, 10.61119366], [92.41923523, 10.61140156], [92.41964722, 10.61147022], [92.42006683, 10.61195278], [92.42028046, 10.61250019], [92.42028046, 10.6133337], [92.42055511, 10.61361027], [92.42056274, 10.61472034], [92.42028046, 10.61499977], [92.42007446, 10.61547947], [92.4199295, 10.61610126], [92.4199295, 10.61755085], [92.41979218, 10.61797047], [92.41971588, 10.61852169], [92.41944122, 10.61916733], [92.41931152, 10.61967468], [92.41889191, 10.62050533], [92.41868591, 10.62112713], [92.41854095, 10.62209129], [92.41854095, 10.62271786], [92.41847229, 10.62326908], [92.41833496, 10.62375546], [92.4182663, 10.62416935], [92.41805267, 10.62444305], [92.41805267, 10.62527657], [92.41757202, 10.62576294], [92.41742706, 10.62736034], [92.41736603, 10.62833309], [92.41694641, 10.62861061], [92.41666412, 10.62888908], [92.41666412, 10.62916756], [92.41638947, 10.62944126], [92.41638947, 10.63000202], [92.41611481, 10.63027668], [92.41611481, 10.63166809], [92.41583252, 10.6319437], [92.41583252, 10.63222218], [92.41521454, 10.63340378], [92.41493225, 10.63416576], [92.41464996, 10.63444424], [92.41444397, 10.63472176], [92.41396332, 10.63597298], [92.41340637, 10.63701534], [92.41305542, 10.63749981], [92.41306305, 10.63833046], [92.41278076, 10.63861179], [92.41278076, 10.63889027], [92.41249847, 10.63916588], [92.41249847, 10.63944435], [92.41221619, 10.63971996], [92.41221619, 10.64000034], [92.41194153, 10.64027786], [92.41194153, 10.64055634], [92.41166687, 10.64083004], [92.41166687, 10.64112186], [92.41139221, 10.64138794], [92.41139221, 10.64166641], [92.41110992, 10.64194393], [92.41110992, 10.64221954], [92.41083527, 10.64249992], [92.41083527, 10.64277935], [92.41056061, 10.64340305], [92.41027832, 10.64388847], [92.41027832, 10.64416695], [92.41027832, 10.64444542], [92.40999603, 10.64472008], [92.41000366, 10.64500141], [92.40972137, 10.64527893], [92.40972137, 10.64583302], [92.40944672, 10.64611053], [92.40944672, 10.64638901], [92.40916443, 10.64666653], [92.40916443, 10.646945], [92.40888977, 10.64722061], [92.40888977, 10.64750099], [92.40833282, 10.64805698], [92.40833282, 10.64861107], [92.40721893, 10.64972115], [92.40721893, 10.65000057], [92.40694427, 10.65027905], [92.40694427, 10.65055466], [92.40666962, 10.65083313], [92.40666962, 10.65111065], [92.40611267, 10.65166664], [92.40611267, 10.65222073], [92.40582275, 10.6524992], [92.40583038, 10.65277672], [92.40444183, 10.65416527], [92.40444183, 10.65444469], [92.40416718, 10.65472126], [92.40416718, 10.65499878], [92.40361023, 10.65555477], [92.40361023, 10.65583324], [92.40222168, 10.65722084], [92.40188599, 10.65792084], [92.40174103, 10.65819931], [92.40125275, 10.65888691], [92.40084076, 10.65944099], [92.40020752, 10.66006279], [92.39971924, 10.6607542], [92.39971924, 10.66111183], [92.39944458, 10.6613903], [92.39888763, 10.66166592], [92.39639282, 10.66471958], [92.39639282, 10.66499996], [92.39499664, 10.66639042], [92.39472198, 10.66639042], [92.39444733, 10.66611004], [92.39360809, 10.66611004], [92.39332581, 10.66639042], [92.39305878, 10.66639042], [92.39277649, 10.6666708], [92.39250183, 10.6666708], [92.39193726, 10.66611004], [92.391716, 10.66606045], [92.39122772, 10.66585732], [92.39066315, 10.66557884], [92.3901062, 10.66558075], [92.38912964, 10.66565037], [92.38829803, 10.66578579], [92.38725281, 10.66592503], [92.38641357, 10.66599369], [92.38585663, 10.66627026], [92.38536835, 10.66647911], [92.38425446, 10.66668701], [92.38362122, 10.66675472], [92.38334656, 10.66675472], [92.38264465, 10.66647911], [92.38208771, 10.66640854], [92.3813858, 10.6664114], [92.3812561, 10.66648197], [92.38097382, 10.66647911], [92.38083649, 10.66668701], [92.3805542, 10.66694355], [92.3805542, 10.66722202], [92.38027954, 10.66749954], [92.38027954, 10.6683321], [92.3805542, 10.66861343], [92.38083649, 10.66860962], [92.38083649, 10.66889095], [92.38111115, 10.66917133], [92.38194275, 10.66916561], [92.38222504, 10.66944408], [92.38223267, 10.6697197], [92.38249969, 10.67000103], [92.38249969, 10.67027855], [92.38277435, 10.67055416], [92.38277435, 10.67083454], [92.38305664, 10.67111015], [92.38305664, 10.67194462], [92.3833313, 10.67222309], [92.3833313, 10.67388916], [92.38361359, 10.67416668], [92.38361359, 10.67444515], [92.3833313, 10.67472267], [92.3833313, 10.67527676], [92.38308716, 10.67560291], [92.38246155, 10.67601681], [92.38224792, 10.67621994], [92.38179779, 10.67667389], [92.38169098, 10.67719078], [92.38154602, 10.67761135], [92.3812027, 10.67808914], [92.3812027, 10.67836666], [92.38149261, 10.67885017], [92.38175964, 10.67892075], [92.38217926, 10.67905807], [92.38217926, 10.67919731], [92.38222504, 10.67972088], [92.38222504, 10.68166733], [92.38194275, 10.68194485], [92.38194275, 10.68222141], [92.38166809, 10.68249893], [92.38166809, 10.6827774], [92.38111115, 10.68333054], [92.38083649, 10.68389034], [92.38083649, 10.68999958], [92.3805542, 10.69027805], [92.38062286, 10.69063091], [92.38050079, 10.69139004], [92.38050079, 10.69174099], [92.38018799, 10.69257069], [92.38006592, 10.69325924], [92.37979126, 10.69408894], [92.37985992, 10.69470882], [92.37999725, 10.69546986], [92.3805542, 10.69583225], [92.3805542, 10.69666576], [92.38083649, 10.69694042], [92.38083649, 10.69889069], [92.38111115, 10.69916725], [92.38111115, 10.70055676], [92.38083649, 10.70083046], [92.38083649, 10.70111084], [92.3805542, 10.70138931], [92.3805542, 10.70222282], [92.38046265, 10.70321178], [92.38039398, 10.70411015], [92.38018799, 10.70473194], [92.38018799, 10.70549393], [92.38004303, 10.70632267], [92.38027954, 10.70694065], [92.38027954, 10.70777702], [92.37999725, 10.70805454], [92.38027954, 10.70833302], [92.38027954, 10.7102766], [92.3805542, 10.71055508], [92.3805542, 10.7127018], [92.38051605, 10.71346378], [92.38051605, 10.71401501], [92.38065338, 10.71512127], [92.38100433, 10.71581268], [92.38121033, 10.71636486], [92.38137054, 10.71671104], [92.38162994, 10.71719456], [92.38169861, 10.71760941], [92.38191223, 10.71816063], [92.38194275, 10.71860981], [92.38222504, 10.71889019], [92.38222504, 10.71944427], [92.38249969, 10.71972179], [92.38249969, 10.72138119], [92.38212585, 10.72242069], [92.38183594, 10.72289944], [92.38176727, 10.72332096], [92.3817749, 10.72414589], [92.38163757, 10.72456074], [92.38163757, 10.72482967], [92.38143158, 10.7254591], [92.38135529, 10.72608089], [92.3809433, 10.72670269], [92.38083649, 10.72722054], [92.38054657, 10.72750092], [92.38054657, 10.7277813], [92.38027954, 10.72805691], [92.38027954, 10.72861099], [92.37999725, 10.72889137], [92.37999725, 10.73027897], [92.3797226, 10.73055458], [92.3797226, 10.73111057], [92.3795166, 10.73173523], [92.37916565, 10.7341671], [92.37917328, 10.7344408], [92.37869263, 10.73548889], [92.37847137, 10.73611069], [92.37832642, 10.73751068], [92.37805176, 10.73777962], [92.37805176, 10.73806], [92.37785339, 10.73888969], [92.37785339, 10.73951435], [92.37770844, 10.74007034], [92.37792206, 10.7407608], [92.37833405, 10.74111176], [92.37833405, 10.74166584], [92.3786087, 10.74194431], [92.3786087, 10.74250031], [92.37847137, 10.74270725], [92.37847137, 10.74319267], [92.37854004, 10.74361038], [92.3786087, 10.74500179], [92.37854004, 10.74528027], [92.37840271, 10.74631977], [92.37830353, 10.74679565], [92.37830353, 10.74755478], [92.37837219, 10.74783325], [92.37837219, 10.74838543], [92.37844086, 10.74935341], [92.37830353, 10.75004387], [92.37823486, 10.75032043], [92.37805176, 10.7508297], [92.37833405, 10.75111008], [92.37833405, 10.75285244], [92.3782196, 10.75347233], [92.37828827, 10.75395012], [92.37835693, 10.75457859], [92.3784256, 10.75485516], [92.3784256, 10.75520134], [92.37828827, 10.75575256], [92.37850189, 10.75623608], [92.37899017, 10.75672245], [92.3793335, 10.75727463], [92.37975311, 10.75768757], [92.3800354, 10.75810337], [92.38024139, 10.75858784], [92.38024139, 10.7597599], [92.38046265, 10.76031971], [92.38072968, 10.76073074], [92.3813858, 10.76139164], [92.38144684, 10.76192856], [92.38147736, 10.76217079], [92.38140106, 10.76237774], [92.38105774, 10.76327038], [92.38098907, 10.76390076], [92.38056946, 10.76466179], [92.38035583, 10.76500416], [92.37992096, 10.7652483], [92.37943268, 10.76559353], [92.37901306, 10.76648998], [92.37873077, 10.7669754], [92.37859344, 10.76759815], [92.37859344, 10.76801205], [92.37845612, 10.76856613], [92.37810516, 10.76891041], [92.3777771, 10.7691679], [92.37722015, 10.76972198], [92.37722015, 10.77055645], [92.3769455, 10.77083397], [92.3769455, 10.77166557], [92.37666321, 10.77194405], [92.37666321, 10.77221966], [92.37638855, 10.77250004], [92.37638855, 10.77278042], [92.37610626, 10.7730608], [92.37610626, 10.77334118], [92.37604523, 10.77388763], [92.37590027, 10.77451038], [92.3758316, 10.77527809], [92.3758316, 10.77555561], [92.37590027, 10.77590275], [92.3758316, 10.77618122], [92.37596893, 10.7765274], [92.37596893, 10.77701283], [92.3758316, 10.77882004], [92.37583923, 10.77943134], [92.37611389, 10.77999783], [92.37611389, 10.78166676], [92.37638855, 10.78194523], [92.37638855, 10.78222275], [92.37666321, 10.78249168], [92.37666321, 10.78277683], [92.3769455, 10.78305531], [92.37695313, 10.78333092], [92.37750244, 10.78389072], [92.37750244, 10.78416729], [92.38083649, 10.78750134], [92.38083649, 10.78777695], [92.3813858, 10.78833103], [92.3813858, 10.78862], [92.38305664, 10.79028034], [92.3833313, 10.79028034], [92.38360596, 10.79055977], [92.38388824, 10.790555], [92.3841629, 10.79083347], [92.38471985, 10.79083347], [92.38555908, 10.78999901], [92.38555908, 10.78972435], [92.38583374, 10.78944302], [92.38583374, 10.78909397], [92.3861084, 10.78833294], [92.38625336, 10.78805542], [92.38639069, 10.78777695], [92.38625336, 10.78695202], [92.3861084, 10.78583145], [92.38583374, 10.78555489], [92.38583374, 10.78472328], [92.38603973, 10.78421307], [92.38617706, 10.78379822], [92.38659668, 10.78317642], [92.38707733, 10.78297043], [92.38786316, 10.7825489], [92.38861847, 10.78234577], [92.38924408, 10.78207016], [92.3897171, 10.78167057], [92.39055634, 10.78167057], [92.39082336, 10.78139114], [92.39167023, 10.78139114], [92.39193726, 10.7811079], [92.39221954, 10.78111076], [92.39277649, 10.78055668], [92.39305878, 10.78056145], [92.39332581, 10.78028107], [92.39360809, 10.78028107], [92.39451599, 10.77962017], [92.39472961, 10.77913857], [92.39479828, 10.77851677], [92.39466095, 10.77796078], [92.39417267, 10.77748013], [92.39368439, 10.77720356], [92.3934021, 10.776721], [92.39291382, 10.77623558], [92.39277649, 10.77547741], [92.39291382, 10.77340317], [92.39298248, 10.77278042], [92.39305878, 10.77194405], [92.39326477, 10.76972198], [92.39333344, 10.7691679], [92.39332581, 10.76889038], [92.39360809, 10.76861191], [92.39360809, 10.76749992], [92.39388275, 10.7672224], [92.39402771, 10.76597023], [92.39416504, 10.76527786], [92.39437866, 10.76416779], [92.39444733, 10.76389027], [92.39444733, 10.76333141], [92.39472198, 10.76305485], [92.39472198, 10.76249886], [92.39499664, 10.76222134], [92.39499664, 10.76194477], [92.39527893, 10.76166725], [92.39527893, 10.76138878], [92.39554596, 10.76111126], [92.39555359, 10.76083279], [92.39611053, 10.76041603], [92.39659882, 10.76027679], [92.39694977, 10.76028156], [92.39722443, 10.76034832], [92.39749908, 10.76055527], [92.39771271, 10.76076031], [92.39839935, 10.76138878], [92.39861298, 10.76166725], [92.39901733, 10.76222134], [92.39916992, 10.76250172], [92.39944458, 10.76277733], [92.39937592, 10.76305485], [92.39902496, 10.7634716], [92.39854431, 10.76298714], [92.39833069, 10.76277733], [92.39756775, 10.76173592], [92.39680481, 10.76166725], [92.39659882, 10.76187706], [92.39638519, 10.76222134], [92.39583588, 10.76277733], [92.39583588, 10.76333141], [92.39554596, 10.76361084], [92.3953476, 10.76437664], [92.39527893, 10.76499939], [92.39499664, 10.76589108], [92.39499664, 10.76638985], [92.39479065, 10.76701641], [92.39472198, 10.76756954], [92.39465332, 10.76826286], [92.39444733, 10.76888847], [92.3942337, 10.77104378], [92.39389038, 10.77194405], [92.39409637, 10.77221966], [92.39479065, 10.77285099], [92.39499664, 10.7730608], [92.3951416, 10.77365971], [92.39527893, 10.77401066], [92.39527893, 10.77417088], [92.39527893, 10.77499962], [92.39555359, 10.77527809], [92.39555359, 10.77666569], [92.39639282, 10.77750111], [92.39639282, 10.77778053], [92.39666748, 10.77806091], [92.39666748, 10.77858543], [92.396698, 10.77907085], [92.39697266, 10.77941513], [92.39718628, 10.77982998], [92.39718628, 10.7803812], [92.39711761, 10.78079796], [92.39711761, 10.78093529], [92.39749908, 10.7811079], [92.39768982, 10.78129768], [92.39778137, 10.78139114], [92.39833069, 10.78138924], [92.39888763, 10.78194523], [92.39916992, 10.78194523], [92.39944458, 10.78201485], [92.39971924, 10.78201485], [92.40007019, 10.7820816], [92.40090179, 10.78222275], [92.40166473, 10.78222275], [92.4017868, 10.782341], [92.40194702, 10.78250122], [92.40277863, 10.78249168], [92.40339661, 10.78265095], [92.40416718, 10.78278065], [92.40444183, 10.78306198], [92.40499878, 10.78305531], [92.40528107, 10.78333282], [92.40555573, 10.78333282], [92.40583038, 10.7836113], [92.40611267, 10.7836113], [92.40666962, 10.7841692], [92.40694427, 10.78416729], [92.40777588, 10.78479385], [92.40805817, 10.78499889], [92.40888977, 10.78583336], [92.40916443, 10.78583336], [92.41166687, 10.78805733], [92.41194153, 10.78833294], [92.4126358, 10.78874969], [92.41305542, 10.78888893], [92.41333008, 10.7891674], [92.41333008, 10.78944111], [92.41388702, 10.79000187], [92.41416931, 10.78999901], [92.41416931, 10.79027653], [92.41471863, 10.79083347], [92.41471863, 10.79111195], [92.41610718, 10.79249954], [92.41610718, 10.79277992], [92.41722107, 10.79389191], [92.41722107, 10.79417038], [92.41833496, 10.7952776], [92.41833496, 10.79555607], [92.41860962, 10.79583359], [92.41860962, 10.79638767], [92.41971588, 10.79749107], [92.41972351, 10.79777813], [92.41999817, 10.79805565], [92.41999817, 10.79833412], [92.42028046, 10.79860973], [92.42028046, 10.79916573], [92.42055511, 10.7994442], [92.42066193, 10.79998589], [92.42066193, 10.80033112], [92.42094421, 10.80088425], [92.42128754, 10.80157661], [92.42163849, 10.80198956], [92.42194366, 10.80277824], [92.42222595, 10.80305576], [92.42222595, 10.80472279], [92.42250061, 10.80500126], [92.42250061, 10.80638885], [92.42222595, 10.8066597], [92.42211151, 10.80681705], [92.42218018, 10.80743885], [92.42233276, 10.80799103], [92.42266846, 10.80848122], [92.42295074, 10.80902958], [92.42343903, 10.80937672], [92.42399597, 10.80951309], [92.42444611, 10.80944538], [92.42492676, 10.80987835], [92.4254837, 10.81098557], [92.42582703, 10.81188107], [92.42590332, 10.81244183], [92.42610931, 10.81278229], [92.42610931, 10.81361103], [92.4263916, 10.81388855], [92.4263916, 10.81444454], [92.42666626, 10.81472111], [92.42666626, 10.8152771], [92.4263916, 10.81555462], [92.4263916, 10.81583118], [92.42694092, 10.81638908], [92.42694092, 10.8166666], [92.42722321, 10.81694126], [92.42722321, 10.81750202], [92.42714691, 10.81783199], [92.42722321, 10.81818104], [92.42729187, 10.81865692], [92.42722321, 10.81927872], [92.42714691, 10.81962109], [92.42687225, 10.82003784], [92.42666626, 10.82073116], [92.42666626, 10.82250023], [92.42688751, 10.82328415], [92.42771912, 10.82363033], [92.4282074, 10.8234911], [92.42884064, 10.82293987], [92.42967224, 10.82231712], [92.43036652, 10.82197094], [92.43106842, 10.82175922], [92.43281555, 10.82176399], [92.43357849, 10.82204247], [92.4342041, 10.82224655], [92.43490601, 10.8228693], [92.43560028, 10.82328415], [92.43671417, 10.82404518], [92.43741608, 10.82487488], [92.43804169, 10.82577324], [92.43852997, 10.82639503], [92.44139099, 10.82944393], [92.44139099, 10.82971954], [92.44167328, 10.82999992], [92.44167328, 10.83056068], [92.44249725, 10.83139133], [92.44256592, 10.83159828], [92.4438858, 10.83305359], [92.44403076, 10.83326435], [92.44451141, 10.83353996], [92.44472504, 10.83388901], [92.44499969, 10.83416653], [92.44499207, 10.83444023], [92.44555664, 10.83500099], [92.44555664, 10.83555698], [92.4458313, 10.8358326], [92.4458313, 10.83611107], [92.44721985, 10.83750057], [92.44777679, 10.83750057], [92.44805908, 10.83778095], [92.44916534, 10.83777905], [92.4493103, 10.83792019], [92.44944763, 10.83805943], [92.44999695, 10.83805943], [92.45027924, 10.83778095], [92.45054626, 10.83778095], [92.45083618, 10.83750057], [92.45388794, 10.83749866], [92.45432281, 10.8376379], [92.45500183, 10.83778095], [92.45527649, 10.83805943], [92.45573425, 10.83812332], [92.4562912, 10.83846664], [92.45664978, 10.83881187], [92.4569931, 10.83936977], [92.45741272, 10.83998966], [92.45775604, 10.84081936], [92.45777893, 10.8413887], [92.45805359, 10.84166718], [92.45804596, 10.84222126], [92.45855713, 10.8425312], [92.45856476, 10.84335804], [92.45888519, 10.84416771], [92.45888519, 10.84444332], [92.45916748, 10.84472084], [92.45916748, 10.84527683], [92.45944214, 10.84555626], [92.45944214, 10.84583378], [92.45972443, 10.84611225], [92.45986176, 10.84663105], [92.45993042, 10.84759998], [92.45999908, 10.84861183], [92.45999908, 10.85056019], [92.45999908, 10.85099125], [92.45999908, 10.85175037], [92.45986176, 10.85244083], [92.4597168, 10.85326958], [92.45972443, 10.85388756], [92.45944214, 10.85416603], [92.45944214, 10.85471058], [92.45916748, 10.85499954], [92.45916748, 10.85527802], [92.45888519, 10.85555553], [92.45888519, 10.8558321], [92.45861053, 10.85610962], [92.45861053, 10.85638809], [92.45833588, 10.85666561], [92.45833588, 10.85694408], [92.45722198, 10.85805416], [92.45722198, 10.85833454], [92.45666504, 10.85888767], [92.45667267, 10.85972023], [92.45639038, 10.86000061], [92.45639038, 10.86028099], [92.45667267, 10.86056137], [92.45666504, 10.86083317], [92.45694733, 10.86111069], [92.45694733, 10.86139107], [92.45861053, 10.8630619], [92.45888519, 10.86305523], [92.45916748, 10.86333275], [92.45972443, 10.86333275], [92.45999908, 10.86361122], [92.46193695, 10.86361122], [92.46221924, 10.86390018], [92.46277618, 10.86390018], [92.46305847, 10.86417103], [92.46333313, 10.86416721], [92.46348572, 10.8643198], [92.46360779, 10.86444473], [92.46389008, 10.86444473], [92.46416473, 10.86472321], [92.46444702, 10.8647213], [92.46458435, 10.86485958], [92.46472168, 10.86500072], [92.46499634, 10.86500072], [92.46555328, 10.86555862], [92.4658432, 10.86555862], [92.46646118, 10.86618423], [92.46666718, 10.86638927], [92.46694183, 10.86638927], [92.46721649, 10.86667156], [92.46778107, 10.86666679], [92.46805573, 10.86694527], [92.46833038, 10.86694527], [92.46944427, 10.86805534], [92.46944427, 10.86833286], [92.46971893, 10.86861134], [92.46971893, 10.86888885], [92.47000122, 10.86916733], [92.47000122, 10.86944485], [92.47027588, 10.86970997], [92.47027588, 10.87000179], [92.47000885, 10.87047958], [92.46994019, 10.87095928], [92.46994019, 10.8712368], [92.47014618, 10.87151337], [92.47037506, 10.87157917], [92.47062683, 10.87165165], [92.47104645, 10.87144184], [92.47154236, 10.8712368], [92.47194672, 10.87111092], [92.47222137, 10.8708334], [92.47389221, 10.8708334], [92.47416687, 10.87111092], [92.47497559, 10.8710804], [92.47573853, 10.87094307], [92.47629547, 10.87080383], [92.47748566, 10.87080383], [92.47797394, 10.8708744], [92.47831726, 10.87101078], [92.47859955, 10.87111092], [92.47888947, 10.87111092], [92.47915649, 10.87139034], [92.47944641, 10.87139034], [92.48027802, 10.87222099], [92.48027802, 10.87249947], [92.48306274, 10.87528038], [92.48306274, 10.87555981], [92.48332977, 10.87584114], [92.48332977, 10.8763876], [92.48361206, 10.87666798], [92.48361206, 10.87694359], [92.48388672, 10.87722206], [92.48388672, 10.87749958], [92.48610687, 10.87971973], [92.4861145, 10.88000011], [92.48666382, 10.88055611], [92.48665619, 10.88083172], [92.48722076, 10.88138771], [92.48764038, 10.88172531], [92.48792267, 10.88206959], [92.48826599, 10.88241577], [92.48861694, 10.88310909], [92.48874664, 10.88352108], [92.48883057, 10.88408184], [92.48910522, 10.88456059], [92.48916626, 10.88500118], [92.48944092, 10.8852787], [92.48944092, 10.88555431], [92.4908371, 10.88694477], [92.4908371, 10.88722038], [92.49138641, 10.88778114], [92.49138641, 10.88807106], [92.49250031, 10.88917065], [92.49277496, 10.88916683], [92.49305725, 10.8894453], [92.4936142, 10.8894453], [92.49388885, 10.88972282], [92.4944458, 10.88972282], [92.49514008, 10.88992977], [92.49694824, 10.8900013], [92.4972229, 10.89021111], [92.49749756, 10.89028072], [92.4980545, 10.89041805], [92.4991684, 10.89055538], [92.49951172, 10.89069366], [92.49973297, 10.8906889], [92.50006866, 10.89077091], [92.50035095, 10.89077091], [92.50055695, 10.89083958], [92.50138855, 10.8908329], [92.50164032, 10.89088345], [92.5017395, 10.89090347], [92.50228882, 10.89090347], [92.50250244, 10.8908329], [92.5027771, 10.89083958], [92.50305176, 10.8905592], [92.50332642, 10.8905592], [92.5036087, 10.89028072], [92.50389099, 10.89028072], [92.50499725, 10.88917065], [92.50499725, 10.88822079], [92.50502014, 10.88705158], [92.50508881, 10.88634968], [92.5052948, 10.88518143], [92.50543213, 10.88435078], [92.50583649, 10.88333035], [92.50583649, 10.88277817], [92.50611115, 10.88249969], [92.50611115, 10.88222027], [92.5063858, 10.8819437], [92.5063858, 10.88166618], [92.5083313, 10.87972164], [92.50861359, 10.87972164], [92.50888824, 10.87944412], [92.5091629, 10.87944412], [92.50971985, 10.87889004], [92.51000214, 10.87890244], [92.5111084, 10.87812042], [92.51145935, 10.87750435], [92.51145935, 10.87695122], [92.51139069, 10.87584496], [92.51132202, 10.87487698], [92.5112381, 10.8737011], [92.5111084, 10.87249947], [92.51083374, 10.87222099], [92.51083374, 10.87194347], [92.51079559, 10.87118435], [92.51037598, 10.87063122], [92.50975037, 10.87000847], [92.50891113, 10.86966419], [92.50821686, 10.86980057], [92.50744629, 10.87022018], [92.50688934, 10.87090874], [92.50577545, 10.87145996], [92.50473022, 10.87208176], [92.50395966, 10.87256622], [92.50308228, 10.87274075], [92.50256348, 10.87284374], [92.50270844, 10.87242889], [92.50333405, 10.87194347], [92.50444794, 10.8708334], [92.5047226, 10.8708334], [92.50499725, 10.87055492], [92.50527191, 10.87055969], [92.50583649, 10.87000179], [92.50611115, 10.87000179], [92.5063858, 10.86970997], [92.50666809, 10.86972332], [92.50694275, 10.86944485], [92.50722504, 10.86944485], [92.50777435, 10.86888885], [92.50805664, 10.86889172], [92.5083313, 10.86861134], [92.50945282, 10.86861134], [92.50971985, 10.86889172], [92.51000214, 10.86889172], [92.51027679, 10.86917019], [92.51055908, 10.86917019], [92.51139069, 10.86999893], [92.51139069, 10.8702774], [92.51167297, 10.87063122], [92.51187134, 10.87105179], [92.51222229, 10.8715992], [92.51222229, 10.87305641], [92.51249695, 10.87333393], [92.51249695, 10.8736124], [92.51277924, 10.87388992], [92.51277924, 10.87444401], [92.5128479, 10.87472153], [92.51277924, 10.87576294], [92.51277924, 10.87611198], [92.51256561, 10.87743187], [92.51222229, 10.87805557], [92.51194, 10.87833405], [92.51069641, 10.87965107], [92.51027679, 10.88000011], [92.50992584, 10.88014126], [92.50971985, 10.88027763], [92.5083313, 10.88166618], [92.5083313, 10.88222027], [92.50805664, 10.88249969], [92.50782776, 10.88285828], [92.50769043, 10.88341236], [92.50769043, 10.88396358], [92.50762177, 10.88486385], [92.50740814, 10.88555431], [92.50699615, 10.88652325], [92.50678253, 10.88748932], [92.50678253, 10.88942432], [92.50694275, 10.88972282], [92.50723267, 10.8900013], [92.50723267, 10.89028072], [92.50749969, 10.8905592], [92.50749969, 10.89083958], [92.50805664, 10.89138889], [92.50805664, 10.89166737], [92.5083313, 10.89194489], [92.5083313, 10.89222145], [92.50860596, 10.89250088], [92.50860596, 10.89277935], [92.50888824, 10.89305496], [92.50888824, 10.89361095], [92.5091629, 10.89388943], [92.5091629, 10.89416695], [92.50944519, 10.89444542], [92.50944519, 10.89472103], [92.50997925, 10.89526081], [92.51027679, 10.89556026], [92.51055908, 10.89556026], [92.51139832, 10.89639187], [92.51166534, 10.89638901], [92.51222229, 10.89694309], [92.51277924, 10.89694309], [92.51288605, 10.89705276], [92.51305389, 10.89722443], [92.51361084, 10.89722443], [92.51403046, 10.89743137], [92.51499939, 10.89750195], [92.51541901, 10.89770889], [92.51583099, 10.89764118], [92.51611328, 10.89750195], [92.51638794, 10.89750195], [92.51667023, 10.89722061], [92.52027893, 10.89722443], [92.52055359, 10.89694309], [92.52111053, 10.89694309], [92.52305603, 10.89500141], [92.52305603, 10.89472103], [92.52639008, 10.89138889], [92.5266571, 10.89138889], [92.52777863, 10.89028072], [92.52777863, 10.8900013], [92.52805328, 10.88972282], [92.52805328, 10.8894453], [92.52833557, 10.88916683], [92.52833557, 10.88888931], [92.52889252, 10.88833046], [92.52889252, 10.88805676], [92.52999878, 10.88694477], [92.52999878, 10.88666725], [92.53006744, 10.88632011], [92.53006744, 10.88597393], [92.52979279, 10.8852787], [92.52944183, 10.88500118], [92.52889252, 10.88444424], [92.52889252, 10.88388824], [92.52840424, 10.883214], [92.52832794, 10.88265991], [92.52832794, 10.88190079], [92.52889252, 10.88111019], [92.52889252, 10.88083363], [92.52916718, 10.88055611], [92.52916718, 10.88027763], [92.52944183, 10.88000011], [92.52944183, 10.87971973], [92.52999878, 10.87916565], [92.52999878, 10.87777805], [92.53028107, 10.87749958], [92.53028107, 10.87722015], [92.53166962, 10.87583447], [92.53197479, 10.87480831], [92.53196716, 10.87419128], [92.53161621, 10.87322044], [92.53099823, 10.87217999], [92.53044128, 10.871768], [92.52953339, 10.87100697], [92.52897644, 10.8703804], [92.52848816, 10.86927891], [92.52841949, 10.86858845], [92.52855682, 10.86776066], [92.52889252, 10.86694145], [92.52889252, 10.86666679], [92.53028107, 10.8652792], [92.53056335, 10.8652792], [92.53083038, 10.86500072], [92.53138733, 10.86500072], [92.53183746, 10.86474991], [92.53239441, 10.86475277], [92.53281403, 10.8646841], [92.53337097, 10.86482143], [92.53421021, 10.8652401], [92.5351181, 10.86531067], [92.53588104, 10.86531067], [92.53623199, 10.86516953], [92.53651428, 10.86530685], [92.5369339, 10.86565304], [92.53694916, 10.86610413], [92.53648376, 10.86619473], [92.53578949, 10.86619473], [92.5345993, 10.86612701], [92.53390503, 10.86584854], [92.53292847, 10.86571026], [92.53173828, 10.86578083], [92.53074646, 10.86619091], [92.53013611, 10.8667469], [92.52978516, 10.8675766], [92.52971649, 10.8684063], [92.52986145, 10.86902809], [92.52999878, 10.86944485], [92.53028107, 10.86970997], [92.53028107, 10.86999893], [92.53277588, 10.87249947], [92.53308868, 10.87311268], [92.53330231, 10.87387371], [92.53337097, 10.87456036], [92.53308105, 10.87512016], [92.5328064, 10.87574005], [92.53196716, 10.87718964], [92.53166962, 10.87749958], [92.53166962, 10.87777805], [92.53138733, 10.87805557], [92.53138733, 10.87833405], [92.53111267, 10.87861156], [92.53111267, 10.87916565], [92.53166962, 10.87972164], [92.53166962, 10.88111019], [92.53138733, 10.88138771], [92.53138733, 10.88166618], [92.53083038, 10.88222027], [92.53083038, 10.88249969], [92.53056335, 10.88278103], [92.53028107, 10.88278103], [92.52999878, 10.88306141], [92.52972412, 10.88305569], [92.52944183, 10.88333035], [92.52964783, 10.88395882], [92.52999878, 10.88416576], [92.53034973, 10.88458061], [92.53076172, 10.88465214], [92.53152466, 10.88493156], [92.53166962, 10.88500118], [92.53194427, 10.88500118], [92.53221893, 10.88471985], [92.53250122, 10.88472176], [92.53277588, 10.88444424], [92.53305817, 10.88444424], [92.53333282, 10.88416576], [92.5341568, 10.88417053], [92.53444672, 10.88389111], [92.53499603, 10.88389111], [92.53527832, 10.88360977], [92.53555298, 10.88360977], [92.53583527, 10.88333225], [92.53610992, 10.88333225], [92.53666687, 10.88277817], [92.53694153, 10.88278103], [92.53943634, 10.88027954], [92.53971863, 10.88027954], [92.54083252, 10.87917042], [92.54083252, 10.87890244], [92.54277802, 10.87694073], [92.54277802, 10.87666798], [92.54305267, 10.8763876], [92.54332733, 10.87639046], [92.54332733, 10.87611198], [92.54416656, 10.87528038], [92.54471588, 10.87528038], [92.54611206, 10.87389183], [92.54611206, 10.87360859], [92.54666901, 10.87305641], [92.54666901, 10.87277794], [92.54750824, 10.87194061], [92.54777527, 10.87194347], [92.54833221, 10.87139034], [92.54972076, 10.87139034], [92.55000305, 10.87111092], [92.55083466, 10.87111092], [92.55278015, 10.86917019], [92.55278015, 10.86889172], [92.55361176, 10.86806202], [92.55361176, 10.86778164], [92.5541687, 10.86722088], [92.55444336, 10.86722088], [92.55666351, 10.86499882], [92.55687714, 10.86479378], [92.5577774, 10.86382103], [92.55805206, 10.86361122], [92.55833435, 10.86333275], [92.55833435, 10.86305523], [92.55860901, 10.86277676], [92.55860901, 10.86250114], [92.5588913, 10.86222267], [92.5588913, 10.86166668], [92.55916595, 10.86138916], [92.55916595, 10.86111069], [92.55944824, 10.86083317], [92.55944824, 10.86028099], [92.5597229, 10.86000061], [92.5597229, 10.85917091], [92.55999756, 10.85889053], [92.55999756, 10.85861015], [92.5597229, 10.85833454], [92.5597229, 10.85750008], [92.55944824, 10.8572216], [92.55944824, 10.85694408], [92.55916595, 10.85666561], [92.55916595, 10.85638809], [92.55832672, 10.85556126], [92.55832672, 10.85528088], [92.5577774, 10.85471058], [92.5577774, 10.85444355], [92.55750275, 10.85416603], [92.55750275, 10.85111237], [92.55722046, 10.85083389], [92.55722046, 10.85055637], [92.5569458, 10.8502779], [92.5569458, 10.84972191], [92.55666351, 10.84944439], [92.55666351, 10.84916782], [92.55638885, 10.8488903], [92.55654144, 10.84527111], [92.55666351, 10.84409714], [92.5569458, 10.84388924], [92.5569458, 10.84333134], [92.55750275, 10.84277725], [92.55750275, 10.84222126], [92.5577774, 10.84194469], [92.5577774, 10.8413887], [92.55805206, 10.84111118], [92.55805206, 10.84000111], [92.55833435, 10.83972263], [92.55832672, 10.8394413], [92.55860901, 10.83916664], [92.55860901, 10.83888912], [92.5588913, 10.83861065], [92.5588913, 10.83833313], [92.55916595, 10.83805466], [92.55916595, 10.83777905], [92.55944824, 10.83750057], [92.55944824, 10.83667088], [92.5597229, 10.83639145], [92.5597229, 10.83611107], [92.55999756, 10.8358326], [92.55999756, 10.8352766], [92.56027985, 10.83500099], [92.56027985, 10.83444023], [92.5605545, 10.83416653], [92.5605545, 10.83277893], [92.56083679, 10.83250141], [92.56083679, 10.83194542], [92.56111145, 10.83166599], [92.56111145, 10.83138847], [92.56138611, 10.83111], [92.56138611, 10.83083153], [92.56194305, 10.8302784], [92.56194305, 10.82999992], [92.56305695, 10.82888985], [92.56305695, 10.82833195], [92.5633316, 10.82805634], [92.5633316, 10.82722187], [92.56305695, 10.82694435], [92.56305695, 10.82666588], [92.5625, 10.82610989], [92.56250763, 10.82583046], [92.56222534, 10.8255558], [92.56194305, 10.82527828], [92.56194305, 10.82473087], [92.56138611, 10.82417011], [92.56138611, 10.82361031], [92.56111145, 10.82333374], [92.56138611, 10.82305622], [92.56111145, 10.82277775], [92.56111145, 10.8208313], [92.56083679, 10.82055569], [92.56111145, 10.82027817], [92.56111145, 10.81917], [92.56138611, 10.81888962], [92.56138611, 10.81805992], [92.5616684, 10.81777954], [92.5616684, 10.81694126], [92.56194305, 10.8166666], [92.56194305, 10.81444454], [92.5616684, 10.81416702], [92.5616684, 10.81361103], [92.56138611, 10.81333256], [92.56138611, 10.81194496], [92.5616684, 10.81166744], [92.5616684, 10.81138897], [92.56194305, 10.81111145], [92.56194305, 10.81083298], [92.56222534, 10.81055546], [92.56222534, 10.81027889], [92.56276703, 10.80972099], [92.56277466, 10.80944538], [92.5644455, 10.8077774], [92.5644455, 10.80750084], [92.56472015, 10.80722046], [92.56472015, 10.80611134], [92.56361389, 10.80500126], [92.56288147, 10.80494785], [92.56273651, 10.80481052], [92.56253815, 10.80445957], [92.56176758, 10.80391121], [92.56121063, 10.80363464], [92.56059265, 10.80350113], [92.56030273, 10.80425835], [92.56023407, 10.80488014], [92.56016541, 10.8053627], [92.56009674, 10.80605412], [92.55981445, 10.80570889], [92.55967712, 10.80501747], [92.55974579, 10.80426025], [92.55995941, 10.8035717], [92.56022644, 10.80294037], [92.56023407, 10.80176926], [92.5603714, 10.80121708], [92.56051636, 10.8008709], [92.56079102, 10.80066109], [92.5610733, 10.80038548], [92.56134796, 10.8002491], [92.56169891, 10.80031681], [92.56183624, 10.80052376], [92.56176758, 10.8008709], [92.56183624, 10.80135441], [92.56176758, 10.80204678], [92.56163025, 10.80273724], [92.56162262, 10.80301094], [92.56183624, 10.80328941], [92.56204987, 10.80356693], [92.56268311, 10.80377197], [92.56315613, 10.80398178], [92.5637207, 10.80412102], [92.56420898, 10.80420113], [92.56449127, 10.80398178], [92.56500244, 10.80361938], [92.5652771, 10.80361938], [92.56555176, 10.80333042], [92.56583405, 10.80333233], [92.5661087, 10.80305576], [92.56667328, 10.80306053], [92.56694794, 10.80278111], [92.56833649, 10.80278111], [92.56861115, 10.80249977], [92.57026672, 10.80249977], [92.57055664, 10.80278111], [92.57195282, 10.80278111], [92.57332611, 10.80138969], [92.57332611, 10.80111027], [92.5736084, 10.8008337], [92.5736084, 10.80055618], [92.57389069, 10.80027771], [92.57389069, 10.79972172], [92.57416534, 10.7994442], [92.57416534, 10.79805565], [92.57444763, 10.79777813], [92.57444763, 10.79749107], [92.57472229, 10.79722214], [92.57479095, 10.79666805], [92.57861328, 10.79277802], [92.5790863, 10.79249954], [92.57937622, 10.79236317], [92.57965088, 10.79222393], [92.58000183, 10.79201412], [92.58034515, 10.79187679], [92.58110809, 10.79168129], [92.58132172, 10.79152203], [92.58166504, 10.79139042], [92.58187103, 10.79125118], [92.58222198, 10.79111195], [92.58257294, 10.79083347], [92.58305359, 10.790555], [92.58333588, 10.79055977], [92.58361816, 10.79028034], [92.58444214, 10.79028034], [92.5847168, 10.79000187], [92.58528137, 10.79000187], [92.58708191, 10.7881918], [92.58750153, 10.78750134], [92.58770752, 10.78694534], [92.58777618, 10.78638744], [92.58777618, 10.78583336], [92.58784485, 10.78555489], [92.58791351, 10.78534794], [92.58784485, 10.78513813], [92.58777618, 10.78472137], [92.58777618, 10.78166676], [92.58805847, 10.78138924], [92.58805847, 10.77943134], [92.58833313, 10.77916718], [92.58805847, 10.7788887], [92.58805847, 10.77806091], [92.58777618, 10.77778053], [92.58777618, 10.77721977], [92.58750153, 10.77694416], [92.58750153, 10.77555561], [92.58721924, 10.77527809], [92.58721924, 10.77444172], [92.58694458, 10.77416611], [92.58694458, 10.77305603], [92.58667755, 10.77278042], [92.58667755, 10.77055073], [92.58694458, 10.77027798], [92.58694458, 10.76944447], [92.58638763, 10.76888847], [92.58638763, 10.76833439], [92.58555603, 10.76749992], [92.58555603, 10.76638985], [92.58528137, 10.76610947], [92.58528137, 10.76472092], [92.58499908, 10.7644434], [92.58499908, 10.76361084], [92.5847168, 10.76333141], [92.58472443, 10.76305485], [92.58444214, 10.76277733], [92.58444214, 10.76250172], [92.58416748, 10.76222134], [92.58416748, 10.76194477], [92.58388519, 10.76166725], [92.58388519, 10.76055527], [92.58361816, 10.76028156], [92.58361816, 10.75916862], [92.58333588, 10.7588892], [92.58333588, 10.75778103], [92.58361816, 10.75750065], [92.58361816, 10.75639057], [92.58333588, 10.75611115], [92.58333588, 10.75583267], [92.58361053, 10.75555515], [92.58361053, 10.7547226], [92.58347321, 10.75437641], [92.58361053, 10.75235939], [92.58354187, 10.75194454], [92.58361053, 10.75166702], [92.58347321, 10.75124931], [92.58354187, 10.75035095], [92.58333588, 10.74840069], [92.58305359, 10.74750042], [92.5828476, 10.74660015], [92.58257294, 10.74549007], [92.58277893, 10.74250031], [92.58305359, 10.74222183], [92.58305359, 10.74194431], [92.58333588, 10.74166584], [92.58333588, 10.74111176], [92.58361053, 10.74083424], [92.58361053, 10.74055576], [92.58388519, 10.74027824], [92.58409882, 10.74014091], [92.5845108, 10.73971939], [92.58472443, 10.73944569], [92.58499908, 10.73916531], [92.58499908, 10.73888969], [92.58528137, 10.73860931], [92.58528137, 10.7383337], [92.58555603, 10.73805618], [92.58555603, 10.73777676], [92.58583069, 10.73751068], [92.58583069, 10.73721886], [92.58611298, 10.73694324], [92.58611298, 10.73638916], [92.58638763, 10.73611069], [92.58638763, 10.73583317], [92.58694458, 10.73527718], [92.58694458, 10.7349987], [92.58777618, 10.73417187], [92.58777618, 10.73389244], [92.58805847, 10.73361111], [92.58805847, 10.73249912], [92.58833313, 10.73194504], [92.58833313, 10.73166656], [92.58867645, 10.73055458], [92.58860779, 10.72861099], [92.58860779, 10.72806168], [92.58860779, 10.72527885], [92.58867645, 10.72472], [92.58889008, 10.72360992], [92.58916473, 10.72333241], [92.58916473, 10.72166634], [92.58944702, 10.72138786], [92.58944702, 10.72056103], [92.58972168, 10.72028065], [92.58972168, 10.71889019], [92.58999634, 10.71861172], [92.58999634, 10.71778011], [92.59027863, 10.71749973], [92.59027863, 10.71722031], [92.59194183, 10.71555614], [92.59194183, 10.71500015], [92.59222412, 10.71472168], [92.59222412, 10.71389008], [92.59249878, 10.7136097], [92.59249115, 10.71249962], [92.59278107, 10.71221924], [92.59278107, 10.71138954], [92.59333038, 10.71083355], [92.59401703, 10.70987415], [92.59450531, 10.70932198], [92.59548187, 10.708354], [92.59590912, 10.70796871], [92.59666443, 10.70728016], [92.59687805, 10.70700455], [92.59736633, 10.70631409], [92.597435, 10.70610714], [92.59757233, 10.70472527], [92.59799194, 10.703825], [92.5982666, 10.70313454], [92.5982666, 10.70237255], [92.59841156, 10.70140743], [92.59848022, 10.70036983], [92.59848022, 10.69982147], [92.5983429, 10.69899082], [92.59799194, 10.69781113], [92.59784698, 10.69715595], [92.59784698, 10.69639683], [92.59744263, 10.69522095], [92.59729004, 10.69449711], [92.5969162, 10.69414139], [92.59684753, 10.69365788], [92.59671021, 10.69283104], [92.5969162, 10.69234085], [92.59705353, 10.69158363], [92.59726715, 10.69089127], [92.59726715, 10.6893034], [92.59740448, 10.68847275], [92.59747314, 10.68758869], [92.59747314, 10.68586063], [92.59754181, 10.68482399], [92.5976181, 10.68309593], [92.5976181, 10.68205929], [92.59754181, 10.68144035], [92.59733582, 10.68094921], [92.59726715, 10.68019295], [92.59705353, 10.67950153], [92.5969162, 10.67887974], [92.59677887, 10.67832565], [92.59642029, 10.67776966], [92.59566498, 10.6772213], [92.59461975, 10.67687416], [92.59361267, 10.67694473], [92.59333038, 10.67706966], [92.59249115, 10.67723179], [92.59221649, 10.67750072], [92.59194183, 10.67750072], [92.59166718, 10.6777792], [92.59139252, 10.6777792], [92.59111023, 10.67784977], [92.59055328, 10.67805481], [92.58916473, 10.67909908], [92.58889008, 10.67944527], [92.58853912, 10.67951584], [92.58757019, 10.67957973], [92.58730316, 10.67959118], [92.58687592, 10.67959118], [92.58673859, 10.67951107], [92.58625031, 10.67944527], [92.58611298, 10.67944527], [92.58548737, 10.67923832], [92.58499908, 10.67916679], [92.5847168, 10.6791687], [92.58444214, 10.67888927], [92.58416748, 10.67888927], [92.58389282, 10.67860889], [92.58361053, 10.6786108], [92.58277893, 10.6777792], [92.58277893, 10.67749882], [92.58249664, 10.67723179], [92.58222198, 10.67723179], [92.58202362, 10.67702484], [92.58194733, 10.67694473], [92.58139038, 10.67694473], [92.58110809, 10.67666721], [92.58082581, 10.67667198], [92.57943726, 10.67528057], [92.57888794, 10.67528057], [92.57833099, 10.6747179], [92.57805634, 10.67472267], [92.57722473, 10.67388916], [92.57722473, 10.6730547], [92.57639313, 10.67222023], [92.5763855, 10.6716671], [92.57624817, 10.67129517], [92.57589722, 10.67080975], [92.57589722, 10.6703949], [92.57596588, 10.66963577], [92.57611084, 10.66894341], [92.5761795, 10.66832066], [92.57631683, 10.6678381], [92.57666779, 10.66721535], [92.57681274, 10.66625118], [92.57694244, 10.66582966], [92.57694244, 10.66527843], [92.57722473, 10.66499996], [92.5772171, 10.66471958], [92.57749939, 10.66444397], [92.57749939, 10.66416645], [92.57805634, 10.66361237], [92.57802582, 10.66290283], [92.57802582, 10.66262531], [92.57795715, 10.66193485], [92.57802582, 10.66137886], [92.57809448, 10.66048336], [92.57823181, 10.65999985], [92.5785141, 10.65944576], [92.57865143, 10.65876198], [92.57892609, 10.65819931], [92.57949066, 10.65820408], [92.57962799, 10.65827179], [92.58004761, 10.65868664], [92.58053589, 10.65882587], [92.5807724, 10.65895557], [92.5811615, 10.65917015], [92.58158112, 10.65910244], [92.58220673, 10.65882587], [92.58248901, 10.65861893], [92.58255768, 10.65841103], [92.5827713, 10.65785027], [92.58297729, 10.65737438], [92.58290863, 10.6570282], [92.58255768, 10.65689087], [92.58228302, 10.6568203], [92.58193207, 10.65696239], [92.58165741, 10.65689087], [92.58138275, 10.6568203], [92.58083344, 10.65645981], [92.58027649, 10.65583324], [92.58000183, 10.65583324], [92.57987976, 10.65571308], [92.57944489, 10.65527725], [92.57944489, 10.65499878], [92.57861328, 10.65417194], [92.57833099, 10.65417194], [92.57805634, 10.65389156], [92.57776642, 10.65389156], [92.57749176, 10.65361118], [92.57722473, 10.65361118], [92.57694244, 10.65333271], [92.57666779, 10.65333271], [92.5763855, 10.65305519], [92.57601929, 10.65284824], [92.57546997, 10.65285015], [92.57491302, 10.65271091], [92.57441711, 10.65278244], [92.57392883, 10.65292072], [92.57253265, 10.65291595], [92.57211304, 10.65312576], [92.57138824, 10.65305519], [92.57111359, 10.65277672], [92.57055664, 10.65278244], [92.57026672, 10.6524992], [92.56999969, 10.6524992], [92.56916809, 10.65166664], [92.5688858, 10.65166855], [92.56833649, 10.65111065], [92.56804657, 10.65111065], [92.56784821, 10.65090561], [92.56777954, 10.65083122], [92.56694794, 10.65083313], [92.56666565, 10.65055466], [92.56639099, 10.65056038], [92.56582642, 10.65000057], [92.56555176, 10.65000057], [92.56472015, 10.64917183], [92.56445313, 10.64917183], [92.56426239, 10.64898682], [92.56416321, 10.64889145], [92.56416321, 10.64861107], [92.56388855, 10.6483326], [92.56388855, 10.64805698], [92.56361389, 10.6477766], [92.5633316, 10.64778137], [92.56250763, 10.64693069], [92.56222534, 10.646945], [92.5616684, 10.64638901], [92.56138611, 10.64639091], [92.56083679, 10.64583015], [92.56083679, 10.64555454], [92.55944824, 10.64416695], [92.55916595, 10.64395905], [92.5579834, 10.64291477], [92.55764008, 10.64270782], [92.55708313, 10.64215183], [92.5569458, 10.64194393], [92.55583191, 10.64083195], [92.55388641, 10.63889027], [92.55361176, 10.63860989], [92.55271149, 10.63784885], [92.55249786, 10.63750172], [92.55194092, 10.63694191], [92.55194092, 10.6366663], [92.55110931, 10.63583374], [92.55110931, 10.63555622], [92.55027771, 10.63472176], [92.55027771, 10.63444424], [92.54972076, 10.63389015], [92.54972076, 10.63361168], [92.54916382, 10.63305569], [92.54915619, 10.63278008], [92.54860687, 10.63221931], [92.5486145, 10.6319437], [92.54805756, 10.63138962], [92.54805756, 10.6311121], [92.54777527, 10.63083363], [92.54777527, 10.63055611], [92.54722595, 10.62999916], [92.54722595, 10.62972069], [92.54694366, 10.62944317], [92.54694366, 10.62916756], [92.54666901, 10.62888908], [92.54666901, 10.62861061], [92.54611206, 10.62805462], [92.5460434, 10.6277771], [92.54582977, 10.62758064], [92.54556274, 10.62722111], [92.54555511, 10.62680626], [92.54534149, 10.62631893], [92.54506683, 10.62583065], [92.54444122, 10.62500381], [92.54423523, 10.62437534], [92.54416656, 10.62416744], [92.54416656, 10.62388897], [92.54360962, 10.62333107], [92.54360962, 10.62305546], [92.54333496, 10.62277699], [92.54333496, 10.62250137], [92.54305267, 10.62222099], [92.54305267, 10.62166691], [92.54277802, 10.62138939], [92.54277802, 10.62111092], [92.54250336, 10.6208334], [92.54250336, 10.61972332], [92.54222107, 10.61944485], [92.54222107, 10.61916733], [92.54194641, 10.61888885], [92.54194641, 10.61861134], [92.54138947, 10.61805439], [92.54138947, 10.61750126], [92.54110718, 10.61721992], [92.54111481, 10.61638832], [92.54083252, 10.61610985], [92.54083252, 10.61472225], [92.54055786, 10.61444378], [92.54055786, 10.61388779], [92.54027557, 10.61361027], [92.54027557, 10.61305618], [92.54000092, 10.61277771], [92.54000092, 10.61250019], [92.54006958, 10.61229134], [92.54006958, 10.61173439], [92.54000092, 10.61139011], [92.54000092, 10.61081791], [92.53979492, 10.61055565], [92.53993225, 10.60999966], [92.54000092, 10.60972023], [92.54000092, 10.60861206], [92.53985596, 10.60833359], [92.53985596, 10.6077776], [92.54000092, 10.60750008], [92.54000092, 10.60472202], [92.54027557, 10.6044426], [92.54027557, 10.60333443], [92.54055786, 10.603055], [92.54055786, 10.6016674], [92.54083252, 10.60139179], [92.54083252, 10.60056019], [92.54138184, 10.60000134], [92.54138184, 10.59944057], [92.54194641, 10.59888935], [92.54194641, 10.59861088], [92.54222107, 10.59833336], [92.54222107, 10.59805489], [92.54256439, 10.59715271], [92.54305267, 10.5961113], [92.54333496, 10.59583282], [92.54333496, 10.59555531], [92.54360962, 10.59527683], [92.54360962, 10.59500122], [92.54389191, 10.59472084], [92.54389191, 10.59444523], [92.54416656, 10.59416676], [92.54416656, 10.59388924], [92.54444122, 10.5936079], [92.54444122, 10.59333324], [92.54555511, 10.59222317], [92.54714966, 10.59201527], [92.54777527, 10.59194469], [92.54853821, 10.59166908], [92.54888916, 10.59167099], [92.54915619, 10.59167099], [92.54972076, 10.59111118], [92.55027771, 10.59111118], [92.55055237, 10.59083462], [92.55110931, 10.59083462], [92.5513916, 10.59055424], [92.55222321, 10.59056091], [92.55249786, 10.59028053], [92.55304718, 10.59028053], [92.5533371, 10.59000969], [92.55361176, 10.59000969], [92.55388641, 10.58971977], [92.5541687, 10.58972263], [92.55444336, 10.58944416], [92.55472565, 10.58944416], [92.55500031, 10.58916569], [92.55555725, 10.58917141], [92.55583191, 10.58889103], [92.55638123, 10.58882046], [92.55665588, 10.5886097], [92.55700684, 10.58854198], [92.55722046, 10.5886097], [92.55757141, 10.58868122], [92.55791473, 10.58868122], [92.55840302, 10.5886097], [92.55944824, 10.58826637], [92.55999756, 10.58806133], [92.56054688, 10.58806133], [92.56104279, 10.58778095], [92.5616684, 10.58749962], [92.56285095, 10.58722019], [92.5633316, 10.58694363], [92.56388855, 10.58687592], [92.56416321, 10.58666611], [92.56445313, 10.58631992], [92.5661087, 10.58443928], [92.56652832, 10.58430481], [92.56777954, 10.58291721], [92.56804657, 10.58250046], [92.56916809, 10.58139038], [92.56916809, 10.58111191], [92.56944275, 10.58083439], [92.56944275, 10.57888985], [92.56916809, 10.57860947], [92.56916809, 10.57833385], [92.5688858, 10.57805634], [92.5688858, 10.57750034], [92.56861115, 10.57722092], [92.56861115, 10.57666779], [92.56833649, 10.57639027], [92.56833649, 10.57611179], [92.5661087, 10.57389164], [92.5661087, 10.57361126], [92.56583405, 10.57333279], [92.56583405, 10.57305527], [92.5652771, 10.57249928], [92.5652771, 10.5722208], [92.56472015, 10.57166672], [92.56472015, 10.5713892], [92.56388855, 10.57056046], [92.56388855, 10.57028198], [92.56360626, 10.57000065], [92.56360626, 10.56972122], [92.56138611, 10.56750107], [92.56138611, 10.5672226], [92.56083679, 10.5666666], [92.55996704, 10.56476116], [92.55899048, 10.56337833], [92.55846405, 10.56198311], [92.55762482, 10.56136131], [92.55636597, 10.56053066], [92.55574036, 10.55976963], [92.55483246, 10.55908012], [92.55462646, 10.55852985], [92.55442047, 10.55796146], [92.55406952, 10.55714512], [92.55302429, 10.55624676], [92.55155945, 10.55576134], [92.55083466, 10.55527782], [92.55055237, 10.55500031], [92.55027771, 10.55500031], [92.55000305, 10.55472183], [92.5486145, 10.55472183], [92.54805756, 10.55416584], [92.5477829, 10.55416965], [92.54764557, 10.55403423], [92.54750061, 10.55389023], [92.54750824, 10.55360985], [92.54638672, 10.55249977], [92.54638672, 10.55222225], [92.54582977, 10.55166626], [92.54582977, 10.55138969], [92.54556274, 10.55110931], [92.54555511, 10.55055618], [92.54528046, 10.55027771], [92.54528046, 10.54971886], [92.54499817, 10.54944324], [92.54499817, 10.54777718], [92.54472351, 10.5474987], [92.54472351, 10.54583263], [92.54444122, 10.54555511], [92.54444122, 10.54444313], [92.54416656, 10.54416656], [92.54416656, 10.54339504], [92.54386139, 10.5430479], [92.54371643, 10.54201126], [92.54302216, 10.54055882], [92.54239655, 10.53952217], [92.54204559, 10.53876305], [92.54179382, 10.5380249], [92.5415802, 10.53754234], [92.54123688, 10.53664398], [92.54081726, 10.53595257], [92.54009247, 10.53558445], [92.53995514, 10.53544521], [92.53842163, 10.53516865], [92.53807068, 10.53503036], [92.5373764, 10.53427124], [92.53695679, 10.53364658], [92.53653717, 10.53261185], [92.53639984, 10.53205776], [92.53598022, 10.53130054], [92.53562927, 10.5304718], [92.53494263, 10.52991962], [92.5341568, 10.5296402], [92.53396606, 10.52896118], [92.53367615, 10.52806091], [92.53367615, 10.52764606], [92.53388977, 10.52674961], [92.53437042, 10.52610016], [92.53437042, 10.52560997], [92.53443909, 10.52505875], [92.53423309, 10.52443886], [92.53408813, 10.52340031], [92.53401184, 10.52299881], [92.53387451, 10.5225153], [92.53351593, 10.52203178], [92.53304291, 10.52133942], [92.53268433, 10.52071667], [92.53240967, 10.52030468], [92.53205872, 10.51981926], [92.53177643, 10.5189209], [92.53135681, 10.51844025], [92.53093719, 10.51816177], [92.53028107, 10.51779079], [92.52999878, 10.51779079], [92.52971649, 10.51750088], [92.52916718, 10.51750088], [92.52907562, 10.51740837], [92.52889252, 10.51722336], [92.52861023, 10.51722336], [92.52833557, 10.51694489], [92.52805328, 10.51694489], [92.52732086, 10.51721191], [92.52648163, 10.51721191], [92.52571869, 10.51700687], [92.52529907, 10.51686764], [92.5245285, 10.51631165], [92.52383423, 10.51583099], [92.52334595, 10.51555538], [92.52230072, 10.51513958], [92.52104187, 10.51465702], [92.52083588, 10.51443958], [92.5203476, 10.51409912], [92.51972198, 10.51417065], [92.51922607, 10.51375198], [92.51860809, 10.51361084], [92.51750183, 10.51361084], [92.51721191, 10.51333046], [92.51694489, 10.51333332], [92.51667023, 10.51305485], [92.51611328, 10.51306152], [92.51555634, 10.51249886], [92.51472473, 10.51250076], [92.51444244, 10.51222324], [92.51361084, 10.51222324], [92.51305389, 10.51166725], [92.51249695, 10.51166725], [92.51222229, 10.51194477], [92.51083374, 10.51194477], [92.51055908, 10.51222324], [92.50971985, 10.51222324], [92.50944519, 10.51250076], [92.5091629, 10.51222324], [92.50805664, 10.51222324], [92.50777435, 10.51194477], [92.50722504, 10.51194477], [92.50694275, 10.51166725], [92.5063858, 10.51166725], [92.50611115, 10.51138878], [92.50534821, 10.51139069], [92.50527191, 10.51111126], [92.50369263, 10.51090336], [92.50083923, 10.51090527], [92.49903107, 10.51118088], [92.49812317, 10.51187611], [92.49777985, 10.51222324], [92.49749756, 10.51250076], [92.4972229, 10.51249886], [92.49680328, 10.51264], [92.49610901, 10.51278114], [92.49582672, 10.51306152], [92.49555206, 10.51305485], [92.4952774, 10.51333046], [92.4952774, 10.51361084], [92.49500275, 10.51389122], [92.49500275, 10.51417065], [92.4944458, 10.51473045], [92.49416351, 10.51472092], [92.49388885, 10.5150013], [92.49360657, 10.5150013], [92.49305725, 10.5155592], [92.49250031, 10.5155592], [92.49223328, 10.5155592], [92.49124908, 10.51562977], [92.4908371, 10.5155592], [92.49055481, 10.51555538], [92.49028015, 10.5158329], [92.48916626, 10.5158329], [92.4888916, 10.51611137], [92.48832703, 10.51611137], [92.48805237, 10.51638889], [92.48665619, 10.51638889], [92.48638916, 10.51666927], [92.48583221, 10.51666737], [92.48555756, 10.51694489], [92.48500061, 10.51694489], [92.48472595, 10.51722336], [92.48443604, 10.51722145], [92.48416901, 10.51750088], [92.48361206, 10.51750088], [92.48332977, 10.51779079], [92.48306274, 10.51779079], [92.48278046, 10.51805973], [92.48249817, 10.51805496], [92.48222351, 10.51833344], [92.48139191, 10.51833344], [92.48000336, 10.51972103], [92.48000336, 10.52028179], [92.47972107, 10.52056026]]], [[[92.81416321, 9.12694359], [92.81416321, 9.1263876], [92.81445313, 9.12639046], [92.81445313, 9.12611198], [92.81472015, 9.12611198], [92.81472015, 9.12583447], [92.81388855, 9.12583447], [92.81388855, 9.12555599], [92.81360626, 9.1255579], [92.81360626, 9.12528038], [92.8133316, 9.12528038], [92.8133316, 9.12500191], [92.81276703, 9.12500191], [92.81276703, 9.12472057], [92.81201172, 9.12471676], [92.81201935, 9.12444115], [92.8116684, 9.12444115], [92.8116684, 9.1255579], [92.8125, 9.12555599], [92.8125, 9.12583447], [92.8133316, 9.12583065], [92.8133316, 9.12639046], [92.81361389, 9.1263876], [92.81361389, 9.12694359], [92.81416321, 9.12694359]]], [[[92.79332733, 9.11889076], [92.79332733, 9.11861134], [92.79444122, 9.11861134], [92.79444122, 9.11833286], [92.79582977, 9.11833286], [92.79582977, 9.11805534], [92.79638672, 9.11805534], [92.79638672, 9.11833286], [92.79666901, 9.11861134], [92.7986145, 9.11861134], [92.7986145, 9.11833286], [92.79833221, 9.11833286], [92.79833221, 9.11805534], [92.79696655, 9.11795521], [92.79666901, 9.11773968], [92.79222107, 9.11778164], [92.79222107, 9.11806202], [92.79250336, 9.11805534], [92.79250336, 9.11861134], [92.79305267, 9.11861134], [92.79305267, 9.11889076], [92.79332733, 9.11889076]]], [[[92.8041687, 9.1208334], [92.8041687, 9.1202774], [92.80444336, 9.12027931], [92.80444336, 9.12000084], [92.8041687, 9.12000084], [92.8041687, 9.11972141], [92.80374908, 9.11958885], [92.80361176, 9.11944485], [92.80305481, 9.119133], [92.80278015, 9.11917019], [92.80278015, 9.11889076], [92.80166626, 9.11889076], [92.80166626, 9.11861134], [92.8013916, 9.11861134], [92.80131531, 9.11865234], [92.80095673, 9.11886024], [92.80055237, 9.11865044], [92.79972076, 9.11861134], [92.79972076, 9.11889076], [92.80027008, 9.11889076], [92.80027008, 9.11917019], [92.80110931, 9.11916733], [92.80110931, 9.11944485], [92.8013916, 9.11944485], [92.8013916, 9.11916733], [92.80194092, 9.11923122], [92.80235291, 9.11954975], [92.80267334, 9.11952305], [92.80303955, 9.11972141], [92.80303955, 9.12000084], [92.80388641, 9.11999893], [92.80388641, 9.1208334], [92.8041687, 9.1208334]]], [[[92.78778076, 9.24416637], [92.78888702, 9.24305439], [92.78971863, 9.24306107], [92.7902832, 9.24250031], [92.79055786, 9.24250031], [92.79111481, 9.24194431], [92.79138947, 9.24194431], [92.79222107, 9.24110985], [92.79222107, 9.24083424], [92.79305267, 9.23999977], [92.79305267, 9.23972225], [92.79472351, 9.23805618], [92.79472351, 9.23777771], [92.79499817, 9.23750019], [92.79499817, 9.23722172], [92.79528046, 9.2369442], [92.79611206, 9.2367363], [92.79729462, 9.23555565], [92.79750061, 9.23499966], [92.79805756, 9.23444366], [92.79805756, 9.23416805], [92.79833221, 9.23388767], [92.79882813, 9.2336092], [92.79917908, 9.23334503], [92.79953003, 9.23306942], [92.80001831, 9.2325201], [92.80058289, 9.23168087], [92.80099487, 9.23112965], [92.80168915, 9.23050785], [92.80222321, 9.2300024], [92.80332947, 9.22888947], [92.80361176, 9.22888947], [92.80473328, 9.22777939], [92.80500031, 9.22777939], [92.80750275, 9.22528172], [92.8077774, 9.22528172], [92.8088913, 9.22417164], [92.80916595, 9.22417164], [92.8097229, 9.22361088], [92.80999756, 9.22361088], [92.81083679, 9.22277737], [92.81111145, 9.22278118], [92.8125, 9.22139072], [92.81276703, 9.22139072], [92.81388855, 9.22028065], [92.81388855, 9.22000122], [92.8144455, 9.21944523], [92.8144455, 9.21916676], [92.8152771, 9.21833229], [92.8152771, 9.21805668], [92.81583405, 9.21750069], [92.81667328, 9.21667099], [92.81667328, 9.21639061], [92.8172226, 9.21582985], [92.8172226, 9.21555424], [92.81749725, 9.21527767], [92.81832886, 9.21445084], [92.81861115, 9.21380234], [92.81916809, 9.21324062], [92.81944275, 9.21220589], [92.81964874, 9.21103001], [92.81999969, 9.21000004], [92.8208313, 9.20917034], [92.8208313, 9.20860958], [92.82055664, 9.20833397], [92.82055664, 9.20777798], [92.8208313, 9.20750046], [92.8208313, 9.20722198], [92.82118225, 9.2067337], [92.82145691, 9.20604324], [92.8216629, 9.2052784], [92.8216629, 9.20444584], [92.82194519, 9.20416546], [92.82194519, 9.20388985], [92.82221985, 9.20361137], [92.82221985, 9.20249939], [92.82250214, 9.20222092], [92.82277679, 9.20147419], [92.82326508, 9.20022678], [92.82333374, 9.19939709], [92.82367706, 9.19858074], [92.82430267, 9.19584179], [92.85436249, 9.2091589], [92.8544693, 9.20884895], [92.85686493, 9.20195866], [92.82553101, 9.19213104], [92.82588196, 9.19033337], [92.82601929, 9.18929577], [92.82637024, 9.18798065], [92.82650757, 9.18770313], [92.82623291, 9.18687439], [92.82601929, 9.18638802], [92.82601929, 9.1850729], [92.82567596, 9.18410397], [92.82553101, 9.18306541], [92.82567596, 9.18237209], [92.82581329, 9.18209553], [92.82588196, 9.1817503], [92.82518768, 9.18091965], [92.82553101, 9.1798811], [92.82553101, 9.17953491], [92.82567596, 9.1792593], [92.8264389, 9.17875957], [92.82713318, 9.17787266], [92.82846069, 9.17655754], [92.82880402, 9.17628193], [92.82894897, 9.17558956], [92.82888031, 9.17468929], [92.82901764, 9.1743412], [92.82950592, 9.17358208], [92.82971191, 9.17295933], [92.82984924, 9.17254543], [92.82984924, 9.17171288], [92.83033752, 9.17143726], [92.83047485, 9.17101955], [92.83082581, 9.17067146], [92.83082581, 9.17005062], [92.83089447, 9.16977501], [92.8310318, 9.16901207], [92.83110809, 9.16845989], [92.83152008, 9.16755104], [92.8317337, 9.16652107], [92.83152008, 9.16555214], [92.83166504, 9.16520596], [92.8317337, 9.16437626], [92.83187103, 9.16341019], [92.83174133, 9.16271019], [92.83166504, 9.16188335], [92.83131409, 9.1610527], [92.83110809, 9.16036034], [92.83096313, 9.15918446], [92.83096313, 9.15800571], [92.83068848, 9.15724468], [92.8302002, 9.15683174], [92.8302002, 9.15620995], [92.82956696, 9.15550995], [92.82936096, 9.1550293], [92.82901764, 9.1539917], [92.82888031, 9.15330029], [92.82874298, 9.15287971], [92.82859802, 9.1521244], [92.82824707, 9.15149879], [92.82817841, 9.15073967], [92.82810974, 9.14990997], [92.82832336, 9.1491518], [92.82832336, 9.14789104], [92.82839203, 9.14720726], [92.82817841, 9.14672375], [92.82859802, 9.14554596], [92.82873535, 9.14478493], [92.82888031, 9.14423084], [92.82888031, 9.14354038], [92.82880402, 9.14312267], [92.82894897, 9.14256859], [92.8290863, 9.14153194], [92.82915497, 9.14097881], [92.82964325, 9.14007759], [92.82984924, 9.13993931], [92.8302002, 9.13993931], [92.83068848, 9.13973045], [92.83068848, 9.13931656], [92.83055115, 9.13869476], [92.83013153, 9.13827801], [92.8290863, 9.13827991], [92.82817841, 9.13807011], [92.82784271, 9.13807011], [92.8274231, 9.13815022], [92.82657623, 9.13827991], [92.82581329, 9.13820934], [92.82518768, 9.13827991], [92.82414246, 9.13835144], [92.82302856, 9.13772202], [92.82233429, 9.13772392], [92.82156372, 9.13716984], [92.82066345, 9.13682365], [92.81996155, 9.13640881], [92.81926727, 9.13585472], [92.8184967, 9.13537025], [92.81759644, 9.13544273], [92.81746674, 9.13544273], [92.81682587, 9.1355114], [92.81648254, 9.13508034], [92.81606293, 9.13426208], [92.8157196, 9.13357067], [92.81529999, 9.13287926], [92.81494904, 9.13246441], [92.8143158, 9.13169956], [92.81369781, 9.13163185], [92.81349182, 9.13163185], [92.81300354, 9.13177109], [92.81216431, 9.13149548], [92.81188965, 9.13107967], [92.81195831, 9.13052559], [92.81195831, 9.12900162], [92.81216431, 9.12810135], [92.81223297, 9.12727165], [92.81223297, 9.12678623], [92.81195831, 9.12644005], [92.81160736, 9.12588787], [92.81138611, 9.1255579], [92.81083679, 9.1255579], [92.81083679, 9.12472057], [92.81111145, 9.12472057], [92.81111145, 9.12444305], [92.81138611, 9.12444305], [92.81138611, 9.1236124], [92.81111145, 9.1236124], [92.81111145, 9.12389183], [92.80999756, 9.12389183], [92.80999756, 9.1236124], [92.80860901, 9.1236124], [92.80860901, 9.12389183], [92.80833435, 9.12388992], [92.80833435, 9.12416458], [92.80805206, 9.12416458], [92.80805206, 9.1236124], [92.80722046, 9.1236124], [92.80673218, 9.12360191], [92.80632019, 9.12339497], [92.80561829, 9.12304878], [92.8052063, 9.12290955], [92.80471802, 9.12221909], [92.80451202, 9.12187004], [92.8042984, 9.121665], [92.80381012, 9.12111092], [92.80332184, 9.12076473], [92.80262756, 9.12055779], [92.80200195, 9.12034988], [92.80137634, 9.12042141], [92.80046844, 9.12042141], [92.79971313, 9.12014008], [92.79892731, 9.12035179], [92.79880524, 9.12015629], [92.79775238, 9.11986542], [92.79725647, 9.11986923], [92.7964325, 9.11966038], [92.79601288, 9.11966038], [92.79524994, 9.11952019], [92.79434204, 9.11959076], [92.79399109, 9.11966038], [92.79342651, 9.1192379], [92.79225159, 9.11931133], [92.79155731, 9.11924171], [92.79100037, 9.11924171], [92.79037476, 9.11910343], [92.78960419, 9.1189642], [92.78870392, 9.1189642], [92.78703308, 9.11931133], [92.78583527, 9.11944485], [92.78555298, 9.11944485], [92.78527832, 9.11972332], [92.78360748, 9.11972141], [92.78333282, 9.12000084], [92.78314209, 9.11995125], [92.78299713, 9.12022018], [92.78251648, 9.12019253], [92.78233337, 9.12018108], [92.78233337, 9.11991501], [92.78250122, 9.11984921], [92.78253174, 9.1196804], [92.78286743, 9.11918068], [92.78334045, 9.11912441], [92.78360748, 9.11861134], [92.78388977, 9.11861134], [92.78398895, 9.11884117], [92.7841568, 9.11889076], [92.7841568, 9.11861134], [92.78500366, 9.11861134], [92.78500366, 9.11805534], [92.78694153, 9.11806202], [92.78694153, 9.11778164], [92.78806305, 9.11778164], [92.78806305, 9.11806202], [92.78833008, 9.11806202], [92.78833008, 9.11778164], [92.78861237, 9.11778164], [92.78861237, 9.11750126], [92.78943634, 9.11750126], [92.78943634, 9.11778164], [92.79000092, 9.11778164], [92.79000092, 9.11750126], [92.79000092, 9.11722088], [92.78968048, 9.11702347], [92.78944397, 9.11694527], [92.78583527, 9.11694527], [92.78583527, 9.11722088], [92.78527832, 9.11722088], [92.78528595, 9.11750126], [92.7841568, 9.11750126], [92.7841568, 9.11778164], [92.78360748, 9.11777687], [92.78277588, 9.11861134], [92.78268433, 9.11863804], [92.78236389, 9.11873436], [92.78159332, 9.11923313], [92.78131866, 9.1193037], [92.78111267, 9.11972141], [92.78083038, 9.12000084], [92.77999878, 9.11999893], [92.77889252, 9.1208334], [92.77741241, 9.12110901], [92.7767868, 9.12159538], [92.77615356, 9.12221909], [92.77559662, 9.12277126], [92.77477264, 9.12339973], [92.77308655, 9.12478065], [92.7723999, 9.12505722], [92.77156067, 9.12553978], [92.77107239, 9.1260252], [92.77051544, 9.12651062], [92.7699585, 9.12720108], [92.7697525, 9.12741089], [92.76891327, 9.1276207], [92.76870728, 9.12727165], [92.76856995, 9.12651062], [92.76808167, 9.12553978], [92.76786804, 9.12540054], [92.76717377, 9.12561035], [92.76634216, 9.12595367], [92.76599121, 9.12609386], [92.76578522, 9.12567902], [92.76578522, 9.12526417], [92.7653656, 9.12491703], [92.7638855, 9.12388992], [92.76361084, 9.1236124], [92.76222229, 9.1236124], [92.76194763, 9.12389183], [92.76166534, 9.12388992], [92.76139069, 9.12416458], [92.7611084, 9.12416458], [92.76083374, 9.12444305], [92.76000214, 9.12444305], [92.75971985, 9.12472057], [92.75945282, 9.12500191], [92.7591629, 9.125], [92.75805664, 9.12611198], [92.75776672, 9.12611198], [92.75749969, 9.12639046], [92.75694275, 9.12639046], [92.75666809, 9.12667179], [92.75583649, 9.12667179], [92.75549316, 9.12679958], [92.75514221, 9.1266613], [92.75473022, 9.12638474], [92.75444794, 9.12596798], [92.753685, 9.12541676], [92.7527771, 9.12500191], [92.75110626, 9.12500191], [92.75020599, 9.12528038], [92.74846649, 9.1255579], [92.74777985, 9.12528038], [92.74749756, 9.12528038], [92.7472229, 9.12500191], [92.74666595, 9.12500191], [92.7463913, 9.12472057], [92.74611664, 9.12500191], [92.7444458, 9.12500191], [92.74415588, 9.12528038], [92.74388885, 9.12500191], [92.74333191, 9.12500191], [92.74304962, 9.12472057], [92.74250031, 9.12472057], [92.74222565, 9.12444305], [92.74118042, 9.12382984], [92.73986053, 9.12334538], [92.73887634, 9.12320995], [92.73658752, 9.12334538], [92.73583221, 9.1236124], [92.73555756, 9.1236124], [92.73527527, 9.12333298], [92.73500061, 9.1236124], [92.73472595, 9.1236124], [92.73438263, 9.12347031], [92.73332977, 9.12389183], [92.73305511, 9.12388992], [92.73222351, 9.12416458], [92.73166656, 9.12437725], [92.73139191, 9.12472057], [92.72833252, 9.12777805], [92.72833252, 9.12832928], [92.72750092, 9.12916565], [92.72692108, 9.12965775], [92.72657776, 9.13021183], [92.72629547, 9.13152695], [92.72622681, 9.13311958], [92.72644043, 9.13416195], [92.72650909, 9.13512993], [92.72622681, 9.13624001], [92.72580719, 9.13699722], [92.72553253, 9.13775826], [92.72540283, 9.13838005], [92.72490692, 9.13888168], [92.72413635, 9.1395607], [92.7227478, 9.14046097], [92.72261047, 9.14129066], [92.72225952, 9.14219093], [92.72222137, 9.14305496], [92.72027588, 9.14500141], [92.71972656, 9.14607239], [92.71952057, 9.14752674], [92.71952057, 9.14974213], [92.71944427, 9.15022469], [92.71916962, 9.15084934], [92.71881866, 9.15153122], [92.71847534, 9.15257931], [92.71833038, 9.15277767], [92.71833038, 9.15444088], [92.7183075, 9.15564728], [92.7183075, 9.1571703], [92.7181015, 9.15847969], [92.71817017, 9.15979958], [92.71844482, 9.16090679], [92.71872711, 9.16277599], [92.71900177, 9.16409111], [92.71927643, 9.16582108], [92.71949005, 9.16714096], [92.720047, 9.16879845], [92.72039795, 9.1704607], [92.72067261, 9.171772], [92.72081757, 9.17323112], [92.72081757, 9.17426968], [92.72094727, 9.17537975], [92.72116089, 9.17607021], [92.72110748, 9.17667198], [92.72110748, 9.17777729], [92.72083282, 9.17805576], [92.72083282, 9.17972183], [92.72110748, 9.18000031], [92.72110748, 9.18278027], [92.72083282, 9.18305588], [92.72083282, 9.18500042], [92.72055817, 9.18527794], [92.72055817, 9.1861124], [92.72027588, 9.18697166], [92.72013855, 9.1875906], [92.72006989, 9.18828678], [92.72006989, 9.18870068], [92.72000122, 9.18972206], [92.72000122, 9.19110966], [92.71971893, 9.19138813], [92.71971893, 9.19305515], [92.71944427, 9.19333267], [92.71943665, 9.19443989], [92.72055817, 9.19555473], [92.72055817, 9.19611073], [92.72110748, 9.19666672], [92.72110748, 9.19694519], [92.72138977, 9.1972208], [92.72138977, 9.19833279], [92.72110748, 9.19861126], [92.72110748, 9.19889069], [92.72083282, 9.19916725], [92.72083282, 9.19944477], [92.72055817, 9.19972134], [92.72055817, 9.19999886], [92.72027588, 9.20027733], [92.72027588, 9.20083141], [92.72020721, 9.20111084], [92.72027588, 9.20138931], [92.72027588, 9.20166683], [92.72055817, 9.2019453], [92.72055817, 9.2033329], [92.72042084, 9.20361137], [92.72042084, 9.20388985], [92.72055817, 9.20416546], [92.72055817, 9.20583439], [92.72027588, 9.20611191], [92.72027588, 9.20694447], [92.71971893, 9.20750046], [92.71971893, 9.20777798], [92.72027588, 9.20833397], [92.72027588, 9.20971966], [92.72055817, 9.21000004], [92.72055817, 9.21028042], [92.72083282, 9.2105608], [92.72083282, 9.21138954], [92.72055817, 9.21167088], [92.72055817, 9.21249962], [92.72083282, 9.21277809], [92.72083282, 9.2136097], [92.72110748, 9.21388817], [92.72110748, 9.21416569], [92.7216568, 9.21471977], [92.72166443, 9.21500015], [92.72194672, 9.21527767], [92.72250366, 9.21583366], [92.72249603, 9.21611023], [92.72277832, 9.21638775], [92.72277832, 9.21666622], [92.72305298, 9.21694374], [92.72305298, 9.21722221], [92.72393036, 9.21826553], [92.72455597, 9.21875191], [92.72497559, 9.21895885], [92.72566986, 9.21916676], [92.72646332, 9.21931744], [92.7271347, 9.21944523], [92.72777557, 9.21944523], [92.72805786, 9.21972275], [92.72944641, 9.21972275], [92.72972107, 9.21944523], [92.73000336, 9.21944523], [92.73027802, 9.21916676], [92.73055267, 9.21917057], [92.73110962, 9.2186079], [92.73166656, 9.21860981], [92.73194122, 9.21833229], [92.73305511, 9.21833229], [92.73332977, 9.21805668], [92.73361206, 9.21806145], [92.73388672, 9.21778107], [92.73443604, 9.21778107], [92.73501587, 9.21726131], [92.73509216, 9.21698284], [92.73543549, 9.21601486], [92.73571777, 9.21580696], [92.73592377, 9.21546078], [92.73626709, 9.2153101], [92.73722076, 9.21528053], [92.73750305, 9.21556091], [92.73805237, 9.21555424], [92.73833466, 9.21583366], [92.73860931, 9.21583366], [92.7388916, 9.21611023], [92.73944092, 9.21611023], [92.73972321, 9.21639061], [92.74028015, 9.21639061], [92.74054718, 9.21667099], [92.74194336, 9.21667099], [92.74223328, 9.21639061], [92.74250031, 9.21639061], [92.74276733, 9.21611023], [92.74305725, 9.21611023], [92.74333191, 9.21583366], [92.74416351, 9.21583366], [92.7452774, 9.21472168], [92.7452774, 9.21416569], [92.74555206, 9.21388817], [92.74555206, 9.2136097], [92.74610901, 9.21305561], [92.74611664, 9.21278], [92.74694824, 9.21194172], [92.74777985, 9.21194172], [92.74861145, 9.21278], [92.74861145, 9.21306133], [92.7491684, 9.21305561], [92.74944305, 9.21333218], [92.75, 9.21333027], [92.75055695, 9.21389008], [92.7508316, 9.21389008], [92.75138855, 9.21445084], [92.75166321, 9.21444416], [92.7519455, 9.21472168], [92.75222015, 9.21472168], [92.75250244, 9.21500015], [92.75498962, 9.21500015], [92.75527954, 9.21528053], [92.75611115, 9.21528053], [92.7563858, 9.21556091], [92.75723267, 9.21556091], [92.75749969, 9.21528053], [92.75805664, 9.21528053], [92.7583313, 9.21500015], [92.75888824, 9.21500015], [92.7591629, 9.21472168], [92.76527405, 9.21472168], [92.76555634, 9.21500015], [92.76583099, 9.21500015], [92.76611328, 9.21528053], [92.76667023, 9.21528053], [92.76692963, 9.21556091], [92.76721954, 9.21555424], [92.76777649, 9.21611023], [92.76805878, 9.21611023], [92.76860809, 9.21666622], [92.76860809, 9.21694374], [92.76916504, 9.21750069], [92.76916504, 9.21785164], [92.76950836, 9.21813011], [92.76985931, 9.21868324], [92.7703476, 9.21909809], [92.77069092, 9.21958447], [92.77111053, 9.22027874], [92.77111053, 9.22055531], [92.77166748, 9.2211113], [92.77166748, 9.22166729], [92.77138519, 9.22194481], [92.77138519, 9.22222328], [92.77111053, 9.2225008], [92.77111053, 9.22278118], [92.77083588, 9.22305489], [92.77046967, 9.22373581], [92.77053833, 9.22408295], [92.77083588, 9.22472095], [92.77083588, 9.22611141], [92.77111053, 9.22638893], [92.77111053, 9.22722054], [92.77139282, 9.22750092], [92.77139282, 9.22777939], [92.77153015, 9.22791767], [92.77166748, 9.22805977], [92.77222443, 9.228055], [92.77249908, 9.22833347], [92.77278137, 9.22833347], [92.77305603, 9.22861099], [92.77361298, 9.22861099], [92.77416992, 9.22916985], [92.77416992, 9.22945023], [92.77471924, 9.2300024], [92.77485657, 9.23092937], [92.77493286, 9.23113728], [92.77493286, 9.23141479], [92.77527618, 9.23194313], [92.77527618, 9.23305607], [92.77583313, 9.23361206], [92.77583313, 9.23416805], [92.77610779, 9.23444366], [92.77610016, 9.23471928], [92.77583313, 9.23499966], [92.77583313, 9.23527813], [92.77555847, 9.23555565], [92.77555847, 9.23610973], [92.77500153, 9.23666954], [92.77444458, 9.23666573], [92.77416992, 9.2369442], [92.77388763, 9.2369442], [92.77278137, 9.23805618], [92.77278137, 9.2383337], [92.77333069, 9.23888779], [92.77333069, 9.23944378], [92.77361298, 9.23972034], [92.77361298, 9.24027824], [92.77372742, 9.24061966], [92.77407074, 9.24069118], [92.77455902, 9.24069118], [92.77497864, 9.24041271], [92.77532196, 9.23985863], [92.77511597, 9.23930454], [92.77490997, 9.23910046], [92.77497864, 9.23888969], [92.77532196, 9.23882198], [92.77559662, 9.23882198], [92.77597046, 9.23888969], [92.7768631, 9.23924065], [92.77748108, 9.24020958], [92.7776947, 9.24089813], [92.77811432, 9.24165916], [92.77825165, 9.24228191], [92.77861023, 9.24333191], [92.77861023, 9.24416637], [92.77889252, 9.24443054], [92.77889252, 9.24528122], [92.77861023, 9.24555683], [92.77861023, 9.24611092], [92.77833557, 9.24638939], [92.77833557, 9.24666691], [92.77777863, 9.2472229], [92.77777863, 9.24750137], [92.77749634, 9.24777889], [92.77749634, 9.24833298], [92.77694702, 9.24888897], [92.77694702, 9.24972057], [92.7766571, 9.25000095], [92.7766571, 9.25028133], [92.77639008, 9.25055695], [92.77639008, 9.25111103], [92.77500153, 9.25250053], [92.77500153, 9.25388908], [92.77471924, 9.2541666], [92.77471924, 9.25444317], [92.77388763, 9.25527668], [92.77388763, 9.25611115], [92.77471924, 9.25694561], [92.77639008, 9.25694561], [92.77700806, 9.25684834], [92.77763367, 9.2567091], [92.77819061, 9.25636196], [92.77861023, 9.25580788], [92.77861023, 9.2547226], [92.77889252, 9.25444317], [92.77889252, 9.2541666], [92.77944183, 9.25361061], [92.77944183, 9.25333118], [92.78032684, 9.25272942], [92.7804718, 9.25231171], [92.7806778, 9.25196648], [92.78096008, 9.25148201], [92.78102875, 9.25092888], [92.78116608, 9.25023556], [92.78144073, 9.24982071], [92.78192902, 9.24912834], [92.78263092, 9.2484417], [92.78304291, 9.24802017], [92.78374481, 9.2478838], [92.78443909, 9.24760628], [92.78499603, 9.24705219], [92.78569031, 9.24663734], [92.78638458, 9.24608326], [92.78694153, 9.24555683], [92.78749847, 9.24500084], [92.78749847, 9.24472046], [92.78778076, 9.24444389], [92.78778076, 9.24416637]]], [[[93.54728699, 8.02805233], [93.54715729, 8.0277071], [93.54715729, 8.02722168], [93.54777527, 8.02666569], [93.5486145, 8.02666569], [93.54888916, 8.02694416], [93.54944611, 8.02694416], [93.54972076, 8.02722168], [93.55000305, 8.02722168], [93.55027771, 8.02750015], [93.55055237, 8.02722168], [93.55110931, 8.02722168], [93.5513916, 8.02694416], [93.55194092, 8.02694416], [93.55222321, 8.02666569], [93.55361176, 8.02667046], [93.55388641, 8.02639008], [93.55444336, 8.02639008], [93.55500031, 8.02582932], [93.55527496, 8.02583408], [93.55555725, 8.02555561], [93.55583191, 8.02556038], [93.55638885, 8.02499962], [93.55665588, 8.02499962], [93.5569458, 8.02471924], [93.5577774, 8.02471924], [93.55805206, 8.02499962], [93.55916595, 8.02499962], [93.55944824, 8.02471924], [93.56027985, 8.0247221], [93.5605545, 8.02444363], [93.5605545, 8.02416801], [93.56083679, 8.02388763], [93.56083679, 8.02361202], [93.56111145, 8.02333355], [93.56166077, 8.02333069], [93.56222534, 8.02388763], [93.56222534, 8.02416801], [93.5625, 8.02444363], [93.56254578, 8.02477169], [93.56276703, 8.02499962], [93.56305695, 8.02499962], [93.5633316, 8.02471924], [93.56361389, 8.0247221], [93.56472015, 8.02361202], [93.56472015, 8.02333355], [93.56500244, 8.02305603], [93.56500244, 8.02222157], [93.5652771, 8.02194309], [93.5652771, 8.02138996], [93.56555176, 8.02111244], [93.56555176, 8.02083397], [93.56583405, 8.02055454], [93.56583405, 8.02027702], [93.5661087, 8.01999855], [93.5661087, 8.01972103], [93.56639099, 8.01944637], [93.56639099, 8.01777744], [93.56694794, 8.01722336], [93.56694794, 8.01694489], [93.56666565, 8.01666737], [93.56666565, 8.01555538], [93.56833649, 8.01388931], [93.56833649, 8.01362038], [93.56973267, 8.01222134], [93.57027435, 8.01222324], [93.57055664, 8.01194477], [93.5708313, 8.01194477], [93.57111359, 8.01166725], [93.57138824, 8.01167107], [93.57174683, 8.01109886], [93.57175446, 8.01041126], [93.57182312, 8.00840092], [93.57250214, 8.00777912], [93.57250214, 8.00722313], [93.57416534, 8.0055542], [93.57416534, 8.00500011], [93.57444763, 8.00471973], [93.57444763, 8.00444412], [93.57472229, 8.00416565], [93.57472229, 8.00388813], [93.57527924, 8.00333023], [93.57527924, 8.00305557], [93.57555389, 8.00277805], [93.57554626, 8.00249958], [93.57583618, 8.00222015], [93.57583618, 8.00194359], [93.57624817, 8.00117779], [93.5763855, 8.00048542], [93.57666779, 8.0], [93.57639313, 7.9997201], [93.57805634, 7.99805593], [93.57833099, 7.99806023], [93.57917023, 7.99721909], [93.57951355, 7.99652719], [93.58000183, 7.99527788], [93.58000183, 7.99472094], [93.58027649, 7.99444294], [93.58027649, 7.9941678], [93.58110809, 7.99333286], [93.58110809, 7.99305487], [93.58139038, 7.99277687], [93.58167267, 7.99278021], [93.5827713, 7.99167013], [93.5827713, 7.9911108], [93.58249664, 7.99083281], [93.58249664, 7.99055481], [93.58222198, 7.99027681], [93.58222198, 7.98972082], [93.58194733, 7.98944521], [93.58194733, 7.98861122], [93.58166504, 7.98833323], [93.58166504, 7.98694515], [93.58194733, 7.98666716], [93.58194733, 7.98638916], [93.58167267, 7.98611116], [93.58166504, 7.98527718], [93.58305359, 7.9838891], [93.58304596, 7.98332977], [93.58083344, 7.9811101], [93.58055878, 7.9811101], [93.58027649, 7.9808321], [93.58027649, 7.98055696], [93.58000183, 7.98027897], [93.58000183, 7.98000097], [93.57972717, 7.9788909], [93.57972717, 7.97778082], [93.58000183, 7.97750902], [93.58000183, 7.97722006], [93.58139038, 7.97583389], [93.58194733, 7.97583389], [93.58222198, 7.9755559], [93.58222198, 7.97222185], [93.58305359, 7.97138977], [93.58305359, 7.97027779], [93.58255768, 7.96985197], [93.58200073, 7.96950102], [93.58213806, 7.96881008], [93.58213806, 7.96839094], [93.58164978, 7.96819019], [93.58082581, 7.96806002], [93.58000183, 7.96722078], [93.58000183, 7.96666813], [93.57971954, 7.96639013], [93.57972717, 7.9658308], [93.57944489, 7.96555519], [93.57944489, 7.96527719], [93.57978821, 7.96395111], [93.58034515, 7.96339893], [93.58125305, 7.96332884], [93.58187866, 7.96297979], [93.58187866, 7.96242619], [93.5817337, 7.96138716], [93.58159637, 7.96048021], [93.58139038, 7.9595108], [93.58139038, 7.95881796], [93.5817337, 7.95826387], [93.58139038, 7.95750093], [93.58027649, 7.95638895], [93.58027649, 7.95611095], [93.58000183, 7.95583296], [93.58000183, 7.95500088], [93.57971954, 7.95472288], [93.57971954, 7.95444489], [93.57982635, 7.95357418], [93.58052063, 7.9527421], [93.58100891, 7.95253515], [93.58166504, 7.95222187], [93.58166504, 7.95138788], [93.58194733, 7.95110989], [93.58194733, 7.94999981], [93.58139038, 7.94860983], [93.58139038, 7.94833422], [93.58110809, 7.94805622], [93.58110809, 7.94777822], [93.58082581, 7.94750881], [93.58082581, 7.94528008], [93.58110809, 7.94500017], [93.58110809, 7.94444418], [93.58055878, 7.94388819], [93.58055878, 7.94277811], [93.58027649, 7.94250011], [93.58027649, 7.94194412], [93.58055878, 7.94166517], [93.58055878, 7.94139004], [93.58083344, 7.94111204], [93.58083344, 7.9399991], [93.58110809, 7.93972111], [93.58110809, 7.93944597], [93.58139038, 7.93916798], [93.58139038, 7.93833303], [93.58082581, 7.9377799], [93.58055878, 7.9377799], [93.57943726, 7.93666983], [93.57943726, 7.93361092], [93.57888794, 7.93305492], [93.57805634, 7.93305922], [93.57776642, 7.93278122], [93.57749939, 7.93278122], [93.5772171, 7.93250084], [93.5772171, 7.93220901], [93.57666779, 7.93166685], [93.57666779, 7.93111086], [93.57694244, 7.93083286], [93.57694244, 7.93055487], [93.57749939, 7.93000078], [93.57776642, 7.93000078], [93.57833099, 7.92944002], [93.57777405, 7.9288888], [93.57777405, 7.9286108], [93.57749939, 7.92833281], [93.57722473, 7.92833281], [93.57694244, 7.9286108], [93.57666779, 7.9286108], [93.57611084, 7.92917109], [93.57583618, 7.92916679], [93.57555389, 7.92944479], [93.57472229, 7.92944479], [93.57416534, 7.9288888], [93.57389069, 7.92889118], [93.57250214, 7.93028116], [93.57221985, 7.93027878], [93.5688858, 7.93361092], [93.56861115, 7.93361092], [93.56777954, 7.9344449], [93.56749725, 7.93444109], [93.56667328, 7.93527889], [93.56639099, 7.93527889], [93.5661087, 7.93556023], [93.56583405, 7.93555498], [93.56555176, 7.93583298], [93.56500244, 7.93583298], [93.56472015, 7.93611097], [93.56445313, 7.93611097], [93.56388855, 7.93666983], [93.56361389, 7.93666697], [93.56305695, 7.93722105], [93.56276703, 7.93722105], [93.56223297, 7.9377799], [93.56222534, 7.93805504], [93.56194305, 7.93833303], [93.56223297, 7.93861103], [93.56222534, 7.93916798], [93.5588913, 7.94250011], [93.5588913, 7.94277811], [93.55722046, 7.94444418], [93.5569458, 7.94444418], [93.55638885, 7.94500017], [93.55583191, 7.94500017], [93.55555725, 7.94528008], [93.55500031, 7.94527817], [93.5533371, 7.94694424], [93.5533371, 7.94721985], [93.55278015, 7.94777822], [93.55278015, 7.94805622], [93.55249786, 7.94833422], [93.55249786, 7.94860983], [93.55194092, 7.94917107], [93.55166626, 7.94916582], [93.55023193, 7.94970179], [93.54968262, 7.94970179], [93.54884338, 7.95004988], [93.5486145, 7.9505558], [93.54805756, 7.95110989], [93.5477829, 7.95110989], [93.54722595, 7.95167112], [93.54666138, 7.95188093], [93.54633331, 7.95160007], [93.54555511, 7.95138788], [93.54499817, 7.95194006], [93.54499817, 7.95277882], [93.54472351, 7.95305395], [93.54471588, 7.95332098], [93.54277802, 7.95528078], [93.54250336, 7.95527887], [93.54194641, 7.95583296], [93.54166412, 7.95583296], [93.54138947, 7.95611095], [93.54111481, 7.95611095], [93.54083252, 7.95638895], [93.54027557, 7.95638895], [93.53971863, 7.95694494], [93.53944397, 7.95694494], [93.53805542, 7.95833302], [93.53805542, 7.959445], [93.53833008, 7.959723], [93.53805542, 7.96000099], [93.53806305, 7.96083117], [93.53749847, 7.96139097], [93.53749847, 7.96166706], [93.53639221, 7.96277714], [93.53555298, 7.96361113], [93.53527832, 7.96361113], [93.53499603, 7.96389198], [93.53472137, 7.96389198], [93.53444672, 7.96416998], [93.53416443, 7.96416712], [93.53388977, 7.96444511], [93.53193665, 7.96444082], [93.53083038, 7.96557093], [93.53055573, 7.96555519], [93.53028107, 7.96583319], [93.52999878, 7.96583319], [93.52861023, 7.96722078], [93.5283432, 7.96722078], [93.52777863, 7.96778011], [93.52639008, 7.96778011], [93.52610779, 7.96806002], [93.52527618, 7.9680562], [93.52500153, 7.9683342], [93.52471924, 7.96831989], [93.52416992, 7.96889019], [93.52416992, 7.96917009], [93.52500153, 7.96999979], [93.52471924, 7.97027779], [93.52471924, 7.97055578], [93.52444458, 7.97083378], [93.52416992, 7.97055578], [93.52388763, 7.97056007], [93.52361298, 7.97028017], [93.52278137, 7.97028017], [93.52249146, 7.97056007], [93.52194214, 7.97055578], [93.52166748, 7.97083378], [93.52138519, 7.97083378], [93.52111053, 7.97111177], [93.52083588, 7.97111177], [93.52027893, 7.97166586], [93.52027893, 7.97194386], [93.51833344, 7.97388792], [93.51673889, 7.97451496], [93.51611328, 7.97465086], [93.51583099, 7.9749999], [93.51667023, 7.97583389], [93.51694489, 7.97583389], [93.51721954, 7.97610998], [93.51694489, 7.97638798], [93.51694489, 7.97666597], [93.51667023, 7.97694397], [93.51667786, 7.97722006], [93.51638794, 7.97749996], [93.51638794, 7.97805595], [93.51611328, 7.97833395], [93.51611328, 7.97861004], [93.51555634, 7.9791708], [93.51527405, 7.97916603], [93.51499939, 7.97944403], [93.51472473, 7.97944403], [93.51444244, 7.97972202], [93.51389313, 7.97972012], [93.51333618, 7.98028088], [93.51304626, 7.98028088], [93.51194763, 7.98139095], [93.51166534, 7.98138905], [93.5111084, 7.98194504], [93.51082611, 7.98193979], [93.50888824, 7.98389101], [93.50805664, 7.9838891], [93.50723267, 7.98472118], [93.50722504, 7.98527718], [93.50749969, 7.98555517], [93.50749969, 7.98583317], [93.50777435, 7.98611116], [93.50777435, 7.98666716], [93.5083313, 7.98722315], [93.5083313, 7.98861122], [93.50805664, 7.98888922], [93.50805664, 7.98972082], [93.50776672, 7.9900012], [93.50777435, 7.99027681], [93.50749969, 7.99055481], [93.50749969, 7.99083281], [93.50722504, 7.9911108], [93.50722504, 7.9913888], [93.5063858, 7.99222088], [93.5063858, 7.99249887], [93.50527954, 7.99360895], [93.50527954, 7.99388981], [93.50666809, 7.99527788], [93.50666809, 7.99610901], [93.50723267, 7.99666977], [93.50776672, 7.99666977], [93.5083313, 7.99610901], [93.50861359, 7.99611187], [93.50971985, 7.99722195], [93.51027679, 7.99721909], [93.51055145, 7.99749994], [93.51082611, 7.99749994], [93.51139069, 7.99806023], [93.51167297, 7.99806023], [93.51249695, 7.99888992], [93.51333618, 7.99888992], [93.51412964, 7.99816084], [93.51448059, 7.99772978], [93.51454926, 7.99697781], [93.51448059, 7.99607515], [93.51461792, 7.99517298], [93.51538086, 7.99461699], [93.51600647, 7.9943409], [93.51698303, 7.99385118], [93.5175705, 7.99361181], [93.51763916, 7.9934721], [93.51791382, 7.993402], [93.51833344, 7.99312592], [93.51889038, 7.99361181], [93.51916504, 7.99361181], [93.51999664, 7.99444294], [93.51999664, 7.99472094], [93.52027893, 7.99499989], [93.52027893, 7.99555111], [93.5222168, 7.99749994], [93.5222168, 7.99777985], [93.52361298, 7.99916983], [93.52388763, 7.99916601], [93.52416992, 7.99944401], [93.52443695, 7.99943876], [93.52555847, 8.0], [93.52583313, 8.00055599], [93.52583313, 8.00111198], [93.52666473, 8.00194359], [93.5266571, 8.00222015], [93.52694702, 8.00249958], [93.52694702, 8.00305557], [93.52722168, 8.00333214], [93.52722168, 8.00416565], [93.52749634, 8.00444412], [93.52749634, 8.00472164], [93.52771759, 8.00494289], [93.52805328, 8.00528145], [93.52889252, 8.00528145], [93.52916718, 8.00556087], [93.52999878, 8.0055542], [93.53028107, 8.00583458], [93.53055573, 8.00583458], [93.53111267, 8.00638771], [93.53111267, 8.00750065], [93.53083038, 8.00777912], [93.53083038, 8.00833225], [93.53055573, 8.00861073], [93.53055573, 8.01222324], [93.53028107, 8.01249886], [93.53028107, 8.01555538], [93.52999878, 8.0158329], [93.52999878, 8.01611137], [93.52972412, 8.01638889], [93.52913666, 8.01733971], [93.52872467, 8.0178299], [93.52837372, 8.01824665], [93.52823639, 8.01873207], [93.52844238, 8.01928616], [93.52858734, 8.01984024], [93.52872467, 8.02032471], [93.52899933, 8.02094746], [93.52941895, 8.02136517], [93.52916718, 8.02194309], [93.52944183, 8.02222157], [93.52944183, 8.02250195], [93.52971649, 8.02279091], [93.52972412, 8.02305603], [93.53028107, 8.02361202], [93.53028107, 8.02388763], [93.53037262, 8.02398109], [93.53056335, 8.02416992], [93.53083038, 8.02416801], [93.53111267, 8.02444363], [93.53166962, 8.02444363], [93.53194427, 8.0247221], [93.53221893, 8.02471924], [93.53250122, 8.02499962], [93.53305817, 8.02499962], [93.53333282, 8.02471924], [93.53416443, 8.0247221], [93.53472137, 8.02416801], [93.53499603, 8.02416992], [93.53527832, 8.02388954], [93.53527832, 8.02361202], [93.53555298, 8.02333355], [93.53555298, 8.02277756], [93.53583527, 8.02250004], [93.5358429, 8.02222157], [93.53639221, 8.02166462], [93.53666687, 8.02167034], [93.53694153, 8.02139187], [93.53694153, 8.02028179], [93.53721619, 8.01999855], [93.53666687, 8.01943016], [93.53666687, 8.01916695], [93.53639221, 8.01888943], [93.53639221, 8.01861095], [93.53749847, 8.01749897], [93.53888702, 8.01750088], [93.53916931, 8.01722145], [93.53971863, 8.01722336], [93.54000092, 8.01694489], [93.54055786, 8.01694489], [93.54250336, 8.0150013], [93.54250336, 8.01472092], [93.54277802, 8.0144453], [93.54277802, 8.01361084], [93.54250336, 8.01333332], [93.54250336, 8.01305485], [93.54222107, 8.01277733], [93.54222107, 8.01249886], [93.54194641, 8.01222324], [93.54194641, 8.01111126], [93.54222107, 8.01083279], [93.54222107, 8.01055527], [93.54250336, 8.0102787], [93.54250336, 8.01000118], [93.54277802, 8.00972271], [93.54277802, 8.00944519], [93.54305267, 8.00916672], [93.54305267, 8.00805664], [93.54277802, 8.00778103], [93.54277802, 8.00722027], [93.54305267, 8.0069437], [93.54305267, 8.00638771], [93.54333496, 8.00611019], [93.54333496, 8.00583458], [93.54389191, 8.00527763], [93.54389191, 8.00500011], [93.54582977, 8.00306129], [93.54611206, 8.00306129], [93.54638672, 8.00277996], [93.54666138, 8.00277996], [93.5477829, 8.00168037], [93.5477829, 8.00139046], [93.54805756, 8.00111198], [93.54805756, 8.00083447], [93.54833221, 8.00055599], [93.54833221, 8.00027847], [93.54888916, 8.0], [93.54866791, 7.99864197], [93.54846191, 7.99850512], [93.54853821, 7.99768877], [93.54930115, 7.9973402], [93.54978943, 7.99713278], [93.55027771, 7.99678612], [93.55034637, 7.99643993], [93.55076599, 7.99623013], [93.55117798, 7.99699593], [93.55131531, 7.99775696], [93.55132294, 7.99866009], [93.55166626, 7.9991498], [93.55194092, 8.0], [93.55166626, 8.00027847], [93.55166626, 8.00111198], [93.5513916, 8.0013876], [93.5513916, 8.00222206], [93.55110931, 8.00249958], [93.55110931, 8.00333214], [93.55083466, 8.00361156], [93.55083466, 8.00416565], [93.55055237, 8.00444412], [93.55055237, 8.0055542], [93.55083466, 8.00583458], [93.55194092, 8.00695133], [93.55215454, 8.00715923], [93.55222321, 8.00778103], [93.55194092, 8.00806141], [93.55145264, 8.00806141], [93.55075836, 8.00840473], [93.55055237, 8.00861073], [93.55055237, 8.00916672], [93.55027771, 8.00944519], [93.55027771, 8.01000118], [93.55000305, 8.0102787], [93.55000305, 8.01111126], [93.54972076, 8.01138878], [93.54972076, 8.01194477], [93.54950714, 8.01242065], [93.5497818, 8.01269913], [93.55040741, 8.01297665], [93.55047607, 8.01353073], [93.55005646, 8.01366997], [93.54943848, 8.01353073], [93.54915619, 8.01416016], [93.54862976, 8.01415062], [93.54845428, 8.01507854], [93.54838562, 8.01542473], [93.54824066, 8.01577187], [93.54824066, 8.01611805], [93.54810333, 8.016325], [93.54789734, 8.01667404], [93.54777527, 8.01694489], [93.5483017, 8.01789093], [93.5483017, 8.01851082], [93.54843903, 8.01927662], [93.54864502, 8.01955509], [93.54892731, 8.01990128], [93.54892731, 8.02039146], [93.5483017, 8.0203867], [93.54781342, 8.02059364], [93.54733276, 8.02073097], [93.54676819, 8.02143097], [93.5464859, 8.02205086], [93.54582977, 8.02194309], [93.54389191, 8.02388763], [93.54389191, 8.02443886], [93.54332733, 8.02499962], [93.54333496, 8.02527809], [93.54472351, 8.02666569], [93.54471588, 8.02722168], [93.54479218, 8.02750015], [93.54479218, 8.02784634], [93.54506683, 8.02805424], [93.54576874, 8.02805424], [93.54590607, 8.02798462], [93.54624939, 8.02798462], [93.54646301, 8.02832985], [93.54653168, 8.02854156], [93.54688263, 8.02882195], [93.54722595, 8.02854156], [93.54728699, 8.02805233]]], [[[93.57861328, 8.12527943], [93.57940674, 8.12483978], [93.57981873, 8.12491322], [93.58030701, 8.12498283], [93.58030701, 8.12470531], [93.58058167, 8.12429047], [93.58080292, 8.12393856], [93.58065796, 8.12338829], [93.58079529, 8.12283421], [93.58110809, 8.12222099], [93.58139038, 8.12194538], [93.58139038, 8.12138939], [93.58194733, 8.12083054], [93.58194733, 8.12055492], [93.58277893, 8.11958408], [93.58354187, 8.11778069], [93.58486176, 8.11625862], [93.58514404, 8.11535835], [93.58611298, 8.11417103], [93.58666992, 8.11417103], [93.58721924, 8.11361027], [93.58721924, 8.11250019], [93.58750153, 8.11222172], [93.58750153, 8.1119442], [93.58777618, 8.11166573], [93.58786011, 8.11061096], [93.58786011, 8.11012459], [93.5881424, 8.11006165], [93.58821106, 8.10991955], [93.58873749, 8.10935116], [93.58868408, 8.10858917], [93.58889008, 8.1077776], [93.58889771, 8.10639], [93.5891571, 8.10610962], [93.58916473, 8.10499954], [93.59021759, 8.10208035], [93.59049225, 8.10027981], [93.59056854, 8.09889221], [93.59055328, 8.09694481], [93.59055328, 8.0961113], [93.58916473, 8.09472084], [93.58972168, 8.09416676], [93.59027863, 8.09417152], [93.59111023, 8.09333134], [93.59083557, 8.09305477], [93.59083557, 8.09277916], [93.59055328, 8.09250069], [93.59055328, 8.09193993], [93.59083557, 8.09166718], [93.59083557, 8.0913887], [93.59055328, 8.09111118], [93.59055328, 8.09055519], [93.59083557, 8.09027863], [93.5908432, 8.08971977], [93.59055328, 8.08944511], [93.59055328, 8.08916664], [93.59083557, 8.08888912], [93.5908432, 8.08833027], [93.59055328, 8.08805656], [93.59055328, 8.0872221], [93.59083557, 8.08694363], [93.59083557, 8.08611012], [93.59055328, 8.08583355], [93.59055328, 8.08305645], [93.5908432, 8.08278275], [93.5908432, 8.0819416], [93.59111023, 8.08166599], [93.59111023, 8.08111], [93.59139252, 8.08083439], [93.59139252, 8.08055592], [93.59194183, 8.07999992], [93.59194183, 8.07971001], [93.59222412, 8.07944393], [93.59222412, 8.07916641], [93.59249878, 8.07888985], [93.59249878, 8.07777977], [93.59278107, 8.07750034], [93.59278107, 8.07694435], [93.59305573, 8.07666779], [93.59305573, 8.07639027], [93.59278107, 8.07611179], [93.59278107, 8.0755558], [93.59249878, 8.07528019], [93.59249878, 8.07499886], [93.59222412, 8.07472134], [93.59222412, 8.07444572], [93.59194183, 8.07416534], [93.59194183, 8.07388973], [93.59166718, 8.07360935], [93.59166718, 8.07333279], [93.59139252, 8.07305527], [93.59139252, 8.07249928], [93.59111023, 8.0722208], [93.59111023, 8.07166672], [93.59083557, 8.0713892], [93.5908432, 8.07000065], [93.59055328, 8.06972122], [93.59083557, 8.06944466], [93.59083557, 8.06861115], [93.59111023, 8.06833267], [93.59111023, 8.0672226], [93.59139252, 8.06583309], [93.59166718, 8.06555462], [93.59166718, 8.06527901], [93.59194183, 8.06500053], [93.59194183, 8.06471062], [93.59333038, 8.06333256], [93.59361267, 8.06333256], [93.59388733, 8.06305695], [93.59416962, 8.06305885], [93.59443665, 8.06278133], [93.5947113, 8.06278133], [93.59527588, 8.06221962], [93.59527588, 8.06194496], [93.59555817, 8.06166744], [93.59555817, 8.06138802], [93.59583282, 8.06110954], [93.59583282, 8.06083202], [93.59610748, 8.06055737], [93.59610748, 8.06000042], [93.59638977, 8.06000042], [93.59750366, 8.05888844], [93.59749603, 8.05832958], [93.59777832, 8.05805588], [93.59777832, 8.05611229], [93.59860992, 8.05527782], [93.59860992, 8.05500031], [93.59889221, 8.05472183], [93.59860992, 8.05444431], [93.59889221, 8.05416584], [93.59889221, 8.05389023], [93.59916687, 8.05360985], [93.59944153, 8.05360985], [93.59999847, 8.05305576], [93.59999847, 8.05277824], [93.59972382, 8.05249977], [93.59972382, 8.05194378], [93.59944153, 8.05166626], [93.59944153, 8.05138779], [93.59971619, 8.05111027], [93.59972382, 8.0508337], [93.59999847, 8.05055618], [93.60056305, 8.05056], [93.60083771, 8.05027962], [93.60111237, 8.05027962], [93.60138702, 8.05000019], [93.60138702, 8.0494442], [93.60111237, 8.04916763], [93.60111237, 8.04833412], [93.60083008, 8.04805565], [93.60083008, 8.04722118], [93.60055542, 8.04694557], [93.60055542, 8.04555511], [93.60083008, 8.04527664], [93.60083771, 8.04472065], [93.60111237, 8.04444313], [93.60111237, 8.04416656], [93.59889221, 8.04194546], [93.59889221, 8.04166698], [93.59805298, 8.04083347], [93.59750366, 8.04083347], [93.59722137, 8.040555], [93.5966568, 8.04056168], [93.59500122, 8.03889084], [93.59500122, 8.03861141], [93.59471893, 8.03833294], [93.59388733, 8.03805733], [93.59346771, 8.0379858], [93.59278107, 8.0377903], [93.59249878, 8.03777885], [93.59166718, 8.03861141], [93.59166718, 8.03888893], [93.59139252, 8.0391674], [93.59139252, 8.0397234], [93.59055328, 8.040555], [93.59055328, 8.04083061], [93.58999634, 8.04139137], [93.58999634, 8.04166889], [93.58889008, 8.04277706], [93.58889008, 8.04305458], [93.58860779, 8.04333305], [93.58860779, 8.04444122], [93.58777618, 8.04528046], [93.58750153, 8.04527664], [93.58694458, 8.04583263], [93.58682251, 8.04679489], [93.58654785, 8.04728127], [93.5861969, 8.04762936], [93.58599091, 8.04797268], [93.58571625, 8.04831982], [93.5851593, 8.04915237], [93.58487701, 8.04935932], [93.58446503, 8.04929066], [93.58418274, 8.04915237], [93.58405304, 8.04935932], [93.58410645, 8.04978085], [93.58355713, 8.0496397], [93.58335114, 8.04908085], [93.58265686, 8.04901314], [93.58222198, 8.04944134], [93.58222198, 8.04972172], [93.58194733, 8.05000019], [93.58194733, 8.05027771], [93.58139038, 8.0508337], [93.58139038, 8.05111217], [93.58110809, 8.05138779], [93.58110809, 8.05194378], [93.58083344, 8.05222225], [93.58083344, 8.05305576], [93.58055878, 8.05333424], [93.58055878, 8.05360985], [93.58055115, 8.05389214], [93.58082581, 8.05430889], [93.58110046, 8.05486298], [93.58110046, 8.05514145], [93.58087921, 8.05527973], [93.5803833, 8.05545807], [93.57997131, 8.05552673], [93.57982635, 8.05601215], [93.58030701, 8.05616474], [93.58030701, 8.05651093], [93.58003235, 8.05692959], [93.5796814, 8.05692768], [93.57919312, 8.0569973], [93.57892609, 8.05788326], [93.57836914, 8.05809116], [93.57781219, 8.05788326], [93.57725525, 8.05753708], [93.57666779, 8.05778122], [93.57639313, 8.05778122], [93.57554626, 8.05860996], [93.57555389, 8.05888844], [93.57527924, 8.05916595], [93.57527924, 8.05972195], [93.57389069, 8.06110954], [93.57389069, 8.06166744], [93.5736084, 8.06194496], [93.57360077, 8.06221962], [93.57333374, 8.06250095], [93.57333374, 8.06277561], [93.57277679, 8.0633297], [93.57277679, 8.06388855], [93.57250214, 8.06416702], [93.57250214, 8.06471062], [93.57221985, 8.06499863], [93.57221985, 8.06555462], [93.57194519, 8.06583309], [93.57194519, 8.06611061], [93.5716629, 8.06638908], [93.5716629, 8.0672226], [93.57194519, 8.06750107], [93.57194519, 8.06777668], [93.57250214, 8.06916714], [93.57250214, 8.06944466], [93.57277679, 8.06972122], [93.57277679, 8.07000065], [93.57305908, 8.07027721], [93.57305908, 8.07055473], [93.57277679, 8.07083321], [93.57277679, 8.07111073], [93.57333374, 8.07166672], [93.57332611, 8.07194138], [93.57369995, 8.07231522], [93.57417297, 8.07277966], [93.57444763, 8.07277966], [93.57472229, 8.07306004], [93.57527924, 8.07305527], [93.57555389, 8.07333279], [93.57611084, 8.07333279], [93.5763855, 8.07361126], [93.57666779, 8.07360935], [93.57694244, 8.07390118], [93.57917023, 8.07390118], [93.57943726, 8.07360935], [93.57971954, 8.07361126], [93.58027649, 8.07305527], [93.58055878, 8.07306004], [93.58082581, 8.07277966], [93.58110809, 8.07277966], [93.58131409, 8.07305527], [93.58145142, 8.07354069], [93.58138275, 8.07416534], [93.58131409, 8.07492733], [93.58130646, 8.07527065], [93.58152008, 8.07603645], [93.58138275, 8.07652187], [93.58158875, 8.07713985], [93.58138275, 8.07790756], [93.5810318, 8.0780468], [93.58047485, 8.07818317], [93.58005524, 8.07818317], [93.57971954, 8.07833385], [93.58000183, 8.07861233], [93.58000183, 8.07944107], [93.58055878, 8.07999992], [93.58103943, 8.08020687], [93.58139038, 8.08041477], [93.58145905, 8.08069324], [93.58103943, 8.08069324], [93.58027649, 8.08083439], [93.57945251, 8.08208275], [93.57917023, 8.08236122], [93.57875824, 8.08256817], [93.57826996, 8.08277607], [93.57798767, 8.08326054], [93.57771301, 8.08346939], [93.57750702, 8.08374691], [93.57736206, 8.08409309], [93.5770874, 8.08430099], [93.57688141, 8.08478642], [93.57666779, 8.08499336], [93.5762558, 8.08533955], [93.57604218, 8.08575726], [93.57569885, 8.08596039], [93.57549286, 8.0865202], [93.57541656, 8.08673], [93.57492828, 8.08658886], [93.57444763, 8.0872221], [93.57416534, 8.08750057], [93.5737381, 8.08882046], [93.57346344, 8.08916664], [93.57318115, 8.08937645], [93.57297516, 8.08965206], [93.57276154, 8.09013653], [93.57269287, 8.09055519], [93.57248688, 8.09076214], [93.57213593, 8.09048367], [93.57206726, 8.09013653], [93.57206726, 8.08986187], [93.57110596, 8.08971977], [93.57055664, 8.09027863], [93.57055664, 8.09055519], [93.56999969, 8.09111118], [93.56999969, 8.0913887], [93.57027435, 8.09166718], [93.57027435, 8.09333324], [93.56999969, 8.09360886], [93.56999969, 8.09388924], [93.56972504, 8.09416676], [93.56972504, 8.09444523], [93.56944275, 8.09472084], [93.56944275, 8.09500122], [93.56916809, 8.09527683], [93.56916809, 8.0961113], [93.56944275, 8.09638882], [93.56944275, 8.09694481], [93.56972504, 8.09722328], [93.56972504, 8.09749889], [93.57055664, 8.09833336], [93.57055664, 8.09861088], [93.57111359, 8.09916687], [93.57111359, 8.09944534], [93.5716629, 8.09999943], [93.5716629, 8.10027695], [93.57194519, 8.10055542], [93.57195282, 8.10111237], [93.57221985, 8.10138988], [93.57221985, 8.10305595], [93.57250214, 8.10333443], [93.57250214, 8.10388756], [93.57277679, 8.10416794], [93.57277679, 8.10472202], [93.57305908, 8.10499954], [93.57305908, 8.10555553], [93.57333374, 8.10583401], [93.57333374, 8.10666561], [93.5736084, 8.10694408], [93.5736084, 8.10805607], [93.57367706, 8.10833168], [93.57402802, 8.10868073], [93.57485962, 8.10902691], [93.57514191, 8.10929966], [93.57514191, 8.10978985], [93.57493591, 8.10993195], [93.57460785, 8.1097517], [93.57417297, 8.10951042], [93.5736084, 8.10923386], [93.57250214, 8.10888767], [93.57221985, 8.10854244], [93.57194519, 8.1077776], [93.57195282, 8.10750008], [93.5716629, 8.1072197], [93.5716629, 8.10694408], [93.5708313, 8.10611153], [93.57055664, 8.10611153], [93.56833649, 8.10833359], [93.56833649, 8.10861015], [93.5680542, 8.10888767], [93.5680542, 8.10916615], [93.56777954, 8.10944366], [93.56778717, 8.10972023], [93.56749725, 8.11000919], [93.56749725, 8.11027813], [93.5672226, 8.11055565], [93.5672226, 8.11083221], [93.56555176, 8.11250019], [93.56555176, 8.11277771], [93.56500244, 8.11333466], [93.56500244, 8.11361027], [93.56416321, 8.11444378], [93.56388855, 8.11444378], [93.56361389, 8.11472321], [93.5633316, 8.11472034], [93.56305695, 8.11500072], [93.56277466, 8.11500072], [93.56222534, 8.11555672], [93.56222534, 8.11583233], [93.56194305, 8.1161108], [93.56194305, 8.11666679], [93.56166077, 8.11693954], [93.5616684, 8.11777878], [93.56138611, 8.11805534], [93.56138611, 8.11861134], [93.5616684, 8.11888885], [93.5616684, 8.11944485], [93.56194305, 8.11972332], [93.56194305, 8.12000084], [93.56277466, 8.1208334], [93.56361389, 8.1208334], [93.56388855, 8.12111092], [93.56416321, 8.12111092], [93.56445313, 8.1213913], [93.56555176, 8.1213913], [93.56582642, 8.12167168], [93.56749725, 8.12167168], [93.56778717, 8.12195015], [93.56833649, 8.12194538], [93.56861115, 8.12222099], [93.5688858, 8.12222099], [93.56916809, 8.12250137], [93.56944275, 8.12250137], [93.56973267, 8.12277889], [93.56999969, 8.12277889], [93.57026672, 8.12306023], [93.5708313, 8.12305546], [93.57111359, 8.12333298], [93.57138824, 8.12333298], [93.5716629, 8.12361145], [93.57194519, 8.12361145], [93.57238007, 8.12404633], [93.57250214, 8.1241703], [93.57555389, 8.12416744], [93.57575989, 8.12436962], [93.57583618, 8.12444305], [93.5763855, 8.12444305], [93.57666779, 8.12472343], [93.57696533, 8.12474823], [93.5772171, 8.12501144], [93.57749939, 8.12501144], [93.57776642, 8.12527943], [93.57861328, 8.12527943]]], [[[93.40555573, 7.90305519], [93.40528107, 7.90333319], [93.40444183, 7.90333319], [93.40416718, 7.90305519], [93.4016571, 7.90306091], [93.40139008, 7.90278101], [93.40000153, 7.90278101], [93.39971924, 7.90250111], [93.39861298, 7.90250111], [93.39833069, 7.90222311], [93.39805603, 7.90222979], [93.39778137, 7.90194178], [93.39749908, 7.90194511], [93.39638519, 7.90083218], [93.39638519, 7.90055704], [93.39527893, 7.8994441], [93.39527893, 7.89916611], [93.39499664, 7.89888811], [93.39499664, 7.89861012], [93.39472198, 7.89833498], [93.39472198, 7.89805603], [93.39444733, 7.89777803], [93.39444733, 7.89750004], [93.39417267, 7.89722013], [93.39416504, 7.89638805], [93.39389038, 7.89611006], [93.39389038, 7.89583397], [93.39360809, 7.89555597], [93.39360809, 7.89527798], [93.39332581, 7.89499998], [93.39332581, 7.89443922], [93.39305878, 7.89416599], [93.39305878, 7.89361], [93.39277649, 7.89333391], [93.39277649, 7.89305592], [93.39250183, 7.89277792], [93.39250183, 7.89249992], [93.39167023, 7.89167023], [93.39138794, 7.89167023], [93.39111328, 7.89138985], [93.39083099, 7.89138985], [93.39055634, 7.89110994], [93.39027405, 7.89111185], [93.38972473, 7.89055586], [93.38972473, 7.89027786], [93.38861084, 7.88917017], [93.38861084, 7.88888979], [93.38804626, 7.88833094], [93.38757324, 7.88798523], [93.38687897, 7.88743114], [93.3861084, 7.88694286], [93.38583374, 7.88694286], [93.38527679, 7.88639021], [93.38500214, 7.88639021], [93.38483429, 7.88622284], [93.38471985, 7.88610888], [93.38388824, 7.88611221], [93.38361359, 7.88583279], [93.38277435, 7.88583279], [93.38249969, 7.88555479], [93.38194275, 7.88556004], [93.38111877, 7.8847208], [93.38111115, 7.8836112], [93.38027954, 7.88277721], [93.38027954, 7.88249922], [93.37999725, 7.88222122], [93.3797226, 7.88249922], [93.37889099, 7.88249922], [93.37833405, 7.88194513], [93.37805176, 7.88194513], [93.3777771, 7.88166714], [93.37722015, 7.88166714], [93.3769455, 7.88194513], [93.37666321, 7.88194513], [93.37638855, 7.88222122], [93.37555695, 7.88222122], [93.37526703, 7.88249922], [93.37499237, 7.88249922], [93.37473297, 7.88277912], [93.37444305, 7.88277912], [93.3741684, 7.88305998], [93.37388611, 7.88305521], [93.37361145, 7.88333321], [93.3730545, 7.88333321], [93.37277985, 7.8836112], [93.37249756, 7.8836112], [93.37194824, 7.88416719], [93.37194824, 7.88444281], [93.37166595, 7.8847208], [93.37166595, 7.88610888], [93.37110901, 7.88667011], [93.37083435, 7.88666821], [93.37055206, 7.88694286], [93.3702774, 7.88666821], [93.3694458, 7.88667011], [93.36915588, 7.88639021], [93.36888885, 7.88639021], [93.36860657, 7.88610888], [93.36805725, 7.88611221], [93.36777496, 7.88583279], [93.36750031, 7.88583088], [93.36694336, 7.88639021], [93.36611938, 7.88639021], [93.3658371, 7.88667011], [93.36528015, 7.88667011], [93.36499786, 7.88639021], [93.36444092, 7.88639021], [93.36416626, 7.88667011], [93.3638916, 7.88667011], [93.36332703, 7.88723087], [93.36277771, 7.88723087], [93.36250305, 7.88749981], [93.36165619, 7.88749981], [93.36110687, 7.88792086], [93.36000061, 7.88791704], [93.35944366, 7.88847303], [93.35916901, 7.88847303], [93.35832977, 7.88861179], [93.35778046, 7.88888979], [93.35749817, 7.88888979], [93.35639191, 7.88888979], [93.35610962, 7.88917017], [93.35583496, 7.88916779], [93.35555267, 7.88944387], [93.35527802, 7.88944387], [93.35388947, 7.89083385], [93.35333252, 7.89083195], [93.3527832, 7.89138985], [93.35250092, 7.89138985], [93.35028076, 7.89361], [93.35028076, 7.893888], [93.34972382, 7.89444399], [93.34972382, 7.89555597], [93.34944153, 7.89583397], [93.34944153, 7.896101], [93.34916687, 7.89638805], [93.34916687, 7.89666605], [93.34889221, 7.89694023], [93.34889221, 7.89888811], [93.34777832, 7.90000105], [93.34638977, 7.90000105], [93.34610748, 7.90028095], [93.34583282, 7.90028095], [93.34443665, 7.90167093], [93.34443665, 7.90250111], [93.34416962, 7.90277719], [93.34444427, 7.90305519], [93.34444427, 7.90472317], [93.34416962, 7.90500116], [93.34416962, 7.90527678], [93.34388733, 7.90555477], [93.34388733, 7.90583277], [93.34361267, 7.90611076], [93.34361267, 7.90638924], [93.34416962, 7.90694523], [93.34471893, 7.90694523], [93.34500122, 7.90666723], [93.34583282, 7.90666914], [93.3466568, 7.90750122], [93.3466568, 7.90777922], [93.34694672, 7.90806007], [93.34694672, 7.9100008], [93.34666443, 7.91027689], [93.34666443, 7.91166687], [93.34638977, 7.91194296], [93.34638977, 7.91222095], [93.34610748, 7.91249895], [93.34610748, 7.91305494], [93.34583282, 7.91332912], [93.34583282, 7.91388988], [93.34555817, 7.91416502], [93.34555817, 7.91444302], [93.34527588, 7.91472197], [93.34527588, 7.91499996], [93.34500122, 7.91527796], [93.34500122, 7.91555595], [93.34443665, 7.91611004], [93.34443665, 7.91638994], [93.34333038, 7.91750002], [93.34263611, 7.91813087], [93.34263611, 7.91883087], [93.3429184, 7.91930723], [93.34326172, 7.92013884], [93.34361267, 7.92083406], [93.34361267, 7.92111206], [93.34471893, 7.92222214], [93.34471893, 7.92250013], [93.34777832, 7.92555714], [93.34777832, 7.92583179], [93.34805298, 7.92610979], [93.34805298, 7.92638779], [93.34833527, 7.92666578], [93.34833527, 7.92694521], [93.35083008, 7.92944479], [93.35083008, 7.92972088], [93.35111237, 7.93000078], [93.35111237, 7.93027878], [93.35138702, 7.93055487], [93.35138702, 7.93083286], [93.35166931, 7.93111086], [93.35166931, 7.93166685], [93.35154724, 7.93178797], [93.35111237, 7.93222284], [93.35083008, 7.93194485], [93.35083008, 7.93166685], [93.34944153, 7.93027878], [93.34944153, 7.93000078], [93.34722137, 7.92778111], [93.34694672, 7.92778111], [93.3466568, 7.9275012], [93.34638977, 7.9275012], [93.34629822, 7.92740917], [93.34610748, 7.92722321], [93.34555817, 7.92721987], [93.34527588, 7.9275012], [93.34500122, 7.9275012], [93.34500885, 7.9286108], [93.34471893, 7.92889118], [93.34471893, 7.93000078], [93.34500122, 7.93027878], [93.34500122, 7.93083286], [93.34638977, 7.93222284], [93.3466568, 7.93220901], [93.34687805, 7.93242979], [93.34694672, 7.93250084], [93.34722137, 7.93250084], [93.34749603, 7.93278122], [93.34777832, 7.93278122], [93.34805298, 7.93305922], [93.34860992, 7.93305492], [93.34916687, 7.93361092], [93.34945679, 7.93362188], [93.34971619, 7.93389082], [93.34999847, 7.93388891], [93.35055542, 7.9344449], [93.35083008, 7.93444109], [93.35193634, 7.93556023], [93.35221863, 7.93555498], [93.35250092, 7.93583298], [93.35250092, 7.93611097], [93.35388947, 7.93749905], [93.35388947, 7.93777704], [93.35555267, 7.93944597], [93.35555267, 7.9397192], [93.35639191, 7.94056177], [93.35694122, 7.94055605], [93.35805511, 7.94166517], [93.35758209, 7.9421401], [93.35749817, 7.94222212], [93.35722351, 7.94194412], [93.35694122, 7.94194412], [93.35639191, 7.94139004], [93.35583496, 7.94139004], [93.35527802, 7.94083405], [93.35472107, 7.94083405], [93.35444641, 7.94111204], [93.35416412, 7.94111204], [93.35388947, 7.94139004], [93.35361481, 7.94139004], [93.35250092, 7.94250011], [93.35193634, 7.94250011], [93.35166931, 7.94278002], [93.35138702, 7.94278002], [93.35111237, 7.94305992], [93.35083008, 7.94305611], [93.35083008, 7.94332886], [93.35028076, 7.94388819], [93.35028076, 7.94416618], [93.35083008, 7.94472218], [93.35083008, 7.94500017], [93.34944153, 7.94500017], [93.34777832, 7.9433341], [93.34750366, 7.9433341], [93.34694672, 7.94277811], [93.3466568, 7.94278002], [93.34555817, 7.94166994], [93.34555817, 7.94138098], [93.34471893, 7.94055605], [93.34443665, 7.94056177], [93.34416962, 7.94027996], [93.34388733, 7.94027996], [93.34306335, 7.9394412], [93.34305573, 7.93916798], [93.34361267, 7.93861103], [93.34471893, 7.93972111], [93.34500885, 7.9397192], [93.34527588, 7.9399991], [93.34555817, 7.9399991], [93.34610748, 7.94056177], [93.34805298, 7.94056177], [93.34860992, 7.9399991], [93.34860992, 7.9394412], [93.34805298, 7.93888903], [93.34805298, 7.93777704], [93.34815979, 7.9366312], [93.3477478, 7.93559217], [93.34663391, 7.93468904], [93.34583282, 7.9344449], [93.34555817, 7.9344449], [93.34416962, 7.93305492], [93.34416962, 7.93277693], [93.34305573, 7.93166685], [93.34139252, 7.93333292], [93.34139252, 7.93361092], [93.33999634, 7.9350009], [93.33972168, 7.9350009], [93.3391571, 7.93556023], [93.33860779, 7.93555498], [93.33833313, 7.93583298], [93.33805847, 7.93583298], [93.33777618, 7.93611097], [93.33721924, 7.93611097], [93.33693695, 7.93638897], [93.33528137, 7.93638897], [93.33499908, 7.93611097], [93.33472443, 7.93611097], [93.33453369, 7.93592215], [93.33444214, 7.93583298], [93.33388519, 7.93583298], [93.33305359, 7.93499899], [93.33291626, 7.93451118], [93.3326416, 7.93381596], [93.3326416, 7.93256712], [93.33215332, 7.93194294], [93.33152771, 7.9309721], [93.33152771, 7.93062496], [93.33139038, 7.93055487], [93.33110809, 7.93028116], [93.33110809, 7.93000078], [93.33082581, 7.92972088], [93.33083344, 7.92916679], [93.33055878, 7.9288888], [93.33055878, 7.92806101], [93.33194733, 7.92667103], [93.33194733, 7.92640018], [93.33222198, 7.92610979], [93.33298492, 7.92548609], [93.33277893, 7.92527819], [93.33222198, 7.92471981], [93.33222198, 7.9244442], [93.33139038, 7.92361021], [93.33110809, 7.92361021], [93.33083344, 7.92333221], [93.33027649, 7.9233408], [93.32971954, 7.92389011], [93.32917023, 7.92388821], [93.32805634, 7.92500019], [93.32666779, 7.92500019], [93.32583618, 7.92583179], [93.32555389, 7.92610979], [93.32527924, 7.92610979], [93.32499695, 7.92640018], [93.32305908, 7.92640018], [93.32277679, 7.92667103], [93.32250214, 7.92667103], [93.3216629, 7.9275012], [93.3216629, 7.92778111], [93.32138824, 7.92806101], [93.32138824, 7.92917109], [93.31999969, 7.93055916], [93.31972504, 7.93055487], [93.31944275, 7.93083286], [93.31944275, 7.93111086], [93.31916809, 7.93138885], [93.31916809, 7.93220901], [93.31861115, 7.93278122], [93.31833649, 7.93278122], [93.31804657, 7.93305922], [93.31777954, 7.93305492], [93.3172226, 7.93361092], [93.3172226, 7.9344449], [93.31749725, 7.9347229], [93.31777954, 7.93472099], [93.3180542, 7.93499899], [93.3180542, 7.93527699], [93.31861115, 7.93583298], [93.31861115, 7.93611097], [93.31916809, 7.93666983], [93.31916809, 7.9399991], [93.3188858, 7.9402771], [93.3188858, 7.94083405], [93.31861115, 7.94111204], [93.31861115, 7.94166517], [93.31833649, 7.94194412], [93.31833649, 7.94250011], [93.3180542, 7.94277811], [93.3180542, 7.94305611], [93.31639099, 7.94472218], [93.31639099, 7.94500017], [93.3152771, 7.94611216], [93.3152771, 7.94638777], [93.31472015, 7.94694424], [93.31472015, 7.94721985], [93.3144455, 7.94750023], [93.3144455, 7.94777822], [93.3125, 7.94971991], [93.3125, 7.94999981], [93.31194305, 7.9505558], [93.31194305, 7.95166588], [93.31222534, 7.95194387], [93.31223297, 7.95221996], [93.31194305, 7.95249987], [93.31194305, 7.9527812], [93.3116684, 7.9530611], [93.3116684, 7.9538908], [93.31138611, 7.95416689], [93.31138611, 7.95555496], [93.31111145, 7.9558301], [93.31111145, 7.95750093], [93.31083679, 7.95778084], [93.31083679, 7.96027708], [93.3105545, 7.96055508], [93.3105545, 7.96194506], [93.31083679, 7.96222115], [93.31083679, 7.96251011], [93.31111145, 7.96277905], [93.31229401, 7.9631958], [93.31298828, 7.96388912], [93.31388855, 7.96486282], [93.31472015, 7.96555519], [93.31500244, 7.96583319], [93.31500244, 7.96666813], [93.3152771, 7.96694279], [93.3152771, 7.96722078], [93.31583405, 7.96777821], [93.31583405, 7.9680562], [93.3161087, 7.9683342], [93.3161087, 7.96860886], [93.31639099, 7.96889019], [93.31639099, 7.96999979], [93.31694794, 7.97056007], [93.3172226, 7.97055578], [93.31777954, 7.97111177], [93.31804657, 7.97111177], [93.31833649, 7.97138977], [93.31861115, 7.97138977], [93.3188858, 7.97167015], [93.31916809, 7.97166586], [93.31944275, 7.97194386], [93.31972504, 7.97194386], [93.31999969, 7.97222185], [93.32055664, 7.97222185], [93.32064819, 7.97231293], [93.32110596, 7.97278023], [93.32138824, 7.97277784], [93.32305908, 7.97444391], [93.32305908, 7.97472], [93.3236084, 7.9752779], [93.3236084, 7.9755559], [93.32389069, 7.97583389], [93.32389069, 7.97666597], [93.32416534, 7.97694397], [93.32416534, 7.9808321], [93.32389069, 7.9811101], [93.32388306, 7.98222017], [93.3236084, 7.98250103], [93.3236084, 7.9841671], [93.32333374, 7.9844451], [93.32333374, 7.98555517], [93.32305908, 7.98583317], [93.32305908, 7.98972082], [93.32250214, 7.99027681], [93.32250214, 7.99055481], [93.32221985, 7.9908309], [93.32221985, 7.9913888], [93.32250214, 7.99167013], [93.32250214, 7.99306011], [93.32332611, 7.99388981], [93.3236084, 7.99388981], [93.32416534, 7.99444294], [93.32416534, 7.99472094], [93.32444763, 7.99499989], [93.32444763, 7.99611187], [93.32416534, 7.99638987], [93.32417297, 7.99721909], [93.32444763, 7.99749994], [93.32444763, 7.99777794], [93.32499695, 7.99832916], [93.32499695, 7.99861193], [93.32555389, 7.99916601], [93.32555389, 7.99944401], [93.32583618, 7.999722], [93.32583618, 8.0], [93.32583618, 8.00083447], [93.32611084, 8.00111198], [93.32611084, 8.0013876], [93.3263855, 8.00166607], [93.3263855, 8.00194359], [93.32666779, 8.00222015], [93.32666779, 8.00249958], [93.32695007, 8.00277996], [93.32818604, 8.00358009], [93.32950592, 8.00503922], [93.330513, 8.00634003], [93.33126068, 8.0068779], [93.33153534, 8.00701523], [93.33202362, 8.00750065], [93.33222961, 8.00784683], [93.33222961, 8.00826359], [93.33230591, 8.00861073], [93.33341217, 8.00981808], [93.33508301, 8.01078892], [93.33577728, 8.01113605], [93.33611298, 8.01194477], [93.33638763, 8.01222324], [93.33750153, 8.01222324], [93.33777618, 8.01194477], [93.33860779, 8.01194477], [93.33889008, 8.01166725], [93.34027863, 8.01167107], [93.34055328, 8.01139069], [93.34092712, 8.01056099], [93.34121704, 8.01049137], [93.34211731, 8.01062965], [93.34259796, 8.01062965], [93.34278107, 8.01139069], [93.34306335, 8.01139069], [93.34555817, 8.01388931], [93.34555817, 8.01416683], [93.34583282, 8.0144453], [93.34583282, 8.01472092], [93.34610748, 8.0150013], [93.34610748, 8.01527691], [93.34638977, 8.01555538], [93.34638977, 8.01583099], [93.34694672, 8.01638889], [93.34749603, 8.01638889], [93.34889221, 8.0150013], [93.34889221, 8.01472092], [93.34916687, 8.0144453], [93.34916687, 8.01416683], [93.34972382, 8.01361084], [93.34971619, 8.01306152], [93.34999847, 8.01277924], [93.34999847, 8.01167107], [93.34971619, 8.01139069], [93.34971619, 8.01056099], [93.34999847, 8.01028061], [93.34999847, 8.00971985], [93.35083008, 8.0088892], [93.35111237, 8.00889111], [93.35166931, 8.00833035], [93.35221863, 8.00833225], [93.35250092, 8.00805664], [93.35388947, 8.00806141], [93.35415649, 8.00778103], [93.35472107, 8.00778103], [93.35500336, 8.00806141], [93.35555267, 8.00805664], [93.35583496, 8.00833225], [93.35610962, 8.00833225], [93.35639191, 8.00861073], [93.35666656, 8.00861073], [93.35694885, 8.00889111], [93.35721588, 8.00889111], [93.35749817, 8.00917053], [93.35832977, 8.00916672], [93.35861206, 8.00944519], [93.35944366, 8.00944519], [93.35962677, 8.00962543], [93.35972595, 8.00972271], [93.36000061, 8.00972271], [93.36011505, 8.00983906], [93.36027527, 8.01000118], [93.36055756, 8.01000118], [93.36083221, 8.01028061], [93.3611145, 8.0102787], [93.36305237, 8.01222324], [93.36332703, 8.01222134], [93.3638916, 8.01277924], [93.36416626, 8.01277733], [93.36444092, 8.01305485], [93.36472321, 8.01333332], [93.36499786, 8.01333332], [93.36611176, 8.0144453], [93.36611938, 8.01472092], [93.3666687, 8.01527691], [93.3666687, 8.01555538], [93.36694336, 8.0158329], [93.36694336, 8.01611137], [93.36722565, 8.01638889], [93.36723328, 8.01665974], [93.3694458, 8.01888943], [93.3694458, 8.01916695], [93.36972046, 8.01944637], [93.36972046, 8.01972103], [93.37000275, 8.01999855], [93.37000275, 8.02027702], [93.3702774, 8.02055454], [93.3702774, 8.02083397], [93.37055206, 8.02111244], [93.37055206, 8.02138996], [93.3713913, 8.02222157], [93.37194824, 8.02222157], [93.37213135, 8.02240753], [93.3722229, 8.02250195], [93.37249756, 8.02222157], [93.37277985, 8.02250195], [93.37361145, 8.02250195], [93.37388611, 8.02279091], [93.3741684, 8.02279091], [93.37444305, 8.02250195], [93.37499237, 8.02250195], [93.37526703, 8.02279091], [93.37610626, 8.02279091], [93.37638855, 8.02305984], [93.3769455, 8.02305603], [93.37722015, 8.02333355], [93.37750244, 8.02333355], [93.3777771, 8.02361202], [93.37805176, 8.02361202], [93.37889099, 8.02444363], [93.37916565, 8.02444363], [93.37944794, 8.0247221], [93.37999725, 8.0247221], [93.38027954, 8.02444363], [93.3805542, 8.02444363], [93.38194275, 8.02305603], [93.38223267, 8.02305984], [93.38249969, 8.02279091], [93.38276672, 8.02279091], [93.38305664, 8.02250195], [93.38360596, 8.02250195], [93.38388824, 8.02222157], [93.3841629, 8.02222157], [93.38444519, 8.02194309], [93.38471985, 8.02194309], [93.38527679, 8.02138996], [93.38555908, 8.02139187], [93.38582611, 8.02111244], [93.38666534, 8.02111244], [93.38694763, 8.02083397], [93.38805389, 8.02083397], [93.38833618, 8.02055454], [93.38861084, 8.02056026], [93.38944244, 8.01972103], [93.38999939, 8.01972103], [93.39027405, 8.01944637], [93.39083099, 8.01944637], [93.39111328, 8.01972103], [93.39221954, 8.01972103], [93.39250183, 8.01944637], [93.39305878, 8.01944637], [93.39360809, 8.01888943], [93.39389038, 8.01888943], [93.39417267, 8.01861095], [93.39527893, 8.01861095], [93.39555359, 8.01833344], [93.39611053, 8.01833344], [93.39638519, 8.01805496], [93.39694214, 8.01805973], [93.3972168, 8.01777935], [93.39749908, 8.01777935], [93.39778137, 8.01750088], [93.39805603, 8.01750088], [93.39833069, 8.01722145], [93.39861298, 8.01722336], [93.40000153, 8.0158329], [93.40000153, 8.01555538], [93.40055847, 8.0150013], [93.40055847, 8.01472092], [93.40110779, 8.01416683], [93.40110779, 8.01388931], [93.40277863, 8.01222134], [93.40305328, 8.01222324], [93.40361023, 8.01166725], [93.40389252, 8.01167107], [93.40416718, 8.01139069], [93.40444183, 8.01139069], [93.40471649, 8.01111126], [93.40499878, 8.01111126], [93.40528107, 8.01083279], [93.40555573, 8.01083279], [93.40583038, 8.01055527], [93.40638733, 8.01056099], [93.40777588, 8.00917053], [93.40777588, 8.00889111], [93.4091568, 8.0074892], [93.40965271, 8.00708294], [93.40979004, 8.00659847], [93.40979004, 8.00597572], [93.40944672, 8.00528336], [93.4090271, 8.00521183], [93.40798187, 8.00500488], [93.40721893, 8.00500011], [93.40583038, 8.00361156], [93.40583038, 8.00333214], [93.40555573, 8.00305557], [93.40555573, 8.00249958], [93.4052887, 8.00222015], [93.40528107, 8.00194359], [93.40499878, 8.00166607], [93.40499878, 8.0013876], [93.40471649, 8.00111198], [93.40416718, 8.0], [93.40389252, 7.99832916], [93.40361023, 7.99805593], [93.40361023, 7.99555588], [93.40333557, 7.99527788], [93.40333557, 7.99472094], [93.40305328, 7.99444294], [93.40305328, 7.9913888], [93.40333557, 7.9911108], [93.40305328, 7.99083281], [93.40305328, 7.98999882], [93.40333557, 7.98972321], [93.40333557, 7.98888922], [93.40361023, 7.98861122], [93.40361023, 7.98722315], [93.40389252, 7.98694515], [93.40389252, 7.98638916], [93.40416718, 7.98611116], [93.40416718, 7.98527718], [93.40444183, 7.98500109], [93.40444183, 7.9844451], [93.40472412, 7.9841671], [93.40444183, 7.9838891], [93.40444183, 7.98193979], [93.40416718, 7.98166704], [93.40416718, 7.9811101], [93.40389252, 7.9808321], [93.40389252, 7.98055696], [93.40277863, 7.97944403], [93.40277863, 7.97916603], [93.40249634, 7.97888803], [93.40249634, 7.97861004], [93.40222168, 7.97833395], [93.40222168, 7.97638798], [93.40249634, 7.97610998], [93.40249634, 7.9755559], [93.40277863, 7.9752779], [93.40277863, 7.97445107], [93.40471649, 7.97249985], [93.40471649, 7.97221994], [93.40528107, 7.97166586], [93.40528107, 7.97138977], [93.40611267, 7.97056007], [93.40638733, 7.97056007], [93.40693665, 7.96999979], [93.40750122, 7.96999979], [93.40777588, 7.96972179], [93.40805817, 7.96972179], [93.40833282, 7.9694438], [93.40860748, 7.9694438], [93.41027832, 7.96777821], [93.41027832, 7.96722078], [93.41055298, 7.96694279], [93.41055298, 7.96583319], [93.41083527, 7.96555519], [93.41083527, 7.9649992], [93.41110992, 7.9647212], [93.41110992, 7.96444511], [93.41139221, 7.96416712], [93.41139221, 7.96361113], [93.41166687, 7.96333313], [93.41166687, 7.96305513], [93.41194153, 7.96277714], [93.41194153, 7.96251011], [93.41221619, 7.96222115], [93.41222382, 7.96194506], [93.41416931, 7.96000099], [93.41443634, 7.96000099], [93.41471863, 7.95972109], [93.41527557, 7.959723], [93.41555786, 7.959445], [93.41610718, 7.95944977], [93.41638947, 7.95917177], [93.42082977, 7.95917177], [93.42111206, 7.95944977], [93.42138672, 7.959445], [93.42166901, 7.959723], [93.42222595, 7.95972109], [93.4224472, 7.95994377], [93.42250061, 7.96000099], [93.42277527, 7.96000099], [93.42388916, 7.96111107], [93.42388916, 7.96138906], [93.42416382, 7.96166706], [93.42415619, 7.96194077], [93.42472076, 7.96249914], [93.42472076, 7.96277714], [93.42805481, 7.96611118], [93.4283371, 7.96611118], [93.42881012, 7.96658611], [93.43000031, 7.96778011], [93.4327774, 7.9649992], [93.4327774, 7.96444511], [93.43305206, 7.96416712], [93.43305206, 7.96388912], [93.43332672, 7.96361113], [93.43333435, 7.96305513], [93.43360901, 7.96277714], [93.43360901, 7.96222115], [93.4338913, 7.96194506], [93.4338913, 7.96111107], [93.43416595, 7.96083307], [93.43416595, 7.96027708], [93.43444824, 7.96000099], [93.43444824, 7.95917177], [93.4347229, 7.95889091], [93.4347229, 7.95833111], [93.43499756, 7.95805502], [93.43499756, 7.95777893], [93.43527222, 7.95750093], [93.43527222, 7.95722103], [93.43583679, 7.95666695], [93.43583679, 7.95638895], [93.43638611, 7.95583296], [93.4366684, 7.95583296], [93.43722534, 7.95527887], [93.43805695, 7.95528078], [93.4383316, 7.95500088], [93.43888855, 7.95500088], [93.43916321, 7.95472002], [93.4394455, 7.95472288], [93.43972015, 7.95444489], [93.44000244, 7.95444489], [93.44249725, 7.95194387], [93.44249725, 7.95166588], [93.44416809, 7.94999981], [93.44444275, 7.94999981], [93.44473267, 7.94971991], [93.44499969, 7.94972181], [93.44833374, 7.94638777], [93.4486084, 7.94639015], [93.44917297, 7.94583178], [93.44944763, 7.94583416], [93.45333099, 7.94194412], [93.45361328, 7.94194412], [93.45388794, 7.94166517], [93.45417023, 7.94166994], [93.45500183, 7.94083118], [93.45527649, 7.94083405], [93.45583344, 7.9402771], [93.45610809, 7.94027996], [93.45667267, 7.9397192], [93.45694733, 7.93972111], [93.45777893, 7.93888903], [93.45804596, 7.93888903], [93.45944214, 7.93750095], [93.4597168, 7.93750095], [93.46138763, 7.93583107], [93.46111298, 7.93583298], [93.46250153, 7.9344449], [93.46250153, 7.93416691], [93.46277618, 7.93388891], [93.46277618, 7.93361092], [93.46305847, 7.93333292], [93.46305847, 7.93305492], [93.46333313, 7.93277693], [93.46333313, 7.93250084], [93.46360779, 7.93220901], [93.46360779, 7.93194485], [93.46389008, 7.93166685], [93.46389008, 7.93138885], [93.4641571, 7.93111086], [93.46416473, 7.93083286], [93.46499634, 7.93000078], [93.46499634, 7.92972279], [93.46527863, 7.92944479], [93.46527863, 7.92916679], [93.46555328, 7.9288888], [93.46555328, 7.92806101], [93.4658432, 7.92778111], [93.4658432, 7.92610979], [93.46611023, 7.92583179], [93.46611023, 7.9241662], [93.46639252, 7.92388821], [93.46639252, 7.92250013], [93.46638489, 7.92089319], [93.46645355, 7.91992283], [93.4661026, 7.91888094], [93.46611023, 7.91777802], [93.46611023, 7.91750002], [93.4658432, 7.9172101], [93.46583557, 7.91694403], [93.46555328, 7.91666603], [93.46555328, 7.91611195], [93.46583557, 7.91583395], [93.46583557, 7.91499996], [93.46611023, 7.91472197], [93.46611023, 7.91444302], [93.46639252, 7.91416502], [93.46639252, 7.91388988], [93.46666718, 7.91361189], [93.46666718, 7.91333389], [93.46694183, 7.91305494], [93.46694183, 7.91277695], [93.46721649, 7.91249895], [93.46721649, 7.91222095], [93.46749878, 7.91194296], [93.46749878, 7.91138887], [93.46778107, 7.91111088], [93.46778107, 7.91027689], [93.46805573, 7.90999889], [93.46806335, 7.9097209], [93.46833038, 7.90944481], [93.46833038, 7.90916681], [93.46888733, 7.90861082], [93.46888733, 7.90833282], [93.46944427, 7.90777683], [93.46944427, 7.90694523], [93.46971893, 7.90666723], [93.46971893, 7.90583277], [93.47000122, 7.90555477], [93.47000122, 7.90472317], [93.47027588, 7.90444517], [93.47027588, 7.90361118], [93.47055817, 7.90333319], [93.47055817, 7.90222311], [93.47083282, 7.90194511], [93.47083282, 7.90138912], [93.47110748, 7.90111113], [93.47110748, 7.90083218], [93.47138977, 7.90055704], [93.47138977, 7.90027905], [93.47222137, 7.89943981], [93.47222137, 7.89916611], [93.47250366, 7.89888811], [93.47249603, 7.89833021], [93.47277832, 7.89805603], [93.47277832, 7.89777803], [93.47305298, 7.89750004], [93.47305298, 7.89722013], [93.47333527, 7.89694405], [93.47333527, 7.89666605], [93.47416687, 7.89583397], [93.47416687, 7.89444399], [93.47444153, 7.89416599], [93.47444153, 7.893888], [93.47471619, 7.89361], [93.47472382, 7.89249992], [93.47222137, 7.88999987], [93.47249603, 7.88971901], [93.47250366, 7.88944387], [93.47138977, 7.8883338], [93.47138977, 7.88777781], [93.47166443, 7.88749981], [93.4716568, 7.88694096], [93.47138977, 7.88666821], [93.47138977, 7.88639021], [93.47110748, 7.88610888], [93.47110748, 7.88555479], [93.47083282, 7.88527679], [93.47083282, 7.8836112], [93.47055817, 7.88333321], [93.47055817, 7.88305521], [93.47000122, 7.88249922], [93.46971893, 7.88249922], [93.46944427, 7.88222122], [93.46944427, 7.88194513], [93.46916962, 7.88166714], [93.46916962, 7.88138914], [93.46721649, 7.87944078], [93.46694183, 7.87944508], [93.46679688, 7.87929678], [93.46666718, 7.87916708], [93.46666718, 7.87888908], [93.46639252, 7.87861109], [93.46639252, 7.87750101], [93.46611023, 7.87722301], [93.46611023, 7.87694502], [93.46583557, 7.87666702], [93.46583557, 7.87638903], [93.46527863, 7.87583017], [93.46527863, 7.87555504], [93.46472168, 7.87500095], [93.46472168, 7.8747201], [93.46389008, 7.87388897], [93.46360779, 7.87389088], [93.46340179, 7.87368107], [93.46333313, 7.87361002], [93.46305847, 7.87361002], [93.46166992, 7.87222195], [93.46111298, 7.87222004], [93.46083069, 7.8725009], [93.46028137, 7.8725009], [93.45999908, 7.8727808], [93.4597168, 7.8727808], [93.45944214, 7.87306118], [93.45916748, 7.87305403], [93.45888519, 7.87333202], [93.45722198, 7.87333202], [93.45694733, 7.87361002], [93.45667267, 7.87361002], [93.45639801, 7.87389088], [93.45610809, 7.87389088], [93.45582581, 7.87417078], [93.45527649, 7.87416697], [93.45500183, 7.87444496], [93.45417023, 7.87444496], [93.45305634, 7.87555504], [93.45305634, 7.87583303], [93.45276642, 7.87611103], [93.45277405, 7.87638903], [93.45249939, 7.87666702], [93.45249939, 7.87694502], [93.4522171, 7.87722111], [93.4522171, 7.87778091], [93.45194244, 7.87806177], [93.45194244, 7.87888908], [93.45222473, 7.87916708], [93.45166779, 7.87972116], [93.45166779, 7.88027716], [93.4513855, 7.88055515], [93.45139313, 7.88110018], [93.45111084, 7.88138914], [93.45111084, 7.88249922], [93.4513855, 7.88277721], [93.4513855, 7.88333321], [93.45166779, 7.8836112], [93.45166779, 7.8838892], [93.4513855, 7.88416719], [93.4513855, 7.88444281], [93.45111084, 7.8847208], [93.45111084, 7.8849988], [93.44889069, 7.88723087], [93.44889069, 7.88749981], [93.44833374, 7.8880558], [93.44833374, 7.8883338], [93.44805908, 7.88861179], [93.44805908, 7.88888979], [93.44777679, 7.88916779], [93.44777679, 7.88971901], [93.44750214, 7.89000177], [93.44750214, 7.89028883], [93.44721222, 7.89056015], [93.44721985, 7.89138985], [93.44694519, 7.89166594], [93.44694519, 7.89222193], [93.44555664, 7.89361], [93.44555664, 7.893888], [93.44499969, 7.89444399], [93.44499969, 7.89472008], [93.44444275, 7.89527988], [93.44444275, 7.89555597], [93.44333649, 7.89666605], [93.44333649, 7.89694023], [93.44139862, 7.89889097], [93.4411087, 7.89888811], [93.44055176, 7.8994441], [93.4402771, 7.8994441], [93.43972015, 7.90000105], [93.43945313, 7.90000105], [93.43916321, 7.90028095], [93.43888855, 7.90028095], [93.43860626, 7.90056086], [93.43805695, 7.90055704], [93.43777466, 7.90083218], [93.4375, 7.90082979], [93.43694305, 7.90139103], [93.4366684, 7.90139103], [93.43638611, 7.90167093], [93.43611145, 7.90166712], [93.43583679, 7.90194511], [93.43554687, 7.90194178], [93.43527222, 7.90222979], [93.4347229, 7.90222311], [93.43444824, 7.90250111], [93.43416595, 7.90250111], [93.4338913, 7.90278101], [93.43333435, 7.90277719], [93.4327774, 7.90333319], [93.43250275, 7.90333319], [93.43222046, 7.90361118], [93.43165588, 7.90361118], [93.43138885, 7.90389109], [93.43083191, 7.90389109], [93.43055725, 7.90417099], [93.43027496, 7.90416718], [93.4291687, 7.90527678], [93.42888641, 7.9052701], [93.42861176, 7.90555906], [93.42778015, 7.90555477], [93.42749786, 7.90583277], [93.42722321, 7.90583277], [93.42694092, 7.90611076], [93.42610931, 7.90611076], [93.42582703, 7.90638924], [93.42415619, 7.90638924], [93.42388916, 7.90666914], [93.4236145, 7.90666723], [93.42333221, 7.90694523], [93.42277527, 7.90694523], [93.42250061, 7.90722322], [93.41999817, 7.90722322], [93.41972351, 7.90694523], [93.41860962, 7.90694523], [93.41833496, 7.90666723], [93.41638947, 7.90666914], [93.41610718, 7.90638924], [93.41555786, 7.90638924], [93.4152832, 7.90611076], [93.41444397, 7.90611076], [93.41388702, 7.90555477], [93.41333008, 7.90555906], [93.41326904, 7.90549088], [93.41306305, 7.9052701], [93.41278076, 7.90527678], [93.41249847, 7.90500116], [93.41221619, 7.90500116], [93.41027832, 7.90306091], [93.40999603, 7.90306091], [93.40972137, 7.90278101], [93.4091568, 7.90278101], [93.40888977, 7.90250111], [93.40860748, 7.90250111], [93.40805817, 7.90194511], [93.40721893, 7.90194178], [93.40638733, 7.90278101], [93.40611267, 7.90278101], [93.40583038, 7.90306091], [93.40555573, 7.90305519]]], [[[93.53250122, 8.04778194], [93.53138733, 8.04889202], [93.53056335, 8.04889202], [93.53029633, 8.04862976], [93.52971649, 8.04806042], [93.52971649, 8.04778194], [93.52944183, 8.04750156], [93.52944183, 8.04722118], [93.52861023, 8.04638863], [93.52861023, 8.04611111], [93.52833557, 8.04583263], [93.52833557, 8.04555511], [93.52805328, 8.04527664], [93.52805328, 8.04472065], [93.52833557, 8.04444313], [93.52833557, 8.04194546], [93.52861023, 8.04166698], [93.52861023, 8.040555], [93.5283432, 8.0402813], [93.5283432, 8.03972054], [93.52861023, 8.03944492], [93.52861023, 8.03888893], [93.52889252, 8.03861141], [93.52889252, 8.03833294], [93.52777863, 8.03722286], [93.52777863, 8.03694534], [93.52694702, 8.03611088], [93.52694702, 8.03583336], [93.52666473, 8.03555679], [93.52666473, 8.03416634], [93.52639008, 8.03389072], [93.52639008, 8.03306103], [93.52527618, 8.03194046], [93.52500153, 8.03194427], [93.52471924, 8.0316658], [93.52416992, 8.0316658], [93.52388763, 8.03194427], [93.52361298, 8.03194046], [93.52278137, 8.03278065], [93.52249908, 8.03277779], [93.52222443, 8.03305435], [93.5222168, 8.03332996], [93.52166748, 8.03388786], [93.52166748, 8.03416634], [93.52139282, 8.03444004], [93.52138519, 8.03472328], [93.52111053, 8.0350008], [93.52111053, 8.03555679], [93.52076721, 8.03694153], [93.52052307, 8.03704453], [93.52027893, 8.03715038], [93.52006531, 8.03708076], [93.51985931, 8.03701115], [93.51972198, 8.03638935], [93.51972198, 8.03611088], [93.51860809, 8.0350008], [93.51832581, 8.0350008], [93.51805878, 8.03473186], [93.51777649, 8.03473186], [93.51750183, 8.03444004], [93.51721954, 8.03444481], [93.51694489, 8.03416634], [93.51583099, 8.0341711], [93.51464844, 8.03409958], [93.51354218, 8.03403187], [93.512146, 8.03375244], [93.51145172, 8.03354168], [93.51083374, 8.03361034], [93.51000214, 8.03361034], [93.50971985, 8.03389072], [93.50944519, 8.03388786], [93.50888062, 8.03402328], [93.50839996, 8.03381538], [93.50791168, 8.03291512], [93.50777435, 8.03194427], [93.50777435, 8.03110981], [93.50791931, 8.03035069], [93.50750732, 8.02972889], [93.50688171, 8.0291729], [93.50653076, 8.02847958], [93.5062561, 8.02695465], [93.5062561, 8.02488136], [93.50611115, 8.02388954], [93.5063858, 8.02361202], [93.5063858, 8.02333355], [93.50666809, 8.02305603], [93.50666809, 8.02277756], [93.50723267, 8.02222157], [93.50722504, 8.02194309], [93.50805664, 8.02111244], [93.5083313, 8.02111244], [93.50888824, 8.02055454], [93.50971985, 8.02056026], [93.51027679, 8.01999855], [93.51027679, 8.01972103], [93.51055908, 8.01944637], [93.51055908, 8.01916695], [93.5111084, 8.01861095], [93.5111084, 8.01833344], [93.51139069, 8.01805496], [93.51139069, 8.01749897], [93.51194763, 8.01694107], [93.51194763, 8.01666737], [93.51055908, 8.01527691], [93.51027679, 8.01528168], [93.51000214, 8.0150013], [93.50971985, 8.0150013], [93.50945282, 8.01528168], [93.5091629, 8.01528168], [93.50888824, 8.01556015], [93.50861359, 8.01555538], [93.5083313, 8.0158329], [93.50805664, 8.0158329], [93.50694275, 8.01472092], [93.50694275, 8.0144453], [93.50666809, 8.01416683], [93.50666809, 8.01277733], [93.50776672, 8.01167107], [93.50805664, 8.01167107], [93.5083313, 8.01139069], [93.50860596, 8.01139069], [93.50945282, 8.01056099], [93.50945282, 8.01000118], [93.50861359, 8.00916672], [93.5083313, 8.00917053], [93.50805664, 8.00889111], [93.50776672, 8.00889111], [93.50694275, 8.00806141], [93.50694275, 8.00693989], [93.50722504, 8.00666618], [93.50722504, 8.00638771], [93.50749207, 8.00611019], [93.50749969, 8.00527763], [93.50722504, 8.00500011], [93.50723267, 8.00443268], [93.50694275, 8.00416565], [93.50694275, 8.00333214], [93.50666809, 8.00305557], [93.50666809, 8.00166607], [93.5063858, 8.00097084], [93.50605011, 8.00069141], [93.5055542, 8.0], [93.5055542, 7.99916601], [93.50499725, 7.99862099], [93.5047226, 7.99862099], [93.50417328, 7.99916983], [93.50389099, 7.99916601], [93.5036087, 7.99944401], [93.50333405, 7.99944401], [93.50305176, 8.0], [93.50313568, 8.00034618], [93.50285339, 8.00048542], [93.50251007, 8.00055408], [93.50188446, 8.00048542], [93.50146484, 8.00027847], [93.50138855, 8.0], [93.50166321, 7.99916983], [93.50215149, 7.99910021], [93.50235748, 7.99875116], [93.50242615, 7.99840021], [93.50228882, 7.99812412], [93.50180817, 7.99770689], [93.50166321, 7.99749994], [93.50138855, 7.99721909], [93.5008316, 7.99721909], [93.50026703, 7.99777985], [93.49972534, 7.99777794], [93.4991684, 7.99833393], [93.49888611, 7.99832916], [93.49861145, 7.99862099], [93.49833679, 7.99862099], [93.49777985, 7.99916983], [93.49749756, 7.99916983], [93.49666595, 8.0], [93.49656677, 8.00028038], [93.49630737, 8.00028038], [93.49603271, 8.00028038], [93.49575043, 8.00028038], [93.4954834, 8.00028038], [93.49518585, 8.00028038], [93.49491882, 8.00028038], [93.49472046, 8.0], [93.49388885, 7.99916983], [93.49360657, 7.99916983], [93.49333191, 7.99888992], [93.49305725, 7.99888992], [93.49194336, 8.0], [93.49223328, 8.00028038], [93.49222565, 8.00055599], [93.4916687, 8.00111198], [93.49138641, 8.00159454], [93.49138641, 8.00277805], [93.49054718, 8.00360966], [93.49055481, 8.00388813], [93.4908371, 8.00416565], [93.4908371, 8.00471973], [93.49055481, 8.00500011], [93.49055481, 8.0055542], [93.49028015, 8.00583458], [93.49028015, 8.00611019], [93.48999786, 8.00638771], [93.48999786, 8.00666618], [93.48972321, 8.00693989], [93.48972321, 8.00777912], [93.48944092, 8.00805664], [93.48944092, 8.00833225], [93.48916626, 8.00861073], [93.48916626, 8.0088892], [93.4888916, 8.00916672], [93.4888916, 8.00944519], [93.48860931, 8.00972271], [93.48860931, 8.01000118], [93.48833466, 8.0102787], [93.48833466, 8.01055527], [93.48805237, 8.01083279], [93.48805237, 8.01111126], [93.48777771, 8.01138878], [93.48777771, 8.01166725], [93.48750305, 8.01194477], [93.48750305, 8.01222324], [93.48722076, 8.01249886], [93.48722076, 8.01277924], [93.48694611, 8.01306152], [93.48694611, 8.01361084], [93.48666382, 8.01388931], [93.48666382, 8.0144453], [93.48638153, 8.01472092], [93.48638916, 8.0150013], [93.4861145, 8.01527691], [93.4861145, 8.0158329], [93.48583221, 8.01611137], [93.48583221, 8.01638889], [93.48555756, 8.01665974], [93.48555756, 8.01750088], [93.48527527, 8.01777744], [93.48555756, 8.01805496], [93.48555756, 8.01833344], [93.48583221, 8.01861095], [93.48583221, 8.01916695], [93.4861145, 8.01944637], [93.4861145, 8.01972103], [93.48527527, 8.02055454], [93.48527527, 8.02111244], [93.48555756, 8.02138996], [93.48555756, 8.02194118], [93.48472595, 8.02277756], [93.48583221, 8.02388763], [93.48583221, 8.02444363], [93.4861145, 8.0247221], [93.48583221, 8.02499962], [93.48583221, 8.02833366], [93.48555756, 8.02861214], [93.48555756, 8.02944374], [93.48527527, 8.02972221], [93.48527527, 8.03055573], [93.48555756, 8.03083038], [93.48555756, 8.03111172], [93.48583221, 8.03138828], [93.48583221, 8.03250027], [93.48555756, 8.03277779], [93.48555756, 8.03333473], [93.48527527, 8.03361034], [93.4852829, 8.0350008], [93.48555756, 8.03527641], [93.48555756, 8.03555679], [93.48583221, 8.03583336], [93.48583221, 8.03611088], [93.48638916, 8.03666687], [93.48638916, 8.0391674], [93.4861145, 8.03944492], [93.4861145, 8.04194546], [93.48583221, 8.04222107], [93.48583221, 8.04249859], [93.48527527, 8.04305458], [93.48527527, 8.04444313], [93.48555756, 8.04472256], [93.48555756, 8.04499912], [93.48638916, 8.04583263], [93.48694611, 8.04583263], [93.4872818, 8.04616833], [93.48750305, 8.04638863], [93.48805237, 8.04638863], [93.48832703, 8.0461092], [93.48916626, 8.04611111], [93.4892807, 8.04622459], [93.48972321, 8.04666996], [93.49028015, 8.04666996], [93.49223328, 8.04472065], [93.49222565, 8.04444313], [93.49250031, 8.04416656], [93.49250031, 8.04361057], [93.49305725, 8.04305458], [93.49360657, 8.0430603], [93.49388885, 8.04278183], [93.49472046, 8.04278183], [93.49500275, 8.04250145], [93.49555206, 8.04250145], [93.49582672, 8.04222107], [93.4963913, 8.04222107], [93.49666595, 8.04194546], [93.49694824, 8.04194546], [93.49749756, 8.04138947], [93.49777985, 8.04139137], [93.49861145, 8.04056168], [93.49861145, 8.0402813], [93.49944305, 8.03944016], [93.49972534, 8.03944492], [93.5, 8.0397234], [93.50027466, 8.0397234], [93.50138855, 8.04083347], [93.50138855, 8.04111099], [93.50166321, 8.04138947], [93.50166321, 8.04333305], [93.5019455, 8.04361057], [93.5019455, 8.04416656], [93.50222015, 8.04444313], [93.50222015, 8.04472256], [93.5027771, 8.04527664], [93.5027771, 8.04722118], [93.50305176, 8.04722118], [93.50327301, 8.0474453], [93.5036087, 8.04778194], [93.50389099, 8.04778194], [93.50444794, 8.04722118], [93.50444794, 8.04638863], [93.50416565, 8.04611111], [93.50416565, 8.04416656], [93.50444794, 8.04388905], [93.50444794, 8.0430603], [93.5047226, 8.04278183], [93.5047226, 8.04222107], [93.50499725, 8.04194546], [93.50499725, 8.04166698], [93.50534821, 8.04083538], [93.50562286, 8.04069614], [93.50604248, 8.04111099], [93.50611115, 8.04194069], [93.50611115, 8.04250145], [93.5063858, 8.04277706], [93.5063858, 8.04416656], [93.50666809, 8.04444313], [93.50666809, 8.04472065], [93.50694275, 8.04500103], [93.50694275, 8.04527664], [93.50722504, 8.04555511], [93.50722504, 8.04583263], [93.50749969, 8.04611111], [93.50749969, 8.04666805], [93.50777435, 8.04694557], [93.50777435, 8.04833412], [93.50805664, 8.04861164], [93.50805664, 8.04916763], [93.5083313, 8.04944134], [93.5083313, 8.04972172], [93.50888824, 8.05027771], [93.50888824, 8.05111217], [93.5083313, 8.05166626], [93.5083313, 8.05194378], [93.50805664, 8.05221939], [93.50805664, 8.05249977], [93.50749969, 8.05305576], [93.50749969, 8.05333424], [93.50722504, 8.05360985], [93.50694275, 8.05360985], [93.50666809, 8.05389023], [93.50611115, 8.05389023], [93.50583649, 8.05416965], [93.50499725, 8.05416584], [93.5047226, 8.05444431], [93.50417328, 8.05443859], [93.50333405, 8.05527782], [93.50333405, 8.0555563], [93.5036087, 8.05583191], [93.5036087, 8.05611038], [93.50389099, 8.05639267], [93.50417328, 8.05639267], [93.50444794, 8.05667114], [93.50499725, 8.05666637], [93.50527954, 8.05694389], [93.5055542, 8.05694389], [93.5057373, 8.05712414], [93.50583649, 8.05722237], [93.50611115, 8.05722046], [93.5063324, 8.05744553], [93.50666809, 8.05778122], [93.50723267, 8.05778122], [93.50776672, 8.05722046], [93.5083313, 8.05722046], [93.50888824, 8.05777836], [93.50888824, 8.05805588], [93.5091629, 8.05833435], [93.5091629, 8.05916595], [93.50888824, 8.05944443], [93.50888824, 8.05972004], [93.50861359, 8.06000042], [93.5091629, 8.06055737], [93.5091629, 8.06221962], [93.5083313, 8.06305695], [93.5083313, 8.06361103], [93.50861359, 8.06388855], [93.50860596, 8.06443977], [93.5091629, 8.06500053], [93.5091629, 8.06527901], [93.50944519, 8.06555462], [93.50944519, 8.06583309], [93.50971985, 8.06611061], [93.50971985, 8.06638908], [93.51000214, 8.0666666], [93.51000214, 8.06694508], [93.51027679, 8.0672226], [93.51027679, 8.06750107], [93.5111084, 8.06833267], [93.51222229, 8.06833267], [93.51249695, 8.06805515], [93.51249695, 8.06777668], [93.51277924, 8.06750107], [93.51277924, 8.0672226], [93.51305389, 8.06694508], [93.51305389, 8.0666666], [93.51333618, 8.06638908], [93.51333618, 8.06611061], [93.51361084, 8.06583309], [93.51361084, 8.06527901], [93.5138855, 8.06499863], [93.51389313, 8.06443977], [93.51416779, 8.06416702], [93.51416779, 8.06388855], [93.51444244, 8.06361103], [93.51444244, 8.06250095], [93.51416779, 8.06221962], [93.51416779, 8.06166744], [93.5138855, 8.06138802], [93.51389313, 8.0602808], [93.51444244, 8.05972004], [93.51444244, 8.05944443], [93.51527405, 8.05860996], [93.51527405, 8.05777836], [93.51555634, 8.05749989], [93.51555634, 8.05639267], [93.51526642, 8.05611038], [93.51527405, 8.05500031], [93.51499939, 8.05472183], [93.51499939, 8.05416584], [93.51472473, 8.05389023], [93.5147171, 8.05332947], [93.51444244, 8.05305576], [93.51444244, 8.05249977], [93.51416779, 8.05221939], [93.51416779, 8.05111217], [93.5138855, 8.0508337], [93.5138855, 8.05000019], [93.51416779, 8.04972172], [93.51416779, 8.0494442], [93.51472473, 8.04889011], [93.51499939, 8.04889202], [93.51526642, 8.04861164], [93.51583099, 8.04861164], [93.51611328, 8.04833412], [93.51638794, 8.04833412], [93.51777649, 8.04694557], [93.51805878, 8.04694557], [93.51944733, 8.04833412], [93.51944733, 8.04861164], [93.51972198, 8.04889011], [93.51972198, 8.04916763], [93.51999664, 8.0494442], [93.51999664, 8.04972172], [93.52138519, 8.05111217], [93.52166748, 8.05111217], [93.52175903, 8.05120277], [93.52194214, 8.05138969], [93.5222168, 8.05138969], [93.52249146, 8.05167007], [93.52416992, 8.05166626], [93.52527618, 8.05277824], [93.52527618, 8.05305576], [93.52555847, 8.05333424], [93.52555847, 8.05360985], [93.52583313, 8.05389023], [93.52583313, 8.05527782], [93.52555847, 8.0555563], [93.52555847, 8.05583191], [93.52471924, 8.05666637], [93.52471924, 8.05694389], [93.52443695, 8.05722046], [93.52444458, 8.05749989], [93.52416992, 8.05777836], [93.52416992, 8.06222343], [93.52388763, 8.06250095], [93.52388763, 8.06333256], [93.52416992, 8.06361103], [93.52416992, 8.06389141], [93.52443695, 8.06417084], [93.52471924, 8.06389141], [93.52527618, 8.06389141], [93.52583313, 8.0633297], [93.52694702, 8.06333256], [93.52722168, 8.06361103], [93.52749634, 8.06361103], [93.52777863, 8.06389141], [93.52805328, 8.06388855], [93.52861023, 8.06444454], [93.52889252, 8.06443977], [93.52944183, 8.06500053], [93.52944183, 8.06527901], [93.52972412, 8.06555462], [93.52972412, 8.06583309], [93.52999878, 8.06611061], [93.52999878, 8.06777668], [93.52944183, 8.06833267], [93.52805328, 8.06833267], [93.52777863, 8.06805515], [93.52749634, 8.06806183], [93.52736664, 8.06792736], [93.52722168, 8.06777668], [93.52694702, 8.06777668], [93.52583313, 8.0666666], [93.52527618, 8.0666666], [93.52500153, 8.06694508], [93.52500153, 8.06722069], [93.52471924, 8.06750107], [93.52471924, 8.06805515], [93.52443695, 8.06833076], [93.52444458, 8.06888866], [93.52416992, 8.06916714], [93.52416992, 8.06972122], [93.52388763, 8.07000065], [93.52416992, 8.07027721], [93.52416992, 8.07249928], [93.52388763, 8.07277679], [93.52388763, 8.07305527], [93.52361298, 8.07333279], [93.52361298, 8.07361126], [93.52394104, 8.07393742], [93.52464294, 8.07463932], [93.52555847, 8.07555962], [93.52583313, 8.0755558], [93.52639008, 8.07611179], [93.5266571, 8.07611179], [93.52694702, 8.07639027], [93.52722168, 8.07639027], [93.52861786, 8.07777977], [93.52889252, 8.07777977], [93.52916718, 8.07806015], [93.52944183, 8.07805634], [93.52971649, 8.07833195], [93.52986145, 8.07868004], [93.5295105, 8.07888985], [93.52861786, 8.07861042], [93.52805328, 8.07861233], [93.52777863, 8.07833385], [93.52722168, 8.07833385], [93.52714539, 8.07825375], [93.52694702, 8.07805634], [93.52555847, 8.07805634], [93.52527618, 8.07833385], [93.52444458, 8.07833385], [93.52361298, 8.07916641], [93.52361298, 8.08083439], [93.52388763, 8.08111], [93.52388763, 8.08166599], [93.52416992, 8.08194447], [93.52416992, 8.08222198], [93.52388763, 8.08250046], [93.52388763, 8.08305645], [93.52361298, 8.08333206], [93.52333069, 8.08333015], [93.52278137, 8.08388996], [93.52249146, 8.08388996], [93.5222168, 8.08360958], [93.52194214, 8.08361244], [93.51972198, 8.08138847], [93.51944733, 8.08139038], [93.51917267, 8.08167267], [93.51889038, 8.08166599], [93.51860809, 8.08194447], [93.51833344, 8.08194447], [93.51777649, 8.08250046], [93.51750183, 8.08250046], [93.51667023, 8.08333206], [93.51638794, 8.08333015], [93.51583099, 8.08388996], [93.51444244, 8.08388996], [93.51435852, 8.08380604], [93.5138855, 8.08333206], [93.5138855, 8.08277798], [93.51361084, 8.08250046], [93.51361084, 8.08194447], [93.51333618, 8.08166599], [93.51333618, 8.08138847], [93.51304626, 8.08111], [93.51304626, 8.07999992], [93.51333618, 8.07971001], [93.51333618, 8.07944393], [93.51361084, 8.07916641], [93.51361084, 8.07861233], [93.5138855, 8.07833385], [93.5138855, 8.07750034], [93.51361084, 8.07722187], [93.51312256, 8.07712078], [93.51277924, 8.07726002], [93.51257324, 8.07691193], [93.51257324, 8.07559013], [93.51264191, 8.07503796], [93.51277924, 8.07413769], [93.51230621, 8.0735817], [93.51154327, 8.07372093], [93.51027679, 8.07386017], [93.5099411, 8.07370853], [93.50965881, 8.0735817], [93.50861359, 8.07309914], [93.50785065, 8.07275009], [93.50695038, 8.07254314], [93.5064621, 8.07247353], [93.50611115, 8.07198906], [93.50563049, 8.07143497], [93.50563049, 8.06976891], [93.50548553, 8.06921673], [93.50479126, 8.06845379], [93.50416565, 8.06833267], [93.50417328, 8.06861115], [93.5036087, 8.06917191], [93.5027771, 8.06917191], [93.50242615, 8.06873608], [93.50216675, 8.06840992], [93.5019455, 8.06777668], [93.5008316, 8.0666666], [93.5008316, 8.06638908], [93.50055695, 8.06611061], [93.50055695, 8.06583309], [93.49972534, 8.06499863], [93.49944305, 8.06500053], [93.4991684, 8.06471062], [93.49804688, 8.06471062], [93.49777985, 8.06500053], [93.49749756, 8.06499863], [93.4963913, 8.06611061], [93.49610901, 8.06611061], [93.4952774, 8.06527901], [93.4952774, 8.06499863], [93.49500275, 8.06471062], [93.49500275, 8.06444454], [93.4936142, 8.06305695], [93.49333191, 8.06305885], [93.49305725, 8.06278133], [93.49276733, 8.06278133], [93.49260712, 8.06260967], [93.49250031, 8.06250095], [93.49223328, 8.06250095], [93.49194336, 8.06221962], [93.49194336, 8.06194496], [93.4916687, 8.06166744], [93.49194336, 8.06138802], [93.49194336, 8.06110954], [93.49250031, 8.06055737], [93.49276733, 8.06056118], [93.49305725, 8.0602808], [93.49388885, 8.0602808], [93.4944458, 8.05972004], [93.4944458, 8.05888844], [93.49388885, 8.05833435], [93.49388885, 8.05722237], [93.49416351, 8.05694389], [93.49416351, 8.05472183], [93.4944458, 8.05444431], [93.4944458, 8.05389023], [93.49416351, 8.05360985], [93.49416351, 8.05333424], [93.49388885, 8.05305576], [93.49312592, 8.05201721], [93.49256897, 8.0511713], [93.49166107, 8.05028534], [93.49069214, 8.04952145], [93.49006653, 8.04924297], [93.48944092, 8.04952145], [93.48944855, 8.05000019], [93.48916626, 8.05027962], [93.48916626, 8.05056], [93.48832703, 8.05138969], [93.48805237, 8.05138779], [93.48750305, 8.05194378], [93.48722076, 8.05194378], [93.4861145, 8.0508337], [93.48500061, 8.05194378], [93.48500061, 8.05222225], [93.48472595, 8.05249977], [93.48472595, 8.05444431], [93.48443604, 8.05472183], [93.48444366, 8.05500031], [93.48416901, 8.05527782], [93.48416901, 8.05583191], [93.48388672, 8.05611038], [93.48388672, 8.0563879], [93.48416901, 8.05666637], [93.48416901, 8.05694389], [93.48443604, 8.05722046], [93.48443604, 8.05778122], [93.48472595, 8.05805588], [93.48472595, 8.05916595], [93.48500061, 8.05944443], [93.48500061, 8.06000042], [93.48472595, 8.06027889], [93.48472595, 8.06055737], [93.48443604, 8.06083012], [93.48443604, 8.06139088], [93.48472595, 8.06167126], [93.48472595, 8.06388855], [93.48444366, 8.06416702], [93.48443604, 8.06443977], [93.48388672, 8.06500053], [93.48388672, 8.06527901], [93.48361206, 8.06555462], [93.48361206, 8.06694508], [93.48332214, 8.06722069], [93.48332977, 8.06750107], [93.48388672, 8.06805515], [93.48388672, 8.06861115], [93.48416901, 8.06888866], [93.48416901, 8.06916714], [93.48443604, 8.06944084], [93.48443604, 8.07028198], [93.48416901, 8.07055473], [93.48416901, 8.07166672], [93.48388672, 8.07194328], [93.48388672, 8.07333279], [93.48361206, 8.07360935], [93.48361206, 8.07390118], [93.48332214, 8.07417202], [93.48332977, 8.07750034], [93.48305511, 8.07777786], [93.48305511, 8.07833385], [93.48278046, 8.07861233], [93.48278046, 8.07944393], [93.48249817, 8.07971001], [93.48249817, 8.0802803], [93.48221588, 8.08056068], [93.48222351, 8.08111], [93.48194122, 8.08138847], [93.48194122, 8.08194447], [93.48166656, 8.08222198], [93.48166656, 8.08277798], [93.48110962, 8.08333206], [93.48110962, 8.08416557], [93.48055267, 8.08471966], [93.48055267, 8.08500004], [93.48082733, 8.08528137], [93.48055267, 8.08555603], [93.48055267, 8.08611012], [93.48110962, 8.08667088], [93.48139191, 8.08667088], [93.48166656, 8.08639145], [93.48194122, 8.08639145], [93.48249817, 8.08584118], [93.48332977, 8.08583355], [93.48388672, 8.08631992], [93.48395538, 8.08687592], [93.48420715, 8.08719254], [93.48425293, 8.08725357], [93.48471832, 8.08744144], [93.4852829, 8.08722019], [93.48638153, 8.08722019], [93.48665619, 8.08750057], [93.48722076, 8.08750057], [93.48860931, 8.08888912], [93.48860931, 8.08944511], [93.4888916, 8.08972263], [93.4888916, 8.09000111], [93.48916626, 8.09027863], [93.48916626, 8.09055519], [93.48944092, 8.09083271], [93.48938751, 8.09160519], [93.48917389, 8.09194946], [93.48854828, 8.09250641], [93.48820496, 8.0929203], [93.48709106, 8.09333706], [93.48667145, 8.09360886], [93.4861908, 8.09409904], [93.48500824, 8.09500122], [93.48458862, 8.09534836], [93.48382568, 8.09569359], [93.48298645, 8.09583092], [93.48249817, 8.09590054], [93.48208618, 8.0961113], [93.48152924, 8.09639072], [93.48138428, 8.09636593], [93.48104095, 8.09631634], [93.48083496, 8.09610939], [93.48110962, 8.09583092], [93.48110962, 8.09527683], [93.48082733, 8.09536076], [93.48055267, 8.09459972], [93.47970581, 8.09321022], [93.47950745, 8.09278965], [93.47915649, 8.09182167], [93.47915649, 8.09071445], [93.47908783, 8.09050655], [93.47825623, 8.09030247], [93.47714233, 8.09154606], [93.47631073, 8.09293175], [93.47602844, 8.09342194], [93.47505951, 8.09438992], [93.47416687, 8.09528065], [93.47416687, 8.09555531], [93.47166443, 8.09805489], [93.4716568, 8.09833145], [93.47138977, 8.09861088], [93.47138977, 8.09888935], [93.47083282, 8.09944534], [93.47083282, 8.09972095], [93.47027588, 8.10027981], [93.47027588, 8.10055542], [93.47000122, 8.10083294], [93.47000122, 8.10111237], [93.46971893, 8.10139179], [93.46971893, 8.10167027], [93.46861267, 8.10277843], [93.46861267, 8.10305595], [93.46833038, 8.10333443], [93.46833038, 8.10361195], [93.46805573, 8.10388756], [93.46805573, 8.10416794], [93.46778107, 8.10444355], [93.46778107, 8.10472202], [93.46722412, 8.10527802], [93.46722412, 8.10555553], [93.46694183, 8.10583401], [93.46694183, 8.10611153], [93.46666718, 8.10639], [93.46666718, 8.10694408], [93.46639252, 8.1072216], [93.46639252, 8.10805607], [93.46611023, 8.10833168], [93.46611023, 8.10888767], [93.46583557, 8.10916615], [93.46583557, 8.10944366], [93.46611023, 8.10972214], [93.46611023, 8.11055565], [93.46639252, 8.11083221], [93.46639252, 8.1119442], [93.46611023, 8.11222172], [93.46611023, 8.11250019], [93.46389008, 8.11472034], [93.46389008, 8.11500072], [93.46416473, 8.1152792], [93.4641571, 8.11582088], [93.46499634, 8.11667061], [93.46527863, 8.11666679], [93.46555328, 8.11694527], [93.4658432, 8.11693954], [93.46601868, 8.11717701], [93.46607971, 8.11726379], [93.46624756, 8.11737061], [93.46649933, 8.11767578], [93.46726227, 8.11781502], [93.46817017, 8.11795044], [93.4683075, 8.11830997], [93.4681015, 8.11851025], [93.46678162, 8.11850834], [93.46611023, 8.11861134], [93.46555328, 8.11861134], [93.46527863, 8.11888885], [93.46499634, 8.11888027], [93.46472168, 8.11916924], [93.46463776, 8.1190834], [93.46444702, 8.11888885], [93.46389008, 8.11888885], [93.46360779, 8.11861134], [93.46250153, 8.11861134], [93.46221924, 8.11833286], [93.46166992, 8.11833286], [93.46083069, 8.11916733], [93.46083069, 8.11972141], [93.46055603, 8.12000084], [93.46055603, 8.1202774], [93.46028137, 8.12055492], [93.46028137, 8.1208334], [93.45999908, 8.12111092], [93.45999908, 8.1213913], [93.45972443, 8.12166691], [93.45972443, 8.12194538], [93.45944214, 8.12222099], [93.45944214, 8.12277699], [93.45916748, 8.12305546], [93.45916748, 8.12361145], [93.45888519, 8.12388897], [93.45888519, 8.12444305], [93.45916748, 8.12472057], [93.45916748, 8.12501144], [93.4597168, 8.12555981], [93.4597168, 8.12611103], [93.45999908, 8.12638855], [93.45999908, 8.1277771], [93.45972443, 8.12805462], [93.45972443, 8.12889004], [93.45916748, 8.12944317], [93.45916748, 8.12972164], [93.45805359, 8.13083363], [93.45805359, 8.13222218], [93.45833588, 8.13249969], [93.45833588, 8.13444424], [93.45861053, 8.13472176], [93.45888519, 8.13472176], [93.45999908, 8.13583374], [93.45999908, 8.13611031], [93.46083069, 8.13695145], [93.46111298, 8.13695145], [93.46166992, 8.13750172], [93.46221924, 8.13750172], [93.46250153, 8.13778114], [93.46277618, 8.13778114], [93.46305847, 8.13806057], [93.46333313, 8.1380558], [93.46472168, 8.13944435], [93.46472168, 8.13972187], [93.46444702, 8.14000034], [93.46444702, 8.14055729], [93.46416473, 8.14083195], [93.4641571, 8.14111042], [93.46389008, 8.14138794], [93.46389008, 8.14166641], [93.46360779, 8.14194489], [93.46360779, 8.14222336], [93.46250153, 8.14333344], [93.46111298, 8.14333344], [93.46055603, 8.14277554], [93.46028137, 8.14278126], [93.46001434, 8.14251041], [93.45992279, 8.14242077], [93.45944214, 8.14194489], [93.45916748, 8.14194489], [93.45861053, 8.14138794], [93.45833588, 8.14138794], [93.45694733, 8.14277554], [93.45694733, 8.14305687], [93.45666504, 8.14333344], [93.45667267, 8.14361095], [93.45639038, 8.14388943], [93.45639038, 8.14416695], [93.45610809, 8.14444542], [93.45610809, 8.14472008], [93.45583344, 8.14500141], [93.45583344, 8.14555454], [93.45555878, 8.14583302], [93.45555878, 8.1483326], [93.45500183, 8.14888859], [93.45500183, 8.15083313], [93.45471954, 8.15111065], [93.45527649, 8.15166664], [93.45527649, 8.15194321], [93.45534515, 8.15305805], [93.45555878, 8.15444565], [93.45555878, 8.15472126], [93.45582581, 8.1549902], [93.45582581, 8.15639019], [93.45610809, 8.15666962], [93.45652771, 8.15724659], [93.45659637, 8.15787125], [93.45639038, 8.15888977], [93.45610809, 8.15916634], [93.45610809, 8.15944386], [93.45555878, 8.15999985], [93.45555878, 8.16055584], [93.45527649, 8.16083431], [93.45527649, 8.16194439], [93.45500183, 8.16222191], [93.45500183, 8.1627779], [93.45471954, 8.16305637], [93.45471954, 8.16361237], [93.45444489, 8.16388798], [93.45444489, 8.16444397], [93.45417023, 8.16471958], [93.45417023, 8.16527843], [93.45388794, 8.16555595], [93.45388794, 8.16583443], [93.45361328, 8.16611004], [93.45361328, 8.16833019], [93.45417023, 8.16889095], [93.45433044, 8.16870403], [93.45465088, 8.16833019], [93.45485687, 8.16840267], [93.45500183, 8.16874886], [93.45500183, 8.16944027], [93.45500183, 8.17000103], [93.45471954, 8.17028141], [93.45500183, 8.17056084], [93.45500183, 8.17138863], [93.45471954, 8.1716671], [93.45471954, 8.17222118], [93.45443726, 8.17250061], [93.45444489, 8.17277908], [93.45417023, 8.1730547], [93.45417023, 8.17333317], [93.45388794, 8.17361069], [93.45417023, 8.17388916], [93.45417023, 8.17444515], [93.45443726, 8.1747179], [93.45443726, 8.17500114], [93.45500183, 8.1755619], [93.45527649, 8.17555523], [93.45583344, 8.17611122], [93.45610809, 8.17609978], [93.45667267, 8.17667198], [93.45722198, 8.17666721], [93.45749664, 8.17694473], [93.45777893, 8.17694473], [93.45861053, 8.1777792], [93.45861053, 8.17833328], [93.45944214, 8.17916679], [93.45999908, 8.17916679], [93.46028137, 8.17944527], [93.46221924, 8.17944527], [93.46250153, 8.17972088], [93.46360779, 8.17972088], [93.46389008, 8.17999935], [93.46527863, 8.17999935], [93.46555328, 8.18027973], [93.46611023, 8.18027687], [93.46666718, 8.18083286], [93.46694183, 8.18083286], [93.46916962, 8.18111134], [93.46943665, 8.18111134], [93.47000122, 8.18167019], [93.47027588, 8.18166542], [93.47083282, 8.18222141], [93.47110748, 8.1819458], [93.47138214, 8.18194103], [93.47194672, 8.18250179], [93.47249603, 8.18250179], [93.47277832, 8.18278027], [93.47333527, 8.18277836], [93.47457123, 8.18342304], [93.47519684, 8.18390846], [93.47595978, 8.18425179], [93.47705841, 8.18516064], [93.47756195, 8.18591595], [93.47784424, 8.18675041], [93.47818756, 8.18730164], [93.4789505, 8.1881361], [93.47930145, 8.18869019], [93.4796524, 8.18910694], [93.48006439, 8.1897974], [93.48040771, 8.1904192], [93.48069, 8.191185], [93.48097229, 8.1920166], [93.48131561, 8.19250298], [93.48180389, 8.19257069], [93.48278046, 8.19361019], [93.48278046, 8.19388771], [93.48332977, 8.1944437], [93.48443604, 8.19472027], [93.4852829, 8.19556141], [93.48555756, 8.19555664], [93.48583221, 8.19583225], [93.48610687, 8.19583035], [93.48638153, 8.19610977], [93.48665619, 8.19610977], [93.48694611, 8.19639111], [93.48750305, 8.19639111], [93.48777771, 8.19667053], [93.48833466, 8.19666672], [93.49055481, 8.19888878], [93.49055481, 8.20222092], [93.49028015, 8.2025013], [93.49028015, 8.20388889], [93.49055481, 8.20416737], [93.49054718, 8.20444107], [93.49138641, 8.20527744], [93.49138641, 8.20555496], [93.4916687, 8.20583344], [93.4916687, 8.20611095], [93.49194336, 8.20638943], [93.49194336, 8.20694542], [93.49222565, 8.20722103], [93.49222565, 8.20805454], [93.49250031, 8.20833302], [93.49250031, 8.21055603], [93.49223328, 8.21083069], [93.49223328, 8.21223068], [93.49194336, 8.21249962], [93.49194336, 8.21277809], [93.4916687, 8.21305561], [93.4916687, 8.21527767], [93.49194336, 8.21555614], [93.4916687, 8.21583366], [93.4916687, 8.21666622], [93.49111176, 8.21722221], [93.49138641, 8.21749973], [93.49138641, 8.21833038], [93.4916687, 8.21861172], [93.4916687, 8.21888828], [93.49194336, 8.2191658], [93.49194336, 8.21944427], [93.49222565, 8.21972179], [93.49222565, 8.22027779], [93.49277496, 8.22083473], [93.49277496, 8.22111034], [93.49465179, 8.22277355], [93.49632263, 8.2235384], [93.49806976, 8.22427368], [93.49855804, 8.22448063], [93.49945831, 8.22469139], [93.50036621, 8.22482777], [93.50237274, 8.22533798], [93.50326538, 8.22550392], [93.50376892, 8.22560024], [93.50428772, 8.22572994], [93.50483704, 8.22588062], [93.50534821, 8.22605801], [93.5058136, 8.22626781], [93.50624847, 8.22651196], [93.50665283, 8.22681046], [93.50700378, 8.22714996], [93.50733948, 8.22751522], [93.50765991, 8.22787189], [93.50800323, 8.2281847], [93.50837708, 8.22843075], [93.50881958, 8.22861099], [93.50927734, 8.2286911], [93.50972748, 8.22868156], [93.51014709, 8.2285614], [93.51056671, 8.22838974], [93.51098633, 8.22821236], [93.51140594, 8.228055], [93.51181793, 8.22795868], [93.5121994, 8.22794056], [93.51255798, 8.22802544], [93.51290894, 8.22816181], [93.51326752, 8.22831154], [93.51364136, 8.22846127], [93.51403046, 8.22863102], [93.51441956, 8.22885036], [93.5147934, 8.22914028], [93.51513672, 8.2294817], [93.51548767, 8.22982597], [93.51583099, 8.23013592], [93.51617432, 8.23037338], [93.51650238, 8.23052311], [93.51665497, 8.23055267], [93.51680756, 8.23058033], [93.51715088, 8.2305603], [93.51750946, 8.23052311], [93.5178833, 8.2305603], [93.51824188, 8.23073959], [93.51857758, 8.23106766], [93.5189209, 8.23150063], [93.51931, 8.23196125], [93.51976013, 8.23239422], [93.52026367, 8.23275948], [93.5207901, 8.23303509], [93.52129364, 8.2332058], [93.52176666, 8.23328114], [93.52220154, 8.23327637], [93.52259064, 8.23321533], [93.52296448, 8.23312378], [93.52336121, 8.23302078], [93.52378082, 8.23290539], [93.5242157, 8.23275948], [93.52462769, 8.23256111], [93.52498627, 8.23231697], [93.52527618, 8.23204327], [93.52552032, 8.23178101], [93.52577972, 8.23155594], [93.52610016, 8.23138046], [93.52648926, 8.23127079], [93.52693939, 8.2312336], [93.52739716, 8.23127079], [93.52784729, 8.23136425], [93.52829742, 8.23147583], [93.52877045, 8.23156929], [93.52929688, 8.23163128], [93.52986145, 8.23163128], [93.53042603, 8.23156166], [93.53095245, 8.23141193], [93.53141785, 8.23119068], [93.53183746, 8.23093128], [93.53225708, 8.23067093], [93.53269196, 8.23043919], [93.53314972, 8.23024273], [93.53359985, 8.23005962], [93.53404236, 8.22990131], [93.53449249, 8.22977638], [93.5349884, 8.22967052], [93.53559875, 8.22959328], [93.53639984, 8.22955894], [93.53682709, 8.22956085], [93.53723907, 8.22957039], [93.5375061, 8.22945023], [93.53778076, 8.22916698], [93.53805542, 8.22888947], [93.53861237, 8.22889137], [93.53916931, 8.22833061], [93.53944397, 8.22833347], [93.54083252, 8.22694492], [93.54111481, 8.22694492], [93.54138947, 8.2266674], [93.54165649, 8.22667122], [93.54194641, 8.22639084], [93.54222107, 8.22639084], [93.54250336, 8.22611141], [93.54277802, 8.22611141], [93.54333496, 8.22555542], [93.54360199, 8.22555923], [93.54416656, 8.22500134], [93.54473877, 8.22325039], [93.54550171, 8.22110271], [93.54557037, 8.21936893], [93.54563141, 8.21722889], [93.54563141, 8.21536541], [93.54556274, 8.2139082], [93.54563141, 8.21273041], [93.54590607, 8.21155167], [93.54653168, 8.21085644], [93.54682159, 8.21016979], [93.54638672, 8.20778179], [93.54638672, 8.20750237], [93.54611206, 8.20722103], [93.54611206, 8.20444489], [93.54638672, 8.20416737], [93.54638672, 8.20277691], [93.54582977, 8.20222092], [93.54582977, 8.20083332], [93.54555511, 8.20055485], [93.54555511, 8.19916725], [93.54528046, 8.19889069], [93.54528046, 8.19778061], [93.54499817, 8.19750118], [93.54499817, 8.19722271], [93.54471588, 8.19694042], [93.54472351, 8.19610977], [93.54416656, 8.19555664], [93.54416656, 8.19528103], [93.54277802, 8.19389057], [93.54277802, 8.19361019], [93.54250336, 8.19333363], [93.54250336, 8.1930542], [93.54166412, 8.19222164], [93.54111481, 8.19222164], [93.54021454, 8.19214916], [93.53965759, 8.19200993], [93.53909302, 8.19187069], [93.53868103, 8.19126034], [93.53798676, 8.19048977], [93.53778076, 8.18972015], [93.53778076, 8.18861198], [93.53805542, 8.18833447], [93.53805542, 8.1875], [93.53778076, 8.18722153], [93.53778076, 8.18666553], [93.53805542, 8.18638992], [93.53806305, 8.18556023], [93.53778076, 8.18529129], [93.53778076, 8.18472195], [93.53666687, 8.18361187], [93.53666687, 8.18333435], [93.53639221, 8.18305588], [93.53639221, 8.18277836], [93.53610992, 8.18250179], [93.53610992, 8.18194103], [93.53583527, 8.18166542], [93.53583527, 8.18138981], [93.53555298, 8.18111134], [93.53555298, 8.18083286], [93.53500366, 8.18027687], [93.53500366, 8.17999935], [93.53305817, 8.17805958], [93.53277588, 8.17805958], [93.53193665, 8.1772213], [93.53166962, 8.17722321], [93.53055573, 8.17611122], [93.53028107, 8.17611122], [93.52749634, 8.17333317], [93.52722168, 8.17333317], [93.52605438, 8.17216587], [93.52527618, 8.17138863], [93.52500153, 8.17138863], [93.52416992, 8.17222118], [93.52416992, 8.17278099], [93.52388763, 8.1730547], [93.52388763, 8.17361069], [93.52444458, 8.17416668], [93.52443695, 8.17444038], [93.5266571, 8.17667198], [93.52694702, 8.17666721], [93.52722168, 8.17694473], [93.52861023, 8.17694473], [93.52889252, 8.17722321], [93.52944183, 8.17722321], [93.53277588, 8.18055534], [93.53305817, 8.18083286], [93.53305817, 8.18111134], [93.53360748, 8.18166542], [93.53360748, 8.1819458], [93.53388977, 8.18222141], [93.53388977, 8.18250179], [93.53395844, 8.182971], [93.5341568, 8.18352127], [93.53410339, 8.18373013], [93.53382111, 8.1838007], [93.53347015, 8.18365955], [93.53277588, 8.18333054], [93.53250122, 8.18305588], [93.53221893, 8.18305969], [93.53138733, 8.18222141], [93.53111267, 8.18222141], [93.53083038, 8.1819458], [93.53028107, 8.1819458], [93.52999878, 8.18166542], [93.52971649, 8.18167019], [93.52916718, 8.18111134], [93.52889252, 8.18111134], [93.52838135, 8.18060112], [93.52583313, 8.17805481], [93.52583313, 8.1777792], [93.52555847, 8.17750072], [93.52555847, 8.1772213], [93.52416992, 8.17583275], [93.52416992, 8.17555523], [93.52361298, 8.17500114], [93.52361298, 8.17416668], [93.52166748, 8.17222118], [93.52081299, 8.17243004], [93.52032471, 8.17277718], [93.51983643, 8.1729126], [93.51900482, 8.1729126], [93.51872253, 8.17277718], [93.51837921, 8.17278099], [93.51809692, 8.17263985], [93.51782227, 8.17256927], [93.51753998, 8.17228889], [93.51719666, 8.17180634], [93.51691437, 8.1714592], [93.51635742, 8.17097187], [93.51615143, 8.17062664], [93.51566315, 8.17007446], [93.51503754, 8.1698637], [93.51438141, 8.17007065], [93.51377106, 8.16979122], [93.51229095, 8.16944027], [93.51194763, 8.1691637], [93.51139069, 8.16867924], [93.51076508, 8.16826153], [93.51055908, 8.16749954], [93.51055908, 8.16722202], [93.51027679, 8.16694355], [93.51027679, 8.16666603], [93.51000214, 8.16638756], [93.51000214, 8.16611004], [93.50971985, 8.16583443], [93.50971985, 8.16416645], [93.51000214, 8.16388798], [93.51000214, 8.16361237], [93.51055908, 8.16305637], [93.5111084, 8.16306114], [93.51197052, 8.16300106], [93.51232147, 8.1630106], [93.51267242, 8.16273499], [93.51280975, 8.16211033], [93.51264191, 8.1612854], [93.51235962, 8.16073132], [93.51222229, 8.16017532], [93.5120163, 8.15962124], [93.51194763, 8.15927505], [93.51187134, 8.15886021], [93.5120163, 8.15837002], [93.51194763, 8.15775013], [93.51180267, 8.15747547], [93.51152802, 8.15719891], [93.51125336, 8.15684986], [93.51035309, 8.15622997], [93.50978851, 8.15617085], [93.50943756, 8.15609074], [93.50874329, 8.15609074], [93.50811768, 8.15601063], [93.50793457, 8.15523624], [93.50786591, 8.15482235], [93.50786591, 8.15377998], [93.50793457, 8.1532259], [93.50792694, 8.15287971], [93.50814819, 8.15274143], [93.50805664, 8.1524992], [93.50778961, 8.15226364], [93.50730133, 8.1515007], [93.50723267, 8.15101528], [93.50710297, 8.15067101], [93.50710297, 8.15045929], [93.50737, 8.14983654], [93.50737, 8.14935207], [93.50730133, 8.14921284], [93.50674438, 8.14893723], [93.50666809, 8.14861107], [93.50563049, 8.14852905], [93.50514221, 8.14859962], [93.5045166, 8.14866829], [93.50423431, 8.148736], [93.50389099, 8.148736], [93.5036087, 8.14866829], [93.50319672, 8.14853096], [93.50305176, 8.14818001], [93.50326538, 8.14804268], [93.50354004, 8.14735126], [93.5036087, 8.14722347], [93.50389099, 8.146945], [93.50389099, 8.14666653], [93.50416565, 8.14638901], [93.50417328, 8.14555931], [93.50428772, 8.14451981], [93.50435638, 8.14430141], [93.50491333, 8.14381599], [93.50526428, 8.14360809], [93.50547028, 8.14346886], [93.50588989, 8.14291477], [93.50609589, 8.14243031], [93.50652313, 8.14201069], [93.50722504, 8.14194489], [93.50749969, 8.14194489], [93.50777435, 8.14166641], [93.50805664, 8.14167118], [93.51082611, 8.13889027], [93.5111084, 8.13889027], [93.51167297, 8.13833046], [93.51194763, 8.13833427], [93.51249695, 8.13777828], [93.51277924, 8.13778114], [93.51361847, 8.13695145], [93.51361847, 8.13667107], [93.5147171, 8.13556099], [93.5147171, 8.13527966], [93.51499939, 8.13500023], [93.51499939, 8.13444424], [93.51527405, 8.13416576], [93.51527405, 8.13389015], [93.51555634, 8.13361168], [93.51555634, 8.13332939], [93.51583099, 8.13305569], [93.51583099, 8.13277817], [93.51638794, 8.13221931], [93.51638794, 8.1319437], [93.51805878, 8.13027763], [93.51832581, 8.13027954], [93.51931763, 8.12833977], [93.51980591, 8.12799168], [93.5202179, 8.12730122], [93.52043152, 8.12674522], [93.52056885, 8.12639904], [93.52063751, 8.12549782], [93.52056885, 8.12514019], [93.52077484, 8.12487411], [93.52133179, 8.12494373], [93.52209473, 8.12445927], [93.52300262, 8.12334919], [93.52416992, 8.12250137], [93.52388763, 8.12222099], [93.52388763, 8.12194538], [93.52416992, 8.12166691], [93.52416992, 8.12111092], [93.52583313, 8.11944485], [93.52583313, 8.11722279], [93.52610779, 8.11694527], [93.52610779, 8.11666679], [93.52694702, 8.11583233], [93.52694702, 8.11555672], [93.52722168, 8.1152792], [93.52722168, 8.11472034], [93.52749634, 8.11444378], [93.52749634, 8.11416626], [93.52777863, 8.11388779], [93.52777863, 8.11361027], [93.52805328, 8.11333466], [93.52840424, 8.11261368], [93.52861023, 8.11166573], [93.52861023, 8.11083221], [93.52889252, 8.11055565], [93.52889252, 8.11027813], [93.52897644, 8.11013889], [93.52999878, 8.10888767], [93.52999878, 8.10805607], [93.53111267, 8.10693932], [93.53111267, 8.10666561], [93.53138733, 8.10639], [93.53138733, 8.10610962], [93.53166962, 8.10583401], [93.53166962, 8.10555553], [93.53194427, 8.10527802], [93.53193665, 8.10499954], [93.53221893, 8.10472202], [93.53221893, 8.10444355], [93.53194427, 8.10416794], [93.53194427, 8.10333443], [93.53166962, 8.10305595], [93.53166962, 8.09972095], [93.53194427, 8.09944534], [93.53194427, 8.09916687], [93.53416443, 8.09694481], [93.53450012, 8.09640694], [93.53560638, 8.09619999], [93.53666687, 8.09500122], [93.53694153, 8.09500122], [93.53722382, 8.09472084], [93.53749847, 8.09472084], [93.53778076, 8.09444523], [93.53805542, 8.09444523], [93.53833008, 8.09416676], [93.53833008, 8.09388924], [93.53888702, 8.09333134], [93.53916931, 8.09333324], [93.53944397, 8.09305477], [93.53944397, 8.09277916], [93.54083252, 8.09139061], [93.54110718, 8.09139061], [93.54138947, 8.09111118], [93.54194641, 8.09111118], [93.54212952, 8.09091854], [93.54317474, 8.09070969], [93.54393768, 8.0905714], [93.54582977, 8.09055519], [93.54611206, 8.09056091], [93.54833221, 8.08833027], [93.54833221, 8.08694363], [93.5486145, 8.08666611], [93.5486145, 8.08472157], [93.54888916, 8.08444405], [93.54888916, 8.08416557], [93.54916382, 8.08388805], [93.54915619, 8.08360958], [93.54944611, 8.08333206], [93.54944611, 8.08305645], [93.54972076, 8.08277798], [93.54972076, 8.08250046], [93.55000305, 8.08222198], [93.55000305, 8.08194447], [93.55027771, 8.08166599], [93.55027771, 8.08138847], [93.55055237, 8.08111], [93.55055237, 8.08083439], [93.55083466, 8.08055592], [93.55083466, 8.0797224], [93.55055237, 8.07944393], [93.55055237, 8.07888985], [93.55027771, 8.07861233], [93.55027771, 8.07666779], [93.55055237, 8.07639027], [93.55055237, 8.07611179], [93.55194092, 8.07472134], [93.55194092, 8.07416534], [93.55222321, 8.07388973], [93.55222321, 8.07306004], [93.55249786, 8.07277966], [93.55222321, 8.07249928], [93.55222321, 8.07194328], [93.55194092, 8.07166672], [93.55194092, 8.07027721], [93.55222321, 8.07000065], [93.55222321, 8.06917191], [93.55249786, 8.06889057], [93.55249786, 8.06833076], [93.55278015, 8.06805515], [93.55278015, 8.0672226], [93.55305481, 8.06694508], [93.55305481, 8.06638908], [93.55278015, 8.06611061], [93.55229187, 8.06603813], [93.55187225, 8.06582832], [93.55152893, 8.06528091], [93.5515976, 8.06464958], [93.55083466, 8.06388855], [93.55082703, 8.06194019], [93.55055237, 8.06166744], [93.55055237, 8.06055737], [93.55027771, 8.0602808], [93.55027771, 8.05943966], [93.55000305, 8.05916595], [93.55000305, 8.05888844], [93.54972076, 8.05860996], [93.54972076, 8.05777836], [93.55000305, 8.05749989], [93.55000305, 8.05722046], [93.54944611, 8.05666637], [93.54915619, 8.05667114], [93.54860687, 8.05611038], [93.5486145, 8.05305576], [93.54916382, 8.05249977], [93.54915619, 8.05138969], [93.54888916, 8.05111027], [93.54888916, 8.05055618], [93.5486145, 8.05027771], [93.54860687, 8.05000019], [93.5477829, 8.04916954], [93.54750061, 8.0494442], [93.54693604, 8.04944134], [93.54666138, 8.04973125], [93.54611206, 8.04973125], [93.54582977, 8.04944134], [93.54555511, 8.0494442], [93.54534912, 8.0492363], [93.54533386, 8.04915619], [93.54528046, 8.04889202], [93.54722595, 8.0469389], [93.54722595, 8.04666805], [93.5486145, 8.04527664], [93.54860687, 8.04444122], [93.54916382, 8.04388905], [93.54916382, 8.04333305], [93.54944611, 8.04305458], [93.54944611, 8.04249859], [93.54972076, 8.04222107], [93.54972076, 8.04083347], [93.54944611, 8.040555], [93.54944611, 8.03888893], [93.54972076, 8.03861141], [93.54972076, 8.03777885], [93.55000305, 8.03750134], [93.55000305, 8.03666687], [93.55027771, 8.03639126], [93.55027771, 8.03611088], [93.55000305, 8.03583336], [93.55000305, 8.03555679], [93.54972076, 8.03527641], [93.54916382, 8.03527641], [93.5486145, 8.03583336], [93.54777527, 8.03583336], [93.54750061, 8.03611088], [93.54666138, 8.03611088], [93.54638672, 8.03639126], [93.54582977, 8.03639126], [93.54567719, 8.03681946], [93.54532623, 8.03689003], [93.54491425, 8.03688812], [93.54450226, 8.03722954], [93.54412079, 8.03731155], [93.54376984, 8.03738022], [93.54250336, 8.03750134], [93.54222107, 8.03722286], [93.54194641, 8.03750134], [93.54165649, 8.03750134], [93.5402832, 8.03889084], [93.54000092, 8.03889084], [93.53971863, 8.03916931], [93.53944397, 8.0391674], [93.53916931, 8.03944492], [93.53916931, 8.03972054], [93.53943634, 8.04000092], [93.53943634, 8.0402813], [93.53971863, 8.040555], [93.53971863, 8.04166698], [93.53944397, 8.04194546], [93.53944397, 8.04222107], [93.53805542, 8.04361057], [93.53694153, 8.04361057], [93.5358429, 8.04472065], [93.53583527, 8.04527664], [93.53610992, 8.04555511], [93.53610992, 8.04611111], [93.53617859, 8.04652596], [93.53590393, 8.04708195], [93.53527832, 8.04694557], [93.53416443, 8.04694557], [93.53388977, 8.04722118], [93.53360748, 8.04722118], [93.53333282, 8.04750156], [93.53305817, 8.04750156], [93.53277588, 8.04778194], [93.53250122, 8.04778194]]], [[[92.60888672, 10.93861008], [92.60916901, 10.93833542], [92.61000061, 10.93833542], [92.61027527, 10.93805695], [92.61076355, 10.93784904], [92.61222076, 10.93638992], [92.61292267, 10.93612194], [92.61360168, 10.93556118], [92.61458588, 10.93492985], [92.61576843, 10.93479061], [92.61666107, 10.93500042], [92.61704254, 10.93462563], [92.61723328, 10.93443966], [92.61750031, 10.93444443], [92.61805725, 10.93388844], [92.61833191, 10.93389034], [92.61902618, 10.93278027], [92.61923218, 10.93236065], [92.61999512, 10.93118286], [92.62034607, 10.93062687], [92.62090302, 10.92993355], [92.62000275, 10.92861176], [92.61937714, 10.92819691], [92.61854553, 10.92784405], [92.61763763, 10.92763615], [92.61722565, 10.92749691], [92.61694336, 10.92750168], [92.61682129, 10.92743111], [92.61631775, 10.92736053], [92.61569214, 10.92729187], [92.61507416, 10.92715454], [92.61444092, 10.92722225], [92.61416626, 10.92721939], [92.6138916, 10.92750168], [92.61332703, 10.92750168], [92.61277771, 10.92785072], [92.61222076, 10.92805576], [92.61118317, 10.92882061], [92.61083221, 10.92916775], [92.6102066, 10.92965317], [92.60972595, 10.92998791], [92.60943604, 10.93027973], [92.60909271, 10.93041706], [92.60832977, 10.93166637], [92.60798645, 10.93194199], [92.60778046, 10.93250179], [92.60778046, 10.93277836], [92.60639191, 10.93416595], [92.60639191, 10.93444443], [92.60610962, 10.93472195], [92.60610962, 10.93555641], [92.60583496, 10.93583202], [92.60582733, 10.93694019], [92.60694122, 10.93806076], [92.60778046, 10.93805695], [92.60805511, 10.93833542], [92.60832977, 10.93833542], [92.60861206, 10.93861008], [92.60888672, 10.93861008]]], [[[92.22673798, 10.98229027], [92.22736359, 10.9822216], [92.22777557, 10.9822216], [92.22805786, 10.9822216], [92.22833252, 10.98222446], [92.22861481, 10.9822216], [92.22861481, 10.98194408], [92.22888947, 10.98166466], [92.22888947, 10.98111153], [92.22916412, 10.98083401], [92.22916412, 10.98027802], [92.22868347, 10.97930431], [92.22860718, 10.97881889], [92.22860718, 10.9779892], [92.22846985, 10.97771072], [92.22792053, 10.97611141], [92.22743225, 10.97590446], [92.22694397, 10.97555542], [92.22645569, 10.97534847], [92.22611237, 10.97529125], [92.22583008, 10.97507191], [92.22471619, 10.97417164], [92.22409821, 10.97389126], [92.22333527, 10.97361088], [92.22298431, 10.97340393], [92.22222137, 10.97277737], [92.22181702, 10.97277927], [92.22084045, 10.97249889], [92.22014618, 10.97249889], [92.21930695, 10.97243023], [92.21888733, 10.97249889], [92.21861267, 10.97249889], [92.21833038, 10.97277927], [92.21806335, 10.9730587], [92.21778107, 10.97305489], [92.21749878, 10.97333336], [92.21749878, 10.97361088], [92.21639252, 10.97472095], [92.21640015, 10.97500134], [92.21611023, 10.97527695], [92.21611023, 10.97555542], [92.21583557, 10.97583294], [92.21583557, 10.97611141], [92.21499634, 10.97694302], [92.21499634, 10.9772234], [92.21472168, 10.97749901], [92.21472168, 10.97833347], [92.21499634, 10.97861099], [92.21499634, 10.97889042], [92.21602631, 10.97948933], [92.21727753, 10.98018169], [92.21839142, 10.98087215], [92.21916199, 10.98163128], [92.22006989, 10.9821167], [92.22090912, 10.98260021], [92.22138977, 10.98291874], [92.22222137, 10.98312569], [92.22250366, 10.98326302], [92.22312164, 10.9831934], [92.22360992, 10.98305321], [92.22423553, 10.98298454], [92.22451782, 10.9827776], [92.22479248, 10.98270035], [92.22499847, 10.98250008], [92.2260437, 10.98236084], [92.22673798, 10.98229027]]], [[[92.66335297, 10.98180008], [92.66194153, 10.98139191], [92.66166687, 10.98167038], [92.66139221, 10.98167038], [92.66110992, 10.98166466], [92.65972137, 10.98305607], [92.65972137, 10.98333359], [92.65944672, 10.98361206], [92.65944672, 10.98388767], [92.65916443, 10.98416805], [92.6591568, 10.98472023], [92.6588974, 10.98499966], [92.65888977, 10.98527813], [92.65860748, 10.98555565], [92.65844727, 10.98655033], [92.65846252, 10.98696709], [92.65866852, 10.98744965], [92.65873718, 10.9880724], [92.65873718, 10.98862076], [92.65895081, 10.98924637], [92.65901947, 10.98986816], [92.65936279, 10.99042225], [92.65950775, 10.99104404], [92.66020203, 10.99166584], [92.66083527, 10.99222183], [92.66110992, 10.99222183], [92.66139221, 10.99250126], [92.66166687, 10.99250126], [92.66194153, 10.99277878], [92.66284943, 10.99281025], [92.6635437, 10.99281025], [92.66487122, 10.99273968], [92.66563416, 10.9926033], [92.66647339, 10.99218845], [92.66772461, 10.99170494], [92.66861725, 10.99110126], [92.66929626, 10.99004078], [92.66951752, 10.98942089], [92.66979218, 10.98845291], [92.66979218, 10.98748398], [92.66951752, 10.98679447], [92.66916656, 10.98583412], [92.66916656, 10.98555565], [92.66777802, 10.98416805], [92.66750336, 10.98416805], [92.66721344, 10.98393822], [92.66694641, 10.98388958], [92.66638947, 10.98333168], [92.66600037, 10.98296928], [92.66474152, 10.98228073], [92.66335297, 10.98180008]]], [[[92.73194122, 11.14973068], [92.73249817, 11.14917088], [92.73278046, 11.14917088], [92.73332977, 11.14861202], [92.73339844, 11.14833641], [92.73423767, 11.14785099], [92.73443604, 11.14693928], [92.73472595, 11.14666557], [92.73472595, 11.14611244], [92.73500061, 11.14583397], [92.73500061, 11.14555645], [92.73444366, 11.14500046], [92.73416901, 11.14500046], [92.73388672, 11.14472198], [92.73361206, 11.14458466], [92.73319244, 11.14402866], [92.73256683, 11.14285278], [92.73139191, 11.14194584], [92.73110962, 11.14194584], [92.73083496, 11.14166546], [92.73027802, 11.14145756], [92.72944641, 11.14215279], [92.72916412, 11.14222145], [92.7277832, 11.14360046], [92.72777557, 11.14388847], [92.72750092, 11.1441679], [92.72750092, 11.14444447], [92.72721863, 11.14472198], [92.72721863, 11.14500046], [92.72694397, 11.14527798], [92.72694397, 11.14555645], [92.72721863, 11.14583397], [92.72721863, 11.14611244], [92.72846985, 11.14770985], [92.72902679, 11.14804935], [92.73110962, 11.14973068], [92.73194122, 11.14973068]]], [[[92.67694092, 11.18361092], [92.67749786, 11.18305683], [92.67804718, 11.18306065], [92.6783371, 11.18278122], [92.67888641, 11.18278122], [92.6791687, 11.18250275], [92.67944336, 11.18250275], [92.67973328, 11.18222046], [92.68000031, 11.18222332], [92.6811142, 11.18111038], [92.6811142, 11.18055439], [92.68055725, 11.18000031], [92.68026733, 11.18000031], [92.67804718, 11.17778111], [92.67804718, 11.17749977], [92.67749786, 11.17694187], [92.67722321, 11.17694187], [92.67666626, 11.17749977], [92.6763916, 11.17749977], [92.67610931, 11.17778111], [92.67583466, 11.17777824], [92.67555237, 11.17805576], [92.67555237, 11.17833424], [92.67610931, 11.17888832], [92.67610931, 11.17971134], [92.67555237, 11.18027782], [92.67555237, 11.18055439], [92.67500305, 11.18111038], [92.67527771, 11.1813879], [92.67500305, 11.18166637], [92.67500305, 11.18194485], [92.67472076, 11.18222046], [92.67472076, 11.18250275], [92.67444611, 11.18277645], [92.67444611, 11.18305683], [92.67415619, 11.18332958], [92.67416382, 11.18388939], [92.67388916, 11.18416691], [92.67388916, 11.18444538], [92.67333221, 11.18500137], [92.67333221, 11.18527889], [92.67305756, 11.18555546], [92.67305756, 11.18694019], [92.67360687, 11.18750095], [92.6736145, 11.18777657], [92.67388916, 11.18805504], [92.67389679, 11.18833065], [92.67416382, 11.18861103], [92.67416382, 11.18888855], [92.67472076, 11.18944454], [92.67555237, 11.18944454], [92.6763916, 11.18861103], [92.6763916, 11.18833256], [92.67666626, 11.18805504], [92.67666626, 11.18694496], [92.67694092, 11.18666744], [92.67694092, 11.18638897], [92.67666626, 11.18611145], [92.67666626, 11.18583298], [92.6763916, 11.18555546], [92.6763916, 11.18500137], [92.67666626, 11.1847229], [92.67666626, 11.18416691], [92.67694092, 11.18388939], [92.67694092, 11.18361092]]], [[[92.70597839, 11.28916645], [92.70639038, 11.28833008], [92.70659637, 11.28763676], [92.70694733, 11.28735924], [92.70694733, 11.28708076], [92.70722198, 11.28673458], [92.70722198, 11.28652668], [92.70722198, 11.28610992], [92.70722198, 11.28582954], [92.70694733, 11.28555584], [92.70694733, 11.28528976], [92.70687866, 11.28479099], [92.70687866, 11.28444195], [92.70749664, 11.28333378], [92.70749664, 11.28277779], [92.70722198, 11.28250027], [92.70722198, 11.28222179], [92.70659637, 11.28125095], [92.70659637, 11.28020859], [92.70667267, 11.27993107], [92.70667267, 11.27971935], [92.7069397, 11.27916622], [92.7069397, 11.27833366], [92.70666504, 11.27777767], [92.70667267, 11.27750015], [92.7059021, 11.27659702], [92.7059021, 11.27590179], [92.70610809, 11.27527714], [92.70610809, 11.27472115], [92.70639038, 11.27444553], [92.70639038, 11.2733326], [92.70666504, 11.27305508], [92.70667267, 11.27250099], [92.70639038, 11.27222061], [92.70639038, 11.27166653], [92.70582581, 11.27111053], [92.70583344, 11.27083302], [92.70555878, 11.27055454], [92.70555878, 11.27028179], [92.70527649, 11.27000141], [92.70527649, 11.26889133], [92.70555878, 11.26861095], [92.70555878, 11.26750088], [92.70639038, 11.26666927], [92.70639038, 11.2650013], [92.70610809, 11.26471996], [92.70583344, 11.26416683], [92.70583344, 11.26305676], [92.70388031, 11.26112175], [92.70361328, 11.26112175], [92.70305634, 11.26056099], [92.70305634, 11.26000023], [92.7022171, 11.25917053], [92.70139313, 11.25917053], [92.70110321, 11.25893402], [92.70083618, 11.25889015], [92.70069885, 11.25874901], [92.70027924, 11.25833035], [92.69999695, 11.25833416], [92.69916534, 11.25749969], [92.69902802, 11.25729275], [92.69880676, 11.25624657], [92.69832611, 11.25556087], [92.69721985, 11.25443935], [92.69694519, 11.25444412], [92.69472504, 11.25222206], [92.69472504, 11.25194359], [92.69451904, 11.25145817], [92.69444275, 11.25111198], [92.69444275, 11.25083065], [92.69472504, 11.25055599], [92.69473267, 11.25028038], [92.69444275, 11.25000191], [92.69444275, 11.24918079], [92.69500732, 11.2486124], [92.69499969, 11.24833298], [92.69527435, 11.24805546], [92.69526672, 11.24777985], [92.69473267, 11.24722099], [92.69472504, 11.24694538], [92.69444275, 11.24666691], [92.69444275, 11.24638939], [92.69416809, 11.24612045], [92.69416809, 11.24555969], [92.6938858, 11.24527931], [92.6938858, 11.24500084], [92.69361115, 11.24472141], [92.69361115, 11.24388885], [92.69333649, 11.24361134], [92.69333649, 11.24333286], [92.69277954, 11.24277687], [92.69249725, 11.24278164], [92.6922226, 11.24250126], [92.69139099, 11.24250126], [92.6911087, 11.24278164], [92.69055176, 11.24278164], [92.6902771, 11.24250126], [92.68972015, 11.24250126], [92.68945313, 11.24222088], [92.6883316, 11.24222088], [92.68736267, 11.24208164], [92.68722534, 11.24277687], [92.68723297, 11.24333096], [92.68776703, 11.24389076], [92.68777466, 11.24416733], [92.68805695, 11.24444103], [92.68805695, 11.24500084], [92.6875, 11.24555969], [92.6875, 11.24638939], [92.68972015, 11.2486124], [92.68972015, 11.24889183], [92.69000244, 11.24916458], [92.69000244, 11.24972057], [92.6902771, 11.25000191], [92.6902771, 11.25055599], [92.69055176, 11.25083065], [92.69055176, 11.25111198], [92.6911087, 11.25166798], [92.6911087, 11.25194359], [92.69139099, 11.2522192], [92.69139099, 11.25249958], [92.69194794, 11.25305557], [92.69194794, 11.25444412], [92.6922226, 11.25472164], [92.6922226, 11.25583363], [92.69361115, 11.25722218], [92.6938858, 11.25722027], [92.69416809, 11.25749969], [92.69444275, 11.25749969], [92.69473267, 11.25778103], [92.69472504, 11.25805569], [92.69499969, 11.25833416], [92.69500732, 11.25860977], [92.69526672, 11.25889015], [92.69527435, 11.25916576], [92.6958313, 11.25971985], [92.6958313, 11.26000023], [92.6966629, 11.26082993], [92.6966629, 11.26139069], [92.69694519, 11.2616663], [92.69694519, 11.26194382], [92.6966629, 11.26222324], [92.6966629, 11.2624979], [92.69638824, 11.26277637], [92.69638824, 11.26416683], [92.69610596, 11.26443958], [92.69610596, 11.2650013], [92.69555664, 11.26555538], [92.69555664, 11.2658329], [92.69526672, 11.26611137], [92.69526672, 11.26638889], [92.69500732, 11.26666927], [92.69499969, 11.26777744], [92.69444275, 11.26833057], [92.69444275, 11.26861095], [92.69361115, 11.26944542], [92.69361115, 11.26972103], [92.69333649, 11.27000141], [92.69333649, 11.27055454], [92.6930542, 11.27083302], [92.69304657, 11.27222061], [92.69333649, 11.27249908], [92.69333649, 11.27333069], [92.69361115, 11.27361107], [92.69381714, 11.27437496], [92.6938858, 11.27472115], [92.69381714, 11.27507019], [92.69361115, 11.27610016], [92.69322205, 11.27673244], [92.69322205, 11.27713871], [92.69301605, 11.27796936], [92.69307709, 11.27852058], [92.69287872, 11.27893543], [92.69277954, 11.27971935], [92.69277954, 11.27999973], [92.69249725, 11.28027821], [92.69249725, 11.2808342], [92.69277954, 11.28110981], [92.69277954, 11.28139019], [92.69444275, 11.28306103], [92.69444275, 11.2841711], [92.69526672, 11.28499985], [92.69610596, 11.28499985], [92.69638824, 11.28528976], [92.6966629, 11.28528976], [92.69695282, 11.28556061], [92.69721985, 11.28555584], [92.69750214, 11.28583431], [92.69777679, 11.28583431], [92.69805908, 11.28610992], [92.69832611, 11.28610992], [92.6986084, 11.2863903], [92.69889069, 11.2863903], [92.69917297, 11.28667068], [92.69972229, 11.28666592], [92.70027924, 11.28722191], [92.70055389, 11.28722191], [92.70166779, 11.28833199], [92.70194244, 11.28833199], [92.70222473, 11.28861046], [92.70252228, 11.28863335], [92.70276642, 11.28889084], [92.70333099, 11.28889084], [92.70361328, 11.28861046], [92.70417023, 11.28861046], [92.70443726, 11.28889084], [92.70471954, 11.28888798], [92.70527649, 11.28944492], [92.70555878, 11.28944492], [92.70597839, 11.28916645]]], [[[92.72566223, 11.14421844], [92.72576141, 11.14415932], [92.72589874, 11.14381504], [92.72589874, 11.1434679], [92.72583008, 11.14305592], [92.72583008, 11.14249992], [92.72556305, 11.14222145], [92.72555542, 11.14166546], [92.72528076, 11.14138985], [92.72528076, 11.14111233], [92.72444153, 11.14027691], [92.72416687, 11.14027977], [92.72389221, 11.14056015], [92.72360992, 11.14055538], [92.72277832, 11.14138985], [92.72277832, 11.14194584], [92.72249603, 11.14222145], [92.72250366, 11.14249992], [92.72277832, 11.1427784], [92.72277832, 11.14333057], [92.7233429, 11.14389038], [92.72444153, 11.14389038], [92.72471619, 11.14416981], [92.72499847, 11.1441679], [92.72528076, 11.14444447], [92.72566223, 11.14421844]]], [[[92.54833221, 11.39302921], [92.54801941, 11.392869], [92.54749298, 11.3931179], [92.54696655, 11.39356709], [92.5464859, 11.39395428], [92.54610443, 11.39437389], [92.54577637, 11.39484119], [92.54567719, 11.39538765], [92.54588318, 11.39592075], [92.54627991, 11.39636612], [92.54673004, 11.39671421], [92.54721832, 11.39695072], [92.54766846, 11.39715576], [92.54815674, 11.3972702], [92.54860687, 11.39744759], [92.54911804, 11.39749241], [92.54960632, 11.39745045], [92.55001831, 11.3972702], [92.55036926, 11.39717484], [92.5506134, 11.3970108], [92.55084229, 11.39680481], [92.55104828, 11.39651394], [92.55112457, 11.396101], [92.5511322, 11.39562702], [92.55091858, 11.39511204], [92.55073547, 11.39456272], [92.55037689, 11.39410686], [92.54992676, 11.39363098], [92.54888153, 11.39333153], [92.54858398, 11.39316273], [92.54833221, 11.39302921]]], [[[92.55757904, 11.39093685], [92.55724335, 11.39022064], [92.55683136, 11.39023018], [92.55564117, 11.39094067], [92.55567169, 11.39146137], [92.55583191, 11.39212036], [92.55606079, 11.39273262], [92.55613708, 11.39325047], [92.55621338, 11.39379692], [92.55622864, 11.39448071], [92.55640411, 11.39519596], [92.55696106, 11.3955946], [92.55734253, 11.39604187], [92.55780029, 11.39647961], [92.55831909, 11.39687157], [92.5589447, 11.39708614], [92.55939484, 11.39734554], [92.56003571, 11.39749241], [92.56074524, 11.39770985], [92.56130219, 11.39770794], [92.56181335, 11.39764023], [92.56237793, 11.39745045], [92.56274414, 11.39721775], [92.56302643, 11.39687157], [92.56342316, 11.39629459], [92.56356049, 11.39600086], [92.56368256, 11.39541531], [92.56347656, 11.39481068], [92.56304169, 11.39419079], [92.56267548, 11.39366341], [92.56220245, 11.39310932], [92.56189728, 11.39276028], [92.56150055, 11.39247131], [92.56079865, 11.39216137], [92.5603714, 11.39186192], [92.55999756, 11.39173031], [92.55973816, 11.39159107], [92.55921936, 11.3913517], [92.55906677, 11.39127159], [92.55871582, 11.39126873], [92.55800629, 11.391222], [92.55757904, 11.39093685]]], [[[92.70054626, 11.31138992], [92.70166779, 11.31027985], [92.70166779, 11.31000042], [92.70291901, 11.30867958], [92.70361328, 11.30860996], [92.70388031, 11.3085413], [92.70417023, 11.3085413], [92.70443726, 11.30860996], [92.70555878, 11.30860996], [92.70582581, 11.30832863], [92.70610809, 11.30833435], [92.70639038, 11.30805588], [92.70667267, 11.30806065], [92.70701599, 11.3080492], [92.7076416, 11.3080492], [92.70804596, 11.30806065], [92.70888519, 11.30805588], [92.70916748, 11.30833435], [92.70972443, 11.30833435], [92.70999908, 11.30860996], [92.71028137, 11.30860996], [92.71055603, 11.30832863], [92.71090698, 11.30812359], [92.71083069, 11.30777836], [92.71083069, 11.30722046], [92.71096802, 11.30694389], [92.71111298, 11.30666637], [92.71111298, 11.30638981], [92.71111298, 11.30611038], [92.71131897, 11.30472183], [92.71215057, 11.30354118], [92.7121582, 11.30312157], [92.71138763, 11.30250168], [92.71111298, 11.3022213], [92.71083069, 11.3022213], [92.71058655, 11.30197525], [92.70972443, 11.30111122], [92.70944214, 11.30110931], [92.70916748, 11.3013916], [92.70888519, 11.30138874], [92.70694733, 11.30333138], [92.70603943, 11.30360889], [92.70582581, 11.30416965], [92.70582581, 11.30500031], [92.70388794, 11.30680943], [92.70276642, 11.30722046], [92.70194244, 11.30806065], [92.70166779, 11.30805588], [92.7013855, 11.30833435], [92.69916534, 11.30833435], [92.69889069, 11.30805588], [92.69833374, 11.30805588], [92.69805908, 11.30833435], [92.69806671, 11.30860996], [92.69750214, 11.30916595], [92.69777679, 11.30944443], [92.69777679, 11.30972195], [92.69806671, 11.31000042], [92.69806671, 11.31027985], [92.69832611, 11.31056118], [92.6986084, 11.31055641], [92.69916534, 11.3111124], [92.69944763, 11.3111124], [92.69953918, 11.311203], [92.69972229, 11.31138992], [92.70054626, 11.31138992]]], [[[92.72305298, 11.31638813], [92.72277832, 11.31610966], [92.72277832, 11.31583214], [92.72138977, 11.31444359], [92.72083282, 11.31444359], [92.71994019, 11.31484985], [92.71903992, 11.31618118], [92.71861267, 11.31632042], [92.71847534, 11.31621838], [92.71833038, 11.31611347], [92.71778107, 11.31611347], [92.71729279, 11.31548595], [92.71721649, 11.31499958], [92.71721649, 11.31472015], [92.71670532, 11.31420135], [92.7166748, 11.31388569], [92.71646118, 11.31312943], [92.71666718, 11.31236076], [92.71646118, 11.31140232], [92.71646118, 11.31022835], [92.71598053, 11.30995178], [92.71583557, 11.30916595], [92.71472168, 11.30806065], [92.71444702, 11.30805588], [92.71416473, 11.30833435], [92.71360779, 11.30833435], [92.71283722, 11.30901146], [92.7122879, 11.30999756], [92.71235657, 11.31062508], [92.71257019, 11.3109026], [92.71277618, 11.31110954], [92.71305084, 11.31166553], [92.71333313, 11.31194019], [92.71333313, 11.31223106], [92.71360779, 11.31278133], [92.71389008, 11.31306076], [92.71389008, 11.31361008], [92.7141571, 11.31389141], [92.71416473, 11.31416607], [92.71444702, 11.31444359], [92.71444702, 11.31472015], [92.71472168, 11.31499958], [92.71472168, 11.3166666], [92.71499634, 11.31694508], [92.71499634, 11.3172226], [92.71492767, 11.31763268], [92.71478271, 11.31832314], [92.7141571, 11.31972122], [92.7141571, 11.32000065], [92.71389008, 11.32028103], [92.71389008, 11.32056236], [92.71430969, 11.32117939], [92.71507263, 11.32139969], [92.71611023, 11.32250118], [92.71639252, 11.32264042], [92.71687317, 11.32291603], [92.71721649, 11.32319164], [92.71756744, 11.32367897], [92.71778107, 11.32444096], [92.7179184, 11.32479191], [92.7179184, 11.32500076], [92.71833038, 11.32527924], [92.71833038, 11.32555485], [92.71826172, 11.32583141], [92.71833038, 11.32611084], [92.71805573, 11.32638931], [92.71777344, 11.32708359], [92.71763611, 11.32748985], [92.71736145, 11.32847691], [92.71784973, 11.32944584], [92.71805573, 11.32972145], [92.71833038, 11.33027077], [92.71861267, 11.33055592], [92.72000122, 11.33194447], [92.72042084, 11.33215141], [92.72110748, 11.33278179], [92.72138977, 11.33278179], [92.7216568, 11.33306026], [92.72274017, 11.33306026], [92.72302246, 11.33292103], [92.72344208, 11.33278179], [92.72371674, 11.33264065], [92.72399902, 11.33195019], [92.72399902, 11.33098412], [92.72410583, 11.32983112], [92.72396851, 11.32921124], [92.72354889, 11.32852268], [92.7232666, 11.32707977], [92.72312927, 11.32590199], [92.72277832, 11.32576942], [92.72249603, 11.32500076], [92.72252655, 11.32429028], [92.72253418, 11.32318878], [92.72289276, 11.3220787], [92.72281647, 11.32153225], [92.72323608, 11.32084179], [92.72344208, 11.32001495], [92.72393036, 11.31925964], [92.72386169, 11.31878185], [92.72399902, 11.31781101], [92.72379303, 11.3176012], [92.72344208, 11.31663036], [92.72305298, 11.31638813]]], [[[92.27179718, 11.51599121], [92.27068329, 11.51598835], [92.27053833, 11.51619053], [92.270401, 11.516469], [92.270401, 11.51688194], [92.27046967, 11.5170908], [92.27159119, 11.51771069], [92.27186584, 11.51805782], [92.27214813, 11.51833439], [92.27278137, 11.51819515], [92.27362061, 11.51750183], [92.27334595, 11.51653099], [92.27194214, 11.51605701], [92.27179718, 11.51599121]]], [[[92.2141571, 11.57568073], [92.21396637, 11.57594967], [92.21385193, 11.57629204], [92.21364594, 11.57654953], [92.21347046, 11.57682133], [92.21334076, 11.57712173], [92.21316528, 11.57739735], [92.21304321, 11.57769108], [92.21289063, 11.57795334], [92.21276093, 11.57823181], [92.2125473, 11.57849979], [92.21240234, 11.57886124], [92.21218109, 11.579216], [92.21192932, 11.57961273], [92.21163177, 11.58004093], [92.21129608, 11.58050156], [92.21086121, 11.5809164], [92.21038818, 11.58134937], [92.20983124, 11.58172989], [92.20929718, 11.58216953], [92.20871735, 11.58254147], [92.20816803, 11.58296108], [92.20770264, 11.58344173], [92.20739746, 11.58401108], [92.20723724, 11.58463955], [92.20726013, 11.58525085], [92.20757294, 11.5857296], [92.20799255, 11.58601856], [92.20848083, 11.5861063], [92.20894623, 11.58613968], [92.20936584, 11.5863018], [92.20975494, 11.58622742], [92.21014404, 11.58615208], [92.21091461, 11.58622169], [92.21127319, 11.58629131], [92.21237946, 11.5866394], [92.21321869, 11.58725929], [92.2138443, 11.58780766], [92.21412659, 11.58815479], [92.21510315, 11.58884144], [92.21566772, 11.58912086], [92.21607971, 11.58981037], [92.21631622, 11.59037018], [92.21650696, 11.59081745], [92.21669006, 11.59125042], [92.21690369, 11.59167576], [92.21704102, 11.59215164], [92.21704102, 11.59276962], [92.21669006, 11.59332561], [92.21585083, 11.59360027], [92.21550751, 11.59366989], [92.21536255, 11.59395123], [92.21550751, 11.59457111], [92.21591949, 11.59457111], [92.21746063, 11.59464073], [92.21781158, 11.59464073], [92.21814728, 11.59395123], [92.21800232, 11.59284973], [92.21825409, 11.59238529], [92.21893311, 11.5923233], [92.21906281, 11.59230328], [92.21934509, 11.5924921], [92.21988678, 11.59246159], [92.22039032, 11.59226227], [92.22090149, 11.59217072], [92.22132111, 11.59195232], [92.22170258, 11.59173489], [92.22206116, 11.59153938], [92.222435, 11.5913372], [92.22277069, 11.59108067], [92.22310638, 11.59076023], [92.22348022, 11.59041977], [92.22387695, 11.59007168], [92.22429657, 11.58974075], [92.22470093, 11.58945179], [92.22509003, 11.58922195], [92.22551727, 11.58907127], [92.22590637, 11.58889103], [92.2263031, 11.58872032], [92.22670746, 11.58859921], [92.22711945, 11.58845139], [92.22756958, 11.58830261], [92.2279892, 11.58805466], [92.22840881, 11.58778572], [92.22884369, 11.58757401], [92.22931671, 11.58750057], [92.22984314, 11.5874424], [92.2303772, 11.58728027], [92.23097229, 11.58724117], [92.23153687, 11.58731174], [92.231987, 11.58751202], [92.23230743, 11.58776283], [92.23255157, 11.58801365], [92.2327652, 11.58825302], [92.23297119, 11.58852196], [92.23323059, 11.58877945], [92.23351288, 11.58906746], [92.23383331, 11.5893898], [92.23412323, 11.58979988], [92.23439026, 11.59028053], [92.23467255, 11.59076691], [92.23504639, 11.59114265], [92.23548889, 11.59141159], [92.23600769, 11.59135342], [92.23641968, 11.59139061], [92.23684692, 11.59139061], [92.2374115, 11.59143734], [92.23788452, 11.5916214], [92.23841095, 11.59169197], [92.23900604, 11.59177017], [92.23958588, 11.59186077], [92.24021149, 11.59181118], [92.2408371, 11.59194088], [92.24150085, 11.59206963], [92.24217224, 11.59198189], [92.24288177, 11.59195042], [92.24359131, 11.59194088], [92.24424744, 11.59190369], [92.24479675, 11.59170628], [92.24533844, 11.5916214], [92.24581146, 11.59142971], [92.24627686, 11.591362], [92.24669647, 11.59115028], [92.24714661, 11.59111118], [92.24760437, 11.59111118], [92.2480545, 11.59090424], [92.24841309, 11.59086037], [92.24888611, 11.59073925], [92.24938202, 11.59062958], [92.24990845, 11.59059143], [92.25042725, 11.59062958], [92.25096893, 11.59049129], [92.25166321, 11.59037495], [92.25228119, 11.59031773], [92.2529068, 11.59029007], [92.25354004, 11.59034061], [92.25417328, 11.59029007], [92.25479126, 11.59028053], [92.25541687, 11.59031582], [92.25602722, 11.59050179], [92.25666809, 11.59055328], [92.2572403, 11.59043407], [92.25786591, 11.59027004], [92.25845337, 11.59029961], [92.25910187, 11.59010124], [92.25982666, 11.58982086], [92.26074219, 11.58969116], [92.26132965, 11.58964062], [92.26152039, 11.58967972], [92.26171875, 11.58972073], [92.26216888, 11.58965492], [92.26244354, 11.5897274], [92.26258087, 11.58976364], [92.26313019, 11.58967113], [92.26369476, 11.58947468], [92.26407623, 11.58923054], [92.26439667, 11.58889103], [92.26455688, 11.58783054], [92.26542664, 11.5873909], [92.26598358, 11.58743477], [92.26631927, 11.58728886], [92.26646423, 11.58722496], [92.26693726, 11.58694935], [92.26721954, 11.58672142], [92.26766968, 11.5863018], [92.26808929, 11.58588886], [92.26864624, 11.58551979], [92.26902771, 11.585495], [92.26937866, 11.58527184], [92.26990509, 11.58494377], [92.27031708, 11.58452034], [92.27072906, 11.58409119], [92.27096558, 11.58358955], [92.2710495, 11.5830698], [92.27102661, 11.58213139], [92.27088928, 11.58115101], [92.27088928, 11.57964516], [92.27061462, 11.5787468], [92.27054596, 11.57792187], [92.27060699, 11.57716274], [92.27076721, 11.57678032], [92.27076721, 11.57644939], [92.27054596, 11.57611179], [92.27047729, 11.57578087], [92.27031708, 11.57550335], [92.2702713, 11.57512283], [92.27021027, 11.57467842], [92.27002716, 11.57421112], [92.2699585, 11.57365322], [92.2697525, 11.57312393], [92.26963806, 11.57258224], [92.26943207, 11.5720892], [92.26917267, 11.57160187], [92.2689209, 11.57108402], [92.2687149, 11.57053471], [92.26856232, 11.56997204], [92.26835632, 11.56941128], [92.26833344, 11.56878662], [92.26837921, 11.56812096], [92.26860809, 11.56748486], [92.26860809, 11.56686497], [92.26879883, 11.56612015], [92.26916504, 11.56594944], [92.2694397, 11.56579018], [92.26965332, 11.56533241], [92.2696991, 11.56488037], [92.26959229, 11.56443977], [92.2694397, 11.56400108], [92.26925659, 11.5635519], [92.26912689, 11.56305027], [92.26893616, 11.56260109], [92.26889038, 11.56212044], [92.26883698, 11.56165981], [92.26869202, 11.56124306], [92.26880646, 11.56075478], [92.26864624, 11.56024456], [92.26861572, 11.55969524], [92.26866913, 11.5591507], [92.26885223, 11.55865097], [92.26889038, 11.55811977], [92.26889038, 11.55762386], [92.26889038, 11.55713844], [92.26889038, 11.55665016], [92.26889038, 11.55615807], [92.26889038, 11.5556612], [92.26889038, 11.55518723], [92.26892853, 11.55477047], [92.26912689, 11.55443954], [92.26917267, 11.55409145], [92.26916504, 11.55375576], [92.26919556, 11.55342102], [92.26935577, 11.55311108], [92.26946259, 11.55272102], [92.26961517, 11.55230904], [92.26972198, 11.55182076], [92.26982117, 11.551301], [92.26997375, 11.55080223], [92.26999664, 11.55027103], [92.26999664, 11.54973125], [92.27001953, 11.54921436], [92.27017975, 11.54874039], [92.2702179, 11.54804039], [92.27070618, 11.54756069], [92.27122498, 11.54754257], [92.2716217, 11.54725075], [92.2719574, 11.54690933], [92.27217865, 11.54648113], [92.27222443, 11.54593563], [92.27226257, 11.54535007], [92.27243805, 11.5448103], [92.27250671, 11.54428196], [92.27259064, 11.54382133], [92.27275085, 11.54339981], [92.27279663, 11.54293919], [92.27292633, 11.5425024], [92.27308655, 11.5420866], [92.27330017, 11.54173088], [92.27342224, 11.5413208], [92.27360535, 11.54093075], [92.27378845, 11.54051876], [92.27391815, 11.54008102], [92.27411652, 11.53969955], [92.27416229, 11.539258], [92.27416992, 11.53878021], [92.27420044, 11.53831196], [92.27435303, 11.53785706], [92.27448273, 11.53738022], [92.27468109, 11.53693771], [92.27472687, 11.53640938], [92.27472687, 11.53586864], [92.27471161, 11.53536129], [92.27464294, 11.53492069], [92.27445984, 11.53456116], [92.27430725, 11.53419018], [92.27410889, 11.5338316], [92.27390289, 11.53343964], [92.27371979, 11.53304291], [92.27357483, 11.53265953], [92.27337646, 11.53234959], [92.27325439, 11.53203297], [92.2730484, 11.53179359], [92.27284241, 11.53156185], [92.2727356, 11.53126526], [92.27256775, 11.53100967], [92.27246094, 11.53071594], [92.27229309, 11.53046989], [92.27218628, 11.53018093], [92.27201843, 11.52992058], [92.27191162, 11.52962685], [92.27173615, 11.52935791], [92.27165222, 11.52905178], [92.27155304, 11.52878094], [92.27142334, 11.52853012], [92.27139282, 11.52821064], [92.27133179, 11.5279007], [92.27115631, 11.52760124], [92.27107239, 11.52722931], [92.27086639, 11.52686024], [92.27083588, 11.52641964], [92.27082825, 11.52596188], [92.27076721, 11.52552032], [92.27059174, 11.52514839], [92.27054596, 11.52475166], [92.27054596, 11.52434063], [92.27055359, 11.52392864], [92.2705307, 11.52353001], [92.27039337, 11.52316093], [92.27016449, 11.5228138], [92.2698288, 11.52250671], [92.26869965, 11.52239037], [92.26772308, 11.5223217], [92.26688385, 11.52211475], [92.26667786, 11.52162933], [92.26646423, 11.52115059], [92.26634216, 11.52051926], [92.26595306, 11.52016068], [92.26544952, 11.52001762], [92.26493835, 11.51998138], [92.26449585, 11.51989746], [92.26412964, 11.51972198], [92.26378632, 11.51947117], [92.26339722, 11.51921272], [92.26279449, 11.51897621], [92.26222229, 11.51839066], [92.26203156, 11.51789093], [92.26145935, 11.51756954], [92.2611084, 11.51750183], [92.26081085, 11.51750183], [92.26040649, 11.51753998], [92.26000214, 11.51775932], [92.25952148, 11.51801014], [92.25911713, 11.51841068], [92.25885773, 11.51890564], [92.25859833, 11.51936054], [92.25831604, 11.51976013], [92.25809479, 11.5201273], [92.25793457, 11.52052402], [92.25775146, 11.52086067], [92.25746918, 11.52115059], [92.25720978, 11.52147198], [92.2569046, 11.52180004], [92.25650787, 11.52211189], [92.25613403, 11.52249527], [92.25575256, 11.52285957], [92.25541687, 11.52318954], [92.25505829, 11.5234108], [92.25479889, 11.52365112], [92.25460815, 11.52388096], [92.25439453, 11.52408409], [92.25409698, 11.52424335], [92.25373077, 11.52445126], [92.25328827, 11.52472019], [92.25271606, 11.52496147], [92.25206757, 11.52516174], [92.25141907, 11.52536011], [92.25081635, 11.52558136], [92.25031281, 11.52579975], [92.24981689, 11.52584076], [92.24937439, 11.52583408], [92.24901581, 11.52590275], [92.24848175, 11.52598], [92.24802399, 11.52604198], [92.24745178, 11.52608013], [92.24680328, 11.52605057], [92.24621582, 11.52595043], [92.24562836, 11.52592087], [92.24501038, 11.52568817], [92.24456787, 11.52537155], [92.24404907, 11.5251503], [92.24358368, 11.52509308], [92.24341583, 11.52513885], [92.24318695, 11.52521038], [92.2427063, 11.52507114], [92.24224091, 11.5251503], [92.24172211, 11.52509117], [92.24127197, 11.52525806], [92.24075317, 11.52537155], [92.24019623, 11.52552891], [92.23958588, 11.52556133], [92.23898315, 11.52556133], [92.23838806, 11.52556133], [92.23783112, 11.5255518], [92.23731232, 11.52548122], [92.23684692, 11.52531242], [92.23636627, 11.52523518], [92.23593903, 11.52505207], [92.23551178, 11.52502537], [92.23512268, 11.5251503], [92.23471069, 11.52525997], [92.23426056, 11.52532101], [92.23383331, 11.52552032], [92.23332977, 11.52558994], [92.23285675, 11.52574062], [92.23239899, 11.5258503], [92.23203278, 11.526021], [92.23162842, 11.52616692], [92.23126984, 11.52638054], [92.23091888, 11.52656555], [92.23057556, 11.52669144], [92.23030853, 11.52690125], [92.22998047, 11.52709007], [92.22960663, 11.5272541], [92.22924805, 11.52749062], [92.22885132, 11.52770138], [92.22838593, 11.5278511], [92.22792816, 11.52802658], [92.22740936, 11.52811146], [92.22696686, 11.52832985], [92.2265625, 11.52858067], [92.22614288, 11.52876091], [92.22576904, 11.52895927], [92.22543335, 11.52915859], [92.22509003, 11.5293417], [92.22466278, 11.52942753], [92.22416687, 11.52948284], [92.22370911, 11.52971554], [92.22323608, 11.52992058], [92.2227478, 11.52999592], [92.222229, 11.53000259], [92.22171783, 11.52996159], [92.22109985, 11.52995872], [92.2207489, 11.52969074], [92.22034454, 11.52943134], [92.2199707, 11.52917099], [92.21961975, 11.52905178], [92.21924591, 11.52896118], [92.21903992, 11.52866268], [92.21897125, 11.52853966], [92.21876526, 11.52813244], [92.21870422, 11.52762127], [92.21891785, 11.52700138], [92.21884918, 11.52652264], [92.21864319, 11.52638054], [92.21821594, 11.52651596], [92.21787262, 11.52672291], [92.217659, 11.52741146], [92.21752167, 11.5279007], [92.21752167, 11.52838039], [92.21787262, 11.52886105], [92.21794128, 11.52920723], [92.21779633, 11.52948093], [92.21763611, 11.52952194], [92.21753693, 11.52948284], [92.21725464, 11.52937603], [92.21703339, 11.52912998], [92.21685028, 11.52883053], [92.21621704, 11.52862167], [92.21550751, 11.52862167], [92.21517181, 11.52890015], [92.21489716, 11.52903557], [92.2145462, 11.52945137], [92.21440887, 11.52986622], [92.21440887, 11.53014183], [92.21460724, 11.53028107], [92.21463013, 11.53036499], [92.21472168, 11.53069973], [92.21517181, 11.53083515], [92.21524048, 11.53097057], [92.21524048, 11.53138828], [92.21475983, 11.53184891], [92.21463776, 11.53217697], [92.2144165, 11.53248024], [92.21414948, 11.53280163], [92.21388245, 11.5331707], [92.21360016, 11.53353977], [92.21331787, 11.53389072], [92.21305084, 11.53424644], [92.21277618, 11.53459072], [92.21257782, 11.53495979], [92.21251678, 11.53543186], [92.21244049, 11.53582096], [92.21238708, 11.53628159], [92.21224213, 11.53678513], [92.21218872, 11.53722095], [92.21212006, 11.53786087], [92.21212006, 11.53848553], [92.21195984, 11.53925133], [92.21174622, 11.53959084], [92.21127319, 11.5400219], [92.21109009, 11.54049969], [92.21100616, 11.54095173], [92.21089935, 11.54143047], [92.21089935, 11.54191971], [92.21096802, 11.5424099], [92.21077728, 11.54287148], [92.21081543, 11.54327011], [92.21061707, 11.54360008], [92.21031952, 11.54380703], [92.21025085, 11.54413319], [92.21007538, 11.54439259], [92.20999146, 11.54472065], [92.20990753, 11.5450201], [92.20987701, 11.54531193], [92.20972443, 11.54563522], [92.20934296, 11.54591274], [92.20903015, 11.54622269], [92.20874786, 11.5465107], [92.20845795, 11.54684067], [92.20826721, 11.54728127], [92.20809937, 11.54775047], [92.20804596, 11.54829121], [92.20804596, 11.54883957], [92.20805359, 11.54940701], [92.20804596, 11.54999065], [92.20804596, 11.55062199], [92.20809174, 11.55123997], [92.20822144, 11.5518322], [92.20820618, 11.55244064], [92.20822906, 11.5530901], [92.20822906, 11.55377197], [92.20822906, 11.55447197], [92.20831299, 11.55515957], [92.20832062, 11.55574989], [92.20849609, 11.55628967], [92.20864105, 11.55677986], [92.20883942, 11.55720425], [92.20909882, 11.55770111], [92.20912933, 11.5582304], [92.20896149, 11.55871105], [92.20896912, 11.55927086], [92.20907593, 11.55979061], [92.20932007, 11.5604496], [92.20963287, 11.56097794], [92.20999146, 11.56124115], [92.21022797, 11.56162071], [92.21087646, 11.56238174], [92.21096802, 11.56289101], [92.21111298, 11.56343842], [92.21138763, 11.5639801], [92.21165466, 11.5645113], [92.21186066, 11.56505966], [92.21198273, 11.56564236], [92.21222687, 11.56612015], [92.21248627, 11.56656933], [92.21272278, 11.5670414], [92.21286011, 11.56756973], [92.2130661, 11.5680666], [92.21334076, 11.56851101], [92.21353912, 11.56893921], [92.21367645, 11.56934071], [92.21387482, 11.56961632], [92.21403503, 11.56986332], [92.21417236, 11.57008076], [92.21431732, 11.57029057], [92.21443939, 11.57050991], [92.21453094, 11.57078075], [92.21468353, 11.57106781], [92.21472168, 11.57147217], [92.21472168, 11.57194996], [92.2147522, 11.57246971], [92.21489716, 11.5729599], [92.21498871, 11.57345009], [92.21495819, 11.57389736], [92.2147522, 11.57429123], [92.21460724, 11.57469177], [92.21444702, 11.57505035], [92.21431732, 11.57538891], [92.2141571, 11.57568073]]], [[[93.08297729, 11.77968025], [93.08244324, 11.7792902], [93.08181763, 11.77908039], [93.08145905, 11.77915955], [93.08120728, 11.77917576], [93.08090973, 11.77924919], [93.08060455, 11.77940941], [93.08024597, 11.77944279], [93.07984161, 11.77944279], [93.079422, 11.77944469], [93.07898712, 11.77947044], [93.07861328, 11.77969074], [93.07817078, 11.77983856], [93.07787323, 11.7801609], [93.07757568, 11.78053665], [93.07757568, 11.78100395], [93.07776642, 11.78143501], [93.07792664, 11.7818222], [93.07805634, 11.78221035], [93.07817841, 11.78261471], [93.07832336, 11.7830143], [93.07845306, 11.78343105], [93.07862854, 11.78379631], [93.07879639, 11.78416061], [93.07865143, 11.78462124], [93.07865143, 11.7850399], [93.07884979, 11.78537083], [93.07904816, 11.78573132], [93.079216, 11.78614807], [93.07945251, 11.78653336], [93.07971954, 11.78687954], [93.07997894, 11.78723145], [93.08014679, 11.78765202], [93.08036041, 11.78800488], [93.0806427, 11.7882843], [93.08099365, 11.78849316], [93.08133698, 11.78869057], [93.08166504, 11.78892899], [93.0819931, 11.78917027], [93.08233643, 11.78943729], [93.0827713, 11.78966713], [93.08336639, 11.78972244], [93.08407593, 11.78973103], [93.08479309, 11.78968143], [93.0854187, 11.78942108], [93.08589935, 11.78906059], [93.08615875, 11.78859997], [93.08642578, 11.78822041], [93.08641052, 11.78777122], [93.08639526, 11.78731728], [93.08638763, 11.78686142], [93.08638763, 11.78640079], [93.08634949, 11.78596306], [93.08617401, 11.78559875], [93.08603668, 11.78524113], [93.0858078, 11.78497028], [93.08555603, 11.78470993], [93.08529663, 11.78442001], [93.08506012, 11.78407192], [93.08487701, 11.7836113], [93.08466339, 11.78310966], [93.08434296, 11.78267002], [93.08405304, 11.78228855], [93.08374786, 11.78205013], [93.08359528, 11.78176308], [93.08347321, 11.78147793], [93.08355713, 11.78114128], [93.08356476, 11.78071022], [93.08335114, 11.78022003], [93.08297729, 11.77968025]]], [[[93.02083588, 11.84333134], [93.02111053, 11.84305573], [93.02166748, 11.84305954], [93.02249908, 11.84221935], [93.02278137, 11.84222221], [93.02305603, 11.84194565], [93.02388763, 11.84195042], [93.02416992, 11.84167004], [93.02610779, 11.84167004], [93.02639008, 11.84138966], [93.0266571, 11.84138966], [93.02694702, 11.84110928], [93.02722168, 11.84111214], [93.02749634, 11.84083366], [93.02777863, 11.84083366], [93.02833557, 11.84027672], [93.02865601, 11.84007931], [93.02886963, 11.83971214], [93.02909851, 11.83943367], [93.0294342, 11.83924294], [93.02993774, 11.83922005], [93.03038025, 11.8390398], [93.03056335, 11.83861065], [93.03055573, 11.83833313], [93.03111267, 11.83777714], [93.03138733, 11.83778191], [93.03250122, 11.83667183], [93.03305817, 11.83666706], [93.03333282, 11.83694458], [93.03360748, 11.83694458], [93.03416443, 11.83638859], [93.03444672, 11.8363924], [93.03472137, 11.83611107], [93.03555298, 11.83611107], [93.03610992, 11.83667183], [93.03666687, 11.83667183], [93.03694153, 11.8363924], [93.03749847, 11.8363924], [93.03778076, 11.83666706], [93.03800201, 11.83682919], [93.03845215, 11.83718014], [93.03896332, 11.83747196], [93.03955078, 11.83761501], [93.04016113, 11.83779144], [93.04071045, 11.83806705], [93.0411911, 11.83841991], [93.04162598, 11.83884239], [93.04209137, 11.83921528], [93.04247284, 11.83960533], [93.04276276, 11.83997154], [93.04304504, 11.84026432], [93.04332733, 11.84055138], [93.04363251, 11.84093189], [93.04403687, 11.8413868], [93.04453278, 11.84185886], [93.04509735, 11.84220123], [93.04566956, 11.84243584], [93.04628754, 11.84256554], [93.04688263, 11.84274101], [93.04749298, 11.84278202], [93.04812622, 11.84277821], [93.04873657, 11.84281635], [93.04929352, 11.84301472], [93.04989624, 11.84309006], [93.0504303, 11.84331799], [93.0510025, 11.8434906], [93.05161285, 11.84363174], [93.05216217, 11.84382057], [93.0526886, 11.84396076], [93.05311584, 11.84412003], [93.05347443, 11.84416103], [93.05355835, 11.84416962], [93.05397034, 11.84416962], [93.05435944, 11.84416962], [93.05475616, 11.84416962], [93.05516815, 11.84414959], [93.05555725, 11.84403133], [93.05594635, 11.84391022], [93.05635071, 11.84389019], [93.05674744, 11.84389019], [93.05712128, 11.84389019], [93.05745697, 11.84392166], [93.05770874, 11.84409046], [93.05802917, 11.84415913], [93.05835724, 11.84419346], [93.05863953, 11.84433174], [93.05893707, 11.8444643], [93.05918884, 11.8446722], [93.05947113, 11.84488964], [93.05974579, 11.84508896], [93.06011963, 11.84514809], [93.06072235, 11.84475136], [93.061203, 11.84434605], [93.06162262, 11.8441906], [93.06203461, 11.84423161], [93.06257629, 11.84447098], [93.06331635, 11.84475994], [93.063797, 11.84465122], [93.06395721, 11.84423161], [93.06417847, 11.84379005], [93.06445313, 11.84339142], [93.06471252, 11.84306526], [93.06498718, 11.8427906], [93.06531525, 11.84257507], [93.06568146, 11.84241104], [93.06606293, 11.8422718], [93.06639099, 11.84222221], [93.06667328, 11.84221935], [93.06694794, 11.84249973], [93.0672226, 11.84249973], [93.06777954, 11.84195042], [93.06806183, 11.84195042], [93.06806183, 11.84167004], [93.06835175, 11.84167004], [93.06944275, 11.84278202], [93.06977844, 11.84244537], [93.06999969, 11.84222221], [93.06999969, 11.84194565], [93.07026672, 11.84167004], [93.07026672, 11.84138966], [93.07055664, 11.84110928], [93.07055664, 11.84083366], [93.0708313, 11.84055519], [93.0708313, 11.84027958], [93.07112122, 11.8399992], [93.07111359, 11.83972359], [93.07142639, 11.83939266], [93.07168579, 11.83892822], [93.07187653, 11.83857346], [93.07199097, 11.83849335], [93.07221985, 11.83833313], [93.07221985, 11.83749866], [93.07195282, 11.83722115], [93.07194519, 11.83638859], [93.07221985, 11.83611107], [93.07221985, 11.83556175], [93.07195282, 11.83527946], [93.07195282, 11.83500099], [93.0716629, 11.83472061], [93.07168579, 11.83444691], [93.0716095, 11.83400059], [93.07141113, 11.83354855], [93.07115936, 11.83307076], [93.07089996, 11.83257198], [93.0705719, 11.83218193], [93.07026672, 11.83185101], [93.06997681, 11.83156013], [93.06971741, 11.83127499], [93.06945038, 11.83096027], [93.06920624, 11.83057976], [93.06903076, 11.83013058], [93.06885529, 11.82963753], [93.06861115, 11.82915115], [93.06835175, 11.82866096], [93.06803894, 11.82824135], [93.06772614, 11.82790184], [93.06745911, 11.82760143], [93.06720734, 11.82729053], [93.06693268, 11.826931], [93.0666275, 11.82653046], [93.06627655, 11.82616043], [93.06594086, 11.82584095], [93.06563568, 11.8255558], [93.0654068, 11.82526016], [93.06522369, 11.82495022], [93.06495667, 11.82469273], [93.06463623, 11.82446003], [93.06433105, 11.82421017], [93.0640564, 11.82393074], [93.06381989, 11.82364178], [93.06360626, 11.82335854], [93.06340027, 11.82311058], [93.06317139, 11.82289696], [93.06297302, 11.82269192], [93.0627594, 11.82242012], [93.0625, 11.82210064], [93.06227875, 11.82171154], [93.0622406, 11.82120132], [93.06233978, 11.82069969], [93.06254578, 11.82030964], [93.06282043, 11.81999969], [93.06304932, 11.81966019], [93.0632019, 11.8192358], [93.06308746, 11.81871891], [93.06277466, 11.81824303], [93.06243896, 11.81781006], [93.06212616, 11.81742001], [93.0617981, 11.81707096], [93.06141663, 11.8166914], [93.06099701, 11.81628513], [93.06053162, 11.81588364], [93.06005859, 11.81560135], [93.05967712, 11.81539154], [93.05937958, 11.81527138], [93.05912781, 11.81514072], [93.05918121, 11.81499958], [93.0588913, 11.81499958], [93.05860901, 11.8147192], [93.05833435, 11.81472111], [93.05805206, 11.81444263], [93.05750275, 11.81444263], [93.05722046, 11.81416798], [93.0569458, 11.81417179], [93.05665588, 11.81389046], [93.05638885, 11.81389046], [93.05612183, 11.81361198], [93.05555725, 11.81361198], [93.05526733, 11.81333065], [93.05500031, 11.81333256], [93.05472565, 11.81305504], [93.05444336, 11.81305981], [93.0541687, 11.81278038], [93.05304718, 11.81278038], [93.05278015, 11.81250191], [93.05166626, 11.81250191], [93.0513916, 11.81222057], [93.04998779, 11.81222057], [93.04972076, 11.81250191], [93.04944611, 11.81250191], [93.04915619, 11.81278038], [93.04860687, 11.81278038], [93.04833221, 11.81305981], [93.04805756, 11.81305504], [93.04777527, 11.81333256], [93.04722595, 11.81333256], [93.04695129, 11.81361198], [93.04638672, 11.81361198], [93.04611206, 11.81389046], [93.04533386, 11.81416321], [93.0446701, 11.81446171], [93.04404449, 11.81477642], [93.04350281, 11.81512928], [93.04306793, 11.81550121], [93.04268646, 11.81583786], [93.0423584, 11.81613922], [93.04208374, 11.81642628], [93.04182434, 11.81666565], [93.04152679, 11.81683159], [93.04138947, 11.81666565], [93.04111481, 11.81694412], [93.04055786, 11.81694412], [93.04027557, 11.81722164], [93.04000092, 11.81722164], [93.03971863, 11.81750202], [93.03943634, 11.81750202], [93.03888702, 11.81807041], [93.03861237, 11.81805611], [93.03805542, 11.8186121], [93.03778076, 11.81861019], [93.03749847, 11.81888962], [93.03666687, 11.81888962], [93.03639221, 11.81917], [93.03610992, 11.81916809], [93.03610992, 11.81972218], [93.03588867, 11.81994534], [93.03555298, 11.82028008], [93.03527832, 11.81999969], [93.0341568, 11.82111168], [93.03388977, 11.82111168], [93.03333282, 11.82167053], [93.03277588, 11.82166576], [93.03250122, 11.82194424], [93.03221893, 11.82220173], [93.03185272, 11.82249069], [93.03148651, 11.82273006], [93.03119659, 11.82299042], [93.03090668, 11.82334137], [93.03059387, 11.82381058], [93.03037262, 11.82439232], [93.03025055, 11.82486057], [93.03025055, 11.82525063], [93.03037262, 11.8256197], [93.03050995, 11.82597065], [93.03047943, 11.82639122], [93.03022003, 11.82635021], [93.02987671, 11.82621098], [93.02957153, 11.82616329], [93.02926636, 11.82621098], [93.02896881, 11.82626057], [93.02867889, 11.82621098], [93.02839661, 11.82611942], [93.0280838, 11.82607174], [93.02771759, 11.82619476], [93.02722168, 11.8255558], [93.0266571, 11.82611275], [93.02639008, 11.82611275], [93.02610779, 11.82639122], [93.02581787, 11.82639122], [93.02555847, 11.82667065], [93.02527618, 11.82666588], [93.02500153, 11.82694435], [93.02443695, 11.82693958], [93.02388763, 11.8275013], [93.02361298, 11.8275013], [93.02249908, 11.82861137], [93.02166748, 11.82861137], [93.02139282, 11.8288908], [93.02111053, 11.82888889], [93.02027893, 11.82972336], [93.02002716, 11.82973194], [93.0196991, 11.82974339], [93.01927948, 11.82984066], [93.01881409, 11.83014011], [93.01834869, 11.83045197], [93.01782227, 11.83068943], [93.01733398, 11.83074379], [93.01700592, 11.83049965], [93.01687622, 11.83008099], [93.01674652, 11.82977962], [93.0165863, 11.82954025], [93.01694489, 11.82916737], [93.01638794, 11.82861137], [93.01611328, 11.82861137], [93.01583099, 11.82833004], [93.01499939, 11.82917118], [93.01499939, 11.83001041], [93.01444244, 11.83055687], [93.01428223, 11.83094025], [93.01412201, 11.83139992], [93.01391602, 11.83185101], [93.01384735, 11.83225918], [93.01374817, 11.83263969], [93.0138092, 11.83294964], [93.01390076, 11.8332386], [93.0139389, 11.83350372], [93.01396179, 11.83378601], [93.01396942, 11.83415127], [93.01397705, 11.83461189], [93.01407623, 11.8350811], [93.01407623, 11.83549118], [93.01394653, 11.83580971], [93.01374817, 11.83606052], [93.01348877, 11.83629131], [93.01332092, 11.83660793], [93.01305389, 11.83694458], [93.01277924, 11.83722115], [93.01277924, 11.83750057], [93.01222229, 11.83805466], [93.01249695, 11.83833122], [93.01222229, 11.83861065], [93.01222229, 11.83887959], [93.01249695, 11.83916664], [93.01257324, 11.83974171], [93.01273346, 11.84023571], [93.01277161, 11.84067154], [93.01271057, 11.84107685], [93.01242828, 11.84147167], [93.0120163, 11.84189129], [93.01202393, 11.84227943], [93.01217651, 11.8426609], [93.01222229, 11.84305954], [93.01222992, 11.84344101], [93.01228333, 11.84383106], [93.01238251, 11.84423161], [93.0124588, 11.84463692], [93.01249695, 11.84504128], [93.01249695, 11.84543133], [93.01249695, 11.84582043], [93.01249695, 11.84620094], [93.01248932, 11.84656143], [93.01245117, 11.84689808], [93.01235962, 11.84720135], [93.01222229, 11.84748554], [93.01209259, 11.84777355], [93.01196289, 11.84808064], [93.01197052, 11.84849072], [93.0123291, 11.84902], [93.01282501, 11.84929562], [93.01320648, 11.8495512], [93.01346588, 11.84965229], [93.01380157, 11.84952164], [93.01416779, 11.84926033], [93.01454926, 11.8489399], [93.01490021, 11.84860992], [93.01519775, 11.84832287], [93.01542664, 11.84804916], [93.01564789, 11.8477602], [93.0158844, 11.84747028], [93.01612854, 11.8471241], [93.01639557, 11.84679317], [93.01667023, 11.84649277], [93.01692963, 11.84619904], [93.01719666, 11.84587955], [93.01751709, 11.84553146], [93.01789093, 11.845191], [93.01834869, 11.84490204], [93.01882935, 11.84464169], [93.01925659, 11.84437084], [93.0196991, 11.84412003], [93.0200882, 11.84381866], [93.02050018, 11.84354115], [93.02083588, 11.84333134]]], [[[92.56565857, 11.94977188], [92.56610107, 11.94956017], [92.56659698, 11.94960117], [92.5671463, 11.95002174], [92.56764984, 11.95027542], [92.56783295, 11.95017147], [92.56795502, 11.95010185], [92.56809998, 11.94967079], [92.56830597, 11.94929123], [92.56845856, 11.94890118], [92.5686264, 11.94851971], [92.56874847, 11.94820118], [92.56887054, 11.94784641], [92.56920624, 11.94743061], [92.56947327, 11.94694138], [92.56961823, 11.94647789], [92.56970978, 11.94599056], [92.56967926, 11.94546223], [92.56944275, 11.94491005], [92.56945038, 11.94451141], [92.56930542, 11.94430637], [92.56909943, 11.94403076], [92.56861115, 11.94367981], [92.56832886, 11.94368362], [92.56790924, 11.94382095], [92.56763458, 11.94396019], [92.56736755, 11.94469357], [92.5670929, 11.94486046], [92.56682587, 11.94510174], [92.56630707, 11.94524956], [92.56589508, 11.94531822], [92.56568909, 11.94559193], [92.56548309, 11.94594002], [92.5652771, 11.94645977], [92.56491852, 11.94673824], [92.56445313, 11.9469614], [92.5641098, 11.94714165], [92.56382751, 11.94692039], [92.56347656, 11.94686604], [92.56313324, 11.94692039], [92.56291962, 11.94734669], [92.56305695, 11.94776058], [92.56326294, 11.94808102], [92.56330872, 11.94822216], [92.56347656, 11.94872093], [92.56376648, 11.94919968], [92.56406403, 11.94968319], [92.56443787, 11.95008373], [92.56482697, 11.9504137], [92.56508636, 11.95017719], [92.56565857, 11.94977188]]], [[[92.6995697, 11.66445065], [92.69993591, 11.66423702], [92.70030975, 11.66401958], [92.70070648, 11.66384506], [92.70102692, 11.66359043], [92.70127869, 11.66326237], [92.70133972, 11.66286469], [92.70115662, 11.66240025], [92.70098877, 11.66191864], [92.70085907, 11.66141129], [92.70083618, 11.66087532], [92.70079041, 11.6603117], [92.70075226, 11.65943718], [92.70040131, 11.65937996], [92.70007324, 11.65932083], [92.69959259, 11.65934086], [92.69914246, 11.6596489], [92.69847107, 11.65961933], [92.69802856, 11.65944195], [92.69753265, 11.65944386], [92.697052, 11.65944195], [92.69654846, 11.65947819], [92.69600677, 11.65963078], [92.69538879, 11.65971088], [92.69470978, 11.65976524], [92.69407654, 11.65999985], [92.69352722, 11.66030788], [92.69283295, 11.66070175], [92.69264984, 11.66114044], [92.69278717, 11.66169071], [92.69309235, 11.66190147], [92.69332123, 11.66207027], [92.69381714, 11.66228771], [92.69416046, 11.66261196], [92.69433594, 11.66298103], [92.69470978, 11.66318417], [92.69510651, 11.66342068], [92.69557953, 11.66368103], [92.69610596, 11.66390038], [92.69661713, 11.66412067], [92.69709778, 11.66431046], [92.69756317, 11.66440964], [92.69811249, 11.66427135], [92.69863892, 11.66432095], [92.6991806, 11.6645813], [92.6995697, 11.66445065]]], [[[92.76225281, 11.66969967], [92.76177979, 11.66955185], [92.76104736, 11.66983891], [92.76112366, 11.6705389], [92.7611084, 11.67116642], [92.76111603, 11.67179012], [92.76107788, 11.67242146], [92.76100159, 11.6730299], [92.76094055, 11.67360878], [92.76094055, 11.67412186], [92.76084137, 11.67454815], [92.76072693, 11.67505074], [92.76039886, 11.67525673], [92.76019287, 11.67562103], [92.75985718, 11.67606068], [92.7598114, 11.6766901], [92.76003265, 11.67726231], [92.76043701, 11.67765427], [92.76101685, 11.67777061], [92.76165009, 11.67784595], [92.76226807, 11.6780386], [92.76290131, 11.67824173], [92.76342773, 11.67851067], [92.76383972, 11.67892075], [92.76413727, 11.67942142], [92.76438141, 11.67989922], [92.76467133, 11.68023872], [92.76488495, 11.6805439], [92.7651062, 11.68079853], [92.76539612, 11.68095016], [92.76593018, 11.68083096], [92.76615143, 11.68071079], [92.76639557, 11.68059731], [92.76673889, 11.68033886], [92.766922, 11.67976856], [92.76673126, 11.6790514], [92.76660919, 11.67838955], [92.76638031, 11.67789078], [92.76612854, 11.67751789], [92.76589203, 11.67720985], [92.76570129, 11.67693901], [92.76552582, 11.67667198], [92.76534271, 11.67642117], [92.76517487, 11.67616367], [92.7649765, 11.67592239], [92.76478577, 11.67566681], [92.76467896, 11.67535019], [92.76451874, 11.67503071], [92.76441193, 11.67463017], [92.7642746, 11.67424679], [92.76418304, 11.67383003], [92.76412964, 11.67341137], [92.76400757, 11.67306042], [92.76386261, 11.6727314], [92.76368713, 11.67242146], [92.76355743, 11.67208195], [92.76343536, 11.67174721], [92.76322174, 11.67134953], [92.76316833, 11.67090321], [92.76305389, 11.67041588], [92.76303101, 11.67013836], [92.76249695, 11.66976166], [92.76225281, 11.66969967]]], [[[92.72498322, 11.68912125], [92.72546387, 11.6887722], [92.7258606, 11.6888113], [92.72615051, 11.68848038], [92.72647858, 11.68822002], [92.72666168, 11.68793106], [92.7266922, 11.6876297], [92.72618103, 11.68726063], [92.72567749, 11.68695831], [92.72519684, 11.68670177], [92.72464752, 11.68657017], [92.7243576, 11.68665695], [92.72403717, 11.68675041], [92.72359467, 11.68688869], [92.72298431, 11.68699169], [92.72229004, 11.68723106], [92.72175598, 11.68772125], [92.72168732, 11.68834114], [92.72193146, 11.68884659], [92.72233582, 11.68922138], [92.72276306, 11.68962193], [92.72335815, 11.68953133], [92.72394562, 11.68927956], [92.72453308, 11.68920517], [92.72498322, 11.68912125]]], [[[92.55091858, 11.72124004], [92.55069733, 11.72124004], [92.55036163, 11.72143936], [92.55001068, 11.72185135], [92.55001068, 11.72198963], [92.54987335, 11.7222662], [92.54965973, 11.72261047], [92.54944611, 11.72350979], [92.54945374, 11.72426701], [92.54994202, 11.72474957], [92.55064392, 11.72495842], [92.55140686, 11.72530365], [92.55154419, 11.72513294], [92.55168915, 11.72495842], [92.55148315, 11.72441101], [92.55091858, 11.72412968], [92.55056763, 11.72365189], [92.55069733, 11.72323036], [92.55084991, 11.72254181], [92.55098724, 11.72206116], [92.5511322, 11.72178078], [92.55120087, 11.72136974], [92.55091858, 11.72124004]]], [[[92.59694672, 11.90528965], [92.59638977, 11.90528965], [92.59638977, 11.90556145], [92.59583282, 11.90611267], [92.59610748, 11.90639114], [92.59610748, 11.90889072], [92.59583282, 11.9091711], [92.59583282, 11.9100008], [92.59555817, 11.91027737], [92.59555817, 11.91109943], [92.59527588, 11.91139126], [92.59555817, 11.91167068], [92.59555817, 11.91500092], [92.59583282, 11.91527939], [92.59583282, 11.915555], [92.59610748, 11.91583061], [92.59610748, 11.91639137], [92.59666443, 11.91666698], [92.59694672, 11.91694069], [92.59694672, 11.91750145], [92.59999847, 11.91777706], [92.60056305, 11.91833115], [92.60056305, 11.91889191], [92.60111237, 11.91889191], [92.60167694, 11.91861057], [92.60221863, 11.91805458], [92.60221863, 11.91666985], [92.60167694, 11.91611099], [92.60166931, 11.91444492], [92.60138702, 11.9141674], [92.60138702, 11.91388893], [92.60083008, 11.91333103], [92.60028076, 11.91305542], [92.60028076, 11.91250134], [92.59999847, 11.91222095], [92.59999847, 11.91166687], [92.59889221, 11.91056061], [92.59944153, 11.91028118], [92.59999847, 11.90972042], [92.59999847, 11.90916729], [92.59971619, 11.90889072], [92.59971619, 11.90832996], [92.59944153, 11.90805435], [92.59944153, 11.90778065], [92.59916687, 11.90750122], [92.59916687, 11.90694046], [92.59889221, 11.9066658], [92.59889221, 11.90639114], [92.59749603, 11.90611267], [92.59694672, 11.90556145], [92.59694672, 11.90528965]]], [[[92.75013733, 11.96833992], [92.75048828, 11.96799088], [92.7507019, 11.96799088], [92.75196075, 11.96784973], [92.75349426, 11.96771336], [92.75405121, 11.96778107], [92.7543335, 11.96771336], [92.75475311, 11.96743679], [92.75537872, 11.96715927], [92.75614929, 11.96709347], [92.75635529, 11.96709347], [92.7567749, 11.96702194], [92.75718689, 11.96689034], [92.75810242, 11.9667511], [92.75978088, 11.9667511], [92.76082611, 11.96681499], [92.76159668, 11.96695423], [92.7620163, 11.96695423], [92.76250458, 11.96688557], [92.76304626, 11.96678066], [92.76308441, 11.96625233], [92.76350403, 11.96562958], [92.76357269, 11.96541119], [92.76399231, 11.96514702], [92.76434326, 11.96508121], [92.76539612, 11.96523952], [92.76560211, 11.96506023], [92.76577759, 11.9648304], [92.76586914, 11.96449947], [92.76608276, 11.96412086], [92.76583099, 11.96368122], [92.76583099, 11.96317959], [92.76563263, 11.96269035], [92.76566315, 11.96221066], [92.76570129, 11.96177101], [92.76576233, 11.96127701], [92.76579285, 11.96082973], [92.76599121, 11.96046066], [92.76644897, 11.95996189], [92.76657867, 11.95950413], [92.76663208, 11.95901394], [92.76664734, 11.9585104], [92.76670074, 11.95798111], [92.76670837, 11.95748711], [92.76696014, 11.95695972], [92.76719666, 11.95644283], [92.76713562, 11.95588398], [92.76696777, 11.955369], [92.766716, 11.95483971], [92.76663208, 11.95423889], [92.7664032, 11.95367146], [92.76613617, 11.95309925], [92.76579285, 11.95259953], [92.76537323, 11.95223999], [92.7649231, 11.95194054], [92.76448059, 11.9516201], [92.76406097, 11.95128727], [92.7636261, 11.95095921], [92.763237, 11.9505806], [92.7628479, 11.95020008], [92.76255035, 11.94974041], [92.76217651, 11.94934082], [92.76169586, 11.94904041], [92.76124573, 11.94876194], [92.76075745, 11.94854069], [92.76022339, 11.94835854], [92.75965118, 11.94820118], [92.75936127, 11.9483242], [92.75887299, 11.94832039], [92.7585907, 11.94860172], [92.75817871, 11.94887638], [92.7576828, 11.94908333], [92.75733948, 11.9491539], [92.75663757, 11.94922161], [92.75636292, 11.94908333], [92.7559433, 11.94880772], [92.75566101, 11.94826126], [92.75518036, 11.94762039], [92.75462341, 11.94746304], [92.75408173, 11.9472208], [92.75354767, 11.94694805], [92.75300598, 11.94666958], [92.75250244, 11.9463892], [92.75200653, 11.94611073], [92.7515564, 11.94604111], [92.75114441, 11.9459877], [92.75065613, 11.9458704], [92.75022888, 11.94577026], [92.74984741, 11.94561005], [92.74939728, 11.94553471], [92.74891663, 11.94547462], [92.74849701, 11.94532108], [92.7480011, 11.94521141], [92.74740601, 11.94504929], [92.74662018, 11.94493961], [92.74626923, 11.94476223], [92.74575806, 11.94479179], [92.74514771, 11.94504738], [92.74466705, 11.94546223], [92.74417114, 11.94584465], [92.74372864, 11.94626045], [92.74331665, 11.94666481], [92.74294281, 11.9470892], [92.74273682, 11.94764137], [92.74249268, 11.94810963], [92.74228668, 11.94847012], [92.74230194, 11.94876194], [92.74191284, 11.94960976], [92.7413559, 11.95030022], [92.74099731, 11.95084953], [92.74065399, 11.95112514], [92.74002838, 11.95133114], [92.73918915, 11.951581], [92.73866272, 11.95142174], [92.73813629, 11.95112991], [92.7375412, 11.9509201], [92.73686218, 11.95098019], [92.73641968, 11.95133972], [92.73616028, 11.95184326], [92.73610687, 11.95247936], [92.73615265, 11.95319939], [92.73636627, 11.95393085], [92.73661041, 11.95463753], [92.73693085, 11.95524216], [92.73718262, 11.95582008], [92.73729706, 11.95643997], [92.73750305, 11.95695972], [92.73771667, 11.95745945], [92.73786163, 11.95799923], [92.73806763, 11.95854187], [92.73832703, 11.95907116], [92.73860931, 11.95961761], [92.73887634, 11.96015072], [92.739151, 11.96063614], [92.7394104, 11.96105957], [92.73970032, 11.96138763], [92.73999786, 11.96168232], [92.74074554, 11.96172333], [92.74088287, 11.96158695], [92.74101257, 11.96152115], [92.74157715, 11.96166039], [92.74208832, 11.96233654], [92.74254608, 11.96249199], [92.74311829, 11.96267223], [92.74378967, 11.96278954], [92.74446869, 11.96294975], [92.74489594, 11.96278572], [92.74504089, 11.96273136], [92.74526215, 11.96226406], [92.74594116, 11.96182632], [92.746521, 11.9618206], [92.74703979, 11.96210194], [92.7474823, 11.96228218], [92.74788666, 11.96247101], [92.74839783, 11.96289921], [92.74888611, 11.9631319], [92.74925995, 11.96343136], [92.74959564, 11.96373081], [92.74974823, 11.96410275], [92.74975586, 11.96444035], [92.74973297, 11.9648304], [92.74971771, 11.96522045], [92.74964905, 11.96560478], [92.7494812, 11.96598339], [92.74931335, 11.96646023], [92.74922943, 11.96697044], [92.74948883, 11.9675436], [92.74957275, 11.96790028], [92.74980164, 11.96833992], [92.75013733, 11.96833992]]], [[[92.73243713, 11.95422268], [92.73219299, 11.95390129], [92.73188019, 11.95355034], [92.73152161, 11.95319939], [92.73114014, 11.9528904], [92.73082733, 11.95256996], [92.73055267, 11.95228958], [92.73033142, 11.95199203], [92.73026276, 11.95152855], [92.73015594, 11.95099068], [92.72997284, 11.95043278], [92.72972107, 11.94992733], [92.72949219, 11.94946194], [92.72944641, 11.94893074], [92.72943878, 11.94839954], [92.72946167, 11.94787788], [92.72956848, 11.94738102], [92.72975159, 11.94692039], [92.73005676, 11.94651508], [92.73047638, 11.94618034], [92.73092651, 11.94588089], [92.7313385, 11.94568729], [92.7315979, 11.94546032], [92.73174286, 11.94521999], [92.73191071, 11.94500065], [92.73191071, 11.94475079], [92.73175812, 11.94450855], [92.73165894, 11.94421101], [92.73152161, 11.94390965], [92.73127747, 11.94361973], [92.73093414, 11.94335365], [92.73046875, 11.94312096], [92.7298584, 11.94299984], [92.72935486, 11.9427948], [92.72894287, 11.94256973], [92.72852325, 11.94235992], [92.72812653, 11.9420414], [92.72764587, 11.94170094], [92.72702789, 11.94135475], [92.72677612, 11.94114304], [92.72638702, 11.94101524], [92.72593689, 11.94123173], [92.72561646, 11.94164181], [92.72551727, 11.9421711], [92.72538757, 11.94266796], [92.72527313, 11.94310284], [92.7251358, 11.94347], [92.72499847, 11.94381618], [92.72486115, 11.94417191], [92.72470093, 11.94454956], [92.72450256, 11.94493961], [92.72444916, 11.94544983], [92.72440338, 11.94599056], [92.72421265, 11.94650841], [92.72416687, 11.94702053], [92.72419739, 11.94751453], [92.72436523, 11.9479599], [92.72457886, 11.94839096], [92.72470093, 11.94890976], [92.72476959, 11.94949055], [92.72502899, 11.95005035], [92.72538757, 11.9505558], [92.72574615, 11.95103168], [92.72608185, 11.95150185], [92.72639465, 11.95201015], [92.72663116, 11.95259953], [92.72641754, 11.95274067], [92.72621155, 11.95274067], [92.72606659, 11.95247173], [92.72572327, 11.95205116], [92.72556305, 11.95166969], [92.7250061, 11.95166969], [92.72381592, 11.95076084], [92.7233429, 11.95063114], [92.72305298, 11.95111179], [92.72305298, 11.95222187], [92.72319031, 11.95250034], [92.72325897, 11.95291042], [92.72367859, 11.95353889], [92.72416687, 11.95417023], [92.72444153, 11.95416641], [92.72486115, 11.95430279], [92.72589874, 11.95409489], [92.72605896, 11.95465088], [92.7259903, 11.95514774], [92.72624207, 11.95551968], [92.72659302, 11.95584106], [92.72692871, 11.95618057], [92.72723389, 11.95653439], [92.72759247, 11.95686245], [92.72806549, 11.95708275], [92.72857666, 11.95727921], [92.72907257, 11.95751572], [92.72954559, 11.95778275], [92.73000336, 11.95805168], [92.73046112, 11.95829964], [92.73094177, 11.95845127], [92.73139954, 11.95862198], [92.7318573, 11.95879936], [92.73230743, 11.95898247], [92.73272705, 11.95918179], [92.73311615, 11.9593811], [92.7335434, 11.95919991], [92.73383331, 11.95862198], [92.73388672, 11.95791721], [92.73383331, 11.95720196], [92.73361206, 11.95657921], [92.73335266, 11.95603943], [92.73313141, 11.95557022], [92.73294067, 11.95517063], [92.73277283, 11.95483971], [92.73259735, 11.95454025], [92.73243713, 11.95422268]]], [[[92.59610748, 11.97610855], [92.59722137, 11.97499943], [92.59722137, 11.97444057], [92.59693909, 11.97416782], [92.59749603, 11.97388935], [92.59887695, 11.97249889], [92.59887695, 11.97194099], [92.59999847, 11.97166729], [92.60083008, 11.97138023], [92.60083008, 11.96861076], [92.60138702, 11.96833324], [92.60166168, 11.96805859], [92.60221863, 11.96778107], [92.6027832, 11.96722126], [92.60277557, 11.96694469], [92.60305023, 11.96666718], [92.60305023, 11.96639061], [92.60333252, 11.96611118], [92.60333252, 11.96583271], [92.60360718, 11.96555519], [92.60360718, 11.96500111], [92.60333252, 11.96472073], [92.60333252, 11.96444511], [92.60305023, 11.96416664], [92.60305023, 11.96389103], [92.60250092, 11.96333027], [92.60305023, 11.96277905], [92.60305023, 11.96250057], [92.60360718, 11.96193981], [92.60360718, 11.96166611], [92.60305023, 11.96111012], [92.60388947, 11.96028137], [92.60388947, 11.9591713], [92.60472107, 11.95833015], [92.60472107, 11.95611], [92.60500336, 11.95582962], [92.60499573, 11.95555592], [92.60527802, 11.9552803], [92.60527802, 11.95444202], [92.60499573, 11.95416641], [92.60582733, 11.95334053], [92.60582733, 11.95194054], [92.60694122, 11.95139027], [92.60721588, 11.95111179], [92.60721588, 11.94944096], [92.60666656, 11.94888973], [92.60694122, 11.94860935], [92.60694122, 11.94833374], [92.60722351, 11.94805527], [92.60721588, 11.94556046], [92.60666656, 11.94500065], [92.60721588, 11.94472122], [92.60805511, 11.94388866], [92.60861206, 11.94361115], [92.60944366, 11.94277668], [92.60943604, 11.94055939], [92.60888672, 11.94000053], [92.60777283, 11.93943977], [92.60777283, 11.93861103], [92.60749817, 11.9383297], [92.60749817, 11.93777657], [92.60637665, 11.93667126], [92.60527802, 11.93639088], [92.60325623, 11.9363203], [92.60360718, 11.93583012], [92.60305023, 11.93555355], [92.60305023, 11.93500137], [92.60221863, 11.93472004], [92.60221863, 11.93444443], [92.60166168, 11.93388844], [92.60166168, 11.93111038], [92.59999847, 11.92944431], [92.59999847, 11.92889023], [92.59944153, 11.92833042], [92.59888458, 11.92805576], [92.59887695, 11.92778015], [92.59860992, 11.92777824], [92.59860992, 11.92833424], [92.5983429, 11.92860985], [92.59833527, 11.92889023], [92.59777832, 11.92943954], [92.5966568, 11.93000031], [92.59666443, 11.9305563], [92.59638977, 11.93083191], [92.59693909, 11.93111229], [92.59693909, 11.93194199], [92.5966568, 11.93223095], [92.59722137, 11.93249989], [92.59638977, 11.93332958], [92.5966568, 11.93360996], [92.5966568, 11.9338913], [92.59693909, 11.93417072], [92.59693909, 11.93500137], [92.5966568, 11.93527031], [92.59666443, 11.93555355], [92.59638977, 11.93583202], [92.59638977, 11.93721962], [92.59583282, 11.93778133], [92.59610748, 11.93805695], [92.59749603, 11.9383297], [92.59749603, 11.94138908], [92.59638977, 11.94194126], [92.59638977, 11.94277668], [92.59693909, 11.94333076], [92.59693909, 11.94528198], [92.59666443, 11.94555473], [92.5966568, 11.9458313], [92.59610748, 11.9463892], [92.59610748, 11.94999981], [92.59722137, 11.95111179], [92.59722137, 11.95222187], [92.59638977, 11.95305634], [92.59693909, 11.95361042], [92.59693909, 11.95388794], [92.59638977, 11.95444202], [92.59638977, 11.95555592], [92.59610748, 11.95582962], [92.59610748, 11.95666599], [92.59583282, 11.95694447], [92.59610748, 11.95722198], [92.59610748, 11.95750046], [92.59638977, 11.95777798], [92.59638977, 11.96082973], [92.59555054, 11.96166611], [92.59583282, 11.96193981], [92.59583282, 11.96389103], [92.59555817, 11.96417141], [92.59555817, 11.96528053], [92.59527588, 11.96555519], [92.59555817, 11.96582985], [92.59555817, 11.96639061], [92.59527588, 11.96666718], [92.59527588, 11.96694469], [92.59500122, 11.96722126], [92.59500122, 11.96750069], [92.59471893, 11.96778107], [92.59471893, 11.96805859], [92.59388733, 11.96888924], [92.59194183, 11.96916676], [92.59194183, 11.96944141], [92.59166718, 11.96972084], [92.59166718, 11.9702816], [92.59138489, 11.97055531], [92.59138489, 11.9711113], [92.59111023, 11.97138023], [92.58889008, 11.97249889], [92.58916473, 11.97277737], [92.58916473, 11.97444344], [92.58889008, 11.97472095], [92.58889008, 11.97499943], [92.58860779, 11.97527981], [92.58889008, 11.97555637], [92.58889008, 11.97610855], [92.58999634, 11.97639179], [92.59111023, 11.97639179], [92.59111023, 11.97610855], [92.59166718, 11.97610855], [92.59166718, 11.97638988], [92.59222412, 11.97694397], [92.59388733, 11.97722244], [92.59527588, 11.97722244], [92.59583282, 11.97694397], [92.59610748, 11.97666454], [92.59610748, 11.97610855]]], [[[92.74308014, 11.96451092], [92.74277496, 11.96444893], [92.74233246, 11.96454716], [92.74169159, 11.96495342], [92.74173737, 11.96559334], [92.74196625, 11.96613979], [92.74228668, 11.96657085], [92.74272156, 11.96689034], [92.74320984, 11.96720886], [92.74376678, 11.96743965], [92.7443924, 11.96743965], [92.74491882, 11.96712017], [92.745224, 11.96663284], [92.74516296, 11.96605396], [92.74478149, 11.9655304], [92.7443161, 11.96505833], [92.74373627, 11.96473026], [92.74308014, 11.96451092]]], [[[92.58275604, 11.97598171], [92.5823822, 11.97572041], [92.58211517, 11.97594261], [92.58175659, 11.97630119], [92.58145142, 11.97679806], [92.58129883, 11.97742176], [92.58133698, 11.97808075], [92.58139038, 11.97874165], [92.5814743, 11.97938156], [92.58163452, 11.97999287], [92.58172607, 11.98058128], [92.58197784, 11.98105145], [92.5823288, 11.98149014], [92.58279419, 11.98195076], [92.58338165, 11.98239994], [92.58363342, 11.98252106], [92.58396149, 11.98268032], [92.58435059, 11.98248196], [92.58448029, 11.98190975], [92.58467865, 11.9813509], [92.58472443, 11.98077011], [92.5847168, 11.98019123], [92.58472443, 11.97962761], [92.5847168, 11.97908974], [92.5847702, 11.97859097], [92.5849762, 11.97815609], [92.58505249, 11.9777298], [92.5849762, 11.97733593], [92.58473969, 11.97697067], [92.58439636, 11.97663975], [92.58396912, 11.9763813], [92.58342743, 11.97612953], [92.58275604, 11.97598171]]], [[[92.77604675, 12.01770973], [92.77648926, 12.01714993], [92.77684784, 12.01667976], [92.77688599, 12.01621056], [92.77659607, 12.0157299], [92.77631378, 12.01567078], [92.77597046, 12.01533985], [92.77574921, 12.01479053], [92.77545929, 12.01422977], [92.77519989, 12.01382923], [92.77496338, 12.01312923], [92.77472687, 12.01280117], [92.77423859, 12.01266003], [92.77363586, 12.01286983], [92.77310181, 12.01338196], [92.7723999, 12.01337147], [92.77178955, 12.01351929], [92.7714386, 12.01390743], [92.77138519, 12.01436234], [92.77138519, 12.01480007], [92.77134705, 12.01521015], [92.7713623, 12.01575947], [92.77101898, 12.01610756], [92.77091217, 12.01662064], [92.77081299, 12.01734066], [92.77118683, 12.01778984], [92.77197266, 12.01775074], [92.77266693, 12.01746178], [92.77307892, 12.01721096], [92.77346802, 12.01717281], [92.77361298, 12.01721954], [92.77361298, 12.01778126], [92.77388763, 12.01805687], [92.77416992, 12.01826191], [92.77471924, 12.01861095], [92.77490234, 12.01850128], [92.77548981, 12.01832104], [92.77604675, 12.01770973]]], [[[92.96578979, 11.96675968], [92.96565247, 11.96704102], [92.96553802, 11.96732998], [92.96537781, 11.96759033], [92.965271, 11.96790028], [92.96511841, 11.96822071], [92.96491241, 11.96856499], [92.96459961, 11.96890259], [92.9642334, 11.9692812], [92.96391296, 11.96975136], [92.96363068, 11.97025204], [92.96343231, 11.9707489], [92.96330261, 11.97124958], [92.96309662, 11.97169018], [92.9630127, 11.97219563], [92.96282196, 11.97271347], [92.962677, 11.97333145], [92.96253204, 11.9739809], [92.96246338, 11.97461033], [92.96215057, 11.97511959], [92.9620285, 11.97558117], [92.96174622, 11.97589111], [92.96161652, 11.97630978], [92.9614563, 11.97679996], [92.96147156, 11.97721195], [92.96141815, 11.97760391], [92.96124268, 11.97800064], [92.96116638, 11.97836971], [92.96115112, 11.97867584], [92.96077728, 11.97901344], [92.96075439, 11.97933197], [92.96079254, 11.97973061], [92.96057129, 11.98010921], [92.96031189, 11.98051929], [92.95999146, 11.98093891], [92.95960236, 11.98133755], [92.95912933, 11.98166084], [92.95865631, 11.98195076], [92.95820618, 11.9822197], [92.95780182, 11.98244953], [92.95734406, 11.98256588], [92.95690918, 11.98273945], [92.95641327, 11.98282146], [92.95596313, 11.98300076], [92.95545959, 11.9831152], [92.95507813, 11.983325], [92.95468903, 11.98350143], [92.95422363, 11.98359585], [92.95366669, 11.98365116], [92.95307159, 11.98385239], [92.95244598, 11.98397923], [92.95181274, 11.98418045], [92.95121002, 11.98443985], [92.95059204, 11.98465157], [92.9499054, 11.98473835], [92.94921875, 11.98486137], [92.9486084, 11.98506927], [92.9479599, 11.98524189], [92.94724274, 11.98528099], [92.9464798, 11.98528099], [92.9457016, 11.98528099], [92.94493866, 11.98528099], [92.94420624, 11.98528099], [92.94351196, 11.98528099], [92.94286346, 11.98527813], [92.94226074, 11.9853096], [92.94174957, 11.98547173], [92.94130707, 11.98564053], [92.94095612, 11.9858408], [92.94062042, 11.98601913], [92.94025421, 11.98609447], [92.93983459, 11.98604012], [92.93927765, 11.98597145], [92.93878937, 11.98569965], [92.93851471, 11.98545837], [92.93815613, 11.98511887], [92.93769073, 11.98502064], [92.93718719, 11.98499966], [92.9367218, 11.98499966], [92.93623352, 11.98499966], [92.93577576, 11.98506355], [92.93531799, 11.98496246], [92.93454742, 11.98473358], [92.93386841, 11.98499298], [92.93361664, 11.98548985], [92.93340302, 11.9858408], [92.93300629, 11.98617935], [92.93268585, 11.98667145], [92.93232727, 11.98725033], [92.93206024, 11.98790169], [92.93215942, 11.98851013], [92.93209839, 11.98899078], [92.93196106, 11.98936939], [92.93183899, 11.98972511], [92.93170166, 11.99010086], [92.93160248, 11.99058628], [92.93138885, 11.99104691], [92.93112946, 11.99149132], [92.93088531, 11.99190426], [92.93070221, 11.99225044], [92.93054199, 11.99250984], [92.93029785, 11.99271965], [92.93000793, 11.99302101], [92.92937469, 11.99320507], [92.92903137, 11.99350071], [92.92854309, 11.99376583], [92.92807007, 11.9940424], [92.92765045, 11.9943037], [92.92706299, 11.99446964], [92.92640686, 11.99498653], [92.92595673, 11.9954319], [92.92553711, 11.99578953], [92.92542267, 11.99633026], [92.92512512, 11.99688816], [92.92502594, 11.99771118], [92.92545319, 11.99812126], [92.92617798, 11.99838066], [92.92656708, 11.99861145], [92.92700195, 11.99878883], [92.92745972, 11.99892998], [92.92788696, 11.99927044], [92.92827606, 11.99972057], [92.92804718, 12.00000191], [92.92851257, 12.00086117], [92.92864227, 12.00119114], [92.92888641, 12.00158978], [92.92912292, 12.00212097], [92.92926025, 12.00272274], [92.92939758, 12.00329018], [92.92948914, 12.00382996], [92.92970276, 12.0042448], [92.92990875, 12.00460052], [92.93019104, 12.0048399], [92.93041992, 12.00508881], [92.93058777, 12.00537109], [92.93084717, 12.00555611], [92.93113708, 12.0057106], [92.93148041, 12.00586128], [92.93183136, 12.0060463], [92.93221283, 12.00610065], [92.93256378, 12.0061264], [92.93300629, 12.00633144], [92.93347931, 12.00636005], [92.93393707, 12.00625992], [92.93438721, 12.00618267], [92.93480682, 12.00621891], [92.93521881, 12.00636673], [92.93564606, 12.00654316], [92.9361496, 12.00649261], [92.93667603, 12.00642872], [92.93720245, 12.00640106], [92.93769073, 12.00640965], [92.93815613, 12.00645828], [92.93863678, 12.00655174], [92.93916321, 12.00665188], [92.93972778, 12.00667858], [92.94033051, 12.0067091], [92.94091797, 12.00674343], [92.94140625, 12.0069437], [92.94187927, 12.00710106], [92.94232178, 12.00726128], [92.94268799, 12.00751591], [92.94303131, 12.00780106], [92.943367, 12.00809002], [92.94377899, 12.00828171], [92.94426727, 12.00838566], [92.94473267, 12.00861168], [92.94516754, 12.00888062], [92.94563293, 12.00911999], [92.94612122, 12.00931168], [92.94658661, 12.0094986], [92.94698334, 12.00974274], [92.94727325, 12.01005268], [92.94757843, 12.01032066], [92.94785309, 12.01060581], [92.94820404, 12.01083374], [92.94857788, 12.01107979], [92.94893646, 12.01138973], [92.94930267, 12.01173019], [92.94960022, 12.01211071], [92.9499588, 12.01246166], [92.95030975, 12.01280117], [92.95065308, 12.0131197], [92.95085907, 12.01350784], [92.9510498, 12.01390743], [92.95121765, 12.01433277], [92.95134735, 12.01488018], [92.95142365, 12.01548767], [92.95165253, 12.01605129], [92.95187378, 12.01659966], [92.9520874, 12.0170927], [92.95230103, 12.01754189], [92.95256042, 12.01790047], [92.95278931, 12.01824093], [92.95298767, 12.01861095], [92.95314026, 12.01903915], [92.95333099, 12.01946068], [92.95352173, 12.01993275], [92.95368958, 12.02044964], [92.95393372, 12.02085972], [92.95423889, 12.0211792], [92.9545517, 12.02149582], [92.95485687, 12.02180386], [92.95515442, 12.0221138], [92.955513, 12.02238941], [92.95573425, 12.0227747], [92.95597839, 12.02319431], [92.95625305, 12.02361107], [92.9565506, 12.02402973], [92.95691681, 12.02433968], [92.95729065, 12.02466202], [92.9577179, 12.02495098], [92.95813751, 12.0252037], [92.95835876, 12.02555275], [92.95860291, 12.02591133], [92.95878601, 12.02629089], [92.95902252, 12.02663994], [92.95932007, 12.0269413], [92.95963287, 12.02725124], [92.95990753, 12.02762032], [92.96008301, 12.02812195], [92.96031952, 12.02863216], [92.96066284, 12.02910233], [92.96103668, 12.02950954], [92.96138, 12.02993107], [92.9616394, 12.03031158], [92.96180725, 12.03068829], [92.96193695, 12.03104115], [92.96208954, 12.03141499], [92.96219635, 12.03188229], [92.96222687, 12.03249073], [92.96227264, 12.03318977], [92.96245575, 12.03390598], [92.96253967, 12.03463078], [92.96269989, 12.03529167], [92.96264648, 12.03590679], [92.96276855, 12.03644943], [92.9629364, 12.03693485], [92.96305084, 12.03722382], [92.96333313, 12.03749084], [92.96333313, 12.03889275], [92.96334076, 12.03934193], [92.96333313, 12.03969955], [92.96333313, 12.0402813], [92.96333313, 12.04055595], [92.96337128, 12.04136086], [92.96317291, 12.04190063], [92.96312714, 12.04239082], [92.96325684, 12.0428896], [92.96326447, 12.04338741], [92.96311951, 12.04389286], [92.96308136, 12.04438972], [92.96315002, 12.04486179], [92.96325684, 12.04531097], [92.96337128, 12.04576874], [92.96361542, 12.04618073], [92.96388245, 12.0466013], [92.96411133, 12.04706097], [92.9641571, 12.04750061], [92.96416473, 12.0480547], [92.96444702, 12.04833126], [92.96444702, 12.04916668], [92.96499634, 12.04972267], [92.96611023, 12.04861069], [92.96611023, 12.04805946], [92.96582794, 12.04778099], [92.96582794, 12.04582977], [92.96527863, 12.04527664], [92.96527863, 12.04417133], [92.96553802, 12.04389095], [92.96553802, 12.04278088], [92.96553802, 12.04257965], [92.96557617, 12.04216957], [92.96568298, 12.04183102], [92.96582794, 12.04152966], [92.96598816, 12.04121494], [92.9661026, 12.04080868], [92.96620178, 12.0403347], [92.96640015, 12.03983402], [92.96663666, 12.03929615], [92.96685028, 12.03870964], [92.96705627, 12.03813076], [92.96736908, 12.03763008], [92.96766663, 12.03713131], [92.96788025, 12.0365696], [92.96807098, 12.03611374], [92.9683075, 12.03571796], [92.96845245, 12.03529167], [92.96864319, 12.03485203], [92.96890259, 12.03442097], [92.96917725, 12.03398991], [92.96953583, 12.03367996], [92.96987915, 12.03361893], [92.97029114, 12.03366184], [92.97127533, 12.03455067], [92.97158813, 12.03494072], [92.97196198, 12.03541946], [92.97209167, 12.03562737], [92.97222137, 12.03581142], [92.97242737, 12.03608036], [92.97257996, 12.03641129], [92.97276306, 12.03668022], [92.9729538, 12.03680515], [92.97322845, 12.03680515], [92.97354126, 12.03668022], [92.97396851, 12.03649139], [92.97423553, 12.03665924], [92.97447968, 12.03683472], [92.97470093, 12.0370512], [92.97486115, 12.03737736], [92.97492981, 12.03772068], [92.9747467, 12.03806114], [92.97462463, 12.03839779], [92.97441101, 12.03864193], [92.97407532, 12.03926563], [92.97395325, 12.03979969], [92.97390747, 12.0402689], [92.97405243, 12.0407753], [92.97416687, 12.04129028], [92.97428131, 12.0416851], [92.97438812, 12.04197025], [92.97459412, 12.04216099], [92.97489166, 12.042243], [92.97528076, 12.04222298], [92.97750092, 12.04222298], [92.97777557, 12.04194355], [92.97857666, 12.04201126], [92.97902679, 12.04204941], [92.97949982, 12.04231071], [92.97997284, 12.04247093], [92.9803009, 12.04251194], [92.9806366, 12.04253006], [92.98107147, 12.04257107], [92.98139191, 12.04258919], [92.98174286, 12.04294014], [92.98176575, 12.04323006], [92.98178864, 12.04333019], [92.98192596, 12.04348087], [92.98214722, 12.04354], [92.98246002, 12.04354], [92.98277283, 12.04337978], [92.98304749, 12.04294014], [92.98335266, 12.04246426], [92.98361969, 12.04226112], [92.98389435, 12.04197598], [92.98416901, 12.04162121], [92.98441315, 12.04123783], [92.98458862, 12.04084969], [92.98473358, 12.04052544], [92.98487854, 12.04026222], [92.98501587, 12.04002094], [92.98519135, 12.03981113], [92.9854126, 12.03961086], [92.98570251, 12.03940964], [92.98604584, 12.03914833], [92.98645782, 12.03883076], [92.98693848, 12.03848934], [92.98742676, 12.03813076], [92.98792267, 12.03780079], [92.98840332, 12.03752136], [92.9888916, 12.03726101], [92.98937988, 12.03700638], [92.98987579, 12.03674126], [92.99047089, 12.03659058], [92.99106598, 12.03643131], [92.99172211, 12.0363903], [92.99240875, 12.03638554], [92.99304962, 12.03634167], [92.99355316, 12.03614044], [92.99401855, 12.03598022], [92.99443054, 12.03581142], [92.99478149, 12.03558064], [92.99517822, 12.03539181], [92.9956131, 12.0352459], [92.99584961, 12.03507137], [92.99606323, 12.03484535], [92.99623108, 12.03472042], [92.99643707, 12.03461742], [92.99675751, 12.03449154], [92.99707031, 12.03441238], [92.99723816, 12.03436947], [92.99777985, 12.03419971], [92.99856567, 12.03378296], [92.9988327, 12.03335857], [92.99900818, 12.03285122], [92.99925232, 12.03238106], [92.9994278, 12.03197098], [93.0, 12.03139019], [93.00055695, 12.03139019], [93.00110626, 12.03083134], [93.00138855, 12.0308342], [93.00222015, 12.02999973], [93.00250244, 12.03000164], [93.00332642, 12.02917004], [93.00332642, 12.02888966], [93.00389099, 12.0283289], [93.00389099, 12.02805519], [93.00417328, 12.02777958], [93.00417328, 12.0274992], [93.00444794, 12.02722359], [93.00444794, 12.02694321], [93.0047226, 12.02666664], [93.0047226, 12.02639198], [93.00554657, 12.02555275], [93.0055542, 12.02527714], [93.00611115, 12.02472115], [93.00611115, 12.02444458], [93.0063858, 12.02416706], [93.0063858, 12.02389145], [93.00666809, 12.02361107], [93.00666809, 12.02306175], [93.00694275, 12.02278233], [93.00694275, 12.02222061], [93.00722504, 12.021945], [93.00722504, 12.02166653], [93.00888824, 12.02000141], [93.00888824, 12.01972103], [93.0091629, 12.01944542], [93.0091629, 12.01916695], [93.00945282, 12.01889133], [93.00945282, 12.01832962], [93.00971985, 12.01805687], [93.00971985, 12.01750088], [93.01000214, 12.01721954], [93.01000214, 12.01360989], [93.0100708, 12.01306057], [93.00985718, 12.01278687], [93.00965118, 12.01224041], [93.00937653, 12.01169109], [93.00894928, 12.01107121], [93.00860596, 12.01027966], [93.00860596, 12.00943947], [93.0083313, 12.00916576], [93.0083313, 12.00861168], [93.0080719, 12.00833035], [93.00805664, 12.00805569], [93.00778198, 12.00778008], [93.00778198, 12.00722027], [93.00749969, 12.0069437], [93.00749969, 12.00555611], [93.00723267, 12.00527954], [93.00723267, 12.00472164], [93.00694275, 12.00444412], [93.00694275, 12.00167179], [93.00723267, 12.00139046], [93.00723267, 12.00028038], [93.00749969, 12.00028038], [93.00778198, 12.00000191], [93.0080719, 11.99889183], [93.0083313, 11.99861145], [93.0083313, 11.99805546], [93.00860596, 11.99777889], [93.00888062, 11.99747181], [93.0091095, 11.9971714], [93.00927734, 11.99682045], [93.0094223, 11.99642086], [93.00948334, 11.9959898], [93.00963593, 11.99562073], [93.00975037, 11.99525166], [93.00991821, 11.99493027], [93.01004791, 11.99460888], [93.01022339, 11.99431133], [93.01036072, 11.99394608], [93.01056671, 11.99356079], [93.01081848, 11.99314976], [93.01104736, 11.99271965], [93.01119995, 11.99229145], [93.01136017, 11.99192429], [93.01145172, 11.99154758], [93.01159668, 11.99122047], [93.01171875, 11.99084187], [93.01197052, 11.99051094], [93.01216125, 11.99011707], [93.01243591, 11.98976135], [93.01254272, 11.98925114], [93.01276398, 11.98878765], [93.01302338, 11.98830032], [93.01328278, 11.98778057], [93.01352692, 11.98727036], [93.0137558, 11.9867506], [93.01402283, 11.98637486], [93.0140686, 11.98596001], [93.01416779, 11.98561954], [93.01431274, 11.98526001], [93.0144577, 11.98484135], [93.0147171, 11.98439217], [93.01496124, 11.983881], [93.01520538, 11.98335743], [93.01547241, 11.98287201], [93.01573181, 11.98243618], [93.01580811, 11.98192978], [93.01587677, 11.98147011], [93.01608276, 11.98108006], [93.0161972, 11.98064041], [93.0164032, 11.98024082], [93.0166626, 11.97988129], [93.01686096, 11.9795208], [93.01705933, 11.97917938], [93.01728058, 11.97888088], [93.01763153, 11.97872829], [93.01790619, 11.97846127], [93.01809692, 11.97803974], [93.01824951, 11.97762012], [93.01847076, 11.97728062], [93.01858521, 11.97695923], [93.01872253, 11.97667027], [93.01891327, 11.9763813], [93.0191803, 11.97609138], [93.0194397, 11.97574043], [93.01967621, 11.97533035], [93.01980591, 11.97478104], [93.02001953, 11.97422695], [93.02030182, 11.97367096], [93.02057648, 11.9731102], [93.02086639, 11.97260189], [93.02114105, 11.97219181], [93.02138519, 11.97186089], [93.02159882, 11.97155094], [93.02174377, 11.97118378], [93.02194977, 11.97083092], [93.02216339, 11.97046185], [93.02231598, 11.9700489], [93.02250671, 11.96969128], [93.02272034, 11.96938133], [93.02288818, 11.96905136], [93.02308655, 11.96876812], [93.02333069, 11.96849537], [93.02359009, 11.9681797], [93.02384949, 11.96783638], [93.02414703, 11.96750069], [93.02442932, 11.96711636], [93.02469635, 11.96669197], [93.02494049, 11.96625423], [93.02510071, 11.96575546], [93.02528381, 11.96529293], [93.02548218, 11.96487999], [93.02559662, 11.96446133], [93.02577972, 11.96410084], [93.02577972, 11.96369934], [93.02561188, 11.96328163], [93.02560425, 11.96287441], [93.02578735, 11.96248913], [93.02587128, 11.96210194], [93.02598572, 11.96169567], [93.02590179, 11.96121979], [93.02562714, 11.96077061], [93.0255661, 11.96033955], [93.02565002, 11.95993042], [93.02580261, 11.95954037], [93.02588654, 11.95914078], [93.02607727, 11.95879936], [93.02619934, 11.95841026], [93.02635956, 11.95805168], [93.02645111, 11.95765114], [93.02661133, 11.95732021], [93.02671051, 11.95696926], [93.02688599, 11.95669079], [93.02700043, 11.95633125], [93.02715302, 11.95600986], [93.02722931, 11.95566082], [93.02732849, 11.9553299], [93.02746582, 11.9550209], [93.02754211, 11.95467186], [93.02768707, 11.95436192], [93.02778625, 11.95403957], [93.02792358, 11.95373726], [93.0280304, 11.95340919], [93.02805328, 11.95300961], [93.02805328, 11.95258045], [93.02805328, 11.95213985], [93.02809906, 11.95172024], [93.02831268, 11.95141029], [93.02851868, 11.95111942], [93.02877808, 11.95083141], [93.02905273, 11.95053673], [93.02923584, 11.95021152], [93.02946472, 11.9499197], [93.02971649, 11.94965076], [93.02999878, 11.94936085], [93.0302887, 11.94903564], [93.03061676, 11.94870472], [93.03100586, 11.94846058], [93.03141022, 11.94837475], [93.03177643, 11.94846058], [93.03213501, 11.94859791], [93.03244781, 11.94871235], [93.03270721, 11.94886017], [93.03299713, 11.94898129], [93.03328705, 11.94913101], [93.03365326, 11.94917011], [93.03398132, 11.94916344], [93.03447723, 11.94909859], [93.03491211, 11.94893074], [93.03540039, 11.94885826], [93.03588867, 11.94871044], [93.03639984, 11.94857121], [93.03682709, 11.94829273], [93.0371933, 11.94791031], [93.03743744, 11.94745159], [93.03749084, 11.94689274], [93.03744507, 11.94634247], [93.03727722, 11.94586086], [93.03722382, 11.94538879], [93.03723907, 11.94493103], [93.03734589, 11.94447041], [93.03749847, 11.94444466], [93.03778076, 11.94416714], [93.03778076, 11.94361115], [93.03805542, 11.94361115], [93.03861237, 11.94305515], [93.03833008, 11.9427824], [93.03888702, 11.94222069], [93.03888702, 11.94194508], [93.03916931, 11.9416666], [93.03916931, 11.94139957], [93.03971863, 11.94083118], [93.03971863, 11.94027901], [93.04000092, 11.94000053], [93.04000092, 11.93972111], [93.04027557, 11.93944454], [93.04027557, 11.93916702], [93.04055786, 11.93889141], [93.04055786, 11.93861103], [93.04083252, 11.9383297], [93.04083252, 11.93750095], [93.04110718, 11.93721962], [93.04111481, 11.93694496], [93.04149628, 11.936553], [93.04164124, 11.93612194], [93.04167175, 11.93569088], [93.04167175, 11.93527031], [93.04166412, 11.93487453], [93.04165649, 11.93447018], [93.04167938, 11.93408012], [93.04180145, 11.93373108], [93.04210663, 11.93343925], [93.04243469, 11.93314266], [93.04267883, 11.93277645], [93.04286957, 11.93245029], [93.04308319, 11.93208122], [93.04335022, 11.93166161], [93.04368591, 11.93123531], [93.04400635, 11.93077087], [93.04431152, 11.93032169], [93.04447174, 11.92991066], [93.04460144, 11.9296217], [93.04469299, 11.92936039], [93.0447464, 11.9290657], [93.04483032, 11.92873287], [93.04477692, 11.92837334], [93.04473114, 11.92799187], [93.04472351, 11.9276123], [93.04475403, 11.92724037], [93.04489136, 11.92689133], [93.04498291, 11.92653084], [93.04503632, 11.92615128], [93.04524994, 11.92585659], [93.04550934, 11.92556], [93.04579926, 11.92527103], [93.04608917, 11.92496967], [93.0463562, 11.92468834], [93.04654694, 11.9243803], [93.04665375, 11.92401695], [93.04663849, 11.92362118], [93.04658508, 11.92329025], [93.04640198, 11.92304039], [93.0462265, 11.92282104], [93.04611206, 11.92278004], [93.04582977, 11.92249966], [93.04528046, 11.9219389], [93.04611206, 11.92111206], [93.04638672, 11.9211092], [93.04666901, 11.92138958], [93.04695129, 11.92138958], [93.04724121, 11.9211092], [93.0474472, 11.92096329], [93.04775238, 11.92060089], [93.04792786, 11.92014122], [93.04784393, 11.91974926], [93.04779053, 11.91937923], [93.04774475, 11.9189806], [93.04759216, 11.91854095], [93.04746246, 11.91803741], [93.04727173, 11.9175396], [93.04724121, 11.91699982], [93.0473175, 11.91650105], [93.04738617, 11.91603088], [93.04747009, 11.91559601], [93.04753113, 11.91518974], [93.04766083, 11.91477966], [93.0477829, 11.91430092], [93.04789734, 11.91384602], [93.04808044, 11.91342163], [93.04833221, 11.91308022], [93.04865265, 11.91278076], [93.04901886, 11.91248703], [93.0493927, 11.91214085], [93.04962921, 11.91168022], [93.04946136, 11.91113281], [93.04922485, 11.91059113], [93.04915619, 11.91013145], [93.04916382, 11.90974998], [93.04915619, 11.90941048], [93.04915619, 11.90905857], [93.04921722, 11.90868092], [93.04944611, 11.90832615], [93.04972076, 11.90793991], [93.04998779, 11.90753937], [93.05028534, 11.90717888], [93.05055237, 11.90687847], [93.05078888, 11.90660858], [93.05098724, 11.90631962], [93.05136108, 11.90601921], [93.051651, 11.90558243], [93.05190277, 11.90512085], [93.05222321, 11.90487957], [93.05253601, 11.9047308], [93.05285645, 11.90462017], [93.05317688, 11.90442085], [93.05349731, 11.90413189], [93.05381775, 11.90371037], [93.05403137, 11.9031496], [93.05409241, 11.90254116], [93.05393982, 11.90193939], [93.05389404, 11.90139008], [93.05390167, 11.90092087], [93.05397797, 11.90048981], [93.05412292, 11.90010929], [93.05416107, 11.89966011], [93.0541687, 11.89913177], [93.0541687, 11.89854145], [93.05416107, 11.89791012], [93.0541153, 11.89729881], [93.05393982, 11.89674091], [93.05384064, 11.89616203], [93.05361938, 11.89563084], [93.05339813, 11.89507008], [93.05314636, 11.89452267], [93.05290985, 11.89401531], [93.05258942, 11.89368916], [93.05233765, 11.89342022], [93.05223846, 11.89311886], [93.05218506, 11.89281845], [93.05200958, 11.89253139], [93.05192566, 11.89222813], [93.05178833, 11.89192009], [93.05168152, 11.8915596], [93.05161285, 11.89115047], [93.05129242, 11.89085102], [93.05092621, 11.89056015], [93.05066681, 11.89021969], [93.05052948, 11.88982582], [93.05031586, 11.88948154], [93.05007172, 11.88918304], [93.04978943, 11.88892841], [93.04955292, 11.88869095], [93.04931641, 11.8884306], [93.04911041, 11.88811016], [93.04886627, 11.88771057], [93.04860687, 11.88724995], [93.04839325, 11.88670063], [93.04801178, 11.88640022], [93.04766083, 11.88614273], [93.04734039, 11.88591003], [93.04706573, 11.88566399], [93.04680634, 11.88540363], [93.04655457, 11.88513088], [93.04634857, 11.88479614], [93.04614258, 11.88444042], [93.04598236, 11.88400936], [93.04566193, 11.88376808], [93.04512024, 11.88374138], [93.04464722, 11.88363075], [93.04434967, 11.88350105], [93.04415131, 11.88337994], [93.04390717, 11.8833189], [93.04360199, 11.88319778], [93.04328918, 11.88292027], [93.04299927, 11.88252068], [93.0426712, 11.88226128], [93.042099, 11.88229084], [93.04180145, 11.88220882], [93.04160309, 11.8821497], [93.04107666, 11.88198566], [93.04055023, 11.88194656], [93.04007721, 11.8819418], [93.039711, 11.88193989], [93.03940582, 11.88190079], [93.03917694, 11.88175106], [93.03896332, 11.88157082], [93.03855133, 11.88160038], [93.03807068, 11.88165092], [93.03755188, 11.88167095], [93.03725433, 11.88166428], [93.0369873, 11.88166046], [93.03634644, 11.88158035], [93.03593445, 11.88165665], [93.0355072, 11.88173008], [93.03482819, 11.88189697], [93.03439331, 11.88216972], [93.03391266, 11.88234138], [93.03341675, 11.88254166], [93.03292847, 11.88280201], [93.03244019, 11.88309097], [93.03196716, 11.88335991], [93.03161621, 11.88369274], [93.03136444, 11.88405991], [93.03111267, 11.88436985], [93.03079224, 11.88461971], [93.03037262, 11.88479996], [93.02993011, 11.88507843], [93.02945709, 11.88542938], [93.0290451, 11.88580799], [93.02858734, 11.88611317], [93.02813721, 11.88639069], [93.02767944, 11.88667202], [93.02719879, 11.88694954], [93.02671051, 11.88723373], [93.02625275, 11.88753986], [93.02578735, 11.88787937], [93.0252533, 11.88821697], [93.02494049, 11.88887119], [93.02459717, 11.88953018], [93.02468872, 11.89011955], [93.02471161, 11.89057064], [93.02462006, 11.8909359], [93.0245285, 11.89127254], [93.02446747, 11.89163113], [93.02422333, 11.89194107], [93.02391815, 11.89233112], [93.02349091, 11.8927412], [93.0234375, 11.89328098], [93.02349091, 11.89396], [93.02348328, 11.89465141], [93.02340698, 11.89524555], [93.02336121, 11.89572239], [93.02334595, 11.89610481], [93.02327728, 11.89637375], [93.02309418, 11.89652443], [93.02287292, 11.89663124], [93.02259827, 11.89671993], [93.02236176, 11.89701939], [93.0222702, 11.89778519], [93.02225494, 11.89855289], [93.02231598, 11.89905167], [93.02245331, 11.89935017], [93.02249908, 11.89962196], [93.02249908, 11.89990044], [93.02250671, 11.90017986], [93.02249908, 11.90050983], [93.02246094, 11.9008522], [93.02230835, 11.90120125], [93.0220871, 11.90151119], [93.02186584, 11.90187073], [93.02156067, 11.90221119], [93.02118683, 11.90254116], [93.02086639, 11.90289021], [93.02060699, 11.90329075], [93.02039337, 11.90375805], [93.02012634, 11.904212], [93.01991272, 11.90472031], [93.01971436, 11.90521717], [93.01951599, 11.90567493], [93.01944733, 11.90613079], [93.01937103, 11.90654087], [93.01920319, 11.90685081], [93.01908112, 11.9071722], [93.01886749, 11.90746021], [93.01860046, 11.90780067], [93.01833344, 11.90820503], [93.01803589, 11.9085989], [93.01773071, 11.90893173], [93.01750946, 11.9092989], [93.01735687, 11.90966129], [93.01729584, 11.90997124], [93.01721954, 11.91025066], [93.01708221, 11.91052723], [93.01685333, 11.91076183], [93.0165329, 11.91097164], [93.01637268, 11.91132927], [93.01613617, 11.91165066], [93.01592255, 11.9119606], [93.01574707, 11.91226196], [93.01551819, 11.91253662], [93.01535034, 11.91288185], [93.01515961, 11.91321945], [93.01494598, 11.91356277], [93.01452637, 11.91380024], [93.01419067, 11.91415596], [93.01383209, 11.91451073], [93.0135498, 11.9148922], [93.01329803, 11.91522503], [93.01304626, 11.91548443], [93.01280975, 11.91571236], [93.01263428, 11.91598129], [93.01248932, 11.91627312], [93.01233673, 11.91657162], [93.01220703, 11.9169178], [93.01206207, 11.91723919], [93.01196289, 11.91755772], [93.01190186, 11.91786385], [93.0117569, 11.91809177], [93.01166534, 11.91835594], [93.01153564, 11.91861439], [93.01138306, 11.91890144], [93.0111618, 11.91922855], [93.01093292, 11.91962147], [93.01062775, 11.92004013], [93.01035309, 11.92047977], [93.01004028, 11.92090607], [93.00977325, 11.92136002], [93.00953674, 11.92186069], [93.00917816, 11.92224407], [93.00888824, 11.92268181], [93.00862122, 11.9231348], [93.00836945, 11.92362118], [93.00808716, 11.92414093], [93.00778198, 11.92467785], [93.00749969, 11.92525005], [93.0072403, 11.92583179], [93.00701904, 11.92638779], [93.00681305, 11.92689133], [93.00653076, 11.92727375], [93.00610352, 11.9275341], [93.00582886, 11.92786026], [93.00563812, 11.92815018], [93.00557709, 11.92843437], [93.00554657, 11.92860985], [93.0036087, 11.9305563], [93.0036087, 11.93083191], [93.00335693, 11.93105125], [93.00305176, 11.93128967], [93.00261688, 11.93146992], [93.00215912, 11.93175125], [93.00171661, 11.93209934], [93.00164795, 11.93223095], [93.0, 11.9338913], [92.99973297, 11.93391132], [92.99936676, 11.93391132], [92.99880219, 11.93390656], [92.99829865, 11.93404102], [92.99803925, 11.93460178], [92.99775696, 11.93501186], [92.99761963, 11.93549061], [92.99761963, 11.93605137], [92.99817657, 11.93667126], [92.9983902, 11.93715], [92.99852753, 11.93728924], [92.99845886, 11.9377718], [92.99810791, 11.93825054], [92.99771118, 11.93871784], [92.99733734, 11.938941], [92.99671173, 11.93956566], [92.99636078, 11.93977261], [92.9956665, 11.93949699], [92.99545288, 11.93949699], [92.99517059, 11.93962955], [92.99468231, 11.94004917], [92.99453735, 11.94066048], [92.99447632, 11.94164181], [92.99482727, 11.94196129], [92.99494171, 11.94219112], [92.99512482, 11.94242096], [92.99542236, 11.94258308], [92.99563599, 11.94283199], [92.99585724, 11.94315147], [92.9961319, 11.94349003], [92.99645233, 11.94389057], [92.99682617, 11.94432926], [92.99726868, 11.94476032], [92.99775696, 11.94514275], [92.99829865, 11.94550133], [92.9990387, 11.94578075], [92.99972534, 11.94555473], [93.0, 11.94583321], [93.00031281, 11.94614315], [93.00055695, 11.94642067], [93.00086212, 11.94670582], [93.00110626, 11.94699287], [93.0015564, 11.94720078], [93.00190735, 11.94762039], [93.00190735, 11.94803047], [93.00177002, 11.94837475], [93.0013504, 11.94837475], [93.00093079, 11.94865036], [93.00048065, 11.94968128], [93.0003891, 11.95020008], [93.00026703, 11.95014095], [93.0, 11.94999981], [92.99972534, 11.94883728], [92.99962616, 11.94857121], [92.99925995, 11.94828129], [92.998909, 11.94794178], [92.99855042, 11.94756985], [92.99809265, 11.94724178], [92.99733734, 11.94715977], [92.99698639, 11.94714165], [92.99651337, 11.94720078], [92.99604034, 11.94740105], [92.99537659, 11.94782066], [92.99513245, 11.94837475], [92.99479675, 11.94887066], [92.99433136, 11.94924736], [92.99397278, 11.94960117], [92.99355316, 11.95001602], [92.99307251, 11.95019341], [92.99254608, 11.95031166], [92.99209595, 11.95063305], [92.99167633, 11.95084953], [92.99110413, 11.95108223], [92.99085999, 11.95118046], [92.99028015, 11.95107079], [92.98977661, 11.95092869], [92.98929596, 11.95040131], [92.98883057, 11.95020866], [92.98844147, 11.94996071], [92.98813629, 11.94964218], [92.98787689, 11.9492588], [92.98753357, 11.94890785], [92.98721313, 11.94855022], [92.98693848, 11.94817162], [92.98654175, 11.9477911], [92.98618317, 11.94740963], [92.98599243, 11.9469614], [92.98599243, 11.94647598], [92.98635864, 11.94601059], [92.98619843, 11.94563961], [92.98599243, 11.94535923], [92.9858017, 11.94511986], [92.98487854, 11.94494438], [92.98403168, 11.94511986], [92.98340607, 11.94543362], [92.98287964, 11.94556427], [92.98240662, 11.94556046], [92.98163605, 11.94567204], [92.98117828, 11.94581127], [92.98071289, 11.94615173], [92.98027039, 11.94643974], [92.97985077, 11.94668579], [92.97941589, 11.94694138], [92.97897339, 11.94717121], [92.97845459, 11.94723988], [92.97793579, 11.94734001], [92.97744751, 11.94749928], [92.9769516, 11.94764519], [92.97650146, 11.94776058], [92.97609711, 11.94783878], [92.9757309, 11.94794369], [92.97541809, 11.94805145], [92.9749527, 11.94806004], [92.97438049, 11.94839096], [92.97386932, 11.94880104], [92.97336578, 11.94917011], [92.9730072, 11.9496212], [92.97264099, 11.95007038], [92.97235107, 11.95059013], [92.9719162, 11.95112133], [92.97154999, 11.95152187], [92.97144318, 11.9518137], [92.97118378, 11.95220375], [92.97103119, 11.95259094], [92.97071075, 11.953022], [92.97059631, 11.95335007], [92.97041321, 11.95372105], [92.97000885, 11.95407009], [92.96981812, 11.95451927], [92.96949768, 11.9549408], [92.96920776, 11.9553442], [92.96895599, 11.95575428], [92.96864319, 11.95613003], [92.96835327, 11.95652008], [92.96820068, 11.95692062], [92.9682312, 11.95731068], [92.96808624, 11.95767975], [92.96805573, 11.95809746], [92.96800995, 11.95853329], [92.96781921, 11.95891094], [92.96770477, 11.959342], [92.96749878, 11.95969486], [92.9672699, 11.96000004], [92.96713257, 11.96037197], [92.9670105, 11.96074963], [92.96686554, 11.96118641], [92.96650696, 11.96155262], [92.96630096, 11.96211815], [92.96627808, 11.96253014], [92.96628571, 11.9630661], [92.96631622, 11.9635601], [92.966362, 11.96407986], [92.96624756, 11.96459103], [92.96611786, 11.96510124], [92.96604156, 11.96559143], [92.96586609, 11.96601105], [92.96583557, 11.96640491], [92.96578979, 11.96675968]]], [[[92.63062286, 12.11791039], [92.63050842, 12.11791039], [92.63019562, 12.11799717], [92.63013458, 12.11822319], [92.63006592, 12.11848927], [92.63008881, 12.11875057], [92.63021851, 12.11889935], [92.63031769, 12.11919594], [92.63031769, 12.11946201], [92.63047028, 12.11973095], [92.6305542, 12.11991787], [92.6307373, 12.12010288], [92.63096619, 12.1202898], [92.63116455, 12.12045383], [92.63153839, 12.12045383], [92.63166809, 12.12022781], [92.63165283, 12.11979103], [92.6315155, 12.11938], [92.63141632, 12.11901093], [92.6312027, 12.11857986], [92.63101196, 12.11824131], [92.63082123, 12.1180582], [92.63062286, 12.11791039]]], [[[92.62884521, 12.11245632], [92.62821198, 12.11220074], [92.62800598, 12.11244011], [92.62802124, 12.11275005], [92.62812805, 12.11310101], [92.62828064, 12.11339092], [92.62847137, 12.11370087], [92.62863922, 12.11405182], [92.62867737, 12.1143589], [92.62867737, 12.11475086], [92.62872314, 12.11508179], [92.62896729, 12.11537075], [92.62922668, 12.11561775], [92.62956238, 12.1158638], [92.62985229, 12.11609173], [92.63002014, 12.11633968], [92.63018799, 12.11655045], [92.63037872, 12.11655045], [92.63041687, 12.11622238], [92.63041687, 12.1157589], [92.63037872, 12.1151638], [92.63033295, 12.11435699], [92.63031769, 12.11375999], [92.63031769, 12.11332035], [92.63018799, 12.11305618], [92.62982941, 12.11281013], [92.62934875, 12.11262035], [92.62884521, 12.11245632]]], [[[92.69890594, 12.24483776], [92.69860077, 12.24473095], [92.69824982, 12.24481487], [92.69777679, 12.24501133], [92.69732666, 12.24528408], [92.69692993, 12.24556923], [92.69660187, 12.24584103], [92.69633484, 12.24617767], [92.69610596, 12.24661064], [92.69593811, 12.24714184], [92.69586945, 12.24769974], [92.69605255, 12.24827003], [92.69610596, 12.2489109], [92.69618988, 12.24958706], [92.69657898, 12.25021362], [92.6969986, 12.25082493], [92.69743347, 12.25085163], [92.69769287, 12.25067234], [92.6978302, 12.25057888], [92.69822693, 12.25028038], [92.6986084, 12.24998379], [92.69889069, 12.24960995], [92.69911194, 12.24920177], [92.69921875, 12.24870968], [92.69940948, 12.24828053], [92.69948578, 12.24780273], [92.69967651, 12.24738979], [92.69972229, 12.2468996], [92.69972229, 12.24635124], [92.699646, 12.24577427], [92.6993866, 12.24524117], [92.69890594, 12.24483776]]], [[[92.90143585, 12.26215172], [92.90141296, 12.25907135], [92.9008255, 12.25855637], [92.90029907, 12.25861454], [92.89972687, 12.25915527], [92.89968872, 12.25965405], [92.89949036, 12.25961113], [92.89944458, 12.26079178], [92.89974976, 12.26081181], [92.89974976, 12.26158047], [92.90001678, 12.26163006], [92.90001678, 12.26246452], [92.90115356, 12.26244926], [92.90143585, 12.26215172]]], [[[92.88054657, 12.25], [92.88083649, 12.24971962], [92.88111115, 12.24972153], [92.88194275, 12.24888992], [92.88175201, 12.24632072], [92.88111115, 12.24527073], [92.88027954, 12.24611187], [92.88027954, 12.24666786], [92.87999725, 12.24694061], [92.87999725, 12.24777985], [92.8797226, 12.24777985], [92.87944794, 12.24805641], [92.87944794, 12.2486124], [92.8797226, 12.24860954], [92.87999725, 12.24888992], [92.87999725, 12.24971962], [92.88018799, 12.24990559], [92.88027954, 12.25], [92.88054657, 12.25]]], [[[93.02966309, 12.28017139], [93.02997589, 12.27981567], [93.03029633, 12.27965069], [93.03044128, 12.27928925], [93.03037262, 12.27844143], [93.03029633, 12.27791023], [93.0300827, 12.27749062], [93.02980042, 12.2772007], [93.02947235, 12.27706242], [93.02925873, 12.27699184], [93.02922058, 12.27671146], [93.02919006, 12.27639008], [93.02900696, 12.27600861], [93.02879333, 12.27554035], [93.02850342, 12.27501297], [93.02832794, 12.27476501], [93.02813721, 12.27458954], [93.02778625, 12.27427006], [93.02749634, 12.2740202], [93.02700043, 12.27353001], [93.0266037, 12.27342319], [93.02645874, 12.27346134], [93.02613831, 12.27334976], [93.02584839, 12.27338791], [93.02548981, 12.27356243], [93.0252533, 12.27359962], [93.02487946, 12.27367115], [93.0247345, 12.27402401], [93.0242691, 12.27395439], [93.02394867, 12.27398968], [93.02359009, 12.2740612], [93.02323151, 12.27423573], [93.02279663, 12.27440929], [93.02230072, 12.27458954], [93.02207947, 12.27476501], [93.02194214, 12.27501297], [93.0220108, 12.27522469], [93.02216339, 12.27540112], [93.02230072, 12.27582932], [93.02258301, 12.27618027], [93.02283478, 12.27639008], [93.02323151, 12.27667046], [93.02362823, 12.27699184], [93.02379608, 12.27731991], [93.02391052, 12.27755928], [93.02420044, 12.277771], [93.02448273, 12.27802181], [93.02462769, 12.27812004], [93.02502441, 12.27815628], [93.0253067, 12.27824116], [93.0256424, 12.27834797], [93.02585602, 12.27845001], [93.02613831, 12.27848911], [93.02649689, 12.27859402], [93.02703094, 12.27900028], [93.02746582, 12.27935696], [93.02761078, 12.27949047], [93.02803802, 12.28003025], [93.02832794, 12.27996063], [93.0284729, 12.27982044], [93.028862, 12.28003025], [93.02929688, 12.28017139], [93.02966309, 12.28017139]]], [[[92.73760986, 12.27133274], [92.73729706, 12.27073097], [92.73703766, 12.27073574], [92.73703766, 12.27045727], [92.736763, 12.27017021], [92.736763, 12.26990128], [92.73648071, 12.2696228], [92.73648071, 12.26934528], [92.73506927, 12.26935387], [92.73506927, 12.27047253], [92.73536682, 12.27046204], [92.73542023, 12.27106094], [92.73590088, 12.27106094], [92.73622894, 12.27133274], [92.73620605, 12.27184963], [92.73648834, 12.27184963], [92.73648834, 12.27243137], [92.73699951, 12.27243137], [92.73703766, 12.27435017], [92.73762512, 12.27466488], [92.73760986, 12.27524376], [92.73786926, 12.27552414], [92.73839569, 12.27550316], [92.73841858, 12.27522469], [92.73880005, 12.27504063], [92.7388916, 12.27479935], [92.73886871, 12.27458286], [92.73870087, 12.27440739], [92.73871613, 12.27299023], [92.73844147, 12.27293015], [92.73847961, 12.27243137], [92.73815155, 12.27243137], [92.73813629, 12.27133274], [92.73760986, 12.27133274]]], [[[93.12052917, 12.14834976], [93.12052917, 12.14800167], [93.12021637, 12.14800358], [93.12021637, 12.1477623], [93.12049103, 12.14762592], [93.12039185, 12.14558983], [93.11992645, 12.14563084], [93.11987305, 12.14528275], [93.11937714, 12.14528275], [93.11937714, 12.14462852], [93.11965179, 12.14459038], [93.11965179, 12.14421558], [93.11860657, 12.14422131], [93.11856842, 12.14439201], [93.11836243, 12.14439201], [93.11836243, 12.14387035], [93.11909485, 12.14383602], [93.119133, 12.14356041], [93.11940765, 12.14339066], [93.11972809, 12.14339066], [93.11979675, 12.14360142], [93.12018585, 12.14360142], [93.12024689, 12.14376926], [93.12049103, 12.14380074], [93.12081146, 12.14383984], [93.12081146, 12.14409065], [93.12049103, 12.14414501], [93.12052917, 12.14435291], [93.12136841, 12.14442062], [93.12140656, 12.14466953], [93.12161255, 12.14470196], [93.1216507, 12.14494133], [93.12188721, 12.14484119], [93.12191772, 12.14435101], [93.12220764, 12.1442852], [93.12217712, 12.14387226], [93.12188721, 12.14391136], [93.12188721, 12.14363003], [93.12161255, 12.14356041], [93.12161255, 12.1430397], [93.12133026, 12.14297581], [93.12136841, 12.14280128], [93.12161255, 12.14266586], [93.12161255, 12.14169979], [93.12133026, 12.14162922], [93.12136841, 12.14135647], [93.12161255, 12.14128971], [93.12161255, 12.14076996], [93.12185669, 12.14076996], [93.12188721, 12.14050102], [93.12238312, 12.14050102], [93.12242126, 12.14030075], [93.12266541, 12.14028931], [93.12269592, 12.14050102], [93.12361145, 12.14050102], [93.12361145, 12.14026165], [93.1232605, 12.14026165], [93.1232605, 12.13995171], [93.12290955, 12.1399107], [93.12290955, 12.13973999], [93.12272644, 12.13963985], [93.12267303, 12.13857079], [93.12185669, 12.13857079], [93.12185669, 12.13777065], [93.1216507, 12.13777542], [93.12158203, 12.13746452], [93.12133026, 12.13746452], [93.12129974, 12.1372242], [93.12101746, 12.1372242], [93.12101746, 12.13691425], [93.12028503, 12.13694763], [93.12025452, 12.13674068], [93.12029266, 12.13630104], [93.11992645, 12.13630104], [93.11992645, 12.13613033], [93.11962128, 12.13613033], [93.11965179, 12.13558006], [93.11936951, 12.13561153], [93.11930084, 12.13519955], [93.11878204, 12.13527107], [93.11881256, 12.13479042], [93.1181488, 12.13471889], [93.11821747, 12.13441086], [93.11856842, 12.13441086], [93.11856842, 12.13416958], [93.11801147, 12.13416958], [93.11801147, 12.13362026], [93.11772919, 12.13362026], [93.11772919, 12.13330078], [93.11737823, 12.13330555], [93.11737823, 12.13306427], [93.11724091, 12.13298893], [93.11720276, 12.13226032], [93.11664581, 12.13185215], [93.11664581, 12.1313343], [93.11636353, 12.1313343], [93.11640167, 12.13078308], [93.11605072, 12.13078308], [93.11608887, 12.12992096], [93.11556244, 12.12995052], [93.11546326, 12.13050938], [93.11499786, 12.13050938], [93.1149292, 12.13105869], [93.11437225, 12.13154221], [93.11437225, 12.13202], [93.11472321, 12.13237095], [93.11472321, 12.13284969], [93.11444092, 12.13298893], [93.11444092, 12.13315105], [93.11419678, 12.13340187], [93.11408997, 12.13430023], [93.11382294, 12.13461018], [93.11342621, 12.13464069], [93.11328888, 12.13529968], [93.11276245, 12.1353302], [93.11274719, 12.13550091], [93.11248016, 12.13553715], [93.11244965, 12.13581085], [93.11269379, 12.13581085], [93.11255646, 12.13622475], [93.11220551, 12.13653469], [93.11221313, 12.13722134], [93.11188507, 12.13725758], [93.11188507, 12.13749981], [93.11221313, 12.13749981], [93.11223602, 12.13805103], [93.11199188, 12.13808537], [93.11192322, 12.13853168], [93.11132813, 12.139081], [93.11102295, 12.13926125], [93.11107635, 12.13981056], [93.11052704, 12.13980579], [93.11052704, 12.14001274], [93.11017609, 12.14001083], [93.11017609, 12.14046001], [93.10964966, 12.14046001], [93.10971832, 12.14112091], [93.10996246, 12.14112091], [93.11000061, 12.14198017], [93.11027527, 12.14197636], [93.11027527, 12.14249325], [93.10940552, 12.14249325], [93.10933685, 12.14273167], [93.10909271, 12.1427803], [93.10909271, 12.14308071], [93.10936737, 12.1430788], [93.10936737, 12.14387035], [93.10946655, 12.14393997], [93.10975647, 12.14391136], [93.10975647, 12.14352989], [93.11077118, 12.14352989], [93.1108017, 12.14387226], [93.11161041, 12.14383602], [93.11161041, 12.14356041], [93.11269379, 12.14356041], [93.11269379, 12.14387226], [93.11300659, 12.14387226], [93.11300659, 12.14411068], [93.11437225, 12.14411068], [93.11444092, 12.14442062], [93.11503601, 12.14442062], [93.11503601, 12.14500713], [93.1153183, 12.14504147], [93.1153183, 12.14548969], [93.11582184, 12.14542198], [93.11582184, 12.14577007], [93.11608887, 12.14577007], [93.11608887, 12.14638996], [93.1163559, 12.14638996], [93.11633301, 12.14717674], [93.11660767, 12.14721107], [93.11664581, 12.14807224], [93.11720276, 12.14807224], [93.11720276, 12.14772797], [93.11752319, 12.14773273], [93.11749268, 12.14803791], [93.11881256, 12.14803791], [93.11881256, 12.14776039], [93.11972809, 12.1477623], [93.11975861, 12.14807034], [93.12000275, 12.14810658], [93.12004089, 12.14831448], [93.12025452, 12.14832973], [93.12052917, 12.14834976]]], [[[93.09793091, 12.13719177], [93.09799957, 12.13695335], [93.0982132, 12.13695335], [93.0982132, 12.13664341], [93.09856415, 12.13660622], [93.09855652, 12.13606071], [93.09874725, 12.13601971], [93.09875488, 12.13581467], [93.09851074, 12.13578129], [93.09851074, 12.13519096], [93.09829712, 12.13522911], [93.09836578, 12.13512707], [93.09835052, 12.13448048], [93.09799957, 12.13448048], [93.09799957, 12.134202], [93.09832001, 12.13409042], [93.09832001, 12.13388729], [93.09803772, 12.13385296], [93.09790039, 12.13350868], [93.09748077, 12.13357925], [93.09739685, 12.13392067], [93.09716034, 12.133955], [93.09706116, 12.134161], [93.09664154, 12.134202], [93.09664154, 12.13474941], [93.09632111, 12.13478279], [93.09638977, 12.13657188], [93.09688568, 12.13653755], [93.0969162, 12.13688183], [93.09739685, 12.13688183], [93.09748077, 12.13715839], [93.09793091, 12.13719177]]], [[[92.96982574, 12.06400681], [92.96974182, 12.06394482], [92.96951294, 12.06414986], [92.96953583, 12.0643568], [92.96959686, 12.06448078], [92.96951294, 12.06470776], [92.9694519, 12.06484985], [92.96946716, 12.06496143], [92.96954346, 12.064991], [92.96976471, 12.06507969], [92.96987152, 12.06520081], [92.9702301, 12.06527138], [92.97052002, 12.06529045], [92.97090149, 12.06529045], [92.97106934, 12.06520081], [92.97108459, 12.06425476], [92.97052002, 12.06423378], [92.97012329, 12.06423378], [92.96990967, 12.06414986], [92.96982574, 12.06400681]]], [[[92.94863129, 12.11584091], [92.94890594, 12.11526203], [92.9491272, 12.11526203], [92.94919586, 12.11444187], [92.94967651, 12.1144619], [92.95027161, 12.11388111], [92.95030975, 12.11330032], [92.95083618, 12.11330223], [92.95089722, 12.11272335], [92.95140839, 12.11274433], [92.95142365, 12.11226273], [92.9519577, 12.11220264], [92.95230103, 12.11164474], [92.95281219, 12.11166286], [92.95289612, 12.11075211], [92.95330048, 12.11056519], [92.95336151, 12.10985088], [92.95353699, 12.10958004], [92.95391083, 12.10945034], [92.95417786, 12.10916996], [92.954216, 12.10818958], [92.9550705, 12.10746098], [92.95517731, 12.10674858], [92.95529175, 12.1066103], [92.95585632, 12.10609055], [92.95598602, 12.10571003], [92.95641327, 12.10556889], [92.95651245, 12.10488129], [92.95667267, 12.10470963], [92.95685577, 12.10368156], [92.95695496, 12.10329247], [92.95708466, 12.10291767], [92.95723724, 12.10276985], [92.95741272, 12.10229778], [92.95748138, 12.10219097], [92.95750427, 12.10077572], [92.95752716, 12.10033131], [92.95757294, 12.10000134], [92.95782471, 12.0990572], [92.95781708, 12.09848118], [92.95768738, 12.09786129], [92.95746613, 12.09689045], [92.95729065, 12.09654999], [92.95717621, 12.09615135], [92.95696259, 12.09579086], [92.95664215, 12.0954113], [92.95627594, 12.09502125], [92.95584869, 12.09464931], [92.95540619, 12.09429836], [92.95497894, 12.09398174], [92.95456696, 12.09373093], [92.95417786, 12.09350109], [92.95276642, 12.09222031], [92.95249939, 12.09222221], [92.9513855, 12.09111214], [92.9513855, 12.09083366], [92.95111084, 12.09055614], [92.95111084, 12.0886097], [92.95139313, 12.08832932], [92.9513855, 12.08777809], [92.95166779, 12.08749962], [92.95166779, 12.08722019], [92.95194244, 12.08694363], [92.95194244, 12.08638763], [92.9522171, 12.08611202], [92.9522171, 12.08555984], [92.95249939, 12.08528042], [92.95249939, 12.08444118], [92.95194244, 12.08388996], [92.95166779, 12.08388996], [92.95111084, 12.08444405], [92.95111084, 12.08472157], [92.95082855, 12.08500195], [92.95082855, 12.08528042], [92.95053864, 12.08555984], [92.95053864, 12.08638954], [92.95027924, 12.08666992], [92.95027924, 12.08749962], [92.94999695, 12.08778], [92.94999695, 12.08805561], [92.94972229, 12.08832932], [92.94972229, 12.09138966], [92.94967651, 12.09177113], [92.94967651, 12.09224987], [92.9495163, 12.09274197], [92.94944763, 12.09329987], [92.94940186, 12.09388828], [92.94921112, 12.09440136], [92.94918823, 12.09492779], [92.9492569, 12.0954113], [92.94915771, 12.09581184], [92.9489975, 12.09615135], [92.94890594, 12.0965004], [92.94889069, 12.09691048], [92.94889069, 12.097332], [92.94889069, 12.0977993], [92.94889069, 12.09832096], [92.94892883, 12.09889126], [92.9491272, 12.0994606], [92.94916534, 12.10006046], [92.94917297, 12.10064983], [92.94916534, 12.10123825], [92.94917297, 12.1018219], [92.94917297, 12.10240078], [92.94917297, 12.1029501], [92.94919586, 12.10344028], [92.94937134, 12.10384083], [92.94944, 12.10419178], [92.94944763, 12.10451603], [92.94944763, 12.10484886], [92.94944, 12.10522938], [92.94944763, 12.10567093], [92.94949341, 12.10617065], [92.94967651, 12.10668087], [92.94975281, 12.10725975], [92.94996643, 12.10773945], [92.95007324, 12.11104107], [92.94966125, 12.11107063], [92.94974518, 12.1119051], [92.94921875, 12.11218262], [92.94919586, 12.11326122], [92.94832611, 12.11392021], [92.94834137, 12.11584091], [92.94863129, 12.11584091]]], [[[92.99136353, 12.10892773], [92.99154663, 12.10807133], [92.99214935, 12.10723495], [92.99256897, 12.10696125], [92.9930191, 12.10676098], [92.99362183, 12.10712147], [92.99373627, 12.10725117], [92.9940033, 12.10733128], [92.99414063, 12.10733128], [92.99447632, 12.10729027], [92.99479675, 12.10722065], [92.99504852, 12.10709953], [92.99544525, 12.1069746], [92.99578094, 12.10678959], [92.9961319, 12.10662174], [92.99693298, 12.10635471], [92.99730682, 12.10617065], [92.99732971, 12.10581017], [92.99783325, 12.10558891], [92.99840546, 12.10551357], [92.99908447, 12.10562134], [92.99965668, 12.10540676], [93.0, 12.10527706], [93.00055695, 12.10528183], [93.0008316, 12.1055603], [93.00138855, 12.10500145], [93.00166321, 12.10527706], [93.0018158, 12.10538387], [93.00209808, 12.10534477], [93.00273895, 12.1049509], [93.00305176, 12.10499001], [93.00314331, 12.10500145], [93.00332642, 12.10500145], [93.00389099, 12.10444069], [93.00416565, 12.10444546], [93.00499725, 12.10361099], [93.00499725, 12.103055], [93.00527954, 12.1027813], [93.00527954, 12.09917068], [93.00479126, 12.09868145], [93.00417328, 12.09806061], [93.00417328, 12.09776974], [93.00389099, 12.0975008], [93.00389099, 12.09722042], [93.0036087, 12.09694481], [93.0036087, 12.09472179], [93.00389099, 12.09444427], [93.0036087, 12.0941658], [93.0036087, 12.09389114], [93.00250244, 12.09278107], [93.00250244, 12.09249973], [93.00222015, 12.09222031], [93.00222015, 12.09166622], [93.00193787, 12.09138966], [93.00193787, 12.08943939], [93.00222015, 12.08916569], [93.00193787, 12.08890247], [93.00193787, 12.08832932], [93.00166321, 12.08805561], [93.00164795, 12.08778], [93.00138855, 12.08749962], [93.00138855, 12.08722019], [93.00111389, 12.08694363], [93.00111389, 12.08666801], [93.0008316, 12.08638954], [93.0008316, 12.08444118], [93.00055695, 12.08416462], [93.00055695, 12.08111095], [93.0008316, 12.08083057], [93.0008316, 12.07916737], [93.00055695, 12.07888889], [93.00055695, 12.0775013], [93.00026703, 12.0775013], [93.00026703, 12.07722092], [93.00027466, 12.0769453], [93.00166321, 12.07527733], [93.00164795, 12.07444], [93.00139618, 12.07402611], [93.00118256, 12.07376099], [93.0, 12.07417107], [92.99973297, 12.07374096], [92.99967194, 12.07353973], [92.99946594, 12.07328892], [92.99928284, 12.07303047], [92.99913788, 12.07269001], [92.99894714, 12.07232094], [92.99893188, 12.07188129], [92.99910736, 12.07146168], [92.99935913, 12.07108116], [92.9996109, 12.0707798], [92.99973297, 12.07049274], [93.0, 12.07027912], [93.00055695, 12.07000065], [93.00055695, 12.0694418], [93.00067902, 12.06849575], [93.00055695, 12.06806087], [93.00055695, 12.06721973], [93.00027466, 12.06722164], [93.0, 12.06694412], [92.99966431, 12.06663704], [92.99938965, 12.06659985], [92.99913788, 12.06642246], [92.99884796, 12.06632423], [92.99861908, 12.06613541], [92.99835205, 12.06592083], [92.9981308, 12.0656004], [92.99806213, 12.06517601], [92.99809265, 12.06476116], [92.99830627, 12.0644598], [92.99848175, 12.06421185], [92.998703, 12.06406116], [92.99889374, 12.06388092], [92.99926758, 12.06365967], [93.0, 12.06306076], [93.0008316, 12.06306076], [93.00164795, 12.06221962], [93.00166321, 12.06166553], [93.00138855, 12.06138992], [93.00138855, 12.06110954], [93.00111389, 12.06083393], [93.00111389, 12.06027794], [93.0008316, 12.06000042], [93.0008316, 12.05972195], [93.00055695, 12.05944443], [93.00027466, 12.05944061], [93.0, 12.05916786], [92.99958038, 12.05902195], [92.99944305, 12.05846977], [93.0, 12.05778027], [93.00026703, 12.05750179], [93.0, 12.05667019], [92.99973297, 12.05637074], [92.99973297, 12.05622101], [92.99950409, 12.05587482], [92.99928284, 12.05544376], [92.99919128, 12.05492401], [92.99919128, 12.05440044], [92.99928284, 12.05393028], [92.99941254, 12.05355358], [92.9994812, 12.05323124], [92.99952698, 12.05289555], [92.99967957, 12.05268764], [92.99973297, 12.05237198], [93.0, 12.05194473], [93.00111389, 12.05166721], [93.00110626, 12.05139065], [93.00138855, 12.05111122], [93.00138855, 12.05083275], [93.00111389, 12.05055523], [93.00110626, 12.05028152], [93.0008316, 12.05000114], [93.0008316, 12.04971886], [93.0, 12.04972267], [92.99972534, 12.04914665], [92.99973297, 12.04856968], [92.99958038, 12.04796124], [92.9993515, 12.04753113], [92.99915314, 12.04723167], [92.99894714, 12.04698086], [92.99879456, 12.04669189], [92.99858856, 12.04639053], [92.99833679, 12.04611301], [92.99806213, 12.0458374], [92.99780273, 12.04557133], [92.99753571, 12.04532909], [92.9972229, 12.04515076], [92.9969101, 12.04496193], [92.99659729, 12.0447197], [92.9962616, 12.04451466], [92.99584961, 12.04441261], [92.99546814, 12.04421043], [92.99497986, 12.04412079], [92.99449158, 12.04393578], [92.99391937, 12.04384995], [92.99334717, 12.0436697], [92.99277496, 12.04361725], [92.99221039, 12.04365158], [92.99169159, 12.04382896], [92.99119568, 12.04393196], [92.99079895, 12.0441227], [92.99041748, 12.04433537], [92.99006653, 12.04465389], [92.98970032, 12.04499245], [92.98932648, 12.04531097], [92.98905182, 12.04566193], [92.98879242, 12.04593086], [92.98855591, 12.04611969], [92.98834229, 12.04627037], [92.98832703, 12.04639053], [92.98805237, 12.04638863], [92.98777771, 12.0466671], [92.98750305, 12.0466671], [92.98694611, 12.04722309], [92.98664856, 12.04722118], [92.98638916, 12.04750061], [92.98638916, 12.04778099], [92.9861145, 12.0480547], [92.9861145, 12.04833317], [92.98500061, 12.04944515], [92.98472595, 12.04944515], [92.98444366, 12.04972267], [92.98416901, 12.04971886], [92.98361206, 12.05028152], [92.98194122, 12.05028152], [92.98166656, 12.05000114], [92.98110962, 12.05000114], [92.98027802, 12.05083275], [92.97982025, 12.05136204], [92.97976685, 12.05204105], [92.97994995, 12.05269527], [92.98000336, 12.05335236], [92.98000336, 12.05398273], [92.97989655, 12.05456161], [92.97955322, 12.05504036], [92.97917175, 12.05556011], [92.97878265, 12.05609989], [92.97834778, 12.05663109], [92.97787476, 12.05711174], [92.97740173, 12.05753136], [92.97702789, 12.057971], [92.97670746, 12.05836105], [92.97646332, 12.05871201], [92.97633362, 12.05906105], [92.97616577, 12.05933189], [92.97603607, 12.05962086], [92.97605896, 12.0601387], [92.97598267, 12.06057167], [92.97574615, 12.06086063], [92.97548676, 12.06097984], [92.97541809, 12.06087971], [92.9753418, 12.06078243], [92.97535706, 12.06041908], [92.97537994, 12.06001091], [92.97528076, 12.05978966], [92.97505951, 12.05964947], [92.974823, 12.0594511], [92.97454071, 12.0592804], [92.97422791, 12.05922699], [92.97386932, 12.0593996], [92.9734726, 12.0595417], [92.97318268, 12.05986118], [92.97307587, 12.06035137], [92.97315216, 12.06090927], [92.97329712, 12.06147385], [92.9733429, 12.06206226], [92.97341919, 12.0626297], [92.97368622, 12.06313133], [92.97399902, 12.06352997], [92.97440338, 12.06387043], [92.97473907, 12.06422138], [92.97499847, 12.06459904], [92.97519684, 12.064991], [92.97524261, 12.06538105], [92.97509003, 12.06571102], [92.97486877, 12.06580925], [92.97457886, 12.06563187], [92.97415161, 12.0652256], [92.97360229, 12.06468964], [92.97305298, 12.06455135], [92.97264862, 12.06483173], [92.97225952, 12.06517982], [92.97196198, 12.06559086], [92.97164154, 12.06602097], [92.97160339, 12.06623077], [92.97114563, 12.06686687], [92.97080994, 12.06707191], [92.97033691, 12.06735039], [92.96981812, 12.06765079], [92.96931458, 12.06787872], [92.9688797, 12.06808186], [92.96845245, 12.06812859], [92.96807861, 12.06812859], [92.96779633, 12.06808186], [92.96695709, 12.06821156], [92.96656799, 12.06827068], [92.96640015, 12.06827068], [92.96595764, 12.06812859], [92.96568298, 12.06804085], [92.96522522, 12.06812668], [92.96411133, 12.06858063], [92.96395111, 12.06902122], [92.96385956, 12.0693903], [92.96369171, 12.0694313], [92.96305847, 12.07137012], [92.9622879, 12.07186985], [92.96182251, 12.07220173], [92.96179962, 12.07281971], [92.96178436, 12.07349873], [92.96177673, 12.07395267], [92.96174622, 12.07433987], [92.96163177, 12.07495117], [92.96163177, 12.07532024], [92.96109009, 12.07620716], [92.96089935, 12.07651043], [92.96092224, 12.076931], [92.96116638, 12.07755089], [92.96117401, 12.07777691], [92.96112823, 12.07828999], [92.96111298, 12.07852173], [92.96070862, 12.07918072], [92.96047974, 12.07962132], [92.9604187, 12.08025742], [92.96050262, 12.08073139], [92.96039581, 12.08091831], [92.960289, 12.08138943], [92.96064758, 12.08264065], [92.96123505, 12.08304596], [92.96167755, 12.08327389], [92.96234894, 12.08390999], [92.9626236, 12.08407879], [92.96312714, 12.0841608], [92.96356201, 12.08437061], [92.96383667, 12.08447075], [92.96486664, 12.08499146], [92.96543121, 12.08520031], [92.96566772, 12.08520031], [92.96589661, 12.08522129], [92.96631622, 12.08525658], [92.96666718, 12.08543873], [92.96694183, 12.08553123], [92.96723938, 12.08561039], [92.96755219, 12.08569241], [92.9679718, 12.08571339], [92.96819305, 12.08573055], [92.96832275, 12.0858202], [92.96847534, 12.08592033], [92.96864319, 12.0860796], [92.96887207, 12.08623028], [92.96914673, 12.08623028], [92.96936035, 12.08615112], [92.96946716, 12.08586979], [92.9699173, 12.08605003], [92.97027588, 12.08631706], [92.9705658, 12.08663082], [92.97077942, 12.08701038], [92.97084808, 12.08745193], [92.97084045, 12.08789635], [92.97077942, 12.08829975], [92.97060394, 12.0886097], [92.97055054, 12.08895206], [92.9704895, 12.08927059], [92.9703598, 12.08953953], [92.97027588, 12.08981991], [92.97016907, 12.09008694], [92.96999359, 12.09029198], [92.96977997, 12.09050369], [92.96950531, 12.09072018], [92.96910858, 12.09080219], [92.96864319, 12.09072018], [92.96816254, 12.09053135], [92.96772003, 12.09027958], [92.96730042, 12.09002972], [92.96684265, 12.0898838], [92.96639252, 12.08974457], [92.96591949, 12.08973789], [92.96544647, 12.08990192], [92.96511841, 12.09041023], [92.96501923, 12.09101009], [92.96507263, 12.09152317], [92.96526337, 12.09188938], [92.96541595, 12.09225178], [92.96549988, 12.09261036], [92.96537018, 12.09296513], [92.96540833, 12.09340286], [92.96556091, 12.09375191], [92.96562195, 12.0941124], [92.96543121, 12.09429169], [92.96515656, 12.09429169], [92.96469879, 12.09412956], [92.96450806, 12.0941124], [92.96411133, 12.09417057], [92.96362305, 12.09417057], [92.96351624, 12.09412956], [92.9628067, 12.09368992], [92.96266174, 12.0934639], [92.96234894, 12.09307194], [92.96190643, 12.09274197], [92.96092224, 12.09309101], [92.96069336, 12.0935297], [92.96060181, 12.09381962], [92.96056366, 12.09420967], [92.96064758, 12.09460163], [92.96082306, 12.09491158], [92.96137238, 12.09504604], [92.96161652, 12.09515095], [92.96187592, 12.0959301], [92.96170044, 12.09651184], [92.96166229, 12.09705639], [92.96166229, 12.09755135], [92.96166992, 12.0980196], [92.96164703, 12.09849739], [92.96156311, 12.09899139], [92.96142578, 12.09949017], [92.96154022, 12.09999943], [92.96173096, 12.10037231], [92.96168518, 12.1009922], [92.96151733, 12.10132122], [92.96112061, 12.10184002], [92.96058655, 12.10185432], [92.96002197, 12.10369968], [92.96017456, 12.10408497], [92.96017456, 12.10433388], [92.96005249, 12.10459995], [92.95983887, 12.1048708], [92.95973206, 12.10555077], [92.95963287, 12.10608768], [92.95960999, 12.10648346], [92.95964813, 12.1068306], [92.95973206, 12.10718536], [92.96062469, 12.1076746], [92.96112823, 12.10790253], [92.96173096, 12.10792255], [92.96221924, 12.10777664], [92.96250153, 12.10750198], [92.96305847, 12.10750198], [92.96333313, 12.10722065], [92.96389008, 12.10722065], [92.9642334, 12.10733509], [92.96460724, 12.10752201], [92.96489716, 12.10789108], [92.9650116, 12.10807991], [92.96515656, 12.10837173], [92.96527863, 12.10867977], [92.96540833, 12.10894871], [92.9655304, 12.10915184], [92.96576691, 12.10931969], [92.96616364, 12.1094017], [92.96639252, 12.10931778], [92.96669769, 12.10915184], [92.96728516, 12.10844135], [92.96769714, 12.10801029], [92.96806335, 12.10757446], [92.96839905, 12.10714817], [92.96869659, 12.10674], [92.96910095, 12.10647964], [92.96929169, 12.10644245], [92.96955872, 12.10644245], [92.96989441, 12.10638046], [92.970047, 12.10601139], [92.970047, 12.10558891], [92.97001648, 12.10505581], [92.9702301, 12.10474396], [92.97038269, 12.10445213], [92.97058868, 12.10420132], [92.97116852, 12.10412598], [92.97138214, 12.10380173], [92.97175598, 12.10361099], [92.97226715, 12.10334015], [92.9727478, 12.10305023], [92.9731369, 12.10271072], [92.97345734, 12.10243034], [92.97374725, 12.10228729], [92.97403717, 12.10230064], [92.9743576, 12.10239601], [92.97476196, 12.1025238], [92.97522736, 12.10264492], [92.9757309, 12.10269928], [92.97621918, 12.10282516], [92.97666931, 12.1030407], [92.97703552, 12.10334396], [92.97720337, 12.10370445], [92.97712708, 12.10400963], [92.97686768, 12.10402107], [92.97648621, 12.10384083], [92.97602081, 12.10361958], [92.97550964, 12.10347652], [92.97489166, 12.10345173], [92.9741745, 12.1036377], [92.97373199, 12.10397339], [92.97355652, 12.10447025], [92.97351074, 12.10471916], [92.97373962, 12.10509014], [92.97387695, 12.10526085], [92.97399902, 12.10534096], [92.97438812, 12.10535908], [92.97470856, 12.10544109], [92.9748764, 12.10555077], [92.9750824, 12.10566902], [92.97525024, 12.10572624], [92.97536469, 12.10576344], [92.97564697, 12.10583973], [92.97589111, 12.1058197], [92.9763031, 12.10567093], [92.97663879, 12.10558891], [92.97711945, 12.10548019], [92.97764587, 12.10558701], [92.97783661, 12.10573101], [92.97801971, 12.10587692], [92.97828674, 12.10604095], [92.97854614, 12.10616589], [92.97885895, 12.10639191], [92.97917938, 12.10652161], [92.97960663, 12.10645962], [92.97988892, 12.10643005], [92.98020172, 12.10641384], [92.98052216, 12.10628891], [92.98117828, 12.10612011], [92.98156738, 12.10619259], [92.98192596, 12.10636425], [92.98233795, 12.10652161], [92.9825058, 12.10673809], [92.98266602, 12.10718918], [92.98288727, 12.1076107], [92.98309326, 12.10800076], [92.98342896, 12.10828972], [92.98391724, 12.10859776], [92.98457336, 12.10877991], [92.98509216, 12.10900974], [92.98562622, 12.1091404], [92.98606873, 12.1091814], [92.98654175, 12.10921955], [92.98678589, 12.10924053], [92.98725128, 12.10924053], [92.98777771, 12.1091404], [92.98796082, 12.10926056], [92.98819733, 12.10934067], [92.9884491, 12.10936069], [92.98859406, 12.10927868], [92.98918152, 12.10890961], [92.98945618, 12.10890961], [92.98969269, 12.10895061], [92.98987579, 12.10903072], [92.99008942, 12.10949135], [92.99027252, 12.1096096], [92.9905777, 12.1096096], [92.99069214, 12.10929966], [92.99085999, 12.10908985], [92.99105072, 12.10898972], [92.99136353, 12.10892773]]], [[[92.96231079, 12.12280083], [92.96212769, 12.12341022], [92.96192932, 12.12392044], [92.96168518, 12.12436295], [92.96147919, 12.12479115], [92.96134949, 12.12524033], [92.96115875, 12.12564564], [92.96109772, 12.12613297], [92.96101379, 12.1266098], [92.96086884, 12.1270504], [92.96082306, 12.12753105], [92.96073151, 12.12801075], [92.96059418, 12.12850571], [92.96055603, 12.12905121], [92.96050262, 12.12961102], [92.960289, 12.13012028], [92.96006012, 12.13064575], [92.95989227, 12.13119125], [92.9596405, 12.13161659], [92.95936584, 12.13195419], [92.95910645, 12.13228035], [92.95886993, 12.13263607], [92.95861053, 12.13297081], [92.95833588, 12.13330078], [92.95805359, 12.13362026], [92.95778656, 12.13395119], [92.95752716, 12.13452053], [92.95728302, 12.13512039], [92.95717621, 12.13549232], [92.95700836, 12.1359272], [92.95694733, 12.13646317], [92.95691681, 12.13677025], [92.95684052, 12.13719177], [92.95661163, 12.13751793], [92.95635986, 12.1380558], [92.9564209, 12.13859081], [92.9565506, 12.13936234], [92.95662689, 12.13975143], [92.9565506, 12.14025021], [92.95620728, 12.14087009], [92.95585632, 12.14134407], [92.95560455, 12.14219189], [92.95565033, 12.14289188], [92.9557724, 12.1438446], [92.95583344, 12.14472198], [92.95582581, 12.14610958], [92.95610809, 12.14638805], [92.95610809, 12.14694405], [92.95639038, 12.14721966], [92.95639038, 12.14750004], [92.95667267, 12.14750004], [92.95675659, 12.14788055], [92.95697784, 12.14814091], [92.95723724, 12.14835739], [92.9575119, 12.14858055], [92.95786285, 12.14877033], [92.95825195, 12.14893246], [92.95865631, 12.14912796], [92.95910645, 12.14927959], [92.95956421, 12.14941692], [92.95995331, 12.14960384], [92.96035004, 12.14976978], [92.96067047, 12.15000534], [92.96098328, 12.15023994], [92.9613266, 12.15044022], [92.96170044, 12.15052891], [92.96209717, 12.15056133], [92.96247864, 12.1505909], [92.962883, 12.15069103], [92.96330261, 12.15078545], [92.96376038, 12.1506958], [92.96429443, 12.15057278], [92.96490479, 12.15047741], [92.96547699, 12.15027046], [92.96601868, 12.15000057], [92.96649933, 12.14972019], [92.9669342, 12.14949226], [92.96737671, 12.14940262], [92.96775055, 12.1492281], [92.96816254, 12.14917088], [92.96859741, 12.1491642], [92.96904755, 12.14914131], [92.96946716, 12.14901066], [92.9699173, 12.14888191], [92.97038269, 12.14877415], [92.97086334, 12.14860058], [92.97135925, 12.14840126], [92.97192383, 12.14834118], [92.97249603, 12.14832973], [92.97306061, 12.14833164], [92.97357178, 12.14831161], [92.97400665, 12.14820004], [92.97441101, 12.14808178], [92.97483826, 12.1480608], [92.97531128, 12.14805031], [92.97585297, 12.14805031], [92.9764328, 12.14806557], [92.97698212, 12.14813232], [92.97744751, 12.14828682], [92.97770691, 12.14831161], [92.97789001, 12.14825153], [92.97814941, 12.1480341], [92.97837067, 12.14781857], [92.97860718, 12.14781857], [92.97890472, 12.14811802], [92.97929382, 12.14847374], [92.97966766, 12.1485424], [92.9800415, 12.14838219], [92.98045349, 12.14833546], [92.98083496, 12.14830303], [92.98090363, 12.14824963], [92.98108673, 12.14811134], [92.98136139, 12.14822292], [92.98150635, 12.14845276], [92.98194122, 12.14895439], [92.98213196, 12.1489954], [92.9824295, 12.1490593], [92.98329163, 12.14899063], [92.98397827, 12.14871979], [92.98443604, 12.14834118], [92.98498535, 12.14814091], [92.98539734, 12.14777184], [92.98583221, 12.14742088], [92.9862442, 12.14708138], [92.9866333, 12.1467104], [92.98699188, 12.14634037], [92.98737335, 12.14598179], [92.98771667, 12.14560032], [92.98805237, 12.14518929], [92.98838806, 12.14479733], [92.98873901, 12.14446926], [92.98911285, 12.14424992], [92.98948669, 12.14417267], [92.98986816, 12.14416599], [92.99025726, 12.14417267], [92.99069214, 12.14415932], [92.9911499, 12.14409065], [92.99154663, 12.14390182], [92.99192047, 12.14368057], [92.99220276, 12.14339256], [92.99241638, 12.14304543], [92.99259949, 12.14269066], [92.99278259, 12.14237022], [92.99292755, 12.14206028], [92.99304962, 12.1417141], [92.99315643, 12.14129734], [92.99330139, 12.14083195], [92.99333191, 12.14027977], [92.99328613, 12.13972378], [92.99308014, 12.13923645], [92.99291229, 12.13875103], [92.99279785, 12.13828754], [92.99278259, 12.13781166], [92.99278259, 12.13733959], [92.99277496, 12.13690186], [92.99278259, 12.13648319], [92.99284363, 12.13607502], [92.99304962, 12.13570976], [92.9932785, 12.1352911], [92.99359131, 12.13487911], [92.99391937, 12.13444138], [92.99427032, 12.13404179], [92.99450684, 12.13354969], [92.99474335, 12.13305092], [92.99494171, 12.13257885], [92.99495697, 12.13208389], [92.99481964, 12.13159943], [92.99474335, 12.13111115], [92.99476624, 12.13062954], [92.99494934, 12.13017178], [92.99508667, 12.12966156], [92.99529266, 12.12917233], [92.99555206, 12.12871838], [92.99555206, 12.12861061], [92.99583435, 12.12833309], [92.99583435, 12.12805462], [92.9963913, 12.12750053], [92.9963913, 12.12722111], [92.99666595, 12.12694454], [92.99666595, 12.12666702], [92.99694824, 12.12639141], [92.99694824, 12.12611103], [92.99777985, 12.12528133], [92.99777985, 12.12500095], [92.99887848, 12.12389088], [92.99887848, 12.12360954], [92.99945068, 12.12275791], [92.99973297, 12.12250137], [93.0, 12.1227808], [93.00026703, 12.12250137], [93.00026703, 12.12222004], [93.00027466, 12.12194443], [93.0008316, 12.12138844], [93.0008316, 12.12056065], [93.00110626, 12.12028122], [93.00110626, 12.11777973], [93.00164795, 12.11721992], [93.00250244, 12.11722183], [93.00305176, 12.11666584], [93.00305176, 12.11610985], [93.00333405, 12.11583424], [93.00332642, 12.11388969], [93.00389099, 12.11333179], [93.00416565, 12.1133337], [93.00428772, 12.11346054], [93.00465393, 12.11345673], [93.0046463, 12.11373043], [93.00492859, 12.11392879], [93.00492859, 12.11432076], [93.0052948, 12.11451912], [93.00528717, 12.11483097], [93.0056076, 12.11515045], [93.00537109, 12.11530495], [93.00556946, 12.11562157], [93.00556946, 12.11601353], [93.00521088, 12.11617088], [93.00521088, 12.11644745], [93.00553131, 12.11672115], [93.0052948, 12.11703682], [93.00528717, 12.11810017], [93.00497437, 12.11845493], [93.00497437, 12.11916447], [93.00476837, 12.11927986], [93.00481415, 12.11959743], [93.00440979, 12.11991119], [93.00444794, 12.12038136], [93.00413513, 12.12069988], [93.00414276, 12.12176037], [93.00389099, 12.12203979], [93.00389099, 12.12270641], [93.0036087, 12.12290192], [93.0036087, 12.12333679], [93.00341034, 12.12356853], [93.00337219, 12.12432194], [93.00292969, 12.12443829], [93.0027771, 12.12444019], [93.0027771, 12.12555695], [93.0027771, 12.12925053], [93.00254059, 12.12936974], [93.00250244, 12.1297226], [93.00245667, 12.13094044], [93.00229645, 12.13121796], [93.00229645, 12.13184738], [93.00197601, 12.13212109], [93.00193787, 12.13390064], [93.00254059, 12.13453197], [93.00254059, 12.13511562], [93.0027771, 12.13527107], [93.0027771, 12.13601971], [93.0027771, 12.13645554], [93.0027771, 12.13694572], [93.00332642, 12.13749981], [93.00332642, 12.13778019], [93.0036087, 12.1380558], [93.0036087, 12.13833141], [93.00389099, 12.13861179], [93.00409698, 12.13862133], [93.00409698, 12.13936806], [93.00417328, 12.13944054], [93.00444794, 12.13972569], [93.0047226, 12.14001083], [93.00492096, 12.14000034], [93.00495911, 12.14043045], [93.00520325, 12.14066982], [93.00520325, 12.14098358], [93.00556183, 12.14114189], [93.00552368, 12.14192772], [93.00588226, 12.14232159], [93.00588226, 12.14303112], [93.00604248, 12.14320183], [93.00608063, 12.14400005], [93.00659943, 12.14498425], [93.00668335, 12.1455307], [93.00668335, 12.14605141], [93.007164, 12.14671612], [93.0078125, 12.14747143], [93.0078125, 12.14783096], [93.00829315, 12.14799023], [93.00858307, 12.14831161], [93.00857544, 12.14865589], [93.00860596, 12.14888191], [93.01000214, 12.15028095], [93.01000214, 12.15055656], [93.01043701, 12.15098953], [93.0110321, 12.15111065], [93.01119232, 12.1514616], [93.01239777, 12.15174007], [93.01275635, 12.15213203], [93.01280975, 12.15219784], [93.01304626, 12.15250111], [93.01333618, 12.15250111], [93.01361084, 12.15278053], [93.01387787, 12.15278053], [93.01416779, 12.15306091], [93.01444244, 12.15305519], [93.01472473, 12.15333271], [93.01499939, 12.15333271], [93.01527405, 12.15361118], [93.01555634, 12.15361118], [93.01564789, 12.15370369], [93.01583099, 12.15389061], [93.01611328, 12.15389061], [93.01638794, 12.15417099], [93.01667023, 12.15416718], [93.01721954, 12.15472317], [93.01750183, 12.15472126], [93.01805878, 12.15528107], [93.01832581, 12.15528107], [93.01944733, 12.15639114], [93.01972198, 12.15638924], [93.02027893, 12.15694523], [93.02054596, 12.15694141], [93.02076721, 12.15716171], [93.02113342, 12.15716171], [93.02113342, 12.15759468], [93.02185059, 12.15830135], [93.02188873, 12.15881443], [93.02213287, 12.15889072], [93.02217102, 12.15928555], [93.02249146, 12.1594429], [93.02245331, 12.16038036], [93.02272797, 12.1605854], [93.02272797, 12.16192341], [93.02278137, 12.16222095], [93.02278137, 12.16277695], [93.02333069, 12.16333389], [93.02333069, 12.16361237], [93.02500153, 12.16527843], [93.02561951, 12.16549015], [93.02613831, 12.16576958], [93.02654266, 12.16581059], [93.02713013, 12.16631889], [93.0273819, 12.16648102], [93.02749634, 12.16666985], [93.0283432, 12.16583061], [93.02833557, 12.16555595], [93.02944183, 12.16444111], [93.02944183, 12.16416454], [93.02971649, 12.16389179], [93.02944183, 12.16361237], [93.02944183, 12.16333389], [93.02916718, 12.16305542], [93.02916718, 12.16249943], [93.02889252, 12.16222095], [93.02889252, 12.16166687], [93.02861023, 12.16138935], [93.02861023, 12.16111088], [93.0283432, 12.16082191], [93.02833557, 12.16027737], [93.02805328, 12.15999889], [93.02805328, 12.15944099], [93.02833557, 12.15916729], [93.0283432, 12.15804958], [93.02805328, 12.15777683], [93.02805328, 12.15722084], [93.02777863, 12.15694141], [93.02777863, 12.15638924], [93.02749634, 12.15610886], [93.02749634, 12.15527916], [93.02722168, 12.15501022], [93.02722168, 12.15195179], [93.02749634, 12.15167141], [93.02749634, 12.15056133], [93.02722168, 12.15028095], [93.02722168, 12.14888191], [93.02694702, 12.14861012], [93.02694702, 12.14778137], [93.02722168, 12.14750004], [93.02722168, 12.14694023], [93.02749634, 12.14666557], [93.02749634, 12.14610958], [93.02777863, 12.14583206], [93.02777863, 12.14555645], [93.0283432, 12.14500046], [93.02833557, 12.14444447], [93.02861023, 12.14416599], [93.02861023, 12.14361], [93.0283432, 12.14332962], [93.02833557, 12.14305592], [93.02778625, 12.14251995], [93.02758026, 12.14254093], [93.02752686, 12.14239693], [93.02749634, 12.14230156], [93.02685547, 12.1421442], [93.02688599, 12.14188004], [93.02610779, 12.14111233], [93.02610779, 12.13889027], [93.02639008, 12.13861179], [93.02639008, 12.13833141], [93.02722168, 12.13749981], [93.02749634, 12.13749981], [93.02777863, 12.13722134], [93.02805328, 12.13722134], [93.02805328, 12.13694572], [93.02916718, 12.13583279], [93.02944183, 12.13583279], [93.03055573, 12.1347208], [93.03055573, 12.1338892], [93.03083038, 12.13361073], [93.03083038, 12.13306046], [93.03111267, 12.13278198], [93.03111267, 12.13194084], [93.03138733, 12.13166714], [93.03138733, 12.13111115], [93.03166962, 12.13083267], [93.03166962, 12.13028145], [93.0319519, 12.13000107], [93.0319519, 12.12972069], [93.03221893, 12.12944508], [93.03221893, 12.1291666], [93.03250122, 12.12889099], [93.03250122, 12.12861061], [93.03277588, 12.12833309], [93.03277588, 12.12805462], [93.03305817, 12.12778091], [93.03305817, 12.12722111], [93.03333282, 12.12694454], [93.03360748, 12.12694454], [93.03388977, 12.12666702], [93.0341568, 12.12667084], [93.03501129, 12.1258297], [93.03500366, 12.12555695], [93.03527832, 12.12528133], [93.03527832, 12.12389088], [93.03388977, 12.12250137], [93.03388977, 12.12222004], [93.03360748, 12.12194443], [93.03360748, 12.12138844], [93.03333282, 12.12110996], [93.03333282, 12.12028122], [93.03305817, 12.12000275], [93.03305817, 12.11944199], [93.03221893, 12.11861229], [93.03221893, 12.11833191], [93.03194427, 12.1180563], [93.0319519, 12.11639023], [93.03166962, 12.11610985], [93.03194427, 12.11583424], [93.0319519, 12.11528015], [93.03221893, 12.11499977], [93.03221893, 12.11472034], [93.03194427, 12.11444378], [93.03194427, 12.11388779], [93.03166962, 12.11361027], [93.03166962, 12.11250019], [93.0319519, 12.11221886], [93.03194427, 12.11139011], [93.03166962, 12.11111164], [93.03166962, 12.11028194], [93.0319519, 12.11000156], [93.0319519, 12.1094389], [93.03221893, 12.10916805], [93.03221893, 12.1086092], [93.03250122, 12.10833263], [93.03250122, 12.10805511], [93.03277588, 12.10778046], [93.03277588, 12.10722065], [93.03305817, 12.10694313], [93.03305817, 12.10666656], [93.03333282, 12.10639191], [93.03333282, 12.10583115], [93.03360748, 12.10555458], [93.03360748, 12.10528183], [93.03388977, 12.10500145], [93.03388977, 12.10472107], [93.03416443, 12.10444546], [93.03416443, 12.10416698], [93.03472137, 12.10361099], [93.03472137, 12.10333061], [93.03527832, 12.10277653], [93.03501129, 12.10250092], [93.03501129, 12.10194016], [93.03472137, 12.1016674], [93.03472137, 12.10083961], [93.03444672, 12.10055923], [93.03444672, 12.10028076], [93.03472137, 12.10000134], [93.03472137, 12.09943962], [93.03500366, 12.09916687], [93.03501129, 12.09861088], [93.03555298, 12.09805679], [93.03555298, 12.09776974], [93.03833008, 12.09500027], [93.03833008, 12.0947113], [93.03888702, 12.0941658], [93.03888702, 12.09389114], [93.03916931, 12.09361172], [93.03916931, 12.09333038], [93.03944397, 12.09305573], [93.03943634, 12.09278107], [93.04083252, 12.09138966], [93.04083252, 12.09111023], [93.04111481, 12.09083366], [93.04111481, 12.09055614], [93.04138947, 12.09027958], [93.04138947, 12.09000015], [93.04165649, 12.08972168], [93.04166412, 12.08916569], [93.04222107, 12.0886097], [93.04222107, 12.08832932], [93.04333496, 12.0872221], [93.04360962, 12.0872221], [93.04389191, 12.08694363], [93.04416656, 12.08694363], [93.04416656, 12.08666801], [93.04499817, 12.08583164], [93.04499817, 12.08555603], [93.04638672, 12.08417034], [93.04666901, 12.08417034], [93.04695129, 12.08389187], [93.0477829, 12.08389187], [93.04805756, 12.08361244], [93.04888916, 12.08361244], [93.04944611, 12.08305645], [93.04944611, 12.0827713], [93.05000305, 12.08222103], [93.05000305, 12.08138943], [93.05027771, 12.08111095], [93.05027771, 12.08055973], [93.05110931, 12.07973003], [93.05110931, 12.07944107], [93.0513916, 12.07916737], [93.0513916, 12.07861137], [93.0533371, 12.07666683], [93.0533371, 12.07639122], [93.05361176, 12.07611084], [93.05361176, 12.07555866], [93.05278015, 12.07472134], [93.05222321, 12.07472324], [93.05194092, 12.07444477], [93.05166626, 12.07444477], [93.0513916, 12.07416725], [93.0513916, 12.07359886], [93.05110931, 12.07333279], [93.05110931, 12.07250118], [93.05166626, 12.07194042], [93.05166626, 12.0713892], [93.05278015, 12.07028103], [93.05278015, 12.06972027], [93.05305481, 12.06944466], [93.05305481, 12.06833458], [93.05278015, 12.0680542], [93.05278015, 12.06694031], [93.05305481, 12.06666565], [93.05304718, 12.06556129], [93.05278015, 12.06528091], [93.05278015, 12.06499958], [93.05249786, 12.06473064], [93.05249786, 12.06444168], [93.05222321, 12.06416607], [93.05222321, 12.06306076], [93.05249786, 12.06278038], [93.05249786, 12.0625], [93.05304718, 12.06193924], [93.05305481, 12.06166553], [93.0533371, 12.06138992], [93.0533371, 12.06056023], [93.05304718, 12.06027985], [93.05304718, 12.06000042], [93.05249786, 12.05944061], [93.05249786, 12.05916786], [93.05166626, 12.05833054], [93.05166626, 12.05805588], [93.0513916, 12.05778027], [93.0513916, 12.05722237], [93.05166626, 12.0569458], [93.05166626, 12.05666542], [93.05194092, 12.05638981], [93.05194092, 12.05610943], [93.05166626, 12.05583382], [93.05166626, 12.05555534], [93.0513916, 12.05527973], [93.0513916, 12.05499935], [93.05110931, 12.05472088], [93.05110931, 12.05444336], [93.05083466, 12.05416679], [93.05082703, 12.05360889], [93.05027771, 12.05305481], [93.05027771, 12.05279064], [93.04998779, 12.05250072], [93.04998779, 12.0522213], [93.04972076, 12.05194473], [93.04972076, 12.05111122], [93.04944611, 12.05083275], [93.04895782, 12.05001545], [93.04823303, 12.04891396], [93.04763794, 12.04824448], [93.04711914, 12.04792881], [93.04675293, 12.04789066], [93.04654694, 12.04738045], [93.04555511, 12.04638863], [93.04556274, 12.04582977], [93.0455246, 12.0453701], [93.04453278, 12.0453701], [93.0443573, 12.04553032], [93.04360962, 12.04560661], [93.04332733, 12.04580307], [93.04272461, 12.04572582], [93.04212952, 12.04577065], [93.04155731, 12.04572105], [93.04113007, 12.04607868], [93.04077148, 12.04655075], [93.04036713, 12.04761505], [93.04024506, 12.04828262], [93.04000092, 12.04833126], [93.03971863, 12.04861069], [93.03971863, 12.04916668], [93.03943634, 12.04971886], [93.03916931, 12.05000114], [93.03916931, 12.05027676], [93.03861237, 12.05083275], [93.03861237, 12.05111122], [93.03833008, 12.05139065], [93.03833008, 12.05166721], [93.03805542, 12.05194473], [93.03804779, 12.0522213], [93.03778076, 12.05250072], [93.03778076, 12.05277729], [93.03722382, 12.05333328], [93.03721619, 12.05360889], [93.03666687, 12.05416679], [93.03666687, 12.05444336], [93.03639221, 12.05472088], [93.03639221, 12.05499935], [93.03610992, 12.05527973], [93.03610992, 12.05555534], [93.03555298, 12.05610943], [93.03555298, 12.05778027], [93.03527832, 12.05805588], [93.03527832, 12.05860043], [93.03501129, 12.05889034], [93.03500366, 12.05916786], [93.03472137, 12.05944061], [93.03472137, 12.06000042], [93.03444672, 12.06027985], [93.03444672, 12.06055641], [93.03388977, 12.06110954], [93.03388977, 12.06138992], [93.03305817, 12.06222153], [93.03277588, 12.06222153], [93.02916718, 12.06583214], [93.02916718, 12.06610966], [93.02861023, 12.06666565], [93.02861023, 12.06694031], [93.02749634, 12.06806087], [93.02722168, 12.0680542], [93.02666473, 12.06861019], [93.02639008, 12.06861019], [93.02500153, 12.07000065], [93.02471924, 12.07000065], [93.02443695, 12.07028103], [93.02416992, 12.07028103], [93.02388763, 12.07056141], [93.02305603, 12.07055664], [93.02278137, 12.07083321], [93.02249908, 12.07083035], [93.0222168, 12.07111073], [93.02194214, 12.07111073], [93.02166748, 12.07139111], [93.02139282, 12.07139111], [93.02111053, 12.07167053], [93.02083588, 12.07166672], [93.02055359, 12.07194519], [93.01999664, 12.07194519], [93.01972198, 12.07222271], [93.01860809, 12.07222271], [93.01833344, 12.07194519], [93.01777649, 12.07194519], [93.01750183, 12.07222271], [93.01526642, 12.0722208], [93.01499939, 12.07250118], [93.01304626, 12.07250118], [93.01277924, 12.0722208], [93.01249695, 12.07222271], [93.01222229, 12.07194519], [93.01194763, 12.07194519], [93.01166534, 12.07166672], [93.01139069, 12.07167053], [93.0111084, 12.0713892], [93.01055908, 12.07194519], [93.01045227, 12.07238007], [93.00997925, 12.07254887], [93.00954437, 12.07286263], [93.00905609, 12.07357025], [93.00862122, 12.0740509], [93.00814056, 12.0745163], [93.00778198, 12.07475281], [93.00746155, 12.07530022], [93.00701904, 12.0757761], [93.00694275, 12.07608986], [93.00694275, 12.0769453], [93.00666809, 12.07722092], [93.00666809, 12.07805538], [93.0063858, 12.07833099], [93.0063858, 12.07888889], [93.00611115, 12.07916737], [93.00611115, 12.08333397], [93.0063858, 12.08361244], [93.0063858, 12.08444405], [93.00666809, 12.08472157], [93.00666809, 12.08666801], [93.00694275, 12.08694363], [93.00723267, 12.08718967], [93.00722504, 12.08974934], [93.00694275, 12.09010315], [93.0069809, 12.09139919], [93.00694275, 12.09195995], [93.00694275, 12.09361172], [93.00722504, 12.09388828], [93.00722504, 12.09444427], [93.00749969, 12.0947113], [93.00749969, 12.09500027], [93.00777435, 12.09527874], [93.00777435, 12.09583473], [93.0080719, 12.09611034], [93.00805664, 12.09666729], [93.0083313, 12.09694481], [93.0083313, 12.09832954], [93.00860596, 12.09861088], [93.00860596, 12.09995079], [93.00901031, 12.09995079], [93.00888824, 12.1012907], [93.00860596, 12.1012907], [93.00860596, 12.10166931], [93.00868988, 12.101861], [93.00863647, 12.10296059], [93.0083313, 12.10296059], [93.0083313, 12.10361099], [93.00830078, 12.10384083], [93.00830078, 12.10467052], [93.0080719, 12.10475063], [93.0080719, 12.10526085], [93.00773621, 12.10542107], [93.00773621, 12.10584927], [93.00749969, 12.10592747], [93.00737762, 12.10628223], [93.00721741, 12.10632133], [93.00726318, 12.10723019], [93.0069809, 12.10726738], [93.0069809, 12.10750198], [93.00669861, 12.10758114], [93.00669861, 12.10778046], [93.00610352, 12.10773945], [93.00610352, 12.10805321], [93.0044632, 12.10809231], [93.00430298, 12.10778046], [93.00354004, 12.10770035], [93.00354004, 12.10718918], [93.0032959, 12.10718918], [93.00305176, 12.10694122], [93.00166321, 12.10694313], [93.0014267, 12.1069088], [93.00111389, 12.10694313], [93.0008316, 12.10694313], [93.00055695, 12.10722256], [93.00055695, 12.1086092], [93.0008316, 12.10888958], [93.0008316, 12.1093502], [93.00086212, 12.10955048], [93.00066376, 12.10958862], [93.00066376, 12.11006069], [93.00093842, 12.11006069], [93.00093842, 12.11033726], [93.00065613, 12.11053085], [93.00063324, 12.11081123], [93.00042725, 12.11129856], [93.00026703, 12.11166954], [93.0, 12.11139202], [92.99968719, 12.11137199], [92.99944305, 12.1118412], [92.99919891, 12.11198044], [92.99894714, 12.11221886], [92.99865723, 12.11244011], [92.99846649, 12.11256123], [92.99830627, 12.11278152], [92.99810028, 12.11300087], [92.99716187, 12.11357975], [92.99680328, 12.11361027], [92.99658966, 12.11358738], [92.99638367, 12.11356354], [92.99602509, 12.11334991], [92.99565887, 12.11316967], [92.99526215, 12.1130724], [92.99485016, 12.11306], [92.9944458, 12.11310101], [92.9940567, 12.11329079], [92.99359131, 12.11333179], [92.99305725, 12.11329079], [92.99259949, 12.11306], [92.991539, 12.11303139], [92.9912262, 12.11294937], [92.99061584, 12.11270046], [92.99002838, 12.11288738], [92.98918915, 12.11301231], [92.98805237, 12.11305428], [92.98686218, 12.11311531], [92.98584747, 12.11307621], [92.985466, 12.11302185], [92.98517609, 12.1129303], [92.98456573, 12.11268425], [92.98429108, 12.1125412], [92.9838562, 12.11220074], [92.98297882, 12.11192989], [92.98243713, 12.11180878], [92.98197174, 12.11173153], [92.9815979, 12.11173153], [92.98073578, 12.11176968], [92.98052216, 12.11189079], [92.98031616, 12.11218071], [92.9801712, 12.1125927], [92.97980499, 12.11296463], [92.97968292, 12.11308956], [92.97933197, 12.11299038], [92.97881317, 12.1129303], [92.97796631, 12.11294365], [92.97705841, 12.11323071], [92.97670746, 12.11327457], [92.97628784, 12.11354065], [92.97607422, 12.11379242], [92.9759903, 12.11410236], [92.97612, 12.11476326], [92.97625732, 12.11509132], [92.97646332, 12.11557198], [92.97646332, 12.11606026], [92.97637177, 12.11631012], [92.97619629, 12.11658764], [92.97600555, 12.11691189], [92.97575378, 12.11720371], [92.97544098, 12.11744118], [92.97502136, 12.11760044], [92.97453308, 12.11777973], [92.97397614, 12.11795139], [92.9733963, 12.11800194], [92.97286224, 12.11780071], [92.97233582, 12.11763], [92.97181702, 12.11750031], [92.97130585, 12.11740017], [92.97083282, 12.11729717], [92.97036743, 12.11744976], [92.96984863, 12.11750031], [92.96930695, 12.1175499], [92.96881866, 12.11777115], [92.96826935, 12.11798954], [92.96765137, 12.1182003], [92.96703339, 12.11852074], [92.966362, 12.11889935], [92.96570587, 12.11935139], [92.96521759, 12.11993599], [92.96472931, 12.12043953], [92.96427155, 12.12090111], [92.96382904, 12.1213789], [92.96331787, 12.12181854], [92.9627533, 12.12226963], [92.96231079, 12.12280083]]], [[[93.08309174, 12.19578171], [93.08354187, 12.19572926], [93.08364868, 12.19525146], [93.08403015, 12.194911], [93.08441925, 12.194911], [93.08448792, 12.19522095], [93.08545685, 12.19522095], [93.08545685, 12.19384193], [93.08574677, 12.19380093], [93.08574677, 12.19304657], [93.08661652, 12.19305134], [93.08664703, 12.19270039], [93.08602905, 12.19274139], [93.08605957, 12.19229031], [93.0858078, 12.19207954], [93.08550262, 12.19194412], [93.08554077, 12.18946362], [93.08588409, 12.18943024], [93.08584595, 12.18787956], [93.08554077, 12.18787956], [93.08554077, 12.18691063], [93.08596039, 12.18691254], [93.08609772, 12.18656921], [93.08629608, 12.18650055], [93.08630371, 12.18543434], [93.08683014, 12.18536091], [93.08753204, 12.18470955], [93.08757019, 12.18436527], [93.08798981, 12.1843996], [93.08798981, 12.18302059], [93.08833313, 12.18298912], [93.08830261, 12.18271065], [93.08753204, 12.18216133], [93.08718109, 12.18216133], [93.08714294, 12.18195629], [93.0868988, 12.18192005], [93.08686829, 12.18161201], [93.086586, 12.18157959], [93.086586, 12.18075085], [93.08634186, 12.18075085], [93.08634186, 12.18030167], [93.08693695, 12.18013096], [93.08703613, 12.18033123], [93.08721924, 12.18041134], [93.08718109, 12.18103123], [93.08772278, 12.18107033], [93.08773804, 12.18020058], [93.08805847, 12.18020058], [93.08812714, 12.17989063], [93.08826447, 12.17995834], [93.08830261, 12.18054295], [93.08861542, 12.18054295], [93.08861542, 12.18016529], [93.08903503, 12.18019867], [93.08903503, 12.18054295], [93.08938599, 12.18054295], [93.08938599, 12.180336], [93.08969879, 12.180336], [93.08969879, 12.17995834], [93.08938599, 12.17992115], [93.08938599, 12.17971611], [93.08973694, 12.17968178], [93.08973694, 12.17944241], [93.08938599, 12.17940617], [93.08938599, 12.1791296], [93.08966827, 12.17913246], [93.08969879, 12.17889118], [93.08931732, 12.17881966], [93.08934784, 12.17778778], [93.08969879, 12.17768097], [93.08969879, 12.17720222], [93.08934784, 12.17724133], [93.08931732, 12.17682076], [93.08998108, 12.17685986], [93.08998108, 12.17445087], [93.08973694, 12.17445087], [93.08969879, 12.17366028], [93.08938599, 12.17361927], [93.08938599, 12.17306995], [93.08973694, 12.17304039], [93.08973694, 12.17276001], [93.08934784, 12.17268944], [93.08934784, 12.17251778], [93.08966827, 12.17252064], [93.08973694, 12.17190075], [93.0894165, 12.17185974], [93.08942413, 12.17076111], [93.0891037, 12.17076111], [93.08917236, 12.16914272], [93.08885956, 12.16921139], [93.08885956, 12.16835213], [93.08850861, 12.16835213], [93.08854675, 12.16749096], [93.08830261, 12.16742039], [93.08830261, 12.16697311], [93.08805847, 12.1669054], [93.08808899, 12.16583824], [93.08777618, 12.1658411], [93.08777618, 12.16462994], [93.08746338, 12.1646328], [93.0874939, 12.16404724], [93.08721924, 12.16408062], [93.08718109, 12.1644249], [93.08686829, 12.16445923], [93.08683014, 12.16414928], [93.08630371, 12.16418362], [93.08630371, 12.16387367], [93.08602905, 12.16387367], [93.08602905, 12.16325378], [93.0858078, 12.16329002], [93.08584595, 12.16222095], [93.08550262, 12.16222095], [93.08554077, 12.16084003], [93.08522034, 12.16080761], [93.08525848, 12.16004944], [93.08494568, 12.1599474], [93.08490753, 12.15915966], [93.08466339, 12.15912247], [93.08459473, 12.15832901], [93.08495331, 12.15828991], [93.0849762, 12.15750122], [93.08522034, 12.15750122], [93.08515167, 12.156847], [93.08483887, 12.15688133], [93.0845871, 12.15734196], [93.08413696, 12.15734196], [93.08418274, 12.15603065], [93.08444977, 12.15603065], [93.08441925, 12.15582085], [93.08381653, 12.15585136], [93.08381653, 12.15554142], [93.08399963, 12.15551186], [93.08403015, 12.15526104], [93.08435059, 12.15520191], [93.08441925, 12.15551186], [93.0845871, 12.15551186], [93.08468628, 12.15530014], [93.08495331, 12.15530014], [93.08500671, 12.1549902], [93.08473206, 12.1549511], [93.08469391, 12.15474796], [93.0849762, 12.15468025], [93.08512115, 12.15406036], [93.08557129, 12.15358067], [93.08605957, 12.15361118], [93.08605957, 12.15343761], [93.08587646, 12.15322971], [93.08588409, 12.15299129], [93.08609772, 12.15278339], [93.08609772, 12.15250778], [93.08574677, 12.15244198], [93.08577728, 12.1518507], [93.08605957, 12.15181923], [93.08609772, 12.15161037], [93.08679962, 12.15161419], [93.0869751, 12.15126991], [93.0874939, 12.15130424], [93.08753204, 12.15149975], [93.08822632, 12.15219975], [93.08837128, 12.15244198], [93.08889771, 12.15244198], [93.08899689, 12.15216064], [93.08931732, 12.15164757], [93.08994293, 12.15165997], [93.08994293, 12.15126991], [93.09050751, 12.15126991], [93.09046936, 12.15157986], [93.09075165, 12.15161419], [93.09076691, 12.15140724], [93.09078217, 12.15126991], [93.09113312, 12.15126991], [93.09113312, 12.1510601], [93.0907135, 12.15106297], [93.09075165, 12.15020084], [93.09099579, 12.15020084], [93.09148407, 12.14968395], [93.09179688, 12.14968395], [93.0920105, 12.14941025], [93.09243011, 12.14941025], [93.09246063, 12.14886093], [93.09348297, 12.14871979], [93.09355164, 12.14831161], [93.09403992, 12.14838028], [93.09410858, 12.14778996], [93.09442139, 12.14769173], [93.09442139, 12.14719963], [93.09407043, 12.1472044], [93.09407043, 12.14658356], [93.09442139, 12.14655018], [93.09442139, 12.14576054], [93.09470367, 12.14579296], [93.09474182, 12.14527607], [93.09435272, 12.14538097], [93.09449005, 12.14335918], [93.09468842, 12.14331055], [93.09463501, 12.14241791], [93.09500122, 12.14242172], [93.09494781, 12.14200115], [93.09417725, 12.14128113], [93.09414673, 12.1403513], [93.09355164, 12.13986969], [93.09355164, 12.13862991], [93.09306335, 12.1382494], [93.09302521, 12.13756084], [93.09278107, 12.13749313], [93.09274292, 12.13680363], [93.09223175, 12.13617992], [93.09221649, 12.13580608], [93.0916214, 12.13584042], [93.0916214, 12.1352911], [93.091362, 12.13521957], [93.09130859, 12.13498116], [93.09082031, 12.13501263], [93.09043884, 12.13432503], [93.08998108, 12.13436127], [93.08998108, 12.13364124], [93.08966827, 12.13350201], [93.08969879, 12.13307953], [93.08938599, 12.13301563], [93.08934784, 12.13276958], [93.08966827, 12.13274097], [93.08963013, 12.13250065], [93.08909607, 12.13243961], [93.08914185, 12.13173962], [93.08885956, 12.13171101], [93.08889771, 12.13085079], [93.08864594, 12.13080978], [93.08772278, 12.12998104], [93.08781433, 12.12960529], [93.08830261, 12.12926006], [93.08822632, 12.12881088], [93.08882904, 12.12881374], [93.08892822, 12.12853813], [93.0894165, 12.12851143], [93.08944702, 12.12825966], [93.08969879, 12.12822819], [93.08969879, 12.12750053], [93.08994293, 12.12743473], [93.08994293, 12.12718201], [93.08969879, 12.12712479], [93.08969879, 12.12585068], [93.08934784, 12.1258173], [93.08938599, 12.12492085], [93.08921051, 12.12496185], [93.08825684, 12.12389088], [93.0878067, 12.12385178], [93.08753204, 12.12364674], [93.08766937, 12.12306118], [93.08795166, 12.12306118], [93.08805847, 12.1232338], [93.08896637, 12.12330341], [93.08892822, 12.12354374], [93.09123993, 12.12351036], [93.09123993, 12.12330055], [93.09236145, 12.12330341], [93.09302521, 12.12268257], [93.09302521, 12.12120056], [93.09278107, 12.12099648], [93.09187317, 12.12020969], [93.09189606, 12.11917114], [93.09159088, 12.11914063], [93.0916214, 12.11878967], [93.09243011, 12.11883068], [93.09243011, 12.11841202], [93.09221649, 12.11834335], [93.09225464, 12.11779213], [93.09246063, 12.11758709], [93.09256744, 12.11697102], [93.09218597, 12.11693001], [93.09207916, 12.11662292], [93.09190369, 12.11658573], [93.09189606, 12.11631012], [93.09142303, 12.11634922], [93.09123993, 12.11659145], [93.09078217, 12.11659145], [93.09075165, 12.11584091], [93.08991241, 12.11584091], [93.08983612, 12.11524105], [93.09018707, 12.11524391], [93.09026337, 12.11469173], [93.09050751, 12.11469173], [93.09050751, 12.11414146], [93.09068298, 12.11410618], [93.09075165, 12.11383057], [93.09095764, 12.11379719], [93.0911026, 12.11358929], [93.09147644, 12.11363029], [93.09158325, 12.11340427], [93.0916214, 12.11331558], [93.09223175, 12.11325169], [93.09224701, 12.11275864], [93.09302521, 12.11276436], [93.09305573, 12.11252213], [93.0932312, 12.11252213], [93.0932312, 12.11228085], [93.09278107, 12.11193657], [93.09278107, 12.11163139], [93.0933075, 12.11166096], [93.0933075, 12.11111164], [93.09303284, 12.11108017], [93.09306335, 12.11077023], [93.0933075, 12.11077023], [93.0933075, 12.11053085], [93.09249878, 12.11056042], [93.09223175, 12.11101055], [93.09204102, 12.11111164], [93.09179688, 12.11094093], [93.09179688, 12.11049175], [93.09214783, 12.11039066], [93.09214783, 12.10953045], [93.09187317, 12.10949135], [93.09187317, 12.10921764], [93.09218597, 12.10921955], [93.09218597, 12.10894203], [93.09183502, 12.10894203], [93.09187317, 12.10863209], [93.09211731, 12.10842514], [93.09218597, 12.10766792], [93.09187317, 12.10766983], [93.09187317, 12.10738087], [93.09214783, 12.10739231], [93.09221649, 12.1069088], [93.09187317, 12.10694122], [93.09184265, 12.10722065], [93.09159088, 12.10722065], [93.09165955, 12.10670185], [93.09183502, 12.10656548], [93.09183502, 12.10618591], [93.09155273, 12.10604954], [93.09159088, 12.10557079], [93.09179688, 12.10545921], [93.09179688, 12.10463715], [93.091362, 12.10439968], [93.091362, 12.10419178], [93.09155273, 12.10419178], [93.09159088, 12.10384083], [93.09137726, 12.10380936], [93.091362, 12.10254002], [93.09078217, 12.10254002], [93.09078217, 12.10147095], [93.09050751, 12.10142994], [93.09046936, 12.10088253], [93.09011841, 12.10074425], [93.09015656, 12.10029697], [93.09082031, 12.10030174], [93.09082031, 12.0999918], [93.09046936, 12.09992123], [93.09050751, 12.09919167], [93.08998108, 12.09919357], [93.09011841, 12.09857368], [93.09011841, 12.09833336], [93.08973694, 12.0979538], [93.08966827, 12.09754181], [93.08892822, 12.09750843], [93.08773804, 12.09636974], [93.08777618, 12.09582138], [93.08711243, 12.09585285], [93.08711243, 12.09557724], [93.08683014, 12.09558201], [93.08686066, 12.09454536], [93.08686829, 12.09420013], [93.08662415, 12.0941658], [93.08661652, 12.09337139], [93.08605957, 12.0933733], [93.08605957, 12.09309959], [93.08545685, 12.09309959], [93.08545685, 12.09268856], [93.08599091, 12.09268856], [93.08599091, 12.09200096], [93.08624268, 12.09195995], [93.08627319, 12.09130764], [93.086586, 12.09131145], [93.086586, 12.09110069], [93.0861969, 12.09082985], [93.08518982, 12.09082985], [93.08518982, 12.0903101], [93.08554077, 12.09034443], [93.08554077, 12.08979321], [93.0853653, 12.08961868], [93.08486938, 12.08914089], [93.08413696, 12.08917332], [93.08417511, 12.08855343], [93.08385468, 12.08855343], [93.08382416, 12.08886337], [93.08329773, 12.08882904], [93.0831604, 12.08917332], [93.08280945, 12.08917332], [93.08280945, 12.08886337], [93.08238983, 12.08886337], [93.0822525, 12.08858681], [93.08138275, 12.08862114], [93.08133698, 12.08890247], [93.08088684, 12.08889675], [93.08084869, 12.08972168], [93.08053589, 12.08976078], [93.08053589, 12.08941174], [93.07965851, 12.08948326], [93.07965851, 12.08886337], [93.07945251, 12.08882904], [93.079422, 12.08837986], [93.07910156, 12.08834457], [93.07910156, 12.08804035], [93.07972717, 12.08800125], [93.07965851, 12.08748436], [93.07913208, 12.08748436], [93.07906342, 12.08693504], [93.07885742, 12.08686447], [93.07888794, 12.08665943], [93.07935333, 12.08628273], [93.07930756, 12.08604145], [93.07858276, 12.08545113], [93.0786438, 12.08465958], [93.07727814, 12.084692], [93.07685852, 12.08525944], [93.07650757, 12.08528042], [93.07616425, 12.08545303], [93.07553101, 12.08493614], [93.07546234, 12.08442116], [93.07493591, 12.08445263], [93.07497406, 12.08393764], [93.074646, 12.083951], [93.074646, 12.08362961], [93.07440948, 12.0836277], [93.07444763, 12.08521175], [93.0739212, 12.08576298], [93.07338715, 12.08583164], [93.07328796, 12.08617973], [93.0727005, 12.08614063], [93.07263184, 12.0865202], [93.07248688, 12.0865202], [93.07248688, 12.08693504], [93.07186127, 12.08693504], [93.07186127, 12.08717442], [93.07003784, 12.08717155], [93.06990051, 12.08742046], [93.0694809, 12.0874157], [93.06941223, 12.08769131], [93.06973267, 12.08769131], [93.06976318, 12.08831978], [93.07007599, 12.08837986], [93.07000732, 12.08921146], [93.06976318, 12.08921146], [93.06944275, 12.08963108], [93.07003784, 12.09017086], [93.07032013, 12.09017086], [93.07032013, 12.09054947], [93.06968689, 12.09054947], [93.06958771, 12.09020138], [93.0686264, 12.090271], [93.06859589, 12.09054947], [93.06832123, 12.09062004], [93.06832123, 12.09165192], [93.06859589, 12.09165001], [93.06842804, 12.09199715], [93.06772614, 12.09257984], [93.06776428, 12.09333897], [93.06745148, 12.09340096], [93.06748199, 12.09409809], [93.06720734, 12.0943737], [93.06661224, 12.09444237], [93.06668091, 12.09523296], [93.06632996, 12.09523106], [93.0663681, 12.09557724], [93.06668091, 12.09561062], [93.06668091, 12.09665108], [93.06632996, 12.09667969], [93.06632996, 12.09799099], [93.06580353, 12.0979538], [93.06580353, 12.09833336], [93.06520844, 12.09833336], [93.06520844, 12.09850597], [93.06503296, 12.09847832], [93.06472015, 12.09826374], [93.06482697, 12.09778118], [93.06450653, 12.09775066], [93.06450653, 12.09813023], [93.06419373, 12.09812737], [93.06419373, 12.09833336], [93.06339264, 12.09829807], [93.06332397, 12.09878159], [93.06293488, 12.09878159], [93.06292725, 12.09908009], [93.06332397, 12.09912586], [93.06331635, 12.09950161], [93.06304169, 12.09960747], [93.06307983, 12.10057259], [93.06272888, 12.10057068], [93.0627594, 12.10092163], [93.06304169, 12.10091686], [93.06300354, 12.10136414], [93.06248474, 12.10150337], [93.06248474, 12.10170841], [93.06220245, 12.10170078], [93.06215668, 12.10281086], [93.06140137, 12.10281086], [93.06140137, 12.10333061], [93.06101227, 12.10333061], [93.06101227, 12.10361099], [93.06078339, 12.10364056], [93.06080627, 12.10395145], [93.06051636, 12.10395145], [93.06051636, 12.10361099], [93.06017303, 12.10361099], [93.06017303, 12.1032896], [93.05967712, 12.1032896], [93.05967712, 12.10356998], [93.05919647, 12.10356808], [93.05919647, 12.10384083], [93.05886841, 12.10387993], [93.05886078, 12.10415077], [93.05885315, 12.10442924], [93.0580368, 12.10439968], [93.0580368, 12.10494709], [93.05779266, 12.1050148], [93.05779266, 12.10546398], [93.05758667, 12.10563469], [93.05738831, 12.10587692], [93.05728149, 12.10601139], [93.05719757, 12.10612011], [93.05674744, 12.10608387], [93.056427, 12.10645962], [93.05541229, 12.10729027], [93.05496216, 12.10776997], [93.05506897, 12.10885143], [93.05464935, 12.10885143], [93.05467987, 12.10914707], [93.05454254, 12.10942078], [93.05412292, 12.10993958], [93.05307007, 12.10997391], [93.05307007, 12.11131001], [93.05223083, 12.11142159], [93.05223083, 12.11187077], [93.05161285, 12.11242008], [93.05160522, 12.11293507], [93.05110931, 12.11338425], [93.05110931, 12.11406994], [93.05051422, 12.11452103], [93.05050659, 12.1149292], [93.05020142, 12.1149683], [93.05023956, 12.11555099], [93.05055237, 12.1155901], [93.05055237, 12.11607075], [93.05023956, 12.11620998], [93.05023956, 12.11638069], [93.05059052, 12.11638069], [93.05062103, 12.11748219], [93.05220032, 12.11748028], [93.05220032, 12.11800194], [93.0526886, 12.11800194], [93.05271912, 12.11862087], [93.05307007, 12.11862087], [93.05307007, 12.11937809], [93.05325317, 12.11948109], [93.05328369, 12.12078857], [93.05381012, 12.12082291], [93.05387878, 12.12136078], [93.05407715, 12.12141132], [93.05412292, 12.12189198], [93.05443573, 12.12199497], [93.05443573, 12.12244129], [93.05464935, 12.12244129], [93.05474854, 12.12266922], [93.05527496, 12.1227169], [93.05541229, 12.12299347], [93.05653381, 12.12295914], [93.05657196, 12.1232338], [93.05576324, 12.12322998], [93.05576324, 12.12351036], [93.05545044, 12.12354374], [93.05541229, 12.1232338], [93.05467987, 12.12327099], [93.05467987, 12.12303162], [93.05419159, 12.12303162], [93.05415344, 12.12286282], [93.05412292, 12.12275124], [93.05303955, 12.12279034], [93.05296326, 12.12234116], [93.0524826, 12.12203121], [93.05243683, 12.12136078], [93.05198669, 12.1213398], [93.05132294, 12.12058067], [93.0510788, 12.12058067], [93.05110931, 12.11996174], [93.05079651, 12.11996174], [93.0506897, 12.11968803], [93.05030823, 12.11972046], [93.05023956, 12.11999798], [93.04998779, 12.1200304], [93.04992676, 12.12030983], [93.04960632, 12.12030792], [93.04957581, 12.12058067], [93.04936218, 12.12061977], [93.04936218, 12.12030983], [93.04911804, 12.12030792], [93.04915619, 12.12113094], [93.04862976, 12.12117195], [93.04862976, 12.1220293], [93.04827881, 12.12244129], [93.04803467, 12.12264919], [93.04803467, 12.12299347], [93.04772186, 12.12299061], [93.04772186, 12.12334156], [93.04799652, 12.12340546], [93.04807281, 12.12360954], [93.04834747, 12.1237154], [93.04827881, 12.12423325], [93.04754639, 12.12423038], [93.04750824, 12.12444019], [93.04708099, 12.12451077], [93.04715729, 12.12496185], [93.04750824, 12.12498856], [93.04750824, 12.12516022], [93.04715729, 12.12550735], [93.04688263, 12.12564564], [93.04691315, 12.12664413], [93.04663086, 12.12660122], [93.04656219, 12.12774944], [93.0460434, 12.12774944], [93.04586792, 12.12743855], [93.04548645, 12.12743855], [93.04554749, 12.12807083], [93.04522705, 12.12809086], [93.04522705, 12.12830067], [93.0443573, 12.12830067], [93.04440308, 12.12799072], [93.04302979, 12.12809086], [93.04299927, 12.12774944], [93.0427475, 12.12774944], [93.04250336, 12.12743855], [93.0422287, 12.12694931], [93.04135132, 12.12688637], [93.04131317, 12.12653923], [93.03998566, 12.1266098], [93.03998566, 12.12695408], [93.039711, 12.12695408], [93.039711, 12.12740135], [93.03942871, 12.12750053], [93.03942871, 12.1301899], [93.03923035, 12.13043022], [93.03925323, 12.13078117], [93.03887177, 12.13088131], [93.03890228, 12.13132954], [93.03830719, 12.1315012], [93.03830719, 12.13212109], [93.03775024, 12.13228035], [93.0377121, 12.13249874], [93.03743744, 12.13253117], [93.03743744, 12.1333313], [93.03718567, 12.13336086], [93.03718567, 12.13353157], [93.03746796, 12.1335907], [93.03761292, 12.13387966], [93.03778076, 12.13395119], [93.03775024, 12.13436127], [93.03743744, 12.13449574], [93.03746796, 12.13501072], [93.0377121, 12.13506126], [93.03778076, 12.13607979], [93.03827667, 12.1361208], [93.03837585, 12.13667202], [93.03862, 12.13667202], [93.03865814, 12.13700962], [93.03830719, 12.13700962], [93.03830719, 12.1372509], [93.03798676, 12.13729], [93.03799438, 12.1382494], [93.03827667, 12.13828564], [93.03827667, 12.13934994], [93.03862, 12.13949108], [93.03858948, 12.14007854], [93.03890228, 12.14010906], [93.03890228, 12.14059162], [93.03918457, 12.14059162], [93.03923035, 12.14107132], [93.03945923, 12.14110661], [93.03949738, 12.14472198], [93.03977966, 12.14475918], [93.03974152, 12.14510536], [93.03942871, 12.14509106], [93.03942871, 12.14555168], [93.03967285, 12.14555168], [93.03967285, 12.14641953], [93.03996277, 12.14641953], [93.03996277, 12.14693069], [93.0402298, 12.14693069], [93.0402298, 12.14803123], [93.04051208, 12.14803123], [93.04051208, 12.14886093], [93.04082489, 12.14885902], [93.04079437, 12.14975357], [93.04110718, 12.14974976], [93.04106903, 12.15082073], [93.04138947, 12.15082073], [93.04138947, 12.15113068], [93.04110718, 12.15113068], [93.04110718, 12.15126991], [93.04170227, 12.15168285], [93.04170227, 12.15268135], [93.04194641, 12.1528492], [93.04190826, 12.15320015], [93.0422287, 12.15327072], [93.0422287, 12.15405655], [93.04281616, 12.15447044], [93.0427475, 12.15485096], [93.04309845, 12.15489197], [93.04320526, 12.15581512], [93.04297638, 12.15588093], [93.03647614, 12.15692043], [93.03690338, 12.15802097], [93.03752899, 12.15974236], [93.04095459, 12.15905285], [93.04324341, 12.15853596], [93.04359436, 12.15891361], [93.04366302, 12.15943241], [93.04411316, 12.15936279], [93.04412079, 12.15959644], [93.04415131, 12.16054153], [93.04470825, 12.16050053], [93.04470825, 12.16195011], [93.04495239, 12.16191101], [93.04499054, 12.16211891], [93.04522705, 12.16215134], [93.04527283, 12.16267014], [93.04579163, 12.16311932], [93.04576111, 12.16408062], [93.04607391, 12.16418362], [93.0460434, 12.16473484], [93.04634857, 12.16473103], [93.04638672, 12.16529083], [93.04663086, 12.16529083], [93.04666901, 12.16570187], [93.04628754, 12.16570187], [93.04628754, 12.16615105], [93.04691315, 12.16611195], [93.04691315, 12.16658974], [93.04715729, 12.16663074], [93.04715729, 12.16749096], [93.04754639, 12.16752529], [93.04754639, 12.16828156], [93.04831696, 12.16887188], [93.04831696, 12.16948891], [93.04862976, 12.16948891], [93.04862976, 12.16996956], [93.04891205, 12.17000484], [93.04891205, 12.17130089], [93.04921722, 12.17149067], [93.04964447, 12.17183018], [93.04965973, 12.17268944], [93.04967499, 12.17355061], [93.04995728, 12.17355061], [93.04995728, 12.17465401], [93.05027008, 12.17464924], [93.05027008, 12.17521], [93.05051422, 12.17523956], [93.05055237, 12.17658043], [93.05104065, 12.17692947], [93.05104065, 12.17768478], [93.05136108, 12.17768478], [93.05136108, 12.17830467], [93.05169678, 12.17829132], [93.05174255, 12.17854691], [93.05191803, 12.1786108], [93.05202484, 12.17988873], [93.05243683, 12.18023109], [93.05243683, 12.18113136], [93.05275726, 12.18112946], [93.05279541, 12.18164635], [93.05303955, 12.18171024], [93.0530014, 12.18212986], [93.05330658, 12.18220043], [93.05330658, 12.18251038], [93.0530014, 12.18253994], [93.0530014, 12.1832304], [93.05327606, 12.1832304], [93.05327606, 12.18408966], [93.0535965, 12.18413067], [93.05362701, 12.18553925], [93.0539093, 12.18553925], [93.05394745, 12.18577766], [93.05415344, 12.18581295], [93.05414581, 12.18629074], [93.05443573, 12.18632984], [93.05445099, 12.18673801], [93.05446625, 12.18715954], [93.05464935, 12.18709087], [93.05467987, 12.18739891], [93.05499268, 12.18746471], [93.05499268, 12.18829155], [93.05526733, 12.18828964], [93.05538177, 12.18857002], [93.05555725, 12.18857002], [93.05555725, 12.18918991], [93.05580139, 12.18918991], [93.05580139, 12.19026184], [93.05615234, 12.19026184], [93.05615234, 12.19081116], [93.05635834, 12.19081116], [93.05635834, 12.19136047], [93.05657196, 12.19143105], [93.05688477, 12.19173622], [93.05699158, 12.1921854], [93.05723572, 12.1921854], [93.05719757, 12.19301033], [93.05747986, 12.1930809], [93.05747986, 12.19352818], [93.05779266, 12.19363022], [93.05776215, 12.19411087], [93.0580368, 12.19415188], [93.0580368, 12.19494057], [93.05891418, 12.19552422], [93.05891418, 12.19604111], [93.05912781, 12.19604111], [93.05912781, 12.19651985], [93.05999756, 12.19724655], [93.05999756, 12.19769382], [93.06027985, 12.19775963], [93.0602417, 12.1980381], [93.06056213, 12.19806957], [93.06059265, 12.19828033], [93.06083679, 12.19831085], [93.06083679, 12.19848919], [93.06111908, 12.19856167], [93.06108093, 12.19911098], [93.06143188, 12.19917965], [93.06143188, 12.19996834], [93.06160736, 12.20000267], [93.06164551, 12.20024395], [93.06195831, 12.20024014], [93.06188965, 12.20066071], [93.06212616, 12.20073032], [93.06220245, 12.20097065], [93.06253052, 12.20092964], [93.06253052, 12.20159054], [93.0627594, 12.20159054], [93.0627594, 12.20190144], [93.06297302, 12.20190144], [93.06297302, 12.2024498], [93.06331635, 12.2024498], [93.06332397, 12.20323944], [93.06408691, 12.2038908], [93.06416321, 12.20496178], [93.06465149, 12.20499611], [93.06468964, 12.20551109], [93.06492615, 12.20555019], [93.06495667, 12.20658016], [93.06552887, 12.20696068], [93.06549072, 12.20816422], [93.06632996, 12.20892143], [93.06629944, 12.21015167], [93.06646729, 12.21019936], [93.06693268, 12.21019936], [93.06693268, 12.2105093], [93.06723785, 12.2105751], [93.06723785, 12.21102428], [93.06752014, 12.21102047], [93.06752014, 12.2112999], [93.06829071, 12.21129799], [93.06830597, 12.21140957], [93.06832123, 12.2115736], [93.06860352, 12.2115736], [93.06860352, 12.21133423], [93.07021332, 12.21126366], [93.07025146, 12.21098804], [93.07055664, 12.21081924], [93.07213593, 12.2107811], [93.07224274, 12.21016312], [93.07238007, 12.21016312], [93.07336426, 12.21020889], [93.07385254, 12.21023083], [93.07389069, 12.20988941], [93.07462311, 12.20992088], [93.07472992, 12.21023083], [93.07491302, 12.21023083], [93.07493591, 12.20992088], [93.07591248, 12.20988941], [93.07601929, 12.20971203], [93.07633972, 12.20957661], [93.07633972, 12.2086792], [93.07658386, 12.2086134], [93.07658386, 12.20758057], [93.07717896, 12.20711994], [93.07717896, 12.2067194], [93.076828, 12.2066803], [93.07685852, 12.20616817], [93.07717896, 12.20610142], [93.07717896, 12.20580959], [93.07685852, 12.20575523], [93.07685852, 12.205513], [93.07717896, 12.20534039], [93.07717896, 12.20496178], [93.07769775, 12.20496178], [93.07769775, 12.20475006], [93.07745361, 12.20451546], [93.07745361, 12.20434189], [93.07710266, 12.20416927], [93.07710266, 12.20383072], [93.07749176, 12.2037611], [93.07749176, 12.20352173], [93.07720947, 12.20352173], [93.07720947, 12.20303154], [93.07689667, 12.20289516], [93.07697296, 12.20269203], [93.07717896, 12.20262146], [93.07720947, 12.20217037], [93.07798004, 12.20217228], [93.07798004, 12.201931], [93.07829285, 12.20190144], [93.07821655, 12.20141125], [93.07850647, 12.20134544], [93.07850647, 12.20045185], [93.07905579, 12.20045185], [93.07913208, 12.20020962], [93.07965851, 12.20017147], [93.07983398, 12.1998291], [93.07997131, 12.19968987], [93.08022308, 12.19958782], [93.08029175, 12.19828033], [93.08133698, 12.19834995], [93.08158112, 12.19858932], [93.08183289, 12.19838047], [93.08190155, 12.19773006], [93.08242035, 12.19773006], [93.08242035, 12.19742012], [93.08270264, 12.19738197], [93.08270264, 12.19676399], [93.08294678, 12.19672966], [93.08294678, 12.19618034], [93.08309174, 12.19608021], [93.08309174, 12.19578171]]], [[[92.99388123, 12.10993958], [92.99305725, 12.10993958], [92.99246216, 12.11053085], [92.99249268, 12.11163998], [92.99337769, 12.11163998], [92.99389648, 12.11107063], [92.99388123, 12.10993958]]], [[[92.74285126, 12.11499977], [92.74286652, 12.11472034], [92.74315643, 12.11472034], [92.74315643, 12.11389923], [92.74254608, 12.11382198], [92.74256897, 12.11220074], [92.74204254, 12.11216545], [92.74204254, 12.11133003], [92.74176025, 12.11128044], [92.74178314, 12.11086082], [92.74143982, 12.11054039], [92.74092865, 12.11046028], [92.7409668, 12.10996056], [92.74072266, 12.10996056], [92.7407074, 12.10942078], [92.74042511, 12.10942268], [92.74032593, 12.10886192], [92.74015808, 12.10856438], [92.73985291, 12.10856438], [92.73979187, 12.1080637], [92.73957062, 12.1080637], [92.73959351, 12.10744667], [92.73928833, 12.10746956], [92.73925781, 12.10689068], [92.7387085, 12.10688591], [92.7387085, 12.10716438], [92.73842621, 12.10743999], [92.73842621, 12.10883045], [92.7387085, 12.10910797], [92.7387085, 12.10966396], [92.7389679, 12.10993958], [92.7389679, 12.11050129], [92.73950195, 12.11049175], [92.73977661, 12.11081123], [92.73980713, 12.11165047], [92.74008942, 12.11165047], [92.74009705, 12.11216545], [92.74061584, 12.11221027], [92.74067688, 12.11271191], [92.74095154, 12.11279106], [92.74091339, 12.11361027], [92.74121094, 12.11361027], [92.74120331, 12.11411095], [92.74173737, 12.11411953], [92.74228668, 12.11468124], [92.74230194, 12.11499977], [92.74285126, 12.11499977]]], [[[92.68302917, 12.21490097], [92.68287659, 12.21472073], [92.68219757, 12.21484184], [92.68179321, 12.21505165], [92.68138885, 12.21524811], [92.68113708, 12.21574497], [92.68103027, 12.21628475], [92.68083954, 12.21677017], [92.68065643, 12.2172308], [92.68051147, 12.2176609], [92.68031311, 12.21803474], [92.68023682, 12.21846962], [92.6800766, 12.21888065], [92.68017578, 12.21934986], [92.680336, 12.21988106], [92.6806488, 12.2203598], [92.6810379, 12.22077942], [92.68132782, 12.22126484], [92.68147278, 12.22183037], [92.681633, 12.22232437], [92.68165588, 12.22280979], [92.68165588, 12.22331142], [92.68171692, 12.22386074], [92.6820755, 12.22437763], [92.68281555, 12.22443295], [92.68330383, 12.22383499], [92.68353271, 12.22313118], [92.68338013, 12.22241116], [92.68332672, 12.22171974], [92.68332672, 12.22107124], [92.68332672, 12.22047138], [92.68332672, 12.21988106], [92.68333435, 12.21927738], [92.68332672, 12.21862125], [92.6833725, 12.21793461], [92.68350983, 12.2172718], [92.6833725, 12.21669006], [92.68331909, 12.21610928], [92.68321228, 12.21558475], [92.68305969, 12.21510887], [92.68302917, 12.21490097]]], [[[92.84584808, 12.14756203], [92.84552765, 12.14752102], [92.84501648, 12.1475687], [92.84443665, 12.14785099], [92.84401703, 12.14841938], [92.84402466, 12.1489954], [92.84417725, 12.14941025], [92.84440613, 12.14969063], [92.8446579, 12.14993], [92.8449707, 12.15015984], [92.84527588, 12.15045166], [92.84564209, 12.15075493], [92.84586334, 12.15086746], [92.84611511, 12.1509943], [92.84676361, 12.15097141], [92.84724426, 12.15074825], [92.84720612, 12.15044022], [92.84700775, 12.15010071], [92.84675598, 12.14974976], [92.84661865, 12.14933109], [92.84644318, 12.14887238], [92.84631348, 12.14831161], [92.84600067, 12.14780807], [92.84584808, 12.14756203]]], [[[92.75895691, 12.18131065], [92.75927734, 12.18080139], [92.76059723, 12.18082142], [92.7607193, 12.18060303], [92.76093292, 12.18023968], [92.7617569, 12.18026066], [92.76174927, 12.17993927], [92.76229858, 12.17996025], [92.76244354, 12.1796751], [92.7625885, 12.17938995], [92.76367188, 12.17937946], [92.7636795, 12.17685127], [92.76341248, 12.17688084], [92.76341248, 12.1760397], [92.76307678, 12.1760397], [92.76312256, 12.17523098], [92.76256561, 12.17521], [92.76255035, 12.17406082], [92.7623291, 12.17409134], [92.7623291, 12.17352962], [92.76203156, 12.17356205], [92.76204681, 12.17243862], [92.76172638, 12.17241955], [92.76176453, 12.17163181], [92.76119232, 12.17161369], [92.76117706, 12.17108727], [92.76088715, 12.17104244], [92.76089478, 12.17048836], [92.76062012, 12.17021179], [92.76062012, 12.16992855], [92.76035309, 12.16996956], [92.76034546, 12.16943932], [92.76033783, 12.1691227], [92.76008606, 12.1691227], [92.7600708, 12.16826344], [92.75978088, 12.16824722], [92.75978088, 12.16798115], [92.7594986, 12.16798306], [92.7594986, 12.16689587], [92.75923157, 12.16687965], [92.75923157, 12.16660023], [92.75894928, 12.16660023], [92.75894928, 12.16798973], [92.75865173, 12.16804695], [92.75871277, 12.16857147], [92.75921631, 12.16883755], [92.7592392, 12.17024231], [92.7594986, 12.17022133], [92.75953674, 12.17107105], [92.7592392, 12.17107105], [92.75925446, 12.17191029], [92.75949097, 12.17192078], [92.75953674, 12.17244053], [92.7592392, 12.17243576], [92.75923157, 12.17464924], [92.75894165, 12.17468071], [92.75895691, 12.17522144], [92.75924683, 12.17525101], [92.75923157, 12.17548847], [92.75923157, 12.17632198], [92.75921631, 12.17720222], [92.75950623, 12.17720222], [92.75948334, 12.17804527], [92.75923157, 12.17804527], [92.75921631, 12.17855358], [92.75842285, 12.17855072], [92.75839996, 12.17910099], [92.75784302, 12.1796608], [92.7567215, 12.17963791], [92.75675201, 12.18023968], [92.7564621, 12.18023968], [92.7564621, 12.18075085], [92.75679016, 12.18107033], [92.75785828, 12.18107891], [92.75788116, 12.18132973], [92.75895691, 12.18131065]]], [[[92.72029114, 12.18043804], [92.72000122, 12.1802702], [92.71987152, 12.18016911], [92.71982574, 12.18011284], [92.71968079, 12.17990971], [92.71961975, 12.17974091], [92.71955872, 12.17947197], [92.71949768, 12.17936039], [92.71941376, 12.17926025], [92.71928406, 12.17924023], [92.71917725, 12.17928123], [92.71909332, 12.17936039], [92.71903992, 12.17951107], [92.71897125, 12.17974091], [92.71884155, 12.18021107], [92.71886444, 12.180336], [92.7190094, 12.18031502], [92.71920013, 12.18031979], [92.71942902, 12.18039703], [92.7194519, 12.18062496], [92.7194519, 12.18087101], [92.71942902, 12.1811018], [92.71942902, 12.18129063], [92.71955872, 12.18140888], [92.71981049, 12.18157101], [92.72033691, 12.18202877], [92.72045898, 12.1821909], [92.72075653, 12.18229961], [92.72094727, 12.18232059], [92.72106171, 12.18223667], [92.72117615, 12.18215466], [92.72126007, 12.18190575], [92.72122192, 12.18170071], [92.72077179, 12.18132973], [92.7202301, 12.18122864], [92.7202301, 12.18091011], [92.7204361, 12.18075275], [92.72050476, 12.18068695], [92.72029114, 12.18043804]]], [[[92.73137665, 12.18758106], [92.73119354, 12.18743992], [92.73123932, 12.18662167], [92.7309494, 12.18662167], [92.73093414, 12.18604279], [92.73066711, 12.18606281], [92.73066711, 12.18550491], [92.73038483, 12.18548393], [92.73034668, 12.18442726], [92.73114777, 12.18490124], [92.73171234, 12.18444729], [92.7325058, 12.18235111], [92.73040009, 12.18235111], [92.72850037, 12.18157959], [92.72852325, 12.18382835], [92.72850037, 12.18498516], [92.72789764, 12.18496323], [92.72789764, 12.1846838], [92.72595215, 12.18467999], [92.72595215, 12.18524075], [92.72537994, 12.18553543], [92.72540283, 12.18607235], [92.72589111, 12.18611336], [92.72621155, 12.18661308], [92.72673798, 12.18661308], [92.72678375, 12.18746281], [92.72735596, 12.18745136], [92.7276001, 12.18795013], [92.72814941, 12.18803024], [92.72841644, 12.18826962], [92.72847748, 12.18887138], [92.72872925, 12.18913078], [92.73014832, 12.18915367], [92.73008728, 12.18940926], [92.73091888, 12.18940926], [92.73092651, 12.18917179], [92.73121643, 12.18913078], [92.73142242, 12.18875027], [92.73137665, 12.18758106]]], [[[93.01988983, 12.22515965], [93.02030945, 12.22494984], [93.02094269, 12.22502327], [93.02101135, 12.2247467], [93.02170563, 12.22495174], [93.02198792, 12.22419643], [93.02178192, 12.22392178], [93.02178192, 12.22363853], [93.02128601, 12.22316265], [93.02108002, 12.22316265], [93.02072906, 12.22288704], [93.02030945, 12.22282124], [93.01980591, 12.22264099], [93.01931763, 12.22270679], [93.0191803, 12.22290993], [93.01953125, 12.22311974], [93.01953125, 12.22394657], [93.01944733, 12.22416592], [93.01967621, 12.22440338], [93.01953888, 12.22495174], [93.01977539, 12.22509098], [93.01988983, 12.22515965]]], [[[92.9389801, 12.22386074], [92.93916321, 12.22332859], [92.93968964, 12.22278023], [92.93998718, 12.22238064], [92.9402771, 12.22194099], [92.9405365, 12.2214613], [92.94072723, 12.22096634], [92.9407959, 12.22050953], [92.94089508, 12.22023201], [92.94108582, 12.22002029], [92.94122314, 12.21969891], [92.94140625, 12.21926975], [92.94161987, 12.21872139], [92.94166565, 12.21804047], [92.94161987, 12.21735096], [92.94140625, 12.21673107], [92.94120026, 12.21618938], [92.94104767, 12.21567154], [92.94082642, 12.21520042], [92.94056702, 12.21472073], [92.94032288, 12.21417046], [92.94001007, 12.21362495], [92.93965149, 12.21313858], [92.93926239, 12.21276569], [92.93890381, 12.21240807], [92.93858337, 12.21207142], [92.9382019, 12.21183109], [92.93779755, 12.21165085], [92.93738556, 12.21146202], [92.93695068, 12.21165085], [92.93650818, 12.21185875], [92.93616486, 12.21222115], [92.93596649, 12.21271324], [92.93576813, 12.21301365], [92.93553925, 12.21310139], [92.93538666, 12.21295929], [92.93540955, 12.21249008], [92.93554688, 12.21194744], [92.93540955, 12.21173954], [92.93517303, 12.21152973], [92.93493652, 12.21118164], [92.93466949, 12.21080112], [92.93450928, 12.21037865], [92.93461609, 12.2099514], [92.9347229, 12.20947933], [92.93483734, 12.20906162], [92.93497467, 12.20869255], [92.93502045, 12.20829201], [92.93512726, 12.20791054], [92.93524933, 12.20747089], [92.93533325, 12.2069397], [92.93553925, 12.20645714], [92.93570709, 12.20595074], [92.93580627, 12.20546055], [92.93585205, 12.2049799], [92.93583679, 12.2045269], [92.93582916, 12.20407963], [92.93585205, 12.20362186], [92.93592834, 12.20314121], [92.93606567, 12.2026577], [92.93591309, 12.20201969], [92.93580627, 12.20139122], [92.93567657, 12.20083046], [92.93556213, 12.20030117], [92.93546295, 12.19979095], [92.93527222, 12.19933033], [92.93505859, 12.19885159], [92.93483734, 12.19833183], [92.93460083, 12.19777966], [92.93431854, 12.19721985], [92.93393707, 12.19664097], [92.9334259, 12.1961422], [92.9331665, 12.19585514], [92.93275452, 12.19612312], [92.93255615, 12.19671059], [92.93257141, 12.19729042], [92.93276978, 12.19769573], [92.93299103, 12.19800377], [92.93313599, 12.19826984], [92.93328857, 12.19850063], [92.93331146, 12.19873524], [92.93322754, 12.19899273], [92.93309021, 12.19928932], [92.93300629, 12.19968319], [92.93282318, 12.20010281], [92.93279266, 12.20065022], [92.93279266, 12.20123959], [92.93279266, 12.2018013], [92.93274689, 12.20229053], [92.93260956, 12.20266914], [92.93242645, 12.20295429], [92.93213654, 12.2031498], [92.93183136, 12.20343018], [92.93141937, 12.20366096], [92.93097687, 12.20390034], [92.93056488, 12.20416927], [92.93016815, 12.20444489], [92.92977905, 12.20471954], [92.92939758, 12.20500088], [92.92899323, 12.20527363], [92.92854309, 12.205513], [92.92803955, 12.20569134], [92.92751312, 12.2058506], [92.92697906, 12.20611954], [92.92645264, 12.20649147], [92.9259491, 12.20699501], [92.92552185, 12.20759201], [92.92514801, 12.2081604], [92.92510986, 12.2089119], [92.9252243, 12.20964622], [92.92520142, 12.21028137], [92.92498779, 12.21090126], [92.92488098, 12.2114706], [92.92504883, 12.2119503], [92.92529297, 12.21243095], [92.92550659, 12.21294117], [92.92556, 12.21350193], [92.92559814, 12.21405983], [92.92576599, 12.2145586], [92.92590332, 12.21505165], [92.92606354, 12.21551228], [92.92610931, 12.21598244], [92.92617035, 12.21641922], [92.92633057, 12.21679688], [92.92649078, 12.21720123], [92.92669678, 12.2176199], [92.92694855, 12.21802139], [92.92722321, 12.21843243], [92.92739105, 12.21885109], [92.92730713, 12.21927929], [92.92698669, 12.21973133], [92.92699432, 12.22012997], [92.92715454, 12.22054386], [92.92722321, 12.22108173], [92.92727661, 12.22165203], [92.92756653, 12.22211933], [92.92796326, 12.22248173], [92.92842102, 12.22272778], [92.92897797, 12.22278214], [92.92955017, 12.22283268], [92.93009949, 12.22299862], [92.93063354, 12.22305107], [92.93109131, 12.22311306], [92.93144226, 12.22335529], [92.93173218, 12.22372437], [92.93209839, 12.2241497], [92.93269348, 12.22444153], [92.93332672, 12.22472191], [92.93360901, 12.22500038], [92.9347229, 12.22500038], [92.93495941, 12.22501087], [92.93519592, 12.22484112], [92.93540955, 12.22472858], [92.93572998, 12.22446918], [92.93583679, 12.22416592], [92.93638611, 12.22360992], [92.9366684, 12.2238903], [92.93675232, 12.22362137], [92.93694305, 12.22360992], [92.93722534, 12.22360992], [92.93741608, 12.22401142], [92.93718719, 12.22461033], [92.93799591, 12.22518921], [92.9389801, 12.22386074]]], [[[93.07777405, 12.26194477], [93.07805634, 12.26166725], [93.07833099, 12.26167107], [93.07861328, 12.26139069], [93.07888794, 12.26139069], [93.07943726, 12.26082993], [93.07949829, 12.26038074], [93.08033752, 12.25934887], [93.08139038, 12.26031303], [93.08167267, 12.25989819], [93.08209229, 12.25942039], [93.08277893, 12.25944519], [93.08361053, 12.25861073], [93.08361053, 12.2569418], [93.08388519, 12.25666618], [93.08389282, 12.25611019], [93.08416748, 12.25583458], [93.08416748, 12.2555542], [93.08444214, 12.25528145], [93.08444214, 12.25417137], [93.0847168, 12.25389004], [93.0847168, 12.25360966], [93.08499908, 12.25333214], [93.08499908, 12.25277805], [93.08528137, 12.25249958], [93.08528137, 12.24971962], [93.08555603, 12.24944401], [93.08555603, 12.2486124], [93.08583069, 12.24833393], [93.08583069, 12.24638844], [93.08609772, 12.24611187], [93.08609772, 12.24583054], [93.08583069, 12.24555588], [93.08609772, 12.24527073], [93.08583069, 12.24499989], [93.08583069, 12.24444103], [93.08611298, 12.24416542], [93.08609772, 12.24306011], [93.08583069, 12.24277973], [93.08583069, 12.24166965], [93.08555603, 12.24138927], [93.08555603, 12.24055958], [93.08528137, 12.2402792], [93.08528137, 12.23944092], [93.08499908, 12.23916721], [93.08499908, 12.23861122], [93.08611298, 12.23750114], [93.08638763, 12.23750114], [93.08666992, 12.23721886], [93.08860779, 12.23721886], [93.08889008, 12.23750114], [93.08944702, 12.23750114], [93.08972168, 12.23778057], [93.09027863, 12.23778057], [93.09055328, 12.2380619], [93.09222412, 12.23805523], [93.09278107, 12.23861122], [93.09278107, 12.23889065], [93.09306335, 12.23917198], [93.09306335, 12.24000072], [93.09333038, 12.24000072], [93.09333038, 12.2402792], [93.09361267, 12.24055481], [93.09361267, 12.2411108], [93.09583282, 12.24333286], [93.09583282, 12.24361229], [93.09610748, 12.24388981], [93.09610748, 12.2444458], [93.09638977, 12.24472141], [93.09638977, 12.24499989], [93.09610748, 12.24527073], [93.09610748, 12.24611187], [93.09638977, 12.24638844], [93.09638977, 12.24694443], [93.09694672, 12.24750233], [93.09709167, 12.24765015], [93.09722137, 12.24777985], [93.09750366, 12.24777794], [93.09805298, 12.24833393], [93.09832764, 12.24833202], [93.09916687, 12.24916553], [93.09916687, 12.24944401], [93.09944153, 12.24971962], [93.09944153, 12.25028038], [93.09916687, 12.25056076], [93.09916687, 12.25111198], [93.09889221, 12.2514019], [93.09889221, 12.25249958], [93.09860992, 12.25277996], [93.09860992, 12.25389004], [93.09889221, 12.25417137], [93.09889221, 12.25500011], [93.09916687, 12.25528145], [93.09916687, 12.2555542], [93.09944153, 12.25583458], [93.09944153, 12.25611019], [93.09951019, 12.25623989], [93.09964752, 12.25623989], [93.09966278, 12.25788975], [93.09967804, 12.25858784], [93.10002899, 12.25899982], [93.10009766, 12.25935078], [93.10024261, 12.25942039], [93.10051727, 12.25941467], [93.10058594, 12.25961971], [93.10086823, 12.26003456], [93.10087585, 12.26031971], [93.10109711, 12.26056099], [93.10138702, 12.26055527], [93.10157776, 12.26074123], [93.10166931, 12.26083279], [93.10333252, 12.26083279], [93.10361481, 12.26055527], [93.10416412, 12.26111126], [93.10424042, 12.26092243], [93.10424042, 12.26078033], [93.10459137, 12.26078033], [93.1047287, 12.26106071], [93.10486603, 12.26105785], [93.10486603, 12.26096344], [93.10570526, 12.26075459], [93.10598755, 12.26020432], [93.10598755, 12.25958443], [93.10612488, 12.25896358], [93.1063385, 12.25841236], [93.10647583, 12.25779247], [93.1063385, 12.25689888], [93.10618591, 12.25538063], [93.1063385, 12.25428009], [93.10591888, 12.25428009], [93.10598755, 12.25373077], [93.1063385, 12.25332069], [93.10661316, 12.25275993], [93.10661316, 12.25214481], [93.10696411, 12.25159264], [93.10689545, 12.25069714], [93.10647583, 12.2500906], [93.1063385, 12.2493906], [93.10666656, 12.24888992], [93.10666656, 12.24833202], [93.10639191, 12.24805641], [93.10639191, 12.24417019], [93.10610962, 12.24389172], [93.10610962, 12.24194145], [93.10583496, 12.24166679], [93.10582733, 12.24138927], [93.10569763, 12.24103165], [93.10555267, 12.24083328], [93.10555267, 12.23999882], [93.10582733, 12.2397213], [93.10562897, 12.23941135], [93.10528564, 12.23906708], [93.10507202, 12.23803043], [93.10472107, 12.23755074], [93.10472107, 12.2366724], [93.10333252, 12.23528099], [93.10305786, 12.23528099], [93.10166931, 12.23389053], [93.10166931, 12.23332977], [93.10138702, 12.23305511], [93.10138702, 12.23278141], [93.10109711, 12.23250103], [93.10109711, 12.2322197], [93.10083008, 12.23194504], [93.10083008, 12.23166656], [93.10056305, 12.23139095], [93.10083008, 12.23110962], [93.10083008, 12.23027897], [93.10138702, 12.22972012], [93.10138702, 12.22944355], [93.10166931, 12.22916603], [93.10166931, 12.22861004], [93.10138702, 12.22832966], [93.10221863, 12.22749996], [93.10221863, 12.22611046], [93.10250092, 12.22583199], [93.10250092, 12.22500038], [93.1027832, 12.22472191], [93.10277557, 12.22444439], [93.10305786, 12.22416592], [93.10305786, 12.22333431], [93.10333252, 12.22305584], [93.10333252, 12.22194099], [93.10361481, 12.22166634], [93.10360718, 12.22056007], [93.10333252, 12.22027969], [93.10333252, 12.22000027], [93.10333252, 12.21860886], [93.10361481, 12.2183342], [93.10361481, 12.21611118], [93.10333252, 12.21583271], [93.10333252, 12.21472263], [93.10361481, 12.21444321], [93.10361481, 12.21361065], [93.10333252, 12.21333122], [93.10333252, 12.21277714], [93.10305786, 12.21250057], [93.10305786, 12.21111107], [93.10333252, 12.21083069], [93.10333252, 12.20972347], [93.10361481, 12.209445], [93.10355377, 12.20831871], [93.10328674, 12.20826721], [93.10307312, 12.20805931], [93.10293579, 12.20785046], [93.10272217, 12.20709515], [93.10272217, 12.20660973], [93.10250092, 12.20638943], [93.10250092, 12.20610142], [93.10166931, 12.20527554], [93.10166931, 12.20471954], [93.1009903, 12.20404816], [93.10074615, 12.20394135], [93.10018921, 12.20394325], [93.09998322, 12.20373821], [93.09941864, 12.20374012], [93.09941864, 12.20415115], [93.09893036, 12.20415115], [93.09893036, 12.20511532], [93.09857941, 12.20532227], [93.09830475, 12.20587444], [93.09830475, 12.20642281], [93.09803772, 12.20639133], [93.09777832, 12.20666695], [93.09777832, 12.20722103], [93.09749603, 12.20750141], [93.09750366, 12.20777893], [93.09733582, 12.20836926], [93.09706879, 12.20872021], [93.09664154, 12.20872021], [93.09606171, 12.2088213], [93.09564209, 12.20957947], [93.09514618, 12.20957947], [93.09472656, 12.20978928], [93.09416962, 12.20972061], [93.09416962, 12.21000099], [93.09388733, 12.2102766], [93.09388733, 12.2108326], [93.09249878, 12.21222115], [93.09249878, 12.21250057], [93.09222412, 12.21277714], [93.09223175, 12.21361065], [93.09194183, 12.21389198], [93.09194183, 12.21416664], [93.09166718, 12.21444321], [93.09166718, 12.21472073], [93.09139252, 12.2149992], [93.09139252, 12.21555519], [93.09111023, 12.21583271], [93.09111023, 12.21694565], [93.09139252, 12.21722126], [93.09139252, 12.21750164], [93.09166718, 12.21777821], [93.09166718, 12.2183342], [93.09278107, 12.21944141], [93.09278107, 12.21972179], [93.09306335, 12.22000027], [93.09319305, 12.22000694], [93.09333801, 12.22014332], [93.09333038, 12.22083378], [93.09333038, 12.22111225], [93.09352875, 12.22111225], [93.09353638, 12.22283268], [93.09338379, 12.22310829], [93.09362793, 12.22334957], [93.09348297, 12.22349072], [93.09340668, 12.22362995], [93.09320831, 12.22349072], [93.09299469, 12.22376728], [93.09307861, 12.22380829], [93.09350586, 12.22402191], [93.09308624, 12.22443485], [93.09266663, 12.22436619], [93.09217834, 12.22443485], [93.09169006, 12.22422695], [93.09155273, 12.22375107], [93.09113312, 12.22347069], [93.08994293, 12.22347069], [93.08944702, 12.2238903], [93.08916473, 12.22360992], [93.08860779, 12.22416592], [93.08638763, 12.22416592], [93.08611298, 12.2238903], [93.08583069, 12.2238903], [93.08569336, 12.22375107], [93.08528137, 12.22333431], [93.08499908, 12.22333431], [93.0847168, 12.22305393], [93.08444214, 12.22277832], [93.08444214, 12.22249985], [93.08416748, 12.22222042], [93.08277893, 12.22222042], [93.08249664, 12.22249985], [93.08194733, 12.22249985], [93.08167267, 12.22278023], [93.08110809, 12.22278023], [93.08082581, 12.22306061], [93.08055878, 12.22305584], [93.08029175, 12.22332859], [93.08013153, 12.22340012], [93.07985687, 12.22382164], [93.07943726, 12.22347069], [93.07943726, 12.22415924], [93.07832336, 12.22415924], [93.07776642, 12.22429562], [93.07727051, 12.22450066], [93.07670593, 12.22471142], [93.07615662, 12.22499084], [93.07559204, 12.22525978], [93.07538605, 12.22554016], [93.07509613, 12.22554016], [93.07462311, 12.22546959], [93.07348633, 12.22546959], [93.07277679, 12.22556114], [93.07221985, 12.22555637], [93.07194519, 12.22583199], [93.07138824, 12.22583199], [93.07111359, 12.22611237], [93.0708313, 12.22611046], [93.07055664, 12.22639275], [93.06999969, 12.22639275], [93.06973267, 12.22667122], [93.06916809, 12.22666645], [93.0688858, 12.22694397], [93.06835175, 12.22694016], [93.06806183, 12.22723103], [93.06555176, 12.22723103], [93.0652771, 12.22749996], [93.06498718, 12.22749996], [93.06472015, 12.2277813], [93.0644455, 12.22777843], [93.06388855, 12.22832966], [93.06388855, 12.22861004], [93.0633316, 12.22916603], [93.0633316, 12.22972012], [93.06319427, 12.22985935], [93.06305695, 12.23000145], [93.06327057, 12.23000145], [93.06333923, 12.23055172], [93.06318665, 12.2308979], [93.06277466, 12.2308321], [93.06276703, 12.2322197], [93.0625, 12.23250103], [93.0625, 12.23305511], [93.06277466, 12.23333263], [93.06276703, 12.23361111], [93.0625, 12.23389053], [93.06277466, 12.2341671], [93.06277466, 12.23444462], [93.06298065, 12.23465157], [93.06370544, 12.23537159], [93.06380463, 12.23527431], [93.06415558, 12.23527431], [93.06434631, 12.23567963], [93.06439972, 12.23580074], [93.06475067, 12.23580074], [93.06472015, 12.23639107], [93.06472015, 12.23666668], [93.06500244, 12.23694515], [93.06498718, 12.23721886], [93.0652771, 12.23750114], [93.0652771, 12.23805523], [93.06555176, 12.23833084], [93.06555176, 12.23889065], [93.06582642, 12.23917198], [93.06582642, 12.24000072], [93.0661087, 12.2402792], [93.0661087, 12.24138927], [93.06639099, 12.24166965], [93.06639099, 12.24222088], [93.06667328, 12.24249935], [93.06666565, 12.24499989], [93.06694794, 12.24527073], [93.0671463, 12.2455101], [93.0671463, 12.24605656], [93.06700134, 12.24619102], [93.06721497, 12.24640083], [93.06720734, 12.24687099], [93.067276, 12.24708939], [93.06742096, 12.24723053], [93.06742096, 12.24854088], [93.06749725, 12.24888992], [93.06749725, 12.2491703], [93.06835175, 12.25], [93.06861115, 12.25], [93.06964111, 12.25103474], [93.06971741, 12.25102329], [93.07006073, 12.25097084], [93.07012939, 12.25144863], [93.07027435, 12.25166607], [93.07027435, 12.25194359], [93.07044983, 12.2518568], [93.07086945, 12.2518568], [93.07093811, 12.25227165], [93.07135773, 12.25282192], [93.07138824, 12.25333023], [93.07133484, 12.25457001], [93.07132721, 12.25472164], [93.07132721, 12.25512123], [93.07141113, 12.25595093], [93.07125854, 12.25636101], [93.07083893, 12.25683975], [93.07068634, 12.25726128], [93.07055664, 12.25778103], [93.0716629, 12.2588892], [93.0718689, 12.25896358], [93.07215118, 12.25910091], [93.07235718, 12.25938129], [93.07248688, 12.2596817], [93.07285309, 12.25967026], [93.07348633, 12.26001358], [93.07361603, 12.26029015], [93.07467651, 12.26072121], [93.07522583, 12.26098061], [93.07593536, 12.26118565], [93.07670593, 12.26139069], [93.07754517, 12.26166916], [93.07767487, 12.26182556], [93.07777405, 12.26194477]]], [[[92.72397614, 12.18855], [92.72393799, 12.18884182], [92.72344208, 12.18884182], [92.72341156, 12.18969154], [92.72315216, 12.18965054], [92.72315216, 12.19050121], [92.7228241, 12.19049931], [92.7228775, 12.19104099], [92.72254944, 12.19106102], [92.7225647, 12.19243813], [92.72202301, 12.19274139], [92.7220459, 12.19550991], [92.7226181, 12.19579983], [92.7226181, 12.19636345], [92.72284698, 12.19635963], [92.72284698, 12.19744968], [92.72260284, 12.19746971], [92.72255707, 12.19856167], [92.72286987, 12.19863033], [92.72286987, 12.19909954], [92.72315216, 12.19913197], [92.72309875, 12.20104027], [92.72338867, 12.20104027], [92.72342682, 12.20195103], [92.72396088, 12.20191002], [92.72402191, 12.20293999], [92.72341156, 12.20300198], [92.72337341, 12.20328712], [92.7228775, 12.20330524], [92.72233582, 12.2038908], [92.72232819, 12.20412064], [92.72260284, 12.20411587], [92.72260284, 12.20491409], [92.7223053, 12.20491409], [92.7223053, 12.20551109], [92.72258759, 12.20580292], [92.72312164, 12.20577145], [92.72367859, 12.20635033], [92.72370911, 12.20687199], [92.72424316, 12.20690823], [92.72428131, 12.20743465], [92.72451782, 12.20745087], [92.72451782, 12.20802116], [92.72399139, 12.20830059], [92.72396851, 12.20883179], [92.72370911, 12.20886612], [92.72372437, 12.20997143], [92.72395325, 12.20997143], [92.72398376, 12.21049786], [92.72369385, 12.2107687], [92.72367096, 12.21136189], [92.72341156, 12.21133041], [92.72341156, 12.21189308], [92.72317505, 12.2119112], [92.72312927, 12.21246338], [92.7228775, 12.21243954], [92.7228775, 12.21384144], [92.72258759, 12.21384144], [92.7225647, 12.21465492], [92.72286224, 12.21469212], [92.7228775, 12.21576309], [92.72232819, 12.21603203], [92.72232819, 12.21658134], [92.72260284, 12.21658134], [92.72255707, 12.21828079], [92.72341156, 12.218297], [92.72341919, 12.21882057], [92.72367859, 12.21882057], [92.72367859, 12.21938038], [92.72396088, 12.21940708], [92.72396088, 12.21996117], [92.72506714, 12.22108173], [92.72506714, 12.221632], [92.72484589, 12.2216177], [92.72480774, 12.22243404], [92.72454834, 12.22243404], [92.72454834, 12.22301292], [92.72419739, 12.22328377], [92.72340393, 12.22330189], [92.72312927, 12.22357559], [92.72315216, 12.22495174], [92.72338867, 12.22492886], [92.72341156, 12.22552013], [92.72285461, 12.22607613], [92.72285461, 12.2277422], [92.72255707, 12.22772121], [92.72257996, 12.22826195], [92.72233582, 12.22827721], [92.72229767, 12.23047161], [92.72232056, 12.23134136], [92.72255707, 12.23134136], [92.72260284, 12.2327404], [92.72228241, 12.23273754], [92.72228241, 12.23328018], [92.72255707, 12.23330116], [92.72255707, 12.23379135], [92.72283173, 12.23409557], [92.72340393, 12.23413277], [92.72342682, 12.2344017], [92.72424316, 12.23440838], [92.72453308, 12.2346611], [92.72458649, 12.23523998], [92.72505188, 12.23549557], [92.72509003, 12.23609257], [92.72483063, 12.23608971], [92.72479248, 12.23664188], [92.72534943, 12.23660088], [92.72534943, 12.2380209], [92.72509766, 12.2380209], [92.72509766, 12.23888016], [92.72534943, 12.23885345], [92.72535706, 12.23926067], [92.72537231, 12.23967075], [92.72563171, 12.23967075], [92.72564697, 12.24023247], [92.72648621, 12.24024963], [92.72647858, 12.2399416], [92.72732544, 12.23997879], [92.72731781, 12.24023247], [92.7278595, 12.24024963], [92.72783661, 12.24050045], [92.72870636, 12.2405386], [92.72924042, 12.24107456], [92.72924042, 12.24134064], [92.72979736, 12.24190903], [92.72979736, 12.24245358], [92.73061371, 12.24245358], [92.73092651, 12.24189281], [92.73147583, 12.24189281], [92.73147583, 12.24164009], [92.73203278, 12.24162197], [92.73201752, 12.24171829], [92.73197937, 12.24191093], [92.73262024, 12.24189091], [92.73287201, 12.24160385], [92.73285675, 12.24107742], [92.73313141, 12.24105167], [92.73313141, 12.24020576], [92.73343658, 12.24021053], [92.73340607, 12.23970127], [92.73394012, 12.23965931], [92.73400116, 12.23939133], [92.73478699, 12.23941135], [92.73478699, 12.2380209], [92.7339859, 12.23744202], [92.73397064, 12.23583126], [92.73365784, 12.23553181], [92.73287964, 12.23550034], [92.73287964, 12.23521137], [92.73233032, 12.23519039], [92.73201752, 12.23491859], [92.73201752, 12.2341013], [92.73171997, 12.23408699], [92.73174286, 12.23271275], [92.73147583, 12.23271275], [92.7314682, 12.23218441], [92.7311554, 12.23219967], [92.73118591, 12.23079586], [92.73203278, 12.23019886], [92.73203278, 12.22970867], [92.73146057, 12.22971058], [92.73147583, 12.22940063], [92.7309494, 12.22942162], [92.73033905, 12.22886086], [92.73034668, 12.22831154], [92.73065186, 12.22825909], [92.73065186, 12.22773266], [92.73035431, 12.22773457], [92.73035431, 12.22550392], [92.7300415, 12.22550392], [92.73006439, 12.22498035], [92.73065186, 12.22465134], [92.73061371, 12.22356415], [92.73034668, 12.22357082], [92.73034668, 12.2221899], [92.73118591, 12.221632], [92.73118591, 12.22024059], [92.73146057, 12.22024059], [92.73147583, 12.21885967], [92.73117065, 12.21886158], [92.73122406, 12.21724892], [92.730896, 12.21720123], [92.730896, 12.21413136], [92.73118591, 12.21411514], [92.73118591, 12.21301937], [92.73149872, 12.21276093], [92.73229218, 12.21275043], [92.73233032, 12.21244717], [92.73287201, 12.21243095], [92.73284149, 12.21191978], [92.73223877, 12.21164894], [92.7322998, 12.21107006], [92.73286438, 12.21079731], [92.73288727, 12.21025181], [92.73330688, 12.21023083], [92.73369598, 12.21049118], [92.73368073, 12.21107006], [92.73395538, 12.21108627], [92.73397064, 12.21232796], [92.7339859, 12.21359062], [92.73425293, 12.21353054], [92.73423004, 12.21407604], [92.73455811, 12.21409035], [92.73452759, 12.21502018], [92.7350769, 12.21552086], [92.73509979, 12.21634197], [92.73474884, 12.21634197], [92.73482513, 12.21741104], [92.73535156, 12.21774101], [92.73535156, 12.22051907], [92.73537445, 12.22075367], [92.73618317, 12.22106171], [92.73728943, 12.22102833], [92.73755646, 12.22099113], [92.73757935, 12.22191429], [92.73789215, 12.22193241], [92.73791504, 12.22242165], [92.7381134, 12.22242165], [92.73813629, 12.22298145], [92.73872375, 12.22352791], [92.73925781, 12.22356415], [92.73927307, 12.2230196], [92.7397995, 12.2230196], [92.73977661, 12.22275066], [92.74034882, 12.22270012], [92.74042511, 12.22245693], [92.74091339, 12.22244072], [92.74088287, 12.2218914], [92.74143982, 12.22191238], [92.74201965, 12.22107506], [92.74260712, 12.22105026], [92.74259186, 12.22076321], [92.74312592, 12.22078133], [92.74316406, 12.22054672], [92.74391937, 12.22049046], [92.74425507, 12.22023869], [92.7442627, 12.21968079], [92.74395752, 12.21966171], [92.7440033, 12.2182579], [92.74368286, 12.21829891], [92.74368286, 12.21774101], [92.7434082, 12.21775532], [92.74344635, 12.21661282], [92.74312592, 12.21663094], [92.74312592, 12.21603203], [92.742836, 12.21603203], [92.74285126, 12.21437931], [92.74256134, 12.21438217], [92.7425766, 12.21356583], [92.742836, 12.21358395], [92.74285126, 12.21246338], [92.74313354, 12.21217346], [92.74368286, 12.21219063], [92.74368286, 12.21160984], [92.74397278, 12.21163082], [92.74397278, 12.21052074], [92.74423981, 12.21049976], [92.74423981, 12.21024036], [92.74423981, 12.20965004], [92.74453735, 12.20963192], [92.74453735, 12.21025181], [92.74476624, 12.2102108], [92.74479675, 12.21190929], [92.74423981, 12.21245956], [92.74423981, 12.21356964], [92.74341583, 12.21356964], [92.74341583, 12.21464062], [92.74368286, 12.21468925], [92.74368286, 12.21525002], [92.7440033, 12.2152319], [92.74394226, 12.21605015], [92.74423981, 12.21607971], [92.74423218, 12.21665192], [92.74452209, 12.21663094], [92.74449921, 12.21774101], [92.74479675, 12.21771812], [92.74481201, 12.21971226], [92.74510956, 12.21966171], [92.74510193, 12.22104073], [92.74481201, 12.22104073], [92.74476624, 12.22301006], [92.74453735, 12.22299194], [92.74455261, 12.22355461], [92.74396515, 12.22355461], [92.74396515, 12.22384453], [92.74288177, 12.22383118], [92.742836, 12.22408199], [92.74230957, 12.22411633], [92.74202728, 12.22463989], [92.74091339, 12.22469044], [92.7403717, 12.22518921], [92.74035645, 12.22579956], [92.74035645, 12.22607994], [92.7400589, 12.22604179], [92.7400589, 12.22652721], [92.73976135, 12.22687435], [92.73928833, 12.22685528], [92.73812866, 12.22803116], [92.73812866, 12.22910309], [92.73841858, 12.2290802], [92.73838043, 12.23108101], [92.73871613, 12.23104191], [92.73867798, 12.23160267], [92.73899078, 12.23158455], [92.7389679, 12.23327065], [92.73924255, 12.23330116], [92.73924255, 12.23384094], [92.73951721, 12.23385715], [92.73955536, 12.2344017], [92.73980713, 12.2344017], [92.73980713, 12.23577976], [92.74059296, 12.23572063], [92.74118805, 12.23496437], [92.74118805, 12.23412991], [92.74173737, 12.23357201], [92.74288177, 12.2335701], [92.74289703, 12.23326015], [92.74341583, 12.23326206], [92.74337006, 12.23275375], [92.74313354, 12.23268318], [92.74314117, 12.23243046], [92.74339294, 12.23237991], [92.7434082, 12.23163033], [92.74371338, 12.23133183], [92.74424744, 12.23129082], [92.74452209, 12.23104191], [92.74456024, 12.23050022], [92.74478149, 12.23047924], [92.74478149, 12.22718143], [92.74510193, 12.22716141], [92.74510956, 12.22663689], [92.74563599, 12.22659969], [92.74562836, 12.22801971], [92.74619293, 12.22857094], [92.74619293, 12.22994137], [92.74645996, 12.23022556], [92.74697876, 12.23024178], [92.74697876, 12.23052025], [92.74874115, 12.23050022], [92.74868774, 12.23023129], [92.7492218, 12.2302103], [92.74923706, 12.22994137], [92.74951935, 12.22994137], [92.74951935, 12.22940063], [92.74975586, 12.22941017], [92.75006866, 12.22908401], [92.75006866, 12.22858143], [92.75173187, 12.22856045], [92.75174713, 12.22883129], [92.75233459, 12.22881317], [92.75232697, 12.22939014], [92.75286865, 12.22990036], [92.753479, 12.22995472], [92.75366211, 12.23047924], [92.75418854, 12.23049068], [92.754776, 12.23050022], [92.75508118, 12.22994137], [92.75563049, 12.22994137], [92.75563049, 12.22939014], [92.75587463, 12.22941017], [92.75590515, 12.22856045], [92.75614929, 12.22860146], [92.75616455, 12.2290659], [92.75647736, 12.22939205], [92.7570343, 12.22939205], [92.75695801, 12.22966099], [92.75782013, 12.22972012], [92.75784302, 12.22995472], [92.75922394, 12.2299366], [92.75927734, 12.22939014], [92.75979614, 12.22939205], [92.76010895, 12.22886753], [92.76036072, 12.22887039], [92.76036072, 12.22914124], [92.76150513, 12.22913933], [92.76146698, 12.22937393], [92.76229858, 12.22937393], [92.7622757, 12.22408199], [92.7625885, 12.22408199], [92.7625885, 12.22355747], [92.76224518, 12.22357559], [92.76229858, 12.2230196], [92.7625885, 12.22301006], [92.76255798, 12.22244072], [92.76288605, 12.22244072], [92.76288605, 12.22104073], [92.7631073, 12.22102547], [92.76312256, 12.21992016], [92.7628479, 12.21996117], [92.7628479, 12.21885109], [92.76285553, 12.218297], [92.76261139, 12.21829891], [92.76261139, 12.21299076], [92.76228333, 12.21300316], [92.76229858, 12.21216869], [92.76262665, 12.21219063], [92.76255798, 12.20941067], [92.76283264, 12.20941067], [92.7628479, 12.20887089], [92.76313019, 12.20888233], [92.76313019, 12.20828533], [92.76339722, 12.20830059], [92.76339722, 12.20719147], [92.76395416, 12.20719337], [92.76400757, 12.20665073], [92.76452637, 12.20632267], [92.76451874, 12.20524216], [92.76535034, 12.20440769], [92.76535034, 12.20384979], [92.76590729, 12.20357609], [92.7664566, 12.2030201], [92.7664566, 12.20245934], [92.76701355, 12.2018919], [92.7678299, 12.2018919], [92.76786041, 12.20136547], [92.76811218, 12.20137024], [92.76815796, 12.19882202], [92.76784515, 12.1988287], [92.76786041, 12.19743443], [92.7676239, 12.19743156], [92.76758575, 12.19688892], [92.7670517, 12.19661999], [92.76703644, 12.19609165], [92.76647949, 12.19610977], [92.76644897, 12.19549179], [92.76616669, 12.1954937], [92.76618958, 12.19498634], [92.76590729, 12.19499111], [92.76590729, 12.19419098], [92.76567078, 12.19416142], [92.76565552, 12.19355488], [92.76530457, 12.19355488], [92.76535034, 12.19329739], [92.76535034, 12.19079685], [92.76593018, 12.19026184], [92.766716, 12.19022274], [92.76675415, 12.18942738], [92.7670517, 12.18939114], [92.76698303, 12.18856144], [92.7664566, 12.18828106], [92.76649475, 12.18634605], [92.76618958, 12.18608189], [92.76618958, 12.18496037], [92.76565552, 12.18493271], [92.76567078, 12.18442535], [92.76506042, 12.18385029], [92.76452637, 12.18385029], [92.76454926, 12.18330097], [92.76425171, 12.18332195], [92.76426697, 12.18274021], [92.7636795, 12.1821804], [92.76035309, 12.1821909], [92.7600708, 12.18245983], [92.75952148, 12.18248081], [92.75952148, 12.18273067], [92.75868988, 12.18276978], [92.75868988, 12.1830616], [92.75509644, 12.18302059], [92.75508118, 12.18327141], [92.7545929, 12.18330956], [92.75453186, 12.18275166], [92.75401306, 12.18275166], [92.75370026, 12.18248081], [92.7526474, 12.18242073], [92.75230408, 12.18271065], [92.75228119, 12.18329239], [92.75177002, 12.18327427], [92.75174713, 12.18385315], [92.75119781, 12.18387127], [92.75121307, 12.18363571], [92.75064087, 12.18360043], [92.75064087, 12.1833601], [92.75010681, 12.18330956], [92.7501297, 12.18297958], [92.74925995, 12.18302059], [92.74923706, 12.18245983], [92.74901581, 12.18241215], [92.74897766, 12.1816349], [92.74866486, 12.18161678], [92.74865723, 12.18104935], [92.74814606, 12.18050861], [92.74701691, 12.18047047], [92.74697876, 12.18080139], [92.74648285, 12.18104172], [92.74645233, 12.1816206], [92.74613953, 12.18191147], [92.74536896, 12.18188953], [92.7454071, 12.18216133], [92.74481201, 12.1821804], [92.74446869, 12.18274021], [92.74397278, 12.18274021], [92.74397278, 12.18330097], [92.74370575, 12.18325996], [92.74370575, 12.18382072], [92.74285889, 12.18382072], [92.74287415, 12.18413067], [92.74091339, 12.18413067], [92.74093628, 12.18441963], [92.73925018, 12.18441963], [92.73926544, 12.18467522], [92.73847961, 12.18467522], [92.73814392, 12.18413067], [92.7375946, 12.18413067], [92.73755646, 12.18440247], [92.73590088, 12.18469143], [92.73587799, 12.18521976], [92.73316193, 12.18521976], [92.7328949, 12.18552494], [92.73287964, 12.18634129], [92.73230743, 12.18634129], [92.73234558, 12.18715668], [92.73188782, 12.18745995], [92.73182678, 12.18797112], [92.73203278, 12.18801022], [92.73208618, 12.18855], [92.73181915, 12.18853188], [92.73174286, 12.18916798], [92.73159027, 12.18927479], [92.73165131, 12.19007015], [92.73174286, 12.19026184], [92.73178101, 12.19078064], [92.73201752, 12.19080162], [92.73201752, 12.19163132], [92.73175812, 12.19164944], [92.73178101, 12.19215965], [92.73147583, 12.19215965], [92.7314682, 12.19274139], [92.73118591, 12.19301033], [92.73008728, 12.19301033], [92.73008728, 12.19274139], [92.72926331, 12.19270039], [92.72898102, 12.19244862], [92.72897339, 12.19164944], [92.7284317, 12.19163418], [92.72647858, 12.1896944], [92.72649384, 12.18913078], [92.72592163, 12.18913078], [92.72594452, 12.18885994], [92.72457886, 12.18887997], [92.72454071, 12.188591], [92.72397614, 12.18855]]], [[[92.86646271, 12.23562145], [92.86621094, 12.23551083], [92.86565399, 12.23581219], [92.86508942, 12.23635006], [92.86468506, 12.23694706], [92.86430359, 12.23743343], [92.86392212, 12.23779964], [92.86354828, 12.23812103], [92.86321259, 12.23845577], [92.86293793, 12.23893929], [92.86279297, 12.23962975], [92.86261749, 12.24024105], [92.86250305, 12.24079037], [92.86231995, 12.24129963], [92.86208344, 12.24186993], [92.86165619, 12.24249935], [92.86146545, 12.24302769], [92.86156464, 12.24341297], [92.86165619, 12.24389172], [92.86170959, 12.24449062], [92.86167908, 12.24515438], [92.86170959, 12.24584103], [92.86192322, 12.24650097], [92.86207581, 12.24715137], [92.86224365, 12.24775696], [92.86251831, 12.24827003], [92.86291504, 12.2487278], [92.86339569, 12.24912167], [92.86396027, 12.24945259], [92.86450958, 12.24978256], [92.86506653, 12.25015926], [92.86564636, 12.25063992], [92.86601257, 12.250741], [92.86621857, 12.25058079], [92.86649323, 12.25035954], [92.86686707, 12.25020695], [92.86721802, 12.24999142], [92.86756134, 12.24973106], [92.86789703, 12.24949169], [92.86831665, 12.24929142], [92.86872864, 12.24902153], [92.8690033, 12.2485714], [92.86915588, 12.24800968], [92.86914825, 12.2474308], [92.86903381, 12.24691391], [92.86888123, 12.24646664], [92.86871338, 12.24609089], [92.86860657, 12.24573135], [92.86847687, 12.24535275], [92.86833954, 12.24484921], [92.86820221, 12.24427891], [92.86804199, 12.24375057], [92.86779785, 12.24320984], [92.8675766, 12.24264145], [92.8673172, 12.2422142], [92.86747742, 12.24178123], [92.86760712, 12.2412796], [92.86771393, 12.24078846], [92.86756134, 12.24029064], [92.86750031, 12.23983002], [92.86750031, 12.23941135], [92.86750031, 12.2390213], [92.86745453, 12.23865032], [92.86730194, 12.2383194], [92.86736298, 12.23784065], [92.86738586, 12.23731709], [92.86721039, 12.23685169], [92.86694336, 12.23637104], [92.86662292, 12.23586178], [92.86646271, 12.23562145]]], [[[92.90167236, 12.25584984], [92.90193939, 12.25552177], [92.90215302, 12.25515079], [92.90225983, 12.25471115], [92.90248108, 12.25430107], [92.90271759, 12.25390625], [92.9030304, 12.25354195], [92.90335846, 12.25319958], [92.90376282, 12.25294018], [92.90422821, 12.25275993], [92.90468597, 12.25252056], [92.90509796, 12.25220203], [92.90542603, 12.251791], [92.90569305, 12.25133991], [92.9058075, 12.25082016], [92.90583801, 12.25025082], [92.90589905, 12.24970055], [92.90605164, 12.24920177], [92.90598297, 12.24876881], [92.9058609, 12.24839115], [92.90583801, 12.24803829], [92.90587616, 12.24769974], [92.90610504, 12.24742889], [92.9063797, 12.24715996], [92.90667725, 12.24690533], [92.9070282, 12.24666977], [92.90742493, 12.24647427], [92.90783691, 12.24629879], [92.90813446, 12.24602318], [92.90834045, 12.24568558], [92.90851593, 12.24535275], [92.908638, 12.244977], [92.90880585, 12.24461174], [92.90891266, 12.24414921], [92.90899658, 12.24365044], [92.90917969, 12.24314022], [92.90937805, 12.24264336], [92.90943909, 12.24213505], [92.90944672, 12.24165821], [92.90947723, 12.24123192], [92.90963745, 12.24089336], [92.90975952, 12.24052811], [92.9099884, 12.24023247], [92.91025543, 12.2399416], [92.91052246, 12.2396183], [92.91075897, 12.23923111], [92.91094971, 12.23877525], [92.91116333, 12.23828506], [92.91139984, 12.23777008], [92.91168213, 12.23725986], [92.91192627, 12.23678112], [92.91213226, 12.23632145], [92.9122467, 12.23587608], [92.91240692, 12.2354908], [92.91249847, 12.23506927], [92.91260529, 12.23464108], [92.9128418, 12.23425102], [92.91314697, 12.23388195], [92.91345978, 12.23350143], [92.91374969, 12.23317146], [92.91390991, 12.23281097], [92.91409302, 12.23255062], [92.91416168, 12.23223019], [92.91423798, 12.23190975], [92.91440582, 12.2316103], [92.91442871, 12.23124886], [92.91442871, 12.23085117], [92.91444397, 12.230443], [92.91439819, 12.23004436], [92.91420746, 12.22971821], [92.91413879, 12.22937107], [92.91404724, 12.22907066], [92.91391754, 12.22883129], [92.91385651, 12.2285099], [92.91374969, 12.22818375], [92.91363525, 12.22779655], [92.91359711, 12.22732925], [92.91350555, 12.22685146], [92.91336823, 12.22637653], [92.91333771, 12.22584057], [92.91333008, 12.22528267], [92.91333008, 12.22473145], [92.91333771, 12.22419071], [92.91336823, 12.22367096], [92.91343689, 12.22319984], [92.91327667, 12.22280979], [92.91287994, 12.22267532], [92.91247559, 12.22253418], [92.91160583, 12.222682], [92.91136169, 12.22319031], [92.91165924, 12.22372055], [92.91184998, 12.22411633], [92.91179657, 12.22445488], [92.91171265, 12.22473145], [92.91168213, 12.22498608], [92.91168213, 12.22525978], [92.91160583, 12.22561455], [92.91147614, 12.22613335], [92.91146851, 12.22683525], [92.91162109, 12.22747135], [92.91162109, 12.22804737], [92.91143036, 12.22851467], [92.91134644, 12.22891998], [92.91117859, 12.22922134], [92.911026, 12.22951984], [92.91082001, 12.2298317], [92.91057587, 12.23015118], [92.91031647, 12.23049068], [92.90995026, 12.23074055], [92.90953827, 12.2309103], [92.90920258, 12.23113823], [92.90892029, 12.23134518], [92.90860748, 12.23141956], [92.9083252, 12.23151207], [92.90805817, 12.23148727], [92.9078064, 12.23139095], [92.90756989, 12.23125935], [92.90735626, 12.23099041], [92.90709686, 12.23071194], [92.9068222, 12.23040199], [92.90660095, 12.23001194], [92.90637207, 12.22957039], [92.90583038, 12.22919083], [92.90509796, 12.22920132], [92.90447998, 12.22933006], [92.90397644, 12.22923946], [92.90357971, 12.22896099], [92.90320587, 12.2286396], [92.90283966, 12.2283392], [92.9024353, 12.22808838], [92.9019928, 12.22796059], [92.90149689, 12.22781944], [92.90093994, 12.22785759], [92.90042877, 12.22809982], [92.90001678, 12.22825241], [92.89956665, 12.22842312], [92.8988266, 12.22873974], [92.89820099, 12.22918034], [92.89803314, 12.22966957], [92.89785767, 12.23008537], [92.89774323, 12.23044968], [92.89755249, 12.23067665], [92.89749908, 12.2308321], [92.89722443, 12.2308321], [92.89694214, 12.23110962], [92.89583588, 12.23110962], [92.89554596, 12.23139095], [92.89527893, 12.23139095], [92.89499664, 12.23167133], [92.89499664, 12.23278141], [92.89472198, 12.23278141], [92.89444733, 12.23306084], [92.89416504, 12.23305511], [92.89389038, 12.23333263], [92.89362335, 12.23332977], [92.89305878, 12.23389053], [92.89167023, 12.23389053], [92.89111328, 12.23332977], [92.89058685, 12.23316574], [92.89028168, 12.23275089], [92.88999176, 12.23230171], [92.8897171, 12.23185062], [92.88942719, 12.23141956], [92.88913727, 12.23099041], [92.88878632, 12.23059082], [92.88838196, 12.2302103], [92.88799286, 12.22980022], [92.88757324, 12.22943115], [92.88713837, 12.2290926], [92.88670349, 12.22881126], [92.8862915, 12.22852135], [92.88587952, 12.22824955], [92.88549042, 12.22789001], [92.88504791, 12.22756577], [92.88474274, 12.22709179], [92.88445282, 12.22653198], [92.8841629, 12.22596931], [92.88421631, 12.22530079], [92.88452911, 12.22494984], [92.88484192, 12.22463989], [92.88484192, 12.22445107], [92.88481903, 12.22426605], [92.88469696, 12.22406101], [92.884552, 12.22396088], [92.88427734, 12.2238903], [92.88400269, 12.2239151], [92.8837738, 12.224123], [92.8837204, 12.22441196], [92.88354492, 12.22465801], [92.8833313, 12.22480392], [92.88297272, 12.22462368], [92.88258362, 12.22422981], [92.8824234, 12.22387886], [92.88265228, 12.22359753], [92.88279724, 12.223382], [92.88307953, 12.2232132], [92.88349915, 12.22301006], [92.88397217, 12.22267056], [92.88432312, 12.22214031], [92.88419342, 12.2215023], [92.88373566, 12.22103691], [92.8833313, 12.22056866], [92.88294983, 12.22016144], [92.88261414, 12.21974373], [92.88224792, 12.21934795], [92.88191986, 12.21893978], [92.8815918, 12.21854973], [92.88127136, 12.21818066], [92.88109589, 12.21772957], [92.88092804, 12.21728992], [92.8809433, 12.21687031], [92.88109589, 12.21648121], [92.88127899, 12.21607018], [92.88144684, 12.2156353], [92.88168335, 12.21520042], [92.88185883, 12.21475315], [92.8817749, 12.21426964], [92.88162994, 12.21379089], [92.88143158, 12.21337891], [92.88134003, 12.21298695], [92.88117981, 12.21269035], [92.88105774, 12.21238136], [92.88090515, 12.2121048], [92.88084412, 12.21172428], [92.88079071, 12.21124077], [92.88057709, 12.21071911], [92.88027954, 12.21028137], [92.88027954, 12.21000099], [92.87999725, 12.20972061], [92.87953186, 12.20933342], [92.87944794, 12.20902348], [92.87940216, 12.20871067], [92.87934113, 12.20836163], [92.87923431, 12.2082777], [92.87917328, 12.20832443], [92.87892914, 12.20852184], [92.87889099, 12.20892143], [92.87880707, 12.20926857], [92.87870026, 12.20951557], [92.87850952, 12.20972061], [92.87786102, 12.21062088], [92.87763214, 12.21099472], [92.87751007, 12.21137333], [92.87741852, 12.21171284], [92.8772583, 12.21198177], [92.87718201, 12.21230125], [92.87700653, 12.2126112], [92.87692261, 12.21298885], [92.87677765, 12.21338081], [92.8766861, 12.21382141], [92.87663269, 12.21432495], [92.8764801, 12.21479034], [92.87635803, 12.21527958], [92.87617493, 12.21571541], [92.87610626, 12.21615696], [92.87602997, 12.21656322], [92.87587738, 12.21691132], [92.8757782, 12.21733093], [92.87558746, 12.21770859], [92.87545013, 12.21814919], [92.87528992, 12.21864128], [92.87513733, 12.21916962], [92.87496948, 12.21973133], [92.87477112, 12.22025871], [92.87473297, 12.22081089], [92.87471008, 12.22133064], [92.87464905, 12.22180939], [92.87448883, 12.22224045], [92.87445068, 12.22270012], [92.87444305, 12.22316074], [92.87444305, 12.2235918], [92.87439728, 12.22401142], [92.87423706, 12.22442627], [92.87419128, 12.22487926], [92.87425995, 12.22535133], [92.87441254, 12.225811], [92.87445831, 12.22628975], [92.87451172, 12.22676182], [92.87446594, 12.22723961], [92.87444305, 12.22774029], [92.87439728, 12.22828197], [92.87418365, 12.22878838], [92.87400055, 12.22932053], [92.87380219, 12.22980022], [92.87361145, 12.23017597], [92.87342072, 12.23047924], [92.8732605, 12.23078918], [92.87304688, 12.23108101], [92.87278748, 12.23137856], [92.87250519, 12.2317028], [92.8722229, 12.23204041], [92.87194061, 12.23237133], [92.87166595, 12.23267174], [92.87140656, 12.23294735], [92.87120819, 12.23325062], [92.87107849, 12.2335968], [92.87088013, 12.23388195], [92.87082672, 12.23423958], [92.87077332, 12.23458195], [92.8706131, 12.23487759], [92.8705368, 12.23522186], [92.8704071, 12.23555946], [92.87030029, 12.23589039], [92.87026978, 12.2362318], [92.87021637, 12.23653698], [92.87006378, 12.23681259], [92.86997223, 12.23717308], [92.86981964, 12.23758125], [92.86973572, 12.23806858], [92.86972046, 12.23860168], [92.86972046, 12.23913956], [92.86976624, 12.23965931], [92.86994934, 12.24013996], [92.87000275, 12.24063015], [92.87000275, 12.24112701], [92.87001038, 12.241642], [92.87008667, 12.24215126], [92.87023926, 12.24264145], [92.87032318, 12.24316502], [92.87051392, 12.24364281], [92.8706131, 12.24419308], [92.87084198, 12.24469185], [92.87110901, 12.24519062], [92.87138367, 12.2456789], [92.87166595, 12.24619102], [92.87197876, 12.24674129], [92.8723526, 12.24724007], [92.87277222, 12.24776173], [92.87322235, 12.24821091], [92.873703, 12.24856186], [92.87419891, 12.24880123], [92.87482452, 12.2488327], [92.87534332, 12.24884224], [92.87575531, 12.24870968], [92.87621307, 12.2485733], [92.87667084, 12.24837303], [92.87718201, 12.24829102], [92.87767029, 12.24810123], [92.87818146, 12.24806309], [92.8786087, 12.24805641], [92.8786087, 12.24722195], [92.87889099, 12.24694443], [92.87889099, 12.24666786], [92.87944794, 12.24611187], [92.87944794, 12.24361229], [92.8797226, 12.24333286], [92.87966156, 12.24304199], [92.87948608, 12.24268436], [92.87949371, 12.24228954], [92.87967682, 12.24187946], [92.87970734, 12.24143028], [92.8797226, 12.24099064], [92.8797226, 12.24055481], [92.87999725, 12.2402792], [92.87999725, 12.2397213], [92.88083649, 12.23888874], [92.88111115, 12.23889065], [92.8813858, 12.23916721], [92.8813858, 12.23944473], [92.88124847, 12.24001503], [92.881073, 12.24096107], [92.8811264, 12.24108887], [92.88136292, 12.2412138], [92.88152313, 12.24132061], [92.88162994, 12.24129105], [92.88173676, 12.2411499], [92.88183594, 12.24094009], [92.88196564, 12.24073792], [92.88208771, 12.24063015], [92.88227844, 12.24057102], [92.88253021, 12.24053001], [92.88272095, 12.24051189], [92.88292694, 12.24051189], [92.88310242, 12.24011135], [92.88312531, 12.23992634], [92.88324738, 12.2397604], [92.883461, 12.23978043], [92.88358307, 12.23990345], [92.88391876, 12.24028206], [92.88406372, 12.24007702], [92.8841095, 12.23983002], [92.8841095, 12.23962116], [92.88419342, 12.23935223], [92.88446045, 12.23924923], [92.88463593, 12.23954773], [92.88471222, 12.23999214], [92.88477325, 12.24055958], [92.88495636, 12.24117088], [92.88503265, 12.24175644], [92.88514709, 12.24221039], [92.88526154, 12.24257946], [92.88532257, 12.24291039], [92.88542175, 12.24320126], [92.88552856, 12.24349976], [92.88555908, 12.24386024], [92.88559723, 12.24424267], [92.88577271, 12.24460125], [92.88582611, 12.2449789], [92.88580322, 12.24537086], [92.88565063, 12.24577045], [92.88556671, 12.24621201], [92.88555145, 12.24669075], [92.88551331, 12.24720097], [92.88532257, 12.24770927], [92.88532257, 12.24829102], [92.88555908, 12.24888515], [92.88585663, 12.24948025], [92.88625336, 12.25001144], [92.88661957, 12.25053978], [92.88695526, 12.25110817], [92.88732147, 12.25160027], [92.88774872, 12.25199604], [92.88821411, 12.25233364], [92.88882446, 12.25252342], [92.88943481, 12.25269222], [92.8900528, 12.25259113], [92.89063263, 12.25274181], [92.89118195, 12.25280094], [92.89165497, 12.25291729], [92.89206696, 12.25306129], [92.89241028, 12.2532568], [92.89266205, 12.25351429], [92.89285278, 12.25383282], [92.8928299, 12.25454235], [92.89306641, 12.25504398], [92.89363098, 12.25519371], [92.89391327, 12.25536537], [92.89427948, 12.25528145], [92.89470673, 12.25555038], [92.89524078, 12.25577068], [92.89582825, 12.25583172], [92.89639282, 12.25584126], [92.89686584, 12.25584126], [92.89703369, 12.25583744], [92.89722443, 12.25583458], [92.89861298, 12.25583458], [92.8989563, 12.2561264], [92.89942169, 12.2562294], [92.89993286, 12.25636101], [92.90034485, 12.2563839], [92.90048218, 12.25639057], [92.90099335, 12.25634956], [92.90136719, 12.25613976], [92.90167236, 12.25584984]]], [[[92.67346191, 11.48752022], [92.673172, 11.48735619], [92.67259216, 11.48733044], [92.67193604, 11.48736], [92.67124176, 11.48728943], [92.67061615, 11.48756123], [92.67047882, 11.48790932], [92.67019653, 11.48880959], [92.67125702, 11.48890972], [92.67158508, 11.4890604], [92.67197418, 11.48911285], [92.67235565, 11.48898697], [92.67271423, 11.48868942], [92.67312622, 11.48828125], [92.67344666, 11.48775864], [92.67346191, 11.48752022]]], [[[92.61048889, 11.50405025], [92.61021423, 11.50392723], [92.60980988, 11.50407982], [92.60941315, 11.50423908], [92.60904694, 11.50475025], [92.60913086, 11.50521946], [92.60916901, 11.50562096], [92.60925293, 11.50597191], [92.60943604, 11.50627899], [92.60964203, 11.50660133], [92.60983276, 11.50701141], [92.6100769, 11.50732994], [92.61032104, 11.50774002], [92.61068726, 11.50804996], [92.61109924, 11.5083456], [92.61147308, 11.50866985], [92.61186981, 11.50896168], [92.61219788, 11.50933075], [92.61248016, 11.50977993], [92.61277771, 11.5102396], [92.61322021, 11.51062107], [92.61382294, 11.51085091], [92.61445618, 11.51111126], [92.61508942, 11.51139069], [92.61563873, 11.51160145], [92.61599731, 11.51149178], [92.61625671, 11.51129818], [92.61634827, 11.51101112], [92.61619568, 11.51066208], [92.61591339, 11.51026821], [92.61561584, 11.50987053], [92.61533356, 11.50951576], [92.61500549, 11.50922394], [92.61468506, 11.50892258], [92.61431885, 11.50861454], [92.61389923, 11.50828457], [92.61348724, 11.50791073], [92.61312103, 11.50750256], [92.6128006, 11.50710011], [92.61252594, 11.50670147], [92.61225891, 11.50631142], [92.61212158, 11.50584221], [92.61197662, 11.50534916], [92.61167908, 11.50494957], [92.61138153, 11.50458431], [92.61104584, 11.50424576], [92.61048889, 11.50405025]]], [[[92.64444733, 11.51303005], [92.6440506, 11.51303005], [92.64382172, 11.51316738], [92.64368439, 11.51330566], [92.64369202, 11.51372147], [92.64389038, 11.51418972], [92.6440506, 11.51447964], [92.64444733, 11.51502037], [92.64473724, 11.51516056], [92.64512634, 11.51557064], [92.64567566, 11.51539612], [92.64607239, 11.51494026], [92.64615631, 11.51453018], [92.64610291, 11.51428127], [92.6460495, 11.51405144], [92.64559937, 11.51379108], [92.64524078, 11.51357746], [92.6452179, 11.51344013], [92.6450119, 11.51316738], [92.64480591, 11.51310062], [92.64444733, 11.51303005]]], [[[92.62797546, 11.54216194], [92.62741852, 11.54216194], [92.62706757, 11.54271126], [92.62679291, 11.54326725], [92.62664795, 11.54402637], [92.62671661, 11.54478073], [92.6269989, 11.54540539], [92.62706757, 11.54630089], [92.62721252, 11.54747677], [92.62713623, 11.54837036], [92.62713623, 11.54858017], [92.62734985, 11.54899025], [92.6277771, 11.54916954], [92.62827301, 11.54924107], [92.62889099, 11.54896069], [92.62957764, 11.54854107], [92.6297226, 11.54749966], [92.6297226, 11.54721928], [92.6297226, 11.54666805], [92.62944794, 11.54638958], [92.62944794, 11.54361057], [92.62923431, 11.54278183], [92.62916565, 11.54257679], [92.62876129, 11.54230118], [92.62797546, 11.54216194]]], [[[92.6046524, 11.53458214], [92.6046524, 11.53430557], [92.60520935, 11.53430557], [92.60520935, 11.53458214], [92.60548401, 11.53485966], [92.60575867, 11.5348053], [92.60610962, 11.53452873], [92.60639191, 11.53446102], [92.60624695, 11.53399086], [92.60624695, 11.5335598], [92.60646057, 11.53321648], [92.60646057, 11.53100967], [92.6065979, 11.52997112], [92.60666656, 11.52893829], [92.60666656, 11.52832127], [92.60674286, 11.52811146], [92.60681152, 11.52783489], [92.60688019, 11.52707577], [92.60681152, 11.5261097], [92.60681152, 11.52396965], [92.6065979, 11.52349091], [92.6065979, 11.52307034], [92.60652924, 11.52238369], [92.60646057, 11.52190018], [92.60631561, 11.52190018], [92.60603333, 11.52208042], [92.60542297, 11.52259064], [92.60507202, 11.52279568], [92.6046524, 11.52313995], [92.60409546, 11.52348709], [92.60340118, 11.52362347], [92.60256195, 11.52383137], [92.60188293, 11.52429962], [92.60187531, 11.52680492], [92.60159302, 11.52708054], [92.60187531, 11.52735901], [92.60188293, 11.52930069], [92.60131836, 11.52986145], [92.60076141, 11.53013706], [92.60076141, 11.53097057], [92.60131836, 11.53125191], [92.60131836, 11.53236198], [92.60103607, 11.53263664], [92.60103607, 11.53319359], [92.60076141, 11.5334692], [92.60103607, 11.53374958], [92.60103607, 11.53458214], [92.60131836, 11.53485966], [92.60131836, 11.53569412], [92.60159302, 11.53597164], [92.60159302, 11.53707886], [92.60243225, 11.53791618], [92.60243225, 11.5381937], [92.60298157, 11.5381937], [92.60353851, 11.53763771], [92.60353851, 11.53736019], [92.6038208, 11.53707886], [92.6038208, 11.53680611], [92.60410309, 11.53652954], [92.60410309, 11.53625202], [92.60437012, 11.53597164], [92.60437012, 11.53485966], [92.6046524, 11.53458214]]], [[[92.61000061, 11.55888939], [92.6102066, 11.5587492], [92.61076355, 11.55937195], [92.61166382, 11.56069374], [92.61194611, 11.56097221], [92.61266327, 11.56097221], [92.61328888, 11.56075668], [92.61342621, 11.56033134], [92.61357117, 11.56027412], [92.61412811, 11.56020641], [92.61448669, 11.55972004], [92.61468506, 11.55923939], [92.61469269, 11.55807018], [92.61448669, 11.55751038], [92.61483002, 11.55716991], [92.61546326, 11.55709934], [92.61594391, 11.5568943], [92.61672974, 11.55665016], [92.61699677, 11.55707169], [92.61699677, 11.55724144], [92.61699677, 11.5577898], [92.61734009, 11.55799961], [92.61741638, 11.55862045], [92.61734009, 11.55903244], [92.61712646, 11.55910015], [92.61706543, 11.55944729], [92.61734009, 11.55958366], [92.61811066, 11.55979061], [92.61839294, 11.56007099], [92.61853027, 11.56007099], [92.61882019, 11.55985928], [92.61908722, 11.5595789], [92.61909485, 11.55930328], [92.61930847, 11.55888939], [92.62020874, 11.55764198], [92.62020874, 11.55733013], [92.6202774, 11.55609035], [92.6202774, 11.55416203], [92.62020874, 11.55360985], [92.62020874, 11.55278015], [92.62020874, 11.55179977], [92.61992645, 11.55152702], [92.61992645, 11.55097103], [92.61965179, 11.5506897], [92.61965179, 11.54986095], [92.61936951, 11.54958057], [92.61936951, 11.54902744], [92.6194458, 11.54891014], [92.61923218, 11.54822445], [92.61930084, 11.54739475], [92.61930084, 11.54635143], [92.61923218, 11.54580879], [92.61936951, 11.54520035], [92.61923218, 11.54380989], [92.61923218, 11.54325962], [92.61908722, 11.5425806], [92.61908722, 11.54236031], [92.6185379, 11.54207993], [92.6185379, 11.54069424], [92.61826324, 11.54041576], [92.6180191, 11.54020023], [92.61797333, 11.53985977], [92.61797333, 11.53903008], [92.61736298, 11.5381918], [92.6177063, 11.53763771], [92.6177063, 11.53681087], [92.61631775, 11.53542042], [92.61519623, 11.53485012], [92.61437225, 11.53458214], [92.61437225, 11.53430557], [92.61381531, 11.53374958], [92.61325836, 11.5334692], [92.61159515, 11.53319359], [92.61083221, 11.53208447], [92.61048126, 11.53180599], [92.6102066, 11.5318718], [92.6102066, 11.53264046], [92.60993195, 11.53291512], [92.60993195, 11.53319073], [92.60958099, 11.53374958], [92.60964966, 11.53402805], [92.60964966, 11.5342989], [92.6085434, 11.53541565], [92.6074295, 11.53597164], [92.6074295, 11.53625202], [92.60714722, 11.53652954], [92.60714722, 11.53680611], [92.60687256, 11.53707886], [92.60687256, 11.53736019], [92.60674286, 11.53771114], [92.60687256, 11.53791618], [92.60687256, 11.53847027], [92.6065979, 11.53874969], [92.6065979, 11.53902817], [92.60631561, 11.53930378], [92.60632324, 11.54207993], [92.60603333, 11.54236031], [92.60604095, 11.5429163], [92.60575867, 11.54319], [92.60575867, 11.5437479], [92.60547638, 11.54402161], [92.60548401, 11.54652596], [92.60575867, 11.54679108], [92.60575867, 11.54736137], [92.60603333, 11.5476408], [92.60603333, 11.54875088], [92.60575867, 11.54903126], [92.60575867, 11.54930496], [92.60547638, 11.54958057], [92.60548401, 11.54986095], [92.6046524, 11.55069256], [92.60410309, 11.55097103], [92.60409546, 11.55152702], [92.6038208, 11.55180454], [92.60243225, 11.55208111], [92.60243225, 11.55236053], [92.60214996, 11.55264091], [92.60214996, 11.55291462], [92.60159302, 11.55347061], [92.60188293, 11.55375099], [92.60188293, 11.5551424], [92.60230255, 11.55521011], [92.60299683, 11.55538082], [92.60353851, 11.5551424], [92.60492706, 11.55402946], [92.60507202, 11.55381966], [92.60547638, 11.55389023], [92.6057663, 11.55492973], [92.60679626, 11.55500031], [92.60714722, 11.55458069], [92.60714722, 11.55430508], [92.6074295, 11.55402946], [92.60778046, 11.55389023], [92.60887146, 11.55381966], [92.60993195, 11.55395889], [92.61000061, 11.55506039], [92.60993195, 11.55569267], [92.60909271, 11.5559597], [92.6085434, 11.55625153], [92.60826111, 11.55652714], [92.60770416, 11.55680466], [92.60769653, 11.55708122], [92.6074295, 11.55736065], [92.6074295, 11.55764198], [92.60714722, 11.55791473], [92.60714722, 11.55819321], [92.60687256, 11.55847073], [92.60714722, 11.5587492], [92.60714722, 11.559021], [92.60604095, 11.5601368], [92.60603333, 11.56096935], [92.60575867, 11.56124973], [92.60632324, 11.56180096], [92.60632324, 11.56209087], [92.60687256, 11.56264019], [92.60687256, 11.5629158], [92.60714722, 11.56319427], [92.60798645, 11.56319427], [92.60826111, 11.5629158], [92.60826111, 11.56264019], [92.6085434, 11.56235981], [92.6085434, 11.56124973], [92.60909271, 11.56096935], [92.60964966, 11.56041622], [92.60964966, 11.55985928], [92.60993195, 11.5595789], [92.61000061, 11.55888939]]], [[[92.59718323, 11.54166985], [92.59697723, 11.54127979], [92.59694672, 11.54085064], [92.59694672, 11.54042053], [92.59693909, 11.53998089], [92.59687042, 11.53952026], [92.59670258, 11.53900146], [92.59662628, 11.53840065], [92.59645844, 11.53781986], [92.5963974, 11.53724098], [92.59638214, 11.53670311], [92.59631348, 11.53622723], [92.59613037, 11.53585052], [92.59600067, 11.53543186], [92.59583282, 11.53499222], [92.59566498, 11.53455639], [92.59571075, 11.53353119], [92.59571075, 11.53312111], [92.5955658, 11.53284264], [92.59529114, 11.53263092], [92.59494781, 11.53270054], [92.59467316, 11.5329113], [92.59459686, 11.53345966], [92.59459686, 11.53394318], [92.59461212, 11.53429222], [92.59386444, 11.53448582], [92.59329224, 11.53479099], [92.59291077, 11.53514004], [92.59292603, 11.53560925], [92.59294128, 11.5360899], [92.59285736, 11.53623199], [92.5925827, 11.53629971], [92.59172821, 11.53573036], [92.59152985, 11.53559971], [92.59114838, 11.53543186], [92.59079742, 11.53523254], [92.59049988, 11.53499603], [92.59023285, 11.5347414], [92.58995819, 11.53468037], [92.58969116, 11.53448105], [92.58943176, 11.53410721], [92.58920288, 11.53379059], [92.58898926, 11.53367043], [92.58844757, 11.5334692], [92.58808899, 11.53348064], [92.58760071, 11.53349209], [92.58751678, 11.53417969], [92.58756256, 11.53485012], [92.58766937, 11.53528118], [92.58790588, 11.5357008], [92.58779907, 11.53627014], [92.5878067, 11.53661919], [92.58782196, 11.53715038], [92.58776855, 11.53764725], [92.58778381, 11.5381422], [92.58777618, 11.5385952], [92.58773041, 11.53898335], [92.58753204, 11.53928089], [92.58731079, 11.53963375], [92.58706665, 11.5400629], [92.58646393, 11.54089165], [92.58631897, 11.54103088], [92.58596802, 11.54103088], [92.58583069, 11.54089165], [92.58596802, 11.54041195], [92.58596802, 11.54000092], [92.58611298, 11.53944111], [92.58611298, 11.5391674], [92.58583069, 11.53889084], [92.58583069, 11.53861141], [92.58555603, 11.53833294], [92.58555603, 11.53777695], [92.58528137, 11.53750134], [92.58528137, 11.53693962], [92.58499908, 11.53666687], [92.58499908, 11.53639126], [92.5847168, 11.53611088], [92.58429718, 11.53507233], [92.58416748, 11.53444004], [92.58361816, 11.53444004], [92.58319855, 11.53534985], [92.58304596, 11.53611088], [92.58319092, 11.53707886], [92.58326721, 11.53944302], [92.58304596, 11.53972054], [92.58304596, 11.54000092], [92.58305359, 11.54027653], [92.58333588, 11.54083347], [92.58444214, 11.54194546], [92.58472443, 11.54194546], [92.58499908, 11.54166698], [92.58528137, 11.54194546], [92.58555603, 11.54194546], [92.58580017, 11.54156303], [92.58600616, 11.54163074], [92.58621979, 11.541852], [92.58628845, 11.54298019], [92.58634949, 11.54348183], [92.5861969, 11.54397202], [92.58615112, 11.54443932], [92.58609772, 11.54487228], [92.58599854, 11.54524136], [92.58584595, 11.54556179], [92.58579254, 11.54587936], [92.5856781, 11.54613018], [92.58557129, 11.54640293], [92.58551788, 11.54673195], [92.5853653, 11.54700279], [92.58525848, 11.54728127], [92.5851059, 11.54752922], [92.58496094, 11.54780102], [92.58474731, 11.54805088], [92.58455658, 11.54837894], [92.58441925, 11.54880142], [92.58421326, 11.54922962], [92.58416748, 11.54975128], [92.58422089, 11.55030537], [92.58439636, 11.55088043], [92.58447266, 11.55153561], [92.58467865, 11.55215073], [92.58500671, 11.55264091], [92.58540344, 11.55296707], [92.58584595, 11.55309963], [92.58620453, 11.55334091], [92.586586, 11.55350113], [92.58677673, 11.55401993], [92.58702087, 11.55443954], [92.58722687, 11.55483246], [92.58746338, 11.55515099], [92.58758545, 11.55549526], [92.58774567, 11.55581379], [92.58782196, 11.55618095], [92.58805847, 11.55654144], [92.58828735, 11.55702019], [92.5880127, 11.55751038], [92.58795166, 11.55797005], [92.58792877, 11.55847073], [92.58811951, 11.55896091], [92.58833313, 11.5593853], [92.58854675, 11.55979347], [92.58869934, 11.56010056], [92.58911133, 11.56058025], [92.58925629, 11.56101036], [92.58937836, 11.56140041], [92.58937836, 11.56175995], [92.58930206, 11.56216145], [92.58924103, 11.56240082], [92.58893585, 11.5626812], [92.58888245, 11.56304073], [92.58879852, 11.56340122], [92.58863831, 11.56371117], [92.58854675, 11.56406403], [92.58837128, 11.56437397], [92.58828735, 11.56472969], [92.58808899, 11.56503105], [92.58805847, 11.5654211], [92.58805847, 11.5658474], [92.5880127, 11.56630516], [92.587883, 11.56676483], [92.58791351, 11.56737137], [92.58798218, 11.56769466], [92.58798218, 11.56822205], [92.58798981, 11.56861115], [92.58795929, 11.56907177], [92.5880127, 11.56950474], [92.58805847, 11.56993294], [92.58807373, 11.57032299], [92.58816528, 11.57065296], [92.58830261, 11.570961], [92.58837128, 11.57137585], [92.58857727, 11.57173061], [92.58870697, 11.57217789], [92.58887482, 11.57260227], [92.58900452, 11.5730238], [92.58914185, 11.57339954], [92.5892334, 11.57377625], [92.58940125, 11.57408142], [92.5894928, 11.57444954], [92.58972168, 11.57473087], [92.58998108, 11.57505035], [92.590271, 11.57538891], [92.59055328, 11.57576084], [92.5908432, 11.57610989], [92.59115601, 11.57639027], [92.59146881, 11.57666969], [92.59179688, 11.57695103], [92.59213257, 11.5772171], [92.59243774, 11.57739258], [92.5925293, 11.57734966], [92.59268188, 11.57727718], [92.59288788, 11.57697105], [92.59303284, 11.57664108], [92.59310913, 11.57628059], [92.59327698, 11.57594109], [92.59336853, 11.57554245], [92.59354401, 11.57514286], [92.59360504, 11.57464027], [92.59364319, 11.57408619], [92.59379578, 11.57356167], [92.59393311, 11.57304192], [92.5941391, 11.57261086], [92.59425354, 11.57216358], [92.59442902, 11.57179546], [92.59456635, 11.57141018], [92.59469604, 11.57100201], [92.59468842, 11.57054424], [92.59451294, 11.57004547], [92.59435272, 11.56945038], [92.59414673, 11.56881046], [92.59388733, 11.56815529], [92.59333038, 11.567132], [92.59355927, 11.56662369], [92.59429932, 11.56618404], [92.59487915, 11.56580639], [92.59538269, 11.56544971], [92.59581757, 11.56509018], [92.59619141, 11.56471634], [92.59649658, 11.56431103], [92.59671021, 11.56386185], [92.59690857, 11.56343079], [92.59699249, 11.56298447], [92.59716797, 11.56260586], [92.59722137, 11.56219101], [92.59722137, 11.56175995], [92.59725189, 11.5613203], [92.59737396, 11.56089878], [92.59725189, 11.56052017], [92.59707642, 11.56013966], [92.59702301, 11.55977058], [92.59693909, 11.55939007], [92.59707642, 11.55891132], [92.59726715, 11.5584898], [92.59732056, 11.55796814], [92.59749603, 11.55731964], [92.59750366, 11.55663204], [92.5973587, 11.55594158], [92.59738922, 11.55527782], [92.59723663, 11.55468082], [92.5970993, 11.55405045], [92.59676361, 11.55343723], [92.59680176, 11.55278969], [92.59694672, 11.5521307], [92.59697723, 11.55150032], [92.59712219, 11.5509119], [92.59721375, 11.55034161], [92.59722137, 11.54980183], [92.59722137, 11.54930687], [92.59722137, 11.54885101], [92.59722137, 11.54841137], [92.59722137, 11.54796886], [92.59722137, 11.5475111], [92.59722137, 11.54704762], [92.59722137, 11.54658127], [92.59726715, 11.54613686], [92.59745789, 11.54576111], [92.59749603, 11.54535007], [92.59749603, 11.54493999], [92.59749603, 11.54452991], [92.59749603, 11.54413128], [92.59749603, 11.54371166], [92.59749603, 11.54329872], [92.59744263, 11.54290009], [92.59725952, 11.54251957], [92.59722137, 11.54209995], [92.59718323, 11.54166985]]], [[[92.5745163, 11.56257153], [92.57367706, 11.56257153], [92.57367706, 11.56284714], [92.5734024, 11.56312466], [92.5734024, 11.56340122], [92.57284546, 11.56395721], [92.57285309, 11.56562138], [92.57367706, 11.56645775], [92.57367706, 11.56701088], [92.57588959, 11.56923962], [92.57588959, 11.56952095], [92.57604218, 11.56999683], [92.5761795, 11.57090187], [92.57701111, 11.57090187], [92.57701111, 11.56895828], [92.57673645, 11.56867981], [92.57673645, 11.56840229], [92.57562256, 11.56729221], [92.57590485, 11.56701374], [92.57590485, 11.56673622], [92.57562256, 11.56645966], [92.57562256, 11.56617928], [92.5753479, 11.5658989], [92.57562256, 11.56562328], [92.57562256, 11.56479073], [92.5753479, 11.56451321], [92.5753479, 11.56423473], [92.57507324, 11.56396198], [92.57507324, 11.5636816], [92.57479095, 11.56340122], [92.57479095, 11.56312466], [92.5745163, 11.56284714], [92.5745163, 11.56257153]]], [[[92.62509918, 11.42097092], [92.62497711, 11.4215889], [92.62483978, 11.42210197], [92.62471771, 11.42247772], [92.62459564, 11.42276287], [92.62447357, 11.42302227], [92.62444305, 11.4233799], [92.62444305, 11.42381954], [92.62444305, 11.42431927], [92.62444305, 11.42485046], [92.62444305, 11.42541122], [92.6244278, 11.42595959], [92.62432861, 11.42650032], [92.62419128, 11.42704964], [92.62413788, 11.4276104], [92.62393951, 11.42811203], [92.62380981, 11.42859936], [92.62364197, 11.42908001], [92.62354279, 11.42961788], [92.62332916, 11.43007183], [92.62309265, 11.43046093], [92.62296295, 11.43078136], [92.62280273, 11.43097019], [92.62274933, 11.43109131], [92.62245178, 11.43146038], [92.62213898, 11.43146038], [92.62188721, 11.43124962], [92.62164307, 11.43109131], [92.62137604, 11.43094921], [92.6211319, 11.43074036], [92.62088776, 11.43052959], [92.6203537, 11.43013573], [92.61971283, 11.43041134], [92.61981964, 11.4315424], [92.62000275, 11.43212128], [92.62023163, 11.43266964], [92.62024689, 11.4335289], [92.62032318, 11.43395996], [92.62031555, 11.4340992], [92.61997223, 11.43457985], [92.61997223, 11.43500233], [92.62004089, 11.43554592], [92.62024689, 11.43575382], [92.62052917, 11.43582439], [92.62129974, 11.43582439], [92.62171173, 11.43568516], [92.62178802, 11.43556023], [92.62198639, 11.43506145], [92.62199402, 11.43465137], [92.62164307, 11.43444061], [92.62108612, 11.4340992], [92.62101746, 11.43375015], [92.62115479, 11.43360901], [92.62168884, 11.43343067], [92.62220764, 11.43346977], [92.62252808, 11.4335413], [92.62274933, 11.43366814], [92.62291718, 11.43387985], [92.62307739, 11.43414021], [92.62328339, 11.43441105], [92.62345886, 11.43470764], [92.62356567, 11.43500233], [92.6235199, 11.43527985], [92.62335205, 11.43556881], [92.62312317, 11.43591118], [92.62281799, 11.43636036], [92.62255859, 11.43694973], [92.62259674, 11.43758202], [92.62278748, 11.43819046], [92.62304688, 11.43873024], [92.62328339, 11.43922043], [92.62345123, 11.43968964], [92.62359619, 11.44009972], [92.62364197, 11.44046879], [92.62358856, 11.44078064], [92.62341309, 11.44102955], [92.62316895, 11.44127083], [92.62290955, 11.44153976], [92.622612, 11.44178677], [92.62226868, 11.44180489], [92.62190247, 11.4416914], [92.621521, 11.44166088], [92.62114716, 11.44166088], [92.62077332, 11.4417181], [92.6204834, 11.44198036], [92.62026978, 11.44240189], [92.62011719, 11.44283867], [92.62024689, 11.44331074], [92.62026215, 11.4437809], [92.62017059, 11.44419956], [92.62000275, 11.44458961], [92.61978912, 11.44494057], [92.61959076, 11.44528484], [92.61937714, 11.44559002], [92.61910248, 11.44587135], [92.61882782, 11.44618797], [92.61859894, 11.44658184], [92.61833954, 11.44697189], [92.61805725, 11.44731998], [92.61778259, 11.44765091], [92.61750031, 11.44798088], [92.61720276, 11.44832993], [92.61686707, 11.44868088], [92.61650848, 11.44906807], [92.61618042, 11.44954014], [92.61585999, 11.45007133], [92.61557007, 11.4506197], [92.61527252, 11.4511404], [92.61501312, 11.45158005], [92.61472321, 11.45194912], [92.61448669, 11.45227146], [92.61431885, 11.45261669], [92.61414337, 11.45294094], [92.61395264, 11.45324802], [92.61384583, 11.45359039], [92.61367035, 11.45387268], [92.61360168, 11.45416737], [92.61351013, 11.454422], [92.61338043, 11.45464993], [92.61328888, 11.4549284], [92.61312103, 11.45519924], [92.61297607, 11.45556164], [92.6128006, 11.45589447], [92.61260223, 11.45621109], [92.61235046, 11.45657063], [92.61207581, 11.4567194], [92.6115799, 11.45736027], [92.6113205, 11.45786572], [92.61106873, 11.45863247], [92.61139679, 11.45905972], [92.6114502, 11.45947933], [92.61161804, 11.46023178], [92.61167145, 11.46093082], [92.61168671, 11.46157169], [92.61174011, 11.46217632], [92.61194611, 11.46272945], [92.61218262, 11.4633112], [92.61231232, 11.46392059], [92.61251068, 11.46441078], [92.61271667, 11.46483994], [92.61277771, 11.4652977], [92.61283112, 11.46576977], [92.61296844, 11.46623039], [92.61303711, 11.46673203], [92.61310577, 11.46724033], [92.61325073, 11.46774101], [92.61331177, 11.46825027], [92.61334229, 11.46877098], [92.61335754, 11.46930027], [92.61340332, 11.46983624], [92.61335754, 11.47041035], [92.61334229, 11.47103024], [92.61334229, 11.47164059], [92.6133728, 11.47217178], [92.61353302, 11.47257996], [92.61360168, 11.47296143], [92.61360168, 11.47332954], [92.61360168, 11.47373104], [92.6136322, 11.47418022], [92.61373138, 11.47464657], [92.61387634, 11.4750824], [92.61398315, 11.47546291], [92.61412048, 11.47576237], [92.61416626, 11.47608089], [92.61421967, 11.47639275], [92.61437988, 11.47665024], [92.61447906, 11.47701263], [92.61457825, 11.47747993], [92.61461639, 11.47817135], [92.61473846, 11.47885036], [92.61490631, 11.47947025], [92.6150589, 11.48015118], [92.61515808, 11.48088074], [92.61524963, 11.48160076], [92.61539459, 11.48231602], [92.61559296, 11.48289967], [92.61586761, 11.48338985], [92.61588287, 11.48384094], [92.6160202, 11.48419857], [92.61617279, 11.48467064], [92.6162796, 11.48513985], [92.61670685, 11.48569202], [92.61723328, 11.48595238], [92.61750793, 11.48616123], [92.61785889, 11.48678112], [92.61792755, 11.48726177], [92.61792755, 11.4880867], [92.61807251, 11.48905087], [92.6182785, 11.48960972], [92.61841583, 11.49022675], [92.61849213, 11.49125957], [92.61862183, 11.49168968], [92.61891174, 11.49209785], [92.61914825, 11.49244022], [92.61933899, 11.49279118], [92.61953735, 11.4931612], [92.61980438, 11.49354553], [92.62008667, 11.49393272], [92.62026978, 11.4943552], [92.62037659, 11.49471855], [92.62052917, 11.4949789], [92.62057495, 11.49522781], [92.62056732, 11.4955101], [92.62056732, 11.49584103], [92.62055969, 11.49619198], [92.62056732, 11.49659061], [92.6206131, 11.49702072], [92.62078094, 11.49742699], [92.62098694, 11.49780083], [92.62117004, 11.4981966], [92.62139893, 11.49860096], [92.62166595, 11.49905014], [92.6219635, 11.49956894], [92.62230682, 11.50007057], [92.62266541, 11.50051975], [92.62303925, 11.50087261], [92.62341309, 11.50117397], [92.62387848, 11.50140381], [92.62436676, 11.50170326], [92.62484741, 11.50207424], [92.62532043, 11.50244999], [92.62577057, 11.50276947], [92.62614441, 11.50302219], [92.62647247, 11.50316429], [92.62664032, 11.5033102], [92.62709808, 11.50373077], [92.6271286, 11.50417137], [92.62724304, 11.50471973], [92.62750244, 11.50521946], [92.62771606, 11.50573921], [92.62800598, 11.50609016], [92.62841797, 11.50681496], [92.62874603, 11.50731182], [92.62888336, 11.50765133], [92.62909698, 11.50801563], [92.62915802, 11.50846863], [92.62919617, 11.50899124], [92.62934875, 11.50949097], [92.62948608, 11.51000977], [92.6297226, 11.51046753], [92.62999725, 11.51091003], [92.63027954, 11.51137066], [92.63056946, 11.51181126], [92.63150787, 11.51242065], [92.63178253, 11.51283169], [92.63178253, 11.51352024], [92.63170624, 11.51385975], [92.63179016, 11.51416016], [92.63198853, 11.51449108], [92.63241577, 11.51476669], [92.63275146, 11.51501274], [92.6330719, 11.51524067], [92.633461, 11.51540947], [92.63385773, 11.51557064], [92.63423157, 11.51578999], [92.63461304, 11.51601601], [92.63500214, 11.51635265], [92.63545227, 11.51682472], [92.63598633, 11.51728344], [92.63639832, 11.51718712], [92.63667297, 11.51686954], [92.63689423, 11.51649666], [92.63698578, 11.51606083], [92.63717651, 11.51570129], [92.6373291, 11.51533222], [92.63754272, 11.51503086], [92.63775635, 11.51475143], [92.63796234, 11.51445198], [92.63816071, 11.51414871], [92.63831329, 11.51379108], [92.63838196, 11.51336288], [92.63861084, 11.51299763], [92.63887787, 11.51264], [92.63912964, 11.51226044], [92.63929749, 11.51188374], [92.63970184, 11.51161003], [92.64015961, 11.51115036], [92.64063263, 11.51069164], [92.6410675, 11.51035023], [92.6414566, 11.51014042], [92.64185333, 11.51005077], [92.64222717, 11.51007175], [92.64261627, 11.51006889], [92.64295959, 11.51003075], [92.64319611, 11.5100193], [92.64344025, 11.51012039], [92.64367676, 11.51034069], [92.64389038, 11.5106163], [92.64405823, 11.51101971], [92.64440155, 11.51131821], [92.64487457, 11.51137257], [92.64530182, 11.51130486], [92.64566803, 11.51118565], [92.64594269, 11.51104927], [92.64601898, 11.5107851], [92.64595032, 11.51034737], [92.64586639, 11.50984192], [92.64585876, 11.50938988], [92.64588165, 11.50903034], [92.64591217, 11.5086813], [92.64594269, 11.5082798], [92.64595795, 11.50782204], [92.64594269, 11.50732136], [92.64588165, 11.50681019], [92.64576721, 11.50631142], [92.64566803, 11.50578022], [92.64559937, 11.50520992], [92.64554596, 11.50463104], [92.64550781, 11.50408745], [92.64541626, 11.50360966], [92.64537811, 11.50316143], [92.64533234, 11.50270081], [92.64530182, 11.50222015], [92.64530945, 11.50175953], [92.64537048, 11.50137711], [92.64549255, 11.50108147], [92.64565277, 11.50080013], [92.64589691, 11.50057697], [92.64621735, 11.50039005], [92.64660645, 11.50024033], [92.64698792, 11.50013161], [92.64731598, 11.50005531], [92.6476059, 11.4999361], [92.64789581, 11.49977016], [92.64821625, 11.49956036], [92.64861298, 11.49934196], [92.6490097, 11.49908161], [92.6493988, 11.49880791], [92.6497879, 11.49851036], [92.6502533, 11.4982996], [92.65066528, 11.49805832], [92.65101624, 11.49775124], [92.65120697, 11.49720097], [92.65164948, 11.49682999], [92.65211487, 11.49649906], [92.65261841, 11.49619198], [92.65312195, 11.49594116], [92.65355682, 11.4957428], [92.65390778, 11.49555111], [92.65421295, 11.49536037], [92.65455627, 11.49518204], [92.65505219, 11.49501991], [92.65551758, 11.49479008], [92.65584564, 11.49448872], [92.65605164, 11.49416065], [92.65628052, 11.49383068], [92.65661621, 11.49363041], [92.65692139, 11.49341965], [92.65719604, 11.49315071], [92.65753937, 11.49279976], [92.6579895, 11.49250221], [92.65846252, 11.49221516], [92.6588974, 11.49193192], [92.6592865, 11.49166107], [92.65963745, 11.49142647], [92.66001892, 11.49131203], [92.66044617, 11.49124146], [92.66091156, 11.49112988], [92.66142273, 11.49104118], [92.66194916, 11.49087906], [92.6624527, 11.49079037], [92.66287994, 11.49063969], [92.66327667, 11.49057102], [92.66364288, 11.49061012], [92.6639328, 11.49081993], [92.66422272, 11.49110889], [92.66452789, 11.49142647], [92.66496277, 11.49163055], [92.66545868, 11.4917202], [92.66602325, 11.49164009], [92.66658783, 11.49143982], [92.66710663, 11.49110031], [92.66762543, 11.49073315], [92.66817474, 11.49039555], [92.66858673, 11.48996067], [92.66877747, 11.48941612], [92.66876221, 11.48877144], [92.66893768, 11.48814869], [92.66924286, 11.4875927], [92.66953278, 11.48712063], [92.66985321, 11.48680401], [92.67009735, 11.48653126], [92.67030334, 11.4862318], [92.67043304, 11.48589039], [92.67043304, 11.48544979], [92.67038727, 11.484972], [92.67048645, 11.48447037], [92.670578, 11.48396015], [92.6707077, 11.48346138], [92.67081451, 11.48291111], [92.6708374, 11.48233032], [92.6708374, 11.48173141], [92.67080688, 11.48112202], [92.67067719, 11.48053646], [92.67060852, 11.47997093], [92.6708374, 11.47941017], [92.67108154, 11.47887325], [92.67134857, 11.47833729], [92.67162323, 11.4778204], [92.67185974, 11.47733402], [92.67218018, 11.47698307], [92.67249298, 11.47667122], [92.67277527, 11.47635555], [92.67302704, 11.47601891], [92.6732254, 11.47565365], [92.67337036, 11.47526932], [92.67360687, 11.47495937], [92.67385864, 11.47462654], [92.67411804, 11.47422791], [92.67447662, 11.47387028], [92.67492676, 11.47360992], [92.67533875, 11.47336197], [92.67572784, 11.47312927], [92.6760025, 11.47283077], [92.67629242, 11.47255039], [92.67649078, 11.4721899], [92.6769104, 11.47187996], [92.67729187, 11.47151089], [92.67740631, 11.4709301], [92.67726135, 11.47022057], [92.67713928, 11.46951199], [92.67701721, 11.46884727], [92.67698669, 11.46818066], [92.67676544, 11.46778011], [92.676651, 11.46741104], [92.67663574, 11.46694374], [92.67643738, 11.46646023], [92.67649078, 11.46592045], [92.67652893, 11.46539593], [92.67623901, 11.46488094], [92.6761322, 11.46434975], [92.67610931, 11.46380997], [92.67607117, 11.4633112], [92.67588806, 11.46289825], [92.67582703, 11.46250153], [92.6758728, 11.46210003], [92.67607117, 11.46171093], [92.6765213, 11.46138], [92.67698669, 11.46123028], [92.67751312, 11.46086121], [92.67767334, 11.46018124], [92.67764282, 11.45934963], [92.67747498, 11.45872974], [92.67801666, 11.45833111], [92.67839813, 11.45799065], [92.67853546, 11.45740128], [92.67890167, 11.45694256], [92.67935181, 11.45664406], [92.67971802, 11.45636368], [92.68001556, 11.45614719], [92.68013, 11.45599174], [92.68016052, 11.4556303], [92.68016052, 11.4550209], [92.6800766, 11.45471096], [92.67978668, 11.45433998], [92.6795578, 11.45399094], [92.67952728, 11.45363998], [92.67945862, 11.45321178], [92.67978668, 11.45279026], [92.68029022, 11.45223045], [92.68035126, 11.45173264], [92.68060303, 11.451231], [92.68079376, 11.45093727], [92.6810379, 11.45045185], [92.6809082, 11.4499979], [92.68107605, 11.44948959], [92.68136597, 11.44901085], [92.68157959, 11.44855976], [92.68158722, 11.44806576], [92.68180084, 11.44772053], [92.68190765, 11.44742966], [92.68186951, 11.44714928], [92.68177795, 11.44690323], [92.6815567, 11.4464817], [92.68173981, 11.44600105], [92.68229675, 11.44597054], [92.68274689, 11.44572735], [92.6831665, 11.44537163], [92.68341827, 11.44479275], [92.68370056, 11.44419956], [92.68402863, 11.44362068], [92.68434143, 11.44305134], [92.68456268, 11.4425106], [92.68466187, 11.44204617], [92.68447876, 11.44166088], [92.68430328, 11.44149017], [92.68386841, 11.44118881], [92.68386078, 11.44081974], [92.68409729, 11.44032097], [92.68440247, 11.44005203], [92.68469238, 11.4396944], [92.6847229, 11.43929958], [92.68504333, 11.43882084], [92.685112, 11.43839073], [92.68519592, 11.4379797], [92.6852951, 11.43760204], [92.68538666, 11.43733978], [92.68546295, 11.43712139], [92.68579102, 11.43661118], [92.68572998, 11.43611145], [92.68556976, 11.43552971], [92.68543243, 11.43490124], [92.68535614, 11.43436146], [92.68528748, 11.43388939], [92.68506622, 11.43325996], [92.68453217, 11.43282032], [92.68418121, 11.43246937], [92.68371582, 11.43221188], [92.68319702, 11.4321003], [92.68262482, 11.43190193], [92.68210602, 11.43184853], [92.6816864, 11.43172169], [92.68138885, 11.43155956], [92.68123627, 11.43129253], [92.68122864, 11.43088055], [92.68132782, 11.43039989], [92.68144226, 11.42996025], [92.68154907, 11.42958164], [92.68165588, 11.42925072], [92.68183899, 11.42895985], [92.68209839, 11.42872047], [92.68229675, 11.42851067], [92.68274689, 11.42813015], [92.68312836, 11.42784023], [92.68356323, 11.42765999], [92.68379211, 11.4273777], [92.68383789, 11.4270792], [92.68373871, 11.42680073], [92.68350983, 11.42649078], [92.68314362, 11.42623138], [92.68273926, 11.4260807], [92.68235779, 11.4260006], [92.68173981, 11.42558384], [92.68123627, 11.42577267], [92.68121338, 11.42634106], [92.68107605, 11.42720032], [92.68074799, 11.42746925], [92.68035889, 11.42784023], [92.68017578, 11.42807102], [92.68006134, 11.42822075], [92.67980957, 11.42817116], [92.67938995, 11.42809963], [92.67897797, 11.42792034], [92.6786499, 11.42778778], [92.67830658, 11.42772198], [92.67796326, 11.42753124], [92.67753601, 11.42741203], [92.67711639, 11.42723179], [92.67670441, 11.42708397], [92.67634583, 11.42689037], [92.67605591, 11.4267149], [92.67572021, 11.42679024], [92.6753006, 11.42694283], [92.67485046, 11.42709064], [92.67440033, 11.4272089], [92.67394257, 11.42723179], [92.67352295, 11.4272213], [92.67312622, 11.42714119], [92.67276001, 11.42693996], [92.67238617, 11.42671013], [92.67218018, 11.42640018], [92.67194366, 11.42613792], [92.67173767, 11.42588043], [92.67167664, 11.42558193], [92.67173004, 11.42523956], [92.67191315, 11.42485046], [92.67198944, 11.42439175], [92.67222595, 11.42397976], [92.67249298, 11.42359734], [92.6727829, 11.42323017], [92.67305756, 11.42287922], [92.67333984, 11.42254066], [92.67362976, 11.42221069], [92.67393494, 11.42193317], [92.67420197, 11.42163181], [92.67444611, 11.42131519], [92.6746521, 11.42097092], [92.67468262, 11.42056084], [92.67449188, 11.42013168], [92.67444611, 11.41967201], [92.67443085, 11.41923046], [92.67433929, 11.41878986], [92.67415619, 11.41834831], [92.67386627, 11.41785145], [92.67346191, 11.41734695], [92.67298889, 11.41687775], [92.67253113, 11.41643143], [92.67221069, 11.41598034], [92.67189789, 11.41574097], [92.67145538, 11.41568089], [92.67111969, 11.41543293], [92.67064667, 11.41533947], [92.67025757, 11.4151907], [92.6699295, 11.4151001], [92.66944122, 11.41496086], [92.66904449, 11.41487026], [92.66864014, 11.41471004], [92.6682663, 11.41453266], [92.6678009, 11.41441631], [92.66732788, 11.41421127], [92.66678619, 11.41412926], [92.66627502, 11.41394901], [92.66573334, 11.41384029], [92.66527557, 11.41364574], [92.66481781, 11.41357136], [92.6644516, 11.41337872], [92.66403198, 11.41329956], [92.66365814, 11.41312885], [92.66325378, 11.41302395], [92.66291046, 11.41284847], [92.6625824, 11.41267109], [92.66215515, 11.41257858], [92.66169739, 11.41251278], [92.66122437, 11.41250038], [92.66079712, 11.41245174], [92.66047668, 11.4121809], [92.66007233, 11.41197109], [92.65970612, 11.41187954], [92.6592865, 11.41172028], [92.65854645, 11.41176319], [92.65818787, 11.41163826], [92.65797424, 11.41156292], [92.65749359, 11.41124153], [92.65701294, 11.41092014], [92.65667725, 11.41073132], [92.65648651, 11.41047287], [92.65618896, 11.41036034], [92.65563965, 11.41010189], [92.6550827, 11.40966034], [92.65441895, 11.40972137], [92.65383911, 11.40968037], [92.65331268, 11.40958214], [92.65280914, 11.40944767], [92.65229797, 11.40929985], [92.65181732, 11.40908337], [92.65136719, 11.4087801], [92.65091705, 11.40841103], [92.65039063, 11.40807819], [92.64987946, 11.40777969], [92.64949036, 11.40751457], [92.6493454, 11.40724754], [92.64958954, 11.40696144], [92.64990997, 11.40692043], [92.6504364, 11.40692043], [92.65094757, 11.40727139], [92.65136719, 11.40725994], [92.65180969, 11.40722084], [92.65219116, 11.40722084], [92.65255737, 11.40722561], [92.6529007, 11.40724182], [92.65327454, 11.40727615], [92.65371704, 11.40734196], [92.65422058, 11.4076519], [92.65480804, 11.40777969], [92.6556015, 11.4076519], [92.65596008, 11.40738773], [92.65624237, 11.40717125], [92.65653992, 11.40694141], [92.65679169, 11.4069109], [92.65718842, 11.40680027], [92.65753937, 11.40680027], [92.65797424, 11.40681458], [92.65836334, 11.40682697], [92.65854645, 11.40683365], [92.65912628, 11.40676498], [92.6595993, 11.40666008], [92.65997314, 11.40665627], [92.66033936, 11.4063797], [92.66082764, 11.40612888], [92.66098022, 11.40563011], [92.66043091, 11.40528202], [92.66031647, 11.40431786], [92.66033173, 11.40380001], [92.66043091, 11.40334225], [92.66052246, 11.40299797], [92.66073608, 11.40273952], [92.66104126, 11.40253067], [92.66140747, 11.40236664], [92.66179657, 11.4022913], [92.66221619, 11.40225887], [92.66259766, 11.40223026], [92.66295624, 11.40216064], [92.66327667, 11.40203762], [92.66372681, 11.40207005], [92.66394806, 11.40186119], [92.66387939, 11.40147114], [92.66351318, 11.40105247], [92.66308594, 11.40065956], [92.66272736, 11.40032005], [92.66248322, 11.39992142], [92.662323, 11.39951992], [92.66221619, 11.39913177], [92.66216278, 11.39875031], [92.66220093, 11.39837074], [92.66227722, 11.39799118], [92.6623764, 11.39756203], [92.66246796, 11.39704037], [92.66266632, 11.39654064], [92.66294861, 11.39605999], [92.66330719, 11.39564323], [92.66369629, 11.39528084], [92.66414642, 11.39499092], [92.66470337, 11.39480019], [92.66526031, 11.39473057], [92.66582489, 11.39482498], [92.66641235, 11.39488411], [92.66685486, 11.39501381], [92.6672287, 11.39536953], [92.66760254, 11.39557934], [92.6678772, 11.39566135], [92.66851044, 11.39568043], [92.66913605, 11.39560223], [92.66970062, 11.39569283], [92.67007446, 11.39593315], [92.67056274, 11.39616108], [92.67119598, 11.39640903], [92.67164612, 11.39665985], [92.67201996, 11.39712048], [92.67222595, 11.39762783], [92.67198944, 11.39828014], [92.67177582, 11.39848995], [92.67178345, 11.39862728], [92.67198944, 11.3989706], [92.67240906, 11.39925098], [92.67269135, 11.39932156], [92.672966, 11.39932156], [92.67356873, 11.39898014], [92.67399597, 11.39903927], [92.67443085, 11.39910316], [92.67481232, 11.39914608], [92.67507935, 11.39912605], [92.67514801, 11.39910316], [92.6754303, 11.39901161], [92.67560577, 11.3987999], [92.6756897, 11.39855957], [92.6756897, 11.39829445], [92.67570496, 11.39797688], [92.67578888, 11.39763069], [92.67591095, 11.39727974], [92.67605591, 11.39695072], [92.6762085, 11.39663029], [92.67640686, 11.39629269], [92.676651, 11.39587975], [92.67682648, 11.39545155], [92.67691803, 11.39506245], [92.67712402, 11.39453316], [92.67741394, 11.39395428], [92.67774963, 11.39339066], [92.67811584, 11.39287186], [92.6784668, 11.39241791], [92.67896271, 11.39211273], [92.67948151, 11.39192104], [92.67996979, 11.39173031], [92.68045044, 11.39159107], [92.68089294, 11.39141273], [92.68132019, 11.39125824], [92.68165588, 11.39105129], [92.68196869, 11.39084053], [92.68225098, 11.39062023], [92.68254852, 11.3903904], [92.6829071, 11.39017105], [92.68336487, 11.39002991], [92.68389893, 11.39002991], [92.68447876, 11.39013386], [92.685112, 11.39024162], [92.68570709, 11.39028263], [92.6862793, 11.39033031], [92.68678284, 11.39048958], [92.68733978, 11.39064693], [92.68795776, 11.39082527], [92.68862152, 11.39116192], [92.68886566, 11.39088726], [92.68895721, 11.39040089], [92.68891907, 11.38992882], [92.68895721, 11.38945103], [92.68916321, 11.38901138], [92.68917084, 11.38860512], [92.68920135, 11.38822174], [92.68934631, 11.38785076], [92.6894989, 11.38742924], [92.68977356, 11.38713074], [92.69011688, 11.38698006], [92.69049835, 11.38699245], [92.69081879, 11.38716698], [92.69116974, 11.38726044], [92.69145203, 11.38744068], [92.69174957, 11.38759136], [92.69204712, 11.3877821], [92.69239044, 11.38793278], [92.69287872, 11.38781166], [92.69348145, 11.38741779], [92.69393921, 11.38695145], [92.69387054, 11.38656139], [92.6934433, 11.38654709], [92.69319153, 11.38628006], [92.69261169, 11.3860836], [92.69245911, 11.38566971], [92.69230652, 11.38518047], [92.69158173, 11.38509083], [92.69119263, 11.38483143], [92.69095612, 11.38414001], [92.69065094, 11.3836298], [92.69049835, 11.38298035], [92.69031525, 11.38232613], [92.69020844, 11.38162041], [92.69037628, 11.38092041], [92.69049835, 11.38023186], [92.69090271, 11.37967968], [92.69126129, 11.37915421], [92.69130707, 11.37844467], [92.69156647, 11.37782001], [92.69182587, 11.37730122], [92.69178772, 11.37687206], [92.69181061, 11.3765707], [92.69165039, 11.37630463], [92.69165039, 11.37593269], [92.69172668, 11.3754797], [92.6917572, 11.37495136], [92.69153595, 11.37447453], [92.69126892, 11.37403488], [92.69104004, 11.37361813], [92.69082642, 11.37321186], [92.69062805, 11.37280178], [92.69055176, 11.37232971], [92.6905365, 11.37183952], [92.69077301, 11.37132931], [92.69095612, 11.37084389], [92.69087219, 11.37034035], [92.69061279, 11.36990929], [92.69007111, 11.36965942], [92.68952942, 11.36942196], [92.68901825, 11.36917591], [92.68852997, 11.36894989], [92.68810272, 11.36883068], [92.68780518, 11.36862946], [92.68759918, 11.3684206], [92.68743896, 11.36822128], [92.68723297, 11.36803055], [92.68700409, 11.36779213], [92.68673706, 11.36749363], [92.68645477, 11.36714268], [92.6860199, 11.36693954], [92.68551636, 11.36680984], [92.68498993, 11.36670494], [92.68444824, 11.36648178], [92.68383789, 11.36636066], [92.68334961, 11.36656094], [92.68292999, 11.36675072], [92.68251801, 11.36678028], [92.68237305, 11.36669827], [92.68225098, 11.3666296], [92.68193817, 11.366436], [92.68167114, 11.3663702], [92.6812973, 11.36633301], [92.68077087, 11.3663168], [92.68045044, 11.36603928], [92.68022919, 11.36565018], [92.68015289, 11.3651619], [92.68048096, 11.36472893], [92.680336, 11.36431026], [92.67982483, 11.36397743], [92.67941284, 11.36361027], [92.67900848, 11.36324978], [92.6784668, 11.36298084], [92.6778717, 11.36276436], [92.67730713, 11.36255169], [92.67681122, 11.36241055], [92.67632294, 11.36239147], [92.67581177, 11.36240387], [92.67525482, 11.36226082], [92.67463684, 11.36216927], [92.67405701, 11.36213112], [92.67370605, 11.36258888], [92.67350006, 11.36300087], [92.67329407, 11.36306953], [92.67308044, 11.36314011], [92.67209625, 11.36293125], [92.67160797, 11.36293316], [92.67063141, 11.36272621], [92.66924286, 11.36216927], [92.66860962, 11.3620348], [92.66794586, 11.3612709], [92.66761017, 11.36108017], [92.66729736, 11.36083794], [92.66696167, 11.3608408], [92.66632843, 11.36038017], [92.66629791, 11.35973263], [92.66634369, 11.35926819], [92.6661377, 11.35888958], [92.6659317, 11.35854053], [92.66561127, 11.35815144], [92.66533661, 11.35789204], [92.66506958, 11.35742188], [92.66487885, 11.35694981], [92.66483307, 11.35623169], [92.664711, 11.35560131], [92.6648941, 11.35507011], [92.66483307, 11.35470963], [92.66487885, 11.35450459], [92.66483307, 11.35391045], [92.66490173, 11.3532238], [92.66490173, 11.35260391], [92.66448212, 11.35218906], [92.66433716, 11.35218906], [92.66399384, 11.35267162], [92.66371155, 11.3532896], [92.66371918, 11.35353565], [92.66329956, 11.35367966], [92.66278839, 11.3537302], [92.66253662, 11.35394859], [92.66226196, 11.35426998], [92.66197968, 11.35470963], [92.66160583, 11.3550396], [92.66130066, 11.35519123], [92.66075134, 11.35533905], [92.66031647, 11.35555458], [92.65981293, 11.35573101], [92.65922546, 11.35585594], [92.65864563, 11.35604954], [92.65804291, 11.35615921], [92.6574707, 11.35639191], [92.65688324, 11.35663986], [92.65621185, 11.35682869], [92.65545654, 11.35698032], [92.6546936, 11.35718727], [92.65390778, 11.35722446], [92.65315247, 11.35717773], [92.65248108, 11.35713005], [92.6517868, 11.3570118], [92.65112305, 11.35688019], [92.65036774, 11.35663986], [92.64981079, 11.35639191], [92.64924622, 11.3563509], [92.64884186, 11.35611153], [92.64848328, 11.35585403], [92.64810944, 11.35562229], [92.64774323, 11.35545063], [92.64740753, 11.35516071], [92.64684296, 11.35474396], [92.64640808, 11.35438633], [92.64594269, 11.35387993], [92.64543915, 11.35342884], [92.64494324, 11.35306931], [92.6444397, 11.35276985], [92.64398193, 11.3524189], [92.64360809, 11.351964], [92.64225006, 11.35130024], [92.64126587, 11.35068035], [92.64057159, 11.35013103], [92.63994598, 11.34965038], [92.63965607, 11.34902096], [92.6394577, 11.34840107], [92.63903809, 11.34798622], [92.63868713, 11.34729958], [92.63861847, 11.34703064], [92.63842773, 11.34652138], [92.63799286, 11.34627724], [92.63743591, 11.34622002], [92.63689423, 11.34646606], [92.63643646, 11.34687042], [92.63595581, 11.3472414], [92.63555908, 11.34759045], [92.63514709, 11.34790039], [92.63465881, 11.34807968], [92.6341629, 11.34829044], [92.63359833, 11.34834194], [92.63304138, 11.34838772], [92.63256073, 11.3485899], [92.63207245, 11.3487606], [92.63156891, 11.34889793], [92.63109589, 11.34905148], [92.63059998, 11.34915066], [92.63007355, 11.34916687], [92.62950134, 11.3492012], [92.62892914, 11.34938145], [92.6282959, 11.34943962], [92.6276474, 11.34945202], [92.6269989, 11.34941959], [92.62635803, 11.34926033], [92.62573242, 11.34904194], [92.62523651, 11.34865189], [92.62477875, 11.34823036], [92.62445068, 11.34779263], [92.62420654, 11.34755802], [92.62384033, 11.34745121], [92.62355804, 11.34737968], [92.62298584, 11.34724998], [92.62255859, 11.34725857], [92.62207031, 11.3472414], [92.62139893, 11.34784985], [92.62069702, 11.34839916], [92.62020874, 11.34887981], [92.61985779, 11.34908962], [92.61956787, 11.34916019], [92.61868286, 11.34916019], [92.61797333, 11.34908962], [92.61749268, 11.34908962], [92.61657715, 11.34895039], [92.61483002, 11.34861088], [92.6133728, 11.34840107], [92.61260223, 11.34834194], [92.61218262, 11.34778118], [92.61218262, 11.34743023], [92.61210632, 11.34701824], [92.61183167, 11.34681034], [92.61154938, 11.34667397], [92.61050415, 11.3466053], [92.61001587, 11.34619045], [92.60890961, 11.34579182], [92.60843658, 11.34583282], [92.60792542, 11.34583473], [92.60739899, 11.34583473], [92.60688782, 11.34582996], [92.60521698, 11.3461113], [92.60468292, 11.34624958], [92.60426331, 11.34624958], [92.60367584, 11.34618092], [92.60307312, 11.34622002], [92.60251617, 11.3463316], [92.60192108, 11.34613991], [92.60134888, 11.34630203], [92.60079193, 11.34640026], [92.60029602, 11.34652138], [92.59983063, 11.34665489], [92.59937286, 11.3467598], [92.5989151, 11.34693813], [92.59845734, 11.34711361], [92.59809113, 11.34733009], [92.59780884, 11.34756947], [92.59758759, 11.34779739], [92.59737396, 11.34802341], [92.59707642, 11.34817791], [92.59667969, 11.34834194], [92.59622192, 11.34848976], [92.59571838, 11.34855175], [92.59516144, 11.34859943], [92.59455872, 11.34865189], [92.59404755, 11.34916019], [92.59355164, 11.34954071], [92.59282684, 11.34982109], [92.59250641, 11.35032654], [92.59222412, 11.35075092], [92.59192657, 11.35109138], [92.59156036, 11.35140133], [92.59107208, 11.35170078], [92.59050751, 11.3524189], [92.58986664, 11.35311031], [92.58946228, 11.35352039], [92.58869171, 11.35409164], [92.58862305, 11.35453033], [92.58842468, 11.35507011], [92.58803558, 11.35543156], [92.58757782, 11.3557806], [92.58701324, 11.35676098], [92.58686066, 11.35723972], [92.58631134, 11.35766125], [92.58622742, 11.35821056], [92.5860672, 11.35896969], [92.58610535, 11.35942459], [92.58598328, 11.35979462], [92.58582306, 11.36013889], [92.58557892, 11.36046028], [92.58530426, 11.36079979], [92.5849762, 11.36116028], [92.58468628, 11.36161995], [92.58435059, 11.36205959], [92.58399963, 11.36250019], [92.58370972, 11.36290073], [92.58358765, 11.36326981], [92.5834198, 11.3635416], [92.58328247, 11.36379719], [92.58310699, 11.36402035], [92.58300018, 11.36431885], [92.58280945, 11.36457157], [92.5826416, 11.36486053], [92.58250427, 11.36514568], [92.58236694, 11.36538982], [92.58220673, 11.36557007], [92.58204651, 11.36575031], [92.58189392, 11.36602974], [92.58154297, 11.36626053], [92.58120728, 11.36667061], [92.58113861, 11.36748886], [92.58107758, 11.36824989], [92.58100891, 11.3689909], [92.58117676, 11.36968231], [92.58152771, 11.37026024], [92.58193207, 11.37080097], [92.58242798, 11.37127018], [92.58304596, 11.37166214], [92.58368683, 11.37203121], [92.58433533, 11.37240696], [92.58495331, 11.37281132], [92.58553314, 11.37324238], [92.58620453, 11.37333012], [92.58686829, 11.37337589], [92.58747864, 11.37357426], [92.58808136, 11.37366104], [92.58850861, 11.37389755], [92.58885193, 11.37415791], [92.58914185, 11.37443066], [92.5893631, 11.3747406], [92.58953094, 11.37508106], [92.58972168, 11.37541962], [92.58991241, 11.37575054], [92.59008789, 11.37609005], [92.59030151, 11.37640953], [92.59056091, 11.37673759], [92.59082794, 11.37711143], [92.59106445, 11.37755108], [92.59126282, 11.37802124], [92.59146881, 11.3784399], [92.59166718, 11.37884998], [92.59185028, 11.3792038], [92.59197998, 11.37954998], [92.59216309, 11.37984943], [92.59226227, 11.38021088], [92.59246063, 11.38057995], [92.59246063, 11.38099098], [92.59221649, 11.38140106], [92.59222412, 11.38238525], [92.59222412, 11.38321495], [92.59208679, 11.38390255], [92.59179688, 11.38452053], [92.59179688, 11.38501072], [92.59166718, 11.38556004], [92.59144592, 11.38666058], [92.59107971, 11.38718128], [92.59111023, 11.38772106], [92.59106445, 11.38814735], [92.59092712, 11.38848019], [92.59085846, 11.38882637], [92.59083557, 11.389184], [92.59080505, 11.38952446], [92.59072113, 11.38981056], [92.59060669, 11.39006233], [92.59056091, 11.39036179], [92.59049988, 11.39066982], [92.59037018, 11.39096165], [92.59030151, 11.39126492], [92.59028625, 11.39157486], [92.59027863, 11.39186859], [92.59024811, 11.39213085], [92.5901413, 11.39237022], [92.59003448, 11.39263916], [92.58998108, 11.39297199], [92.58986664, 11.39332962], [92.58975983, 11.3937006], [92.58966827, 11.39409065], [92.5894928, 11.39446926], [92.58940125, 11.3949213], [92.58924103, 11.39540577], [92.58912659, 11.39591026], [92.58894348, 11.39635944], [92.58882141, 11.39677429], [92.58868408, 11.39710236], [92.58861542, 11.39745045], [92.58852386, 11.39780426], [92.58827972, 11.39810467], [92.58796692, 11.39840126], [92.58761597, 11.3987112], [92.58730316, 11.3991394], [92.58706665, 11.39975929], [92.5871048, 11.40047932], [92.5874176, 11.40098953], [92.58785248, 11.40125179], [92.58837128, 11.40121078], [92.58891296, 11.40112019], [92.58947754, 11.40103054], [92.59007263, 11.40088272], [92.59069824, 11.40085125], [92.59130859, 11.40089035], [92.59184265, 11.40105247], [92.59230042, 11.40109921], [92.59252167, 11.40107155], [92.59269714, 11.40105247], [92.5930481, 11.40088081], [92.59342194, 11.40074158], [92.59384155, 11.40061188], [92.59430695, 11.40051079], [92.59477234, 11.40034008], [92.59520721, 11.40028095], [92.59562683, 11.40023994], [92.5960083, 11.40018082], [92.5963974, 11.40023994], [92.59680939, 11.40027046], [92.59723663, 11.40028095], [92.59767151, 11.40028095], [92.59807587, 11.40028095], [92.59846497, 11.40027714], [92.59884644, 11.40029335], [92.59922028, 11.40036106], [92.59958649, 11.4005909], [92.59989166, 11.40083027], [92.6003418, 11.40091896], [92.60076904, 11.40117168], [92.60147858, 11.40125179], [92.60202789, 11.40109921], [92.60243225, 11.40078926], [92.60295105, 11.40082073], [92.60356903, 11.4008007], [92.60421753, 11.40088081], [92.60475159, 11.40088463], [92.60527039, 11.40086174], [92.6057663, 11.40088081], [92.60623169, 11.40111065], [92.60669708, 11.40137959], [92.60720825, 11.40161037], [92.60787201, 11.40165997], [92.60853577, 11.40167809], [92.60917664, 11.40172386], [92.60968018, 11.401824], [92.60980988, 11.40185165], [92.61006165, 11.40176487], [92.61032104, 11.40168095], [92.61081696, 11.40147781], [92.61127472, 11.40122032], [92.61170197, 11.40095139], [92.61212921, 11.40077591], [92.61248016, 11.4005909], [92.612854, 11.40055466], [92.61321259, 11.40052032], [92.61354065, 11.40036964], [92.61387634, 11.40029907], [92.61425018, 11.40036964], [92.61467743, 11.40054989], [92.6151886, 11.4007206], [92.61577606, 11.40082073], [92.6164093, 11.40088654], [92.61691284, 11.40111065], [92.61734009, 11.401371], [92.6177597, 11.40152073], [92.61811829, 11.40168285], [92.61842346, 11.40187168], [92.61876678, 11.40199471], [92.61907196, 11.40219975], [92.61943817, 11.40242958], [92.61979675, 11.40273952], [92.62023163, 11.40304756], [92.62071991, 11.40333271], [92.62120056, 11.40361118], [92.62166595, 11.40389061], [92.62210083, 11.40419006], [92.62245941, 11.40454292], [92.62271881, 11.40493965], [92.62294769, 11.40533161], [92.62308502, 11.40573978], [92.62329102, 11.40609074], [92.6234436, 11.40649414], [92.62362671, 11.40690231], [92.62385559, 11.40727425], [92.62393188, 11.40768242], [92.62395477, 11.40798664], [92.62409973, 11.40843105], [92.62435913, 11.40895557], [92.6244812, 11.40942287], [92.62445831, 11.40981007], [92.6244278, 11.41019821], [92.6243515, 11.41058064], [92.62414551, 11.41102695], [92.62381744, 11.41152191], [92.62386322, 11.4119482], [92.62388611, 11.41240215], [92.62388611, 11.41287136], [92.62388611, 11.41332912], [92.62387848, 11.41376019], [92.62384033, 11.41416836], [92.62380981, 11.41455078], [92.623909, 11.41502857], [92.62412262, 11.41559887], [92.62431335, 11.41615963], [92.62445831, 11.4167366], [92.62454224, 11.41729927], [92.62508392, 11.41937828], [92.62525177, 11.41982174], [92.62525177, 11.42039013], [92.62509918, 11.42097092]]], [[[92.56035614, 11.53799057], [92.56051636, 11.53758144], [92.56054688, 11.53711128], [92.56054688, 11.53660965], [92.56054688, 11.53606129], [92.5605545, 11.53551769], [92.56060028, 11.53495979], [92.56057739, 11.5344038], [92.56050873, 11.53379345], [92.56079102, 11.53304958], [92.56125641, 11.53264046], [92.5615921, 11.53217697], [92.56189728, 11.5317297], [92.56230164, 11.53139114], [92.56273651, 11.5311079], [92.56318665, 11.53083038], [92.56369019, 11.53058434], [92.56425476, 11.53045177], [92.56481934, 11.53029919], [92.56536865, 11.53018093], [92.56577301, 11.52983189], [92.56598663, 11.52948093], [92.56632233, 11.52909088], [92.56680298, 11.52862167], [92.56735992, 11.52831173], [92.56783295, 11.52814102], [92.56830597, 11.52803993], [92.56873322, 11.52775574], [92.56906128, 11.5273819], [92.56915283, 11.52690506], [92.56912231, 11.52639866], [92.56893158, 11.52593708], [92.5688858, 11.52544022], [92.56880188, 11.52496147], [92.56873322, 11.52451038], [92.56858063, 11.52411079], [92.56852722, 11.52367783], [92.56838226, 11.52326965], [92.56835175, 11.52291012], [92.56819916, 11.52249146], [92.56804657, 11.52202129], [92.56791687, 11.52152157], [92.56778717, 11.52101612], [92.56770325, 11.52050114], [92.56754303, 11.51999092], [92.56750488, 11.51940918], [92.56745911, 11.51882076], [92.56723785, 11.51828098], [92.56703186, 11.51777077], [92.56681061, 11.51730061], [92.56643677, 11.51698875], [92.56595612, 11.51686954], [92.56541443, 11.51692295], [92.56522369, 11.51694298], [92.564888, 11.51698017], [92.56434631, 11.51695919], [92.563797, 11.51684284], [92.5630188, 11.51674271], [92.56259918, 11.51669884], [92.56186676, 11.51655102], [92.56149292, 11.51675034], [92.56149292, 11.51723003], [92.56138611, 11.51778698], [92.56131744, 11.51839066], [92.56082916, 11.51896], [92.56063843, 11.51946163], [92.5606308, 11.52008247], [92.5605545, 11.52057934], [92.56043243, 11.5209589], [92.56021881, 11.52128029], [92.5598526, 11.52151108], [92.55938721, 11.52171993], [92.55898285, 11.52203274], [92.55867004, 11.52234268], [92.55849457, 11.52260876], [92.55833435, 11.52283287], [92.55814362, 11.52303314], [92.55784607, 11.52324104], [92.55753326, 11.52364445], [92.55724335, 11.52416134], [92.55697632, 11.52466965], [92.5566864, 11.52507114], [92.55641174, 11.52543068], [92.55613708, 11.52579975], [92.55584717, 11.52620125], [92.55555725, 11.5266819], [92.55526733, 11.52723122], [92.5548172, 11.52773952], [92.55448151, 11.52837086], [92.55422974, 11.52887917], [92.55419159, 11.52929401], [92.55396271, 11.52962017], [92.55370331, 11.52994061], [92.55335999, 11.53035069], [92.55272675, 11.53098965], [92.55256653, 11.5317297], [92.55240631, 11.53232956], [92.5522995, 11.5329113], [92.55229187, 11.53339195], [92.55211639, 11.53391075], [92.55220795, 11.53432178], [92.55203247, 11.53473186], [92.55190277, 11.53537941], [92.55175018, 11.536026], [92.55161285, 11.5367012], [92.55171967, 11.53742123], [92.55198669, 11.53812981], [92.55245972, 11.53869057], [92.55300903, 11.5384903], [92.55361176, 11.53851318], [92.55415344, 11.53835106], [92.55449677, 11.53785038], [92.55508423, 11.53794956], [92.55548096, 11.53835964], [92.55577087, 11.5385704], [92.55601501, 11.53890514], [92.55626678, 11.53930378], [92.55659485, 11.53969383], [92.55684662, 11.54008961], [92.55737305, 11.5406599], [92.55771637, 11.54073143], [92.55806732, 11.5410614], [92.55845642, 11.5413208], [92.55886841, 11.54134083], [92.55921936, 11.54107857], [92.55947113, 11.5406599], [92.5597229, 11.54020023], [92.55995178, 11.53973866], [92.56004333, 11.53924179], [92.56022644, 11.53885937], [92.56028748, 11.53841972], [92.56035614, 11.53799057]]], [[[92.61102295, 11.5882597], [92.61139679, 11.58802032], [92.61170959, 11.58762169], [92.61178589, 11.58716965], [92.61209869, 11.58681679], [92.61250305, 11.58644104], [92.61304474, 11.58608818], [92.61332703, 11.58578014], [92.6135788, 11.58558178], [92.61406708, 11.58508015], [92.6145401, 11.58479309], [92.61485291, 11.58448792], [92.61496735, 11.58427143], [92.61534882, 11.58399963], [92.61546326, 11.58355141], [92.61595917, 11.58329105], [92.61630249, 11.58315659], [92.61662292, 11.582901], [92.61682892, 11.58258247], [92.61715698, 11.58248043], [92.6173172, 11.58226109], [92.61746979, 11.58198071], [92.61754608, 11.58161068], [92.6175766, 11.58123112], [92.61763763, 11.58080482], [92.617836, 11.58016205], [92.61777496, 11.57960129], [92.61798096, 11.57898998], [92.6184082, 11.57837105], [92.61863708, 11.57806969], [92.61889648, 11.57783985], [92.61902618, 11.57762146], [92.61921692, 11.57709026], [92.6192627, 11.57644939], [92.61927032, 11.57602978], [92.61921692, 11.5748806], [92.61914825, 11.57405186], [92.61897278, 11.57301903], [92.61868286, 11.57260036], [92.61856079, 11.5721283], [92.61852264, 11.57164001], [92.61857605, 11.57110023], [92.61850739, 11.57058716], [92.61828613, 11.57015038], [92.61810303, 11.56973934], [92.61789703, 11.56931114], [92.61769867, 11.56881046], [92.61750793, 11.56826019], [92.61734772, 11.56770039], [92.61730957, 11.56705189], [92.61726379, 11.56645298], [92.61714172, 11.56613159], [92.61694336, 11.56579018], [92.61666107, 11.565382], [92.61640167, 11.56492138], [92.61617279, 11.56448174], [92.61592865, 11.56414032], [92.61575317, 11.56382275], [92.61554718, 11.5635519], [92.61534882, 11.56326199], [92.61510468, 11.5629158], [92.61461639, 11.56269932], [92.6144104, 11.56280041], [92.61394501, 11.56305885], [92.61331177, 11.5633812], [92.61266327, 11.5636816], [92.6121521, 11.56412601], [92.61167908, 11.56455421], [92.61128998, 11.56500053], [92.61094666, 11.56544304], [92.610672, 11.56589031], [92.61052704, 11.56638908], [92.61031342, 11.56682205], [92.61025238, 11.56727123], [92.61010742, 11.56765175], [92.6099472, 11.56797123], [92.60971069, 11.56818962], [92.60943604, 11.56836128], [92.60916138, 11.56856823], [92.6089325, 11.56859493], [92.6088028, 11.56861115], [92.60839844, 11.5685997], [92.60795593, 11.56851101], [92.6075058, 11.56838131], [92.60707092, 11.56850243], [92.60669708, 11.56876183], [92.60639191, 11.56908131], [92.6062088, 11.56984901], [92.60607147, 11.57032967], [92.60600281, 11.57053947], [92.60578918, 11.57061005], [92.60543823, 11.57061005], [92.60528564, 11.57050514], [92.60516357, 11.57005596], [92.60508728, 11.56971169], [92.60488129, 11.56888008], [92.60443115, 11.56847], [92.60398102, 11.56807995], [92.603508, 11.56777859], [92.60305786, 11.56753063], [92.60251617, 11.56738091], [92.60195923, 11.56724644], [92.60135651, 11.56727791], [92.60089111, 11.56760788], [92.6006012, 11.56809425], [92.60055542, 11.56867313], [92.60053253, 11.56926346], [92.60042572, 11.56985092], [92.60050201, 11.57040024], [92.60048676, 11.5711298], [92.60048676, 11.57180023], [92.60048676, 11.57246971], [92.60048676, 11.57313061], [92.60045624, 11.57374191], [92.60049438, 11.57446384], [92.60041809, 11.57514095], [92.60047913, 11.57581139], [92.60050201, 11.57646275], [92.60055542, 11.57712555], [92.60069275, 11.57779217], [92.60072327, 11.57849979], [92.60069275, 11.57903194], [92.60102081, 11.57960796], [92.60101318, 11.58019161], [92.60106659, 11.58075047], [92.60111237, 11.58134937], [92.6013031, 11.58195782], [92.60131073, 11.58254147], [92.60115051, 11.58314133], [92.60107422, 11.58380222], [92.60088348, 11.58442211], [92.60092163, 11.58506203], [92.60115814, 11.58561993], [92.60154724, 11.5860014], [92.60199738, 11.5863018], [92.60249329, 11.58650017], [92.60298157, 11.58668518], [92.6034317, 11.58690071], [92.60394287, 11.5869379], [92.60443115, 11.58699036], [92.60486603, 11.58720875], [92.60533905, 11.58740044], [92.60587311, 11.58753014], [92.60639191, 11.58773994], [92.60695648, 11.58782196], [92.60747528, 11.58801556], [92.60800934, 11.58808422], [92.60831451, 11.58814621], [92.60852051, 11.58819103], [92.60901642, 11.5880909], [92.60945129, 11.58811188], [92.60980988, 11.58829212], [92.61019897, 11.58833504], [92.61060333, 11.58833027], [92.61102295, 11.5882597]]], [[[92.56751251, 11.57081795], [92.56772614, 11.57053947], [92.56765747, 11.57012653], [92.56751251, 11.56999016], [92.56738281, 11.56991959], [92.5670929, 11.56964397], [92.56716156, 11.5692997], [92.56716919, 11.56901932], [92.56702423, 11.56867695], [92.56646729, 11.56826019], [92.56625366, 11.56798935], [92.56577301, 11.56792068], [92.56549072, 11.56812954], [92.56520844, 11.56812572], [92.56500244, 11.56833076], [92.56500244, 11.56854057], [92.56513977, 11.56881618], [92.56520844, 11.56901932], [92.56542206, 11.5692997], [92.56535339, 11.56991959], [92.56549072, 11.57026577], [92.56555176, 11.5704689], [92.56555176, 11.57074928], [92.56584167, 11.5708313], [92.56632996, 11.57067204], [92.56660461, 11.57088566], [92.56681824, 11.57102489], [92.56723785, 11.57102489], [92.56751251, 11.57081795]]], [[[92.53975677, 11.60332012], [92.54003906, 11.60325623], [92.54091644, 11.60331345], [92.54132843, 11.60312939], [92.54171753, 11.60298061], [92.54202271, 11.60277081], [92.5428772, 11.602005], [92.54399109, 11.60179996], [92.54483032, 11.60172939], [92.54538727, 11.60172939], [92.54572296, 11.60186195], [92.5461731, 11.6019392], [92.54660034, 11.60162926], [92.54693604, 11.60128021], [92.54724884, 11.60095692], [92.54749298, 11.60063076], [92.54767609, 11.60029984], [92.54782867, 11.59996986], [92.54807281, 11.59967995], [92.54818726, 11.59946156], [92.54763794, 11.59894943], [92.54724121, 11.59887123], [92.54659271, 11.59869099], [92.54641724, 11.59801197], [92.54615784, 11.59760189], [92.54601288, 11.59720516], [92.54597473, 11.59669304], [92.54607391, 11.59613228], [92.5458374, 11.5955801], [92.54556274, 11.59499931], [92.54532623, 11.59434032], [92.54519653, 11.5936203], [92.54512024, 11.59293175], [92.54512787, 11.59237957], [92.54550934, 11.59178066], [92.54582214, 11.59169197], [92.54647064, 11.5916853], [92.54682922, 11.59166241], [92.54718018, 11.59170055], [92.54747772, 11.5919199], [92.54776001, 11.59206581], [92.54821777, 11.59241486], [92.54841614, 11.59261131], [92.54888916, 11.59283161], [92.54930115, 11.5930891], [92.54973602, 11.59329033], [92.55027771, 11.59333992], [92.55079651, 11.59333992], [92.55132294, 11.59329033], [92.55175781, 11.59307575], [92.55223083, 11.59290218], [92.55264282, 11.59252357], [92.55309296, 11.59236908], [92.55356598, 11.59229183], [92.55387115, 11.59198189], [92.5539856, 11.59179211], [92.55427551, 11.59127331], [92.55475616, 11.59125042], [92.55532074, 11.59132957], [92.55541992, 11.59130001], [92.55562592, 11.59123421], [92.55621338, 11.59119129], [92.55648041, 11.59125042], [92.55683136, 11.59125042], [92.55716705, 11.59140015], [92.55755615, 11.59147072], [92.55791473, 11.5916214], [92.55832672, 11.59165955], [92.55874634, 11.59167194], [92.55916595, 11.59171009], [92.55951691, 11.59184933], [92.55992889, 11.59192657], [92.56035614, 11.59196091], [92.56080627, 11.59205723], [92.5612793, 11.5921936], [92.56182861, 11.59227085], [92.56245422, 11.59241486], [92.5631485, 11.59229565], [92.56391144, 11.59222126], [92.56468201, 11.59212112], [92.56533051, 11.59181976], [92.56563568, 11.59195423], [92.56609344, 11.59217262], [92.5667038, 11.59212971], [92.56713104, 11.59183979], [92.56735229, 11.59141159], [92.56736755, 11.59045029], [92.56751251, 11.59017181], [92.56828308, 11.59017181], [92.56903839, 11.58996868], [92.56926727, 11.58969975], [92.56942749, 11.58934021], [92.56945801, 11.58889103], [92.56939697, 11.58842182], [92.56916046, 11.58804131], [92.5688324, 11.58773327], [92.56837463, 11.587533], [92.56780243, 11.58748531], [92.5672226, 11.58745289], [92.56674194, 11.58722496], [92.56627655, 11.58699036], [92.5657959, 11.58679199], [92.5652771, 11.5866394], [92.56477356, 11.5864048], [92.5642395, 11.58618069], [92.56371307, 11.58591747], [92.56321716, 11.58554077], [92.56276703, 11.58508015], [92.56239319, 11.58456993], [92.56221771, 11.58399487], [92.56207275, 11.58346367], [92.56195831, 11.58297443], [92.56194305, 11.58245945], [92.56194305, 11.58187962], [92.56196594, 11.58126259], [92.56208038, 11.58061314], [92.56223297, 11.57999611], [92.56241608, 11.57947063], [92.5626297, 11.57905197], [92.56276703, 11.57865143], [92.56291962, 11.57833004], [92.56310272, 11.57800961], [92.5632782, 11.57769966], [92.56358337, 11.57746124], [92.56380463, 11.57709408], [92.56402588, 11.57666111], [92.56430054, 11.57626247], [92.56454468, 11.57585907], [92.56476593, 11.57550144], [92.56499481, 11.57517529], [92.56516266, 11.57481956], [92.56529236, 11.57441425], [92.56539917, 11.57400799], [92.56535339, 11.57349968], [92.56507874, 11.57291889], [92.56443024, 11.57308292], [92.56388092, 11.57305336], [92.56338501, 11.57301903], [92.56299591, 11.5728302], [92.56262207, 11.57263184], [92.56225586, 11.5723896], [92.56188965, 11.5720892], [92.56143951, 11.57188892], [92.56099701, 11.571661], [92.56058502, 11.57143497], [92.56015015, 11.57125092], [92.55974579, 11.570961], [92.55937195, 11.57056904], [92.55895233, 11.5701704], [92.55858612, 11.56971359], [92.55820465, 11.56932735], [92.55779266, 11.56905079], [92.55742645, 11.56879997], [92.55712891, 11.56851959], [92.55685425, 11.56822586], [92.5566864, 11.5678606], [92.55659485, 11.56746292], [92.55644226, 11.56710339], [92.55651855, 11.56668282], [92.55661011, 11.56624126], [92.55644989, 11.56582165], [92.55619812, 11.565382], [92.55584717, 11.56495094], [92.55547333, 11.56449127], [92.55504608, 11.56405067], [92.55473328, 11.5635519], [92.55445862, 11.56305027], [92.55423737, 11.56258965], [92.55397034, 11.56222057], [92.55371094, 11.56194496], [92.55343628, 11.56172085], [92.55306244, 11.56165981], [92.55261993, 11.56162834], [92.55214691, 11.56157112], [92.55169678, 11.56139088], [92.55127716, 11.56118107], [92.5508194, 11.56109238], [92.55039978, 11.56095982], [92.54995728, 11.560853], [92.54947662, 11.56079197], [92.54902649, 11.56055927], [92.5485611, 11.56039047], [92.54802704, 11.56054115], [92.54750824, 11.56070995], [92.54702759, 11.56087971], [92.54662323, 11.56110191], [92.54620361, 11.56126785], [92.54576111, 11.56139278], [92.54530334, 11.56151199], [92.5447998, 11.56162643], [92.54434204, 11.56185055], [92.54387665, 11.56206989], [92.543396, 11.5622406], [92.54296875, 11.56243038], [92.54251099, 11.56250763], [92.54208374, 11.56257439], [92.54180145, 11.5625782], [92.54167175, 11.56258106], [92.54128265, 11.56253147], [92.5408783, 11.56247997], [92.54046631, 11.56234074], [92.54003143, 11.5622406], [92.53952789, 11.56218433], [92.53901672, 11.56200409], [92.53842926, 11.56186676], [92.53791046, 11.56161022], [92.5375061, 11.56122017], [92.5371933, 11.56080055], [92.5369339, 11.56039047], [92.53666687, 11.55999756], [92.53639221, 11.55960178], [92.53610229, 11.55918026], [92.53578186, 11.5587492], [92.53533936, 11.55840969], [92.53488159, 11.55808163], [92.53444672, 11.55778122], [92.53403473, 11.55752277], [92.533638, 11.55729485], [92.53330994, 11.55702019], [92.53296661, 11.55674171], [92.53262329, 11.55646992], [92.53231812, 11.55612373], [92.53198242, 11.55574608], [92.5316391, 11.55533981], [92.53149414, 11.55509377], [92.53118134, 11.55485725], [92.53074646, 11.55447197], [92.53045654, 11.55420017], [92.53018188, 11.55412674], [92.52997589, 11.5544014], [92.52997589, 11.55481625], [92.53018188, 11.55495453], [92.53032684, 11.55515957], [92.53040314, 11.55563164], [92.53035736, 11.55626965], [92.5303421, 11.55693054], [92.53045654, 11.55754185], [92.53060913, 11.55814648], [92.53082275, 11.55865097], [92.53104401, 11.55908012], [92.53125763, 11.55938053], [92.53147888, 11.5595789], [92.53166962, 11.55980015], [92.53183746, 11.56007099], [92.53183746, 11.56042004], [92.53206635, 11.56101704], [92.53248596, 11.56123066], [92.53279114, 11.56167126], [92.53312683, 11.56212044], [92.53328705, 11.56247139], [92.53399658, 11.56258774], [92.53444672, 11.56280041], [92.53483582, 11.56309795], [92.5351181, 11.56348991], [92.53526306, 11.56399059], [92.53527832, 11.56448174], [92.53527832, 11.56490803], [92.53527832, 11.56562996], [92.53513336, 11.56666946], [92.53466034, 11.56797123], [92.53447723, 11.56830978], [92.53439331, 11.56861782], [92.53423309, 11.56885147], [92.53414154, 11.56914043], [92.53404999, 11.56944084], [92.53375244, 11.56972122], [92.5333786, 11.56980324], [92.53312683, 11.56990147], [92.53296661, 11.57025719], [92.53277588, 11.57060337], [92.53255463, 11.57096577], [92.5324173, 11.57143974], [92.53225708, 11.57192516], [92.53224945, 11.57245445], [92.53238678, 11.57299042], [92.53248596, 11.5735302], [92.53256989, 11.57409859], [92.53279114, 11.57462978], [92.5330658, 11.57509136], [92.53335571, 11.5752573], [92.53369141, 11.57557201], [92.53401184, 11.57608032], [92.53418732, 11.57642174], [92.5341568, 11.57680035], [92.53424072, 11.57720089], [92.53430176, 11.57759953], [92.53420258, 11.57801723], [92.53425598, 11.57839966], [92.53440857, 11.57880592], [92.53447723, 11.57929134], [92.53465271, 11.57978058], [92.53477478, 11.58030987], [92.53497314, 11.58078194], [92.53504181, 11.58126736], [92.53524017, 11.58167076], [92.53527832, 11.58211136], [92.53527069, 11.58255005], [92.53518677, 11.58298969], [92.53501892, 11.58342075], [92.53488922, 11.58386326], [92.53473663, 11.58427143], [92.53469849, 11.58468056], [92.53452301, 11.58494568], [92.5344162, 11.58523083], [92.53426361, 11.58547878], [92.5341568, 11.58580112], [92.5340271, 11.58610058], [92.53391266, 11.58641148], [92.53380585, 11.58672142], [92.53363037, 11.58698082], [92.53349304, 11.58732986], [92.53330994, 11.58771515], [92.5330658, 11.58813], [92.5328064, 11.58862019], [92.532547, 11.58917618], [92.53244781, 11.58988476], [92.53231049, 11.59059143], [92.53223419, 11.59128189], [92.53222656, 11.59191322], [92.53221893, 11.5924511], [92.5321579, 11.59292126], [92.53198242, 11.5933466], [92.53201294, 11.59384441], [92.53215027, 11.59442043], [92.5319519, 11.59506512], [92.53217316, 11.5957098], [92.53251648, 11.59632111], [92.53270721, 11.5968914], [92.53285217, 11.59743595], [92.53308105, 11.59800053], [92.53338623, 11.59856129], [92.53357697, 11.59901047], [92.53369904, 11.59956169], [92.53376007, 11.60018444], [92.53362274, 11.60072041], [92.53360748, 11.60135078], [92.53379059, 11.60182953], [92.5341568, 11.60221004], [92.53446198, 11.60252666], [92.5346756, 11.60287952], [92.53475952, 11.60332012], [92.53491974, 11.60367107], [92.53504181, 11.604002], [92.53525543, 11.60424614], [92.5354538, 11.60452366], [92.53559113, 11.60492039], [92.53588104, 11.60537148], [92.53635406, 11.60577869], [92.53668213, 11.60592842], [92.53691864, 11.60603523], [92.53741455, 11.6058979], [92.53787994, 11.60569954], [92.53904724, 11.60464001], [92.53975677, 11.60332012]]], [[[92.57826233, 11.58180523], [92.57805634, 11.58166599], [92.57771301, 11.58319092], [92.57659912, 11.58485889], [92.5772171, 11.58528137], [92.57805634, 11.58528137], [92.57861328, 11.58500099], [92.57888794, 11.58471966], [92.57944489, 11.58444405], [92.57958221, 11.58382034], [92.57971954, 11.58306122], [92.57943726, 11.58278084], [92.57861328, 11.58250046], [92.57861328, 11.58222008], [92.57833099, 11.58194447], [92.57826233, 11.58180523]]], [[[92.77108765, 11.78885078], [92.77098846, 11.78822041], [92.77085876, 11.78759098], [92.77082062, 11.78696156], [92.77102661, 11.78633022], [92.77094269, 11.78576088], [92.77069855, 11.78524971], [92.77036285, 11.78480053], [92.77002716, 11.78434086], [92.76973724, 11.78386021], [92.7694931, 11.78335094], [92.76930237, 11.78277016], [92.76895905, 11.78215885], [92.76882172, 11.78175163], [92.76869202, 11.78126144], [92.76847076, 11.78112507], [92.76798248, 11.78071022], [92.76763153, 11.78043175], [92.76728058, 11.78001881], [92.76714325, 11.77940178], [92.76706696, 11.77871132], [92.76727295, 11.77807999], [92.76741028, 11.77761269], [92.76755524, 11.77716446], [92.76778412, 11.77675819], [92.76803589, 11.77637005], [92.76825714, 11.77598953], [92.7684021, 11.77567959], [92.76851654, 11.77544975], [92.76860809, 11.77523994], [92.76866913, 11.77499199], [92.76876831, 11.77471066], [92.76883698, 11.77439404], [92.76869202, 11.77338886], [92.76862335, 11.77235031], [92.7682724, 11.77145672], [92.76777649, 11.77015114], [92.7664566, 11.76904106], [92.76616669, 11.76871014], [92.76568604, 11.76798058], [92.76531219, 11.76753044], [92.76500702, 11.76710606], [92.76481628, 11.76670933], [92.76490021, 11.76634693], [92.76499176, 11.76599121], [92.76496124, 11.76567745], [92.76506042, 11.76546001], [92.76502991, 11.76512337], [92.76509857, 11.7648468], [92.76529694, 11.76456928], [92.76558685, 11.76429558], [92.76571655, 11.76373959], [92.76579285, 11.76339817], [92.76579285, 11.76271152], [92.76558685, 11.76194954], [92.76529694, 11.76140118], [92.76502991, 11.7609787], [92.764534, 11.76070595], [92.76405334, 11.76071072], [92.76397705, 11.76043034], [92.76377106, 11.75987911], [92.76390839, 11.75967979], [92.76399231, 11.75962257], [92.76412201, 11.75953388], [92.764534, 11.75939465], [92.76499176, 11.75890064], [92.76526642, 11.75854111], [92.76553345, 11.75823784], [92.76554108, 11.75800991], [92.76560211, 11.75791168], [92.76563263, 11.75769138], [92.76554871, 11.75738144], [92.7657547, 11.75682545], [92.76589203, 11.75627995], [92.76596832, 11.75583076], [92.76595306, 11.75540924], [92.76590729, 11.75505066], [92.76583862, 11.75470734], [92.76577759, 11.75433064], [92.76566315, 11.75389099], [92.76570892, 11.75339031], [92.76583862, 11.75286102], [92.76596069, 11.75235081], [92.76598358, 11.75188255], [92.76580811, 11.75146008], [92.76554871, 11.75104046], [92.76528168, 11.75059605], [92.76502991, 11.75010109], [92.76481628, 11.74956989], [92.76455688, 11.7490797], [92.76416016, 11.74868965], [92.7637558, 11.74834156], [92.76341248, 11.74799061], [92.76319885, 11.74750996], [92.76284027, 11.74671173], [92.76262665, 11.746562], [92.76235199, 11.74643612], [92.76200104, 11.74630165], [92.76130676, 11.7459507], [92.76109314, 11.74560738], [92.76081085, 11.74506187], [92.76081085, 11.74457169], [92.76095581, 11.7439518], [92.76102448, 11.74346924], [92.7611618, 11.74304962], [92.76130676, 11.7426424], [92.76158142, 11.74229527], [92.76180267, 11.74188042], [92.76193237, 11.74153614], [92.76193237, 11.74112129], [92.76179504, 11.7407093], [92.76151276, 11.74022102], [92.76123047, 11.73953533], [92.76109314, 11.7388401], [92.76108551, 11.73856926], [92.76055908, 11.7381897], [92.75974274, 11.73732853], [92.75918579, 11.73664093], [92.75904083, 11.73608017], [92.75883484, 11.73560429], [92.75869751, 11.73504734], [92.75866699, 11.73475075], [92.75881195, 11.73440933], [92.75891876, 11.73400116], [92.75900269, 11.73359108], [92.75917053, 11.73318958], [92.75920868, 11.73287106], [92.75920868, 11.73253632], [92.75927734, 11.73213005], [92.75891113, 11.73151016], [92.75891113, 11.73099995], [92.75910187, 11.73025036], [92.75919342, 11.72961903], [92.75911713, 11.72906017], [92.75891876, 11.72864056], [92.75862885, 11.72833061], [92.75835419, 11.72806358], [92.7580719, 11.7278204], [92.7576828, 11.72768116], [92.75740051, 11.72741032], [92.75712585, 11.72721195], [92.75688171, 11.72696114], [92.75665283, 11.72670078], [92.75643158, 11.72640038], [92.7562561, 11.7260313], [92.7561264, 11.72559071], [92.75614929, 11.72510147], [92.75631714, 11.72461128], [92.75643921, 11.72407341], [92.75662994, 11.7235651], [92.75666809, 11.723032], [92.75666809, 11.72248268], [92.75668335, 11.72192192], [92.75669861, 11.72137737], [92.75667572, 11.72083187], [92.75666809, 11.72027874], [92.75662994, 11.71972275], [92.75641632, 11.71920967], [92.75608063, 11.71879005], [92.75576019, 11.71840954], [92.75546265, 11.71813202], [92.75506592, 11.71819973], [92.7550354, 11.71806335], [92.75489807, 11.71744061], [92.75495148, 11.71699905], [92.75505066, 11.71663189], [92.75526428, 11.71622181], [92.75547791, 11.71578884], [92.75563049, 11.71535969], [92.75583649, 11.71500015], [92.75609589, 11.71466064], [92.7563324, 11.71427059], [92.7564621, 11.71377373], [92.7567215, 11.71336555], [92.75699615, 11.71298122], [92.75721741, 11.71253014], [92.75740051, 11.71207142], [92.75758362, 11.7116003], [92.75765991, 11.71037102], [92.75772858, 11.70954418], [92.75772858, 11.70809364], [92.75759125, 11.70767975], [92.75710297, 11.70677853], [92.75682068, 11.70616245], [92.75654602, 11.70547104], [92.75619507, 11.70416069], [92.75584412, 11.70319366], [92.75570679, 11.70236683], [92.75535583, 11.70181084], [92.75507355, 11.70105553], [92.75457001, 11.70118427], [92.75400543, 11.7015152], [92.75366974, 11.70188141], [92.75337219, 11.70228863], [92.75311279, 11.70271969], [92.75282288, 11.70314026], [92.75248718, 11.7035408], [92.75215149, 11.70388699], [92.75183868, 11.70421982], [92.75164032, 11.7046423], [92.7514267, 11.70501995], [92.75131226, 11.70546436], [92.75111389, 11.70583439], [92.7509079, 11.70615005], [92.75074768, 11.70645618], [92.75055695, 11.70671082], [92.75032043, 11.70697975], [92.75004578, 11.7072897], [92.74971771, 11.70765018], [92.7493515, 11.70804024], [92.74894714, 11.70842934], [92.74859619, 11.70888996], [92.74816895, 11.70931816], [92.74767303, 11.70975971], [92.74723053, 11.71032143], [92.74697876, 11.7109499], [92.74694061, 11.71153069], [92.74688721, 11.71194553], [92.74671173, 11.71219921], [92.74659729, 11.71298981], [92.74645996, 11.71334076], [92.74645996, 11.71375084], [92.7461853, 11.71402454], [92.74576569, 11.71416378], [92.74555206, 11.71416378], [92.74534607, 11.71409321], [92.74494934, 11.71357059], [92.74454498, 11.71342754], [92.74415588, 11.71321964], [92.74377441, 11.7130537], [92.74345398, 11.71284866], [92.74327087, 11.71247864], [92.74297333, 11.71215057], [92.74280548, 11.71169281], [92.74275208, 11.71112823], [92.74263, 11.71055984], [92.74249268, 11.71001625], [92.74236298, 11.70949173], [92.74224854, 11.70898056], [92.74221802, 11.70847034], [92.74221802, 11.70796204], [92.74224091, 11.70745182], [92.74234772, 11.70694065], [92.74247742, 11.70639038], [92.74253082, 11.70573139], [92.74265289, 11.70502663], [92.74278259, 11.70430183], [92.74295044, 11.70362282], [92.74311829, 11.70301628], [92.74333191, 11.70256138], [92.74352264, 11.70215034], [92.74364471, 11.70175171], [92.74363708, 11.70141697], [92.74372864, 11.70086002], [92.7437973, 11.70036125], [92.74391937, 11.69996929], [92.74391937, 11.69969082], [92.74394226, 11.6993742], [92.74397278, 11.69909191], [92.74407959, 11.69879055], [92.74407959, 11.6984396], [92.74401093, 11.69804573], [92.74391937, 11.69756031], [92.74402618, 11.69701099], [92.74415588, 11.696455], [92.74424744, 11.69594002], [92.74440765, 11.69554138], [92.74446106, 11.69515991], [92.7445755, 11.69487095], [92.74469757, 11.69460201], [92.74472809, 11.69429016], [92.74481201, 11.69397068], [92.74495697, 11.69364929], [92.74500275, 11.6932497], [92.74504089, 11.69283104], [92.74517822, 11.69244957], [92.74518585, 11.69208145], [92.74501038, 11.69173717], [92.74481201, 11.69141102], [92.74452209, 11.69113064], [92.74417114, 11.6909256], [92.74375153, 11.69074059], [92.74324799, 11.69057178], [92.74265289, 11.69043064], [92.74201965, 11.69025993], [92.74137878, 11.69007969], [92.7407074, 11.69013691], [92.74008942, 11.69029045], [92.73958588, 11.69049263], [92.73911285, 11.6906004], [92.73867798, 11.69080925], [92.73821259, 11.69097614], [92.73776245, 11.69126511], [92.73726654, 11.69160938], [92.73677063, 11.69200134], [92.73631287, 11.69244099], [92.73587799, 11.69282627], [92.73561859, 11.69327068], [92.73549652, 11.69373989], [92.7352829, 11.69408035], [92.73500824, 11.69437599], [92.73470306, 11.69471359], [92.73426056, 11.69500256], [92.73377991, 11.69531345], [92.73336792, 11.69571018], [92.73303223, 11.69614029], [92.73271179, 11.69649124], [92.73253632, 11.69686699], [92.73239136, 11.6970911], [92.73232269, 11.69724846], [92.73197937, 11.69758129], [92.73190308, 11.69803047], [92.73146057, 11.69840145], [92.73107147, 11.69815063], [92.73072052, 11.69819164], [92.73023224, 11.69804955], [92.7299118, 11.69791126], [92.72970581, 11.69736195], [92.72973633, 11.69724846], [92.72975159, 11.69696999], [92.72953033, 11.69672203], [92.72927856, 11.69626141], [92.72916412, 11.69600964], [92.72891998, 11.69566154], [92.72867584, 11.69530201], [92.72834015, 11.69503021], [92.72792816, 11.69494247], [92.72753143, 11.69527912], [92.72722626, 11.69578934], [92.72701263, 11.6962862], [92.72674561, 11.69661427], [92.72677612, 11.69740963], [92.72634125, 11.69746017], [92.72603607, 11.69742107], [92.72558594, 11.69736195], [92.72524261, 11.69723034], [92.72483826, 11.69725037], [92.72444916, 11.69731426], [92.72403717, 11.69738007], [92.72370148, 11.69745064], [92.72360992, 11.69747066], [92.72348022, 11.69746876], [92.72309875, 11.69746208], [92.72252655, 11.69742966], [92.72193909, 11.69796753], [92.72145844, 11.69848061], [92.72120667, 11.69896889], [92.72107697, 11.69946957], [92.72088623, 11.69999027], [92.72079468, 11.70056915], [92.72061157, 11.70108414], [92.72052765, 11.70157242], [92.72038269, 11.7019701], [92.72026825, 11.70232964], [92.72011566, 11.70268631], [92.72001648, 11.70310307], [92.71996307, 11.70355034], [92.71980286, 11.70392132], [92.71964264, 11.70423126], [92.71947479, 11.70445919], [92.71935272, 11.70471191], [92.71916199, 11.70493126], [92.71897888, 11.70525455], [92.71869659, 11.70549202], [92.7184906, 11.70573807], [92.71820068, 11.70599079], [92.71772003, 11.70577908], [92.71734619, 11.7056694], [92.71708679, 11.70558071], [92.7164917, 11.70544147], [92.71620941, 11.70482159], [92.71585083, 11.7044611], [92.71550751, 11.70410824], [92.71523285, 11.70397091], [92.71495056, 11.70382595], [92.71434784, 11.70367146], [92.71409607, 11.70320129], [92.71398163, 11.7027607], [92.71396637, 11.70240974], [92.71405029, 11.70186138], [92.71407318, 11.7014389], [92.71404266, 11.70096111], [92.71420288, 11.70048714], [92.71437836, 11.70005131], [92.71443176, 11.69961071], [92.71440125, 11.69922638], [92.71421814, 11.6989212], [92.71414948, 11.69861126], [92.7140274, 11.69832802], [92.71389008, 11.69802094], [92.71376038, 11.69764042], [92.71363068, 11.69723892], [92.71356201, 11.69678116], [92.71337891, 11.6963501], [92.71328735, 11.69584179], [92.71304321, 11.69543171], [92.71269989, 11.69513321], [92.71231079, 11.6950264], [92.71189117, 11.69511032], [92.71154022, 11.69544125], [92.71115875, 11.69569778], [92.71076202, 11.69608116], [92.71032715, 11.69649124], [92.7100296, 11.69699001], [92.70987701, 11.69745064], [92.70970154, 11.69779491], [92.70948029, 11.69807053], [92.70928955, 11.69841003], [92.70911407, 11.69880199], [92.70887756, 11.69917202], [92.70862579, 11.69953156], [92.70843506, 11.69991493], [92.70832062, 11.70033169], [92.70817566, 11.70071697], [92.70807648, 11.70106316], [92.7084198, 11.70169926], [92.70890808, 11.70197868], [92.70905304, 11.70259857], [92.70905304, 11.70300961], [92.70877075, 11.70351124], [92.70845795, 11.70346069], [92.70794678, 11.70326042], [92.70761108, 11.70325089], [92.70736694, 11.70345879], [92.70705414, 11.7037344], [92.70671082, 11.70410061], [92.70635223, 11.70448208], [92.7060318, 11.70485115], [92.70581055, 11.70524979], [92.70556641, 11.70556927], [92.70530701, 11.70585155], [92.70506287, 11.70606136], [92.70472717, 11.70617104], [92.70446014, 11.7063303], [92.70420074, 11.70643139], [92.70394897, 11.70658112], [92.70366669, 11.70671082], [92.70334625, 11.70692062], [92.70231628, 11.70718002], [92.70189667, 11.70713043], [92.70207214, 11.70662022], [92.70233154, 11.70610046], [92.70269012, 11.70566273], [92.70311737, 11.70534134], [92.70350647, 11.70506096], [92.70378876, 11.70476532], [92.70410919, 11.70450878], [92.70448303, 11.70427036], [92.70485687, 11.70401001], [92.70522308, 11.70364094], [92.70545197, 11.70320129], [92.70526123, 11.70281124], [92.70477295, 11.7025013], [92.70419312, 11.70222092], [92.70357513, 11.70199299], [92.70294189, 11.70196056], [92.7023468, 11.70202065], [92.70185852, 11.70194054], [92.70143127, 11.70183086], [92.7010498, 11.7017107], [92.70067596, 11.70167446], [92.70030212, 11.70167446], [92.69993591, 11.70171547], [92.69927216, 11.70163536], [92.69878387, 11.70170403], [92.69850159, 11.70177174], [92.69742584, 11.70140266], [92.69637299, 11.70112705], [92.69563293, 11.70055008], [92.69599152, 11.70018959], [92.69661713, 11.70026112], [92.69830322, 11.70054054], [92.69934082, 11.7007513], [92.7041626, 11.7007513], [92.70479584, 11.70072079], [92.70517731, 11.70055008], [92.70553589, 11.70033169], [92.70592499, 11.70022678], [92.70623016, 11.70003128], [92.70654297, 11.69982147], [92.7067337, 11.69953632], [92.70682526, 11.69918346], [92.70704651, 11.69907379], [92.70718384, 11.69859028], [92.70717621, 11.69776058], [92.70739746, 11.69714069], [92.70739746, 11.69693565], [92.7072525, 11.69672775], [92.70690918, 11.69672775], [92.70662689, 11.69714069], [92.7064209, 11.69741726], [92.70627594, 11.69789982], [92.7064209, 11.69845104], [92.70630646, 11.69882965], [92.70565796, 11.69853973], [92.70490265, 11.69834042], [92.70449829, 11.69791985], [92.70388031, 11.69764042], [92.7035675, 11.69729137], [92.70314789, 11.69689941], [92.70281219, 11.69650269], [92.70259094, 11.69602203], [92.70250702, 11.69546986], [92.70249176, 11.69492054], [92.70243835, 11.6944313], [92.70226288, 11.69402981], [92.7022171, 11.69363976], [92.7022171, 11.69326019], [92.70217896, 11.6928606], [92.70199585, 11.69244957], [92.70198059, 11.69200134], [92.70215607, 11.69154072], [92.70223236, 11.69104195], [92.7023468, 11.69057941], [92.70252228, 11.69018745], [92.70275879, 11.68983173], [92.70292664, 11.6894207], [92.70305634, 11.68894958], [92.70314026, 11.68844414], [92.70307159, 11.68785095], [92.70307159, 11.68721962], [92.70314789, 11.68659306], [92.70330048, 11.68599606], [92.70334625, 11.68541718], [92.70343781, 11.68492031], [92.70361328, 11.68447113], [92.70375824, 11.68401527], [92.70387268, 11.68353176], [92.70388031, 11.68302822], [92.70379639, 11.68256092], [92.70359802, 11.68217754], [92.70334625, 11.68187141], [92.70310974, 11.68158054], [92.70292664, 11.68122101], [92.70271301, 11.6807518], [92.70249176, 11.68028355], [92.70224762, 11.67988968], [92.70204163, 11.67953014], [92.70189667, 11.67912197], [92.70166779, 11.67871189], [92.70140839, 11.67824745], [92.70118713, 11.67764091], [92.70094299, 11.67696095], [92.70107269, 11.67627144], [92.70111084, 11.67560959], [92.70114899, 11.67506504], [92.7013092, 11.67463017], [92.70140839, 11.6742239], [92.70142365, 11.67386627], [92.7015686, 11.67352009], [92.70171356, 11.67328072], [92.70197296, 11.67294979], [92.70251465, 11.67261124], [92.70291138, 11.67270184], [92.70329285, 11.67265797], [92.70366669, 11.67251015], [92.70407104, 11.67228222], [92.70453644, 11.67191124], [92.7049408, 11.67185402], [92.70513153, 11.67191315], [92.70532227, 11.67197037], [92.70569611, 11.67193127], [92.70607758, 11.67192173], [92.70644379, 11.67193985], [92.70684052, 11.67193985], [92.70726013, 11.67195034], [92.70747375, 11.67194653], [92.70768738, 11.67194271], [92.70808411, 11.67190647], [92.70836639, 11.6717186], [92.70855713, 11.67151356], [92.70861053, 11.67121124], [92.70858002, 11.67086029], [92.70839691, 11.67050743], [92.70819855, 11.67011929], [92.70791626, 11.6698246], [92.70761871, 11.66953087], [92.70729828, 11.66922092], [92.70694733, 11.66893196], [92.70649719, 11.66877937], [92.70610809, 11.66864014], [92.70574188, 11.66858959], [92.70542908, 11.6684761], [92.70513153, 11.66830063], [92.70484161, 11.66805458], [92.7045517, 11.66779232], [92.70423889, 11.66757965], [92.70392609, 11.66740036], [92.70365143, 11.66718769], [92.70334625, 11.66694927], [92.70292664, 11.66675091], [92.70240784, 11.66666889], [92.70184326, 11.66666698], [92.70131683, 11.66666889], [92.7008667, 11.66666889], [92.70049286, 11.66665077], [92.70015717, 11.66654968], [92.69986725, 11.6664114], [92.69958496, 11.66632175], [92.69936371, 11.66613102], [92.69908905, 11.66590977], [92.6986618, 11.66569138], [92.69804382, 11.66566086], [92.69758606, 11.6658392], [92.69719696, 11.66609001], [92.69674683, 11.66632175], [92.69628143, 11.66663933], [92.69580078, 11.66694927], [92.69541168, 11.6672411], [92.69511414, 11.66751003], [92.69487, 11.66774464], [92.69459534, 11.6679039], [92.69432831, 11.66807079], [92.69406891, 11.66825962], [92.69377136, 11.66833019], [92.69346619, 11.66834164], [92.69328308, 11.66832256], [92.69317627, 11.66831207], [92.69293976, 11.66819572], [92.69276428, 11.66797924], [92.69258881, 11.66774178], [92.69245148, 11.66746426], [92.69232941, 11.66714478], [92.69243622, 11.66667843], [92.69255066, 11.6661396], [92.69256592, 11.66555023], [92.69246674, 11.66493034], [92.69212341, 11.66448116], [92.69158173, 11.66417122], [92.69107819, 11.66391087], [92.69056702, 11.6637516], [92.69010925, 11.66359043], [92.68972778, 11.66334057], [92.68930817, 11.66306973], [92.68881226, 11.66281033], [92.68824768, 11.66260147], [92.68763733, 11.66254139], [92.68707275, 11.66261196], [92.68663788, 11.66276932], [92.68604279, 11.66251183], [92.68564606, 11.66222191], [92.68541718, 11.66178703], [92.68519592, 11.66141129], [92.68501282, 11.66102123], [92.68486786, 11.66061115], [92.68466187, 11.66022968], [92.68453217, 11.65985203], [92.68435669, 11.6595974], [92.68421936, 11.65936184], [92.68421173, 11.65911579], [92.68408966, 11.65884018], [92.68419647, 11.65831089], [92.68448639, 11.65806961], [92.68495178, 11.65767097], [92.68540192, 11.65765476], [92.68572235, 11.65734005], [92.68609619, 11.65703011], [92.68649292, 11.65666962], [92.68671417, 11.65631485], [92.68667603, 11.65592289], [92.68668365, 11.65545845], [92.68654633, 11.65505886], [92.68622589, 11.6547308], [92.68588257, 11.65442085], [92.68559265, 11.6540699], [92.68534851, 11.65364075], [92.68521881, 11.65310097], [92.68493652, 11.65270042], [92.68466187, 11.65233517], [92.6844635, 11.65195656], [92.68431854, 11.65156269], [92.68411255, 11.65126038], [92.68386841, 11.6509819], [92.68350983, 11.65070343], [92.68295288, 11.65049171], [92.68237305, 11.6508007], [92.68186188, 11.65111065], [92.68138123, 11.651371], [92.68083954, 11.65155125], [92.6802597, 11.65169716], [92.67971039, 11.65190029], [92.67915344, 11.65199757], [92.6787262, 11.65221024], [92.67836761, 11.65244007], [92.67798615, 11.65254021], [92.67769623, 11.65271091], [92.67739868, 11.65277958], [92.67710114, 11.65283871], [92.67687225, 11.65297985], [92.67661285, 11.65305138], [92.67632294, 11.65305996], [92.67598724, 11.65308094], [92.67562866, 11.6531601], [92.67526245, 11.65329933], [92.67481232, 11.65334034], [92.67431641, 11.65339661], [92.67385101, 11.65357304], [92.67334747, 11.65362453], [92.67285156, 11.65361881], [92.67236328, 11.65360928], [92.67185974, 11.65361404], [92.67137909, 11.65365505], [92.6709671, 11.65382099], [92.67050934, 11.65388107], [92.66999817, 11.65388966], [92.66944885, 11.65388966], [92.66886902, 11.65388966], [92.66828918, 11.65388966], [92.66776276, 11.65386009], [92.66711426, 11.654109], [92.66641235, 11.654109], [92.66620636, 11.6539011], [92.66627502, 11.65328121], [92.66655731, 11.6527977], [92.66667175, 11.65234375], [92.66661835, 11.65180206], [92.66641235, 11.65127563], [92.6662674, 11.65071011], [92.66612244, 11.65013599], [92.66602325, 11.6495409], [92.66598511, 11.64892292], [92.66586304, 11.64836979], [92.66580963, 11.64783192], [92.6657486, 11.64731026], [92.66564941, 11.64678955], [92.66546631, 11.64627075], [92.6653595, 11.64570332], [92.66555786, 11.64513588], [92.66565704, 11.64440155], [92.66623688, 11.6439867], [92.66661835, 11.64371967], [92.66693115, 11.64354897], [92.66722107, 11.64324188], [92.66748047, 11.64292717], [92.66768646, 11.6425724], [92.66780853, 11.64218235], [92.6680069, 11.64182377], [92.66816711, 11.64141083], [92.66835022, 11.64101028], [92.66854095, 11.64058018], [92.66854095, 11.64015961], [92.66838074, 11.63978195], [92.66833496, 11.6394186], [92.66805267, 11.63902092], [92.66805267, 11.63619041], [92.66812897, 11.6356411], [92.66832733, 11.63494968], [92.66868591, 11.63321972], [92.66889191, 11.6328783], [92.66947937, 11.63239098], [92.6697998, 11.63204193], [92.67016602, 11.63177967], [92.6704483, 11.63153076], [92.6707077, 11.6314106], [92.67098236, 11.63141727], [92.67127228, 11.63153839], [92.67160034, 11.63160229], [92.67195892, 11.63142872], [92.67234802, 11.63132191], [92.67266083, 11.63112831], [92.67294312, 11.63092136], [92.67311859, 11.63064671], [92.67334747, 11.63039017], [92.67359161, 11.63012314], [92.67378998, 11.62980175], [92.67386627, 11.6294117], [92.67381287, 11.62903118], [92.67359161, 11.62871742], [92.67333221, 11.62842274], [92.6730423, 11.62820244], [92.6727829, 11.62751102], [92.67282104, 11.62691784], [92.67312622, 11.62628937], [92.67326355, 11.62570572], [92.67365265, 11.6252203], [92.67407227, 11.6248064], [92.67449951, 11.62457085], [92.67481232, 11.62472057], [92.67516327, 11.62475109], [92.6754837, 11.62492943], [92.6758194, 11.62520027], [92.67613983, 11.62559891], [92.6764679, 11.62609959], [92.67684937, 11.62664032], [92.67681122, 11.6272192], [92.67697144, 11.62775898], [92.67693329, 11.62849331], [92.67743683, 11.62862301], [92.67787933, 11.62858009], [92.6783905, 11.62865734], [92.67897034, 11.62884426], [92.67958069, 11.62893963], [92.68003845, 11.62926102], [92.68031311, 11.6297493], [92.68062592, 11.63018036], [92.68074799, 11.63074112], [92.68081665, 11.6312809], [92.68079376, 11.63183022], [92.68061829, 11.63235188], [92.68049622, 11.63288116], [92.68031311, 11.63334084], [92.68017578, 11.63381958], [92.67999268, 11.63427067], [92.6798172, 11.63471127], [92.68000031, 11.63512135], [92.68026733, 11.63550186], [92.68054962, 11.63588047], [92.68086243, 11.63631058], [92.68121338, 11.63678932], [92.68147278, 11.6374979], [92.68193817, 11.6374712], [92.6823349, 11.63742065], [92.68242645, 11.63708115], [92.68255615, 11.63675308], [92.68263245, 11.63611698], [92.68321991, 11.63566113], [92.68360901, 11.63544941], [92.68392944, 11.6350708], [92.68424988, 11.63473129], [92.68450165, 11.63440132], [92.68467712, 11.63404083], [92.68476105, 11.63367558], [92.68489838, 11.63344097], [92.68486023, 11.63328171], [92.68481445, 11.63293076], [92.68469238, 11.63221741], [92.68453217, 11.63162041], [92.68447876, 11.63116169], [92.68448639, 11.63104057], [92.6848526, 11.63085175], [92.68530273, 11.63121033], [92.6853714, 11.63183022], [92.6853714, 11.63238239], [92.68572235, 11.63280106], [92.68600464, 11.63321114], [92.68614197, 11.63369179], [92.68636322, 11.63438034], [92.68636322, 11.63480186], [92.68600464, 11.63521004], [92.68599701, 11.63569069], [92.6860733, 11.63632202], [92.68614197, 11.63673019], [92.68641663, 11.63694191], [92.68642426, 11.63742065], [92.68636322, 11.63845062], [92.68636322, 11.63969994], [92.68641663, 11.64011002], [92.68654633, 11.64024925], [92.68683624, 11.64024925], [92.68726349, 11.64038563], [92.68768311, 11.64059258], [92.68795776, 11.64045429], [92.68850708, 11.64003944], [92.68907928, 11.63949013], [92.68976593, 11.638731], [92.69005585, 11.63755989], [92.69019318, 11.63700962], [92.69033051, 11.63625145], [92.6905365, 11.63466072], [92.6905365, 11.63184071], [92.69048309, 11.63148975], [92.69026184, 11.63121033], [92.69005585, 11.63073063], [92.68984222, 11.63024139], [92.6897049, 11.62989712], [92.68963623, 11.62962055], [92.68994904, 11.62918377], [92.69023132, 11.62909985], [92.69050598, 11.62888145], [92.69085693, 11.62860012], [92.69129181, 11.62832928], [92.69173431, 11.62804413], [92.69211578, 11.62769127], [92.69235992, 11.62720108], [92.69254303, 11.6266489], [92.69277954, 11.62613392], [92.69303894, 11.62561893], [92.69326782, 11.6250906], [92.69356537, 11.62465763], [92.69386292, 11.62421131], [92.69411469, 11.62378025], [92.69432068, 11.62320995], [92.69457245, 11.6227293], [92.69484711, 11.62345409], [92.69484711, 11.62414169], [92.69476318, 11.62475109], [92.69472504, 11.6250267], [92.69471741, 11.6253233], [92.69473267, 11.62565136], [92.69477081, 11.62603188], [92.69495392, 11.62641907], [92.69499969, 11.62688446], [92.69497681, 11.62737179], [92.69493103, 11.62787056], [92.6949234, 11.62837029], [92.69476318, 11.62883091], [92.69470215, 11.62930012], [92.69458771, 11.62971497], [92.69445801, 11.63010025], [92.69435883, 11.63048077], [92.69419861, 11.63080406], [92.69412994, 11.6311636], [92.69396973, 11.63146973], [92.6938324, 11.63184071], [92.69361115, 11.63218975], [92.69335938, 11.63260937], [92.69313049, 11.63311768], [92.69296265, 11.63369179], [92.69278717, 11.63424969], [92.69269562, 11.63478756], [92.69264221, 11.63530254], [92.69275665, 11.63574314], [92.69286346, 11.63617229], [92.69303894, 11.63659286], [92.69316864, 11.63704014], [92.69335175, 11.63747787], [92.69361877, 11.63788986], [92.69393158, 11.63832092], [92.69425964, 11.63871765], [92.69462585, 11.63903427], [92.69515991, 11.63907146], [92.69563293, 11.63915062], [92.6960907, 11.63920975], [92.6965332, 11.63912106], [92.69697571, 11.63916683], [92.6974411, 11.63931179], [92.69789886, 11.63951492], [92.69831848, 11.63972855], [92.69873047, 11.63984966], [92.69915009, 11.64019203], [92.69950867, 11.64038086], [92.69973755, 11.6406498], [92.69994354, 11.64086914], [92.70011902, 11.64109516], [92.70027161, 11.64134312], [92.70030975, 11.64162064], [92.70028687, 11.641922], [92.70022583, 11.64224625], [92.70002747, 11.64259243], [92.69989777, 11.64303207], [92.69975281, 11.64351082], [92.699646, 11.64407063], [92.69954681, 11.64459991], [92.69967651, 11.6450901], [92.6998291, 11.64552498], [92.70011139, 11.64591026], [92.70021057, 11.64627075], [92.70027924, 11.64657593], [92.70027924, 11.64683437], [92.70014191, 11.64713383], [92.69998169, 11.64729214], [92.69988251, 11.64750957], [92.69975281, 11.64774704], [92.699646, 11.64803219], [92.69944, 11.64830971], [92.69917297, 11.64861107], [92.69879913, 11.6488924], [92.69831848, 11.64911938], [92.69770813, 11.64916706], [92.69707489, 11.64921474], [92.6965332, 11.64944077], [92.69606781, 11.64976883], [92.69574738, 11.65023232], [92.69538879, 11.65072155], [92.69503784, 11.65127087], [92.69480896, 11.65189457], [92.69480896, 11.6524992], [92.69509888, 11.65294647], [92.69550323, 11.65315437], [92.69586945, 11.65329933], [92.69628906, 11.65334034], [92.69668579, 11.65340042], [92.69708252, 11.65356827], [92.6975174, 11.65362072], [92.69796753, 11.65372086], [92.69841003, 11.65394878], [92.69894409, 11.6541748], [92.69953156, 11.65439796], [92.7002182, 11.65449142], [92.70085907, 11.65467358], [92.70147705, 11.65466499], [92.70199585, 11.65443707], [92.7024231, 11.65412045], [92.70275879, 11.65374756], [92.70302582, 11.65334034], [92.70333099, 11.65295792], [92.70365143, 11.65257931], [92.70401001, 11.65225792], [92.70437622, 11.6519804], [92.70462799, 11.65162182], [92.70478058, 11.6512394], [92.70498657, 11.65090179], [92.70520782, 11.65055275], [92.70547485, 11.65015888], [92.7057724, 11.64969158], [92.70609283, 11.64914227], [92.70631409, 11.64848614], [92.70638275, 11.6477499], [92.70643616, 11.64707088], [92.70664215, 11.6465807], [92.70677948, 11.64614964], [92.70691681, 11.64580059], [92.7069931, 11.64544964], [92.70715332, 11.64517021], [92.70726776, 11.64486885], [92.70729065, 11.64461994], [92.70733643, 11.64425087], [92.70757294, 11.64409447], [92.70770264, 11.64380741], [92.70800018, 11.64336014], [92.7086792, 11.64326191], [92.70918274, 11.6433897], [92.70957947, 11.64354038], [92.71000671, 11.64356995], [92.71041107, 11.64361095], [92.71091461, 11.6437521], [92.71102142, 11.64375401], [92.71127319, 11.64376068], [92.71180725, 11.64375019], [92.71215057, 11.64431953], [92.71218109, 11.64470005], [92.71218109, 11.64503956], [92.71218109, 11.64544106], [92.71199036, 11.64586926], [92.71189117, 11.64638042], [92.71168518, 11.64685917], [92.7115097, 11.64736462], [92.71131897, 11.64784527], [92.71109772, 11.64830112], [92.71083069, 11.64876175], [92.71054077, 11.64929008], [92.71019745, 11.64988136], [92.70981598, 11.65048695], [92.70983887, 11.65122986], [92.71021271, 11.65180016], [92.71060944, 11.65226936], [92.71100616, 11.65246964], [92.711586, 11.65260029], [92.71212006, 11.65284061], [92.71273804, 11.65305996], [92.71331787, 11.65305996], [92.71385956, 11.65310287], [92.7143631, 11.65328121], [92.71483612, 11.6533289], [92.71527863, 11.65315056], [92.71569061, 11.65308094], [92.71607971, 11.65295124], [92.71653748, 11.65285015], [92.71704865, 11.652812], [92.71761322, 11.65285969], [92.71819305, 11.65295124], [92.71877289, 11.65295124], [92.71929169, 11.65307236], [92.71974945, 11.65304184], [92.7201767, 11.65312195], [92.72053528, 11.65331459], [92.72089386, 11.65349293], [92.72119141, 11.65370274], [92.72144318, 11.65396309], [92.72158813, 11.65434074], [92.72180939, 11.65471172], [92.72205353, 11.65507317], [92.72242737, 11.65531445], [92.72278595, 11.65553093], [92.72319031, 11.65567875], [92.72360992, 11.65581322], [92.72408295, 11.6558733], [92.72454071, 11.65593433], [92.72493744, 11.65601158], [92.72528076, 11.65610027], [92.72563171, 11.65616035], [92.72598267, 11.65633965], [92.72638702, 11.65651989], [92.72679901, 11.65676594], [92.72712708, 11.65716934], [92.72767639, 11.65701675], [92.72789764, 11.65695667], [92.72831726, 11.65702629], [92.72881317, 11.65723133], [92.72901917, 11.65744114], [92.72926331, 11.65829754], [92.72946167, 11.6585598], [92.72968292, 11.65886974], [92.72984314, 11.65923023], [92.72996521, 11.65964222], [92.72997284, 11.66007137], [92.72979736, 11.66048145], [92.72979736, 11.66086197], [92.72966766, 11.66118145], [92.72949982, 11.66140175], [92.72928619, 11.66146088], [92.72873688, 11.66152], [92.72834015, 11.66164112], [92.72786713, 11.66167068], [92.72734833, 11.66167068], [92.72679138, 11.66167068], [92.72623444, 11.66171169], [92.72576141, 11.66192436], [92.72528076, 11.66208267], [92.724823, 11.66220188], [92.72436523, 11.6622591], [92.72395325, 11.66240025], [92.72351074, 11.66248894], [92.72303772, 11.66250038], [92.72253418, 11.66253662], [92.7220459, 11.66267967], [92.72149658, 11.66281033], [92.72103119, 11.66304016], [92.72052002, 11.66322136], [92.71998596, 11.66335011], [92.71952057, 11.66353512], [92.71910095, 11.66372013], [92.71882629, 11.66399956], [92.71849823, 11.66419125], [92.71813202, 11.66435146], [92.71769714, 11.66443062], [92.71725464, 11.66448784], [92.71694946, 11.66478157], [92.71613312, 11.66475201], [92.71614075, 11.6658802], [92.71627045, 11.66630173], [92.716362, 11.66666031], [92.71646118, 11.66704273], [92.71663666, 11.66742134], [92.71683502, 11.6678791], [92.71714783, 11.66827965], [92.717453, 11.66870022], [92.71768951, 11.6690979], [92.71776581, 11.66945171], [92.71779633, 11.66974068], [92.71782684, 11.66997147], [92.71788788, 11.67018986], [92.71792603, 11.67044067], [92.71782684, 11.67076015], [92.71752167, 11.67115021], [92.71729279, 11.67161179], [92.71723175, 11.67210007], [92.71721649, 11.67255974], [92.71720123, 11.67297745], [92.71707916, 11.67334366], [92.71691895, 11.67370224], [92.71672058, 11.67404366], [92.71658325, 11.6744318], [92.71637726, 11.67480755], [92.71613312, 11.67519093], [92.71586609, 11.67564011], [92.71557617, 11.67615891], [92.71537781, 11.67682934], [92.71535492, 11.67755413], [92.71557617, 11.67807102], [92.71614838, 11.67822647], [92.71671295, 11.67843437], [92.71684265, 11.67864132], [92.71684265, 11.67892075], [92.71679688, 11.67899418], [92.71650696, 11.67947102], [92.71636963, 11.67988968], [92.71629333, 11.68038177], [92.71642303, 11.68097019], [92.71666718, 11.68148994], [92.71697235, 11.68190861], [92.71761322, 11.68183041], [92.71790314, 11.68190002], [92.71817017, 11.68225098], [92.71843719, 11.68280125], [92.71858978, 11.68314457], [92.71872711, 11.68328094], [92.71922302, 11.6838398], [92.7199173, 11.68417931], [92.72013092, 11.68453026], [92.72035217, 11.68507957], [92.72117615, 11.68590546], [92.72138977, 11.68604088], [92.72145844, 11.6863203], [92.72193146, 11.68640232], [92.72225189, 11.68576336], [92.72229004, 11.68525124], [92.72185516, 11.6851778], [92.72186279, 11.6848402], [92.72212982, 11.68448925], [92.72263336, 11.68414116], [92.7226944, 11.68400574], [92.72309875, 11.68401146], [92.72350311, 11.684412], [92.72379303, 11.6843214], [92.72416687, 11.68413353], [92.72428894, 11.6829443], [92.72457123, 11.68231964], [92.72512817, 11.68163586], [92.72568512, 11.68080616], [92.72624207, 11.68025017], [92.72694397, 11.68004704], [92.72743225, 11.68012047], [92.72801971, 11.68027973], [92.72843933, 11.68033504], [92.72879791, 11.68029594], [92.72917938, 11.68027973], [92.72957611, 11.68025017], [92.72997284, 11.68008232], [92.7303009, 11.67976475], [92.73060608, 11.67938042], [92.73087311, 11.67893124], [92.73110962, 11.67846107], [92.73134613, 11.6780014], [92.73139191, 11.67754269], [92.73143005, 11.67712975], [92.73143005, 11.67657185], [92.73136139, 11.67595387], [92.73136139, 11.67450523], [92.73149872, 11.67361069], [92.7321167, 11.67345238], [92.73241425, 11.67315292], [92.73279572, 11.67300701], [92.73320007, 11.67292118], [92.73361206, 11.67294121], [92.73394012, 11.67309093], [92.73413086, 11.67336273], [92.73414612, 11.67370892], [92.73412323, 11.67403316], [92.73435211, 11.67432022], [92.73451233, 11.67449093], [92.73460388, 11.6748209], [92.73455048, 11.67530918], [92.73451996, 11.67607021], [92.73493195, 11.67650986], [92.73503876, 11.67677689], [92.73522186, 11.67697334], [92.73548889, 11.67720127], [92.73587799, 11.67739201], [92.73632813, 11.67754269], [92.73680878, 11.67756081], [92.73719025, 11.67772007], [92.73743439, 11.67766094], [92.73767853, 11.67760181], [92.73818207, 11.67766094], [92.73864746, 11.67789078], [92.73908997, 11.67779064], [92.73950195, 11.67771816], [92.73993683, 11.67744923], [92.74053955, 11.67743301], [92.74101257, 11.67727566], [92.74138641, 11.67698193], [92.74169922, 11.67679024], [92.74182892, 11.67643929], [92.74202728, 11.67623043], [92.74238586, 11.67609119], [92.74308777, 11.67602158], [92.74350739, 11.67595387], [92.74448395, 11.67560768], [92.74489594, 11.67554188], [92.74575043, 11.67604065], [92.7461319, 11.67616367], [92.74662781, 11.67638016], [92.7472229, 11.67661953], [92.74788666, 11.67663097], [92.74855042, 11.67640972], [92.74913025, 11.6759901], [92.74958801, 11.67546177], [92.74982452, 11.67493057], [92.74977875, 11.67444992], [92.74954987, 11.67400455], [92.74933624, 11.67361069], [92.74924469, 11.67333508], [92.74928284, 11.67323971], [92.74916077, 11.67286968], [92.74916077, 11.67255974], [92.74954224, 11.67180824], [92.74968719, 11.67167187], [92.74982452, 11.67125702], [92.74954224, 11.67119122], [92.74912262, 11.67119122], [92.74854279, 11.67165089], [92.74833679, 11.67206097], [92.74771118, 11.67178059], [92.74749756, 11.67157841], [92.74755859, 11.67088985], [92.74771118, 11.67039967], [92.74777985, 11.66978168], [92.7480545, 11.66895485], [92.74826813, 11.66840267], [92.74847412, 11.66812706], [92.7488327, 11.6677103], [92.74910736, 11.66750526], [92.74952698, 11.66730022], [92.75002289, 11.66688061], [92.75043488, 11.6668148], [92.75134277, 11.66661167], [92.7514801, 11.66661167], [92.75161743, 11.66722965], [92.7516861, 11.66744137], [92.7517395, 11.66765976], [92.75209045, 11.6678896], [92.75257111, 11.66779041], [92.75315857, 11.66741562], [92.753479, 11.66646099], [92.75431061, 11.66650677], [92.75482178, 11.66657066], [92.75530243, 11.66618824], [92.75578308, 11.6658802], [92.75624847, 11.66572094], [92.75652313, 11.66541958], [92.75665283, 11.66507053], [92.75668335, 11.66469955], [92.75668335, 11.66432953], [92.75634003, 11.66393185], [92.75605011, 11.66350079], [92.75587463, 11.66305161], [92.7559433, 11.66257095], [92.7562027, 11.66187954], [92.7562027, 11.66133118], [92.7558136, 11.660923], [92.75566101, 11.66040134], [92.75546265, 11.66000938], [92.75524139, 11.65968132], [92.75496674, 11.65937996], [92.75473022, 11.6590519], [92.75454712, 11.65867138], [92.7544632, 11.65829086], [92.75448608, 11.65790844], [92.7546463, 11.65758038], [92.75480652, 11.65732193], [92.75505829, 11.65715313], [92.75533295, 11.65698528], [92.75572205, 11.65694618], [92.75617981, 11.65694141], [92.75669098, 11.65690327], [92.75721741, 11.65671825], [92.75778198, 11.65659046], [92.75830841, 11.65616035], [92.75823212, 11.65531445], [92.75809479, 11.65483093], [92.75760651, 11.65427876], [92.7571106, 11.65393066], [92.75697327, 11.65345001], [92.75683594, 11.65248108], [92.75704193, 11.65179539], [92.75788116, 11.65111065], [92.75788116, 11.65097046], [92.7578125, 11.65055084], [92.75746155, 11.65041637], [92.75718689, 11.65034962], [92.75697327, 11.64993095], [92.75701904, 11.64920807], [92.75688171, 11.64878178], [92.75666809, 11.64836121], [92.75641632, 11.64786053], [92.75621796, 11.64726353], [92.75604248, 11.64693832], [92.75527191, 11.64680195], [92.75498962, 11.64665985], [92.75450897, 11.64666271], [92.75429535, 11.64645481], [92.75408936, 11.64631557], [92.75388336, 11.64590073], [92.75345612, 11.64528084], [92.75324249, 11.64480114], [92.7530365, 11.64438057], [92.75227356, 11.64417839], [92.75151062, 11.64404202], [92.75073242, 11.64410782], [92.74968719, 11.64445019], [92.74919891, 11.64466095], [92.74871063, 11.64459133], [92.74807739, 11.64459133], [92.74804688, 11.64448833], [92.74794006, 11.64417839], [92.74758911, 11.64356136], [92.74738312, 11.64328003], [92.74723816, 11.64245129], [92.74719238, 11.6412859], [92.74688721, 11.64103127], [92.74653625, 11.64081192], [92.74637604, 11.64041138], [92.74617004, 11.63999367], [92.74662018, 11.63982964], [92.74748993, 11.64027596], [92.74794769, 11.64023781], [92.74828339, 11.64001179], [92.74855804, 11.63978195], [92.74877167, 11.63948059], [92.74892426, 11.63909817], [92.74897003, 11.6386404], [92.7489624, 11.63793087], [92.7489624, 11.63758945], [92.7490387, 11.63731098], [92.74952698, 11.63724136], [92.75024414, 11.63722706], [92.75061798, 11.63698959], [92.75096893, 11.6367712], [92.75118256, 11.63643169], [92.75139618, 11.63607788], [92.75161743, 11.63567924], [92.75177002, 11.63518047], [92.75196075, 11.63463783], [92.75219727, 11.63408184], [92.75235748, 11.63348007], [92.75247955, 11.63288975], [92.75247955, 11.63233089], [92.75237274, 11.63182545], [92.75224304, 11.63134003], [92.75198364, 11.63093376], [92.75172424, 11.6305418], [92.75152588, 11.63015461], [92.75119781, 11.62984943], [92.75093079, 11.62944126], [92.75051117, 11.62896061], [92.7504425, 11.62860966], [92.7506485, 11.62819672], [92.75128174, 11.62827015], [92.75177002, 11.62827015], [92.75209808, 11.62813091], [92.75246429, 11.62764072], [92.75248718, 11.62695026], [92.75249481, 11.62405586], [92.75242615, 11.62350178], [92.7518692, 11.62259293], [92.75193787, 11.62239933], [92.75228882, 11.6214304], [92.75222015, 11.62108612], [92.75209045, 11.62088108], [92.75193024, 11.62047958], [92.75193024, 11.61971188], [92.75209045, 11.61943054], [92.7527771, 11.61929226], [92.75312805, 11.61929226], [92.75403595, 11.61903667], [92.75428772, 11.61884975], [92.75448608, 11.61859035], [92.75467682, 11.61828136], [92.75468445, 11.61788177], [92.75454712, 11.61742973], [92.75424194, 11.61693096], [92.75382233, 11.61686325], [92.75326538, 11.61686325], [92.7530365, 11.61676502], [92.7527771, 11.61665535], [92.7527771, 11.61265087], [92.75291443, 11.61023712], [92.75285339, 11.609622], [92.75221252, 11.60851002], [92.75137329, 11.60782242], [92.75061035, 11.60706329], [92.7502594, 11.60727024], [92.75004578, 11.60734081], [92.74970245, 11.60706043], [92.74872589, 11.6060276], [92.7486496, 11.60540962], [92.74868011, 11.60458088], [92.7485199, 11.60429287], [92.74845123, 11.60388088], [92.74830627, 11.60319042], [92.74858093, 11.60286045], [92.74897003, 11.60278034], [92.74916077, 11.60234547], [92.74915314, 11.60171127], [92.74890137, 11.60098171], [92.74841309, 11.60037136], [92.74788666, 11.60003757], [92.74738312, 11.59986973], [92.74692535, 11.59970284], [92.74652863, 11.5994978], [92.74619293, 11.5995121], [92.74591827, 11.59963322], [92.74570465, 11.5995636], [92.74521637, 11.59922028], [92.74459076, 11.59852982], [92.74417114, 11.59797955], [92.74368286, 11.59708023], [92.74326324, 11.59673119], [92.74284363, 11.59618187], [92.74249268, 11.59562969], [92.74236298, 11.59521961], [92.7423172, 11.59468174], [92.74202728, 11.59426975], [92.74169922, 11.59382057], [92.74092865, 11.5931921], [92.74072266, 11.59257221], [92.74079132, 11.59112167], [92.74107361, 11.59043217], [92.74121094, 11.59001923], [92.74176788, 11.58967113], [92.74225616, 11.58987999], [92.74260712, 11.58995056], [92.74357605, 11.58982086], [92.74391937, 11.58967113], [92.74417114, 11.58944702], [92.74436188, 11.58924198], [92.74452972, 11.58903027], [92.74463654, 11.58875179], [92.74466705, 11.58841038], [92.74465179, 11.58801079], [92.74448395, 11.5876379], [92.74440002, 11.58724117], [92.74420929, 11.5868597], [92.74417114, 11.5864048], [92.74415588, 11.58588886], [92.74416351, 11.58535385], [92.744133, 11.58482456], [92.74396515, 11.5843401], [92.74385834, 11.58384037], [92.74362946, 11.58335018], [92.74343109, 11.58280087], [92.74291992, 11.58220196], [92.74265289, 11.58172989], [92.74259186, 11.58112621], [92.74259186, 11.58056068], [92.74250031, 11.58010006], [92.74224854, 11.57971096], [92.74209595, 11.57933044], [92.74188232, 11.5789814], [92.74149323, 11.57868958], [92.7408371, 11.57857132], [92.74028015, 11.57862091], [92.74025726, 11.57895184], [92.73996735, 11.57909107], [92.73941803, 11.57915688], [92.73892975, 11.57936382], [92.73886108, 11.57984734], [92.73831177, 11.57973957], [92.73815918, 11.5797081], [92.73802185, 11.57860088], [92.73788452, 11.57791519], [92.73783112, 11.57644939], [92.73781586, 11.57586956], [92.73802948, 11.57522964], [92.73864746, 11.57477379], [92.73911285, 11.57438374], [92.73928833, 11.57310104], [92.73928833, 11.57186127], [92.739151, 11.5708313], [92.73902893, 11.5703907], [92.73888397, 11.57004738], [92.73867798, 11.56970119], [92.73860931, 11.56956387], [92.73825836, 11.56866646], [92.73789978, 11.56827164], [92.73761749, 11.56786823], [92.73737335, 11.56750107], [92.73716736, 11.56717777], [92.73693085, 11.56692028], [92.7366333, 11.56669044], [92.73625946, 11.56654167], [92.73589325, 11.56637096], [92.73557281, 11.56613159], [92.73523712, 11.565938], [92.73490906, 11.56579018], [92.73464966, 11.56552982], [92.73426819, 11.56526089], [92.73401642, 11.56483936], [92.7337265, 11.56443977], [92.7335434, 11.56378174], [92.73337555, 11.56321716], [92.73313904, 11.56288242], [92.7328186, 11.5621109], [92.73267365, 11.56171513], [92.73226929, 11.56140518], [92.73192596, 11.56111145], [92.73166656, 11.56083488], [92.73137665, 11.5607214], [92.73113251, 11.56060028], [92.7307663, 11.56016922], [92.73053741, 11.55982971], [92.7303772, 11.55947018], [92.73036957, 11.559021], [92.73017883, 11.55842113], [92.73014069, 11.55784035], [92.73023224, 11.55729103], [92.7304306, 11.55680084], [92.73046875, 11.55628109], [92.7307663, 11.55587101], [92.73112488, 11.55555153], [92.73149872, 11.55521679], [92.73200226, 11.55494118], [92.73252106, 11.55471325], [92.73300934, 11.55445099], [92.73349762, 11.55417061], [92.73400116, 11.55388355], [92.73445892, 11.55355072], [92.73472595, 11.55311108], [92.73483276, 11.55264091], [92.73474121, 11.55219173], [92.73462677, 11.55174065], [92.73446655, 11.55136681], [92.73430634, 11.55101013], [92.73419952, 11.55064011], [92.73412323, 11.5502758], [92.73394775, 11.55000401], [92.7338562, 11.54968452], [92.73361206, 11.54979038], [92.73319244, 11.54993153], [92.73304749, 11.54979038], [92.73277283, 11.54971981], [92.73270416, 11.54951382], [92.73277283, 11.54916763], [92.73297882, 11.54896069], [92.73363495, 11.54879189], [92.73361206, 11.54848194], [92.7335968, 11.54810143], [92.73351288, 11.54768181], [92.73308563, 11.54729462], [92.7323761, 11.54716492], [92.73184967, 11.54717445], [92.73138428, 11.54725361], [92.73103333, 11.54704571], [92.730896, 11.546422], [92.730896, 11.54559708], [92.73132324, 11.54524994], [92.73152161, 11.5450449], [92.73180389, 11.54435444], [92.73194122, 11.54345894], [92.73195648, 11.54321861], [92.73197174, 11.54295063], [92.73189545, 11.54245377], [92.73168945, 11.54204559], [92.73152161, 11.54166126], [92.73134613, 11.54127979], [92.73110199, 11.54095173], [92.73082733, 11.54064178], [92.73053741, 11.54034996], [92.73017883, 11.5404892], [92.72975922, 11.54042053], [92.7293396, 11.54014015], [92.72891998, 11.54000378], [92.72864532, 11.53952026], [92.72836304, 11.53869343], [92.72815704, 11.53834724], [92.72786713, 11.53780174], [92.72766113, 11.53745079], [92.72731781, 11.53676033], [92.72682953, 11.53642082], [92.72653198, 11.53617668], [92.72647095, 11.53559971], [92.72631836, 11.53513145], [92.72622681, 11.53470039], [92.72606659, 11.53428078], [92.72579956, 11.53384972], [92.72551727, 11.53341007], [92.72489929, 11.53309345], [92.72462463, 11.53264904], [92.72460175, 11.53224087], [92.72476959, 11.53189182], [92.72467804, 11.53145695], [92.72445679, 11.53100967], [92.72420502, 11.53050613], [92.72384644, 11.53001022], [92.72371674, 11.52933979], [92.72366333, 11.52879047], [92.72366333, 11.52825928], [92.72363281, 11.52773952], [92.72366333, 11.52723122], [92.72386169, 11.52674961], [92.72405243, 11.52627182], [92.7243576, 11.52586174], [92.72478485, 11.52554512], [92.72519684, 11.52518463], [92.72548676, 11.52473068], [92.72556305, 11.52418041], [92.72557831, 11.52367115], [92.72554779, 11.52320576], [92.72569275, 11.52272797], [92.72601318, 11.5222187], [92.72625732, 11.52168179], [92.72653198, 11.52118015], [92.72676849, 11.52071953], [92.72673798, 11.52029991], [92.72693634, 11.51993084], [92.72695923, 11.51961708], [92.72705841, 11.51935005], [92.72724915, 11.51902199], [92.72749329, 11.51865864], [92.72775269, 11.51820087], [92.72793579, 11.51759148], [92.72799683, 11.51692963], [92.72793579, 11.51622963], [92.72741699, 11.51568985], [92.72692871, 11.51533699], [92.72615814, 11.51495075], [92.72548676, 11.51466179], [92.72490692, 11.51433086], [92.72451019, 11.5139389], [92.72393036, 11.51352024], [92.72372437, 11.51338577], [92.72372437, 11.51283169], [92.72393036, 11.51228237], [92.72384644, 11.5119772], [92.72361755, 11.51150131], [92.72335815, 11.5109396], [92.72311401, 11.51030922], [92.72278595, 11.50973034], [92.72245026, 11.50920773], [92.72203827, 11.50884056], [92.72171783, 11.50848103], [92.72149658, 11.50809097], [92.72129822, 11.50778103], [92.72107697, 11.50745964], [92.72091675, 11.50709724], [92.7205658, 11.50683975], [92.72020721, 11.50658035], [92.71983337, 11.5062561], [92.71952057, 11.50582123], [92.71948242, 11.5053196], [92.71943665, 11.50477028], [92.71938324, 11.50415134], [92.71927643, 11.50353336], [92.71891785, 11.50321198], [92.71844482, 11.50302505], [92.71821594, 11.50280094], [92.71768951, 11.50231075], [92.71775818, 11.50185966], [92.71773529, 11.50136089], [92.71810913, 11.50084114], [92.71810913, 11.50041008], [92.71811676, 11.49993038], [92.71808624, 11.4995718], [92.71781921, 11.4992094], [92.71750641, 11.49880123], [92.71675873, 11.49831963], [92.71645355, 11.49783516], [92.71649933, 11.49713516], [92.7168808, 11.49681187], [92.71699524, 11.49641705], [92.71701813, 11.49594975], [92.71695709, 11.49532127], [92.71677399, 11.49464226], [92.71672821, 11.49399471], [92.71672058, 11.49343586], [92.71594238, 11.49317169], [92.71504211, 11.49302101], [92.7145462, 11.49247169], [92.71434784, 11.49177933], [92.71427917, 11.49109077], [92.7144928, 11.49037075], [92.71437836, 11.48987198], [92.71407318, 11.48943615], [92.71372986, 11.48903084], [92.71331024, 11.48874092], [92.71292114, 11.48854065], [92.71266174, 11.48828983], [92.7125473, 11.48805141], [92.71231079, 11.48784065], [92.71221161, 11.48758125], [92.71214294, 11.4873209], [92.71215057, 11.48700047], [92.7121048, 11.48664856], [92.7121582, 11.4862318], [92.71229553, 11.48577213], [92.71246338, 11.48529339], [92.71250153, 11.48474121], [92.71255493, 11.48417568], [92.71269989, 11.48361111], [92.71263123, 11.48307991], [92.71247101, 11.48258972], [92.71230316, 11.48209095], [92.71224213, 11.48157978], [92.71216583, 11.48106956], [92.71218872, 11.48065472], [92.71226501, 11.48043156], [92.71193695, 11.48015118], [92.71190643, 11.47932243], [92.71190643, 11.47787189], [92.71170044, 11.47766018], [92.71156311, 11.47745514], [92.71128082, 11.47731781], [92.71092987, 11.47752094], [92.71071625, 11.47787189], [92.71044159, 11.47821426], [92.71030426, 11.47890472], [92.71009064, 11.47966099], [92.70987701, 11.48012161], [92.70963287, 11.48036098], [92.7093811, 11.48060036], [92.70900726, 11.48084164], [92.70845032, 11.48108101], [92.70793152, 11.48163891], [92.7077713, 11.48225689], [92.70761108, 11.48269939], [92.70755768, 11.48304844], [92.7075882, 11.48333073], [92.7075882, 11.48361111], [92.7074585, 11.48392963], [92.70722961, 11.48437023], [92.70697784, 11.48490143], [92.70678711, 11.48554134], [92.70705414, 11.48609734], [92.7073288, 11.48661041], [92.70765686, 11.48703861], [92.70800018, 11.48742199], [92.7086792, 11.48757744], [92.70893097, 11.48780918], [92.70913696, 11.48832607], [92.70922089, 11.48874092], [92.70922852, 11.4891901], [92.70935822, 11.48960972], [92.70921326, 11.4900198], [92.70909882, 11.49044228], [92.70889282, 11.49081135], [92.70862579, 11.49115467], [92.70832825, 11.49146938], [92.70796967, 11.49174118], [92.70748901, 11.49190712], [92.70685577, 11.49194145], [92.70613861, 11.49199772], [92.70552063, 11.49230576], [92.70516205, 11.49280262], [92.70500183, 11.49328995], [92.70490265, 11.4936924], [92.70475006, 11.49398994], [92.70469666, 11.49429798], [92.70458221, 11.49458027], [92.70446014, 11.49488068], [92.70436096, 11.49520016], [92.70420074, 11.49547195], [92.70407867, 11.49579144], [92.70392609, 11.49609089], [92.7039032, 11.49644947], [92.70388794, 11.49681187], [92.70384979, 11.49716282], [92.70365906, 11.49750519], [92.70355225, 11.49793053], [92.70337677, 11.49835014], [92.70329285, 11.49875069], [92.70333862, 11.49917126], [92.70309448, 11.49938679], [92.70262909, 11.49958134], [92.70225525, 11.49992657], [92.7019577, 11.50026035], [92.70170593, 11.50054932], [92.70155334, 11.50084591], [92.70139313, 11.50112247], [92.70118713, 11.50142002], [92.70094299, 11.50175095], [92.70063782, 11.50218964], [92.70014954, 11.50265121], [92.69985199, 11.50334072], [92.70001984, 11.5039587], [92.70027924, 11.50443077], [92.70046997, 11.50487137], [92.70043945, 11.50524044], [92.70024109, 11.50558186], [92.69992828, 11.50590134], [92.69950867, 11.50620174], [92.69909668, 11.50652122], [92.69863129, 11.50673008], [92.69827271, 11.50704956], [92.69790649, 11.50716114], [92.69757843, 11.507061], [92.69723511, 11.50691128], [92.69690704, 11.50660515], [92.69656372, 11.50615215], [92.69613647, 11.5056963], [92.69557953, 11.50571156], [92.69509125, 11.50558186], [92.69448853, 11.50551319], [92.69386292, 11.50542927], [92.69341278, 11.50579071], [92.69307709, 11.5062809], [92.69284058, 11.50673485], [92.69267273, 11.50706959], [92.69255066, 11.50732517], [92.69233704, 11.50752068], [92.6919632, 11.50766945], [92.69149017, 11.507761], [92.69100952, 11.50778103], [92.69056702, 11.50778103], [92.69017792, 11.50778103], [92.68979645, 11.50778103], [92.68939972, 11.50777721], [92.6889267, 11.50778103], [92.68843079, 11.50786114], [92.68795013, 11.50809097], [92.68753815, 11.50844002], [92.68718719, 11.5088501], [92.68686676, 11.50927162], [92.68660736, 11.5097208], [92.68636322, 11.5101614], [92.68608093, 11.51053047], [92.68579865, 11.51081944], [92.68551636, 11.51103973], [92.68519592, 11.51119995], [92.68482971, 11.51141167], [92.68441772, 11.51162243], [92.68421173, 11.51163292], [92.68392944, 11.51165104], [92.68350983, 11.5115099], [92.68312073, 11.5112114], [92.68267059, 11.51100159], [92.68219757, 11.51079178], [92.68170166, 11.51059437], [92.68118286, 11.51055527], [92.68070984, 11.51056862], [92.68032837, 11.51066017], [92.68002319, 11.5108099], [92.67970276, 11.51089001], [92.67947388, 11.51104927], [92.67919922, 11.51114273], [92.67893219, 11.51132107], [92.67864227, 11.5113802], [92.67836761, 11.51135921], [92.67813873, 11.5112114], [92.67789459, 11.51110554], [92.67765045, 11.51097202], [92.67741394, 11.51081657], [92.67719269, 11.51060009], [92.67694092, 11.51039791], [92.67668152, 11.51021099], [92.67642975, 11.51000118], [92.67616272, 11.50977135], [92.67590332, 11.50945187], [92.67559814, 11.50912094], [92.6753006, 11.50873184], [92.67507172, 11.50828743], [92.67489624, 11.50781059], [92.67472839, 11.50736427], [92.67457581, 11.5069418], [92.67446136, 11.50651169], [92.67436981, 11.50606728], [92.67414856, 11.50568199], [92.67385101, 11.50533962], [92.67352295, 11.50505066], [92.673172, 11.50484085], [92.6728363, 11.5046587], [92.67251587, 11.50444031], [92.67222595, 11.50421429], [92.67192078, 11.50397968], [92.67156219, 11.50378799], [92.67115784, 11.5036602], [92.67067719, 11.50376129], [92.67017365, 11.5039196], [92.66970825, 11.50410271], [92.66931152, 11.50402737], [92.66890717, 11.50391102], [92.66850281, 11.50388813], [92.66808319, 11.50389099], [92.66764069, 11.50389099], [92.6672287, 11.503932], [92.66694641, 11.50414085], [92.66660309, 11.50424862], [92.66625214, 11.50446033], [92.66587067, 11.50475025], [92.66545868, 11.50510979], [92.66508484, 11.50552654], [92.66467285, 11.50590324], [92.66432953, 11.50631142], [92.6639328, 11.50663853], [92.66362, 11.50700378], [92.66333771, 11.50738239], [92.66305542, 11.50778103], [92.66278076, 11.50820732], [92.66249084, 11.50866127], [92.66217041, 11.50912762], [92.66179657, 11.50957012], [92.66139984, 11.50998974], [92.66120148, 11.51043034], [92.66088104, 11.51100159], [92.66056824, 11.51148701], [92.66015625, 11.51169014], [92.65987396, 11.51203918], [92.65960693, 11.51267242], [92.65931702, 11.51314163], [92.65896606, 11.51350021], [92.65851593, 11.51376247], [92.65802765, 11.51396179], [92.65743256, 11.51412201], [92.65670776, 11.51410294], [92.65596008, 11.51416969], [92.65528107, 11.51442719], [92.65466309, 11.51477432], [92.65403748, 11.51513386], [92.65351868, 11.51546192], [92.65332031, 11.51580143], [92.65313721, 11.51606083], [92.6530304, 11.51637077], [92.65287781, 11.5167017], [92.65273285, 11.51705456], [92.65252686, 11.51735973], [92.65235138, 11.51763821], [92.6521759, 11.51781178], [92.65193939, 11.51786041], [92.65159607, 11.51780033], [92.65117645, 11.51785278], [92.65075684, 11.5181694], [92.6505127, 11.51866627], [92.65036774, 11.51914024], [92.650177, 11.51955128], [92.64994812, 11.51993084], [92.64964294, 11.52023029], [92.64925385, 11.52045822], [92.64878082, 11.52065372], [92.64824677, 11.52085018], [92.64771271, 11.52116203], [92.64723969, 11.5215807], [92.64688873, 11.52202129], [92.646698, 11.5223999], [92.64661407, 11.52270508], [92.64646149, 11.52292442], [92.64633179, 11.52324104], [92.64615631, 11.5236187], [92.64611053, 11.5241127], [92.64611816, 11.52488422], [92.64631653, 11.52549934], [92.64646149, 11.52612591], [92.64668274, 11.52701855], [92.64667511, 11.52729988], [92.64665222, 11.52770138], [92.64666748, 11.52803993], [92.64662933, 11.52838039], [92.646492, 11.52866268], [92.64639282, 11.52893829], [92.6463089, 11.529212], [92.64614868, 11.5294466], [92.64607239, 11.52976131], [92.64594269, 11.53008938], [92.64583588, 11.53053188], [92.64578247, 11.53105068], [92.64560699, 11.53157139], [92.64553833, 11.53211975], [92.64544678, 11.53259182], [92.64530182, 11.53297043], [92.64521027, 11.53328896], [92.64502716, 11.53358269], [92.64478302, 11.53390026], [92.64472961, 11.53435802], [92.64478302, 11.53485012], [92.64498138, 11.53526974], [92.64512634, 11.53567123], [92.64525604, 11.53610611], [92.64520264, 11.53657055], [92.64502716, 11.53698826], [92.64486694, 11.53738022], [92.64471436, 11.53778076], [92.64447021, 11.53813934], [92.64426422, 11.53854656], [92.6441803, 11.53905964], [92.64405823, 11.53989029], [92.6439209, 11.54072189], [92.64413452, 11.54133701], [92.64454651, 11.54168129], [92.64503479, 11.54221439], [92.64559937, 11.5425024], [92.6461792, 11.54275894], [92.64672852, 11.54297638], [92.6470871, 11.54327202], [92.64730835, 11.54369831], [92.64746857, 11.54414463], [92.6476593, 11.54446793], [92.64794922, 11.54475594], [92.64850616, 11.54504967], [92.649086, 11.54572201], [92.64935303, 11.54626179], [92.64966583, 11.54677868], [92.64988708, 11.54728127], [92.6500473, 11.54770947], [92.65016937, 11.54810143], [92.65029144, 11.54850483], [92.6504364, 11.54891968], [92.65059662, 11.54931164], [92.65080261, 11.5496397], [92.65105438, 11.54997921], [92.65104675, 11.5503006], [92.65099335, 11.55113029], [92.65062714, 11.55182076], [92.65007782, 11.55237007], [92.64930725, 11.55298996], [92.64819336, 11.55360985], [92.64714813, 11.55443954], [92.6462326, 11.55513], [92.64560699, 11.55566978], [92.64525604, 11.55602646], [92.64434814, 11.55644131], [92.64385986, 11.55671597], [92.64326477, 11.55717468], [92.64308929, 11.55751228], [92.64299011, 11.55792046], [92.64282227, 11.55830669], [92.64273834, 11.55873585], [92.64254761, 11.55912971], [92.64238739, 11.55955601], [92.64222717, 11.55999184], [92.64216614, 11.56049061], [92.64247894, 11.56103802], [92.6427002, 11.56151199], [92.64277649, 11.56203079], [92.64277649, 11.56269932], [92.64274597, 11.56348991], [92.64296722, 11.56387138], [92.64330292, 11.56414032], [92.64369202, 11.56441116], [92.64411926, 11.56470013], [92.6444397, 11.56516838], [92.64472198, 11.56564236], [92.64495087, 11.56608391], [92.64504242, 11.56654167], [92.64523315, 11.56694126], [92.64531708, 11.5674057], [92.64547729, 11.56787968], [92.64549255, 11.56838989], [92.64537811, 11.56887054], [92.64547729, 11.56952095], [92.64572906, 11.56980324], [92.64630127, 11.57021141], [92.64666748, 11.57061005], [92.6469574, 11.57101059], [92.64719391, 11.57141018], [92.64736176, 11.57180023], [92.64739227, 11.57213306], [92.6472702, 11.5723629], [92.64707947, 11.57250023], [92.64682007, 11.57260036], [92.64642334, 11.57269764], [92.64587402, 11.57277298], [92.64515686, 11.57277298], [92.64434814, 11.57274055], [92.64383698, 11.57287979], [92.64356995, 11.57316971], [92.64325714, 11.57339954], [92.64294434, 11.57360935], [92.64259338, 11.57378292], [92.64218903, 11.57387161], [92.64174652, 11.57388973], [92.64129639, 11.57393074], [92.64083099, 11.57411957], [92.64025116, 11.57426071], [92.63956451, 11.57455063], [92.63900757, 11.57499123], [92.63864899, 11.57546043], [92.6383667, 11.57584953], [92.63812256, 11.5761919], [92.63791656, 11.57651138], [92.63764954, 11.57678032], [92.63729858, 11.57703018], [92.63696289, 11.57736111], [92.63660431, 11.57770729], [92.63616943, 11.5779829], [92.63567352, 11.57821274], [92.63516998, 11.57846165], [92.63470459, 11.5787878], [92.63424683, 11.57905197], [92.63379669, 11.57916069], [92.63343811, 11.57917118], [92.63315582, 11.5791502], [92.6329422, 11.57904053], [92.63276672, 11.57882023], [92.63259125, 11.57855129], [92.63245392, 11.57820415], [92.63227081, 11.57785988], [92.63223267, 11.57744122], [92.63221741, 11.57696438], [92.63222504, 11.57641506], [92.63221741, 11.57580662], [92.63218689, 11.57518196], [92.6320343, 11.5746603], [92.63191223, 11.57416058], [92.63172913, 11.57375526], [92.63169098, 11.57336998], [92.63176727, 11.57295132], [92.63186646, 11.57252884], [92.63166046, 11.57214165], [92.63137817, 11.57173061], [92.6309967, 11.57141018], [92.63057709, 11.57122135], [92.63014984, 11.57135963], [92.62973022, 11.5715313], [92.62934875, 11.5716486], [92.62901306, 11.5716486], [92.62876129, 11.5715313], [92.62853241, 11.57139015], [92.62832642, 11.57124138], [92.62812042, 11.57108021], [92.6279068, 11.57086086], [92.62763214, 11.57063293], [92.62741089, 11.57021809], [92.6269989, 11.56984043], [92.62669373, 11.56938171], [92.6264267, 11.56892109], [92.62612915, 11.5685606], [92.62587738, 11.56819439], [92.6255722, 11.56787491], [92.62528992, 11.56744194], [92.62496185, 11.56694984], [92.62446594, 11.56655979], [92.62399292, 11.56616974], [92.62361908, 11.56575108], [92.62333679, 11.56534958], [92.62307739, 11.56498146], [92.62284851, 11.56462955], [92.62269592, 11.56421947], [92.62245941, 11.56386185], [92.62213135, 11.56355572], [92.62190247, 11.56315041], [92.62164307, 11.56276131], [92.62137604, 11.56237125], [92.62110901, 11.56205177], [92.62084198, 11.56177616], [92.62056732, 11.56157112], [92.62032318, 11.56142139], [92.62000275, 11.56140041], [92.61964417, 11.56147957], [92.61923218, 11.56167126], [92.61875153, 11.56195164], [92.61823273, 11.56229115], [92.61785889, 11.56282043], [92.617836, 11.56347179], [92.61797333, 11.56413269], [92.61804199, 11.56482124], [92.61804199, 11.56552124], [92.61798859, 11.56622314], [92.61804962, 11.56732082], [92.61860657, 11.56773186], [92.61885834, 11.56839943], [92.61902618, 11.56903076], [92.61921692, 11.56956196], [92.61940765, 11.57010174], [92.61955261, 11.57063961], [92.61974335, 11.57115269], [92.61991882, 11.57163811], [92.62002563, 11.57217121], [92.62018585, 11.57268047], [92.62020874, 11.5731287], [92.6202774, 11.5736208], [92.62024689, 11.57411098], [92.62017059, 11.57468128], [92.62026978, 11.57511806], [92.6202774, 11.57569027], [92.62026215, 11.57611179], [92.62030029, 11.57663155], [92.62039948, 11.57705784], [92.62030029, 11.57751083], [92.62023163, 11.577981], [92.62008667, 11.57840919], [92.62001038, 11.57884026], [92.6199646, 11.57926178], [92.61981964, 11.57964516], [92.61969757, 11.58007145], [92.61951447, 11.58052921], [92.61945343, 11.58108521], [92.61940002, 11.58165932], [92.61921692, 11.58218956], [92.61911774, 11.58272076], [92.618927, 11.58316994], [92.61880493, 11.58366966], [92.61859894, 11.58412075], [92.6183548, 11.58454514], [92.61817932, 11.58497143], [92.61798859, 11.58533955], [92.6177597, 11.58561993], [92.61746216, 11.58580112], [92.61705017, 11.58587074], [92.61669159, 11.58609009], [92.61636353, 11.58637047], [92.61597443, 11.58659077], [92.61551666, 11.58678055], [92.61508179, 11.58701992], [92.61482239, 11.58745956], [92.61460114, 11.58789539], [92.61440277, 11.5882616], [92.61419678, 11.58855057], [92.61406708, 11.58886147], [92.61386871, 11.5891304], [92.61361694, 11.58942413], [92.61334229, 11.5897913], [92.61303711, 11.59018612], [92.61270142, 11.59054089], [92.6124115, 11.59086037], [92.61221313, 11.59119129], [92.61197662, 11.5914917], [92.61178589, 11.59183121], [92.61161041, 11.59220028], [92.61138153, 11.59256268], [92.61110687, 11.59289074], [92.61079407, 11.59317112], [92.61044312, 11.59340096], [92.61000824, 11.59360027], [92.60955048, 11.59374142], [92.60909271, 11.59381199], [92.60865021, 11.5937109], [92.60798645, 11.59363365], [92.60762787, 11.59419918], [92.6073761, 11.59477997], [92.60762787, 11.59535503], [92.60780334, 11.59583092], [92.60803223, 11.59630966], [92.6082077, 11.59681988], [92.60830688, 11.59735107], [92.60838318, 11.59792995], [92.6085434, 11.59847927], [92.60861206, 11.59905148], [92.60868073, 11.59957123], [92.6088028, 11.6000042], [92.60865021, 11.60037136], [92.6085434, 11.6007309], [92.60837555, 11.60100937], [92.60826874, 11.60130119], [92.60810852, 11.60156059], [92.60798645, 11.60188198], [92.60777283, 11.60218143], [92.6072998, 11.60236835], [92.60720062, 11.60289383], [92.60709381, 11.60334301], [92.60691071, 11.60378075], [92.60668945, 11.60416794], [92.60655212, 11.6045742], [92.60640717, 11.60499954], [92.60634613, 11.60551071], [92.60614777, 11.60599136], [92.60598755, 11.60650635], [92.60585785, 11.60701942], [92.60582733, 11.60759068], [92.60575867, 11.60819054], [92.60555267, 11.60883141], [92.60566711, 11.60948086], [92.60610199, 11.6100893], [92.60632324, 11.61069965], [92.60643005, 11.61133099], [92.60652924, 11.61190605], [92.60671997, 11.61240005], [92.60700226, 11.6128397], [92.60743713, 11.61314106], [92.60778809, 11.61352921], [92.60809326, 11.61404991], [92.60826111, 11.61439037], [92.60848999, 11.61485481], [92.60864258, 11.61529922], [92.60868073, 11.61569786], [92.60856628, 11.61629105], [92.60845184, 11.61688614], [92.60855103, 11.61745071], [92.60848236, 11.61796093], [92.60832214, 11.61833668], [92.60822296, 11.61893177], [92.60823059, 11.61972141], [92.60842133, 11.62020397], [92.60897827, 11.62096119], [92.60983276, 11.6214962], [92.60990143, 11.62154007], [92.61030579, 11.62165356], [92.6109314, 11.62165356], [92.61143494, 11.62134838], [92.61190033, 11.62142086], [92.61235046, 11.62141037], [92.61277008, 11.62145138], [92.61315155, 11.6215353], [92.61351776, 11.62163067], [92.61387634, 11.62166023], [92.61422729, 11.62167168], [92.61457825, 11.6216507], [92.61499786, 11.62163067], [92.61530304, 11.62174034], [92.61557007, 11.62164688], [92.61569977, 11.6216011], [92.61610413, 11.6216011], [92.61654663, 11.62147999], [92.61698151, 11.62138462], [92.61743927, 11.62115669], [92.61782074, 11.62114143], [92.61823273, 11.62094021], [92.61865234, 11.62080383], [92.61903381, 11.62061214], [92.61928558, 11.62048435], [92.62017822, 11.61943436], [92.62088013, 11.61901855], [92.62185669, 11.61895084], [92.62213135, 11.6185379], [92.62262726, 11.61826038], [92.6233902, 11.61798191], [92.62422943, 11.61756897], [92.62444305, 11.61756897], [92.62464905, 11.61770821], [92.62485504, 11.61798382], [92.62493134, 11.61874294], [92.62513733, 11.61943054], [92.62520599, 11.61970997], [92.62520599, 11.62019253], [92.62516022, 11.6204319], [92.62545013, 11.62093067], [92.62561035, 11.62150097], [92.62581635, 11.62199974], [92.62600708, 11.62247181], [92.62635803, 11.62292957], [92.62650299, 11.62323093], [92.62663269, 11.62345028], [92.62693024, 11.62383175], [92.62736511, 11.62457848], [92.62754059, 11.62524128], [92.62785339, 11.62579918], [92.62844849, 11.62570953], [92.62890625, 11.62555981], [92.62932587, 11.6252594], [92.62956238, 11.62465954], [92.62970734, 11.62403107], [92.62980652, 11.62341976], [92.62992859, 11.62284756], [92.62999725, 11.62228012], [92.63006592, 11.62171078], [92.63009644, 11.62114143], [92.63012695, 11.62055111], [92.63018036, 11.61998081], [92.63033295, 11.61946106], [92.63031006, 11.61896038], [92.63008881, 11.61804771], [92.62993622, 11.61750126], [92.62966919, 11.61722088], [92.62988281, 11.61680984], [92.63028717, 11.61674023], [92.63085175, 11.61667061], [92.63189697, 11.61680984], [92.6322403, 11.61680984], [92.63259888, 11.61674023], [92.63308716, 11.61667061], [92.63363647, 11.61660099], [92.6342392, 11.61662102], [92.63447571, 11.61604023], [92.63459015, 11.61575317], [92.63493347, 11.6154089], [92.63549805, 11.6154089], [92.63606262, 11.61555004], [92.63654327, 11.61588955], [92.63716888, 11.61637497], [92.63772583, 11.61713028], [92.63800812, 11.61747837], [92.63857269, 11.61789131], [92.63906097, 11.61830616], [92.63954926, 11.61913109], [92.63989258, 11.61940861], [92.64052582, 11.61982059], [92.64108276, 11.62045002], [92.64126587, 11.62078953], [92.64134979, 11.62117958], [92.64157867, 11.6215601], [92.64177704, 11.62191963], [92.64196777, 11.62227821], [92.64221191, 11.62259007], [92.64259338, 11.62287998], [92.64295197, 11.62316227], [92.64328003, 11.62338257], [92.64363098, 11.6236496], [92.64395142, 11.62399197], [92.6441803, 11.62438202], [92.64435577, 11.6248312], [92.64450836, 11.62531185], [92.64459229, 11.62582874], [92.64460754, 11.62636185], [92.6446228, 11.62686443], [92.64466858, 11.62731266], [92.64476776, 11.62772083], [92.6448822, 11.62814045], [92.64502716, 11.62857056], [92.64504242, 11.62901974], [92.64511108, 11.62955093], [92.64515686, 11.62987041], [92.64512634, 11.63026047], [92.6452179, 11.63091087], [92.64520264, 11.63123131], [92.64530182, 11.6315794], [92.64524841, 11.63199043], [92.64520264, 11.63229275], [92.64525604, 11.63272095], [92.64502716, 11.6332407], [92.64502716, 11.63383102], [92.64488983, 11.63452625], [92.64460754, 11.63495922], [92.64465332, 11.63541031], [92.64451599, 11.63585854], [92.64438629, 11.6362896], [92.64420319, 11.63662529], [92.64409637, 11.63698101], [92.64391327, 11.63729954], [92.64373016, 11.63766003], [92.64369202, 11.63808155], [92.64360046, 11.63836193], [92.64312744, 11.63891125], [92.64286804, 11.63901234], [92.64241028, 11.63916016], [92.64176178, 11.63896084], [92.6413269, 11.63847065], [92.64112091, 11.63809967], [92.64083099, 11.63767147], [92.64054108, 11.63723183], [92.64025116, 11.63678932], [92.63990784, 11.63635635], [92.63961029, 11.63587093], [92.63928986, 11.63539886], [92.63899994, 11.63495922], [92.63871765, 11.6348114], [92.63842773, 11.63464165], [92.63780975, 11.63449192], [92.63724518, 11.63429642], [92.6366272, 11.63442993], [92.63603973, 11.6342907], [92.6354599, 11.63436031], [92.63521576, 11.63438034], [92.63485718, 11.63453102], [92.63444519, 11.63475609], [92.63420105, 11.63521194], [92.63404083, 11.63579082], [92.6341095, 11.63639736], [92.63426208, 11.63689041], [92.63417816, 11.63742065], [92.63424683, 11.63792896], [92.63444519, 11.63840294], [92.63461304, 11.63891411], [92.63475037, 11.63945103], [92.63494873, 11.63997078], [92.63504791, 11.6405592], [92.63529205, 11.64110565], [92.63563538, 11.64158916], [92.63625336, 11.64165306], [92.63684082, 11.64241028], [92.63684082, 11.64278984], [92.63703918, 11.64316177], [92.63720703, 11.64351082], [92.63735962, 11.643857], [92.63762665, 11.64423084], [92.63775635, 11.64465904], [92.63791656, 11.64516258], [92.63791656, 11.64555931], [92.63775635, 11.64583969], [92.63777924, 11.6461134], [92.63767242, 11.64644241], [92.63748169, 11.64679909], [92.63683319, 11.64697933], [92.63648224, 11.64742184], [92.63613892, 11.64789963], [92.63582611, 11.64839935], [92.63555145, 11.64883041], [92.63536072, 11.64914036], [92.63523102, 11.64966869], [92.6350708, 11.64978313], [92.63482666, 11.64995384], [92.63446808, 11.64966011], [92.63410187, 11.64971733], [92.63373566, 11.64972305], [92.63337708, 11.64972115], [92.63305664, 11.64975071], [92.63275909, 11.64985085], [92.63253021, 11.65010166], [92.63217926, 11.65065098], [92.63204193, 11.65086079], [92.63175964, 11.65086079], [92.63127136, 11.65043926], [92.63127136, 11.64975262], [92.63085175, 11.64906311], [92.63071442, 11.64795685], [92.63092041, 11.64665127], [92.6311264, 11.64596081], [92.63162231, 11.64451122], [92.63189697, 11.64334202], [92.63204193, 11.64216137], [92.63217926, 11.6411953], [92.63231659, 11.64072132], [92.63246155, 11.6403017], [92.63265228, 11.64021015], [92.63276672, 11.63976097], [92.63278198, 11.63915062], [92.63277435, 11.63855076], [92.63273621, 11.63796139], [92.63254547, 11.63742065], [92.63249969, 11.63683033], [92.63249969, 11.63626957], [92.63249969, 11.6357708], [92.63228607, 11.63532162], [92.63228607, 11.63501358], [92.63223267, 11.63459682], [92.63220215, 11.63422775], [92.63212585, 11.63391972], [92.6317215, 11.63359165], [92.63171387, 11.63309479], [92.63166046, 11.63260937], [92.63166046, 11.63213062], [92.63166046, 11.63164997], [92.63170624, 11.63120079], [92.63175964, 11.63076973], [92.63170624, 11.63031197], [92.63162231, 11.62994289], [92.63153839, 11.62953854], [92.63188934, 11.62924099], [92.63157654, 11.62871933], [92.6309967, 11.62825203], [92.63050079, 11.62814045], [92.62996674, 11.62801933], [92.62956238, 11.62805271], [92.62918091, 11.62804699], [92.62883759, 11.6280489], [92.62851715, 11.62793922], [92.62822723, 11.62800121], [92.62805939, 11.62794876], [92.62786865, 11.62789154], [92.62741852, 11.62789154], [92.62689972, 11.6280489], [92.6263504, 11.62818623], [92.62581635, 11.62834072], [92.62516785, 11.62842941], [92.62478638, 11.62879562], [92.62444305, 11.62895107], [92.62409973, 11.62917042], [92.62384033, 11.62952137], [92.62335968, 11.62976074], [92.62291718, 11.63014793], [92.62257385, 11.63058567], [92.62230682, 11.63101196], [92.62210083, 11.63136005], [92.62189484, 11.63160896], [92.62168884, 11.63179111], [92.62151337, 11.63197136], [92.621315, 11.63215828], [92.62106323, 11.63229275], [92.62075806, 11.63247013], [92.6204071, 11.63257122], [92.62008667, 11.63274193], [92.61975861, 11.63277054], [92.61942291, 11.63272095], [92.61904907, 11.6325407], [92.61862183, 11.63249969], [92.6181488, 11.63249779], [92.61762238, 11.63252068], [92.6170578, 11.63267994], [92.61600494, 11.63350105], [92.615448, 11.63398075], [92.61474609, 11.63446712], [92.61390686, 11.63467216], [92.61341858, 11.6348114], [92.6129303, 11.63502121], [92.61244202, 11.63516045], [92.61152649, 11.63516045], [92.61125183, 11.63502121], [92.61097717, 11.63475037], [92.61083221, 11.63447094], [92.61062622, 11.63399124], [92.6102829, 11.63386059], [92.60990143, 11.63369179], [92.60941315, 11.63362122], [92.6088562, 11.6336813], [92.60839844, 11.63402939], [92.60810852, 11.63451004], [92.60806274, 11.63504124], [92.60805511, 11.63554478], [92.60805511, 11.63604164], [92.60805511, 11.63654137], [92.60806274, 11.63704014], [92.60800934, 11.63753033], [92.60783386, 11.6379652], [92.60771942, 11.63844395], [92.60752106, 11.63887501], [92.6073761, 11.63932133], [92.6072464, 11.63976097], [92.60720825, 11.6402216], [92.60710144, 11.64067078], [92.60692596, 11.64112186], [92.60666656, 11.64157772], [92.60637665, 11.6420908], [92.60608673, 11.64264202], [92.60573578, 11.64316177], [92.60546112, 11.6436882], [92.6051712, 11.64415073], [92.60488892, 11.64457035], [92.60462189, 11.64497566], [92.60427856, 11.64532185], [92.60392761, 11.64568043], [92.60391235, 11.64611053], [92.60384369, 11.64672184], [92.60338593, 11.64737129], [92.60310364, 11.64783573], [92.60267639, 11.64830971], [92.60247803, 11.64876175], [92.60221863, 11.64910984], [92.60190582, 11.64941978], [92.60144043, 11.64965057], [92.60101318, 11.64986038], [92.60040283, 11.65019512], [92.59964752, 11.65034962], [92.59906769, 11.65099144], [92.59879303, 11.65167046], [92.59896088, 11.6522398], [92.59912872, 11.65273857], [92.59916687, 11.65318966], [92.59918213, 11.65360737], [92.59924316, 11.65398121], [92.59932709, 11.65431118], [92.5994873, 11.65456867], [92.59954071, 11.65482044], [92.59970856, 11.65507698], [92.5997467, 11.65533161], [92.59980774, 11.65559006], [92.5999527, 11.65588188], [92.59983063, 11.65616035], [92.59965515, 11.65635586], [92.59925842, 11.65662003], [92.59897614, 11.65709877], [92.59885406, 11.65769577], [92.59863281, 11.65823078], [92.59844971, 11.65876007], [92.5982666, 11.65923023], [92.59805298, 11.65966702], [92.59784698, 11.66008377], [92.59768677, 11.66050053], [92.59747314, 11.66084957], [92.59719086, 11.66116238], [92.59693146, 11.66154099], [92.59667206, 11.66193962], [92.59642029, 11.66235447], [92.59620667, 11.66280079], [92.59601593, 11.66327953], [92.5957489, 11.66372204], [92.59554291, 11.66420269], [92.59529114, 11.66459942], [92.59525299, 11.66497993], [92.5951767, 11.66516018], [92.59500885, 11.66537666], [92.59479523, 11.66563225], [92.59464264, 11.66592121], [92.59428406, 11.66629982], [92.59424591, 11.66670132], [92.59388733, 11.66691017], [92.59361267, 11.66698074], [92.59319305, 11.66691017], [92.59298706, 11.66655922], [92.59268188, 11.6666851], [92.59253693, 11.66679382], [92.59224701, 11.66685963], [92.59204865, 11.66722012], [92.59183502, 11.6679678], [92.59137726, 11.66884995], [92.59140015, 11.66938972], [92.59146118, 11.6699028], [92.59153748, 11.67041111], [92.59169006, 11.67084217], [92.59197235, 11.67116261], [92.59236145, 11.67139053], [92.59275055, 11.67165089], [92.59311676, 11.67198563], [92.59359741, 11.67224121], [92.59390259, 11.67239189], [92.59410858, 11.67249203], [92.59495544, 11.67237568], [92.59538269, 11.67264938], [92.59565735, 11.67300034], [92.59572601, 11.67348099], [92.59574127, 11.6739006], [92.59609985, 11.67431068], [92.59642029, 11.67472076], [92.59671021, 11.67513084], [92.59696198, 11.67559242], [92.59719849, 11.67608166], [92.59749603, 11.67651653], [92.59777069, 11.67695522], [92.59796906, 11.67740822], [92.59819031, 11.67782307], [92.59835052, 11.6782608], [92.598526, 11.67871189], [92.59860229, 11.67918777], [92.59861755, 11.67968273], [92.59860992, 11.68017006], [92.59857941, 11.68063068], [92.59844971, 11.68110943], [92.59855652, 11.68171597], [92.59861755, 11.68229008], [92.59867859, 11.68281746], [92.59870911, 11.68331337], [92.59870148, 11.68379211], [92.59870148, 11.68424129], [92.59876251, 11.68474674], [92.59906006, 11.68517971], [92.59908295, 11.68565178], [92.59909058, 11.68614388], [92.59909821, 11.68657017], [92.59909821, 11.68716145], [92.59909821, 11.68765068], [92.59906006, 11.68811131], [92.59910583, 11.68844128], [92.59910583, 11.68894958], [92.59919739, 11.68945122], [92.59919739, 11.68989277], [92.59938049, 11.69024181], [92.59958649, 11.69054127], [92.59966278, 11.69084072], [92.59951019, 11.69110107], [92.59942627, 11.69145203], [92.59931183, 11.69178867], [92.59914398, 11.69209003], [92.59893036, 11.69237328], [92.59874725, 11.69270992], [92.59848022, 11.69297028], [92.5982132, 11.69319057], [92.59802246, 11.69345093], [92.59777069, 11.69368076], [92.59741211, 11.6939497], [92.59690857, 11.69423485], [92.59645844, 11.69470406], [92.59622955, 11.69527435], [92.59613037, 11.69578934], [92.59619904, 11.6962204], [92.59634399, 11.69653702], [92.5963974, 11.69685364], [92.59642029, 11.69717979], [92.59644318, 11.69753075], [92.59638977, 11.69789124], [92.59630585, 11.69825077], [92.59609985, 11.69854927], [92.59583282, 11.69884109], [92.59555817, 11.69917202], [92.59527588, 11.69953156], [92.595047, 11.69991016], [92.59490967, 11.70034504], [92.59472656, 11.70075321], [92.5945282, 11.70114994], [92.59436798, 11.7015667], [92.59406281, 11.70189095], [92.59331512, 11.70211601], [92.59303284, 11.70246029], [92.59289551, 11.70315075], [92.59295654, 11.70377064], [92.59303284, 11.70440006], [92.59312439, 11.70504665], [92.59344482, 11.70555115], [92.59374237, 11.70600033], [92.59391785, 11.7065506], [92.59412384, 11.7071104], [92.5941925, 11.7077322], [92.59430695, 11.70829964], [92.59449005, 11.70879173], [92.59468842, 11.70918179], [92.59475708, 11.70950699], [92.59487152, 11.70970058], [92.59474945, 11.71055126], [92.59456635, 11.71073055], [92.5943985, 11.71104145], [92.59416962, 11.71136284], [92.59393311, 11.71166992], [92.59366608, 11.71197128], [92.59336853, 11.71224022], [92.59304047, 11.71249104], [92.59266663, 11.71277618], [92.59223175, 11.71303272], [92.59173584, 11.71326256], [92.59121704, 11.71350956], [92.59079742, 11.71387196], [92.5904007, 11.71419144], [92.59004974, 11.71451473], [92.58972168, 11.71486568], [92.58938599, 11.71523476], [92.58901215, 11.71560192], [92.58867645, 11.7160511], [92.58840942, 11.71652031], [92.58811951, 11.71677971], [92.5880661, 11.71753693], [92.58813477, 11.71788311], [92.58792877, 11.71795177], [92.58764648, 11.71788311], [92.58737183, 11.71733189], [92.58722687, 11.71677971], [92.58709717, 11.71629047], [92.58696747, 11.7160511], [92.58683014, 11.71572018], [92.58669281, 11.71533298], [92.58660126, 11.71487522], [92.58638763, 11.71448708], [92.58612823, 11.71417141], [92.58580017, 11.71399975], [92.5854187, 11.71420193], [92.58503723, 11.71455956], [92.58466339, 11.71498203], [92.584198, 11.71527576], [92.58370209, 11.71554947], [92.58322144, 11.71584129], [92.58277893, 11.71611023], [92.58236694, 11.71632671], [92.58190918, 11.71640205], [92.58148956, 11.71660042], [92.58104706, 11.71667099], [92.58053589, 11.71660042], [92.57994843, 11.71649075], [92.57936859, 11.7164793], [92.57885742, 11.71654129], [92.57834625, 11.71638966], [92.57788849, 11.71632195], [92.57744598, 11.71638966], [92.57702637, 11.71611023], [92.57663727, 11.71609402], [92.57624817, 11.71599388], [92.57583618, 11.71582985], [92.57483673, 11.71594143], [92.57441711, 11.71558952], [92.57414246, 11.71490192], [92.57407379, 11.71428013], [92.57406616, 11.71380138], [92.57421112, 11.71318054], [92.57427979, 11.71269131], [92.57442474, 11.71234989], [92.57441711, 11.71200085], [92.57427979, 11.71110725], [92.57433319, 11.71020889], [92.57424927, 11.70990562], [92.57377625, 11.70942974], [92.57371521, 11.70888996], [92.57363892, 11.70806026], [92.57385254, 11.70771599], [92.57385254, 11.70730114], [92.57378387, 11.70702457], [92.5734024, 11.70599079], [92.57327271, 11.70575142], [92.57292938, 11.7052002], [92.57286072, 11.70472145], [92.57279205, 11.70416069], [92.57279205, 11.70022869], [92.57272339, 11.69974995], [92.57254028, 11.69915104], [92.57211304, 11.69874763], [92.5716629, 11.69847202], [92.57122803, 11.69826031], [92.57086182, 11.69803905], [92.57050323, 11.69779968], [92.57009125, 11.69754028], [92.56964874, 11.69724083], [92.56919098, 11.69693089], [92.56884003, 11.69653034], [92.568573, 11.69605064], [92.56829834, 11.69557095], [92.56798553, 11.69515133], [92.56756592, 11.69489574], [92.56719208, 11.6946907], [92.56685638, 11.69450188], [92.56655121, 11.69436932], [92.56624603, 11.69416046], [92.565979, 11.6938324], [92.56584167, 11.6933279], [92.56567383, 11.69288635], [92.56539154, 11.69201088], [92.56510925, 11.69201088], [92.56483459, 11.69214725], [92.56445313, 11.69258022], [92.56402588, 11.69268131], [92.56365204, 11.69287014], [92.56328583, 11.69305038], [92.56295013, 11.69321632], [92.56260681, 11.6933918], [92.56231689, 11.69367409], [92.56208801, 11.69405937], [92.56182098, 11.69446087], [92.56156158, 11.69484997], [92.5613327, 11.69524002], [92.56111145, 11.69559097], [92.56091309, 11.6959219], [92.56076813, 11.69629955], [92.56063843, 11.69670105], [92.56050873, 11.69713402], [92.56031036, 11.69756889], [92.56023407, 11.69804764], [92.56005096, 11.69843292], [92.55999756, 11.69882965], [92.55996704, 11.6991806], [92.5598526, 11.69946957], [92.55974579, 11.69977093], [92.55966949, 11.70011139], [92.55950928, 11.70045185], [92.55944824, 11.70089245], [92.55939484, 11.7013731], [92.55919647, 11.70181084], [92.55909729, 11.70223522], [92.55898285, 11.70256996], [92.55883026, 11.70285034], [92.55870819, 11.70317078], [92.55857849, 11.70349979], [92.55839539, 11.70392799], [92.55819702, 11.70448685], [92.5579834, 11.70511055], [92.55776215, 11.70573997], [92.55751801, 11.70634174], [92.55734253, 11.7069273], [92.55715942, 11.70746136], [92.55693054, 11.707901], [92.55670929, 11.70828056], [92.55659485, 11.70869827], [92.556427, 11.70912457], [92.55631256, 11.70960331], [92.55613708, 11.71010017], [92.55605316, 11.71066093], [92.55583191, 11.71117592], [92.5555191, 11.71173191], [92.55510712, 11.71234703], [92.55522919, 11.71297169], [92.55513, 11.71352959], [92.5548172, 11.71469021], [92.55441284, 11.71558094], [92.55436707, 11.71587086], [92.55415344, 11.71643829], [92.55390167, 11.71694183], [92.55370331, 11.71741199], [92.5535202, 11.71780109], [92.55338287, 11.71811962], [92.55330658, 11.71840954], [92.55323029, 11.71866035], [92.5531311, 11.71887684], [92.55296326, 11.7190733], [92.55274963, 11.7193327], [92.55260468, 11.71977329], [92.55250549, 11.72028065], [92.55241394, 11.72078514], [92.5522995, 11.72126961], [92.5522995, 11.72179031], [92.55239105, 11.72234821], [92.55246735, 11.72292042], [92.55249786, 11.72348118], [92.55249786, 11.72398663], [92.55246735, 11.72443104], [92.55256653, 11.72484779], [92.55263519, 11.72526264], [92.5524826, 11.72580147], [92.5525589, 11.72614956], [92.55261993, 11.72655106], [92.5525589, 11.72699833], [92.55251312, 11.72760201], [92.55251312, 11.72870922], [92.55233002, 11.72998142], [92.55246735, 11.73035526], [92.55249786, 11.73071861], [92.55249786, 11.73110008], [92.55249786, 11.73152161], [92.55249786, 11.73202991], [92.55249786, 11.73498058], [92.55249786, 11.73543262], [92.55249786, 11.73588753], [92.55249786, 11.73639202], [92.55253601, 11.73695087], [92.552742, 11.73748589], [92.55304718, 11.73797226], [92.55332184, 11.73841095], [92.5535965, 11.73882198], [92.55378723, 11.73923016], [92.55391693, 11.73972034], [92.5541153, 11.74026012], [92.5541687, 11.74090004], [92.55416107, 11.74158859], [92.55410004, 11.74223995], [92.55387878, 11.74279022], [92.55361176, 11.74324989], [92.55336761, 11.74370098], [92.55325317, 11.74422073], [92.55309296, 11.74471092], [92.55304718, 11.74523067], [92.55304718, 11.74576187], [92.55304718, 11.74629021], [92.55305481, 11.74681664], [92.55304718, 11.74734974], [92.55305481, 11.74788761], [92.55310059, 11.74841499], [92.55329132, 11.74889088], [92.55332184, 11.74943066], [92.55332184, 11.74997139], [92.55331421, 11.75049782], [92.55330658, 11.75091934], [92.55330658, 11.75144958], [92.55335236, 11.75187016], [92.5533371, 11.75225925], [92.5533371, 11.75268078], [92.55332184, 11.75316048], [92.55325317, 11.75366974], [92.55304718, 11.75415134], [92.55278778, 11.75461197], [92.55252075, 11.75511837], [92.5522995, 11.75569439], [92.55224609, 11.75632763], [92.55235291, 11.75691986], [92.55251312, 11.75747204], [92.55269623, 11.75802135], [92.55282593, 11.75864124], [92.55309296, 11.75918102], [92.55332184, 11.75969601], [92.55349731, 11.76014996], [92.55355835, 11.76047134], [92.55354309, 11.76105499], [92.55310822, 11.76130104], [92.55301666, 11.76149178], [92.55287933, 11.76203918], [92.55276489, 11.76274776], [92.55289459, 11.76341438], [92.55306244, 11.76389217], [92.55329895, 11.76430225], [92.55356598, 11.7646904], [92.55387878, 11.76502037], [92.55418396, 11.76537132], [92.55439758, 11.76577854], [92.55471802, 11.76612091], [92.55506897, 11.76643085], [92.55562592, 11.76657009], [92.55606079, 11.76682091], [92.55667877, 11.76719189], [92.55715942, 11.7675209], [92.55764008, 11.76782131], [92.55804443, 11.76817036], [92.55838776, 11.76855755], [92.55869293, 11.76895428], [92.55898285, 11.76932144], [92.55918884, 11.76970863], [92.55934143, 11.77012062], [92.55941772, 11.7705698], [92.55943298, 11.77104187], [92.55937958, 11.77149105], [92.55924988, 11.77191925], [92.55909729, 11.77229977], [92.55911255, 11.77273083], [92.55930328, 11.77313614], [92.55922699, 11.77340126], [92.55898285, 11.77353954], [92.55861664, 11.77340126], [92.55799866, 11.77305031], [92.55722809, 11.77305412], [92.55645752, 11.77277946], [92.55605316, 11.77268982], [92.55599213, 11.77361012], [92.55591583, 11.77413177], [92.55578613, 11.77462006], [92.55555725, 11.77509022], [92.55526733, 11.77559566], [92.55509949, 11.77621078], [92.55519867, 11.7768898], [92.5552597, 11.77750778], [92.5552063, 11.77807999], [92.55504608, 11.77861118], [92.55496216, 11.77912807], [92.55478668, 11.77959538], [92.55471802, 11.78007221], [92.55462646, 11.78049564], [92.55446625, 11.78083134], [92.55439758, 11.78114128], [92.5542984, 11.78140068], [92.55416107, 11.78166866], [92.55397797, 11.78194141], [92.55383301, 11.78225136], [92.55377197, 11.78277493], [92.55377197, 11.78297997], [92.55370331, 11.78327179], [92.55342102, 11.78339672], [92.552742, 11.78351116], [92.55241394, 11.78403473], [92.55229187, 11.78470516], [92.55246735, 11.78533173], [92.5526123, 11.78591061], [92.55282593, 11.78635788], [92.55303192, 11.78675175], [92.55316925, 11.78721714], [92.55325317, 11.7876997], [92.55309296, 11.78820801], [92.55296326, 11.78875065], [92.55272675, 11.78919125], [92.55260468, 11.78974915], [92.55273438, 11.79031372], [92.55275726, 11.79095173], [92.55290222, 11.79140091], [92.55326843, 11.79190063], [92.55356598, 11.79238129], [92.55378723, 11.79258442], [92.55391693, 11.79301262], [92.55388641, 11.7933588], [92.55383301, 11.79374027], [92.55363464, 11.79415035], [92.55350494, 11.79463291], [92.55342865, 11.79515266], [92.5533371, 11.79566097], [92.55329132, 11.79615116], [92.55310822, 11.79653168], [92.55298615, 11.79691029], [92.55282593, 11.79724979], [92.55261993, 11.79755974], [92.55242157, 11.79791069], [92.55242157, 11.79839134], [92.55224609, 11.79881954], [92.55208588, 11.79930115], [92.55188751, 11.7997818], [92.55165863, 11.80025578], [92.55145264, 11.80072975], [92.5513916, 11.80130196], [92.55137634, 11.80185986], [92.55134583, 11.80237961], [92.55115509, 11.80282402], [92.55105591, 11.80331039], [92.55090332, 11.80377007], [92.55097198, 11.80421925], [92.55105591, 11.80462933], [92.55110168, 11.80498981], [92.5512619, 11.80531311], [92.55126953, 11.80546093], [92.55142212, 11.8057394], [92.55149078, 11.80602169], [92.55149078, 11.80642986], [92.55127716, 11.8068428], [92.55072021, 11.80753136], [92.55002594, 11.80804062], [92.54979706, 11.80866146], [92.54969025, 11.80933094], [92.54969788, 11.81002426], [92.54987335, 11.81069183], [92.54998016, 11.81127834], [92.55000305, 11.81186104], [92.55000305, 11.81247044], [92.54995728, 11.81305981], [92.54977417, 11.81359768], [92.54968262, 11.81414318], [92.54949188, 11.81463337], [92.54937744, 11.81516361], [92.54918671, 11.81564045], [92.54904175, 11.8161087], [92.54888153, 11.81650066], [92.5486908, 11.81680012], [92.54856873, 11.81709194], [92.54833221, 11.81733131], [92.547966, 11.81758595], [92.54751587, 11.8178854], [92.54705811, 11.81820202], [92.54666138, 11.81851196], [92.54626465, 11.81873512], [92.54588318, 11.81893063], [92.54545593, 11.81909084], [92.5450058, 11.81893063], [92.54418182, 11.81914997], [92.54361725, 11.81914997], [92.54321289, 11.81888103], [92.54271698, 11.8187418], [92.54247284, 11.81855011], [92.54193115, 11.81839466], [92.54141235, 11.81849289], [92.54106903, 11.81883144], [92.54087067, 11.81926155], [92.54083252, 11.81975174], [92.54083252, 11.82026196], [92.54083252, 11.82075882], [92.54083252, 11.82126045], [92.54081726, 11.82177544], [92.54078674, 11.82229042], [92.54088593, 11.82278061], [92.54103088, 11.82321072], [92.5411911, 11.82356453], [92.54136658, 11.82385159], [92.54150391, 11.82414627], [92.54165649, 11.82443142], [92.54181671, 11.82475185], [92.54197693, 11.8251009], [92.54225159, 11.8253994], [92.54260254, 11.82565022], [92.54297638, 11.82589436], [92.54331207, 11.82618999], [92.54361725, 11.82652092], [92.54396057, 11.82683086], [92.54438019, 11.82707024], [92.54477692, 11.82738018], [92.5451889, 11.82769203], [92.54560089, 11.827981], [92.54588318, 11.82839203], [92.54614258, 11.82879066], [92.5463562, 11.8291893], [92.54651642, 11.82957935], [92.54662323, 11.82993031], [92.54664612, 11.83026981], [92.54666901, 11.83060741], [92.54666901, 11.83096886], [92.54666901, 11.83137131], [92.54664612, 11.83178139], [92.54650879, 11.83215046], [92.5463028, 11.83249187], [92.54640198, 11.83364964], [92.54640198, 11.83494663], [92.54632568, 11.83515358], [92.54605103, 11.8350172], [92.54576874, 11.83440018], [92.54563141, 11.83343124], [92.54532623, 11.83229065], [92.54501343, 11.83194733], [92.54473114, 11.83156013], [92.54447937, 11.83113098], [92.54426575, 11.83065701], [92.54406738, 11.83018112], [92.54384613, 11.82978153], [92.54361725, 11.82946968], [92.54338837, 11.82923031], [92.54312897, 11.82909107], [92.5429306, 11.82894993], [92.54263306, 11.82866096], [92.54216003, 11.82874012], [92.54216766, 11.82927132], [92.54208374, 11.82960892], [92.54219055, 11.83005333], [92.54222107, 11.83051109], [92.54222107, 11.83096886], [92.54222107, 11.83142281], [92.54222107, 11.83187199], [92.54222107, 11.83232117], [92.54217529, 11.83274937], [92.54199219, 11.83314133], [92.54191589, 11.83358955], [92.54180908, 11.83402061], [92.54168701, 11.83444118], [92.54165649, 11.83488274], [92.54162598, 11.83530426], [92.5414505, 11.83567142], [92.54129791, 11.83606625], [92.54106903, 11.8364296], [92.54081726, 11.83679867], [92.54051971, 11.83712101], [92.54013062, 11.83735561], [92.53969574, 11.83754539], [92.53926849, 11.83778191], [92.53883362, 11.83803463], [92.53830719, 11.83821011], [92.53774261, 11.83837032], [92.53720093, 11.83856964], [92.53697205, 11.83856773], [92.5366745, 11.83856583], [92.53623199, 11.8383379], [92.5358429, 11.83805084], [92.53547668, 11.83769131], [92.53517151, 11.83723927], [92.53482056, 11.83676147], [92.53443909, 11.83629608], [92.53407288, 11.83586025], [92.53371429, 11.83547306], [92.53350067, 11.83500385], [92.53331757, 11.83453178], [92.5330658, 11.83409214], [92.53281403, 11.83364964], [92.53246307, 11.83327961], [92.53214264, 11.83287525], [92.53178406, 11.83258343], [92.53140259, 11.83247089], [92.5311203, 11.83306599], [92.53104401, 11.83327389], [92.53070068, 11.83327389], [92.5304184, 11.83299828], [92.5304184, 11.83250999], [92.53035736, 11.83190632], [92.53013611, 11.83164024], [92.52990723, 11.83131123], [92.52960205, 11.83099174], [92.52919769, 11.83067131], [92.52881622, 11.83025169], [92.52848816, 11.82974052], [92.52810669, 11.82923031], [92.52773285, 11.82874012], [92.52725983, 11.8283577], [92.52680206, 11.82796955], [92.52633667, 11.82758045], [92.52583313, 11.82719994], [92.52535248, 11.82677078], [92.5249176, 11.82629871], [92.52472687, 11.8260603], [92.52432251, 11.82604885], [92.52390289, 11.82605076], [92.52355194, 11.82584095], [92.52296448, 11.82557487], [92.52230835, 11.82588196], [92.52186584, 11.82642937], [92.521492, 11.826931], [92.52114105, 11.82739067], [92.52083588, 11.82788086], [92.52055359, 11.82835484], [92.5202713, 11.82877922], [92.51999664, 11.8291893], [92.51972198, 11.82961082], [92.51944733, 11.8300581], [92.51920319, 11.83053398], [92.51906586, 11.83106327], [92.51887512, 11.83156204], [92.51862335, 11.83205032], [92.51834106, 11.83261013], [92.51805878, 11.83323002], [92.51774597, 11.83390045], [92.51763916, 11.83459759], [92.51767731, 11.83522034], [92.51803589, 11.83568954], [92.5182724, 11.83605194], [92.51846313, 11.83640099], [92.51863861, 11.83674526], [92.51882172, 11.83711243], [92.51909637, 11.83757687], [92.51909637, 11.83809185], [92.51909637, 11.83861065], [92.51888275, 11.83910084], [92.5187912, 11.83952141], [92.51864624, 11.83989239], [92.51860809, 11.84029102], [92.51856995, 11.8406992], [92.51847076, 11.84109116], [92.51824951, 11.84237194], [92.51818085, 11.84292126], [92.51789856, 11.8432703], [92.51754761, 11.84389019], [92.51727295, 11.84437084], [92.51719666, 11.84447098], [92.51703644, 11.84464169], [92.516922, 11.84492016], [92.51673889, 11.84517097], [92.51639557, 11.84530735], [92.51611328, 11.84555054], [92.51583099, 11.84582043], [92.51548004, 11.84603024], [92.51507568, 11.84614754], [92.51473236, 11.84638119], [92.51439667, 11.84667015], [92.51394653, 11.84692097], [92.51364899, 11.84738827], [92.51351929, 11.84800053], [92.51373291, 11.84868145], [92.5139389, 11.84932995], [92.51417542, 11.84989452], [92.51445007, 11.8503809], [92.51473236, 11.85082054], [92.51499939, 11.85122395], [92.5152359, 11.85157967], [92.51535797, 11.85195065], [92.51542664, 11.85229111], [92.51552582, 11.85262108], [92.51557159, 11.85299683], [92.51564026, 11.85340977], [92.51584625, 11.85381985], [92.51609802, 11.85426712], [92.5163269, 11.85474968], [92.51657867, 11.85522938], [92.51693726, 11.85559273], [92.51731873, 11.85577106], [92.51770782, 11.85591888], [92.51818085, 11.8565321], [92.51847076, 11.85689926], [92.51856995, 11.8572979], [92.51860809, 11.85775375], [92.51857758, 11.85823154], [92.51847839, 11.85874081], [92.51860046, 11.85928059], [92.51874542, 11.85982132], [92.51891327, 11.86023998], [92.51920319, 11.86061859], [92.51948547, 11.86100197], [92.51967621, 11.86135864], [92.5197525, 11.86179924], [92.5198822, 11.862257], [92.52002716, 11.8627634], [92.5202179, 11.86325073], [92.5202713, 11.86380959], [92.5202713, 11.8643589], [92.52030945, 11.86495781], [92.52048492, 11.86556244], [92.52059937, 11.86622334], [92.52086639, 11.86685181], [92.52127075, 11.86739922], [92.5214386, 11.8679781], [92.52169037, 11.86837196], [92.52184296, 11.86872959], [92.5220871, 11.86894894], [92.5222702, 11.86919308], [92.52245331, 11.86944103], [92.52268982, 11.86967087], [92.5230484, 11.86975956], [92.52339172, 11.86992741], [92.52375793, 11.87010384], [92.52419281, 11.87016106], [92.52436066, 11.87076092], [92.52468109, 11.87103939], [92.5248642, 11.87135983], [92.52494049, 11.87170029], [92.52485657, 11.87208652], [92.52472687, 11.87254333], [92.52459717, 11.87308121], [92.52448273, 11.8736763], [92.52449799, 11.87426567], [92.52466583, 11.87474918], [92.52490997, 11.8752737], [92.52471161, 11.87564087], [92.52465057, 11.87607956], [92.5245285, 11.87656975], [92.5246048, 11.87709045], [92.52462769, 11.87761021], [92.52461243, 11.87815857], [92.52474976, 11.87863064], [92.52505493, 11.87906837], [92.52527618, 11.87942219], [92.52549744, 11.87976074], [92.52568817, 11.88013268], [92.52588654, 11.88049126], [92.52613068, 11.88080025], [92.52635956, 11.88110065], [92.52648926, 11.8814497], [92.52658081, 11.8818264], [92.52675629, 11.88216114], [92.52687073, 11.88251019], [92.52688599, 11.88286781], [92.52672577, 11.88322258], [92.52664948, 11.88363075], [92.5265274, 11.88403034], [92.52641296, 11.88440228], [92.52636719, 11.88476181], [92.52629089, 11.88508129], [92.52617645, 11.8853817], [92.52575684, 11.88573933], [92.52577209, 11.88617897], [92.5258255, 11.88669205], [92.52585602, 11.88726044], [92.52583313, 11.88787937], [92.52583313, 11.88852024], [92.52583313, 11.88916874], [92.52583313, 11.88982105], [92.52587891, 11.8904686], [92.52606201, 11.89106083], [92.52610779, 11.89168072], [92.52613831, 11.89227962], [92.52625275, 11.89284134], [92.52633667, 11.8933897], [92.52638245, 11.89394665], [92.52639008, 11.89450264], [92.52642059, 11.89502239], [92.52658081, 11.89544201], [92.52681732, 11.89576054], [92.52702332, 11.89614964], [92.52713776, 11.89622593], [92.52728271, 11.8963213], [92.52767181, 11.89618015], [92.52812195, 11.89612103], [92.52858734, 11.89610004], [92.52902222, 11.89610481], [92.5294342, 11.89611244], [92.5298233, 11.89616203], [92.53013611, 11.89635563], [92.53047943, 11.89654922], [92.53078461, 11.89686203], [92.53124237, 11.89703178], [92.53159332, 11.89733124], [92.53188324, 11.89770031], [92.53230286, 11.89795971], [92.53275299, 11.89818954], [92.53318787, 11.8984499], [92.53369141, 11.89868259], [92.53425598, 11.89890099], [92.53481293, 11.89917946], [92.53533936, 11.89953518], [92.53578949, 11.89997005], [92.53608704, 11.90054035], [92.53639221, 11.90111923], [92.53671265, 11.90170002], [92.53704071, 11.90223789], [92.53730011, 11.90275955], [92.53751373, 11.90322685], [92.53774261, 11.90360069], [92.53783417, 11.90399837], [92.53800201, 11.9043417], [92.53806305, 11.9047308], [92.53801727, 11.90515137], [92.53784943, 11.90559101], [92.53765106, 11.90604019], [92.53756714, 11.9064703], [92.53734589, 11.90673733], [92.53717041, 11.90694427], [92.53695679, 11.90711975], [92.53672028, 11.90732956], [92.53643036, 11.90746021], [92.53617096, 11.90764046], [92.53583527, 11.90786457], [92.53547668, 11.9081707], [92.53525543, 11.90860844], [92.53502655, 11.9090004], [92.53489685, 11.90941048], [92.53475952, 11.90978909], [92.53468323, 11.91025066], [92.53449249, 11.91073036], [92.53444672, 11.91127014], [92.53447723, 11.91178131], [92.53468323, 11.91217709], [92.53491974, 11.9124918], [92.53518677, 11.91276836], [92.53549957, 11.91302967], [92.53581238, 11.91338539], [92.5361557, 11.91378021], [92.53659058, 11.91413975], [92.53704834, 11.91447735], [92.53747559, 11.91488266], [92.53785706, 11.91535187], [92.53824615, 11.91577244], [92.53876495, 11.91603374], [92.53931427, 11.9162817], [92.5398941, 11.91655254], [92.54048157, 11.91683102], [92.54090881, 11.91722107], [92.54122162, 11.91763115], [92.54141235, 11.91808033], [92.54160309, 11.91850567], [92.54165649, 11.91900063], [92.54167175, 11.91954136], [92.54171753, 11.92006969], [92.54189301, 11.92052078], [92.54193878, 11.92103195], [92.54199219, 11.92157173], [92.54219818, 11.9221096], [92.54238892, 11.92267036], [92.54260254, 11.92320156], [92.54297638, 11.92352104], [92.54347992, 11.92373943], [92.54405975, 11.92387199], [92.54470825, 11.92389202], [92.54535675, 11.92389202], [92.54595184, 11.9239397], [92.5464325, 11.92416954], [92.54688263, 11.92444134], [92.54736328, 11.92468452], [92.5479126, 11.92486095], [92.54847717, 11.92506599], [92.54899597, 11.92537117], [92.54955292, 11.92561054], [92.55001068, 11.92589092], [92.55047607, 11.92613029], [92.55088043, 11.92615986], [92.55119324, 11.92602062], [92.55193329, 11.92571068], [92.55239868, 11.92555618], [92.55296326, 11.9254694], [92.55348206, 11.92551041], [92.55377197, 11.92544174], [92.55429077, 11.92521191], [92.55479431, 11.92523193], [92.55499268, 11.92542076], [92.55497742, 11.92582893], [92.55503845, 11.92638969], [92.5552063, 11.92707062], [92.55528259, 11.92780113], [92.55536652, 11.92852592], [92.55558014, 11.92915154], [92.55590057, 11.9296608], [92.55626678, 11.93011189], [92.55651855, 11.93064976], [92.55690002, 11.93101025], [92.55721283, 11.93134022], [92.55744171, 11.93165493], [92.55757141, 11.932024], [92.55780792, 11.93229294], [92.55802155, 11.93257141], [92.55858612, 11.93307018], [92.55900574, 11.93382931], [92.55956268, 11.93438053], [92.56026459, 11.93527889], [92.56025696, 11.93600082], [92.56027985, 11.93626976], [92.5602417, 11.93663025], [92.56008911, 11.93705177], [92.55996704, 11.93757057], [92.55974579, 11.93805027], [92.55957031, 11.93843079], [92.55967712, 11.938941], [92.55960846, 11.93915081], [92.5594635, 11.93928528], [92.55918884, 11.93935394], [92.55870056, 11.93935394], [92.55834198, 11.93936253], [92.5581665, 11.93991375], [92.55838013, 11.94041443], [92.55873108, 11.94080067], [92.55909729, 11.94111061], [92.55943298, 11.94139957], [92.5597229, 11.94168091], [92.56001282, 11.94200039], [92.56027985, 11.9423418], [92.5605545, 11.94270897], [92.56082153, 11.94311047], [92.56101227, 11.9435606], [92.56103516, 11.94402599], [92.56109619, 11.94444084], [92.56118011, 11.94485569], [92.56139374, 11.94525242], [92.5616684, 11.94570255], [92.56198883, 11.94617271], [92.56240082, 11.94647408], [92.56288147, 11.94631004], [92.5630188, 11.94515038], [92.56321716, 11.94480133], [92.56350708, 11.94452477], [92.56378937, 11.9440403], [92.56441498, 11.94362926], [92.56490326, 11.94335079], [92.56537628, 11.94322395], [92.56554413, 11.94282913], [92.56565857, 11.94242096], [92.56582642, 11.9420414], [92.56598663, 11.94165611], [92.56614685, 11.94126129], [92.56635284, 11.94089031], [92.56648254, 11.94048023], [92.56664276, 11.9400692], [92.56671143, 11.93961143], [92.5668869, 11.93916035], [92.56698608, 11.93862915], [92.5672226, 11.93814754], [92.56745911, 11.93764019], [92.56763458, 11.93709087], [92.56781006, 11.9365406], [92.56806183, 11.93605137], [92.56832123, 11.93560028], [92.568573, 11.93518066], [92.5687561, 11.9347477], [92.56896973, 11.93435955], [92.56918335, 11.93396091], [92.56941223, 11.93356037], [92.56955719, 11.93307495], [92.56971741, 11.93257141], [92.56987, 11.93207645], [92.57003021, 11.93159962], [92.57028198, 11.93120575], [92.57055664, 11.93081188], [92.57083893, 11.93035984], [92.57116699, 11.92984962], [92.5716095, 11.92936039], [92.57202911, 11.92881012], [92.57245636, 11.92828178], [92.5728302, 11.92785645], [92.57315063, 11.92708969], [92.57343292, 11.92695141], [92.57454681, 11.92695141], [92.57524872, 11.92674065], [92.57629395, 11.92674065], [92.57653809, 11.92679977], [92.5769577, 11.9268074], [92.57738495, 11.92697334], [92.57776642, 11.92708969], [92.57811737, 11.92720127], [92.57840729, 11.92718124], [92.5786438, 11.92702389], [92.57887268, 11.92684078], [92.57907867, 11.92659092], [92.579216, 11.92623043], [92.579422, 11.92586803], [92.57956696, 11.92545128], [92.57975769, 11.92508411], [92.57997894, 11.92476654], [92.58014679, 11.92444134], [92.58027649, 11.92410183], [92.58042145, 11.92375088], [92.58053589, 11.92336082], [92.58061218, 11.92292976], [92.58078766, 11.92254734], [92.58082581, 11.92210102], [92.58088684, 11.92164898], [92.58101654, 11.92122078], [92.58087921, 11.92077732], [92.58082581, 11.92029095], [92.58080292, 11.91975975], [92.5806427, 11.91924], [92.58056641, 11.91869068], [92.58055878, 11.91811371], [92.58060455, 11.91753578], [92.58082581, 11.91706181], [92.58109283, 11.91663837], [92.58126831, 11.9162302], [92.58141327, 11.91587162], [92.58158875, 11.91561031], [92.58167267, 11.91532326], [92.58176422, 11.91504669], [92.58190918, 11.91477966], [92.58197021, 11.91441059], [92.58209991, 11.91399384], [92.5821991, 11.91350365], [92.58222198, 11.9129591], [92.58226776, 11.91240978], [92.58245087, 11.91190624], [92.58252716, 11.91135025], [92.58273315, 11.91081047], [92.58291626, 11.91025066], [92.58309174, 11.90966129], [92.58332825, 11.90912056], [92.58349609, 11.90858078], [92.58335876, 11.90804482], [92.58321381, 11.90748692], [92.58304596, 11.90695095], [92.58287048, 11.90642929], [92.5825882, 11.90598869], [92.58252716, 11.90558243], [92.5825882, 11.90518856], [92.58275604, 11.90483189], [92.58287811, 11.90445995], [92.58305359, 11.90410709], [92.58320618, 11.90373993], [92.58339691, 11.90338039], [92.58364105, 11.90303993], [92.58393097, 11.90272141], [92.58418274, 11.90234089], [92.58442688, 11.90197086], [92.58463287, 11.90159988], [92.58474731, 11.90117073], [92.58492279, 11.90072918], [92.58499146, 11.90022087], [92.58499908, 11.89969921], [92.58499908, 11.89920044], [92.58499908, 11.89873981], [92.58503723, 11.89827919], [92.58519745, 11.89782143], [92.58526611, 11.89731979], [92.58532715, 11.89682102], [92.58551788, 11.89639187], [92.58563995, 11.8959198], [92.58579254, 11.89546204], [92.5858078, 11.89496517], [92.58569336, 11.89445019], [92.58550262, 11.8939209], [92.58526611, 11.89338779], [92.58500671, 11.89284134], [92.58483887, 11.89227104], [92.58496094, 11.89171124], [92.58499908, 11.89118195], [92.58505249, 11.89074039], [92.58521271, 11.89038181], [92.58531952, 11.89000416], [92.58553314, 11.88968468], [92.58571625, 11.88929272], [92.58591461, 11.88888454], [92.58613586, 11.88848114], [92.58638, 11.88813496], [92.58660889, 11.88783169], [92.58677673, 11.88753986], [92.58698273, 11.88731194], [92.58720398, 11.88712692], [92.58743286, 11.88693142], [92.587677, 11.88673115], [92.58805847, 11.88663006], [92.58840942, 11.88642979], [92.58887482, 11.88634586], [92.58930206, 11.88615227], [92.58976746, 11.88611126], [92.59026337, 11.88614273], [92.59072876, 11.88630009], [92.59118652, 11.88640499], [92.59156036, 11.88656044], [92.59185028, 11.88673973], [92.59203339, 11.88701057], [92.59216309, 11.88741016], [92.59237671, 11.88789082], [92.59247589, 11.88846111], [92.59249878, 11.8891058], [92.59250641, 11.88976192], [92.59255219, 11.89037132], [92.59268951, 11.89089012], [92.59278107, 11.89140129], [92.59288788, 11.89191055], [92.59301758, 11.89243507], [92.59306335, 11.89303017], [92.59308624, 11.89364147], [92.59326172, 11.89411068], [92.59343719, 11.89444065], [92.59358215, 11.89473057], [92.59375, 11.89498806], [92.59382629, 11.89523029], [92.59379578, 11.89546204], [92.59390259, 11.89568996], [92.59371185, 11.89602089], [92.59333038, 11.89649868], [92.59321594, 11.8977232], [92.5933609, 11.89793015], [92.59364319, 11.89868927], [92.59378052, 11.89882755], [92.59399414, 11.89898586], [92.59438324, 11.89914131], [92.59481812, 11.89911556], [92.59519196, 11.89895439], [92.59547424, 11.89871693], [92.5957489, 11.89855003], [92.59597778, 11.8983202], [92.59733582, 11.89659023], [92.59783173, 11.89623928], [92.59817505, 11.89617252], [92.59838867, 11.89617252], [92.59858704, 11.89623928], [92.59880829, 11.896451], [92.59895325, 11.8966608], [92.59908295, 11.89710999], [92.59934235, 11.89727879], [92.59955597, 11.89748096], [92.59976959, 11.89768028], [92.60002136, 11.89782143], [92.60025024, 11.8979969], [92.60053253, 11.89805126], [92.60083771, 11.89801025], [92.60111237, 11.89778233], [92.60138702, 11.89749527], [92.60163879, 11.89715099], [92.60179901, 11.89668083], [92.60196686, 11.89619064], [92.6021347, 11.89569473], [92.60202026, 11.89512253], [92.60211182, 11.89454842], [92.60220337, 11.8939724], [92.60218048, 11.89341068], [92.6019516, 11.89290047], [92.60169983, 11.89242554], [92.60150146, 11.89191055], [92.60133362, 11.89135456], [92.60115814, 11.89080811], [92.6011734, 11.89025021], [92.60137939, 11.88973045], [92.60160828, 11.88922024], [92.60180664, 11.8887434], [92.60195923, 11.88827419], [92.60199738, 11.88783836], [92.60214233, 11.88737965], [92.6020813, 11.88691139], [92.60215759, 11.88645267], [92.60221863, 11.88601112], [92.60220337, 11.88560009], [92.60212708, 11.885252], [92.60206604, 11.88492107], [92.60192108, 11.8845911], [92.60173035, 11.88430595], [92.60164642, 11.88399124], [92.60150146, 11.88371468], [92.60140991, 11.88343143], [92.60138702, 11.88311195], [92.60138702, 11.88276958], [92.60138702, 11.8824234], [92.60138702, 11.88204861], [92.60138702, 11.88165665], [92.60138702, 11.88124943], [92.60137177, 11.8808279], [92.60125732, 11.88044262], [92.60114288, 11.88007069], [92.60111237, 11.87968826], [92.60112762, 11.87930107], [92.60124207, 11.87889957], [92.60138702, 11.87847137], [92.6015625, 11.87799931], [92.60164642, 11.87743187], [92.60167694, 11.87677956], [92.60171509, 11.87609196], [92.60189819, 11.87540054], [92.60193634, 11.87470055], [92.60191345, 11.87403107], [92.60176849, 11.87343025], [92.60167694, 11.87289047], [92.60166931, 11.87242222], [92.60165405, 11.87202835], [92.6015625, 11.87171078], [92.60137177, 11.87146282], [92.60116577, 11.8712244], [92.60105133, 11.87094116], [92.60089111, 11.87069035], [92.60080719, 11.87039185], [92.60070038, 11.87011147], [92.60057831, 11.86983109], [92.60047913, 11.86952114], [92.60031891, 11.86920929], [92.60028076, 11.86875057], [92.60027313, 11.86821079], [92.60028076, 11.86764145], [92.60031128, 11.86709595], [92.60045624, 11.86662197], [92.60054016, 11.86612129], [92.6006012, 11.86562061], [92.60079193, 11.86517906], [92.60090637, 11.86468029], [92.60112, 11.86423969], [92.60137177, 11.86382961], [92.60157776, 11.86341286], [92.60175323, 11.86297798], [92.60193634, 11.86258125], [92.60209656, 11.86221027], [92.60220337, 11.86186314], [92.60223389, 11.86150455], [92.60231781, 11.8611517], [92.60249329, 11.86079407], [92.60268402, 11.86036777], [92.60289001, 11.85990143], [92.60323334, 11.85948753], [92.60366058, 11.85921001], [92.60369873, 11.85850143], [92.60385132, 11.85836697], [92.60415649, 11.85818005], [92.60427094, 11.85816193], [92.60462189, 11.85829639], [92.60475922, 11.85871124], [92.60500336, 11.85915089], [92.60491943, 11.85943127], [92.60498047, 11.85974121], [92.60497284, 11.86013126], [92.6048584, 11.86055946], [92.60472107, 11.86099529], [92.60456085, 11.86141014], [92.60443115, 11.86183071], [92.60430908, 11.86221027], [92.60419464, 11.86256504], [92.60415649, 11.86294079], [92.60412598, 11.8633194], [92.60399628, 11.86367512], [92.60388184, 11.86410427], [92.60375977, 11.86457062], [92.6036377, 11.86506081], [92.60359955, 11.86555958], [92.60359955, 11.86606789], [92.60379028, 11.86657429], [92.60402679, 11.86707973], [92.60430145, 11.86758137], [92.60459137, 11.86795998], [92.60488129, 11.86828995], [92.6052475, 11.86856174], [92.60560608, 11.86888981], [92.60603333, 11.86918068], [92.60654449, 11.86947823], [92.60707092, 11.86981487], [92.60771942, 11.87004089], [92.60837555, 11.87028694], [92.6089859, 11.87034416], [92.60993195, 11.87022305], [92.61035156, 11.87029362], [92.61048889, 11.87036037], [92.61062622, 11.87063789], [92.61077118, 11.87105274], [92.61104584, 11.87125969], [92.61104584, 11.87181187], [92.61103821, 11.87263203], [92.61109924, 11.87317371], [92.6111145, 11.87373543], [92.61110687, 11.87426186], [92.61110687, 11.87473965], [92.6111145, 11.87518501], [92.61110687, 11.87561131], [92.61109924, 11.87602997], [92.61103821, 11.87646103], [92.61095428, 11.87689877], [92.61103058, 11.87737942], [92.61123657, 11.87784004], [92.61135864, 11.8782959], [92.61147308, 11.87870121], [92.61154175, 11.87907982], [92.61151123, 11.87938976], [92.61141205, 11.87971115], [92.61134338, 11.8801012], [92.61113739, 11.88048553], [92.6109848, 11.88096237], [92.6108551, 11.881464], [92.61083221, 11.88196087], [92.61083221, 11.88244057], [92.61062622, 11.88325119], [92.61048126, 11.88387012], [92.61039734, 11.88608074], [92.61013794, 11.88704967], [92.6102066, 11.88849926], [92.61054993, 11.88870525], [92.61052704, 11.88922024], [92.61044312, 11.88971043], [92.61024475, 11.88981915], [92.61010742, 11.8907814], [92.61010742, 11.89120007], [92.61026764, 11.89175415], [92.61026764, 11.89214134], [92.61016846, 11.89293003], [92.6100769, 11.89375114], [92.61011505, 11.8945303], [92.6102066, 11.89524555], [92.6102829, 11.89592934], [92.61039734, 11.89658833], [92.61060333, 11.89715958], [92.61035919, 11.89777088], [92.61031342, 11.89830875], [92.61035156, 11.89867115], [92.61042023, 11.89934444], [92.61042023, 11.90071964], [92.61048889, 11.90128136], [92.61052704, 11.90167141], [92.61065674, 11.90187073], [92.61067963, 11.90227032], [92.61068726, 11.90279865], [92.61080933, 11.90331364], [92.61096954, 11.90384007], [92.61100006, 11.90442085], [92.61096191, 11.90500927], [92.61093903, 11.90553093], [92.6108017, 11.90604877], [92.61055756, 11.90655041], [92.61035156, 11.90709019], [92.61044312, 11.90764618], [92.61062622, 11.9081707], [92.61081696, 11.90868092], [92.61097717, 11.90918922], [92.61128235, 11.90963554], [92.61132813, 11.91016483], [92.61125183, 11.91073036], [92.61136627, 11.91129112], [92.61144257, 11.91186142], [92.61149597, 11.91240978], [92.6116333, 11.91279697], [92.61166382, 11.91315269], [92.61164856, 11.91351128], [92.61154938, 11.91385937], [92.61135864, 11.91419029], [92.61109924, 11.91453171], [92.61078644, 11.91490841], [92.61039734, 11.91531086], [92.61005402, 11.91580582], [92.60982513, 11.91640282], [92.60965729, 11.9169817], [92.60945892, 11.91742611], [92.60926819, 11.91771984], [92.60912323, 11.91800976], [92.60896301, 11.91809177], [92.60856628, 11.91808033], [92.60809326, 11.91825104], [92.60756683, 11.91819191], [92.60713196, 11.91802979], [92.60639191, 11.91770935], [92.60600281, 11.91784763], [92.60599518, 11.91884232], [92.60611725, 11.91940022], [92.60632324, 11.91996956], [92.60645294, 11.92051697], [92.60648346, 11.92108154], [92.60634613, 11.92164326], [92.60616302, 11.92220974], [92.6060791, 11.92281628], [92.60600281, 11.92341328], [92.60620117, 11.92397022], [92.60642242, 11.92451191], [92.60665131, 11.92501068], [92.60687256, 11.92549038], [92.60719299, 11.92582035], [92.6075058, 11.92610073], [92.60782623, 11.92642021], [92.60807037, 11.92684078], [92.60832977, 11.92724037], [92.60852051, 11.92767143], [92.60871887, 11.92804241], [92.60890198, 11.92837143], [92.60907745, 11.9286871], [92.60915375, 11.92905426], [92.60916901, 11.92950344], [92.60916901, 11.93003178], [92.60920715, 11.93061066], [92.60940552, 11.93112755], [92.60949707, 11.93169117], [92.60970306, 11.93221092], [92.60983276, 11.93274403], [92.60996246, 11.93327141], [92.61000824, 11.93382168], [92.61009216, 11.93435097], [92.61029053, 11.93482971], [92.61049652, 11.93527031], [92.61051941, 11.93578243], [92.61048889, 11.93629074], [92.61049652, 11.93676853], [92.61068726, 11.93709087], [92.61074829, 11.93751717], [92.61075592, 11.93799973], [92.61083984, 11.93849945], [92.61096191, 11.93900013], [92.61110687, 11.93943977], [92.61129761, 11.93990993], [92.61149597, 11.94036102], [92.61155701, 11.9408989], [92.61142731, 11.94150829], [92.61138153, 11.94184017], [92.61159515, 11.94218922], [92.61160278, 11.94253063], [92.61138153, 11.94267178], [92.61123657, 11.94316006], [92.61096191, 11.94371128], [92.61048889, 11.94393921], [92.61009979, 11.94433975], [92.60964966, 11.94479179], [92.60919952, 11.9453001], [92.60889435, 11.9459362], [92.60865784, 11.94656277], [92.60856628, 11.94720078], [92.60837555, 11.94776821], [92.60836792, 11.94831276], [92.60852814, 11.94884396], [92.60864258, 11.94941235], [92.6088562, 11.94994926], [92.6089859, 11.95051003], [92.60913849, 11.95105934], [92.60916901, 11.95163059], [92.60917664, 11.95219898], [92.60923004, 11.95277309], [92.60930634, 11.95337009], [92.60936737, 11.95401096], [92.60920715, 11.95467186], [92.60907745, 11.95534039], [92.60900879, 11.95599079], [92.60925293, 11.95652008], [92.60971832, 11.95692635], [92.61024475, 11.9572134], [92.61103058, 11.95714188], [92.61116791, 11.95713997], [92.61151886, 11.95734978], [92.61193848, 11.95776463], [92.61221313, 11.957901], [92.6122818, 11.9581089], [92.6122818, 11.95839119], [92.6120224, 11.95852566], [92.61218262, 11.95885181], [92.6122818, 11.95929813], [92.6126709, 11.9597702], [92.61283112, 11.96028996], [92.61295319, 11.96070004], [92.61302185, 11.961092], [92.61300659, 11.96138763], [92.61305237, 11.96173], [92.61319733, 11.96210861], [92.6132431, 11.96248531], [92.61328888, 11.96281147], [92.61332703, 11.96321201], [92.61332703, 11.9636898], [92.61333466, 11.96424198], [92.61332703, 11.9648304], [92.61328125, 11.96542931], [92.61306763, 11.96588135], [92.61289215, 11.96629333], [92.6129303, 11.966712], [92.61302185, 11.96712971], [92.61305237, 11.96754932], [92.61294556, 11.96809101], [92.61264801, 11.96863365], [92.61251831, 11.96912193], [92.61241913, 11.96964836], [92.61251831, 11.9701128], [92.61260223, 11.97049999], [92.61264038, 11.97078991], [92.61270142, 11.97119999], [92.61270142, 11.97154045], [92.61271667, 11.9718504], [92.61258698, 11.97215652], [92.61250305, 11.97249222], [92.61239624, 11.97284126], [92.61222839, 11.97330761], [92.61207581, 11.97379112], [92.61222839, 11.97425175], [92.61228943, 11.97472095], [92.61231232, 11.97518158], [92.61234283, 11.9756403], [92.61247253, 11.97607517], [92.61267853, 11.97650433], [92.61261749, 11.97700119], [92.61258698, 11.97756577], [92.61257172, 11.97820377], [92.61264801, 11.97879028], [92.61264038, 11.97913074], [92.61250305, 11.97941875], [92.61234283, 11.97978115], [92.61222839, 11.9802103], [92.61212921, 11.9806242], [92.61197662, 11.98099136], [92.61194611, 11.9814291], [92.61194611, 11.98190975], [92.61194611, 11.98244953], [92.61194611, 11.98302174], [92.61196136, 11.98357964], [92.61206055, 11.98410034], [92.61222839, 11.98453999], [92.61241913, 11.98496246], [92.61252594, 11.98543072], [92.61268616, 11.98592567], [92.61275482, 11.98648357], [92.61278534, 11.9870224], [92.61283112, 11.9874754], [92.61299896, 11.9878006], [92.61305237, 11.98816586], [92.61306, 11.98853111], [92.61309814, 11.98889542], [92.61325836, 11.98920059], [92.61341095, 11.98952198], [92.61360168, 11.98984623], [92.61383057, 11.99020386], [92.61426544, 11.99035168], [92.61463928, 11.99044132], [92.6151123, 11.99049091], [92.61566925, 11.99055862], [92.61597443, 11.99056053], [92.61641693, 11.99059963], [92.6167984, 11.99084187], [92.61699677, 11.99121094], [92.61695862, 11.9914093], [92.6169281, 11.99168301], [92.61694336, 11.99202919], [92.61685944, 11.99242115], [92.61666107, 11.99276066], [92.61641693, 11.99304581], [92.61624908, 11.99334431], [92.61606598, 11.99363995], [92.61580658, 11.99392128], [92.61555481, 11.99422646], [92.61488342, 11.99468899], [92.61440277, 11.99510098], [92.61403656, 11.99545002], [92.6138382, 11.99606991], [92.6133728, 11.99759007], [92.61332703, 11.99785042], [92.61334229, 11.99814606], [92.61332703, 11.99831963], [92.61340332, 11.99889183], [92.61360931, 11.99999905], [92.61370087, 12.00055981], [92.61360931, 12.00111103], [92.61360168, 12.0022192], [92.61332703, 12.00249863], [92.6131897, 12.00300503], [92.61318207, 12.00360012], [92.61302185, 12.0041914], [92.61289978, 12.00470066], [92.61297607, 12.00526905], [92.61295319, 12.00596428], [92.61306, 12.00660038], [92.61329651, 12.00722027], [92.61348724, 12.00788116], [92.61380768, 12.00853539], [92.61412811, 12.00915241], [92.61436462, 12.00969219], [92.61451721, 12.01015091], [92.61467743, 12.01049709], [92.61476898, 12.01082325], [92.61493683, 12.01109886], [92.61509705, 12.01140594], [92.6151123, 12.01178932], [92.61502838, 12.01226139], [92.61496735, 12.01283073], [92.61487579, 12.01350117], [92.61486816, 12.01419067], [92.6151886, 12.01470661], [92.61550903, 12.01517105], [92.6157074, 12.01567078], [92.61573792, 12.01612186], [92.61576843, 12.01657104], [92.61592865, 12.01696968], [92.61604309, 12.01736164], [92.6159668, 12.01776981], [92.61592865, 12.01817989], [92.6160202, 12.01852608], [92.61608124, 12.01882935], [92.61611176, 12.01913738], [92.61612701, 12.01947212], [92.61621094, 12.01982975], [92.61638641, 12.0201807], [92.61660767, 12.02052975], [92.61678314, 12.02089024], [92.61695099, 12.0212698], [92.61712646, 12.02159023], [92.61720276, 12.02188969], [92.61717224, 12.02219105], [92.61698151, 12.02248955], [92.61683655, 12.02287006], [92.61670685, 12.02328968], [92.61666107, 12.0237999], [92.61666107, 12.02439976], [92.61672974, 12.02503967], [92.61694336, 12.02555466], [92.61722565, 12.02555466], [92.61750031, 12.02527714], [92.61805725, 12.02583313], [92.61833191, 12.02583313], [92.6186142, 12.02555466], [92.62055206, 12.02555466], [92.62194824, 12.02694321], [92.6222229, 12.02694321], [92.62249756, 12.02722073], [92.62249756, 12.0274992], [92.62277985, 12.02777672], [92.62278748, 12.0283289], [92.62249756, 12.02862072], [92.62249756, 12.02917004], [92.62233734, 12.02942085], [92.62214661, 12.02978992], [92.62190247, 12.03010178], [92.62159729, 12.03035069], [92.62120819, 12.03058147], [92.62081909, 12.03085041], [92.62043762, 12.03114986], [92.62017059, 12.03151989], [92.62001801, 12.03195286], [92.61991882, 12.03238964], [92.61976624, 12.03278923], [92.61972809, 12.03322506], [92.61978912, 12.03372097], [92.62111664, 12.0352211], [92.62166595, 12.03563118], [92.62188721, 12.03623104], [92.62194824, 12.03666592], [92.62194824, 12.03693867], [92.62149048, 12.03805161], [92.62089539, 12.03808784], [92.6202774, 12.03833199], [92.6202774, 12.03861046], [92.62000275, 12.03889275], [92.62000275, 12.03916645], [92.61972046, 12.03944397], [92.61972046, 12.03971958], [92.61984253, 12.03999996], [92.61988068, 12.04031944], [92.61973572, 12.04057693], [92.61968994, 12.04117203], [92.62010193, 12.04149055], [92.62055206, 12.04139137], [92.62166595, 12.04073048], [92.6222229, 12.04055595], [92.62277985, 12.04111004], [92.62314606, 12.04123974], [92.62333679, 12.04139137], [92.62403107, 12.04162979], [92.625, 12.04166603], [92.62527466, 12.04194355], [92.62555695, 12.04194355], [92.6258316, 12.04222012], [92.62610626, 12.04250145], [92.6269455, 12.04250145], [92.6277771, 12.04333019], [92.6277771, 12.04388905], [92.62770081, 12.04410458], [92.62750244, 12.04439926], [92.62750244, 12.04498005], [92.62750244, 12.04528141], [92.62741852, 12.04555511], [92.62750244, 12.04583263], [92.62750244, 12.0466671], [92.62722015, 12.04694462], [92.62722015, 12.04722118], [92.62695313, 12.04750061], [92.62695313, 12.04778099], [92.62610626, 12.04861069], [92.625, 12.04861069], [92.62473297, 12.04889107], [92.6241684, 12.04889107], [92.62388611, 12.04861069], [92.62333679, 12.04861069], [92.62304688, 12.04833126], [92.62249756, 12.04833126], [92.6222229, 12.04861069], [92.62166595, 12.04934025], [92.62133789, 12.05024147], [92.62166595, 12.05119133], [92.62156677, 12.05163097], [92.62164307, 12.05173969], [92.621521, 12.05202103], [92.62090302, 12.05245972], [92.62063599, 12.05285931], [92.62082672, 12.05362034], [92.6213913, 12.05416965], [92.62249756, 12.05416679], [92.62277985, 12.05444336], [92.6230545, 12.05444336], [92.62333679, 12.05472088], [92.62361145, 12.05472088], [92.62388611, 12.05499935], [92.62412262, 12.05485058], [92.62420654, 12.05526638], [92.62429047, 12.05576134], [92.62437439, 12.05626869], [92.62457275, 12.05646038], [92.62477875, 12.05672932], [92.62496948, 12.05707264], [92.62509155, 12.05751991], [92.62520599, 12.05799866], [92.62531281, 12.05844975], [92.62533569, 12.05891705], [92.62526703, 12.05944061], [92.62527466, 12.06055641], [92.62555695, 12.06083393], [92.62555695, 12.06193924], [92.62473297, 12.06278038], [92.62444305, 12.06278038], [92.6241684, 12.06306076], [92.62333679, 12.06306076], [92.62307739, 12.06297016], [92.62277985, 12.06304741], [92.6222229, 12.06333447], [92.62194824, 12.0633297], [92.6202774, 12.06499958], [92.62015533, 12.06548119], [92.6202774, 12.06694031], [92.6202774, 12.06750011], [92.62000275, 12.06779003], [92.62000275, 12.06787014], [92.62000275, 12.06833458], [92.61999512, 12.06882], [92.61994171, 12.06931019], [92.61975861, 12.06980896], [92.61963654, 12.07032204], [92.61952972, 12.07078457], [92.61959839, 12.0711813], [92.61968994, 12.07147121], [92.61972046, 12.07175827], [92.61972046, 12.07207203], [92.61972046, 12.07241154], [92.61974335, 12.07276058], [92.61979675, 12.07309055], [92.61995697, 12.07338142], [92.62004089, 12.07374954], [92.62011719, 12.07420063], [92.62034607, 12.07459068], [92.62050629, 12.07494164], [92.6206665, 12.0752306], [92.62078094, 12.07551193], [92.62082672, 12.0758009], [92.62082672, 12.07608986], [92.62078857, 12.0764389], [92.62069702, 12.07682037], [92.62069702, 12.07719135], [92.62077332, 12.07766056], [92.62084198, 12.07820129], [92.62090302, 12.07872963], [92.62107086, 12.07921124], [92.62119293, 12.07969189], [92.62135315, 12.08001995], [92.6213913, 12.08036423], [92.62140656, 12.08072186], [92.62166595, 12.08111095], [92.62166595, 12.08249855], [92.62194824, 12.0827713], [92.62194824, 12.08416462], [92.62166595, 12.08444118], [92.62166595, 12.08500195], [92.62194824, 12.08528042], [92.62194824, 12.08555603], [92.6222229, 12.08583164], [92.6222229, 12.08638954], [92.62194824, 12.08666801], [92.6222229, 12.08693886], [92.6222229, 12.08805561], [92.62194824, 12.08833408], [92.62194824, 12.08944416], [92.6222229, 12.08972168], [92.6222229, 12.09000015], [92.62249756, 12.09027958], [92.62249756, 12.09055614], [92.6230545, 12.09111214], [92.6230545, 12.09194374], [92.62333679, 12.09222031], [92.62304688, 12.09249973], [92.6230545, 12.09305573], [92.62278748, 12.09333038], [92.62277985, 12.0941658], [92.62304688, 12.09444046], [92.6230545, 12.09666729], [92.62333679, 12.09694004], [92.62333679, 12.09861088], [92.62361145, 12.09888935], [92.62361145, 12.09972095], [92.62388611, 12.10000134], [92.62388611, 12.10111141], [92.62361145, 12.10139084], [92.62361145, 12.1027813], [92.62388611, 12.103055], [92.62388611, 12.10333347], [92.6241684, 12.10363388], [92.62433624, 12.10407066], [92.62444305, 12.10451126], [92.62448883, 12.10496044], [92.62462616, 12.10539055], [92.62483978, 12.10581493], [92.62512207, 12.10632992], [92.62538147, 12.1068306], [92.6256485, 12.10717106], [92.62592316, 12.10750198], [92.62618256, 12.10794067], [92.62644958, 12.10844135], [92.62670135, 12.10886002], [92.62689972, 12.10916805], [92.62689209, 12.10962105], [92.62715149, 12.11002922], [92.62730408, 12.11029816], [92.62761688, 12.11050129], [92.62789154, 12.11058521], [92.62789154, 12.11075211], [92.62809753, 12.11112309], [92.62826538, 12.111413], [92.62876129, 12.11170197], [92.6291275, 12.11181068], [92.62958527, 12.11194992], [92.62983704, 12.11201191], [92.63012695, 12.11204243], [92.63034058, 12.11213684], [92.63062286, 12.11233139], [92.6309967, 12.11257267], [92.63143921, 12.11287975], [92.63166809, 12.1133337], [92.63194275, 12.11361027], [92.63194275, 12.11388969], [92.63222504, 12.11416626], [92.63223267, 12.11444187], [92.6324234, 12.11509132], [92.63250732, 12.11556053], [92.63262939, 12.11596203], [92.63250732, 12.11651802], [92.63282013, 12.11730194], [92.63290405, 12.1175909], [92.63301086, 12.11783981], [92.63309479, 12.11804485], [92.63323975, 12.11824989], [92.63340759, 12.11843872], [92.63365936, 12.11855984], [92.63391113, 12.11867237], [92.63405609, 12.11874866], [92.63437653, 12.11883068], [92.63463593, 12.11886978], [92.63485718, 12.11900043], [92.63521576, 12.11926556], [92.63536072, 12.11945057], [92.63542175, 12.11964035], [92.63546753, 12.11989117], [92.63552856, 12.12000942], [92.63569641, 12.12019634], [92.63587952, 12.12046146], [92.6359024, 12.12119007], [92.63580322, 12.12142944], [92.63566589, 12.12162971], [92.63553619, 12.12192154], [92.63522339, 12.12210178], [92.63477325, 12.12221146], [92.63427734, 12.12232018], [92.63387299, 12.12247086], [92.63342285, 12.12248039], [92.63292694, 12.12239075], [92.6324234, 12.12230015], [92.63191986, 12.12250137], [92.63153839, 12.12280846], [92.63166809, 12.12324429], [92.63188934, 12.12371063], [92.63195038, 12.12422085], [92.63196564, 12.12473011], [92.63197327, 12.12524033], [92.63205719, 12.125741], [92.63231659, 12.12621784], [92.63250732, 12.12684155], [92.63259125, 12.12742138], [92.63265991, 12.12789059], [92.63286591, 12.12832069], [92.63304901, 12.1288414], [92.63330841, 12.12938118], [92.63339996, 12.12997246], [92.63358307, 12.13034058], [92.63363647, 12.13062954], [92.63360596, 12.13114071], [92.63368225, 12.13171101], [92.63368225, 12.13211823], [92.63352203, 12.13261986], [92.6337204, 12.13306046], [92.63391113, 12.13344002], [92.63405609, 12.13375854], [92.63404846, 12.13411713], [92.63414764, 12.13450241], [92.63421631, 12.13490105], [92.6342926, 12.1353178], [92.6344223, 12.13566017], [92.6344223, 12.13601112], [92.6344986, 12.13637066], [92.63456726, 12.13670921], [92.63488007, 12.13716221], [92.63491821, 12.13739014], [92.63485718, 12.13778687], [92.6350174, 12.13798046], [92.63503265, 12.13833141], [92.63525391, 12.13899708], [92.63522339, 12.13933182], [92.63526154, 12.13978958], [92.63542938, 12.14038944], [92.63577271, 12.14079094], [92.63595581, 12.14120102], [92.63607025, 12.14162922], [92.63616943, 12.14202118], [92.63639069, 12.14229679], [92.63659668, 12.14247894], [92.63674927, 12.14266396], [92.63683319, 12.14293098], [92.63743591, 12.14307022], [92.63757324, 12.14358902], [92.63765717, 12.14406109], [92.63739777, 12.14437962], [92.63722992, 12.14477539], [92.63706207, 12.14517117], [92.63697052, 12.14566803], [92.63706207, 12.14620113], [92.63726044, 12.14668941], [92.63751221, 12.14708138], [92.63778687, 12.14743233], [92.63807678, 12.14781857], [92.63829041, 12.14832973], [92.63843536, 12.14891815], [92.63873291, 12.14939022], [92.63887787, 12.14977932], [92.63897705, 12.15019035], [92.63919067, 12.15063], [92.63957977, 12.1510601], [92.63977051, 12.15160275], [92.63996124, 12.15211105], [92.6398468, 12.15273952], [92.64003754, 12.1530571], [92.64026642, 12.15329361], [92.64044952, 12.15353107], [92.64054108, 12.15381622], [92.64057159, 12.1541214], [92.64066315, 12.15439892], [92.64080811, 12.15464115], [92.64091492, 12.15491676], [92.64105988, 12.15520191], [92.64111328, 12.15559101], [92.6411438, 12.15599537], [92.64126587, 12.15639114], [92.64137268, 12.15679741], [92.64139557, 12.15721416], [92.64144897, 12.15761089], [92.64161682, 12.15797138], [92.641716, 12.15833092], [92.64194489, 12.15862465], [92.64200592, 12.15896034], [92.64200592, 12.15933132], [92.64198303, 12.15972996], [92.64199829, 12.16024113], [92.64217377, 12.16078091], [92.64225006, 12.16134357], [92.6423645, 12.16187286], [92.64241028, 12.16234207], [92.64234924, 12.16283035], [92.64222717, 12.1633606], [92.64241028, 12.16392612], [92.64250183, 12.16453934], [92.64264679, 12.16514969], [92.64282227, 12.1657362], [92.64318085, 12.16617107], [92.64344788, 12.16658974], [92.64348602, 12.16711712], [92.64362335, 12.16764069], [92.64380646, 12.16819859], [92.64402008, 12.16877174], [92.64414215, 12.16937065], [92.64421082, 12.16996956], [92.64435577, 12.17053127], [92.6444397, 12.17108917], [92.6444931, 12.17164993], [92.64460754, 12.17219925], [92.64452362, 12.1727829], [92.64460754, 12.1733799], [92.6447525, 12.17389011], [92.64493561, 12.17433929], [92.64499664, 12.17479134], [92.64500427, 12.17526913], [92.64502716, 12.17579079], [92.64512634, 12.17636108], [92.64528656, 12.17695999], [92.64547729, 12.1776104], [92.64559174, 12.17837143], [92.64572906, 12.17916203], [92.64608765, 12.17969131], [92.64653778, 12.18013096], [92.64704132, 12.18052483], [92.64746857, 12.18099499], [92.647789, 12.18152142], [92.64807892, 12.18201637], [92.64836884, 12.18241215], [92.64865112, 12.18274021], [92.64892578, 12.18305016], [92.64920044, 12.1833601], [92.64948273, 12.18365192], [92.64968109, 12.18394089], [92.64972687, 12.18428993], [92.64972687, 12.18467999], [92.64971924, 12.18513775], [92.64977264, 12.18569183], [92.65001678, 12.18624973], [92.65029144, 12.18673801], [92.65057373, 12.18708229], [92.65080261, 12.18734169], [92.65098572, 12.18761063], [92.65124512, 12.18785477], [92.65141296, 12.18819046], [92.65158844, 12.18855], [92.65174866, 12.18896008], [92.65190887, 12.1894207], [92.6519928, 12.18997192], [92.6521759, 12.1905508], [92.65235901, 12.19119072], [92.65268707, 12.19170189], [92.65300751, 12.19218063], [92.65326691, 12.19268036], [92.65336609, 12.19325161], [92.65353394, 12.19376659], [92.65381622, 12.19415188], [92.65406036, 12.19447136], [92.65423584, 12.19476986], [92.65442657, 12.19503593], [92.65455627, 12.19539165], [92.6546936, 12.19583893], [92.65473175, 12.19641113], [92.65480042, 12.19708061], [92.65497589, 12.19775963], [92.65513611, 12.19843006], [92.65534973, 12.19895172], [92.65556335, 12.19937992], [92.65574646, 12.19976997], [92.6558609, 12.20015144], [92.65599823, 12.20044708], [92.65611267, 12.20071125], [92.65622711, 12.20096016], [92.6563797, 12.20120811], [92.65650177, 12.20148182], [92.65663147, 12.20177078], [92.65666199, 12.20216084], [92.65667725, 12.20263004], [92.65673828, 12.20316124], [92.65693665, 12.20366096], [92.65714264, 12.20414066], [92.65727234, 12.20464516], [92.65748596, 12.20507431], [92.65771484, 12.20548439], [92.6579361, 12.20586014], [92.65809631, 12.20621777], [92.65825653, 12.20649147], [92.6583786, 12.20676899], [92.65854645, 12.20701122], [92.65868378, 12.20727825], [92.65883636, 12.20753956], [92.6588974, 12.20788193], [92.65896606, 12.2082119], [92.65914917, 12.20850086], [92.65934753, 12.20877934], [92.65961456, 12.20904446], [92.65990448, 12.20929241], [92.66004944, 12.20963192], [92.66023254, 12.20997143], [92.66026306, 12.21040154], [92.66031647, 12.21108055], [92.6603241, 12.21164227], [92.66036987, 12.21170139], [92.66059875, 12.21199131], [92.66085052, 12.21238136], [92.66110229, 12.2127018], [92.66139984, 12.21310997], [92.66162872, 12.21341991], [92.66191864, 12.21385098], [92.66203308, 12.21439075], [92.66188049, 12.21488953], [92.6619873, 12.21550655], [92.66223907, 12.21592045], [92.66249084, 12.21631241], [92.66274261, 12.21658134], [92.66313934, 12.21687031], [92.66359711, 12.21724415], [92.66389465, 12.21750927], [92.66414642, 12.2176199], [92.66458893, 12.2176199], [92.66490173, 12.2175312], [92.66516113, 12.21730328], [92.66549683, 12.21709442], [92.66555786, 12.21670628], [92.6655426, 12.21629238], [92.66543579, 12.21586132], [92.66530609, 12.21544075], [92.66522217, 12.21498108], [92.66503143, 12.214571], [92.66493988, 12.21415138], [92.66475677, 12.21384144], [92.66467285, 12.21348953], [92.66451263, 12.21321487], [92.6644516, 12.21288204], [92.66442871, 12.21251965], [92.66435242, 12.21214294], [92.66418457, 12.21173954], [92.66403198, 12.21125031], [92.66387177, 12.21070957], [92.6636734, 12.21015167], [92.66353607, 12.20952034], [92.66336823, 12.20892143], [92.66333771, 12.20831013], [92.66333008, 12.20773602], [92.66329193, 12.20719147], [92.66309357, 12.2067194], [92.66279602, 12.2062912], [92.6625061, 12.20583534], [92.66221619, 12.20536137], [92.66194153, 12.20489597], [92.66169739, 12.20444012], [92.66156006, 12.20394135], [92.66137695, 12.20350075], [92.66117859, 12.20309067], [92.66110229, 12.2026186], [92.66100311, 12.20213127], [92.66086578, 12.20162106], [92.66078949, 12.20106888], [92.66057587, 12.20057011], [92.66033936, 12.20009136], [92.66004944, 12.19972038], [92.65981293, 12.1994009], [92.65962982, 12.19907856], [92.65940094, 12.19884491], [92.65918732, 12.19858456], [92.65904236, 12.19820881], [92.65888214, 12.19777107], [92.65870667, 12.1973114], [92.65859222, 12.19685459], [92.65841675, 12.19644928], [92.65830994, 12.19603539], [92.65815735, 12.19561958], [92.65801239, 12.19517326], [92.65779877, 12.19469929], [92.65763092, 12.19416142], [92.6574707, 12.19361019], [92.65722656, 12.19310093], [92.65705109, 12.19260216], [92.65690613, 12.19212437], [92.65670013, 12.19172859], [92.65657806, 12.19132137], [92.65638733, 12.19097519], [92.65618134, 12.19060135], [92.65605164, 12.19012737], [92.65583038, 12.18967056], [92.65561676, 12.18918133], [92.65556335, 12.18857956], [92.65550232, 12.18799114], [92.65530396, 12.18747902], [92.65516663, 12.18696976], [92.65502167, 12.18647957], [92.65493011, 12.18597031], [92.65471649, 12.18550968], [92.65448761, 12.18506145], [92.65437317, 12.18455029], [92.65420532, 12.18413258], [92.6541214, 12.18365383], [92.65393066, 12.18322086], [92.65389252, 12.18276978], [92.65396118, 12.18238258], [92.65418243, 12.18211079], [92.65445709, 12.18193054], [92.65475464, 12.18179703], [92.65512085, 12.18169022], [92.65548706, 12.18171024], [92.65582275, 12.18188953], [92.65618134, 12.18196106], [92.6565094, 12.18207455], [92.65681458, 12.1821928], [92.65712738, 12.18223], [92.65738678, 12.18229103], [92.65760803, 12.18244553], [92.65783691, 12.18256855], [92.65804291, 12.18274879], [92.65825653, 12.18292522], [92.65838623, 12.18321037], [92.65854645, 12.18349934], [92.65863037, 12.18384075], [92.65873718, 12.1841507], [92.65886688, 12.18445015], [92.65894318, 12.184762], [92.65898132, 12.18506718], [92.65891266, 12.1853838], [92.65882874, 12.18568039], [92.658638, 12.18591976], [92.65841675, 12.18618202], [92.65820313, 12.18651009], [92.65792847, 12.18682861], [92.6578064, 12.18719196], [92.65785217, 12.18754005], [92.65804291, 12.1878109], [92.65821075, 12.18805981], [92.65838623, 12.18828964], [92.658638, 12.18848801], [92.65892792, 12.18866158], [92.65917969, 12.18887997], [92.65944672, 12.18908119], [92.65972137, 12.1892767], [92.65998077, 12.18950462], [92.66021729, 12.18978119], [92.66040802, 12.19012928], [92.66059875, 12.19047642], [92.66082001, 12.19079304], [92.66098785, 12.1911211], [92.66113281, 12.19145775], [92.66130066, 12.19175243], [92.66137695, 12.19207954], [92.66143036, 12.19243145], [92.66156769, 12.19272137], [92.66166687, 12.1930809], [92.66174316, 12.19352055], [92.66191101, 12.19401073], [92.66201019, 12.19455147], [92.66217804, 12.19505024], [92.66226959, 12.19555092], [92.6624527, 12.19595718], [92.66259766, 12.19635963], [92.66275024, 12.19677067], [92.66282654, 12.19723606], [92.66299438, 12.19767094], [92.66311646, 12.19817162], [92.66333771, 12.19863319], [92.66356659, 12.19911098], [92.66371155, 12.19966125], [92.66391754, 12.20016193], [92.66416931, 12.2006197], [92.66443634, 12.20107079], [92.66468048, 12.20154762], [92.66487122, 12.2020607], [92.66506958, 12.20253658], [92.6654129, 12.20290184], [92.66578674, 12.203269], [92.66623688, 12.20353127], [92.66677856, 12.20366669], [92.66723633, 12.20389271], [92.66763306, 12.20415306], [92.66799927, 12.20440102], [92.66831207, 12.20469761], [92.66860962, 12.20498943], [92.66889954, 12.20528984], [92.66915894, 12.2055912], [92.66934967, 12.20590782], [92.66944885, 12.20627022], [92.66956329, 12.20663929], [92.66969299, 12.20704079], [92.66977692, 12.20753956], [92.66996765, 12.20807076], [92.67005157, 12.20864964], [92.67028046, 12.20913506], [92.67056274, 12.20957947], [92.67082977, 12.21003532], [92.67111206, 12.21052074], [92.67138672, 12.21103764], [92.67166901, 12.21152973], [92.67193604, 12.21197033], [92.67220306, 12.2123394], [92.67240906, 12.21269035], [92.67260742, 12.21307087], [92.67279053, 12.21348953], [92.67299652, 12.21395111], [92.67317963, 12.21445179], [92.67333984, 12.2149601], [92.67350769, 12.21546173], [92.67365265, 12.21596146], [92.67384338, 12.2164011], [92.67392731, 12.21689129], [92.67409515, 12.21738815], [92.67414856, 12.21798038], [92.67471313, 12.21841145], [92.67537689, 12.21860027], [92.67594147, 12.21848202], [92.67634583, 12.21816254], [92.67671204, 12.21774578], [92.67708588, 12.21734047], [92.6774292, 12.21687317], [92.67766571, 12.21630955], [92.67776489, 12.21566868], [92.67778015, 12.2149992], [92.67775726, 12.21431065], [92.67764282, 12.21363163], [92.67752075, 12.21295929], [92.67749786, 12.21228027], [92.67749786, 12.21165562], [92.67749786, 12.2111063], [92.67749786, 12.21064186], [92.67749786, 12.21019936], [92.67750549, 12.20975971], [92.6775589, 12.20928955], [92.67765808, 12.2088089], [92.67759705, 12.208251], [92.67756653, 12.20767021], [92.67752075, 12.20708179], [92.67745972, 12.20648193], [92.67733002, 12.20594025], [92.67724609, 12.20545197], [92.67723083, 12.20498943], [92.67726898, 12.20458126], [92.67749786, 12.20416737], [92.67778015, 12.20417118], [92.67804718, 12.2038908], [92.6783371, 12.20388794], [92.6791687, 12.20471954], [92.6791687, 12.20570946], [92.6791687, 12.20583344], [92.6791687, 12.20600128], [92.67916107, 12.20627022], [92.67913055, 12.20652294], [92.67923737, 12.20683098], [92.67942047, 12.20718575], [92.67944336, 12.20752144], [92.679245, 12.20790005], [92.6789856, 12.20839214], [92.67890167, 12.2088623], [92.67896271, 12.20930099], [92.67916107, 12.20972538], [92.67935944, 12.21023369], [92.67944336, 12.21084023], [92.67945099, 12.21148682], [92.67948151, 12.21208191], [92.67961884, 12.21252155], [92.67972565, 12.21288395], [92.67984772, 12.21317959], [92.67997742, 12.21347713], [92.68009949, 12.21382523], [92.68041992, 12.21414471], [92.68112183, 12.21419525], [92.68154907, 12.2141037], [92.68197632, 12.21401215], [92.68240356, 12.21397781], [92.68283081, 12.21395111], [92.68319702, 12.21372986], [92.68338776, 12.21341991], [92.68356323, 12.21312141], [92.68366241, 12.21277046], [92.68385315, 12.21247196], [92.6838913, 12.21212101], [92.6838913, 12.21177197], [92.6838913, 12.2114296], [92.6838913, 12.21109295], [92.68388367, 12.2107172], [92.68383789, 12.21028137], [92.68366241, 12.20980072], [92.6836319, 12.20925999], [92.68371582, 12.20876122], [92.68398285, 12.20841026], [92.68427277, 12.20822144], [92.68449402, 12.20815277], [92.68467712, 12.20831013], [92.68482208, 12.20853806], [92.68496704, 12.20874119], [92.685112, 12.20901203], [92.6852417, 12.20936108], [92.68527222, 12.20981026], [92.68531036, 12.21030426], [92.68544769, 12.21076012], [92.68572235, 12.21115017], [92.68599701, 12.21155071], [92.68624115, 12.21199131], [92.68641663, 12.21245098], [92.68662262, 12.21284962], [92.68669128, 12.21332169], [92.68682098, 12.21377087], [92.68694305, 12.21425629], [92.68701935, 12.21477127], [92.68696594, 12.2152977], [92.68694305, 12.21583271], [92.68692017, 12.21634197], [92.68681335, 12.21679974], [92.68664551, 12.21718693], [92.68641663, 12.21750164], [92.68630219, 12.21784115], [92.68612671, 12.21808147], [92.68597412, 12.2183342], [92.68577576, 12.21859264], [92.68548584, 12.21889019], [92.68516541, 12.21928883], [92.68502808, 12.21990204], [92.68501282, 12.22056866], [92.68502808, 12.22117996], [92.68517303, 12.22168159], [92.68530273, 12.2221489], [92.68546295, 12.22258186], [92.68554688, 12.22305107], [92.68560791, 12.22355747], [92.68578339, 12.22406101], [92.68585968, 12.22467041], [92.68596649, 12.22528267], [92.68612671, 12.22592068], [92.68634033, 12.22651958], [92.68651581, 12.22713089], [92.68681335, 12.22762108], [92.68714905, 12.22799015], [92.68746185, 12.22832108], [92.68773651, 12.22855091], [92.68798065, 12.22869015], [92.6881485, 12.22886086], [92.68828583, 12.22904778], [92.6883316, 12.22931194], [92.68834686, 12.22964001], [92.68834686, 12.23006725], [92.68834686, 12.23060036], [92.68834686, 12.23117733], [92.68833923, 12.23168468], [92.68833923, 12.23212242], [92.68833923, 12.23252106], [92.68840027, 12.23291969], [92.68856812, 12.23330975], [92.68865204, 12.23374462], [92.68884277, 12.23420143], [92.6889801, 12.23478889], [92.68939209, 12.23534966], [92.69008636, 12.2354908], [92.6906662, 12.23536968], [92.69108582, 12.23550034], [92.69139862, 12.23573875], [92.69167328, 12.23600101], [92.69192505, 12.23627472], [92.69211578, 12.23657131], [92.69224548, 12.23688793], [92.69242096, 12.23717117], [92.69252014, 12.23755074], [92.69268799, 12.23797131], [92.69287109, 12.23840809], [92.69314575, 12.23878193], [92.69355011, 12.23902416], [92.69415283, 12.23905087], [92.69471741, 12.2391901], [92.69522095, 12.23939133], [92.695755, 12.23944473], [92.69634247, 12.23949337], [92.69694519, 12.23966408], [92.69757843, 12.23965263], [92.69815063, 12.23949146], [92.69867706, 12.23946095], [92.69915009, 12.23940182], [92.69950867, 12.239151], [92.6998291, 12.2387619], [92.70007324, 12.23826218], [92.70028687, 12.23773575], [92.70050049, 12.23724079], [92.70059204, 12.23674202], [92.700737, 12.23634148], [92.70082092, 12.23596287], [92.7008667, 12.23560905], [92.70102692, 12.23533058], [92.7011261, 12.23500061], [92.70127869, 12.23468018], [92.70141602, 12.23431015], [92.70158386, 12.23396587], [92.70176697, 12.2336607], [92.70199585, 12.2334404], [92.70226288, 12.23331356], [92.7025528, 12.23315716], [92.70289612, 12.23302937], [92.70327759, 12.23286343], [92.70371246, 12.23275089], [92.70410156, 12.23254204], [92.70444489, 12.23224545], [92.70477295, 12.23190117], [92.70511627, 12.23153877], [92.70542908, 12.2311306], [92.70570374, 12.23073673], [92.70581818, 12.23029041], [92.70584869, 12.22982025], [92.70591736, 12.22939873], [92.70609283, 12.22904968], [92.70619202, 12.22870064], [92.7063446, 12.228405], [92.70639038, 12.22807026], [92.70639038, 12.22770786], [92.70633698, 12.22729969], [92.7061615, 12.22688484], [92.70615387, 12.22638416], [92.70632172, 12.22587109], [92.7064209, 12.22531891], [92.70656586, 12.22482872], [92.70655823, 12.22437096], [92.7064209, 12.22392178], [92.70639038, 12.22342968], [92.70642853, 12.2229557], [92.70662689, 12.22249985], [92.70679474, 12.22202587], [92.70706177, 12.22161961], [92.70727539, 12.22116375], [92.70749664, 12.22073078], [92.70765686, 12.2203207], [92.70751953, 12.21995163], [92.70745087, 12.21953011], [92.70726776, 12.21914959], [92.70722961, 12.21870136], [92.70728302, 12.21824932], [92.70748138, 12.21788025], [92.70769501, 12.21761131], [92.70796967, 12.21748066], [92.70822906, 12.21734047], [92.70854187, 12.21724033], [92.70892334, 12.21716022], [92.70926666, 12.21693039], [92.70955658, 12.21660137], [92.70970154, 12.21617126], [92.7097168, 12.21568966], [92.70972443, 12.21523571], [92.7097168, 12.21481037], [92.70972443, 12.21442509], [92.7097168, 12.21404934], [92.7097168, 12.21369076], [92.70976257, 12.2133007], [92.70992279, 12.21294117], [92.71002197, 12.21254539], [92.71018219, 12.21217537], [92.71026611, 12.21181107], [92.71028137, 12.21146202], [92.71028137, 12.21111965], [92.71028137, 12.21078491], [92.71028137, 12.21041965], [92.71028137, 12.21000957], [92.71028137, 12.20957279], [92.71028137, 12.20911694], [92.71026611, 12.20864964], [92.71021271, 12.20818043], [92.71003723, 12.2077198], [92.70993805, 12.20720005], [92.70974731, 12.20673275], [92.70965576, 12.20628643], [92.70950317, 12.20595074], [92.70944977, 12.20557976], [92.70942688, 12.20523071], [92.70935059, 12.20489597], [92.70928192, 12.20452023], [92.70918274, 12.20409393], [92.70913696, 12.2036171], [92.70900726, 12.20317078], [92.70890808, 12.20273972], [92.70889282, 12.20232964], [92.70889282, 12.20195103], [92.70886993, 12.20157146], [92.70876312, 12.2011652], [92.70862579, 12.20069981], [92.70848083, 12.20018005], [92.70823669, 12.19976997], [92.70792389, 12.19947147], [92.70758057, 12.19925022], [92.70726776, 12.19906139], [92.70701599, 12.19882202], [92.70685577, 12.1985302], [92.70678711, 12.19826126], [92.70691681, 12.19795132], [92.70703125, 12.19760036], [92.70722961, 12.19724941], [92.70750427, 12.19688034], [92.70778656, 12.19648075], [92.70807648, 12.19608021], [92.70836639, 12.19566059], [92.70870972, 12.19530106], [92.70907593, 12.19497013], [92.70942688, 12.19460106], [92.7097168, 12.19421959], [92.70999908, 12.19381714], [92.71026611, 12.19343185], [92.7105484, 12.19306946], [92.71083832, 12.19275856], [92.71113586, 12.19248104], [92.71144867, 12.19220066], [92.71175385, 12.19187069], [92.71205139, 12.19153118], [92.71224976, 12.19106102], [92.71244812, 12.19059181], [92.71248627, 12.19007206], [92.71242523, 12.18959141], [92.7122345, 12.1892271], [92.7120285, 12.18892097], [92.71173859, 12.1887207], [92.71142578, 12.18862724], [92.7110672, 12.18861103], [92.71072388, 12.18861103], [92.71037292, 12.1885891], [92.71000671, 12.18844986], [92.70959473, 12.18819904], [92.709198, 12.18781567], [92.70886993, 12.18725967], [92.70856476, 12.18664742], [92.70832062, 12.18600178], [92.70804596, 12.18540001], [92.70778656, 12.18487072], [92.7075882, 12.18437004], [92.70746613, 12.18387985], [92.70722961, 12.18347168], [92.70703125, 12.18307972], [92.70677948, 12.18272018], [92.70656586, 12.18227959], [92.70630646, 12.18185139], [92.70607758, 12.18135929], [92.70583344, 12.18084431], [92.70561218, 12.1803093], [92.70552063, 12.17969131], [92.70536041, 12.17910099], [92.70523071, 12.17854214], [92.70504761, 12.17806053], [92.70500183, 12.17755127], [92.70500183, 12.17703342], [92.70500183, 12.17649078], [92.70500183, 12.1759119], [92.70495605, 12.1753149], [92.70476532, 12.17476082], [92.70472717, 12.17420292], [92.70471954, 12.17369366], [92.70471954, 12.17324257], [92.70471954, 12.17281914], [92.70471954, 12.17239094], [92.70475006, 12.17195988], [92.70485687, 12.17153168], [92.70493317, 12.17113972], [92.70475006, 12.17079067], [92.70458984, 12.1704216], [92.70439911, 12.17008209], [92.7041626, 12.16975212], [92.7039032, 12.16938496], [92.70368958, 12.16893959], [92.70358276, 12.16839123], [92.70337677, 12.16786385], [92.70335388, 12.16732693], [92.70346832, 12.16679096], [92.70358276, 12.16629219], [92.70362091, 12.16582012], [92.70371246, 12.16543007], [92.70394897, 12.16520691], [92.70417023, 12.16503143], [92.70458984, 12.16504097], [92.70472717, 12.16522121], [92.70487976, 12.16543865], [92.70503235, 12.16572189], [92.70516205, 12.16608047], [92.70507813, 12.16660023], [92.70513916, 12.1669302], [92.70539093, 12.16719723], [92.70568085, 12.16740227], [92.70610046, 12.16769123], [92.70665741, 12.16837978], [92.70687103, 12.16897202], [92.70678711, 12.16958141], [92.70675659, 12.1700592], [92.70694733, 12.17037106], [92.70742798, 12.17070198], [92.70786285, 12.17103004], [92.70832825, 12.1713562], [92.7089386, 12.17175007], [92.70952606, 12.1721611], [92.70994568, 12.172575], [92.71044922, 12.17305183], [92.71118927, 12.17370796], [92.71147919, 12.1741457], [92.71179962, 12.17457199], [92.71196747, 12.17504597], [92.71214294, 12.17531013], [92.7123642, 12.17554092], [92.71274567, 12.17564297], [92.7130127, 12.17556095], [92.71318054, 12.17519188], [92.71299744, 12.17467022], [92.71305084, 12.17429638], [92.7130661, 12.17391109], [92.71305084, 12.17350292], [92.71300507, 12.17304325], [92.71282196, 12.17253208], [92.71282196, 12.1719532], [92.71302795, 12.1713562], [92.71335602, 12.17085934], [92.71349335, 12.17022324], [92.71304321, 12.16954613], [92.71259308, 12.16917038], [92.71218109, 12.1688509], [92.7119751, 12.16852283], [92.71194458, 12.16819], [92.71195984, 12.16787148], [92.71211243, 12.16770267], [92.71239471, 12.16743088], [92.71237183, 12.1669054], [92.71228027, 12.16633129], [92.71244812, 12.16594124], [92.71246338, 12.16549015], [92.71298218, 12.16498756], [92.71328735, 12.16509056], [92.7135849, 12.16525936], [92.71379852, 12.1656723], [92.71405792, 12.16625118], [92.71446991, 12.16647625], [92.71474457, 12.16688442], [92.7148819, 12.16725063], [92.71520996, 12.16787434], [92.71551514, 12.16832256], [92.71565247, 12.16896057], [92.7158432, 12.16957188], [92.71605682, 12.17010498], [92.71621704, 12.17064953], [92.71640015, 12.17116928], [92.71663666, 12.17163181], [92.71684265, 12.172122], [92.71704865, 12.17259979], [92.71724701, 12.1730814], [92.71750641, 12.17353725], [92.71772766, 12.17402267], [92.71776581, 12.17461109], [92.71778107, 12.17523479], [92.71784973, 12.17585278], [92.71813202, 12.1763134], [92.71852112, 12.17666435], [92.71891785, 12.17698097], [92.71928406, 12.17732525], [92.71967316, 12.17762375], [92.7199707, 12.1779747], [92.7201767, 12.17840481], [92.72026062, 12.1789093], [92.7203064, 12.17948055], [92.72051239, 12.18001938], [92.72115326, 12.18028069], [92.72161102, 12.18000126], [92.7219162, 12.17950153], [92.72223663, 12.17907143], [92.72254944, 12.17872047], [92.72289276, 12.17849922], [92.72323608, 12.17835999], [92.72360229, 12.17833042], [92.72396088, 12.17833328], [92.72431183, 12.1783638], [92.72464752, 12.17851257], [92.72503662, 12.17864037], [92.72540283, 12.17889118], [92.72556305, 12.17889118], [92.72583008, 12.17918015], [92.72611237, 12.17916679], [92.72666931, 12.17972279], [92.72693634, 12.17972088], [92.72721863, 12.18000126], [92.72777557, 12.18000126], [92.72789764, 12.18012238], [92.72805023, 12.18028069], [92.72833252, 12.18028069], [92.72860718, 12.18056202], [92.72916412, 12.18055534], [92.72944641, 12.18083286], [92.72972107, 12.18083286], [92.73000336, 12.18111134], [92.73110962, 12.18111134], [92.73139191, 12.18138885], [92.73221588, 12.18138885], [92.73249817, 12.18166924], [92.73332977, 12.18166733], [92.73361206, 12.18194485], [92.73527527, 12.18194485], [92.73555756, 12.18222332], [92.73666382, 12.18222332], [92.73694611, 12.18194485], [92.73722076, 12.18194485], [92.73777771, 12.18138885], [92.73805237, 12.18138885], [92.73832703, 12.18111134], [92.73860931, 12.18111134], [92.7388916, 12.18083286], [92.73972321, 12.18083286], [92.73999786, 12.18055534], [92.74333191, 12.18056202], [92.74360657, 12.18028069], [92.74388885, 12.18028069], [92.74611664, 12.17806053], [92.7463913, 12.17806053], [92.74666595, 12.17778111], [92.74694824, 12.17778111], [92.7472229, 12.17750072], [92.74749756, 12.17750072], [92.74777985, 12.17722034], [92.7480545, 12.17722321], [92.74833679, 12.17694473], [92.7491684, 12.17694473], [92.75055695, 12.17833328], [92.75055695, 12.1786108], [92.75097656, 12.17902756], [92.75222015, 12.18028069], [92.75250244, 12.18028069], [92.7527771, 12.18000126], [92.75305176, 12.18000126], [92.75389099, 12.17918015], [92.75417328, 12.17918015], [92.75498962, 12.17833042], [92.75527954, 12.17833328], [92.7555542, 12.17805672], [92.75583649, 12.17806053], [92.75611115, 12.17778111], [92.7563858, 12.17778111], [92.75723267, 12.17693996], [92.75722504, 12.17666626], [92.75749969, 12.17639065], [92.75749969, 12.17583179], [92.75722504, 12.17555428], [92.75723267, 12.17056084], [92.75749969, 12.17028046], [92.75749969, 12.16943932], [92.75722504, 12.16916561], [92.75720978, 12.16878986], [92.75701141, 12.16836071], [92.75699615, 12.16788006], [92.75717163, 12.16739273], [92.75722504, 12.16687775], [92.75727081, 12.16639042], [92.75745392, 12.16598225], [92.75753784, 12.16551495], [92.75769043, 12.16505909], [92.75775146, 12.16456032], [92.75765991, 12.16405773], [92.75746155, 12.16358185], [92.75723267, 12.16313076], [92.75699615, 12.16269112], [92.75683594, 12.16224194], [92.75666809, 12.16181087], [92.75652313, 12.16138458], [92.75634766, 12.16097927], [92.75611115, 12.16063023], [92.75588989, 12.16030025], [92.75582886, 12.15990067], [92.75580597, 12.1595211], [92.75576019, 12.15919018], [92.75572968, 12.1588707], [92.7557373, 12.15849018], [92.75556183, 12.15501881], [92.75550842, 12.15431023], [92.75533295, 12.15367889], [92.75526428, 12.15307713], [92.75517273, 12.15254021], [92.75500488, 12.15208435], [92.75483704, 12.15164757], [92.75466156, 12.15119934], [92.75439453, 12.15077114], [92.7541275, 12.15028095], [92.7538681, 12.1498003], [92.7536087, 12.14938068], [92.75337219, 12.14901066], [92.75319672, 12.1486311], [92.75298309, 12.14826393], [92.75276184, 12.14789486], [92.75253296, 12.14754105], [92.75240326, 12.14713097], [92.75223541, 12.14677334], [92.75209808, 12.14640617], [92.75195312, 12.14605999], [92.75182343, 12.14572525], [92.75169373, 12.14540386], [92.75164032, 12.14503384], [92.75149536, 12.14467239], [92.75136566, 12.14425278], [92.75115967, 12.14381313], [92.7509613, 12.14330673], [92.75078583, 12.14275074], [92.75055695, 12.14221001], [92.75038147, 12.1417017], [92.75046539, 12.14119244], [92.75054169, 12.14068127], [92.75051117, 12.14019108], [92.75032806, 12.13975143], [92.75020599, 12.13929081], [92.75, 12.13891029], [92.74977112, 12.13855457], [92.74957275, 12.13818073], [92.74942017, 12.13774967], [92.74921417, 12.13737583], [92.74906158, 12.13698006], [92.74888611, 12.13661098], [92.74865723, 12.13625717], [92.74849701, 12.13585186], [92.74830627, 12.13543034], [92.74809265, 12.13503075], [92.74791718, 12.1345892], [92.74776459, 12.13418102], [92.74758911, 12.13383484], [92.74745941, 12.13349533], [92.74726868, 12.13323116], [92.74711609, 12.13296604], [92.7469101, 12.13274097], [92.74669647, 12.13251019], [92.74651337, 12.1321907], [92.74635315, 12.13179016], [92.74611664, 12.1313982], [92.74590302, 12.13099003], [92.74577332, 12.13052082], [92.74559784, 12.13009167], [92.74550629, 12.12959957], [92.74532318, 12.12914181], [92.74523163, 12.12863064], [92.74504089, 12.12818241], [92.74494934, 12.1277113], [92.74478149, 12.12731171], [92.74472809, 12.12685108], [92.74469757, 12.1264019], [92.74459839, 12.12599182], [92.74446869, 12.12559795], [92.7444458, 12.12518978], [92.7444458, 12.12477684], [92.7444458, 12.12435055], [92.7444458, 12.12392044], [92.7444458, 12.12349033], [92.7444458, 12.12306976], [92.74442291, 12.1226511], [92.74433136, 12.12223244], [92.74420166, 12.12182617], [92.74414062, 12.12131977], [92.74401855, 12.12079144], [92.74386597, 12.12024021], [92.74360657, 12.11971092], [92.74333954, 12.11919117], [92.74301147, 12.11870956], [92.74263, 12.11828041], [92.7423172, 12.11779022], [92.74201965, 12.11730194], [92.74169922, 12.11684418], [92.7414093, 12.11634922], [92.7410965, 12.11584091], [92.74075317, 12.11533928], [92.7403183, 12.11491776], [92.73995209, 12.11450958], [92.73960876, 12.11418247], [92.73931885, 12.11388969], [92.73908234, 12.11362076], [92.7388382, 12.11334133], [92.73856354, 12.11304855], [92.73828125, 12.11270046], [92.73803711, 12.11225128], [92.73777771, 12.11179066], [92.7375412, 12.1113348], [92.73744202, 12.11081123], [92.73726654, 12.11035347], [92.73718262, 12.1098671], [92.73697662, 12.10945034], [92.73686981, 12.10898113], [92.73670959, 12.10857296], [92.73664093, 12.10807133], [92.73649597, 12.10758972], [92.73636627, 12.10709095], [92.73621368, 12.10660362], [92.73612976, 12.10604095], [92.7360611, 12.10540009], [92.73588562, 12.10476208], [92.73579407, 12.10407352], [92.73564911, 12.10344887], [92.73578644, 12.10291958], [92.73586273, 12.10242844], [92.73602295, 12.10202026], [92.73615265, 12.1015892], [92.73628998, 12.10114956], [92.73615265, 12.1006937], [92.73607635, 12.10020828], [92.7359314, 12.09979057], [92.73583984, 12.09937191], [92.73583221, 12.09895039], [92.73583221, 12.09850121], [92.73583221, 12.09806061], [92.73578644, 12.09764194], [92.73564148, 12.09727955], [92.7355423, 12.09685135], [92.73545074, 12.09640694], [92.73551941, 12.09589195], [92.73545837, 12.09533978], [92.73526764, 12.09480667], [92.73526001, 12.09427071], [92.73524475, 12.09375381], [92.73523712, 12.09311962], [92.73527527, 12.09261417], [92.7352829, 12.09214687], [92.7352829, 12.0916996], [92.7352829, 12.09125137], [92.7352829, 12.09080029], [92.73527527, 12.09035301], [92.7352829, 12.08989143], [92.7352829, 12.08939171], [92.7352829, 12.08883953], [92.73532867, 12.08824062], [92.73551178, 12.08763885], [92.73555756, 12.08697128], [92.73558807, 12.08630085], [92.73571014, 12.08567047], [92.73580933, 12.08507919], [92.73584747, 12.08450031], [92.7359314, 12.08396339], [92.73610687, 12.08347893], [92.73628998, 12.08302116], [92.73641968, 12.08256054], [92.7366333, 12.08218002], [92.73674774, 12.08176327], [92.73694611, 12.08137131], [92.73710632, 12.08092022], [92.73721313, 12.08039284], [92.73722076, 12.08027744], [92.73722076, 12.08000088], [92.73750305, 12.07973003], [92.73750305, 12.07944107], [92.73777771, 12.07916737], [92.73803711, 12.07883167], [92.73844147, 12.07855034], [92.73873138, 12.07831287], [92.73908997, 12.07802296], [92.73934174, 12.07773399], [92.73954773, 12.07742405], [92.73965454, 12.07713413], [92.73988342, 12.07672024], [92.74040985, 12.07608986], [92.74059296, 12.0756712], [92.74082947, 12.07506943], [92.74111176, 12.07472134], [92.74111176, 12.07416725], [92.7408371, 12.07389069], [92.7408371, 12.07250118], [92.74054718, 12.0722208], [92.74055481, 12.07194519], [92.73944092, 12.07083321], [92.73880005, 12.07075024], [92.73838043, 12.07090092], [92.73815155, 12.07094193], [92.73750305, 12.07083035], [92.73743439, 12.07067966], [92.73722076, 12.07028103], [92.7371521, 12.07014179], [92.73719788, 12.06984615], [92.73710632, 12.06941891], [92.73730469, 12.0688343], [92.73742676, 12.06854439], [92.73742676, 12.06817341], [92.73736572, 12.06794453], [92.73719788, 12.06763268], [92.73700714, 12.06742668], [92.73665619, 12.06721973], [92.73638916, 12.06722164], [92.73527527, 12.06611156], [92.73527527, 12.06527805], [92.73610687, 12.06444168], [92.7361145, 12.06416607], [92.73638916, 12.06389046], [92.73638916, 12.06361008], [92.73665619, 12.0633297], [92.73694611, 12.0633297], [92.73750305, 12.0638876], [92.73687744, 12.06429386], [92.73654175, 12.06464005], [92.73639679, 12.06499577], [92.73635101, 12.06530094], [92.73634338, 12.06562042], [92.73631287, 12.06576061], [92.73634338, 12.06593037], [92.73652649, 12.06627655], [92.73723602, 12.06706142], [92.73805237, 12.06711102], [92.73805237, 12.06721973], [92.73832703, 12.06750011], [92.73833466, 12.06777763], [92.73800659, 12.06855106], [92.73779297, 12.06902695], [92.73773193, 12.0694809], [92.73781586, 12.06985474], [92.73796082, 12.0701437], [92.7383194, 12.07016468], [92.73860931, 12.0701437], [92.7389679, 12.07018089], [92.73937225, 12.07023144], [92.73970032, 12.07031059], [92.74027252, 12.07054138], [92.74072266, 12.07091045], [92.74111176, 12.07111073], [92.7416687, 12.07166672], [92.7416687, 12.07194519], [92.74194336, 12.0722208], [92.74194336, 12.07305527], [92.74250031, 12.07359886], [92.74223328, 12.07389069], [92.74194336, 12.07389069], [92.7416687, 12.07416725], [92.74180603, 12.07430363], [92.74191284, 12.07441139], [92.74236298, 12.07439041], [92.74297333, 12.07428074], [92.74326324, 12.07415771], [92.74349976, 12.07392979], [92.74362183, 12.07374096], [92.74375153, 12.07364273], [92.7440033, 12.07349682], [92.74433899, 12.07332993], [92.74469757, 12.07299995], [92.74500275, 12.0722208], [92.7452774, 12.0722208], [92.74537659, 12.07246017], [92.7455368, 12.07252121], [92.74582672, 12.07250118], [92.74611664, 12.07239056], [92.74647522, 12.07225037], [92.74674988, 12.07211113], [92.74701691, 12.07192039], [92.74724579, 12.07185078], [92.747612, 12.07179737], [92.74794769, 12.07161045], [92.74859619, 12.07136059], [92.74871826, 12.07136059], [92.74893188, 12.07137966], [92.74908447, 12.07141399], [92.74916077, 12.07143021], [92.74941254, 12.07143021], [92.74989319, 12.07126141], [92.75039673, 12.07108974], [92.75083923, 12.07107162], [92.75111389, 12.07107162], [92.75159454, 12.07100964], [92.75184631, 12.07088947], [92.75226593, 12.07056141], [92.75250244, 12.07038975], [92.75302124, 12.07010078], [92.7532959, 12.06997967], [92.7536087, 12.06976986], [92.75372314, 12.069561], [92.75392914, 12.06927395], [92.75424194, 12.068964], [92.75470734, 12.06863308], [92.75499725, 12.06842804], [92.75546265, 12.06820011], [92.75580597, 12.06801128], [92.75623322, 12.06776524], [92.75646973, 12.06753922], [92.75681305, 12.06721115], [92.75691986, 12.06674099], [92.75726318, 12.06635189], [92.75750732, 12.06597996], [92.75773621, 12.0656662], [92.75788879, 12.06530094], [92.7580719, 12.0649004], [92.75827789, 12.06444645], [92.75829315, 12.06389046], [92.75808716, 12.06328869], [92.75791931, 12.06264973], [92.75772095, 12.06202984], [92.75743866, 12.06146145], [92.75708771, 12.06097984], [92.75674438, 12.06057644], [92.75641632, 12.06026173], [92.75614166, 12.05996132], [92.75591278, 12.05962086], [92.75576019, 12.05924511], [92.75554657, 12.05889034], [92.75528717, 12.05856609], [92.75498199, 12.05821133], [92.75461578, 12.05782986], [92.75413513, 12.05750942], [92.7536087, 12.05722237], [92.75311279, 12.0569458], [92.75267792, 12.05668354], [92.75229645, 12.05646038], [92.75196838, 12.05626678], [92.7517395, 12.0560503], [92.75166321, 12.05578995], [92.75165558, 12.05551434], [92.75171661, 12.05525017], [92.75193024, 12.05500793], [92.75222015, 12.05474186], [92.75260925, 12.05454063], [92.75306702, 12.05445004], [92.75356293, 12.05446625], [92.75401306, 12.05457115], [92.75441742, 12.05469608], [92.75483704, 12.05472088], [92.75525665, 12.05472374], [92.75567627, 12.05472374], [92.75609589, 12.05472088], [92.7565155, 12.05472088], [92.75691223, 12.05472088], [92.75720978, 12.05476475], [92.75744629, 12.05499935], [92.7576828, 12.05523014], [92.75784302, 12.05523014], [92.75839996, 12.05556679], [92.75972748, 12.05575371], [92.76032257, 12.05510426], [92.76055908, 12.05499935], [92.76111603, 12.05444145], [92.76117706, 12.05405426], [92.76142883, 12.05345631], [92.76156616, 12.05294991], [92.76143646, 12.05250359], [92.7614212, 12.05211353], [92.76154327, 12.05181313], [92.76172638, 12.05159855], [92.76190948, 12.05142117], [92.76210785, 12.05124092], [92.76236725, 12.05113411], [92.76272583, 12.051157], [92.76314545, 12.05138206], [92.76365662, 12.05163097], [92.7642746, 12.05185032], [92.76454163, 12.05186272], [92.76493073, 12.0518837], [92.76550293, 12.05160999], [92.76584625, 12.05109119], [92.76608276, 12.0505209], [92.76618195, 12.04996872], [92.76629639, 12.04950047], [92.76613617, 12.04912376], [92.76596832, 12.04875469], [92.76581573, 12.04842186], [92.76564789, 12.04812813], [92.76557159, 12.04781055], [92.76563263, 12.04747963], [92.76583862, 12.04718399], [92.7661438, 12.04688835], [92.76657104, 12.04665089], [92.76708984, 12.0464592], [92.76767731, 12.04657078], [92.76829529, 12.04674911], [92.76883698, 12.04695892], [92.76931763, 12.0472002], [92.76981354, 12.04738903], [92.77030945, 12.04741383], [92.77072906, 12.04721355], [92.77110291, 12.04697514], [92.771492, 12.04683113], [92.77184296, 12.04669189], [92.77220154, 12.0466671], [92.77256775, 12.04668713], [92.77289581, 12.04680061], [92.77327728, 12.04697037], [92.77363586, 12.04722118], [92.77407837, 12.04750061], [92.77453613, 12.04781055], [92.77495575, 12.04820538], [92.77527618, 12.04866123], [92.77555847, 12.0490799], [92.77581787, 12.04942703], [92.77607727, 12.04971886], [92.77638245, 12.0499897], [92.77677155, 12.05019283], [92.7772522, 12.05029964], [92.77774811, 12.05048943], [92.77829742, 12.05055046], [92.77884674, 12.0505619], [92.77941895, 12.05050945], [92.77993011, 12.05030727], [92.7804184, 12.05009174], [92.78079987, 12.04973507], [92.78108978, 12.04932022], [92.78134155, 12.04894066], [92.78193665, 12.04833126], [92.78277588, 12.04833317], [92.78360748, 12.0474987], [92.78360748, 12.04693985], [92.78333282, 12.0466671], [92.78333282, 12.04611111], [92.78304291, 12.04568005], [92.78276825, 12.04531097], [92.78253937, 12.04485703], [92.78233337, 12.04427147], [92.78206635, 12.04378128], [92.78185272, 12.04343987], [92.78194427, 12.0433321], [92.78138733, 12.04277897], [92.78138733, 12.04250145], [92.77999878, 12.04111004], [92.77971649, 12.04111004], [92.77944183, 12.04082966], [92.77916718, 12.04111004], [92.7783432, 12.04111004], [92.77805328, 12.04139137], [92.77749634, 12.04139137], [92.77722168, 12.04111004], [92.77694702, 12.04111004], [92.77694702, 12.04056072], [92.7766571, 12.0402813], [92.77694702, 12.03999996], [92.77694702, 12.03971958], [92.77722168, 12.03944397], [92.77639008, 12.03861237], [92.77639008, 12.0377779], [92.77657318, 12.03765106], [92.77658844, 12.03701019], [92.77639008, 12.03650188], [92.7762146, 12.0361166], [92.77612305, 12.03578186], [92.77610016, 12.03541946], [92.77610016, 12.03503036], [92.77607727, 12.03464222], [92.77593231, 12.03425026], [92.77584839, 12.0338192], [92.77578735, 12.0333786], [92.77560425, 12.03299046], [92.77555847, 12.03277969], [92.77555847, 12.03250027], [92.77583313, 12.03222179], [92.77565002, 12.03174973], [92.77562714, 12.03142166], [92.77565002, 12.03119183], [92.77568817, 12.03090191], [92.77572632, 12.03078079], [92.77587891, 12.03057194], [92.77623749, 12.03024101], [92.77654266, 12.0300293], [92.77709198, 12.02974415], [92.77749634, 12.02944565], [92.77749634, 12.02916527], [92.77722168, 12.02888966], [92.77722168, 12.02862072], [92.77745056, 12.0281601], [92.77749634, 12.02805996], [92.77749634, 12.02777958], [92.77777863, 12.0274992], [92.77805328, 12.0274992], [92.7783432, 12.02722073], [92.77861023, 12.02722359], [92.77889252, 12.02694321], [92.77889252, 12.02666664], [92.77915955, 12.02639198], [92.77915955, 12.02528191], [92.77889252, 12.02500057], [92.77889252, 12.02472115], [92.77861023, 12.02444458], [92.77861023, 12.02416706], [92.77805328, 12.02361107], [92.77749634, 12.02361107], [92.77722168, 12.02389145], [92.77694702, 12.02389145], [92.7766571, 12.02417183], [92.77632141, 12.02434731], [92.77590179, 12.02447033], [92.77580261, 12.0244894], [92.77542114, 12.02455044], [92.77478027, 12.02448177], [92.77427673, 12.02454567], [92.77416992, 12.02472115], [92.77388763, 12.02500057], [92.77361298, 12.02500057], [92.77333069, 12.02528191], [92.77278137, 12.02528191], [92.77249908, 12.02500057], [92.7722168, 12.02500057], [92.77199554, 12.02477074], [92.77194214, 12.02472115], [92.77166748, 12.02472115], [92.77139282, 12.02500057], [92.77111053, 12.02500057], [92.77083588, 12.02528191], [92.77054596, 12.02528191], [92.77008057, 12.02480793], [92.76999664, 12.02472115], [92.76972198, 12.02472115], [92.76944733, 12.02500057], [92.76944733, 12.02527714], [92.76889038, 12.02583313], [92.76777649, 12.02583313], [92.76734161, 12.02579689], [92.766922, 12.02582359], [92.76660156, 12.02548885], [92.76624298, 12.02534103], [92.76579285, 12.02539063], [92.76517487, 12.02550697], [92.76496887, 12.02589512], [92.76477051, 12.02587223], [92.76459503, 12.0256443], [92.76451874, 12.02529526], [92.76460266, 12.02488136], [92.76490784, 12.02441978], [92.76546478, 12.02402782], [92.76552582, 12.02373886], [92.76539612, 12.02344894], [92.7651825, 12.02310085], [92.76499939, 12.0227766], [92.76442719, 12.02238941], [92.76416016, 12.02222061], [92.76269531, 12.02139091], [92.76222229, 12.02083302], [92.76194763, 12.02055454], [92.76166534, 12.02055454], [92.76139069, 12.02083302], [92.7611084, 12.02083302], [92.76083374, 12.02111053], [92.76055908, 12.02111053], [92.76027679, 12.02139091], [92.75971985, 12.02139091], [92.75945282, 12.02166939], [92.75888824, 12.02166653], [92.75782776, 12.02233028], [92.75750732, 12.02270222], [92.75723267, 12.02313042], [92.75699615, 12.02359962], [92.75695801, 12.02413082], [92.75702667, 12.02460003], [92.75694275, 12.02472115], [92.75722504, 12.02499866], [92.75723267, 12.02583122], [92.75666809, 12.02639198], [92.75498962, 12.02639198], [92.75457001, 12.02646923], [92.75418854, 12.02668095], [92.75389862, 12.02700901], [92.75367737, 12.02738094], [92.75361633, 12.02783203], [92.7536087, 12.02826977], [92.75356293, 12.02869129], [92.75327301, 12.02906132], [92.75321198, 12.02950954], [92.75322723, 12.0299902], [92.75321198, 12.0306263], [92.75325775, 12.03125954], [92.75332642, 12.03139019], [92.7536087, 12.03168201], [92.7536087, 12.03222179], [92.75328827, 12.03283882], [92.75324249, 12.03301525], [92.75332642, 12.03333187], [92.75333405, 12.03416634], [92.75305176, 12.03444386], [92.75250244, 12.03388786], [92.75250244, 12.03333187], [92.7519455, 12.03277779], [92.75154114, 12.03253174], [92.75112152, 12.03232384], [92.75074005, 12.0321331], [92.75035858, 12.03197575], [92.74993896, 12.03197098], [92.74952698, 12.03207111], [92.7492218, 12.03236771], [92.74900055, 12.03281212], [92.74882507, 12.0333252], [92.74868774, 12.03384018], [92.7487793, 12.03433895], [92.74888611, 12.03472042], [92.74888611, 12.03481293], [92.74888611, 12.03555584], [92.7485733, 12.03621006], [92.74833679, 12.0363903], [92.74777985, 12.0363903], [92.7474823, 12.03621006], [92.7472229, 12.03610992], [92.74711609, 12.03587055], [92.74680328, 12.03541946], [92.74645233, 12.03499985], [92.74604797, 12.0346384], [92.7455368, 12.03446198], [92.74501038, 12.03447056], [92.74452209, 12.03463078], [92.74401855, 12.03475571], [92.74362183, 12.03499317], [92.74328613, 12.03528023], [92.74302673, 12.03559017], [92.74279022, 12.03590679], [92.74260712, 12.03628063], [92.74247742, 12.03671169], [92.74227905, 12.03711033], [92.74216461, 12.03751755], [92.74198914, 12.03781033], [92.74186707, 12.03806114], [92.74169922, 12.03821754], [92.74147797, 12.03838921], [92.74111176, 12.03889275], [92.7408371, 12.03889275], [92.74055481, 12.03916645], [92.74054718, 12.03971958], [92.74028015, 12.03999996], [92.74028015, 12.0402813], [92.74039459, 12.04092598], [92.74111938, 12.04144096], [92.74124908, 12.04169083], [92.7412262, 12.04209042], [92.7408371, 12.0421114], [92.74049377, 12.04190063], [92.74037933, 12.04183292], [92.73986816, 12.04148197], [92.73948669, 12.04117203], [92.73924255, 12.0409174], [92.73928833, 12.04061127], [92.73937988, 12.04014206], [92.73972321, 12.03967857], [92.74010468, 12.03908443], [92.74040222, 12.0384407], [92.74040222, 12.03816986], [92.74024963, 12.03785133], [92.74008179, 12.03746128], [92.74017334, 12.03703499], [92.74028015, 12.0365696], [92.74045563, 12.03632164], [92.74066162, 12.03610325], [92.7406311, 12.03514957], [92.74077606, 12.0346899], [92.7407608, 12.03425026], [92.74054718, 12.03398609], [92.74017334, 12.03401089], [92.7397995, 12.03427124], [92.73944092, 12.03464031], [92.73905182, 12.03512096], [92.73860168, 12.0352602], [92.73841858, 12.03514099], [92.73816681, 12.03460121], [92.73815918, 12.03392029], [92.73784637, 12.03385067], [92.73783112, 12.03309917], [92.73760986, 12.03306007], [92.73760986, 12.03250027], [92.73735809, 12.03238106], [92.73710632, 12.03197956], [92.73680115, 12.03162003], [92.73653412, 12.03124428], [92.73632813, 12.03090668], [92.73628998, 12.03058147], [92.73644257, 12.03022957], [92.73677826, 12.02991104], [92.73715973, 12.02962112], [92.73845673, 12.02971172], [92.73929596, 12.02968025], [92.73982239, 12.02988052], [92.74028015, 12.02987194], [92.74093628, 12.0302906], [92.74117279, 12.0302906], [92.74149323, 12.0299902], [92.74156952, 12.02897358], [92.74104309, 12.02863216], [92.74098206, 12.02827644], [92.74088287, 12.0278616], [92.7408371, 12.02739716], [92.74082184, 12.02687931], [92.74075317, 12.02634239], [92.74054718, 12.02583981], [92.740242, 12.02540016], [92.73986816, 12.02503109], [92.73943329, 12.02472115], [92.7389679, 12.02446079], [92.73845673, 12.02429295], [92.73795319, 12.02413464], [92.73745728, 12.0239296], [92.73690796, 12.0239048], [92.73636627, 12.02390957], [92.73583984, 12.02398014], [92.73535156, 12.02399158], [92.73493195, 12.02392101], [92.73457336, 12.02383041], [92.73433685, 12.02364063], [92.73414612, 12.02343082], [92.73396301, 12.02317142], [92.73384857, 12.02277184], [92.7336731, 12.02231693], [92.73361206, 12.02175999], [92.73360443, 12.02120209], [92.73364258, 12.02067757], [92.73378754, 12.02026081], [92.73403168, 12.02009201], [92.73431396, 12.01989365], [92.73462677, 12.01974964], [92.73532867, 12.02030182], [92.73561096, 12.02054596], [92.73586273, 12.02077103], [92.73604584, 12.0208807], [92.73628235, 12.0208807], [92.7365799, 12.02085972], [92.73697662, 12.02079201], [92.73735809, 12.02073288], [92.73769379, 12.0207119], [92.73815155, 12.02059078], [92.73854828, 12.0202198], [92.73915863, 12.01961994], [92.73999023, 12.01935101], [92.74022675, 12.01902103], [92.74030304, 12.01850128], [92.74044037, 12.01810932], [92.74030304, 12.01770973], [92.7401886, 12.01729107], [92.7399826, 12.01694202], [92.7396698, 12.01668262], [92.73926544, 12.01650906], [92.73877716, 12.01640034], [92.73829651, 12.01631069], [92.73790741, 12.01606274], [92.73742676, 12.01606274], [92.73681641, 12.01616096], [92.73662567, 12.01592064], [92.73725128, 12.01573658], [92.73758698, 12.01546097], [92.73779297, 12.01512623], [92.73800659, 12.01476955], [92.73830414, 12.01441479], [92.7386322, 12.01402283], [92.73901367, 12.01363754], [92.7394104, 12.01329994], [92.74006653, 12.01317024], [92.74028015, 12.01319122], [92.74054718, 12.01342106], [92.7408905, 12.01379013], [92.74098969, 12.01399994], [92.74120331, 12.01462173], [92.7414093, 12.01491165], [92.74173737, 12.01523972], [92.74221039, 12.01556587], [92.74259186, 12.01577091], [92.74355316, 12.01688957], [92.74362946, 12.01720047], [92.74378204, 12.01748943], [92.74398804, 12.0176506], [92.74415588, 12.01772022], [92.7444458, 12.01779938], [92.74478912, 12.01786137], [92.74507904, 12.01783085], [92.74539185, 12.01779938], [92.74594116, 12.0176506], [92.74627686, 12.01753044], [92.74690247, 12.01724052], [92.74726868, 12.01677132], [92.74754333, 12.01631069], [92.74774933, 12.01573181], [92.74797821, 12.01502323], [92.74836731, 12.01466846], [92.748703, 12.01431179], [92.7490387, 12.01423454], [92.74967194, 12.01419353], [92.75003052, 12.01411247], [92.75018311, 12.01388073], [92.75023651, 12.01342773], [92.75025177, 12.01287174], [92.75041962, 12.01247501], [92.75054932, 12.01200104], [92.7505722, 12.01148224], [92.7502594, 12.01097775], [92.74983215, 12.01056957], [92.74938965, 12.01023006], [92.74900055, 12.00995922], [92.74874115, 12.00966072], [92.74866486, 12.0093298], [92.74881744, 12.00898075], [92.74907684, 12.0086298], [92.74936676, 12.00831985], [92.74984741, 12.00809002], [92.75009918, 12.0079689], [92.75028992, 12.00769997], [92.75032806, 12.00749111], [92.75032806, 12.00720119], [92.75020599, 12.00691223], [92.74980927, 12.00542355], [92.74989319, 12.00509262], [92.74997711, 12.00482368], [92.75022888, 12.00455475], [92.75035095, 12.00443172], [92.75065613, 12.00422001], [92.75093842, 12.00399685], [92.75123596, 12.0037508], [92.7513504, 12.00362968], [92.75151062, 12.00336075], [92.75167847, 12.00307178], [92.75187683, 12.00286198], [92.75226593, 12.00262928], [92.75272369, 12.00248814], [92.75299835, 12.00249004], [92.75325012, 12.00267506], [92.75345612, 12.002985], [92.75356293, 12.00321102], [92.75365448, 12.00325394], [92.75383759, 12.00333977], [92.75440216, 12.00331974], [92.75482178, 12.00330162], [92.75527954, 12.00306034], [92.75569916, 12.00304031], [92.75608063, 12.00293922], [92.7564621, 12.00277996], [92.75686646, 12.00263214], [92.75724792, 12.00261116], [92.75753784, 12.00278378], [92.75776672, 12.002985], [92.75786591, 12.00325203], [92.75773621, 12.00368023], [92.75778961, 12.00413799], [92.75795746, 12.00456047], [92.75829315, 12.00487041], [92.75862885, 12.00522518], [92.75894165, 12.0056448], [92.75913239, 12.00621033], [92.75922394, 12.00686169], [92.7594986, 12.00741959], [92.75984955, 12.00788975], [92.76021576, 12.00827312], [92.76055908, 12.00865078], [92.76084137, 12.00912857], [92.76114655, 12.00966454], [92.76153564, 12.01010036], [92.76200104, 12.01033974], [92.76246643, 12.01056957], [92.76294708, 12.01084137], [92.76345062, 12.01115131], [92.76390839, 12.01154137], [92.76439667, 12.01185989], [92.76499176, 12.01191044], [92.76552582, 12.0117712], [92.76597595, 12.01156139], [92.76611328, 12.01138973], [92.76638794, 12.01111031], [92.76638794, 12.01083374], [92.76667023, 12.01055622], [92.76667023, 12.00944424], [92.76638794, 12.00916576], [92.76605225, 12.00885105], [92.76583099, 12.00833035], [92.76574707, 12.00767326], [92.76585388, 12.00652695], [92.76631927, 12.00540066], [92.76625824, 12.00341606], [92.76638794, 12.00306034], [92.76638794, 12.00277996], [92.76667023, 12.00249863], [92.76667023, 12.0022192], [92.76721954, 12.00166798], [92.76721954, 12.00139046], [92.76805878, 12.00055981], [92.76805878, 12.00028038], [92.76832581, 12.00000191], [92.76875305, 11.99903965], [92.76854706, 11.99871159], [92.76819611, 11.99831963], [92.76766968, 11.99811172], [92.76712036, 11.99800014], [92.76664734, 11.9978199], [92.76622009, 11.9977293], [92.76583099, 11.99756145], [92.76535797, 11.99752045], [92.76477051, 11.99755096], [92.76415253, 11.99764919], [92.76389313, 11.99790001], [92.76377106, 11.99825954], [92.76365662, 11.99838066], [92.76346588, 11.99855042], [92.76309204, 11.99854088], [92.76275635, 11.99859142], [92.76239777, 11.99849033], [92.76195526, 11.99847221], [92.76158905, 11.99829006], [92.76122284, 11.9980278], [92.7609024, 11.99775028], [92.76052094, 11.99750996], [92.76010132, 11.99734211], [92.75961304, 11.9972229], [92.75905609, 11.99710941], [92.75847626, 11.99698162], [92.75788116, 11.99694061], [92.75736237, 11.99688053], [92.75694275, 11.99670124], [92.75649261, 11.99658966], [92.75602722, 11.99651718], [92.75550842, 11.99644184], [92.75491333, 11.99636173], [92.75440216, 11.99634075], [92.75402069, 11.996521], [92.75356293, 11.99667168], [92.7531662, 11.9966011], [92.75276184, 11.9963913], [92.75232697, 11.99635029], [92.75193024, 11.99616146], [92.7514267, 11.99606991], [92.75099182, 11.9958601], [92.75052643, 11.99567127], [92.75003052, 11.99557114], [92.74952698, 11.99555492], [92.74904633, 11.99549103], [92.74858093, 11.99535179], [92.74801636, 11.99534988], [92.74772644, 11.99535179], [92.74733734, 11.99557114], [92.74700165, 11.99580574], [92.74693298, 11.99608135], [92.74680328, 11.99627972], [92.74643707, 11.99644184], [92.74616241, 11.99621964], [92.74616241, 11.99574184], [92.74581146, 11.99496937], [92.74542236, 11.99448586], [92.74521637, 11.99428082], [92.74458313, 11.99413967], [92.74395752, 11.99379539], [92.74318695, 11.99373245], [92.74304962, 11.99359035], [92.74298096, 11.99344921], [92.74291229, 11.99269199], [92.74291229, 11.99214077], [92.74304962, 11.99179363], [92.74311829, 11.99124336], [92.74318695, 11.9909668], [92.74298096, 11.98966122], [92.74291992, 11.98938084], [92.74291992, 11.98883057], [92.74304962, 11.98841], [92.74325562, 11.98834419], [92.74367523, 11.98848343], [92.74472809, 11.98848343], [92.74514771, 11.98910046], [92.74611664, 11.98960018], [92.74710083, 11.99020767], [92.74780273, 11.99069118], [92.74828339, 11.99110603], [92.74904633, 11.99131107], [92.74940491, 11.99158669], [92.74989319, 11.9920702], [92.75074005, 11.99215221], [92.75101471, 11.99215221], [92.75143433, 11.99229145], [92.75227356, 11.99229145], [92.75304413, 11.99208355], [92.75339508, 11.99194717], [92.75380707, 11.99145889], [92.75402069, 11.99118805], [92.75402069, 11.99084187], [92.75430298, 11.99035931], [92.75457764, 11.99008274], [92.75499725, 11.98973942], [92.75563049, 11.98939228], [92.75611877, 11.98911572], [92.75631714, 11.98891068], [92.75717163, 11.9883709], [92.75722504, 11.98789024], [92.75720978, 11.98738194], [92.75705719, 11.98688126], [92.75694275, 11.98659992], [92.75669098, 11.98633957], [92.75652313, 11.98627186], [92.75630188, 11.98627186], [92.75580597, 11.98606014], [92.7556076, 11.9855814], [92.75533295, 11.98524189], [92.75511932, 11.9847517], [92.75525665, 11.98440838], [92.75530243, 11.98361015], [92.75512695, 11.98304939], [92.75496674, 11.98250008], [92.7547226, 11.98203087], [92.75443268, 11.98164845], [92.7541275, 11.98136044], [92.75372314, 11.9813509], [92.7532196, 11.98116016], [92.75295258, 11.98093033], [92.75265503, 11.98054504], [92.75229645, 11.98021889], [92.75209045, 11.97964191], [92.75195312, 11.97917938], [92.7515564, 11.97881031], [92.75105286, 11.97854137], [92.75053406, 11.97829723], [92.75004578, 11.97803974], [92.74957275, 11.97782326], [92.74903107, 11.97779846], [92.7484436, 11.97756767], [92.74768829, 11.977561], [92.74715424, 11.97768879], [92.74653625, 11.97797108], [92.74645233, 11.97820759], [92.74610138, 11.97874165], [92.74588013, 11.97930241], [92.74582672, 11.97981071], [92.74583435, 11.98023033], [92.74582672, 11.98058128], [92.74584198, 11.98089123], [92.74585724, 11.98115063], [92.74588776, 11.98139], [92.74594116, 11.98169994], [92.74591064, 11.98207188], [92.7456665, 11.98238182], [92.74512482, 11.98241138], [92.74471283, 11.9824543], [92.74432373, 11.98234653], [92.7440033, 11.98221111], [92.74362946, 11.98186016], [92.74315643, 11.98155022], [92.74293518, 11.98120308], [92.74240112, 11.98064899], [92.74189758, 11.98024082], [92.74130249, 11.9799614], [92.74082184, 11.97965622], [92.74038696, 11.97942066], [92.74002838, 11.97933197], [92.73970032, 11.97910023], [92.73945618, 11.97903061], [92.73927307, 11.97889042], [92.73892212, 11.97863007], [92.73868561, 11.9784956], [92.73845673, 11.97825623], [92.73812103, 11.97779083], [92.73764801, 11.97750187], [92.73715973, 11.97722244], [92.73668671, 11.97694969], [92.73622131, 11.97671986], [92.73564148, 11.97668076], [92.7350769, 11.97679138], [92.73458862, 11.97709179], [92.73419189, 11.97749996], [92.73388672, 11.97801495], [92.73365784, 11.97858524], [92.73361206, 11.97924137], [92.73361206, 11.97991085], [92.73361969, 11.98054028], [92.73365021, 11.98109627], [92.73361969, 11.98161983], [92.73332977, 11.98217201], [92.73342133, 11.98313999], [92.73361969, 11.98338032], [92.73412323, 11.98359871], [92.73458862, 11.9838829], [92.73509979, 11.98411369], [92.73564911, 11.98407936], [92.73625946, 11.98427105], [92.73652649, 11.98485374], [92.73674011, 11.98533058], [92.7370224, 11.98576164], [92.73728943, 11.98620605], [92.73767853, 11.98656082], [92.73787689, 11.98703957], [92.73802948, 11.98754597], [92.73805237, 11.98808384], [92.73801422, 11.98858261], [92.7378006, 11.98895168], [92.73755646, 11.98929024], [92.73729706, 11.98977661], [92.73696136, 11.99038124], [92.7368927, 11.99100113], [92.73697662, 11.99145031], [92.73713684, 11.99175072], [92.73721313, 11.99202919], [92.73722076, 11.99233246], [92.73722076, 11.99266338], [92.73722839, 11.99304295], [92.73726654, 11.99347019], [92.73738861, 11.99392986], [92.73751068, 11.99438095], [92.73764801, 11.99475002], [92.73777008, 11.99506855], [92.73787689, 11.99534988], [92.73802185, 11.99557972], [92.73805237, 11.99586868], [92.73819733, 11.99615192], [92.73833466, 11.99642563], [92.73861694, 11.99660301], [92.73890686, 11.99686146], [92.73875427, 11.99733734], [92.73867035, 11.99750423], [92.73845673, 11.99746037], [92.73797607, 11.997262], [92.73770905, 11.99727631], [92.73742676, 11.99741173], [92.73706818, 11.99748802], [92.7366333, 11.99750137], [92.73612213, 11.99750137], [92.73558044, 11.99751472], [92.73505402, 11.99760246], [92.73457336, 11.99775028], [92.73408508, 11.99783039], [92.7336731, 11.99795341], [92.73344421, 11.99787331], [92.73329163, 11.99781799], [92.73291779, 11.99775028], [92.73259735, 11.99759007], [92.73229218, 11.99744415], [92.73200226, 11.997262], [92.73163605, 11.997159], [92.73129272, 11.99697018], [92.73088837, 11.99679947], [92.7305069, 11.99650955], [92.73008728, 11.99619961], [92.7296524, 11.99588108], [92.7292099, 11.99558926], [92.72883606, 11.99526119], [92.72828674, 11.99500084], [92.72808075, 11.99479103], [92.72793579, 11.99437904], [92.72786713, 11.9939003], [92.72786713, 11.99361992], [92.72793579, 11.99335098], [92.72821808, 11.99328041], [92.72856903, 11.99327564], [92.72877502, 11.99355221], [92.72940063, 11.99341488], [92.72982025, 11.99341488], [92.73001099, 11.99352932], [92.73033905, 11.99373245], [92.73062134, 11.9934597], [92.73066711, 11.9932394], [92.73049927, 11.99295044], [92.73014832, 11.99263096], [92.72964478, 11.99231625], [92.72926331, 11.99178123], [92.72924042, 11.99100113], [92.72917175, 11.99031067], [92.72916412, 11.98966122], [92.72895813, 11.98902988], [92.72886658, 11.98842144], [92.72865295, 11.98783779], [92.72853088, 11.9872818], [92.72853851, 11.98674202], [92.72827911, 11.98621273], [92.72789764, 11.98574066], [92.72751617, 11.98528099], [92.72689819, 11.98468113], [92.72651672, 11.98414135], [92.72653961, 11.98351192], [92.72698212, 11.98296261], [92.727005, 11.98241329], [92.72651672, 11.98198509], [92.72589874, 11.98168182], [92.72531128, 11.98143101], [92.72486115, 11.98130417], [92.72388458, 11.9810276], [92.72338867, 11.9808197], [92.72332764, 11.98040962], [92.72345734, 11.97999096], [92.72388458, 11.97978592], [92.72409821, 11.97903061], [92.72429657, 11.97881031], [92.72472382, 11.97835922], [92.72473145, 11.97798061], [92.72479248, 11.9776001], [92.7249527, 11.97718143], [92.7248764, 11.97679138], [92.72470093, 11.97646046], [92.72410583, 11.97601986], [92.72376251, 11.97546196], [92.72376251, 11.97498131], [92.72396851, 11.9746418], [92.72418213, 11.9744997], [92.72445679, 11.97429085], [92.72502136, 11.97422028], [92.7258606, 11.97422028], [92.72606659, 11.97435856], [92.72640991, 11.97465992], [92.72679901, 11.97483063], [92.72729492, 11.97511959], [92.72767639, 11.97542953], [92.72815704, 11.97566032], [92.72867584, 11.975811], [92.72923279, 11.975811], [92.72969055, 11.9756794], [92.73011017, 11.97545147], [92.73049927, 11.97519112], [92.7308197, 11.97483063], [92.73110962, 11.97439098], [92.73139191, 11.97388935], [92.73152924, 11.9733696], [92.73187256, 11.97284126], [92.73200226, 11.97234726], [92.73229218, 11.97179031], [92.73258209, 11.97135067], [92.73274231, 11.97087193], [92.73278046, 11.97032928], [92.73282623, 11.96978664], [92.73300934, 11.96926975], [92.73298645, 11.96876144], [92.7327652, 11.96833324], [92.73240662, 11.96800041], [92.73192596, 11.96786118], [92.73137665, 11.96805], [92.73087311, 11.9682579], [92.73044586, 11.96840096], [92.73019409, 11.96856308], [92.72994232, 11.96860886], [92.72969055, 11.96861267], [92.72945404, 11.96861267], [92.72920227, 11.96861267], [92.72891235, 11.96859264], [92.72859955, 11.96848774], [92.72824097, 11.96831036], [92.7278595, 11.96805668], [92.72744751, 11.9677906], [92.72701263, 11.96753979], [92.72644806, 11.96740532], [92.72602844, 11.96726608], [92.72574615, 11.96712971], [92.7253952, 11.96699333], [92.72531128, 11.96696091], [92.72518921, 11.9669199], [92.72505188, 11.96671009], [92.72505188, 11.96609306], [92.72532654, 11.96554089], [92.72548676, 11.96533108], [92.72537994, 11.96475029], [92.7250061, 11.96417141], [92.72466278, 11.9635601], [92.72424316, 11.96304989], [92.72381592, 11.96260071], [92.72332764, 11.96229076], [92.72276306, 11.96230221], [92.72228241, 11.96257973], [92.72174835, 11.96305656], [92.72146606, 11.96333313], [92.72126007, 11.96333313], [92.72076416, 11.96338654], [92.72062683, 11.96340275], [92.72035217, 11.96305656], [92.72006989, 11.96257114], [92.71985626, 11.96214962], [92.71945953, 11.96203995], [92.71924591, 11.96177101], [92.71897888, 11.96152973], [92.71890259, 11.96118832], [92.71877289, 11.96077061], [92.71891785, 11.96027565], [92.71888733, 11.95980167], [92.71893311, 11.95932961], [92.71903992, 11.95888138], [92.71910858, 11.9584713], [92.71911621, 11.9581089], [92.71909332, 11.9577713], [92.71903992, 11.95744801], [92.7190094, 11.9571104], [92.71889496, 11.9567709], [92.71875, 11.95636082], [92.71859741, 11.95602989], [92.71836853, 11.95567036], [92.71820831, 11.95518017], [92.71804047, 11.95460796], [92.7178421, 11.95399857], [92.71772766, 11.95335388], [92.71743011, 11.95287132], [92.71705627, 11.95254135], [92.71673584, 11.95226955], [92.71656799, 11.95200062], [92.71643066, 11.95178032], [92.71624756, 11.95156288], [92.71621704, 11.95149708], [92.71604156, 11.95116425], [92.71596527, 11.95081997], [92.71598053, 11.95020008], [92.71617889, 11.94999027], [92.71638489, 11.949646], [92.71708679, 11.94950962], [92.71750641, 11.94950962], [92.71806335, 11.94956017], [92.71833801, 11.94928169], [92.71856689, 11.94877148], [92.71856689, 11.94816017], [92.71833038, 11.94756126], [92.71802521, 11.9470253], [92.717659, 11.94680882], [92.71752167, 11.94676113], [92.71738434, 11.94648743], [92.71703339, 11.94614124], [92.71681976, 11.94586754], [92.71689606, 11.94511127], [92.71703339, 11.94393921], [92.717453, 11.94330978], [92.71787262, 11.94186497], [92.71801758, 11.94083118], [92.71821594, 11.93986416], [92.71851349, 11.93960857], [92.71861267, 11.93918133], [92.71852875, 11.93868065], [92.71832275, 11.9382], [92.71805573, 11.93772411], [92.71775055, 11.93721962], [92.7173233, 11.93676853], [92.71687317, 11.93634129], [92.71652222, 11.93640709], [92.71630859, 11.93654442], [92.7161026, 11.9366827], [92.71588898, 11.9366827], [92.71546936, 11.9364748], [92.71512604, 11.93626785], [92.71505737, 11.93571186], [92.71505737, 11.93516159], [92.71512604, 11.93488884], [92.71491241, 11.9344101], [92.71470642, 11.93412971], [92.71456146, 11.93399143], [92.71456146, 11.93343925], [92.7144928, 11.93316078], [92.71442413, 11.93295574], [92.7144165, 11.93260956], [92.71450043, 11.93255138], [92.71498108, 11.93219662], [92.71512604, 11.93192101], [92.71518707, 11.93136978], [92.7154007, 11.93089104], [92.71554565, 11.93088436], [92.71575165, 11.93116283], [92.71596527, 11.93185139], [92.71614838, 11.93283081], [92.71645355, 11.93309498], [92.71674347, 11.93345261], [92.71711731, 11.93371964], [92.71740723, 11.93405533], [92.71776581, 11.93435955], [92.71814728, 11.93438053], [92.71862793, 11.9344492], [92.71915436, 11.9344492], [92.71968079, 11.9345417], [92.72015381, 11.9344759], [92.72064209, 11.93433952], [92.72107697, 11.93416023], [92.72149658, 11.93391132], [92.72196198, 11.93361855], [92.72244263, 11.93327141], [92.72261047, 11.93283081], [92.72312927, 11.93221092], [92.72366333, 11.93180084], [92.72396088, 11.93129921], [92.72432709, 11.93098927], [92.72463226, 11.93057919], [92.72458649, 11.9302206], [92.72458649, 11.92992306], [92.72472382, 11.92964745], [92.72471619, 11.92938042], [92.72473145, 11.92910004], [92.72473145, 11.92883587], [92.7247467, 11.92859173], [92.72483063, 11.92827034], [92.72498322, 11.92800999], [92.72512817, 11.92772102], [92.72528076, 11.92739105], [92.72528076, 11.92702103], [92.72528076, 11.92661762], [92.72529602, 11.92618275], [92.72531891, 11.92572212], [92.72531128, 11.92526245], [92.72532654, 11.92487717], [92.72531128, 11.92434978], [92.72535706, 11.9239397], [92.72528076, 11.92345047], [92.72519684, 11.92292976], [92.72502899, 11.92241955], [92.72489929, 11.92186069], [92.7247467, 11.92127991], [92.72471619, 11.92065144], [92.72467804, 11.92002869], [92.72444916, 11.9195118], [92.72424316, 11.91905117], [92.72422028, 11.91858196], [92.7241745, 11.91812992], [92.72428894, 11.91769123], [92.72431183, 11.91725063], [92.72450256, 11.91681957], [92.72454071, 11.91643047], [92.7246933, 11.91596985], [92.72478485, 11.91553879], [92.72483063, 11.91508961], [92.72473907, 11.91458035], [92.7246933, 11.91404247], [92.72458649, 11.91353989], [92.72451019, 11.91309071], [92.7246933, 11.91270161], [92.72480011, 11.91230297], [92.72499084, 11.91192245], [92.72514343, 11.91152096], [92.72525787, 11.91109943], [92.72528076, 11.91069603], [92.72528076, 11.9102993], [92.72528076, 11.90988922], [92.72527313, 11.90945053], [92.72524261, 11.9089613], [92.72511292, 11.90845966], [92.7248764, 11.90802002], [92.72471619, 11.90756035], [92.72460175, 11.90711117], [92.72447205, 11.9066906], [92.72445679, 11.90623093], [92.72454834, 11.90574074], [92.72466278, 11.90525055], [92.72454071, 11.90482903], [92.72428131, 11.90448093], [92.72393036, 11.90419102], [92.72364044, 11.90388966], [92.72331238, 11.903615], [92.72290802, 11.90337753], [92.72248077, 11.90319061], [92.72231293, 11.90296268], [92.72245026, 11.9026804], [92.72289276, 11.90257072], [92.72342682, 11.90284729], [92.72398376, 11.90308094], [92.72422791, 11.90303326], [92.72451782, 11.90284443], [92.72480011, 11.90268517], [92.72506714, 11.90250015], [92.72530365, 11.902318], [92.72551727, 11.9021492], [92.72569275, 11.90193939], [92.72585297, 11.90167141], [92.72606659, 11.90139008], [92.72622681, 11.90100288], [92.7264328, 11.90057373], [92.72667694, 11.90009308], [92.72694397, 11.89956188], [92.72716522, 11.89898968], [92.72721863, 11.89836979], [92.72718811, 11.8978014], [92.72699738, 11.89734173], [92.72686768, 11.89689636], [92.72667694, 11.89651966], [92.72653961, 11.89612103], [92.72637177, 11.89573956], [92.72615814, 11.8953619], [92.72605896, 11.8948946], [92.72585297, 11.89445019], [92.72564697, 11.89398956], [92.72541809, 11.89358902], [92.72524261, 11.89319038], [92.72499084, 11.89285946], [92.72406769, 11.89188194], [92.72371674, 11.89161015], [92.72342682, 11.89133167], [92.72329712, 11.89105034], [92.72357941, 11.89091492], [92.72399902, 11.89098072], [92.72441101, 11.89125919], [92.72496033, 11.89115047], [92.72585297, 11.89098072], [92.72611237, 11.89062977], [92.72631836, 11.89025021], [92.72621155, 11.88979435], [92.72611237, 11.88924026], [92.72601318, 11.88866329], [92.72586823, 11.88811016], [92.72583771, 11.88756943], [92.72583008, 11.88704967], [92.72582245, 11.88654804], [92.72574615, 11.88604927], [92.72558594, 11.88554955], [92.72553253, 11.88498974], [92.72541046, 11.88444042], [92.72529602, 11.88387012], [92.72528076, 11.88330078], [92.72525787, 11.88275146], [92.72517395, 11.88227463], [92.72502899, 11.88187408], [92.72496796, 11.88150024], [92.72483063, 11.88121128], [92.72473907, 11.88091183], [92.7246933, 11.88057518], [92.72457123, 11.88025093], [92.72445679, 11.8798933], [92.72434998, 11.87950134], [92.72416687, 11.87915325], [92.72396851, 11.87881088], [92.72383118, 11.87843037], [92.72358704, 11.87819099], [92.72336578, 11.87782574], [92.72312164, 11.87739086], [92.72348785, 11.87686157], [92.7247467, 11.8767252], [92.72496033, 11.87643814], [92.72509766, 11.87601185], [92.72524261, 11.87552738], [92.72528076, 11.87494087], [92.7251358, 11.87429142], [92.72506714, 11.87361431], [92.72506714, 11.87293053], [92.72532654, 11.87226963], [92.72550201, 11.87174797], [92.72556305, 11.87125111], [92.72556305, 11.87082005], [92.72556305, 11.87045956], [92.72560883, 11.87014961], [92.72576141, 11.86988068], [92.72582245, 11.86958885], [92.72583771, 11.86929131], [92.72589874, 11.86900997], [92.72605133, 11.86872959], [92.72611237, 11.86836815], [92.72615814, 11.86792088], [92.72637939, 11.86744022], [92.72657013, 11.86686993], [92.72665405, 11.86625004], [92.72667694, 11.8656311], [92.72676086, 11.86507034], [92.72691345, 11.86458683], [92.72698975, 11.8640604], [92.72718811, 11.86351109], [92.72721863, 11.86289787], [92.72718811, 11.86225986], [92.72699738, 11.86165142], [92.72692108, 11.86102009], [92.72679138, 11.8604002], [92.72664642, 11.85975933], [92.7264328, 11.85912132], [92.72631836, 11.85846043], [92.72615051, 11.8578701], [92.72608948, 11.85730457], [92.72596741, 11.85678959], [92.72583008, 11.85630703], [92.72566986, 11.85580063], [92.72551727, 11.8552599], [92.72531128, 11.85474968], [92.72518921, 11.85423946], [92.72503662, 11.85377026], [92.72496796, 11.85329056], [92.72480774, 11.85284042], [92.72466278, 11.85231113], [92.72447968, 11.85180092], [92.72444153, 11.85129929], [92.72442627, 11.85085869], [92.7243042, 11.85051346], [92.72419739, 11.85026741], [92.72410583, 11.84997082], [92.72392273, 11.84971142], [92.72380829, 11.84932995], [92.72366333, 11.8488903], [92.72346497, 11.84844398], [92.72322845, 11.84800434], [92.72291565, 11.84770489], [92.72267914, 11.84726143], [92.7224884, 11.84682083], [92.72223663, 11.84639168], [92.72200775, 11.84589958], [92.72177887, 11.8453598], [92.72162628, 11.84475994], [92.72134399, 11.84425545], [92.72104645, 11.84377098], [92.72083282, 11.84320164], [92.72062683, 11.84263611], [92.72055817, 11.842062], [92.72051239, 11.84148979], [92.72032166, 11.84098244], [92.72023773, 11.84040546], [92.72005463, 11.83984947], [92.7199173, 11.83926964], [92.71972656, 11.83875275], [92.71952057, 11.83828831], [92.71933746, 11.83782959], [92.71909332, 11.83740997], [92.71885681, 11.83698177], [92.71861267, 11.83655071], [92.71833038, 11.83618641], [92.71808624, 11.83581924], [92.71798706, 11.83541393], [92.71781158, 11.83505058], [92.71768951, 11.83465481], [92.7175293, 11.8342514], [92.71743774, 11.83380032], [92.71723175, 11.83341026], [92.71704865, 11.8330183], [92.71688843, 11.83261013], [92.71665955, 11.83224964], [92.71640015, 11.83189011], [92.7162323, 11.83150005], [92.71608734, 11.83105087], [92.71591187, 11.83060741], [92.7158432, 11.83008957], [92.71581268, 11.8295517], [92.71569061, 11.82903004], [92.7155304, 11.82852173], [92.71527863, 11.8280201], [92.71501923, 11.82750511], [92.7148056, 11.82695103], [92.71461487, 11.82642746], [92.7144165, 11.82599163], [92.71420288, 11.82565022], [92.71405792, 11.82531929], [92.71391296, 11.82503891], [92.71378326, 11.82475185], [92.71362305, 11.82448101], [92.71347809, 11.82417107], [92.71329498, 11.82385159], [92.7130661, 11.82348919], [92.7128067, 11.82308578], [92.7125473, 11.8226757], [92.71234894, 11.82224941], [92.71215057, 11.82188034], [92.71193695, 11.8215704], [92.7117157, 11.82129669], [92.71154022, 11.82099056], [92.71135712, 11.82069111], [92.71111298, 11.82045078], [92.71086121, 11.82022095], [92.71061707, 11.81998158], [92.71039581, 11.81972027], [92.71018219, 11.81945133], [92.70992279, 11.81917], [92.70961761, 11.81886005], [92.70931244, 11.8184824], [92.708992, 11.81807423], [92.70863342, 11.81770515], [92.70827484, 11.8173542], [92.70783997, 11.81708717], [92.7074585, 11.81674099], [92.70704651, 11.81640053], [92.70658875, 11.8161087], [92.70613098, 11.81581116], [92.70570374, 11.81547356], [92.70521545, 11.81525707], [92.70475006, 11.81503105], [92.70423126, 11.81490421], [92.70375824, 11.81470776], [92.70332336, 11.81447124], [92.70281982, 11.81433868], [92.70230865, 11.8142004], [92.70173645, 11.81417179], [92.70115662, 11.81418991], [92.70056152, 11.81429958], [92.69996643, 11.81443024], [92.69937897, 11.81449986], [92.69877625, 11.8146801], [92.69848633, 11.81473064], [92.69793701, 11.81487179], [92.69765472, 11.81513596], [92.69723511, 11.81541157], [92.69689178, 11.81542301], [92.69675446, 11.81507683], [92.69682312, 11.81466007], [92.69709778, 11.8143177], [92.69724274, 11.81411076], [92.69698334, 11.81336975], [92.69663239, 11.81305122], [92.69628906, 11.81292629], [92.69594574, 11.81305981], [92.69560242, 11.81325817], [92.69520569, 11.81337166], [92.69484711, 11.81354141], [92.69447327, 11.81365013], [92.69351196, 11.81416988], [92.69281006, 11.8147192], [92.69225311, 11.81493092], [92.69140625, 11.81514072], [92.69071198, 11.81582928], [92.69033051, 11.81606197], [92.68995667, 11.81627083], [92.68956757, 11.81634045], [92.68902588, 11.81630993], [92.68875122, 11.81634045], [92.68828583, 11.81647015], [92.68782043, 11.81670189], [92.68733978, 11.81665039], [92.6869278, 11.81681061], [92.68643951, 11.81694126], [92.68572998, 11.81735802], [92.68516541, 11.81758213], [92.68475342, 11.81791878], [92.6844101, 11.81826115], [92.684021, 11.81843185], [92.68358612, 11.81858921], [92.68315887, 11.81868267], [92.68276215, 11.81881714], [92.68238068, 11.81893063], [92.68200684, 11.81906986], [92.68164825, 11.81910038], [92.68135071, 11.81905556], [92.68029785, 11.81941223], [92.68001556, 11.81947994], [92.67991638, 11.81913757], [92.6799469, 11.81880093], [92.6800766, 11.81857967], [92.68022919, 11.81851387], [92.68043518, 11.81844616], [92.68093109, 11.81836128], [92.68109131, 11.81816101], [92.68154907, 11.81795979], [92.68206024, 11.81769085], [92.68247223, 11.81732178], [92.68296051, 11.8172102], [92.6834259, 11.81711197], [92.68383789, 11.81692982], [92.68421936, 11.81668186], [92.68466187, 11.81643963], [92.68507385, 11.81619167], [92.68551636, 11.8160162], [92.68592072, 11.81581974], [92.6862793, 11.81556034], [92.68665314, 11.8152914], [92.6870575, 11.81499958], [92.6875, 11.81473541], [92.68799591, 11.81452847], [92.68850708, 11.81439972], [92.68897247, 11.81421089], [92.68939972, 11.8142004], [92.69008636, 11.81417179], [92.69065857, 11.81437969], [92.69113922, 11.81437016], [92.69217682, 11.8141613], [92.69274139, 11.81360912], [92.69303131, 11.81313992], [92.69303131, 11.81127071], [92.69302368, 11.81002045], [92.69246674, 11.80966187], [92.69190979, 11.80902958], [92.69197845, 11.80883026], [92.69246674, 11.8087616], [92.69267273, 11.80910969], [92.69351959, 11.80951786], [92.69415283, 11.80979156], [92.69462585, 11.80988979], [92.69503784, 11.81004715], [92.69542694, 11.81027889], [92.69582367, 11.81056881], [92.69619751, 11.81090164], [92.69659424, 11.81120491], [92.69695282, 11.81155968], [92.69731903, 11.81191063], [92.69773865, 11.81222057], [92.69819641, 11.81250191], [92.69869995, 11.81273174], [92.6992569, 11.81273174], [92.69976044, 11.81252193], [92.70024872, 11.81234932], [92.70062256, 11.81215096], [92.70083618, 11.81184959], [92.70124054, 11.81176758], [92.70156097, 11.81190205], [92.70182037, 11.81195927], [92.70211029, 11.81210041], [92.70243835, 11.81241512], [92.70295715, 11.81264973], [92.70363617, 11.81273174], [92.70437622, 11.81277084], [92.70510864, 11.81282997], [92.70574951, 11.81303024], [92.70635223, 11.81318092], [92.70685577, 11.81335163], [92.70730591, 11.8135252], [92.70775604, 11.81359959], [92.70820618, 11.81366158], [92.70861053, 11.81385136], [92.70903778, 11.81396008], [92.70941162, 11.81416321], [92.70979309, 11.81436062], [92.71018219, 11.81451607], [92.71047211, 11.81474209], [92.71070099, 11.81500912], [92.71086884, 11.81530952], [92.71102905, 11.81568146], [92.71133423, 11.81593895], [92.711586, 11.81629181], [92.71167755, 11.8168211], [92.71177673, 11.81736088], [92.71198273, 11.81783867], [92.71220398, 11.81831264], [92.71250153, 11.81875992], [92.71282196, 11.81924057], [92.71312714, 11.81975174], [92.71363068, 11.8200798], [92.71399689, 11.82056713], [92.71432495, 11.82126331], [92.71475983, 11.82174969], [92.71512604, 11.82213116], [92.71546936, 11.82241058], [92.71588135, 11.82254791], [92.71620941, 11.82278061], [92.71655273, 11.82304859], [92.71692657, 11.82332134], [92.7173233, 11.82362175], [92.717659, 11.82393074], [92.7179184, 11.8242712], [92.71819305, 11.82452202], [92.71833038, 11.82482719], [92.71844482, 11.82512283], [92.71858215, 11.82541275], [92.71862793, 11.82572079], [92.7186203, 11.82604408], [92.7186203, 11.82638168], [92.71868896, 11.82677078], [92.71882629, 11.82721138], [92.71891785, 11.82774925], [92.71910858, 11.82830143], [92.7192688, 11.82883167], [92.71936798, 11.82936859], [92.71932983, 11.82993507], [92.71957397, 11.83035183], [92.71970367, 11.83076191], [92.71971893, 11.83116531], [92.71972656, 11.83155346], [92.71974945, 11.83191967], [92.71995544, 11.83221626], [92.72013092, 11.83253956], [92.72032928, 11.83284092], [92.72045898, 11.83320999], [92.72064972, 11.83349037], [92.72079468, 11.83383656], [92.72104645, 11.83411217], [92.72117615, 11.83449078], [92.7213974, 11.83484936], [92.72161865, 11.8352108], [92.72177887, 11.83563328], [92.72210693, 11.83595371], [92.72231293, 11.83637142], [92.72250366, 11.83680153], [92.72270203, 11.83723259], [92.72289276, 11.83768082], [92.72309113, 11.83820057], [92.72336578, 11.83871174], [92.72372437, 11.83922863], [92.72405243, 11.83983994], [92.72453308, 11.8404417], [92.72489929, 11.8409996], [92.72525787, 11.84143543], [92.72556305, 11.84183025], [92.7257843, 11.84221935], [92.72587585, 11.84268188], [92.7259903, 11.84312916], [92.72621918, 11.84354782], [92.72635651, 11.84409046], [92.72641754, 11.84464169], [92.72653961, 11.84509087], [92.72664642, 11.84539032], [92.7266922, 11.84566975], [92.72680664, 11.84597492], [92.72692108, 11.84633064], [92.72694397, 11.84676647], [92.72698212, 11.84722042], [92.72714233, 11.84764957], [92.72715759, 11.84811974], [92.72718811, 11.8485508], [92.7273407, 11.84890175], [92.72749329, 11.84924984], [92.72763062, 11.84963131], [92.72775269, 11.85006428], [92.72782898, 11.85057926], [92.72805023, 11.85105991], [92.72834015, 11.85154057], [92.72868347, 11.85199738], [92.72909546, 11.85241413], [92.72968292, 11.85255146], [92.73008728, 11.85291958], [92.73033905, 11.85335064], [92.7306366, 11.85371113], [92.73082733, 11.85418034], [92.73096466, 11.8546133], [92.73110199, 11.85497284], [92.73121643, 11.8553009], [92.73133087, 11.85556126], [92.73139191, 11.85585976], [92.73147583, 11.85623646], [92.73165894, 11.85663891], [92.73181152, 11.85714054], [92.73174286, 11.85745144], [92.73163605, 11.85782909], [92.73139191, 11.85819435], [92.73112488, 11.85855198], [92.73088837, 11.85892296], [92.73069, 11.85931969], [92.73036957, 11.85974979], [92.73020172, 11.86014938], [92.73020172, 11.86088085], [92.73020172, 11.8612566], [92.73012543, 11.86191273], [92.73027039, 11.86242199], [92.7305603, 11.86292076], [92.73060608, 11.86338997], [92.73078156, 11.8637619], [92.73088074, 11.86415958], [92.73114777, 11.86448193], [92.73134613, 11.864851], [92.73139191, 11.86530876], [92.73139191, 11.86583138], [92.73134613, 11.86638737], [92.7311554, 11.86693192], [92.73110962, 11.86752033], [92.73110962, 11.86811924], [92.7310791, 11.86870098], [92.73097992, 11.86927891], [92.73110199, 11.86991119], [92.73124695, 11.87052155], [92.73136902, 11.87115097], [92.73143005, 11.87180042], [92.73161316, 11.87242889], [92.73175049, 11.87311745], [92.73203278, 11.87368011], [92.73239899, 11.87408161], [92.7325058, 11.87449169], [92.73259735, 11.87482929], [92.73264313, 11.87513924], [92.73252869, 11.8755703], [92.7325058, 11.87600517], [92.7325058, 11.87643433], [92.73246765, 11.87687111], [92.73231506, 11.87730694], [92.73216248, 11.87773037], [92.73194122, 11.87830257], [92.73187256, 11.87874222], [92.73190308, 11.87907982], [92.73195648, 11.8794899], [92.73182678, 11.87952042], [92.73182678, 11.87974072], [92.73180389, 11.88012981], [92.73168945, 11.88052177], [92.73166656, 11.88098145], [92.73166656, 11.88144112], [92.73166656, 11.88190556], [92.73162079, 11.88237095], [92.73147583, 11.88283062], [92.73137665, 11.88328934], [92.73137665, 11.88375187], [92.73139191, 11.88422108], [92.73139954, 11.8846817], [92.73150635, 11.88511467], [92.7315979, 11.88554096], [92.73165131, 11.88598061], [92.73166656, 11.88642502], [92.73167419, 11.88688087], [92.7317276, 11.88732147], [92.73188782, 11.88771057], [92.73197937, 11.88812065], [92.73210907, 11.8885107], [92.73220062, 11.88891411], [92.73221588, 11.88936138], [92.73226166, 11.88982964], [92.73243713, 11.89025021], [92.73252869, 11.89067841], [92.73269653, 11.89105034], [92.73277283, 11.8914299], [92.73278046, 11.8918314], [92.73277283, 11.89225769], [92.7326889, 11.8927002], [92.7325058, 11.89316177], [92.73232269, 11.89365482], [92.73214722, 11.89424515], [92.73195648, 11.89491081], [92.73179626, 11.89565086], [92.73168182, 11.89637184], [92.73170471, 11.89701653], [92.7318573, 11.89751053], [92.73194885, 11.89787579], [92.73195648, 11.89813995], [92.73190308, 11.89837933], [92.73178101, 11.89868927], [92.73171997, 11.89914989], [92.73188019, 11.89964008], [92.73215485, 11.90007114], [92.7322464, 11.9005537], [92.73239136, 11.9009819], [92.73252106, 11.90137196], [92.73269653, 11.90177059], [92.73277283, 11.90221119], [92.73278046, 11.90267563], [92.73280334, 11.9031496], [92.73288727, 11.90360069], [92.73300171, 11.90404129], [92.733078, 11.90448093], [92.73316193, 11.90492344], [92.73330688, 11.90536022], [92.73343658, 11.90584087], [92.73361969, 11.90626144], [92.73387146, 11.90665722], [92.7341156, 11.90706062], [92.73431396, 11.90753174], [92.73446655, 11.908041], [92.73467255, 11.90853119], [92.73474884, 11.90905857], [92.73487091, 11.90955162], [92.73499298, 11.9100008], [92.7351532, 11.91046143], [92.735466, 11.91087055], [92.73560333, 11.91143036], [92.73579407, 11.91196823], [92.7359314, 11.91255093], [92.73612213, 11.91307831], [92.73636627, 11.91351986], [92.73656464, 11.91394806], [92.73667908, 11.91440201], [92.73681641, 11.9148674], [92.73700714, 11.91532898], [92.73726654, 11.91576004], [92.73758698, 11.91622066], [92.73788452, 11.916749], [92.73825073, 11.91725254], [92.73861694, 11.91774082], [92.73900604, 11.91817093], [92.7394104, 11.91854095], [92.73977661, 11.91893005], [92.74018097, 11.91925621], [92.7405014, 11.91965294], [92.74082184, 11.919981], [92.74108887, 11.92030716], [92.74131775, 11.92061043], [92.74150848, 11.92096138], [92.74170685, 11.92132759], [92.7419281, 11.92171955], [92.74208832, 11.92218018], [92.74219513, 11.92268562], [92.74221802, 11.92324924], [92.74225616, 11.9238596], [92.74246216, 11.92446041], [92.74259186, 11.92506123], [92.74279022, 11.92554379], [92.7430191, 11.92592144], [92.74323273, 11.92628956], [92.74346161, 11.92669296], [92.74372101, 11.92716026], [92.74410248, 11.92762756], [92.74443817, 11.92818356], [92.74472809, 11.92872238], [92.74500275, 11.92919064], [92.74520111, 11.92955971], [92.74526978, 11.92991066], [92.74529266, 11.93026924], [92.74532318, 11.93065739], [92.7455368, 11.93105125], [92.74588013, 11.93144131], [92.74625397, 11.93182087], [92.74664307, 11.93211269], [92.74711609, 11.93218994], [92.74750519, 11.93232727], [92.74798584, 11.93245316], [92.74847412, 11.93244839], [92.74891663, 11.93223095], [92.7493515, 11.9320097], [92.74984741, 11.93195057], [92.75032043, 11.93190098], [92.7507019, 11.93173027], [92.75108337, 11.93163013], [92.75137329, 11.9315176], [92.75163269, 11.93141079], [92.75192261, 11.93139267], [92.7522583, 11.93139267], [92.75263214, 11.93131256], [92.75315857, 11.9313612], [92.75350952, 11.93159962], [92.75382233, 11.93188953], [92.75418091, 11.93231106], [92.75434113, 11.93260956], [92.754776, 11.93270969], [92.75524902, 11.93305588], [92.75579071, 11.93354416], [92.75605774, 11.9338932], [92.7563858, 11.93418026], [92.75683594, 11.93446732], [92.75728607, 11.93478203], [92.75776672, 11.93505955], [92.75820923, 11.93530083], [92.75853729, 11.93554115], [92.75880432, 11.93573666], [92.75908661, 11.93588924], [92.7592926, 11.93609905], [92.75952911, 11.93631554], [92.75984955, 11.93647957], [92.76022339, 11.93663025], [92.76085663, 11.93618965], [92.76135254, 11.93632507], [92.76219177, 11.9368763], [92.76239777, 11.93729115], [92.76239777, 11.93757057], [92.76213837, 11.93794823], [92.76242828, 11.93825054], [92.76274109, 11.93858147], [92.76303864, 11.93889141], [92.76334381, 11.93918133], [92.7636795, 11.93945408], [92.76405334, 11.93972301], [92.7644577, 11.93992138], [92.76488495, 11.93980026], [92.76506042, 11.93937016], [92.76547241, 11.93905067], [92.76583862, 11.93875694], [92.76624298, 11.93850136], [92.76683807, 11.9383297], [92.76728058, 11.93824387], [92.76774597, 11.93828297], [92.76811218, 11.93859291], [92.76824188, 11.93863964], [92.76850891, 11.93874073], [92.76877594, 11.93888187], [92.769104, 11.93902969], [92.76948547, 11.93923283], [92.76992035, 11.93948364], [92.77039337, 11.93974972], [92.7706604, 11.93985462], [92.77092743, 11.93995953], [92.77168274, 11.93933964], [92.7720871, 11.93920135], [92.77250671, 11.9390707], [92.77426147, 11.9390707], [92.77496338, 11.93879128], [92.77565765, 11.93865204], [92.7771225, 11.93844032], [92.77761078, 11.93809605], [92.77831268, 11.93782043], [92.77870941, 11.93761921], [92.77934265, 11.93693066], [92.77968597, 11.93651772], [92.77996826, 11.93637943], [92.78113556, 11.93643188], [92.78161621, 11.93638611], [92.78203583, 11.93605137], [92.78218079, 11.93605423], [92.78288269, 11.93612194], [92.78372192, 11.93626118], [92.78399658, 11.93626118], [92.78449249, 11.93605137], [92.78476715, 11.93577766], [92.78476715, 11.93515968], [92.78504944, 11.93488026], [92.78555298, 11.93484974], [92.78544617, 11.93443966], [92.78491211, 11.93413925], [92.78434753, 11.93385601], [92.78383636, 11.93354034], [92.78343201, 11.93315029], [92.78308868, 11.93270111], [92.78285217, 11.93220043], [92.78266907, 11.93167114], [92.78252411, 11.9311533], [92.78233337, 11.93062019], [92.78249359, 11.93009758], [92.7828598, 11.92947102], [92.78341675, 11.92897034], [92.78386688, 11.92849064], [92.78424072, 11.92798996], [92.78444672, 11.92753029], [92.78483582, 11.92695141], [92.78542328, 11.92669964], [92.78578186, 11.92635059], [92.78650665, 11.9261694], [92.78714752, 11.92603016], [92.78768158, 11.92556286], [92.78781891, 11.92503834], [92.78791046, 11.92432976], [92.78762054, 11.92383099], [92.78753662, 11.92349052], [92.78740692, 11.92266083], [92.78762054, 11.92162037], [92.7878952, 11.9206562], [92.7881012, 11.92032146], [92.78817749, 11.91980076], [92.78811646, 11.91929722], [92.78793335, 11.91893959], [92.78785706, 11.91843987], [92.78778076, 11.91798019], [92.7876358, 11.91763973], [92.78753662, 11.91740131], [92.78727722, 11.91691113], [92.78717804, 11.91643715], [92.78697968, 11.91595173], [92.78686523, 11.91537285], [92.78666687, 11.91479397], [92.7864151, 11.91420078], [92.78612518, 11.91363144], [92.78583527, 11.91309834], [92.78556061, 11.91260147], [92.78536224, 11.91214275], [92.7853241, 11.91170311], [92.78522491, 11.91126823], [92.78527069, 11.91081047], [92.78541565, 11.91040039], [92.78556061, 11.91000462], [92.78554535, 11.90961838], [92.78547668, 11.90924168], [92.78531647, 11.90889072], [92.78515625, 11.90853119], [92.78499603, 11.90814972], [92.78475952, 11.90778542], [92.7844696, 11.90740681], [92.78417206, 11.90697193], [92.78367615, 11.90649128], [92.78342438, 11.90604877], [92.78327942, 11.90544033], [92.78328705, 11.90487957], [92.78340912, 11.90435123], [92.78366089, 11.90399075], [92.78399658, 11.90352058], [92.78437042, 11.90334129], [92.78482819, 11.90305233], [92.78498077, 11.90303802], [92.78542328, 11.90279198], [92.78557587, 11.90255928], [92.7855072, 11.90221119], [92.78557587, 11.90179825], [92.78578949, 11.9014492], [92.78620911, 11.90145397], [92.78662872, 11.90138626], [92.78697205, 11.90145397], [92.78739166, 11.9015913], [92.78791046, 11.90186024], [92.78835297, 11.9015913], [92.78855133, 11.90121937], [92.78824615, 11.90087128], [92.78785706, 11.90056133], [92.78782654, 11.90005016], [92.78766632, 11.89960957], [92.78731537, 11.8995533], [92.78675842, 11.89963055], [92.78637695, 11.89974022], [92.78591919, 11.8997612], [92.78566742, 11.89968109], [92.78536987, 11.89922047], [92.78522491, 11.89863014], [92.78460693, 11.89843178], [92.78392792, 11.8985939], [92.78347778, 11.89857483], [92.78333282, 11.89857101], [92.78286743, 11.89834118], [92.78244019, 11.89806938], [92.78202057, 11.89784241], [92.78164673, 11.89754963], [92.78130341, 11.8972702], [92.78092194, 11.89702129], [92.78059387, 11.89671993], [92.78040314, 11.89630127], [92.78018188, 11.89591312], [92.77999878, 11.89554024], [92.77977753, 11.89507008], [92.77957916, 11.89457798], [92.77944183, 11.89402199], [92.77936554, 11.89393997], [92.77922821, 11.89352036], [92.77908325, 11.89255905], [92.77894592, 11.89214134], [92.77894592, 11.89152431], [92.77922821, 11.8910408], [92.77992249, 11.89042091], [92.78026581, 11.89021111], [92.78095245, 11.89015388], [92.78128815, 11.88982105], [92.78156281, 11.88951969], [92.78170776, 11.88916016], [92.78190613, 11.88887119], [92.78205109, 11.88852024], [92.78222656, 11.88817978], [92.7824173, 11.88784981], [92.7826004, 11.8875103], [92.78285217, 11.88718033], [92.78325653, 11.88691998], [92.78369904, 11.88666534], [92.7841568, 11.88641167], [92.78460693, 11.88619137], [92.78495026, 11.88588715], [92.78530121, 11.88559055], [92.78566742, 11.88529015], [92.78604889, 11.88500118], [92.78643799, 11.88473034], [92.78690338, 11.88451958], [92.78740692, 11.88445187], [92.78785706, 11.88434887], [92.78811646, 11.8838501], [92.78791046, 11.88313389], [92.78743744, 11.88305855], [92.78688812, 11.88266945], [92.78639984, 11.88226128], [92.78614044, 11.88180065], [92.78618622, 11.88136578], [92.78607178, 11.8808918], [92.78587341, 11.88044739], [92.7858429, 11.88000965], [92.7858963, 11.87955093], [92.78586578, 11.87909985], [92.78594208, 11.87863064], [92.78600311, 11.87830544], [92.78636932, 11.87768269], [92.78659058, 11.87767792], [92.78665924, 11.87737274], [92.78665924, 11.87703991], [92.78662109, 11.87672138], [92.78652191, 11.87642479], [92.78640747, 11.87613678], [92.78617859, 11.87589073], [92.78583527, 11.87547874], [92.7858429, 11.8745079], [92.78625488, 11.87389183], [92.78617859, 11.87368488], [92.78666687, 11.87292385], [92.78689575, 11.87232399], [92.78694153, 11.87172985], [92.7868042, 11.87164974], [92.78642273, 11.87137222], [92.78635406, 11.87089062], [92.78621674, 11.87020016], [92.78565979, 11.86902046], [92.78544617, 11.86826706], [92.78559113, 11.86771107], [92.78572845, 11.86744022], [92.78588104, 11.86723042], [92.78610992, 11.86667919], [92.78630829, 11.86619091], [92.78620148, 11.86566925], [92.78598022, 11.86493969], [92.7858963, 11.86446953], [92.78560638, 11.86395073], [92.78551483, 11.86341095], [92.78533173, 11.86295033], [92.7852478, 11.86248779], [92.78508759, 11.86206055], [92.78496552, 11.86167431], [92.78473663, 11.86139107], [92.78450012, 11.86114311], [92.78429413, 11.86091518], [92.7841568, 11.86064625], [92.78398895, 11.86034966], [92.78383636, 11.85999203], [92.78366852, 11.8595953], [92.78362274, 11.8591404], [92.78365326, 11.85867691], [92.78363037, 11.85824203], [92.78353882, 11.85788059], [92.78373718, 11.85736179], [92.78387451, 11.85709667], [92.78418732, 11.8565712], [92.78458405, 11.85638905], [92.78492737, 11.85642147], [92.78526306, 11.85624123], [92.78557587, 11.85601044], [92.78586578, 11.85568047], [92.78611755, 11.85523129], [92.78594971, 11.85468197], [92.78586578, 11.85405922], [92.78559875, 11.85349941], [92.78556061, 11.85287189], [92.78539276, 11.85231972], [92.78521729, 11.85181904], [92.78482056, 11.85139275], [92.78440857, 11.85103989], [92.78394318, 11.85085869], [92.78341675, 11.85084057], [92.78289795, 11.85090733], [92.7824173, 11.85107422], [92.78192902, 11.85110092], [92.78151703, 11.85103035], [92.78116608, 11.85087109], [92.78093719, 11.85069084], [92.78083038, 11.85013008], [92.78083801, 11.8496666], [92.78064728, 11.84904957], [92.78057861, 11.8485527], [92.7804184, 11.84792423], [92.78028107, 11.84729004], [92.78018188, 11.84669971], [92.78014374, 11.84618473], [92.78029633, 11.84572029], [92.78055573, 11.84532261], [92.7808075, 11.84491062], [92.78096008, 11.84445953], [92.78105164, 11.84401131], [92.78108978, 11.84357262], [92.78096008, 11.84313297], [92.78060913, 11.8427248], [92.78022003, 11.84230995], [92.77979279, 11.84196186], [92.77935791, 11.84166145], [92.77896118, 11.84135532], [92.77861786, 11.84097481], [92.77830505, 11.84050846], [92.77809143, 11.83994007], [92.77789307, 11.83931065], [92.7780304, 11.83867741], [92.77825928, 11.83813], [92.77845001, 11.83764267], [92.7786026, 11.8372736], [92.77852631, 11.83688831], [92.77832031, 11.83657169], [92.77802277, 11.83622074], [92.77762604, 11.83581924], [92.77723694, 11.83532047], [92.7769165, 11.83477116], [92.77664948, 11.83428955], [92.77639008, 11.83388042], [92.77617645, 11.83347034], [92.77616119, 11.83298016], [92.77617645, 11.8324604], [92.77644348, 11.83174038], [92.77674866, 11.83132267], [92.77707672, 11.83094025], [92.77735138, 11.83071041], [92.77754211, 11.83036137], [92.777771, 11.8300209], [92.77797699, 11.82962513], [92.77804565, 11.82913876], [92.77791595, 11.8286314], [92.77791595, 11.82812977], [92.77784729, 11.82766914], [92.77787018, 11.82721138], [92.77780151, 11.82674408], [92.77760315, 11.82622433], [92.77725983, 11.82582474], [92.77687073, 11.82548141], [92.77645874, 11.82527161], [92.77612305, 11.8250618], [92.77587128, 11.82479095], [92.77575684, 11.82439899], [92.7756424, 11.82396126], [92.77557373, 11.82355976], [92.77554321, 11.82291985], [92.77568054, 11.82223129], [92.77588654, 11.82180977], [92.77615356, 11.82143974], [92.77620697, 11.82096195], [92.77614594, 11.82063961], [92.77586365, 11.81974506], [92.77565002, 11.81940079], [92.7754364, 11.81898975], [92.7754364, 11.81885147], [92.77513885, 11.81844997], [92.77507782, 11.81802177], [92.77488708, 11.81781197], [92.77474213, 11.81732941], [92.77433014, 11.81684971], [92.77411652, 11.81581116], [92.77425385, 11.81470776], [92.77433014, 11.81408978], [92.77446747, 11.81353188], [92.77467346, 11.81325817], [92.7747345, 11.81284618], [92.77462769, 11.81217957], [92.77446747, 11.81159019], [92.77435303, 11.8109951], [92.77420807, 11.81042957], [92.77384186, 11.81001091], [92.7734375, 11.80966187], [92.77308655, 11.80932045], [92.77284241, 11.80904579], [92.77266693, 11.80879974], [92.77253723, 11.80858135], [92.77278137, 11.80817795], [92.77298737, 11.80735111], [92.77298737, 11.80659199], [92.77271271, 11.80618191], [92.77229309, 11.80566025], [92.7723465, 11.80539131], [92.77226257, 11.80508137], [92.77179718, 11.80473042], [92.77163696, 11.80431747], [92.77133179, 11.80402088], [92.77105713, 11.80355072], [92.77091217, 11.80281067], [92.77084351, 11.80204487], [92.77079773, 11.80136585], [92.77065277, 11.80083179], [92.77063751, 11.80023098], [92.77015686, 11.79988194], [92.76976776, 11.79953098], [92.76950073, 11.7991209], [92.7693634, 11.79860783], [92.76953888, 11.79806137], [92.76991272, 11.79760075], [92.77015686, 11.79724979], [92.77023315, 11.79687119], [92.77022552, 11.7964716], [92.7702713, 11.79611683], [92.77031708, 11.79576969], [92.770401, 11.79544926], [92.77046204, 11.79515076], [92.77033997, 11.79482937], [92.77011871, 11.79453278], [92.76994324, 11.79422474], [92.76979828, 11.79391479], [92.7697525, 11.7935276], [92.76978302, 11.79312038], [92.76991272, 11.79276657], [92.77001953, 11.79243183], [92.7701416, 11.79215622], [92.7702713, 11.79187107], [92.77039337, 11.79159069], [92.77050018, 11.79128075], [92.77060699, 11.79091072], [92.77081299, 11.79052162], [92.77095795, 11.79001999], [92.77108765, 11.7894659], [92.77108765, 11.78885078]]], [[[92.7024231, 12.63786983], [92.70204163, 12.63783073], [92.70160675, 12.63809109], [92.70121765, 12.63853073], [92.70094299, 12.63910961], [92.70090485, 12.63972759], [92.70118713, 12.64020157], [92.7016449, 12.64054585], [92.7021637, 12.64074421], [92.70269012, 12.64054585], [92.70307159, 12.63998985], [92.70336914, 12.63935566], [92.70336914, 12.63873196], [92.70294189, 12.638237], [92.7026825, 12.63803196], [92.7024231, 12.63786983]]], [[[92.87503052, 12.44508266], [92.87538147, 12.44481087], [92.87565613, 12.44481087], [92.87586975, 12.44474125], [92.87586975, 12.4443903], [92.87545013, 12.44404793], [92.87474823, 12.44411755], [92.87425995, 12.44453144], [92.87425995, 12.44481087], [92.87452698, 12.44528961], [92.87474823, 12.44528961], [92.87503052, 12.44508266]]], [[[92.67945862, 12.54112816], [92.67988586, 12.54111195], [92.68032074, 12.54111195], [92.68073273, 12.54111195], [92.68114471, 12.54111195], [92.68154907, 12.54111195], [92.68195343, 12.54109573], [92.68232727, 12.54099274], [92.68268585, 12.54083633], [92.68305969, 12.54065132], [92.68347168, 12.54039097], [92.68388367, 12.54002476], [92.68432617, 12.53966713], [92.68460083, 12.53924274], [92.68457031, 12.53878021], [92.68432617, 12.538311], [92.68411255, 12.53783035], [92.68387604, 12.53739166], [92.68366241, 12.53697014], [92.68354797, 12.53652573], [92.68334961, 12.53617001], [92.68318939, 12.53582382], [92.68307495, 12.53544807], [92.6830368, 12.53502178], [92.68292999, 12.5346117], [92.68274689, 12.53427029], [92.68251801, 12.53399181], [92.68232727, 12.53371143], [92.68215942, 12.53341007], [92.6819458, 12.53313923], [92.68174744, 12.53283596], [92.681633, 12.53240108], [92.68138885, 12.5319519], [92.68115997, 12.53144073], [92.68106842, 12.53086662], [92.68089294, 12.53036976], [92.68080139, 12.52985668], [92.68061829, 12.52939034], [92.68045044, 12.52889061], [92.68026733, 12.52839184], [92.68006897, 12.52794266], [92.67996979, 12.52749157], [92.67980957, 12.52716255], [92.67971039, 12.52683735], [92.67958069, 12.52652073], [92.67946625, 12.52616501], [92.67944336, 12.52571201], [92.67940521, 12.52523136], [92.67925262, 12.52475929], [92.6792984, 12.5243206], [92.67942047, 12.52395439], [92.67944336, 12.52363777], [92.67941284, 12.52334976], [92.67920685, 12.52309132], [92.67894745, 12.52278137], [92.67856598, 12.52245045], [92.67842102, 12.52224731], [92.67811584, 12.52221966], [92.67767334, 12.52229118], [92.67720795, 12.52258015], [92.67670441, 12.52294922], [92.67627716, 12.52342129], [92.67579651, 12.52380562], [92.67529297, 12.52408886], [92.67482758, 12.52434635], [92.67446136, 12.52460194], [92.67415619, 12.52484131], [92.67385864, 12.52504063], [92.67360687, 12.52528954], [92.67331696, 12.52557945], [92.67299652, 12.52590084], [92.67268372, 12.52632904], [92.67229462, 12.52671432], [92.67195129, 12.52711964], [92.67163849, 12.52752113], [92.67131805, 12.52786827], [92.67105865, 12.52826023], [92.67074585, 12.52861977], [92.6704483, 12.52898884], [92.67010498, 12.52934361], [92.6697998, 12.52977085], [92.66958618, 12.53027725], [92.66938782, 12.53077984], [92.66915894, 12.53126144], [92.66893005, 12.53171921], [92.66887665, 12.53223896], [92.66879272, 12.53272247], [92.66864014, 12.53314781], [92.66860962, 12.5336628], [92.66860962, 12.53423119], [92.66866302, 12.53483868], [92.66886902, 12.53539753], [92.66902161, 12.53596306], [92.66918182, 12.53647137], [92.66942596, 12.53694057], [92.66972351, 12.53736019], [92.6700058, 12.53779984], [92.67028046, 12.53826046], [92.67054749, 12.53864098], [92.67079163, 12.53898144], [92.67095947, 12.5392952], [92.67111969, 12.53962994], [92.67131805, 12.53994942], [92.67140961, 12.54032993], [92.67163086, 12.54067898], [92.67183685, 12.54106236], [92.67224121, 12.54139042], [92.67276764, 12.54166985], [92.67337799, 12.54195023], [92.67404938, 12.54217625], [92.67475891, 12.54222393], [92.67544556, 12.54219437], [92.67602539, 12.54203701], [92.67655182, 12.5418911], [92.67698669, 12.54168129], [92.67737579, 12.54150105], [92.67780304, 12.54140568], [92.67823029, 12.5413866], [92.67865753, 12.5413599], [92.67905426, 12.54123497], [92.67945862, 12.54112816]]], [[[92.65584564, 12.76895905], [92.65564728, 12.7688818], [92.65537262, 12.76893616], [92.65503693, 12.76931], [92.65473175, 12.76999187], [92.65444183, 12.7707119], [92.65426636, 12.77139759], [92.65454865, 12.77195168], [92.65490723, 12.77250767], [92.65528107, 12.77307129], [92.6556778, 12.77361774], [92.65612793, 12.77405262], [92.6567688, 12.77399445], [92.65724945, 12.77359486], [92.65753937, 12.77317619], [92.65730286, 12.77268124], [92.65686798, 12.77217674], [92.6566391, 12.77165985], [92.65644836, 12.77118969], [92.65643311, 12.77067089], [92.6565094, 12.77012062], [92.65628052, 12.76949024], [92.65584564, 12.76895905]]], [[[92.73144531, 12.70312405], [92.73145294, 12.70259094], [92.73087311, 12.70259094], [92.73088074, 12.70293045], [92.73116302, 12.7029171], [92.73116302, 12.70452118], [92.73143768, 12.70452118], [92.73170471, 12.70420933], [92.7317276, 12.70398998], [92.73226929, 12.70396709], [92.73229218, 12.70344067], [92.73253632, 12.7034111], [92.73254395, 12.70313263], [92.73144531, 12.70312405]]], [[[92.72425842, 12.73672962], [92.72425079, 12.73589134], [92.72621918, 12.73590946], [92.72615814, 12.73621178], [92.72701263, 12.73621178], [92.72705078, 12.73532963], [92.72766113, 12.73507309], [92.72757721, 12.73371506], [92.72814941, 12.73335361], [92.72812653, 12.73257732], [92.72870636, 12.7325592], [92.72870636, 12.73174095], [92.72926331, 12.73147202], [92.72926331, 12.73089123], [92.72957611, 12.73089123], [92.72953796, 12.72866154], [92.72901154, 12.72870255], [92.72870636, 12.72840405], [92.72872162, 12.72782516], [92.72843933, 12.72784424], [92.72840118, 12.72730637], [92.72786713, 12.7267313], [92.72704315, 12.72672653], [92.72697449, 12.72729206], [92.72670746, 12.72731209], [92.7266922, 12.72787094], [92.72618103, 12.72784996], [92.72619629, 12.72955132], [92.72589874, 12.72957993], [92.72589874, 12.73063087], [92.7256546, 12.73064709], [92.72561646, 12.73230362], [92.72510529, 12.73232365], [92.72512817, 12.732584], [92.72541046, 12.73284435], [92.72592163, 12.73286438], [92.72592926, 12.73339272], [92.72537231, 12.73339272], [92.72537231, 12.7331152], [92.72481537, 12.7331152], [92.72480774, 12.73369217], [92.72454834, 12.73367119], [92.72454834, 12.7339716], [92.72399139, 12.73393059], [92.72399902, 12.73510933], [92.7234726, 12.73507118], [92.72289276, 12.73561096], [92.72290039, 12.73593044], [92.72370911, 12.73672962], [92.72425842, 12.73672962]]], [[[92.72669983, 12.75137997], [92.72653198, 12.75137997], [92.72623444, 12.75146675], [92.72598267, 12.75168991], [92.72572327, 12.7518816], [92.72554779, 12.75217056], [92.72541809, 12.75248146], [92.72540283, 12.75281143], [92.72537994, 12.75326538], [92.72537994, 12.75351143], [92.72541809, 12.75367832], [92.7257309, 12.75382328], [92.72623444, 12.75380325], [92.72648621, 12.75367832], [92.72667694, 12.7533493], [92.72680664, 12.75292969], [92.72684479, 12.75254345], [92.72680664, 12.75219154], [92.72680664, 12.75157166], [92.72682953, 12.75142097], [92.72669983, 12.75137997]]], [[[92.71707916, 12.77478027], [92.71624756, 12.77478027], [92.7162323, 12.77531147], [92.71562958, 12.77565098], [92.71563721, 12.77701092], [92.71618652, 12.77699089], [92.71617126, 12.77674007], [92.71707916, 12.77672577], [92.71763611, 12.77616119], [92.71763611, 12.77561569], [92.71707916, 12.7750597], [92.71707916, 12.77478027]]], [[[92.91278076, 12.33166599], [92.91222382, 12.33166599], [92.91166687, 12.33222198], [92.91168213, 12.33249092], [92.91139221, 12.33278275], [92.91139221, 12.33305645], [92.91110992, 12.33333206], [92.91110992, 12.33471966], [92.91130066, 12.33490658], [92.91139221, 12.33500004], [92.91168213, 12.33500004], [92.91194153, 12.33528137], [92.91278076, 12.33444023], [92.91278076, 12.33416557], [92.91306305, 12.33388996], [92.91306305, 12.33360958], [92.91361237, 12.33305645], [92.91361237, 12.33278275], [92.91333008, 12.33249092], [92.91333008, 12.33222198], [92.91278076, 12.33166599]]], [[[92.90593719, 12.33850765], [92.90573883, 12.33835125], [92.90546417, 12.33845329], [92.90507507, 12.33876133], [92.90473938, 12.33930111], [92.90453339, 12.33997059], [92.90468597, 12.34068012], [92.90537262, 12.34114265], [92.90555573, 12.34106731], [92.90602112, 12.34087563], [92.90638733, 12.34037018], [92.90660858, 12.33985043], [92.90654755, 12.33933067], [92.90633392, 12.33884144], [92.90593719, 12.33850765]]], [[[92.91173553, 12.33795166], [92.91104889, 12.33769417], [92.91072083, 12.33773136], [92.91040039, 12.33788109], [92.91014099, 12.3382206], [92.90997314, 12.33868122], [92.909729, 12.33908939], [92.90950775, 12.33947182], [92.90930939, 12.33986187], [92.90908813, 12.34023094], [92.90882111, 12.3405571], [92.90857697, 12.34086037], [92.9083786, 12.34113598], [92.90842438, 12.3414526], [92.90865326, 12.34181023], [92.90898132, 12.34219074], [92.90937042, 12.342556], [92.90969086, 12.34295177], [92.90990448, 12.34338284], [92.91003418, 12.34383202], [92.91023254, 12.34423065], [92.91027832, 12.34466171], [92.9102478, 12.34507942], [92.91011047, 12.3454504], [92.90997314, 12.34579659], [92.90979004, 12.34608078], [92.90970612, 12.34643936], [92.90962219, 12.34681129], [92.90948486, 12.34720993], [92.90944672, 12.34767532], [92.90944672, 12.34817791], [92.9095459, 12.34869957], [92.90973663, 12.34916973], [92.90995026, 12.34961033], [92.91005707, 12.35007], [92.91023254, 12.35046196], [92.91034698, 12.35088062], [92.91056061, 12.3512001], [92.91078949, 12.35145092], [92.91101837, 12.35169029], [92.91121674, 12.35195923], [92.91143799, 12.35228062], [92.91168213, 12.35266781], [92.91197205, 12.35308075], [92.9122467, 12.35352516], [92.91255951, 12.35395145], [92.91290283, 12.35437965], [92.9133606, 12.35475063], [92.9139328, 12.35509968], [92.91449738, 12.35547066], [92.91504669, 12.35548115], [92.91558075, 12.35529137], [92.91609955, 12.35510921], [92.9165802, 12.35491085], [92.9169693, 12.35464001], [92.91738129, 12.35439968], [92.91773224, 12.35408115], [92.9180069, 12.35365963], [92.91832733, 12.35323143], [92.91860962, 12.35277081], [92.9188385, 12.35229874], [92.91889191, 12.3517704], [92.91889191, 12.35122967], [92.91888428, 12.35070992], [92.91880798, 12.35021973], [92.91858673, 12.34980106], [92.91832733, 12.34939957], [92.91805267, 12.34898663], [92.91777802, 12.34854126], [92.91750336, 12.34805107], [92.91720581, 12.34754944], [92.91689301, 12.34704971], [92.91652679, 12.34659672], [92.91628265, 12.34612179], [92.91609192, 12.34565067], [92.91584778, 12.34524727], [92.91562653, 12.34482098], [92.91536713, 12.34442043], [92.91509247, 12.34401035], [92.91477203, 12.34358978], [92.91445923, 12.3431797], [92.91416931, 12.34274006], [92.91387177, 12.34231186], [92.91352844, 12.34196091], [92.91317749, 12.34169197], [92.91285706, 12.34145927], [92.91262054, 12.34121132], [92.91243744, 12.34090137], [92.91221619, 12.34056091], [92.91203308, 12.34016037], [92.91197968, 12.33965015], [92.91204834, 12.33907127], [92.91208649, 12.33845997], [92.91173553, 12.33795166]]], [[[92.85290527, 12.40883064], [92.853302, 12.4087534], [92.85405731, 12.40888119], [92.85463715, 12.40878963], [92.85514832, 12.40859985], [92.85562134, 12.40838242], [92.85614014, 12.4083128], [92.85665131, 12.40819931], [92.85714722, 12.40804195], [92.85765839, 12.40785122], [92.85817719, 12.40773201], [92.85858917, 12.40751076], [92.85891724, 12.40723991], [92.85928345, 12.40699959], [92.85970306, 12.40683174], [92.86013031, 12.40664005], [92.86058044, 12.40639019], [92.86107635, 12.40610886], [92.86161804, 12.40583992], [92.86219025, 12.40558147], [92.86274719, 12.40530014], [92.86326599, 12.40501976], [92.86376953, 12.40471172], [92.86421967, 12.40444279], [92.86464691, 12.40417004], [92.86505127, 12.40391922], [92.86542511, 12.40374565], [92.86575317, 12.4036684], [92.86606598, 12.40380478], [92.86637878, 12.40387058], [92.86675262, 12.40389156], [92.86717224, 12.40389156], [92.86762238, 12.40389156], [92.86807251, 12.403862], [92.86847687, 12.40374088], [92.86884308, 12.40367985], [92.8691864, 12.40384197], [92.86955261, 12.40389156], [92.86995697, 12.4039402], [92.87034607, 12.40416145], [92.87078857, 12.40441132], [92.87126923, 12.40470982], [92.87181854, 12.40500164], [92.87241364, 12.40528202], [92.87303162, 12.40550137], [92.87368011, 12.40543461], [92.87408447, 12.40501308], [92.8741684, 12.40445042], [92.87421417, 12.40396023], [92.87442017, 12.40359116], [92.87458801, 12.4032011], [92.87477875, 12.40282059], [92.87502289, 12.40248299], [92.87527466, 12.40216637], [92.8755188, 12.40184975], [92.87571716, 12.4015007], [92.87594604, 12.40114975], [92.87625885, 12.40084171], [92.87661743, 12.40055275], [92.87702179, 12.40027714], [92.87748718, 12.40000057], [92.87800598, 12.39972115], [92.87856293, 12.39942932], [92.87909698, 12.39915085], [92.87960052, 12.39887142], [92.88006592, 12.3986063], [92.88054657, 12.39838123], [92.8811264, 12.39833546], [92.8817215, 12.39837646], [92.88224792, 12.39856052], [92.88278198, 12.39866066], [92.88321686, 12.39889622], [92.88362885, 12.39920998], [92.88394165, 12.39965725], [92.88424683, 12.40010357], [92.88441467, 12.40059376], [92.88445282, 12.40110016], [92.88445282, 12.40159035], [92.88437653, 12.40204144], [92.88421631, 12.40240955], [92.88418579, 12.40279961], [92.88432312, 12.4032011], [92.88457489, 12.40357494], [92.88491821, 12.40390968], [92.88524628, 12.40429115], [92.88548279, 12.40468025], [92.88562012, 12.40514088], [92.88581085, 12.40554047], [92.8859787, 12.40597725], [92.88616943, 12.4064436], [92.88643646, 12.40692139], [92.88684845, 12.40739918], [92.88748932, 12.40775013], [92.888237, 12.40793037], [92.88878632, 12.4076004], [92.88916016, 12.40699959], [92.88939667, 12.40639019], [92.88939667, 12.40583992], [92.88920593, 12.40537071], [92.88916779, 12.40493107], [92.88916779, 12.40448189], [92.88916779, 12.40400124], [92.88916779, 12.40344048], [92.88916779, 12.40287971], [92.88920593, 12.40233135], [92.88941956, 12.40183067], [92.88964081, 12.40135002], [92.88986969, 12.40089512], [92.89025116, 12.40056038], [92.89073944, 12.40032005], [92.89138031, 12.40030193], [92.8920517, 12.40040016], [92.8927002, 12.40052986], [92.89331055, 12.40055275], [92.89380646, 12.40040016], [92.89408875, 12.39976597], [92.89415741, 12.39901447], [92.89411163, 12.39835072], [92.89392853, 12.39776993], [92.89380646, 12.39716816], [92.89369202, 12.39655113], [92.8934021, 12.39610386], [92.89307404, 12.3956728], [92.89276886, 12.39518547], [92.8924408, 12.39468575], [92.89203644, 12.39425087], [92.89167786, 12.39382458], [92.89138794, 12.39340115], [92.89113617, 12.39301968], [92.89096069, 12.39264202], [92.89079285, 12.39227962], [92.89054871, 12.39195824], [92.89025116, 12.39164066], [92.88989258, 12.39133072], [92.88941956, 12.39110088], [92.88893127, 12.39091015], [92.8884201, 12.39083004], [92.88793945, 12.39076614], [92.88755035, 12.3905611], [92.88717651, 12.39033985], [92.88680267, 12.39013004], [92.88639069, 12.38992977], [92.88600159, 12.38971138], [92.88564301, 12.38945103], [92.88529968, 12.38918018], [92.88498688, 12.38889027], [92.88469696, 12.3886013], [92.88440704, 12.38833046], [92.88420868, 12.38806057], [92.8841629, 12.38773918], [92.88409424, 12.38747311], [92.88394165, 12.38724518], [92.8839035, 12.38700771], [92.88395691, 12.38675022], [92.88411713, 12.38647461], [92.8841629, 12.3861599], [92.88417053, 12.38581085], [92.88417053, 12.38543129], [92.8841629, 12.38502026], [92.88417053, 12.38458729], [92.88420868, 12.384161], [92.88437653, 12.38379192], [92.884552, 12.38338184], [92.88481903, 12.38296032], [92.88514709, 12.38251114], [92.88549042, 12.38204193], [92.88571167, 12.38149166], [92.88581848, 12.38093853], [92.88582611, 12.3804512], [92.88583374, 12.38003063], [92.88586426, 12.37964153], [92.88600159, 12.37925434], [92.88606262, 12.37886238], [92.88593292, 12.37847042], [92.88565826, 12.37812233], [92.88555145, 12.37777328], [92.88547516, 12.3774538], [92.88537598, 12.37716389], [92.88542938, 12.37680435], [92.88549805, 12.37636662], [92.88537598, 12.37591076], [92.88506317, 12.37545967], [92.8846817, 12.37493134], [92.88418579, 12.37442017], [92.88398743, 12.374156], [92.88374329, 12.37399197], [92.88329315, 12.37391186], [92.88275909, 12.37395096], [92.88223267, 12.37415123], [92.88173676, 12.37444115], [92.8814621, 12.37488079], [92.88149261, 12.37537098], [92.88165283, 12.37586498], [92.88179779, 12.37638474], [92.88196564, 12.37690353], [92.88217163, 12.37740421], [92.88217926, 12.3779211], [92.88201904, 12.37848186], [92.88195038, 12.37905788], [92.88194275, 12.37966537], [92.88194275, 12.38024998], [92.88189697, 12.38076973], [92.88169098, 12.38115978], [92.88152313, 12.3815403], [92.88134003, 12.38189983], [92.88109589, 12.38225079], [92.88080597, 12.38261127], [92.88041687, 12.38294029], [92.88005066, 12.38330173], [92.87963104, 12.38352108], [92.87921143, 12.38354969], [92.87885284, 12.38334084], [92.87848663, 12.38305092], [92.87806702, 12.38272095], [92.87760162, 12.3824091], [92.87708282, 12.38238144], [92.87657166, 12.38252926], [92.87612152, 12.38278008], [92.87573242, 12.38305092], [92.87536621, 12.38331985], [92.87496948, 12.38349819], [92.87452698, 12.38363934], [92.87416077, 12.38387012], [92.87375641, 12.38402462], [92.87352753, 12.3840704], [92.8733902, 12.38410187], [92.87306213, 12.38389015], [92.87270355, 12.38366032], [92.87230682, 12.38341141], [92.87195587, 12.38305092], [92.87164307, 12.38258171], [92.87126923, 12.38210773], [92.8708725, 12.38164139], [92.87049866, 12.38118935], [92.87014771, 12.38081074], [92.86989594, 12.38045979], [92.86969757, 12.38014984], [92.86949158, 12.37989044], [92.86933136, 12.37962055], [92.86915588, 12.37938404], [92.868927, 12.37917042], [92.86868286, 12.37893963], [92.86849213, 12.37863731], [92.86826324, 12.3783493], [92.86798096, 12.37810993], [92.86765289, 12.3779211], [92.86727905, 12.37780476], [92.86688232, 12.37782955], [92.8664856, 12.37804413], [92.86605835, 12.37827396], [92.86561584, 12.37847042], [92.865242, 12.37873173], [92.86483765, 12.37893105], [92.86444855, 12.37917042], [92.86399078, 12.37939072], [92.86342621, 12.37949085], [92.86284637, 12.37974167], [92.86229706, 12.38009071], [92.86183929, 12.38053703], [92.86141205, 12.38097954], [92.8610611, 12.38145065], [92.86078644, 12.38194084], [92.8605423, 12.382411], [92.86027527, 12.38285828], [92.86003113, 12.38329124], [92.85992432, 12.38376904], [92.86001587, 12.38422298], [92.8602066, 12.38464355], [92.86043549, 12.38504124], [92.86061859, 12.385499], [92.86083221, 12.38597965], [92.86099243, 12.38653183], [92.8609314, 12.38710976], [92.86078644, 12.38764095], [92.86057281, 12.38801956], [92.86030579, 12.38828945], [92.85999298, 12.38847065], [92.8596344, 12.38863659], [92.8592453, 12.38882446], [92.85879517, 12.38882446], [92.85832214, 12.3886652], [92.8578949, 12.38861942], [92.85749054, 12.38861942], [92.85710144, 12.3886404], [92.85668182, 12.38861942], [92.8562088, 12.38858986], [92.85571289, 12.38850117], [92.85520172, 12.38849163], [92.8547287, 12.38878059], [92.85427856, 12.38921356], [92.85385895, 12.38973427], [92.85338593, 12.39022064], [92.8529129, 12.39069843], [92.85243225, 12.39117622], [92.85196686, 12.39164352], [92.85151672, 12.39208126], [92.85105896, 12.39246559], [92.85061646, 12.39280128], [92.85022736, 12.3931179], [92.84989929, 12.39344025], [92.84957886, 12.39372921], [92.84916687, 12.39391613], [92.84880829, 12.39415264], [92.84842682, 12.39433098], [92.84803009, 12.39443111], [92.8476181, 12.39444923], [92.84727478, 12.39442635], [92.84680939, 12.39430809], [92.84642792, 12.39420128], [92.84609222, 12.39418507], [92.84576416, 12.39426231], [92.84545135, 12.39441109], [92.8451004, 12.39451122], [92.84474945, 12.39469147], [92.84435272, 12.39495087], [92.84421539, 12.39572811], [92.84391785, 12.39650536], [92.84397888, 12.39702034], [92.84413147, 12.39748096], [92.84416199, 12.39791965], [92.84411621, 12.39835644], [92.84393311, 12.39883232], [92.84384155, 12.3994112], [92.84365082, 12.40001011], [92.84365845, 12.40062141], [92.84385681, 12.40113926], [92.84397888, 12.40158081], [92.84413147, 12.40191269], [92.84416962, 12.40223312], [92.84416962, 12.40255165], [92.84416199, 12.40289116], [92.84417725, 12.40327168], [92.84426117, 12.40367985], [92.84449005, 12.4040699], [92.84480286, 12.40441418], [92.84512329, 12.40471172], [92.84544373, 12.40498066], [92.84575653, 12.40519142], [92.84607697, 12.40538025], [92.84638977, 12.40561008], [92.84670258, 12.40587902], [92.84703827, 12.40617847], [92.8474884, 12.40640068], [92.84793091, 12.40666962], [92.84838104, 12.40694141], [92.84886932, 12.40717602], [92.8494339, 12.40733147], [92.84999847, 12.4075222], [92.85048676, 12.40781021], [92.85092163, 12.4081583], [92.85132599, 12.40854073], [92.85179138, 12.40888119], [92.85250092, 12.40891266], [92.85290527, 12.40883064]]], [[[92.95536041, 12.41469002], [92.95501709, 12.41419125], [92.95472717, 12.41369915], [92.95443726, 12.41324139], [92.9541626, 12.4128418], [92.95391846, 12.41244984], [92.95380402, 12.41202354], [92.9536438, 12.41161346], [92.95357513, 12.41116905], [92.95340729, 12.41075039], [92.95334625, 12.41032124], [92.95333099, 12.40988064], [92.95333099, 12.40944099], [92.95326996, 12.40904045], [92.95305634, 12.40869236], [92.95278168, 12.40836143], [92.95240021, 12.40806484], [92.9519577, 12.40777969], [92.95150757, 12.40754986], [92.95104218, 12.40750027], [92.95059967, 12.40748405], [92.95019531, 12.40739918], [92.94978333, 12.40725136], [92.94932556, 12.40718079], [92.94890594, 12.40699959], [92.94846344, 12.40694809], [92.94802856, 12.40694141], [92.94761658, 12.40695], [92.9471817, 12.40695], [92.94668579, 12.40691185], [92.94616699, 12.40666103], [92.94565582, 12.40630054], [92.94527435, 12.40583611], [92.94497681, 12.40539074], [92.94473267, 12.4050312], [92.94451141, 12.40475845], [92.94444275, 12.4044199], [92.94443512, 12.40406704], [92.94454193, 12.40364075], [92.94428253, 12.40348053], [92.94397736, 12.40343094], [92.94386292, 12.40321922], [92.94367218, 12.40290928], [92.94352722, 12.40241718], [92.94332123, 12.40182018], [92.94306183, 12.40118027], [92.94285583, 12.40049076], [92.94284058, 12.39978886], [92.94302368, 12.39915562], [92.94313812, 12.39856052], [92.94330597, 12.39806557], [92.94333649, 12.39757156], [92.94333649, 12.39706135], [92.94333649, 12.39653015], [92.94332886, 12.3960104], [92.94328308, 12.39554119], [92.94309235, 12.39517879], [92.94304657, 12.39481163], [92.94304657, 12.3944397], [92.94301605, 12.39404106], [92.94284058, 12.39363956], [92.94274139, 12.39310932], [92.94258118, 12.39254379], [92.94273376, 12.39191723], [92.94281006, 12.39124012], [92.94294739, 12.39059544], [92.94281006, 12.3899641], [92.94271851, 12.38935089], [92.94252777, 12.38883972], [92.94252777, 12.38837147], [92.94270325, 12.3879509], [92.94281006, 12.38750172], [92.94299316, 12.38705063], [92.9430542, 12.38650894], [92.94306183, 12.38591194], [92.94304657, 12.38525963], [92.94300842, 12.38460827], [92.94278717, 12.38401985], [92.94260406, 12.38342476], [92.94247437, 12.38281727], [92.9422226, 12.3822813], [92.94194031, 12.38179779], [92.94161987, 12.38136005], [92.94126129, 12.38097], [92.94093323, 12.38058758], [92.94056702, 12.38027096], [92.94021606, 12.37996101], [92.93984222, 12.37970066], [92.93949127, 12.37943745], [92.93916321, 12.37917042], [92.93884277, 12.37890053], [92.93851471, 12.3786478], [92.93815613, 12.37842178], [92.93786621, 12.37813091], [92.93763733, 12.3777504], [92.93744659, 12.37731171], [92.93724823, 12.37689114], [92.93712616, 12.37644577], [92.93696594, 12.3760519], [92.93686676, 12.37564182], [92.93669891, 12.37524986], [92.93662262, 12.37477112], [92.936409, 12.37431335], [92.93624878, 12.37373447], [92.93613434, 12.37308216], [92.93611145, 12.37241745], [92.93611145, 12.37178135], [92.9360733, 12.37118244], [92.93583679, 12.37068462], [92.93562317, 12.37018967], [92.93546295, 12.3696413], [92.93531036, 12.36910057], [92.93527985, 12.36854172], [92.93522644, 12.36800003], [92.93505096, 12.36750984], [92.93495941, 12.36707687], [92.93479156, 12.36670113], [92.93473053, 12.36629963], [92.9347229, 12.3658514], [92.93467712, 12.36534023], [92.93457031, 12.36476135], [92.93464661, 12.36405468], [92.93437195, 12.36364174], [92.93401337, 12.36328888], [92.93371582, 12.36287022], [92.93350983, 12.36239624], [92.93335724, 12.36193085], [92.93331909, 12.3615036], [92.93322754, 12.36116028], [92.93308258, 12.3608799], [92.93296814, 12.36058998], [92.93278503, 12.36030769], [92.93258667, 12.35992336], [92.93234253, 12.35944939], [92.93197632, 12.35898972], [92.9313736, 12.35878468], [92.93107605, 12.35879898], [92.9307785, 12.35898972], [92.93054199, 12.35942078], [92.93028259, 12.35991764], [92.93000031, 12.36043072], [92.92970276, 12.36091423], [92.92935944, 12.36131954], [92.92896271, 12.36168003], [92.92856598, 12.36198997], [92.92814636, 12.36225033], [92.92775726, 12.36250019], [92.92736053, 12.36268044], [92.92690277, 12.36271], [92.92674255, 12.36266422], [92.9263916, 12.36257553], [92.92588806, 12.36256027], [92.92546082, 12.36278534], [92.92505646, 12.36304092], [92.92461395, 12.36323738], [92.92405701, 12.3632412], [92.92352295, 12.36339092], [92.92301941, 12.36367035], [92.92249298, 12.36392021], [92.92198181, 12.36417103], [92.9214859, 12.36438274], [92.92097473, 12.36443996], [92.92044067, 12.36444187], [92.91989136, 12.36446285], [92.91933441, 12.36461544], [92.91889954, 12.36502075], [92.91860962, 12.36556053], [92.91835785, 12.36614037], [92.91823578, 12.36672974], [92.91804504, 12.36726761], [92.91783905, 12.36776066], [92.91780853, 12.36828041], [92.91777802, 12.36876965], [92.91779327, 12.36923981], [92.9178772, 12.3696804], [92.91806793, 12.37010956], [92.91828918, 12.37057304], [92.91838074, 12.37111473], [92.91851044, 12.3716526], [92.91838837, 12.37224102], [92.91834259, 12.37285423], [92.91837311, 12.37346268], [92.91854858, 12.37401009], [92.91866302, 12.37452698], [92.91884613, 12.37495995], [92.91893768, 12.37543201], [92.91915894, 12.37586308], [92.91938019, 12.37632084], [92.91960144, 12.37683201], [92.91985321, 12.37731934], [92.92022705, 12.37774467], [92.92059326, 12.37819004], [92.92098236, 12.3786211], [92.9213562, 12.37903976], [92.92167664, 12.37945938], [92.92195129, 12.37983131], [92.92221832, 12.38011646], [92.92246246, 12.38038921], [92.92266846, 12.38072014], [92.92289734, 12.38105011], [92.9232254, 12.38129902], [92.92350769, 12.38156128], [92.92373657, 12.3817997], [92.92397308, 12.38205147], [92.92414093, 12.38236141], [92.92434692, 12.38266182], [92.92446136, 12.38299179], [92.92462158, 12.38325405], [92.92475128, 12.38354969], [92.92495728, 12.38387585], [92.92515564, 12.38430023], [92.92549133, 12.38474464], [92.92590332, 12.38521385], [92.92636108, 12.38564968], [92.9267807, 12.38606167], [92.92714691, 12.38634014], [92.92736816, 12.38661098], [92.92759705, 12.38677979], [92.92774963, 12.38700104], [92.92778015, 12.38731956], [92.92778015, 12.3876667], [92.927742, 12.38799191], [92.92758942, 12.38826084], [92.92743683, 12.38853741], [92.92723083, 12.38876057], [92.92701721, 12.38896084], [92.92684174, 12.38916874], [92.92665863, 12.38936234], [92.92642212, 12.38953972], [92.92617035, 12.38974953], [92.92584229, 12.38995934], [92.92534637, 12.39013004], [92.92485046, 12.39046955], [92.92450714, 12.39099026], [92.9245224, 12.39155006], [92.92471313, 12.39206123], [92.92488861, 12.39253044], [92.92498779, 12.393013], [92.92500305, 12.39350796], [92.92500305, 12.39399147], [92.92499542, 12.39446831], [92.92500305, 12.39493179], [92.92504883, 12.39540005], [92.92523193, 12.39585114], [92.92529297, 12.3964119], [92.92536926, 12.3970089], [92.92551422, 12.3976078], [92.92555237, 12.39821243], [92.92556763, 12.39879131], [92.92563629, 12.39931965], [92.92579651, 12.39978027], [92.92583466, 12.40025711], [92.92582703, 12.4007206], [92.92583466, 12.40117741], [92.92583466, 12.40163326], [92.92585754, 12.40209961], [92.92592621, 12.40258121], [92.92601013, 12.40308475], [92.92592621, 12.40362072], [92.92611694, 12.40415192], [92.92636871, 12.40467072], [92.92666626, 12.4051857], [92.92693329, 12.40568066], [92.9271698, 12.40617085], [92.92733765, 12.40664864], [92.92746735, 12.40711021], [92.9275589, 12.40759087], [92.92773438, 12.40801716], [92.92784119, 12.40849304], [92.92801666, 12.40897179], [92.92810059, 12.40952969], [92.92832947, 12.41002274], [92.92856598, 12.41055107], [92.92868805, 12.41116047], [92.92890167, 12.41172123], [92.92916107, 12.41224003], [92.92941284, 12.41275978], [92.92961121, 12.41328907], [92.92986298, 12.41374016], [92.93013, 12.41419792], [92.930336, 12.41468143], [92.93057251, 12.41518021], [92.93083191, 12.41567516], [92.93110657, 12.41617393], [92.93138123, 12.41664791], [92.93165588, 12.4171114], [92.9319458, 12.41755962], [92.93223572, 12.41803074], [92.93254089, 12.41852188], [92.93291473, 12.4189682], [92.9334259, 12.41926003], [92.93395996, 12.41951275], [92.93448639, 12.41973591], [92.93493652, 12.41999245], [92.93532562, 12.42022419], [92.93569946, 12.4204216], [92.9360733, 12.42066193], [92.93643188, 12.4210062], [92.93689728, 12.42135429], [92.93747711, 12.42160511], [92.93811798, 12.42171001], [92.9387207, 12.42189693], [92.93934631, 12.42194462], [92.93997955, 12.42194462], [92.94059753, 12.42189026], [92.94111633, 12.42168045], [92.94159698, 12.42142963], [92.94203186, 12.42112923], [92.94243622, 12.42083931], [92.94284058, 12.42056084], [92.9432373, 12.42031956], [92.94371033, 12.42017174], [92.94416809, 12.41998005], [92.94460297, 12.41972256], [92.9450531, 12.41943455], [92.94548035, 12.41910267], [92.94584656, 12.41871071], [92.94621277, 12.41834641], [92.94654083, 12.41798973], [92.9467392, 12.41759586], [92.94698334, 12.41729069], [92.94721222, 12.41701031], [92.94742584, 12.41670704], [92.9475708, 12.41631126], [92.94776154, 12.41596889], [92.94793701, 12.41561127], [92.9480896, 12.41515064], [92.94820404, 12.41465187], [92.94841766, 12.41436386], [92.94872284, 12.41438007], [92.9490509, 12.41463089], [92.94935608, 12.41497993], [92.94957733, 12.4154129], [92.94954681, 12.41587067], [92.94921875, 12.41630554], [92.94877625, 12.41683006], [92.94843292, 12.4174118], [92.948349, 12.41794682], [92.94834137, 12.41843891], [92.94832611, 12.41891098], [92.94832611, 12.41936016], [92.94832611, 12.41982079], [92.94833374, 12.42032433], [92.94837952, 12.42087078], [92.94856262, 12.42142963], [92.94856262, 12.42203999], [92.94843292, 12.42271137], [92.94857025, 12.42341042], [92.9486618, 12.42416], [92.94886017, 12.42483044], [92.94902039, 12.42545223], [92.94926453, 12.42593575], [92.94946289, 12.42634964], [92.94967651, 12.42673111], [92.94967651, 12.42714977], [92.94948578, 12.42757034], [92.94940186, 12.42807102], [92.94924164, 12.42857933], [92.94927216, 12.42912197], [92.94969177, 12.42959118], [92.95030212, 12.42978954], [92.95082092, 12.42996025], [92.95128632, 12.42999935], [92.95172119, 12.4300108], [92.95207977, 12.43006992], [92.95236969, 12.43025208], [92.95262146, 12.43040943], [92.95282745, 12.43059921], [92.95302582, 12.43085194], [92.95319366, 12.43126869], [92.95332336, 12.43182945], [92.95334625, 12.43248558], [92.95346832, 12.43312168], [92.95381927, 12.43362141], [92.95419312, 12.43406963], [92.95461273, 12.43451023], [92.95509338, 12.43502045], [92.95575714, 12.43545055], [92.95625305, 12.43548965], [92.95638275, 12.43525028], [92.95639038, 12.4349041], [92.95642853, 12.4345026], [92.95657349, 12.4340992], [92.95667267, 12.43365955], [92.95667267, 12.43319035], [92.95667267, 12.43271065], [92.95662689, 12.43224907], [92.95645905, 12.43182945], [92.95638275, 12.43138027], [92.95622253, 12.43094063], [92.95612335, 12.43045044], [92.95602417, 12.42993259], [92.95591736, 12.42942715], [92.95606995, 12.42895126], [92.95614624, 12.42849255], [92.95629883, 12.42812634], [92.95638275, 12.42776108], [92.95643616, 12.42740059], [92.95661926, 12.42708015], [92.95674896, 12.4267168], [92.95696259, 12.42634964], [92.95717621, 12.4259491], [92.95733643, 12.42544079], [92.95752716, 12.42490959], [92.95780945, 12.42443562], [92.95818329, 12.42404175], [92.95855713, 12.4236927], [92.95902252, 12.42346287], [92.95948029, 12.42321873], [92.9599762, 12.42303181], [92.96041107, 12.42277241], [92.96074677, 12.42243004], [92.96076202, 12.42175102], [92.96057129, 12.42121506], [92.96044159, 12.42076015], [92.96057129, 12.42031479], [92.96071625, 12.41983891], [92.96055603, 12.41932106], [92.96031952, 12.41876125], [92.96007538, 12.41819096], [92.95969391, 12.41774178], [92.95928955, 12.41734314], [92.95892334, 12.41697884], [92.95857239, 12.41664791], [92.95820618, 12.41639137], [92.95781708, 12.41618061], [92.95741272, 12.41607094], [92.9569931, 12.41591358], [92.95652771, 12.41576576], [92.95609283, 12.41551113], [92.95569611, 12.4151392], [92.95536041, 12.41469002]]], [[[92.89693451, 12.39207745], [92.89671326, 12.39196968], [92.89639282, 12.39204025], [92.8959198, 12.39233017], [92.89541626, 12.39279747], [92.89550781, 12.39331436], [92.89554596, 12.3938818], [92.89558411, 12.39443111], [92.89581299, 12.39492321], [92.89618683, 12.3951807], [92.89686584, 12.39516926], [92.89743042, 12.39484119], [92.897789, 12.39431858], [92.89774323, 12.39366055], [92.89753723, 12.39299107], [92.89731598, 12.39240932], [92.89693451, 12.39207745]]], [[[92.89916992, 12.40750027], [92.89861298, 12.40750027], [92.89861298, 12.40777111], [92.89749908, 12.40888977], [92.89749908, 12.41110992], [92.89805603, 12.4113903], [92.89916992, 12.4113903], [92.89916992, 12.40777111], [92.89916992, 12.40750027]]], [[[92.88935089, 12.41285133], [92.88913727, 12.41257095], [92.88899994, 12.41271019], [92.88878632, 12.41298771], [92.88844299, 12.41312027], [92.88829803, 12.41333199], [92.88829803, 12.41381073], [92.88858032, 12.41416168], [92.88899994, 12.41423035], [92.88935089, 12.41416168], [92.88948822, 12.41395187], [92.88948822, 12.41354179], [92.88935089, 12.41285133]]], [[[92.8317337, 12.42682171], [92.83277893, 12.42666721], [92.83361053, 12.42667198], [92.83389282, 12.42639065], [92.8347168, 12.42639065], [92.83499908, 12.42611122], [92.83528137, 12.42611122], [92.83555603, 12.42583275], [92.83640289, 12.42584038], [92.83666992, 12.4255619], [92.83721924, 12.4255619], [92.83777618, 12.42500114], [92.83805847, 12.42500114], [92.84055328, 12.42250061], [92.84111023, 12.42222118], [92.84139252, 12.42194462], [92.84194183, 12.42111111], [92.84222412, 12.42083263], [92.84249878, 12.42083263], [92.84278107, 12.42055416], [92.84278107, 12.42028141], [92.84333038, 12.41971111], [92.84361267, 12.41972256], [92.84416962, 12.41916561], [92.84443665, 12.41917133], [92.84583282, 12.41778088], [92.84583282, 12.41749954], [92.8466568, 12.4166708], [92.8466568, 12.41639137], [92.84694672, 12.41611004], [92.84694672, 12.41582966], [92.84638977, 12.41527843], [92.84638977, 12.41499996], [92.84610748, 12.41471958], [92.84583282, 12.41472244], [92.84555817, 12.41444397], [92.84471893, 12.41444397], [92.84444427, 12.41472244], [92.84416962, 12.41471958], [92.84388733, 12.41499996], [92.84361267, 12.41499996], [92.84333038, 12.4152813], [92.8408432, 12.4152813], [92.84055328, 12.41499996], [92.83889008, 12.41499996], [92.83860779, 12.4152813], [92.83833313, 12.4152813], [92.83805847, 12.41556072], [92.83750153, 12.41555595], [92.83721924, 12.41583443], [92.83666992, 12.41583443], [92.83640289, 12.41611004], [92.83611298, 12.41611004], [92.83528137, 12.41694355], [92.83499908, 12.41694355], [92.83472443, 12.41722202], [92.83444214, 12.41722012], [92.83416748, 12.41749954], [92.83389282, 12.41749954], [92.83333588, 12.41806126], [92.83110809, 12.42028141], [92.83083344, 12.42027855], [92.83000183, 12.42111111], [92.83000183, 12.42139053], [92.82971954, 12.4216671], [92.82971954, 12.42194462], [92.82943726, 12.42222118], [92.82944489, 12.4230547], [92.82917023, 12.42333031], [92.82917023, 12.42361069], [92.82944489, 12.42388916], [92.82943726, 12.4247179], [92.82971954, 12.42500114], [92.82971954, 12.4255619], [92.83055878, 12.42639065], [92.83093262, 12.4267168], [92.83141327, 12.42677879], [92.8317337, 12.42682171]]], [[[92.90323639, 12.42018986], [92.90288544, 12.42008018], [92.90248108, 12.4202404], [92.90200043, 12.42037201], [92.90151978, 12.42054081], [92.90100861, 12.42067146], [92.90048218, 12.42080975], [92.89995575, 12.42095566], [92.89962769, 12.42142963], [92.89946747, 12.42201996], [92.89948273, 12.42259026], [92.89959717, 12.42309093], [92.89969635, 12.42358971], [92.89975739, 12.42413044], [92.89990997, 12.42466068], [92.8999939, 12.42519474], [92.90008545, 12.42568493], [92.90042114, 12.42602158], [92.90091705, 12.42612934], [92.90164948, 12.42601109], [92.90223694, 12.42577076], [92.90270996, 12.42547131], [92.90309143, 12.42513561], [92.90348053, 12.42475033], [92.90392303, 12.4242897], [92.90442657, 12.4237318], [92.90485382, 12.42313004], [92.9048233, 12.42273998], [92.90468597, 12.42235661], [92.90444946, 12.42198086], [92.90422058, 12.42152977], [92.90402222, 12.4210062], [92.90364838, 12.42056084], [92.90348816, 12.42031956], [92.90323639, 12.42018986]]], [[[92.86587524, 12.42100334], [92.86589813, 12.42068672], [92.86751556, 12.42072296], [92.86754608, 12.42045021], [92.86808014, 12.42045021], [92.86891937, 12.41964054], [92.86895752, 12.41574574], [92.8691864, 12.41573048], [92.86921692, 12.41378117], [92.86839294, 12.41379929], [92.86810303, 12.41322041], [92.86750793, 12.41320038], [92.86750793, 12.41292191], [92.86727142, 12.41265965], [92.86584473, 12.41264057], [92.8658371, 12.41236115], [92.8653183, 12.4123497], [92.86532593, 12.41265011], [92.86226654, 12.4126482], [92.86226654, 12.41291332], [92.86171722, 12.41298294], [92.86167908, 12.41347313], [92.86060333, 12.41349125], [92.86058807, 12.41405201], [92.86009216, 12.41407013], [92.85890198, 12.41541958], [92.85890198, 12.41680813], [92.8595047, 12.41737461], [92.86006165, 12.4173727], [92.86000824, 12.41792202], [92.86061859, 12.41794014], [92.86061859, 12.41822147], [92.86115265, 12.41822147], [92.86113739, 12.4185009], [92.86172485, 12.4185009], [92.86171722, 12.41878128], [92.86252594, 12.41880035], [92.86367035, 12.42016029], [92.86421967, 12.42018795], [92.86420441, 12.42043114], [92.86476898, 12.42042923], [92.86474609, 12.42076015], [92.86532593, 12.42073917], [92.86532593, 12.42100334], [92.86587524, 12.42100334]]], [[[92.66895294, 12.95335007], [92.66895294, 12.95306969], [92.66945648, 12.9531002], [92.66979218, 12.95280075], [92.66983795, 12.95221806], [92.66916656, 12.95167065], [92.66868591, 12.95162964], [92.66870117, 12.95278072], [92.6681366, 12.95275974], [92.66812134, 12.95361042], [92.66868591, 12.95360088], [92.66895294, 12.95335007]]], [[[92.67150879, 12.94834137], [92.67008972, 12.94830036], [92.67006683, 12.94948006], [92.67230225, 12.94943047], [92.67260742, 12.94919968], [92.67263794, 12.94888115], [92.67177582, 12.94886971], [92.67177582, 12.9486208], [92.67150879, 12.94834137]]], [[[92.72499847, 12.7616663], [92.72444153, 12.7616663], [92.72444153, 12.76194191], [92.72277832, 12.76361179], [92.72277832, 12.76389027], [92.72110748, 12.7655611], [92.72110748, 12.76666641], [92.72083282, 12.76694393], [92.72083282, 12.76721954], [92.72000122, 12.76805687], [92.72000122, 12.76833153], [92.71888733, 12.7694397], [92.71888733, 12.77028084], [92.71778107, 12.77139091], [92.71805573, 12.77166653], [92.71806335, 12.77333069], [92.71888733, 12.77416706], [92.71888733, 12.77444458], [92.71861267, 12.77472115], [92.71888733, 12.77501011], [92.71888733, 12.77555466], [92.71916962, 12.77583122], [92.71916962, 12.77639103], [92.71971893, 12.77666664], [92.72000122, 12.7769413], [92.72000122, 12.77777672], [92.71944427, 12.77805519], [92.71527863, 12.77833271], [92.71527863, 12.77944469], [92.71555328, 12.77972126], [92.71555328, 12.78111076], [92.71721649, 12.78194141], [92.71778107, 12.78249931], [92.71778107, 12.78388977], [92.71749878, 12.78416634], [92.71749878, 12.78471947], [92.71721649, 12.78499985], [92.71749878, 12.78527832], [92.71749878, 12.78583241], [92.71721649, 12.78611183], [92.71721649, 12.7863903], [92.71666718, 12.78695107], [92.71721649, 12.78750038], [92.71721649, 12.78777981], [92.71833038, 12.78777981], [92.71833038, 12.78722191], [92.71888733, 12.78694439], [92.71943665, 12.7863903], [92.71943665, 12.78611183], [92.71971893, 12.78583241], [92.71971893, 12.78555584], [92.72000122, 12.78528023], [92.72000122, 12.78499985], [92.72027588, 12.78471947], [92.72027588, 12.78444576], [92.72055817, 12.78416634], [92.72055817, 12.78249931], [92.72083282, 12.78222084], [92.72083282, 12.78194141], [92.72110748, 12.78166771], [92.72110748, 12.78139019], [92.72138977, 12.78110886], [92.72138977, 12.77972126], [92.72194672, 12.77916527], [92.72194672, 12.77889156], [92.72222137, 12.77861118], [92.72222137, 12.77666664], [92.72249603, 12.77639103], [92.72249603, 12.7744379], [92.72277832, 12.77416706], [92.72277832, 12.77389145], [92.72305298, 12.77361107], [92.72305298, 12.77305889], [92.72277832, 12.77278137], [92.7233429, 12.77222061], [92.72333527, 12.771945], [92.72360992, 12.7716713], [92.72360992, 12.77139091], [92.7233429, 12.77111053], [92.72360992, 12.77083302], [92.72360992, 12.77027893], [92.72389221, 12.77000141], [92.72389221, 12.7694397], [92.72416687, 12.76916695], [92.72416687, 12.76861], [92.72444153, 12.76832962], [92.72444153, 12.76777935], [92.72416687, 12.76749992], [92.72444153, 12.76721954], [92.72444153, 12.76694393], [92.72472382, 12.76666641], [92.72471619, 12.76361179], [92.7250061, 12.76333046], [92.72499847, 12.7630558], [92.72528076, 12.76278019], [92.72528076, 12.76222038], [92.72499847, 12.76194382], [92.72499847, 12.7616663]]], [[[92.72763062, 12.83647156], [92.72763062, 12.83588791], [92.72786713, 12.8359108], [92.72788239, 12.83533001], [92.7273407, 12.83507919], [92.72730255, 12.83393955], [92.72677612, 12.83393955], [92.72673798, 12.83342171], [92.72566986, 12.83230114], [92.7253952, 12.83230305], [92.72506714, 12.83257198], [92.72503662, 12.83309174], [92.724823, 12.83307076], [92.72479248, 12.83393002], [92.72506714, 12.83393002], [92.72512054, 12.83449078], [92.72540283, 12.83455944], [92.72541809, 12.83563137], [92.72592926, 12.83562565], [92.72595215, 12.83702564], [92.72644043, 12.83751774], [92.72705841, 12.83813953], [92.72789001, 12.83813953], [92.72792053, 12.83647156], [92.72763062, 12.83647156]]], [[[92.69777679, 12.79068184], [92.69748688, 12.79107094], [92.69713593, 12.79146099], [92.6967926, 12.79182816], [92.69654083, 12.79223442], [92.6963501, 12.79264164], [92.69612122, 12.79296112], [92.69593048, 12.79325008], [92.69578552, 12.79350758], [92.69561005, 12.79370117], [92.69548798, 12.79394054], [92.6953125, 12.7942009], [92.69523621, 12.79459], [92.69506836, 12.79496193], [92.69499207, 12.79540157], [92.69487762, 12.79582977], [92.69474792, 12.79624653], [92.69469452, 12.79671383], [92.69454193, 12.79714298], [92.69451904, 12.79754162], [92.69468689, 12.79796124], [92.69476318, 12.79845142], [92.69495392, 12.7988863], [92.69504547, 12.79948139], [92.69532013, 12.80003071], [92.69567871, 12.8005209], [92.6960907, 12.800951], [92.69651031, 12.80133438], [92.6969986, 12.80157375], [92.69749451, 12.80163479], [92.69794464, 12.80148697], [92.69830322, 12.80126095], [92.69857788, 12.80104256], [92.69880676, 12.80084419], [92.6990509, 12.80068016], [92.69930267, 12.80051136], [92.69957733, 12.80031776], [92.69987488, 12.80023766], [92.70017242, 12.80043411], [92.70057678, 12.80060863], [92.70054626, 12.8008213], [92.70033264, 12.8010807], [92.70012665, 12.80139637], [92.69994354, 12.80170345], [92.69975281, 12.80196953], [92.699646, 12.8022604], [92.69947815, 12.80253124], [92.69941711, 12.80286121], [92.69930267, 12.80320454], [92.6991806, 12.80359268], [92.69909668, 12.80402088], [92.6989212, 12.80439091], [92.69882965, 12.80475807], [92.69871521, 12.80504227], [92.69888306, 12.80532265], [92.69908142, 12.80562973], [92.69921875, 12.80598068], [92.69944, 12.80621243], [92.69960785, 12.80640125], [92.69973755, 12.80661011], [92.69986725, 12.80683231], [92.69998169, 12.80711174], [92.69999695, 12.8074007], [92.70000458, 12.80775928], [92.7000351, 12.80822372], [92.70021057, 12.80873203], [92.70033264, 12.80930042], [92.70055389, 12.80980396], [92.70079803, 12.81023026], [92.70102692, 12.81058979], [92.70119476, 12.81089687], [92.70134735, 12.81114101], [92.70143127, 12.81147194], [92.70159912, 12.81178188], [92.70166016, 12.81215954], [92.70166779, 12.81257725], [92.70166779, 12.81301022], [92.70166779, 12.81344318], [92.70170593, 12.81383991], [92.70189667, 12.8141613], [92.70204163, 12.81453705], [92.70224762, 12.81493187], [92.7026062, 12.81527138], [92.70305634, 12.81555557], [92.70349121, 12.81578159], [92.70391846, 12.81583023], [92.7042923, 12.81583881], [92.70461273, 12.81589985], [92.70484924, 12.8161211], [92.7050705, 12.81639004], [92.70529938, 12.81668186], [92.70552826, 12.81697083], [92.70567322, 12.81734085], [92.70584869, 12.81770134], [92.70606995, 12.81805897], [92.70614624, 12.81856918], [92.70636749, 12.81906128], [92.70652008, 12.81957626], [92.70664978, 12.82008171], [92.70667267, 12.820611], [92.70666504, 12.82114887], [92.70667267, 12.82167053], [92.70667267, 12.82217026], [92.70667267, 12.82262135], [92.70666504, 12.82300854], [92.70666504, 12.82336044], [92.70671082, 12.82368088], [92.70687103, 12.82398033], [92.70693207, 12.82432175], [92.70694733, 12.82469082], [92.70697784, 12.82503986], [92.70713043, 12.82533073], [92.70720673, 12.82563019], [92.70722198, 12.8259716], [92.70722198, 12.82631111], [92.70722961, 12.82667065], [92.7073288, 12.82704067], [92.70746613, 12.82742977], [92.70749664, 12.82787037], [92.70749664, 12.8283596], [92.70751953, 12.82886791], [92.70770264, 12.82934856], [92.7080307, 12.82971191], [92.70847321, 12.82995987], [92.70868683, 12.82996464], [92.70900726, 12.82997417], [92.70946503, 12.82981873], [92.70987701, 12.82967091], [92.71016693, 12.82946301], [92.71043396, 12.82929707], [92.71070099, 12.82915974], [92.71096802, 12.82903004], [92.71121979, 12.8289299], [92.71152496, 12.82901859], [92.71192932, 12.82918262], [92.71238708, 12.82941532], [92.71292114, 12.82954121], [92.71302795, 12.82952499], [92.71342468, 12.82946587], [92.71391296, 12.82938957], [92.71421814, 12.82916927], [92.71448517, 12.82892799], [92.71472931, 12.82870197], [92.71494293, 12.82842159], [92.71504974, 12.82796097], [92.71524811, 12.82743931], [92.71526337, 12.82685757], [92.71515656, 12.82628155], [92.71498108, 12.82573891], [92.71476746, 12.82527924], [92.7146759, 12.82474995], [92.71447754, 12.8243103], [92.7143631, 12.82382011], [92.71420288, 12.82335281], [92.71413422, 12.82286453], [92.71398163, 12.82243919], [92.71385956, 12.82199001], [92.71364594, 12.82155037], [92.71355438, 12.82100964], [92.71335602, 12.82046127], [92.71326447, 12.8198204], [92.71308899, 12.81915665], [92.7130127, 12.81842136], [92.7128067, 12.81770134], [92.71277618, 12.81695461], [92.71277618, 12.8162384], [92.71277618, 12.81559944], [92.71279144, 12.81507111], [92.71289063, 12.81463146], [92.71302795, 12.81423187], [92.71305847, 12.81379032], [92.71305847, 12.81330204], [92.7130127, 12.81278706], [92.71286011, 12.81227016], [92.7130127, 12.81174088], [92.71296692, 12.81118011], [92.7128067, 12.81058121], [92.71277618, 12.80992031], [92.71277618, 12.80921078], [92.71277618, 12.80850029], [92.71277618, 12.80777073], [92.71277618, 12.80704117], [92.71274567, 12.8063097], [92.71257019, 12.80560303], [92.71250916, 12.80489445], [92.71253967, 12.8042078], [92.71273041, 12.80358791], [92.71277618, 12.80299282], [92.71277618, 12.8024416], [92.71277618, 12.80194283], [92.71277618, 12.80148029], [92.71277618, 12.8010397], [92.71277618, 12.79644108], [92.71277618, 12.79587078], [92.71277618, 12.79536057], [92.71277618, 12.79484081], [92.71283722, 12.79428291], [92.71302795, 12.79367161], [92.71315002, 12.79297161], [92.71330261, 12.79227543], [92.71337891, 12.79160881], [92.71356964, 12.79109192], [92.71362305, 12.79061127], [92.71369171, 12.79022789], [92.71385193, 12.78991985], [92.71389008, 12.78955078], [92.71389008, 12.78911972], [92.71389008, 12.78866005], [92.71389008, 12.78816128], [92.71387482, 12.78765488], [92.71383667, 12.78714657], [92.71386719, 12.78664112], [92.71380615, 12.78619862], [92.71364594, 12.78581142], [92.71360779, 12.78542995], [92.71360779, 12.78507042], [92.71360779, 12.78474236], [92.71356201, 12.78443718], [92.71337891, 12.78418064], [92.71333313, 12.78386021], [92.7133255, 12.78351402], [92.71325684, 12.78314686], [92.71309662, 12.78276157], [92.71305847, 12.78229046], [92.71303558, 12.78177929], [92.71292877, 12.78127956], [92.7128067, 12.7807703], [92.71277618, 12.78024483], [92.71273804, 12.7797327], [92.71253967, 12.77928352], [92.71245575, 12.77876186], [92.71225739, 12.77823734], [92.71222687, 12.77764034], [92.7122879, 12.77705479], [92.71247101, 12.77654171], [92.71256256, 12.77608776], [92.7127533, 12.77578068], [92.71279144, 12.77545929], [92.71289063, 12.77517033], [92.71302795, 12.77485275], [92.71309662, 12.77441311], [92.71328735, 12.77398014], [92.71338654, 12.77348137], [92.71361542, 12.7730751], [92.71389771, 12.77273083], [92.71421814, 12.77245522], [92.7145462, 12.77219486], [92.71481323, 12.77186966], [92.71508789, 12.77155972], [92.71531677, 12.77118969], [92.71559143, 12.77086735], [92.71588135, 12.7705698], [92.71617889, 12.77028084], [92.71646881, 12.76999187], [92.71672058, 12.76966095], [92.71695709, 12.76931], [92.71721649, 12.76898193], [92.717453, 12.76866531], [92.71769714, 12.76839638], [92.71785736, 12.76809978], [92.71807861, 12.76786137], [92.71831512, 12.76767445], [92.71852112, 12.76743031], [92.71865845, 12.76708317], [92.7188797, 12.7667551], [92.71910095, 12.76638126], [92.71930695, 12.76595974], [92.71951294, 12.76548958], [92.71975708, 12.76506901], [92.72003937, 12.76467037], [92.72029114, 12.76425266], [92.72055817, 12.76385212], [92.72080994, 12.76346397], [92.72100067, 12.7630682], [92.72119141, 12.76270962], [92.72141266, 12.76237011], [92.72164154, 12.76204681], [92.72181702, 12.76165009], [92.72198486, 12.76124001], [92.72219086, 12.76084995], [92.72229004, 12.760396], [92.72247314, 12.75996971], [92.72259521, 12.75949764], [92.72277069, 12.75906086], [92.72293091, 12.75858021], [92.7230835, 12.75807858], [92.7233429, 12.75764084], [92.72358704, 12.75723457], [92.72374725, 12.75680923], [92.72389984, 12.75641918], [92.72406769, 12.75607967], [92.72419739, 12.75575161], [92.72437286, 12.75545979], [92.7250061, 12.75440884], [92.72486115, 12.75393009], [92.72475433, 12.75337696], [92.724823, 12.75300121], [92.72489929, 12.7526722], [92.72475433, 12.75205231], [92.72475433, 12.75149632], [92.7246933, 12.75113201], [92.7246933, 12.75067139], [92.72471619, 12.75000095], [92.7250061, 12.74972057], [92.72528839, 12.74924946], [92.72550201, 12.74870014], [92.72554016, 12.74807072], [92.72544861, 12.74740982], [92.72525787, 12.74680805], [92.7250061, 12.74628162], [92.72473145, 12.74580097], [92.72453308, 12.74534035], [92.72445679, 12.74487114], [92.72444153, 12.74440098], [92.72441101, 12.74398041], [92.72424316, 12.74364853], [92.72413635, 12.7432909], [92.72396851, 12.74300194], [92.72380829, 12.74271297], [92.72361755, 12.74253273], [92.7233429, 12.74253464], [92.72303772, 12.74276257], [92.72270966, 12.74309063], [92.72246552, 12.74354362], [92.72221375, 12.74398899], [92.7219696, 12.74440098], [92.72180939, 12.74484825], [92.72167206, 12.74526978], [92.72154236, 12.74567127], [92.72141266, 12.74604034], [92.72138977, 12.74647141], [92.72138977, 12.74691105], [92.72138977, 12.74736023], [92.72135925, 12.74778843], [92.72118378, 12.74816227], [92.72107697, 12.74854469], [92.72088623, 12.74887085], [92.72083282, 12.7492218], [92.72083282, 12.74959087], [92.72080231, 12.74993992], [92.72064209, 12.75023079], [92.72052765, 12.75057793], [92.72034454, 12.75091076], [92.72019196, 12.75124073], [92.72003937, 12.75128365], [92.719841, 12.75134087], [92.71955872, 12.7511797], [92.71936035, 12.75100613], [92.71914673, 12.75069046], [92.71894836, 12.7503109], [92.71888733, 12.74984169], [92.71888733, 12.74934864], [92.71888733, 12.74885941], [92.71888733, 12.74836922], [92.71888733, 12.74789333], [92.71888733, 12.74742794], [92.71888733, 12.74697018], [92.71888733, 12.74652576], [92.71888733, 12.74606991], [92.71888733, 12.74559975], [92.71882629, 12.74513531], [92.71865082, 12.74470043], [92.71856689, 12.74420071], [92.71834564, 12.74380398], [92.71816254, 12.74343109], [92.71806335, 12.74309063], [92.71807098, 12.74279022], [92.71817017, 12.74253941], [92.7183075, 12.74227047], [92.71833801, 12.74195385], [92.71841431, 12.7416048], [92.71857452, 12.74124336], [92.71861267, 12.74077988], [92.71861267, 12.74030113], [92.71859741, 12.73984146], [92.71846771, 12.73944378], [92.71835327, 12.73905945], [92.71833038, 12.73863125], [92.71833038, 12.73818398], [92.71833038, 12.73772812], [92.71833038, 12.73727226], [92.71833038, 12.73682594], [92.71833038, 12.73639011], [92.71833801, 12.73597336], [92.71831512, 12.73556519], [92.71821594, 12.7351799], [92.71808624, 12.73482037], [92.71806335, 12.73437119], [92.71805573, 12.73391342], [92.71812439, 12.73344612], [92.71835327, 12.7330513], [92.71859741, 12.7326889], [92.71877289, 12.73233128], [92.71887207, 12.73200989], [92.71888733, 12.73171139], [92.71888733, 12.73143101], [92.71884918, 12.73113918], [92.71871185, 12.73087025], [92.71872711, 12.73062897], [92.71879578, 12.73042107], [92.71891785, 12.73019123], [92.71914673, 12.729949], [92.71940613, 12.72964191], [92.71959686, 12.72926998], [92.71968842, 12.72887135], [92.71958923, 12.72848606], [92.71945953, 12.72811031], [92.71944427, 12.72774601], [92.71943665, 12.72735119], [92.71943665, 12.7269001], [92.71943665, 12.72636032], [92.71949005, 12.72580147], [92.71968079, 12.72523785], [92.71971893, 12.72466183], [92.71972656, 12.72412205], [92.71972656, 12.72362041], [92.71972656, 12.72314167], [92.71970367, 12.72267914], [92.71959686, 12.72225094], [92.71942139, 12.7218399], [92.71922302, 12.72141171], [92.71914673, 12.72083473], [92.71900177, 12.72020245], [92.71872711, 12.71959114], [92.71826172, 12.71910954], [92.71803284, 12.71889973], [92.71772766, 12.71889114], [92.71734619, 12.71892834], [92.71694946, 12.71912956], [92.71653748, 12.71935558], [92.71627808, 12.7198143], [92.71598053, 12.72021961], [92.71560669, 12.72047138], [92.71546173, 12.72044754], [92.71516418, 12.72039986], [92.71463776, 12.72012901], [92.71405029, 12.71989155], [92.71354675, 12.71953201], [92.71308899, 12.71948147], [92.712677, 12.71967983], [92.71227264, 12.71976185], [92.71193695, 12.7199707], [92.71156311, 12.72000122], [92.71115112, 12.72001743], [92.71073914, 12.72010136], [92.71034241, 12.72026062], [92.70992279, 12.72028065], [92.7095108, 12.72026062], [92.7091217, 12.72010136], [92.70876312, 12.71995068], [92.70845032, 12.71975327], [92.70818329, 12.71963024], [92.70796967, 12.71979141], [92.7078476, 12.72040939], [92.70796967, 12.72093964], [92.70833588, 12.72121811], [92.70874786, 12.72148037], [92.70907593, 12.72186089], [92.70941162, 12.72218704], [92.70968628, 12.7225132], [92.7098465, 12.72292137], [92.71002197, 12.7233696], [92.71025848, 12.72377968], [92.71044922, 12.72418308], [92.71054077, 12.72456169], [92.71055603, 12.72491932], [92.71055603, 12.72523785], [92.71051025, 12.72556019], [92.71031952, 12.7259016], [92.71025848, 12.72630692], [92.71025085, 12.72671986], [92.71083069, 12.72720146], [92.7111969, 12.72760582], [92.71134949, 12.72795963], [92.71134186, 12.72828102], [92.7111969, 12.72849083], [92.71096802, 12.72859097], [92.71070862, 12.72859573], [92.71047974, 12.72847462], [92.71026611, 12.72810841], [92.71000671, 12.72750187], [92.70974731, 12.72725105], [92.70952606, 12.72729015], [92.70925903, 12.72757721], [92.70902252, 12.72810268], [92.70910645, 12.72888088], [92.70907593, 12.72957993], [92.70883179, 12.73007679], [92.70865631, 12.73049164], [92.70867157, 12.73085022], [92.7088623, 12.73118019], [92.70888519, 12.73139], [92.70944214, 12.73194408], [92.70944214, 12.7322216], [92.71028137, 12.73305607], [92.71028137, 12.73333359], [92.71055603, 12.73361206], [92.71055603, 12.7344389], [92.71111298, 12.73499966], [92.71111298, 12.73527813], [92.71138763, 12.7355814], [92.71160126, 12.7358799], [92.71179199, 12.73623085], [92.71201324, 12.73659992], [92.71225739, 12.73691177], [92.71248627, 12.73723602], [92.71264648, 12.73765278], [92.71276093, 12.73816967], [92.71277618, 12.73876953], [92.71277618, 12.7393961], [92.71277618, 12.74002075], [92.71277618, 12.74061108], [92.71276855, 12.74113083], [92.71269989, 12.74158192], [92.71253204, 12.74193954], [92.71246338, 12.74237537], [92.7122879, 12.74273109], [92.71221161, 12.74312115], [92.71208954, 12.7434597], [92.71195984, 12.74382019], [92.71189117, 12.7442646], [92.71170807, 12.7446909], [92.71164703, 12.74518108], [92.71157837, 12.74562073], [92.71141815, 12.74596024], [92.71138763, 12.74629784], [92.71138, 12.74662971], [92.71131897, 12.74698639], [92.71116638, 12.74733925], [92.71124268, 12.74775887], [92.71136475, 12.74815655], [92.71135712, 12.74851131], [92.71128082, 12.74882984], [92.71127319, 12.74916935], [92.7113266, 12.74963188], [92.7111969, 12.75020027], [92.71112061, 12.75088978], [92.71115112, 12.7516098], [92.71138763, 12.75226021], [92.71161652, 12.75284958], [92.71166992, 12.75342941], [92.71166992, 12.75393963], [92.71161652, 12.75439072], [92.71142578, 12.75473976], [92.71138763, 12.75514984], [92.71138763, 12.75561047], [92.71134949, 12.75615025], [92.71115112, 12.75677013], [92.71111298, 12.75748062], [92.71111298, 12.75820637], [92.71111298, 12.75889015], [92.71111298, 12.75953007], [92.7110672, 12.76014137], [92.71087646, 12.76077461], [92.71080017, 12.76145554], [92.71061707, 12.76208115], [92.71051788, 12.76272583], [92.71031952, 12.76329136], [92.71025085, 12.76384926], [92.71012115, 12.76432991], [92.70998383, 12.76479053], [92.70980835, 12.76520061], [92.70968628, 12.76564121], [92.70949554, 12.76601696], [92.70941162, 12.76646996], [92.70923615, 12.76690102], [92.70916748, 12.76739788], [92.70910645, 12.76791096], [92.70892334, 12.76839638], [92.70889282, 12.76891136], [92.70888519, 12.76945782], [92.70894623, 12.77002335], [92.70916748, 12.7705431], [92.70939636, 12.77105999], [92.70948792, 12.77166653], [92.7096405, 12.77220154], [92.70948792, 12.77271461], [92.70944977, 12.77315044], [92.70944214, 12.77352047], [92.70943451, 12.77381611], [92.7093811, 12.77407074], [92.70922852, 12.77428055], [92.70918274, 12.77459145], [92.70915222, 12.77493954], [92.70905304, 12.77527046], [92.70891571, 12.77558899], [92.70886993, 12.77593994], [92.70876312, 12.77625179], [92.70860291, 12.77655983], [92.70837402, 12.77690411], [92.70806885, 12.77731037], [92.70775604, 12.77779961], [92.7074585, 12.7783308], [92.70719147, 12.77884102], [92.7069397, 12.77926826], [92.70670319, 12.77961445], [92.7065506, 12.77996063], [92.70635223, 12.78026104], [92.70610046, 12.78055954], [92.70580292, 12.78088093], [92.70543671, 12.78122997], [92.70503998, 12.78160095], [92.7045517, 12.78186131], [92.70414734, 12.78217983], [92.70379639, 12.78248978], [92.70348358, 12.78277969], [92.70322418, 12.78306484], [92.70302582, 12.7833519], [92.70278931, 12.78359985], [92.70250702, 12.78378677], [92.7022171, 12.78404045], [92.70194244, 12.78434563], [92.7016449, 12.78466511], [92.7013092, 12.78495026], [92.70092773, 12.78520012], [92.70059967, 12.78550816], [92.70024109, 12.78584099], [92.69987488, 12.78622818], [92.69948578, 12.78664112], [92.69921112, 12.78716946], [92.69911194, 12.78778267], [92.69892883, 12.78827], [92.6988678, 12.78870106], [92.69876099, 12.789011], [92.69863129, 12.78927994], [92.69859314, 12.78959179], [92.6984787, 12.78986073], [92.69831085, 12.7901001], [92.69806671, 12.79035091], [92.69777679, 12.79068184]]], [[[92.71618652, 12.79729271], [92.71620941, 12.79673481], [92.71651459, 12.79673481], [92.71651459, 12.79589558], [92.71620941, 12.7959013], [92.71617126, 12.79536057], [92.71589661, 12.79506016], [92.71511078, 12.79504776], [92.71508789, 12.79620171], [92.71533966, 12.79615593], [92.7154007, 12.79695415], [92.7156601, 12.79731369], [92.71618652, 12.79729271]]], [[[92.71676636, 12.80059147], [92.71676636, 12.80007172], [92.71704102, 12.80007172], [92.71704102, 12.7986927], [92.71673584, 12.79839039], [92.71620941, 12.7983923], [92.71620941, 12.7989502], [92.71562195, 12.7992506], [92.71563721, 12.80059147], [92.71570587, 12.8006506], [92.71598053, 12.80088997], [92.71650696, 12.80088997], [92.71676636, 12.80059147]]], [[[92.71760559, 12.80310345], [92.71704102, 12.80255985], [92.71596527, 12.80258465], [92.71590424, 12.80312347], [92.71618652, 12.80310345], [92.71620941, 12.80394173], [92.7164917, 12.80428123], [92.7173233, 12.80424213], [92.71759033, 12.80396175], [92.71760559, 12.80310345]]], [[[92.72861481, 12.86444569], [92.72861481, 12.86277676], [92.72888947, 12.86277676], [92.72888947, 12.8633337], [92.72944641, 12.8633337], [92.72972107, 12.86305618], [92.72972107, 12.86277962], [92.73000336, 12.86249924], [92.73000336, 12.86111069], [92.72915649, 12.86028194], [92.72860718, 12.86000061], [92.72860718, 12.85889244], [92.72721863, 12.85750103], [92.72721863, 12.85666943], [92.72638702, 12.85639095], [92.72638702, 12.85555935], [92.72583008, 12.85500145], [92.72528076, 12.85472107], [92.72528076, 12.85416698], [92.7250061, 12.85389137], [92.7250061, 12.85332966], [92.72472382, 12.85305691], [92.72556305, 12.85222054], [92.72555542, 12.85111141], [92.72499847, 12.85055447], [92.72444153, 12.8502903], [92.72471619, 12.85000134], [92.72416687, 12.84943962], [92.72416687, 12.84833241], [92.72389221, 12.84805679], [92.72389221, 12.84778118], [92.72360992, 12.84749985], [92.72360992, 12.84723091], [92.7233429, 12.84694195], [92.72333527, 12.84666634], [92.72277832, 12.84611034], [92.72277832, 12.84583378], [92.72250366, 12.84555626], [92.72249603, 12.84528065], [92.72194672, 12.84472179], [92.72194672, 12.84306145], [92.7216568, 12.84278011], [92.72110748, 12.84249973], [92.72110748, 12.84167004], [92.72055817, 12.84110069], [92.72055817, 12.83972168], [92.72000122, 12.83944416], [92.72000122, 12.83805561], [92.71971893, 12.83778], [92.71971893, 12.83749962], [92.71943665, 12.83721924], [92.71944427, 12.83694267], [92.71916962, 12.83666801], [92.71916962, 12.83638954], [92.71888733, 12.83611202], [92.71888733, 12.83583069], [92.71861267, 12.83555508], [92.71861267, 12.83529091], [92.71806335, 12.83472061], [92.71749878, 12.83444309], [92.71749878, 12.83361053], [92.71583557, 12.83277702], [92.7158432, 12.83250141], [92.71499634, 12.83250141], [92.71499634, 12.83305454], [92.7130661, 12.83333111], [92.71305847, 12.83416653], [92.71277618, 12.83444309], [92.71111298, 12.83444309], [92.71111298, 12.83361053], [92.70999908, 12.83361053], [92.70999908, 12.83444309], [92.7097168, 12.83472061], [92.70889282, 12.83500195], [92.70889282, 12.83529091], [92.70804596, 12.83611202], [92.70861053, 12.83666801], [92.70777893, 12.83694267], [92.70805359, 12.8372221], [92.70804596, 12.83832932], [92.70861053, 12.8386116], [92.70916748, 12.83916569], [92.70916748, 12.83944416], [92.70944214, 12.83972168], [92.70944214, 12.84000015], [92.7097168, 12.84027958], [92.70972443, 12.84055614], [92.70999908, 12.84083366], [92.71000671, 12.84110069], [92.71028137, 12.84138966], [92.71028137, 12.84166622], [92.71055603, 12.84194374], [92.71055603, 12.84222031], [92.71083069, 12.84249973], [92.71083069, 12.84278011], [92.71111298, 12.84305573], [92.71111298, 12.84333038], [92.71138763, 12.84361172], [92.71138763, 12.84389019], [92.71277618, 12.84389019], [92.7130661, 12.84361172], [92.7130661, 12.84333038], [92.71333313, 12.84333038], [92.71333313, 12.8441658], [92.71305847, 12.84444427], [92.7130661, 12.84500027], [92.71277618, 12.84528065], [92.7130661, 12.84556103], [92.71305847, 12.84666634], [92.71333313, 12.84694386], [92.71333313, 12.84832954], [92.7141571, 12.84917068], [92.71416473, 12.85027885], [92.71472168, 12.85083294], [92.71472168, 12.85222054], [92.71527863, 12.85250092], [92.71555328, 12.85277653], [92.71555328, 12.85332966], [92.71611023, 12.85361099], [92.71666718, 12.85416889], [92.71666718, 12.85555458], [92.71722412, 12.85583305], [92.71749878, 12.85611057], [92.71749878, 12.85750103], [92.71806335, 12.85750103], [92.71833038, 12.85722065], [92.71833038, 12.85694504], [92.71861267, 12.85694122], [92.71861267, 12.85750103], [92.71833038, 12.85778236], [92.71778107, 12.85805511], [92.71778107, 12.85861111], [92.71749878, 12.85889244], [92.71806335, 12.85917187], [92.71888733, 12.85917187], [92.71943665, 12.85889244], [92.71943665, 12.85861111], [92.72000122, 12.85861111], [92.72000122, 12.85944462], [92.72083282, 12.85972118], [92.72138977, 12.8599987], [92.72055817, 12.86083126], [92.72000122, 12.86111069], [92.72027588, 12.86139202], [92.72027588, 12.8622303], [92.71971893, 12.86249924], [92.72000122, 12.86277676], [92.72000122, 12.8633337], [92.72027588, 12.86361217], [92.72027588, 12.86444569], [92.72277832, 12.86444569], [92.72305298, 12.86416531], [92.72360992, 12.86388969], [92.72360992, 12.86360931], [92.72444153, 12.86360931], [92.72444153, 12.86388969], [92.72583008, 12.86527824], [92.72750092, 12.86527824], [92.72721863, 12.86499977], [92.72833252, 12.86471939], [92.72861481, 12.86444569]]], [[[92.73178101, 12.85643005], [92.73178101, 12.85586929], [92.73147583, 12.85588074], [92.73147583, 12.85531998], [92.73092651, 12.85531998], [92.73066711, 12.8550396], [92.73066711, 12.85475922], [92.72956085, 12.85475922], [92.72956085, 12.85490513], [92.72956848, 12.85534096], [92.72924042, 12.85531616], [92.72927856, 12.85586929], [92.72984314, 12.85643005], [92.73178101, 12.85643005]]], [[[92.76547241, 12.85472107], [92.76506042, 12.85464096], [92.76452637, 12.85480976], [92.76403046, 12.85505104], [92.7636795, 12.85534954], [92.76345062, 12.85571384], [92.76333618, 12.85624123], [92.76327515, 12.85682678], [92.76317596, 12.85737991], [92.76307678, 12.85792065], [92.76296997, 12.85845757], [92.76271057, 12.85901546], [92.76235199, 12.85954094], [92.76241302, 12.85982132], [92.76254272, 12.86016083], [92.76275635, 12.86055088], [92.76293945, 12.86101055], [92.76303864, 12.86153126], [92.76305389, 12.86206627], [92.76303864, 12.86260891], [92.76294708, 12.86316013], [92.76280975, 12.86372089], [92.76274872, 12.86431122], [92.76261902, 12.86487198], [92.76241302, 12.86536026], [92.76220703, 12.86580181], [92.76194, 12.86620522], [92.76167297, 12.86664963], [92.76139069, 12.86718082], [92.76119995, 12.86773014], [92.76135254, 12.86828804], [92.7614975, 12.8688097], [92.76171112, 12.86919975], [92.76194763, 12.8694849], [92.76219177, 12.86972427], [92.7624588, 12.86992931], [92.76283264, 12.87007141], [92.76317596, 12.87026024], [92.76357269, 12.87038517], [92.76391602, 12.87057018], [92.76419067, 12.870821], [92.76444244, 12.87106895], [92.76464844, 12.87133121], [92.76481628, 12.87164974], [92.7650528, 12.8719902], [92.76532745, 12.87235737], [92.76576233, 12.87261391], [92.76634979, 12.87247658], [92.76677704, 12.87210083], [92.76687622, 12.87164974], [92.766716, 12.87120819], [92.76664734, 12.87074089], [92.76654816, 12.87032127], [92.76637268, 12.86992931], [92.76615143, 12.86959743], [92.76595306, 12.86919117], [92.76573181, 12.86878109], [92.76558685, 12.86830044], [92.76555634, 12.86781025], [92.76555634, 12.8673811], [92.76555634, 12.86700344], [92.76555634, 12.86663818], [92.76555634, 12.86496067], [92.76555634, 12.86457062], [92.76555634, 12.8642292], [92.76555634, 12.8639307], [92.76558685, 12.86365032], [92.76573944, 12.86340046], [92.76584625, 12.86309719], [92.76602173, 12.86276245], [92.76624298, 12.86236], [92.76646423, 12.86192989], [92.76667786, 12.86145115], [92.76689911, 12.86100006], [92.76692963, 12.86048889], [92.76692963, 12.859972], [92.76692963, 12.85946083], [92.76699066, 12.85892963], [92.76716614, 12.8584404], [92.76718903, 12.85794067], [92.76705933, 12.85746002], [92.76696777, 12.85696983], [92.766922, 12.85645962], [92.76676178, 12.85595798], [92.76635742, 12.8554678], [92.76574707, 12.85497093], [92.76547241, 12.85472107]]], [[[92.77856445, 12.86475754], [92.77842712, 12.86466026], [92.77809906, 12.86465454], [92.77793884, 12.86467361], [92.77774048, 12.86469555], [92.77739716, 12.86466026], [92.77719879, 12.86474037], [92.7768631, 12.86481953], [92.77628326, 12.86497021], [92.77606201, 12.86514091], [92.77606201, 12.86536026], [92.77597809, 12.86564732], [92.77593994, 12.86583233], [92.77593994, 12.86604118], [92.77631378, 12.8662672], [92.77658844, 12.86639214], [92.77687836, 12.86643124], [92.77706909, 12.86651993], [92.77725983, 12.86663818], [92.77748871, 12.86670208], [92.77761841, 12.86667919], [92.77774048, 12.86666107], [92.77802277, 12.86645126], [92.77822113, 12.86616421], [92.77851868, 12.86591625], [92.77863312, 12.8655014], [92.77870941, 12.86523438], [92.77864838, 12.86498642], [92.77856445, 12.86475754]]], [[[92.71916962, 13.09889126], [92.72027588, 13.09777927], [92.72055817, 13.09749889], [92.72110748, 13.09639072], [92.72112274, 13.0961113], [92.72111511, 13.09555531], [92.72083282, 13.09514046], [92.719841, 13.09420967], [92.71969604, 13.09379101], [92.7191391, 13.09317493], [92.7182312, 13.09296989], [92.71704102, 13.09263134], [92.71598816, 13.09242058], [92.71514893, 13.09193993], [92.71444702, 13.09139061], [92.71360779, 13.09124947], [92.71347046, 13.09111023], [92.71305847, 13.09097385], [92.71193695, 13.09000015], [92.71166992, 13.09000015], [92.71138763, 13.08971977], [92.71111298, 13.08972168], [92.70999908, 13.0886097], [92.70999908, 13.08833218], [92.70944214, 13.08777809], [92.70916748, 13.08778095], [92.70804596, 13.08667088], [92.70804596, 13.08638954], [92.70777893, 13.08638954], [92.70749664, 13.08611012], [92.70749664, 13.0855608], [92.70722198, 13.08528042], [92.70722198, 13.08501053], [92.70694733, 13.08471966], [92.70694733, 13.08416557], [92.70527649, 13.08222198], [92.70513916, 13.08152866], [92.70527649, 13.08139038], [92.70527649, 13.08111191], [92.70417023, 13.07958889], [92.70388031, 13.07806015], [92.70417023, 13.07777977], [92.70417023, 13.07694054], [92.70444489, 13.07666779], [92.70443726, 13.07638931], [92.70500183, 13.07582188], [92.70500183, 13.07555485], [92.70527649, 13.07528019], [92.70542145, 13.07472134], [92.70583344, 13.07416725], [92.70597076, 13.07389164], [92.70610809, 13.07361126], [92.70625305, 13.07374954], [92.70652771, 13.07319164], [92.70667267, 13.07236195], [92.70666504, 13.0722208], [92.70666504, 13.0713892], [92.70667267, 13.07111073], [92.70652771, 13.0708313], [92.70611572, 13.07013988], [92.70513916, 13.06987095], [92.70443726, 13.06972122], [92.70417023, 13.07001019], [92.70361328, 13.07001019], [92.70333099, 13.07028103], [92.70249939, 13.07028103], [92.7022171, 13.07055855], [92.70194244, 13.07055473], [92.70166779, 13.07083321], [92.70111084, 13.0708313], [92.70027924, 13.07167244], [92.70027924, 13.07250118], [92.69999695, 13.07277679], [92.69999695, 13.07361126], [92.69972229, 13.07388878], [92.69972229, 13.07472134], [92.69944763, 13.07500076], [92.69944763, 13.07528019], [92.69916534, 13.07555485], [92.69917297, 13.07582188], [92.69889069, 13.07611084], [92.69889069, 13.07749939], [92.6986084, 13.07777977], [92.6986084, 13.07805538], [92.69889069, 13.07833385], [92.69889069, 13.07861233], [92.69916534, 13.07888985], [92.69916534, 13.07944584], [92.69889069, 13.0797224], [92.69889069, 13.0802784], [92.69832611, 13.08083057], [92.69832611, 13.08139038], [92.69805908, 13.0816679], [92.69806671, 13.08250046], [92.69777679, 13.08278179], [92.69777679, 13.08305645], [92.69750214, 13.0833292], [92.69750214, 13.08388996], [92.69721985, 13.08417034], [92.69721985, 13.08501053], [92.69694519, 13.08527756], [92.69695282, 13.08611012], [92.6966629, 13.08638954], [92.6966629, 13.08777809], [92.69638824, 13.0880518], [92.69638824, 13.08889103], [92.69611359, 13.08916569], [92.69611359, 13.08944416], [92.6958313, 13.08971977], [92.6958313, 13.09028053], [92.69555664, 13.09055424], [92.69555664, 13.09083462], [92.6958313, 13.09111023], [92.6958313, 13.09194469], [92.69610596, 13.09222031], [92.6958313, 13.09250069], [92.6958313, 13.0936079], [92.69610596, 13.09389114], [92.6958313, 13.09416676], [92.6958313, 13.09444046], [92.69610596, 13.09472275], [92.69610596, 13.09500122], [92.6966629, 13.09556198], [92.69695282, 13.09597015], [92.69916534, 13.09777737], [92.69944, 13.09805012], [92.69999695, 13.0980587], [92.70139313, 13.0980587], [92.70166779, 13.09805012], [92.70194244, 13.09777737], [92.7022171, 13.09776974], [92.70249939, 13.09722328], [92.70291901, 13.0969429], [92.70305634, 13.0966692], [92.70417023, 13.09556198], [92.70443726, 13.09556198], [92.70500183, 13.09500122], [92.70582581, 13.09500122], [92.70610809, 13.09472275], [92.70819092, 13.09500122], [92.70861053, 13.09500122], [92.70944214, 13.09514046], [92.7097168, 13.09528065], [92.71013641, 13.09528065], [92.71111298, 13.09528065], [92.71166992, 13.09556198], [92.71221924, 13.09555531], [92.71250153, 13.09582996], [92.71333313, 13.09610939], [92.71360779, 13.0961113], [92.71389008, 13.09652138], [92.71472168, 13.09694958], [92.71499634, 13.09694958], [92.71555328, 13.09749889], [92.71583557, 13.09749889], [92.71666718, 13.09833336], [92.71721649, 13.09833145], [92.71749878, 13.09861088], [92.71806335, 13.09861088], [92.71833038, 13.09889126], [92.71916962, 13.09889126]]], [[[93.06138611, 13.22138786], [93.06096649, 13.22069073], [93.05990601, 13.22097111], [93.05970001, 13.22104168], [93.05934906, 13.22166157], [93.05906677, 13.22192955], [93.05877686, 13.22247982], [93.05877686, 13.22358131], [93.05836487, 13.22412968], [93.05808258, 13.22453976], [93.05806732, 13.2248106], [93.05764771, 13.22549725], [93.05757904, 13.22611523], [93.05792999, 13.22666359], [93.0586319, 13.22666359], [93.05925751, 13.22659588], [93.05947113, 13.22618103], [93.05999756, 13.22555447], [93.05999756, 13.22528076], [93.06027985, 13.22500038], [93.06027985, 13.22472], [93.0605545, 13.22444439], [93.0605545, 13.22305584], [93.06083679, 13.22278118], [93.06083679, 13.22249985], [93.06138611, 13.22194195], [93.06138611, 13.22138786]]], [[[92.79499817, 13.17111015], [92.79528046, 13.17083454], [92.79582977, 13.17083454], [92.79611206, 13.17055416], [92.79638672, 13.17056084], [92.79763794, 13.16930103], [92.79750061, 13.16833687], [92.79680634, 13.16764069], [92.79611206, 13.16764069], [92.79582977, 13.16749954], [92.79499817, 13.16749954], [92.79471588, 13.16778088], [92.79444122, 13.16777802], [92.79360962, 13.16860962], [92.79360962, 13.16889], [92.79333496, 13.16916561], [92.79332733, 13.16944027], [92.79333496, 13.16999817], [92.79444122, 13.17111015], [92.79499817, 13.17111015]]], [[[93.01667023, 13.28416729], [93.01583099, 13.28332996], [93.01519775, 13.28333282], [93.01491547, 13.28347206], [93.01470947, 13.28381062], [93.01444244, 13.28402138], [93.01431274, 13.28436089], [93.01437378, 13.28463936], [93.0147934, 13.28477764], [93.01500702, 13.2849102], [93.01542664, 13.28499889], [93.01611328, 13.28499889], [93.01667023, 13.28444004], [93.01667023, 13.28416729]]], [[[93.07450867, 13.30333424], [93.07499695, 13.30305576], [93.07554626, 13.30306053], [93.07611084, 13.30249977], [93.07666779, 13.30249977], [93.07692719, 13.30222034], [93.07749939, 13.30222225], [93.07777405, 13.30194378], [93.07868195, 13.3018074], [93.07910156, 13.30125141], [93.07888794, 13.30000019], [93.07861328, 13.29971981], [93.07791901, 13.29889011], [93.07749939, 13.29860115], [93.07722473, 13.29860973], [93.07680511, 13.29853916], [93.07554626, 13.29832935], [93.07527924, 13.29805565], [93.07499695, 13.29806042], [93.07472229, 13.29778004], [93.07305908, 13.29778004], [93.07277679, 13.29806042], [93.07250214, 13.29805565], [93.07111359, 13.2994442], [93.07103729, 13.29979038], [93.07111359, 13.30054855], [93.07290649, 13.30222034], [93.0734024, 13.30270481], [93.07367706, 13.30333424], [93.07450867, 13.30333424]]], [[[93.01867676, 13.32963085], [93.01868439, 13.3293457], [93.01888275, 13.32935143], [93.01889038, 13.32907963], [93.01942444, 13.3290844], [93.01941681, 13.32937431], [93.02005005, 13.32937431], [93.02024841, 13.32936001], [93.02086639, 13.32942963], [93.02157593, 13.32942963], [93.02200317, 13.32929134], [93.02220917, 13.32915211], [93.02277374, 13.32915211], [93.02346802, 13.32894707], [93.02346802, 13.32874203], [93.02381897, 13.32853889], [93.02472687, 13.32839966], [93.02509308, 13.32833195], [93.02501678, 13.3278513], [93.02501678, 13.32661057], [93.02514648, 13.32640171], [93.02515411, 13.32612801], [93.02480316, 13.3260603], [93.02438354, 13.32612801], [93.02419281, 13.32618332], [93.02390289, 13.32628059], [93.02311707, 13.32599068], [93.02284241, 13.3260603], [93.02262878, 13.32612801], [93.0223465, 13.3260603], [93.02220917, 13.32572174], [93.02227783, 13.32551003], [93.02262878, 13.32551003], [93.02269745, 13.32537079], [93.02284241, 13.3249588], [93.02287292, 13.32487392], [93.02297974, 13.32454872], [93.02256012, 13.32441044], [93.02227783, 13.32434082], [93.02192688, 13.3242712], [93.02185822, 13.32399654], [93.02200317, 13.32372093], [93.02192688, 13.32324028], [93.02178955, 13.3228302], [93.02150726, 13.32262039], [93.0214386, 13.32234669], [93.0214386, 13.321661], [93.02136993, 13.32111168], [93.02115631, 13.32084274], [93.02115631, 13.32015038], [93.02121735, 13.31912041], [93.02121735, 13.31836128], [93.02136993, 13.31781101], [93.0214386, 13.31740093], [93.0214386, 13.3172617], [93.02108765, 13.31733131], [93.02095032, 13.31739902], [93.02088165, 13.31767178], [93.02059937, 13.31774139], [93.0205307, 13.31746674], [93.02024841, 13.31733131], [93.0198288, 13.31718922], [93.01989746, 13.31698418], [93.01989746, 13.31671143], [93.01967621, 13.31644154], [93.01996613, 13.31609058], [93.02059937, 13.31560993], [93.02095032, 13.31540012], [93.02130127, 13.31506062], [93.0214386, 13.31479168], [93.02157593, 13.31437016], [93.0214386, 13.31416702], [93.02121735, 13.31417179], [93.02086639, 13.31424046], [93.02059937, 13.3145113], [93.02031708, 13.31472111], [93.02017975, 13.31472111], [93.02009583, 13.31444073], [93.02031708, 13.31402969], [93.02086639, 13.31376076], [93.02130127, 13.31340981], [93.02130127, 13.3127203], [93.0214386, 13.31258488], [93.02192688, 13.31258488], [93.02200317, 13.31244946], [93.02192688, 13.31217098], [93.02192688, 13.31189728], [93.0223465, 13.31126976], [93.02249146, 13.31100368], [93.02249146, 13.31004238], [93.02269745, 13.30976772], [93.0230484, 13.30956078], [93.02346802, 13.3091507], [93.02353668, 13.30887032], [93.02339935, 13.30853081], [93.02339935, 13.3081913], [93.02361298, 13.30791092], [93.02361298, 13.30743027], [93.02346802, 13.3060627], [93.02368164, 13.30537033], [93.02368164, 13.30523109], [93.02353668, 13.30501175], [93.02312469, 13.30481815], [93.02275848, 13.30427074], [93.02284241, 13.30391979], [93.02256012, 13.30351162], [93.02172089, 13.30296135], [93.02130127, 13.30337143], [93.02121735, 13.30365086], [93.02122498, 13.30406094], [93.02066803, 13.30461121], [93.02044678, 13.30501175], [93.02031708, 13.30536747], [93.02017975, 13.30550385], [93.02002716, 13.30571175], [93.02003479, 13.30605602], [93.01996613, 13.30632019], [93.0197525, 13.30660534], [93.01954651, 13.30674171], [93.01947784, 13.30708981], [93.01933289, 13.30743027], [93.01898956, 13.30757141], [93.01842499, 13.30770588], [93.01835632, 13.30784321], [93.01828766, 13.30832291], [93.01793671, 13.30839157], [93.0174408, 13.30839157], [93.01709747, 13.30846024], [93.01682281, 13.30873966], [93.01568604, 13.30873966], [93.01499939, 13.30881119], [93.01500702, 13.30935097], [93.01386261, 13.3088913], [93.01293182, 13.3091011], [93.0099411, 13.31073666], [93.00942993, 13.31096935], [93.00957489, 13.31214809], [93.01014709, 13.31686115], [93.01576233, 13.31589031], [93.01576233, 13.31637955], [93.01568604, 13.31671143], [93.01561737, 13.31739902], [93.01561737, 13.31774139], [93.01589966, 13.31815147], [93.01589966, 13.31842899], [93.01589966, 13.31925201], [93.01611328, 13.31960106], [93.01611328, 13.32001972], [93.01625061, 13.32049179], [93.01625061, 13.32083607], [93.01603699, 13.32118034], [93.01589966, 13.32145405], [93.01596832, 13.32159042], [93.01596832, 13.32207108], [93.01611328, 13.32331085], [93.01625061, 13.32372093], [93.01638794, 13.32406998], [93.01638794, 13.32455063], [93.01646423, 13.32509804], [93.0165329, 13.32537365], [93.0165329, 13.32578373], [93.01682281, 13.32647038], [93.01695251, 13.32688522], [93.01722717, 13.32750034], [93.01721954, 13.32822037], [93.01612854, 13.32822037], [93.01463318, 13.33012104], [93.01483917, 13.33046055], [93.01631165, 13.33155918], [93.01867676, 13.32963085]]], [[[92.98805237, 12.99805069], [92.98807526, 12.99779797], [92.9875412, 12.99779797], [92.9875412, 12.99805069], [92.98664856, 12.99805069], [92.98638916, 13.00000191], [92.98664856, 13.00028038], [92.98693848, 13.00028038], [92.98750305, 13.00028038], [92.98860931, 13.00055981], [92.98944092, 13.00055981], [92.98970795, 13.00028038], [92.98916626, 13.00000191], [92.98916626, 12.99920177], [92.98887634, 12.99914265], [92.98886108, 12.99838066], [92.98861694, 12.99805069], [92.98805237, 12.99805069]]], [[[92.91249847, 13.00249958], [92.91168213, 13.00249958], [92.91166687, 13.00277805], [92.9108429, 13.00360107], [92.9108429, 13.00500011], [92.91110992, 13.00527954], [92.91139221, 13.00527954], [92.91168213, 13.00500011], [92.91168213, 13.00471973], [92.91222382, 13.00416565], [92.91221619, 13.00389004], [92.91278076, 13.00332928], [92.91278076, 13.00305557], [92.91249847, 13.00277996], [92.91249847, 13.00249958]]], [[[92.94972229, 13.02111053], [92.9486084, 13.02111053], [92.9486084, 13.02166653], [92.94805908, 13.02222061], [92.94805908, 13.02250195], [92.94750214, 13.02306175], [92.94750214, 13.02361202], [92.94721985, 13.02388954], [92.94721985, 13.02444553], [92.94695282, 13.0247097], [92.94526672, 13.02499866], [92.94526672, 13.02528], [92.9458313, 13.02555561], [92.94694519, 13.02583408], [92.94721985, 13.02583408], [92.94721985, 13.02555561], [92.94889069, 13.02499866], [92.94944763, 13.0247097], [92.94944763, 13.02444553], [92.94972229, 13.02416801], [92.94944763, 13.02388954], [92.94944763, 13.02361202], [92.94972229, 13.02333069], [92.94972229, 13.02305508], [92.94999695, 13.02278042], [92.94999695, 13.02250195], [92.94972229, 13.02222061], [92.94972229, 13.02138901], [92.94972229, 13.02111053]]], [[[92.91860962, 13.04000092], [92.91665649, 13.04000092], [92.91500092, 13.04166698], [92.91486359, 13.04194546], [92.91458893, 13.04222107], [92.91451263, 13.04250145], [92.91444397, 13.04277897], [92.91430664, 13.04354], [92.91438293, 13.04410076], [92.91451263, 13.04500103], [92.91478729, 13.04542065], [92.91500092, 13.04584026], [92.91513824, 13.04618168], [92.91527557, 13.04638863], [92.91575623, 13.04714966], [92.91610718, 13.04750061], [92.91660309, 13.04736042], [92.91722107, 13.04722118], [92.91777802, 13.0466671], [92.91777802, 13.04639053], [92.91805267, 13.04611111], [92.91805267, 13.04555511], [92.91832733, 13.04528236], [92.91832733, 13.04444122], [92.91860962, 13.04416656], [92.91860962, 13.04389095], [92.91889191, 13.04361057], [92.91889191, 13.04222298], [92.91916656, 13.04194546], [92.91916656, 13.04138947], [92.91944122, 13.04111099], [92.91944122, 13.04082966], [92.91860962, 13.04000092]]], [[[92.93360901, 13.04944324], [92.93333435, 13.04944324], [92.93305206, 13.04972363], [92.93291473, 13.04986286], [92.93249512, 13.05000401], [92.93208313, 13.05110931], [92.93193817, 13.05166531], [92.93180084, 13.05194092], [92.93180084, 13.05236053], [92.93193817, 13.05264091], [92.93222046, 13.05278015], [92.93305206, 13.05278015], [92.93444824, 13.05138969], [92.93416595, 13.05097008], [92.9338913, 13.04999924], [92.93360901, 13.04972076], [92.93360901, 13.04944324]]], [[[92.91681671, 13.05789185], [92.91613007, 13.05789185], [92.91599274, 13.05810165], [92.91584778, 13.05850983], [92.91549683, 13.0586462], [92.91520691, 13.05878067], [92.91485596, 13.05920029], [92.91465759, 13.05968094], [92.91465759, 13.06023026], [92.91458893, 13.06077957], [92.91437531, 13.06091404], [92.91416168, 13.06097126], [92.91381073, 13.06118965], [92.91353607, 13.06125832], [92.91324615, 13.06153202], [92.91324615, 13.06180954], [92.91310883, 13.06235886], [92.91304016, 13.06270123], [92.91304016, 13.06345844], [92.91310883, 13.06428337], [92.91310883, 13.0658617], [92.91318512, 13.06620884], [92.91345978, 13.06655025], [92.91345978, 13.0668993], [92.91388702, 13.0668993], [92.91409302, 13.06668854], [92.91423035, 13.06634998], [92.91438293, 13.0658617], [92.91444397, 13.06538391], [92.91451263, 13.06497097], [92.91478729, 13.06463146], [92.91507721, 13.06456089], [92.9152832, 13.06421185], [92.91549683, 13.06366539], [92.91562653, 13.06346035], [92.91613007, 13.06298065], [92.91647339, 13.06284046], [92.91681671, 13.06256199], [92.9169693, 13.06201458], [92.91710663, 13.06167126], [92.91717529, 13.06118965], [92.91725159, 13.06077671], [92.91738892, 13.06049919], [92.91738892, 13.05933475], [92.91745758, 13.0588541], [92.91745758, 13.05837059], [92.91738892, 13.05809689], [92.91718292, 13.05795956], [92.91681671, 13.05789185]]], [[[92.73055267, 13.09569073], [92.73069, 13.09554958], [92.73110962, 13.09556198], [92.73166656, 13.09500122], [92.73179626, 13.09430122], [92.73152924, 13.09375191], [92.73139191, 13.09334183], [92.73139191, 13.09319973], [92.73110962, 13.0929203], [92.73097992, 13.09278107], [92.73082733, 13.0923624], [92.73069763, 13.09208584], [92.73027802, 13.09180832], [92.73027802, 13.09167099], [92.72888947, 13.09028053], [92.72833252, 13.09027863], [92.7277832, 13.09082127], [92.7277832, 13.09139061], [92.72805023, 13.09167099], [92.72805023, 13.09278107], [92.72833252, 13.09305668], [92.72833252, 13.09333038], [92.7298584, 13.0951376], [92.73014069, 13.0954113], [92.73055267, 13.09569073]]], [[[94.27333069, 13.46444416], [94.27333069, 13.46416569], [94.27361298, 13.46389008], [94.27361298, 13.46306133], [94.27355194, 13.46286011], [94.27361298, 13.46257114], [94.27388763, 13.46249962], [94.27416992, 13.46222019], [94.27444458, 13.4622221], [94.27471924, 13.46194363], [94.27555847, 13.46194363], [94.27597046, 13.46215439], [94.2765274, 13.46228981], [94.2775116, 13.46229267], [94.27777863, 13.46180534], [94.27757263, 13.46145153], [94.27722168, 13.46055603], [94.27694702, 13.46035099], [94.27661133, 13.46007061], [94.27639008, 13.46000004], [94.27604675, 13.45937061], [94.27555847, 13.45888996], [94.27542114, 13.45860958], [94.27527618, 13.45833397], [94.27514648, 13.45784569], [94.27500916, 13.45750046], [94.27500153, 13.45555592], [94.27507019, 13.45529079], [94.27513885, 13.45493126], [94.27520752, 13.45472145], [94.27520752, 13.45437527], [94.27561951, 13.45410061], [94.27617645, 13.45374966], [94.2767334, 13.45319939], [94.27702332, 13.45244026], [94.27694702, 13.44889069], [94.27687836, 13.44861126], [94.27666473, 13.44833279], [94.27610779, 13.44777679], [94.27610779, 13.44750118], [94.27583313, 13.4472208], [94.27583313, 13.44694519], [94.27555847, 13.44666672], [94.27555847, 13.4458313], [94.27527618, 13.44555473], [94.27527618, 13.44528103], [94.27555847, 13.44500065], [94.27555847, 13.44194031], [94.27527618, 13.4416666], [94.27527618, 13.44139099], [94.27500916, 13.44110966], [94.27500153, 13.44055653], [94.27443695, 13.43999958], [94.27443695, 13.43972015], [94.27416992, 13.43944359], [94.27416992, 13.43916607], [94.27361298, 13.43861008], [94.27361298, 13.4383297], [94.27305603, 13.43777847], [94.27305603, 13.4375], [94.27278137, 13.43721962], [94.27243042, 13.43694592], [94.27207947, 13.43638992], [94.27047729, 13.43508434], [94.26944733, 13.43444157], [94.26902771, 13.43465424], [94.26889038, 13.43472195], [94.26874542, 13.43474293], [94.26832581, 13.43479919], [94.26763153, 13.43465996], [94.26638794, 13.43360996], [94.26582336, 13.43360996], [94.26555634, 13.43332863], [94.26542664, 13.43287563], [94.26486969, 13.43240166], [94.26416779, 13.43198013], [94.26395416, 13.431777], [94.2636795, 13.43109131], [94.26332855, 13.43047142], [94.26317596, 13.43006134], [94.26291656, 13.42998791], [94.26270294, 13.42998791], [94.26248932, 13.43006134], [94.2622757, 13.43019581], [94.26206207, 13.43026447], [94.26192474, 13.43019581], [94.26156616, 13.43013191], [94.26109314, 13.4299202], [94.26080322, 13.4299202], [94.26074219, 13.43013191], [94.26045227, 13.43019962], [94.26003265, 13.4299202], [94.2596817, 13.42978287], [94.25954437, 13.42978287], [94.25919342, 13.42943859], [94.25869751, 13.42943859], [94.25862885, 13.42971516], [94.25862885, 13.4299221], [94.25849152, 13.43026161], [94.25834656, 13.43054199], [94.25820923, 13.4306097], [94.25814056, 13.43074703], [94.25785828, 13.43088436], [94.25767517, 13.43083191], [94.25737, 13.43074703], [94.25681305, 13.4306097], [94.25659943, 13.4306097], [94.25631714, 13.43054199], [94.25575256, 13.43026161], [94.25561523, 13.43047142], [94.2555542, 13.43094063], [94.25552368, 13.43101215], [94.25540161, 13.43130112], [94.25519562, 13.43164062], [94.25512695, 13.43190956], [94.254776, 13.43240166], [94.25421143, 13.4328804], [94.25379181, 13.43316078], [94.25332642, 13.43360996], [94.25305176, 13.43360996], [94.2527771, 13.43388844], [94.2527771, 13.43416595], [94.25222015, 13.43472195], [94.25222778, 13.43486118], [94.25222778, 13.43527985], [94.25222015, 13.43555641], [94.25222015, 13.43610954], [94.2519455, 13.43638802], [94.25195313, 13.43721962], [94.25055695, 13.43861008], [94.25055695, 13.43889141], [94.25027466, 13.43916607], [94.25026703, 13.43972015], [94.25, 13.43999958], [94.24986267, 13.44021034], [94.24931335, 13.44083023], [94.24916077, 13.4416666], [94.24938202, 13.44208145], [94.24926758, 13.44311619], [94.24916077, 13.44361115], [94.24916077, 13.44389057], [94.24901581, 13.44423962], [94.24909973, 13.44527912], [94.24916077, 13.44562054], [94.24944305, 13.44624996], [94.24973297, 13.44639111], [94.25055695, 13.44653034], [94.25077057, 13.44659615], [94.25137329, 13.44677162], [94.25147247, 13.44680119], [94.25161743, 13.44679928], [94.25189209, 13.44715023], [94.25250244, 13.44778061], [94.25263977, 13.44930553], [94.2527771, 13.44972134], [94.2527771, 13.45000076], [94.25332642, 13.45055962], [94.25332642, 13.45111084], [94.2536087, 13.45138931], [94.2536087, 13.45166683], [94.25389099, 13.4519453], [94.25388336, 13.45222092], [94.25506592, 13.45369053], [94.25527954, 13.45388985], [94.25576019, 13.45444584], [94.25686646, 13.45673847], [94.25721741, 13.45722198], [94.25776672, 13.45778179], [94.25777435, 13.45798683], [94.25805664, 13.45833397], [94.2583313, 13.45861244], [94.25971985, 13.45861244], [94.26082611, 13.45971966], [94.26083374, 13.46027756], [94.26126099, 13.46097088], [94.26161194, 13.46146107], [94.26174164, 13.46187782], [94.26194763, 13.46222019], [94.26242828, 13.46305561], [94.26262665, 13.46333027], [94.26277924, 13.46395397], [94.26333618, 13.46444416], [94.26361084, 13.46444416], [94.26409912, 13.46416569], [94.2647171, 13.46326065], [94.26583099, 13.46305561], [94.2664566, 13.46278], [94.26694489, 13.46249962], [94.26805878, 13.46249962], [94.26832581, 13.46278], [94.26860809, 13.46278], [94.26889038, 13.46305561], [94.26889038, 13.46333408], [94.26917267, 13.4636097], [94.26951599, 13.46410179], [94.26979065, 13.46430969], [94.26999664, 13.46444416], [94.27027893, 13.46444035], [94.27062225, 13.4646492], [94.27069855, 13.46470642], [94.27090454, 13.4648571], [94.27131653, 13.46513462], [94.27186584, 13.46520138], [94.27249908, 13.46528053], [94.27278137, 13.46528053], [94.27305603, 13.46500015], [94.27305603, 13.46471977], [94.27333069, 13.46444416]]], [[[93.09902191, 13.43576145], [93.09957886, 13.43548965], [93.10056305, 13.43562508], [93.10166931, 13.43555641], [93.10193634, 13.43527985], [93.10250092, 13.43527985], [93.10305786, 13.43472195], [93.10305786, 13.43305588], [93.10333252, 13.43278027], [93.10333252, 13.43222046], [93.10361481, 13.43194389], [93.10361481, 13.43166637], [93.10388947, 13.43138981], [93.10388947, 13.43112087], [93.10417175, 13.43083191], [93.10424805, 13.42992878], [93.10334015, 13.42986107], [93.10250092, 13.43000031], [93.10221863, 13.43000031], [93.10166168, 13.43006992], [93.09929657, 13.43027973], [93.09889221, 13.4305563], [93.09867859, 13.43083382], [93.09777832, 13.43194389], [93.09777832, 13.43222046], [93.09757233, 13.43272114], [93.09729004, 13.43306065], [93.09666443, 13.43388844], [93.09666443, 13.43416595], [93.09638977, 13.43444443], [93.09638977, 13.43583202], [93.0966568, 13.43610954], [93.09666443, 13.43666553], [93.09694672, 13.43694401], [93.09694672, 13.43721962], [93.09715271, 13.43743229], [93.09777832, 13.43806076], [93.09860992, 13.43806076], [93.09887695, 13.4375], [93.09881592, 13.43736076], [93.09860992, 13.4369297], [93.09889221, 13.43638802], [93.09902191, 13.43576145]]], [[[92.96806335, 13.33250046], [92.96749878, 13.33250046], [92.96749878, 13.33278084], [92.96722412, 13.3330574], [92.96722412, 13.33333206], [92.96694183, 13.33360958], [92.96694183, 13.33444023], [92.96611023, 13.33528137], [92.96611023, 13.33555698], [92.96639252, 13.33582973], [92.96639252, 13.33639145], [92.96666718, 13.33666706], [92.96666718, 13.33694458], [92.96694183, 13.33722115], [92.96749878, 13.33749866], [92.96778107, 13.33777905], [92.96944427, 13.33833313], [92.96971893, 13.33833313], [92.96971893, 13.33805466], [92.96943665, 13.33777046], [92.96944427, 13.33749866], [92.96916962, 13.33722115], [92.96861267, 13.33694458], [92.96861267, 13.33638859], [92.96833038, 13.33611107], [92.96833038, 13.33555889], [92.96778107, 13.33528137], [92.96778107, 13.33471107], [92.96833038, 13.33416653], [92.96833038, 13.33389091], [92.96806335, 13.33360958], [92.96833038, 13.33333206], [92.96833038, 13.3330574], [92.96806335, 13.33278084], [92.96806335, 13.33250046]]], [[[93.01611328, 13.33908939], [93.01611328, 13.33833981], [93.01612091, 13.33793163], [93.01580048, 13.33793163], [93.01526642, 13.33793163], [93.01526642, 13.33771133], [93.01390839, 13.33770847], [93.01390839, 13.33879089], [93.01404572, 13.33881378], [93.0144577, 13.33880711], [93.01444244, 13.33905125], [93.01441956, 13.33928967], [93.01442719, 13.34038639], [93.01504517, 13.3405304], [93.01560974, 13.34043026], [93.01558685, 13.33910084], [93.01611328, 13.33908939]]], [[[93.03749847, 13.34056187], [93.03694153, 13.34056187], [93.03688049, 13.34084034], [93.0368042, 13.34166718], [93.03666687, 13.34194088], [93.03660583, 13.34250069], [93.03666687, 13.34278202], [93.03701782, 13.3432579], [93.03721619, 13.34367085], [93.03771973, 13.3438797], [93.03804779, 13.34390068], [93.03861237, 13.34333134], [93.03861237, 13.34249878], [93.03833008, 13.34222126], [93.03826141, 13.3413887], [93.03749847, 13.34056187]]], [[[93.07723999, 13.36481571], [93.0772934, 13.36472511], [93.07785797, 13.36472511], [93.07814026, 13.36451817], [93.07840729, 13.36423969], [93.0786972, 13.36410522], [93.0786972, 13.36382866], [93.07805634, 13.36382866], [93.0779953, 13.36376095], [93.07814026, 13.36356068], [93.07820892, 13.3632803], [93.07805634, 13.36314106], [93.07778931, 13.36314106], [93.07758331, 13.36342239], [93.07692719, 13.36356068], [93.07652283, 13.36348534], [93.07610321, 13.36369038], [93.07603455, 13.36390018], [93.07596588, 13.3642416], [93.07498169, 13.36423969], [93.07448578, 13.36438084], [93.07441711, 13.36443806], [93.07414246, 13.36466122], [93.07400513, 13.36486244], [93.07386017, 13.36534119], [93.07386017, 13.36575508], [93.07414246, 13.36582375], [93.07456207, 13.36582375], [93.07491302, 13.36589241], [93.07540131, 13.36643887], [93.07546997, 13.36664867], [93.07558441, 13.36671734], [93.07582092, 13.36685371], [93.07617188, 13.366786], [93.07631683, 13.36637115], [93.07631683, 13.36610031], [93.07624817, 13.36582088], [93.07652283, 13.36548042], [93.07673645, 13.36506939], [93.07723999, 13.36481571]]], [[[93.08257294, 13.36687183], [93.08222198, 13.36687183], [93.08167267, 13.36722088], [93.08097076, 13.36805534], [93.08104706, 13.36861134], [93.08117676, 13.36896038], [93.08132172, 13.36923981], [93.08194733, 13.37000084], [93.08249664, 13.37000084], [93.08283997, 13.36944103], [93.08347321, 13.36882114], [93.08353424, 13.36833477], [93.08352661, 13.36799145], [93.08306122, 13.36715031], [93.08277893, 13.36694527], [93.08257294, 13.36687183]]], [[[93.06231689, 13.38329792], [93.06217194, 13.3830204], [93.06196594, 13.38309002], [93.06175232, 13.38322735], [93.06162262, 13.38357067], [93.06140137, 13.38391972], [93.0613327, 13.38419056], [93.0615387, 13.38447189], [93.06161499, 13.38501644], [93.06162262, 13.38529015], [93.06217194, 13.38556576], [93.06238556, 13.38570213], [93.06252289, 13.38611507], [93.06280518, 13.38632202], [93.06308746, 13.38673019], [93.0631485, 13.38679409], [93.06328583, 13.38694], [93.06358337, 13.38680077], [93.06385803, 13.38632202], [93.06399536, 13.3857708], [93.06399536, 13.38542938], [93.06378937, 13.38508034], [93.06357574, 13.38480854], [93.06322479, 13.38453293], [93.06308746, 13.38405228], [93.06238556, 13.38357067], [93.06231689, 13.38329792]]], [[[92.81305695, 13.41972256], [92.81361389, 13.41916656], [92.81388855, 13.41918087], [92.81416321, 13.41889095], [92.81526947, 13.41889095], [92.81639099, 13.41778088], [92.81694794, 13.41778088], [92.8172226, 13.41750145], [92.81749725, 13.41750145], [92.81804657, 13.41693974], [92.81833649, 13.41694546], [92.8188858, 13.41638947], [92.8188858, 13.41582966], [92.8180542, 13.41500092], [92.81804657, 13.41471958], [92.81777954, 13.41444492], [92.81777954, 13.41388798], [92.81804657, 13.41361046], [92.8180542, 13.41194439], [92.81819153, 13.41166592], [92.81749725, 13.41082954], [92.81749725, 13.40999985], [92.81681824, 13.4077301], [92.81594849, 13.40649033], [92.81611633, 13.40580654], [92.81611633, 13.40429115], [92.81500244, 13.40305614], [92.81445313, 13.40305996], [92.81360626, 13.40388966], [92.81360626, 13.40418243], [92.81275177, 13.4050293], [92.81192017, 13.40587044], [92.81208038, 13.40670013], [92.81236267, 13.40739059], [92.8126297, 13.40848923], [92.8133316, 13.41040993], [92.8134079, 13.41206074], [92.81355286, 13.41356945], [92.8134079, 13.41480923], [92.81305695, 13.41639137], [92.81277466, 13.41666698], [92.81277466, 13.41694546], [92.8125, 13.41722107], [92.8125, 13.41750145], [92.81223297, 13.41778088], [92.81222534, 13.41805458], [92.81194305, 13.41833305], [92.81194305, 13.41861057], [92.8116684, 13.41889095], [92.8116684, 13.41918087], [92.81222534, 13.41916656], [92.81277466, 13.41972256], [92.81305695, 13.41972256]]], [[[92.87444305, 13.51220989], [92.87444305, 13.51194382], [92.8730545, 13.51055622], [92.87319946, 13.51041889], [92.87304688, 13.51027966], [92.87304688, 13.50971889], [92.87333679, 13.50944328], [92.87333679, 13.50916767], [92.87361145, 13.50889015], [92.87361145, 13.5083313], [92.87388611, 13.50805473], [92.87388611, 13.50778198], [92.87444305, 13.50722122], [92.87444305, 13.50694561], [92.87472534, 13.50666714], [92.87473297, 13.50444126], [92.87277985, 13.50249863], [92.87251282, 13.50250053], [92.8722229, 13.50222111], [92.87194824, 13.50222301], [92.87166595, 13.50194454], [92.8713913, 13.50194454], [92.87110901, 13.50194454], [92.87083435, 13.50222301], [92.87055206, 13.50222301], [92.86958313, 13.50264263], [92.8694458, 13.50306034], [92.8686142, 13.50388908], [92.86860657, 13.50444126], [92.86805725, 13.50500107], [92.86750031, 13.50500107], [92.86723328, 13.50527859], [92.86722565, 13.50555515], [92.86694336, 13.50583267], [92.86694336, 13.50610924], [92.8666687, 13.50640106], [92.8666687, 13.5075016], [92.8666687, 13.50778198], [92.86638641, 13.50805473], [92.8666687, 13.5083313], [92.8666687, 13.50916767], [92.86694336, 13.50944328], [92.86694336, 13.50957966], [92.86722565, 13.50958729], [92.86778259, 13.51000023], [92.8686142, 13.5116663], [92.86860657, 13.51194096], [92.8694458, 13.51278019], [92.86972046, 13.51278019], [92.87000275, 13.51305962], [92.87110901, 13.51305962], [92.8713913, 13.51278019], [92.87194824, 13.51278019], [92.87251282, 13.51220989], [92.87277985, 13.51249981], [92.87333679, 13.51249981], [92.87388611, 13.51305962], [92.8741684, 13.51305962], [92.87473297, 13.51249981], [92.87444305, 13.51220989]]], [[[92.91889191, 13.51556969], [92.91916656, 13.51528263], [92.91944122, 13.51528263], [92.91971588, 13.51500034], [92.92028046, 13.51500034], [92.92138672, 13.51389027], [92.92138672, 13.51278019], [92.91916656, 13.51056004], [92.91916656, 13.51027966], [92.91860962, 13.50971889], [92.91860962, 13.50944328], [92.91833496, 13.50916767], [92.91832733, 13.50889015], [92.91805267, 13.50861168], [92.91805267, 13.5083313], [92.91694641, 13.50722122], [92.91666412, 13.50722122], [92.91638947, 13.50694561], [92.91611481, 13.50694561], [92.91583252, 13.50666714], [92.91555786, 13.50694561], [92.91500092, 13.50694084], [92.91442871, 13.5075016], [92.91388702, 13.5075016], [92.91333008, 13.50805473], [92.91333008, 13.5083313], [92.91361237, 13.50861168], [92.91361237, 13.50889015], [92.91416931, 13.50944328], [92.91416931, 13.50971889], [92.91471863, 13.51027966], [92.91471863, 13.5116663], [92.91500092, 13.51194096], [92.91500092, 13.5130558], [92.9152832, 13.51332855], [92.9152832, 13.51361179], [92.91665649, 13.51500034], [92.91694641, 13.51500034], [92.91722107, 13.51528263], [92.91750336, 13.51528263], [92.91777802, 13.51556969], [92.91832733, 13.51556969], [92.91889191, 13.51556969]]], [[[93.09449005, 13.41763115], [93.09462738, 13.41755962], [93.09490967, 13.41755962], [93.09519196, 13.41777039], [93.09532928, 13.41763115], [93.09532928, 13.41722107], [93.095047, 13.41708088], [93.095047, 13.41680145], [93.09519196, 13.41652775], [93.09526062, 13.41625023], [93.09519196, 13.41570473], [93.09511566, 13.41549683], [93.09468842, 13.41557026], [93.09442139, 13.41590977], [93.09442139, 13.41646194], [93.09398651, 13.41646194], [93.09371948, 13.41611958], [93.09356689, 13.41569996], [93.09308624, 13.41522217], [93.09308624, 13.41501713], [93.09301758, 13.41474056], [93.09300995, 13.41466618], [93.09294891, 13.41412258], [93.09287262, 13.41377926], [93.09259796, 13.41363144], [93.09252167, 13.41350269], [93.09252167, 13.41288567], [93.092453, 13.41261196], [93.09217834, 13.41226959], [93.09217834, 13.41185093], [93.09182739, 13.41158009], [93.0917511, 13.41151142], [93.09168243, 13.41123104], [93.09168243, 13.41075516], [93.09147644, 13.41034222], [93.09119415, 13.41027355], [93.09077454, 13.40999794], [93.09062958, 13.40993023], [93.09027863, 13.4097929], [93.08992767, 13.40999794], [93.08978271, 13.41005707], [93.08957672, 13.41015053], [93.0891571, 13.41007137], [93.08901978, 13.40999794], [93.08860016, 13.41020298], [93.08853149, 13.41075039], [93.08818054, 13.41151142], [93.08747864, 13.41206074], [93.08732605, 13.41220188], [93.08732605, 13.41261196], [93.08747864, 13.41281509], [93.0875473, 13.41357231], [93.08761597, 13.41412258], [93.08712006, 13.41508007], [93.08705902, 13.41563416], [93.08705902, 13.41577053], [93.087677, 13.41611958], [93.08818054, 13.41660118], [93.08895111, 13.41722107], [93.08950806, 13.41783619], [93.08965302, 13.41852188], [93.0901413, 13.41914177], [93.0908432, 13.41961956], [93.09196472, 13.41989613], [93.092453, 13.42017174], [93.09266663, 13.42017174], [93.09294891, 13.42003536], [93.09336853, 13.41989613], [93.09407043, 13.41954994], [93.09427643, 13.41921043], [93.09420776, 13.41880035], [93.09420776, 13.41825104], [93.09449005, 13.41784], [93.09449005, 13.41763115]]], [[[92.8658371, 13.41361046], [92.86611176, 13.41333199], [92.86638641, 13.41333199], [92.8666687, 13.41305733], [92.86694336, 13.41305733], [92.86750031, 13.41250038], [92.86752319, 13.41201019], [92.86751556, 13.41160202], [92.86709595, 13.41146088], [92.86667633, 13.41132736], [92.86611176, 13.41133118], [92.86582947, 13.41139507], [92.86499786, 13.41193962], [92.86499786, 13.41250038], [92.86528015, 13.4127779], [92.86528015, 13.41305733], [92.8658371, 13.41361046]]], [[[92.84333038, 13.44083214], [92.84333038, 13.43999958], [92.84361267, 13.43972015], [92.84361267, 13.43833447], [92.84388733, 13.43805599], [92.84388733, 13.4375], [92.84443665, 13.4369297], [92.84444427, 13.43666553], [92.84471893, 13.43638992], [92.84471893, 13.43472195], [92.84485626, 13.43444443], [92.84514618, 13.43347454], [92.84485626, 13.43360996], [92.84583282, 13.43222046], [92.84583282, 13.43194389], [92.84610748, 13.43166637], [92.84610748, 13.43112087], [92.84638977, 13.43083191], [92.84555817, 13.43000031], [92.84527588, 13.43000031], [92.84361267, 13.42833138], [92.84361267, 13.42805576], [92.84278107, 13.4272213], [92.84278107, 13.42694569], [92.84249878, 13.42666531], [92.84249878, 13.4263916], [92.84194183, 13.42583084], [92.84166718, 13.42583275], [92.84139252, 13.42555523], [92.84055328, 13.42556], [92.84027863, 13.42527962], [92.83972168, 13.42527962], [92.83889008, 13.42444134], [92.83889008, 13.42416668], [92.83499908, 13.42028141], [92.8347168, 13.42028141], [92.83444214, 13.42000103], [92.83389282, 13.42000103], [92.83361053, 13.41972065], [92.83333588, 13.41972256], [92.83305359, 13.41944504], [92.83277893, 13.41944504], [92.83194733, 13.41861057], [92.83139038, 13.41861057], [92.83082581, 13.41918087], [92.83055878, 13.41916656], [92.83027649, 13.41944504], [92.83000183, 13.41944027], [92.82888794, 13.42056179], [92.82833099, 13.42055511], [92.82805634, 13.42083263], [92.82749939, 13.42083263], [92.82722473, 13.42111111], [92.82692719, 13.42105389], [92.82652283, 13.42097378], [92.8263855, 13.42083263], [92.82583618, 13.42083263], [92.82555389, 13.42055511], [92.82472229, 13.42000961], [92.82446289, 13.42028141], [92.82402802, 13.41987133], [92.82332611, 13.41972065], [92.82250214, 13.42056179], [92.82221985, 13.42055511], [92.82195282, 13.42083073], [92.82195282, 13.42250061], [92.8216629, 13.42277718], [92.8215332, 13.42403126], [92.82148743, 13.42415619], [92.82124329, 13.4249897], [92.82110596, 13.42527962], [92.82111359, 13.42555523], [92.82069397, 13.42625046], [92.82055664, 13.42694569], [92.82055664, 13.42833424], [92.8208313, 13.42860889], [92.8208313, 13.42889023], [92.82111359, 13.42916775], [92.82111359, 13.42944431], [92.82138824, 13.42972183], [92.82138824, 13.43000031], [92.82180023, 13.43083191], [92.82195282, 13.43112087], [92.82194519, 13.43166637], [92.82221985, 13.43194103], [92.82221985, 13.43305588], [92.82250214, 13.43333435], [92.82250214, 13.43444443], [92.82221985, 13.43472195], [92.82221985, 13.43500042], [92.82139587, 13.43583202], [92.82139587, 13.43638992], [92.8216629, 13.43667126], [92.82277679, 13.43667126], [92.82305908, 13.43638992], [92.82333374, 13.43638802], [92.82417297, 13.43721962], [92.82416534, 13.43749809], [92.82457733, 13.43805027], [92.82485962, 13.43847084], [92.82527924, 13.43889141], [92.82554626, 13.43917084], [92.82611084, 13.43917084], [92.82624817, 13.43902969], [92.82666779, 13.43889141], [92.82720947, 13.4383297], [92.82749939, 13.43833447], [92.82777405, 13.43805599], [92.83110809, 13.43805599], [92.83139038, 13.4383297], [92.8319397, 13.43874931], [92.83249664, 13.43889141], [92.83499908, 13.43861008], [92.83528137, 13.43889141], [92.83555603, 13.4388876], [92.83611298, 13.43944359], [92.83638763, 13.43944359], [92.83666992, 13.43944168], [92.83721924, 13.43972206], [92.83750153, 13.43972015], [92.83833313, 13.44056129], [92.83860779, 13.44055653], [92.83889008, 13.44083214], [92.83944702, 13.44083214], [92.83972168, 13.44055653], [92.83999634, 13.44056129], [92.84027863, 13.44028091], [92.84139252, 13.44138813], [92.84139252, 13.44194508], [92.84166718, 13.4422226], [92.84166718, 13.44361115], [92.84194183, 13.44389057], [92.84194183, 13.44416714], [92.84249878, 13.44472313], [92.84259033, 13.44455624], [92.84267426, 13.44451332], [92.84333038, 13.44416714], [92.84333038, 13.4433279], [92.84305573, 13.44305515], [92.84306335, 13.44110966], [92.84333038, 13.44083214]]], [[[93.072052, 13.42608166], [93.07198334, 13.42580795], [93.07163239, 13.42581081], [93.07150269, 13.42567158], [93.07128143, 13.42512226], [93.07121277, 13.42471027], [93.07100677, 13.42443371], [93.07086182, 13.4234724], [93.07057953, 13.42312813], [93.07051086, 13.42284966], [93.07065582, 13.42250824], [93.07065582, 13.42210007], [93.07079315, 13.42181969], [93.07093048, 13.42134094], [93.07086182, 13.42100239], [93.07071686, 13.42078972], [93.07071686, 13.42045021], [93.07086182, 13.42003059], [93.07086182, 13.41969109], [93.07093048, 13.41942024], [93.07108307, 13.41913986], [93.07107544, 13.41886616], [93.07100677, 13.41858101], [93.07107544, 13.4181776], [93.07121277, 13.41784], [93.0713501, 13.41763115], [93.0713501, 13.41742992], [93.07121277, 13.41701126], [93.07113647, 13.41672993], [93.0711441, 13.41577339], [93.07121277, 13.41542912], [93.0713501, 13.41508007], [93.0713501, 13.4146719], [93.07156372, 13.41432762], [93.07184601, 13.41399097], [93.07190704, 13.41363144], [93.0713501, 13.41343498], [93.07113647, 13.41344166], [93.07051086, 13.41329956], [93.06896973, 13.41329956], [93.06896973, 13.41384983], [93.06890106, 13.41439724], [93.06841278, 13.41474056], [93.06819153, 13.4148798], [93.06819153, 13.4153614], [93.06841278, 13.41549683], [93.06896973, 13.41569996], [93.06910706, 13.41619015], [93.06910706, 13.41660118], [93.0687561, 13.41701126], [93.06868744, 13.41769695], [93.06855011, 13.4179697], [93.06841278, 13.41831684], [93.06833649, 13.41866112], [93.06835175, 13.41900063], [93.06841278, 13.41948605], [93.06826782, 13.41961956], [93.06799316, 13.41976166], [93.06784821, 13.42031097], [93.06784821, 13.42057991], [93.06762695, 13.42093086], [93.06756592, 13.42161465], [93.06754303, 13.42169666], [93.06735992, 13.42230129], [93.06771088, 13.42264938], [93.06762695, 13.42368031], [93.06762695, 13.42416], [93.06806183, 13.42429733], [93.06835175, 13.4244318], [93.06868744, 13.42477989], [93.06896973, 13.42539787], [93.06918335, 13.42615032], [93.06918335, 13.42642784], [93.06945801, 13.42732239], [93.07009888, 13.42780018], [93.07051086, 13.42821503], [93.07079315, 13.42896938], [93.07093048, 13.42924786], [93.07121277, 13.42986488], [93.07149506, 13.43014145], [93.07156372, 13.43055344], [93.07184601, 13.43096066], [93.07233429, 13.43110275], [93.07268524, 13.43110275], [93.07296753, 13.43096638], [93.07324982, 13.43068981], [93.07324982, 13.43020916], [93.07303619, 13.42958927], [93.07269287, 13.42924976], [93.07247162, 13.42877102], [93.07261658, 13.42828083], [93.07254791, 13.42793941], [93.07213593, 13.42753124], [93.07199097, 13.42712116], [93.07199097, 13.42650127], [93.072052, 13.42608166]]], [[[93.06388855, 13.65416622], [93.06472015, 13.65332985], [93.06576538, 13.65312672], [93.06749725, 13.65146065], [93.06749725, 13.65062046], [93.0672226, 13.65027809], [93.06694794, 13.64999962], [93.06624603, 13.64924145], [93.06535339, 13.64777756], [93.06500244, 13.64750004], [93.06472015, 13.6472187], [93.06416321, 13.6472187], [93.06388855, 13.64750195], [93.06361389, 13.64750004], [93.0633316, 13.64756966], [93.06256866, 13.64764118], [93.06221771, 13.64750195], [93.06173706, 13.6473608], [93.06111145, 13.64722157], [93.06076813, 13.64701653], [93.06027985, 13.64693928], [93.05986023, 13.64680672], [93.05944824, 13.64667034], [93.05895996, 13.64646053], [93.05832672, 13.64610958], [93.05812836, 13.64590359], [93.05764008, 13.64548683], [93.05750275, 13.64528179], [93.05665588, 13.64444065], [93.05638885, 13.64406681], [93.05583191, 13.64337921], [93.05539703, 13.64275932], [93.05526733, 13.64194107], [93.05527496, 13.64055538], [93.05500031, 13.64028168], [93.05500031, 13.63722134], [93.05500031, 13.63673782], [93.05473328, 13.63583088], [93.05458832, 13.63555527], [93.05444336, 13.63528061], [93.0541687, 13.63500118], [93.0541687, 13.6347208], [93.05403137, 13.63444519], [93.05403137, 13.63416672], [93.05396271, 13.63389111], [93.05361176, 13.63333035], [93.05361176, 13.63305473], [93.05362701, 13.63276958], [93.05314636, 13.63209534], [93.05272675, 13.63134098], [93.05249786, 13.63111115], [93.05249786, 13.63083267], [93.05222321, 13.6305542], [93.05222321, 13.63028145], [93.05194092, 13.63000107], [93.05194092, 13.62972927], [93.05166626, 13.62944031], [93.05166626, 13.62907791], [93.05148315, 13.62873077], [93.05099487, 13.62797737], [93.05050659, 13.62714863], [93.04972076, 13.62611008], [93.04972076, 13.6258297], [93.04916382, 13.62527847], [93.04915619, 13.62471962], [93.0486145, 13.62416553], [93.04860687, 13.62388992], [93.04833221, 13.62360096], [93.04833221, 13.62333202], [93.04888916, 13.62277794], [93.04888916, 13.62250042], [93.04915619, 13.62222195], [93.04916382, 13.62194443], [93.04888916, 13.62166595], [93.04860687, 13.62167263], [93.04833221, 13.62139034], [93.04805756, 13.62139034], [93.0477829, 13.62111187], [93.04750061, 13.62111187], [93.04724121, 13.62083244], [93.04695129, 13.62083244], [93.04638672, 13.62138844], [93.04638672, 13.62194443], [93.04695129, 13.62250042], [93.04694366, 13.62277794], [93.04672241, 13.62298965], [93.04611969, 13.62339973], [93.04556274, 13.62417126], [93.04576874, 13.62553978], [93.0458374, 13.62618065], [93.04582977, 13.62680054], [93.04562378, 13.62771034], [93.04541779, 13.62860966], [93.04541779, 13.62889099], [93.04528046, 13.62917137], [93.04528046, 13.62972927], [93.04499817, 13.63000107], [93.04499817, 13.63028145], [93.04472351, 13.6305542], [93.04472351, 13.63083267], [93.04444122, 13.63111115], [93.04444122, 13.63166714], [93.04416656, 13.63194466], [93.04418182, 13.63222027], [93.04389191, 13.63250065], [93.04389191, 13.63276958], [93.04360962, 13.63305473], [93.04360962, 13.63333035], [93.04305267, 13.6338892], [93.04305267, 13.63444519], [93.04277802, 13.6347208], [93.04277802, 13.63555527], [93.04250336, 13.63583279], [93.04250336, 13.63694477], [93.04499817, 13.6394453], [93.04499817, 13.63972092], [93.04556274, 13.64028168], [93.04555511, 13.64055538], [93.04582977, 13.6408329], [93.04582977, 13.64111137], [93.04638672, 13.64166832], [93.04660034, 13.64194107], [93.04777527, 13.64277744], [93.04798889, 13.64297962], [93.04833221, 13.64305973], [93.0486145, 13.64333057], [93.05027771, 13.64470959], [93.05027771, 13.64500046], [93.05110931, 13.64583397], [93.05132294, 13.64589977], [93.05200958, 13.64666557], [93.05222321, 13.64694405], [93.05249786, 13.6472187], [93.05249786, 13.64805603], [93.05278015, 13.64833164], [93.05278015, 13.64888954], [93.05304718, 13.64916992], [93.05304718, 13.64999962], [93.0533371, 13.65028], [93.0533371, 13.65055561], [93.05379486, 13.65135193], [93.05414581, 13.65176392], [93.05470276, 13.65176392], [93.05504608, 13.65190125], [93.05526733, 13.65210819], [93.055336, 13.65244961], [93.05526733, 13.65278053], [93.05555725, 13.65305424], [93.05555725, 13.65333366], [93.05595398, 13.65370083], [93.05645752, 13.65417099], [93.06082916, 13.65416622], [93.06138611, 13.65444374], [93.06222534, 13.65444374], [93.06263733, 13.65458584], [93.06319427, 13.65465355], [93.06368256, 13.65444183], [93.06388855, 13.65416622]]], [[[93.22442627, 14.01583099], [93.22666931, 14.01388454], [93.22708893, 14.0132618], [93.22715759, 14.01207924], [93.22694397, 14.01138878], [93.22666931, 14.01111126], [93.22666931, 14.01083279], [93.22639465, 14.01027679], [93.22638702, 14.00992966], [93.22653198, 14.00951099], [93.22673798, 14.00930309], [93.22687531, 14.00881958], [93.22666931, 14.00722313], [93.22638702, 14.00694466], [93.22638702, 14.00666714], [93.22631836, 14.00618076], [93.22611237, 14.00500011], [93.22556305, 14.00444031], [93.22555542, 14.00416565], [93.22499847, 14.00360966], [93.22499847, 14.00166607], [93.22528076, 14.00139046], [93.22528076, 14.00111008], [93.22556305, 14.0008297], [93.22555542, 14.00055599], [93.22611237, 14.00001144], [93.22638702, 13.99971962], [93.22638702, 13.99944401], [93.22666931, 13.99916553], [93.22666931, 13.99888992], [93.22721863, 13.99833202], [93.22721863, 13.99805641], [93.22750092, 13.99777985], [93.22750092, 13.99750042], [93.2277832, 13.99722195], [93.22777557, 13.99694443], [93.22805786, 13.99666786], [93.22805786, 13.99555969], [93.22833252, 13.99528027], [93.22833252, 13.99472237], [93.22895813, 13.99388981], [93.22930908, 13.99249935], [93.22944641, 13.99222088], [93.22944641, 13.99166775], [93.22972107, 13.99138927], [93.22986603, 13.99055958], [93.23000336, 13.99028015], [93.23000336, 13.99000072], [93.23027802, 13.9897213], [93.23027802, 13.98944473], [93.23055267, 13.98916721], [93.2305603, 13.9888916], [93.23110962, 13.98807144], [93.23139191, 13.98750114], [93.23145294, 13.98722076], [93.23166656, 13.98666668], [93.23166656, 13.98631191], [93.23173523, 13.98590374], [93.23165894, 13.98569584], [93.23179626, 13.98534966], [93.23194122, 13.98465919], [93.23236847, 13.98353958], [93.2324295, 13.98326397], [93.23236084, 13.98222065], [93.23216248, 13.98167133], [93.23194122, 13.98111057], [93.23166656, 13.98083305], [93.23166656, 13.98027897], [93.23139191, 13.98000145], [93.23139191, 13.97943974], [93.23110962, 13.97916603], [93.23110962, 13.9786396], [93.23078918, 13.97788143], [93.23078918, 13.97732925], [93.23085785, 13.97692204], [93.23085785, 13.97623062], [93.23114014, 13.9756794], [93.23114014, 13.97526932], [93.23107147, 13.9748497], [93.23043823, 13.97437286], [93.22953033, 13.97402859], [93.22889709, 13.97375107], [93.22777557, 13.97313595], [93.227211, 13.97266197], [93.22659302, 13.9725914], [93.22611237, 13.97249985], [93.22548676, 13.97250175], [93.22506714, 13.97236347], [93.22472382, 13.97236347], [93.22444153, 13.9721508], [93.22416687, 13.97194386], [93.22382355, 13.97166824], [93.22305298, 13.97159958], [93.22249603, 13.97174072], [93.22244263, 13.97244072], [93.22202301, 13.97299004], [93.22055817, 13.97360992], [93.22027588, 13.97360992], [93.22000122, 13.9738903], [93.21971893, 13.9738903], [93.21943665, 13.97417068], [93.21916962, 13.97416592], [93.21888733, 13.97444439], [93.21888733, 13.97472191], [93.2186203, 13.97500038], [93.2186203, 13.97528267], [93.21833038, 13.97555637], [93.21833038, 13.97611046], [93.21833038, 13.97680092], [93.2186203, 13.97806072], [93.21881866, 13.97874928], [93.21902466, 13.9795742], [93.21930695, 13.98081207], [93.21958923, 13.98184204], [93.2196579, 13.98294067], [93.21986389, 13.98383617], [93.22000122, 13.98444462], [93.22000122, 13.98583317], [93.22006989, 13.98631763], [93.22027588, 13.98694515], [93.22055817, 13.98722076], [93.22055817, 13.98807144], [93.22055054, 13.98847008], [93.22083282, 13.9897213], [93.22083282, 13.99360943], [93.22097778, 13.99402618], [93.22110748, 13.9944458], [93.22110748, 13.99583244], [93.22117615, 13.99617958], [93.22117615, 13.99812698], [93.22110748, 13.9986124], [93.22110748, 13.99944401], [93.22083282, 13.99971962], [93.22083282, 14.00001144], [93.22055817, 14.00028038], [93.22033691, 14.00123978], [93.22027588, 14.00278091], [93.22013855, 14.00305557], [93.22013855, 14.00360966], [93.22027588, 14.00389099], [93.22027588, 14.00416565], [93.22055817, 14.00444031], [93.22055817, 14.00528145], [93.22083282, 14.0055542], [93.22083282, 14.00694466], [93.22055817, 14.00722027], [93.22055817, 14.00805664], [93.22027588, 14.00833321], [93.22027588, 14.00887966], [93.22000122, 14.00916672], [93.22000122, 14.00944519], [93.21971893, 14.00972271], [93.21971893, 14.01083279], [93.21943665, 14.01111126], [93.21944427, 14.01166725], [93.21951294, 14.01242447], [93.21971893, 14.0144453], [93.22000122, 14.01472092], [93.22000122, 14.01528168], [93.22027588, 14.01556015], [93.22055817, 14.01555538], [93.22083282, 14.0158329], [93.22138977, 14.01583099], [93.22161102, 14.01605415], [93.22194672, 14.01639175], [93.22249603, 14.01639175], [93.22277832, 14.01667023], [93.2233429, 14.01667023], [93.22360992, 14.01639175], [93.22381592, 14.01632118], [93.22389221, 14.0160408], [93.22442627, 14.01583099]]], [[[93.01583099, 13.67611217], [93.01638794, 13.67555618], [93.01667023, 13.67556095], [93.01695251, 13.67527962], [93.01750183, 13.67527962], [93.01777649, 13.67500019], [93.01805878, 13.67500019], [93.01889038, 13.67416954], [93.01889038, 13.67389011], [93.01917267, 13.67360973], [93.01916504, 13.67305565], [93.01944733, 13.67278004], [93.01944733, 13.67249966], [93.02027893, 13.67166996], [93.02081299, 13.67148113], [93.02108765, 13.67100239], [93.02129364, 13.67065811], [93.02157593, 13.67045116], [93.02185822, 13.67045307], [93.0221405, 13.67038155], [93.02227783, 13.67031384], [93.0223465, 13.66976547], [93.0223465, 13.6694212], [93.02205658, 13.66901016], [93.02194214, 13.66861057], [93.02194214, 13.66722107], [93.02249908, 13.66666698], [93.02249908, 13.66638947], [93.02278137, 13.66611099], [93.02278137, 13.66527939], [93.02307129, 13.66500092], [93.02307129, 13.66472054], [93.02333069, 13.66444302], [93.02333069, 13.66388893], [93.02361298, 13.66361141], [93.02361298, 13.66333294], [93.02444458, 13.66250134], [93.02443695, 13.66222095], [93.02500153, 13.66166687], [93.02500153, 13.66139126], [93.02555847, 13.66082954], [93.02555847, 13.65944481], [93.02500153, 13.65888882], [93.02500153, 13.6586113], [93.02444458, 13.65805435], [93.02443695, 13.65722275], [93.02500153, 13.65667057], [93.02500153, 13.65639114], [93.02527618, 13.65610981], [93.02527618, 13.65583038], [93.02555847, 13.65555668], [93.02555847, 13.65499973], [93.02581787, 13.65472031], [93.02583313, 13.65416622], [93.02610779, 13.65390015], [93.02610779, 13.65361023], [93.02583313, 13.65333366], [93.02583313, 13.65222168], [93.02555847, 13.65194416], [93.02555847, 13.6497221], [93.02527618, 13.64944363], [93.02527618, 13.64833355], [93.02555847, 13.64805603], [93.02555847, 13.64777088], [93.02583313, 13.64750004], [93.02581787, 13.64693928], [93.02610779, 13.64666557], [93.02610779, 13.64638996], [93.02639008, 13.64610958], [93.02639008, 13.64583397], [93.02694702, 13.64527798], [93.02694702, 13.64500046], [93.02722168, 13.64470959], [93.02722168, 13.64444447], [93.02777863, 13.64388657], [93.02777863, 13.64361191], [93.0283432, 13.64305973], [93.0283432, 13.6427803], [93.02861023, 13.64250183], [93.02861023, 13.64222145], [93.02889252, 13.64194584], [93.02889252, 13.64138889], [93.02916718, 13.64111137], [93.02916718, 13.64055538], [93.02944183, 13.64028168], [93.02944183, 13.63890076], [93.02971649, 13.63861084], [93.02971649, 13.63694096], [93.02999878, 13.63666725], [93.02999878, 13.63639069], [93.0319519, 13.63444042], [93.03194427, 13.63416672], [93.03221893, 13.63389111], [93.03221893, 13.63333035], [93.03194427, 13.63305473], [93.0319519, 13.63222027], [93.03166962, 13.63194466], [93.03166962, 13.63000107], [93.03145599, 13.62924194], [93.03125, 13.62896061], [93.03034973, 13.62799263], [93.02986145, 13.62778091], [93.02944183, 13.62778091], [93.02903748, 13.62757111], [93.02861023, 13.62749958], [93.0284729, 13.62716103], [93.02777863, 13.62693977], [93.02694702, 13.62694359], [93.02666473, 13.62722206], [93.02610779, 13.62722206], [93.02583313, 13.62694359], [93.02527618, 13.62694359], [93.02500153, 13.62722206], [93.02443695, 13.62722015], [93.02416992, 13.62749958], [93.02388763, 13.62749958], [93.01972198, 13.63167095], [93.01944733, 13.63166714], [93.01916504, 13.63194466], [93.01889038, 13.6319418], [93.01832581, 13.63250065], [93.01805878, 13.63250065], [93.01777649, 13.63276958], [93.01777649, 13.63305473], [93.01750183, 13.63333035], [93.01750183, 13.63528061], [93.01721954, 13.63555527], [93.01721954, 13.63583088], [93.01555634, 13.63750076], [93.01555634, 13.63777924], [93.01526642, 13.63805962], [93.01526642, 13.63861084], [93.01499939, 13.63888931], [93.01499939, 13.64111137], [93.01526642, 13.64139175], [93.01527405, 13.64166832], [93.01555634, 13.64194107], [93.01555634, 13.64305973], [93.0147171, 13.64389038], [93.01167297, 13.64389038], [93.01139069, 13.64416981], [93.01083374, 13.6441679], [93.01055908, 13.64444447], [93.01027679, 13.64444447], [93.00888824, 13.64583397], [93.0083313, 13.64583397], [93.00805664, 13.64611244], [93.00749969, 13.64610958], [93.00723267, 13.64638996], [93.00666809, 13.64638996], [93.0063858, 13.64667034], [93.00583649, 13.64666557], [93.0055542, 13.64694405], [93.00333405, 13.64694405], [93.00250244, 13.64777088], [93.00250244, 13.64805603], [93.00111389, 13.64944363], [93.0008316, 13.64944363], [93.00066376, 13.64927769], [93.00055695, 13.64916801], [93.00026703, 13.64916992], [93.0, 13.64888954], [92.99973297, 13.64861202], [92.99972534, 13.64833355], [92.9991684, 13.64777756], [92.9991684, 13.64750004], [92.99887848, 13.6472187], [92.99861145, 13.64722157], [92.9980545, 13.64666557], [92.99694824, 13.64667034], [92.99666595, 13.64638996], [92.9963913, 13.64638996], [92.9952774, 13.64528179], [92.9952774, 13.64500046], [92.9944458, 13.64416981], [92.99416351, 13.64444447], [92.99388885, 13.64444447], [92.9936142, 13.64472198], [92.99333191, 13.64470959], [92.99305725, 13.64500046], [92.99194336, 13.64500046], [92.9916687, 13.64470959], [92.9908371, 13.64472198], [92.99055481, 13.64444447], [92.98944092, 13.64444447], [92.98805237, 13.64305592], [92.98777771, 13.64305973], [92.98750305, 13.6427803], [92.98638916, 13.6427803], [92.98610687, 13.64305973], [92.98583221, 13.64305592], [92.98555756, 13.64333439], [92.98500061, 13.64333057], [92.98472595, 13.64361191], [92.98443604, 13.64361191], [92.98388672, 13.6441679], [92.98390198, 13.64444065], [92.98444366, 13.64500046], [92.98444366, 13.64583397], [92.98472595, 13.64610958], [92.98472595, 13.64638996], [92.98444366, 13.64666557], [92.98444366, 13.64694405], [92.98416901, 13.6472187], [92.98416901, 13.64750004], [92.98390198, 13.64777088], [92.98388672, 13.64805603], [92.98361206, 13.64833164], [92.98361206, 13.64861202], [92.98166656, 13.65056133], [92.98166656, 13.65084076], [92.98084259, 13.65167141], [92.98055267, 13.65166569], [92.98027802, 13.65194416], [92.98000336, 13.65194416], [92.97972107, 13.65222168], [92.97944641, 13.65221977], [92.97888947, 13.65278053], [92.97861481, 13.65277767], [92.97805786, 13.65333366], [92.97776794, 13.65332985], [92.97721863, 13.65390015], [92.97721863, 13.65416622], [92.97694397, 13.65444374], [92.97693634, 13.65472031], [92.97666931, 13.65499973], [92.97666931, 13.65639114], [92.97694397, 13.65666676], [92.97693634, 13.65694046], [92.97721863, 13.65722275], [92.97750092, 13.65722275], [92.97776794, 13.65750122], [92.97805786, 13.65750122], [92.97833252, 13.65722275], [92.97860718, 13.65750122], [92.97915649, 13.65750122], [92.98083496, 13.65916729], [92.98084259, 13.65971088], [92.98110962, 13.6600008], [92.98110962, 13.66028118], [92.98139191, 13.66056156], [92.98139191, 13.66139126], [92.98110962, 13.66166687], [92.98110962, 13.66222286], [92.98000336, 13.66333294], [92.98000336, 13.66361141], [92.98042297, 13.66403008], [92.98166656, 13.66527939], [92.98194122, 13.66527939], [92.98221588, 13.66555977], [92.98278046, 13.66555977], [92.98306274, 13.66584015], [92.98390198, 13.66584015], [92.98416901, 13.66611099], [92.98443604, 13.66611099], [92.98472595, 13.66638947], [92.98500061, 13.66638947], [92.9852829, 13.66611099], [92.98555756, 13.66611099], [92.98583221, 13.66584015], [92.98722076, 13.66584015], [92.98750305, 13.66611099], [92.98777771, 13.66584015], [92.98805237, 13.66584015], [92.98832703, 13.66611099], [92.9888916, 13.66611099], [92.98916626, 13.66638947], [92.98944092, 13.66638947], [92.98970795, 13.66667175], [92.99055481, 13.66666698], [92.9908371, 13.66694546], [92.99138641, 13.66694546], [92.9916687, 13.66722107], [92.99223328, 13.66722107], [92.99250031, 13.6675024], [92.99305725, 13.6675024], [92.99333191, 13.66778183], [92.99360657, 13.66778183], [92.99388885, 13.6680603], [92.99500275, 13.6680603], [92.9952774, 13.66778183], [92.99584198, 13.66778183], [92.99610901, 13.6680603], [92.9972229, 13.6680603], [92.99749756, 13.66778183], [92.99777985, 13.6680603], [92.9991684, 13.6680603], [93.0, 13.66890144], [93.00049591, 13.66895962], [93.00055695, 13.66916847], [93.0008316, 13.66944313], [93.00111389, 13.66944313], [93.001297, 13.66963005], [93.00138855, 13.66972446], [93.00164795, 13.66972065], [93.00222015, 13.67028046], [93.00250244, 13.67028046], [93.0029068, 13.67056179], [93.00389099, 13.67056179], [93.0047226, 13.66972065], [93.0047226, 13.66889], [93.00501251, 13.66861057], [93.00499725, 13.66833305], [93.00527954, 13.66805458], [93.00527954, 13.66778183], [93.00554657, 13.6675024], [93.0063858, 13.6675024], [93.00666809, 13.66778183], [93.00701904, 13.66791916], [93.00722504, 13.66861057], [93.00722504, 13.66944313], [93.00701141, 13.66972446], [93.00708771, 13.67096996], [93.00723267, 13.67138958], [93.00722504, 13.67166805], [93.00778198, 13.67221928], [93.00778198, 13.67249966], [93.0080719, 13.67278004], [93.0080719, 13.67306042], [93.00837708, 13.67337894], [93.00860596, 13.67360973], [93.00888824, 13.67360973], [93.00945282, 13.67416954], [93.00971985, 13.67416573], [93.01000214, 13.6744442], [93.01055908, 13.6744442], [93.01083374, 13.67472172], [93.01194763, 13.67472172], [93.01222229, 13.6744442], [93.01277924, 13.67444134], [93.01294708, 13.67445278], [93.01315308, 13.6744709], [93.01338196, 13.6742363], [93.01384735, 13.67405415], [93.0141983, 13.67391491], [93.01454926, 13.67391491], [93.01454926, 13.67412186], [93.0142746, 13.6745348], [93.01377869, 13.67466927], [93.01371002, 13.67509079], [93.01416779, 13.67527962], [93.01444244, 13.67556095], [93.01472473, 13.67555618], [93.01527405, 13.67611217], [93.01583099, 13.67611217]]], [[[93.02361298, 13.67086124], [93.02311707, 13.67086124], [93.0229187, 13.67127991], [93.02311707, 13.67162037], [93.02339935, 13.67196369], [93.02346802, 13.67224026], [93.02326202, 13.67258167], [93.02291107, 13.67292595], [93.02275848, 13.67320156], [93.02284241, 13.6734066], [93.02284241, 13.67354107], [93.02256012, 13.6738224], [93.02269745, 13.67430019], [93.02318573, 13.67389011], [93.02339935, 13.6738224], [93.0239563, 13.67354107], [93.02403259, 13.67327023], [93.02403259, 13.67300129], [93.02423859, 13.6725111], [93.02423859, 13.67217064], [93.02403259, 13.67169094], [93.02381897, 13.67135143], [93.02361298, 13.67086124]]], [[[93.3666687, 14.04749966], [93.36611938, 14.0469389], [93.36611176, 14.04666805], [93.3658371, 14.04666996], [93.36541748, 14.04666138], [93.36444092, 14.04749966], [93.36416626, 14.04749966], [93.36354065, 14.04806042], [93.36360931, 14.04861164], [93.36360931, 14.04889202], [93.3638916, 14.04916573], [93.3638916, 14.0494442], [93.36360931, 14.04971886], [93.36360931, 14.05027962], [93.36464691, 14.05138969], [93.36486053, 14.05280781], [93.36472321, 14.05356026], [93.36450958, 14.05376911], [93.36444092, 14.05416584], [93.36444092, 14.05444431], [93.36416626, 14.05471992], [93.36416626, 14.05527973], [93.36402893, 14.05631065], [93.36424255, 14.05686188], [93.36499786, 14.05694389], [93.36528015, 14.05666637], [93.36528015, 14.05639267], [93.36554718, 14.05611038], [93.36555481, 14.05583191], [93.36603546, 14.05534172], [93.36610413, 14.05478764], [93.36633301, 14.05416107], [93.36638641, 14.05389023], [93.36638641, 14.05360985], [93.3666687, 14.05333424], [93.3666687, 14.05277824], [93.36694336, 14.05249977], [93.36694336, 14.05222034], [93.3666687, 14.05194759], [93.36646271, 14.05180931], [93.36638641, 14.05167007], [93.36638641, 14.05146122], [93.36618042, 14.05104065], [93.36604309, 14.05027962], [93.36611938, 14.05000019], [93.36632538, 14.04937267], [93.36638641, 14.04889011], [93.36638641, 14.04861164], [93.3666687, 14.04833126], [93.3666687, 14.04749966]]], [[[93.38360596, 14.12777996], [93.38360596, 14.12736034], [93.38319397, 14.12707806], [93.38223267, 14.1272192], [93.38194275, 14.12736034], [93.38166809, 14.12749863], [93.3813858, 14.12749863], [93.38083649, 14.12805557], [93.38083649, 14.12833118], [93.38131714, 14.12910175], [93.38166809, 14.12930679], [93.38222504, 14.12944412], [93.3833313, 14.12833405], [93.3833313, 14.12805557], [93.38360596, 14.12777996]]], [[[93.36624908, 14.15638065], [93.36638641, 14.15611172], [93.36694336, 14.15555954], [93.36694336, 14.15528202], [93.3666687, 14.15500164], [93.3666687, 14.15388966], [93.36694336, 14.15360928], [93.36694336, 14.15166664], [93.36750031, 14.15111065], [93.36750031, 14.15057087], [93.36776733, 14.15028191], [93.36776733, 14.14889145], [93.36833191, 14.14833069], [93.3694458, 14.1483326], [93.37000275, 14.1477766], [93.3702774, 14.14778137], [93.37055206, 14.14806175], [93.37083435, 14.14805508], [93.37110901, 14.1483326], [93.37304688, 14.14833069], [93.37333679, 14.14861107], [93.37695313, 14.14861107], [93.37722015, 14.1483326], [93.3777771, 14.1483326], [93.37805176, 14.14805508], [93.37832642, 14.14806175], [93.3786087, 14.14778137], [93.3786087, 14.14722061], [93.37750244, 14.14611053], [93.37722015, 14.14611053], [93.3769455, 14.14583302], [93.37638855, 14.14583302], [93.37610626, 14.14555931], [93.37555695, 14.14555931], [93.37526703, 14.14528084], [93.37499237, 14.14555931], [93.37388611, 14.14555931], [93.37361145, 14.14528084], [93.37333679, 14.14527893], [93.37277985, 14.14583302], [93.37166595, 14.14583302], [93.37110901, 14.14527893], [93.37055206, 14.14528084], [93.37055206, 14.14500141], [93.3702774, 14.14472103], [93.3702774, 14.14416695], [93.37000275, 14.14389133], [93.37000275, 14.14332962], [93.36972046, 14.14305687], [93.36972046, 14.14137936], [93.3694458, 14.14111042], [93.3694458, 14.14055443], [93.36972046, 14.14028072], [93.36972046, 14.13971996], [93.37000275, 14.13944435], [93.37000275, 14.13888836], [93.36972046, 14.13861275], [93.37000275, 14.13834095], [93.37000275, 14.13611031], [93.3702774, 14.13583374], [93.37021637, 14.1351366], [93.3702774, 14.13464928], [93.37034607, 14.13416958], [93.37055206, 14.13360977], [93.37055206, 14.13167], [93.37082672, 14.13138962], [93.37082672, 14.13111019], [93.37110901, 14.13083363], [93.37110901, 14.13027763], [93.3713913, 14.13000202], [93.3713913, 14.12972164], [93.37194824, 14.12916565], [93.37194824, 14.12889194], [93.37249756, 14.12833118], [93.37249756, 14.12805557], [93.37304688, 14.12749863], [93.37304688, 14.1272192], [93.37472534, 14.12555504], [93.37473297, 14.12528038], [93.37596893, 14.12389183], [93.37610626, 14.12333965], [93.37673187, 14.12284088], [93.37784576, 14.12270641], [93.37805939, 14.12222099], [93.37805176, 14.1208334], [93.3777771, 14.12055492], [93.3777771, 14.12026978], [93.37750244, 14.11999893], [93.37750244, 14.11972141], [93.37722015, 14.11944485], [93.37722015, 14.11916733], [93.37695313, 14.11889076], [93.37695313, 14.11778069], [93.37722015, 14.11750126], [93.37722015, 14.11721134], [93.37666321, 14.11666679], [93.37666321, 14.11583042], [93.37638855, 14.11555672], [93.37638855, 14.11528111], [93.37610626, 14.11500072], [93.37610626, 14.11443996], [93.37555695, 14.11388779], [93.37555695, 14.11306095], [93.37526703, 14.11278057], [93.37526703, 14.11194038], [93.375, 14.11166573], [93.37499237, 14.11110973], [93.37473297, 14.11083031], [93.37472534, 14.11055565], [93.37499237, 14.11028099], [93.37499237, 14.10917091], [93.37555695, 14.10861015], [93.37555695, 14.10805607], [93.3758316, 14.10778046], [93.3758316, 14.10750008], [93.37610626, 14.1072197], [93.37611389, 14.10583401], [93.3758316, 14.10555553], [93.3758316, 14.10527134], [93.375, 14.10444355], [93.375, 14.10305595], [93.37473297, 14.10278034], [93.37473297, 14.10223103], [93.37444305, 14.10194111], [93.37444305, 14.10138988], [93.37499237, 14.10083103], [93.375, 14.10027695], [93.37526703, 14.09999943], [93.37526703, 14.09833145], [93.37555695, 14.09805489], [93.37555695, 14.09639168], [93.37526703, 14.0961113], [93.37527466, 14.09583282], [93.375, 14.09555531], [93.37499237, 14.09388924], [93.37473297, 14.09361076], [93.37472534, 14.09249878], [93.37464905, 14.09222126], [93.37409973, 14.09145737], [93.37388611, 14.09139061], [93.37333679, 14.09082985], [93.3730545, 14.09083271], [93.37249756, 14.09027672], [93.37249756, 14.09000111], [93.37304688, 14.08944035], [93.3730545, 14.08888912], [93.37166595, 14.08750057], [93.37166595, 14.08723164], [93.3713913, 14.08694172], [93.3713913, 14.08666611], [93.37110901, 14.08639145], [93.37110901, 14.08611012], [93.37082672, 14.08582973], [93.37110901, 14.08555698], [93.37110901, 14.0841713], [93.37082672, 14.08388996], [93.37082672, 14.08278275], [93.37055206, 14.08250046], [93.37055206, 14.0819397], [93.3702774, 14.08166599], [93.3702774, 14.08110142], [93.37000275, 14.08083439], [93.37000275, 14.08055592], [93.36972046, 14.0802803], [93.36972046, 14.07999992], [93.37000275, 14.07971954], [93.37000275, 14.07916641], [93.36972046, 14.07888985], [93.36972046, 14.07861042], [93.36916351, 14.07805634], [93.36915588, 14.07750034], [93.36888885, 14.07722187], [93.36916351, 14.07694435], [93.36916351, 14.07639027], [93.3694458, 14.07611179], [93.3694458, 14.07555962], [93.36972046, 14.07529068], [93.36972046, 14.07500172], [93.3694458, 14.07471943], [93.3694458, 14.07444572], [93.36916351, 14.07416534], [93.3694458, 14.07388973], [93.3694458, 14.07360935], [93.36916351, 14.07333374], [93.36916351, 14.07249928], [93.3694458, 14.07221889], [93.36972046, 14.0722208], [93.37000275, 14.07194328], [93.3694458, 14.0713892], [93.36860657, 14.0713892], [93.36833191, 14.07111073], [93.36805725, 14.07111073], [93.36723328, 14.07028198], [93.36723328, 14.07000065], [93.3666687, 14.06944084], [93.3666687, 14.06916714], [93.36638641, 14.06888866], [93.36638641, 14.06666946], [93.3666687, 14.06639099], [93.3666687, 14.06583118], [93.36694336, 14.06555462], [93.36694336, 14.06500053], [93.36750031, 14.06443977], [93.36750031, 14.06416702], [93.36753845, 14.06374073], [93.36704254, 14.06306076], [93.36685181, 14.06257057], [93.3664093, 14.06202221], [93.36592102, 14.06133842], [93.36535645, 14.06051064], [93.36507416, 14.0595541], [93.36493683, 14.05886841], [93.36430359, 14.05873108], [93.36367035, 14.05907345], [93.36346436, 14.0595541], [93.36360168, 14.06002998], [93.3640213, 14.06031132], [93.36444092, 14.06072998], [93.36451721, 14.06133842], [93.36451721, 14.06209087], [93.36444092, 14.06278133], [93.36444092, 14.06305695], [93.36416626, 14.0633297], [93.36416626, 14.06361103], [93.3638916, 14.06389141], [93.3638916, 14.06416702], [93.36341095, 14.0650034], [93.36284637, 14.06555271], [93.36236572, 14.06597424], [93.36165619, 14.06610203], [93.3611145, 14.0666666], [93.3611145, 14.06916714], [93.36083221, 14.06944466], [93.36083221, 14.06972122], [93.3602829, 14.07028198], [93.3602829, 14.07056046], [93.35943604, 14.0713892], [93.35916901, 14.0713892], [93.35861206, 14.07194328], [93.35778809, 14.07201385], [93.35666656, 14.0722208], [93.35582733, 14.07221889], [93.35555267, 14.07249928], [93.35472107, 14.07249928], [93.35458374, 14.07277679], [93.35424042, 14.07291031], [93.35402679, 14.07318974], [93.35388947, 14.0734024], [93.35360718, 14.07444096], [93.35312653, 14.07521152], [93.35277557, 14.0755558], [93.35263824, 14.07583141], [93.35250092, 14.07666779], [93.35229492, 14.07694435], [93.35228729, 14.07722187], [93.35250092, 14.07750034], [93.35250092, 14.07777786], [93.35305786, 14.07833385], [93.35333252, 14.07833195], [93.35388947, 14.07888985], [93.3542099, 14.07918167], [93.35462952, 14.07951927], [93.3549118, 14.07965565], [93.3549118, 14.08082294], [93.35476685, 14.08123112], [93.35456085, 14.0815773], [93.35444641, 14.08222198], [93.35444641, 14.08250046], [93.35472107, 14.08278275], [93.35500336, 14.08277798], [93.35555267, 14.08333206], [93.35639191, 14.08333206], [93.35666656, 14.08305645], [93.35749817, 14.08305645], [93.35778046, 14.08333206], [93.35805511, 14.08333206], [93.35832977, 14.08360958], [93.35832977, 14.08388996], [93.35861206, 14.08416557], [93.35861206, 14.08444405], [93.35888672, 14.08471966], [93.35888672, 14.08500004], [93.35938263, 14.08582973], [93.35943604, 14.08778095], [93.35972595, 14.08806133], [93.35972595, 14.08889103], [93.36138916, 14.09055519], [93.36138916, 14.09083271], [93.36165619, 14.09111118], [93.36166382, 14.09166718], [93.36222076, 14.09222126], [93.36222076, 14.09278107], [93.36250305, 14.09305477], [93.36250305, 14.09333134], [93.36277771, 14.09361076], [93.36277771, 14.09388924], [93.36305237, 14.09417152], [93.36305237, 14.09500122], [93.36333466, 14.09527683], [93.36332703, 14.0961113], [93.36360931, 14.09639168], [93.36360931, 14.09666729], [93.36374664, 14.09701061], [93.3638916, 14.09749889], [93.3638916, 14.09785938], [93.36382294, 14.09825993], [93.36361694, 14.09860897], [93.36332703, 14.09972095], [93.36312866, 14.10007], [93.36305237, 14.10139179], [93.36333466, 14.10166454], [93.36332703, 14.10194111], [93.36340332, 14.10223103], [93.36340332, 14.10320187], [93.36332703, 14.10361195], [93.36333466, 14.10416794], [93.36305237, 14.10444069], [93.36305237, 14.10499954], [93.36277771, 14.10527802], [93.36277771, 14.10583401], [93.36250305, 14.10610962], [93.36250305, 14.10639], [93.36228943, 14.10667038], [93.36228943, 14.10771179], [93.36235809, 14.10820198], [93.36235809, 14.10888958], [93.36222076, 14.10916615], [93.36222076, 14.10972214], [93.36187744, 14.11041069], [93.36180115, 14.11250687], [93.36166382, 14.11333466], [93.36165619, 14.11361027], [93.36138916, 14.11388779], [93.36138916, 14.11444473], [93.36165619, 14.11472034], [93.36166382, 14.11555672], [93.36138916, 14.11583328], [93.36138916, 14.1161108], [93.36055756, 14.11693954], [93.36055756, 14.11805534], [93.36027527, 14.11833286], [93.3602829, 14.11861134], [93.36000061, 14.11888885], [93.35999298, 14.11972141], [93.35972595, 14.11999893], [93.35972595, 14.1202774], [93.36027527, 14.1208334], [93.3602829, 14.12111092], [93.36055756, 14.12138939], [93.36055756, 14.12194538], [93.36027527, 14.12222099], [93.3602829, 14.12250137], [93.36000061, 14.12277699], [93.36000061, 14.12361145], [93.35972595, 14.12361145], [93.35972595, 14.12416744], [93.35943604, 14.12444115], [93.35943604, 14.12500191], [93.35916901, 14.12527657], [93.35916901, 14.12694645], [93.35888672, 14.1272192], [93.35888672, 14.12749863], [93.35861206, 14.12777996], [93.35861206, 14.12889194], [93.35860443, 14.12916565], [93.35868073, 14.12944412], [93.35861206, 14.12972164], [93.35839844, 14.13006783], [93.35749817, 14.13111019], [93.35749817, 14.13138962], [93.35722351, 14.13166809], [93.35721588, 14.13220978], [93.35694122, 14.13249969], [93.35694885, 14.13332939], [93.35721588, 14.13360977], [93.35721588, 14.13389015], [93.35694885, 14.13416958], [93.35694885, 14.13527966], [93.35666656, 14.13555622], [93.35666656, 14.13583183], [93.35582733, 14.13667107], [93.35582733, 14.13750267], [93.35555267, 14.13778114], [93.35548401, 14.14069557], [93.35534668, 14.14137936], [93.35500336, 14.14166737], [93.35479736, 14.14221954], [93.35444641, 14.14277744], [93.35388947, 14.14332962], [93.35388947, 14.14361095], [93.35360718, 14.14389133], [93.35360718, 14.14417076], [93.35333252, 14.14471817], [93.35333252, 14.14583111], [93.35346985, 14.14679718], [93.35360718, 14.14833069], [93.35374451, 14.14950657], [93.35416412, 14.14972115], [93.35639191, 14.14972115], [93.35666656, 14.15000057], [93.35721588, 14.15000057], [93.35749817, 14.15028191], [93.35778046, 14.15027714], [93.35944366, 14.15194321], [93.35972595, 14.1519413], [93.36332703, 14.15555954], [93.36360931, 14.15555954], [93.36416626, 14.15611172], [93.36444092, 14.15611172], [93.36472321, 14.15639019], [93.36499786, 14.15638065], [93.36519623, 14.15658092], [93.36528015, 14.15666962], [93.3658371, 14.15659046], [93.36604309, 14.1564579], [93.36624908, 14.15638065]]], [[[93.55055237, 14.78392029], [93.55013275, 14.78392029], [93.5497818, 14.784132], [93.54928589, 14.78508854], [93.5493927, 14.78583908], [93.54940796, 14.78592777], [93.54956818, 14.78625584], [93.54963684, 14.78680134], [93.54971313, 14.78763103], [93.5497818, 14.78817844], [93.55033875, 14.78838253], [93.55055237, 14.78824615], [93.55090332, 14.78770065], [93.55090332, 14.78516006], [93.55069733, 14.78427124], [93.55055237, 14.78392029]]], [[[93.3702774, 14.19333458], [93.37055206, 14.1930542], [93.37110901, 14.19306087], [93.37194824, 14.19221973], [93.37194824, 14.19194412], [93.3722229, 14.19166565], [93.3722229, 14.19110966], [93.37277985, 14.19055557], [93.37277985, 14.18972015], [93.37249756, 14.18944359], [93.37249756, 14.1888876], [93.3722229, 14.18861008], [93.3722229, 14.1883297], [93.37194824, 14.18805599], [93.37194824, 14.1875], [93.37166595, 14.18721962], [93.37166595, 14.18694401], [93.37110901, 14.18638992], [93.37110901, 14.18610954], [93.37083435, 14.18583393], [93.37083435, 14.18500042], [93.37055206, 14.18472195], [93.37055206, 14.18444443], [93.3702774, 14.18416786], [93.3702774, 14.18389034], [93.37000275, 14.18361187], [93.37000275, 14.18333054], [93.36972046, 14.18305588], [93.36972046, 14.18278027], [93.3694458, 14.18250179], [93.3694458, 14.18167019], [93.36915588, 14.18138981], [93.36915588, 14.18083096], [93.36722565, 14.17888927], [93.36694336, 14.17888927], [93.3666687, 14.17916679], [93.36611176, 14.17972088], [93.36611176, 14.17999935], [93.36555481, 14.18055534], [93.36554718, 14.18083096], [93.36472321, 14.18167019], [93.36333466, 14.18166542], [93.36305237, 14.1819458], [93.36090088, 14.18194103], [93.36042023, 14.18264103], [93.36055756, 14.18305588], [93.36055756, 14.18583393], [93.3602829, 14.18610954], [93.3602829, 14.18638992], [93.36000061, 14.18666553], [93.36000061, 14.18694401], [93.35972595, 14.18721962], [93.3600769, 14.18804932], [93.36125183, 14.18889046], [93.36340332, 14.18868065], [93.36416626, 14.18917274], [93.36402893, 14.18996143], [93.36416626, 14.19056129], [93.36431885, 14.19126129], [93.36486053, 14.19139004], [93.36528778, 14.19132042], [93.36776733, 14.19118118], [93.36901855, 14.19237137], [93.36978912, 14.19319344], [93.3702774, 14.19333458]]], [[[93.35694122, 14.19250011], [93.35722351, 14.19222164], [93.35749817, 14.19222164], [93.35813141, 14.19208145], [93.35888672, 14.19214916], [93.35916901, 14.19222164], [93.35943604, 14.19221973], [93.35972595, 14.19229126], [93.3601532, 14.19236088], [93.3602829, 14.19221973], [93.36055756, 14.19222164], [93.3611145, 14.19166565], [93.36110687, 14.19110966], [93.36083221, 14.19083214], [93.36083221, 14.19055557], [93.3602829, 14.18999958], [93.35943604, 14.18999958], [93.35921478, 14.18976974], [93.35888672, 14.18972206], [93.35861206, 14.18944359], [93.35832977, 14.18944359], [93.35778046, 14.1888876], [93.35749817, 14.1888876], [93.35694122, 14.18944359], [93.35694885, 14.18972015], [93.35639191, 14.19028091], [93.35582733, 14.19028091], [93.35555267, 14.18999958], [93.35527802, 14.18999958], [93.35472107, 14.19055557], [93.35500336, 14.19083023], [93.35500336, 14.19138813], [93.35541534, 14.19194412], [93.35555267, 14.19221973], [93.35590363, 14.19242668], [93.35610962, 14.19250011], [93.35694122, 14.19250011]]], [[[93.57274628, 14.87036133], [93.57315826, 14.86987972], [93.57315826, 14.86850071], [93.57274628, 14.86815929], [93.57246399, 14.86815929], [93.57221985, 14.86833286], [93.57194519, 14.86861134], [93.5716629, 14.86861134], [93.57110596, 14.86917114], [93.5708313, 14.86916733], [93.57055664, 14.86944485], [93.57026672, 14.86944008], [93.56999969, 14.8697319], [93.56944275, 14.8697319], [93.56916809, 14.87000084], [93.5688858, 14.87000084], [93.56861115, 14.87028122], [93.56833649, 14.87028122], [93.56804657, 14.8705616], [93.56804657, 14.87111092], [93.56874847, 14.87194729], [93.56944275, 14.87215233], [93.5696106, 14.87209988], [93.56976318, 14.8720293], [93.57017517, 14.87168694], [93.57067108, 14.87147999], [93.57122803, 14.87127686], [93.57206726, 14.87100124], [93.57239532, 14.87069798], [93.57274628, 14.87036133]]], [[[93.64840698, 14.93486977], [93.64916992, 14.93444061], [93.64944458, 14.93444347], [93.65034485, 14.93402386], [93.65076447, 14.93367958], [93.65194702, 14.93270016], [93.65194702, 14.93166733], [93.65159607, 14.93104076], [93.65139008, 14.93055534], [93.65112305, 14.92993069], [93.65083313, 14.92972088], [93.65013123, 14.92978859], [93.64952087, 14.93083954], [93.64916992, 14.93138885], [93.64805603, 14.93243122], [93.64805603, 14.93278027], [93.64833069, 14.93305492], [93.64833069, 14.93333054], [93.64749908, 14.93416977], [93.64639282, 14.93437958], [93.64611053, 14.93500042], [93.64611053, 14.93527794], [93.64666748, 14.93583393], [93.64722443, 14.93583393], [93.64749908, 14.93555641], [93.64771271, 14.93535042], [93.6479187, 14.93528175], [93.64840698, 14.93486977]]], [[[93.64138794, 14.9024992], [93.64250183, 14.90139103], [93.64250183, 14.90111065], [93.64306641, 14.90055943], [93.64306641, 14.89889145], [93.64332581, 14.89861107], [93.64332581, 14.89806175], [93.64306641, 14.89778137], [93.64306641, 14.89750099], [93.64277649, 14.89722061], [93.64250183, 14.89722347], [93.64221954, 14.896945], [93.64194489, 14.896945], [93.64167023, 14.89666653], [93.64138794, 14.8966713], [93.63804626, 14.89332962], [93.63805389, 14.89305687], [93.63777924, 14.89278126], [93.63777924, 14.89221954], [93.63749695, 14.89194393], [93.63749695, 14.89166641], [93.63722229, 14.89139271], [93.63722229, 14.8905611], [93.63694763, 14.89028072], [93.63694763, 14.88971996], [93.63666534, 14.88944435], [93.63666534, 14.88916588], [93.63694763, 14.88889027], [93.63694763, 14.88806057], [93.63722229, 14.88777065], [93.63722229, 14.88694382], [93.63694763, 14.8866663], [93.63694763, 14.88611031], [93.63666534, 14.88583374], [93.63666534, 14.88555622], [93.63639069, 14.88527966], [93.63639069, 14.88361168], [93.6361084, 14.88332939], [93.6361084, 14.88249969], [93.63582611, 14.88221931], [93.63583374, 14.88138962], [93.6361084, 14.88110924], [93.6361084, 14.88027668], [93.63639069, 14.88000202], [93.63639069, 14.87972069], [93.6361084, 14.87944317], [93.6361084, 14.87888908], [93.63582611, 14.87861061], [93.63583374, 14.87805462], [93.63555908, 14.87778187], [93.63555908, 14.87694073], [93.63527679, 14.87666702], [93.63527679, 14.87611103], [93.63565063, 14.87547112], [93.63591766, 14.87512016], [93.63635254, 14.87464333], [93.6364212, 14.87429905], [93.63613892, 14.87389088], [93.6357193, 14.87374973], [93.63514709, 14.87382126], [93.63507843, 14.87387753], [93.63488007, 14.87403011], [93.63404083, 14.87403011], [93.6333313, 14.87389088], [93.63305664, 14.87361145], [93.63277435, 14.87361145], [93.63194275, 14.87277699], [93.63166809, 14.87277699], [93.6313858, 14.87250137], [93.63111115, 14.87250137], [93.63054657, 14.87193966], [93.63027954, 14.87194538], [93.62916565, 14.8708334], [93.62889099, 14.8708334], [93.6286087, 14.87055683], [93.62832642, 14.8705616], [93.6277771, 14.87000084], [93.62750244, 14.87000084], [93.6258316, 14.86833], [93.62555695, 14.86833286], [93.62472534, 14.86750126], [93.62444305, 14.86750126], [93.62333679, 14.86639118], [93.62333679, 14.86611271], [93.62249756, 14.86528111], [93.62249756, 14.86472034], [93.6222229, 14.86444378], [93.6222229, 14.86416626], [93.62194061, 14.86388969], [93.62194061, 14.86333179], [93.62166595, 14.86305618], [93.62166595, 14.86250019], [93.6213913, 14.86222172], [93.6213913, 14.8619442], [93.62110901, 14.86166573], [93.62110901, 14.86139011], [93.6194458, 14.85972023], [93.6194458, 14.85944366], [93.61888885, 14.85888767], [93.61888123, 14.85861015], [93.6186142, 14.85833359], [93.6186142, 14.8577776], [93.61833191, 14.85750198], [93.61833191, 14.85694122], [93.61805725, 14.85666561], [93.61805725, 14.85527992], [93.61776733, 14.85499954], [93.61776733, 14.85444069], [93.61722565, 14.85389042], [93.61723328, 14.85361195], [93.61694336, 14.85333443], [93.61694336, 14.853055], [93.61638641, 14.85250187], [93.61638641, 14.85222054], [93.6158371, 14.8516674], [93.6158371, 14.85138893], [93.61554718, 14.85111141], [93.61555481, 14.85083294], [93.61416626, 14.84944534], [93.61416626, 14.84916687], [93.6138916, 14.84888935], [93.6138916, 14.84860039], [93.61277771, 14.84749889], [93.61277771, 14.84722137], [93.61250305, 14.84694481], [93.61250305, 14.84666729], [93.61194611, 14.8461113], [93.61194611, 14.84555531], [93.61165619, 14.84528065], [93.61165619, 14.84417057], [93.61138916, 14.84389114], [93.61138916, 14.84333038], [93.61166382, 14.84305477], [93.61165619, 14.84250069], [93.61222076, 14.84193993], [93.61222076, 14.84166718], [93.61250305, 14.84139061], [93.61250305, 14.84056091], [93.61222076, 14.84028053], [93.61222076, 14.83971977], [93.61194611, 14.83944416], [93.61194611, 14.83805561], [93.61193848, 14.83778095], [93.61207581, 14.83729076], [93.61249542, 14.83694363], [93.61277771, 14.83666611], [93.61291504, 14.83638763], [93.61290741, 14.83582973], [93.61264038, 14.83562469], [93.61194611, 14.8355608], [93.61138916, 14.83611012], [93.6111145, 14.83611012], [93.61055756, 14.83666611], [93.61055756, 14.83694172], [93.61048889, 14.83743191], [93.60999298, 14.83819962], [93.61000061, 14.83888817], [93.60971069, 14.83944035], [93.60943604, 14.84000111], [93.60943604, 14.84139061], [93.60916901, 14.84167099], [93.60916901, 14.84250069], [93.60889435, 14.8429184], [93.60874939, 14.84333038], [93.60874939, 14.84375191], [93.60874939, 14.84430981], [93.60861206, 14.84472084], [93.60861206, 14.84639072], [93.60888672, 14.84666729], [93.60888672, 14.84722137], [93.60916901, 14.84749889], [93.60916901, 14.84805489], [93.60943604, 14.84833145], [93.60943604, 14.84888935], [93.60972595, 14.84917164], [93.60972595, 14.85055542], [93.61000061, 14.85083294], [93.61000061, 14.8516674], [93.6102829, 14.85222054], [93.61048889, 14.85250187], [93.61068726, 14.85284996], [93.61069489, 14.85326099], [93.61096954, 14.85374069], [93.61103821, 14.85408783], [93.61118317, 14.85478973], [93.61125183, 14.85639], [93.61125183, 14.85666561], [93.61118317, 14.85694122], [93.6113205, 14.85742664], [93.61154175, 14.85826969], [93.61167908, 14.85929966], [93.611763, 14.86032963], [93.61174774, 14.86190796], [93.61182404, 14.86259365], [93.61194611, 14.8633337], [93.61194611, 14.86472034], [93.61222076, 14.86499977], [93.61222076, 14.86693954], [93.61207581, 14.8677597], [93.61208344, 14.86878586], [93.61228943, 14.86954021], [93.61228943, 14.87022591], [93.61279297, 14.87084198], [93.612854, 14.87173462], [93.61299133, 14.87242126], [93.61290741, 14.87325096], [93.61292267, 14.87365723], [93.61341858, 14.87434292], [93.61360931, 14.87444305], [93.61638641, 14.87722111], [93.61638641, 14.87750053], [93.61694336, 14.87805462], [93.61694336, 14.87833309], [93.61723328, 14.87861061], [93.61723328, 14.87890053], [93.61750031, 14.87916756], [93.61750031, 14.87944126], [93.61805725, 14.88000202], [93.61805725, 14.88027668], [93.6186142, 14.88083363], [93.61860657, 14.88110924], [93.61916351, 14.88166809], [93.61916351, 14.88194561], [93.6194458, 14.88221931], [93.6194458, 14.88249969], [93.61972046, 14.88278008], [93.61972046, 14.88305569], [93.62000275, 14.88332939], [93.62000275, 14.88361168], [93.62055206, 14.88416576], [93.62055206, 14.88471031], [93.62082672, 14.88500023], [93.62082672, 14.88527966], [93.62110901, 14.88555622], [93.62110901, 14.88611031], [93.6213913, 14.88638973], [93.6213913, 14.8866663], [93.62166595, 14.88694382], [93.62166595, 14.88722038], [93.62194824, 14.88749981], [93.62194061, 14.88777065], [93.6222229, 14.8880558], [93.6222229, 14.88833046], [93.62249756, 14.88861179], [93.62249756, 14.88916588], [93.62277985, 14.88944435], [93.62277985, 14.88971996], [93.62304687, 14.89000034], [93.62304687, 14.8905611], [93.62333679, 14.89084053], [93.62333679, 14.89166641], [93.62361145, 14.89194393], [93.62389374, 14.89323425], [93.6239624, 14.89419174], [93.62438202, 14.89495087], [93.62460327, 14.8955698], [93.62500763, 14.8966713], [93.62500763, 14.89750099], [93.62526703, 14.89778137], [93.62527466, 14.89805698], [93.62805176, 14.90083313], [93.6286087, 14.90083122], [93.62889099, 14.90111065], [93.6297226, 14.90111065], [93.62999725, 14.90083122], [93.63027954, 14.90083313], [93.6305542, 14.90055466], [93.63111115, 14.90055943], [93.6313858, 14.90028095], [93.63222504, 14.90027905], [93.63241577, 14.90046787], [93.63249969, 14.90055943], [93.63305664, 14.90055466], [93.6333313, 14.90083313], [93.63360596, 14.90083122], [93.63388062, 14.90111065], [93.63639069, 14.90111065], [93.63667297, 14.90139103], [93.63694763, 14.90139103], [93.63722229, 14.90166855], [93.63749695, 14.90166664], [93.63777924, 14.90194511], [93.63805389, 14.90194511], [93.63833618, 14.90222263], [93.63861084, 14.90222263], [93.6388855, 14.9024992], [93.63916779, 14.9024992], [93.63944244, 14.90278244], [93.64000702, 14.90278244], [93.64070129, 14.90264034], [93.64138794, 14.9024992]]], [[[93.5708313, 14.84632111], [93.57055664, 14.84618187], [93.57021332, 14.846241], [93.56986237, 14.84665775], [93.56965637, 14.84714127], [93.56944275, 14.84777927], [93.56916809, 14.84805489], [93.56916809, 14.84833336], [93.5689621, 14.84860039], [93.5689621, 14.84888935], [93.56964874, 14.84952068], [93.56993103, 14.84945202], [93.57026672, 14.84944057], [93.5708313, 14.84916973], [93.57158661, 14.84860039], [93.5716629, 14.84833336], [93.57194519, 14.84805489], [93.57195282, 14.84722137], [93.5716629, 14.84694481], [93.5716629, 14.84680367], [93.57138824, 14.84666729], [93.5708313, 14.84632111]]], [[[93.57221985, 14.85944366], [93.5716629, 14.85888767], [93.57110596, 14.85888958], [93.5708313, 14.85916996], [93.57055664, 14.85916805], [93.56999969, 14.85972023], [93.56999969, 14.85999966], [93.56973267, 14.86028004], [93.56972504, 14.86055565], [93.56972504, 14.86083412], [93.56999969, 14.86118126], [93.57131958, 14.86131954], [93.57250214, 14.86028004], [93.57250214, 14.85972023], [93.57221985, 14.85944366]]], [[[92.91000366, 13.53722191], [92.91194153, 13.53527737], [92.91194153, 13.53499889], [92.91249847, 13.53444099], [92.91249847, 13.53416538], [92.91278076, 13.53389168], [92.91249847, 13.5336113], [92.91249847, 13.53333282], [92.91166687, 13.53249931], [92.91110992, 13.53249931], [92.9108429, 13.53222084], [92.91055298, 13.53222084], [92.90999603, 13.53166962], [92.90972137, 13.53166962], [92.9091568, 13.53111076], [92.90888977, 13.53111076], [92.90833282, 13.53057098], [92.90805817, 13.53057098], [92.90777588, 13.53028202], [92.90611267, 13.53027916], [92.90556335, 13.53083134], [92.90556335, 13.53111076], [92.90528107, 13.53138924], [92.90528107, 13.53222084], [92.90499878, 13.53249931], [92.90499878, 13.53333282], [92.90471649, 13.5336113], [92.90472412, 13.53388882], [92.90556335, 13.53472137], [92.90555573, 13.53527737], [92.90611267, 13.53583145], [92.90611267, 13.53611183], [92.90694427, 13.53694439], [92.90777588, 13.53694439], [92.90805817, 13.53666782], [92.90833282, 13.53666782], [92.90877533, 13.53711033], [92.90888977, 13.53722191], [92.91000366, 13.53722191]]], [[[92.875, 13.54083443], [92.87638855, 13.53944397], [92.87695313, 13.53945065], [92.8786087, 13.53777981], [92.8786087, 13.53722191], [92.87805176, 13.53666782], [92.87722015, 13.53666973], [92.87666321, 13.53611183], [92.87666321, 13.53583145], [92.87638855, 13.53555584], [92.87638855, 13.53528023], [92.8758316, 13.53472137], [92.87555695, 13.53472137], [92.87444305, 13.53583145], [92.87444305, 13.53611183], [92.87388611, 13.53666782], [92.87388611, 13.53722191], [92.8741684, 13.53750038], [92.8741684, 13.54056263], [92.87444305, 13.54055595], [92.87454987, 13.54065895], [92.87472534, 13.54083443], [92.875, 13.54083443]]], [[[93.05734253, 13.5662508], [93.05734253, 13.56590939], [93.05747986, 13.56557178], [93.05741119, 13.5652914], [93.05719757, 13.56481075], [93.05692291, 13.56439972], [93.05670929, 13.56398106], [93.05670929, 13.56350231], [93.05679321, 13.56345654], [93.05706024, 13.56329727], [93.05719757, 13.56315994], [93.05741119, 13.56282139], [93.05741119, 13.56239891], [93.05699158, 13.56192303], [93.05649567, 13.56192303], [93.05610657, 13.56181622], [93.05580139, 13.56157875], [93.05565643, 13.56116581], [93.05536652, 13.56068134], [93.05488586, 13.56020355], [93.0548172, 13.5599966], [93.05444336, 13.55972099], [93.05388641, 13.55972099], [93.05361176, 13.56000233], [93.05361176, 13.56083298], [93.0534668, 13.56111145], [93.0534668, 13.56139183], [93.05207825, 13.56305599], [93.05222321, 13.5646534], [93.0533371, 13.56583405], [93.05361176, 13.56583405], [93.05388641, 13.56611156], [93.0541687, 13.56610966], [93.05444336, 13.56639004], [93.05612183, 13.56639004], [93.05665588, 13.56668186], [93.05697632, 13.56668186], [93.05713654, 13.56668186], [93.05734253, 13.5662508]]], [[[92.89694214, 13.60167122], [92.8972168, 13.60139275], [92.89778137, 13.60139275], [92.89833069, 13.60083008], [92.89888763, 13.60083199], [92.89916992, 13.60111046], [92.90083313, 13.60111046], [92.90110779, 13.60083199], [92.90166473, 13.60083199], [92.90194702, 13.60055637], [92.90222168, 13.60056114], [92.90361023, 13.59917068], [92.90361023, 13.59860992], [92.90389252, 13.59832954], [92.90389252, 13.59805584], [92.90361023, 13.59778023], [92.90389252, 13.59749985], [92.90361023, 13.59722042], [92.90361023, 13.59638786], [92.9033432, 13.59611034], [92.90333557, 13.59583378], [92.90139008, 13.59389019], [92.90139008, 13.59362125], [92.90027618, 13.59249973], [92.90027618, 13.59221935], [92.90000153, 13.59194374], [92.89971924, 13.59194374], [92.89805603, 13.59027767], [92.89778137, 13.59027958], [92.89749908, 13.59000015], [92.8972168, 13.59000015], [92.89668274, 13.5894413], [92.89638519, 13.58944321], [92.89499664, 13.58805466], [92.89472198, 13.58806038], [92.89444733, 13.58778191], [92.89417267, 13.58778191], [92.89250183, 13.58611107], [92.89250183, 13.58556175], [92.89221954, 13.58527946], [92.89221954, 13.58472061], [92.89194489, 13.58444309], [92.89194489, 13.58388901], [92.89138794, 13.58333111], [92.89138794, 13.58305454], [92.88999939, 13.58168125], [92.88999939, 13.58111095], [92.8897171, 13.58083057], [92.88972473, 13.57972336], [92.88944244, 13.57944489], [92.88944244, 13.57861137], [92.88916779, 13.57833004], [92.88916779, 13.57805538], [92.88889313, 13.57778072], [92.88889313, 13.57693958], [92.88861084, 13.57666683], [92.88833618, 13.57667065], [92.8881073, 13.57622719], [92.88804626, 13.57611275], [92.88722229, 13.57541847], [92.88694763, 13.57528114], [92.8861084, 13.57444], [92.88583374, 13.57444382], [92.88555908, 13.5741663], [92.88527679, 13.57417107], [92.88445282, 13.57500076], [92.88445282, 13.57528114], [92.88360596, 13.57611275], [92.88360596, 13.57639122], [92.8833313, 13.57666683], [92.8833313, 13.5769453], [92.88305664, 13.57721996], [92.88305664, 13.5775013], [92.88277435, 13.57777882], [92.88276672, 13.57833004], [92.88249969, 13.57861137], [92.88249969, 13.57944489], [92.88222504, 13.57972336], [92.88223267, 13.58083057], [92.88194275, 13.58111095], [92.88194275, 13.58139133], [92.88166809, 13.58166695], [92.88168335, 13.58222103], [92.8813858, 13.58250141], [92.8813858, 13.58277702], [92.88146973, 13.58285713], [92.88168335, 13.58306026], [92.88194275, 13.58306026], [92.88249969, 13.58209133], [92.88305664, 13.58250141], [92.88361359, 13.58305454], [92.88361359, 13.58333302], [92.88388824, 13.58361053], [92.88388824, 13.58500099], [92.8841629, 13.58527946], [92.8841629, 13.58555508], [92.88445282, 13.58583069], [92.88445282, 13.58638859], [92.88471985, 13.58667183], [92.88500214, 13.58681107], [92.88555908, 13.58778191], [92.88555908, 13.58805466], [92.88582611, 13.58833122], [92.88582611, 13.5886116], [92.88639069, 13.58916759], [92.88639069, 13.58972359], [92.88666534, 13.59000015], [92.88667297, 13.59221935], [92.88639069, 13.59249973], [92.88639069, 13.59277821], [92.88804626, 13.59444237], [92.88805389, 13.59527779], [92.88944244, 13.59666634], [92.88972473, 13.59666634], [92.89027405, 13.59722233], [92.89054871, 13.59722042], [92.89138794, 13.59806061], [92.89167023, 13.59806061], [92.89250183, 13.5988903], [92.89277649, 13.5988903], [92.89444733, 13.60056114], [92.89472198, 13.60055637], [92.89527893, 13.60111046], [92.89554596, 13.60111046], [92.89583588, 13.60139275], [92.89639282, 13.60139275], [92.89668274, 13.60167122], [92.89694214, 13.60167122]]], [[[93.00785828, 13.5553627], [93.00758362, 13.55529499], [93.00723267, 13.55529976], [93.00681305, 13.55522919], [93.0063858, 13.55522728], [93.00631714, 13.55543232], [93.00610352, 13.5558424], [93.00604248, 13.55611134], [93.00583649, 13.55666733], [93.0055542, 13.55694485], [93.0055542, 13.55749893], [93.00541687, 13.55797958], [93.00541687, 13.55825806], [93.00520325, 13.55860043], [93.00554657, 13.55895138], [93.00583649, 13.55895138], [93.00597382, 13.55942726], [93.00604248, 13.55970287], [93.00618744, 13.55997562], [93.0064621, 13.55997562], [93.00660706, 13.55956554], [93.00681305, 13.55936146], [93.00681305, 13.5583992], [93.00715637, 13.55785179], [93.00730896, 13.55743122], [93.00737762, 13.55722809], [93.00749969, 13.55666924], [93.00778198, 13.55639076], [93.00778198, 13.55583096], [93.00785828, 13.5553627]]], [[[93.00673676, 12.9968996], [93.00673676, 12.99614143], [93.00645447, 12.99586773], [93.00652313, 12.99524975], [93.00589752, 12.99532127], [93.00589752, 12.99435043], [93.00526428, 12.99359512], [93.00491333, 12.99359512], [93.00414276, 12.99297523], [93.00414276, 12.99276829], [93.00393677, 12.99248981], [93.00393677, 12.99221611], [93.00337982, 12.99160099], [93.0032959, 12.99110889], [93.00309753, 12.99110889], [93.00287628, 12.99139118], [93.00267029, 12.99117947], [93.00274658, 12.99097729], [93.00197601, 12.99029064], [93.00163269, 12.99022007], [93.0015564, 12.99008083], [93.00108337, 12.99001026], [93.00106812, 12.98953247], [93.00084686, 12.98953247], [93.00084686, 12.98912144], [93.00071716, 12.98891163], [93.00042725, 12.98864269], [93.0, 12.98889065], [92.9991684, 12.9880619], [92.9988327, 12.98777199], [92.99804688, 12.98695755], [92.9972229, 12.98698139], [92.99726105, 12.98663044], [92.99666595, 12.98668957], [92.99637604, 12.98606968], [92.99421692, 12.98614025], [92.99414825, 12.98582077], [92.99279022, 12.9857893], [92.99253082, 12.98550034], [92.99254608, 12.98502064], [92.99221802, 12.98502064], [92.99223328, 12.98389053], [92.99199677, 12.98389053], [92.99195862, 12.98335075], [92.99172211, 12.98335075], [92.99167633, 12.9822607], [92.9910965, 12.98195076], [92.99112701, 12.98057175], [92.99056244, 12.98055172], [92.9905777, 12.97969913], [92.98999786, 12.97945976], [92.99002075, 12.97891998], [92.98922729, 12.97888088], [92.98917389, 12.97835732], [92.98887634, 12.9783411], [92.98887634, 12.97752094], [92.98863983, 12.97723103], [92.98805237, 12.97723103], [92.98781586, 12.97694206], [92.9878006, 12.97557354], [92.98720551, 12.97556496], [92.98720551, 12.97500229], [92.98673248, 12.97498226], [92.98673248, 12.97445679], [92.98532104, 12.9733696], [92.98532104, 12.97252178], [92.98474884, 12.97254086], [92.98472595, 12.97192097], [92.98417664, 12.97193432], [92.98419189, 12.97168446], [92.98334503, 12.97168446], [92.98336792, 12.97112083], [92.98277283, 12.97056007], [92.98221588, 12.97056007], [92.98221588, 12.9694109], [92.98194885, 12.9694109], [92.98194885, 12.96892834], [92.98087311, 12.96887112], [92.98084259, 12.96832657], [92.98060608, 12.96834946], [92.98056793, 12.9677496], [92.98055267, 12.96754932], [92.98001862, 12.9675312], [92.97999573, 12.96694469], [92.97946167, 12.96697044], [92.97944641, 12.96615028], [92.97975922, 12.9661293], [92.97979736, 12.9655304], [92.97944641, 12.9655714], [92.97943115, 12.96416855], [92.97970581, 12.96418953], [92.97969055, 12.96248055], [92.98000336, 12.96248055], [92.98002625, 12.96143436], [92.97976685, 12.96143436], [92.97973633, 12.96048641], [92.9797287, 12.96024895], [92.98108673, 12.95914173], [92.98107147, 12.95862007], [92.98165894, 12.95866108], [92.98170471, 12.95836926], [92.98221588, 12.95837116], [92.98223114, 12.95804119], [92.98282623, 12.95804119], [92.98280334, 12.957551], [92.98310089, 12.95722485], [92.98416901, 12.95722294], [92.98421478, 12.95697594], [92.98596954, 12.95710182], [92.98652649, 12.95681], [92.98776245, 12.95675087], [92.98789215, 12.95580673], [92.98812103, 12.95555019], [92.98803711, 12.95393085], [92.98731995, 12.95362186], [92.98677826, 12.95339108], [92.98586273, 12.95221996], [92.98526001, 12.95224285], [92.9850235, 12.95164108], [92.98445129, 12.95166111], [92.98445129, 12.95139027], [92.98335266, 12.95139027], [92.98335266, 12.9511404], [92.98284149, 12.95116043], [92.98265839, 12.95082283], [92.98252106, 12.95057392], [92.98167419, 12.95057392], [92.98169708, 12.94999313], [92.98086548, 12.94999313], [92.98082733, 12.94943047], [92.98060608, 12.94947147], [92.98056793, 12.9485817], [92.98029327, 12.9485817], [92.98026276, 12.94806957], [92.98001862, 12.94807243], [92.98000336, 12.94639015], [92.98001099, 12.94530964], [92.98034668, 12.94530964], [92.98033142, 12.94451046], [92.98003387, 12.94447327], [92.97999573, 12.94224167], [92.98062897, 12.94169712], [92.98114014, 12.94166088], [92.98110199, 12.94086075], [92.98141479, 12.94088268], [92.98141479, 12.94029999], [92.98168945, 12.94026089], [92.98168945, 12.93917561], [92.98249817, 12.93865204], [92.98249817, 12.93808937], [92.98280334, 12.93807125], [92.98282623, 12.93448067], [92.98165131, 12.93334198], [92.98060608, 12.93335533], [92.98060608, 12.93310165], [92.98001099, 12.93306446], [92.98001099, 12.93275356], [92.97918701, 12.93277168], [92.97912598, 12.93335342], [92.97749329, 12.93330097], [92.97749329, 12.93417072], [92.97618866, 12.93416882], [92.97605133, 12.93506336], [92.97556305, 12.93504238], [92.9755249, 12.93533421], [92.97392273, 12.93529034], [92.97392273, 12.93583965], [92.97364807, 12.93583679], [92.97360992, 12.93725491], [92.97336578, 12.93725014], [92.9733429, 12.93777943], [92.97141266, 12.93780041], [92.97115326, 12.93806171], [92.97113037, 12.93867016], [92.97226715, 12.93975067], [92.97306061, 12.93972969], [92.97306061, 12.94029331], [92.97254181, 12.94031143], [92.9724884, 12.94083977], [92.97167206, 12.94083977], [92.97171783, 12.94167042], [92.97226715, 12.94198036], [92.97225189, 12.94309044], [92.97171783, 12.94309044], [92.97138977, 12.94363022], [92.97055817, 12.94359112], [92.97058105, 12.94386196], [92.96949768, 12.94386196], [92.96949768, 12.94446373], [92.96805573, 12.94444561], [92.96805573, 12.94388962], [92.96724701, 12.94388103], [92.96723175, 12.94360924], [92.96528625, 12.94363022], [92.96528625, 12.94332886], [92.96308899, 12.9433403], [92.96308899, 12.94307137], [92.96250153, 12.94308472], [92.96245575, 12.94275475], [92.95804596, 12.94281387], [92.9569397, 12.9416666], [92.95696259, 12.94114971], [92.95641327, 12.94112968], [92.95614624, 12.94083118], [92.95606995, 12.94027042], [92.95420074, 12.9402914], [92.95420074, 12.93999863], [92.95333099, 12.94000053], [92.95333099, 12.94028187], [92.95256042, 12.94026566], [92.9524765, 12.9405756], [92.95195007, 12.94053936], [92.95198822, 12.94112015], [92.95226288, 12.94141006], [92.95249939, 12.94139194], [92.95474243, 12.94143963], [92.95478058, 12.94196129], [92.95500183, 12.94193554], [92.95502472, 12.94261265], [92.95503998, 12.94306183], [92.95556641, 12.94302082], [92.95558929, 12.94391918], [92.95527649, 12.94387817], [92.95533752, 12.94473076], [92.95582581, 12.94470978], [92.95578766, 12.94525528], [92.9561615, 12.94527054], [92.95614624, 12.94642162], [92.95670319, 12.94640064], [92.95729065, 12.94696236], [92.95720673, 12.94754505], [92.95780182, 12.94751072], [92.95781708, 12.94780064], [92.95837402, 12.94781685], [92.959198, 12.94888306], [92.95973206, 12.94894028], [92.95999908, 12.94917011], [92.96003723, 12.94945145], [92.96057129, 12.94948864], [92.96057129, 12.94916058], [92.9625473, 12.94916058], [92.96251678, 12.9486208], [92.96308136, 12.9486351], [92.96308136, 12.9483614], [92.96363068, 12.9483614], [92.96421814, 12.94749069], [92.96586609, 12.94751072], [92.96586609, 12.94721889], [92.96753693, 12.94725609], [92.96785736, 12.94671345], [92.96832275, 12.94671059], [92.96832275, 12.94640064], [92.96918488, 12.94642162], [92.96948242, 12.94585896], [92.9703064, 12.94586086], [92.97032928, 12.94559002], [92.97086334, 12.94561005], [92.971138, 12.94532967], [92.971138, 12.94473267], [92.97143555, 12.94471455], [92.97145081, 12.94418812], [92.97254181, 12.94418812], [92.97254181, 12.94473267], [92.97303009, 12.94473267], [92.97306824, 12.9450407], [92.97389984, 12.94508171], [92.97392273, 12.94532108], [92.97424316, 12.94532967], [92.97415161, 12.94668579], [92.97306824, 12.94781017], [92.97312927, 12.94861031], [92.9733963, 12.94865131], [92.97338867, 12.94919109], [92.97306824, 12.94920921], [92.97309113, 12.94975185], [92.97278595, 12.94971085], [92.97278595, 12.95053101], [92.97305298, 12.95053101], [92.97306824, 12.95111179], [92.97249603, 12.95141983], [92.97251892, 12.9522562], [92.97281647, 12.95226955], [92.97284698, 12.95476055], [92.9723053, 12.95473766], [92.97193146, 12.95528316], [92.971138, 12.95528316], [92.971138, 12.95501041], [92.97058868, 12.95501041], [92.9705658, 12.95471954], [92.96891022, 12.95470047], [92.96891022, 12.95448971], [92.96695709, 12.95445061], [92.96697998, 12.95420265], [92.96556091, 12.95420265], [92.96559906, 12.95448971], [92.96443939, 12.95445061], [92.96444702, 12.95471954], [92.96170044, 12.95468998], [92.96170044, 12.95504093], [92.96112823, 12.95503712], [92.96110535, 12.95554066], [92.96059418, 12.95556068], [92.96061707, 12.95532894], [92.9597702, 12.95528984], [92.95917511, 12.95614243], [92.95862579, 12.95616341], [92.95861816, 12.9563179], [92.95858765, 12.95670986], [92.95786285, 12.95667076], [92.95778656, 12.95695972], [92.95724487, 12.95695782], [92.95635986, 12.95808411], [92.95582581, 12.95804119], [92.95584869, 12.95946121], [92.95531464, 12.95948124], [92.95471954, 12.960042], [92.95474243, 12.96169186], [92.95419312, 12.9619627], [92.95417023, 12.96365166], [92.95391083, 12.96363068], [92.95391083, 12.96418095], [92.95417786, 12.96415997], [92.95417786, 12.96503067], [92.95389557, 12.96498966], [92.95389557, 12.96555328], [92.95423126, 12.96559238], [92.95422363, 12.96572781], [92.95420837, 12.96614075], [92.95443726, 12.96611118], [92.95445251, 12.96665955], [92.95388031, 12.96698856], [92.95388031, 12.9674921], [92.95446777, 12.96811199], [92.95474243, 12.96805477], [92.95472717, 12.96691132], [92.95529938, 12.96695042], [92.95529938, 12.96673965], [92.95584869, 12.96673965], [92.95584869, 12.96695042], [92.95667267, 12.96695042], [92.95670319, 12.96642971], [92.95719147, 12.9661293], [92.95724487, 12.96555328], [92.95754242, 12.96529961], [92.95803833, 12.96531963], [92.95804596, 12.96469975], [92.95889282, 12.96467972], [92.95892334, 12.96500969], [92.96060181, 12.96500969], [92.96055603, 12.96529961], [92.96111298, 12.96527672], [92.96112061, 12.96599293], [92.96112823, 12.96694469], [92.96170044, 12.96694088], [92.96168518, 12.96752739], [92.96167755, 12.96782112], [92.96227264, 12.96778202], [92.96222687, 12.96805096], [92.96278381, 12.9680891], [92.96311951, 12.96833992], [92.96309662, 12.96972084], [92.96250916, 12.97004986], [92.96250916, 12.9705534], [92.96217346, 12.97088432], [92.96063232, 12.97082424], [92.96059418, 12.97113705], [92.96002197, 12.97111607], [92.96004486, 12.97249508], [92.96059418, 12.9725132], [92.96057129, 12.97445297], [92.95974731, 12.97447109], [92.95974731, 12.97473145], [92.95921326, 12.97471046], [92.9588623, 12.97531033], [92.95833588, 12.97528934], [92.95831299, 12.97558117], [92.95726013, 12.97552204], [92.95722198, 12.97610283], [92.95643616, 12.97610283], [92.95641327, 12.97639465], [92.95505524, 12.97639465], [92.95503235, 12.97610283], [92.95475769, 12.97608471], [92.95475769, 12.97695065], [92.95446777, 12.97698021], [92.95446777, 12.97754955], [92.95420837, 12.97752094], [92.95420837, 12.97859192], [92.95388794, 12.97888088], [92.95337677, 12.97889709], [92.95252991, 12.97971344], [92.95251465, 12.98031235], [92.95333862, 12.9803009], [92.95363617, 12.98059082], [92.95365906, 12.9811306], [92.95397186, 12.98139954], [92.95475769, 12.98136139], [92.95469666, 12.98227024], [92.95503235, 12.98250961], [92.95558929, 12.98250008], [92.95558929, 12.98280144], [92.95609283, 12.98281956], [92.95613861, 12.98250961], [92.95668793, 12.98250961], [92.95697021, 12.98307037], [92.95783234, 12.98310661], [92.95780182, 12.98363304], [92.95806122, 12.98365116], [92.95807648, 12.9841938], [92.95833588, 12.98419189], [92.95833588, 12.98476124], [92.95867157, 12.98476124], [92.95864868, 12.98612022], [92.95922089, 12.9864502], [92.95918274, 12.98808193], [92.95974731, 12.98835087], [92.95974731, 12.98891163], [92.96032715, 12.98889065], [92.96034241, 12.98949337], [92.96060181, 12.98974419], [92.96113586, 12.98974419], [92.96195984, 12.98887062], [92.96198273, 12.98830986], [92.96279144, 12.98830986], [92.96282959, 12.9872179], [92.96331787, 12.98696995], [92.96337891, 12.98639107], [92.96363831, 12.98639107], [92.96363831, 12.98585129], [92.96448517, 12.98586369], [92.96446228, 12.98559093], [92.96503448, 12.98555183], [92.96502686, 12.98501015], [92.96553802, 12.98501015], [92.96640778, 12.9839201], [92.96694946, 12.98388386], [92.96696472, 12.98338032], [92.96730042, 12.98305035], [92.9686203, 12.98307037], [92.96864319, 12.98252964], [92.96917725, 12.98252964], [92.96917725, 12.98084068], [92.96808624, 12.98084068], [92.96807098, 12.98055172], [92.96721649, 12.98055172], [92.96723938, 12.97999954], [92.96694946, 12.97973442], [92.96588135, 12.97973442], [92.96586609, 12.97944164], [92.96530914, 12.97944164], [92.96530914, 12.97918892], [92.96450043, 12.97914791], [92.96446228, 12.97779179], [92.96502686, 12.97749996], [92.96501923, 12.9769392], [92.96560669, 12.97695827], [92.96615601, 12.97610283], [92.96747589, 12.97614384], [92.9680481, 12.97556019], [92.96808624, 12.97502041], [92.96865845, 12.97500038], [92.96946716, 12.97416115], [92.96946716, 12.97363853], [92.96864319, 12.97303963], [92.96865845, 12.97224045], [92.96894073, 12.97224236], [92.96889496, 12.97140789], [92.96942902, 12.97113037], [92.9694519, 12.97059441], [92.96974945, 12.9703207], [92.97031403, 12.9703207], [92.97029877, 12.97001076], [92.97083282, 12.97001076], [92.97145844, 12.96915627], [92.97220612, 12.96914005], [92.97220612, 12.96947098], [92.97277832, 12.96944141], [92.97305298, 12.96972084], [92.97305298, 12.96999931], [92.97360992, 12.97055626], [92.97360992, 12.97083378], [92.97362518, 12.97104836], [92.97364807, 12.97141171], [92.97422028, 12.97140789], [92.97418213, 12.97224236], [92.97475433, 12.972785], [92.97527313, 12.97282124], [92.97528839, 12.97362137], [92.97555542, 12.97361183], [92.97638702, 12.97444439], [92.97637177, 12.9747448], [92.97695923, 12.9747448], [92.97695923, 12.97447109], [92.97808838, 12.97443008], [92.97805023, 12.97476101], [92.9786377, 12.97476101], [92.97862244, 12.97448921], [92.97918701, 12.97445965], [92.97917938, 12.97472191], [92.97945404, 12.97471714], [92.97945404, 12.97555065], [92.97975159, 12.97555065], [92.97975159, 12.97611427], [92.9800415, 12.97612953], [92.98001862, 12.97634506], [92.9799881, 12.97669983], [92.97975159, 12.97667694], [92.97978973, 12.97804928], [92.97917938, 12.97836399], [92.97917938, 12.979743], [92.98033905, 12.979743], [92.98032379, 12.98005295], [92.98110962, 12.98005009], [92.98197937, 12.98116016], [92.98282623, 12.98112202], [92.98282623, 12.98085022], [92.98390961, 12.98083019], [92.98475647, 12.98195267], [92.98500824, 12.98195076], [92.98503113, 12.98252106], [92.9855423, 12.98278999], [92.98558044, 12.98335075], [92.98470306, 12.98358059], [92.98503113, 12.98447609], [92.98551941, 12.9847002], [92.98583984, 12.98500061], [92.98613739, 12.98500061], [92.98647308, 12.98446274], [92.98891449, 12.98445606], [92.98887634, 12.98558235], [92.98861694, 12.98558235], [92.9885788, 12.98650265], [92.98808289, 12.98666859], [92.98804474, 12.98692226], [92.98753357, 12.98696136], [92.98749542, 12.98750305], [92.98723602, 12.98750305], [92.98722076, 12.98833275], [92.98670197, 12.98863125], [92.98667908, 12.98913479], [92.98639679, 12.98917103], [92.98638153, 12.9897213], [92.98667908, 12.98974133], [92.98670197, 12.9902401], [92.98612976, 12.9903183], [92.98612976, 12.9905529], [92.98555756, 12.9905529], [92.9852829, 12.99083996], [92.98529816, 12.9925127], [92.98545074, 12.99274731], [92.98560333, 12.9930706], [92.98578644, 12.99325562], [92.98587799, 12.99335098], [92.98693848, 12.99333096], [92.98726654, 12.99282265], [92.98890686, 12.99278164], [92.98886871, 12.99253082], [92.9905777, 12.9925127], [92.99115753, 12.9916811], [92.99169159, 12.99166012], [92.99170685, 12.99142075], [92.99221802, 12.99138546], [92.99252319, 12.99088097], [92.993927, 12.99083996], [92.99446869, 12.99169922], [92.9952774, 12.991642], [92.9952774, 12.9921999], [92.9956131, 12.99253082], [92.99666595, 12.99248981], [92.99804688, 12.99389172], [93.0, 12.99388885], [93.00063324, 12.99437046], [93.00110626, 12.99444103], [93.00108337, 12.99455929], [93.00108337, 12.99518204], [93.0015564, 12.99565983], [93.0013504, 12.99601078], [93.0016861, 12.99635124], [93.00203705, 12.99606991], [93.00283051, 12.99648952], [93.00302887, 12.9968996], [93.00344849, 12.9968996], [93.00364685, 12.99676991], [93.00364685, 12.99627972], [93.00400543, 12.99641895], [93.00400543, 12.99669266], [93.00456238, 12.9966898], [93.00533295, 12.99752045], [93.00723267, 12.99752045], [93.00722504, 12.9968996], [93.00673676, 12.9968996]]], [[[92.89277649, 12.93722057], [92.8928299, 12.93642139], [92.89170074, 12.9364233], [92.89141083, 12.93560982], [92.89061737, 12.93557072], [92.89060211, 12.93531132], [92.89006805, 12.9353199], [92.89006805, 12.93502808], [92.88949585, 12.93504715], [92.88947296, 12.93642139], [92.89002991, 12.9367218], [92.89002991, 12.9372406], [92.89060211, 12.9372406], [92.89061737, 12.93753147], [92.89141083, 12.93753147], [92.89141083, 12.93725967], [92.89277649, 12.93722057]]], [[[92.90142822, 12.94114971], [92.90168762, 12.94083977], [92.90225983, 12.94089031], [92.90228271, 12.9402914], [92.90255737, 12.94031143], [92.90255737, 12.93975067], [92.90280914, 12.9397707], [92.90283966, 12.9391098], [92.90284729, 12.93889141], [92.90312195, 12.93891239], [92.90306854, 12.93834877], [92.90280914, 12.93834877], [92.90252686, 12.93887138], [92.90200043, 12.93895054], [92.90145111, 12.93951416], [92.90145111, 12.94055462], [92.90058136, 12.94056225], [92.9005661, 12.94087219], [92.89975739, 12.94085407], [92.89978027, 12.94111061], [92.90033722, 12.94167042], [92.90145111, 12.94167042], [92.90142822, 12.94114971]]], [[[92.75959778, 12.87759018], [92.76010132, 12.8775692], [92.76004028, 12.87781143], [92.76032257, 12.87779045], [92.76042938, 12.87724972], [92.76006317, 12.87694931], [92.75895691, 12.87699032], [92.75894928, 12.8764286], [92.75871277, 12.87613106], [92.75705719, 12.87613106], [92.75705719, 12.87808037], [92.75699615, 12.87843132], [92.75757599, 12.87839031], [92.75757599, 12.8781004], [92.75843811, 12.87807274], [92.75847626, 12.87786961], [92.75959778, 12.87783146], [92.75959778, 12.87759018]]], [[[92.78555298, 12.89333439], [92.78583527, 12.89305592], [92.78639221, 12.89305973], [92.78666687, 12.8927803], [92.78716278, 12.89306927], [92.78740692, 12.89319038], [92.78801727, 12.89319038], [92.78820038, 12.89317036], [92.78837585, 12.89308834], [92.78868866, 12.89298534], [92.78896332, 12.89298534], [92.78988647, 12.89265156], [92.79017639, 12.89243126], [92.79087067, 12.89197063], [92.79116058, 12.89176369], [92.79164886, 12.89128876], [92.7917099, 12.89096069], [92.79154968, 12.89052105], [92.79135132, 12.89035988], [92.79116058, 12.8901701], [92.79090881, 12.88996792], [92.79088593, 12.88976002], [92.79078674, 12.88907623], [92.79062653, 12.88849068], [92.79055786, 12.88816929], [92.7905426, 12.88797092], [92.7904892, 12.8876543], [92.79040527, 12.88728046], [92.7903595, 12.88691998], [92.7902832, 12.88556194], [92.79055786, 12.88528156], [92.79055786, 12.8847208], [92.79000092, 12.88416672], [92.79000092, 12.8838892], [92.78916931, 12.88305855], [92.78861237, 12.88305855], [92.78833008, 12.88278103], [92.78749847, 12.88278103], [92.78721619, 12.88250065], [92.78666687, 12.88250065], [92.78639221, 12.88222122], [92.78610992, 12.88222313], [92.78583527, 12.88194466], [92.78555298, 12.88194466], [92.78527832, 12.88222313], [92.78499603, 12.88222122], [92.78472137, 12.88250065], [92.78444672, 12.88250065], [92.7841568, 12.88278103], [92.78388977, 12.88278103], [92.78360748, 12.88305855], [92.78333282, 12.88305473], [92.78193665, 12.88444138], [92.78193665, 12.88500118], [92.78166962, 12.88527679], [92.78166962, 12.88583279], [92.78193665, 12.88611126], [92.78194427, 12.88638878], [92.78250122, 12.88694096], [92.78250122, 12.88861084], [92.78221893, 12.88889027], [92.78221893, 12.8894434], [92.78194427, 12.88972092], [92.78194427, 12.89083385], [92.78166962, 12.89110947], [92.78166962, 12.89138985], [92.78194427, 12.89166641], [92.78193665, 12.89194107], [92.78250122, 12.89250183], [92.78277588, 12.89250183], [92.78333282, 12.89305592], [92.78359985, 12.89311028], [92.78366852, 12.89313793], [92.78395081, 12.89323997], [92.78423309, 12.89325047], [92.78555298, 12.89333439]]], [[[92.89370728, 12.89856434], [92.89380646, 12.8985014], [92.89393616, 12.8985033], [92.89391327, 12.89825439], [92.89389801, 12.89799023], [92.8937912, 12.89776039], [92.8936615, 12.89754963], [92.89353943, 12.89745045], [92.89328766, 12.89741135], [92.89305115, 12.89735031], [92.89276123, 12.89735031], [92.89245605, 12.89732933], [92.89231873, 12.89730167], [92.89206696, 12.89728069], [92.89169312, 12.89740181], [92.89156342, 12.89757347], [92.89151764, 12.89785957], [92.89151764, 12.8983593], [92.89154053, 12.89847088], [92.89162445, 12.89869022], [92.89173126, 12.89879036], [92.89176941, 12.8989563], [92.89176941, 12.89912319], [92.89167023, 12.89938927], [92.89203644, 12.89982891], [92.89227295, 12.89991093], [92.89263153, 12.89986992], [92.89282227, 12.89977932], [92.89292908, 12.89962006], [92.8931427, 12.89960098], [92.89325714, 12.89949036], [92.89330292, 12.89939213], [92.89330292, 12.89926624], [92.89346313, 12.89912128], [92.89363861, 12.89908218], [92.89368439, 12.89897919], [92.89367676, 12.89879036], [92.89370728, 12.89856434]]], [[[92.75508118, 12.91281128], [92.75505829, 12.91225338], [92.75538635, 12.91225338], [92.75540161, 12.91141415], [92.75566864, 12.91139412], [92.75566864, 12.91059589], [92.75591278, 12.91060066], [92.75595093, 12.91002178], [92.75617218, 12.91002178], [92.75617218, 12.90922165], [92.7564621, 12.90922165], [92.75647736, 12.90864086], [92.75727081, 12.90864086], [92.75728607, 12.90784073], [92.7575531, 12.90784073], [92.75759125, 12.90477085], [92.75731659, 12.90477085], [92.75730896, 12.90309143], [92.75704956, 12.90311146], [92.75701904, 12.90004063], [92.75699615, 12.89810181], [92.75669861, 12.89810181], [92.75675201, 12.89447975], [92.75645447, 12.89448261], [92.75645447, 12.8928051], [92.75591278, 12.89253235], [92.75592804, 12.89141273], [92.75512695, 12.89115047], [92.75479126, 12.89089108], [92.75480652, 12.89006996], [92.7545166, 12.88977242], [92.7539978, 12.88975143], [92.75397491, 12.88947296], [92.75341034, 12.88948441], [92.75341034, 12.88920593], [92.75312805, 12.8892107], [92.75311279, 12.8900404], [92.75284576, 12.89002514], [92.75286865, 12.89142418], [92.75231934, 12.89146328], [92.75175476, 12.89056492], [92.75092316, 12.89060307], [92.75090027, 12.89034367], [92.7503891, 12.89032459], [92.75032806, 12.89058304], [92.74982452, 12.89060307], [92.74978638, 12.89112282], [92.74923706, 12.89116192], [92.74923706, 12.89198017], [92.74894714, 12.89200974], [92.74893951, 12.89261055], [92.74840546, 12.8928051], [92.74840546, 12.89337254], [92.74871063, 12.89336109], [92.748703, 12.89504147], [92.74897766, 12.89505672], [92.74895477, 12.89615345], [92.74925995, 12.89619446], [92.7492218, 12.89671421], [92.74980927, 12.89671421], [92.74980927, 12.89701176], [92.75039673, 12.89697361], [92.75037384, 12.89675331], [92.75175476, 12.89669323], [92.75173187, 12.8953352], [92.75202179, 12.89534187], [92.75205994, 12.89422035], [92.75228119, 12.89398098], [92.75285339, 12.89392185], [92.75341797, 12.89339066], [92.75341034, 12.89310074], [92.75341034, 12.89282131], [92.75367737, 12.89282131], [92.75367737, 12.89312172], [92.75396729, 12.89310074], [92.75399017, 12.89364243], [92.75366211, 12.89365959], [92.75370789, 12.89500046], [92.75337982, 12.89501572], [92.7534256, 12.89561462], [92.75312042, 12.89561462], [92.75312805, 12.89587307], [92.75370026, 12.89639187], [92.75422668, 12.89643097], [92.75426483, 12.89695072], [92.75450897, 12.89697075], [92.75454712, 12.89754295], [92.75479889, 12.89754105], [92.75479889, 12.89810181], [92.75534821, 12.8980608], [92.75538635, 12.90087986], [92.75504303, 12.90087986], [92.75508118, 12.90118122], [92.75454712, 12.90116024], [92.75453186, 12.90067005], [92.75422668, 12.90060043], [92.7542572, 12.90034008], [92.75367737, 12.90034008], [92.75367737, 12.90111923], [92.75340271, 12.90114021], [92.75341797, 12.90174198], [92.75366211, 12.90169621], [92.753685, 12.90337276], [92.75396729, 12.90337276], [92.75396729, 12.90476131], [92.75337219, 12.90502071], [92.75341797, 12.90532207], [92.75370026, 12.90534019], [92.75367737, 12.90837193], [92.7542572, 12.9086504], [92.75422668, 12.90891171], [92.75390625, 12.90891171], [92.75401306, 12.9105711], [92.75455475, 12.91085625], [92.75453186, 12.91169453], [92.75396729, 12.91197014], [92.75396729, 12.91310978], [92.75479889, 12.91309166], [92.75508118, 12.91281128]]], [[[92.86476135, 12.91248131], [92.86421204, 12.91248131], [92.86421204, 12.91276073], [92.86307526, 12.91364765], [92.86309814, 12.9144249], [92.86420441, 12.9144249], [92.86476135, 12.91414738], [92.86503601, 12.9138689], [92.86503601, 12.91302967], [92.86476135, 12.91275883], [92.86476135, 12.91248131]]], [[[92.69565582, 12.99195862], [92.69563293, 12.99141598], [92.69618988, 12.99142075], [92.69650269, 12.9910717], [92.69651031, 12.99001026], [92.6967392, 12.989748], [92.6973114, 12.98969078], [92.6973114, 12.98918533], [92.69838715, 12.98920059], [92.69843292, 12.98891163], [92.70011139, 12.98891163], [92.7000885, 12.98834038], [92.70040894, 12.98834419], [92.70038605, 12.98801804], [92.70172119, 12.98805046], [92.70227814, 12.98891163], [92.70318604, 12.98891163], [92.70343781, 12.98857021], [92.70342255, 12.98726177], [92.70452118, 12.98722458], [92.70454407, 12.98752403], [92.70648193, 12.98750496], [92.70643616, 12.98612022], [92.70700073, 12.98612022], [92.70701599, 12.98585129], [92.7081604, 12.98583031], [92.70844269, 12.98609924], [92.7084198, 12.98696136], [92.70900726, 12.98694038], [92.70900726, 12.98668003], [92.7095108, 12.9866581], [92.70954895, 12.98718166], [92.70870972, 12.98777199], [92.70870972, 12.98837185], [92.71037292, 12.98833275], [92.71037292, 12.98810005], [92.71092224, 12.9880476], [92.71103668, 12.98750973], [92.71066284, 12.98749161], [92.71063232, 12.98556995], [92.71118927, 12.9855566], [92.71118927, 12.98473167], [92.71234131, 12.98469067], [92.7122879, 12.98418045], [92.71283722, 12.98414135], [92.71282196, 12.98448086], [92.7145462, 12.98441029], [92.7145462, 12.98301983], [92.71341705, 12.98311138], [92.71341705, 12.98258018], [92.71395874, 12.98252773], [92.71395874, 12.98227024], [92.7145462, 12.98222923], [92.71453094, 12.98255062], [92.71504211, 12.98250961], [92.71508789, 12.98167992], [92.7157135, 12.98110294], [92.71677399, 12.98107433], [92.71677399, 12.98023987], [92.71704865, 12.98024178], [92.71704865, 12.98079967], [92.71788788, 12.98079967], [92.71927643, 12.97941017], [92.71929169, 12.97919083], [92.71872711, 12.97919083], [92.71871948, 12.97865963], [92.71901703, 12.97840023], [92.71988678, 12.97835922], [92.719841, 12.97751808], [92.71927643, 12.97746086], [92.71923828, 12.97613335], [92.72003174, 12.97611427], [92.72041321, 12.97579479], [92.72038269, 12.97528934], [92.72003937, 12.97531033], [92.72006989, 12.97391987], [92.71959686, 12.97360039], [92.71953583, 12.9722147], [92.71929169, 12.9722147], [92.71925354, 12.97142601], [92.71955872, 12.97114563], [92.72009277, 12.97113037], [92.72009277, 12.97058105], [92.71952057, 12.97058296], [92.71925354, 12.97030258], [92.71927643, 12.96972084], [92.71983337, 12.96942043], [92.7197876, 12.96863365], [92.72013092, 12.96863365], [92.72009277, 12.96751118], [92.71980286, 12.96751118], [92.719841, 12.96695042], [92.71959686, 12.96692944], [92.71953583, 12.96614075], [92.71982574, 12.96614075], [92.71982574, 12.96559811], [92.71924591, 12.96562099], [92.71923828, 12.96529961], [92.71980286, 12.96528244], [92.719841, 12.96500969], [92.71925354, 12.96477318], [92.71925354, 12.96415615], [92.71893311, 12.96417427], [92.71894836, 12.96331024], [92.71982574, 12.9627676], [92.71985626, 12.96222115], [92.71931458, 12.96226215], [92.71927643, 12.96166229], [92.71957397, 12.96166229], [92.71957397, 12.96111774], [92.71901703, 12.96111965], [92.71871948, 12.96079159], [92.71872711, 12.95974064], [92.71811676, 12.95974064], [92.71814728, 12.95915985], [92.71843719, 12.95887947], [92.71843719, 12.95835114], [92.71815491, 12.95835304], [92.71813965, 12.95782948], [92.71844482, 12.95788574], [92.71844482, 12.95728397], [92.71813965, 12.95724964], [92.71814728, 12.95667076], [92.71785736, 12.95639992], [92.71788788, 12.95610428], [92.71811676, 12.95610428], [92.71815491, 12.9552784], [92.7175827, 12.95528126], [92.7175827, 12.95499992], [92.71707153, 12.9550209], [92.71704102, 12.95459461], [92.7170105, 12.95417118], [92.71754456, 12.95385647], [92.71761322, 12.95252132], [92.71730042, 12.95254326], [92.71731567, 12.95136261], [92.71704865, 12.95135212], [92.71704865, 12.95079517], [92.71761322, 12.95023918], [92.71760559, 12.94996357], [92.71704865, 12.94940662], [92.71733093, 12.94913197], [92.71733093, 12.94885063], [92.71621704, 12.94774055], [92.71621704, 12.94691181], [92.71598053, 12.94639015], [92.71511078, 12.94581985], [92.71509552, 12.94529819], [92.71482849, 12.9453001], [92.71479797, 12.94473076], [92.71448517, 12.94469643], [92.71457672, 12.94365025], [92.7148819, 12.94363022], [92.71482849, 12.94310093], [92.71452332, 12.94280529], [92.71453857, 12.94225979], [92.71508789, 12.94224167], [92.71511078, 12.94198036], [92.71570587, 12.94196129], [92.71566772, 12.94222355], [92.71617889, 12.94224167], [92.71620178, 12.94254303], [92.7167511, 12.94254303], [92.71676636, 12.94228077], [92.7173233, 12.94224167], [92.71733856, 12.94254303], [92.71785736, 12.94254017], [92.71790314, 12.94307137], [92.71840668, 12.94309044], [92.71842957, 12.94363022], [92.71895599, 12.94394875], [92.71901703, 12.94449139], [92.71926117, 12.94449139], [92.71926117, 12.94535255], [92.71955109, 12.94532108], [92.7195282, 12.94584274], [92.71977997, 12.94586086], [92.71981812, 12.94648075], [92.72011566, 12.94645786], [92.72007751, 12.94698238], [92.72064972, 12.94698238], [92.72064972, 12.94643974], [92.72122192, 12.94645977], [92.72122192, 12.94556046], [92.72146606, 12.94556046], [92.72148895, 12.94498062], [92.72181702, 12.94499969], [92.7217865, 12.94447136], [92.72122192, 12.94390965], [92.72124481, 12.94362831], [92.72145081, 12.94363022], [92.72146606, 12.9430809], [92.72093964, 12.94301891], [92.72088623, 12.94083977], [92.72146606, 12.94086266], [92.72144318, 12.94003963], [92.72177124, 12.94000053], [92.72174835, 12.93897057], [92.72094727, 12.93890095], [92.72093964, 12.93691063], [92.72093964, 12.93580055], [92.7206955, 12.9358511], [92.72065735, 12.93393898], [92.72041321, 12.93390179], [92.72035217, 12.93171024], [92.72064209, 12.93168926], [92.7206192, 12.93114662], [92.72093964, 12.93115234], [92.72097778, 12.92971992], [92.7206192, 12.92976093], [92.7206192, 12.92897034], [92.72088623, 12.92895412], [92.72093964, 12.92811108], [92.7206192, 12.92811108], [92.72064209, 12.92778969], [92.72148895, 12.92784023], [92.72154999, 12.92697239], [92.72097778, 12.92673016], [92.72093964, 12.92530632], [92.72064972, 12.92525959], [92.72061157, 12.92420006], [92.7201004, 12.92420006], [92.7201004, 12.92390156], [92.71956635, 12.92391968], [92.7195282, 12.92362118], [92.71898651, 12.9236393], [92.71894073, 12.9233408], [92.71842194, 12.92339134], [92.71842194, 12.92361927], [92.71756744, 12.92369366], [92.71762848, 12.92333889], [92.71649933, 12.92337513], [92.71646118, 12.92307663], [92.71566772, 12.92308998], [92.71566772, 12.92253017], [92.71640015, 12.92257118], [92.71676636, 12.92198944], [92.71779633, 12.92197132], [92.71871185, 12.92087936], [92.71951294, 12.92086411], [92.71951294, 12.92032146], [92.71982574, 12.92024136], [92.71981049, 12.91754055], [92.72009277, 12.91754055], [92.72009277, 12.916399], [92.71983337, 12.91642094], [92.71981049, 12.91501141], [92.72001648, 12.91501141], [92.72007751, 12.91420555], [92.71981049, 12.91422367], [92.71982574, 12.91334248], [92.72007751, 12.91338062], [92.72009277, 12.91279984], [92.71983337, 12.91281986], [92.71983337, 12.91222095], [92.72009277, 12.91226196], [92.72012329, 12.91141033], [92.71982574, 12.9111681], [92.71981049, 12.91058922], [92.72032166, 12.91031075], [92.72035217, 12.90892124], [92.72064209, 12.90894985], [92.72065735, 12.90723038], [92.72093201, 12.90723038], [92.72094727, 12.90671921], [92.72149658, 12.90616131], [92.72228241, 12.90616131], [92.72232056, 12.90531063], [92.72264862, 12.90533066], [92.72261047, 12.90138054], [92.72232819, 12.90141296], [92.7223053, 12.90034389], [92.72177124, 12.90034389], [92.72171783, 12.89980221], [92.72122192, 12.89976311], [92.72119904, 12.89923859], [92.72171783, 12.89924145], [92.72177124, 12.89860058], [92.72200012, 12.8986311], [92.72200012, 12.8978014], [92.72232819, 12.8978014], [92.72231293, 12.89697075], [92.72180939, 12.89669132], [92.72177124, 12.89587116], [92.72207642, 12.89587116], [92.72203827, 12.89532089], [92.72173309, 12.89532089], [92.72175598, 12.89339066], [92.72149658, 12.89341068], [92.72149658, 12.89281178], [92.72173309, 12.89281178], [92.72174835, 12.89198017], [92.72148132, 12.89196396], [92.72149658, 12.88834476], [92.72094727, 12.88834858], [92.72094727, 12.88673115], [92.72033691, 12.88673306], [92.72045135, 12.88309765], [92.71981812, 12.88307953], [92.71980286, 12.88256931], [92.71952057, 12.88253498], [92.71956635, 12.88171005], [92.71895599, 12.88113976], [92.71818542, 12.88114738], [92.71785736, 12.88062286], [92.71593475, 12.88058662], [92.71534729, 12.88141155], [92.71479797, 12.8814497], [92.7145462, 12.88171005], [92.71450806, 12.88224125], [92.71399689, 12.88253975], [92.71399689, 12.88301754], [92.71343231, 12.8831234], [92.71343231, 12.88331032], [92.71202087, 12.88336658], [92.71205139, 12.88361073], [92.71154785, 12.88364983], [92.7115097, 12.88339043], [92.71012115, 12.88340092], [92.71003723, 12.88364983], [92.70952606, 12.88366795], [92.70948792, 12.88391209], [92.70868683, 12.88391209], [92.70870972, 12.88334942], [92.70955658, 12.88339043], [92.70955658, 12.88309097], [92.71009827, 12.88309097], [92.71008301, 12.88282013], [92.71143341, 12.8828249], [92.71181488, 12.88226223], [92.71232605, 12.88228035], [92.71227264, 12.88112736], [92.71257782, 12.88111973], [92.7125473, 12.87947178], [92.71286011, 12.87947178], [92.71286011, 12.87894058], [92.71316528, 12.87892532], [92.71317291, 12.87755966], [92.71733093, 12.87754154], [92.7173233, 12.87786102], [92.71785736, 12.87786102], [92.71807861, 12.87782192], [92.71895599, 12.8769989], [92.71897125, 12.8758707], [92.71927643, 12.8758297], [92.71929169, 12.87478447], [92.71955872, 12.87478447], [92.71952057, 12.87422085], [92.71898651, 12.87420273], [92.71897125, 12.87335873], [92.71869659, 12.87336159], [92.71869659, 12.87280083], [92.71842194, 12.87282181], [92.71843719, 12.8719902], [92.71790314, 12.87169075], [92.71785736, 12.87117195], [92.71729279, 12.87115097], [92.7173233, 12.87061977], [92.71704865, 12.87060356], [92.71702576, 12.87005901], [92.71647644, 12.8695097], [92.71591949, 12.86948013], [92.71591949, 12.86753178], [92.71563721, 12.8675499], [92.71569061, 12.86670017], [92.71510315, 12.86670208], [92.71510315, 12.86612129], [92.71483612, 12.86614132], [92.71479797, 12.86502934], [92.71451569, 12.8650341], [92.71453094, 12.86280346], [92.71395874, 12.86282063], [92.7137146, 12.862463], [92.71372986, 12.86170197], [92.71340179, 12.86172009], [92.71341705, 12.86115932], [92.71259308, 12.86058044], [92.71259308, 12.86003113], [92.71228027, 12.85976887], [92.71173859, 12.8597393], [92.7117691, 12.85950661], [92.71121216, 12.85951138], [92.7111969, 12.85889244], [92.71038055, 12.85885143], [92.71038055, 12.85811234], [92.71009827, 12.85779285], [92.70925903, 12.8578701], [92.708992, 12.85755062], [92.708992, 12.85616112], [92.70868683, 12.85616112], [92.70844269, 12.85586262], [92.70844269, 12.85531807], [92.70732117, 12.85531998], [92.70732117, 12.85449123], [92.70703125, 12.85419369], [92.70619202, 12.85421944], [92.70590973, 12.853652], [92.7053833, 12.8536911], [92.70482635, 12.85281086], [92.70343781, 12.85284519], [92.70343781, 12.85228157], [92.70313263, 12.85228157], [92.70314026, 12.85189533], [92.70314789, 12.85170078], [92.70285797, 12.8517189], [92.70288086, 12.8511219], [92.70259857, 12.85087967], [92.70263672, 12.84838009], [92.70230865, 12.84838486], [92.70230865, 12.84782219], [92.70288086, 12.84727669], [92.70339966, 12.84729958], [92.70343781, 12.8467207], [92.70372009, 12.84669971], [92.70375824, 12.845891], [92.70340729, 12.845891], [92.70343781, 12.8448019], [92.70314789, 12.84480381], [92.70314789, 12.8442049], [92.70257568, 12.8442049], [92.70256042, 12.84337997], [92.70230865, 12.84338188], [92.70230865, 12.84286022], [92.70173645, 12.84255028], [92.70178223, 12.84200954], [92.70123291, 12.84171104], [92.70122528, 12.84120464], [92.70037079, 12.84116745], [92.70040131, 12.84032059], [92.6995697, 12.84034157], [92.6995697, 12.83974171], [92.69898224, 12.83976269], [92.69896698, 12.83963108], [92.69895935, 12.83949757], [92.69841003, 12.8394804], [92.69844818, 12.83922005], [92.6975708, 12.83924103], [92.69676971, 12.83810997], [92.69623566, 12.83809376], [92.69623566, 12.8377943], [92.69454193, 12.83781242], [92.69456482, 12.83753109], [92.69393158, 12.83753109], [92.69393158, 12.83698654], [92.69429779, 12.83701038], [92.69425964, 12.83643055], [92.69400787, 12.83615017], [92.69345856, 12.83614254], [92.69343567, 12.83558273], [92.69315338, 12.83531761], [92.69204712, 12.83532143], [92.69204712, 12.83502197], [92.69036865, 12.83504009], [92.69037628, 12.83552074], [92.68982697, 12.83552074], [92.68982697, 12.83449078], [92.68871307, 12.8345089], [92.68868256, 12.83476925], [92.68735504, 12.83478737], [92.68702698, 12.83531189], [92.68596649, 12.83533001], [92.6859436, 12.83557415], [92.68539429, 12.8356123], [92.6853714, 12.83589268], [92.68479919, 12.83589268], [92.68482208, 12.83559418], [92.68373871, 12.8356123], [92.6834259, 12.83586121], [92.6834259, 12.83642197], [92.68287659, 12.83644199], [92.68257141, 12.83668137], [92.6825943, 12.83728123], [92.68228912, 12.83751965], [92.68177795, 12.83756065], [92.6817627, 12.83782101], [92.68122101, 12.83786201], [92.68120575, 12.83810425], [92.68016052, 12.83808994], [92.68013763, 12.83837032], [92.67926788, 12.83840179], [92.67926788, 12.83810139], [92.67874908, 12.83810139], [92.67871094, 12.83787823], [92.67791748, 12.83784103], [92.6776123, 12.83730125], [92.67713165, 12.83730125], [92.67713165, 12.8370409], [92.67620087, 12.83702087], [92.67623138, 12.8359108], [92.67539978, 12.83588791], [92.67538452, 12.83534622], [92.6765213, 12.83421993], [92.67730713, 12.8341856], [92.67732239, 12.83365917], [92.67758942, 12.83364105], [92.67758942, 12.83313274], [92.67787933, 12.83313465], [92.67791748, 12.83148479], [92.67758942, 12.83143044], [92.6776123, 12.83094025], [92.6765213, 12.83088589], [92.67648315, 12.83034134], [92.6770401, 12.83006001], [92.67707825, 12.82920074], [92.67736053, 12.82924175], [92.67735291, 12.82866955], [92.67701721, 12.82865429], [92.6770401, 12.82782936], [92.67739868, 12.82785034], [92.67732239, 12.82734108], [92.6770401, 12.82707882], [92.67701721, 12.825881], [92.67675018, 12.825881], [92.67677307, 12.8251009], [92.67627716, 12.82476139], [92.67624664, 12.82423019], [92.67597198, 12.82426929], [92.67597198, 12.82341003], [92.67650604, 12.82338715], [92.67648315, 12.82421207], [92.6770401, 12.82479286], [92.67785645, 12.82479095], [92.67784119, 12.82505989], [92.67897797, 12.82505989], [92.67897797, 12.82533646], [92.67951202, 12.82536983], [92.6798172, 12.82566166], [92.67983246, 12.82676029], [92.680336, 12.82671928], [92.68062592, 12.82726192], [92.68118286, 12.82731628], [92.68148804, 12.82756042], [92.68152618, 12.82814121], [92.68202209, 12.82814121], [92.68229675, 12.82842159], [92.68229675, 12.82897091], [92.68308258, 12.82896614], [92.68341064, 12.82949066], [92.68479919, 12.82949066], [92.68565369, 12.82865047], [92.68564606, 12.82811165], [92.68595886, 12.82811165], [92.68596649, 12.82748985], [92.68622589, 12.82730007], [92.68678284, 12.82728004], [92.68725586, 12.82670116], [92.68727112, 12.82616138], [92.6867981, 12.82616138], [92.6867981, 12.82563019], [92.68649292, 12.82569122], [92.68644714, 12.82452202], [92.68595886, 12.82448769], [92.68593597, 12.82395935], [92.68621063, 12.82366276], [92.68673706, 12.82371998], [92.68673706, 12.82199001], [92.68706512, 12.82199478], [92.68704987, 12.82002544], [92.68813324, 12.82005119], [92.68842316, 12.81976128], [92.68843842, 12.81869698], [92.68868256, 12.8186903], [92.68868256, 12.81813145], [92.68897247, 12.81809711], [92.68901062, 12.81672955], [92.68843842, 12.81671238], [92.68843842, 12.81643105], [92.68763733, 12.81647015], [92.68759918, 12.81620121], [92.68786621, 12.81592083], [92.68788147, 12.81530285], [92.68813324, 12.81534195], [92.68817139, 12.81476116], [92.68843079, 12.81474018], [92.68842316, 12.81421089], [92.68791962, 12.81423187], [92.68788147, 12.81395245], [92.68739319, 12.81395245], [92.68734741, 12.81282139], [92.68708038, 12.81280518], [92.68681335, 12.8131237], [92.68624878, 12.81314182], [92.68592072, 12.81284237], [92.6859436, 12.81227875], [92.68344879, 12.81226254], [92.68344879, 12.81033039], [92.68310547, 12.81033039], [92.68312073, 12.80978966], [92.68314362, 12.8092432], [92.68257141, 12.80922508], [92.68258667, 12.80894184], [92.68038177, 12.80894375], [92.68038177, 12.8092432], [92.67914581, 12.80923557], [92.67708588, 12.80922508], [92.67649841, 12.80869961], [92.67648315, 12.80812168], [92.67594147, 12.80812168], [92.67591095, 12.80782318], [92.67536163, 12.8078413], [92.67536163, 12.80728054], [92.67513275, 12.80725956], [92.67508698, 12.80673122], [92.67539978, 12.80673122], [92.67539978, 12.80476379], [92.67514801, 12.80476379], [92.67513275, 12.80427742], [92.67487335, 12.80428123], [92.67484283, 12.80255127], [92.67429352, 12.80230713], [92.674263, 12.80087185], [92.6737442, 12.80090332], [92.67368317, 12.80004025], [92.67314911, 12.79975891], [92.67314911, 12.79920101], [92.67259216, 12.79897118], [92.67263794, 12.79841042], [92.673172, 12.79841042], [92.67314911, 12.79755116], [92.67262268, 12.79755116], [92.67263794, 12.79618073], [92.67234802, 12.79618073], [92.67233276, 12.79505062], [92.67204285, 12.79505539], [92.67204285, 12.79430485], [92.67206573, 12.79419136], [92.67177582, 12.79415512], [92.67177582, 12.79309273], [92.67198944, 12.79311085], [92.67202759, 12.79227924], [92.67177582, 12.79230022], [92.67176056, 12.79172134], [92.67153168, 12.79174137], [92.6714859, 12.79112053], [92.67094421, 12.79117393], [92.67095947, 12.79061794], [92.6706543, 12.79061317], [92.67063904, 12.7889452], [92.67009735, 12.78899956], [92.67015839, 12.78839111], [92.66983795, 12.78838158], [92.66983795, 12.78729534], [92.66957092, 12.78730202], [92.66957092, 12.78532791], [92.66927338, 12.78530979], [92.66929626, 12.78391933], [92.66896057, 12.7839222], [92.66899872, 12.78335857], [92.66867828, 12.78338146], [92.66867828, 12.78253078], [92.66815948, 12.78257179], [92.66789246, 12.78283024], [92.66789246, 12.78336143], [92.66758728, 12.78338146], [92.66761017, 12.78396034], [92.66741943, 12.78400135], [92.66730499, 12.78757477], [92.66757202, 12.78761196], [92.66761017, 12.78893089], [92.66781616, 12.7889061], [92.66791534, 12.79001141], [92.66761017, 12.79001141], [92.66758728, 12.79057407], [92.66731262, 12.79063129], [92.66732788, 12.7911396], [92.66703796, 12.7914381], [92.66649628, 12.79146957], [92.66649628, 12.79172134], [92.66594696, 12.79172134], [92.66591644, 12.79201698], [92.66538239, 12.79203129], [92.66532898, 12.79230022], [92.66452789, 12.79230022], [92.66454315, 12.79254436], [92.66339874, 12.79369545], [92.66288757, 12.79366016], [92.66285706, 12.79396057], [92.66233063, 12.79396057], [92.66227722, 12.79428005], [92.66094208, 12.79423714], [92.66094208, 12.7947607], [92.66176605, 12.7947998], [92.66179657, 12.79508018], [92.66098022, 12.79510117], [92.66065979, 12.79564285], [92.66013336, 12.79561138], [92.66013336, 12.79673004], [92.66094208, 12.79675102], [92.66094208, 12.79619026], [92.66127014, 12.7958889], [92.66174316, 12.79592419], [92.66175842, 12.79578209], [92.66178131, 12.79560661], [92.66313171, 12.79561138], [92.66343689, 12.79591179], [92.66345978, 12.79647064], [92.66374207, 12.79673004], [92.66429138, 12.79671001], [92.66429138, 12.79754162], [92.6645813, 12.79754162], [92.6645813, 12.79810047], [92.66512299, 12.79808044], [92.66509247, 12.79979134], [92.66568756, 12.80008507], [92.66565704, 12.80087185], [92.6659317, 12.80091], [92.6659317, 12.80144119], [92.66622162, 12.80144119], [92.66623688, 12.80314159], [92.66673279, 12.80312061], [92.66677094, 12.8042469], [92.66649628, 12.80426121], [92.66649628, 12.80579662], [92.66649628, 12.80607033], [92.66620636, 12.80615902], [92.66620636, 12.80893326], [92.66565704, 12.80921268], [92.66565704, 12.80983067], [92.66596222, 12.80979443], [92.66590881, 12.81086254], [92.66573334, 12.81086063], [92.66567993, 12.81224918], [92.66426849, 12.81339264], [92.66428375, 12.81401062], [92.66401672, 12.81398964], [92.66397858, 12.81447983], [92.66368866, 12.81478119], [92.66316223, 12.81479931], [92.66230774, 12.81561089], [92.66234589, 12.81618977], [92.66177368, 12.81644726], [92.66172028, 12.81699181], [92.66150665, 12.81697083], [92.66149139, 12.81782246], [92.66122437, 12.81783485], [92.66120148, 12.81843472], [92.66091919, 12.81843472], [92.66093445, 12.8195219], [92.66122437, 12.81954002], [92.66122437, 12.82087135], [92.66150665, 12.82086182], [92.66149139, 12.82170105], [92.66118622, 12.82170105], [92.66123199, 12.8258009], [92.66091156, 12.82588959], [92.66092682, 12.82701588], [92.66064453, 12.827034], [92.66064453, 12.8275404], [92.66010284, 12.8278017], [92.66011047, 12.8289299], [92.65982819, 12.8289299], [92.65982819, 12.82946968], [92.65927124, 12.82983017], [92.65927124, 12.83030033], [92.65872192, 12.83029461], [92.65872192, 12.83063316], [92.65812683, 12.83065128], [92.65814972, 12.83116055], [92.6576004, 12.83116055], [92.6576004, 12.83144188], [92.65648651, 12.8314209], [92.65647888, 12.83172035], [92.65679932, 12.83177662], [92.65676117, 12.83258343], [92.65645599, 12.83253098], [92.65648651, 12.83330059], [92.65625, 12.83337021], [92.65621185, 12.83393002], [92.6556778, 12.833951], [92.65538788, 12.83426952], [92.65533447, 12.83479404], [92.6550827, 12.83477592], [92.65510559, 12.83588123], [92.65480804, 12.83586121], [92.65480804, 12.83640957], [92.65426636, 12.83668995], [92.65426636, 12.83755016], [92.65367889, 12.83782768], [92.65377045, 12.83923244], [92.65345001, 12.83924961], [92.65346527, 12.84003925], [92.65313721, 12.84008026], [92.65319824, 12.84142685], [92.65286255, 12.8414402], [92.65287781, 12.84198856], [92.65259552, 12.84202576], [92.65259552, 12.84309483], [92.65206146, 12.8434124], [92.65202332, 12.84476089], [92.65148926, 12.84502983], [92.6515274, 12.84556961], [92.65118408, 12.84582996], [92.65119934, 12.84671211], [92.65096283, 12.84671021], [92.65097809, 12.84808159], [92.65119934, 12.84807873], [92.65116882, 12.84864044], [92.65091705, 12.84866047], [92.65091705, 12.84976959], [92.65122223, 12.84976959], [92.65119934, 12.85227966], [92.65091705, 12.8522768], [92.6509552, 12.85394573], [92.65065765, 12.85396194], [92.65065765, 12.85447025], [92.65036774, 12.85449123], [92.650383, 12.85523987], [92.65010071, 12.85531139], [92.65011597, 12.85614109], [92.64981079, 12.85617924], [92.64982605, 12.85674], [92.65011597, 12.85674], [92.65013885, 12.85726357], [92.64981079, 12.85726166], [92.64982605, 12.85811043], [92.64956665, 12.85808945], [92.64956665, 12.85948181], [92.64923859, 12.85946083], [92.64926147, 12.86060143], [92.64846039, 12.86058044], [92.64844513, 12.86116219], [92.64816284, 12.86115932], [92.64821625, 12.86171055], [92.6509552, 12.86166763], [92.65120697, 12.86204147], [92.65126801, 12.86364079], [92.65148163, 12.86364079], [92.65151978, 12.8644619], [92.6512146, 12.86449814], [92.65122986, 12.86697102], [92.65122986, 12.86782074], [92.6517868, 12.86782074], [92.65181732, 12.86697102], [92.65205383, 12.866992], [92.65209198, 12.86671066], [92.65290833, 12.86674786], [92.65292358, 12.866992], [92.65401459, 12.86703014], [92.65401459, 12.8672924], [92.65444946, 12.86728096], [92.65645599, 12.86919117], [92.65648651, 12.86973953], [92.65679169, 12.87002087], [92.65733337, 12.87004089], [92.65814209, 12.87089825], [92.65816498, 12.87142467], [92.65843201, 12.87141991], [92.65844727, 12.87198544], [92.65899658, 12.87226105], [92.65901947, 12.87274933], [92.65901947, 12.87283134], [92.65926361, 12.87282753], [92.65932465, 12.87335491], [92.6600647, 12.87337303], [92.6600647, 12.87395382], [92.66035461, 12.87391567], [92.66036987, 12.87532234], [92.66094208, 12.87561131], [92.66094208, 12.8764267], [92.66123199, 12.87650013], [92.66123199, 12.87691021], [92.66317749, 12.87868118], [92.66316223, 12.87914181], [92.66075134, 12.87880421], [92.65894318, 12.87855434], [92.65772247, 12.87895012], [92.62985229, 12.8807869], [92.62988281, 12.88273144], [92.65854645, 12.88077068], [92.65968323, 12.88016987], [92.6607132, 12.88056183], [92.66265869, 12.88080978], [92.66372681, 12.88057995], [92.66454315, 12.88059998], [92.66454315, 12.88169193], [92.6651001, 12.88171005], [92.66512299, 12.88201141], [92.66454315, 12.88201141], [92.66454315, 12.88281059], [92.6651001, 12.88280869], [92.6651001, 12.88365173], [92.66539001, 12.88363171], [92.66536713, 12.88529968], [92.66593933, 12.88531971], [92.66593933, 12.88669014], [92.66645813, 12.88698196], [92.66652679, 12.88836098], [92.66593933, 12.88834], [92.66597748, 12.88864136], [92.66653442, 12.88889885], [92.66657257, 12.89110947], [92.66620636, 12.89119053], [92.66622925, 12.89171124], [92.66591644, 12.89172935], [92.66593933, 12.89339066], [92.66563416, 12.8933773], [92.6656723, 12.89390373], [92.66593933, 12.89420223], [92.66649628, 12.89420223], [92.66674042, 12.89446354], [92.66676331, 12.89508438], [92.66706085, 12.89501095], [92.66706085, 12.89558983], [92.66732788, 12.89555073], [92.66731262, 12.89587116], [92.6676178, 12.89585018], [92.6676178, 12.89640236], [92.66735077, 12.89668179], [92.66680145, 12.89669991], [92.66677094, 12.89801979], [92.66619873, 12.8980608], [92.66619873, 12.8986311], [92.66588593, 12.89863968], [92.6659317, 12.89921188], [92.66623688, 12.89918232], [92.66621399, 12.89976311], [92.6659317, 12.8997612], [92.6659317, 12.9005909], [92.66570282, 12.90061092], [92.66570282, 12.90252113], [92.66620636, 12.90256023], [92.66628265, 12.90340137], [92.66760254, 12.90338039], [92.66762543, 12.90390396], [92.6681366, 12.90392017], [92.66819763, 12.90449047], [92.67009735, 12.9044857], [92.67038727, 12.90480042], [92.67038727, 12.90531063], [92.67064667, 12.90531063], [92.67064667, 12.90585327], [92.67095184, 12.90585136], [92.67095184, 12.90642071], [92.67119598, 12.90639973], [92.67121887, 12.90699959], [92.6709137, 12.90699673], [92.67097473, 12.90754223], [92.67124176, 12.90752125], [92.67121887, 12.90810299], [92.67090607, 12.90808201], [92.67089844, 12.9105711], [92.67063141, 12.91061401], [92.67059326, 12.91186523], [92.670578, 12.91228294], [92.66860962, 12.91145515], [92.63659668, 12.91329002], [92.63687134, 12.91953945], [92.66816711, 12.91862965], [92.67012024, 12.91803741], [92.67006683, 12.91972446], [92.67041016, 12.9197216], [92.67037201, 12.92165661], [92.67067719, 12.92169094], [92.67067719, 12.92307854], [92.67094421, 12.9233799], [92.67204285, 12.92336082], [92.67230988, 12.92669964], [92.67288208, 12.92669964], [92.67345428, 12.92729759], [92.67345428, 12.92838478], [92.67427063, 12.92834568], [92.67425537, 12.92975235], [92.67398834, 12.92972946], [92.67397308, 12.93085098], [92.67370605, 12.93085957], [92.67372131, 12.93139076], [92.67398834, 12.93171883], [92.67401123, 12.9322319], [92.67372131, 12.9322319], [92.67370605, 12.93278122], [92.67427063, 12.93338108], [92.67484283, 12.93338108], [92.67484283, 12.93396187], [92.67568207, 12.93392086], [92.67568207, 12.93418312], [92.6765213, 12.93416023], [92.6765213, 12.93557072], [92.67593384, 12.93558884], [92.67568207, 12.93583107], [92.67565918, 12.93690586], [92.67646027, 12.93694115], [92.67733765, 12.93780708], [92.67731476, 12.93889427], [92.67784882, 12.93891239], [92.67783356, 12.9391737], [92.67730713, 12.93918991], [92.67703247, 12.93944073], [92.67707062, 12.94029999], [92.67761993, 12.94029999], [92.67819214, 12.94112492], [92.67978668, 12.94111061], [92.67980957, 12.94281197], [92.67871094, 12.94281197], [92.67871094, 12.94364071], [92.67926025, 12.94364071], [92.67983246, 12.94421768], [92.67980957, 12.94472408], [92.67926025, 12.9450407], [92.67926788, 12.94552135], [92.6795578, 12.94556046], [92.6795578, 12.94614124], [92.67984772, 12.94611645], [92.67984772, 12.94694138], [92.68013, 12.94696236], [92.68036652, 12.94724178], [92.68039703, 12.94805145], [92.6795578, 12.94806957], [92.67957306, 12.94792843], [92.67958069, 12.94782257], [92.67900848, 12.94782257], [92.67870331, 12.94724178], [92.67787933, 12.94724178], [92.67788696, 12.94802189], [92.67759705, 12.9483614], [92.6767807, 12.9483614], [92.6767807, 12.94889927], [92.67704773, 12.94888115], [92.67706299, 12.94999981], [92.67590332, 12.95003033], [92.67565918, 12.95055199], [92.67376709, 12.95059013], [92.6734314, 12.95003033], [92.67288208, 12.95003033], [92.67289734, 12.94974041], [92.67230225, 12.94974041], [92.67232513, 12.9500227], [92.67154694, 12.95003891], [92.67150879, 12.95059013], [92.67095184, 12.95057201], [92.67093658, 12.94974041], [92.67063141, 12.94974232], [92.67066956, 12.94999981], [92.66954803, 12.95003033], [92.66925812, 12.95053101], [92.66868591, 12.95053101], [92.66871643, 12.95107269], [92.66908264, 12.95130062], [92.66954041, 12.95143127], [92.66967773, 12.95158386], [92.67009735, 12.95167065], [92.67021179, 12.95223141], [92.67034912, 12.95252132], [92.67038727, 12.9536314], [92.66983795, 12.95360565], [92.66983795, 12.95529366], [92.67009735, 12.95527172], [92.67010498, 12.95579624], [92.66925049, 12.95587063], [92.66927338, 12.95611858], [92.66982269, 12.9563818], [92.66982269, 12.95696259], [92.67009735, 12.95695972], [92.67008972, 12.95837116], [92.66953278, 12.95834827], [92.66953278, 12.95919228], [92.66983795, 12.95919228], [92.6697998, 12.96084213], [92.66956329, 12.96084023], [92.66956329, 12.96168137], [92.66982269, 12.96170139], [92.66983795, 12.96249199], [92.67063904, 12.96247101], [92.67098236, 12.96278954], [92.67095947, 12.96335316], [92.67067719, 12.96335125], [92.67066193, 12.96412754], [92.67150879, 12.96415329], [92.67149353, 12.9644537], [92.67316437, 12.96447182], [92.67316437, 12.96501732], [92.67373657, 12.96499729], [92.67372131, 12.96612263], [92.67427063, 12.96610355], [92.67427063, 12.96670055], [92.67484283, 12.96695042], [92.67482758, 12.96802139], [92.67455292, 12.9683609], [92.67398834, 12.9683609], [92.67398834, 12.96867085], [92.67431641, 12.96863556], [92.674263, 12.96944141], [92.67462158, 12.96979046], [92.67485046, 12.97001076], [92.67537689, 12.97001076], [92.67533875, 12.97056007], [92.67623901, 12.97116566], [92.67620087, 12.97165394], [92.67733002, 12.97246075], [92.67733002, 12.97329521], [92.67785645, 12.97331333], [92.67818451, 12.97359371], [92.67814636, 12.97417545], [92.67843628, 12.97416973], [92.6784668, 12.97474003], [92.67897797, 12.97500038], [92.67896271, 12.97587967], [92.67926788, 12.97587967], [92.67958069, 12.97639179], [92.67958069, 12.97695065], [92.67987823, 12.97694778], [92.6798172, 12.97809315], [92.68010712, 12.97809029], [92.68010712, 12.9786396], [92.68092346, 12.97859859], [92.68092346, 12.97942448], [92.68121338, 12.9794302], [92.68122864, 12.98080921], [92.68177795, 12.98139095], [92.68235016, 12.98135376], [92.6823349, 12.98169136], [92.68286133, 12.98165035], [92.68289948, 12.98280144], [92.6831665, 12.98280144], [92.68315125, 12.98363972], [92.68341827, 12.98363972], [92.68341827, 12.98531055], [92.68370056, 12.98531055], [92.68371582, 12.98580074], [92.68427277, 12.98582077], [92.68427277, 12.98691273], [92.68478394, 12.98692703], [92.685112, 12.98726368], [92.68510437, 12.98773956], [92.68566132, 12.98773956], [92.68595123, 12.98751926], [92.68592834, 12.98693085], [92.68704987, 12.98693085], [92.68704987, 12.98830128], [92.68760681, 12.98830128], [92.68788147, 12.9880209], [92.68788147, 12.98773956], [92.68843842, 12.98773956], [92.68840027, 12.98915958], [92.68899536, 12.98945904], [92.68900299, 12.98995972], [92.68900299, 12.99029064], [92.68927765, 12.9902792], [92.68926239, 12.99080563], [92.69065094, 12.99083996], [92.69120789, 12.99163055], [92.69203949, 12.99168968], [92.69203949, 12.99197006], [92.6934433, 12.99191093], [92.6934433, 12.99163055], [92.69454956, 12.99163055], [92.69454956, 12.99218464], [92.69538116, 12.99218464], [92.69565582, 12.99195862]]], [[[92.93531799, 12.91808987], [92.93534088, 12.91779995], [92.93585205, 12.91779995], [92.93638611, 12.91728973], [92.93638611, 12.91671085], [92.93666077, 12.91669273], [92.93669891, 12.91504002], [92.93586731, 12.91448021], [92.93585205, 12.91392136], [92.93559265, 12.91393471], [92.9355545, 12.91335392], [92.93527985, 12.91331291], [92.93527985, 12.9130373], [92.93416595, 12.9130373], [92.93416595, 12.91331291], [92.93391418, 12.91337204], [92.9338913, 12.91556454], [92.93335724, 12.91555977], [92.93335724, 12.91615009], [92.93197632, 12.91613197], [92.9316864, 12.91641903], [92.9316864, 12.91725254], [92.931427, 12.91725063], [92.93141937, 12.91867065], [92.9327774, 12.91868877], [92.9327774, 12.91893959], [92.93336487, 12.91892242], [92.93334961, 12.91866875], [92.93392181, 12.91862965], [92.93422699, 12.91810989], [92.93531799, 12.91808987]]], [[[92.91307831, 12.91728973], [92.91200256, 12.91641045], [92.91200256, 12.91418076], [92.91230011, 12.91418076], [92.91226196, 12.9136591], [92.91143036, 12.91364098], [92.91136932, 12.91339016], [92.9108963, 12.91335106], [92.9108963, 12.91307259], [92.90999603, 12.91306019], [92.9099884, 12.91331005], [92.90947723, 12.91335106], [92.90947723, 12.91364098], [92.90860748, 12.91359997], [92.90865326, 12.91447067], [92.90900421, 12.9144907], [92.90895081, 12.91473866], [92.90947723, 12.91477108], [92.90947723, 12.91504002], [92.91027832, 12.91509724], [92.91059875, 12.91536903], [92.91056061, 12.91583347], [92.91086578, 12.91583061], [92.9108963, 12.91640091], [92.91114807, 12.91646004], [92.91120911, 12.91675186], [92.91142273, 12.91674519], [92.91142273, 12.91749954], [92.91172791, 12.91751957], [92.91311646, 12.91751957], [92.91307831, 12.91728973]]], [[[92.77420044, 12.93113327], [92.77456665, 12.93057346], [92.77560425, 12.93057346], [92.7756424, 12.92863846], [92.77591705, 12.92860985], [92.77590179, 12.92612076], [92.77560425, 12.92610073], [92.77561951, 12.92476082], [92.77533722, 12.9247427], [92.77536011, 12.92310619], [92.77507019, 12.92311096], [92.77513123, 12.92253017], [92.7747879, 12.92254066], [92.7747879, 12.92114162], [92.77452087, 12.92115116], [92.77452087, 12.92029381], [92.77425385, 12.92029381], [92.77429962, 12.91947269], [92.77368927, 12.91948509], [92.77368927, 12.91864586], [92.77338409, 12.91864586], [92.77339935, 12.91812611], [92.77308655, 12.91779137], [92.77205658, 12.91784954], [92.77205658, 12.91837025], [92.77178192, 12.91838646], [92.77173615, 12.91892433], [92.77143097, 12.91893959], [92.771492, 12.91944981], [92.77120972, 12.91944408], [92.77119446, 12.92086124], [92.77089691, 12.92086124], [92.77089691, 12.92140102], [92.77059937, 12.92167854], [92.77007294, 12.92166138], [92.77009583, 12.92224026], [92.76976776, 12.92224026], [92.76976776, 12.92278004], [92.76953125, 12.92280102], [92.76951599, 12.92309475], [92.7700882, 12.92331791], [92.7700882, 12.9239397], [92.76980591, 12.92390156], [92.76979828, 12.92532158], [92.77065277, 12.92529202], [92.77065277, 12.9258709], [92.77091217, 12.92585945], [92.77094269, 12.92725182], [92.77062988, 12.92726994], [92.77062988, 12.92778969], [92.77005768, 12.92807007], [92.77008057, 12.92895031], [92.77059174, 12.92889977], [92.77062988, 12.92919064], [92.77121735, 12.9294672], [92.77119446, 12.93056393], [92.77139282, 12.93079376], [92.77146149, 12.93087292], [92.77253723, 12.93087292], [92.77253723, 12.93115234], [92.77420044, 12.93113327]]], [[[92.79498291, 12.9112587], [92.79524994, 12.91084003], [92.79556274, 12.91044331], [92.79592133, 12.91003799], [92.7963028, 12.90962982], [92.79654694, 12.90910053], [92.79669952, 12.90849018], [92.79690552, 12.90790939], [92.79693604, 12.90732956], [92.79693604, 12.90675068], [92.79694366, 12.9062252], [92.79694366, 12.90577126], [92.79695129, 12.90540028], [92.79701996, 12.90510082], [92.79715729, 12.90485859], [92.79722595, 12.90456104], [92.79722595, 12.9042387], [92.7973175, 12.90393639], [92.79747009, 12.90361023], [92.79753876, 12.90319061], [92.79773712, 12.90273094], [92.79780579, 12.90218639], [92.79794312, 12.90165043], [92.79808044, 12.90112782], [92.79833221, 12.90069103], [92.79859924, 12.90028667], [92.79888153, 12.89988041], [92.79916382, 12.89944935], [92.79950714, 12.89901066], [92.79995728, 12.89861012], [92.80027008, 12.89807034], [92.80047607, 12.89752102], [92.80033875, 12.89703655], [92.80001831, 12.89662933], [92.79972076, 12.89621925], [92.79944611, 12.8958292], [92.79924011, 12.89543056], [92.79910278, 12.89496994], [92.79872894, 12.8945713], [92.79825592, 12.89422035], [92.79772949, 12.89391041], [92.79714203, 12.89365101], [92.79650116, 12.89344978], [92.7958374, 12.89326096], [92.79525757, 12.89301014], [92.79476166, 12.89274788], [92.79434204, 12.89250183], [92.79396057, 12.89232635], [92.79360199, 12.89221001], [92.79325867, 12.89211369], [92.79289246, 12.89177036], [92.79250336, 12.89187145], [92.79194641, 12.89221001], [92.79165649, 12.89250183], [92.79138947, 12.89250183], [92.79111481, 12.8927784], [92.79013824, 12.89315414], [92.78946686, 12.89345932], [92.78901672, 12.89360046], [92.78861237, 12.89376545], [92.78831482, 12.89377403], [92.7875824, 12.89381504], [92.7872467, 12.89374447], [92.78702545, 12.89368343], [92.78682709, 12.89369202], [92.78653717, 12.89364243], [92.78639221, 12.89366245], [92.78614807, 12.8937006], [92.78444672, 12.89388847], [92.78360748, 12.89472198], [92.78333282, 12.89509964], [92.7830658, 12.89554691], [92.78285217, 12.89607334], [92.78286743, 12.89666367], [92.78326416, 12.89713097], [92.78385162, 12.89748192], [92.78452301, 12.89772987], [92.78527069, 12.89782429], [92.7858963, 12.89804935], [92.78643799, 12.89829636], [92.78688812, 12.89853001], [92.78720856, 12.89887047], [92.78753662, 12.89918041], [92.78782654, 12.89952183], [92.78808594, 12.89988899], [92.78834534, 12.90023518], [92.78859711, 12.90056992], [92.78878784, 12.90095997], [92.7890625, 12.90128136], [92.78922272, 12.901721], [92.78935242, 12.90213966], [92.78952789, 12.90249062], [92.78962708, 12.90280819], [92.78948975, 12.90310001], [92.78943634, 12.9034214], [92.78939056, 12.90372944], [92.78923035, 12.90400028], [92.7890625, 12.90436935], [92.78876495, 12.90468788], [92.78836823, 12.90495968], [92.7879715, 12.90523148], [92.78749084, 12.90528965], [92.7869873, 12.90524006], [92.78653717, 12.90501022], [92.78607178, 12.90475178], [92.78560638, 12.90449047], [92.78523254, 12.90419197], [92.7848587, 12.90386963], [92.78449249, 12.90352154], [92.78414917, 12.90311623], [92.78370667, 12.90278053], [92.78325653, 12.90249062], [92.78282166, 12.90222931], [92.78238678, 12.90201092], [92.78192139, 12.90190792], [92.78153229, 12.90172958], [92.78111267, 12.90167141], [92.78069305, 12.90167141], [92.78023529, 12.90173531], [92.77979279, 12.90190125], [92.77925873, 12.90198994], [92.77879333, 12.90221977], [92.7783432, 12.9024868], [92.77789307, 12.90273952], [92.77735138, 12.90291786], [92.77677917, 12.9030838], [92.77622223, 12.90337086], [92.77568054, 12.90376091], [92.77514648, 12.90423012], [92.77474213, 12.90481758], [92.77443695, 12.90545177], [92.77423859, 12.90602875], [92.77430725, 12.90651417], [92.77444458, 12.90690231], [92.77456665, 12.90719986], [92.77469635, 12.907444], [92.77475739, 12.90771484], [92.77490234, 12.90798187], [92.77496338, 12.90823936], [92.77485657, 12.90847588], [92.77472687, 12.9087286], [92.77458191, 12.90903854], [92.77442169, 12.90944004], [92.77423096, 12.9098959], [92.77416992, 12.91041088], [92.77420044, 12.91094017], [92.77438354, 12.91140079], [92.77462006, 12.91182041], [92.77494049, 12.91211605], [92.77539825, 12.91221428], [92.77590179, 12.91222286], [92.77641296, 12.91217995], [92.77693939, 12.9119997], [92.77752686, 12.91193199], [92.77812195, 12.91184998], [92.77864075, 12.91168118], [92.77910614, 12.91155815], [92.77944946, 12.91139126], [92.77973938, 12.9112196], [92.78005219, 12.91113186], [92.78034973, 12.91111088], [92.78068542, 12.91110897], [92.78102875, 12.91111088], [92.78137207, 12.91116142], [92.78167725, 12.91135025], [92.78209686, 12.91145992], [92.782547, 12.91164684], [92.78303528, 12.91178322], [92.78354645, 12.91191101], [92.78410339, 12.91195202], [92.78466797, 12.91199112], [92.78518677, 12.91217995], [92.7857132, 12.91222095], [92.78617859, 12.91222954], [92.78659821, 12.91227055], [92.78694153, 12.91245079], [92.7873764, 12.91250992], [92.7878418, 12.91259003], [92.78827667, 12.91279125], [92.78868103, 12.91300964], [92.78903961, 12.9131012], [92.78925323, 12.91325569], [92.78940582, 12.91343117], [92.78948975, 12.91368198], [92.78959656, 12.91401005], [92.78971863, 12.91441059], [92.7898407, 12.91483974], [92.79001617, 12.91530037], [92.7902832, 12.91574001], [92.7906189, 12.91614056], [92.79110718, 12.91640282], [92.79162598, 12.91659164], [92.79212952, 12.9164238], [92.7924881, 12.91594505], [92.79277802, 12.91542339], [92.79301453, 12.9149313], [92.79312134, 12.91442966], [92.79334259, 12.91405106], [92.79359436, 12.91372776], [92.79382324, 12.91337204], [92.79395294, 12.91289997], [92.79416656, 12.91249943], [92.79444122, 12.91209126], [92.79471588, 12.91167355], [92.79498291, 12.9112587]]], [[[92.76815033, 12.91754055], [92.76815033, 12.91641903], [92.76756287, 12.91642094], [92.76753998, 12.91674995], [92.76727295, 12.9169836], [92.76707458, 12.91722584], [92.76669312, 12.91723061], [92.76670837, 12.91782093], [92.76786041, 12.91782093], [92.76815033, 12.91754055]]], [[[92.76702118, 12.92470169], [92.76698303, 12.92391968], [92.76729584, 12.92391968], [92.76735687, 12.92339993], [92.76706696, 12.92336082], [92.76700592, 12.92251968], [92.76731873, 12.92254066], [92.76731873, 12.92171955], [92.76703644, 12.92176056], [92.76703644, 12.92112064], [92.76725769, 12.92114162], [92.76728058, 12.92034245], [92.76677704, 12.92004108], [92.76674652, 12.9194603], [92.7661972, 12.91944981], [92.76587677, 12.91913128], [92.76587677, 12.91858196], [92.76534271, 12.91801929], [92.76477814, 12.91774082], [92.76477814, 12.9174614], [92.76422119, 12.9174614], [92.76422119, 12.91801453], [92.76365662, 12.91829014], [92.76365662, 12.91913128], [92.76333618, 12.91947079], [92.76287079, 12.91947079], [92.76254272, 12.91991138], [92.76262665, 12.92085171], [92.76226044, 12.92088604], [92.7622757, 12.92190456], [92.76314545, 12.92196369], [92.7636795, 12.92256355], [92.76369476, 12.92310238], [92.76422119, 12.92310238], [92.76452637, 12.92366219], [92.765625, 12.92368126], [92.76590729, 12.92394924], [92.76590729, 12.92476082], [92.76702118, 12.92470169]]], [[[92.87702179, 12.9320612], [92.87722778, 12.93167114], [92.87747192, 12.93135357], [92.87773132, 12.93104172], [92.87799072, 12.93072128], [92.8782959, 12.93061066], [92.8786087, 12.9307003], [92.87896729, 12.93081188], [92.87937164, 12.93082142], [92.87982178, 12.9307909], [92.8802948, 12.93062305], [92.88078308, 12.93043423], [92.88109589, 12.92984772], [92.88156891, 12.92980003], [92.88195801, 12.92988205], [92.88233185, 12.92986202], [92.88275146, 12.92997074], [92.8832016, 12.93029022], [92.8837204, 12.92997074], [92.88411713, 12.92982674], [92.88440704, 12.9295702], [92.88461304, 12.92926025], [92.88470459, 12.92887688], [92.884758, 12.92839146], [92.88490295, 12.92785358], [92.88503265, 12.92722034], [92.88527679, 12.92663193], [92.88555145, 12.92607975], [92.88581085, 12.9255743], [92.88600922, 12.92507839], [92.8861084, 12.92455101], [92.88617706, 12.92406559], [92.88627625, 12.92361355], [92.88608551, 12.92298508], [92.88535309, 12.92278004], [92.88473511, 12.92277813], [92.88417816, 12.92250919], [92.88363647, 12.92223072], [92.88311005, 12.92202091], [92.88259888, 12.92191029], [92.88226318, 12.92198277], [92.88198853, 12.9218502], [92.88168335, 12.92130089], [92.88142395, 12.92107105], [92.88114929, 12.92083168], [92.88092804, 12.9205513], [92.88046265, 12.92080021], [92.88030243, 12.92174625], [92.88012695, 12.92236996], [92.87997437, 12.92293072], [92.87973785, 12.92337132], [92.87950134, 12.92381954], [92.87908936, 12.92416096], [92.87857056, 12.92451], [92.87805176, 12.92495918], [92.87754059, 12.92543125], [92.87712097, 12.9259119], [92.87674713, 12.92635155], [92.87632751, 12.92662144], [92.87583923, 12.92667103], [92.87563324, 12.92665005], [92.87534332, 12.92662144], [92.87490845, 12.9263792], [92.87451172, 12.92605114], [92.87419128, 12.92566109], [92.87394714, 12.92526245], [92.87377167, 12.92488575], [92.87362671, 12.92455101], [92.87361145, 12.92420006], [92.87361908, 12.92387676], [92.873703, 12.92355061], [92.87387848, 12.92323589], [92.87404633, 12.92287064], [92.87419891, 12.92243576], [92.87439728, 12.92200089], [92.87444305, 12.92144012], [92.87445068, 12.92083168], [92.87444305, 12.92020035], [92.87438202, 12.91960144], [92.87420654, 12.91903973], [92.87413025, 12.91846085], [92.87394714, 12.91790104], [92.87385559, 12.91733074], [92.87362671, 12.91683197], [92.8733139, 12.91636372], [92.8728714, 12.91599083], [92.87264252, 12.91584015], [92.87230682, 12.91583061], [92.87182617, 12.91585159], [92.87129974, 12.91593647], [92.87081146, 12.91612053], [92.87033844, 12.91634178], [92.86981201, 12.91644192], [92.86929321, 12.91656971], [92.86872864, 12.91670036], [92.86837769, 12.91658115], [92.86759949, 12.91670418], [92.86706543, 12.91666794], [92.86660767, 12.91666126], [92.8663559, 12.91667175], [92.86588287, 12.91671085], [92.8655777, 12.91659164], [92.86503601, 12.91673374], [92.86496735, 12.91737175], [92.86472321, 12.91774082], [92.86445618, 12.91810131], [92.86429596, 12.91848564], [92.86418152, 12.91887188], [92.86411285, 12.91926098], [92.86395264, 12.91958046], [92.86386108, 12.91993141], [92.86369324, 12.92022991], [92.86357117, 12.92055988], [92.8633728, 12.92083168], [92.86322784, 12.92120075], [92.86301422, 12.92156982], [92.86269379, 12.92195511], [92.86234283, 12.9223814], [92.86197662, 12.92285061], [92.86164093, 12.92333603], [92.86123657, 12.92376328], [92.86083221, 12.92419147], [92.86052704, 12.92468071], [92.86019135, 12.925107], [92.85974121, 12.92549229], [92.85927582, 12.92594147], [92.85904694, 12.92626953], [92.85883331, 12.92682076], [92.85887146, 12.92724514], [92.85874176, 12.92767429], [92.85865784, 12.92823029], [92.85840607, 12.92911911], [92.8585434, 12.92965031], [92.85876465, 12.93007755], [92.85887146, 12.93057346], [92.85900116, 12.93099022], [92.85913849, 12.93133831], [92.85926056, 12.93170071], [92.85940552, 12.93203831], [92.85955048, 12.93241024], [92.85979462, 12.9327383], [92.86003876, 12.93310928], [92.86038208, 12.933424], [92.86074066, 12.93362045], [92.86126709, 12.93367004], [92.86190796, 12.93359947], [92.86252594, 12.93352032], [92.86310577, 12.93340969], [92.86368561, 12.93336678], [92.8642807, 12.93334198], [92.86490631, 12.93330097], [92.86553955, 12.93326187], [92.86631012, 12.93338966], [92.86647797, 12.93337059], [92.86680603, 12.93332958], [92.86706543, 12.93307686], [92.86743164, 12.93278122], [92.86790466, 12.93250847], [92.86843109, 12.93229103], [92.868927, 12.93215179], [92.86936951, 12.93198109], [92.86979675, 12.93194008], [92.870224, 12.93198586], [92.87059021, 12.9321909], [92.87094879, 12.93235016], [92.87124634, 12.9325304], [92.87149811, 12.9327898], [92.87172699, 12.93314075], [92.87195587, 12.93353081], [92.87224579, 12.93390179], [92.87268066, 12.93417072], [92.87317657, 12.93437004], [92.87338257, 12.93438339], [92.87378693, 12.93441296], [92.8744278, 12.93429375], [92.87503815, 12.93410492], [92.8755188, 12.93383026], [92.87593079, 12.93353081], [92.87632751, 12.93325138], [92.87664795, 12.93290424], [92.87689972, 12.93251228], [92.87702179, 12.9320612]]], [[[92.76561737, 12.93252373], [92.76566315, 12.93142509], [92.76590729, 12.93142986], [92.76595306, 12.92975044], [92.7661972, 12.92972946], [92.76618958, 12.92919064], [92.76647186, 12.92919064], [92.76648712, 12.92807007], [92.76563263, 12.92805195], [92.76486969, 12.9272337], [92.76486969, 12.92669392], [92.7645874, 12.92667294], [92.76456451, 12.92613506], [92.76422119, 12.92613506], [92.76428223, 12.92555618], [92.76316833, 12.92555618], [92.76316833, 12.92611027], [92.7623291, 12.92610073], [92.7623291, 12.92672253], [92.76203918, 12.92675972], [92.76206207, 12.92778111], [92.76147461, 12.92813873], [92.76143646, 12.92866039], [92.76114655, 12.92864037], [92.76114655, 12.92950058], [92.76091003, 12.92949677], [92.76094818, 12.93083191], [92.76117706, 12.9308424], [92.76119995, 12.93142033], [92.76148224, 12.93142033], [92.76151276, 12.93199921], [92.76117706, 12.93198109], [92.76117706, 12.93254185], [92.76148224, 12.93255997], [92.76150513, 12.9327774], [92.76151276, 12.93332958], [92.76177979, 12.93361092], [92.76177979, 12.93416691], [92.76232147, 12.93418121], [92.76230621, 12.93470001], [92.76261902, 12.93500137], [92.76374054, 12.93500137], [92.76369476, 12.93448067], [92.76397705, 12.93424034], [92.76452637, 12.93420124], [92.76454926, 12.93336201], [92.76478577, 12.93334198], [92.76561737, 12.93252373]]], [[[92.9263916, 13.02416801], [92.9263916, 13.02333069], [92.92694092, 13.02333069], [92.92694092, 13.02361202], [92.92722321, 13.02361202], [92.92749786, 13.02333069], [92.92749786, 13.02305508], [92.92888641, 13.02305508], [92.92888641, 13.0233326], [92.9291687, 13.0233326], [92.9291687, 13.02305508], [92.92944336, 13.02305508], [92.92944336, 13.02333069], [92.93000031, 13.02361202], [92.9319458, 13.02388954], [92.93250275, 13.02416801], [92.93360901, 13.02444553], [92.93444824, 13.02472115], [92.9347229, 13.02472115], [92.9347229, 13.02444553], [92.93499756, 13.02444553], [92.93499756, 13.0247097], [92.93583679, 13.02555561], [92.9366684, 13.02583122], [92.93694305, 13.0261116], [92.93805695, 13.0261116], [92.9383316, 13.02583122], [92.93888855, 13.02555561], [92.94000244, 13.02528], [92.94000244, 13.0247097], [92.9402771, 13.02444553], [92.9402771, 13.02388954], [92.93972015, 13.02361202], [92.93888855, 13.02333069], [92.9383316, 13.02305508], [92.93805695, 13.02278042], [92.93805695, 13.02167034], [92.9383316, 13.02139187], [92.9383316, 13.02083111], [92.93888855, 13.02055454], [92.93972015, 13.02028179], [92.9402771, 13.02000141], [92.9402771, 13.01972103], [92.94082642, 13.01972103], [92.94082642, 13.02000141], [92.9411087, 13.02000141], [92.9411087, 13.01972103], [92.94194794, 13.01944542], [92.94249725, 13.01916695], [92.94249725, 13.01833057], [92.94277954, 13.01805496], [92.94249725, 13.01777935], [92.94194794, 13.01750088], [92.94194794, 13.01666927], [92.9422226, 13.01638889], [92.9422226, 13.01611137], [92.94166565, 13.01555538], [92.94165802, 13.01443958], [92.94139099, 13.01416683], [92.9402771, 13.01389122], [92.9402771, 13.0127697], [92.93972015, 13.01222324], [92.93972015, 13.01166725], [92.93945312, 13.01139069], [92.93945312, 13.00944042], [92.93972015, 13.00916576], [92.93972015, 13.00889111], [92.94000244, 13.00860977], [92.94000244, 13.00833035], [92.9402771, 13.00805569], [92.9402771, 13.0069418], [92.94055176, 13.00666618], [92.94055176, 13.00611019], [92.94083405, 13.00583363], [92.94083405, 13.00555611], [92.94055176, 13.00527954], [92.94055176, 13.00471973], [92.94083405, 13.00444412], [92.94083405, 13.00389004], [92.9411087, 13.00360107], [92.94083405, 13.00333405], [92.94139099, 13.00277805], [92.94139099, 13.00249958], [92.94165802, 13.00222015], [92.94277954, 13.00194359], [92.94249725, 13.00166798], [92.94304657, 13.00139046], [92.94304657, 13.00111198], [92.94333649, 13.0008316], [92.94333649, 13.0], [92.943367, 12.99889183], [92.9436264, 12.99890995], [92.9436264, 12.99808121], [92.94387054, 12.99806023], [92.94394684, 12.99749947], [92.94418335, 12.99749947], [92.94418335, 12.99697113], [92.94359589, 12.99695492], [92.94332123, 12.99635315], [92.94252777, 12.99637127], [92.94251251, 12.99612141], [92.94197845, 12.99612141], [92.94197845, 12.99562073], [92.94165802, 12.99532127], [92.9411087, 12.99532127], [92.94113159, 12.99583054], [92.94003296, 12.99583054], [92.94004822, 12.99555969], [92.93810272, 12.99555969], [92.93805695, 12.99526978], [92.93746948, 12.99530029], [92.93746948, 12.9955759], [92.9367218, 12.99559021], [92.9367218, 12.99581146], [92.93615723, 12.99583054], [92.93586731, 12.99612141], [92.93582916, 12.99746132], [92.93504333, 12.99752045], [92.9347229, 12.99806023], [92.93360138, 12.99814034], [92.93332672, 12.99833107], [92.93332672, 12.99889183], [92.93254089, 12.99943733], [92.93250275, 12.99972153], [92.93027496, 12.99972153], [92.93001556, 12.99947453], [92.9291687, 12.99946022], [92.92920685, 12.9991703], [92.92727661, 12.99918079], [92.92723846, 12.99950123], [92.92585754, 12.99945736], [92.92558289, 12.99972153], [92.92555237, 13.00000191], [92.92582703, 13.00028038], [92.92555237, 13.00027847], [92.92555237, 13.0008316], [92.92527771, 13.00111198], [92.92444611, 13.00139046], [92.92415619, 13.00139046], [92.92415619, 13.00111198], [92.92388916, 13.00111198], [92.92388916, 13.00139046], [92.9227829, 13.00139046], [92.92250061, 13.00111198], [92.92250061, 13.00055981], [92.92222595, 13.00028038], [92.92193604, 13.00028038], [92.92138672, 13.00055981], [92.92082977, 13.00111198], [92.92082977, 13.00249958], [92.92056274, 13.00277996], [92.92055511, 13.00305557], [92.92082977, 13.00333405], [92.92055511, 13.00361156], [92.92055511, 13.00444412], [92.92028046, 13.00471973], [92.92028046, 13.00500011], [92.91999817, 13.00527954], [92.91944122, 13.00555611], [92.91889191, 13.00611019], [92.91889191, 13.00638771], [92.91833496, 13.0069437], [92.91860962, 13.00722027], [92.91805267, 13.00749969], [92.91805267, 13.00777817], [92.91750336, 13.00833035], [92.91750336, 13.00860977], [92.91722107, 13.00888824], [92.91722107, 13.00944042], [92.91694641, 13.00972939], [92.91694641, 13.01000118], [92.91638947, 13.01056099], [92.91638947, 13.01139069], [92.91611481, 13.01166725], [92.91611481, 13.01194477], [92.91583252, 13.01222038], [92.91583252, 13.01250076], [92.91610718, 13.0127697], [92.91583252, 13.01305676], [92.91583252, 13.01472092], [92.91610718, 13.0150013], [92.91610718, 13.0155592], [92.91694641, 13.01638889], [92.91694641, 13.01722145], [92.91777802, 13.01805496], [92.91832733, 13.01833057], [92.91889191, 13.01890087], [92.91944122, 13.01917171], [92.91999817, 13.01917171], [92.91999817, 13.01890087], [92.92056274, 13.01890087], [92.92055511, 13.01916695], [92.92111206, 13.01944542], [92.92138672, 13.01972103], [92.92138672, 13.02000141], [92.92194366, 13.02055454], [92.92193604, 13.02083111], [92.92250061, 13.02139187], [92.92250061, 13.02166653], [92.9227829, 13.02194118], [92.9227829, 13.02250195], [92.92222595, 13.02278042], [92.92194366, 13.02305508], [92.92193604, 13.02333069], [92.92138672, 13.02361202], [92.92111206, 13.02388954], [92.92166901, 13.02444553], [92.92138672, 13.02472115], [92.92138672, 13.02583122], [92.92166901, 13.0261116], [92.92166901, 13.02777767], [92.92250061, 13.02861214], [92.92388916, 13.02861214], [92.92416382, 13.02833366], [92.92527771, 13.02805614], [92.92555237, 13.027771], [92.92555237, 13.02750015], [92.92582703, 13.02722168], [92.92583466, 13.02666569], [92.92610931, 13.02639198], [92.92610931, 13.0261116], [92.9263916, 13.02583122], [92.92610931, 13.02555561], [92.92610931, 13.02443886], [92.9263916, 13.02416801]]], [[[92.83000183, 13.17193985], [92.83027649, 13.17194366], [92.83055878, 13.17166615], [92.83082581, 13.17167091], [92.83110809, 13.17139053], [92.83139038, 13.17139053], [92.83167267, 13.17111015], [92.83222198, 13.17111015], [92.83249664, 13.17083454], [92.83389282, 13.17082977], [92.83444214, 13.17139053], [92.83444214, 13.17166615], [92.8347168, 13.17193985], [92.8347168, 13.17223167], [92.83499908, 13.17250061], [92.83499908, 13.17278099], [92.83528137, 13.17306137], [92.83528137, 13.17361069], [92.83555603, 13.17389107], [92.83528137, 13.17416668], [92.83528137, 13.1747179], [92.83444214, 13.17556095], [92.83416748, 13.17556095], [92.83333588, 13.17639065], [92.83305359, 13.17638874], [92.83249664, 13.17694473], [92.83222198, 13.17694473], [92.83194733, 13.17722321], [92.83167267, 13.1772213], [92.83139038, 13.17750072], [92.83110809, 13.17750072], [92.83055878, 13.17805862], [92.83027649, 13.17805481], [92.83000183, 13.17833328], [92.82971954, 13.17805481], [92.82944489, 13.17833328], [92.82943726, 13.1786108], [92.82749939, 13.18056202], [92.82722473, 13.18055534], [92.82666779, 13.18111134], [92.82611084, 13.18111134], [92.82555389, 13.18055534], [92.82554626, 13.18028164], [92.82499695, 13.17972088], [92.82499695, 13.17944527], [92.82472229, 13.17916679], [92.82446289, 13.17917156], [92.82417297, 13.17889118], [92.82389069, 13.17888927], [92.82333374, 13.17944527], [92.82333374, 13.17972088], [92.82195282, 13.18111134], [92.82195282, 13.18140125], [92.8216629, 13.18166733], [92.8216629, 13.18194103], [92.8208313, 13.18278027], [92.81999969, 13.18278027], [92.8188858, 13.18388939], [92.8188858, 13.18416691], [92.81916809, 13.18444824], [92.81972504, 13.18499947], [92.81986237, 13.18500233], [92.81999969, 13.18499947], [92.82026672, 13.18528175], [92.82055664, 13.18528175], [92.8208313, 13.18556023], [92.82110596, 13.18556023], [92.82195282, 13.18639183], [92.82194519, 13.18666458], [92.82221985, 13.18694305], [92.82221985, 13.18721008], [92.82250214, 13.18750191], [92.82250214, 13.18805599], [92.82277679, 13.18833447], [92.82277679, 13.18944359], [92.82305908, 13.1897192], [92.82305908, 13.18999958], [92.82389069, 13.19083405], [92.82389069, 13.19110966], [92.82417297, 13.19139004], [92.82417297, 13.19306087], [92.82305908, 13.19417095], [92.82277679, 13.19416618], [92.82250214, 13.1944437], [92.82221985, 13.1944437], [92.82194519, 13.19472218], [92.82055664, 13.19458485], [92.82027435, 13.1944437], [92.81972504, 13.1944437], [92.81944275, 13.19431019], [92.81902313, 13.19445133], [92.8188858, 13.1944437], [92.81861115, 13.19472027], [92.81861115, 13.19499969], [92.81916809, 13.19555569], [92.81916809, 13.19583035], [92.81999969, 13.19666576], [92.81999969, 13.19694424], [92.82026672, 13.19721985], [92.82026672, 13.19778061], [92.81999969, 13.19805431], [92.81999969, 13.19832993], [92.81916809, 13.19917107], [92.81861115, 13.19930553], [92.81832886, 13.19972038], [92.81806183, 13.20028114], [92.8180542, 13.20055676], [92.81832886, 13.20139122], [92.81833649, 13.20166683], [92.81861115, 13.2019453], [92.8188858, 13.20193958], [92.81944275, 13.20236206], [92.82138824, 13.2025013], [92.82221985, 13.2033329], [92.82221985, 13.20361137], [92.82250214, 13.20388889], [92.82250214, 13.20472145], [92.8225708, 13.20478916], [92.82332611, 13.20557117], [92.8236084, 13.20555496], [92.82417297, 13.20611095], [92.82430267, 13.20639133], [92.82472229, 13.20666695], [92.82472229, 13.20694065], [92.82518768, 13.20740795], [92.82611084, 13.20833969], [92.82639313, 13.20833969], [92.82694244, 13.20778179], [92.82720947, 13.20778179], [92.82777405, 13.20763588], [92.82917023, 13.20861053], [92.82917023, 13.20889187], [92.82943726, 13.20917034], [92.82972717, 13.21055508], [92.83083344, 13.21194553], [92.83082581, 13.21221924], [92.83110809, 13.21250153], [92.83110809, 13.21277714], [92.83167267, 13.21333122], [92.83167267, 13.21389198], [92.83055878, 13.21500015], [92.82943726, 13.21500015], [92.82917023, 13.21500015], [92.82888794, 13.21500015], [92.82861328, 13.21500015], [92.82805634, 13.21555996], [92.82777405, 13.21555614], [92.82722473, 13.21611214], [92.82639313, 13.21611023], [92.82611084, 13.21638966], [92.82499695, 13.21638966], [92.82472229, 13.21666622], [92.82472229, 13.21694374], [92.82446289, 13.21722031], [92.82444763, 13.21749973], [92.82554626, 13.21860981], [92.82555389, 13.21889019], [92.82611084, 13.21943855], [92.82611084, 13.21972179], [92.82749939, 13.22111225], [92.82776642, 13.22111034], [92.82833099, 13.2216711], [92.82861328, 13.22166634], [92.82917023, 13.22222042], [92.82888794, 13.22249985], [92.82888794, 13.22278118], [92.82917023, 13.22305584], [92.82917023, 13.22332096], [92.82943726, 13.22360992], [92.82946014, 13.2240963], [92.82932281, 13.22430134], [92.82897186, 13.22437096], [92.82847595, 13.22422791], [92.82805634, 13.2238884], [92.82776642, 13.22360992], [92.82720947, 13.22360992], [92.82694244, 13.22332096], [92.82666779, 13.22332096], [92.82583618, 13.22417068], [92.82583618, 13.22500038], [92.82611084, 13.22528076], [92.82611084, 13.22555447], [92.82749939, 13.22694016], [92.82749939, 13.22750092], [92.82776642, 13.2277813], [92.82776642, 13.23000145], [92.82805634, 13.23027897], [92.82805634, 13.23111057], [92.82777405, 13.23138905], [92.82777405, 13.23194504], [92.82805634, 13.23222256], [92.82805634, 13.23361111], [92.82776642, 13.23389053], [92.82777405, 13.2341671], [92.82749939, 13.23444462], [92.82749939, 13.23583126], [92.82776642, 13.23611069], [92.82777405, 13.23666668], [92.82833099, 13.23722076], [92.82833099, 13.23749924], [92.82861328, 13.23749924], [92.83000183, 13.23888969], [92.83000183, 13.23916531], [92.83027649, 13.23944569], [92.83026886, 13.2397213], [92.83055878, 13.24000168], [92.83055878, 13.24055576], [92.83082581, 13.24083138], [92.83083344, 13.24166775], [92.83110809, 13.24194431], [92.83110809, 13.24222183], [92.83167267, 13.24277973], [92.83194733, 13.24277973], [92.83222198, 13.24306011], [92.83249664, 13.24277973], [92.83304596, 13.24277973], [92.83333588, 13.24250031], [92.8347168, 13.24250031], [92.83499908, 13.24277973], [92.83528137, 13.24277782], [92.83583069, 13.24333382], [92.83611298, 13.24333382], [92.83638763, 13.24361229], [92.83666992, 13.24361229], [92.83721924, 13.2430563], [92.83750153, 13.24333382], [92.83833313, 13.24333382], [92.83860779, 13.2430563], [92.83889008, 13.24306011], [92.83914948, 13.24277973], [92.83943939, 13.24277973], [92.83999634, 13.24222183], [92.83999634, 13.24194431], [92.84083557, 13.24111176], [92.84083557, 13.24083424], [92.84166718, 13.23999882], [92.84166718, 13.23917198], [92.84194183, 13.23888969], [92.84194183, 13.23860931], [92.84222412, 13.23833275], [92.84249878, 13.23833275], [92.84333038, 13.23749924], [92.84361267, 13.23749924], [92.84416962, 13.23694134], [92.84444427, 13.23694324], [92.84471893, 13.23722267], [92.84500122, 13.23722076], [92.84527588, 13.23749924], [92.8455658, 13.23749924], [92.8458786, 13.23782063], [92.84610748, 13.23806], [92.84638977, 13.23805523], [92.84666443, 13.23833275], [92.84805298, 13.23833275], [92.84833527, 13.23861122], [92.84860992, 13.23860931], [92.84870148, 13.23870277], [92.84889221, 13.23888969], [92.84916687, 13.23888969], [92.84944153, 13.23917198], [92.84972382, 13.23916531], [92.84999847, 13.23944569], [92.84999847, 13.2397213], [92.85056305, 13.24028015], [92.85055542, 13.24139023], [92.84999847, 13.24194431], [92.84999847, 13.24222183], [92.84971619, 13.24250031], [92.84999847, 13.24277782], [92.84999847, 13.24361038], [92.85028076, 13.24388981], [92.85028076, 13.24417019], [92.85055542, 13.24444389], [92.85056305, 13.24472046], [92.85083008, 13.24500179], [92.85083008, 13.24528027], [92.85111237, 13.24556065], [92.85111237, 13.24610996], [92.85137939, 13.24639034], [92.85138702, 13.24666595], [92.85166931, 13.24694443], [92.85166931, 13.24722195], [92.85193634, 13.24749088], [92.85194397, 13.24805641], [92.85221863, 13.24833202], [92.85221863, 13.24860954], [92.85250092, 13.24888802], [92.85250092, 13.24944401], [92.8527832, 13.24971962], [92.85277557, 13.25027847], [92.85305786, 13.25055027], [92.85305786, 13.25139141], [92.85333252, 13.25166607], [92.85333252, 13.25333214], [92.85360718, 13.25360966], [92.85360718, 13.25528145], [92.85388947, 13.25555515], [92.85388947, 13.25583267], [92.85416412, 13.25611115], [92.85416412, 13.25694466], [92.85443878, 13.25722122], [92.85444641, 13.25777912], [92.85277557, 13.25944519], [92.85166931, 13.25944519], [92.85138702, 13.2597208], [92.85111237, 13.2597208], [92.85056305, 13.26028156], [92.85028076, 13.26028156], [92.84916687, 13.26139069], [92.84889221, 13.26138878], [92.84805298, 13.26222324], [92.84777832, 13.26222324], [92.84750366, 13.26249886], [92.84583282, 13.26249886], [92.84555817, 13.26222324], [92.84527588, 13.26222324], [92.84471893, 13.26166725], [92.84333038, 13.26167202], [92.84320831, 13.26154423], [92.84305573, 13.26138878], [92.84249878, 13.26139069], [92.84227753, 13.26116753], [92.84194183, 13.26083279], [92.84083557, 13.26083279], [92.83999634, 13.26000118], [92.83999634, 13.2597208], [92.83972168, 13.25944519], [92.83944702, 13.25944519], [92.83889008, 13.2588892], [92.83860779, 13.25916672], [92.83860779, 13.2597208], [92.83833313, 13.26000118], [92.83833313, 13.26028156], [92.83805847, 13.26055527], [92.83777618, 13.26111126], [92.83750153, 13.26166725], [92.8374939, 13.26194477], [92.83750153, 13.26222324], [92.83721924, 13.26249027], [92.83708191, 13.26305485], [92.83721924, 13.26333141], [92.83693695, 13.26361084], [92.83693695, 13.26388931], [92.83666992, 13.26416683], [92.83666992, 13.26444054], [92.83611298, 13.26499939], [92.83611298, 13.2658329], [92.83583069, 13.26611233], [92.83583069, 13.26666546], [92.83555603, 13.26694584], [92.83555603, 13.26722145], [92.83486938, 13.26813126], [92.8345108, 13.26846123], [92.83403015, 13.26862144], [92.83389282, 13.26862144], [92.83361053, 13.26889038], [92.83333588, 13.26889038], [92.83304596, 13.26916981], [92.83222198, 13.26916981], [92.83208466, 13.26916599], [92.83194733, 13.26916122], [92.83167267, 13.26889038], [92.83139038, 13.26916981], [92.83069611, 13.26916981], [92.83000183, 13.26862144], [92.82958221, 13.26846123], [92.82944489, 13.26833439], [92.82833099, 13.26722145], [92.82833099, 13.26666546], [92.82749939, 13.26583099], [92.82694244, 13.26583099], [92.82695007, 13.26638985], [92.8270874, 13.26681137], [92.82763672, 13.26805973], [92.82749939, 13.26861191], [92.82666779, 13.26944447], [92.82666779, 13.26972198], [92.82527924, 13.27110958], [92.82527924, 13.27138996], [92.82472229, 13.27193928], [92.82472229, 13.27416611], [92.82446289, 13.27443027], [92.82444763, 13.27527809], [92.82250214, 13.27722168], [92.82250214, 13.27832985], [92.82309723, 13.27912521], [92.82406616, 13.27966976], [92.82492065, 13.28023148], [92.82534027, 13.28133202], [92.82527924, 13.28250122], [92.82554626, 13.28278065], [92.82554626, 13.28362179], [92.82527924, 13.28416729], [92.82527924, 13.28444004], [92.82527924, 13.28499889], [92.82499695, 13.28528118], [92.82499695, 13.28555489], [92.82472229, 13.28583145], [92.82472229, 13.28638935], [92.82444763, 13.28666687], [92.82444763, 13.28722095], [92.82417297, 13.28750134], [92.82416534, 13.28805542], [92.82472229, 13.28861141], [92.82499695, 13.28861141], [92.82527924, 13.28833294], [92.82611084, 13.28833294], [92.8263855, 13.28861141], [92.82666779, 13.28833294], [92.82888794, 13.28833294], [92.83055878, 13.28666687], [92.83083344, 13.28666687], [92.83139038, 13.28611088], [92.83167267, 13.28611088], [92.83194733, 13.28583336], [92.83222198, 13.28583336], [92.83277893, 13.28527737], [92.83389282, 13.28528118], [92.83416748, 13.28556156], [92.83444214, 13.28556156], [92.83499908, 13.28611088], [92.83555603, 13.28611088], [92.83583069, 13.28583145], [92.83693695, 13.28583145], [92.83721924, 13.28611088], [92.83750153, 13.28611088], [92.83777618, 13.28639126], [92.83805847, 13.28638935], [92.83860779, 13.28694534], [92.83860779, 13.28833103], [92.83805847, 13.28889179], [92.83805847, 13.28917027], [92.83693695, 13.29027939], [92.83694458, 13.29111099], [92.83583069, 13.29222107], [92.83583069, 13.29249859], [92.83555603, 13.29279137], [92.83555603, 13.29305458], [92.83583069, 13.29333401], [92.83555603, 13.29361153], [92.83555603, 13.29416847], [92.83583069, 13.29444122], [92.83583069, 13.29500198], [92.83611298, 13.2952776], [92.83611298, 13.29583073], [92.83833313, 13.29806042], [92.83860779, 13.29805565], [92.83889008, 13.29833412], [92.83916473, 13.29833412], [92.84194183, 13.30111217], [92.84194183, 13.30166626], [92.84222412, 13.30194378], [92.84194183, 13.30222225], [92.84194183, 13.30333424], [92.84166718, 13.30360985], [92.84166718, 13.30389023], [92.84139252, 13.30416584], [92.84139252, 13.30443954], [92.83943939, 13.30639076], [92.83914948, 13.30639076], [92.83889008, 13.30667114], [92.83721924, 13.30667114], [92.83693695, 13.30639076], [92.83666992, 13.30639076], [92.83640289, 13.30611038], [92.83611298, 13.30611038], [92.83472443, 13.30472183], [92.83389282, 13.30473137], [92.83304596, 13.30556107], [92.83249664, 13.30555439], [92.83222198, 13.30583191], [92.82971954, 13.30583191], [92.82944489, 13.30611038], [92.82917023, 13.30611038], [92.82861328, 13.30667114], [92.82666779, 13.30666637], [92.8263855, 13.30694485], [92.82611084, 13.30694485], [92.82472229, 13.3083334], [92.82444763, 13.3083334], [92.82417297, 13.30861092], [92.82250214, 13.30861092], [92.82194519, 13.30916691], [92.82194519, 13.30944538], [92.8216629, 13.30972099], [92.8216629, 13.31000137], [92.82195282, 13.31027889], [92.82194519, 13.31055546], [92.82221985, 13.31083298], [92.82250214, 13.31083298], [92.82277679, 13.31111145], [92.82308197, 13.31113625], [92.82332611, 13.31139088], [92.82417297, 13.31139088], [92.82446289, 13.31166935], [92.82749939, 13.31166744], [92.82777405, 13.31194496], [92.82917023, 13.31194496], [92.83055878, 13.31333256], [92.83055878, 13.31359959], [92.83083344, 13.31388855], [92.83083344, 13.31444454], [92.83110809, 13.31472111], [92.83110809, 13.31528187], [92.83139038, 13.31555462], [92.83139038, 13.31611061], [92.83082581, 13.31667042], [92.83027649, 13.3166666], [92.83000183, 13.31694317], [92.82971954, 13.31694317], [92.82944489, 13.3172226], [92.82917023, 13.31722069], [92.82888794, 13.31750107], [92.82861328, 13.31749916], [92.82749939, 13.31860924], [92.82749939, 13.31916809], [92.82720947, 13.31944084], [92.82720947, 13.3197298], [92.82694244, 13.3200016], [92.82694244, 13.32111168], [92.82720947, 13.32139015], [92.82722473, 13.32166767], [92.82749939, 13.32194138], [92.82749939, 13.32305622], [92.82720947, 13.32333183], [92.82720947, 13.32388973], [92.82694244, 13.32417011], [92.82694244, 13.32528019], [92.82666779, 13.3255558], [92.82666779, 13.32582855], [92.8263855, 13.32610989], [92.82639313, 13.32722187], [92.82666779, 13.32750034], [92.82666779, 13.32861042], [92.82694244, 13.32889938], [92.82694244, 13.32916641], [92.82722473, 13.32944393], [92.82722473, 13.3297224], [92.82833099, 13.33082962], [92.82833099, 13.33111], [92.82917023, 13.33194447], [92.82917023, 13.33222008], [92.83000183, 13.33306122], [92.83027649, 13.3330574], [92.83100128, 13.33377934], [92.83166504, 13.334445], [92.83194733, 13.33444023], [92.83277893, 13.33528137], [92.83277893, 13.33555698], [92.83304596, 13.33582973], [92.83304596, 13.33611107], [92.83333588, 13.33639145], [92.83361053, 13.33638859], [92.83444214, 13.33722305], [92.83444214, 13.33777046], [92.83472443, 13.33805466], [92.8347168, 13.33833122], [92.83444214, 13.33861065], [92.83444214, 13.33916664], [92.83416748, 13.33944511], [92.83416748, 13.33972263], [92.83389282, 13.34000111], [92.83388519, 13.34027672], [92.83363342, 13.34110165], [92.83444214, 13.34194469], [92.83444214, 13.34222126], [92.8347168, 13.34250069], [92.83472443, 13.34305477], [92.83499908, 13.34333134], [92.83499908, 13.34361076], [92.83528137, 13.34388924], [92.83528137, 13.3461113], [92.83555603, 13.34638977], [92.83555603, 13.34722137], [92.83528137, 13.34749889], [92.83528137, 13.34778023], [92.83499908, 13.34805584], [92.83499908, 13.34833145], [92.83444214, 13.3488903], [92.83444214, 13.34916782], [92.83389282, 13.34971046], [92.83389282, 13.35027981], [92.83361053, 13.35055637], [92.83361053, 13.35221958], [92.83388519, 13.35249996], [92.83389282, 13.35332966], [92.83416748, 13.35361195], [92.83416748, 13.35416603], [92.83444214, 13.35444355], [92.83444214, 13.35472202], [92.83528137, 13.35556126], [92.83528137, 13.3558321], [92.83555603, 13.35610962], [92.83555603, 13.35639], [92.83583069, 13.35666561], [92.83583069, 13.3572197], [92.83611298, 13.35750008], [92.83611298, 13.36000061], [92.83640289, 13.36028099], [92.83640289, 13.36139107], [92.83666992, 13.36166668], [92.83666992, 13.36194515], [92.83640289, 13.3622179], [92.83638763, 13.36305523], [92.83611298, 13.36333275], [92.83611298, 13.3661108], [92.83638763, 13.36638927], [92.83640289, 13.36694145], [92.83833313, 13.36889076], [92.83833313, 13.36916733], [92.83860779, 13.36944103], [92.83860779, 13.37000084], [92.83889008, 13.37027931], [92.83889008, 13.37138939], [92.83916473, 13.37166691], [92.83916473, 13.3736124], [92.83944702, 13.37388992], [92.83943939, 13.37472057], [92.83999634, 13.37528038], [92.83999634, 13.37555599], [92.84027863, 13.37583065], [92.84027863, 13.37611198], [92.84194183, 13.37777996], [92.84306335, 13.37777996], [92.84333038, 13.37749958], [92.84388733, 13.37749958], [92.84416962, 13.3772192], [92.84471893, 13.37722206], [92.84500122, 13.37694359], [92.84527588, 13.37694359], [92.84555817, 13.37666798], [92.8455658, 13.37639046], [92.84638977, 13.37555981], [92.84638977, 13.37528038], [92.8466568, 13.37500191], [92.8466568, 13.37472057], [92.84750366, 13.37388992], [92.84750366, 13.3736124], [92.84777832, 13.37333298], [92.84777832, 13.37277699], [92.84805298, 13.37249947], [92.84805298, 13.37222099], [92.84916687, 13.37111092], [92.84944153, 13.37111092], [92.84971619, 13.37084007], [92.85056305, 13.37084007], [92.85083008, 13.37111092], [92.85111237, 13.37111092], [92.85137939, 13.37138939], [92.85138702, 13.37166691], [92.85166931, 13.37194538], [92.85166931, 13.3736124], [92.85194397, 13.37388992], [92.85194397, 13.37444305], [92.85221863, 13.37472057], [92.85221863, 13.37528038], [92.85250092, 13.37555599], [92.85250092, 13.37583447], [92.85527802, 13.37861156], [92.85557556, 13.37863731], [92.85582733, 13.37889004], [92.85722351, 13.37889004], [92.85778046, 13.37944412], [92.85916901, 13.37944412], [92.85944366, 13.37972164], [92.86000061, 13.37972164], [92.86011505, 13.37983799], [92.8602829, 13.3800106], [92.86057281, 13.3800106], [92.86074066, 13.38018227], [92.86083221, 13.38027954], [92.86110687, 13.38027954], [92.86138916, 13.38056087], [92.86194611, 13.38055611], [92.86222076, 13.38083363], [92.86360931, 13.38083363], [92.86360931, 13.3811121], [92.86472321, 13.38111019], [92.86499786, 13.38138962], [92.86528015, 13.38138962], [92.86555481, 13.38166809], [92.86555481, 13.3819437], [92.8658371, 13.38222027], [92.8658371, 13.38360977], [92.86638641, 13.38416576], [92.86638641, 13.38444424], [92.8666687, 13.38471985], [92.8666687, 13.38528061], [92.86694336, 13.38556099], [92.86694336, 13.3866663], [92.8666687, 13.38694382], [92.8666687, 13.38722038], [92.8658371, 13.38805676], [92.86611176, 13.38833237], [92.86499786, 13.3894453], [92.86472321, 13.3894453], [92.86402893, 13.38971424], [92.86347198, 13.38916397], [92.86305237, 13.38874722], [92.86263275, 13.38861275], [92.86057281, 13.38582134], [92.86027527, 13.38583469], [92.86000061, 13.38555431], [92.85972595, 13.38556099], [92.85943604, 13.38528061], [92.85916901, 13.38527775], [92.85861206, 13.38583469], [92.85832977, 13.38583469], [92.85805511, 13.38611031], [92.8575058, 13.38611031], [92.85721588, 13.38639069], [92.85694122, 13.38639069], [92.85666656, 13.38667107], [92.85361481, 13.3866663], [92.85333252, 13.38694382], [92.85277557, 13.38694382], [92.85083008, 13.38888931], [92.85056305, 13.38888168], [92.85028076, 13.38917065], [92.84999847, 13.38916683], [92.84972382, 13.3894453], [92.84944153, 13.3894453], [92.84916687, 13.38972282], [92.84889221, 13.38971996], [92.84860992, 13.3900013], [92.84749603, 13.3900013], [92.84722137, 13.39028072], [92.84666443, 13.39027882], [92.84610748, 13.39083004], [92.84610748, 13.39166927], [92.84527588, 13.39250088], [92.84443665, 13.39250088], [92.84388733, 13.39306164], [92.84361267, 13.39305496], [92.84333038, 13.39333057], [92.84333038, 13.39361095], [92.84305573, 13.39388943], [92.84249878, 13.39444065], [92.84249878, 13.39500999], [92.84278107, 13.39528179], [92.84278107, 13.39638901], [92.84221649, 13.39694118], [92.84221649, 13.39750099], [92.84208679, 13.39819717], [92.84249878, 13.39944553], [92.84249878, 13.39972115], [92.84278107, 13.40000153], [92.84278107, 13.40027714], [92.84333038, 13.40081978], [92.84333038, 13.40166759], [92.84305573, 13.40194321], [92.84306335, 13.40222168], [92.84333038, 13.40250015], [92.84333038, 13.40277958], [92.84361267, 13.40305614], [92.84361267, 13.40333366], [92.84500122, 13.40471935], [92.84500122, 13.40499973], [92.84471893, 13.40528011], [92.84443665, 13.40528011], [92.84416962, 13.40555573], [92.84416962, 13.4058342], [92.84443665, 13.40610981], [92.84443665, 13.40666962], [92.84471893, 13.40695095], [92.84471893, 13.40722179], [92.84500122, 13.40750027], [92.84500122, 13.40805626], [92.84527588, 13.40833378], [92.84527588, 13.40861225], [92.8456955, 13.40902901], [92.84615326, 13.40948963], [92.84694672, 13.41028118], [92.84722137, 13.41028118], [92.84749603, 13.41056061], [92.84777832, 13.41055584], [92.84805298, 13.41083431], [92.84889221, 13.41083431], [92.84933472, 13.41127872], [92.84944153, 13.4113903], [92.84971619, 13.4113903], [92.84999847, 13.41167068], [92.85137939, 13.41167068], [92.85166931, 13.4113903], [92.85221863, 13.4113903], [92.85250092, 13.41110992], [92.85250092, 13.41082954], [92.85277557, 13.41055584], [92.85250092, 13.41028118], [92.85250092, 13.40944195], [92.85305786, 13.40888786], [92.85333252, 13.40888977], [92.85360718, 13.40861034], [92.85443878, 13.40861034], [92.85472107, 13.40888977], [92.85555267, 13.40888786], [92.85573578, 13.40907288], [92.85610962, 13.40944386], [92.85639191, 13.40944386], [92.85694122, 13.40888786], [92.85806274, 13.40888977], [92.85832977, 13.4091711], [92.85861206, 13.40888977], [92.85916901, 13.40888977], [92.86000061, 13.40806103], [92.86000061, 13.40666962], [92.86057281, 13.40610981], [92.86055756, 13.4058342], [92.86027527, 13.40555573], [92.8602829, 13.40528011], [92.86057281, 13.40499973], [92.86057281, 13.40444088], [92.86083221, 13.40416622], [92.86110687, 13.40418243], [92.86138916, 13.40388966], [92.86194611, 13.40388966], [92.86222076, 13.40361023], [92.86250305, 13.40361214], [92.86360931, 13.40250015], [92.8638916, 13.40250015], [92.86444092, 13.4019413], [92.86472321, 13.40194321], [92.86499786, 13.40166759], [92.86528015, 13.40167046], [92.86554718, 13.40139198], [92.8658371, 13.40139198], [92.86611176, 13.40167046], [92.86638641, 13.40166759], [92.86659241, 13.40187073], [92.8666687, 13.40194321], [92.86722565, 13.40194321], [92.86750031, 13.40222168], [92.86777496, 13.40222168], [92.86888885, 13.4033289], [92.86888885, 13.40388966], [92.86916351, 13.40416622], [92.86916351, 13.40444374], [92.8694458, 13.40471935], [92.8694458, 13.40499973], [92.86972046, 13.40528011], [92.86972046, 13.40695095], [92.8694458, 13.40722179], [92.8694458, 13.40833378], [92.86972046, 13.40861034], [92.86972046, 13.40916634], [92.87000275, 13.40944386], [92.87000275, 13.40972233], [92.87110901, 13.41082954], [92.87110901, 13.41110992], [92.87194824, 13.41194439], [92.8722229, 13.41194439], [92.87249756, 13.41166592], [92.87291718, 13.41000938], [92.87306976, 13.4093256], [92.87335205, 13.40850067], [92.87348938, 13.4078207], [92.87398529, 13.40786457], [92.87425995, 13.4078598], [92.87452698, 13.40800095], [92.87432861, 13.40864182], [92.87419128, 13.4095993], [92.873909, 13.41056061], [92.873909, 13.41084099], [92.87361145, 13.41166592], [92.87388611, 13.41194439], [92.87361145, 13.41222], [92.87361145, 13.41250038], [92.87333679, 13.41278076], [92.87333679, 13.41416645], [92.8730545, 13.41444492], [92.87304688, 13.41471958], [92.8722229, 13.41556072], [92.87166595, 13.41555691], [92.8713913, 13.41583347], [92.87055206, 13.41582966], [92.8702774, 13.41611958], [92.87000275, 13.41611958], [92.86972046, 13.41639137], [92.8694458, 13.41638947], [92.86915588, 13.41652107], [92.86917114, 13.41693974], [92.86888885, 13.41777897], [92.86847687, 13.41846943], [92.86833191, 13.41889095], [92.86847687, 13.41918087], [92.86972046, 13.42055511], [92.86972046, 13.42083263], [92.87000275, 13.42111111], [92.87000275, 13.42138863], [92.8694458, 13.42192936], [92.8694458, 13.42250061], [92.86972046, 13.42278194], [92.86972046, 13.4230547], [92.87000275, 13.42333126], [92.87000275, 13.42389202], [92.8702774, 13.42416668], [92.87032318, 13.4247694], [92.87082672, 13.42527962], [92.87110901, 13.42527962], [92.8713913, 13.42556], [92.8722229, 13.42555523], [92.87249756, 13.42583275], [92.87277985, 13.42583275], [92.87444305, 13.42416668], [92.87444305, 13.42361069], [92.875, 13.42306042], [92.8752594, 13.42333126], [92.8752594, 13.42361069], [92.87555695, 13.42388916], [92.87555695, 13.42444324], [92.87610626, 13.4249897], [92.87611389, 13.42527676], [92.87666321, 13.42583275], [92.87666321, 13.42610931], [92.87722015, 13.42666531], [92.87722015, 13.42694569], [92.87750244, 13.42694092], [92.87805176, 13.42750168], [92.87831879, 13.42750168], [92.8786087, 13.42778015], [92.87917328, 13.42778015], [92.87931824, 13.42793179], [92.87944794, 13.42805958], [92.87999725, 13.42805576], [92.88027954, 13.42833424], [92.88083649, 13.42833424], [92.88111115, 13.42861176], [92.8813858, 13.42860889], [92.88168335, 13.42889023], [92.88194275, 13.42889023], [92.88249969, 13.42944431], [92.88277435, 13.42916775], [92.88305664, 13.42916965], [92.8833313, 13.42889023], [92.8841629, 13.42972183], [92.8841629, 13.43027973], [92.88445282, 13.43056011], [92.88444519, 13.43166637], [92.8841629, 13.43194389], [92.8841629, 13.43222046], [92.88388824, 13.43249989], [92.88388824, 13.43332863], [92.88361359, 13.43360996], [92.88360596, 13.43472195], [92.8833313, 13.43500042], [92.8833313, 13.43527985], [92.88305664, 13.43555641], [92.88305664, 13.43583202], [92.88249969, 13.43638802], [92.88249969, 13.4369297], [92.88194275, 13.4375], [92.88194275, 13.43805599], [92.88222504, 13.43833447], [92.88223267, 13.43861008], [92.88249969, 13.43889141], [92.88249969, 13.43916607], [92.88276672, 13.43943977], [92.88276672, 13.43999958], [92.88222504, 13.44055653], [92.88222504, 13.44083214], [92.88194275, 13.44110966], [92.88194275, 13.44138813], [92.8813858, 13.44194508], [92.8813858, 13.44221973], [92.88111115, 13.44250107], [92.88111115, 13.44305515], [92.88083649, 13.4433279], [92.88083649, 13.44388866], [92.87999725, 13.44472313], [92.87944794, 13.44472313], [92.87916565, 13.44444466], [92.87889099, 13.44444466], [92.8786087, 13.44416714], [92.87831879, 13.44417095], [92.87805176, 13.44389057], [92.8777771, 13.44389057], [92.87759399, 13.44370365], [92.87750244, 13.44361115], [92.87666321, 13.44361115], [92.87638855, 13.44389057], [92.87611389, 13.44388866], [92.87527466, 13.44472313], [92.875, 13.44472122], [92.87473297, 13.44500065], [92.87473297, 13.44528103], [92.87361145, 13.4463892], [92.87361145, 13.44694519], [92.87333679, 13.4472208], [92.87333679, 13.44750118], [92.87304688, 13.44778061], [92.8730545, 13.44805527], [92.87361145, 13.44861126], [92.87361145, 13.44916725], [92.8741684, 13.44972134], [92.8741684, 13.45055485], [92.87388611, 13.45083141], [92.87388611, 13.45111084], [92.8741684, 13.45138931], [92.8741684, 13.45277977], [92.87444305, 13.45305538], [92.87444305, 13.45361137], [92.87473297, 13.45388985], [92.87472534, 13.45416546], [92.875, 13.45444107], [92.875, 13.45500183], [92.8752594, 13.45529079], [92.8752594, 13.45639038], [92.87554932, 13.45666981], [92.87555695, 13.45805645], [92.8758316, 13.4583292], [92.8758316, 13.45888996], [92.87610626, 13.45917034], [92.87610626, 13.46028042], [92.87473297, 13.46166992], [92.8741684, 13.46166611], [92.87388611, 13.46194363], [92.87333679, 13.46193886], [92.8722229, 13.46305561], [92.8722229, 13.46333027], [92.87194824, 13.4636097], [92.87194824, 13.46388817], [92.87110901, 13.46471977], [92.87110901, 13.46500015], [92.87083435, 13.46527767], [92.8713913, 13.46583366], [92.8713913, 13.46611023], [92.87166595, 13.46639061], [92.87166595, 13.46666622], [92.87194824, 13.46693993], [92.87194824, 13.46750069], [92.8722229, 13.46778107], [92.8722229, 13.47000122], [92.87194824, 13.47027874], [92.87194824, 13.4711113], [92.87166595, 13.47139072], [92.87277985, 13.4725008], [92.87388611, 13.47139072], [92.8741684, 13.47139072], [92.87444305, 13.4711113], [92.87472534, 13.4711113], [92.87527466, 13.47055531], [92.87555695, 13.47083473], [92.87611389, 13.47083473], [92.87638855, 13.4711113], [92.87638855, 13.47138882], [92.8769455, 13.47194481], [92.87695313, 13.47222137], [92.87722015, 13.4725008], [92.87722015, 13.47305489], [92.8769455, 13.47333336], [92.87695313, 13.47361088], [92.87666321, 13.47389126], [92.87666321, 13.47500134], [92.87695313, 13.47528076], [92.8777771, 13.47528076], [92.87805176, 13.47556019], [92.87833405, 13.47555542], [92.8786087, 13.47583294], [92.87889099, 13.47583294], [92.87916565, 13.47611141], [92.87944031, 13.47616577], [92.8795166, 13.47618198], [92.8797226, 13.47639084], [92.87999725, 13.47639084], [92.88027954, 13.47611141], [92.88054657, 13.47611141], [92.88083649, 13.47639084], [92.88111115, 13.47611141], [92.8841629, 13.47611141], [92.88500214, 13.47694302], [92.88527679, 13.47694302], [92.88555908, 13.4772234], [92.88582611, 13.47722054], [92.8861084, 13.47750092], [92.88643646, 13.47754669], [92.88667297, 13.47777939], [92.88861084, 13.47777939], [92.88889313, 13.47750092], [92.89193726, 13.47750092], [92.89221954, 13.47722054], [92.89250183, 13.4772234], [92.89472198, 13.47500134], [92.89611053, 13.47500134], [92.89639282, 13.47528076], [92.89694214, 13.47528076], [92.8972168, 13.47556019], [92.89749908, 13.47555542], [92.89778137, 13.47583294], [92.89833069, 13.47583294], [92.89861298, 13.47611141], [92.89888763, 13.47611141], [92.90055847, 13.47777939], [92.90055847, 13.478055], [92.90083313, 13.47833061], [92.90083313, 13.47861099], [92.90110779, 13.47888947], [92.90110779, 13.4800024], [92.90139008, 13.48027706], [92.90139008, 13.48083305], [92.9016571, 13.48111153], [92.9016571, 13.48167038], [92.90222168, 13.48223114], [92.90222168, 13.48250198], [92.90248871, 13.48278046], [92.90249634, 13.48305607], [92.90305328, 13.4836092], [92.90305328, 13.48388958], [92.90333557, 13.48416805], [92.90333557, 13.48444366], [92.90361023, 13.48471928], [92.90361023, 13.48750019], [92.90389252, 13.48777771], [92.90389252, 13.48861027], [92.90416718, 13.48888969], [92.90416718, 13.48916626], [92.90444183, 13.48944378], [92.90444183, 13.48972034], [92.90472412, 13.48999977], [92.90457916, 13.49221992], [92.90416718, 13.49278069], [92.90444183, 13.4930563], [92.90416718, 13.49333191], [92.90416718, 13.49361038], [92.90389252, 13.49389076], [92.90389252, 13.49416637], [92.90361023, 13.49444008], [92.90361023, 13.49528122], [92.90341949, 13.49587631], [92.90341949, 13.49670124], [92.90370178, 13.4972496], [92.90426636, 13.49752998], [92.90496063, 13.49793816], [92.90583038, 13.49833298], [92.90638733, 13.49833298], [92.90666962, 13.49861145], [92.90944672, 13.49861145], [92.90972137, 13.49833298], [92.91055298, 13.49833298], [92.91083527, 13.49805546], [92.91194153, 13.49805927], [92.91221619, 13.49777889], [92.91306305, 13.49777889], [92.91333008, 13.49750137], [92.91361237, 13.49750137], [92.91388702, 13.49777889], [92.91416931, 13.49777889], [92.91444397, 13.49805546], [92.91442871, 13.49833012], [92.91500092, 13.49889088], [92.91500092, 13.49916744], [92.91527557, 13.49944496], [92.91542053, 13.49972057], [92.91558075, 13.49998283], [92.91597748, 13.50027657], [92.91722107, 13.5002718], [92.91750336, 13.50056171], [92.91971588, 13.50056171], [92.92028046, 13.50000095], [92.92028046, 13.49972057], [92.92082977, 13.49916744], [92.92082977, 13.49805927], [92.92111206, 13.49777889], [92.92111206, 13.49667072], [92.92138672, 13.4963913], [92.92138672, 13.49611092], [92.92193604, 13.49556065], [92.9227829, 13.49556065], [92.92305756, 13.49555874], [92.92333221, 13.49583244], [92.92359924, 13.49570274], [92.92472076, 13.49611092], [92.92527771, 13.49666691], [92.92527771, 13.49694538], [92.92555237, 13.49721146], [92.92582703, 13.49763966], [92.92582703, 13.49777889], [92.92610931, 13.49805927], [92.9263916, 13.49805546], [92.92666626, 13.49833298], [92.92665863, 13.49861145], [92.92722321, 13.49916744], [92.92722321, 13.50027657], [92.92778015, 13.50083256], [92.9283371, 13.50083065], [92.92861176, 13.50111103], [92.92888641, 13.50111103], [92.92944336, 13.50166702], [92.92944336, 13.50194454], [92.92971802, 13.50222111], [92.92971802, 13.50250053], [92.92944336, 13.50278187], [92.92944336, 13.50305462], [92.92805481, 13.50444317], [92.92778015, 13.50444317], [92.92749786, 13.5047226], [92.92722321, 13.50472069], [92.92665863, 13.50527859], [92.92694092, 13.50555515], [92.92665863, 13.50583076], [92.92666626, 13.50638866], [92.92582703, 13.50722122], [92.92582703, 13.5075016], [92.92527771, 13.50805473], [92.92527771, 13.5083313], [92.92500305, 13.50861168], [92.92500305, 13.50889015], [92.92527771, 13.50916958], [92.92527771, 13.51027775], [92.92333221, 13.51220989], [92.92333221, 13.51249981], [92.92305756, 13.51278019], [92.92305756, 13.5130558], [92.92333221, 13.51332855], [92.92333221, 13.51361179], [92.92359924, 13.51389027], [92.92388916, 13.51389027], [92.9240036, 13.51400185], [92.92444611, 13.51444435], [92.92472076, 13.51444435], [92.92500305, 13.51472187], [92.92555237, 13.51472187], [92.92582703, 13.51500034], [92.92610931, 13.51500034], [92.92694092, 13.51583195], [92.92694092, 13.51666641], [92.92722321, 13.51694202], [92.92722321, 13.51749992], [92.92749786, 13.51778126], [92.92749786, 13.51861], [92.92778015, 13.51889038], [92.92778015, 13.52027798], [92.92666626, 13.52138805], [92.92610931, 13.52138805], [92.92583466, 13.52110958], [92.92555237, 13.52110958], [92.92527771, 13.52083206], [92.92500305, 13.52083206], [92.92472076, 13.5205574], [92.92444611, 13.52056122], [92.92416382, 13.52055168], [92.9236145, 13.52083206], [92.92277527, 13.52083206], [92.92222595, 13.52055168], [92.92193604, 13.52056122], [92.92166901, 13.5205574], [92.92138672, 13.52083206], [92.92111206, 13.52083206], [92.92082977, 13.52110958], [92.92055511, 13.52110958], [92.92028046, 13.52138805], [92.91999817, 13.52137947], [92.91971588, 13.5216713], [92.91944122, 13.52166557], [92.91916656, 13.521945], [92.91860962, 13.521945], [92.91833496, 13.52166557], [92.91805267, 13.521945], [92.91777802, 13.52194023], [92.91610718, 13.52361107], [92.91610718, 13.52389145], [92.91471863, 13.52528095], [92.91471863, 13.52556229], [92.91416931, 13.52611065], [92.91416931, 13.52833271], [92.91388702, 13.52861118], [92.91388702, 13.52916718], [92.91416931, 13.52944469], [92.91388702, 13.52972126], [92.91388702, 13.53111076], [92.91416931, 13.53138924], [92.91416931, 13.53166676], [92.91442871, 13.53194141], [92.91442871, 13.53249931], [92.91471863, 13.53277969], [92.91471863, 13.53306198], [92.91694641, 13.53528023], [92.91694641, 13.53555584], [92.91722107, 13.53583145], [92.91722107, 13.53611183], [92.91750336, 13.5363903], [92.91777802, 13.53638268], [92.91805267, 13.53666973], [92.91833496, 13.53666782], [92.91860962, 13.53694439], [92.91916656, 13.53694439], [92.91944122, 13.53722191], [92.91971588, 13.53722191], [92.91999817, 13.53750038], [92.92056274, 13.53750038], [92.92082977, 13.53722191], [92.92111206, 13.53722191], [92.92166901, 13.53666782], [92.92444611, 13.53666782], [92.9263916, 13.53861237], [92.92665863, 13.53861046], [92.92694092, 13.53889179], [92.92722321, 13.53889179], [92.92749786, 13.53917027], [92.92804718, 13.53917027], [92.9283371, 13.53889179], [92.93000031, 13.53889179], [92.93026733, 13.53861046], [92.93055725, 13.53889179], [92.93110657, 13.53889179], [92.93138885, 13.53917027], [92.93165588, 13.53917027], [92.9319458, 13.53945065], [92.93279266, 13.53945065], [92.93279266, 13.53917027], [92.93638611, 13.53917027], [92.9366684, 13.53945065], [92.93776703, 13.53945065], [92.93859863, 13.53861046], [92.93861389, 13.53833389], [92.93888855, 13.53805637], [92.93888855, 13.53750038], [92.93945312, 13.53694057], [92.9402771, 13.53694439], [92.94055176, 13.53666782], [92.94194794, 13.53666973], [92.9422226, 13.53638268], [92.94249725, 13.53638268], [92.94277954, 13.53666973], [92.94333649, 13.53666782], [92.94361115, 13.53694439], [92.94416809, 13.53694439], [92.94444275, 13.53666782], [92.94527435, 13.53666782], [92.9458313, 13.53722191], [92.94611359, 13.53722191], [92.94638824, 13.53694439], [92.94721985, 13.53694439], [92.94750214, 13.53722191], [92.94777679, 13.53722191], [92.94917297, 13.53861046], [92.94917297, 13.53889179], [92.94972229, 13.53944397], [92.94972229, 13.53971863], [92.94999695, 13.53999996], [92.94999695, 13.54111195], [92.95053864, 13.54166985], [92.95053864, 13.54251099], [92.95082855, 13.54277992], [92.95111084, 13.54277992], [92.95139313, 13.54306126], [92.95305634, 13.54306126], [92.95417023, 13.54417133], [92.95610809, 13.54417133], [92.95639038, 13.54389], [92.95667267, 13.54389], [92.95749664, 13.54306126], [92.95777893, 13.54306126], [92.95916748, 13.54166985], [92.96055603, 13.54166985], [92.96194458, 13.54305553], [92.96193695, 13.54333019], [92.96250153, 13.54389], [92.96305847, 13.54389], [92.96333313, 13.54417133], [92.96360779, 13.54417133], [92.96389008, 13.54389], [92.9641571, 13.54417133], [92.96444702, 13.54416561], [92.96458435, 13.54430485], [92.96472168, 13.54444408], [92.96499634, 13.54416561], [92.96527863, 13.54417133], [92.96553802, 13.54389], [92.96582794, 13.54389], [92.96639252, 13.54333019], [92.96694183, 13.5433321], [92.96749878, 13.54277802], [92.96763611, 13.54292202], [92.96833038, 13.54251099], [92.96861267, 13.54251099], [92.96916962, 13.54194164], [92.96916962, 13.54083443], [92.96888733, 13.54055595], [92.96890259, 13.53971863], [92.96916962, 13.53944397], [92.96916962, 13.53917027], [92.96971893, 13.53861046], [92.97000122, 13.53861046], [92.97006989, 13.53868008], [92.97027588, 13.53889179], [92.97055817, 13.53889179], [92.97083282, 13.53917027], [92.97138977, 13.53917027], [92.97222137, 13.53833199], [92.97222137, 13.53750038], [92.97360992, 13.53611183], [92.97360992, 13.53583145], [92.97389221, 13.53555584], [92.97389221, 13.53444099], [92.97416687, 13.53416538], [92.97416687, 13.5336113], [92.97444153, 13.53333282], [92.97444153, 13.53305531], [92.97470856, 13.53277969], [92.97470856, 13.53194141], [92.97499847, 13.53166676], [92.97499847, 13.52944088], [92.97528076, 13.52916718], [92.97528076, 13.52889061], [92.97638702, 13.52778053], [92.97693634, 13.52778053], [92.97721863, 13.52750969], [92.97805786, 13.52750969], [92.97833252, 13.52778053], [92.97860718, 13.52778053], [92.97888947, 13.52764034], [92.97915649, 13.52778053], [92.97944641, 13.52778053], [92.97972107, 13.52778053], [92.98000336, 13.52750969], [92.98027802, 13.52750969], [92.98055267, 13.52722073], [92.98110962, 13.52722263], [92.98139191, 13.52694511], [92.98222351, 13.52694511], [92.98249817, 13.52666664], [92.98332977, 13.52667141], [92.98361206, 13.52639103], [92.98390198, 13.52667141], [92.98500061, 13.52666664], [92.98527527, 13.52694511], [92.98583221, 13.52694035], [92.98638916, 13.52750969], [92.98805237, 13.52750969], [92.98832703, 13.52778053], [92.9888916, 13.52777672], [92.98944092, 13.52833271], [92.98944092, 13.52861118], [92.98999786, 13.52916718], [92.98999786, 13.52972126], [92.98970795, 13.53000069], [92.98970795, 13.53028202], [92.98944092, 13.53055477], [92.98944092, 13.53083134], [92.98970795, 13.53111076], [92.98970795, 13.53138924], [92.98999786, 13.53166962], [92.98999786, 13.53222084], [92.99028015, 13.53249931], [92.99028015, 13.53277969], [92.99055481, 13.53305531], [92.99055481, 13.53333282], [92.9908371, 13.5336113], [92.9908371, 13.53388882], [92.9916687, 13.53472137], [92.9916687, 13.53499889], [92.99194336, 13.53528023], [92.99194336, 13.53555584], [92.99222565, 13.53583431], [92.99223328, 13.53611183], [92.99194336, 13.53611183], [92.99194336, 13.53638268], [92.9916687, 13.53666973], [92.99028015, 13.53666973], [92.98999786, 13.53638268], [92.98972321, 13.53666782], [92.98972321, 13.53694439], [92.98944092, 13.53722191], [92.98944092, 13.53750038], [92.98916626, 13.53777981], [92.98916626, 13.53805637], [92.9888916, 13.53833389], [92.9888916, 13.53861237], [92.98777771, 13.53971863], [92.98777771, 13.53999996], [92.98722076, 13.54056263], [92.98722076, 13.54139042], [92.98693848, 13.54166985], [92.98694611, 13.54416561], [92.98664856, 13.54444027], [92.98664856, 13.54500008], [92.98638916, 13.54528141], [92.98555756, 13.54528141], [92.98527527, 13.54500008], [92.98194122, 13.54832077], [92.98194122, 13.54860973], [92.98166656, 13.54888821], [92.98166656, 13.54944515], [92.98139191, 13.54972267], [92.98139191, 13.55083466], [92.98110962, 13.55111122], [92.98110962, 13.55194473], [92.98084259, 13.5522213], [92.98084259, 13.55278111], [92.98110962, 13.55305481], [92.98110962, 13.55333328], [92.9814682, 13.55369091], [92.98162079, 13.55384254], [92.98194122, 13.55417061], [92.98222351, 13.55416679], [92.98361206, 13.55486202], [92.98388672, 13.55527687], [92.98472595, 13.55611134], [92.98472595, 13.55639076], [92.98500061, 13.55666733], [92.98500061, 13.55694485], [92.9852829, 13.55722141], [92.98527527, 13.55805492], [92.98513794, 13.55833054], [92.98513794, 13.55916691], [92.98486328, 13.55944538], [92.98500061, 13.55972099], [92.98472595, 13.56000233], [92.98472595, 13.56055546], [92.98443604, 13.56083107], [92.98444366, 13.5616684], [92.98472595, 13.56194305], [92.98472595, 13.56222057], [92.98555756, 13.56305981], [92.98583221, 13.56305599], [92.98750305, 13.5647192], [92.98750305, 13.56527996], [92.98777771, 13.56555557], [92.98777771, 13.56583405], [92.98805237, 13.56610966], [92.98805237, 13.56666565], [92.98832703, 13.56693935], [92.98832703, 13.56806087], [92.98838806, 13.56885147], [92.98838806, 13.56981087], [92.98804474, 13.56987858], [92.98776245, 13.56946659], [92.98726654, 13.56919098], [92.98694611, 13.5694437], [92.98693848, 13.57083035], [92.98722076, 13.57110977], [92.98722076, 13.57166576], [92.98750305, 13.57194424], [92.98750305, 13.57249069], [92.98777771, 13.57278061], [92.98777771, 13.57306099], [92.98860931, 13.57389069], [92.9888916, 13.57389069], [92.98916626, 13.57417107], [92.99028015, 13.57417107], [92.9908371, 13.57361031], [92.9908371, 13.57305431], [92.99138641, 13.57249069], [92.9916687, 13.57250023], [92.99305725, 13.57110977], [92.99360657, 13.57056141], [92.99333191, 13.57028008], [92.99360657, 13.56999969], [92.99360657, 13.56972027], [92.99388885, 13.5694437], [92.99388885, 13.56916809], [92.99415588, 13.56888962], [92.99415588, 13.56861019], [92.99388885, 13.56833363], [92.99388885, 13.56805611], [92.99360657, 13.56777954], [92.99360657, 13.56750202], [92.99305725, 13.56693935], [92.99305725, 13.56611156], [92.99388885, 13.56527805], [92.99415588, 13.56527996], [92.9944458, 13.56499958], [92.99472046, 13.56499958], [92.99500275, 13.5647192], [92.99610901, 13.56472206], [92.9963913, 13.56444359], [92.99666595, 13.56416798], [92.99694824, 13.56417179], [92.99777985, 13.56333065], [92.99944305, 13.5616684], [92.99944305, 13.56139183], [92.99973297, 13.56111145], [93.0, 13.56139183], [93.00110626, 13.56139183], [93.00138855, 13.5616703], [93.00164795, 13.5616703], [93.00193787, 13.56139183], [93.00222015, 13.56139183], [93.0027771, 13.56083107], [93.0027771, 13.56055546], [93.00305176, 13.56027699], [93.00305176, 13.56000233], [93.00332642, 13.55972099], [93.00333405, 13.55916691], [93.0036087, 13.55888939], [93.00374603, 13.55833054], [93.00415802, 13.55749702], [93.0047226, 13.55708218], [93.00518799, 13.55643463], [93.00556183, 13.55556202], [93.00602722, 13.55445194], [93.00624847, 13.55306244], [93.00630951, 13.55278111], [93.0063858, 13.55250072], [93.0063858, 13.55111122], [93.00666809, 13.55083466], [93.00666809, 13.55000114], [93.00694275, 13.5497179], [93.00694275, 13.54916668], [93.00723267, 13.54889107], [93.00723267, 13.54860973], [93.00749969, 13.54833221], [93.00749969, 13.5480566], [93.00771332, 13.54778099], [93.00771332, 13.54743195], [93.00771332, 13.54667091], [93.00778198, 13.54639053], [93.00772858, 13.5461216], [93.00765991, 13.54571056], [93.00752258, 13.54522991], [93.00737762, 13.5446806], [93.00744629, 13.54433918], [93.00772858, 13.54433727], [93.00801086, 13.54461098], [93.00829315, 13.54496193], [93.00871277, 13.54522991], [93.00913239, 13.54522991], [93.00948334, 13.54502106], [93.00971985, 13.5447216], [93.00971985, 13.54444408], [93.00944519, 13.54416561], [93.00945282, 13.54389], [93.00850677, 13.54375076], [93.00836945, 13.54327011], [93.00850677, 13.54292202], [93.0087204, 13.54230404], [93.00900269, 13.54216957], [93.00969696, 13.54203129], [93.01011658, 13.54195976], [93.01026154, 13.54203129], [93.0103302, 13.54223633], [93.01011658, 13.54244137], [93.00991058, 13.54257965], [93.00984192, 13.54292202], [93.00984192, 13.5432682], [93.01004791, 13.54354382], [93.01052856, 13.54380417], [93.01068878, 13.54389], [93.01158905, 13.54388618], [93.01187134, 13.5439539], [93.01229095, 13.54409313], [93.01276398, 13.54407883], [93.01304626, 13.54401112], [93.01332092, 13.54366684], [93.01360321, 13.5434618], [93.01436615, 13.5434618], [93.01444244, 13.54359913], [93.01444244, 13.54386997], [93.01423645, 13.54415035], [93.01409149, 13.54456043], [93.01381683, 13.54476833], [93.01352692, 13.54504108], [93.01346588, 13.54532242], [93.01352692, 13.54580021], [93.01381683, 13.54628086], [93.01381683, 13.54649067], [93.01374817, 13.54682827], [93.01369476, 13.54732513], [93.01405334, 13.54780102], [93.014328, 13.54801083], [93.01461029, 13.54849243], [93.01495361, 13.5490427], [93.01529694, 13.54945087], [93.01551819, 13.54987144], [93.01551819, 13.55049133], [93.0152359, 13.55097198], [93.01502991, 13.5515871], [93.01481628, 13.5522728], [93.01467896, 13.55282211], [93.01467896, 13.55399132], [93.01461029, 13.55447006], [93.0147171, 13.55500126], [93.01444244, 13.55527687], [93.01444244, 13.55611134], [93.01416779, 13.55638885], [93.01416779, 13.55694485], [93.01448822, 13.55710506], [93.01462555, 13.55724144], [93.01483917, 13.55724144], [93.01504517, 13.55717278], [93.01547241, 13.55689716], [93.01596069, 13.55696964], [93.01602936, 13.55731201], [93.01624298, 13.55786133], [93.01638031, 13.55820274], [93.01659393, 13.55875492], [93.0166626, 13.55944061], [93.01694489, 13.55999184], [93.01694489, 13.56054211], [93.01686859, 13.5610199], [93.01673126, 13.56171131], [93.01686859, 13.5623312], [93.01715088, 13.56253624], [93.01715088, 13.56322193], [93.01701355, 13.56356621], [93.0166626, 13.56363392], [93.01624298, 13.56336117], [93.01609802, 13.56308079], [93.01624298, 13.562397], [93.01602936, 13.56163979], [93.01582336, 13.56067753], [93.01596069, 13.56019974], [93.01574707, 13.55950928], [93.01560974, 13.55869102], [93.01539612, 13.55834007], [93.0149765, 13.55841064], [93.01477051, 13.55862045], [93.01477051, 13.55950928], [93.01462555, 13.55971718], [93.01441956, 13.5598526], [93.01441956, 13.56047058], [93.01435089, 13.56115913], [93.01444244, 13.56194115], [93.01444244, 13.56250191], [93.0147171, 13.56278038], [93.0147171, 13.56361198], [93.01499939, 13.56389046], [93.01499939, 13.56416798], [93.01527405, 13.56444359], [93.01526642, 13.5647192], [93.01555634, 13.56499958], [93.01555634, 13.56527996], [93.01583099, 13.56556034], [93.01583099, 13.56639004], [93.01611328, 13.56666565], [93.01611328, 13.56722164], [93.01659393, 13.56777763], [93.01667023, 13.5694437], [93.01638794, 13.56972027], [93.01638794, 13.56999969], [93.01611328, 13.57028008], [93.01611328, 13.57056141], [93.01721954, 13.57167053], [93.01750183, 13.57166576], [93.01805878, 13.57222176], [93.01805878, 13.57250023], [93.01916504, 13.57361031], [93.01944733, 13.57361031], [93.01972198, 13.57333374], [93.01999664, 13.57333374], [93.02027893, 13.57305431], [93.02054596, 13.57306099], [93.02083588, 13.57278061], [93.02333069, 13.57278061], [93.02443695, 13.57389069], [93.02444458, 13.57500076], [93.02500153, 13.57555199], [93.02500153, 13.57638931], [93.02555847, 13.5769453], [93.02555847, 13.57721996], [93.02610779, 13.57777882], [93.02610779, 13.57833004], [93.02639008, 13.57861137], [93.02694702, 13.57917118], [93.02722168, 13.57917118], [93.02805328, 13.57833004], [93.02805328, 13.57805538], [93.02861023, 13.5775013], [93.02861023, 13.57721996], [93.02889252, 13.5769453], [93.02889252, 13.57666683], [93.02916718, 13.57639122], [93.02916718, 13.57611275], [93.02944183, 13.57583046], [93.02944183, 13.5741663], [93.02916718, 13.57389069], [93.02916718, 13.57361031], [93.02944183, 13.57333374], [93.02944183, 13.57250023], [93.02972412, 13.57222176], [93.02972412, 13.57166576], [93.02999878, 13.57139015], [93.02999878, 13.57083035], [93.03028107, 13.57055569], [93.03028107, 13.57028008], [93.03056335, 13.56999969], [93.03056335, 13.56943035], [93.03083038, 13.56916809], [93.03083038, 13.56888962], [93.03111267, 13.56861019], [93.03111267, 13.56833363], [93.03138733, 13.56805611], [93.03138733, 13.56777954], [93.03166962, 13.56750202], [93.03166962, 13.56722164], [93.03194427, 13.56694412], [93.03194427, 13.56666565], [93.03250122, 13.56610966], [93.03250122, 13.56583405], [93.03305817, 13.56527805], [93.03305817, 13.5647192], [93.03333282, 13.56444359], [93.03333282, 13.56416798], [93.03360748, 13.56389046], [93.03360748, 13.56305981], [93.03388977, 13.56278038], [93.03388977, 13.5616703], [93.0341568, 13.56139183], [93.0341568, 13.56083107], [93.03444672, 13.56055546], [93.03444672, 13.56000233], [93.03472137, 13.55972099], [93.03472137, 13.55888939], [93.03501129, 13.55861092], [93.03500366, 13.5577774], [93.03527832, 13.55749035], [93.03527832, 13.55694485], [93.03555298, 13.55666733], [93.03555298, 13.55583096], [93.03583527, 13.55555534], [93.0358429, 13.55500126], [93.03610992, 13.55472088], [93.03610992, 13.55444527], [93.03639221, 13.55417061], [93.03639221, 13.5536108], [93.03666687, 13.55333328], [93.03666687, 13.55305481], [93.03694153, 13.55278111], [93.03694153, 13.55250072], [93.03833008, 13.55111122], [93.03833008, 13.55083466], [93.03861237, 13.55055523], [93.03861237, 13.55028057], [93.03888702, 13.55000114], [93.03888702, 13.54944038], [93.03916931, 13.54916668], [93.03916931, 13.54860973], [93.03943634, 13.54832077], [93.03944397, 13.54749966], [93.03971863, 13.54722023], [93.03971863, 13.54555416], [93.03944397, 13.5452776], [93.03943634, 13.5447197], [93.03971863, 13.54444408], [93.03971863, 13.54388809], [93.04000092, 13.54360962], [93.04000092, 13.54305553], [93.0402832, 13.54277992], [93.0402832, 13.54222202], [93.04055786, 13.54194355], [93.04055786, 13.54111195], [93.04083252, 13.54083157], [93.04125214, 13.53770161], [93.04138947, 13.53666782], [93.04138947, 13.53583145], [93.04166412, 13.53555584], [93.04165649, 13.53417015], [93.04194641, 13.53389168], [93.04194641, 13.5336113], [93.04222107, 13.53333282], [93.04222107, 13.53305531], [93.04250336, 13.53277969], [93.04250336, 13.53249931], [93.04389191, 13.53111076], [93.04389191, 13.53083134], [93.04444122, 13.53027916], [93.04444122, 13.52972126], [93.04472351, 13.52944469], [93.04472351, 13.52611065], [93.04499817, 13.52583027], [93.04499817, 13.52527905], [93.04471588, 13.52500057], [93.04471588, 13.52472115], [93.04444122, 13.52444458], [93.04444122, 13.52416706], [93.04418182, 13.52389145], [93.04418182, 13.52361107], [93.04389191, 13.5233326], [93.04389191, 13.52277946], [93.04360962, 13.52250099], [93.04360962, 13.52221966], [93.04277802, 13.52138805], [93.04277802, 13.52110958], [93.04305267, 13.52083206], [93.04305267, 13.5205574], [93.04250336, 13.52000046], [93.04250336, 13.51861], [93.04277802, 13.51834106], [93.04277802, 13.51721954], [93.04305267, 13.51694393], [93.04305267, 13.51611233], [93.04333496, 13.51583195], [93.04333496, 13.51527786], [93.04360962, 13.51500034], [93.04360962, 13.51249981], [93.04332733, 13.51220989], [93.04333496, 13.51111221], [93.04305267, 13.51083374], [93.04305267, 13.50805473], [93.04332733, 13.50778198], [93.04332733, 13.50694084], [93.04360962, 13.50666714], [93.04360962, 13.50527859], [93.04305267, 13.50472069], [93.04305267, 13.5041666], [93.04277802, 13.50389099], [93.04277802, 13.50333977], [93.04222107, 13.50278187], [93.04222107, 13.50250053], [93.04194641, 13.50222111], [93.04194641, 13.50194454], [93.04138947, 13.50138855], [93.04138947, 13.50111103], [93.04083252, 13.50056171], [93.04083252, 13.5002718], [93.04027557, 13.49972343], [93.04027557, 13.49916744], [93.04000092, 13.49889088], [93.04000092, 13.49528122], [93.0402832, 13.49500275], [93.0402832, 13.49472046], [93.04055786, 13.49444389], [93.04055786, 13.49416637], [93.04083252, 13.49389076], [93.04083252, 13.49361038], [93.04111481, 13.49333191], [93.04111481, 13.4930563], [93.04138947, 13.49278069], [93.04110718, 13.49250031], [93.04110718, 13.49193954], [93.04083252, 13.49166584], [93.04083252, 13.49110985], [93.04055786, 13.49083424], [93.04055786, 13.49027824], [93.0402832, 13.48999977], [93.0402832, 13.48972034], [93.04000092, 13.48944378], [93.04000092, 13.48750019], [93.03971863, 13.48721981], [93.03971863, 13.48666573], [93.03888702, 13.48582935], [93.03861237, 13.48583412], [93.03805542, 13.48527813], [93.03778076, 13.48527813], [93.03749847, 13.48499966], [93.03721619, 13.48499966], [93.03659058, 13.48468971], [93.03617096, 13.48456001], [93.03582001, 13.48456001], [93.03568268, 13.48442078], [93.03555298, 13.48416805], [93.03527832, 13.48388958], [93.03527832, 13.4836092], [93.03500366, 13.48333359], [93.03500366, 13.4827776], [93.03527832, 13.48250198], [93.03527832, 13.48194122], [93.03583527, 13.48139], [93.03666687, 13.48139191], [93.03743744, 13.48108196], [93.0375824, 13.48108196], [93.03785706, 13.48094463], [93.03793335, 13.48073959], [93.03785706, 13.48019123], [93.03785706, 13.47970963], [93.0375824, 13.47929955], [93.03723145, 13.47900963], [93.03666687, 13.47833347], [93.03639221, 13.47833347], [93.03527832, 13.4772234], [93.03527832, 13.47694302], [93.03500366, 13.4766674], [93.03501129, 13.47639084], [93.03472137, 13.47611141], [93.03472137, 13.47416687], [93.03501129, 13.47389126], [93.03501129, 13.47333145], [93.03527832, 13.47305489], [93.03527832, 13.47194004], [93.03555298, 13.47166729], [93.03555298, 13.47056103], [93.03501129, 13.47000122], [93.03500366, 13.46972275], [93.03444672, 13.46916676], [93.03444672, 13.46723175], [93.0341568, 13.46693993], [93.03416443, 13.46638775], [93.03360748, 13.46582985], [93.03333282, 13.46583366], [93.03194427, 13.46444416], [93.03166962, 13.46444416], [93.03138733, 13.46472168], [93.03111267, 13.46444416], [93.03083038, 13.46444416], [93.03055573, 13.46472168], [93.02999878, 13.46471977], [93.02916718, 13.46556091], [93.02889252, 13.46555424], [93.02861023, 13.46583366], [93.02777863, 13.46583366], [93.02749634, 13.46611023], [93.02722168, 13.46611023], [93.02694702, 13.46639061], [93.02639008, 13.46639061], [93.02610779, 13.46667099], [93.02583313, 13.46666622], [93.02555847, 13.46694374], [93.02527618, 13.46693993], [93.02500153, 13.46723175], [93.02471924, 13.46723175], [93.02443695, 13.46750069], [93.02388763, 13.46750069], [93.02361298, 13.46723175], [93.02278137, 13.46723175], [93.02249908, 13.46693993], [93.02194214, 13.46694374], [93.02166748, 13.46666622], [93.02083588, 13.46667099], [93.02054596, 13.46639061], [93.02027893, 13.46639061], [93.0200119, 13.46611023], [93.01944733, 13.46611023], [93.01889038, 13.46555424], [93.01889038, 13.46500015], [93.01860809, 13.46471977], [93.01860809, 13.46388817], [93.01917267, 13.46333027], [93.02055359, 13.46333408], [93.02083588, 13.46305561], [93.02139282, 13.46306133], [93.02166748, 13.46278], [93.0222168, 13.46278], [93.02249908, 13.46249962], [93.02278137, 13.46249962], [93.02307129, 13.46222019], [93.02333069, 13.4622221], [93.02361298, 13.46194363], [93.02388763, 13.46194363], [93.02416992, 13.46166611], [93.02471924, 13.46166992], [93.02500153, 13.46138954], [93.0266571, 13.46138954], [93.02694702, 13.46166992], [93.02749634, 13.46166992], [93.02777863, 13.46138954], [93.02805328, 13.46138954], [93.02861023, 13.46083164], [93.02919006, 13.46073818], [93.02967072, 13.4605608], [93.02999115, 13.46018028], [93.03040314, 13.45983124], [93.03073883, 13.45939445], [93.03108215, 13.45894909], [93.03098297, 13.45870972], [93.03098297, 13.45829105], [93.03111267, 13.45815563], [93.03166962, 13.45823097], [93.03188324, 13.45823097], [93.03217316, 13.45835018], [93.03264618, 13.45808315], [93.03273773, 13.4580307], [93.03324127, 13.45759964], [93.03359985, 13.45695019], [93.03388977, 13.45625973], [93.03411865, 13.45558071], [93.03424072, 13.45488071], [93.03463745, 13.45427036], [93.03542328, 13.45328999], [93.03569031, 13.45259953], [93.0359726, 13.45218945], [93.03569031, 13.45137119], [93.03542328, 13.45102024], [93.03520203, 13.45102024], [93.03491974, 13.4514904], [93.03485107, 13.45239735], [93.03463745, 13.4527998], [93.03414917, 13.45296192], [93.03392792, 13.45286369], [93.03379822, 13.45280933], [93.03344727, 13.45205307], [93.0333786, 13.45170784], [93.03344727, 13.45109081], [93.03394318, 13.45068073], [93.03443146, 13.45040035], [93.03472137, 13.44999886], [93.03472137, 13.44889069], [93.03501129, 13.44861126], [93.03500366, 13.44833279], [93.03516388, 13.44782734], [93.03515625, 13.44658947], [93.03530121, 13.44604015], [93.03543091, 13.44501019], [93.03588104, 13.44417953], [93.03593445, 13.44342613], [93.0358429, 13.44278145], [93.0358429, 13.44250107], [93.03555298, 13.44221973], [93.03555298, 13.44194508], [93.03527832, 13.4416666], [93.03527832, 13.44139099], [93.03501129, 13.44110966], [93.03500366, 13.44083214], [93.03472137, 13.44055653], [93.03472137, 13.43999958], [93.03444672, 13.43972015], [93.03444672, 13.4375], [93.03472137, 13.43721962], [93.03472137, 13.43527794], [93.0341568, 13.43472195], [93.03416443, 13.43444443], [93.03305817, 13.43333435], [93.03305817, 13.43305588], [93.03277588, 13.43278027], [93.03250122, 13.43278027], [93.03221893, 13.43250179], [93.03166962, 13.43250179], [93.03111267, 13.43306065], [93.03083038, 13.43305588], [93.03055573, 13.43333435], [93.02999878, 13.43332863], [93.02971649, 13.43360996], [93.02889252, 13.43360996], [93.02861023, 13.43389034], [93.0266571, 13.43389034], [93.02639008, 13.43360996], [93.02555847, 13.43360996], [93.02527618, 13.43332863], [93.02416992, 13.43333435], [93.02406311, 13.43322945], [93.02388763, 13.43305588], [93.02278137, 13.43306065], [93.0222168, 13.43278027], [93.02111053, 13.43167019], [93.02111053, 13.43112087], [93.02166748, 13.43056011], [93.02194214, 13.43056011], [93.0222168, 13.43027973], [93.02278137, 13.43027973], [93.02307129, 13.43000031], [93.02333069, 13.43000031], [93.02361298, 13.42972183], [93.02388763, 13.42972183], [93.02416992, 13.42944431], [93.02471924, 13.42944431], [93.02500153, 13.42916775], [93.02527618, 13.42916965], [93.02555847, 13.42889023], [93.02581787, 13.42889023], [93.02610779, 13.42860889], [93.02639008, 13.42861176], [93.02666473, 13.42833424], [93.02722168, 13.42833424], [93.02749634, 13.42805576], [93.02916718, 13.42805958], [93.02944183, 13.42778015], [93.03028107, 13.42778015], [93.03166962, 13.4263916], [93.03166962, 13.42583084], [93.03277588, 13.42472267], [93.03416443, 13.42472267], [93.03444672, 13.42499924], [93.03472137, 13.42499924], [93.03555298, 13.42583275], [93.0358429, 13.42583084], [93.03666687, 13.42667198], [93.03694153, 13.42666531], [93.03722382, 13.42694569], [93.03833008, 13.42694092], [93.03873444, 13.42694569], [93.03903198, 13.42695045], [93.03913879, 13.42688179], [93.0395813, 13.42660427], [93.03993225, 13.42653847], [93.04042053, 13.42654037], [93.04070282, 13.4263916], [93.04083252, 13.42583275], [93.04055786, 13.42555523], [93.04055786, 13.42472076], [93.04027557, 13.42444324], [93.04027557, 13.42388916], [93.04000092, 13.42361069], [93.04000092, 13.42333126], [93.03916931, 13.4224987], [93.03888702, 13.42250061], [93.03833008, 13.42192936], [93.03805542, 13.42194462], [93.03778076, 13.4216671], [93.03778076, 13.42139053], [93.03749847, 13.42111111], [93.03749847, 13.42083263], [93.03722382, 13.42055511], [93.03721619, 13.42028141], [93.03694153, 13.42000103], [93.03694153, 13.41972065], [93.03666687, 13.41944504], [93.03666687, 13.41861057], [93.03639221, 13.41833305], [93.03639221, 13.41666698], [93.03778076, 13.4152813], [93.04000092, 13.4152813], [93.04083252, 13.41444016], [93.04083252, 13.41416645], [93.04165649, 13.41333008], [93.04194641, 13.41333199], [93.04333496, 13.41194439], [93.04360962, 13.41194439], [93.04499817, 13.41055584], [93.04499817, 13.41028118], [93.04528046, 13.40999126], [93.04528046, 13.40888786], [93.04499817, 13.40861034], [93.04499817, 13.40833378], [93.04472351, 13.40805626], [93.04471588, 13.40777969], [93.04418182, 13.40722179], [93.04416656, 13.4058342], [93.04444122, 13.40555573], [93.04444122, 13.40471935], [93.04528046, 13.40388775], [93.04695129, 13.40388966], [93.04724121, 13.40418243], [93.04777527, 13.40416622], [93.04805756, 13.40444374], [93.0486145, 13.40444374], [93.04888916, 13.40472221], [93.04915619, 13.40471935], [93.04944611, 13.40499973], [93.04972076, 13.40499973], [93.04998779, 13.40528011], [93.05027771, 13.40528011], [93.05055237, 13.40555954], [93.05082703, 13.40555954], [93.05222321, 13.40695095], [93.05222321, 13.40722179], [93.05278015, 13.40777969], [93.05278015, 13.40805626], [93.05305481, 13.40833378], [93.05304718, 13.40861034], [93.0533371, 13.40888786], [93.0533371, 13.40944386], [93.05361176, 13.40972233], [93.05361176, 13.40999985], [93.05444336, 13.41083431], [93.05473328, 13.41082954], [93.05500031, 13.41110992], [93.05555725, 13.41110992], [93.05583191, 13.4113903], [93.0561142, 13.4113903], [93.0569458, 13.41222], [93.0569458, 13.41250038], [93.05750275, 13.41305733], [93.05750275, 13.41333199], [93.0577774, 13.41361046], [93.0577774, 13.41389084], [93.05805206, 13.41417122], [93.05805206, 13.41555691], [93.05832672, 13.41582966], [93.05833435, 13.41638947], [93.0588913, 13.41694546], [93.0588913, 13.41722107], [93.05918121, 13.41750145], [93.05916595, 13.41805458], [93.05944824, 13.41833305], [93.05944824, 13.41861057], [93.0597229, 13.41888905], [93.0597229, 13.41944027], [93.06054688, 13.42028141], [93.06062317, 13.42049122], [93.06083679, 13.42089939], [93.06138611, 13.42111111], [93.06152344, 13.42107677], [93.0616684, 13.42103958], [93.06212616, 13.42076015], [93.06253052, 13.42035198], [93.06271362, 13.41985703], [93.06263733, 13.41930103], [93.0625, 13.41805935], [93.0625, 13.41778088], [93.06236267, 13.41742992], [93.06221771, 13.41666889], [93.06221771, 13.41639137], [93.06221771, 13.41611958], [93.06208801, 13.41582966], [93.06194305, 13.41555691], [93.06181335, 13.4152813], [93.06138611, 13.41471958], [93.06138611, 13.41416645], [93.06124878, 13.4137516], [93.06111145, 13.41083431], [93.06083679, 13.41055584], [93.06083679, 13.40944195], [93.0605545, 13.40916634], [93.06054688, 13.40833187], [93.06027985, 13.40805626], [93.06027985, 13.40722179], [93.05999756, 13.40695095], [93.05999756, 13.40582943], [93.06027985, 13.40555573], [93.06027985, 13.40528011], [93.06054688, 13.40499973], [93.06054688, 13.40388966], [93.05918121, 13.40250015], [93.05916595, 13.40222168], [93.0588913, 13.40194321], [93.0588913, 13.40083408], [93.05944824, 13.40027714], [93.05944824, 13.39972115], [93.0597229, 13.39944553], [93.0597229, 13.39916706], [93.06027985, 13.39861107], [93.06054688, 13.39861107], [93.06083679, 13.39888859], [93.06111145, 13.39888859], [93.06221771, 13.40000153], [93.06221771, 13.40056038], [93.06276703, 13.4011116], [93.06277466, 13.40166759], [93.0633316, 13.40222168], [93.0633316, 13.40250015], [93.06388855, 13.40305614], [93.06388855, 13.4033289], [93.06582642, 13.40528011], [93.06639099, 13.40528011], [93.06666565, 13.40555573], [93.06694794, 13.4058342], [93.06749725, 13.4058342], [93.06777954, 13.40610981], [93.06835175, 13.40610981], [93.06916809, 13.40695095], [93.06944275, 13.40695095], [93.06999969, 13.40750027], [93.07026672, 13.40750027], [93.07055664, 13.40722179], [93.07055664, 13.40695095], [93.0708313, 13.40666962], [93.0708313, 13.40610981], [93.07027435, 13.40555573], [93.07026672, 13.40499973], [93.06999969, 13.40471935], [93.06999969, 13.40388775], [93.06973267, 13.40361023], [93.06972504, 13.40333366], [93.06916809, 13.40277767], [93.06916809, 13.40250015], [93.0688858, 13.40222168], [93.0688858, 13.40194321], [93.06861115, 13.40166759], [93.0688858, 13.40139198], [93.06859589, 13.40063953], [93.0688858, 13.4001627], [93.06881714, 13.39954376], [93.06846619, 13.39919853], [93.06832886, 13.39878178], [93.06846619, 13.39837742], [93.06902313, 13.39817142], [93.06909943, 13.39789104], [93.06916809, 13.39749908], [93.0688858, 13.3968792], [93.06832886, 13.396451], [93.06809235, 13.396492], [93.06796265, 13.39622116], [93.06754303, 13.3958807], [93.06732178, 13.39531994], [93.06690216, 13.39511108], [93.06641388, 13.39497757], [93.06556702, 13.39490986], [93.06479645, 13.39442921], [93.0642395, 13.39395142], [93.06395721, 13.3933897], [93.06388855, 13.39277744], [93.0625, 13.39138889], [93.06173706, 13.39140511], [93.06144714, 13.39147091], [93.06124878, 13.39167786], [93.06096649, 13.39202023], [93.06075287, 13.39229965], [93.05983734, 13.39229965], [93.05948639, 13.39207935], [93.0592804, 13.39181709], [93.05879211, 13.39181709], [93.05850983, 13.39188576], [93.0583725, 13.39195156], [93.05815887, 13.39229965], [93.05795288, 13.39264011], [93.05773926, 13.39278126], [93.05738831, 13.39299107], [93.05634308, 13.39299107], [93.05623627, 13.39290714], [93.05599213, 13.39271069], [93.05591583, 13.39250088], [93.05564117, 13.3920908], [93.05555725, 13.39166737], [93.05555725, 13.39111137], [93.05527496, 13.3908329], [93.05527496, 13.39055538], [93.05473328, 13.3900013], [93.05388641, 13.3900013], [93.05354309, 13.39037037], [93.05339813, 13.39072132], [93.05311584, 13.39106274], [93.05291748, 13.3911314], [93.0525589, 13.3911314], [93.05249023, 13.39058018], [93.05249023, 13.38982105], [93.05235291, 13.38954735], [93.05232239, 13.38907146], [93.05194092, 13.38861275], [93.05194092, 13.38778114], [93.05166626, 13.38750076], [93.05166626, 13.38694], [93.0513916, 13.3866663], [93.0513916, 13.38556099], [93.05110931, 13.38528061], [93.05110931, 13.38444042], [93.05083466, 13.38416576], [93.05082703, 13.38360977], [93.05110931, 13.38333035], [93.05110931, 13.38277817], [93.05082703, 13.38249969], [93.05082703, 13.38138962], [93.05055237, 13.38111019], [93.05055237, 13.38055611], [93.05027771, 13.38027954], [93.05027771, 13.3800106], [93.04998779, 13.37971973], [93.05000305, 13.37944412], [93.04972076, 13.37916565], [93.04972076, 13.37889004], [93.04944611, 13.37860966], [93.04944611, 13.37833405], [93.04916382, 13.37805557], [93.04915619, 13.37749958], [93.04895782, 13.3772192], [93.04902649, 13.3763876], [93.04902649, 13.37611198], [93.04910278, 13.37569046], [93.04902649, 13.37527847], [93.04888916, 13.37472057], [93.0486145, 13.37441444], [93.04826355, 13.37441444], [93.04805756, 13.37448215], [93.0477066, 13.37460995], [93.04742432, 13.37516975], [93.04721832, 13.37558079], [93.04679108, 13.37633991], [93.0462265, 13.37667942], [93.04580688, 13.37689114], [93.04524994, 13.37703037], [93.04483032, 13.37703037], [93.04434204, 13.37689114], [93.04377747, 13.37655163], [93.04328918, 13.37655163], [93.04266357, 13.37623882], [93.04244995, 13.37613201], [93.04230499, 13.37572002], [93.04189301, 13.37537956], [93.04174805, 13.37516975], [93.0412674, 13.37489891], [93.04006195, 13.3748951], [93.03901672, 13.37510204], [93.03837585, 13.37510014], [93.03768158, 13.37524128], [93.03704834, 13.37524128], [93.03627777, 13.37544632], [93.03543854, 13.3755827], [93.03431702, 13.37551498], [93.03368378, 13.37544632], [93.03256226, 13.37524128], [93.03144073, 13.37476921], [93.03003693, 13.37413979], [93.0289917, 13.37386036], [93.02877808, 13.37358856], [93.02828979, 13.37318134], [93.02864075, 13.37310791], [93.02906036, 13.37310791], [93.03011322, 13.3735199], [93.03277588, 13.37434483], [93.03466797, 13.37455082], [93.03592682, 13.37469196], [93.03704834, 13.37469196], [93.03775024, 13.37434959], [93.03852081, 13.37400055], [93.03957367, 13.37379646], [93.04020691, 13.37380123], [93.04132843, 13.37359142], [93.04238129, 13.37366199], [93.04322052, 13.37379646], [93.04412842, 13.37400055], [93.04489899, 13.37434483], [93.04511261, 13.37460995], [93.04560089, 13.37516975], [93.04588318, 13.37516975], [93.0461731, 13.37489891], [93.0463028, 13.37469196], [93.04707336, 13.37421131], [93.0477066, 13.37400055], [93.04798889, 13.37386513], [93.04840851, 13.3737278], [93.04911041, 13.37393093], [93.04916382, 13.37416458], [93.04972076, 13.37472057], [93.05007172, 13.37666798], [93.05117798, 13.37785339], [93.05166626, 13.37833405], [93.05194092, 13.37860966], [93.05194092, 13.37889004], [93.05222321, 13.37916565], [93.05222321, 13.37943935], [93.05278015, 13.3800106], [93.05278015, 13.38027763], [93.0533371, 13.38083363], [93.0533371, 13.3811121], [93.0541687, 13.3819437], [93.05444336, 13.3819437], [93.05472565, 13.38222218], [93.05527496, 13.38222218], [93.05583191, 13.38166809], [93.05583191, 13.38138962], [93.05612183, 13.38111019], [93.0561142, 13.38083363], [93.05638885, 13.38055611], [93.05638885, 13.38027954], [93.05722046, 13.37943935], [93.05722046, 13.37889004], [93.05750275, 13.37860966], [93.05750275, 13.37833405], [93.0577774, 13.37805557], [93.0577774, 13.37777996], [93.05805206, 13.37749958], [93.05805206, 13.3772192], [93.05833435, 13.37694359], [93.05833435, 13.3763876], [93.05860901, 13.37611198], [93.05860901, 13.37583065], [93.0588913, 13.37555599], [93.0588913, 13.37528038], [93.05918121, 13.37500191], [93.05918121, 13.37472057], [93.05944824, 13.37444305], [93.05944824, 13.37416458], [93.0597229, 13.37388039], [93.0597229, 13.37194538], [93.05999756, 13.37166691], [93.05999756, 13.37084007], [93.06027985, 13.37055969], [93.06027985, 13.36972141], [93.0605545, 13.36944485], [93.0605545, 13.36916733], [93.06083679, 13.36889076], [93.06083679, 13.36861134], [93.06138611, 13.36805534], [93.06138611, 13.36750126], [93.0619278, 13.36694145], [93.06194305, 13.36555481], [93.06221771, 13.36528111], [93.06221771, 13.36250114], [93.0625, 13.3622179], [93.0625, 13.36166668], [93.06276703, 13.36139107], [93.06276703, 13.36083031], [93.06305695, 13.3605566], [93.0633316, 13.36056137], [93.06360626, 13.36028099], [93.06388855, 13.36028099], [93.06416321, 13.36000061], [93.06472015, 13.36000061], [93.06555176, 13.35917091], [93.06555176, 13.35890198], [93.06582642, 13.35861015], [93.06583405, 13.35833359], [93.0661087, 13.35805416], [93.0661087, 13.35778141], [93.06639099, 13.35750008], [93.06639099, 13.35694027], [93.06666565, 13.35666561], [93.06667328, 13.35639], [93.06694794, 13.35610962], [93.06694794, 13.3558321], [93.06749725, 13.35527992], [93.06749725, 13.35499954], [93.06806183, 13.35444164], [93.0680542, 13.35388756], [93.06835175, 13.35361195], [93.06833649, 13.35333443], [93.06861115, 13.35305595], [93.06861115, 13.35278034], [93.0688858, 13.35249996], [93.0688858, 13.35221958], [93.06916809, 13.35194397], [93.06916809, 13.35166645], [93.06973267, 13.35111046], [93.06972504, 13.35083389], [93.06999969, 13.35083389], [93.0708313, 13.35000038], [93.0708313, 13.34971046], [93.07111359, 13.34944439], [93.07111359, 13.3488903], [93.07138824, 13.34861183], [93.07138824, 13.34833145], [93.0716629, 13.34805584], [93.0716629, 13.34749889], [93.07213593, 13.34723091], [93.07248688, 13.34722614], [93.07298279, 13.34743118], [93.0736084, 13.34749889], [93.07389069, 13.34722137], [93.07416534, 13.34722137], [93.07472229, 13.34666538], [93.07499695, 13.34666538], [93.07527924, 13.34694576], [93.07583618, 13.34694099], [93.0759964, 13.34710979], [93.07658386, 13.3477726], [93.07720947, 13.34811687], [93.07770538, 13.34839344], [93.07833099, 13.34833431], [93.07888794, 13.34777832], [93.07888794, 13.34749889], [93.07861328, 13.34722137], [93.07861328, 13.34694576], [93.07805634, 13.34638977], [93.07805634, 13.3461113], [93.07777405, 13.34583282], [93.07777405, 13.34555531], [93.07749939, 13.34527969], [93.07749939, 13.34305954], [93.07776642, 13.34278202], [93.07776642, 13.34250069], [93.07861328, 13.34167194], [93.07888794, 13.34167194], [93.07917023, 13.34139061], [93.08416748, 13.34139061], [93.08444214, 13.34167194], [93.08472443, 13.34166718], [93.08499908, 13.34194469], [93.08499908, 13.34222126], [93.08555603, 13.34278202], [93.08555603, 13.34305477], [93.08583069, 13.34333324], [93.08609772, 13.34333134], [93.08638763, 13.34361076], [93.08666992, 13.34361076], [93.08693695, 13.34333134], [93.08761597, 13.34344864], [93.08802032, 13.34313869], [93.08837128, 13.3427906], [93.08864594, 13.3425169], [93.08872223, 13.34190178], [93.08872223, 13.34121132], [93.08885956, 13.34052277], [93.08899689, 13.3399744], [93.0894165, 13.3394928], [93.08984375, 13.33901215], [93.08998108, 13.33818722], [93.09004974, 13.33722115], [93.09026337, 13.33660507], [93.09059143, 13.33593273], [93.09017181, 13.3351717], [93.08953857, 13.33462048], [93.08891296, 13.33428955], [93.0880661, 13.33366108], [93.08722687, 13.33290195], [93.08560944, 13.33227921], [93.08358002, 13.33138847], [93.08055878, 13.33139133], [93.08029175, 13.33111], [93.07971954, 13.33111], [93.07943726, 13.33082962], [93.07888794, 13.33083439], [93.07861328, 13.33055592], [93.07805634, 13.33056068], [93.07749939, 13.32999992], [93.0772171, 13.32999992], [93.07692719, 13.32971954], [93.07666779, 13.3297224], [93.07611084, 13.32916641], [93.07611084, 13.32889938], [93.07554626, 13.32833195], [93.07555389, 13.32777786], [93.07527924, 13.32750034], [93.07527924, 13.32722187], [93.07305908, 13.32499981], [93.07305908, 13.32472038], [93.07277679, 13.32444382], [93.07277679, 13.3241663], [93.07250214, 13.32388973], [93.07250214, 13.32361031], [93.07221985, 13.32333374], [93.07221985, 13.32305622], [93.07195282, 13.32277107], [93.07194519, 13.32111168], [93.07221985, 13.32083416], [93.07221985, 13.31944561], [93.07250214, 13.31916809], [93.07250214, 13.31694126], [93.07221985, 13.3166666], [93.07221985, 13.31583118], [93.07194519, 13.31555462], [93.07195282, 13.31500053], [93.0716629, 13.31472111], [93.0716629, 13.31444454], [93.07138824, 13.31416702], [93.07138824, 13.31389141], [93.0708313, 13.31333065], [93.07111359, 13.31305504], [93.0708313, 13.31278133], [93.0708313, 13.31000137], [93.07055664, 13.30972099], [93.07055664, 13.30694485], [93.06999969, 13.3063879], [93.0688858, 13.30639076], [93.0687027, 13.30620384], [93.06861115, 13.30611038], [93.0680542, 13.30611038], [93.06777954, 13.30583191], [93.06749725, 13.30583191], [93.0672226, 13.30555439], [93.06694794, 13.30556107], [93.06667328, 13.30528069], [93.06667328, 13.30473137], [93.06639099, 13.30443954], [93.06639099, 13.30388832], [93.0661087, 13.30360985], [93.0661087, 13.30333424], [93.06583405, 13.30305576], [93.06534576, 13.30326366], [93.06492615, 13.30427074], [93.06458282, 13.30510139], [93.06416321, 13.30557919], [93.0636673, 13.30585098], [93.06305695, 13.30639076], [93.06291199, 13.30680561], [93.06276703, 13.30722046], [93.06276703, 13.30750275], [93.0633316, 13.30805683], [93.0633316, 13.30832958], [93.06361389, 13.30861092], [93.06360626, 13.30972099], [93.0633316, 13.31000137], [93.0633316, 13.31027889], [93.06270599, 13.31111145], [93.0625, 13.31138897], [93.06222534, 13.31201267], [93.0619278, 13.31228924], [93.06181335, 13.31256866], [93.0616684, 13.31278133], [93.0614624, 13.31354046], [93.06138611, 13.31555462], [93.06111145, 13.31611061], [93.06111145, 13.31639194], [93.06083679, 13.31667042], [93.06083679, 13.3197298], [93.06096649, 13.31993103], [93.06083679, 13.32028198], [93.06111145, 13.32056046], [93.06111145, 13.32139015], [93.06138611, 13.32166767], [93.06138611, 13.32221889], [93.0616684, 13.32250023], [93.0616684, 13.32444382], [93.06138611, 13.32472038], [93.06138611, 13.3255558], [93.06111145, 13.32583427], [93.06111145, 13.32694435], [93.06083679, 13.32722187], [93.06083679, 13.32805634], [93.0605545, 13.32833195], [93.06054688, 13.32861042], [93.05999756, 13.32917118], [93.0597229, 13.32916641], [93.05944824, 13.32944393], [93.05722046, 13.32944393], [93.0569458, 13.32916641], [93.05638885, 13.32917118], [93.05612183, 13.32889938], [93.05526733, 13.32889938], [93.05500031, 13.32861042], [93.05472565, 13.32861233], [93.05444336, 13.32833195], [93.0541687, 13.32833195], [93.05394745, 13.32811069], [93.05361176, 13.32777786], [93.0533371, 13.32777977], [93.05278015, 13.32722187], [93.05249786, 13.32722187], [93.05207825, 13.32680321], [93.05166626, 13.32639027], [93.05166626, 13.32611179], [93.05110931, 13.32556057], [93.05110931, 13.32528019], [93.05055237, 13.32472038], [93.05055237, 13.32444382], [93.05027771, 13.3241663], [93.05027771, 13.32388973], [93.04915619, 13.32277107], [93.04888916, 13.32277775], [93.04777527, 13.32166767], [93.04750061, 13.32166958], [93.04695129, 13.32111168], [93.04666901, 13.32111168], [93.04638672, 13.3208313], [93.04611206, 13.32083416], [93.04520416, 13.32069206], [93.04333496, 13.32062435], [93.04277802, 13.32083416], [93.04250336, 13.3208313], [93.04222107, 13.32111168], [93.04194641, 13.32111168], [93.04165649, 13.32139015], [93.04138947, 13.32139015], [93.04110718, 13.32166958], [93.04083252, 13.32166767], [93.04055786, 13.32194424], [93.0402832, 13.32221889], [93.03985596, 13.32298088], [93.03971863, 13.3255558], [93.04000092, 13.32582855], [93.04000092, 13.32666588], [93.0402832, 13.32694244], [93.0402832, 13.32777977], [93.04055786, 13.32805634], [93.04055786, 13.32944393], [93.04083252, 13.32971954], [93.04083252, 13.33055592], [93.04110718, 13.33082962], [93.04110718, 13.33250046], [93.04138947, 13.33277893], [93.04138947, 13.33360958], [93.04110718, 13.33389091], [93.04111481, 13.33416653], [93.04138947, 13.334445], [93.04138947, 13.33833122], [93.04165649, 13.33861065], [93.04166412, 13.33916664], [93.04444122, 13.34194088], [93.04444122, 13.34250069], [93.04472351, 13.34277725], [93.04471588, 13.34333134], [93.04499817, 13.34361076], [93.04499817, 13.34416676], [93.04528046, 13.34444141], [93.04528046, 13.34499931], [93.04555511, 13.34527683], [93.04555511, 13.34583282], [93.04582977, 13.3461113], [93.04582977, 13.34722137], [93.04556274, 13.34749889], [93.04555511, 13.34805584], [93.04528046, 13.34833145], [93.04528046, 13.3488903], [93.04499817, 13.34916973], [93.04499817, 13.35055637], [93.04471588, 13.35083199], [93.04471588, 13.35139179], [93.04444122, 13.35166645], [93.04444122, 13.35221958], [93.04418182, 13.35249996], [93.04418182, 13.35278034], [93.04389191, 13.35306072], [93.04389191, 13.35361195], [93.04360962, 13.35388756], [93.04360962, 13.35472202], [93.04332733, 13.35499954], [93.04332733, 13.35527992], [93.04305267, 13.35556126], [93.04305267, 13.3558321], [93.04194641, 13.35694408], [93.04194641, 13.3572197], [93.04111481, 13.35805416], [93.04110718, 13.35832977], [93.04027557, 13.35916615], [93.0402832, 13.35943985], [93.03971863, 13.36000061], [93.03971863, 13.36028099], [93.03943634, 13.36056137], [93.03943634, 13.36110973], [93.03916931, 13.36139107], [93.03916931, 13.36166668], [93.03943634, 13.36194038], [93.03943634, 13.36278057], [93.03971863, 13.36305523], [93.03971863, 13.36361122], [93.04027557, 13.36416721], [93.04027557, 13.36444473], [93.04055786, 13.3647213], [93.04055786, 13.36500072], [93.04083252, 13.36528111], [93.04083252, 13.36555481], [93.04110718, 13.36583138], [93.04111481, 13.36638927], [93.04166412, 13.36694527], [93.04166412, 13.36722088], [93.04083252, 13.36722088], [93.04055786, 13.36694527], [93.04000092, 13.36694527], [93.03971863, 13.36666679], [93.03943634, 13.36667156], [93.03905487, 13.3662796], [93.0389328, 13.36615181], [93.03861237, 13.3661108], [93.03805542, 13.36555481], [93.03778076, 13.36556244], [93.03749847, 13.36528111], [93.03749847, 13.36500072], [93.03721619, 13.3647213], [93.03722382, 13.36388874], [93.03694153, 13.36361122], [93.03694153, 13.36333275], [93.03666687, 13.36305523], [93.03608704, 13.36312103], [93.03581238, 13.36312103], [93.03530884, 13.36292458], [93.03504181, 13.36248875], [93.03517914, 13.36201096], [93.03497314, 13.36146069], [93.03482819, 13.36118126], [93.03475952, 13.36083889], [93.03460693, 13.36063194], [93.0345459, 13.36049461], [93.03504181, 13.36063194], [93.03539276, 13.36077118], [93.03573608, 13.36083889], [93.03573608, 13.36118126], [93.03594971, 13.3615303], [93.03623199, 13.36180973], [93.03665161, 13.36208057], [93.03833008, 13.36028099], [93.03833008, 13.35972023], [93.03971863, 13.35833359], [93.03971863, 13.35805416], [93.04055786, 13.3572197], [93.04055786, 13.35694408], [93.04083252, 13.35666561], [93.04083252, 13.35639], [93.04110718, 13.35610962], [93.04111481, 13.3558321], [93.04138947, 13.35556126], [93.04138947, 13.35472202], [93.04166412, 13.35444355], [93.04166412, 13.35361195], [93.04138947, 13.35332966], [93.04138947, 13.35277843], [93.04110718, 13.35249996], [93.04110718, 13.3519392], [93.04083252, 13.35166645], [93.04083252, 13.35139179], [93.04000092, 13.35056019], [93.03971863, 13.35056019], [93.03943634, 13.35027981], [93.03861237, 13.35027981], [93.03833008, 13.35000038], [93.03804779, 13.35000038], [93.03794098, 13.34988308], [93.03778076, 13.34971046], [93.03694153, 13.34972191], [93.03666687, 13.34944439], [93.03500366, 13.34944439], [93.03472137, 13.34916782], [93.03444672, 13.34916973], [93.03396606, 13.34869099], [93.03360748, 13.34833145], [93.03360748, 13.34805584], [93.03320313, 13.34743118], [93.0331955, 13.34583282], [93.03278351, 13.34527493], [93.03202057, 13.3451376], [93.03083038, 13.34583282], [93.03055573, 13.34583282], [93.03028107, 13.3461113], [93.02916718, 13.3461113], [93.02889252, 13.34583282], [93.02861023, 13.34583282], [93.02805328, 13.34527683], [93.02777863, 13.34527969], [93.02749634, 13.34514141], [93.02722168, 13.34527493], [93.02639008, 13.34583282], [93.02639008, 13.3461113], [93.02610779, 13.34639168], [93.02610779, 13.34666538], [93.02583313, 13.34694576], [93.02581787, 13.34722137], [93.02500153, 13.34805965], [93.02471924, 13.34805584], [93.02443695, 13.34833145], [93.02416992, 13.34861183], [93.02388763, 13.34861183], [93.02361298, 13.3488903], [93.02249908, 13.3488903], [93.0222168, 13.34916973], [93.02166748, 13.34916782], [93.02138519, 13.34944439], [93.02083588, 13.34944439], [93.02055359, 13.34972191], [93.02027893, 13.34972191], [93.0200119, 13.35000038], [93.01944733, 13.35000038], [93.01917267, 13.35027981], [93.01889038, 13.35027981], [93.01860809, 13.35056019], [93.01832581, 13.35027981], [93.01805878, 13.35027981], [93.01750183, 13.34971046], [93.01721954, 13.34972191], [93.01694489, 13.34944439], [93.01583099, 13.34944057], [93.01499939, 13.35027981], [93.01499939, 13.35056019], [93.01416779, 13.35139179], [93.01387787, 13.35139179], [93.01361084, 13.35167027], [93.01333618, 13.35167027], [93.01249695, 13.35249996], [93.01194763, 13.35249996], [93.01167297, 13.35278034], [93.01081848, 13.35278034], [93.01055908, 13.35306072], [93.00749969, 13.35305595], [93.00722504, 13.35333443], [93.00554657, 13.35332966], [93.00527954, 13.35361195], [93.00501251, 13.35332966], [93.0047226, 13.35332966], [93.00444794, 13.35361195], [93.00416565, 13.35361195], [93.00389099, 13.35333443], [93.00333405, 13.35333443], [93.00250244, 13.35249996], [93.00250244, 13.35221958], [93.0019455, 13.35166645], [93.00164795, 13.35167027], [93.00138855, 13.35139179], [93.00110626, 13.35139179], [93.0008316, 13.35111046], [93.00055695, 13.35111237], [93.00027466, 13.35083389], [93.0, 13.35083389], [92.99848175, 13.34971714], [92.99828339, 13.34950066], [92.99804688, 13.34930038], [92.99777985, 13.34916782], [92.99666595, 13.34805965], [92.99666595, 13.34778023], [92.99500275, 13.3461113], [92.99472046, 13.3461113], [92.9944458, 13.34583282], [92.99416351, 13.34583282], [92.99305725, 13.34472084], [92.99262238, 13.34457111], [92.99225616, 13.34437275], [92.99196625, 13.34414005], [92.99173737, 13.34390068], [92.99156189, 13.34367085], [92.99140167, 13.34339046], [92.99107361, 13.34328079], [92.99079895, 13.34302998], [92.99046326, 13.34276962], [92.9901123, 13.3424511], [92.98983002, 13.34204102], [92.98960114, 13.34155464], [92.98937988, 13.34111309], [92.98917389, 13.34069633], [92.9890213, 13.34028053], [92.98889923, 13.3398962], [92.98880005, 13.3395319], [92.98863983, 13.33920956], [92.98861694, 13.338871], [92.98871613, 13.33851528], [92.98886108, 13.33810043], [92.98886108, 13.33764935], [92.98871613, 13.33720016], [92.98862457, 13.33677387], [92.98860931, 13.33636761], [92.98860931, 13.33597183], [92.98864746, 13.33557701], [92.98884583, 13.33518982], [92.9888916, 13.33477497], [92.9888916, 13.33437157], [92.9888916, 13.33400726], [92.9888916, 13.33368111], [92.98887634, 13.33335972], [92.9888916, 13.33303165], [92.98895264, 13.33265972], [92.98912048, 13.33226967], [92.98919678, 13.33175087], [92.98934937, 13.33119011], [92.98940277, 13.33065033], [92.98915863, 13.33018017], [92.98880768, 13.32977676], [92.98834991, 13.32947159], [92.98779297, 13.3293066], [92.98725891, 13.32916164], [92.98677826, 13.32901096], [92.9863205, 13.32889938], [92.98586273, 13.32889938], [92.98540497, 13.32892895], [92.98501587, 13.32914066], [92.98470306, 13.32934189], [92.98438263, 13.32944202], [92.98409271, 13.32954025], [92.98387909, 13.32976055], [92.98365784, 13.33000946], [92.98339844, 13.33028126], [92.98309326, 13.33056068], [92.98274994, 13.33088017], [92.98246002, 13.33128262], [92.98213196, 13.3316412], [92.98178864, 13.33195972], [92.98149109, 13.33226585], [92.98127747, 13.33262062], [92.98106384, 13.33297729], [92.98083496, 13.33333206], [92.98084259, 13.33360958], [92.98027802, 13.33416653], [92.98000336, 13.334445], [92.97972107, 13.33471107], [92.97972107, 13.33528137], [92.97944641, 13.33555698], [92.97944641, 13.33694458], [92.97956085, 13.33740139], [92.97961426, 13.33791637], [92.97966003, 13.33832073], [92.97949219, 13.33862019], [92.97941589, 13.3390007], [92.97924042, 13.33936977], [92.97897339, 13.33976173], [92.97866058, 13.34023094], [92.97834015, 13.3407402], [92.97803497, 13.34123611], [92.97767639, 13.34164047], [92.97730255, 13.34197903], [92.97696686, 13.34234047], [92.97672272, 13.34276104], [92.97666931, 13.343297], [92.97666168, 13.34383202], [92.9766922, 13.34432507], [92.97681427, 13.34472275], [92.97692871, 13.34508419], [92.97701263, 13.34543228], [92.97717285, 13.34570122], [92.97724152, 13.34599113], [92.97735596, 13.34623909], [92.97747803, 13.34645081], [92.97750092, 13.34669018], [92.97744751, 13.34697056], [92.97725677, 13.34729004], [92.97714996, 13.3476696], [92.97695923, 13.34801006], [92.97679901, 13.34833431], [92.97663116, 13.34863377], [92.97638702, 13.3488903], [92.9761734, 13.34916973], [92.97598267, 13.34942055], [92.9757843, 13.34963512], [92.97556305, 13.34975147], [92.97531128, 13.34989929], [92.97486877, 13.34982014], [92.97441101, 13.34983063], [92.97415924, 13.34972572], [92.97389221, 13.3495779], [92.97363281, 13.34934998], [92.97338104, 13.34908104], [92.97319031, 13.34874439], [92.97296143, 13.34838581], [92.97264862, 13.34809017], [92.97231293, 13.34791183], [92.9720459, 13.34799194], [92.97184753, 13.34828091], [92.97164154, 13.34854126], [92.97144318, 13.34880066], [92.97133636, 13.3491497], [92.97115326, 13.34943676], [92.97112274, 13.34976006], [92.97113037, 13.35004997], [92.97122955, 13.35027122], [92.97137451, 13.35046005], [92.97150421, 13.35066128], [92.97167206, 13.3508606], [92.9717865, 13.35111046], [92.97193146, 13.35139179], [92.97203064, 13.35174084], [92.97219086, 13.35210133], [92.97222137, 13.35249138], [92.97220612, 13.35286045], [92.97210693, 13.35321999], [92.97200012, 13.35354137], [92.97186279, 13.35384178], [92.9716568, 13.3540659], [92.97141266, 13.35424995], [92.97113037, 13.35445499], [92.97080231, 13.3546896], [92.9703598, 13.35487175], [92.9699707, 13.35523701], [92.96963501, 13.35569954], [92.96959686, 13.35620975], [92.96982574, 13.35668659], [92.97000122, 13.357131], [92.97014618, 13.35750008], [92.97029114, 13.35781002], [92.9704361, 13.35808182], [92.97054291, 13.35837555], [92.97058105, 13.35869503], [92.97058105, 13.3590107], [92.97061157, 13.35930061], [92.97068024, 13.35953999], [92.97062683, 13.35977268], [92.97046661, 13.35998917], [92.97018433, 13.3601923], [92.96980286, 13.3603096], [92.96942902, 13.36052036], [92.96904755, 13.36056137], [92.96868896, 13.36056137], [92.96833038, 13.36056995], [92.9679718, 13.36062717], [92.96759033, 13.36069298], [92.96724701, 13.36077118], [92.96692657, 13.36068439], [92.96657562, 13.36057472], [92.96617126, 13.36053181], [92.96578979, 13.36038113], [92.96539307, 13.36026001], [92.96507263, 13.36007977], [92.96473694, 13.35992146], [92.9644165, 13.3597002], [92.96411896, 13.35940075], [92.96379089, 13.3590498], [92.96356964, 13.35859203], [92.96333313, 13.35806084], [92.96305847, 13.35778141], [92.96305847, 13.35750008], [92.96276855, 13.3572197], [92.96277618, 13.35638809], [92.96250153, 13.35610962], [92.96250153, 13.3558321], [92.96193695, 13.35527992], [92.96166992, 13.35527992], [92.96138763, 13.35499954], [92.96083069, 13.35499954], [92.96072388, 13.35488796], [92.96028137, 13.35444164], [92.96028137, 13.35388756], [92.95999908, 13.35361195], [92.95992279, 13.35311127], [92.95975494, 13.35274792], [92.95967865, 13.3523016], [92.95947266, 13.3519392], [92.95923615, 13.35158062], [92.95907593, 13.35115147], [92.95886993, 13.35073757], [92.95854187, 13.35032845], [92.9581604, 13.34989929], [92.957901, 13.34931087], [92.95759583, 13.34883308], [92.95741272, 13.3483839], [92.95722198, 13.34803295], [92.95703888, 13.3477211], [92.95688629, 13.34735107], [92.95664978, 13.34701633], [92.95633698, 13.34668064], [92.95604706, 13.34632111], [92.95581055, 13.34589958], [92.95555115, 13.34547138], [92.95529175, 13.34499931], [92.95504761, 13.34447956], [92.95464325, 13.34411335], [92.95417023, 13.3439436], [92.95374298, 13.34405994], [92.95334625, 13.34427929], [92.95305634, 13.34444332], [92.95276642, 13.34444141], [92.95249939, 13.34472084], [92.9522171, 13.34472084], [92.95166779, 13.34527969], [92.95139313, 13.34527969], [92.95111084, 13.34499931], [92.95111084, 13.34472084], [92.95082855, 13.34444141], [92.95083618, 13.34416676], [92.95053864, 13.34390068], [92.95059204, 13.34359074], [92.95078278, 13.34322166], [92.95089722, 13.34288406], [92.95105743, 13.34263611], [92.95111084, 13.34239197], [92.95128632, 13.34204102], [92.95144653, 13.34187889], [92.95166779, 13.34167194], [92.95191956, 13.34142971], [92.95223999, 13.3412199], [92.95256805, 13.34103107], [92.95284271, 13.34077072], [92.95305634, 13.34044838], [92.95324707, 13.34006023], [92.95336914, 13.33957863], [92.9535675, 13.33917236], [92.95361328, 13.3387413], [92.95359802, 13.33835125], [92.95361328, 13.33798218], [92.95361328, 13.33759022], [92.95359039, 13.33714104], [92.95349884, 13.33665085], [92.95359039, 13.33611107], [92.95359039, 13.33550358], [92.95346069, 13.3348484], [92.95334625, 13.33418179], [92.95337677, 13.33355999], [92.9535675, 13.3331089], [92.95378113, 13.33278084], [92.95401001, 13.3325367], [92.95430756, 13.33236599], [92.95468903, 13.33221054], [92.95509338, 13.33199024], [92.95549774, 13.33180141], [92.95582581, 13.33150864], [92.95612335, 13.33119011], [92.95643616, 13.33087063], [92.95680237, 13.33055019], [92.95716858, 13.33020115], [92.95751953, 13.32982159], [92.95788574, 13.32946491], [92.95825958, 13.32913208], [92.95858002, 13.32877159], [92.95888519, 13.32833195], [92.95888519, 13.32805634], [92.95916748, 13.32777977], [92.95944214, 13.32777977], [92.95973206, 13.32750034], [92.95999908, 13.32777977], [92.96028137, 13.32777977], [92.96055603, 13.3280611], [92.96083069, 13.3280611], [92.96111298, 13.32777977], [92.96147919, 13.327981], [92.96196747, 13.32772636], [92.96225739, 13.32727242], [92.96247101, 13.32683182], [92.96253967, 13.32642174], [92.96272278, 13.32614613], [92.962883, 13.32586098], [92.96309662, 13.3255806], [92.96338654, 13.32530117], [92.96372986, 13.32505035], [92.96412659, 13.32489014], [92.9644928, 13.32470989], [92.96478271, 13.32452106], [92.96509552, 13.32445145], [92.96544647, 13.32444096], [92.96582794, 13.32449245], [92.96626282, 13.32468128], [92.96673584, 13.32463074], [92.96720123, 13.32453346], [92.96765137, 13.32439995], [92.96807861, 13.32419968], [92.96855927, 13.32414532], [92.96900177, 13.3240242], [92.96942139, 13.32388115], [92.96981049, 13.32368946], [92.97020721, 13.3236208], [92.97061157, 13.32361031], [92.97100067, 13.32361031], [92.97138214, 13.32361031], [92.9717865, 13.3236208], [92.97219849, 13.32371044], [92.9726181, 13.32384014], [92.97305298, 13.32388973], [92.97348022, 13.32388973], [92.97389984, 13.32388973], [92.97431946, 13.32388973], [92.97472382, 13.32392406], [92.97507477, 13.32407475], [92.9754715, 13.32415199], [92.97592163, 13.32417011], [92.97636414, 13.32417011], [92.97679138, 13.32419968], [92.97720337, 13.32434082], [92.97759247, 13.32421112], [92.97802734, 13.32415199], [92.97845459, 13.32403088], [92.97883606, 13.32380962], [92.97915649, 13.32344055], [92.97944641, 13.32297802], [92.97973633, 13.32247925], [92.98002625, 13.32204628], [92.98033142, 13.321702], [92.98062897, 13.32146931], [92.98095703, 13.32134438], [92.98122406, 13.32115746], [92.98152161, 13.32099056], [92.98178101, 13.32079029], [92.98206329, 13.32058144], [92.9823761, 13.32040119], [92.98273468, 13.32029343], [92.98312378, 13.32027721], [92.98351288, 13.32028198], [92.9838562, 13.32024097], [92.98416901, 13.32003975], [92.98448944, 13.3200016], [92.98480225, 13.31999683], [92.9850769, 13.31996059], [92.98532104, 13.31976032], [92.98556519, 13.31949806], [92.98578644, 13.31915188], [92.98583221, 13.31870937], [92.98583984, 13.31826019], [92.98591614, 13.31787968], [92.98612213, 13.31762695], [92.98639679, 13.31742191], [92.98670959, 13.31723022], [92.98694611, 13.3172226], [92.98860931, 13.3172226], [92.9888916, 13.31694317], [92.98916626, 13.31694317], [92.98944092, 13.3172226], [92.98972321, 13.3172226], [92.98999786, 13.31694317], [92.99055481, 13.31694317], [92.9908371, 13.3166666], [92.99138641, 13.31667042], [92.99191284, 13.31655979], [92.99230194, 13.31637955], [92.99266052, 13.31616974], [92.99305725, 13.31609058], [92.99339294, 13.31592178], [92.99370575, 13.31584167], [92.99402618, 13.31583309], [92.99433899, 13.31583309], [92.99464417, 13.31583309], [92.99495697, 13.31583309], [92.99528503, 13.31583309], [92.99562836, 13.31583309], [92.99595642, 13.31583118], [92.99632263, 13.31583977], [92.99669647, 13.31583118], [92.99717712, 13.31575108], [92.99767303, 13.31554127], [92.99812317, 13.31525421], [92.99845123, 13.31485844], [92.99858856, 13.31438065], [92.99862671, 13.31393242], [92.99860382, 13.31351757], [92.99852753, 13.31312084], [92.99833679, 13.31274033], [92.99813843, 13.31228924], [92.99784851, 13.31215], [92.99782562, 13.31201267], [92.99953461, 13.31071186], [92.99973297, 13.31139088], [93.0, 13.31166744], [93.00055695, 13.31222057], [93.0008316, 13.31250095], [93.0008316, 13.31278133], [93.00111389, 13.31305504], [93.00111389, 13.31333256], [93.00138855, 13.31359959], [93.00138855, 13.31389141], [93.00166321, 13.31416702], [93.00164795, 13.31444073], [93.00222015, 13.31500053], [93.00222015, 13.3152771], [93.0027771, 13.31583309], [93.0027771, 13.31611061], [93.00305176, 13.31639194], [93.00305176, 13.3166666], [93.00333405, 13.31694317], [93.00332642, 13.31722069], [93.00583649, 13.3197298], [93.00611115, 13.3197298], [93.0063858, 13.3200016], [93.00666809, 13.3200016], [93.00694275, 13.32028198], [93.00749969, 13.32027721], [93.0076828, 13.32046413], [93.00778198, 13.32056046], [93.00888824, 13.32056046], [93.00945282, 13.3200016], [93.00945282, 13.31694126], [93.0091629, 13.3166666], [93.0091629, 13.31611061], [93.00888824, 13.31583309], [93.00888824, 13.31555462], [93.0091629, 13.31528187], [93.00888824, 13.31500053], [93.00888824, 13.31472111], [93.00861359, 13.31444454], [93.00861359, 13.31361103], [93.0083313, 13.31333256], [93.0083313, 13.31305504], [93.0080719, 13.31278133], [93.0080719, 13.31250095], [93.00749969, 13.31194019], [93.00749969, 13.31166744], [93.00694275, 13.31111145], [93.0067749, 13.31006718], [93.00676727, 13.30930996], [93.00698853, 13.30902958], [93.00712585, 13.30902958], [93.00733948, 13.30937862], [93.00778198, 13.30972099], [93.00826263, 13.31000137], [93.00888824, 13.31000137], [93.0091629, 13.31000137], [93.00945282, 13.31000137], [93.00986481, 13.30992794], [93.01027679, 13.30972099], [93.01166534, 13.3083334], [93.01194763, 13.3083334], [93.01333618, 13.30694485], [93.01340485, 13.30666637], [93.01354218, 13.30639076], [93.01361084, 13.30590057], [93.01361084, 13.30555439], [93.01374817, 13.30500031], [93.01387787, 13.30473137], [93.01387787, 13.30443954], [93.01416779, 13.30416584], [93.01416779, 13.30389023], [93.01409912, 13.30368137], [93.01416779, 13.30340004], [93.01416779, 13.30305576], [93.01374817, 13.30229092], [93.01361084, 13.30194378], [93.01305389, 13.30138779], [93.01304626, 13.30027962], [93.01361084, 13.29971981], [93.01361084, 13.2994442], [93.0138855, 13.29916573], [93.01387787, 13.29889011], [93.01416779, 13.29860115], [93.01493835, 13.29830933], [93.01567841, 13.29796886], [93.01638794, 13.29777813], [93.01772308, 13.29780102], [93.01799011, 13.29758167], [93.01792145, 13.29676819], [93.01806641, 13.29656124], [93.0182724, 13.29656124], [93.01853943, 13.2967701], [93.01869965, 13.29684067], [93.01925659, 13.29691029], [93.01960754, 13.29697609], [93.0200119, 13.29721928], [93.02027893, 13.29749966], [93.02036285, 13.29758358], [93.02062225, 13.29784393], [93.02138519, 13.29777813], [93.02153015, 13.29749966], [93.02166748, 13.29728985], [93.02166748, 13.29694366], [93.02173615, 13.29666805], [93.02166748, 13.29638958], [93.02166748, 13.29611015], [93.02166748, 13.29555607], [93.02194214, 13.29528046], [93.02194214, 13.29444122], [93.02111053, 13.29361153], [93.02027893, 13.29354095], [93.01972198, 13.29333401], [93.01777649, 13.29333401], [93.01743317, 13.29354095], [93.01721954, 13.29361153], [93.01703644, 13.29394722], [93.01654816, 13.29421997], [93.01605988, 13.29457092], [93.01542664, 13.29483986], [93.01451111, 13.29511642], [93.01409149, 13.29532146], [93.01338959, 13.29545975], [93.01270294, 13.29539204], [93.01255035, 13.29518032], [93.01255035, 13.29483986], [93.01261902, 13.29457092], [93.01290131, 13.2941494], [93.01332092, 13.29373932], [93.01367188, 13.29326057], [93.01387787, 13.29298019], [93.01444244, 13.29277706], [93.01499939, 13.29222107], [93.01555634, 13.29222107], [93.01638794, 13.29138947], [93.01638794, 13.29111099], [93.01667023, 13.29083061], [93.01667023, 13.2897234], [93.01611328, 13.2891674], [93.01611328, 13.28889179], [93.01555634, 13.28833103], [93.01555634, 13.28805542], [93.01526642, 13.28778172], [93.01526642, 13.28750134], [93.01499939, 13.28722095], [93.01499939, 13.28694534], [93.01472473, 13.28666687], [93.01472473, 13.28638935], [93.01416779, 13.28583145], [93.01416779, 13.28555489], [93.01409912, 13.28528118], [93.01387787, 13.28499889], [93.01381683, 13.2841692], [93.01333618, 13.28382015], [93.01249695, 13.28306103], [93.01222229, 13.28306103], [93.01194763, 13.28278065], [93.01167297, 13.28278065], [93.01139069, 13.28250122], [93.0111084, 13.28250122], [93.01081848, 13.28222275], [93.01081848, 13.28056145], [93.0111084, 13.28028107], [93.0111084, 13.27943993], [93.01139069, 13.27916622], [93.01139069, 13.27861023], [93.01166534, 13.27833462], [93.01166534, 13.27750015], [93.01249695, 13.27666569], [93.01304626, 13.27667141], [93.01333618, 13.27639008], [93.01361084, 13.27639008], [93.01387787, 13.27667141], [93.01472473, 13.27666569], [93.01499939, 13.27694416], [93.01526642, 13.27694035], [93.01611328, 13.27778053], [93.01638794, 13.27777767], [93.01694489, 13.27833462], [93.01721954, 13.27833462], [93.01777649, 13.27777767], [93.01832581, 13.27778053], [93.01860809, 13.27749062], [93.0200119, 13.27749062], [93.02035522, 13.27785969], [93.02054596, 13.27806091], [93.02083588, 13.27805424], [93.02111053, 13.27833462], [93.02166748, 13.27833462], [93.02194214, 13.27861023], [93.0222168, 13.27861023], [93.02416992, 13.28055668], [93.02416992, 13.28083229], [93.02443695, 13.2811079], [93.02443695, 13.28139114], [93.02471924, 13.28166676], [93.02471924, 13.28194523], [93.02487946, 13.28264046], [93.02502441, 13.28314972], [93.0252533, 13.28349018], [93.02593994, 13.2837019], [93.02622223, 13.28363132], [93.02635956, 13.28349495], [93.02635956, 13.28301144], [93.02622223, 13.28273773], [93.02635956, 13.28225708], [93.02664185, 13.28198147], [93.02761841, 13.28198147], [93.02796936, 13.28205204], [93.02839661, 13.28205204], [93.02909088, 13.2817812], [93.0302124, 13.2806797], [93.03063965, 13.27992058], [93.03083038, 13.27972031], [93.03083038, 13.27888775], [93.03111267, 13.27861023], [93.03111267, 13.27805424], [93.03138733, 13.27778053], [93.03138733, 13.27721977], [93.03221893, 13.27638817], [93.03250122, 13.27639008], [93.03277588, 13.2761097], [93.03388977, 13.2761097], [93.0341568, 13.27639008], [93.03444672, 13.27639008], [93.03444672, 13.27666569], [93.03472137, 13.27694416], [93.03472137, 13.27721977], [93.03778076, 13.28028107], [93.03804779, 13.28028107], [93.03833008, 13.28056145], [93.03861237, 13.28056145], [93.03916168, 13.28062057], [93.03954315, 13.28059101], [93.03974915, 13.28066158], [93.04009247, 13.28052044], [93.04051971, 13.28059101], [93.04083252, 13.28028107], [93.04110718, 13.28028107], [93.04138947, 13.28000069], [93.04165649, 13.28000069], [93.04194641, 13.27972031], [93.04222107, 13.27972317], [93.04250336, 13.27944374], [93.04360962, 13.27943993], [93.04418182, 13.28000069], [93.04418182, 13.28028107], [93.04444122, 13.28055668], [93.04444122, 13.28083038], [93.04528046, 13.28167057], [93.04555511, 13.28166676], [93.04582977, 13.28194523], [93.04611206, 13.28194523], [93.04722595, 13.28083229], [93.04722595, 13.28055668], [93.04728699, 13.28020954], [93.04724121, 13.27972031], [93.04722595, 13.27944374], [93.04722595, 13.27805424], [93.04695129, 13.27778053], [93.04695129, 13.27721977], [93.04666901, 13.27694416], [93.04666901, 13.27666569], [93.04611206, 13.2761097], [93.04611206, 13.27583027], [93.04250336, 13.27222157], [93.04222107, 13.27222157], [93.04138947, 13.27138996], [93.04110718, 13.27138996], [93.04055786, 13.2708292], [93.04055786, 13.27055645], [93.0402832, 13.27028179], [93.0402832, 13.26944065], [93.04083252, 13.26888847], [93.04083252, 13.26833057], [93.04166412, 13.26749992], [93.04165649, 13.26722145], [93.04250336, 13.26638985], [93.04250336, 13.26611233], [93.04277802, 13.2658329], [93.04277802, 13.26555538], [93.04305267, 13.26527691], [93.04277802, 13.26499939], [93.04305267, 13.26472092], [93.04305267, 13.26333332], [93.04333496, 13.26305485], [93.04332733, 13.26222134], [93.04360962, 13.26194477], [93.04360962, 13.26166725], [93.04471588, 13.26056194], [93.04471588, 13.26028156], [93.04582977, 13.25917244], [93.04611206, 13.25917244], [93.04724121, 13.26028156], [93.04750061, 13.26028156], [93.04860687, 13.26139069], [93.04888916, 13.26139069], [93.04915619, 13.26167202], [93.04944611, 13.26166725], [93.04972076, 13.26194477], [93.05055237, 13.26194477], [93.05083466, 13.26222324], [93.05166626, 13.26222324], [93.05194092, 13.26249886], [93.05249786, 13.26249027], [93.05304718, 13.26305962], [93.0533371, 13.26305485], [93.05351257, 13.26323128], [93.05361176, 13.26333332], [93.05388641, 13.26333332], [93.0542984, 13.26374626], [93.05527496, 13.26472092], [93.05555725, 13.26472092], [93.05638885, 13.26555538], [93.05666351, 13.26555538], [93.05833435, 13.26722145], [93.05860901, 13.26722145], [93.0588913, 13.26750183], [93.05918121, 13.26750183], [93.05944824, 13.2677803], [93.0597229, 13.2677803], [93.05999756, 13.26805973], [93.06027985, 13.26805973], [93.06083679, 13.26862144], [93.06111145, 13.26862144], [93.0625, 13.27000046], [93.06276703, 13.27000046], [93.0633316, 13.27056026], [93.06361389, 13.27055645], [93.06416321, 13.27110958], [93.06416321, 13.27138996], [93.06582642, 13.2730608], [93.0661087, 13.2730608], [93.06667328, 13.27250004], [93.06639099, 13.27221966], [93.06639099, 13.27194405], [93.0661087, 13.27166557], [93.0661087, 13.27056026], [93.06582642, 13.27028179], [93.06582642, 13.26916981], [93.06555176, 13.26889038], [93.06555176, 13.26694107], [93.0652771, 13.26666546], [93.0652771, 13.26583099], [93.06500244, 13.26555538], [93.06500244, 13.26499939], [93.06492615, 13.26472092], [93.06478882, 13.26416969], [93.0642395, 13.2634697], [93.06298828, 13.2634697], [93.0625, 13.26361084], [93.06159973, 13.26257038], [93.06111145, 13.26249027], [93.05999756, 13.26138878], [93.05999756, 13.26111126], [93.05944824, 13.26055527], [93.05944824, 13.26028156], [93.0588913, 13.2597208], [93.0588913, 13.25916672], [93.05860901, 13.25889111], [93.05860901, 13.25861073], [93.05832672, 13.2583313], [93.05833435, 13.25777912], [93.05805206, 13.25750065], [93.05805206, 13.25722122], [93.0577774, 13.25694466], [93.0577774, 13.25666714], [93.05750275, 13.25639057], [93.05750275, 13.2558279], [93.05770111, 13.25490475], [93.05770111, 13.25456142], [93.05791473, 13.25401211], [93.05805206, 13.25353146], [93.05818939, 13.25297928], [93.05827332, 13.25264168], [93.05827332, 13.25235939], [93.05791473, 13.25126076], [93.0579834, 13.25071144], [93.0577774, 13.24972153], [93.0577774, 13.24833202], [93.05750275, 13.24805641], [93.05750275, 13.24722195], [93.05722046, 13.24694443], [93.05722046, 13.24638844], [93.05555725, 13.24472046], [93.05555725, 13.24444389], [93.05526733, 13.24417019], [93.05526733, 13.24388981], [93.05555725, 13.24361038], [93.05555725, 13.24222183], [93.05583191, 13.24194431], [93.05583191, 13.24166775], [93.05612183, 13.24139023], [93.05612183, 13.24028015], [93.05638885, 13.24000168], [93.05638885, 13.23944092], [93.05666351, 13.23916531], [93.05665588, 13.23832035], [93.0569458, 13.23805523], [93.0569458, 13.23666954], [93.05665588, 13.23639202], [93.05665588, 13.23472118], [93.05638885, 13.23444462], [93.05638885, 13.23388863], [93.05612183, 13.23361111], [93.0561142, 13.23277664], [93.05526733, 13.23194027], [93.05500031, 13.23194504], [93.05472565, 13.23166656], [93.05444336, 13.23166943], [93.05278015, 13.23000145], [93.05278015, 13.22972107], [93.05249786, 13.22944546], [93.05249786, 13.22889137], [93.05222321, 13.22861099], [93.05222321, 13.22832966], [93.05083466, 13.22694492], [93.05055237, 13.22694492], [93.05034637, 13.22673702], [93.05000305, 13.22638798], [93.04972076, 13.22638798], [93.04888916, 13.22555447], [93.04860687, 13.22556114], [93.04833221, 13.22528076], [93.04805756, 13.22528076], [93.04798126, 13.22520256], [93.0477829, 13.22500038], [93.04750061, 13.22500038], [93.04724121, 13.22472], [93.04694366, 13.22472191], [93.04666901, 13.22444439], [93.04638672, 13.22444439], [93.04611206, 13.22416592], [93.04556274, 13.22417068], [93.04528046, 13.22389126], [93.04499817, 13.22389126], [93.04471588, 13.22360992], [93.04444122, 13.22360992], [93.04389191, 13.22306061], [93.04332733, 13.22306061], [93.04302979, 13.22288132], [93.04296112, 13.22253036], [93.04296112, 13.22205067], [93.04316711, 13.2215004], [93.04359436, 13.22081375], [93.04386902, 13.21998882], [93.04380035, 13.21881008], [93.04410553, 13.21738052], [93.04438782, 13.21696663], [93.04453278, 13.21628094], [93.04453278, 13.21449089], [93.04494476, 13.21332359], [93.04508209, 13.21201897], [93.04515839, 13.21119118], [93.04550934, 13.21112537], [93.045784, 13.21112537], [93.04587555, 13.21061707], [93.04612732, 13.2101202], [93.04589081, 13.20977974], [93.04543304, 13.20946121], [93.04476929, 13.20936966], [93.04416656, 13.20916653], [93.04389191, 13.20889187], [93.04360962, 13.20889187], [93.04250336, 13.20778179], [93.04250336, 13.20750141], [93.04222107, 13.20722103], [93.04222107, 13.20694542], [93.04194641, 13.20666695], [93.04194641, 13.20639133], [93.04165649, 13.20611095], [93.04165649, 13.20557117], [93.04138947, 13.20528126], [93.04138947, 13.20472145], [93.04111481, 13.20444489], [93.04111481, 13.20361137], [93.04083252, 13.2033329], [93.04083252, 13.20055676], [93.04055786, 13.20028114], [93.04055786, 13.20000076], [93.03943634, 13.19889069], [93.03916931, 13.19889069], [93.03861237, 13.19832993], [93.03861237, 13.19805431], [93.03833008, 13.19778061], [93.03833008, 13.19750023], [93.03804779, 13.19721985], [93.03805542, 13.19694424], [93.03749847, 13.19638824], [93.03749847, 13.19610977], [93.03721619, 13.19583035], [93.03722382, 13.19555569], [93.03694153, 13.19528103], [93.03694153, 13.19472027], [93.03666687, 13.1944437], [93.03666687, 13.19277763], [93.03639221, 13.19250011], [93.03639221, 13.19221973], [93.03610992, 13.19194412], [93.03610992, 13.19166565], [93.0358429, 13.19139004], [93.0358429, 13.19110966], [93.03555298, 13.19083405], [93.03555298, 13.19027805], [93.03527832, 13.18999958], [93.03527832, 13.18805981], [93.03501129, 13.18778038], [93.03501129, 13.18750191], [93.03472137, 13.18721008], [93.03472137, 13.18666458], [93.03444672, 13.18639183], [93.03444672, 13.18583107], [93.03416443, 13.18555546], [93.0341568, 13.18528175], [93.03388977, 13.18499947], [93.03388977, 13.18472099], [93.03360748, 13.18444633], [93.03360748, 13.18416691], [93.03333282, 13.18388939], [93.03333282, 13.18222141], [93.03305817, 13.18194485], [93.03305817, 13.18083286], [93.03277588, 13.18055534], [93.03277588, 13.18000126], [93.03250122, 13.17972088], [93.03250122, 13.17916679], [93.03221893, 13.17889118], [93.03221893, 13.17805862], [93.03250122, 13.1777792], [93.0326767, 13.17742062], [93.03316498, 13.17700863], [93.03366089, 13.17673969], [93.03421783, 13.17632008], [93.03501129, 13.17527199], [93.03500366, 13.17500114], [93.03666687, 13.17333221], [93.03666687, 13.17250061], [93.03694153, 13.17223167], [93.03694153, 13.17111015], [93.03722382, 13.17083454], [93.03722382, 13.17000008], [93.03694153, 13.1697197], [93.03694153, 13.16944408], [93.03666687, 13.16916561], [93.03666687, 13.16889], [93.0358429, 13.16806126], [93.0358429, 13.16778088], [93.03527832, 13.16722202], [93.03527832, 13.16694355], [93.03500366, 13.16666603], [93.03501129, 13.16639042], [93.03472137, 13.16611004], [93.03472137, 13.16528034], [93.03444672, 13.16499996], [93.03444672, 13.16471958], [93.03416443, 13.16444397], [93.03416443, 13.16250038], [93.03444672, 13.16222191], [93.03444672, 13.16194439], [93.03427887, 13.16144943], [93.03438568, 13.16126442], [93.03424835, 13.16037083], [93.03424835, 13.15989017], [93.03431702, 13.15939999], [93.03424835, 13.15851593], [93.03424835, 13.15680027], [93.03453064, 13.15625], [93.03481293, 13.15522003], [93.03536987, 13.15445042], [93.03607178, 13.15272236], [93.03610992, 13.15211105], [93.03610992, 13.15149593], [93.03610992, 13.15090084], [93.03614807, 13.15033054], [93.03633118, 13.14982796], [93.03637695, 13.14929199], [93.03639984, 13.1487608], [93.03649139, 13.14825058], [93.03666687, 13.14805889], [93.03666687, 13.14721107], [93.0366745, 13.14529037], [93.03653717, 13.14398193], [93.03653717, 13.14219475], [93.03674316, 13.14129925], [93.03722382, 13.14083195], [93.03722382, 13.14027786], [93.03734589, 13.13958073], [93.03740692, 13.13887215], [93.03713226, 13.13827896], [93.03668976, 13.13787079], [93.03626251, 13.13750362], [93.03588104, 13.13715267], [93.03559113, 13.13675022], [93.03542328, 13.13625145], [93.03526306, 13.13574696], [93.03505707, 13.13525009], [93.03486633, 13.13473129], [93.03462982, 13.13421059], [93.03430939, 13.13375759], [93.03395081, 13.13330173], [93.03362274, 13.13284111], [93.03331757, 13.13237], [93.0329895, 13.13193035], [93.03269958, 13.13147163], [93.032341, 13.131073], [93.0320282, 13.13065147], [93.03194427, 13.13055515], [93.03153229, 13.12993145], [93.03138733, 13.12972355], [93.03131866, 13.12923813], [93.03096771, 13.12799072], [93.03083038, 13.12778187], [93.03098297, 13.12646198], [93.03111267, 13.12611103], [93.03145599, 13.12535], [93.03166962, 13.12500095], [93.03188324, 13.12465], [93.03194427, 13.12416744], [93.03222656, 13.12367725], [93.03250122, 13.12312126], [93.03243256, 13.12291622], [93.03250122, 13.12250137], [93.03250122, 13.12193966], [93.03236389, 13.12166691], [93.03243256, 13.12112045], [93.03250122, 13.12082958], [93.03250122, 13.12023544], [93.03250122, 13.11975002], [93.03246307, 13.11927128], [93.03225708, 13.11883163], [93.03224182, 13.1183424], [93.03221893, 13.11783791], [93.03221893, 13.11736107], [93.0319519, 13.11667061], [93.03186798, 13.11611938], [93.03172302, 13.11557007], [93.03172302, 13.11481094], [93.03200531, 13.11446857], [93.03221893, 13.11399078], [93.03250122, 13.11308956], [93.032547, 13.11250019], [93.0327301, 13.11190987], [93.03277588, 13.11125565], [93.0327301, 13.11056328], [93.03253937, 13.10988426], [93.03251648, 13.10918808], [93.03263855, 13.10853195], [93.03299713, 13.10796928], [93.03331757, 13.10741138], [93.03356171, 13.10684109], [93.03362274, 13.10620975], [93.03361511, 13.1055994], [93.03362274, 13.10501099], [93.03363037, 13.10444069], [93.03373718, 13.10387993], [93.03382111, 13.10333824], [93.03369904, 13.10278034], [93.03354645, 13.10272026], [93.03354645, 13.10217094], [93.03404236, 13.10134125], [93.03473663, 13.10044956], [93.03524017, 13.09976196], [93.03544617, 13.09879971], [93.0355072, 13.09797096], [93.03551483, 13.09721565], [93.03524017, 13.09612179], [93.03495789, 13.09536076], [93.03456116, 13.09496021], [93.03427887, 13.09451962], [93.03418732, 13.09364891], [93.03425598, 13.09324074], [93.03440094, 13.09262085], [93.03460693, 13.09241199], [93.03495789, 13.09213066], [93.0354538, 13.09179211], [93.03596497, 13.09115791], [93.0358963, 13.09050179], [93.03600311, 13.08984089], [93.03604889, 13.08919144], [93.0358429, 13.08863258], [93.03562164, 13.08810425], [93.03544617, 13.08757973], [93.03520966, 13.08713818], [93.03502655, 13.08668041], [93.03501129, 13.08615971], [93.03504181, 13.0856657], [93.03523254, 13.08517838], [93.03527832, 13.08461857], [93.03527832, 13.08401966], [93.03526306, 13.08342075], [93.03517914, 13.0828104], [93.03503418, 13.08221722], [93.03501129, 13.0815897], [93.03488159, 13.08099079], [93.0344696, 13.08056927], [93.03390503, 13.08031368], [93.03325653, 13.0802803], [93.03258514, 13.08035469], [93.03199768, 13.08056259], [93.03181458, 13.08063316], [93.03145599, 13.08076954], [93.03117371, 13.08073997], [93.03089142, 13.08071136], [93.03032684, 13.08061695], [93.02980804, 13.08036041], [93.02931213, 13.08018589], [93.02899933, 13.07983971], [93.02866364, 13.07949066], [93.0283432, 13.0791111], [93.02804565, 13.0787096], [93.027771, 13.07831097], [93.02754974, 13.07786179], [93.02723694, 13.07749939], [93.02700043, 13.07708931], [93.02687073, 13.07661724], [93.0266571, 13.07619095], [93.02646637, 13.0757513], [93.02639771, 13.07524109], [93.02633667, 13.07470989], [93.02614594, 13.07417202], [93.02610779, 13.07359123], [93.02610016, 13.07298946], [93.02609253, 13.07237053], [93.02614594, 13.07178116], [93.02657318, 13.07132053], [93.0271225, 13.07116127], [93.02746582, 13.07089424], [93.02796936, 13.07048225], [93.02859497, 13.07041359], [93.0295105, 13.07006931], [93.02979279, 13.07006931], [93.02999878, 13.07001019], [93.03028107, 13.06972122], [93.03028107, 13.06944466], [93.03055573, 13.06916714], [93.03056335, 13.06889057], [93.0302124, 13.06799126], [93.02971649, 13.06694031], [93.02944183, 13.0666666], [93.02923584, 13.06597233], [93.02833557, 13.06500053], [93.0283432, 13.06417084], [93.02805328, 13.06388187], [93.02805328, 13.06361008], [93.02777863, 13.0633297], [93.02777863, 13.06277847], [93.02749634, 13.0625], [93.02749634, 13.06221962], [93.02694702, 13.06166553], [93.02694702, 13.06138992], [93.02527618, 13.05972195], [93.02527618, 13.05944443], [93.02500153, 13.05916595], [93.02500153, 13.05889034], [93.02416992, 13.05807018], [93.02416992, 13.05750179], [93.02388763, 13.05722046], [93.02388763, 13.05694389], [93.02361298, 13.05611229], [93.02361298, 13.0555563], [93.02333069, 13.05527973], [93.02333069, 13.05472183], [93.02249908, 13.05389023], [93.02249908, 13.05360889], [93.02132416, 13.05228996], [93.02111053, 13.05194092], [93.02104187, 13.05152893], [93.02083588, 13.05083084], [93.02083588, 13.05055523], [93.02076721, 13.04999924], [93.01999664, 13.04972363], [93.01917267, 13.04972076], [93.01833344, 13.04999924], [93.01770782, 13.05034256], [93.01701355, 13.05048466], [93.01576233, 13.05048466], [93.01555634, 13.05034256], [93.01499939, 13.04999924], [93.0147171, 13.04972076], [93.01444244, 13.04972363], [93.0138855, 13.04916668], [93.01342773, 13.0489006], [93.01298523, 13.04860497], [93.01261139, 13.04828072], [93.01235199, 13.04784966], [93.01204681, 13.04734039], [93.01207733, 13.04675198], [93.01216125, 13.04628658], [93.01232147, 13.04596996], [93.01267242, 13.04566002], [93.01294708, 13.04559135], [93.013237, 13.04545021], [93.01351929, 13.04531574], [93.0139389, 13.04497242], [93.0141449, 13.04455853], [93.01413727, 13.04401016], [93.01378632, 13.04373169], [93.01351929, 13.04366589], [93.01316833, 13.04366589], [93.01295471, 13.0437336], [93.01267242, 13.04380035], [93.01225281, 13.04408264], [93.01183319, 13.04415131], [93.0114212, 13.04422188], [93.01098633, 13.04415131], [93.01022339, 13.04408264], [93.00984192, 13.04380035], [93.00946045, 13.04335117], [93.00928497, 13.04285717], [93.00943756, 13.04266071], [93.00943756, 13.04218197], [93.00958252, 13.04183102], [93.01000214, 13.04141808], [93.01037598, 13.04127026], [93.01066589, 13.04106712], [93.01080322, 13.04066181], [93.01074982, 13.04022026], [93.010849, 13.0395813], [93.01068878, 13.03921032], [93.01035309, 13.03894997], [93.0100174, 13.03861046], [93.00971985, 13.03818035], [93.00945282, 13.03773117], [93.00927734, 13.03729057], [93.00949097, 13.03688145], [93.00959015, 13.03646755], [93.00948334, 13.0362606], [93.00934601, 13.03577995], [93.00879669, 13.03489113], [93.00850677, 13.03434181], [93.00808716, 13.03365135], [93.00763702, 13.03265095], [93.00726318, 13.03224277], [93.00695038, 13.03177547], [93.00666046, 13.03129005], [93.00634003, 13.03081131], [93.0059433, 13.0303812], [93.00549316, 13.02995014], [93.00501251, 13.02952957], [93.00447083, 13.02907944], [93.00389862, 13.02858925], [93.00331116, 13.02822018], [93.00305176, 13.0283289], [93.00250244, 13.02888775], [93.00250244, 13.02972031], [93.0027771, 13.02999973], [93.0027771, 13.0308342], [93.00270844, 13.03107262], [93.00242615, 13.03148079], [93.00193787, 13.03182983], [93.00158691, 13.03196716], [93.00088501, 13.03210354], [93.00026703, 13.03193855], [93.0, 13.03222179], [92.99973297, 13.03199196], [92.99948883, 13.03190517], [92.9991684, 13.03172112], [92.99882507, 13.03174305], [92.9985199, 13.03194427], [92.99819946, 13.0321722], [92.99781799, 13.03232479], [92.99746704, 13.03254128], [92.99715424, 13.03285599], [92.99690247, 13.0332613], [92.99662018, 13.03365993], [92.99637604, 13.03404808], [92.9961319, 13.03437996], [92.99597168, 13.03470039], [92.99578094, 13.03494072], [92.9955368, 13.03510475], [92.99526215, 13.03520966], [92.99494934, 13.0352602], [92.99465942, 13.03518963], [92.99433136, 13.03504086], [92.99396515, 13.03498173], [92.99360657, 13.0348568], [92.99324036, 13.03470039], [92.99289703, 13.03448105], [92.99249268, 13.03431034], [92.99208069, 13.034132], [92.99172211, 13.03385162], [92.99139404, 13.03350067], [92.99105835, 13.03312016], [92.99069977, 13.03275967], [92.99043274, 13.03234959], [92.99024963, 13.03184795], [92.98999786, 13.03134918], [92.98983002, 13.03080368], [92.98973083, 13.03021431], [92.98972321, 13.02961159], [92.98973846, 13.02903557], [92.98985291, 13.0284996], [92.99007416, 13.02805138], [92.99028778, 13.02759075], [92.99051666, 13.02712059], [92.99048615, 13.02661991], [92.99019623, 13.02620983], [92.98976135, 13.02595234], [92.98934174, 13.0257473], [92.98896027, 13.02560139], [92.9885788, 13.02555084], [92.98819733, 13.02555275], [92.9878006, 13.02555084], [92.98739624, 13.02556038], [92.98700714, 13.02560139], [92.98668671, 13.02577019], [92.98628235, 13.02583122], [92.9858551, 13.02584743], [92.98545074, 13.0259037], [92.9850769, 13.0259037], [92.98497772, 13.02588177], [92.98474121, 13.02582455], [92.98445892, 13.02569008], [92.98420715, 13.02550983], [92.98401642, 13.02528], [92.9838028, 13.02506065], [92.98351288, 13.02486706], [92.98327637, 13.02453041], [92.98300934, 13.02423096], [92.98271179, 13.02402878], [92.98242188, 13.02404213], [92.98216248, 13.02442074], [92.98197937, 13.02487183], [92.98191833, 13.02527142], [92.98179626, 13.02557182], [92.98163605, 13.0258503], [92.98139954, 13.02611923], [92.98118591, 13.02645969], [92.98101807, 13.02686596], [92.98075104, 13.02715969], [92.98044586, 13.02734947], [92.98014832, 13.02748108], [92.97980499, 13.02753639], [92.97947693, 13.02772141], [92.97911835, 13.0278511], [92.97881317, 13.02802181], [92.97846985, 13.02805996], [92.97820282, 13.02810097], [92.97799683, 13.0282402], [92.97777557, 13.02832031], [92.97749329, 13.02837276], [92.97723389, 13.02856445], [92.97690582, 13.02862072], [92.97657776, 13.02871895], [92.97628021, 13.02886009], [92.97592926, 13.02888966], [92.97553253, 13.02888966], [92.97512054, 13.02888966], [92.9746933, 13.02889919], [92.97425842, 13.028965], [92.97384644, 13.02913189], [92.9733963, 13.0291996], [92.97299957, 13.02936172], [92.97263336, 13.02944183], [92.97225952, 13.02945137], [92.97203064, 13.02944374], [92.97189331, 13.02944183], [92.97150421, 13.02944374], [92.971138, 13.0294714], [92.97083282, 13.0296402], [92.9705658, 13.02986813], [92.97034454, 13.03016186], [92.97026062, 13.03056145], [92.97014618, 13.03094959], [92.97001648, 13.03129005], [92.96998596, 13.03161621], [92.96990204, 13.03189182], [92.96972656, 13.03211021], [92.96953583, 13.0323267], [92.96917725, 13.03252125], [92.9688797, 13.0328722], [92.96856689, 13.03324986], [92.9682312, 13.03361034], [92.96788788, 13.03393078], [92.96763611, 13.03431034], [92.96740723, 13.03467941], [92.9671402, 13.03497982], [92.96685028, 13.03523064], [92.96653748, 13.03536034], [92.96629333, 13.03537178], [92.96604919, 13.03520966], [92.96582794, 13.03499985], [92.96562195, 13.03475189], [92.9655838, 13.03441906], [92.96569824, 13.03401089], [92.96585846, 13.03351402], [92.96607208, 13.03301144], [92.9661026, 13.03250027], [92.96603394, 13.03205776], [92.96586609, 13.03172112], [92.96582794, 13.03140163], [92.96582794, 13.03110981], [92.96583557, 13.03084087], [92.96582794, 13.03057194], [92.96582794, 13.02965069], [92.96583557, 13.02928734], [92.96582794, 13.02888966], [92.96583557, 13.02849102], [92.9658432, 13.02810383], [92.96591187, 13.02772808], [92.96607208, 13.02736092], [92.96611023, 13.02696037], [92.96611023, 13.02654934], [92.96614838, 13.02616405], [92.96633911, 13.0258503], [92.96647644, 13.02550125], [92.96672821, 13.02523041], [92.96705627, 13.02499008], [92.96739197, 13.0247097], [92.96768188, 13.02440453], [92.96790314, 13.02404022], [92.96807098, 13.02363873], [92.96829224, 13.02326965], [92.96837616, 13.02285004], [92.96858215, 13.02248955], [92.96869659, 13.0220089], [92.9688797, 13.02153111], [92.96901703, 13.02103806], [92.96909332, 13.02056026], [92.96890259, 13.02019119], [92.96866608, 13.01980114], [92.96839142, 13.0194788], [92.96836853, 13.01908302], [92.96855927, 13.01863766], [92.96869659, 13.01814175], [92.96894073, 13.01772022], [92.96917725, 13.01731014], [92.9694519, 13.01694965], [92.96974182, 13.01665115], [92.96998596, 13.01636791], [92.97021484, 13.01612186], [92.97048187, 13.01593304], [92.97083282, 13.0158329], [92.97119141, 13.01573277], [92.97151184, 13.01558018], [92.97181702, 13.01549053], [92.97206879, 13.01534081], [92.97233582, 13.01527023], [92.97261047, 13.01515961], [92.97284698, 13.01503086], [92.97310638, 13.0150013], [92.97338867, 13.01501179], [92.97364807, 13.0150671], [92.97386169, 13.01523113], [92.97408295, 13.01538181], [92.97424316, 13.01562119], [92.97442627, 13.0158577], [92.97460938, 13.01620007], [92.97477722, 13.0163517], [92.97506714, 13.01625919], [92.97543335, 13.01585102], [92.9757843, 13.01542282], [92.97602081, 13.01494598], [92.97605896, 13.01448059], [92.97585297, 13.01405144], [92.97558594, 13.01364899], [92.97531891, 13.0133419], [92.97499847, 13.01307964], [92.974617, 13.01286125], [92.97414398, 13.01287937], [92.97368622, 13.01288128], [92.97327423, 13.01283264], [92.97289276, 13.01281261], [92.97251129, 13.01283073], [92.97210693, 13.01279926], [92.97170258, 13.01275063], [92.97130585, 13.01257992], [92.97091675, 13.0125103], [92.97052765, 13.01253033], [92.97015381, 13.01269913], [92.96974945, 13.01278305], [92.96933746, 13.01288128], [92.96900177, 13.01302528], [92.96864319, 13.01305008], [92.96826172, 13.01307964], [92.96788788, 13.01321411], [92.96749878, 13.01333332], [92.96708679, 13.01346016], [92.96669006, 13.01363087], [92.96633911, 13.0138998], [92.96604156, 13.01423073], [92.96580505, 13.01461792], [92.96553802, 13.01492119], [92.96527863, 13.01516724], [92.9650116, 13.01538181], [92.96475983, 13.0156002], [92.96453857, 13.01584625], [92.96434021, 13.01609039], [92.96411896, 13.01629066], [92.96383667, 13.01640701], [92.96356964, 13.01656437], [92.96325684, 13.01665115], [92.96290588, 13.01666927], [92.9625473, 13.01666927], [92.96221161, 13.01663971], [92.96193695, 13.01648045], [92.96169281, 13.0163002], [92.9614563, 13.01608086], [92.96128082, 13.01582432], [92.96109009, 13.01552963], [92.96083832, 13.01523972], [92.96060181, 13.01484108], [92.9602356, 13.01480484], [92.9598465, 13.01505089], [92.95951843, 13.01546955], [92.95918274, 13.015872], [92.95890045, 13.01626587], [92.95864105, 13.01662064], [92.95836639, 13.01691055], [92.95809937, 13.01718044], [92.95780182, 13.01744556], [92.95739746, 13.01761055], [92.95693207, 13.01780033], [92.95648956, 13.01803017], [92.95601654, 13.01811028], [92.9556427, 13.01831341], [92.95530701, 13.0184927], [92.9550705, 13.01874065], [92.95500183, 13.01907063], [92.95498657, 13.01939106], [92.95491028, 13.01967144], [92.95477295, 13.01990795], [92.95471191, 13.02021122], [92.95461273, 13.02054214], [92.9544754, 13.02088261], [92.95446777, 13.02124977], [92.95459747, 13.02163982], [92.95470428, 13.0220499], [92.95469666, 13.02248096], [92.95458221, 13.02292061], [92.95440674, 13.02335167], [92.95417023, 13.02373886], [92.95391846, 13.02413082], [92.95368195, 13.02452087], [92.95353699, 13.02492237], [92.95333099, 13.02526188], [92.95311737, 13.02559185], [92.95292664, 13.0258503], [92.9527359, 13.02609062], [92.95249176, 13.02630997], [92.9522171, 13.02657413], [92.95194244, 13.02688217], [92.95172119, 13.02721024], [92.95166779, 13.02761078], [92.95166016, 13.02801037], [92.95157623, 13.02839088], [92.95140076, 13.02873039], [92.95121002, 13.02905178], [92.95096588, 13.02929974], [92.95072937, 13.02954197], [92.95041656, 13.02975082], [92.95009613, 13.02997875], [92.94972992, 13.03016186], [92.9493866, 13.03035069], [92.94908905, 13.03054047], [92.94878387, 13.03067207], [92.94850922, 13.03082275], [92.94824982, 13.03093433], [92.94799805, 13.03108025], [92.94768524, 13.03115463], [92.94735718, 13.03131962], [92.94696045, 13.03139019], [92.94655609, 13.03144932], [92.94625854, 13.03161621], [92.94599152, 13.03170013], [92.94577789, 13.03186035], [92.94551086, 13.03197098], [92.94521332, 13.03213501], [92.94483948, 13.03227234], [92.94448853, 13.03250027], [92.94415283, 13.0327549], [92.94374084, 13.03293133], [92.94332886, 13.03317928], [92.94290161, 13.03349209], [92.94246674, 13.03385162], [92.9420166, 13.0342207], [92.94161224, 13.03463078], [92.94117737, 13.03495026], [92.9407959, 13.03527164], [92.9404068, 13.03556061], [92.94007111, 13.03586197], [92.93974304, 13.03619003], [92.93945312, 13.03654957], [92.93914032, 13.03690147], [92.938797, 13.0372324], [92.93842316, 13.03756046], [92.93804932, 13.03794479], [92.93767548, 13.03831387], [92.93728638, 13.03865242], [92.93695831, 13.03903198], [92.9367218, 13.03945065], [92.93662262, 13.03995132], [92.93638611, 13.0402813], [92.9366684, 13.04056072], [92.93611145, 13.04111099], [92.93611145, 13.04139137], [92.93585205, 13.04166889], [92.93548584, 13.04194927], [92.93508911, 13.04230022], [92.93477631, 13.04280186], [92.93465424, 13.04346466], [92.93445587, 13.04408264], [92.93432617, 13.04466248], [92.93419647, 13.04510117], [92.93416595, 13.04549122], [92.93416595, 13.04585075], [92.93416595, 13.04621124], [92.9341507, 13.04658699], [92.93405151, 13.04699135], [92.93369293, 13.04742241], [92.93367004, 13.04782963], [92.93386841, 13.04819393], [92.93409729, 13.04854107], [92.93438721, 13.04884243], [92.93466949, 13.04914665], [92.9348526, 13.04959965], [92.93499756, 13.05017853], [92.93515778, 13.05079937], [92.93541718, 13.05131912], [92.93582153, 13.05163097], [92.93631744, 13.05176067], [92.93678284, 13.05189991], [92.93724823, 13.05194092], [92.93769836, 13.05189991], [92.93807983, 13.05170631], [92.93843079, 13.05167007], [92.93875885, 13.05165195], [92.9390564, 13.05166531], [92.93937683, 13.05169964], [92.93971252, 13.05189991], [92.94007874, 13.0519886], [92.94036865, 13.05218029], [92.9406662, 13.05236053], [92.94093323, 13.05259132], [92.941185, 13.05281639], [92.94142914, 13.05304241], [92.94168854, 13.05326271], [92.94197083, 13.05346107], [92.942276, 13.05364132], [92.94249725, 13.05389023], [92.94249725, 13.05416775], [92.94304657, 13.05472183], [92.9430542, 13.05500031], [92.94282532, 13.0552597], [92.94271088, 13.05558586], [92.94249725, 13.05586147], [92.94223022, 13.05618], [92.94194794, 13.05654716], [92.94165802, 13.05694199], [92.94143677, 13.05737019], [92.94128418, 13.05783463], [92.94111633, 13.05827045], [92.94095612, 13.05868053], [92.94093323, 13.05911064], [92.94093323, 13.05955982], [92.94094086, 13.06005478], [92.94106293, 13.06058121], [92.94114685, 13.06115341], [92.94135284, 13.06166363], [92.94165802, 13.06221962], [92.94165802, 13.0625], [92.94194794, 13.06278133], [92.94194794, 13.06305695], [92.9422226, 13.0633297], [92.94194794, 13.06361008], [92.94194794, 13.06417084], [92.94146729, 13.06449032], [92.94114685, 13.06476974], [92.94085693, 13.06510544], [92.94058228, 13.06554127], [92.94032288, 13.06608105], [92.94001007, 13.06662083], [92.93971252, 13.06717014], [92.93943787, 13.06767368], [92.93917084, 13.06812477], [92.93894958, 13.06856537], [92.93878174, 13.06904411], [92.93863678, 13.06954098], [92.93856049, 13.07008076], [92.93830872, 13.07057953], [92.93817902, 13.07108593], [92.93817902, 13.07165146], [92.93817902, 13.07219982], [92.93815613, 13.07269001], [92.93818665, 13.07314587], [92.93830872, 13.07359982], [92.93842316, 13.07409191], [92.93852234, 13.0746212], [92.93858337, 13.07516766], [92.93860626, 13.07570267], [92.93859863, 13.07619095], [92.93862915, 13.0766058], [92.93872833, 13.07693386], [92.93881226, 13.07721233], [92.9388504, 13.07746983], [92.938797, 13.07773018], [92.93867493, 13.07795715], [92.93852234, 13.07818127], [92.93844604, 13.07846069], [92.93844604, 13.07877064], [92.93841553, 13.07905579], [92.93824005, 13.07929993], [92.93819427, 13.07998562], [92.9380188, 13.08045101], [92.93776703, 13.08115101], [92.93763733, 13.08162022], [92.93762207, 13.08220577], [92.93750763, 13.08316517], [92.9373703, 13.08359241], [92.93709564, 13.08443928], [92.93667603, 13.08471298], [92.93605804, 13.08455753], [92.93585205, 13.08388996], [92.93585205, 13.08355045], [92.93582916, 13.08316135], [92.93585205, 13.0828104], [92.93587494, 13.08251095], [92.93605804, 13.0822401], [92.93611145, 13.08189964], [92.93611145, 13.08154488], [92.93611145, 13.08117771], [92.9361496, 13.08081055], [92.93630981, 13.08045101], [92.93637848, 13.08003235], [92.93638611, 13.07958889], [92.93643188, 13.07917023], [92.93657684, 13.07880974], [92.93666077, 13.07841969], [92.9366684, 13.07802105], [92.9366684, 13.07761097], [92.9366684, 13.07717991], [92.9366684, 13.07673073], [92.9366684, 13.0757103], [92.9366684, 13.07516956], [92.9366684, 13.07462978], [92.9366684, 13.07409191], [92.93662262, 13.07355404], [92.93643188, 13.07302284], [92.93638611, 13.07242393], [92.93638611, 13.07181072], [92.93638611, 13.07121086], [92.93634796, 13.07064056], [92.9361496, 13.07014179], [92.93611145, 13.06965923], [92.93611145, 13.06922245], [92.93611145, 13.06879997], [92.93611145, 13.06836033], [92.93611145, 13.0666256], [92.93611145, 13.06621075], [92.93611145, 13.06575012], [92.93611145, 13.06525135], [92.9360733, 13.06472015], [92.93586731, 13.06421185], [92.93579865, 13.06365967], [92.93560791, 13.06317043], [92.9355011, 13.06266403], [92.93530273, 13.06221104], [92.93515778, 13.06172085], [92.93492889, 13.06131268], [92.93467712, 13.06096363], [92.93435669, 13.06074333], [92.934021, 13.06058407], [92.93364716, 13.06058979], [92.93327332, 13.06076145], [92.93284607, 13.06092072], [92.93250275, 13.06115627], [92.93221283, 13.06138134], [92.93190002, 13.06157112], [92.93157196, 13.06168175], [92.93125916, 13.0617981], [92.93091583, 13.06191921], [92.93054199, 13.06200123], [92.93022919, 13.06218815], [92.92985535, 13.06228828], [92.92949677, 13.06245327], [92.92913055, 13.06243038], [92.9287796, 13.06226063], [92.92842102, 13.06221104], [92.92810059, 13.06212044], [92.92781067, 13.06195641], [92.92752075, 13.06182098], [92.92722321, 13.06167126], [92.9263916, 13.06084061], [92.9263916, 13.06056118], [92.92624664, 13.06028271], [92.9263916, 13.06000042], [92.92624664, 13.0595808], [92.92610168, 13.05906582], [92.92589569, 13.05852985], [92.92572784, 13.05799007], [92.92542267, 13.057621], [92.92515564, 13.05725574], [92.92482758, 13.0569706], [92.92440796, 13.05677986], [92.92391968, 13.05665016], [92.9234314, 13.05649853], [92.922966, 13.05643845], [92.92254639, 13.05659103], [92.92212677, 13.05670929], [92.92182922, 13.05692959], [92.92153168, 13.05714893], [92.9212265, 13.05737019], [92.92093658, 13.0576086], [92.92076111, 13.05799484], [92.92055511, 13.05840015], [92.92034149, 13.05884933], [92.92019653, 13.05938911], [92.91998291, 13.05990028], [92.91966248, 13.06036854], [92.91942596, 13.06089973], [92.91918945, 13.06138992], [92.91900635, 13.06185341], [92.91880798, 13.06228161], [92.91866302, 13.06275558], [92.91867065, 13.06327057], [92.91854095, 13.06371975], [92.91851807, 13.06422997], [92.9182663, 13.06459045], [92.91823578, 13.06504631], [92.91806793, 13.06535244], [92.91805267, 13.06555367], [92.91777802, 13.06583214], [92.91777802, 13.06611061], [92.91750336, 13.06639099], [92.91750336, 13.0666666], [92.91694641, 13.06721973], [92.91694641, 13.06750107], [92.91665649, 13.06778145], [92.91666412, 13.06805515], [92.91638947, 13.06833267], [92.91638947, 13.06861115], [92.91555786, 13.06944466], [92.9154129, 13.06965542], [92.91519928, 13.06995106], [92.91490936, 13.07034969], [92.9136734, 13.07003117], [92.91336823, 13.06995106], [92.9131546, 13.06982327], [92.91287231, 13.06975746], [92.91287994, 13.06965542], [92.91306305, 13.06771088], [92.91306305, 13.06721973], [92.91291809, 13.06652546], [92.91278076, 13.06611061], [92.9126358, 13.06583214], [92.91249847, 13.06555367], [92.91207886, 13.06423855], [92.91152954, 13.0633297], [92.91138458, 13.06312466], [92.91139221, 13.06277847], [92.91139221, 13.0625], [92.91123962, 13.06208134], [92.91110992, 13.06179237], [92.9109726, 13.06155014], [92.9107666, 13.0613308], [92.91049194, 13.06115055], [92.91010284, 13.0610714], [92.90973663, 13.06088161], [92.90934753, 13.06083393], [92.90898132, 13.0607996], [92.90866852, 13.06064129], [92.90828705, 13.06053066], [92.9079361, 13.06035137], [92.907547, 13.0602417], [92.90726471, 13.06007099], [92.90693665, 13.06000042], [92.90660858, 13.05992031], [92.90628815, 13.05976105], [92.90590668, 13.05972195], [92.90552521, 13.05968571], [92.90518188, 13.05951023], [92.90472412, 13.05944443], [92.90361023, 13.05944443], [92.90333557, 13.05972195], [92.90249634, 13.05972195], [92.90222168, 13.05944443], [92.90194702, 13.05972195], [92.90000153, 13.05972195], [92.89971924, 13.05944443], [92.89861298, 13.05944443], [92.89833069, 13.05916595], [92.89778137, 13.05917072], [92.89749908, 13.05889034], [92.8972168, 13.05889034], [92.89694214, 13.05860996], [92.89666748, 13.05860996], [92.89583588, 13.05777836], [92.89554596, 13.05778027], [92.89444733, 13.05667019], [92.89431, 13.05653095], [92.89417267, 13.05611038], [92.89360809, 13.0555563], [92.89362335, 13.05527973], [92.88999939, 13.05167007], [92.88999939, 13.05138969], [92.8897171, 13.05110931], [92.88972473, 13.0508337], [92.88944244, 13.05055523], [92.88944244, 13.05027962], [92.88880157, 13.04899025], [92.88838196, 13.04817104], [92.88817596, 13.047472], [92.88790131, 13.04651165], [92.88790131, 13.04568672], [92.88818359, 13.04555035], [92.88846588, 13.04555035], [92.88874054, 13.04582405], [92.88895416, 13.04589462], [92.88910675, 13.04611111], [92.88931274, 13.04618168], [92.88944244, 13.04638863], [92.88999939, 13.04694462], [92.88999939, 13.04722118], [92.89025879, 13.04750061], [92.89015961, 13.04889202], [92.89029694, 13.04930401], [92.89043427, 13.05040264], [92.8914566, 13.05146027], [92.89167023, 13.05167007], [92.89193726, 13.05167007], [92.89305878, 13.05277824], [92.89333344, 13.0530529], [92.89499664, 13.05444431], [92.89499664, 13.05472183], [92.89583588, 13.0555563], [92.89599609, 13.05613041], [92.89614868, 13.05654716], [92.8965683, 13.05723095], [92.89749908, 13.05778027], [92.89805603, 13.0580492], [92.89861298, 13.0580492], [92.89916992, 13.0581913], [92.89942932, 13.05807018], [92.90083313, 13.05832958], [92.90110779, 13.05833435], [92.90249634, 13.05833435], [92.90297699, 13.05821323], [92.90499878, 13.05805588], [92.90538788, 13.05780983], [92.90574646, 13.05773926], [92.90608215, 13.05756378], [92.90644836, 13.05750465], [92.90682983, 13.05746365], [92.90718079, 13.05729485], [92.90760803, 13.05722427], [92.90808868, 13.05716038], [92.90854645, 13.05698013], [92.90908051, 13.0569191], [92.90960693, 13.05677986], [92.9101181, 13.05662918], [92.91053772, 13.05638981], [92.91094971, 13.05615139], [92.91140747, 13.05607128], [92.91179657, 13.05587006], [92.91220856, 13.05572033], [92.91261292, 13.05555058], [92.91298676, 13.05536175], [92.91339111, 13.05528927], [92.91375732, 13.05527973], [92.91407776, 13.05527973], [92.91439056, 13.05527973], [92.914711, 13.05525017], [92.91505432, 13.05510712], [92.91545105, 13.05497932], [92.91580963, 13.05473995], [92.91610718, 13.05445957], [92.91629028, 13.05414963], [92.91615295, 13.0537796], [92.91610718, 13.05338192], [92.91604614, 13.0530014], [92.91591644, 13.05261993], [92.91584778, 13.05220795], [92.91587067, 13.05174065], [92.91603088, 13.05123043], [92.91587067, 13.05076122], [92.91578674, 13.05027103], [92.91555786, 13.04972076], [92.91555786, 13.04916668], [92.9152832, 13.0489006], [92.9152832, 13.04806042], [92.91500092, 13.04778194], [92.91500092, 13.04750061], [92.91442871, 13.0469408], [92.91444397, 13.0466671], [92.91416931, 13.04639053], [92.91416931, 13.04584026], [92.91388702, 13.04556179], [92.91388702, 13.04528236], [92.91361237, 13.04500103], [92.91361237, 13.04472065], [92.91305542, 13.04416656], [92.91306305, 13.04389095], [92.91249847, 13.04333115], [92.91249847, 13.04305458], [92.91221619, 13.04278088], [92.91221619, 13.04250145], [92.91194153, 13.04222107], [92.91194153, 13.04194546], [92.91166687, 13.04166698], [92.91168213, 13.04139137], [92.91172791, 13.04118061], [92.91190338, 13.04082108], [92.91194153, 13.04039955], [92.91188049, 13.03995991], [92.91165924, 13.03959656], [92.91139221, 13.03924179], [92.91114807, 13.03884983], [92.91092682, 13.03843021], [92.91070557, 13.03806591], [92.91049957, 13.03773975], [92.91030884, 13.03746223], [92.91022491, 13.03711319], [92.9100647, 13.03681469], [92.90996552, 13.03644753], [92.90975952, 13.03610134], [92.90972137, 13.03571129], [92.90972137, 13.03534031], [92.90976715, 13.03499985], [92.90995026, 13.03468132], [92.90990448, 13.03435802], [92.90973663, 13.03397942], [92.90962219, 13.03353024], [92.90943146, 13.03311062], [92.90917969, 13.03272057], [92.90895081, 13.0323019], [92.90869904, 13.03192139], [92.90847778, 13.03154087], [92.90827942, 13.03117085], [92.90803528, 13.0308609], [92.90777588, 13.03056717], [92.90750885, 13.03029156], [92.90724182, 13.03001118], [92.90705109, 13.0296917], [92.90689087, 13.02934074], [92.90661621, 13.02908134], [92.90637207, 13.02878475], [92.9061203, 13.02850342], [92.90589142, 13.02821064], [92.90574646, 13.02784157], [92.90556335, 13.02748394], [92.90541077, 13.02707386], [92.90524292, 13.02665234], [92.90503693, 13.02624226], [92.90494537, 13.02574158], [92.90476227, 13.02531624], [92.90466309, 13.02488995], [92.90450287, 13.02453041], [92.90444946, 13.02413273], [92.90444183, 13.02371407], [92.90439606, 13.02330208], [92.90416718, 13.02305508], [92.90416718, 13.02278042], [92.90389252, 13.02250195], [92.90389252, 13.02222061], [92.90361023, 13.02194309], [92.90297699, 13.02229023], [92.90248871, 13.02250195], [92.90207672, 13.02243137], [92.90194702, 13.02222061], [92.90166473, 13.02180386], [92.90249634, 13.02166653], [92.90277863, 13.02153111], [92.90305328, 13.02139187], [92.9033432, 13.02083111], [92.90346527, 13.02042294], [92.90359497, 13.02013111], [92.90367126, 13.01985073], [92.90383911, 13.01963043], [92.9039917, 13.01935196], [92.90422821, 13.01910114], [92.9045105, 13.01882458], [92.90480804, 13.01853085], [92.90511322, 13.01818943], [92.90532684, 13.01774025], [92.90551758, 13.01727104], [92.90555573, 13.01677418], [92.90550995, 13.01631355], [92.90531921, 13.01595783], [92.90516663, 13.0156002], [92.9050293, 13.01528072], [92.90503693, 13.0150032], [92.90519714, 13.01477528], [92.90529633, 13.01450157], [92.90545654, 13.01425266], [92.9056015, 13.013978], [92.90579987, 13.01371098], [92.90592957, 13.01338482], [92.90611267, 13.01307964], [92.90626526, 13.01275444], [92.90637207, 13.01238155], [92.90638733, 13.01197433], [92.90633392, 13.01156616], [92.90615845, 13.01120186], [92.90611267, 13.01085091], [92.9061203, 13.01051998], [92.90619659, 13.01021004], [92.9063797, 13.00991154], [92.90651703, 13.00959015], [92.90667725, 13.00927067], [92.90688324, 13.00895023], [92.90708923, 13.0085783], [92.90727997, 13.00816059], [92.90756226, 13.00778103], [92.90785217, 13.0074091], [92.90802002, 13.0069418], [92.90802002, 13.00642014], [92.90783691, 13.00596237], [92.90773773, 13.00549507], [92.90750122, 13.00527763], [92.90750122, 13.00360107], [92.90777588, 13.00333405], [92.90777588, 13.00305557], [92.90805817, 13.00277996], [92.90827179, 13.00238132], [92.90840149, 13.00191021], [92.90857697, 13.00152397], [92.90860748, 13.00114441], [92.90860748, 13.00082493], [92.90862274, 13.00054359], [92.90805817, 13.0], [92.90865326, 12.99972153], [92.90892029, 12.99970627], [92.90936279, 12.99944115], [92.909729, 12.9991684], [92.91004944, 12.99890137], [92.91034698, 12.9986496], [92.91069794, 12.99847317], [92.91114044, 12.99829674], [92.91160583, 12.9981308], [92.91181183, 12.99810791], [92.91207123, 12.99827671], [92.9124527, 12.99842167], [92.9128418, 12.99868011], [92.91311646, 12.99910164], [92.91327667, 12.99951172], [92.91388702, 13.00000191], [92.91339111, 13.00049877], [92.91342926, 13.0010004], [92.91357422, 13.00135994], [92.91384125, 13.00156498], [92.91417694, 13.00148964], [92.91445923, 13.00163174], [92.91477966, 13.00161076], [92.91506195, 13.00138092], [92.91536713, 13.00104141], [92.91598511, 13.00055122], [92.91583252, 13.0], [92.91603088, 12.99952126], [92.91609192, 12.99915218], [92.91631317, 12.99861622], [92.91616821, 12.9980011], [92.91615295, 12.99742413], [92.91605377, 12.99679661], [92.91590118, 12.99622059], [92.91590118, 12.99563122], [92.91584015, 12.99506092], [92.91584015, 12.99452972], [92.91590118, 12.99409199], [92.91604614, 12.99376202], [92.91613007, 12.9934473], [92.91609955, 12.9929409], [92.91616058, 12.99278164], [92.91651154, 12.99219799], [92.91696167, 12.99191093], [92.91734314, 12.99147129], [92.91772461, 12.99123859], [92.91861725, 12.99072075], [92.91844177, 12.99010086], [92.91771698, 12.98995113], [92.91749573, 12.98958874], [92.91732788, 12.98925114], [92.91720581, 12.98892975], [92.91732788, 12.98854923], [92.91773224, 12.98825836], [92.91793823, 12.98789978], [92.91819763, 12.98753071], [92.91851807, 12.98722076], [92.91882324, 12.98694038], [92.91912079, 12.98671913], [92.91947937, 12.98663712], [92.91980743, 12.98650932], [92.92015076, 12.98641396], [92.92053986, 12.98638916], [92.92095947, 12.98639107], [92.92138672, 12.98639107], [92.92180634, 12.98643017], [92.92217255, 12.98659229], [92.92255402, 12.98671532], [92.92285156, 12.98698139], [92.92313385, 12.98733902], [92.92357635, 12.98755074], [92.92405701, 12.98776054], [92.92453003, 12.98794079], [92.92492676, 12.98808193], [92.92521667, 12.98827076], [92.92551422, 12.98842812], [92.92576599, 12.98861122], [92.92602539, 12.98878193], [92.92633057, 12.98891163], [92.92664337, 12.98910999], [92.92701721, 12.98925114], [92.92742157, 12.98938084], [92.92779541, 12.98929501], [92.92827606, 12.98929501], [92.92867279, 12.98941326], [92.92909241, 12.98945045], [92.92948914, 12.98952007], [92.92984009, 12.9896822], [92.9302597, 12.9897213], [92.93073273, 12.989748], [92.93126678, 12.98986244], [92.93187714, 12.98993301], [92.93251801, 12.98971176], [92.93309784, 12.9893446], [92.93338776, 12.98877907], [92.93335724, 12.98820114], [92.93334198, 12.98763084], [92.93331909, 12.98709106], [92.9332428, 12.98660469], [92.93305206, 12.9861927], [92.93280029, 12.98583508], [92.93251038, 12.98551083], [92.93221283, 12.98521042], [92.93190002, 12.98495102], [92.931633, 12.98466969], [92.93138885, 12.98438072], [92.93119049, 12.98407078], [92.93094635, 12.98376083], [92.93097687, 12.98309994], [92.93106079, 12.98252106], [92.93088531, 12.98195267], [92.93087006, 12.98139954], [92.93090057, 12.9808979], [92.93103027, 12.98033142], [92.93148804, 12.98016739], [92.93180084, 12.9802742], [92.93215942, 12.98027134], [92.93257904, 12.98035431], [92.93306732, 12.98046303], [92.93360138, 12.98062229], [92.93414307, 12.98085022], [92.93470001, 12.98112202], [92.93527985, 12.98139286], [92.93590546, 12.98159313], [92.93651581, 12.98148155], [92.9369812, 12.98111916], [92.93733978, 12.98067856], [92.93754578, 12.98014164], [92.93773651, 12.97962189], [92.93774414, 12.97910213], [92.9376297, 12.97861671], [92.93756866, 12.97816086], [92.93777466, 12.97776413], [92.93804932, 12.97737503], [92.93830109, 12.97696686], [92.93847656, 12.976511], [92.938591, 12.97602463], [92.93856812, 12.97554016], [92.93840027, 12.97513866], [92.93828583, 12.97471046], [92.93805695, 12.97439098], [92.93786621, 12.97410011], [92.93786621, 12.97373009], [92.93776703, 12.97345924], [92.93780518, 12.97317028], [92.93789673, 12.97255039], [92.93810272, 12.97216225], [92.93835449, 12.97176266], [92.93852234, 12.97127628], [92.93834686, 12.9708519], [92.93817902, 12.97039127], [92.93802643, 12.96994209], [92.9377594, 12.96955967], [92.93744659, 12.96921062], [92.93715668, 12.96888924], [92.93690491, 12.96857262], [92.93677521, 12.96821022], [92.93656921, 12.96790028], [92.93636322, 12.9676199], [92.93609619, 12.96735954], [92.93580627, 12.96709061], [92.93544769, 12.96685028], [92.93501282, 12.96665096], [92.9345932, 12.96643925], [92.93414307, 12.96645069], [92.93373108, 12.96663094], [92.93331146, 12.96667194], [92.9329071, 12.96665096], [92.93253326, 12.96655273], [92.9322052, 12.9663868], [92.93193817, 12.96619129], [92.93171692, 12.96600246], [92.93157959, 12.965765], [92.93141937, 12.96551037], [92.93136597, 12.96514034], [92.93138123, 12.96464062], [92.93138885, 12.96402836], [92.93138885, 12.96336269], [92.93138123, 12.9627018], [92.93132782, 12.96209145], [92.93110657, 12.96158504], [92.93080902, 12.96110153], [92.93038177, 12.96066856], [92.92984772, 12.96026993], [92.92932129, 12.95985031], [92.92892456, 12.9593401], [92.92861938, 12.95880032], [92.92835236, 12.9582777], [92.92803955, 12.95782185], [92.92755127, 12.95757103], [92.92694092, 12.95755959], [92.92643738, 12.95782661], [92.9260788, 12.95823002], [92.92562866, 12.95841885], [92.92523956, 12.95886135], [92.9249115, 12.95936966], [92.92440796, 12.95969963], [92.92388916, 12.96000099], [92.9234314, 12.96028137], [92.9230423, 12.96049976], [92.92266083, 12.96058178], [92.92233276, 12.96066189], [92.92208099, 12.96064091], [92.92182922, 12.96055031], [92.92154694, 12.96043205], [92.92124176, 12.9602766], [92.92093658, 12.96010971], [92.92055511, 12.96000099], [92.92028046, 12.96000099], [92.91999817, 12.95971966], [92.91971588, 12.96000099], [92.91889191, 12.96000099], [92.9188385, 12.95952034], [92.91893768, 12.9592514], [92.91915131, 12.95894146], [92.91892242, 12.9582119], [92.91832733, 12.95722008], [92.91802216, 12.95696259], [92.91763306, 12.95689201], [92.91705322, 12.95710182], [92.91662598, 12.95724106], [92.9167099, 12.95695972], [92.91699219, 12.95653152], [92.91697693, 12.95631123], [92.91687775, 12.95605087], [92.9167099, 12.95571136], [92.91665649, 12.95517063], [92.91662598, 12.95453072], [92.91644287, 12.95390606], [92.91633606, 12.95326138], [92.91609955, 12.95271015], [92.91580963, 12.95220184], [92.91546631, 12.95169067], [92.91512299, 12.951231], [92.91477966, 12.95084953], [92.91464233, 12.95037079], [92.91445923, 12.94995022], [92.91429901, 12.94954586], [92.91413879, 12.94917011], [92.9139328, 12.94886684], [92.91387177, 12.94846153], [92.91374207, 12.94803143], [92.91356659, 12.94755745], [92.91330719, 12.94707108], [92.91300201, 12.94664955], [92.91268158, 12.94645119], [92.91234589, 12.94651985], [92.91194916, 12.94684982], [92.91144562, 12.94703674], [92.91092682, 12.94725132], [92.91044617, 12.94756126], [92.90999603, 12.9479599], [92.90956116, 12.94839096], [92.90920258, 12.94886971], [92.90891266, 12.9494009], [92.90867615, 12.94994831], [92.90822601, 12.95059013], [92.90791321, 12.95115089], [92.90782928, 12.9518528], [92.90791321, 12.95251179], [92.90814209, 12.95290756], [92.90833282, 12.95327473], [92.90836334, 12.95355129], [92.90848541, 12.95377445], [92.90859222, 12.95397472], [92.90862274, 12.95420265], [92.90862274, 12.95446014], [92.90861511, 12.95473766], [92.90862274, 12.95504093], [92.90820313, 12.95600986], [92.90809631, 12.95652962], [92.9081192, 12.95749569], [92.90821838, 12.95788956], [92.90843201, 12.9586544], [92.90844727, 12.95923042], [92.90907288, 12.96033764], [92.90920258, 12.96079159], [92.90940857, 12.96117878], [92.90953827, 12.96159172], [92.90968323, 12.96197033], [92.90969849, 12.96231937], [92.90959167, 12.96262169], [92.90944672, 12.96290398], [92.9092865, 12.96319199], [92.90904236, 12.96343994], [92.90872955, 12.96364975], [92.90841675, 12.96391201], [92.90811157, 12.96419907], [92.90782928, 12.96452045], [92.90761566, 12.9648962], [92.90727234, 12.96540928], [92.90702057, 12.96585083], [92.90682983, 12.96624088], [92.90673065, 12.96660995], [92.90662384, 12.96710491], [92.90647888, 12.96778202], [92.90639496, 12.96865463], [92.90641785, 12.96919537], [92.90647888, 12.96964169], [92.90670776, 12.97001076], [92.90692902, 12.97036171], [92.90703583, 12.97083092], [92.90711975, 12.97127056], [92.90720367, 12.97164917], [92.90716553, 12.97204399], [92.90696716, 12.9724474], [92.90679169, 12.97294426], [92.90661621, 12.97350502], [92.90638733, 12.97406101], [92.90603638, 12.9744072], [92.9058075, 12.9752512], [92.90618896, 12.97587967], [92.90639496, 12.976367], [92.90664673, 12.97677994], [92.9068985, 12.97718143], [92.90711212, 12.97756767], [92.9072113, 12.97799206], [92.9072113, 12.97842312], [92.90711975, 12.97882175], [92.90692902, 12.9791708], [92.90667725, 12.97949028], [92.90623474, 12.97967911], [92.90612793, 12.98056126], [92.90641785, 12.98125076], [92.90663147, 12.98153019], [92.90676117, 12.98188114], [92.9069519, 12.98250008], [92.90709686, 12.98275566], [92.90725708, 12.98299026], [92.90744019, 12.98330975], [92.90750122, 12.98362446], [92.90749359, 12.9839344], [92.9074173, 12.98422146], [92.90725708, 12.98448563], [92.90714264, 12.98476982], [92.90693665, 12.98502827], [92.9066391, 12.98528957], [92.90625, 12.98555946], [92.9058075, 12.98583031], [92.9053421, 12.98606014], [92.90484619, 12.98611069], [92.90438843, 12.98611546], [92.90393829, 12.98611069], [92.9034729, 12.98606968], [92.90296936, 12.9858799], [92.90239716, 12.98585129], [92.90180206, 12.98586369], [92.90162659, 12.98590469], [92.90125275, 12.98599243], [92.90068054, 12.9859581], [92.90011597, 12.98590088], [92.89962769, 12.98596001], [92.89901733, 12.98620892], [92.89850616, 12.9865818], [92.89833069, 12.98708153], [92.89813995, 12.98753071], [92.89817047, 12.98816013], [92.89837646, 12.98884106], [92.89834595, 12.98933125], [92.89837646, 12.98993969], [92.89845276, 12.99048042], [92.89840698, 12.99094868], [92.89884186, 12.99151039], [92.89853668, 12.99201107], [92.89863586, 12.99266148], [92.89914703, 12.99299622], [92.89939117, 12.99330139], [92.89940643, 12.99367142], [92.89930725, 12.99398041], [92.89903259, 12.99419689], [92.89875793, 12.99442005], [92.8984375, 12.99461555], [92.89806366, 12.99480057], [92.89768219, 12.99496269], [92.89730072, 12.99500179], [92.89720917, 12.99499702], [92.89697266, 12.9949789], [92.89671326, 12.99489212], [92.89652252, 12.99472141], [92.89634705, 12.99452114], [92.89614868, 12.99432182], [92.89598846, 12.99404716], [92.89581299, 12.99374104], [92.89554596, 12.99341965], [92.89530182, 12.99305058], [92.89509583, 12.99261475], [92.89484406, 12.99224758], [92.89453888, 12.99194527], [92.89421844, 12.99166012], [92.89389038, 12.99136162], [92.89354706, 12.99103832], [92.89319611, 12.99068928], [92.89285278, 12.99034977], [92.8924942, 12.99012184], [92.89218903, 12.98995113], [92.89196014, 12.98974133], [92.89176178, 12.98954296], [92.89156342, 12.98933792], [92.89138794, 12.98910522], [92.89122009, 12.98885536], [92.89109039, 12.98857021], [92.89092255, 12.98830128], [92.89076233, 12.98799992], [92.89054871, 12.98768139], [92.89035797, 12.98729134], [92.89015961, 12.98686028], [92.88994598, 12.98636055], [92.88970947, 12.98583031], [92.88944244, 12.98531532], [92.88916779, 12.98481178], [92.88889313, 12.98433113], [92.88861084, 12.98386574], [92.88833618, 12.98341179], [92.88806152, 12.98297024], [92.88794708, 12.98253918], [92.88777924, 12.98250008], [92.88748932, 12.98228168], [92.88722229, 12.98278999], [92.88694763, 12.98306084], [92.88666534, 12.98305416], [92.8861084, 12.98361015], [92.88583374, 12.98361015], [92.88563538, 12.98341179], [92.88555908, 12.98333454], [92.88471985, 12.98333454], [92.8842392, 12.98333454], [92.88370514, 12.98332787], [92.88317871, 12.9832592], [92.88270569, 12.98304272], [92.88230133, 12.98272419], [92.8819809, 12.98232746], [92.88182831, 12.98188114], [92.88189697, 12.98148155], [92.88212585, 12.98112202], [92.88239288, 12.98085308], [92.88271332, 12.98061562], [92.8830719, 12.98029423], [92.88342285, 12.97985363], [92.88358307, 12.97923946], [92.88356018, 12.97861004], [92.88336945, 12.97808075], [92.88323975, 12.97756767], [92.88304901, 12.97711945], [92.8828125, 12.97671127], [92.88253784, 12.97633076], [92.88228607, 12.97592068], [92.88198853, 12.97554016], [92.88168335, 12.97515011], [92.8813858, 12.97472191], [92.88110352, 12.97430038], [92.88080597, 12.97391033], [92.88049316, 12.97355938], [92.88011169, 12.97336102], [92.87976074, 12.97321129], [92.87953949, 12.97298145], [92.87947845, 12.972682], [92.87961578, 12.97233295], [92.87984467, 12.97194767], [92.88011169, 12.97158146], [92.88043976, 12.97122955], [92.88076782, 12.970891], [92.88109589, 12.97050953], [92.8813858, 12.97009087], [92.88160706, 12.96964169], [92.88159943, 12.96914005], [92.8813858, 12.96869087], [92.88111115, 12.96829033], [92.88092041, 12.96749687], [92.88031006, 12.96739674], [92.87975311, 12.96726036], [92.87927246, 12.96724606], [92.87892151, 12.96720982], [92.87856293, 12.96700191], [92.87820435, 12.96681309], [92.87783813, 12.96660328], [92.87749481, 12.96631908], [92.87711334, 12.96601105], [92.87667084, 12.96570969], [92.87623596, 12.96539116], [92.87584686, 12.965065], [92.87552643, 12.96472073], [92.8752594, 12.96436119], [92.87505341, 12.96397114], [92.87501526, 12.96349716], [92.87507629, 12.96299076], [92.87528992, 12.96253777], [92.87552643, 12.96214962], [92.87573242, 12.96179008], [92.87599182, 12.96152115], [92.87638855, 12.96136379], [92.87676239, 12.9611063], [92.87712097, 12.96079159], [92.87741089, 12.96039104], [92.87748718, 12.95983028], [92.87750244, 12.9592514], [92.87749481, 12.95868778], [92.87741852, 12.95815945], [92.87721252, 12.9576807], [92.87692261, 12.95722485], [92.87654114, 12.95683098], [92.87615204, 12.95646954], [92.8757782, 12.95605087], [92.87548065, 12.9555912], [92.87515259, 12.95516014], [92.87477875, 12.95483398], [92.87452698, 12.95446873], [92.87431335, 12.9541502], [92.87414551, 12.95384026], [92.87397766, 12.95353699], [92.87393951, 12.95321083], [92.87406921, 12.95283985], [92.87413025, 12.9524641], [92.87401581, 12.95209217], [92.87382507, 12.95173168], [92.87354279, 12.95138264], [92.87322998, 12.95101643], [92.87291718, 12.95066071], [92.8727951, 12.95028305], [92.87277985, 12.94993591], [92.87281036, 12.94964027], [92.87296295, 12.94937134], [92.87309265, 12.94908619], [92.8731308, 12.94877243], [92.87332153, 12.9485817], [92.87355042, 12.94856167], [92.87384033, 12.94841766], [92.8742981, 12.94829273], [92.87483978, 12.94810104], [92.87542725, 12.94803143], [92.87597656, 12.94787121], [92.87637329, 12.94756603], [92.87666321, 12.94721031], [92.87690735, 12.9468708], [92.87708282, 12.94651985], [92.87719727, 12.94614124], [92.87722015, 12.94571686], [92.87718964, 12.94527054], [92.87700653, 12.94486141], [92.87712097, 12.94439316], [92.87680817, 12.94399357], [92.87605286, 12.94383907], [92.87567902, 12.94355011], [92.8753891, 12.94316864], [92.87509918, 12.94273186], [92.87482452, 12.94221401], [92.87449646, 12.94167042], [92.87411499, 12.94115162], [92.87359619, 12.94079494], [92.87319183, 12.94038391], [92.87294769, 12.93989372], [92.87275696, 12.93941975], [92.87254333, 12.93903065], [92.87239075, 12.93863201], [92.87223816, 12.93825054], [92.87211609, 12.93785], [92.87187958, 12.93749046], [92.87159729, 12.93712521], [92.87133026, 12.93663979], [92.8709259, 12.93622017], [92.8704834, 12.93583107], [92.87005615, 12.93544102], [92.86972046, 12.93502617], [92.86937714, 12.93466091], [92.86889648, 12.93443775], [92.86837769, 12.93425083], [92.86782074, 12.93412971], [92.86733246, 12.93396187], [92.86699677, 12.93390179], [92.86669159, 12.93396187], [92.8660965, 12.9341011], [92.86572266, 12.93408012], [92.86519623, 12.93420124], [92.86472321, 12.93418121], [92.86414337, 12.93428993], [92.86377716, 12.93438053], [92.86325836, 12.93440247], [92.86281586, 12.93436146], [92.86232758, 12.93433094], [92.86187744, 12.93433094], [92.86154175, 12.93429661], [92.86112976, 12.93435383], [92.8607254, 12.93420601], [92.86004639, 12.93405056], [92.85980225, 12.93417645], [92.85955048, 12.93432045], [92.85926819, 12.93456554], [92.85897827, 12.93484116], [92.85869598, 12.93497086], [92.85839081, 12.93500805], [92.85782623, 12.93504238], [92.85716248, 12.93430996], [92.85735321, 12.93306065], [92.85772705, 12.93279934], [92.85778046, 12.93232059], [92.8577652, 12.93181038], [92.85765839, 12.93133163], [92.85739136, 12.93100071], [92.85714722, 12.9307003], [92.85684204, 12.93055153], [92.85654449, 12.9304266], [92.85624695, 12.93028069], [92.85595703, 12.93013], [92.85569763, 12.92996025], [92.85546112, 12.92971134], [92.85523987, 12.92940331], [92.85501862, 12.92904091], [92.8548584, 12.92861938], [92.85470581, 12.9282074], [92.85452271, 12.9278307], [92.85443878, 12.92743015], [92.85443878, 12.9270401], [92.85443878, 12.92669106], [92.85443878, 12.92636967], [92.85443878, 12.92605972], [92.85441589, 12.92572021], [92.85430908, 12.92535114], [92.85441589, 12.92492867], [92.85443878, 12.92446041], [92.85443878, 12.92394924], [92.85444641, 12.92342281], [92.85444641, 12.92286491], [92.85443878, 12.92226982], [92.85444641, 12.92166328], [92.85449219, 12.92107964], [92.85466003, 12.92060089], [92.85470581, 12.92015934], [92.85472107, 12.91975975], [92.85472107, 12.91935921], [92.85472107, 12.91893101], [92.85468292, 12.91847038], [92.85448456, 12.9180603], [92.85437775, 12.91762924], [92.8542099, 12.91729927], [92.85412598, 12.91695023], [92.85398102, 12.91665173], [92.85413361, 12.91636372], [92.85421753, 12.91612053], [92.85427856, 12.91570091], [92.85455322, 12.91578102], [92.85486603, 12.91565132], [92.85523987, 12.91534996], [92.85555267, 12.91472054], [92.85555267, 12.9141674], [92.85569, 12.91392994], [92.8557663, 12.9137907], [92.85579681, 12.91349125], [92.85581207, 12.91289997], [92.85596466, 12.91270638], [92.85632324, 12.9129343], [92.85722351, 12.91333294], [92.85778046, 12.91333294], [92.85836029, 12.91334248], [92.85900879, 12.91315842], [92.85943604, 12.91274071], [92.85962677, 12.91220093], [92.85943604, 12.91164017], [92.85913849, 12.91107178], [92.85874176, 12.9105711], [92.85830688, 12.91014004], [92.8578949, 12.90983486], [92.85753632, 12.90959072], [92.85730743, 12.9093399], [92.85723114, 12.90902138], [92.85721588, 12.90866089], [92.85721588, 12.90827084], [92.85722351, 12.90789318], [92.85723877, 12.90753746], [92.85733795, 12.90724087], [92.85748291, 12.90696144], [92.85755157, 12.90665531], [92.85772705, 12.90639973], [92.85780334, 12.90604019], [92.85792542, 12.9056797], [92.85803986, 12.90527725], [92.85813141, 12.90484142], [92.85832977, 12.90446091], [92.8585434, 12.90408039], [92.85869598, 12.90368271], [92.85892487, 12.90336895], [92.85919189, 12.9031496], [92.85948181, 12.90302944], [92.85971069, 12.90289879], [92.85996246, 12.90278053], [92.86029816, 12.90265083], [92.86076355, 12.9025116], [92.86138153, 12.90239811], [92.86206818, 12.90227032], [92.8628006, 12.90219975], [92.8635025, 12.90207195], [92.86415863, 12.90198135], [92.86474609, 12.90201092], [92.8651886, 12.90221119], [92.86548615, 12.90240002], [92.86582947, 12.90262127], [92.86586761, 12.90288067], [92.86591339, 12.90318871], [92.8658371, 12.90371132], [92.8658371, 12.90428066], [92.86591339, 12.90480042], [92.86617279, 12.90513992], [92.86644745, 12.90540886], [92.86672211, 12.90568447], [92.86701202, 12.90602016], [92.86741638, 12.90635014], [92.86786652, 12.90668964], [92.86828613, 12.90709972], [92.86864471, 12.90759182], [92.8690567, 12.90802956], [92.86952209, 12.90841007], [92.87002563, 12.90874958], [92.87056732, 12.90903854], [92.87116241, 12.9092989], [92.87181091, 12.90946102], [92.87242889, 12.90964127], [92.87303925, 12.90971184], [92.87361908, 12.90970039], [92.87414551, 12.90960026], [92.87462616, 12.9094696], [92.87509155, 12.90939045], [92.87547302, 12.9091692], [92.87578583, 12.90893173], [92.87605286, 12.90865612], [92.87625885, 12.90829182], [92.87641144, 12.90781975], [92.87661743, 12.90729141], [92.87666321, 12.90665054], [92.87663269, 12.90600109], [92.87638855, 12.9054203], [92.87610626, 12.90492344], [92.8757782, 12.90450764], [92.87541962, 12.90417957], [92.87502289, 12.90389061], [92.87465668, 12.90358067], [92.87433624, 12.90320492], [92.87394714, 12.90283108], [92.87359619, 12.90248013], [92.87332153, 12.90209007], [92.87304688, 12.90170956], [92.8727951, 12.90133953], [92.872612, 12.90092087], [92.87245178, 12.90051079], [92.87226868, 12.90013504], [92.8722229, 12.89968109], [92.87218475, 12.8992281], [92.87203979, 12.89883137], [92.87195587, 12.89843178], [92.87188721, 12.89804935], [92.87171173, 12.89773941], [92.87165833, 12.89740658], [92.87158966, 12.89705086], [92.87143707, 12.89671612], [92.87137604, 12.89630127], [92.87126923, 12.89585018], [92.8711319, 12.89540958], [92.87100983, 12.89492035], [92.87081909, 12.89442062], [92.87060547, 12.89391518], [92.87050629, 12.89333153], [92.87030792, 12.89282131], [92.87018585, 12.8923111], [92.87003326, 12.8918457], [92.86995697, 12.89135075], [92.86978149, 12.89085197], [92.86974335, 12.89031887], [92.86981201, 12.88980961], [92.86995697, 12.88936996], [92.87001801, 12.88893986], [92.87010956, 12.88854122], [92.87023163, 12.88818073], [92.87030792, 12.88773155], [92.87047577, 12.88729858], [92.8706665, 12.88689137], [92.87097168, 12.88653088], [92.87132263, 12.88615704], [92.87171936, 12.88574028], [92.87219238, 12.8853302], [92.87269592, 12.88493061], [92.87299347, 12.88448238], [92.8730545, 12.88400269], [92.87303925, 12.88357735], [92.87293243, 12.88323021], [92.8727417, 12.88294983], [92.87245941, 12.88273144], [92.87211609, 12.88253975], [92.87166595, 12.88245106], [92.87123108, 12.88228512], [92.87075806, 12.88221169], [92.87029266, 12.88209057], [92.86985016, 12.88197231], [92.86942291, 12.8819313], [92.8690567, 12.88184547], [92.86875916, 12.88162422], [92.8682785, 12.88156414], [92.86786652, 12.88146877], [92.86721802, 12.88155079], [92.8666687, 12.88152122], [92.86615753, 12.88142109], [92.86565399, 12.88132668], [92.86522675, 12.88117027], [92.86479187, 12.88110447], [92.86435699, 12.88107681], [92.86392975, 12.88109016], [92.86377716, 12.88109016], [92.86347961, 12.88108826], [92.86302185, 12.88107014], [92.86258698, 12.88094044], [92.86212921, 12.8808279], [92.86167145, 12.88069057], [92.8612442, 12.88053226], [92.86084747, 12.88031769], [92.8604126, 12.8801403], [92.85999298, 12.87983036], [92.85951233, 12.87953377], [92.85899353, 12.87927246], [92.85848236, 12.87903023], [92.85800934, 12.8788414], [92.85755157, 12.87871075], [92.85701752, 12.87870026], [92.85652161, 12.87866783], [92.85605621, 12.87852192], [92.85557556, 12.87830544], [92.85519409, 12.87834167], [92.85482788, 12.87844181], [92.85443878, 12.8785696], [92.85401917, 12.87860775], [92.85359955, 12.87861347], [92.85318756, 12.87861061], [92.85277557, 12.87861061], [92.85236359, 12.87861061], [92.85194397, 12.87861061], [92.85150909, 12.87861347], [92.85105896, 12.87861061], [92.85058594, 12.8785696], [92.85015869, 12.87839031], [92.84966278, 12.8783102], [92.84916687, 12.87819386], [92.84867096, 12.87805462], [92.84818268, 12.87790203], [92.84771729, 12.87774944], [92.84729004, 12.8775301], [92.84681702, 12.87737083], [92.84630585, 12.87721062], [92.84583282, 12.87704945], [92.84533691, 12.87689018], [92.84488678, 12.87670135], [92.84440613, 12.87656593], [92.84390259, 12.87644958], [92.84340668, 12.8763504], [92.8429718, 12.87629986], [92.84243774, 12.87652302], [92.84201813, 12.87658024], [92.84171295, 12.87662983], [92.84134674, 12.87693501], [92.84126282, 12.87718201], [92.84123993, 12.8776207], [92.84123993, 12.87801075], [92.84130859, 12.87851048], [92.84139252, 12.8791666], [92.84139252, 12.87944508], [92.84166718, 12.87972069], [92.84166718, 12.88055515], [92.84194183, 12.8808279], [92.84194183, 12.88139057], [92.84222412, 12.88166714], [92.84222412, 12.88194466], [92.84249878, 12.88222122], [92.84249878, 12.88250065], [92.84288788, 12.88314247], [92.84306335, 12.88334179], [92.84306335, 12.88361073], [92.84333038, 12.8838892], [92.84333038, 12.88444519], [92.84361267, 12.8847208], [92.84361267, 12.88528156], [92.84388733, 12.88556194], [92.84388733, 12.88640118], [92.84388733, 12.88671112], [92.84393311, 12.88776588], [92.84388733, 12.88833141], [92.84368134, 12.88936138], [92.84361267, 12.89027977], [92.84346771, 12.89099121], [92.84311676, 12.89155197], [92.84278107, 12.89187145], [92.84233856, 12.8920393], [92.84194183, 12.8921814], [92.84156799, 12.89229012], [92.83891296, 12.89185047], [92.83839417, 12.891716], [92.83782196, 12.89144039], [92.83718109, 12.89112091], [92.83653259, 12.89075184], [92.83600616, 12.89027119], [92.83553314, 12.88973713], [92.83505249, 12.88924122], [92.83467865, 12.88868046], [92.83416748, 12.88827038], [92.83365631, 12.8879118], [92.83322144, 12.88753986], [92.83280945, 12.8872509], [92.83246613, 12.88698196], [92.83216095, 12.88676071], [92.83144379, 12.88624573], [92.83100128, 12.88618183], [92.83049774, 12.88618183], [92.82997131, 12.88619995], [92.82965851, 12.88643265], [92.82917786, 12.8866396], [92.82884216, 12.88689137], [92.82849884, 12.88723946], [92.82771301, 12.88819027], [92.82762146, 12.88847733], [92.82759857, 12.88886929], [92.82758331, 12.88926125], [92.82736969, 12.89040089], [92.82723999, 12.89091969], [92.82722473, 12.89130783], [92.82714081, 12.89177036], [92.82705688, 12.89228058], [92.8265686, 12.89404011], [92.82644653, 12.89472198], [92.8264389, 12.89521027], [92.82615662, 12.89554024], [92.82579041, 12.89584064], [92.82538605, 12.89614201], [92.82499695, 12.89648056], [92.8245697, 12.89675903], [92.82406616, 12.89693928], [92.82353973, 12.89708996], [92.8229599, 12.89718628], [92.82236481, 12.89723301], [92.82205963, 12.89725876], [92.82180023, 12.89728069], [92.82125854, 12.89723969], [92.82077026, 12.89723301], [92.82032013, 12.89727211], [92.81990814, 12.8973999], [92.81947327, 12.89748192], [92.81900024, 12.89749813], [92.81851959, 12.89750195], [92.81803131, 12.89754581], [92.81755829, 12.89772129], [92.81703186, 12.89782143], [92.81655884, 12.89804268], [92.81611633, 12.89826965], [92.81565857, 12.89849758], [92.81516266, 12.89869022], [92.81456757, 12.89882183], [92.8140564, 12.89914131], [92.81350708, 12.89936447], [92.81289673, 12.89948082], [92.81230927, 12.89968109], [92.81167603, 12.89972019], [92.81099701, 12.89973068], [92.81031036, 12.8997612], [92.80961609, 12.89992142], [92.80890656, 12.9000206], [92.80818939, 12.90011024], [92.80745697, 12.9000597], [92.80675507, 12.90000534], [92.80607605, 12.89994144], [92.80554199, 12.89972019], [92.80512238, 12.89946175], [92.80480194, 12.89923], [92.80449677, 12.89907742], [92.80426025, 12.89892006], [92.80397797, 12.89881134], [92.80367279, 12.89865971], [92.80329132, 12.89863968], [92.80288696, 12.89879036], [92.80253601, 12.89904976], [92.80229187, 12.89940071], [92.80216217, 12.89983559], [92.80194092, 12.90017414], [92.80170441, 12.9004631], [92.80148315, 12.90075016], [92.80134583, 12.9011507], [92.80130768, 12.90156174], [92.8013382, 12.90195084], [92.80120087, 12.90227032], [92.80106354, 12.90264893], [92.80091095, 12.90311432], [92.80075836, 12.90367889], [92.80053711, 12.9042902], [92.8003006, 12.90489101], [92.8000946, 12.90544987], [92.79989624, 12.90592384], [92.79969025, 12.90629101], [92.79946899, 12.90659809], [92.79930878, 12.9069519], [92.79914093, 12.90732288], [92.79891968, 12.90767193], [92.79875946, 12.908041], [92.79859924, 12.90837193], [92.79842377, 12.90869713], [92.79831696, 12.90907097], [92.79817963, 12.909482], [92.79802704, 12.90994358], [92.7977829, 12.9104023], [92.79750061, 12.91088104], [92.79719543, 12.91137505], [92.79679871, 12.91181278], [92.79638672, 12.91222095], [92.79599762, 12.91258144], [92.79557037, 12.91281128], [92.79551697, 12.9129982], [92.79463959, 12.91349125], [92.79438782, 12.91382599], [92.79419708, 12.91438198], [92.79430389, 12.91522884], [92.79493713, 12.91575432], [92.79502869, 12.91631889], [92.7951889, 12.91687965], [92.7952652, 12.91746521], [92.79522705, 12.91807175], [92.79505157, 12.91866016], [92.7950058, 12.91928196], [92.79506683, 12.9198494], [92.79522705, 12.92034245], [92.79527283, 12.92084122], [92.79528046, 12.92132187], [92.79512024, 12.92208672], [92.79503632, 12.92227364], [92.79515839, 12.92313957], [92.7952652, 12.92345047], [92.79538727, 12.92383957], [92.79543304, 12.92405033], [92.79547119, 12.92467022], [92.79548645, 12.92525959], [92.7953186, 12.92605972], [92.79506683, 12.92644119], [92.79477692, 12.92688274], [92.79447937, 12.92735004], [92.79389191, 12.92801952], [92.79380798, 12.92851925], [92.79366302, 12.92892933], [92.7935791, 12.92923927], [92.7935791, 12.92971325], [92.79361725, 12.92996025], [92.79374695, 12.93035603], [92.79385376, 12.93064308], [92.79405975, 12.93089199], [92.7942276, 12.93100071], [92.79476166, 12.93093967], [92.79502869, 12.93082142], [92.79528046, 12.93057919], [92.79554749, 12.9304018], [92.79586029, 12.93030071], [92.79624176, 12.93028069], [92.79667664, 12.93028069], [92.79712677, 12.93028069], [92.79753113, 12.9302702], [92.79785156, 12.93029022], [92.79811096, 12.93035793], [92.79833984, 12.93052006], [92.79857635, 12.93062973], [92.79873657, 12.93081188], [92.79886627, 12.93104172], [92.79892731, 12.9314003], [92.79911804, 12.93185997], [92.79917908, 12.93242073], [92.79928589, 12.93298912], [92.79947662, 12.93350124], [92.79972076, 12.93396854], [92.79997253, 12.93439198], [92.80031586, 12.93465042], [92.80053711, 12.93496704], [92.80078888, 12.93521118], [92.80094147, 12.93552971], [92.8010788, 12.93586922], [92.80110931, 12.93629074], [92.80111694, 12.93677044], [92.80117035, 12.93728161], [92.80136108, 12.93772221], [92.80151367, 12.93817139], [92.80164337, 12.93858242], [92.80164337, 12.9389801], [92.80149078, 12.93937016], [92.80134583, 12.93982124], [92.80108643, 12.94031143], [92.80072784, 12.94078064], [92.80027008, 12.94120026], [92.79981232, 12.94161034], [92.79951477, 12.94213676], [92.79944611, 12.94276428], [92.79949951, 12.94335175], [92.79972076, 12.94380474], [92.79998016, 12.94419956], [92.80021667, 12.94460106], [92.80034637, 12.94510746], [92.80051422, 12.94564247], [92.80055237, 12.9461689], [92.80055237, 12.94639015], [92.80055237, 12.94666576], [92.80027008, 12.94694138], [92.80027008, 12.94750023], [92.80000305, 12.94777966], [92.80000305, 12.94805622], [92.79972076, 12.94833183], [92.79950714, 12.94852066], [92.79921722, 12.94868946], [92.79895782, 12.94888973], [92.79869843, 12.94906139], [92.79837799, 12.94914055], [92.79795837, 12.94917011], [92.7974472, 12.94916821], [92.79688263, 12.94920921], [92.79634094, 12.94941044], [92.79579926, 12.94952106], [92.79541779, 12.94974041], [92.79514313, 12.94999981], [92.7949295, 12.95023918], [92.79469299, 12.95043087], [92.79441833, 12.95060158], [92.79412079, 12.95083046], [92.79376221, 12.95107079], [92.79332733, 12.95125961], [92.7928772, 12.95147038], [92.79277802, 12.95167065], [92.79265594, 12.95229053], [92.79269409, 12.95253658], [92.79268646, 12.95368958], [92.79263306, 12.95390034], [92.79269409, 12.95421028], [92.79273987, 12.95462036], [92.79263306, 12.95505524], [92.79244232, 12.95530128], [92.79210663, 12.95543957], [92.79190063, 12.95569134], [92.79177094, 12.95608139], [92.79173279, 12.95631123], [92.79173279, 12.95672131], [92.7918396, 12.95707035], [92.79196167, 12.95728016], [92.79216766, 12.95762825], [92.79250336, 12.95833015], [92.79250336, 12.9591713], [92.79194641, 12.96028137], [92.79263306, 12.9604454], [92.7928009, 12.96079159], [92.79277802, 12.96150112], [92.79273987, 12.96168137], [92.79224396, 12.96144581], [92.7921524, 12.96140003], [92.7918396, 12.9613409], [92.79161072, 12.96155071], [92.79158783, 12.9618988], [92.79167175, 12.96229362], [92.79194641, 12.9644289], [92.79219055, 12.96472073], [92.79222107, 12.96521759], [92.79227448, 12.96576214], [92.79224396, 12.96591282], [92.79231262, 12.96626186], [92.79243469, 12.9664917], [92.79248047, 12.96690369], [92.79248047, 12.96714973], [92.79266357, 12.96737766], [92.79279327, 12.96745968], [92.79298401, 12.9676466], [92.79321289, 12.96779346], [92.79347992, 12.96784973], [92.79393005, 12.96794128], [92.79411316, 12.9677906], [92.79433441, 12.96761322], [92.79471588, 12.9671936], [92.7950592, 12.96675205], [92.79543304, 12.966362], [92.79574585, 12.96594048], [92.79598236, 12.96543026], [92.79618073, 12.96500111], [92.79640961, 12.96471024], [92.79663086, 12.96454144], [92.79683685, 12.96459579], [92.79701996, 12.96478462], [92.79715729, 12.96501541], [92.79714203, 12.96536446], [92.79693604, 12.9657917], [92.79655457, 12.96628857], [92.79647064, 12.96669006], [92.79660034, 12.96707058], [92.79670715, 12.9675312], [92.79695129, 12.96799564], [92.79722595, 12.96846104], [92.79760742, 12.97071743], [92.79754639, 12.97120953], [92.79727173, 12.97166824], [92.79710388, 12.97183418], [92.79614258, 12.97272968], [92.79589081, 12.97313976], [92.79556274, 12.97362137], [92.79555511, 12.9738903], [92.79499817, 12.97444057], [92.7943573, 12.97523022], [92.79413605, 12.97556019], [92.79385376, 12.97654724], [92.79385376, 12.97704411], [92.79347229, 12.97890186], [92.79328156, 12.97928047], [92.79315186, 12.9796114], [92.79294586, 12.97998047], [92.7929306, 12.98033142], [92.79301453, 12.98092842], [92.79302979, 12.98134041], [92.79310608, 12.98178005], [92.79329681, 12.98215199], [92.79390717, 12.98291969], [92.79383087, 12.98329067], [92.79395294, 12.98343945], [92.79418945, 12.98397541], [92.79416656, 12.98449039], [92.79408264, 12.985322], [92.79413605, 12.98561096], [92.79427338, 12.98569107], [92.79447937, 12.98575115], [92.79458618, 12.98598099], [92.79464722, 12.98631096], [92.7946701, 12.98647976], [92.79486084, 12.98711586], [92.79502869, 12.98734093], [92.79511261, 12.98742962], [92.79528046, 12.98750973], [92.79543304, 12.98750973], [92.79756927, 12.98928547], [92.79842377, 12.98982334], [92.79873657, 12.9901104], [92.79892731, 12.99053001], [92.79899597, 12.99082184], [92.79910278, 12.99119091], [92.79915619, 12.99131203], [92.79930878, 12.99145508], [92.79968262, 12.99166298], [92.79995728, 12.99158096], [92.80053711, 12.9911499], [92.8009491, 12.99083996], [92.8014679, 12.99042034], [92.80165863, 12.98990536], [92.80197144, 12.98953247], [92.80229187, 12.98895454], [92.80246735, 12.98851967], [92.8025589, 12.98814964], [92.80259705, 12.98767185], [92.80274963, 12.98732281], [92.80310822, 12.98684692], [92.80342102, 12.98629093], [92.80355072, 12.9857893], [92.80361176, 12.98527908], [92.80361176, 12.98500061], [92.80444336, 12.98417091], [92.80473328, 12.98417091], [92.80500031, 12.98389053], [92.80526733, 12.98389053], [92.80583191, 12.98332977], [92.8061142, 12.98333454], [92.80638885, 12.98305416], [92.80805206, 12.98305416], [92.80833435, 12.98333454], [92.8088913, 12.98333454], [92.80932617, 12.98338032], [92.80973053, 12.98360062], [92.81017303, 12.98378086], [92.81056976, 12.98391056], [92.81080627, 12.98425102], [92.81128693, 12.98420143], [92.81167603, 12.98384953], [92.81200409, 12.98361492], [92.81228638, 12.9833889], [92.81259155, 12.98322964], [92.81285858, 12.98307037], [92.81317902, 12.98306084], [92.81355286, 12.98313427], [92.81398773, 12.98336697], [92.81440735, 12.98374939], [92.81479645, 12.98425961], [92.81510162, 12.98484993], [92.81500244, 12.98535156], [92.81502533, 12.98567963], [92.81507111, 12.98598957], [92.81521606, 12.98628235], [92.81542206, 12.9865694], [92.81564331, 12.98673058], [92.81597137, 12.98681927], [92.81645203, 12.98681927], [92.81668854, 12.98673058], [92.81700134, 12.98669434], [92.81712341, 12.98667145], [92.81788635, 12.98667145], [92.81826019, 12.98678112], [92.818367, 12.98720932], [92.8188858, 12.98778057], [92.81916809, 12.98805523], [92.81890106, 12.98860168], [92.81884003, 12.98897076], [92.8187561, 12.98919201], [92.818367, 12.98946095], [92.81820679, 12.98968887], [92.81815338, 12.98983002], [92.81749725, 12.99053669], [92.81703186, 12.99075985], [92.81663513, 12.99090767], [92.81613159, 12.99105358], [92.81466675, 12.99086666], [92.81408691, 12.99090958], [92.81332397, 12.99126053], [92.81302643, 12.99168968], [92.81285095, 12.99215031], [92.81260681, 12.99255085], [92.81242371, 12.9929657], [92.81218719, 12.99330139], [92.81192017, 12.99357033], [92.81161499, 12.99377823], [92.81126404, 12.99387264], [92.81086731, 12.99388027], [92.81047821, 12.99390125], [92.81028748, 12.99387074], [92.81003571, 12.99368858], [92.80869293, 12.99362946], [92.80840302, 12.99403954], [92.80844116, 12.99424744], [92.8086319, 12.99441147], [92.80877686, 12.99446964], [92.80893707, 12.99455929], [92.80908966, 12.9946413], [92.80914307, 12.99495125], [92.80908966, 12.99578094], [92.80905151, 12.99611092], [92.80898285, 12.9965601], [92.80900574, 12.99695206], [92.80900574, 12.99724197], [92.80882263, 12.99744034], [92.80873108, 12.99760723], [92.80869293, 12.99777126], [92.80890656, 12.99801922], [92.80903625, 12.9980402], [92.80930328, 12.9980402], [92.80990601, 12.99808979], [92.81008148, 12.99808979], [92.81066132, 12.99844456], [92.81130981, 12.99875069], [92.81147766, 12.99875832], [92.81199646, 12.99878025], [92.81222534, 12.99868679], [92.81255341, 12.99855232], [92.81283569, 12.99824047], [92.81327057, 12.99799156], [92.81363678, 12.99808121], [92.8139267, 12.9981308], [92.8141861, 12.99829865], [92.81442261, 12.9985714], [92.81490326, 12.99855042], [92.81510925, 12.99860001], [92.8154068, 12.99867058], [92.81598663, 12.99864101], [92.81624603, 12.9988327], [92.81639099, 12.99889183], [92.81671143, 12.99894047], [92.81697083, 12.99914265], [92.81777954, 13.00000191], [92.81832886, 13.00028038], [92.8188858, 13.00055981], [92.8188858, 13.00111198], [92.81916809, 13.0013876], [92.81916809, 13.00222015], [92.81944275, 13.00249958], [92.81944275, 13.00333405], [92.81973267, 13.00360107], [92.81972504, 13.00416565], [92.81999969, 13.00444412], [92.81999969, 13.00472164], [92.82020569, 13.00492859], [92.8208313, 13.00556087], [92.82111359, 13.00555611], [92.82138824, 13.00583363], [92.82250214, 13.00583363], [92.82277679, 13.00611019], [92.82305908, 13.00611019], [92.82333374, 13.00638771], [92.82333374, 13.0069437], [92.8236084, 13.00722027], [92.8236084, 13.00889111], [92.82389069, 13.00916576], [92.82389069, 13.00944042], [92.82417297, 13.00972939], [92.82416534, 13.0102787], [92.82472229, 13.01083469], [92.82472229, 13.01111031], [92.82499695, 13.01139069], [92.82499695, 13.01166725], [92.82527924, 13.01194], [92.82506561, 13.01270771], [92.82478333, 13.01298428], [92.82450104, 13.01298428], [92.8236084, 13.01277637], [92.82305908, 13.01222324], [92.82277679, 13.01222324], [92.82250214, 13.01194477], [92.82221985, 13.01194477], [92.82184601, 13.01157284], [92.8216629, 13.01138878], [92.82139587, 13.01167107], [92.82110596, 13.01139069], [92.8208313, 13.01167107], [92.81973267, 13.01167107], [92.81944275, 13.01139069], [92.81861115, 13.01139069], [92.81832886, 13.01111031], [92.8180542, 13.01111031], [92.81777954, 13.01083469], [92.81749725, 13.01083469], [92.8172226, 13.01055431], [92.81667328, 13.01056099], [92.8161087, 13.01000118], [92.8161087, 13.00972939], [92.81582642, 13.00944042], [92.81583405, 13.00888824], [92.81555176, 13.00860977], [92.81555176, 13.00806141], [92.81526947, 13.00778103], [92.81526947, 13.00749969], [92.81500244, 13.00722027], [92.81472015, 13.00722027], [92.81305695, 13.00889111], [92.81276703, 13.00889111], [92.8125, 13.00917053], [92.81083679, 13.00917053], [92.81054688, 13.00889111], [92.80999756, 13.00889111], [92.8097229, 13.00860977], [92.80944824, 13.00860977], [92.80916595, 13.00833225], [92.8088913, 13.00833225], [92.80860901, 13.00805569], [92.80832672, 13.00806141], [92.80742645, 13.0071516], [92.80722046, 13.0069418], [92.80666351, 13.0069437], [92.80638885, 13.00666618], [92.8061142, 13.0069437], [92.80583191, 13.0069418], [92.80500031, 13.00778103], [92.80500031, 13.00916576], [92.80526733, 13.00944042], [92.80526733, 13.01028061], [92.80555725, 13.01055431], [92.80555725, 13.01111031], [92.80472565, 13.01194477], [92.80444336, 13.01194477], [92.8041687, 13.01222324], [92.80361176, 13.01222324], [92.8035202, 13.01212883], [92.8033371, 13.01194477], [92.80305481, 13.01194477], [92.80194092, 13.01083469], [92.80194092, 13.01055431], [92.80110931, 13.00972939], [92.80000305, 13.00972939], [92.79980469, 13.00953102], [92.79972076, 13.00944424], [92.79888916, 13.00944042], [92.79860687, 13.00972939], [92.79833221, 13.00972176], [92.79722595, 13.01083469], [92.79694366, 13.01083469], [92.79666901, 13.01111031], [92.79638672, 13.01111031], [92.79611206, 13.01139069], [92.79389191, 13.01139069], [92.79360962, 13.01111031], [92.79277802, 13.01111031], [92.79250336, 13.01139069], [92.79222107, 13.01139069], [92.79138947, 13.01195145], [92.79111481, 13.01194477], [92.79083252, 13.01222324], [92.79096985, 13.01277637], [92.79068756, 13.01318359], [92.79083252, 13.01333046], [92.79055023, 13.01389122], [92.78943634, 13.0150013], [92.78943634, 13.01528072], [92.78958893, 13.01555538], [92.78944397, 13.0158329], [92.78916931, 13.01611137], [92.78916931, 13.01638889], [92.78888702, 13.01666737], [92.78888702, 13.01694489], [92.78861237, 13.01722145], [92.78861237, 13.01805496], [92.78833008, 13.01833057], [92.78833008, 13.01917171], [92.78943634, 13.02028179], [92.78944397, 13.02055454], [92.78971863, 13.02083111], [92.78971863, 13.02166653], [92.79000092, 13.02194118], [92.79000092, 13.02250195], [92.7902832, 13.02278042], [92.79027557, 13.02416801], [92.79055786, 13.02444553], [92.79055786, 13.0247097], [92.79138947, 13.02556038], [92.79166412, 13.02555561], [92.79194641, 13.02583408], [92.79222107, 13.02583408], [92.79332733, 13.0269413], [92.79333496, 13.02750015], [92.79360962, 13.02777767], [92.79360962, 13.02944183], [92.79416656, 13.02999973], [92.79416656, 13.03028011], [92.79471588, 13.03084087], [92.79472351, 13.03139019], [92.79416656, 13.03193855], [92.79416656, 13.03222179], [92.79360962, 13.03277969], [92.79360962, 13.03306103], [92.79277802, 13.03390026], [92.79277802, 13.03416634], [92.79264069, 13.03444386], [92.79277802, 13.03472233], [92.79277802, 13.03582954], [92.79305267, 13.03610992], [92.79305267, 13.03694439], [92.79332733, 13.03722], [92.79332733, 13.03750134], [92.79360962, 13.03777885], [92.79360962, 13.03833008], [92.79528046, 13.04000092], [92.79528046, 13.0402813], [92.79555511, 13.04055691], [92.79556274, 13.04111099], [92.79528046, 13.04139137], [92.79528046, 13.04166698], [92.79499817, 13.04194546], [92.79499817, 13.04222107], [92.79471588, 13.04250145], [92.79472351, 13.04305458], [92.79444122, 13.04333115], [92.79444122, 13.04556179], [92.79472351, 13.04583263], [92.79471588, 13.04611111], [92.79444122, 13.04639053], [92.79444122, 13.04667187], [92.79332733, 13.04778194], [92.79333496, 13.0480547], [92.79360962, 13.04833317], [92.79499817, 13.04833126], [92.79582977, 13.04916954], [92.79582977, 13.05027962], [92.79555511, 13.05055523], [92.79556274, 13.05110931], [92.79528046, 13.05138969], [92.79528046, 13.05167007], [92.79444122, 13.05249977], [92.79444122, 13.05333424], [92.79333496, 13.05444431], [92.79305267, 13.05444145], [92.79250336, 13.05500031], [92.79250336, 13.05583382], [92.79277802, 13.05611038], [92.79277802, 13.05666637], [92.79305267, 13.05694199], [92.79305267, 13.05860996], [92.79332733, 13.05889034], [92.79333496, 13.05916595], [92.79360962, 13.05943966], [92.79360962, 13.06305695], [92.79528046, 13.06472015], [92.79528046, 13.06527901], [92.79582977, 13.06583214], [92.79582977, 13.06611061], [92.79611206, 13.06639099], [92.79611206, 13.0666666], [92.79638672, 13.06694031], [92.79638672, 13.06750107], [92.79694366, 13.06805515], [92.79666901, 13.0683279], [92.79666901, 13.06916714], [92.79638672, 13.06944275], [92.79638672, 13.07028103], [92.79611206, 13.07055473], [92.79611206, 13.07194519], [92.79638672, 13.0722208], [92.79638672, 13.07250118], [92.79693604, 13.07307053], [92.79693604, 13.07389164], [92.79666901, 13.07416725], [92.79666901, 13.07472134], [92.79611206, 13.07528019], [92.79611206, 13.07555485], [92.79582977, 13.07582188], [92.79582977, 13.07638931], [92.79666901, 13.07722092], [92.79666901, 13.07749939], [92.79694366, 13.07777691], [92.79694366, 13.07861233], [92.79722595, 13.07888126], [92.79722595, 13.08166981], [92.79693604, 13.08195114], [92.79693604, 13.08278179], [92.79666901, 13.08305645], [92.79666901, 13.0833292], [92.79611206, 13.08388996], [92.79611206, 13.08416557], [92.7958374, 13.08472157], [92.79569244, 13.08499146], [92.79582977, 13.08528042], [92.79693604, 13.08638954], [92.79694366, 13.08777809], [92.79666901, 13.0880518], [92.79666901, 13.0886097], [92.79680634, 13.08875084], [92.79666138, 13.08916569], [92.79666901, 13.08944035], [92.79750061, 13.09000015], [92.79777527, 13.09041309], [92.79860687, 13.09082127], [92.79888916, 13.09097958], [92.79972076, 13.09139061], [92.80000305, 13.09138775], [92.80027771, 13.09139061], [92.80055237, 13.09138775], [92.80055237, 13.09111023], [92.80083466, 13.09083462], [92.80083466, 13.09000015], [92.80110931, 13.08971977], [92.80110931, 13.08944416], [92.8013916, 13.08916569], [92.8013916, 13.08889103], [92.80194092, 13.08833027], [92.80194092, 13.08805561], [92.80222321, 13.08777809], [92.80222321, 13.08749962], [92.80194092, 13.08722019], [92.80194092, 13.08666611], [92.80166626, 13.08638954], [92.80166626, 13.08443928], [92.8013916, 13.08416557], [92.8013916, 13.08388996], [92.80082703, 13.0833292], [92.80083466, 13.08305645], [92.80055237, 13.08278179], [92.80055237, 13.08250046], [92.80166626, 13.08139038], [92.80194092, 13.08139038], [92.80194092, 13.08111191], [92.80249786, 13.08055973], [92.80249786, 13.0802803], [92.80278015, 13.08000183], [92.80278015, 13.07944107], [92.80305481, 13.07916546], [92.80303955, 13.07777977], [92.80332947, 13.07749939], [92.80332947, 13.07722092], [92.80500031, 13.07555485], [92.80526733, 13.07555962], [92.80583191, 13.07500076], [92.8069458, 13.07500076], [92.80722046, 13.07528019], [92.8077774, 13.07528019], [92.80805206, 13.07555962], [92.80860901, 13.07555485], [92.8088913, 13.07583332], [92.80944824, 13.07583332], [92.80999756, 13.07527733], [92.81027985, 13.07528019], [92.81054688, 13.07555962], [92.81083679, 13.07555485], [92.81111145, 13.07582188], [92.81111145, 13.07611084], [92.81138611, 13.07638931], [92.81138611, 13.0769434], [92.8116684, 13.07722092], [92.8116684, 13.07749939], [92.81138611, 13.07777977], [92.8112793, 13.07888126], [92.8105545, 13.07944584], [92.80944824, 13.07944584], [92.80916595, 13.0797224], [92.8088913, 13.07972431], [92.80805969, 13.07973099], [92.80750275, 13.0797224], [92.80722046, 13.08000183], [92.80722046, 13.08055973], [92.80832672, 13.08166981], [92.80832672, 13.08195114], [92.8088913, 13.08250046], [92.8088913, 13.0833292], [92.80805206, 13.08417034], [92.8077774, 13.08416557], [92.80750275, 13.08444405], [92.80722046, 13.08444405], [92.8069458, 13.08472157], [92.80638885, 13.08471966], [92.80555725, 13.0855608], [92.80555725, 13.08611012], [92.80527496, 13.08638763], [92.80527496, 13.08805561], [92.80555725, 13.08833027], [92.80555725, 13.0886097], [92.80583191, 13.08889103], [92.80583191, 13.08916569], [92.8061142, 13.08944416], [92.80610657, 13.08971977], [92.80638885, 13.09000015], [92.80638885, 13.09083462], [92.80665588, 13.09111023], [92.80665588, 13.09139061], [92.8069458, 13.09166622], [92.8069458, 13.09222031], [92.80722046, 13.09250069], [92.80722046, 13.09305668], [92.8077774, 13.09361076], [92.8077774, 13.09583282], [92.80750275, 13.0961113], [92.80750275, 13.09722137], [92.8077774, 13.09749889], [92.8077774, 13.09944534], [92.80827332, 13.0999403], [92.8088913, 13.10056019], [92.80945587, 13.10056019], [92.81027985, 13.10139179], [92.81027985, 13.1016674], [92.8105545, 13.10194302], [92.8105545, 13.1022234], [92.8116684, 13.10333347], [92.8125, 13.10333061], [92.81256866, 13.10340595], [92.81276703, 13.10361099], [92.81388855, 13.10361099], [92.81472015, 13.10278034], [92.81472015, 13.10250187], [92.81500244, 13.10222054], [92.81500244, 13.1016674], [92.81526947, 13.10139179], [92.81526947, 13.10111141], [92.8161087, 13.10027695], [92.81639099, 13.10028172], [92.81667328, 13.09998989], [92.81694794, 13.10000134], [92.81749725, 13.09944534], [92.8180542, 13.09944534], [92.81944275, 13.09805489], [92.81944275, 13.09777927], [92.81999969, 13.09722137], [92.81999969, 13.09694481], [92.82026672, 13.0966692], [92.82026672, 13.0961113], [92.82111359, 13.09527683], [92.82138824, 13.09527683], [92.82194519, 13.09583282], [92.82195282, 13.0961113], [92.82221985, 13.09639072], [92.82221985, 13.09694481], [92.82195282, 13.09722137], [92.82195282, 13.09777927], [92.8216629, 13.09805489], [92.8216629, 13.09833336], [92.82139587, 13.09861088], [92.82139587, 13.09889126], [92.82111359, 13.09916687], [92.82111359, 13.09944534], [92.8208313, 13.09972095], [92.8208313, 13.09998989], [92.82027435, 13.10055542], [92.82027435, 13.10083294], [92.81999969, 13.10111141], [92.81999969, 13.10249901], [92.8208313, 13.10333061], [92.8208313, 13.10361099], [92.82110596, 13.10389042], [92.82111359, 13.10416794], [92.82138824, 13.10444641], [92.82139587, 13.10472107], [92.82110596, 13.10499859], [92.82110596, 13.1055603], [92.82055664, 13.10612106], [92.82055664, 13.10778046], [92.8208313, 13.10805607], [92.8208313, 13.10833168], [92.82138824, 13.10888767], [92.82138824, 13.10944366], [92.8216629, 13.10972023], [92.8216629, 13.10999966], [92.82194519, 13.11027813], [92.82195282, 13.11082935], [92.82221985, 13.11110973], [92.82221985, 13.11192989], [92.82277679, 13.11250019], [92.8236084, 13.11250019], [92.82389069, 13.11277962], [92.82416534, 13.11277771], [92.82499695, 13.11361027], [92.82499695, 13.11388969], [92.82527924, 13.11416626], [92.82527924, 13.11444187], [92.82417297, 13.11556053], [92.82332611, 13.11556053], [92.82305908, 13.11528111], [92.82221985, 13.11528111], [92.82195282, 13.11499119], [92.82111359, 13.11499977], [92.8208313, 13.11472225], [92.81999969, 13.11472225], [92.81972504, 13.11499977], [92.81861115, 13.11499977], [92.81843567, 13.11482334], [92.81833649, 13.11472225], [92.8180542, 13.11472225], [92.81788635, 13.11455441], [92.81777954, 13.11444378], [92.81749725, 13.11444378], [92.8172226, 13.11472225], [92.81694794, 13.11472225], [92.81666565, 13.11499977], [92.81639099, 13.11499119], [92.8161087, 13.11528111], [92.8161087, 13.11555576], [92.81583405, 13.11583233], [92.81582642, 13.11610985], [92.81555176, 13.11638832], [92.81555176, 13.11694431], [92.81526947, 13.11721992], [92.81526947, 13.11750031], [92.81500244, 13.11778069], [92.81500244, 13.11805439], [92.81472015, 13.11833191], [92.81472015, 13.11861038], [92.81445313, 13.11889076], [92.8144455, 13.11916733], [92.81416321, 13.11944485], [92.81416321, 13.11972046], [92.81388855, 13.12000084], [92.81388855, 13.12028122], [92.81276703, 13.1213913], [92.8125, 13.1213913], [92.81138611, 13.12250137], [92.81138611, 13.12472057], [92.81111145, 13.12500095], [92.81111145, 13.12528133], [92.80999756, 13.12638855], [92.80999756, 13.12692928], [92.81054688, 13.12750053], [92.81083679, 13.12750053], [92.81111145, 13.12722111], [92.81445313, 13.12722111], [92.81472015, 13.12750053], [92.81555176, 13.12750053], [92.81582642, 13.12778187], [92.81861115, 13.1277771], [92.81944275, 13.12861061], [92.81944275, 13.12889194], [92.81972504, 13.1291666], [92.81972504, 13.12944317], [92.81999969, 13.12972069], [92.81999969, 13.13055515], [92.81973267, 13.13083076], [92.81973267, 13.13138962], [92.81999969, 13.13166809], [92.81999969, 13.13194561], [92.82041931, 13.13236523], [92.8208313, 13.13278198], [92.82111359, 13.13277817], [92.82139587, 13.13306046], [92.82221985, 13.13306046], [92.82277679, 13.13361168], [92.82446289, 13.13361168], [92.82527924, 13.13277817], [92.82527924, 13.1325016], [92.82554626, 13.13221931], [92.82555389, 13.13166809], [92.82583618, 13.13138962], [92.82583618, 13.13110924], [92.82666779, 13.13027668], [92.82749939, 13.13027668], [92.82805634, 13.13083267], [92.82805634, 13.13110924], [92.82861328, 13.13167], [92.82888794, 13.13166809], [92.82944489, 13.13222122], [92.82971954, 13.13222122], [92.83027649, 13.13166809], [92.83026886, 13.12972069], [92.83055878, 13.12944317], [92.83055878, 13.12888908], [92.83110809, 13.12833118], [92.83110809, 13.12805462], [92.83167267, 13.12750053], [92.83167267, 13.12722111], [92.83194733, 13.12694454], [92.83180237, 13.12611294], [92.83139038, 13.12583256], [92.83139038, 13.12555504], [92.83167267, 13.12528133], [92.83249664, 13.12472343], [92.83333588, 13.12472057], [92.83416748, 13.12555504], [92.83416748, 13.12583065], [92.83444214, 13.12611103], [92.83444214, 13.12638855], [92.83486176, 13.12692928], [92.8347168, 13.12708378], [92.83472443, 13.12722111], [92.83472443, 13.12833309], [92.83444214, 13.12861061], [92.83444214, 13.12972069], [92.8347168, 13.13000202], [92.83499908, 13.13000202], [92.83528137, 13.13027954], [92.83611298, 13.13027954], [92.83640289, 13.13000202], [92.83666992, 13.13000202], [92.83721924, 13.12944126], [92.83721924, 13.1291666], [92.83833313, 13.12806034], [92.83860779, 13.12806034], [92.83889008, 13.12778187], [92.83914948, 13.12778187], [92.83943939, 13.12750053], [92.83972168, 13.12750053], [92.83999634, 13.12722111], [92.8408432, 13.12722111], [92.84111023, 13.12750053], [92.84222412, 13.12749863], [92.84306335, 13.12833118], [92.84306335, 13.12889194], [92.84333038, 13.12917042], [92.84333038, 13.13138962], [92.84278107, 13.13194084], [92.84278107, 13.13278198], [92.84194183, 13.13361168], [92.84139252, 13.13361168], [92.84111023, 13.13389015], [92.84055328, 13.13389015], [92.83999634, 13.13444138], [92.83999634, 13.13527966], [92.83972168, 13.13556004], [92.83972168, 13.13638783], [92.84055328, 13.13722038], [92.84055328, 13.13749981], [92.84166718, 13.13861179], [92.84194183, 13.13861179], [92.84221649, 13.13889027], [92.84249878, 13.13889027], [92.84278107, 13.13916588], [92.84388733, 13.13916588], [92.84416962, 13.13889027], [92.84500122, 13.13889027], [92.84527588, 13.13861179], [92.8455658, 13.13861179], [92.84583282, 13.13833046], [92.84666443, 13.13833427], [92.84749603, 13.1391592], [92.84750366, 13.14027786], [92.84666443, 13.14111233], [92.84638977, 13.14111042], [92.84610748, 13.14138985], [92.84555817, 13.14138794], [92.84471893, 13.14221954], [92.84471893, 13.14249992], [92.84416962, 13.14305592], [92.84416962, 13.14332962], [92.84361267, 13.14388847], [92.84361267, 13.14444447], [92.84333038, 13.14472008], [92.84333038, 13.14527893], [92.84278107, 13.14583206], [92.84249878, 13.14583206], [92.84222412, 13.14610958], [92.84194183, 13.14610958], [92.84166718, 13.14583206], [92.84111023, 13.14583206], [92.84083557, 13.14555359], [92.84027863, 13.14556122], [92.83999634, 13.14529037], [92.83860779, 13.14529037], [92.83833313, 13.14556122], [92.83805847, 13.14555359], [92.83777618, 13.14583206], [92.83583069, 13.14583206], [92.83528137, 13.14527893], [92.83499908, 13.14529037], [92.8347168, 13.14500141], [92.83333588, 13.14500141], [92.83333588, 13.14529037], [92.83305359, 13.14555359], [92.83305359, 13.14583206], [92.83277893, 13.14610958], [92.83277893, 13.146945], [92.83304596, 13.14721966], [92.83304596, 13.14778137], [92.83194733, 13.14889145], [92.82943726, 13.14889145], [92.82917023, 13.14861107], [92.82861328, 13.14861107], [92.82833099, 13.14832973], [92.82805634, 13.1483326], [92.82777405, 13.14805698], [92.82749939, 13.14805889], [92.82720947, 13.14778137], [92.82694244, 13.14778137], [92.82666779, 13.14750099], [92.82639313, 13.14750099], [92.82554626, 13.1466713], [92.82527924, 13.1466713], [92.82499695, 13.14639091], [92.82472229, 13.14639091], [92.82446289, 13.14610958], [92.82416534, 13.14610958], [92.82389069, 13.14583206], [92.8236084, 13.14583206], [92.82333374, 13.14555359], [92.82277679, 13.14556122], [92.82250214, 13.14529037], [92.82221985, 13.14529037], [92.822052, 13.14511013], [92.82194519, 13.14500141], [92.8216629, 13.14500141], [92.82111359, 13.14555359], [92.82111359, 13.14583206], [92.8208313, 13.14610958], [92.8208313, 13.14638901], [92.82097626, 13.14721966], [92.82080841, 13.14823532], [92.81708527, 13.15013981], [92.81694794, 13.15000057], [92.81667328, 13.15028095], [92.81639099, 13.15027905], [92.81555176, 13.15111065], [92.8152771, 13.15111065], [92.81416321, 13.15222263], [92.8125, 13.15222263], [92.81222534, 13.15194511], [92.81111145, 13.15194511], [92.81083679, 13.15222263], [92.81054688, 13.15222073], [92.8097229, 13.15305519], [92.8097229, 13.15361118], [92.80999756, 13.15389061], [92.80999756, 13.15416718], [92.81027985, 13.15444469], [92.81027985, 13.15472126], [92.81222534, 13.15666676], [92.81223297, 13.15694141], [92.8125, 13.15723038], [92.8125, 13.15749931], [92.81277466, 13.15777683], [92.81277466, 13.15833282], [92.81305695, 13.15861225], [92.81305695, 13.16083145], [92.81276703, 13.16111183], [92.81276703, 13.1613903], [92.8125, 13.16166782], [92.8125, 13.16222191], [92.81276703, 13.16250038], [92.81276703, 13.16277981], [92.81305695, 13.16305637], [92.81305695, 13.16444397], [92.8133316, 13.16472244], [92.8133316, 13.16582966], [92.81360626, 13.16611004], [92.81361389, 13.16666603], [92.81388855, 13.16694164], [92.81388855, 13.16749954], [92.81582642, 13.16944027], [92.81582642, 13.17000008], [92.8161087, 13.1702776], [92.8161087, 13.17083454], [92.81582642, 13.17111015], [92.81583405, 13.17138767], [92.8152771, 13.17194366], [92.81500244, 13.17193985], [92.81416321, 13.17278099], [92.81416321, 13.1730566], [92.8144455, 13.17333221], [92.8144455, 13.17361069], [92.8152771, 13.17444515], [92.81583405, 13.17444515], [92.81777954, 13.17250061], [92.81804657, 13.17250061], [92.81832886, 13.17250061], [92.81861115, 13.17250061], [92.8188858, 13.17250061], [92.81916809, 13.17250061], [92.8208313, 13.17278099], [92.82110596, 13.17278099], [92.82139587, 13.17278099], [92.8216629, 13.17277908], [92.8221283, 13.17263985], [92.82277679, 13.17361069], [92.82332611, 13.17417145], [92.82389069, 13.17417145], [92.82499695, 13.17306137], [92.82611084, 13.17306137], [92.82694244, 13.17389107], [92.82776642, 13.17389107], [92.82805634, 13.1740303], [92.82826233, 13.17385387], [92.82888794, 13.17333031], [92.82888794, 13.1730566], [92.83000183, 13.17193985]]], [[[93.83969879, 12.32081985], [93.85774994, 12.29312992], [93.8603363, 12.29471016], [93.86160278, 12.29553699], [93.86174011, 12.29574203], [93.86211395, 12.29593372], [93.8626709, 12.29593372], [93.86333466, 12.29527664], [93.86553955, 12.29528046], [93.86585236, 12.29556179], [93.86723328, 12.29556179], [93.86888885, 12.29389191], [93.86915588, 12.29389191], [93.8694458, 12.29361057], [93.86972046, 12.29361057], [93.87000275, 12.29333305], [93.87083435, 12.29277706], [93.87082672, 12.29250145], [93.87361145, 12.28972054], [93.87361145, 12.28944492], [93.87388611, 12.2891674], [93.8741684, 12.28916931], [93.87526703, 12.28805923], [93.87526703, 12.28693962], [93.87555695, 12.28666687], [93.87555695, 12.28611088], [93.87526703, 12.28582954], [93.87527466, 12.28555679], [93.875, 12.28528118], [93.875, 12.2850008], [93.87526703, 12.28472042], [93.87527466, 12.28361034], [93.87611389, 12.28277779], [93.87666321, 12.28278065], [93.87695313, 12.28250027], [93.87750244, 12.28250027], [93.87779236, 12.28222179], [93.8777771, 12.28194427], [93.87805176, 12.2816658], [93.87805176, 12.27917099], [93.87779236, 12.27888966], [93.87779236, 12.27834129], [93.87750244, 12.27806091], [93.87750244, 12.27750015], [93.87722015, 12.27721977], [93.87722015, 12.27694416], [93.8769455, 12.27666569], [93.87695313, 12.27416992], [93.87666321, 12.27388954], [93.87666321, 12.27305984], [93.87638855, 12.27278042], [93.87638855, 12.27083111], [93.8741684, 12.26861095], [93.87361145, 12.26847172], [93.87243652, 12.26777935], [93.8730011, 12.26585102], [93.87594604, 12.25538063], [93.88069916, 12.23664188], [93.87034607, 12.23347378], [93.86810303, 12.23355579], [93.86811829, 12.23378372], [93.86250305, 12.2658329], [93.86250305, 12.26604271], [93.86231232, 12.2659626], [93.86201477, 12.26583958], [93.86174011, 12.26570129], [93.86096954, 12.26562786], [93.86090088, 12.26542091], [93.86062622, 12.26521111], [93.86042023, 12.26487064], [93.85993195, 12.26486206], [93.85971832, 12.2650013], [93.85926056, 12.26517391], [93.85916901, 12.26521111], [93.85888672, 12.2650013], [93.86167908, 12.23377037], [93.85103607, 12.23416042], [93.84053802, 12.23692036], [93.83200836, 12.24124146], [93.83338165, 12.24245071], [93.8520813, 12.26743984], [93.85166168, 12.26834011], [93.85138702, 12.26868725], [93.8511734, 12.26882267], [93.85020447, 12.26944256], [93.84964752, 12.26864338], [93.82668304, 12.2448597], [93.81549072, 12.27081108], [93.81520844, 12.27755928], [93.81478882, 12.28526974], [93.81871033, 12.30035973], [93.82128906, 12.30461502], [93.82415009, 12.30747509], [93.84819031, 12.2856226], [93.8483963, 12.28575039], [93.84902954, 12.28611088], [93.84916687, 12.28611088], [93.84944153, 12.28639126], [93.84972382, 12.28652763], [93.85012054, 12.28682423], [93.85028076, 12.28694534], [93.85056305, 12.28693962], [93.85083008, 12.28729057], [93.82901001, 12.31233025], [93.8311615, 12.31448078], [93.83969879, 12.32081985]]], [[[92.75008392, 12.28769493], [92.75006104, 12.28687572], [92.74983978, 12.28688145], [92.74981689, 12.28604031], [92.74899292, 12.28546143], [92.74897003, 12.2849617], [92.74929047, 12.28494072], [92.74925232, 12.28380203], [92.74898529, 12.28380203], [92.74897003, 12.28324127], [92.74868774, 12.28321648], [92.748703, 12.28216076], [92.74842072, 12.28211117], [92.7484436, 12.28106022], [92.74788666, 12.28106022], [92.7478714, 12.28049946], [92.74755859, 12.28044033], [92.74759674, 12.27938938], [92.74788666, 12.27937317], [92.74786377, 12.27881527], [92.74760437, 12.27883339], [92.74760437, 12.27827454], [92.74726868, 12.2782793], [92.74733734, 12.27716255], [92.74701691, 12.27710056], [92.74701691, 12.27571487], [92.74674225, 12.27522087], [92.74676514, 12.27408409], [92.74641418, 12.27404499], [92.74649811, 12.27188873], [92.74617004, 12.27187061], [92.74621582, 12.2707901], [92.74563599, 12.27021122], [92.74568939, 12.26967144], [92.74588776, 12.26963234], [92.74588776, 12.26889229], [92.74647522, 12.26859283], [92.74647522, 12.26769543], [92.74621582, 12.26769543], [92.7461853, 12.26682663], [92.7461853, 12.26654911], [92.7456665, 12.26634121], [92.74562073, 12.26572132], [92.74532318, 12.26570129], [92.74534607, 12.26493073], [92.74510956, 12.26491928], [92.74510956, 12.26439953], [92.74482727, 12.26436138], [92.74481201, 12.26382065], [92.74430084, 12.26358128], [92.7442627, 12.26134491], [92.7440033, 12.26131058], [92.74401855, 12.25990963], [92.74368286, 12.25988007], [92.74371338, 12.25882912], [92.7434082, 12.258811], [92.74341583, 12.25799274], [92.74314117, 12.25796986], [92.74288177, 12.25773335], [92.74285889, 12.25661373], [92.7425766, 12.25663376], [92.74259186, 12.25575542], [92.74288177, 12.25580025], [92.74285889, 12.25524044], [92.74150085, 12.25384045], [92.74035645, 12.25386143], [92.74034119, 12.25354195], [92.73896027, 12.25349236], [92.73871613, 12.25301456], [92.7381897, 12.25298119], [92.73813629, 12.25271034], [92.73755646, 12.25271034], [92.73757935, 12.25242043], [92.73706818, 12.25244141], [92.736763, 12.25214005], [92.73671722, 12.25157928], [92.73647308, 12.25160027], [92.73647308, 12.250741], [92.73619843, 12.25076103], [92.73618317, 12.24934959], [92.73535156, 12.24877071], [92.73535156, 12.24849129], [92.73478699, 12.24849129], [92.73478699, 12.25516033], [92.73501587, 12.25522137], [92.73512268, 12.25632], [92.73538208, 12.25632], [92.73535156, 12.25794029], [92.73509216, 12.25797653], [92.73509216, 12.25823021], [92.73567963, 12.25855637], [92.73561859, 12.25959969], [92.73703766, 12.2607708], [92.7370224, 12.26131058], [92.73754883, 12.26134968], [92.73754883, 12.26157093], [92.73677826, 12.26158047], [92.736763, 12.26213169], [92.73647308, 12.26213169], [92.73647308, 12.26385021], [92.73671722, 12.26385021], [92.73673248, 12.26463032], [92.73813629, 12.26463032], [92.73896027, 12.26572132], [92.73896027, 12.26766109], [92.73922729, 12.2677412], [92.73925018, 12.26939964], [92.73953247, 12.26941776], [92.73951721, 12.27056694], [92.73950958, 12.27133274], [92.7397995, 12.27130985], [92.7397995, 12.27273178], [92.74008179, 12.27270889], [92.74009705, 12.27408791], [92.73983765, 12.2741003], [92.73983765, 12.27491093], [92.73964691, 12.27497005], [92.73940277, 12.27525043], [92.73945618, 12.27547169], [92.73974609, 12.27553082], [92.74032593, 12.27602482], [92.74034119, 12.27710342], [92.73981476, 12.27736282], [92.73983765, 12.27856159], [92.73953247, 12.27850056], [92.73948669, 12.27962017], [92.73980713, 12.27962017], [92.73986053, 12.28022957], [92.73949432, 12.28021908], [92.73951721, 12.28210354], [92.73976135, 12.28216457], [92.73986053, 12.28268337], [92.74067688, 12.28268337], [92.74063873, 12.28188515], [92.74089813, 12.28189182], [92.74093628, 12.28100967], [92.74064636, 12.28100967], [92.7406311, 12.28065205], [92.74059296, 12.27997112], [92.74085999, 12.27997112], [92.74088287, 12.27885246], [92.74117279, 12.27883053], [92.74125671, 12.27909088], [92.74202728, 12.27911091], [92.74207306, 12.27967167], [92.74228668, 12.27959919], [92.74228668, 12.28016186], [92.7425766, 12.28020096], [92.7425766, 12.28131962], [92.74285126, 12.28127193], [92.74285126, 12.28210354], [92.74368286, 12.28214455], [92.74372864, 12.28246403], [92.74427032, 12.28248215], [92.74427032, 12.28298378], [92.74481201, 12.28324127], [92.74484253, 12.28380203], [92.74534607, 12.28414059], [92.74537659, 12.28464127], [92.74562836, 12.28467941], [92.74562836, 12.28546143], [92.74617767, 12.28572083], [92.74617767, 12.28631973], [92.74648285, 12.28635693], [92.74646759, 12.28738213], [92.74758148, 12.28742123], [92.74845123, 12.28826046], [92.74842834, 12.28854179], [92.74894714, 12.28854179], [92.74897766, 12.28824234], [92.74917603, 12.28820133], [92.74919891, 12.28778076], [92.75008392, 12.28769493]]], [[[92.76673889, 12.27032089], [92.76661682, 12.26988125], [92.76639557, 12.26950455], [92.76618958, 12.26913643], [92.76600647, 12.26877975], [92.76583099, 12.26844025], [92.76567078, 12.26811886], [92.76552582, 12.26776791], [92.76535797, 12.26741886], [92.76519775, 12.26699066], [92.7650528, 12.26655102], [92.76476288, 12.26616955], [92.76416016, 12.26610184], [92.76387787, 12.26610374], [92.76345062, 12.26620007], [92.76301575, 12.26648045], [92.76277161, 12.26691055], [92.76255798, 12.26739025], [92.76248169, 12.26793003], [92.76236725, 12.26845169], [92.76222229, 12.26891041], [92.76209259, 12.26928616], [92.76196289, 12.26955891], [92.76183319, 12.26976013], [92.76165771, 12.26992035], [92.76140594, 12.26998138], [92.76111603, 12.26988125], [92.76081085, 12.26971245], [92.76042938, 12.26947975], [92.75992584, 12.26931095], [92.75938416, 12.26931572], [92.75893402, 12.26964378], [92.75861359, 12.2700634], [92.75834656, 12.27046204], [92.75813293, 12.27088642], [92.75791931, 12.27131367], [92.7575531, 12.27164936], [92.75705719, 12.27194977], [92.75653076, 12.27230072], [92.75608826, 12.27278709], [92.7557373, 12.2733202], [92.75541687, 12.27383137], [92.75502014, 12.27426147], [92.7545929, 12.27468109], [92.7541275, 12.27507305], [92.75379944, 12.27558136], [92.7536087, 12.27612972], [92.75346375, 12.27663803], [92.75330353, 12.27710342], [92.75311279, 12.27751064], [92.75311279, 12.2779398], [92.75328827, 12.27834129], [92.75340271, 12.27875137], [92.75356293, 12.27911091], [92.7536087, 12.27949047], [92.75364685, 12.27987003], [92.75379181, 12.28020954], [92.75389862, 12.2806406], [92.75402069, 12.28111935], [92.75418854, 12.28162098], [92.75442505, 12.28207874], [92.75460052, 12.28251171], [92.75473022, 12.28291512], [92.75491333, 12.28324986], [92.75522614, 12.28353119], [92.75559235, 12.28380203], [92.75598145, 12.2840414], [92.75631714, 12.28431034], [92.75650787, 12.28466797], [92.75671387, 12.28496361], [92.75694275, 12.28523064], [92.75717163, 12.28549671], [92.75740814, 12.28574371], [92.75766754, 12.28599167], [92.75794983, 12.28623104], [92.75820923, 12.28647995], [92.75831604, 12.2868309], [92.75836945, 12.28721142], [92.75856781, 12.28748035], [92.75872803, 12.28777027], [92.75886536, 12.28812122], [92.75893402, 12.28856468], [92.75911713, 12.28902054], [92.75930023, 12.28955173], [92.75961304, 12.29000092], [92.75994873, 12.29045677], [92.7602005, 12.29103088], [92.76045227, 12.29168797], [92.76072693, 12.2923708], [92.7611084, 12.29302502], [92.76164246, 12.29354954], [92.76226807, 12.29389191], [92.76287842, 12.29412174], [92.76346588, 12.29408073], [92.76396179, 12.29382133], [92.76439667, 12.29356289], [92.76474762, 12.29328537], [92.76500702, 12.29292965], [92.76528168, 12.29259014], [92.76550293, 12.29223919], [92.76554871, 12.291852], [92.7654953, 12.29147339], [92.76531982, 12.2911129], [92.76509857, 12.29074383], [92.76496887, 12.29029655], [92.76477051, 12.28990078], [92.76477051, 12.2894907], [92.76494598, 12.28910065], [92.76500702, 12.28867722], [92.76509857, 12.28825092], [92.76528931, 12.28786087], [92.76556396, 12.28751183], [92.76593781, 12.28722286], [92.76634216, 12.28694153], [92.76670837, 12.28666687], [92.76700592, 12.28639126], [92.76721954, 12.28611088], [92.76743317, 12.28587055], [92.76753998, 12.28555202], [92.76773071, 12.28528309], [92.7678299, 12.2848959], [92.768013, 12.28450108], [92.76805115, 12.28401089], [92.768013, 12.28350067], [92.76782227, 12.28302002], [92.76776886, 12.28251171], [92.76768494, 12.28202438], [92.76753235, 12.28158188], [92.76750183, 12.28108978], [92.7674942, 12.28061771], [92.76745605, 12.28014088], [92.76727295, 12.27973366], [92.76721954, 12.27933502], [92.7672348, 12.27896786], [92.76732635, 12.27863026], [92.76748657, 12.27826118], [92.76759338, 12.27782059], [92.76773071, 12.27736092], [92.76777649, 12.27687073], [92.76777649, 12.27641296], [92.76773071, 12.27597523], [92.76754761, 12.27556515], [92.76750183, 12.2751503], [92.76750183, 12.2747097], [92.76750183, 12.27421093], [92.76750183, 12.27364445], [92.76744843, 12.27301025], [92.76724243, 12.27241135], [92.76708984, 12.27181053], [92.76696777, 12.27126408], [92.76690674, 12.27075386], [92.76673889, 12.27032089]]], [[[92.73706055, 12.28518105], [92.73680115, 12.28489971], [92.736763, 12.28185081], [92.73622894, 12.28184605], [92.73622894, 12.28157139], [92.73594666, 12.28157139], [92.73561859, 12.28188038], [92.735672, 12.28295612], [92.73593903, 12.28302479], [92.73592377, 12.28352356], [92.7362442, 12.28354359], [92.73622894, 12.28401089], [92.73620605, 12.28494072], [92.73587799, 12.28492069], [92.73590088, 12.28663921], [92.73538971, 12.28712463], [92.73538971, 12.28851032], [92.73565674, 12.2887907], [92.7361908, 12.28883171], [92.73622894, 12.28993034], [92.73652649, 12.28995132], [92.7365036, 12.29073524], [92.73674774, 12.29075527], [92.736763, 12.29135323], [92.73700714, 12.29137325], [92.73705292, 12.29189301], [92.73761749, 12.29240322], [92.73817444, 12.29240322], [92.73815918, 12.2918539], [92.737854, 12.2918539], [92.73791504, 12.28937912], [92.73757172, 12.289361], [92.73763275, 12.28826046], [92.73728943, 12.28824234], [92.73734283, 12.28629112], [92.73706055, 12.28601265], [92.73706055, 12.28518105]]], [[[92.71141815, 12.2960701], [92.71205139, 12.29598141], [92.71272278, 12.29603195], [92.71333313, 12.29585171], [92.71386719, 12.295681], [92.71434784, 12.29553032], [92.71472931, 12.29533195], [92.71508789, 12.29537964], [92.71544647, 12.29554367], [92.71582031, 12.29570103], [92.71620178, 12.29592037], [92.7166214, 12.29620934], [92.71711731, 12.29658985], [92.7177887, 12.29679966], [92.71837616, 12.29654026], [92.71871185, 12.29603195], [92.71900177, 12.29560757], [92.71930695, 12.29528046], [92.71962738, 12.29500771], [92.71994019, 12.29480076], [92.72029114, 12.29472828], [92.72064972, 12.29470062], [92.72101593, 12.29463005], [92.72132874, 12.29471016], [92.72164154, 12.29496956], [92.72200012, 12.29526138], [92.72236633, 12.29548931], [92.72278595, 12.29552078], [92.72299957, 12.2954073], [92.7231369, 12.29533386], [92.72344208, 12.29513073], [92.72358704, 12.29475975], [92.72360992, 12.29429531], [92.72357178, 12.29380322], [92.72340393, 12.29334545], [92.72348022, 12.29290485], [92.72360229, 12.29246521], [92.72367859, 12.29205036], [92.72385406, 12.29171276], [92.72386169, 12.29137993], [92.72370911, 12.29103088], [92.72357178, 12.29061413], [92.72329712, 12.29023075], [92.72301483, 12.289814], [92.72272491, 12.28942871], [92.72252655, 12.28901196], [92.72249603, 12.28850079], [92.72249603, 12.28796101], [92.72245789, 12.2874012], [92.72225952, 12.28688145], [92.72213745, 12.28632927], [92.72197723, 12.28581047], [92.72190094, 12.28528118], [92.72167969, 12.28486156], [92.72145081, 12.28447247], [92.72114563, 12.2841692], [92.72084808, 12.28389072], [92.72054291, 12.2835989], [92.72024536, 12.28328419], [92.72003937, 12.28288078], [92.72003937, 12.28236103], [92.72026825, 12.28182602], [92.72050476, 12.28124905], [92.72064972, 12.28061962], [92.72080994, 12.28005314], [92.72085571, 12.27950096], [92.72076416, 12.27900219], [92.72058105, 12.27861023], [92.7204361, 12.27823162], [92.72027588, 12.27792168], [92.72012329, 12.27761173], [92.71997833, 12.27721977], [92.71980286, 12.27684116], [92.71968842, 12.27644157], [92.71949005, 12.27611923], [92.71943665, 12.27576065], [92.71943665, 12.27538967], [92.71944427, 12.27502728], [92.71943665, 12.27463055], [92.71942139, 12.27417183], [92.71929169, 12.27366161], [92.71898651, 12.2731514], [92.71863556, 12.27258587], [92.71837616, 12.27190018], [92.71833038, 12.27114105], [92.7183075, 12.27043247], [92.71817017, 12.26984882], [92.71798706, 12.26939964], [92.71779633, 12.26907158], [92.71765137, 12.2687664], [92.71750641, 12.26847172], [92.71743011, 12.26815605], [92.7172699, 12.26788044], [92.71720886, 12.26755238], [92.71708679, 12.26723003], [92.71692657, 12.26691055], [92.7167511, 12.266572], [92.71663666, 12.26615047], [92.71656036, 12.26575089], [92.71669769, 12.26539803], [92.71692657, 12.26515198], [92.71714783, 12.26495075], [92.71739197, 12.26473045], [92.71774292, 12.26451969], [92.71819305, 12.2643404], [92.71858215, 12.26395988], [92.71884155, 12.26345062], [92.71884918, 12.26286983], [92.71864319, 12.26232338], [92.71839905, 12.26178074], [92.71794891, 12.26142979], [92.71740723, 12.26126957], [92.71694183, 12.26134491], [92.71656799, 12.26130676], [92.71627045, 12.26120186], [92.71600342, 12.26107407], [92.71578217, 12.26085758], [92.71553802, 12.26058197], [92.71527863, 12.2602787], [92.71527863, 12.25972271], [92.71611023, 12.2588892], [92.71666718, 12.25889111], [92.71694183, 12.25917053], [92.71722412, 12.25916672], [92.71749878, 12.25944519], [92.71778107, 12.25944519], [92.71805573, 12.25972271], [92.71861267, 12.25972271], [92.71916962, 12.25916672], [92.71916962, 12.25889111], [92.71888733, 12.25861073], [92.71888733, 12.25833035], [92.71861267, 12.25805664], [92.71861267, 12.25778103], [92.71833038, 12.25750065], [92.71833038, 12.2569418], [92.71722412, 12.25583458], [92.71639252, 12.25583458], [92.71607208, 12.25554085], [92.71582031, 12.25533962], [92.71555328, 12.2550602], [92.71527863, 12.25471115], [92.71502686, 12.25432587], [92.71482086, 12.25389957], [92.71459961, 12.25347996], [92.71437836, 12.25306988], [92.7141571, 12.25267124], [92.71396637, 12.25226116], [92.71389771, 12.2518158], [92.71389008, 12.25133133], [92.71383667, 12.25082016], [92.71364594, 12.25029182], [92.71353149, 12.24967194], [92.71333313, 12.24905014], [92.71310425, 12.24845028], [92.7130127, 12.24779129], [92.71277618, 12.24722195], [92.7125473, 12.24667454], [92.71250153, 12.24607086], [92.71246338, 12.245471], [92.71230316, 12.24491119], [92.7122345, 12.24435234], [92.71221924, 12.24377346], [92.71221924, 12.24317646], [92.71221924, 12.24256134], [92.71219635, 12.24192047], [92.71214294, 12.24131012], [92.71209717, 12.24071026], [92.71219635, 12.24009037], [92.71221924, 12.23946095], [92.71221924, 12.23882103], [92.7122345, 12.2381916], [92.71231079, 12.23756981], [92.71246338, 12.23695183], [92.71250153, 12.23631096], [92.71248627, 12.23567295], [92.71239471, 12.23504734], [92.71219635, 12.23446083], [92.71193695, 12.23390007], [92.7117157, 12.2333231], [92.71166992, 12.23263741], [92.71161652, 12.23194027], [92.71138, 12.23129082], [92.71105957, 12.23071194], [92.71092224, 12.23038101], [92.71069336, 12.23032856], [92.71035767, 12.23051071], [92.71002197, 12.23088741], [92.70977783, 12.23129082], [92.70972443, 12.2317009], [92.7097168, 12.23206139], [92.7097168, 12.23239136], [92.70970917, 12.23269939], [92.70962524, 12.23301411], [92.70948029, 12.23335457], [92.70939636, 12.23376083], [92.70921326, 12.23416042], [92.7091217, 12.23462677], [92.7089386, 12.23508072], [92.70889282, 12.2356596], [92.7088089, 12.23630047], [92.70864868, 12.23698425], [92.70855713, 12.23769855], [92.70836639, 12.2383604], [92.70823669, 12.23895073], [92.70807648, 12.23940182], [92.70797729, 12.2397604], [92.70782471, 12.239995], [92.70777893, 12.2402792], [92.70773315, 12.24057961], [92.70755768, 12.24079895], [92.70741272, 12.24106979], [92.7071991, 12.24134064], [92.7069397, 12.24160576], [92.70662689, 12.24190044], [92.7062912, 12.24223042], [92.70590973, 12.24254704], [92.70555878, 12.24293232], [92.70523071, 12.24336338], [92.70498657, 12.24388504], [92.70476532, 12.24443245], [92.70471954, 12.24506092], [92.70471954, 12.24571133], [92.7046814, 12.24637794], [92.70452881, 12.24702072], [92.70445251, 12.24772072], [92.70446014, 12.24841976], [92.70453644, 12.24909973], [92.70466614, 12.24973965], [92.70461273, 12.25039196], [92.70451355, 12.25104618], [92.70462799, 12.2517004], [92.70446014, 12.25231075], [92.70435333, 12.25291538], [92.70437622, 12.25353336], [92.70439148, 12.25413418], [92.70423889, 12.25467396], [92.70417023, 12.25517082], [92.70411682, 12.25562859], [92.7039566, 12.25597954], [92.70387268, 12.25633144], [92.70372009, 12.25667095], [92.70349884, 12.25705242], [92.70337677, 12.25758934], [92.70337677, 12.25820923], [92.70350647, 12.25878143], [92.70359039, 12.25928974], [92.70353699, 12.25976086], [92.70336151, 12.26019001], [92.70323181, 12.2606411], [92.70302582, 12.26103115], [92.70276642, 12.26140022], [92.70249939, 12.26179028], [92.70223999, 12.2622118], [92.70205688, 12.26268101], [92.70191956, 12.26320076], [92.70175934, 12.26374054], [92.70172119, 12.26432037], [92.70184326, 12.26490974], [92.70188141, 12.26549816], [92.7016983, 12.26607227], [92.70155334, 12.26669025], [92.70147705, 12.26736927], [92.70172119, 12.26811028], [92.7020874, 12.2688303], [92.7022934, 12.26960278], [92.70265961, 12.26999855], [92.70301819, 12.27033043], [92.70332336, 12.2706604], [92.70355225, 12.27104092], [92.70361328, 12.27147198], [92.7035675, 12.27186775], [92.70339203, 12.2721796], [92.70323181, 12.27248096], [92.70304871, 12.27273655], [92.70285034, 12.2729826], [92.70262146, 12.27323055], [92.70243073, 12.27358913], [92.70220947, 12.27398109], [92.7019577, 12.27442074], [92.70181274, 12.27492046], [92.70189667, 12.27548981], [92.70240021, 12.27606201], [92.70264435, 12.27666569], [92.70263672, 12.27733994], [92.70284271, 12.27771187], [92.70307922, 12.27799034], [92.70333099, 12.27826977], [92.70353699, 12.27858925], [92.70362091, 12.2789793], [92.70370483, 12.27935123], [92.70384979, 12.27969265], [92.70388031, 12.28007126], [92.70388031, 12.2805109], [92.70385742, 12.28096199], [92.7036972, 12.28139973], [92.7035141, 12.28181744], [92.70355225, 12.2822504], [92.70404053, 12.28278828], [92.70436096, 12.2833004], [92.70436859, 12.28381062], [92.70413971, 12.28429031], [92.7038269, 12.28477955], [92.70365143, 12.28531075], [92.7035675, 12.28585052], [92.70342255, 12.28634834], [92.70331573, 12.28688335], [92.70314789, 12.28739071], [92.70297241, 12.28786469], [92.7026825, 12.28836918], [92.70244598, 12.28905106], [92.70246887, 12.28971195], [92.70279694, 12.29023075], [92.70327759, 12.29066944], [92.70365143, 12.29110241], [92.7039032, 12.29158974], [92.70375824, 12.29230118], [92.70387268, 12.29273605], [92.70405579, 12.2930603], [92.70423126, 12.29339695], [92.70440674, 12.29375935], [92.70443726, 12.29424], [92.70443726, 12.29475975], [92.70443726, 12.29529953], [92.70444489, 12.29583645], [92.70444489, 12.29637432], [92.70443726, 12.29691982], [92.70446014, 12.29750156], [92.70461273, 12.29809189], [92.70527649, 12.29854107], [92.70571899, 12.29864979], [92.7061615, 12.2987709], [92.70668793, 12.29878044], [92.70694733, 12.29858017], [92.70715332, 12.2983036], [92.70737457, 12.29798889], [92.70754242, 12.29765034], [92.70774078, 12.29740143], [92.70792389, 12.29721165], [92.70811462, 12.29703236], [92.70838165, 12.29688168], [92.70869446, 12.29669476], [92.70909119, 12.29658127], [92.70947266, 12.29642963], [92.70992279, 12.29638004], [92.71037292, 12.2963438], [92.71084595, 12.29615211], [92.71141815, 12.2960701]]], [[[92.77657318, 12.3102808], [92.77684784, 12.31011868], [92.77700806, 12.31014442], [92.77870178, 12.31010342], [92.77946472, 12.31011391], [92.77972412, 12.31011391], [92.77999878, 12.31006241], [92.78050995, 12.3101387], [92.78083038, 12.3102808], [92.78111267, 12.3102808], [92.78164673, 12.31075001], [92.78231812, 12.31093025], [92.7829361, 12.31096172], [92.78341675, 12.31096172], [92.78395081, 12.31103992], [92.78456879, 12.31097126], [92.78513336, 12.310812], [92.78559875, 12.31054974], [92.78598785, 12.31029034], [92.78633118, 12.31005955], [92.78665924, 12.30987072], [92.78696442, 12.30968571], [92.7872467, 12.3094511], [92.7875824, 12.30925655], [92.78801727, 12.30912971], [92.78846741, 12.30891991], [92.78897858, 12.30878067], [92.78944397, 12.30858135], [92.78978729, 12.30825043], [92.79013062, 12.30792618], [92.7904129, 12.30762959], [92.79057312, 12.30729103], [92.79074097, 12.3070097], [92.79081726, 12.30671597], [92.79086304, 12.30641079], [92.79094696, 12.30613041], [92.79109955, 12.30586243], [92.79122162, 12.30558777], [92.79138184, 12.30535126], [92.79155731, 12.30513], [92.79176331, 12.30491066], [92.79200745, 12.30473995], [92.79231262, 12.3046217], [92.7926178, 12.3044796], [92.79299164, 12.30445099], [92.793396, 12.30443001], [92.79380798, 12.30436039], [92.79421234, 12.30421066], [92.79463959, 12.30416107], [92.79502869, 12.30408192], [92.7953949, 12.30392742], [92.79573822, 12.30389023], [92.79608154, 12.303895], [92.79644012, 12.30394936], [92.79679871, 12.30416965], [92.79721069, 12.30443001], [92.79767609, 12.30472183], [92.79819489, 12.3049984], [92.79869843, 12.30528259], [92.79915619, 12.30558109], [92.79956055, 12.30589962], [92.79982758, 12.30632019], [92.80014038, 12.30666161], [92.80045319, 12.30696011], [92.8007431, 12.30726814], [92.80095673, 12.30763531], [92.8011322, 12.30805397], [92.80136871, 12.30845547], [92.80153656, 12.30891323], [92.80169678, 12.30942154], [92.80194092, 12.30992126], [92.80223083, 12.31044006], [92.80258942, 12.31093502], [92.80314636, 12.31131077], [92.80380249, 12.31156445], [92.80449677, 12.31173515], [92.80516052, 12.31190109], [92.80580139, 12.31195068], [92.80638885, 12.31198978], [92.80684662, 12.31217003], [92.80729675, 12.31227016], [92.80768585, 12.31245136], [92.80812836, 12.31254196], [92.80854797, 12.31274033], [92.80901337, 12.31282043], [92.80947876, 12.31283092], [92.80995941, 12.31276035], [92.81045532, 12.31261539], [92.81096649, 12.31246185], [92.81144714, 12.31221962], [92.81195068, 12.31199932], [92.81252289, 12.31194019], [92.81303406, 12.31189442], [92.81345367, 12.31169415], [92.81386566, 12.3115406], [92.81425476, 12.31137466], [92.8146286, 12.31123066], [92.8150177, 12.3113308], [92.81539917, 12.31119919], [92.81581116, 12.31087303], [92.81622314, 12.31058407], [92.81661987, 12.31031513], [92.81703949, 12.31004143], [92.81748962, 12.30976963], [92.81803131, 12.30952168], [92.81861115, 12.30922985], [92.8192215, 12.30890179], [92.81987, 12.30859184], [92.82047272, 12.30821991], [92.82095337, 12.30777836], [92.82142639, 12.30731964], [92.82196808, 12.30690956], [92.8225174, 12.30649662], [92.82306671, 12.3060894], [92.82361603, 12.30568123], [92.82416534, 12.30527115], [92.82468414, 12.30483055], [92.82512665, 12.30432129], [92.82552338, 12.3038063], [92.8258667, 12.30331135], [92.8262558, 12.30293274], [92.82672119, 12.30270958], [92.82715607, 12.30248165], [92.82753754, 12.30219364], [92.82792664, 12.30193043], [92.82827759, 12.30164146], [92.82859802, 12.30133724], [92.82891846, 12.30104637], [92.8292923, 12.3008337], [92.82964325, 12.3006258], [92.82995605, 12.30037117], [92.83032227, 12.30027962], [92.8307724, 12.30027771], [92.83130646, 12.30031013], [92.83188629, 12.30048275], [92.8325119, 12.30054188], [92.83307648, 12.30048275], [92.83357239, 12.30031872], [92.83399963, 12.30027771], [92.83434296, 12.30027103], [92.83463287, 12.30027485], [92.8348999, 12.30027962], [92.83516693, 12.30035114], [92.83542633, 12.30054188], [92.83573914, 12.30076122], [92.83600616, 12.30103016], [92.83621979, 12.30135059], [92.83638763, 12.30167866], [92.83653259, 12.30202579], [92.83674622, 12.30232239], [92.83693695, 12.30264091], [92.83716583, 12.30298996], [92.8374939, 12.30326557], [92.8380127, 12.30337048], [92.83854675, 12.30357075], [92.83912659, 12.30360985], [92.83970642, 12.30360985], [92.840271, 12.30365753], [92.84081268, 12.30383968], [92.841362, 12.30389023], [92.84192657, 12.30389023], [92.84244537, 12.30388832], [92.84290314, 12.30389023], [92.84327698, 12.3038969], [92.84355164, 12.30396271], [92.84444427, 12.30444431], [92.84610748, 12.30444431], [92.84638977, 12.30416584], [92.84750366, 12.30444431], [92.84777832, 12.30416584], [92.84805298, 12.30416965], [92.84860992, 12.30360985], [92.84860992, 12.30333424], [92.84889221, 12.30305576], [92.84889221, 12.30278015], [92.84944153, 12.30221939], [92.85028076, 12.30221939], [92.85056305, 12.30251122], [92.85111237, 12.30249977], [92.85148621, 12.30274105], [92.85201263, 12.30282974], [92.85248566, 12.30305767], [92.85299683, 12.30332947], [92.85353851, 12.30362129], [92.8540802, 12.30393791], [92.85456848, 12.30429077], [92.85504913, 12.30460072], [92.85555267, 12.30482006], [92.8560791, 12.30500889], [92.85662842, 12.30521202], [92.85723114, 12.30534363], [92.85787201, 12.30543137], [92.85845184, 12.30517292], [92.85887146, 12.30475426], [92.85922241, 12.30440521], [92.85957336, 12.30416965], [92.86000061, 12.30389023], [92.86165619, 12.30389023], [92.86194611, 12.30360985], [92.86277771, 12.30360985], [92.86305237, 12.30333424], [92.86333466, 12.30333424], [92.86387634, 12.30431175], [92.8640213, 12.30470371], [92.86502838, 12.30539227], [92.8653183, 12.30548096], [92.86582184, 12.30555153], [92.86637878, 12.30561066], [92.86676788, 12.30498886], [92.86670685, 12.3043499], [92.8666687, 12.30389023], [92.86637878, 12.30360985], [92.86638641, 12.30333424], [92.8658371, 12.30277824], [92.86544037, 12.30231094], [92.86575317, 12.3011694], [92.86723328, 12.30111027], [92.86777496, 12.30111217], [92.86842346, 12.30097103], [92.86894989, 12.30087852], [92.8694458, 12.30083084], [92.86972046, 12.3008337], [92.87000275, 12.30111217], [92.87082672, 12.30111027], [92.87100983, 12.30112076], [92.87130737, 12.30112076], [92.87166595, 12.30111027], [92.87194824, 12.30138779], [92.87242889, 12.30159283], [92.87298584, 12.30154037], [92.8732605, 12.30123043], [92.87336731, 12.30097961], [92.87346649, 12.30067158], [92.87345123, 12.30027962], [92.87328339, 12.29996967], [92.87290192, 12.29970074], [92.87254333, 12.29954243], [92.8720932, 12.29934978], [92.87178802, 12.29903984], [92.87162018, 12.29875088], [92.87151337, 12.2983017], [92.87155914, 12.29798031], [92.87168884, 12.2975111], [92.87187195, 12.29718018], [92.87210846, 12.29695034], [92.87229156, 12.2967062], [92.8724823, 12.29629135], [92.872612, 12.29585838], [92.87262726, 12.29558945], [92.87245178, 12.29523182], [92.87223816, 12.29496002], [92.87207794, 12.29469395], [92.87193298, 12.29442024], [92.87176514, 12.29416275], [92.87158203, 12.29388714], [92.87133026, 12.29356956], [92.87110901, 12.29333305], [92.8702774, 12.29333305], [92.87000275, 12.29305458], [92.86972046, 12.2930603], [92.86902618, 12.29236221], [92.86888885, 12.29222107], [92.86888885, 12.29138947], [92.86915588, 12.29111099], [92.86915588, 12.29083061], [92.86972046, 12.29027653], [92.8702774, 12.29057121], [92.87055206, 12.290555], [92.87194824, 12.29194546], [92.8730545, 12.29083347], [92.8730545, 12.29027653], [92.87304688, 12.2899189], [92.87309265, 12.28944016], [92.87322235, 12.28905106], [92.87332916, 12.28871059], [92.87342072, 12.28841019], [92.87358093, 12.28818035], [92.87374115, 12.28794289], [92.87397766, 12.28776073], [92.87421417, 12.28758526], [92.87446594, 12.28743935], [92.87472534, 12.28725719], [92.87503815, 12.28722], [92.87536621, 12.28726768], [92.87567139, 12.28743458], [92.87600708, 12.28756046], [92.8763504, 12.28777027], [92.8767395, 12.28794956], [92.87715912, 12.28803921], [92.87755585, 12.28805161], [92.87789154, 12.28805161], [92.87820435, 12.28805542], [92.87851715, 12.28807068], [92.87886047, 12.28817081], [92.87918091, 12.28831673], [92.87947083, 12.28838062], [92.87971497, 12.28827286], [92.88002014, 12.28777027], [92.88043976, 12.28743172], [92.88056946, 12.28768063], [92.8805542, 12.28805542], [92.88054657, 12.28861141], [92.88083649, 12.28888893], [92.88083649, 12.28944016], [92.8813858, 12.29000092], [92.88194275, 12.29000092], [92.88249969, 12.28944016], [92.88249969, 12.2891674], [92.88276672, 12.28889084], [92.8833313, 12.28889084], [92.88360596, 12.28861141], [92.88388824, 12.28861141], [92.8841629, 12.28833294], [92.88471985, 12.28833294], [92.88555908, 12.28750134], [92.88582611, 12.28750992], [92.88667297, 12.28667068], [92.88667297, 12.28611088], [92.88694763, 12.28583336], [92.88694763, 12.28527641], [92.8861084, 12.28444004], [92.8861084, 12.28416634], [92.88582611, 12.28389072], [92.88582611, 12.28361034], [92.88555908, 12.28333473], [92.88555908, 12.28277779], [92.88527679, 12.28250027], [92.88527679, 12.28222179], [92.88445282, 12.28138065], [92.88388824, 12.28138065], [92.88360596, 12.28167057], [92.88314819, 12.28166199], [92.88269806, 12.28162098], [92.88237762, 12.28142929], [92.88215637, 12.28120136], [92.88208771, 12.28086567], [92.88183594, 12.28048134], [92.8813324, 12.28020287], [92.88085175, 12.27988625], [92.88047028, 12.27953053], [92.88011169, 12.27923203], [92.87999725, 12.27888966], [92.8797226, 12.27861023], [92.8797226, 12.27777767], [92.87999725, 12.27750015], [92.87999725, 12.27693939], [92.8805542, 12.27639008], [92.88054657, 12.2761097], [92.88168335, 12.27499962], [92.88168335, 12.27471924], [92.88194275, 12.27444363], [92.88194275, 12.27416801], [92.88223267, 12.27388954], [92.88220215, 12.27016068], [92.88221741, 12.2696209], [92.88223267, 12.26906013], [92.88222504, 12.26851559], [92.88223267, 12.26797104], [92.88222504, 12.26741886], [92.8822403, 12.26684666], [92.88234711, 12.26627064], [92.88246918, 12.26571655], [92.88249969, 12.265172], [92.88253021, 12.26465034], [92.88266754, 12.26418972], [92.88289642, 12.26377964], [92.88314056, 12.26344013], [92.88343048, 12.26323032], [92.88363647, 12.26306152], [92.88401031, 12.2631712], [92.88417816, 12.26335812], [92.8843689, 12.26364136], [92.88455963, 12.26401043], [92.88477325, 12.26439953], [92.88499451, 12.26479626], [92.88520813, 12.26521969], [92.88533783, 12.26568985], [92.88554382, 12.26605415], [92.8857193, 12.26642323], [92.88589478, 12.26682663], [92.88623047, 12.26718235], [92.88671112, 12.26744366], [92.88732147, 12.26745415], [92.88757324, 12.26735592], [92.88790131, 12.26722813], [92.88848877, 12.26694107], [92.88905334, 12.26653099], [92.88931274, 12.26594162], [92.88909149, 12.26540947], [92.8886261, 12.26498127], [92.88820648, 12.26459122], [92.88777161, 12.26444054], [92.88741302, 12.26433086], [92.88719177, 12.26414204], [92.88700867, 12.26393032], [92.88686371, 12.26366138], [92.88671112, 12.26338482], [92.88661957, 12.26306152], [92.88643646, 12.26277161], [92.88645172, 12.26247597], [92.88664246, 12.26216125], [92.88682556, 12.26177597], [92.88703156, 12.26134968], [92.88739777, 12.26103115], [92.88772583, 12.26061153], [92.88799286, 12.26015091], [92.88802338, 12.25963593], [92.88787079, 12.25918007], [92.88764954, 12.25879955], [92.88730621, 12.25857162], [92.88697815, 12.25834179], [92.88661194, 12.25816154], [92.88617706, 12.25806999], [92.88577271, 12.25801086], [92.88536072, 12.25783062], [92.88492584, 12.25773144], [92.88453674, 12.25750065], [92.88417053, 12.25723171], [92.88381958, 12.2569313], [92.88353729, 12.25658226], [92.88333893, 12.25620079], [92.88316345, 12.2558136], [92.88300323, 12.25542355], [92.88275146, 12.25509644], [92.8824234, 12.25479126], [92.88201141, 12.25450134], [92.88158417, 12.25419807], [92.88114166, 12.25393105], [92.88067627, 12.25370979], [92.8802948, 12.25343037], [92.87996674, 12.2531004], [92.87963867, 12.25279045], [92.87930298, 12.25247955], [92.87895966, 12.25213146], [92.8786087, 12.25177956], [92.87825012, 12.25144005], [92.87783051, 12.25119019], [92.87734985, 12.25105095], [92.87691498, 12.25087261], [92.8764267, 12.25078869], [92.87599182, 12.25054932], [92.87555695, 12.25032997], [92.87502289, 12.25030994], [92.8744278, 12.25039196], [92.87426758, 12.25034904], [92.87378693, 12.25022125], [92.87336731, 12.25034428], [92.87297821, 12.25051022], [92.87251282, 12.25058079], [92.87203217, 12.25073242], [92.87165833, 12.25081635], [92.87158203, 12.25081635], [92.8694458, 12.2508297], [92.86915588, 12.25111198], [92.86860657, 12.25111198], [92.86833191, 12.2514019], [92.86782074, 12.25141144], [92.86741638, 12.25156116], [92.86694336, 12.25169086], [92.86649323, 12.25171185], [92.86607361, 12.25162697], [92.86569977, 12.25146961], [92.86515045, 12.25143433], [92.8646698, 12.25134468], [92.86424255, 12.25115967], [92.86382294, 12.25089073], [92.8638916, 12.25111198], [92.86250305, 12.24971962], [92.86222076, 12.24972153], [92.8611145, 12.2486124], [92.8611145, 12.24833393], [92.86027527, 12.24750042], [92.86000061, 12.24750042], [92.85943604, 12.24694061], [92.85944366, 12.24666786], [92.85916901, 12.24639034], [92.85916901, 12.24611187], [92.85888672, 12.24583054], [92.85916901, 12.24555588], [92.85916901, 12.24500179], [92.85916901, 12.24470997], [92.85921478, 12.24425697], [92.85941315, 12.24383926], [92.85958099, 12.24341106], [92.85984039, 12.24310112], [92.86016846, 12.24289131], [92.86049652, 12.24272919], [92.8608017, 12.2425518], [92.86106873, 12.2423811], [92.86123657, 12.24163055], [92.86134338, 12.24090195], [92.86141205, 12.24033642], [92.86147308, 12.23979187], [92.86158752, 12.23926258], [92.86173248, 12.23876572], [92.86192322, 12.2383194], [92.86209869, 12.23789978], [92.86226654, 12.23747158], [92.86248016, 12.23706055], [92.86266327, 12.2366209], [92.86281586, 12.23617172], [92.86308289, 12.23581886], [92.86338043, 12.23553181], [92.8637085, 12.23528099], [92.86406708, 12.23508072], [92.86451721, 12.23495102], [92.86502075, 12.23475933], [92.86556244, 12.23456955], [92.86582947, 12.23429203], [92.86603546, 12.23397064], [92.86625671, 12.23363304], [92.86650848, 12.23331356], [92.866745, 12.23298836], [92.86701965, 12.23271275], [92.86730194, 12.23246193], [92.86752319, 12.23214054], [92.86769104, 12.23182201], [92.86776733, 12.23145676], [92.86781311, 12.23106861], [92.86791229, 12.23069286], [92.86803436, 12.23027897], [92.86814117, 12.2298317], [92.86834717, 12.22942162], [92.86862946, 12.22902966], [92.86895752, 12.22869015], [92.86933899, 12.2284317], [92.8697052, 12.22817039], [92.87006378, 12.22790146], [92.87049103, 12.22768879], [92.87094116, 12.22739124], [92.87140656, 12.22706032], [92.87188721, 12.22667122], [92.87220001, 12.22613144], [92.87245178, 12.2255106], [92.87251282, 12.22479725], [92.87256622, 12.22413158], [92.87264252, 12.22354126], [92.87256622, 12.22301006], [92.87272644, 12.22252274], [92.87281799, 12.2220602], [92.87298584, 12.22170925], [92.87309265, 12.22135067], [92.87323761, 12.22104645], [92.87332153, 12.22072029], [92.87333679, 12.2203598], [92.87333679, 12.21997929], [92.87333679, 12.21955109], [92.87332153, 12.21907425], [92.87325287, 12.21855736], [92.87313843, 12.21807194], [92.87328339, 12.21764088], [92.87336731, 12.21720123], [92.87354279, 12.2168293], [92.87360382, 12.21645069], [92.87361145, 12.21607304], [92.87365723, 12.21568775], [92.8738327, 12.21529102], [92.87387848, 12.21480083], [92.87388611, 12.21426487], [92.87388611, 12.21371174], [92.87388611, 12.21317959], [92.87388611, 12.21269035], [92.87387848, 12.21225071], [92.87380219, 12.2118969], [92.8736496, 12.21166039], [92.87366486, 12.21142292], [92.87381744, 12.21112537], [92.87377167, 12.21084881], [92.87364197, 12.21049976], [92.8736496, 12.21014023], [92.87379456, 12.20979595], [92.87386322, 12.2094202], [92.87375641, 12.20900059], [92.87362671, 12.20852184], [92.87361145, 12.20798016], [92.87361145, 12.20740128], [92.8736496, 12.20681], [92.87381744, 12.20625019], [92.873909, 12.20572758], [92.87403107, 12.20531082], [92.87419891, 12.2049799], [92.87440491, 12.20474339], [92.87454987, 12.20449162], [92.87474823, 12.20430279], [92.87500763, 12.20415974], [92.87532806, 12.20401192], [92.87571716, 12.20390034], [92.87619019, 12.20376968], [92.87665558, 12.20351696], [92.87709808, 12.20317078], [92.87747955, 12.20278072], [92.87776184, 12.20234966], [92.87800598, 12.20197868], [92.87827301, 12.20172119], [92.87853241, 12.20149136], [92.87884521, 12.2013998], [92.87921143, 12.20139122], [92.87963104, 12.20141125], [92.88015747, 12.20151138], [92.88080597, 12.20148182], [92.88131714, 12.20092964], [92.88160706, 12.20038128], [92.88168335, 12.19988155], [92.88168335, 12.1994009], [92.88172913, 12.19895363], [92.88195801, 12.19850731], [92.88185883, 12.19798088], [92.88163757, 12.19742012], [92.88132477, 12.1968956], [92.88098907, 12.19633961], [92.8807373, 12.19573116], [92.88050842, 12.19513702], [92.88020325, 12.19467163], [92.87982941, 12.19437122], [92.87947845, 12.19413376], [92.87911987, 12.19392872], [92.87866211, 12.19384193], [92.8782196, 12.19368935], [92.87769318, 12.19356155], [92.87718964, 12.19336128], [92.87666321, 12.19320202], [92.87612915, 12.19308758], [92.87561035, 12.19306946], [92.87510681, 12.19312191], [92.87465668, 12.19332027], [92.87422943, 12.19357109], [92.87382507, 12.19384003], [92.87342834, 12.19408989], [92.8731308, 12.19437122], [92.87285614, 12.19463062], [92.87254333, 12.19485188], [92.8722229, 12.19515038], [92.87184906, 12.19549179], [92.87140656, 12.19575691], [92.87097931, 12.19596386], [92.87055969, 12.1961441], [92.87014771, 12.19639206], [92.86967468, 12.19661331], [92.86914063, 12.19662476], [92.8686142, 12.19653606], [92.86815643, 12.1967802], [92.86772156, 12.19692135], [92.86727142, 12.19695091], [92.86680603, 12.19698048], [92.86637115, 12.19710827], [92.86589813, 12.19720364], [92.86540222, 12.19722366], [92.86490631, 12.19722366], [92.86443329, 12.19721699], [92.86396027, 12.19717026], [92.86348724, 12.19703102], [92.86299896, 12.19726753], [92.86260986, 12.19775295], [92.86255646, 12.19842052], [92.86277771, 12.19908619], [92.86296082, 12.19968987], [92.86280823, 12.20015812], [92.8626709, 12.20038128], [92.86245728, 12.20044041], [92.86221313, 12.20042419], [92.86200714, 12.20051098], [92.86177826, 12.20064068], [92.86152649, 12.20084572], [92.86117554, 12.20105267], [92.86068726, 12.20115089], [92.86019135, 12.20134735], [92.85966492, 12.20144081], [92.85926056, 12.20164108], [92.85886383, 12.20179844], [92.85850525, 12.20188999], [92.85812378, 12.20190144], [92.85773468, 12.20177269], [92.85728455, 12.20168686], [92.85679626, 12.20175076], [92.85634613, 12.20200062], [92.85591125, 12.20234966], [92.85553741, 12.20278072], [92.8551712, 12.20312691], [92.85489655, 12.20339203], [92.85469818, 12.20356941], [92.85441589, 12.20362186], [92.85411072, 12.20370197], [92.85378265, 12.20384979], [92.85343933, 12.20382023], [92.85311127, 12.20361042], [92.85279083, 12.20335102], [92.85246277, 12.20313358], [92.85214996, 12.20296955], [92.85189056, 12.20278072], [92.85164642, 12.20258045], [92.85137939, 12.2023983], [92.85108948, 12.20221138], [92.85085297, 12.20197201], [92.8506012, 12.20170021], [92.85034943, 12.20139503], [92.85006714, 12.20108128], [92.84979248, 12.20073891], [92.84955597, 12.20037174], [92.84921265, 12.20016193], [92.84896851, 12.19994068], [92.84881592, 12.19974709], [92.84660339, 12.19768047], [92.84651947, 12.19742012], [92.84650421, 12.19717407], [92.84659576, 12.19693661], [92.84677124, 12.19673729], [92.84703064, 12.19656086], [92.84729004, 12.19628143], [92.84764862, 12.19592953], [92.8478775, 12.19540119], [92.84798431, 12.19476318], [92.84803772, 12.19408989], [92.8480072, 12.19342041], [92.84780884, 12.19283009], [92.84749603, 12.19235134], [92.84716797, 12.19192123], [92.8469162, 12.19143963], [92.84671021, 12.19094753], [92.84670258, 12.19042969], [92.84687805, 12.18999004], [92.84707642, 12.18962097], [92.84738922, 12.18940544], [92.84768677, 12.18921089], [92.84801483, 12.18916798], [92.84835052, 12.1891613], [92.84870911, 12.18917656], [92.84910583, 12.18925381], [92.84952545, 12.18943214], [92.85002136, 12.18959141], [92.85053253, 12.18975067], [92.85098267, 12.18999863], [92.85137939, 12.19028187], [92.85183716, 12.19061947], [92.85235596, 12.191082], [92.85299683, 12.19148064], [92.85359955, 12.19137096], [92.85404205, 12.1911211], [92.85437775, 12.19083118], [92.85462952, 12.19052124], [92.85481262, 12.19019127], [92.8549881, 12.18985558], [92.85511017, 12.18946171], [92.85523987, 12.18900108], [92.8552475, 12.1884203], [92.85514069, 12.18780041], [92.85501862, 12.18720055], [92.85505676, 12.18666744], [92.85518646, 12.18622971], [92.85508728, 12.18590355], [92.85499573, 12.18558502], [92.85488892, 12.18527889], [92.85472107, 12.18500137], [92.85450745, 12.18471909], [92.85421753, 12.18445015], [92.85383606, 12.18420982], [92.85340118, 12.18413067], [92.85302734, 12.18401718], [92.85256195, 12.1841507], [92.85217285, 12.18395519], [92.85237885, 12.18364143], [92.85238647, 12.18323326], [92.85237122, 12.18286324], [92.85260773, 12.18268967], [92.8529129, 12.18258095], [92.85302734, 12.18237114], [92.85305786, 12.18207264], [92.85303497, 12.18168545], [92.85293579, 12.18127918], [92.8527832, 12.18091011], [92.85264587, 12.18056202], [92.85249329, 12.18022633], [92.85231781, 12.17986202], [92.8521347, 12.17945385], [92.85192108, 12.17902279], [92.85166168, 12.17860413], [92.85138702, 12.17818928], [92.85111237, 12.17778111], [92.85111237, 12.17722034], [92.85083008, 12.17694473], [92.85083008, 12.17666626], [92.85221863, 12.17528057], [92.85221863, 12.17472172], [92.85305786, 12.17388821], [92.85305786, 12.17360973], [92.85388947, 12.17278099], [92.85388947, 12.17249966], [92.85415649, 12.17222023], [92.85444641, 12.17222214], [92.85500336, 12.17166615], [92.85500336, 12.17138958], [92.85527802, 12.17111015], [92.85388947, 12.1697216], [92.85361481, 12.17000008], [92.85333252, 12.1697216], [92.85305786, 12.1697216], [92.85194397, 12.16861153], [92.85194397, 12.16833401], [92.85055542, 12.16694355], [92.85056305, 12.16666985], [92.85028076, 12.16639042], [92.85028076, 12.16528034], [92.85002136, 12.16500187], [92.8499527, 12.16465092], [92.84976196, 12.16431141], [92.84960175, 12.16396046], [92.84940338, 12.16364956], [92.84916687, 12.16335201], [92.84899902, 12.16304016], [92.84884644, 12.16273022], [92.84870911, 12.1624403], [92.84864807, 12.16215706], [92.84871674, 12.16187], [92.84887695, 12.16156864], [92.84908295, 12.16124439], [92.84940338, 12.16095924], [92.84970856, 12.16063976], [92.84998322, 12.16030025], [92.85018921, 12.15993118], [92.85034943, 12.15954781], [92.85051727, 12.15919018], [92.85064697, 12.15882111], [92.85079193, 12.15848064], [92.85083008, 12.15810108], [92.85079193, 12.15769863], [92.85058594, 12.15732098], [92.85015869, 12.15707302], [92.84963226, 12.15696144], [92.84909821, 12.15688133], [92.84860229, 12.15667629], [92.84809875, 12.15650082], [92.84758759, 12.15654373], [92.84712219, 12.15677357], [92.84680176, 12.1570816], [92.84657288, 12.15747166], [92.84648132, 12.15796185], [92.84654236, 12.15846062], [92.84662628, 12.15899181], [92.84661102, 12.15946102], [92.84646606, 12.15980053], [92.84632111, 12.1600647], [92.84606934, 12.16031075], [92.8456955, 12.16055775], [92.84521484, 12.16074371], [92.84465027, 12.16082382], [92.84406281, 12.16083336], [92.84346771, 12.16078758], [92.84285736, 12.1606102], [92.84212494, 12.16042519], [92.84168243, 12.16044998], [92.84123993, 12.16047764], [92.84047699, 12.1607008], [92.8398819, 12.16107464], [92.8394928, 12.16158485], [92.8392334, 12.16206169], [92.83918762, 12.1624403], [92.83922577, 12.16267014], [92.8394928, 12.16289139], [92.83950806, 12.16311932], [92.8394165, 12.16349125], [92.83917236, 12.16394043], [92.83888245, 12.16445732], [92.83859253, 12.16501999], [92.83824921, 12.16553116], [92.83789825, 12.16595173], [92.8375473, 12.16627121], [92.83724976, 12.16649532], [92.83699036, 12.16664124], [92.83686066, 12.16687107], [92.83670044, 12.16703033], [92.83650208, 12.1671896], [92.8361969, 12.16729736], [92.83583832, 12.1674633], [92.83538055, 12.1675024], [92.83521271, 12.16749954], [92.83486938, 12.16749668], [92.83435822, 12.16744137], [92.83389282, 12.16721916], [92.83347321, 12.16699791], [92.83296967, 12.16695118], [92.83245087, 12.16695118], [92.83196259, 12.16689968], [92.83149719, 12.16672039], [92.83104706, 12.16660023], [92.83072662, 12.16630077], [92.83045197, 12.16605854], [92.83023071, 12.1657877], [92.82998657, 12.16549015], [92.82978058, 12.16506577], [92.82946014, 12.16470814], [92.82894135, 12.1644001], [92.82784271, 12.16441631], [92.82778931, 12.16467094], [92.82736206, 12.16473961], [92.82697296, 12.16477203], [92.82663727, 12.16500187], [92.82637024, 12.16528893], [92.8261261, 12.16555119], [92.82595825, 12.16582012], [92.82579803, 12.16602707], [92.82563019, 12.16619205], [92.82552338, 12.16640377], [92.82540131, 12.16666985], [92.82485199, 12.16684055], [92.82463074, 12.16672707], [92.82452393, 12.16667461], [92.82402039, 12.16656494], [92.82348633, 12.16625118], [92.82299805, 12.16584969], [92.82258606, 12.16545296], [92.82234192, 12.16499996], [92.82216644, 12.16456032], [92.82196045, 12.16416836], [92.82177734, 12.16372108], [92.82160187, 12.1632309], [92.82142639, 12.16268158], [92.82128906, 12.16212082], [92.82083893, 12.16176319], [92.8205719, 12.16121578], [92.82025909, 12.16109085], [92.81997681, 12.16110039], [92.81977844, 12.1612711], [92.81939697, 12.16088963], [92.8192215, 12.16065121], [92.81905365, 12.16029453], [92.8188858, 12.15970516], [92.81871796, 12.15900135], [92.81864929, 12.1583147], [92.81877899, 12.15764713], [92.81906891, 12.15703201], [92.81937408, 12.15648174], [92.81971741, 12.15602875], [92.82006836, 12.1556406], [92.82047272, 12.15536118], [92.82086182, 12.15512943], [92.82128906, 12.1549511], [92.82170868, 12.15474987], [92.82219696, 12.15463161], [92.82270813, 12.15448093], [92.82315063, 12.15422153], [92.82356262, 12.15418053], [92.82395935, 12.15425968], [92.82433319, 12.154459], [92.8247757, 12.15467453], [92.82535553, 12.15465164], [92.82589722, 12.15430355], [92.82610321, 12.15375233], [92.82587433, 12.15326214], [92.82559967, 12.15282726], [92.82528687, 12.15245056], [92.82498932, 12.15208054], [92.82466888, 12.15175819], [92.82427979, 12.15152073], [92.82386017, 12.15134144], [92.82348633, 12.15113831], [92.82311249, 12.15100956], [92.82277679, 12.15086174], [92.82244873, 12.15075016], [92.82218933, 12.15056133], [92.82192993, 12.15036964], [92.8216629, 12.15018082], [92.82138062, 12.14998531], [92.82115173, 12.14970016], [92.82102203, 12.14927101], [92.82080078, 12.14893246], [92.82050323, 12.14869022], [92.82026672, 12.14832973], [92.81999207, 12.14797401], [92.81970978, 12.14760685], [92.81951141, 12.14724064], [92.81938171, 12.14680099], [92.81918335, 12.14633083], [92.81900024, 12.14579964], [92.81886292, 12.14523888], [92.81865692, 12.14472198], [92.81855774, 12.14415932], [92.81832886, 12.1437397], [92.81804657, 12.14337063], [92.81778717, 12.14304924], [92.81754303, 12.14275074], [92.81735229, 12.14247894], [92.81721497, 12.14220619], [92.8170929, 12.14195061], [92.8170166, 12.14169121], [92.81717682, 12.14137554], [92.81720734, 12.14098167], [92.81717682, 12.14050961], [92.81703186, 12.14001083], [92.81682587, 12.13952065], [92.81654358, 12.13915157], [92.81628418, 12.13878727], [92.81598663, 12.13843155], [92.81571198, 12.13807201], [92.8152771, 12.13777828], [92.81472015, 12.13583088], [92.81486511, 12.13459396], [92.81513977, 12.13404179], [92.81520081, 12.13318062], [92.81503296, 12.13279057], [92.81484985, 12.13239193], [92.81446838, 12.13217545], [92.81413269, 12.13192463], [92.81387329, 12.13165092], [92.81362915, 12.13142109], [92.81336975, 12.13126755], [92.8131485, 12.13108444], [92.81296539, 12.13086033], [92.81276703, 12.13064384], [92.81255341, 12.13040924], [92.81236267, 12.13009167], [92.81196594, 12.12985134], [92.81147766, 12.12957954], [92.81086731, 12.12951088], [92.81027985, 12.12978172], [92.80992126, 12.13026142], [92.80960846, 12.13072586], [92.80919647, 12.1310606], [92.80874634, 12.13138008], [92.80825043, 12.13167191], [92.807724, 12.13197708], [92.80724335, 12.13236046], [92.80680084, 12.13274765], [92.80636597, 12.13305092], [92.80595398, 12.13327885], [92.8055191, 12.13335419], [92.80509949, 12.13331509], [92.80471039, 12.13316154], [92.80435181, 12.13294125], [92.80394745, 12.13278389], [92.80351257, 12.13264465], [92.80310822, 12.13236046], [92.80274963, 12.13191986], [92.80245972, 12.13137054], [92.80226135, 12.13079166], [92.80222321, 12.1302309], [92.80227661, 12.12969971], [92.80246735, 12.12921047], [92.80258179, 12.12871075], [92.802742, 12.12829018], [92.8028183, 12.1278429], [92.80300903, 12.12743282], [92.80305481, 12.12696075], [92.80310059, 12.12644958], [92.80329132, 12.12596035], [92.80348969, 12.12545395], [92.80393982, 12.12514687], [92.80459595, 12.12489986], [92.805336, 12.12475014], [92.80605316, 12.12468243], [92.806633, 12.12446117], [92.80712891, 12.12427139], [92.80755615, 12.12415695], [92.80789948, 12.12403202], [92.80815125, 12.12387276], [92.8097229, 12.12083435], [92.80999756, 12.12055588], [92.8116684, 12.11750031], [92.81194305, 12.11556053], [92.8116684, 12.11528015], [92.8116684, 12.11472034], [92.81151581, 12.1141634], [92.81141663, 12.11359119], [92.81143188, 12.11303997], [92.8115921, 12.11257267], [92.81175995, 12.11215115], [92.81195831, 12.11182976], [92.81218719, 12.11158085], [92.81240082, 12.1113596], [92.81257629, 12.11114979], [92.81276703, 12.11098194], [92.8129425, 12.11077023], [92.81302643, 12.11045074], [92.81305695, 12.11000156], [92.81302643, 12.10951614], [92.81291199, 12.10901928], [92.81277466, 12.10888958], [92.81276703, 12.10750198], [92.8125, 12.10722065], [92.8125, 12.10694313], [92.8105545, 12.10499859], [92.8097229, 12.10500145], [92.80945587, 12.10472107], [92.80916595, 12.10472107], [92.80860901, 12.10528183], [92.80832672, 12.10528183], [92.80805206, 12.1055603], [92.80750275, 12.10555458], [92.80722046, 12.10583305], [92.8069458, 12.10583115], [92.80635834, 12.10589695], [92.80588531, 12.10610199], [92.80541229, 12.10628414], [92.8049469, 12.10645103], [92.80451202, 12.10665131], [92.80401611, 12.10681057], [92.80349731, 12.10696125], [92.80297089, 12.10715961], [92.80242157, 12.10733509], [92.80197144, 12.10764122], [92.80155182, 12.10800076], [92.80104065, 12.10826969], [92.80045319, 12.10843754], [92.79982758, 12.10857964], [92.79918671, 12.1086092], [92.79859161, 12.10856056], [92.79815674, 12.1083107], [92.79780579, 12.10797977], [92.79746246, 12.1076107], [92.79707336, 12.10725117], [92.79659271, 12.10694313], [92.7960968, 12.10665417], [92.79563904, 12.10638714], [92.79524231, 12.10615921], [92.79482269, 12.10607338], [92.79450226, 12.10589218], [92.79421234, 12.10565758], [92.7939682, 12.10531139], [92.79360962, 12.10500145], [92.79319763, 12.10472107], [92.79277802, 12.10446072], [92.79233551, 12.1042881], [92.79189301, 12.10414886], [92.79144287, 12.10397339], [92.79096222, 12.10385323], [92.79053497, 12.1036272], [92.7901001, 12.10343075], [92.78966522, 12.10326481], [92.78927612, 12.10305309], [92.78894043, 12.10283566], [92.78865051, 12.10266972], [92.78843689, 12.10249043], [92.7882843, 12.10230064], [92.7881012, 12.10210037], [92.78796387, 12.101861], [92.78787231, 12.10163975], [92.78800201, 12.10140038], [92.78808594, 12.10111809], [92.78827667, 12.10088062], [92.78852844, 12.10066891], [92.78887939, 12.10052109], [92.78918457, 12.10027885], [92.78946686, 12.10000992], [92.78974915, 12.0997324], [92.78999329, 12.09942436], [92.79020691, 12.09907055], [92.79036713, 12.09863091], [92.79057312, 12.09819126], [92.79083252, 12.09778595], [92.79112244, 12.09743023], [92.79147339, 12.09716129], [92.7918396, 12.09698105], [92.7922821, 12.09694004], [92.79271698, 12.09694481], [92.79316711, 12.09692574], [92.79358673, 12.09683132], [92.79392242, 12.09665966], [92.79418945, 12.09642029], [92.79441833, 12.09613514], [92.79456329, 12.09571171], [92.79464722, 12.09521008], [92.79469299, 12.09463978], [92.79457855, 12.09407139], [92.79441071, 12.09358978], [92.79425049, 12.09317493], [92.79437256, 12.09280968], [92.79443359, 12.09249115], [92.79444122, 12.09219933], [92.79440308, 12.09194183], [92.79425049, 12.09171867], [92.79416656, 12.09143066], [92.79412079, 12.09107113], [92.79395294, 12.09068203], [92.79381561, 12.09023857], [92.79353333, 12.08994102], [92.79332733, 12.08956909], [92.79308319, 12.08924961], [92.79268646, 12.0890789], [92.79236603, 12.08872128], [92.79210663, 12.08824062], [92.79177094, 12.08788967], [92.79162598, 12.08749962], [92.79142761, 12.08719158], [92.79138947, 12.08687115], [92.79138947, 12.08654022], [92.79144287, 12.08620071], [92.79161072, 12.08584976], [92.79173279, 12.08543873], [92.79195404, 12.08505917], [92.79222107, 12.08460999], [92.79250336, 12.08407688], [92.79277802, 12.08347034], [92.79298401, 12.08282471], [92.79294586, 12.08213902], [92.79280853, 12.08153057], [92.79271698, 12.08105373], [92.79247284, 12.08078289], [92.79206085, 12.08061695], [92.79144287, 12.08088112], [92.79100037, 12.0813303], [92.7905426, 12.08166313], [92.79004669, 12.08189487], [92.78952026, 12.08191395], [92.7890625, 12.08177662], [92.78872681, 12.08163071], [92.78851318, 12.08143044], [92.78830719, 12.08123016], [92.78810883, 12.08100033], [92.78798676, 12.08070087], [92.78778076, 12.08047962], [92.78755188, 12.08027267], [92.78726196, 12.08006763], [92.78687286, 12.07991028], [92.78642273, 12.07972813], [92.78595734, 12.07956791], [92.78549957, 12.07946396], [92.78502655, 12.07944298], [92.78453827, 12.07944107], [92.78404236, 12.07949066], [92.78356934, 12.07968044], [92.78305817, 12.07977104], [92.78263855, 12.07995605], [92.78224945, 12.07997227], [92.78191376, 12.07984638], [92.78160095, 12.07969189], [92.78134918, 12.07945728], [92.78111267, 12.07919025], [92.78089142, 12.07890511], [92.7808075, 12.07853603], [92.78067017, 12.07815075], [92.78053284, 12.07771778], [92.78031158, 12.07724094], [92.78005219, 12.07674026], [92.77971649, 12.07627964], [92.77935028, 12.0758419], [92.77901459, 12.07544804], [92.77870941, 12.0751009], [92.77835846, 12.07485104], [92.77805328, 12.07469559], [92.77776337, 12.07444954], [92.7773819, 12.07420063], [92.77693176, 12.07400131], [92.77639008, 12.07389069], [92.77583313, 12.07332993], [92.77471924, 12.07333279], [92.77416992, 12.07277679], [92.77416992, 12.07250118], [92.77388763, 12.0722208], [92.77388763, 12.07194519], [92.77361298, 12.07166672], [92.77361298, 12.07139111], [92.77305603, 12.07083035], [92.77305603, 12.07055664], [92.77278137, 12.07028103], [92.77278137, 12.0694418], [92.77222443, 12.06888771], [92.77166748, 12.06889057], [92.77139282, 12.06917095], [92.77028656, 12.06917095], [92.77009583, 12.06898594], [92.76999664, 12.06889057], [92.76972198, 12.06889057], [92.76944733, 12.06861019], [92.76860809, 12.06861019], [92.76833344, 12.06833458], [92.76805878, 12.06833458], [92.76777649, 12.0680542], [92.76750183, 12.06806087], [92.76750183, 12.06779003], [92.76692963, 12.06721973], [92.76694489, 12.06694412], [92.76638794, 12.06638813], [92.76638794, 12.06610966], [92.76583099, 12.06555557], [92.76583099, 12.06528091], [92.76587677, 12.06515121], [92.76595306, 12.06470203], [92.76593781, 12.0646286], [92.76583099, 12.06416607], [92.76499939, 12.0633297], [92.76467896, 12.06332016], [92.76403046, 12.06368065], [92.76345825, 12.06393147], [92.76293945, 12.06430054], [92.76252747, 12.06479073], [92.76226807, 12.06536674], [92.762146, 12.06597137], [92.76195526, 12.06648445], [92.76176453, 12.06697369], [92.76158905, 12.06746387], [92.7613678, 12.06791973], [92.76110077, 12.06834793], [92.76080322, 12.06874943], [92.76045227, 12.06911182], [92.76005554, 12.06941032], [92.759758, 12.06983185], [92.75940704, 12.0702486], [92.75905609, 12.07067299], [92.75874329, 12.07115173], [92.75849152, 12.07169914], [92.75830078, 12.07226181], [92.75804901, 12.07274723], [92.75776672, 12.07316017], [92.75745392, 12.07349682], [92.75712585, 12.07374096], [92.75688171, 12.0740509], [92.7566452, 12.0743084], [92.7562561, 12.0743494], [92.75591278, 12.07448769], [92.75553131, 12.07450199], [92.75513458, 12.07439709], [92.754776, 12.07417107], [92.75447083, 12.0739727], [92.75415802, 12.07411003], [92.75385284, 12.07417107], [92.75354767, 12.07422161], [92.75325775, 12.07436085], [92.7529068, 12.07443142], [92.75251007, 12.07449055], [92.75214386, 12.074687], [92.75177765, 12.07479382], [92.75147247, 12.07491398], [92.75125122, 12.07487297], [92.7511673, 12.07487106], [92.75080872, 12.07485962], [92.75045013, 12.07482147], [92.75006104, 12.07471848], [92.74962616, 12.07460022], [92.74928284, 12.07461071], [92.74894714, 12.07449055], [92.74855804, 12.07444954], [92.74812317, 12.07445908], [92.74768829, 12.07454967], [92.74726868, 12.07472992], [92.74685669, 12.0749464], [92.74640656, 12.07511044], [92.7459259, 12.0752697], [92.74544525, 12.07539845], [92.74497223, 12.07554054], [92.74447632, 12.07566929], [92.74398804, 12.07588291], [92.74352264, 12.07621098], [92.74304199, 12.07662201], [92.74258423, 12.07701588], [92.74223328, 12.07741928], [92.74194336, 12.07778645], [92.74167633, 12.07810116], [92.74143219, 12.07841969], [92.7412262, 12.07878017], [92.74108124, 12.0792017], [92.74088287, 12.0795908], [92.74069977, 12.08002186], [92.74053192, 12.08047962], [92.74028778, 12.0809269], [92.7400589, 12.08141232], [92.73986053, 12.08193016], [92.73969269, 12.08249855], [92.73950958, 12.08302784], [92.73944855, 12.08357143], [92.73940277, 12.08410168], [92.73928833, 12.08463955], [92.7392807, 12.08525944], [92.73935699, 12.08586597], [92.73942566, 12.08654308], [92.73938751, 12.08726978], [92.73924255, 12.08806133], [92.73933411, 12.08879662], [92.73940277, 12.08941174], [92.73944092, 12.09004974], [92.73943329, 12.09072018], [92.73935699, 12.09141064], [92.73928833, 12.09212875], [92.73928833, 12.09288311], [92.73919678, 12.09350109], [92.73916626, 12.09412956], [92.73916626, 12.0947504], [92.73923492, 12.09529686], [92.73940277, 12.09573174], [92.73944092, 12.09612179], [92.73944855, 12.0965004], [92.73944092, 12.09692192], [92.73944092, 12.09739113], [92.73944092, 12.09789467], [92.73944855, 12.09841919], [92.73947906, 12.09895039], [92.73958588, 12.09941101], [92.73973083, 12.09987068], [92.73988342, 12.10029888], [92.74001312, 12.10072994], [92.74015045, 12.10114002], [92.74028015, 12.10157108], [92.74032593, 12.10222054], [92.74054718, 12.10279274], [92.74080658, 12.10332203], [92.74102783, 12.10380936], [92.7412262, 12.10420132], [92.74137878, 12.10463047], [92.74150085, 12.10510826], [92.74164581, 12.10566044], [92.74182129, 12.10625935], [92.7420578, 12.10674], [92.7423172, 12.10712147], [92.74254608, 12.10751057], [92.74294281, 12.10781097], [92.74308777, 12.10829926], [92.74331665, 12.10875034], [92.74353027, 12.1092062], [92.74371338, 12.10969162], [92.74391937, 12.11015415], [92.74420166, 12.11060143], [92.74445343, 12.11110497], [92.74472046, 12.11160183], [92.74495697, 12.11212063], [92.74504089, 12.11268044], [92.74511719, 12.11316967], [92.74530029, 12.11357784], [92.74545288, 12.1139307], [92.7455368, 12.11427498], [92.74558258, 12.11460972], [92.74572754, 12.11491966], [92.74585724, 12.11530113], [92.74604797, 12.11572933], [92.74613953, 12.11625957], [92.74624634, 12.11678028], [92.74640656, 12.11721134], [92.74652863, 12.1175909], [92.74665833, 12.11793518], [92.74677277, 12.11833382], [92.74685669, 12.11882019], [92.74692535, 12.11927795], [92.74694061, 12.11974525], [92.74694061, 12.12020969], [92.74694824, 12.12067032], [92.74697876, 12.12111855], [92.74710846, 12.121562], [92.74720001, 12.12203121], [92.7472229, 12.12253475], [92.7472229, 12.12304115], [92.7472229, 12.12351513], [92.74726105, 12.12392044], [92.74740601, 12.12422752], [92.74754333, 12.12455177], [92.74775696, 12.12485313], [92.74797821, 12.12520123], [92.74819183, 12.12558174], [92.74838257, 12.12600136], [92.74861145, 12.12637043], [92.74884796, 12.12673092], [92.74904633, 12.12712002], [92.74919891, 12.12755108], [92.74938202, 12.12794113], [92.7494812, 12.12835979], [92.74964142, 12.12870884], [92.74973297, 12.12911224], [92.74983215, 12.1295414], [92.74997711, 12.12999439], [92.75005341, 12.13051224], [92.75012207, 12.13103962], [92.75017548, 12.13157558], [92.75032806, 12.13204098], [92.75051117, 12.13250065], [92.7506485, 12.13302135], [92.75083923, 12.13351059], [92.75106812, 12.13406944], [92.75118256, 12.13525009], [92.7513504, 12.13552094], [92.7515564, 12.13585186], [92.75187683, 12.13644886], [92.75226593, 12.13717079], [92.75266266, 12.13782978], [92.75300598, 12.13836956], [92.75330353, 12.13875961], [92.7535553, 12.13915157], [92.75382996, 12.13954353], [92.75409698, 12.14012146], [92.75441742, 12.14114189], [92.7543869, 12.14182091], [92.75439453, 12.14233398], [92.75432587, 12.14295101], [92.75431061, 12.14365959], [92.75431061, 12.14533138], [92.75435638, 12.1460743], [92.75453949, 12.1466713], [92.75483704, 12.14711094], [92.75531769, 12.14777184], [92.75559235, 12.14838886], [92.75567627, 12.14870071], [92.75582123, 12.14904118], [92.75598907, 12.14929581], [92.75614166, 12.14950371], [92.75653839, 12.14981365], [92.75691223, 12.15008259], [92.75757599, 12.15074062], [92.75760651, 12.15123558], [92.75760651, 12.15183067], [92.75771332, 12.15240955], [92.75795746, 12.15291786], [92.75804901, 12.15343475], [92.75808716, 12.15397072], [92.75823975, 12.15449047], [92.7583847, 12.15502834], [92.75860596, 12.15552139], [92.75884247, 12.15603065], [92.75897217, 12.15660954], [92.75913239, 12.15718174], [92.75920868, 12.15779114], [92.7594223, 12.15835953], [92.75958252, 12.15892124], [92.75966644, 12.1595211], [92.75972748, 12.16010857], [92.75978851, 12.16066933], [92.75995636, 12.16117954], [92.76006317, 12.16168118], [92.76023102, 12.16209602], [92.76027679, 12.16255188], [92.76029968, 12.16299152], [92.76036835, 12.16337872], [92.76043701, 12.16372967], [92.76055145, 12.16401958], [92.76065826, 12.16431808], [92.76077271, 12.16462994], [92.76100922, 12.16491127], [92.76109314, 12.16530037], [92.76111603, 12.16583061], [92.76113892, 12.16645145], [92.76127625, 12.16707993], [92.76146698, 12.16770935], [92.76169586, 12.16827011], [92.76194, 12.16880131], [92.762146, 12.16931152], [92.7623291, 12.16980171], [92.76246643, 12.17022133], [92.76274872, 12.17045116], [92.76299286, 12.17069054], [92.76313782, 12.17103481], [92.76331329, 12.17141056], [92.76341248, 12.17190075], [92.7641449, 12.17302895], [92.76425171, 12.17407322], [92.76431274, 12.17440319], [92.76439667, 12.17469311], [92.76454163, 12.17502117], [92.76468658, 12.17521], [92.76493835, 12.17543602], [92.76538849, 12.1765213], [92.76538849, 12.1769762], [92.76525879, 12.17846012], [92.76509094, 12.1789999], [92.76500702, 12.17947197], [92.76509094, 12.18010139], [92.76512909, 12.18082809], [92.76508331, 12.18161392], [92.76522827, 12.18225002], [92.76539612, 12.18250084], [92.76586151, 12.18274879], [92.76634216, 12.18320084], [92.76689148, 12.18384075], [92.76714325, 12.18428135], [92.76728058, 12.18478012], [92.76743317, 12.18524075], [92.76750183, 12.18570995], [92.76758575, 12.18616772], [92.76773834, 12.18659019], [92.76773834, 12.18705654], [92.76763916, 12.18756104], [92.76779938, 12.18808937], [92.76797485, 12.188591], [92.76791382, 12.18911266], [92.76802063, 12.1895504], [92.76802063, 12.18994045], [92.76789093, 12.19032097], [92.76771545, 12.19074917], [92.76744843, 12.19116211], [92.76715088, 12.19160175], [92.76687622, 12.19207096], [92.76689911, 12.19279957], [92.76690674, 12.19352055], [92.76716614, 12.19399929], [92.76735687, 12.19448853], [92.76761627, 12.19497013], [92.76794434, 12.19542789], [92.76819611, 12.19589329], [92.7685318, 12.19629192], [92.76870728, 12.19675922], [92.76889038, 12.19718075], [92.76906586, 12.19755936], [92.76920319, 12.19794178], [92.7693634, 12.19828415], [92.76943207, 12.19869041], [92.76944733, 12.19916153], [92.76948547, 12.19965553], [92.76966095, 12.20016193], [92.76967621, 12.20069122], [92.76950836, 12.20120144], [92.76935577, 12.20173931], [92.76914978, 12.20222187], [92.76889038, 12.20263004], [92.76862335, 12.20298958], [92.76835632, 12.20330048], [92.76811218, 12.20356941], [92.76792145, 12.20388603], [92.76770782, 12.20423317], [92.76744843, 12.20462036], [92.76706696, 12.20503044], [92.76669312, 12.20549965], [92.76638794, 12.20603848], [92.76609039, 12.20654106], [92.76580811, 12.2069788], [92.76555634, 12.20738029], [92.76532745, 12.20776844], [92.76506042, 12.20814991], [92.76480103, 12.20856953], [92.7647171, 12.20917606], [92.76462555, 12.20978165], [92.76442719, 12.21030045], [92.76422119, 12.2107811], [92.76419067, 12.21128178], [92.76429749, 12.21180153], [92.76443481, 12.21232986], [92.76456451, 12.21284294], [92.76469421, 12.21331024], [92.76482391, 12.21373177], [92.76493073, 12.21412182], [92.76502991, 12.21452332], [92.76511383, 12.21502209], [92.76525879, 12.2155304], [92.76538849, 12.21606064], [92.76557922, 12.21641922], [92.76574707, 12.21671963], [92.76586914, 12.21702099], [92.76602173, 12.21728992], [92.76609802, 12.21760368], [92.76611328, 12.21797371], [92.76612091, 12.21838093], [92.7661972, 12.21881008], [92.76635742, 12.21923161], [92.76644897, 12.21975136], [92.76663208, 12.22028923], [92.76674652, 12.2208786], [92.76695251, 12.22140598], [92.76721954, 12.22188473], [92.76744843, 12.22236061], [92.76754761, 12.22293091], [92.76774597, 12.22344971], [92.7678833, 12.22396088], [92.76806641, 12.22439194], [92.76828766, 12.22478104], [92.76833344, 12.22524929], [92.76831055, 12.22574139], [92.76822662, 12.22624874], [92.76824951, 12.22676182], [92.76831818, 12.22723961], [92.76841736, 12.22772121], [92.76857758, 12.22817039], [92.76876831, 12.22862244], [92.76899719, 12.2290802], [92.76935577, 12.22943974], [92.76974487, 12.22977543], [92.77005768, 12.23021221], [92.7703476, 12.23065472], [92.77049255, 12.23112202], [92.7703476, 12.23157978], [92.77011108, 12.23200226], [92.76992798, 12.23243237], [92.76970673, 12.23278999], [92.76943207, 12.23309994], [92.76933289, 12.2335062], [92.76937103, 12.23399067], [92.76938629, 12.23444939], [92.76930237, 12.23487091], [92.76941681, 12.23526764], [92.76951599, 12.23570347], [92.7696991, 12.23609543], [92.7698288, 12.23649406], [92.76986694, 12.23685169], [92.76972198, 12.23722839], [92.76953888, 12.23758125], [92.76938629, 12.23782921], [92.76915741, 12.23805046], [92.76882172, 12.23822594], [92.76851654, 12.23829365], [92.76818848, 12.23818493], [92.76786041, 12.23800945], [92.76756287, 12.23776817], [92.76724243, 12.23750114], [92.76690674, 12.23721886], [92.76661682, 12.23701096], [92.76629639, 12.23713398], [92.7660141, 12.23744202], [92.76582336, 12.23730278], [92.76573944, 12.23670292], [92.7654953, 12.23621559], [92.76502991, 12.23601055], [92.76460266, 12.23577118], [92.76429749, 12.23541069], [92.76407623, 12.23501015], [92.76390076, 12.23463154], [92.7637558, 12.23423958], [92.76360321, 12.23381424], [92.76343536, 12.23339367], [92.76329803, 12.23298645], [92.76304626, 12.23271275], [92.76275635, 12.23250103], [92.76246643, 12.23233032], [92.76212311, 12.23224068], [92.76171875, 12.2322197], [92.7612915, 12.23224068], [92.76087189, 12.23233032], [92.76048279, 12.23252106], [92.76010132, 12.23278141], [92.75972748, 12.23309803], [92.75952911, 12.23350143], [92.75949097, 12.23390007], [92.75977325, 12.23427773], [92.76035309, 12.23464775], [92.76072693, 12.23505116], [92.76098633, 12.23542023], [92.76117706, 12.23575115], [92.7612381, 12.23604012], [92.76111603, 12.23626137], [92.76084137, 12.23639107], [92.76048279, 12.23626137], [92.76007843, 12.23591042], [92.75969696, 12.23546124], [92.75934601, 12.23505974], [92.7590332, 12.23475933], [92.75874329, 12.23457718], [92.75842285, 12.23443985], [92.75805664, 12.23429203], [92.75777435, 12.23417759], [92.7574234, 12.23406029], [92.75701904, 12.23387718], [92.75654602, 12.23364925], [92.75597382, 12.23356533], [92.75539398, 12.23334408], [92.75480652, 12.23314953], [92.75428009, 12.23301983], [92.75388336, 12.232831], [92.75347137, 12.23275089], [92.75312042, 12.23268127], [92.75282288, 12.23254204], [92.75247955, 12.23250103], [92.7521286, 12.23250103], [92.75177765, 12.23249626], [92.7514267, 12.23254204], [92.75112152, 12.23273087], [92.75078583, 12.2328701], [92.7508316, 12.23306084], [92.74973297, 12.23417091], [92.74944305, 12.2341671], [92.7491684, 12.23444462], [92.74861145, 12.23443985], [92.74804688, 12.23500061], [92.7480545, 12.2355547], [92.74781799, 12.23592186], [92.74777985, 12.2364254], [92.74777985, 12.23691273], [92.74783325, 12.23733044], [92.7480011, 12.23764038], [92.74812317, 12.23795891], [92.74828339, 12.23828125], [92.74834442, 12.23867893], [92.74842834, 12.23910999], [92.74858093, 12.23958015], [92.7486496, 12.24015045], [92.74878693, 12.24075985], [92.74881744, 12.24140072], [92.74861145, 12.24199963], [92.74833679, 12.24254704], [92.74806213, 12.24304199], [92.7477951, 12.24347687], [92.74755859, 12.2438736], [92.74729919, 12.24419498], [92.74703217, 12.24448013], [92.74674988, 12.24476719], [92.74641418, 12.24501514], [92.74602509, 12.24518871], [92.7455368, 12.24506092], [92.74507141, 12.24502945], [92.74465179, 12.24507236], [92.74429321, 12.24505901], [92.74397278, 12.24484921], [92.74357605, 12.24467087], [92.74317169, 12.24448872], [92.7427063, 12.24453926], [92.74234009, 12.24493122], [92.74228668, 12.24553967], [92.74249268, 12.24601555], [92.74274445, 12.2464056], [92.74297333, 12.24675179], [92.74308777, 12.24714184], [92.74327087, 12.2474699], [92.74336243, 12.24785995], [92.74349976, 12.24824047], [92.74359131, 12.2486372], [92.74360657, 12.24907017], [92.74360657, 12.24955082], [92.74360657, 12.25004959], [92.74362946, 12.25058079], [92.7437973, 12.25108719], [92.74397278, 12.25161076], [92.74419403, 12.25210953], [92.7444458, 12.25255871], [92.74472046, 12.25296974], [92.74500275, 12.25337124], [92.74526978, 12.25374889], [92.74549103, 12.25412273], [92.74565125, 12.25451946], [92.74582672, 12.25486088], [92.74598694, 12.25517082], [92.74610138, 12.25552177], [92.74619293, 12.25588703], [92.74637604, 12.2562151], [92.74654388, 12.25656414], [92.7466507, 12.2569809], [92.74671173, 12.25742817], [92.74690247, 12.25783062], [92.74697876, 12.25826168], [92.74718475, 12.25859928], [92.74732971, 12.25898361], [92.74749756, 12.25936031], [92.74767303, 12.25975513], [92.74783325, 12.26017189], [92.74803162, 12.26055908], [92.74819946, 12.26097393], [92.74846649, 12.26129055], [92.74859619, 12.26173306], [92.74867249, 12.26224995], [92.74880981, 12.26278114], [92.74868774, 12.26327991], [92.74855804, 12.26375008], [92.74836731, 12.26413059], [92.74823761, 12.26451969], [92.74809265, 12.26488018], [92.74809265, 12.26527691], [92.74825287, 12.26567078], [92.74837494, 12.26610374], [92.74861145, 12.26643944], [92.74888611, 12.26678085], [92.74914551, 12.26713657], [92.74935913, 12.26753998], [92.74948883, 12.26806736], [92.74971771, 12.26852226], [92.74989319, 12.2689333], [92.74977875, 12.26934147], [92.74971008, 12.26980114], [92.74960327, 12.27026367], [92.74948883, 12.27072239], [92.74953461, 12.27117252], [92.74968719, 12.27159023], [92.7497406, 12.27199078], [92.74983978, 12.27232647], [92.74996948, 12.27264309], [92.75004578, 12.27302074], [92.75019836, 12.27338791], [92.75035858, 12.27377796], [92.7506485, 12.2740736], [92.751091, 12.27427292], [92.75154114, 12.27447319], [92.75196838, 12.27465343], [92.752388, 12.27453041], [92.75274658, 12.27424145], [92.75300598, 12.27383137], [92.75313568, 12.27328587], [92.75337982, 12.27273178], [92.75364685, 12.27215958], [92.75409698, 12.27171135], [92.7546463, 12.27139187], [92.75521088, 12.27109146], [92.75572968, 12.270751], [92.75611115, 12.27035046], [92.75643921, 12.26993084], [92.75668335, 12.2694912], [92.75691223, 12.26909733], [92.75704193, 12.26869106], [92.75722504, 12.26837444], [92.7574234, 12.26810837], [92.75757599, 12.26786232], [92.75777435, 12.26777267], [92.75801849, 12.26777267], [92.75831604, 12.26777935], [92.75872803, 12.26777935], [92.75920868, 12.2677412], [92.75971222, 12.26755238], [92.76017761, 12.26729202], [92.76052094, 12.26692009], [92.76082611, 12.2665596], [92.76114655, 12.26624107], [92.76154327, 12.26599026], [92.76198578, 12.26579189], [92.7624588, 12.26544571], [92.76288605, 12.2650013], [92.76328278, 12.26459122], [92.76360321, 12.26425076], [92.76389313, 12.26400089], [92.76420593, 12.26385021], [92.764534, 12.26379585], [92.76490021, 12.26394367], [92.76528168, 12.26421261], [92.76568604, 12.26455021], [92.76609802, 12.26494694], [92.76629639, 12.26543045], [92.76637268, 12.26596069], [92.76641083, 12.26645088], [92.76647186, 12.26690197], [92.76659393, 12.26728535], [92.76670837, 12.26766968], [92.76685333, 12.26805973], [92.76703644, 12.26847172], [92.76732635, 12.26877117], [92.76767731, 12.26898098], [92.76803589, 12.26929092], [92.76835632, 12.26965141], [92.76869202, 12.27000618], [92.76898193, 12.27037144], [92.76921844, 12.27074909], [92.76948547, 12.2710638], [92.76978302, 12.2713213], [92.77012634, 12.27151012], [92.77050018, 12.27169037], [92.77082825, 12.27193928], [92.77114105, 12.27221203], [92.7714386, 12.27250195], [92.77171326, 12.27283001], [92.77194214, 12.27318287], [92.77213287, 12.27352524], [92.77230835, 12.27384186], [92.77248383, 12.27411842], [92.77262115, 12.27439117], [92.77274323, 12.27466011], [92.77281952, 12.27499104], [92.77291107, 12.27532959], [92.77309418, 12.27576256], [92.77332306, 12.27622128], [92.77350616, 12.276721], [92.77362061, 12.27728558], [92.77377319, 12.27783489], [92.77404785, 12.27821064], [92.77420807, 12.27871704], [92.77445221, 12.279212], [92.77474213, 12.27965641], [92.77509308, 12.27994537], [92.77548981, 12.27995491], [92.77583313, 12.27972221], [92.77666473, 12.27888775], [92.77694702, 12.27888966], [92.7771759, 12.27863026], [92.7775116, 12.27866936], [92.77778625, 12.27888107], [92.77805328, 12.27910042], [92.77829742, 12.27929974], [92.77855682, 12.27952194], [92.77870941, 12.2798996], [92.77892303, 12.28034019], [92.77913666, 12.28083038], [92.77937317, 12.28133106], [92.77960205, 12.28175545], [92.77973938, 12.28222179], [92.77999115, 12.28265762], [92.78022766, 12.28310394], [92.7804718, 12.28355122], [92.78082275, 12.28390026], [92.78111267, 12.28431034], [92.78139496, 12.28470898], [92.78172302, 12.28507996], [92.78183746, 12.28549099], [92.7817688, 12.28586197], [92.78166199, 12.28623104], [92.78147125, 12.28656864], [92.78105164, 12.28677368], [92.78073883, 12.28717041], [92.78032684, 12.28747272], [92.77996063, 12.28785038], [92.77971649, 12.28832817], [92.77954102, 12.28880024], [92.77945709, 12.28928757], [92.77942657, 12.28975868], [92.77935028, 12.29021072], [92.77915955, 12.29061031], [92.77887726, 12.29096699], [92.77852631, 12.29127979], [92.7780838, 12.29147625], [92.77760315, 12.29163074], [92.77703857, 12.29169941], [92.77646637, 12.29186058], [92.77588654, 12.29207039], [92.77541351, 12.29239178], [92.7750473, 12.29281139], [92.77481079, 12.29326916], [92.77472687, 12.29378033], [92.77476501, 12.29427719], [92.77497864, 12.29468155], [92.77539825, 12.2949543], [92.77593231, 12.29506969], [92.77639771, 12.29529953], [92.7767334, 12.2955389], [92.77693939, 12.2957468], [92.77707672, 12.29596996], [92.77719879, 12.29624844], [92.77722168, 12.29658127], [92.77719116, 12.2969389], [92.77703094, 12.29725075], [92.7768631, 12.29758072], [92.77667236, 12.29793453], [92.776474, 12.29833126], [92.77626038, 12.29875278], [92.77604675, 12.29921055], [92.77583313, 12.29966927], [92.77562714, 12.30010891], [92.77552032, 12.30054188], [92.77533722, 12.30086136], [92.77510834, 12.30112076], [92.77481079, 12.30133057], [92.77439117, 12.30138779], [92.77394867, 12.3013916], [92.77352905, 12.30138302], [92.77316284, 12.30130768], [92.77288055, 12.30109119], [92.77263641, 12.30077171], [92.7724762, 12.30031013], [92.77222443, 12.29986286], [92.77194214, 12.29941559], [92.77168274, 12.29899025], [92.771492, 12.29858685], [92.77133942, 12.29821014], [92.77112579, 12.29796219], [92.77091217, 12.29773903], [92.77072906, 12.2975111], [92.77047729, 12.29731941], [92.77017975, 12.29722977], [92.7698288, 12.29722118], [92.76945496, 12.29722118], [92.76907349, 12.29722118], [92.76868439, 12.29722404], [92.76828766, 12.29727077], [92.76792908, 12.29747868], [92.76760864, 12.29773045], [92.76754761, 12.29812241], [92.76767731, 12.29854965], [92.76778412, 12.29903984], [92.76789093, 12.29954433], [92.76802063, 12.30004978], [92.76805115, 12.30065823], [92.76808929, 12.30130959], [92.76824951, 12.3019762], [92.76843262, 12.30259991], [92.76874542, 12.30303764], [92.76904297, 12.30339146], [92.76921844, 12.3037672], [92.76940155, 12.30409145], [92.76950073, 12.30445957], [92.76967621, 12.30478954], [92.76972198, 12.30517578], [92.76972198, 12.30558109], [92.76972198, 12.30598927], [92.76972198, 12.30644035], [92.76972198, 12.30692959], [92.76972198, 12.30750275], [92.76972198, 12.30814838], [92.76973724, 12.30883121], [92.76969147, 12.30952168], [92.76999664, 12.31026936], [92.77044678, 12.310812], [92.77059937, 12.31133556], [92.77082825, 12.31186008], [92.77110291, 12.31213093], [92.77128601, 12.31285191], [92.7718811, 12.31291103], [92.77249908, 12.31245136], [92.77289581, 12.31225204], [92.77333069, 12.31203556], [92.77375793, 12.31179047], [92.77420044, 12.3115387], [92.77469635, 12.3113308], [92.77516937, 12.31110096], [92.77558899, 12.31083679], [92.77597046, 12.31060886], [92.77630615, 12.31046963], [92.77657318, 12.3102808]]], [[[92.94139862, 12.28080177], [92.94165802, 12.28033066], [92.94193268, 12.27989101], [92.9421463, 12.2794714], [92.94244385, 12.27910233], [92.94262695, 12.27865982], [92.94248962, 12.27805233], [92.94236755, 12.27748203], [92.94245911, 12.27703953], [92.94249725, 12.27662945], [92.94249725, 12.27618027], [92.94248962, 12.27565193], [92.94241333, 12.27509117], [92.94219971, 12.27459621], [92.94193268, 12.27416992], [92.94165802, 12.27377605], [92.94139099, 12.27338791], [92.94114685, 12.27296925], [92.94094086, 12.27251816], [92.9406662, 12.27208042], [92.94033813, 12.27170372], [92.94004059, 12.27128696], [92.93978119, 12.27081966], [92.9394989, 12.27035046], [92.93913269, 12.26999283], [92.9386673, 12.26973724], [92.9381485, 12.26954079], [92.93766022, 12.26936054], [92.93727112, 12.2690506], [92.93695068, 12.26867104], [92.9366684, 12.26828957], [92.93643188, 12.26792145], [92.93626404, 12.26752567], [92.93608856, 12.26714993], [92.93588257, 12.26674938], [92.93575287, 12.26624107], [92.93548584, 12.26577187], [92.93518066, 12.2652998], [92.93487549, 12.26487446], [92.93462372, 12.26444054], [92.9344101, 12.26402092], [92.93417358, 12.26368237], [92.93393707, 12.26338768], [92.93370819, 12.26315975], [92.9335022, 12.26294136], [92.93333435, 12.26272202], [92.93318939, 12.26249409], [92.9330368, 12.26225853], [92.93286896, 12.2620306], [92.93271637, 12.26175117], [92.93253326, 12.26148033], [92.93239594, 12.26116085], [92.93218231, 12.26088142], [92.93190002, 12.2606411], [92.9315567, 12.26044655], [92.93121338, 12.2602396], [92.93093109, 12.25999832], [92.93071747, 12.25974083], [92.93055725, 12.25947189], [92.93032074, 12.25932598], [92.93013763, 12.25916195], [92.93000031, 12.25896072], [92.92987823, 12.2587204], [92.92971039, 12.25829124], [92.92951202, 12.25778961], [92.9294281, 12.25720024], [92.92931366, 12.25661373], [92.92916107, 12.25610828], [92.92899323, 12.25561142], [92.92882538, 12.25515842], [92.92862701, 12.25471973], [92.92845917, 12.25426865], [92.92830658, 12.25386143], [92.92817688, 12.25349236], [92.92797089, 12.253232], [92.92781067, 12.25298977], [92.92778015, 12.25273705], [92.92778015, 12.25244141], [92.92775726, 12.25213146], [92.92765808, 12.25184059], [92.92752838, 12.25156116], [92.92749786, 12.25123978], [92.92749786, 12.25089264], [92.92749786, 12.25044441], [92.92750549, 12.24991322], [92.92758942, 12.24939823], [92.92785645, 12.24905014], [92.92808533, 12.24873257], [92.92832947, 12.24844074], [92.92858124, 12.24808979], [92.92884064, 12.24767971], [92.92901611, 12.24720097], [92.92910004, 12.24667931], [92.92893982, 12.2461319], [92.92890167, 12.24558067], [92.92888641, 12.24507046], [92.92888641, 12.24460125], [92.92892456, 12.24418354], [92.92907715, 12.24379635], [92.92914581, 12.24337006], [92.9291687, 12.24291039], [92.9291687, 12.2424612], [92.92919922, 12.24206161], [92.92933655, 12.24175167], [92.92943573, 12.24151516], [92.92945862, 12.24129963], [92.92938995, 12.24103165], [92.92922974, 12.24071026], [92.92914581, 12.24039078], [92.92914581, 12.24002171], [92.92914581, 12.23957062], [92.92905426, 12.23907375], [92.92888641, 12.23853397], [92.92866516, 12.2379427], [92.92841339, 12.23730278], [92.92799377, 12.23672867], [92.92752075, 12.23620033], [92.92708588, 12.23569202], [92.92674255, 12.23520184], [92.92649078, 12.2347002], [92.92627716, 12.23418045], [92.92607117, 12.23366547], [92.92582703, 12.23316193], [92.92555237, 12.23269939], [92.92527771, 12.2322607], [92.92495728, 12.23182774], [92.92450714, 12.23139095], [92.92392731, 12.23097134], [92.92362213, 12.23085117], [92.92321014, 12.23083687], [92.92263794, 12.23085117], [92.92208862, 12.23095131], [92.92170715, 12.23118973], [92.92147827, 12.23148441], [92.92133331, 12.23184013], [92.92110443, 12.23215866], [92.92085266, 12.23248005], [92.92058563, 12.23283768], [92.91853333, 12.23877144], [92.91880798, 12.24207973], [92.91853333, 12.24400997], [92.91916656, 12.24555969], [92.91916656, 12.24611187], [92.91944122, 12.24638844], [92.91944122, 12.24722195], [92.91972351, 12.24750042], [92.91972351, 12.24833393], [92.91999817, 12.24860954], [92.91999817, 12.25027847], [92.9200058, 12.25068092], [92.92007446, 12.25109577], [92.92016602, 12.25157928], [92.92030334, 12.25213146], [92.92047119, 12.25264645], [92.92064667, 12.25313091], [92.92084503, 12.25351906], [92.92108154, 12.25381088], [92.92140961, 12.25401592], [92.92176056, 12.25425053], [92.92180634, 12.25475597], [92.92183685, 12.25517559], [92.92195892, 12.25548077], [92.92214203, 12.25579262], [92.92221069, 12.25626087], [92.92225647, 12.25680065], [92.92236328, 12.25731087], [92.9225235, 12.2577219], [92.92267609, 12.25806999], [92.92276001, 12.25838947], [92.9227829, 12.2586813], [92.9227829, 12.25895023], [92.9227829, 12.25922108], [92.92272949, 12.25953102], [92.92256165, 12.25983047], [92.92238617, 12.2602396], [92.92212677, 12.26065922], [92.92205811, 12.26117039], [92.92216492, 12.26169872], [92.92215729, 12.26212025], [92.92199707, 12.26249027], [92.92190552, 12.26290703], [92.92173767, 12.2633009], [92.92163086, 12.26371956], [92.92147064, 12.26412106], [92.92138672, 12.26454067], [92.92132568, 12.26488972], [92.9210968, 12.26510143], [92.92085266, 12.26537037], [92.92066956, 12.26556396], [92.92041779, 12.26563263], [92.92015076, 12.26567364], [92.92003632, 12.2656641], [92.91983795, 12.26564598], [92.91950226, 12.26539135], [92.91925812, 12.26485062], [92.91911316, 12.26412106], [92.91877747, 12.26341915], [92.91829681, 12.26289082], [92.91777039, 12.26291084], [92.9172287, 12.26307106], [92.91668701, 12.26336002], [92.91623688, 12.26382732], [92.91616821, 12.26451111], [92.91641235, 12.26519012], [92.91677856, 12.26579189], [92.91713715, 12.26632118], [92.9174118, 12.26679039], [92.91751099, 12.26718044], [92.91739655, 12.26743126], [92.91720581, 12.26752186], [92.91697693, 12.26745129], [92.91673279, 12.2672596], [92.9164505, 12.2670002], [92.91616058, 12.26671124], [92.91586304, 12.26641178], [92.9155426, 12.26611996], [92.91525269, 12.26588631], [92.91500854, 12.26568031], [92.91482544, 12.26548195], [92.91468048, 12.2651968], [92.91440582, 12.26493073], [92.91416168, 12.26456642], [92.91388702, 12.26410961], [92.91361237, 12.26360035], [92.91335297, 12.26311016], [92.91295624, 12.26296139], [92.91256714, 12.26310253], [92.91223145, 12.26353264], [92.91203308, 12.2640419], [92.912117, 12.26462078], [92.91227722, 12.26521111], [92.9125061, 12.26573658], [92.91278076, 12.26622105], [92.91306305, 12.26672173], [92.91331482, 12.26721668], [92.91351318, 12.26769257], [92.91365051, 12.2681303], [92.91381836, 12.26858902], [92.91384125, 12.26912212], [92.91378021, 12.26970959], [92.91404724, 12.27038002], [92.91419983, 12.27103043], [92.91433716, 12.27157021], [92.91439056, 12.27202129], [92.91429901, 12.27237225], [92.91417694, 12.27263165], [92.91398621, 12.27283001], [92.91364288, 12.27300072], [92.91304016, 12.27304935], [92.912323, 12.27305984], [92.91160583, 12.27312183], [92.91100311, 12.27334118], [92.91044617, 12.27357101], [92.90989685, 12.27367973], [92.90945435, 12.27388763], [92.90899658, 12.2741003], [92.90853119, 12.27429962], [92.90804291, 12.27440929], [92.9076004, 12.27439117], [92.90722656, 12.27406979], [92.90692902, 12.27367973], [92.90661621, 12.27326107], [92.90634155, 12.27281189], [92.90602875, 12.27232647], [92.90558624, 12.27188015], [92.90516663, 12.27144718], [92.90471649, 12.27112103], [92.90428162, 12.27089024], [92.90380096, 12.27083111], [92.90332031, 12.27083969], [92.90283203, 12.27092934], [92.90235901, 12.27109146], [92.9018631, 12.27121639], [92.90145874, 12.27147198], [92.90117645, 12.27188015], [92.90112305, 12.27243996], [92.90115356, 12.27301025], [92.9013443, 12.27350521], [92.90146637, 12.2740612], [92.90170288, 12.27455997], [92.9020462, 12.27496147], [92.90248108, 12.27528], [92.90283966, 12.27562046], [92.90312958, 12.27592087], [92.90333557, 12.27618885], [92.90351105, 12.27643585], [92.90364075, 12.276721], [92.90380859, 12.27705765], [92.90387726, 12.27744961], [92.90383911, 12.27785969], [92.90366364, 12.27817726], [92.9034729, 12.27846432], [92.90320587, 12.27872372], [92.90284729, 12.27896976], [92.90252686, 12.27929974], [92.90222931, 12.27965069], [92.90194702, 12.27999115], [92.90171814, 12.28035831], [92.90158844, 12.28076363], [92.9018631, 12.28130245], [92.90213776, 12.28178692], [92.90221405, 12.28227234], [92.90222931, 12.28269196], [92.90228271, 12.2830677], [92.90245819, 12.28338242], [92.90249634, 12.28372383], [92.90250397, 12.28407288], [92.90248871, 12.28443146], [92.90238953, 12.284832], [92.90219879, 12.28528118], [92.90202332, 12.2857914], [92.90194702, 12.28635025], [92.9019165, 12.28689003], [92.90177917, 12.28737068], [92.90157318, 12.2877903], [92.90146637, 12.28822136], [92.90184784, 12.28877926], [92.9021759, 12.289361], [92.90242004, 12.2899189], [92.90278625, 12.29032707], [92.90320587, 12.29066181], [92.90376282, 12.29090118], [92.90429688, 12.29119968], [92.90484619, 12.29158974], [92.90544128, 12.29184341], [92.90604401, 12.29171276], [92.90663147, 12.2917099], [92.90717316, 12.29188633], [92.9076767, 12.29189014], [92.90815735, 12.29195023], [92.90859985, 12.29206085], [92.9090271, 12.29223728], [92.90943909, 12.2924509], [92.90992737, 12.29259014], [92.91034698, 12.29279137], [92.91074371, 12.29300022], [92.91118622, 12.2930479], [92.91163635, 12.2930603], [92.91213226, 12.2930603], [92.91266632, 12.29302979], [92.91324615, 12.29286098], [92.91382599, 12.29261112], [92.91430664, 12.29220009], [92.914711, 12.29175377], [92.91509247, 12.29132462], [92.91552734, 12.29099178], [92.91598511, 12.29067326], [92.91640472, 12.29032707], [92.91681671, 12.29000092], [92.91718292, 12.28971195], [92.91750336, 12.28946114], [92.91780853, 12.28928089], [92.91816711, 12.28916931], [92.91857147, 12.28907108], [92.91896057, 12.28887081], [92.91928101, 12.28855228], [92.91942596, 12.2881279], [92.91944122, 12.28765965], [92.91938782, 12.28720188], [92.91921234, 12.28678513], [92.91916656, 12.28628063], [92.91916656, 12.28573036], [92.91916656, 12.28516006], [92.91916656, 12.28461075], [92.91916656, 12.28412056], [92.91919708, 12.28372192], [92.91933441, 12.28342628], [92.91944122, 12.28317738], [92.91956329, 12.2830019], [92.91971588, 12.28286266], [92.91983032, 12.2824297], [92.9200058, 12.2822504], [92.92021942, 12.28227043], [92.92040253, 12.28249073], [92.92066956, 12.28283978], [92.92095947, 12.28329086], [92.92134857, 12.2837019], [92.92181396, 12.28412819], [92.92243958, 12.28439236], [92.9230957, 12.28436184], [92.92359161, 12.28397465], [92.92395782, 12.28353119], [92.92420197, 12.28308201], [92.92440796, 12.28271008], [92.92453003, 12.28231144], [92.92472076, 12.28195953], [92.92492676, 12.2816], [92.92506409, 12.28123093], [92.92529297, 12.28096199], [92.92552185, 12.28074074], [92.92572784, 12.28055191], [92.92592621, 12.2804203], [92.92617798, 12.28038979], [92.92643738, 12.28046989], [92.92673492, 12.28058147], [92.92700958, 12.28080654], [92.9272995, 12.28103924], [92.92765045, 12.28125095], [92.92798615, 12.28151131], [92.92835236, 12.28183937], [92.92873383, 12.28218842], [92.92914581, 12.28250027], [92.92944336, 12.28287029], [92.92969513, 12.28318882], [92.92987823, 12.28347969], [92.92999268, 12.28378105], [92.9300766, 12.284091], [92.93023682, 12.28439045], [92.93032837, 12.28477955], [92.93050385, 12.28519726], [92.93054962, 12.28569317], [92.93055725, 12.28623104], [92.93055725, 12.28678989], [92.93054199, 12.28734112], [92.93045807, 12.28785038], [92.93026733, 12.28830147], [92.93003845, 12.28867531], [92.92991638, 12.28907967], [92.92972565, 12.2894268], [92.92952728, 12.28977966], [92.92938232, 12.29018974], [92.92914581, 12.29057121], [92.92888641, 12.29098797], [92.92868042, 12.29147053], [92.9287796, 12.29206085], [92.92910004, 12.29259014], [92.92936707, 12.29309177], [92.92954254, 12.29355621], [92.9296875, 12.29399395], [92.92974091, 12.29443169], [92.92980957, 12.29483986], [92.92993927, 12.29520226], [92.92999268, 12.29561043], [92.93000031, 12.29605675], [92.93000793, 12.29655075], [92.93006897, 12.29709816], [92.93028259, 12.29765224], [92.93048096, 12.29823112], [92.93048096, 12.29887104], [92.93026733, 12.2994709], [92.93004608, 12.30010033], [92.93000031, 12.30072021], [92.9299469, 12.30124187], [92.92978668, 12.30164146], [92.92970276, 12.30202103], [92.92958832, 12.30234909], [92.92946625, 12.3026619], [92.92942047, 12.30299664], [92.92931366, 12.30335236], [92.92922211, 12.30377388], [92.92933655, 12.30428886], [92.92965698, 12.30484009], [92.92991638, 12.30536938], [92.93010712, 12.30586815], [92.93039703, 12.30620098], [92.93074799, 12.30644035], [92.93102264, 12.30666161], [92.93127441, 12.30686855], [92.93158722, 12.30703068], [92.93190765, 12.30727673], [92.93221283, 12.307621], [92.93251801, 12.30806828], [92.93282318, 12.30857372], [92.9331665, 12.30902004], [92.93344879, 12.30950069], [92.93367767, 12.31000042], [92.93403625, 12.31038094], [92.93421936, 12.31046104], [92.93444824, 12.31056118], [92.9347229, 12.3102808], [92.9347229, 12.30943966], [92.93444824, 12.30916595], [92.93444824, 12.3088913], [92.93416595, 12.30860996], [92.93416595, 12.308321], [92.93444824, 12.30805588], [92.93444824, 12.30694199], [92.9347229, 12.30666637], [92.9347229, 12.30639267], [92.93499756, 12.30611038], [92.93499756, 12.30583191], [92.93527985, 12.3055563], [92.9347229, 12.30500031], [92.9347229, 12.30443859], [92.93499756, 12.30416584], [92.93499756, 12.30389023], [92.93553925, 12.30332947], [92.9355545, 12.30277824], [92.93585205, 12.30251122], [92.93585205, 12.30221939], [92.93598175, 12.30180454], [92.9361496, 12.30144215], [92.9363327, 12.30103683], [92.93638611, 12.30055141], [92.93644714, 12.30001068], [92.93660736, 12.2994709], [92.93666077, 12.29895973], [92.9366684, 12.29849052], [92.93663788, 12.29809666], [92.93653107, 12.29778194], [92.93638611, 12.2974968], [92.93622589, 12.29720974], [92.93606567, 12.29691601], [92.93585968, 12.2966404], [92.93570709, 12.29629135], [92.93544769, 12.29602337], [92.93508911, 12.29581738], [92.93473053, 12.29556179], [92.93438721, 12.29526997], [92.93341064, 12.29403973], [92.93299103, 12.29321003], [92.93299103, 12.29183578], [92.93326569, 12.2903204], [92.93327332, 12.28894138], [92.9336853, 12.28742599], [92.93424988, 12.28604031], [92.9353714, 12.28508282], [92.93759155, 12.28362179], [92.93803406, 12.28305435], [92.93847656, 12.28254128], [92.93897247, 12.28214931], [92.93947601, 12.28190804], [92.93997955, 12.28167057], [92.94050598, 12.28144073], [92.94100952, 12.28118515], [92.94139862, 12.28080177]]], [[[92.75444794, 12.29472256], [92.7547226, 12.29444313], [92.75499725, 12.29444313], [92.75499725, 12.29361057], [92.75333405, 12.29194546], [92.75305176, 12.29194546], [92.7527771, 12.29222107], [92.75222015, 12.29278183], [92.75250244, 12.29305458], [92.75250244, 12.29333305], [92.7527771, 12.29361057], [92.7527771, 12.29416656], [92.75333405, 12.29472256], [92.75444794, 12.29472256]]], [[[92.77118683, 12.29492378], [92.77120972, 12.29350567], [92.771492, 12.29354954], [92.7714386, 12.29295921], [92.77060699, 12.29212093], [92.77060699, 12.29101276], [92.77033234, 12.29073524], [92.77033234, 12.29046059], [92.76950073, 12.2896204], [92.76894379, 12.28934669], [92.76893616, 12.2887907], [92.76893616, 12.28851032], [92.76838684, 12.28851318], [92.7684021, 12.2887907], [92.76811218, 12.28907108], [92.76673126, 12.2890892], [92.76667023, 12.28991032], [92.76700592, 12.28988934], [92.76699829, 12.29045677], [92.76756287, 12.29075146], [92.76757813, 12.29133034], [92.76815033, 12.29130936], [92.76818848, 12.29214954], [92.76837158, 12.29213047], [92.76838684, 12.29295731], [92.76894379, 12.29323483], [92.76950073, 12.29378891], [92.76950073, 12.29406929], [92.76977539, 12.29434681], [92.76977539, 12.29462528], [92.77033234, 12.29464436], [92.77035522, 12.29494381], [92.77118683, 12.29492378]]], [[[93.07256317, 12.31904411], [93.07259369, 12.31831932], [93.07287598, 12.31815147], [93.07318878, 12.31790924], [93.0734024, 12.31762886], [93.07382202, 12.31732082], [93.07375336, 12.31701088], [93.07389069, 12.31670094], [93.07364655, 12.31648922], [93.07343292, 12.31618404], [93.07350159, 12.31573677], [93.07293701, 12.31539059], [93.07263184, 12.31542683], [93.07234955, 12.3157711], [93.07203674, 12.3157711], [93.07171631, 12.31591034], [93.07147217, 12.31608105], [93.07084656, 12.31584167], [93.07042694, 12.31584167], [93.06978607, 12.31591034], [93.06960297, 12.31617928], [93.06954956, 12.31648922], [93.06919861, 12.31620026], [93.06829071, 12.31620026], [93.06800842, 12.31606102], [93.06758881, 12.31585979], [93.06710052, 12.31613064], [93.0669632, 12.31599045], [93.06632996, 12.31603146], [93.06614685, 12.31620026], [93.06601715, 12.31609726], [93.06562805, 12.3163023], [93.06531525, 12.3163023], [93.06520844, 12.31616592], [93.06490326, 12.31616974], [93.06458282, 12.31627274], [93.06394958, 12.31606102], [93.06363678, 12.31592178], [93.06339264, 12.31571674], [93.06301117, 12.31592178], [93.06301117, 12.31616592], [93.06321716, 12.31633186], [93.06349945, 12.31657791], [93.06352997, 12.31678104], [93.06381226, 12.31696129], [93.0640564, 12.31707001], [93.06433868, 12.31703186], [93.06478882, 12.31707001], [93.06520844, 12.3173027], [93.06542206, 12.31737137], [93.06591034, 12.31747055], [93.0663681, 12.31775188], [93.06671906, 12.31799126], [93.06698608, 12.31816196], [93.06748962, 12.31850624], [93.06793976, 12.31884956], [93.06825256, 12.31884956], [93.06852722, 12.31906033], [93.06867218, 12.31895065], [93.06934357, 12.31888676], [93.06949615, 12.31871128], [93.06972504, 12.31861115], [93.07053375, 12.31861115], [93.07063293, 12.31842041], [93.07112885, 12.31887054], [93.07141113, 12.31879997], [93.07170105, 12.31908131], [93.07186127, 12.31918144], [93.0723877, 12.31935406], [93.07256317, 12.31904411]]], [[[92.87805939, 12.29364967], [92.87774658, 12.29364109], [92.87732697, 12.29382992], [92.87696075, 12.29424], [92.87670898, 12.29476357], [92.87670898, 12.29535007], [92.87697601, 12.29589939], [92.87742615, 12.29636192], [92.87798309, 12.29676056], [92.87853241, 12.29717636], [92.87915802, 12.29755878], [92.87967682, 12.29787064], [92.88021088, 12.29784966], [92.88066864, 12.29746056], [92.88098907, 12.29689503], [92.880867, 12.29614067], [92.88059998, 12.29541588], [92.88008881, 12.29493999], [92.87956238, 12.29450035], [92.87895203, 12.29417038], [92.87831879, 12.29388046], [92.87805939, 12.29364967]]], [[[92.76590729, 12.29907036], [92.76593018, 12.29852009], [92.765625, 12.29854107], [92.76566315, 12.2980032], [92.76590729, 12.2980032], [92.76593018, 12.29744244], [92.76534271, 12.29688358], [92.7647934, 12.29684544], [92.7647934, 12.29657173], [92.76368713, 12.29656982], [92.76368713, 12.29714394], [92.7634201, 12.29714394], [92.76346588, 12.2977047], [92.76371002, 12.29771996], [92.76368713, 12.29823589], [92.76396942, 12.29852295], [92.7647934, 12.29854107], [92.76508331, 12.29907036], [92.76590729, 12.29907036]]], [[[92.78022766, 12.62918186], [92.78038025, 12.62890911], [92.78054047, 12.62861919], [92.78072357, 12.6283226], [92.78095245, 12.62801743], [92.78128815, 12.62777138], [92.78164673, 12.6275177], [92.78203583, 12.62726116], [92.7824707, 12.62700081], [92.78292084, 12.62676811], [92.78337097, 12.62648964], [92.78382111, 12.6261797], [92.78431702, 12.62589455], [92.78479767, 12.62560368], [92.78521729, 12.62531853], [92.78553772, 12.62504101], [92.78578949, 12.62479019], [92.78586578, 12.62427044], [92.7857132, 12.62396145], [92.7855072, 12.62356186], [92.78530884, 12.62304878], [92.78502655, 12.62253094], [92.7846756, 12.62203693], [92.78440094, 12.62158108], [92.78400421, 12.62102509], [92.78383636, 12.62052059], [92.78378296, 12.61970139], [92.78360748, 12.61899853], [92.78353882, 12.61851978], [92.78383636, 12.61823463], [92.78392029, 12.61832047], [92.78427887, 12.61865044], [92.78473663, 12.61900139], [92.78543091, 12.61924744], [92.78591156, 12.61972427], [92.78620911, 12.62028217], [92.78629303, 12.62090015], [92.78648376, 12.62170601], [92.78662872, 12.62257004], [92.78671265, 12.62325573], [92.78662872, 12.6243906], [92.78653717, 12.62460136], [92.78624725, 12.62572002], [92.786026, 12.62599087], [92.78556824, 12.62617588], [92.7852478, 12.62652493], [92.78464508, 12.62694168], [92.78434753, 12.62714005], [92.78398132, 12.62764072], [92.78318787, 12.62816143], [92.78263855, 12.62845039], [92.78199005, 12.62878132], [92.78159332, 12.62905025], [92.78110504, 12.62941933], [92.78074646, 12.62985039], [92.7804718, 12.63022995], [92.7802887, 12.6307106], [92.78026581, 12.63123798], [92.78031158, 12.63173008], [92.78056335, 12.63222885], [92.78092194, 12.63350964], [92.78105164, 12.63389778], [92.78114319, 12.63416195], [92.78129578, 12.6343689], [92.78145599, 12.63464069], [92.78157806, 12.63493919], [92.78168488, 12.63522243], [92.78182983, 12.63549137], [92.78192139, 12.6358099], [92.78199005, 12.63621998], [92.78217316, 12.63671017], [92.78218842, 12.63724995], [92.78208923, 12.63778973], [92.7821579, 12.63827991], [92.78206635, 12.63871956], [92.78207397, 12.63916683], [92.78215027, 12.6396637], [92.78198242, 12.64016056], [92.78179932, 12.64074039], [92.78179169, 12.64143944], [92.78183746, 12.64208031], [92.78192139, 12.64265156], [92.78193665, 12.64321041], [92.78193665, 12.64376163], [92.78193665, 12.64428139], [92.7819519, 12.64476204], [92.78148651, 12.64568996], [92.78121948, 12.64612103], [92.78113556, 12.64645576], [92.78081512, 12.64753056], [92.78063202, 12.64816856], [92.7804184, 12.6490202], [92.78038025, 12.64966011], [92.78038025, 12.65067196], [92.78047943, 12.65125084], [92.78045654, 12.65195274], [92.78038025, 12.65275955], [92.78040314, 12.65346241], [92.7804718, 12.6539402], [92.78063202, 12.65428734], [92.78096771, 12.65439224], [92.78119659, 12.65439224], [92.78199768, 12.65434361], [92.78219604, 12.65391541], [92.78246307, 12.65329075], [92.78273773, 12.65296936], [92.78291321, 12.65316105], [92.7829361, 12.65375996], [92.78287506, 12.65441895], [92.78305817, 12.65482235], [92.7832489, 12.65502453], [92.78346252, 12.65533066], [92.78363037, 12.65579128], [92.78379059, 12.65630817], [92.78391266, 12.65692139], [92.78401947, 12.65756035], [92.78414154, 12.65806961], [92.78421021, 12.6585989], [92.78439331, 12.65908718], [92.78443909, 12.65956306], [92.78440094, 12.65997982], [92.78420258, 12.66034889], [92.78407288, 12.66076565], [92.78388214, 12.66118145], [92.78367615, 12.66163731], [92.78362274, 12.66219139], [92.78360748, 12.66276073], [92.783638, 12.66330814], [92.78373718, 12.66381264], [92.78374481, 12.66438293], [92.7838974, 12.66495991], [92.78411865, 12.66555691], [92.78429413, 12.66615391], [92.7845459, 12.66662121], [92.78481293, 12.66702938], [92.78499603, 12.66750145], [92.78520203, 12.66795921], [92.78553772, 12.6682806], [92.78586578, 12.66860199], [92.78614807, 12.66894245], [92.78634644, 12.66941071], [92.78653717, 12.66990089], [92.78677368, 12.67033195], [92.78701782, 12.67072201], [92.78721619, 12.67115021], [92.78743744, 12.67165089], [92.78761292, 12.67220783], [92.78785706, 12.67269993], [92.78813934, 12.673172], [92.78842926, 12.67359638], [92.78858948, 12.67403984], [92.78864288, 12.67448044], [92.78859711, 12.67488956], [92.78848267, 12.67525005], [92.78833008, 12.6755867], [92.78814697, 12.67589283], [92.78801727, 12.6762352], [92.78782654, 12.67656136], [92.78771973, 12.67697144], [92.78754425, 12.6773653], [92.78746033, 12.67783928], [92.78729248, 12.6782999], [92.7871933, 12.6788311], [92.7869873, 12.6793499], [92.78691101, 12.67988777], [92.78681183, 12.68042183], [92.78691101, 12.68095684], [92.78694153, 12.68146133], [92.78690338, 12.68195057], [92.78671265, 12.68240166], [92.78666687, 12.68288136], [92.78666687, 12.68336201], [92.78666687, 12.68386078], [92.78662109, 12.68432999], [92.78643799, 12.68477726], [92.78639221, 12.6852417], [92.78643799, 12.68569088], [92.78662109, 12.68612194], [92.78666687, 12.68658733], [92.78666687, 12.68709946], [92.78666687, 12.687644], [92.78666687, 12.68818188], [92.78666687, 12.68867016], [92.78666687, 12.68908024], [92.78666687, 12.68942165], [92.78666687, 12.68972301], [92.78665924, 12.69001198], [92.78665924, 12.69031525], [92.78666687, 12.69064999], [92.78671265, 12.69103146], [92.78672791, 12.69136143], [92.78672791, 12.69164181], [92.78679657, 12.69186687], [92.78691101, 12.69210434], [92.78694153, 12.69241047], [92.78694153, 12.69279957], [92.78694153, 12.6932373], [92.78694153, 12.69370174], [92.78694153, 12.69417381], [92.78694916, 12.69464111], [92.78694153, 12.69511986], [92.78690338, 12.69560146], [92.78672791, 12.6960907], [92.7866745, 12.69659901], [92.78668213, 12.69717121], [92.78675842, 12.69780922], [92.78681946, 12.69849491], [92.78684235, 12.69919014], [92.78684235, 12.69985104], [92.78692627, 12.70040035], [92.78700256, 12.70086956], [92.7872467, 12.70119095], [92.78734589, 12.70162201], [92.78747559, 12.70211887], [92.7875061, 12.70259953], [92.78749847, 12.70303726], [92.78746033, 12.7033844], [92.78733063, 12.70359135], [92.7871933, 12.70374203], [92.78716278, 12.70411968], [92.78721619, 12.70484924], [92.78726196, 12.7055397], [92.787323, 12.70614815], [92.78740692, 12.70667934], [92.78739166, 12.70720959], [92.78721619, 12.70768929], [92.7869873, 12.70815182], [92.78671265, 12.70857143], [92.78636169, 12.70892906], [92.78598022, 12.70926189], [92.78556061, 12.70954037], [92.78513336, 12.7097559], [92.78370667, 12.71020126], [92.7827301, 12.71041012], [92.78147125, 12.71123791], [92.77993774, 12.71275139], [92.77915955, 12.71310043], [92.77886963, 12.7129612], [92.77894592, 12.71241093], [92.77937317, 12.71151066], [92.78035736, 12.71068573], [92.78189087, 12.70979023], [92.78298187, 12.7091589], [92.78343964, 12.70889854], [92.78391266, 12.70864201], [92.78440094, 12.70839119], [92.78486633, 12.70809937], [92.78524017, 12.70772076], [92.78552246, 12.70731068], [92.78572845, 12.70689106], [92.78585052, 12.70646095], [92.78594208, 12.70604992], [92.78605652, 12.70568085], [92.78617859, 12.705266], [92.78610229, 12.70328999], [92.78594208, 12.70294571], [92.7858429, 12.70261097], [92.7857666, 12.70217133], [92.78555298, 12.7017498], [92.78531647, 12.70129204], [92.78523254, 12.70076275], [92.78505707, 12.70029068], [92.78500366, 12.69977093], [92.78499603, 12.69920158], [92.78499603, 12.6985817], [92.78495789, 12.6979208], [92.78476715, 12.69727135], [92.78456879, 12.69660091], [92.78449249, 12.69590092], [92.78457642, 12.69520187], [92.7844696, 12.69451141], [92.78436279, 12.69384098], [92.78418732, 12.69323921], [92.78405762, 12.69268799], [92.78386688, 12.69224072], [92.78362274, 12.69185066], [92.78333282, 12.69146633], [92.78302765, 12.69105053], [92.78263855, 12.69068909], [92.78225708, 12.69031143], [92.78186798, 12.68992996], [92.78148651, 12.68954945], [92.78118134, 12.68918324], [92.78087616, 12.6888628], [92.78063202, 12.68856335], [92.78046417, 12.6882534], [92.78025055, 12.68798065], [92.77996826, 12.68772221], [92.77967072, 12.68734646], [92.77923584, 12.68695068], [92.77876282, 12.6864996], [92.7783432, 12.68593025], [92.77796936, 12.68536472], [92.77758789, 12.68490696], [92.77733612, 12.68443966], [92.7771759, 12.68402004], [92.7769928, 12.68369198], [92.77684021, 12.68337059], [92.77670288, 12.68307018], [92.77658844, 12.68273258], [92.77641296, 12.68240738], [92.77628326, 12.6819706], [92.77612305, 12.68149471], [92.77596283, 12.68098354], [92.77580261, 12.68049431], [92.77555847, 12.6800909], [92.77529907, 12.67972183], [92.77500153, 12.67937088], [92.77466583, 12.67903996], [92.77424622, 12.678792], [92.77392578, 12.67847061], [92.77364349, 12.67810822], [92.7733078, 12.67780113], [92.77294159, 12.6774931], [92.77257538, 12.67714596], [92.7722702, 12.6767292], [92.77193451, 12.6763649], [92.77165985, 12.67597294], [92.77138519, 12.6755743], [92.77111053, 12.67514515], [92.77083588, 12.67467117], [92.77056122, 12.67414856], [92.77028656, 12.67362118], [92.76995087, 12.67315578], [92.76957703, 12.67279053], [92.76921082, 12.67245102], [92.76888275, 12.67212105], [92.76850128, 12.6718502], [92.76805878, 12.67164707], [92.76763916, 12.67140102], [92.76719666, 12.67122078], [92.76674652, 12.67111969], [92.76634216, 12.67108154], [92.76592255, 12.67097664], [92.76534271, 12.67095184], [92.76470184, 12.6710701], [92.76444244, 12.67106819], [92.76405334, 12.67106342], [92.76344299, 12.67089462], [92.76281738, 12.67085075], [92.7621994, 12.67089939], [92.76165009, 12.6710701], [92.76111603, 12.67111111], [92.76062775, 12.67111969], [92.76013947, 12.67119122], [92.75966644, 12.67138004], [92.75911713, 12.67155075], [92.75853729, 12.67166996], [92.7579422, 12.67179012], [92.75741577, 12.67195892], [92.7569809, 12.67217064], [92.75657654, 12.67232609], [92.75624084, 12.67248058], [92.75589752, 12.67261124], [92.75563049, 12.67281246], [92.75540161, 12.67306042], [92.75515747, 12.6733427], [92.75489044, 12.67360687], [92.75457764, 12.67385483], [92.75419617, 12.67403984], [92.75386047, 12.67427731], [92.753479, 12.67447472], [92.75305176, 12.67467594], [92.75250244, 12.67472076], [92.75233459, 12.67471504], [92.75192261, 12.67469597], [92.75138092, 12.67457104], [92.75086212, 12.67442131], [92.75042725, 12.67416096], [92.75004578, 12.6738596], [92.74965668, 12.67355919], [92.74926758, 12.6733017], [92.74891663, 12.67301178], [92.7485733, 12.67269993], [92.7481308, 12.67247391], [92.74762726, 12.67226696], [92.74703217, 12.67222118], [92.74643707, 12.67217636], [92.74595642, 12.6719408], [92.74550629, 12.67165089], [92.74504089, 12.67138195], [92.74452209, 12.67116642], [92.74397278, 12.6711607], [92.7434845, 12.67138863], [92.74304962, 12.67167187], [92.74263763, 12.67195034], [92.74223328, 12.67222977], [92.74182892, 12.67246056], [92.74137115, 12.67250156], [92.74092865, 12.67241001], [92.74053192, 12.67222118], [92.74013519, 12.67214584], [92.73969269, 12.67233086], [92.73918152, 12.67251968], [92.73868561, 12.67272854], [92.73818207, 12.67273235], [92.73773956, 12.67251301], [92.73730469, 12.67229366], [92.73690033, 12.67209053], [92.73651123, 12.67205048], [92.73607635, 12.67243099], [92.73561096, 12.67276096], [92.7352829, 12.67309189], [92.73497009, 12.67336082], [92.7346344, 12.67356777], [92.73418427, 12.67365932], [92.73374176, 12.67385292], [92.73332977, 12.6739397], [92.73305511, 12.6741581], [92.73288727, 12.67441082], [92.73301697, 12.67473698], [92.73313141, 12.67519093], [92.7333374, 12.67566013], [92.7335968, 12.67609978], [92.73390961, 12.67645836], [92.73420715, 12.67674065], [92.73443604, 12.6770916], [92.73461914, 12.67742729], [92.73472595, 12.67783928], [92.7348175, 12.67832947], [92.73491669, 12.67889023], [92.73505402, 12.6794796], [92.73529816, 12.6799612], [92.73557281, 12.68031025], [92.73578644, 12.68063068], [92.73593903, 12.68096161], [92.73612213, 12.68126011], [92.73625183, 12.68161964], [92.73628235, 12.68204212], [92.73622894, 12.6824913], [92.73613739, 12.68293095], [92.73609161, 12.68336201], [92.7359848, 12.68372154], [92.73586273, 12.68403244], [92.73583221, 12.68435097], [92.73578644, 12.68467045], [92.73561859, 12.68498039], [92.73551941, 12.68539047], [92.7352829, 12.68584061], [92.73501587, 12.6863699], [92.73472595, 12.68693066], [92.73443604, 12.68750095], [92.73416901, 12.68805885], [92.73387909, 12.68859482], [92.73353577, 12.68908215], [92.73310852, 12.6894989], [92.73269653, 12.68992996], [92.7322464, 12.69027042], [92.73082733, 12.69139099], [92.73027802, 12.69139099], [92.73000336, 12.69167137], [92.72972107, 12.69167137], [92.72888947, 12.69083023], [92.72861481, 12.69083309], [92.72808838, 12.69127274], [92.72782135, 12.69165993], [92.72782135, 12.69201088], [92.7279892, 12.69237137], [92.72805023, 12.69276142], [92.72811127, 12.69313908], [92.72826385, 12.69347191], [92.72836304, 12.69388199], [92.72850037, 12.69434929], [92.72865295, 12.69487095], [92.72888184, 12.69538021], [92.72908783, 12.69588089], [92.72919464, 12.69644833], [92.72930908, 12.69699955], [92.7294693, 12.69744873], [92.72973633, 12.69779968], [92.73005676, 12.69808006], [92.73053741, 12.69817066], [92.73107147, 12.69812965], [92.73153687, 12.69830132], [92.73200989, 12.69845009], [92.7325058, 12.6985836], [92.73297882, 12.69861126], [92.73337555, 12.69861126], [92.73369598, 12.69860935], [92.7339859, 12.69861126], [92.73432922, 12.69863033], [92.73474121, 12.69874096], [92.73833466, 12.69916725], [92.73860931, 12.69944477], [92.73916626, 12.69944096], [92.73944092, 12.69972992], [92.73972321, 12.69972992], [92.73999023, 12.70000172], [92.7408371, 12.70000172], [92.74111176, 12.70028019], [92.74223328, 12.69917202], [92.74250031, 12.69916725], [92.74277496, 12.69944477], [92.74304962, 12.69944096], [92.74305725, 12.69972134], [92.74194336, 12.70083141], [92.74194336, 12.70111179], [92.74137878, 12.701581], [92.74095154, 12.70205975], [92.74069214, 12.70265865], [92.7405014, 12.70334339], [92.74044037, 12.7039814], [92.74061584, 12.70437145], [92.74076843, 12.70471001], [92.74082947, 12.70508003], [92.7408371, 12.70548534], [92.74079895, 12.70591068], [92.74066162, 12.70633125], [92.74057007, 12.70672035], [92.7405014, 12.70705128], [92.74048615, 12.7073307], [92.74042511, 12.707757], [92.74030304, 12.70795059], [92.74012756, 12.70814037], [92.74002838, 12.70842075], [92.73999023, 12.70880127], [92.7399292, 12.70919991], [92.73976135, 12.70954895], [92.73972321, 12.70993423], [92.73972321, 12.71031189], [92.73968506, 12.71068382], [92.7395401, 12.71103859], [92.73943329, 12.71143055], [92.73932648, 12.71182632], [92.73950195, 12.71224976], [92.73963928, 12.71265793], [92.73966217, 12.71302509], [92.73957825, 12.71337128], [92.73951721, 12.71373081], [92.73964691, 12.71412086], [92.73977661, 12.71458435], [92.73972321, 12.71471119], [92.73999023, 12.71500111], [92.73999786, 12.71555424], [92.74028015, 12.71582985], [92.74028015, 12.71666718], [92.74055481, 12.71694469], [92.74028015, 12.71722031], [92.74028015, 12.71805477], [92.74055481, 12.71833324], [92.74054718, 12.71944046], [92.7408371, 12.71972084], [92.7408371, 12.72028065], [92.74111176, 12.72056198], [92.74111176, 12.72084045], [92.7416687, 12.72139072], [92.74388885, 12.72138882], [92.74412537, 12.72162628], [92.7444458, 12.72194481], [92.74583435, 12.72194481], [92.74610901, 12.72222328], [92.74611664, 12.72249889], [92.74582672, 12.72277927], [92.74555206, 12.72277927], [92.74504089, 12.72263622], [92.74481201, 12.72277927], [92.74472046, 12.72361088], [92.7444458, 12.7239027], [92.74416351, 12.72388935], [92.7436142, 12.72444534], [92.74305725, 12.72444534], [92.74263, 12.72437], [92.74223328, 12.72422886], [92.74147797, 12.72447968], [92.74124146, 12.72528553], [92.7409668, 12.72614288], [92.74089813, 12.72722054], [92.7408371, 12.72787094], [92.74057007, 12.72837925], [92.74030304, 12.7288599], [92.73996735, 12.72918129], [92.73977661, 12.72957993], [92.73995972, 12.73022747], [92.7400589, 12.73069477], [92.74021149, 12.73110008], [92.74015808, 12.7314806], [92.73999786, 12.73166561], [92.73972321, 12.73194122], [92.73972321, 12.73250008], [92.73944092, 12.73357105], [92.73954773, 12.73393059], [92.73954773, 12.73440075], [92.73944092, 12.73499966], [92.7388916, 12.73499966], [92.73873138, 12.73464203], [92.73861694, 12.73419094], [92.73867035, 12.73359108], [92.73867798, 12.73318958], [92.73869324, 12.73269844], [92.73858643, 12.73246956], [92.7383728, 12.73249054], [92.73797607, 12.73316956], [92.73806, 12.73359108], [92.73816681, 12.73397923], [92.73825836, 12.73438931], [92.73828888, 12.73486996], [92.73832703, 12.73556137], [92.73832703, 12.7358408], [92.73860931, 12.73610973], [92.73860931, 12.7369442], [92.7388916, 12.73722172], [92.7388916, 12.73750019], [92.73860931, 12.73778057], [92.73860931, 12.73805618], [92.73805237, 12.73861027], [92.73777771, 12.73861027], [92.73750305, 12.7383337], [92.73694611, 12.7383337], [92.73638916, 12.73816967], [92.73571014, 12.73838043], [92.7351532, 12.73876095], [92.73477173, 12.73912811], [92.73452759, 12.73944187], [92.73429108, 12.73973083], [92.73401642, 12.74003887], [92.7337265, 12.7404108], [92.73339844, 12.74079132], [92.73307037, 12.74117565], [92.73274994, 12.74157143], [92.73240662, 12.74191856], [92.73207092, 12.74221992], [92.73175049, 12.74250984], [92.73145294, 12.7428112], [92.73120117, 12.74317074], [92.73106384, 12.74363136], [92.73086548, 12.74405956], [92.73073578, 12.74451065], [92.73059082, 12.74493694], [92.73055267, 12.74540043], [92.73049164, 12.7458601], [92.73031616, 12.74629116], [92.73021698, 12.74678135], [92.7300415, 12.74722958], [92.73002625, 12.74767017], [92.73013306, 12.74804974], [92.73023224, 12.7483902], [92.73027039, 12.74874115], [92.73027802, 12.74912167], [92.7303009, 12.74953938], [92.7303772, 12.74999046], [92.73048401, 12.75047779], [92.73055267, 12.75094891], [92.73060608, 12.75142956], [92.73069, 12.75189114], [92.73085785, 12.75226021], [92.73103333, 12.75260162], [92.73112488, 12.75295734], [92.73121643, 12.75330067], [92.73129272, 12.75365925], [92.73110199, 12.75399685], [92.73085022, 12.75434113], [92.73062897, 12.75473022], [92.7304306, 12.7551384], [92.73026276, 12.75561047], [92.7300415, 12.75607967], [92.72992706, 12.75654697], [92.72972107, 12.75694084], [92.72947693, 12.75730133], [92.72930908, 12.75764084], [92.72915649, 12.7579689], [92.72901154, 12.75821972], [92.72888184, 12.75848198], [92.72875214, 12.75875092], [92.72860718, 12.7590704], [92.72846985, 12.75946045], [92.72832489, 12.75989723], [92.72814178, 12.76038265], [92.72802734, 12.76097775], [92.7278595, 12.76159954], [92.7277298, 12.76231766], [92.72753906, 12.76299477], [92.72741699, 12.76366043], [92.727211, 12.76424122], [92.72693634, 12.76476097], [92.72666168, 12.76529026], [92.72639465, 12.76585484], [92.72619629, 12.76646996], [92.72612, 12.76712036], [92.72611237, 12.76773071], [92.72609711, 12.76825047], [92.72600555, 12.76869488], [92.72587585, 12.76910019], [92.72582245, 12.76952171], [92.72575378, 12.76990032], [92.7256012, 12.77022171], [92.72554016, 12.77054119], [92.72543335, 12.77082062], [92.72528076, 12.77108955], [92.72512817, 12.77143002], [92.72499084, 12.7718811], [92.724823, 12.77242088], [92.7246933, 12.77305031], [92.7244873, 12.77365017], [92.72441101, 12.77423954], [92.72428894, 12.77471638], [92.72418976, 12.7751236], [92.72416687, 12.7755003], [92.72415161, 12.77585983], [92.72406006, 12.77620697], [92.72392273, 12.77655983], [92.72386932, 12.77696133], [92.72377777, 12.77731037], [92.72363281, 12.77758121], [92.72354889, 12.77780437], [92.7234726, 12.77804089], [92.72354889, 12.77845192], [92.72342682, 12.77880955], [92.72315979, 12.77916145], [92.72323608, 12.77975082], [92.72310638, 12.78026772], [92.72306061, 12.78079033], [92.72305298, 12.78126907], [92.72299194, 12.78166294], [92.72274017, 12.78197956], [92.72257233, 12.78238106], [92.72252655, 12.78291035], [92.72262573, 12.78348637], [92.72249603, 12.78393078], [92.72232819, 12.78434753], [92.72218323, 12.78474045], [92.72198486, 12.78505898], [92.7219162, 12.78540993], [92.7217865, 12.78571129], [92.72168732, 12.78600025], [92.72162628, 12.7863102], [92.72149658, 12.78656101], [92.72141266, 12.78682995], [92.72138977, 12.78713989], [92.72134399, 12.78744984], [92.72117615, 12.78774071], [92.72112274, 12.7881403], [92.72110748, 12.78862095], [92.72110748, 12.78919125], [92.72112274, 12.78981972], [92.72119904, 12.79045582], [92.72136688, 12.79099178], [92.72154999, 12.79145908], [92.72180939, 12.79174137], [92.72196198, 12.79208088], [92.72212219, 12.79241085], [92.72229767, 12.79275131], [92.72253418, 12.79309082], [92.72278595, 12.79345989], [92.72305298, 12.79384041], [92.7232666, 12.79421043], [92.72344208, 12.79492092], [92.72364807, 12.7953558], [92.72377777, 12.79560375], [92.72386169, 12.79585075], [92.72383118, 12.79610062], [92.72381592, 12.79628563], [92.72364807, 12.79647064], [92.7233963, 12.79638863], [92.72322845, 12.79623985], [92.72289276, 12.79607868], [92.72255707, 12.79592991], [92.72219849, 12.79587078], [92.72167969, 12.79597569], [92.72148895, 12.79620171], [92.72123718, 12.79662132], [92.72106934, 12.79702854], [92.72096252, 12.79744053], [92.72079468, 12.79942703], [92.72093201, 12.79994202], [92.7210083, 12.80059814], [92.72107697, 12.80134964], [92.72110748, 12.80211067], [92.72106171, 12.80286598], [92.72087097, 12.80358791], [92.72038269, 12.80549812], [92.72049713, 12.80599117], [92.72075653, 12.80644894], [92.72075653, 12.80723], [92.72081757, 12.80802059], [92.72086334, 12.80836964], [92.72098541, 12.80872059], [92.72104645, 12.80908966], [92.72117615, 12.80947113], [92.72128296, 12.80978107], [92.72155762, 12.8100996], [92.72194672, 12.81100178], [92.72197723, 12.81169987], [92.72203064, 12.81227016], [92.72202301, 12.81265736], [92.72211456, 12.8129921], [92.72215271, 12.8132906], [92.72207642, 12.81360054], [92.7219696, 12.81391144], [92.72190094, 12.81431389], [92.72171021, 12.81474209], [92.7216568, 12.81527138], [92.72166443, 12.81579971], [92.72170258, 12.81626034], [92.72186279, 12.81660175], [92.72193909, 12.81692791], [92.72200012, 12.81723976], [92.7221756, 12.8174963], [92.72225189, 12.81780815], [92.72238159, 12.8180809], [92.7224884, 12.81838036], [92.72255707, 12.81872559], [92.72271729, 12.81904984], [92.72277069, 12.81948471], [92.72280884, 12.81997108], [92.72302246, 12.82038784], [92.72315979, 12.82082272], [92.72329712, 12.82121277], [92.72333527, 12.82156181], [92.72332001, 12.82188129], [92.72323608, 12.82219982], [92.72309113, 12.82250977], [92.72306061, 12.82290173], [92.72309113, 12.82332134], [92.72325897, 12.82373142], [92.72335815, 12.82418728], [92.72350311, 12.82463169], [92.72358704, 12.8251009], [92.72364044, 12.82557106], [92.72377014, 12.82598972], [92.72386932, 12.82637119], [92.72389221, 12.82674408], [92.7239151, 12.82708359], [92.72402191, 12.82738018], [92.72416687, 12.82767868], [92.72438049, 12.82797146], [92.72477722, 12.82817078], [92.72524261, 12.8283596], [92.72570801, 12.82856083], [92.72618866, 12.82865906], [92.72657013, 12.82884121], [92.72690582, 12.82898045], [92.72717285, 12.82918072], [92.72737885, 12.82944107], [92.72759247, 12.82975101], [92.72779846, 12.83011055], [92.72805023, 12.83049965], [92.72833252, 12.8309269], [92.72860718, 12.83140087], [92.72888947, 12.83191109], [92.72917175, 12.83243084], [92.72943878, 12.83296204], [92.72966766, 12.83350945], [92.72975922, 12.83409214], [92.72989655, 12.8346014], [92.7302475, 12.83489513], [92.73062134, 12.83520889], [92.73108673, 12.83544159], [92.73129272, 12.83537483], [92.73165131, 12.83525944], [92.73206329, 12.83493996], [92.73223877, 12.83457088], [92.73239899, 12.83425045], [92.73249817, 12.8338604], [92.73265076, 12.8333807], [92.73293304, 12.83285046], [92.73303986, 12.83217144], [92.73306274, 12.8314209], [92.73306274, 12.8306303], [92.73310089, 12.82985115], [92.73331451, 12.82914925], [92.73348999, 12.82844925], [92.73364258, 12.8277607], [92.73383331, 12.82711983], [92.73388672, 12.82637119], [92.73394012, 12.82562065], [92.73416138, 12.82495117], [92.73439026, 12.8243103], [92.73451996, 12.82372189], [92.73468781, 12.82322502], [92.73477173, 12.82273102], [92.73497009, 12.82234097], [92.7351532, 12.82196045], [92.73535156, 12.82160854], [92.73563385, 12.82131481], [92.7359314, 12.82100105], [92.73616791, 12.82056999], [92.73640442, 12.82012081], [92.73661041, 12.81964016], [92.73658752, 12.81912136], [92.73638153, 12.81862068], [92.73612213, 12.81813145], [92.73595428, 12.8176136], [92.73606873, 12.81707382], [92.73610687, 12.81648064], [92.73610687, 12.81586075], [92.73618317, 12.81524181], [92.73634338, 12.81466866], [92.73638916, 12.8141613], [92.73638916, 12.81333447], [92.73686218, 12.81237698], [92.73742676, 12.81223106], [92.73815918, 12.81223297], [92.73822021, 12.81156254], [92.7372818, 12.81122589], [92.73722076, 12.81056023], [92.73750305, 12.81027985], [92.73777771, 12.81027985], [92.73860931, 12.81112099], [92.73860931, 12.8116703], [92.73890686, 12.81210136], [92.7388916, 12.81250191], [92.73889923, 12.81276035], [92.73905182, 12.81309891], [92.73916626, 12.81348038], [92.7390213, 12.8137579], [92.73908234, 12.81427288], [92.73893738, 12.81472015], [92.73923492, 12.8155241], [92.73929596, 12.815732], [92.73921204, 12.81607056], [92.73931885, 12.81649017], [92.73920441, 12.81716728], [92.73940277, 12.81751156], [92.7395401, 12.81803131], [92.73934174, 12.81857967], [92.73948669, 12.81906128], [92.73929596, 12.81954002], [92.73919678, 12.81987], [92.73893738, 12.82030106], [92.73889923, 12.82068634], [92.73890686, 12.82096004], [92.73867035, 12.82128143], [92.73851013, 12.8214407], [92.73848724, 12.82185078], [92.73853302, 12.82216072], [92.7383728, 12.82250118], [92.73833466, 12.82293606], [92.73815155, 12.82329082], [92.73792267, 12.8237114], [92.73786926, 12.82423973], [92.73810577, 12.82482147], [92.73826599, 12.82526112], [92.7383194, 12.8257103], [92.73828888, 12.82616138], [92.7381134, 12.82648659], [92.7381134, 12.82719326], [92.73792267, 12.82771969], [92.73797607, 12.82831001], [92.73803711, 12.82890511], [92.73810577, 12.82949066], [92.73831177, 12.83002853], [92.7385025, 12.83052063], [92.7387085, 12.83093071], [92.73892212, 12.83128357], [92.73914337, 12.83160114], [92.73932648, 12.83196068], [92.73947906, 12.83234024], [92.7396698, 12.83269978], [92.73976898, 12.83311653], [92.73993683, 12.83351135], [92.73999023, 12.83398056], [92.74001312, 12.83453178], [92.74008179, 12.8351469], [92.74035645, 12.83579159], [92.74074554, 12.83636189], [92.74108124, 12.83635521], [92.74138641, 12.83600044], [92.74166107, 12.83554173], [92.74188995, 12.83507919], [92.74194336, 12.83461189], [92.74195099, 12.83417034], [92.74201202, 12.83374977], [92.7421875, 12.83334923], [92.74223328, 12.83284092], [92.74226379, 12.83227444], [92.74238586, 12.8316946], [92.74225616, 12.83110046], [92.74224854, 12.83054066], [92.74234009, 12.83002186], [92.74236298, 12.8295126], [92.74246979, 12.82901192], [92.74250031, 12.82845402], [92.74250031, 12.82785702], [92.74250031, 12.82725525], [92.74250031, 12.82666683], [92.7425766, 12.82546997], [92.74269104, 12.82503033], [92.74279785, 12.82492065], [92.74291992, 12.82470036], [92.74346161, 12.82448101], [92.74388885, 12.82555676], [92.74388885, 12.8260994], [92.74419403, 12.82681274], [92.7441864, 12.82730961], [92.74415588, 12.82778072], [92.74416351, 12.82805538], [92.7444458, 12.8283329], [92.74450684, 12.82882118], [92.74449921, 12.8292923], [92.7444458, 12.82977962], [92.7444458, 12.83027935], [92.7444458, 12.83075142], [92.74443054, 12.83117962], [92.74433899, 12.83151913], [92.74407196, 12.83180237], [92.74391937, 12.8322258], [92.74391174, 12.83271313], [92.74391174, 12.83321285], [92.74398804, 12.83370304], [92.74410248, 12.83417225], [92.74406433, 12.83462334], [92.74414062, 12.83510208], [92.74414062, 12.83559418], [92.74414062, 12.83615303], [92.74415588, 12.83679485], [92.74416351, 12.83750439], [92.74420929, 12.83821964], [92.74442291, 12.83887196], [92.74471283, 12.83946037], [92.74498749, 12.84001064], [92.74526978, 12.84055138], [92.74556732, 12.84108925], [92.74598694, 12.84152031], [92.74652863, 12.84178734], [92.74679565, 12.84185028], [92.74707031, 12.84191418], [92.74752808, 12.84188938], [92.7478714, 12.84182072], [92.7481308, 12.84192562], [92.74839783, 12.84208298], [92.74858856, 12.84245205], [92.74890137, 12.84277058], [92.74929047, 12.84305382], [92.74968719, 12.84333038], [92.75007629, 12.8436327], [92.75041199, 12.84394741], [92.7508316, 12.84401131], [92.75112152, 12.84405041], [92.751091, 12.84427071], [92.75100708, 12.84459019], [92.75118256, 12.84485722], [92.75160217, 12.84502983], [92.75202942, 12.84532166], [92.75271606, 12.84535122], [92.75292969, 12.84519768], [92.75345612, 12.84543991], [92.75352478, 12.84565926], [92.75305176, 12.84611225], [92.75305176, 12.84694386], [92.75327301, 12.84760094], [92.75365448, 12.84797668], [92.75434875, 12.84805393], [92.75485229, 12.84774685], [92.75537109, 12.84749985], [92.75585175, 12.8472271], [92.75627136, 12.84700108], [92.75668335, 12.84692192], [92.75704193, 12.84694195], [92.75733948, 12.84696007], [92.75757599, 12.84705067], [92.75779724, 12.8471899], [92.75807953, 12.84730721], [92.75823212, 12.84763527], [92.75845337, 12.84794331], [92.75860596, 12.84826183], [92.75874329, 12.84857178], [92.75894928, 12.84881783], [92.75911713, 12.8491087], [92.75912476, 12.84947586], [92.75896454, 12.84986401], [92.75887299, 12.85031128], [92.7587204, 12.85073662], [92.75862885, 12.85116959], [92.75861359, 12.85163021], [92.75860596, 12.85211086], [92.75860596, 12.85262203], [92.75865173, 12.85311604], [92.75881958, 12.85355186], [92.75898743, 12.85398674], [92.75913239, 12.85441113], [92.75917053, 12.8548851], [92.75915527, 12.85538387], [92.75908661, 12.85588074], [92.75891876, 12.85634995], [92.75891876, 12.85676956], [92.75905609, 12.85714054], [92.75913239, 12.85749722], [92.75919342, 12.85783195], [92.75931549, 12.85811234], [92.75946045, 12.85838127], [92.75965118, 12.85862923], [92.75989532, 12.85887623], [92.76055908, 12.85944462], [92.76083374, 12.85944462], [92.7611084, 12.8591671], [92.76139069, 12.85917187], [92.76194763, 12.85861111], [92.76194763, 12.85694504], [92.76219177, 12.85496235], [92.76275635, 12.85379124], [92.76289368, 12.85317135], [92.76333618, 12.85250092], [92.76333618, 12.85222054], [92.76472473, 12.85083294], [92.76514435, 12.85042], [92.76570129, 12.85000992], [92.7664032, 12.84925079], [92.76667786, 12.84877014], [92.76689148, 12.84822273], [92.76786804, 12.84739113], [92.76843262, 12.84691048], [92.76918793, 12.84669971], [92.76943207, 12.84633064], [92.76965332, 12.8460207], [92.76982117, 12.84573936], [92.76999664, 12.84547043], [92.77021027, 12.84521198], [92.77046967, 12.84492302], [92.77077484, 12.84459496], [92.77110291, 12.8442297], [92.77147675, 12.84386063], [92.7719574, 12.8435421], [92.7724762, 12.84320927], [92.77300262, 12.8428297], [92.77347565, 12.84241104], [92.77388, 12.84193039], [92.77416992, 12.84143066], [92.77436829, 12.84093189], [92.77442932, 12.84043121], [92.77440643, 12.83994675], [92.77432251, 12.83949184], [92.77420044, 12.83906078], [92.77410889, 12.8386116], [92.7739563, 12.83816147], [92.77387238, 12.83764076], [92.77377319, 12.83707142], [92.77360535, 12.83648777], [92.77342224, 12.83586121], [92.77328491, 12.8352356], [92.77313995, 12.83463001], [92.77303314, 12.83403969], [92.77292633, 12.83348083], [92.77301788, 12.83297062], [92.77310944, 12.8324852], [92.77324677, 12.83204079], [92.77334595, 12.83160114], [92.77346039, 12.83119106], [92.77359772, 12.83082199], [92.77372742, 12.83047104], [92.77387238, 12.83018398], [92.7740097, 12.82989597], [92.77414703, 12.82963181], [92.77428436, 12.82935619], [92.77446747, 12.82911015], [92.77469635, 12.82885933], [92.77497864, 12.82859039], [92.77529907, 12.82830143], [92.77568054, 12.82799053], [92.77610779, 12.82772923], [92.77654266, 12.82747078], [92.77698517, 12.82721424], [92.7774353, 12.82698631], [92.77790833, 12.82678986], [92.77838898, 12.82657146], [92.77882385, 12.82631111], [92.77922821, 12.82604027], [92.77958679, 12.82573891], [92.77986145, 12.82541084], [92.78005219, 12.82507133], [92.78018188, 12.82476139], [92.78025818, 12.82445621], [92.78028107, 12.82413006], [92.78029633, 12.82376099], [92.7803421, 12.82337093], [92.78044891, 12.82299137], [92.78051758, 12.82261658], [92.78056335, 12.82224083], [92.78059387, 12.82188511], [92.78068542, 12.82153702], [92.78077698, 12.82119179], [92.78082275, 12.82082081], [92.78083038, 12.82041073], [92.7808609, 12.81997299], [92.78094482, 12.81950378], [92.78109741, 12.81901073], [92.78122711, 12.81851387], [92.78134918, 12.81806278], [92.78138733, 12.81763172], [92.78140259, 12.81724739], [92.78143311, 12.81690979], [92.78147888, 12.81657028], [92.78147125, 12.81617641], [92.78161621, 12.81575203], [92.78166199, 12.81525135], [92.78166962, 12.81472015], [92.78166962, 12.8141613], [92.78166962, 12.81361198], [92.78166962, 12.81305408], [92.78166962, 12.81248569], [92.78166962, 12.81191158], [92.78167725, 12.8113327], [92.78173065, 12.81076145], [92.78188324, 12.81025028], [92.78194427, 12.80971527], [92.78194427, 12.80916786], [92.78166962, 12.80889034], [92.78166962, 12.80833054], [92.78166199, 12.8080759], [92.78177643, 12.80764103], [92.78194427, 12.80749893], [92.78221893, 12.80749893], [92.78305817, 12.8083334], [92.78333282, 12.80833054], [92.78388977, 12.80889034], [92.78444672, 12.80889034], [92.78472137, 12.80916977], [92.78498077, 12.80931091], [92.78521729, 12.80952835], [92.78526306, 12.8096714], [92.78555298, 12.80972099], [92.78610992, 12.81027985], [92.78618622, 12.81083107], [92.78591156, 12.81101131], [92.78528595, 12.81083107], [92.78388977, 12.80944347], [92.78333282, 12.80944347], [92.78333282, 12.80972099], [92.78305817, 12.81000042], [92.78305817, 12.81194401], [92.78333282, 12.81222153], [92.78333282, 12.8133316], [92.78330231, 12.81402016], [92.78320313, 12.81459236], [92.78309631, 12.81515312], [92.78305817, 12.81571102], [92.78305817, 12.81639004], [92.78305817, 12.81666565], [92.78277588, 12.81692791], [92.78277588, 12.81750011], [92.78250122, 12.81777763], [92.78250122, 12.81861019], [92.78221893, 12.81888771], [92.78222656, 12.81972027], [92.78193665, 12.81999969], [92.78194427, 12.82055569], [92.78166962, 12.82083035], [92.78166962, 12.82139111], [92.78138733, 12.82166576], [92.78138733, 12.82361126], [92.78193665, 12.82417107], [92.78222656, 12.82389069], [92.78305817, 12.82389069], [92.78363037, 12.82421017], [92.78380585, 12.82448959], [92.78354645, 12.82466793], [92.78312683, 12.82483196], [92.78266144, 12.82497597], [92.78216553, 12.82510281], [92.78173065, 12.82531071], [92.78137207, 12.82557487], [92.78111267, 12.82583332], [92.78083038, 12.82583046], [92.78028107, 12.82639122], [92.78028107, 12.82667065], [92.77944183, 12.8275013], [92.7783432, 12.8275013], [92.77777863, 12.8280592], [92.77749634, 12.82805538], [92.77722168, 12.8283329], [92.77694702, 12.8283329], [92.77666473, 12.82861137], [92.77639008, 12.82861137], [92.77583313, 12.82916737], [92.77555847, 12.82915974], [92.77471924, 12.83000088], [92.77471924, 12.83027935], [92.77443695, 12.83055973], [92.77443695, 12.83111095], [92.77416992, 12.83139133], [92.77416992, 12.83250141], [92.77388763, 12.83278179], [92.77388763, 12.83529091], [92.77416992, 12.83555508], [92.77416992, 12.83583069], [92.77443695, 12.83611202], [92.77444458, 12.83666801], [92.77471924, 12.83694267], [92.77471924, 12.83721924], [92.77500153, 12.83749962], [92.77500153, 12.8386116], [92.77527618, 12.83889008], [92.77527618, 12.83972168], [92.77555847, 12.84000015], [92.77555847, 12.84138966], [92.77527618, 12.84166622], [92.77527618, 12.84222031], [92.77500153, 12.84249973], [92.77500153, 12.84277821], [92.77443695, 12.84333038], [92.77416992, 12.84361172], [92.77388763, 12.84361172], [92.77361298, 12.84389019], [92.77333069, 12.84389019], [92.77305603, 12.84417057], [92.77249908, 12.84417057], [92.77194214, 12.84472179], [92.77166748, 12.84472179], [92.77111053, 12.84528065], [92.77111053, 12.84555626], [92.77054596, 12.84611034], [92.77054596, 12.84638977], [92.77027893, 12.84666634], [92.77028656, 12.84694195], [92.77004242, 12.84752083], [92.76978302, 12.84799004], [92.76950836, 12.8484602], [92.76938629, 12.84899139], [92.76915741, 12.84950638], [92.76889801, 12.85000324], [92.76869202, 12.85050201], [92.76876831, 12.85112], [92.76883698, 12.85173035], [92.76879883, 12.85230923], [92.76899719, 12.85281086], [92.76916504, 12.85328484], [92.76931, 12.85375023], [92.76943207, 12.85424709], [92.76951599, 12.8547802], [92.76957703, 12.85534096], [92.76969147, 12.85589886], [92.76976013, 12.85645103], [92.76996613, 12.85692024], [92.77023315, 12.85731888], [92.77036285, 12.85776138], [92.77036285, 12.85821724], [92.77028656, 12.8586607], [92.77018738, 12.8591013], [92.76999664, 12.85946083], [92.76981354, 12.85980511], [92.76972961, 12.86019325], [92.76965332, 12.86058044], [92.76948547, 12.86091995], [92.7694397, 12.86129093], [92.76946259, 12.86167431], [92.76958466, 12.86209106], [92.76979065, 12.86257172], [92.77025604, 12.86294842], [92.77081299, 12.86330414], [92.77105713, 12.86336994], [92.77142334, 12.86347008], [92.77194214, 12.86318111], [92.77242279, 12.86284447], [92.7729187, 12.86255169], [92.77345276, 12.86236668], [92.77392578, 12.86216927], [92.77427673, 12.86198044], [92.77458191, 12.86192131], [92.77482605, 12.8618412], [92.77506256, 12.86177921], [92.77539063, 12.86190891], [92.77574921, 12.86203003], [92.77610016, 12.86224174], [92.77641296, 12.86254025], [92.77667236, 12.86294174], [92.77694702, 12.86340046], [92.77729797, 12.86382771], [92.77791595, 12.86409855], [92.77861023, 12.86417007], [92.78028107, 12.86249924], [92.78028107, 12.8622303], [92.78083038, 12.86166954], [92.78083038, 12.86083126], [92.78111267, 12.8605547], [92.78111267, 12.85833073], [92.78119659, 12.8580761], [92.78111267, 12.85778236], [92.78111267, 12.85639095], [92.78083038, 12.85611057], [92.78083038, 12.85333347], [92.78074646, 12.85309792], [92.78083038, 12.8527813], [92.78083038, 12.85111141], [92.78105164, 12.85058403], [92.78098297, 12.84925079], [92.78083038, 12.84889126], [92.78083038, 12.84832954], [92.78111267, 12.84805679], [92.78144836, 12.84812927], [92.78150177, 12.84841728], [92.78153992, 12.84867191], [92.78159332, 12.85058022], [92.78138733, 12.85139084], [92.78138733, 12.85361099], [92.78166962, 12.85388947], [92.78166962, 12.85472107], [92.78194427, 12.85499859], [92.78193665, 12.85611057], [92.78222656, 12.85639095], [92.78222656, 12.85806179], [92.78212738, 12.85865021], [92.78222656, 12.85911274], [92.78235626, 12.85962963], [92.78259277, 12.86012745], [92.78294373, 12.86049366], [92.78330994, 12.86081123], [92.78370667, 12.86110878], [92.7841568, 12.86139202], [92.78466797, 12.86166954], [92.78527069, 12.86190033], [92.7859726, 12.86194992], [92.78666687, 12.86194134], [92.78722382, 12.86194324], [92.78749847, 12.86166763], [92.78778076, 12.86166954], [92.78806305, 12.86139202], [92.78916931, 12.86139202], [92.78943634, 12.86166954], [92.78971863, 12.86166763], [92.79033661, 12.86196423], [92.79080963, 12.86217117], [92.79132843, 12.8622303], [92.79183197, 12.86226654], [92.79225922, 12.86248112], [92.79260254, 12.86271095], [92.79286957, 12.86283016], [92.79316711, 12.86297131], [92.79323578, 12.86322021], [92.79322052, 12.86355019], [92.79308319, 12.86390114], [92.7929306, 12.86427021], [92.7926712, 12.86467648], [92.79264069, 12.86530972], [92.79278564, 12.86598015], [92.79294586, 12.86662006], [92.79281616, 12.86713982], [92.79270172, 12.86766243], [92.79254913, 12.86815166], [92.79257202, 12.8686552], [92.79277039, 12.86914253], [92.7930069, 12.86964035], [92.79335785, 12.87003899], [92.79358673, 12.8704834], [92.79371643, 12.87094116], [92.79386139, 12.87136459], [92.79389191, 12.87185097], [92.79384613, 12.87244129], [92.79361725, 12.87302017], [92.79338837, 12.87359047], [92.79329681, 12.87415028], [92.79309845, 12.87454891], [92.7930603, 12.87492085], [92.79305267, 12.87525272], [92.79304504, 12.87558174], [92.79305267, 12.87593937], [92.79310608, 12.8763504], [92.7933197, 12.87666035], [92.79355621, 12.87697029], [92.7935791, 12.87732983], [92.79341888, 12.8776989], [92.79325867, 12.87811756], [92.7930603, 12.87852192], [92.7928772, 12.87896156], [92.79279327, 12.87943077], [92.7928009, 12.87992096], [92.79290771, 12.8803997], [92.79308319, 12.88087559], [92.79335785, 12.88134956], [92.7937088, 12.88183975], [92.79394531, 12.88237762], [92.79337311, 12.88282013], [92.79315186, 12.88293171], [92.79298401, 12.88323021], [92.79276276, 12.88351059], [92.79249573, 12.88380909], [92.79222107, 12.88415146], [92.7919693, 12.88455009], [92.79176331, 12.88495064], [92.79154968, 12.88524055], [92.79136658, 12.88544846], [92.79131317, 12.8859129], [92.79128265, 12.8865633], [92.79123688, 12.8871212], [92.79125977, 12.88773155], [92.79117584, 12.88824654], [92.79131317, 12.88902187], [92.79168701, 12.88952065], [92.79190826, 12.88985443], [92.79217529, 12.89009094], [92.7924118, 12.8901701], [92.79283142, 12.89032841], [92.79321289, 12.89055061], [92.79358673, 12.89075184], [92.79402924, 12.89083576], [92.794487, 12.89092255], [92.79494476, 12.89107323], [92.79544067, 12.89119053], [92.79597473, 12.89138699], [92.79651642, 12.89160156], [92.79696655, 12.89191246], [92.79742432, 12.89223957], [92.79786682, 12.89258194], [92.79836273, 12.89295101], [92.79886627, 12.89339066], [92.79933167, 12.89395809], [92.79973602, 12.89466286], [92.80007935, 12.89478111], [92.80042267, 12.89492035], [92.80076599, 12.89514828], [92.80111694, 12.89544201], [92.80148315, 12.89576054], [92.80193329, 12.8960104], [92.80236053, 12.89626026], [92.80276489, 12.89655685], [92.80316162, 12.89687347], [92.80365753, 12.89708996], [92.80419922, 12.89720154], [92.80434418, 12.89719009], [92.80474091, 12.8971653], [92.80522156, 12.89698696], [92.80570984, 12.89695072], [92.80621338, 12.89693928], [92.80670929, 12.89695072], [92.80718994, 12.89699173], [92.80763245, 12.89718056], [92.80810547, 12.89721966], [92.80857086, 12.89721966], [92.80901337, 12.8972311], [92.80947876, 12.89728832], [92.80993652, 12.89745045], [92.81043243, 12.89750004], [92.81069946, 12.89747715], [92.81095886, 12.89745235], [92.81145477, 12.89723969], [92.8119812, 12.89705086], [92.81253815, 12.89690971], [92.81305695, 12.89667034], [92.81357574, 12.89645863], [92.81414795, 12.89635086], [92.81468201, 12.89618301], [92.81520844, 12.89611912], [92.8157196, 12.89610958], [92.81620789, 12.89610958], [92.81668091, 12.89610958], [92.81715393, 12.89611244], [92.81761932, 12.89611244], [92.81808472, 12.89611244], [92.81855011, 12.89611244], [92.81902313, 12.89611244], [92.81948853, 12.89610767], [92.81996155, 12.89608002], [92.82042694, 12.8959589], [92.82089233, 12.89582729], [92.8213501, 12.89571953], [92.82182312, 12.89578247], [92.82231903, 12.89581108], [92.82280731, 12.89577007], [92.82331848, 12.89563084], [92.82385254, 12.89552402], [92.82434845, 12.89534187], [92.82470703, 12.89501095], [92.82499695, 12.89460087], [92.82522583, 12.89416313], [92.82532501, 12.89366436], [92.82550812, 12.89325619], [92.82554626, 12.89281178], [92.82554626, 12.89237022], [92.82554626, 12.89194965], [92.82554626, 12.89155197], [92.82557678, 12.89118004], [92.82567596, 12.89085579], [92.82581329, 12.89054203], [92.82585907, 12.89018631], [92.82598877, 12.88984203], [92.82610321, 12.88947964], [92.82618713, 12.88910103], [92.82637024, 12.88875008], [92.82649994, 12.88836098], [92.82668304, 12.88796043], [92.82691193, 12.88753986], [92.82720184, 12.88710022], [92.82749939, 12.88658142], [92.82785797, 12.88604736], [92.82832336, 12.88560104], [92.82891083, 12.88528156], [92.82952118, 12.88503456], [92.83010101, 12.88490105], [92.83059692, 12.88470745], [92.83109283, 12.88467121], [92.8316803, 12.88500118], [92.83214569, 12.8852129], [92.83244324, 12.88510418], [92.83279419, 12.88502026], [92.83322144, 12.88505077], [92.83366394, 12.8852663], [92.83409882, 12.88552094], [92.83442688, 12.88589001], [92.83467102, 12.88629627], [92.83483887, 12.88664246], [92.83502197, 12.88694096], [92.83535767, 12.88717842], [92.83586121, 12.88733292], [92.83630371, 12.88749218], [92.83664703, 12.88763142], [92.83689117, 12.88778019], [92.83709717, 12.88792992], [92.83731842, 12.88807106], [92.83751678, 12.88824463], [92.83769226, 12.88844299], [92.83777618, 12.88873005], [92.837883, 12.88903999], [92.8380661, 12.88938046], [92.83831787, 12.88971233], [92.83863068, 12.89002037], [92.83898163, 12.89032078], [92.83921051, 12.89075184], [92.83943939, 12.89109993], [92.83969879, 12.89129162], [92.84033966, 12.89132977], [92.84122467, 12.89133263], [92.84149933, 12.89129162], [92.84196472, 12.89114761], [92.84224701, 12.89103889], [92.84249878, 12.89055634], [92.84278107, 12.89019108], [92.84282684, 12.88963032], [92.84284973, 12.88896179], [92.84291077, 12.88823128], [92.84300995, 12.88749027], [92.8430481, 12.88673115], [92.84305573, 12.88599491], [92.84299469, 12.88541794], [92.84285736, 12.88465023], [92.84266663, 12.88411236], [92.84246063, 12.88362026], [92.84208679, 12.88317966], [92.84172058, 12.88274956], [92.84144592, 12.88232136], [92.84130096, 12.8818903], [92.84115601, 12.88156414], [92.84107208, 12.88125038], [92.8409729, 12.88096046], [92.84085846, 12.88060856], [92.84075165, 12.8801899], [92.84056091, 12.8797617], [92.84037781, 12.87928963], [92.84026337, 12.87877178], [92.84018707, 12.8782711], [92.84020996, 12.87779522], [92.84028625, 12.87734795], [92.84041595, 12.87693977], [92.84059906, 12.87654114], [92.84088898, 12.87617016], [92.84125519, 12.87585068], [92.84172821, 12.87560654], [92.8423996, 12.87551975], [92.84311676, 12.87549019], [92.84348297, 12.87528992], [92.84387207, 12.87509155], [92.8443222, 12.87502766], [92.8447876, 12.87506199], [92.84519958, 12.87520313], [92.84558105, 12.8752737], [92.84591675, 12.87532043], [92.84619141, 12.87548065], [92.84651947, 12.87555027], [92.84689331, 12.87561131], [92.84728241, 12.8757], [92.84768677, 12.87581444], [92.84810638, 12.87590122], [92.84850311, 12.87607193], [92.84893799, 12.87611008], [92.84941101, 12.87613964], [92.8498764, 12.87627029], [92.85038757, 12.87637901], [92.85089874, 12.87648201], [92.85132599, 12.87667084], [92.85173798, 12.87685108], [92.85215759, 12.87693977], [92.85258484, 12.87701511], [92.85299683, 12.8771019], [92.85341644, 12.87720203], [92.85386658, 12.8772316], [92.85401154, 12.87722492], [92.85427094, 12.87721062], [92.854599, 12.87713814], [92.85660553, 12.87741184], [92.85716248, 12.87749195], [92.85771179, 12.87755108], [92.85822296, 12.87767601], [92.85871124, 12.87782192], [92.85917664, 12.87800026], [92.85968018, 12.8781004], [92.86016846, 12.87822056], [92.86064911, 12.87834167], [92.86113739, 12.87848282], [92.86164093, 12.87863064], [92.86213684, 12.87887001], [92.86268616, 12.87907124], [92.86322784, 12.87924194], [92.86368561, 12.87945843], [92.86405182, 12.87970924], [92.8644104, 12.87993526], [92.86485291, 12.8800602], [92.86547852, 12.8801012], [92.86608887, 12.88019466], [92.86675262, 12.88025188], [92.86740112, 12.88031101], [92.86808014, 12.88042927], [92.8687439, 12.88052654], [92.8693924, 12.88055229], [92.87002563, 12.88056183], [92.87062073, 12.88060856], [92.87114716, 12.88078499], [92.87166595, 12.88083267], [92.87214661, 12.88086891], [92.87260437, 12.88102627], [92.87309265, 12.88110161], [92.87354279, 12.88116074], [92.87393188, 12.88138676], [92.87431335, 12.88165092], [92.87467957, 12.88192654], [92.87496948, 12.88229084], [92.87518311, 12.88270855], [92.87531281, 12.88317108], [92.87549591, 12.88357925], [92.87555695, 12.88416672], [92.87527466, 12.88444519], [92.8752594, 12.8847208], [92.87473297, 12.88528156], [92.87444305, 12.88556194], [92.87388611, 12.88555527], [92.87361145, 12.88583279], [92.87333679, 12.88583279], [92.8730545, 12.88611126], [92.87277985, 12.88611126], [92.8713913, 12.88750172], [92.8713913, 12.88778019], [92.87110901, 12.88805485], [92.87110901, 12.88972092], [92.8713913, 12.88999939], [92.8713913, 12.89083099], [92.87194824, 12.89138985], [92.87218475, 12.89200115], [92.87243652, 12.8924427], [92.87285614, 12.89271164], [92.87329102, 12.89293671], [92.87367249, 12.89322376], [92.87402344, 12.89350033], [92.87439728, 12.89375305], [92.87486267, 12.89390087], [92.87530518, 12.89407158], [92.87574005, 12.89422035], [92.87615204, 12.89443016], [92.87654114, 12.89460087], [92.87696075, 12.89476109], [92.87735748, 12.89496136], [92.87779236, 12.89501953], [92.87817383, 12.89512539], [92.87854004, 12.89525318], [92.87898254, 12.89532089], [92.87914276, 12.89537144], [92.87947083, 12.89547157], [92.88005066, 12.89532089], [92.88069916, 12.89521027], [92.88128662, 12.89500904], [92.8818512, 12.8948307], [92.88237, 12.894701], [92.88279724, 12.89447975], [92.88326263, 12.89435863], [92.88369751, 12.89420033], [92.8841629, 12.89413166], [92.88453674, 12.89396954], [92.88492584, 12.89390087], [92.8853302, 12.89389038], [92.88575745, 12.89389038], [92.88622284, 12.89389038], [92.88667297, 12.89393139], [92.88704681, 12.89409065], [92.8874588, 12.89419079], [92.8878479, 12.89435005], [92.88828278, 12.89447975], [92.88868713, 12.89473057], [92.88911438, 12.89502716], [92.88957214, 12.89537144], [92.8902359, 12.89548111], [92.89089203, 12.89558125], [92.89131165, 12.89545345], [92.89147949, 12.895401], [92.89176941, 12.89538002], [92.89202118, 12.89558792], [92.89234161, 12.8959589], [92.89250946, 12.89620972], [92.89263153, 12.89646053], [92.89278412, 12.89649963], [92.89290619, 12.8967247], [92.89311981, 12.89695263], [92.89330292, 12.89695072], [92.89388275, 12.89704037], [92.89418793, 12.89720154], [92.89446259, 12.89742947], [92.89497375, 12.89778709], [92.89537048, 12.89814472], [92.89567566, 12.89849377], [92.89597321, 12.89883995], [92.89605713, 12.8993597], [92.89627838, 12.89980888], [92.89641571, 12.90031338], [92.89653778, 12.90079975], [92.89670563, 12.90124893], [92.89694977, 12.90160465], [92.89717865, 12.90191936], [92.89733124, 12.9022913], [92.89743042, 12.90271854], [92.89759064, 12.90317059], [92.89780426, 12.90356922], [92.89807892, 12.90388393], [92.89829254, 12.90416241], [92.89833069, 12.90445423], [92.89830017, 12.90473175], [92.89819336, 12.90504169], [92.89808655, 12.90543556], [92.89800262, 12.90592098], [92.89782715, 12.90642738], [92.89778137, 12.90703583], [92.89778137, 12.90760994], [92.89782715, 12.90816021], [92.89797974, 12.90864468], [92.89808655, 12.90912056], [92.89825439, 12.90953159], [92.89829254, 12.90992355], [92.89816284, 12.91030407], [92.89801788, 12.91068459], [92.897789, 12.91103077], [92.89755249, 12.91142082], [92.89729309, 12.91186142], [92.89698029, 12.91232967], [92.89672852, 12.91285038], [92.89669037, 12.91343975], [92.89673615, 12.91397381], [92.89660645, 12.91438198], [92.89640045, 12.91471195], [92.89618683, 12.91500187], [92.89595795, 12.91528416], [92.89569855, 12.91558456], [92.89546204, 12.91594505], [92.89528656, 12.91637993], [92.89520264, 12.91686821], [92.8952179, 12.91738319], [92.89552307, 12.91779137], [92.89582825, 12.9182291], [92.89611053, 12.91870117], [92.89640045, 12.91921997], [92.89672089, 12.91971016], [92.89713287, 12.92001057], [92.89748383, 12.92026901], [92.89774323, 12.9205513], [92.89785004, 12.92094135], [92.89791107, 12.92140102], [92.89807892, 12.92180347], [92.89820862, 12.92219925], [92.89824677, 12.92260933], [92.89819336, 12.92299175], [92.89805603, 12.92331791], [92.89792633, 12.92359161], [92.89779663, 12.92382622], [92.89768219, 12.9240818], [92.89745331, 12.92430019], [92.89710999, 12.9245491], [92.89684296, 12.92505264], [92.89671326, 12.92566109], [92.89681244, 12.92622852], [92.89707184, 12.92665291], [92.89737701, 12.92702198], [92.89778137, 12.92741108], [92.89839935, 12.92744064], [92.89897919, 12.92718124], [92.89945221, 12.92677975], [92.89987183, 12.9263792], [92.9002533, 12.92597961], [92.90055084, 12.92556477], [92.90077209, 12.92510986], [92.90087128, 12.92457199], [92.90106201, 12.92407036], [92.90112305, 12.92354107], [92.90116119, 12.92306519], [92.90130615, 12.92266178], [92.90117645, 12.92226124], [92.90112305, 12.92179966], [92.90109253, 12.92131901], [92.90100098, 12.92087936], [92.90084076, 12.92049026], [92.9006958, 12.92013931], [92.90055847, 12.91979027], [92.90041351, 12.91942978], [92.90026093, 12.91903114], [92.9000473, 12.91862488], [92.89990997, 12.91812611], [92.89969635, 12.91764069], [92.89949036, 12.91716003], [92.89945221, 12.91662025], [92.89916992, 12.91639042], [92.89916992, 12.91611195], [92.89888763, 12.91583061], [92.89916992, 12.915555], [92.89942932, 12.91555977], [92.90000153, 12.91500187], [92.90027618, 12.91528034], [92.90055847, 12.91527653], [92.90077209, 12.91535854], [92.90112305, 12.91559029], [92.90151215, 12.91592026], [92.90202332, 12.91603947], [92.90261078, 12.91605473], [92.90322876, 12.91587734], [92.90384674, 12.9157896], [92.90435791, 12.9155798], [92.90485382, 12.9154253], [92.90537262, 12.91526127], [92.90590668, 12.91499043], [92.90649414, 12.91465473], [92.90699768, 12.91417408], [92.90740204, 12.9136982], [92.9076767, 12.91324043], [92.90784454, 12.91279984], [92.90804291, 12.91246891], [92.90820313, 12.91219139], [92.90830994, 12.91193199], [92.90833282, 12.91164017], [92.90828705, 12.91129971], [92.9080658, 12.91082191], [92.9079895, 12.91044998], [92.90833282, 12.91026115], [92.90875244, 12.91015434], [92.90895844, 12.90993309], [92.90914154, 12.90965176], [92.90927124, 12.90932369], [92.9095459, 12.90913296], [92.90982819, 12.90892506], [92.9101181, 12.90876102], [92.91040802, 12.90863609], [92.91072845, 12.9086113], [92.91107178, 12.9086113], [92.91143799, 12.90865612], [92.91182709, 12.90882111], [92.91226196, 12.90889072], [92.91268921, 12.90897083], [92.91306305, 12.90912056], [92.91345215, 12.90920067], [92.91378021, 12.90932655], [92.91410065, 12.90942478], [92.91446686, 12.90946102], [92.9148407, 12.90956974], [92.91523743, 12.90972996], [92.91565704, 12.90991879], [92.91613007, 12.91002178], [92.9165802, 12.9101696], [92.91705322, 12.91031075], [92.91750336, 12.91058731], [92.91793823, 12.91098976], [92.91845703, 12.91142082], [92.91899109, 12.91187191], [92.91956329, 12.91222954], [92.92005157, 12.91255188], [92.92050171, 12.91279125], [92.92089081, 12.91297054], [92.92137146, 12.91281986], [92.92192078, 12.91222954], [92.92204285, 12.91179943], [92.92193604, 12.91155148], [92.92176056, 12.91133404], [92.92160034, 12.91105556], [92.92137146, 12.91078091], [92.92108154, 12.91051865], [92.92076111, 12.91023064], [92.92037201, 12.90999031], [92.91999054, 12.90968037], [92.91963959, 12.90936756], [92.91929626, 12.90902138], [92.91899109, 12.90863132], [92.91864777, 12.90827847], [92.91829681, 12.90792274], [92.91790009, 12.90762234], [92.91751862, 12.90733242], [92.91716003, 12.90705681], [92.91674805, 12.90688133], [92.91636658, 12.90665054], [92.91597748, 12.90639973], [92.91549683, 12.90621758], [92.91493988, 12.9061079], [92.91435242, 12.90598488], [92.9138031, 12.90572071], [92.91320801, 12.90545654], [92.91262817, 12.90526104], [92.91210175, 12.90501022], [92.91156769, 12.90477085], [92.91100311, 12.90458107], [92.91052246, 12.90426922], [92.91010284, 12.90392017], [92.90990448, 12.90339565], [92.90969086, 12.90289021], [92.90947723, 12.90239143], [92.90944672, 12.90186501], [92.90948486, 12.90137482], [92.90964508, 12.90097809], [92.909729, 12.90056992], [92.90983582, 12.90015984], [92.90999603, 12.89973068], [92.91017151, 12.89925003], [92.91026306, 12.89874458], [92.91027832, 12.89824963], [92.91027832, 12.89777088], [92.91024017, 12.89730167], [92.91007996, 12.89682961], [92.90996552, 12.89632607], [92.90976715, 12.89585018], [92.90959167, 12.89541245], [92.9094162, 12.89495945], [92.9091568, 12.8945713], [92.90888977, 12.89419079], [92.90862274, 12.89379025], [92.9083786, 12.89338207], [92.90812683, 12.89298058], [92.90792084, 12.89253235], [92.9076767, 12.8921032], [92.90746307, 12.89164543], [92.9072113, 12.89125061], [92.90695953, 12.89089108], [92.9067688, 12.89050961], [92.9066391, 12.89008236], [92.90641022, 12.88967133], [92.90625, 12.8892107], [92.90603638, 12.8888073], [92.90583038, 12.88840199], [92.90564728, 12.88801193], [92.90553284, 12.88763142], [92.90538788, 12.88732433], [92.90529633, 12.8870182], [92.90524292, 12.8867197], [92.90511322, 12.88647079], [92.90501404, 12.88619804], [92.90499878, 12.88585091], [92.90500641, 12.88543034], [92.9050827, 12.88495064], [92.90529633, 12.88449287], [92.90557098, 12.88404942], [92.90590668, 12.88366127], [92.90627289, 12.88336468], [92.9066925, 12.88317108], [92.90711212, 12.88307095], [92.90753174, 12.88305473], [92.90792084, 12.88305283], [92.90828705, 12.88304996], [92.90867615, 12.88305855], [92.90904236, 12.88308907], [92.9093399, 12.88322353], [92.90963745, 12.88331223], [92.90995026, 12.88335133], [92.91026306, 12.88345242], [92.9106369, 12.88363171], [92.91104126, 12.8838501], [92.91148376, 12.88400078], [92.91188049, 12.88420963], [92.91226196, 12.88446999], [92.91266632, 12.8847208], [92.9131012, 12.88490105], [92.91353607, 12.88500118], [92.91442871, 12.88500118], [92.91471863, 12.88528156], [92.9152832, 12.88528156], [92.91555786, 12.88556194], [92.91750336, 12.88556194], [92.91833496, 12.88638878], [92.91845703, 12.88686275], [92.91880798, 12.8872118], [92.91925812, 12.8875494], [92.91981506, 12.88772869], [92.92034149, 12.8876543], [92.92079163, 12.88737202], [92.92112732, 12.88703728], [92.92141724, 12.88676071], [92.92175293, 12.8865633], [92.92201996, 12.88632298], [92.92230225, 12.88610172], [92.92256927, 12.88591099], [92.92285156, 12.88583088], [92.92310333, 12.88576031], [92.9233017, 12.8856144], [92.92353821, 12.88556194], [92.92379761, 12.88555527], [92.92408752, 12.88555145], [92.92442322, 12.88556194], [92.92485809, 12.88556194], [92.92539215, 12.88556194], [92.92601776, 12.88551044], [92.92662048, 12.8853302], [92.92708588, 12.88498116], [92.92746735, 12.8845911], [92.92778015, 12.88416862], [92.92804718, 12.88376141], [92.92828369, 12.88333511], [92.92832947, 12.88282013], [92.9283371, 12.88231182], [92.92832947, 12.88183975], [92.9283371, 12.88141155], [92.92842102, 12.88101101], [92.92856598, 12.88056183], [92.9285965, 12.88010788], [92.92852783, 12.87967014], [92.92836761, 12.87927246], [92.9283371, 12.87887001], [92.92832947, 12.87847614], [92.92832947, 12.87807274], [92.9283371, 12.87763977], [92.92832947, 12.87719059], [92.92830658, 12.87676239], [92.92819977, 12.87639523], [92.92806244, 12.87605953], [92.92793274, 12.87569141], [92.92775726, 12.87534046], [92.92751312, 12.8749094], [92.92731476, 12.87434196], [92.92727661, 12.87365627], [92.92742157, 12.87295246], [92.92750549, 12.87229538], [92.92760468, 12.87173176], [92.92776489, 12.87127018], [92.92791748, 12.87084103], [92.92804718, 12.87041855], [92.92817688, 12.87001133], [92.92830658, 12.86963081], [92.92835236, 12.86924076], [92.92845917, 12.86891079], [92.92858124, 12.86865997], [92.92861176, 12.86837006], [92.92861176, 12.86803055], [92.92861938, 12.86763], [92.92870331, 12.86715126], [92.92887878, 12.86658096], [92.92906189, 12.86592007], [92.92920685, 12.86520004], [92.92939758, 12.86450005], [92.92944336, 12.86377144], [92.92939758, 12.86310101], [92.92920685, 12.86249924], [92.9291687, 12.86198425], [92.92916107, 12.86154366], [92.9291687, 12.86116791], [92.9291687, 12.86082745], [92.92917633, 12.86048031], [92.92923737, 12.8601017], [92.92941284, 12.85970974], [92.92952728, 12.85923958], [92.92971802, 12.85876179], [92.93000793, 12.85828114], [92.93036652, 12.85785007], [92.93080902, 12.85753059], [92.93128204, 12.85727978], [92.9318161, 12.85715008], [92.93235016, 12.85694504], [92.93289185, 12.85673141], [92.93347931, 12.85658264], [92.93395996, 12.85631371], [92.93435669, 12.85601807], [92.93461609, 12.85566044], [92.93488312, 12.8553772], [92.93507385, 12.85505581], [92.93531799, 12.85476589], [92.93562317, 12.85451126], [92.93596649, 12.85431004], [92.93630981, 12.85418987], [92.93663788, 12.85421944], [92.9369278, 12.85441113], [92.9372406, 12.85458565], [92.93756866, 12.85474396], [92.93788147, 12.8549366], [92.93823242, 12.85507202], [92.93852234, 12.85526085], [92.9388504, 12.85536957], [92.93953705, 12.85601997], [92.93995667, 12.85623169], [92.94043732, 12.85623169], [92.94100189, 12.85582161], [92.94135284, 12.85505962], [92.94124603, 12.8546114], [92.94108582, 12.8540802], [92.94087219, 12.85357189], [92.94074249, 12.8529911], [92.94046021, 12.85253334], [92.94025421, 12.85193634], [92.94000244, 12.85140038], [92.9397583, 12.85088921], [92.93958282, 12.85040188], [92.93937683, 12.84998035], [92.93916321, 12.84951973], [92.93894958, 12.84899998], [92.93888855, 12.84838009], [92.93888855, 12.84774399], [92.93888855, 12.84708309], [92.93890381, 12.84641838], [92.9389801, 12.8457613], [92.93908691, 12.8451004], [92.93897247, 12.84444618], [92.9391098, 12.84380054], [92.93916321, 12.84317017], [92.93921661, 12.84262085], [92.93939972, 12.84222031], [92.93945312, 12.84183025], [92.93951416, 12.8415184], [92.93965149, 12.84127235], [92.93972015, 12.84098911], [92.93978119, 12.8406992], [92.93972015, 12.84055996], [92.94000244, 12.84027958], [92.94000244, 12.84000015], [92.9402771, 12.83972168], [92.9402771, 12.83944416], [92.94055176, 12.83916569], [92.94055176, 12.83778], [92.94082642, 12.83749962], [92.94082642, 12.83693886], [92.94139099, 12.83638954], [92.94161987, 12.83617973], [92.9419632, 12.83608723], [92.94229126, 12.83609104], [92.94258118, 12.83617115], [92.9427948, 12.83640099], [92.94304657, 12.83666134], [92.94334412, 12.83697128], [92.94365692, 12.83735371], [92.94412231, 12.83767128], [92.94436646, 12.83770657], [92.94478607, 12.83777142], [92.94550323, 12.83773041], [92.94612885, 12.83753586], [92.94674683, 12.83739853], [92.94728851, 12.8372097], [92.94779205, 12.83692074], [92.94814301, 12.83652878], [92.94827271, 12.8360796], [92.94806671, 12.83565331], [92.94776154, 12.83519459], [92.94740295, 12.83475971], [92.9469986, 12.83434963], [92.94667053, 12.83392429], [92.94638824, 12.83349133], [92.94610596, 12.83305073], [92.94583893, 12.83259869], [92.94561005, 12.83210945], [92.94545746, 12.83158112], [92.94529724, 12.83105183], [92.94527435, 12.83050728], [92.94522858, 12.82999039], [92.94502258, 12.82953358], [92.94487, 12.82904243], [92.94471741, 12.82854271], [92.94456482, 12.82804108], [92.94441223, 12.82755089], [92.94420624, 12.82711983], [92.94419098, 12.82673264], [92.94431305, 12.82637978], [92.94441986, 12.82603073], [92.94445801, 12.82566166], [92.94455719, 12.82528973], [92.94474792, 12.82492828], [92.94502258, 12.8245697], [92.94532776, 12.82422066], [92.94566345, 12.82390213], [92.94599152, 12.8236084], [92.94628906, 12.82331181], [92.9465332, 12.8229723], [92.94662476, 12.82256222], [92.94654846, 12.82211781], [92.94638824, 12.82167053], [92.94621277, 12.82119179], [92.94612122, 12.82067966], [92.94613647, 12.82020092], [92.94629669, 12.81979847], [92.94641876, 12.81941891], [92.94658661, 12.81904984], [92.94670868, 12.8186264], [92.94692993, 12.81824112], [92.94715881, 12.81785297], [92.94741058, 12.81747055], [92.94766235, 12.81709003], [92.94802856, 12.81680012], [92.94839478, 12.81647205], [92.94883728, 12.8161602], [92.94930267, 12.81579971], [92.94972229, 12.81534195], [92.95014191, 12.81485367], [92.95053864, 12.81434631], [92.95089722, 12.81383133], [92.95127106, 12.81332016], [92.95163727, 12.81279755], [92.95194244, 12.81223965], [92.9522171, 12.81171131], [92.95249176, 12.8112669], [92.95271301, 12.81088161], [92.95279694, 12.81048012], [92.95292664, 12.81011963], [92.95307922, 12.80975342], [92.95329285, 12.80941582], [92.95340729, 12.80900097], [92.95359039, 12.80862141], [92.95374298, 12.80822182], [92.95388794, 12.8078413], [92.95405579, 12.80746269], [92.95414734, 12.80704117], [92.95417023, 12.80659008], [92.95413971, 12.80611992], [92.95401001, 12.80566883], [92.95391083, 12.80521965], [92.95388794, 12.80476189], [92.95384979, 12.8043108], [92.95367432, 12.80390739], [92.95359802, 12.80345154], [92.95355225, 12.80297279], [92.95331573, 12.80257225], [92.95294189, 12.80223179], [92.95248413, 12.80192947], [92.95201111, 12.80160999], [92.95150757, 12.80122852], [92.95100403, 12.80086899], [92.95049286, 12.80054092], [92.95004272, 12.80013084], [92.94972229, 12.7996521], [92.94948578, 12.79915524], [92.94944, 12.79861069], [92.94944, 12.79808044], [92.94945526, 12.79760647], [92.9495163, 12.79717541], [92.94967651, 12.79680061], [92.94976807, 12.79638577], [92.94995117, 12.7959919], [92.94999695, 12.79553223], [92.9499588, 12.79506016], [92.94976807, 12.794631], [92.94967651, 12.7941618], [92.94946289, 12.79374027], [92.9492569, 12.79330921], [92.94906616, 12.79286957], [92.94877625, 12.79252148], [92.94843292, 12.79222012], [92.94805908, 12.79198837], [92.94763184, 12.79191017], [92.94728088, 12.79174137], [92.94690704, 12.79165936], [92.94655609, 12.79154968], [92.94619751, 12.79139042], [92.94579315, 12.79121017], [92.94530487, 12.79103279], [92.94480133, 12.79077721], [92.94433594, 12.79045105], [92.94386292, 12.79015064], [92.94338989, 12.78991985], [92.94299316, 12.78965092], [92.94268799, 12.78936005], [92.94241333, 12.78906059], [92.94219208, 12.78871918], [92.94193268, 12.78839111], [92.94165802, 12.78805065], [92.94135284, 12.78773022], [92.94100952, 12.78741646], [92.94062805, 12.78713131], [92.94029236, 12.78672028], [92.94000244, 12.78622055], [92.93972015, 12.78567028], [92.93942261, 12.78514099], [92.9391098, 12.7846508], [92.9388504, 12.78413963], [92.93859863, 12.78369141], [92.93834686, 12.78334045], [92.93811035, 12.78304195], [92.93785095, 12.78277969], [92.93750763, 12.7825613], [92.93699646, 12.78249931], [92.93650055, 12.78245354], [92.93610382, 12.78226471], [92.93573761, 12.78217125], [92.93541718, 12.78201199], [92.93505859, 12.7819109], [92.93477631, 12.78172874], [92.93453979, 12.78155994], [92.93440247, 12.78127956], [92.93422699, 12.78103161], [92.93413544, 12.78074932], [92.93396759, 12.78046036], [92.93389893, 12.78011322], [92.93388367, 12.77971172], [92.93385315, 12.7792902], [92.93366241, 12.7789011], [92.93361664, 12.77847004], [92.93360901, 12.77802086], [92.93360901, 12.7775507], [92.93360901, 12.77706814], [92.93361664, 12.77655983], [92.93370819, 12.77603054], [92.93385315, 12.7755003], [92.93392181, 12.77493954], [92.93406677, 12.77439022], [92.93419647, 12.77382088], [92.93444824, 12.77330112], [92.93473053, 12.77283573], [92.93504333, 12.7724514], [92.93530273, 12.77208233], [92.93556213, 12.7717762], [92.93585968, 12.77147102], [92.93623352, 12.7711544], [92.93674469, 12.77084637], [92.93728638, 12.77050018], [92.93772125, 12.77002811], [92.93792725, 12.76946068], [92.9380722, 12.76897526], [92.93821716, 12.76863098], [92.93839264, 12.76839161], [92.93859863, 12.76820946], [92.93881226, 12.76801968], [92.93904877, 12.76781273], [92.93930054, 12.76774025], [92.93962097, 12.76784515], [92.93981934, 12.76795197], [92.94001007, 12.7681179], [92.94025421, 12.76832104], [92.94062805, 12.76850128], [92.94113159, 12.76865101], [92.94165802, 12.7688818], [92.94223022, 12.76911926], [92.94285583, 12.76917076], [92.94342804, 12.76928043], [92.94391632, 12.76946068], [92.94438171, 12.76971817], [92.94486237, 12.7699604], [92.94541168, 12.77013493], [92.94593811, 12.77025127], [92.94648743, 12.77028084], [92.94706726, 12.77028084], [92.94764709, 12.77028084], [92.94821167, 12.77028084], [92.94877625, 12.77025127], [92.94934845, 12.77007961], [92.94982147, 12.76978588], [92.94989014, 12.76937199], [92.94976044, 12.76893425], [92.94972992, 12.76849365], [92.94972229, 12.76809311], [92.94971466, 12.76772213], [92.94966125, 12.76736069], [92.94948578, 12.76699924], [92.94941711, 12.76655006], [92.9493103, 12.76611233], [92.94917297, 12.7656517], [92.94904327, 12.76515961], [92.9488678, 12.7646904], [92.94866943, 12.7642498], [92.94861603, 12.76380062], [92.9486084, 12.76338673], [92.94861603, 12.76300144], [92.94867706, 12.76260853], [92.94889069, 12.76220131], [92.94917297, 12.76173019], [92.9495163, 12.76124191], [92.94998932, 12.76084137], [92.95046234, 12.7604847], [92.95082855, 12.76008892], [92.95111847, 12.75973129], [92.95139313, 12.75938034], [92.95161438, 12.75903797], [92.95176697, 12.75863934], [92.95194244, 12.75826073], [92.95211029, 12.75788689], [92.95230103, 12.75755024], [92.95256042, 12.75729179], [92.95291138, 12.75710106], [92.95332336, 12.75692081], [92.9537735, 12.75671101], [92.95432281, 12.75663376], [92.95493317, 12.75650978], [92.95556641, 12.75650406], [92.95611572, 12.75638294], [92.95662689, 12.75620461], [92.95709229, 12.75597], [92.9575882, 12.75579929], [92.9580307, 12.75559044], [92.95851135, 12.755476], [92.95897675, 12.75531197], [92.95951843, 12.75519085], [92.96006012, 12.75498104], [92.96057129, 12.75469875], [92.96103668, 12.75436974], [92.96139526, 12.75399399], [92.96170044, 12.75364971], [92.9619751, 12.75336838], [92.96222687, 12.75312138], [92.96247864, 12.75286198], [92.96269226, 12.75254726], [92.96276855, 12.75209999], [92.96277618, 12.75161934], [92.96273804, 12.75114059], [92.96257782, 12.75069046], [92.96256256, 12.75023079], [92.96259308, 12.74975967], [92.96248627, 12.74929237], [92.96231079, 12.74881363], [92.96224213, 12.74828529], [92.96229553, 12.74773788], [92.96247864, 12.74722099], [92.9627533, 12.74671936], [92.96308136, 12.74627018], [92.96350098, 12.74587059], [92.96399689, 12.74551105], [92.9644165, 12.74505138], [92.96478271, 12.74450874], [92.96517944, 12.74400043], [92.96560669, 12.7435627], [92.96601868, 12.74315929], [92.96644592, 12.74283123], [92.96688843, 12.74255085], [92.9673233, 12.7421999], [92.96773529, 12.74177074], [92.96805573, 12.74121284], [92.96833801, 12.74059486], [92.96856689, 12.73996162], [92.96858215, 12.73927116], [92.96841431, 12.73863983], [92.9681778, 12.73811054], [92.96787262, 12.7377367], [92.967659, 12.73738194], [92.96746826, 12.73705959], [92.96728516, 12.73679447], [92.9671936, 12.73647213], [92.96704865, 12.73619747], [92.96695709, 12.73589134], [92.96691132, 12.73555183], [92.96675873, 12.73521042], [92.96668243, 12.73482037], [92.96666718, 12.73435974], [92.9666214, 12.73391056], [92.96643066, 12.73355007], [92.96631622, 12.733181], [92.96612549, 12.73290539], [92.96593475, 12.7325964], [92.96572876, 12.73224926], [92.9654541, 12.73190498], [92.96523285, 12.7314806], [92.96496582, 12.73106194], [92.96475983, 12.73057175], [92.9646759, 12.73002529], [92.9644928, 12.72955513], [92.96444702, 12.72906971], [92.96443939, 12.72861195], [92.96444702, 12.72820091], [92.96443939, 12.72784138], [92.96444702, 12.72751141], [92.96447754, 12.72719193], [92.96460724, 12.72691441], [92.96469879, 12.72661495], [92.96472168, 12.72628021], [92.96472168, 12.72593975], [92.96475983, 12.7256012], [92.96491241, 12.72534275], [92.9650116, 12.72503567], [92.9651413, 12.72471046], [92.96528625, 12.72434044], [92.96547699, 12.7239418], [92.96560669, 12.72345161], [92.96583557, 12.72297955], [92.96611023, 12.72246933], [92.96637726, 12.72193432], [92.96664429, 12.72139072], [92.96691132, 12.72088146], [92.96720886, 12.7204771], [92.96749878, 12.72014046], [92.96781158, 12.71987057], [92.9681778, 12.71970463], [92.96856689, 12.71952248], [92.96903229, 12.7194519], [92.96956635, 12.71944332], [92.97012329, 12.71946526], [92.97068024, 12.71957016], [92.97120667, 12.71969986], [92.97170258, 12.71972084], [92.97214508, 12.71972275], [92.97255707, 12.71972275], [92.97298431, 12.71972466], [92.97345734, 12.71972275], [92.97399139, 12.71967506], [92.97447968, 12.71944046], [92.9749527, 12.71916866], [92.97541809, 12.71889114], [92.97589111, 12.71863079], [92.97638702, 12.71843147], [92.97689056, 12.71817112], [92.97730255, 12.71774673], [92.97762299, 12.71720028], [92.97785187, 12.71659088], [92.97808075, 12.71597099], [92.97833252, 12.71540928], [92.97854614, 12.71487141], [92.9786377, 12.71428871], [92.97883606, 12.71374035], [92.97892761, 12.71316814], [92.97912598, 12.71264172], [92.97928619, 12.71211147], [92.97953033, 12.71161175], [92.97978973, 12.71115112], [92.98010254, 12.71071053], [92.98033905, 12.71022129], [92.98051453, 12.70972919], [92.9805069, 12.70922089], [92.98027802, 12.70877171], [92.9799881, 12.70833874], [92.97960663, 12.70796013], [92.97914124, 12.70769119], [92.97866821, 12.70757961], [92.9782486, 12.7077713], [92.97789001, 12.70798111], [92.97750092, 12.70805645], [92.97583008, 12.70944405], [92.97473907, 12.7105751], [92.97441864, 12.71084976], [92.97409821, 12.71115971], [92.97368622, 12.71138096], [92.97323608, 12.71150017], [92.97281647, 12.71164131], [92.97245789, 12.71167088], [92.97219086, 12.71161175], [92.9719696, 12.71144962], [92.97166443, 12.71135235], [92.97134399, 12.71114731], [92.97091675, 12.71099186], [92.97054291, 12.71067715], [92.9701004, 12.71029186], [92.96959686, 12.70987034], [92.96907806, 12.70943928], [92.9686203, 12.70901108], [92.9682312, 12.70864201], [92.96790314, 12.70833015], [92.96759033, 12.70804691], [92.96730042, 12.70775986], [92.96697998, 12.70746136], [92.96668243, 12.70713997], [92.96643066, 12.70683861], [92.96624756, 12.70652008], [92.96607208, 12.70622826], [92.96586609, 12.70599079], [92.96570587, 12.70571995], [92.96553802, 12.70545959], [92.96536255, 12.7052002], [92.96523285, 12.70487022], [92.965065, 12.70457554], [92.96499634, 12.70425034], [92.96499634, 12.70393085], [92.96499634, 12.70363045], [92.9650116, 12.70331955], [92.965065, 12.70300102], [92.96512604, 12.7026701], [92.96499634, 12.70230961], [92.96477509, 12.70191765], [92.96453857, 12.7014904], [92.96425629, 12.70106125], [92.96401215, 12.70057964], [92.96376038, 12.70011806], [92.96357727, 12.69957066], [92.96334076, 12.69904041], [92.96312714, 12.69847012], [92.96305847, 12.69781971], [92.9630127, 12.69710922], [92.96292877, 12.69678116], [92.96270752, 12.6958313], [92.96292877, 12.69486046], [92.96305847, 12.69452], [92.96362305, 12.69423962], [92.96459961, 12.6938324], [92.96515656, 12.69369316], [92.96550751, 12.69334888], [92.96565247, 12.69314098], [92.96522522, 12.69286633], [92.96501923, 12.69155979], [92.96465302, 12.68995953], [92.96448517, 12.6895237], [92.96444702, 12.68900871], [92.96444702, 12.68844032], [92.96440125, 12.68783092], [92.96417236, 12.6872406], [92.96392059, 12.68665028], [92.96368408, 12.68606186], [92.96350098, 12.68545246], [92.96337128, 12.68486118], [92.96337891, 12.6842804], [92.96360016, 12.68378639], [92.96382141, 12.68330002], [92.96404266, 12.68280983], [92.96431732, 12.68236065], [92.96466064, 12.68192959], [92.96498108, 12.68148136], [92.96520996, 12.68097115], [92.965271, 12.68037128], [92.96523285, 12.67976093], [92.96505737, 12.67917919], [92.96498108, 12.6785593], [92.96485901, 12.67795086], [92.96473694, 12.67733097], [92.96472168, 12.67672253], [92.96470642, 12.67613888], [92.96463013, 12.67563057], [92.96444702, 12.67520046], [92.9642868, 12.6747694], [92.96406555, 12.67436123], [92.96372986, 12.67407036], [92.96350098, 12.67366791], [92.96329498, 12.6731596], [92.96305847, 12.67266083], [92.96286011, 12.67214108], [92.96274567, 12.67157841], [92.96259308, 12.671031], [92.96245575, 12.6704731], [92.9622345, 12.66995335], [92.96206665, 12.66942501], [92.96196747, 12.66887474], [92.96194458, 12.66829681], [92.96193695, 12.66771984], [92.96193695, 12.66714096], [92.96198273, 12.66657066], [92.9621582, 12.66603088], [92.96233368, 12.66544533], [92.96253204, 12.66480923], [92.96273041, 12.66413021], [92.96276855, 12.66337967], [92.96277618, 12.66260147], [92.96277618, 12.66180325], [92.96277618, 12.66100788], [92.96276855, 12.66024017], [92.96276855, 12.65950966], [92.96273041, 12.65886784], [92.96250916, 12.65832996], [92.96228027, 12.65781879], [92.96212769, 12.65727043], [92.96192169, 12.65674114], [92.96166229, 12.65623093], [92.96141052, 12.65572929], [92.96118927, 12.65524387], [92.96102142, 12.65475845], [92.96082306, 12.65429974], [92.96060181, 12.65384007], [92.96051025, 12.65326118], [92.96030426, 12.6527071], [92.96015167, 12.65210056], [92.96002197, 12.65148067], [92.9599762, 12.65086079], [92.95987701, 12.65030956], [92.95974731, 12.64983559], [92.95967102, 12.64938927], [92.9595108, 12.64903069], [92.95944977, 12.64868546], [92.95943451, 12.64833355], [92.95935822, 12.64799404], [92.95920563, 12.64766598], [92.9591217, 12.64725971], [92.9589386, 12.64686108], [92.95890045, 12.64640808], [92.95893097, 12.64592171], [92.95887756, 12.64544964], [92.95876312, 12.64500141], [92.95863342, 12.64456558], [92.95857239, 12.64414024], [92.95848083, 12.64377308], [92.95835876, 12.64345932], [92.95826721, 12.64315987], [92.95810699, 12.64286995], [92.95806885, 12.64252186], [92.95807648, 12.6420908], [92.95809174, 12.64160061], [92.95820618, 12.64104939], [92.9582901, 12.64044094], [92.95832825, 12.63985252], [92.95832825, 12.63927174], [92.95828247, 12.63869476], [92.95809937, 12.63810921], [92.95806122, 12.63749599], [92.95809937, 12.63688087], [92.95828247, 12.63630867], [92.95833588, 12.63571167], [92.95833588, 12.63513088], [92.95831299, 12.63456059], [92.95818329, 12.63400936], [92.95807648, 12.63349915], [92.95806122, 12.6330204], [92.95810699, 12.63258171], [92.95828247, 12.63216972], [92.95828247, 12.63176918], [92.95810699, 12.63134861], [92.95806122, 12.63085938], [92.95802307, 12.63033962], [92.95786285, 12.62982178], [92.95778656, 12.62928009], [92.95777893, 12.62872791], [92.95777893, 12.62818146], [92.95781708, 12.62763023], [92.95793915, 12.62709904], [92.95804596, 12.62694168], [92.95805359, 12.62444401], [92.95722198, 12.62360954], [92.95749664, 12.62333393], [92.95694733, 12.62277794], [92.95722198, 12.62250042], [92.95722198, 12.62194061], [92.95805359, 12.62111187], [92.95804596, 12.62083054], [92.95833588, 12.62055492], [92.95833588, 12.61972141], [92.95840454, 12.6194067], [92.95857239, 12.61908054], [92.95859528, 12.61874104], [92.95851898, 12.61836529], [92.95839691, 12.61795044], [92.95829773, 12.61750126], [92.95808411, 12.61710739], [92.95793915, 12.61669922], [92.95780182, 12.61634064], [92.95773315, 12.61598969], [92.95758057, 12.61572838], [92.9575119, 12.6154213], [92.9574585, 12.61505127], [92.95726776, 12.61470032], [92.95717621, 12.61421871], [92.95700073, 12.61369133], [92.95696259, 12.61309147], [92.95696259, 12.61247063], [92.95696259, 12.61188984], [92.95693207, 12.61138153], [92.95687103, 12.6109581], [92.95671082, 12.61062145], [92.95663452, 12.61025238], [92.9564743, 12.60991859], [92.95639038, 12.6095314], [92.95632172, 12.60908031], [92.95622253, 12.60860062], [92.95613861, 12.60808182], [92.95614624, 12.60750961], [92.95633698, 12.60689735], [92.95639038, 12.60624886], [92.95643616, 12.60559082], [92.95656586, 12.60499573], [92.95643616, 12.60437965], [92.95633698, 12.60369015], [92.95615387, 12.60300636], [92.95612335, 12.60229969], [92.95614624, 12.60167503], [92.95630646, 12.60115147], [92.95652771, 12.60069275], [92.95667267, 12.60021019], [92.95685577, 12.59976959], [92.95716095, 12.59941196], [92.95748901, 12.59902], [92.95778656, 12.59858036], [92.95801544, 12.59809017], [92.95801544, 12.59754753], [92.95781708, 12.59700966], [92.95779419, 12.59645844], [92.9577713, 12.59591103], [92.95770264, 12.59540272], [92.95753479, 12.59494305], [92.95745087, 12.59444141], [92.95729065, 12.59396267], [92.95739746, 12.59346962], [92.95754242, 12.59304428], [92.95777893, 12.59263611], [92.95800781, 12.59220123], [92.95809174, 12.59166145], [92.95825195, 12.59120178], [92.95844269, 12.59082603], [92.95861816, 12.59046173], [92.95878601, 12.59009266], [92.95894623, 12.58967972], [92.95913696, 12.58928108], [92.9592514, 12.58884144], [92.95941925, 12.58848953], [92.95952606, 12.5881424], [92.95968628, 12.58787346], [92.95980072, 12.58757877], [92.95996857, 12.58732128], [92.96008301, 12.58702946], [92.96024323, 12.58678055], [92.96034241, 12.58650684], [92.96051025, 12.5862999], [92.96066284, 12.58603096], [92.9608078, 12.58572102], [92.96124268, 12.58549118], [92.96163177, 12.58511543], [92.96193695, 12.58459473], [92.96216583, 12.58397961], [92.96216583, 12.58331203], [92.96194458, 12.58271694], [92.96170044, 12.58218193], [92.96160126, 12.58165264], [92.96162415, 12.5811491], [92.96166229, 12.58065033], [92.96166229, 12.58012104], [92.96165466, 12.57956505], [92.96163177, 12.57899094], [92.96160889, 12.57841873], [92.96160126, 12.57783985], [92.96165466, 12.57728767], [92.96172333, 12.57671165], [92.96194458, 12.57621002], [92.96218872, 12.57575035], [92.96240234, 12.57531929], [92.96268463, 12.57500172], [92.96299744, 12.57472229], [92.96338654, 12.57444191], [92.96385193, 12.57410908], [92.96427155, 12.57359791], [92.96457672, 12.57304859], [92.96443939, 12.57247925], [92.9642334, 12.57197571], [92.96421051, 12.57151985], [92.96438599, 12.57112312], [92.96446228, 12.57069492], [92.96456909, 12.57029629], [92.96473694, 12.56993961], [92.96501923, 12.56965065], [92.9653244, 12.56937695], [92.96552277, 12.56896019], [92.96563721, 12.56850719], [92.96559143, 12.56805992], [92.96562195, 12.56765938], [92.96581268, 12.56727791], [92.96595001, 12.56683636], [92.96611786, 12.56640053], [92.96637726, 12.56604099], [92.96663666, 12.56571007], [92.96684265, 12.56536198], [92.96700287, 12.56496143], [92.96723175, 12.56457806], [92.96749878, 12.56418991], [92.96777344, 12.56378937], [92.96806335, 12.56335068], [92.9683609, 12.56287956], [92.96871185, 12.56239891], [92.96907806, 12.56191635], [92.96939087, 12.56141186], [92.96968079, 12.56091976], [92.96994781, 12.56044102], [92.9701004, 12.55992985], [92.9703064, 12.5595293], [92.97051239, 12.55920315], [92.97059631, 12.55883408], [92.97075653, 12.55850124], [92.97084045, 12.55810261], [92.97093964, 12.55768776], [92.97106934, 12.55727959], [92.97112274, 12.55683994], [92.97115326, 12.55642128], [92.97135162, 12.55607891], [92.97144318, 12.55573463], [92.97159576, 12.55544472], [92.9716568, 12.55511475], [92.97168732, 12.55477524], [92.97177887, 12.55447006], [92.97190857, 12.55417061], [92.97196198, 12.55378056], [92.97199249, 12.5533638], [92.97219086, 12.55296993], [92.97233582, 12.55253029], [92.97251892, 12.55211544], [92.97277832, 12.5517416], [92.97303772, 12.55139542], [92.97328186, 12.55109024], [92.97348022, 12.55080891], [92.97360229, 12.55051994], [92.97367859, 12.55022144], [92.97375488, 12.54993629], [92.97364044, 12.54963112], [92.97367859, 12.54939175], [92.97415924, 12.54660416], [92.9743042, 12.54623699], [92.97444153, 12.54584122], [92.97455597, 12.54540062], [92.97466278, 12.54493141], [92.97476196, 12.54442978], [92.97496796, 12.54400158], [92.9751358, 12.54352093], [92.97528839, 12.54300594], [92.97544098, 12.54246998], [92.97550964, 12.54189968], [92.97543335, 12.54133034], [92.97541046, 12.54076672], [92.97531128, 12.54027081], [92.97528076, 12.53975964], [92.97522736, 12.53928185], [92.97502899, 12.53888512], [92.97489166, 12.53848171], [92.97476196, 12.53807068], [92.97463226, 12.53767014], [92.97451782, 12.53726006], [92.97441864, 12.53687], [92.9743576, 12.53650093], [92.97434998, 12.53604984], [92.97442627, 12.53560066], [92.9744339, 12.53519344], [92.97441864, 12.53482056], [92.97444916, 12.53443241], [92.97451782, 12.53398037], [92.97467804, 12.53347874], [92.97470856, 12.53289127], [92.97470856, 12.53229141], [92.97467041, 12.53176022], [92.97445679, 12.5313797], [92.97426605, 12.5310812], [92.97416687, 12.53080082], [92.97410583, 12.53053188], [92.97403717, 12.53026104], [92.97396851, 12.52997971], [92.97389221, 12.52968884], [92.97380829, 12.52939034], [92.97364807, 12.52911186], [92.97358704, 12.52877045], [92.97345734, 12.52845097], [92.97332764, 12.52810001], [92.97317505, 12.52774715], [92.97303009, 12.52735043], [92.97281647, 12.52694035], [92.9727478, 12.52643204], [92.97260284, 12.52591038], [92.97247314, 12.52533817], [92.97226715, 12.52473164], [92.97218323, 12.5240202], [92.97193909, 12.52332115], [92.97163391, 12.52269554], [92.97128296, 12.52221107], [92.97099304, 12.52178192], [92.97071075, 12.52135372], [92.97052002, 12.52092075], [92.9703598, 12.52051067], [92.97026825, 12.52009106], [92.97018433, 12.51967621], [92.97010803, 12.51924133], [92.97003174, 12.51878071], [92.97000122, 12.51831055], [92.96998596, 12.51787758], [92.96988678, 12.51751995], [92.9697113, 12.51721001], [92.96946716, 12.5169096], [92.96916962, 12.51656055], [92.96834564, 12.5159893], [92.96775818, 12.51541042], [92.96720886, 12.51504135], [92.96691895, 12.51483059], [92.96630859, 12.51412868], [92.96620178, 12.51357079], [92.96602631, 12.51243973], [92.96591187, 12.51082039], [92.96546936, 12.50887966], [92.96553802, 12.50861073], [92.96553802, 12.50472069], [92.96583557, 12.50444508], [92.96583557, 12.50388908], [92.96611023, 12.50361061], [92.96611023, 12.50305462], [92.96639252, 12.50278091], [92.96639252, 12.50193977], [92.96666718, 12.50166702], [92.96666718, 12.50139141], [92.96694183, 12.50111961], [92.96694183, 12.5008297], [92.96722412, 12.50055695], [92.96721649, 12.50028133], [92.96749878, 12.50000095], [92.96749878, 12.49971962], [92.96746063, 12.49892044], [92.96766663, 12.49806976], [92.96797943, 12.49747276], [92.96821594, 12.4971199], [92.96842194, 12.49666882], [92.96827698, 12.4963789], [92.96740723, 12.49562931], [92.96707916, 12.4949522], [92.96653748, 12.49464226], [92.96495819, 12.49402237], [92.96451569, 12.49375343], [92.96417999, 12.49334145], [92.96386719, 12.4926796], [92.96375275, 12.49189091], [92.96366119, 12.49096394], [92.96391296, 12.48993111], [92.96405792, 12.48927021], [92.96404266, 12.48857975], [92.96376038, 12.48815441], [92.96337128, 12.48771191], [92.96231842, 12.48718262], [92.96164703, 12.4871006], [92.96083069, 12.48666954], [92.95999908, 12.48666954], [92.95905304, 12.48668766], [92.95852661, 12.48691368], [92.95800018, 12.48722363], [92.95755768, 12.48751259], [92.95684814, 12.48838234], [92.95671844, 12.48888969], [92.95683289, 12.48944092], [92.9569931, 12.48983097], [92.95705414, 12.49015903], [92.95674133, 12.49061108], [92.95632172, 12.49104977], [92.95582581, 12.49166965], [92.95555878, 12.49166584], [92.95527649, 12.49193001], [92.95509338, 12.4919796], [92.95466614, 12.49213314], [92.9541626, 12.49226475], [92.95363617, 12.49253178], [92.95316315, 12.49291897], [92.95287323, 12.49341202], [92.95253754, 12.49378967], [92.95217896, 12.49413013], [92.95172119, 12.49437141], [92.95128632, 12.49473953], [92.95088959, 12.49517059], [92.95063019, 12.49564075], [92.95046234, 12.49606037], [92.95024872, 12.49640179], [92.94999695, 12.49673462], [92.94973755, 12.4971199], [92.9495163, 12.49759197], [92.94937134, 12.49810028], [92.94911957, 12.49851036], [92.94877625, 12.4988203], [92.94837189, 12.4989996], [92.94789124, 12.49914074], [92.94744873, 12.49912071], [92.94705963, 12.49895], [92.94664764, 12.49883842], [92.94631195, 12.49860954], [92.94602203, 12.49834061], [92.94576263, 12.49808598], [92.94552612, 12.49785995], [92.94534302, 12.49763012], [92.94528198, 12.49734306], [92.94527435, 12.4969883], [92.94529724, 12.49659061], [92.9454422, 12.49620819], [92.94554138, 12.49579144], [92.94555664, 12.49533081], [92.94550323, 12.49485397], [92.94526672, 12.49442101], [92.94494629, 12.49399281], [92.94455719, 12.49361897], [92.94419861, 12.4932909], [92.94391632, 12.49301529], [92.94372559, 12.49276924], [92.94361877, 12.4925108], [92.94352722, 12.49216938], [92.94333649, 12.49177074], [92.94313049, 12.49127197], [92.94303131, 12.49068069], [92.94291687, 12.49014091], [92.94277954, 12.48968124], [92.94262695, 12.48927689], [92.94242859, 12.48894024], [92.94220734, 12.48856163], [92.94194031, 12.48817158], [92.94169617, 12.48778439], [92.94154358, 12.48740387], [92.94126892, 12.48721027], [92.94113159, 12.48698711], [92.9411087, 12.48668957], [92.9411087, 12.48636913], [92.94111633, 12.48602867], [92.9411087, 12.48565102], [92.94106293, 12.48525047], [92.94085693, 12.48487186], [92.94062042, 12.48446083], [92.94033051, 12.48407173], [92.94007874, 12.48363018], [92.93978119, 12.48324013], [92.93955231, 12.48283195], [92.93926239, 12.48251057], [92.93897247, 12.48224163], [92.93868256, 12.48201084], [92.93840027, 12.48176098], [92.93801117, 12.4816103], [92.93757629, 12.48143005], [92.93704987, 12.48139095], [92.93647766, 12.48140144], [92.93589783, 12.48147964], [92.93535614, 12.48166275], [92.9348526, 12.48182011], [92.93440247, 12.48190022], [92.93405151, 12.48179722], [92.93358612, 12.48168087], [92.93318176, 12.48159027], [92.93282318, 12.4813776], [92.93247986, 12.48109055], [92.93213654, 12.48072147], [92.93192291, 12.48031807], [92.93180084, 12.47994041], [92.93173218, 12.47970867], [92.93178558, 12.47944069], [92.93193817, 12.47923088], [92.93218994, 12.47897053], [92.93242645, 12.47868443], [92.9324646, 12.47834682], [92.93231201, 12.47797966], [92.93212128, 12.4775486], [92.93184662, 12.4771204], [92.93160248, 12.47669601], [92.931427, 12.47630024], [92.931427, 12.47593689], [92.93157959, 12.47562122], [92.93173218, 12.47533131], [92.93193817, 12.47506237], [92.93218994, 12.47476101], [92.93255615, 12.47447014], [92.93305206, 12.47423458], [92.93357086, 12.47395039], [92.93403625, 12.47352791], [92.93438721, 12.4730196], [92.93450928, 12.47249126], [92.93470001, 12.47208118], [92.93483734, 12.47167778], [92.93499756, 12.47126961], [92.93515015, 12.4708004], [92.93525696, 12.47029209], [92.93526459, 12.4697504], [92.9347229, 12.46833038], [92.93360901, 12.46722221], [92.9327774, 12.46722221], [92.93250275, 12.46694374], [92.93166351, 12.46694374], [92.93138885, 12.46666622], [92.93110657, 12.46667099], [92.93083191, 12.46638966], [92.93083191, 12.46611023], [92.9311142, 12.46583366], [92.93360901, 12.46583366], [92.9338913, 12.46611214], [92.93416595, 12.46611214], [92.93425751, 12.46620274], [92.93444824, 12.46638966], [92.9347229, 12.46638966], [92.93515015, 12.46652889], [92.93549347, 12.4666729], [92.93588257, 12.46685123], [92.93630981, 12.46705055], [92.9367218, 12.46736145], [92.93717957, 12.46765137], [92.93760681, 12.46798992], [92.93808746, 12.46824074], [92.93858337, 12.46842098], [92.9390564, 12.46858025], [92.93961334, 12.46861172], [92.94019318, 12.46858025], [92.94077301, 12.46842098], [92.94135284, 12.46830177], [92.94187164, 12.46813583], [92.94233704, 12.46819115], [92.94270325, 12.46829796], [92.94299316, 12.46836376], [92.94326019, 12.46851444], [92.943573, 12.46861935], [92.94387054, 12.46879673], [92.94415283, 12.46909142], [92.94435883, 12.46951866], [92.94449615, 12.47004986], [92.94471741, 12.47054672], [92.94493866, 12.47102356], [92.94500732, 12.4715023], [92.94503784, 12.47194386], [92.94503784, 12.47236156], [92.94512939, 12.47274685], [92.94533539, 12.47310543], [92.94563293, 12.47340965], [92.94605255, 12.47355843], [92.94651794, 12.47370243], [92.94697571, 12.47391796], [92.94744873, 12.47418022], [92.94790649, 12.47451115], [92.94837952, 12.47488022], [92.9489212, 12.47521973], [92.94948578, 12.4755497], [92.95010376, 12.47582817], [92.95069885, 12.47604179], [92.95130157, 12.47610569], [92.95186615, 12.47613144], [92.95239258, 12.47622013], [92.95289612, 12.4762907], [92.95336914, 12.47614861], [92.95387268, 12.47611141], [92.95435333, 12.47606277], [92.95476532, 12.47585964], [92.95521545, 12.47570992], [92.95574951, 12.4755497], [92.95630646, 12.47536087], [92.95684814, 12.47514915], [92.95728302, 12.47478199], [92.95768738, 12.47441959], [92.95800781, 12.47406578], [92.95826721, 12.47370243], [92.95854187, 12.47341919], [92.95881653, 12.47320938], [92.95892334, 12.47291088], [92.95867157, 12.47239113], [92.95838165, 12.47182083], [92.95820618, 12.47128963], [92.95807648, 12.47078037], [92.95797729, 12.47024632], [92.95778656, 12.46969032], [92.9577179, 12.4690609], [92.95800781, 12.46833706], [92.95793915, 12.46770954], [92.95765686, 12.4671402], [92.95724487, 12.46668911], [92.95683289, 12.46632195], [92.95635223, 12.46610069], [92.95588684, 12.4659214], [92.95540619, 12.46580029], [92.95500946, 12.46564484], [92.95466614, 12.4654789], [92.95439148, 12.465271], [92.95413971, 12.46505547], [92.95384979, 12.46483135], [92.95349121, 12.46463108], [92.95306396, 12.46453953], [92.95259857, 12.46469021], [92.95213318, 12.46483994], [92.95172119, 12.46501064], [92.95128632, 12.4651413], [92.9510498, 12.46506405], [92.95080566, 12.46498394], [92.95027161, 12.46472168], [92.94972992, 12.46440506], [92.94927216, 12.46399021], [92.94888306, 12.46356201], [92.94857788, 12.46311665], [92.94831848, 12.4627409], [92.94808197, 12.46246147], [92.94787598, 12.4622097], [92.9477005, 12.46196175], [92.94753265, 12.4616909], [92.94731903, 12.46140099], [92.94702911, 12.46111202], [92.94667816, 12.46083641], [92.94629669, 12.46062183], [92.94577026, 12.46076107], [92.94529724, 12.46085167], [92.94487762, 12.46093178], [92.94454193, 12.46093178], [92.94429779, 12.46075153], [92.94415283, 12.46055984], [92.94416046, 12.46034145], [92.94432831, 12.46011066], [92.94469452, 12.45989895], [92.94515228, 12.45967102], [92.94558716, 12.45938015], [92.94579315, 12.45904732], [92.94583893, 12.45868015], [92.94589996, 12.45831966], [92.94610596, 12.45800114], [92.94629669, 12.45759964], [92.9462204, 12.45705891], [92.94590759, 12.45647144], [92.94567871, 12.45582199], [92.94539642, 12.45532036], [92.9450531, 12.45491028], [92.94474792, 12.45445442], [92.94445801, 12.4539547], [92.94402313, 12.45361137], [92.94358063, 12.45330143], [92.9432373, 12.45302963], [92.94300842, 12.45273972], [92.94281006, 12.45247173], [92.94271851, 12.45209122], [92.94254303, 12.45168304], [92.94250488, 12.45115185], [92.94244385, 12.45056152], [92.94217682, 12.44999027], [92.9417572, 12.44952011], [92.9412384, 12.44917965], [92.94069672, 12.44889069], [92.94017029, 12.44861126], [92.93963623, 12.44832993], [92.93910217, 12.44805527], [92.938591, 12.44778061], [92.93811798, 12.44750118], [92.93763733, 12.44726086], [92.93711853, 12.44721985], [92.93660736, 12.44723606], [92.93612671, 12.44733429], [92.93564606, 12.4474411], [92.93511963, 12.44735909], [92.93450165, 12.44728184], [92.93383026, 12.44737053], [92.93328094, 12.44760132], [92.93286133, 12.44795036], [92.93247986, 12.44823933], [92.93212128, 12.44843483], [92.93196106, 12.44850826], [92.93183136, 12.44856453], [92.9315567, 12.44849682], [92.93125916, 12.4483099], [92.93093109, 12.44802856], [92.93058014, 12.4476881], [92.9302063, 12.44729137], [92.92980957, 12.44693089], [92.92944336, 12.44659996], [92.92910767, 12.446311], [92.92888641, 12.44594193], [92.9286499, 12.44559956], [92.9283371, 12.44532204], [92.92799377, 12.44502831], [92.92759705, 12.44473171], [92.92715454, 12.44445419], [92.92668152, 12.44418716], [92.92617798, 12.44394112], [92.92572021, 12.44363117], [92.92524719, 12.44338036], [92.92473602, 12.44328022], [92.92433167, 12.44308376], [92.92392731, 12.44294167], [92.92353058, 12.44275761], [92.92312622, 12.4425602], [92.92267609, 12.44254971], [92.92221832, 12.44278145], [92.9217453, 12.44308567], [92.92128754, 12.44341183], [92.92079926, 12.44365978], [92.92037201, 12.44380188], [92.91999817, 12.44359016], [92.91968536, 12.44329643], [92.91938019, 12.44303989], [92.91912842, 12.44278145], [92.91890717, 12.4425602], [92.91870117, 12.44246197], [92.91816711, 12.44271946], [92.91762543, 12.44311142], [92.91716003, 12.44347954], [92.91671753, 12.44374943], [92.91631317, 12.44394112], [92.91590881, 12.44400024], [92.9156723, 12.44393158], [92.91557312, 12.44390202], [92.91532135, 12.44371128], [92.91517639, 12.44346046], [92.91506958, 12.44314957], [92.91491699, 12.44279861], [92.91468811, 12.44236088], [92.9145813, 12.44186401], [92.914711, 12.44139004], [92.91504669, 12.44110966], [92.91555786, 12.4409914], [92.91616058, 12.44100094], [92.91674805, 12.44102955], [92.91744232, 12.44110966], [92.91823578, 12.44124889], [92.91899872, 12.4414196], [92.9193573, 12.44121933], [92.91951752, 12.44079113], [92.91969299, 12.44034195], [92.9197464, 12.43980026], [92.91964722, 12.43921089], [92.91950226, 12.43864155], [92.91946411, 12.4381361], [92.91957092, 12.43772125], [92.91989136, 12.43741989], [92.92015076, 12.43717194], [92.92041016, 12.43699837], [92.9207077, 12.43695068], [92.92102814, 12.43693924], [92.92138672, 12.43697071], [92.92179108, 12.43707085], [92.92221069, 12.43715096], [92.92263031, 12.43695068], [92.9230423, 12.43669128], [92.92339325, 12.43636036], [92.92357635, 12.43595028], [92.92359924, 12.43548489], [92.92350006, 12.43504143], [92.92330933, 12.43463039], [92.92310333, 12.43426991], [92.92280579, 12.43395996], [92.92238617, 12.43382072], [92.92205048, 12.4335928], [92.92178345, 12.43330383], [92.92157745, 12.43296432], [92.92140961, 12.43258095], [92.92128754, 12.43214417], [92.9210968, 12.43171978], [92.92085266, 12.4313097], [92.92059326, 12.43088055], [92.92034912, 12.43050098], [92.92011261, 12.4300518], [92.91976929, 12.42974567], [92.91945648, 12.42939091], [92.91942596, 12.42887974], [92.919487, 12.4283514], [92.91971588, 12.42792702], [92.91996002, 12.42752171], [92.92014313, 12.42708015], [92.92028809, 12.42663097], [92.92043304, 12.42623043], [92.92050171, 12.42590141], [92.92035675, 12.42560959], [92.92028809, 12.42529106], [92.92024231, 12.42494202], [92.92014313, 12.42459106], [92.92022705, 12.42410088], [92.92015076, 12.42361069], [92.91997528, 12.42316628], [92.91971588, 12.42272186], [92.91944122, 12.42222977], [92.91911316, 12.42172432], [92.91871643, 12.42122459], [92.91827393, 12.42074108], [92.91792297, 12.42018127], [92.91783905, 12.41953087], [92.91799164, 12.41887856], [92.91793823, 12.41822147], [92.9177475, 12.41760254], [92.91750336, 12.41703796], [92.91725922, 12.41652012], [92.91709137, 12.41599178], [92.91694641, 12.41550159], [92.9168396, 12.41505718], [92.91666412, 12.41469479], [92.91646576, 12.41436005], [92.9163208, 12.41396999], [92.91613007, 12.41363335], [92.91595459, 12.41327477], [92.91567993, 12.41295433], [92.91552734, 12.41252136], [92.91532135, 12.41205788], [92.9152832, 12.41150188], [92.9152832, 12.41091061], [92.91527557, 12.41036892], [92.9152832, 12.40989971], [92.9152832, 12.40948009], [92.91527557, 12.40909958], [92.9152832, 12.40870285], [92.91535187, 12.40828419], [92.91551971, 12.40785503], [92.91555786, 12.40739155], [92.91551971, 12.4069643], [92.91532898, 12.40664864], [92.9151001, 12.40638065], [92.9148407, 12.40610886], [92.91452789, 12.40589333], [92.91413116, 12.40583801], [92.91369629, 12.40583134], [92.91326141, 12.40581131], [92.9128418, 12.4057312], [92.91239929, 12.40572643], [92.91204834, 12.40562153], [92.91165924, 12.40557098], [92.91123962, 12.40555096], [92.91079712, 12.40555286], [92.91033936, 12.40556526], [92.9098587, 12.40563107], [92.90940857, 12.40583992], [92.90894318, 12.40609074], [92.90841675, 12.40631008], [92.90782166, 12.40654182], [92.90731049, 12.40684986], [92.90686798, 12.40721035], [92.9065094, 12.40764141], [92.90640259, 12.40819931], [92.90643311, 12.40884209], [92.90666962, 12.40946198], [92.90692902, 12.41005039], [92.90711975, 12.41060162], [92.90725708, 12.41112137], [92.90747833, 12.41154957], [92.9076767, 12.41196728], [92.90784454, 12.41238403], [92.90805817, 12.41272259], [92.90827942, 12.41308975], [92.90838623, 12.41362095], [92.90862274, 12.41415024], [92.90883636, 12.41466141], [92.90892792, 12.4151392], [92.90907288, 12.41551971], [92.90905762, 12.41593933], [92.90925598, 12.41631126], [92.90940857, 12.41676044], [92.90943909, 12.41726112], [92.90944672, 12.41776943], [92.90948486, 12.41827774], [92.90963745, 12.41875172], [92.90966034, 12.41923046], [92.90959167, 12.41969967], [92.90943909, 12.42016029], [92.90923309, 12.42059994], [92.90898895, 12.42107201], [92.90859985, 12.42147064], [92.90815735, 12.42183971], [92.90769958, 12.42219543], [92.90724182, 12.42250347], [92.90679932, 12.42278099], [92.90640259, 12.42304134], [92.90602875, 12.42320728], [92.90571594, 12.42325115], [92.90544891, 12.42350388], [92.90533447, 12.42391396], [92.90522003, 12.42432022], [92.90489197, 12.42498684], [92.90442657, 12.42547131], [92.90390015, 12.42591], [92.90335846, 12.42631626], [92.90277863, 12.42665958], [92.9021759, 12.42694092], [92.90149689, 12.42709064], [92.90071869, 12.42711163], [92.90027618, 12.4272604], [92.89997864, 12.42752171], [92.8996582, 12.4277792], [92.89930725, 12.42803478], [92.89891052, 12.42827225], [92.89853668, 12.42854977], [92.89815521, 12.4287796], [92.89774323, 12.42895985], [92.89740753, 12.42925167], [92.89702606, 12.42950916], [92.89668274, 12.429842], [92.89634705, 12.43024063], [92.89601135, 12.43066883], [92.89569092, 12.43117523], [92.89546967, 12.4317503], [92.89524078, 12.43232155], [92.89496613, 12.43282986], [92.8946991, 12.43327045], [92.89444733, 12.43365288], [92.89418793, 12.43398094], [92.89398193, 12.43435001], [92.89370728, 12.43470097], [92.89335632, 12.43505192], [92.89302063, 12.43549919], [92.89255524, 12.43583393], [92.89225006, 12.43631172], [92.89187622, 12.43665886], [92.89151001, 12.43694115], [92.89113617, 12.43719387], [92.89070892, 12.43739986], [92.89034271, 12.43775082], [92.88990784, 12.43804932], [92.88942719, 12.43832874], [92.88890076, 12.43861389], [92.88838959, 12.43898964], [92.88781738, 12.43937969], [92.88722992, 12.43978119], [92.8866806, 12.44017982], [92.88622284, 12.44053078], [92.88588715, 12.44079971], [92.8850174, 12.44190788], [92.88478851, 12.44212437], [92.88442993, 12.44231319], [92.8840332, 12.44252968], [92.88362885, 12.44282818], [92.88323212, 12.4431324], [92.88276672, 12.44336033], [92.88232422, 12.44358253], [92.88187408, 12.44371128], [92.88149261, 12.44386101], [92.88108063, 12.44392014], [92.88065338, 12.44396973], [92.88020325, 12.44404125], [92.87981415, 12.44419765], [92.87899017, 12.44435978], [92.87869263, 12.44444656], [92.87825012, 12.44466972], [92.87808228, 12.44508934], [92.87811279, 12.44544029], [92.87872314, 12.44577122], [92.87934875, 12.44616127], [92.8799057, 12.44653225], [92.88033295, 12.44678974], [92.88085175, 12.44699669], [92.88132477, 12.44723892], [92.88175964, 12.44752121], [92.88215637, 12.44787025], [92.88247681, 12.44824791], [92.88273621, 12.44864273], [92.88291931, 12.44902134], [92.88311005, 12.44931316], [92.88329315, 12.44956112], [92.883461, 12.44982147], [92.88365173, 12.450037], [92.88387299, 12.45024014], [92.88414764, 12.45045662], [92.88443756, 12.45074368], [92.88474274, 12.45111084], [92.88504028, 12.45152092], [92.88535309, 12.45190907], [92.88559723, 12.45227146], [92.88582611, 12.45261097], [92.88600159, 12.45293045], [92.88589478, 12.45350933], [92.88575745, 12.45399189], [92.8855896, 12.45415974], [92.88529968, 12.45374107], [92.88498688, 12.45331001], [92.88465118, 12.45289135], [92.88426971, 12.45253086], [92.88385773, 12.45225334], [92.88342285, 12.45206642], [92.88301849, 12.45191097], [92.8826828, 12.45170116], [92.88219452, 12.45072269], [92.88221741, 12.45051384], [92.88219452, 12.4502697], [92.88210297, 12.4500103], [92.88194275, 12.44972134], [92.88170624, 12.44941139], [92.88137054, 12.44906616], [92.88092041, 12.44870186], [92.88034058, 12.44833946], [92.87975311, 12.44802856], [92.87918854, 12.44777203], [92.87873077, 12.44755077], [92.8783493, 12.44746017], [92.87811279, 12.44729137], [92.87785339, 12.44722271], [92.87760925, 12.44715691], [92.87738037, 12.44700241], [92.87705994, 12.44688511], [92.87667084, 12.44672966], [92.87621307, 12.44684029], [92.87567902, 12.4469862], [92.87518311, 12.44719124], [92.87462616, 12.44729137], [92.87404633, 12.44733047], [92.87343597, 12.44733047], [92.87285614, 12.44733047], [92.87194824, 12.44721985], [92.8713913, 12.44694519], [92.87104797, 12.44659138], [92.87071991, 12.44639969], [92.87033844, 12.44628143], [92.86998749, 12.44614029], [92.86960602, 12.44613075], [92.8691864, 12.44626141], [92.86875153, 12.44653702], [92.86828613, 12.44692039], [92.86777496, 12.44734764], [92.86724854, 12.44779015], [92.86675262, 12.44824791], [92.86631012, 12.44879818], [92.8658371, 12.44927216], [92.86534119, 12.44972134], [92.86485291, 12.45014], [92.86433411, 12.45053864], [92.86384583, 12.45090103], [92.86347961, 12.45133018], [92.86304474, 12.45170593], [92.86267853, 12.45216179], [92.8622818, 12.45260143], [92.86194611, 12.45308018], [92.86160278, 12.45353127], [92.86120605, 12.45388889], [92.86080933, 12.45419025], [92.86042023, 12.45441818], [92.85999298, 12.45458031], [92.85957336, 12.45491028], [92.85913086, 12.45527935], [92.8585968, 12.45556927], [92.85806274, 12.4558506], [92.85758972, 12.45612717], [92.85720062, 12.45638943], [92.85688019, 12.45664692], [92.85656738, 12.45685196], [92.85620117, 12.45696068], [92.85591125, 12.4571104], [92.85572052, 12.45728683], [92.8549881, 12.45761299], [92.85460663, 12.4575901], [92.85423279, 12.45772934], [92.85389709, 12.45804882], [92.85359955, 12.45842934], [92.85327148, 12.45878029], [92.8528595, 12.45903969], [92.85244751, 12.45931816], [92.85209656, 12.45972061], [92.85173035, 12.46018028], [92.85128784, 12.46067047], [92.85095978, 12.46128941], [92.85045624, 12.46177006], [92.8500061, 12.46224022], [92.84966278, 12.4627409], [92.84944153, 12.46278], [92.84944153, 12.46306038], [92.84749603, 12.46501064], [92.84750366, 12.46527767], [92.8466568, 12.46611023], [92.8466568, 12.46638966], [92.84638977, 12.46666622], [92.84638977, 12.46694374], [92.84610748, 12.46722031], [92.84610748, 12.46749973], [92.84555817, 12.46805573], [92.84555817, 12.4683342], [92.84443665, 12.46944046], [92.84443665, 12.46972179], [92.84416962, 12.47000027], [92.84388733, 12.47064972], [92.84377289, 12.47105122], [92.84379578, 12.47221088], [92.84361267, 12.47278118], [92.84368134, 12.47318172], [92.84369659, 12.47531796], [92.84361267, 12.47611141], [92.84416962, 12.47667122], [92.84416962, 12.47916889], [92.8443222, 12.47929859], [92.84416962, 12.47972298], [92.84416962, 12.47999191], [92.84444427, 12.48027706], [92.84444427, 12.48083305], [92.84416962, 12.48111057], [92.84416962, 12.48139095], [92.84388733, 12.48166656], [92.84388733, 12.48194122], [92.84306335, 12.48277855], [92.84278107, 12.48277664], [92.84249878, 12.48305511], [92.84139252, 12.48305511], [92.84055328, 12.48361111], [92.84027863, 12.4836092], [92.83999634, 12.48389244], [92.83972168, 12.48389244], [92.83943939, 12.48417187], [92.83914948, 12.48417187], [92.83833313, 12.4849987], [92.83822632, 12.48517513], [92.83792877, 12.48551178], [92.83778381, 12.48573112], [92.83766937, 12.48612976], [92.83777618, 12.48666763], [92.83777618, 12.48692131], [92.8378067, 12.48720074], [92.83789063, 12.4879303], [92.83833313, 12.48916626], [92.83860016, 12.48986053], [92.83868408, 12.49031925], [92.83876801, 12.49075031], [92.83889771, 12.49125099], [92.83885956, 12.49164104], [92.83889771, 12.491889], [92.83879089, 12.49236965], [92.83840942, 12.49248886], [92.83840942, 12.491992], [92.83839417, 12.49166107], [92.83804321, 12.49151993], [92.83763885, 12.49160004], [92.83666992, 12.49261189], [92.83618927, 12.49290085], [92.83589172, 12.49329281], [92.83586884, 12.49368668], [92.83561707, 12.49393368], [92.83511353, 12.49453259], [92.83467865, 12.49478054], [92.83397675, 12.49497128], [92.83384705, 12.49500942], [92.83280945, 12.49538136], [92.83228302, 12.49557018], [92.83152771, 12.49583435], [92.83088684, 12.49600983], [92.83037567, 12.49620819], [92.82988739, 12.49637222], [92.82915497, 12.49643421], [92.82923889, 12.4961853], [92.8296814, 12.49584103], [92.83116913, 12.49512959], [92.83180237, 12.49478054], [92.83303833, 12.49387169], [92.83362579, 12.49343872], [92.83400726, 12.49324131], [92.83446503, 12.49316978], [92.83490753, 12.49311066], [92.83528137, 12.49300098], [92.83561707, 12.49267292], [92.83614349, 12.49246788], [92.83661652, 12.49189091], [92.83701324, 12.49151993], [92.83728027, 12.49102116], [92.83759308, 12.49057198], [92.83757019, 12.49011135], [92.83721924, 12.48916626], [92.83721924, 12.48888969], [92.83693695, 12.48860931], [92.83694458, 12.48805618], [92.83666992, 12.48777962], [92.83647919, 12.48701191], [92.83640289, 12.48666954], [92.83640289, 12.48639202], [92.83611298, 12.48612118], [92.83611298, 12.48583126], [92.83641815, 12.48527718], [92.83666992, 12.48500156], [92.83860779, 12.4830513], [92.83889008, 12.48305511], [92.83916473, 12.48277664], [92.83943939, 12.48277855], [92.83972168, 12.48250103], [92.83999634, 12.48250103], [92.84027863, 12.48222065], [92.84030151, 12.48184299], [92.84033966, 12.48155308], [92.84042358, 12.48140717], [92.84059143, 12.48124123], [92.84086609, 12.48112011], [92.84105682, 12.48106098], [92.84130859, 12.48101139], [92.84152222, 12.48099518], [92.8417511, 12.4809494], [92.84195709, 12.48085117], [92.84218597, 12.48069191], [92.8423233, 12.48048019], [92.842453, 12.48014927], [92.84262848, 12.47980118], [92.84333038, 12.47916889], [92.84333038, 12.47833061], [92.84305573, 12.47805691], [92.84306335, 12.47639084], [92.84249878, 12.47583008], [92.84249878, 12.47555542], [92.84221649, 12.47528076], [92.84221649, 12.47418022], [92.84194183, 12.47389126], [92.84194183, 12.47332954], [92.84166718, 12.47305679], [92.84166718, 12.47056103], [92.84361267, 12.46861172], [92.84361267, 12.46833038], [92.84388733, 12.46805573], [92.84388733, 12.46749973], [92.84416962, 12.46722031], [92.84416962, 12.46666622], [92.84443665, 12.46638966], [92.84443665, 12.46611023], [92.84500122, 12.46555614], [92.84500122, 12.46527958], [92.84583282, 12.46443939], [92.84583282, 12.46416569], [92.84638977, 12.4636097], [92.84638977, 12.46332932], [92.84666443, 12.46305561], [92.8466568, 12.46278], [92.84694672, 12.46249962], [92.84694672, 12.4619503], [92.84722137, 12.46166992], [92.84725189, 12.46143055], [92.84744263, 12.46115971], [92.84764099, 12.46081066], [92.84781647, 12.46043015], [92.84803009, 12.4601202], [92.84822845, 12.4598217], [92.8483963, 12.45950031], [92.84859467, 12.45920944], [92.84879303, 12.45890141], [92.84900665, 12.45861435], [92.84928131, 12.45833588], [92.849617, 12.45805073], [92.8500061, 12.45773602], [92.85031128, 12.45730114], [92.85063934, 12.45687008], [92.85101318, 12.45648098], [92.85135651, 12.45611572], [92.85173798, 12.45577621], [92.85215759, 12.45547104], [92.85256195, 12.45511055], [92.85295868, 12.45480824], [92.85337067, 12.45451355], [92.85379791, 12.45424938], [92.85423279, 12.45399189], [92.85470581, 12.45378017], [92.85517883, 12.45357895], [92.85562134, 12.45333958], [92.85601807, 12.45315456], [92.85640717, 12.45302963], [92.85674286, 12.45282936], [92.85707092, 12.45265388], [92.85744476, 12.45246029], [92.85782623, 12.45222092], [92.85824585, 12.45195198], [92.85871887, 12.45166016], [92.85920715, 12.45132065], [92.85968018, 12.45089722], [92.86022186, 12.45049953], [92.86074829, 12.45009232], [92.86122894, 12.44971371], [92.86164093, 12.44934177], [92.86197662, 12.44895935], [92.86228943, 12.44863319], [92.86257935, 12.44834232], [92.86283112, 12.44806767], [92.86309052, 12.44780159], [92.86338043, 12.44750977], [92.8637085, 12.44717026], [92.86400604, 12.44673538], [92.86437225, 12.44635201], [92.86472321, 12.44595146], [92.86506653, 12.44559479], [92.86543274, 12.4452877], [92.8658371, 12.44499969], [92.86625671, 12.4446907], [92.86669922, 12.44430065], [92.86720276, 12.4439106], [92.86775208, 12.44351006], [92.86830902, 12.44310665], [92.868927, 12.44278145], [92.86956787, 12.44249821], [92.87018585, 12.44221973], [92.87077332, 12.44194412], [92.87130737, 12.44166565], [92.8717804, 12.44139862], [92.87217712, 12.44118118], [92.87256622, 12.44102955], [92.87290955, 12.44084072], [92.87325287, 12.44066143], [92.87359619, 12.44058418], [92.87394714, 12.44065189], [92.87432861, 12.44079971], [92.87470245, 12.44087791], [92.87499237, 12.44108295], [92.8752594, 12.44126034], [92.87554932, 12.44151115], [92.8758316, 12.44185829], [92.87615204, 12.44227886], [92.87654114, 12.44260979], [92.87703705, 12.44241142], [92.87751007, 12.44194031], [92.87798309, 12.44147682], [92.87844086, 12.44107056], [92.87883759, 12.44062042], [92.87924957, 12.44020653], [92.8797226, 12.43983078], [92.88025665, 12.43946934], [92.88088989, 12.43919086], [92.88156891, 12.43895245], [92.88220215, 12.43860054], [92.88272095, 12.43813992], [92.88326263, 12.43775082], [92.88374329, 12.43738079], [92.8841629, 12.43707085], [92.88453674, 12.43684292], [92.88484955, 12.43664455], [92.88510895, 12.43642902], [92.88542175, 12.43625069], [92.88577271, 12.43606186], [92.88611603, 12.43583202], [92.88647461, 12.43558502], [92.88685608, 12.43535709], [92.8871994, 12.43509102], [92.88755798, 12.43480587], [92.88793182, 12.43456173], [92.88829803, 12.43430042], [92.88860321, 12.43400097], [92.88889313, 12.43367958], [92.88916779, 12.43338776], [92.88944244, 12.43312168], [92.88969421, 12.43287754], [92.88990784, 12.43260193], [92.89015961, 12.43233967], [92.89042664, 12.43204975], [92.89068604, 12.43169022], [92.89099121, 12.43134785], [92.89126587, 12.43099117], [92.8915863, 12.43071938], [92.89185333, 12.43037128], [92.89208984, 12.42999935], [92.89231873, 12.4296093], [92.89253998, 12.42922211], [92.89278412, 12.42884827], [92.89303589, 12.42848969], [92.89325714, 12.42813015], [92.89346313, 12.42780018], [92.89367676, 12.42752171], [92.89389801, 12.42725086], [92.89414978, 12.42695045], [92.89441681, 12.42658138], [92.8946991, 12.42614079], [92.89500427, 12.42572784], [92.89531708, 12.4253912], [92.8956604, 12.42513084], [92.89585876, 12.42475033], [92.89605713, 12.42432022], [92.89614105, 12.42374992], [92.89628601, 12.4231596], [92.89644623, 12.42259026], [92.89667511, 12.42210007], [92.89694214, 12.42166042], [92.8972168, 12.42123127], [92.89749908, 12.42079163], [92.89778137, 12.42034721], [92.89805603, 12.41987991], [92.89832306, 12.4193716], [92.89853668, 12.41882896], [92.8986969, 12.41827106], [92.89891815, 12.4177599], [92.89916229, 12.41730022], [92.89936066, 12.41685104], [92.89942169, 12.41638088], [92.89933014, 12.41593933], [92.89901733, 12.41562939], [92.89852142, 12.41546059], [92.89794922, 12.41526508], [92.89731598, 12.41505909], [92.89660645, 12.41504955], [92.89599609, 12.41534042], [92.89552307, 12.41574955], [92.89509583, 12.4161377], [92.89473724, 12.41653442], [92.89441681, 12.41695976], [92.89409637, 12.41742992], [92.89369202, 12.41788101], [92.89324188, 12.41834068], [92.89266968, 12.41866112], [92.89215088, 12.41896057], [92.89173126, 12.41926003], [92.89134979, 12.41956997], [92.89089966, 12.41980934], [92.89031982, 12.42002106], [92.88970947, 12.42027187], [92.88907623, 12.42048168], [92.88844299, 12.42063046], [92.88788605, 12.42088318], [92.88750458, 12.42131329], [92.88717651, 12.42175102], [92.88681793, 12.42213154], [92.88651276, 12.42261028], [92.88626099, 12.4229908], [92.88606262, 12.42314053], [92.885849, 12.42300034], [92.88559723, 12.4231596], [92.88535309, 12.42306232], [92.88500214, 12.42270756], [92.88463593, 12.42228031], [92.88428497, 12.42190647], [92.88401031, 12.42152977], [92.88367462, 12.42125225], [92.88339996, 12.42091942], [92.88305664, 12.42064095], [92.88273621, 12.42037201], [92.8824234, 12.42018986], [92.8819809, 12.42002964], [92.88179016, 12.41977024], [92.88154602, 12.41959], [92.88109589, 12.41948128], [92.88054657, 12.41941929], [92.8800354, 12.41930103], [92.87958527, 12.41912842], [92.87921906, 12.41889095], [92.87889862, 12.41862202], [92.87858582, 12.41834068], [92.87828064, 12.41805172], [92.87799835, 12.41769886], [92.87778473, 12.41725159], [92.87756348, 12.41674137], [92.87724304, 12.41629028], [92.87695313, 12.41578197], [92.87667084, 12.41523266], [92.87639618, 12.41468811], [92.87610626, 12.41419125], [92.87577057, 12.41379929], [92.87536621, 12.41364193], [92.87496948, 12.41372204], [92.87471771, 12.41410732], [92.87451172, 12.41457367], [92.87439728, 12.41508007], [92.8742218, 12.41553974], [92.87417603, 12.41602993], [92.8741684, 12.4165411], [92.87411499, 12.41706467], [92.87390137, 12.41757107], [92.87361908, 12.41810036], [92.87330627, 12.4186306], [92.87294006, 12.4191246], [92.87255096, 12.41955185], [92.87223816, 12.41998005], [92.87194824, 12.420331], [92.87165833, 12.42061138], [92.87135315, 12.42083931], [92.8710022, 12.42105961], [92.87056732, 12.42121983], [92.87013245, 12.42142105], [92.86972046, 12.42168045], [92.86929321, 12.42194462], [92.86886597, 12.42222118], [92.86844635, 12.42252064], [92.86806488, 12.42284966], [92.86772156, 12.42324162], [92.86736298, 12.42358112], [92.86698151, 12.42387962], [92.86672211, 12.42422199], [92.86653137, 12.42455673], [92.86628723, 12.4248209], [92.8660965, 12.42508125], [92.86585236, 12.4252882], [92.86559296, 12.42549992], [92.86528015, 12.4255619], [92.86499786, 12.42584038], [92.86305237, 12.42584038], [92.86277771, 12.4255619], [92.86165619, 12.4255619], [92.8611908, 12.42531109], [92.86077881, 12.42523098], [92.86013794, 12.42459965], [92.85996246, 12.42438984], [92.85975647, 12.4240799], [92.85962677, 12.42370892], [92.85938263, 12.42338085], [92.85901642, 12.42306232], [92.85858154, 12.4227972], [92.858078, 12.42255116], [92.85753632, 12.42240143], [92.85701752, 12.42230034], [92.85655212, 12.42242813], [92.85609436, 12.42253494], [92.85566711, 12.4227314], [92.85517883, 12.42289066], [92.85463715, 12.42308044], [92.85412598, 12.42333984], [92.85368347, 12.42362022], [92.85253906, 12.4243536], [92.85241699, 12.42417622], [92.85212708, 12.42413044], [92.85173798, 12.4239893], [92.85127258, 12.42389965], [92.8507843, 12.42388725], [92.85031891, 12.42384148], [92.84990692, 12.42365646], [92.84944916, 12.42361069], [92.84898376, 12.42361069], [92.84851074, 12.42361069], [92.84806824, 12.42361069], [92.84766388, 12.42361069], [92.84729004, 12.42358971], [92.84690857, 12.42348957], [92.84648895, 12.423419], [92.84613037, 12.42361069], [92.84577942, 12.42398453], [92.84537506, 12.42434502], [92.84507751, 12.4246912], [92.84486389, 12.4249258], [92.84464264, 12.42506886], [92.84429169, 12.42525578], [92.84391785, 12.4255209], [92.84352112, 12.42580605], [92.84313965, 12.4260807], [92.84307861, 12.42613602], [92.84278107, 12.42639065], [92.84249878, 12.42639065], [92.84221649, 12.42667198], [92.84194183, 12.42666721], [92.84139252, 12.42722321], [92.8408432, 12.4272213], [92.84027863, 12.4277792], [92.83999634, 12.4277792], [92.83944702, 12.42833328], [92.83889008, 12.42833328], [92.83860779, 12.42860889], [92.83860779, 12.42916679], [92.83833313, 12.42944527], [92.83833313, 12.42972088], [92.83805847, 12.42999935], [92.83750153, 12.43056202], [92.83750153, 12.43139172], [92.83693695, 12.43139172], [92.83583069, 12.43027973], [92.83444214, 12.43027973], [92.83416748, 12.43055534], [92.83384705, 12.43056393], [92.83347321, 12.43070126], [92.83309174, 12.43082047], [92.83269501, 12.43088627], [92.8323288, 12.4310503], [92.83188629, 12.43116188], [92.83142853, 12.43135071], [92.83090973, 12.43146896], [92.8303833, 12.43163109], [92.82981873, 12.43166828], [92.82929993, 12.43170166], [92.82884979, 12.4318409], [92.82840729, 12.43192959], [92.82795715, 12.43194771], [92.82750702, 12.43198395], [92.82711792, 12.4321394], [92.8266983, 12.43223095], [92.82628632, 12.43233109], [92.82589722, 12.43247032], [92.82546234, 12.43255043], [92.82506561, 12.43274593], [92.82463074, 12.4328804], [92.82420349, 12.43304634], [92.82375336, 12.43319225], [92.8236084, 12.43333435], [92.82333374, 12.43333435], [92.82195282, 12.43472195], [92.8216629, 12.43503189], [92.82178497, 12.4356699], [92.82167816, 12.43602085], [92.82131958, 12.43638992], [92.82080078, 12.43659973], [92.82006073, 12.43729496], [92.81955719, 12.43754101], [92.81890106, 12.43723106], [92.8184433, 12.4367981], [92.81822968, 12.43653107], [92.81846619, 12.43622112], [92.81906891, 12.43647194], [92.81942749, 12.43653107], [92.81984711, 12.43647194], [92.82073212, 12.43607998], [92.82080078, 12.43558788], [92.82055664, 12.43500042], [92.81999969, 12.43444061], [92.81868744, 12.43444443], [92.81865692, 12.43432999], [92.81861115, 12.43413353], [92.81865692, 12.43398094], [92.81867218, 12.43390083], [92.81869507, 12.4338026], [92.81842804, 12.43377972], [92.81793976, 12.43391037], [92.81777954, 12.43416977], [92.81723785, 12.43429089], [92.81673431, 12.434412], [92.81625366, 12.43444443], [92.81577301, 12.43444443], [92.81526947, 12.43444061], [92.81476593, 12.43446159], [92.8142395, 12.43453693], [92.81374359, 12.43473339], [92.81326294, 12.43498135], [92.81275177, 12.43516636], [92.81223297, 12.43529129], [92.81173706, 12.43546009], [92.81127167, 12.43555069], [92.81082916, 12.43560791], [92.81046295, 12.43579674], [92.81006622, 12.43592262], [92.80964661, 12.43615055], [92.80922699, 12.43653965], [92.80878448, 12.43706036], [92.80834961, 12.43762112], [92.80796051, 12.43813992], [92.80764771, 12.43855953], [92.80736542, 12.43889046], [92.8070755, 12.43918228], [92.8067627, 12.4394598], [92.80640411, 12.43972397], [92.80605316, 12.43994999], [92.80567932, 12.44011593], [92.80522919, 12.44015026], [92.80480194, 12.44024181], [92.80439758, 12.44040108], [92.80400848, 12.44030952], [92.80356598, 12.44020081], [92.80311584, 12.43999958], [92.80265808, 12.43976116], [92.80221558, 12.43955803], [92.80182648, 12.4393301], [92.80148315, 12.43901062], [92.8010025, 12.43875122], [92.80041504, 12.43859768], [92.79981995, 12.4384594], [92.79927063, 12.43834114], [92.79875183, 12.43823147], [92.7983017, 12.43805599], [92.79788208, 12.43790054], [92.7974472, 12.43782997], [92.79698944, 12.43787956], [92.79650879, 12.43795967], [92.79620361, 12.43825245], [92.7960968, 12.43873978], [92.79597473, 12.43932533], [92.79585266, 12.43995667], [92.79568481, 12.44059277], [92.79572296, 12.44124031], [92.79580688, 12.44175529], [92.79582977, 12.44223118], [92.79582977, 12.44272995], [92.79579926, 12.4432106], [92.79569244, 12.44371986], [92.79579163, 12.44428921], [92.79582977, 12.44487667], [92.79587555, 12.44546318], [92.79605103, 12.44602203], [92.7960968, 12.44666195], [92.79666901, 12.4477787], [92.79666901, 12.44833469], [92.79693604, 12.44861126], [92.79693604, 12.44889069], [92.79722595, 12.44916725], [92.79722595, 12.44944477], [92.79750061, 12.44972134], [92.79750061, 12.4500103], [92.7977829, 12.45028114], [92.79777527, 12.45055485], [92.79805756, 12.45083141], [92.79805756, 12.45111084], [92.79833221, 12.45139122], [92.79833221, 12.45166683], [92.7986145, 12.4519453], [92.79860687, 12.45222092], [92.79888916, 12.4525013], [92.7990799, 12.45351124], [92.79927063, 12.45399189], [92.79949188, 12.45437908], [92.79968262, 12.45477962], [92.79966736, 12.4552002], [92.79949951, 12.45557976], [92.7993927, 12.45601082], [92.79917908, 12.45637989], [92.79892731, 12.45676994], [92.7986908, 12.45723724], [92.79853821, 12.45790291], [92.79837799, 12.45851994], [92.79831696, 12.4590807], [92.79825592, 12.459548], [92.79811096, 12.45994854], [92.79798889, 12.46030045], [92.79786682, 12.46063995], [92.79785919, 12.46100044], [92.79799652, 12.46128941], [92.79846954, 12.46175003], [92.79889679, 12.4622097], [92.79944611, 12.46277809], [92.80000305, 12.46332932], [92.80000305, 12.4636097], [92.80027771, 12.46389008], [92.80027771, 12.46444416], [92.79888916, 12.46583366], [92.79833221, 12.46583366], [92.79805756, 12.46611214], [92.79750061, 12.46611023], [92.79722595, 12.46638966], [92.79666901, 12.46638966], [92.79638672, 12.46667099], [92.79611206, 12.46667099], [92.79442596, 12.46814728], [92.79416656, 12.46833038], [92.79364777, 12.46853924], [92.79310608, 12.46895027], [92.7926178, 12.46932125], [92.79225922, 12.46973133], [92.79165649, 12.47028065], [92.79109955, 12.46972179], [92.79109955, 12.46917057], [92.79138947, 12.46889019], [92.79138947, 12.46861172], [92.79165649, 12.46833038], [92.79250336, 12.4683342], [92.79277802, 12.46805573], [92.79305267, 12.46805573], [92.79360962, 12.46749973], [92.79383087, 12.46741104], [92.79421997, 12.46699047], [92.7946167, 12.46661091], [92.79508209, 12.46632195], [92.79556274, 12.46605968], [92.79602051, 12.46581841], [92.79646301, 12.46556091], [92.79689789, 12.46530342], [92.79732513, 12.46503162], [92.79776001, 12.46477032], [92.79817963, 12.46452141], [92.79846954, 12.46420002], [92.79846191, 12.46380138], [92.79824829, 12.46336079], [92.7979126, 12.46289158], [92.79756165, 12.46236134], [92.79722595, 12.46179104], [92.79693604, 12.46124172], [92.79666901, 12.46068954], [92.79650116, 12.46012497], [92.79663086, 12.45953178], [92.79677582, 12.45893097], [92.79697418, 12.45841789], [92.79720306, 12.45800114], [92.79738617, 12.45757008], [92.79750061, 12.4570961], [92.79759979, 12.45660114], [92.79773712, 12.45609283], [92.79777527, 12.45558453], [92.7977829, 12.45508957], [92.7977829, 12.45463657], [92.7978363, 12.45423985], [92.79805756, 12.45388889], [92.79805756, 12.45361137], [92.79750061, 12.45305538], [92.79750061, 12.4525013], [92.79722595, 12.45222092], [92.79722595, 12.45166683], [92.79666901, 12.45111084], [92.79666901, 12.45083141], [92.79638672, 12.45055485], [92.79638672, 12.45028114], [92.79611206, 12.4500103], [92.79611206, 12.44972134], [92.79582977, 12.44944477], [92.79582977, 12.44888878], [92.79556274, 12.44861126], [92.79555511, 12.44805527], [92.79444122, 12.44694042], [92.79444122, 12.44666672], [92.79416656, 12.44639111], [92.79416656, 12.44610977], [92.79416656, 12.44553185], [92.79416656, 12.44492054], [92.79412079, 12.4443512], [92.79393768, 12.44390202], [92.79389191, 12.44346046], [92.79387665, 12.44297886], [92.79386902, 12.44248676], [92.79377747, 12.44198132], [92.79364014, 12.44146061], [92.79360962, 12.44093704], [92.79360962, 12.4404192], [92.79360962, 12.43991089], [92.79366302, 12.43941021], [92.79386139, 12.43895245], [92.79400635, 12.43851185], [92.79419708, 12.43818092], [92.79441833, 12.43791008], [92.79463959, 12.43762112], [92.79499054, 12.43741131], [92.7953949, 12.43717575], [92.79579926, 12.43684959], [92.79623413, 12.43654537], [92.79677582, 12.43637943], [92.79734802, 12.43638134], [92.7979126, 12.43644238], [92.79840088, 12.43660355], [92.79881287, 12.43666553], [92.79917145, 12.43671989], [92.79949188, 12.4368906], [92.79991913, 12.43698025], [92.80039215, 12.43708706], [92.8008728, 12.43727016], [92.80134583, 12.4374609], [92.80185699, 12.43757057], [92.80232239, 12.43776035], [92.8028183, 12.43793106], [92.80335236, 12.43809891], [92.80388641, 12.43834114], [92.80446625, 12.43857956], [92.80509186, 12.4386692], [92.8057785, 12.43839073], [92.80632782, 12.43802166], [92.8066864, 12.43760681], [92.80696869, 12.43718147], [92.80729675, 12.4367609], [92.80770111, 12.43631172], [92.80817413, 12.43587875], [92.80869293, 12.43545341], [92.80914307, 12.43500423], [92.80950165, 12.43455505], [92.80989838, 12.43417931], [92.81030273, 12.43386936], [92.81072235, 12.43361187], [92.81112671, 12.43338108], [92.81163025, 12.43328953], [92.8121109, 12.4331007], [92.81260681, 12.4330101], [92.81310272, 12.43282986], [92.81363678, 12.43278027], [92.81420135, 12.43278027], [92.81476593, 12.43277073], [92.81532288, 12.43272972], [92.81581116, 12.43256092], [92.81630707, 12.43250942], [92.81680298, 12.43250179], [92.81729126, 12.43244934], [92.81777191, 12.43227196], [92.81830597, 12.4321804], [92.81886292, 12.43198013], [92.81946564, 12.43180943], [92.82009888, 12.43169022], [92.82074738, 12.43167019], [92.82137299, 12.43164921], [92.82195282, 12.43161488], [92.82245636, 12.43142414], [92.82296753, 12.43130302], [92.8234024, 12.43109989], [92.82380676, 12.43087196], [92.82427216, 12.43071938], [92.82470703, 12.43054199], [92.82514191, 12.43033409], [92.8256073, 12.43021107], [92.8259964, 12.42999172], [92.82637787, 12.42977142], [92.82678986, 12.42959976], [92.82720184, 12.42943192], [92.82758331, 12.42919922], [92.82800293, 12.42906857], [92.82836914, 12.42891026], [92.82888794, 12.42888927], [92.82917023, 12.42860889], [92.82944489, 12.4286108], [92.83027649, 12.4277792], [92.83026886, 12.42750072], [92.82888794, 12.42611122], [92.82888794, 12.42555523], [92.82861328, 12.42528057], [92.82861328, 12.42306232], [92.82888794, 12.42278099], [92.82888794, 12.42167091], [92.82917023, 12.42139053], [92.82917023, 12.42082977], [92.82944489, 12.42055416], [92.82943726, 12.42000103], [92.82994843, 12.4196701], [92.83053589, 12.4193306], [92.83084869, 12.41908741], [92.83123016, 12.41868973], [92.83198547, 12.41813564], [92.83242798, 12.41783142], [92.83286285, 12.4174118], [92.83305359, 12.41666603], [92.83304596, 12.41639137], [92.83333588, 12.41611004], [92.83333588, 12.41556072], [92.83361053, 12.4152813], [92.83361053, 12.41471958], [92.83388519, 12.41444397], [92.83388519, 12.41333199], [92.83416748, 12.41305637], [92.83416748, 12.41222191], [92.83444214, 12.41194439], [92.83444214, 12.4113903], [92.8347168, 12.41110992], [92.8347168, 12.41055965], [92.83389282, 12.40971947], [92.83388519, 12.40916634], [92.83416748, 12.40888977], [92.83472443, 12.40944386], [92.83555603, 12.40944386], [92.83583069, 12.40916634], [92.83640289, 12.40914059], [92.83692932, 12.40893841], [92.83751678, 12.40885067], [92.83807373, 12.40867805], [92.83864594, 12.40847969], [92.83925629, 12.4083004], [92.83982086, 12.40802193], [92.84030914, 12.40764141], [92.84076691, 12.40725994], [92.8411026, 12.40683174], [92.84137726, 12.40639019], [92.84159851, 12.40594769], [92.84166718, 12.40543938], [92.84172058, 12.40492439], [92.84185028, 12.40441799], [92.84168243, 12.40387058], [92.84146881, 12.4033289], [92.84125519, 12.40284348], [92.84096527, 12.4024744], [92.84055328, 12.4024992], [92.84055328, 12.4019413], [92.83999634, 12.40138912], [92.83999634, 12.40111065], [92.83972168, 12.40083122], [92.83972168, 12.40055466], [92.83943939, 12.40028191], [92.83943939, 12.40000057], [92.83889008, 12.3994379], [92.83889008, 12.39916706], [92.83833313, 12.39861107], [92.83833313, 12.39833069], [92.83805847, 12.39805698], [92.83833313, 12.39778137], [92.83833313, 12.39722061], [92.83860779, 12.396945], [92.83860779, 12.39638901], [92.83833313, 12.39611053], [92.83833313, 12.39583302], [92.83860779, 12.39555454], [92.83860779, 12.39500141], [92.83889008, 12.39472008], [92.83889008, 12.39444542], [92.83972168, 12.39361095], [92.83972168, 12.39332962], [92.84027863, 12.39277554], [92.84055328, 12.39277554], [92.84139252, 12.39194393], [92.84166718, 12.39194393], [92.84194183, 12.39166641], [92.84249878, 12.39167118], [92.84278107, 12.3913908], [92.84302521, 12.39140224], [92.84339905, 12.39134121], [92.84378815, 12.3911562], [92.84426117, 12.39100075], [92.8446579, 12.39073944], [92.84500122, 12.39036274], [92.84535217, 12.38995266], [92.84577179, 12.38961983], [92.846138, 12.38922977], [92.84648895, 12.38883972], [92.84671021, 12.38841915], [92.8469162, 12.3880024], [92.84706116, 12.38752079], [92.84723663, 12.38704014], [92.84748077, 12.38661766], [92.84767914, 12.38624001], [92.84790802, 12.38598919], [92.8481369, 12.38582039], [92.84838104, 12.38564491], [92.84866333, 12.38549042], [92.84893799, 12.38527107], [92.84921265, 12.38500023], [92.84947968, 12.3846693], [92.84970856, 12.3842411], [92.84984589, 12.38370132], [92.84978485, 12.38310814], [92.84977722, 12.38251972], [92.84997559, 12.38201237], [92.85012817, 12.38154316], [92.85029602, 12.38111877], [92.85051727, 12.38073063], [92.85071564, 12.38031864], [92.85098267, 12.37994003], [92.85118866, 12.37950993], [92.85144043, 12.37909889], [92.85167694, 12.37866402], [92.85193634, 12.37823963], [92.85223389, 12.37782955], [92.85256958, 12.37745094], [92.85296631, 12.37712097], [92.85331726, 12.37671471], [92.85372925, 12.37637329], [92.85413361, 12.3760128], [92.85450745, 12.37561703], [92.85489655, 12.37524986], [92.85527802, 12.37486172], [92.85564423, 12.37448597], [92.85604095, 12.37416267], [92.85642242, 12.37386036], [92.85677338, 12.37359142], [92.856987, 12.37331009], [92.8571167, 12.37307072], [92.85726166, 12.37289333], [92.85756683, 12.37294102], [92.85791779, 12.37291145], [92.85832214, 12.37275887], [92.85877228, 12.37248993], [92.85926056, 12.37213039], [92.85968781, 12.3716917], [92.86000824, 12.3710947], [92.86023712, 12.37042904], [92.86022949, 12.36971188], [92.86000061, 12.36905956], [92.85968018, 12.36849022], [92.85927582, 12.36806107], [92.85916901, 12.36806107], [92.85832977, 12.36721992], [92.85832977, 12.36694527], [92.85805511, 12.36666679], [92.85806274, 12.36639118], [92.85832977, 12.36610985], [92.85832977, 12.36583233], [92.85861206, 12.36555672], [92.85865021, 12.36515999], [92.8588562, 12.36470222], [92.8589859, 12.36422062], [92.85916138, 12.36377907], [92.85935974, 12.36334133], [92.85957336, 12.36292744], [92.85980225, 12.36254978], [92.86006927, 12.36224079], [92.86036682, 12.36198521], [92.86070251, 12.36179161], [92.86105347, 12.3616066], [92.86139679, 12.36141109], [92.86178589, 12.36127186], [92.86221313, 12.36118984], [92.86267853, 12.36135197], [92.86319733, 12.36145687], [92.86367798, 12.36162281], [92.86418152, 12.36166191], [92.8646698, 12.36169147], [92.86511993, 12.36180115], [92.86557007, 12.36192131], [92.86602783, 12.36194897], [92.86649323, 12.36200142], [92.86692047, 12.36216068], [92.86738586, 12.3621397], [92.86777496, 12.36220932], [92.86786652, 12.36221313], [92.86815643, 12.36222172], [92.86833191, 12.36222172], [92.8686142, 12.3619442], [92.86888885, 12.3619442], [92.86972046, 12.36110973], [92.86972046, 12.36083031], [92.87000275, 12.36055565], [92.87000275, 12.35888958], [92.86972046, 12.35861015], [92.86972046, 12.35750008], [92.87000275, 12.3572197], [92.87021637, 12.35687542], [92.87038422, 12.35656548], [92.87056732, 12.35627079], [92.87082672, 12.35595036], [92.87111664, 12.35553074], [92.87140656, 12.35505199], [92.87168121, 12.35458946], [92.87197113, 12.35422039], [92.87223816, 12.35392189], [92.87250519, 12.35369396], [92.87275696, 12.35351372], [92.87302399, 12.35336781], [92.87333679, 12.35333061], [92.873703, 12.35333061], [92.87404633, 12.35334969], [92.87442017, 12.35343933], [92.87479401, 12.35359955], [92.87523651, 12.35378265], [92.87571716, 12.35404205], [92.87621307, 12.35436153], [92.87677765, 12.3545208], [92.87718201, 12.35481071], [92.87745667, 12.35516167], [92.87766266, 12.35557175], [92.87782288, 12.35602093], [92.87800598, 12.35653114], [92.87812805, 12.35712242], [92.87851715, 12.35764122], [92.87918854, 12.35791016], [92.87973785, 12.35780525], [92.87991333, 12.35777092], [92.88046265, 12.35739136], [92.88082886, 12.35696888], [92.88111115, 12.35658073], [92.8813858, 12.35627365], [92.88166046, 12.35603428], [92.88194275, 12.3558569], [92.88224792, 12.3557806], [92.88260651, 12.35570908], [92.88301086, 12.35586071], [92.88349152, 12.35604095], [92.88401031, 12.35593033], [92.88446045, 12.35561085], [92.88485718, 12.35527992], [92.88520813, 12.3549614], [92.88548279, 12.35462093], [92.88564301, 12.35423183], [92.88580322, 12.35386944], [92.88583374, 12.35348034], [92.88582611, 12.35305977], [92.88582611, 12.35263157], [92.88587189, 12.35224724], [92.88607025, 12.35195923], [92.88629913, 12.35171127], [92.88637543, 12.35140991], [92.88650513, 12.3511343], [92.88673401, 12.3509407], [92.8870163, 12.35088062], [92.88733673, 12.35096073], [92.88771057, 12.35108185], [92.88813019, 12.35111237], [92.88860321, 12.35111237], [92.88912201, 12.35109138], [92.88961792, 12.35095024], [92.8899765, 12.35037994], [92.89025879, 12.34988976], [92.89045715, 12.3494997], [92.89045715, 12.34913063], [92.89029694, 12.3487711], [92.89015198, 12.34838963], [92.8899765, 12.34804153], [92.88986969, 12.34773827], [92.88999176, 12.34743118], [92.89019012, 12.34713173], [92.89041901, 12.34678078], [92.89077759, 12.34649563], [92.89103699, 12.34614086], [92.89111328, 12.34570122], [92.89115143, 12.34523106], [92.89131165, 12.34476376], [92.89142609, 12.34423542], [92.89138794, 12.34388924], [92.89193726, 12.3430624], [92.89193726, 12.34222126], [92.89221954, 12.34194469], [92.89305878, 12.34083271], [92.89499664, 12.33888912], [92.89499664, 12.33806133], [92.89527893, 12.33778095], [92.89527893, 12.33750057], [92.89554596, 12.33722019], [92.89555359, 12.33694363], [92.89583588, 12.33666611], [92.89583588, 12.33639145], [92.89611053, 12.33582973], [92.89555359, 12.33527756], [92.89499664, 12.33527756], [92.89444733, 12.33583355], [92.89417267, 12.33582973], [92.89305878, 12.33805656], [92.89277649, 12.33833027], [92.89277649, 12.33889103], [92.89250183, 12.33916664], [92.89250183, 12.33944035], [92.89167023, 12.34027863], [92.89141083, 12.34049511], [92.89103699, 12.34055042], [92.89058685, 12.34061241], [92.8901062, 12.34083462], [92.88960266, 12.34111118], [92.88912201, 12.34142113], [92.88874054, 12.34176922], [92.88851166, 12.34220028], [92.88832855, 12.34261036], [92.88813019, 12.34296131], [92.88792419, 12.34322834], [92.88777924, 12.34360886], [92.88748932, 12.34389114], [92.88582611, 12.34389114], [92.88560486, 12.3436594], [92.88527679, 12.34361076], [92.88500214, 12.34333324], [92.88475037, 12.34330273], [92.88409424, 12.34307766], [92.88366699, 12.34329033], [92.88333893, 12.34363842], [92.88301849, 12.34396362], [92.88262939, 12.34418488], [92.88246918, 12.34426308], [92.88223267, 12.34438133], [92.88182831, 12.34431267], [92.88144684, 12.34410954], [92.88116455, 12.34387779], [92.8809433, 12.34364986], [92.8807373, 12.34340954], [92.88070679, 12.34297276], [92.88058472, 12.34253502], [92.88054657, 12.34210014], [92.8805542, 12.341712], [92.8805542, 12.34134483], [92.88050079, 12.34101868], [92.88037109, 12.34075069], [92.88025665, 12.34043789], [92.88011932, 12.34010983], [92.88008118, 12.33975029], [92.88024139, 12.3393507], [92.88041687, 12.33885193], [92.88058472, 12.33831882], [92.88078308, 12.33778954], [92.88082886, 12.33716965], [92.88080597, 12.33652973], [92.88065338, 12.33590984], [92.88056946, 12.33528137], [92.88046265, 12.33468628], [92.88008118, 12.33420944], [92.87969208, 12.33383083], [92.87969208, 12.33353043], [92.87998199, 12.3334074], [92.88040161, 12.33348179], [92.88085938, 12.33370113], [92.88131714, 12.33393955], [92.88181305, 12.33404064], [92.88235474, 12.33410454], [92.88286591, 12.33399487], [92.88321686, 12.33368969], [92.88345337, 12.33343506], [92.88329315, 12.33308983], [92.88278961, 12.33271027], [92.88202667, 12.33248043], [92.8813858, 12.33222198], [92.88111115, 12.33222198], [92.88111115, 12.33166599], [92.88168335, 12.33111191], [92.88194275, 12.33111191], [92.8829422, 12.33154106], [92.88349915, 12.33193016], [92.88404083, 12.33218956], [92.88436127, 12.33205795], [92.88449097, 12.33200264], [92.88500977, 12.33194923], [92.88556671, 12.3319416], [92.88614655, 12.33195114], [92.88671875, 12.3319416], [92.88726044, 12.33187103], [92.88772583, 12.33166599], [92.88815308, 12.33141136], [92.88854218, 12.33113861], [92.88873291, 12.33068085], [92.88873291, 12.33003044], [92.8887558, 12.32941914], [92.88852692, 12.32909012], [92.88822174, 12.32885075], [92.88792419, 12.32861233], [92.88761139, 12.32835197], [92.88730621, 12.32808113], [92.88724518, 12.32769585], [92.88733673, 12.32730103], [92.88759613, 12.32694054], [92.88789368, 12.32655811], [92.88815308, 12.32602978], [92.88851166, 12.32560062], [92.88900757, 12.32529259], [92.889534, 12.32505608], [92.8900528, 12.32491112], [92.89048004, 12.32481861], [92.89081573, 12.32492733], [92.89115906, 12.32498074], [92.89154053, 12.32506084], [92.89196014, 12.32526398], [92.89245605, 12.32546043], [92.89307404, 12.32554626], [92.89367676, 12.32556152], [92.89422607, 12.32561016], [92.89472198, 12.32581997], [92.89521027, 12.32613182], [92.89572906, 12.32646275], [92.89631653, 12.32653999], [92.89679718, 12.32629204], [92.89700317, 12.32578087], [92.89694977, 12.32537079], [92.89676666, 12.32506084], [92.8965683, 12.32473087], [92.89636993, 12.32440186], [92.89622498, 12.32403088], [92.89611816, 12.32363033], [92.89599609, 12.32324696], [92.89581299, 12.3229208], [92.89563751, 12.32259274], [92.89556885, 12.32218933], [92.89554596, 12.32173061], [92.89552307, 12.32122993], [92.89539337, 12.32074165], [92.89511871, 12.32034492], [92.89476013, 12.32008076], [92.89432526, 12.32001495], [92.89386749, 12.32004166], [92.89342499, 12.32016087], [92.89293671, 12.320261], [92.89245605, 12.3203907], [92.89206696, 12.32063007], [92.89176941, 12.32091141], [92.89149475, 12.32116795], [92.8911972, 12.32118416], [92.89093781, 12.32110691], [92.89080811, 12.32106781], [92.89035034, 12.32088089], [92.88981628, 12.32080078], [92.88932037, 12.3209486], [92.88891602, 12.32125854], [92.88852692, 12.32165146], [92.88812256, 12.32205868], [92.88775635, 12.32248116], [92.88732147, 12.32279968], [92.88690948, 12.32308292], [92.88651276, 12.32329178], [92.88610077, 12.32333088], [92.88575745, 12.32322216], [92.88538361, 12.32302761], [92.88508606, 12.3227911], [92.8848114, 12.32256508], [92.88462067, 12.32224178], [92.88439941, 12.32189846], [92.8841629, 12.32148266], [92.88388062, 12.32098103], [92.88352203, 12.3204298], [92.88300323, 12.31995773], [92.88247681, 12.31957054], [92.88201904, 12.31923962], [92.88168335, 12.31889057], [92.88140869, 12.31849003], [92.88117981, 12.31805897], [92.8809433, 12.31760979], [92.88069153, 12.317173], [92.88051605, 12.31668091], [92.88037109, 12.31614971], [92.88012695, 12.3156004], [92.87979126, 12.31509876], [92.87934113, 12.31462002], [92.87888336, 12.31416035], [92.87845612, 12.31363106], [92.87812805, 12.3131752], [92.87787628, 12.31322098], [92.87756348, 12.31341934], [92.87722015, 12.31375027], [92.87683868, 12.31412983], [92.87637329, 12.31446075], [92.8758316, 12.31471062], [92.87523651, 12.31490993], [92.87464905, 12.31512356], [92.87423706, 12.31554985], [92.87390137, 12.31601143], [92.8736496, 12.31643677], [92.87354279, 12.31682014], [92.87336731, 12.31707859], [92.87323761, 12.31731033], [92.87303925, 12.31751919], [92.87277222, 12.317729], [92.87241364, 12.31776333], [92.87201691, 12.31767654], [92.87164307, 12.31747055], [92.87127686, 12.31719971], [92.87097931, 12.31689262], [92.87078094, 12.3164854], [92.87055206, 12.31608105], [92.87031555, 12.31565666], [92.87016296, 12.31516266], [92.86995697, 12.31466103], [92.86968994, 12.31427383], [92.86936188, 12.31399632], [92.86897278, 12.31388187], [92.86860657, 12.31377029], [92.86827087, 12.31371975], [92.86791229, 12.31386757], [92.86751556, 12.31400299], [92.86710358, 12.31418037], [92.86668396, 12.31441116], [92.86623383, 12.31458569], [92.86582184, 12.31464481], [92.86547852, 12.3144722], [92.86518097, 12.31433105], [92.86499023, 12.31416035], [92.86480713, 12.31396198], [92.86464691, 12.31374073], [92.86440277, 12.31359005], [92.86414337, 12.31341171], [92.86384583, 12.313241], [92.86348724, 12.31313229], [92.86307526, 12.31317997], [92.86271667, 12.31337357], [92.8622818, 12.31355953], [92.86190796, 12.31382656], [92.86146545, 12.31388378], [92.86101532, 12.31384468], [92.86060333, 12.31370163], [92.86011505, 12.31368446], [92.85958099, 12.31385231], [92.85909271, 12.31399059], [92.85862732, 12.31412792], [92.85818481, 12.31418514], [92.8577652, 12.31424427], [92.85739136, 12.31434441], [92.85701752, 12.31421947], [92.8565979, 12.31392956], [92.85609436, 12.31352901], [92.8555069, 12.31320858], [92.85492706, 12.31329155], [92.85473633, 12.31329441], [92.85437775, 12.31330109], [92.85388184, 12.31317997], [92.85346985, 12.31306076], [92.85312653, 12.31295872], [92.85286713, 12.31278992], [92.85262299, 12.31260967], [92.85234833, 12.31237125], [92.85198212, 12.31213093], [92.8515625, 12.31182766], [92.8511734, 12.31146145], [92.85077667, 12.31110096], [92.8504715, 12.31076622], [92.85015869, 12.31052017], [92.8499527, 12.31023121], [92.84973907, 12.30994129], [92.84959412, 12.30960178], [92.8494339, 12.30926704], [92.84924316, 12.30896091], [92.84905243, 12.30865097], [92.84879303, 12.30838013], [92.84841919, 12.30816078], [92.84793854, 12.30795193], [92.84736633, 12.30780792], [92.84671021, 12.30778122], [92.84599304, 12.30772972], [92.84529114, 12.30755043], [92.84451294, 12.30750275], [92.84373474, 12.30749798], [92.84298706, 12.30747128], [92.84233856, 12.30734062], [92.84173584, 12.30723953], [92.84118652, 12.30718613], [92.84073639, 12.30703068], [92.84030151, 12.30692101], [92.83989716, 12.30674076], [92.83946228, 12.30663872], [92.83904266, 12.30646133], [92.83857727, 12.30635166], [92.83815002, 12.30611038], [92.83768463, 12.30583191], [92.83719635, 12.3054924], [92.83678436, 12.30502319], [92.8363266, 12.30459023], [92.83580017, 12.30430889], [92.83526611, 12.30414963], [92.83477783, 12.30397034], [92.83430481, 12.3038578], [92.83390808, 12.30365086], [92.83361053, 12.30342102], [92.83332062, 12.30320644], [92.83302307, 12.30298996], [92.83272552, 12.30273724], [92.83242798, 12.3025589], [92.8320694, 12.30267525], [92.83168793, 12.30298328], [92.83132935, 12.30337048], [92.83094025, 12.30378056], [92.83053589, 12.30414772], [92.83008575, 12.30444431], [92.82965851, 12.30472183], [92.82926178, 12.3049984], [92.82887268, 12.3052597], [92.82846832, 12.30555153], [92.82801819, 12.30582142], [92.82752991, 12.30608654], [92.82706451, 12.30638123], [92.82660675, 12.30666161], [92.8261795, 12.30691528], [92.825737, 12.30709457], [92.82530975, 12.30728054], [92.82489777, 12.30750275], [92.82447052, 12.30773735], [92.82402802, 12.30792046], [92.82364655, 12.30812931], [92.82330322, 12.30836201], [92.82298279, 12.30860996], [92.82263184, 12.30883121], [92.82217407, 12.3089571], [92.82170105, 12.30914116], [92.82121277, 12.30927277], [92.82074738, 12.30951023], [92.82032776, 12.3097496], [92.81998444, 12.30999374], [92.819664, 12.31020641], [92.81929016, 12.31036091], [92.81887054, 12.31060028], [92.81842041, 12.31085968], [92.81794739, 12.31114006], [92.81742859, 12.31140041], [92.81684113, 12.31163502], [92.81616974, 12.31183147], [92.8156662, 12.31212044], [92.81552124, 12.31244087], [92.81533813, 12.31270123], [92.81504059, 12.31287003], [92.81472015, 12.31306076], [92.81433868, 12.31326199], [92.8138504, 12.31338692], [92.81331635, 12.31355953], [92.81272888, 12.31366539], [92.81220245, 12.31389332], [92.8117218, 12.31416416], [92.81125641, 12.31442165], [92.81078339, 12.31462002], [92.81022644, 12.31474113], [92.80969238, 12.31487083], [92.80914307, 12.31492138], [92.80861664, 12.3147707], [92.80809021, 12.31468201], [92.80762482, 12.31450558], [92.80715179, 12.31440067], [92.8067627, 12.31419182], [92.80635834, 12.31400013], [92.80591583, 12.31386375], [92.80545807, 12.31365585], [92.80490112, 12.31355953], [92.80434418, 12.31340981], [92.80374908, 12.31329155], [92.80323029, 12.31305695], [92.80271149, 12.3127718], [92.80222321, 12.31243229], [92.80185699, 12.31192207], [92.80139923, 12.31161594], [92.80094147, 12.31134129], [92.80054474, 12.31102371], [92.80018616, 12.31070042], [92.79995728, 12.31025791], [92.79971313, 12.30985165], [92.79944611, 12.30946541], [92.79915619, 12.30908203], [92.79885101, 12.30870056], [92.79850006, 12.30834961], [92.79811859, 12.30801964], [92.79775238, 12.30770111], [92.79734039, 12.30746078], [92.79696655, 12.30718136], [92.79659271, 12.30688858], [92.79618073, 12.30664063], [92.79579926, 12.30639267], [92.7954483, 12.30618095], [92.79509735, 12.30614376], [92.79476166, 12.30629158], [92.79444885, 12.30659103], [92.79418945, 12.30695057], [92.79403687, 12.30735016], [92.79389191, 12.30772114], [92.79373932, 12.30806065], [92.79358673, 12.30838013], [92.79341888, 12.30869007], [92.79328156, 12.30906105], [92.79306793, 12.30939198], [92.79286194, 12.3097496], [92.79263306, 12.3101387], [92.7923584, 12.31052017], [92.79199982, 12.31083012], [92.79160309, 12.31110096], [92.79117584, 12.3113308], [92.79083252, 12.31162071], [92.79042053, 12.31179047], [92.79003906, 12.31198978], [92.78965759, 12.31218243], [92.78919983, 12.31221962], [92.78874207, 12.31222343], [92.78827667, 12.31223202], [92.78784943, 12.31231785], [92.7874527, 12.31250954], [92.78707123, 12.31276703], [92.78665924, 12.31300354], [92.78620911, 12.31320858], [92.78566742, 12.31336021], [92.78509521, 12.31350613], [92.78450775, 12.31359482], [92.78390503, 12.31361294], [92.78329468, 12.31361294], [92.78272247, 12.31358814], [92.78222656, 12.31347179], [92.78177643, 12.3133297], [92.78139496, 12.31319618], [92.78100586, 12.31308174], [92.78057098, 12.31302929], [92.78011322, 12.31297684], [92.77958679, 12.31311131], [92.77909851, 12.31343079], [92.77867889, 12.3138504], [92.77822876, 12.31425953], [92.77773285, 12.31457043], [92.77719116, 12.3147707], [92.77671051, 12.31499863], [92.77627563, 12.31520367], [92.77581024, 12.31531143], [92.77540588, 12.31555939], [92.77490997, 12.3158102], [92.77429199, 12.31601143], [92.77374268, 12.31629086], [92.77339172, 12.31667137], [92.77327728, 12.31707859], [92.77320862, 12.31740093], [92.77333069, 12.31769943], [92.77345276, 12.31799126], [92.77334595, 12.31820107], [92.77310181, 12.31840134], [92.77277374, 12.31840801], [92.7724762, 12.31859112], [92.77220917, 12.31917191], [92.77189636, 12.31958199], [92.77152252, 12.3196907], [92.77114868, 12.319561], [92.7709198, 12.31937027], [92.77099609, 12.31916046], [92.77128601, 12.31885719], [92.77172852, 12.31844044], [92.77189636, 12.31807137], [92.7718811, 12.31775188], [92.77169037, 12.31747055], [92.77152252, 12.31707001], [92.77133179, 12.31662369], [92.7710495, 12.3161974], [92.7706604, 12.31582069], [92.77025604, 12.31544113], [92.76984406, 12.31511497], [92.76947021, 12.31480026], [92.76917267, 12.3144474], [92.76895905, 12.31404972], [92.76883698, 12.31359005], [92.76863098, 12.3132], [92.76850128, 12.31274891], [92.76838684, 12.31226635], [92.76825714, 12.31175137], [92.76808167, 12.31125164], [92.76792145, 12.31073189], [92.76764679, 12.31029034], [92.76734924, 12.30991173], [92.7671814, 12.3094511], [92.76703644, 12.3089571], [92.76692963, 12.30842972], [92.76677704, 12.30788136], [92.76663971, 12.30735207], [92.76643372, 12.30682278], [92.76638794, 12.30620098], [92.76638794, 12.30556965], [92.76634216, 12.30494118], [92.7661438, 12.30443287], [92.76598358, 12.30398083], [92.76582336, 12.30359173], [92.76560211, 12.30325031], [92.76541138, 12.30291939], [92.7652359, 12.30262089], [92.7650528, 12.30237007], [92.7648468, 12.30208969], [92.76463318, 12.3018589], [92.76435852, 12.3017292], [92.76403046, 12.30188179], [92.76370239, 12.30235195], [92.76361847, 12.3029604], [92.76357269, 12.30351162], [92.76345062, 12.30393124], [92.76335144, 12.30428886], [92.76332855, 12.30463982], [92.76329041, 12.30500031], [92.76313782, 12.30539036], [92.7631073, 12.30583191], [92.76326752, 12.30631065], [92.76332855, 12.30685139], [92.76338196, 12.30738163], [92.76358032, 12.30782795], [92.76370239, 12.30833435], [92.76379395, 12.30889511], [92.76387024, 12.30951023], [92.76394653, 12.31015968], [92.76418304, 12.31074142], [92.76442719, 12.31122017], [92.76461792, 12.31155014], [92.7645874, 12.31177998], [92.76442719, 12.31198788], [92.76420593, 12.31219101], [92.76393127, 12.31234074], [92.76364136, 12.31221962], [92.7633667, 12.31190109], [92.76315308, 12.31140709], [92.76304626, 12.31074142], [92.76283264, 12.31054974], [92.76255798, 12.31039047], [92.76229095, 12.31005955], [92.7620163, 12.30960178], [92.7617569, 12.30909061], [92.76158905, 12.30855083], [92.76138306, 12.30808067], [92.76117706, 12.30767822], [92.76101685, 12.30726147], [92.76081085, 12.30688], [92.76052094, 12.3064909], [92.76018524, 12.30614376], [92.7598114, 12.30583191], [92.75940704, 12.30552197], [92.75901794, 12.3052187], [92.75869751, 12.30482006], [92.75834656, 12.30441189], [92.75805664, 12.30394268], [92.75776672, 12.30346203], [92.7575531, 12.3030014], [92.75749969, 12.30246067], [92.75749969, 12.30194092], [92.75749969, 12.30142021], [92.75751495, 12.30088615], [92.75759125, 12.30035114], [92.75776672, 12.29983997], [92.75790405, 12.2993269], [92.75801086, 12.29887104], [92.75792694, 12.29840183], [92.75769806, 12.2979784], [92.7574234, 12.29757023], [92.75702667, 12.2972374], [92.75656128, 12.2969389], [92.75605011, 12.29663754], [92.75553894, 12.29626179], [92.75495148, 12.29593563], [92.75476837, 12.295681], [92.75418091, 12.29588127], [92.75353241, 12.29588127], [92.75322723, 12.2961092], [92.75300598, 12.2963829], [92.75276184, 12.29666996], [92.75244141, 12.2970047], [92.75203705, 12.29738998], [92.75160217, 12.29777527], [92.7512207, 12.29810143], [92.7509613, 12.29836082], [92.75076294, 12.29854965], [92.75052643, 12.29865932], [92.75032043, 12.29882145], [92.75006104, 12.29891014], [92.74982452, 12.29904938], [92.74957275, 12.29916954], [92.74928284, 12.29933167], [92.74897766, 12.2994957], [92.74868011, 12.29970646], [92.74832916, 12.29986095], [92.74794769, 12.29997921], [92.74751282, 12.29997921], [92.7470932, 12.29985142], [92.74668884, 12.29962063], [92.74635315, 12.2993412], [92.74591827, 12.29921055], [92.74545288, 12.29932022], [92.74500275, 12.2996006], [92.74453735, 12.29991531], [92.74411774, 12.30027103], [92.74369049, 12.30063057], [92.74331665, 12.30099106], [92.74294281, 12.30123711], [92.74256134, 12.30137157], [92.74217987, 12.30145359], [92.74185944, 12.30162239], [92.74156952, 12.30162239], [92.74128723, 12.30146122], [92.74091339, 12.30132198], [92.74051666, 12.30111027], [92.74009705, 12.30091095], [92.73963928, 12.30088234], [92.73919678, 12.30104256], [92.73876953, 12.30106354], [92.73836517, 12.30090714], [92.73792267, 12.30084133], [92.73745728, 12.30078125], [92.7370224, 12.30060959], [92.73651123, 12.30058098], [92.73596954, 12.30076122], [92.73557281, 12.30120087], [92.73527527, 12.30166626], [92.7352829, 12.30221939], [92.73500061, 12.30251122], [92.73500061, 12.30278015], [92.73555756, 12.30527973], [92.73640442, 12.30693531], [92.73639679, 12.30831242], [92.73597717, 12.30873108], [92.73557281, 12.30859184], [92.7352829, 12.30666161], [92.73472595, 12.30583191], [92.73444366, 12.3055563], [92.73443604, 12.30443859], [92.73416901, 12.30416584], [92.73417664, 12.30360985], [92.73249817, 12.30194378], [92.73213196, 12.30194092], [92.73171997, 12.30204868], [92.7313385, 12.30224037], [92.73139191, 12.30251122], [92.73110962, 12.30251122], [92.73082733, 12.30278015], [92.72915649, 12.30278015], [92.72888947, 12.30251122], [92.72860718, 12.30251122], [92.72833252, 12.30278015], [92.72750092, 12.30194092], [92.72638702, 12.30194378], [92.72568512, 12.30185318], [92.72480011, 12.30173588], [92.72389221, 12.30167007], [92.7233429, 12.30111027], [92.72305298, 12.30111217], [92.72277832, 12.3008337], [92.72250366, 12.3008337], [92.72222137, 12.30055618], [92.72194672, 12.30056], [92.7216568, 12.30027962], [92.72110748, 12.30027771], [92.7204361, 12.30031013], [92.71980286, 12.30056], [92.7191391, 12.3008976], [92.71871185, 12.3014698], [92.71866608, 12.30221939], [92.71887207, 12.30278015], [92.71904755, 12.30321503], [92.71916199, 12.30355072], [92.7191925, 12.30388069], [92.71910095, 12.30422115], [92.71888733, 12.30455112], [92.71861267, 12.30486965], [92.71833801, 12.30520058], [92.7181015, 12.30558109], [92.71800995, 12.30606937], [92.71781921, 12.30649281], [92.71773529, 12.30690289], [92.71755981, 12.30718136], [92.71740723, 12.30747128], [92.71720886, 12.3077507], [92.71695709, 12.30805016], [92.71675873, 12.30842113], [92.71663666, 12.30884266], [92.71640778, 12.30914593], [92.71617889, 12.3094101], [92.71604919, 12.3097496], [92.71586609, 12.31005096], [92.71583557, 12.31042671], [92.71578217, 12.31079102], [92.71561432, 12.31108761], [92.71554565, 12.31139469], [92.71546173, 12.31164074], [92.71529388, 12.31182098], [92.71508026, 12.31200218], [92.71482086, 12.31221962], [92.71450043, 12.31242085], [92.71411896, 12.31249237], [92.71373749, 12.31243038], [92.71338654, 12.31221771], [92.71305084, 12.31191921], [92.71276093, 12.31152058], [92.71250153, 12.31112003], [92.71222687, 12.3107214], [92.71201324, 12.31032181], [92.71187592, 12.30992126], [92.71166992, 12.30965614], [92.71140289, 12.30952168], [92.71089935, 12.30997086], [92.71038818, 12.31056118], [92.71015167, 12.31111526], [92.70999146, 12.31153393], [92.70981598, 12.31183147], [92.70974731, 12.31214714], [92.70967102, 12.31246376], [92.7095108, 12.31274223], [92.7094574, 12.31306076], [92.70942688, 12.31340122], [92.7093277, 12.31372929], [92.70916748, 12.31410122], [92.708992, 12.3144989], [92.70883942, 12.31488705], [92.70863342, 12.31518269], [92.70842743, 12.31544971], [92.7081604, 12.31572056], [92.70778656, 12.31605244], [92.70738983, 12.31655121], [92.70726013, 12.31731033], [92.7072525, 12.31806183], [92.7073288, 12.31869125], [92.7074585, 12.31921959], [92.70743561, 12.31973743], [92.70728302, 12.32031059], [92.70729828, 12.3209219], [92.7074585, 12.32150078], [92.70749664, 12.32207108], [92.70749664, 12.3226614], [92.70749664, 12.32329178], [92.70751953, 12.32394886], [92.70768738, 12.32460976], [92.70796967, 12.32520008], [92.70835876, 12.32563114], [92.70863342, 12.32612133], [92.70889282, 12.326581], [92.70908356, 12.32703018], [92.70915222, 12.32746124], [92.7091217, 12.32783031], [92.70895386, 12.32813644], [92.7088089, 12.32839108], [92.70862579, 12.32859993], [92.70841217, 12.32883072], [92.70804596, 12.32914066], [92.70753479, 12.3294096], [92.70694733, 12.32972431], [92.70632935, 12.33006096], [92.70571899, 12.33036518], [92.70514679, 12.33048534], [92.70492554, 12.33040142], [92.70464325, 12.33029556], [92.70414734, 12.33007145], [92.70372009, 12.32978058], [92.70346832, 12.32929993], [92.70330811, 12.32870102], [92.70305634, 12.32818127], [92.70278168, 12.32774067], [92.70249176, 12.32735157], [92.70217896, 12.32700729], [92.70178986, 12.32670021], [92.70128632, 12.32648754], [92.70069122, 12.32643127], [92.70011902, 12.32662201], [92.69975281, 12.32713032], [92.69950867, 12.32779121], [92.69944763, 12.3284874], [92.69944, 12.3291111], [92.69944763, 12.32968998], [92.69947815, 12.33025074], [92.69962311, 12.33076096], [92.69976807, 12.33125114], [92.69997406, 12.33165932], [92.70016479, 12.33203316], [92.70031738, 12.33241272], [92.70046234, 12.33281231], [92.70053101, 12.33327961], [92.70054626, 12.33383083], [92.70056152, 12.33441925], [92.7006073, 12.33502102], [92.70079041, 12.33557892], [92.70082092, 12.33615971], [92.70083618, 12.33675957], [92.70083618, 12.33735466], [92.70083618, 12.3379631], [92.70083618, 12.33980179], [92.70083618, 12.34041595], [92.70083618, 12.34101868], [92.70083618, 12.34162998], [92.70082855, 12.34222698], [92.70078278, 12.34282017], [92.7006073, 12.34340096], [92.70055389, 12.34403896], [92.70054626, 12.34469986], [92.70066071, 12.34535027], [92.70089722, 12.34593105], [92.70108032, 12.34650135], [92.70111084, 12.34709263], [92.70111084, 12.34769058], [92.70111084, 12.34830093], [92.70105743, 12.34890079], [92.70088196, 12.34947968], [92.70083618, 12.35009003], [92.70083618, 12.35068989], [92.70082855, 12.35127258], [92.70079041, 12.35181999], [92.70062256, 12.35232162], [92.70049286, 12.35282993], [92.70032501, 12.3533287], [92.70033264, 12.3538599], [92.7004776, 12.35435009], [92.70069885, 12.35479546], [92.7008667, 12.35527134], [92.70110321, 12.35568142], [92.70132446, 12.35608482], [92.70143127, 12.35654259], [92.70162201, 12.3570013], [92.70166016, 12.3575201], [92.70162201, 12.35806274], [92.70144653, 12.35860062], [92.70142365, 12.35915947], [92.70152283, 12.35972881], [92.70157623, 12.36030293], [92.70139313, 12.36085033], [92.70110321, 12.36139965], [92.70079803, 12.36195087], [92.70052338, 12.36250019], [92.70027161, 12.36304092], [92.70005035, 12.36360073], [92.69999695, 12.36425114], [92.69999695, 12.36492062], [92.70001221, 12.36557007], [92.7000885, 12.36616993], [92.70027161, 12.36668015], [92.70048523, 12.3671484], [92.70075226, 12.36759377], [92.70102692, 12.36802006], [92.70137024, 12.36839199], [92.70170593, 12.36870193], [92.70211029, 12.36885166], [92.70256805, 12.36881065], [92.70304871, 12.36864853], [92.70355988, 12.36861992], [92.70402527, 12.36868572], [92.70437622, 12.36888027], [92.70465851, 12.36909199], [92.70491791, 12.36923504], [92.70510864, 12.36942196], [92.70529175, 12.36961079], [92.70546722, 12.36979961], [92.70553589, 12.37004185], [92.70555878, 12.37029266], [92.70555878, 12.37055016], [92.70552063, 12.3707962], [92.70535278, 12.37101269], [92.70504761, 12.37122726], [92.70471191, 12.3715353], [92.70433044, 12.37189484], [92.70391083, 12.37224579], [92.70362091, 12.37268639], [92.70341492, 12.37317371], [92.70329285, 12.37374115], [92.70310211, 12.37434483], [92.70305634, 12.37506104], [92.70310974, 12.37578964], [92.70333099, 12.37638474], [92.70353699, 12.37690163], [92.70361328, 12.37737179], [92.70355988, 12.37777996], [92.70334625, 12.37809181], [92.70313263, 12.37839985], [92.70291901, 12.37872791], [92.70261383, 12.3790102], [92.70223236, 12.37914467], [92.70181274, 12.37914467], [92.70139313, 12.37903118], [92.70095825, 12.37886047], [92.70050812, 12.37865925], [92.70001221, 12.37867069], [92.69957733, 12.37898064], [92.69933319, 12.37948036], [92.69918823, 12.38004112], [92.69916534, 12.38061333], [92.69921112, 12.3811512], [92.69937897, 12.3816309], [92.69944, 12.38210106], [92.69944763, 12.38256073], [92.69944763, 12.38300991], [92.69944763, 12.38346386], [92.69944763, 12.38391972], [92.69941711, 12.3843708], [92.69928741, 12.38474655], [92.69917297, 12.38500023], [92.69916534, 12.38555622], [92.69889069, 12.38583374], [92.69889069, 12.38694382], [92.6986084, 12.38722038], [92.6986084, 12.38778114], [92.69832611, 12.38806057], [92.69832611, 12.38861179], [92.69806671, 12.38889027], [92.69805908, 12.38916588], [92.69777679, 12.38943958], [92.69777679, 12.39000034], [92.69805908, 12.39027786], [92.69806671, 12.39083004], [92.69832611, 12.39167118], [92.69828033, 12.39184856], [92.69832611, 12.39240932], [92.69832611, 12.39299107], [92.69833374, 12.39359665], [92.69832611, 12.39426041], [92.69832611, 12.39497089], [92.69833374, 12.39985085], [92.69833374, 12.40031338], [92.69832611, 12.40073967], [92.69833374, 12.40112877], [92.69835663, 12.40147114], [92.69844055, 12.40175629], [92.69857788, 12.40202522], [92.6986084, 12.40234184], [92.69861603, 12.40270424], [92.69863892, 12.40310097], [92.69877625, 12.40351772], [92.69888306, 12.40398121], [92.69894409, 12.40448856], [92.69917297, 12.40497017], [92.69944, 12.40549183], [92.69972229, 12.40602016], [92.69999695, 12.40651703], [92.70025635, 12.40695], [92.70043182, 12.40738106], [92.70053101, 12.40781021], [92.70056152, 12.40825939], [92.70055389, 12.40872288], [92.70052338, 12.40916061], [92.70033264, 12.40950489], [92.70015717, 12.40981102], [92.69999695, 12.41012096], [92.69985199, 12.41044044], [92.69972229, 12.41081142], [92.69960022, 12.41123104], [92.69947815, 12.41168022], [92.69941711, 12.41217041], [92.69930267, 12.41264057], [92.69919586, 12.41309929], [92.69917297, 12.41357994], [92.69916534, 12.41404819], [92.69916534, 12.41450977], [92.69916534, 12.41496372], [92.69917297, 12.41540146], [92.69915009, 12.41582108], [92.69905853, 12.41620064], [92.69892883, 12.4165802], [92.69889069, 12.41699028], [92.69888306, 12.4174118], [92.69880676, 12.41783142], [92.69863892, 12.41818047], [92.69850922, 12.41855812], [92.69837189, 12.41891098], [92.69832611, 12.41928959], [92.69832611, 12.41966057], [92.69833374, 12.41998672], [92.69831848, 12.4202919], [92.69823456, 12.42060471], [92.6980896, 12.42098999], [92.69812012, 12.42141819], [92.69835663, 12.42185974], [92.69848633, 12.42239094], [92.69851685, 12.4229908], [92.69880676, 12.42357922], [92.69888306, 12.42410278], [92.6988678, 12.42451286], [92.69877625, 12.42484188], [92.69871521, 12.42520809], [92.69869232, 12.4256506], [92.69882965, 12.42607021], [92.69896698, 12.42646027], [92.6991806, 12.42674923], [92.69944, 12.42699337], [92.69970703, 12.42725086], [92.69995117, 12.42757034], [92.70011139, 12.42792988], [92.70031738, 12.42820072], [92.70042419, 12.42849731], [92.70053101, 12.42877102], [92.70059967, 12.42910957], [92.70059204, 12.42956161], [92.70061493, 12.43010044], [92.70083618, 12.43063068], [92.70110321, 12.43119144], [92.70136261, 12.43172455], [92.70159149, 12.43225098], [92.70178223, 12.43275928], [92.70197296, 12.43321705], [92.70217896, 12.43362141], [92.70236206, 12.43399906], [92.7024765, 12.43435001], [92.70256805, 12.43470097], [92.70269775, 12.43504143], [92.70279694, 12.43540096], [92.70291138, 12.43574905], [92.70300293, 12.43609142], [92.70304108, 12.43642902], [92.70304871, 12.43676376], [92.70305634, 12.43710995], [92.70313263, 12.43748379], [92.70321655, 12.43789196], [92.70327759, 12.43833447], [92.70329285, 12.43878269], [92.70326233, 12.4392004], [92.70308685, 12.43955994], [92.70302582, 12.43991089], [92.70298004, 12.44021702], [92.70289612, 12.44048977], [92.70279694, 12.44074535], [92.70272827, 12.44101048], [92.70262909, 12.4412899], [92.70250702, 12.44159126], [92.70238495, 12.44192791], [92.70223999, 12.44229126], [92.70209503, 12.44268036], [92.70197296, 12.44309139], [92.70194244, 12.44355965], [92.70194244, 12.44401073], [92.70194244, 12.44445133], [92.70192719, 12.44489956], [92.70194244, 12.44540596], [92.70198822, 12.44599247], [92.70222473, 12.44659424], [92.70256042, 12.44720173], [92.70310974, 12.4475832], [92.7039032, 12.44738674], [92.70439911, 12.44750118], [92.70468903, 12.44779015], [92.70484924, 12.44822788], [92.70497894, 12.44878387], [92.70527649, 12.44912148], [92.7056427, 12.44944], [92.70594788, 12.44974136], [92.70617676, 12.45005131], [92.70632935, 12.45036793], [92.70641327, 12.45068932], [92.70652771, 12.45101547], [92.70659637, 12.45135021], [92.70661163, 12.45168972], [92.70654297, 12.45201111], [92.70641327, 12.45230961], [92.70627594, 12.452631], [92.70611572, 12.45295525], [92.70596313, 12.4532814], [92.70578003, 12.45359135], [92.70553589, 12.45388889], [92.70522308, 12.45430183], [92.70497894, 12.45503139], [92.70510864, 12.45570087], [92.70532227, 12.45618629], [92.70539093, 12.4565897], [92.7053299, 12.4569664], [92.70516968, 12.4573307], [92.70491791, 12.45767021], [92.70456696, 12.45795059], [92.7041626, 12.45817184], [92.70372009, 12.45836067], [92.70330811, 12.45862484], [92.70297241, 12.45900059], [92.70279694, 12.45953178], [92.70276642, 12.46011829], [92.70276642, 12.46071529], [92.70275879, 12.46130085], [92.70271301, 12.46184063], [92.70262146, 12.46230125], [92.70250702, 12.46267986], [92.70243835, 12.46299171], [92.70233917, 12.46327686], [92.70223236, 12.46355534], [92.70213318, 12.46385956], [92.70202637, 12.46419144], [92.70192719, 12.46452141], [92.70182037, 12.46481991], [92.70168304, 12.46509838], [92.7015152, 12.46539402], [92.7012558, 12.46570015], [92.7009201, 12.46603012], [92.70049286, 12.46632195], [92.7000351, 12.46662045], [92.69970703, 12.46703529], [92.69950867, 12.46747017], [92.69963837, 12.46798134], [92.69982147, 12.46850967], [92.70011902, 12.46888828], [92.70043182, 12.4692297], [92.70069122, 12.46959019], [92.70085907, 12.46995926], [92.7009964, 12.47033119], [92.70111847, 12.47071838], [92.70123291, 12.47111034], [92.70131683, 12.4715414], [92.70140076, 12.47193146], [92.70152283, 12.47227001], [92.70159912, 12.47257805], [92.70163727, 12.4728899], [92.70166016, 12.47322083], [92.70170593, 12.4735508], [92.70186615, 12.47383785], [92.70192719, 12.47412968], [92.70194244, 12.4744606], [92.70194244, 12.47482109], [92.70194244, 12.47523594], [92.70198059, 12.47570038], [92.70218658, 12.47620201], [92.70233154, 12.47676945], [92.70250702, 12.47733021], [92.70272064, 12.47786999], [92.70290375, 12.47842216], [92.70305634, 12.47896385], [92.70318604, 12.47945023], [92.70326233, 12.47988033], [92.70329285, 12.48023796], [92.70329285, 12.48054981], [92.70329285, 12.48083115], [92.70329285, 12.48110008], [92.70330811, 12.48137093], [92.70332336, 12.48168087], [92.70333099, 12.48204994], [92.70333099, 12.48253059], [92.70333099, 12.48312092], [92.70336151, 12.48379421], [92.70353699, 12.48447132], [92.70376587, 12.48515034], [92.70410919, 12.48573971], [92.70456696, 12.4861908], [92.70502472, 12.48659706], [92.70545959, 12.48698235], [92.70582581, 12.48739243], [92.70614624, 12.48782063], [92.70641327, 12.48827171], [92.70666504, 12.4886961], [92.70688629, 12.48909855], [92.70709991, 12.48950958], [92.70726776, 12.48990917], [92.70750427, 12.49025345], [92.70772552, 12.49058533], [92.70791626, 12.49091053], [92.70809174, 12.4912672], [92.70829773, 12.49157238], [92.70842743, 12.49193001], [92.70853424, 12.49230862], [92.70860291, 12.49269104], [92.70861816, 12.49308109], [92.70857239, 12.49344635], [92.70845795, 12.49378967], [92.70823669, 12.49413013], [92.70793915, 12.49444199], [92.70758057, 12.49476147], [92.70722961, 12.49515057], [92.70689392, 12.49556541], [92.70661163, 12.49602985], [92.70633698, 12.49652004], [92.70609283, 12.49701023], [92.70582581, 12.49748039], [92.70555115, 12.49788094], [92.70524597, 12.49821091], [92.70491791, 12.49843025], [92.70456696, 12.49853134], [92.704216, 12.49853134], [92.70384979, 12.49850082], [92.70346832, 12.49850082], [92.70310211, 12.49862194], [92.70276642, 12.4988699], [92.7024765, 12.49918938], [92.70214844, 12.49946499], [92.70188141, 12.49978161], [92.70163727, 12.50012398], [92.70143127, 12.50053215], [92.7013855, 12.50108337], [92.70139313, 12.50166035], [92.70137787, 12.50222015], [92.70134735, 12.50275612], [92.7012558, 12.50328922], [92.70115662, 12.50387096], [92.7011261, 12.50447178], [92.70124817, 12.50506496], [92.70136261, 12.50564098], [92.70140839, 12.50619793], [92.70153809, 12.50668335], [92.70166016, 12.5071497], [92.70173645, 12.50764275], [92.70175934, 12.50815105], [92.70170593, 12.50868034], [92.70163727, 12.50918961], [92.70156097, 12.50964832], [92.7014389, 12.51004028], [92.7013092, 12.5104208], [92.7011261, 12.51076984], [92.70082092, 12.51109123], [92.70044708, 12.51136875], [92.69998932, 12.51160431], [92.69946289, 12.51177025], [92.69883728, 12.51187038], [92.69815063, 12.51191998], [92.69740295, 12.51198196], [92.69664001, 12.51222992], [92.69592285, 12.51260185], [92.69535828, 12.51314735], [92.69496155, 12.51379395], [92.69455719, 12.5142107], [92.69426727, 12.51475811], [92.6942215, 12.51566124], [92.69461823, 12.51615334], [92.69476318, 12.516572], [92.6949234, 12.5169096], [92.69503784, 12.51723099], [92.69521332, 12.51756096], [92.69477081, 12.51825619], [92.69468689, 12.51906109], [92.69468689, 12.51954174], [92.69475555, 12.51992893], [92.69496155, 12.52007103], [92.69576263, 12.52049541], [92.69615936, 12.52078247], [92.69651031, 12.52101421], [92.6966629, 12.52110958], [92.69721985, 12.52166557], [92.69721985, 12.52221966], [92.69727325, 12.52311134], [92.69745636, 12.52369022], [92.69766998, 12.52432823], [92.69773102, 12.52482033], [92.69768524, 12.52519608], [92.69756317, 12.52571201], [92.69758606, 12.52628994], [92.69761658, 12.52656174], [92.69783783, 12.52683067], [92.69818878, 12.52711964], [92.6986084, 12.52750111], [92.69889069, 12.52778053], [92.69889069, 12.52805424], [92.69916534, 12.52833271], [92.69917297, 12.52861118], [92.69944763, 12.52889061], [92.69944763, 12.53000069], [92.69972229, 12.53028107], [92.6996994, 12.53273582], [92.69992828, 12.53321171], [92.70009613, 12.53379059], [92.70007324, 12.53451443], [92.69995117, 12.53477955], [92.69972229, 12.53490067], [92.69935608, 12.53482056], [92.69900513, 12.5349493], [92.69900513, 12.5354023], [92.69892883, 12.53600025], [92.69895172, 12.53633022], [92.69890594, 12.53695011], [92.6988678, 12.53755188], [92.69892883, 12.53856087], [92.69896698, 12.53918076], [92.69901276, 12.53973961], [92.69914246, 12.54014111], [92.69933319, 12.54045963], [92.69950104, 12.54076958], [92.69970703, 12.54117966], [92.69983673, 12.54163837], [92.69999695, 12.5420208], [92.70021057, 12.54253197], [92.70027924, 12.54285717], [92.70029449, 12.54329109], [92.70036316, 12.54370308], [92.70049286, 12.54395103], [92.700737, 12.54421997], [92.70082092, 12.54461479], [92.70102692, 12.54517078], [92.70130157, 12.54568768], [92.70152283, 12.54586983], [92.70191193, 12.54602146], [92.70235443, 12.54628754], [92.70281219, 12.54644489], [92.70348358, 12.54607296], [92.70407104, 12.54579544], [92.70449066, 12.54580021], [92.70480347, 12.54585934], [92.70506287, 12.54598045], [92.70526123, 12.54614162], [92.70543671, 12.54633999], [92.7056427, 12.54656124], [92.70585632, 12.54680538], [92.70612335, 12.54708958], [92.70648193, 12.54736996], [92.70675659, 12.54766178], [92.70667267, 12.54802036], [92.70630646, 12.54790974], [92.70584106, 12.54773045], [92.70535278, 12.54754066], [92.70493317, 12.54731083], [92.70449829, 12.54713345], [92.70391083, 12.54705334], [92.70346069, 12.54722023], [92.70339203, 12.54747963], [92.70360565, 12.54784393], [92.70378113, 12.54886055], [92.70384216, 12.54908943], [92.7039032, 12.54927063], [92.70409393, 12.54946041], [92.70448303, 12.54977036], [92.70464325, 12.55023003], [92.70497894, 12.55053997], [92.705513, 12.55089092], [92.70572662, 12.55153179], [92.70594025, 12.55208588], [92.70606995, 12.55239582], [92.70623779, 12.55262089], [92.70644379, 12.55284882], [92.70659637, 12.55296993], [92.70684814, 12.55305672], [92.7069931, 12.5532589], [92.70736694, 12.55379963], [92.70761871, 12.55422974], [92.70783234, 12.55469131], [92.70797729, 12.55506039], [92.70820618, 12.55543137], [92.70863342, 12.55579185], [92.70884705, 12.55624104], [92.70889282, 12.55674171], [92.70889282, 12.5572319], [92.70889282, 12.55771065], [92.70889282, 12.55815029], [92.70889282, 12.55875015], [92.70870209, 12.55908012], [92.70847321, 12.55936527], [92.70822144, 12.55963421], [92.70793152, 12.55992413], [92.70774078, 12.56021976], [92.70767975, 12.56072998], [92.70778656, 12.5610199], [92.70774841, 12.56166935], [92.7074585, 12.56199074], [92.70716095, 12.56225967], [92.70683289, 12.56250095], [92.70646667, 12.56270885], [92.70613098, 12.56296158], [92.70584106, 12.56325054], [92.70559692, 12.56352901], [92.70543671, 12.56383038], [92.70526886, 12.56407166], [92.70506287, 12.5642786], [92.70490265, 12.56462097], [92.70482635, 12.56534958], [92.70481873, 12.56580639], [92.70481873, 12.56626225], [92.70495605, 12.56689072], [92.70513916, 12.56738091], [92.7052536, 12.56788921], [92.70529175, 12.56844139], [92.7053833, 12.56896687], [92.70555878, 12.56944084], [92.70667267, 12.57056046], [92.70694733, 12.57056046], [92.70777893, 12.57139015], [92.70777893, 12.57166576], [92.70804596, 12.57194233], [92.70804596, 12.57250023], [92.70833588, 12.57277966], [92.70833588, 12.57333374], [92.70805359, 12.57361221], [92.70804596, 12.57472038], [92.70833588, 12.57500172], [92.70833588, 12.57528019], [92.70861053, 12.57556057], [92.70861053, 12.57610989], [92.70777893, 12.57694435], [92.70742035, 12.5771904], [92.70701599, 12.57731056], [92.70658875, 12.5774889], [92.7061615, 12.57767963], [92.70584106, 12.57800198], [92.70555115, 12.57818031], [92.70519257, 12.57871056], [92.70523834, 12.57956123], [92.70527649, 12.58029461], [92.70591736, 12.58062267], [92.70607758, 12.58086014], [92.70619202, 12.5812912], [92.70639038, 12.58169174], [92.70658875, 12.58206081], [92.70665741, 12.5824604], [92.70667267, 12.58286953], [92.70671844, 12.58328915], [92.70690155, 12.58371067], [92.7069397, 12.58413696], [92.70693207, 12.58451271], [92.70684052, 12.58481026], [92.70670319, 12.58506012], [92.70659637, 12.58532047], [92.7064209, 12.58552742], [92.70623016, 12.58570099], [92.70597839, 12.58580971], [92.70565033, 12.58583069], [92.70527649, 12.58585072], [92.70491028, 12.58596039], [92.70461273, 12.58627033], [92.704422, 12.58674717], [92.70420837, 12.58726025], [92.7041626, 12.58781147], [92.7041626, 12.58835125], [92.70420837, 12.58889771], [92.70442963, 12.58945179], [92.70475006, 12.59002018], [92.70516205, 12.59051609], [92.70561981, 12.59092045], [92.70597076, 12.59135056], [92.70583344, 12.5913887], [92.70639038, 12.59194088], [92.70639038, 12.59250164], [92.70694733, 12.59305954], [92.70694733, 12.59500027], [92.70667267, 12.59527969], [92.70667267, 12.59556007], [92.70749664, 12.59638977], [92.70749664, 12.59694576], [92.70722198, 12.59722233], [92.70666504, 12.59722233], [92.70610809, 12.59666634], [92.70527649, 12.59667015], [92.70500183, 12.59638977], [92.70444489, 12.59694576], [92.70417023, 12.59694576], [92.70388031, 12.59721947], [92.70362091, 12.59756088], [92.70347595, 12.59788036], [92.70346832, 12.59819031], [92.70334625, 12.59840012], [92.70308685, 12.59852123], [92.70282745, 12.59867954], [92.7025528, 12.59892178], [92.70220184, 12.59919071], [92.70176697, 12.59945107], [92.70126343, 12.59967422], [92.70069122, 12.59972191], [92.70012665, 12.59976959], [92.69970703, 12.59991074], [92.69927216, 12.59981346], [92.6989212, 12.59992027], [92.69854736, 12.59999084], [92.69814301, 12.60000038], [92.69772339, 12.60000038], [92.69728851, 12.60000038], [92.69684601, 12.60000038], [92.69642639, 12.60002041], [92.69605255, 12.60012054], [92.6958313, 12.60028267], [92.69561768, 12.6003809], [92.69538879, 12.60043144], [92.69512939, 12.60040092], [92.69487, 12.60031033], [92.69460297, 12.60029888], [92.69433594, 12.60039043], [92.69407654, 12.60056973], [92.69377136, 12.60076141], [92.693367, 12.600811], [92.69283295, 12.60077], [92.69248199, 12.60105991], [92.69223022, 12.60135078], [92.69184875, 12.60159969], [92.69132233, 12.60169983], [92.6910553, 12.60175896], [92.69050598, 12.60190105], [92.69002533, 12.60204887], [92.68946075, 12.60215378], [92.68888855, 12.60213089], [92.68844604, 12.60192585], [92.68785858, 12.60157013], [92.68710327, 12.60114193], [92.68669891, 12.60123062], [92.68637085, 12.6014204], [92.68608093, 12.60169792], [92.68578339, 12.60200977], [92.68548584, 12.60241985], [92.68512726, 12.60280991], [92.68482971, 12.60328865], [92.68467712, 12.60391998], [92.68453217, 12.60462189], [92.68453217, 12.60536003], [92.68456268, 12.60608482], [92.68447113, 12.60678959], [92.68445587, 12.60748005], [92.68448639, 12.60814095], [92.68461609, 12.60879135], [92.68495178, 12.60929012], [92.68505096, 12.60977077], [92.68522644, 12.61018085], [92.68540192, 12.61057091], [92.68545532, 12.61177444], [92.68545532, 12.61231041], [92.68560028, 12.61305523], [92.68592072, 12.61388206], [92.68583679, 12.6147213], [92.6866684, 12.61557102], [92.68694305, 12.61557102], [92.68721771, 12.61503983], [92.68719482, 12.61454773], [92.68710327, 12.614151], [92.68702698, 12.61357689], [92.68712616, 12.61267185], [92.6875, 12.61167145], [92.68776703, 12.61139107], [92.68795013, 12.61124992], [92.68855286, 12.61077976], [92.68915558, 12.61026096], [92.68969727, 12.6096611], [92.69016266, 12.60904121], [92.69062805, 12.60863113], [92.69104767, 12.60832119], [92.69142151, 12.60806084], [92.69181061, 12.60785198], [92.69230652, 12.60778522], [92.69288635, 12.60777187], [92.69348907, 12.60768986], [92.69402313, 12.60752773], [92.69447327, 12.60742092], [92.69478607, 12.60726357], [92.69508362, 12.60727501], [92.69539642, 12.60747337], [92.69576263, 12.60771275], [92.69609833, 12.60804081], [92.69639587, 12.60841179], [92.69670105, 12.60875034], [92.69706726, 12.60902119], [92.69747925, 12.60936737], [92.69801331, 12.60956097], [92.69850922, 12.60984135], [92.6988678, 12.6102562], [92.69917297, 12.61067104], [92.69945526, 12.61101532], [92.69972992, 12.61126995], [92.69998169, 12.6114912], [92.70020294, 12.61170101], [92.70040131, 12.61195183], [92.70063019, 12.61219978], [92.7009201, 12.61240959], [92.70131683, 12.61252785], [92.70169067, 12.6127224], [92.70207977, 12.61290359], [92.70243835, 12.61299133], [92.70276642, 12.61279964], [92.70305634, 12.6124897], [92.70331573, 12.61215878], [92.70347595, 12.61178112], [92.70359039, 12.61142063], [92.70361328, 12.611022], [92.70360565, 12.61058903], [92.7035675, 12.61011028], [92.70346069, 12.60963154], [92.70335388, 12.6091671], [92.70336914, 12.60873127], [92.70333099, 12.60861111], [92.70333099, 12.60833168], [92.70361328, 12.60805416], [92.70361328, 12.60778141], [92.70388031, 12.60750103], [92.70417023, 12.60750103], [92.70471954, 12.60805416], [92.70506287, 12.60842133], [92.70524597, 12.60884094], [92.7053833, 12.60931683], [92.70565796, 12.60969067], [92.7059021, 12.61008072], [92.70612335, 12.6105547], [92.70633698, 12.61111069], [92.70648956, 12.61175823], [92.70665741, 12.6124506], [92.70683289, 12.6131506], [92.70701599, 12.61379814], [92.70729828, 12.61433125], [92.7077179, 12.61473179], [92.70816803, 12.61509037], [92.70865631, 12.61534119], [92.70907593, 12.61557961], [92.70938873, 12.61582184], [92.70960999, 12.61603069], [92.70973206, 12.61631203], [92.7098465, 12.61665058], [92.7099762, 12.61704063], [92.71000671, 12.61749172], [92.71002197, 12.61802101], [92.71006775, 12.61861134], [92.71022797, 12.61913109], [92.71032715, 12.61959076], [92.71045685, 12.6199789], [92.71060181, 12.62041187], [92.71086121, 12.62083054], [92.7111969, 12.62121582], [92.71147919, 12.62168121], [92.71172333, 12.62221527], [92.71195221, 12.62280464], [92.71217346, 12.62343216], [92.71221924, 12.62404919], [92.71222687, 12.62462139], [92.71221161, 12.62508202], [92.71215057, 12.62543964], [92.71199036, 12.62571812], [92.71186066, 12.62603474], [92.71172333, 12.62637424], [92.71179199, 12.62676239], [92.71201324, 12.62716961], [92.71230316, 12.62757111], [92.71253967, 12.62790108], [92.7127533, 12.62821102], [92.71284485, 12.62859917], [92.7130127, 12.62895203], [92.7130127, 12.62942791], [92.71289825, 12.62994957], [92.71305084, 12.63049698], [92.71325684, 12.63107395], [92.71340942, 12.63168526], [92.71369934, 12.6321516], [92.71396637, 12.63258934], [92.71413422, 12.63299656], [92.71418762, 12.63342094], [92.71430206, 12.6337862], [92.71444702, 12.63407993], [92.7146225, 12.63440132], [92.71473694, 12.63476086], [92.71486664, 12.63516045], [92.71498108, 12.63559055], [92.71504974, 12.63603973], [92.71522522, 12.63642979], [92.71524811, 12.63687038], [92.71520233, 12.63735676], [92.7154007, 12.63783073], [92.7155304, 12.63836002], [92.71555328, 12.63889122], [92.7155304, 12.63941097], [92.71543121, 12.63990116], [92.71517181, 12.64035034], [92.71501923, 12.64091969], [92.71494293, 12.64158344], [92.71489716, 12.64229202], [92.71504974, 12.64296246], [92.7154007, 12.64345169], [92.71586609, 12.6437912], [92.71644592, 12.64374065], [92.71704102, 12.64359093], [92.71746826, 12.6433897], [92.71782684, 12.64333534], [92.7181778, 12.64333057], [92.71855164, 12.64338779], [92.71891022, 12.64362335], [92.71932983, 12.64375496], [92.71973419, 12.64330578], [92.71996307, 12.64270878], [92.71994781, 12.6421299], [92.71976471, 12.64163113], [92.71972656, 12.64116096], [92.71969604, 12.6407299], [92.71956635, 12.64039326], [92.71946716, 12.6400671], [92.71943665, 12.63969994], [92.71944427, 12.63932037], [92.71943665, 12.63893032], [92.71943665, 12.63854027], [92.7194519, 12.63817787], [92.71953583, 12.63783073], [92.71970367, 12.63749409], [92.71987152, 12.63707542], [92.72007751, 12.63662148], [92.72040558, 12.63622856], [92.72064209, 12.63574123], [92.72080231, 12.63519192], [92.72083282, 12.63461971], [92.72084045, 12.63407993], [92.7208786, 12.63361931], [92.72106171, 12.63326836], [92.721138, 12.63292027], [92.72125244, 12.63264179], [92.72136688, 12.63237095], [92.72145081, 12.63208294], [92.72160339, 12.6318388], [92.72171021, 12.63154984], [92.72187805, 12.63126087], [92.72198486, 12.63089371], [92.7221756, 12.63052368], [92.72228241, 12.62996578], [92.72245789, 12.62933922], [92.72254181, 12.62867069], [92.72274017, 12.62807178], [92.72296906, 12.62756157], [92.72328186, 12.62722015], [92.72357178, 12.62695122], [92.72383118, 12.62674141], [92.72410583, 12.62667274], [92.72440338, 12.6266613], [92.72470093, 12.6267004], [92.72492981, 12.62687969], [92.72509766, 12.62716961], [92.72521973, 12.62773705], [92.72537994, 12.62833023], [92.72554016, 12.62878132], [92.72569275, 12.6292572], [92.72583008, 12.62944031], [92.72583008, 12.63000011], [92.72611237, 12.63027763], [92.72611237, 12.6319437], [92.72638702, 12.63222027], [92.72638702, 12.63306141], [92.72693634, 12.63360977], [92.72693634, 12.63417053], [92.72805023, 12.63528061], [92.72861481, 12.6352787], [92.72916412, 12.63583469], [92.73055267, 12.63583469], [92.73083496, 12.63611126], [92.73110962, 12.63611126], [92.73139191, 12.63639069], [92.73166656, 12.63639069], [92.73194122, 12.63667965], [92.73222351, 12.63666725], [92.73249817, 12.63694477], [92.73278046, 12.63694477], [92.73305511, 12.63722324], [92.73332977, 12.63722324], [92.73361206, 12.63750076], [92.73388672, 12.63749886], [92.73417664, 12.63778114], [92.73443604, 12.63778114], [92.73555756, 12.63888931], [92.73555756, 12.639431], [92.73583221, 12.63951969], [92.7360611, 12.64003086], [92.7360611, 12.64052105], [92.73589325, 12.64096069], [92.73571014, 12.64138889], [92.73552704, 12.64179707], [92.73532867, 12.64219093], [92.73529816, 12.64265156], [92.73536682, 12.64310074], [92.73543549, 12.64352703], [92.73544312, 12.64394188], [92.73538208, 12.64435005], [92.73527527, 12.64474392], [92.7351532, 12.64511108], [92.73497009, 12.64542103], [92.73469543, 12.64568329], [92.73434448, 12.6459837], [92.73405457, 12.64648342], [92.73391724, 12.64711189], [92.73384094, 12.64777088], [92.7336731, 12.648386], [92.73368835, 12.6490097], [92.73361206, 12.64964199], [92.73351288, 12.65020943], [92.73336792, 12.65070248], [92.73331451, 12.65115547], [92.73320007, 12.65151119], [92.733078, 12.65182972], [92.73306274, 12.65215111], [92.73304749, 12.65248585], [92.73305511, 12.65286922], [92.73310852, 12.65332031], [92.73332977, 12.65378094], [92.73356628, 12.65432072], [92.73374176, 12.65494537], [92.73394012, 12.65554237], [92.73412323, 12.65616226], [92.73432159, 12.65680122], [92.7348175, 12.65728092], [92.73544312, 12.65746593], [92.73604584, 12.65747261], [92.73657227, 12.65752983], [92.73697662, 12.65772057], [92.73737335, 12.65793991], [92.73777771, 12.65820026], [92.7381897, 12.6585207], [92.73862457, 12.65886116], [92.73908997, 12.65916443], [92.73953247, 12.65945053], [92.73992157, 12.65977001], [92.74025726, 12.66010761], [92.74055481, 12.66047192], [92.7408371, 12.66087055], [92.74111176, 12.66134071], [92.74138641, 12.66187763], [92.74167633, 12.6624918], [92.74205017, 12.66310024], [92.7424469, 12.66358089], [92.74286652, 12.66399097], [92.74310303, 12.66451073], [92.74331665, 12.66497612], [92.74356842, 12.66535187], [92.74375153, 12.66576672], [92.74386597, 12.66620445], [92.74388885, 12.66667175], [92.74391937, 12.66709995], [92.74407196, 12.66746044], [92.74433899, 12.66768074], [92.74472046, 12.66771984], [92.74517822, 12.66759682], [92.74563599, 12.66773129], [92.74611664, 12.66778088], [92.74659729, 12.66778088], [92.74675751, 12.66777039], [92.74707031, 12.66775036], [92.74745941, 12.66759872], [92.74774933, 12.66733932], [92.74795532, 12.66703415], [92.7481308, 12.66670132], [92.74835205, 12.66638184], [92.74865723, 12.6661129], [92.74900055, 12.66588306], [92.74937439, 12.66574192], [92.74969482, 12.66558933], [92.75004578, 12.66556168], [92.75036621, 12.6655798], [92.75068665, 12.66570663], [92.75096893, 12.66595078], [92.75125885, 12.66621971], [92.75141907, 12.66664028], [92.7515564, 12.66709995], [92.75170135, 12.6675787], [92.75184631, 12.6680479], [92.75171661, 12.6686697], [92.75180054, 12.66925144], [92.75202942, 12.66967773], [92.75218964, 12.669981], [92.75234985, 12.67024136], [92.75256348, 12.67047787], [92.75289917, 12.67066002], [92.75332642, 12.67078114], [92.7538681, 12.67065144], [92.75444031, 12.67036438], [92.75501251, 12.6700058], [92.75556946, 12.66967297], [92.75610352, 12.66942883], [92.75653076, 12.66916943], [92.75689697, 12.66894245], [92.75728607, 12.66884136], [92.75763702, 12.66867924], [92.75802612, 12.66860199], [92.75841522, 12.66851139], [92.75878143, 12.66836452], [92.75917816, 12.66833115], [92.75959778, 12.66833305], [92.76003265, 12.66833305], [92.76046753, 12.66833305], [92.76089478, 12.66832447], [92.76128387, 12.66825581], [92.7616272, 12.66808891], [92.76198578, 12.66797066], [92.76234436, 12.66781616], [92.76277924, 12.66778088], [92.76325226, 12.66778088], [92.76374054, 12.66778088], [92.76425171, 12.66778088], [92.76477814, 12.66782188], [92.76528168, 12.66796398], [92.76580048, 12.66781998], [92.7663269, 12.66778088], [92.76686096, 12.66778088], [92.76737976, 12.66778088], [92.76789856, 12.66778088], [92.7684021, 12.66777897], [92.76885986, 12.66781998], [92.76924896, 12.6680088], [92.76965332, 12.66807079], [92.7700119, 12.66819191], [92.770401, 12.66835976], [92.77085114, 12.66862011], [92.77136993, 12.66889095], [92.77191162, 12.66918468], [92.77243805, 12.66946125], [92.77292633, 12.66967964], [92.77311707, 12.66969585], [92.77345276, 12.66972065], [92.77392578, 12.66965008], [92.7743988, 12.66946125], [92.77487946, 12.66926956], [92.77529907, 12.66898918], [92.77571869, 12.6687088], [92.77610016, 12.66833115], [92.77642822, 12.66789532], [92.77677155, 12.66749191], [92.77706909, 12.66708183], [92.77728271, 12.66662121], [92.77745819, 12.66618633], [92.77754211, 12.66571045], [92.77771759, 12.66530895], [92.77780151, 12.66490078], [92.77794647, 12.66453075], [92.77809143, 12.66411018], [92.77829742, 12.663661], [92.77842712, 12.66311169], [92.77861023, 12.66257095], [92.77877808, 12.66203976], [92.77886963, 12.66149139], [92.77890778, 12.66093922], [92.77902985, 12.66043091], [92.77913666, 12.65993881], [92.77915955, 12.65940094], [92.77921295, 12.65881348], [92.77935791, 12.65819836], [92.77925873, 12.65752125], [92.77931213, 12.65680122], [92.77935028, 12.65607643], [92.77921295, 12.6553812], [92.77921295, 12.65472698], [92.77934265, 12.65416145], [92.77919006, 12.65368271], [92.77906036, 12.65324974], [92.77892303, 12.6528511], [92.77887726, 12.65242004], [92.77881622, 12.65200138], [92.77873993, 12.65159035], [92.77882385, 12.65113926], [92.77871704, 12.65067196], [92.77863312, 12.6502018], [92.77865601, 12.64972401], [92.77883148, 12.64925003], [92.77883911, 12.64878273], [92.77865601, 12.64831066], [92.77861023, 12.64782143], [92.77861023, 12.64734173], [92.77861023, 12.64686966], [92.77861023, 12.6464119], [92.77861023, 12.64596558], [92.77861023, 12.64550972], [92.77861023, 12.64504528], [92.77864075, 12.64456844], [92.77879333, 12.64413071], [92.77890778, 12.64367008], [92.77908325, 12.64324188], [92.77919006, 12.64276123], [92.77935791, 12.64228916], [92.77942657, 12.64179039], [92.77940369, 12.6413002], [92.77922058, 12.64085579], [92.77910614, 12.64043045], [92.77892303, 12.64008999], [92.77877808, 12.63974953], [92.77838898, 12.63949966], [92.77805328, 12.63927555], [92.77770233, 12.63905144], [92.77725983, 12.63871956], [92.77683258, 12.63833046], [92.77657318, 12.63791084], [92.77645874, 12.63743687], [92.77643585, 12.63685989], [92.7765274, 12.63630199], [92.77700806, 12.63544273], [92.7771225, 12.63492107], [92.77722168, 12.63450623], [92.77729034, 12.63411045], [92.77729797, 12.63368988], [92.77728271, 12.63323021], [92.77754211, 12.63246155], [92.77779388, 12.63262558], [92.77791595, 12.63319969], [92.7779007, 12.63388634], [92.77784729, 12.63441944], [92.77774811, 12.63491917], [92.77762604, 12.63539505], [92.77739716, 12.63593102], [92.77728271, 12.63647079], [92.77722931, 12.63700581], [92.77726746, 12.63748264], [92.77745819, 12.63785172], [92.777771, 12.63801956], [92.77820587, 12.63814068], [92.77865601, 12.6384306], [92.77875519, 12.63835812], [92.77894592, 12.63822079], [92.77926636, 12.63802719], [92.77953339, 12.63776112], [92.77973938, 12.63742065], [92.77993774, 12.63706303], [92.7800293, 12.63662148], [92.78013611, 12.63617039], [92.78003693, 12.6357193], [92.77999878, 12.63527203], [92.78002167, 12.63484097], [92.780159, 12.63450623], [92.78024292, 12.63420963], [92.7802124, 12.63389778], [92.78019714, 12.63350964], [92.78002167, 12.63288116], [92.77976227, 12.63225746], [92.77958679, 12.63167953], [92.77951813, 12.63113976], [92.77951813, 12.63064957], [92.77957916, 12.63024902], [92.77973175, 12.62994957], [92.7798996, 12.62969017], [92.78005219, 12.62942791], [92.78022766, 12.62918186]]]]}}, {\\\"id\\\": \\\"1\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.2_1\\\", \\\"HASC_1\\\": \\\"IN.AP\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Andhra Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -8.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 590.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1186.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -596.0, \\\"geo-id\\\": 1, \\\"hpm25_child_popweighted\\\": -122.9, \\\"hpm25_female_popweighted\\\": -141.2, \\\"hpm25_male_popweighted\\\": -101.7, \\\"location\\\": \\\"Andhra Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 9244.0, \\\"mort_hpm25_6cod_mean_total\\\": -18526.0, \\\"mort_tpm25_6cod_mean_total\\\": -9281.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[80.19264221, 13.52069569], [80.19264221, 13.52041531], [80.19374847, 13.52042198], [80.19374847, 13.5201416], [80.19403076, 13.5201416], [80.19403076, 13.51958084], [80.19430542, 13.51958275], [80.19430542, 13.51930523], [80.19458008, 13.51931], [80.19458008, 13.51874924], [80.19486237, 13.51874924], [80.19486237, 13.51847076], [80.19513702, 13.51847267], [80.19513702, 13.51819324], [80.19541931, 13.51819324], [80.19541931, 13.51763916], [80.19568634, 13.51764202], [80.19568634, 13.51653194], [80.19596863, 13.51653194], [80.19596863, 13.51514053], [80.19625092, 13.51514053], [80.19625092, 13.51486111], [80.19652557, 13.51486111], [80.19652557, 13.51430511], [80.19680786, 13.51431179], [80.19680786, 13.51375103], [80.19708252, 13.51375103], [80.19708252, 13.51292133], [80.19596863, 13.51291656], [80.19596863, 13.51319504], [80.19541931, 13.51319504], [80.19541931, 13.51347256], [80.19291687, 13.51347065], [80.19291687, 13.51375103], [80.1920929, 13.51375103], [80.1920929, 13.51403141], [80.19124603, 13.51403141], [80.19124603, 13.51431179], [80.19069672, 13.51430511], [80.19069672, 13.51458263], [80.18985748, 13.51458263], [80.18985748, 13.51486111], [80.18930817, 13.51486111], [80.18930817, 13.51514053], [80.18846893, 13.51514053], [80.18846893, 13.51625061], [80.18819427, 13.5162487], [80.18819427, 13.51708317], [80.18791962, 13.51708317], [80.18791962, 13.51819324], [80.18763733, 13.5181818], [80.18763733, 13.51931], [80.18791962, 13.51931], [80.18791962, 13.5201416], [80.18985748, 13.5201416], [80.18985748, 13.52042198], [80.19180298, 13.52041531], [80.19180298, 13.52069569], [80.19264221, 13.52069569]]], [[[80.18486023, 13.53542137], [80.18486023, 13.53514099], [80.18514252, 13.53514099], [80.18514252, 13.53458023], [80.18541718, 13.53458214], [80.18541718, 13.53430653], [80.18514252, 13.53431129], [80.18514252, 13.53403091], [80.18486023, 13.53403091], [80.18486023, 13.5334816], [80.1845932, 13.5334816], [80.1845932, 13.53318977], [80.18430328, 13.53319359], [80.18430328, 13.53291607], [80.18374634, 13.53292084], [80.18374634, 13.53264141], [80.18068695, 13.53264141], [80.18068695, 13.53292084], [80.18041992, 13.53291607], [80.18041992, 13.53319359], [80.18013763, 13.53318977], [80.18013763, 13.5334816], [80.17986298, 13.5334816], [80.17986298, 13.53403091], [80.18152618, 13.53403091], [80.18152618, 13.53431129], [80.18180847, 13.53430653], [80.18180847, 13.53458214], [80.18319702, 13.53458214], [80.18319702, 13.53486347], [80.18374634, 13.53485966], [80.18374634, 13.53514099], [80.18402863, 13.53514099], [80.18402863, 13.53542137], [80.18486023, 13.53542137]]], [[[80.14902496, 13.61847305], [80.14902496, 13.61819458], [80.14930725, 13.61819458], [80.14930725, 13.61652946], [80.14958191, 13.61653137], [80.14958191, 13.61485958], [80.14930725, 13.6148634], [80.14930725, 13.61430645], [80.14901733, 13.61431122], [80.14901733, 13.61375046], [80.14875031, 13.61375046], [80.14875031, 13.6131897], [80.14847565, 13.61319447], [80.14847565, 13.61291599], [80.14819336, 13.61292076], [80.14819336, 13.61236], [80.1479187, 13.61236], [80.1479187, 13.61207962], [80.14763641, 13.61208439], [80.14763641, 13.61180592], [80.1473465, 13.61182022], [80.1473465, 13.61124992], [80.1470871, 13.61124992], [80.1470871, 13.61096954], [80.14653015, 13.6109724], [80.14653015, 13.61069393], [80.14680481, 13.61069393], [80.14680481, 13.61041641], [80.14763641, 13.61041641], [80.14763641, 13.61069393], [80.14819336, 13.61069393], [80.14819336, 13.6109724], [80.14848328, 13.61096954], [80.14848328, 13.61124992], [80.14875031, 13.61124992], [80.14875031, 13.61153126], [80.14901733, 13.61153126], [80.14901733, 13.61182022], [80.1506958, 13.61182022], [80.1506958, 13.61153126], [80.15097046, 13.61153126], [80.15097046, 13.61124992], [80.15125275, 13.61124992], [80.15125275, 13.61096954], [80.1515274, 13.6109724], [80.1515274, 13.61069393], [80.15208435, 13.61069393], [80.15208435, 13.61041641], [80.15235901, 13.61042118], [80.15235901, 13.61013985], [80.1526413, 13.61013985], [80.1526413, 13.60986042], [80.15291595, 13.60986233], [80.15291595, 13.60958195], [80.1534729, 13.60958195], [80.1534729, 13.60930634], [80.15374756, 13.6093111], [80.15374756, 13.60903263], [80.15429687, 13.60903263], [80.15429687, 13.60876083], [80.15458679, 13.60876083], [80.15458679, 13.60847187], [80.15513611, 13.60847187], [80.15513611, 13.60819435], [80.1554184, 13.60819435], [80.1554184, 13.60791588], [80.15598297, 13.60791969], [80.15598297, 13.60764027], [80.1592865, 13.60764027], [80.15930939, 13.60736179], [80.16042328, 13.60736179], [80.16042328, 13.60707855], [80.16124725, 13.60708427], [80.16124725, 13.6068058], [80.16152954, 13.60680962], [80.16152954, 13.60624981], [80.16179657, 13.60624981], [80.16179657, 13.60569096], [80.16208649, 13.60569382], [80.16208649, 13.6054163], [80.16234589, 13.60542011], [80.16234589, 13.60485935], [80.1626358, 13.60486221], [80.1626358, 13.60236168], [80.16234589, 13.60236168], [80.16234589, 13.5995903], [80.16208649, 13.5995903], [80.16208649, 13.59930992], [80.16152954, 13.59930992], [80.16152954, 13.59625053], [80.16179657, 13.59625053], [80.16179657, 13.59569073], [80.16208649, 13.59569454], [80.16208649, 13.59541702], [80.16234589, 13.59542179], [80.16234589, 13.59486103], [80.1626358, 13.59486103], [80.1626358, 13.59458065], [80.16291809, 13.59458256], [80.16291809, 13.59402657], [80.16319275, 13.59403133], [80.16319275, 13.59375095], [80.16348267, 13.59375095], [80.16348267, 13.59319019], [80.16374969, 13.59319496], [80.16374969, 13.59291744], [80.16401672, 13.59292126], [80.16401672, 13.59236145], [80.16625214, 13.59236145], [80.16625214, 13.59208298], [80.16708374, 13.59208298], [80.16708374, 13.59152889], [80.1673584, 13.59152889], [80.1673584, 13.59097004], [80.16764069, 13.5909729], [80.16764069, 13.58985996], [80.1673584, 13.58985996], [80.1673584, 13.58875275], [80.16707611, 13.58875275], [80.16707611, 13.5876503], [80.16680908, 13.5876503], [80.16680908, 13.58708], [80.16652679, 13.58708191], [80.16652679, 13.58652782], [80.16625214, 13.58653069], [80.16625214, 13.58596992], [80.16596985, 13.58597183], [80.16596985, 13.58541584], [80.16570282, 13.58542061], [80.16570282, 13.58485985], [80.1654129, 13.58485985], [80.1654129, 13.58430576], [80.16513824, 13.58431053], [80.16513824, 13.58403015], [80.16348267, 13.58403015], [80.16348267, 13.58375168], [80.16319275, 13.58375168], [80.16319275, 13.58347034], [80.16291809, 13.58347225], [80.16291809, 13.58319378], [80.1626358, 13.58319378], [80.1626358, 13.58291626], [80.16208649, 13.58292103], [80.16208649, 13.58263969], [80.16179657, 13.58263969], [80.16179657, 13.58236027], [80.16152954, 13.58236217], [80.16152954, 13.5820837], [80.16124725, 13.5820837], [80.16124725, 13.58180618], [80.1609726, 13.58181095], [80.1609726, 13.58152103], [80.16041565, 13.58152771], [80.16041565, 13.58125019], [80.16014099, 13.58125019], [80.16014099, 13.57931042], [80.16042328, 13.57931042], [80.16042328, 13.57845974], [80.16069794, 13.57847214], [80.16069794, 13.57791805], [80.16042328, 13.57791996], [80.16042328, 13.5773592], [80.16014099, 13.57736206], [80.16014099, 13.57708359], [80.1598587, 13.57708359], [80.1598587, 13.57624912], [80.15957642, 13.57625198], [80.15957642, 13.57458115], [80.15930939, 13.57458305], [80.15930939, 13.57347107], [80.15958405, 13.57347107], [80.15958405, 13.57263947], [80.1598587, 13.57265091], [80.1598587, 13.57180977], [80.16014099, 13.57180977], [80.16014099, 13.57125092], [80.1598587, 13.57125092], [80.1598587, 13.57069111], [80.15958405, 13.57069302], [80.15958405, 13.57013893], [80.15930939, 13.57014084], [80.1592865, 13.56958103], [80.1590271, 13.56958294], [80.1590271, 13.56902695], [80.15875244, 13.56903076], [80.15875244, 13.56818962], [80.15847015, 13.56819534], [80.15847015, 13.56763935], [80.15820313, 13.56764126], [80.15820313, 13.56708145], [80.15791321, 13.56708336], [80.15791321, 13.5662508], [80.15763855, 13.5662508], [80.15763855, 13.56569004], [80.15736389, 13.56569481], [80.15736389, 13.56458473], [80.1570816, 13.56458473], [80.1570816, 13.56347275], [80.15680695, 13.56347275], [80.15680695, 13.56235981], [80.15651703, 13.56235981], [80.15651703, 13.56124973], [80.15625, 13.56124973], [80.15625, 13.56014061], [80.15598297, 13.56014061], [80.15598297, 13.55957985], [80.15569305, 13.55958366], [80.15569305, 13.55902767], [80.1554184, 13.55903053], [80.1554184, 13.55846977], [80.15513611, 13.55847168], [80.15513611, 13.55791569], [80.15486145, 13.55792141], [80.15486145, 13.5573597], [80.15458679, 13.5573597], [80.15458679, 13.55681133], [80.15429687, 13.55681133], [80.15429687, 13.55624962], [80.15402985, 13.55624962], [80.15402985, 13.55568886], [80.15374756, 13.55569363], [80.15374756, 13.55541801], [80.15348053, 13.55541992], [80.15348053, 13.55486202], [80.15319824, 13.55486202], [80.15319824, 13.55458164], [80.15291595, 13.55458355], [80.15291595, 13.55402756], [80.1526413, 13.55403042], [80.1526413, 13.55346966], [80.15235901, 13.55347157], [80.15235901, 13.55319405], [80.15208435, 13.55319405], [80.15208435, 13.55263996], [80.15180206, 13.55263996], [80.15180206, 13.55235958], [80.1515274, 13.55236244], [80.1515274, 13.55180645], [80.15125275, 13.55181026], [80.15125275, 13.55125046], [80.15097046, 13.55125046], [80.15097046, 13.55097198], [80.1506958, 13.55097198], [80.1506958, 13.55069447], [80.15041351, 13.55069447], [80.15041351, 13.5504179], [80.15013885, 13.55041981], [80.15013885, 13.55014038], [80.14985657, 13.55014038], [80.14985657, 13.54986191], [80.14958191, 13.54986191], [80.14958191, 13.54958057], [80.14930725, 13.54958439], [80.14930725, 13.54930592], [80.14901733, 13.54930973], [80.14901733, 13.5490303], [80.14875031, 13.5490303], [80.14875031, 13.54875183], [80.14848328, 13.54875183], [80.14848328, 13.54848003], [80.14819336, 13.54848003], [80.14819336, 13.54819107], [80.1479187, 13.54819584], [80.1479187, 13.54791832], [80.14763641, 13.54792023], [80.14763641, 13.54764175], [80.1473465, 13.54764175], [80.1473465, 13.54736137], [80.1470871, 13.54736137], [80.1470871, 13.5470829], [80.14680481, 13.5470829], [80.14680481, 13.54680538], [80.14653015, 13.54681015], [80.14653015, 13.54653168], [80.14624786, 13.54653168], [80.14624786, 13.54624939], [80.14569092, 13.54624939], [80.14569092, 13.54597092], [80.1451416, 13.54597092], [80.1451416, 13.5456953], [80.14485931, 13.5456953], [80.14485931, 13.54541683], [80.14431, 13.54541969], [80.14431, 13.54513931], [80.14375305, 13.54513931], [80.14375305, 13.54486084], [80.14180756, 13.54486084], [80.14180756, 13.54513931], [80.14125061, 13.54513931], [80.14125061, 13.54541969], [80.14097595, 13.54541683], [80.14097595, 13.54597092], [80.14068604, 13.54597092], [80.14068604, 13.54653168], [80.14041901, 13.54652691], [80.14041901, 13.5470829], [80.14013672, 13.5470829], [80.14013672, 13.54819584], [80.13986206, 13.54819584], [80.13986206, 13.54958439], [80.14013672, 13.54958057], [80.14013672, 13.55014038], [80.13986206, 13.55014038], [80.13986206, 13.55041981], [80.13957977, 13.5504179], [80.13957977, 13.55097198], [80.13931274, 13.55097198], [80.13931274, 13.55125046], [80.13903046, 13.55125046], [80.13903046, 13.55152798], [80.13874817, 13.55152798], [80.13874817, 13.55208397], [80.13847351, 13.55208397], [80.13847351, 13.55236244], [80.13817596, 13.55235958], [80.13817596, 13.55263996], [80.13791656, 13.55263996], [80.13791656, 13.55319405], [80.13764191, 13.55319405], [80.13764191, 13.55347157], [80.13735962, 13.55347157], [80.13735962, 13.55819416], [80.13708496, 13.55819416], [80.13708496, 13.56069374], [80.13819122, 13.56069374], [80.13819122, 13.56097221], [80.13903046, 13.56097031], [80.13903046, 13.56124973], [80.13931274, 13.56124973], [80.13931274, 13.56181145], [80.13957977, 13.56181145], [80.13957977, 13.56235981], [80.13986206, 13.56235981], [80.13986206, 13.56292057], [80.14013672, 13.56292057], [80.14013672, 13.56403065], [80.14041901, 13.56402874], [80.14041901, 13.56569481], [80.14013672, 13.56569004], [80.14013672, 13.5662508], [80.13986206, 13.5662508], [80.13986206, 13.56708336], [80.13957977, 13.56708145], [80.13957977, 13.56764126], [80.13930511, 13.56763935], [80.13930511, 13.56819534], [80.13903046, 13.56818962], [80.13903046, 13.56875134], [80.13874817, 13.56875134], [80.13874817, 13.56931019], [80.13847351, 13.56930542], [80.13847351, 13.56958294], [80.13817596, 13.56958103], [80.13817596, 13.57014084], [80.13791656, 13.57013893], [80.13791656, 13.57069302], [80.13764191, 13.57069111], [80.13764191, 13.57125092], [80.13735962, 13.57125092], [80.13735962, 13.57180977], [80.13708496, 13.571805], [80.13708496, 13.57208347], [80.13680267, 13.57208061], [80.13680267, 13.57236099], [80.13652802, 13.57236099], [80.13652802, 13.57265091], [80.13625336, 13.57265091], [80.13625336, 13.57292175], [80.13597107, 13.57291698], [80.13597107, 13.57347107], [80.13569641, 13.57347107], [80.13569641, 13.5737524], [80.13540649, 13.5737524], [80.13540649, 13.57403183], [80.13513947, 13.57403183], [80.13513947, 13.5743103], [80.13486481, 13.57430458], [80.13486481, 13.57458305], [80.13346863, 13.57458305], [80.13346863, 13.57486057], [80.13318634, 13.57486057], [80.13318634, 13.57514191], [80.13263702, 13.57514191], [80.13263702, 13.57542038], [80.13236237, 13.57541847], [80.13236237, 13.57569313], [80.13208008, 13.57569313], [80.13208008, 13.57597065], [80.13181305, 13.57597065], [80.13181305, 13.57625198], [80.13124847, 13.57625198], [80.13124847, 13.57653046], [80.13096619, 13.57653046], [80.13096619, 13.57681179], [80.13041687, 13.57680607], [80.13041687, 13.57708359], [80.13014221, 13.57708359], [80.13014221, 13.57736206], [80.12960052, 13.5773592], [80.12960052, 13.57763958], [80.12902832, 13.57763958], [80.12902832, 13.57791996], [80.12875366, 13.57791805], [80.12875366, 13.57819366], [80.12819672, 13.57819366], [80.12819672, 13.57847214], [80.1279068, 13.57845974], [80.1279068, 13.57903004], [80.12763977, 13.57902813], [80.12763977, 13.57958412], [80.12735748, 13.57957935], [80.12735748, 13.58014011], [80.12708282, 13.58014011], [80.12708282, 13.5806942], [80.12680817, 13.5806942], [80.12680817, 13.58220863], [80.12680817, 13.58263969], [80.12652588, 13.58263779], [80.12652588, 13.58485985], [80.12680817, 13.58485985], [80.12680817, 13.58542061], [80.12708282, 13.58542061], [80.12708282, 13.58625031], [80.12735748, 13.58625031], [80.12735748, 13.58681107], [80.12847137, 13.5868063], [80.12847137, 13.58708191], [80.12958527, 13.58708382], [80.12958527, 13.58736038], [80.12985992, 13.58736038], [80.12985992, 13.5876503], [80.13041687, 13.5876503], [80.13041687, 13.58792114], [80.13069153, 13.58791637], [80.13069153, 13.58819389], [80.13124847, 13.58819389], [80.13124847, 13.58847237], [80.13236237, 13.58847237], [80.13236237, 13.58819389], [80.13263702, 13.58819389], [80.13263702, 13.58791637], [80.13346863, 13.58791637], [80.13346863, 13.58819389], [80.13402557, 13.58819389], [80.13402557, 13.58847237], [80.13458252, 13.58847046], [80.13458252, 13.58875275], [80.13513947, 13.58875275], [80.13513947, 13.58903122], [80.13569641, 13.58903122], [80.13569641, 13.58931065], [80.1359024, 13.58930874], [80.13625336, 13.58930683], [80.13625336, 13.58958244], [80.13652802, 13.58957958], [80.13652802, 13.58985996], [80.13707733, 13.58985996], [80.13707733, 13.5901413], [80.13735962, 13.5901413], [80.13735962, 13.59042072], [80.13791656, 13.59041691], [80.13791656, 13.59069538], [80.13817596, 13.59068966], [80.13817596, 13.59125137], [80.14013672, 13.59125137], [80.14013672, 13.59097004], [80.14125061, 13.5909729], [80.14125061, 13.59069538], [80.14180756, 13.59069538], [80.14180756, 13.5909729], [80.14263916, 13.59097004], [80.14263916, 13.59125137], [80.14653015, 13.59125137], [80.14653015, 13.59097004], [80.14819336, 13.5909729], [80.14819336, 13.59069538], [80.1498642, 13.59069538], [80.1498642, 13.59041691], [80.15116882, 13.59041882], [80.1515274, 13.59042072], [80.1515274, 13.5901413], [80.15319824, 13.5901413], [80.15319824, 13.58985996], [80.15513611, 13.58985996], [80.15513611, 13.58957958], [80.15569305, 13.58958244], [80.15569305, 13.58930683], [80.15651703, 13.58931065], [80.15651703, 13.58903122], [80.15735626, 13.58903122], [80.15735626, 13.58931065], [80.15791321, 13.58931065], [80.15791321, 13.5901413], [80.1581955, 13.59013939], [80.1581955, 13.5909729], [80.15791321, 13.59097004], [80.15791321, 13.59152889], [80.15763855, 13.59152889], [80.15763855, 13.59180927], [80.15680695, 13.59180927], [80.15680695, 13.59152889], [80.15651703, 13.59152889], [80.15651703, 13.59125137], [80.15625, 13.59125137], [80.15625, 13.59097004], [80.1554184, 13.59097004], [80.1554184, 13.59125137], [80.15348053, 13.59125137], [80.15348053, 13.59152889], [80.15180206, 13.59152889], [80.15180206, 13.59180927], [80.1505127, 13.59180546], [80.15013885, 13.59180546], [80.15013885, 13.59208298], [80.14902496, 13.59208298], [80.14902496, 13.59236145], [80.14763641, 13.59236145], [80.14763641, 13.59264088], [80.1470871, 13.59264088], [80.1470871, 13.59292126], [80.14680481, 13.59291744], [80.14680481, 13.59319496], [80.14624786, 13.59319496], [80.14624786, 13.59347343], [80.14541626, 13.59346199], [80.14541626, 13.59403133], [80.1451416, 13.59403133], [80.1451416, 13.59514141], [80.14485931, 13.59513855], [80.14485931, 13.59597301], [80.14457703, 13.59597111], [80.14457703, 13.59625053], [80.14431, 13.59625053], [80.14431, 13.59653187], [80.14347076, 13.59653187], [80.14347076, 13.59682083], [80.1423645, 13.59680462], [80.1423645, 13.59708309], [80.14152527, 13.59708309], [80.14152527, 13.59736061], [80.13874817, 13.59736061], [80.13874817, 13.59764099], [80.13764191, 13.59764099], [80.13764191, 13.59792042], [80.13680267, 13.5979166], [80.13680267, 13.59819317], [80.13625336, 13.59819317], [80.13625336, 13.5984726], [80.13569641, 13.59847069], [80.13569641, 13.59875107], [80.13540649, 13.59875107], [80.13540649, 13.59902859], [80.13485718, 13.59902859], [80.13485718, 13.59930992], [80.1340332, 13.59930992], [80.1340332, 13.5995903], [80.13319397, 13.59958267], [80.13319397, 13.59986115], [80.12763977, 13.59986115], [80.12763977, 13.60014153], [80.12735748, 13.60014153], [80.12735748, 13.60042191], [80.12680817, 13.60041714], [80.12680817, 13.60069466], [80.12625122, 13.60069466], [80.12625122, 13.60097122], [80.12596893, 13.60097122], [80.12596893, 13.6012516], [80.12541962, 13.6012516], [80.12541962, 13.60153198], [80.12486267, 13.60153198], [80.12486267, 13.60069084], [80.12513733, 13.60069466], [80.12513733, 13.59986115], [80.12541962, 13.59986115], [80.12541962, 13.59958267], [80.12596893, 13.5995903], [80.12596893, 13.59930992], [80.12623596, 13.59930992], [80.12623596, 13.59902859], [80.12847137, 13.59902859], [80.12847137, 13.59875107], [80.12874603, 13.59875107], [80.12874603, 13.59819126], [80.12902832, 13.59819317], [80.12902832, 13.5979166], [80.12931061, 13.59792042], [80.12931061, 13.59764099], [80.12960052, 13.59764099], [80.12960052, 13.59736061], [80.12902832, 13.59736061], [80.12902832, 13.59597111], [80.12930298, 13.59597301], [80.12930298, 13.59569454], [80.12958527, 13.59569454], [80.12958527, 13.59513855], [80.12985992, 13.59514141], [80.12985992, 13.59486103], [80.13014221, 13.59486103], [80.13014221, 13.59458065], [80.13041687, 13.59458256], [80.13041687, 13.59319496], [80.13014221, 13.59319496], [80.13014221, 13.59291744], [80.12985992, 13.59292126], [80.12985992, 13.59264088], [80.12960052, 13.59264088], [80.12960052, 13.59180927], [80.12931061, 13.59180927], [80.12931061, 13.59125137], [80.12958527, 13.59125137], [80.12958527, 13.5909729], [80.12985992, 13.5909729], [80.12985992, 13.59069538], [80.13014221, 13.59069538], [80.13014221, 13.59013939], [80.13041687, 13.5901413], [80.13041687, 13.58990192], [80.13041687, 13.58958244], [80.13069153, 13.58958244], [80.13069153, 13.58930683], [80.12985992, 13.58931065], [80.12985992, 13.58903122], [80.12902832, 13.58903122], [80.12902832, 13.58875275], [80.12819672, 13.58875275], [80.12819672, 13.58847046], [80.12652588, 13.58847237], [80.12652588, 13.58859062], [80.12652588, 13.58903122], [80.12623596, 13.58903122], [80.12623596, 13.58985996], [80.12596893, 13.58985996], [80.12596893, 13.59069538], [80.12568665, 13.59068966], [80.12568665, 13.59125137], [80.12541962, 13.59125137], [80.12541962, 13.59180927], [80.12513733, 13.59180546], [80.12513733, 13.59236145], [80.12486267, 13.59236145], [80.12486267, 13.59292126], [80.12458038, 13.59291744], [80.12458038, 13.59347343], [80.12486267, 13.59346199], [80.12486267, 13.59431171], [80.12458038, 13.59431171], [80.12458038, 13.59514141], [80.12430573, 13.59513855], [80.12430573, 13.59569454], [80.12374878, 13.59569454], [80.12374878, 13.59597301], [80.12346649, 13.59597111], [80.12346649, 13.59653187], [80.12319183, 13.5965271], [80.12319183, 13.59708309], [80.12291718, 13.59708118], [80.12291718, 13.59764099], [80.12264252, 13.59763908], [80.12264252, 13.5984726], [80.12236023, 13.59847069], [80.12236023, 13.5995903], [80.12208557, 13.59958267], [80.12208557, 13.60069466], [80.12180328, 13.60069466], [80.12180328, 13.60115147], [80.12180328, 13.60153198], [80.12152863, 13.60153198], [80.12152863, 13.60181046], [80.12124634, 13.60181046], [80.12124634, 13.60236168], [80.12097168, 13.60236168], [80.12097168, 13.60264015], [80.12069702, 13.60262966], [80.12069702, 13.60402966], [80.12041473, 13.60402775], [80.12041473, 13.60569382], [80.12069702, 13.60569096], [80.12069702, 13.60624981], [80.12097168, 13.60624981], [80.12097168, 13.60680962], [80.12124634, 13.6068058], [80.12124634, 13.60708427], [80.12291718, 13.60708427], [80.12291718, 13.6068058], [80.12403107, 13.60680962], [80.12403107, 13.60653019], [80.12374878, 13.60653019], [80.12374878, 13.60624981], [80.12346649, 13.60624981], [80.12346649, 13.60596943], [80.12319183, 13.60597229], [80.12319183, 13.6054163], [80.12374878, 13.60542011], [80.12374878, 13.60513973], [80.12431335, 13.60513973], [80.12431335, 13.6050396], [80.12430573, 13.60486221], [80.12486267, 13.60486221], [80.12486267, 13.60458374], [80.12625122, 13.60458374], [80.12625122, 13.60486221], [80.12652588, 13.60485935], [80.12652588, 13.60513973], [80.12708282, 13.60513973], [80.12708282, 13.60542011], [80.12735748, 13.6054163], [80.12735748, 13.60569382], [80.12763977, 13.60569382], [80.12763977, 13.60597229], [80.13124847, 13.60596943], [80.13124847, 13.60624981], [80.13680267, 13.60624981], [80.13680267, 13.60653019], [80.13764191, 13.60653019], [80.13764191, 13.60680962], [80.13780975, 13.60680771], [80.13819122, 13.6068058], [80.13819122, 13.60708427], [80.13903046, 13.60707855], [80.13903046, 13.60736179], [80.13931274, 13.60736179], [80.13931274, 13.60764027], [80.13986206, 13.60764027], [80.13986206, 13.60791969], [80.14013672, 13.60791588], [80.14013672, 13.60819435], [80.14069366, 13.60819435], [80.14069366, 13.60847187], [80.14097595, 13.60847187], [80.14097595, 13.60876083], [80.14154053, 13.60876083], [80.14154053, 13.60903263], [80.14180756, 13.60903263], [80.14180756, 13.6093111], [80.14208221, 13.60930634], [80.14208221, 13.60958195], [80.14263916, 13.60958195], [80.14263916, 13.60986233], [80.14290619, 13.60986042], [80.14290619, 13.61013985], [80.14347076, 13.61013985], [80.14347076, 13.61042118], [80.14375305, 13.61041641], [80.14375305, 13.61069393], [80.14402771, 13.61069393], [80.14402771, 13.6109724], [80.14457703, 13.61096954], [80.14457703, 13.61124992], [80.14485931, 13.61124992], [80.14485931, 13.61153126], [80.14541626, 13.61153126], [80.14541626, 13.61182022], [80.14569092, 13.61182022], [80.14569092, 13.61236], [80.14597321, 13.61236], [80.14597321, 13.61292076], [80.14624786, 13.61291599], [80.14624786, 13.61347198], [80.14653015, 13.61347008], [80.14653015, 13.61431122], [80.14680481, 13.61430645], [80.14680481, 13.6148634], [80.1470871, 13.61485958], [80.1470871, 13.6154213], [80.1473465, 13.6154213], [80.1473465, 13.61625099], [80.14763641, 13.61625099], [80.14763641, 13.6168108], [80.1479187, 13.6168108], [80.1479187, 13.61736107], [80.14819336, 13.61736107], [80.14819336, 13.61792088], [80.14847565, 13.61791706], [80.14847565, 13.61847305], [80.14902496, 13.61847305]]], [[[80.0534668, 13.58931065], [80.0534668, 13.58903122], [80.05403137, 13.58903122], [80.05403137, 13.58875275], [80.05596924, 13.58875275], [80.05596924, 13.58847046], [80.05625153, 13.58847237], [80.05625153, 13.58819389], [80.05652618, 13.58819389], [80.05652618, 13.58736038], [80.05680847, 13.58736038], [80.05680847, 13.5868063], [80.05652618, 13.58681107], [80.05652618, 13.58653069], [80.05458069, 13.58653069], [80.05458069, 13.58681107], [80.05430603, 13.5868063], [80.05430603, 13.58708191], [80.05403137, 13.58708191], [80.05403137, 13.58736038], [80.05374908, 13.58736038], [80.05374908, 13.5876503], [80.0534668, 13.5876503], [80.0534668, 13.58792114], [80.05291748, 13.58791637], [80.05291748, 13.58819389], [80.05236053, 13.58819199], [80.05236053, 13.58875275], [80.05264282, 13.58875275], [80.05264282, 13.58903122], [80.05291748, 13.58903122], [80.05291748, 13.58931065], [80.0534668, 13.58931065]]], [[[80.09707642, 13.64153099], [80.09707642, 13.64124966], [80.0973587, 13.64124966], [80.0973587, 13.64013958], [80.09707642, 13.64013958], [80.09707642, 13.63874054], [80.09680939, 13.63875008], [80.09680176, 13.63819408], [80.0965271, 13.63819408], [80.0965271, 13.63763809], [80.09626007, 13.63764], [80.09626007, 13.63735962], [80.09597015, 13.63736153], [80.09597015, 13.63708401], [80.09541321, 13.63708401], [80.09541321, 13.63680553], [80.09430695, 13.63681126], [80.09430695, 13.63652992], [80.0929184, 13.63652992], [80.0929184, 13.63624954], [80.09152985, 13.63624954], [80.09152985, 13.63681126], [80.09124756, 13.63680553], [80.09124756, 13.63694096], [80.09124756, 13.63736153], [80.09152985, 13.63735962], [80.09152985, 13.63792133], [80.0918045, 13.63791561], [80.0918045, 13.63819408], [80.09208679, 13.63819408], [80.09208679, 13.6384716], [80.09236145, 13.6384716], [80.09236145, 13.63875008], [80.09263611, 13.63874054], [80.09263611, 13.63931084], [80.0929184, 13.63930416], [80.0929184, 13.63958359], [80.09319305, 13.63958359], [80.09319305, 13.63986015], [80.0934906, 13.63986015], [80.0934906, 13.64013958], [80.09401703, 13.64013958], [80.09401703, 13.64042091], [80.09430695, 13.64041615], [80.09430695, 13.64069366], [80.0945816, 13.64069366], [80.0945816, 13.64097214], [80.09485626, 13.64097023], [80.09485626, 13.64124966], [80.09533691, 13.64124966], [80.09597015, 13.64124966], [80.09597015, 13.64153099], [80.09707642, 13.64153099]]], [[[80.10652924, 13.65291977], [80.10652924, 13.65208054], [80.10624695, 13.6520834], [80.10624695, 13.6515274], [80.10652924, 13.65152931], [80.10652924, 13.65125084], [80.10708618, 13.65125084], [80.10708618, 13.65097141], [80.10736084, 13.65097332], [80.10736084, 13.65013885], [80.10764313, 13.65014076], [80.10764313, 13.64931202], [80.10791779, 13.64931202], [80.10791779, 13.64847088], [80.10819244, 13.64847088], [80.10819244, 13.64680481], [80.10791779, 13.64681244], [80.10791779, 13.64625072], [80.10764313, 13.64625072], [80.10764313, 13.6459713], [80.10680389, 13.64597321], [80.10680389, 13.64569473], [80.10652924, 13.64569473], [80.10652924, 13.64541721], [80.10624695, 13.64542103], [80.10624695, 13.64514065], [80.10597229, 13.64514065], [80.10597229, 13.64431095], [80.10569763, 13.64431095], [80.10569763, 13.64319038], [80.10541534, 13.64319515], [80.10541534, 13.64235973], [80.10514069, 13.64235973], [80.10514069, 13.64153099], [80.1048584, 13.64153099], [80.1048584, 13.64068985], [80.10458374, 13.64069366], [80.10458374, 13.63958359], [80.10430908, 13.63958359], [80.10430908, 13.63875008], [80.10402679, 13.63875008], [80.10402679, 13.63791561], [80.10375214, 13.63792133], [80.10375214, 13.63735962], [80.10346985, 13.63736153], [80.10346985, 13.6372509], [80.10346985, 13.63708401], [80.1029129, 13.63708401], [80.1029129, 13.63680553], [80.10124969, 13.63680553], [80.10124969, 13.63708401], [80.10097504, 13.63708401], [80.10097504, 13.63736153], [80.10069275, 13.63735962], [80.10069275, 13.63764], [80.10041809, 13.63763809], [80.10041809, 13.6384716], [80.1001358, 13.6384697], [80.1001358, 13.63931084], [80.10041809, 13.63930416], [80.10041809, 13.63986015], [80.10069275, 13.63986015], [80.10069275, 13.64011097], [80.10069275, 13.64042091], [80.10097504, 13.64041615], [80.10097504, 13.64097214], [80.10124969, 13.64097023], [80.10124969, 13.64153099], [80.10152435, 13.64152813], [80.10152435, 13.6418066], [80.10180664, 13.64180183], [80.10180664, 13.64235973], [80.1020813, 13.64235973], [80.1020813, 13.64292145], [80.10236359, 13.64291573], [80.10236359, 13.64347267], [80.10263824, 13.6434679], [80.10263824, 13.64403057], [80.1029129, 13.64402866], [80.1029129, 13.64458466], [80.10320282, 13.64458275], [80.10320282, 13.6448698], [80.10346985, 13.6448698], [80.10346985, 13.64542103], [80.10375214, 13.64542103], [80.10375214, 13.64625072], [80.10402679, 13.64625072], [80.10402679, 13.64681244], [80.10430908, 13.64680481], [80.10430908, 13.64708328], [80.10458374, 13.64708328], [80.10458374, 13.6473608], [80.1048584, 13.6473608], [80.1048584, 13.64819527], [80.10514069, 13.64818954], [80.10514069, 13.64903069], [80.1054306, 13.64903069], [80.1054306, 13.65014076], [80.10569763, 13.65014076], [80.10569763, 13.65125084], [80.10597229, 13.65125084], [80.10597229, 13.65263939], [80.10624695, 13.65263939], [80.10624695, 13.65291977], [80.10652924, 13.65291977]]], [[[80.10263824, 13.67764091], [80.10263824, 13.67736053], [80.10402679, 13.67736053], [80.10402679, 13.67708302], [80.10541534, 13.67708302], [80.10541534, 13.67680454], [80.10624695, 13.67681026], [80.10624695, 13.6756897], [80.10597229, 13.67569542], [80.10597229, 13.67541695], [80.10569763, 13.67542171], [80.10569763, 13.67486954], [80.1054306, 13.67486954], [80.1054306, 13.67347145], [80.10569763, 13.67347336], [80.10569763, 13.67152882], [80.1054306, 13.67153072], [80.1054306, 13.66986275], [80.10514069, 13.66986275], [80.10514069, 13.66874981], [80.1048584, 13.66874981], [80.1048584, 13.66847038], [80.10430908, 13.66847229], [80.10430908, 13.66819382], [80.10402679, 13.66819191], [80.10402679, 13.66903114], [80.10375214, 13.66902637], [80.10375214, 13.6706953], [80.10402679, 13.67068958], [80.10402679, 13.6718092], [80.10375214, 13.67180538], [80.10375214, 13.67236137], [80.10346985, 13.67236137], [80.10346985, 13.67292118], [80.10320282, 13.67292118], [80.10320282, 13.67403126], [80.1029129, 13.67403126], [80.1029129, 13.67514133], [80.10263824, 13.67513943], [80.10263824, 13.67597294], [80.10235596, 13.67597103], [80.10235596, 13.67681026], [80.1020813, 13.67681026], [80.1020813, 13.67764091], [80.10263824, 13.67764091]]], [[[81.02791595, 15.76569366], [81.02791595, 15.76541615], [81.02874756, 15.76542091], [81.02874756, 15.76513958], [81.02958679, 15.76513958], [81.02958679, 15.76486015], [81.02986145, 15.76486015], [81.02986145, 15.76458359], [81.02958679, 15.76458359], [81.02958679, 15.76430416], [81.02929688, 15.76431084], [81.02929688, 15.76375008], [81.02902985, 15.76375008], [81.02902985, 15.76319027], [81.02874756, 15.76319408], [81.02874756, 15.76291561], [81.0284729, 15.76292133], [81.0284729, 15.76264], [81.02819824, 15.76264], [81.02819824, 15.76235962], [81.02791595, 15.76236153], [81.02791595, 15.76208401], [81.0276413, 15.76208401], [81.0276413, 15.76180553], [81.02735901, 15.76181126], [81.02735901, 15.76152992], [81.02707672, 15.76152992], [81.02707672, 15.76124954], [81.02680206, 15.76124954], [81.02680206, 15.76097202], [81.0265274, 15.76097202], [81.0265274, 15.76069355], [81.02625275, 15.76069355], [81.02625275, 15.76041794], [81.02597046, 15.76041985], [81.02597046, 15.76014042], [81.0256958, 15.76014042], [81.0256958, 15.75986195], [81.02540588, 15.75986195], [81.02540588, 15.75958157], [81.02513885, 15.75958443], [81.02513885, 15.75930595], [81.02485657, 15.75930977], [81.02485657, 15.75903034], [81.02458191, 15.75903034], [81.02458191, 15.75874996], [81.02430725, 15.75874996], [81.02430725, 15.75846863], [81.02402496, 15.75847244], [81.02402496, 15.75819397], [81.02375031, 15.75819397], [81.02375031, 15.75791645], [81.0229187, 15.75792027], [81.0229187, 15.75765133], [81.02179718, 15.75765133], [81.02179718, 15.75736046], [81.02097321, 15.75736046], [81.02097321, 15.75765133], [81.02041626, 15.75765133], [81.02041626, 15.75792027], [81.0201416, 15.75791645], [81.0201416, 15.7581892], [81.02041626, 15.75819588], [81.02041626, 15.75847244], [81.02097321, 15.75846863], [81.02097321, 15.75874996], [81.02124786, 15.75874996], [81.02124786, 15.75903034], [81.02179718, 15.75903034], [81.02179718, 15.75930977], [81.02236176, 15.75930595], [81.02236176, 15.75958443], [81.0229187, 15.75958157], [81.0229187, 15.75986195], [81.02320099, 15.75986195], [81.02320099, 15.76014042], [81.02375031, 15.76014042], [81.02375031, 15.76041985], [81.02430725, 15.76041794], [81.02430725, 15.76069355], [81.0248642, 15.76069355], [81.0248642, 15.76097202], [81.02513885, 15.76097202], [81.02513885, 15.76124954], [81.0256958, 15.76124954], [81.0256958, 15.76181126], [81.02597046, 15.76180553], [81.02597046, 15.76236153], [81.02626038, 15.76235962], [81.02626038, 15.76292133], [81.0265274, 15.76291561], [81.0265274, 15.7634716], [81.02680206, 15.7634697], [81.02680206, 15.76403141], [81.02708435, 15.7640276], [81.02708435, 15.76458359], [81.02735901, 15.76457977], [81.02735901, 15.76513958], [81.0276413, 15.76513767], [81.0276413, 15.76569366], [81.02791595, 15.76569366]]], [[[80.78291321, 15.83763981], [80.78291321, 15.83708096], [80.7831955, 15.83708382], [80.7831955, 15.8368063], [80.78347015, 15.83681011], [80.78347015, 15.83652973], [80.7840271, 15.83652973], [80.7840271, 15.83625031], [80.78430176, 15.83625031], [80.78430939, 15.83597088], [80.78458405, 15.83597088], [80.78458405, 15.83569336], [80.7848587, 15.83569336], [80.7848587, 15.83541775], [80.78542328, 15.83541965], [80.78542328, 15.83514023], [80.7859726, 15.83514023], [80.7859726, 15.83486176], [80.78624725, 15.83486176], [80.78624725, 15.83458138], [80.7868042, 15.83458328], [80.7868042, 15.83430481], [80.78708649, 15.83430958], [80.78708649, 15.83403015], [80.78736115, 15.83403015], [80.78736115, 15.83375168], [80.7876358, 15.83375168], [80.7876358, 15.8334713], [80.78847504, 15.8334713], [80.78847504, 15.83319473], [80.78930664, 15.83319473], [80.78930664, 15.83291531], [80.7895813, 15.83293056], [80.7895813, 15.8326416], [80.78985596, 15.8326416], [80.78985596, 15.83236122], [80.79013824, 15.83236122], [80.79013824, 15.83208275], [80.7904129, 15.83208275], [80.7904129, 15.83152676], [80.79070282, 15.83153152], [80.79070282, 15.83124924], [80.79096985, 15.83124924], [80.79096985, 15.83069134], [80.79125214, 15.83069515], [80.79125214, 15.83013916], [80.79151917, 15.83014107], [80.79151917, 15.82958126], [80.79180908, 15.82958317], [80.79180908, 15.82763863], [80.79207611, 15.82764053], [80.79207611, 15.82736111], [80.7923584, 15.82736111], [80.7923584, 15.82708263], [80.79319763, 15.82708263], [80.79319763, 15.82680511], [80.79347229, 15.82681179], [80.79347229, 15.82653141], [80.79374695, 15.82653141], [80.79374695, 15.82625103], [80.79319763, 15.82625103], [80.79319763, 15.82597065], [80.79264069, 15.82597256], [80.79264069, 15.82569504], [80.79208374, 15.82569504], [80.79208374, 15.82513905], [80.79180908, 15.82514095], [80.79180908, 15.82431126], [80.79151917, 15.82431126], [80.79151917, 15.82403088], [80.79096985, 15.82403088], [80.79096985, 15.82374191], [80.7904129, 15.82374191], [80.7904129, 15.82403088], [80.78985596, 15.82403088], [80.78985596, 15.82431126], [80.78930664, 15.82430458], [80.78930664, 15.82486057], [80.78901672, 15.82486057], [80.78901672, 15.82542133], [80.78874969, 15.82541656], [80.78874969, 15.82597256], [80.78848267, 15.82597065], [80.78848267, 15.82653141], [80.78819275, 15.82652664], [80.78819275, 15.82708263], [80.78791809, 15.82708073], [80.78791809, 15.82764053], [80.7876358, 15.82763863], [80.7876358, 15.82819462], [80.78736115, 15.82819462], [80.78736115, 15.82847309], [80.78708649, 15.82847118], [80.78708649, 15.82903099], [80.78679657, 15.82903099], [80.78679657, 15.82931042], [80.78652954, 15.8293047], [80.78652954, 15.82958317], [80.78624725, 15.82958126], [80.78624725, 15.82987022], [80.7859726, 15.82987022], [80.7859726, 15.83097076], [80.78569794, 15.83097076], [80.78569794, 15.83153152], [80.78541565, 15.83152676], [80.78541565, 15.83208275], [80.78514099, 15.83208275], [80.78514099, 15.83236122], [80.7848587, 15.83236122], [80.7848587, 15.83293056], [80.78458405, 15.83291531], [80.78458405, 15.8334713], [80.78430176, 15.8334713], [80.78430176, 15.83375168], [80.7840271, 15.83375168], [80.7840271, 15.83403015], [80.78375244, 15.83402729], [80.78375244, 15.83458328], [80.78347015, 15.83458138], [80.78347015, 15.83486176], [80.78320313, 15.83486176], [80.78320313, 15.83514023], [80.78291321, 15.83514023], [80.78291321, 15.83569336], [80.78263855, 15.83568192], [80.78263855, 15.83625031], [80.78234863, 15.83625031], [80.78234863, 15.83681011], [80.7820816, 15.83681011], [80.7820816, 15.83763981], [80.78291321, 15.83763981]]], [[[80.78791809, 15.84319401], [80.78791809, 15.84291553], [80.78848267, 15.84292126], [80.78848267, 15.84263992], [80.78901672, 15.84263992], [80.78901672, 15.84235954], [80.78930664, 15.8423624], [80.78930664, 15.84208393], [80.78986359, 15.84208393], [80.78986359, 15.84180641], [80.7904129, 15.84181118], [80.7904129, 15.84069157], [80.79013824, 15.84069443], [80.79013824, 15.84041595], [80.78985596, 15.84041977], [80.78985596, 15.84014034], [80.7895813, 15.84014034], [80.7895813, 15.83986187], [80.78930664, 15.83986187], [80.78930664, 15.83958244], [80.78902435, 15.83958435], [80.78902435, 15.8381958], [80.78874969, 15.8381958], [80.78874969, 15.83763981], [80.78791809, 15.83763981], [80.78791809, 15.83792019], [80.7876358, 15.83791637], [80.7876358, 15.8381958], [80.78736115, 15.83819103], [80.78736115, 15.84014034], [80.78708649, 15.84013844], [80.78708649, 15.84097195], [80.78679657, 15.84097195], [80.78679657, 15.84125042], [80.78652954, 15.84125042], [80.78652954, 15.84152985], [80.78624725, 15.84152985], [80.78624725, 15.84263992], [80.78652954, 15.84263992], [80.78652954, 15.84292126], [80.7868042, 15.84291553], [80.7868042, 15.84319401], [80.78791809, 15.84319401]]], [[[80.7859726, 15.85652924], [80.7859726, 15.85625076], [80.78624725, 15.85625076], [80.78624725, 15.85597134], [80.7868042, 15.85597324], [80.7868042, 15.85569477], [80.78708649, 15.85569477], [80.78708649, 15.85541725], [80.78736115, 15.85542202], [80.78736115, 15.85514069], [80.7876358, 15.85514069], [80.7876358, 15.85458088], [80.78791809, 15.85458279], [80.78791809, 15.85180473], [80.7876358, 15.85181141], [80.7876358, 15.85097027], [80.78791809, 15.85097313], [80.78791809, 15.8493042], [80.78819275, 15.84931087], [80.78819275, 15.84597015], [80.78791809, 15.84597206], [80.78791809, 15.84569359], [80.7876358, 15.84569359], [80.7876358, 15.84486008], [80.78708649, 15.84485054], [80.78708649, 15.84514046], [80.78652954, 15.84514046], [80.78652954, 15.84542084], [80.78624725, 15.84541607], [80.78624725, 15.84569359], [80.7859726, 15.84568977], [80.7859726, 15.84624958], [80.78569794, 15.84624958], [80.78569794, 15.84653091], [80.78541565, 15.84652805], [80.78541565, 15.84735966], [80.78514099, 15.84736347], [80.78514099, 15.84791565], [80.7848587, 15.84791565], [80.7848587, 15.8484726], [80.78457642, 15.84846973], [80.78457642, 15.85042095], [80.78430176, 15.85042095], [80.78430176, 15.85153103], [80.7840271, 15.85152912], [80.7840271, 15.85208321], [80.78375244, 15.85208321], [80.78375244, 15.85458279], [80.7840271, 15.85458088], [80.7840271, 15.85514069], [80.78430176, 15.85514069], [80.78430176, 15.85542202], [80.7848587, 15.85541725], [80.7848587, 15.85569477], [80.78514099, 15.85569477], [80.78514099, 15.85597324], [80.78542328, 15.85597134], [80.78542328, 15.85625076], [80.78569794, 15.85625076], [80.78569794, 15.85652924], [80.7859726, 15.85652924]]], [[[80.77348328, 15.86180973], [80.77348328, 15.86125183], [80.77375031, 15.86125183], [80.77375031, 15.86097145], [80.77402496, 15.86097145], [80.77402496, 15.86013889], [80.77430725, 15.86014175], [80.77430725, 15.85958099], [80.77458191, 15.8595829], [80.77458191, 15.85902691], [80.77485657, 15.85903168], [80.77485657, 15.8587513], [80.77540588, 15.8587513], [80.77540588, 15.85819054], [80.7756958, 15.8581953], [80.7756958, 15.85791683], [80.77597046, 15.85791969], [80.77597046, 15.85569096], [80.77625275, 15.85569477], [80.77625275, 15.85541725], [80.77654266, 15.85542202], [80.77654266, 15.85514069], [80.77680206, 15.85514069], [80.77680206, 15.85404015], [80.77707672, 15.85404015], [80.77707672, 15.85153103], [80.7776413, 15.85153103], [80.7776413, 15.85125065], [80.77791595, 15.85125065], [80.77791595, 15.85097027], [80.77874756, 15.85097313], [80.77874756, 15.85041714], [80.77902985, 15.85042095], [80.77902985, 15.85014057], [80.77928925, 15.85014057], [80.77928925, 15.84875107], [80.77960205, 15.84875107], [80.77960205, 15.84846973], [80.77986145, 15.8484726], [80.77986145, 15.84791565], [80.78013611, 15.84791565], [80.78013611, 15.84708214], [80.7804184, 15.84708214], [80.7804184, 15.84624958], [80.78069305, 15.84624958], [80.78069305, 15.84485054], [80.7804184, 15.84486008], [80.7804184, 15.84367275], [80.7804184, 15.84347153], [80.77986145, 15.84346962], [80.77986145, 15.84375], [80.77958679, 15.84375], [80.77958679, 15.84429932], [80.77958679, 15.84458447], [80.77928925, 15.8445797], [80.77928925, 15.84514046], [80.77902985, 15.8451376], [80.77902985, 15.84597206], [80.77874756, 15.84597015], [80.77874756, 15.84624958], [80.7784729, 15.84624958], [80.7784729, 15.84681129], [80.77819824, 15.84680557], [80.77819061, 15.84708214], [80.77791595, 15.84708023], [80.77791595, 15.84735966], [80.7776413, 15.84736347], [80.7776413, 15.84791565], [80.77735901, 15.84791565], [80.77735901, 15.8484726], [80.77707672, 15.84846973], [80.77707672, 15.84875107], [80.77680206, 15.84875107], [80.77680206, 15.84903145], [80.7765274, 15.84902859], [80.7765274, 15.84958458], [80.77625275, 15.84958458], [80.77625275, 15.84986115], [80.77597046, 15.84986115], [80.77597046, 15.85014057], [80.7756958, 15.85014057], [80.7756958, 15.85042095], [80.77541351, 15.85041714], [80.77541351, 15.85097313], [80.77513885, 15.85097027], [80.77513885, 15.85153103], [80.7748642, 15.85152912], [80.7748642, 15.85208321], [80.77458191, 15.85208035], [80.77458191, 15.85264111], [80.77430725, 15.85264111], [80.77430725, 15.85292053], [80.77402496, 15.85291672], [80.77402496, 15.85319519], [80.77375031, 15.85319519], [80.77375031, 15.8534708], [80.77347565, 15.8534708], [80.77348328, 15.85375118], [80.77319336, 15.85375118], [80.77319336, 15.85404015], [80.7729187, 15.85402679], [80.7729187, 15.85486126], [80.77263641, 15.85486126], [80.77263641, 15.85542202], [80.77236176, 15.85541725], [80.77236176, 15.85569477], [80.7720871, 15.85569477], [80.7720871, 15.85597324], [80.77179718, 15.85597134], [80.77179718, 15.85736084], [80.77153015, 15.85736084], [80.77153015, 15.8587513], [80.77179718, 15.8587513], [80.77179718, 15.86014175], [80.7720871, 15.86014175], [80.7720871, 15.86042023], [80.77236176, 15.86041737], [80.77236176, 15.86097145], [80.77263641, 15.86097145], [80.77263641, 15.8615303], [80.7729187, 15.8615303], [80.7729187, 15.86180973], [80.77348328, 15.86180973]]], [[[80.05986023, 15.19986153], [80.05986023, 15.1995821], [80.06041718, 15.1995821], [80.06041718, 15.19930553], [80.06069183, 15.19931126], [80.06069183, 15.19874954], [80.06124878, 15.19874954], [80.06124878, 15.19847202], [80.06153107, 15.19847202], [80.06153107, 15.19819355], [80.06180573, 15.19819355], [80.06180573, 15.19791603], [80.06208038, 15.19793034], [80.06208038, 15.19764042], [80.06236267, 15.19764042], [80.06236267, 15.19707966], [80.06124878, 15.19707966], [80.06124878, 15.19736004], [80.06096649, 15.19736004], [80.06096649, 15.19764042], [80.06069183, 15.19764042], [80.06069183, 15.19793034], [80.06041718, 15.19791603], [80.06041718, 15.19819355], [80.06014252, 15.19819355], [80.06014252, 15.19847202], [80.05986023, 15.19847202], [80.05986023, 15.19874954], [80.0595932, 15.19874954], [80.0595932, 15.19903088], [80.05930328, 15.19902802], [80.05930328, 15.1995821], [80.05958557, 15.1995821], [80.05958557, 15.19986153], [80.05986023, 15.19986153]]], [[[80.21069336, 15.50153065], [80.21069336, 15.50125122], [80.21098328, 15.50125122], [80.21097565, 15.50069523], [80.21125031, 15.50069523], [80.21125031, 15.50041676], [80.21153259, 15.50042057], [80.21153259, 15.49985981], [80.21180725, 15.49985981], [80.21180725, 15.49931145], [80.21153259, 15.49931145], [80.21153259, 15.49903107], [80.2095871, 15.49903107], [80.2095871, 15.49931145], [80.20929718, 15.49931145], [80.20929718, 15.49985981], [80.20903015, 15.49985981], [80.20903015, 15.50042057], [80.20929718, 15.50042057], [80.20929718, 15.50097275], [80.2095871, 15.50097275], [80.2095871, 15.50125122], [80.20986176, 15.50125122], [80.20986176, 15.50153065], [80.21069336, 15.50153065]]], [[[82.31735229, 16.57653046], [82.31735229, 16.57457924], [82.31708527, 16.57458115], [82.31708527, 16.57402992], [82.31680298, 16.57403183], [82.31680298, 16.57374954], [82.31652832, 16.57374954], [82.31652832, 16.57346916], [82.3154068, 16.57346916], [82.3154068, 16.57374954], [82.31485748, 16.57374954], [82.31485748, 16.57485962], [82.31513977, 16.57485962], [82.31513977, 16.57542038], [82.31541443, 16.57541656], [82.31541443, 16.57597351], [82.31597137, 16.5759697], [82.31597137, 16.57625961], [82.31624603, 16.57625961], [82.31624603, 16.57653046], [82.31735229, 16.57653046]]], [[[83.31208038, 17.68486023], [83.31208038, 17.68403053], [83.31124878, 17.68403053], [83.31124878, 17.68374062], [83.31014252, 17.68375015], [83.31014252, 17.68347168], [83.30986023, 17.68347168], [83.30986023, 17.68319511], [83.30902863, 17.68320274], [83.30902863, 17.68292046], [83.30847168, 17.68292046], [83.30847168, 17.68264008], [83.30764771, 17.68264008], [83.30764771, 17.6823616], [83.30680847, 17.6823616], [83.30680847, 17.68208313], [83.30652618, 17.68208313], [83.30652618, 17.68180466], [83.30569458, 17.68180466], [83.30569458, 17.68152809], [83.30513763, 17.68152809], [83.30513763, 17.68124962], [83.30430603, 17.68124962], [83.30430603, 17.68097115], [83.30403137, 17.68097305], [83.30403137, 17.68069458], [83.30291748, 17.68069458], [83.30291748, 17.68041611], [83.30236053, 17.68041992], [83.30236053, 17.68013954], [83.30179596, 17.68013954], [83.30179596, 17.67986107], [83.30069733, 17.67986107], [83.30069733, 17.67958069], [83.30014038, 17.6795826], [83.30014038, 17.67930794], [83.29930878, 17.67930984], [83.29930878, 17.67902946], [83.29818726, 17.67902946], [83.29818726, 17.67930984], [83.29792023, 17.67930794], [83.29792023, 17.6795826], [83.29902649, 17.67958069], [83.29902649, 17.67986107], [83.29985809, 17.67986107], [83.29985809, 17.68013954], [83.30042267, 17.68013954], [83.30042267, 17.68041992], [83.30152893, 17.68041611], [83.30152893, 17.68069458], [83.30180359, 17.68069458], [83.30180359, 17.68097305], [83.30263519, 17.68097305], [83.30263519, 17.68124962], [83.3034668, 17.68124962], [83.3034668, 17.68152809], [83.30403137, 17.68152809], [83.30403137, 17.68180466], [83.30486298, 17.68180466], [83.30486298, 17.68208313], [83.30541992, 17.68208313], [83.30541992, 17.6823616], [83.30596924, 17.6823616], [83.30596924, 17.68264008], [83.30652618, 17.68264008], [83.30652618, 17.68292046], [83.30735779, 17.68292046], [83.30735779, 17.68320274], [83.30791473, 17.68319511], [83.30791473, 17.68347168], [83.30874634, 17.68347168], [83.30874634, 17.68375015], [83.30930328, 17.68374062], [83.30930328, 17.68403053], [83.30986023, 17.68403053], [83.30986023, 17.68431282], [83.31069183, 17.68430519], [83.31069183, 17.68458366], [83.31124878, 17.68458176], [83.31124878, 17.68486023], [83.31208038, 17.68486023]]], [[[83.30569458, 17.68458366], [83.30569458, 17.68347168], [83.30541992, 17.68347168], [83.30541992, 17.68319511], [83.30458832, 17.68320274], [83.30458832, 17.68292046], [83.30430603, 17.68292046], [83.30430603, 17.68264008], [83.30403137, 17.68264008], [83.30403137, 17.6823616], [83.30319214, 17.6823616], [83.30319214, 17.68264008], [83.30291748, 17.68264008], [83.30291748, 17.68320274], [83.30319214, 17.68319511], [83.30319214, 17.68347168], [83.30347443, 17.68347168], [83.30347443, 17.68375015], [83.30374908, 17.68374062], [83.30374908, 17.68403053], [83.30430603, 17.68403053], [83.30430603, 17.68431282], [83.30513763, 17.68430519], [83.30513763, 17.68458366], [83.30569458, 17.68458366]]], [[[83.17207336, 17.56903076], [83.17207336, 17.56875038], [83.17236328, 17.56875038], [83.17236328, 17.56680107], [83.17208099, 17.56680489], [83.17208099, 17.56652832], [83.17180634, 17.56653976], [83.17180634, 17.56624985], [83.17124939, 17.56624985], [83.17124939, 17.56596947], [83.17069244, 17.56596947], [83.17069244, 17.56624985], [83.17041779, 17.56624985], [83.17041779, 17.56680489], [83.17069244, 17.56680489], [83.17069244, 17.56708336], [83.17097473, 17.56708336], [83.17097473, 17.56736183], [83.17124939, 17.56735992], [83.17124939, 17.56875038], [83.17151642, 17.56875038], [83.17151642, 17.56903076], [83.17207336, 17.56903076]]], [[[83.26985931, 17.70874977], [83.26985931, 17.70819092], [83.26875305, 17.70819473], [83.26875305, 17.7084713], [83.26847076, 17.7084713], [83.26847076, 17.70986176], [83.26875305, 17.70986176], [83.26875305, 17.71014023], [83.2701416, 17.71014023], [83.2701416, 17.70874977], [83.26985931, 17.70874977]]], [[[82.33207703, 16.72486115], [82.33207703, 16.72513962], [82.33180237, 16.72513962], [82.33180237, 16.72542], [82.33152771, 16.72541618], [82.33152771, 16.72597313], [82.33125305, 16.72597122], [82.33125305, 16.72624969], [82.33152771, 16.72624969], [82.33152771, 16.72653008], [82.33180237, 16.72652817], [82.33180237, 16.72708321], [82.33152771, 16.72707939], [82.33152771, 16.72764015], [82.33180237, 16.72764015], [82.33180237, 16.72820091], [82.33235168, 16.72820091], [82.33235168, 16.72792053], [82.3326416, 16.72792053], [82.3326416, 16.72764015], [82.33319092, 16.72764015], [82.33319092, 16.72707939], [82.33347321, 16.72708321], [82.33347321, 16.72652817], [82.33319092, 16.72653008], [82.33319092, 16.72624969], [82.33347321, 16.72624969], [82.33347321, 16.72597122], [82.33374786, 16.72597313], [82.33374786, 16.72513962], [82.33319092, 16.72513962], [82.33319092, 16.72486115], [82.33207703, 16.72486115]]], [[[82.35430908, 16.71403122], [82.35457611, 16.71403122], [82.35457611, 16.71375084], [82.3548584, 16.71375084], [82.3548584, 16.71292114], [82.35514069, 16.71292114], [82.35514069, 16.71264076], [82.35542297, 16.71264076], [82.35542297, 16.71236038], [82.35819244, 16.71236038], [82.35819244, 16.71208], [82.35874939, 16.71208], [82.35874939, 16.71236038], [82.35901642, 16.71236038], [82.35901642, 16.71292114], [82.35930634, 16.71291733], [82.35930634, 16.7131958], [82.35986328, 16.7131958], [82.35986328, 16.71347237], [82.36042023, 16.71347046], [82.36042023, 16.71375084], [82.36068726, 16.71375084], [82.36068726, 16.71430969], [82.36096954, 16.71430588], [82.36096954, 16.71458244], [82.36125183, 16.714571], [82.36125183, 16.71486092], [82.36152649, 16.71486092], [82.36152649, 16.71513939], [82.36207581, 16.71513939], [82.36207581, 16.71541977], [82.36264038, 16.71541786], [82.36264038, 16.71569443], [82.36291504, 16.71569443], [82.36291504, 16.71624947], [82.36319733, 16.71624947], [82.36319733, 16.71652985], [82.36347198, 16.71652794], [82.36347198, 16.71708298], [82.36374664, 16.71708298], [82.36374664, 16.71736145], [82.36430359, 16.71736145], [82.36430359, 16.71763992], [82.36458588, 16.71763039], [82.36458588, 16.7179184], [82.36486053, 16.7179184], [82.36486053, 16.71902847], [82.36458588, 16.71902847], [82.36458588, 16.72070122], [82.36486053, 16.72070122], [82.36486053, 16.72153282], [82.36458588, 16.72153282], [82.36458588, 16.72291946], [82.36430359, 16.72291756], [82.36430359, 16.7234745], [82.36402893, 16.72347069], [82.36402893, 16.7237606], [82.36374664, 16.7237606], [82.36374664, 16.72486115], [82.36347198, 16.72486115], [82.36347198, 16.72542], [82.36319733, 16.72541618], [82.36319733, 16.72569466], [82.36208344, 16.72569466], [82.36208344, 16.72541618], [82.35986328, 16.72541618], [82.35986328, 16.72597313], [82.35958099, 16.72597122], [82.35958099, 16.72624969], [82.35901642, 16.72624969], [82.35901642, 16.72653008], [82.35874939, 16.72652817], [82.35874939, 16.72680664], [82.35819244, 16.72680664], [82.35819244, 16.72708321], [82.35791779, 16.72707939], [82.35791779, 16.72764015], [82.3584671, 16.72764015], [82.3584671, 16.72792053], [82.35901642, 16.72792053], [82.35901642, 16.72820091], [82.35930634, 16.72819519], [82.35930634, 16.72847176], [82.36042023, 16.72847176], [82.36042023, 16.72819519], [82.36068726, 16.72820091], [82.36068726, 16.72764015], [82.36125183, 16.72764015], [82.36125183, 16.72735977], [82.36152649, 16.72736168], [82.36152649, 16.72708321], [82.36458588, 16.72708321], [82.36458588, 16.72624969], [82.36486053, 16.72624969], [82.36486053, 16.72597122], [82.36541748, 16.72597313], [82.36541748, 16.72569466], [82.36597443, 16.72569466], [82.36597443, 16.72513962], [82.36653137, 16.72513962], [82.36653137, 16.72402954], [82.36708069, 16.72402954], [82.36708069, 16.72430992], [82.36763763, 16.72430992], [82.36763763, 16.72402954], [82.36818695, 16.72402954], [82.36818695, 16.72291946], [82.36791992, 16.72291946], [82.36791992, 16.72236252], [82.36763763, 16.72236252], [82.36763763, 16.72180939], [82.36736298, 16.72180939], [82.36736298, 16.72125244], [82.36708069, 16.72125244], [82.36708069, 16.72070122], [82.36736298, 16.72070122], [82.36736298, 16.72042274], [82.36763763, 16.72042274], [82.36763763, 16.71985817], [82.36736298, 16.71986008], [82.36736298, 16.71930504], [82.36708069, 16.71931076], [82.36708069, 16.71846962], [82.36680603, 16.71847153], [82.36680603, 16.71819496], [82.36624908, 16.71820068], [82.36624908, 16.71763039], [82.36597443, 16.71763992], [82.36597443, 16.71708298], [82.36569214, 16.71708298], [82.36569214, 16.71652794], [82.36541748, 16.71652985], [82.36541748, 16.71597099], [82.36513519, 16.7159729], [82.36513519, 16.71541786], [82.36486053, 16.71541977], [82.36486053, 16.71486092], [82.36458588, 16.71486092], [82.36458588, 16.71430969], [82.36429596, 16.71430969], [82.36429596, 16.71403122], [82.36402893, 16.71403122], [82.36402893, 16.71375084], [82.36374664, 16.71375084], [82.36374664, 16.71319008], [82.36347198, 16.7131958], [82.36347198, 16.71291733], [82.36319733, 16.71292114], [82.36319733, 16.71264076], [82.36292267, 16.71264076], [82.36292267, 16.71208], [82.36264038, 16.71208572], [82.36264038, 16.71180534], [82.36235809, 16.7118206], [82.36235809, 16.71153069], [82.36207581, 16.71153069], [82.36207581, 16.71096992], [82.36180878, 16.71097374], [82.36180878, 16.71069527], [82.36152649, 16.71070099], [82.36152649, 16.71042061], [82.36125183, 16.71042061], [82.36125183, 16.71014023], [82.36096954, 16.71014023], [82.36096954, 16.70985985], [82.36069489, 16.70986366], [82.36069489, 16.70958138], [82.36042023, 16.70958138], [82.36042023, 16.70930481], [82.36013794, 16.70930481], [82.36013794, 16.70902824], [82.35986328, 16.70903015], [82.35986328, 16.70846939], [82.35958099, 16.70846939], [82.35958099, 16.70819473], [82.35930634, 16.70819473], [82.35930634, 16.7076416], [82.35901642, 16.7076416], [82.35901642, 16.70735931], [82.35874939, 16.70735931], [82.35874939, 16.7068119], [82.3584671, 16.7068119], [82.3584671, 16.70653152], [82.35819244, 16.70653152], [82.35819244, 16.70597076], [82.35791779, 16.70597267], [82.35791779, 16.7056942], [82.3576355, 16.7056942], [82.3576355, 16.70513725], [82.35679626, 16.70513916], [82.35679626, 16.70430756], [82.35652161, 16.70430756], [82.35652161, 16.70402908], [82.35624695, 16.70402908], [82.35624695, 16.70375061], [82.35597229, 16.70375061], [82.35597229, 16.70347023], [82.35514069, 16.70347214], [82.35514069, 16.70319366], [82.35430908, 16.70319366], [82.35430908, 16.70236206], [82.35402679, 16.70236015], [82.35402679, 16.70153046], [82.35375214, 16.70153046], [82.35375214, 16.70125008], [82.35346222, 16.70125008], [82.35346222, 16.7009697], [82.35319519, 16.7009716], [82.35319519, 16.70069695], [82.3529129, 16.70070076], [82.3529129, 16.70042038], [82.35263824, 16.70042038], [82.35263824, 16.69985962], [82.35236359, 16.69986153], [82.35236359, 16.69958305], [82.3520813, 16.69959068], [82.3520813, 16.6993103], [82.35180664, 16.69930077], [82.35180664, 16.69874954], [82.35151672, 16.69874954], [82.35151672, 16.69847107], [82.35124969, 16.69847488], [82.35124969, 16.6981945], [82.35097504, 16.6981945], [82.35097504, 16.69791603], [82.35069275, 16.69791985], [82.35069275, 16.69763947], [82.35041809, 16.69763947], [82.35041809, 16.6973629], [82.3501358, 16.6973629], [82.3501358, 16.69708061], [82.34986115, 16.69708443], [82.34986115, 16.69680595], [82.34958649, 16.69682121], [82.34958649, 16.69652939], [82.34929657, 16.69652939], [82.34929657, 16.69625282], [82.34902954, 16.69625282], [82.34902954, 16.69597054], [82.34874725, 16.69597054], [82.34874725, 16.6954174], [82.3484726, 16.69542122], [82.3484726, 16.69514275], [82.34819794, 16.69514275], [82.34819794, 16.69458008], [82.34791565, 16.69458389], [82.34791565, 16.69430542], [82.34764099, 16.69431114], [82.34764099, 16.69403267], [82.3473587, 16.69403267], [82.3473587, 16.69375229], [82.34707642, 16.69375229], [82.34707642, 16.69346809], [82.34680939, 16.69347191], [82.34680176, 16.69319534], [82.34625244, 16.69319916], [82.34625244, 16.69292068], [82.34597015, 16.69292068], [82.34597015, 16.6926384], [82.34570313, 16.6926384], [82.34570313, 16.69235992], [82.34541321, 16.69236183], [82.34541321, 16.69208336], [82.34513855, 16.69208336], [82.34513855, 16.69180489], [82.34486389, 16.69180489], [82.34486389, 16.69124985], [82.3445816, 16.69124985], [82.3445816, 16.69069099], [82.34430695, 16.69069481], [82.34430695, 16.69013977], [82.34401703, 16.69013977], [82.34401703, 16.68958092], [82.3429184, 16.68958282], [82.3429184, 16.68930626], [82.34263611, 16.68930817], [82.34263611, 16.68902969], [82.34236145, 16.68902969], [82.34236145, 16.68847084], [82.34208679, 16.68847275], [82.34208679, 16.68819427], [82.3418045, 16.68819427], [82.3418045, 16.68791771], [82.34152222, 16.68791962], [82.34152222, 16.68765068], [82.34124756, 16.68765068], [82.34124756, 16.68736076], [82.3409729, 16.68736076], [82.3409729, 16.68708038], [82.34069824, 16.6870842], [82.34069824, 16.68652725], [82.34041595, 16.68653107], [82.34041595, 16.68625069], [82.3401413, 16.68625069], [82.3401413, 16.68597031], [82.33985901, 16.68597221], [82.33985901, 16.68541718], [82.33930206, 16.68542099], [82.33930206, 16.68486023], [82.3390274, 16.68486023], [82.3390274, 16.68458939], [82.33875275, 16.68458939], [82.33875275, 16.68431091], [82.33847809, 16.68431091], [82.33847809, 16.68403053], [82.3381958, 16.68403053], [82.3381958, 16.68346977], [82.33791351, 16.68347359], [82.33791351, 16.68319511], [82.33763885, 16.68320084], [82.33763885, 16.68264008], [82.33735657, 16.68264008], [82.33735657, 16.6823597], [82.33708191, 16.68236351], [82.33708191, 16.68180466], [82.33680725, 16.68180466], [82.33680725, 16.68152809], [82.33651733, 16.68153191], [82.33651733, 16.68124962], [82.33625031, 16.68124962], [82.33625031, 16.68096924], [82.33569336, 16.68097115], [82.33569336, 16.68069458], [82.3354187, 16.68069458], [82.3354187, 16.68041611], [82.33513641, 16.68042183], [82.33513641, 16.68014145], [82.33486176, 16.68014145], [82.33486176, 16.67985916], [82.33429718, 16.67985916], [82.33429718, 16.67958069], [82.33403015, 16.6795826], [82.33403015, 16.67874718], [82.33374786, 16.67874908], [82.33374786, 16.67846107], [82.33347321, 16.67847252], [82.33347321, 16.67791748], [82.33319092, 16.67791748], [82.33319092, 16.67764091], [82.33291626, 16.67764091], [82.33291626, 16.67736053], [82.3326416, 16.67736053], [82.3326416, 16.67681122], [82.33235168, 16.67681122], [82.33235168, 16.67653084], [82.33207703, 16.67653084], [82.33207703, 16.67625046], [82.33180237, 16.67625046], [82.33180237, 16.6756897], [82.33152771, 16.67569351], [82.33152771, 16.67541695], [82.33125305, 16.67542076], [82.33125305, 16.67514038], [82.33097076, 16.67514038], [82.33097076, 16.67457962], [82.33069611, 16.67458344], [82.33069611, 16.67430687], [82.33040619, 16.67431068], [82.33040619, 16.67374992], [82.33013916, 16.67374992], [82.33013916, 16.67319107], [82.3298645, 16.67319679], [82.3298645, 16.67263794], [82.32958221, 16.67264938], [82.32958221, 16.67208099], [82.32930756, 16.67208481], [82.32930756, 16.67180634], [82.3290329, 16.67181015], [82.3290329, 16.67124939], [82.32875061, 16.67124939], [82.32875061, 16.67069054], [82.32847595, 16.67069435], [82.32847595, 16.67013931], [82.32818604, 16.67014122], [82.32818604, 16.66958046], [82.32791901, 16.66958046], [82.32791901, 16.6693058], [82.32763672, 16.66930962], [82.32763672, 16.66903114], [82.32736206, 16.66903114], [82.32736206, 16.66875267], [82.32680511, 16.66875267], [82.32680511, 16.66791725], [82.32653809, 16.66792107], [82.32653809, 16.66764259], [82.32624817, 16.66764259], [82.32624817, 16.66707993], [82.32597351, 16.66708374], [82.32597351, 16.66653061], [82.32569122, 16.66653061], [82.32569122, 16.66597176], [82.32541656, 16.66597176], [82.32541656, 16.66402626], [82.32514191, 16.66402817], [82.32514191, 16.66345978], [82.32485962, 16.66347313], [82.32485962, 16.66319466], [82.32458496, 16.66319466], [82.32458496, 16.66236115], [82.32430267, 16.66236115], [82.32430267, 16.66180992], [82.32402802, 16.66180992], [82.32402802, 16.66125107], [82.32375336, 16.66125107], [82.32375336, 16.66041946], [82.32319641, 16.66041946], [82.32319641, 16.65958023], [82.32291412, 16.65958595], [82.32291412, 16.6581955], [82.32236481, 16.6581955], [82.32236481, 16.65763855], [82.32208252, 16.65764046], [82.32208252, 16.65736008], [82.32236481, 16.65736389], [82.32236481, 16.65597343], [82.32208252, 16.65597343], [82.32208252, 16.65569496], [82.32180786, 16.65570068], [82.32180786, 16.6554203], [82.3215332, 16.6554203], [82.3215332, 16.65514183], [82.32125092, 16.65514183], [82.32125092, 16.65457916], [82.32096863, 16.65458107], [82.32096863, 16.65402794], [82.32068634, 16.65403175], [82.32068634, 16.65346909], [82.32041931, 16.6534729], [82.32041931, 16.65319443], [82.32069397, 16.65319443], [82.32069397, 16.65263939], [82.31930542, 16.65263939], [82.31930542, 16.65236092], [82.31874847, 16.65236092], [82.31874847, 16.65125084], [82.31846619, 16.65125084], [82.31846619, 16.65097046], [82.31903076, 16.65097237], [82.31903076, 16.65041733], [82.31931305, 16.65042114], [82.31931305, 16.65014076], [82.31958008, 16.65014076], [82.31958008, 16.64958], [82.31930542, 16.64958382], [82.31930542, 16.64791679], [82.31903076, 16.64792061], [82.31903076, 16.64764023], [82.31931305, 16.64764023], [82.31931305, 16.64747047], [82.31930542, 16.64652824], [82.31958008, 16.64653015], [82.31958008, 16.64596939], [82.31930542, 16.6459713], [82.31930542, 16.64486122], [82.31958008, 16.64486122], [82.31958008, 16.64347267], [82.31930542, 16.64347458], [82.31930542, 16.64319229], [82.31903076, 16.64319229], [82.31903076, 16.64291573], [82.31874847, 16.64291954], [82.31874847, 16.64264107], [82.31791687, 16.64264107], [82.31791687, 16.64208031], [82.31819153, 16.64208412], [82.31819153, 16.64180565], [82.31846619, 16.64180946], [82.31846619, 16.64097023], [82.31874847, 16.64097023], [82.31874847, 16.6404171], [82.31846619, 16.64042282], [82.31846619, 16.63874817], [82.31819153, 16.63874817], [82.31819153, 16.63792038], [82.31791687, 16.63792038], [82.31791687, 16.63763809], [82.31819153, 16.63763809], [82.31819153, 16.63735962], [82.31791687, 16.63736153], [82.31791687, 16.63430405], [82.31764221, 16.63430977], [82.31764221, 16.63402939], [82.31791687, 16.63402939], [82.31791687, 16.63292122], [82.31764221, 16.63292122], [82.31764221, 16.63181114], [82.31735229, 16.63181114], [82.31735229, 16.63142967], [82.31735992, 16.62986374], [82.31764221, 16.62986374], [82.31764221, 16.62958145], [82.31791687, 16.62958145], [82.31791687, 16.62930489], [82.31847382, 16.62930489], [82.31847382, 16.62875175], [82.31735229, 16.62875175], [82.31735229, 16.62903023], [82.31708527, 16.62902832], [82.31708527, 16.62958145], [82.31680298, 16.62957954], [82.31680298, 16.6301403], [82.31652832, 16.6301403], [82.31652832, 16.63070107], [82.31624603, 16.63070107], [82.31624603, 16.63125038], [82.31597137, 16.63125038], [82.31597137, 16.6320858], [82.31569672, 16.63208008], [82.31569672, 16.63292122], [82.31541443, 16.6329174], [82.31541443, 16.63329124], [82.31541443, 16.63597298], [82.31513977, 16.63597107], [82.31513977, 16.63624954], [82.31485748, 16.63624954], [82.31485748, 16.63680077], [82.31458282, 16.63680649], [82.31458282, 16.63708305], [82.31417084, 16.63708305], [82.31402588, 16.63708305], [82.31402588, 16.63736153], [82.31346893, 16.63735962], [82.31346893, 16.63763809], [82.31318665, 16.63763809], [82.31318665, 16.63820076], [82.31263733, 16.63819504], [82.31263733, 16.6384716], [82.31236267, 16.6384697], [82.31236267, 16.64180946], [82.31208038, 16.64180946], [82.31208038, 16.64264107], [82.31236267, 16.64263916], [82.31236267, 16.64319229], [82.31263733, 16.64319038], [82.31263733, 16.64375114], [82.31291962, 16.64375114], [82.31291962, 16.64431], [82.31319427, 16.64430618], [82.31319427, 16.64458466], [82.31346893, 16.64458084], [82.31346893, 16.64486122], [82.31375122, 16.64486122], [82.31375122, 16.64542007], [82.31402588, 16.64541626], [82.31402588, 16.6459713], [82.31430817, 16.64596939], [82.31430817, 16.64624977], [82.31458282, 16.64624977], [82.31458282, 16.64764023], [82.31430817, 16.64764023], [82.31430817, 16.64792061], [82.31402588, 16.64792061], [82.31402588, 16.64820099], [82.31375122, 16.64820099], [82.31375122, 16.64847946], [82.31346893, 16.64847946], [82.31346893, 16.64875031], [82.31318665, 16.64875031], [82.31318665, 16.64903069], [82.31291962, 16.64903069], [82.31291962, 16.64931107], [82.31263733, 16.64930534], [82.31263733, 16.64958382], [82.31236267, 16.64958], [82.31236267, 16.64986038], [82.31208038, 16.64986038], [82.31208038, 16.65014076], [82.31180573, 16.65013885], [82.31180573, 16.65069389], [82.31153107, 16.65069389], [82.31153107, 16.65125084], [82.30958557, 16.65125084], [82.30958557, 16.64958382], [82.30986023, 16.64958382], [82.30986023, 16.64652824], [82.31014252, 16.64653015], [82.31014252, 16.64542007], [82.31041718, 16.64542007], [82.31041718, 16.64431], [82.31069183, 16.64431], [82.31069183, 16.64402962], [82.31096649, 16.64402962], [82.31096649, 16.64375114], [82.31124878, 16.64375114], [82.31124878, 16.64264107], [82.31096649, 16.64264107], [82.31096649, 16.64234924], [82.31069183, 16.64236259], [82.31069183, 16.64208412], [82.31041718, 16.64208412], [82.31041718, 16.64097023], [82.31014252, 16.64097023], [82.31014252, 16.63986015], [82.31041718, 16.63986015], [82.31041718, 16.63958359], [82.31069183, 16.63958359], [82.31069183, 16.63930511], [82.31096649, 16.63931084], [82.31096649, 16.6384697], [82.31124878, 16.6384716], [82.31124878, 16.63763809], [82.3115387, 16.63763809], [82.3115387, 16.63735962], [82.31180573, 16.63736153], [82.31180573, 16.63680649], [82.31208038, 16.6368103], [82.31208038, 16.63653755], [82.31236267, 16.63653755], [82.31236267, 16.63624954], [82.31263733, 16.63624954], [82.31263733, 16.63597107], [82.31291962, 16.63597298], [82.31291962, 16.6356945], [82.31319427, 16.6356945], [82.31319427, 16.63541794], [82.31346893, 16.63541985], [82.31346893, 16.63513947], [82.31375122, 16.63513947], [82.31375122, 16.63458061], [82.31402588, 16.63458252], [82.31402588, 16.63402748], [82.31430817, 16.63402939], [82.31430817, 16.63348007], [82.31458282, 16.63348007], [82.31458282, 16.63292122], [82.31485748, 16.63292122], [82.31485748, 16.63208008], [82.31513977, 16.6320858], [82.31513977, 16.63097382], [82.31541443, 16.63097382], [82.31541443, 16.62875175], [82.31569672, 16.62875175], [82.31569672, 16.62818909], [82.31625366, 16.62819481], [82.31625366, 16.62791634], [82.31652832, 16.62792015], [82.31652832, 16.62734985], [82.31680298, 16.62735939], [82.31680298, 16.62708282], [82.31708527, 16.62708282], [82.31708527, 16.62680626], [82.31735229, 16.62681007], [82.31735229, 16.6265316], [82.31764221, 16.6265316], [82.31764221, 16.62597084], [82.31791687, 16.62597275], [82.31791687, 16.62513733], [82.31819153, 16.62513924], [82.31819153, 16.62402916], [82.31791687, 16.62402916], [82.31791687, 16.62347031], [82.31764221, 16.62347221], [82.31764221, 16.62208366], [82.31791687, 16.62208366], [82.31791687, 16.62180519], [82.31874847, 16.62181091], [82.31874847, 16.62125015], [82.31903076, 16.62125015], [82.31903076, 16.62070084], [82.31931305, 16.62070084], [82.31931305, 16.6198597], [82.31903076, 16.6198616], [82.31903076, 16.61819458], [82.31874847, 16.61819458], [82.31874847, 16.61680603], [82.31846619, 16.61680984], [82.31846619, 16.61597061], [82.31819153, 16.61597061], [82.31819153, 16.61541748], [82.31791687, 16.61541748], [82.31791687, 16.61486244], [82.31764221, 16.61486244], [82.31764221, 16.61403275], [82.31735229, 16.61403275], [82.31735229, 16.61292076], [82.3170929, 16.61292076], [82.3170929, 16.61236954], [82.31680298, 16.61236954], [82.31680298, 16.61181068], [82.31652832, 16.61181068], [82.31652832, 16.61124992], [82.31624603, 16.61124992], [82.31624603, 16.61096954], [82.31569672, 16.61097145], [82.31569672, 16.61069489], [82.31541443, 16.61069489], [82.31541443, 16.61041641], [82.31569672, 16.61041832], [82.31569672, 16.60958099], [82.31541443, 16.6095829], [82.31541443, 16.60902786], [82.31513977, 16.60902977], [82.31513977, 16.60819054], [82.31485748, 16.60819435], [82.31485748, 16.60791779], [82.31458282, 16.60791969], [82.31458282, 16.60736084], [82.31430817, 16.60736084], [82.31430817, 16.60708046], [82.31402588, 16.60708237], [82.31402588, 16.6068058], [82.31375122, 16.60680962], [82.31375122, 16.60624123], [82.31346893, 16.60625076], [82.31346893, 16.60541725], [82.31318665, 16.60542107], [82.31318665, 16.60457993], [82.31291962, 16.60458374], [82.31291962, 16.6040287], [82.31263733, 16.60403061], [82.31263733, 16.60346985], [82.31236267, 16.60347366], [82.31236267, 16.60291672], [82.31208038, 16.60292053], [82.31208038, 16.60235977], [82.31069183, 16.60235977], [82.31069183, 16.60264015], [82.31014252, 16.60264015], [82.31014252, 16.60292053], [82.30930328, 16.60292053], [82.30930328, 16.60320091], [82.30874634, 16.60319519], [82.30874634, 16.60347366], [82.30847168, 16.60346985], [82.30847168, 16.60375023], [82.3079071, 16.60375023], [82.3079071, 16.60403061], [82.30764008, 16.60403061], [82.30764008, 16.60431099], [82.30708313, 16.60430527], [82.30708313, 16.60458374], [82.30652618, 16.60457993], [82.30652618, 16.60486031], [82.30625153, 16.60486031], [82.30625153, 16.60514069], [82.30568695, 16.60514069], [82.30568695, 16.60542107], [82.30541992, 16.60541725], [82.30541992, 16.60569572], [82.30486298, 16.60569572], [82.30486298, 16.60597229], [82.30458069, 16.60597229], [82.30458069, 16.60625076], [82.30403137, 16.60624123], [82.30403137, 16.60653114], [82.30374908, 16.60653114], [82.30374908, 16.60680962], [82.3033905, 16.6068058], [82.30319214, 16.6068058], [82.30319214, 16.60708237], [82.30264282, 16.60708046], [82.30264282, 16.60764122], [82.30236816, 16.60764122], [82.30236816, 16.60791969], [82.30208588, 16.60791779], [82.30208588, 16.60819435], [82.30152893, 16.60819435], [82.30152893, 16.60847282], [82.30124664, 16.60847092], [82.30124664, 16.60874939], [82.30097198, 16.60874939], [82.30097198, 16.60931015], [82.30069733, 16.60930634], [82.30069733, 16.60986137], [82.30042267, 16.60985947], [82.30042267, 16.61013985], [82.30014038, 16.61013985], [82.30014038, 16.61041832], [82.29985809, 16.61041641], [82.29985809, 16.61069489], [82.29958344, 16.61069489], [82.29958344, 16.61097145], [82.29930878, 16.61096954], [82.29930878, 16.61124992], [82.29902649, 16.61124992], [82.29902649, 16.6115284], [82.29875183, 16.6115284], [82.29875183, 16.61181068], [82.29846954, 16.61180496], [82.29846954, 16.61208344], [82.29818726, 16.61207962], [82.29818726, 16.61263847], [82.29792023, 16.61263847], [82.29792023, 16.61292076], [82.29736328, 16.61291695], [82.29736328, 16.61347008], [82.29708099, 16.61346817], [82.29708099, 16.61403275], [82.29680634, 16.61402702], [82.29680634, 16.61458206], [82.29651642, 16.61458015], [82.29651642, 16.61514282], [82.29624939, 16.61514091], [82.29624939, 16.61541748], [82.2959671, 16.61541176], [82.2959671, 16.6162529], [82.29569244, 16.6162529], [82.29569244, 16.61652946], [82.29541779, 16.61652946], [82.29541779, 16.61736107], [82.2951355, 16.61736107], [82.2951355, 16.61819458], [82.29458618, 16.61818123], [82.29458618, 16.61874962], [82.29430389, 16.61874962], [82.29430389, 16.61958313], [82.29402924, 16.61958122], [82.29402924, 16.62014008], [82.29374695, 16.62014008], [82.29374695, 16.62042046], [82.29347229, 16.62042046], [82.29347229, 16.62153816], [82.29319763, 16.62152863], [82.29319763, 16.62208366], [82.29292297, 16.62207985], [82.29292297, 16.62264061], [82.29264069, 16.6226387], [82.29264069, 16.62347221], [82.2923584, 16.62347031], [82.2923584, 16.62375069], [82.29207611, 16.62375069], [82.29207611, 16.62430954], [82.29180908, 16.62430954], [82.29180908, 16.62486076], [82.29152679, 16.62486076], [82.29152679, 16.62513924], [82.29125214, 16.62513924], [82.29125214, 16.62624931], [82.29096985, 16.62624931], [82.29096985, 16.62708282], [82.29070282, 16.62708092], [82.29070282, 16.62792015], [82.29013824, 16.62792015], [82.29013824, 16.62903023], [82.28986359, 16.62902832], [82.28986359, 16.62930489], [82.2895813, 16.62930489], [82.2895813, 16.63041687], [82.28930664, 16.63041687], [82.28930664, 16.63097382], [82.28901672, 16.63097], [82.28901672, 16.63181114], [82.28874969, 16.63181114], [82.28874969, 16.63236046], [82.28848267, 16.63236046], [82.28848267, 16.63292122], [82.28791809, 16.6329174], [82.28791809, 16.63319588], [82.2876358, 16.63319016], [82.2876358, 16.63375092], [82.28736877, 16.63375092], [82.28736877, 16.63402939], [82.28708649, 16.63402939], [82.28708649, 16.63430977], [82.28652954, 16.63430977], [82.28652954, 16.63486099], [82.28624725, 16.63486099], [82.28624725, 16.63624954], [82.2859726, 16.63624954], [82.2859726, 16.63680077], [82.28569794, 16.6368103], [82.28569794, 16.63820076], [82.28542328, 16.63820076], [82.28542328, 16.63902855], [82.2848587, 16.63902855], [82.2848587, 16.63931084], [82.28457642, 16.63931084], [82.28457642, 16.64013863], [82.28430176, 16.64013863], [82.28430176, 16.64042282], [82.2840271, 16.64042282], [82.2840271, 16.6415329], [82.28430176, 16.64152718], [82.28430176, 16.64208412], [82.2840271, 16.64208412], [82.2840271, 16.64236259], [82.28375244, 16.64234924], [82.28375244, 16.64264107], [82.28320313, 16.64264107], [82.28320313, 16.64234924], [82.28291321, 16.64234924], [82.28291321, 16.64264107], [82.28235626, 16.64264107], [82.28235626, 16.64234924], [82.27485657, 16.64234924], [82.27485657, 16.64264107], [82.27375031, 16.64264107], [82.27375031, 16.64291954], [82.27319336, 16.64291573], [82.27319336, 16.64319229], [82.2729187, 16.64319229], [82.2729187, 16.64347458], [82.27236176, 16.64347267], [82.27236176, 16.64375114], [82.2701416, 16.64375114], [82.2701416, 16.64402962], [82.26930237, 16.64402962], [82.26930237, 16.64375114], [82.26875305, 16.64375114], [82.26875305, 16.64319038], [82.26763916, 16.64319229], [82.26763916, 16.64347458], [82.26708221, 16.64347267], [82.26708221, 16.64375114], [82.26680756, 16.64375114], [82.26680756, 16.64402962], [82.26625824, 16.64402962], [82.26625824, 16.64431], [82.26569366, 16.64430618], [82.26569366, 16.64458466], [82.26513672, 16.64458084], [82.26513672, 16.64486122], [82.26486206, 16.64486122], [82.26486206, 16.64513969], [82.26431274, 16.64513969], [82.26431274, 16.64542007], [82.26374817, 16.64541626], [82.26374817, 16.64569473], [82.26291656, 16.64569473], [82.26291656, 16.6459713], [82.26264191, 16.6459713], [82.26264191, 16.64569473], [82.26235962, 16.64569473], [82.26235962, 16.6459713], [82.26180267, 16.64596939], [82.26180267, 16.64624977], [82.26125336, 16.64624977], [82.26125336, 16.64653015], [82.26069641, 16.64652824], [82.26069641, 16.64680672], [82.26040649, 16.64680099], [82.26040649, 16.64764023], [82.25985718, 16.64764023], [82.25985718, 16.64792061], [82.25958252, 16.64792061], [82.25958252, 16.64847946], [82.25930786, 16.64847946], [82.25930786, 16.64875031], [82.25875092, 16.64875031], [82.25875092, 16.64931107], [82.25846863, 16.64930534], [82.25846863, 16.64958382], [82.25818634, 16.64958], [82.25818634, 16.65014076], [82.25791931, 16.65014076], [82.25791931, 16.65042114], [82.25763702, 16.65041733], [82.25763702, 16.65097237], [82.25736237, 16.65097046], [82.25736237, 16.65125084], [82.25707245, 16.65125084], [82.25707245, 16.65180969], [82.25680542, 16.65180588], [82.25681305, 16.65236092], [82.25653076, 16.65236092], [82.25653076, 16.65292168], [82.25624847, 16.65292168], [82.25624847, 16.65374947], [82.25596619, 16.65374947], [82.25596619, 16.6554203], [82.25569153, 16.6554203], [82.25569153, 16.65625191], [82.25596619, 16.65625191], [82.25596619, 16.65764046], [82.25624847, 16.65763855], [82.25624847, 16.6581955], [82.25653076, 16.65818977], [82.25653076, 16.65875053], [82.25681305, 16.65875053], [82.25681305, 16.65930939], [82.25708008, 16.65930557], [82.25708008, 16.65958595], [82.25763702, 16.65958023], [82.25763702, 16.65986061], [82.25791931, 16.65986061], [82.25791931, 16.6609726], [82.25818634, 16.66097069], [82.25818634, 16.66125107], [82.25846863, 16.66125107], [82.25846863, 16.66152954], [82.25875092, 16.66152763], [82.25875092, 16.66208267], [82.25902557, 16.66208267], [82.25902557, 16.66236115], [82.25958252, 16.66236115], [82.25958252, 16.66263962], [82.25985718, 16.66263962], [82.25985718, 16.66291809], [82.26013947, 16.66291618], [82.26013947, 16.66347313], [82.26040649, 16.66345978], [82.26040649, 16.66374969], [82.26069641, 16.66374969], [82.26069641, 16.66430473], [82.26097107, 16.66430473], [82.26097107, 16.66458321], [82.26125336, 16.66458321], [82.26125336, 16.66486168], [82.26152802, 16.66485977], [82.26152802, 16.66513824], [82.26180267, 16.66513824], [82.26180267, 16.66542053], [82.26207733, 16.66542053], [82.26207733, 16.66570091], [82.26235962, 16.66569519], [82.26235962, 16.66597176], [82.26291656, 16.66596985], [82.26291656, 16.66624832], [82.26319122, 16.66624832], [82.26319122, 16.66653061], [82.26346588, 16.66651917], [82.26346588, 16.66736031], [82.26374817, 16.66736031], [82.26374817, 16.66792107], [82.26403046, 16.66791725], [82.26403046, 16.66819382], [82.26457977, 16.66819191], [82.26457977, 16.66875267], [82.26486206, 16.66875267], [82.26486206, 16.66903114], [82.26513672, 16.66902733], [82.26513672, 16.67097473], [82.26541901, 16.67097282], [82.26541901, 16.67124939], [82.26568604, 16.67124939], [82.26568604, 16.67152977], [82.26597595, 16.67152977], [82.26597595, 16.67431068], [82.26569366, 16.67430687], [82.26569366, 16.67458344], [82.26541901, 16.67457962], [82.26541901, 16.67514038], [82.26513672, 16.67514038], [82.26513672, 16.67653084], [82.26486206, 16.67652893], [82.26486206, 16.67708397], [82.26457977, 16.67708015], [82.26457977, 16.67736053], [82.26431274, 16.67736053], [82.26431274, 16.67791748], [82.26403046, 16.67791748], [82.26403046, 16.67819405], [82.26430511, 16.67819405], [82.26430511, 16.67847252], [82.26403046, 16.67846107], [82.26403046, 16.67874908], [82.26374817, 16.67874718], [82.26374817, 16.6795826], [82.26346588, 16.67958069], [82.26347351, 16.68014145], [82.26319885, 16.68014145], [82.26319885, 16.68042183], [82.26291656, 16.68042183], [82.26291656, 16.68153191], [82.26264191, 16.68152809], [82.26264191, 16.68236351], [82.26235962, 16.6823597], [82.26235962, 16.68292046], [82.26264191, 16.68292046], [82.26264191, 16.68320084], [82.26235962, 16.68320084], [82.26235962, 16.68458939], [82.26208496, 16.68458366], [82.26208496, 16.68569565], [82.26180267, 16.68568993], [82.26180267, 16.68625069], [82.26152802, 16.68625069], [82.26152802, 16.68653107], [82.26125336, 16.68653107], [82.26125336, 16.68680954], [82.26097107, 16.68680954], [82.26097107, 16.68736076], [82.26069641, 16.68736076], [82.26069641, 16.68791962], [82.26041412, 16.68791771], [82.26041412, 16.68847275], [82.25985718, 16.68847084], [82.25985718, 16.68875122], [82.25958252, 16.68875122], [82.25958252, 16.68930817], [82.25930786, 16.68930626], [82.25930786, 16.68958282], [82.25902557, 16.68958282], [82.25902557, 16.6898613], [82.25875092, 16.6898613], [82.25875092, 16.69011116], [82.26467133, 16.69053078], [82.27633667, 16.69310951], [82.28515625, 16.6974411], [82.28539276, 16.69763947], [82.2876358, 16.69763947], [82.2876358, 16.6973629], [82.2895813, 16.6973629], [82.2895813, 16.69708061], [82.29013824, 16.69708443], [82.29013824, 16.69680595], [82.29096985, 16.69682121], [82.29096985, 16.69652939], [82.29207611, 16.69652939], [82.29207611, 16.69682121], [82.2923584, 16.69680595], [82.2923584, 16.69708443], [82.29264069, 16.69708061], [82.29264069, 16.69763947], [82.29292297, 16.69763947], [82.29292297, 16.69791985], [82.29319763, 16.69791603], [82.29319763, 16.6981945], [82.29458618, 16.6981945], [82.29458618, 16.69847488], [82.2959671, 16.69847107], [82.2959671, 16.69874954], [82.29708099, 16.69874954], [82.29708099, 16.69902992], [82.30374908, 16.69902992], [82.30374908, 16.6993103], [82.30430603, 16.6993103], [82.30430603, 16.69959068], [82.30596924, 16.69958305], [82.30596924, 16.69986153], [82.30652618, 16.69985962], [82.30652618, 16.70014], [82.30680847, 16.70014], [82.30680847, 16.70042038], [82.30735779, 16.70042038], [82.30735779, 16.70070076], [82.30791473, 16.70069695], [82.30791473, 16.7009716], [82.30847168, 16.7009697], [82.30847168, 16.70125008], [82.30902863, 16.70125008], [82.30902863, 16.70153046], [82.3095932, 16.70153046], [82.3095932, 16.70125008], [82.31041718, 16.70125008], [82.31041718, 16.70181084], [82.31069183, 16.70180511], [82.31069183, 16.70208359], [82.31153107, 16.70208359], [82.31153107, 16.70236206], [82.31208038, 16.70236206], [82.31208038, 16.70263863], [82.31236267, 16.702631], [82.31236267, 16.70292091], [82.31319427, 16.7029171], [82.31319427, 16.70347214], [82.31430817, 16.70347023], [82.31430817, 16.70375061], [82.31458282, 16.70375061], [82.31458282, 16.70402908], [82.3154068, 16.70402908], [82.3154068, 16.70430756], [82.31569672, 16.70430565], [82.31569672, 16.70458412], [82.31652832, 16.70458031], [82.31652832, 16.70486069], [82.31680298, 16.70486069], [82.31680298, 16.70513916], [82.3171463, 16.70513916], [82.31735229, 16.70513916], [82.31735229, 16.70541763], [82.31764221, 16.70541763], [82.31764221, 16.70597267], [82.31819153, 16.70597076], [82.31819153, 16.70624924], [82.31846619, 16.70624924], [82.31846619, 16.70653152], [82.31931305, 16.70653152], [82.31931305, 16.7068119], [82.31986237, 16.70680618], [82.31986237, 16.70708275], [82.32013702, 16.70708084], [82.32013702, 16.70735931], [82.32041168, 16.70735931], [82.32041168, 16.7076416], [82.32069397, 16.7076416], [82.32069397, 16.70819473], [82.32125092, 16.70819473], [82.32125092, 16.70846939], [82.3215332, 16.70846939], [82.3215332, 16.70903015], [82.32180786, 16.70902824], [82.32180786, 16.70958138], [82.32235718, 16.70957947], [82.32235718, 16.71014023], [82.32263947, 16.71014023], [82.32263947, 16.71070099], [82.32290649, 16.71070099], [82.32290649, 16.71125031], [82.32319641, 16.71125031], [82.32319641, 16.71153069], [82.32347107, 16.71152687], [82.32347107, 16.71208572], [82.32375336, 16.71208], [82.32375336, 16.71236038], [82.32402802, 16.71236038], [82.32402802, 16.71264076], [82.32430267, 16.71264076], [82.32430267, 16.71292114], [82.32458496, 16.71291733], [82.32458496, 16.71347237], [82.32514191, 16.71347046], [82.32514191, 16.71403122], [82.32569122, 16.71403122], [82.32569122, 16.71430969], [82.32662201, 16.71430779], [82.32763672, 16.71430969], [82.32763672, 16.71403122], [82.32818604, 16.71403122], [82.32818604, 16.71430969], [82.32902527, 16.71430588], [82.32902527, 16.71486092], [82.32930756, 16.71486092], [82.32930756, 16.71513939], [82.32902527, 16.71513939], [82.32902527, 16.71569443], [82.32875061, 16.71569443], [82.32875061, 16.7159729], [82.32818604, 16.71597099], [82.32818604, 16.71624947], [82.32791901, 16.71624947], [82.32791901, 16.71652985], [82.32736206, 16.71652985], [82.32736206, 16.71681023], [82.32653046, 16.71680641], [82.32653046, 16.71736145], [82.32624817, 16.71735954], [82.32624817, 16.7179184], [82.32653046, 16.71791649], [82.32653046, 16.71847153], [82.32624817, 16.71846962], [82.32624817, 16.71874809], [82.32653046, 16.71874809], [82.32653046, 16.71986008], [82.32681274, 16.71985817], [82.32681274, 16.72180939], [82.32707977, 16.72180939], [82.32707977, 16.7226429], [82.32736206, 16.72263908], [82.32736206, 16.7234745], [82.32763672, 16.7234745], [82.32763672, 16.72458458], [82.32791901, 16.72458076], [82.32791901, 16.72486115], [82.32875061, 16.72486115], [82.32875061, 16.72542], [82.32930756, 16.72542], [82.32930756, 16.72513962], [82.32958221, 16.72513962], [82.32958221, 16.72486115], [82.33207703, 16.72486115], [82.33207703, 16.72458076], [82.33180237, 16.72458458], [82.33180237, 16.72430611], [82.33235168, 16.72430992], [82.33235168, 16.7226429], [82.3326416, 16.7226429], [82.3326416, 16.72208023], [82.33291626, 16.72208214], [82.33291626, 16.72125244], [82.33319092, 16.72125244], [82.33319092, 16.72070122], [82.33347321, 16.72070122], [82.33347321, 16.72042274], [82.33374786, 16.72042274], [82.33374786, 16.72013855], [82.33429718, 16.72013855], [82.33429718, 16.71985817], [82.3345871, 16.71986008], [82.3345871, 16.71958351], [82.33625031, 16.71958351], [82.33625031, 16.71986008], [82.33651733, 16.71985817], [82.33651733, 16.72013855], [82.33680725, 16.72013855], [82.33680725, 16.71985817], [82.33763885, 16.71986008], [82.33763885, 16.71958351], [82.3373642, 16.71958351], [82.3373642, 16.71874809], [82.33708191, 16.71874809], [82.33708191, 16.7179184], [82.33680725, 16.7179184], [82.33680725, 16.71708107], [82.33625031, 16.71708298], [82.33625031, 16.71680641], [82.33598328, 16.71681023], [82.33598328, 16.71652985], [82.33569336, 16.71652985], [82.33569336, 16.71624947], [82.33598328, 16.71624947], [82.33597565, 16.7159729], [82.3354187, 16.7159729], [82.3354187, 16.71569443], [82.33597565, 16.71569443], [82.33597565, 16.71541786], [82.33651733, 16.71541977], [82.33651733, 16.71513939], [82.33708191, 16.71513939], [82.33708191, 16.71541977], [82.33735657, 16.71541977], [82.33735657, 16.71513939], [82.33790588, 16.71513939], [82.33790588, 16.71486092], [82.33847809, 16.71486092], [82.33847046, 16.71458244], [82.3390274, 16.71458244], [82.3390274, 16.7140274], [82.33930206, 16.71403122], [82.33930206, 16.71292114], [82.33957672, 16.71292114], [82.33957672, 16.71236038], [82.33985901, 16.71236038], [82.33985901, 16.7118206], [82.3401413, 16.7118206], [82.3401413, 16.71153069], [82.34041595, 16.71153069], [82.34041595, 16.71096992], [82.34069824, 16.71097374], [82.34069824, 16.71041679], [82.3409729, 16.71040154], [82.3409729, 16.71013832], [82.34124756, 16.71014023], [82.34124756, 16.70957947], [82.34152985, 16.70958138], [82.34152985, 16.70902824], [82.34179688, 16.70903015], [82.34179688, 16.70846939], [82.34208679, 16.70846939], [82.34208679, 16.70819473], [82.34319305, 16.70819473], [82.34319305, 16.70791626], [82.34348297, 16.70792007], [82.34348297, 16.7076416], [82.34402466, 16.7076416], [82.34401703, 16.70735931], [82.34430695, 16.70735931], [82.34430695, 16.70597076], [82.3445816, 16.70597267], [82.3445816, 16.70513725], [82.34485626, 16.70513916], [82.34485626, 16.70430756], [82.3445816, 16.70430756], [82.3445816, 16.70375061], [82.34319305, 16.70375061], [82.34319305, 16.70402908], [82.34263611, 16.70402908], [82.34263611, 16.70430756], [82.34208679, 16.70430565], [82.34208679, 16.70458412], [82.3418045, 16.70458412], [82.3418045, 16.70430565], [82.34124756, 16.70430756], [82.34124756, 16.70402908], [82.3409729, 16.70402908], [82.3409729, 16.70375061], [82.34041595, 16.70375061], [82.34041595, 16.70318985], [82.3401413, 16.70319366], [82.3401413, 16.7029171], [82.33985901, 16.70292091], [82.33985901, 16.702631], [82.33958435, 16.70263863], [82.33958435, 16.70236206], [82.33930206, 16.70236015], [82.33930206, 16.70207977], [82.3390274, 16.70208359], [82.3390274, 16.70180511], [82.33875275, 16.70181084], [82.33875275, 16.70153046], [82.3381958, 16.70153046], [82.3381958, 16.70125008], [82.33790588, 16.70125008], [82.33790588, 16.7009697], [82.33763885, 16.7009716], [82.33763885, 16.70069695], [82.33735657, 16.70070076], [82.33735657, 16.70042038], [82.33651733, 16.70042038], [82.33651733, 16.69985962], [82.33625031, 16.69986153], [82.33625031, 16.69930649], [82.33598328, 16.69930077], [82.33597565, 16.69902802], [82.33569336, 16.69902992], [82.33569336, 16.69874954], [82.33513641, 16.69874954], [82.33513641, 16.69819069], [82.33486176, 16.6981945], [82.33486176, 16.69763947], [82.3345871, 16.69763947], [82.3345871, 16.69652939], [82.33429718, 16.69652939], [82.33429718, 16.69542122], [82.3345871, 16.69542122], [82.3345871, 16.69486046], [82.33486176, 16.69486046], [82.33486176, 16.69375229], [82.33513641, 16.69375229], [82.33513641, 16.69319916], [82.3354187, 16.69319916], [82.3354187, 16.6926384], [82.33569336, 16.6926384], [82.33569336, 16.69180107], [82.33597565, 16.69180489], [82.33597565, 16.69152832], [82.33625031, 16.69152832], [82.33625031, 16.69124985], [82.33708191, 16.69124985], [82.33708191, 16.69152832], [82.33763885, 16.69152832], [82.33763885, 16.69180489], [82.33791351, 16.69180489], [82.33791351, 16.69208336], [82.33847046, 16.69208336], [82.33847046, 16.69236183], [82.33875275, 16.69235992], [82.33875275, 16.6926384], [82.3390274, 16.6926384], [82.3390274, 16.69292068], [82.33930206, 16.69292068], [82.33930206, 16.69319916], [82.33985901, 16.69319534], [82.33985901, 16.69347191], [82.3401413, 16.69346809], [82.3401413, 16.69403267], [82.34041595, 16.69403267], [82.34041595, 16.69431114], [82.3409729, 16.69430542], [82.3409729, 16.69458389], [82.34124756, 16.69458008], [82.34124756, 16.69486046], [82.34152222, 16.69486046], [82.34152222, 16.69542122], [82.34208679, 16.6954174], [82.34208679, 16.69569206], [82.34263611, 16.69569016], [82.34263611, 16.69625282], [82.3429184, 16.69625282], [82.3429184, 16.69708443], [82.34319305, 16.69708061], [82.34319305, 16.69763947], [82.34348297, 16.69763947], [82.34348297, 16.69791985], [82.34375, 16.69791603], [82.34375, 16.69847488], [82.34430695, 16.69847107], [82.34430695, 16.69874954], [82.34513855, 16.69874954], [82.34513855, 16.69902992], [82.34541321, 16.69902992], [82.34541321, 16.6993103], [82.34597015, 16.6993103], [82.34597015, 16.69959068], [82.34625244, 16.69958305], [82.34625244, 16.69986153], [82.3465271, 16.69985962], [82.3465271, 16.70014], [82.34680176, 16.70014], [82.34680176, 16.70042038], [82.34707642, 16.70042038], [82.34707642, 16.70070076], [82.34764099, 16.70069695], [82.34764099, 16.7009716], [82.34819794, 16.7009697], [82.34819794, 16.70125008], [82.3484726, 16.70125008], [82.3484726, 16.70181084], [82.34874725, 16.70181084], [82.34874725, 16.70292091], [82.34902954, 16.7029171], [82.34902954, 16.70347214], [82.34929657, 16.70347023], [82.34929657, 16.70402908], [82.34958649, 16.70402908], [82.34958649, 16.70430756], [82.35041809, 16.70430565], [82.35041809, 16.70458412], [82.35097504, 16.70458412], [82.35097504, 16.70486069], [82.35124969, 16.70486069], [82.35124969, 16.70513916], [82.35151672, 16.70513916], [82.35151672, 16.70541763], [82.3520813, 16.70541763], [82.3520813, 16.7056942], [82.35236359, 16.7056942], [82.35236359, 16.70597267], [82.35263824, 16.70597076], [82.35263824, 16.7068119], [82.3529129, 16.7068119], [82.3529129, 16.70735931], [82.35263824, 16.70735931], [82.35263824, 16.70846939], [82.3529129, 16.70846939], [82.3529129, 16.70986366], [82.35235596, 16.70985985], [82.35235596, 16.71014023], [82.35069275, 16.71014023], [82.35069275, 16.70985985], [82.34792328, 16.70985985], [82.34792328, 16.71042061], [82.34764099, 16.71041679], [82.34764099, 16.71097374], [82.34791565, 16.71097374], [82.34792328, 16.71236038], [82.34707642, 16.71236038], [82.34707642, 16.71208], [82.34625244, 16.71208572], [82.34625244, 16.71180534], [82.34597015, 16.71180534], [82.34597015, 16.71208572], [82.3445816, 16.71208572], [82.3445816, 16.71180534], [82.34430695, 16.7118206], [82.34430695, 16.71153069], [82.34401703, 16.71153069], [82.34401703, 16.71125031], [82.34347534, 16.71125031], [82.34347534, 16.71069527], [82.34319305, 16.71070099], [82.34319305, 16.71042061], [82.3429184, 16.71042061], [82.3429184, 16.71070099], [82.34263611, 16.71069527], [82.34263611, 16.71097374], [82.34236145, 16.71096992], [82.34236145, 16.7118206], [82.34208679, 16.7118206], [82.34208679, 16.71236038], [82.3418045, 16.71236038], [82.3418045, 16.7131958], [82.34159088, 16.71319008], [82.34152222, 16.71403122], [82.34124756, 16.7140274], [82.34124756, 16.71458244], [82.3409729, 16.714571], [82.3409729, 16.71513939], [82.34069824, 16.71513939], [82.34069061, 16.71569443], [82.3401413, 16.71569443], [82.3401413, 16.7159729], [82.34041595, 16.71597099], [82.34041595, 16.71624947], [82.3401413, 16.71624947], [82.3401413, 16.71708298], [82.33958435, 16.71708298], [82.33958435, 16.71736145], [82.33985901, 16.71735954], [82.33985901, 16.71820068], [82.34041595, 16.71819496], [82.34041595, 16.71847153], [82.34069824, 16.71847153], [82.34069824, 16.71819496], [82.3412323, 16.7181797], [82.34124756, 16.71791649], [82.34179688, 16.7179184], [82.34179688, 16.71763039], [82.34347534, 16.71763992], [82.34347534, 16.71736145], [82.34402466, 16.71736145], [82.34402466, 16.71708298], [82.34597015, 16.71708298], [82.34597015, 16.71652794], [82.34680176, 16.71652985], [82.34680939, 16.71597099], [82.3473587, 16.7159729], [82.3473587, 16.71569443], [82.3484726, 16.71569443], [82.3484726, 16.71541786], [82.34902954, 16.71541977], [82.34902954, 16.71513939], [82.35180664, 16.71513939], [82.35180664, 16.71541977], [82.3520813, 16.71541786], [82.3520813, 16.71569443], [82.35236359, 16.71569443], [82.35236359, 16.71513939], [82.35263824, 16.71513939], [82.35263824, 16.714571], [82.35346985, 16.71458244], [82.35346985, 16.71430588], [82.35430908, 16.71430969], [82.35430908, 16.71403122]]], [[[82.26235962, 16.67791748], [82.26235962, 16.67764091], [82.26264191, 16.67764091], [82.26264191, 16.67736053], [82.26291656, 16.67736053], [82.26291656, 16.67542076], [82.26319885, 16.67542076], [82.26319885, 16.67486], [82.26347351, 16.67486191], [82.26347351, 16.67458344], [82.26319122, 16.67458344], [82.26319122, 16.67430687], [82.26346588, 16.67431068], [82.26346588, 16.67346954], [82.26319122, 16.67347145], [82.26319122, 16.67180634], [82.26291656, 16.67181015], [82.26291656, 16.66986275], [82.26264191, 16.66986275], [82.26264191, 16.66958046], [82.26235962, 16.66958046], [82.26235962, 16.66986275], [82.26207733, 16.66986275], [82.26207733, 16.67014122], [82.26180267, 16.67013931], [82.26180267, 16.67069435], [82.26152802, 16.67069054], [82.26152802, 16.67264938], [82.26125336, 16.67263794], [82.26125336, 16.67347145], [82.26097107, 16.67347145], [82.26097107, 16.67597198], [82.26069641, 16.67597008], [82.26069641, 16.67625046], [82.26097107, 16.67625046], [82.26097107, 16.67736053], [82.26125336, 16.67736053], [82.26125336, 16.67764091], [82.26152802, 16.67764091], [82.26152802, 16.67791748], [82.26235962, 16.67791748]]], [[[82.31485748, 16.72597313], [82.31485748, 16.72486115], [82.31458282, 16.72486115], [82.31458282, 16.72347069], [82.31430817, 16.7234745], [82.31430817, 16.72263908], [82.31402588, 16.7226429], [82.31402588, 16.7195797], [82.31375122, 16.71958351], [82.31375122, 16.71986008], [82.31346893, 16.71986008], [82.31346893, 16.71958351], [82.31236267, 16.71958351], [82.31236267, 16.71930504], [82.31181335, 16.71931076], [82.31181335, 16.71902847], [82.31124878, 16.71902847], [82.31124878, 16.71874809], [82.30986023, 16.71874809], [82.30986023, 16.71902847], [82.3095932, 16.71902847], [82.3095932, 16.71931076], [82.30930328, 16.71930504], [82.30930328, 16.71958351], [82.30902863, 16.71958351], [82.30902863, 16.71986008], [82.30930328, 16.71985817], [82.30930328, 16.72042274], [82.3095932, 16.72042274], [82.3095932, 16.72070122], [82.30986023, 16.72070122], [82.30986023, 16.72125244], [82.31014252, 16.72125244], [82.31014252, 16.72153282], [82.31041718, 16.72153282], [82.31041718, 16.72180939], [82.31069183, 16.72180557], [82.31069183, 16.72208214], [82.31096649, 16.72208023], [82.31096649, 16.7226429], [82.31124878, 16.7226429], [82.31124878, 16.72291946], [82.31153107, 16.72291756], [82.31153107, 16.72319221], [82.31181335, 16.72319031], [82.31181335, 16.7237606], [82.31208038, 16.7237606], [82.31208038, 16.72402954], [82.31236267, 16.72402954], [82.31236267, 16.72430992], [82.31263733, 16.72430611], [82.31263733, 16.72458458], [82.31291962, 16.72458076], [82.31291962, 16.72486115], [82.31318665, 16.72486115], [82.31318665, 16.72513962], [82.31346893, 16.72513962], [82.31346893, 16.72542], [82.31375122, 16.72541618], [82.31375122, 16.72569466], [82.31402588, 16.72569466], [82.31402588, 16.72597313], [82.31485748, 16.72597313]]], [[[82.3079071, 16.71652985], [82.3079071, 16.71624947], [82.30819702, 16.71624947], [82.30819702, 16.71597099], [82.30902863, 16.7159729], [82.30902863, 16.71430588], [82.30819702, 16.71430969], [82.30819702, 16.71403122], [82.3079071, 16.71403122], [82.3079071, 16.71375084], [82.30764008, 16.71375084], [82.30764008, 16.71347046], [82.30735779, 16.71347237], [82.30735779, 16.7131958], [82.30708313, 16.7131958], [82.30708313, 16.71291733], [82.30596924, 16.71292114], [82.30596924, 16.71264076], [82.30486298, 16.71264076], [82.30486298, 16.71236038], [82.30374908, 16.71236038], [82.30374908, 16.71208], [82.30319214, 16.71208572], [82.30319214, 16.71180534], [82.30236816, 16.7118206], [82.30236816, 16.71153069], [82.30179596, 16.71153069], [82.30179596, 16.71125031], [82.30152893, 16.71125031], [82.30152893, 16.71096992], [82.30041504, 16.71097374], [82.30042267, 16.71125031], [82.30014038, 16.71125031], [82.30014038, 16.71236038], [82.30042267, 16.71236038], [82.30042267, 16.71264076], [82.30014038, 16.71264076], [82.30014038, 16.71292114], [82.30069733, 16.71291733], [82.30069733, 16.7131958], [82.30097198, 16.7131958], [82.30097198, 16.71347237], [82.30124664, 16.71347046], [82.30124664, 16.71375084], [82.30152893, 16.71375084], [82.30152893, 16.71403122], [82.30208588, 16.71403122], [82.30208588, 16.71430969], [82.30291748, 16.71430588], [82.30291748, 16.71458244], [82.30319214, 16.714571], [82.30319214, 16.71486092], [82.30374908, 16.71486092], [82.30374908, 16.71513939], [82.30430603, 16.71513939], [82.30430603, 16.71541977], [82.30458069, 16.71541786], [82.30458069, 16.71569443], [82.30486298, 16.71569443], [82.30486298, 16.7159729], [82.30513763, 16.71597099], [82.30513763, 16.71624947], [82.30708313, 16.71624947], [82.30708313, 16.71652985], [82.3079071, 16.71652985]]], [[[82.29951477, 16.71433258], [82.29957581, 16.71403122], [82.29938507, 16.71402931], [82.29943848, 16.71412849], [82.29951477, 16.71433258]]], [[[78.46292877, 12.63537025], [78.4618988, 12.6322794], [78.45907593, 12.63152027], [78.46008301, 12.62045956], [78.45961761, 12.61740971], [78.45478058, 12.61201954], [78.45140076, 12.61575127], [78.44744873, 12.61650085], [78.43943787, 12.61692047], [78.42489624, 12.61490059], [78.41834259, 12.62064171], [78.41233063, 12.61831093], [78.40711212, 12.61752033], [78.39980316, 12.6133194], [78.39955902, 12.61335087], [78.3975296, 12.61359024], [78.38613892, 12.61387062], [78.37420654, 12.61309147], [78.36833954, 12.61184025], [78.36054993, 12.61511135], [78.34835815, 12.62364101], [78.33883667, 12.63190079], [78.32939911, 12.6384306], [78.32235718, 12.63720036], [78.30876923, 12.64999962], [78.29496765, 12.65424061], [78.29045868, 12.65292072], [78.28885651, 12.6565609], [78.28700256, 12.65814972], [78.28418732, 12.66761971], [78.26722717, 12.68743038], [78.26442719, 12.69184017], [78.23906708, 12.69239235], [78.23265839, 12.69376087], [78.22744751, 12.68928146], [78.22664642, 12.68014145], [78.22808075, 12.67385101], [78.21398926, 12.67475128], [78.20011139, 12.67564201], [78.19683838, 12.67859077], [78.1953125, 12.67996979], [78.18984985, 12.6813097], [78.18946075, 12.68355083], [78.19877625, 12.68871117], [78.19934082, 12.68997955], [78.19473267, 12.69526958], [78.19608307, 12.69668961], [78.19999695, 12.69622135], [78.20324707, 12.6990099], [78.20980835, 12.69926071], [78.21382141, 12.70236015], [78.22032928, 12.70328999], [78.22722626, 12.71517181], [78.22886658, 12.72020245], [78.21927643, 12.7470293], [78.2199173, 12.74962139], [78.22064972, 12.75259018], [78.22512054, 12.75493145], [78.22949982, 12.76200962], [78.23542786, 12.78757954], [78.24021912, 12.80314159], [78.24186707, 12.8123312], [78.2410965, 12.84742069], [78.24465942, 12.85110092], [78.24874878, 12.8498497], [78.25382233, 12.8495903], [78.25814819, 12.85562992], [78.26262665, 12.85659027], [78.27056885, 12.8505497], [78.27568817, 12.84916019], [78.30310059, 12.84720039], [78.30622101, 12.85647106], [78.30409241, 12.8657608], [78.31105042, 12.86537075], [78.32158661, 12.86285019], [78.32271576, 12.86785126], [78.32749176, 12.8740406], [78.32271576, 12.87619019], [78.32141876, 12.87165928], [78.31617737, 12.87220192], [78.31093597, 12.8738308], [78.30996704, 12.87648201], [78.31328583, 12.87977123], [78.31240845, 12.88330078], [78.31347656, 12.88862133], [78.31645966, 12.89261055], [78.32216644, 12.88960075], [78.32718658, 12.88923073], [78.33833313, 12.90649986], [78.33773041, 12.91312122], [78.33827209, 12.91575146], [78.34398651, 12.91809177], [78.34041595, 12.92198944], [78.34076691, 12.92492008], [78.34542847, 12.92806053], [78.36097717, 12.91161919], [78.36868286, 12.90178013], [78.37834167, 12.89519119], [78.38337708, 12.89540958], [78.38508606, 12.89625072], [78.38839722, 12.90552044], [78.39953613, 12.89620113], [78.40291595, 12.89132118], [78.41152954, 12.89089966], [78.41734314, 12.88903141], [78.42465973, 12.89341068], [78.42489624, 12.89817047], [78.42640686, 12.90206146], [78.43582916, 12.90067005], [78.43570709, 12.88885975], [78.43830109, 12.88624096], [78.43849182, 12.87974072], [78.44644165, 12.87473202], [78.45266724, 12.86549187], [78.45211792, 12.85572147], [78.45423889, 12.85316181], [78.45694733, 12.8660593], [78.45833588, 12.87972069], [78.45613098, 12.89275265], [78.4490509, 12.8966589], [78.44290161, 12.90411186], [78.4412384, 12.90563202], [78.43447113, 12.90827084], [78.4259491, 12.91713047], [78.4213562, 12.92352962], [78.42035675, 12.92895889], [78.42328644, 12.93379974], [78.42459106, 12.93820953], [78.41977692, 12.94668198], [78.420578, 12.94764996], [78.42735291, 12.95053101], [78.42384338, 12.95440102], [78.42282104, 12.95773125], [78.42191315, 12.96274853], [78.4226532, 12.96860027], [78.42565155, 12.96977139], [78.43358612, 12.96877956], [78.457901, 12.96324158], [78.45759583, 12.97066021], [78.45939636, 12.97575188], [78.46142578, 12.97912025], [78.45542145, 12.99009037], [78.45231628, 13.00376034], [78.45263672, 13.00858116], [78.45036316, 13.01487064], [78.44991302, 13.0258112], [78.4506073, 13.0282402], [78.45157623, 13.03153229], [78.45500946, 13.03259087], [78.46105194, 13.03201008], [78.46472168, 13.03489971], [78.46704865, 13.04137135], [78.47107697, 13.04385853], [78.47738647, 13.04322147], [78.48108673, 13.04438972], [78.48750305, 13.04939079], [78.48792267, 13.04972076], [78.50457764, 13.05276203], [78.50479889, 13.05937958], [78.4985733, 13.06979084], [78.49958038, 13.07582188], [78.50192261, 13.08166122], [78.50681305, 13.08419132], [78.5138092, 13.08468056], [78.51480865, 13.09111023], [78.52796173, 13.09735966], [78.52237701, 13.09966183], [78.5161972, 13.10081959], [78.51113892, 13.10632992], [78.50869751, 13.11326981], [78.50875092, 13.11958981], [78.51291656, 13.12023067], [78.52143097, 13.12905121], [78.53544617, 13.13074017], [78.53669739, 13.13693047], [78.53269958, 13.14209175], [78.53369904, 13.14610958], [78.53878021, 13.15157127], [78.54685974, 13.15343094], [78.55805969, 13.15234184], [78.56125641, 13.15570068], [78.56536865, 13.15681076], [78.56907654, 13.1564827], [78.56568146, 13.17175102], [78.56472778, 13.17404079], [78.56333923, 13.17740059], [78.55940247, 13.17980099], [78.55647278, 13.179842], [78.55349731, 13.17987061], [78.54688263, 13.17862034], [78.54247284, 13.18017006], [78.54094696, 13.18725109], [78.5532608, 13.18924141], [78.5583725, 13.19218063], [78.56012726, 13.19820023], [78.56588745, 13.20088959], [78.56867981, 13.20426273], [78.56433105, 13.20805073], [78.55719757, 13.21202087], [78.55887604, 13.22713089], [78.5594101, 13.23038197], [78.55989075, 13.23337173], [78.56321716, 13.23841095], [78.56854248, 13.24353027], [78.57215118, 13.24860096], [78.57746887, 13.26204967], [78.57611084, 13.2671299], [78.56716919, 13.27177143], [78.56443787, 13.28341007], [78.56156158, 13.28803921], [78.56009674, 13.29334927], [78.55565643, 13.29942989], [78.55413818, 13.2983017], [78.55323029, 13.28462029], [78.55060577, 13.27602959], [78.54717255, 13.27267075], [78.54361725, 13.27323246], [78.53557587, 13.27608013], [78.53327179, 13.27600098], [78.52876282, 13.27586174], [78.52561951, 13.26929092], [78.52377319, 13.26062107], [78.52229309, 13.25811195], [78.52079773, 13.25559139], [78.51550293, 13.2571497], [78.51197052, 13.25995064], [78.5083313, 13.26947117], [78.50392914, 13.27245045], [78.50115967, 13.27721119], [78.49521637, 13.279212], [78.48352814, 13.28808022], [78.47255707, 13.29113197], [78.4701767, 13.29390144], [78.47174835, 13.30792046], [78.46640015, 13.31012154], [78.46053314, 13.30792046], [78.45417786, 13.30414963], [78.44790649, 13.30281925], [78.44507599, 13.30139923], [78.44130707, 13.29950142], [78.43785858, 13.29876041], [78.43598175, 13.29835033], [78.43031311, 13.3078289], [78.42906952, 13.31711197], [78.42682648, 13.31807995], [78.42446899, 13.31910133], [78.42077637, 13.3190918], [78.41526031, 13.31713009], [78.40706635, 13.31009197], [78.40206146, 13.30737972], [78.39125061, 13.30370998], [78.38291168, 13.3140707], [78.37914276, 13.31687927], [78.37512207, 13.31859112], [78.36699677, 13.32003975], [78.36791229, 13.3284893], [78.37129211, 13.33240891], [78.37754059, 13.33131981], [78.3753891, 13.32640171], [78.37899017, 13.32452106], [78.38456726, 13.32354069], [78.38838959, 13.31845188], [78.39125061, 13.32371044], [78.39523315, 13.32256985], [78.39737701, 13.33233166], [78.39253235, 13.33554077], [78.38491058, 13.33820057], [78.38366699, 13.34235096], [78.37477112, 13.3464098], [78.36818695, 13.34831142], [78.3640213, 13.34830189], [78.36051178, 13.34696198], [78.35839844, 13.34684086], [78.35640717, 13.34671974], [78.35515594, 13.35507107], [78.3598175, 13.36432171], [78.36444855, 13.37049103], [78.36871338, 13.37981129], [78.37127686, 13.39100075], [78.37127686, 13.3971796], [78.36946106, 13.40894985], [78.3673172, 13.41500092], [78.36531067, 13.42439079], [78.36702728, 13.4312706], [78.36463165, 13.43685055], [78.36416626, 13.43791103], [78.36419678, 13.44561195], [78.36255646, 13.45207119], [78.3635788, 13.45924091], [78.36728668, 13.46685123], [78.3674469, 13.48197079], [78.36828613, 13.48976994], [78.36728668, 13.49517155], [78.36958313, 13.49993038], [78.37419128, 13.50551033], [78.37309265, 13.5122509], [78.38546753, 13.53166962], [78.38600922, 13.54395199], [78.39775848, 13.56619167], [78.39389801, 13.57065201], [78.39076233, 13.5781002], [78.38031769, 13.58130932], [78.36709595, 13.58030033], [78.36139679, 13.57887268], [78.34366608, 13.57778072], [78.3228302, 13.58299065], [78.31247711, 13.58350182], [78.2918396, 13.57882023], [78.28058624, 13.577672], [78.26539612, 13.57822132], [78.25827026, 13.57530975], [78.24967957, 13.57430077], [78.23655701, 13.58449078], [78.22769165, 13.58722115], [78.22261047, 13.57709026], [78.21840668, 13.57800198], [78.21479034, 13.58010101], [78.20849609, 13.58188057], [78.20240021, 13.56796932], [78.19583893, 13.56068134], [78.18900299, 13.55638027], [78.18327332, 13.55638027], [78.18161011, 13.5591507], [78.18012238, 13.56417179], [78.18105316, 13.5737009], [78.17946625, 13.57894135], [78.18856812, 13.58840179], [78.19374084, 13.59490204], [78.19536591, 13.6015501], [78.19393921, 13.61615944], [78.18583679, 13.62117958], [78.16555786, 13.62097073], [78.16053772, 13.62343025], [78.15899658, 13.64517117], [78.15576172, 13.64871025], [78.14617157, 13.64966011], [78.12908936, 13.64826965], [78.12322998, 13.64890099], [78.1158905, 13.64563084], [78.10736084, 13.64709187], [78.09390259, 13.6402607], [78.09060669, 13.63300037], [78.08634949, 13.63350105], [78.08072662, 13.63534069], [78.07965851, 13.64454174], [78.07998657, 13.65038967], [78.07280731, 13.65517139], [78.06585693, 13.6644907], [78.05834198, 13.66697025], [78.06092072, 13.6717701], [78.06408691, 13.67455959], [78.06537628, 13.68006039], [78.06260681, 13.68560028], [78.0640564, 13.68817997], [78.08515167, 13.68063164], [78.09986877, 13.68256187], [78.1053772, 13.68440056], [78.10721588, 13.69835186], [78.10988617, 13.70395184], [78.10938263, 13.71023083], [78.1055069, 13.71463203], [78.10044098, 13.71801186], [78.09738922, 13.72315121], [78.09327698, 13.72762108], [78.08492279, 13.7334919], [78.08927155, 13.74304962], [78.09532166, 13.75028038], [78.10119629, 13.75298977], [78.10649872, 13.75679111], [78.11100769, 13.76175117], [78.11823273, 13.77690029], [78.11517334, 13.78767967], [78.10900116, 13.79836273], [78.10765839, 13.80360031], [78.11725616, 13.82177162], [78.11353302, 13.84089088], [78.10604095, 13.85354137], [78.09736633, 13.85276127], [78.08837891, 13.85491943], [78.07491302, 13.85491943], [78.07092285, 13.87195969], [78.06796265, 13.8745203], [78.06034851, 13.87678146], [78.05471039, 13.87935162], [78.04831696, 13.88453007], [78.04115295, 13.88672924], [78.04270172, 13.87337971], [78.04292297, 13.86378098], [78.04133606, 13.8580513], [78.03782654, 13.85284996], [78.01558685, 13.85438156], [78.01033783, 13.85649014], [78.004776, 13.86171055], [77.99149323, 13.86241055], [77.98516083, 13.86166954], [77.98226929, 13.85680199], [77.98123932, 13.84879971], [77.97038269, 13.82664204], [77.96578217, 13.82015991], [77.94458008, 13.81997108], [77.94814301, 13.82480145], [77.94805145, 13.82936096], [77.94571686, 13.83980179], [77.94184113, 13.87105083], [77.94246674, 13.8802309], [77.9495163, 13.88447094], [77.97161865, 13.88858891], [77.97802734, 13.89334965], [77.97466278, 13.90533161], [77.97460175, 13.91225147], [77.97336578, 13.91988182], [77.97351074, 13.92422962], [77.97795105, 13.93762016], [77.97857666, 13.94765091], [77.96643066, 13.95055199], [77.96127319, 13.9499712], [77.95532227, 13.94190025], [77.95426941, 13.93704987], [77.95075989, 13.92792034], [77.9490509, 13.92673969], [77.94602203, 13.92843056], [77.93885803, 13.92461967], [77.93564606, 13.91790962], [77.92973328, 13.90880966], [77.91980743, 13.89870167], [77.91160583, 13.89724064], [77.90593719, 13.89945126], [77.90045166, 13.90234089], [77.89570618, 13.90771961], [77.88968658, 13.9113512], [77.88732147, 13.91774082], [77.88786316, 13.92772198], [77.88698578, 13.93118191], [77.86242676, 13.92680073], [77.85407257, 13.9270792], [77.84600067, 13.92832088], [77.83011627, 13.92715168], [77.82158661, 13.93054104], [77.81829071, 13.93488121], [77.81423187, 13.93100166], [77.80848694, 13.9225893], [77.80635071, 13.91755009], [77.80635834, 13.90864086], [77.80737305, 13.90322971], [77.81108093, 13.89470196], [77.81468964, 13.89111042], [77.82099152, 13.88923168], [77.82504272, 13.87990093], [77.82724762, 13.87160015], [77.81920624, 13.86602116], [77.82772064, 13.86061954], [77.81080627, 13.85211182], [77.80784607, 13.8466711], [77.80278015, 13.84066963], [77.79453278, 13.84095955], [77.78637695, 13.83992004], [77.77603912, 13.8359108], [77.77410126, 13.83173084], [77.77742767, 13.82406044], [77.78026581, 13.82002068], [77.78044128, 13.8166914], [77.77848816, 13.81289196], [77.76921082, 13.8085413], [77.75533295, 13.80754089], [77.74817657, 13.80620956], [77.74102783, 13.803792], [77.7335968, 13.80344105], [77.72841644, 13.80173969], [77.71849823, 13.79272175], [77.71286011, 13.79051971], [77.71512604, 13.78327179], [77.7127533, 13.7747097], [77.71420288, 13.76079082], [77.7131424, 13.75074005], [77.71346283, 13.74615002], [77.71100616, 13.73771], [77.70874786, 13.73273945], [77.70736694, 13.73418045], [77.70218658, 13.73099136], [77.69552612, 13.76143169], [77.68467712, 13.75862122], [77.67881775, 13.75568104], [77.66850281, 13.75228119], [77.66371155, 13.75226021], [77.66979218, 13.76255989], [77.67176819, 13.77013111], [77.67022705, 13.7774992], [77.66401672, 13.77587032], [77.65659332, 13.77666092], [77.649086, 13.77583981], [77.61434937, 13.76031017], [77.610466, 13.75543976], [77.61264801, 13.74687004], [77.63375092, 13.74129105], [77.63674927, 13.73524189], [77.63356018, 13.73283958], [77.62851715, 13.72994137], [77.62124634, 13.72740173], [77.61564636, 13.72836113], [77.60427094, 13.74255085], [77.59559631, 13.74357891], [77.5868988, 13.7367897], [77.58154297, 13.73057175], [77.57363129, 13.72665024], [77.56661987, 13.72938919], [77.55607605, 13.71646023], [77.54814148, 13.72040939], [77.54514313, 13.72818089], [77.54155731, 13.73493195], [77.53951263, 13.74372005], [77.52950287, 13.74585056], [77.51966858, 13.74384975], [77.51512146, 13.73703957], [77.52268982, 13.73107147], [77.52659607, 13.72525024], [77.52754211, 13.71903038], [77.52783966, 13.70703125], [77.5255661, 13.69721031], [77.52152252, 13.68787003], [77.5123291, 13.68568039], [77.50797272, 13.68879986], [77.50691986, 13.69266129], [77.50679016, 13.70047092], [77.50276947, 13.7044096], [77.48734283, 13.70679188], [77.47972107, 13.70321083], [77.48239899, 13.6988306], [77.48352051, 13.69170094], [77.48513794, 13.68669033], [77.48294067, 13.67970181], [77.47648621, 13.67759991], [77.44975281, 13.67579079], [77.44481659, 13.69576073], [77.44600677, 13.70063972], [77.45340729, 13.70409966], [77.45684814, 13.71263981], [77.45806885, 13.72303867], [77.45809937, 13.73033047], [77.46006012, 13.73388958], [77.46261597, 13.74357891], [77.46212006, 13.74905109], [77.4587326, 13.74981022], [77.4539566, 13.77804184], [77.45240021, 13.78040123], [77.45079041, 13.78553104], [77.4527359, 13.79131985], [77.45745087, 13.79705048], [77.45559692, 13.79981041], [77.44676971, 13.80202961], [77.44056702, 13.80229187], [77.43546295, 13.79923058], [77.42865753, 13.78798962], [77.4200592, 13.78896141], [77.41689301, 13.79094028], [77.41954041, 13.79580116], [77.41925812, 13.79971027], [77.41470337, 13.80019093], [77.41158295, 13.79889107], [77.40866089, 13.79925156], [77.40820313, 13.80247021], [77.41368103, 13.80738068], [77.41275787, 13.81175041], [77.41506195, 13.81536007], [77.42472076, 13.82668972], [77.42624664, 13.82973003], [77.42453003, 13.83512974], [77.41873932, 13.83353043], [77.40393066, 13.83142185], [77.39920044, 13.83242035], [77.38983917, 13.83292961], [77.38111115, 13.83125114], [77.37285614, 13.83128929], [77.3731308, 13.83819103], [77.36753845, 13.84320927], [77.35946655, 13.8456707], [77.35220337, 13.84438133], [77.34697723, 13.83958054], [77.3398819, 13.83484936], [77.33468628, 13.82942009], [77.32724762, 13.82479191], [77.32000732, 13.8257513], [77.31616211, 13.83973122], [77.31088257, 13.85113144], [77.30693054, 13.85723972], [77.29602814, 13.8535614], [77.28970337, 13.85002232], [77.28552246, 13.84603119], [77.28292847, 13.84097958], [77.27514648, 13.84280109], [77.25595093, 13.83945084], [77.2504425, 13.83947086], [77.2530365, 13.85612106], [77.24373627, 13.86029053], [77.24073792, 13.86588192], [77.23925018, 13.87359047], [77.23882294, 13.88150978], [77.24156189, 13.88885117], [77.24009705, 13.89408016], [77.23384094, 13.89493179], [77.22547913, 13.89546967], [77.22189331, 13.88883114], [77.22093201, 13.8817606], [77.21700287, 13.86926174], [77.2115097, 13.86141872], [77.20812225, 13.86040115], [77.20884705, 13.87843132], [77.2049408, 13.88116074], [77.20256805, 13.87484074], [77.20095825, 13.86651993], [77.19689178, 13.85953045], [77.19271088, 13.8562212], [77.17880249, 13.85984039], [77.17513275, 13.8614006], [77.17822266, 13.8713913], [77.17959595, 13.87833118], [77.17920685, 13.88328075], [77.18134308, 13.89118958], [77.18221283, 13.90130043], [77.18161774, 13.91077042], [77.17703247, 13.91740036], [77.17006683, 13.91634178], [77.15956116, 13.90846062], [77.15593719, 13.89981174], [77.15702057, 13.89130116], [77.16171265, 13.88243103], [77.1623764, 13.87629128], [77.16491699, 13.86621857], [77.16249084, 13.85698032], [77.14821625, 13.85980129], [77.13938904, 13.85904026], [77.13015747, 13.84993935], [77.12388611, 13.84939003], [77.12526703, 13.8430109], [77.14045715, 13.83788967], [77.14576721, 13.83493996], [77.14789581, 13.82885075], [77.15791321, 13.82547092], [77.1622467, 13.8207407], [77.16194153, 13.81546116], [77.15619659, 13.81134033], [77.15537262, 13.80739021], [77.15632629, 13.80375957], [77.15409851, 13.8005619], [77.15573883, 13.79814243], [77.15599823, 13.79331017], [77.15849304, 13.78710079], [77.16407013, 13.78035069], [77.16918945, 13.77556038], [77.17134094, 13.7720499], [77.16964722, 13.76136971], [77.1665802, 13.75466919], [77.15815735, 13.75493145], [77.14673615, 13.75475121], [77.13751984, 13.75565243], [77.1341095, 13.75303078], [77.1235199, 13.75089073], [77.11094666, 13.75462055], [77.09526825, 13.76088047], [77.08577728, 13.758111], [77.08521271, 13.75455093], [77.08036041, 13.75342274], [77.07927704, 13.74602032], [77.08058929, 13.73739147], [77.07148743, 13.73875046], [77.06004333, 13.73886108], [77.05474854, 13.74450016], [77.04734802, 13.75607967], [77.03518677, 13.76928139], [77.02636719, 13.77144146], [77.01986694, 13.76986027], [77.01844025, 13.76169968], [77.01384735, 13.74747181], [77.0114212, 13.73272133], [77.00193787, 13.73666191], [76.993927, 13.74151039], [76.99259186, 13.74255085], [76.99167633, 13.7453413], [76.99212646, 13.74950886], [76.99012756, 13.7530899], [76.98898315, 13.76018047], [76.98634338, 13.76652145], [76.98435974, 13.77657032], [76.98123169, 13.78579998], [76.98484802, 13.78870106], [76.98577881, 13.79300022], [76.98371887, 13.80418968], [76.98002625, 13.80719185], [76.96882629, 13.8102417], [76.96839142, 13.81439018], [76.97155762, 13.81886101], [76.97653961, 13.82136059], [76.9839859, 13.82774067], [76.98625946, 13.83922958], [76.9899292, 13.83950996], [76.994133, 13.83897018], [77.00598907, 13.85009003], [77.00711823, 13.85417175], [77.00802612, 13.86290073], [77.01230621, 13.86409092], [77.01259613, 13.86723995], [77.01169586, 13.87144089], [77.01661682, 13.88772964], [77.01728058, 13.89337063], [77.02780914, 13.89717007], [77.04128265, 13.8973999], [77.0358429, 13.92559147], [77.01860046, 13.93479156], [77.01397705, 13.93948174], [77.00810242, 13.94736958], [76.99942017, 13.95044041], [76.99505615, 13.9527216], [76.99433136, 13.95337963], [76.98899841, 13.95669174], [76.99019623, 13.97027969], [76.99133301, 13.97581196], [76.99437714, 13.98149109], [76.98501587, 13.98752022], [76.97734833, 13.99387074], [76.97764587, 13.99386024], [76.97518158, 13.99658966], [76.96420288, 14.00224018], [76.94857025, 14.00677967], [76.9447403, 14.0106802], [76.94232941, 14.01548004], [76.94078064, 14.02060127], [76.93109894, 14.02273178], [76.93371582, 14.04067135], [76.93797302, 14.04759979], [76.94328308, 14.04721928], [76.94972992, 14.04784107], [76.9715271, 14.05239105], [76.97421265, 14.05770969], [76.9750061, 14.06527042], [76.97225189, 14.06840134], [76.97184753, 14.07571125], [76.96808624, 14.07973957], [76.96012115, 14.08296967], [76.95143127, 14.08537197], [76.94629669, 14.08526039], [76.94854736, 14.09141159], [76.94822693, 14.09658146], [76.94658661, 14.10297108], [76.94291687, 14.11190128], [76.93739319, 14.11515141], [76.92697906, 14.12720966], [76.92241669, 14.12903976], [76.91712952, 14.12448025], [76.9125061, 14.12210941], [76.89846802, 14.12687969], [76.89090729, 14.127841], [76.88368225, 14.13103199], [76.88691711, 14.13624001], [76.88919067, 14.15087891], [76.89142609, 14.15899944], [76.89675903, 14.16190147], [76.91718292, 14.15767097], [76.922966, 14.1633997], [76.9369812, 14.16589165], [76.93924713, 14.1677103], [76.94153595, 14.17803001], [76.9392395, 14.18680859], [76.94164276, 14.18931198], [76.94404602, 14.18832016], [76.94908142, 14.18381023], [76.95378113, 14.18103027], [76.95849609, 14.17550945], [76.96568298, 14.17432022], [76.97276306, 14.1742897], [76.97818756, 14.17292023], [76.98626709, 14.17253113], [76.9943924, 14.17374992], [77.00605011, 14.17485142], [77.01403809, 14.17304134], [77.0198288, 14.17270184], [77.02133942, 14.16839886], [77.02105713, 14.16432953], [77.01600647, 14.15269089], [77.01493835, 14.13218117], [77.01380157, 14.12740135], [77.01920319, 14.12529087], [77.0202713, 14.12232113], [77.01635742, 14.11752129], [77.01703644, 14.11195087], [77.0165863, 14.10609245], [77.00831604, 14.09813118], [77.01043701, 14.0920496], [77.01470947, 14.08869934], [77.02398682, 14.08337116], [77.02453613, 14.07716942], [77.02024078, 14.06144142], [77.0236969, 14.0532589], [77.02848053, 14.05198002], [77.0348587, 14.05144024], [77.04322052, 14.05167007], [77.05120087, 14.04959202], [77.06903076, 14.04718971], [77.06952667, 14.03944111], [77.07649231, 14.0380497], [77.09075928, 14.03826046], [77.0966568, 14.04070091], [77.10396576, 14.04057121], [77.1101532, 14.04204082], [77.12110138, 14.04218006], [77.12468719, 14.0347414], [77.12783051, 14.01865005], [77.1340332, 14.00967026], [77.13288116, 14.00421047], [77.13434601, 13.9981308], [77.13949585, 13.99719048], [77.14437103, 13.99351978], [77.14459991, 13.99351978], [77.14733887, 13.99162197], [77.15444183, 13.99061012], [77.15836334, 13.99351978], [77.15815735, 13.99351978], [77.16278076, 13.99775982], [77.16168976, 14.00624943], [77.17138672, 14.00859928], [77.19455719, 14.00286007], [77.20767975, 14.00487137], [77.21884918, 14.00791073], [77.22727203, 14.00795174], [77.24256897, 14.00631142], [77.25575256, 14.0209589], [77.26451874, 14.02652931], [77.27150726, 14.02810192], [77.27420807, 14.01618195], [77.2726059, 14.0080204], [77.27851105, 14.00690079], [77.28518677, 14.01152992], [77.2922821, 14.01449966], [77.29802704, 14.02303123], [77.30355835, 14.02672958], [77.31349182, 14.02482033], [77.31648254, 14.02145958], [77.31700897, 14.01532269], [77.32022095, 14.00925064], [77.32409668, 14.00531006], [77.33011627, 13.99488068], [77.32966614, 13.99335194], [77.32977295, 13.99335194], [77.3303299, 13.99035931], [77.33347321, 13.98805141], [77.34567261, 13.98558044], [77.35378265, 13.98232079], [77.35338593, 13.97628975], [77.34693909, 13.96058941], [77.34720612, 13.95535183], [77.34374237, 13.95089245], [77.36200714, 13.9454689], [77.36260986, 13.9423008], [77.35263824, 13.92845058], [77.34261322, 13.91224194], [77.34350586, 13.90598106], [77.34590149, 13.9033308], [77.3483429, 13.89654064], [77.35884857, 13.89556122], [77.39041901, 13.89768982], [77.39186096, 13.87989044], [77.39626312, 13.88044071], [77.39705658, 13.88054085], [77.4085083, 13.88881016], [77.4189682, 13.89490891], [77.42562866, 13.90205193], [77.42740631, 13.90921974], [77.42250061, 13.91195011], [77.41015625, 13.91460133], [77.40843964, 13.92161083], [77.40770721, 13.93610001], [77.4225769, 13.93900108], [77.42870331, 13.94334126], [77.42904663, 13.9563818], [77.43090057, 13.96199131], [77.43064117, 13.96877956], [77.42661285, 13.97328186], [77.42050171, 13.97687054], [77.41018677, 13.97692204], [77.38651276, 13.97400188], [77.37565613, 13.96911144], [77.37269592, 13.9755106], [77.37320709, 13.98171043], [77.37988281, 13.99328136], [77.38336182, 14.00735855], [77.37507629, 14.01210022], [77.36232758, 14.01599026], [77.35009766, 14.01645088], [77.34406281, 14.01906013], [77.32618713, 14.02293968], [77.33126068, 14.03984165], [77.33454895, 14.04779053], [77.33796692, 14.0538311], [77.35012054, 14.05338192], [77.35855865, 14.05892944], [77.36136627, 14.06595135], [77.37238312, 14.07185173], [77.37966156, 14.09039116], [77.38568115, 14.09346104], [77.39544678, 14.10344124], [77.39643097, 14.11056995], [77.39444733, 14.11464119], [77.38973999, 14.11857033], [77.38035583, 14.1166296], [77.37325287, 14.1125803], [77.3589325, 14.10872173], [77.35246277, 14.10535145], [77.34851074, 14.09926128], [77.34453583, 14.09601116], [77.34651184, 14.11044025], [77.34651184, 14.1178503], [77.34773254, 14.12434101], [77.3548584, 14.12374973], [77.36501312, 14.12710953], [77.3766861, 14.12960052], [77.37873077, 14.13827991], [77.38262177, 14.14772034], [77.38955688, 14.15354061], [77.3897171, 14.16526031], [77.39745331, 14.16650009], [77.40972137, 14.1697197], [77.41631317, 14.16930103], [77.42347717, 14.16508007], [77.45392609, 14.16298103], [77.46333313, 14.16423035], [77.48854065, 14.15307999], [77.5004425, 14.15096092], [77.50267029, 14.1571207], [77.50679016, 14.16424084], [77.51035309, 14.17201996], [77.5094223, 14.17695045], [77.50414276, 14.18066025], [77.50108337, 14.19322109], [77.49971008, 14.20446968], [77.49308777, 14.21397018], [77.49285126, 14.22006035], [77.49008179, 14.22763062], [77.49627686, 14.24040985], [77.49878693, 14.24954033], [77.49936676, 14.26051044], [77.4962616, 14.2717514], [77.49214172, 14.27128124], [77.48439026, 14.27525997], [77.47934723, 14.28477097], [77.47912598, 14.283741], [77.46842957, 14.27943993], [77.45469666, 14.27219009], [77.4436264, 14.2775507], [77.44243622, 14.29091072], [77.44233704, 14.30975056], [77.42752838, 14.30484962], [77.4258728, 14.32081127], [77.42072296, 14.32199192], [77.4092865, 14.32710171], [77.39488983, 14.32915974], [77.38565826, 14.32487011], [77.37882233, 14.31707954], [77.37386322, 14.30510998], [77.37500763, 14.2951889], [77.3812027, 14.28299141], [77.38504791, 14.27245045], [77.38433838, 14.26561069], [77.38986969, 14.26138973], [77.40101624, 14.26041031], [77.40479279, 14.24860096], [77.40618134, 14.23671055], [77.40905762, 14.22358131], [77.41470337, 14.21706009], [77.41570282, 14.21196175], [77.41487885, 14.20322132], [77.39122009, 14.19088173], [77.38378906, 14.1918211], [77.38011169, 14.20255089], [77.38162231, 14.21018028], [77.37661743, 14.216712], [77.36431122, 14.22331047], [77.35540771, 14.2300396], [77.35923767, 14.24360085], [77.35826874, 14.26032066], [77.35926056, 14.26933002], [77.35340881, 14.27067947], [77.34336853, 14.27052021], [77.32058716, 14.27345085], [77.30748749, 14.27383995], [77.29545593, 14.27647114], [77.28549957, 14.27474976], [77.27958679, 14.27608967], [77.28189087, 14.29045963], [77.2826767, 14.30228043], [77.28114319, 14.33111095], [77.2733078, 14.33175087], [77.26732635, 14.32701015], [77.25785065, 14.32570171], [77.251297, 14.32060242], [77.24508667, 14.31453037], [77.23195648, 14.31107044], [77.22292328, 14.31498146], [77.20979309, 14.31301022], [77.19635773, 14.31429958], [77.17951202, 14.32637024], [77.17674255, 14.32629013], [77.17188263, 14.33023071], [77.16422272, 14.33046055], [77.15975952, 14.33623886], [77.15215302, 14.3377409], [77.14644623, 14.33219147], [77.14054108, 14.33611107], [77.13553619, 14.33401203], [77.13191986, 14.3305912], [77.13262939, 14.32404995], [77.13092804, 14.31381035], [77.12577057, 14.30153179], [77.11730957, 14.29141045], [77.11192322, 14.2875309], [77.1105423, 14.27493], [77.10692596, 14.26176071], [77.11551666, 14.25681973], [77.1115799, 14.24846172], [77.11299896, 14.23991966], [77.110466, 14.23198032], [77.1099472, 14.22148037], [77.10507965, 14.21328163], [77.09522247, 14.20948029], [77.08486938, 14.20845032], [77.07534027, 14.20934963], [77.06761932, 14.21786022], [77.06022644, 14.22416019], [77.05532074, 14.23230076], [77.04962921, 14.23954201], [77.04064941, 14.2407589], [77.03304291, 14.24048996], [77.02458954, 14.23668098], [77.01251221, 14.23509121], [77.00411987, 14.23156929], [76.99456024, 14.23556042], [76.99279022, 14.23298931], [76.98937988, 14.2364006], [76.98248291, 14.23815155], [76.97560883, 14.23742008], [76.96971893, 14.23521137], [76.96157074, 14.23590183], [76.95139313, 14.23415184], [76.94346619, 14.23631001], [76.93784332, 14.24012089], [76.93598938, 14.24877167], [76.9336319, 14.25350094], [76.92582703, 14.26439953], [76.92485809, 14.27218056], [76.93548584, 14.27664185], [76.9437561, 14.28168106], [76.9487381, 14.28676128], [76.95011139, 14.29402924], [76.94670105, 14.30044937], [76.94293976, 14.30537891], [76.93656158, 14.30840969], [76.92314911, 14.30965042], [76.91680908, 14.31225967], [76.90615845, 14.315341], [76.89897156, 14.31924057], [76.88536072, 14.33959103], [76.87909698, 14.34638977], [76.87861633, 14.35139275], [76.88314056, 14.39029121], [76.88677979, 14.39245129], [76.89232635, 14.3928709], [76.89663696, 14.39447975], [76.90116119, 14.3983202], [76.9131012, 14.41355228], [76.9189682, 14.41145039], [76.93678284, 14.40130997], [76.94156647, 14.39954185], [76.94359589, 14.40326118], [76.94467926, 14.40892029], [76.94432068, 14.42523193], [76.94271088, 14.43984127], [76.94378662, 14.44510174], [76.95858765, 14.4453907], [76.96437073, 14.45174122], [76.97419739, 14.47036076], [76.9733963, 14.47828102], [76.96909332, 14.47908974], [76.95580292, 14.47958946], [76.94541168, 14.48215103], [76.90651703, 14.48416138], [76.89427185, 14.48075199], [76.88549042, 14.4759407], [76.88030243, 14.47052956], [76.87020111, 14.46844006], [76.86380768, 14.47467136], [76.86044312, 14.48713112], [76.85421753, 14.49888039], [76.84393311, 14.50914955], [76.83207703, 14.51507092], [76.82842255, 14.52224064], [76.82758331, 14.52305889], [76.81973267, 14.52033997], [76.81089783, 14.5237999], [76.80509186, 14.52487087], [76.79972839, 14.5277319], [76.79469299, 14.54073048], [76.78617096, 14.55305958], [76.78405762, 14.56198025], [76.77815247, 14.5793314], [76.77628326, 14.59033012], [76.77435303, 14.59057045], [76.77275085, 14.58720112], [76.76091003, 14.59628105], [76.76017761, 14.60201073], [76.7629776, 14.61192131], [76.76950836, 14.65631104], [76.77127838, 14.67383957], [76.78108215, 14.6904707], [76.78553772, 14.70709133], [76.79807281, 14.73459053], [76.79502869, 14.74113178], [76.78813934, 14.75184059], [76.78642273, 14.76191139], [76.78128815, 14.77433014], [76.78034973, 14.77926159], [76.81096649, 14.7814312], [76.81671143, 14.78249073], [76.81735229, 14.78544044], [76.82073212, 14.78660965], [76.82641602, 14.78698063], [76.83136749, 14.78411198], [76.83377075, 14.78490925], [76.83496857, 14.8001318], [76.83721161, 14.80414104], [76.8469162, 14.80231094], [76.84873962, 14.80403137], [76.84960175, 14.81180954], [76.84854126, 14.81425095], [76.8444519, 14.81559086], [76.84298706, 14.82430172], [76.84026337, 14.82807159], [76.84008789, 14.83004093], [76.84436035, 14.83325195], [76.84938812, 14.83869934], [76.85411835, 14.86137199], [76.85167694, 14.86252117], [76.85087585, 14.87285042], [76.84905243, 14.87993145], [76.84326172, 14.88147163], [76.84377289, 14.88642025], [76.846138, 14.89033127], [76.86030579, 14.89118958], [76.86271667, 14.90176964], [76.86389923, 14.91174126], [76.86348724, 14.91564274], [76.86547852, 14.93760014], [76.86367035, 14.95521069], [76.86445618, 14.96401978], [76.84115601, 14.96117115], [76.83587646, 14.9590807], [76.83255005, 14.95348072], [76.82789612, 14.95100975], [76.82364655, 14.95361137], [76.82028198, 14.95917034], [76.81545258, 14.96380997], [76.79688263, 14.96292114], [76.7720871, 14.96864033], [76.76377106, 14.96986961], [76.76185608, 14.97528076], [76.75863647, 14.97946072], [76.75698853, 14.98297119], [76.7592392, 14.98507023], [76.76235962, 14.9894619], [76.7651825, 14.98906136], [76.76622009, 14.99081135], [76.76805878, 14.9956398], [76.76953125, 15.00058174], [76.77974701, 15.00588989], [76.78457642, 15.01667023], [76.78179169, 15.02332973], [76.78079224, 15.03423977], [76.77501678, 15.04395962], [76.77112579, 15.05409145], [76.77082062, 15.05828857], [76.77256012, 15.06511974], [76.77574158, 15.06916142], [76.77422333, 15.07138062], [76.77636719, 15.07329273], [76.7786026, 15.0715704], [76.78391266, 15.07567024], [76.78224945, 15.07882023], [76.78423309, 15.08078003], [76.78756714, 15.08043957], [76.79693604, 15.09076023], [76.81188202, 15.08023071], [76.82126617, 15.07485199], [76.82943726, 15.07429123], [76.83740997, 15.07246971], [76.84320831, 15.06615925], [76.86057281, 15.05671024], [76.86406708, 15.05000019], [76.86975098, 15.0440197], [76.87670135, 15.02867889], [76.88868713, 15.03175068], [76.89620972, 15.03188133], [76.90544128, 15.0292902], [76.91352081, 15.03095055], [76.9193573, 15.02852154], [76.93167114, 15.02631092], [76.94274902, 15.02703094], [76.95066833, 15.02443123], [76.96679688, 15.01316929], [76.98178101, 15.01036072], [76.98351288, 15.02042198], [76.99565125, 15.02368069], [76.99862671, 15.02706146], [77.00067902, 15.02958965], [77.0092926, 15.02958107], [77.02295685, 15.02765083], [77.0374527, 15.02757072], [77.04688263, 15.029212], [77.04878998, 15.02386093], [77.04638672, 15.01601791], [77.041008, 15.00548172], [77.05092621, 15.00428963], [77.06147003, 15.00154972], [77.06858826, 15.00111008], [77.07881927, 15.00000954], [77.08049774, 15.00791073], [77.0820694, 15.02229023], [77.08825684, 15.02303791], [77.09078217, 15.02772236], [77.10167694, 15.02734089], [77.10957336, 15.02856922], [77.11161041, 15.03812981], [77.11606598, 15.04010201], [77.11839294, 15.05063057], [77.12091064, 15.05507088], [77.12552643, 15.06820965], [77.12760925, 15.09364128], [77.13938904, 15.09988117], [77.14771271, 15.10733032], [77.15403748, 15.12052059], [77.15276337, 15.13162136], [77.13536072, 15.13601017], [77.13208008, 15.14268112], [77.13697052, 15.14925194], [77.14549255, 15.15070057], [77.15305328, 15.14882088], [77.15770721, 15.14895058], [77.1592865, 15.15212059], [77.15879059, 15.15786934], [77.16320038, 15.16133118], [77.16448212, 15.16847038], [77.16153717, 15.18221092], [77.15815735, 15.19382], [77.15577698, 15.19433975], [77.14996338, 15.207901], [77.14707947, 15.20880985], [77.14138031, 15.21813202], [77.12090302, 15.221241], [77.12345886, 15.23332024], [77.13265991, 15.2346096], [77.14025116, 15.25155067], [77.14668274, 15.25029087], [77.1579361, 15.2513504], [77.16525269, 15.25097179], [77.16414642, 15.2590704], [77.15766907, 15.26037979], [77.14985657, 15.26693058], [77.14517212, 15.26605129], [77.14491272, 15.26928043], [77.14803314, 15.27095127], [77.14872742, 15.27785015], [77.14791107, 15.28567028], [77.13883972, 15.28547955], [77.12374878, 15.28757], [77.11541748, 15.28985023], [77.11342621, 15.31912041], [77.11023712, 15.32073021], [77.10968781, 15.32728195], [77.09929657, 15.32662106], [77.0690918, 15.31947136], [77.06157684, 15.32186031], [77.0631485, 15.32808018], [77.06289673, 15.3379097], [77.05784607, 15.34319019], [77.04260254, 15.35224056], [77.03803253, 15.35878181], [77.04228973, 15.37479973], [77.04382324, 15.38374138], [77.041008, 15.39151001], [77.03325653, 15.39626026], [77.02854156, 15.40130234], [77.0268631, 15.40775204], [77.03100586, 15.41833973], [77.03048706, 15.42633057], [77.02739716, 15.43518066], [77.02384186, 15.43856144], [77.01528168, 15.4410696], [77.00609589, 15.44823074], [77.00203705, 15.45538139], [77.00074005, 15.46170139], [76.9960022, 15.46745968], [76.98898315, 15.47315121], [76.97608185, 15.48201275], [76.97039032, 15.49092197], [76.97013855, 15.49495125], [76.97189331, 15.50633144], [76.98165131, 15.50477028], [76.99085236, 15.50107098], [76.99603271, 15.49973106], [77.00543213, 15.50277138], [77.02659607, 15.49999046], [77.02874756, 15.50856018], [77.028862, 15.52512169], [77.02371216, 15.57638168], [77.02443695, 15.58436203], [77.02889252, 15.59825993], [77.02839661, 15.60684967], [77.02710724, 15.62934971], [77.02928162, 15.63383865], [77.03266144, 15.63200855], [77.03601074, 15.6323719], [77.06887054, 15.64090919], [77.08143616, 15.65284061], [77.08889771, 15.64752102], [77.09593201, 15.64414978], [77.10056305, 15.63916111], [77.10389709, 15.63393116], [77.11620331, 15.62510967], [77.1209259, 15.63720131], [77.12497711, 15.65905094], [77.1190567, 15.66208935], [77.110466, 15.67126274], [77.10083771, 15.67887974], [77.07592773, 15.69087887], [77.07792664, 15.69336128], [77.08164978, 15.69533062], [77.08436584, 15.70895958], [77.0762558, 15.71037102], [77.07627106, 15.72141075], [77.06299591, 15.72367191], [77.04708862, 15.72501183], [77.04724884, 15.73317146], [77.04322815, 15.73448181], [77.04669189, 15.75133133], [77.05171967, 15.7501297], [77.05316925, 15.75887966], [77.04850769, 15.76076031], [77.04972076, 15.76410103], [77.0537262, 15.76364994], [77.05660248, 15.77228069], [77.05976868, 15.77884007], [77.06247711, 15.77839088], [77.06723785, 15.79605007], [77.06151581, 15.79792118], [77.06388855, 15.82316971], [77.05226135, 15.82433891], [77.04991913, 15.82014275], [77.04154205, 15.821661], [77.03836823, 15.82551003], [77.03388214, 15.82439995], [77.02815247, 15.82559013], [77.02442169, 15.82948971], [77.0222702, 15.83178043], [77.02902985, 15.84490108], [77.03318787, 15.85308075], [77.04104614, 15.86395931], [77.05245209, 15.87628269], [77.05821228, 15.88716125], [77.06595612, 15.89931107], [77.07679749, 15.90974045], [77.09005737, 15.91786957], [77.10460663, 15.92453194], [77.12065887, 15.92882061], [77.12993622, 15.93039131], [77.13677216, 15.93621922], [77.14343262, 15.9406004], [77.15712738, 15.9444809], [77.17070007, 15.94554996], [77.18062592, 15.95006275], [77.18782806, 15.9507103], [77.20295715, 15.94987965], [77.21866608, 15.95164204], [77.22711945, 15.95160961], [77.23609161, 15.95271111], [77.2440567, 15.95676136], [77.24891663, 15.95774078], [77.25813293, 15.95397091], [77.26317596, 15.95138931], [77.28244781, 15.94736195], [77.29178619, 15.94996929], [77.30021667, 15.95049953], [77.31478882, 15.94519043], [77.33516693, 15.94327068], [77.35360718, 15.94370174], [77.35987091, 15.94155025], [77.36814117, 15.93604088], [77.3762207, 15.93325043], [77.38559723, 15.9344511], [77.3927002, 15.93676186], [77.40003204, 15.93546009], [77.40763092, 15.93565178], [77.41644287, 15.93796062], [77.42193604, 15.94129944], [77.42642212, 15.94227886], [77.43647766, 15.9390316], [77.45250702, 15.93152046], [77.46697998, 15.92758083], [77.48332214, 15.92805958], [77.49732208, 15.92630005], [77.50945282, 15.92086029], [77.53173828, 15.91611958], [77.54884338, 15.91366863], [77.57163239, 15.91232014], [77.58010101, 15.91020966], [77.58841705, 15.90699196], [77.59868622, 15.90874195], [77.60637665, 15.91172981], [77.61384583, 15.90783024], [77.61882019, 15.90375137], [77.62570953, 15.89913082], [77.63204956, 15.89180088], [77.63960266, 15.88313103], [77.64821625, 15.87893963], [77.65894318, 15.87652016], [77.68353271, 15.87389183], [77.69249725, 15.87532139], [77.69944763, 15.88043976], [77.70730591, 15.88409996], [77.71611786, 15.88657093], [77.72486115, 15.88479137], [77.73195648, 15.88221073], [77.73883057, 15.87852097], [77.74964142, 15.87587929], [77.76004791, 15.876791], [77.77020264, 15.87327194], [77.77889252, 15.8693018], [77.78978729, 15.86658859], [77.79918671, 15.86532021], [77.80921936, 15.86702919], [77.81772614, 15.86949062], [77.8253479, 15.87379074], [77.83384705, 15.87551022], [77.83976746, 15.87394047], [77.85011292, 15.87382126], [77.85565186, 15.87576103], [77.86694336, 15.8923893], [77.87638092, 15.89600182], [77.88768005, 15.89592171], [77.90756226, 15.88489056], [77.92829895, 15.87650967], [77.94402313, 15.87491035], [77.96308136, 15.87590027], [77.9728775, 15.87411976], [77.99360657, 15.86098003], [78.0018692, 15.85923004], [78.00660706, 15.87197018], [78.01473236, 15.88881111], [78.01696777, 15.89514923], [78.02423859, 15.89858246], [78.02879333, 15.90269089], [78.03629303, 15.90209103], [78.03981781, 15.89810085], [78.04071808, 15.87220097], [78.04886627, 15.87075138], [78.05847168, 15.85041046], [78.0636673, 15.84456158], [78.10114288, 15.82792187], [78.10958099, 15.82718086], [78.11978912, 15.83026886], [78.12687683, 15.83492088], [78.1258316, 15.84893131], [78.13791656, 15.85024071], [78.14840698, 15.84996986], [78.15093231, 15.84904003], [78.16467285, 15.84899044], [78.16867065, 15.85317039], [78.17066193, 15.86643887], [78.17384338, 15.87252045], [78.17907715, 15.87977886], [78.18148804, 15.88765144], [78.17919159, 15.89494038], [78.18003082, 15.90044975], [78.19667053, 15.91224003], [78.20539856, 15.91706085], [78.22786713, 15.92348099], [78.23796844, 15.9290514], [78.24286652, 15.93704891], [78.24401093, 15.9469614], [78.2473526, 15.96004963], [78.24835968, 15.9683094], [78.25110626, 15.97083855], [78.25293732, 15.97844028], [78.25974274, 15.99473095], [78.25868225, 16.00508118], [78.25138092, 16.02568054], [78.25666809, 16.03129959], [78.26815796, 16.03475952], [78.28105927, 16.03209114], [78.29218292, 16.02849007], [78.31620789, 16.02915192], [78.32356262, 16.03724289], [78.33114624, 16.04709053], [78.34041595, 16.05277061], [78.35311127, 16.05451012], [78.37003326, 16.05984116], [78.38424683, 16.07183075], [78.40566254, 16.08094978], [78.42095184, 16.0828495], [78.45101166, 16.0810318], [78.49559784, 16.0730896], [78.52083588, 16.0650692], [78.5328598, 16.06232262], [78.54689789, 16.05620003], [78.55912781, 16.05637169], [78.56711578, 16.06187057], [78.57643127, 16.07034111], [78.59256744, 16.08723068], [78.60350037, 16.09643936], [78.61701202, 16.09890938], [78.63648987, 16.09144974], [78.646698, 16.08273125], [78.65776062, 16.07143974], [78.66837311, 16.05579948], [78.67498016, 16.0490303], [78.68656158, 16.04038048], [78.71366882, 16.02666092], [78.72596741, 16.02304077], [78.73898315, 16.02114105], [78.75393677, 16.02100945], [78.7750473, 16.02360916], [78.79001617, 16.03269958], [78.80799866, 16.04619026], [78.81376648, 16.05219078], [78.82155609, 16.06220055], [78.83650208, 16.08737755], [78.83937836, 16.09424019], [78.84028625, 16.10283089], [78.83808899, 16.11086082], [78.83394623, 16.12014008], [78.83127594, 16.13297844], [78.83049774, 16.14215088], [78.83213043, 16.15176964], [78.83783722, 16.15673828], [78.84628296, 16.15954018], [78.85645294, 16.15859985], [78.86293793, 16.15308952], [78.86633301, 16.14385986], [78.86802673, 16.13526154], [78.86942291, 16.12162971], [78.87267303, 16.11017036], [78.8890686, 16.09856033], [78.90117645, 16.09762192], [78.91047668, 16.1052227], [78.91335297, 16.10884094], [78.91726685, 16.11351967], [78.92186737, 16.12187195], [78.92086029, 16.13367081], [78.90558624, 16.16492081], [78.90545654, 16.18186951], [78.90808105, 16.19104004], [78.92549896, 16.20233917], [78.94108582, 16.20981026], [78.95900726, 16.21722031], [78.97805786, 16.22307014], [78.99243164, 16.22830009], [79.01017761, 16.24044991], [79.0201416, 16.24427032], [79.03093719, 16.2457428], [79.04252625, 16.24495125], [79.05407715, 16.24255943], [79.06859589, 16.23814011], [79.12300873, 16.23791122], [79.13317871, 16.23637962], [79.14248657, 16.22925949], [79.15117645, 16.22462082], [79.16272736, 16.2202282], [79.17658234, 16.21713066], [79.19198608, 16.22271919], [79.2075119, 16.23067093], [79.21868896, 16.23964119], [79.22505951, 16.25007057], [79.22982025, 16.30022049], [79.22785187, 16.33681107], [79.22323608, 16.35036087], [79.21147156, 16.36281013], [79.21330261, 16.37438965], [79.21260071, 16.39376068], [79.21501923, 16.41576195], [79.21906281, 16.43816948], [79.22635651, 16.45253944], [79.23618317, 16.45853996], [79.23513031, 16.47068977], [79.23091125, 16.48167038], [79.22410583, 16.49213982], [79.22527313, 16.50822067], [79.23044586, 16.51929092], [79.26077271, 16.54642105], [79.26611328, 16.56147003], [79.28237915, 16.56544113], [79.29512024, 16.56735039], [79.31977844, 16.57587051], [79.33333588, 16.57852173], [79.34552765, 16.57956123], [79.40270996, 16.58044052], [79.42658997, 16.58252144], [79.43450165, 16.58566093], [79.44315338, 16.59370041], [79.45059204, 16.60914993], [79.47009277, 16.61874962], [79.49717712, 16.63051033], [79.51212311, 16.63365173], [79.53671265, 16.63156128], [79.55399323, 16.63459015], [79.56359863, 16.63806915], [79.57402039, 16.64359093], [79.58558655, 16.65135002], [79.59990692, 16.66327095], [79.61680603, 16.66464043], [79.63329315, 16.6608696], [79.64803314, 16.66200066], [79.65550232, 16.67408943], [79.66864014, 16.68400955], [79.6830368, 16.6903801], [79.72274017, 16.69260979], [79.7338028, 16.69802094], [79.75048065, 16.72011948], [79.76309204, 16.7271328], [79.77490234, 16.7295208], [79.7833786, 16.72484016], [79.81025696, 16.69049072], [79.8259201, 16.69146919], [79.84456635, 16.69646072], [79.86183929, 16.69822121], [79.87330627, 16.68869972], [79.88065338, 16.67617035], [79.89092255, 16.64956093], [79.90207672, 16.63784981], [79.91382599, 16.63313103], [79.92366791, 16.63073921], [79.94256592, 16.63262939], [79.95815277, 16.64204979], [79.97302246, 16.6595211], [79.99151611, 16.69255066], [79.99368286, 16.69444084], [80.002388, 16.70294952], [80.01667786, 16.71183014], [80.0233078, 16.71847916], [80.03276062, 16.73178101], [80.04335022, 16.73970032], [80.04789734, 16.74515152], [80.05158997, 16.77128983], [80.05767059, 16.78187943], [80.06492615, 16.80251122], [80.06967163, 16.81360817], [80.0418396, 16.82606125], [80.03666687, 16.83238983], [80.03439331, 16.83912277], [80.03436279, 16.84776115], [80.03309631, 16.85244942], [80.01383209, 16.85293961], [79.994133, 16.86218071], [79.99167633, 16.86325073], [79.99505615, 16.87731171], [80.0027771, 16.89146805], [80.009552, 16.90726089], [80.01860046, 16.91880989], [80.02849579, 16.92741013], [80.03705597, 16.93647003], [80.04588318, 16.96529961], [80.08423615, 16.96319008], [80.08394623, 16.9776783], [80.08769226, 16.98744011], [80.09947205, 16.98280144], [80.10578918, 16.98131943], [80.11279297, 16.98232079], [80.11467743, 16.98587036], [80.12014771, 16.98681068], [80.12689972, 16.98533058], [80.13385773, 16.98535919], [80.14057159, 16.99328995], [80.14247131, 17.0014801], [80.14911652, 17.00805092], [80.16718292, 17.02362061], [80.17053223, 17.03041267], [80.18212891, 17.04494095], [80.19426727, 17.04251289], [80.19610596, 17.02568817], [80.19554901, 17.01804161], [80.2012558, 17.01313972], [80.21321869, 17.0191803], [80.2178421, 17.0196209], [80.23223877, 17.0049305], [80.23574829, 17.00233078], [80.2411499, 17.00280952], [80.25026703, 17.00737953], [80.26217651, 17.01062965], [80.27617645, 16.99324989], [80.28898621, 16.97680283], [80.30137634, 16.95586014], [80.30396271, 16.93947029], [80.30784607, 16.92381287], [80.31537628, 16.91238976], [80.31328583, 16.91200256], [80.31613159, 16.89466286], [80.31600189, 16.88400078], [80.3184433, 16.87743759], [80.3192215, 16.87094116], [80.32731628, 16.87101936], [80.33731079, 16.86708069], [80.33495331, 16.85573959], [80.35090637, 16.85330009], [80.35862732, 16.8549099], [80.36120605, 16.85038185], [80.36472321, 16.83890152], [80.36711121, 16.82676125], [80.37293243, 16.81110001], [80.37587738, 16.8106308], [80.37784576, 16.81248093], [80.3793869, 16.81953049], [80.39422607, 16.82516289], [80.39914703, 16.83158112], [80.400177, 16.83704948], [80.39971161, 16.84973907], [80.41867065, 16.84231949], [80.42140961, 16.83712006], [80.4228363, 16.82930946], [80.43210602, 16.82718086], [80.43183136, 16.82385063], [80.44476318, 16.81939125], [80.4526062, 16.81529045], [80.45507813, 16.80648041], [80.45639801, 16.79002953], [80.47101593, 16.78832054], [80.47905731, 16.78495026], [80.48464966, 16.78131104], [80.48953247, 16.77585983], [80.51098633, 16.76993752], [80.51806641, 16.76876831], [80.53005981, 16.77005959], [80.54650879, 16.76765823], [80.56281281, 16.76283073], [80.56933594, 16.77075005], [80.59751892, 16.78508949], [80.60410309, 16.78775978], [80.59777832, 16.79203033], [80.59364319, 16.79791832], [80.58584595, 16.8066597], [80.57176971, 16.81209946], [80.56700897, 16.81710052], [80.56124878, 16.81712914], [80.55602264, 16.81841087], [80.55458069, 16.82478905], [80.56243134, 16.83632088], [80.56400299, 16.84256172], [80.56482697, 16.84991074], [80.56497192, 16.86903954], [80.57650757, 16.87310028], [80.58674622, 16.87393951], [80.58577728, 16.88716125], [80.58335876, 16.89060974], [80.58123779, 16.89677811], [80.5821228, 16.90310287], [80.58587646, 16.90432167], [80.5893631, 16.9071312], [80.59030914, 16.91163063], [80.58914185, 16.91666985], [80.58419037, 16.92651939], [80.56948853, 16.92688942], [80.53173828, 16.95017815], [80.52069092, 16.93639946], [80.509758, 16.94243813], [80.49130249, 16.94818115], [80.48693848, 16.93685913], [80.48558807, 16.92703819], [80.48781586, 16.91744041], [80.47688293, 16.92117119], [80.46985626, 16.92651176], [80.46324921, 16.93021011], [80.45308685, 16.9383297], [80.44254303, 16.94494057], [80.41234589, 16.95417023], [80.39762115, 16.95701027], [80.38080597, 16.96251106], [80.36042023, 16.97050095], [80.35824585, 16.97063065], [80.36106873, 16.9744606], [80.36972046, 16.98295021], [80.37161255, 16.98711967], [80.37120056, 16.99315071], [80.37119293, 16.99584007], [80.38197327, 17.00004005], [80.3864975, 17.00294113], [80.38790894, 17.00729942], [80.38871765, 17.01406097], [80.38376617, 17.01975822], [80.37789154, 17.02334023], [80.37722015, 17.02787018], [80.37838745, 17.03412056], [80.37162018, 17.04752922], [80.36775208, 17.05269814], [80.36699677, 17.05656815], [80.37416077, 17.06311035], [80.37905884, 17.06615067], [80.39012146, 17.07620049], [80.39319611, 17.07781029], [80.3950882, 17.07756805], [80.3973465, 17.07389069], [80.39977264, 17.0652504], [80.39890289, 17.05978966], [80.40087128, 17.05418968], [80.41429138, 17.0417881], [80.41777802, 17.02861023], [80.42053986, 17.02486038], [80.43266296, 17.02178192], [80.44624329, 17.01702118], [80.45288849, 17.03704262], [80.46422577, 17.03718185], [80.47174835, 17.0381012], [80.47506714, 17.04281044], [80.48220062, 17.05027008], [80.48465729, 17.05631065], [80.48462677, 17.06759071], [80.48678589, 17.08289909], [80.48873138, 17.08733177], [80.49240112, 17.09244156], [80.49653625, 17.10129166], [80.49611664, 17.10786057], [80.51172638, 17.10621071], [80.51941681, 17.10815048], [80.52916718, 17.11364937], [80.53542328, 17.11978912], [80.54165649, 17.12041092], [80.54907227, 17.12362289], [80.56017303, 17.1380291], [80.57348633, 17.13529015], [80.58026123, 17.13095093], [80.59510803, 17.11956024], [80.60388184, 17.11551094], [80.61292267, 17.11664009], [80.61654663, 17.11569977], [80.62391663, 17.11188126], [80.62975311, 17.11001968], [80.62523651, 17.10173988], [80.63640594, 17.09699059], [80.64626312, 17.09445953], [80.65664673, 17.08776283], [80.65541077, 17.08397102], [80.64438629, 17.07710075], [80.63775635, 17.07193947], [80.6377182, 17.06561089], [80.63392639, 17.05887985], [80.63960266, 17.05512047], [80.64919281, 17.05458069], [80.66059875, 17.05672073], [80.66777039, 17.05992126], [80.67563629, 17.0612793], [80.68139648, 17.06430054], [80.68399811, 17.06874084], [80.69516754, 17.06834984], [80.71261597, 17.06546021], [80.7257309, 17.06460953], [80.74659729, 17.05491829], [80.76609802, 17.0503006], [80.78019714, 17.04879951], [80.78528595, 17.04762268], [80.79284668, 17.04303932], [80.80322266, 17.0425396], [80.82322693, 17.03778076], [80.82930756, 17.0323391], [80.83246613, 17.02571106], [80.84487915, 17.03284073], [80.85053253, 17.0401516], [80.85489655, 17.04404068], [80.85884857, 17.05085182], [80.85646057, 17.06851959], [80.86254883, 17.08152962], [80.86239624, 17.08563042], [80.86421204, 17.09581757], [80.85504913, 17.11141014], [80.86347198, 17.11799812], [80.8667984, 17.12462044], [80.87030792, 17.14630127], [80.87676239, 17.14520073], [80.88886261, 17.14105034], [80.89615631, 17.1407795], [80.90397644, 17.14114952], [80.90939331, 17.14245033], [80.91330719, 17.14595032], [80.9121933, 17.15350914], [80.91400146, 17.16077042], [80.91487122, 17.16983986], [80.91301727, 17.17378044], [80.90847778, 17.17803955], [80.90699005, 17.18384171], [80.90763855, 17.19285965], [80.90534973, 17.20129013], [80.91384888, 17.20525932], [80.92064667, 17.20582962], [80.9306488, 17.20503044], [80.93904877, 17.20038033], [80.94773102, 17.19333076], [80.95598602, 17.18820953], [80.96633148, 17.1845417], [80.98516083, 17.17938995], [80.99125671, 17.17970276], [80.99771881, 17.18201065], [81.00540161, 17.18444824], [81.02617645, 17.1866684], [81.03145599, 17.19235039], [81.03485107, 17.1972599], [81.03996277, 17.19994164], [81.04386139, 17.20454025], [81.04654694, 17.2138176], [81.05384064, 17.21014023], [81.06221008, 17.20409966], [81.08450317, 17.21364021], [81.11817932, 17.2245903], [81.14554596, 17.23166275], [81.16278839, 17.23258018], [81.16799927, 17.24232101], [81.18055725, 17.25460052], [81.17463684, 17.26037025], [81.17114258, 17.26666069], [81.17061615, 17.29646111], [81.17195892, 17.30545044], [81.17822266, 17.31451035], [81.18154144, 17.32222939], [81.19030762, 17.32736969], [81.21875, 17.3217392], [81.23429108, 17.32282066], [81.25752258, 17.32266045], [81.26222229, 17.32194138], [81.26716614, 17.31999969], [81.28179932, 17.3297596], [81.28916931, 17.33754921], [81.29881287, 17.35214043], [81.30162048, 17.35972977], [81.31162262, 17.37478065], [81.32247162, 17.38915062], [81.3246994, 17.3906498], [81.33035278, 17.39209938], [81.33734894, 17.38999939], [81.34292603, 17.38541031], [81.34329987, 17.37572098], [81.34983826, 17.36852264], [81.36395264, 17.36026001], [81.37180328, 17.3571682], [81.37864685, 17.35612106], [81.38522339, 17.35513115], [81.40644836, 17.36141014], [81.41564941, 17.36162949], [81.41831207, 17.36638069], [81.42011261, 17.37218285], [81.43364716, 17.37494278], [81.44151306, 17.38171005], [81.44608307, 17.39069176], [81.45155334, 17.39833069], [81.45726013, 17.40539932], [81.47223663, 17.41953087], [81.481987, 17.43220139], [81.49341583, 17.44882011], [81.49536133, 17.45380974], [81.49585724, 17.46037102], [81.49373627, 17.4659996], [81.49360657, 17.47702026], [81.49816132, 17.48999977], [81.49951172, 17.50154114], [81.49803162, 17.51007271], [81.49946594, 17.53153992], [81.5014267, 17.53936005], [81.50907898, 17.54932022], [81.51374054, 17.55726051], [81.52030945, 17.56460953], [81.52371979, 17.56970978], [81.52390289, 17.57261086], [81.52089691, 17.57574081], [81.51267242, 17.58296013], [81.50292969, 17.58987999], [81.50789642, 17.59532166], [81.50926971, 17.59832954], [81.50927734, 17.60355949], [81.51187897, 17.60988045], [81.51895905, 17.61878967], [81.53414917, 17.63042259], [81.54432678, 17.64529991], [81.54608917, 17.65069962], [81.5536499, 17.66638947], [81.56018066, 17.67665291], [81.56819153, 17.68283081], [81.57116699, 17.68786812], [81.57108307, 17.70289993], [81.57198334, 17.71183014], [81.5729599, 17.71866989], [81.57662201, 17.72609138], [81.58194733, 17.73065948], [81.60919952, 17.7436409], [81.61281586, 17.74693108], [81.61859131, 17.75858116], [81.62306213, 17.76279068], [81.64189911, 17.76564026], [81.65299988, 17.76561165], [81.67469025, 17.76711082], [81.68477631, 17.77056122], [81.69138336, 17.77570152], [81.69824219, 17.78449059], [81.70398712, 17.79956055], [81.70951843, 17.80511093], [81.72342682, 17.81522179], [81.72959137, 17.8192997], [81.7388916, 17.8216095], [81.75293732, 17.81830978], [81.76393127, 17.82992935], [81.78235626, 17.83195114], [81.78784943, 17.83924103], [81.79440308, 17.84415054], [81.79277039, 17.8525219], [81.78753662, 17.86251068], [81.78144073, 17.87071991], [81.76885986, 17.87869835], [81.7634201, 17.88540077], [81.75829315, 17.89336014], [81.76222229, 17.89658928], [81.77574921, 17.9047699], [81.7824173, 17.90974045], [81.78601074, 17.91361046], [81.7893219, 17.92136955], [81.79405212, 17.9296608], [81.80104065, 17.93608093], [81.81980133, 17.94546127], [81.83333588, 17.95103073], [81.83969879, 17.95006943], [81.84681702, 17.95079994], [81.87413788, 17.95984077], [81.88507843, 17.96583939], [81.89927673, 17.96854973], [81.90454865, 17.97347069], [81.91369629, 17.97989082], [81.92471313, 17.98088074], [81.93609619, 17.98409081], [81.95176697, 17.99209976], [81.95713043, 17.99707031], [81.96404266, 17.99986839], [81.97305298, 18.00567055], [81.98046112, 18.01128006], [81.98587799, 18.01427078], [81.98886108, 18.02034187], [81.99147797, 18.02182007], [82.0016861, 18.02366066], [82.00211334, 18.0282402], [82.00473022, 18.03430939], [82.00157928, 18.04481125], [82.00663757, 18.04919815], [82.01677704, 18.0551281], [82.0246582, 18.0578804], [82.02986145, 18.05653191], [82.03263855, 18.05171013], [82.04516602, 18.04558945], [82.05085754, 18.0444603], [82.0597229, 18.04511833], [82.06564331, 18.04891968], [82.06546783, 18.05130005], [82.06098938, 18.05398178], [82.05898285, 18.0584507], [82.06440735, 18.05837059], [82.06989288, 18.06043053], [82.07221222, 18.06563759], [82.08006287, 18.0604496], [82.0891571, 18.05741119], [82.09236145, 18.05276108], [82.10797882, 18.05401993], [82.11058807, 18.05766106], [82.11326599, 18.05782127], [82.1193161, 18.05120087], [82.12708282, 18.0510006], [82.12924194, 18.04866982], [82.13041687, 18.04090118], [82.13237, 18.03561974], [82.14229584, 18.04356956], [82.14730835, 18.04042053], [82.16034698, 18.04359818], [82.16374969, 18.04162025], [82.17314911, 18.0255928], [82.17694092, 18.02089119], [82.17424774, 18.01550293], [82.17740631, 18.01057053], [82.18508911, 18.00735283], [82.19101715, 18.00895119], [82.1969223, 18.00868988], [82.20775604, 18.00070953], [82.2181778, 17.99419022], [82.22297668, 17.99287987], [82.23079681, 17.99370956], [82.23699188, 17.99201012], [82.2383194, 17.98390007], [82.24170685, 17.97976112], [82.25318909, 17.98019028], [82.26107788, 17.98240089], [82.26725006, 17.98644066], [82.26885223, 17.99198914], [82.27052307, 17.9977417], [82.27081299, 18.01066971], [82.26893616, 18.01993942], [82.26624298, 18.02569008], [82.25815582, 18.03487015], [82.26220703, 18.03630066], [82.26460266, 18.039011], [82.2651062, 18.0430603], [82.26695251, 18.04827118], [82.27894592, 18.05492973], [82.28302765, 18.05577087], [82.28505707, 18.0594101], [82.28777313, 18.06056023], [82.29789734, 18.06196022], [82.29640198, 18.05755806], [82.29280853, 18.05433273], [82.2964859, 18.04614067], [82.30105591, 18.04404068], [82.30634308, 18.04499054], [82.30441284, 18.03961945], [82.30552673, 18.03780937], [82.30961609, 18.03842926], [82.31320953, 18.03475761], [82.3169632, 18.03602028], [82.31299591, 18.04519081], [82.31572723, 18.04668045], [82.31730652, 18.04853058], [82.31964874, 18.04857063], [82.32182312, 18.05018044], [82.3261795, 18.0465107], [82.32491302, 18.04269028], [82.32977295, 18.040411], [82.33634949, 18.04726028], [82.33692932, 18.04910088], [82.3431778, 18.0678196], [82.34194183, 18.07130051], [82.34362793, 18.07499123], [82.34316254, 18.08247948], [82.34055328, 18.08708954], [82.33466339, 18.08988762], [82.33216095, 18.09412193], [82.33248901, 18.10704994], [82.33030701, 18.11899948], [82.33535767, 18.1272583], [82.33336639, 18.14237976], [82.33825684, 18.13796043], [82.34487152, 18.13462067], [82.35756683, 18.12510109], [82.361763, 18.12919807], [82.36429596, 18.13485909], [82.36515808, 18.13966942], [82.35897827, 18.1491394], [82.34873199, 18.16183281], [82.34160614, 18.16343117], [82.33302307, 18.16341972], [82.32479095, 18.16641998], [82.31931305, 18.17143059], [82.31030273, 18.17460251], [82.30821991, 18.18128014], [82.30943298, 18.18938065], [82.30609894, 18.19565964], [82.31973267, 18.20104027], [82.33281708, 18.21578979], [82.32673645, 18.21623039], [82.32131958, 18.22245979], [82.32253265, 18.22812843], [82.33022308, 18.23134041], [82.33100891, 18.23336029], [82.33203888, 18.24012947], [82.33180237, 18.24679184], [82.33390045, 18.25229073], [82.3368988, 18.26624107], [82.34365082, 18.27165031], [82.3670578, 18.27094078], [82.37187958, 18.27410126], [82.3822403, 18.28429031], [82.38540649, 18.28909111], [82.38735199, 18.30062294], [82.393013, 18.30644035], [82.38842773, 18.3112011], [82.3843689, 18.31870079], [82.38049316, 18.31931114], [82.37510681, 18.31800079], [82.3691864, 18.31775284], [82.36524963, 18.31642914], [82.35797119, 18.30824089], [82.35456085, 18.309021], [82.34874725, 18.30615044], [82.34290314, 18.30734062], [82.34101105, 18.31065941], [82.33444214, 18.31713295], [82.33641815, 18.32011986], [82.34542084, 18.32181931], [82.35021973, 18.32891083], [82.35656738, 18.33357048], [82.36013794, 18.34370041], [82.36947632, 18.35036278], [82.3763504, 18.35326958], [82.37970734, 18.3574295], [82.37879944, 18.3616581], [82.38109589, 18.36668968], [82.38442993, 18.36911011], [82.38443756, 18.37240982], [82.37841034, 18.37813187], [82.37523651, 18.38306046], [82.37490845, 18.39281082], [82.37251282, 18.39809036], [82.36599731, 18.40335274], [82.36128998, 18.4099102], [82.36599731, 18.41301155], [82.36702728, 18.41716957], [82.37174225, 18.42016983], [82.37760162, 18.42198944], [82.38065338, 18.42642975], [82.38227081, 18.43169975], [82.39737701, 18.45160103], [82.41220093, 18.46467018], [82.42032623, 18.46988106], [82.42687225, 18.47699165], [82.42913818, 18.48514175], [82.43712616, 18.4973011], [82.44993591, 18.5114212], [82.45342255, 18.51702118], [82.47400665, 18.53683281], [82.48161316, 18.53845978], [82.48532104, 18.53370094], [82.48191833, 18.53271103], [82.47783661, 18.53153038], [82.47573853, 18.5294075], [82.48145294, 18.51506042], [82.49820709, 18.50604057], [82.49880981, 18.5032711], [82.49915314, 18.50175095], [82.50202179, 18.50173187], [82.50418091, 18.50549126], [82.50740814, 18.50807953], [82.51426697, 18.50363922], [82.51751709, 18.50563812], [82.52313232, 18.50392914], [82.52390289, 18.49929047], [82.52202606, 18.4969902], [82.52321625, 18.4935112], [82.52449799, 18.48978043], [82.52005768, 18.48726082], [82.51979065, 18.48488998], [82.51951599, 18.48251152], [82.52448273, 18.48284912], [82.52752686, 18.47772026], [82.52101135, 18.47237015], [82.52572632, 18.470541], [82.5275116, 18.46821976], [82.52176666, 18.46175957], [82.51774597, 18.45928955], [82.51676178, 18.45721054], [82.51613617, 18.45588112], [82.52319336, 18.45277977], [82.52043915, 18.45053291], [82.52120209, 18.44711113], [82.52316284, 18.44577026], [82.52670288, 18.44730949], [82.5293808, 18.44293976], [82.52879333, 18.44034004], [82.53015137, 18.43431091], [82.53308105, 18.43406105], [82.53560638, 18.43665123], [82.53900909, 18.43808937], [82.5383606, 18.44318008], [82.54421234, 18.44129944], [82.54772949, 18.44178963], [82.55011749, 18.43889046], [82.55377197, 18.43765068], [82.55107117, 18.43390083], [82.55021667, 18.42650032], [82.54605865, 18.42414284], [82.54512024, 18.41724968], [82.53968048, 18.41686821], [82.5376358, 18.41222954], [82.53591156, 18.40831947], [82.53697968, 18.4041996], [82.53968811, 18.40362167], [82.54057312, 18.40343094], [82.54032135, 18.40187073], [82.5326004, 18.39682007], [82.53230286, 18.39344978], [82.53515625, 18.3895607], [82.54234314, 18.38904953], [82.54944611, 18.38351059], [82.55172729, 18.38708115], [82.55603027, 18.38850975], [82.56521606, 18.38398933], [82.57060242, 18.38418961], [82.57556152, 18.37986946], [82.57733154, 18.37732124], [82.58080292, 18.37885094], [82.58917236, 18.37713814], [82.59364319, 18.37049103], [82.59902191, 18.37161827], [82.60050964, 18.36870956], [82.60087585, 18.36605072], [82.59768677, 18.3625927], [82.59931183, 18.35997009], [82.5976181, 18.35621834], [82.59857941, 18.35401154], [82.60566711, 18.35280991], [82.60865784, 18.35123062], [82.61128235, 18.34646034], [82.60787964, 18.34167099], [82.59915161, 18.34242058], [82.59783173, 18.34164047], [82.59651184, 18.3408699], [82.59757996, 18.33361816], [82.60031891, 18.33076096], [82.60382843, 18.32037163], [82.60214233, 18.31726074], [82.59568787, 18.3159008], [82.59229279, 18.31792068], [82.58966827, 18.3194828], [82.58863831, 18.31847954], [82.58596039, 18.3159008], [82.58325195, 18.3114109], [82.57805634, 18.30935097], [82.5764389, 18.30681038], [82.57978058, 18.30104065], [82.58107758, 18.30093956], [82.58270264, 18.30080032], [82.58783722, 18.3020401], [82.59095001, 18.29195976], [82.59031677, 18.28778076], [82.58757782, 18.2847805], [82.58558655, 18.28096008], [82.58722687, 18.27943993], [82.58840179, 18.27833939], [82.58846283, 18.27504921], [82.58428192, 18.27322006], [82.58074188, 18.27009964], [82.58318329, 18.26655006], [82.58547211, 18.26612091], [82.58724976, 18.2657795], [82.58866882, 18.26211929], [82.58920288, 18.25672913], [82.5982666, 18.25447273], [82.60076904, 18.25201988], [82.60948181, 18.24925041], [82.61181641, 18.24651146], [82.61103058, 18.24384117], [82.61341858, 18.23942947], [82.6164093, 18.23812103], [82.62039185, 18.23637009], [82.62687683, 18.22874069], [82.6288681, 18.22866058], [82.63165283, 18.22853088], [82.63716888, 18.23493004], [82.64530945, 18.24044991], [82.64758301, 18.2447319], [82.64485931, 18.25707817], [82.64910889, 18.26383972], [82.65222931, 18.2721405], [82.65648651, 18.27880096], [82.65883636, 18.28660965], [82.66493988, 18.2906208], [82.6725769, 18.29220009], [82.67539978, 18.29236984], [82.68177795, 18.29277992], [82.69032288, 18.29706955], [82.69374084, 18.29733086], [82.69809723, 18.29627037], [82.70050049, 18.29978943], [82.70169067, 18.30484009], [82.7025528, 18.30846977], [82.70670319, 18.31063271], [82.71090698, 18.31282043], [82.71726227, 18.31482124], [82.72531128, 18.31157112], [82.73432922, 18.3132515], [82.73280334, 18.3178997], [82.73781586, 18.31990051], [82.74642944, 18.31985092], [82.7506485, 18.32329941], [82.7510376, 18.3283329], [82.7544632, 18.32982063], [82.75849915, 18.32718086], [82.76184845, 18.32781029], [82.7670517, 18.33107948], [82.7714386, 18.33967972], [82.78421783, 18.35415077], [82.77790833, 18.37092018], [82.78096771, 18.37252045], [82.78761292, 18.37816048], [82.78675842, 18.38458061], [82.78748322, 18.3902092], [82.79329681, 18.39496994], [82.78739166, 18.39982033], [82.78118134, 18.3994503], [82.78160858, 18.4042511], [82.77845764, 18.40947914], [82.77620697, 18.41551971], [82.77622223, 18.41969109], [82.78710938, 18.42674065], [82.79197693, 18.4331398], [82.79917145, 18.43940163], [82.81835938, 18.43852997], [82.81874847, 18.43337059], [82.82417297, 18.4299202], [82.83014679, 18.42612076], [82.83576965, 18.42423058], [82.83634186, 18.41954041], [82.83698273, 18.4142704], [82.83978271, 18.41177177], [82.84490967, 18.40977287], [82.84863281, 18.41500854], [82.85597992, 18.41080093], [82.86296844, 18.40792084], [82.87001038, 18.40620041], [82.87706757, 18.4118309], [82.87935638, 18.41464043], [82.88461304, 18.41275978], [82.88835907, 18.40625954], [82.89077759, 18.39859962], [82.89095306, 18.39221954], [82.88490295, 18.37862015], [82.89186096, 18.36688042], [82.89852142, 18.35930061], [82.90274811, 18.35591125], [82.90838623, 18.35943031], [82.91166687, 18.35737991], [82.91513062, 18.35639954], [82.9200592, 18.3597393], [82.9276123, 18.36098862], [82.93268585, 18.35136986], [82.94550323, 18.35046959], [82.94816589, 18.35206032], [82.95204926, 18.35434914], [82.95597076, 18.35581017], [82.95979309, 18.35724068], [82.96878052, 18.35758018], [82.97644806, 18.3549118], [82.9784317, 18.36098862], [82.9812088, 18.36581993], [82.98610687, 18.36590195], [82.98761749, 18.36950111], [82.99196625, 18.37499809], [82.99286652, 18.37482071], [82.99711609, 18.37486076], [83.00348663, 18.3769207], [83.01161194, 18.37821007], [83.0171814, 18.3845005], [83.02005005, 18.38348007], [83.02375793, 18.37644958], [83.03188324, 18.3732605], [83.03697968, 18.36984253], [83.03952026, 18.37008095], [83.0533905, 18.37529945], [83.05619812, 18.37726021], [83.06582642, 18.38940048], [83.0664978, 18.3922596], [83.06582642, 18.39315987], [83.06373596, 18.39570999], [83.05903625, 18.3990097], [83.05581665, 18.40436935], [83.05531311, 18.40811157], [83.06035614, 18.41337967], [83.06046295, 18.41348839], [83.06062317, 18.41924286], [83.06208801, 18.42088127], [83.061203, 18.42394066], [83.05982971, 18.42863274], [83.05825806, 18.42905998], [83.0485611, 18.42486], [83.04261017, 18.41829109], [83.03743744, 18.41894913], [83.03555298, 18.42007065], [83.03330231, 18.42333984], [83.03819275, 18.42671013], [83.03900909, 18.43204117], [83.037323, 18.43482971], [83.032341, 18.43618965], [83.02484131, 18.43666077], [83.01803589, 18.44040108], [83.01541138, 18.4444294], [83.01644897, 18.44767952], [83.02455902, 18.45369911], [83.02672577, 18.45692062], [83.03414917, 18.46076965], [83.03701782, 18.46313095], [83.04384613, 18.47211075], [83.05179596, 18.47748947], [83.05517578, 18.48812294], [83.06035614, 18.49442101], [83.06511688, 18.4975605], [83.06881714, 18.50202942], [83.07315826, 18.51473999], [83.08230591, 18.52717018], [83.08850861, 18.53276062], [83.08933258, 18.53791046], [83.08705139, 18.54105949], [83.0714798, 18.54249191], [83.05735779, 18.53469086], [83.05414581, 18.53479958], [83.05117798, 18.5349102], [83.04509735, 18.53932953], [83.04023743, 18.54489136], [83.03247833, 18.54788971], [83.03370667, 18.55829048], [83.02545929, 18.56430054], [83.0268631, 18.56796074], [83.03114319, 18.5717907], [83.03376007, 18.57571983], [83.03650665, 18.57757187], [83.04171753, 18.5773201], [83.04203796, 18.57730293], [83.0447464, 18.57817078], [83.0511322, 18.58307076], [83.05394745, 18.58646965], [83.05297852, 18.58993912], [83.05208588, 18.59305954], [83.04946899, 18.59486961], [83.04891968, 18.59526253], [83.04110718, 18.59673119], [83.04065704, 18.59526253], [83.03970337, 18.59207916], [83.03781891, 18.58871269], [83.03114319, 18.58358955], [83.02770233, 18.58227158], [83.01586914, 18.58477974], [83.00804138, 18.58842087], [83.00948334, 18.5914402], [83.02030182, 18.60541153], [83.02126312, 18.61045074], [83.01737976, 18.62339973], [83.01461029, 18.62626076], [83.01132202, 18.62771034], [83.00934601, 18.63148117], [83.00948334, 18.63354111], [83.0096817, 18.63652992], [83.01154327, 18.63903046], [83.0226059, 18.64435959], [83.03616333, 18.64768982], [83.05097198, 18.65415955], [83.05146027, 18.6632309], [83.05584717, 18.66714096], [83.07080841, 18.68930054], [83.06987762, 18.69188118], [83.0690918, 18.69405174], [83.07073212, 18.69719124], [83.07788086, 18.70533943], [83.08574677, 18.70998001], [83.0880661, 18.71240044], [83.08960724, 18.71627045], [83.09079742, 18.71925926], [83.09259033, 18.7217617], [83.09546661, 18.72309113], [83.09921265, 18.72689056], [83.10600281, 18.73849106], [83.11650085, 18.74797058], [83.11752319, 18.75048065], [83.11219025, 18.7582798], [83.11580658, 18.76208115], [83.13295746, 18.77244949], [83.13884735, 18.77113914], [83.14491272, 18.76690102], [83.14686584, 18.76317978], [83.15083313, 18.75868988], [83.15622711, 18.75731087], [83.16854858, 18.75906944], [83.17394257, 18.75676918], [83.17701721, 18.75440979], [83.18080139, 18.74825096], [83.1853714, 18.74414253], [83.19181824, 18.74178123], [83.20170593, 18.74222946], [83.20342255, 18.74035263], [83.20188904, 18.73613167], [83.2024231, 18.73254967], [83.20626068, 18.7287426], [83.20633698, 18.72803116], [83.20641327, 18.72742081], [83.20366669, 18.72350121], [83.20332336, 18.7195797], [83.20506287, 18.71586037], [83.20677948, 18.71749115], [83.20918274, 18.72454071], [83.2125473, 18.7344799], [83.21363831, 18.73602104], [83.21446228, 18.73719978], [83.22033691, 18.74204826], [83.22235107, 18.74505043], [83.2230072, 18.74798012], [83.22268677, 18.74861908], [83.22189331, 18.75202179], [83.21733093, 18.75895119], [83.21707916, 18.76356125], [83.21939087, 18.76581955], [83.22103119, 18.76587105], [83.22271729, 18.76593018], [83.22651672, 18.76490021], [83.22931671, 18.76414108], [83.23956299, 18.75878143], [83.24508667, 18.75808907], [83.25541687, 18.75881958], [83.2593689, 18.75760078], [83.26609802, 18.75700951], [83.26991272, 18.75980949], [83.27171326, 18.76317978], [83.27124786, 18.76732063], [83.26914978, 18.77075958], [83.26992035, 18.77528763], [83.2752533, 18.78536987], [83.27950287, 18.78960037], [83.29210663, 18.79253006], [83.30036926, 18.79791069], [83.30422211, 18.79887009], [83.31404114, 18.79580116], [83.31826019, 18.79584122], [83.32302094, 18.79828072], [83.32614136, 18.79482079], [83.32978821, 18.79372978], [83.33333588, 18.7926712], [83.33587646, 18.79321289], [83.33687592, 18.79465294], [83.33761597, 18.79570007], [83.33812714, 18.80035019], [83.33927917, 18.80309105], [83.34073639, 18.8035202], [83.34429169, 18.80293083], [83.34780884, 18.80125809], [83.3524704, 18.80018997], [83.35629272, 18.8001194], [83.35848236, 18.80179977], [83.36022949, 18.80447006], [83.35999298, 18.80735016], [83.35011292, 18.82163811], [83.35349274, 18.82748985], [83.35887909, 18.83200073], [83.36032104, 18.83204079], [83.36226654, 18.83210945], [83.37283325, 18.82121086], [83.3763504, 18.82195091], [83.38313293, 18.82607079], [83.38648987, 18.82576942], [83.39630127, 18.83070946], [83.39871216, 18.83352852], [83.39694214, 18.84921074], [83.39787292, 18.85259056], [83.39985657, 18.85365105], [83.40680695, 18.85367966], [83.40875244, 18.85445023], [83.41073608, 18.85676193], [83.41133881, 18.85934067], [83.40585327, 18.86532974], [83.40432739, 18.86598015], [83.40177917, 18.86707115], [83.39425659, 18.8682003], [83.38780975, 18.87103081], [83.38539124, 18.87326241], [83.38568115, 18.87549019], [83.37890625, 18.88027954], [83.37390137, 18.88591194], [83.37248993, 18.88983917], [83.37444305, 18.89194107], [83.38326263, 18.89723969], [83.38391113, 18.89969063], [83.3809967, 18.90182114], [83.37684631, 18.90246964], [83.36715698, 18.90036011], [83.36631012, 18.9004612], [83.36052704, 18.90117073], [83.35777283, 18.9036808], [83.35649872, 18.90480995], [83.35016632, 18.91592979], [83.34768677, 18.92098808], [83.34661102, 18.92687035], [83.34792328, 18.93214035], [83.34902954, 18.9338398], [83.35523987, 18.93303108], [83.36276245, 18.93007088], [83.36406708, 18.92278862], [83.3710022, 18.91708946], [83.37384033, 18.91679192], [83.37634277, 18.91777039], [83.37966156, 18.92152023], [83.38022614, 18.92328262], [83.36741638, 18.93349075], [83.36389923, 18.93793106], [83.36084747, 18.94811058], [83.36106873, 18.95340157], [83.36022949, 18.95389938], [83.35890198, 18.95471191], [83.35440826, 18.95445061], [83.34903717, 18.95609093], [83.34575653, 18.95709991], [83.34501648, 18.95630074], [83.34480286, 18.94524956], [83.34326172, 18.93516159], [83.33983612, 18.93321991], [83.33972931, 18.93275261], [83.33952332, 18.93191147], [83.33953857, 18.9294796], [83.33957672, 18.92620087], [83.34136963, 18.91839981], [83.33905792, 18.91620064], [83.33454132, 18.91582108], [83.32901001, 18.91690826], [83.32202911, 18.9232502], [83.31991577, 18.92581749], [83.31887817, 18.92843819], [83.3184967, 18.93362045], [83.32119751, 18.93602943], [83.33113098, 18.93763924], [83.33302307, 18.93931961], [83.3324585, 18.94337082], [83.33104706, 18.94581032], [83.32888794, 18.94682121], [83.32704163, 18.94790077], [83.32601166, 18.95016289], [83.32565308, 18.95292282], [83.32691956, 18.95734024], [83.32556152, 18.95897102], [83.32055664, 18.96103096], [83.31980896, 18.96133041], [83.31334686, 18.96663094], [83.30961609, 18.9768219], [83.30914307, 18.98035049], [83.30774689, 18.98324966], [83.30432892, 18.98698997], [83.30526733, 18.98968124], [83.30783844, 18.99094963], [83.31643677, 18.99040031], [83.32537842, 18.98880959], [83.32917786, 18.98818016], [83.33120728, 18.99007034], [83.33075714, 18.99257088], [83.33010101, 18.99695969], [83.33067322, 18.99842834], [83.33271027, 18.99983978], [83.3349762, 19.00671959], [83.34091187, 19.0091629], [83.34633636, 19.0098896], [83.35498047, 19.00938988], [83.35800934, 19.00613976], [83.36232758, 18.99473], [83.36747742, 18.99361992], [83.37719727, 18.99472046], [83.38471985, 18.99727249], [83.3887558, 19.00001907], [83.39295959, 18.99912834], [83.39605713, 18.99583054], [83.40142059, 18.99638176], [83.40231323, 18.99516106], [83.4046402, 18.99320984], [83.4068985, 18.99508095], [83.40885162, 18.99619102], [83.41057587, 18.99261093], [83.41142273, 18.98871994], [83.40878296, 18.97989082], [83.4148407, 18.97787285], [83.43292236, 18.96139908], [83.43647766, 18.95787811], [83.44001007, 18.95022011], [83.44267273, 18.94774055], [83.44684601, 18.94564819], [83.45120239, 18.94445992], [83.45548248, 18.94557953], [83.46227264, 18.95922089], [83.46224213, 18.96359062], [83.46147156, 18.9679203], [83.45894623, 18.97044945], [83.45831299, 18.97247124], [83.46029663, 18.98077965], [83.4577179, 18.98250008], [83.45022583, 18.98242188], [83.44908905, 18.99261093], [83.44822693, 18.99594116], [83.44851685, 18.99963188], [83.45017242, 19.00188828], [83.45327759, 19.00246048], [83.45848083, 19.00209808], [83.46750641, 18.99891853], [83.4718399, 18.99897957], [83.47460175, 19.00031281], [83.47663879, 19.00407028], [83.47511292, 19.01152992], [83.47796631, 19.02119064], [83.47735596, 19.02551842], [83.46543884, 19.03619003], [83.46279907, 19.04395103], [83.46327209, 19.05260086], [83.45670319, 19.05611038], [83.45736694, 19.0598011], [83.45913696, 19.06348991], [83.45826721, 19.06713295], [83.45939636, 19.06967163], [83.46382904, 19.0714016], [83.46746826, 19.06987953], [83.47027588, 19.07032013], [83.47202301, 19.07274055], [83.47323608, 19.0777626], [83.47698975, 19.07533073], [83.47817993, 19.07022095], [83.48043823, 19.06648064], [83.49249268, 19.05495071], [83.49362946, 19.05308914], [83.49633026, 19.05550957], [83.50036621, 19.06208038], [83.50287628, 19.06466103], [83.50538635, 19.06477165], [83.50617981, 19.05430984], [83.50847626, 19.0499115], [83.51074982, 19.04800034], [83.50979614, 19.04008102], [83.51008606, 19.03617287], [83.51322937, 19.03032112], [83.51367188, 19.02478027], [83.50817871, 19.02197075], [83.50392914, 19.02620125], [83.49931335, 19.02708054], [83.49355316, 19.02680016], [83.49263, 19.02398109], [83.49292755, 19.01803017], [83.49539948, 19.01109123], [83.50460052, 19.01009941], [83.51529694, 19.00490952], [83.53138733, 19.00542068], [83.53311157, 19.01246071], [83.53309631, 19.01938248], [83.53482819, 19.02861977], [83.53578949, 19.03034973], [83.54277802, 19.03684044], [83.54772949, 19.04496956], [83.5522995, 19.04718971], [83.55148315, 19.05038071], [83.54486847, 19.06208038], [83.54485321, 19.06940269], [83.5464325, 19.07382965], [83.55149078, 19.07785034], [83.55497742, 19.07813072], [83.56067657, 19.06622124], [83.56038666, 19.06396103], [83.55710602, 19.05998993], [83.556427, 19.05583954], [83.55766296, 19.05138016], [83.56105042, 19.05038834], [83.56735992, 19.05225945], [83.57876587, 19.04978943], [83.58078003, 19.05514908], [83.58178711, 19.06277275], [83.5821991, 19.07563972], [83.58444977, 19.07973099], [83.58763123, 19.08307076], [83.59320831, 19.08489037], [83.59986115, 19.08480263], [83.60441589, 19.08818054], [83.60440063, 19.09287071], [83.59677887, 19.10519981], [83.59429932, 19.11058044], [83.59365082, 19.11548996], [83.59429932, 19.12033081], [83.60051727, 19.12770081], [83.60521698, 19.13103294], [83.61060333, 19.13093758], [83.61408997, 19.13381958], [83.619133, 19.14188194], [83.62271881, 19.14468765], [83.62023926, 19.14862823], [83.62116241, 19.15192032], [83.62328339, 19.15363121], [83.62850952, 19.14974022], [83.63018799, 19.14479065], [83.62844086, 19.13150024], [83.62983704, 19.12699127], [83.63331604, 19.1244297], [83.64556122, 19.12310028], [83.64943695, 19.12187958], [83.65072632, 19.11840057], [83.64974976, 19.11482048], [83.64627075, 19.11449814], [83.64472961, 19.11329079], [83.64588165, 19.10873032], [83.647789, 19.10594177], [83.6479187, 19.10225105], [83.65026855, 19.10009956], [83.65748596, 19.08777237], [83.65809631, 19.08210945], [83.65685272, 19.07493973], [83.65969849, 19.0697403], [83.66261292, 19.06649017], [83.66673279, 19.06446075], [83.67637634, 19.05245018], [83.68438721, 19.04393005], [83.69415283, 19.02114105], [83.69702148, 19.01647949], [83.69983673, 19.01503181], [83.71682739, 19.01444817], [83.72128296, 19.0134182], [83.72325134, 19.01189995], [83.71984863, 19.00428963], [83.71478271, 19.00213051], [83.70941925, 19.00195122], [83.70500183, 18.99946976], [83.70436096, 18.99530983], [83.70469666, 18.99248123], [83.70484924, 18.99200821], [83.70574188, 18.98524094], [83.70880127, 18.9838028], [83.71140289, 18.98495102], [83.71689606, 18.98253822], [83.7263031, 18.97556114], [83.72746277, 18.96607971], [83.73002625, 18.9601593], [83.73649597, 18.93897057], [83.73992157, 18.93406105], [83.74140167, 18.93029022], [83.74214935, 18.92313957], [83.74582672, 18.91817284], [83.75614929, 18.91669083], [83.7628479, 18.90653992], [83.76750183, 18.90236282], [83.77050018, 18.90159035], [83.77127075, 18.90130043], [83.77739716, 18.90439987], [83.78006744, 18.90772057], [83.77715302, 18.9190712], [83.76986694, 18.93297005], [83.76525116, 18.93642044], [83.76148224, 18.94460106], [83.75520325, 18.94202995], [83.75036621, 18.94437027], [83.74836731, 18.95137024], [83.74900055, 18.95844078], [83.74597168, 18.9632206], [83.74172211, 18.96705818], [83.73956299, 18.97844124], [83.74108124, 18.98389053], [83.74923706, 18.99067116], [83.75061798, 18.99241829], [83.75128174, 18.99328041], [83.75242615, 18.99333191], [83.75354767, 18.99316978], [83.75469208, 18.99337006], [83.75582886, 18.99361038], [83.75695801, 18.99390984], [83.75778961, 18.99455833], [83.75845337, 18.99547005], [83.75946808, 18.99605942], [83.76056671, 18.9964695], [83.76171112, 18.99677849], [83.76288605, 18.99705124], [83.76405334, 18.99731064], [83.7652359, 18.99760056], [83.7664032, 18.99795914], [83.76747894, 18.99842834], [83.76850128, 18.99908066], [83.76941681, 18.99977112], [83.77021027, 19.00059128], [83.7706604, 19.0016098], [83.77111816, 19.00263977], [83.7715683, 19.00366974], [83.77204895, 19.0046711], [83.77259827, 19.00566101], [83.77320099, 19.00658989], [83.77392578, 19.00745964], [83.77474213, 19.00824928], [83.77565002, 19.00896072], [83.77664948, 19.00951958], [83.77774048, 19.00988007], [83.77887726, 19.01000977], [83.78037262, 19.0099411], [83.78148651, 19.00979042], [83.78263855, 19.00957108], [83.78375244, 19.00933075], [83.78486633, 19.00909042], [83.7859726, 19.00878906], [83.78704071, 19.00836945], [83.78830719, 19.00781059], [83.78894806, 18.99833107], [83.79116821, 18.99235916], [83.80253601, 18.98180962], [83.80809021, 18.96840286], [83.81063843, 18.9648304], [83.81476593, 18.95317841], [83.81606293, 18.9486599], [83.8134079, 18.9335804], [83.814888, 18.93003845], [83.81890106, 18.92609978], [83.82116699, 18.92196083], [83.81693268, 18.90940285], [83.81845093, 18.90711975], [83.82305145, 18.90546036], [83.83487701, 18.90929985], [83.83772278, 18.90860939], [83.840271, 18.90406036], [83.84163666, 18.89763069], [83.8423233, 18.88824081], [83.83669281, 18.87272072], [83.83600616, 18.8691082], [83.83709717, 18.86470985], [83.84366608, 18.85140038], [83.84797668, 18.8476181], [83.85906982, 18.84301186], [83.86434174, 18.83904076], [83.86686707, 18.82345009], [83.87017822, 18.81842995], [83.87391663, 18.8177681], [83.88323975, 18.8196907], [83.88463593, 18.8178196], [83.88535309, 18.81004143], [83.88687897, 18.80540848], [83.89064026, 18.80686951], [83.89547729, 18.81487846], [83.89855194, 18.81644058], [83.90197754, 18.81692123], [83.90775299, 18.81638908], [83.92059326, 18.81157112], [83.9226532, 18.80853271], [83.9263916, 18.80656052], [83.93358612, 18.80685806], [83.93572235, 18.8031292], [83.93657684, 18.79920006], [83.93978882, 18.79660034], [83.94368744, 18.79628754], [83.94902039, 18.79704094], [83.95121002, 18.8000412], [83.95561218, 18.80306053], [83.9640274, 18.80410957], [83.96938324, 18.80382919], [83.98232269, 18.80001068], [83.991539, 18.8046627], [83.99997711, 18.8047905], [84.00739288, 18.80421066], [84.01249695, 18.80063057], [84.01586914, 18.80141068], [84.01966095, 18.79762268], [84.02231598, 18.79862976], [84.02372742, 18.80115128], [84.02706146, 18.80220032], [84.03071594, 18.80027962], [84.03077698, 18.79544067], [84.0342865, 18.79012108], [84.03871918, 18.78742981], [84.04794312, 18.78347969], [84.04760742, 18.77987289], [84.04972076, 18.77730942], [84.04804993, 18.77440262], [84.04920197, 18.77065086], [84.05355835, 18.76836967], [84.05860901, 18.76810074], [84.06046295, 18.76267052], [84.06577301, 18.75169945], [84.06989288, 18.74975967], [84.07788086, 18.74888039], [84.07933044, 18.74611092], [84.08177948, 18.74464035], [84.08557892, 18.74518013], [84.08878326, 18.74711037], [84.09163666, 18.74523926], [84.10072327, 18.75267982], [84.10758972, 18.7548008], [84.11406708, 18.7551403], [84.118927, 18.75303078], [84.12294006, 18.74826813], [84.12948608, 18.75286293], [84.12793732, 18.76126862], [84.13136292, 18.76480293], [84.13497925, 18.76678848], [84.14042664, 18.76769066], [84.14811707, 18.77176094], [84.15136719, 18.77576065], [84.15493011, 18.77601051], [84.15934753, 18.77503967], [84.16027069, 18.77231979], [84.15818787, 18.76918983], [84.16262817, 18.76856995], [84.16703033, 18.77013969], [84.1798172, 18.76897049], [84.18151093, 18.77752113], [84.18651581, 18.77960014], [84.19033813, 18.77673912], [84.2038269, 18.78264046], [84.21671295, 18.78728104], [84.22145844, 18.78647995], [84.22429657, 18.78426933], [84.22698975, 18.78716087], [84.23069, 18.78564072], [84.23116302, 18.78012085], [84.24603271, 18.7734108], [84.25218964, 18.77248192], [84.25888824, 18.77482986], [84.26422119, 18.78051949], [84.26818848, 18.78030968], [84.27321625, 18.78248978], [84.27533722, 18.78718185], [84.27854919, 18.78968048], [84.28392029, 18.79082108], [84.30036926, 18.78174019], [84.30432129, 18.78071976], [84.30716705, 18.78166008], [84.30885315, 18.77841949], [84.31249237, 18.77919006], [84.31292725, 18.78218079], [84.3157196, 18.78617096], [84.3269577, 18.78967285], [84.33222198, 18.79202271], [84.33358765, 18.79505157], [84.32952881, 18.8045311], [84.32932281, 18.80899811], [84.34410095, 18.81194115], [84.34075928, 18.81825066], [84.34243011, 18.82150841], [84.3442688, 18.8227005], [84.34516907, 18.82678032], [84.34435272, 18.8327198], [84.3380661, 18.83621979], [84.33598328, 18.84142113], [84.33413696, 18.85156059], [84.33413696, 18.85799026], [84.33442688, 18.86384964], [84.33602142, 18.86671066], [84.33979034, 18.86592102], [84.34438324, 18.86276245], [84.3469696, 18.85997963], [84.35146332, 18.85090065], [84.35411835, 18.85149956], [84.35521698, 18.85264015], [84.3583374, 18.85134125], [84.3624115, 18.85106087], [84.36933899, 18.85897064], [84.37146759, 18.86338234], [84.37156677, 18.86721992], [84.36624908, 18.87170982], [84.3613205, 18.87268066], [84.35962677, 18.87190056], [84.35382843, 18.87506294], [84.35183716, 18.87779045], [84.35144806, 18.88319969], [84.35473633, 18.88293076], [84.37135315, 18.8754406], [84.37406921, 18.87649918], [84.37808228, 18.87409973], [84.38323212, 18.86927986], [84.38622284, 18.87170982], [84.38762665, 18.87766838], [84.38609314, 18.88302994], [84.37903595, 18.88546944], [84.37422943, 18.8888607], [84.36767578, 18.88932991], [84.36490631, 18.8932209], [84.3653183, 18.89625931], [84.36976624, 18.89581108], [84.37406921, 18.89402962], [84.37845612, 18.89324188], [84.38687134, 18.88986969], [84.39396667, 18.88586998], [84.39782715, 18.88611984], [84.40981293, 18.89063072], [84.41208649, 18.89393997], [84.41072083, 18.89825821], [84.40769958, 18.90112114], [84.40615082, 18.9061203], [84.40956879, 18.90810013], [84.41796875, 18.90065956], [84.42032623, 18.90487099], [84.42938995, 18.91368294], [84.41998291, 18.92971039], [84.41713715, 18.93330193], [84.41559601, 18.93803978], [84.42030334, 18.94935989], [84.43454742, 18.96315956], [84.43772888, 18.96570969], [84.44064331, 18.96693039], [84.4347229, 18.97682953], [84.42796326, 18.98264122], [84.42640686, 18.98397064], [84.42555237, 18.989151], [84.42610931, 18.99176979], [84.42526245, 18.99534035], [84.42003632, 19.00084114], [84.41803741, 19.00498962], [84.4154129, 19.00813293], [84.41464996, 19.01235962], [84.41513062, 19.0138607], [84.42002106, 19.01251984], [84.42218781, 19.00853157], [84.42980194, 19.00118065], [84.43297577, 19.00185966], [84.43739319, 18.99745941], [84.44406128, 18.99455833], [84.44815063, 18.99173927], [84.45218658, 18.98833084], [84.46282959, 18.98328972], [84.4716568, 18.98122025], [84.47306061, 18.98264122], [84.47569275, 18.99173927], [84.47551727, 18.99603271], [84.47782898, 19.0078907], [84.48206329, 19.00990868], [84.48938751, 19.02095032], [84.49777985, 19.02487946], [84.5030899, 19.02926254], [84.5071106, 19.03544807], [84.50991821, 19.03746033], [84.52715302, 19.03871918], [84.53147125, 19.0441494], [84.53481293, 19.04536057], [84.54772186, 19.04609108], [84.5535965, 19.04740906], [84.5597229, 19.05956078], [84.56613922, 19.06503868], [84.56797028, 19.06347084], [84.56852722, 19.06064034], [84.57060242, 19.06041145], [84.57644653, 19.06456184], [84.57811737, 19.06212807], [84.57509613, 19.03753853], [84.57364655, 19.03511047], [84.57531738, 19.02719116], [84.57813263, 19.01890182], [84.58769226, 19.01299095], [84.59011841, 19.01338005], [84.59697723, 19.01974106], [84.60048676, 19.03293037], [84.60756683, 19.04540825], [84.60946655, 19.04673958], [84.61418915, 19.0467205], [84.61235809, 19.04973984], [84.61152649, 19.05373001], [84.61271667, 19.05483055], [84.62329102, 19.05566025], [84.62541199, 19.05278015], [84.62608337, 19.05029106], [84.63005829, 19.04959106], [84.63437653, 19.05554008], [84.63683319, 19.05714989], [84.64772797, 19.0560894], [84.65453339, 19.05231094], [84.65901184, 19.06364822], [84.66320038, 19.06445122], [84.66458893, 19.06629181], [84.65962219, 19.07093048], [84.65416718, 19.08101273], [84.64871216, 19.08419991], [84.64460754, 19.08445168], [84.63474274, 19.07868958], [84.63360596, 19.07463837], [84.63144684, 19.07262039], [84.62444305, 19.07442093], [84.61982727, 19.07650948], [84.61656952, 19.08520126], [84.61678314, 19.09000015], [84.6144104, 19.09231758], [84.60962677, 19.09089279], [84.6055603, 19.09263039], [84.60293579, 19.09657097], [84.59577179, 19.11520958], [84.59168243, 19.12112045], [84.59184265, 19.12384033], [84.59464264, 19.12354851], [84.60939789, 19.11745071], [84.62554932, 19.11827087], [84.62931824, 19.12070084], [84.64037323, 19.12223816], [84.64170837, 19.12478828], [84.64729309, 19.12037086], [84.65342712, 19.12290955], [84.65731812, 19.12138939], [84.66117096, 19.1218605], [84.66451263, 19.12815094], [84.66590118, 19.13527107], [84.6654129, 19.14470291], [84.66326904, 19.14748001], [84.66501617, 19.15673065], [84.66929626, 19.15568161], [84.67333221, 19.15689087], [84.67807007, 19.15346909], [84.68141174, 19.14974976], [84.69213867, 19.15170097], [84.69756317, 19.15029144], [84.7020874, 19.15114975], [84.70522308, 19.1490097], [84.70648193, 19.14356041], [84.69731903, 19.1251297], [84.69391632, 19.12155151], [84.69381714, 19.11952019], [84.69776917, 19.1156311], [84.69832611, 19.1103096], [84.69754791, 19.10881805], [84.71185303, 19.1000309], [84.71903229, 19.09584427], [84.71902466, 19.09513855], [84.72022247, 19.09513855], [84.72041321, 19.09513855], [84.72041321, 19.09505844], [84.72041321, 19.09486198], [84.7206955, 19.09486198], [84.7206955, 19.09430695], [84.72097015, 19.09431076], [84.72097015, 19.09375], [84.7206955, 19.09375], [84.7206955, 19.09291649], [84.72097015, 19.0929203], [84.72097015, 19.09208107], [84.72125244, 19.09208488], [84.72125244, 19.09180641], [84.7215271, 19.09181023], [84.7215271, 19.09152985], [84.72180176, 19.09152985], [84.72180176, 19.09124947], [84.7223587, 19.09124947], [84.7223587, 19.09097099], [84.72264099, 19.09097481], [84.72264099, 19.09041405], [84.7223587, 19.09041977], [84.7223587, 19.08986282], [84.72264099, 19.08986282], [84.72264099, 19.08958054], [84.72319794, 19.08958054], [84.72319794, 19.08986282], [84.7234726, 19.08986282], [84.7234726, 19.09013939], [84.72374725, 19.09013939], [84.72374725, 19.09041977], [84.72402954, 19.09041405], [84.72402954, 19.09069252], [84.7243042, 19.09069252], [84.7243042, 19.09041405], [84.72486115, 19.09041977], [84.72486115, 19.09013939], [84.72541809, 19.09013939], [84.72541809, 19.08986282], [84.72569275, 19.08986282], [84.72569275, 19.09013939], [84.72624969, 19.09013939], [84.72624969, 19.08986282], [84.72820282, 19.08986282], [84.72819519, 19.08958244], [84.72973633, 19.08958244], [84.7298584, 19.08958244], [84.7298584, 19.08930588], [84.73021698, 19.08930588], [84.76101685, 19.07131195], [84.76097107, 19.07097054], [84.76069641, 19.07097244], [84.76069641, 19.07069397], [84.76041412, 19.07069397], [84.76041412, 19.0704174], [84.76013947, 19.07042122], [84.76013947, 19.06986046], [84.75985718, 19.06986046], [84.75985718, 19.06958008], [84.75958252, 19.06958389], [84.75958252, 19.06930542], [84.75930786, 19.06931114], [84.75930786, 19.06875038], [84.75902557, 19.06875038], [84.75902557, 19.06847191], [84.75875092, 19.06847191], [84.75875092, 19.06819534], [84.75846863, 19.06820107], [84.75846863, 19.0676403], [84.7582016, 19.0676403], [84.7582016, 19.06680107], [84.75791931, 19.06680679], [84.75791931, 19.06597137], [84.75763702, 19.06597137], [84.75763702, 19.06569672], [84.75736237, 19.06569672], [84.75736237, 19.06541634], [84.75708008, 19.06542969], [84.75708008, 19.06513977], [84.75680542, 19.06513977], [84.75680542, 19.0648613], [84.75624847, 19.0648613], [84.75624847, 19.06458473], [84.75597382, 19.06458473], [84.75597382, 19.06402779], [84.75569153, 19.06402969], [84.75569153, 19.06375122], [84.75543213, 19.06375122], [84.75543213, 19.06347084], [84.75514221, 19.06347466], [84.75514221, 19.06263924], [84.75485992, 19.06264114], [84.75485992, 19.06153107], [84.7545929, 19.06153107], [84.7545929, 19.06125259], [84.75430298, 19.06125259], [84.75430298, 19.06097031], [84.75402832, 19.06097031], [84.75402832, 19.06069374], [84.75375366, 19.06069374], [84.75375366, 19.05986023], [84.75347137, 19.05986023], [84.75347137, 19.05958176], [84.75319672, 19.05958366], [84.75319672, 19.05930519], [84.75291443, 19.05930519], [84.75291443, 19.05902863], [84.75263977, 19.05903244], [84.75263977, 19.05874825], [84.75235748, 19.05874825], [84.75235748, 19.05846977], [84.75208282, 19.05847168], [84.75208282, 19.05791664], [84.75180817, 19.05791855], [84.75180817, 19.05763817], [84.75125122, 19.05763817], [84.75125122, 19.05708122], [84.75096893, 19.05708313], [84.75096893, 19.05680466], [84.75069427, 19.05680466], [84.75069427, 19.05624962], [84.75041962, 19.05625916], [84.75041962, 19.05541992], [84.75013733, 19.05541992], [84.75013733, 19.05513954], [84.74986267, 19.05513954], [84.74986267, 19.05486107], [84.74958038, 19.05486107], [84.74958038, 19.05430984], [84.7492981, 19.05430984], [84.7492981, 19.05402946], [84.74903107, 19.05402946], [84.74903107, 19.05375099], [84.74874878, 19.05375099], [84.74874878, 19.05319977], [84.74846649, 19.05319977], [84.74846649, 19.05291939], [84.74791718, 19.05291939], [84.74791718, 19.05264091], [84.74764252, 19.05264091], [84.74764252, 19.05236053], [84.74736023, 19.05236053], [84.74736023, 19.05181122], [84.7470932, 19.05181122], [84.7470932, 19.05125046], [84.74680328, 19.05125046], [84.74680328, 19.05070114], [84.74652863, 19.0506897], [84.74652863, 19.04958153], [84.74624634, 19.04958153], [84.74624634, 19.04847145], [84.74597168, 19.04847145], [84.74597168, 19.04819489], [84.74541473, 19.04819489], [84.74541473, 19.04791641], [84.74514008, 19.04792023], [84.74514008, 19.04764175], [84.74485779, 19.04764175], [84.74485779, 19.04735947], [84.74430847, 19.04736137], [84.74430847, 19.0470829], [84.74402618, 19.0470829], [84.74402618, 19.04680634], [84.74346924, 19.04681015], [84.74346924, 19.04624939], [84.74319458, 19.04624939], [84.74319458, 19.04541588], [84.74236298, 19.0454216], [84.74236298, 19.04458046], [84.74208069, 19.04458427], [84.74208069, 19.0443058], [84.74180603, 19.04432106], [84.74180603, 19.04375076], [84.74124908, 19.04375076], [84.74124908, 19.04347038], [84.74097443, 19.04347229], [84.74097443, 19.04319382], [84.74069214, 19.04319382], [84.74069214, 19.04291725], [84.74041748, 19.04291916], [84.74041748, 19.04207993], [84.74013519, 19.04208374], [84.74013519, 19.04125023], [84.73986053, 19.04125977], [84.73986053, 19.04042053], [84.73958588, 19.04042053], [84.73958588, 19.03985977], [84.73930359, 19.03986168], [84.73930359, 19.03930664], [84.73902893, 19.03930664], [84.73902893, 19.03902817], [84.73847198, 19.03903008], [84.73847198, 19.03874969], [84.73821259, 19.03874969], [84.73791504, 19.03874969], [84.73791504, 19.03847313], [84.73764038, 19.03847313], [84.73764038, 19.03791428], [84.73706818, 19.03792], [84.73706818, 19.03763962], [84.73652649, 19.03763962], [84.73652649, 19.03736115], [84.73625183, 19.03736115], [84.73625183, 19.03680992], [84.73596954, 19.03680992], [84.73596954, 19.03652954], [84.73568726, 19.03652954], [84.73568726, 19.03625107], [84.73542023, 19.03625107], [84.73542023, 19.03569031], [84.73513794, 19.03569221], [84.73513794, 19.03513908], [84.73486328, 19.03513908], [84.73486328, 19.03486061], [84.73430634, 19.03486061], [84.73430634, 19.0340271], [84.73400879, 19.03403282], [84.73400879, 19.03347015], [84.73347473, 19.03347015], [84.73347473, 19.03319359], [84.73319244, 19.03319359], [84.73319244, 19.03291702], [84.73291779, 19.03292274], [84.73291779, 19.03264236], [84.73264313, 19.03264236], [84.73264313, 19.03235817], [84.73236084, 19.03236008], [84.73236084, 19.03124809], [84.73208618, 19.03124809], [84.73208618, 19.03096962], [84.73180389, 19.03097153], [84.73180389, 19.03069496], [84.73152924, 19.03070068], [84.73152924, 19.0304184], [84.73126221, 19.0304184], [84.73126221, 19.03013992], [84.73069763, 19.03013992], [84.73069763, 19.02985954], [84.73041534, 19.02986145], [84.73041534, 19.02930641], [84.73014069, 19.02932167], [84.73014069, 19.02902985], [84.7298584, 19.02902985], [84.7298584, 19.02874947], [84.72957611, 19.02874947], [84.72957611, 19.02847099], [84.72930908, 19.0284729], [84.72930908, 19.02791786], [84.72875214, 19.02791977], [84.72875214, 19.02680969], [84.72820282, 19.02680969], [84.72820282, 19.02626038], [84.7279129, 19.02626038], [84.7279129, 19.02597046], [84.72763824, 19.02597237], [84.72763824, 19.0256958], [84.72736359, 19.0256958], [84.72736359, 19.02513885], [84.72680664, 19.02514076], [84.72680664, 19.02486038], [84.72651672, 19.02486038], [84.72651672, 19.02458], [84.72624969, 19.02458572], [84.72624969, 19.02430344], [84.72598267, 19.02431107], [84.72598267, 19.02375031], [84.72569275, 19.02375031], [84.72569275, 19.02346039], [84.72569275, 19.02291679], [84.72558594, 19.0229187], [84.72541809, 19.02292061], [84.72541809, 19.02264023], [84.72512817, 19.02264023], [84.72512817, 19.02235985], [84.72486115, 19.02236366], [84.72486115, 19.02180481], [84.7243042, 19.02180481], [84.7243042, 19.02152824], [84.72402954, 19.02153015], [84.72402954, 19.02069283], [84.72374725, 19.02069473], [84.72374725, 19.02041626], [84.7234726, 19.02042007], [84.7234726, 19.02025986], [84.7234726, 19.02013969], [84.72303009, 19.02013969], [84.72291565, 19.02013969], [84.72291565, 19.01985931], [84.72264099, 19.01985931], [84.72264099, 19.0193119], [84.7223587, 19.0193119], [84.7223587, 19.01874924], [84.72206879, 19.01874924], [84.72206879, 19.01847076], [84.72180176, 19.01847267], [84.72180176, 19.0181942], [84.7215271, 19.0181942], [84.7215271, 19.01763916], [84.72125244, 19.01763916], [84.72125244, 19.01736069], [84.72097015, 19.01736069], [84.72097015, 19.01680756], [84.72070313, 19.01680756], [84.72070313, 19.01652908], [84.72041321, 19.01652908], [84.72041321, 19.01625061], [84.71985626, 19.01625061], [84.71985626, 19.01597023], [84.7195816, 19.01597214], [84.7195816, 19.01458359], [84.71930695, 19.01458359], [84.71930695, 19.01430511], [84.71875, 19.01432037], [84.71875, 19.01403046], [84.71819305, 19.01403046], [84.71819305, 19.01375008], [84.7179184, 19.01375008], [84.7179184, 19.01320076], [84.71763611, 19.01320076], [84.71763611, 19.01264], [84.71736145, 19.01264], [84.71736145, 19.01235962], [84.71708679, 19.01236153], [84.71708679, 19.01208305], [84.7168045, 19.01208305], [84.7168045, 19.01180649], [84.7159729, 19.0118103], [84.7159729, 19.01124954], [84.71569824, 19.01124954], [84.71569061, 19.01069069], [84.71541595, 19.0106926], [84.71541595, 19.01041412], [84.71485901, 19.01041985], [84.71485901, 19.01013947], [84.71457672, 19.01013947], [84.71457672, 19.00958061], [84.71430206, 19.00958443], [84.71430206, 19.00930405], [84.7140274, 19.00930977], [84.7140274, 19.00847054], [84.71375275, 19.00847054], [84.71375275, 19.00819206], [84.71347046, 19.00819206], [84.71347046, 19.0079174], [84.71318817, 19.00792122], [84.71318817, 19.00764275], [84.71289825, 19.00764275], [84.71289825, 19.00736046], [84.71263885, 19.00736046], [84.71263885, 19.00681114], [84.71235657, 19.00681114], [84.71235657, 19.00653267], [84.71208191, 19.00653267], [84.71208191, 19.00597191], [84.71180725, 19.00597191], [84.71180725, 19.00569534], [84.71151733, 19.00570107], [84.71151733, 19.00542068], [84.71098328, 19.00542068], [84.71098328, 19.00515175], [84.71069336, 19.00515175], [84.71069336, 19.00485992], [84.71013641, 19.00486183], [84.71013641, 19.00402832], [84.70986176, 19.00402832], [84.70986176, 19.00346947], [84.70930481, 19.00347137], [84.70930481, 19.00319481], [84.70903015, 19.00319481], [84.70903015, 19.00263977], [84.70874786, 19.00263977], [84.70874786, 19.00209045], [84.70847321, 19.00209045], [84.70847321, 19.00152969], [84.70819092, 19.00152969], [84.70819092, 19.00041962], [84.70791626, 19.00041962], [84.70791626, 19.00014114], [84.70791626, 18.99986076], [84.70791626, 18.99958038], [84.7076416, 18.9995842], [84.7076416, 18.99930573], [84.70735931, 18.99930954], [84.70735931, 18.99875069], [84.70708466, 18.99875069], [84.70708466, 18.99847221], [84.70680237, 18.99847221], [84.70680237, 18.99819565], [84.70652771, 18.99819565], [84.70652771, 18.9976387], [84.70625305, 18.99764061], [84.70625305, 18.99736023], [84.70597076, 18.99736023], [84.70597076, 18.99707985], [84.70569611, 18.99708557], [84.70569611, 18.99652863], [84.70540619, 18.99653053], [84.70540619, 18.99625015], [84.70513916, 18.99625015], [84.70513916, 18.99596024], [84.7048645, 18.99597359], [84.7048645, 18.99541664], [84.70458221, 18.99542046], [84.70458221, 18.99514008], [84.70430756, 18.99514008], [84.70430756, 18.9948597], [84.70402527, 18.99486351], [84.70402527, 18.99430466], [84.70375061, 18.99430466], [84.70375061, 18.99402809], [84.70347595, 18.99403191], [84.70347595, 18.99346924], [84.70319366, 18.99347115], [84.70319366, 18.99319458], [84.70291901, 18.99319458], [84.70291901, 18.99263954], [84.70263672, 18.99263954], [84.70263672, 18.99235916], [84.70236206, 18.99235916], [84.70236206, 18.99208069], [84.70207977, 18.9920826], [84.70207977, 18.99152756], [84.70181274, 18.99153137], [84.70181274, 18.99124908], [84.70153046, 18.99124908], [84.70153046, 18.99097061], [84.70124817, 18.99097252], [84.70124817, 18.99041748], [84.70095825, 18.99041748], [84.70095825, 18.99014854], [84.70069122, 18.99014854], [84.70069122, 18.98986053], [84.70041656, 18.98986053], [84.70041656, 18.98958015], [84.70014191, 18.98958397], [84.70014191, 18.98902893], [84.69985962, 18.98903084], [84.69985962, 18.98875046], [84.69957733, 18.98875046], [84.69957733, 18.98847008], [84.69930267, 18.98847198], [84.69930267, 18.98819542], [84.69902802, 18.9881897], [84.69902802, 18.98791885], [84.69875336, 18.98792076], [84.69875336, 18.98736], [84.69847107, 18.98736191], [84.69847107, 18.98708344], [84.69819641, 18.98708344], [84.69819641, 18.98680687], [84.69789886, 18.98681068], [84.69789886, 18.9865303], [84.69763947, 18.9865303], [84.69763947, 18.98596954], [84.69736481, 18.98597145], [84.69736481, 18.98569679], [84.69708252, 18.98569679], [84.69708252, 18.98541641], [84.69680786, 18.98542023], [84.69680786, 18.98513985], [84.6965332, 18.98513985], [84.6965332, 18.98458099], [84.69625092, 18.98458481], [84.69625092, 18.98430634], [84.69596863, 18.98431015], [84.69596863, 18.98402023], [84.69569397, 18.98402786], [84.69569397, 18.98374939], [84.69541931, 18.98374939], [84.69541931, 18.98319054], [84.69513702, 18.98319244], [84.69513702, 18.98291588], [84.69486237, 18.98291969], [84.69486237, 18.98264122], [84.69458008, 18.98264122], [84.69458008, 18.98208046], [84.69430542, 18.98208237], [84.69430542, 18.9818058], [84.69403076, 18.98180962], [84.69403076, 18.98153114], [84.69374847, 18.98153114], [84.69374847, 18.98125267], [84.69346619, 18.98125267], [84.69346619, 18.98069191], [84.69319153, 18.98069382], [84.69319153, 18.98041725], [84.69291687, 18.98042107], [84.69291687, 18.98014259], [84.69264221, 18.98014259], [84.69264221, 18.97986031], [84.69235992, 18.97986031], [84.69235992, 18.9793129], [84.6920929, 18.9793129], [84.6920929, 18.97903252], [84.69180298, 18.97903252], [84.69180298, 18.97874832], [84.69152832, 18.97874832], [84.69152832, 18.97821045], [84.69124603, 18.97821045], [84.69124603, 18.97792053], [84.69097137, 18.97792053], [84.69097137, 18.97763824], [84.69069672, 18.97763824], [84.69069672, 18.97707939], [84.69041443, 18.97708321], [84.69041443, 18.97680473], [84.69013977, 18.97680473], [84.69013977, 18.97624969], [84.68985748, 18.97624969], [84.68985748, 18.97597122], [84.68958282, 18.97597313], [84.68958282, 18.97541618], [84.68930817, 18.97541809], [84.68930817, 18.97513962], [84.68901825, 18.97513962], [84.68901825, 18.9748497], [84.68875122, 18.97486115], [84.68875122, 18.97430611], [84.68846893, 18.97430992], [84.68846893, 18.97375107], [84.68818665, 18.97375107], [84.68818665, 18.97319031], [84.68791962, 18.97319412], [84.68791962, 18.97291756], [84.68763733, 18.97291946], [84.68763733, 18.97236061], [84.68736267, 18.97236061], [84.68736267, 18.97264099], [84.68708038, 18.97264099], [84.68708038, 18.97236061], [84.68680573, 18.97236061], [84.68680573, 18.97180557], [84.68653107, 18.97180557], [84.68653107, 18.97208595], [84.68597412, 18.97208595], [84.68597412, 18.97180557], [84.68569183, 18.97180939], [84.68569183, 18.97153091], [84.68541718, 18.97153091], [84.68541718, 18.97097015], [84.68486023, 18.97097206], [84.68486023, 18.9706955], [84.68458557, 18.9706955], [84.68458557, 18.97041702], [84.68430328, 18.97042084], [84.68430328, 18.97014046], [84.68402863, 18.97014046], [84.68402863, 18.96986008], [84.68374634, 18.96986389], [84.68374634, 18.9695816], [84.68347168, 18.9695816], [84.68347168, 18.96930313], [84.68319702, 18.96930313], [84.68319702, 18.9695816], [84.67485809, 18.9695816], [84.67485809, 18.96986389], [84.67401886, 18.96986008], [84.67401886, 18.97014046], [84.67318726, 18.97014046], [84.67318726, 18.97042084], [84.67263794, 18.97041702], [84.67263794, 18.9706955], [84.67236328, 18.9706955], [84.67236328, 18.97041702], [84.67041779, 18.97042084], [84.67041779, 18.97014046], [84.66986084, 18.97014046], [84.66986084, 18.96986008], [84.66958618, 18.96986389], [84.66958618, 18.9695816], [84.66874695, 18.9695816], [84.66874695, 18.96930313], [84.66847229, 18.96931076], [84.66847229, 18.96903992], [84.66792297, 18.96903992], [84.66792297, 18.96875191], [84.66764069, 18.96875191], [84.66764069, 18.96820068], [84.6673584, 18.96820068], [84.6673584, 18.9679203], [84.66707611, 18.9679203], [84.66707611, 18.96764183], [84.66680908, 18.96764183], [84.66680908, 18.96735954], [84.66652679, 18.96736336], [84.66652679, 18.96708107], [84.66625214, 18.96708107], [84.66625214, 18.96680641], [84.66596985, 18.96681023], [84.66596985, 18.96653175], [84.6654129, 18.96653175], [84.6654129, 18.96624947], [84.66513824, 18.96624947], [84.66513824, 18.96598053], [84.66484833, 18.96598053], [84.66484833, 18.96569061], [84.6645813, 18.96569443], [84.6645813, 18.96430588], [84.66430664, 18.9643116], [84.66430664, 18.96375084], [84.66401672, 18.96375084], [84.66401672, 18.96181107], [84.66374969, 18.96181107], [84.66374969, 18.96153069], [84.66401672, 18.96153069], [84.66401672, 18.96125031], [84.6645813, 18.96125031], [84.6645813, 18.96153069], [84.66484833, 18.96153069], [84.66484833, 18.96181107], [84.66570282, 18.96181107], [84.66570282, 18.96125031], [84.66596985, 18.96125031], [84.66596985, 18.95792007], [84.66625214, 18.95792007], [84.66625214, 18.95763969], [84.66652679, 18.95763969], [84.66652679, 18.95736122], [84.6673584, 18.95736122], [84.6673584, 18.95708084], [84.66791534, 18.95708466], [84.66791534, 18.95736122], [84.66874695, 18.95736122], [84.66874695, 18.95763969], [84.66929626, 18.95763969], [84.66929626, 18.95792007], [84.66958618, 18.95791626], [84.66958618, 18.95819664], [84.66986084, 18.95819664], [84.66986084, 18.9584713], [84.6701355, 18.9584713], [84.6701355, 18.95874977], [84.67041779, 18.95874977], [84.67041779, 18.95903015], [84.67069244, 18.95902824], [84.67069244, 18.95930672], [84.67097473, 18.95930672], [84.67097473, 18.95958328], [84.67124939, 18.95958328], [84.67124939, 18.95986176], [84.67151642, 18.95985031], [84.67151642, 18.96014023], [84.67180634, 18.96014023], [84.67180634, 18.96042061], [84.67208099, 18.96042061], [84.67208099, 18.96070099], [84.67236328, 18.96069527], [84.67236328, 18.96097183], [84.67263794, 18.96096992], [84.67263794, 18.96125031], [84.67292023, 18.96125031], [84.67292023, 18.96181107], [84.67346954, 18.96180534], [84.67346954, 18.96208382], [84.67375183, 18.96208382], [84.67375183, 18.96319389], [84.67402649, 18.96319389], [84.67402649, 18.96347237], [84.67430878, 18.96347046], [84.67430878, 18.96375084], [84.67457581, 18.96375084], [84.67457581, 18.96402931], [84.67542267, 18.96402931], [84.67542267, 18.9643116], [84.67569733, 18.96430588], [84.67569733, 18.96458244], [84.67597198, 18.96458054], [84.67597198, 18.96542168], [84.67624664, 18.96541595], [84.67624664, 18.96569443], [84.67652893, 18.96569061], [84.67652893, 18.96598053], [84.67678833, 18.96598053], [84.67678833, 18.96624947], [84.67707825, 18.96624947], [84.67707825, 18.96653175], [84.67764282, 18.96653175], [84.67764282, 18.96681023], [84.67791748, 18.96680641], [84.67791748, 18.96708107], [84.67819214, 18.96708107], [84.67819214, 18.96736336], [84.67930603, 18.96735954], [84.67930603, 18.96764183], [84.67986298, 18.96764183], [84.67986298, 18.9679203], [84.68015289, 18.9679203], [84.68015289, 18.96820068], [84.67986298, 18.96819305], [84.67986298, 18.96847153], [84.68013763, 18.96847153], [84.68013763, 18.96875191], [84.68180847, 18.96875191], [84.68180847, 18.96846962], [84.68208313, 18.96847153], [84.68208313, 18.96819305], [84.68264008, 18.96820068], [84.68264008, 18.9679203], [84.68292236, 18.9679203], [84.68292236, 18.96764183], [84.68321228, 18.96764183], [84.68321228, 18.96681023], [84.68292236, 18.96681023], [84.68292236, 18.96653175], [84.68264008, 18.96653175], [84.68264008, 18.96624947], [84.68235779, 18.96624947], [84.68235779, 18.96598053], [84.68208313, 18.96598053], [84.68208313, 18.96569061], [84.68180847, 18.96569443], [84.68180847, 18.96541595], [84.68152618, 18.96542168], [84.68152618, 18.96513939], [84.68125153, 18.96513939], [84.68125153, 18.96486092], [84.68096924, 18.96486092], [84.68096924, 18.96458054], [84.68069458, 18.96458244], [84.68069458, 18.96430588], [84.68041992, 18.9643116], [84.68041992, 18.96402931], [84.68015289, 18.96402931], [84.68015289, 18.96375084], [84.67986298, 18.96375084], [84.67986298, 18.96347046], [84.67958069, 18.96347237], [84.67958069, 18.96319389], [84.67930603, 18.96319389], [84.67930603, 18.96291733], [84.67903137, 18.96291733], [84.67903137, 18.96263885], [84.67874908, 18.96264076], [84.67874908, 18.96208], [84.67847443, 18.96208382], [84.67847443, 18.96180534], [84.67819214, 18.96181107], [84.67819214, 18.96153069], [84.67791748, 18.96153069], [84.67791748, 18.96125031], [84.67763519, 18.96125031], [84.67763519, 18.96097183], [84.67736053, 18.96097183], [84.67736053, 18.96069527], [84.67707825, 18.96070099], [84.67707825, 18.96042061], [84.67678833, 18.96042061], [84.67678833, 18.96014023], [84.67652893, 18.96014023], [84.67652893, 18.95985031], [84.67624664, 18.95986176], [84.67624664, 18.95958328], [84.67597198, 18.95958328], [84.67597198, 18.95930672], [84.67569733, 18.95930672], [84.67569733, 18.95902824], [84.67514038, 18.95903015], [84.67514038, 18.95874977], [84.67457581, 18.95874977], [84.67457581, 18.95846939], [84.67430878, 18.9584713], [84.67430878, 18.95819664], [84.67402649, 18.95819664], [84.67402649, 18.95763969], [84.67375183, 18.95763969], [84.67375183, 18.95708084], [84.67346954, 18.95708466], [84.67346954, 18.95680618], [84.67318726, 18.95681], [84.67318726, 18.95625114], [84.67208099, 18.95625114], [84.67208099, 18.95597076], [84.67152405, 18.95597458], [84.67152405, 18.95569229], [84.67124939, 18.95569229], [84.67124939, 18.95541763], [84.67098236, 18.95541954], [84.67098236, 18.95486069], [84.67069244, 18.95486069], [84.67069244, 18.95430946], [84.67041779, 18.95430946], [84.67041779, 18.95375252], [84.6701355, 18.95375252], [84.6701355, 18.95319366], [84.66986084, 18.95319366], [84.66986084, 18.95263863], [84.66958618, 18.95264244], [84.66958618, 18.95207977], [84.66930389, 18.95208359], [84.66930389, 18.95152855], [84.66902924, 18.95152855], [84.66902924, 18.95124817], [84.66874695, 18.95124817], [84.66874695, 18.9509697], [84.66847229, 18.9509716], [84.66847229, 18.95069504], [84.66792297, 18.95070076], [84.66792297, 18.95041847], [84.66764069, 18.95041847], [84.66764069, 18.95013809], [84.6673584, 18.95013809], [84.6673584, 18.94985962], [84.66708374, 18.94986153], [84.66708374, 18.94958305], [84.66680908, 18.94958305], [84.66680908, 18.94930649], [84.66625214, 18.9493103], [84.66625214, 18.94902992], [84.66596985, 18.94902992], [84.66596985, 18.94874954], [84.66569519, 18.94874954], [84.66569519, 18.94847298], [84.6654129, 18.94847298], [84.6654129, 18.9481945], [84.66513824, 18.9481945], [84.66513824, 18.94791794], [84.6645813, 18.94791794], [84.6645813, 18.94763947], [84.66430664, 18.94763947], [84.66430664, 18.94736099], [84.66401672, 18.94736099], [84.66401672, 18.94708061], [84.66374969, 18.94708252], [84.66374969, 18.94680786], [84.66348267, 18.94680977], [84.66348267, 18.94652939], [84.66291809, 18.94652939], [84.66291809, 18.94625092], [84.6626358, 18.94625092], [84.6626358, 18.94597054], [84.66236115, 18.94597244], [84.66236115, 18.94569588], [84.66208649, 18.94569588], [84.66208649, 18.9454174], [84.66178894, 18.94542122], [84.66178894, 18.94514084], [84.66124725, 18.94514084], [84.66124725, 18.94485283], [84.6609726, 18.94486046], [84.6609726, 18.9445858], [84.66069794, 18.9445858], [84.66069794, 18.94430542], [84.66042328, 18.94431114], [84.66042328, 18.94403076], [84.66014099, 18.94403076], [84.66014099, 18.94375038], [84.6598587, 18.94375038], [84.6598587, 18.94347], [84.65958405, 18.94347382], [84.65958405, 18.94319534], [84.65930176, 18.94320107], [84.65930176, 18.94292068], [84.65875244, 18.94292068], [84.65875244, 18.9426403], [84.65847015, 18.9426403], [84.65847015, 18.94235992], [84.6581955, 18.94236374], [84.6581955, 18.94208145], [84.65791321, 18.94208145], [84.65791321, 18.94180489], [84.65763855, 18.94181061], [84.65763855, 18.94153023], [84.65735626, 18.94153023], [84.65735626, 18.94124985], [84.6570816, 18.94124985], [84.6570816, 18.94096947], [84.65680695, 18.94097137], [84.65680695, 18.94069481], [84.65652466, 18.94069481], [84.65652466, 18.94041634], [84.65598297, 18.94042015], [84.65598297, 18.94014168], [84.65569305, 18.94014168], [84.65569305, 18.93985939], [84.6554184, 18.93985939], [84.6554184, 18.93958282], [84.65513611, 18.93958282], [84.65513611, 18.93930626], [84.65486145, 18.93931007], [84.65486145, 18.9390316], [84.65458679, 18.9390316], [84.65458679, 18.93874931], [84.65429688, 18.93874931], [84.65429688, 18.93847084], [84.65402985, 18.93847275], [84.65402985, 18.93819427], [84.65374756, 18.93819427], [84.65374756, 18.9379158], [84.6534729, 18.93792152], [84.6534729, 18.93763924], [84.65290833, 18.93763924], [84.65290833, 18.93736076], [84.6526413, 18.93736076], [84.6526413, 18.93708038], [84.65235901, 18.9370842], [84.65235901, 18.93680573], [84.65207672, 18.93680763], [84.65207672, 18.93652916], [84.65180206, 18.93652916], [84.65180206, 18.93625069], [84.6515274, 18.93625069], [84.6515274, 18.93597031], [84.65125275, 18.93597221], [84.65125275, 18.93569374], [84.65097046, 18.93569374], [84.65097046, 18.93541718], [84.6506958, 18.93541908], [84.6506958, 18.93514061], [84.65040588, 18.93514061], [84.65040588, 18.93486023], [84.65013885, 18.93486023], [84.65013885, 18.93457985], [84.64958191, 18.93458366], [84.64958191, 18.93430519], [84.64930725, 18.93431091], [84.64930725, 18.93403053], [84.64901733, 18.93403053], [84.64901733, 18.93375015], [84.64875031, 18.93375015], [84.64875031, 18.93346977], [84.64847565, 18.93347168], [84.64847565, 18.93319511], [84.64819336, 18.93320084], [84.64819336, 18.93291092], [84.6479187, 18.93291664], [84.6479187, 18.93263817], [84.64763641, 18.93264008], [84.64763641, 18.9323597], [84.64736176, 18.9323616], [84.64736176, 18.93208313], [84.6470871, 18.93208313], [84.6470871, 18.93180656], [84.64680481, 18.93180656], [84.64680481, 18.93152809], [84.64653015, 18.93153], [84.64653015, 18.93124962], [84.64597321, 18.93124962], [84.64597321, 18.93097115], [84.64569092, 18.93097305], [84.64569092, 18.93069458], [84.64541626, 18.93069458], [84.64541626, 18.9304142], [84.6451416, 18.93041992], [84.6451416, 18.93013954], [84.64485931, 18.93013954], [84.64485931, 18.92987061], [84.64457703, 18.92987061], [84.64457703, 18.92958069], [84.64430237, 18.9295845], [84.64430237, 18.92930603], [84.64404297, 18.92930984], [84.64404297, 18.92902946], [84.64375305, 18.92902946], [84.64375305, 18.9287529], [84.64347076, 18.9287529], [84.64347076, 18.92847061], [84.64319611, 18.92847061], [84.64319611, 18.92819214], [84.64291382, 18.92819214], [84.64291382, 18.92791748], [84.64263916, 18.92791939], [84.64263916, 18.92764282], [84.64208221, 18.92764282], [84.64208221, 18.92736053], [84.64180756, 18.92736053], [84.64180756, 18.92708015], [84.64152527, 18.92708206], [84.64152527, 18.9268055], [84.64125061, 18.92681122], [84.64125061, 18.92653275], [84.64096832, 18.92653275], [84.64096832, 18.92625237], [84.64068604, 18.92625237], [84.64068604, 18.92597008], [84.64041901, 18.92597008], [84.64041901, 18.92569542], [84.64013672, 18.9256897], [84.64013672, 18.92541695], [84.63986206, 18.92542267], [84.63986206, 18.92525101], [84.63986206, 18.92513847], [84.63957977, 18.92513847], [84.63957977, 18.92485809], [84.63874817, 18.92486191], [84.63874817, 18.92458344], [84.63847351, 18.92458344], [84.63847351, 18.92430496], [84.63819122, 18.92431068], [84.63819122, 18.9240284], [84.63790894, 18.9240284], [84.63790894, 18.92346954], [84.63764191, 18.92347145], [84.63764191, 18.92319489], [84.63735962, 18.92319489], [84.63735962, 18.92291641], [84.63707733, 18.92291832], [84.63707733, 18.92263985], [84.63680267, 18.92263985], [84.63680267, 18.92235947], [84.63652802, 18.92236137], [84.63652802, 18.9220829], [84.63625336, 18.9220829], [84.63625336, 18.92180634], [84.63597107, 18.92180824], [84.63597107, 18.92152977], [84.63569641, 18.92152977], [84.63569641, 18.92124939], [84.63540649, 18.92124939], [84.63540649, 18.92097092], [84.63513947, 18.92097282], [84.63513947, 18.92069435], [84.63458252, 18.92069435], [84.63458252, 18.92041779], [84.63430786, 18.92041969], [84.63430786, 18.92014122], [84.6340332, 18.92014122], [84.6340332, 18.91986084], [84.63375092, 18.91986084], [84.63375092, 18.91958046], [84.63346863, 18.91958046], [84.63346863, 18.91986084], [84.63318634, 18.91986084], [84.63318634, 18.91958046], [84.63291931, 18.91958427], [84.63291931, 18.91875076], [84.63263702, 18.91875076], [84.63263702, 18.91819], [84.63236237, 18.91819572], [84.63236237, 18.91791725], [84.63208008, 18.9179306], [84.63208008, 18.91764069], [84.63181305, 18.91764069], [84.63181305, 18.91707993], [84.63153076, 18.91708565], [84.63153076, 18.91680336], [84.63124847, 18.91681099], [84.63124847, 18.91653061], [84.63096619, 18.91653061], [84.63096619, 18.91625023], [84.63014221, 18.91625023], [84.63014221, 18.91596985], [84.62958527, 18.91597366], [84.62958527, 18.91569519], [84.62902832, 18.91570091], [84.62902832, 18.91542053], [84.62874603, 18.91542053], [84.62874603, 18.91514015], [84.62819672, 18.91514015], [84.62819672, 18.91487122], [84.6279068, 18.91487122], [84.6279068, 18.91457939], [84.62763977, 18.9145813], [84.62763977, 18.91430473], [84.62735748, 18.91430473], [84.62735748, 18.91402817], [84.62708282, 18.91403008], [84.62708282, 18.91374969], [84.62680817, 18.91374969], [84.62680817, 18.91346931], [84.62652588, 18.91347122], [84.62652588, 18.91291618], [84.62625122, 18.91292191], [84.62625122, 18.91264153], [84.62596893, 18.91264153], [84.62596893, 18.91208076], [84.62569427, 18.91208267], [84.62569427, 18.91180611], [84.62541962, 18.91180611], [84.62541962, 18.91152763], [84.62513733, 18.91153145], [84.62513733, 18.91124916], [84.62486267, 18.91124916], [84.62486267, 18.91097069], [84.62458038, 18.9109726], [84.62458038, 18.91069412], [84.62374878, 18.91069412], [84.62374878, 18.91041756], [84.62346649, 18.91041756], [84.62346649, 18.91013908], [84.62319183, 18.91013908], [84.62319183, 18.90958023], [84.62291718, 18.90958405], [84.62291718, 18.90930557], [84.62264252, 18.90930748], [84.62264252, 18.90903091], [84.62236023, 18.90903091], [84.62236023, 18.908741], [84.62180328, 18.90875053], [84.62180328, 18.90847206], [84.62152863, 18.90847206], [84.62152863, 18.90819359], [84.62124634, 18.90819359], [84.62124634, 18.90791893], [84.62097168, 18.90792084], [84.62097168, 18.90736008], [84.62069702, 18.90736198], [84.62069702, 18.90708351], [84.62041473, 18.90708351], [84.62041473, 18.90680695], [84.62014008, 18.90681076], [84.62014008, 18.90653038], [84.61987305, 18.90653038], [84.61987305, 18.90625], [84.61958313, 18.90625], [84.61958313, 18.90596962], [84.61930847, 18.90597153], [84.61930847, 18.90569687], [84.61902618, 18.90570068], [84.61902618, 18.9054203], [84.61875153, 18.9054203], [84.61875153, 18.90513992], [84.61846924, 18.90513992], [84.61846924, 18.90485954], [84.61819458, 18.90486145], [84.61819458, 18.90458488], [84.61791992, 18.90458488], [84.61791992, 18.90430641], [84.61763763, 18.90431023], [84.61763763, 18.90402985], [84.61708069, 18.90402985], [84.61708069, 18.90374947], [84.61653137, 18.90374947], [84.61653137, 18.9034729], [84.61624908, 18.90347481], [84.61624908, 18.90319252], [84.61569214, 18.90319252], [84.61569214, 18.90291405], [84.61541748, 18.90293121], [84.61541748, 18.90263939], [84.61513519, 18.90263939], [84.61513519, 18.90236282], [84.61458588, 18.90236282], [84.61458588, 18.90208054], [84.61430359, 18.90208435], [84.61430359, 18.90180588], [84.61402893, 18.90180969], [84.61402893, 18.90153122], [84.61373901, 18.90153122], [84.61373901, 18.90125275], [84.61347198, 18.90125275], [84.61347198, 18.90097046], [84.61319733, 18.90097046], [84.61319733, 18.90069389], [84.61291504, 18.90069389], [84.61291504, 18.90041733], [84.61264038, 18.90042114], [84.61264038, 18.90014267], [84.61235809, 18.90014267], [84.61235809, 18.89986038], [84.61180878, 18.89986038], [84.61180878, 18.89957047], [84.61152649, 18.89958382], [84.61152649, 18.89930534], [84.61180878, 18.89931107], [84.61180878, 18.8987484], [84.61152649, 18.8987484], [84.61152649, 18.89846992], [84.61125183, 18.89847183], [84.61125183, 18.89819527], [84.61067963, 18.89819908], [84.61067963, 18.89792061], [84.61042023, 18.89792061], [84.61042023, 18.89763832], [84.61013794, 18.89763832], [84.61013794, 18.89707947], [84.60986328, 18.89708328], [84.60986328, 18.89680481], [84.60930634, 18.89680481], [84.60930634, 18.89652824], [84.60901642, 18.89652824], [84.60901642, 18.89624977], [84.60874939, 18.89624977], [84.60874939, 18.89569092], [84.60847473, 18.89569473], [84.60847473, 18.89541626], [84.60819244, 18.89541817], [84.60819244, 18.89513969], [84.60791779, 18.89513969], [84.60791779, 18.89486122], [84.6076355, 18.89486122], [84.6076355, 18.89458275], [84.60736084, 18.89458275], [84.60736084, 18.89402771], [84.60708618, 18.89402962], [84.60708618, 18.89430809], [84.60679626, 18.89430809], [84.60679626, 18.89402962], [84.60652924, 18.89402962], [84.60652924, 18.89291954], [84.60624695, 18.89291954], [84.60624695, 18.89208031], [84.60597229, 18.89208412], [84.60597229, 18.89180565], [84.60542297, 18.89180946], [84.60542297, 18.89153099], [84.60514069, 18.89153099], [84.60514069, 18.89125061], [84.6048584, 18.89125061], [84.6048584, 18.89069557], [84.60457611, 18.89069939], [84.60457611, 18.89014053], [84.60430908, 18.89014053], [84.60430908, 18.88986015], [84.60402679, 18.88986206], [84.60402679, 18.88958168], [84.60375214, 18.88958168], [84.60375214, 18.88930321], [84.60346985, 18.88931084], [84.60346985, 18.88903046], [84.6029129, 18.88903046], [84.6029129, 18.88875008], [84.60263824, 18.88875008], [84.60263824, 18.8884697], [84.60236359, 18.88847351], [84.60236359, 18.88819313], [84.6020813, 18.88820076], [84.6020813, 18.88792038], [84.60179901, 18.88792038], [84.60179901, 18.88735962], [84.6020813, 18.88736343], [84.6020813, 18.88680649], [84.60180664, 18.88680649], [84.60180664, 18.88708115], [84.60152435, 18.88708115], [84.60152435, 18.88680649], [84.60124969, 18.8868103], [84.60124969, 18.88653183], [84.60098267, 18.88653183], [84.60098267, 18.88596916], [84.60069275, 18.88597107], [84.60069275, 18.8856945], [84.60041809, 18.8856945], [84.60041809, 18.88513947], [84.6001358, 18.88513947], [84.6001358, 18.88485909], [84.59986115, 18.88485909], [84.59986115, 18.88457108], [84.59958649, 18.88458252], [84.59958649, 18.88430595], [84.59929657, 18.88431168], [84.59929657, 18.8840313], [84.59902954, 18.8840313], [84.59902954, 18.88319016], [84.59874725, 18.88319397], [84.59874725, 18.88263893], [84.5984726, 18.88264084], [84.5984726, 18.88208008], [84.59819794, 18.88208389], [84.59819794, 18.88180542], [84.59764099, 18.88182068], [84.59764099, 18.88153076], [84.5973587, 18.88153076], [84.5973587, 18.88125038], [84.59707642, 18.88125038], [84.59707642, 18.88097], [84.5965271, 18.88097191], [84.5965271, 18.88069534], [84.59625244, 18.88070107], [84.59625244, 18.88042068], [84.59597015, 18.88042068], [84.59597015, 18.87985992], [84.5956955, 18.87986183], [84.5956955, 18.87958336], [84.59541321, 18.87958336], [84.59541321, 18.87930679], [84.59513855, 18.87930679], [84.59513855, 18.87902832], [84.59485626, 18.87903023], [84.59485626, 18.87875938], [84.5945816, 18.87875938], [84.5945816, 18.87846947], [84.59430695, 18.87847137], [84.59430695, 18.87819672], [84.59402466, 18.87819672], [84.59402466, 18.87763977], [84.59375, 18.87763977], [84.59375, 18.87735939], [84.59347534, 18.8773613], [84.59347534, 18.87708473], [84.59319305, 18.87708473], [84.59319305, 18.87652779], [84.59292603, 18.87652969], [84.59292603, 18.87625122], [84.59263611, 18.87625122], [84.59263611, 18.87597084], [84.59236145, 18.87597466], [84.59236145, 18.87569237], [84.59208679, 18.87569237], [84.59208679, 18.8754158], [84.59179688, 18.87541962], [84.59179688, 18.87514114], [84.59152985, 18.87514114], [84.59152985, 18.87486267], [84.59124756, 18.87486267], [84.59124756, 18.87458038], [84.59069824, 18.87458229], [84.59069061, 18.87430573], [84.59041595, 18.87430954], [84.59041595, 18.87375259], [84.5901413, 18.87375259], [84.5901413, 18.87347031], [84.58985901, 18.87347031], [84.58985901, 18.87319374], [84.58958435, 18.87319374], [84.58958435, 18.87291718], [84.5890274, 18.8729229], [84.5890274, 18.87262917], [84.58847046, 18.87262917], [84.58847046, 18.8729229], [84.58680725, 18.87291718], [84.58680725, 18.87319374], [84.58625031, 18.87319374], [84.58625031, 18.87347031], [84.58569336, 18.87347031], [84.58569336, 18.87375259], [84.5854187, 18.87375259], [84.5854187, 18.87403107], [84.58513641, 18.87403107], [84.58513641, 18.87430954], [84.5845871, 18.87430954], [84.5845871, 18.87486267], [84.58429718, 18.87486267], [84.58429718, 18.87514114], [84.58403015, 18.87514114], [84.58403015, 18.87541962], [84.58374786, 18.8754158], [84.58374786, 18.87569237], [84.58347321, 18.87569046], [84.58347321, 18.87625122], [84.58319092, 18.87625122], [84.58319092, 18.87652969], [84.58291626, 18.87652969], [84.58291626, 18.87625122], [84.5826416, 18.87625122], [84.5826416, 18.87569046], [84.58291626, 18.87569237], [84.58291626, 18.87513924], [84.58319092, 18.87514114], [84.58319092, 18.87486267], [84.58347321, 18.87486267], [84.58347321, 18.87458038], [84.58374786, 18.87458229], [84.58374786, 18.87430573], [84.58403015, 18.87430954], [84.58403015, 18.87403107], [84.58429718, 18.87403107], [84.58429718, 18.87375259], [84.5845871, 18.87375259], [84.5845871, 18.87319183], [84.58486176, 18.87319374], [84.58486176, 18.87291718], [84.5854187, 18.8729229], [84.5854187, 18.87262917], [84.58597565, 18.8726387], [84.58597565, 18.87236023], [84.58625031, 18.87236023], [84.58625031, 18.87207985], [84.58652496, 18.87208366], [84.58652496, 18.87041664], [84.58625031, 18.87042046], [84.58625031, 18.8698597], [84.58597565, 18.8698616], [84.58597565, 18.86819458], [84.58569336, 18.86819458], [84.58569336, 18.86791611], [84.5854187, 18.86791992], [84.5854187, 18.86736107], [84.58513641, 18.86736107], [84.58513641, 18.86681747], [84.58486176, 18.86681747], [84.58486176, 18.86569023], [84.5845871, 18.86569595], [84.5845871, 18.86513901], [84.58429718, 18.86514091], [84.58429718, 18.86458015], [84.58403015, 18.86458588], [84.58403015, 18.8643055], [84.58376312, 18.86431122], [84.58376312, 18.86403084], [84.5826416, 18.86403084], [84.5826416, 18.86375046], [84.58207703, 18.86375046], [84.58207703, 18.86347008], [84.58180237, 18.86347389], [84.58180237, 18.8631916], [84.58208466, 18.8631916], [84.58208466, 18.86291695], [84.58180237, 18.86292076], [84.58180237, 18.86264038], [84.58152771, 18.86264038], [84.58152771, 18.8624897], [84.58152771, 18.86236382], [84.58125305, 18.86236382], [84.58125305, 18.85985947], [84.58097076, 18.85985947], [84.58097076, 18.85819435], [84.58069611, 18.85819435], [84.58069611, 18.85763931], [84.58040619, 18.85765266], [84.58040619, 18.85736084], [84.58013916, 18.85736084], [84.58013916, 18.85708046], [84.5798645, 18.85708427], [84.5798645, 18.85652733], [84.57958221, 18.85652924], [84.57958221, 18.85625076], [84.57930756, 18.85625076], [84.57930756, 18.85514069], [84.5790329, 18.85514069], [84.5790329, 18.85431099], [84.57875061, 18.85431099], [84.57875061, 18.85346985], [84.57847595, 18.85347176], [84.57847595, 18.85263824], [84.57818604, 18.85264015], [84.57818604, 18.85207939], [84.57791901, 18.85208321], [84.57791901, 18.85180664], [84.57763672, 18.85180664], [84.57763672, 18.85124969], [84.57736206, 18.85124969], [84.57736206, 18.85097122], [84.57707977, 18.85097313], [84.57707977, 18.85041618], [84.57681274, 18.85042], [84.57681274, 18.84986115], [84.57653046, 18.84986115], [84.57653046, 18.84930992], [84.57624817, 18.84930992], [84.57624817, 18.84875107], [84.57596588, 18.84875107], [84.57596588, 18.84736252], [84.57569122, 18.84736252], [84.57569122, 18.8429184], [84.57596588, 18.8429184], [84.57596588, 18.84235954], [84.57569122, 18.84236145], [84.57569122, 18.84013939], [84.57596588, 18.84013939], [84.57596588, 18.83930969], [84.57624817, 18.83930969], [84.57624817, 18.83903122], [84.57653046, 18.83903122], [84.57653046, 18.83875084], [84.57681274, 18.83875084], [84.57680511, 18.8381958], [84.57653046, 18.8381958], [84.57653046, 18.83708572], [84.57624817, 18.83708572], [84.57624817, 18.83680534], [84.57569122, 18.83681107], [84.57569122, 18.83652115], [84.57514191, 18.83652687], [84.57514191, 18.83625031], [84.57485962, 18.83625031], [84.57485962, 18.83596992], [84.57458496, 18.83597374], [84.57458496, 18.83569527], [84.57402802, 18.83570099], [84.57402802, 18.83542061], [84.57375336, 18.83542061], [84.57375336, 18.83514023], [84.57347107, 18.83514023], [84.57347107, 18.83485985], [84.57277679, 18.83486366], [84.57263947, 18.83486366], [84.57263947, 18.83458138], [84.57208252, 18.83458138], [84.57208252, 18.83430481], [84.57180786, 18.83430481], [84.57180786, 18.83402824], [84.5715332, 18.83403015], [84.5715332, 18.83375168], [84.57125092, 18.83375168], [84.57125092, 18.83319092], [84.57096863, 18.83319473], [84.57096863, 18.83291626], [84.57041931, 18.83292007], [84.57041931, 18.8326416], [84.57013702, 18.8326416], [84.57013702, 18.83235931], [84.56986237, 18.83235931], [84.56986237, 18.83208084], [84.56958008, 18.83208275], [84.56958008, 18.83180618], [84.56931305, 18.8318119], [84.56931305, 18.83153152], [84.56903076, 18.83153152], [84.56903076, 18.83124924], [84.5687561, 18.83124924], [84.5687561, 18.83097076], [84.56847382, 18.83097267], [84.56847382, 18.8306942], [84.568367, 18.8306942], [84.56819153, 18.8306942], [84.56819153, 18.83055115], [84.56819153, 18.83041763], [84.56799316, 18.83041573], [84.56791687, 18.83041573], [84.56791687, 18.83013916], [84.56759644, 18.83013916], [84.56735992, 18.83013916], [84.56735992, 18.82998085], [84.56735992, 18.82986069], [84.56720734, 18.82986069], [84.56680298, 18.82986069], [84.56680298, 18.82958031], [84.56652832, 18.82958412], [84.56652832, 18.8293705], [84.56652832, 18.82902718], [84.56624603, 18.82902908], [84.56624603, 18.82875061], [84.56568909, 18.82875061], [84.56568909, 18.82847023], [84.56541443, 18.82847214], [84.56541443, 18.82819366], [84.56511688, 18.82819366], [84.56485748, 18.82819366], [84.56485748, 18.8279171], [84.56458282, 18.82792091], [84.56456757, 18.82766151], [84.56430817, 18.82764053], [84.56430817, 18.82740021], [84.56430817, 18.82708359], [84.56402588, 18.82708359], [84.56402588, 18.82652855], [84.56387329, 18.82653046], [84.56375122, 18.82653046], [84.56375122, 18.82625008], [84.56346893, 18.82625008], [84.56346893, 18.8259697], [84.56319427, 18.8259716], [84.56319427, 18.82569695], [84.56291962, 18.82570076], [84.56291962, 18.82514], [84.56318665, 18.82514], [84.56318665, 18.82485962], [84.56291962, 18.82486153], [84.56291962, 18.82458305], [84.56263733, 18.82458305], [84.56263733, 18.82430649], [84.56236267, 18.8243103], [84.56236267, 18.82402992], [84.56208038, 18.82402992], [84.56208038, 18.82374954], [84.56180573, 18.82374954], [84.56180573, 18.8231945], [84.56153107, 18.8231945], [84.56153107, 18.82291412], [84.56124878, 18.82291985], [84.56124878, 18.82263947], [84.56096649, 18.82263947], [84.56096649, 18.8223629], [84.56069183, 18.8223629], [84.56069183, 18.82208061], [84.56041718, 18.82208443], [84.56041718, 18.82180595], [84.56014252, 18.82180977], [84.56014252, 18.82125282], [84.55986023, 18.82125282], [84.55986023, 18.82097054], [84.55958557, 18.82097054], [84.55958557, 18.82069206], [84.55930328, 18.82069206], [84.55930328, 18.8204174], [84.55902863, 18.82042122], [84.55902863, 18.81986046], [84.55874634, 18.81986046], [84.55874634, 18.81931114], [84.55847168, 18.81931114], [84.55847168, 18.81875229], [84.55819702, 18.81875229], [84.55819702, 18.81847954], [84.5579071, 18.81847954], [84.5579071, 18.81792068], [84.55764008, 18.81792068], [84.55764008, 18.8176384], [84.55735779, 18.8176384], [84.55735779, 18.81735992], [84.55708313, 18.81736183], [84.55708313, 18.81597137], [84.55680847, 18.81597137], [84.55680847, 18.81513977], [84.55652618, 18.81513977], [84.55652618, 18.81264114], [84.55625153, 18.81264114], [84.55625153, 18.81068993], [84.55596924, 18.81069565], [84.55596924, 18.80958366], [84.55569458, 18.80958366], [84.55569458, 18.80930328], [84.55541992, 18.80931091], [84.55541992, 18.80846977], [84.55569458, 18.80847359], [84.55569458, 18.80736351], [84.55541992, 18.80736351], [84.55541992, 18.80680466], [84.55513763, 18.80680466], [84.55513763, 18.80541611], [84.55486298, 18.80542183], [84.55486298, 18.80514145], [84.55458069, 18.80514145], [84.55458069, 18.80458069], [84.55430603, 18.8045826], [84.55430603, 18.80402756], [84.55403137, 18.80403137], [84.55403137, 18.80291748], [84.55374908, 18.80291748], [84.55374908, 18.80236053], [84.55403137, 18.80236053], [84.55403137, 18.80010033], [84.55403137, 18.79847145], [84.55430603, 18.79847145], [84.55430603, 18.79791641], [84.55458069, 18.79792023], [84.55458069, 18.79597282], [84.55403137, 18.79597473], [84.55403137, 18.79569244], [84.55374908, 18.79569244], [84.55374908, 18.79541588], [84.5534668, 18.79541969], [84.5534668, 18.79514122], [84.55319214, 18.79514122], [84.55319214, 18.79486275], [84.55291748, 18.79486275], [84.55291748, 18.79458046], [84.55319214, 18.79458046], [84.55319214, 18.7943058], [84.5534668, 18.79430962], [84.5534668, 18.79403114], [84.55374908, 18.79403114], [84.55374908, 18.79292107], [84.55403137, 18.79292107], [84.55403137, 18.79264259], [84.55374908, 18.79264259], [84.55374908, 18.79236031], [84.5534668, 18.79236031], [84.5534668, 18.79180908], [84.55319214, 18.79180908], [84.55319214, 18.79154015], [84.55291748, 18.79154015], [84.55291748, 18.79236031], [84.55264282, 18.79236031], [84.55264282, 18.79264259], [84.55236053, 18.79264259], [84.55236053, 18.79292107], [84.55152893, 18.79292107], [84.55152893, 18.79264259], [84.55124664, 18.79264259], [84.55124664, 18.79124832], [84.5506897, 18.79124832], [84.5506897, 18.79096985], [84.55014038, 18.79097176], [84.55014038, 18.79069519], [84.54930878, 18.79070091], [84.54930878, 18.79124832], [84.54917908, 18.79124832], [84.54902649, 18.79124832], [84.54902649, 18.79096985], [84.54846954, 18.79097176], [84.54846954, 18.79069519], [84.54818726, 18.79070091], [84.54818726, 18.79013824], [84.54905701, 18.79013824], [84.54930878, 18.79013824], [84.54930878, 18.78985977], [84.54902649, 18.78986168], [84.54902649, 18.78972816], [84.54902649, 18.78930473], [84.54875183, 18.78930473], [84.54875183, 18.78874969], [84.54846954, 18.78874969], [84.54846954, 18.78847122], [84.54819489, 18.78847313], [84.54819489, 18.78819466], [84.54792023, 18.78819466], [84.54792023, 18.78791618], [84.5476532, 18.78791809], [84.5476532, 18.78763962], [84.54651642, 18.78763962], [84.54651642, 18.78680992], [84.54624939, 18.78680992], [84.54624939, 18.78625107], [84.5459671, 18.78625107], [84.5459671, 18.78569031], [84.54569244, 18.78569412], [84.54569244, 18.78541756], [84.5451355, 18.78541756], [84.5451355, 18.78513908], [84.54458618, 18.78514099], [84.54458618, 18.78486061], [84.54429626, 18.78486061], [84.54429626, 18.78458023], [84.54402924, 18.78458595], [84.54402924, 18.78430557], [84.54374695, 18.78430939], [84.54374695, 18.78403091], [84.54319763, 18.78403091], [84.54319763, 18.78375053], [84.54291534, 18.78375053], [84.54291534, 18.78347206], [84.54264069, 18.78347206], [84.54264069, 18.7831955], [84.5423584, 18.7831955], [84.5423584, 18.78263855], [84.54207611, 18.78264046], [84.54207611, 18.78236961], [84.54151917, 18.78236961], [84.54151917, 18.78181076], [84.54125214, 18.78181076], [84.54125214, 18.78153038], [84.54096985, 18.78153038], [84.54096985, 18.78125191], [84.54013824, 18.78125191], [84.54013824, 18.78096962], [84.53986359, 18.78097343], [84.53986359, 18.78041649], [84.5395813, 18.7804203], [84.5395813, 18.78014183], [84.53901672, 18.78014183], [84.53901672, 18.77957916], [84.53874969, 18.77958107], [84.53874969, 18.77930641], [84.53848267, 18.77931023], [84.53848267, 18.77903175], [84.53791809, 18.77903175], [84.53791809, 18.77874947], [84.53708649, 18.77874947], [84.53708649, 18.77792168], [84.53679657, 18.77792168], [84.53679657, 18.77736092], [84.53652954, 18.77736092], [84.53652954, 18.77653122], [84.5359726, 18.77653122], [84.5359726, 18.7762394], [84.53569794, 18.77625084], [84.53569794, 18.77597237], [84.53541565, 18.77597237], [84.53541565, 18.77569389], [84.53514099, 18.77569389], [84.53514099, 18.77541733], [84.53457642, 18.77542114], [84.53457642, 18.77514076], [84.53430176, 18.77514076], [84.53430176, 18.77486038], [84.5340271, 18.77486038], [84.5340271, 18.77458], [84.53375244, 18.77458382], [84.53375244, 18.77430534], [84.53320313, 18.77431107], [84.53320313, 18.77375031], [84.53263855, 18.77375031], [84.53263855, 18.77347183], [84.53236389, 18.77347183], [84.53236389, 18.77319527], [84.5320816, 18.77320099], [84.5320816, 18.77292061], [84.53180695, 18.77292061], [84.53180695, 18.77235985], [84.53152466, 18.77236176], [84.53152466, 18.77208328], [84.53069305, 18.77208328], [84.53069305, 18.77180672], [84.53013611, 18.77180672], [84.53013611, 18.77152824], [84.52957916, 18.77153015], [84.52957916, 18.77069092], [84.5293045, 18.77069473], [84.5293045, 18.77041626], [84.52902985, 18.77042961], [84.52902985, 18.77013969], [84.52819824, 18.77013969], [84.52819061, 18.76986122], [84.5276413, 18.76986122], [84.5276413, 18.76958084], [84.52735901, 18.76958466], [84.52735901, 18.76930618], [84.52651978, 18.76931], [84.52651978, 18.76902962], [84.52625275, 18.76902962], [84.52625275, 18.76737022], [84.52401733, 18.76737022], [84.52401733, 18.76708031], [84.52375031, 18.76708412], [84.52375031, 18.76680565], [84.52348328, 18.76680946], [84.52348328, 18.7665329], [84.52319336, 18.7665329], [84.52319336, 18.76625252], [84.52263641, 18.76625252], [84.52263641, 18.76597023], [84.5220871, 18.76597023], [84.5220871, 18.76569366], [84.52153015, 18.76569366], [84.52153015, 18.7654171], [84.52124786, 18.76542282], [84.52124786, 18.76485825], [84.52097321, 18.76486015], [84.52097321, 18.76458359], [84.52041626, 18.76458359], [84.52041626, 18.76430511], [84.51985931, 18.76430511], [84.51985931, 18.76402855], [84.51957703, 18.76402855], [84.51957703, 18.7634697], [84.51875305, 18.7634716], [84.51875305, 18.76319504], [84.51847076, 18.76320076], [84.51847076, 18.76263809], [84.51819611, 18.76263809], [84.51819611, 18.76235962], [84.51763916, 18.76236153], [84.51763916, 18.76208305], [84.51708221, 18.76208305], [84.51708221, 18.76180649], [84.5165329, 18.7618103], [84.5165329, 18.76152992], [84.51625061, 18.76152992], [84.51625061, 18.76124001], [84.51597595, 18.76124954], [84.51597595, 18.76097298], [84.51569366, 18.76097298], [84.51569366, 18.7606945], [84.51541901, 18.7606945], [84.51541901, 18.76041794], [84.51486206, 18.76041985], [84.51486206, 18.76013947], [84.51457977, 18.76013947], [84.51457977, 18.75986099], [84.51374817, 18.75986099], [84.51374817, 18.75958061], [84.51347351, 18.75958252], [84.51347351, 18.75930405], [84.51291656, 18.75930977], [84.51291656, 18.75875092], [84.51235962, 18.75875092], [84.51235962, 18.75847054], [84.51180267, 18.75847244], [84.51180267, 18.75819588], [84.51125336, 18.75819588], [84.51125336, 18.7579174], [84.51097107, 18.75792122], [84.51097107, 18.75764084], [84.51040649, 18.75764084], [84.51040649, 18.75736046], [84.51013947, 18.75736046], [84.51013947, 18.75708008], [84.50986481, 18.7570858], [84.50986481, 18.75680542], [84.50958252, 18.75681114], [84.50958252, 18.75653076], [84.50930786, 18.75653076], [84.50930786, 18.75625038], [84.50875092, 18.75625038], [84.50875092, 18.75570107], [84.50847626, 18.75570107], [84.50847626, 18.75543022], [84.50818634, 18.75543022], [84.50818634, 18.7551403], [84.50791931, 18.7551403], [84.50791931, 18.75486183], [84.50736237, 18.75486374], [84.50736237, 18.75458145], [84.50708008, 18.75458145], [84.50708008, 18.75430489], [84.50680542, 18.75430489], [84.50680542, 18.75402832], [84.50653076, 18.75403023], [84.50653076, 18.75375175], [84.50596619, 18.75375175], [84.50596619, 18.75346947], [84.50541687, 18.75347328], [84.50541687, 18.75319481], [84.50514221, 18.75319481], [84.50514221, 18.75291634], [84.50485992, 18.75292015], [84.50485992, 18.75264168], [84.50458527, 18.75264168], [84.50458527, 18.75235939], [84.50430298, 18.75235939], [84.50430298, 18.75208282], [84.50402832, 18.75208282], [84.50402832, 18.75152779], [84.50347137, 18.7515316], [84.50347137, 18.75124931], [84.50319672, 18.75124931], [84.50319672, 18.75097084], [84.50208282, 18.75097275], [84.50208282, 18.7504158], [84.50180817, 18.75042152], [84.50180817, 18.75013924], [84.50152588, 18.75013924], [84.50152588, 18.74986076], [84.50125122, 18.74986076], [84.50125122, 18.74958038], [84.50096893, 18.7495842], [84.50096893, 18.74930573], [84.50069427, 18.74930573], [84.50069427, 18.74902725], [84.50041962, 18.74902916], [84.50041962, 18.74818993], [84.50013733, 18.74819374], [84.50013733, 18.74791718], [84.49931335, 18.74792099], [84.49931335, 18.74736023], [84.49874878, 18.74736023], [84.49874878, 18.74707985], [84.49847412, 18.74708366], [84.49847412, 18.74680519], [84.49819183, 18.74681091], [84.49819183, 18.74653053], [84.49791718, 18.74653053], [84.49791718, 18.74625969], [84.49764252, 18.74625969], [84.49764252, 18.74596977], [84.49736023, 18.74597168], [84.49736023, 18.74569511], [84.49653625, 18.74570084], [84.49653625, 18.74542046], [84.49597168, 18.74542046], [84.49597168, 18.7448597], [84.49569702, 18.7448616], [84.49569702, 18.74430466], [84.49541473, 18.74430466], [84.49541473, 18.74402809], [84.49514008, 18.74403], [84.49514008, 18.74374962], [84.49485779, 18.74374962], [84.49485779, 18.74347115], [84.49458313, 18.74347305], [84.49458313, 18.74291611], [84.49430847, 18.74291992], [84.49430847, 18.74263954], [84.49402618, 18.74263954], [84.49402618, 18.74236107], [84.49346924, 18.74236107], [84.49346924, 18.7420845], [84.49319458, 18.7420845], [84.49319458, 18.74180603], [84.49263763, 18.74180984], [84.49263763, 18.74152946], [84.49236298, 18.74152946], [84.49236298, 18.7412529], [84.49208069, 18.7412529], [84.49208069, 18.74097061], [84.49180603, 18.74097061], [84.49180603, 18.74069214], [84.49153137, 18.74069214], [84.49153137, 18.74041748], [84.49124908, 18.74041939], [84.49124908, 18.74014282], [84.4909668, 18.74014282], [84.4909668, 18.73986244], [84.49069214, 18.73986244], [84.49069214, 18.73958015], [84.49041748, 18.73958206], [84.49041748, 18.7393055], [84.49014282, 18.73931122], [84.49014282, 18.73875237], [84.48986053, 18.73875237], [84.48986053, 18.73846817], [84.48958588, 18.73847008], [84.48958588, 18.73791695], [84.48929596, 18.73792076], [84.48929596, 18.73735809], [84.48902893, 18.73736191], [84.48902893, 18.73708344], [84.48874664, 18.73708344], [84.48874664, 18.73680496], [84.48847198, 18.73681068], [84.48847198, 18.7365284], [84.48819733, 18.7365284], [84.48819733, 18.73624992], [84.48791504, 18.73624992], [84.48791504, 18.73597145], [84.48764038, 18.73597145], [84.48764038, 18.73569489], [84.48735809, 18.73569489], [84.48735809, 18.73430634], [84.48707581, 18.73431969], [84.48707581, 18.73374939], [84.48680878, 18.73374939], [84.48680878, 18.73319054], [84.48652649, 18.73319435], [84.48652649, 18.73263931], [84.48625183, 18.73264122], [84.48625183, 18.73236084], [84.48568726, 18.73236084], [84.48568726, 18.73208046], [84.48542023, 18.73208427], [84.48542023, 18.7318058], [84.48513794, 18.73180962], [84.48513794, 18.73097038], [84.48486328, 18.73097229], [84.48486328, 18.73041725], [84.48458099, 18.73042107], [84.48458099, 18.72986031], [84.48401642, 18.72986031], [84.48401642, 18.72957993], [84.48374939, 18.72958374], [84.48374939, 18.72930527], [84.4834671, 18.72931099], [84.4834671, 18.72903061], [84.48319244, 18.72903061], [84.48319244, 18.72875023], [84.48291779, 18.72875023], [84.48291779, 18.72820091], [84.48264313, 18.72820091], [84.48264313, 18.72792053], [84.48236084, 18.72792053], [84.48236084, 18.72764015], [84.48208618, 18.72764015], [84.48208618, 18.72735977], [84.48180389, 18.72736359], [84.48180389, 18.7270813], [84.48124695, 18.7270813], [84.48124695, 18.72680473], [84.48097229, 18.72680473], [84.48097229, 18.72652817], [84.48042297, 18.72653008], [84.48042297, 18.7262516], [84.48014069, 18.7262516], [84.48014069, 18.72596931], [84.4798584, 18.72597122], [84.4798584, 18.72569466], [84.47958374, 18.72569466], [84.47958374, 18.72541618], [84.47902679, 18.72542191], [84.47902679, 18.72485924], [84.47875214, 18.72485924], [84.47875214, 18.72458076], [84.47819519, 18.72458267], [84.47819519, 18.72430611], [84.47763824, 18.72431183], [84.47763824, 18.72403145], [84.47735596, 18.72403145], [84.47735596, 18.72374916], [84.47680664, 18.72374916], [84.47680664, 18.72291756], [84.47651672, 18.72291756], [84.47651672, 18.72263908], [84.47569275, 18.72263908], [84.47569275, 18.72236061], [84.47541046, 18.72236061], [84.47541046, 18.72207069], [84.4751358, 18.72208405], [84.4751358, 18.7215271], [84.47486115, 18.72153091], [84.47486115, 18.72125053], [84.47458649, 18.72125053], [84.47458649, 18.72097015], [84.4743042, 18.72097206], [84.4743042, 18.72069359], [84.47374725, 18.72069359], [84.47374725, 18.72041512], [84.4734726, 18.72042084], [84.4734726, 18.72014046], [84.47319794, 18.72014046], [84.47319794, 18.71986008], [84.47291565, 18.71986198], [84.47291565, 18.71958351], [84.47264099, 18.71958351], [84.47264099, 18.71930695], [84.47236633, 18.7193203], [84.47236633, 18.71903038], [84.47207642, 18.71903038], [84.47207642, 18.71875], [84.47180176, 18.71875], [84.47180176, 18.71846962], [84.4715271, 18.71847153], [84.4715271, 18.71791649], [84.47125244, 18.7179203], [84.47125244, 18.71763992], [84.47097015, 18.71763992], [84.47097015, 18.71708107], [84.4706955, 18.71708488], [84.4706955, 18.71652794], [84.47041321, 18.71652985], [84.47041321, 18.71626091], [84.47013855, 18.71626091], [84.47013855, 18.7159729], [84.46986389, 18.71597481], [84.46986389, 18.71569443], [84.46930695, 18.71569443], [84.46930695, 18.71513939], [84.46901703, 18.71513939], [84.46901703, 18.71486282], [84.46875, 18.71486282], [84.46875, 18.71430969], [84.46848297, 18.71430969], [84.46848297, 18.71403122], [84.46819305, 18.71403122], [84.46819305, 18.71375275], [84.4679184, 18.71375275], [84.4679184, 18.71347046], [84.46763611, 18.71347046], [84.46763611, 18.71319389], [84.4659729, 18.71319389], [84.4659729, 18.71291733], [84.46569824, 18.71292114], [84.46569061, 18.71153069], [84.46541595, 18.71153069], [84.46541595, 18.71096992], [84.4651413, 18.71097183], [84.4651413, 18.71069527], [84.46485901, 18.71069908], [84.46485901, 18.71013069], [84.46458435, 18.71013832], [84.46458435, 18.70986176], [84.46430206, 18.70986176], [84.46430206, 18.70958328], [84.4640274, 18.70958328], [84.4640274, 18.70930481], [84.46375275, 18.70930481], [84.46375275, 18.70874977], [84.46347046, 18.70874977], [84.46347046, 18.70846939], [84.46291351, 18.7084713], [84.46291351, 18.70819473], [84.46263885, 18.70819473], [84.46263885, 18.70791626], [84.46235657, 18.70791817], [84.46235657, 18.70736122], [84.46208191, 18.70736122], [84.46208191, 18.70652962], [84.46180725, 18.70652962], [84.46180725, 18.70597076], [84.46152496, 18.70597267], [84.46152496, 18.70513916], [84.46125031, 18.70514107], [84.46125031, 18.70486069], [84.46097565, 18.70486069], [84.46097565, 18.70458412], [84.46069336, 18.70458412], [84.46069336, 18.70347214], [84.4604187, 18.70347214], [84.4604187, 18.70319557], [84.46013641, 18.70319557], [84.46013641, 18.70263863], [84.45986176, 18.70264053], [84.45986176, 18.70207977], [84.4595871, 18.70208359], [84.4595871, 18.70180511], [84.45847321, 18.70181084], [84.45847321, 18.70125008], [84.45819092, 18.70125008], [84.45819092, 18.70096016], [84.45791626, 18.70097351], [84.45791626, 18.70069504], [84.4576416, 18.70070076], [84.4576416, 18.70014191], [84.45736694, 18.70014191], [84.45736694, 18.69957924], [84.45708466, 18.69958115], [84.45708466, 18.69902992], [84.45680237, 18.69903183], [84.45680237, 18.69819069], [84.45652771, 18.6981945], [84.45652771, 18.69791603], [84.45625305, 18.69792175], [84.45625305, 18.69764137], [84.45597076, 18.69764137], [84.45597076, 18.69735909], [84.45569611, 18.69735909], [84.45569611, 18.69680977], [84.45485687, 18.69680977], [84.45485687, 18.69652748], [84.45458221, 18.69652748], [84.45458221, 18.69625092], [84.45429993, 18.69625092], [84.45429993, 18.69597054], [84.45402527, 18.69597244], [84.45402527, 18.6954174], [84.45375061, 18.69542122], [84.45375061, 18.69514847], [84.45347595, 18.69514847], [84.45347595, 18.69486046], [84.45318604, 18.69486046], [84.45318604, 18.69431114], [84.45291901, 18.69431114], [84.45291901, 18.69403076], [84.45263672, 18.69403076], [84.45263672, 18.69375038], [84.45236206, 18.69375038], [84.45236206, 18.69347], [84.45207977, 18.69347191], [84.45207977, 18.69291687], [84.45181274, 18.69292068], [84.45181274, 18.69235992], [84.45124817, 18.69236183], [84.45124817, 18.69208336], [84.45096588, 18.69209099], [84.45096588, 18.69153023], [84.45069122, 18.69153023], [84.45069122, 18.69124985], [84.45041656, 18.69124985], [84.45041656, 18.69096947], [84.45014191, 18.69097137], [84.45014191, 18.69069481], [84.44985962, 18.69069481], [84.44985962, 18.69041634], [84.44957733, 18.69042015], [84.44957733, 18.69013977], [84.44930267, 18.69013977], [84.44930267, 18.68985939], [84.44902802, 18.6898613], [84.44902802, 18.68958473], [84.44875336, 18.68958473], [84.44875336, 18.68902779], [84.44847107, 18.68902779], [84.44847107, 18.68874931], [84.44819641, 18.68875122], [84.44819641, 18.68847275], [84.44791412, 18.68847466], [84.44791412, 18.68819427], [84.44763947, 18.68819427], [84.44763947, 18.6879158], [84.44735718, 18.68791962], [84.44735718, 18.68736267], [84.44708252, 18.68736267], [84.44708252, 18.68708038], [84.44680786, 18.6870842], [84.44680786, 18.68680573], [84.4465332, 18.68680954], [84.4465332, 18.68625259], [84.44625092, 18.68625259], [84.44625092, 18.68596077], [84.44596863, 18.68597031], [84.44596863, 18.68569374], [84.44569397, 18.68569374], [84.44569397, 18.6851387], [84.44542694, 18.68514252], [84.44542694, 18.68457985], [84.44513702, 18.68458366], [84.44513702, 18.68430519], [84.44486237, 18.68431091], [84.44486237, 18.68403053], [84.44458008, 18.68403053], [84.44458008, 18.68374825], [84.44430542, 18.68374825], [84.44430542, 18.68347168], [84.44403076, 18.68347168], [84.44403076, 18.68319511], [84.44374847, 18.68321037], [84.44374847, 18.68292046], [84.44346619, 18.68292046], [84.44346619, 18.68263817], [84.44319153, 18.68263817], [84.44319153, 18.6823597], [84.44291687, 18.6823616], [84.44291687, 18.68208313], [84.44235992, 18.68208313], [84.44235992, 18.68180466], [84.44208527, 18.68180466], [84.44208527, 18.68124962], [84.44180298, 18.68124962], [84.44180298, 18.68041992], [84.44124603, 18.68041992], [84.44124603, 18.68014908], [84.44097137, 18.68014908], [84.44097137, 18.67930984], [84.44069672, 18.67930984], [84.44069672, 18.67847061], [84.44097137, 18.67847252], [84.44097137, 18.67819595], [84.44125366, 18.67819595], [84.44125366, 18.67791748], [84.44152832, 18.67791939], [84.44152832, 18.67597008], [84.44125366, 18.67597389], [84.44125366, 18.67486382], [84.44097137, 18.67486382], [84.44097137, 18.67375183], [84.44069672, 18.67375183], [84.44069672, 18.67235947], [84.44041443, 18.67235947], [84.44041443, 18.67180634], [84.44013977, 18.67181015], [84.44013977, 18.66847038], [84.44041443, 18.66847229], [84.44041443, 18.66763878], [84.44069672, 18.66764069], [84.44069672, 18.6672802], [84.44069672, 18.6665287], [84.4404068, 18.66653061], [84.4404068, 18.66570091], [84.44069672, 18.66570091], [84.44069672, 18.66403008], [84.43985748, 18.66402817], [84.43985748, 18.66430473], [84.43902588, 18.66430473], [84.43902588, 18.66402817], [84.43875122, 18.66403008], [84.43875122, 18.66319084], [84.43846893, 18.66319466], [84.43846893, 18.66291618], [84.43818665, 18.66292], [84.43818665, 18.66236115], [84.43791962, 18.66236115], [84.43791962, 18.66180992], [84.43736267, 18.66180992], [84.43736267, 18.66152954], [84.43708038, 18.66152954], [84.43708038, 18.66125107], [84.43681335, 18.66125107], [84.43681335, 18.66152954], [84.43653107, 18.66152954], [84.43653107, 18.66125107], [84.43625641, 18.66125107], [84.43625641, 18.6609726], [84.43597412, 18.6609726], [84.43597412, 18.66069221], [84.43569183, 18.66069221], [84.43569183, 18.66013908], [84.43541718, 18.6601429], [84.43541718, 18.65958023], [84.43514252, 18.65958405], [84.43514252, 18.65847015], [84.43486023, 18.65847015], [84.43486023, 18.65763855], [84.4345932, 18.65763855], [84.4345932, 18.65735817], [84.43430328, 18.65736008], [84.43430328, 18.65708351], [84.43402863, 18.65708351], [84.43402863, 18.65680504], [84.43374634, 18.65681076], [84.43374634, 18.65652847], [84.43347168, 18.65652847], [84.43347168, 18.65624809], [84.43319702, 18.65624809], [84.43319702, 18.65597916], [84.4329071, 18.65597916], [84.4329071, 18.6554203], [84.43264008, 18.6554203], [84.43264008, 18.65513992], [84.43235779, 18.65513992], [84.43235779, 18.65485954], [84.43208313, 18.65486145], [84.43208313, 18.65430641], [84.43152618, 18.65431023], [84.43152618, 18.65402985], [84.43131256, 18.65402985], [84.43096924, 18.65402985], [84.43096924, 18.65374947], [84.43068695, 18.65374947], [84.43068695, 18.65347099], [84.43041992, 18.6534729], [84.43041992, 18.65291786], [84.42986298, 18.65291786], [84.42986298, 18.65263939], [84.42903137, 18.65263939], [84.42903137, 18.65236092], [84.42874908, 18.65236092], [84.42874908, 18.65208054], [84.42763519, 18.65208244], [84.42763519, 18.65180588], [84.42791748, 18.65180969], [84.42791748, 18.65153122], [84.42764282, 18.65153122], [84.42764282, 18.65125084], [84.42708588, 18.65125084], [84.42708588, 18.65069008], [84.42680359, 18.6506958], [84.42680359, 18.65041733], [84.42652893, 18.65042114], [84.42652893, 18.65014076], [84.42624664, 18.65014076], [84.42624664, 18.64985275], [84.42597198, 18.64986038], [84.42597198, 18.64958572], [84.42569733, 18.64958572], [84.42569733, 18.64930534], [84.42542267, 18.64931107], [84.42542267, 18.64903069], [84.42514038, 18.64903069], [84.42514038, 18.64875031], [84.42485809, 18.64875031], [84.42485809, 18.6482029], [84.42457581, 18.6482029], [84.42457581, 18.64792061], [84.42431641, 18.64792061], [84.42431641, 18.64764023], [84.42402649, 18.64764023], [84.42402649, 18.64736176], [84.42375183, 18.64736366], [84.42375183, 18.64708138], [84.42346954, 18.64708138], [84.42346954, 18.64680481], [84.42319489, 18.64680481], [84.42319489, 18.64652824], [84.42292023, 18.64653015], [84.42292023, 18.64596939], [84.42263794, 18.64596939], [84.42263794, 18.64569473], [84.42236328, 18.64569473], [84.42236328, 18.64541626], [84.42180634, 18.64542007], [84.42180634, 18.6451416], [84.42124939, 18.6451416], [84.42124939, 18.64430618], [84.4209671, 18.6443119], [84.4209671, 18.64404106], [84.42069244, 18.64404106], [84.42069244, 18.64374924], [84.41958618, 18.64374924], [84.41958618, 18.64347076], [84.41902924, 18.64347267], [84.41902924, 18.6431942], [84.41874695, 18.6431942], [84.41874695, 18.64291763], [84.41847229, 18.64291763], [84.41847229, 18.64236069], [84.41819763, 18.64236069], [84.41819763, 18.64208031], [84.41791534, 18.64208412], [84.41791534, 18.64180565], [84.41764069, 18.64180946], [84.41764069, 18.64152908], [84.4173584, 18.64152908], [84.4173584, 18.64125061], [84.41707611, 18.64125061], [84.41707611, 18.64068985], [84.41680908, 18.64069366], [84.41680908, 18.64041519], [84.41652679, 18.64042091], [84.41652679, 18.64014053], [84.4154129, 18.64014053], [84.4154129, 18.63986015], [84.4145813, 18.63986206], [84.4145813, 18.63930511], [84.41430664, 18.63931084], [84.41430664, 18.63903046], [84.41401672, 18.63903046], [84.41401672, 18.63875008], [84.41374969, 18.63875008], [84.41374969, 18.6384697], [84.41347504, 18.6384716], [84.41347504, 18.63819695], [84.41319275, 18.63820076], [84.41319275, 18.63791084], [84.41291809, 18.63791656], [84.41291809, 18.63763809], [84.4126358, 18.63764], [84.4126358, 18.63735962], [84.41236115, 18.63736153], [84.41236115, 18.63708305], [84.41208649, 18.63708305], [84.41208649, 18.63680649], [84.41179657, 18.6368103], [84.41179657, 18.63652992], [84.41152954, 18.63652992], [84.41152954, 18.63624954], [84.41124725, 18.63624954], [84.41124725, 18.63597107], [84.4109726, 18.63597488], [84.4109726, 18.6356945], [84.41041565, 18.6356945], [84.41041565, 18.63541603], [84.41014099, 18.63541985], [84.41014099, 18.63513947], [84.4098587, 18.63513947], [84.4098587, 18.63484955], [84.40958405, 18.6348629], [84.40958405, 18.63458061], [84.40930176, 18.63458061], [84.40930176, 18.63430595], [84.4090271, 18.63430977], [84.4090271, 18.63402939], [84.40875244, 18.63402939], [84.40875244, 18.63375282], [84.4081955, 18.63375282], [84.4081955, 18.63347054], [84.40791321, 18.63347054], [84.40791321, 18.63319206], [84.40763855, 18.63319206], [84.40763855, 18.6329174], [84.40735626, 18.63292122], [84.40735626, 18.63264275], [84.4070816, 18.63264275], [84.4070816, 18.63236237], [84.40680695, 18.63236237], [84.40680695, 18.63208008], [84.40625, 18.63208389], [84.40625, 18.63180542], [84.40598297, 18.63181114], [84.40598297, 18.63153076], [84.40569305, 18.63153076], [84.40569305, 18.63124847], [84.4054184, 18.63124847], [84.4054184, 18.63096809], [84.40513611, 18.63097191], [84.40513611, 18.63069534], [84.40486145, 18.63069916], [84.40486145, 18.63042068], [84.40458679, 18.63042068], [84.40458679, 18.6301384], [84.40429688, 18.6301384], [84.40429688, 18.62985992], [84.40374756, 18.62986183], [84.40374756, 18.62958336], [84.4034729, 18.62958336], [84.4034729, 18.62930489], [84.40319824, 18.62930489], [84.40319061, 18.62902832], [84.4026413, 18.62902832], [84.4026413, 18.62874985], [84.40235901, 18.62874985], [84.40235901, 18.62846947], [84.40208435, 18.62847137], [84.40208435, 18.62819481], [84.40180206, 18.62819481], [84.40180206, 18.62791634], [84.40125275, 18.62791824], [84.40125275, 18.62763977], [84.40097046, 18.62763977], [84.40097046, 18.62735939], [84.4006958, 18.6273613], [84.4006958, 18.62680626], [84.40040588, 18.62681007], [84.40040588, 18.62625122], [84.40013123, 18.62625122], [84.40013123, 18.62597084], [84.3998642, 18.62597275], [84.3998642, 18.62569427], [84.39958191, 18.62569427], [84.39958191, 18.6254158], [84.39930725, 18.62541962], [84.39930725, 18.62514114], [84.39875031, 18.62514114], [84.39875031, 18.62486076], [84.39847565, 18.62486076], [84.39847565, 18.6245842], [84.3979187, 18.6245842], [84.3979187, 18.62430573], [84.39763641, 18.62430954], [84.39763641, 18.62403107], [84.39736176, 18.62403107], [84.39736176, 18.62375069], [84.3970871, 18.62375069], [84.3970871, 18.62347031], [84.39680481, 18.62347221], [84.39680481, 18.62291718], [84.39653015, 18.62291718], [84.39653015, 18.6226387], [84.39624786, 18.62264061], [84.39624786, 18.62236023], [84.39597321, 18.62236023], [84.39597321, 18.62207985], [84.39569092, 18.62208366], [84.39569092, 18.62180519], [84.39541626, 18.62181091], [84.39541626, 18.62153053], [84.3951416, 18.62153053], [84.3951416, 18.62125015], [84.39485931, 18.62125015], [84.39485931, 18.62096977], [84.39430237, 18.62097359], [84.39430237, 18.62069511], [84.39402771, 18.62070084], [84.39402771, 18.62042046], [84.39375305, 18.62042046], [84.39375305, 18.61987114], [84.39319611, 18.61987114], [84.39319611, 18.61957932], [84.39291382, 18.61958122], [84.39291382, 18.61930466], [84.39263916, 18.61930466], [84.39263916, 18.61902809], [84.39235687, 18.61903191], [84.39235687, 18.61875153], [84.39180756, 18.61875153], [84.39180756, 18.61846924], [84.39125061, 18.61847115], [84.39125061, 18.61819458], [84.39097595, 18.61819458], [84.39097595, 18.61791611], [84.39068604, 18.61792183], [84.39068604, 18.61735916], [84.39041901, 18.61735916], [84.39041901, 18.61708069], [84.39013672, 18.6170826], [84.39013672, 18.61680603], [84.38986206, 18.61681175], [84.38986206, 18.61652756], [84.38957977, 18.61652756], [84.38957977, 18.61624908], [84.38931274, 18.61624908], [84.38931274, 18.61597061], [84.38847351, 18.61597252], [84.38847351, 18.61569405], [84.38764191, 18.61569405], [84.38764191, 18.61458397], [84.38735962, 18.61458397], [84.38735962, 18.6143055], [84.38707733, 18.61431122], [84.38707733, 18.61403084], [84.38680267, 18.61403084], [84.38680267, 18.61374092], [84.38652802, 18.61375046], [84.38652802, 18.61347198], [84.38625336, 18.61347198], [84.38625336, 18.61291695], [84.38597107, 18.61292076], [84.38597107, 18.61264038], [84.38540649, 18.61264038], [84.38540649, 18.61236], [84.38513947, 18.61236191], [84.38513947, 18.61208344], [84.38486481, 18.61208344], [84.38486481, 18.61180687], [84.3840332, 18.61181068], [84.3840332, 18.6115303], [84.38346863, 18.6115303], [84.38346863, 18.61124992], [84.38318634, 18.61124992], [84.38318634, 18.61067963], [84.38291931, 18.61069489], [84.38291931, 18.61041641], [84.38263702, 18.61042023], [84.38263702, 18.61013985], [84.38236237, 18.61013985], [84.38236237, 18.6095829], [84.38208008, 18.60958481], [84.38208008, 18.60930634], [84.38153076, 18.60931015], [84.38153076, 18.60902977], [84.38124847, 18.60902977], [84.38124847, 18.60874939], [84.38096619, 18.60874939], [84.38096619, 18.60819054], [84.38041687, 18.60819435], [84.38041687, 18.60791588], [84.37985992, 18.60793114], [84.37985992, 18.60736275], [84.37958527, 18.60736275], [84.37958527, 18.60708427], [84.37875366, 18.60708427], [84.37875366, 18.6068058], [84.37847137, 18.60680962], [84.37847137, 18.60653114], [84.37819672, 18.60653114], [84.37819672, 18.60625267], [84.3779068, 18.60625267], [84.3779068, 18.60597038], [84.37763977, 18.60597038], [84.37763977, 18.60541725], [84.37735748, 18.60542107], [84.37735748, 18.60514259], [84.37708282, 18.60514259], [84.37708282, 18.60487175], [84.37680817, 18.60487175], [84.37680817, 18.60457993], [84.37652588, 18.60458374], [84.37652588, 18.60430527], [84.37625122, 18.60430908], [84.37625122, 18.60346985], [84.37596893, 18.60347176], [84.37596893, 18.60319519], [84.37568665, 18.60320091], [84.37568665, 18.60263824], [84.37541962, 18.60263824], [84.37541962, 18.60235977], [84.37513733, 18.60236168], [84.37513733, 18.60208321], [84.37486267, 18.60208321], [84.37486267, 18.60180473], [84.37430573, 18.60180473], [84.37430573, 18.60152626], [84.37403107, 18.60152817], [84.37403107, 18.60124969], [84.37346649, 18.60124969], [84.37346649, 18.60097122], [84.37319183, 18.60097313], [84.37319183, 18.60069466], [84.37291718, 18.60069466], [84.37291718, 18.60013962], [84.37264252, 18.60013962], [84.37264252, 18.59986115], [84.37236023, 18.59986115], [84.37236023, 18.59958076], [84.37208557, 18.59958267], [84.37208557, 18.59930611], [84.37180328, 18.59930992], [84.37180328, 18.59902954], [84.37152863, 18.59902954], [84.37152863, 18.59847069], [84.37124634, 18.5984726], [84.37124634, 18.59819412], [84.37097168, 18.59819412], [84.37097168, 18.59791756], [84.37069702, 18.59791946], [84.37069702, 18.59764099], [84.3704071, 18.59764099], [84.3704071, 18.59708023], [84.37014008, 18.59708595], [84.37014008, 18.59680557], [84.36985779, 18.59680939], [84.36985779, 18.59653091], [84.36958313, 18.59653091], [84.36958313, 18.59625053], [84.36930847, 18.59625053], [84.36930847, 18.59570122], [84.36902618, 18.59570122], [84.36902618, 18.59542084], [84.36875153, 18.59542084], [84.36875153, 18.59514046], [84.36846924, 18.59514046], [84.36846924, 18.59486008], [84.36819458, 18.59486389], [84.36819458, 18.59458351], [84.36791992, 18.59458351], [84.36791992, 18.59402847], [84.36763763, 18.59403038], [84.36763763, 18.59375191], [84.36736298, 18.59375191], [84.36736298, 18.59346962], [84.36708069, 18.59347343], [84.36708069, 18.59319496], [84.36680603, 18.59320068], [84.36680603, 18.59264183], [84.36653137, 18.59264183], [84.36653137, 18.59235954], [84.36624908, 18.59235954], [84.36624908, 18.59208107], [84.36597443, 18.59208107], [84.36597443, 18.59180641], [84.36569214, 18.59181023], [84.36569214, 18.59124947], [84.36541748, 18.59124947], [84.36541748, 18.59096909], [84.36513519, 18.5909729], [84.36513519, 18.59069443], [84.36486053, 18.59069443], [84.36486053, 18.59041595], [84.36458588, 18.59042168], [84.36458588, 18.59013748], [84.36429596, 18.59013748], [84.36429596, 18.589571], [84.36402893, 18.58958244], [84.36402893, 18.58930588], [84.36374664, 18.58930969], [84.36374664, 18.58903122], [84.36347198, 18.58903122], [84.36347198, 18.58875084], [84.36319733, 18.58875084], [84.36319733, 18.58847046], [84.36291504, 18.58847237], [84.36291504, 18.58763885], [84.36264038, 18.58764076], [84.36264038, 18.58736038], [84.36235809, 18.58736038], [84.36235809, 18.58708], [84.36208344, 18.58708382], [84.36208344, 18.58680534], [84.36180878, 18.58680534], [84.36180878, 18.58625031], [84.36152649, 18.58625031], [84.36152649, 18.58485985], [84.36125183, 18.58486176], [84.36125183, 18.58430672], [84.36096954, 18.58430672], [84.36096954, 18.58402824], [84.36068726, 18.58403015], [84.36068726, 18.58346939], [84.36042023, 18.5834713], [84.36042023, 18.58208466], [84.36013794, 18.58208466], [84.36013794, 18.58180618], [84.35986328, 18.58181], [84.35986328, 18.58152962], [84.35958099, 18.58152962], [84.35958099, 18.58125114], [84.35930634, 18.58125114], [84.35930634, 18.58097267], [84.35902405, 18.58097267], [84.35902405, 18.5806942], [84.35874939, 18.58069992], [84.35874939, 18.58014107], [84.3584671, 18.58014107], [84.3584671, 18.57986259], [84.35819244, 18.57986259], [84.35819244, 18.57958031], [84.35791779, 18.57958412], [84.35791779, 18.57875252], [84.3576355, 18.57875252], [84.3576355, 18.57708359], [84.35736084, 18.57708359], [84.35736084, 18.57680511], [84.35708618, 18.57681084], [84.35708618, 18.57653046], [84.35679626, 18.57653046], [84.35679626, 18.57624817], [84.35652924, 18.57624817], [84.35652924, 18.5759697], [84.35624695, 18.5759716], [84.35624695, 18.57569504], [84.35597229, 18.57570076], [84.35597229, 18.57485962], [84.35569763, 18.57486153], [84.35569763, 18.5695858], [84.35597229, 18.5695858], [84.35597229, 18.56875038], [84.35569763, 18.56875992], [84.35569763, 18.56847191], [84.35541534, 18.56847382], [84.35541534, 18.56736374], [84.35514069, 18.56736374], [84.35514069, 18.56693077], [84.35514069, 18.56569481], [84.3548584, 18.56569481], [84.3548584, 18.56430626], [84.35457611, 18.56431007], [84.35457611, 18.5640316], [84.35430908, 18.5640316], [84.35430908, 18.56374931], [84.35402679, 18.56374931], [84.35402679, 18.56319046], [84.3536377, 18.56319237], [84.35319519, 18.56319427], [84.35319519, 18.5629158], [84.35180664, 18.56291962], [84.35180664, 18.5626297], [84.35069275, 18.56263733], [84.35069275, 18.56236076], [84.3501358, 18.56236076], [84.3501358, 18.56263733], [84.3493042, 18.56263733], [84.3493042, 18.56236076], [84.34819794, 18.56236076], [84.34819794, 18.56208038], [84.3465271, 18.56208038], [84.3465271, 18.56236076], [84.34625244, 18.56236076], [84.34625244, 18.56208038], [84.34597015, 18.5620842], [84.34597015, 18.56180573], [84.34513855, 18.56180954], [84.34513855, 18.56153107], [84.34430695, 18.56153107], [84.34430695, 18.56125069], [84.34401703, 18.56125069], [84.34401703, 18.56097031], [84.34375, 18.56097221], [84.34375, 18.56069374], [84.34347534, 18.56069374], [84.34347534, 18.5601387], [84.34319305, 18.56014061], [84.34319305, 18.55986023], [84.34291077, 18.55986023], [84.34291077, 18.55958939], [84.34263611, 18.55958939], [84.34263611, 18.55931091], [84.34236145, 18.55931091], [84.34236145, 18.55903053], [84.34208679, 18.55903053], [84.34208679, 18.55875015], [84.34179688, 18.55875015], [84.34179688, 18.55820084], [84.34152985, 18.55820084], [84.34152985, 18.55792046], [84.34124756, 18.55792046], [84.34124756, 18.55764008], [84.3409729, 18.55764008], [84.3409729, 18.55708122], [84.34081268, 18.55708313], [84.34069824, 18.55708313], [84.34069061, 18.55624962], [84.34041595, 18.55624962], [84.34041595, 18.55569077], [84.3401413, 18.55569458], [84.3401413, 18.55513954], [84.33985138, 18.55513954], [84.33985138, 18.55458069], [84.3401413, 18.55458069], [84.3401413, 18.55374908], [84.34041595, 18.5537529], [84.34041595, 18.55319023], [84.34069061, 18.55319214], [84.34069061, 18.55264091], [84.34041595, 18.55264282], [84.34041595, 18.55236244], [84.3401413, 18.55236244], [84.3401413, 18.55208015], [84.33985901, 18.55208397], [84.33985901, 18.5518055], [84.33957672, 18.55181122], [84.33957672, 18.55153275], [84.33930206, 18.55153275], [84.33930206, 18.55096817], [84.3390274, 18.55097008], [84.3390274, 18.55069351], [84.33985901, 18.55069351], [84.33985901, 18.55097008], [84.34041595, 18.55096817], [84.34041595, 18.55124855], [84.34124756, 18.55124855], [84.34124756, 18.55153275], [84.34152985, 18.55153275], [84.34152985, 18.55181122], [84.34179688, 18.55181122], [84.34179688, 18.55264282], [84.34152985, 18.55264091], [84.34152985, 18.55474091], [84.34152985, 18.55597305], [84.34179688, 18.55597115], [84.34179688, 18.55624962], [84.34208679, 18.55624962], [84.34208679, 18.55653], [84.34263611, 18.55652809], [84.34263611, 18.55680466], [84.3429184, 18.55680466], [84.3429184, 18.55708313], [84.34319305, 18.55708122], [84.34319305, 18.55764008], [84.34348297, 18.55764008], [84.34348297, 18.55792046], [84.34401703, 18.55792046], [84.34401703, 18.55820084], [84.34430695, 18.55819511], [84.34430695, 18.55847168], [84.3445816, 18.55846977], [84.3445816, 18.55875015], [84.34485626, 18.55875015], [84.34485626, 18.55903053], [84.34541321, 18.55903053], [84.34541321, 18.55931091], [84.34570312, 18.55931091], [84.34570312, 18.55958939], [84.3473587, 18.55958939], [84.3473587, 18.55986023], [84.3484726, 18.55986023], [84.3484726, 18.56014061], [84.34958649, 18.56014061], [84.34958649, 18.56042099], [84.35041809, 18.56041527], [84.35041809, 18.56069374], [84.35124969, 18.56069374], [84.35124969, 18.56097221], [84.35263824, 18.56097031], [84.35263824, 18.56125069], [84.3529129, 18.56125069], [84.3529129, 18.56153107], [84.35305786, 18.56153107], [84.35320282, 18.56153107], [84.35320282, 18.56180954], [84.35346985, 18.56180573], [84.35346985, 18.5620842], [84.35430908, 18.56208038], [84.35430908, 18.56236076], [84.35458374, 18.56236076], [84.35458374, 18.56263733], [84.35514069, 18.5626297], [84.35514069, 18.56291962], [84.35569763, 18.5629158], [84.35569763, 18.56319427], [84.35652924, 18.56319427], [84.35652924, 18.56125069], [84.35624695, 18.56125069], [84.35624695, 18.56068993], [84.35597229, 18.56069374], [84.35597229, 18.55986023], [84.35569763, 18.55986023], [84.35569763, 18.55958939], [84.35542297, 18.55958939], [84.35542297, 18.55846977], [84.35569763, 18.55847168], [84.35569763, 18.55819511], [84.35597229, 18.55820084], [84.35597229, 18.5573597], [84.35624695, 18.5573616], [84.35624695, 18.55680466], [84.35597229, 18.55680466], [84.35597229, 18.55652809], [84.35569763, 18.55653], [84.35569763, 18.55624962], [84.35514069, 18.55624962], [84.35514069, 18.55597115], [84.35430908, 18.55597305], [84.35430908, 18.55569458], [84.35375214, 18.55569458], [84.35375214, 18.55541611], [84.35346985, 18.55541992], [84.35346985, 18.55513954], [84.3529129, 18.55513954], [84.3529129, 18.55486107], [84.35263824, 18.55486107], [84.35263824, 18.55458069], [84.35236359, 18.55458069], [84.35236359, 18.55430603], [84.3520813, 18.55430984], [84.3520813, 18.55402946], [84.35180664, 18.55402946], [84.35180664, 18.5537529], [84.35124969, 18.5537529], [84.35124969, 18.55347252], [84.35097504, 18.55347252], [84.35097504, 18.55319214], [84.35069275, 18.55319214], [84.35069275, 18.55291748], [84.35041809, 18.55291939], [84.35041809, 18.55264282], [84.34986115, 18.55264282], [84.34986115, 18.55236244], [84.34958649, 18.55236244], [84.34958649, 18.55208015], [84.3493042, 18.55208397], [84.3493042, 18.5518055], [84.34903717, 18.55181122], [84.34903717, 18.55153275], [84.34874725, 18.55153275], [84.34874725, 18.55124855], [84.34819794, 18.55124855], [84.34819794, 18.55096817], [84.34791565, 18.55097008], [84.34791565, 18.55069542], [84.34764099, 18.55069351], [84.34764099, 18.55041695], [84.3473587, 18.55042076], [84.3473587, 18.55013847], [84.34680176, 18.55013847], [84.34680176, 18.54985809], [84.3465271, 18.54986191], [84.3465271, 18.54958344], [84.34625244, 18.54958344], [84.34625244, 18.54930496], [84.34597778, 18.54931068], [84.34597778, 18.5490284], [84.34570312, 18.5490284], [84.34570312, 18.54874992], [84.34513855, 18.54874992], [84.34513855, 18.54846954], [84.34486389, 18.54847145], [84.34486389, 18.54819489], [84.3445816, 18.54819489], [84.3445816, 18.54791641], [84.34430695, 18.54792023], [84.34430695, 18.54764748], [84.34375, 18.54764748], [84.34375, 18.54735947], [84.34347534, 18.54736137], [84.34347534, 18.5470829], [84.34319305, 18.5470829], [84.34319305, 18.54680634], [84.34291077, 18.54681015], [84.34291077, 18.54652977], [84.34236145, 18.54652977], [84.34236145, 18.54624939], [84.34208679, 18.54624939], [84.34208679, 18.54597092], [84.3418045, 18.54597282], [84.3418045, 18.54569435], [84.34152985, 18.54569435], [84.34152985, 18.54541588], [84.34124756, 18.54541969], [84.34124756, 18.54514122], [84.34069824, 18.54514122], [84.34069061, 18.54486084], [84.34041595, 18.54486084], [84.34041595, 18.54459], [84.3401413, 18.54459], [84.3401413, 18.54430962], [84.33985138, 18.54430962], [84.33985138, 18.54403114], [84.33930206, 18.54403114], [84.33930206, 18.54375076], [84.3390274, 18.54375076], [84.3390274, 18.54347038], [84.33875275, 18.54347229], [84.33875275, 18.54319572], [84.33847046, 18.54319572], [84.33847046, 18.54291725], [84.3381958, 18.54292107], [84.3381958, 18.54264069], [84.33766174, 18.54264069], [84.33763885, 18.54236031], [84.3373642, 18.54236031], [84.3373642, 18.54208374], [84.33719635, 18.54208374], [84.33708191, 18.54208374], [84.33708191, 18.54195023], [84.33708191, 18.54180527], [84.33693695, 18.54180527], [84.33680725, 18.54181099], [84.33680725, 18.54164124], [84.33680725, 18.5415287], [84.3366394, 18.5415287], [84.33625031, 18.54153061], [84.33625031, 18.54125977], [84.33598328, 18.54125023], [84.33597565, 18.54097366], [84.33583069, 18.54097366], [84.33569336, 18.54097366], [84.33569336, 18.54069519], [84.33542633, 18.54070282], [84.3354187, 18.54042053], [84.33513641, 18.54042053], [84.33513641, 18.54014015], [84.33460236, 18.54014015], [84.3345871, 18.53986168], [84.33430481, 18.53986359], [84.33430481, 18.5395813], [84.33403015, 18.5395813], [84.33403015, 18.53930473], [84.33374786, 18.53930473], [84.33374786, 18.53902817], [84.33319092, 18.53903008], [84.33319092, 18.5387516], [84.33291626, 18.5387516], [84.33291626, 18.53845978], [84.3326416, 18.53847313], [84.3326416, 18.53819466], [84.33235931, 18.53819466], [84.33235931, 18.53791618], [84.33207703, 18.53792191], [84.33207703, 18.53764153], [84.33152771, 18.53764153], [84.33152771, 18.53735924], [84.33125305, 18.53735924], [84.33125305, 18.53708076], [84.33097076, 18.53708267], [84.33097076, 18.53680611], [84.33069611, 18.53681183], [84.33069611, 18.53652763], [84.33013916, 18.53652763], [84.33013916, 18.53624916], [84.32985687, 18.53624916], [84.32985687, 18.53597069], [84.32958221, 18.5359726], [84.32958221, 18.53569412], [84.32930756, 18.53569412], [84.32930756, 18.53541756], [84.3290329, 18.53541756], [84.3290329, 18.53513908], [84.32847595, 18.53513908], [84.32847595, 18.53486061], [84.32818604, 18.53486061], [84.32818604, 18.53458023], [84.32791901, 18.53458405], [84.32791901, 18.53430557], [84.32763672, 18.53430939], [84.32763672, 18.53403091], [84.32707977, 18.53403091], [84.32707977, 18.53375053], [84.32680511, 18.53375053], [84.32680511, 18.53347206], [84.32653046, 18.53347206], [84.32653046, 18.53319359], [84.32624817, 18.53319359], [84.32624817, 18.53291512], [84.32596588, 18.53292084], [84.32596588, 18.53264809], [84.32541656, 18.53264809], [84.32541656, 18.53236008], [84.32514191, 18.53236198], [84.32514191, 18.53208351], [84.32485962, 18.53208351], [84.32485962, 18.53180695], [84.32457733, 18.53181076], [84.32457733, 18.53153038], [84.32402802, 18.53153038], [84.32402802, 18.53125], [84.32375336, 18.53125], [84.32375336, 18.53096962], [84.32347107, 18.53097153], [84.32347107, 18.53069305], [84.32319641, 18.53070068], [84.32319641, 18.5304203], [84.32263947, 18.5304203], [84.32263947, 18.53013992], [84.32235718, 18.53013992], [84.32235718, 18.52985954], [84.32208252, 18.52986145], [84.32208252, 18.52958488], [84.32180786, 18.52959061], [84.32180786, 18.52931023], [84.3215332, 18.52931023], [84.3215332, 18.52902985], [84.32096863, 18.52902985], [84.32096863, 18.52874947], [84.32068634, 18.52874947], [84.32068634, 18.5284729], [84.32041931, 18.52847481], [84.32041931, 18.52819443], [84.32013702, 18.52819443], [84.32013702, 18.52791595], [84.31958008, 18.52791977], [84.31958008, 18.52763939], [84.31930542, 18.52763939], [84.31930542, 18.52736282], [84.31903076, 18.52736282], [84.31903076, 18.52708054], [84.31874847, 18.52708054], [84.31874847, 18.52680588], [84.31846619, 18.52680969], [84.31846619, 18.52652168], [84.31791687, 18.5265274], [84.31791687, 18.52625275], [84.31764221, 18.52625275], [84.31764221, 18.52597046], [84.31735992, 18.52597046], [84.31735992, 18.52569389], [84.31708527, 18.52569389], [84.31708527, 18.52541733], [84.31652832, 18.52542114], [84.31652832, 18.52514267], [84.31624603, 18.52514267], [84.31624603, 18.52485847], [84.31597137, 18.52485847], [84.31597137, 18.52457809], [84.31569672, 18.52458382], [84.31569672, 18.52430534], [84.3154068, 18.52430916], [84.3154068, 18.52403069], [84.31485748, 18.52403069], [84.31485748, 18.5237484], [84.31458282, 18.5237484], [84.31458282, 18.52346039], [84.31430817, 18.52347183], [84.31430817, 18.52319527], [84.31402588, 18.52319908], [84.31402588, 18.52292061], [84.31346893, 18.52292061], [84.31346893, 18.52263832], [84.31318665, 18.52263832], [84.31318665, 18.52235985], [84.31291962, 18.52236176], [84.31291962, 18.52208328], [84.31236267, 18.52208328], [84.31236267, 18.52180481], [84.31208038, 18.52180481], [84.31208038, 18.52152634], [84.31181335, 18.52152824], [84.31181335, 18.52124977], [84.31124878, 18.52124977], [84.31124878, 18.52096939], [84.31097412, 18.5209713], [84.31097412, 18.52069473], [84.31069183, 18.52069473], [84.31069183, 18.52041626], [84.31041718, 18.52041817], [84.31041718, 18.52013969], [84.30986023, 18.52013969], [84.30986023, 18.51986122], [84.30958557, 18.51986122], [84.30958557, 18.51958275], [84.30930328, 18.51958275], [84.30930328, 18.51930618], [84.30874634, 18.51931], [84.30874634, 18.51902962], [84.30847168, 18.51902962], [84.30847168, 18.51875114], [84.30819702, 18.51875114], [84.30819702, 18.51847076], [84.30764008, 18.51847267], [84.30764008, 18.5181942], [84.30735779, 18.5181942], [84.30735779, 18.51791763], [84.30708313, 18.51791954], [84.30708313, 18.51764107], [84.30652618, 18.51764107], [84.30652618, 18.51736069], [84.30625153, 18.51736069], [84.30625153, 18.51708031], [84.30596924, 18.51708412], [84.30596924, 18.51680565], [84.30568695, 18.51680946], [84.30568695, 18.51653099], [84.30513763, 18.51653099], [84.30513763, 18.51625061], [84.30486298, 18.51625061], [84.30486298, 18.51597023], [84.30458069, 18.51597214], [84.30458069, 18.51569366], [84.30403137, 18.51569366], [84.30403137, 18.5154171], [84.30374146, 18.51542091], [84.30374146, 18.51514053], [84.3034668, 18.51514053], [84.3034668, 18.51486015], [84.30291748, 18.51486206], [84.30291748, 18.51458359], [84.30263519, 18.51458359], [84.30263519, 18.51430511], [84.30236053, 18.51431084], [84.30236053, 18.51403046], [84.30208588, 18.51403046], [84.30208588, 18.51375008], [84.30152893, 18.51375008], [84.30152893, 18.5134697], [84.30124664, 18.51347351], [84.30124664, 18.51319504], [84.30097198, 18.51320076], [84.30097198, 18.51292038], [84.30042267, 18.51292038], [84.30042267, 18.51264191], [84.30014038, 18.51264191], [84.30014038, 18.51235962], [84.29985809, 18.51235962], [84.29985809, 18.51208115], [84.29930878, 18.51208115], [84.29930878, 18.51180649], [84.29902649, 18.5118103], [84.29902649, 18.51151848], [84.29875183, 18.51152992], [84.29875183, 18.51125145], [84.29846954, 18.51125145], [84.29846954, 18.51096916], [84.29792023, 18.51097107], [84.29792023, 18.5106945], [84.29763794, 18.5106945], [84.29763794, 18.51041603], [84.29736328, 18.51042175], [84.29736328, 18.51014137], [84.29708099, 18.51014137], [84.29708099, 18.50985909], [84.29651642, 18.50985909], [84.29651642, 18.50958061], [84.29624939, 18.50958252], [84.29624939, 18.50930595], [84.2959671, 18.50930977], [84.2959671, 18.50902748], [84.29541779, 18.50902748], [84.29541779, 18.50875092], [84.2951355, 18.50875092], [84.2951355, 18.50847244], [84.29486847, 18.50847816], [84.29486847, 18.50819016], [84.29458618, 18.50819397], [84.29458618, 18.5079174], [84.29402924, 18.50792122], [84.29402924, 18.50764084], [84.29374695, 18.50764084], [84.29374695, 18.50736046], [84.29347229, 18.50736046], [84.29347229, 18.50708008], [84.29319763, 18.50708389], [84.29319763, 18.50680542], [84.29264069, 18.50681114], [84.29264069, 18.50653076], [84.2923584, 18.50653076], [84.2923584, 18.50625038], [84.29207611, 18.50625038], [84.29207611, 18.50597], [84.29180908, 18.50597191], [84.29180908, 18.50569534], [84.29125214, 18.50570107], [84.29125214, 18.50542068], [84.29096985, 18.50542068], [84.29096985, 18.5051403], [84.29070282, 18.5051403], [84.29070282, 18.50485992], [84.2904129, 18.50486183], [84.2904129, 18.50458336], [84.28986359, 18.50458336], [84.28986359, 18.50430679], [84.2895813, 18.50430679], [84.2895813, 18.50402832], [84.28930664, 18.50403023], [84.28930664, 18.50374985], [84.28874207, 18.50374985], [84.28874207, 18.50346947], [84.28847504, 18.50347137], [84.28847504, 18.50319481], [84.28819275, 18.50319481], [84.28819275, 18.50291634], [84.28791809, 18.50292015], [84.28791809, 18.50263977], [84.28736115, 18.50263977], [84.28736115, 18.50235176], [84.28708649, 18.5023613], [84.28708649, 18.50208473], [84.2868042, 18.50208473], [84.2868042, 18.50180626], [84.28652954, 18.50181007], [84.28652954, 18.50152969], [84.2859726, 18.50152969], [84.2859726, 18.50125122], [84.28569794, 18.50125122], [84.28569794, 18.50097275], [84.28541565, 18.50097275], [84.28541565, 18.50069427], [84.28514099, 18.50069427], [84.28514099, 18.5004158], [84.2848587, 18.50041962], [84.2848587, 18.50014114], [84.28430176, 18.50014114], [84.28430176, 18.49986267], [84.2840271, 18.49986267], [84.2840271, 18.49958038], [84.28375244, 18.4995842], [84.28375244, 18.49930573], [84.28347015, 18.49930954], [84.28347015, 18.49903107], [84.28320313, 18.49903107], [84.28320313, 18.49875259], [84.28291321, 18.49875259], [84.28291321, 18.49847031], [84.28263855, 18.49847031], [84.28263855, 18.49819374], [84.2820816, 18.49819374], [84.2820816, 18.49791718], [84.28180695, 18.49791908], [84.28180695, 18.49764061], [84.28151703, 18.49764061], [84.28151703, 18.49735832], [84.28125, 18.49735832], [84.28125, 18.49707985], [84.28097534, 18.49708366], [84.28097534, 18.49680519], [84.28069305, 18.49681091], [84.28069305, 18.49654007], [84.28013611, 18.49654007], [84.28013611, 18.49624825], [84.27986145, 18.49624825], [84.27986145, 18.49596977], [84.27958679, 18.49597168], [84.27958679, 18.49569511], [84.27929688, 18.49570084], [84.27929688, 18.49542046], [84.27902985, 18.49542046], [84.27902985, 18.49513817], [84.27874756, 18.49513817], [84.27874756, 18.4948597], [84.27819824, 18.4948616], [84.27819061, 18.49458313], [84.27791595, 18.49458313], [84.27791595, 18.49430466], [84.2776413, 18.49430466], [84.2776413, 18.49402618], [84.27735901, 18.49402809], [84.27735901, 18.49374962], [84.27707672, 18.49374962], [84.27707672, 18.49348068], [84.27680206, 18.49348068], [84.27680206, 18.49319077], [84.2765274, 18.49319458], [84.2765274, 18.49291611], [84.27597046, 18.49291992], [84.27597046, 18.49274254], [84.27597046, 18.49263954], [84.2756958, 18.49263954], [84.2756958, 18.49236107], [84.27540588, 18.49236107], [84.27540588, 18.49208069], [84.27513885, 18.4920826], [84.27513885, 18.49180412], [84.27485657, 18.49180984], [84.27485657, 18.49152946], [84.27458191, 18.49152946], [84.27458191, 18.49125099], [84.27403259, 18.49125099], [84.27403259, 18.49097061], [84.27375031, 18.49097252], [84.27375031, 18.49069595], [84.27347565, 18.49069595], [84.27347565, 18.49041748], [84.27319336, 18.49041748], [84.27319336, 18.49013901], [84.2729187, 18.49014091], [84.2729187, 18.48986053], [84.27263641, 18.48986053], [84.27263641, 18.48958015], [84.2720871, 18.48958588], [84.2720871, 18.4893055], [84.27179718, 18.48931122], [84.27179718, 18.48903084], [84.27153015, 18.48903084], [84.27153015, 18.48875046], [84.27124786, 18.48875046], [84.27124786, 18.48847008], [84.27097321, 18.48847389], [84.27097321, 18.48819542], [84.27069855, 18.4881897], [84.27069092, 18.48791695], [84.27041626, 18.48792076], [84.27041626, 18.48764038], [84.26985931, 18.48764038], [84.26985931, 18.48735237], [84.26958466, 18.48736382], [84.26958466, 18.48708344], [84.26930237, 18.48708344], [84.26930237, 18.48680496], [84.26902771, 18.48681068], [84.26902771, 18.4865303], [84.26875305, 18.4865303], [84.26875305, 18.48625183], [84.26847076, 18.48625183], [84.26847076, 18.48596954], [84.26791382, 18.48596954], [84.26791382, 18.48569489], [84.26763916, 18.48569489], [84.26763916, 18.48541641], [84.26735687, 18.48542023], [84.26735687, 18.48514175], [84.26708221, 18.48514175], [84.26708221, 18.48485947], [84.26680756, 18.48485947], [84.26680756, 18.4845829], [84.26652527, 18.4845829], [84.26652527, 18.48430634], [84.26625061, 18.48431015], [84.26625061, 18.48403168], [84.26568604, 18.48403168], [84.26568604, 18.48374939], [84.26541901, 18.48374939], [84.26541901, 18.48347092], [84.26513672, 18.48347282], [84.26513672, 18.48319435], [84.26486206, 18.48319435], [84.26486206, 18.48291588], [84.26457214, 18.48291969], [84.26457214, 18.48264122], [84.26431274, 18.48264122], [84.26431274, 18.48236084], [84.26374817, 18.48236084], [84.26374817, 18.48208046], [84.26347351, 18.48208427], [84.26347351, 18.4818058], [84.26319122, 18.48180962], [84.26319122, 18.48154068], [84.26291656, 18.48154068], [84.26291656, 18.48125076], [84.26264191, 18.48125076], [84.26264191, 18.48097038], [84.26235962, 18.48097229], [84.26235962, 18.48069382], [84.26180267, 18.48069382], [84.26180267, 18.48041725], [84.26152802, 18.48042107], [84.26152802, 18.48014069], [84.26125336, 18.48014069], [84.26125336, 18.47986031], [84.26097107, 18.47986031], [84.26097107, 18.47957993], [84.26069641, 18.47958374], [84.26069641, 18.47930527], [84.26040649, 18.47931099], [84.26040649, 18.47903061], [84.26013947, 18.47903061], [84.26013947, 18.47875023], [84.25958252, 18.47875023], [84.25958252, 18.47846985], [84.25930786, 18.47847176], [84.25930786, 18.47819519], [84.2590332, 18.47820091], [84.2590332, 18.47792053], [84.25875854, 18.47792053], [84.25875854, 18.47764015], [84.25846863, 18.47764015], [84.25846863, 18.47735977], [84.25819397, 18.47736168], [84.25819397, 18.47708321], [84.25763702, 18.47708321], [84.25763702, 18.47680473], [84.25736237, 18.47680473], [84.25736237, 18.47652817], [84.25708008, 18.47653008], [84.25708008, 18.47624969], [84.25680542, 18.47624969], [84.25680542, 18.47597313], [84.25653076, 18.47597313], [84.25653076, 18.47569466], [84.25624847, 18.47569466], [84.25624847, 18.47541618], [84.25569153, 18.47541618], [84.25569153, 18.47513962], [84.25541687, 18.47513962], [84.25541687, 18.47486115], [84.25514221, 18.47486115], [84.25514221, 18.47458267], [84.25485992, 18.47458458], [84.25485992, 18.47430611], [84.2545929, 18.47430992], [84.2545929, 18.47402954], [84.25430298, 18.47402954], [84.25430298, 18.47375107], [84.25402832, 18.47375107], [84.25402832, 18.4734726], [84.25347137, 18.4734726], [84.25347137, 18.47319412], [84.25319672, 18.47319412], [84.25319672, 18.47291756], [84.2529068, 18.47291946], [84.2529068, 18.4726429], [84.25263214, 18.4726429], [84.25263214, 18.47237015], [84.25235748, 18.47237015], [84.25235748, 18.47208023], [84.25208282, 18.47208405], [84.25208282, 18.47180557], [84.25180817, 18.47180939], [84.25180817, 18.47153282], [84.25152588, 18.47153282], [84.25152588, 18.47124863], [84.25125122, 18.47124863], [84.25125122, 18.47096825], [84.25069427, 18.47097015], [84.25069427, 18.47069359], [84.25041962, 18.47069359], [84.25041962, 18.47041893], [84.25013733, 18.47042084], [84.25013733, 18.47013855], [84.24986267, 18.47013855], [84.24986267, 18.46985817], [84.24958038, 18.46986008], [84.24958038, 18.46958351], [84.24930573, 18.46958351], [84.24930573, 18.46930504], [84.24903107, 18.46931076], [84.24903107, 18.46903038], [84.24874878, 18.46903038], [84.24874878, 18.46874809], [84.24846649, 18.46874809], [84.24846649, 18.46846962], [84.24819183, 18.46847153], [84.24819183, 18.46819496], [84.24791718, 18.46820068], [84.24791718, 18.4679203], [84.24736023, 18.4679203], [84.24736023, 18.46763992], [84.2470932, 18.46763992], [84.2470932, 18.46735954], [84.24680328, 18.46736145], [84.24680328, 18.46708298], [84.24652863, 18.46708298], [84.24652863, 18.46680641], [84.24624634, 18.46681023], [84.24624634, 18.46652985], [84.24597168, 18.46652985], [84.24597168, 18.46623993], [84.24569702, 18.46624947], [84.24569702, 18.4659729], [84.24541473, 18.4659729], [84.24541473, 18.46569443], [84.24514008, 18.46569443], [84.24514008, 18.46541405], [84.24485779, 18.46541977], [84.24485779, 18.46513939], [84.24458313, 18.46513939], [84.24458313, 18.46486092], [84.24402618, 18.46486092], [84.24402618, 18.46458054], [84.24375153, 18.46458244], [84.24375153, 18.46430588], [84.24346924, 18.46430969], [84.24346924, 18.46403122], [84.24318695, 18.46403122], [84.24318695, 18.46375084], [84.24291992, 18.46375084], [84.24291992, 18.46347046], [84.24263763, 18.46347237], [84.24263763, 18.4631958], [84.24236298, 18.4631958], [84.24236298, 18.46291733], [84.24208069, 18.46292114], [84.24208069, 18.46264076], [84.24180603, 18.46264076], [84.24180603, 18.46236038], [84.24153137, 18.46236038], [84.24153137, 18.46208], [84.24124908, 18.46208382], [84.24124908, 18.46180534], [84.24069214, 18.46181107], [84.24069214, 18.46153069], [84.24041748, 18.46153069], [84.24041748, 18.46125031], [84.24013519, 18.46125031], [84.24013519, 18.46097374], [84.23986053, 18.46097374], [84.23986053, 18.46069527], [84.23958588, 18.4607029], [84.23958588, 18.46043015], [84.23929596, 18.46043015], [84.23929596, 18.46014023], [84.23902893, 18.46014023], [84.23902893, 18.45986176], [84.23874664, 18.45986366], [84.23874664, 18.45958328], [84.23847198, 18.45958328], [84.23847198, 18.45930481], [84.23819733, 18.45930481], [84.23819733, 18.45902824], [84.23792267, 18.45903015], [84.23792267, 18.45875168], [84.23735809, 18.45875168], [84.23735809, 18.45846939], [84.23708344, 18.45846939], [84.23708344, 18.45819473], [84.23680878, 18.45819473], [84.23680878, 18.45791626], [84.23652649, 18.45792007], [84.23652649, 18.4576416], [84.23625183, 18.4576416], [84.23625183, 18.45737267], [84.23596954, 18.45737267], [84.23596954, 18.45708084], [84.23569489, 18.45708275], [84.23569489, 18.45680618], [84.23542023, 18.4568119], [84.23542023, 18.45652771], [84.23513794, 18.45652771], [84.23513794, 18.45624924], [84.23486328, 18.45624924], [84.23486328, 18.45597076], [84.23458099, 18.45597267], [84.23458099, 18.4556942], [84.23402405, 18.4556942], [84.23402405, 18.45541954], [84.23374939, 18.45541954], [84.23374939, 18.45513916], [84.2334671, 18.45513916], [84.2334671, 18.45486069], [84.23319244, 18.45486069], [84.23319244, 18.45458031], [84.23291779, 18.45458412], [84.23291779, 18.45430565], [84.2326355, 18.45430565], [84.2326355, 18.45402718], [84.23236084, 18.45403099], [84.23236084, 18.45375061], [84.23208618, 18.45375061], [84.23208618, 18.45347023], [84.23180389, 18.45347214], [84.23180389, 18.45319366], [84.23152924, 18.45319366], [84.23152924, 18.45291519], [84.23124695, 18.45292091], [84.23124695, 18.45264053], [84.23069763, 18.45264053], [84.23069763, 18.45236015], [84.23041534, 18.45236206], [84.23041534, 18.45208359], [84.23014069, 18.45208359], [84.23014069, 18.45180511], [84.2298584, 18.45181084], [84.2298584, 18.45153046], [84.22957611, 18.45153046], [84.22957611, 18.45124054], [84.22930908, 18.45125008], [84.22930908, 18.4509716], [84.22902679, 18.4509716], [84.22902679, 18.45069695], [84.22875214, 18.45070076], [84.22875214, 18.45042038], [84.22846222, 18.45042038], [84.22846222, 18.45014], [84.22820282, 18.45014], [84.22820282, 18.44985962], [84.2279129, 18.44986153], [84.2279129, 18.44958305], [84.22763824, 18.44958305], [84.22763824, 18.44930649], [84.22735596, 18.4493103], [84.22735596, 18.44902992], [84.22680664, 18.44902992], [84.22680664, 18.44874954], [84.22651672, 18.44874954], [84.22651672, 18.44847107], [84.22624969, 18.44847488], [84.22624969, 18.4481945], [84.22597504, 18.4481945], [84.22597504, 18.44791603], [84.22569275, 18.44791985], [84.22569275, 18.44763947], [84.22541809, 18.44763947], [84.22541809, 18.4473629], [84.2251358, 18.4473629], [84.2251358, 18.44708061], [84.22486115, 18.44708061], [84.22486115, 18.44680595], [84.22458649, 18.44680977], [84.22458649, 18.44652939], [84.22429657, 18.44652939], [84.22429657, 18.44625282], [84.22402954, 18.44625282], [84.22402954, 18.44597244], [84.22374725, 18.44597244], [84.22374725, 18.44569206], [84.2234726, 18.44569206], [84.2234726, 18.4454174], [84.22292328, 18.44543076], [84.22292328, 18.44514275], [84.22264862, 18.44514275], [84.22264862, 18.44486237], [84.2223587, 18.44486237], [84.2223587, 18.44457817], [84.22208405, 18.44458389], [84.22208405, 18.44430542], [84.22180176, 18.44430923], [84.22180176, 18.44403076], [84.2215271, 18.44403076], [84.2215271, 18.44374847], [84.22125244, 18.44374847], [84.22125244, 18.44346809], [84.22097015, 18.44347191], [84.22097015, 18.44319534], [84.22070313, 18.44319916], [84.22070313, 18.44292068], [84.22041321, 18.44292068], [84.22041321, 18.4426384], [84.22013855, 18.4426384], [84.22013855, 18.44235992], [84.21986389, 18.44236183], [84.21986389, 18.44208336], [84.2195816, 18.44208336], [84.2195816, 18.44180489], [84.21902466, 18.44180489], [84.21902466, 18.44152641], [84.21875, 18.44152832], [84.21875, 18.44124985], [84.21847534, 18.44124985], [84.21847534, 18.44097137], [84.21819305, 18.44097137], [84.21819305, 18.44069481], [84.2179184, 18.44069481], [84.2179184, 18.44041634], [84.21763611, 18.44042015], [84.21763611, 18.44013977], [84.21736145, 18.44013977], [84.21736145, 18.43985939], [84.21708679, 18.4398613], [84.21708679, 18.43958282], [84.2168045, 18.43958282], [84.2168045, 18.43930626], [84.21652985, 18.43930626], [84.21652985, 18.43902779], [84.21624756, 18.43902969], [84.21624756, 18.43875122], [84.2159729, 18.43875122], [84.2159729, 18.43847084], [84.21569824, 18.43847275], [84.21569061, 18.43819427], [84.21541595, 18.43819427], [84.21541595, 18.4379158], [84.2151413, 18.43791962], [84.2151413, 18.43764114], [84.21485901, 18.43764114], [84.21485901, 18.43736076], [84.21457672, 18.43736076], [84.21457672, 18.43708038], [84.21430206, 18.4370842], [84.21430206, 18.43680573], [84.2140274, 18.43680954], [84.2140274, 18.43653107], [84.21346283, 18.43653107], [84.21346283, 18.43626022], [84.2131958, 18.43626022], [84.2131958, 18.43597031], [84.21291351, 18.43597221], [84.21291351, 18.43569374], [84.21263885, 18.43569374], [84.21263885, 18.43541718], [84.21235657, 18.43542099], [84.21235657, 18.43514061], [84.21208191, 18.43514061], [84.21208191, 18.43486023], [84.21180725, 18.43486023], [84.21180725, 18.43457985], [84.21152496, 18.43458366], [84.21152496, 18.43430519], [84.21125031, 18.43431091], [84.21125031, 18.43403053], [84.21098328, 18.43403053], [84.21098328, 18.43375015], [84.21069336, 18.43375015], [84.21069336, 18.43346977], [84.2104187, 18.43347359], [84.2104187, 18.43319511], [84.21013641, 18.43320274], [84.21013641, 18.43292046], [84.20986176, 18.43292046], [84.20986176, 18.4323616], [84.2095871, 18.4323616], [84.2095871, 18.43208122], [84.20930481, 18.43208122], [84.20930481, 18.43180466], [84.20903015, 18.43180466], [84.20903015, 18.43152809], [84.20874786, 18.43153191], [84.20874786, 18.43125153], [84.20847321, 18.43125153], [84.20847321, 18.43096924], [84.20819092, 18.43097305], [84.20819092, 18.43069458], [84.20791626, 18.43069458], [84.20791626, 18.43041611], [84.2076416, 18.43042183], [84.2076416, 18.43014145], [84.20707703, 18.43014145], [84.20707703, 18.42985916], [84.20680237, 18.42985916], [84.20680237, 18.42958069], [84.20652771, 18.4295826], [84.20652771, 18.42930603], [84.20625305, 18.42930984], [84.20625305, 18.42902756], [84.20597076, 18.42902756], [84.20597076, 18.42874908], [84.20569611, 18.42874908], [84.20569611, 18.42847061], [84.20541382, 18.42847252], [84.20541382, 18.42819405], [84.20513916, 18.42819405], [84.20513916, 18.42791748], [84.20485687, 18.42791748], [84.20485687, 18.42764091], [84.2040329, 18.42764091], [84.2040329, 18.42736053], [84.20375061, 18.42736053], [84.20375061, 18.42707062], [84.20319366, 18.42708397], [84.20319366, 18.4268055], [84.20291901, 18.42681122], [84.20291901, 18.42653084], [84.20263672, 18.42653084], [84.20263672, 18.42625046], [84.20207977, 18.42625046], [84.20207977, 18.42570114], [84.20181274, 18.4256897], [84.20180511, 18.42541695], [84.20207977, 18.42542076], [84.20207977, 18.42514038], [84.20181274, 18.42514038], [84.20181274, 18.42486], [84.20153046, 18.42486191], [84.20153046, 18.42458344], [84.20097351, 18.42458344], [84.20097351, 18.42430687], [84.20069122, 18.42432022], [84.20069122, 18.4240303], [84.20041656, 18.4240303], [84.20041656, 18.42374992], [84.20014191, 18.42374992], [84.20014191, 18.42346954], [84.19985962, 18.42347145], [84.19985962, 18.42319489], [84.19958496, 18.42319489], [84.19958496, 18.42291641], [84.19902802, 18.42292023], [84.19902802, 18.42263985], [84.19875336, 18.42263985], [84.19875336, 18.42235947], [84.19847107, 18.42236137], [84.19847107, 18.42208481], [84.19819641, 18.42208481], [84.19819641, 18.42180634], [84.19790649, 18.42181015], [84.19790649, 18.42152977], [84.19763947, 18.42152977], [84.19763947, 18.42126083], [84.19708252, 18.42126083], [84.19708252, 18.42097282], [84.19680786, 18.42097282], [84.19680786, 18.42069435], [84.19652557, 18.42069435], [84.19652557, 18.42041588], [84.19596863, 18.42041969], [84.19596863, 18.42014122], [84.19568634, 18.42014122], [84.19568634, 18.41958046], [84.19541931, 18.41958427], [84.19541931, 18.41902733], [84.19513702, 18.41903114], [84.19513702, 18.41875267], [84.19486237, 18.41875267], [84.19486237, 18.41792107], [84.19431305, 18.41792107], [84.19431305, 18.41764069], [84.19403076, 18.41764069], [84.19403076, 18.4173584], [84.19374847, 18.4173584], [84.19374847, 18.41707993], [84.19347382, 18.41708374], [84.19347382, 18.41680527], [84.19319153, 18.41680908], [84.19319153, 18.41653061], [84.19291687, 18.41653061], [84.19291687, 18.41624832], [84.19264221, 18.41624832], [84.19264221, 18.41596985], [84.19208527, 18.41597176], [84.19208527, 18.41569519], [84.19180298, 18.41570091], [84.19180298, 18.41542053], [84.19097137, 18.41542053], [84.19097137, 18.41513062], [84.19041443, 18.41513824], [84.19041443, 18.41486168], [84.19013977, 18.41486168], [84.19013977, 18.41458321], [84.18985748, 18.41458321], [84.18985748, 18.41402626], [84.18930817, 18.41402817], [84.18930817, 18.41374969], [84.18902588, 18.41374969], [84.18902588, 18.41347122], [84.18875122, 18.41347313], [84.18875122, 18.41319466], [84.18846893, 18.41319466], [84.18846893, 18.41236115], [84.18818665, 18.41236115], [84.18818665, 18.41207123], [84.18791962, 18.41208267], [84.18791962, 18.4118042], [84.18763733, 18.41180992], [84.18763733, 18.41152954], [84.18736267, 18.41152954], [84.18736267, 18.41125107], [84.18708038, 18.41125107], [84.18708038, 18.41097069], [84.18680573, 18.4109726], [84.18680573, 18.41069412], [84.18653107, 18.41069412], [84.18653107, 18.41041756], [84.18624878, 18.41041946], [84.18624878, 18.41014099], [84.18596649, 18.41014099], [84.18596649, 18.40958023], [84.18569183, 18.40958595], [84.18569183, 18.40930557], [84.18541718, 18.40932083], [84.18541718, 18.40903091], [84.18514252, 18.40903091], [84.18514252, 18.40875053], [84.18486023, 18.40875053], [84.18486023, 18.40847015], [84.18458557, 18.40847206], [84.18458557, 18.40819359], [84.18430328, 18.40819359], [84.18430328, 18.40791702], [84.18402863, 18.40792084], [84.18402863, 18.40764046], [84.18374634, 18.40764046], [84.18374634, 18.40736008], [84.18347168, 18.40736389], [84.18347168, 18.40708351], [84.18319702, 18.40708351], [84.18319702, 18.40680504], [84.1829071, 18.40681076], [84.1829071, 18.40653038], [84.18264008, 18.40653038], [84.18264008, 18.40625954], [84.18235779, 18.40625954], [84.18235779, 18.40596962], [84.18208313, 18.40596962], [84.18208313, 18.40569496], [84.18180847, 18.40570068], [84.18180847, 18.4054203], [84.18152618, 18.4054203], [84.18152618, 18.40514183], [84.18125153, 18.40514183], [84.18125153, 18.40485954], [84.18096924, 18.40485954], [84.18096924, 18.40458107], [84.18069458, 18.40458107], [84.18069458, 18.40430641], [84.18041229, 18.40431023], [84.18041229, 18.40403175], [84.17986298, 18.40403175], [84.17986298, 18.40375137], [84.17958069, 18.40375137], [84.17958069, 18.40346909], [84.17930603, 18.4034729], [84.17930603, 18.40319443], [84.17903137, 18.40319443], [84.17903137, 18.40291595], [84.17874908, 18.40291977], [84.17874908, 18.40263748], [84.1784668, 18.40263748], [84.1784668, 18.40236092], [84.17819214, 18.40236092], [84.17819214, 18.40208054], [84.17791748, 18.40208244], [84.17791748, 18.40180588], [84.17764282, 18.40180969], [84.17764282, 18.40153122], [84.17735291, 18.40153122], [84.17735291, 18.40125084], [84.17708588, 18.40125084], [84.17708588, 18.40097046], [84.17680359, 18.40097237], [84.17680359, 18.40069389], [84.17652893, 18.40069389], [84.17652893, 18.40041733], [84.17624664, 18.40042114], [84.17624664, 18.40013123], [84.17597198, 18.40013885], [84.17597198, 18.39986038], [84.17569733, 18.39986038], [84.17569733, 18.39958], [84.17541504, 18.39958382], [84.17541504, 18.39930534], [84.17514038, 18.39931107], [84.17514038, 18.39875031], [84.17485809, 18.39875031], [84.17485809, 18.39846992], [84.17458344, 18.39847183], [84.17458344, 18.39819527], [84.17430878, 18.39820099], [84.17430878, 18.39792061], [84.17402649, 18.39792061], [84.17402649, 18.39764023], [84.17375183, 18.39764023], [84.17375183, 18.39735985], [84.17346954, 18.39736176], [84.17346954, 18.39708328], [84.17318726, 18.39709091], [84.17318726, 18.39680099], [84.17292023, 18.39680481], [84.17292023, 18.39652824], [84.17263794, 18.39653015], [84.17263794, 18.39624977], [84.17236328, 18.39624977], [84.17236328, 18.39596939], [84.17208099, 18.3959713], [84.17208099, 18.39569473], [84.17180634, 18.39569473], [84.17180634, 18.39541626], [84.17151642, 18.39542007], [84.17151642, 18.39486122], [84.17124939, 18.39486122], [84.17124939, 18.39458275], [84.17097473, 18.39458466], [84.17097473, 18.39430618], [84.17069244, 18.39431953], [84.17069244, 18.39402962], [84.17041779, 18.39402962], [84.17041779, 18.39375114], [84.17014313, 18.39375114], [84.17014313, 18.39347267], [84.16986084, 18.39347267], [84.16986084, 18.3931942], [84.16958618, 18.3931942], [84.16958618, 18.39291763], [84.16929626, 18.39291954], [84.16929626, 18.39264107], [84.16902924, 18.39264107], [84.16902924, 18.39236259], [84.16874695, 18.39236259], [84.16874695, 18.39208031], [84.16847229, 18.39208412], [84.16847229, 18.39180565], [84.16819763, 18.39180946], [84.16819763, 18.3915329], [84.16792297, 18.3915329], [84.16792297, 18.3912487], [84.16764069, 18.3912487], [84.16764069, 18.39096069], [84.1673584, 18.39097023], [84.1673584, 18.39069366], [84.16708374, 18.39069366], [84.16708374, 18.3904171], [84.16680908, 18.39042091], [84.16680908, 18.39014053], [84.16652679, 18.39014053], [84.16652679, 18.38985825], [84.16625214, 18.38986015], [84.16625214, 18.38958359], [84.16596985, 18.38958359], [84.16596985, 18.38930511], [84.16570282, 18.38931084], [84.16570282, 18.38874817], [84.1654129, 18.38874817], [84.1654129, 18.3884697], [84.16513824, 18.3884716], [84.16513824, 18.38819504], [84.16486359, 18.38819504], [84.16486359, 18.38791656], [84.1645813, 18.38792038], [84.1645813, 18.38763809], [84.16430664, 18.38763809], [84.16430664, 18.38735962], [84.16402435, 18.38736153], [84.16402435, 18.38708305], [84.16374969, 18.38708305], [84.16374969, 18.38680649], [84.16348267, 18.3868103], [84.16348267, 18.38652992], [84.16319275, 18.38652992], [84.16319275, 18.38624954], [84.16291809, 18.38624954], [84.16291809, 18.38597107], [84.1626358, 18.38597298], [84.1626358, 18.3856945], [84.16236115, 18.3856945], [84.16236115, 18.38541412], [84.16208649, 18.38541985], [84.16208649, 18.38515091], [84.16179657, 18.38515091], [84.16179657, 18.38486099], [84.16152954, 18.38486099], [84.16152954, 18.38458061], [84.16124725, 18.38458252], [84.16124725, 18.38430405], [84.1609726, 18.38430977], [84.1609726, 18.38402939], [84.16069794, 18.38402939], [84.16069794, 18.38375092], [84.16041565, 18.38375092], [84.16041565, 18.38347244], [84.16014099, 18.38347244], [84.16014099, 18.38319588], [84.1598587, 18.38319588], [84.1598587, 18.3829174], [84.15957642, 18.38292122], [84.15957642, 18.38264084], [84.15930939, 18.38264084], [84.15930939, 18.38236046], [84.1590271, 18.38236046], [84.1590271, 18.38208961], [84.15875244, 18.38208961], [84.15875244, 18.38181114], [84.15847015, 18.38181114], [84.15847015, 18.38153076], [84.15820312, 18.38153076], [84.15820312, 18.38125038], [84.15791321, 18.38125038], [84.15791321, 18.38097191], [84.15763855, 18.38097382], [84.15763855, 18.38069534], [84.15735626, 18.38070107], [84.15735626, 18.38042068], [84.1570816, 18.38042068], [84.1570816, 18.3801403], [84.15680695, 18.3801403], [84.15680695, 18.37986183], [84.15652466, 18.37986374], [84.15652466, 18.37958336], [84.15625, 18.37958336], [84.15625, 18.37930489], [84.15597534, 18.37930489], [84.15597534, 18.37902832], [84.15569305, 18.37902832], [84.15569305, 18.37875175], [84.1554184, 18.37875175], [84.1554184, 18.37846947], [84.15513611, 18.37846947], [84.15513611, 18.37819481], [84.15486145, 18.37819481], [84.15486145, 18.37791634], [84.15458679, 18.37792015], [84.15458679, 18.37764168], [84.15429688, 18.37764168], [84.15429688, 18.37735939], [84.15402985, 18.37735939], [84.15402985, 18.37708282], [84.15374756, 18.37708282], [84.15374756, 18.37680626], [84.1534729, 18.37681007], [84.1534729, 18.3765316], [84.15319824, 18.3765316], [84.15318298, 18.3759594], [84.15291595, 18.37597275], [84.15291595, 18.37569427], [84.1526413, 18.37569427], [84.1526413, 18.3754158], [84.15235901, 18.37541962], [84.15235901, 18.37514114], [84.15207672, 18.37514114], [84.15207672, 18.37486076], [84.15180206, 18.37486076], [84.15180206, 18.37458038], [84.1515274, 18.3745842], [84.1515274, 18.37430573], [84.15125275, 18.37430954], [84.15125275, 18.37403107], [84.15097046, 18.37403107], [84.15097046, 18.37375069], [84.1506958, 18.37375069], [84.1506958, 18.37347031], [84.15041351, 18.37347221], [84.15041351, 18.37291527], [84.15013885, 18.37292099], [84.15013885, 18.37236023], [84.14958191, 18.37236023], [84.14958191, 18.37207985], [84.14930725, 18.37208366], [84.14930725, 18.37180519], [84.14903259, 18.37181091], [84.14903259, 18.37125015], [84.14875031, 18.37125015], [84.14875031, 18.37042046], [84.14848328, 18.37042046], [84.14848328, 18.3698597], [84.14819336, 18.3698616], [84.14819336, 18.36930466], [84.1479187, 18.36930466], [84.1479187, 18.36874962], [84.14763641, 18.36874962], [84.14763641, 18.36847115], [84.14736176, 18.36847305], [84.14736176, 18.36819458], [84.1470871, 18.36819458], [84.1470871, 18.36736107], [84.14679718, 18.36736107], [84.14679718, 18.36652946], [84.14653015, 18.36652946], [84.14653015, 18.36597252], [84.14624786, 18.36597252], [84.14624786, 18.36569405], [84.14597321, 18.36569405], [84.14597321, 18.36402702], [84.14569092, 18.36402702], [84.14569092, 18.36374855], [84.14541626, 18.36374855], [84.14541626, 18.36319923], [84.1451416, 18.3631897], [84.1451416, 18.36263847], [84.14485931, 18.36263847], [84.14485931, 18.36235809], [84.14430237, 18.36236191], [84.14430237, 18.36208344], [84.14402771, 18.36208344], [84.14402771, 18.36124992], [84.14375305, 18.36124992], [84.14375305, 18.36086273], [84.14375305, 18.36069489], [84.14347076, 18.36069489], [84.14347076, 18.36013985], [84.14319611, 18.36013985], [84.14319611, 18.35985947], [84.14291382, 18.35986137], [84.14291382, 18.35930634], [84.14263916, 18.35931015], [84.14263916, 18.35874939], [84.14235687, 18.35874939], [84.14235687, 18.35847092], [84.14208221, 18.35847282], [84.14208221, 18.35819435], [84.14180756, 18.35819435], [84.14180756, 18.35791588], [84.1415329, 18.35791969], [84.1415329, 18.35764122], [84.14124298, 18.35764122], [84.14124298, 18.35680962], [84.14097595, 18.35680962], [84.14097595, 18.35625076], [84.14068604, 18.35625076], [84.14068604, 18.35597038], [84.14041901, 18.35597229], [84.14041901, 18.35569382], [84.14013672, 18.35569382], [84.14013672, 18.35541725], [84.13986206, 18.35542107], [84.13986206, 18.35485268], [84.13957977, 18.35486031], [84.13957977, 18.35458374], [84.13930511, 18.35458374], [84.13930511, 18.3540287], [84.13903046, 18.35403061], [84.13903046, 18.35375023], [84.13874817, 18.35375023], [84.13874817, 18.35320282], [84.13846588, 18.35320282], [84.13846588, 18.35264015], [84.13819885, 18.35264015], [84.13819885, 18.35178947], [84.13791656, 18.35180473], [84.13791656, 18.3512516], [84.13764191, 18.3512516], [84.13764191, 18.35069084], [84.13735962, 18.35069466], [84.13735962, 18.34985924], [84.13708496, 18.34985924], [84.13708496, 18.34930611], [84.13652802, 18.34930992], [84.13652802, 18.34903908], [84.13597107, 18.34903908], [84.13597107, 18.34874916], [84.13569641, 18.34874916], [84.13569641, 18.34847069], [84.13541412, 18.3484726], [84.13541412, 18.34819412], [84.13513947, 18.34819412], [84.13513947, 18.34791946], [84.13485718, 18.34791946], [84.13485718, 18.34763908], [84.13458252, 18.34763908], [84.13458252, 18.34736061], [84.13430786, 18.34736061], [84.13430786, 18.34708405], [84.13319397, 18.34708405], [84.13319397, 18.34680557], [84.13208008, 18.34680939], [84.13208008, 18.34736061], [84.13180542, 18.34736061], [84.13180542, 18.3484726], [84.13124847, 18.34847069], [84.13124847, 18.34930992], [84.13041687, 18.34930611], [84.13041687, 18.34958267], [84.12985992, 18.34958076], [84.12985992, 18.34985924], [84.12930298, 18.34985924], [84.12930298, 18.35014153], [84.12902832, 18.35014153], [84.12902832, 18.35042191], [84.12847137, 18.35041618], [84.12847137, 18.35069466], [84.12819672, 18.35069466], [84.12819672, 18.35097313], [84.1279068, 18.35096931], [84.1279068, 18.3512516], [84.12708282, 18.3512516], [84.12708282, 18.35153008], [84.12652588, 18.35152817], [84.12652588, 18.35180473], [84.12596893, 18.35180473], [84.12596893, 18.35152817], [84.12568665, 18.35153008], [84.12568665, 18.3512516], [84.12596893, 18.3512516], [84.12596893, 18.35096931], [84.12625122, 18.35097313], [84.12625122, 18.35069466], [84.12680817, 18.35069466], [84.12680817, 18.35014153], [84.12708282, 18.35014153], [84.12708282, 18.34958076], [84.12735748, 18.34958267], [84.12735748, 18.34930611], [84.12763977, 18.34930992], [84.12763977, 18.34903908], [84.12735748, 18.34903908], [84.12735748, 18.34819031], [84.12708282, 18.34819412], [84.12708282, 18.34680557], [84.12735748, 18.34680939], [84.12735748, 18.34653091], [84.1279068, 18.34653091], [84.1279068, 18.34680939], [84.12819672, 18.34680557], [84.12819672, 18.34708405], [84.1279068, 18.34708023], [84.1279068, 18.34791946], [84.12819672, 18.34791946], [84.12819672, 18.34763908], [84.12847137, 18.34763908], [84.12847137, 18.34736061], [84.12874603, 18.34736061], [84.12874603, 18.34708023], [84.12902832, 18.34708405], [84.12902832, 18.34597206], [84.12847137, 18.34597969], [84.12847137, 18.34568977], [84.12819672, 18.34569359], [84.12819672, 18.34541512], [84.1279068, 18.34542084], [84.1279068, 18.34514046], [84.12819672, 18.34514046], [84.12819672, 18.34486008], [84.12875366, 18.34486198], [84.12875366, 18.34458351], [84.12902832, 18.34458351], [84.12902832, 18.34430695], [84.12930298, 18.34431076], [84.12930298, 18.34320068], [84.12847137, 18.34320068], [84.12847137, 18.34291077], [84.12625885, 18.34291077], [84.12625885, 18.34320068], [84.12569427, 18.34319305], [84.12569427, 18.34347153], [84.12486267, 18.34347153], [84.12486267, 18.34319305], [84.12431335, 18.34320068], [84.12431335, 18.34291077], [84.12486267, 18.34291649], [84.12486267, 18.34263802], [84.12513733, 18.34263992], [84.12513733, 18.34235954], [84.12569427, 18.34236145], [84.12569427, 18.34208488], [84.12596893, 18.34208488], [84.12596893, 18.34152794], [84.12625885, 18.34152985], [84.12625885, 18.34124947], [84.12680817, 18.34124947], [84.12680817, 18.3409729], [84.12735748, 18.34097481], [84.12735748, 18.34041595], [84.12708282, 18.34041977], [84.12708282, 18.33992195], [84.12680817, 18.33987045], [84.12680817, 18.33903122], [84.12652588, 18.33903122], [84.12652588, 18.33847237], [84.12680817, 18.33847237], [84.12680817, 18.33708382], [84.12708282, 18.33708382], [84.12708282, 18.33680534], [84.12735748, 18.33680916], [84.12735748, 18.3362484], [84.12708282, 18.3362484], [84.12708282, 18.33513832], [84.12680817, 18.33513832], [84.12680817, 18.33403969], [84.12652588, 18.33403969], [84.12652588, 18.33292007], [84.12625885, 18.33292007], [84.12625885, 18.33181], [84.12596893, 18.33181], [84.12596893, 18.33014107], [84.12568665, 18.33014107], [84.12568665, 18.32875061], [84.12541962, 18.32875061], [84.12541962, 18.32818985], [84.12486267, 18.32819366], [84.12486267, 18.32847214], [84.12458038, 18.32847023], [84.12458038, 18.32875061], [84.12346649, 18.32875061], [84.12346649, 18.32707977], [84.12374878, 18.32708359], [84.12374878, 18.32652855], [84.12403107, 18.32653046], [84.12403107, 18.32570267], [84.12431335, 18.32570267], [84.12431335, 18.32542038], [84.12458038, 18.32542038], [84.12458038, 18.32514191], [84.12486267, 18.32514191], [84.12486267, 18.32484818], [84.12513733, 18.32486153], [84.12513733, 18.32458115], [84.12596893, 18.32457924], [84.12596893, 18.32570267], [84.12625122, 18.32569504], [84.12625122, 18.32625008], [84.12680817, 18.32625008], [84.12680817, 18.32653046], [84.12708282, 18.32653046], [84.12708282, 18.32625008], [84.12735748, 18.32625008], [84.12735748, 18.32484818], [84.12763977, 18.32486153], [84.12763977, 18.32291603], [84.1279068, 18.32291985], [84.1279068, 18.32069016], [84.12819672, 18.32069397], [84.12819672, 18.31958389], [84.12847137, 18.31958389], [84.12847137, 18.31902695], [84.12874603, 18.31903076], [84.12874603, 18.31847], [84.12902832, 18.31847191], [84.12902832, 18.31819534], [84.12930298, 18.31820107], [84.12930298, 18.3176403], [84.1295929, 18.3176403], [84.1295929, 18.31680107], [84.12930298, 18.31680489], [84.12930298, 18.31597137], [84.12958527, 18.31597137], [84.12958527, 18.31569481], [84.12985992, 18.31569481], [84.12985992, 18.31513977], [84.12958527, 18.31513977], [84.12958527, 18.31430626], [84.12902832, 18.31431007], [84.12902832, 18.31402969], [84.12847137, 18.31402969], [84.12847137, 18.31375122], [84.12819672, 18.31375122], [84.12819672, 18.31347275], [84.12763977, 18.31347275], [84.12763977, 18.31319427], [84.12735748, 18.31319427], [84.12735748, 18.3129158], [84.12708282, 18.3129158], [84.12708282, 18.3120842], [84.12680817, 18.3120842], [84.12680817, 18.31152725], [84.12652588, 18.31153107], [84.12652588, 18.31125259], [84.12596893, 18.31125259], [84.12596893, 18.3109684], [84.12569427, 18.31097031], [84.12569427, 18.31041718], [84.12541962, 18.31041908], [84.12541962, 18.31014061], [84.12513733, 18.31014061], [84.12513733, 18.30987167], [84.12486267, 18.30987167], [84.12486267, 18.30957985], [84.12458038, 18.30958366], [84.12458038, 18.30930519], [84.12403107, 18.30931091], [84.12403107, 18.30903053], [84.12346649, 18.30903053], [84.12346649, 18.30874825], [84.12291718, 18.30874825], [84.12291718, 18.30846977], [84.12264252, 18.30847168], [84.12264252, 18.30819511], [84.1220932, 18.30820084], [84.1220932, 18.30792046], [84.12097168, 18.30792046], [84.12097168, 18.30820084], [84.12014008, 18.30820084], [84.12014008, 18.30792046], [84.11985779, 18.30792046], [84.11985779, 18.30763817], [84.11958313, 18.30763817], [84.11958313, 18.3073597], [84.11902618, 18.3073616], [84.11902618, 18.30708313], [84.11875153, 18.30708313], [84.11875153, 18.30680466], [84.11859894, 18.30680847], [84.11846924, 18.30681038], [84.11846924, 18.30652809], [84.11818695, 18.30652809], [84.11818695, 18.30624962], [84.11763763, 18.30624962], [84.11763763, 18.30597115], [84.11708069, 18.30597305], [84.11708069, 18.30569458], [84.11680603, 18.30569458], [84.11680603, 18.30541611], [84.11624908, 18.30541992], [84.11624908, 18.30513954], [84.11569214, 18.30513954], [84.11569214, 18.30486107], [84.11541748, 18.30486107], [84.11541748, 18.30458069], [84.11486053, 18.3045826], [84.11486053, 18.30430412], [84.11429596, 18.30430984], [84.11429596, 18.30402946], [84.11402893, 18.30402946], [84.11402893, 18.30373955], [84.11347198, 18.30374908], [84.11347198, 18.30347252], [84.11319733, 18.30347252], [84.11319733, 18.30319595], [84.11264038, 18.30319595], [84.11264038, 18.30291748], [84.11207581, 18.30291939], [84.11207581, 18.30264091], [84.11180878, 18.30264091], [84.11180878, 18.30236053], [84.11125183, 18.30236053], [84.11125183, 18.30208206], [84.11069489, 18.30208206], [84.11069489, 18.3018055], [84.11042023, 18.30181122], [84.11042023, 18.30153084], [84.10986328, 18.30153084], [84.10986328, 18.30125046], [84.10930634, 18.30125046], [84.10930634, 18.30097008], [84.10902405, 18.30097389], [84.10902405, 18.30069542], [84.1084671, 18.30068016], [84.10847473, 18.30041695], [84.10791779, 18.30042076], [84.10791779, 18.30014038], [84.10764313, 18.30014038], [84.10764313, 18.29986191], [84.10708618, 18.29986382], [84.10708618, 18.29958344], [84.10652924, 18.29958344], [84.10652924, 18.29930496], [84.10624695, 18.29931068], [84.10624695, 18.2990303], [84.10569763, 18.2990303], [84.10569763, 18.29875183], [84.10513306, 18.29875183], [84.10513306, 18.29846954], [84.1048584, 18.29846954], [84.1048584, 18.29819489], [84.10430908, 18.29819489], [84.10430908, 18.29791641], [84.10375214, 18.29792976], [84.10375214, 18.29764175], [84.10346985, 18.29764175], [84.10346985, 18.29735947], [84.1029129, 18.29735947], [84.1029129, 18.2970829], [84.10263824, 18.2970829], [84.10263824, 18.29680634], [84.10206604, 18.29681015], [84.10206604, 18.29653168], [84.10151672, 18.29653168], [84.10151672, 18.29624748], [84.10124969, 18.29624748], [84.10124969, 18.29597092], [84.10069275, 18.29597282], [84.10069275, 18.29569435], [84.1001358, 18.29569435], [84.1001358, 18.29541588], [84.09986115, 18.29541969], [84.09986115, 18.29514122], [84.09929657, 18.29514122], [84.09929657, 18.29486847], [84.09874725, 18.29486847], [84.09874725, 18.29458046], [84.0984726, 18.29458427], [84.0984726, 18.2943058], [84.09792328, 18.29430962], [84.09792328, 18.29403114], [84.0973587, 18.29403114], [84.0973587, 18.29375076], [84.09680176, 18.29375076], [84.09680176, 18.29347038], [84.0965271, 18.29347229], [84.0965271, 18.29319382], [84.09597015, 18.29319382], [84.09597015, 18.29291534], [84.09541321, 18.29292107], [84.09541321, 18.29264069], [84.09485626, 18.29264069], [84.09485626, 18.29236031], [84.0945816, 18.29236031], [84.0945816, 18.29207993], [84.09402466, 18.29208374], [84.09402466, 18.29180527], [84.09347534, 18.29180527], [84.09347534, 18.2915287], [84.0929184, 18.29153061], [84.0929184, 18.29125023], [84.09263611, 18.29125023], [84.09263611, 18.29096985], [84.09208679, 18.29097176], [84.09208679, 18.29069519], [84.09152985, 18.29070091], [84.09152985, 18.29042053], [84.09124756, 18.29042053], [84.09124756, 18.29014015], [84.09069824, 18.29014015], [84.09069061, 18.28985977], [84.0901413, 18.28986168], [84.0901413, 18.28958321], [84.08958435, 18.28958321], [84.08958435, 18.28930473], [84.08930206, 18.28930473], [84.08930206, 18.28902817], [84.08875275, 18.28903008], [84.08875275, 18.28874016], [84.08847046, 18.28874016], [84.08847046, 18.28903008], [84.08790588, 18.28903008], [84.08790588, 18.28874016], [84.08763885, 18.28874969], [84.08763885, 18.28819466], [84.0873642, 18.28819466], [84.0873642, 18.28791618], [84.08598328, 18.28792], [84.08598328, 18.28763962], [84.08569336, 18.28763962], [84.08569336, 18.28541946], [84.0854187, 18.28541946], [84.0854187, 18.2851429], [84.08513641, 18.2851429], [84.08513641, 18.28486252], [84.08486176, 18.28486252], [84.08486176, 18.28457832], [84.08430481, 18.28458405], [84.08430481, 18.28430557], [84.08403015, 18.28430939], [84.08403015, 18.28403091], [84.08374786, 18.28403091], [84.08374786, 18.28374863], [84.08403015, 18.28374863], [84.08403015, 18.28346825], [84.08291626, 18.28347015], [84.08291626, 18.28319359], [84.08208466, 18.28319359], [84.08208466, 18.28291893], [84.08180237, 18.28293037], [84.08180237, 18.28264046], [84.08152771, 18.28264046], [84.08152771, 18.28235817], [84.08097076, 18.28236008], [84.08097076, 18.28208351], [84.08069611, 18.28208351], [84.08069611, 18.28153038], [84.07985687, 18.28153038], [84.07985687, 18.28124809], [84.07958221, 18.28124809], [84.07958221, 18.28096962], [84.07930756, 18.28097153], [84.07930756, 18.28069496], [84.07847595, 18.28070068], [84.07847595, 18.2804203], [84.07818604, 18.2804203], [84.07818604, 18.28013992], [84.07763672, 18.28013992], [84.07763672, 18.27985954], [84.07736206, 18.27986145], [84.07736206, 18.27958298], [84.07707977, 18.27958298], [84.07707977, 18.27902794], [84.07681274, 18.27902985], [84.07681274, 18.27874947], [84.07653046, 18.27874947], [84.07653046, 18.27819061], [84.07624817, 18.27819443], [84.07624817, 18.27791405], [84.07596588, 18.27791977], [84.07596588, 18.27763939], [84.07541656, 18.27763939], [84.07541656, 18.27736092], [84.07457733, 18.27736092], [84.07457733, 18.27708054], [84.07402802, 18.27708244], [84.07402802, 18.27680588], [84.07375336, 18.27680588], [84.07375336, 18.2765274], [84.07209015, 18.27653122], [84.07209015, 18.27625084], [84.07041931, 18.27625084], [84.07041931, 18.27597046], [84.06958008, 18.27597237], [84.06958008, 18.2756958], [84.06903076, 18.2756958], [84.06903076, 18.27541733], [84.06846619, 18.27542114], [84.06846619, 18.27514076], [84.06791687, 18.27514076], [84.06791687, 18.27486038], [84.06735992, 18.27486038], [84.06735992, 18.27458191], [84.06680298, 18.27458382], [84.06680298, 18.27430534], [84.06624603, 18.27431107], [84.06624603, 18.27403069], [84.06569672, 18.27403069], [84.06569672, 18.27375984], [84.06485748, 18.27375984], [84.06485748, 18.27347183], [84.06430817, 18.27347374], [84.06430817, 18.27319527], [84.06375122, 18.2732029], [84.06375122, 18.27292061], [84.06318665, 18.27292061], [84.06318665, 18.27264023], [84.06263733, 18.27264023], [84.06263733, 18.27236176], [84.06208038, 18.27236176], [84.06208038, 18.27208328], [84.06153107, 18.27208328], [84.06153107, 18.27180481], [84.06097412, 18.27180481], [84.06097412, 18.27152824], [84.06015015, 18.27153015], [84.06015015, 18.27125168], [84.05958557, 18.27125168], [84.05958557, 18.27096939], [84.05902863, 18.27096939], [84.05902863, 18.27069473], [84.05847168, 18.27070045], [84.05847168, 18.27042007], [84.0579071, 18.27042007], [84.0579071, 18.2701416], [84.05735779, 18.2701416], [84.05735779, 18.26985931], [84.05680847, 18.26985931], [84.05680847, 18.26958084], [84.05596924, 18.26958275], [84.05596924, 18.26930618], [84.05541992, 18.26930809], [84.05541992, 18.26902962], [84.05486298, 18.26902962], [84.05486298, 18.26874924], [84.05430603, 18.26874924], [84.05430603, 18.26847076], [84.05374908, 18.26847267], [84.05374908, 18.2681942], [84.05319214, 18.2681942], [84.05319214, 18.26791954], [84.05264282, 18.26791954], [84.05264282, 18.26762962], [84.05208588, 18.26763725], [84.05208588, 18.26736069], [84.05124664, 18.26736069], [84.05124664, 18.26708031], [84.05069733, 18.26708412], [84.05069733, 18.26680565], [84.05014038, 18.26680946], [84.05014038, 18.26653099], [84.04957581, 18.26653099], [84.04957581, 18.26625061], [84.04902649, 18.26625061], [84.04902649, 18.26597023], [84.04846954, 18.26597214], [84.04846954, 18.26569366], [84.04792023, 18.26569366], [84.04792023, 18.26541519], [84.04736328, 18.26542091], [84.04736328, 18.26514053], [84.04651642, 18.26514053], [84.04651642, 18.26486015], [84.04597473, 18.26486206], [84.04597473, 18.26458359], [84.04541779, 18.26458359], [84.04541779, 18.26430511], [84.04485321, 18.26431084], [84.04485321, 18.26403046], [84.04429626, 18.26403046], [84.04429626, 18.26375008], [84.04374695, 18.26375008], [84.04374695, 18.2634697], [84.04291534, 18.2634716], [84.04291534, 18.26319313], [84.0423584, 18.26320076], [84.0423584, 18.26292038], [84.04180908, 18.26292038], [84.04180908, 18.26264], [84.04125214, 18.26264], [84.04125214, 18.26235962], [84.04013824, 18.26236153], [84.04013824, 18.26208305], [84.03930664, 18.26208305], [84.03930664, 18.26180649], [84.03901672, 18.26181984], [84.03901672, 18.26152992], [84.03874969, 18.26152992], [84.03874969, 18.26124954], [84.03819275, 18.26124954], [84.03819275, 18.26097107], [84.0376358, 18.26097488], [84.0376358, 18.2606945], [84.03708649, 18.2606945], [84.03708649, 18.26041603], [84.03652954, 18.26041985], [84.03652954, 18.26013947], [84.03569794, 18.26013947], [84.03569794, 18.2598629], [84.03514099, 18.2598629], [84.03514099, 18.25958252], [84.03458405, 18.25958252], [84.03458405, 18.25930595], [84.0340271, 18.25930977], [84.0340271, 18.25902939], [84.03347015, 18.25902939], [84.03347015, 18.25876045], [84.03291321, 18.25876045], [84.03291321, 18.25847244], [84.0320816, 18.25847244], [84.0320816, 18.25819397], [84.03152466, 18.25819397], [84.03152466, 18.2579174], [84.03098297, 18.25792122], [84.03098297, 18.25764084], [84.0304184, 18.25764084], [84.0304184, 18.25735855], [84.02984619, 18.25735855], [84.02984619, 18.25707817], [84.0293045, 18.25708389], [84.0293045, 18.25680542], [84.0284729, 18.25680923], [84.0284729, 18.25653076], [84.02791595, 18.25653076], [84.02791595, 18.25624847], [84.02735901, 18.25624847], [84.02735901, 18.25596809], [84.02680206, 18.25597191], [84.02680206, 18.25569534], [84.02625275, 18.25569534], [84.02625275, 18.25541878], [84.0256958, 18.25542068], [84.0256958, 18.2551384], [84.02485657, 18.2551384], [84.02485657, 18.25485992], [84.02430725, 18.25486183], [84.02430725, 18.25458336], [84.02375031, 18.25458336], [84.02375031, 18.25430489], [84.02319336, 18.25430489], [84.02319336, 18.25402641], [84.02263641, 18.25403023], [84.02263641, 18.25374985], [84.0220871, 18.25374985], [84.0220871, 18.25346947], [84.02153015, 18.25347137], [84.02153015, 18.25319481], [84.02097321, 18.25319481], [84.02097321, 18.25291634], [84.02041626, 18.25292015], [84.02041626, 18.25263023], [84.01985931, 18.25263977], [84.01985931, 18.2523613], [84.01930237, 18.2523613], [84.01930237, 18.25208282], [84.01875305, 18.25208282], [84.01875305, 18.25180435], [84.01819611, 18.25181007], [84.01819611, 18.25152969], [84.01763916, 18.25152969], [84.01763916, 18.25125122], [84.01708221, 18.25125122], [84.01708221, 18.25097084], [84.01652527, 18.25097275], [84.01652527, 18.25069427], [84.01597595, 18.25069427], [84.01597595, 18.25097275], [84.01513672, 18.25097275], [84.01513672, 18.25069427], [84.01403046, 18.25069427], [84.01403046, 18.2504158], [84.01264191, 18.25041962], [84.01264191, 18.25014114], [84.0118103, 18.25014114], [84.0118103, 18.24986076], [84.01125336, 18.24986076], [84.01125336, 18.24958992], [84.01097107, 18.24958992], [84.01097107, 18.24930954], [84.01069641, 18.24930954], [84.01069641, 18.24903107], [84.01040649, 18.24903107], [84.01040649, 18.24818993], [84.01013947, 18.24819374], [84.01013947, 18.24791718], [84.00985718, 18.24792099], [84.00985718, 18.24764061], [84.00958252, 18.24764061], [84.00958252, 18.24792099], [84.0090332, 18.24792099], [84.0090332, 18.24764061], [84.00875092, 18.24764061], [84.00875092, 18.24736023], [84.00846863, 18.24736023], [84.00846863, 18.24707985], [84.00791931, 18.24708366], [84.00791931, 18.24680519], [84.00763702, 18.24682045], [84.00763702, 18.24653053], [84.00736237, 18.24653053], [84.00736237, 18.24625015], [84.00680542, 18.24625015], [84.00680542, 18.24597359], [84.00597382, 18.24597359], [84.00597382, 18.24569511], [84.00541687, 18.24570274], [84.00541687, 18.24542046], [84.00485992, 18.24541664], [84.00485992, 18.24597359], [84.00458527, 18.24597359], [84.0045929, 18.24625015], [84.00402832, 18.24625015], [84.00402832, 18.24597168], [84.00375366, 18.24597359], [84.00375366, 18.24569511], [84.00347137, 18.24570274], [84.00347137, 18.24542046], [84.00319672, 18.24542046], [84.00319672, 18.2448616], [84.00291443, 18.2448616], [84.00291443, 18.24402809], [84.00235748, 18.24403191], [84.00235748, 18.24375153], [84.00180817, 18.24375153], [84.00180817, 18.24346924], [84.00125122, 18.24347305], [84.00125122, 18.24319458], [84.00069427, 18.24319458], [84.00069427, 18.24291611], [83.9998703, 18.24292183], [83.99903107, 18.24292183], [83.99903107, 18.24263763], [83.99846649, 18.24263763], [83.99846649, 18.24235916], [83.99819183, 18.24235916], [83.99819183, 18.24208069], [83.99764252, 18.2420826], [83.99764252, 18.24180794], [83.99736023, 18.24180984], [83.99736023, 18.24152756], [83.99652863, 18.24152756], [83.99652863, 18.24124908], [83.99624634, 18.24124908], [83.99624634, 18.24097061], [83.99569702, 18.24097252], [83.99569702, 18.24069405], [83.99541473, 18.24069405], [83.99541473, 18.24041939], [83.99485779, 18.24041939], [83.99485779, 18.24014091], [83.99430847, 18.24014091], [83.99430847, 18.23986053], [83.99373627, 18.23986053], [83.99373627, 18.23958015], [83.99319458, 18.23958397], [83.99319458, 18.2393055], [83.99263763, 18.23931122], [83.99263763, 18.23903084], [83.99208069, 18.23903084], [83.99208069, 18.23875046], [83.99124908, 18.23875046], [83.99124908, 18.23847008], [83.99069214, 18.23847198], [83.99069214, 18.23819542], [83.99014282, 18.2381897], [83.99013519, 18.23791695], [83.98958588, 18.23792076], [83.98958588, 18.23764992], [83.98902893, 18.23764992], [83.98902893, 18.23736], [83.98847198, 18.23736191], [83.98847198, 18.23708344], [83.98791504, 18.23708344], [83.98791504, 18.23680305], [83.98735809, 18.23681068], [83.98735809, 18.2365303], [83.98680878, 18.2365303], [83.98680878, 18.23624992], [83.98625183, 18.23624992], [83.98625183, 18.23596954], [83.98569489, 18.23597145], [83.98569489, 18.23569489], [83.98513794, 18.23569489], [83.98513794, 18.23541641], [83.98430634, 18.23542023], [83.98430634, 18.23513985], [83.98401642, 18.23513985], [83.98401642, 18.23485947], [83.98347473, 18.23486137], [83.98347473, 18.23458481], [83.98264313, 18.23459053], [83.98264313, 18.23431015], [83.98208618, 18.23431015], [83.98208618, 18.23402977], [83.98152924, 18.23402977], [83.98152924, 18.23374939], [83.98097229, 18.23374939], [83.98097229, 18.23347282], [83.98041534, 18.23347282], [83.98041534, 18.23319435], [83.98014069, 18.23319435], [83.98014069, 18.23291588], [83.97957611, 18.23291969], [83.97957611, 18.23264122], [83.97846985, 18.23264122], [83.97846985, 18.23236275], [83.97819519, 18.23236275], [83.97819519, 18.23208427], [83.97763824, 18.23208427], [83.97763824, 18.2318058], [83.9770813, 18.23180962], [83.9770813, 18.23153114], [83.97651672, 18.23153114], [83.97651672, 18.23125267], [83.97597504, 18.23125267], [83.97597504, 18.23097229], [83.97569275, 18.23097229], [83.97569275, 18.23069382], [83.97541809, 18.23069382], [83.97541809, 18.23041725], [83.97458649, 18.23041916], [83.97458649, 18.23014069], [83.97402954, 18.23014069], [83.97402954, 18.2298584], [83.9734726, 18.2298584], [83.9734726, 18.22957993], [83.97264099, 18.22958374], [83.97264099, 18.22930527], [83.9723587, 18.22930908], [83.9723587, 18.22903061], [83.97207642, 18.22903061], [83.97207642, 18.22874832], [83.97041321, 18.22874832], [83.97041321, 18.22820091], [83.97013855, 18.22820091], [83.97013855, 18.22792053], [83.96985626, 18.22792053], [83.96985626, 18.22763824], [83.96956635, 18.22763824], [83.96956635, 18.22735977], [83.96930695, 18.22736168], [83.96930695, 18.22708321], [83.96875, 18.22708321], [83.96875, 18.22680473], [83.96819305, 18.22680473], [83.96819305, 18.22652626], [83.96763611, 18.22653008], [83.96763611, 18.22624969], [83.96708679, 18.22624969], [83.96708679, 18.22597122], [83.9668045, 18.22597313], [83.9668045, 18.22569466], [83.96624756, 18.22569466], [83.96624756, 18.22541618], [83.96541595, 18.22542], [83.96541595, 18.22513962], [83.96457672, 18.22513962], [83.96457672, 18.22486115], [83.96430206, 18.22486115], [83.96430206, 18.22458076], [83.9640274, 18.22458267], [83.9640274, 18.2243042], [83.96376038, 18.22430992], [83.96376038, 18.22402954], [83.96235657, 18.22402954], [83.96235657, 18.22375107], [83.96208191, 18.22375107], [83.96208191, 18.22347069], [83.96152496, 18.2234726], [83.96152496, 18.22319412], [83.96125031, 18.22319412], [83.96125031, 18.22291756], [83.96099091, 18.22291946], [83.96099091, 18.22265053], [83.9604187, 18.22265053], [83.9604187, 18.22236061], [83.96013641, 18.22236061], [83.96013641, 18.22208023], [83.95903015, 18.22208214], [83.95903015, 18.22180557], [83.95874786, 18.22180939], [83.95874786, 18.22153091], [83.95847321, 18.22153091], [83.95847321, 18.22125053], [83.95819092, 18.22125053], [83.95819092, 18.22097015], [83.95680237, 18.22097206], [83.95680237, 18.22069359], [83.95652771, 18.22069359], [83.95652771, 18.22041702], [83.95597076, 18.22042084], [83.95597076, 18.22014046], [83.95540619, 18.22014046], [83.95540619, 18.21986008], [83.9548645, 18.21986389], [83.9548645, 18.21958351], [83.95456696, 18.21959114], [83.95456696, 18.21931076], [83.95430756, 18.21931076], [83.95430756, 18.21903038], [83.95347595, 18.21903038], [83.95347595, 18.21875191], [83.95291901, 18.21875191], [83.95291901, 18.21846962], [83.95236206, 18.21846962], [83.95236206, 18.21819496], [83.95182037, 18.21820259], [83.95182037, 18.2179203], [83.95153046, 18.2179203], [83.95153046, 18.21764183], [83.95124817, 18.21764183], [83.95124817, 18.21736145], [83.95097351, 18.21736145], [83.95097351, 18.21708107], [83.95069122, 18.21708107], [83.95069122, 18.21680641], [83.94958496, 18.21680641], [83.94958496, 18.21708107], [83.94902802, 18.21708107], [83.94902802, 18.21680641], [83.94876099, 18.21681023], [83.94876099, 18.21624756], [83.94819641, 18.21624756], [83.94819641, 18.21596909], [83.94708252, 18.2159729], [83.94708252, 18.21569443], [83.94625092, 18.21569443], [83.94625092, 18.21541595], [83.94486237, 18.21541977], [83.94486237, 18.21513748], [83.94458008, 18.21513748], [83.94458008, 18.21486092], [83.94403076, 18.21486092], [83.94403076, 18.21458054], [83.94319153, 18.21458244], [83.94319153, 18.21430779], [83.94235992, 18.21430969], [83.94235992, 18.21403122], [83.93875122, 18.21403122], [83.93875122, 18.21430969], [83.93653107, 18.21430969], [83.93653107, 18.21403122], [83.93569183, 18.21403122], [83.93569183, 18.21430969], [83.93430328, 18.21430969], [83.93430328, 18.21375084], [83.9345932, 18.21375084], [83.93458557, 18.21291542], [83.93486023, 18.21292114], [83.93486023, 18.21264076], [83.93514252, 18.21264076], [83.93514252, 18.21236038], [83.93541718, 18.21236038], [83.93541718, 18.21208], [83.93624878, 18.21208382], [83.93624878, 18.21180534], [83.93653107, 18.21181107], [83.93653107, 18.21153069], [83.93682098, 18.21153069], [83.93682098, 18.21125031], [83.93708038, 18.21125031], [83.93708038, 18.21071053], [83.93596649, 18.21071053], [83.93596649, 18.21042061], [83.93430328, 18.21042061], [83.93430328, 18.21014023], [83.93402863, 18.21014023], [83.93402863, 18.20985985], [83.93291473, 18.20986176], [83.93291473, 18.20958328], [83.93235779, 18.20958328], [83.93235779, 18.20902824], [83.93208313, 18.20903015], [83.93208313, 18.20874977], [83.93102264, 18.20874977], [83.92903137, 18.20874977], [83.92903137, 18.20846939], [83.92763519, 18.2084713], [83.92763519, 18.20819473], [83.92708588, 18.20819473], [83.92708588, 18.20791626], [83.92624664, 18.20792007], [83.92624664, 18.20763969], [83.92346954, 18.20763969], [83.92346954, 18.20736122], [83.92236328, 18.20736122], [83.92236328, 18.20708275], [83.92152405, 18.20708275], [83.92152405, 18.20680618], [83.92069244, 18.20681], [83.92069244, 18.20652962], [83.92041779, 18.20652962], [83.92041779, 18.20625114], [83.91929626, 18.20625114], [83.91929626, 18.20652962], [83.91897583, 18.20652771], [83.91819763, 18.20652962], [83.91819763, 18.20625114], [83.91764069, 18.20625114], [83.91764069, 18.20597267], [83.91708374, 18.20597267], [83.91708374, 18.2056942], [83.91625214, 18.2056942], [83.91625214, 18.20541763], [83.91539764, 18.20541954], [83.91539764, 18.20514107], [83.9145813, 18.20514107], [83.9145813, 18.20486259], [83.91374969, 18.20486259], [83.91374969, 18.20458031], [83.91291809, 18.20458412], [83.91291809, 18.20430565], [83.91179657, 18.20430946], [83.91179657, 18.20402908], [83.91124725, 18.20402908], [83.91124725, 18.20375061], [83.90957642, 18.20375061], [83.90957642, 18.20346832], [83.9081955, 18.20347023], [83.9081955, 18.20319366], [83.90763855, 18.20319366], [83.90763855, 18.2029171], [83.9070816, 18.20292091], [83.9070816, 18.20264053], [83.90680695, 18.20264053], [83.90680695, 18.20235825], [83.90652466, 18.20236206], [83.90652466, 18.20208359], [83.9054184, 18.20208359], [83.9054184, 18.20180511], [83.90429688, 18.20181084], [83.90429688, 18.20152092], [83.9034729, 18.20153046], [83.9034729, 18.20124817], [83.90319824, 18.20124817], [83.90319824, 18.20153046], [83.90235901, 18.20153046], [83.90235901, 18.20124817], [83.90125275, 18.20124817], [83.90125275, 18.2009697], [83.90097046, 18.2009716], [83.90097046, 18.20069695], [83.90042114, 18.20070076], [83.90042114, 18.20042038], [83.89901733, 18.20042038], [83.89901733, 18.20013809], [83.89848328, 18.20013809], [83.89848328, 18.19985962], [83.89819336, 18.19986153], [83.89819336, 18.19958305], [83.89763641, 18.19958305], [83.89763641, 18.1993084], [83.89653015, 18.1993103], [83.89653015, 18.19902992], [83.89597321, 18.19902992], [83.89597321, 18.19874954], [83.89541626, 18.19874954], [83.89541626, 18.19848061], [83.89457703, 18.19848061], [83.89457703, 18.19819069], [83.89263916, 18.1981945], [83.89263916, 18.19791412], [83.89208221, 18.19791985], [83.89208221, 18.19763947], [83.89180756, 18.19763947], [83.89180756, 18.19736099], [83.89125061, 18.19736099], [83.89125061, 18.19708061], [83.89069366, 18.19708252], [83.89069366, 18.19680405], [83.88931274, 18.19680977], [83.88931274, 18.19625092], [83.88874817, 18.19625092], [83.88874817, 18.19597054], [83.88847351, 18.19597244], [83.88847351, 18.19569588], [83.88819122, 18.19569588], [83.88819122, 18.1954174], [83.88791656, 18.19542122], [83.88791656, 18.19514084], [83.88707733, 18.19514084], [83.88707733, 18.19542122], [83.88625336, 18.19542122], [83.88625336, 18.19514084], [83.88597107, 18.19514084], [83.88597107, 18.19486046], [83.88569641, 18.19486046], [83.88569641, 18.19458008], [83.88486481, 18.19458389], [83.88486481, 18.19402695], [83.88458252, 18.19403076], [83.88458252, 18.19375038], [83.88430786, 18.19375038], [83.88430786, 18.19347191], [83.88375092, 18.19347382], [83.88375092, 18.19319534], [83.88263702, 18.19320107], [83.88263702, 18.19292068], [83.88234711, 18.19292068], [83.88234711, 18.1926403], [83.88181305, 18.1926403], [83.88181305, 18.19234848], [83.88124847, 18.19236183], [83.88124847, 18.19208336], [83.88014221, 18.19208336], [83.88014221, 18.19152832], [83.87985992, 18.19153023], [83.87985992, 18.19125175], [83.87957764, 18.19125175], [83.87957764, 18.19096947], [83.87875366, 18.19096947], [83.87875366, 18.19069481], [83.87847137, 18.19069481], [83.87847137, 18.19041634], [83.8779068, 18.19042015], [83.8779068, 18.19014168], [83.87735748, 18.19014168], [83.87735748, 18.18985939], [83.87708282, 18.18985939], [83.87708282, 18.18958282], [83.87680817, 18.18958282], [83.87680817, 18.18930626], [83.87654114, 18.18930817], [83.87654114, 18.18902969], [83.87625122, 18.18902969], [83.87625122, 18.18819046], [83.87569427, 18.18819427], [83.87569427, 18.1879158], [83.87486267, 18.18791962], [83.87486267, 18.18764114], [83.87458038, 18.18764114], [83.87458038, 18.18625069], [83.87430573, 18.18625069], [83.87430573, 18.18597221], [83.87403107, 18.18597221], [83.87403107, 18.18486023], [83.87431335, 18.18486023], [83.87430573, 18.18430519], [83.87403107, 18.18431091], [83.87403107, 18.18403053], [83.87374878, 18.18403053], [83.87374878, 18.18375015], [83.87347412, 18.18375015], [83.87347412, 18.18347168], [83.87319183, 18.18348122], [83.87319183, 18.18320084], [83.87291718, 18.18320084], [83.87291718, 18.18292046], [83.87264252, 18.18292046], [83.87264252, 18.18264008], [83.87236023, 18.18264008], [83.87236023, 18.1823597], [83.87208557, 18.1823616], [83.87208557, 18.18208313], [83.87152863, 18.18208313], [83.87152863, 18.18180466], [83.87124634, 18.18180466], [83.87124634, 18.18152809], [83.87097168, 18.18153], [83.87097168, 18.18124962], [83.87069702, 18.18124962], [83.87069702, 18.18069267], [83.87041473, 18.18069458], [83.87041473, 18.18041611], [83.87014008, 18.18041611], [83.87014008, 18.18013954], [83.86985779, 18.18013954], [83.86985779, 18.17986107], [83.86958313, 18.17986107], [83.86958313, 18.1795826], [83.86819458, 18.1795826], [83.86819458, 18.17930603], [83.86734772, 18.17930984], [83.86734772, 18.17902946], [83.86708069, 18.17902946], [83.86708069, 18.1787529], [83.86624908, 18.1787529], [83.86624908, 18.17847252], [83.86569214, 18.17847252], [83.86569214, 18.17819405], [83.86541748, 18.17819405], [83.86541748, 18.17791748], [83.86514282, 18.17791939], [83.86514282, 18.17764282], [83.86460114, 18.17764282], [83.86460114, 18.17734909], [83.86430359, 18.17735863], [83.86430359, 18.17708397], [83.86347198, 18.17708397], [83.86347198, 18.1768055], [83.86319733, 18.17680931], [83.86319733, 18.17624855], [83.86291504, 18.17624855], [83.86291504, 18.17597008], [83.86264038, 18.17597008], [83.86264038, 18.17569542], [83.86125183, 18.1756897], [83.86125183, 18.17541885], [83.86068726, 18.17542076], [83.86068726, 18.17514038], [83.86042023, 18.17514038], [83.86042023, 18.17485809], [83.85986328, 18.17486191], [83.85986328, 18.17458344], [83.85874939, 18.17458344], [83.85874939, 18.17430496], [83.85817719, 18.17431068], [83.85817719, 18.1740303], [83.85791779, 18.1740303], [83.85791779, 18.17374992], [83.8576355, 18.17374992], [83.8576355, 18.17347145], [83.85708618, 18.17347145], [83.85708618, 18.17319489], [83.85652924, 18.17319489], [83.85652924, 18.17291641], [83.85597229, 18.17292023], [83.85597229, 18.17263985], [83.85430908, 18.17263985], [83.85430908, 18.17235947], [83.85346985, 18.17235947], [83.85346985, 18.17263985], [83.85320282, 18.17263985], [83.85320282, 18.17235947], [83.85097504, 18.17236137], [83.85097504, 18.17180634], [83.85124969, 18.17181015], [83.85124969, 18.17154121], [83.85041809, 18.17154121], [83.85041809, 18.17124939], [83.84958649, 18.17124939], [83.84958649, 18.17097282], [83.84874725, 18.17097282], [83.84874725, 18.17069435], [83.84819794, 18.17069435], [83.84819794, 18.17041588], [83.8473587, 18.17041969], [83.8473587, 18.17014122], [83.8465271, 18.17014122], [83.8465271, 18.16986084], [83.8456955, 18.16986084], [83.8456955, 18.16958427], [83.84486389, 18.16958427], [83.84486389, 18.1693058], [83.84401703, 18.16930962], [83.84401703, 18.16903114], [83.8431778, 18.16903114], [83.8431778, 18.16875076], [83.84236145, 18.16875076], [83.84236145, 18.16847038], [83.8418045, 18.16847229], [83.8418045, 18.16819382], [83.8409729, 18.16819382], [83.8409729, 18.16791725], [83.8401413, 18.16792107], [83.8401413, 18.16764069], [83.83930206, 18.16764069], [83.83930206, 18.16736031], [83.83790588, 18.16736031], [83.83790588, 18.16764069], [83.83763885, 18.16764069], [83.83763885, 18.16736031], [83.8373642, 18.16736031], [83.8373642, 18.16708374], [83.83680725, 18.16708374], [83.83680725, 18.16680527], [83.83625031, 18.1668129], [83.83625031, 18.16653061], [83.83569336, 18.16653061], [83.83569336, 18.16625023], [83.8354187, 18.16625023], [83.8354187, 18.16597176], [83.83486176, 18.16597366], [83.83486176, 18.16569519], [83.83403015, 18.16570282], [83.83403015, 18.16540909], [83.83319092, 18.16541672], [83.83319092, 18.16513824], [83.83180237, 18.16514015], [83.83180237, 18.16486168], [83.82958221, 18.16486168], [83.82958221, 18.16458321], [83.82930756, 18.16458321], [83.82930756, 18.16402817], [83.82849121, 18.16403008], [83.82849121, 18.1637516], [83.82791901, 18.1637516], [83.82791901, 18.16346931], [83.82707977, 18.16347313], [83.82707977, 18.16319466], [83.82653046, 18.16319466], [83.82653046, 18.16291618], [83.82569122, 18.16292191], [83.82569122, 18.16263771], [83.82514191, 18.16263771], [83.82514191, 18.16237068], [83.82457733, 18.16237068], [83.82457733, 18.16208076], [83.82375336, 18.16208267], [83.82375336, 18.16180611], [83.82319641, 18.16180992], [83.82319641, 18.16152954], [83.82235718, 18.16152954], [83.82235718, 18.16125107], [83.82180786, 18.16125107], [83.82180786, 18.16097069], [83.82125092, 18.1609726], [83.82125092, 18.16069412], [83.82041931, 18.16069412], [83.82041931, 18.16041946], [83.81986237, 18.16041946], [83.81986237, 18.16014099], [83.81903076, 18.16014099], [83.81903076, 18.15986061], [83.81846619, 18.15986061], [83.81846619, 18.15958023], [83.81764221, 18.15958405], [83.81764221, 18.15930557], [83.8170929, 18.15930939], [83.8170929, 18.15903091], [83.81626129, 18.15903091], [83.81626129, 18.15875053], [83.81569672, 18.15875053], [83.81569672, 18.15847015], [83.81485748, 18.15847206], [83.81485748, 18.15819359], [83.81430817, 18.15819359], [83.81430817, 18.15791512], [83.81346893, 18.15792084], [83.81346893, 18.15764046], [83.81263733, 18.15764046], [83.81263733, 18.15736008], [83.81180573, 18.15736198], [83.81180573, 18.15708351], [83.81124878, 18.15708351], [83.81124878, 18.15680313], [83.81041718, 18.15681076], [83.81041718, 18.15653038], [83.80819702, 18.15653038], [83.80819702, 18.15624046], [83.80791473, 18.15625], [83.80791473, 18.15597153], [83.80764008, 18.15597153], [83.80764008, 18.15569305], [83.80735779, 18.15570068], [83.80735779, 18.1554203], [83.80680847, 18.1554203], [83.80680847, 18.15513992], [83.80652618, 18.15513992], [83.80652618, 18.15485954], [83.80625153, 18.15486145], [83.80625153, 18.15458488], [83.80541992, 18.15458488], [83.80541992, 18.15430641], [83.80486298, 18.15431023], [83.80486298, 18.15402985], [83.80403137, 18.15402985], [83.80403137, 18.15374947], [83.80319214, 18.15374947], [83.80319214, 18.1534729], [83.80263519, 18.1534729], [83.80263519, 18.15319443], [83.80180359, 18.15319443], [83.80180359, 18.15291595], [83.8012619, 18.15291977], [83.8012619, 18.15263939], [83.80041504, 18.15263939], [83.80041504, 18.15236282], [83.79957581, 18.15236282], [83.79957581, 18.15208244], [83.79902649, 18.15208244], [83.79902649, 18.15180588], [83.79820251, 18.15180969], [83.79820251, 18.15153122], [83.79736328, 18.15153122], [83.79736328, 18.15125275], [83.79680634, 18.15125275], [83.79680634, 18.15096855], [83.79597473, 18.15097237], [83.79597473, 18.15069389], [83.79402924, 18.15069389], [83.79402924, 18.15097237], [83.79347229, 18.15097237], [83.79347229, 18.15041733], [83.79292297, 18.15043068], [83.79292297, 18.14985847], [83.79264069, 18.14985847], [83.79264069, 18.14957809], [83.7923584, 18.14958382], [83.7923584, 18.14930534], [83.79180908, 18.14930916], [83.79180908, 18.14903069], [83.79152679, 18.14903069], [83.79152679, 18.1487484], [83.79096985, 18.1487484], [83.79096985, 18.14846992], [83.79069519, 18.14847183], [83.79069519, 18.14819527], [83.78985596, 18.14819908], [83.78985596, 18.14792061], [83.78819275, 18.14792061], [83.78819275, 18.14764023], [83.78736115, 18.14764023], [83.78736115, 18.14736748], [83.78457642, 18.14736748], [83.78457642, 18.14707947], [83.78430176, 18.14708328], [83.78430176, 18.14680481], [83.78375244, 18.14680481], [83.78375244, 18.14652634], [83.78318787, 18.14653015], [83.78318787, 18.14624977], [83.78263855, 18.14624977], [83.78263855, 18.14596939], [83.7820816, 18.1459713], [83.7820816, 18.14569473], [83.78180695, 18.14569473], [83.78180695, 18.14541626], [83.78125, 18.14542007], [83.78125, 18.14513969], [83.78097534, 18.14513969], [83.78097534, 18.14486122], [83.7804184, 18.14486122], [83.7804184, 18.14458084], [83.77986145, 18.14458275], [83.77986145, 18.14430428], [83.77958679, 18.14430428], [83.77958679, 18.14402771], [83.77902985, 18.14402962], [83.77902985, 18.14375114], [83.7784729, 18.14375114], [83.7784729, 18.14347076], [83.77791595, 18.14347267], [83.77791595, 18.1431942], [83.7776413, 18.1431942], [83.7776413, 18.14291763], [83.77709198, 18.14291954], [83.77709198, 18.14264107], [83.7765274, 18.14264107], [83.7765274, 18.14208031], [83.77513885, 18.14208412], [83.77513885, 18.14180565], [83.77430725, 18.14180946], [83.77430725, 18.14153099], [83.77403259, 18.14153099], [83.77403259, 18.14124107], [83.77375031, 18.14125061], [83.77375031, 18.14097214], [83.77347565, 18.14097214], [83.77347565, 18.14069366], [83.77319336, 18.14069366], [83.77319336, 18.1404171], [83.7729187, 18.14042091], [83.7729187, 18.14014053], [83.77236176, 18.14014053], [83.77236176, 18.13986015], [83.77153015, 18.13986206], [83.77153015, 18.13958359], [83.77041626, 18.13958359], [83.77041626, 18.13930511], [83.76957703, 18.13931274], [83.76957703, 18.13903046], [83.76875305, 18.13903046], [83.76875305, 18.13875008], [83.76763916, 18.13875008], [83.76763916, 18.1384716], [83.76680756, 18.1384716], [83.76680756, 18.13791656], [83.7665329, 18.13792038], [83.7665329, 18.13764191], [83.76625061, 18.13764191], [83.76625061, 18.13736153], [83.76569366, 18.13736153], [83.76569366, 18.13708305], [83.76513672, 18.13708305], [83.76513672, 18.13680649], [83.76457977, 18.1368103], [83.76457977, 18.13596916], [83.76430511, 18.13597298], [83.76430511, 18.1356945], [83.76264191, 18.1356945], [83.76264191, 18.13541794], [83.76180267, 18.13542938], [83.76180267, 18.13513756], [83.76069641, 18.13513756], [83.76069641, 18.13485909], [83.76013947, 18.13485909], [83.76013947, 18.13458061], [83.75958252, 18.13458252], [83.75958252, 18.13430786], [83.75901794, 18.13430977], [83.75901794, 18.13402939], [83.75875092, 18.13402939], [83.75875092, 18.13375092], [83.75846863, 18.13375092], [83.75846863, 18.13347054], [83.75791931, 18.13347244], [83.75791931, 18.13319397], [83.75708008, 18.13319397], [83.75708008, 18.1329155], [83.75653076, 18.13292122], [83.75653076, 18.13264084], [83.75595856, 18.13264084], [83.75595856, 18.13236046], [83.75541687, 18.13236046], [83.75541687, 18.13208008], [83.75485992, 18.13208389], [83.75485992, 18.13180542], [83.75430298, 18.13181114], [83.75430298, 18.13125038], [83.75347137, 18.13125038], [83.75347137, 18.13097], [83.75263977, 18.13097191], [83.75263977, 18.13069534], [83.75208282, 18.13070107], [83.75208282, 18.13042068], [83.75152588, 18.13042068], [83.75152588, 18.1301403], [83.75125122, 18.1301403], [83.75125122, 18.12985992], [83.75041962, 18.12986183], [83.75041962, 18.12958336], [83.74986267, 18.12958336], [83.74986267, 18.12930489], [83.74958038, 18.12930489], [83.74958038, 18.12902832], [83.74903107, 18.12903023], [83.74903107, 18.12874985], [83.74846649, 18.12874985], [83.74846649, 18.12846947], [83.74819183, 18.12847137], [83.74819183, 18.12819481], [83.74764252, 18.12819481], [83.74764252, 18.12791634], [83.74707794, 18.12792015], [83.74707794, 18.12763977], [83.74678802, 18.12763977], [83.74678802, 18.12735939], [83.74624634, 18.1273613], [83.74624634, 18.12708282], [83.74569702, 18.12708282], [83.74569702, 18.12680626], [83.7454071, 18.12681007], [83.7454071, 18.12652969], [83.74485779, 18.12652969], [83.74485779, 18.12626076], [83.74430847, 18.12626076], [83.74430847, 18.12597275], [83.74402618, 18.12597275], [83.74402618, 18.12569427], [83.74346924, 18.12569427], [83.74346924, 18.1254158], [83.74263763, 18.12541962], [83.74263763, 18.12514114], [83.74236298, 18.12514114], [83.74236298, 18.12486267], [83.74153137, 18.12486267], [83.74153137, 18.12458038], [83.74069214, 18.1245842], [83.74069214, 18.12430573], [83.74014282, 18.12430954], [83.74014282, 18.12402916], [83.73958588, 18.12402916], [83.73958588, 18.12375069], [83.73902893, 18.12375069], [83.73902893, 18.1234684], [83.73847198, 18.12347221], [83.73847198, 18.12319374], [83.73792267, 18.12319946], [83.73792267, 18.12291908], [83.73735809, 18.12291908], [83.73735809, 18.12264061], [83.73680878, 18.12264061], [83.73680878, 18.12235832], [83.73625183, 18.12235832], [83.73625183, 18.12207985], [83.73569489, 18.12208366], [83.73569489, 18.12180519], [83.73513794, 18.12181091], [83.73513794, 18.12153053], [83.73458099, 18.12153053], [83.73458099, 18.12124825], [83.73401642, 18.12124825], [83.73401642, 18.12096977], [83.73347473, 18.12097168], [83.73347473, 18.12069511], [83.73291779, 18.12070084], [83.73291779, 18.12042046], [83.73236084, 18.12042046], [83.73236084, 18.12013817], [83.73207855, 18.12013817], [83.73207855, 18.1198597], [83.73152924, 18.1198616], [83.73152924, 18.11958313], [83.73097229, 18.11958313], [83.73097229, 18.11930466], [83.73041534, 18.11930466], [83.73041534, 18.11902618], [83.7298584, 18.11903], [83.7298584, 18.11874962], [83.72930908, 18.11874962], [83.72930908, 18.11847115], [83.72875214, 18.11847305], [83.72875214, 18.11819458], [83.72819519, 18.11819458], [83.72819519, 18.1179142], [83.72846985, 18.11791992], [83.72846985, 18.11763954], [83.72819519, 18.11763954], [83.72819519, 18.11736107], [83.72763824, 18.11736107], [83.72763824, 18.11707115], [83.72624969, 18.1170826], [83.72624969, 18.11680412], [83.72598267, 18.11680984], [83.72598267, 18.11652946], [83.72541809, 18.11652946], [83.72541809, 18.11625099], [83.7251358, 18.11625099], [83.7251358, 18.11597061], [83.72458649, 18.11597252], [83.72458649, 18.11569595], [83.72402954, 18.11569595], [83.72402954, 18.11541748], [83.72374725, 18.11541939], [83.72374725, 18.11514091], [83.72319794, 18.11514091], [83.72319794, 18.11486053], [83.7223587, 18.11486053], [83.7223587, 18.11458015], [83.72125244, 18.11458206], [83.72125244, 18.1143055], [83.72097015, 18.11432076], [83.72097015, 18.11375046], [83.71930695, 18.11375046], [83.71930695, 18.11347008], [83.71875, 18.11347389], [83.71875, 18.11291695], [83.71848297, 18.11292076], [83.71848297, 18.11264038], [83.7179184, 18.11264038], [83.7179184, 18.11236191], [83.71763611, 18.11236382], [83.71763611, 18.11208344], [83.71708679, 18.11208344], [83.71708679, 18.11180496], [83.71678925, 18.11181068], [83.71678925, 18.1115303], [83.71624756, 18.1115303], [83.71624756, 18.11125946], [83.71541595, 18.11125946], [83.71541595, 18.11096954], [83.71430206, 18.11096954], [83.71430206, 18.11069489], [83.71347046, 18.11069489], [83.71347046, 18.11041641], [83.7131958, 18.11042023], [83.7131958, 18.11014175], [83.71263885, 18.11014175], [83.71263885, 18.10986137], [83.71208191, 18.10986137], [83.71208191, 18.1095829], [83.71152496, 18.1095829], [83.71152496, 18.10930634], [83.71096802, 18.10931015], [83.71096802, 18.10902977], [83.71069336, 18.10902977], [83.71069336, 18.10847092], [83.7104187, 18.10847282], [83.7104187, 18.10819435], [83.71013641, 18.10819817], [83.71013641, 18.10791969], [83.7095871, 18.10791969], [83.7095871, 18.10764122], [83.70903015, 18.10764122], [83.70903015, 18.10736084], [83.70874786, 18.10736084], [83.70874786, 18.10708046], [83.70847321, 18.10708427], [83.70847321, 18.10680771], [83.7076416, 18.10680962], [83.7076416, 18.10653114], [83.70735931, 18.10653114], [83.70735931, 18.10625076], [83.70707703, 18.10625076], [83.70707703, 18.10597038], [83.70680237, 18.10597229], [83.70680237, 18.10569382], [83.70541382, 18.10569382], [83.70541382, 18.10541534], [83.70513916, 18.10542107], [83.70513916, 18.10513115], [83.7048645, 18.10513878], [83.7048645, 18.10486031], [83.70430756, 18.10486031], [83.70430756, 18.10457993], [83.70402527, 18.10458374], [83.70402527, 18.10430527], [83.70375061, 18.10431099], [83.70375061, 18.10403061], [83.70318604, 18.10403061], [83.70318604, 18.10375023], [83.70207977, 18.10375023], [83.70207977, 18.10346985], [83.70153046, 18.10347176], [83.70153046, 18.10319328], [83.70124817, 18.10320091], [83.70124817, 18.10292053], [83.70069122, 18.10292053], [83.70069122, 18.10264015], [83.70014191, 18.10264015], [83.70014191, 18.10235977], [83.69958496, 18.10236168], [83.69958496, 18.10208321], [83.69902802, 18.10208321], [83.69902802, 18.10180473], [83.69847107, 18.10180473], [83.69847107, 18.10152817], [83.69819641, 18.10153008], [83.69819641, 18.10124969], [83.69790649, 18.10124969], [83.69790649, 18.10069275], [83.69736481, 18.10069466], [83.69736481, 18.10041618], [83.6965332, 18.10042], [83.6965332, 18.10013962], [83.69567871, 18.10013962], [83.69567871, 18.09986115], [83.69513702, 18.09986115], [83.69513702, 18.09958267], [83.69486237, 18.09958267], [83.69486237, 18.09930611], [83.69431305, 18.09931946], [83.69431305, 18.09902954], [83.69403076, 18.09902954], [83.69403076, 18.09875107], [83.69374847, 18.09875107], [83.69374847, 18.0984726], [83.69347382, 18.0984726], [83.69347382, 18.09819412], [83.69291687, 18.09819412], [83.69291687, 18.09791756], [83.69235992, 18.09791946], [83.69235992, 18.0976429], [83.69180298, 18.0976429], [83.69180298, 18.0973587], [83.69124603, 18.0973587], [83.69124603, 18.09707832], [83.69097137, 18.09708405], [83.69097137, 18.09680557], [83.6904068, 18.09680939], [83.6904068, 18.09653091], [83.68987274, 18.09653091], [83.68987274, 18.09626007], [83.68930817, 18.09626007], [83.68930817, 18.09596825], [83.68902588, 18.09597206], [83.68902588, 18.09569359], [83.68875122, 18.09569359], [83.68875122, 18.09541893], [83.68818665, 18.09542084], [83.68818665, 18.09514046], [83.68791962, 18.09514046], [83.68791962, 18.09485817], [83.68763733, 18.09486198], [83.68763733, 18.09458351], [83.68736267, 18.09458351], [83.68736267, 18.09430504], [83.68596649, 18.09431076], [83.68596649, 18.09403038], [83.68541718, 18.09403038], [83.68541718, 18.09374809], [83.68514252, 18.09374809], [83.68514252, 18.09346962], [83.68486023, 18.09347153], [83.68486023, 18.09319687], [83.68430328, 18.09319687], [83.68430328, 18.09291649], [83.68402863, 18.0929203], [83.68402863, 18.09263992], [83.68347168, 18.09263992], [83.68347168, 18.09235954], [83.68319702, 18.09236145], [83.68319702, 18.09208298], [83.68264008, 18.09208298], [83.68264008, 18.09180832], [83.68208313, 18.09181023], [83.68208313, 18.09152985], [83.68180847, 18.09152985], [83.68180847, 18.09124947], [83.68125153, 18.09124947], [83.68125153, 18.09097099], [83.68069458, 18.0909729], [83.68069458, 18.09069443], [83.68041992, 18.09069443], [83.68041992, 18.09041405], [83.67986298, 18.09041977], [83.67986298, 18.09012985], [83.67958069, 18.09013939], [83.67958069, 18.08986092], [83.6784668, 18.08986092], [83.6784668, 18.08930969], [83.67819214, 18.08930969], [83.67819214, 18.08903122], [83.67764282, 18.08903122], [83.67764282, 18.08875084], [83.67708588, 18.08875084], [83.67708588, 18.08847046], [83.67680359, 18.08847237], [83.67680359, 18.08819389], [83.67624664, 18.08819389], [83.67624664, 18.08791733], [83.67597198, 18.08791733], [83.67597198, 18.08819389], [83.67541504, 18.08819389], [83.67541504, 18.08791733], [83.67514038, 18.08792114], [83.67514038, 18.08736038], [83.67485809, 18.08736038], [83.67485809, 18.08708382], [83.67457581, 18.08708954], [83.67457581, 18.08681107], [83.67318726, 18.08681107], [83.67318726, 18.08653069], [83.67292023, 18.08653069], [83.67292023, 18.08625031], [83.67263794, 18.08625031], [83.67263794, 18.08597183], [83.67208099, 18.08597374], [83.67208099, 18.08569527], [83.67179871, 18.0857029], [83.67179871, 18.08542061], [83.67124939, 18.08542061], [83.67124939, 18.08514023], [83.6709671, 18.08514023], [83.6709671, 18.08457947], [83.67069244, 18.08458328], [83.67069244, 18.08430481], [83.6701355, 18.08430481], [83.6701355, 18.08402824], [83.66958618, 18.08403015], [83.66958618, 18.08375168], [83.66929626, 18.08375168], [83.66929626, 18.08346939], [83.66902924, 18.08346939], [83.66902924, 18.08319473], [83.66874695, 18.08319473], [83.66874695, 18.08291626], [83.66847229, 18.08292007], [83.66847229, 18.08263969], [83.66819763, 18.08263969], [83.66819763, 18.08236122], [83.66791534, 18.08236122], [83.66791534, 18.08208275], [83.66764069, 18.08208275], [83.66764069, 18.08180618], [83.6673584, 18.08180809], [83.6673584, 18.08152962], [83.66680908, 18.08152962], [83.66680908, 18.08125114], [83.66652679, 18.08125114], [83.66652679, 18.08096123], [83.66625214, 18.08097267], [83.66625214, 18.0806942], [83.66596985, 18.0806942], [83.66596985, 18.08013725], [83.66570282, 18.08014107], [83.66570282, 18.07958031], [83.6654129, 18.07958412], [83.6654129, 18.07930565], [83.66485596, 18.07930946], [83.66485596, 18.07903099], [83.6645813, 18.07903099], [83.6645813, 18.07875061], [83.66401672, 18.07875061], [83.66401672, 18.07847023], [83.66374969, 18.07847214], [83.66374969, 18.07819366], [83.66319275, 18.07819366], [83.66319275, 18.07791519], [83.66293335, 18.07792091], [83.66293335, 18.07764053], [83.66236115, 18.07764053], [83.66236115, 18.07736015], [83.66208649, 18.07736206], [83.66208649, 18.07708359], [83.6618042, 18.07708359], [83.6618042, 18.07680511], [83.66152954, 18.07681084], [83.66152954, 18.07653046], [83.6609726, 18.07653046], [83.6609726, 18.07625008], [83.66069794, 18.07625008], [83.66069794, 18.0759697], [83.66014099, 18.0759716], [83.66014099, 18.07569313], [83.65956879, 18.07570076], [83.65958405, 18.07550049], [83.65958405, 18.07541656], [83.65875244, 18.07542038], [83.65875244, 18.07514954], [83.65820313, 18.07514954], [83.65820313, 18.07485962], [83.65791321, 18.07486153], [83.65791321, 18.07458305], [83.65763855, 18.07458305], [83.65763855, 18.07430649], [83.65735626, 18.0743103], [83.65735626, 18.07402992], [83.6565094, 18.07402992], [83.6565094, 18.07291985], [83.65679932, 18.07291985], [83.65679932, 18.0723629], [83.6565094, 18.0723629], [83.6565094, 18.07152939], [83.65569305, 18.07152939], [83.65569305, 18.07125282], [83.65513611, 18.07125282], [83.65513611, 18.07097244], [83.65458679, 18.07097244], [83.65458679, 18.07069397], [83.6543045, 18.07069397], [83.6543045, 18.07014084], [83.65402985, 18.07014084], [83.65402985, 18.06985855], [83.6534729, 18.06985855], [83.6534729, 18.06957817], [83.6526413, 18.06958389], [83.6526413, 18.06930542], [83.65235901, 18.06930923], [83.65235901, 18.06902122], [83.65180206, 18.06902885], [83.65180206, 18.06875038], [83.6515274, 18.06875038], [83.6515274, 18.06846809], [83.65097046, 18.06847191], [83.65097046, 18.06819534], [83.64985657, 18.06819916], [83.64985657, 18.06792068], [83.64958191, 18.06792068], [83.64958191, 18.0676403], [83.64819336, 18.0676403], [83.64819336, 18.06735992], [83.6479187, 18.06736183], [83.6479187, 18.06680489], [83.64736176, 18.06680489], [83.64736176, 18.06652641], [83.6470871, 18.06653023], [83.6470871, 18.06624985], [83.64679718, 18.06624985], [83.64679718, 18.06595993], [83.64653015, 18.06597137], [83.64653015, 18.06569481], [83.64624786, 18.06569481], [83.64624786, 18.06513977], [83.64597321, 18.06513977], [83.64597321, 18.06485939], [83.64569092, 18.0648613], [83.64569092, 18.06458282], [83.6451416, 18.06458282], [83.6451416, 18.06430435], [83.64485931, 18.06431007], [83.64485931, 18.06402969], [83.6445694, 18.06402969], [83.6445694, 18.06319046], [83.64430237, 18.06319427], [83.64430237, 18.0629158], [83.64402771, 18.06291962], [83.64402771, 18.06208038], [83.64375305, 18.0620842], [83.64375305, 18.06180573], [83.64235687, 18.06180954], [83.64235687, 18.06153107], [83.6415329, 18.06153107], [83.6415329, 18.06125069], [83.64097595, 18.06125069], [83.64097595, 18.06097031], [83.64041901, 18.06097221], [83.64041901, 18.06069374], [83.63986206, 18.06069374], [83.63986206, 18.06041718], [83.63903046, 18.0604229], [83.63903046, 18.06015015], [83.63846588, 18.06015015], [83.63846588, 18.05986023], [83.63791656, 18.05986023], [83.63791656, 18.05958176], [83.63764191, 18.05958366], [83.63764191, 18.05930519], [83.63735962, 18.05931282], [83.63735962, 18.05903053], [83.63680267, 18.05903053], [83.63680267, 18.05875015], [83.63652802, 18.05875015], [83.63652802, 18.05847168], [83.63597107, 18.05847168], [83.63597107, 18.05819511], [83.63513947, 18.05820274], [83.63513947, 18.05792046], [83.63485718, 18.05792046], [83.63485718, 18.05764008], [83.63458252, 18.05764008], [83.63458252, 18.05707932], [83.63430786, 18.05708313], [83.63430786, 18.05680466], [83.63402557, 18.05680466], [83.63402557, 18.05625153], [83.63346863, 18.05625153], [83.63346863, 18.05596924], [83.63291931, 18.05597305], [83.63291931, 18.05569458], [83.63263702, 18.05569458], [83.63263702, 18.05541611], [83.63236237, 18.05541992], [83.63236237, 18.05485916], [83.63208008, 18.05485916], [83.63208008, 18.05458069], [83.63180542, 18.0545826], [83.63180542, 18.05430794], [83.63124847, 18.05430984], [83.63124847, 18.05401993], [83.63069153, 18.05402946], [83.63069153, 18.05374718], [83.63041687, 18.05375099], [83.63041687, 18.05347061], [83.62985992, 18.05347252], [83.62985992, 18.05319405], [83.62958527, 18.05319405], [83.62958527, 18.05291557], [83.62874603, 18.05291939], [83.62874603, 18.05264091], [83.62847137, 18.05264091], [83.62847137, 18.05236053], [83.62625122, 18.05236053], [83.62625122, 18.05208015], [83.62596893, 18.05208397], [83.62596893, 18.05125046], [83.62568665, 18.05125046], [83.62568665, 18.05097961], [83.62513733, 18.05097961], [83.62513733, 18.05070114], [83.62458038, 18.0506897], [83.62458038, 18.05041695], [83.62431335, 18.05042076], [83.62431335, 18.04986], [83.62347412, 18.04986191], [83.62347412, 18.04958344], [83.62291718, 18.04958344], [83.62291718, 18.04930305], [83.62264252, 18.04931068], [83.62264252, 18.0490303], [83.6220932, 18.0490303], [83.6220932, 18.04874992], [83.62180328, 18.04874992], [83.62180328, 18.04846954], [83.62124634, 18.04847145], [83.62124634, 18.04819489], [83.62097168, 18.04819489], [83.62097168, 18.04791641], [83.62039948, 18.04792023], [83.62039948, 18.04763985], [83.62014008, 18.04763985], [83.62014008, 18.04735947], [83.61958313, 18.04736137], [83.61958313, 18.0470829], [83.61930847, 18.0470829], [83.61930847, 18.04680634], [83.61846924, 18.04681015], [83.61846924, 18.04652977], [83.61818695, 18.04652977], [83.61818695, 18.04624939], [83.61791992, 18.04624939], [83.61791992, 18.04597282], [83.61736298, 18.04597282], [83.61736298, 18.04569435], [83.61708069, 18.04569435], [83.61708069, 18.04541588], [83.61653137, 18.04541969], [83.61653137, 18.04514122], [83.6159668, 18.04514122], [83.6159668, 18.0448494], [83.61569214, 18.04486275], [83.61569214, 18.04458427], [83.61486053, 18.04458427], [83.61486053, 18.0443058], [83.61429596, 18.04430962], [83.61429596, 18.04403114], [83.61402893, 18.04403114], [83.61402893, 18.04375076], [83.61347198, 18.04375076], [83.61347198, 18.04346848], [83.61264038, 18.04347229], [83.61264038, 18.04319382], [83.61208344, 18.04319382], [83.61208344, 18.04291725], [83.61180878, 18.04291916], [83.61180878, 18.04264069], [83.61068726, 18.04264069], [83.61068726, 18.0423584], [83.61042023, 18.0423584], [83.61042023, 18.04207993], [83.61013794, 18.04208374], [83.61013794, 18.04180527], [83.60986328, 18.04180908], [83.60986328, 18.04153061], [83.60958099, 18.04153061], [83.60958099, 18.04124832], [83.60901642, 18.04124832], [83.60901642, 18.04096985], [83.60847473, 18.04097176], [83.60847473, 18.04069519], [83.60819244, 18.04070091], [83.60819244, 18.04042053], [83.60791779, 18.04042053], [83.60791779, 18.03957939], [83.6076355, 18.03958321], [83.6076355, 18.03902626], [83.60708618, 18.03903961], [83.60708618, 18.03874969], [83.60597229, 18.03874969], [83.60597229, 18.03847122], [83.60541534, 18.03847313], [83.60541534, 18.03819466], [83.60514069, 18.03819466], [83.60514069, 18.03791428], [83.6048584, 18.03792], [83.6048584, 18.03763962], [83.60430908, 18.03763962], [83.60430908, 18.03736115], [83.60402679, 18.03736115], [83.60402679, 18.03708076], [83.60346985, 18.03708267], [83.60346985, 18.0368042], [83.60320282, 18.03680992], [83.60320282, 18.03625107], [83.6029129, 18.03625107], [83.6029129, 18.03598022], [83.60264587, 18.03598022], [83.60264587, 18.03569031], [83.60236359, 18.03569412], [83.60236359, 18.03513908], [83.6020813, 18.03514099], [83.6020813, 18.03486061], [83.60151672, 18.03486061], [83.60151672, 18.03458023], [83.60097504, 18.03458214], [83.60097504, 18.03430557], [83.60069275, 18.03430939], [83.60069275, 18.03403091], [83.6001358, 18.03403091], [83.6001358, 18.03375053], [83.59986115, 18.03375053], [83.59986115, 18.03347015], [83.59958649, 18.03347206], [83.59958649, 18.03319359], [83.5993042, 18.03319359], [83.5993042, 18.03291702], [83.59902954, 18.03291702], [83.59902954, 18.03263855], [83.59874725, 18.03264046], [83.59874725, 18.03236008], [83.59819794, 18.03236389], [83.59819794, 18.03208351], [83.59764099, 18.03208351], [83.59764099, 18.03180504], [83.5973587, 18.03181267], [83.5973587, 18.03153038], [83.59707642, 18.03153038], [83.59707642, 18.03125191], [83.59680176, 18.03125191], [83.59680176, 18.03097153], [83.5965271, 18.03097153], [83.5965271, 18.03069496], [83.59625244, 18.03070259], [83.59625244, 18.0304203], [83.59597015, 18.0304203], [83.59597015, 18.03014183], [83.59570313, 18.03014183], [83.59570313, 18.0298481], [83.59541321, 18.02986145], [83.59541321, 18.02958298], [83.59513855, 18.02958298], [83.59513855, 18.02930641], [83.5945816, 18.02931023], [83.5945816, 18.02902985], [83.59430695, 18.02902985], [83.59430695, 18.02874756], [83.59375, 18.02874756], [83.59375, 18.02846909], [83.59347534, 18.0284729], [83.59347534, 18.02819443], [83.59319305, 18.02819443], [83.59319305, 18.02791786], [83.5929184, 18.02791977], [83.5929184, 18.02763748], [83.59236145, 18.02763748], [83.59236145, 18.02736092], [83.59208679, 18.02736092], [83.59208679, 18.02708054], [83.5918045, 18.02708244], [83.5918045, 18.02680779], [83.59152985, 18.02680969], [83.59152985, 18.02653122], [83.59124756, 18.02653122], [83.59124756, 18.02625084], [83.59069824, 18.02625084], [83.59069061, 18.02597237], [83.59041595, 18.02597237], [83.59041595, 18.02569389], [83.5901413, 18.02569389], [83.5901413, 18.02541542], [83.58985901, 18.02542114], [83.58985901, 18.02514076], [83.58957672, 18.02514076], [83.58957672, 18.02486038], [83.58847046, 18.02486038], [83.58847046, 18.02458], [83.5881958, 18.02458382], [83.5881958, 18.02430534], [83.58790588, 18.02431107], [83.58790588, 18.02404022], [83.58763885, 18.02404022], [83.58763885, 18.02375031], [83.58708191, 18.02375031], [83.58708191, 18.02346992], [83.58680725, 18.02347183], [83.58680725, 18.02319336], [83.58651733, 18.02320099], [83.58651733, 18.02292061], [83.58598328, 18.02292061], [83.58598328, 18.02264023], [83.58569336, 18.02264023], [83.58569336, 18.02207947], [83.5854187, 18.02208328], [83.5854187, 18.02180481], [83.58513641, 18.02180481], [83.58513641, 18.02152824], [83.58486176, 18.02153015], [83.58486176, 18.02124977], [83.58403015, 18.02124977], [83.58403015, 18.02153015], [83.58319092, 18.02153015], [83.58319092, 18.02124977], [83.58291626, 18.02124977], [83.58291626, 18.02096939], [83.5826416, 18.0209713], [83.5826416, 18.02069473], [83.58235931, 18.02069473], [83.58235931, 18.02013969], [83.58207703, 18.02013969], [83.58207703, 18.01986122], [83.58180237, 18.01986122], [83.58180237, 18.01958275], [83.58152771, 18.01958275], [83.58152771, 18.01930618], [83.58125305, 18.01930618], [83.58125305, 18.01958275], [83.58041382, 18.01958275], [83.58041382, 18.01930618], [83.58013916, 18.01931], [83.58013916, 18.01902962], [83.57985687, 18.01902962], [83.57985687, 18.01847267], [83.57958221, 18.01847267], [83.57958221, 18.0181942], [83.57875061, 18.0181942], [83.57875061, 18.01791763], [83.57791901, 18.01791573], [83.57791901, 18.01763916], [83.57763672, 18.01764107], [83.57763672, 18.01736069], [83.57736206, 18.01736069], [83.57736206, 18.0170784], [83.57680511, 18.01708412], [83.57680511, 18.01680565], [83.57569122, 18.01680946], [83.57569122, 18.01652908], [83.57514191, 18.01652908], [83.57514191, 18.01625061], [83.57430267, 18.01625061], [83.57430267, 18.01708412], [83.57402802, 18.01708412], [83.57402802, 18.01791573], [83.57347107, 18.01791763], [83.57347107, 18.0181942], [83.57263947, 18.0181942], [83.57263947, 18.01763916], [83.57234955, 18.01764107], [83.57234955, 18.0170784], [83.57208252, 18.01708412], [83.57208252, 18.01625061], [83.57290649, 18.01625061], [83.57290649, 18.01568985], [83.57319641, 18.01569366], [83.57319641, 18.0154171], [83.57290649, 18.01542091], [83.57290649, 18.01485062], [83.57263947, 18.01486206], [83.57263947, 18.01458359], [83.57152557, 18.01458359], [83.57152557, 18.01430511], [83.57041931, 18.01431084], [83.57041931, 18.01374817], [83.57013702, 18.01374817], [83.57013702, 18.01320076], [83.56986237, 18.01320076], [83.56986237, 18.01292038], [83.56931305, 18.01292038], [83.56931305, 18.01263809], [83.56846619, 18.01263809], [83.56846619, 18.01235962], [83.56819153, 18.01236153], [83.56819153, 18.0118084], [83.56735992, 18.0118103], [83.56735992, 18.01152992], [83.5670929, 18.01152992], [83.5670929, 18.01124954], [83.56485748, 18.01124954], [83.56485748, 18.01097107], [83.56458282, 18.01097298], [83.56458282, 18.01013947], [83.56485748, 18.01013947], [83.56485748, 18.00986099], [83.56569672, 18.00986099], [83.56569672, 18.00875092], [83.56597137, 18.00875092], [83.56597137, 18.00847054], [83.56625366, 18.00847244], [83.56625366, 18.00763893], [83.56597137, 18.00764084], [83.56597137, 18.00736046], [83.56569672, 18.00736046], [83.56569672, 18.00681114], [83.5654068, 18.00681114], [83.5654068, 18.00653076], [83.56513977, 18.00653076], [83.56513977, 18.00625038], [83.56485748, 18.00625038], [83.56485748, 18.00570107], [83.56458282, 18.00570107], [83.56458282, 18.00542068], [83.56430817, 18.00542068], [83.56430817, 18.0051403], [83.56458282, 18.0051403], [83.56458282, 18.00486183], [83.56430817, 18.00486183], [83.56430817, 18.00451088], [83.56430817, 18.00430489], [83.56402588, 18.00430489], [83.56402588, 18.00402832], [83.56375122, 18.00403023], [83.56375122, 18.00318909], [83.56346893, 18.00319481], [83.56346893, 18.00291634], [83.56291962, 18.00291634], [83.56291962, 18.00264168], [83.56124878, 18.00264168], [83.56124878, 18.00235748], [83.56097412, 18.0023613], [83.56097412, 18.00180626], [83.56040955, 18.00180817], [83.56040955, 18.00041962], [83.56014252, 18.00041962], [83.56014252, 18.00014114], [83.55986023, 18.00014114], [83.55986023, 17.99986839], [83.55986023, 17.99958038], [83.55958557, 17.9995842], [83.55958557, 17.99902534], [83.55930328, 17.99903107], [83.55930328, 17.99707985], [83.55902863, 17.99708366], [83.55902863, 17.99680519], [83.55874634, 17.99681091], [83.55874634, 17.99291992], [83.55902863, 17.99291992], [83.55902863, 17.99152946], [83.55930328, 17.99152946], [83.55930328, 17.99041939], [83.5595932, 17.99041939], [83.5595932, 17.98986053], [83.55986023, 17.98986053], [83.55986023, 17.98957825], [83.56014252, 17.98958397], [83.56014252, 17.9893055], [83.56040955, 17.98930931], [83.56040955, 17.9879303], [83.56014252, 17.9879303], [83.56014252, 17.98735809], [83.55986023, 17.98736191], [83.55986023, 17.98680496], [83.5595932, 17.98681068], [83.5595932, 17.98624992], [83.55930328, 17.98624992], [83.55930328, 17.98569107], [83.55902863, 17.98569679], [83.55902863, 17.98347282], [83.55874634, 17.98347282], [83.55874634, 17.98319435], [83.55847168, 17.98319435], [83.55847168, 17.98291588], [83.55819702, 17.98291969], [83.55819702, 17.98264122], [83.5579071, 17.98264122], [83.5579071, 17.98236084], [83.55764008, 17.98236084], [83.55764008, 17.98208046], [83.55735779, 17.98208427], [83.55735779, 17.98152733], [83.55708313, 17.98153114], [83.55708313, 17.98125076], [83.55680847, 17.98125076], [83.55680847, 17.98097038], [83.55652618, 17.98097229], [83.55652618, 17.98041725], [83.55625153, 17.98042107], [83.55625153, 17.98014069], [83.55596924, 17.98014069], [83.55596924, 17.97986031], [83.55568695, 17.97986031], [83.55568695, 17.97958183], [83.55513763, 17.97958374], [83.55513763, 17.97930527], [83.55486298, 17.9793129], [83.55486298, 17.97903061], [83.55458069, 17.97903061], [83.55458069, 17.97874069], [83.55430603, 17.97875023], [83.55430603, 17.97847176], [83.55403137, 17.97847176], [83.55403137, 17.97819519], [83.5534668, 17.97820282], [83.5534668, 17.97792053], [83.55319214, 17.97792053], [83.55319214, 17.97764015], [83.55291748, 17.97764015], [83.55291748, 17.97736168], [83.55263519, 17.97736168], [83.55263519, 17.97708321], [83.55236053, 17.97708321], [83.55236053, 17.97680473], [83.55208588, 17.97680473], [83.55208588, 17.97652817], [83.55153656, 17.97653008], [83.55153656, 17.9762516], [83.55124664, 17.9762516], [83.55124664, 17.97596931], [83.55097198, 17.97597313], [83.55097198, 17.97569466], [83.55069733, 17.97570229], [83.55069733, 17.97541809], [83.55042267, 17.97541809], [83.55042267, 17.97486115], [83.55014038, 17.97486115], [83.55014038, 17.97458076], [83.54985809, 17.97458267], [83.54985809, 17.97430611], [83.54957581, 17.97430992], [83.54957581, 17.97375107], [83.54930878, 17.97375107], [83.54930878, 17.97347069], [83.54902649, 17.9734726], [83.54902649, 17.97319412], [83.54875183, 17.97319412], [83.54875183, 17.97263718], [83.54846954, 17.97264099], [83.54846954, 17.97236061], [83.54817963, 17.97236061], [83.54817963, 17.97208023], [83.54792023, 17.97208595], [83.54792023, 17.97180557], [83.54763794, 17.97180939], [83.54763794, 17.97153091], [83.54736328, 17.97153091], [83.54736328, 17.97125053], [83.54708099, 17.97125053], [83.54708099, 17.97097015], [83.54680634, 17.97097206], [83.54680634, 17.97013855], [83.54651642, 17.97014046], [83.54651642, 17.96903038], [83.54624939, 17.96903038], [83.54624939, 17.9679203], [83.5459671, 17.9679203], [83.5459671, 17.96708107], [83.54569244, 17.96708488], [83.54569244, 17.96652794], [83.54541016, 17.96652985], [83.54541016, 17.9659729], [83.5451355, 17.9659729], [83.5451355, 17.96569443], [83.54486084, 17.96569443], [83.54486084, 17.96513939], [83.54458618, 17.96513939], [83.54458618, 17.96458244], [83.54430389, 17.96458244], [83.54430389, 17.9640274], [83.54402924, 17.96403122], [83.54402924, 17.96346855], [83.54374695, 17.96347237], [83.54374695, 17.96319389], [83.54347229, 17.96319389], [83.54347229, 17.96291733], [83.54319763, 17.96291924], [83.54319763, 17.96264076], [83.54292297, 17.96264076], [83.54292297, 17.96235847], [83.54264069, 17.96235847], [83.54264069, 17.96207809], [83.54208374, 17.96208382], [83.54208374, 17.96180534], [83.54180908, 17.96180916], [83.54180908, 17.96153069], [83.54152679, 17.96153069], [83.54152679, 17.96125031], [83.54125214, 17.96125031], [83.54125214, 17.96096992], [83.54096985, 17.96097183], [83.54096985, 17.96069527], [83.54070282, 17.96069908], [83.54070282, 17.96042061], [83.5404129, 17.96042061], [83.5404129, 17.96014023], [83.53985596, 17.96014023], [83.53985596, 17.95985985], [83.5395813, 17.95986176], [83.5395813, 17.95958328], [83.53930664, 17.95958328], [83.53930664, 17.95930481], [83.53902435, 17.95930481], [83.53902435, 17.95902634], [83.53848267, 17.95903015], [83.53848267, 17.95874977], [83.53819275, 17.95874977], [83.53819275, 17.95846939], [83.53791809, 17.9584713], [83.53791809, 17.95819473], [83.5376358, 17.95819473], [83.5376358, 17.95791435], [83.53708649, 17.95792007], [83.53708649, 17.95763016], [83.5368042, 17.95763969], [83.5368042, 17.95736122], [83.53652954, 17.95736122], [83.53652954, 17.95708084], [83.53624725, 17.95708275], [83.53624725, 17.95680428], [83.5359726, 17.95681], [83.5359726, 17.95652962], [83.53569794, 17.95652962], [83.53569794, 17.95625114], [83.53514099, 17.95625114], [83.53514099, 17.95597076], [83.5348587, 17.95597267], [83.5348587, 17.9556942], [83.53458405, 17.9556942], [83.53458405, 17.95541763], [83.53430176, 17.95541954], [83.53430176, 17.95514107], [83.5340271, 17.95514107], [83.5340271, 17.95486069], [83.53375244, 17.95486069], [83.53375244, 17.95430946], [83.53347015, 17.95430946], [83.53347015, 17.95403099], [83.53320313, 17.95403099], [83.53320313, 17.95347023], [83.53291321, 17.95347214], [83.53291321, 17.95319366], [83.53263855, 17.95319366], [83.53263855, 17.9529171], [83.53235626, 17.95292282], [83.53235626, 17.95236015], [83.5320816, 17.95236206], [83.5320816, 17.95208359], [83.53180695, 17.95208359], [83.53180695, 17.95180511], [83.53151703, 17.95182037], [83.53151703, 17.95153046], [83.53125, 17.95153046], [83.53125, 17.95125008], [83.53097534, 17.95125008], [83.53097534, 17.95069504], [83.53069305, 17.95070267], [83.53069305, 17.95042038], [83.53042603, 17.95042038], [83.53042603, 17.95014191], [83.53013611, 17.95014191], [83.53013611, 17.94986153], [83.52986145, 17.94986153], [83.52986145, 17.94958305], [83.52958679, 17.94958305], [83.52958679, 17.94930649], [83.52874756, 17.9493103], [83.52874756, 17.94902992], [83.52819824, 17.94902992], [83.52819061, 17.94875908], [83.52736664, 17.94875908], [83.52736664, 17.94846916], [83.52680206, 17.94847298], [83.52680206, 17.9481945], [83.52597046, 17.9481945], [83.52597046, 17.94791794], [83.52540588, 17.94791985], [83.52540588, 17.94763947], [83.52485657, 17.94763947], [83.52485657, 17.94735909], [83.52429962, 17.94735909], [83.52429962, 17.94708061], [83.52375031, 17.94708252], [83.52375031, 17.94680786], [83.52319336, 17.94680977], [83.52319336, 17.94652939], [83.52263641, 17.94652939], [83.52263641, 17.94625092], [83.5220871, 17.94625092], [83.5220871, 17.94597054], [83.52153015, 17.94597244], [83.52153015, 17.94569397], [83.52097321, 17.94569397], [83.52097321, 17.9454155], [83.52041626, 17.94542122], [83.52041626, 17.94514084], [83.5201416, 17.94514084], [83.5201416, 17.94486046], [83.51957703, 17.94486046], [83.51957703, 17.94458008], [83.51930237, 17.94458389], [83.51930237, 17.94430542], [83.51875305, 17.94431114], [83.51875305, 17.94403076], [83.51847076, 17.94403076], [83.51847076, 17.94375038], [83.51790619, 17.94375038], [83.51790619, 17.94347], [83.51763916, 17.94347191], [83.51763916, 17.94319534], [83.51708221, 17.94320107], [83.51708221, 17.94292068], [83.51680756, 17.94292068], [83.51680756, 17.94263077], [83.51625061, 17.9426384], [83.51625061, 17.94236183], [83.51597595, 17.94236183], [83.51597595, 17.94208336], [83.51569366, 17.94208336], [83.51569366, 17.94180489], [83.51513672, 17.94180489], [83.51513672, 17.94152832], [83.51486206, 17.94153023], [83.51486206, 17.94124985], [83.51430511, 17.94124985], [83.51430511, 17.94097137], [83.51403046, 17.94097137], [83.51403046, 17.94069481], [83.51374817, 17.94069481], [83.51374817, 17.94013977], [83.51346588, 17.94013977], [83.51346588, 17.93985939], [83.51319122, 17.9398613], [83.51319122, 17.93958282], [83.51291656, 17.93959045], [83.51291656, 17.93931007], [83.51264191, 17.93931007], [83.51264191, 17.93875122], [83.51235962, 17.93875122], [83.51235962, 17.93847275], [83.51208496, 17.93847275], [83.51208496, 17.93819427], [83.51180267, 17.93819427], [83.51180267, 17.9379158], [83.51125336, 17.93791962], [83.51125336, 17.93764114], [83.51097107, 17.93764114], [83.51097107, 17.93736267], [83.51040649, 17.93736267], [83.51040649, 17.93707848], [83.50986481, 17.9370842], [83.50986481, 17.93680573], [83.50958252, 17.93682289], [83.50958252, 17.93652916], [83.5090332, 17.93652916], [83.5090332, 17.93625069], [83.50846863, 17.93625069], [83.50846863, 17.9359684], [83.50791931, 17.93597221], [83.50791931, 17.93569374], [83.50763702, 17.93569374], [83.50763702, 17.93541718], [83.50708008, 17.93541908], [83.50708008, 17.93514061], [83.50653076, 17.93514061], [83.50653076, 17.93485832], [83.50596619, 17.93485832], [83.50596619, 17.93457985], [83.50541687, 17.93458366], [83.50541687, 17.93430519], [83.50485992, 17.93431091], [83.50485992, 17.93403053], [83.50430298, 17.93403053], [83.50430298, 17.93374825], [83.50374603, 17.93374825], [83.50374603, 17.93346977], [83.50319672, 17.93347168], [83.50319672, 17.93319511], [83.50263977, 17.93320084], [83.50263977, 17.93292046], [83.50208282, 17.93292046], [83.50208282, 17.93264008], [83.50152588, 17.93264008], [83.50152588, 17.9323597], [83.50096893, 17.9323616], [83.50096893, 17.93208313], [83.50041962, 17.93208313], [83.50041962, 17.93180466], [83.49986267, 17.93180466], [83.49986267, 17.93152618], [83.49903107, 17.93153], [83.49903107, 17.93124962], [83.49846649, 17.93124962], [83.49846649, 17.93097115], [83.49791718, 17.93097305], [83.49791718, 17.93069458], [83.49736023, 17.93069458], [83.49736023, 17.9304142], [83.49680328, 17.93041992], [83.49680328, 17.93013954], [83.49652863, 17.93013954], [83.49652863, 17.92986107], [83.49597168, 17.92986107], [83.49597168, 17.92958069], [83.49541473, 17.9295826], [83.49541473, 17.92930412], [83.49485779, 17.92930984], [83.49485779, 17.92902946], [83.4943161, 17.92902946], [83.4943161, 17.92875099], [83.49402618, 17.92875099], [83.49402618, 17.92847061], [83.49346924, 17.92847252], [83.49346924, 17.92819214], [83.49319458, 17.92819214], [83.49319458, 17.92791748], [83.49291992, 17.92791939], [83.49291992, 17.92765045], [83.49236298, 17.92765045], [83.49236298, 17.92736053], [83.49208069, 17.92736053], [83.49208069, 17.92708015], [83.49180603, 17.92708206], [83.49180603, 17.9268055], [83.49125671, 17.92681122], [83.49125671, 17.92653084], [83.49041748, 17.92653084], [83.49041748, 17.92625046], [83.48986053, 17.92625046], [83.48986053, 17.92597008], [83.48902893, 17.92597389], [83.48902893, 17.92569542], [83.48792267, 17.9256897], [83.48791504, 17.92541695], [83.48764038, 17.92542267], [83.48764038, 17.92514038], [83.48735809, 17.92514038], [83.48735809, 17.92486191], [83.48708344, 17.92486191], [83.48708344, 17.92430496], [83.48680878, 17.92431259], [83.48680878, 17.9240303], [83.48652649, 17.9240303], [83.48652649, 17.92375183], [83.48625183, 17.92375183], [83.48625183, 17.92347145], [83.48569489, 17.92347145], [83.48569489, 17.92319489], [83.48542023, 17.92319489], [83.48542023, 17.92291641], [83.48486328, 17.92292023], [83.48486328, 17.92264175], [83.48430634, 17.92264175], [83.48430634, 17.92235756], [83.48402405, 17.92236137], [83.48402405, 17.9220829], [83.48347473, 17.9220829], [83.48347473, 17.92180634], [83.48291779, 17.92180824], [83.48291779, 17.92152977], [83.48236084, 17.92152977], [83.48236084, 17.92124748], [83.48208618, 17.92124748], [83.48208618, 17.92097092], [83.48152924, 17.92097282], [83.48152924, 17.92069435], [83.48097229, 17.92069435], [83.48097229, 17.92041779], [83.48069763, 17.92041969], [83.48069763, 17.92014122], [83.48014069, 17.92014122], [83.48014069, 17.91986084], [83.47957611, 17.91986084], [83.47957611, 17.91958046], [83.47930908, 17.91958427], [83.47930908, 17.91930771], [83.47875214, 17.91930962], [83.47875214, 17.91903114], [83.47820282, 17.91903114], [83.47820282, 17.91875076], [83.47763824, 17.91875076], [83.47763824, 17.91846085], [83.47744751, 17.91846085], [83.47736359, 17.91819382], [83.47680664, 17.91819382], [83.47680664, 17.91791534], [83.47651672, 17.91792107], [83.47651672, 17.91764069], [83.47598267, 17.91764069], [83.47598267, 17.91736031], [83.47569275, 17.91736031], [83.47569275, 17.91707993], [83.4751358, 17.91708374], [83.4751358, 17.91680527], [83.47486115, 17.91681099], [83.47486115, 17.91653061], [83.47429657, 17.91653061], [83.47429657, 17.91625023], [83.47402954, 17.91625023], [83.47402954, 17.91596985], [83.4734726, 17.91597176], [83.4734726, 17.91569328], [83.47319031, 17.91571045], [83.47319031, 17.91542053], [83.4723587, 17.91542053], [83.4723587, 17.91514015], [83.47180176, 17.91514015], [83.47180176, 17.91485977], [83.4706955, 17.91486168], [83.4706955, 17.91458321], [83.47013855, 17.91458321], [83.47013855, 17.91430473], [83.46986389, 17.91430473], [83.46986389, 17.91402817], [83.4695816, 17.91403008], [83.4695816, 17.91374969], [83.46930695, 17.91374969], [83.46930695, 17.91347122], [83.46902466, 17.91347122], [83.46902466, 17.91319466], [83.46875, 17.91319466], [83.46875, 17.91291618], [83.46848297, 17.91292], [83.46848297, 17.91265106], [83.46819305, 17.91265106], [83.46819305, 17.91236115], [83.4679184, 17.91236115], [83.4679184, 17.91208267], [83.46763611, 17.91208267], [83.46763611, 17.91180611], [83.46736145, 17.91181183], [83.46736145, 17.91152954], [83.46708679, 17.91152954], [83.46708679, 17.91125107], [83.46679687, 17.91125107], [83.46679687, 17.91069031], [83.46652985, 17.91069412], [83.46652985, 17.91041756], [83.46624756, 17.91041946], [83.46624756, 17.91013908], [83.4659729, 17.91013908], [83.4659729, 17.90986061], [83.46569824, 17.90986061], [83.46569061, 17.90957832], [83.46541595, 17.90958405], [83.46541595, 17.90930557], [83.4651413, 17.90930939], [83.4651413, 17.90903091], [83.46485901, 17.90903091], [83.46485901, 17.90875053], [83.46457672, 17.90875053], [83.46457672, 17.90846825], [83.46430206, 17.90847206], [83.46430206, 17.90819359], [83.4640274, 17.90819359], [83.4640274, 17.90791893], [83.46375275, 17.90792084], [83.46375275, 17.90764046], [83.4631958, 17.90764046], [83.4631958, 17.90735817], [83.46291351, 17.90736198], [83.46291351, 17.90708351], [83.46263885, 17.90708351], [83.46263885, 17.90680695], [83.46235657, 17.90681076], [83.46235657, 17.90652084], [83.46208191, 17.90652657], [83.46208191, 17.90624809], [83.46180725, 17.90624809], [83.46180725, 17.90596962], [83.46152496, 17.90597153], [83.46152496, 17.90569687], [83.46125031, 17.90570068], [83.46125031, 17.9054203], [83.46098328, 17.9054203], [83.46098328, 17.90513992], [83.46069336, 17.90513992], [83.46069336, 17.90485954], [83.4604187, 17.90486145], [83.4604187, 17.90458298], [83.46013641, 17.90458107], [83.46013641, 17.9054203], [83.4604187, 17.9054184], [83.4604187, 17.90597153], [83.46069336, 17.90597153], [83.46069336, 17.90708351], [83.4604187, 17.9070797], [83.4604187, 17.90764046], [83.46013641, 17.90764046], [83.46013641, 17.90875053], [83.45986176, 17.90875053], [83.45986176, 17.91236115], [83.4595871, 17.91236115], [83.4595871, 17.91458321], [83.45930481, 17.91458321], [83.45930481, 17.91847229], [83.4595871, 17.91846085], [83.4595871, 17.92014122], [83.45903015, 17.92014122], [83.45903015, 17.92041969], [83.45874786, 17.92041779], [83.45874786, 17.92097282], [83.45847321, 17.92097092], [83.45847321, 17.92124748], [83.45791626, 17.92124748], [83.45791626, 17.92097092], [83.4576416, 17.92097282], [83.4576416, 17.92069435], [83.45735931, 17.92069435], [83.45735931, 17.91902542], [83.4576416, 17.91903114], [83.4576416, 17.91875076], [83.45791626, 17.91875076], [83.45791626, 17.91846085], [83.45819092, 17.91847229], [83.45819092, 17.91208267], [83.45847321, 17.91208267], [83.45847321, 17.9109726], [83.45874786, 17.9109726], [83.45874786, 17.90847206], [83.45903015, 17.90847206], [83.45903015, 17.90569687], [83.45874786, 17.90570068], [83.45874786, 17.9054203], [83.45847321, 17.9054203], [83.45847321, 17.90513992], [83.45819092, 17.90513992], [83.45819092, 17.90485954], [83.4576416, 17.90486145], [83.4576416, 17.90458298], [83.45708466, 17.90458298], [83.45708466, 17.9043045], [83.45680237, 17.90431023], [83.45680237, 17.90402985], [83.45625305, 17.90402985], [83.45625305, 17.90374947], [83.45597076, 17.90374947], [83.45597076, 17.90345955], [83.45569611, 17.9034729], [83.45569611, 17.90319443], [83.45402527, 17.90319443], [83.45402527, 17.90291405], [83.45347595, 17.90291977], [83.45347595, 17.90263939], [83.45318604, 17.90263939], [83.45318604, 17.90180969], [83.45263672, 17.90180969], [83.45263672, 17.90125084], [83.45236206, 17.90125084], [83.45236206, 17.90097046], [83.45207977, 17.90097237], [83.45207977, 17.90069389], [83.45180511, 17.90069389], [83.45180511, 17.90013885], [83.45153046, 17.90014076], [83.45153046, 17.89653015], [83.45181274, 17.89653015], [83.45181274, 17.89569092], [83.45207977, 17.89569473], [83.45207977, 17.89513969], [83.45236206, 17.89513969], [83.45236206, 17.89458084], [83.45263672, 17.89458275], [83.45263672, 17.89430618], [83.45291901, 17.89430809], [83.45291901, 17.89402962], [83.45347595, 17.89402962], [83.45347595, 17.89375114], [83.4540329, 17.89375114], [83.4540329, 17.89347076], [83.45430756, 17.89347267], [83.45430756, 17.8931942], [83.45458221, 17.8931942], [83.45458221, 17.89263725], [83.45485687, 17.89264107], [83.45485687, 17.89236069], [83.45514679, 17.89236069], [83.45513916, 17.89208412], [83.45541382, 17.89208412], [83.45541382, 17.89041519], [83.45514679, 17.89042091], [83.45514679, 17.88903046], [83.45485687, 17.88903046], [83.45485687, 17.88820076], [83.45458221, 17.88820076], [83.45458221, 17.88764], [83.45430756, 17.88764], [83.45430756, 17.88735962], [83.45402527, 17.88736153], [83.45402527, 17.88680649], [83.45375061, 17.8868103], [83.45375061, 17.88652992], [83.45347595, 17.88652992], [83.45347595, 17.88624954], [83.45291901, 17.88624954], [83.45291901, 17.88597107], [83.45263672, 17.88597107], [83.45263672, 17.8856945], [83.45236206, 17.8856945], [83.45236206, 17.88541603], [83.45181274, 17.88541985], [83.45181274, 17.88513947], [83.45124817, 17.88513947], [83.45124817, 17.8848629], [83.45096588, 17.8848629], [83.45096588, 17.88458252], [83.45069122, 17.88458252], [83.45069122, 17.88430595], [83.45041656, 17.88430977], [83.45041656, 17.88402939], [83.45014191, 17.88402939], [83.45014191, 17.88375092], [83.44957733, 17.88375092], [83.44957733, 17.88346863], [83.44930267, 17.88347244], [83.44930267, 17.88319397], [83.44902802, 17.88319397], [83.44902802, 17.8829174], [83.44875336, 17.88291931], [83.44875336, 17.88264084], [83.44847107, 17.88264084], [83.44847107, 17.88235092], [83.44819641, 17.88236046], [83.44819641, 17.88208389], [83.44791412, 17.88208389], [83.44791412, 17.88180542], [83.44763947, 17.88180923], [83.44763947, 17.88153076], [83.44735718, 17.88153076], [83.44735718, 17.88125038], [83.44708252, 17.88125038], [83.44708252, 17.88096809], [83.44680786, 17.88097191], [83.44680786, 17.88069534], [83.4465332, 17.88069916], [83.4465332, 17.8801403], [83.44638824, 17.8801403], [83.44625092, 17.8801403], [83.44625092, 17.87957954], [83.44596863, 17.87958336], [83.44596863, 17.87902641], [83.44568634, 17.87903023], [83.44568634, 17.87846947], [83.44541931, 17.87847137], [83.44541931, 17.87791443], [83.44513702, 17.87792015], [83.44513702, 17.87735939], [83.44486237, 17.8773613], [83.44486237, 17.87680435], [83.44458008, 17.87681007], [83.44458008, 17.87514114], [83.44431305, 17.87514114], [83.44431305, 17.87319183], [83.44403076, 17.87319374], [83.44403076, 17.8726387], [83.44374847, 17.87264061], [83.44374847, 17.87236023], [83.44291687, 17.87236023], [83.44291687, 17.87208176], [83.44235992, 17.87208366], [83.44235992, 17.87180519], [83.44152832, 17.87181282], [83.44152832, 17.87153053], [83.44069672, 17.87153053], [83.44069672, 17.87125015], [83.43958282, 17.87125015], [83.43958282, 17.87097168], [83.43902588, 17.87097168], [83.43902588, 17.87069511], [83.43875122, 17.87070274], [83.43875122, 17.87041092], [83.43819427, 17.87041664], [83.43819427, 17.87013817], [83.43791962, 17.87014008], [83.43791962, 17.8698616], [83.43736267, 17.8698616], [83.43736267, 17.86958313], [83.43708038, 17.86958313], [83.43708038, 17.86930466], [83.43653107, 17.86930466], [83.43653107, 17.86902809], [83.43624878, 17.86903191], [83.43624878, 17.86874962], [83.43569183, 17.86874962], [83.43569183, 17.86846924], [83.43541718, 17.86847305], [83.43541718, 17.86819458], [83.43486023, 17.86819458], [83.43486023, 17.86791611], [83.43430328, 17.86791992], [83.43430328, 17.86763954], [83.43374634, 17.86763954], [83.43374634, 17.86734962], [83.43347168, 17.86736107], [83.43347168, 17.8670826], [83.43319702, 17.8670826], [83.43319702, 17.86680794], [83.43264008, 17.86680984], [83.43264008, 17.86652946], [83.43208313, 17.86652946], [83.43208313, 17.86625099], [83.43180847, 17.86625099], [83.43180847, 17.86597061], [83.43125153, 17.86597252], [83.43125153, 17.86569405], [83.43096924, 17.86569405], [83.43096924, 17.86541557], [83.43041992, 17.86541939], [83.43041992, 17.86514091], [83.42986298, 17.86514091], [83.42986298, 17.86486053], [83.42958069, 17.86486053], [83.42958069, 17.86458015], [83.42903137, 17.86458588], [83.42903137, 17.8643055], [83.42874908, 17.86431122], [83.42874908, 17.86403084], [83.42819214, 17.86403084], [83.42819214, 17.86375046], [83.42791748, 17.86375046], [83.42791748, 17.86347008], [83.42736053, 17.86347198], [83.42736053, 17.86319733], [83.42708588, 17.8631897], [83.42708588, 17.86291695], [83.42679596, 17.86292076], [83.42679596, 17.86264038], [83.42624664, 17.86264038], [83.42624664, 17.86236], [83.42597198, 17.86236191], [83.42597198, 17.86208344], [83.42569733, 17.86208344], [83.42569733, 17.86180305], [83.42514038, 17.86181068], [83.42514038, 17.86153984], [83.42485046, 17.86153984], [83.42485046, 17.86124992], [83.42457581, 17.86124992], [83.42457581, 17.86096954], [83.42402649, 17.86097145], [83.42402649, 17.86069489], [83.42375183, 17.86069489], [83.42375183, 17.86041641], [83.42346954, 17.86042023], [83.42346954, 17.86013985], [83.42318726, 17.86013985], [83.42318726, 17.85985947], [83.42263794, 17.85986137], [83.42263794, 17.8595829], [83.42236328, 17.8595829], [83.42236328, 17.85930634], [83.42208099, 17.85931015], [83.42208099, 17.85902977], [83.42151642, 17.85902977], [83.42151642, 17.85874939], [83.42124939, 17.85874939], [83.42124939, 17.85847282], [83.42069244, 17.85847282], [83.42069244, 17.85819435], [83.42041779, 17.85819435], [83.42041779, 17.85791588], [83.42014313, 17.85791969], [83.42014313, 17.85764122], [83.41986084, 17.85764122], [83.41986084, 17.85736275], [83.41929626, 17.85736275], [83.41929626, 17.85707855], [83.41902924, 17.85708427], [83.41902924, 17.8568058], [83.41874695, 17.85680962], [83.41874695, 17.85625076], [83.41847229, 17.85625076], [83.41847229, 17.85596848], [83.41819763, 17.85597229], [83.41819763, 17.85569382], [83.41791534, 17.85569382], [83.41791534, 17.85514069], [83.41764069, 17.85514069], [83.41764069, 17.8548584], [83.41707611, 17.8548584], [83.41707611, 17.85457993], [83.41680908, 17.85458374], [83.41680908, 17.85375023], [83.41652679, 17.85375023], [83.41652679, 17.85346985], [83.41625214, 17.85347176], [83.41625214, 17.85291862], [83.41597748, 17.85292053], [83.41597748, 17.85264015], [83.41570282, 17.85264015], [83.41570282, 17.85237122], [83.41513824, 17.85237122], [83.41513824, 17.85207939], [83.41486359, 17.85208321], [83.41486359, 17.85180473], [83.4145813, 17.85180473], [83.4145813, 17.85124969], [83.41430664, 17.85124969], [83.41430664, 17.85097122], [83.41402435, 17.85097313], [83.41402435, 17.84986115], [83.41374969, 17.84986115], [83.41374969, 17.84958076], [83.41347504, 17.84958267], [83.41347504, 17.84902763], [83.41319275, 17.84902954], [83.41319275, 17.84875107], [83.41291046, 17.84875107], [83.41291046, 17.84819031], [83.4126358, 17.84819221], [83.4126358, 17.84791756], [83.41236115, 17.84791946], [83.41236115, 17.84764099], [83.41208649, 17.84764099], [83.41208649, 17.84708023], [83.4118042, 17.84708214], [83.4118042, 17.84625053], [83.41152954, 17.84625053], [83.41152954, 17.84597206], [83.41124725, 17.84597206], [83.41124725, 17.84541702], [83.4109726, 17.84542274], [83.4109726, 17.84486008], [83.41069794, 17.84486008], [83.41069794, 17.84430504], [83.41042328, 17.84431267], [83.41042328, 17.84375191], [83.41014099, 17.84375191], [83.41014099, 17.84347153], [83.4098587, 17.84347153], [83.4098587, 17.83986092], [83.41014099, 17.83986092], [83.41014099, 17.83903122], [83.41042328, 17.83903122], [83.41042328, 17.83847046], [83.41069794, 17.83847237], [83.41069794, 17.83763885], [83.4109726, 17.83764076], [83.4109726, 17.83708], [83.41124725, 17.83708382], [83.41124725, 17.83680534], [83.41152954, 17.83681107], [83.41152954, 17.83653069], [83.41179657, 17.83653069], [83.41179657, 17.83625031], [83.41236115, 17.83625031], [83.41236115, 17.83596992], [83.4126358, 17.83597183], [83.4126358, 17.83569336], [83.41291046, 17.83570099], [83.41291046, 17.83542061], [83.4154129, 17.83542061], [83.4154129, 17.83514023], [83.41570282, 17.83514023], [83.41570282, 17.83374977], [83.41596985, 17.83374977], [83.41596985, 17.83013916], [83.41570282, 17.83013916], [83.41570282, 17.82319069], [83.4154129, 17.8231945], [83.4154129, 17.82263947], [83.41513824, 17.82263947], [83.41513824, 17.82180977], [83.41485596, 17.82180977], [83.41485596, 17.82097054], [83.4145813, 17.82097244], [83.4145813, 17.8204174], [83.41430664, 17.82042122], [83.41430664, 17.81986046], [83.41401672, 17.81986046], [83.41401672, 17.8192997], [83.41374969, 17.81930542], [83.41374969, 17.81902695], [83.41348267, 17.81903076], [83.41348267, 17.81875038], [83.41319275, 17.81875038], [83.41319275, 17.81820107], [83.41291046, 17.81820107], [83.41291046, 17.81792259], [83.4126358, 17.81792259], [83.4126358, 17.81736183], [83.41236115, 17.81736183], [83.41236115, 17.81680489], [83.41208649, 17.81680489], [83.41208649, 17.81625175], [83.41179657, 17.81625938], [83.41179657, 17.81568909], [83.41152954, 17.81569481], [83.41152954, 17.81513977], [83.41124725, 17.81513977], [83.41124725, 17.81430817], [83.4109726, 17.81430817], [83.4109726, 17.81375122], [83.41069794, 17.81375122], [83.41069794, 17.81208038], [83.41041565, 17.8120842], [83.41041565, 17.81180763], [83.41014099, 17.81180954], [83.41014099, 17.81042099], [83.40985107, 17.81042099], [83.40985107, 17.81014061], [83.40930176, 17.81014061], [83.40930176, 17.80986023], [83.4090271, 17.80986023], [83.4090271, 17.80957985], [83.40875244, 17.80958366], [83.40875244, 17.80930328], [83.40847015, 17.80931091], [83.40847015, 17.80903053], [83.40791321, 17.80903053], [83.40791321, 17.80875015], [83.40763855, 17.80875015], [83.40763855, 17.80846977], [83.40736389, 17.80847168], [83.40736389, 17.80819321], [83.4070816, 17.80820084], [83.4070816, 17.80792046], [83.40651703, 17.80792046], [83.40651703, 17.8073597], [83.40625, 17.8073616], [83.40625, 17.80708313], [83.40597534, 17.80708313], [83.40597534, 17.80680466], [83.40569305, 17.80680466], [83.40569305, 17.80652809], [83.4054184, 17.80653], [83.4054184, 17.80624962], [83.40513611, 17.80624962], [83.40513611, 17.80597115], [83.40486145, 17.80597115], [83.40486145, 17.80569458], [83.40458679, 17.80569458], [83.40458679, 17.80541611], [83.40429688, 17.80541992], [83.40429688, 17.80513954], [83.40402985, 17.80513954], [83.40402985, 17.80486107], [83.40374756, 17.80486107], [83.40374756, 17.8045826], [83.4034729, 17.8045826], [83.4034729, 17.80430603], [83.40319824, 17.80431938], [83.40319061, 17.80402946], [83.40291595, 17.80402946], [83.40291595, 17.8037529], [83.40235901, 17.8037529], [83.40235901, 17.80347061], [83.40208435, 17.80347252], [83.40208435, 17.80319405], [83.4015274, 17.80319405], [83.4015274, 17.80264091], [83.40097046, 17.80264091], [83.40097046, 17.80236053], [83.4006958, 17.80236053], [83.4006958, 17.80207825], [83.40013885, 17.80208397], [83.40013885, 17.8018055], [83.39985657, 17.80180931], [83.39985657, 17.80153084], [83.39930725, 17.80153084], [83.39930725, 17.8012619], [83.39875031, 17.8012619], [83.39875031, 17.80069923], [83.39848328, 17.8006897], [83.39847565, 17.80013657], [83.39819336, 17.80014038], [83.39819336, 17.79957962], [83.3979187, 17.79958344], [83.3979187, 17.79902649], [83.39763641, 17.7990303], [83.39763641, 17.79846954], [83.39736176, 17.79847145], [83.39736176, 17.79791832], [83.3970871, 17.79792023], [83.3970871, 17.79763985], [83.39653015, 17.79763985], [83.39653015, 17.79735947], [83.39611053, 17.79736137], [83.39569092, 17.79736137], [83.39569092, 17.79680443], [83.39541626, 17.79681015], [83.39541626, 17.79652977], [83.39485168, 17.79652977], [83.39485168, 17.79624939], [83.39430237, 17.79624939], [83.39430237, 17.79597092], [83.39402771, 17.79597282], [83.39402771, 17.79569435], [83.39375305, 17.79569435], [83.39375305, 17.79541588], [83.39319611, 17.79541969], [83.39319611, 17.79512978], [83.39291382, 17.79513931], [83.39291382, 17.79486084], [83.39235687, 17.79486084], [83.39235687, 17.79458046], [83.39208221, 17.79458237], [83.39208221, 17.7943058], [83.39180756, 17.79430962], [83.39180756, 17.79403114], [83.3915329, 17.79403114], [83.3915329, 17.79375076], [83.39125061, 17.79375076], [83.39125061, 17.79292107], [83.39097595, 17.79292107], [83.39097595, 17.79264069], [83.39068604, 17.79264069], [83.39068604, 17.79206848], [83.39041901, 17.79208374], [83.39041901, 17.79125023], [83.39013672, 17.79125023], [83.39013672, 17.79070282], [83.38986206, 17.79070282], [83.38986206, 17.79042053], [83.38957977, 17.79042053], [83.38957977, 17.79014015], [83.38931274, 17.79014015], [83.38931274, 17.78986168], [83.38903046, 17.78986168], [83.38903046, 17.78958321], [83.38819122, 17.78958321], [83.38819122, 17.78874969], [83.38791656, 17.78874969], [83.38791656, 17.78847122], [83.38764191, 17.78847313], [83.38764191, 17.78819466], [83.38735962, 17.78819466], [83.38735962, 17.78791618], [83.38707733, 17.78791809], [83.38707733, 17.78763962], [83.38680267, 17.78763962], [83.38680267, 17.78680992], [83.38652802, 17.78680992], [83.38652802, 17.7862606], [83.38625336, 17.7862606], [83.38625336, 17.78597069], [83.38597107, 17.7859726], [83.38597107, 17.78541565], [83.38569641, 17.78541946], [83.38569641, 17.78486061], [83.38540649, 17.78486061], [83.38540649, 17.78430939], [83.38513947, 17.78430939], [83.38513947, 17.78375053], [83.38485718, 17.78375053], [83.38485718, 17.78236008], [83.38513947, 17.78236198], [83.38513947, 17.78125], [83.38540649, 17.78125], [83.38540649, 17.78096962], [83.38569641, 17.78097153], [83.38569641, 17.78013802], [83.38597107, 17.78013802], [83.38597107, 17.77902794], [83.38569641, 17.77902985], [83.38569641, 17.7784729], [83.38541412, 17.7784729], [83.38541412, 17.77791595], [83.38513947, 17.77791977], [83.38513947, 17.77763939], [83.38485718, 17.77763939], [83.38485718, 17.77736282], [83.38458252, 17.77736282], [83.38458252, 17.77709007], [83.3840332, 17.77709007], [83.3840332, 17.77680969], [83.38375092, 17.77680969], [83.38375092, 17.77652931], [83.38346863, 17.77652931], [83.38346863, 17.77625084], [83.38318634, 17.77625084], [83.38318634, 17.77596855], [83.38263702, 17.77597237], [83.38263702, 17.77569389], [83.38208008, 17.77569389], [83.38208008, 17.77541733], [83.38153076, 17.77541924], [83.38153076, 17.77514076], [83.38096619, 17.77514076], [83.38096619, 17.77486038], [83.38069153, 17.77486038], [83.38069153, 17.77457809], [83.38014221, 17.77458382], [83.38014221, 17.77430534], [83.37986755, 17.77432251], [83.37986755, 17.77403069], [83.3795929, 17.77403069], [83.3795929, 17.77375031], [83.37902832, 17.77375031], [83.37902832, 17.77346992], [83.37875366, 17.77347183], [83.37875366, 17.77319527], [83.37847137, 17.77319908], [83.37847137, 17.77292061], [83.3779068, 17.77292061], [83.3779068, 17.77264023], [83.37763977, 17.77264023], [83.37763977, 17.77235985], [83.37735748, 17.77236176], [83.37735748, 17.77208328], [83.37680817, 17.77208328], [83.37680817, 17.77180481], [83.37652588, 17.77180481], [83.37652588, 17.77152634], [83.37596893, 17.77153015], [83.37596893, 17.77124977], [83.37568665, 17.77124977], [83.37568665, 17.77095985], [83.37541962, 17.7709713], [83.37541962, 17.77069664], [83.37486267, 17.77069664], [83.37486267, 17.77041435], [83.37458038, 17.77042007], [83.37458038, 17.77013969], [83.37430573, 17.77013969], [83.37430573, 17.76986122], [83.37374115, 17.76986122], [83.37374115, 17.76958084], [83.37347412, 17.76958275], [83.37347412, 17.76930428], [83.37291718, 17.76931], [83.37291718, 17.76902962], [83.37236023, 17.76902962], [83.37236023, 17.76875114], [83.37180328, 17.76875114], [83.37180328, 17.76847076], [83.37152863, 17.76847267], [83.37152863, 17.7681942], [83.37097168, 17.7681942], [83.37097168, 17.76791763], [83.3704071, 17.76791954], [83.3704071, 17.76764107], [83.36985779, 17.76764107], [83.36985779, 17.76736069], [83.36930847, 17.76736069], [83.36930847, 17.76708031], [83.36875153, 17.76708221], [83.36875153, 17.76680565], [83.36818695, 17.76680946], [83.36818695, 17.7665329], [83.36763763, 17.7665329], [83.36763763, 17.76625061], [83.36736298, 17.76625061], [83.36736298, 17.76597023], [83.36680603, 17.76597214], [83.36680603, 17.76569366], [83.36624908, 17.76569366], [83.36624908, 17.7654171], [83.36569214, 17.76542282], [83.36569214, 17.76515007], [83.36458588, 17.76515007], [83.36458588, 17.76486015], [83.36402893, 17.76486015], [83.36402893, 17.76458359], [83.36374664, 17.76458359], [83.36374664, 17.76430511], [83.36347198, 17.76431274], [83.36347198, 17.76403046], [83.36319733, 17.76403046], [83.36319733, 17.76375008], [83.36264038, 17.76375008], [83.36264038, 17.7634716], [83.36235809, 17.7634716], [83.36235809, 17.76319504], [83.36207581, 17.76320267], [83.36207581, 17.76292038], [83.36152649, 17.76292038], [83.36152649, 17.76264191], [83.36125183, 17.76264191], [83.36125183, 17.76236153], [83.36096954, 17.76236153], [83.36096954, 17.76208305], [83.36068726, 17.76209259], [83.36068726, 17.7618084], [83.36042023, 17.7618084], [83.36042023, 17.76152992], [83.35986328, 17.76152992], [83.35986328, 17.76124954], [83.35901642, 17.76124954], [83.35901642, 17.76096916], [83.35874939, 17.76097298], [83.35874939, 17.7606945], [83.35819244, 17.7606945], [83.35819244, 17.76041794], [83.35791779, 17.76041985], [83.35791779, 17.76013947], [83.3576355, 17.76013947], [83.3576355, 17.75986099], [83.35708618, 17.75986099], [83.35708618, 17.75958061], [83.35680389, 17.75958252], [83.35680389, 17.75930786], [83.35652924, 17.75930977], [83.35652924, 17.75901985], [83.35624695, 17.75902557], [83.35624695, 17.75875092], [83.35597229, 17.75875092], [83.35597229, 17.75847054], [83.35569763, 17.75847244], [83.35569763, 17.75819397], [83.35541534, 17.75819397], [83.35541534, 17.7579155], [83.35514069, 17.75792122], [83.35514069, 17.75764084], [83.3548584, 17.75764084], [83.3548584, 17.75736046], [83.35457611, 17.75736046], [83.35457611, 17.75708008], [83.35430908, 17.7570858], [83.35430908, 17.75597191], [83.35402679, 17.75597191], [83.35402679, 17.75569344], [83.35375214, 17.75570107], [83.35375214, 17.75542068], [83.35346985, 17.75542068], [83.35346985, 17.75485992], [83.35319519, 17.75486183], [83.35319519, 17.75430489], [83.3529129, 17.75430489], [83.3529129, 17.75402832], [83.35263824, 17.75403023], [83.35263824, 17.75346947], [83.35236359, 17.75347137], [83.35236359, 17.75319481], [83.3520813, 17.75319481], [83.3520813, 17.75263977], [83.35180664, 17.75263977], [83.35180664, 17.75235939], [83.35152435, 17.7523613], [83.35152435, 17.75208282], [83.35124969, 17.75208282], [83.35124969, 17.75180626], [83.35098267, 17.75181007], [83.35098267, 17.75152969], [83.35069275, 17.75152969], [83.35069275, 17.75125122], [83.35041809, 17.75125122], [83.35041809, 17.75097275], [83.34986115, 17.75097275], [83.34986115, 17.75069427], [83.34902954, 17.75069427], [83.34902954, 17.7504158], [83.34929657, 17.75041962], [83.34929657, 17.74986076], [83.34958649, 17.74986076], [83.34958649, 17.74957848], [83.34986115, 17.7495842], [83.34986115, 17.74930573], [83.35041809, 17.74930954], [83.35041809, 17.74875069], [83.35069275, 17.74875069], [83.35069275, 17.74818993], [83.35097504, 17.74819374], [83.35097504, 17.74764061], [83.35069275, 17.74764061], [83.35069275, 17.74707985], [83.35041809, 17.74708366], [83.35041809, 17.74652863], [83.3501358, 17.74653053], [83.3501358, 17.74625015], [83.34986115, 17.74625015], [83.34986115, 17.74596977], [83.34958649, 17.74597168], [83.34958649, 17.74569511], [83.34929657, 17.74570084], [83.34929657, 17.74542046], [83.34902954, 17.74542046], [83.34902954, 17.74514008], [83.34874725, 17.74514008], [83.34874725, 17.7448597], [83.3473587, 17.7448616], [83.3473587, 17.74458313], [83.3465271, 17.74458313], [83.3465271, 17.74430466], [83.34625244, 17.74430466], [83.34625244, 17.74374962], [83.34597015, 17.74374962], [83.34597015, 17.74319077], [83.3456955, 17.74319458], [83.3456955, 17.74263954], [83.34541321, 17.74263954], [83.34541321, 17.74236107], [83.34513855, 17.74236107], [83.34513855, 17.74180984], [83.34485626, 17.74180984], [83.34485626, 17.74125099], [83.3445816, 17.74125099], [83.3445816, 17.74069023], [83.34430695, 17.74069214], [83.34430695, 17.74013901], [83.34401703, 17.74014091], [83.34401703, 17.73958015], [83.34375, 17.73958206], [83.34375, 17.73902702], [83.34348297, 17.73903275], [83.34348297, 17.73847008], [83.34319305, 17.73847389], [83.34319305, 17.73791695], [83.3429184, 17.73792267], [83.3429184, 17.73736191], [83.34263611, 17.73736191], [83.34263611, 17.73541641], [83.3429184, 17.73542023], [83.3429184, 17.73389053], [83.3429184, 17.73347282], [83.34319305, 17.73347282], [83.34319305, 17.73263931], [83.34348297, 17.73264122], [83.34348297, 17.73153114], [83.34375763, 17.73153114], [83.34375763, 17.73125076], [83.34402466, 17.73125076], [83.34401703, 17.73042107], [83.34430695, 17.73042107], [83.34430695, 17.72986031], [83.3445816, 17.72986031], [83.3445816, 17.72957993], [83.34513855, 17.72958374], [83.34513855, 17.72930336], [83.34570313, 17.72931099], [83.34570313, 17.72820091], [83.34541321, 17.72820091], [83.34541321, 17.72735977], [83.34513855, 17.72736168], [83.34513855, 17.72652817], [83.34485626, 17.72653008], [83.34485626, 17.72569275], [83.3445816, 17.72569466], [83.3445816, 17.72513962], [83.34430695, 17.72513962], [83.34430695, 17.72486115], [83.34375, 17.72486115], [83.34375, 17.72458267], [83.34319305, 17.72458267], [83.34319305, 17.72402763], [83.3429184, 17.72402954], [83.3429184, 17.72375107], [83.34263611, 17.72375107], [83.34263611, 17.72347069], [83.34208679, 17.7234726], [83.34208679, 17.72319412], [83.3418045, 17.72319412], [83.3418045, 17.72291756], [83.34124756, 17.72291756], [83.34124756, 17.72263908], [83.34069824, 17.72263908], [83.34069824, 17.72236061], [83.34041595, 17.72236061], [83.34041595, 17.72207832], [83.33985901, 17.72208405], [83.33985901, 17.72180557], [83.33930206, 17.72180939], [83.33930206, 17.72153091], [83.33875275, 17.72153091], [83.33875275, 17.72125053], [83.33850098, 17.72125053], [83.3381958, 17.72125053], [83.3381958, 17.72096825], [83.3373642, 17.72097206], [83.3373642, 17.72069359], [83.33680725, 17.72069359], [83.33680725, 17.72041893], [83.33625031, 17.72042084], [83.33625031, 17.72014046], [83.33569336, 17.72014046], [83.33569336, 17.71985054], [83.33513641, 17.71986198], [83.33513641, 17.71958351], [83.3345871, 17.71958351], [83.3345871, 17.71930695], [83.33374786, 17.71931076], [83.33374786, 17.71903038], [83.33319092, 17.71903038], [83.33319092, 17.71874809], [83.3326416, 17.71874809], [83.3326416, 17.71846962], [83.33208466, 17.71847153], [83.33208466, 17.71819687], [83.33152771, 17.71820068], [83.33152771, 17.7179203], [83.33097076, 17.7179203], [83.33097076, 17.71763992], [83.33040619, 17.71763992], [83.33040619, 17.71735954], [83.3298645, 17.71736145], [83.3298645, 17.71708298], [83.32930756, 17.71708298], [83.32930756, 17.7168045], [83.32875824, 17.71681023], [83.32875824, 17.71652985], [83.32818604, 17.71652985], [83.32818604, 17.71624947], [83.32763672, 17.71624947], [83.32763672, 17.71597099], [83.32707977, 17.7159729], [83.32707977, 17.71569443], [83.32653046, 17.71569443], [83.32653046, 17.71541405], [83.32596588, 17.71541977], [83.32596588, 17.71513939], [83.32541656, 17.71513939], [83.32541656, 17.71486092], [83.32485962, 17.71486092], [83.32485962, 17.71458054], [83.32430267, 17.71458244], [83.32430267, 17.71430588], [83.32375336, 17.71430969], [83.32375336, 17.71404076], [83.32319641, 17.71404076], [83.32319641, 17.71375084], [83.32290649, 17.71375084], [83.32290649, 17.71347046], [83.32236481, 17.71347237], [83.32236481, 17.71319389], [83.32180786, 17.71319389], [83.32180786, 17.71291733], [83.32125092, 17.71292114], [83.32125092, 17.71264076], [83.32096863, 17.71264076], [83.32096863, 17.71236038], [83.32041931, 17.71236038], [83.32041931, 17.71208191], [83.31986237, 17.71208382], [83.31986237, 17.71180534], [83.31931305, 17.71181107], [83.31931305, 17.71153069], [83.31903076, 17.71153069], [83.31903076, 17.71125031], [83.31846619, 17.71125031], [83.31846619, 17.71097183], [83.31791687, 17.71097183], [83.31791687, 17.71069527], [83.31735992, 17.7107029], [83.31735992, 17.71042252], [83.3170929, 17.71042252], [83.3170929, 17.71014023], [83.31652832, 17.71014023], [83.31652832, 17.70986176], [83.31625366, 17.70986176], [83.31625366, 17.70958328], [83.31597137, 17.70958328], [83.31597137, 17.70930481], [83.31541443, 17.70930481], [83.31541443, 17.70902824], [83.31513977, 17.70903015], [83.31513977, 17.70874977], [83.31485748, 17.70874977], [83.31485748, 17.70846748], [83.31458282, 17.7084713], [83.31458282, 17.70819473], [83.31430817, 17.70819473], [83.31430817, 17.70791626], [83.31402588, 17.70791626], [83.31402588, 17.70763969], [83.31346893, 17.70763969], [83.31346893, 17.70736122], [83.31318665, 17.70736122], [83.31318665, 17.70708084], [83.31291962, 17.70708275], [83.31291962, 17.70680618], [83.31263733, 17.70680809], [83.31263733, 17.70652962], [83.31236267, 17.70652962], [83.31236267, 17.70625114], [83.31208038, 17.70625114], [83.31208038, 17.70597076], [83.31153107, 17.70597267], [83.31153107, 17.7056942], [83.31124878, 17.7056942], [83.31124878, 17.70541763], [83.31096649, 17.70541954], [83.31096649, 17.70514107], [83.31069183, 17.70514107], [83.31069183, 17.70485115], [83.31014252, 17.70486069], [83.31014252, 17.70458412], [83.30986023, 17.70458412], [83.30986023, 17.70430756], [83.3095932, 17.70430946], [83.3095932, 17.70403099], [83.30902863, 17.70403099], [83.30902863, 17.70375061], [83.30874634, 17.70375061], [83.30874634, 17.70347023], [83.30847168, 17.70347214], [83.30847168, 17.70319366], [83.30819702, 17.70319366], [83.30819702, 17.70291519], [83.30764771, 17.70292091], [83.30764771, 17.70264053], [83.30735779, 17.70264053], [83.30735779, 17.70236015], [83.30708313, 17.70236206], [83.30708313, 17.70208359], [83.30652618, 17.70208359], [83.30652618, 17.70180321], [83.30625153, 17.70181084], [83.30625153, 17.70125008], [83.30596924, 17.70125008], [83.30596924, 17.70042038], [83.30568695, 17.70042038], [83.30568695, 17.6981926], [83.30596924, 17.6981945], [83.30596924, 17.69791603], [83.30625153, 17.69791985], [83.30625153, 17.6973629], [83.30513763, 17.6973629], [83.30513763, 17.69763947], [83.30486298, 17.69763947], [83.30486298, 17.69791985], [83.30458069, 17.69791603], [83.30458069, 17.6981945], [83.30319214, 17.6981945], [83.30319214, 17.69791603], [83.30264282, 17.69791985], [83.30264282, 17.69763947], [83.30236053, 17.69763947], [83.30236053, 17.69681168], [83.30264282, 17.69681168], [83.30264282, 17.69652939], [83.30291748, 17.69652939], [83.30291748, 17.69625092], [83.30319214, 17.69625092], [83.30319214, 17.69597054], [83.30347443, 17.69597244], [83.30347443, 17.69569397], [83.30374908, 17.69569397], [83.30374908, 17.6954174], [83.30403137, 17.69541931], [83.30403137, 17.69514084], [83.30541992, 17.69514084], [83.30541992, 17.69541931], [83.30569458, 17.6954174], [83.30569458, 17.69597244], [83.30596924, 17.69597054], [83.30596924, 17.69625092], [83.30625153, 17.69625092], [83.30625153, 17.69652939], [83.30652618, 17.69652939], [83.30652618, 17.69681168], [83.30680847, 17.69680595], [83.30680847, 17.69708252], [83.30735779, 17.69708252], [83.30735779, 17.6973629], [83.30764008, 17.6973629], [83.30764008, 17.69763947], [83.30819702, 17.69763947], [83.30819702, 17.69681168], [83.30764771, 17.69681168], [83.30764771, 17.69652939], [83.30735779, 17.69652939], [83.30735779, 17.69625092], [83.30708313, 17.69625092], [83.30708313, 17.69568062], [83.30680847, 17.69569397], [83.30680847, 17.69514084], [83.30652618, 17.69514084], [83.30652618, 17.6914711], [83.30652618, 17.69124985], [83.30680847, 17.69124985], [83.30680847, 17.68931007], [83.30652618, 17.68931007], [83.30652618, 17.68819046], [83.30596924, 17.68819046], [83.30596924, 17.68931007], [83.30625153, 17.68930435], [83.30625153, 17.69097137], [83.30596924, 17.69097137], [83.30596924, 17.69123077], [83.30596924, 17.69291878], [83.30568695, 17.69291115], [83.30568695, 17.69319916], [83.30236053, 17.69319916], [83.30236053, 17.69375038], [83.30208588, 17.69375038], [83.30208588, 17.69430923], [83.30179596, 17.69430923], [83.30179596, 17.69486046], [83.3015213, 17.69486046], [83.3015213, 17.69541931], [83.30124664, 17.6954174], [83.30124664, 17.69597244], [83.30014038, 17.69597244], [83.30014038, 17.69569397], [83.29985809, 17.69569397], [83.29985809, 17.6954174], [83.29930878, 17.69541931], [83.29930878, 17.69514084], [83.29957581, 17.69514084], [83.29957581, 17.69486046], [83.29985809, 17.69486046], [83.29985809, 17.69457817], [83.30014038, 17.69458389], [83.30014038, 17.69430542], [83.30042267, 17.69430923], [83.30042267, 17.69403076], [83.30069733, 17.69403076], [83.30069733, 17.69375038], [83.30124664, 17.69375038], [83.30124664, 17.69346809], [83.30152893, 17.69347191], [83.30152893, 17.69319534], [83.30179596, 17.69319916], [83.30179596, 17.69291115], [83.30152893, 17.69291878], [83.30152893, 17.69263649], [83.30124664, 17.6926403], [83.30124664, 17.69207954], [83.30097198, 17.69208336], [83.30097198, 17.69236183], [83.30069733, 17.69235992], [83.30069733, 17.6926403], [83.30041504, 17.69263649], [83.30041504, 17.69291878], [83.29985809, 17.69291115], [83.29985809, 17.69319916], [83.29958344, 17.69319534], [83.29958344, 17.69347191], [83.29902649, 17.69346809], [83.29902649, 17.69375038], [83.29875183, 17.69375038], [83.29875183, 17.69403076], [83.29846191, 17.69403076], [83.29846191, 17.69430923], [83.29763794, 17.69430923], [83.29763794, 17.69403076], [83.29736328, 17.69403076], [83.29736328, 17.69375038], [83.29708099, 17.69375038], [83.29708099, 17.69319916], [83.29736328, 17.69319916], [83.29736328, 17.69291115], [83.29763794, 17.69291878], [83.29763794, 17.69263649], [83.29818726, 17.6926403], [83.29818726, 17.69235992], [83.29875183, 17.69236183], [83.29875183, 17.69208336], [83.29902649, 17.69208336], [83.29902649, 17.69180679], [83.29930878, 17.69180679], [83.29930878, 17.69152641], [83.29957581, 17.69153023], [83.29957581, 17.69042015], [83.29875183, 17.69041443], [83.29875183, 17.69069672], [83.29818726, 17.69069099], [83.29818726, 17.69124985], [83.29792023, 17.69124985], [83.29792023, 17.69153023], [83.29763794, 17.69152641], [83.29763794, 17.69180679], [83.29708099, 17.69180679], [83.29708099, 17.69152641], [83.29680634, 17.69153023], [83.29680634, 17.69124985], [83.29651642, 17.69124985], [83.29651642, 17.69096947], [83.29624939, 17.69097137], [83.29624939, 17.69069672], [83.29597473, 17.69069672], [83.29597473, 17.69041443], [83.29569244, 17.69042015], [83.29569244, 17.69013977], [83.29541779, 17.69013977], [83.29541779, 17.68987083], [83.29514313, 17.68987083], [83.29514313, 17.68958092], [83.29486084, 17.68958282], [83.29486084, 17.68930435], [83.29402924, 17.68931007], [83.29402924, 17.68902969], [83.29319763, 17.68902969], [83.29319763, 17.68875122], [83.29096985, 17.68875122], [83.29096985, 17.68847084], [83.2895813, 17.68847275], [83.2895813, 17.68819427], [83.28791809, 17.68819427], [83.28791809, 17.6879158], [83.28624725, 17.6879158], [83.28624725, 17.68819427], [83.2859726, 17.68819427], [83.2859726, 17.68847275], [83.28430939, 17.68847084], [83.28430176, 17.68875122], [83.2840271, 17.68875122], [83.2840271, 17.68902969], [83.28346252, 17.68902969], [83.28346252, 17.68931007], [83.28235626, 17.68931007], [83.28235626, 17.69013977], [83.2820816, 17.69013977], [83.2820816, 17.69236183], [83.28235626, 17.69235992], [83.28235626, 17.69375038], [83.2820816, 17.69375038], [83.2820816, 17.69458389], [83.28180695, 17.69457817], [83.28180695, 17.69486046], [83.2804184, 17.69486046], [83.2804184, 17.69457817], [83.27986145, 17.69457817], [83.27986145, 17.69486046], [83.27958679, 17.69486046], [83.27958679, 17.69541931], [83.2793045, 17.6954174], [83.2793045, 17.69597244], [83.27902985, 17.69597054], [83.27902985, 17.69681168], [83.27874756, 17.69681168], [83.27874756, 17.6993103], [83.2784729, 17.6993103], [83.2784729, 17.70014], [83.27819824, 17.70014], [83.27819824, 17.70042038], [83.27791595, 17.70042038], [83.27791595, 17.70070076], [83.2776413, 17.70069313], [83.2776413, 17.7009716], [83.27735901, 17.7009697], [83.27735901, 17.70125008], [83.27680206, 17.70125008], [83.27680206, 17.70208359], [83.2765274, 17.70208359], [83.2765274, 17.70236206], [83.27625275, 17.70236015], [83.27625275, 17.70292091], [83.27597046, 17.70291519], [83.27597046, 17.70319366], [83.2756958, 17.70319366], [83.2756958, 17.70347214], [83.27540588, 17.70347023], [83.27540588, 17.70375061], [83.27513885, 17.70375061], [83.27513885, 17.70403099], [83.27458191, 17.70403099], [83.27458191, 17.70430946], [83.27430725, 17.70430756], [83.27430725, 17.70486069], [83.27401733, 17.70485115], [83.27401733, 17.70514107], [83.27375031, 17.70514107], [83.27375031, 17.70541954], [83.27347565, 17.70541763], [83.27347565, 17.70597267], [83.27319336, 17.70597076], [83.27319336, 17.70652962], [83.2729187, 17.70652962], [83.2729187, 17.70708275], [83.27263641, 17.70708084], [83.27263641, 17.70903015], [83.2729187, 17.70902824], [83.2729187, 17.70930481], [83.27319336, 17.70929909], [83.27319336, 17.7107029], [83.2729187, 17.7107029], [83.2729187, 17.71125031], [83.27263641, 17.71125031], [83.27263641, 17.71181107], [83.27236176, 17.71180534], [83.27236176, 17.71208382], [83.2720871, 17.71208191], [83.2720871, 17.71236038], [83.27179718, 17.71236038], [83.27179718, 17.71264076], [83.27069092, 17.71264076], [83.27069092, 17.71292114], [83.2701416, 17.71292114], [83.2701416, 17.71264076], [83.26957703, 17.71264076], [83.26957703, 17.71236038], [83.26930237, 17.71236038], [83.26930237, 17.71208191], [83.26902771, 17.71208382], [83.26902771, 17.71180534], [83.26847839, 17.71181107], [83.26847839, 17.71153069], [83.26819611, 17.71153069], [83.26819611, 17.71125031], [83.26790619, 17.71125031], [83.26790619, 17.71097183], [83.26763916, 17.71097183], [83.26763916, 17.71069527], [83.26735687, 17.7107029], [83.26735687, 17.71014023], [83.26680756, 17.71014023], [83.26680756, 17.71042252], [83.26625061, 17.71042252], [83.26625061, 17.7107029], [83.26569366, 17.71069527], [83.26569366, 17.71097183], [83.26541901, 17.71097183], [83.26541901, 17.71125031], [83.26374817, 17.71125031], [83.26374817, 17.71097183], [83.26347351, 17.71097183], [83.26347351, 17.70958328], [83.26374817, 17.70958328], [83.26374817, 17.70902824], [83.26403046, 17.70903015], [83.26403046, 17.70874977], [83.26457977, 17.70874977], [83.26457977, 17.70846748], [83.26486206, 17.7084713], [83.26486206, 17.70819473], [83.26513672, 17.70819473], [83.26513672, 17.70791626], [83.26625061, 17.70791626], [83.26625061, 17.70597267], [83.26597595, 17.70597267], [83.26597595, 17.7056942], [83.26457977, 17.7056942], [83.26457977, 17.70541763], [83.26346588, 17.70541954], [83.26346588, 17.70514107], [83.26319122, 17.70514107], [83.26319122, 17.70430946], [83.26346588, 17.70430946], [83.26346588, 17.70403099], [83.26431274, 17.70403099], [83.26431274, 17.70430946], [83.26541901, 17.70430756], [83.26541901, 17.70458412], [83.26597595, 17.70458412], [83.26597595, 17.70486069], [83.26930237, 17.70485115], [83.26930237, 17.70514107], [83.27179718, 17.70514107], [83.27179718, 17.70458031], [83.2720871, 17.70458412], [83.2720871, 17.70430756], [83.27236176, 17.70430946], [83.27236176, 17.70318985], [83.27263641, 17.70319366], [83.27263641, 17.70291519], [83.2729187, 17.70292091], [83.2729187, 17.70236015], [83.27319336, 17.70236015], [83.27319336, 17.70207977], [83.27347565, 17.70208359], [83.27347565, 17.70180321], [83.27375031, 17.70181084], [83.27375031, 17.70125008], [83.27401733, 17.70125008], [83.27401733, 17.70042038], [83.27430725, 17.70042038], [83.27430725, 17.70014], [83.27458191, 17.70014], [83.27458191, 17.69958115], [83.2748642, 17.69958115], [83.2748642, 17.69930649], [83.27513885, 17.69930267], [83.27513885, 17.69902802], [83.27540588, 17.69902992], [83.27540588, 17.69874954], [83.2756958, 17.69874954], [83.2756958, 17.69847107], [83.27597046, 17.69847107], [83.27597046, 17.6981945], [83.27625275, 17.6981945], [83.27625275, 17.69791603], [83.2765274, 17.69791985], [83.2765274, 17.69763947], [83.27680206, 17.69763947], [83.27680206, 17.6973629], [83.27735901, 17.6973629], [83.27735901, 17.69708252], [83.2776413, 17.69708252], [83.2776413, 17.69652748], [83.27791595, 17.69652939], [83.27791595, 17.69597054], [83.27819061, 17.69597244], [83.27819824, 17.6954174], [83.2784729, 17.69541931], [83.2784729, 17.69486046], [83.27874756, 17.69486046], [83.27874756, 17.69430923], [83.27902985, 17.69430923], [83.27902985, 17.69403076], [83.2784729, 17.69403076], [83.2784729, 17.69291115], [83.27874756, 17.69291878], [83.27874756, 17.69236183], [83.27902985, 17.69236183], [83.27902985, 17.69180679], [83.2793045, 17.69180679], [83.2793045, 17.69152641], [83.27958679, 17.69153023], [83.27958679, 17.69124985], [83.27986145, 17.69124985], [83.27986145, 17.69096947], [83.28013611, 17.69097137], [83.28013611, 17.69069672], [83.28069305, 17.69069672], [83.28069305, 17.69041443], [83.28098297, 17.69042015], [83.28098297, 17.69013977], [83.28125, 17.69013977], [83.28125, 17.68958092], [83.28152466, 17.68958282], [83.28152466, 17.68874931], [83.28180695, 17.68875122], [83.28180695, 17.68819046], [83.2820816, 17.68819427], [83.2820816, 17.6879158], [83.28235626, 17.68791962], [83.28235626, 17.68764114], [83.28346252, 17.68764114], [83.28346252, 17.68736076], [83.2848587, 17.68736076], [83.2848587, 17.68764114], [83.28569794, 17.68764114], [83.28569794, 17.68736076], [83.2859726, 17.68736076], [83.2859726, 17.68708038], [83.28819275, 17.68708038], [83.28819275, 17.68736076], [83.2904129, 17.68736076], [83.2904129, 17.68764114], [83.29125214, 17.68764114], [83.29125214, 17.68791962], [83.2923584, 17.68791962], [83.2923584, 17.68764114], [83.29319763, 17.68764114], [83.29319763, 17.68736076], [83.29347229, 17.68736076], [83.29347229, 17.68708038], [83.29374695, 17.68708229], [83.29374695, 17.68680573], [83.29402924, 17.68680954], [83.29402924, 17.68653107], [83.29429626, 17.68653107], [83.29429626, 17.68597031], [83.29458618, 17.68597221], [83.29458618, 17.68569374], [83.29541779, 17.68569374], [83.29541779, 17.68597221], [83.2959671, 17.68597031], [83.2959671, 17.68625069], [83.29624939, 17.68625069], [83.29624939, 17.68653107], [83.29708099, 17.68653107], [83.29708099, 17.68680954], [83.29763794, 17.68680954], [83.29763794, 17.68653107], [83.2980423, 17.68652916], [83.29818726, 17.68653107], [83.29818726, 17.6854229], [83.29680634, 17.6854229], [83.29680634, 17.68514061], [83.29572296, 17.68514061], [83.29569244, 17.68486023], [83.29547882, 17.68486023], [83.29458618, 17.68486023], [83.29458618, 17.68394089], [83.29458618, 17.68347168], [83.29430389, 17.68347168], [83.29430389, 17.6823616], [83.29486084, 17.6823616], [83.29486084, 17.68152809], [83.29514313, 17.68152809], [83.29514313, 17.68124962], [83.29569244, 17.68124962], [83.29569244, 17.68097115], [83.29597473, 17.68097305], [83.29597473, 17.67930794], [83.29569244, 17.67930984], [83.29569244, 17.67847061], [83.29541779, 17.67847252], [83.29541779, 17.67513847], [83.29514313, 17.67514038], [83.29514313, 17.67486954], [83.29486084, 17.67486954], [83.29486084, 17.67431068], [83.29458618, 17.67431068], [83.29458618, 17.6740303], [83.29429626, 17.6740303], [83.29429626, 17.67374992], [83.29402924, 17.67374992], [83.29402924, 17.67319107], [83.29374695, 17.67319489], [83.29374695, 17.67291641], [83.29347229, 17.67292023], [83.29347229, 17.67235947], [83.29291534, 17.67236137], [83.29291534, 17.6720829], [83.29264069, 17.6720829], [83.29264069, 17.67180634], [83.29208374, 17.67180634], [83.29208374, 17.67152786], [83.29180908, 17.67152977], [83.29180908, 17.67124939], [83.29125214, 17.67124939], [83.29125214, 17.67097282], [83.29096985, 17.67097282], [83.29096985, 17.67069435], [83.2904129, 17.67069435], [83.2904129, 17.67041588], [83.29013824, 17.67041969], [83.29013824, 17.66986084], [83.28985596, 17.66986084], [83.28985596, 17.66957855], [83.28930664, 17.66958427], [83.28930664, 17.6693058], [83.28901672, 17.66930962], [83.28901672, 17.66902924], [83.28874969, 17.66902924], [83.28874969, 17.66874123], [83.28819275, 17.66875076], [83.28819275, 17.66847229], [83.28806305, 17.66847229], [83.28791809, 17.66847229], [83.28791809, 17.66819382], [83.2876358, 17.66819382], [83.2876358, 17.66791725], [83.28736115, 17.66791916], [83.28736115, 17.66764069], [83.28679657, 17.66764069], [83.28679657, 17.66736031], [83.28652191, 17.66736031], [83.28652191, 17.66707993], [83.28624725, 17.66708374], [83.28624725, 17.66680527], [83.2859726, 17.66680908], [83.2859726, 17.66653061], [83.28542328, 17.66653061], [83.28542328, 17.66625023], [83.28514099, 17.66625023], [83.28514099, 17.66570091], [83.28457642, 17.66570091], [83.28457642, 17.66542053], [83.28430176, 17.66542053], [83.28430176, 17.66514015], [83.2840271, 17.66514015], [83.2840271, 17.66485977], [83.28375244, 17.66486168], [83.28375244, 17.66458321], [83.28347015, 17.66458321], [83.28347015, 17.66374969], [83.28375244, 17.66374969], [83.28375244, 17.66347122], [83.2840271, 17.66347313], [83.2840271, 17.66319656], [83.28375244, 17.66319656], [83.28375244, 17.66263962], [83.28346252, 17.66263962], [83.28346252, 17.66180992], [83.28320313, 17.66180992], [83.28320313, 17.66125107], [83.28291321, 17.66125107], [83.28291321, 17.66069031], [83.28263855, 17.66069221], [83.28263855, 17.66013908], [83.28235626, 17.6601429], [83.28235626, 17.65986061], [83.28125, 17.65986061], [83.28125, 17.6595726], [83.28013611, 17.65958214], [83.28013611, 17.65930557], [83.27902985, 17.65930939], [83.27902985, 17.65903282], [83.2776413, 17.65903282], [83.2776413, 17.65875053], [83.27735901, 17.65875053], [83.27735901, 17.65847015], [83.2765274, 17.65847206], [83.2765274, 17.65791702], [83.27625275, 17.65792274], [83.27625275, 17.65764046], [83.2756958, 17.65764046], [83.2756958, 17.65736008], [83.2748642, 17.65736008], [83.2748642, 17.65708351], [83.27430725, 17.65708351], [83.27430725, 17.65680504], [83.27347565, 17.65680504], [83.27347565, 17.65652847], [83.2729187, 17.65653038], [83.2729187, 17.65625191], [83.27236176, 17.65625191], [83.27236176, 17.65597153], [83.27180481, 17.65597153], [83.27180481, 17.65569496], [83.27124786, 17.65570259], [83.27124786, 17.6554203], [83.27069092, 17.6554203], [83.27069092, 17.65513992], [83.2701416, 17.65513992], [83.2701416, 17.65485764], [83.26958466, 17.65486145], [83.26958466, 17.65458298], [83.26902771, 17.65458298], [83.26902771, 17.65430641], [83.26875305, 17.65430832], [83.26875305, 17.65402985], [83.26819611, 17.65402985], [83.26819611, 17.65376091], [83.26763916, 17.65376091], [83.26763916, 17.65346909], [83.26708221, 17.6534729], [83.26708221, 17.65319443], [83.26652527, 17.65319443], [83.26652527, 17.65291786], [83.26597595, 17.65291977], [83.26597595, 17.65263939], [83.26541901, 17.65263939], [83.26541901, 17.65236092], [83.26486206, 17.65236092], [83.26486206, 17.65208054], [83.26430511, 17.65208244], [83.26430511, 17.65180779], [83.26374817, 17.65180969], [83.26374817, 17.65153122], [83.26319122, 17.65153122], [83.26319122, 17.65125084], [83.26264191, 17.65125084], [83.26264191, 17.65097046], [83.26180267, 17.65097237], [83.26180267, 17.65069389], [83.26152802, 17.65069962], [83.26152802, 17.65042114], [83.26125336, 17.65042114], [83.26125336, 17.65014076], [83.26069641, 17.65014076], [83.26069641, 17.64903069], [83.26097107, 17.64903069], [83.26097107, 17.64875031], [83.26125336, 17.64875031], [83.26125336, 17.64763069], [83.26097107, 17.64763832], [83.26097107, 17.64736176], [83.26069641, 17.64736176], [83.26069641, 17.64708328], [83.26013947, 17.64708328], [83.26013947, 17.64680481], [83.25986481, 17.64680481], [83.25986481, 17.6459713], [83.26013947, 17.6459713], [83.26013947, 17.64569473], [83.26041412, 17.64569473], [83.26041412, 17.64541626], [83.26013947, 17.64542007], [83.26013947, 17.64402962], [83.25985718, 17.64402962], [83.25985718, 17.64375114], [83.25930786, 17.64375114], [83.25930786, 17.64347076], [83.25902557, 17.64347267], [83.25902557, 17.6431942], [83.25875092, 17.6431942], [83.25875092, 17.64291763], [83.25791931, 17.64291954], [83.25791931, 17.64263916], [83.25736237, 17.64263916], [83.25736237, 17.64236069], [83.25680542, 17.64236069], [83.25680542, 17.64208412], [83.25653076, 17.64208412], [83.25653076, 17.64180565], [83.25569153, 17.64182281], [83.25569153, 17.64152908], [83.25485992, 17.64152908], [83.25485992, 17.64125061], [83.25458527, 17.64125061], [83.25458527, 17.64097214], [83.25402832, 17.64097214], [83.25402832, 17.64069366], [83.25375366, 17.64069366], [83.25375366, 17.6404171], [83.25319672, 17.64042091], [83.25319672, 17.64014053], [83.25263977, 17.64014053], [83.25263977, 17.63985825], [83.25208282, 17.63986206], [83.25208282, 17.63958359], [83.25180817, 17.63958359], [83.25180817, 17.63930511], [83.25068665, 17.63931084], [83.25068665, 17.63903046], [83.25013733, 17.63903046], [83.25013733, 17.63875961], [83.24958038, 17.63875961], [83.24958038, 17.6384697], [83.24903107, 17.6384716], [83.24903107, 17.63819695], [83.24819183, 17.63820076], [83.24819183, 17.63792038], [83.24764252, 17.63792038], [83.24764252, 17.63764], [83.2473526, 17.63764], [83.2473526, 17.63735962], [83.24680328, 17.63736153], [83.24680328, 17.63708305], [83.24624634, 17.63708305], [83.24624634, 17.63680458], [83.24597168, 17.6368103], [83.24597168, 17.63652992], [83.2454071, 17.63652992], [83.2454071, 17.63624954], [83.24485779, 17.63624954], [83.24485779, 17.63597107], [83.24458313, 17.63597488], [83.24458313, 17.6356945], [83.24402618, 17.6356945], [83.24402618, 17.63541412], [83.24291992, 17.63541985], [83.24291992, 17.63513947], [83.24263763, 17.63513947], [83.24263763, 17.63486099], [83.24236298, 17.63486099], [83.24236298, 17.63458061], [83.24180603, 17.63458252], [83.24180603, 17.63430405], [83.24124908, 17.63430977], [83.24124908, 17.63402939], [83.2409668, 17.63402939], [83.2409668, 17.63375092], [83.24069214, 17.63375092], [83.24069214, 17.63347054], [83.24013519, 17.63347244], [83.24013519, 17.63319206], [83.23986053, 17.63319206], [83.23986053, 17.63263893], [83.23958588, 17.63263893], [83.23958588, 17.63236046], [83.23929596, 17.63236046], [83.23929596, 17.63208008], [83.23874664, 17.63208389], [83.23874664, 17.63180542], [83.23847198, 17.63181114], [83.23847198, 17.63153267], [83.23819733, 17.63153267], [83.23819733, 17.63125038], [83.23791504, 17.63125038], [83.23791504, 17.63097191], [83.23764038, 17.63097191], [83.23764038, 17.63069534], [83.23735809, 17.63070107], [83.23735809, 17.63042259], [83.23707581, 17.63042259], [83.23707581, 17.6301403], [83.23680878, 17.6301403], [83.23680878, 17.62986183], [83.23625183, 17.62986183], [83.23625183, 17.62958336], [83.23596954, 17.6295929], [83.23596954, 17.62929916], [83.23569489, 17.62930489], [83.23569489, 17.62902832], [83.2354126, 17.62903023], [83.2354126, 17.62846756], [83.23513794, 17.62847137], [83.23513794, 17.62819481], [83.23486328, 17.62819481], [83.23486328, 17.62763977], [83.23458099, 17.62763977], [83.23458099, 17.62735748], [83.23430634, 17.6273613], [83.23430634, 17.62680626], [83.23401642, 17.62682152], [83.23401642, 17.62652969], [83.23374939, 17.62652969], [83.23374939, 17.62597084], [83.23347473, 17.62597275], [83.23347473, 17.62569427], [83.23319244, 17.62569427], [83.23319244, 17.62513924], [83.23291779, 17.62514114], [83.23291779, 17.62430954], [83.23264313, 17.62430954], [83.23264313, 17.62264061], [83.23236847, 17.62264061], [83.23236847, 17.61930275], [83.2326355, 17.61930466], [83.2326355, 17.61902809], [83.2334671, 17.61903], [83.2334671, 17.61874962], [83.23374939, 17.61874962], [83.23374939, 17.61736107], [83.2334671, 17.61736107], [83.2334671, 17.6170826], [83.23319244, 17.6170826], [83.23319244, 17.61680603], [83.23291779, 17.61681175], [83.23291779, 17.61652946], [83.23264313, 17.61652946], [83.23264313, 17.61568832], [83.23291779, 17.61569405], [83.23291779, 17.61514091], [83.233078, 17.61514091], [83.23319244, 17.61514091], [83.23319244, 17.6145916], [83.2334671, 17.6145916], [83.2334671, 17.61403084], [83.23374939, 17.61403084], [83.23374939, 17.61375046], [83.23401642, 17.61375046], [83.23401642, 17.61346817], [83.23430634, 17.61347198], [83.23430634, 17.61319351], [83.23486328, 17.61319351], [83.23486328, 17.61291885], [83.23513794, 17.61292076], [83.23513794, 17.61264038], [83.23596954, 17.61264038], [83.23596954, 17.61292076], [83.23652649, 17.61291885], [83.23652649, 17.61319351], [83.23680878, 17.61319351], [83.23680878, 17.61347198], [83.23764038, 17.61346817], [83.23764038, 17.61375046], [83.23819733, 17.61375046], [83.23819733, 17.61346817], [83.23847198, 17.61347198], [83.23847198, 17.61263657], [83.23819733, 17.61264038], [83.23819733, 17.61181068], [83.23792267, 17.61181068], [83.23792267, 17.6115303], [83.23735809, 17.6115303], [83.23735809, 17.61124992], [83.23680878, 17.61124992], [83.23680878, 17.61096954], [83.23596954, 17.61096954], [83.23596954, 17.61124992], [83.23568726, 17.61124992], [83.23568726, 17.61096954], [83.23542023, 17.61097145], [83.23542023, 17.61069679], [83.23486328, 17.61069679], [83.23486328, 17.61041451], [83.23458099, 17.61042023], [83.23458099, 17.61013985], [83.23430634, 17.61013985], [83.23430634, 17.60985947], [83.23402405, 17.60986137], [83.23402405, 17.6095829], [83.23347473, 17.6095829], [83.23347473, 17.60930443], [83.23319244, 17.60931015], [83.23319244, 17.60902977], [83.23291779, 17.60902977], [83.23291779, 17.60874939], [83.23236084, 17.60874939], [83.23236084, 17.60847473], [83.23208618, 17.60847473], [83.23208618, 17.60819435], [83.23180389, 17.60819435], [83.23180389, 17.60791588], [83.23152924, 17.60791969], [83.23152924, 17.60764122], [83.23124695, 17.60764122], [83.23124695, 17.60736084], [83.23097229, 17.60736084], [83.23097229, 17.60708046], [83.23041534, 17.60708237], [83.23041534, 17.6068058], [83.2298584, 17.60680962], [83.2298584, 17.60653114], [83.22957611, 17.60653114], [83.22957611, 17.60625076], [83.22875214, 17.60625076], [83.22875214, 17.60597038], [83.22763824, 17.60597229], [83.22763824, 17.60569382], [83.2270813, 17.60569382], [83.2270813, 17.60541725], [83.22680664, 17.60542107], [83.22680664, 17.60514069], [83.22651672, 17.60514069], [83.22651672, 17.60486031], [83.22597504, 17.60486031], [83.22597504, 17.60458374], [83.22541809, 17.60458374], [83.22541809, 17.60430527], [83.2251358, 17.6043129], [83.2251358, 17.60403061], [83.22486115, 17.60403061], [83.22486115, 17.60375023], [83.22458649, 17.60375023], [83.22458649, 17.60347176], [83.22402954, 17.60347176], [83.22402954, 17.60319519], [83.2234726, 17.60320282], [83.2234726, 17.60292244], [83.22319794, 17.60292244], [83.22319794, 17.60264969], [83.22292328, 17.60264969], [83.22289276, 17.60236168], [83.2223587, 17.60236168], [83.2223587, 17.60208321], [83.22180176, 17.60208321], [83.22180176, 17.60180473], [83.22097015, 17.60180473], [83.22097015, 17.60152817], [83.22070313, 17.60152817], [83.22070313, 17.60124969], [83.2195816, 17.60124969], [83.2195816, 17.60097122], [83.21902466, 17.60097313], [83.21902466, 17.60069466], [83.21875, 17.60069466], [83.21875, 17.60041618], [83.21848297, 17.60041809], [83.21848297, 17.60013962], [83.2179184, 17.60013962], [83.2179184, 17.59986115], [83.21763611, 17.59986115], [83.21763611, 17.59958076], [83.21736145, 17.59958267], [83.21736145, 17.59930611], [83.21679688, 17.59930992], [83.21679688, 17.59902954], [83.21652985, 17.59902954], [83.21652985, 17.59875107], [83.21624756, 17.59875107], [83.21624756, 17.59847069], [83.2159729, 17.5984726], [83.2159729, 17.59819412], [83.21569824, 17.59819412], [83.21569061, 17.59791756], [83.21541595, 17.59791946], [83.21541595, 17.59680939], [83.21569061, 17.59680939], [83.21569824, 17.59651947], [83.2159729, 17.59652519], [83.2159729, 17.59541512], [83.21569824, 17.59542084], [83.21569061, 17.59403038], [83.2151413, 17.59403038], [83.2151413, 17.59375], [83.21485901, 17.59375], [83.21485901, 17.59320068], [83.21457672, 17.59320068], [83.21457672, 17.5929203], [83.21430206, 17.5929203], [83.21430206, 17.59263992], [83.2140274, 17.59263992], [83.2140274, 17.59152985], [83.21375275, 17.59152985], [83.21375275, 17.59124947], [83.21347046, 17.59124947], [83.21347046, 17.5909729], [83.21291351, 17.5909729], [83.21291351, 17.59069443], [83.21180725, 17.59069443], [83.21180725, 17.59041595], [83.20791626, 17.59041977], [83.20791626, 17.59013939], [83.20735931, 17.59013939], [83.20735931, 17.58986092], [83.20680237, 17.58986092], [83.20680237, 17.58957863], [83.20625305, 17.58958244], [83.20625305, 17.58930588], [83.20569611, 17.5893116], [83.20569611, 17.58902931], [83.20485687, 17.58902931], [83.20485687, 17.58875084], [83.20458221, 17.58875084], [83.20458221, 17.58847046], [83.20347595, 17.58847237], [83.20347595, 17.58819389], [83.20319366, 17.58819389], [83.20319366, 17.58791733], [83.20291901, 17.58791924], [83.20291901, 17.58764076], [83.20263672, 17.58764076], [83.20263672, 17.58736038], [83.20207977, 17.58736038], [83.20207977, 17.58707809], [83.20097351, 17.58708382], [83.20097351, 17.58680534], [83.20041656, 17.58680916], [83.20041656, 17.58653069], [83.19985962, 17.58653069], [83.19985962, 17.58625031], [83.19902802, 17.58625031], [83.19902802, 17.58596992], [83.19875336, 17.58597183], [83.19875336, 17.58569527], [83.19790649, 17.58569908], [83.19790649, 17.58542061], [83.19735718, 17.58542061], [83.19735718, 17.58514023], [83.19708252, 17.58514023], [83.19708252, 17.58485985], [83.19680786, 17.58486176], [83.19680786, 17.58458328], [83.19652557, 17.58458328], [83.19652557, 17.58430672], [83.19596863, 17.58430672], [83.19596863, 17.58402634], [83.19513702, 17.58403015], [83.19513702, 17.58374977], [83.19430542, 17.58374977], [83.19430542, 17.5834713], [83.19374847, 17.5834713], [83.19374847, 17.58319664], [83.19264221, 17.58319664], [83.19264221, 17.58291435], [83.1920929, 17.58292007], [83.1920929, 17.58263969], [83.19180298, 17.58263969], [83.19180298, 17.58236122], [83.19097137, 17.58236122], [83.19097137, 17.58208084], [83.19013977, 17.58208275], [83.19013977, 17.58180428], [83.18958282, 17.58181], [83.18958282, 17.58152008], [83.18875122, 17.58152771], [83.18875122, 17.58124924], [83.18818665, 17.58125114], [83.18818665, 17.58097076], [83.18736267, 17.58097267], [83.18736267, 17.58069229], [83.18680573, 17.58069229], [83.18680573, 17.58041763], [83.18624878, 17.58041954], [83.18624878, 17.58014107], [83.18569183, 17.58014107], [83.18569183, 17.57986069], [83.18514252, 17.57986069], [83.18514252, 17.57958031], [83.18430328, 17.57958221], [83.18430328, 17.57930565], [83.18374634, 17.57930946], [83.18374634, 17.5790329], [83.18319702, 17.5790329], [83.18319702, 17.57875061], [83.18264008, 17.57875061], [83.18264008, 17.57847977], [83.18208313, 17.57847977], [83.18208313, 17.57819176], [83.18152618, 17.57819366], [83.18152618, 17.5779171], [83.18096924, 17.57792282], [83.18096924, 17.57764053], [83.18041992, 17.57764053], [83.18041992, 17.57736015], [83.17958069, 17.57736015], [83.17958069, 17.57708359], [83.17903137, 17.57708359], [83.17903137, 17.57680511], [83.1784668, 17.57681274], [83.1784668, 17.57653046], [83.17791748, 17.57653046], [83.17791748, 17.57625008], [83.17736053, 17.57625008], [83.17736053, 17.5759716], [83.17680359, 17.5759716], [83.17680359, 17.57569504], [83.17624664, 17.57570267], [83.17624664, 17.57542038], [83.17569733, 17.57542038], [83.17569733, 17.57513809], [83.17542267, 17.57513809], [83.17542267, 17.57485962], [83.17514038, 17.57486153], [83.17514038, 17.57458305], [83.17430878, 17.57458305], [83.17430878, 17.57430649], [83.17402649, 17.5743084], [83.17402649, 17.57402992], [83.17346954, 17.57402992], [83.17346954, 17.57374954], [83.17292023, 17.57374954], [83.17292023, 17.57347107], [83.17236328, 17.57347298], [83.17236328, 17.5731945], [83.17208099, 17.5731945], [83.17208099, 17.57291794], [83.17180634, 17.57291985], [83.17180634, 17.57263947], [83.17124939, 17.57263947], [83.17124939, 17.57234955], [83.17097473, 17.57236099], [83.17097473, 17.57180786], [83.17069244, 17.57180977], [83.17069244, 17.57152939], [83.17041779, 17.57152939], [83.17041779, 17.57125092], [83.1701355, 17.57125092], [83.1701355, 17.57069588], [83.16986084, 17.57069588], [83.16986084, 17.57013893], [83.16958618, 17.57014084], [83.16958618, 17.56735992], [83.16930389, 17.56736183], [83.16930389, 17.56680489], [83.16902924, 17.56680489], [83.16902924, 17.56624985], [83.16874695, 17.56624985], [83.16874695, 17.56596947], [83.16847229, 17.56597137], [83.16847229, 17.56569481], [83.16819763, 17.56569481], [83.16819763, 17.56541634], [83.16764069, 17.56542015], [83.16764069, 17.56513977], [83.1673584, 17.56513977], [83.1673584, 17.56485939], [83.16708374, 17.5648613], [83.16708374, 17.56458282], [83.16680908, 17.56458282], [83.16680908, 17.56402779], [83.16652679, 17.56402969], [83.16652679, 17.56375122], [83.16596985, 17.56375122], [83.16596985, 17.56348038], [83.16570282, 17.56348038], [83.16570282, 17.56318855], [83.16513824, 17.56319427], [83.16513824, 17.5629158], [83.16485596, 17.56291962], [83.16485596, 17.56263924], [83.16430664, 17.56263924], [83.16430664, 17.56236076], [83.16374969, 17.56236076], [83.16374969, 17.56207848], [83.16347504, 17.5620842], [83.16347504, 17.56180573], [83.16291809, 17.56180954], [83.16291809, 17.56152916], [83.16236115, 17.56152916], [83.16236115, 17.56125069], [83.16152954, 17.56125069], [83.16152954, 17.5609684], [83.1609726, 17.56097221], [83.1609726, 17.56069374], [83.1598587, 17.56069374], [83.1598587, 17.56041718], [83.15930176, 17.56041718], [83.15930176, 17.5601387], [83.1590271, 17.56014061], [83.1590271, 17.55986023], [83.15763855, 17.55986023], [83.15763855, 17.55957985], [83.1570816, 17.55958366], [83.1570816, 17.55930519], [83.15651703, 17.55931091], [83.15651703, 17.55903053], [83.15513611, 17.55903053], [83.15513611, 17.55875015], [83.15429688, 17.55875015], [83.15429688, 17.55846977], [83.15319824, 17.55847168], [83.15319061, 17.55819511], [83.15235901, 17.55820084], [83.15235901, 17.55792046], [83.1506958, 17.55792046], [83.1506958, 17.55764008], [83.14985657, 17.55764008], [83.14985657, 17.55735016], [83.14847565, 17.5573616], [83.14847565, 17.55708313], [83.1479187, 17.55708313], [83.1479187, 17.55680466], [83.1470871, 17.55680466], [83.1470871, 17.55652618], [83.14679718, 17.55653], [83.14679718, 17.55624962], [83.14541626, 17.55624962], [83.14541626, 17.55597115], [83.14485931, 17.55597305], [83.14485931, 17.55569649], [83.14430237, 17.55569649], [83.14430237, 17.55597305], [83.14375305, 17.55597305], [83.14375305, 17.55569649], [83.14263916, 17.55569649], [83.14263916, 17.5554142], [83.14180756, 17.55541992], [83.14180756, 17.55513954], [83.14068604, 17.55513954], [83.14068604, 17.55486107], [83.14013672, 17.55486107], [83.14013672, 17.55458069], [83.13874817, 17.5545826], [83.13874817, 17.55430412], [83.13735962, 17.55430984], [83.13735962, 17.55402946], [83.13652802, 17.55402946], [83.13652802, 17.55375099], [83.13540649, 17.55375099], [83.13540649, 17.55347061], [83.13458252, 17.55347252], [83.13458252, 17.55319214], [83.13375092, 17.55319214], [83.13375092, 17.55291748], [83.13291931, 17.55291939], [83.13291931, 17.55264282], [83.13263702, 17.55264282], [83.13263702, 17.55236053], [83.13236237, 17.55236053], [83.13236237, 17.55208015], [83.13208008, 17.55208015], [83.13208008, 17.55236053], [83.13096619, 17.55236053], [83.13096619, 17.55208015], [83.12958527, 17.55208206], [83.12958527, 17.5518055], [83.12874603, 17.55181122], [83.12874603, 17.55154037], [83.12763977, 17.55154037], [83.12763977, 17.55125046], [83.12652588, 17.55125046], [83.12652588, 17.55097008], [83.12541962, 17.55097008], [83.12541962, 17.55069542], [83.12431335, 17.5506916], [83.12430573, 17.55041695], [83.12346649, 17.55042267], [83.12346649, 17.55014038], [83.12264252, 17.55014038], [83.12264252, 17.54986191], [83.12180328, 17.54986191], [83.12180328, 17.54958344], [83.12124634, 17.54958344], [83.12124634, 17.54930496], [83.1204071, 17.54931259], [83.1204071, 17.5490303], [83.11875153, 17.5490303], [83.11875153, 17.54875183], [83.11763763, 17.54875183], [83.11763763, 17.54846764], [83.11653137, 17.54847145], [83.11653137, 17.54819489], [83.11569214, 17.54819489], [83.11569214, 17.54791641], [83.11485291, 17.54791832], [83.11485291, 17.54763985], [83.11374664, 17.54763985], [83.11374664, 17.54735756], [83.11291504, 17.54736137], [83.11291504, 17.5470829], [83.11208344, 17.5470829], [83.11208344, 17.54680634], [83.11152649, 17.54680824], [83.11152649, 17.54652977], [83.11099243, 17.54652977], [83.11068726, 17.54652977], [83.11068726, 17.54624939], [83.10986328, 17.54624939], [83.10986328, 17.54597092], [83.10930634, 17.54597282], [83.10930634, 17.54569435], [83.10847473, 17.54569435], [83.10847473, 17.54541779], [83.10791779, 17.54541779], [83.10791779, 17.54513931], [83.10708618, 17.54514122], [83.10708618, 17.54486084], [83.10652924, 17.54486084], [83.10652924, 17.54458046], [83.10569763, 17.54458427], [83.10569763, 17.54430771], [83.10514069, 17.54430962], [83.10514069, 17.54403114], [83.10430908, 17.54403114], [83.10430908, 17.54375076], [83.10375214, 17.54375076], [83.10375214, 17.54347038], [83.10319519, 17.54347229], [83.10319519, 17.54319382], [83.10263824, 17.54319382], [83.10263824, 17.54291534], [83.10180664, 17.54292107], [83.10180664, 17.54264069], [83.10124969, 17.54264069], [83.10124969, 17.54236984], [83.10069275, 17.54236984], [83.10069275, 17.54207993], [83.1001358, 17.54208565], [83.1001358, 17.54180336], [83.09929657, 17.54181099], [83.09929657, 17.54153061], [83.09874725, 17.54153061], [83.09874725, 17.54125023], [83.09819794, 17.54125023], [83.09819794, 17.54096985], [83.09764099, 17.54097176], [83.09764099, 17.54069328], [83.0967865, 17.54070091], [83.0967865, 17.54042053], [83.09625244, 17.54042053], [83.09625244, 17.54014015], [83.09570313, 17.54014015], [83.09570313, 17.53985977], [83.09513855, 17.53986168], [83.09513855, 17.53958321], [83.09430695, 17.53958321], [83.09430695, 17.53930473], [83.09152985, 17.53931046], [83.09152985, 17.53903008], [83.09124756, 17.53903008], [83.09124756, 17.53819275], [83.09152985, 17.53819466], [83.09152985, 17.53763962], [83.09124756, 17.53763962], [83.09124756, 17.53736115], [83.0909729, 17.53736115], [83.0909729, 17.53708267], [83.09069824, 17.53708267], [83.09069061, 17.53652763], [83.09059143, 17.53652763], [83.09041595, 17.53652954], [83.09041595, 17.53633118], [83.09041595, 17.53624916], [83.0901413, 17.53624916], [83.0901413, 17.53603935], [83.0901413, 17.53569412], [83.08985901, 17.53569412], [83.08985901, 17.53513908], [83.08957672, 17.53513908], [83.08957672, 17.53486061], [83.08930206, 17.53486061], [83.08930206, 17.53430939], [83.0890274, 17.53430939], [83.0890274, 17.53403091], [83.08875275, 17.53403091], [83.08875275, 17.53375053], [83.08847046, 17.53375053], [83.08847046, 17.53346825], [83.08777618, 17.53347206], [83.08763885, 17.53347206], [83.08763885, 17.53319359], [83.08708191, 17.53319359], [83.08708191, 17.53291893], [83.08625031, 17.53292084], [83.08625031, 17.53264046], [83.0854187, 17.53264046], [83.0854187, 17.53235817], [83.08374786, 17.53236198], [83.08374786, 17.53208351], [83.08291626, 17.53208351], [83.08291626, 17.53180695], [83.08097076, 17.53181076], [83.08097076, 17.53153038], [83.08069611, 17.53153038], [83.08069611, 17.53125], [83.07985687, 17.53125], [83.07985687, 17.53096962], [83.07902527, 17.53097153], [83.07902527, 17.53069687], [83.07736206, 17.53070068], [83.07736206, 17.53042984], [83.07681274, 17.53042984], [83.07681274, 17.53013992], [83.07624817, 17.53013992], [83.07624817, 17.52985954], [83.07485962, 17.52986145], [83.07485962, 17.52958298], [83.07430267, 17.52958298], [83.07430267, 17.5293045], [83.07208252, 17.52931023], [83.07208252, 17.52902985], [83.07180786, 17.52902985], [83.07180786, 17.52874947], [83.07125092, 17.52874947], [83.07125092, 17.52847099], [83.07096863, 17.52847481], [83.07096863, 17.52819633], [83.07069397, 17.52819633], [83.07069397, 17.52791405], [83.06987, 17.52791977], [83.06987, 17.52763939], [83.06958008, 17.52763939], [83.06958008, 17.52737045], [83.06874847, 17.52737045], [83.06874847, 17.52708054], [83.06791687, 17.52708244], [83.06791687, 17.52680588], [83.06735992, 17.52680969], [83.06735992, 17.52653122], [83.0670929, 17.52653122], [83.0670929, 17.52625084], [83.06680298, 17.52625084], [83.06680298, 17.52486038], [83.06652832, 17.52486038], [83.06652832, 17.52458191], [83.06597137, 17.52458191], [83.06597137, 17.52486038], [83.06569672, 17.52486038], [83.06569672, 17.52514076], [83.0654068, 17.52514076], [83.0654068, 17.52542114], [83.06513977, 17.52541733], [83.06513977, 17.52569389], [83.06430817, 17.52569389], [83.06430817, 17.52541733], [83.06346893, 17.52542114], [83.06346893, 17.52514076], [83.06208038, 17.52514076], [83.06208038, 17.52486038], [83.05930328, 17.52486038], [83.05930328, 17.52458191], [83.05902863, 17.52458382], [83.05902863, 17.52430534], [83.05847168, 17.52430534], [83.05847168, 17.52402687], [83.0579071, 17.52403259], [83.0579071, 17.52347183], [83.05764008, 17.52347183], [83.05764008, 17.52319527], [83.05680847, 17.5232029], [83.05680847, 17.52264023], [83.05652618, 17.52264023], [83.05652618, 17.52236176], [83.05625153, 17.52236176], [83.05625153, 17.52208328], [83.05569458, 17.52208328], [83.05569458, 17.52180481], [83.05486298, 17.52180481], [83.05486298, 17.52152824], [83.05403137, 17.52152824], [83.05403137, 17.52124023], [83.05319214, 17.52124977], [83.05319214, 17.5209713], [83.05263519, 17.5209713], [83.05263519, 17.52069473], [83.05180359, 17.52069473], [83.05180359, 17.52041626], [83.05124664, 17.52041817], [83.05124664, 17.52013969], [83.05041504, 17.52013969], [83.05041504, 17.51986122], [83.04957581, 17.51986122], [83.04957581, 17.51958084], [83.04902649, 17.51958275], [83.04902649, 17.51930618], [83.04818726, 17.51930809], [83.04818726, 17.51902962], [83.04736328, 17.51902962], [83.04736328, 17.51875114], [83.04680634, 17.51875114], [83.04680634, 17.51847076], [83.04597473, 17.51847267], [83.04597473, 17.5181942], [83.04514313, 17.51819992], [83.04514313, 17.51791954], [83.04458618, 17.51791954], [83.04458618, 17.51764107], [83.04374695, 17.51764107], [83.04374695, 17.51736069], [83.04291534, 17.51736069], [83.04291534, 17.51708412], [83.0423584, 17.51708412], [83.0423584, 17.51680756], [83.04152679, 17.51680946], [83.04152679, 17.51653099], [83.04096985, 17.51653099], [83.04096985, 17.51625061], [83.04069519, 17.51625061], [83.04069519, 17.51597214], [83.03930664, 17.51597214], [83.03930664, 17.51569366], [83.03874969, 17.51569366], [83.03874969, 17.51541519], [83.03791809, 17.51543045], [83.03791809, 17.51514053], [83.03736115, 17.51514053], [83.03736115, 17.51486015], [83.0368042, 17.51486206], [83.0368042, 17.51458549], [83.0359726, 17.51458549], [83.0359726, 17.51430321], [83.03514099, 17.51431084], [83.03514099, 17.51403046], [83.03430176, 17.51403046], [83.03430176, 17.51375008], [83.03347015, 17.51375008], [83.03347015, 17.5134697], [83.03291321, 17.5134716], [83.03291321, 17.51319313], [83.03263855, 17.51320076], [83.03263855, 17.51292038], [83.0320816, 17.51292038], [83.0320816, 17.51264], [83.03125, 17.51264], [83.03125, 17.51235962], [83.03069305, 17.51236153], [83.03069305, 17.51208115], [83.03013611, 17.51208115], [83.03013611, 17.51180649], [83.02958679, 17.5118103], [83.02958679, 17.51152992], [83.02902985, 17.51152992], [83.02902985, 17.51124954], [83.0284729, 17.51124954], [83.0284729, 17.51097107], [83.02819824, 17.51097107], [83.02819061, 17.5106945], [83.0276413, 17.5106945], [83.0276413, 17.51041603], [83.02707672, 17.51042175], [83.02707672, 17.51013947], [83.0265274, 17.51013947], [83.0265274, 17.50985909], [83.02597046, 17.50985909], [83.02597046, 17.50958061], [83.02541351, 17.50958252], [83.02541351, 17.50930595], [83.0248642, 17.50930595], [83.0248642, 17.50902748], [83.02430725, 17.50902939], [83.02430725, 17.50875092], [83.02375031, 17.50875092], [83.02375031, 17.50847054], [83.02319336, 17.50847244], [83.02319336, 17.50819397], [83.02263641, 17.50819397], [83.02263641, 17.5079174], [83.0220871, 17.50791931], [83.0220871, 17.50764084], [83.02153015, 17.50764084], [83.02153015, 17.50736046], [83.02097321, 17.50736046], [83.02097321, 17.50707817], [83.02041626, 17.50708389], [83.02041626, 17.50680542], [83.01985931, 17.50680923], [83.01985931, 17.50653076], [83.01930237, 17.50653076], [83.01930237, 17.50625992], [83.01876068, 17.50625992], [83.01876068, 17.50596809], [83.01819611, 17.50597191], [83.01819611, 17.50569534], [83.01790619, 17.50569916], [83.01790619, 17.50542068], [83.01735687, 17.50542068], [83.01735687, 17.5051403], [83.01680756, 17.5051403], [83.01680756, 17.50485992], [83.01625061, 17.50486183], [83.01625061, 17.50458336], [83.01569366, 17.50458336], [83.01569366, 17.50430679], [83.01513672, 17.50430679], [83.01513672, 17.50402832], [83.01457977, 17.50403023], [83.01457977, 17.50374985], [83.01403046, 17.50374985], [83.01403046, 17.50346947], [83.01347351, 17.50347137], [83.01347351, 17.50319672], [83.01291656, 17.50320053], [83.01291656, 17.50292015], [83.01262665, 17.50292015], [83.01262665, 17.50263977], [83.01207733, 17.50263977], [83.01207733, 17.50235939], [83.01180267, 17.5023613], [83.01180267, 17.50208282], [83.01152802, 17.50208282], [83.01152802, 17.50180435], [83.01125336, 17.50181007], [83.01125336, 17.50152969], [83.01069641, 17.50152969], [83.01069641, 17.50125122], [83.01040649, 17.50125122], [83.01040649, 17.50097084], [83.01013947, 17.50097466], [83.01013947, 17.50069237], [83.00986481, 17.50069237], [83.00986481, 17.5004158], [83.00930786, 17.50041962], [83.00930786, 17.50014114], [83.0090332, 17.50014114], [83.0090332, 17.49986076], [83.00875092, 17.49986076], [83.00875092, 17.49958038], [83.00819397, 17.49958229], [83.00819397, 17.49930573], [83.00791931, 17.49930954], [83.00791931, 17.49903107], [83.00763702, 17.49903107], [83.00763702, 17.49875069], [83.00736237, 17.49875069], [83.00736237, 17.49847031], [83.00708008, 17.49847221], [83.00708008, 17.49819374], [83.00680542, 17.49819374], [83.00680542, 17.4976387], [83.00653076, 17.49764061], [83.00653076, 17.49736023], [83.00624847, 17.49736023], [83.00624847, 17.49706841], [83.00597382, 17.49708366], [83.00597382, 17.49652863], [83.00569153, 17.49653053], [83.00569153, 17.49625015], [83.00541687, 17.49625015], [83.00541687, 17.49597168], [83.00514221, 17.49597168], [83.00514221, 17.49569511], [83.00485992, 17.49570274], [83.00485992, 17.4948597], [83.00458527, 17.4948616], [83.00458527, 17.49402809], [83.00430298, 17.49402809], [83.00430298, 17.49347115], [83.00402832, 17.49347305], [83.00402832, 17.49263954], [83.00374603, 17.49263954], [83.00374603, 17.49014091], [83.00402832, 17.49014091], [83.00402832, 17.48958015], [83.00430298, 17.48958588], [83.00430298, 17.4893074], [83.00444031, 17.4893074], [83.0045929, 17.48931122], [83.0045929, 17.48903084], [83.00485992, 17.48903084], [83.00485992, 17.48875046], [83.00514221, 17.48875046], [83.00514221, 17.48847008], [83.00541687, 17.48847198], [83.00541687, 17.48791695], [83.00514221, 17.48792076], [83.00514221, 17.48764038], [83.0045929, 17.48764038], [83.0045929, 17.48736], [83.00402832, 17.48736382], [83.00402832, 17.48708344], [83.00347137, 17.48708344], [83.00347137, 17.48680305], [83.0029068, 17.48681068], [83.0029068, 17.4865303], [83.00263977, 17.4865303], [83.00263977, 17.48624992], [83.00235748, 17.48624992], [83.00235748, 17.48596954], [83.00208282, 17.48597145], [83.00208282, 17.48569489], [83.00180817, 17.48569489], [83.00180817, 17.48541641], [83.00152588, 17.48542023], [83.00152588, 17.48513031], [83.00125122, 17.48513794], [83.00125122, 17.48486137], [83.00069427, 17.48486137], [83.00069427, 17.4845829], [83.00041962, 17.4845829], [83.00041962, 17.48430634], [83.00013733, 17.48431015], [83.00013733, 17.48402977], [82.99986267, 17.48402977], [82.99986267, 17.48374939], [82.99958038, 17.48374939], [82.99958038, 17.48347282], [82.99930573, 17.48347282], [82.99930573, 17.48319435], [82.99903107, 17.48319435], [82.99903107, 17.48291588], [82.99874878, 17.48291969], [82.99874878, 17.48263931], [82.99846649, 17.48263931], [82.99846649, 17.48236084], [82.99791718, 17.48236084], [82.99791718, 17.48207092], [82.99736023, 17.48208427], [82.99736023, 17.4818058], [82.9970932, 17.48181152], [82.9970932, 17.48152924], [82.99682617, 17.48152924], [82.99652863, 17.48152924], [82.99652863, 17.48125076], [82.99597168, 17.48125076], [82.99597168, 17.48097038], [82.99569702, 17.48097229], [82.99569702, 17.48069382], [82.99514008, 17.48069382], [82.99514008, 17.48041725], [82.99485779, 17.48041916], [82.99485779, 17.48014069], [82.99459076, 17.48014069], [82.99459076, 17.47986031], [82.99402618, 17.47986031], [82.99402618, 17.47957993], [82.99375153, 17.47958374], [82.99375153, 17.47736168], [82.99402618, 17.47736168], [82.99402618, 17.47708321], [82.99458313, 17.47708321], [82.99458313, 17.47680664], [82.99485779, 17.47680664], [82.99485779, 17.47652626], [82.99514008, 17.47653008], [82.99514008, 17.47597122], [82.99541473, 17.47597313], [82.99541473, 17.47541428], [82.99514008, 17.47542], [82.99514008, 17.47486115], [82.99485779, 17.47486115], [82.99485779, 17.47458076], [82.99430847, 17.47458267], [82.99430847, 17.4743042], [82.99375153, 17.47430992], [82.99375153, 17.47402954], [82.99291992, 17.47402954], [82.99291992, 17.47375107], [82.99263763, 17.47375107], [82.99263763, 17.47347069], [82.99153137, 17.4734726], [82.99153137, 17.47319221], [82.99124908, 17.47319221], [82.99124908, 17.47291756], [82.9909668, 17.47291946], [82.9909668, 17.4726429], [82.99069214, 17.4726429], [82.99069214, 17.47236061], [82.99013519, 17.47236061], [82.99013519, 17.47208214], [82.98930359, 17.47208214], [82.98930359, 17.47180557], [82.98874664, 17.47180939], [82.98874664, 17.47153282], [82.98819733, 17.47153282], [82.98819733, 17.47125053], [82.98764038, 17.47125053], [82.98764038, 17.47097015], [82.98708344, 17.47097015], [82.98708344, 17.47069359], [82.98652649, 17.47069359], [82.98652649, 17.47041702], [82.98568726, 17.47042274], [82.98568726, 17.47013092], [82.98513794, 17.47013855], [82.98513794, 17.46986008], [82.98430634, 17.46986008], [82.98430634, 17.46958351], [82.98347473, 17.46958351], [82.98347473, 17.46930504], [82.98291779, 17.46931267], [82.98291779, 17.46903038], [82.98208618, 17.46903038], [82.98208618, 17.46875191], [82.98124695, 17.46875191], [82.98124695, 17.46847153], [82.98041534, 17.46847153], [82.98041534, 17.46819496], [82.9798584, 17.46820259], [82.9798584, 17.4679184], [82.97902679, 17.4679184], [82.97902679, 17.46763992], [82.97820282, 17.46763992], [82.97820282, 17.46735954], [82.97763824, 17.46736145], [82.97763824, 17.46708298], [82.97680664, 17.46709061], [82.97680664, 17.46680832], [82.97598267, 17.46680832], [82.97598267, 17.46652985], [82.97541809, 17.46652985], [82.97541809, 17.46624947], [82.97458649, 17.46624947], [82.97458649, 17.46597099], [82.97374725, 17.4659729], [82.97374725, 17.46569443], [82.97291565, 17.46569443], [82.97291565, 17.46541786], [82.9723587, 17.46541977], [82.9723587, 17.46513939], [82.9715271, 17.46513939], [82.9715271, 17.46486092], [82.9706955, 17.46486092], [82.9706955, 17.46458244], [82.9695816, 17.46458244], [82.9695816, 17.46430779], [82.96875, 17.46431923], [82.96875, 17.46403122], [82.96763611, 17.46403122], [82.96763611, 17.46375084], [82.96679688, 17.46375084], [82.96679688, 17.46347046], [82.96569824, 17.46347237], [82.96569061, 17.4631958], [82.96485901, 17.4631958], [82.96485901, 17.46291733], [82.96375275, 17.46292114], [82.96375275, 17.46264076], [82.96290588, 17.46264076], [82.96290588, 17.46236038], [82.96151733, 17.46236038], [82.96151733, 17.46208], [82.96125031, 17.46208572], [82.96125031, 17.46180344], [82.96069336, 17.46181107], [82.96069336, 17.46153069], [82.9604187, 17.46153069], [82.9604187, 17.46125031], [82.96013641, 17.46125031], [82.96013641, 17.46096039], [82.95903015, 17.46097183], [82.95903015, 17.46069336], [82.95791626, 17.46070099], [82.95791626, 17.46042061], [82.95597076, 17.46042061], [82.95597076, 17.46014023], [82.95513916, 17.46014023], [82.95513916, 17.45985985], [82.95402527, 17.45986176], [82.95402527, 17.45958328], [82.95347595, 17.45958328], [82.95347595, 17.45930481], [82.95291901, 17.45930481], [82.95291901, 17.45902824], [82.95263672, 17.45903015], [82.95263672, 17.45874977], [82.9523468, 17.45874977], [82.9523468, 17.45846939], [82.95097351, 17.4584713], [82.95097351, 17.45819473], [82.95069122, 17.45819473], [82.95069122, 17.45791626], [82.95041656, 17.45792007], [82.95041656, 17.45763969], [82.95014191, 17.45763969], [82.95014191, 17.45708275], [82.94985962, 17.45708275], [82.94985962, 17.45597267], [82.95014191, 17.45597267], [82.95014191, 17.45486069], [82.94985962, 17.45486069], [82.94985962, 17.4545784], [82.94958496, 17.45458412], [82.94958496, 17.45430565], [82.94902802, 17.45430946], [82.94902802, 17.45402908], [82.94875336, 17.45402908], [82.94875336, 17.45375061], [82.94847107, 17.45375061], [82.94847107, 17.45318985], [82.94819641, 17.45319366], [82.94819641, 17.4529171], [82.94790649, 17.45292091], [82.94790649, 17.45264053], [82.94763947, 17.45264053], [82.94763947, 17.45236015], [82.94708252, 17.45236206], [82.94708252, 17.45208359], [82.94654083, 17.45209122], [82.94654083, 17.45181084], [82.94596863, 17.45181084], [82.94596863, 17.45153046], [82.94541931, 17.45153046], [82.94541931, 17.45125008], [82.94291687, 17.45125008], [82.94291687, 17.45153046], [82.9420929, 17.45153046], [82.9420929, 17.45125008], [82.94152832, 17.45125008], [82.94152832, 17.4509697], [82.94097137, 17.4509716], [82.94097137, 17.45069695], [82.94069672, 17.45070076], [82.94069672, 17.45042038], [82.93985748, 17.45042038], [82.93985748, 17.45014], [82.93902588, 17.45014], [82.93902588, 17.44985962], [82.93846893, 17.44986153], [82.93846893, 17.44958305], [82.93791962, 17.44958305], [82.93791962, 17.44930649], [82.93734741, 17.4493103], [82.93734741, 17.44902039], [82.93680573, 17.44902611], [82.93680573, 17.44874954], [82.93624878, 17.44874954], [82.93624878, 17.44847107], [82.93569183, 17.44847488], [82.93569183, 17.44819641], [82.93514252, 17.44819641], [82.93514252, 17.44791412], [82.93431091, 17.44791985], [82.93431091, 17.44763947], [82.93374634, 17.44763947], [82.93374634, 17.44736099], [82.93319702, 17.44736099], [82.93319702, 17.44708061], [82.93264008, 17.44708252], [82.93264008, 17.44680405], [82.93208313, 17.44680977], [82.93208313, 17.44652939], [82.93154144, 17.44652939], [82.93154144, 17.44625092], [82.93096924, 17.44625092], [82.93096924, 17.44596291], [82.93041992, 17.44597244], [82.93041992, 17.44569206], [82.92986298, 17.44569206], [82.92986298, 17.4454174], [82.92958069, 17.44542122], [82.92958069, 17.44514275], [82.92903137, 17.44514275], [82.92903137, 17.44486046], [82.9284668, 17.44486046], [82.9284668, 17.44458008], [82.92791748, 17.44458389], [82.92791748, 17.44430542], [82.92736053, 17.44431114], [82.92736053, 17.44403267], [82.92679596, 17.44403267], [82.92679596, 17.44375038], [82.92624664, 17.44375038], [82.92624664, 17.44347191], [82.92541504, 17.44347191], [82.92541504, 17.44319534], [82.92402649, 17.4432106], [82.92402649, 17.44292259], [82.92318726, 17.44292259], [82.92318726, 17.4426403], [82.92208099, 17.4426403], [82.92208099, 17.44236183], [82.92180634, 17.44236183], [82.92180634, 17.44208336], [82.92069244, 17.44208336], [82.92069244, 17.44180489], [82.9201355, 17.44180489], [82.9201355, 17.44152832], [82.91931152, 17.44152832], [82.91931152, 17.44124985], [82.91847229, 17.44124985], [82.91847229, 17.44096756], [82.91764069, 17.44097137], [82.91764069, 17.44069481], [82.91708374, 17.44069481], [82.91708374, 17.44041634], [82.91623688, 17.44041824], [82.91623688, 17.44014931], [82.91570282, 17.44014931], [82.91570282, 17.43985748], [82.91486359, 17.4398613], [82.91486359, 17.43958282], [82.91430664, 17.43958282], [82.91430664, 17.43930626], [82.91346741, 17.43930817], [82.91346741, 17.43902969], [82.91291809, 17.43902969], [82.91291809, 17.43875122], [82.91208649, 17.43875122], [82.91208649, 17.43847084], [82.91152954, 17.43847275], [82.91152954, 17.43819427], [82.91069794, 17.43819427], [82.91069794, 17.43791771], [82.91014099, 17.43791962], [82.91014099, 17.43764114], [82.90930176, 17.43764114], [82.90930176, 17.43736076], [82.90847015, 17.43736076], [82.90847015, 17.43708038], [82.90791321, 17.4370842], [82.90791321, 17.43680763], [82.9070816, 17.43680954], [82.9070816, 17.43653107], [82.90680695, 17.43653107], [82.90680695, 17.43625069], [82.90625, 17.43625069], [82.90625, 17.43597031], [82.90569305, 17.43597221], [82.90569305, 17.43569565], [82.90513611, 17.43569565], [82.90513611, 17.43541527], [82.90429688, 17.43542099], [82.90429688, 17.43514061], [82.90374756, 17.43514061], [82.90374756, 17.43486023], [82.9034729, 17.43486023], [82.9034729, 17.43457985], [82.90291595, 17.43458557], [82.90291595, 17.43430328], [82.90235901, 17.43431091], [82.90235901, 17.4340229], [82.90180206, 17.43402863], [82.90180206, 17.43375015], [82.90123749, 17.43375015], [82.90123749, 17.43346977], [82.9006958, 17.43347168], [82.9006958, 17.43319321], [82.89985657, 17.43320084], [82.89985657, 17.43292046], [82.89930725, 17.43292046], [82.89930725, 17.43264008], [82.89875031, 17.43264008], [82.89875031, 17.4323597], [82.8979187, 17.4323616], [82.8979187, 17.43208122], [82.89736176, 17.43208122], [82.89736176, 17.43180466], [82.89680481, 17.43180466], [82.89680481, 17.43152809], [82.89597321, 17.43153191], [82.89597321, 17.43124962], [82.89541626, 17.43124962], [82.89541626, 17.43097115], [82.89485931, 17.43098068], [82.89485931, 17.43069267], [82.89402771, 17.43069458], [82.89402771, 17.43041611], [82.89347076, 17.43042183], [82.89347076, 17.43013954], [82.89290619, 17.43013954], [82.89290619, 17.42986107], [82.89208221, 17.42986107], [82.89208221, 17.42958069], [82.89152527, 17.4295826], [82.89152527, 17.42930603], [82.89068604, 17.42931175], [82.89068604, 17.42902946], [82.89013672, 17.42902946], [82.89013672, 17.42874908], [82.88929749, 17.42874908], [82.88929749, 17.42847061], [82.88874817, 17.42847252], [82.88874817, 17.42819405], [82.88791656, 17.42819405], [82.88791656, 17.42791748], [82.88735962, 17.42791939], [82.88735962, 17.42764091], [82.88652802, 17.42764091], [82.88652802, 17.42736053], [82.88569641, 17.42736053], [82.88569641, 17.42707825], [82.88486481, 17.42708397], [82.88486481, 17.4268055], [82.88458252, 17.42680931], [82.88458252, 17.42653084], [82.8840332, 17.42653084], [82.8840332, 17.42625046], [82.88346863, 17.42625046], [82.88346863, 17.42596817], [82.88319397, 17.42597198], [82.88319397, 17.42569542], [82.88291931, 17.4256897], [82.88291931, 17.42541885], [82.88236237, 17.42542076], [82.88236237, 17.42514038], [82.88208008, 17.42514038], [82.88208008, 17.42457962], [82.88180542, 17.42458344], [82.88180542, 17.42430687], [82.88153076, 17.42431068], [82.88153076, 17.42374992], [82.88124847, 17.42374992], [82.88124847, 17.42346954], [82.88097382, 17.42347145], [82.88097382, 17.42319679], [82.88069153, 17.42319679], [82.88069153, 17.42291451], [82.88041687, 17.42292023], [82.88041687, 17.42263985], [82.88014221, 17.42263985], [82.88014221, 17.42235947], [82.87985992, 17.42236137], [82.87985992, 17.42208481], [82.87958527, 17.42208481], [82.87958527, 17.42152786], [82.87930298, 17.42152977], [82.87930298, 17.42124939], [82.87902832, 17.42124939], [82.87902832, 17.42097092], [82.87875366, 17.42097473], [82.87875366, 17.42069244], [82.87847137, 17.42069244], [82.87847137, 17.42041588], [82.8779068, 17.42041969], [82.8779068, 17.42014122], [82.87486267, 17.42014122], [82.87486267, 17.42041969], [82.87430573, 17.42041588], [82.87430573, 17.42069244], [82.87374878, 17.42069244], [82.87374878, 17.42097473], [82.87346649, 17.42097092], [82.87346649, 17.42152977], [82.87319183, 17.42152786], [82.87319183, 17.42208481], [82.87291718, 17.42208099], [82.87291718, 17.42292023], [82.87264252, 17.42291451], [82.87264252, 17.42347145], [82.87291718, 17.42347145], [82.87291718, 17.42486191], [82.87319183, 17.42486191], [82.87319183, 17.42569351], [82.87346649, 17.4256897], [82.87346649, 17.42736053], [82.87319183, 17.42736053], [82.87319183, 17.42847252], [82.87346649, 17.42847061], [82.87346649, 17.42902946], [82.87374878, 17.42902946], [82.87374878, 17.42931175], [82.87403107, 17.42930603], [82.87403107, 17.4295826], [82.87430573, 17.4295826], [82.87430573, 17.42986107], [82.87486267, 17.42986107], [82.87486267, 17.43013954], [82.87513733, 17.43013954], [82.87513733, 17.43042183], [82.87596893, 17.43041611], [82.87596893, 17.43069458], [82.87625122, 17.43069267], [82.87625122, 17.43098068], [82.87680817, 17.43098068], [82.87680817, 17.43124962], [82.87735748, 17.43124962], [82.87735748, 17.43153191], [82.87763977, 17.43152809], [82.87763977, 17.43208122], [82.87791443, 17.43208122], [82.87791443, 17.4323616], [82.87819672, 17.4323597], [82.87819672, 17.43292046], [82.87847137, 17.43292046], [82.87847137, 17.43320084], [82.87875366, 17.43319321], [82.87875366, 17.43347168], [82.87902832, 17.43346977], [82.87902832, 17.43375015], [82.87930298, 17.43375015], [82.87930298, 17.43431091], [82.87958527, 17.43430328], [82.87958527, 17.43458557], [82.87985992, 17.43457985], [82.87985992, 17.43486023], [82.88014221, 17.43486023], [82.88014221, 17.43542099], [82.88041687, 17.43542099], [82.88041687, 17.43625069], [82.87958527, 17.43625069], [82.87958527, 17.43597221], [82.87930298, 17.43597221], [82.87930298, 17.4351387], [82.87902832, 17.43514061], [82.87902832, 17.43486023], [82.87874603, 17.43486023], [82.87874603, 17.43457985], [82.87847137, 17.43458557], [82.87847137, 17.43430328], [82.87819672, 17.43431091], [82.87819672, 17.4340229], [82.87791443, 17.43402863], [82.87791443, 17.43375015], [82.87763977, 17.43375015], [82.87763977, 17.43346977], [82.87708282, 17.43347168], [82.87708282, 17.43319321], [82.87652588, 17.43320084], [82.87652588, 17.43292046], [82.87625122, 17.43292046], [82.87625122, 17.43264008], [82.87568665, 17.43264008], [82.87568665, 17.4323597], [82.87541962, 17.4323616], [82.87541962, 17.43208122], [82.87374878, 17.43208122], [82.87374878, 17.43180466], [82.87347412, 17.43180466], [82.87347412, 17.43152809], [82.87319183, 17.43153191], [82.87319183, 17.43124962], [82.87291718, 17.43124962], [82.87291718, 17.43069267], [82.87264252, 17.43069458], [82.87264252, 17.43041611], [82.87236023, 17.43042183], [82.87236023, 17.42986107], [82.87208557, 17.42986107], [82.87208557, 17.42930603], [82.87180328, 17.42931175], [82.87180328, 17.42847061], [82.87152863, 17.42847252], [82.87152863, 17.42597198], [82.87124634, 17.42597198], [82.87124634, 17.42541885], [82.87069702, 17.42542076], [82.87069702, 17.42514038], [82.8704071, 17.42514038], [82.8704071, 17.42485046], [82.87014008, 17.42486191], [82.87014008, 17.42347145], [82.86985779, 17.42347145], [82.86985779, 17.42291451], [82.86958313, 17.42292023], [82.86958313, 17.42263985], [82.86902618, 17.42263985], [82.86902618, 17.42235947], [82.86875153, 17.42236137], [82.86875153, 17.42180443], [82.86820221, 17.42181015], [82.86820221, 17.42069054], [82.86791992, 17.42069244], [82.86791992, 17.41902733], [82.86820221, 17.41904068], [82.86820221, 17.41875076], [82.86846924, 17.41875076], [82.86846924, 17.41847038], [82.86902618, 17.41847229], [82.86902618, 17.41819382], [82.87014008, 17.41819382], [82.87014008, 17.41791725], [82.87069702, 17.41792107], [82.87069702, 17.41764069], [82.87097168, 17.41764069], [82.87097168, 17.41736031], [82.8712616, 17.41736031], [82.87124634, 17.4165287], [82.87069702, 17.41653252], [82.87069702, 17.41625023], [82.87014008, 17.41625023], [82.87014008, 17.41597939], [82.86985779, 17.41597939], [82.86985779, 17.41570282], [82.86930847, 17.41570282], [82.86930847, 17.41542244], [82.86791992, 17.41542244], [82.86791992, 17.41514015], [82.86708069, 17.41514015], [82.86708069, 17.41485977], [82.86653137, 17.41486168], [82.86653137, 17.41458321], [82.86569214, 17.41458321], [82.86569214, 17.41430473], [82.86486053, 17.41430473], [82.86486053, 17.41402817], [82.86429596, 17.41402817], [82.86429596, 17.41374969], [82.86291504, 17.41374969], [82.86291504, 17.41347313], [82.86125183, 17.41347313], [82.86125183, 17.41319466], [82.85958099, 17.41319466], [82.85958099, 17.41291618], [82.85874939, 17.41291618], [82.85874939, 17.41263962], [82.85791779, 17.41263962], [82.85791779, 17.41236115], [82.85708618, 17.41236115], [82.85708618, 17.41208076], [82.85652924, 17.41208267], [82.85652924, 17.41180611], [82.85569763, 17.41180992], [82.85569763, 17.41152954], [82.8548584, 17.41152954], [82.8548584, 17.41125107], [82.85402679, 17.41125107], [82.85402679, 17.41097069], [82.85319519, 17.4109726], [82.85319519, 17.41069412], [82.85236359, 17.41069412], [82.85236359, 17.41041756], [82.85180664, 17.41041946], [82.85180664, 17.41014099], [82.85098267, 17.41014099], [82.85098267, 17.40985107], [82.8501358, 17.40986061], [82.8501358, 17.40958595], [82.8493042, 17.40958595], [82.8493042, 17.40930748], [82.8484726, 17.40930939], [82.8484726, 17.40903091], [82.84764099, 17.40903091], [82.84764099, 17.40875053], [82.84708405, 17.40875053], [82.84708405, 17.40847206], [82.84625244, 17.40847206], [82.84625244, 17.40819359], [82.84541321, 17.40819359], [82.84541321, 17.40791512], [82.8445816, 17.40792084], [82.8445816, 17.40764046], [82.84430695, 17.40764046], [82.84430695, 17.40736008], [82.84347534, 17.40736389], [82.84347534, 17.40708542], [82.84263611, 17.40708542], [82.84263611, 17.40680313], [82.84152985, 17.40681076], [82.84152985, 17.40653038], [82.84069824, 17.40653038], [82.84069061, 17.40625], [82.83957672, 17.40625], [82.83957672, 17.40596962], [82.8390274, 17.40597153], [82.8390274, 17.40569305], [82.83818817, 17.40570068], [82.83818817, 17.4054203], [82.83763885, 17.4054203], [82.83763885, 17.40513992], [82.83708191, 17.40513992], [82.83708191, 17.40485954], [82.83625031, 17.40486145], [82.83625031, 17.40458107], [82.83569336, 17.40458107], [82.83569336, 17.40430641], [82.83515167, 17.40431023], [82.83515167, 17.40403938], [82.8345871, 17.40403938], [82.8345871, 17.40374947], [82.83374786, 17.40374947], [82.83374786, 17.4034729], [82.83319092, 17.4034729], [82.83319092, 17.40319443], [82.8326416, 17.40319443], [82.8326416, 17.40291595], [82.83180237, 17.40292168], [82.83180237, 17.40263939], [82.83125305, 17.40263939], [82.83125305, 17.40236092], [82.83069611, 17.40236092], [82.83069611, 17.40208054], [82.8298645, 17.40208244], [82.8298645, 17.40180588], [82.82930756, 17.4018116], [82.82930756, 17.40152931], [82.82875061, 17.40152931], [82.82875061, 17.40125084], [82.82791901, 17.40125084], [82.82791901, 17.40097046], [82.82736206, 17.40097237], [82.82736206, 17.40069389], [82.82680511, 17.40069389], [82.82680511, 17.40041733], [82.82595825, 17.40041924], [82.82595825, 17.40014076], [82.82541656, 17.40014076], [82.82541656, 17.39986038], [82.82485962, 17.39986038], [82.82485962, 17.39957809], [82.82430267, 17.39958382], [82.82430267, 17.39930534], [82.82347107, 17.39930916], [82.82347107, 17.39903069], [82.82292175, 17.39903069], [82.82292175, 17.39875031], [82.82235718, 17.39875031], [82.82235718, 17.39846992], [82.82152557, 17.39847183], [82.82152557, 17.39819527], [82.82096863, 17.39819908], [82.82096863, 17.39791107], [82.82041931, 17.3979187], [82.82041931, 17.39763641], [82.81986237, 17.39764023], [82.81986237, 17.39735985], [82.81958008, 17.39736176], [82.81958008, 17.39708328], [82.81874847, 17.39708328], [82.81874847, 17.39680672], [82.81819153, 17.39680672], [82.81819153, 17.39652824], [82.81791687, 17.39653015], [82.81791687, 17.39624977], [82.81735992, 17.39624977], [82.81735992, 17.39596939], [82.81680298, 17.3959713], [82.81680298, 17.39569664], [82.81625366, 17.39569664], [82.81625366, 17.39541435], [82.81569672, 17.39542007], [82.81569672, 17.39513969], [82.81485748, 17.39513969], [82.81485748, 17.39484978], [82.81430817, 17.39486122], [82.81430817, 17.39458275], [82.81375122, 17.39458275], [82.81375122, 17.39430428], [82.81318665, 17.39431], [82.81318665, 17.39402962], [82.81236267, 17.39402962], [82.81236267, 17.39375114], [82.81181335, 17.39375114], [82.81181335, 17.39347076], [82.81124878, 17.39347458], [82.81124878, 17.39319229], [82.81069183, 17.39319229], [82.81069183, 17.39291763], [82.81014252, 17.39291954], [82.81014252, 17.39264107], [82.80930328, 17.39264107], [82.80930328, 17.39236069], [82.80874634, 17.39236069], [82.80874634, 17.39208031], [82.80819702, 17.39208221], [82.80819702, 17.39180565], [82.80764008, 17.39180946], [82.80764008, 17.3915329], [82.80708313, 17.3915329], [82.80708313, 17.39125061], [82.80625153, 17.39125061], [82.80625153, 17.39097023], [82.80569458, 17.39097023], [82.80569458, 17.39069366], [82.80513763, 17.39069366], [82.80513763, 17.3904171], [82.80458069, 17.39042282], [82.80458069, 17.39014053], [82.80374908, 17.39014053], [82.80374908, 17.38986015], [82.80319214, 17.38986015], [82.80319214, 17.38958359], [82.80263519, 17.38958359], [82.80263519, 17.38930511], [82.80207825, 17.38931274], [82.80207825, 17.38903046], [82.80152893, 17.38903046], [82.80152893, 17.38875008], [82.80069733, 17.38875008], [82.80069733, 17.3884716], [82.80014038, 17.3884716], [82.80014038, 17.38819504], [82.79957581, 17.38820267], [82.79957581, 17.38791847], [82.79904175, 17.38791847], [82.79904175, 17.38763809], [82.79818726, 17.38763809], [82.79818726, 17.38735962], [82.79763794, 17.38736153], [82.79763794, 17.38708305], [82.79708099, 17.38708305], [82.79708099, 17.38680649], [82.79651642, 17.3868084], [82.79651642, 17.38652992], [82.79569244, 17.38652992], [82.79569244, 17.38624954], [82.7951355, 17.38624954], [82.7951355, 17.38597298], [82.79458618, 17.38597298], [82.79458618, 17.3856945], [82.79374695, 17.3856945], [82.79374695, 17.38541794], [82.79319763, 17.38541985], [82.79319763, 17.38513947], [82.79264069, 17.38513947], [82.79264069, 17.38486099], [82.79180908, 17.38486099], [82.79180908, 17.38458061], [82.79125214, 17.38458252], [82.79125214, 17.38430786], [82.79070282, 17.38430977], [82.79070282, 17.38402939], [82.78984833, 17.38402939], [82.78984833, 17.38375092], [82.78930664, 17.38375092], [82.78930664, 17.38347054], [82.78874969, 17.38347244], [82.78874969, 17.38319588], [82.78819275, 17.38319588], [82.78819275, 17.3829174], [82.78736115, 17.3829174], [82.78736115, 17.38263893], [82.78678894, 17.38264084], [82.78678894, 17.38236046], [82.78624725, 17.38236046], [82.78624725, 17.38208008], [82.78541565, 17.3820858], [82.78541565, 17.38180351], [82.7848587, 17.38181114], [82.7848587, 17.38153076], [82.78430176, 17.38153076], [82.78430176, 17.38125038], [82.78347015, 17.38125038], [82.78347015, 17.38097], [82.78291321, 17.38097191], [82.78291321, 17.38069344], [82.78235626, 17.38070107], [82.78235626, 17.38042068], [82.78151703, 17.38042068], [82.78151703, 17.3801403], [82.78096771, 17.3801403], [82.78096771, 17.37986946], [82.7804184, 17.37986946], [82.7804184, 17.37957954], [82.77958679, 17.37958336], [82.77958679, 17.37930489], [82.77902985, 17.37930489], [82.77902985, 17.37902832], [82.7784729, 17.37903023], [82.7784729, 17.37874985], [82.7776413, 17.37874985], [82.7776413, 17.37846947], [82.77708435, 17.37847137], [82.77708435, 17.37819481], [82.7765274, 17.37819481], [82.7765274, 17.37791634], [82.77597046, 17.37792015], [82.77597046, 17.37763977], [82.77513885, 17.37763977], [82.77513885, 17.37735939], [82.77458191, 17.3773613], [82.77458191, 17.37708282], [82.77402496, 17.37708282], [82.77402496, 17.37680626], [82.77319336, 17.37681007], [82.77319336, 17.37652969], [82.77263641, 17.37652969], [82.77263641, 17.37624931], [82.77210236, 17.37624931], [82.77210236, 17.37597084], [82.77153015, 17.37597275], [82.77153015, 17.37569427], [82.77069092, 17.37569427], [82.77069092, 17.3754158], [82.7701416, 17.37541962], [82.7701416, 17.37513924], [82.76957703, 17.37513924], [82.76957703, 17.37486076], [82.76902771, 17.37486076], [82.76902771, 17.37457848], [82.76819611, 17.3745842], [82.76819611, 17.37430573], [82.76763916, 17.37431145], [82.76763916, 17.37402916], [82.76708221, 17.37402916], [82.76708221, 17.37374115], [82.76625061, 17.37375069], [82.76625061, 17.37347221], [82.76569366, 17.37347221], [82.76569366, 17.37319374], [82.76513672, 17.37319374], [82.76513672, 17.37291718], [82.76431274, 17.37291908], [82.76431274, 17.37264061], [82.76374817, 17.37264061], [82.76374817, 17.37236023], [82.76319122, 17.37236023], [82.76319122, 17.37207985], [82.76264191, 17.37208366], [82.76264191, 17.37180519], [82.76180267, 17.37181091], [82.76180267, 17.37153053], [82.76125336, 17.37153053], [82.76125336, 17.37125015], [82.76069641, 17.37125015], [82.76069641, 17.37096977], [82.76013947, 17.37097168], [82.76013947, 17.37069511], [82.75930786, 17.37070084], [82.75930786, 17.37042046], [82.75875092, 17.37042046], [82.75875092, 17.37014008], [82.75791931, 17.37014008], [82.75791931, 17.3698597], [82.75736237, 17.3698616], [82.75736237, 17.36958313], [82.75680542, 17.36958313], [82.75680542, 17.36930656], [82.75624847, 17.36930656], [82.75624847, 17.36902809], [82.75569153, 17.36903], [82.75569153, 17.36874962], [82.75514221, 17.36874962], [82.75514221, 17.36847115], [82.75458527, 17.36847305], [82.75458527, 17.36819649], [82.75402832, 17.36819649], [82.75402832, 17.3679142], [82.7537384, 17.36792946], [82.7537384, 17.36763954], [82.75319672, 17.36763954], [82.75319672, 17.36736107], [82.75263977, 17.36736107], [82.75263977, 17.36708069], [82.75208282, 17.3670826], [82.75208282, 17.36680412], [82.75152588, 17.36680984], [82.75152588, 17.36652946], [82.75096893, 17.36652946], [82.75096893, 17.3662529], [82.75041962, 17.3662529], [82.75041962, 17.36597061], [82.75013733, 17.36597252], [82.75013733, 17.36569214], [82.74958038, 17.36569214], [82.74958038, 17.36541748], [82.74903107, 17.36541939], [82.74903107, 17.36514282], [82.74846649, 17.36514282], [82.74846649, 17.36487007], [82.74819183, 17.36487007], [82.74819183, 17.36458015], [82.74764252, 17.36458206], [82.74764252, 17.3643055], [82.7470932, 17.36431122], [82.7470932, 17.36403275], [82.74624634, 17.36403275], [82.74624634, 17.36375046], [82.7454071, 17.36375046], [82.7454071, 17.36347008], [82.74485779, 17.36347008], [82.74485779, 17.36319542], [82.74430847, 17.3631916], [82.74430847, 17.36291695], [82.74346924, 17.36292267], [82.74346924, 17.36264038], [82.74291992, 17.36264038], [82.74291992, 17.36236191], [82.74208069, 17.36236191], [82.74208069, 17.36208344], [82.74153137, 17.36208344], [82.74153137, 17.36180496], [82.74097443, 17.36180496], [82.74097443, 17.3615284], [82.74014282, 17.3615303], [82.74014282, 17.36124992], [82.73986053, 17.36124992], [82.73986053, 17.36096764], [82.73874664, 17.36097145], [82.73874664, 17.36069489], [82.73847198, 17.36069489], [82.73847198, 17.36041641], [82.73764038, 17.36041832], [82.73764038, 17.36013985], [82.73735809, 17.36013985], [82.73735809, 17.35985947], [82.73708344, 17.35986137], [82.73708344, 17.3595829], [82.73680878, 17.3595829], [82.73680878, 17.35930634], [82.73542023, 17.35930824], [82.73542023, 17.35902977], [82.73486328, 17.35902977], [82.73486328, 17.35873985], [82.73430634, 17.35874939], [82.73430634, 17.35847282], [82.73374939, 17.35847282], [82.73374939, 17.35819435], [82.73347473, 17.35819435], [82.73347473, 17.35791779], [82.73293304, 17.35791969], [82.73293304, 17.35764122], [82.73236084, 17.35764122], [82.73236084, 17.35736084], [82.73179626, 17.35736084], [82.73179626, 17.35708046], [82.73124695, 17.35708427], [82.73124695, 17.35680771], [82.73069763, 17.35680962], [82.73069763, 17.35653114], [82.73014069, 17.35653114], [82.73014069, 17.35625076], [82.72956848, 17.35625076], [82.72956848, 17.35597038], [82.72902679, 17.35597229], [82.72902679, 17.35569572], [82.72846985, 17.35569954], [82.72846985, 17.35542107], [82.7279129, 17.35542107], [82.7279129, 17.35514069], [82.72735596, 17.35514069], [82.72735596, 17.35486031], [82.72679901, 17.35486031], [82.72679901, 17.35457993], [82.72624969, 17.35458565], [82.72624969, 17.35430336], [82.72569275, 17.35431099], [82.72569275, 17.35403061], [82.7251358, 17.35403061], [82.7251358, 17.35375023], [82.72458649, 17.35375023], [82.72458649, 17.35346985], [82.72374725, 17.35347176], [82.72374725, 17.35319328], [82.72319794, 17.35320091], [82.72319794, 17.35293007], [82.72264099, 17.35293007], [82.72264099, 17.35264015], [82.72207642, 17.35264015], [82.72207642, 17.35235977], [82.7215271, 17.35236168], [82.7215271, 17.3520813], [82.72097015, 17.3520813], [82.72097015, 17.35180473], [82.72041321, 17.35180473], [82.72041321, 17.35152817], [82.71985626, 17.35153008], [82.71985626, 17.35124969], [82.71930695, 17.35124969], [82.71930695, 17.35097122], [82.71875, 17.35097122], [82.71875, 17.35069466], [82.71819305, 17.35069466], [82.71819305, 17.35041618], [82.71762848, 17.35042191], [82.71762848, 17.35013962], [82.71708679, 17.35013962], [82.71708679, 17.34986115], [82.71652985, 17.34986115], [82.71652985, 17.34957123], [82.7159729, 17.34958267], [82.7159729, 17.34930611], [82.71541595, 17.34931183], [82.71541595, 17.34902954], [82.7151413, 17.34902954], [82.7151413, 17.34874916], [82.71456909, 17.34874916], [82.71456909, 17.34847069], [82.7140274, 17.3484726], [82.7140274, 17.34819412], [82.71347046, 17.34819412], [82.71347046, 17.34791756], [82.71290588, 17.34791946], [82.71290588, 17.34763908], [82.71235657, 17.34763908], [82.71235657, 17.34736061], [82.71180725, 17.34736061], [82.71180725, 17.34708405], [82.71125031, 17.34708405], [82.71125031, 17.34680557], [82.71069336, 17.34680557], [82.71069336, 17.3465271], [82.71013641, 17.34653091], [82.71013641, 17.34625053], [82.7095871, 17.34625053], [82.7095871, 17.34596825], [82.70903015, 17.34597206], [82.70903015, 17.34569359], [82.70847321, 17.34569359], [82.70847321, 17.34541893], [82.70791626, 17.34542084], [82.70791626, 17.34514046], [82.70735931, 17.34514046], [82.70735931, 17.34486008], [82.70652771, 17.34486198], [82.70652771, 17.34458351], [82.70625305, 17.34458351], [82.70625305, 17.34430695], [82.70597076, 17.34431076], [82.70597076, 17.34403038], [82.70568848, 17.34403038], [82.70568848, 17.34375954], [82.70347595, 17.34375954], [82.70347595, 17.34346962], [82.70291901, 17.34347153], [82.70291901, 17.34319687], [82.70236206, 17.34320068], [82.70236206, 17.3429203], [82.70207977, 17.3429203], [82.70207977, 17.34263992], [82.70153046, 17.34263992], [82.70153046, 17.34235954], [82.70097351, 17.34236145], [82.70097351, 17.34208488], [82.70041656, 17.34208488], [82.70041656, 17.34180641], [82.69985962, 17.34181023], [82.69985962, 17.34152985], [82.69930267, 17.34152985], [82.69930267, 17.34124947], [82.69902802, 17.34124947], [82.69902802, 17.34097099], [82.69847107, 17.34097481], [82.69847107, 17.34069252], [82.69790649, 17.34070015], [82.69790649, 17.34041977], [82.69735718, 17.34041977], [82.69735718, 17.34013939], [82.69680786, 17.34013939], [82.69680786, 17.33986092], [82.69625092, 17.33986092], [82.69625092, 17.33958054], [82.69569397, 17.33958244], [82.69569397, 17.33930588], [82.69513702, 17.33930969], [82.69513702, 17.33903122], [82.69458008, 17.33903122], [82.69458008, 17.33875084], [82.69403076, 17.33875084], [82.69403076, 17.33847046], [82.69347382, 17.33847237], [82.69347382, 17.33819389], [82.69291687, 17.33819389], [82.69291687, 17.33791733], [82.69264221, 17.33792114], [82.69264221, 17.33762932], [82.69208527, 17.33763885], [82.69208527, 17.33736038], [82.69152832, 17.33736038], [82.69152832, 17.33708191], [82.69097137, 17.33708382], [82.69097137, 17.33680534], [82.69039917, 17.33681107], [82.69039917, 17.33653259], [82.68985748, 17.33653259], [82.68985748, 17.33625031], [82.68930817, 17.33625031], [82.68930817, 17.33597183], [82.68875122, 17.33597183], [82.68875122, 17.33569527], [82.68818665, 17.3357029], [82.68818665, 17.33542252], [82.68765259, 17.33542252], [82.68765259, 17.33514023], [82.68708038, 17.33514023], [82.68708038, 17.33486176], [82.68653107, 17.33486176], [82.68653107, 17.33458328], [82.68597412, 17.33458328], [82.68597412, 17.33430481], [82.68569183, 17.33430481], [82.68569183, 17.33402824], [82.68514252, 17.33402824], [82.68514252, 17.33374977], [82.68458557, 17.33374977], [82.68458557, 17.3334713], [82.68402863, 17.3334713], [82.68402863, 17.33319473], [82.68347168, 17.33319473], [82.68347168, 17.33291626], [82.6829071, 17.33291817], [82.6829071, 17.33263969], [82.68264008, 17.33263969], [82.68264008, 17.33236122], [82.68208313, 17.33236122], [82.68208313, 17.33208084], [82.68152618, 17.33208275], [82.68152618, 17.33180618], [82.68096924, 17.33182144], [82.68096924, 17.33152962], [82.68041992, 17.33152962], [82.68041992, 17.33125114], [82.67986298, 17.33125114], [82.67986298, 17.33097076], [82.67958069, 17.33097267], [82.67958069, 17.3306942], [82.67903137, 17.3306942], [82.67903137, 17.33041763], [82.67845917, 17.33041954], [82.67845917, 17.33014107], [82.67791748, 17.33014107], [82.67791748, 17.32986069], [82.67736053, 17.32986069], [82.67736053, 17.32958031], [82.67680359, 17.32958412], [82.67680359, 17.32930756], [82.67652893, 17.32930946], [82.67652893, 17.32903099], [82.67597198, 17.32903099], [82.67597198, 17.32876015], [82.67542267, 17.32876015], [82.67542267, 17.32847023], [82.67485809, 17.32847214], [82.67485809, 17.32819557], [82.67430878, 17.32819557], [82.67430878, 17.32791519], [82.67375183, 17.32792091], [82.67375183, 17.32764053], [82.67346954, 17.32764053], [82.67346954, 17.32736015], [82.67292023, 17.32736206], [82.67292023, 17.32708549], [82.67236328, 17.32708549], [82.67236328, 17.32680321], [82.67180634, 17.32681084], [82.67180634, 17.32653046], [82.67151642, 17.32653046], [82.67151642, 17.32625008], [82.6709671, 17.32625008], [82.6709671, 17.3259697], [82.67041779, 17.3259716], [82.67041779, 17.32569313], [82.66986084, 17.32569313], [82.66986084, 17.32541656], [82.66957855, 17.32542038], [82.66957855, 17.32514], [82.66902924, 17.32514], [82.66902924, 17.32485962], [82.66847229, 17.32486153], [82.66847229, 17.32458115], [82.66791534, 17.32458115], [82.66791534, 17.32430649], [82.6673584, 17.3243103], [82.6673584, 17.32403183], [82.66707611, 17.32403183], [82.66707611, 17.32374954], [82.66651917, 17.32374954], [82.66651917, 17.32347107], [82.66596985, 17.32347107], [82.66596985, 17.3231945], [82.6654129, 17.3231945], [82.6654129, 17.32291603], [82.66513824, 17.32292175], [82.66513824, 17.32262993], [82.6645813, 17.32263947], [82.6645813, 17.32235909], [82.66401672, 17.32235909], [82.66401672, 17.32208061], [82.66347504, 17.32208252], [82.66347504, 17.32180595], [82.66319275, 17.32181168], [82.66319275, 17.32152939], [82.6626358, 17.32152939], [82.6626358, 17.32125092], [82.66208649, 17.32125092], [82.66208649, 17.32097054], [82.66152954, 17.32097244], [82.66152954, 17.32069397], [82.66124725, 17.32069397], [82.66124725, 17.3204174], [82.6607132, 17.32041931], [82.6607132, 17.32014084], [82.66042328, 17.32014084], [82.66042328, 17.31986046], [82.66014099, 17.31986046], [82.66014099, 17.31958771], [82.6598587, 17.31958771], [82.6598587, 17.31930923], [82.65930176, 17.31930923], [82.65930176, 17.31903076], [82.65875244, 17.31903076], [82.65875244, 17.31875038], [82.6581955, 17.31875038], [82.6581955, 17.31847191], [82.65791321, 17.31847191], [82.65791321, 17.31819534], [82.65735626, 17.31820107], [82.65735626, 17.31792068], [82.6570816, 17.31792068], [82.6570816, 17.3176403], [82.65651703, 17.3176403], [82.65651703, 17.31735992], [82.65597534, 17.31736183], [82.65597534, 17.31708336], [82.65513611, 17.31708336], [82.65513611, 17.31680679], [82.65458679, 17.31680679], [82.65458679, 17.31652832], [82.65428925, 17.31653023], [82.65428925, 17.31624985], [82.65402985, 17.31624985], [82.65402985, 17.31596947], [82.6534729, 17.31597137], [82.6534729, 17.31569672], [82.65291595, 17.31569672], [82.65291595, 17.31541443], [82.6526413, 17.31542015], [82.6526413, 17.31513977], [82.65207672, 17.31513977], [82.65207672, 17.31485939], [82.6515274, 17.3148613], [82.6515274, 17.31458473], [82.6506958, 17.31458473], [82.6506958, 17.31430435], [82.65013885, 17.31431007], [82.65013885, 17.31402969], [82.64985657, 17.31402969], [82.64985657, 17.31375122], [82.64958191, 17.31375122], [82.64958191, 17.31347084], [82.64902496, 17.31347466], [82.64902496, 17.31319237], [82.64875031, 17.31319237], [82.64875031, 17.3129158], [82.64819336, 17.31291962], [82.64819336, 17.31264114], [82.64736176, 17.31264114], [82.64736176, 17.31236076], [82.64653015, 17.31236076], [82.64653015, 17.31208038], [82.64624786, 17.31208229], [82.64624786, 17.31180573], [82.64597321, 17.31180954], [82.64597321, 17.31153107], [82.64569092, 17.31153107], [82.64569092, 17.31125069], [82.64457703, 17.31125069], [82.64457703, 17.31097031], [82.64347076, 17.31097031], [82.64347076, 17.31069374], [82.64319611, 17.31069374], [82.64319611, 17.31041718], [82.64263916, 17.3104229], [82.64263916, 17.31014061], [82.64234924, 17.31014061], [82.64234924, 17.30986023], [82.64152527, 17.30986023], [82.64152527, 17.30958366], [82.64097595, 17.30958366], [82.64097595, 17.30930519], [82.64041901, 17.30931282], [82.64041901, 17.30903244], [82.63931274, 17.30903244], [82.63931274, 17.30875015], [82.63874817, 17.30875015], [82.63874817, 17.30847168], [82.63847351, 17.30847168], [82.63847351, 17.30819511], [82.63819122, 17.30820274], [82.63819122, 17.30791855], [82.63791656, 17.30791855], [82.63791656, 17.30764961], [82.63764191, 17.30764961], [82.63764191, 17.3073597], [82.63708496, 17.3073616], [82.63708496, 17.30708313], [82.63680267, 17.30708313], [82.63680267, 17.30652809], [82.63654327, 17.30652809], [82.63654327, 17.30624962], [82.63597107, 17.30624962], [82.63597107, 17.30597115], [82.63569641, 17.30597305], [82.63569641, 17.30569458], [82.63513947, 17.30569458], [82.63513947, 17.30541611], [82.63485718, 17.30541992], [82.63485718, 17.30513954], [82.63458252, 17.30513954], [82.63458252, 17.30486107], [82.63402557, 17.30486107], [82.63402557, 17.3045826], [82.63375092, 17.30459023], [82.63375092, 17.30430984], [82.63291931, 17.30430984], [82.63291931, 17.30402946], [82.63263702, 17.30402946], [82.63263702, 17.30375099], [82.63181305, 17.30375099], [82.63181305, 17.30347061], [82.63124847, 17.30347252], [82.63124847, 17.30319595], [82.63097382, 17.30319595], [82.63097382, 17.30291748], [82.63040924, 17.30291939], [82.63040924, 17.30264091], [82.63014221, 17.30264091], [82.63014221, 17.30236053], [82.62985992, 17.30236053], [82.62985992, 17.30208015], [82.62958527, 17.30208588], [82.62958527, 17.30180359], [82.62847137, 17.30181122], [82.62847137, 17.30153084], [82.6279068, 17.30153084], [82.6279068, 17.30125046], [82.62763977, 17.30125046], [82.62763977, 17.30097008], [82.62735748, 17.30097389], [82.62735748, 17.30069351], [82.62596893, 17.3006897], [82.62596893, 17.30041695], [82.62541962, 17.30042076], [82.62541962, 17.30014038], [82.62458038, 17.30014038], [82.62458038, 17.29986], [82.62430573, 17.29986382], [82.62430573, 17.29958534], [82.62374878, 17.29958534], [82.62374878, 17.29930305], [82.62319183, 17.29931068], [82.62319183, 17.2990303], [82.62291718, 17.2990303], [82.62291718, 17.29874992], [82.62264252, 17.29874992], [82.62264252, 17.29846191], [82.62208557, 17.29847145], [82.62208557, 17.29819489], [82.62180328, 17.29819489], [82.62180328, 17.29791641], [82.62124634, 17.29792023], [82.62124634, 17.29763985], [82.62069702, 17.29763985], [82.62069702, 17.29735947], [82.62041473, 17.29736137], [82.62041473, 17.2970829], [82.62014008, 17.2970829], [82.62014008, 17.29680634], [82.61930847, 17.29681015], [82.61930847, 17.29652977], [82.61902618, 17.29652977], [82.61902618, 17.29624939], [82.61875153, 17.29624939], [82.61875153, 17.29597092], [82.61819458, 17.29597282], [82.61819458, 17.29569435], [82.61791992, 17.29569435], [82.61791992, 17.29541588], [82.61708069, 17.2954216], [82.61708069, 17.29513931], [82.61680603, 17.29513931], [82.61680603, 17.29486084], [82.61653137, 17.29486084], [82.61653137, 17.29458046], [82.61624908, 17.29458427], [82.61624908, 17.2943058], [82.6159668, 17.29431152], [82.6159668, 17.29402924], [82.61540985, 17.29402924], [82.61540985, 17.29375076], [82.61513519, 17.29375076], [82.61513519, 17.29347229], [82.61458588, 17.29347229], [82.61458588, 17.29319382], [82.61374664, 17.29319382], [82.61374664, 17.29291725], [82.61347198, 17.29291916], [82.61347198, 17.29264832], [82.61264038, 17.29264832], [82.61264038, 17.29236031], [82.61235809, 17.29236031], [82.61235809, 17.29208374], [82.61152649, 17.29207993], [82.61152649, 17.29236031], [82.61125183, 17.29236031], [82.61125183, 17.29375076], [82.61096954, 17.29375076], [82.61096954, 17.29402924], [82.61042023, 17.29402924], [82.61042023, 17.29431152], [82.61013794, 17.2943058], [82.61013794, 17.29458427], [82.60986328, 17.29458046], [82.60986328, 17.29486084], [82.60958099, 17.29486084], [82.60958099, 17.29513931], [82.60930634, 17.29513931], [82.60930634, 17.2954216], [82.60874939, 17.29541588], [82.60874939, 17.29597282], [82.6084671, 17.29597092], [82.60847473, 17.29624939], [82.6076355, 17.29624939], [82.6076355, 17.29541588], [82.60791779, 17.2954216], [82.60791779, 17.29513931], [82.60819244, 17.29513931], [82.60819244, 17.29458046], [82.60847473, 17.29458237], [82.60847473, 17.29347229], [82.60902405, 17.29347229], [82.60902405, 17.29319382], [82.60930634, 17.29319382], [82.60930634, 17.29263878], [82.60958099, 17.29264832], [82.60958099, 17.29180908], [82.60986328, 17.29180908], [82.60986328, 17.29042053], [82.60958099, 17.29042053], [82.60958099, 17.29014015], [82.60930634, 17.29014015], [82.60930634, 17.28985977], [82.60874939, 17.28986168], [82.60874939, 17.28958321], [82.60847473, 17.28958321], [82.60847473, 17.28930664], [82.60791779, 17.28930664], [82.60791779, 17.28902817], [82.60708618, 17.28903008], [82.60708618, 17.28874969], [82.60623932, 17.28874969], [82.60623932, 17.28847122], [82.60597229, 17.28847313], [82.60597229, 17.28819656], [82.60569763, 17.28819656], [82.60569763, 17.28791428], [82.60514069, 17.28792], [82.60514069, 17.28763962], [82.60430908, 17.28763962], [82.60430908, 17.28736115], [82.60346985, 17.28736115], [82.60346985, 17.28708076], [82.60236359, 17.28708267], [82.60236359, 17.2868042], [82.60151672, 17.28680992], [82.60151672, 17.28652191], [82.60097504, 17.28652763], [82.60097504, 17.28624916], [82.59929657, 17.28625107], [82.59929657, 17.28597069], [82.59764099, 17.28597069], [82.59764099, 17.28625107], [82.59570312, 17.28625107], [82.59570312, 17.28597069], [82.59541321, 17.2859745], [82.59541321, 17.28541756], [82.59570312, 17.28541946], [82.59570312, 17.2851429], [82.59625244, 17.2851429], [82.59625244, 17.28486061], [82.5965271, 17.28486061], [82.5965271, 17.28458023], [82.59680176, 17.28458214], [82.59680176, 17.28430557], [82.59707642, 17.28430939], [82.59707642, 17.28403282], [82.59736633, 17.28403282], [82.59736633, 17.28375053], [82.59680176, 17.28375053], [82.59680176, 17.28346062], [82.5965271, 17.28347015], [82.5965271, 17.28319359], [82.59625244, 17.28319359], [82.59625244, 17.28291702], [82.59597015, 17.28292274], [82.59597015, 17.28264046], [82.59541321, 17.28264046], [82.59541321, 17.28236008], [82.59430695, 17.28236008], [82.59430695, 17.28180504], [82.59401703, 17.28181267], [82.59401703, 17.28153038], [82.59348297, 17.28153038], [82.59348297, 17.28124809], [82.59319305, 17.28124809], [82.59319305, 17.28096962], [82.59263611, 17.28097153], [82.59263611, 17.28069496], [82.59236145, 17.28071022], [82.59236145, 17.2804184], [82.59179688, 17.2804184], [82.59179688, 17.28013992], [82.59123993, 17.28013992], [82.59123993, 17.27985954], [82.59069824, 17.27986145], [82.59069061, 17.27958298], [82.5901413, 17.27958298], [82.5901413, 17.27930641], [82.58957672, 17.27930832], [82.58957672, 17.27902985], [82.58930206, 17.27902985], [82.58930206, 17.27874947], [82.58875275, 17.27874947], [82.58875275, 17.27847099], [82.5881958, 17.2784729], [82.5881958, 17.27791786], [82.58763885, 17.27791977], [82.58763885, 17.27763939], [82.58651733, 17.27763939], [82.58651733, 17.27736092], [82.58597565, 17.27736092], [82.58597565, 17.27708244], [82.58569336, 17.27708244], [82.58569336, 17.27680779], [82.58542633, 17.27680969], [82.58542633, 17.27653122], [82.58486176, 17.27653122], [82.58486176, 17.27625084], [82.58429718, 17.27625084], [82.58429718, 17.27597046], [82.58374786, 17.27597237], [82.58374786, 17.2756958], [82.58347321, 17.2756958], [82.58347321, 17.27541733], [82.58319092, 17.27542114], [82.58319092, 17.27514076], [82.58235931, 17.27514076], [82.58235931, 17.27486038], [82.58207703, 17.27486038], [82.58207703, 17.27458], [82.58152771, 17.27458572], [82.58152771, 17.27430344], [82.58125305, 17.27431107], [82.58125305, 17.27403069], [82.58097076, 17.27403069], [82.58097076, 17.27375031], [82.57985687, 17.27375031], [82.57985687, 17.27346992], [82.57958221, 17.27347183], [82.57958221, 17.27319336], [82.5790329, 17.27320099], [82.5790329, 17.27292061], [82.57847595, 17.27292061], [82.57847595, 17.27235985], [82.57819366, 17.27236366], [82.57819366, 17.27208138], [82.57791901, 17.27208138], [82.57791901, 17.27180481], [82.57736206, 17.27180481], [82.57736206, 17.27152824], [82.57680511, 17.27152824], [82.57680511, 17.27124977], [82.57653046, 17.27124977], [82.57653046, 17.27096939], [82.57624817, 17.2709713], [82.57624817, 17.27069473], [82.57569122, 17.27069473], [82.57569122, 17.27041626], [82.57485962, 17.27042007], [82.57485962, 17.27013969], [82.57430267, 17.27013969], [82.57430267, 17.26986122], [82.57402802, 17.26986122], [82.57402802, 17.26958084], [82.57375336, 17.26958275], [82.57375336, 17.26930618], [82.57319641, 17.2693119], [82.57319641, 17.26902962], [82.57290649, 17.26902962], [82.57290649, 17.26874924], [82.57263947, 17.26874924], [82.57263947, 17.2684803], [82.57180786, 17.2684803], [82.57180786, 17.26818848], [82.57125092, 17.2681942], [82.57125092, 17.26791763], [82.57096863, 17.26791954], [82.57096863, 17.26763916], [82.57068634, 17.26763916], [82.57068634, 17.26736069], [82.57041931, 17.26736069], [82.57041931, 17.2670784], [82.56986237, 17.26708412], [82.56986237, 17.26680565], [82.56958008, 17.26681137], [82.56958008, 17.26625061], [82.56930542, 17.26625061], [82.56930542, 17.26597214], [82.56791687, 17.26597214], [82.56791687, 17.26569366], [82.56764221, 17.26569366], [82.56764221, 17.2654171], [82.5670929, 17.26542091], [82.5670929, 17.26514053], [82.56680298, 17.26514053], [82.56680298, 17.26486015], [82.56652832, 17.26486206], [82.56652832, 17.26458359], [82.56625366, 17.26458359], [82.56625366, 17.26430511], [82.56597137, 17.26431084], [82.56597137, 17.26403046], [82.56485748, 17.26403046], [82.56485748, 17.26375008], [82.56430817, 17.26375008], [82.56430817, 17.2634716], [82.56375122, 17.2634716], [82.56375122, 17.26319695], [82.56291962, 17.26320076], [82.56291962, 17.26292038], [82.56263733, 17.26292038], [82.56263733, 17.26264], [82.56208038, 17.26264], [82.56208038, 17.26235008], [82.56180573, 17.26236153], [82.56180573, 17.26208305], [82.56153107, 17.26208305], [82.56153107, 17.26180649], [82.56096649, 17.2618103], [82.56096649, 17.26152992], [82.56069183, 17.26152992], [82.56069183, 17.26124954], [82.56041718, 17.26124954], [82.56041718, 17.26097107], [82.55986023, 17.26097488], [82.55986023, 17.26069641], [82.55958557, 17.26069641], [82.55958557, 17.26041412], [82.55902863, 17.26041985], [82.55902863, 17.26013947], [82.55847168, 17.26013947], [82.55847168, 17.25986099], [82.55819702, 17.25986099], [82.55819702, 17.25958061], [82.55791473, 17.25958252], [82.55791473, 17.25930405], [82.55735779, 17.25930977], [82.55735779, 17.25902939], [82.55708313, 17.25902939], [82.55708313, 17.25875282], [82.55625153, 17.25875282], [82.55625153, 17.25847054], [82.55569458, 17.25847244], [82.55569458, 17.25819206], [82.55513763, 17.25819206], [82.55513763, 17.2579174], [82.55486298, 17.25792122], [82.55486298, 17.25764275], [82.55458069, 17.25764275], [82.55458069, 17.25736046], [82.55374908, 17.25736046], [82.55374908, 17.25708008], [82.55319214, 17.25708389], [82.55319214, 17.25680542], [82.55291748, 17.25681114], [82.55291748, 17.2565403], [82.55236053, 17.2565403], [82.55236053, 17.25625038], [82.55179596, 17.25625038], [82.55179596, 17.25570107], [82.55124664, 17.25570107], [82.55124664, 17.25542259], [82.55097198, 17.25542259], [82.55097198, 17.2551403], [82.55014038, 17.2551403], [82.55014038, 17.25486183], [82.54985809, 17.25486183], [82.54985809, 17.25458336], [82.54958344, 17.25458336], [82.54958344, 17.25430489], [82.54902649, 17.25430489], [82.54902649, 17.25374985], [82.54846954, 17.25374985], [82.54846954, 17.25348091], [82.54818726, 17.25348091], [82.54818726, 17.25318909], [82.54763794, 17.25319481], [82.54763794, 17.25291634], [82.54736328, 17.25291824], [82.54736328, 17.25263977], [82.54708099, 17.25263977], [82.54708099, 17.25235939], [82.54680634, 17.2523613], [82.54680634, 17.25208282], [82.54652405, 17.25208282], [82.54652405, 17.25180626], [82.54569244, 17.25180817], [82.54569244, 17.25152969], [82.54514313, 17.25152969], [82.54514313, 17.25125122], [82.54458618, 17.25125122], [82.54458618, 17.25097084], [82.54430389, 17.25097275], [82.54430389, 17.25041771], [82.54374695, 17.25041771], [82.54374695, 17.25013924], [82.54292297, 17.25014114], [82.54292297, 17.24986076], [82.54264069, 17.24986076], [82.54264069, 17.24958038], [82.54180908, 17.2495842], [82.54180908, 17.24930763], [82.54152679, 17.24930954], [82.54152679, 17.24903107], [82.54125214, 17.24903107], [82.54125214, 17.24875069], [82.54096985, 17.24875069], [82.54096985, 17.24818993], [82.54069519, 17.24819565], [82.54069519, 17.24791718], [82.54013062, 17.24792099], [82.54013062, 17.24764061], [82.53985596, 17.24764061], [82.53985596, 17.24735069], [82.53930664, 17.24736023], [82.53930664, 17.24708557], [82.53847504, 17.24708557], [82.53847504, 17.24680328], [82.53819275, 17.24681091], [82.53819275, 17.24653053], [82.53791809, 17.24653053], [82.53791809, 17.24625015], [82.53756714, 17.24625015], [82.53736115, 17.24625015], [82.53736115, 17.24596977], [82.5368042, 17.24597168], [82.5368042, 17.24569321], [82.53624725, 17.24570084], [82.53624725, 17.24542046], [82.5359726, 17.24542046], [82.5359726, 17.24514008], [82.53569794, 17.24514008], [82.53569794, 17.2448597], [82.5348587, 17.2448616], [82.5348587, 17.24458122], [82.53430176, 17.24458122], [82.53430176, 17.24430466], [82.53375244, 17.24431038], [82.53375244, 17.24403191], [82.53347015, 17.24403191], [82.53347015, 17.24374962], [82.53291321, 17.24374962], [82.53291321, 17.24347115], [82.53236389, 17.24347115], [82.53236389, 17.24319458], [82.5320816, 17.24319458], [82.5320816, 17.24291611], [82.53151703, 17.24292183], [82.53151703, 17.24263954], [82.53125, 17.24263954], [82.53125, 17.24235916], [82.53097534, 17.24235916], [82.53097534, 17.2420826], [82.53069305, 17.2420826], [82.53069305, 17.24180603], [82.5304184, 17.24181175], [82.5304184, 17.24154282], [82.53013611, 17.24154282], [82.53013611, 17.24124908], [82.52986145, 17.24124908], [82.52986145, 17.24068832], [82.52958679, 17.24069405], [82.52958679, 17.24041748], [82.52929688, 17.24041939], [82.52929688, 17.24014091], [82.52902985, 17.24014091], [82.52902985, 17.23986053], [82.5284729, 17.23986053], [82.5284729, 17.23957825], [82.52791595, 17.23958397], [82.52791595, 17.2393055], [82.52707672, 17.23931122], [82.52707672, 17.23903084], [82.5265274, 17.23903084], [82.5265274, 17.23875046], [82.52625275, 17.23875046], [82.52625275, 17.23820114], [82.52597046, 17.23818016], [82.52597046, 17.23791885], [82.52540588, 17.23792076], [82.52540588, 17.23764038], [82.52485657, 17.23764038], [82.52485657, 17.23736], [82.52430725, 17.23736191], [82.52430725, 17.23708344], [82.52402496, 17.23708344], [82.52402496, 17.23680687], [82.52375031, 17.23681068], [82.52375031, 17.2365303], [82.52348328, 17.2365303], [82.52348328, 17.23624992], [82.52319336, 17.23624992], [82.52319336, 17.23596954], [82.52263641, 17.23597145], [82.52263641, 17.23569679], [82.52236176, 17.23569679], [82.52236176, 17.23541451], [82.52180481, 17.23541451], [82.52180481, 17.23513985], [82.52124786, 17.23513985], [82.52124786, 17.23485947], [82.52069092, 17.23486137], [82.52069092, 17.23458481], [82.51985931, 17.23458481], [82.51985931, 17.23430634], [82.51930237, 17.23431015], [82.51930237, 17.23402977], [82.51902008, 17.23402977], [82.51902008, 17.23374939], [82.51875305, 17.23374939], [82.51875305, 17.23347092], [82.51847076, 17.23347473], [82.51847076, 17.23319244], [82.51819611, 17.23319244], [82.51819611, 17.23291588], [82.51763916, 17.23291969], [82.51763916, 17.23264122], [82.51735687, 17.23264122], [82.51735687, 17.23208046], [82.51708221, 17.23208237], [82.51708221, 17.2318058], [82.51680756, 17.23180962], [82.51680756, 17.23153114], [82.5165329, 17.23153114], [82.5165329, 17.23125076], [82.51568604, 17.23125076], [82.51568604, 17.23097038], [82.51541901, 17.23097229], [82.51541901, 17.23069382], [82.51457977, 17.23069382], [82.51457977, 17.23041725], [82.51431274, 17.23042107], [82.51431274, 17.23014259], [82.51403046, 17.23014259], [82.51403046, 17.22986031], [82.51374817, 17.22986031], [82.51374817, 17.2293129], [82.51346588, 17.2293129], [82.51346588, 17.22875023], [82.51235962, 17.22875023], [82.51235962, 17.22847176], [82.51180267, 17.22847176], [82.51180267, 17.22819519], [82.51152802, 17.22820282], [82.51152802, 17.22792244], [82.51125336, 17.22792244], [82.51125336, 17.22763824], [82.51097107, 17.22763824], [82.51097107, 17.22735977], [82.51041412, 17.22736168], [82.51041412, 17.22708321], [82.51013947, 17.22708321], [82.51013947, 17.22680473], [82.50986481, 17.22680473], [82.50986481, 17.22652817], [82.50930786, 17.22652817], [82.50930786, 17.22624016], [82.50819397, 17.22624969], [82.50819397, 17.22597313], [82.50791931, 17.22597313], [82.50791931, 17.22569466], [82.50763702, 17.22569466], [82.50763702, 17.22541618], [82.50736237, 17.22541809], [82.50736237, 17.22513962], [82.50680542, 17.22513962], [82.50680542, 17.22486115], [82.50653076, 17.22486115], [82.50653076, 17.22458076], [82.50624847, 17.22458267], [82.50624847, 17.22430611], [82.50596619, 17.22430992], [82.50596619, 17.22402954], [82.50514221, 17.22402954], [82.50514221, 17.22375107], [82.50485992, 17.22375107], [82.50485992, 17.22347069], [82.50430298, 17.2234726], [82.50430298, 17.22319412], [82.50402832, 17.22319412], [82.50402832, 17.22291756], [82.50347137, 17.22291946], [82.50347137, 17.22264099], [82.5029068, 17.22264099], [82.5029068, 17.22236061], [82.50263977, 17.22236061], [82.50263977, 17.22208023], [82.50208282, 17.22208595], [82.50208282, 17.22180367], [82.50180817, 17.22180939], [82.50180817, 17.22153091], [82.50125122, 17.22153091], [82.50125122, 17.22125053], [82.50096893, 17.22125053], [82.50096893, 17.22097206], [82.50041962, 17.22097206], [82.50041962, 17.22041512], [82.50013733, 17.22043037], [82.50013733, 17.21986008], [82.49958038, 17.21986389], [82.49958038, 17.21958542], [82.49874878, 17.21958542], [82.49874878, 17.21930313], [82.49846649, 17.21931076], [82.49846649, 17.21903038], [82.49791718, 17.21903038], [82.49791718, 17.21875], [82.49764252, 17.21875], [82.49764252, 17.21846962], [82.49708557, 17.21847153], [82.49708557, 17.21819305], [82.49652863, 17.21820068], [82.49652863, 17.2179203], [82.49624634, 17.2179203], [82.49624634, 17.21763992], [82.49597168, 17.21763992], [82.49597168, 17.21737289], [82.49569702, 17.21737289], [82.49569702, 17.21708107], [82.49514008, 17.21708107], [82.49514008, 17.21680641], [82.49458313, 17.21681023], [82.49458313, 17.21653175], [82.49430847, 17.21653175], [82.49430847, 17.21624947], [82.49402618, 17.21624947], [82.49402618, 17.21596909], [82.49346924, 17.2159729], [82.49346924, 17.21569443], [82.49319458, 17.21569443], [82.49319458, 17.21541595], [82.49263763, 17.21542168], [82.49263763, 17.21513939], [82.49208069, 17.21513939], [82.49208069, 17.21486092], [82.49180603, 17.21486092], [82.49180603, 17.21458054], [82.49153137, 17.21458244], [82.49153137, 17.21430588], [82.49097443, 17.21430588], [82.49097443, 17.2140274], [82.49014282, 17.21402931], [82.49014282, 17.21375084], [82.48986053, 17.21375084], [82.48986053, 17.21347046], [82.48958588, 17.21347237], [82.48958588, 17.21319389], [82.48930359, 17.21319389], [82.48930359, 17.21291733], [82.48903656, 17.21291924], [82.48903656, 17.21264076], [82.48874664, 17.21264076], [82.48874664, 17.21236038], [82.48819733, 17.21236038], [82.48819733, 17.21180916], [82.48792267, 17.21180916], [82.48792267, 17.21153069], [82.48764038, 17.21153069], [82.48764038, 17.21124077], [82.48708344, 17.21125031], [82.48708344, 17.21097183], [82.48652649, 17.21097183], [82.48652649, 17.21069527], [82.48625183, 17.21070099], [82.48625183, 17.21014023], [82.48597717, 17.21014023], [82.48597717, 17.20985985], [82.48542023, 17.20986176], [82.48542023, 17.20958328], [82.48486328, 17.20958328], [82.48486328, 17.20930672], [82.48430634, 17.20930672], [82.48430634, 17.20902824], [82.48401642, 17.20903015], [82.48401642, 17.20874977], [82.4834671, 17.20874977], [82.4834671, 17.20846939], [82.48319244, 17.2084713], [82.48319244, 17.20819664], [82.48291016, 17.20820045], [82.48291016, 17.20792007], [82.48236084, 17.20792007], [82.48236084, 17.20763969], [82.48208618, 17.20763969], [82.48208618, 17.20736122], [82.48179626, 17.20736122], [82.48179626, 17.20708084], [82.48124695, 17.20708466], [82.48124695, 17.20680428], [82.48097229, 17.20681], [82.48097229, 17.20652962], [82.48042297, 17.20652962], [82.48042297, 17.20625114], [82.48014069, 17.20625114], [82.48014069, 17.20597076], [82.47958374, 17.20597458], [82.47958374, 17.20569229], [82.47930908, 17.20569229], [82.47930908, 17.20541763], [82.47875214, 17.20543098], [82.47875214, 17.20514107], [82.47846985, 17.20514107], [82.47846985, 17.20486069], [82.47763824, 17.20486069], [82.47763824, 17.20458031], [82.47736359, 17.20458221], [82.47736359, 17.20430565], [82.4770813, 17.20430946], [82.4770813, 17.2040329], [82.47680664, 17.2040329], [82.47680664, 17.20375061], [82.47651672, 17.20375061], [82.47651672, 17.20319176], [82.47597504, 17.20319366], [82.47597504, 17.20263863], [82.47569275, 17.20264053], [82.47569275, 17.20236015], [82.47541809, 17.20236015], [82.47541809, 17.20208359], [82.4751358, 17.20208359], [82.4751358, 17.20180511], [82.47486115, 17.20181274], [82.47486115, 17.20153236], [82.47458649, 17.20153236], [82.47458649, 17.20125008], [82.47429657, 17.20125008], [82.47429657, 17.2009697], [82.47402954, 17.2009716], [82.47402954, 17.20069504], [82.4734726, 17.20070076], [82.4734726, 17.20041847], [82.47319794, 17.20041847], [82.47319794, 17.20013809], [82.47292328, 17.20013809], [82.47292328, 17.19985962], [82.47264099, 17.19986153], [82.47264099, 17.19958305], [82.4723587, 17.19958305], [82.4723587, 17.19930649], [82.47208405, 17.19930649], [82.47208405, 17.19902992], [82.4715271, 17.19902992], [82.4715271, 17.19874954], [82.47125244, 17.19874954], [82.47125244, 17.19847107], [82.47097015, 17.19847298], [82.47097015, 17.1981945], [82.4706955, 17.1981945], [82.4706955, 17.19791794], [82.47013855, 17.19791985], [82.47013855, 17.19763947], [82.46985626, 17.19763947], [82.46985626, 17.19736099], [82.4695816, 17.19736099], [82.4695816, 17.19708061], [82.46930695, 17.19708252], [82.46930695, 17.19680786], [82.46875, 17.19680977], [82.46875, 17.19652939], [82.46848297, 17.19652939], [82.46848297, 17.19626045], [82.46819305, 17.19626045], [82.46819305, 17.19597054], [82.4679184, 17.19597244], [82.4679184, 17.19569588], [82.46736145, 17.19569588], [82.46736145, 17.1954174], [82.46708679, 17.19542122], [82.46708679, 17.19514084], [82.46679688, 17.19514084], [82.46679688, 17.19486046], [82.46652985, 17.19486046], [82.46652985, 17.19458008], [82.4659729, 17.1945858], [82.4659729, 17.19430351], [82.46569824, 17.19431114], [82.46569061, 17.19403076], [82.46541595, 17.19403076], [82.46541595, 17.19375038], [82.4651413, 17.19375038], [82.4651413, 17.19347], [82.46458435, 17.19347382], [82.46458435, 17.19319344], [82.46430206, 17.19320107], [82.46430206, 17.19292068], [82.4640274, 17.19292068], [82.4640274, 17.1926403], [82.46375275, 17.1926403], [82.46375275, 17.19235992], [82.4631958, 17.19236374], [82.4631958, 17.19208145], [82.46291351, 17.19208145], [82.46291351, 17.19180489], [82.46263885, 17.19180489], [82.46263885, 17.19152832], [82.46235657, 17.19153023], [82.46235657, 17.19124985], [82.46180725, 17.19124985], [82.46180725, 17.19096947], [82.46152496, 17.19097137], [82.46152496, 17.19069481], [82.46125031, 17.19069481], [82.46125031, 17.19041634], [82.46098328, 17.19042015], [82.46098328, 17.19013977], [82.46069336, 17.19013977], [82.46069336, 17.18985939], [82.46013641, 17.1898613], [82.46013641, 17.18958282], [82.45986176, 17.18958282], [82.45986176, 17.18930626], [82.4595871, 17.18931007], [82.4595871, 17.18902969], [82.45929718, 17.18902969], [82.45929718, 17.18874931], [82.45903015, 17.18874931], [82.45903015, 17.18847084], [82.45874786, 17.18847275], [82.45874786, 17.18819427], [82.45819092, 17.18819427], [82.45819092, 17.1879158], [82.45791626, 17.18792152], [82.45791626, 17.18763924], [82.4576416, 17.18763924], [82.4576416, 17.18736076], [82.45735931, 17.18736076], [82.45735931, 17.18707085], [82.45708466, 17.1870842], [82.45708466, 17.18680573], [82.45652771, 17.18681145], [82.45652771, 17.18652916], [82.45625305, 17.18652916], [82.45625305, 17.18625069], [82.45597076, 17.18625069], [82.45597076, 17.18597031], [82.45569611, 17.18597221], [82.45569611, 17.18569374], [82.45541382, 17.18569374], [82.45541382, 17.18541718], [82.45513916, 17.18541908], [82.45513916, 17.18514061], [82.45485687, 17.18514061], [82.45485687, 17.18486023], [82.45430756, 17.18486023], [82.45430756, 17.18457985], [82.45402527, 17.18458366], [82.45402527, 17.18430519], [82.45375061, 17.18432045], [82.45375061, 17.18403053], [82.45347595, 17.18403053], [82.45347595, 17.18375015], [82.45318604, 17.18375015], [82.45318604, 17.18346977], [82.45263672, 17.18347168], [82.45263672, 17.18319511], [82.45236206, 17.18320084], [82.45236206, 17.18292046], [82.45181274, 17.18292046], [82.45181274, 17.18264008], [82.45153046, 17.18264008], [82.45153046, 17.1823597], [82.45097351, 17.1823616], [82.45097351, 17.18208313], [82.45069122, 17.18208313], [82.45069122, 17.18180656], [82.45014191, 17.18180656], [82.45014191, 17.18152809], [82.44986725, 17.18153], [82.44986725, 17.18126106], [82.44930267, 17.18126106], [82.44930267, 17.18097115], [82.44902802, 17.18097305], [82.44902802, 17.18069649], [82.44847107, 17.18069649], [82.44847107, 17.1804142], [82.44819641, 17.18041992], [82.44819641, 17.18013954], [82.44790649, 17.18013954], [82.44790649, 17.17986107], [82.44763947, 17.17986107], [82.44763947, 17.17958069], [82.44736481, 17.1795826], [82.44736481, 17.17930412], [82.44708252, 17.17930984], [82.44708252, 17.17902946], [82.4465332, 17.17902946], [82.4465332, 17.1787529], [82.44625092, 17.1787529], [82.44625092, 17.17847061], [82.44596863, 17.17847443], [82.44596863, 17.17819214], [82.44568634, 17.17819977], [82.44568634, 17.17791939], [82.44541931, 17.17791939], [82.44541931, 17.17764282], [82.44513702, 17.17764282], [82.44513702, 17.17736053], [82.44486237, 17.17736053], [82.44486237, 17.17708015], [82.44458008, 17.17708206], [82.44458008, 17.1768055], [82.44431305, 17.17681122], [82.44431305, 17.17653275], [82.44374084, 17.17653275], [82.44374084, 17.17625046], [82.44346619, 17.17625046], [82.44346619, 17.17597008], [82.44319153, 17.17597008], [82.44319153, 17.17569542], [82.44291687, 17.1756916], [82.44291687, 17.17541695], [82.44264221, 17.17542267], [82.44264221, 17.17513084], [82.44235992, 17.17513847], [82.44235992, 17.17486191], [82.44180298, 17.17486191], [82.44180298, 17.17458344], [82.44152832, 17.17458344], [82.44152832, 17.17430496], [82.44124603, 17.17431068], [82.44124603, 17.1740284], [82.44069672, 17.1740284], [82.44069672, 17.17374992], [82.44013977, 17.17374992], [82.44013977, 17.17346954], [82.43985748, 17.17347145], [82.43985748, 17.17319489], [82.43958282, 17.17319489], [82.43958282, 17.17291641], [82.43930817, 17.17291832], [82.43930817, 17.17263985], [82.43902588, 17.17263985], [82.43902588, 17.17206955], [82.43875122, 17.1720829], [82.43875122, 17.17152786], [82.43846893, 17.17152977], [82.43846893, 17.17124939], [82.43791962, 17.17124939], [82.43791962, 17.17097282], [82.43763733, 17.17097282], [82.43763733, 17.17041779], [82.43736267, 17.17041969], [82.43736267, 17.16958046], [82.43708038, 17.16958427], [82.43708038, 17.16930771], [82.43681335, 17.16932106], [82.43681335, 17.16903114], [82.43653107, 17.16903114], [82.43653107, 17.16875076], [82.43596649, 17.16875076], [82.43596649, 17.16847038], [82.43569183, 17.16847229], [82.43569183, 17.16819572], [82.43514252, 17.16819572], [82.43514252, 17.16791725], [82.4345932, 17.16792107], [82.4345932, 17.16764069], [82.43430328, 17.16764069], [82.43430328, 17.16736031], [82.43402863, 17.16736031], [82.43402863, 17.16707993], [82.43374634, 17.16708565], [82.43374634, 17.16680336], [82.43347168, 17.16681099], [82.43347168, 17.16653061], [82.43264008, 17.16653061], [82.43264008, 17.16625977], [82.43235779, 17.16625977], [82.43235779, 17.16596985], [82.43208313, 17.16597176], [82.43208313, 17.16569328], [82.43152618, 17.16570091], [82.43152618, 17.16542053], [82.43125153, 17.16542053], [82.43125153, 17.16514015], [82.43096924, 17.16514015], [82.43096924, 17.16457939], [82.43069458, 17.1645813], [82.43069458, 17.16430473], [82.43041992, 17.16430473], [82.43041992, 17.16402817], [82.42986298, 17.16403008], [82.42986298, 17.16374969], [82.42958069, 17.16374969], [82.42958069, 17.16347122], [82.42903137, 17.16347122], [82.42903137, 17.16319466], [82.42874908, 17.16319466], [82.42874908, 17.16291618], [82.4284668, 17.16292191], [82.4284668, 17.16263962], [82.42819214, 17.16263962], [82.42819214, 17.16208076], [82.42763519, 17.16208267], [82.42763519, 17.16180611], [82.42736053, 17.16181183], [82.42736053, 17.16152954], [82.42708588, 17.16152954], [82.42708588, 17.16124916], [82.42679596, 17.16124916], [82.42679596, 17.16097069], [82.42652893, 17.1609726], [82.42652893, 17.16069412], [82.42624664, 17.16069412], [82.42624664, 17.16041756], [82.42597198, 17.16042137], [82.42597198, 17.16012955], [82.42569733, 17.16013908], [82.42569733, 17.15986061], [82.42541504, 17.15986061], [82.42541504, 17.15958405], [82.42485809, 17.15958405], [82.42485809, 17.15930557], [82.42457581, 17.15930748], [82.42457581, 17.15903091], [82.42430878, 17.15903091], [82.42430878, 17.15875053], [82.42402649, 17.15875053], [82.42402649, 17.15847015], [82.42375183, 17.15847206], [82.42375183, 17.15819359], [82.42346954, 17.15819359], [82.42346954, 17.15791893], [82.42318726, 17.15792084], [82.42318726, 17.15764046], [82.42292786, 17.15764046], [82.42292786, 17.15736008], [82.42263794, 17.15736198], [82.42263794, 17.15708351], [82.42236328, 17.15709114], [82.42236328, 17.15681076], [82.42208099, 17.15681076], [82.42208099, 17.15653038], [82.42180634, 17.15653038], [82.42180634, 17.15625], [82.42151642, 17.15625], [82.42151642, 17.15596962], [82.42097473, 17.15597153], [82.42097473, 17.15541649], [82.42069244, 17.1554203], [82.42069244, 17.15513992], [82.42041779, 17.15513992], [82.42041779, 17.15485954], [82.4201355, 17.15486145], [82.4201355, 17.15458488], [82.41986084, 17.15458488], [82.41986084, 17.15430641], [82.41958618, 17.15431976], [82.41958618, 17.15402985], [82.41902924, 17.15402985], [82.41902924, 17.15347099], [82.41874695, 17.15347481], [82.41874695, 17.15319252], [82.41847229, 17.15319252], [82.41847229, 17.15263939], [82.41819763, 17.15263939], [82.41819763, 17.15236092], [82.41791534, 17.15236092], [82.41791534, 17.15208244], [82.4173584, 17.15208244], [82.4173584, 17.15180588], [82.41680145, 17.15180969], [82.41680145, 17.15153122], [82.41652679, 17.15153122], [82.41652679, 17.15125275], [82.41625214, 17.15125275], [82.41625214, 17.15096092], [82.41596985, 17.15097237], [82.41596985, 17.15069389], [82.41569519, 17.15069389], [82.41569519, 17.15041733], [82.4154129, 17.15042114], [82.4154129, 17.15014267], [82.41513824, 17.15014267], [82.41513824, 17.14986038], [82.41485596, 17.14986038], [82.41485596, 17.14958191], [82.41402435, 17.14958382], [82.41402435, 17.14902687], [82.41356659, 17.14902687], [82.41319275, 17.14903259], [82.41319275, 17.14875031], [82.41291809, 17.14875031], [82.41291809, 17.14847183], [82.4126358, 17.14847183], [82.4126358, 17.14819527], [82.41236115, 17.14819527], [82.41236115, 17.14791679], [82.41208649, 17.14792252], [82.41208649, 17.14763832], [82.41179657, 17.14763832], [82.41179657, 17.14735985], [82.41152954, 17.14736176], [82.41152954, 17.14708328], [82.41124725, 17.14708328], [82.41124725, 17.14680481], [82.4109726, 17.14680481], [82.4109726, 17.14652824], [82.41069794, 17.14652824], [82.41069794, 17.14624977], [82.41041565, 17.14624977], [82.41041565, 17.1459713], [82.41014099, 17.1459713], [82.41014099, 17.14569473], [82.4098587, 17.14569473], [82.4098587, 17.14541626], [82.40957642, 17.14541817], [82.40957642, 17.14514923], [82.40930176, 17.14514923], [82.40930176, 17.14486122], [82.4090271, 17.14486122], [82.4090271, 17.14458084], [82.40875244, 17.14458275], [82.40875244, 17.14430618], [82.40847015, 17.14430809], [82.40847015, 17.14402962], [82.40820313, 17.14402962], [82.40820313, 17.14375114], [82.40791321, 17.14375114], [82.40791321, 17.14347076], [82.40763855, 17.14347267], [82.40763855, 17.1431942], [82.4070816, 17.1431942], [82.4070816, 17.14291763], [82.40680695, 17.14291954], [82.40680695, 17.14264107], [82.40651703, 17.14264107], [82.40651703, 17.14236069], [82.40625, 17.14236069], [82.40625, 17.14180946], [82.40598297, 17.14180946], [82.40598297, 17.14153099], [82.40569305, 17.14153099], [82.40569305, 17.14125061], [82.4054184, 17.14125061], [82.4054184, 17.14097023], [82.40513611, 17.14097214], [82.40513611, 17.14069557], [82.40486145, 17.14069557], [82.40486145, 17.14013863], [82.40458679, 17.14014053], [82.40458679, 17.13986015], [82.4043045, 17.13986206], [82.4043045, 17.13958549], [82.40374756, 17.13958549], [82.40374756, 17.13930321], [82.4034729, 17.13931084], [82.4034729, 17.13902283], [82.40291595, 17.13902855], [82.40291595, 17.13875008], [82.4026413, 17.13875008], [82.4026413, 17.1384697], [82.40208435, 17.1384716], [82.40208435, 17.13819313], [82.40180206, 17.13820076], [82.40180206, 17.13792038], [82.40125275, 17.13792038], [82.40125275, 17.13764191], [82.40097046, 17.13764191], [82.40097046, 17.13735962], [82.40041351, 17.13736153], [82.40041351, 17.13708115], [82.40013885, 17.13708115], [82.40013885, 17.13680649], [82.39958191, 17.1368103], [82.39958191, 17.13653183], [82.39930725, 17.13653183], [82.39930725, 17.13624954], [82.39901733, 17.13624954], [82.39901733, 17.13569069], [82.39875031, 17.1356945], [82.39875031, 17.13541603], [82.39848328, 17.13542175], [82.39848328, 17.13513947], [82.39819336, 17.13513947], [82.39819336, 17.13485909], [82.3979187, 17.13485909], [82.3979187, 17.13431168], [82.39763641, 17.13431168], [82.39763641, 17.13402939], [82.39736176, 17.13402939], [82.39736176, 17.13375092], [82.3970871, 17.13375092], [82.3970871, 17.13347054], [82.39680481, 17.13347244], [82.39680481, 17.1329174], [82.39653015, 17.13291931], [82.39653015, 17.13264084], [82.39624786, 17.13264084], [82.39624786, 17.13236046], [82.39597321, 17.13236046], [82.39597321, 17.13207817], [82.39569092, 17.13208389], [82.39569092, 17.13180542], [82.39541626, 17.13181114], [82.39541626, 17.13153076], [82.3951416, 17.13153076], [82.3951416, 17.13125038], [82.39485931, 17.13125038], [82.39485931, 17.13097], [82.39430237, 17.13097191], [82.39430237, 17.13069534], [82.39402771, 17.13070107], [82.39402771, 17.13042068], [82.39375305, 17.13042068], [82.39375305, 17.13014984], [82.39347076, 17.13014984], [82.39347076, 17.12985992], [82.39319611, 17.12986183], [82.39319611, 17.12958336], [82.39291382, 17.12958336], [82.39291382, 17.12930679], [82.39263916, 17.12930679], [82.39263916, 17.12902832], [82.39235687, 17.12903023], [82.39235687, 17.12874985], [82.39208221, 17.12874985], [82.39208221, 17.12846947], [82.39180756, 17.12847137], [82.39180756, 17.12819672], [82.39152527, 17.12819672], [82.39152527, 17.12791443], [82.39125061, 17.12792015], [82.39125061, 17.12763977], [82.39097595, 17.12763977], [82.39097595, 17.12735939], [82.39069366, 17.1273613], [82.39069366, 17.12708473], [82.39041901, 17.12708473], [82.39041901, 17.12652779], [82.39013672, 17.12652969], [82.39013672, 17.12625122], [82.38986206, 17.12625122], [82.38986206, 17.12569046], [82.38930511, 17.12569237], [82.38930511, 17.1254158], [82.38903046, 17.12541962], [82.38903046, 17.12514114], [82.38874817, 17.12514114], [82.38874817, 17.12486076], [82.38846588, 17.12486076], [82.38846588, 17.12458038], [82.38819122, 17.12458229], [82.38819122, 17.12430573], [82.38764191, 17.12430954], [82.38764191, 17.12401962], [82.38735962, 17.12402725], [82.38735962, 17.12375069], [82.38707733, 17.12375069], [82.38707733, 17.12347031], [82.38680267, 17.12347031], [82.38680267, 17.12319374], [82.38652802, 17.12319374], [82.38652802, 17.12291718], [82.38625336, 17.1229229], [82.38625336, 17.12264252], [82.38597107, 17.12264252], [82.38597107, 17.12236023], [82.38540649, 17.12236023], [82.38540649, 17.12208176], [82.38513947, 17.12208366], [82.38513947, 17.12180519], [82.38485718, 17.12181282], [82.38485718, 17.12153244], [82.38458252, 17.12153244], [82.38458252, 17.12125015], [82.38430786, 17.12125015], [82.38430786, 17.12098122], [82.3840332, 17.12098122], [82.3840332, 17.12070084], [82.38375092, 17.12070084], [82.38375092, 17.12041855], [82.383461, 17.12041855], [82.383461, 17.12013817], [82.38318634, 17.12013817], [82.38318634, 17.1198597], [82.38291931, 17.1198616], [82.38291931, 17.11958313], [82.38263702, 17.11958313], [82.38263702, 17.11930466], [82.38208008, 17.11930466], [82.38208008, 17.11902809], [82.38181305, 17.11902809], [82.38181305, 17.11874962], [82.38153076, 17.11874962], [82.38153076, 17.11847115], [82.38124847, 17.11847305], [82.38124847, 17.11819458], [82.38097382, 17.11819458], [82.38097382, 17.11791611], [82.38069153, 17.11791992], [82.38069153, 17.11763954], [82.38041687, 17.11763954], [82.38041687, 17.11736107], [82.38014221, 17.11736107], [82.38014221, 17.11708069], [82.37985992, 17.1170826], [82.37985992, 17.11680794], [82.3795929, 17.11680984], [82.3795929, 17.11652946], [82.37930298, 17.11652946], [82.37930298, 17.11597061], [82.37902832, 17.11597252], [82.37902832, 17.11569595], [82.37875366, 17.11569595], [82.37875366, 17.11541748], [82.37847137, 17.11541939], [82.37847137, 17.11514091], [82.37819672, 17.11514091], [82.37819672, 17.114851], [82.37791443, 17.11486053], [82.37791443, 17.11458588], [82.37735748, 17.11458588], [82.37735748, 17.11430359], [82.37708282, 17.11431122], [82.37708282, 17.11403084], [82.37680817, 17.11403084], [82.37680817, 17.11375046], [82.37652588, 17.11375046], [82.37652588, 17.11347008], [82.37625122, 17.11347389], [82.37625122, 17.11319542], [82.37596893, 17.1131897], [82.37596893, 17.11291695], [82.37568665, 17.11292076], [82.37568665, 17.11264038], [82.37541962, 17.11264038], [82.37541962, 17.11236], [82.37513733, 17.11236382], [82.37513733, 17.11208153], [82.37486267, 17.11208153], [82.37486267, 17.11180305], [82.37458801, 17.11181068], [82.37458801, 17.1115303], [82.37431335, 17.1115303], [82.37431335, 17.11124992], [82.37403107, 17.11124992], [82.37403107, 17.11096954], [82.37374878, 17.11097145], [82.37374878, 17.11069489], [82.37319183, 17.11069489], [82.37319183, 17.11041641], [82.37291718, 17.11042023], [82.37291718, 17.11013985], [82.37264252, 17.11013985], [82.37264252, 17.10985947], [82.37236023, 17.10986137], [82.37236023, 17.1095829], [82.37208557, 17.1095829], [82.37208557, 17.10930634], [82.37180328, 17.10931015], [82.37180328, 17.10874939], [82.371521, 17.10874939], [82.371521, 17.10847092], [82.37097168, 17.10847282], [82.37097168, 17.10819435], [82.37041473, 17.10819435], [82.37041473, 17.10791588], [82.37014008, 17.1079216], [82.37014008, 17.10736084], [82.36985779, 17.10736084], [82.36985779, 17.10708046], [82.36958313, 17.10708427], [82.36958313, 17.1068058], [82.36902618, 17.10681152], [82.36902618, 17.10652924], [82.36875153, 17.10652924], [82.36875153, 17.10625076], [82.36763763, 17.10625076], [82.36763763, 17.10597992], [82.36736298, 17.10597992], [82.36736298, 17.10625076], [82.36708069, 17.10625076], [82.36708069, 17.10652924], [82.36653137, 17.10652924], [82.36653137, 17.10681152], [82.36624908, 17.1068058], [82.36624908, 17.10708427], [82.3659668, 17.10708046], [82.3659668, 17.10763931], [82.36569214, 17.10763931], [82.36569214, 17.10819435], [82.36541748, 17.10819435], [82.36541748, 17.10847282], [82.36514282, 17.10847092], [82.36514282, 17.11013985], [82.36541748, 17.11013985], [82.36541748, 17.11042023], [82.36597443, 17.11041641], [82.36597443, 17.11069489], [82.36624908, 17.11069489], [82.36624908, 17.11097145], [82.36653137, 17.11096954], [82.36653137, 17.11124992], [82.36680603, 17.11124992], [82.36680603, 17.1115303], [82.36708069, 17.1115303], [82.36708069, 17.11181068], [82.36736298, 17.11180305], [82.36736298, 17.11208153], [82.36763763, 17.11208153], [82.36763763, 17.11236382], [82.36791992, 17.11236], [82.36791992, 17.11292076], [82.36819458, 17.11291695], [82.36819458, 17.11347389], [82.36846161, 17.11347008], [82.36846161, 17.11736107], [82.36875153, 17.11736107], [82.36875153, 17.11791992], [82.36902618, 17.11791992], [82.36902618, 17.11874962], [82.36846161, 17.11874962], [82.36846161, 17.11847115], [82.36819458, 17.11847305], [82.36819458, 17.11819458], [82.36791992, 17.11819458], [82.36791992, 17.11736107], [82.36763763, 17.11736107], [82.36763763, 17.11375046], [82.36736298, 17.11375046], [82.36736298, 17.11347008], [82.36708069, 17.11347389], [82.36708069, 17.11319542], [82.36680603, 17.1131897], [82.36680603, 17.11263847], [82.36653137, 17.11264038], [82.36653137, 17.11236], [82.36624908, 17.11236382], [82.36624908, 17.11208153], [82.36541748, 17.11208153], [82.36541748, 17.11180305], [82.36514282, 17.11181068], [82.36514282, 17.1115303], [82.36486053, 17.1115303], [82.36486053, 17.11124992], [82.36458588, 17.11124992], [82.36458588, 17.11096954], [82.36430359, 17.11097145], [82.36430359, 17.11069489], [82.36402893, 17.11069489], [82.36402893, 17.11041641], [82.36374664, 17.11042023], [82.36374664, 17.10985947], [82.36347198, 17.10986137], [82.36347198, 17.10930634], [82.36319733, 17.10931015], [82.36319733, 17.10763931], [82.36347198, 17.10763931], [82.36347198, 17.10736084], [82.36402893, 17.10736084], [82.36402893, 17.10708046], [82.36430359, 17.10708237], [82.36430359, 17.1068058], [82.36458588, 17.10681152], [82.36458588, 17.10652924], [82.36486053, 17.10652924], [82.36486053, 17.10625076], [82.36514282, 17.10625076], [82.36513519, 17.10597229], [82.36541748, 17.10597992], [82.36541748, 17.1056881], [82.36569214, 17.10569382], [82.36569214, 17.10458374], [82.36541748, 17.10458374], [82.36541748, 17.10430527], [82.36514282, 17.10430908], [82.36514282, 17.10403061], [82.36486053, 17.10403061], [82.36486053, 17.10375023], [82.36458588, 17.10375023], [82.36458588, 17.10346985], [82.36430359, 17.10347176], [82.36430359, 17.10319519], [82.36374664, 17.10320091], [82.36374664, 17.102911], [82.36347198, 17.10291672], [82.36347198, 17.10263824], [82.36292267, 17.10264015], [82.36292267, 17.10235977], [82.36264038, 17.10236168], [82.36264038, 17.10180664], [82.36235809, 17.10180664], [82.36235809, 17.10152817], [82.36207581, 17.10153008], [82.36207581, 17.10124969], [82.36180878, 17.10124969], [82.36180878, 17.10097122], [82.36152649, 17.10097313], [82.36152649, 17.10069656], [82.36096954, 17.10069656], [82.36096954, 17.10041428], [82.36068726, 17.10042], [82.36068726, 17.0998497], [82.36042023, 17.09986115], [82.36042023, 17.0993042], [82.36013794, 17.09930992], [82.36013794, 17.09902954], [82.35986328, 17.09902954], [82.35986328, 17.09875107], [82.35958099, 17.09875107], [82.35958099, 17.09847069], [82.35930634, 17.0984745], [82.35930634, 17.09819221], [82.35902405, 17.09819221], [82.35902405, 17.09791756], [82.35874939, 17.09791946], [82.35874939, 17.09708023], [82.35847473, 17.09708214], [82.35847473, 17.09680557], [82.35819244, 17.09680939], [82.35819244, 17.09653282], [82.35791779, 17.09653282], [82.35791779, 17.09625053], [82.3576355, 17.09625053], [82.3576355, 17.09597015], [82.35736084, 17.09597015], [82.35736084, 17.09569359], [82.35708618, 17.09569359], [82.35708618, 17.09541702], [82.35679626, 17.09542274], [82.35679626, 17.09514046], [82.35652161, 17.09514046], [82.35652161, 17.09486008], [82.35624695, 17.09486008], [82.35624695, 17.09458351], [82.35597229, 17.09458351], [82.35597229, 17.09430504], [82.35541534, 17.09430504], [82.35541534, 17.09458351], [82.35514069, 17.09458351], [82.35514069, 17.09486008], [82.3548584, 17.09486008], [82.3548584, 17.09569359], [82.35457611, 17.09569168], [82.35457611, 17.09625053], [82.35430908, 17.09625053], [82.35430908, 17.09653282], [82.35402679, 17.09653282], [82.35402679, 17.09680939], [82.35375214, 17.09680557], [82.35375214, 17.09708214], [82.35346222, 17.09708023], [82.35346222, 17.0976429], [82.35320282, 17.0976429], [82.35320282, 17.09791946], [82.3529129, 17.09791756], [82.3529129, 17.09819221], [82.35152435, 17.09819221], [82.35152435, 17.09791756], [82.35124969, 17.09791946], [82.35124969, 17.09736061], [82.35151672, 17.09736061], [82.35151672, 17.09708023], [82.3520813, 17.09708214], [82.3520813, 17.09680557], [82.35235596, 17.09680939], [82.35235596, 17.09653282], [82.35263824, 17.09653282], [82.35263824, 17.09625053], [82.3529129, 17.09625053], [82.3529129, 17.09569168], [82.35319519, 17.09569359], [82.35319519, 17.09374809], [82.3529129, 17.09374809], [82.3529129, 17.09320068], [82.35263824, 17.09320068], [82.35263824, 17.09263992], [82.35235596, 17.09263992], [82.35235596, 17.09235954], [82.3520813, 17.09236145], [82.3520813, 17.09208298], [82.35180664, 17.09208298], [82.35180664, 17.09152985], [82.35151672, 17.09152985], [82.35151672, 17.09124947], [82.35124969, 17.09124947], [82.35124969, 17.09069061], [82.35097504, 17.09069443], [82.35097504, 17.09013939], [82.35069275, 17.09013939], [82.35069275, 17.08986092], [82.3501358, 17.08986092], [82.3501358, 17.08958054], [82.34986115, 17.08958244], [82.34986115, 17.08930779], [82.34958649, 17.08930969], [82.34958649, 17.08903122], [82.34929657, 17.08903122], [82.34929657, 17.08875084], [82.34902954, 17.08875084], [82.34902954, 17.08847046], [82.34874725, 17.08847237], [82.34874725, 17.0881958], [82.34819794, 17.0881958], [82.34819794, 17.08791733], [82.34791565, 17.08791733], [82.34791565, 17.08763885], [82.34764099, 17.08764076], [82.34764099, 17.08736038], [82.3473587, 17.08736038], [82.3473587, 17.08708], [82.34708405, 17.08708572], [82.34708405, 17.08680344], [82.34680176, 17.08681107], [82.34680176, 17.08653069], [82.3465271, 17.08653069], [82.3465271, 17.08625031], [82.34625244, 17.08625031], [82.34625244, 17.08596992], [82.34597015, 17.08597374], [82.34597015, 17.08569336], [82.34541321, 17.08570099], [82.34541321, 17.08542061], [82.34513855, 17.08542061], [82.34513855, 17.08514023], [82.34485626, 17.08514023], [82.34485626, 17.08485031], [82.3445816, 17.08486366], [82.3445816, 17.08458138], [82.34430695, 17.08458138], [82.34430695, 17.08430481], [82.34402466, 17.08430481], [82.34402466, 17.08402824], [82.34375, 17.08403015], [82.34375, 17.08374977], [82.34347534, 17.08374977], [82.34347534, 17.0834713], [82.34319305, 17.0834713], [82.34319305, 17.08319473], [82.3429184, 17.08319473], [82.3429184, 17.08291626], [82.34263611, 17.08292007], [82.34263611, 17.08263969], [82.34236145, 17.08263969], [82.34236145, 17.08235931], [82.34208679, 17.08235931], [82.34208679, 17.08208084], [82.3418045, 17.08208275], [82.3418045, 17.08180618], [82.34152222, 17.0818119], [82.34152222, 17.08152962], [82.34124756, 17.08152962], [82.34124756, 17.08124924], [82.3409729, 17.08124924], [82.3409729, 17.08097076], [82.34069824, 17.08097267], [82.34069061, 17.0806942], [82.34041595, 17.0806942], [82.34041595, 17.08041763], [82.3401413, 17.08042145], [82.3401413, 17.08013916], [82.33985901, 17.08013916], [82.33985901, 17.07986069], [82.33957672, 17.07986069], [82.33957672, 17.07958031], [82.33930206, 17.07958412], [82.33930206, 17.07930565], [82.3390274, 17.07930756], [82.3390274, 17.07902908], [82.33875275, 17.07902908], [82.33875275, 17.07875061], [82.33847046, 17.07875061], [82.33847046, 17.07847214], [82.3381958, 17.07847214], [82.3381958, 17.07819366], [82.33791351, 17.07819366], [82.33791351, 17.0779171], [82.33763885, 17.07792091], [82.33763885, 17.07764053], [82.33735657, 17.07764053], [82.33735657, 17.07736015], [82.33708191, 17.07736206], [82.33708191, 17.07708359], [82.33652496, 17.07708359], [82.33652496, 17.07680511], [82.33625031, 17.07681084], [82.33625031, 17.07653046], [82.33598328, 17.07653046], [82.33598328, 17.07625008], [82.33569336, 17.07625008], [82.33569336, 17.0759697], [82.3354187, 17.0759716], [82.3354187, 17.07569695], [82.33513641, 17.07570076], [82.33513641, 17.07542038], [82.33486176, 17.07542038], [82.33486176, 17.07485962], [82.3345871, 17.07486153], [82.3345871, 17.07458305], [82.33430481, 17.07458305], [82.33430481, 17.07430649], [82.33403015, 17.0743103], [82.33403015, 17.07402992], [82.33374786, 17.07402992], [82.33374786, 17.07374954], [82.33319092, 17.07374954], [82.33319092, 17.07347107], [82.33291626, 17.07347488], [82.33291626, 17.0731926], [82.3326416, 17.0731926], [82.3326416, 17.07291412], [82.33235931, 17.07291412], [82.33235931, 17.07263947], [82.33180237, 17.07263947], [82.33180237, 17.0723629], [82.33152771, 17.0723629], [82.33152771, 17.07180977], [82.33125305, 17.07180977], [82.33125305, 17.07152939], [82.33097076, 17.07152939], [82.33097076, 17.07125282], [82.33069611, 17.07125282], [82.33069611, 17.07097054], [82.33041382, 17.07097435], [82.33041382, 17.07069206], [82.33013916, 17.07069206], [82.33013916, 17.0704174], [82.32985687, 17.07042122], [82.32985687, 17.07014275], [82.32958221, 17.07014275], [82.32958221, 17.06987], [82.32930756, 17.06987], [82.32930756, 17.06958008], [82.32902527, 17.06958389], [82.32902527, 17.06930542], [82.32875061, 17.06931114], [82.32875061, 17.06903267], [82.32847595, 17.06903267], [82.32847595, 17.06875038], [82.32818604, 17.06875038], [82.32818604, 17.06847191], [82.32791901, 17.06847191], [82.32791901, 17.06819534], [82.32763672, 17.06820107], [82.32763672, 17.06792259], [82.32736206, 17.06792259], [82.32736206, 17.0676384], [82.32707977, 17.0676384], [82.32707977, 17.06735992], [82.32680511, 17.06736183], [82.32680511, 17.06708336], [82.32653046, 17.06708336], [82.32653046, 17.06680489], [82.32624817, 17.06681061], [82.32624817, 17.06652832], [82.32596588, 17.06652832], [82.32596588, 17.06624985], [82.32569122, 17.06624985], [82.32569122, 17.06596947], [82.32541656, 17.06597137], [82.32541656, 17.06569481], [82.32514191, 17.06569481], [82.32514191, 17.06541634], [82.32485962, 17.06541824], [82.32485962, 17.06513977], [82.32457733, 17.06513977], [82.32457733, 17.06485939], [82.32430267, 17.0648613], [82.32430267, 17.06458282], [82.32402802, 17.06458282], [82.32402802, 17.06430626], [82.32375336, 17.06430817], [82.32375336, 17.06402969], [82.3234787, 17.06402969], [82.3234787, 17.06373978], [82.32319641, 17.06374931], [82.32319641, 17.06347275], [82.32291412, 17.06347275], [82.32291412, 17.06291771], [82.32263947, 17.06291962], [82.32263947, 17.06264114], [82.32235718, 17.06264114], [82.32235718, 17.06236076], [82.32208252, 17.06236076], [82.32208252, 17.06208038], [82.32180786, 17.0620842], [82.32180786, 17.06180763], [82.3215332, 17.06180954], [82.3215332, 17.06153107], [82.32125092, 17.06153107], [82.32125092, 17.06125069], [82.32096863, 17.06125069], [82.32096863, 17.06097031], [82.32069397, 17.06097221], [82.32069397, 17.06069565], [82.32041931, 17.06069565], [82.32041931, 17.06041718], [82.32013702, 17.06042099], [82.32013702, 17.06014061], [82.31986237, 17.06014061], [82.31986237, 17.05986023], [82.31958008, 17.05986023], [82.31958008, 17.05957985], [82.31930542, 17.05958557], [82.31930542, 17.05930328], [82.31903076, 17.05931091], [82.31903076, 17.05875015], [82.31874847, 17.05875015], [82.31874847, 17.05846977], [82.31847382, 17.05847168], [82.31847382, 17.05819321], [82.31819153, 17.05820084], [82.31819153, 17.05792999], [82.31791687, 17.05792999], [82.31791687, 17.05764008], [82.31764221, 17.05764008], [82.31764221, 17.0573597], [82.31735992, 17.05736351], [82.31735992, 17.05708122], [82.31708527, 17.05708122], [82.31708527, 17.05680466], [82.31680298, 17.05680466], [82.31680298, 17.05652809], [82.31652832, 17.05653191], [82.31652832, 17.05624962], [82.31624603, 17.05624962], [82.31624603, 17.05597115], [82.31597137, 17.05597115], [82.31597137, 17.05569458], [82.31569672, 17.05569458], [82.31569672, 17.05513954], [82.3154068, 17.05513954], [82.3154068, 17.05487061], [82.31513977, 17.05487061], [82.31513977, 17.05458069], [82.31485748, 17.0545826], [82.31485748, 17.05430603], [82.31458282, 17.05431175], [82.31458282, 17.05402946], [82.31430817, 17.05402946], [82.31430817, 17.05374908], [82.31402588, 17.05374908], [82.31402588, 17.05347061], [82.31375122, 17.05347252], [82.31375122, 17.05319405], [82.31346893, 17.05319405], [82.31346893, 17.05291748], [82.31318665, 17.0529213], [82.31318665, 17.05236053], [82.31291962, 17.05236053], [82.31291962, 17.05208015], [82.31263733, 17.05208397], [82.31263733, 17.0518055], [82.31236267, 17.0518055], [82.31236267, 17.05152893], [82.31208038, 17.05153084], [82.31208038, 17.05125046], [82.31180573, 17.05125046], [82.31180573, 17.05097198], [82.31153107, 17.05097198], [82.31153107, 17.05069542], [82.31124878, 17.0506897], [82.31124878, 17.05041885], [82.31096649, 17.05042076], [82.31096649, 17.05014038], [82.31069183, 17.05014038], [82.31069183, 17.04957962], [82.31041718, 17.04958344], [82.31041718, 17.04930687], [82.31014252, 17.04931068], [82.31014252, 17.0490303], [82.30986023, 17.0490303], [82.30986023, 17.04874039], [82.30958557, 17.04874992], [82.30958557, 17.04847145], [82.30930328, 17.04847145], [82.30930328, 17.04819679], [82.30902863, 17.04819679], [82.30902863, 17.04791641], [82.30874634, 17.04792023], [82.30874634, 17.04763985], [82.30847168, 17.04763985], [82.30847168, 17.04708099], [82.30819702, 17.04708481], [82.30819702, 17.04680634], [82.3079071, 17.04681015], [82.3079071, 17.04652977], [82.30764008, 17.04652977], [82.30764008, 17.04624939], [82.30735779, 17.04624939], [82.30735779, 17.04597092], [82.30708313, 17.04597473], [82.30708313, 17.04569244], [82.30680847, 17.04570007], [82.30680847, 17.04514122], [82.30652618, 17.04514122], [82.30652618, 17.04486084], [82.30625153, 17.04486084], [82.30625153, 17.04458046], [82.30596924, 17.04458237], [82.30596924, 17.0443058], [82.30568695, 17.04430962], [82.30568695, 17.04403114], [82.30541229, 17.04403114], [82.30541229, 17.04347038], [82.30513763, 17.04347038], [82.30513763, 17.04319382], [82.30486298, 17.04319382], [82.30486298, 17.04291725], [82.30458069, 17.0429306], [82.30458069, 17.04264259], [82.30430603, 17.04264259], [82.30430603, 17.04236031], [82.30403137, 17.04236031], [82.30403137, 17.04208183], [82.30374908, 17.04208374], [82.30374908, 17.0415287], [82.3034668, 17.04153252], [82.3034668, 17.04125023], [82.30319214, 17.04125023], [82.30319214, 17.04096985], [82.30291748, 17.04097176], [82.30291748, 17.04069519], [82.30264282, 17.04070091], [82.30264282, 17.04013824], [82.30236816, 17.04013824], [82.30236816, 17.03985977], [82.30208588, 17.03986168], [82.30208588, 17.03930473], [82.30180359, 17.03930473], [82.30180359, 17.03874969], [82.30152893, 17.03874969], [82.30152893, 17.03847122], [82.30124664, 17.03847313], [82.30124664, 17.03791618], [82.30097198, 17.03791809], [82.30097198, 17.03763962], [82.30069733, 17.03763962], [82.30069733, 17.03708076], [82.30041504, 17.03708267], [82.30041504, 17.03652763], [82.30014038, 17.03652954], [82.30014038, 17.03625107], [82.29985809, 17.03625107], [82.29985809, 17.03569031], [82.29958344, 17.03569412], [82.29958344, 17.03541756], [82.29930878, 17.03541946], [82.29930878, 17.03486061], [82.29902649, 17.03486061], [82.29902649, 17.03430939], [82.29875183, 17.03430939], [82.29875183, 17.03403091], [82.29846954, 17.03403091], [82.29846954, 17.03347015], [82.29819489, 17.03347206], [82.29819489, 17.0331955], [82.29792023, 17.0331955], [82.29792023, 17.03291702], [82.29763794, 17.03292084], [82.29763794, 17.03265953], [82.29763794, 17.03236389], [82.29736328, 17.03236389], [82.29736328, 17.03180313], [82.29708099, 17.03181076], [82.29708099, 17.03125], [82.29680634, 17.03125], [82.29680634, 17.03096962], [82.29652405, 17.03097153], [82.29652405, 17.03041649], [82.29624176, 17.0304203], [82.29624176, 17.02985954], [82.29597473, 17.02986145], [82.29597473, 17.02958107], [82.29569244, 17.02958107], [82.29569244, 17.02902794], [82.29541779, 17.02903175], [82.29541779, 17.02874947], [82.2951355, 17.02874947], [82.2951355, 17.02819443], [82.29486084, 17.02819443], [82.29486084, 17.02763939], [82.29458618, 17.02763939], [82.29458618, 17.02736092], [82.29429626, 17.02736092], [82.29429626, 17.0268116], [82.29402924, 17.0268116], [82.29402924, 17.02625084], [82.29374695, 17.02625084], [82.29374695, 17.02568817], [82.29347229, 17.02569389], [82.29347229, 17.02513885], [82.29319763, 17.02514076], [82.29319763, 17.02431107], [82.29292297, 17.02431107], [82.29292297, 17.02375031], [82.29264069, 17.02375031], [82.29264069, 17.02292061], [82.2923584, 17.02292061], [82.2923584, 17.02235985], [82.29208374, 17.02236176], [82.29208374, 17.02180672], [82.29180908, 17.02180672], [82.29180908, 17.0209713], [82.29152679, 17.0209713], [82.29152679, 17.02041435], [82.29125214, 17.02042007], [82.29125214, 17.01986122], [82.29096985, 17.01986122], [82.29096985, 17.01931], [82.29070282, 17.01931], [82.29070282, 17.01847076], [82.2904129, 17.01847458], [82.2904129, 17.01791763], [82.29013824, 17.01791954], [82.29013824, 17.01764107], [82.28985596, 17.01764107], [82.28985596, 17.01708031], [82.2895813, 17.01708221], [82.2895813, 17.01652718], [82.28930664, 17.0165329], [82.28930664, 17.01597023], [82.28902435, 17.01597023], [82.28902435, 17.0154171], [82.28874969, 17.01542282], [82.28874969, 17.01486015], [82.28847504, 17.01486015], [82.28847504, 17.01458359], [82.28819275, 17.01458359], [82.28819275, 17.01402855], [82.28791809, 17.01402855], [82.28791809, 17.01374817], [82.2876358, 17.01374817], [82.2876358, 17.0134697], [82.28736115, 17.0134716], [82.28736115, 17.01263809], [82.28708649, 17.01263809], [82.28708649, 17.01208305], [82.2868042, 17.01208305], [82.2868042, 17.01152992], [82.28652954, 17.01152992], [82.28652954, 17.01097107], [82.28624725, 17.01097298], [82.28624725, 17.01041794], [82.2859726, 17.01041985], [82.2859726, 17.00986099], [82.28569794, 17.00986099], [82.28569794, 17.00902939], [82.28542328, 17.00902939], [82.28542328, 17.00819016], [82.28514099, 17.00819588], [82.28514099, 17.00736046], [82.2848587, 17.00736046], [82.2848587, 17.00653076], [82.28457642, 17.00653076], [82.28457642, 17.00570107], [82.28430176, 17.00570107], [82.28430176, 17.00457954], [82.2840271, 17.00458145], [82.2840271, 17.00374985], [82.28375244, 17.00374985], [82.28375244, 17.00292015], [82.28347015, 17.00292015], [82.28347015, 17.00235939], [82.2831955, 17.00235939], [82.2831955, 17.00124931], [82.28291321, 17.00124931], [82.28291321, 17.00042152], [82.28263855, 17.00042152], [82.28263855, 17.00013924], [82.28235626, 17.00013924], [82.28235626, 16.99986076], [82.28235626, 16.99958038], [82.2820816, 16.9995842], [82.2820816, 16.99930573], [82.28180695, 16.99930763], [82.28180695, 16.99902916], [82.28151703, 16.99902916], [82.28151703, 16.99875069], [82.28124237, 16.99875069], [82.28124237, 16.99847031], [82.28097534, 16.99847221], [82.28097534, 16.99819374], [82.28069305, 16.99819374], [82.28069305, 16.99791718], [82.2804184, 16.99791908], [82.2804184, 16.99764824], [82.28013611, 16.99764824], [82.28013611, 16.99736023], [82.27986145, 16.99736023], [82.27986145, 16.99625015], [82.27958679, 16.99625015], [82.27958679, 16.99514008], [82.27929688, 16.99514008], [82.27929688, 16.99459076], [82.27902985, 16.99459076], [82.27902985, 16.99403], [82.27874756, 16.99403], [82.27874756, 16.99319077], [82.2784729, 16.99319267], [82.2784729, 16.9920845], [82.27819824, 16.9920845], [82.27819824, 16.99093056], [82.27819824, 16.99041748], [82.2784729, 16.99041939], [82.2784729, 16.98931122], [82.27874756, 16.98931122], [82.27874756, 16.98903275], [82.27929688, 16.98903275], [82.27929688, 16.9881916], [82.27958679, 16.98819351], [82.27958679, 16.98791695], [82.27986145, 16.98792267], [82.27986145, 16.98707962], [82.28013611, 16.98708344], [82.28013611, 16.9865284], [82.2804184, 16.9865284], [82.2804184, 16.98624992], [82.28098297, 16.98624992], [82.28097534, 16.98597145], [82.28125, 16.98597145], [82.28125, 16.98513985], [82.28151703, 16.98513985], [82.28151703, 16.98485947], [82.28263855, 16.98486137], [82.28263855, 16.9845829], [82.28347015, 16.9845829], [82.28347015, 16.98430634], [82.28430176, 16.98430634], [82.28430939, 16.9845829], [82.28514099, 16.9845829], [82.28514099, 16.98430634], [82.28542328, 16.98430824], [82.28542328, 16.98402977], [82.28569794, 16.98402977], [82.28569794, 16.98319054], [82.28541565, 16.98319435], [82.28541565, 16.98291779], [82.28514099, 16.98291969], [82.28514099, 16.98265076], [82.28457642, 16.98265076], [82.28457642, 16.98236084], [82.28375244, 16.98236084], [82.28375244, 16.98265076], [82.28291321, 16.98265076], [82.28291321, 16.98291969], [82.28151703, 16.98291969], [82.28151703, 16.98265076], [82.28124237, 16.98265076], [82.28124237, 16.98291969], [82.28069305, 16.98291779], [82.28069305, 16.98347282], [82.27958679, 16.98347092], [82.27958679, 16.98374939], [82.27819824, 16.98374939], [82.27819824, 16.98347092], [82.2776413, 16.98347282], [82.2776413, 16.98319435], [82.27735901, 16.98319435], [82.27735901, 16.98291779], [82.27707672, 16.98291969], [82.27707672, 16.98265076], [82.27680206, 16.98265076], [82.27680206, 16.98236084], [82.2765274, 16.98236084], [82.2765274, 16.98180962], [82.27625275, 16.98180962], [82.27625275, 16.98069], [82.27597046, 16.98069572], [82.27597046, 16.97958565], [82.2756958, 16.97958565], [82.2756958, 16.9770813], [82.27597046, 16.9770813], [82.27597046, 16.97680473], [82.27708435, 16.97680473], [82.27708435, 16.97652817], [82.27958679, 16.97652817], [82.27958679, 16.97680473], [82.28013611, 16.97680473], [82.28013611, 16.9770813], [82.28069305, 16.9770813], [82.28069305, 16.97736359], [82.28263855, 16.97736359], [82.28263855, 16.9770813], [82.28375244, 16.9770813], [82.28375244, 16.97680473], [82.2840271, 16.97680473], [82.2840271, 16.97652817], [82.28375244, 16.97652817], [82.28375244, 16.97569466], [82.2840271, 16.97569466], [82.2840271, 16.97402763], [82.28375244, 16.97403145], [82.28375244, 16.97346115], [82.2831955, 16.9734726], [82.2831955, 16.97319412], [82.28347015, 16.97319412], [82.28347015, 16.97263718], [82.28375244, 16.97263908], [82.28375244, 16.97153091], [82.28347015, 16.97153091], [82.28347015, 16.97125053], [82.2831955, 16.97125053], [82.2831955, 16.97097206], [82.27986145, 16.97097015], [82.27986145, 16.97125053], [82.27819824, 16.97125053], [82.27819824, 16.97097015], [82.27680206, 16.97097015], [82.27680206, 16.97125053], [82.27540588, 16.97125053], [82.27540588, 16.97068977], [82.27513885, 16.97069359], [82.27513885, 16.97041893], [82.27485657, 16.97042084], [82.27485657, 16.97014046], [82.27458191, 16.97014046], [82.27458191, 16.9695797], [82.27430725, 16.96958351], [82.27430725, 16.96930695], [82.27401733, 16.96931076], [82.27401733, 16.96903038], [82.27375031, 16.96903038], [82.27375031, 16.96846962], [82.27347565, 16.96847153], [82.27347565, 16.96791649], [82.27319336, 16.9679203], [82.27319336, 16.96735954], [82.2729187, 16.96736145], [82.2729187, 16.96680641], [82.27263641, 16.96681023], [82.27263641, 16.96624947], [82.27236176, 16.96624947], [82.27236176, 16.96458054], [82.2720871, 16.96458244], [82.2720871, 16.96375275], [82.27179718, 16.96375275], [82.27179718, 16.96292114], [82.27153015, 16.96292114], [82.27153015, 16.96236038], [82.27124786, 16.96236038], [82.27124786, 16.96208191], [82.27097321, 16.96208382], [82.27097321, 16.96180534], [82.27069092, 16.96181107], [82.27069092, 16.96125031], [82.27041626, 16.96125031], [82.27041626, 16.96013832], [82.2701416, 16.96013832], [82.2701416, 16.95902824], [82.26985931, 16.95902824], [82.26985931, 16.95652962], [82.26957703, 16.95652962], [82.26957703, 16.95597076], [82.26930237, 16.95597267], [82.26930237, 16.95430565], [82.26957703, 16.95430946], [82.26957703, 16.95318985], [82.26930237, 16.95319557], [82.26930237, 16.95180321], [82.26902771, 16.95181084], [82.26902771, 16.9509697], [82.26930237, 16.9509716], [82.26930237, 16.95069313], [82.26957703, 16.95070076], [82.26957703, 16.95014191], [82.26985931, 16.95014191], [82.26985931, 16.94958115], [82.2701416, 16.94958115], [82.2701416, 16.94930649], [82.27041626, 16.94928932], [82.27041626, 16.94902802], [82.27069092, 16.94903183], [82.27069092, 16.94874954], [82.27097321, 16.94874954], [82.27097321, 16.94846916], [82.27347565, 16.94847107], [82.27347565, 16.94791603], [82.27375031, 16.94792175], [82.27375031, 16.94763947], [82.27319336, 16.94763947], [82.27319336, 16.94735909], [82.2729187, 16.94735909], [82.2729187, 16.94708061], [82.27263641, 16.94708252], [82.27263641, 16.94680595], [82.27236176, 16.94681168], [82.27236176, 16.94568825], [82.2720871, 16.94569397], [82.2720871, 16.94486046], [82.27179718, 16.94486046], [82.27179718, 16.94403076], [82.27153015, 16.94403076], [82.27153015, 16.94153023], [82.27179718, 16.94153023], [82.27179718, 16.94096947], [82.27153015, 16.94097137], [82.27153015, 16.94041634], [82.27069092, 16.94041634], [82.27069092, 16.94069672], [82.26958466, 16.94069672], [82.26958466, 16.94041634], [82.26930237, 16.94041634], [82.26930237, 16.94013977], [82.26902771, 16.94013977], [82.26902771, 16.93985939], [82.26875305, 16.9398613], [82.26875305, 16.93958473], [82.26847076, 16.93958473], [82.26847076, 16.93930626], [82.26819611, 16.93931007], [82.26819611, 16.93902969], [82.26374817, 16.93902969], [82.26374817, 16.93875122], [82.26346588, 16.93875122], [82.26346588, 16.93847084], [82.26319122, 16.93847466], [82.26319122, 16.93819237], [82.26291656, 16.93819237], [82.26291656, 16.9379158], [82.26264191, 16.93791962], [82.26264191, 16.9378109], [82.26264191, 16.93763924], [82.26207733, 16.93764114], [82.26207733, 16.93734932], [82.26180267, 16.93736076], [82.26180267, 16.93708229], [82.26125336, 16.93708229], [82.26125336, 16.93680573], [82.2590332, 16.93680954], [82.2590332, 16.93653107], [82.25875092, 16.93653107], [82.25875092, 16.93680954], [82.25485992, 16.93680954], [82.25485992, 16.93653107], [82.25402832, 16.93653107], [82.25402832, 16.93625259], [82.25347137, 16.93625259], [82.25347137, 16.93597031], [82.25291443, 16.93597031], [82.25291443, 16.93569374], [82.25235748, 16.93569374], [82.25235748, 16.93541718], [82.25180817, 16.9354229], [82.25180817, 16.93514252], [82.25152588, 16.93514252], [82.25152588, 16.93486023], [82.25096893, 16.93486023], [82.25096893, 16.93458176], [82.25069427, 16.93458366], [82.25069427, 16.93402863], [82.25041962, 16.93402863], [82.25041962, 16.93320084], [82.25013733, 16.93320084], [82.25013733, 16.93208122], [82.24986267, 16.93208313], [82.24986267, 16.93097305], [82.24958038, 16.93097305], [82.24958038, 16.93041611], [82.24903107, 16.93041992], [82.24903107, 16.92958069], [82.24930573, 16.9295826], [82.24930573, 16.92902756], [82.24903107, 16.92902946], [82.24903107, 16.92847061], [82.24930573, 16.92847252], [82.24930573, 16.92791748], [82.24958038, 16.92791939], [82.24958038, 16.92736053], [82.24930573, 16.92736053], [82.24930573, 16.92430305], [82.24958038, 16.92431068], [82.24958038, 16.92346954], [82.24930573, 16.92347145], [82.24930573, 16.92319489], [82.24958038, 16.92319489], [82.24958038, 16.92263794], [82.24986267, 16.92264175], [82.24986267, 16.92226982], [82.24986267, 16.9220829], [82.25013733, 16.9220829], [82.25013733, 16.91875076], [82.24986267, 16.91875076], [82.24986267, 16.91764069], [82.24958038, 16.91764069], [82.24958038, 16.91542053], [82.24986267, 16.91542053], [82.24986267, 16.91485977], [82.25013733, 16.91486168], [82.25013733, 16.91430664], [82.25041962, 16.91430664], [82.25041962, 16.91374969], [82.25068665, 16.91374969], [82.25068665, 16.90930939], [82.25041962, 16.90930939], [82.25041962, 16.90903282], [82.25013733, 16.90903282], [82.25013733, 16.90875244], [82.24986267, 16.90875244], [82.24986267, 16.90819168], [82.24958038, 16.90819359], [82.24958038, 16.90763855], [82.24931335, 16.90764236], [82.24931335, 16.90736961], [82.25013733, 16.90736961], [82.25013733, 16.9070797], [82.25041962, 16.90708351], [82.25041962, 16.90652847], [82.25068665, 16.90652847], [82.25068665, 16.90596962], [82.25096893, 16.90597153], [82.25096893, 16.90569496], [82.25152588, 16.90570068], [82.25152588, 16.9054184], [82.25208282, 16.9054184], [82.25208282, 16.90513992], [82.25263977, 16.90513992], [82.25263977, 16.90485954], [82.25319672, 16.90486145], [82.25319672, 16.90458298], [82.25347137, 16.90458298], [82.25347137, 16.90430641], [82.25375366, 16.90430641], [82.25375366, 16.90402794], [82.25402832, 16.90402985], [82.25402832, 16.90374947], [82.25430298, 16.90374947], [82.25430298, 16.90347099], [82.25458527, 16.9034729], [82.25458527, 16.90319443], [82.25485992, 16.90319443], [82.25485992, 16.90236092], [82.25514221, 16.90236092], [82.25514221, 16.90153122], [82.25541687, 16.90153122], [82.25541687, 16.90069008], [82.25569153, 16.9006958], [82.25569153, 16.90013885], [82.25596619, 16.90014076], [82.25596619, 16.89875031], [82.25624847, 16.89875031], [82.25624847, 16.89792061], [82.25653076, 16.89792061], [82.25653076, 16.89707947], [82.25680542, 16.89708138], [82.25680542, 16.89624977], [82.25708008, 16.89624977], [82.25707245, 16.8951416], [82.25736237, 16.8951416], [82.25736237, 16.89263916], [82.25763702, 16.89263916], [82.25763702, 16.89236069], [82.25736237, 16.89236069], [82.25736237, 16.89180756], [82.25707245, 16.89180756], [82.25707245, 16.89125061], [82.25680542, 16.89125061], [82.25680542, 16.88902855], [82.25707245, 16.88903046], [82.25707245, 16.88820076], [82.25681305, 16.88820076], [82.25681305, 16.88764], [82.25653076, 16.88764], [82.25653076, 16.88735962], [82.25624847, 16.88736153], [82.25624847, 16.88652802], [82.25680542, 16.88652802], [82.25681305, 16.88680077], [82.25736237, 16.88680649], [82.25736237, 16.88708305], [82.25763702, 16.88708305], [82.25763702, 16.88736153], [82.25791931, 16.88735962], [82.25791931, 16.88764], [82.25818634, 16.88764], [82.25818634, 16.88792038], [82.25846863, 16.88792038], [82.25846863, 16.88820076], [82.25958252, 16.88819695], [82.25958252, 16.8884716], [82.26013947, 16.8884716], [82.26013947, 16.88819695], [82.26040649, 16.88820076], [82.26040649, 16.88764], [82.26069641, 16.88764], [82.26069641, 16.88735962], [82.26097107, 16.88736153], [82.26097107, 16.88708305], [82.26152802, 16.88708305], [82.26152802, 16.88680649], [82.26207733, 16.88680077], [82.26208496, 16.88652802], [82.26291656, 16.88652992], [82.26291656, 16.88626099], [82.26346588, 16.88626099], [82.26346588, 16.88597107], [82.26403046, 16.88597488], [82.26403046, 16.8856926], [82.26486206, 16.8856926], [82.26486206, 16.88541412], [82.26541901, 16.88541985], [82.26541901, 16.88513947], [82.26568604, 16.88513947], [82.26568604, 16.8848629], [82.26597595, 16.8848629], [82.26597595, 16.88458061], [82.26625061, 16.88458443], [82.26625061, 16.88430405], [82.2665329, 16.88430977], [82.2665329, 16.88375282], [82.26680756, 16.88375282], [82.26680756, 16.88347054], [82.26708221, 16.88347054], [82.26708221, 16.88319206], [82.26735687, 16.88319969], [82.26735687, 16.88264275], [82.26763916, 16.88264275], [82.26763916, 16.88236046], [82.26790619, 16.88236046], [82.26790619, 16.88208008], [82.26819611, 16.88208389], [82.26819611, 16.88152695], [82.26847076, 16.88153267], [82.26847076, 16.88097191], [82.26875305, 16.88097191], [82.26875305, 16.88041687], [82.26902771, 16.88042068], [82.26902771, 16.87985992], [82.26930237, 16.87986183], [82.26930237, 16.87902832], [82.26957703, 16.87902832], [82.26957703, 16.87791824], [82.26985931, 16.87791824], [82.26985931, 16.87569046], [82.27069092, 16.87569427], [82.27069092, 16.87541771], [82.27236176, 16.87541771], [82.27236176, 16.87569427], [82.27263641, 16.87569427], [82.27263641, 16.87541771], [82.27375031, 16.87541771], [82.27375031, 16.87569427], [82.27430725, 16.87569427], [82.27430725, 16.87597275], [82.27513885, 16.87597084], [82.27513885, 16.87625122], [82.2756958, 16.87625122], [82.2756958, 16.87652969], [82.27625275, 16.87652969], [82.27625275, 16.87680817], [82.27680206, 16.87680626], [82.27680206, 16.87708282], [82.2776413, 16.87708282], [82.2776413, 16.8773613], [82.27819824, 16.87735939], [82.27819824, 16.87763977], [82.28180695, 16.87763977], [82.28180695, 16.87735939], [82.2820816, 16.8773613], [82.2820816, 16.87680626], [82.28235626, 16.87680817], [82.28235626, 16.87652969], [82.28263855, 16.87652969], [82.28263855, 16.87625122], [82.28291321, 16.87625122], [82.28291321, 16.87597084], [82.2831955, 16.87597275], [82.2831955, 16.87569427], [82.28347015, 16.87569427], [82.28347015, 16.87541771], [82.28375244, 16.87541962], [82.28375244, 16.87514114], [82.2840271, 16.87514114], [82.2840271, 16.87486076], [82.28430176, 16.87486076], [82.28430176, 16.87458038], [82.2848587, 16.8745842], [82.2848587, 16.87402725], [82.28514099, 16.87403107], [82.28514099, 16.87347031], [82.28541565, 16.87347221], [82.28541565, 16.87208557], [82.28514099, 16.87208557], [82.28514099, 16.87152863], [82.2848587, 16.87153053], [82.2848587, 16.86903191], [82.28457642, 16.86903191], [82.28457642, 16.86846924], [82.28430176, 16.86847115], [82.28430176, 16.86791611], [82.2840271, 16.86792183], [82.2840271, 16.86735916], [82.28375244, 16.86735916], [82.28375244, 16.86708069], [82.28347015, 16.8670826], [82.28347015, 16.86680603], [82.28320313, 16.86681175], [82.28320313, 16.86624908], [82.28291321, 16.86624908], [82.28291321, 16.86597061], [82.28263855, 16.86597252], [82.28263855, 16.86541748], [82.28235626, 16.86541748], [82.28235626, 16.86512947], [82.28320313, 16.86512947], [82.28320313, 16.86541748], [82.28347015, 16.86541748], [82.28347015, 16.86569405], [82.28375244, 16.86569023], [82.28375244, 16.86624908], [82.2840271, 16.86624908], [82.2840271, 16.86653137], [82.28430176, 16.86653137], [82.28430176, 16.86681175], [82.28457642, 16.86681175], [82.28457642, 16.86735916], [82.2848587, 16.86735916], [82.2848587, 16.86792183], [82.28514099, 16.86791611], [82.28514099, 16.86847115], [82.28541565, 16.86847115], [82.28541565, 16.86930466], [82.28569794, 16.86930466], [82.28569794, 16.86986351], [82.2859726, 16.8698597], [82.2859726, 16.87042046], [82.28624725, 16.87041664], [82.28624725, 16.87097359], [82.28652954, 16.87096977], [82.28652954, 16.87153053], [82.28679657, 16.87153053], [82.28679657, 16.87264061], [82.28652954, 16.87264061], [82.28652954, 16.87403107], [82.28624725, 16.87403107], [82.28624725, 16.87486076], [82.2859726, 16.87486076], [82.2859726, 16.87514114], [82.28569794, 16.87514114], [82.28569794, 16.87680817], [82.28624725, 16.87680626], [82.28624725, 16.87708282], [82.28652954, 16.87708282], [82.28652954, 16.87680626], [82.28679657, 16.87680817], [82.28679657, 16.87597084], [82.28708649, 16.87597275], [82.28708649, 16.87569427], [82.2876358, 16.87569427], [82.2876358, 16.87541771], [82.28848267, 16.87541962], [82.28848267, 16.87375069], [82.28874969, 16.87375069], [82.28874969, 16.87264061], [82.28901672, 16.87264061], [82.28901672, 16.87236023], [82.2895813, 16.87236023], [82.2895813, 16.87207985], [82.28986359, 16.87208557], [82.28986359, 16.87180328], [82.2904129, 16.87181091], [82.2904129, 16.87153053], [82.29152679, 16.87153053], [82.29152679, 16.87125969], [82.29180908, 16.87125969], [82.29180908, 16.87096977], [82.29208374, 16.87097359], [82.29208374, 16.87069321], [82.2923584, 16.87070084], [82.2923584, 16.87042046], [82.29264069, 16.87042046], [82.29264069, 16.87014008], [82.29292297, 16.87014008], [82.29292297, 16.8698597], [82.29319763, 16.86986351], [82.29319763, 16.86958122], [82.29374695, 16.86958122], [82.29374695, 16.86930466], [82.29402924, 16.86930466], [82.29402924, 16.86902809], [82.29569244, 16.86903191], [82.29569244, 16.86874962], [82.2959671, 16.86874962], [82.2959671, 16.86846924], [82.29624939, 16.86847115], [82.29624939, 16.86819458], [82.29680634, 16.8682003], [82.29680634, 16.86792183], [82.29708099, 16.86792183], [82.29708099, 16.86763954], [82.29736328, 16.86763954], [82.29736328, 16.86735916], [82.29792023, 16.86735916], [82.29792023, 16.86708069], [82.29819489, 16.8670826], [82.29819489, 16.86680603], [82.29875183, 16.86681175], [82.29875183, 16.86653137], [82.29957581, 16.86653137], [82.29957581, 16.86624908], [82.29985809, 16.86624908], [82.29985809, 16.86569023], [82.30014038, 16.86569405], [82.30014038, 16.86541748], [82.30097198, 16.86541748], [82.30097198, 16.86512947], [82.30124664, 16.8651371], [82.30124664, 16.86486053], [82.30152893, 16.86486053], [82.30152893, 16.86458015], [82.30180359, 16.86458397], [82.30180359, 16.8643055], [82.30264282, 16.86431122], [82.30264282, 16.86375046], [82.30291748, 16.86375046], [82.30291748, 16.86347008], [82.30319214, 16.86347198], [82.30319214, 16.86319351], [82.30374908, 16.86319351], [82.30374908, 16.86291885], [82.30403137, 16.86292076], [82.30403137, 16.86264038], [82.30430603, 16.86264038], [82.30430603, 16.86236], [82.30458069, 16.86236191], [82.30458069, 16.86180687], [82.30486298, 16.86181068], [82.30486298, 16.8615303], [82.30513763, 16.8615303], [82.30513763, 16.86096954], [82.30541992, 16.86097145], [82.30541992, 16.86069679], [82.30596924, 16.86069679], [82.30596924, 16.86041641], [82.30652618, 16.86042023], [82.30652618, 16.86013985], [82.30680847, 16.86013985], [82.30680847, 16.85958099], [82.30708313, 16.85958481], [82.30708313, 16.85930634], [82.30735779, 16.85931969], [82.30735779, 16.85902977], [82.30764008, 16.85902977], [82.30764008, 16.85847092], [82.30791473, 16.85847473], [82.30791473, 16.85819244], [82.30819702, 16.85819244], [82.30819702, 16.85791588], [82.30847168, 16.85791969], [82.30847168, 16.85764122], [82.30902863, 16.85764122], [82.30902863, 16.85736275], [82.30930328, 16.85736275], [82.30930328, 16.85708046], [82.30958557, 16.85708237], [82.30958557, 16.8568058], [82.30986023, 16.85680962], [82.30986023, 16.85653114], [82.31014252, 16.85653114], [82.31014252, 16.85597038], [82.31041718, 16.85597038], [82.31041718, 16.85569382], [82.31069183, 16.85569382], [82.31069183, 16.85541725], [82.31096649, 16.85542107], [82.31096649, 16.85514259], [82.31124878, 16.85514259], [82.31124878, 16.85486031], [82.3115387, 16.85486031], [82.31153107, 16.85430527], [82.31181335, 16.8543129], [82.31181335, 16.85403252], [82.31208038, 16.85403252], [82.31208038, 16.85346985], [82.31236267, 16.85347176], [82.31236267, 16.85291672], [82.31263733, 16.85292053], [82.31263733, 16.85235977], [82.31291962, 16.85236168], [82.31291962, 16.85180473], [82.31319427, 16.85180473], [82.31319427, 16.85097313], [82.31346893, 16.85097313], [82.31346893, 16.84986115], [82.31375122, 16.84986115], [82.31375122, 16.84902954], [82.31402588, 16.84902954], [82.31402588, 16.84791946], [82.31430817, 16.84791946], [82.31430817, 16.84680939], [82.31458282, 16.84680939], [82.31458282, 16.8445797], [82.31430817, 16.8445816], [82.31430817, 16.84347153], [82.31402588, 16.84347153], [82.31402588, 16.84291649], [82.31375122, 16.8429203], [82.31375122, 16.84264183], [82.31346893, 16.84264183], [82.31346893, 16.84235954], [82.31319427, 16.84236336], [82.31319427, 16.84180641], [82.31291962, 16.84181023], [82.31291962, 16.84153175], [82.31263733, 16.84153175], [82.31263733, 16.84124947], [82.31236267, 16.84124947], [82.31236267, 16.84095955], [82.31208038, 16.8409729], [82.31208038, 16.84069443], [82.31180573, 16.84069443], [82.31180573, 16.84013939], [82.31263733, 16.84013939], [82.31263733, 16.84042168], [82.31291962, 16.84041595], [82.31291962, 16.84069443], [82.31346893, 16.84069443], [82.31346893, 16.8409729], [82.31375122, 16.84095955], [82.31375122, 16.84124947], [82.31402588, 16.84124947], [82.31402588, 16.84181023], [82.31430817, 16.84180641], [82.31430817, 16.84208107], [82.31458282, 16.84208107], [82.31458282, 16.84236336], [82.31485748, 16.84235954], [82.31485748, 16.84264183], [82.31513977, 16.84264183], [82.31513977, 16.8429203], [82.31541443, 16.84291649], [82.31541443, 16.84347153], [82.31569672, 16.84346962], [82.31569672, 16.84375191], [82.31597137, 16.84375191], [82.31597137, 16.84403038], [82.31624603, 16.84403038], [82.31624603, 16.84431076], [82.31680298, 16.84430313], [82.31680298, 16.8456955], [82.31708527, 16.8456955], [82.31708527, 16.84625053], [82.31735229, 16.84625053], [82.31735229, 16.84708977], [82.31764221, 16.84708595], [82.31764221, 16.84819412], [82.31791687, 16.84819412], [82.31791687, 16.84958267], [82.31819153, 16.84958267], [82.31819153, 16.85013962], [82.31846619, 16.85013008], [82.31846619, 16.85041809], [82.31874847, 16.85041618], [82.31874847, 16.85069466], [82.31903076, 16.85069084], [82.31903076, 16.85124969], [82.31931305, 16.85124969], [82.31931305, 16.85152817], [82.31958008, 16.85152817], [82.31958008, 16.85180473], [82.31986237, 16.85180473], [82.31986237, 16.85208321], [82.32013702, 16.85208321], [82.32013702, 16.85236168], [82.32041168, 16.85235977], [82.32041168, 16.85263824], [82.32096863, 16.85263824], [82.32096863, 16.85292053], [82.32125092, 16.85291672], [82.32125092, 16.85319519], [82.32152557, 16.85319519], [82.32152557, 16.85347176], [82.32180786, 16.85346985], [82.32180786, 16.85374832], [82.32208252, 16.85374832], [82.32208252, 16.85403252], [82.32319641, 16.85403252], [82.32319641, 16.8543129], [82.32402802, 16.85430527], [82.32402802, 16.85458374], [82.32514191, 16.85458183], [82.32514191, 16.85486031], [82.32541656, 16.85486031], [82.32541656, 16.85514259], [82.32569122, 16.85514259], [82.32569122, 16.85542107], [82.33152771, 16.85541725], [82.33152771, 16.85569382], [82.33208466, 16.85569382], [82.33208466, 16.85597038], [82.33235168, 16.85597038], [82.33235168, 16.8562603], [82.33403015, 16.8562603], [82.33403015, 16.85653114], [82.3345871, 16.85653114], [82.3345871, 16.85680962], [82.33598328, 16.85680962], [82.33598328, 16.85653114], [82.33763885, 16.85653114], [82.33763885, 16.8562603], [82.3381958, 16.8562603], [82.3381958, 16.85597038], [82.33875275, 16.85597038], [82.33875275, 16.85569382], [82.33930206, 16.85569382], [82.33930206, 16.85541725], [82.33957672, 16.85542107], [82.33957672, 16.85514259], [82.33985901, 16.85514259], [82.33985901, 16.85486031], [82.3401413, 16.85486031], [82.3401413, 16.85458183], [82.3409729, 16.85458374], [82.3409729, 16.85430527], [82.34179688, 16.8543129], [82.34179688, 16.85403252], [82.34236145, 16.85403252], [82.34236145, 16.85374832], [82.3429184, 16.85374832], [82.3429184, 16.85346985], [82.34375, 16.85347176], [82.34375, 16.85319519], [82.34513855, 16.85319519], [82.34513855, 16.85291672], [82.34570313, 16.85292053], [82.34570313, 16.85263824], [82.34625244, 16.85263824], [82.34625244, 16.85235977], [82.34680176, 16.85236168], [82.34680176, 16.85208321], [82.3473587, 16.85208321], [82.3473587, 16.85180473], [82.34791565, 16.85180473], [82.34791565, 16.85152817], [82.3484726, 16.85152817], [82.3484726, 16.85124969], [82.34874725, 16.85124969], [82.34874725, 16.85097122], [82.34958649, 16.85097122], [82.34958649, 16.85124969], [82.3501358, 16.85124969], [82.3501358, 16.85152817], [82.35069275, 16.85152817], [82.35069275, 16.85180473], [82.35236359, 16.85180473], [82.35236359, 16.85152817], [82.35430908, 16.85152817], [82.35430908, 16.85180473], [82.3548584, 16.85180473], [82.3548584, 16.85208321], [82.35514069, 16.85207939], [82.35514069, 16.85263824], [82.35541534, 16.85263824], [82.35541534, 16.85319519], [82.35569763, 16.85318756], [82.35569763, 16.85374832], [82.35597229, 16.85374832], [82.35597229, 16.85458374], [82.35569763, 16.85458183], [82.35569763, 16.85486031], [82.35542297, 16.85486031], [82.35542297, 16.85542107], [82.35514069, 16.85541725], [82.35514069, 16.85569382], [82.3548584, 16.85569191], [82.3548584, 16.8562603], [82.35514069, 16.8562603], [82.35514069, 16.85736275], [82.35541534, 16.85736275], [82.35541534, 16.85847473], [82.35569763, 16.85847092], [82.35569763, 16.85902977], [82.35597229, 16.85902786], [82.35597229, 16.85986137], [82.35624695, 16.85985947], [82.35624695, 16.86042023], [82.35597229, 16.86042023], [82.35597229, 16.86124992], [82.35569763, 16.86124992], [82.35569763, 16.86375046], [82.35541534, 16.86375046], [82.35541534, 16.86458397], [82.35514069, 16.86458397], [82.35514069, 16.86569405], [82.35542297, 16.86569023], [82.35542297, 16.86653137], [82.35597229, 16.86653137], [82.35597229, 16.86874962], [82.35624695, 16.86874962], [82.35624695, 16.86903191], [82.35652924, 16.86902809], [82.35652924, 16.86958122], [82.35679626, 16.86958122], [82.35679626, 16.87153053], [82.35708618, 16.87152863], [82.35708618, 16.87208557], [82.35736084, 16.87207985], [82.35736084, 16.87236023], [82.35753632, 16.87236023], [82.35764313, 16.87236023], [82.35764313, 16.87264061], [82.35791779, 16.87264061], [82.35791779, 16.87292099], [82.35819244, 16.87291718], [82.35819244, 16.87319565], [82.35847473, 16.87319565], [82.35847473, 16.87347221], [82.35874939, 16.87347031], [82.35874939, 16.87403107], [82.35901642, 16.87403107], [82.35901642, 16.87486076], [82.35874939, 16.87486076], [82.35874939, 16.87514114], [82.35847473, 16.87513924], [82.35847473, 16.87569427], [82.35819244, 16.87569046], [82.35819244, 16.87652969], [82.35847473, 16.87652779], [82.35847473, 16.8773613], [82.35874939, 16.87735939], [82.35874939, 16.87791824], [82.35902405, 16.87791634], [82.35902405, 16.87847137], [82.35930634, 16.87846947], [82.35930634, 16.87874985], [82.35986328, 16.87874985], [82.35986328, 16.87902832], [82.36013794, 16.87902832], [82.36013794, 16.87958336], [82.36042023, 16.87958336], [82.36042023, 16.87986183], [82.36068726, 16.87985992], [82.36068726, 16.88070107], [82.36096954, 16.88070107], [82.36096954, 16.88181114], [82.36125183, 16.88180542], [82.36125183, 16.88347054], [82.36152649, 16.88347054], [82.36152649, 16.88541985], [82.36125183, 16.88541985], [82.36125183, 16.88652992], [82.36152649, 16.88652802], [82.36152649, 16.88736153], [82.36180878, 16.88735962], [82.36180878, 16.88792038], [82.36208344, 16.88791656], [82.36208344, 16.8931942], [82.36180878, 16.89319038], [82.36180878, 16.89374924], [82.36152649, 16.89374924], [82.36152649, 16.89736366], [82.36180878, 16.89736366], [82.36180878, 16.90097237], [82.36208344, 16.90097237], [82.36208344, 16.90208244], [82.36235809, 16.90208054], [82.36235809, 16.90263939], [82.36208344, 16.90263939], [82.36208344, 16.90319443], [82.36235809, 16.90319443], [82.36235809, 16.90486145], [82.36264038, 16.90486145], [82.36264038, 16.90597153], [82.36292267, 16.90596962], [82.36295319, 16.90681076], [82.36319733, 16.90680504], [82.36319733, 16.90708351], [82.36293793, 16.9070797], [82.36292267, 16.90764236], [82.36319733, 16.90764236], [82.36319733, 16.90903282], [82.36347198, 16.90903282], [82.36347198, 16.9101429], [82.36319733, 16.91013908], [82.36319733, 16.9109745], [82.36291504, 16.9109745], [82.36291504, 16.91236115], [82.36264801, 16.91236115], [82.36264801, 16.91403008], [82.36235809, 16.91403008], [82.36235809, 16.91736031], [82.36207581, 16.91736031], [82.36207581, 16.92292023], [82.36180878, 16.92292023], [82.36180878, 16.92514038], [82.36152649, 16.92514038], [82.36152649, 16.92736053], [82.36125183, 16.92736053], [82.36125183, 16.92930984], [82.36096954, 16.92930984], [82.36096954, 16.93124962], [82.36069489, 16.93124962], [82.36069489, 16.93347168], [82.36042023, 16.93347168], [82.36042023, 16.93597031], [82.36013794, 16.93597031], [82.36013794, 16.93680954], [82.35986328, 16.93680573], [82.35986328, 16.93847466], [82.35958099, 16.93847466], [82.35958099, 16.94041634], [82.35930634, 16.94041061], [82.35930634, 16.94124985], [82.35901642, 16.94124985], [82.35901642, 16.94403076], [82.35930634, 16.94403076], [82.35930634, 16.94431114], [82.35874939, 16.94430542], [82.35874939, 16.94458389], [82.3584671, 16.94458008], [82.3584671, 16.94681168], [82.35819244, 16.94680595], [82.35819244, 16.94708252], [82.35791779, 16.94708061], [82.35791779, 16.9493103], [82.3576355, 16.94930649], [82.3576355, 16.9509716], [82.35736084, 16.9509697], [82.35736084, 16.95153046], [82.35708618, 16.95152855], [82.35708618, 16.95208549], [82.35680389, 16.95208549], [82.35680389, 16.95319557], [82.35652161, 16.95318985], [82.35652161, 16.95375061], [82.35624695, 16.95375061], [82.35624695, 16.95430946], [82.35597229, 16.95430946], [82.35597229, 16.95486069], [82.35569763, 16.95486069], [82.35569763, 16.95514107], [82.35541534, 16.95513916], [82.35541534, 16.9556942], [82.35514069, 16.95569038], [82.35514069, 16.95625114], [82.3548584, 16.95625114], [82.3548584, 16.95652962], [82.35402679, 16.95652962], [82.35402679, 16.95680809], [82.35375214, 16.95680618], [82.35375214, 16.95708275], [82.35346222, 16.95708084], [82.35346985, 16.95736122], [82.35320282, 16.95736122], [82.35320282, 16.95791817], [82.3529129, 16.95791626], [82.3529129, 16.95819473], [82.35263824, 16.95819092], [82.35263824, 16.95848083], [82.35235596, 16.95848083], [82.35235596, 16.95874977], [82.35180664, 16.95874977], [82.35180664, 16.95902824], [82.35152435, 16.95902824], [82.35152435, 16.95930481], [82.35097504, 16.95930481], [82.35097504, 16.95958328], [82.35069275, 16.95958328], [82.35069275, 16.95986176], [82.3501358, 16.95985985], [82.3501358, 16.96013832], [82.34986115, 16.96013832], [82.34986115, 16.96042061], [82.34958649, 16.96041679], [82.34958649, 16.96097183], [82.34929657, 16.96097183], [82.34929657, 16.96125031], [82.34902954, 16.96125031], [82.34902954, 16.96152687], [82.3484726, 16.96151924], [82.3484726, 16.96181107], [82.3465271, 16.96180534], [82.3465271, 16.96208382], [82.34625244, 16.96208191], [82.34625244, 16.96236038], [82.34597015, 16.96236038], [82.34597015, 16.96264267], [82.34541321, 16.96264267], [82.34541321, 16.96292114], [82.34513855, 16.96291733], [82.34513855, 16.96319389], [82.34485626, 16.96319008], [82.34485626, 16.96375275], [82.3445816, 16.96375275], [82.3445816, 16.96403122], [82.34401703, 16.96403122], [82.34401703, 16.96430969], [82.34347534, 16.96430588], [82.34347534, 16.96458244], [82.34319305, 16.96458054], [82.34319305, 16.96486282], [82.34263611, 16.96486282], [82.34263611, 16.96513939], [82.34208679, 16.96513939], [82.34208679, 16.96541977], [82.3409729, 16.96541405], [82.3409729, 16.96569252], [82.34041595, 16.96569061], [82.34041595, 16.96624947], [82.3401413, 16.96624947], [82.3401413, 16.96708488], [82.33930206, 16.96708107], [82.33930206, 16.96763992], [82.3390274, 16.96763992], [82.3390274, 16.96903038], [82.33875275, 16.96902847], [82.33875275, 16.96958351], [82.33847809, 16.9695797], [82.33847809, 16.97042084], [82.3381958, 16.97041893], [82.3381958, 16.97097206], [82.33790588, 16.97097015], [82.33790588, 16.97125053], [82.33763885, 16.97125053], [82.33763885, 16.97180748], [82.3373642, 16.97180557], [82.3373642, 16.97208405], [82.33708191, 16.97208023], [82.33708191, 16.97236061], [82.33680725, 16.97236061], [82.33680725, 16.97263908], [82.33652496, 16.97263718], [82.33652496, 16.97319412], [82.33625031, 16.97319412], [82.33625031, 16.9734726], [82.33597565, 16.9734726], [82.33598328, 16.97485924], [82.33569336, 16.97485924], [82.33569336, 16.97569466], [82.3354187, 16.97569466], [82.3354187, 16.97652817], [82.33513641, 16.97652817], [82.33513641, 16.97680473], [82.33486176, 16.97680473], [82.33486176, 16.9770813], [82.3345871, 16.9770813], [82.3345871, 16.97736359], [82.33429718, 16.97735977], [82.33429718, 16.97764015], [82.33403015, 16.97764015], [82.33403015, 16.97792053], [82.33374786, 16.97791672], [82.33374786, 16.97847366], [82.33347321, 16.97846985], [82.33347321, 16.97903061], [82.33319092, 16.97903061], [82.33319092, 16.97986031], [82.33291626, 16.97986031], [82.33291626, 16.98014069], [82.3326416, 16.98014069], [82.3326416, 16.98042107], [82.33235931, 16.98041725], [82.33235931, 16.98069572], [82.33207703, 16.98069], [82.33207703, 16.98125076], [82.33180237, 16.98125076], [82.33180237, 16.98153114], [82.32958221, 16.98153114], [82.32958221, 16.98180962], [82.32902527, 16.98180771], [82.32902527, 16.98208427], [82.32875061, 16.98208046], [82.32875061, 16.98236084], [82.32847595, 16.98236084], [82.32847595, 16.98265076], [82.32791901, 16.98265076], [82.32791901, 16.98291969], [82.32763672, 16.98291779], [82.32763672, 16.98319435], [82.32736206, 16.98319435], [82.32736206, 16.98347282], [82.32707977, 16.98347092], [82.32707977, 16.98430824], [82.32680511, 16.98430634], [82.32680511, 16.98486137], [82.32653809, 16.98485947], [82.32653809, 16.98513985], [82.32624817, 16.98513985], [82.32624817, 16.98569489], [82.32597351, 16.98569489], [82.32597351, 16.98597145], [82.32569122, 16.98596954], [82.32569122, 16.98624992], [82.32541656, 16.98624992], [82.32541656, 16.98681068], [82.32514191, 16.98680496], [82.32514191, 16.98708344], [82.32485962, 16.98707962], [82.32485962, 16.98764229], [82.32458496, 16.98763847], [82.32457733, 16.9881916], [82.32430267, 16.98820114], [82.32430267, 16.98875046], [82.32457733, 16.98875046], [82.32457733, 16.98903275], [82.32485962, 16.98903275], [82.32485962, 16.98931122], [82.32514191, 16.9893055], [82.32514191, 16.98958206], [82.32541656, 16.98958015], [82.32541656, 16.99014282], [82.32569122, 16.99014282], [82.32569122, 16.99041939], [82.32597351, 16.99041748], [82.32597351, 16.99069214], [82.32624817, 16.99069214], [82.32624817, 16.99097443], [82.32791901, 16.99097443], [82.32791901, 16.99069214], [82.32847595, 16.99069214], [82.32847595, 16.99097443], [82.32930756, 16.99097061], [82.32930756, 16.9912529], [82.32958221, 16.9912529], [82.32958221, 16.99097061], [82.33152771, 16.99097443], [82.33152771, 16.99069214], [82.33208466, 16.99069214], [82.33208466, 16.99041748], [82.3326416, 16.99041939], [82.3326416, 16.99014282], [82.33347321, 16.99014282], [82.33347321, 16.98986053], [82.33403015, 16.98986053], [82.33403015, 16.98958015], [82.3345871, 16.98958206], [82.3345871, 16.9893055], [82.3354187, 16.98931122], [82.3354187, 16.98903275], [82.33569336, 16.98903275], [82.33569336, 16.98875046], [82.33625031, 16.98875046], [82.33625031, 16.98846054], [82.33652496, 16.98847008], [82.33652496, 16.98819351], [82.33708191, 16.98819351], [82.33708191, 16.98791695], [82.33735657, 16.98792267], [82.33735657, 16.98764229], [82.33790588, 16.98764229], [82.33790588, 16.98735809], [82.3381958, 16.98736191], [82.3381958, 16.98708344], [82.33875275, 16.98708344], [82.33875275, 16.98680496], [82.3390274, 16.98681068], [82.3390274, 16.9865284], [82.33957672, 16.9865284], [82.33957672, 16.98624992], [82.33985901, 16.98624992], [82.33985901, 16.98596954], [82.34041595, 16.98597145], [82.34041595, 16.98569489], [82.34069061, 16.98569489], [82.34069824, 16.98541641], [82.34124756, 16.98541832], [82.34124756, 16.98513985], [82.34152222, 16.98513985], [82.34152222, 16.98485947], [82.3418045, 16.98486137], [82.3418045, 16.9845829], [82.34236145, 16.9845829], [82.34236145, 16.98430634], [82.34263611, 16.98430824], [82.34263611, 16.98402977], [82.3429184, 16.98402977], [82.3429184, 16.98374939], [82.34319305, 16.98374939], [82.34319305, 16.98347092], [82.34375, 16.98347282], [82.34375, 16.98319435], [82.34402466, 16.98319435], [82.34402466, 16.98291779], [82.34430695, 16.98291969], [82.34430695, 16.98265076], [82.34485626, 16.98265076], [82.34485626, 16.98236084], [82.34513855, 16.98236084], [82.34513855, 16.98208046], [82.34541321, 16.98208237], [82.34541321, 16.98180771], [82.34570313, 16.98180962], [82.34570313, 16.98153114], [82.34625244, 16.98153114], [82.34625244, 16.98125076], [82.3465271, 16.98125076], [82.3465271, 16.98097038], [82.34680176, 16.98097229], [82.34680176, 16.98069572], [82.34708405, 16.98069572], [82.34708405, 16.98041725], [82.3473587, 16.98042107], [82.3473587, 16.98014069], [82.34764099, 16.98014069], [82.34764099, 16.97957993], [82.34791565, 16.97958565], [82.34791565, 16.97930336], [82.34819794, 16.97931099], [82.34819794, 16.97903061], [82.3484726, 16.97903061], [82.3484726, 16.97875023], [82.34874725, 16.97875023], [82.34874725, 16.97846985], [82.34902954, 16.97847366], [82.34902954, 16.97791672], [82.34929657, 16.97792053], [82.34929657, 16.97735977], [82.34958649, 16.97736359], [82.34958649, 16.9770813], [82.34986115, 16.9770813], [82.34986115, 16.97652817], [82.3501358, 16.97652817], [82.3501358, 16.97624969], [82.35041809, 16.97624969], [82.35041809, 16.97569084], [82.35069275, 16.97569466], [82.35069275, 16.97513962], [82.35098267, 16.97513962], [82.35097504, 16.97485924], [82.35124969, 16.97485924], [82.35124969, 16.97431183], [82.35151672, 16.97431183], [82.35151672, 16.97374916], [82.35180664, 16.97374916], [82.35180664, 16.97346115], [82.3520813, 16.9734726], [82.3520813, 16.97291756], [82.35235596, 16.97292137], [82.35235596, 16.97236061], [82.35263824, 16.97236061], [82.35263824, 16.97208023], [82.3529129, 16.97208405], [82.3529129, 16.9715271], [82.35320282, 16.97153091], [82.35320282, 16.97125053], [82.35346985, 16.97125053], [82.35346222, 16.97068977], [82.35375214, 16.97069359], [82.35375214, 16.97013855], [82.35402679, 16.97014046], [82.35402679, 16.96986008], [82.35430908, 16.96986198], [82.35430908, 16.96930695], [82.35457611, 16.96931076], [82.35457611, 16.96903038], [82.3548584, 16.96903038], [82.3548584, 16.96846962], [82.35514069, 16.96847153], [82.35514069, 16.96819687], [82.35542297, 16.96820068], [82.35542297, 16.96763992], [82.35569763, 16.96763992], [82.35569763, 16.96708107], [82.35597229, 16.96708488], [82.35597229, 16.96680641], [82.35624695, 16.96681023], [82.35624695, 16.96624947], [82.35652161, 16.96624947], [82.35652161, 16.96597099], [82.35680389, 16.96597481], [82.35680389, 16.96541405], [82.35708618, 16.96541977], [82.35708618, 16.96513939], [82.35736084, 16.96513939], [82.35736084, 16.96458054], [82.3576355, 16.96458244], [82.3576355, 16.96375275], [82.35791779, 16.96375275], [82.35791779, 16.96264267], [82.35819244, 16.96264267], [82.35819244, 16.96125031], [82.3584671, 16.96125031], [82.3584671, 16.96013832], [82.35874939, 16.96013832], [82.35874939, 16.95819092], [82.35902405, 16.95819473], [82.35902405, 16.95708275], [82.35930634, 16.95708275], [82.35930634, 16.95597267], [82.35958099, 16.95597267], [82.35958099, 16.95486069], [82.35986328, 16.95486069], [82.35986328, 16.95375061], [82.36013794, 16.95375061], [82.36013794, 16.95014191], [82.36042023, 16.95014191], [82.36042023, 16.94681168], [82.36068726, 16.94681168], [82.36068726, 16.94568825], [82.36096954, 16.94569397], [82.36096954, 16.94458389], [82.36125183, 16.94458389], [82.36125183, 16.94347191], [82.36152649, 16.94347954], [82.36152649, 16.94207954], [82.36180878, 16.94208336], [82.36180878, 16.94041634], [82.36208344, 16.94041634], [82.36208344, 16.93874931], [82.36235809, 16.93875122], [82.36235809, 16.93708038], [82.36264038, 16.93708229], [82.36264038, 16.93652725], [82.36235809, 16.93653107], [82.36235809, 16.93625259], [82.36264801, 16.93625259], [82.36264038, 16.9323616], [82.36291504, 16.9323616], [82.36291504, 16.92986107], [82.36319733, 16.92986107], [82.36319733, 16.92818069], [82.36347198, 16.92819595], [82.36347198, 16.9268055], [82.36374664, 16.92681122], [82.36374664, 16.92514038], [82.36402893, 16.92514038], [82.36402893, 16.92292023], [82.36429596, 16.92292023], [82.36429596, 16.92013931], [82.36458588, 16.92013931], [82.36458588, 16.91902924], [82.36486053, 16.91902924], [82.36486053, 16.91681099], [82.36514282, 16.91681099], [82.36514282, 16.91542053], [82.36541748, 16.91542053], [82.36541748, 16.90624809], [82.36569214, 16.90624809], [82.36569214, 16.90208054], [82.36541748, 16.90208244], [82.36541748, 16.89958572], [82.36513519, 16.89958572], [82.36513519, 16.89680481], [82.36486053, 16.89680481], [82.36486053, 16.89430618], [82.36458588, 16.8943119], [82.36458588, 16.89180756], [82.36429596, 16.89180756], [82.36429596, 16.88929939], [82.36402893, 16.88930511], [82.36402893, 16.88680649], [82.36374664, 16.8868103], [82.36374664, 16.88430977], [82.36347198, 16.88430977], [82.36347198, 16.8848629], [82.36319733, 16.8848629], [82.36319733, 16.88541985], [82.36264801, 16.88541985], [82.36264801, 16.8848629], [82.36235809, 16.8848629], [82.36235809, 16.88430977], [82.36207581, 16.88430977], [82.36207581, 16.88264275], [82.36180878, 16.88264275], [82.36180878, 16.88125038], [82.36152649, 16.88125038], [82.36152649, 16.88070107], [82.36125183, 16.88070107], [82.36125183, 16.87846947], [82.36096954, 16.87847137], [82.36096954, 16.87791634], [82.36068726, 16.87791824], [82.36068726, 16.87763977], [82.36042023, 16.87763977], [82.36042023, 16.87706947], [82.36013794, 16.87708282], [82.36013794, 16.87430573], [82.35986328, 16.87432098], [82.35986328, 16.87264061], [82.35958099, 16.87264061], [82.35958099, 16.87181091], [82.35930634, 16.87181091], [82.35930634, 16.87096977], [82.35902405, 16.87097359], [82.35902405, 16.87013817], [82.35874939, 16.87014008], [82.35874939, 16.86846924], [82.35902405, 16.86847115], [82.35902405, 16.86680603], [82.35874939, 16.86681175], [82.35874939, 16.86624908], [82.3584671, 16.86624908], [82.3584671, 16.86569023], [82.35819244, 16.86569405], [82.35819244, 16.8651371], [82.35791779, 16.8651371], [82.35791779, 16.85958481], [82.3576355, 16.85958481], [82.3576355, 16.85652733], [82.35745239, 16.85652733], [82.35736084, 16.85652733], [82.35736084, 16.85545731], [82.35736084, 16.85430527], [82.35764313, 16.8543129], [82.35764313, 16.85318756], [82.35791779, 16.85318756], [82.35791779, 16.85374832], [82.35819244, 16.85374832], [82.35819244, 16.85403252], [82.3584671, 16.85403252], [82.3584671, 16.85374832], [82.35874939, 16.85374832], [82.35874939, 16.85263824], [82.35901642, 16.85263824], [82.35901642, 16.85124969], [82.35874939, 16.85124969], [82.35874939, 16.85069084], [82.35847473, 16.85069466], [82.35847473, 16.85041618], [82.35874939, 16.85041809], [82.35874939, 16.84986115], [82.35901642, 16.84986115], [82.35901642, 16.84875107], [82.35874939, 16.84875107], [82.35874939, 16.84847069], [82.35847473, 16.8484726], [82.35847473, 16.84819412], [82.35819244, 16.84819412], [82.35819244, 16.84708595], [82.35791779, 16.84708977], [82.35791779, 16.84625053], [82.3576355, 16.84625053], [82.3576355, 16.8456955], [82.35791779, 16.8456955], [82.35791779, 16.84541702], [82.35819244, 16.84542084], [82.35819244, 16.8445797], [82.35847473, 16.8445816], [82.35847473, 16.84430313], [82.35819244, 16.84431076], [82.35819244, 16.84320068], [82.35791779, 16.84320068], [82.35791779, 16.84264183], [82.35764313, 16.84264183], [82.35764313, 16.84235954], [82.35736084, 16.84236336], [82.35736084, 16.84152794], [82.35708618, 16.84153175], [82.35708618, 16.84124947], [82.35679626, 16.84124947], [82.35679626, 16.84095955], [82.35652924, 16.8409729], [82.35652924, 16.84041595], [82.35624695, 16.84042168], [82.35624695, 16.83847046], [82.35597229, 16.83847237], [82.35597229, 16.83763885], [82.35542297, 16.83764076], [82.35542297, 16.83736038], [82.35514069, 16.83736038], [82.35514069, 16.83681107], [82.3548584, 16.83681107], [82.3548584, 16.83570099], [82.35457611, 16.83570099], [82.35457611, 16.83374977], [82.35430908, 16.83374977], [82.35430908, 16.83263969], [82.35402679, 16.83263969], [82.35402679, 16.83209038], [82.35375214, 16.83209038], [82.35375214, 16.83181], [82.35346222, 16.83181], [82.35346222, 16.83069038], [82.35319519, 16.83069229], [82.35319519, 16.82763863], [82.35346222, 16.82764244], [82.35346222, 16.82652855], [82.35320282, 16.82652855], [82.35320282, 16.82624817], [82.3529129, 16.82624817], [82.3529129, 16.8243103], [82.35263824, 16.8243103], [82.35263824, 16.82347107], [82.3529129, 16.82347298], [82.3529129, 16.82291794], [82.35320282, 16.82291985], [82.35320282, 16.82236099], [82.3529129, 16.82236099], [82.3529129, 16.82208061], [82.3520813, 16.82208252], [82.3520813, 16.82180786], [82.35180664, 16.82180977], [82.35180664, 16.82097054], [82.3520813, 16.82097244], [82.3520813, 16.8204174], [82.35235596, 16.82042122], [82.35235596, 16.81931114], [82.3520813, 16.81931114], [82.3520813, 16.81820107], [82.35180664, 16.81820107], [82.35180664, 16.81792068], [82.35151672, 16.81792068], [82.35151672, 16.8176403], [82.35124969, 16.8176403], [82.35124969, 16.81679153], [82.35097504, 16.81680489], [82.35097504, 16.81597137], [82.35069275, 16.81597137], [82.35069275, 16.81514168], [82.35041809, 16.81514168], [82.35041809, 16.81458092], [82.3501358, 16.81458282], [82.3501358, 16.81402779], [82.34986115, 16.81402779], [82.34986115, 16.81374931], [82.34958649, 16.81374931], [82.34958649, 16.81319046], [82.3493042, 16.81319427], [82.3493042, 16.81236076], [82.34902954, 16.81236076], [82.34902954, 16.81180763], [82.34929657, 16.81180763], [82.34929657, 16.81041908], [82.34902954, 16.81041908], [82.34902954, 16.80957985], [82.34874725, 16.80958366], [82.34874725, 16.80930519], [82.3484726, 16.80931091], [82.3484726, 16.80846977], [82.34819794, 16.80847168], [82.34819794, 16.80819511], [82.3484726, 16.80821037], [82.3484726, 16.80792046], [82.34874725, 16.80792046], [82.34877014, 16.80821037], [82.34902954, 16.80819511], [82.34902954, 16.80847168], [82.34929657, 16.80846977], [82.34929657, 16.80931091], [82.34958649, 16.80931091], [82.34958649, 16.80986023], [82.34929657, 16.80986023], [82.34929657, 16.81014061], [82.34958649, 16.81014061], [82.34958649, 16.81041908], [82.34986115, 16.81041718], [82.34986115, 16.81069374], [82.35041809, 16.81068993], [82.35041809, 16.81125069], [82.35069275, 16.81125069], [82.35069275, 16.8120842], [82.35098267, 16.81208038], [82.35098267, 16.81263924], [82.35124969, 16.81263924], [82.35124969, 16.81374931], [82.35180664, 16.81374931], [82.35180664, 16.81402779], [82.35151672, 16.81401825], [82.35151672, 16.81431007], [82.35180664, 16.81431007], [82.35180664, 16.81542015], [82.3520813, 16.81541634], [82.3520813, 16.81597137], [82.35235596, 16.81596947], [82.35235596, 16.81653023], [82.35263824, 16.81652832], [82.35263824, 16.81708145], [82.3529129, 16.81707954], [82.3529129, 16.81792068], [82.35320282, 16.81792068], [82.35320282, 16.81820107], [82.35346985, 16.81819534], [82.35346985, 16.81847382], [82.35458374, 16.81847382], [82.35458374, 16.81819534], [82.3548584, 16.81820107], [82.3548584, 16.8176403], [82.35514069, 16.8176403], [82.35514069, 16.81707954], [82.35541534, 16.81708145], [82.35541534, 16.8163681], [82.35541534, 16.81625175], [82.35569763, 16.81625175], [82.35569763, 16.81514168], [82.35597229, 16.81514168], [82.35597229, 16.81458092], [82.35569763, 16.81458282], [82.35569763, 16.8120842], [82.35541534, 16.8120842], [82.35541534, 16.81097221], [82.35514069, 16.81097984], [82.35514069, 16.81014061], [82.3548584, 16.81014061], [82.3548584, 16.80821037], [82.35457611, 16.80821037], [82.35457611, 16.80708122], [82.35430908, 16.80708313], [82.35430908, 16.80652809], [82.35402679, 16.80653], [82.35402679, 16.80624962], [82.35375214, 16.80624962], [82.35375214, 16.80569077], [82.35346985, 16.80569458], [82.35346985, 16.8045845], [82.35319519, 16.8045845], [82.35319519, 16.80402756], [82.35346222, 16.80402946], [82.35346222, 16.80347061], [82.35319519, 16.80347061], [82.35319519, 16.80236053], [82.3529129, 16.80236053], [82.3529129, 16.80153275], [82.35263824, 16.80153275], [82.35263824, 16.80070114], [82.35235596, 16.8006897], [82.35236359, 16.80013847], [82.3520813, 16.80013847], [82.3520813, 16.79957962], [82.35180664, 16.79958344], [82.35180664, 16.79763985], [82.35151672, 16.79763985], [82.35151672, 16.79652977], [82.35124969, 16.79652977], [82.35124969, 16.79569054], [82.35152435, 16.79569435], [82.35152435, 16.79263878], [82.35124969, 16.79264069], [82.35124969, 16.79125023], [82.35097504, 16.79125023], [82.35097504, 16.79013824], [82.35069275, 16.79014015], [82.35069275, 16.78957939], [82.35041809, 16.7895813], [82.35041809, 16.78930473], [82.3501358, 16.78930473], [82.3501358, 16.78847122], [82.34986115, 16.78847122], [82.34986115, 16.78764153], [82.34958649, 16.78764153], [82.34958649, 16.78735924], [82.34929657, 16.78735924], [82.34929657, 16.78708076], [82.34902954, 16.78708267], [82.34902954, 16.78624916], [82.34929657, 16.78624916], [82.34929657, 16.78597069], [82.34958649, 16.7859726], [82.34958649, 16.78458405], [82.34902954, 16.78458405], [82.34902954, 16.78430557], [82.3473587, 16.78430748], [82.3473587, 16.78375053], [82.34707642, 16.78375053], [82.34707642, 16.78181076], [82.34680176, 16.78181076], [82.34680176, 16.78125], [82.3465271, 16.78125], [82.3465271, 16.7804203], [82.34625244, 16.7804203], [82.34625244, 16.77931023], [82.34597015, 16.77931023], [82.34597015, 16.77819061], [82.3456955, 16.77819252], [82.3456955, 16.77708435], [82.34541321, 16.77708435], [82.34541321, 16.77541733], [82.34513855, 16.77542114], [82.34513855, 16.77319908], [82.34485626, 16.77319908], [82.34485626, 16.77152824], [82.3445816, 16.77152824], [82.3445816, 16.77041817], [82.34430695, 16.77041817], [82.34430695, 16.76736069], [82.3445816, 16.76736069], [82.3445816, 16.76708031], [82.34430695, 16.76708412], [82.34430695, 16.76680565], [82.34401703, 16.76680946], [82.34401703, 16.76653099], [82.34375, 16.76653099], [82.34375, 16.76625061], [82.3429184, 16.76625061], [82.3429184, 16.76514053], [82.34263611, 16.76514053], [82.34263611, 16.76431084], [82.3429184, 16.76431084], [82.3429184, 16.76403046], [82.34348297, 16.76403046], [82.34348297, 16.76375008], [82.34375, 16.76375008], [82.34375, 16.76320076], [82.34348297, 16.76320076], [82.34348297, 16.76291275], [82.34319305, 16.76291656], [82.34319305, 16.76263809], [82.3429184, 16.76264191], [82.3429184, 16.76207924], [82.34319305, 16.76208115], [82.34319305, 16.76124954], [82.34348297, 16.76124954], [82.34347534, 16.76013947], [82.34319305, 16.76013947], [82.34319305, 16.75875092], [82.3429184, 16.75875092], [82.3429184, 16.75792122], [82.34263611, 16.75792122], [82.34263611, 16.75736046], [82.34236145, 16.75736046], [82.34236145, 16.75570107], [82.34208679, 16.75570107], [82.34208679, 16.75542068], [82.34179688, 16.75542068], [82.34179688, 16.75457954], [82.34152985, 16.75458336], [82.34152985, 16.75347137], [82.34124756, 16.75347137], [82.34124756, 16.75208473], [82.34152985, 16.75208473], [82.34152985, 16.75069237], [82.34124756, 16.75069237], [82.34124756, 16.75013924], [82.3409729, 16.75014114], [82.3409729, 16.74986267], [82.34124756, 16.74986267], [82.34124756, 16.74819183], [82.34152985, 16.74819374], [82.34152985, 16.74624825], [82.34124756, 16.74624825], [82.34124756, 16.74596977], [82.3409729, 16.74597168], [82.3409729, 16.7448616], [82.34124756, 16.74486923], [82.34124756, 16.74458122], [82.34152985, 16.74458313], [82.34152985, 16.74430466], [82.3418045, 16.74430466], [82.3418045, 16.74319458], [82.34208679, 16.74319458], [82.34208679, 16.74041748], [82.34236145, 16.74041939], [82.34236145, 16.73931122], [82.34263611, 16.73931122], [82.34263611, 16.7381897], [82.3429184, 16.7381916], [82.3429184, 16.73791695], [82.34263611, 16.73792076], [82.34263611, 16.73764038], [82.34236145, 16.73764038], [82.34236145, 16.73736191], [82.34208679, 16.73736382], [82.34208679, 16.73680305], [82.34179688, 16.73681068], [82.34179688, 16.73625183], [82.34152222, 16.73625183], [82.34152222, 16.73596954], [82.33921051, 16.73596954], [82.33625031, 16.73597336], [82.33625031, 16.73569489], [82.3354187, 16.73570061], [82.3354187, 16.73542023], [82.33429718, 16.73542023], [82.33429718, 16.73514175], [82.3326416, 16.73514175], [82.3326416, 16.73485947], [82.33235168, 16.73485947], [82.33235168, 16.73514175], [82.32985687, 16.73514175], [82.32985687, 16.73485947], [82.32763672, 16.73485947], [82.32763672, 16.7345829], [82.32791901, 16.7345829], [82.32791901, 16.73430634], [82.32736206, 16.73431015], [82.32736206, 16.73403168], [82.32681274, 16.73403168], [82.32681274, 16.73374939], [82.32624817, 16.73374939], [82.32624817, 16.73347092], [82.32569122, 16.73347092], [82.32569122, 16.73374939], [82.32541656, 16.73374939], [82.32541656, 16.7345829], [82.32514191, 16.73457909], [82.32514191, 16.73542023], [82.32457733, 16.73542023], [82.32457733, 16.73570061], [82.32402802, 16.73570061], [82.32402802, 16.73542023], [82.32319641, 16.73542023], [82.32319641, 16.73514175], [82.32263947, 16.73514175], [82.32263947, 16.73485947], [82.32236481, 16.73485947], [82.32236481, 16.7345829], [82.32180786, 16.7345829], [82.32180786, 16.73430634], [82.32068634, 16.73431015], [82.32068634, 16.73403168], [82.31986237, 16.73403168], [82.31986237, 16.73374939], [82.31970215, 16.73374939], [82.31874847, 16.73374939], [82.31874847, 16.73347092], [82.31791687, 16.73347282], [82.31791687, 16.73319435], [82.31764221, 16.73319435], [82.31764221, 16.73291588], [82.31735229, 16.73293114], [82.31735229, 16.73263931], [82.31652832, 16.73263931], [82.31652832, 16.73208046], [82.31625366, 16.73208427], [82.31625366, 16.7318058], [82.31485748, 16.7318058], [82.31485748, 16.73208427], [82.31430817, 16.73208046], [82.31430817, 16.73236084], [82.31402588, 16.73236084], [82.31402588, 16.73263931], [82.31291962, 16.73263931], [82.31291962, 16.73319435], [82.31263733, 16.73319435], [82.31263733, 16.73347282], [82.31180573, 16.73347282], [82.31180573, 16.73291588], [82.3115387, 16.73293114], [82.3115387, 16.73180962], [82.31124878, 16.73180962], [82.31124878, 16.7306881], [82.31097412, 16.73069382], [82.31097412, 16.72986031], [82.31124878, 16.72986031], [82.31124878, 16.72957039], [82.31153107, 16.72958374], [82.31153107, 16.7290287], [82.31181335, 16.72903061], [82.31181335, 16.72875023], [82.31208038, 16.72875023], [82.31208038, 16.72820091], [82.31236267, 16.72820091], [82.31236267, 16.72735977], [82.31263733, 16.72736168], [82.31263733, 16.72652817], [82.31236267, 16.72653008], [82.31236267, 16.72624969], [82.31208038, 16.72624969], [82.31208038, 16.72569084], [82.31180573, 16.72569466], [82.31180573, 16.72513962], [82.31153107, 16.72513962], [82.31153107, 16.72486115], [82.31124878, 16.72486115], [82.31124878, 16.72458076], [82.31097412, 16.72458458], [82.31097412, 16.72430611], [82.31069183, 16.72430992], [82.31069183, 16.7237606], [82.31041718, 16.7237606], [82.31041718, 16.72347069], [82.31014252, 16.7234745], [82.31014252, 16.72319221], [82.30986023, 16.72319221], [82.30986023, 16.72291756], [82.3095932, 16.72291946], [82.3095932, 16.72236252], [82.30930328, 16.72236252], [82.30930328, 16.72208023], [82.30902863, 16.72208214], [82.30902863, 16.7215271], [82.30874634, 16.72153282], [82.30874634, 16.72097015], [82.30847168, 16.72097015], [82.30847168, 16.72069359], [82.30819702, 16.72070122], [82.30819702, 16.72042274], [82.3079071, 16.72042274], [82.3079071, 16.71985817], [82.30764008, 16.71986008], [82.30764008, 16.71930504], [82.30735779, 16.71931076], [82.30735779, 16.71902847], [82.30652618, 16.71902847], [82.30652618, 16.71846962], [82.30596924, 16.71847153], [82.30596924, 16.71819496], [82.30568695, 16.71820068], [82.30568695, 16.71763039], [82.30541992, 16.71763992], [82.30541992, 16.71736145], [82.30513763, 16.71736145], [82.30513763, 16.71708298], [82.30486298, 16.71708298], [82.30486298, 16.71652794], [82.30430603, 16.71652985], [82.30430603, 16.71624947], [82.30403137, 16.71624947], [82.30403137, 16.71597099], [82.30347443, 16.7159729], [82.30347443, 16.71569443], [82.30291748, 16.71569443], [82.30291748, 16.71541786], [82.30264282, 16.71541977], [82.30264282, 16.71513939], [82.30152893, 16.71513939], [82.30152893, 16.71486092], [82.30041504, 16.71486092], [82.30041504, 16.71458244], [82.29985809, 16.71458244], [82.29985809, 16.71430588], [82.29951477, 16.71433258], [82.30282593, 16.72283936], [82.30105591, 16.73333931], [82.29773712, 16.74037933], [82.29370117, 16.74304008], [82.28909302, 16.74098969], [82.28507996, 16.73450851], [82.28070068, 16.72274971], [82.26370239, 16.71936989], [82.24494934, 16.71895981], [82.22704315, 16.71718025], [82.22042084, 16.7183094], [82.21478271, 16.72520065], [82.21096802, 16.72793961], [82.2100296, 16.73127174], [82.2197876, 16.74486923], [82.22181702, 16.75035286], [82.21768188, 16.75168991], [82.21113586, 16.74822044], [82.20722961, 16.74370956], [82.19677734, 16.73647118], [82.18875122, 16.72721291], [82.18032074, 16.72809982], [82.17463684, 16.7251091], [82.17907715, 16.71630096], [82.19358063, 16.70845032], [82.20252991, 16.70769119], [82.21543884, 16.70976067], [82.22740936, 16.70465088], [82.24653625, 16.69144058], [82.25344849, 16.68972015], [82.25763702, 16.69011307], [82.25791931, 16.69013977], [82.25791931, 16.68985939], [82.25846863, 16.6898613], [82.25846863, 16.68874931], [82.25875092, 16.68875122], [82.25875092, 16.68708038], [82.25902557, 16.6870842], [82.25902557, 16.6851387], [82.25875092, 16.68514061], [82.25875092, 16.68403053], [82.2590332, 16.68403053], [82.2590332, 16.68153191], [82.25930786, 16.68153191], [82.25930786, 16.68069077], [82.25958252, 16.68069458], [82.25958252, 16.68041611], [82.25930786, 16.68042183], [82.25930786, 16.68014145], [82.25958252, 16.68014145], [82.25958252, 16.67985916], [82.25985718, 16.67985916], [82.25985718, 16.67846107], [82.26013947, 16.67847252], [82.26013947, 16.67819405], [82.25986481, 16.67819405], [82.25986481, 16.6768055], [82.26013947, 16.67681122], [82.26013947, 16.67625046], [82.25985718, 16.67625046], [82.25985718, 16.67514038], [82.26040649, 16.67514038], [82.26040649, 16.67486], [82.26013947, 16.67486191], [82.26013947, 16.67458344], [82.25986481, 16.67458344], [82.25986481, 16.67430687], [82.25958252, 16.67431068], [82.25958252, 16.67374992], [82.25985718, 16.67374992], [82.25985718, 16.67292023], [82.26013947, 16.67292023], [82.26013947, 16.67235947], [82.26041412, 16.67236137], [82.26041412, 16.67208481], [82.26069641, 16.67208481], [82.26069641, 16.67152786], [82.26097107, 16.67152977], [82.26097107, 16.66930962], [82.26069641, 16.66930962], [82.26069641, 16.66903114], [82.26097107, 16.66903114], [82.26097107, 16.66847038], [82.26152802, 16.66847038], [82.26152802, 16.66819382], [82.26125336, 16.66819382], [82.26125336, 16.66653061], [82.26097107, 16.66653061], [82.26097107, 16.66624832], [82.26069641, 16.66624832], [82.26069641, 16.66596985], [82.26041412, 16.66597176], [82.26041412, 16.66569519], [82.26013947, 16.66570091], [82.26013947, 16.66513824], [82.25985718, 16.66513824], [82.25985718, 16.66485977], [82.25958252, 16.66486168], [82.25958252, 16.66430473], [82.25902557, 16.66430473], [82.25902557, 16.66402626], [82.25875092, 16.66402817], [82.25875092, 16.66374969], [82.25846863, 16.66374969], [82.25846863, 16.66345978], [82.25819397, 16.66347313], [82.25819397, 16.66319466], [82.25791931, 16.66319466], [82.25791931, 16.66291618], [82.25736237, 16.66291809], [82.25736237, 16.66236115], [82.25707245, 16.66236115], [82.25707245, 16.66208076], [82.25680542, 16.66208267], [82.25680542, 16.66180611], [82.25653076, 16.66180992], [82.25653076, 16.66152954], [82.25624847, 16.66152954], [82.25624847, 16.66097069], [82.25569153, 16.6609726], [82.25569153, 16.66069412], [82.25541687, 16.66069412], [82.25541687, 16.66013908], [82.25514221, 16.66014099], [82.25514221, 16.65903091], [82.25485992, 16.65903091], [82.25485992, 16.65875053], [82.25569153, 16.65875053], [82.25569153, 16.65847015], [82.25485992, 16.65847206], [82.25485992, 16.65791702], [82.2545929, 16.65792084], [82.2545929, 16.65736008], [82.25430298, 16.65736389], [82.25430298, 16.65680313], [82.25402832, 16.65681076], [82.25402832, 16.65570068], [82.25430298, 16.65570068], [82.25430298, 16.65514183], [82.25402832, 16.65514183], [82.25402832, 16.65431023], [82.25374603, 16.65431023], [82.25374603, 16.65263939], [82.25402832, 16.65263939], [82.25402832, 16.65208054], [82.25430298, 16.65208244], [82.25430298, 16.65125084], [82.2545929, 16.65125084], [82.25458527, 16.65069389], [82.25485992, 16.65069389], [82.25485992, 16.65013885], [82.25514221, 16.65014076], [82.25514221, 16.64958], [82.25541687, 16.64958382], [82.25541687, 16.64902687], [82.25569153, 16.64903069], [82.25569153, 16.64875031], [82.25596619, 16.64875031], [82.25596619, 16.64847946], [82.25624847, 16.64847946], [82.25624847, 16.64792061], [82.25653076, 16.64792061], [82.25653076, 16.64764023], [82.25681305, 16.64764023], [82.25681305, 16.64735985], [82.25708008, 16.64736176], [82.25708008, 16.64680672], [82.25736237, 16.64680672], [82.25736237, 16.64652824], [82.25763702, 16.64653015], [82.25763702, 16.64624977], [82.25791931, 16.64624977], [82.25791931, 16.64569092], [82.25819397, 16.64569473], [82.25819397, 16.64541626], [82.25875092, 16.64542007], [82.25875092, 16.64347267], [82.25818634, 16.64347267], [82.25818634, 16.64431], [82.25791931, 16.64431], [82.25791931, 16.64402962], [82.25681305, 16.64402962], [82.25681305, 16.64431], [82.25708008, 16.64430618], [82.25708008, 16.64458466], [82.25653076, 16.64458466], [82.25653076, 16.64263916], [82.25681305, 16.64264107], [82.25681305, 16.64208031], [82.25846863, 16.64208412], [82.25846863, 16.64180565], [82.25930786, 16.64180946], [82.25930786, 16.6415329], [82.25985718, 16.6415329], [82.25985718, 16.64125252], [82.26180267, 16.64125252], [82.26180267, 16.6415329], [82.26207733, 16.6415329], [82.26207733, 16.64180946], [82.26264191, 16.64180565], [82.26264191, 16.64208412], [82.26291656, 16.64208412], [82.26291656, 16.64236259], [82.26569366, 16.64236259], [82.26569366, 16.64208412], [82.26652527, 16.64208412], [82.26652527, 16.64180565], [82.26735687, 16.64180946], [82.26735687, 16.6415329], [82.26819611, 16.6415329], [82.26819611, 16.64125252], [82.26902771, 16.64125252], [82.26902771, 16.64097023], [82.26985931, 16.64097023], [82.26985931, 16.64069366], [82.27041626, 16.64069366], [82.27041626, 16.6404171], [82.27124786, 16.64042282], [82.27124786, 16.64013863], [82.27179718, 16.64013863], [82.27179718, 16.63985825], [82.2720871, 16.63985825], [82.2720871, 16.63957977], [82.27263641, 16.63958359], [82.27263641, 16.63930511], [82.27319336, 16.63931084], [82.27319336, 16.63902855], [82.27348328, 16.63902855], [82.27348328, 16.63874817], [82.27402496, 16.63874817], [82.27401733, 16.6384697], [82.27430725, 16.6384716], [82.27430725, 16.63819504], [82.27485657, 16.63820076], [82.27485657, 16.63792038], [82.27540588, 16.63792038], [82.27540588, 16.63763809], [82.2756958, 16.63763809], [82.2756958, 16.63735962], [82.27625275, 16.63736153], [82.27625275, 16.63708305], [82.27680206, 16.63708305], [82.27680206, 16.63680649], [82.27707672, 16.63680077], [82.27708435, 16.63652611], [82.27735901, 16.63653755], [82.27735901, 16.63624954], [82.27819824, 16.63624954], [82.27819824, 16.63597298], [82.2784729, 16.63597298], [82.2784729, 16.6356945], [82.27874756, 16.6356945], [82.27874756, 16.63513947], [82.27902985, 16.63513947], [82.27902985, 16.63430977], [82.27929688, 16.63430977], [82.27929688, 16.63402939], [82.27958679, 16.63402939], [82.27958679, 16.63375092], [82.27986145, 16.63375092], [82.27986145, 16.63348007], [82.2804184, 16.63348007], [82.2804184, 16.63319016], [82.28069305, 16.63319588], [82.28069305, 16.6329174], [82.28098297, 16.63292122], [82.28098297, 16.63264084], [82.28124237, 16.63264084], [82.28124237, 16.63208008], [82.28152466, 16.6320858], [82.28152466, 16.63152695], [82.28180695, 16.63153076], [82.28180695, 16.63070107], [82.2820816, 16.63070107], [82.2820816, 16.6301403], [82.28235626, 16.6301403], [82.28235626, 16.62957954], [82.28263855, 16.62958145], [82.28263855, 16.62930489], [82.28291321, 16.62930489], [82.28291321, 16.62902832], [82.28320313, 16.62903023], [82.28320313, 16.62846947], [82.28347015, 16.62846947], [82.28347015, 16.62791634], [82.28375244, 16.62792015], [82.28375244, 16.62734985], [82.2840271, 16.62735939], [82.2840271, 16.62680626], [82.28430176, 16.62681007], [82.28430176, 16.62624931], [82.28457642, 16.62624931], [82.28457642, 16.62513924], [82.2848587, 16.62513924], [82.2848587, 16.62430954], [82.28514099, 16.62430954], [82.28514099, 16.62347031], [82.28541565, 16.62347221], [82.28541565, 16.62291718], [82.28569794, 16.62292099], [82.28569794, 16.62207985], [82.2859726, 16.62208366], [82.2859726, 16.62152863], [82.28624725, 16.62153816], [82.28624725, 16.62070084], [82.28652954, 16.62070084], [82.28652954, 16.62014008], [82.28679657, 16.62014008], [82.28679657, 16.61958122], [82.28708649, 16.61958313], [82.28708649, 16.61902809], [82.28736877, 16.61903], [82.28736877, 16.61847115], [82.2876358, 16.61847305], [82.2876358, 16.61791611], [82.28791809, 16.61791992], [82.28791809, 16.61763954], [82.28819275, 16.61763954], [82.28819275, 16.61708069], [82.28847504, 16.6170845], [82.28847504, 16.61652756], [82.28874969, 16.61652946], [82.28874969, 16.6162529], [82.28901672, 16.6162529], [82.28901672, 16.61569023], [82.28930664, 16.61569214], [82.28930664, 16.61458206], [82.2895813, 16.61458206], [82.2895813, 16.61263847], [82.28985596, 16.61263847], [82.28985596, 16.61096954], [82.29013824, 16.61097145], [82.29013824, 16.61041641], [82.2904129, 16.61041832], [82.2904129, 16.61013985], [82.29070282, 16.61013985], [82.29070282, 16.60985947], [82.29096985, 16.60986137], [82.29096985, 16.6095829], [82.29180908, 16.6095829], [82.29180908, 16.60930634], [82.29207611, 16.60931015], [82.29207611, 16.60874939], [82.2923584, 16.60874939], [82.2923584, 16.60764122], [82.29207611, 16.60764122], [82.29207611, 16.60653114], [82.29180908, 16.60653114], [82.29180908, 16.60597038], [82.29152679, 16.60597229], [82.29152679, 16.60569572], [82.29125214, 16.60569572], [82.29125214, 16.60541725], [82.29096985, 16.60542107], [82.29096985, 16.60514069], [82.2904129, 16.60514069], [82.2904129, 16.60486031], [82.29013824, 16.60486031], [82.29013824, 16.60457993], [82.28986359, 16.60458374], [82.28986359, 16.60430527], [82.2895813, 16.60431099], [82.2895813, 16.60403061], [82.28901672, 16.60403061], [82.28901672, 16.60375023], [82.28874969, 16.60375023], [82.28874969, 16.60346985], [82.28819275, 16.60347366], [82.28819275, 16.60319519], [82.28791809, 16.60320091], [82.28791809, 16.60292053], [82.28736877, 16.60292053], [82.28736877, 16.60235977], [82.28708649, 16.60236359], [82.28708649, 16.60190964], [82.28708649, 16.60180473], [82.2868042, 16.60180473], [82.2868042, 16.6012516], [82.2848587, 16.6012516], [82.2848587, 16.60153008], [82.28375244, 16.60153008], [82.28375244, 16.6012516], [82.28347015, 16.6012516], [82.28347015, 16.60096931], [82.28263855, 16.60097122], [82.28263855, 16.60069466], [82.28152466, 16.60069466], [82.28152466, 16.60041618], [82.28125, 16.60041618], [82.28125, 16.60069466], [82.28069305, 16.60069466], [82.28069305, 16.60097122], [82.28013611, 16.60097122], [82.28013611, 16.60069466], [82.27986145, 16.60069466], [82.27986145, 16.60041618], [82.27903748, 16.60041618], [82.27874756, 16.60042953], [82.27874756, 16.60014153], [82.27819824, 16.60014153], [82.27819824, 16.59958076], [82.27680206, 16.59958267], [82.27680206, 16.59930611], [82.2765274, 16.59931183], [82.2765274, 16.59903145], [82.27625275, 16.59903145], [82.27625275, 16.59874916], [82.2756958, 16.59874916], [82.2756958, 16.59847069], [82.27430725, 16.5984726], [82.27430725, 16.59819412], [82.27097321, 16.59819412], [82.27097321, 16.59791756], [82.26819611, 16.59791756], [82.26819611, 16.59763908], [82.26597595, 16.59763908], [82.26597595, 16.59736824], [82.26568604, 16.59736824], [82.26568604, 16.59653091], [82.26541901, 16.59653091], [82.26541901, 16.59542084], [82.26513672, 16.59542084], [82.26513672, 16.59430122], [82.26486206, 16.59430695], [82.26486206, 16.59375], [82.26457977, 16.59375], [82.26457977, 16.59320068], [82.26431274, 16.59320068], [82.26431274, 16.59263992], [82.26403046, 16.59263992], [82.26403046, 16.59208107], [82.26374817, 16.59208488], [82.26374817, 16.59152794], [82.26346588, 16.59152985], [82.26346588, 16.5909729], [82.26319122, 16.59097481], [82.26319122, 16.59041595], [82.26291656, 16.59041977], [82.26291656, 16.58986282], [82.26264191, 16.58986282], [82.26264191, 16.58930969], [82.26235962, 16.58930969], [82.26235962, 16.58903122], [82.26207733, 16.58903122], [82.26207733, 16.58875275], [82.26180267, 16.58875275], [82.26180267, 16.58847046], [82.26152802, 16.58847046], [82.26152802, 16.58819389], [82.26125336, 16.58819962], [82.26125336, 16.58792114], [82.26097107, 16.58792114], [82.26097107, 16.58764267], [82.26069641, 16.58764267], [82.26069641, 16.58736038], [82.26013947, 16.58736038], [82.26013947, 16.58708191], [82.25986481, 16.58708382], [82.25986481, 16.58680534], [82.26125336, 16.58680534], [82.26125336, 16.58708382], [82.26152802, 16.58708191], [82.26152802, 16.58736038], [82.26180267, 16.58736038], [82.26180267, 16.58764267], [82.26235962, 16.58764267], [82.26235962, 16.58792114], [82.26264191, 16.58792114], [82.26264191, 16.58819962], [82.26291656, 16.58819389], [82.26291656, 16.58847046], [82.26319122, 16.58847046], [82.26319122, 16.58958054], [82.26374817, 16.58958054], [82.26374817, 16.58986282], [82.26403046, 16.58986282], [82.26403046, 16.59041977], [82.26430511, 16.59041595], [82.26430511, 16.59097481], [82.26457977, 16.5909729], [82.26457977, 16.59152985], [82.26486206, 16.59152794], [82.26486206, 16.59236145], [82.26513672, 16.59236145], [82.26513672, 16.59347153], [82.26541901, 16.59346962], [82.26541901, 16.59403038], [82.26569366, 16.59402847], [82.26569366, 16.59458351], [82.26597595, 16.5945797], [82.26597595, 16.59514046], [82.26625061, 16.59513855], [82.26625061, 16.59569359], [82.26652527, 16.59569359], [82.26652527, 16.59597206], [82.26763916, 16.59597015], [82.26763916, 16.59625053], [82.26875305, 16.59625053], [82.26875305, 16.59653091], [82.27069092, 16.59653091], [82.27069092, 16.59680748], [82.2729187, 16.59680557], [82.2729187, 16.59708405], [82.27485657, 16.59708023], [82.27485657, 16.59736824], [82.27540588, 16.59736824], [82.27540588, 16.59763908], [82.27625275, 16.59763908], [82.27625275, 16.59791756], [82.27735901, 16.59791756], [82.27735901, 16.59819412], [82.27819824, 16.59819412], [82.27819824, 16.5984726], [82.27874756, 16.59847069], [82.27874756, 16.59874916], [82.27986145, 16.59874916], [82.27986145, 16.59903145], [82.2804184, 16.59903145], [82.2804184, 16.59931183], [82.28069305, 16.59930611], [82.28069305, 16.59958267], [82.28124237, 16.59958076], [82.28124237, 16.59985924], [82.28235626, 16.59985924], [82.28235626, 16.60014153], [82.28347015, 16.60014153], [82.28347015, 16.60042953], [82.28569794, 16.60042953], [82.28569794, 16.60014153], [82.28736877, 16.60014153], [82.28736877, 16.60042953], [82.2876358, 16.60041618], [82.2876358, 16.60069466], [82.28778076, 16.60069466], [82.28874969, 16.60069466], [82.28874969, 16.60097122], [82.28930664, 16.60096931], [82.28930664, 16.6012516], [82.29013824, 16.6012516], [82.29013824, 16.60153008], [82.29069519, 16.60152817], [82.29069519, 16.60180473], [82.29152679, 16.60180473], [82.29152679, 16.6020813], [82.29208374, 16.6020813], [82.29208374, 16.60236359], [82.29264069, 16.60235977], [82.29264069, 16.60264015], [82.29402924, 16.60264015], [82.29402924, 16.60235977], [82.29458618, 16.60236359], [82.29458618, 16.60180473], [82.29486084, 16.60180473], [82.29486084, 16.6012516], [82.29514313, 16.6012516], [82.2951355, 16.60069466], [82.29541779, 16.60069466], [82.29541779, 16.59902763], [82.29569244, 16.59903145], [82.29569244, 16.59874916], [82.2959671, 16.59874916], [82.2959671, 16.59847069], [82.29652405, 16.5984726], [82.29652405, 16.59819412], [82.29680634, 16.59819412], [82.29680634, 16.59791756], [82.29708099, 16.59791756], [82.29708099, 16.59736824], [82.29736328, 16.59736824], [82.29736328, 16.59680748], [82.29763794, 16.59680748], [82.29763794, 16.59653091], [82.29792023, 16.59653091], [82.29792023, 16.59568977], [82.29819489, 16.59569359], [82.29819489, 16.59486198], [82.29846954, 16.59486198], [82.29846954, 16.59402847], [82.29875183, 16.59403038], [82.29875183, 16.59346962], [82.29902649, 16.59347153], [82.29902649, 16.59308815], [82.29902649, 16.59263802], [82.29930878, 16.59263992], [82.29930878, 16.59181023], [82.29957581, 16.59181023], [82.29957581, 16.59041977], [82.29930878, 16.59041977], [82.29930878, 16.58930969], [82.29902649, 16.58930969], [82.29902649, 16.58708191], [82.29875183, 16.58708382], [82.29875183, 16.58680534], [82.29846954, 16.58681107], [82.29846954, 16.5862484], [82.29818726, 16.5862484], [82.29818726, 16.58596992], [82.29763794, 16.58597183], [82.29763794, 16.58569527], [82.29736328, 16.58569908], [82.29736328, 16.58346939], [82.29708099, 16.5834713], [82.29708099, 16.58319473], [82.29680634, 16.58319473], [82.29680634, 16.58291626], [82.29651642, 16.58291817], [82.29651642, 16.58263969], [82.29624176, 16.58263969], [82.29624176, 16.58236122], [82.29569244, 16.58236122], [82.29569244, 16.58208084], [82.29541779, 16.58208275], [82.29541779, 16.58180618], [82.29514313, 16.58180809], [82.29514313, 16.58152962], [82.29486084, 16.58152962], [82.29486084, 16.58097076], [82.29458618, 16.58097267], [82.29458618, 16.58080292], [82.29458618, 16.5806942], [82.29430389, 16.5806942], [82.29430389, 16.57986069], [82.29402924, 16.57986069], [82.29402924, 16.57929993], [82.29374695, 16.57930565], [82.29374695, 16.57902718], [82.29402924, 16.57903099], [82.29402924, 16.57875061], [82.29374695, 16.57875061], [82.29374695, 16.57736015], [82.29347229, 16.57736206], [82.29347229, 16.57680511], [82.29319763, 16.57681084], [82.29319763, 16.57653046], [82.29292297, 16.57653046], [82.29292297, 16.57625961], [82.29264069, 16.57625961], [82.29264069, 16.57570076], [82.2923584, 16.57570076], [82.2923584, 16.57542038], [82.29207611, 16.57542038], [82.29207611, 16.57485962], [82.29125214, 16.57485962], [82.29125214, 16.57458115], [82.29096985, 16.57458115], [82.29096985, 16.57402992], [82.29070282, 16.57403183], [82.29070282, 16.57346916], [82.2904129, 16.57347107], [82.2904129, 16.5731945], [82.29013824, 16.57320023], [82.29013824, 16.57264137], [82.28985596, 16.57264137], [82.28985596, 16.57208061], [82.2895813, 16.57208252], [82.2895813, 16.57125092], [82.28930664, 16.57125092], [82.28930664, 16.57097054], [82.28902435, 16.57097244], [82.28902435, 16.57069397], [82.28847504, 16.57069397], [82.28847504, 16.5704174], [82.28819275, 16.57042122], [82.28819275, 16.57014084], [82.28736115, 16.57013893], [82.28736115, 16.57069397], [82.28708649, 16.57069016], [82.28708649, 16.57125092], [82.28679657, 16.57125092], [82.28679657, 16.57152748], [82.28652954, 16.57152748], [82.28652954, 16.57208252], [82.28624725, 16.57208061], [82.28624725, 16.57264137], [82.28457642, 16.57264137], [82.28457642, 16.57235909], [82.28291321, 16.57235909], [82.28291321, 16.57208061], [82.28152466, 16.57208252], [82.28152466, 16.57180595], [82.28069305, 16.57180977], [82.28069305, 16.57152748], [82.27874756, 16.57152748], [82.27874756, 16.57125092], [82.27791595, 16.57125092], [82.27791595, 16.57097054], [82.2776413, 16.57097244], [82.2776413, 16.57069397], [82.27735901, 16.57069397], [82.27735901, 16.5704174], [82.27680206, 16.57042122], [82.27680206, 16.57014084], [82.27597046, 16.57014084], [82.27597046, 16.56986046], [82.27540588, 16.56986046], [82.27540588, 16.56931114], [82.27485657, 16.56931114], [82.27485657, 16.56903076], [82.27430725, 16.56903076], [82.27430725, 16.56875038], [82.27401733, 16.56875038], [82.27401733, 16.56820107], [82.27375031, 16.56820107], [82.27375031, 16.56792068], [82.27348328, 16.56792068], [82.27348328, 16.5676403], [82.27319336, 16.5676403], [82.27319336, 16.56735992], [82.27263641, 16.56736183], [82.27263641, 16.56708336], [82.2720871, 16.56708336], [82.2720871, 16.56680679], [82.27153015, 16.56680679], [82.27153015, 16.56652832], [82.27097321, 16.56653023], [82.27097321, 16.56624985], [82.27041626, 16.56624985], [82.27041626, 16.56596947], [82.26985931, 16.56597137], [82.26985931, 16.56569481], [82.26958466, 16.56569481], [82.26958466, 16.56541634], [82.26930237, 16.56542015], [82.26930237, 16.56513977], [82.26847076, 16.56513977], [82.26847076, 16.56485939], [82.26819611, 16.5648613], [82.26819611, 16.56458473], [82.26791382, 16.56458473], [82.26791382, 16.56402779], [82.26847076, 16.56402969], [82.26847076, 16.56375122], [82.26875305, 16.56375122], [82.26875305, 16.56347275], [82.26958466, 16.56347466], [82.26958466, 16.56319427], [82.27069092, 16.56319427], [82.27069092, 16.5629158], [82.27097321, 16.56291962], [82.27097321, 16.56264114], [82.27124786, 16.56264114], [82.27124786, 16.56236267], [82.27153015, 16.56236267], [82.27153015, 16.56208038], [82.27180481, 16.5620842], [82.27180481, 16.56180573], [82.2720871, 16.56180954], [82.2720871, 16.56153107], [82.27236176, 16.56153107], [82.27236176, 16.56097031], [82.27263641, 16.56097031], [82.27263641, 16.56041718], [82.2729187, 16.5604229], [82.2729187, 16.5601387], [82.27348328, 16.5601387], [82.27348328, 16.55985832], [82.27458191, 16.55985832], [82.27458191, 16.5601387], [82.27485657, 16.5601387], [82.27485657, 16.5604229], [82.27597046, 16.5604229], [82.27597046, 16.5601387], [82.27902985, 16.5601387], [82.27902985, 16.5604229], [82.2793045, 16.56041718], [82.2793045, 16.56069374], [82.2804184, 16.56069374], [82.2804184, 16.56097031], [82.28069305, 16.56097031], [82.28069305, 16.56126022], [82.28098297, 16.56126022], [82.28098297, 16.56180954], [82.28125, 16.56180573], [82.28125, 16.5620842], [82.28180695, 16.56208038], [82.28180695, 16.56236267], [82.28235626, 16.56236267], [82.28235626, 16.56264114], [82.2831955, 16.56263924], [82.2831955, 16.56319427], [82.28375244, 16.56319427], [82.28375244, 16.5629158], [82.28457642, 16.56291962], [82.28457642, 16.56264114], [82.28652954, 16.56264114], [82.28652954, 16.56291962], [82.2868042, 16.5629158], [82.2868042, 16.56319427], [82.28736115, 16.56319427], [82.28736115, 16.56347466], [82.2876358, 16.56347275], [82.2876358, 16.56375122], [82.28819275, 16.56375122], [82.28819275, 16.56402969], [82.28851318, 16.56402969], [82.2904129, 16.56402969], [82.2904129, 16.56375122], [82.2923584, 16.56375122], [82.2923584, 16.56402969], [82.29264069, 16.56402969], [82.29264069, 16.56431961], [82.29402924, 16.56430626], [82.29402924, 16.56458473], [82.29430389, 16.56458473], [82.29430389, 16.5648613], [82.29486084, 16.56485939], [82.29486084, 16.56513977], [82.29514313, 16.56513977], [82.29514313, 16.56542015], [82.29569244, 16.56541634], [82.29569244, 16.56597137], [82.29541779, 16.56597137], [82.29541779, 16.56680679], [82.29736328, 16.56680679], [82.29736328, 16.56708336], [82.29792023, 16.56708336], [82.29792023, 16.56680679], [82.29819489, 16.56680679], [82.29819489, 16.56652832], [82.29875183, 16.56652832], [82.29875183, 16.56680679], [82.29902649, 16.56680107], [82.29902649, 16.5676403], [82.29957581, 16.5676403], [82.29957581, 16.56792068], [82.30042267, 16.56792068], [82.30042267, 16.56820107], [82.30097198, 16.56820107], [82.30097198, 16.56792068], [82.30179596, 16.56792068], [82.30179596, 16.56820107], [82.30208588, 16.56819534], [82.30208588, 16.56847191], [82.30263519, 16.56847191], [82.30263519, 16.56875038], [82.30291748, 16.56875038], [82.30291748, 16.56903076], [82.30319214, 16.56903076], [82.30319214, 16.56875038], [82.30596924, 16.56875038], [82.30596924, 16.56903076], [82.30708313, 16.56902695], [82.30708313, 16.56921005], [82.30708313, 16.57069397], [82.30680847, 16.57069397], [82.30680847, 16.57097244], [82.30652618, 16.57097054], [82.30652618, 16.57152748], [82.30680847, 16.57152748], [82.30680847, 16.57208252], [82.30652618, 16.57208061], [82.30652618, 16.57264137], [82.30625153, 16.57264137], [82.30625153, 16.57374954], [82.30596924, 16.57374954], [82.30596924, 16.57394028], [82.30596924, 16.57458115], [82.30652618, 16.57458115], [82.30652618, 16.57430649], [82.30708313, 16.57430077], [82.30708313, 16.57402992], [82.30764008, 16.57403183], [82.30764008, 16.57374954], [82.30847168, 16.57374954], [82.30847168, 16.57349014], [82.3086319, 16.57348442], [82.30902863, 16.57347107], [82.30902863, 16.57332039], [82.30902863, 16.57291603], [82.3095932, 16.57292175], [82.3095932, 16.57235909], [82.30986023, 16.57235909], [82.30986023, 16.57208061], [82.31014252, 16.57208252], [82.31014252, 16.57152748], [82.31041718, 16.57152748], [82.31041718, 16.57069016], [82.31069183, 16.57069397], [82.31069183, 16.5704174], [82.31096649, 16.57042122], [82.31096649, 16.56958008], [82.31069183, 16.56958389], [82.31069183, 16.56875038], [82.31041718, 16.56875038], [82.31041718, 16.56820107], [82.31014252, 16.56820107], [82.31014252, 16.56792068], [82.30986023, 16.56792068], [82.30986023, 16.5676403], [82.30847168, 16.56763077], [82.30847168, 16.56736183], [82.30791473, 16.56736183], [82.30791473, 16.56708336], [82.30708313, 16.56708336], [82.30708313, 16.56680679], [82.30596924, 16.56680679], [82.30596924, 16.56652832], [82.30541229, 16.56653023], [82.30541229, 16.56624985], [82.30486298, 16.56624985], [82.30486298, 16.56596947], [82.30403137, 16.56597137], [82.30403137, 16.56569481], [82.30319214, 16.56569481], [82.30319214, 16.56541634], [82.30208588, 16.56542015], [82.30208588, 16.56513977], [82.30179596, 16.56513977], [82.30179596, 16.56485939], [82.30152893, 16.5648613], [82.30152893, 16.56458473], [82.30069733, 16.56458473], [82.30069733, 16.56430626], [82.30014038, 16.56431961], [82.30014038, 16.56402969], [82.29957581, 16.56402969], [82.29957581, 16.56375122], [82.29846954, 16.56375122], [82.29846954, 16.56347275], [82.29736328, 16.56347466], [82.29736328, 16.56319427], [82.29680634, 16.56319427], [82.29680634, 16.5629158], [82.29624176, 16.56291962], [82.29624176, 16.56264114], [82.2959671, 16.56264114], [82.2959671, 16.56236267], [82.29569244, 16.56236267], [82.29569244, 16.56208038], [82.29541779, 16.5620842], [82.29541779, 16.56180573], [82.29486084, 16.56180954], [82.29486084, 16.56153107], [82.29458618, 16.56153107], [82.29458618, 16.56126022], [82.29319763, 16.56126022], [82.29319763, 16.56097031], [82.29264069, 16.56097031], [82.29264069, 16.56069374], [82.2923584, 16.56069374], [82.2923584, 16.56041718], [82.29207611, 16.5604229], [82.29207611, 16.5601387], [82.29152679, 16.5601387], [82.29152679, 16.55985832], [82.29096985, 16.55985832], [82.29096985, 16.55957985], [82.29069519, 16.55958366], [82.29069519, 16.55930519], [82.28985596, 16.55931091], [82.28985596, 16.55903053], [82.28930664, 16.55903053], [82.28930664, 16.55874825], [82.28874969, 16.55874825], [82.28874969, 16.55846977], [82.28791809, 16.55847168], [82.28791809, 16.55819511], [82.28736877, 16.55820084], [82.28736877, 16.55792046], [82.28695679, 16.55792046], [82.28679657, 16.55792046], [82.28678894, 16.55770874], [82.28652954, 16.55763817], [82.28652954, 16.5574894], [82.28652954, 16.5573616], [82.28617859, 16.5573616], [82.28569794, 16.5573616], [82.28569794, 16.55708313], [82.28544617, 16.55708313], [82.2840271, 16.55708313], [82.2840271, 16.55680466], [82.2831955, 16.55680466], [82.2831955, 16.55652618], [82.28235626, 16.55652809], [82.28235626, 16.55624962], [82.2804184, 16.55624962], [82.2804184, 16.55597115], [82.27819824, 16.55597305], [82.27819061, 16.55569458], [82.27791595, 16.55569458], [82.27791595, 16.55541611], [82.2776413, 16.55541992], [82.2776413, 16.55513], [82.27735901, 16.55513954], [82.27735901, 16.55486107], [82.27485657, 16.55486107], [82.27485657, 16.55458069], [82.27402496, 16.5545826], [82.27402496, 16.55430794], [82.27375031, 16.55430984], [82.27375031, 16.55402946], [82.27319336, 16.55402946], [82.27319336, 16.55375099], [82.27153015, 16.55375099], [82.27153015, 16.55347061], [82.27124786, 16.55347252], [82.27124786, 16.55319595], [82.27041626, 16.55319595], [82.27041626, 16.55291748], [82.26902771, 16.55291939], [82.26902771, 16.55264091], [82.26819611, 16.55264091], [82.26819611, 16.55236053], [82.26652527, 16.55236053], [82.26652527, 16.55208588], [82.26541901, 16.55208588], [82.26541901, 16.5518055], [82.26457977, 16.55181122], [82.26457977, 16.55153084], [82.26403046, 16.55153084], [82.26403046, 16.55125046], [82.26319122, 16.55125046], [82.26319122, 16.55097389], [82.26208496, 16.55097389], [82.26208496, 16.55069542], [82.26040649, 16.5506897], [82.26041412, 16.55041695], [82.25985718, 16.55042076], [82.25985718, 16.55014038], [82.2590332, 16.55014038], [82.2590332, 16.54986191], [82.25819397, 16.54986382], [82.25819397, 16.54958344], [82.25680542, 16.54958344], [82.25680542, 16.54930305], [82.25624847, 16.54932022], [82.25624847, 16.5490303], [82.25541687, 16.5490303], [82.25541687, 16.54875183], [82.25458527, 16.54875183], [82.25458527, 16.54847336], [82.25421143, 16.54847336], [82.25375366, 16.54847336], [82.25375366, 16.54819489], [82.25291443, 16.54819489], [82.25291443, 16.54791641], [82.25208282, 16.54792023], [82.25208282, 16.54764175], [82.25125885, 16.54764175], [82.25125885, 16.54735947], [82.24986267, 16.54735947], [82.24986267, 16.54680634], [82.24931335, 16.54681015], [82.24931335, 16.54653168], [82.24874878, 16.54653168], [82.24874878, 16.54626274], [82.24736023, 16.54626274], [82.24736023, 16.54597092], [82.24652863, 16.54597282], [82.24652863, 16.54569435], [82.24597168, 16.54569435], [82.24597168, 16.54541588], [82.2454071, 16.5454216], [82.2454071, 16.54513931], [82.24430847, 16.54513931], [82.24430847, 16.54486084], [82.24375153, 16.54486084], [82.24375153, 16.54458046], [82.24263763, 16.54458427], [82.24263763, 16.5443058], [82.24180603, 16.54430962], [82.24180603, 16.54403114], [82.24124908, 16.54403114], [82.24124908, 16.54375076], [82.24069214, 16.54375076], [82.24069214, 16.54347038], [82.23986053, 16.54347229], [82.23986053, 16.54319382], [82.23958588, 16.54319382], [82.23958588, 16.54291725], [82.23874664, 16.54292107], [82.23874664, 16.54264069], [82.23819733, 16.54264069], [82.23819733, 16.54236031], [82.23792267, 16.54236031], [82.23792267, 16.54264069], [82.23764038, 16.54264069], [82.23764038, 16.54236031], [82.23735809, 16.54236031], [82.23735809, 16.54207993], [82.23652649, 16.54208374], [82.23652649, 16.54180527], [82.23568726, 16.54181099], [82.23568726, 16.54153061], [82.23458099, 16.54153061], [82.23458099, 16.54125023], [82.23401642, 16.54125023], [82.23401642, 16.54096985], [82.23347473, 16.54097176], [82.23347473, 16.54069519], [82.23264313, 16.54070091], [82.23264313, 16.54042053], [82.23208618, 16.54042053], [82.23208618, 16.54013062], [82.23124695, 16.54013824], [82.23124695, 16.53986168], [82.23097229, 16.53986168], [82.23097229, 16.53958321], [82.22930908, 16.53958321], [82.22930908, 16.53930473], [82.22875214, 16.53930473], [82.22875214, 16.53902817], [82.22820282, 16.53903008], [82.22820282, 16.53874969], [82.2279129, 16.53874969], [82.2279129, 16.53847122], [82.22763824, 16.53847313], [82.22763824, 16.53819466], [82.22736359, 16.53819466], [82.22736359, 16.53847313], [82.22680664, 16.53847313], [82.22680664, 16.53819466], [82.22624969, 16.53819466], [82.22624969, 16.53791618], [82.22541809, 16.53791618], [82.22541809, 16.53819466], [82.2251358, 16.53819466], [82.2251358, 16.53791618], [82.22429657, 16.53792], [82.22429657, 16.53763962], [82.22402954, 16.53763962], [82.22402954, 16.53736115], [82.22374725, 16.53736115], [82.22374725, 16.5370903], [82.22319794, 16.5370903], [82.22319794, 16.53680992], [82.2223587, 16.53680992], [82.2223587, 16.53652954], [82.2215271, 16.53652954], [82.2215271, 16.53625107], [82.22125244, 16.53625107], [82.22125244, 16.53569031], [82.22097015, 16.53569221], [82.22097015, 16.53541756], [82.2195816, 16.53541946], [82.2195816, 16.5351429], [82.21901703, 16.5351429], [82.21901703, 16.53486252], [82.21875, 16.53486252], [82.21875, 16.53458023], [82.21819305, 16.53458405], [82.21819305, 16.53430557], [82.21736145, 16.53430939], [82.21736145, 16.53403282], [82.21624756, 16.53403282], [82.21624756, 16.53375244], [82.21569824, 16.53375244], [82.21569061, 16.53346825], [82.21541595, 16.53347015], [82.21541595, 16.53319359], [82.2151413, 16.53319359], [82.2151413, 16.53291702], [82.21457672, 16.53292084], [82.21457672, 16.53263855], [82.21430206, 16.53263855], [82.21430206, 16.53292084], [82.21347046, 16.53292084], [82.21347046, 16.53263855], [82.21290588, 16.53263855], [82.21290588, 16.53235817], [82.21263885, 16.53236008], [82.21263885, 16.53208351], [82.2123642, 16.53208351], [82.2123642, 16.53180504], [82.21180725, 16.53181076], [82.21180725, 16.53152847], [82.21069336, 16.53152847], [82.21069336, 16.53124809], [82.2104187, 16.53124809], [82.2104187, 16.53096008], [82.20986176, 16.53097153], [82.20986176, 16.53069496], [82.20929718, 16.53070068], [82.20929718, 16.5304203], [82.20902252, 16.5304203], [82.20902252, 16.53013992], [82.20819092, 16.53013992], [82.20819092, 16.52985954], [82.2076416, 16.52986145], [82.2076416, 16.52958298], [82.20708466, 16.52958298], [82.20708466, 16.52902794], [82.20540619, 16.52902985], [82.20540619, 16.52874947], [82.20513916, 16.52874947], [82.20513916, 16.52847099], [82.2048645, 16.5284729], [82.2048645, 16.52819443], [82.20430756, 16.52819443], [82.20430756, 16.52791786], [82.20347595, 16.52791977], [82.20347595, 16.52763939], [82.20318604, 16.52763939], [82.20318604, 16.52736092], [82.20263672, 16.52736092], [82.20263672, 16.52708054], [82.20236206, 16.52708244], [82.20236206, 16.52680588], [82.20069122, 16.52680969], [82.20069122, 16.52653122], [82.20014954, 16.52653122], [82.20014954, 16.52625084], [82.19957733, 16.52625084], [82.19957733, 16.52542114], [82.19875336, 16.52542114], [82.19875336, 16.5251503], [82.19819641, 16.5251503], [82.19819641, 16.52486038], [82.19735718, 16.52486038], [82.19735718, 16.52458], [82.19680786, 16.52458572], [82.19680786, 16.52430534], [82.19596863, 16.52431107], [82.19596863, 16.52403069], [82.19541931, 16.52403069], [82.19541931, 16.52375031], [82.19486237, 16.52375031], [82.19486237, 16.52346992], [82.19403076, 16.52347374], [82.19403076, 16.52319527], [82.19374847, 16.5232029], [82.19374847, 16.52292061], [82.19291687, 16.52292061], [82.19291687, 16.52264023], [82.19235992, 16.52264023], [82.19235992, 16.52236176], [82.19180298, 16.52236366], [82.19180298, 16.52208138], [82.19124603, 16.52209282], [82.19124603, 16.5218029], [82.19041443, 16.52180481], [82.19041443, 16.52152824], [82.18985748, 16.52153015], [82.18985748, 16.52125168], [82.18930817, 16.52125168], [82.18930817, 16.52096939], [82.18875122, 16.52096939], [82.18875122, 16.52069473], [82.18819427, 16.52069473], [82.18819427, 16.52041626], [82.18763733, 16.52042007], [82.18763733, 16.5201416], [82.18708038, 16.5201416], [82.18708038, 16.51985931], [82.18653107, 16.51985931], [82.18653107, 16.51958084], [82.18624878, 16.51958275], [82.18624878, 16.51930618], [82.18596649, 16.5193119], [82.18596649, 16.51901817], [82.18541718, 16.51902771], [82.18541718, 16.51874924], [82.18514252, 16.51874924], [82.18514252, 16.51847076], [82.18402863, 16.51847267], [82.18402863, 16.5181942], [82.18319702, 16.5181942], [82.18319702, 16.51791763], [82.1829071, 16.51791763], [82.1829071, 16.51763916], [82.18208313, 16.51763916], [82.18208313, 16.51736069], [82.18152618, 16.51736069], [82.18152618, 16.51708031], [82.18096924, 16.51708412], [82.18096924, 16.51680565], [82.18068695, 16.51680946], [82.18068695, 16.51652908], [82.18013763, 16.51652908], [82.18013763, 16.51625061], [82.17986298, 16.51625061], [82.17986298, 16.51596069], [82.17930603, 16.51597214], [82.17930603, 16.51569366], [82.17874908, 16.51569366], [82.17874908, 16.51541519], [82.1784668, 16.51542091], [82.1784668, 16.51514053], [82.17791748, 16.51514053], [82.17791748, 16.51486015], [82.17736053, 16.51486206], [82.17736053, 16.51458359], [82.17708588, 16.51458359], [82.17708588, 16.51430511], [82.17679596, 16.51431084], [82.17679596, 16.51403046], [82.17652893, 16.51403046], [82.17652893, 16.51375008], [82.17597961, 16.51375008], [82.17597961, 16.51403046], [82.17514038, 16.51403046], [82.17514038, 16.51375008], [82.17457581, 16.51375008], [82.17457581, 16.5134697], [82.17430878, 16.5134716], [82.17430878, 16.51291656], [82.17402649, 16.51292038], [82.17402649, 16.51264], [82.17318726, 16.51264], [82.17318726, 16.51235962], [82.17263794, 16.51235962], [82.17263794, 16.51264], [82.17208099, 16.51264], [82.17208099, 16.51235962], [82.17152405, 16.51236153], [82.17152405, 16.51152802], [82.17124939, 16.51152992], [82.17124939, 16.51124954], [82.1709671, 16.51124954], [82.1709671, 16.51097107], [82.17069244, 16.51097488], [82.17069244, 16.5106945], [82.16986084, 16.5106945], [82.16986084, 16.51041603], [82.16929626, 16.51041985], [82.16929626, 16.51015091], [82.16847229, 16.51015091], [82.16847229, 16.5098629], [82.16819763, 16.5098629], [82.16819763, 16.50958061], [82.16764069, 16.50958061], [82.16764069, 16.50930595], [82.16707611, 16.50930977], [82.16707611, 16.50902939], [82.16652679, 16.50902939], [82.16652679, 16.50875282], [82.16596985, 16.50875282], [82.16596985, 16.50847054], [82.16569519, 16.50847054], [82.16569519, 16.50819206], [82.1654129, 16.50819206], [82.1654129, 16.5079174], [82.1645813, 16.50792122], [82.1645813, 16.50764275], [82.16401672, 16.50764275], [82.16401672, 16.50736237], [82.16347504, 16.50736237], [82.16347504, 16.50708389], [82.1626358, 16.50708389], [82.1626358, 16.50680542], [82.16236115, 16.50681114], [82.16236115, 16.50653076], [82.16208649, 16.50653076], [82.16208649, 16.50624847], [82.16124725, 16.50624847], [82.16124725, 16.50596809], [82.16014099, 16.50597191], [82.16014099, 16.50569534], [82.15957642, 16.50569916], [82.15957642, 16.50542068], [82.1590271, 16.50542068], [82.1590271, 16.5051384], [82.15838623, 16.5051384], [82.15820313, 16.5051384], [82.15820313, 16.50485992], [82.15791321, 16.50486183], [82.15791321, 16.50458336], [82.15763855, 16.50458336], [82.15763855, 16.50430489], [82.15680695, 16.50430489], [82.15680695, 16.50402832], [82.15625, 16.50402832], [82.15625, 16.50374985], [82.15569305, 16.50374985], [82.15569305, 16.50346947], [82.1543045, 16.50347137], [82.1543045, 16.50291634], [82.15402985, 16.50291824], [82.15402985, 16.50263977], [82.15319824, 16.50263977], [82.15319061, 16.50235939], [82.15291595, 16.5023613], [82.15291595, 16.50208282], [82.1526413, 16.50208282], [82.1526413, 16.50180626], [82.15207672, 16.50181007], [82.15207672, 16.50152969], [82.15180969, 16.50152969], [82.15180969, 16.50125122], [82.15125275, 16.50125122], [82.15125275, 16.50098038], [82.15040588, 16.50098038], [82.15040588, 16.50069046], [82.15013885, 16.50069427], [82.15013885, 16.5004158], [82.14930725, 16.50041962], [82.14930725, 16.50014114], [82.14848328, 16.50014114], [82.14848328, 16.49986076], [82.1479187, 16.49986076], [82.1479187, 16.49958038], [82.14653015, 16.4995842], [82.14653015, 16.49930573], [82.14597321, 16.49930954], [82.14597321, 16.49903107], [82.1451416, 16.49903107], [82.1451416, 16.49875069], [82.14457703, 16.49875069], [82.14457703, 16.49847031], [82.14430237, 16.49847221], [82.14430237, 16.49819565], [82.14375305, 16.49819565], [82.14375305, 16.4976387], [82.14235687, 16.49764061], [82.14235687, 16.49792099], [82.1415329, 16.49792099], [82.1415329, 16.49736023], [82.14125061, 16.49736023], [82.14125061, 16.49707985], [82.14097595, 16.49708366], [82.14097595, 16.49680519], [82.14068604, 16.49681091], [82.14068604, 16.49653053], [82.14041901, 16.49653053], [82.14041901, 16.49625015], [82.14013672, 16.49625015], [82.14013672, 16.49596977], [82.13931274, 16.49596977], [82.13931274, 16.49653053], [82.13903046, 16.49653053], [82.13903046, 16.49570084], [82.13846588, 16.49570084], [82.13846588, 16.49542046], [82.13819122, 16.49542046], [82.13819122, 16.49514008], [82.1368103, 16.49514008], [82.1368103, 16.49484825], [82.13652802, 16.4948597], [82.13652802, 16.49458122], [82.13625336, 16.49458122], [82.13625336, 16.49430466], [82.13569641, 16.49430466], [82.13569641, 16.49402809], [82.13513947, 16.49403191], [82.13513947, 16.49375153], [82.13402557, 16.49375153], [82.13402557, 16.49347115], [82.13346863, 16.49347115], [82.13346863, 16.49291611], [82.13291931, 16.49292183], [82.13291931, 16.49264145], [82.13236237, 16.49264145], [82.13236237, 16.49208069], [82.13208008, 16.4920826], [82.13208008, 16.49180603], [82.13168335, 16.49180603], [82.13014221, 16.49181175], [82.13014221, 16.49152756], [82.12985992, 16.49152756], [82.12985992, 16.49124908], [82.12930298, 16.49124908], [82.12930298, 16.49097061], [82.12902832, 16.49097252], [82.12902832, 16.49069405], [82.12819672, 16.49069405], [82.12819672, 16.49041748], [82.12708282, 16.49041748], [82.12708282, 16.49014091], [82.12680817, 16.49014091], [82.12680817, 16.48986053], [82.12652588, 16.48986053], [82.12652588, 16.48958015], [82.12569427, 16.48958397], [82.12569427, 16.4893055], [82.1248703, 16.48931122], [82.1248703, 16.48904037], [82.12458038, 16.48904037], [82.12458038, 16.48875046], [82.12403107, 16.48875046], [82.12403107, 16.48847008], [82.12374878, 16.48847198], [82.12374878, 16.48819542], [82.12264252, 16.4881897], [82.12264252, 16.48791695], [82.1220932, 16.48792076], [82.1220932, 16.48764038], [82.12124634, 16.48764038], [82.12124634, 16.48736], [82.12097168, 16.48736191], [82.12097168, 16.48708344], [82.12041473, 16.48708344], [82.12041473, 16.4865284], [82.12014008, 16.4865303], [82.12014008, 16.48598099], [82.11958313, 16.48598099], [82.11958313, 16.48569107], [82.11875153, 16.48569489], [82.11875153, 16.48541641], [82.11791992, 16.48541641], [82.11791992, 16.48569489], [82.11763763, 16.48569489], [82.11763763, 16.48541641], [82.11680603, 16.48542023], [82.11680603, 16.48513985], [82.11541748, 16.48513985], [82.11541748, 16.48624992], [82.11514282, 16.48624992], [82.11514282, 16.48681068], [82.11486053, 16.48680687], [82.11486053, 16.48708344], [82.11458588, 16.48707962], [82.11458588, 16.48764038], [82.11429596, 16.48764038], [82.11429596, 16.48792076], [82.11402893, 16.48791695], [82.11402893, 16.4881897], [82.11374664, 16.48819542], [82.11374664, 16.48847198], [82.11264038, 16.48847198], [82.11264038, 16.48819542], [82.11235809, 16.4881897], [82.11235809, 16.48763847], [82.11207581, 16.48764038], [82.11207581, 16.48736], [82.11235809, 16.48736191], [82.11235809, 16.48569489], [82.11264038, 16.48569489], [82.11264038, 16.48541641], [82.1129303, 16.48542023], [82.1129303, 16.48485947], [82.11319733, 16.48486137], [82.11319733, 16.48458481], [82.11347198, 16.48458481], [82.11347198, 16.48430634], [82.11402893, 16.48431015], [82.11402893, 16.48374939], [82.11374664, 16.48374939], [82.11374664, 16.48347282], [82.11347198, 16.48347473], [82.11347198, 16.48319435], [82.11291504, 16.48319435], [82.11291504, 16.48291588], [82.11235809, 16.48291588], [82.11235809, 16.48263931], [82.11207581, 16.48264122], [82.11207581, 16.48236275], [82.11152649, 16.48236275], [82.11152649, 16.48208046], [82.11096954, 16.48208427], [82.11096954, 16.4818058], [82.11042023, 16.48180962], [82.11042023, 16.48153114], [82.10986328, 16.48153114], [82.10986328, 16.48125267], [82.10957336, 16.48125267], [82.10957336, 16.48097038], [82.10902405, 16.48097038], [82.10902405, 16.48069382], [82.10847473, 16.48069382], [82.10847473, 16.48041725], [82.10791779, 16.48042107], [82.10791779, 16.48014259], [82.10736084, 16.48014259], [82.10736084, 16.47985077], [82.10680389, 16.4798584], [82.10680389, 16.47958374], [82.10624695, 16.47958374], [82.10624695, 16.47930527], [82.10542297, 16.47930908], [82.10542297, 16.47903061], [82.1048584, 16.47903061], [82.1048584, 16.47874832], [82.10402679, 16.47874832], [82.10402679, 16.47846985], [82.10346985, 16.47847176], [82.10346985, 16.47819519], [82.10263824, 16.47820091], [82.10263824, 16.47792053], [82.1020813, 16.47792053], [82.1020813, 16.47763824], [82.10124969, 16.47763824], [82.10124969, 16.47735977], [82.10069275, 16.47736168], [82.10069275, 16.47708321], [82.10041809, 16.47708321], [82.10041809, 16.47680473], [82.1001358, 16.47680473], [82.1001358, 16.47652626], [82.09958649, 16.47652817], [82.09958649, 16.47624969], [82.09902954, 16.47624969], [82.09902954, 16.47597122], [82.09874725, 16.47597313], [82.09874725, 16.47569466], [82.0984726, 16.47569466], [82.0984726, 16.47541618], [82.09792328, 16.47541809], [82.09792328, 16.47513962], [82.09707642, 16.47513962], [82.09707642, 16.47486115], [82.0965271, 16.47486115], [82.0965271, 16.47458076], [82.09597015, 16.47458267], [82.09597015, 16.47430611], [82.09541321, 16.47430992], [82.09541321, 16.47404099], [82.09456635, 16.47404099], [82.09456635, 16.47375107], [82.09430695, 16.47375107], [82.09430695, 16.47347069], [82.09375, 16.4734726], [82.09375, 16.47319412], [82.09319305, 16.47319412], [82.09319305, 16.47291756], [82.09236145, 16.47291946], [82.09236145, 16.47264099], [82.09152985, 16.47264099], [82.09152985, 16.47236061], [82.09124756, 16.47236061], [82.09124756, 16.47208023], [82.0909729, 16.47208595], [82.0909729, 16.47180557], [82.09041595, 16.47180939], [82.09041595, 16.47153091], [82.0901413, 16.47153091], [82.0901413, 16.47097015], [82.08875275, 16.47097206], [82.08875275, 16.47069359], [82.08847046, 16.47069359], [82.08847046, 16.47041702], [82.08790588, 16.47042084], [82.08790588, 16.47014046], [82.08735657, 16.47014046], [82.08735657, 16.46986008], [82.08680725, 16.46986389], [82.08680725, 16.46958351], [82.08652496, 16.46958351], [82.08652496, 16.46930504], [82.08598328, 16.46931076], [82.08598328, 16.46903038], [82.0854187, 16.46903038], [82.0854187, 16.46875191], [82.08429718, 16.46875191], [82.08429718, 16.46846962], [82.08374786, 16.46847343], [82.08374786, 16.46819496], [82.08319092, 16.46820068], [82.08319092, 16.46791077], [82.0826416, 16.46791649], [82.0826416, 16.46763802], [82.08180237, 16.46764183], [82.08180237, 16.46735954], [82.08152771, 16.46735954], [82.08152771, 16.46708107], [82.08097076, 16.46708107], [82.08097076, 16.46680641], [82.08013916, 16.46681023], [82.08013916, 16.46653175], [82.07958984, 16.46653175], [82.07958984, 16.46624947], [82.07875061, 16.46624947], [82.07875061, 16.46596909], [82.07847595, 16.4659729], [82.07847595, 16.46569443], [82.07791901, 16.46569443], [82.07791901, 16.46541595], [82.07736206, 16.46542168], [82.07736206, 16.46513748], [82.07680511, 16.46513748], [82.07680511, 16.46486092], [82.07653046, 16.46486092], [82.07653046, 16.46458244], [82.07624817, 16.46458244], [82.07624817, 16.46430588], [82.07596588, 16.46430969], [82.07596588, 16.46403122], [82.07541656, 16.46403122], [82.07541656, 16.46375084], [82.07514191, 16.46375084], [82.07514191, 16.46347046], [82.07347107, 16.46347237], [82.07347107, 16.46319389], [82.07291412, 16.46319389], [82.07291412, 16.46291733], [82.07263947, 16.46292114], [82.07263947, 16.46264076], [82.07235718, 16.46264076], [82.07235718, 16.46236038], [82.07180786, 16.46236038], [82.07180786, 16.46208], [82.07125092, 16.46208382], [82.07125092, 16.46180534], [82.07068634, 16.46181107], [82.07068634, 16.46125031], [82.06986237, 16.46125031], [82.06986237, 16.46096992], [82.06958008, 16.46097183], [82.06958008, 16.46069527], [82.06903076, 16.46070099], [82.06903076, 16.46042061], [82.06846619, 16.46042061], [82.06846619, 16.46014023], [82.06791687, 16.46014023], [82.06791687, 16.45985985], [82.06735992, 16.45986176], [82.06735992, 16.45958328], [82.06680298, 16.45958328], [82.06680298, 16.45930481], [82.06625366, 16.45930481], [82.06625366, 16.45902824], [82.06597137, 16.45903015], [82.06597137, 16.45874977], [82.06569672, 16.45874977], [82.06569672, 16.45846939], [82.06541443, 16.4584713], [82.06541443, 16.45819473], [82.06458282, 16.45819473], [82.06458282, 16.45791626], [82.06346893, 16.45792007], [82.06346893, 16.45763969], [82.06318665, 16.45763969], [82.06318665, 16.45736122], [82.06291962, 16.45736122], [82.06291962, 16.45708275], [82.06236267, 16.45708466], [82.06236267, 16.45680618], [82.06208038, 16.45681], [82.06208038, 16.45652962], [82.06151581, 16.45652962], [82.06151581, 16.45625114], [82.06096649, 16.45625114], [82.06096649, 16.45597267], [82.05986023, 16.45597267], [82.05986023, 16.4556942], [82.05958557, 16.4556942], [82.05958557, 16.45541763], [82.05930328, 16.45541954], [82.05930328, 16.45514107], [82.05902863, 16.45514107], [82.05902863, 16.45486259], [82.05845642, 16.45486259], [82.05845642, 16.45458031], [82.05791473, 16.45458412], [82.05791473, 16.45430565], [82.05764008, 16.45430946], [82.05764008, 16.4540329], [82.05708313, 16.4540329], [82.05708313, 16.45375252], [82.05680847, 16.45375252], [82.05680847, 16.45347023], [82.05569458, 16.45347023], [82.05569458, 16.45319366], [82.05486298, 16.45319366], [82.05486298, 16.4529171], [82.05430603, 16.45293045], [82.05430603, 16.45263863], [82.05403137, 16.45263863], [82.05403137, 16.45235825], [82.05347443, 16.45236015], [82.05347443, 16.45208359], [82.05291748, 16.45208359], [82.05291748, 16.45180511], [82.05265045, 16.45181084], [82.05265045, 16.45153046], [82.05208588, 16.45153046], [82.05208588, 16.45124817], [82.05179596, 16.45124817], [82.05179596, 16.4509697], [82.05124664, 16.4509716], [82.05124664, 16.45069504], [82.05069733, 16.45070076], [82.05069733, 16.45042038], [82.05014038, 16.45042038], [82.05014038, 16.45013809], [82.04875183, 16.45013809], [82.04875183, 16.44986916], [82.04818726, 16.44986916], [82.04818726, 16.44958115], [82.04792023, 16.44958305], [82.04792023, 16.44930649], [82.04763794, 16.4493103], [82.04763794, 16.44902992], [82.04736328, 16.44902992], [82.04736328, 16.44874954], [82.04680634, 16.44874954], [82.04680634, 16.44847107], [82.04652405, 16.44847298], [82.04652405, 16.4481945], [82.04624939, 16.4481945], [82.04624939, 16.44791794], [82.0459671, 16.44791985], [82.0459671, 16.44763947], [82.04486084, 16.44763947], [82.04486084, 16.44736099], [82.04429626, 16.44736099], [82.04429626, 16.44708061], [82.04374695, 16.44708252], [82.04374695, 16.44680405], [82.04345703, 16.44680977], [82.04345703, 16.44652939], [82.04125214, 16.44652939], [82.04125214, 16.44625092], [82.04096985, 16.44625092], [82.04096985, 16.44597054], [82.04013824, 16.44597054], [82.04013824, 16.44625092], [82.03874969, 16.44625092], [82.03874969, 16.44597054], [82.03819275, 16.44597244], [82.03819275, 16.44569588], [82.03736115, 16.44569588], [82.03736115, 16.4454174], [82.03708649, 16.44542122], [82.03708649, 16.44514084], [82.03679657, 16.44514084], [82.03679657, 16.44458008], [82.03652954, 16.44458008], [82.03652954, 16.44514084], [82.0359726, 16.44514084], [82.0359726, 16.44542122], [82.03514099, 16.44542122], [82.03514099, 16.44514084], [82.03291321, 16.44514084], [82.03291321, 16.44486046], [82.03263855, 16.44486046], [82.03263855, 16.44458008], [82.03236389, 16.4445858], [82.03236389, 16.44430542], [82.03180695, 16.44431114], [82.03180695, 16.44403076], [82.03151703, 16.44403076], [82.03151703, 16.44374275], [82.03125, 16.44375038], [82.03125, 16.44347382], [82.03097534, 16.44347382], [82.03097534, 16.44319534], [82.0304184, 16.44320107], [82.0304184, 16.44292068], [82.03013611, 16.44292068], [82.03013611, 16.4426403], [82.02986145, 16.4426403], [82.02986145, 16.44236183], [82.02958679, 16.44236374], [82.02958679, 16.44208336], [82.0293045, 16.44208336], [82.0293045, 16.44152832], [82.0276413, 16.44153023], [82.0276413, 16.44125175], [82.02735901, 16.44125175], [82.02735901, 16.44096947], [82.02708435, 16.44096947], [82.02708435, 16.43985939], [82.02735901, 16.43985939], [82.02735901, 16.43958282], [82.02819824, 16.43958282], [82.02819824, 16.43985939], [82.02874756, 16.43985939], [82.02874756, 16.44014168], [82.02902985, 16.44014168], [82.02902985, 16.44042015], [82.03013611, 16.44042015], [82.03013611, 16.44014168], [82.03098297, 16.44014168], [82.03097534, 16.43985939], [82.03152466, 16.43985939], [82.03152466, 16.43958282], [82.03097534, 16.43958282], [82.03097534, 16.43930626], [82.0304184, 16.43931007], [82.0304184, 16.4390316], [82.03013611, 16.4390316], [82.03013611, 16.43874931], [82.02986145, 16.43874931], [82.02986145, 16.43847084], [82.0293045, 16.43847275], [82.0293045, 16.43819427], [82.02902985, 16.43819427], [82.02902985, 16.4379158], [82.02848053, 16.43792915], [82.02848053, 16.43763924], [82.02791595, 16.43763924], [82.02791595, 16.43736076], [82.02735901, 16.43736076], [82.02735901, 16.43708038], [82.02708435, 16.4370842], [82.02708435, 16.43680573], [82.02680206, 16.43680954], [82.02680206, 16.43653107], [82.02597046, 16.43653107], [82.02597046, 16.43625069], [82.02513885, 16.43625069], [82.02513885, 16.43597031], [82.0248642, 16.43597221], [82.0248642, 16.43569374], [82.02458191, 16.43569374], [82.02458191, 16.43541527], [82.02430725, 16.43542099], [82.02430725, 16.43514061], [82.02401733, 16.43514061], [82.02401733, 16.43486977], [82.02319336, 16.43486977], [82.02319336, 16.43457985], [82.0229187, 16.43458366], [82.0229187, 16.43430519], [82.02124786, 16.43431091], [82.02124786, 16.43403053], [82.02097321, 16.43403053], [82.02097321, 16.43375015], [82.02069092, 16.43375015], [82.02069092, 16.43346977], [82.02041626, 16.43347168], [82.02041626, 16.43319511], [82.0201416, 16.43320084], [82.0201416, 16.43264008], [82.02041626, 16.43264008], [82.02041626, 16.43180084], [82.02097321, 16.43180466], [82.02097321, 16.43152809], [82.0201416, 16.43153], [82.0201416, 16.43124962], [82.01985931, 16.43124962], [82.01985931, 16.43153], [82.01930237, 16.43152809], [82.01930237, 16.43208313], [82.01902771, 16.43208313], [82.01902771, 16.4323616], [82.01847076, 16.4323616], [82.01847076, 16.43208313], [82.01763916, 16.43208313], [82.01763916, 16.43180466], [82.01652527, 16.43180466], [82.01652527, 16.43152809], [82.01597595, 16.43153], [82.01597595, 16.43124962], [82.01541901, 16.43124962], [82.01541901, 16.43097115], [82.01513672, 16.43097305], [82.01513672, 16.43069458], [82.01457977, 16.43069458], [82.01457977, 16.43041611], [82.01431274, 16.43041992], [82.01431274, 16.43013954], [82.01403046, 16.43013954], [82.01403046, 16.42986107], [82.01347351, 16.42986107], [82.01347351, 16.42958069], [82.01264191, 16.42958069], [82.01264191, 16.42930603], [82.01235962, 16.42930984], [82.01235962, 16.42902946], [82.01207733, 16.42902946], [82.01207733, 16.42873955], [82.01152802, 16.42874908], [82.01152802, 16.42847252], [82.01041412, 16.42847252], [82.01041412, 16.42819214], [82.00986481, 16.42819214], [82.00986481, 16.42791748], [82.00958252, 16.42791939], [82.00958252, 16.42764282], [82.0090332, 16.42764282], [82.0090332, 16.42736244], [82.00846863, 16.42736244], [82.00846863, 16.42708015], [82.00763702, 16.42708397], [82.00763702, 16.4268055], [82.00734711, 16.42681122], [82.00734711, 16.42653084], [82.00708008, 16.42653084], [82.00708008, 16.42624855], [82.00680542, 16.42624855], [82.00680542, 16.42597008], [82.00653076, 16.42597008], [82.00653076, 16.42569351], [82.00708008, 16.42569923], [82.00708008, 16.42513847], [82.00681305, 16.42513847], [82.00681305, 16.42431068], [82.00653076, 16.42431068], [82.00653076, 16.4240284], [82.00514221, 16.4240284], [82.00514221, 16.42513847], [82.00596619, 16.42513847], [82.00596619, 16.42569923], [82.00541687, 16.42569923], [82.00541687, 16.42542076], [82.00460052, 16.42542076], [82.00460052, 16.42513847], [82.00402832, 16.42513847], [82.00402832, 16.42485809], [82.00347137, 16.42486191], [82.00347137, 16.42458344], [82.00291443, 16.42458344], [82.00291443, 16.42430496], [82.00235748, 16.42431068], [82.00235748, 16.4240284], [82.00180817, 16.4240284], [82.00180817, 16.42374992], [82.00125122, 16.42374992], [82.00125122, 16.42346954], [82.00096893, 16.42347145], [82.00096893, 16.42319489], [82.00069427, 16.42319489], [82.00069427, 16.42291641], [82.00041962, 16.42292976], [82.00041962, 16.42263985], [81.99986267, 16.42263985], [81.99931335, 16.42263985], [81.99931335, 16.42235947], [81.99874878, 16.42236137], [81.99874878, 16.4220829], [81.99819183, 16.4220829], [81.99819183, 16.42180634], [81.99764252, 16.42181015], [81.99764252, 16.42152977], [81.9970932, 16.42152977], [81.9970932, 16.42124939], [81.99680328, 16.42124939], [81.99680328, 16.42097092], [81.99652863, 16.42097282], [81.99652863, 16.42069435], [81.99514008, 16.42069435], [81.99514008, 16.42041588], [81.99485779, 16.42041969], [81.99485779, 16.42014122], [81.99458313, 16.42014122], [81.99458313, 16.41986084], [81.99430847, 16.41986084], [81.99430847, 16.41957283], [81.99346924, 16.41958427], [81.99346924, 16.4193058], [81.99263763, 16.41930962], [81.99263763, 16.41903114], [81.99208069, 16.41903114], [81.99208069, 16.41875076], [81.99124908, 16.41875076], [81.99124908, 16.41847038], [81.99097443, 16.41847229], [81.99097443, 16.41819572], [81.99041748, 16.41819572], [81.99041748, 16.41791725], [81.98960114, 16.41792107], [81.98960114, 16.41764069], [81.98931122, 16.41764069], [81.98931122, 16.41736031], [81.98874664, 16.41736031], [81.98874664, 16.41707993], [81.98819733, 16.41708374], [81.98819733, 16.41680527], [81.98764038, 16.41680527], [81.98764038, 16.4165287], [81.98707581, 16.41653061], [81.98707581, 16.41625023], [81.98680878, 16.41625023], [81.98680878, 16.41596985], [81.98652649, 16.41597366], [81.98652649, 16.41569519], [81.98568726, 16.41570282], [81.98568726, 16.41542053], [81.98486328, 16.41542053], [81.98486328, 16.41514015], [81.98401642, 16.41514015], [81.98401642, 16.41486168], [81.98374939, 16.41486359], [81.98374939, 16.4145813], [81.98319244, 16.4145813], [81.98319244, 16.41430473], [81.9826355, 16.41430473], [81.9826355, 16.41402817], [81.98179626, 16.41403008], [81.98179626, 16.41376114], [81.98152924, 16.41376114], [81.98152924, 16.41346931], [81.98097229, 16.41347313], [81.98097229, 16.41319466], [81.98041534, 16.41319466], [81.98041534, 16.41291618], [81.98014069, 16.41292191], [81.98014069, 16.41264153], [81.9798584, 16.41264153], [81.9798584, 16.41235924], [81.97930908, 16.41235924], [81.97930908, 16.41208076], [81.97875214, 16.41208267], [81.97875214, 16.41180611], [81.97846985, 16.41181183], [81.97846985, 16.41152763], [81.9779129, 16.41152763], [81.9779129, 16.41124916], [81.97598267, 16.41124916], [81.97598267, 16.41097069], [81.97569275, 16.4109726], [81.97569275, 16.41069412], [81.9751358, 16.41069984], [81.9751358, 16.41041756], [81.97486115, 16.41041756], [81.97486115, 16.41013908], [81.97458649, 16.41013908], [81.97458649, 16.40986061], [81.97402954, 16.40986061], [81.97402954, 16.40958023], [81.97319794, 16.40958405], [81.97319794, 16.40930557], [81.97292328, 16.40930939], [81.97292328, 16.40903091], [81.9723587, 16.40903091], [81.9723587, 16.40875053], [81.97180176, 16.40875053], [81.97180176, 16.40847015], [81.97123718, 16.40847015], [81.97125244, 16.40875053], [81.9706955, 16.40875053], [81.9706955, 16.40847206], [81.97041321, 16.40847206], [81.97041321, 16.40819359], [81.97013855, 16.40819359], [81.97013855, 16.40791512], [81.96985626, 16.40792084], [81.96985626, 16.40763092], [81.96736145, 16.40763855], [81.96736145, 16.40736198], [81.96708679, 16.40736198], [81.96708679, 16.40708351], [81.9668045, 16.40708351], [81.9668045, 16.40680695], [81.96652985, 16.40681076], [81.96652985, 16.40653038], [81.96624756, 16.40653038], [81.96624756, 16.40625], [81.96569824, 16.40625], [81.96569061, 16.40596962], [81.96485901, 16.40597153], [81.96485901, 16.40569305], [81.96457672, 16.40570068], [81.96457672, 16.4054203], [81.96430206, 16.4054203], [81.96430206, 16.40513992], [81.9631958, 16.40513992], [81.9631958, 16.40485954], [81.96263885, 16.40486145], [81.96263885, 16.40458488], [81.96208191, 16.40458488], [81.96208191, 16.40430641], [81.96098328, 16.40431023], [81.96098328, 16.40402985], [81.96069336, 16.40402985], [81.96069336, 16.40374947], [81.9604187, 16.40374947], [81.9604187, 16.40402985], [81.9595871, 16.40402985], [81.9595871, 16.4034729], [81.95930481, 16.40347481], [81.95930481, 16.40319443], [81.95874786, 16.40319443], [81.95874786, 16.40291595], [81.95819092, 16.40291977], [81.95819092, 16.40263939], [81.9576416, 16.40263939], [81.9576416, 16.40236282], [81.95707703, 16.40236282], [81.95707703, 16.40208054], [81.95652771, 16.40208054], [81.95652771, 16.40180588], [81.95597076, 16.40182114], [81.95597076, 16.40153122], [81.95540619, 16.40153122], [81.95540619, 16.40125275], [81.95485687, 16.40125275], [81.95485687, 16.40097046], [81.95430756, 16.40097046], [81.95430756, 16.40069389], [81.95375061, 16.40070534], [81.95375061, 16.40042114], [81.95361328, 16.40042114], [81.95291901, 16.40042114], [81.95291901, 16.40014267], [81.95236206, 16.40014267], [81.95236206, 16.39985847], [81.95180511, 16.39985847], [81.95180511, 16.39958382], [81.95124817, 16.39958382], [81.95124817, 16.39930534], [81.95069122, 16.39930916], [81.95069122, 16.39903069], [81.95014191, 16.39903069], [81.95014191, 16.39876175], [81.94959259, 16.39876175], [81.94959259, 16.39846992], [81.94902802, 16.39847183], [81.94902802, 16.39819527], [81.94847107, 16.39819527], [81.94847107, 16.39847183], [81.94819641, 16.39847183], [81.94819641, 16.39819527], [81.94790649, 16.39819908], [81.94790649, 16.39792061], [81.94763947, 16.39792061], [81.94763947, 16.39763832], [81.94706726, 16.39763832], [81.94706726, 16.39735985], [81.94652557, 16.39736176], [81.94652557, 16.39708328], [81.94625092, 16.39708328], [81.94625092, 16.39680481], [81.94596863, 16.39680481], [81.94596863, 16.39652634], [81.94568634, 16.39652824], [81.94568634, 16.39624977], [81.94541931, 16.39624977], [81.94541931, 16.39596939], [81.94513702, 16.3959713], [81.94513702, 16.39569473], [81.94486237, 16.39569473], [81.94486237, 16.39541626], [81.94458008, 16.39541817], [81.94458008, 16.39513969], [81.94319153, 16.39513969], [81.94319153, 16.39541817], [81.94235992, 16.39541817], [81.94235992, 16.39513969], [81.94211578, 16.39513969], [81.94180298, 16.39513969], [81.94180298, 16.39486122], [81.94097137, 16.39486122], [81.94097137, 16.39458084], [81.93875122, 16.39458084], [81.93875122, 16.39486122], [81.93819427, 16.39486122], [81.9382019, 16.39513969], [81.93708038, 16.39513969], [81.93708038, 16.39486122], [81.93596649, 16.39486122], [81.93596649, 16.39458084], [81.93569183, 16.39458275], [81.93569183, 16.39430618], [81.9345932, 16.39431], [81.9345932, 16.39402962], [81.93402863, 16.39402962], [81.93402863, 16.39375114], [81.93264008, 16.39375114], [81.93264008, 16.39402962], [81.92958069, 16.39402962], [81.92958069, 16.39375114], [81.9284668, 16.39375114], [81.9284668, 16.39402962], [81.92736053, 16.39402962], [81.92736053, 16.39375114], [81.92457581, 16.39375114], [81.92457581, 16.39347076], [81.92319489, 16.39347267], [81.92319489, 16.3931942], [81.92292023, 16.3931942], [81.92292023, 16.39291763], [81.92263794, 16.39291954], [81.92263794, 16.39262962], [81.92180634, 16.39263916], [81.92180634, 16.39236069], [81.92124939, 16.39236069], [81.92124939, 16.39263916], [81.92069244, 16.39263916], [81.92069244, 16.39236069], [81.91958618, 16.39236069], [81.91958618, 16.39208031], [81.91930389, 16.39208412], [81.91930389, 16.39180565], [81.91792297, 16.39180946], [81.91792297, 16.39153099], [81.9154129, 16.39153099], [81.9154129, 16.39125061], [81.91402435, 16.39125061], [81.91402435, 16.39097214], [81.91291809, 16.39097214], [81.91291809, 16.3904171], [81.91208649, 16.39042091], [81.91208649, 16.39014053], [81.91095734, 16.39014053], [81.91095734, 16.39042091], [81.91042328, 16.39042091], [81.91042328, 16.39014053], [81.90930176, 16.39014053], [81.90930176, 16.38986015], [81.90736389, 16.38986206], [81.90736389, 16.38958359], [81.90651703, 16.38959122], [81.90651703, 16.38931084], [81.90569305, 16.38931084], [81.90569305, 16.38903046], [81.9054184, 16.38903046], [81.9054184, 16.38875008], [81.90458679, 16.38875008], [81.90458679, 16.38903046], [81.90374756, 16.38903046], [81.90374756, 16.38875008], [81.90291595, 16.38875008], [81.90291595, 16.38820076], [81.90125275, 16.38820076], [81.90125275, 16.38792038], [81.90013885, 16.38792038], [81.90013885, 16.38764191], [81.89736176, 16.38764191], [81.89736176, 16.38735962], [81.89680481, 16.38735962], [81.89680481, 16.38708115], [81.89597321, 16.38708115], [81.89597321, 16.38680649], [81.89457703, 16.38681984], [81.89457703, 16.38653183], [81.89402771, 16.38653183], [81.89402771, 16.38625145], [81.89292145, 16.38625145], [81.89292145, 16.38653183], [81.89235687, 16.38653183], [81.89235687, 16.38625145], [81.89152527, 16.38625145], [81.89152527, 16.38597107], [81.89097595, 16.38597107], [81.89097595, 16.3856945], [81.89041901, 16.3856945], [81.89041901, 16.38541603], [81.88903046, 16.38542175], [81.88903046, 16.38514137], [81.88819122, 16.38514137], [81.88819122, 16.38485909], [81.88735962, 16.38485909], [81.88735962, 16.38458061], [81.88625336, 16.38458252], [81.88625336, 16.38430595], [81.88540649, 16.38430977], [81.88540649, 16.38402748], [81.88375092, 16.38402748], [81.88375092, 16.38375092], [81.88318634, 16.38375092], [81.88318634, 16.38347054], [81.88236237, 16.38347244], [81.88236237, 16.38319397], [81.88180542, 16.38319397], [81.88180542, 16.3829174], [81.88069153, 16.38292122], [81.88069153, 16.38264084], [81.87902832, 16.38264084], [81.87902832, 16.38236046], [81.87819672, 16.38236046], [81.87819672, 16.38208389], [81.87791443, 16.38208389], [81.87791443, 16.38180542], [81.87735748, 16.38181114], [81.87735748, 16.38153076], [81.87652588, 16.38153076], [81.87652588, 16.38125038], [81.87513733, 16.38125038], [81.87513733, 16.38097], [81.87403107, 16.38097191], [81.87403107, 16.38069534], [81.87319183, 16.38069534], [81.87319183, 16.38041687], [81.87207794, 16.38042068], [81.87207794, 16.3801403], [81.87097168, 16.3801403], [81.87097168, 16.37985992], [81.87041473, 16.37986183], [81.87041473, 16.37958336], [81.86958313, 16.37958336], [81.86958313, 16.37930679], [81.86875153, 16.37930679], [81.86875153, 16.37902832], [81.86763763, 16.37903023], [81.86763763, 16.37874985], [81.86680603, 16.37874985], [81.86680603, 16.37846947], [81.86513519, 16.37847137], [81.86513519, 16.37819481], [81.86430359, 16.37819481], [81.86430359, 16.37791634], [81.86290741, 16.37792015], [81.86290741, 16.37765121], [81.86264038, 16.37765121], [81.86264038, 16.37735939], [81.86235809, 16.3773613], [81.86235809, 16.37708473], [81.86180878, 16.37708473], [81.86180878, 16.37680626], [81.86096954, 16.37681007], [81.86096954, 16.37652969], [81.86042023, 16.37652969], [81.86042023, 16.37625122], [81.85958099, 16.37625122], [81.85958099, 16.37597275], [81.85902405, 16.37597275], [81.85902405, 16.37569427], [81.85791779, 16.37569427], [81.85791779, 16.3754158], [81.85736084, 16.37541962], [81.85736084, 16.37514114], [81.85678864, 16.37514114], [81.85678864, 16.37486267], [81.85597229, 16.37486267], [81.85597229, 16.37458992], [81.85404205, 16.37458992], [81.85404205, 16.37430954], [81.85375214, 16.37430954], [81.85375214, 16.37403107], [81.85346985, 16.37403107], [81.85346985, 16.37347031], [81.85263824, 16.37347031], [81.85263824, 16.37319374], [81.85152435, 16.37319374], [81.85152435, 16.37291718], [81.85096741, 16.37291908], [81.85096741, 16.37264061], [81.8501358, 16.37264061], [81.8501358, 16.37235832], [81.84986115, 16.37235832], [81.84986115, 16.37207985], [81.84902954, 16.37208366], [81.84902954, 16.37180519], [81.8484726, 16.37181091], [81.8484726, 16.37153053], [81.84764099, 16.37153053], [81.84764099, 16.37124825], [81.84597015, 16.37124825], [81.84597015, 16.37096977], [81.8456955, 16.37097168], [81.8456955, 16.37069511], [81.84541321, 16.37070084], [81.84541321, 16.37042046], [81.84401703, 16.37042046], [81.84401703, 16.37013817], [81.84319305, 16.37013817], [81.84319305, 16.3698597], [81.84236145, 16.3698616], [81.84236145, 16.36958313], [81.8418045, 16.36958313], [81.8418045, 16.36930466], [81.84124756, 16.36930466], [81.84124756, 16.36902618], [81.8409729, 16.36902809], [81.8409729, 16.36874962], [81.8401413, 16.36874962], [81.8401413, 16.3684597], [81.83958435, 16.36847305], [81.83958435, 16.36819458], [81.8390274, 16.36819458], [81.8390274, 16.36791611], [81.8381958, 16.36791992], [81.8381958, 16.36763954], [81.83790588, 16.36763954], [81.83790588, 16.36736107], [81.83735657, 16.36736107], [81.83735657, 16.36708069], [81.83708191, 16.3670826], [81.83708191, 16.36680412], [81.83596802, 16.36680984], [81.83596802, 16.36652946], [81.83513641, 16.36652946], [81.83513641, 16.36625099], [81.8345871, 16.36625099], [81.8345871, 16.36597061], [81.83374786, 16.36597252], [81.83374786, 16.36569595], [81.83347321, 16.36569595], [81.83347321, 16.36541748], [81.83293152, 16.36541939], [81.83293152, 16.36514091], [81.83235931, 16.36514091], [81.83235931, 16.36486053], [81.83207703, 16.36486053], [81.83207703, 16.36458015], [81.83125305, 16.36458588], [81.83125305, 16.3643055], [81.83069611, 16.36431122], [81.83069611, 16.36403084], [81.83040619, 16.36403084], [81.83040619, 16.36375046], [81.83013916, 16.36375046], [81.83013916, 16.36347008], [81.82875061, 16.36347389], [81.82875061, 16.36319542], [81.82847595, 16.3631897], [81.82847595, 16.36291695], [81.82818604, 16.36292076], [81.82818604, 16.36264992], [81.82763672, 16.36264992], [81.82763672, 16.36236191], [81.82707977, 16.36236382], [81.82707977, 16.36208344], [81.82653046, 16.36208344], [81.82653046, 16.36180496], [81.82596588, 16.36181068], [81.82596588, 16.3615303], [81.82485962, 16.3615303], [81.82485962, 16.36181068], [81.82459259, 16.36181068], [81.82459259, 16.3615303], [81.82402802, 16.3615303], [81.82402802, 16.36125183], [81.82347107, 16.36125183], [81.82347107, 16.36096954], [81.82291412, 16.36096954], [81.82291412, 16.36069489], [81.82236481, 16.36069489], [81.82236481, 16.36041641], [81.82180786, 16.36042023], [81.82180786, 16.36014175], [81.8215332, 16.36014175], [81.8215332, 16.35985947], [81.82125092, 16.35985947], [81.82125092, 16.3595829], [81.82069397, 16.3595829], [81.82069397, 16.35930634], [81.82041931, 16.35931015], [81.82041931, 16.35903168], [81.81958008, 16.35903168], [81.81958008, 16.35874939], [81.81903076, 16.35874939], [81.81903076, 16.35847092], [81.81874847, 16.35847282], [81.81874847, 16.35819435], [81.81847382, 16.35819435], [81.81847382, 16.35791588], [81.81819153, 16.35791969], [81.81819153, 16.35764122], [81.81735992, 16.35764122], [81.81735992, 16.35736084], [81.81708527, 16.35736084], [81.81708527, 16.35708427], [81.81625366, 16.35708427], [81.81625366, 16.3568058], [81.8154068, 16.35680962], [81.8154068, 16.3565197], [81.81513977, 16.35652733], [81.81513977, 16.35625076], [81.81430817, 16.35625076], [81.81430817, 16.35597038], [81.81402588, 16.35597229], [81.81402588, 16.35569382], [81.81346893, 16.35569382], [81.81346893, 16.35541725], [81.81291962, 16.35542107], [81.81291962, 16.35514069], [81.81236267, 16.35514069], [81.81236267, 16.35486031], [81.81208038, 16.35486031], [81.81208038, 16.35457993], [81.81153107, 16.35458374], [81.81153107, 16.35430527], [81.81096649, 16.35431099], [81.81096649, 16.35403061], [81.81041718, 16.35403061], [81.81041718, 16.35375023], [81.80902863, 16.35375023], [81.80902863, 16.35346031], [81.80847168, 16.35347176], [81.80847168, 16.35319519], [81.80819702, 16.35320091], [81.80819702, 16.35292053], [81.80764008, 16.35292053], [81.80764008, 16.35264015], [81.80708313, 16.35264015], [81.80708313, 16.35235977], [81.80680847, 16.35236168], [81.80680847, 16.35208321], [81.80652618, 16.35208321], [81.80652618, 16.35180473], [81.80625153, 16.35180473], [81.80625153, 16.35152817], [81.80570221, 16.35153008], [81.80570221, 16.35124969], [81.80541992, 16.35124969], [81.80541992, 16.35097122], [81.80513763, 16.35097313], [81.80513763, 16.35069466], [81.80430603, 16.35069466], [81.80430603, 16.35041618], [81.80374908, 16.35042], [81.80374908, 16.35013962], [81.8034668, 16.35013962], [81.8034668, 16.34986115], [81.80291748, 16.34986115], [81.80291748, 16.34958458], [81.80208588, 16.34958458], [81.80208588, 16.34930611], [81.80152893, 16.34930992], [81.80152893, 16.34902954], [81.80124664, 16.34902954], [81.80124664, 16.34875107], [81.80069733, 16.34875107], [81.80069733, 16.3484726], [81.80014038, 16.3484726], [81.80014038, 16.34819412], [81.79985809, 16.34819412], [81.79985809, 16.34791756], [81.79930878, 16.34791946], [81.79930878, 16.3476429], [81.79875183, 16.3476429], [81.79875183, 16.34736252], [81.79792023, 16.34736252], [81.79792023, 16.34708023], [81.79736328, 16.34708405], [81.79736328, 16.34680557], [81.79679871, 16.34680939], [81.79679871, 16.34653282], [81.79650879, 16.34653282], [81.79650879, 16.34624863], [81.7959671, 16.34624863], [81.7959671, 16.34596825], [81.79569244, 16.34597015], [81.79569244, 16.34569359], [81.7951355, 16.34569359], [81.7951355, 16.34541893], [81.79458618, 16.34542084], [81.79458618, 16.34513855], [81.79402924, 16.34513855], [81.79402924, 16.34485817], [81.79347229, 16.34486008], [81.79347229, 16.34458351], [81.79291534, 16.34458351], [81.79291534, 16.34430504], [81.7923584, 16.34431076], [81.7923584, 16.34403038], [81.79207611, 16.34403038], [81.79207611, 16.34374809], [81.79180908, 16.34374809], [81.79180908, 16.34346962], [81.79125214, 16.34347153], [81.79125214, 16.34319496], [81.79070282, 16.34320068], [81.79070282, 16.3429203], [81.79013824, 16.3429203], [81.79013824, 16.34263992], [81.78985596, 16.34263992], [81.78985596, 16.34235954], [81.78930664, 16.34236145], [81.78930664, 16.34208298], [81.78874969, 16.34208298], [81.78874969, 16.34180641], [81.78819275, 16.34181023], [81.78819275, 16.34152031], [81.7876358, 16.34152794], [81.7876358, 16.34124947], [81.78736115, 16.34124947], [81.78736115, 16.34097099], [81.7868042, 16.3409729], [81.7868042, 16.34069443], [81.7859726, 16.34069443], [81.7859726, 16.34041405], [81.78514099, 16.34041977], [81.78514099, 16.34013939], [81.78456879, 16.34013939], [81.78456879, 16.33986092], [81.78430176, 16.33986092], [81.78430176, 16.33958054], [81.7840271, 16.33958244], [81.7840271, 16.33930588], [81.78375244, 16.33930969], [81.78375244, 16.33903122], [81.78347015, 16.33903122], [81.78347015, 16.33875084], [81.78291321, 16.33875084], [81.78291321, 16.33848], [81.7820816, 16.33848], [81.7820816, 16.33819008], [81.78180695, 16.3381958], [81.78180695, 16.33791733], [81.78098297, 16.33792114], [81.78098297, 16.33764076], [81.7804184, 16.33764076], [81.7804184, 16.33736038], [81.77986145, 16.33736038], [81.77986145, 16.33708], [81.7793045, 16.33708382], [81.7793045, 16.33680534], [81.7784729, 16.33681107], [81.7784729, 16.33653069], [81.77791595, 16.33653069], [81.77791595, 16.33625031], [81.7776413, 16.33625031], [81.7776413, 16.33597183], [81.77708435, 16.33597374], [81.77708435, 16.33569527], [81.7765274, 16.3357029], [81.7765274, 16.33542061], [81.77625275, 16.33542061], [81.77625275, 16.33514023], [81.77568817, 16.33514023], [81.77568817, 16.33486176], [81.77513885, 16.33486366], [81.77513885, 16.33458328], [81.77458191, 16.33458328], [81.77458191, 16.33430481], [81.77402496, 16.33430481], [81.77402496, 16.33402824], [81.7729187, 16.33403015], [81.7729187, 16.33375168], [81.77236176, 16.33375168], [81.77236176, 16.33346939], [81.7720871, 16.33346939], [81.7720871, 16.33319473], [81.77097321, 16.33319473], [81.77097321, 16.33291626], [81.7701416, 16.33292007], [81.7701416, 16.3326416], [81.76958466, 16.3326416], [81.76958466, 16.33235931], [81.76930237, 16.33235931], [81.76930237, 16.33208275], [81.76902771, 16.33208275], [81.76902771, 16.33180618], [81.76763916, 16.3318119], [81.76763916, 16.33152771], [81.76708221, 16.33152771], [81.76708221, 16.33124924], [81.76597595, 16.33124924], [81.76597595, 16.33097076], [81.76569366, 16.33097267], [81.76569366, 16.3306942], [81.76513672, 16.3306942], [81.76513672, 16.33041954], [81.76457977, 16.33041954], [81.76457977, 16.33013916], [81.76403046, 16.33013916], [81.76403046, 16.32986069], [81.76345825, 16.32986069], [81.76345825, 16.32958031], [81.76264191, 16.32958412], [81.76264191, 16.32930565], [81.76235962, 16.32930946], [81.76235962, 16.32903099], [81.76097107, 16.32903099], [81.76097107, 16.32875061], [81.76039886, 16.32875061], [81.76039886, 16.32847023], [81.75958252, 16.32847214], [81.75958252, 16.32819366], [81.75902557, 16.32819366], [81.75902557, 16.32791519], [81.75875092, 16.32792091], [81.75875092, 16.32764053], [81.75791931, 16.32764053], [81.75791931, 16.32736015], [81.75680542, 16.32736206], [81.75680542, 16.32708359], [81.75624847, 16.32708359], [81.75624847, 16.32680511], [81.75569153, 16.32681084], [81.75569153, 16.32653809], [81.75514221, 16.32653809], [81.75514221, 16.32625008], [81.75430298, 16.32625008], [81.75430298, 16.3259697], [81.75375366, 16.3259716], [81.75375366, 16.32569313], [81.75319672, 16.32570076], [81.75319672, 16.32542038], [81.75263977, 16.32542038], [81.75263977, 16.32514], [81.75125122, 16.32514], [81.75125122, 16.32485962], [81.75069427, 16.32486153], [81.75069427, 16.32458305], [81.75041962, 16.32458305], [81.75041962, 16.32430649], [81.75013733, 16.3243103], [81.75013733, 16.32402992], [81.74931335, 16.32402992], [81.74931335, 16.32374954], [81.74845886, 16.32374954], [81.74845886, 16.32348061], [81.74791718, 16.32348061], [81.74791718, 16.32319069], [81.74736023, 16.3231945], [81.74736023, 16.32291603], [81.7470932, 16.32291985], [81.7470932, 16.32263947], [81.74624634, 16.32263947], [81.74624634, 16.3223629], [81.74539948, 16.3223629], [81.74539948, 16.32208061], [81.74485779, 16.32208061], [81.74485779, 16.32180595], [81.74375153, 16.32180977], [81.74375153, 16.32152939], [81.74291992, 16.32152939], [81.74291992, 16.32125282], [81.74208069, 16.32125282], [81.74208069, 16.32097244], [81.74153137, 16.32097244], [81.74153137, 16.32069206], [81.74097443, 16.32069206], [81.74097443, 16.3204174], [81.74041748, 16.3204174], [81.74041748, 16.32014084], [81.73958588, 16.32014084], [81.73958588, 16.3204174], [81.73874664, 16.3204174], [81.73874664, 16.32069206], [81.73847198, 16.32069206], [81.73847198, 16.32014084], [81.73874664, 16.32014275], [81.73874664, 16.31957817], [81.73847198, 16.31958389], [81.73847198, 16.31930542], [81.73792267, 16.31930923], [81.73792267, 16.31903076], [81.73680878, 16.31903076], [81.73680878, 16.31874847], [81.73651886, 16.31874847], [81.73651886, 16.31846809], [81.73596954, 16.31847191], [81.73596954, 16.31819534], [81.73568726, 16.31819916], [81.73568726, 16.31792068], [81.73486328, 16.31792068], [81.73486328, 16.3176384], [81.73430634, 16.3176384], [81.73430634, 16.31735039], [81.73402405, 16.31736183], [81.73402405, 16.31708336], [81.73319244, 16.31708336], [81.73319244, 16.31624985], [81.73291779, 16.31624985], [81.73291779, 16.31569099], [81.7326355, 16.31569481], [81.7326355, 16.31541634], [81.73208618, 16.31542015], [81.73208618, 16.31513977], [81.73069763, 16.31513977], [81.73069763, 16.3148613], [81.72958374, 16.3148613], [81.72958374, 16.31458282], [81.72930908, 16.31458282], [81.72930908, 16.31430626], [81.72846985, 16.31431007], [81.72846985, 16.31402969], [81.7279129, 16.31402969], [81.7279129, 16.31375122], [81.72680664, 16.31375122], [81.72680664, 16.31347084], [81.72569275, 16.31347275], [81.72569275, 16.31319427], [81.72458649, 16.31319427], [81.72458649, 16.3129158], [81.72402954, 16.31291962], [81.72402954, 16.31264114], [81.7234726, 16.31264114], [81.7234726, 16.31236076], [81.72319794, 16.31236076], [81.72319794, 16.31208038], [81.72264099, 16.3120842], [81.72264099, 16.31180573], [81.7223587, 16.31180954], [81.7223587, 16.3115406], [81.72207642, 16.3115406], [81.72207642, 16.31125069], [81.72180939, 16.31125069], [81.72180176, 16.3115406], [81.72097015, 16.3115406], [81.72097015, 16.31068993], [81.7206955, 16.31069374], [81.7206955, 16.31041718], [81.72041321, 16.31042099], [81.72041321, 16.31014061], [81.71901703, 16.31014061], [81.71901703, 16.31042099], [81.71875, 16.31042099], [81.71875, 16.3115406], [81.71901703, 16.3115406], [81.71901703, 16.31180954], [81.71930695, 16.31180954], [81.71930695, 16.31236076], [81.7195816, 16.31236076], [81.7195816, 16.31264114], [81.72013855, 16.31264114], [81.72013855, 16.31291962], [81.71986389, 16.3129158], [81.71986389, 16.31319427], [81.71930695, 16.31319427], [81.71930695, 16.31347275], [81.71902466, 16.31347275], [81.71902466, 16.31458282], [81.71930695, 16.31458282], [81.71930695, 16.31597137], [81.7195816, 16.31597137], [81.7195816, 16.31685066], [81.7195816, 16.31708336], [81.71986389, 16.31708336], [81.71986389, 16.31736183], [81.72013855, 16.31735039], [81.72013855, 16.3176384], [81.72041321, 16.3176384], [81.72041321, 16.31792068], [81.7206955, 16.31791687], [81.7206955, 16.31847191], [81.72019958, 16.31846809], [81.72013855, 16.31874847], [81.7195816, 16.31874847], [81.7195816, 16.31903076], [81.71901703, 16.31903076], [81.71901703, 16.31930923], [81.71819305, 16.31930542], [81.71819305, 16.31958389], [81.71763611, 16.31957817], [81.71763611, 16.31986237], [81.71708679, 16.31986237], [81.71708679, 16.32014275], [81.71624756, 16.32014084], [81.71624756, 16.3204174], [81.7159729, 16.3204174], [81.7159729, 16.31986237], [81.71569824, 16.31986237], [81.71569061, 16.31957817], [81.71457672, 16.31957817], [81.71457672, 16.31986237], [81.71430206, 16.31986237], [81.71430206, 16.31957817], [81.71296692, 16.31958008], [81.71097565, 16.31958389], [81.71097565, 16.31986237], [81.71055603, 16.31986237], [81.7104187, 16.31986237], [81.7104187, 16.3204174], [81.71013641, 16.3204174], [81.71013641, 16.32069206], [81.7095871, 16.32069206], [81.7095871, 16.32097244], [81.70903015, 16.32097244], [81.70903015, 16.32125282], [81.70707703, 16.32125282], [81.70707703, 16.32152939], [81.70680237, 16.32152939], [81.70680237, 16.32180977], [81.70625305, 16.32180595], [81.70625305, 16.32208061], [81.70569611, 16.32208061], [81.70569611, 16.3223629], [81.70513916, 16.3223629], [81.70513916, 16.32263947], [81.70458221, 16.32263947], [81.70458221, 16.32291985], [81.70402527, 16.32291603], [81.70402527, 16.3231945], [81.70347595, 16.32319069], [81.70347595, 16.32348061], [81.70291901, 16.32348061], [81.70291901, 16.32374954], [81.70263672, 16.32374954], [81.70263672, 16.32402992], [81.70207977, 16.32402802], [81.70207977, 16.32458305], [81.70180511, 16.32458305], [81.70180511, 16.32486153], [81.70124817, 16.32485962], [81.70124817, 16.32514], [81.70069122, 16.32514], [81.70069122, 16.32542038], [81.69985962, 16.32542038], [81.69985962, 16.32570076], [81.69847107, 16.32569313], [81.69847107, 16.3259716], [81.69819641, 16.3259697], [81.69819641, 16.32653809], [81.69790649, 16.32653809], [81.69790649, 16.32681084], [81.69763947, 16.32680511], [81.69763947, 16.32708359], [81.69652557, 16.32708359], [81.69652557, 16.32736206], [81.69541931, 16.32736015], [81.69541931, 16.32764053], [81.69513702, 16.32764053], [81.69513702, 16.32792091], [81.69458008, 16.32791519], [81.69458008, 16.32819366], [81.69430542, 16.32819366], [81.69430542, 16.32847214], [81.69374847, 16.32847023], [81.69374847, 16.32875061], [81.6920929, 16.32875061], [81.6920929, 16.32903099], [81.69180298, 16.32903099], [81.69180298, 16.32930946], [81.69152832, 16.32930565], [81.69152832, 16.32958412], [81.69124603, 16.32958031], [81.69124603, 16.32986069], [81.6904068, 16.32986069], [81.6904068, 16.33013916], [81.69013977, 16.33013916], [81.69013977, 16.33041954], [81.68958282, 16.33041954], [81.68958282, 16.3306942], [81.68875122, 16.3306942], [81.68875122, 16.33097267], [81.68846893, 16.33097076], [81.68846893, 16.33124924], [81.68817902, 16.33124924], [81.68817902, 16.33152771], [81.68736267, 16.33152771], [81.68736267, 16.3318119], [81.68653107, 16.33180618], [81.68653107, 16.33208275], [81.68486023, 16.33208275], [81.68486023, 16.33235931], [81.68458557, 16.33235931], [81.6845932, 16.3326416], [81.68402863, 16.3326416], [81.68402863, 16.33292007], [81.68374634, 16.33292007], [81.68374634, 16.3326416], [81.68096924, 16.3326416], [81.68096924, 16.33234978], [81.68041992, 16.33235931], [81.68041992, 16.33208275], [81.67930603, 16.33208275], [81.67930603, 16.33180618], [81.67903137, 16.33180618], [81.67903137, 16.33208275], [81.67874908, 16.33208275], [81.67874908, 16.33180618], [81.67791748, 16.33180618], [81.67791748, 16.33208275], [81.67736053, 16.33208275], [81.67736053, 16.33235931], [81.67652893, 16.33234978], [81.67652893, 16.3326416], [81.67569733, 16.3326416], [81.67569733, 16.33292007], [81.67485809, 16.33291626], [81.67485809, 16.33319473], [81.67430878, 16.33319473], [81.67430878, 16.33346939], [81.67375183, 16.33346939], [81.67375183, 16.33375168], [81.67346954, 16.33375168], [81.67346954, 16.33346939], [81.66874695, 16.33346939], [81.66874695, 16.33375168], [81.66847229, 16.33375168], [81.66847229, 16.33346939], [81.66791534, 16.33346939], [81.66791534, 16.33375168], [81.6673584, 16.33375168], [81.6673584, 16.33346939], [81.66569519, 16.33346939], [81.66570282, 16.33375168], [81.66179657, 16.33375168], [81.66179657, 16.33346939], [81.66041565, 16.33346939], [81.66041565, 16.33319473], [81.66014099, 16.33319473], [81.66014099, 16.33346939], [81.65957642, 16.33346939], [81.65958405, 16.33375168], [81.65820313, 16.33375168], [81.65820313, 16.33403015], [81.65513611, 16.33402824], [81.65513611, 16.33430481], [81.65402985, 16.33430481], [81.65402985, 16.33458328], [81.6526413, 16.33458328], [81.6526413, 16.33430481], [81.65208435, 16.33430481], [81.65208435, 16.33402824], [81.6506958, 16.33402824], [81.6506958, 16.33430481], [81.65041351, 16.33430481], [81.65041351, 16.33458328], [81.64902496, 16.33458328], [81.64902496, 16.33430481], [81.6479187, 16.33430481], [81.6479187, 16.33458328], [81.64763641, 16.33458328], [81.64763641, 16.33486366], [81.64653015, 16.33486366], [81.64653015, 16.33458328], [81.6451416, 16.33458328], [81.6451416, 16.33486366], [81.64457703, 16.33486176], [81.64457703, 16.33514023], [81.64097595, 16.33514023], [81.64097595, 16.33542061], [81.63903046, 16.33542061], [81.63903046, 16.3357029], [81.63791656, 16.33569527], [81.63791656, 16.33597374], [81.63652802, 16.33597183], [81.63652802, 16.33625031], [81.63569641, 16.33625031], [81.63569641, 16.33597183], [81.63485718, 16.33597183], [81.63486481, 16.33625031], [81.6340332, 16.33625031], [81.6340332, 16.33653069], [81.63263702, 16.33653069], [81.63263702, 16.33625031], [81.63181305, 16.33625031], [81.63181305, 16.33653069], [81.6312561, 16.33653069], [81.6312561, 16.33681107], [81.62791443, 16.33680534], [81.62791443, 16.33708382], [81.62763977, 16.33708], [81.62763977, 16.33736038], [81.62625122, 16.33736038], [81.62625122, 16.33708], [81.62458038, 16.33708], [81.62458038, 16.33736038], [81.62374878, 16.33736038], [81.62374878, 16.33764076], [81.62319183, 16.33764076], [81.62319183, 16.33792114], [81.62291718, 16.33792114], [81.62291718, 16.33764076], [81.62014008, 16.33764076], [81.62014008, 16.33792114], [81.61985779, 16.33791733], [81.61985779, 16.3381958], [81.61902618, 16.3381958], [81.61902618, 16.33791733], [81.61846924, 16.33791733], [81.61846924, 16.3381958], [81.61708069, 16.33819008], [81.61708069, 16.33848], [81.61624908, 16.33848], [81.61624908, 16.33875084], [81.61569214, 16.33875084], [81.61569214, 16.33903122], [81.61541748, 16.33903122], [81.61541748, 16.33930969], [81.61458588, 16.33930969], [81.61458588, 16.33903122], [81.6131897, 16.33903122], [81.6131897, 16.33930969], [81.61069489, 16.33930588], [81.61069489, 16.33958244], [81.60958099, 16.33958054], [81.60958099, 16.33986092], [81.6084671, 16.33986092], [81.60847473, 16.34013939], [81.6076355, 16.34013939], [81.6076355, 16.33986092], [81.60652924, 16.33986092], [81.60652924, 16.34013939], [81.6048584, 16.34013939], [81.6048584, 16.34041977], [81.6029129, 16.34041405], [81.6029129, 16.34069443], [81.6001358, 16.34069443], [81.6001358, 16.3409729], [81.59764099, 16.34097099], [81.59764099, 16.34124947], [81.59708405, 16.34124947], [81.59708405, 16.34152794], [81.59401703, 16.34152031], [81.59401703, 16.34181023], [81.59347534, 16.34180641], [81.59347534, 16.34208298], [81.5901413, 16.34208298], [81.5901413, 16.34236145], [81.5881958, 16.34235954], [81.5881958, 16.34263992], [81.58651733, 16.34263992], [81.58651733, 16.3429203], [81.5854187, 16.3429203], [81.5854187, 16.34320068], [81.58430481, 16.34319496], [81.58430481, 16.34347153], [81.58347321, 16.34346962], [81.58347321, 16.34374809], [81.5826416, 16.34374809], [81.5826416, 16.34346962], [81.58013916, 16.34347153], [81.58014679, 16.34374809], [81.57958221, 16.34374809], [81.57958221, 16.34403038], [81.57818604, 16.34403038], [81.57818604, 16.34374809], [81.57707977, 16.34374809], [81.57707977, 16.34403038], [81.57457733, 16.34403038], [81.57457733, 16.34431076], [81.57375336, 16.34430504], [81.57375336, 16.34458351], [81.57291412, 16.34458351], [81.57291412, 16.34430504], [81.57208252, 16.34430504], [81.57208252, 16.34458351], [81.56874847, 16.34458351], [81.56874847, 16.34486008], [81.56680298, 16.34485817], [81.56680298, 16.34513855], [81.56652832, 16.34513855], [81.56652832, 16.34542084], [81.56597137, 16.34542084], [81.56597137, 16.34513855], [81.56569672, 16.34513855], [81.56569672, 16.34542084], [81.56430817, 16.34542084], [81.56430817, 16.34513855], [81.56318665, 16.34513855], [81.56318665, 16.34542084], [81.56097412, 16.34541893], [81.56096649, 16.34558105], [81.56097412, 16.34569359], [81.56014252, 16.34569359], [81.56014252, 16.34597015], [81.55958557, 16.34597015], [81.55958557, 16.34624863], [81.55903625, 16.34624863], [81.55903625, 16.34653282], [81.55874634, 16.3465271], [81.55874634, 16.34708405], [81.55903625, 16.34708023], [81.55903625, 16.34791946], [81.5595932, 16.34791946], [81.5595932, 16.34875107], [81.55986023, 16.34875107], [81.55986023, 16.34902954], [81.56014252, 16.34902763], [81.56014252, 16.34958458], [81.55986023, 16.34958458], [81.55986023, 16.35069466], [81.5595932, 16.35069084], [81.5595932, 16.35153008], [81.55486298, 16.35153008], [81.55486298, 16.35124969], [81.55264282, 16.35124969], [81.55264282, 16.35153008], [81.55180359, 16.35152817], [81.55180359, 16.35180473], [81.55124664, 16.35180473], [81.55124664, 16.35208321], [81.55097198, 16.35208321], [81.55097198, 16.35236168], [81.55069733, 16.35235977], [81.55069733, 16.35264015], [81.55042267, 16.35264015], [81.55042267, 16.35320091], [81.54846954, 16.35319519], [81.54846954, 16.35347176], [81.54792023, 16.35346031], [81.54792023, 16.35403061], [81.54763794, 16.35403061], [81.54763794, 16.35431099], [81.54708099, 16.35431099], [81.54708099, 16.35486031], [81.54651642, 16.35486031], [81.54651642, 16.35514069], [81.5459671, 16.35514069], [81.5459671, 16.35542107], [81.54569244, 16.35541725], [81.54569244, 16.35569382], [81.54541779, 16.35569382], [81.54541779, 16.35597229], [81.5451355, 16.35597229], [81.54514313, 16.35625076], [81.54486084, 16.35625076], [81.54486084, 16.35652733], [81.54458618, 16.3565197], [81.54458618, 16.35680962], [81.54430389, 16.3568058], [81.54430389, 16.35708427], [81.54402924, 16.35708427], [81.54403687, 16.35736084], [81.54347229, 16.35736084], [81.54347229, 16.35764122], [81.54319763, 16.35764122], [81.54319763, 16.35791969], [81.54291534, 16.35791588], [81.54291534, 16.35819435], [81.54180908, 16.35819435], [81.54180908, 16.35847282], [81.54125214, 16.35847092], [81.54125214, 16.35874939], [81.54096985, 16.35874939], [81.54096985, 16.35903168], [81.53791046, 16.35903168], [81.53791046, 16.35874939], [81.53708649, 16.35874939], [81.53708649, 16.35903168], [81.53624725, 16.35903168], [81.53624725, 16.35874939], [81.53457642, 16.35874939], [81.53457642, 16.35847092], [81.5340271, 16.35847282], [81.5340271, 16.35819435], [81.5331955, 16.35819435], [81.5331955, 16.35791588], [81.53291321, 16.35791969], [81.53291321, 16.35764122], [81.53263855, 16.35764122], [81.53263855, 16.35736084], [81.53151703, 16.35736084], [81.53151703, 16.35708046], [81.53125, 16.35708427], [81.53125, 16.3568058], [81.53098297, 16.35680962], [81.53098297, 16.35625076], [81.53069305, 16.35625076], [81.53069305, 16.35569], [81.5304184, 16.35569382], [81.5304184, 16.35513878], [81.53013611, 16.35514069], [81.53013611, 16.35486031], [81.52986145, 16.35486031], [81.52986145, 16.35457993], [81.52902985, 16.35458374], [81.52902985, 16.35430527], [81.52791595, 16.35431099], [81.52791595, 16.35403061], [81.5265274, 16.3540287], [81.5265274, 16.35458374], [81.52625275, 16.35457993], [81.52625275, 16.35486031], [81.52458191, 16.35486031], [81.52458191, 16.35514069], [81.52430725, 16.35514069], [81.52430725, 16.35542107], [81.52402496, 16.35541725], [81.52402496, 16.35569382], [81.52375031, 16.35569382], [81.52375031, 16.35652733], [81.52403259, 16.3565197], [81.52403259, 16.35680962], [81.52430725, 16.3568058], [81.52430725, 16.35819435], [81.5229187, 16.35819435], [81.5229187, 16.35791588], [81.52236176, 16.35791969], [81.52236176, 16.35764122], [81.52124786, 16.35764122], [81.52124786, 16.35791969], [81.52041626, 16.35791588], [81.52041626, 16.35819435], [81.51958466, 16.35819435], [81.51958466, 16.35847282], [81.51875305, 16.35847282], [81.51875305, 16.35819435], [81.51819611, 16.35819435], [81.51819611, 16.35791588], [81.51763916, 16.35791969], [81.51763916, 16.35764122], [81.51735687, 16.35764122], [81.51735687, 16.35736084], [81.51708221, 16.35736084], [81.51708221, 16.35708046], [81.51680756, 16.35708427], [81.51680756, 16.3568058], [81.5165329, 16.35680962], [81.5165329, 16.3565197], [81.51597595, 16.35652733], [81.51597595, 16.35597229], [81.51569366, 16.35597229], [81.51569366, 16.35569382], [81.51541901, 16.35569382], [81.51541901, 16.35541725], [81.51513672, 16.35542107], [81.51513672, 16.35514069], [81.51486206, 16.35514069], [81.51486206, 16.35486031], [81.51457977, 16.35486031], [81.51457977, 16.35457993], [81.51374817, 16.35458374], [81.51374817, 16.35430527], [81.51291656, 16.35430527], [81.51291656, 16.35458374], [81.51069641, 16.35458374], [81.51069641, 16.35430527], [81.51013947, 16.35431099], [81.51013947, 16.35403061], [81.50985718, 16.35403061], [81.50985718, 16.35375023], [81.50930786, 16.35375023], [81.50930786, 16.35320091], [81.5090332, 16.35320091], [81.5090332, 16.35264015], [81.50875092, 16.35264015], [81.50875092, 16.35235977], [81.50763702, 16.35235977], [81.50763702, 16.35264015], [81.50708008, 16.35264015], [81.50708008, 16.35292053], [81.50653076, 16.35292053], [81.50653076, 16.35320091], [81.50569153, 16.35320091], [81.50569153, 16.35292053], [81.50541687, 16.35292053], [81.50541687, 16.35264015], [81.50486755, 16.35264015], [81.50486755, 16.35235977], [81.50180817, 16.35236168], [81.50180817, 16.35208321], [81.50152588, 16.35208321], [81.50152588, 16.35180473], [81.50125122, 16.35180473], [81.50125122, 16.35152817], [81.49874878, 16.35152817], [81.49874878, 16.35180473], [81.49597168, 16.35180473], [81.49597168, 16.35152817], [81.49485779, 16.35152817], [81.49485779, 16.35180473], [81.49208069, 16.35180473], [81.49208069, 16.35208321], [81.49153137, 16.35208321], [81.49153137, 16.35236168], [81.49124908, 16.35235977], [81.49124908, 16.35264015], [81.4909668, 16.35264015], [81.4909668, 16.35292053], [81.48486328, 16.35292053], [81.48486328, 16.35264015], [81.48458099, 16.35264015], [81.48458099, 16.35292053], [81.48375702, 16.35292053], [81.48375702, 16.35320091], [81.48124695, 16.35320091], [81.48124695, 16.35292053], [81.48069763, 16.35292053], [81.48069763, 16.35264015], [81.48042297, 16.35264015], [81.48042297, 16.35292053], [81.48014069, 16.35292053], [81.48014069, 16.35264015], [81.47957611, 16.35264015], [81.47957611, 16.35292053], [81.47902679, 16.35292053], [81.47902679, 16.35320091], [81.47819519, 16.35319519], [81.47819519, 16.35347176], [81.47652435, 16.35347176], [81.47652435, 16.35319519], [81.47402954, 16.35319519], [81.47402954, 16.35347176], [81.47264099, 16.35347176], [81.47264099, 16.35319519], [81.47013855, 16.35320091], [81.47013855, 16.35292053], [81.46901703, 16.35292053], [81.46901703, 16.35320091], [81.46875763, 16.35320091], [81.46875763, 16.35292053], [81.46763611, 16.35292053], [81.46763611, 16.35264015], [81.46736145, 16.35264015], [81.46736145, 16.35292053], [81.4651413, 16.35292053], [81.4651413, 16.35264015], [81.46235657, 16.35264015], [81.46235657, 16.35235977], [81.45874786, 16.35236168], [81.45874786, 16.35208321], [81.45652771, 16.35208321], [81.45652771, 16.35180473], [81.45430756, 16.35180473], [81.45430756, 16.35152817], [81.45263672, 16.35153008], [81.45263672, 16.35124969], [81.44930267, 16.35124969], [81.44930267, 16.35097122], [81.44680786, 16.35097313], [81.44680786, 16.35069466], [81.44458008, 16.35069466], [81.44458008, 16.35041618], [81.44235992, 16.35042], [81.44235992, 16.35013962], [81.44069672, 16.35013962], [81.44069672, 16.34986115], [81.4384613, 16.34986115], [81.4384613, 16.34958267], [81.43708038, 16.34958458], [81.43708038, 16.34930611], [81.43596649, 16.34930992], [81.43596649, 16.34902954], [81.43402863, 16.34902954], [81.43402863, 16.34875107], [81.43180847, 16.34875107], [81.43180847, 16.3484726], [81.43069458, 16.3484726], [81.43069458, 16.34819412], [81.42874908, 16.34819412], [81.42874908, 16.34791756], [81.42708588, 16.34791946], [81.42708588, 16.3476429], [81.42597198, 16.3476429], [81.42597198, 16.34736252], [81.42485809, 16.34736252], [81.42485809, 16.34708023], [81.42375183, 16.34708405], [81.42375183, 16.34680557], [81.42151642, 16.34680939], [81.42151642, 16.34653282], [81.41986084, 16.34653282], [81.41986084, 16.34624863], [81.41764069, 16.34624863], [81.41764069, 16.34596825], [81.41708374, 16.34597015], [81.41708374, 16.34569359], [81.41625214, 16.34569359], [81.41625214, 16.34541893], [81.41485596, 16.34542084], [81.41485596, 16.34513855], [81.41401672, 16.34513855], [81.41401672, 16.34485817], [81.41152954, 16.34486008], [81.41152954, 16.34458351], [81.41041565, 16.34458351], [81.41041565, 16.34430504], [81.4090271, 16.34431076], [81.4090271, 16.34403038], [81.40763855, 16.34403038], [81.40763855, 16.34374809], [81.4054184, 16.34374809], [81.4054184, 16.34403038], [81.40374756, 16.34403038], [81.40374756, 16.34431076], [81.4034729, 16.34431076], [81.4034729, 16.34542084], [81.40374756, 16.34541893], [81.40374756, 16.34569359], [81.40513611, 16.34569359], [81.40513611, 16.34597015], [81.40625, 16.34596825], [81.40625, 16.34624863], [81.40680695, 16.34624863], [81.40680695, 16.34653282], [81.4070816, 16.34653282], [81.4070816, 16.34736252], [81.40680695, 16.34736252], [81.40680695, 16.3476429], [81.40651703, 16.3476429], [81.40651703, 16.34791946], [81.40625, 16.34791756], [81.40625, 16.3484726], [81.4054184, 16.3484726], [81.4054184, 16.34819412], [81.40458679, 16.34819412], [81.40458679, 16.34791756], [81.40402985, 16.34791946], [81.40402985, 16.3476429], [81.4034729, 16.3476429], [81.4034729, 16.34791946], [81.40319824, 16.34791756], [81.40319824, 16.34819412], [81.40291595, 16.34819412], [81.40291595, 16.3484726], [81.4026413, 16.3484726], [81.4026413, 16.34902954], [81.40235901, 16.34902763], [81.40235901, 16.35180473], [81.40208435, 16.35180473], [81.40208435, 16.35208321], [81.40125275, 16.35208321], [81.40125275, 16.35180473], [81.40097046, 16.35180473], [81.40097046, 16.35041618], [81.40125275, 16.35042], [81.40125275, 16.35013962], [81.4015274, 16.35013962], [81.4015274, 16.34819031], [81.40180206, 16.34819412], [81.40180206, 16.34708405], [81.4015274, 16.34708405], [81.4015274, 16.34569359], [81.40125275, 16.34569359], [81.40125275, 16.34541893], [81.4006958, 16.34542084], [81.4006958, 16.34513855], [81.40013885, 16.34513855], [81.40013885, 16.34485817], [81.3998642, 16.34486008], [81.3998642, 16.34458351], [81.39958191, 16.34458351], [81.39958191, 16.34430504], [81.39930725, 16.34431076], [81.39930725, 16.34403038], [81.39736176, 16.34403038], [81.39736176, 16.34431076], [81.3970871, 16.34430504], [81.3970871, 16.34458351], [81.39624786, 16.3445797], [81.39624786, 16.34513855], [81.39597321, 16.34513855], [81.39597321, 16.34530067], [81.39597321, 16.34597015], [81.39569092, 16.34596825], [81.39569092, 16.34624863], [81.39541626, 16.34624863], [81.39541626, 16.34653282], [81.39457703, 16.34653282], [81.39457703, 16.34680939], [81.39430237, 16.34680557], [81.39430237, 16.34708405], [81.39375305, 16.34708023], [81.39375305, 16.34736252], [81.39299011, 16.34736252], [81.39263916, 16.34736252], [81.39263916, 16.3476429], [81.39235687, 16.3476429], [81.39235687, 16.34791946], [81.39208221, 16.34791946], [81.39208221, 16.34902954], [81.3923645, 16.34902763], [81.3923645, 16.34917068], [81.39235687, 16.34986115], [81.39208221, 16.34986115], [81.39208221, 16.35013962], [81.39180756, 16.35013962], [81.39180756, 16.35042], [81.39152527, 16.35041618], [81.39152527, 16.35069466], [81.39069366, 16.35069466], [81.39069366, 16.35097313], [81.39013672, 16.35097313], [81.39013672, 16.35208321], [81.38986206, 16.35207939], [81.38986206, 16.35264015], [81.38957977, 16.35264015], [81.38957977, 16.35320091], [81.38930511, 16.35319519], [81.38930511, 16.35347176], [81.38903046, 16.35346031], [81.38903046, 16.35375023], [81.38874817, 16.35375023], [81.38874817, 16.35403061], [81.38846588, 16.35403061], [81.38846588, 16.35431099], [81.38791656, 16.35430527], [81.38791656, 16.35458374], [81.38735199, 16.35457993], [81.38735199, 16.35486031], [81.38652802, 16.35486031], [81.38652802, 16.35514069], [81.38569641, 16.35514069], [81.38569641, 16.35542107], [81.38486481, 16.35541725], [81.38486481, 16.35569382], [81.38430786, 16.35569], [81.38430786, 16.35625076], [81.3840332, 16.35625076], [81.3840332, 16.35680962], [81.38375092, 16.3568058], [81.38375092, 16.35807037], [81.38375092, 16.35874939], [81.38346863, 16.35874939], [81.38346863, 16.35931015], [81.38318634, 16.35931015], [81.38318634, 16.3615303], [81.38291931, 16.3615303], [81.38291931, 16.36181068], [81.38263702, 16.36181068], [81.38263702, 16.3615303], [81.38236237, 16.3615303], [81.38236237, 16.36125183], [81.38208008, 16.36125183], [81.38208008, 16.36096954], [81.38180542, 16.36096954], [81.38181305, 16.36125183], [81.38124847, 16.36125183], [81.38124847, 16.3615303], [81.38069153, 16.3615303], [81.38069153, 16.36181068], [81.38041687, 16.36180496], [81.38041687, 16.36208344], [81.37930298, 16.36208344], [81.37930298, 16.36180496], [81.37847137, 16.36181068], [81.37847137, 16.3615303], [81.37735748, 16.3615303], [81.37735748, 16.36125183], [81.37680817, 16.36125183], [81.37680817, 16.36096954], [81.37625122, 16.36096954], [81.37625122, 16.36069489], [81.37513733, 16.36069489], [81.37513733, 16.36041641], [81.37458038, 16.36042023], [81.37458038, 16.36014175], [81.37319183, 16.36014175], [81.37319183, 16.35985947], [81.37291718, 16.35985947], [81.37291718, 16.36014175], [81.37180328, 16.36014175], [81.37180328, 16.36042023], [81.37152863, 16.36041641], [81.37152863, 16.36208344], [81.37124634, 16.36208344], [81.37124634, 16.36180496], [81.36985779, 16.36180496], [81.36985779, 16.36208344], [81.36930847, 16.36208344], [81.36930847, 16.36180496], [81.36902618, 16.36181068], [81.36902618, 16.3615303], [81.36875153, 16.3615303], [81.36875153, 16.36125183], [81.36846924, 16.36125183], [81.36846924, 16.36096954], [81.36819458, 16.36096954], [81.36819458, 16.36069489], [81.36736298, 16.36069489], [81.36736298, 16.36041641], [81.36653137, 16.36042023], [81.36653137, 16.36014175], [81.3659668, 16.36014175], [81.3659668, 16.35985947], [81.36513519, 16.35985947], [81.36513519, 16.3595829], [81.36486053, 16.3595829], [81.36486053, 16.35902977], [81.36458588, 16.35903168], [81.36458588, 16.35847092], [81.36430359, 16.35847282], [81.36430359, 16.35791588], [81.36374664, 16.35791969], [81.36374664, 16.35764122], [81.36347198, 16.35764122], [81.36347198, 16.35736084], [81.36319733, 16.35736084], [81.36319733, 16.35708046], [81.36264038, 16.35708427], [81.36264038, 16.3568058], [81.36235809, 16.35680962], [81.36235809, 16.3565197], [81.36208344, 16.35652733], [81.36208344, 16.35597229], [81.36180878, 16.35597229], [81.36180878, 16.35569382], [81.36152649, 16.35569382], [81.36152649, 16.35513878], [81.36125183, 16.35514069], [81.36125183, 16.35486031], [81.36096954, 16.35486031], [81.36096954, 16.35403061], [81.36068726, 16.35403061], [81.36068726, 16.35320091], [81.36042786, 16.35320091], [81.36042786, 16.35292053], [81.36068726, 16.35292053], [81.36068726, 16.35235977], [81.36096954, 16.35236168], [81.36096954, 16.35152817], [81.36125183, 16.35153008], [81.36125183, 16.35124969], [81.36042023, 16.35124969], [81.36042023, 16.35069466], [81.35986328, 16.35069466], [81.35986328, 16.35041618], [81.35874939, 16.35042], [81.35874939, 16.35013962], [81.35819244, 16.35013962], [81.35819244, 16.34986115], [81.35791779, 16.34986115], [81.35791779, 16.34930992], [81.35958099, 16.34930992], [81.35958099, 16.34902954], [81.35986328, 16.34902954], [81.35986328, 16.34875107], [81.36013794, 16.34875107], [81.36013794, 16.34819031], [81.35986328, 16.34819412], [81.35986328, 16.34791756], [81.35958099, 16.34791946], [81.35958099, 16.34708023], [81.35930634, 16.34708405], [81.35930634, 16.34581947], [81.35930634, 16.34569359], [81.35902405, 16.34569359], [81.35902405, 16.34541893], [81.35874939, 16.34542084], [81.35874939, 16.34513855], [81.3584671, 16.34513855], [81.3584671, 16.34485817], [81.35819244, 16.34486008], [81.35819244, 16.34430504], [81.35791779, 16.34431076], [81.35791779, 16.34403038], [81.35764313, 16.34403038], [81.35764313, 16.34374809], [81.35736084, 16.34374809], [81.35736084, 16.34347153], [81.35708618, 16.34347153], [81.35708618, 16.34319496], [81.35679626, 16.34320068], [81.35679626, 16.34263992], [81.35652924, 16.34263992], [81.35652924, 16.34235954], [81.35624695, 16.34236145], [81.35624695, 16.34180641], [81.35597229, 16.34181023], [81.35597229, 16.34069061], [81.35541534, 16.34069443], [81.35541534, 16.34041405], [81.35514069, 16.34041977], [81.35514069, 16.33986092], [81.3548584, 16.33986092], [81.3548584, 16.33958054], [81.35458374, 16.33958244], [81.35458374, 16.33930588], [81.35430145, 16.33930969], [81.35430145, 16.33903122], [81.35402679, 16.33903122], [81.35402679, 16.33875084], [81.35375214, 16.33875084], [81.35375214, 16.33819008], [81.35346985, 16.3381958], [81.35346985, 16.33763885], [81.35320282, 16.33764076], [81.35320282, 16.33736038], [81.3529129, 16.33736038], [81.3529129, 16.33708], [81.35263824, 16.33708382], [81.35263824, 16.33680534], [81.35235596, 16.33681107], [81.35235596, 16.33653069], [81.35180664, 16.33653069], [81.35180664, 16.33625031], [81.35151672, 16.33625031], [81.35151672, 16.33597183], [81.35124969, 16.33597374], [81.35124969, 16.33541679], [81.35098267, 16.33542061], [81.35098267, 16.33514023], [81.35069275, 16.33514023], [81.35069275, 16.33486176], [81.35041809, 16.33486366], [81.35041809, 16.33458328], [81.34986115, 16.33458328], [81.34986115, 16.33430481], [81.34958649, 16.33430481], [81.34958649, 16.33402824], [81.34929657, 16.33403015], [81.34929657, 16.33375168], [81.34874725, 16.33375168], [81.34874725, 16.33346939], [81.3484726, 16.33346939], [81.3484726, 16.33319473], [81.34819794, 16.33319473], [81.34819794, 16.33291626], [81.34792328, 16.33292007], [81.34792328, 16.3326416], [81.34764099, 16.3326416], [81.34764099, 16.33234978], [81.34708405, 16.33235931], [81.34708405, 16.33208275], [81.34680176, 16.33208275], [81.34680176, 16.33180618], [81.3465271, 16.3318119], [81.3465271, 16.33152771], [81.34597015, 16.33152771], [81.34597015, 16.33124924], [81.34570313, 16.33124924], [81.34570313, 16.33069038], [81.34680176, 16.3306942], [81.34680939, 16.33097267], [81.34764099, 16.33097076], [81.34764099, 16.33124924], [81.34819794, 16.33124924], [81.34819794, 16.33152771], [81.34874725, 16.33152771], [81.34874725, 16.3318119], [81.3493042, 16.33180618], [81.3493042, 16.33208275], [81.34958649, 16.33208275], [81.34958649, 16.33235931], [81.35069275, 16.33234978], [81.35069275, 16.3326416], [81.3520813, 16.3326416], [81.3520813, 16.33292007], [81.35263824, 16.33291626], [81.35263824, 16.33319473], [81.35346985, 16.33319473], [81.35346985, 16.33346939], [81.35402679, 16.33346939], [81.35402679, 16.33375168], [81.35569763, 16.33375168], [81.35569763, 16.33403015], [81.35597229, 16.33402824], [81.35597229, 16.33430481], [81.35652924, 16.33430481], [81.35652924, 16.33458328], [81.35679626, 16.33457947], [81.35679626, 16.33514023], [81.35708618, 16.33514023], [81.35708618, 16.33542061], [81.35736084, 16.33541679], [81.35736084, 16.33597374], [81.3576355, 16.33597374], [81.3576355, 16.33625031], [81.35791779, 16.33625031], [81.35791779, 16.33681107], [81.35819244, 16.33681107], [81.35819244, 16.33736038], [81.3584671, 16.33736038], [81.3584671, 16.33764076], [81.35874939, 16.33763885], [81.35874939, 16.3381958], [81.35901642, 16.33819008], [81.35901642, 16.33875084], [81.35930634, 16.33875084], [81.35930634, 16.33958244], [81.35958099, 16.33958054], [81.35958099, 16.33986092], [81.35986328, 16.33986092], [81.35986328, 16.34041977], [81.36013794, 16.34041405], [81.36013794, 16.34069443], [81.36069489, 16.34069443], [81.36069489, 16.3409729], [81.36096954, 16.34097099], [81.36096954, 16.34124947], [81.36152649, 16.34124947], [81.36152649, 16.34152794], [81.36207581, 16.34152031], [81.36207581, 16.34181023], [81.36264038, 16.34180641], [81.36264038, 16.34208298], [81.36319733, 16.34208298], [81.36319733, 16.34236145], [81.36347198, 16.34235954], [81.36347198, 16.34263992], [81.36374664, 16.34263992], [81.36374664, 16.34320068], [81.36402893, 16.34320068], [81.36402893, 16.34374809], [81.36429596, 16.34374809], [81.36429596, 16.34431076], [81.36458588, 16.34430504], [81.36458588, 16.34458351], [81.36513519, 16.34458351], [81.36513519, 16.34486008], [81.36569214, 16.34485817], [81.36569214, 16.34513855], [81.3659668, 16.34513855], [81.3659668, 16.34542084], [81.36653137, 16.34541893], [81.36653137, 16.34569359], [81.36680603, 16.34569359], [81.36680603, 16.34597015], [81.36708069, 16.34597015], [81.36708069, 16.34569359], [81.36958313, 16.34569359], [81.36958313, 16.34597015], [81.37097168, 16.34596825], [81.37097168, 16.34653282], [81.37069702, 16.34653282], [81.37069702, 16.34680939], [81.37041473, 16.34680557], [81.37041473, 16.34708405], [81.37014008, 16.34708023], [81.37014008, 16.34736252], [81.36985779, 16.34736252], [81.36985779, 16.34791946], [81.36902618, 16.34791756], [81.36902618, 16.34819412], [81.36846924, 16.34819412], [81.36846924, 16.3484726], [81.36763763, 16.3484726], [81.36763763, 16.34875107], [81.36736298, 16.34875107], [81.36736298, 16.34902954], [81.36708069, 16.34902954], [81.36708069, 16.34930992], [81.36680603, 16.34930611], [81.36680603, 16.34958458], [81.36653137, 16.34958267], [81.36653137, 16.34986115], [81.36624146, 16.34986115], [81.36624146, 16.35042], [81.36541748, 16.35042], [81.36541748, 16.35124969], [81.36569214, 16.35124969], [81.36569214, 16.35208321], [81.36597443, 16.35208321], [81.36597443, 16.35236168], [81.36624146, 16.35235977], [81.36624146, 16.35264015], [81.36653137, 16.35264015], [81.36653137, 16.35292053], [81.36680603, 16.35292053], [81.36680603, 16.35320091], [81.36708069, 16.35319519], [81.36708069, 16.35347176], [81.36763763, 16.35346031], [81.36763763, 16.35403061], [81.36791992, 16.35403061], [81.36791992, 16.35431099], [81.36846924, 16.35430527], [81.36846924, 16.35458374], [81.37124634, 16.35457993], [81.37124634, 16.35486031], [81.3720932, 16.35486031], [81.3720932, 16.35514069], [81.37264252, 16.35514069], [81.37264252, 16.35542107], [81.37291718, 16.35541725], [81.37291718, 16.35569382], [81.37347412, 16.35569382], [81.37347412, 16.35597229], [81.37430573, 16.35597229], [81.37430573, 16.35625076], [81.37486267, 16.35625076], [81.37486267, 16.35652733], [81.37513733, 16.3565197], [81.37513733, 16.35680962], [81.37569427, 16.3568058], [81.37569427, 16.35708237], [81.37625122, 16.35708046], [81.37625122, 16.35736084], [81.37652588, 16.35736084], [81.37652588, 16.35764122], [81.37680817, 16.35763741], [81.37680817, 16.35819435], [81.37708282, 16.35819054], [81.37708282, 16.35874939], [81.37735748, 16.35874939], [81.37735748, 16.35903168], [81.3779068, 16.35903168], [81.3779068, 16.35931015], [81.37875366, 16.35930634], [81.37875366, 16.3595829], [81.37985992, 16.3595829], [81.37985992, 16.35985947], [81.38097382, 16.35985947], [81.38097382, 16.3595829], [81.38153076, 16.3595829], [81.38153076, 16.35930634], [81.38181305, 16.35931015], [81.38181305, 16.35903168], [81.38236237, 16.35903168], [81.38236237, 16.35847092], [81.38263702, 16.35847282], [81.38263702, 16.35736084], [81.38291931, 16.35733032], [81.38291931, 16.3568058], [81.38318634, 16.35680962], [81.38318634, 16.35625076], [81.38346863, 16.35625076], [81.38346863, 16.35569], [81.38375092, 16.35569382], [81.38375092, 16.35513878], [81.3840332, 16.35514069], [81.3840332, 16.35431099], [81.38430786, 16.35431099], [81.38430786, 16.35403061], [81.38458252, 16.35403061], [81.38458252, 16.35375023], [81.38652802, 16.35375023], [81.38652802, 16.35346031], [81.38708496, 16.35347176], [81.38708496, 16.35319519], [81.38764191, 16.35320091], [81.38764191, 16.35292053], [81.38791656, 16.35292053], [81.38791656, 16.35124969], [81.38764191, 16.35124969], [81.38764191, 16.35097122], [81.38708496, 16.35097313], [81.38708496, 16.35013962], [81.38791656, 16.35013962], [81.38791656, 16.34986115], [81.38846588, 16.34986115], [81.38846588, 16.34958267], [81.38874817, 16.34958458], [81.38874817, 16.34930611], [81.38903046, 16.34930992], [81.38903046, 16.3484726], [81.38930511, 16.3484726], [81.38930511, 16.34819412], [81.38957977, 16.34819412], [81.38957977, 16.34763908], [81.38986206, 16.3476429], [81.38986206, 16.34708023], [81.39013672, 16.34708405], [81.39013672, 16.34680557], [81.39041138, 16.34680939], [81.39041138, 16.34653282], [81.39068604, 16.34653282], [81.39068604, 16.34624863], [81.39097595, 16.34624863], [81.39097595, 16.34596825], [81.39125061, 16.34597015], [81.39125061, 16.34569359], [81.39152527, 16.34569359], [81.39152527, 16.34541893], [81.39208221, 16.34542084], [81.39208221, 16.34513855], [81.39235687, 16.34513855], [81.39235687, 16.3445797], [81.39263916, 16.34458351], [81.39263916, 16.34208298], [81.3923645, 16.34208298], [81.3923645, 16.34180641], [81.39180756, 16.34181023], [81.39180756, 16.34152031], [81.39152527, 16.34152794], [81.39152527, 16.34124947], [81.39097595, 16.34124947], [81.39097595, 16.34097099], [81.39041901, 16.3409729], [81.39041901, 16.34069443], [81.39013672, 16.34069443], [81.39013672, 16.34041405], [81.38957977, 16.34041977], [81.38957977, 16.34013939], [81.38791656, 16.34013939], [81.38791656, 16.33986092], [81.38735199, 16.33986092], [81.38735199, 16.33958054], [81.38652802, 16.33958244], [81.38652802, 16.33930588], [81.38597107, 16.33930969], [81.38597107, 16.33903122], [81.38513947, 16.33903122], [81.38513947, 16.33875084], [81.38375092, 16.33875084], [81.38375092, 16.33848], [81.38263702, 16.33848], [81.38263702, 16.33819008], [81.38180542, 16.3381958], [81.38180542, 16.33791733], [81.38096619, 16.33792114], [81.38096619, 16.33764076], [81.38041687, 16.33764076], [81.38041687, 16.33736038], [81.37985992, 16.33736038], [81.37985992, 16.33708], [81.37930298, 16.33708382], [81.37930298, 16.33680534], [81.37847137, 16.33681107], [81.37847137, 16.33653069], [81.37735748, 16.33653069], [81.37735748, 16.33625031], [81.37652588, 16.33625031], [81.37652588, 16.33597183], [81.37458038, 16.33597374], [81.37458038, 16.33569527], [81.37403107, 16.3357029], [81.37403107, 16.33542061], [81.37346649, 16.33542061], [81.37346649, 16.33514023], [81.37236786, 16.33514023], [81.37236786, 16.33486176], [81.37152863, 16.33486366], [81.37152863, 16.33458328], [81.37097168, 16.33458328], [81.37097168, 16.33430481], [81.37014008, 16.33430481], [81.37014008, 16.33402824], [81.36930847, 16.33403015], [81.36930847, 16.33375168], [81.36846924, 16.33375168], [81.36846924, 16.33346939], [81.36763763, 16.33346939], [81.36763763, 16.33319473], [81.36653137, 16.33319473], [81.36653137, 16.33291626], [81.3659668, 16.33292007], [81.3659668, 16.3326416], [81.36513519, 16.3326416], [81.36513519, 16.33235931], [81.36430359, 16.33235931], [81.36430359, 16.33208275], [81.36347198, 16.33208275], [81.36347198, 16.33180618], [81.36292267, 16.3318119], [81.36292267, 16.33152771], [81.36235809, 16.33152771], [81.36235809, 16.33124924], [81.36207581, 16.33124924], [81.36207581, 16.33097076], [81.36152649, 16.33097267], [81.36152649, 16.3306942], [81.36013794, 16.3306942], [81.36013794, 16.33041954], [81.35930634, 16.33041954], [81.35930634, 16.33013916], [81.3584671, 16.33013916], [81.3584671, 16.32986069], [81.35708618, 16.32986069], [81.35708618, 16.32958031], [81.35652924, 16.32958412], [81.35652924, 16.32930565], [81.35624695, 16.32930946], [81.35624695, 16.32903099], [81.35542297, 16.32903099], [81.35542297, 16.32875061], [81.3548584, 16.32875061], [81.3548584, 16.32847023], [81.35402679, 16.32847214], [81.35402679, 16.32819366], [81.35319519, 16.32819366], [81.35319519, 16.32791519], [81.3529129, 16.32792091], [81.3529129, 16.32764053], [81.35235596, 16.32764053], [81.35235596, 16.32736015], [81.35180664, 16.32736206], [81.35180664, 16.32708359], [81.35124969, 16.32708359], [81.35124969, 16.32680511], [81.35041809, 16.32681084], [81.35041809, 16.32653809], [81.34902954, 16.32653809], [81.34902954, 16.32625008], [81.3484726, 16.32625008], [81.3484726, 16.3259697], [81.34819794, 16.3259716], [81.34819794, 16.32569313], [81.3473587, 16.32570076], [81.3473587, 16.32542038], [81.3465271, 16.32542038], [81.3465271, 16.32514], [81.34597015, 16.32514], [81.34597015, 16.32485962], [81.3456955, 16.32486153], [81.3456955, 16.32458305], [81.3445816, 16.32458305], [81.3445816, 16.32430649], [81.34375, 16.3243103], [81.34375, 16.32402992], [81.34319305, 16.32402992], [81.34319305, 16.32374954], [81.34236145, 16.32374954], [81.34236145, 16.32348061], [81.34179688, 16.32348061], [81.34179688, 16.32319069], [81.34124756, 16.3231945], [81.34124756, 16.32291603], [81.34069824, 16.32291985], [81.34069061, 16.32263947], [81.33985901, 16.32263947], [81.33985901, 16.3223629], [81.33875275, 16.3223629], [81.33875275, 16.32208061], [81.3381958, 16.32208061], [81.3381958, 16.32180595], [81.33735657, 16.32180977], [81.33735657, 16.32152939], [81.33708191, 16.32152939], [81.33708191, 16.32125282], [81.33625031, 16.32125282], [81.33625031, 16.32097244], [81.33597565, 16.32097244], [81.33597565, 16.32069206], [81.3354187, 16.32069206], [81.3354187, 16.3204174], [81.3345871, 16.3204174], [81.3345871, 16.32014084], [81.33347321, 16.32014275], [81.33347321, 16.31986237], [81.3326416, 16.31986237], [81.3326416, 16.31957817], [81.33235931, 16.31958389], [81.33235931, 16.31930542], [81.33180237, 16.31930923], [81.33180237, 16.31903076], [81.33152771, 16.31903076], [81.33152771, 16.31874847], [81.33097076, 16.31874847], [81.33097076, 16.31846809], [81.33013916, 16.31847191], [81.33013916, 16.31819534], [81.32930756, 16.31819916], [81.32930756, 16.31792068], [81.32847595, 16.31792068], [81.32847595, 16.3176384], [81.32791901, 16.3176384], [81.32791901, 16.31735039], [81.32763672, 16.31736183], [81.32763672, 16.31708336], [81.32736206, 16.31708336], [81.32736206, 16.31680489], [81.32653046, 16.31680489], [81.32653046, 16.31652641], [81.32596588, 16.31652832], [81.32596588, 16.31624985], [81.32541656, 16.31624985], [81.32541656, 16.31596947], [81.32485962, 16.31597137], [81.32485962, 16.31569481], [81.32430267, 16.31569481], [81.32430267, 16.31541634], [81.32375336, 16.31542015], [81.32375336, 16.31513977], [81.32347107, 16.31513977], [81.32347107, 16.31485939], [81.32291412, 16.3148613], [81.32291412, 16.31458282], [81.32236481, 16.31458282], [81.32236481, 16.31430626], [81.3215332, 16.31431007], [81.3215332, 16.31402969], [81.32096863, 16.31402969], [81.32096863, 16.31375122], [81.32041931, 16.31375122], [81.32041931, 16.31347084], [81.31958008, 16.31347275], [81.31958008, 16.31319427], [81.31874847, 16.31319427], [81.31874847, 16.3129158], [81.31846619, 16.31291962], [81.31846619, 16.31264114], [81.31819153, 16.31264114], [81.31819153, 16.31236076], [81.31791687, 16.31236076], [81.31791687, 16.31208038], [81.31764221, 16.3120842], [81.31764221, 16.31180573], [81.3170929, 16.31180954], [81.3170929, 16.3115406], [81.31652832, 16.3115406], [81.31652832, 16.31125069], [81.31597137, 16.31125069], [81.31597137, 16.31097031], [81.31541443, 16.31097221], [81.31541443, 16.31069374], [81.31513977, 16.31069374], [81.31513977, 16.31041718], [81.31485748, 16.31042099], [81.31485748, 16.31014061], [81.31458282, 16.31014061], [81.31458282, 16.30994987], [81.31458282, 16.30986023], [81.3140564, 16.30986023], [81.31375122, 16.30986023], [81.31375122, 16.30958366], [81.31291962, 16.30958366], [81.31291962, 16.30930519], [81.31207275, 16.30931091], [81.31207275, 16.30903053], [81.31181335, 16.30903053], [81.31181335, 16.30875015], [81.31153107, 16.30875015], [81.31153107, 16.30846977], [81.31124878, 16.30847359], [81.31124878, 16.30819511], [81.31069183, 16.30820274], [81.31069183, 16.30792046], [81.31014252, 16.30792046], [81.31014252, 16.30764008], [81.3095932, 16.30764008], [81.3095932, 16.3073616], [81.30902863, 16.3073616], [81.30902863, 16.30708122], [81.30847168, 16.30708122], [81.30847168, 16.30680466], [81.30819702, 16.30680466], [81.30819702, 16.30652809], [81.3079071, 16.30653191], [81.3079071, 16.30625153], [81.30735779, 16.30625153], [81.30735779, 16.30596924], [81.30708313, 16.30597305], [81.30708313, 16.30569458], [81.30625153, 16.30569458], [81.30625153, 16.30541611], [81.30596924, 16.30541611], [81.30596924, 16.30514145], [81.30568695, 16.30514145], [81.30568695, 16.30485916], [81.30541992, 16.30485916], [81.30541992, 16.30458069], [81.30458069, 16.3045826], [81.30458069, 16.30430603], [81.30374908, 16.30430984], [81.30374908, 16.30402756], [81.3034668, 16.30402756], [81.3034668, 16.30374908], [81.30291748, 16.30374908], [81.30291748, 16.30347061], [81.30263519, 16.30347252], [81.30263519, 16.30319405], [81.30208588, 16.30319405], [81.30208588, 16.30291748], [81.30152893, 16.30291748], [81.30152893, 16.30264091], [81.30124664, 16.30264091], [81.30124664, 16.30236816], [81.30069733, 16.30236816], [81.30069733, 16.30208015], [81.30041504, 16.30208397], [81.30041504, 16.3018055], [81.30013275, 16.30181122], [81.30013275, 16.30153084], [81.29985809, 16.30153084], [81.29985809, 16.30125046], [81.29930878, 16.30125046], [81.29930878, 16.30097008], [81.29902649, 16.30097198], [81.29902649, 16.30069542], [81.29846954, 16.3006897], [81.29846954, 16.30041695], [81.29736328, 16.30042076], [81.29736328, 16.29986], [81.29680634, 16.29986191], [81.29680634, 16.29958344], [81.29652405, 16.29958344], [81.29652405, 16.29930687], [81.29624939, 16.29931068], [81.29624939, 16.2990303], [81.2959671, 16.2990303], [81.2959671, 16.29874992], [81.29541779, 16.29874992], [81.29541779, 16.29846954], [81.29458618, 16.29847145], [81.29458618, 16.29819489], [81.29430389, 16.29819489], [81.29430389, 16.29791641], [81.29402924, 16.29792023], [81.29402924, 16.29763985], [81.29374695, 16.29763985], [81.29374695, 16.29735947], [81.29347229, 16.29736137], [81.29347229, 16.29708481], [81.29319763, 16.29708481], [81.29319763, 16.29680634], [81.2923584, 16.29681015], [81.2923584, 16.29652977], [81.29207611, 16.29652977], [81.29207611, 16.29624176], [81.29152679, 16.29624939], [81.29152679, 16.29597282], [81.29125214, 16.29597282], [81.29125214, 16.29569435], [81.29069519, 16.29569435], [81.29069519, 16.29541588], [81.2904129, 16.29541969], [81.2904129, 16.29514122], [81.28985596, 16.29514122], [81.28985596, 16.29486275], [81.28901672, 16.29486275], [81.28901672, 16.29458046], [81.28847504, 16.29458427], [81.28847504, 16.2943058], [81.28819275, 16.29430962], [81.28819275, 16.29403114], [81.28791809, 16.29403114], [81.28791809, 16.29375267], [81.28708649, 16.29375267], [81.28708649, 16.29347038], [81.2868042, 16.29347038], [81.2868042, 16.29319382], [81.28652954, 16.29319382], [81.28652954, 16.29291725], [81.28624725, 16.29291916], [81.28624725, 16.29264069], [81.2859726, 16.29264069], [81.2859726, 16.2923584], [81.28569794, 16.2923584], [81.28569794, 16.29207993], [81.28541565, 16.29208374], [81.28541565, 16.29180527], [81.2848587, 16.29180908], [81.2848587, 16.29153061], [81.28457642, 16.29153061], [81.28457642, 16.29124832], [81.28430176, 16.29124832], [81.28430176, 16.29096985], [81.2831955, 16.29097176], [81.2831955, 16.29069519], [81.28263855, 16.29070091], [81.28263855, 16.29013824], [81.28235626, 16.29013824], [81.28235626, 16.28985977], [81.2820816, 16.28986168], [81.2820816, 16.28958321], [81.28180695, 16.28958321], [81.28180695, 16.28930473], [81.28152466, 16.28930473], [81.28152466, 16.28902626], [81.28125, 16.28902817], [81.28125, 16.28874969], [81.28069305, 16.28874969], [81.28069305, 16.28819084], [81.28013611, 16.28819466], [81.28013611, 16.28763962], [81.27986145, 16.28763962], [81.27986145, 16.28737068], [81.27958679, 16.28737068], [81.27958679, 16.28708076], [81.2793045, 16.28708267], [81.2793045, 16.28652763], [81.2784729, 16.28652954], [81.2784729, 16.28625107], [81.27819824, 16.28625107], [81.27819061, 16.28597069], [81.27791595, 16.2859726], [81.27791595, 16.28569412], [81.2776413, 16.28569412], [81.2776413, 16.28541756], [81.27680206, 16.28541946], [81.27680206, 16.28514099], [81.2765274, 16.28514099], [81.2765274, 16.28486061], [81.27625275, 16.28486061], [81.27625275, 16.28458023], [81.2756958, 16.28458595], [81.2756958, 16.28430557], [81.27541351, 16.28430557], [81.27541351, 16.2840271], [81.27485657, 16.28403091], [81.27485657, 16.28375053], [81.27458191, 16.28375053], [81.27458191, 16.28347015], [81.27430725, 16.28347206], [81.27430725, 16.28319359], [81.27402496, 16.28319359], [81.27402496, 16.28291702], [81.27348328, 16.28292084], [81.27348328, 16.28264046], [81.27319336, 16.28264046], [81.27319336, 16.28236008], [81.2729187, 16.28236389], [81.2729187, 16.28208351], [81.27263641, 16.28208351], [81.27263641, 16.28180504], [81.2720871, 16.28181076], [81.2720871, 16.28123856], [81.27180481, 16.28125191], [81.27180481, 16.28096962], [81.27124786, 16.28096962], [81.27124786, 16.28069496], [81.27069092, 16.28070068], [81.27069092, 16.2804203], [81.27041626, 16.2804203], [81.27041626, 16.28014183], [81.27014923, 16.28014183], [81.27014923, 16.27957916], [81.26985931, 16.27958107], [81.26985931, 16.27930641], [81.26930237, 16.27931023], [81.26930237, 16.27903175], [81.26875305, 16.27903175], [81.26875305, 16.27875137], [81.26847076, 16.27875137], [81.26847076, 16.27846909], [81.26819611, 16.27846909], [81.26819611, 16.27875137], [81.26699829, 16.27875137], [81.26680756, 16.27875137], [81.26680756, 16.27903175], [81.2665329, 16.27903175], [81.2665329, 16.27931023], [81.26625061, 16.27931023], [81.26625061, 16.28014183], [81.26597595, 16.28013992], [81.26597595, 16.28096962], [81.26569366, 16.28096962], [81.26569366, 16.28125191], [81.26541901, 16.28125191], [81.26541901, 16.28096962], [81.26513672, 16.28096962], [81.26513672, 16.28013992], [81.26541901, 16.28014183], [81.26541901, 16.27957916], [81.26513672, 16.27958107], [81.26513672, 16.27902985], [81.26486206, 16.27903175], [81.26486206, 16.27807999], [81.26486206, 16.27791595], [81.26457977, 16.27791977], [81.26457977, 16.27653122], [81.26431274, 16.27653122], [81.26431274, 16.27625084], [81.26402283, 16.27625084], [81.26402283, 16.27597046], [81.26374817, 16.27597237], [81.26374817, 16.27541733], [81.26346588, 16.27543068], [81.26346588, 16.27514076], [81.26319122, 16.27514076], [81.26319122, 16.27458], [81.26291656, 16.27458382], [81.26291656, 16.27347183], [81.26264191, 16.27347183], [81.26264191, 16.27124977], [81.26235962, 16.27124977], [81.26235962, 16.27096939], [81.26208496, 16.2709713], [81.26208496, 16.27069473], [81.26180267, 16.27069473], [81.26180267, 16.27041626], [81.26152802, 16.27042007], [81.26152802, 16.27013969], [81.26125336, 16.27013969], [81.2612381, 16.26958275], [81.26097107, 16.26958466], [81.26097107, 16.26930618], [81.26069641, 16.26930618], [81.26069641, 16.26902771], [81.26040649, 16.26902962], [81.26040649, 16.26875114], [81.26013947, 16.26875114], [81.26013947, 16.26847267], [81.25986481, 16.26847267], [81.25986481, 16.2681942], [81.25958252, 16.2681942], [81.25958252, 16.26791763], [81.25930786, 16.26791954], [81.25930786, 16.26764107], [81.2590332, 16.26764107], [81.2590332, 16.26736259], [81.25875092, 16.26736259], [81.25875092, 16.26680946], [81.25846863, 16.26680946], [81.25846863, 16.2665329], [81.25791931, 16.2665329], [81.25791931, 16.26626015], [81.25763702, 16.26626015], [81.25763702, 16.26596832], [81.25736237, 16.26597023], [81.25736237, 16.26569366], [81.25708008, 16.26569366], [81.25708008, 16.2654171], [81.25681305, 16.26542091], [81.25681305, 16.26514053], [81.25653076, 16.26514053], [81.25653076, 16.26485825], [81.25624847, 16.26486015], [81.25624847, 16.26458359], [81.25597382, 16.26458359], [81.25597382, 16.26430511], [81.25569153, 16.26431084], [81.25569153, 16.26403046], [81.25541687, 16.26403046], [81.25541687, 16.26374817], [81.25514221, 16.26374817], [81.25514221, 16.2634697], [81.25485992, 16.2634716], [81.25485992, 16.26319504], [81.2545929, 16.26320076], [81.2545929, 16.26292038], [81.25430298, 16.26292038], [81.25430298, 16.26263809], [81.25402832, 16.26263809], [81.25402832, 16.26208115], [81.25430298, 16.26208305], [81.25430298, 16.26180649], [81.25319672, 16.2618103], [81.25319672, 16.26152992], [81.2529068, 16.26152992], [81.2529068, 16.26124954], [81.25263977, 16.26124954], [81.25263977, 16.26097107], [81.25235748, 16.26097298], [81.25235748, 16.2606945], [81.25208282, 16.2606945], [81.25208282, 16.26041412], [81.25180817, 16.26041985], [81.25180817, 16.26013947], [81.25152588, 16.26013947], [81.25152588, 16.25986099], [81.25125122, 16.25986099], [81.25125122, 16.25958061], [81.25096893, 16.25958252], [81.25096893, 16.25930405], [81.25068665, 16.25930977], [81.25068665, 16.25902939], [81.25041962, 16.25902939], [81.25041962, 16.25875092], [81.25013733, 16.25875092], [81.25013733, 16.25819016], [81.25041962, 16.25819588], [81.25041962, 16.2579174], [81.25013733, 16.25792122], [81.25013733, 16.25764084], [81.24931335, 16.25764084], [81.24931335, 16.25736046], [81.24903107, 16.25736046], [81.24903107, 16.25708389], [81.24874878, 16.25708389], [81.24874878, 16.25680542], [81.24846649, 16.25681114], [81.24846649, 16.2565403], [81.24847412, 16.25625038], [81.24819183, 16.25625038], [81.24819183, 16.25597191], [81.24791718, 16.25597382], [81.24791718, 16.25569534], [81.24764252, 16.25570107], [81.24764252, 16.25542068], [81.24736023, 16.25542068], [81.24736023, 16.2551403], [81.2470932, 16.2551403], [81.2470932, 16.25457954], [81.24680328, 16.25458336], [81.24680328, 16.25430489], [81.24652863, 16.25430489], [81.24652863, 16.25402832], [81.24624634, 16.25403023], [81.24624634, 16.25375175], [81.24597168, 16.25375175], [81.24597168, 16.25346947], [81.24569702, 16.25346947], [81.24569702, 16.25291634], [81.2454071, 16.25292015], [81.2454071, 16.25264168], [81.24514008, 16.25264168], [81.24514008, 16.25235939], [81.24485779, 16.25235939], [81.24485779, 16.25208282], [81.24458313, 16.25208282], [81.24458313, 16.25180626], [81.24430847, 16.25181007], [81.24430847, 16.2515316], [81.24402618, 16.2515316], [81.24402618, 16.25097084], [81.24375153, 16.25097275], [81.24375153, 16.25069427], [81.24346924, 16.25069427], [81.24346924, 16.2504158], [81.24318695, 16.25041962], [81.24318695, 16.25014114], [81.24291229, 16.25014114], [81.24291229, 16.24986076], [81.24263763, 16.24986076], [81.24263763, 16.24930954], [81.24236298, 16.24930954], [81.24236298, 16.24847031], [81.24208069, 16.24847221], [81.24208069, 16.24819374], [81.24153137, 16.24819946], [81.24153137, 16.24792099], [81.24124908, 16.24792099], [81.24124908, 16.24764061], [81.2409668, 16.24764061], [81.2409668, 16.24736023], [81.24069214, 16.24736023], [81.24069214, 16.24707985], [81.24041748, 16.24708366], [81.24041748, 16.24680519], [81.24014282, 16.24681091], [81.24014282, 16.24625015], [81.23985291, 16.24625015], [81.23985291, 16.24596977], [81.23958588, 16.24597168], [81.23958588, 16.24541664], [81.23929596, 16.24542046], [81.23929596, 16.24513054], [81.23902893, 16.24513817], [81.23902893, 16.2448616], [81.23874664, 16.2448616], [81.23874664, 16.24430466], [81.23847198, 16.24430466], [81.23847198, 16.24402809], [81.23819733, 16.24403], [81.23819733, 16.24347115], [81.23791504, 16.24347305], [81.23791504, 16.24319458], [81.23764038, 16.24319458], [81.23764038, 16.24263954], [81.23735809, 16.24263954], [81.23735809, 16.24236107], [81.23707581, 16.24236107], [81.23707581, 16.24180984], [81.23680878, 16.24180984], [81.23680878, 16.2412529], [81.23652649, 16.2412529], [81.23652649, 16.24097252], [81.23680878, 16.24097252], [81.23680878, 16.24069405], [81.23652649, 16.24069405], [81.23652649, 16.24041748], [81.23596954, 16.24041939], [81.23596954, 16.24014282], [81.23568726, 16.24014282], [81.23568726, 16.23986244], [81.23542023, 16.23986244], [81.23542023, 16.23957825], [81.23513794, 16.23958397], [81.23513794, 16.23847008], [81.23542023, 16.23847008], [81.23542023, 16.23819542], [81.23458099, 16.2381897], [81.23458099, 16.23791885], [81.23430634, 16.23792076], [81.23430634, 16.23735809], [81.23402405, 16.23736191], [81.23402405, 16.23708344], [81.23374939, 16.23708344], [81.23374939, 16.23680496], [81.2334671, 16.23681068], [81.2334671, 16.2365303], [81.23264313, 16.2365303], [81.23264313, 16.23625755], [81.23236084, 16.23625755], [81.23236084, 16.23596954], [81.23208618, 16.23597145], [81.23208618, 16.23569489], [81.23180389, 16.23569489], [81.23180389, 16.23541641], [81.23124695, 16.23542023], [81.23124695, 16.23513985], [81.23097229, 16.23513985], [81.23097229, 16.23458099], [81.23069763, 16.2345829], [81.23069763, 16.23430634], [81.23097229, 16.23431015], [81.23097229, 16.23180962], [81.23069763, 16.23180962], [81.23069763, 16.23153114], [81.23014069, 16.23153114], [81.23014069, 16.23125076], [81.2298584, 16.23125076], [81.2298584, 16.23069], [81.22958374, 16.23069382], [81.22958374, 16.23013878], [81.22930908, 16.23013878], [81.22930908, 16.22958374], [81.22902679, 16.22958374], [81.22902679, 16.22930527], [81.22875214, 16.2293129], [81.22875214, 16.22875023], [81.22846985, 16.22875023], [81.22846985, 16.22820282], [81.22820282, 16.22820282], [81.22820282, 16.22764015], [81.2279129, 16.22764015], [81.2279129, 16.22709274], [81.22763824, 16.22709274], [81.22763824, 16.22680092], [81.22736359, 16.22680473], [81.22736359, 16.2262516], [81.2270813, 16.2262516], [81.2270813, 16.22569084], [81.22680664, 16.22569466], [81.22680664, 16.22514153], [81.22651672, 16.22514153], [81.22651672, 16.22485924], [81.22624969, 16.22485924], [81.22624969, 16.22430992], [81.22598267, 16.22430992], [81.22598267, 16.22374916], [81.22569275, 16.22374916], [81.22569275, 16.22319031], [81.22541809, 16.22319412], [81.22541809, 16.22263718], [81.2251358, 16.22264099], [81.2251358, 16.22236061], [81.22486115, 16.22236061], [81.22486115, 16.22180557], [81.22458649, 16.22180939], [81.22458649, 16.22125053], [81.22429657, 16.22125053], [81.22429657, 16.22068977], [81.22402954, 16.22069359], [81.22402954, 16.22041512], [81.22374725, 16.22042084], [81.22374725, 16.21986008], [81.2234726, 16.21986198], [81.2234726, 16.21930695], [81.22319794, 16.21931076], [81.22319794, 16.21875], [81.22291565, 16.21875], [81.22291565, 16.21819305], [81.22264099, 16.21819305], [81.22264099, 16.21763802], [81.2223587, 16.21763992], [81.2223587, 16.21735954], [81.22208405, 16.21736145], [81.22208405, 16.21680641], [81.22180939, 16.21681023], [81.22180939, 16.21624947], [81.2215271, 16.21624947], [81.2215271, 16.21569061], [81.22125244, 16.21569443], [81.22125244, 16.21513939], [81.22097015, 16.21515083], [81.22097015, 16.21458054], [81.2206955, 16.21458054], [81.2206955, 16.2140274], [81.22041321, 16.21403122], [81.22041321, 16.21375275], [81.22013855, 16.21375275], [81.22013855, 16.21319008], [81.21986389, 16.21319389], [81.21986389, 16.21264076], [81.2195816, 16.21264076], [81.2195816, 16.21208954], [81.21930695, 16.21208954], [81.21930695, 16.21153069], [81.21901703, 16.21153069], [81.21901703, 16.21096992], [81.21875, 16.21097183], [81.21875, 16.21041679], [81.21848297, 16.21042061], [81.21848297, 16.20985985], [81.21819305, 16.20986176], [81.21819305, 16.20902634], [81.2179184, 16.20902634], [81.2179184, 16.2084713], [81.21763611, 16.2084713], [81.21763611, 16.20763969], [81.21736145, 16.20763969], [81.21736145, 16.20708084], [81.21708679, 16.20708275], [81.21708679, 16.20624924], [81.21679688, 16.20625114], [81.21679688, 16.20569038], [81.21652985, 16.2056942], [81.21652985, 16.20486069], [81.21624756, 16.20486069], [81.21624756, 16.20430946], [81.2159729, 16.20430946], [81.2159729, 16.20347023], [81.21569824, 16.20347214], [81.21569061, 16.2029171], [81.21541595, 16.20292091], [81.21541595, 16.20207977], [81.2151413, 16.20208359], [81.2151413, 16.20152855], [81.21485901, 16.20153046], [81.21485901, 16.20070267], [81.21457672, 16.20070267], [81.21457672, 16.19986153], [81.21430206, 16.19986153], [81.21430206, 16.19902992], [81.2140274, 16.19903183], [81.2140274, 16.19819069], [81.21375275, 16.1981945], [81.21375275, 16.19735909], [81.21347046, 16.19735909], [81.21347046, 16.19625092], [81.2131958, 16.19625092], [81.2131958, 16.19542122], [81.21290588, 16.19542122], [81.21290588, 16.19458008], [81.21263885, 16.19458389], [81.21263885, 16.19375038], [81.21235657, 16.19375038], [81.21235657, 16.19292068], [81.21208191, 16.19292068], [81.21208191, 16.19207954], [81.21180725, 16.19208336], [81.21180725, 16.19124985], [81.21152496, 16.19124985], [81.21152496, 16.19013977], [81.21125031, 16.19013977], [81.21125031, 16.18931007], [81.21098328, 16.18931007], [81.21098328, 16.18847275], [81.21069336, 16.18847275], [81.21069336, 16.18736267], [81.2104187, 16.18736267], [81.2104187, 16.18653107], [81.21013641, 16.18653107], [81.21013641, 16.18568993], [81.20986176, 16.18569374], [81.20986176, 16.18514061], [81.2095871, 16.18514061], [81.2095871, 16.18457985], [81.20930481, 16.18458366], [81.20930481, 16.18403053], [81.20903015, 16.18403053], [81.20903015, 16.18320084], [81.20874786, 16.18320084], [81.20874786, 16.18263817], [81.20847321, 16.18263817], [81.20847321, 16.18208122], [81.20819092, 16.18208313], [81.20819092, 16.18124962], [81.20791626, 16.18124962], [81.20791626, 16.18069077], [81.2076416, 16.18069458], [81.2076416, 16.18013954], [81.20735931, 16.18013954], [81.20735931, 16.17958069], [81.20708466, 16.1795826], [81.20708466, 16.17874908], [81.20681, 16.17875099], [81.20681, 16.17791939], [81.20652771, 16.17791939], [81.20652771, 16.17708015], [81.20625305, 16.17708206], [81.20625305, 16.1768055], [81.20569611, 16.17681122], [81.20569611, 16.17653084], [81.20540619, 16.17653084], [81.20540619, 16.17597961], [81.20513916, 16.17597961], [81.20513916, 16.17486191], [81.20541382, 16.17486382], [81.20541382, 16.17375183], [81.20513916, 16.17375183], [81.20513916, 16.17264175], [81.20485687, 16.17264175], [81.20485687, 16.17153168], [81.20458221, 16.17153168], [81.20458221, 16.17069054], [81.20430756, 16.17069435], [81.20430756, 16.16986084], [81.20402527, 16.16986084], [81.20402527, 16.1693058], [81.20374298, 16.16930962], [81.20374298, 16.16792107], [81.2040329, 16.16792107], [81.2040329, 16.16485977], [81.20375061, 16.16486168], [81.20375061, 16.16402817], [81.20347595, 16.16403961], [81.20347595, 16.16319275], [81.20319366, 16.16319466], [81.20319366, 16.16152763], [81.20291901, 16.16152954], [81.20291901, 16.15681076], [81.20318604, 16.15681076], [81.20318604, 16.15570068], [81.20347595, 16.15570068], [81.20347595, 16.15458107], [81.20375061, 16.15458298], [81.20375061, 16.15402794], [81.2040329, 16.15402985], [81.2040329, 16.15208054], [81.20430756, 16.15208244], [81.20430756, 16.14958382], [81.20402527, 16.14958382], [81.20402527, 16.14930534], [81.20374298, 16.14931107], [81.20374298, 16.14847183], [81.20347595, 16.14847374], [81.20347595, 16.14819527], [81.20318604, 16.1482029], [81.20318604, 16.14792061], [81.20291901, 16.14792061], [81.20291901, 16.14707947], [81.20263672, 16.14708328], [81.20263672, 16.14680481], [81.20236206, 16.14680481], [81.20236206, 16.14541626], [81.20207977, 16.14542007], [81.20207977, 16.1451416], [81.20180511, 16.1451416], [81.20180511, 16.14485931], [81.20124817, 16.14485931], [81.20124817, 16.14458084], [81.20014191, 16.14458084], [81.20014191, 16.1451416], [81.20041656, 16.1451416], [81.20041656, 16.14653015], [81.20014191, 16.14652824], [81.20014191, 16.14736176], [81.19958496, 16.14736176], [81.19958496, 16.14708328], [81.19902802, 16.14708328], [81.19902802, 16.14680481], [81.19847107, 16.14680481], [81.19847107, 16.14541626], [81.19819641, 16.14542007], [81.19819641, 16.14375114], [81.19790649, 16.14375114], [81.19790649, 16.14347076], [81.19763947, 16.14347267], [81.19763947, 16.1431942], [81.19736481, 16.1431942], [81.19736481, 16.14291954], [81.19680786, 16.14292908], [81.19680786, 16.14264107], [81.19568634, 16.14264107], [81.19568634, 16.14292908], [81.19041443, 16.14291954], [81.19041443, 16.1431942], [81.18902588, 16.1431942], [81.18902588, 16.14291954], [81.18875122, 16.14291954], [81.18875122, 16.1431942], [81.18819427, 16.1431942], [81.18819427, 16.14347267], [81.18763733, 16.14347076], [81.18763733, 16.14375114], [81.18708038, 16.14375114], [81.18708038, 16.14402962], [81.18569946, 16.14402962], [81.18569946, 16.14375114], [81.18514252, 16.14375114], [81.18514252, 16.14347076], [81.18264008, 16.14347267], [81.18264008, 16.14291573], [81.18319702, 16.14292908], [81.18319702, 16.14264107], [81.18402863, 16.14264107], [81.18402863, 16.14236069], [81.18514252, 16.14236069], [81.18514252, 16.14264107], [81.18624878, 16.14264107], [81.18624878, 16.14292908], [81.18736267, 16.14292908], [81.18736267, 16.14264107], [81.18763733, 16.14264107], [81.18763733, 16.14292908], [81.18846893, 16.14292908], [81.18846893, 16.14264107], [81.18863678, 16.14264107], [81.18958282, 16.14264107], [81.18958282, 16.14236069], [81.1904068, 16.14236069], [81.1904068, 16.14208031], [81.19097137, 16.14208412], [81.19097137, 16.14180565], [81.19235992, 16.14180946], [81.19235992, 16.14153099], [81.19374847, 16.14153099], [81.19374847, 16.14125061], [81.19487, 16.14125061], [81.19486237, 16.14097214], [81.19708252, 16.14097023], [81.19708252, 16.14125061], [81.19735718, 16.14125061], [81.19735718, 16.14097023], [81.19819641, 16.14097023], [81.19819641, 16.14125061], [81.19875336, 16.14125061], [81.19875336, 16.14153099], [81.19930267, 16.14153099], [81.19930267, 16.14180946], [81.19985962, 16.14180946], [81.19985962, 16.14236069], [81.20014191, 16.14236069], [81.20014191, 16.1431942], [81.20153046, 16.1431942], [81.20153046, 16.14291573], [81.20181274, 16.14292908], [81.20181274, 16.14236069], [81.20153046, 16.14236069], [81.20153046, 16.14097023], [81.20124817, 16.14097214], [81.20124817, 16.13986206], [81.20096588, 16.13986969], [81.20096588, 16.13820076], [81.20067596, 16.13820076], [81.20067596, 16.13597107], [81.20041656, 16.13597488], [81.20041656, 16.13541603], [81.20014191, 16.13541985], [81.20014191, 16.13402939], [81.19985962, 16.13402939], [81.19985962, 16.13319016], [81.19958496, 16.13319397], [81.19958496, 16.13264084], [81.19930267, 16.13264084], [81.19930267, 16.13207817], [81.19902802, 16.13208389], [81.19902802, 16.13152695], [81.19875336, 16.13153076], [81.19875336, 16.13042068], [81.19847107, 16.13042068], [81.19847107, 16.12957954], [81.19819641, 16.12958336], [81.19819641, 16.12847137], [81.19791412, 16.12847137], [81.19791412, 16.12652779], [81.19763947, 16.12652969], [81.19763947, 16.12597084], [81.19736481, 16.12597275], [81.19736481, 16.12513924], [81.19708252, 16.12514114], [81.19708252, 16.12458038], [81.19680786, 16.1245842], [81.19680786, 16.12375069], [81.19652557, 16.12375069], [81.19652557, 16.12319374], [81.19625092, 16.12319374], [81.19625092, 16.12236023], [81.19596863, 16.12236023], [81.19596863, 16.12153053], [81.19568634, 16.12153053], [81.19568634, 16.12070274], [81.19541931, 16.12070274], [81.19541931, 16.12014008], [81.19513702, 16.12014008], [81.19513702, 16.11930084], [81.19486237, 16.11930466], [81.19486237, 16.11847305], [81.19458008, 16.11847305], [81.19458008, 16.11763763], [81.19430542, 16.11763763], [81.19430542, 16.11680794], [81.19403076, 16.11680984], [81.19403076, 16.11597061], [81.19374847, 16.11597252], [81.19374847, 16.11541939], [81.19346619, 16.11541939], [81.19346619, 16.11458015], [81.19319153, 16.11458397], [81.19319153, 16.11375046], [81.19291687, 16.11375046], [81.19291687, 16.1129303], [81.19264221, 16.1129303], [81.19264221, 16.11236], [81.19235992, 16.11236191], [81.19235992, 16.1115284], [81.1920929, 16.1115303], [81.1920929, 16.11069107], [81.19180298, 16.11069489], [81.19180298, 16.11013985], [81.19152832, 16.11013985], [81.19152832, 16.10931015], [81.19124603, 16.10931015], [81.19124603, 16.10874939], [81.19097137, 16.10874939], [81.19097137, 16.10791969], [81.19069672, 16.10791969], [81.19069672, 16.10708046], [81.19041443, 16.10708427], [81.19041443, 16.10652733], [81.19013977, 16.10653114], [81.19013977, 16.1056881], [81.18985748, 16.10569382], [81.18985748, 16.10514069], [81.18958282, 16.10514069], [81.18958282, 16.10430908], [81.18930817, 16.10430908], [81.18930817, 16.10346985], [81.18902588, 16.10347176], [81.18902588, 16.10291862], [81.18873596, 16.10292053], [81.18873596, 16.10235977], [81.18846893, 16.10236168], [81.18846893, 16.10180473], [81.18819427, 16.10180473], [81.18819427, 16.10124969], [81.18791962, 16.10124969], [81.18791962, 16.10070038], [81.18763733, 16.10070038], [81.18763733, 16.10013962], [81.18736267, 16.10013962], [81.18736267, 16.09958076], [81.18708038, 16.09958267], [81.18708038, 16.09902763], [81.18681335, 16.09902954], [81.18681335, 16.09847069], [81.18653107, 16.0984726], [81.18653107, 16.09819412], [81.18624878, 16.09819412], [81.18624878, 16.09763908], [81.18597412, 16.09763908], [81.18597412, 16.09708214], [81.18569183, 16.09708214], [81.18569183, 16.0965271], [81.18541718, 16.09653091], [81.18541718, 16.09597015], [81.18514252, 16.09597206], [81.18514252, 16.09541702], [81.18486023, 16.09542084], [81.18486023, 16.09486008], [81.18458557, 16.09486389], [81.18458557, 16.09430504], [81.18430328, 16.09431076], [81.18430328, 16.09375191], [81.18402863, 16.09375191], [81.18402863, 16.09346962], [81.18374634, 16.09346962], [81.18374634, 16.09291649], [81.18347168, 16.0929203], [81.18347168, 16.09236145], [81.18319702, 16.09236145], [81.18319702, 16.09180641], [81.1829071, 16.09181976], [81.1829071, 16.09124756], [81.18264008, 16.09124756], [81.18264008, 16.09069061], [81.18235779, 16.09069443], [81.18235779, 16.09013748], [81.18208313, 16.09013748], [81.18208313, 16.08958054], [81.18180847, 16.08958244], [81.18180847, 16.08930779], [81.18152618, 16.08930969], [81.18152618, 16.08876038], [81.18125153, 16.08876038], [81.18125153, 16.08819008], [81.18096924, 16.08819389], [81.18096924, 16.08763885], [81.18068695, 16.08764076], [81.18068695, 16.08736038], [81.18041992, 16.08736038], [81.18041992, 16.08681107], [81.18013763, 16.08681107], [81.18013763, 16.08625031], [81.17986298, 16.08625031], [81.17986298, 16.08568954], [81.17958069, 16.08569527], [81.17958069, 16.08541679], [81.17930603, 16.08542061], [81.17930603, 16.08485985], [81.17903137, 16.08486176], [81.17903137, 16.08430481], [81.17874908, 16.08430481], [81.17874908, 16.08374977], [81.1784668, 16.08374977], [81.1784668, 16.08346939], [81.17819214, 16.0834713], [81.17819214, 16.08291626], [81.17791748, 16.08292007], [81.17791748, 16.08236122], [81.17763519, 16.08236122], [81.17763519, 16.08180618], [81.17736053, 16.08181], [81.17736053, 16.08152962], [81.17708588, 16.08152962], [81.17708588, 16.08097267], [81.17680359, 16.08097267], [81.17680359, 16.08041763], [81.17664337, 16.08041573], [81.17652893, 16.08041954], [81.17652893, 16.07986259], [81.17624664, 16.07986259], [81.17624664, 16.07959175], [81.17597198, 16.07959175], [81.17597198, 16.07902908], [81.17569733, 16.07902908], [81.17569733, 16.07846832], [81.17541504, 16.07847023], [81.17541504, 16.0779171], [81.17514038, 16.07792091], [81.17514038, 16.07764053], [81.17485809, 16.07764053], [81.17485809, 16.07707977], [81.17458344, 16.07708359], [81.17458344, 16.07653046], [81.17430878, 16.07653046], [81.17430878, 16.0759697], [81.17402649, 16.0759716], [81.17402649, 16.07569695], [81.17375946, 16.07570076], [81.17375946, 16.07513809], [81.17346954, 16.07513809], [81.17346954, 16.07458115], [81.17319489, 16.07458305], [81.17319489, 16.07402611], [81.17292023, 16.07402992], [81.17292023, 16.07374954], [81.17263794, 16.07374954], [81.17263794, 16.07319069], [81.17236328, 16.0731945], [81.17236328, 16.07263947], [81.17208099, 16.07263947], [81.17208099, 16.07208061], [81.17180634, 16.07208252], [81.17180634, 16.07152748], [81.17151642, 16.07152939], [81.17151642, 16.07097054], [81.17124939, 16.07097244], [81.17124939, 16.07069588], [81.17097473, 16.07069588], [81.17097473, 16.07013893], [81.17070007, 16.07014084], [81.17070007, 16.06958008], [81.17041779, 16.06958389], [81.17041779, 16.06902695], [81.17014313, 16.06903076], [81.17014313, 16.06847191], [81.16986084, 16.06847382], [81.16986084, 16.06791687], [81.16958618, 16.06792068], [81.16958618, 16.06764984], [81.16929626, 16.06764984], [81.16929626, 16.06707954], [81.16902924, 16.06708336], [81.16902924, 16.06652832], [81.16874695, 16.06653023], [81.16874695, 16.06596947], [81.16847229, 16.06596947], [81.16847229, 16.06541634], [81.16819763, 16.06542015], [81.16819763, 16.0648613], [81.16791534, 16.0648613], [81.16791534, 16.06430626], [81.16763306, 16.06430817], [81.16763306, 16.06402969], [81.1673584, 16.06402969], [81.1673584, 16.06347084], [81.16708374, 16.06347275], [81.16708374, 16.0629158], [81.16680908, 16.06291962], [81.16680908, 16.06236076], [81.16652679, 16.06236076], [81.16652679, 16.06180954], [81.16625214, 16.06180954], [81.16625214, 16.06125069], [81.16596985, 16.06125069], [81.16596985, 16.06097031], [81.16569519, 16.06097221], [81.16569519, 16.06041527], [81.1654129, 16.06042099], [81.1654129, 16.05986023], [81.16513824, 16.05986023], [81.16513824, 16.05931091], [81.16485596, 16.05931091], [81.16485596, 16.05875015], [81.16456604, 16.05875015], [81.16456604, 16.05820084], [81.16430664, 16.05820084], [81.16430664, 16.05792046], [81.16401672, 16.05792046], [81.16401672, 16.0573597], [81.16374969, 16.0573616], [81.16374969, 16.05680466], [81.16347504, 16.05680466], [81.16347504, 16.05624962], [81.16319275, 16.05624962], [81.16319275, 16.05597115], [81.16291809, 16.05597305], [81.16291809, 16.05541611], [81.1626358, 16.05541992], [81.1626358, 16.05486107], [81.16236115, 16.05486107], [81.16236115, 16.05455017], [81.16236115, 16.05430603], [81.16208649, 16.05430603], [81.16208649, 16.05402756], [81.1618042, 16.05402756], [81.1618042, 16.05347252], [81.16152954, 16.05347252], [81.16152954, 16.05291748], [81.16124725, 16.05291939], [81.16124725, 16.05235863], [81.1609726, 16.05235863], [81.1609726, 16.05207825], [81.16069794, 16.05208397], [81.16069794, 16.05152893], [81.16042328, 16.05153084], [81.16042328, 16.05096817], [81.16014099, 16.05097008], [81.16014099, 16.05041885], [81.1598587, 16.05042076], [81.1598587, 16.05014038], [81.15957642, 16.05014038], [81.15957642, 16.04957962], [81.15930176, 16.04958344], [81.15930176, 16.04902649], [81.1590271, 16.0490303], [81.1590271, 16.04846954], [81.15875244, 16.04847145], [81.15875244, 16.04819489], [81.15847015, 16.04819489], [81.15847015, 16.04763985], [81.15820313, 16.04763985], [81.15820313, 16.04708099], [81.15791321, 16.0470829], [81.15791321, 16.04652786], [81.15763855, 16.04652786], [81.15763855, 16.04624939], [81.15735626, 16.04624939], [81.15735626, 16.04569054], [81.1570816, 16.04569435], [81.1570816, 16.04513931], [81.15680695, 16.04514122], [81.15680695, 16.04458046], [81.15652466, 16.04458427], [81.15652466, 16.04402733], [81.15625, 16.04403114], [81.15625, 16.04346275], [81.15597534, 16.04347229], [81.15597534, 16.04291725], [81.15569305, 16.04292107], [81.15569305, 16.04236031], [81.1554184, 16.04236031], [81.1554184, 16.0418129], [81.15513611, 16.0418129], [81.15513611, 16.04125023], [81.15486145, 16.04125023], [81.15486145, 16.04071045], [81.15458679, 16.04071045], [81.15458679, 16.04042053], [81.15429688, 16.04042053], [81.15429688, 16.03986168], [81.15402985, 16.03986168], [81.15402985, 16.03930473], [81.1543045, 16.03930473], [81.1543045, 16.0387516], [81.15402985, 16.0387516], [81.15402985, 16.03846931], [81.1534729, 16.03847313], [81.1534729, 16.03819466], [81.15319824, 16.03819466], [81.15319061, 16.03763962], [81.15291595, 16.03763962], [81.15291595, 16.03708076], [81.1526413, 16.03708267], [81.1526413, 16.03652954], [81.15235901, 16.03652954], [81.15235901, 16.03597069], [81.15208435, 16.0359726], [81.15208435, 16.03541946], [81.15180206, 16.03541946], [81.15180206, 16.03486061], [81.1515274, 16.03486061], [81.1515274, 16.03458023], [81.15125275, 16.03458405], [81.15125275, 16.03402519], [81.15097046, 16.03403091], [81.15097046, 16.03347015], [81.1506958, 16.03347206], [81.1506958, 16.03319359], [81.15041351, 16.03319359], [81.15041351, 16.03263855], [81.15013885, 16.03264046], [81.15013885, 16.03236008], [81.1498642, 16.03236198], [81.1498642, 16.03180313], [81.14958954, 16.03181076], [81.14958954, 16.03125], [81.14930725, 16.03125], [81.14930725, 16.03096962], [81.14902496, 16.03097153], [81.14902496, 16.03041649], [81.14875031, 16.0304203], [81.14875031, 16.03013992], [81.14848328, 16.03013992], [81.14848328, 16.02958107], [81.14819336, 16.02958488], [81.14819336, 16.02930641], [81.1479187, 16.02931023], [81.1479187, 16.02902985], [81.14763641, 16.02902985], [81.14763641, 16.02848053], [81.14736176, 16.02848053], [81.14736176, 16.02819061], [81.1470871, 16.02819443], [81.1470871, 16.02791595], [81.14679718, 16.02791977], [81.14679718, 16.02736282], [81.14653015, 16.02736282], [81.14653015, 16.02708244], [81.14624786, 16.02708244], [81.14624786, 16.0265274], [81.14597321, 16.02653122], [81.14597321, 16.02625275], [81.14569092, 16.02625275], [81.14569092, 16.02596855], [81.14541626, 16.02597237], [81.14541626, 16.02541733], [81.1451416, 16.02541924], [81.1451416, 16.02514076], [81.14485931, 16.02514076], [81.14485931, 16.02485847], [81.14457703, 16.02485847], [81.14457703, 16.02430916], [81.14430237, 16.02430916], [81.14430237, 16.02403069], [81.14402771, 16.02403069], [81.14402771, 16.0237484], [81.14375305, 16.0237484], [81.14375305, 16.02319908], [81.14346313, 16.02319908], [81.14346313, 16.02264023], [81.14319611, 16.02264023], [81.14319611, 16.02207947], [81.14291382, 16.02208328], [81.14291382, 16.02152634], [81.14263916, 16.02153015], [81.14263916, 16.02096939], [81.1423645, 16.0209713], [81.1423645, 16.02041626], [81.14208221, 16.02042007], [81.14208221, 16.01986122], [81.14180756, 16.01986122], [81.14180756, 16.01931], [81.14154053, 16.01931], [81.14152527, 16.01919937], [81.14152527, 16.01874924], [81.14137268, 16.01874924], [81.14125061, 16.01875114], [81.14125061, 16.01844978], [81.14125061, 16.0181942], [81.14097595, 16.0181942], [81.14097595, 16.01769257], [81.14097595, 16.01680565], [81.14068604, 16.01680946], [81.14068604, 16.01542091], [81.14041901, 16.01542091], [81.14041901, 16.01375008], [81.14013672, 16.01375008], [81.14013672, 16.01207924], [81.13986206, 16.01208305], [81.13986206, 16.00985909], [81.13957977, 16.00985909], [81.13957977, 16.00764084], [81.13986206, 16.00764084], [81.13986206, 16.00653076], [81.13957977, 16.00653076], [81.13957977, 16.0051403], [81.13986206, 16.0051403], [81.13986206, 16.0031929], [81.13957977, 16.00319481], [81.13957977, 16.00013924], [81.13957977, 15.99986172], [81.13957977, 15.99763966], [81.13931274, 15.99763966], [81.13931274, 15.99735928], [81.13903046, 15.99736214], [81.13903046, 15.99597359], [81.13930511, 15.99597359], [81.13930511, 15.99569321], [81.13957977, 15.99569321], [81.13957977, 15.99513912], [81.13986206, 15.99514198], [81.13986206, 15.99431038], [81.14013672, 15.99431038], [81.14013672, 15.99403191], [81.14041901, 15.99403191], [81.14041901, 15.99347115], [81.14069366, 15.99347115], [81.14069366, 15.99180508], [81.14097595, 15.99181175], [81.14097595, 15.99097061], [81.14125061, 15.99097347], [81.14125061, 15.98986053], [81.14097595, 15.98986053], [81.14097595, 15.98875141], [81.14125061, 15.98875141], [81.14125061, 15.98847103], [81.14152527, 15.98847294], [81.14152527, 15.98736095], [81.14180756, 15.98736095], [81.14180756, 15.98596954], [81.14208221, 15.98597336], [81.14208221, 15.98513889], [81.14235687, 15.9851408], [81.14235687, 15.98486137], [81.14263916, 15.98486137], [81.14263916, 15.9845829], [81.14291382, 15.9845829], [81.14291382, 15.98430443], [81.14346313, 15.9843111], [81.14346313, 15.98236275], [81.14402771, 15.98236275], [81.14402771, 15.98264122], [81.14430237, 15.98264122], [81.14430237, 15.98236275], [81.14485931, 15.98236275], [81.14485931, 15.98181057], [81.1451416, 15.98181057], [81.1451416, 15.98153114], [81.14541626, 15.98153114], [81.14541626, 15.98097038], [81.14569092, 15.98097229], [81.14569092, 15.98069382], [81.14597321, 15.98069382], [81.14597321, 15.97930622], [81.14569092, 15.97931099], [81.14569092, 15.97903061], [81.14541626, 15.97903061], [81.14541626, 15.97846985], [81.1451416, 15.97847176], [81.1451416, 15.97764015], [81.14541626, 15.97764015], [81.14541626, 15.97486019], [81.14597321, 15.9748621], [81.14597321, 15.97430611], [81.14569092, 15.97430611], [81.14569092, 15.97375011], [81.14402771, 15.97375202], [81.14402771, 15.97347164], [81.14375305, 15.97347164], [81.14375305, 15.97319412], [81.14319611, 15.97319412], [81.14319611, 15.97291565], [81.1423645, 15.97291565], [81.1423645, 15.97319412], [81.14152527, 15.97319412], [81.14152527, 15.97347164], [81.14097595, 15.97347164], [81.14097595, 15.97319412], [81.13986206, 15.97319412], [81.13986206, 15.97347164], [81.13903046, 15.97347164], [81.13903046, 15.97319412], [81.13874817, 15.97319412], [81.13874817, 15.97347164], [81.13819122, 15.97347164], [81.13819122, 15.97375202], [81.13680267, 15.97375202], [81.13680267, 15.97402954], [81.13569641, 15.97402763], [81.13569641, 15.97430611], [81.13541412, 15.97430611], [81.13541412, 15.97402763], [81.13346863, 15.97402954], [81.13346863, 15.97375202], [81.13263702, 15.97375202], [81.13263702, 15.97347164], [81.13236237, 15.97347164], [81.13236237, 15.97319412], [81.13208008, 15.97319412], [81.13208008, 15.97291565], [81.13152313, 15.97292042], [81.13152313, 15.97264194], [81.13124847, 15.97264194], [81.13124847, 15.97235966], [81.13097382, 15.97236156], [81.13097382, 15.97208405], [81.13069153, 15.97208405], [81.13069153, 15.97180557], [81.13041687, 15.97181034], [81.13041687, 15.97124004], [81.13069153, 15.97124958], [81.13069153, 15.97041798], [81.13096619, 15.97042179], [81.13096619, 15.96875191], [81.13069153, 15.96875191], [81.13069153, 15.96736145], [81.13041687, 15.96736145], [81.13041687, 15.96708298], [81.13014221, 15.96708298], [81.13014221, 15.96680546], [81.12985992, 15.96681023], [81.12985992, 15.96653175], [81.1295929, 15.96653175], [81.1295929, 15.96597099], [81.12930298, 15.96597099], [81.12930298, 15.96579075], [81.12930298, 15.96513939], [81.12902832, 15.9651413], [81.12902832, 15.96458054], [81.12875366, 15.9645834], [81.12875366, 15.9640274], [81.12845612, 15.96402931], [81.12845612, 15.96347141], [81.12819672, 15.96347332], [81.12819672, 15.96319485], [81.12791443, 15.96319485], [81.12791443, 15.96291733], [81.12735748, 15.96291924], [81.12735748, 15.96264076], [81.12708282, 15.96264076], [81.12708282, 15.96236134], [81.12680817, 15.96236134], [81.12680817, 15.96208286], [81.12652588, 15.96208286], [81.12652588, 15.96180534], [81.12625122, 15.96181202], [81.12625122, 15.96153069], [81.12596893, 15.96153069], [81.12596893, 15.96125126], [81.12568665, 15.96125126], [81.12568665, 15.96097088], [81.12513733, 15.96097279], [81.12513733, 15.96069527], [81.12486267, 15.96069527], [81.12486267, 15.96041679], [81.12431335, 15.96042061], [81.12431335, 15.96014118], [81.12403107, 15.96014118], [81.12403107, 15.9598608], [81.12374878, 15.9598608], [81.12374878, 15.95958328], [81.12347412, 15.95958328], [81.12347412, 15.9590292], [81.12319183, 15.95903111], [81.12316132, 15.95875072], [81.12291718, 15.95875072], [81.12291718, 15.95847034], [81.12236023, 15.95847321], [81.12236023, 15.95819473], [81.12208557, 15.95819473], [81.12208557, 15.95791721], [81.12152863, 15.95792103], [81.12152863, 15.95764065], [81.12124634, 15.95764065], [81.12124634, 15.95736122], [81.12069702, 15.95736122], [81.12069702, 15.95708466], [81.12041473, 15.95708466], [81.12041473, 15.95680428], [81.12014008, 15.95681095], [81.12014008, 15.95653057], [81.11985779, 15.95653057], [81.11985779, 15.95625973], [81.11958313, 15.95625973], [81.11958313, 15.95597267], [81.11930847, 15.95597267], [81.11930847, 15.9556942], [81.11875153, 15.9556942], [81.11875153, 15.95541573], [81.11846924, 15.95542145], [81.11846924, 15.95514107], [81.11818695, 15.95514107], [81.11818695, 15.95485973], [81.11791992, 15.95485973], [81.11791992, 15.95458031], [81.11708069, 15.95458221], [81.11708069, 15.95430565], [81.11680603, 15.95431137], [81.11680603, 15.95403099], [81.11651611, 15.95403099], [81.11651611, 15.95374966], [81.1159668, 15.95374966], [81.1159668, 15.95347023], [81.11569214, 15.95347214], [81.11569214, 15.95319366], [81.11541748, 15.95320129], [81.11541748, 15.95292091], [81.11514282, 15.95292091], [81.11514282, 15.95263958], [81.11486053, 15.95263958], [81.11486053, 15.95236015], [81.11458588, 15.95236015], [81.11458588, 15.95208359], [81.11430359, 15.95208359], [81.11430359, 15.95180416], [81.11374664, 15.95181084], [81.11374664, 15.95125008], [81.11345673, 15.95125008], [81.11345673, 15.9509697], [81.11319733, 15.9509716], [81.11319733, 15.95069408], [81.11264038, 15.95069408], [81.11264038, 15.95041561], [81.11235809, 15.95042133], [81.11235809, 15.95014], [81.11207581, 15.95014], [81.11207581, 15.94985962], [81.11152649, 15.94986153], [81.11152649, 15.94958401], [81.11125183, 15.94958401], [81.11125183, 15.94930553], [81.11096954, 15.94931126], [81.11096954, 15.94902992], [81.11042023, 15.94902992], [81.11042023, 15.94874954], [81.11013794, 15.94874954], [81.11013794, 15.94847202], [81.10986328, 15.94847202], [81.10986328, 15.94791794], [81.10958099, 15.94791985], [81.10958099, 15.94764042], [81.10930634, 15.94764042], [81.10930634, 15.94736195], [81.10874939, 15.94736195], [81.10874939, 15.94707012], [81.10847473, 15.94708443], [81.10847473, 15.94680595], [81.10791779, 15.94680977], [81.10791779, 15.94653034], [81.10764313, 15.94653034], [81.10764313, 15.94625187], [81.10736084, 15.94625187], [81.10736084, 15.94597244], [81.10708618, 15.94597244], [81.10708618, 15.94569588], [81.10679626, 15.9456892], [81.10680389, 15.94541645], [81.10652924, 15.94542027], [81.10652924, 15.94514179], [81.10624695, 15.94514179], [81.10624695, 15.94485855], [81.10597229, 15.94486237], [81.10597229, 15.94458389], [81.10569763, 15.94458389], [81.10569763, 15.94430637], [81.10542297, 15.94432163], [81.10542297, 15.94402981], [81.10514069, 15.94402981], [81.10514069, 15.94375038], [81.1048584, 15.94375038], [81.1048584, 15.94347095], [81.10458374, 15.94347095], [81.10458374, 15.94291782], [81.10430908, 15.94291973], [81.10430908, 15.9426403], [81.10402679, 15.9426403], [81.10402679, 15.94236183], [81.10375214, 15.94236183], [81.10375214, 15.94208145], [81.10346985, 15.94208336], [81.10346985, 15.94180489], [81.10320282, 15.94180965], [81.10320282, 15.94153023], [81.10263824, 15.94153023], [81.10263824, 15.94126129], [81.10235596, 15.94126129], [81.10235596, 15.94097137], [81.1020813, 15.94097137], [81.1020813, 15.94069481], [81.10152435, 15.94069481], [81.10152435, 15.94041729], [81.10124969, 15.94042015], [81.10124969, 15.9398613], [81.10097504, 15.9398613], [81.10097504, 15.93958282], [81.10069275, 15.93958282], [81.10069275, 15.93930531], [81.10041809, 15.93931198], [81.10041809, 15.9390316], [81.1001358, 15.9390316], [81.1001358, 15.93875122], [81.09986115, 15.93875122], [81.09986115, 15.93847084], [81.09902954, 15.93847084], [81.09902954, 15.9382], [81.09874725, 15.9382], [81.09874725, 15.93791866], [81.09848022, 15.93791866], [81.09848022, 15.93763924], [81.09819794, 15.93763924], [81.09819794, 15.93736076], [81.09764099, 15.93736076], [81.09764099, 15.93708134], [81.0973587, 15.93708324], [81.0973587, 15.93680477], [81.09707642, 15.93680954], [81.09707642, 15.93653107], [81.09680176, 15.93653107], [81.09680176, 15.93625069], [81.0965271, 15.93625069], [81.0965271, 15.93597126], [81.09597015, 15.93597317], [81.09597015, 15.93569469], [81.0956955, 15.93569469], [81.0956955, 15.93541718], [81.09542084, 15.93542194], [81.09542084, 15.93513203], [81.09513855, 15.9351387], [81.09513855, 15.93486118], [81.09486389, 15.93486118], [81.09486389, 15.93458271], [81.0945816, 15.93458271], [81.0945816, 15.93430519], [81.09401703, 15.93431187], [81.09401703, 15.93403053], [81.09348297, 15.93403053], [81.09348297, 15.93375111], [81.09319305, 15.93375111], [81.09319305, 15.93347073], [81.0929184, 15.93347263], [81.0929184, 15.93319511], [81.09263611, 15.93319511], [81.09263611, 15.93291664], [81.09234619, 15.93292141], [81.09234619, 15.93264103], [81.09179688, 15.93264103], [81.09179688, 15.93236065], [81.09124756, 15.93236065], [81.09124756, 15.93207073], [81.0909729, 15.93208313], [81.0909729, 15.93180466], [81.09069824, 15.93181133], [81.09069061, 15.93153095], [81.0901413, 15.93153095], [81.0901413, 15.93125057], [81.08957672, 15.93125057], [81.08957672, 15.93097019], [81.08930206, 15.93097305], [81.08930206, 15.93069458], [81.0890274, 15.93069458], [81.0890274, 15.93041706], [81.08847046, 15.93042088], [81.08847046, 15.93014145], [81.0881958, 15.93014145], [81.0881958, 15.92986012], [81.08790588, 15.92986012], [81.08790588, 15.92957973], [81.08763885, 15.92958546], [81.08763885, 15.92902946], [81.08735657, 15.92903137], [81.08735657, 15.92875099], [81.08708191, 15.92875099], [81.08708191, 15.92819023], [81.08680725, 15.92819405], [81.08680725, 15.92791557], [81.08651733, 15.9279213], [81.08651733, 15.92735958], [81.08625031, 15.9273634], [81.08625031, 15.92680645], [81.08598328, 15.92681122], [81.08598328, 15.9262619], [81.08569336, 15.9262619], [81.08569336, 15.92597008], [81.0854187, 15.92597198], [81.0854187, 15.92569447], [81.08513641, 15.92569447], [81.08513641, 15.92541599], [81.08486176, 15.92542076], [81.08486176, 15.92514038], [81.0845871, 15.92514038], [81.0845871, 15.92486], [81.08429718, 15.92486], [81.08429718, 15.92457962], [81.08403015, 15.92458439], [81.08403015, 15.92430592], [81.08374786, 15.92431068], [81.08374786, 15.92374992], [81.08348083, 15.92374992], [81.08348083, 15.92346954], [81.08319092, 15.9234724], [81.08319092, 15.92319393], [81.0826416, 15.92319393], [81.0826416, 15.92291641], [81.08235931, 15.92292023], [81.08235931, 15.92263985], [81.08207703, 15.92263985], [81.08207703, 15.92236042], [81.08152771, 15.92236233], [81.08152771, 15.92208195], [81.08097076, 15.92208195], [81.08097076, 15.92180634], [81.08069611, 15.9218111], [81.08069611, 15.92152977], [81.08013916, 15.92152977], [81.08013916, 15.92125034], [81.07958221, 15.92125034], [81.07958221, 15.92097187], [81.07930756, 15.92097187], [81.07930756, 15.92069435], [81.07902527, 15.92069435], [81.07902527, 15.92041588], [81.07875061, 15.92041969], [81.07875061, 15.92013073], [81.07847595, 15.92014027], [81.07847595, 15.91986179], [81.07818604, 15.91986179], [81.07818604, 15.91958237], [81.07791901, 15.91958427], [81.07791901, 15.91902828], [81.07763672, 15.91903019], [81.07763672, 15.91874981], [81.0773468, 15.91874981], [81.0773468, 15.91846943], [81.07707977, 15.91847229], [81.07707977, 15.91819572], [81.07680511, 15.91819572], [81.07680511, 15.91763973], [81.07653046, 15.91763973], [81.07653046, 15.91735935], [81.07624817, 15.91736221], [81.07624817, 15.91708374], [81.07596588, 15.91709042], [81.07596588, 15.91681004], [81.07569122, 15.91681004], [81.07569122, 15.91649055], [81.07569122, 15.91624928], [81.07541656, 15.91624928], [81.07541656, 15.9159708], [81.07514191, 15.9159708], [81.07514191, 15.91569138], [81.07485962, 15.91569328], [81.07485962, 15.91541767], [81.07457733, 15.91541958], [81.07457733, 15.91486073], [81.07430267, 15.91486073], [81.07430267, 15.91458321], [81.07402802, 15.91458321], [81.07402802, 15.91430473], [81.07375336, 15.91431046], [81.07375336, 15.91403198], [81.07347107, 15.91403198], [81.07347107, 15.9137516], [81.07319641, 15.9137516], [81.07319641, 15.91347122], [81.07291412, 15.91347122], [81.07291412, 15.91319466], [81.07263947, 15.91319466], [81.07263947, 15.91291714], [81.07235718, 15.91292191], [81.07235718, 15.91264153], [81.07180786, 15.91264153], [81.07180786, 15.91236115], [81.07125092, 15.91236115], [81.07125092, 15.91208267], [81.07069397, 15.91208267], [81.07069397, 15.91152668], [81.07041931, 15.91152859], [81.07041931, 15.91125107], [81.07013702, 15.91125107], [81.07013702, 15.9109602], [81.06986237, 15.9109726], [81.06986237, 15.91069508], [81.06930542, 15.91069508], [81.06930542, 15.91013908], [81.06903076, 15.91014099], [81.06903076, 15.90986061], [81.06874847, 15.90986061], [81.06874847, 15.90958309], [81.06847382, 15.90958309], [81.06847382, 15.90902901], [81.06817627, 15.90903091], [81.06817627, 15.90875053], [81.06791687, 15.90875053], [81.06791687, 15.90847111], [81.06764221, 15.90847301], [81.06764221, 15.90791702], [81.06735992, 15.90792084], [81.06735992, 15.90764141], [81.0670929, 15.90764141], [81.0670929, 15.90736103], [81.06680298, 15.90736103], [81.06680298, 15.90681171], [81.06652832, 15.90681171], [81.06652832, 15.90653133], [81.06624603, 15.90653133], [81.06624603, 15.90597057], [81.06597137, 15.90597343], [81.06597137, 15.90569496], [81.06569672, 15.90569496], [81.06569672, 15.90513897], [81.0654068, 15.90515041], [81.0654068, 15.90486145], [81.06513977, 15.90486145], [81.06513977, 15.90458298], [81.06485748, 15.90458298], [81.06485748, 15.90430546], [81.06458282, 15.90431118], [81.06458282, 15.9040308], [81.06430817, 15.9040308], [81.06430817, 15.90347004], [81.06402588, 15.9034729], [81.06402588, 15.90319538], [81.06375122, 15.90319538], [81.06375122, 15.90291691], [81.06318665, 15.90292072], [81.06318665, 15.9026413], [81.06291962, 15.9026413], [81.06291962, 15.90235996], [81.06263733, 15.90235996], [81.06263733, 15.90209103], [81.0623703, 15.90209103], [81.0623703, 15.90181065], [81.06208038, 15.90181065], [81.06208038, 15.90153122], [81.06181335, 15.90153122], [81.06181335, 15.90125275], [81.06153107, 15.90125275], [81.06153107, 15.90097046], [81.06124878, 15.90097237], [81.06124878, 15.90069389], [81.06097412, 15.90069389], [81.06097412, 15.90041637], [81.06069183, 15.90042114], [81.06069183, 15.89986038], [81.06041718, 15.89986229], [81.06041718, 15.89958382], [81.06014252, 15.89958191], [81.06014252, 15.8993063], [81.05960083, 15.89931107], [81.05960083, 15.89901924], [81.05930328, 15.89902782], [81.05930328, 15.89819431], [81.05902863, 15.89819431], [81.05902863, 15.89791584], [81.05874634, 15.89792061], [81.05874634, 15.89764023], [81.05847168, 15.89764023], [81.05847168, 15.89735985], [81.05819702, 15.89735985], [81.05819702, 15.89708424], [81.05791473, 15.89708424], [81.05791473, 15.89652824], [81.05764008, 15.89653015], [81.05764008, 15.89596081], [81.05735779, 15.89597225], [81.05735779, 15.89569378], [81.05708313, 15.89569378], [81.05708313, 15.89541626], [81.05680847, 15.89542007], [81.05680847, 15.89513969], [81.05652618, 15.89513969], [81.05652618, 15.89486027], [81.05625153, 15.89486217], [81.05625153, 15.8945837], [81.05596924, 15.8945837], [81.05596924, 15.89430618], [81.05568695, 15.89431095], [81.05568695, 15.89375019], [81.05541992, 15.89375019], [81.05541992, 15.89347172], [81.05513763, 15.89347172], [81.05513763, 15.8931942], [81.05486298, 15.8931942], [81.05486298, 15.89264011], [81.05458069, 15.89264202], [81.05458069, 15.89207935], [81.05430603, 15.89208412], [81.05430603, 15.89152813], [81.05403137, 15.89153004], [81.05403137, 15.89124966], [81.05374908, 15.89124966], [81.05374908, 15.89096928], [81.05347443, 15.89097214], [81.05347443, 15.89069366], [81.05319214, 15.89069366], [81.05319214, 15.89041805], [81.05291748, 15.89041996], [81.05291748, 15.89015102], [81.05264282, 15.89015102], [81.05264282, 15.8898592], [81.05236053, 15.88986206], [81.05236053, 15.88958359], [81.05208588, 15.88958359], [81.05208588, 15.88930607], [81.05179596, 15.88931179], [81.05179596, 15.88875198], [81.05152893, 15.88875198], [81.05152893, 15.88847065], [81.05097198, 15.88847446], [81.05097198, 15.88819313], [81.05069733, 15.88819313], [81.05069733, 15.88736057], [81.05041504, 15.88736057], [81.05041504, 15.88708305], [81.05014038, 15.88708305], [81.05014038, 15.88652706], [81.04985809, 15.88653183], [81.04985809, 15.88597107], [81.04958344, 15.88597107], [81.04958344, 15.88569546], [81.04930878, 15.88569546], [81.04930878, 15.88513947], [81.04902649, 15.88514233], [81.04902649, 15.88458061], [81.04875183, 15.88458347], [81.04875183, 15.884305], [81.04846954, 15.88430977], [81.04846954, 15.88401985], [81.04819489, 15.88402653], [81.04819489, 15.88374901], [81.04763794, 15.88375092], [81.04763794, 15.88347054], [81.04736328, 15.8834734], [81.04736328, 15.88319492], [81.04708099, 15.88319111], [81.04708099, 15.8829174], [81.04680634, 15.88291931], [81.04680634, 15.88264084], [81.04651642, 15.88264084], [81.04651642, 15.88236141], [81.04624939, 15.88236141], [81.04624939, 15.88208294], [81.04597473, 15.88208294], [81.04597473, 15.88180542], [81.04541779, 15.88180923], [81.04541779, 15.88153076], [81.04486084, 15.88153076], [81.04486084, 15.88125134], [81.04458618, 15.88125134], [81.04458618, 15.88097954], [81.04429626, 15.88097954], [81.04429626, 15.88068962], [81.04402924, 15.88069534], [81.04402924, 15.88041687], [81.04374695, 15.88042068], [81.04374695, 15.88014126], [81.04347229, 15.88014126], [81.04347229, 15.87986088], [81.04319763, 15.87986088], [81.04319763, 15.87957954], [81.04291534, 15.87958336], [81.04291534, 15.87930679], [81.04264069, 15.87931156], [81.04264069, 15.87903118], [81.0423584, 15.87903118], [81.0423584, 15.8787508], [81.04207611, 15.8787508], [81.04207611, 15.87847137], [81.04152679, 15.87847328], [81.04152679, 15.87791729], [81.04123688, 15.8779211], [81.04123688, 15.87764072], [81.04070282, 15.87764072], [81.04070282, 15.8773613], [81.0404129, 15.8773613], [81.0404129, 15.87708473], [81.03986359, 15.87708473], [81.03986359, 15.87652874], [81.0395813, 15.87653065], [81.0395813, 15.87625122], [81.03930664, 15.87625122], [81.03930664, 15.87597275], [81.03874969, 15.87597275], [81.03874969, 15.87569046], [81.03847504, 15.87569523], [81.03847504, 15.87513828], [81.03820038, 15.87514114], [81.03820038, 15.87485123], [81.03791809, 15.87485981], [81.03791809, 15.87430668], [81.0376358, 15.87431145], [81.0376358, 15.87403107], [81.03736115, 15.87403107], [81.03736115, 15.87374973], [81.03708649, 15.87374973], [81.03708649, 15.87347031], [81.0368042, 15.87347221], [81.0368042, 15.87319374], [81.03624725, 15.87319374], [81.03624725, 15.87291622], [81.0359726, 15.87292099], [81.0359726, 15.87236023], [81.03569794, 15.87236023], [81.03569794, 15.87208366], [81.03541565, 15.87208366], [81.03541565, 15.87180614], [81.0348587, 15.87181091], [81.0348587, 15.87153053], [81.03457642, 15.87153053], [81.03457642, 15.87125015], [81.03430176, 15.87125015], [81.03430176, 15.87097168], [81.03375244, 15.87097168], [81.03375244, 15.87069416], [81.0331955, 15.87069416], [81.0331955, 15.87041569], [81.03291321, 15.87042141], [81.03291321, 15.87014008], [81.03263855, 15.87014008], [81.03263855, 15.8698597], [81.03236389, 15.8698597], [81.03235626, 15.86958027], [81.0320816, 15.86958408], [81.0320816, 15.86902809], [81.03180695, 15.86903858], [81.03180695, 15.86874962], [81.03151703, 15.86874962], [81.03151703, 15.86847019], [81.03125, 15.8684721], [81.03125, 15.86819363], [81.03097534, 15.86819363], [81.03097534, 15.86791801], [81.03069305, 15.86791992], [81.03069305, 15.86763954], [81.0304184, 15.86763954], [81.0304184, 15.86708164], [81.03013611, 15.86708355], [81.03013611, 15.86680603], [81.02986145, 15.86680984], [81.02986145, 15.86653042], [81.02958679, 15.86653042], [81.02958679, 15.8659811], [81.02929688, 15.8659811], [81.02929688, 15.86568928], [81.02902985, 15.86569405], [81.02902985, 15.86541557], [81.02874756, 15.86542034], [81.02874756, 15.86513996], [81.0284729, 15.86513996], [81.0284729, 15.86485958], [81.02819824, 15.86486244], [81.02819061, 15.86430645], [81.02791595, 15.86431026], [81.02791595, 15.86403179], [81.0276413, 15.86403179], [81.0276413, 15.86375046], [81.02735901, 15.86375046], [81.02735901, 15.86347198], [81.02708435, 15.86347198], [81.02708435, 15.86319256], [81.0265274, 15.86319256], [81.0265274, 15.8629179], [81.02597046, 15.8629179], [81.02597046, 15.86263657], [81.0256958, 15.86264038], [81.0256958, 15.86236191], [81.02540588, 15.86236191], [81.02540588, 15.86208057], [81.02513885, 15.86208439], [81.02513885, 15.86124897], [81.02485657, 15.86125183], [81.02485657, 15.86069107], [81.02458191, 15.86069584], [81.02458191, 15.86041737], [81.02401733, 15.86042023], [81.02401733, 15.86014175], [81.02375031, 15.86014175], [81.02375031, 15.85984993], [81.02319336, 15.85986137], [81.02319336, 15.8595829], [81.0229187, 15.8595829], [81.0229187, 15.85930538], [81.02263641, 15.85931015], [81.02263641, 15.85903168], [81.02236176, 15.85903168], [81.02236176, 15.8587513], [81.0220871, 15.8587513], [81.0220871, 15.85819054], [81.02180481, 15.8581953], [81.02180481, 15.85791683], [81.02153015, 15.85791969], [81.02153015, 15.85763931], [81.02124786, 15.85763931], [81.02124786, 15.85736084], [81.02097321, 15.85736084], [81.02097321, 15.85708141], [81.02069092, 15.85708332], [81.02069092, 15.85680485], [81.02041626, 15.85680962], [81.02041626, 15.85652924], [81.0201416, 15.85652924], [81.0201416, 15.85625076], [81.01985931, 15.85625076], [81.01985931, 15.85597134], [81.01958466, 15.85597324], [81.01958466, 15.85569477], [81.01930237, 15.85569477], [81.01930237, 15.85486126], [81.01902771, 15.85486126], [81.01902771, 15.85458279], [81.01875305, 15.85458279], [81.01875305, 15.85430527], [81.01847076, 15.85431194], [81.01847076, 15.85375118], [81.01819611, 15.85375118], [81.01819611, 15.8534708], [81.01791382, 15.8534708], [81.01791382, 15.85319519], [81.01763916, 15.85319519], [81.01763916, 15.85236073], [81.01735687, 15.85236073], [81.01735687, 15.85153103], [81.01706696, 15.85153103], [81.01706696, 15.85097027], [81.01680756, 15.85097313], [81.01680756, 15.85069466], [81.01652527, 15.85069466], [81.01652527, 15.85013866], [81.01625061, 15.85014057], [81.01625061, 15.84957981], [81.01597595, 15.84958458], [81.01597595, 15.84902859], [81.01568604, 15.84903145], [81.01568604, 15.84875107], [81.01541901, 15.84875107], [81.01541901, 15.84846973], [81.01513672, 15.8484726], [81.01513672, 15.84763813], [81.01486206, 15.84764099], [81.01486206, 15.84735966], [81.01457977, 15.84736347], [81.01457977, 15.84708214], [81.01430511, 15.84708214], [81.01430511, 15.84680557], [81.01403046, 15.84681129], [81.01403046, 15.84624958], [81.01374817, 15.84624958], [81.01374817, 15.84597015], [81.01347351, 15.84597206], [81.01347351, 15.84569359], [81.01319122, 15.84569359], [81.01319122, 15.8451376], [81.01291656, 15.84514046], [81.01291656, 15.84485054], [81.01264191, 15.84486008], [81.01264191, 15.84402847], [81.01235962, 15.84403038], [81.01235962, 15.84263992], [81.01207733, 15.84263992], [81.01207733, 15.84208202], [81.01180267, 15.84208393], [81.01180267, 15.84152794], [81.01152802, 15.84152985], [81.01152802, 15.84125042], [81.01125336, 15.84125042], [81.01125336, 15.84097195], [81.01097107, 15.84097195], [81.01097107, 15.84041595], [81.01069641, 15.84041977], [81.01069641, 15.83986187], [81.01040649, 15.83986187], [81.01040649, 15.83930969], [81.01013947, 15.83930969], [81.01013947, 15.83903027], [81.00985718, 15.83903027], [81.00985718, 15.83819103], [81.00958252, 15.8381958], [81.00958252, 15.83791637], [81.00930786, 15.83792019], [81.00930786, 15.83735943], [81.00902557, 15.83736229], [81.00902557, 15.83708382], [81.00846863, 15.83708382], [81.00846863, 15.83736229], [81.00819397, 15.83736229], [81.00819397, 15.83847237], [81.00846863, 15.83846855], [81.00846863, 15.83903027], [81.00818634, 15.83903027], [81.00818634, 15.83930969], [81.00791931, 15.83930588], [81.00791931, 15.83958435], [81.00763702, 15.83958435], [81.00763702, 15.83930588], [81.00736237, 15.83930969], [81.00736237, 15.83903027], [81.00708008, 15.83903027], [81.00708008, 15.83875179], [81.00681305, 15.83875179], [81.00681305, 15.83763981], [81.00708008, 15.83763981], [81.00708008, 15.83541965], [81.00736237, 15.83541965], [81.00736237, 15.83458138], [81.00763702, 15.83458328], [81.00763702, 15.83374882], [81.00736237, 15.83375168], [81.00736237, 15.83236122], [81.00708008, 15.83236122], [81.00708008, 15.83208275], [81.00736237, 15.83208275], [81.00736237, 15.83180523], [81.00681305, 15.8318119], [81.00681305, 15.83153152], [81.00653076, 15.83152676], [81.00653076, 15.8334713], [81.00624847, 15.8334713], [81.00624847, 15.83403015], [81.00597382, 15.83402729], [81.00597382, 15.83569336], [81.00569153, 15.83568192], [81.00569153, 15.83625031], [81.00541687, 15.83625031], [81.00541687, 15.83736229], [81.00512695, 15.83735943], [81.00512695, 15.83903027], [81.00541687, 15.83903027], [81.00541687, 15.83930969], [81.00569153, 15.83930969], [81.00569153, 15.84041977], [81.00541687, 15.84041595], [81.00541687, 15.84069443], [81.00458527, 15.84069443], [81.00458527, 15.84041595], [81.00430298, 15.84041977], [81.00430298, 15.83903027], [81.0045929, 15.83903027], [81.0045929, 15.83875179], [81.00430298, 15.83875179], [81.00430298, 15.83792019], [81.00402832, 15.83792019], [81.00402832, 15.83763981], [81.00374603, 15.83763981], [81.00374603, 15.83681011], [81.00402832, 15.83681011], [81.00402832, 15.83597088], [81.00430298, 15.83597088], [81.00430298, 15.83430481], [81.00235748, 15.83430958], [81.00235748, 15.8334713], [81.00263977, 15.8334713], [81.00263977, 15.83152676], [81.00235748, 15.83153152], [81.00235748, 15.83124924], [81.00180817, 15.83124924], [81.00180817, 15.83153152], [81.00152588, 15.83152676], [81.00152588, 15.83208275], [81.00125122, 15.83208275], [81.00125122, 15.83236122], [81.00013733, 15.83236122], [81.00013733, 15.83208275], [80.99986267, 15.83208275], [80.99986267, 15.83180523], [80.99958038, 15.8318119], [80.99958038, 15.83124924], [80.99930573, 15.83124924], [80.99930573, 15.83069515], [80.99903107, 15.83069515], [80.99903107, 15.83041668], [80.99874878, 15.83041859], [80.99874878, 15.83014107], [80.99846649, 15.83014107], [80.99846649, 15.82987022], [80.99819183, 15.82987022], [80.99819183, 15.82958126], [80.99791718, 15.82958317], [80.99791718, 15.82736111], [80.99764252, 15.82736111], [80.99764252, 15.82680511], [80.99736023, 15.82681179], [80.99736023, 15.82625103], [80.9970932, 15.82625103], [80.9970932, 15.82458019], [80.99680328, 15.82458305], [80.99680328, 15.82402897], [80.99652863, 15.82403088], [80.99652863, 15.82347012], [80.99624634, 15.82347298], [80.99624634, 15.82291698], [80.99597168, 15.8229208], [80.99597168, 15.8215313], [80.99569702, 15.8215313], [80.99569702, 15.82096958], [80.99541473, 15.82097244], [80.99541473, 15.82069397], [80.99485779, 15.82069397], [80.99485779, 15.82097244], [80.99430847, 15.82096958], [80.99430847, 15.82125092], [80.99318695, 15.82125092], [80.99318695, 15.82070065], [80.99291992, 15.82068062], [80.99291992, 15.81847191], [80.99319458, 15.81847191], [80.99319458, 15.81735992], [80.99346924, 15.81735992], [80.99346924, 15.81707954], [80.99375153, 15.81708431], [80.99375153, 15.81680584], [80.99402618, 15.81681061], [80.99402618, 15.81569195], [80.99430847, 15.81569386], [80.99430847, 15.81513786], [80.99458313, 15.81514168], [80.99458313, 15.81375027], [80.99430847, 15.81375027], [80.99430847, 15.81347179], [80.99402618, 15.81347179], [80.99402618, 15.81291962], [80.99375153, 15.81291962], [80.99375153, 15.81013966], [80.99402618, 15.81013966], [80.99402618, 15.80985928], [80.99430847, 15.80986214], [80.99430847, 15.80958366], [80.99458313, 15.80958366], [80.99458313, 15.80930614], [80.99485779, 15.80930996], [80.99485779, 15.80792046], [80.99458313, 15.80792046], [80.99458313, 15.80681038], [80.99485779, 15.80681038], [80.99485779, 15.80347061], [80.99514008, 15.80347347], [80.99514008, 15.80263901], [80.9954071, 15.80264091], [80.9954071, 15.80208111], [80.99569702, 15.80208302], [80.99569702, 15.80152702], [80.99597168, 15.80153084], [80.99597168, 15.80097103], [80.99624634, 15.80097294], [80.99624634, 15.80013943], [80.99652863, 15.80014133], [80.99652863, 15.79986095], [80.99680328, 15.79986095], [80.99680328, 15.79957104], [80.99708557, 15.79958344], [80.99708557, 15.79902744], [80.99736023, 15.79903126], [80.99736023, 15.79875088], [80.99764252, 15.79875088], [80.99764252, 15.79819012], [80.99791718, 15.79819489], [80.99791718, 15.79763889], [80.99819183, 15.7976408], [80.99819183, 15.79708004], [80.99847412, 15.7970829], [80.99847412, 15.79652882], [80.99874878, 15.79653072], [80.99874878, 15.7962513], [80.99903107, 15.7962513], [80.99903107, 15.79568958], [80.99930573, 15.7956953], [80.99930573, 15.79513836], [80.99958038, 15.79514122], [80.99958038, 15.79431057], [80.99986267, 15.79431057], [80.99986267, 15.79403114], [81.00013733, 15.79403114], [81.00013733, 15.7937603], [81.00041962, 15.7937603], [81.00041962, 15.79264069], [81.00068665, 15.79264069], [81.00068665, 15.79153061], [81.00096893, 15.79153061], [81.00096893, 15.79070091], [81.00125122, 15.79070091], [81.00125122, 15.78874969], [81.00152588, 15.78874969], [81.00152588, 15.78792], [81.00180817, 15.78792], [81.00180817, 15.78736019], [81.00208282, 15.7873621], [81.00208282, 15.78708363], [81.00235748, 15.78708363], [81.00235748, 15.78680611], [81.00263977, 15.78681087], [81.00263977, 15.78625202], [81.0029068, 15.78625202], [81.0029068, 15.78568935], [81.00319672, 15.78569412], [81.00319672, 15.78514004], [81.00347137, 15.78514004], [81.00347137, 15.78485966], [81.00375366, 15.78485966], [81.00374603, 15.78456974], [81.00402832, 15.78458405], [81.00402832, 15.78430557], [81.00430298, 15.78431034], [81.00430298, 15.78402996], [81.0045929, 15.78402996], [81.0045929, 15.78374958], [81.00485992, 15.78374958], [81.00485992, 15.7834692], [81.00514221, 15.78347206], [81.00514221, 15.78319359], [81.00541687, 15.78319359], [81.00541687, 15.78291798], [81.00569153, 15.78292179], [81.00569153, 15.78264046], [81.00541687, 15.78264046], [81.00541687, 15.78236198], [81.00569153, 15.78236198], [81.00569153, 15.78208065], [81.00597382, 15.78208447], [81.00597382, 15.78097057], [81.00624847, 15.78097057], [81.00624847, 15.7804184], [81.00653076, 15.7804203], [81.00653076, 15.78014183], [81.00681305, 15.78014183], [81.00681305, 15.77986145], [81.00763702, 15.77986145], [81.00763702, 15.78014183], [81.00791931, 15.78013897], [81.00791931, 15.78208447], [81.00763702, 15.78208065], [81.00763702, 15.78264046], [81.00736237, 15.78264046], [81.00736237, 15.78292179], [81.00708008, 15.78291798], [81.00708008, 15.78347206], [81.00681305, 15.7834692], [81.00681305, 15.78402996], [81.00653076, 15.78402805], [81.00653076, 15.78458405], [81.00791931, 15.78458405], [81.00791931, 15.78430557], [81.00818634, 15.78431034], [81.00818634, 15.7834692], [81.00846863, 15.78347206], [81.00846863, 15.78263664], [81.00875092, 15.78264046], [81.00875092, 15.78208065], [81.00902557, 15.78208447], [81.00902557, 15.78124905], [81.00930786, 15.78125191], [81.00930786, 15.7804203], [81.00958252, 15.7804203], [81.00958252, 15.78014183], [81.01040649, 15.78014183], [81.01040649, 15.77958107], [81.01069641, 15.77958298], [81.01069641, 15.77875137], [81.01097107, 15.77876091], [81.01097107, 15.77791977], [81.01126099, 15.77791977], [81.01126099, 15.77652931], [81.01152802, 15.77652931], [81.01152802, 15.77625084], [81.01207733, 15.77625084], [81.01207733, 15.77514076], [81.01180267, 15.77514076], [81.01180267, 15.77431202], [81.01152802, 15.77431202], [81.01152802, 15.77375126], [81.01125336, 15.77375126], [81.01125336, 15.77347088], [81.01152802, 15.77347088], [81.01152802, 15.77263927], [81.01180267, 15.77263927], [81.01180267, 15.77208328], [81.01208496, 15.77208328], [81.01208496, 15.7715292], [81.01235962, 15.77153111], [81.01235962, 15.7709713], [81.01208496, 15.77097321], [81.01208496, 15.77013874], [81.01180267, 15.77014065], [81.01180267, 15.76958942], [81.01152802, 15.76958942], [81.01152802, 15.76875114], [81.01125336, 15.76875114], [81.01125336, 15.76847267], [81.01097107, 15.76847267], [81.01097107, 15.76819515], [81.01069641, 15.76819515], [81.01069641, 15.76791573], [81.00930786, 15.76792145], [81.00930786, 15.76764107], [81.00846863, 15.76764107], [81.00846863, 15.76735973], [81.00763702, 15.76735973], [81.00763702, 15.76708031], [81.00597382, 15.76708221], [81.00597382, 15.7668066], [81.00569153, 15.76681995], [81.00569153, 15.76653099], [81.00596619, 15.76653099], [81.00596619, 15.76624966], [81.00569153, 15.76624966], [81.00569153, 15.76124954], [81.00541687, 15.76124954], [81.00541687, 15.76041985], [81.00569153, 15.76041985], [81.00569153, 15.75958157], [81.00597382, 15.75958443], [81.00597382, 15.75847244], [81.00624847, 15.75847244], [81.00624847, 15.75791645], [81.00596619, 15.75792027], [81.00596619, 15.75765133], [81.00569153, 15.75765133], [81.00569153, 15.75736046], [81.00541687, 15.75736237], [81.00541687, 15.75708389], [81.00514221, 15.75708389], [81.00514221, 15.75680637], [81.00485992, 15.75681019], [81.00485992, 15.75652981], [81.0045929, 15.75652981], [81.0045929, 15.75625038], [81.00430298, 15.75625038], [81.00430298, 15.75597191], [81.00402832, 15.75597191], [81.00402832, 15.75569344], [81.00375366, 15.75569344], [81.00375366, 15.7551403], [81.00319672, 15.7551403], [81.00319672, 15.75486183], [81.00235748, 15.75486183], [81.00235748, 15.75459003], [81.00206757, 15.75459003], [81.00206757, 15.75319099], [81.00180817, 15.75319576], [81.00180817, 15.75291538], [81.00152588, 15.75292015], [81.00152588, 15.75264168], [81.00125122, 15.75264168], [81.00125122, 15.7523613], [81.00096893, 15.7523613], [81.00096893, 15.75180531], [80.99986267, 15.75181198], [80.99986267, 15.75152016], [80.99958038, 15.75152683], [80.99958038, 15.75124931], [80.99930573, 15.75124931], [80.99930573, 15.75097084], [80.99903107, 15.75097084], [80.99903107, 15.75069141], [80.99874878, 15.75069523], [80.99874878, 15.75041676], [80.99846649, 15.75041962], [80.99846649, 15.75013924], [80.99791718, 15.75013924], [80.99791718, 15.74986076], [80.99764252, 15.74986076], [80.99764252, 15.74958134], [80.99708557, 15.74958324], [80.99708557, 15.74930477], [80.99652863, 15.74930954], [80.99652863, 15.74903202], [80.99624634, 15.74903202], [80.99624634, 15.74875069], [80.99569702, 15.74875069], [80.99569702, 15.74845886], [80.99514008, 15.74847317], [80.99514008, 15.74819469], [80.99485779, 15.74819469], [80.99485779, 15.74791718], [80.99430847, 15.74792194], [80.99430847, 15.74764061], [80.99402618, 15.74764061], [80.99402618, 15.74736118], [80.99346924, 15.74736118], [80.99346924, 15.74708271], [80.99291992, 15.74708271], [80.99291992, 15.74680519], [80.99263763, 15.74681187], [80.99263763, 15.74653053], [80.99208069, 15.74653053], [80.99208069, 15.74625111], [80.99180603, 15.74625111], [80.99180603, 15.74597073], [80.99124908, 15.74597263], [80.99124908, 15.74569511], [80.99069214, 15.74569511], [80.99069214, 15.74541664], [80.99041748, 15.74542141], [80.99041748, 15.74514103], [80.98986053, 15.74514103], [80.98986053, 15.74486065], [80.98930359, 15.74486065], [80.98929596, 15.74458027], [80.98902893, 15.74458313], [80.98902893, 15.74430466], [80.98847198, 15.74431133], [80.98847198, 15.74403095], [80.98819733, 15.74403095], [80.98819733, 15.74375057], [80.98764038, 15.74375057], [80.98764038, 15.74347019], [80.98735809, 15.74347305], [80.98735809, 15.74319458], [80.98680878, 15.74319458], [80.98680878, 15.74291706], [80.98652649, 15.74292088], [80.98652649, 15.74265003], [80.98596954, 15.74265003], [80.98596954, 15.74236107], [80.98568726, 15.74236107], [80.98568726, 15.74207973], [80.98513794, 15.74208164], [80.98513794, 15.74180698], [80.98486328, 15.7418108], [80.98486328, 15.74153137], [80.98430634, 15.74153137], [80.98430634, 15.74125099], [80.98403168, 15.74125099], [80.98403168, 15.74096966], [80.98347473, 15.74097347], [80.98347473, 15.74069405], [80.98319244, 15.74069405], [80.98319244, 15.74041557], [80.98264313, 15.7404213], [80.98264313, 15.74014091], [80.98208618, 15.74014091], [80.98208618, 15.73985958], [80.98152924, 15.7398634], [80.98152924, 15.73958206], [80.98097229, 15.73958206], [80.98097229, 15.73930645], [80.98042297, 15.73931122], [80.98042297, 15.73903084], [80.9798584, 15.73903084], [80.9798584, 15.73875046], [80.97957611, 15.73875046], [80.97957611, 15.73847008], [80.97902679, 15.73847198], [80.97902679, 15.73819447], [80.97846985, 15.73819447], [80.97846985, 15.73791599], [80.97789764, 15.73792076], [80.97789764, 15.73764038], [80.97735596, 15.73764038], [80.97735596, 15.73736], [80.97680664, 15.73736], [80.97680664, 15.73707962], [80.97624969, 15.73708439], [80.97624969, 15.73680592], [80.97569275, 15.73681068], [80.97569275, 15.73651886], [80.9751358, 15.7365284], [80.9751358, 15.73624992], [80.97458649, 15.73624992], [80.97458649, 15.73596954], [80.97402954, 15.7359724], [80.97402954, 15.73569393], [80.9734726, 15.73569393], [80.9734726, 15.73541641], [80.97292328, 15.73542118], [80.97292328, 15.73513985], [80.9723587, 15.73513985], [80.9723587, 15.73486042], [80.9715271, 15.73486233], [80.9715271, 15.73458195], [80.97125244, 15.73458195], [80.97125244, 15.73430634], [80.97070313, 15.7343111], [80.97070313, 15.73403263], [80.97013855, 15.73403263], [80.97013855, 15.73375034], [80.96985626, 15.73375034], [80.96985626, 15.73346138], [80.96930695, 15.73347187], [80.96930695, 15.73319435], [80.96875, 15.73319435], [80.96875, 15.73291588], [80.96819305, 15.73291969], [80.96819305, 15.73264027], [80.96763611, 15.73264027], [80.96763611, 15.73236179], [80.96708679, 15.73236179], [80.96708679, 15.73207855], [80.9668045, 15.73208427], [80.9668045, 15.7318058], [80.96624756, 15.73180962], [80.96624756, 15.73153019], [80.96569824, 15.73153019], [80.96569061, 15.73124981], [80.9651413, 15.73124981], [80.9651413, 15.73096943], [80.96458435, 15.73097229], [80.96458435, 15.73069572], [80.9640274, 15.73069572], [80.9640274, 15.7304163], [80.96347046, 15.73042011], [80.96347046, 15.73013973], [80.96292114, 15.73013973], [80.96292114, 15.72985935], [80.96208191, 15.72986221], [80.96208191, 15.72958374], [80.96152496, 15.72958374], [80.96152496, 15.72930622], [80.96098328, 15.72931004], [80.96098328, 15.72902966], [80.9604187, 15.72902966], [80.9604187, 15.72875023], [80.95986176, 15.72875023], [80.95986176, 15.7284708], [80.95874786, 15.7284708], [80.95874786, 15.72819138], [80.95735931, 15.72819328], [80.95735931, 15.72791767], [80.95678711, 15.72791958], [80.95678711, 15.72764015], [80.95652771, 15.72764015], [80.95652771, 15.72736168], [80.95569611, 15.72736168], [80.95569611, 15.72764015], [80.95401764, 15.72764015], [80.95401764, 15.72736168], [80.95375061, 15.72736168], [80.95375061, 15.7270813], [80.95319366, 15.72708321], [80.95319366, 15.72680473], [80.95263672, 15.72681046], [80.95263672, 15.72653198], [80.95207977, 15.72653198], [80.95207977, 15.7262516], [80.95153046, 15.7262516], [80.95153046, 15.72597122], [80.95097351, 15.72597122], [80.95097351, 15.72569466], [80.95056915, 15.72569466], [80.95041656, 15.72569466], [80.95041656, 15.72541714], [80.94985962, 15.72542191], [80.94985962, 15.72514153], [80.94930267, 15.72514153], [80.94930267, 15.72458076], [80.94902802, 15.72458267], [80.94902802, 15.72430515], [80.94875336, 15.72430992], [80.94875336, 15.72420025], [80.94875336, 15.72374916], [80.94847107, 15.72375107], [80.94847107, 15.72347069], [80.94819641, 15.7234726], [80.94819641, 15.72319317], [80.94791412, 15.72319317], [80.94791412, 15.7229166], [80.94763947, 15.72291946], [80.94763947, 15.72264099], [80.94708252, 15.72264099], [80.94708252, 15.72236061], [80.94652557, 15.72236061], [80.94652557, 15.72208309], [80.94625092, 15.72208309], [80.94625092, 15.72180462], [80.94596863, 15.72181034], [80.94596863, 15.72152042], [80.94569397, 15.7215271], [80.94569397, 15.72124863], [80.94484711, 15.72125053], [80.94484711, 15.72097111], [80.94430542, 15.72097301], [80.94430542, 15.72069454], [80.94403076, 15.72069454], [80.94403076, 15.72041702], [80.94374847, 15.72042179], [80.94374847, 15.72014141], [80.94319153, 15.72014141], [80.94319153, 15.71986103], [80.94291687, 15.71986103], [80.94291687, 15.71958065], [80.94208527, 15.71958256], [80.94208527, 15.71930695], [80.94152832, 15.71931171], [80.94152832, 15.71903133], [80.94069672, 15.71903133], [80.94069672, 15.71875095], [80.93985748, 15.71875095], [80.93985748, 15.71848202], [80.93904114, 15.71848202], [80.93904114, 15.71819019], [80.93791962, 15.71819019], [80.93791962, 15.71848202], [80.93736267, 15.71848202], [80.93736267, 15.71875095], [80.93681335, 15.71875095], [80.93681335, 15.71903133], [80.93569183, 15.71903133], [80.93569183, 15.71931171], [80.93514252, 15.71930695], [80.93514252, 15.71958256], [80.93486023, 15.71958065], [80.93486023, 15.71986103], [80.9345932, 15.71986103], [80.9345932, 15.72014141], [80.93430328, 15.72014141], [80.93430328, 15.72042179], [80.93402863, 15.72041702], [80.93402863, 15.72069454], [80.93374634, 15.72069454], [80.93374634, 15.72097301], [80.93347168, 15.72097111], [80.93347168, 15.72181034], [80.93319702, 15.72181034], [80.93319702, 15.72264099], [80.9329071, 15.72264099], [80.9329071, 15.72375107], [80.93264008, 15.72375107], [80.93264008, 15.72402859], [80.93180847, 15.72402859], [80.93180847, 15.72375107], [80.93041992, 15.72375107], [80.93041992, 15.72347069], [80.92930603, 15.7234726], [80.92930603, 15.72319317], [80.92791748, 15.72319317], [80.92791748, 15.7229166], [80.92652893, 15.72291946], [80.92652893, 15.72264099], [80.92542267, 15.72264099], [80.92542267, 15.72236061], [80.92514038, 15.72236061], [80.92514038, 15.72208309], [80.92430878, 15.72208309], [80.92430878, 15.72180462], [80.92263794, 15.72181034], [80.92263794, 15.72152042], [80.92041779, 15.7215271], [80.92041779, 15.72124863], [80.91929626, 15.72125053], [80.91929626, 15.72097111], [80.91847229, 15.72097301], [80.91847229, 15.72069454], [80.91764069, 15.72069454], [80.91764069, 15.72041702], [80.91680908, 15.72042179], [80.91680908, 15.72014141], [80.91513824, 15.72014141], [80.91513824, 15.71986103], [80.91348267, 15.71986103], [80.91348267, 15.72014141], [80.91236115, 15.72014141], [80.91236115, 15.71986103], [80.91124725, 15.71986103], [80.91124725, 15.71958065], [80.9109726, 15.71958256], [80.9109726, 15.71930695], [80.9090271, 15.71931171], [80.9090271, 15.71903133], [80.90791321, 15.71903133], [80.90791321, 15.71875095], [80.90680695, 15.71875095], [80.90680695, 15.71848202], [80.90625763, 15.71848202], [80.9056778, 15.71848202], [80.9056778, 15.71819019], [80.90097046, 15.71819496], [80.90097046, 15.71791744], [80.9006958, 15.71792126], [80.9006958, 15.71764088], [80.90013885, 15.71764088], [80.90013885, 15.71736145], [80.8998642, 15.71736145], [80.8998642, 15.71708298], [80.89902496, 15.71708298], [80.89902496, 15.71680546], [80.89624786, 15.71680927], [80.89624786, 15.71652889], [80.89541626, 15.71652889], [80.89541626, 15.71625137], [80.89290619, 15.71625137], [80.89290619, 15.71597004], [80.8923645, 15.7159729], [80.8923645, 15.71569538], [80.88986206, 15.71569538], [80.88986206, 15.71541691], [80.88957977, 15.71542072], [80.88957977, 15.7151413], [80.88874817, 15.7151413], [80.88874817, 15.71485996], [80.88735962, 15.71485996], [80.88735962, 15.71457958], [80.88402557, 15.71458244], [80.88402557, 15.71430683], [80.88208008, 15.71431065], [80.88208008, 15.71403122], [80.88153076, 15.71403122], [80.88153076, 15.71375275], [80.88096619, 15.71375275], [80.88096619, 15.71347046], [80.87902832, 15.71347237], [80.87902832, 15.71319389], [80.87596893, 15.71319389], [80.87596893, 15.71291637], [80.87374878, 15.71292114], [80.87374878, 15.71264076], [80.87124634, 15.71264076], [80.87124634, 15.71235085], [80.86902618, 15.71236038], [80.86902618, 15.71208382], [80.86653137, 15.71208191], [80.86653137, 15.7118063], [80.86207581, 15.71181107], [80.86207581, 15.71153069], [80.86152649, 15.71153069], [80.86152649, 15.71125031], [80.85930634, 15.71125031], [80.85930634, 15.71096992], [80.8576355, 15.71097183], [80.8576355, 15.71069431], [80.85569763, 15.71069431], [80.85569763, 15.71041584], [80.85263824, 15.71042061], [80.85263824, 15.71014023], [80.85041809, 15.71014023], [80.85041809, 15.71042061], [80.8501358, 15.71041584], [80.8501358, 15.71069431], [80.84986115, 15.71069431], [80.84986115, 15.71097183], [80.84929657, 15.71096992], [80.84929657, 15.71125031], [80.8484726, 15.71125031], [80.8484726, 15.71096992], [80.84819794, 15.71097183], [80.84819794, 15.71014023], [80.84792328, 15.71014023], [80.84792328, 15.70985985], [80.84764099, 15.70985985], [80.84764099, 15.70958424], [80.84124756, 15.70958424], [80.84124756, 15.70930576], [80.83930206, 15.70931053], [80.83930206, 15.70903015], [80.83790588, 15.70903015], [80.83790588, 15.70931053], [80.83680725, 15.70930576], [80.83680725, 15.70958424], [80.83652496, 15.70958424], [80.83652496, 15.70985985], [80.83598328, 15.70985985], [80.83598328, 15.71014023], [80.8345871, 15.71014023], [80.8345871, 15.71042061], [80.83319092, 15.71041584], [80.83319092, 15.71069431], [80.83180237, 15.71069431], [80.83180237, 15.71097183], [80.83068848, 15.71096992], [80.83068848, 15.71125031], [80.82930756, 15.71125031], [80.82930756, 15.71153069], [80.82791901, 15.71153069], [80.82791901, 15.71181107], [80.82514191, 15.7118063], [80.82514191, 15.71208191], [80.82402802, 15.71208382], [80.82402802, 15.71236038], [80.82319641, 15.71235085], [80.82319641, 15.71264076], [80.82263947, 15.71264076], [80.82263947, 15.71292114], [80.82208252, 15.71291637], [80.82208252, 15.71319389], [80.82180786, 15.71319389], [80.82180786, 15.71347237], [80.82151794, 15.71347046], [80.82151794, 15.71403122], [80.82096863, 15.71402645], [80.82096863, 15.71458244], [80.82068634, 15.71457958], [80.82068634, 15.71485996], [80.82041931, 15.71485996], [80.82041931, 15.7151413], [80.82013702, 15.71513939], [80.82013702, 15.71569538], [80.81986237, 15.71569538], [80.81986237, 15.7159729], [80.81958008, 15.71597004], [80.81958008, 15.71652889], [80.81931305, 15.71652889], [80.81931305, 15.71680927], [80.81903076, 15.71680546], [80.81903076, 15.71708298], [80.81874847, 15.71708012], [80.81874847, 15.71764088], [80.81845856, 15.71764088], [80.81845856, 15.71792126], [80.81819153, 15.71791744], [80.81819153, 15.71819496], [80.81764221, 15.71819019], [80.81764221, 15.71848202], [80.81735992, 15.71848202], [80.81735992, 15.71875095], [80.8170929, 15.71875095], [80.8170929, 15.71903133], [80.81652832, 15.71903133], [80.81652832, 15.71931171], [80.81625366, 15.71930695], [80.81625366, 15.71958256], [80.81597137, 15.71958065], [80.81597137, 15.72014141], [80.81569672, 15.72013855], [80.81569672, 15.72069454], [80.81539917, 15.72069073], [80.81539917, 15.72181034], [80.81513977, 15.72181034], [80.81513977, 15.72291946], [80.81485748, 15.72291946], [80.81485748, 15.72375107], [80.81458282, 15.72375107], [80.81458282, 15.72430992], [80.81430817, 15.72430515], [80.81430817, 15.72486115], [80.81402588, 15.72486115], [80.81402588, 15.72542191], [80.81375122, 15.72541714], [80.81375122, 15.72569466], [80.81346893, 15.72569084], [80.81346893, 15.7262516], [80.81318665, 15.7262516], [80.81318665, 15.72681046], [80.81291962, 15.72681046], [80.81291962, 15.72736168], [80.81265259, 15.72736168], [80.81265259, 15.72791958], [80.81236267, 15.72791767], [80.81236267, 15.72819328], [80.81208038, 15.72819138], [80.81208038, 15.7284708], [80.81180573, 15.72847366], [80.81181335, 15.72875023], [80.81153107, 15.72875023], [80.81153107, 15.72902966], [80.81124878, 15.72902775], [80.81124878, 15.72958374], [80.81097412, 15.72958374], [80.81097412, 15.72986221], [80.81069183, 15.72985935], [80.81069183, 15.73013973], [80.81041718, 15.73013973], [80.81041718, 15.73069572], [80.81014252, 15.73069572], [80.81014252, 15.73097229], [80.80986023, 15.73096943], [80.80986023, 15.73124981], [80.80957794, 15.73124981], [80.80957794, 15.73153019], [80.80930328, 15.73153019], [80.80930328, 15.73180962], [80.80902863, 15.7318058], [80.80902863, 15.73208427], [80.80874634, 15.73207855], [80.80874634, 15.73236179], [80.80847168, 15.73236179], [80.80847168, 15.73291969], [80.80819702, 15.73291588], [80.80819702, 15.73319435], [80.80791473, 15.73319435], [80.80791473, 15.73347187], [80.80764008, 15.73346138], [80.80764008, 15.73375034], [80.80708313, 15.73375034], [80.80708313, 15.73403263], [80.80680847, 15.73403263], [80.80680847, 15.7343111], [80.80652618, 15.73430634], [80.80652618, 15.73458195], [80.80596924, 15.73458195], [80.80596924, 15.73486233], [80.80568695, 15.73486042], [80.80568695, 15.73513985], [80.80541992, 15.73513985], [80.80541992, 15.73542118], [80.80486298, 15.73541641], [80.80486298, 15.73569393], [80.80458069, 15.73569393], [80.80458069, 15.7359724], [80.80430603, 15.73596954], [80.80430603, 15.73624992], [80.80403137, 15.73624992], [80.80403137, 15.7365284], [80.80374908, 15.73651886], [80.80374908, 15.73681068], [80.80347443, 15.73680592], [80.80347443, 15.73708439], [80.80319214, 15.73707962], [80.80319214, 15.73736], [80.80291748, 15.73736], [80.80291748, 15.73764038], [80.80236053, 15.73764038], [80.80236053, 15.73792076], [80.80208588, 15.73791599], [80.80208588, 15.73819447], [80.80180359, 15.73819447], [80.80180359, 15.73847198], [80.80152893, 15.73847008], [80.80152893, 15.73875046], [80.80124664, 15.73875046], [80.80124664, 15.73903084], [80.80097198, 15.73903084], [80.80097198, 15.73931122], [80.80041504, 15.73930645], [80.80041504, 15.7398634], [80.80023956, 15.7398634], [80.80014038, 15.7398634], [80.80014038, 15.74014091], [80.79985809, 15.74014091], [80.79985809, 15.7404213], [80.79958344, 15.74041557], [80.79958344, 15.74097347], [80.79930878, 15.74096966], [80.79930878, 15.74125099], [80.79902649, 15.74125099], [80.79902649, 15.7418108], [80.79875183, 15.74180698], [80.79875183, 15.74208164], [80.79846954, 15.74207973], [80.79846954, 15.74292088], [80.79819489, 15.74291706], [80.79819489, 15.74319458], [80.79792023, 15.74319458], [80.79792023, 15.74347305], [80.79763794, 15.74347019], [80.79763794, 15.74403095], [80.79736328, 15.74403095], [80.79736328, 15.74431133], [80.79708099, 15.74431133], [80.79708099, 15.74542141], [80.79680634, 15.74541664], [80.79680634, 15.74569511], [80.79652405, 15.74569511], [80.79652405, 15.74597263], [80.79624939, 15.74597263], [80.79624939, 15.74736118], [80.7959671, 15.74736118], [80.7959671, 15.74903202], [80.79569244, 15.74903202], [80.79569244, 15.75013924], [80.79541779, 15.75013924], [80.79541779, 15.75097084], [80.79514313, 15.75097084], [80.79514313, 15.75181198], [80.79486084, 15.75180531], [80.79486084, 15.7523613], [80.79458618, 15.7523613], [80.79458618, 15.75319576], [80.79428864, 15.75319099], [80.79428864, 15.75403023], [80.79402924, 15.75403023], [80.79402924, 15.75486183], [80.79374695, 15.75486183], [80.79374695, 15.7551403], [80.79347229, 15.7551403], [80.79347229, 15.75569344], [80.79319763, 15.75569057], [80.79319763, 15.75625038], [80.79291534, 15.75625038], [80.79291534, 15.75736237], [80.79264069, 15.75736046], [80.79264069, 15.75765133], [80.7923584, 15.75765133], [80.7923584, 15.75792027], [80.79208374, 15.75791645], [80.79208374, 15.75847244], [80.79180908, 15.75846863], [80.79180908, 15.75903034], [80.79151917, 15.75903034], [80.79151917, 15.75930977], [80.79125214, 15.75930595], [80.79125214, 15.75958443], [80.79096985, 15.75958157], [80.79096985, 15.76041985], [80.79069519, 15.76041794], [80.79069519, 15.76097202], [80.7904129, 15.76097202], [80.7904129, 15.76124954], [80.79013824, 15.76124954], [80.79013824, 15.76181126], [80.78986359, 15.76180553], [80.78986359, 15.76208401], [80.7895813, 15.76208019], [80.7895813, 15.76264], [80.78930664, 15.76264], [80.78930664, 15.76292133], [80.78902435, 15.76291561], [80.78902435, 15.76319408], [80.78874969, 15.76319027], [80.78874969, 15.76375008], [80.78848267, 15.76375008], [80.78848267, 15.76431084], [80.78819275, 15.76430416], [80.78819275, 15.76486015], [80.78791809, 15.76486015], [80.78791809, 15.76513958], [80.7876358, 15.76513958], [80.7876358, 15.76542091], [80.78736115, 15.76541615], [80.78736115, 15.76569366], [80.78708649, 15.76568985], [80.78708649, 15.76653099], [80.78679657, 15.76653099], [80.78679657, 15.76681995], [80.78652954, 15.76681995], [80.78652954, 15.76735973], [80.78624725, 15.76735973], [80.78624725, 15.76764107], [80.7859726, 15.76763821], [80.7859726, 15.76847267], [80.78569794, 15.76846981], [80.78569794, 15.76931095], [80.78542328, 15.76931095], [80.78542328, 15.77014065], [80.78514099, 15.77014065], [80.78514099, 15.77153111], [80.7848587, 15.77153111], [80.7848587, 15.77181244], [80.78458405, 15.77180481], [80.78458405, 15.7723608], [80.78430939, 15.7723608], [80.78430176, 15.77263927], [80.7840271, 15.77262974], [80.7840271, 15.77375126], [80.78375244, 15.77375126], [80.78375244, 15.77403069], [80.78347015, 15.77403069], [80.78347015, 15.77431202], [80.7831955, 15.77430534], [80.7831955, 15.77458286], [80.78291321, 15.77458096], [80.78291321, 15.77514076], [80.78263855, 15.77514076], [80.78263855, 15.77652931], [80.78236389, 15.7765274], [80.78236389, 15.7770834], [80.7820816, 15.77708054], [80.7820816, 15.77763939], [80.78180695, 15.77763939], [80.78180695, 15.77791977], [80.78152466, 15.77791691], [80.78152466, 15.77819538], [80.78125, 15.77819538], [80.78125, 15.77847099], [80.78098297, 15.77847099], [80.78098297, 15.7804203], [80.78069305, 15.7804203], [80.78069305, 15.78264046], [80.7804184, 15.78264046], [80.7804184, 15.78542042], [80.78069305, 15.78542042], [80.78069305, 15.78931141], [80.78097534, 15.78930569], [80.78097534, 15.78958416], [80.78125, 15.78958035], [80.78125, 15.79070091], [80.78151703, 15.79070091], [80.78151703, 15.79125023], [80.78180695, 15.79125023], [80.78180695, 15.79181099], [80.7820816, 15.79180622], [80.7820816, 15.79208374], [80.78263855, 15.79208374], [80.78263855, 15.79180622], [80.78291321, 15.79181099], [80.78291321, 15.79153061], [80.78320313, 15.79153061], [80.78320313, 15.79042053], [80.78291321, 15.79042053], [80.78291321, 15.79014015], [80.78263855, 15.79014015], [80.78263855, 15.78986168], [80.78234863, 15.78986168], [80.78234863, 15.78931141], [80.78263855, 15.78931141], [80.78263855, 15.78874969], [80.78347015, 15.78874969], [80.78347015, 15.78847027], [80.78375244, 15.78847218], [80.78375244, 15.78791809], [80.7840271, 15.78792], [80.7840271, 15.78736019], [80.78430176, 15.7873621], [80.78430176, 15.78680611], [80.78457642, 15.78681087], [80.78457642, 15.78652954], [80.7848587, 15.78652954], [80.7848587, 15.78625202], [80.78542328, 15.78625202], [80.78542328, 15.78568935], [80.78569794, 15.78569412], [80.78569794, 15.78514004], [80.78679657, 15.78514004], [80.78679657, 15.78542042], [80.78708649, 15.78541565], [80.78708649, 15.78569412], [80.7876358, 15.78569412], [80.7876358, 15.78541565], [80.78819275, 15.78542042], [80.78819275, 15.78431034], [80.78848267, 15.78431034], [80.78848267, 15.78236198], [80.78819275, 15.78236198], [80.78819275, 15.78208065], [80.78791809, 15.78208447], [80.78791809, 15.78180599], [80.7876358, 15.78181934], [80.7876358, 15.78153038], [80.78736115, 15.78153038], [80.78736115, 15.77986145], [80.7876358, 15.77986145], [80.7876358, 15.77958298], [80.78791809, 15.77958298], [80.78791809, 15.77875137], [80.78819275, 15.77876091], [80.78819275, 15.77736092], [80.78848267, 15.77736092], [80.78847504, 15.7765274], [80.78874969, 15.77652931], [80.78874969, 15.77514076], [80.78901672, 15.77514076], [80.78901672, 15.77403069], [80.78874969, 15.77403069], [80.78874969, 15.77262974], [80.78902435, 15.77263927], [80.78902435, 15.7723608], [80.78930664, 15.7723608], [80.78930664, 15.77208328], [80.7895813, 15.77208328], [80.7895813, 15.77180481], [80.78985596, 15.77181244], [80.78985596, 15.77153111], [80.79013824, 15.77153111], [80.79013824, 15.77125072], [80.79347229, 15.77125072], [80.79347229, 15.7709713], [80.79374695, 15.77097321], [80.79374695, 15.76930428], [80.79347229, 15.76931095], [80.79347229, 15.76903057], [80.79292297, 15.76903057], [80.79292297, 15.76846981], [80.79264069, 15.76847267], [80.79264069, 15.76763821], [80.7923584, 15.76764107], [80.7923584, 15.76568985], [80.79208374, 15.76569366], [80.79208374, 15.76291561], [80.79180908, 15.76292133], [80.79180908, 15.76124954], [80.79207611, 15.76124954], [80.79207611, 15.76069164], [80.7923584, 15.76069355], [80.7923584, 15.76013756], [80.79264069, 15.76014042], [80.79264069, 15.75986195], [80.79319763, 15.75986195], [80.79319763, 15.75958157], [80.79374695, 15.75958443], [80.79374695, 15.75930595], [80.79402924, 15.75930977], [80.79402924, 15.75903034], [80.79457855, 15.75903034], [80.79457855, 15.75874996], [80.79486084, 15.75874996], [80.79486084, 15.7581892], [80.7951355, 15.75819397], [80.7951355, 15.75791645], [80.79541779, 15.75792027], [80.79541779, 15.75736046], [80.79569244, 15.75736237], [80.79569244, 15.75708389], [80.79597473, 15.75708389], [80.79597473, 15.75680637], [80.79624939, 15.75681019], [80.79624939, 15.75625038], [80.79651642, 15.75625038], [80.79651642, 15.75597191], [80.79680634, 15.75597191], [80.79680634, 15.7551403], [80.79708099, 15.7551403], [80.79708099, 15.75403023], [80.79736328, 15.75403023], [80.79736328, 15.75319099], [80.79763794, 15.75319576], [80.79763794, 15.75291538], [80.79792023, 15.75292015], [80.79792023, 15.75208092], [80.79819489, 15.75208282], [80.79819489, 15.75152683], [80.79846954, 15.75152683], [80.79846954, 15.75041676], [80.79875183, 15.75041962], [80.79875183, 15.75013924], [80.79930878, 15.75013924], [80.79930878, 15.74986076], [80.80014038, 15.74986076], [80.80014038, 15.74958134], [80.80041504, 15.74958324], [80.80041504, 15.74930477], [80.80071259, 15.74930954], [80.80071259, 15.74845886], [80.80097198, 15.74847317], [80.80097198, 15.74819469], [80.80124664, 15.74819469], [80.80124664, 15.7476387], [80.80152893, 15.74764061], [80.80152893, 15.74681187], [80.80179596, 15.74681187], [80.80179596, 15.74625111], [80.80208588, 15.74625111], [80.80208588, 15.74597073], [80.80236053, 15.74597263], [80.80236053, 15.74486065], [80.80264282, 15.74486065], [80.80263519, 15.74458313], [80.80291748, 15.74458313], [80.80291748, 15.74402905], [80.80319214, 15.74403095], [80.80319214, 15.74375057], [80.80374908, 15.74375057], [80.80374908, 15.74347019], [80.80403137, 15.74347305], [80.80403137, 15.74319458], [80.80430603, 15.74319458], [80.80430603, 15.74291706], [80.80458069, 15.74292088], [80.80458069, 15.74265003], [80.80513763, 15.74265003], [80.80513763, 15.74236107], [80.80541992, 15.74236107], [80.80541992, 15.74207973], [80.80569458, 15.74208164], [80.80569458, 15.74180698], [80.80596924, 15.7418108], [80.80596924, 15.74153137], [80.80651855, 15.74153137], [80.80651855, 15.74125099], [80.80708313, 15.74125099], [80.80708313, 15.74096966], [80.80753326, 15.74097347], [80.80791473, 15.74097347], [80.80791473, 15.74069405], [80.80847168, 15.74069405], [80.80847168, 15.74041557], [80.81041718, 15.7404213], [80.81041718, 15.74014091], [80.81096649, 15.74014091], [80.81096649, 15.73985958], [80.81236267, 15.7398634], [80.81236267, 15.73958206], [80.81346893, 15.73958206], [80.81346893, 15.7398634], [80.81375122, 15.73985958], [80.81375122, 15.74014091], [80.81402588, 15.74014091], [80.81402588, 15.7404213], [80.81430817, 15.74041557], [80.81430817, 15.74097347], [80.81458282, 15.74096966], [80.81458282, 15.74153137], [80.81485748, 15.74153137], [80.81485748, 15.7418108], [80.81513977, 15.7418108], [80.81513977, 15.74265003], [80.81485748, 15.74263859], [80.81485748, 15.74319458], [80.81458282, 15.74319458], [80.81458282, 15.74347305], [80.81430817, 15.74347019], [80.81430817, 15.74375057], [80.81402588, 15.74375057], [80.81402588, 15.74486065], [80.81375122, 15.74486065], [80.81375122, 15.74569511], [80.81346893, 15.74569035], [80.81346893, 15.74681187], [80.81318665, 15.74681187], [80.81318665, 15.74764061], [80.81291962, 15.74764061], [80.81291962, 15.74875069], [80.81265259, 15.74875069], [80.81265259, 15.74986076], [80.81236267, 15.74986076], [80.81236267, 15.75486183], [80.81208038, 15.75486183], [80.81208038, 15.7551403], [80.81181335, 15.7551403], [80.81181335, 15.76041985], [80.81153107, 15.76041794], [80.81153107, 15.76069355], [80.81124878, 15.76069164], [80.81124878, 15.76181126], [80.81096649, 15.76181126], [80.81096649, 15.76375008], [80.81069183, 15.76375008], [80.81069183, 15.76458359], [80.81041718, 15.76457977], [80.81041718, 15.76513958], [80.81014252, 15.76513767], [80.81014252, 15.76569366], [80.80986023, 15.76569366], [80.80986023, 15.76597214], [80.80930328, 15.76597023], [80.80930328, 15.76653099], [80.80902863, 15.76653099], [80.80902863, 15.76681995], [80.80874634, 15.76681995], [80.80874634, 15.76792145], [80.80847168, 15.76791573], [80.80847168, 15.76819515], [80.80819702, 15.76819038], [80.80819702, 15.76931095], [80.80791473, 15.76930428], [80.80791473, 15.76986122], [80.80764008, 15.76986122], [80.80764008, 15.77014065], [80.80735779, 15.77014065], [80.80735779, 15.77042103], [80.80708313, 15.77041721], [80.80708313, 15.77097321], [80.80680847, 15.7709713], [80.80680847, 15.77125072], [80.80651855, 15.77125072], [80.80651855, 15.77153111], [80.80625153, 15.7715292], [80.80625153, 15.77208328], [80.80596924, 15.77208328], [80.80596924, 15.77347088], [80.80568695, 15.77347088], [80.80568695, 15.77375126], [80.80541992, 15.77375126], [80.80541992, 15.77652931], [80.80513763, 15.77652931], [80.80513763, 15.77763939], [80.80486298, 15.77763939], [80.80486298, 15.77791977], [80.80458069, 15.77791977], [80.80458069, 15.77876091], [80.80430603, 15.77876091], [80.80430603, 15.77931023], [80.80403137, 15.77931023], [80.80403137, 15.78014183], [80.80374908, 15.78013897], [80.80374908, 15.78486156], [80.80345917, 15.78485966], [80.80345917, 15.78542042], [80.80319214, 15.78541565], [80.80319214, 15.78597164], [80.8030014, 15.78597164], [80.80291748, 15.78597164], [80.80291748, 15.78625202], [80.80264282, 15.78625202], [80.80264282, 15.78681087], [80.80236053, 15.78680611], [80.80236053, 15.78763771], [80.80208588, 15.78763103], [80.80208588, 15.78874969], [80.80179596, 15.78874969], [80.80179596, 15.78903008], [80.80152893, 15.78902817], [80.80152893, 15.78958416], [80.80124664, 15.78958035], [80.80124664, 15.79042053], [80.80097198, 15.79041576], [80.80097198, 15.79097176], [80.80069733, 15.79097176], [80.80069733, 15.79125023], [80.80041504, 15.79125023], [80.80041504, 15.79208374], [80.80014038, 15.79207993], [80.80014038, 15.79264069], [80.79985809, 15.79263783], [80.79985809, 15.79347229], [80.79957581, 15.79347038], [80.79957581, 15.7937603], [80.79930878, 15.7937603], [80.79930878, 15.79486275], [80.79902649, 15.79486275], [80.79902649, 15.79514122], [80.79875183, 15.79513836], [80.79875183, 15.7956953], [80.79846954, 15.79568958], [80.79846954, 15.7962513], [80.79818726, 15.7962513], [80.79818726, 15.79653072], [80.79792023, 15.79652882], [80.79792023, 15.79736137], [80.79763794, 15.79736137], [80.79763794, 15.79847336], [80.79736328, 15.79847336], [80.79736328, 15.79958344], [80.79708099, 15.79957104], [80.79708099, 15.80014133], [80.79680634, 15.80013943], [80.79680634, 15.80097294], [80.79652405, 15.80097294], [80.79652405, 15.80208302], [80.79624939, 15.80208302], [80.79624939, 15.80236053], [80.79597473, 15.80236053], [80.79597473, 15.8045826], [80.79569244, 15.8045826], [80.79569244, 15.80597115], [80.79541779, 15.80597115], [80.79541779, 15.80708313], [80.79514313, 15.80708122], [80.79514313, 15.80764198], [80.79486084, 15.80764198], [80.79486084, 15.80792046], [80.79458618, 15.80791759], [80.79458618, 15.80819321], [80.79430389, 15.80819321], [80.79430389, 15.80847359], [80.79402924, 15.80847073], [80.79402924, 15.81042004], [80.79374695, 15.81041622], [80.79374695, 15.8120842], [80.79347229, 15.8120842], [80.79347229, 15.81458378], [80.79319763, 15.81458187], [80.79319763, 15.81624985], [80.79347229, 15.81624985], [80.79347229, 15.81653023], [80.79514313, 15.81653023], [80.79514313, 15.81681061], [80.79597473, 15.81680584], [80.79597473, 15.81708431], [80.79846954, 15.81708431], [80.79846954, 15.81680584], [80.80014038, 15.81681061], [80.80014038, 15.81653023], [80.80097198, 15.81653023], [80.80097198, 15.81624985], [80.80139923, 15.81624985], [80.80291748, 15.81624985], [80.80291748, 15.81597042], [80.80374908, 15.81597042], [80.80374908, 15.81624985], [80.80430603, 15.81624985], [80.80430603, 15.81653023], [80.80513763, 15.81653023], [80.80513763, 15.81624985], [80.80541992, 15.81624985], [80.80541992, 15.81597042], [80.80596924, 15.81597042], [80.80596924, 15.81624985], [80.80625153, 15.81624985], [80.80625153, 15.81653023], [80.80708313, 15.81653023], [80.80708313, 15.81624985], [80.8079071, 15.81624985], [80.8079071, 15.81597042], [80.80902863, 15.81597233], [80.80902863, 15.81569386], [80.81069183, 15.81569386], [80.81069183, 15.81597233], [80.81097412, 15.81597233], [80.81097412, 15.81708431], [80.81069183, 15.81707954], [80.81069183, 15.8176403], [80.81041718, 15.8176403], [80.81041718, 15.81986332], [80.81014252, 15.81986046], [80.81014252, 15.82181072], [80.81041718, 15.82181072], [80.81041718, 15.82236004], [80.81069183, 15.82236004], [80.81069183, 15.82319546], [80.81096649, 15.82318974], [80.81096649, 15.82514095], [80.81124878, 15.82514095], [80.81124878, 15.82625103], [80.81153107, 15.82625103], [80.81153107, 15.82708263], [80.81181335, 15.82708073], [80.81181335, 15.82931042], [80.81208038, 15.82931042], [80.81208038, 15.83153152], [80.81181335, 15.83153152], [80.81181335, 15.83293056], [80.81153107, 15.83291531], [80.81153107, 15.83319473], [80.81124878, 15.83319092], [80.81124878, 15.83375168], [80.81096649, 15.83375168], [80.81096649, 15.83403015], [80.81069183, 15.83402729], [80.81069183, 15.83458328], [80.81041718, 15.83458138], [80.81041718, 15.83486176], [80.81014252, 15.83486176], [80.81014252, 15.83541965], [80.80986023, 15.83541775], [80.80986023, 15.83597088], [80.80958557, 15.83597088], [80.80958557, 15.83708382], [80.80930328, 15.83708382], [80.80930328, 15.83736229], [80.80902863, 15.83735943], [80.80902863, 15.83763981], [80.80874634, 15.83763981], [80.80874634, 15.83792019], [80.80847168, 15.83791637], [80.80847168, 15.8381958], [80.80819702, 15.8381958], [80.80819702, 15.83847237], [80.8079071, 15.83846855], [80.8079071, 15.83875179], [80.80764008, 15.83875179], [80.80764008, 15.83930969], [80.80735779, 15.83930588], [80.80735779, 15.83958435], [80.80708313, 15.83958244], [80.80708313, 15.83986187], [80.80680847, 15.83986187], [80.80680847, 15.84041977], [80.80652618, 15.84041595], [80.80652618, 15.84069443], [80.80625153, 15.84069157], [80.80625153, 15.84152985], [80.80596924, 15.84152985], [80.80596924, 15.84181118], [80.80569458, 15.84180641], [80.80569458, 15.84208393], [80.80541992, 15.84208202], [80.80541992, 15.84263992], [80.80513763, 15.84263992], [80.80513763, 15.84292126], [80.80486298, 15.84291553], [80.80486298, 15.84319401], [80.80458069, 15.84319401], [80.80458069, 15.84347153], [80.80430603, 15.84346962], [80.80430603, 15.84375], [80.80403137, 15.84375], [80.80403137, 15.84403038], [80.80374908, 15.84402847], [80.80374908, 15.84458447], [80.80347443, 15.84458447], [80.80347443, 15.84486008], [80.80319214, 15.84485054], [80.80319214, 15.84514046], [80.80291748, 15.84514046], [80.80291748, 15.84542084], [80.80236053, 15.84541607], [80.80236053, 15.84569359], [80.80208588, 15.84569359], [80.80208588, 15.84597206], [80.80179596, 15.84597015], [80.80179596, 15.84624958], [80.80152893, 15.84624958], [80.80152893, 15.84653091], [80.80097198, 15.84653091], [80.80097198, 15.84681129], [80.80069733, 15.84680557], [80.80069733, 15.84708214], [80.80041504, 15.84708214], [80.80041504, 15.84736347], [80.80014038, 15.84735966], [80.80014038, 15.84764099], [80.79985809, 15.84763813], [80.79985809, 15.84791565], [80.79958344, 15.84791565], [80.79958344, 15.84819412], [80.79930878, 15.84819412], [80.79930878, 15.8484726], [80.79902649, 15.84846973], [80.79902649, 15.84875107], [80.79875183, 15.84875107], [80.79875183, 15.84903145], [80.79846954, 15.84903145], [80.79846954, 15.84931087], [80.79819489, 15.8493042], [80.79819489, 15.84958458], [80.79792023, 15.84958458], [80.79792023, 15.84986115], [80.79763794, 15.84986115], [80.79763794, 15.85014057], [80.79736328, 15.85014057], [80.79736328, 15.85042095], [80.79680634, 15.85041714], [80.79680634, 15.85069466], [80.79624939, 15.85069466], [80.79624939, 15.85097313], [80.7959671, 15.85097027], [80.7959671, 15.85153103], [80.79569244, 15.85153103], [80.79569244, 15.85181141], [80.7951355, 15.85180473], [80.7951355, 15.85208321], [80.79486084, 15.85208035], [80.79486084, 15.85236073], [80.79428864, 15.85236073], [80.79428864, 15.85264111], [80.79402924, 15.85264111], [80.79402924, 15.85292053], [80.79374695, 15.85291672], [80.79374695, 15.85319519], [80.79319763, 15.85319519], [80.79319763, 15.8534708], [80.79291534, 15.85347271], [80.79292297, 15.85375118], [80.79264069, 15.85375118], [80.79264069, 15.85404015], [80.7923584, 15.85402679], [80.7923584, 15.85458279], [80.79208374, 15.85458279], [80.79208374, 15.85486126], [80.79180908, 15.85486126], [80.79180908, 15.85514069], [80.79151917, 15.85514069], [80.79151917, 15.85542202], [80.79125214, 15.85541725], [80.79125214, 15.85569477], [80.79096985, 15.85569096], [80.79096985, 15.85625076], [80.79070282, 15.85625076], [80.79070282, 15.85652924], [80.7904129, 15.85652924], [80.7904129, 15.85680962], [80.78986359, 15.85680485], [80.78986359, 15.85708332], [80.7895813, 15.85708141], [80.7895813, 15.85736084], [80.78930664, 15.85736084], [80.78930664, 15.85763931], [80.78901672, 15.85763931], [80.78901672, 15.85791969], [80.78847504, 15.85791683], [80.78847504, 15.8581953], [80.78819275, 15.8581953], [80.78819275, 15.85847092], [80.7876358, 15.85847092], [80.7876358, 15.8587513], [80.78736115, 15.8587513], [80.78736115, 15.85903168], [80.78679657, 15.85903168], [80.78679657, 15.85931015], [80.78652954, 15.85930538], [80.78652954, 15.8595829], [80.78624725, 15.8595829], [80.78624725, 15.85986137], [80.7859726, 15.85984993], [80.7859726, 15.86014175], [80.78514099, 15.86014175], [80.78514099, 15.85984993], [80.78430176, 15.85986137], [80.78430176, 15.8595829], [80.7840271, 15.8595829], [80.7840271, 15.85902691], [80.78375244, 15.85903168], [80.78375244, 15.8587513], [80.78347015, 15.8587513], [80.78347015, 15.85847092], [80.78234863, 15.85847092], [80.78234863, 15.8587513], [80.78180695, 15.8587513], [80.78180695, 15.85903168], [80.78151703, 15.85903168], [80.78151703, 15.85931015], [80.78097534, 15.85930538], [80.78097534, 15.85986137], [80.78069305, 15.85984993], [80.78069305, 15.86014175], [80.7804184, 15.86014175], [80.7804184, 15.86042023], [80.77986145, 15.86041737], [80.77986145, 15.86069584], [80.77958679, 15.86069584], [80.77958679, 15.86097145], [80.77928925, 15.86097145], [80.77928925, 15.86125183], [80.77902985, 15.86125183], [80.77902985, 15.8615303], [80.77874756, 15.86152744], [80.77874756, 15.86208439], [80.7784729, 15.86208057], [80.7784729, 15.86236191], [80.77791595, 15.86236191], [80.77791595, 15.8629179], [80.7776413, 15.8629179], [80.7776413, 15.86319256], [80.77735901, 15.86319256], [80.77735901, 15.86347198], [80.77680206, 15.86347198], [80.77680206, 15.86375046], [80.77654266, 15.86375046], [80.77654266, 15.86403179], [80.77625275, 15.86403179], [80.77625275, 15.86431026], [80.77597046, 15.86430645], [80.77597046, 15.86458397], [80.77541351, 15.86458397], [80.77541351, 15.86486244], [80.77485657, 15.86485958], [80.77485657, 15.86513996], [80.77458191, 15.86513996], [80.77458191, 15.86542034], [80.77430725, 15.86542034], [80.77430725, 15.8659811], [80.77401733, 15.8659811], [80.77401733, 15.86625195], [80.7720871, 15.86625195], [80.7720871, 15.86542034], [80.77179718, 15.86542034], [80.77179718, 15.86513996], [80.77153015, 15.86513996], [80.77153015, 15.8645792], [80.77124786, 15.86458397], [80.77124786, 15.86402798], [80.77069092, 15.86403179], [80.77069092, 15.86375046], [80.7701416, 15.86375046], [80.7701416, 15.86347198], [80.76930237, 15.86347198], [80.76930237, 15.86319256], [80.76875305, 15.86319256], [80.76875305, 15.86347198], [80.76847076, 15.86347198], [80.76847076, 15.86375046], [80.76790619, 15.86375046], [80.76790619, 15.86403179], [80.76763916, 15.86403179], [80.76763916, 15.86431026], [80.76708221, 15.86430645], [80.76708221, 15.86458397], [80.76680756, 15.86458397], [80.76680756, 15.86486244], [80.7665329, 15.86485958], [80.7665329, 15.86513996], [80.76625061, 15.86513996], [80.76625061, 15.86542034], [80.76486206, 15.86541557], [80.76486206, 15.86569405], [80.76346588, 15.86568928], [80.76346588, 15.8659811], [80.76291656, 15.8659811], [80.76291656, 15.86625195], [80.76235962, 15.86625195], [80.76235962, 15.86653042], [80.76180267, 15.86653042], [80.76180267, 15.86680984], [80.76069641, 15.86680603], [80.76069641, 15.86708355], [80.75985718, 15.86708164], [80.75986481, 15.86736202], [80.7590332, 15.86736202], [80.7590332, 15.86763954], [80.75846863, 15.86763954], [80.75846863, 15.86791992], [80.75791931, 15.86791801], [80.75791931, 15.86819363], [80.75708008, 15.86819363], [80.75708008, 15.8684721], [80.75653076, 15.86847019], [80.75653076, 15.86874962], [80.75596619, 15.86874962], [80.75596619, 15.86903858], [80.75569153, 15.86903858], [80.75569153, 15.86931133], [80.75458527, 15.86930561], [80.75458527, 15.86958408], [80.75402832, 15.86958027], [80.75402832, 15.8698597], [80.75347137, 15.8698597], [80.75347137, 15.87014008], [80.7529068, 15.87014008], [80.7529068, 15.87042141], [80.75180817, 15.87041569], [80.75180817, 15.87069416], [80.75096893, 15.87069416], [80.75096893, 15.87097168], [80.74958038, 15.87097168], [80.74958038, 15.87125015], [80.74903107, 15.87125015], [80.74903107, 15.87153053], [80.74846649, 15.87153053], [80.74846649, 15.87181091], [80.74764252, 15.87180614], [80.74764252, 15.87208366], [80.74708557, 15.87208366], [80.74708557, 15.87236023], [80.74458313, 15.87236023], [80.74458313, 15.87263966], [80.74346924, 15.87263966], [80.74346924, 15.87292099], [80.74291992, 15.87291622], [80.74291992, 15.87319374], [80.74097443, 15.87319374], [80.74097443, 15.87347221], [80.74014282, 15.87347031], [80.74014282, 15.87374973], [80.73929596, 15.87374973], [80.73929596, 15.87403107], [80.73874664, 15.87403107], [80.73874664, 15.87431145], [80.73791504, 15.87430668], [80.73791504, 15.87458229], [80.73680878, 15.87458229], [80.73680878, 15.87485981], [80.73513794, 15.87485123], [80.73513794, 15.87514114], [80.73486328, 15.87514114], [80.73486328, 15.87542057], [80.73374939, 15.8754158], [80.73374939, 15.87569523], [80.73152924, 15.87569046], [80.73152924, 15.87597275], [80.72930908, 15.87597275], [80.72930908, 15.87625122], [80.72875214, 15.87625122], [80.72875214, 15.87653065], [80.72624969, 15.87653065], [80.72624969, 15.87681103], [80.72458649, 15.87680435], [80.72458649, 15.87708473], [80.72402954, 15.87708473], [80.72402954, 15.8773613], [80.72292328, 15.8773613], [80.72292328, 15.87764072], [80.7215271, 15.87764072], [80.7215271, 15.8779211], [80.72041321, 15.87791729], [80.72041321, 15.87819481], [80.7195816, 15.87819481], [80.7195816, 15.87847328], [80.71708679, 15.87847137], [80.71708679, 15.8787508], [80.71457672, 15.8787508], [80.71457672, 15.87903118], [80.71375275, 15.87903118], [80.71375275, 15.87931156], [80.71291351, 15.87930679], [80.71291351, 15.87958336], [80.71235657, 15.87957954], [80.71235657, 15.87986088], [80.71180725, 15.87986088], [80.71180725, 15.88014126], [80.7076416, 15.88014126], [80.7076416, 15.88042068], [80.70652771, 15.88041687], [80.70652771, 15.88069534], [80.70347595, 15.88068962], [80.70347595, 15.88097954], [80.70041656, 15.88097954], [80.70041656, 15.88125134], [80.69902802, 15.88125134], [80.69902802, 15.88153076], [80.69235992, 15.88153076], [80.69235992, 15.88125134], [80.68985748, 15.88125134], [80.68985748, 15.88153076], [80.68846893, 15.88153076], [80.68846893, 15.88180923], [80.68819427, 15.88180542], [80.68819427, 15.88208294], [80.68791962, 15.88208294], [80.68791962, 15.88236141], [80.68763733, 15.88236141], [80.68763733, 15.88264084], [80.68681335, 15.88264084], [80.68681335, 15.88236141], [80.68653107, 15.88236141], [80.68653107, 15.88208294], [80.68597412, 15.88208294], [80.68597412, 15.88180542], [80.68569183, 15.88180923], [80.68569183, 15.88153076], [80.68374634, 15.88153076], [80.68374634, 15.88125134], [80.68125153, 15.88125134], [80.68125153, 15.88097954], [80.67958069, 15.88097954], [80.67958069, 15.88068962], [80.67819214, 15.88069534], [80.67819214, 15.88041687], [80.67569733, 15.88042068], [80.67569733, 15.88014126], [80.66902924, 15.88014126], [80.66902924, 15.87986088], [80.66819, 15.87986088], [80.66819, 15.87957954], [80.66236115, 15.87958336], [80.66236115, 15.87930679], [80.65847015, 15.87931156], [80.65847015, 15.87903118], [80.65651703, 15.87903118], [80.65651703, 15.8787508], [80.65458679, 15.8787508], [80.65458679, 15.87847137], [80.6526413, 15.87847328], [80.6526413, 15.87819481], [80.64930725, 15.87819481], [80.64930725, 15.87791729], [80.64707947, 15.8779211], [80.64707947, 15.87764072], [80.64402008, 15.87764072], [80.64402008, 15.8773613], [80.64347076, 15.8773613], [80.64347076, 15.87708473], [80.64319611, 15.87708473], [80.64319611, 15.87680435], [80.64125061, 15.87681103], [80.64125061, 15.87653065], [80.64013672, 15.87653065], [80.64013672, 15.87625122], [80.63903046, 15.87625122], [80.63903046, 15.87597275], [80.63874817, 15.87597275], [80.63874817, 15.87569046], [80.63847351, 15.87569523], [80.63847351, 15.8754158], [80.63625336, 15.87542057], [80.63625336, 15.87514114], [80.63540649, 15.87514114], [80.63540649, 15.87485123], [80.63319397, 15.87485981], [80.63319397, 15.87458229], [80.63208008, 15.87458229], [80.63208008, 15.87430668], [80.62847137, 15.87431145], [80.62847137, 15.87403107], [80.62652588, 15.87403107], [80.62652588, 15.87374973], [80.62486267, 15.87374973], [80.62486267, 15.87347031], [80.62347412, 15.87347221], [80.62347412, 15.87319374], [80.62041473, 15.87319374], [80.62041473, 15.87291622], [80.61846924, 15.87292099], [80.61846924, 15.87263966], [80.61680603, 15.87263966], [80.61680603, 15.87236023], [80.61597443, 15.87236023], [80.61597443, 15.87208366], [80.61347198, 15.87208366], [80.61347198, 15.87180614], [80.61264038, 15.87181091], [80.61264038, 15.87153053], [80.61013794, 15.87153053], [80.61013794, 15.87125015], [80.60930634, 15.87125015], [80.60930634, 15.87097168], [80.60847473, 15.87097168], [80.60847473, 15.87069416], [80.60708618, 15.87069416], [80.60708618, 15.87041569], [80.60624695, 15.87042141], [80.60624695, 15.87014008], [80.60542297, 15.87014008], [80.60542297, 15.8698597], [80.60319519, 15.8698597], [80.60319519, 15.86958408], [80.60124969, 15.86958408], [80.60124969, 15.86930561], [80.59958649, 15.86931133], [80.59958649, 15.86903858], [80.59874725, 15.86903858], [80.59874725, 15.86874962], [80.59764099, 15.86874962], [80.59764099, 15.86847019], [80.59597015, 15.8684721], [80.59597015, 15.86819363], [80.59486389, 15.86819363], [80.59486389, 15.86791801], [80.5945816, 15.86791992], [80.5945816, 15.86763954], [80.59236145, 15.86763954], [80.59236145, 15.86736202], [80.59124756, 15.86736202], [80.59124756, 15.86708164], [80.59041595, 15.86708355], [80.59041595, 15.86680603], [80.58930206, 15.86680984], [80.58930206, 15.86653042], [80.58875275, 15.86653042], [80.58875275, 15.86625195], [80.58790588, 15.86625195], [80.58790588, 15.8659811], [80.58763885, 15.8659811], [80.58763885, 15.86568928], [80.58569336, 15.86569405], [80.58569336, 15.86541557], [80.58486176, 15.86541557], [80.5845871, 15.86542034], [80.5845871, 15.86513996], [80.58403015, 15.86513996], [80.58403015, 15.86485958], [80.5826416, 15.86486244], [80.5826416, 15.86458397], [80.58152771, 15.86458397], [80.58152771, 15.86430645], [80.58097076, 15.86431026], [80.58097076, 15.86403179], [80.58069611, 15.86403179], [80.58069611, 15.86375046], [80.57847595, 15.86375046], [80.57847595, 15.86347198], [80.57763672, 15.86347198], [80.57763672, 15.86319256], [80.57653046, 15.86319256], [80.57653046, 15.8629179], [80.57597351, 15.8629179], [80.57597351, 15.86263657], [80.57402802, 15.86264038], [80.57402802, 15.86236191], [80.57319641, 15.86236191], [80.57319641, 15.86208057], [80.57236481, 15.86208439], [80.57236481, 15.86180496], [80.5715332, 15.86180973], [80.5715332, 15.8615303], [80.56986237, 15.8615303], [80.56986237, 15.86125183], [80.56958008, 15.86125183], [80.56958008, 15.86097145], [80.56903076, 15.86097145], [80.56903076, 15.86069584], [80.56680298, 15.86069584], [80.56680298, 15.86041737], [80.56624603, 15.86042023], [80.56624603, 15.86014175], [80.56569672, 15.86014175], [80.56569672, 15.85984993], [80.56430817, 15.85986137], [80.56430817, 15.8595829], [80.56375122, 15.8595829], [80.56375122, 15.85930538], [80.56292725, 15.85931015], [80.56292725, 15.85903168], [80.56181335, 15.85903168], [80.56181335, 15.8587513], [80.56096649, 15.8587513], [80.56096649, 15.85847092], [80.56014252, 15.85847092], [80.56014252, 15.8581953], [80.55986023, 15.8581953], [80.55986023, 15.85791683], [80.55847168, 15.85791969], [80.55847168, 15.85763931], [80.5579071, 15.85763931], [80.5579071, 15.85736084], [80.55735779, 15.85736084], [80.55735779, 15.85708141], [80.55625153, 15.85708332], [80.55625153, 15.85680485], [80.55568695, 15.85680962], [80.55568695, 15.85652924], [80.55458069, 15.85652924], [80.55458069, 15.85625076], [80.55430603, 15.85625076], [80.55430603, 15.85597134], [80.55403137, 15.85597324], [80.55403137, 15.85569477], [80.55347443, 15.85569477], [80.55347443, 15.85541725], [80.55208588, 15.85542202], [80.55208588, 15.85514069], [80.55069733, 15.85514069], [80.55069733, 15.85486126], [80.54958344, 15.85486126], [80.54958344, 15.85458279], [80.54902649, 15.85458279], [80.54902649, 15.85430527], [80.54875183, 15.85431194], [80.54875183, 15.85404015], [80.54818726, 15.85404015], [80.54818726, 15.85375118], [80.54792023, 15.85375118], [80.54792023, 15.8534708], [80.54763794, 15.8534708], [80.54763794, 15.85319519], [80.54624939, 15.85319519], [80.54624939, 15.85291672], [80.54569244, 15.85292053], [80.54569244, 15.85264111], [80.54514313, 15.85264111], [80.54514313, 15.85236073], [80.54291534, 15.85236073], [80.54291534, 15.85208321], [80.54152679, 15.85208035], [80.54152679, 15.85236073], [80.54096985, 15.85236073], [80.54096985, 15.85252857], [80.54096985, 15.85264111], [80.54070282, 15.85264111], [80.54070282, 15.85292053], [80.5404129, 15.85291672], [80.5404129, 15.85319519], [80.53986359, 15.85319519], [80.53986359, 15.8534708], [80.5395813, 15.8534708], [80.5395813, 15.85404015], [80.53930664, 15.85404015], [80.53930664, 15.85431194], [80.53874969, 15.85430527], [80.53874969, 15.85458279], [80.53847504, 15.85458279], [80.53847504, 15.85486126], [80.53736115, 15.85486126], [80.53736115, 15.85458279], [80.53652954, 15.85458279], [80.53652954, 15.85430527], [80.5359726, 15.85431194], [80.5359726, 15.85404015], [80.53569031, 15.85404015], [80.53569031, 15.85375118], [80.53514099, 15.85375118], [80.53514099, 15.8534708], [80.53458405, 15.8534708], [80.53458405, 15.85319519], [80.53430176, 15.85319519], [80.53430176, 15.85291672], [80.5340271, 15.85292053], [80.5340271, 15.85264111], [80.53375244, 15.85264111], [80.53375244, 15.85236073], [80.53347015, 15.85236073], [80.53347015, 15.85208035], [80.5331955, 15.85208321], [80.5331955, 15.85180473], [80.53291321, 15.85181141], [80.53291321, 15.85153103], [80.53263092, 15.85153103], [80.53263092, 15.85125065], [80.53098297, 15.85125065], [80.53098297, 15.85153103], [80.53069305, 15.85153103], [80.53069305, 15.85181141], [80.5304184, 15.85180473], [80.5304184, 15.85208321], [80.52986145, 15.85208321], [80.52986145, 15.85180473], [80.52958679, 15.85181141], [80.52958679, 15.85125065], [80.52986145, 15.85125065], [80.52986145, 15.85097027], [80.53013611, 15.85097313], [80.53013611, 15.85069466], [80.5304184, 15.85069466], [80.5304184, 15.85041714], [80.53098297, 15.85042095], [80.53098297, 15.85014057], [80.53125, 15.85014057], [80.53125, 15.84986115], [80.53152466, 15.84986115], [80.53152466, 15.84958458], [80.53180695, 15.84958458], [80.53180695, 15.8493042], [80.53235626, 15.84931087], [80.53235626, 15.84903145], [80.53275299, 15.84902859], [80.53347015, 15.84903145], [80.53347015, 15.84875107], [80.53320313, 15.84875107], [80.53320313, 15.84846973], [80.53263855, 15.8484726], [80.53263855, 15.84819412], [80.53236389, 15.84819412], [80.53236389, 15.84791565], [80.5320816, 15.84791565], [80.5320816, 15.84763813], [80.53125, 15.84764099], [80.53125, 15.84735966], [80.53000641, 15.84736347], [80.5293045, 15.84736347], [80.5293045, 15.84708214], [80.52902985, 15.84708214], [80.52902985, 15.84680557], [80.52874756, 15.84681129], [80.52874756, 15.84653091], [80.52819824, 15.84653091], [80.52819061, 15.84624958], [80.52707672, 15.84624958], [80.52707672, 15.84597015], [80.5248642, 15.84597206], [80.5248642, 15.84569359], [80.52458191, 15.84569359], [80.52458191, 15.84541607], [80.52401733, 15.84542084], [80.52401733, 15.84514046], [80.52375031, 15.84514046], [80.52375031, 15.84485054], [80.5229187, 15.84486008], [80.5229187, 15.84458447], [80.52180481, 15.84458447], [80.52180481, 15.84430599], [80.52097321, 15.84431076], [80.52097321, 15.84403038], [80.52041626, 15.84403038], [80.52041626, 15.84375], [80.51985931, 15.84375], [80.51985931, 15.84346962], [80.51958466, 15.84347153], [80.51958466, 15.84319401], [80.51875305, 15.84319401], [80.51875305, 15.84291553], [80.51764679, 15.84292126], [80.51764679, 15.84263992], [80.51735687, 15.84263992], [80.51735687, 15.84235954], [80.51652527, 15.8423624], [80.51652527, 15.84208393], [80.51597595, 15.84208393], [80.51597595, 15.84180641], [80.51486206, 15.84181118], [80.51486206, 15.84152985], [80.51403046, 15.84152985], [80.51403046, 15.84125042], [80.51264191, 15.84125042], [80.51264191, 15.84097195], [80.51208496, 15.84097195], [80.51208496, 15.84069443], [80.51158905, 15.84069443], [80.51097107, 15.84069443], [80.51097107, 15.84041595], [80.51069641, 15.84041977], [80.51069641, 15.84014034], [80.50875092, 15.84014034], [80.50875092, 15.83986187], [80.50791931, 15.83986187], [80.50791931, 15.83958244], [80.50736237, 15.83958435], [80.50736237, 15.83930588], [80.50681305, 15.83930969], [80.50681305, 15.83903027], [80.50653076, 15.83903027], [80.50653076, 15.83875179], [80.50624847, 15.83875179], [80.50624847, 15.83846855], [80.50569153, 15.83847237], [80.50569153, 15.8381958], [80.50458527, 15.8381958], [80.50458527, 15.83791637], [80.50374603, 15.83792019], [80.50374603, 15.83763981], [80.50235748, 15.83763981], [80.50235748, 15.83735943], [80.50125122, 15.83736229], [80.50125122, 15.83708382], [80.50069427, 15.83708382], [80.50069427, 15.8368063], [80.50041962, 15.83681011], [80.50041962, 15.83652973], [80.50013733, 15.83652973], [80.50013733, 15.83625031], [80.49903107, 15.83625031], [80.49903107, 15.83597088], [80.49847412, 15.83597088], [80.49847412, 15.83569336], [80.49791718, 15.83569336], [80.49791718, 15.83541775], [80.49764252, 15.83541965], [80.49764252, 15.83514023], [80.49680328, 15.83514023], [80.49680328, 15.83486176], [80.49597168, 15.83486176], [80.49597168, 15.83458138], [80.49541473, 15.83458328], [80.49541473, 15.83430481], [80.49430847, 15.83430958], [80.49430847, 15.83403015], [80.49375153, 15.83403015], [80.49375153, 15.83375168], [80.49346161, 15.83375168], [80.49346161, 15.8334713], [80.49291992, 15.8334713], [80.49291992, 15.83319473], [80.49236298, 15.83319473], [80.49236298, 15.83291531], [80.49124908, 15.83293056], [80.49124908, 15.8326416], [80.49069214, 15.8326416], [80.49069214, 15.83236122], [80.48958588, 15.83236122], [80.48958588, 15.83208275], [80.48930359, 15.83208275], [80.48930359, 15.83180523], [80.48874664, 15.8318119], [80.48874664, 15.83153152], [80.48764038, 15.83153152], [80.48764038, 15.83124924], [80.48707581, 15.83124924], [80.48707581, 15.83097076], [80.48680878, 15.83097267], [80.48680878, 15.83069515], [80.48596954, 15.83069515], [80.48596954, 15.83041668], [80.48568726, 15.83041859], [80.48568726, 15.83014107], [80.48486328, 15.83014107], [80.48486328, 15.82987022], [80.48401642, 15.82987022], [80.48401642, 15.82958126], [80.48347473, 15.82958317], [80.48347473, 15.8293047], [80.48319244, 15.82931042], [80.48319244, 15.82903099], [80.48236084, 15.82903099], [80.48236084, 15.82875061], [80.48179626, 15.82875061], [80.48179626, 15.82847118], [80.48097229, 15.82847309], [80.48097229, 15.82819462], [80.48014069, 15.82819462], [80.48014069, 15.8279171], [80.47930908, 15.82792187], [80.47930908, 15.82764053], [80.47902679, 15.82764053], [80.47902679, 15.82736111], [80.47875214, 15.82736111], [80.47875214, 15.82708263], [80.47846985, 15.82708263], [80.47846985, 15.82625103], [80.47820282, 15.82625103], [80.47820282, 15.82597065], [80.47763824, 15.82597065], [80.47763824, 15.82625103], [80.4770813, 15.82625103], [80.4770813, 15.82653141], [80.47598267, 15.82653141], [80.47598267, 15.82625103], [80.47486115, 15.82625103], [80.47486115, 15.82597065], [80.4743042, 15.82597256], [80.4743042, 15.82569504], [80.47402954, 15.82569504], [80.47402954, 15.82541656], [80.47264099, 15.82542133], [80.47264099, 15.82514095], [80.47180176, 15.82514095], [80.47180176, 15.82486057], [80.47125244, 15.82486057], [80.47125244, 15.82458305], [80.47097015, 15.82458305], [80.47097015, 15.82430458], [80.47070313, 15.82431126], [80.47070313, 15.82403088], [80.47041321, 15.82403088], [80.47041321, 15.82374191], [80.47013855, 15.82374763], [80.47013855, 15.82347298], [80.46986389, 15.82347298], [80.46986389, 15.82319546], [80.46847534, 15.82319546], [80.46847534, 15.82291698], [80.4679184, 15.8229208], [80.4679184, 15.82264137], [80.46763611, 15.82264137], [80.46763611, 15.82236004], [80.46708679, 15.82236004], [80.46708679, 15.82207966], [80.4668045, 15.82208157], [80.4668045, 15.82180691], [80.4659729, 15.82181072], [80.4659729, 15.8215313], [80.4651413, 15.8215313], [80.4651413, 15.82125092], [80.4640274, 15.82125092], [80.4640274, 15.82096958], [80.46375275, 15.82097244], [80.46375275, 15.82069397], [80.46347809, 15.82068062], [80.46347046, 15.82041645], [80.4631958, 15.82042122], [80.4631958, 15.82014275], [80.46263885, 15.82014275], [80.46263885, 15.81986046], [80.46208191, 15.81986332], [80.46208191, 15.81958199], [80.46180725, 15.81958199], [80.46180725, 15.81930637], [80.46041107, 15.81931114], [80.46041107, 15.81903076], [80.46013641, 15.81903076], [80.46013641, 15.81875038], [80.45986176, 15.81875038], [80.45986176, 15.81847], [80.45930481, 15.81847191], [80.45930481, 15.81819439], [80.45847321, 15.81819439], [80.45847321, 15.81791592], [80.4576416, 15.81793022], [80.4576416, 15.8176403], [80.45680237, 15.8176403], [80.45680237, 15.81735992], [80.45625305, 15.81735992], [80.45625305, 15.81707954], [80.45569611, 15.81708431], [80.45569611, 15.81680584], [80.45540619, 15.81681061], [80.45540619, 15.81653023], [80.45485687, 15.81653023], [80.45485687, 15.81624985], [80.45318604, 15.81624985], [80.45318604, 15.81597042], [80.45291901, 15.81597233], [80.45291901, 15.81569386], [80.45263672, 15.81569386], [80.45263672, 15.81541634], [80.45153809, 15.81542015], [80.45153809, 15.81514168], [80.45096588, 15.81514168], [80.45096588, 15.81487083], [80.45041656, 15.81487083], [80.45041656, 15.81458187], [80.45014191, 15.81458378], [80.45014191, 15.81430626], [80.44957733, 15.81431103], [80.44957733, 15.81402969], [80.44930267, 15.81402969], [80.44930267, 15.81375027], [80.44902802, 15.81375027], [80.44902802, 15.81347179], [80.44875336, 15.81347179], [80.44875336, 15.81319237], [80.44763947, 15.81319427], [80.44763947, 15.8129158], [80.44680786, 15.81291962], [80.44680786, 15.81264019], [80.44625092, 15.81264019], [80.44625092, 15.81236172], [80.44568634, 15.81236172], [80.44568634, 15.81207943], [80.44541931, 15.8120842], [80.44541931, 15.81180573], [80.44486237, 15.81180573], [80.44486237, 15.81152821], [80.44431305, 15.81153011], [80.44431305, 15.81124973], [80.44374847, 15.81124973], [80.44374847, 15.81096935], [80.44319153, 15.81097221], [80.44319153, 15.81069374], [80.44291687, 15.81069374], [80.44291687, 15.81041622], [80.4420929, 15.81042004], [80.4420929, 15.81013966], [80.44124603, 15.81013966], [80.44124603, 15.80985928], [80.44097137, 15.80986214], [80.44097137, 15.80958366], [80.44013977, 15.80958366], [80.44013977, 15.80930614], [80.43985748, 15.80930996], [80.43985748, 15.80902958], [80.43930817, 15.80902958], [80.43930817, 15.80873966], [80.43902588, 15.8087492], [80.43902588, 15.80847359], [80.43846893, 15.80847359], [80.43846893, 15.80819321], [80.43736267, 15.80819321], [80.43736267, 15.80791759], [80.43681335, 15.80792046], [80.43681335, 15.80764198], [80.43624115, 15.80764198], [80.43624115, 15.80736065], [80.43597412, 15.80736065], [80.43596649, 15.80708122], [80.43541718, 15.80708313], [80.43541718, 15.80680466], [80.43514252, 15.80681038], [80.43514252, 15.80653191], [80.43347168, 15.80653191], [80.43347168, 15.80625153], [80.43319702, 15.80625153], [80.43319702, 15.80597115], [80.43264008, 15.80597115], [80.43264008, 15.80569458], [80.43096924, 15.8057003], [80.43096924, 15.80542183], [80.43068695, 15.80542183], [80.43068695, 15.8051424], [80.43042755, 15.8051424], [80.43042755, 15.80486107], [80.43013763, 15.80486107], [80.43013763, 15.80458069], [80.42986298, 15.8045826], [80.42986298, 15.80430508], [80.42958069, 15.80431175], [80.42958069, 15.80402946], [80.42930603, 15.80402946], [80.42930603, 15.80375099], [80.42903137, 15.80375099], [80.42903137, 15.80347061], [80.42874908, 15.80347347], [80.42874908, 15.80319309], [80.42830658, 15.80319309], [80.42819214, 15.80319309], [80.42819214, 15.80291653], [80.42791748, 15.80293083], [80.42791748, 15.80264091], [80.42736816, 15.80264091], [80.42736816, 15.80236053], [80.42680359, 15.80236053], [80.42680359, 15.80208302], [80.42652893, 15.80208302], [80.42652893, 15.80180454], [80.42624664, 15.80181026], [80.42624664, 15.80153084], [80.42597198, 15.80153084], [80.42597198, 15.80125141], [80.42514038, 15.80125141], [80.42514038, 15.80097103], [80.42458344, 15.80097294], [80.42458344, 15.80069542], [80.42430878, 15.80069542], [80.42430878, 15.80041695], [80.42375183, 15.80042171], [80.42375183, 15.80014133], [80.42346954, 15.80014133], [80.42346954, 15.79986095], [80.42236328, 15.79986095], [80.42236328, 15.79957104], [80.42180634, 15.79958344], [80.42180634, 15.79930687], [80.42151642, 15.79931164], [80.42151642, 15.79903126], [80.42124176, 15.79903126], [80.42124176, 15.79875088], [80.4209671, 15.79875088], [80.4209671, 15.79847145], [80.41986084, 15.79847336], [80.41986084, 15.79819489], [80.41902924, 15.79819489], [80.41902924, 15.79791737], [80.41874695, 15.79792118], [80.41874695, 15.7976408], [80.41819763, 15.7976408], [80.41819763, 15.79736137], [80.41791534, 15.79736137], [80.41791534, 15.7970829], [80.41708374, 15.7970829], [80.41708374, 15.79680538], [80.41680908, 15.79680538], [80.41680908, 15.79652882], [80.41625214, 15.79653072], [80.41625214, 15.7962513], [80.4154129, 15.7962513], [80.4154129, 15.79596996], [80.41486359, 15.79597282], [80.41486359, 15.7956953], [80.4145813, 15.7956953], [80.4145813, 15.79541683], [80.41401672, 15.79542065], [80.41401672, 15.79514122], [80.41374969, 15.79514122], [80.41374969, 15.79486275], [80.41291809, 15.79486275], [80.41291809, 15.79458046], [80.41236115, 15.79458237], [80.41236115, 15.79430676], [80.41179657, 15.79431057], [80.41179657, 15.79403114], [80.41152954, 15.79403114], [80.41152954, 15.7937603], [80.4109726, 15.7937603], [80.4109726, 15.79347038], [80.41014099, 15.79347229], [80.41014099, 15.79319382], [80.4098587, 15.79319382], [80.4098587, 15.7929163], [80.40957642, 15.79292107], [80.40957642, 15.79264069], [80.40930176, 15.79264069], [80.40930176, 15.79236031], [80.40875244, 15.79236031], [80.40875244, 15.79208374], [80.40847015, 15.79208374], [80.40847015, 15.79180622], [80.40820313, 15.79181099], [80.40820313, 15.79153061], [80.40763855, 15.79153061], [80.40763855, 15.79125023], [80.40680695, 15.79125023], [80.40680695, 15.79096985], [80.40625, 15.79097176], [80.40625, 15.79069424], [80.40569305, 15.79070091], [80.40569305, 15.79042053], [80.4054184, 15.79042053], [80.4054184, 15.79014015], [80.40513611, 15.79014015], [80.40513611, 15.78986168], [80.40486145, 15.78986168], [80.40486145, 15.78958035], [80.40402985, 15.78958416], [80.40402985, 15.78930569], [80.4034729, 15.78931141], [80.4034729, 15.78903008], [80.40319824, 15.78903008], [80.40319824, 15.78874969], [80.40291595, 15.78874969], [80.40291595, 15.78847027], [80.40235901, 15.78847218], [80.40235901, 15.7881937], [80.40180206, 15.7881937], [80.40180206, 15.78791809], [80.4015274, 15.78792], [80.4015274, 15.78763103], [80.40097046, 15.78763771], [80.40097046, 15.7873621], [80.40041351, 15.7873621], [80.40041351, 15.78708363], [80.3998642, 15.78708363], [80.3998642, 15.78680611], [80.39958191, 15.78681087], [80.39958191, 15.78652954], [80.39875031, 15.78652954], [80.39875031, 15.78625202], [80.39848328, 15.78625202], [80.39848328, 15.78597164], [80.39819336, 15.78597164], [80.39819336, 15.78569412], [80.39763641, 15.78569412], [80.39763641, 15.78541565], [80.39736176, 15.78542042], [80.39736176, 15.78514004], [80.39653015, 15.78514004], [80.39653015, 15.78485966], [80.39597321, 15.78486156], [80.39597321, 15.78458405], [80.39541626, 15.78458405], [80.39541626, 15.78430557], [80.3951416, 15.78431034], [80.3951416, 15.78402996], [80.39485931, 15.78402996], [80.39485931, 15.78374958], [80.39430237, 15.78374958], [80.39430237, 15.7834692], [80.39402771, 15.78347206], [80.39402771, 15.78319359], [80.39347076, 15.78319359], [80.39347076, 15.78291798], [80.39319611, 15.78292179], [80.39319611, 15.78264046], [80.39263916, 15.78264046], [80.39263916, 15.78236198], [80.39235687, 15.78236198], [80.39235687, 15.78208065], [80.39208221, 15.78208447], [80.39208221, 15.78180599], [80.3915329, 15.78181934], [80.3915329, 15.78153038], [80.39125824, 15.78153038], [80.39125824, 15.78125191], [80.39068604, 15.78125191], [80.39068604, 15.78097057], [80.38986206, 15.78097057], [80.38986206, 15.78069305], [80.38930511, 15.78069305], [80.38930511, 15.7804184], [80.38874817, 15.7804203], [80.38874817, 15.78014183], [80.38819122, 15.78014183], [80.38819122, 15.77986145], [80.38791656, 15.77986145], [80.38791656, 15.77958298], [80.38735962, 15.77958298], [80.38735962, 15.77930546], [80.38680267, 15.77931023], [80.38680267, 15.77903175], [80.38652802, 15.77903175], [80.38652802, 15.77876091], [80.38625336, 15.77876091], [80.38625336, 15.77847099], [80.38569641, 15.77847099], [80.38569641, 15.77819538], [80.38513947, 15.77819538], [80.38513947, 15.77791691], [80.38458252, 15.77791977], [80.38458252, 15.77763939], [80.3840332, 15.77763939], [80.3840332, 15.77736092], [80.38375092, 15.77736092], [80.38375092, 15.77708054], [80.38319397, 15.7770834], [80.38319397, 15.77680492], [80.38291931, 15.77680969], [80.38291931, 15.77652931], [80.38236237, 15.77652931], [80.38236237, 15.77625084], [80.38207245, 15.77625084], [80.38207245, 15.77597141], [80.38180542, 15.77597332], [80.38180542, 15.77569485], [80.38153076, 15.77569485], [80.38153076, 15.77541733], [80.38069153, 15.77541924], [80.38069153, 15.77514076], [80.38041687, 15.77514076], [80.38041687, 15.77486134], [80.37985992, 15.77486134], [80.37985992, 15.77458286], [80.37958527, 15.77458286], [80.37958527, 15.77430534], [80.37930298, 15.77431202], [80.37930298, 15.77403069], [80.37902832, 15.77403069], [80.37902832, 15.77375126], [80.37874603, 15.77375126], [80.37874603, 15.77347088], [80.37847137, 15.77347088], [80.37847137, 15.77319527], [80.37763977, 15.77319527], [80.37763977, 15.77291679], [80.37735748, 15.77292061], [80.37735748, 15.77262974], [80.37680817, 15.77263927], [80.37680817, 15.7723608], [80.37652588, 15.7723608], [80.37652588, 15.77208328], [80.37596893, 15.77208328], [80.37596893, 15.77180481], [80.37513733, 15.77181244], [80.37513733, 15.77153111], [80.37486267, 15.77153111], [80.37486267, 15.77125072], [80.37458038, 15.77125072], [80.37458038, 15.7709713], [80.37430573, 15.77097321], [80.37430573, 15.77069473], [80.37374878, 15.77069473], [80.37374878, 15.77041721], [80.37319183, 15.77042103], [80.37319183, 15.77014065], [80.37236023, 15.77014065], [80.37236023, 15.76986122], [80.37208557, 15.76986122], [80.37208557, 15.76958466], [80.37180328, 15.76958942], [80.37180328, 15.76931095], [80.37124634, 15.76931095], [80.37124634, 15.76903057], [80.37097168, 15.76903057], [80.37097168, 15.76875114], [80.37069702, 15.76875114], [80.37069702, 15.76846981], [80.37014008, 15.76847267], [80.37014008, 15.76819515], [80.36985779, 15.76819515], [80.36985779, 15.76791573], [80.36930847, 15.76792145], [80.36930847, 15.76764107], [80.36875153, 15.76764107], [80.36875153, 15.76735973], [80.36846924, 15.76735973], [80.36846924, 15.76708031], [80.36791992, 15.76708221], [80.36791992, 15.7668066], [80.36763763, 15.76681995], [80.36763763, 15.76653099], [80.36708832, 15.76653099], [80.36708832, 15.76624966], [80.36653137, 15.76624966], [80.36653137, 15.76597023], [80.36597443, 15.76597214], [80.36597443, 15.76569366], [80.36569214, 15.76569366], [80.36569214, 15.76541615], [80.36541748, 15.76542091], [80.36541748, 15.76513958], [80.36514282, 15.76513958], [80.36514282, 15.76486015], [80.36430359, 15.76486015], [80.36430359, 15.76458359], [80.36402893, 15.76458359], [80.36402893, 15.76430416], [80.36347198, 15.76431084], [80.36347198, 15.76403141], [80.36319733, 15.76403141], [80.36319733, 15.76375008], [80.36264038, 15.76375008], [80.36264038, 15.7634697], [80.36180878, 15.7634716], [80.36180878, 15.76319408], [80.36125183, 15.76319408], [80.36125183, 15.76291561], [80.36068726, 15.76292133], [80.36068726, 15.76235962], [80.36042023, 15.76236153], [80.36042023, 15.76208401], [80.35958099, 15.76208401], [80.35958099, 15.76180553], [80.35901642, 15.76181126], [80.35901642, 15.76152992], [80.35874939, 15.76152992], [80.35874939, 15.76124954], [80.3584671, 15.76124954], [80.3584671, 15.76097202], [80.35819244, 15.76097202], [80.35819244, 15.76069355], [80.35791779, 15.76069355], [80.35791779, 15.76041794], [80.35764313, 15.76041985], [80.35764313, 15.76014042], [80.35736084, 15.76014042], [80.35736084, 15.75986195], [80.35679626, 15.75986195], [80.35679626, 15.75958157], [80.35624695, 15.75958443], [80.35624695, 15.75930595], [80.35597229, 15.75930977], [80.35597229, 15.75903034], [80.35569763, 15.75903034], [80.35569763, 15.75846863], [80.35541534, 15.75847244], [80.35541534, 15.75819588], [80.35514832, 15.7581892], [80.35514069, 15.75763988], [80.35457611, 15.75765133], [80.35457611, 15.75736046], [80.35402679, 15.75736237], [80.35402679, 15.75708389], [80.35375214, 15.75708389], [80.35375214, 15.75680637], [80.35346985, 15.75681019], [80.35346985, 15.75625038], [80.35319519, 15.75625038], [80.35319519, 15.75597191], [80.35263824, 15.75597191], [80.35263824, 15.75569344], [80.35236359, 15.75569344], [80.35236359, 15.75541782], [80.35180664, 15.75541973], [80.35180664, 15.7551403], [80.35151672, 15.7551403], [80.35151672, 15.75486183], [80.35124969, 15.75486183], [80.35121918, 15.75464344], [80.35111237, 15.75458813], [80.35098267, 15.75459003], [80.35098267, 15.75430965], [80.35069275, 15.75430965], [80.35069275, 15.75403023], [80.35015106, 15.75402069], [80.3501358, 15.75374889], [80.34986115, 15.75375175], [80.34986115, 15.75347137], [80.34958649, 15.75347137], [80.34958649, 15.75319576], [80.3493042, 15.75319576], [80.3493042, 15.75291538], [80.34902191, 15.75292015], [80.34902191, 15.75264168], [80.34874725, 15.75264168], [80.34874725, 15.7523613], [80.3482666, 15.7523613], [80.34791565, 15.7523613], [80.34791565, 15.75208282], [80.3473587, 15.75208282], [80.3473587, 15.75180531], [80.34625244, 15.75181198], [80.34625244, 15.75152016], [80.34597015, 15.75152683], [80.34597015, 15.75124931], [80.34513855, 15.75124931], [80.34513855, 15.75097084], [80.3445816, 15.75097084], [80.3445816, 15.75069141], [80.34430695, 15.75069523], [80.34430695, 15.75041676], [80.34401703, 15.75041962], [80.34401703, 15.75013924], [80.34375, 15.75013924], [80.34375, 15.74986076], [80.34319305, 15.74986076], [80.34319305, 15.74958134], [80.3429184, 15.74958324], [80.3429184, 15.74930477], [80.34263611, 15.74930954], [80.34263611, 15.74903202], [80.34236145, 15.74903202], [80.34236145, 15.74875069], [80.34179687, 15.74875069], [80.34179687, 15.74845886], [80.34124756, 15.74847317], [80.34124756, 15.74819469], [80.3409729, 15.74819469], [80.3409729, 15.74791718], [80.34041595, 15.74792194], [80.34041595, 15.74764061], [80.34014893, 15.74764061], [80.34014893, 15.74736118], [80.33958435, 15.74736118], [80.33958435, 15.74708271], [80.33930206, 15.74708271], [80.33930206, 15.74680519], [80.3390274, 15.74681187], [80.3390274, 15.74653053], [80.33875275, 15.74653053], [80.33875275, 15.74625111], [80.33847046, 15.74625111], [80.33847046, 15.74597073], [80.3381958, 15.74597263], [80.3381958, 15.74569511], [80.33791351, 15.74569511], [80.33791351, 15.74541664], [80.33763885, 15.74542141], [80.33763885, 15.74514103], [80.33735657, 15.74514103], [80.33735657, 15.74458027], [80.33708191, 15.74458313], [80.33708191, 15.74374866], [80.33680725, 15.74375057], [80.33680725, 15.74347019], [80.33652496, 15.74347305], [80.33652496, 15.74319458], [80.33625031, 15.74319458], [80.33625031, 15.74291706], [80.33598328, 15.74292088], [80.33598328, 15.74267006], [80.33569336, 15.74265003], [80.33569336, 15.74249268], [80.33569336, 15.74236107], [80.3354187, 15.74236107], [80.3354187, 15.74208164], [80.33525085, 15.74208164], [80.33513641, 15.74208164], [80.33513641, 15.74194145], [80.33513641, 15.74180698], [80.33486176, 15.7418108], [80.3348465, 15.7415514], [80.3345871, 15.74153137], [80.3345871, 15.74125099], [80.33429718, 15.74125099], [80.33429718, 15.74096966], [80.33403015, 15.74097347], [80.33403015, 15.74069405], [80.33374786, 15.74069405], [80.33374786, 15.74041557], [80.33347321, 15.7404213], [80.33347321, 15.74014091], [80.33319092, 15.74014091], [80.33319092, 15.73985958], [80.33291626, 15.7398634], [80.33291626, 15.73958206], [80.3326416, 15.73958206], [80.3326416, 15.73930645], [80.33235931, 15.73931122], [80.33235931, 15.73903084], [80.33207703, 15.73903084], [80.33207703, 15.73875046], [80.33180237, 15.73875046], [80.33180237, 15.73847008], [80.33125305, 15.73847198], [80.33125305, 15.73819447], [80.33097076, 15.73819447], [80.33097076, 15.73791599], [80.33069611, 15.73792076], [80.33069611, 15.73764038], [80.32985687, 15.73764038], [80.32985687, 15.73736], [80.32958221, 15.73736], [80.32958221, 15.73707962], [80.32930756, 15.73708439], [80.32930756, 15.73680592], [80.3290329, 15.73681068], [80.3290329, 15.73651886], [80.32847595, 15.7365284], [80.32847595, 15.73624992], [80.32818604, 15.73624992], [80.32818604, 15.73596954], [80.32791901, 15.7359724], [80.32791901, 15.73569393], [80.32763672, 15.73569393], [80.32763672, 15.73541641], [80.32736206, 15.73542118], [80.32736206, 15.73513985], [80.32681274, 15.73513985], [80.32681274, 15.73486042], [80.32653046, 15.73486233], [80.32653046, 15.73458195], [80.32624817, 15.73458195], [80.32624817, 15.73402786], [80.32596588, 15.73403263], [80.32596588, 15.73375034], [80.32569122, 15.73375034], [80.32569122, 15.73346138], [80.32541656, 15.73347187], [80.32541656, 15.73319435], [80.32485962, 15.73319435], [80.32485962, 15.73291588], [80.32459259, 15.73291969], [80.32459259, 15.73264027], [80.32430267, 15.73264027], [80.32430267, 15.73236179], [80.32402802, 15.73236179], [80.32402802, 15.73207855], [80.32375336, 15.73208427], [80.32375336, 15.7318058], [80.32347107, 15.73180962], [80.32347107, 15.73124981], [80.32319641, 15.73124981], [80.32319641, 15.73096943], [80.32291412, 15.73097229], [80.32291412, 15.73069572], [80.32263947, 15.73069572], [80.32263947, 15.7304163], [80.32235718, 15.73042011], [80.32235718, 15.73013973], [80.32208252, 15.73013973], [80.32208252, 15.72985935], [80.32152557, 15.72986221], [80.32152557, 15.72958374], [80.32125092, 15.72958374], [80.32125092, 15.72930622], [80.32096863, 15.72931004], [80.32096863, 15.72902966], [80.32068634, 15.72902966], [80.32068634, 15.72875023], [80.32041931, 15.72875023], [80.32041931, 15.7284708], [80.32013702, 15.7284708], [80.32013702, 15.72819138], [80.31986237, 15.72819328], [80.31986237, 15.72791767], [80.31958008, 15.72791958], [80.31958008, 15.72764015], [80.31931305, 15.72764015], [80.31931305, 15.72736168], [80.31903076, 15.72736168], [80.31903076, 15.72708321], [80.31874847, 15.72708321], [80.31874847, 15.72680473], [80.31846619, 15.72681046], [80.31846619, 15.72653198], [80.31819153, 15.72653198], [80.31819153, 15.7262516], [80.31791687, 15.7262516], [80.31791687, 15.72597122], [80.31764221, 15.72597122], [80.31764221, 15.72569466], [80.31708527, 15.72569466], [80.31708527, 15.72541714], [80.31680298, 15.72542191], [80.31680298, 15.72514153], [80.31652832, 15.72514153], [80.31652832, 15.72486115], [80.31625366, 15.72486115], [80.31625366, 15.72458267], [80.31569672, 15.72458267], [80.31569672, 15.72430515], [80.3154068, 15.72430992], [80.3154068, 15.72402859], [80.31513977, 15.72402859], [80.31513977, 15.72347069], [80.31485748, 15.7234726], [80.31485748, 15.72319317], [80.31458282, 15.72319317], [80.31458282, 15.7229166], [80.31430817, 15.72291946], [80.31430817, 15.72264099], [80.31402588, 15.72264099], [80.31402588, 15.72236061], [80.31375122, 15.72236061], [80.31375122, 15.72208309], [80.31346893, 15.72208309], [80.31346893, 15.72180462], [80.31263733, 15.72181034], [80.31263733, 15.72152042], [80.31236267, 15.7215271], [80.31236267, 15.72124863], [80.31208038, 15.72125053], [80.31208038, 15.72097111], [80.31180573, 15.72097301], [80.31180573, 15.72041702], [80.31153107, 15.72042179], [80.31153107, 15.72014141], [80.31124878, 15.72014141], [80.31124878, 15.71986103], [80.31096649, 15.71986103], [80.31096649, 15.71958065], [80.31069183, 15.71958256], [80.31069183, 15.71930695], [80.31041718, 15.71931171], [80.31041718, 15.71903133], [80.31014252, 15.71903133], [80.31014252, 15.71875095], [80.3098526, 15.71875095], [80.3098526, 15.71848202], [80.3095932, 15.71848202], [80.3095932, 15.71792126], [80.30930328, 15.71792126], [80.30930328, 15.71736145], [80.30902863, 15.71736145], [80.30902863, 15.71708298], [80.30874634, 15.71708298], [80.30874634, 15.71652889], [80.30847168, 15.71652889], [80.30847168, 15.71625137], [80.30819702, 15.71625137], [80.30819702, 15.71597004], [80.30791473, 15.7159729], [80.30791473, 15.71569538], [80.30735779, 15.71569538], [80.30735779, 15.71541691], [80.30708313, 15.71542072], [80.30708313, 15.7151413], [80.30680847, 15.7151413], [80.30680847, 15.71457958], [80.30652618, 15.71458244], [80.30652618, 15.71430683], [80.30625153, 15.71431065], [80.30625153, 15.71403122], [80.30596924, 15.71403122], [80.30596924, 15.71347046], [80.30569458, 15.71347237], [80.30569458, 15.71319389], [80.30541992, 15.71319389], [80.30541992, 15.71291637], [80.30513763, 15.71292114], [80.30513763, 15.71264076], [80.30486298, 15.71264076], [80.30486298, 15.71235085], [80.30458069, 15.71236038], [80.30458069, 15.71208382], [80.30430603, 15.71208191], [80.30430603, 15.7118063], [80.304039, 15.71181107], [80.304039, 15.71153069], [80.30374908, 15.71153069], [80.30374908, 15.71125031], [80.3034668, 15.71125031], [80.3034668, 15.71096992], [80.30319214, 15.71097183], [80.30319214, 15.71069431], [80.30291748, 15.71069431], [80.30291748, 15.71041584], [80.30236053, 15.71042061], [80.30236053, 15.71014023], [80.30208588, 15.71014023], [80.30208588, 15.70985985], [80.30180359, 15.70985985], [80.30180359, 15.70958424], [80.30152893, 15.70958424], [80.30152893, 15.70902824], [80.30124664, 15.70903015], [80.30124664, 15.70875168], [80.30097198, 15.70875168], [80.30097198, 15.70847034], [80.30069733, 15.70847225], [80.30069733, 15.70819378], [80.30041504, 15.70819378], [80.30041504, 15.70763779], [80.30014038, 15.70763969], [80.30014038, 15.70736027], [80.29985809, 15.70736217], [80.29985809, 15.7070837], [80.29958344, 15.7070837], [80.29958344, 15.70652771], [80.29930878, 15.70654202], [80.29930878, 15.70625019], [80.29902649, 15.70625019], [80.29902649, 15.70597172], [80.29875183, 15.70597172], [80.29875183, 15.7056942], [80.29846954, 15.7056942], [80.29846954, 15.70541573], [80.29818726, 15.70541954], [80.29818726, 15.70514011], [80.2979126, 15.70514011], [80.2979126, 15.70485973], [80.29763794, 15.70485973], [80.29763794, 15.70431042], [80.29736328, 15.70431042], [80.29736328, 15.70403004], [80.29680634, 15.70403004], [80.29680634, 15.70374966], [80.29651642, 15.70374966], [80.29651642, 15.70348072], [80.29624939, 15.70348072], [80.29624939, 15.7031889], [80.29597473, 15.70319366], [80.29597473, 15.70263958], [80.29569244, 15.70263958], [80.29569244, 15.70208073], [80.29541779, 15.70208359], [80.29541779, 15.70180607], [80.29514313, 15.70181179], [80.29514313, 15.70125198], [80.29486847, 15.70125198], [80.29486847, 15.70097065], [80.29458618, 15.70097065], [80.29458618, 15.70069313], [80.29430389, 15.70069313], [80.29430389, 15.70041847], [80.29402924, 15.70041847], [80.29402924, 15.70014], [80.29374695, 15.70014191], [80.29374695, 15.69986057], [80.29347229, 15.69986057], [80.29347229, 15.69930458], [80.29319763, 15.6993103], [80.29319763, 15.6987524], [80.29292297, 15.6987524], [80.29292297, 15.69847107], [80.29264069, 15.69847107], [80.29264069, 15.69819546], [80.2923584, 15.69819546], [80.2923584, 15.69791698], [80.29207611, 15.69792175], [80.29207611, 15.69734955], [80.29180908, 15.69736099], [80.29180908, 15.69708347], [80.29152679, 15.69708347], [80.29152679, 15.69652653], [80.29125214, 15.69652939], [80.29123688, 15.6962719], [80.29096985, 15.69625092], [80.29096222, 15.69599247], [80.29070282, 15.69597054], [80.29069519, 15.69569492], [80.2904129, 15.69569111], [80.2904129, 15.6954174], [80.29013824, 15.69541931], [80.29013824, 15.69521046], [80.2895813, 15.69514084], [80.2895813, 15.69486141], [80.28930664, 15.69486141], [80.28930664, 15.69458294], [80.28902435, 15.69458294], [80.28902435, 15.69402695], [80.2889328, 15.69402695], [80.28874969, 15.69403076], [80.28874969, 15.69386959], [80.28874969, 15.69375134], [80.28864288, 15.69375134], [80.28847504, 15.69375134], [80.28847504, 15.69358921], [80.28847504, 15.69347095], [80.28835297, 15.69347095], [80.28819275, 15.69347095], [80.28819275, 15.69331074], [80.28819275, 15.69319534], [80.28807068, 15.69319534], [80.28791809, 15.69319534], [80.28791809, 15.69305134], [80.28791809, 15.69263935], [80.28762817, 15.69264126], [80.2876358, 15.69236088], [80.28746796, 15.69236088], [80.28736115, 15.69236088], [80.28736115, 15.69216919], [80.28736115, 15.69208336], [80.28708649, 15.69208336], [80.28708649, 15.69180489], [80.28679657, 15.69181156], [80.28679657, 15.69154263], [80.28652954, 15.69154263], [80.28652954, 15.6912508], [80.28624725, 15.6912508], [80.28624725, 15.69097137], [80.2859726, 15.69097328], [80.2859726, 15.69069481], [80.28569794, 15.69069481], [80.28569794, 15.69013882], [80.28542328, 15.69014072], [80.28542328, 15.68957996], [80.28514099, 15.68958473], [80.28514099, 15.68930531], [80.2848587, 15.68931103], [80.2848587, 15.68903065], [80.28457642, 15.68903065], [80.28457642, 15.68875122], [80.28430176, 15.68875122], [80.28430176, 15.68847275], [80.2840271, 15.68847275], [80.2840271, 15.68818092], [80.28375244, 15.68819523], [80.28375244, 15.68791676], [80.28347015, 15.68792057], [80.28347015, 15.68735981], [80.2831955, 15.68735981], [80.2831955, 15.68708229], [80.28291321, 15.68708229], [80.28291321, 15.68624973], [80.28263855, 15.68624973], [80.28263855, 15.68597031], [80.28236389, 15.68597221], [80.28236389, 15.68569374], [80.2820816, 15.68569374], [80.2820816, 15.68541622], [80.28180695, 15.68541622], [80.28180695, 15.68513775], [80.28151703, 15.68514061], [80.28151703, 15.68486023], [80.28125, 15.68486023], [80.28125, 15.68458366], [80.28097534, 15.68458366], [80.28097534, 15.68430424], [80.28069305, 15.68431091], [80.28069305, 15.68403053], [80.2804184, 15.68403053], [80.2804184, 15.68375015], [80.28013611, 15.68375015], [80.28013611, 15.68319035], [80.27986145, 15.68319416], [80.27986145, 15.68291569], [80.27958679, 15.68292141], [80.27958679, 15.68264008], [80.27929688, 15.68264008], [80.27929688, 15.68236923], [80.27902985, 15.68236923], [80.27902985, 15.68208027], [80.2784729, 15.68208408], [80.2784729, 15.68152809], [80.27819824, 15.68153], [80.27819061, 15.68097019], [80.27791595, 15.6809721], [80.27791595, 15.68069363], [80.2776413, 15.68069363], [80.2776413, 15.68041801], [80.27735901, 15.68041992], [80.27735901, 15.67986202], [80.27707672, 15.67986202], [80.27707672, 15.67958164], [80.27680206, 15.67958355], [80.27680206, 15.67930603], [80.2765274, 15.6793108], [80.27648926, 15.67880726], [80.27640533, 15.67875004], [80.27625275, 15.67875195], [80.27625275, 15.67863083], [80.27625275, 15.67847157], [80.27601624, 15.67847157], [80.27513885, 15.67847157], [80.27513885, 15.67819405], [80.2748642, 15.67819405], [80.2748642, 15.67763996], [80.27458191, 15.67763996], [80.27458191, 15.67745972], [80.27458191, 15.67708397], [80.27403259, 15.67708397], [80.27375031, 15.67708397], [80.27375031, 15.67688084], [80.27375031, 15.67652798], [80.27348328, 15.67653179], [80.27348328, 15.67541981], [80.27319336, 15.67541981], [80.27319336, 15.67486191], [80.27263641, 15.67486191], [80.27263641, 15.67458057], [80.2720871, 15.67458439], [80.2720871, 15.67430592], [80.27153015, 15.67430973], [80.27153015, 15.6740303], [80.27124786, 15.6740303], [80.27124786, 15.67375183], [80.27097321, 15.67375183], [80.27097321, 15.67347145], [80.27069092, 15.67347145], [80.27069092, 15.67319584], [80.27041626, 15.67319584], [80.27041626, 15.67263889], [80.2701416, 15.67264175], [80.2701416, 15.67208099], [80.26985931, 15.6720829], [80.26985931, 15.67124939], [80.26957703, 15.67124939], [80.26957703, 15.67043114], [80.26930237, 15.67043114], [80.26930237, 15.67013931], [80.26902771, 15.67013931], [80.26902771, 15.66986084], [80.26875305, 15.66986084], [80.26875305, 15.66930962], [80.26847076, 15.66930962], [80.26847076, 15.66819096], [80.26819611, 15.66819477], [80.26819611, 15.66763878], [80.26790619, 15.66764069], [80.26790619, 15.66737175], [80.26763916, 15.66737175], [80.26763916, 15.66708088], [80.2673645, 15.66708279], [80.2673645, 15.66680527], [80.26708221, 15.66681194], [80.26708221, 15.66653061], [80.26680756, 15.66653061], [80.26680756, 15.66542053], [80.2665329, 15.66542053], [80.2665329, 15.66458035], [80.26625061, 15.66458321], [80.26625061, 15.66430473], [80.26597595, 15.66430473], [80.26597595, 15.66347313], [80.26569366, 15.66347313], [80.26569366, 15.66208267], [80.26541901, 15.66208267], [80.26541901, 15.66152859], [80.26513672, 15.66153145], [80.26513672, 15.66124153], [80.26486206, 15.66125107], [80.26486206, 15.66069508], [80.26457977, 15.66069508], [80.26457977, 15.66041565], [80.26431274, 15.66042137], [80.26431274, 15.66014099], [80.26403046, 15.66014099], [80.26403046, 15.65931129], [80.26374817, 15.65931129], [80.26374817, 15.65903091], [80.26346588, 15.65903091], [80.26346588, 15.65820122], [80.26319122, 15.65820122], [80.26319122, 15.65792084], [80.26291656, 15.65792084], [80.26291656, 15.65596962], [80.26264191, 15.65597153], [80.26264191, 15.65347195], [80.26235962, 15.65347195], [80.26235962, 15.65291595], [80.26209259, 15.65292263], [80.26209259, 15.65236187], [80.26180267, 15.65236187], [80.26180267, 15.65180969], [80.26152802, 15.65180969], [80.26152802, 15.65125179], [80.26125336, 15.65125179], [80.26125336, 15.65069103], [80.26097107, 15.6506958], [80.26097107, 15.65041637], [80.26069641, 15.65042019], [80.26069641, 15.65013981], [80.26040649, 15.65013981], [80.26040649, 15.64958096], [80.26013947, 15.64958382], [80.26013947, 15.64902782], [80.25985718, 15.64902973], [80.25985718, 15.64847183], [80.25958252, 15.64847183], [80.25958252, 15.64791775], [80.25930786, 15.64791965], [80.25930786, 15.64680958], [80.2590332, 15.64680958], [80.2590332, 15.64626122], [80.25874329, 15.64626122], [80.25874329, 15.6459713], [80.25846863, 15.6459713], [80.25846863, 15.64569569], [80.25819397, 15.64569569], [80.25819397, 15.64541531], [80.25791931, 15.64542198], [80.25791931, 15.6451416], [80.25763702, 15.6451416], [80.25763702, 15.64458084], [80.25736237, 15.64458275], [80.25736237, 15.64374924], [80.25708008, 15.64374924], [80.25708008, 15.64319992], [80.25681305, 15.64319992], [80.25681305, 15.64264202], [80.25653076, 15.64264202], [80.25653076, 15.64208126], [80.25624847, 15.64208317], [80.25624847, 15.64152718], [80.25596619, 15.64153194], [80.25596619, 15.64125061], [80.25569916, 15.64125061], [80.25569916, 15.6406908], [80.25541687, 15.64069462], [80.25541687, 15.63986111], [80.25514221, 15.63986111], [80.25514221, 15.63958263], [80.25485992, 15.63958263], [80.25485992, 15.63875103], [80.2545929, 15.63875103], [80.2545929, 15.63847065], [80.25430298, 15.63847256], [80.25430298, 15.63819504], [80.25402832, 15.63819504], [80.25402832, 15.63736057], [80.25375366, 15.63736057], [80.25375366, 15.63680458], [80.25347137, 15.63680935], [80.25347137, 15.63653088], [80.25319672, 15.63653088], [80.25319672, 15.63625145], [80.2529068, 15.63625145], [80.2529068, 15.63597012], [80.25263977, 15.63597298], [80.25263977, 15.63569546], [80.25235748, 15.63569546], [80.25235748, 15.63513947], [80.25208282, 15.63514137], [80.25208282, 15.63457966], [80.25180817, 15.63458157], [80.25180817, 15.63430691], [80.25152588, 15.63432026], [80.25152588, 15.63375092], [80.25125122, 15.63375092], [80.25125122, 15.63320065], [80.25096893, 15.63319016], [80.25096893, 15.63263798], [80.25068665, 15.63264084], [80.25068665, 15.63208008], [80.25041962, 15.63208199], [80.25041962, 15.63125038], [80.25013733, 15.63126183], [80.25013733, 15.63068962], [80.24986267, 15.63069439], [80.24986267, 15.6301403], [80.24957275, 15.6301403], [80.24957275, 15.62957954], [80.24930573, 15.62958431], [80.24930573, 15.62874985], [80.24903107, 15.62874985], [80.24903107, 15.62820053], [80.24874878, 15.62820053], [80.24874878, 15.62764263], [80.24846649, 15.62764263], [80.24846649, 15.62736034], [80.24819183, 15.62736225], [80.24819183, 15.62680626], [80.24791718, 15.62681103], [80.24791718, 15.62652969], [80.24764252, 15.62652969], [80.24764252, 15.62597179], [80.24736023, 15.62597179], [80.24736023, 15.62513065], [80.24708557, 15.62514019], [80.24708557, 15.6245842], [80.24680328, 15.6245842], [80.24680328, 15.62374973], [80.24652863, 15.62374973], [80.24652863, 15.62292004], [80.24624634, 15.62292004], [80.24624634, 15.62263966], [80.24597168, 15.62263966], [80.24597168, 15.62207031], [80.24569702, 15.62208366], [80.24569702, 15.62152767], [80.2454071, 15.62152958], [80.2454071, 15.62042046], [80.24514008, 15.62042046], [80.24514008, 15.6198616], [80.24485779, 15.6198616], [80.24485779, 15.61932087], [80.24458313, 15.61932087], [80.24458313, 15.61875153], [80.24430847, 15.61875153], [80.24430847, 15.61819077], [80.24402618, 15.61819458], [80.24402618, 15.61763859], [80.24375916, 15.61763859], [80.24375916, 15.61681175], [80.24346924, 15.61681175], [80.24346924, 15.61626053], [80.24318695, 15.61626053], [80.24318695, 15.61542034], [80.24291992, 15.61542034], [80.24291992, 15.61458111], [80.24263763, 15.61458302], [80.24263763, 15.61402702], [80.24236298, 15.61403179], [80.24236298, 15.61347103], [80.24208069, 15.61347103], [80.24208069, 15.61263943], [80.24180603, 15.61264133], [80.24180603, 15.61181164], [80.24153137, 15.61181164], [80.24153137, 15.61125088], [80.24124908, 15.61125088], [80.24124908, 15.61042118], [80.2409668, 15.61042118], [80.2409668, 15.60958004], [80.24069214, 15.6095829], [80.24069214, 15.60902882], [80.24041748, 15.60903072], [80.24041748, 15.60818958], [80.24013519, 15.6081953], [80.24013519, 15.60763931], [80.23986053, 15.60764122], [80.23986053, 15.60681057], [80.23958588, 15.60681057], [80.23958588, 15.60569], [80.23930359, 15.60569382], [80.23930359, 15.60513783], [80.23902893, 15.60514069], [80.23902893, 15.60457993], [80.23874664, 15.60458374], [80.23874664, 15.60235977], [80.23847198, 15.60235977], [80.23847198, 15.60208035], [80.23819733, 15.60208416], [80.23819733, 15.60180569], [80.23792267, 15.60181141], [80.23792267, 15.60141182], [80.23791504, 15.60124969], [80.23763275, 15.60124969], [80.23763275, 15.60096073], [80.23735809, 15.60097218], [80.23735809, 15.59958363], [80.23708344, 15.59958363], [80.23708344, 15.59791565], [80.23680878, 15.59792042], [80.23680878, 15.59652996], [80.23652649, 15.59652996], [80.23652649, 15.59486198], [80.23625183, 15.59486198], [80.23625183, 15.59403038], [80.23596954, 15.59403038], [80.23596954, 15.5929203], [80.23568726, 15.5929203], [80.23568726, 15.59208965], [80.23542023, 15.59208965], [80.23542023, 15.59097099], [80.23513794, 15.59097099], [80.23513794, 15.59013939], [80.23486328, 15.59013939], [80.23486328, 15.58902264], [80.23458099, 15.5890274], [80.23458099, 15.58819485], [80.23430634, 15.58819485], [80.23430634, 15.58708286], [80.23402405, 15.58708286], [80.23402405, 15.58625126], [80.23374939, 15.58625126], [80.23374939, 15.58514118], [80.2334671, 15.58514118], [80.2334671, 15.58431244], [80.23319244, 15.58431244], [80.23319244, 15.58318996], [80.23291779, 15.58319473], [80.23291779, 15.58208275], [80.2326355, 15.58208275], [80.2326355, 15.58097267], [80.23236084, 15.58097267], [80.23236084, 15.58013821], [80.23208618, 15.58014965], [80.23208618, 15.57874966], [80.23179626, 15.57874966], [80.23179626, 15.57792091], [80.23152924, 15.57792091], [80.23152924, 15.57653141], [80.23124695, 15.57653141], [80.23124695, 15.57542133], [80.23097229, 15.57542133], [80.23097229, 15.57458019], [80.23069763, 15.5745821], [80.23069763, 15.57347202], [80.23041534, 15.57347202], [80.23041534, 15.57236195], [80.23014069, 15.57236195], [80.23014069, 15.57153034], [80.2298584, 15.57153034], [80.2298584, 15.57042027], [80.22957611, 15.57042027], [80.22957611, 15.56931019], [80.22930908, 15.56931019], [80.22930908, 15.56653023], [80.22902679, 15.56653023], [80.22902679, 15.56514168], [80.22875977, 15.56514168], [80.22875977, 15.56458092], [80.22846985, 15.56458282], [80.22846985, 15.56291676], [80.22820282, 15.56291962], [80.22820282, 15.56208134], [80.2279129, 15.56208324], [80.2279129, 15.56097317], [80.22763824, 15.56097317], [80.22763824, 15.56041718], [80.22735596, 15.56042194], [80.22735596, 15.56014061], [80.2270813, 15.56014061], [80.2270813, 15.55904102], [80.22680664, 15.55904102], [80.22680664, 15.55792141], [80.22651672, 15.55792141], [80.22651672, 15.55568981], [80.22624969, 15.55569458], [80.22624969, 15.55486107], [80.22597504, 15.55486107], [80.22597504, 15.553195], [80.22624969, 15.553195], [80.22624969, 15.55263805], [80.22651672, 15.55264091], [80.22651672, 15.55208015], [80.22680664, 15.55208206], [80.22680664, 15.5518074], [80.2270813, 15.55181122], [80.2270813, 15.55097008], [80.22736359, 15.55097198], [80.22736359, 15.55013847], [80.22763824, 15.55014133], [80.22763824, 15.54846954], [80.22736359, 15.5484724], [80.22736359, 15.54791641], [80.2270813, 15.54792118], [80.2270813, 15.54708195], [80.22736359, 15.54708195], [80.22736359, 15.54569435], [80.22763824, 15.54569435], [80.22763824, 15.54208374], [80.22736359, 15.54208374], [80.22736359, 15.54180622], [80.2270813, 15.54181004], [80.2270813, 15.54125023], [80.22680664, 15.54125023], [80.22680664, 15.54069138], [80.22652435, 15.54069328], [80.22652435, 15.54041767], [80.22624969, 15.54041958], [80.22624969, 15.5395813], [80.22597504, 15.53958416], [80.22597504, 15.53902721], [80.22569275, 15.53903198], [80.22569275, 15.53847122], [80.22541809, 15.53847122], [80.22541809, 15.53791714], [80.2251358, 15.53791714], [80.2251358, 15.53763866], [80.22486115, 15.53763866], [80.22486115, 15.53347111], [80.2251358, 15.53347301], [80.2251358, 15.53236103], [80.22486115, 15.53236103], [80.22486115, 15.53208065], [80.22458649, 15.53208256], [80.22458649, 15.53180504], [80.22429657, 15.53181171], [80.22429657, 15.53153133], [80.22402954, 15.53153133], [80.22402954, 15.53097057], [80.22374725, 15.53097343], [80.22374725, 15.53041744], [80.2234726, 15.53042126], [80.2234726, 15.53014088], [80.22319794, 15.53014088], [80.22319794, 15.52958012], [80.22291565, 15.52958298], [80.22291565, 15.52930546], [80.22263336, 15.52930927], [80.22263336, 15.52875137], [80.2223587, 15.52875137], [80.2223587, 15.52818966], [80.22208405, 15.52819538], [80.22208405, 15.52791691], [80.22180176, 15.52792072], [80.22180176, 15.52736092], [80.2215271, 15.52736092], [80.2215271, 15.52681065], [80.22125244, 15.52681065], [80.22125244, 15.52597046], [80.22097015, 15.52597332], [80.22097015, 15.52569389], [80.2206955, 15.52569389], [80.2206955, 15.52486038], [80.22041321, 15.52486038], [80.22041321, 15.52402782], [80.22013855, 15.52403069], [80.22013855, 15.52318954], [80.21986389, 15.52319431], [80.21986389, 15.52291584], [80.21958923, 15.52293015], [80.21958923, 15.52264023], [80.21930695, 15.52264023], [80.21930695, 15.52208042], [80.21902466, 15.52208424], [80.21902466, 15.52124977], [80.21875, 15.52124977], [80.21875, 15.52097034], [80.21847534, 15.52097225], [80.21847534, 15.52069378], [80.21819305, 15.52069378], [80.21819305, 15.52041626], [80.2179184, 15.52042103], [80.2179184, 15.51987076], [80.21763611, 15.51987076], [80.21763611, 15.51902962], [80.21736145, 15.51902962], [80.21736145, 15.51846981], [80.21708679, 15.51847172], [80.21708679, 15.51791573], [80.21679688, 15.51791954], [80.21679688, 15.51764011], [80.21652985, 15.51764011], [80.21652985, 15.51707935], [80.21624756, 15.51708412], [80.21624756, 15.51680565], [80.2159729, 15.51681042], [80.2159729, 15.51653004], [80.21569824, 15.51653004], [80.21569061, 15.51596928], [80.21541595, 15.51597214], [80.21541595, 15.51541805], [80.21569061, 15.51541996], [80.21569061, 15.51373959], [80.21541595, 15.51375008], [80.21541595, 15.51347065], [80.2151413, 15.51347065], [80.2151413, 15.51319313], [80.21485901, 15.51319313], [80.21485901, 15.51291847], [80.21457672, 15.51292038], [80.21457672, 15.51264191], [80.21430206, 15.51264191], [80.21430206, 15.51236153], [80.2140274, 15.51236153], [80.2140274, 15.51208305], [80.21375275, 15.51208305], [80.21375275, 15.51180458], [80.21346283, 15.5118103], [80.21346283, 15.51153183], [80.2131958, 15.51153183], [80.2131958, 15.51097107], [80.21291351, 15.51097107], [80.21291351, 15.50986099], [80.2131958, 15.50986099], [80.2131958, 15.50930977], [80.2140274, 15.509305], [80.2140274, 15.50958347], [80.21485901, 15.50958347], [80.21485901, 15.5084734], [80.21458435, 15.5084734], [80.21458435, 15.5079174], [80.21430206, 15.50793076], [80.21430206, 15.50681019], [80.2140274, 15.50681019], [80.2140274, 15.50569057], [80.21375275, 15.50569534], [80.21375275, 15.50513935], [80.21346283, 15.50514126], [80.21346283, 15.50458145], [80.2131958, 15.50458336], [80.2131958, 15.5037508], [80.21290588, 15.5037508], [80.21290588, 15.50264072], [80.21263885, 15.50264072], [80.21263885, 15.5023613], [80.21208191, 15.5023613], [80.21208191, 15.50264072], [80.21125031, 15.50264072], [80.21125031, 15.5029192], [80.21097565, 15.50291729], [80.21097565, 15.50319481], [80.21069336, 15.50319481], [80.21069336, 15.50347328], [80.2104187, 15.50347137], [80.2104187, 15.5037508], [80.21013641, 15.5037508], [80.21013641, 15.50431156], [80.2104187, 15.50430489], [80.2104187, 15.50458336], [80.21069336, 15.50458145], [80.21069336, 15.50487041], [80.2104187, 15.50487041], [80.2104187, 15.50514126], [80.20986176, 15.50514126], [80.20986176, 15.50542164], [80.20903015, 15.50542164], [80.20903015, 15.50514126], [80.20874786, 15.50514126], [80.20874786, 15.50487041], [80.20847321, 15.50487041], [80.20847321, 15.50458145], [80.20819092, 15.50458336], [80.20819092, 15.50430489], [80.20791626, 15.50431156], [80.20791626, 15.5037508], [80.2076416, 15.5037508], [80.2076416, 15.50347328], [80.20735931, 15.50347328], [80.20735931, 15.50319481], [80.20708466, 15.50319481], [80.20708466, 15.50291729], [80.20680237, 15.5029192], [80.20680237, 15.5023613], [80.20652771, 15.5023613], [80.20652771, 15.50180531], [80.20625305, 15.50180531], [80.20625305, 15.50097275], [80.20597076, 15.50097275], [80.20597076, 15.50042057], [80.20513916, 15.50042057], [80.20513916, 15.50014114], [80.20430756, 15.50014114], [80.20430756, 15.49985981], [80.20347595, 15.49985981], [80.20347595, 15.49931145], [80.2040329, 15.49931145], [80.2040329, 15.49903107], [80.20430756, 15.49903107], [80.20430756, 15.49847031], [80.20402527, 15.49847221], [80.20402527, 15.49819374], [80.20347595, 15.49819374], [80.20347595, 15.49791622], [80.20291901, 15.49791622], [80.20291901, 15.49819374], [80.20263672, 15.49819374], [80.20263672, 15.49847221], [80.20236206, 15.49847221], [80.20236206, 15.49875069], [80.20124817, 15.49875069], [80.20124817, 15.49847221], [80.20097351, 15.49847221], [80.20097351, 15.49819374], [80.20041656, 15.49819374], [80.20041656, 15.49736023], [80.20069122, 15.49736023], [80.20069122, 15.49708462], [80.20097351, 15.49708462], [80.20097351, 15.49625015], [80.20069122, 15.49625015], [80.20069122, 15.49570084], [80.20041656, 15.49570084], [80.20041656, 15.49542141], [80.20014191, 15.49542141], [80.20014191, 15.49514008], [80.20041656, 15.49514008], [80.20041656, 15.4948597], [80.20124817, 15.4948597], [80.20124817, 15.49514008], [80.20181274, 15.49514008], [80.20181274, 15.49542141], [80.20847321, 15.49542141], [80.20847321, 15.49514008], [80.2104187, 15.49514008], [80.2104187, 15.49542141], [80.21098328, 15.49542141], [80.21098328, 15.49570084], [80.21125031, 15.49569416], [80.21125031, 15.49597168], [80.21152496, 15.49597168], [80.21152496, 15.49569416], [80.21180725, 15.49570084], [80.21180725, 15.49514008], [80.21153259, 15.49514008], [80.21153259, 15.49431133], [80.21125031, 15.49431133], [80.21125031, 15.49403], [80.21098328, 15.49403], [80.21098328, 15.49236202], [80.21069336, 15.49236202], [80.21069336, 15.49208164], [80.2104187, 15.49208355], [80.2104187, 15.49069405], [80.21013641, 15.49069405], [80.21013641, 15.48958397], [80.20986176, 15.48958397], [80.20986176, 15.48902798], [80.2095871, 15.48903179], [80.2095871, 15.48764038], [80.20929718, 15.48764038], [80.20929718, 15.48736191], [80.20903015, 15.48736191], [80.20903015, 15.48514175], [80.20874786, 15.48514175], [80.20874786, 15.48458099], [80.20847321, 15.4845829], [80.20847321, 15.48374939], [80.20819092, 15.48376083], [80.20819092, 15.48208141], [80.20791626, 15.48208332], [80.20791626, 15.48069477], [80.20764923, 15.48069954], [80.20764923, 15.47958088], [80.20735931, 15.47958279], [80.20735931, 15.47902679], [80.20707703, 15.47903061], [80.20707703, 15.4784708], [80.20680237, 15.4784708], [80.20680237, 15.47819519], [80.20652771, 15.47819519], [80.20652771, 15.47736073], [80.20625305, 15.47736073], [80.20625305, 15.47681236], [80.20597076, 15.47681236], [80.20597076, 15.47625065], [80.20569611, 15.47625065], [80.20569611, 15.47486115], [80.20541382, 15.47486115], [80.20541382, 15.47458267], [80.20513916, 15.47458267], [80.20513916, 15.47430515], [80.20485687, 15.47431087], [80.20485687, 15.47403145], [80.20458984, 15.47403145], [80.20458984, 15.47346973], [80.20430756, 15.4734726], [80.20430756, 15.47235966], [80.20402527, 15.47235966], [80.20402527, 15.47180653], [80.20375061, 15.47182274], [80.20375061, 15.47153091], [80.20347595, 15.47153091], [80.20347595, 15.47125053], [80.20318604, 15.47125053], [80.20318604, 15.47068977], [80.20291901, 15.47069359], [80.20291901, 15.47041607], [80.20263672, 15.47042084], [80.20263672, 15.4695797], [80.20236206, 15.46958447], [80.20236206, 15.46930599], [80.20207977, 15.46931076], [80.20207977, 15.46875858], [80.20181274, 15.46875858], [80.20181274, 15.46819019], [80.20153046, 15.46819401], [80.20153046, 15.46791553], [80.20124817, 15.46792126], [80.20124817, 15.46652985], [80.20096588, 15.46652985], [80.20096588, 15.46597195], [80.20069122, 15.46597195], [80.20069122, 15.46541595], [80.20041656, 15.46542263], [80.20041656, 15.46514034], [80.20014191, 15.46514034], [80.20014191, 15.46485996], [80.19985962, 15.46485996], [80.19985962, 15.46457863], [80.19958496, 15.46458435], [80.19958496, 15.46402836], [80.19930267, 15.46403027], [80.19930267, 15.46375179], [80.19902802, 15.46375179], [80.19902802, 15.46319103], [80.19875336, 15.46319389], [80.19875336, 15.46291637], [80.19845581, 15.46292019], [80.19845581, 15.46263123], [80.19819641, 15.46263981], [80.19819641, 15.46236229], [80.19791412, 15.46236229], [80.19791412, 15.4618063], [80.19763947, 15.46181011], [80.19763947, 15.46152973], [80.19735718, 15.46152973], [80.19735718, 15.46097183], [80.19708252, 15.46097183], [80.19708252, 15.46069431], [80.19680786, 15.46069431], [80.19680786, 15.46014023], [80.1965332, 15.46014023], [80.1965332, 15.45986176], [80.19625092, 15.45986176], [80.19625092, 15.45930958], [80.19596863, 15.45930958], [80.19596863, 15.45903015], [80.19568634, 15.45903015], [80.19568634, 15.45875168], [80.19541931, 15.45875168], [80.19541931, 15.4584713], [80.19513702, 15.4584713], [80.19513702, 15.45763969], [80.19486237, 15.4576416], [80.19486237, 15.45735931], [80.19458008, 15.45736122], [80.19458008, 15.45680523], [80.19431305, 15.45682144], [80.19431305, 15.45652962], [80.19403076, 15.45652962], [80.19403076, 15.45624924], [80.19374847, 15.45624924], [80.19374847, 15.45597076], [80.19347382, 15.45597267], [80.19347382, 15.45541668], [80.19319153, 15.45541954], [80.19319153, 15.45514202], [80.19291687, 15.45514202], [80.19291687, 15.45458126], [80.19264221, 15.45458317], [80.19264221, 15.4543047], [80.19235992, 15.45431042], [80.19235992, 15.45403194], [80.1920929, 15.45403194], [80.1920929, 15.45375061], [80.19180298, 15.45375061], [80.19180298, 15.45347118], [80.19152832, 15.45347309], [80.19152832, 15.4529171], [80.19124603, 15.45292187], [80.19124603, 15.45264053], [80.19097137, 15.45264053], [80.19097137, 15.45236111], [80.19069672, 15.45236111], [80.19069672, 15.45208263], [80.19041443, 15.45208263], [80.19041443, 15.45180511], [80.19013977, 15.45181179], [80.19013977, 15.45097065], [80.18985748, 15.45097256], [80.18985748, 15.45069504], [80.18930817, 15.45069504], [80.18930817, 15.45041656], [80.18875122, 15.45042133], [80.18875122, 15.45014095], [80.18846893, 15.45014095], [80.18846893, 15.44986057], [80.18819427, 15.44986057], [80.18819427, 15.44930458], [80.18791962, 15.44930935], [80.18791962, 15.44903088], [80.18763733, 15.44903088], [80.18763733, 15.44818974], [80.18736267, 15.44819546], [80.18736267, 15.44791698], [80.18708038, 15.4479208], [80.18708038, 15.44736099], [80.18651581, 15.44736099], [80.18651581, 15.44707966], [80.18624878, 15.44708347], [80.18624878, 15.44680691], [80.18596649, 15.44681072], [80.18596649, 15.4465313], [80.18569183, 15.4465313], [80.18569183, 15.44625092], [80.18541718, 15.44625092], [80.18541718, 15.44596958], [80.18514252, 15.4459734], [80.18514252, 15.44541645], [80.18486023, 15.44542122], [80.18486023, 15.44514084], [80.1845932, 15.44514084], [80.1845932, 15.44459057], [80.18430328, 15.44459057], [80.18430328, 15.44431114], [80.18402863, 15.44431114], [80.18402863, 15.44403076], [80.18374634, 15.44403076], [80.18374634, 15.44347], [80.18347168, 15.44347191], [80.18347168, 15.44319439], [80.18319702, 15.44319439], [80.18319702, 15.44291592], [80.1829071, 15.44292068], [80.1829071, 15.44235992], [80.18264008, 15.44235992], [80.18264008, 15.44207954], [80.18235779, 15.44208431], [80.18235779, 15.44180584], [80.18208313, 15.44181061], [80.18208313, 15.44152069], [80.18180847, 15.44152832], [80.18180847, 15.44124985], [80.18152618, 15.44125271], [80.18152618, 15.44069195], [80.18125153, 15.44069386], [80.18125153, 15.44041634], [80.18096924, 15.4404211], [80.18096924, 15.44013977], [80.18068695, 15.44013977], [80.18068695, 15.43986034], [80.18041992, 15.43986225], [80.18041992, 15.43958378], [80.18013763, 15.43958378], [80.18013763, 15.43930626], [80.17986298, 15.43931103], [80.17986298, 15.43875027], [80.17958069, 15.43875027], [80.17958069, 15.4384613], [80.17930603, 15.43847179], [80.17930603, 15.43819427], [80.17903137, 15.43819427], [80.17903137, 15.4379158], [80.17874908, 15.43791962], [80.17874908, 15.43764019], [80.1784668, 15.43764019], [80.1784668, 15.43707943], [80.17819214, 15.4370842], [80.17819214, 15.43680573], [80.17791748, 15.43680954], [80.17791748, 15.43653011], [80.17764282, 15.43653011], [80.17764282, 15.43624973], [80.17736053, 15.43624973], [80.17736053, 15.43596935], [80.17708588, 15.43597221], [80.17708588, 15.43569374], [80.17680359, 15.43569374], [80.17680359, 15.43513775], [80.17652893, 15.43513966], [80.17652893, 15.43486023], [80.17624664, 15.43486214], [80.17624664, 15.43458366], [80.17597198, 15.43458366], [80.17597198, 15.43430614], [80.17569733, 15.43430996], [80.17569733, 15.43402958], [80.17542267, 15.43402958], [80.17542267, 15.43375015], [80.17514038, 15.43375015], [80.17514038, 15.43347168], [80.17485809, 15.43347168], [80.17485809, 15.43291759], [80.17457581, 15.43292046], [80.17457581, 15.43265057], [80.17430878, 15.43265057], [80.17430878, 15.4323616], [80.17402649, 15.4323616], [80.17402649, 15.43208122], [80.17319489, 15.43208408], [80.17319489, 15.43180561], [80.17292023, 15.43181038], [80.17292023, 15.43125153], [80.17263794, 15.43125153], [80.17263794, 15.43069077], [80.17208099, 15.43069553], [80.17208099, 15.43041801], [80.17180634, 15.43041992], [80.17180634, 15.43013859], [80.17151642, 15.43013859], [80.17151642, 15.42958069], [80.17097473, 15.4295826], [80.17097473, 15.42930508], [80.17069244, 15.42931175], [80.17069244, 15.42903042], [80.17041779, 15.42903042], [80.17041779, 15.42875099], [80.17014313, 15.42875099], [80.17014313, 15.42819118], [80.16958618, 15.42819309], [80.16958618, 15.42763901], [80.16929626, 15.42764187], [80.16929626, 15.42736053], [80.16902924, 15.42736053], [80.16902924, 15.42708302], [80.16874695, 15.42708302], [80.16874695, 15.42652702], [80.16847229, 15.42652702], [80.16847229, 15.42625141], [80.16819763, 15.42625141], [80.16819763, 15.42597103], [80.16791534, 15.42597103], [80.16791534, 15.42569542], [80.1673584, 15.42569542], [80.1673584, 15.42541695], [80.16707611, 15.42542171], [80.16707611, 15.42514133], [80.16652679, 15.42514133], [80.16652679, 15.42458057], [80.16625214, 15.42458344], [80.16625214, 15.42430496], [80.16596985, 15.42431164], [80.16596985, 15.42375088], [80.16570282, 15.42375088], [80.16570282, 15.42319012], [80.1654129, 15.42319489], [80.1654129, 15.42291737], [80.16513824, 15.42291927], [80.16513824, 15.42236137], [80.16486359, 15.42236137], [80.16486359, 15.4220829], [80.1645813, 15.4220829], [80.1645813, 15.42180538], [80.16430664, 15.4218092], [80.16430664, 15.4212513], [80.16374969, 15.4212513], [80.16374969, 15.42096996], [80.16319275, 15.42097282], [80.16319275, 15.42041683], [80.16291809, 15.42042065], [80.16291809, 15.42014122], [80.1626358, 15.42014122], [80.1626358, 15.41986275], [80.16234589, 15.41986275], [80.16234589, 15.41958046], [80.16208649, 15.41958237], [80.16208649, 15.41930676], [80.16179657, 15.41931057], [80.16179657, 15.41903114], [80.16124725, 15.41903114], [80.16124725, 15.41875076], [80.1609726, 15.41875076], [80.1609726, 15.41819], [80.16069794, 15.41819477], [80.16069794, 15.4179163], [80.16042328, 15.41792107], [80.16042328, 15.41764069], [80.16014099, 15.41764069], [80.16014099, 15.41736031], [80.1598587, 15.41736031], [80.1598587, 15.41708469], [80.15958405, 15.41708469], [80.15958405, 15.41680431], [80.1592865, 15.41681099], [80.15930176, 15.4164896], [80.15930176, 15.41625023], [80.15909576, 15.41625023], [80.15875244, 15.41625023], [80.15875244, 15.41596985], [80.15847015, 15.41597176], [80.15847015, 15.41557121], [80.15847015, 15.41541576], [80.15831757, 15.41541862], [80.15820313, 15.41542053], [80.1581955, 15.41529083], [80.1581955, 15.41513824], [80.15805817, 15.41513824], [80.15791321, 15.41514015], [80.15791321, 15.41499043], [80.15791321, 15.41458225], [80.15763855, 15.41458225], [80.15763855, 15.41430569], [80.15735626, 15.41431141], [80.15735626, 15.41374969], [80.1570816, 15.41374969], [80.1570816, 15.41347027], [80.15680695, 15.41347218], [80.15680695, 15.4131937], [80.15652466, 15.4131937], [80.15652466, 15.41291618], [80.15625, 15.41292095], [80.15625, 15.41263962], [80.15598297, 15.41263962], [80.15598297, 15.41208172], [80.15569305, 15.41208363], [80.15569305, 15.41180611], [80.1554184, 15.41181087], [80.1554184, 15.41152096], [80.15513611, 15.41152763], [80.15513611, 15.41125011], [80.15486145, 15.41125011], [80.15486145, 15.41096973], [80.15458679, 15.41097164], [80.15458679, 15.41041565], [80.15402985, 15.41042042], [80.15402985, 15.40985966], [80.15374756, 15.40986156], [80.15374756, 15.40958405], [80.1534729, 15.40958405], [80.1534729, 15.40930557], [80.15319824, 15.40931034], [80.15319061, 15.40902996], [80.15291595, 15.40902996], [80.15291595, 15.40848064], [80.1526413, 15.40848064], [80.1526413, 15.40819073], [80.15235901, 15.40819359], [80.15235901, 15.40791798], [80.15207672, 15.40792179], [80.15207672, 15.40764046], [80.15180206, 15.40764046], [80.15180206, 15.40736198], [80.1515274, 15.40736198], [80.1515274, 15.40708065], [80.15125275, 15.40708447], [80.15125275, 15.40688992], [80.15125275, 15.40652847], [80.15106964, 15.40653038], [80.15097046, 15.40652847], [80.15092468, 15.40630436], [80.15085602, 15.40625], [80.1506958, 15.40625191], [80.1506958, 15.40609169], [80.1506958, 15.40597057], [80.1505661, 15.40597057], [80.15041351, 15.40597057], [80.15041351, 15.40583038], [80.15041351, 15.40569305], [80.15026093, 15.40569305], [80.15013885, 15.40569305], [80.15013885, 15.40557861], [80.15013885, 15.40541458], [80.14996338, 15.4054184], [80.14985657, 15.4054203], [80.14985657, 15.40514183], [80.14965057, 15.40514183], [80.14958191, 15.40458107], [80.14930725, 15.40458393], [80.14930725, 15.40430546], [80.14903259, 15.40431023], [80.14903259, 15.40403175], [80.14875031, 15.40403175], [80.14875031, 15.40374947], [80.14847565, 15.40374947], [80.14847565, 15.40347099], [80.14819336, 15.40347099], [80.14819336, 15.40319633], [80.1479187, 15.40319633], [80.1479187, 15.40263939], [80.14763641, 15.40263939], [80.14763641, 15.40235043], [80.14736176, 15.40236092], [80.14736176, 15.4020834], [80.1470871, 15.4020834], [80.1470871, 15.40180492], [80.14679718, 15.40180969], [80.14679718, 15.40125084], [80.14653015, 15.40125084], [80.14653015, 15.40097141], [80.14624786, 15.40097332], [80.14624786, 15.40069485], [80.14597321, 15.40069485], [80.14597321, 15.40013885], [80.14569092, 15.40014076], [80.14569092, 15.39986134], [80.14541626, 15.39986134], [80.14541626, 15.39958286], [80.1451416, 15.39958286], [80.1451416, 15.39902687], [80.14485931, 15.39903164], [80.14485931, 15.39875126], [80.14457703, 15.39875126], [80.14457703, 15.39847088], [80.14430237, 15.39847088], [80.14430237, 15.39791679], [80.14402771, 15.39792156], [80.14402771, 15.39764118], [80.14375305, 15.39764118], [80.14375305, 15.3973608], [80.14347076, 15.3973608], [80.14347076, 15.39708328], [80.14291382, 15.39708328], [80.14291382, 15.3965292], [80.14263916, 15.39653969], [80.14263916, 15.3959713], [80.1423645, 15.39597321], [80.1423645, 15.39541721], [80.14208221, 15.39542103], [80.14208221, 15.39514065], [80.14180756, 15.39514065], [80.14180756, 15.39486122], [80.14152527, 15.39486122], [80.14152527, 15.39430523], [80.14125061, 15.39431095], [80.14125061, 15.39403057], [80.14097595, 15.39403057], [80.14093781, 15.39349079], [80.14068604, 15.3934803], [80.14065552, 15.39325237], [80.14057159, 15.39319515], [80.14041901, 15.39319515], [80.14041901, 15.39291668], [80.14013672, 15.39292145], [80.14013672, 15.39247036], [80.14013672, 15.39236069], [80.13957977, 15.39236069], [80.13957977, 15.39208031], [80.13930511, 15.39208221], [80.13930511, 15.39152908], [80.13903046, 15.39153099], [80.13903046, 15.39125061], [80.13874817, 15.39125061], [80.13874817, 15.39068985], [80.13847351, 15.39069366], [80.13847351, 15.39041615], [80.13819122, 15.39041615], [80.13819122, 15.39013767], [80.13791656, 15.39014053], [80.13791656, 15.38986015], [80.13764191, 15.38986015], [80.13764191, 15.38930416], [80.13735962, 15.38931084], [80.13735962, 15.38903141], [80.13709259, 15.38903141], [80.13708496, 15.38884163], [80.13708496, 15.38875008], [80.1368866, 15.38875008], [80.13680267, 15.38875008], [80.13680267, 15.38847923], [80.13652802, 15.3884697], [80.13652802, 15.38819408], [80.13625336, 15.38819408], [80.13625336, 15.38763809], [80.13597107, 15.38764], [80.13597107, 15.38735104], [80.13569641, 15.38736153], [80.13569641, 15.3870821], [80.13541412, 15.3870821], [80.13541412, 15.38652802], [80.13513947, 15.38652992], [80.13513947, 15.38624954], [80.13485718, 15.38624954], [80.13485718, 15.38597202], [80.13458252, 15.38597202], [80.13458252, 15.38541603], [80.13430786, 15.3854208], [80.13430786, 15.38514042], [80.1340332, 15.38514042], [80.1340332, 15.38486004], [80.13375092, 15.38486004], [80.13375092, 15.38431072], [80.13346863, 15.38431072], [80.13346863, 15.38403034], [80.13318634, 15.38403034], [80.13318634, 15.38374996], [80.13291931, 15.38374996], [80.13291931, 15.38320065], [80.13263702, 15.3831892], [80.13263702, 15.38291645], [80.13237, 15.38292027], [80.13237, 15.38264179], [80.13208008, 15.38264179], [80.13208008, 15.3821907], [80.13208008, 15.38208389], [80.13197327, 15.38208389], [80.13180542, 15.38208389], [80.13180542, 15.3819313], [80.13180542, 15.38180637], [80.13166809, 15.38180637], [80.13153076, 15.38181019], [80.13153076, 15.38169193], [80.13153076, 15.38125038], [80.13124847, 15.38125038], [80.13124847, 15.38097191], [80.13097382, 15.38097191], [80.13097382, 15.38069439], [80.13069153, 15.38069439], [80.13069153, 15.3801403], [80.13041687, 15.3801403], [80.13041687, 15.37986183], [80.13014221, 15.37986183], [80.13014221, 15.37958145], [80.12985992, 15.37958431], [80.12985992, 15.37902832], [80.12960052, 15.37903023], [80.12960052, 15.37875175], [80.12931061, 15.37875175], [80.12931061, 15.37847137], [80.12902832, 15.37847137], [80.12902832, 15.37791538], [80.12874603, 15.37792015], [80.12874603, 15.37764168], [80.12847137, 15.37764168], [80.12847137, 15.37735939], [80.12819672, 15.37736225], [80.12819672, 15.37680531], [80.1279068, 15.37681007], [80.1279068, 15.37652969], [80.12763977, 15.37652969], [80.12763977, 15.37597084], [80.12735748, 15.37597084], [80.12735748, 15.37569141], [80.12708282, 15.37569332], [80.12708282, 15.37513924], [80.12680817, 15.37513924], [80.12680817, 15.37458134], [80.12652588, 15.37458324], [80.12652588, 15.37430477], [80.12623596, 15.37430954], [80.12623596, 15.37375069], [80.12596893, 15.37375069], [80.12596893, 15.37347126], [80.12569427, 15.37347317], [80.12569427, 15.37291718], [80.12541962, 15.37292194], [80.12541962, 15.37264061], [80.12513733, 15.37264061], [80.12513733, 15.3720808], [80.12486267, 15.37208271], [80.12486267, 15.37152672], [80.12458038, 15.37153053], [80.12458038, 15.37125111], [80.12430573, 15.37125111], [80.12430573, 15.37097263], [80.12403107, 15.37097263], [80.12403107, 15.37013912], [80.12374878, 15.37014103], [80.12374878, 15.36986065], [80.12347412, 15.36986065], [80.12346649, 15.36958122], [80.12319183, 15.36958313], [80.12319183, 15.36902905], [80.12291718, 15.36903095], [80.12291718, 15.36875057], [80.12264252, 15.36875057], [80.12264252, 15.36847115], [80.12236023, 15.36847305], [80.12236023, 15.36791706], [80.1220932, 15.36792088], [80.1220932, 15.36764145], [80.12180328, 15.36764145], [80.12180328, 15.36707973], [80.12152863, 15.3670826], [80.12152863, 15.36652565], [80.12124634, 15.36653137], [80.12124634, 15.36624241], [80.12097168, 15.36625099], [80.12097168, 15.365695], [80.12041473, 15.365695], [80.12041473, 15.36458206], [80.12014008, 15.36458206], [80.12014008, 15.3643074], [80.11985779, 15.36431122], [80.11985779, 15.36375141], [80.11958313, 15.36375141], [80.11958313, 15.36318111], [80.11930847, 15.36319447], [80.11930847, 15.36291599], [80.11902618, 15.36292076], [80.11902618, 15.36236], [80.11875153, 15.36236], [80.11875153, 15.36181068], [80.11846924, 15.36181068], [80.11846924, 15.36153126], [80.11818695, 15.36153126], [80.11818695, 15.36096954], [80.11791992, 15.3609724], [80.11791992, 15.36069393], [80.11763763, 15.36069393], [80.11763763, 15.36013794], [80.11737061, 15.36014271], [80.11737061, 15.35958195], [80.11708069, 15.35958195], [80.11708069, 15.35930634], [80.11680603, 15.3593111], [80.11680603, 15.35875034], [80.11653137, 15.35875034], [80.11653137, 15.35818863], [80.11624908, 15.35819435], [80.11624908, 15.35764027], [80.1159668, 15.35764027], [80.1159668, 15.35707855], [80.11569214, 15.35708427], [80.11569214, 15.35652828], [80.11541748, 15.35653019], [80.11541748, 15.35597038], [80.11513519, 15.35597229], [80.11513519, 15.3554163], [80.11486053, 15.35542011], [80.11486053, 15.35486031], [80.11458588, 15.35486221], [80.11458588, 15.35430622], [80.11430359, 15.35430622], [80.11430359, 15.35375023], [80.11402893, 15.35375023], [80.11402893, 15.35319138], [80.11374664, 15.35319424], [80.11374664, 15.35291767], [80.11347198, 15.35291958], [80.11347198, 15.35236168], [80.11319733, 15.35236168], [80.11319733, 15.35181046], [80.11292267, 15.35181046], [80.11292267, 15.35124016], [80.11264038, 15.35124874], [80.11264038, 15.35069561], [80.11235809, 15.35069561], [80.11235809, 15.35013962], [80.11207581, 15.35013962], [80.11207581, 15.34958076], [80.11180878, 15.34958267], [80.11180878, 15.34902668], [80.11152649, 15.34902954], [80.11152649, 15.34875202], [80.11123657, 15.34875202], [80.11123657, 15.34792042], [80.11096954, 15.34792042], [80.11096954, 15.34736061], [80.11069489, 15.34736061], [80.11069489, 15.34680462], [80.11042023, 15.34681034], [80.11042023, 15.34625053], [80.11013794, 15.34625053], [80.11013794, 15.34543133], [80.10986328, 15.34543133], [80.10986328, 15.34486103], [80.10958099, 15.34486103], [80.10958099, 15.34403133], [80.10930634, 15.34403133], [80.10930634, 15.34347057], [80.10902405, 15.34347343], [80.10902405, 15.34263897], [80.10874939, 15.34264088], [80.10874939, 15.34208012], [80.10847473, 15.34208298], [80.10847473, 15.34125137], [80.10819244, 15.34125137], [80.10819244, 15.34069538], [80.10791779, 15.34069538], [80.10791779, 15.33986092], [80.1076355, 15.33986092], [80.1076355, 15.33930683], [80.10736084, 15.33930683], [80.10736084, 15.33847332], [80.10708618, 15.33847332], [80.10708618, 15.33736038], [80.10680389, 15.33736038], [80.10680389, 15.33652878], [80.10652924, 15.33653069], [80.10652924, 15.33568954], [80.10624695, 15.33569431], [80.10624695, 15.33458424], [80.10597229, 15.33458424], [80.10597229, 15.33374977], [80.10569763, 15.33374977], [80.10569763, 15.33347034], [80.10541534, 15.33347225], [80.10541534, 15.33180618], [80.10514069, 15.33181095], [80.10514069, 15.32931042], [80.1054306, 15.32931042], [80.1054306, 15.32791996], [80.10514069, 15.32791996], [80.10514069, 15.32736015], [80.1048584, 15.32736206], [80.1048584, 15.32708359], [80.10458374, 15.32708359], [80.10458374, 15.32680607], [80.10430908, 15.32681274], [80.10430908, 15.32653046], [80.10402679, 15.32653046], [80.10402679, 15.32625198], [80.10375214, 15.32625198], [80.10375214, 15.3259716], [80.10346985, 15.3259716], [80.10346985, 15.32569408], [80.10319519, 15.32569408], [80.10319519, 15.32541466], [80.10263824, 15.32542038], [80.10263824, 15.32486153], [80.10236359, 15.32486153], [80.10236359, 15.32458401], [80.10097504, 15.32458401], [80.10097504, 15.32486153], [80.1001358, 15.32486153], [80.1001358, 15.32514191], [80.09929657, 15.32514191], [80.09929657, 15.32486153], [80.09902954, 15.32486153], [80.09902954, 15.32402706], [80.09929657, 15.32403183], [80.09929657, 15.32374859], [80.09958649, 15.32374859], [80.09958649, 15.32347107], [80.09986115, 15.32347107], [80.09986115, 15.32319641], [80.10041809, 15.32319641], [80.10041809, 15.32263947], [80.10069275, 15.32263947], [80.10069275, 15.32208061], [80.10097504, 15.32208347], [80.10097504, 15.32124901], [80.10124969, 15.32126141], [80.10124969, 15.31958103], [80.10097504, 15.31958294], [80.10097504, 15.31930542], [80.10124969, 15.31931019], [80.10124969, 15.31903172], [80.10098267, 15.31903172], [80.10098267, 15.31820202], [80.10069275, 15.31820202], [80.10069275, 15.31792164], [80.10041809, 15.31792164], [80.10041809, 15.31736088], [80.1001358, 15.31736088], [80.1001358, 15.31708145], [80.09986115, 15.31708336], [80.09986115, 15.31652737], [80.09958649, 15.31652927], [80.09958649, 15.31624889], [80.09929657, 15.31624889], [80.09929657, 15.31569004], [80.09902954, 15.31569481], [80.09902954, 15.31541729], [80.09874725, 15.3154192], [80.09874725, 15.31513023], [80.0984726, 15.31513882], [80.0984726, 15.3148613], [80.09819794, 15.3148613], [80.09819794, 15.31430531], [80.09792328, 15.31431103], [80.09792328, 15.31403065], [80.09764099, 15.31403065], [80.09764099, 15.31375122], [80.09707642, 15.31375122], [80.09707642, 15.31347275], [80.09625244, 15.31347275], [80.09625244, 15.31319523], [80.0956955, 15.31319523], [80.09570313, 15.31347275], [80.09430695, 15.31347275], [80.09430695, 15.31375122], [80.09401703, 15.31375122], [80.09401703, 15.31403065], [80.09208679, 15.31403065], [80.09208679, 15.31431103], [80.0894928, 15.31430912], [80.08875275, 15.31431103], [80.08875275, 15.31403065], [80.08790588, 15.31403065], [80.08790588, 15.31431103], [80.0873642, 15.31430531], [80.0873642, 15.31458282], [80.08597565, 15.31458282], [80.08597565, 15.3148613], [80.0854187, 15.3148613], [80.0854187, 15.31513882], [80.08374786, 15.31513023], [80.08374786, 15.3154192], [80.08347321, 15.31541729], [80.08347321, 15.31569481], [80.0826416, 15.31569481], [80.0826416, 15.31597328], [80.08125305, 15.31597328], [80.08126068, 15.31624889], [80.08013916, 15.31624889], [80.08013916, 15.31597137], [80.0798645, 15.31597328], [80.0798645, 15.31569481], [80.08013916, 15.31569481], [80.08013916, 15.31541729], [80.08040619, 15.3154192], [80.08040619, 15.31513023], [80.08125305, 15.31513882], [80.08125305, 15.31458282], [80.08152771, 15.31458282], [80.08152771, 15.31430531], [80.08235931, 15.31431103], [80.08235931, 15.31403065], [80.08291626, 15.31403065], [80.08291626, 15.31375122], [80.08319092, 15.31375122], [80.08319092, 15.31347275], [80.08374786, 15.31347275], [80.08374786, 15.31319046], [80.08430481, 15.31319523], [80.08430481, 15.31291676], [80.08513641, 15.31292057], [80.08513641, 15.31264114], [80.08598328, 15.31264114], [80.08598328, 15.31236076], [80.08708191, 15.31236076], [80.08706665, 15.31207085], [80.0881958, 15.31208324], [80.0881958, 15.31180668], [80.08885193, 15.31180668], [80.0890274, 15.31181145], [80.0890274, 15.31153107], [80.08985901, 15.31153107], [80.08985901, 15.31125069], [80.09069061, 15.31125069], [80.09069824, 15.31097031], [80.09236145, 15.31097317], [80.09236145, 15.31069469], [80.09375, 15.31069469], [80.09375, 15.31041622], [80.09485626, 15.31042099], [80.09485626, 15.31014061], [80.09597015, 15.31014061], [80.09597015, 15.30986023], [80.09764099, 15.30986023], [80.09764099, 15.31014061], [80.09902954, 15.31014061], [80.09902954, 15.30986023], [80.0993042, 15.30986023], [80.0993042, 15.30958462], [80.09902954, 15.30958462], [80.09902954, 15.30930424], [80.09874725, 15.30932045], [80.09874725, 15.30903053], [80.0984726, 15.30903053], [80.0984726, 15.30846977], [80.09819794, 15.30847168], [80.09819794, 15.30791569], [80.09792328, 15.30792141], [80.09792328, 15.30764008], [80.09764099, 15.30764008], [80.09764099, 15.3073597], [80.0973587, 15.3073597], [80.0973587, 15.30708027], [80.09708405, 15.30708218], [80.09708405, 15.30624962], [80.09680176, 15.30626202], [80.09680176, 15.30568981], [80.0965271, 15.30569363], [80.0965271, 15.30513763], [80.09626007, 15.30513954], [80.09626007, 15.30403042], [80.09597015, 15.30403042], [80.09597015, 15.30375004], [80.09570313, 15.30375004], [80.09570313, 15.30318928], [80.09541321, 15.30319405], [80.09541321, 15.30236244], [80.09513855, 15.30236244], [80.09513855, 15.30152798], [80.09485626, 15.30153179], [80.09485626, 15.30097198], [80.0945816, 15.30097198], [80.0945816, 15.30069447], [80.09430695, 15.30069447], [80.09430695, 15.30013847], [80.09402466, 15.30013847], [80.09402466, 15.29986191], [80.09375, 15.29986191], [80.09375, 15.29930973], [80.0934906, 15.29930973], [80.0934906, 15.2990303], [80.09320068, 15.2990303], [80.09320068, 15.29819107], [80.0929184, 15.29819584], [80.0929184, 15.29736233], [80.09263611, 15.29736233], [80.09263611, 15.29680538], [80.09236145, 15.29681015], [80.09236145, 15.29624939], [80.09208679, 15.29624939], [80.09208679, 15.29541969], [80.09179688, 15.29541969], [80.09179688, 15.29486084], [80.09152985, 15.29486084], [80.09152985, 15.29430962], [80.09124756, 15.29430962], [80.09124756, 15.29375076], [80.0909729, 15.29375076], [80.0909729, 15.29264069], [80.09069824, 15.29264069], [80.09069061, 15.29181194], [80.09041595, 15.29181194], [80.09041595, 15.29069138], [80.0901413, 15.29069519], [80.0901413, 15.28986073], [80.08985901, 15.28986073], [80.08985901, 15.28875065], [80.08957672, 15.28875065], [80.08957672, 15.28792095], [80.08930206, 15.28792095], [80.08930206, 15.28707981], [80.0890274, 15.28708267], [80.0890274, 15.28625107], [80.08875275, 15.28625107], [80.08875275, 15.28569031], [80.08847046, 15.28569508], [80.08847046, 15.28486061], [80.0881958, 15.28486061], [80.0881958, 15.28402901], [80.08790588, 15.28403091], [80.08790588, 15.28318977], [80.08763885, 15.28319359], [80.08763885, 15.28236008], [80.08735657, 15.28236008], [80.08735657, 15.28181076], [80.08706665, 15.28181076], [80.08706665, 15.27985954], [80.08680725, 15.2798624], [80.08680725, 15.27930641], [80.08653259, 15.27931118], [80.08653259, 15.27764034], [80.08625031, 15.27764034], [80.08625031, 15.27707958], [80.08597565, 15.27708435], [80.08597565, 15.27652836], [80.08569336, 15.27653027], [80.08569336, 15.27595997], [80.0854187, 15.27597237], [80.0854187, 15.27541637], [80.08513641, 15.27542019], [80.08513641, 15.27486038], [80.08486176, 15.27486229], [80.08486176, 15.27041531], [80.0845871, 15.27042007], [80.0845871, 15.26931], [80.08429718, 15.26931], [80.08429718, 15.26847076], [80.08403015, 15.26847363], [80.08403015, 15.26763916], [80.08374786, 15.26764202], [80.08374786, 15.26708126], [80.08347321, 15.26708317], [80.08347321, 15.26402664], [80.08319092, 15.26402664], [80.08319092, 15.26236057], [80.08291626, 15.26236057], [80.08291626, 15.25374985], [80.08319092, 15.25375271], [80.08319092, 15.25263977], [80.08347321, 15.25263977], [80.08347321, 15.25152969], [80.08374786, 15.25152969], [80.08374786, 15.25014019], [80.08403015, 15.25014019], [80.08403015, 15.24874973], [80.08429718, 15.24874973], [80.08429718, 15.24763966], [80.0845871, 15.24763966], [80.0845871, 15.24652958], [80.08486176, 15.24652958], [80.08486176, 15.2456913], [80.08513641, 15.24569416], [80.08513641, 15.24514008], [80.0854187, 15.24514198], [80.0854187, 15.24431038], [80.08569336, 15.24431038], [80.08569336, 15.24346924], [80.08597565, 15.24347115], [80.08597565, 15.24291801], [80.08625031, 15.24291801], [80.08625031, 15.24180508], [80.08651733, 15.24181175], [80.08651733, 15.24042034], [80.08680725, 15.24042034], [80.08680725, 15.23875141], [80.08706665, 15.23875141], [80.08706665, 15.23736095], [80.08735657, 15.23736095], [80.08735657, 15.23236275], [80.08763885, 15.23236275], [80.08763885, 15.22735977], [80.08790588, 15.22735977], [80.08790588, 15.22513962], [80.0881958, 15.22513962], [80.0881958, 15.22402954], [80.08847046, 15.22402954], [80.08847046, 15.21930981], [80.0881958, 15.21930981], [80.0881958, 15.2179203], [80.08790588, 15.2179203], [80.08790588, 15.21568203], [80.08763885, 15.21569347], [80.08763885, 15.21347332], [80.0873642, 15.21347332], [80.0873642, 15.21180534], [80.08706665, 15.21181202], [80.08706665, 15.21069145], [80.08680725, 15.21069527], [80.08680725, 15.2098608], [80.08651733, 15.20987034], [80.08651733, 15.20818996], [80.08625031, 15.20819473], [80.08625031, 15.20652676], [80.08598328, 15.20653057], [80.08598328, 15.20486069], [80.08569336, 15.20486069], [80.08569336, 15.20318985], [80.0854187, 15.20319462], [80.0854187, 15.2015276], [80.08513641, 15.20153141], [80.08513641, 15.20042133], [80.08486176, 15.20042133], [80.08486176, 15.19931126], [80.0845871, 15.19931126], [80.0845871, 15.19847202], [80.08430481, 15.19847202], [80.08430481, 15.19736004], [80.08403015, 15.19736004], [80.08403015, 15.19653034], [80.08374786, 15.19653034], [80.08374786, 15.19542027], [80.08347321, 15.19542027], [80.08347321, 15.19458199], [80.08319092, 15.19458389], [80.08319092, 15.19430637], [80.08291626, 15.19431019], [80.08291626, 15.19375038], [80.0826416, 15.19375038], [80.0826416, 15.19319057], [80.08235931, 15.19319439], [80.08235931, 15.19291782], [80.08207703, 15.19291973], [80.08207703, 15.1926403], [80.08180237, 15.1926403], [80.08180237, 15.19236183], [80.08152771, 15.19236183], [80.08152771, 15.19208145], [80.08125305, 15.19208431], [80.08125305, 15.19180584], [80.08097076, 15.19180584], [80.08097076, 15.19124985], [80.08069611, 15.19125175], [80.08069611, 15.19097233], [80.08041382, 15.19097233], [80.08041382, 15.19069576], [80.08013916, 15.19069576], [80.08013916, 15.19041538], [80.0790329, 15.19042015], [80.0790329, 15.19013977], [80.07875061, 15.19013977], [80.07875061, 15.18985939], [80.07847595, 15.18986225], [80.07847595, 15.18958378], [80.07819366, 15.18958378], [80.07819366, 15.18902683], [80.07707977, 15.18902969], [80.07707977, 15.18931007], [80.07569122, 15.18930531], [80.07569122, 15.18958378], [80.07514191, 15.18958378], [80.07514191, 15.18986225], [80.07501221, 15.18986225], [80.07457733, 15.18985939], [80.07457733, 15.19013977], [80.07430267, 15.19013977], [80.07430267, 15.19042015], [80.07402802, 15.19041538], [80.07402802, 15.19069576], [80.07347107, 15.19069576], [80.07347107, 15.19097233], [80.07290649, 15.19097233], [80.07290649, 15.19125175], [80.07206726, 15.19125175], [80.07206726, 15.19153023], [80.07180786, 15.19152832], [80.07180786, 15.19180584], [80.07152557, 15.19180584], [80.07152557, 15.19208431], [80.07068634, 15.19208145], [80.07068634, 15.19236183], [80.07041931, 15.19236183], [80.07041931, 15.1926403], [80.06986237, 15.1926403], [80.06986237, 15.19291973], [80.06958008, 15.19291782], [80.06958008, 15.19347191], [80.06930542, 15.19347191], [80.06932068, 15.19375038], [80.06903076, 15.19375038], [80.06903076, 15.19402981], [80.06874847, 15.19402981], [80.06874847, 15.19431019], [80.06846619, 15.19431019], [80.06846619, 15.19487095], [80.06819153, 15.19487095], [80.06819153, 15.19542027], [80.06791687, 15.19541645], [80.06791687, 15.1956892], [80.06764221, 15.19569397], [80.06764221, 15.19597244], [80.06735992, 15.19596958], [80.06735992, 15.19624996], [80.0670929, 15.19624996], [80.0670929, 15.19681072], [80.06680298, 15.19680595], [80.06680298, 15.19708443], [80.06652832, 15.19707966], [80.06652832, 15.19764042], [80.06597137, 15.19764042], [80.06597137, 15.19793034], [80.06569672, 15.19791603], [80.06569672, 15.19819355], [80.06513977, 15.19819355], [80.06513977, 15.19847202], [80.06485748, 15.19847202], [80.06485748, 15.19874954], [80.06430817, 15.19874954], [80.06430817, 15.19931126], [80.06375122, 15.19930553], [80.06375122, 15.1995821], [80.06346893, 15.1995821], [80.06346893, 15.19986153], [80.06318665, 15.19985962], [80.06318665, 15.20014], [80.06291962, 15.20014], [80.06291962, 15.20042133], [80.06236267, 15.20041561], [80.06236267, 15.20069408], [80.06208038, 15.20069408], [80.06208038, 15.2009716], [80.06153107, 15.2009697], [80.06153107, 15.20125008], [80.06124878, 15.20125008], [80.06124878, 15.20153141], [80.06096649, 15.20153141], [80.06096649, 15.20181084], [80.06069183, 15.20180416], [80.06069183, 15.20208454], [80.05986023, 15.20208454], [80.05986023, 15.20236015], [80.05930328, 15.20236015], [80.05930328, 15.20264053], [80.05874634, 15.20264053], [80.05874634, 15.20292091], [80.05819702, 15.20291615], [80.05819702, 15.20319462], [80.05791473, 15.20319462], [80.05791473, 15.20347309], [80.05764008, 15.20347309], [80.05764008, 15.20375061], [80.05735779, 15.20374203], [80.05735779, 15.20403099], [80.05709076, 15.20403099], [80.05709076, 15.20431137], [80.05680847, 15.20431137], [80.05680847, 15.20486069], [80.05652618, 15.20486069], [80.05652618, 15.20514107], [80.05625153, 15.20514107], [80.05625153, 15.20542145], [80.05596924, 15.20541668], [80.05596924, 15.20569515], [80.05541992, 15.20569515], [80.05541992, 15.20597267], [80.05513763, 15.20597076], [80.05513763, 15.20625114], [80.05486298, 15.20625114], [80.05486298, 15.20653057], [80.05458069, 15.20653057], [80.05458069, 15.2068119], [80.05403137, 15.20680523], [80.05403137, 15.20708275], [80.05347443, 15.20708275], [80.05347443, 15.20736122], [80.05291748, 15.20736122], [80.05291748, 15.20764065], [80.05208588, 15.20764065], [80.05208588, 15.20792103], [80.05152893, 15.20791721], [80.05152893, 15.20819473], [80.05041504, 15.20819473], [80.05041504, 15.20847321], [80.05014038, 15.2084713], [80.05014038, 15.20875072], [80.04957581, 15.20875072], [80.04957581, 15.2090292], [80.04875183, 15.2090292], [80.04875183, 15.20930862], [80.04846954, 15.20930481], [80.04846954, 15.20958328], [80.04736328, 15.20958138], [80.04736328, 15.20987034], [80.04651642, 15.20987034], [80.04651642, 15.20958138], [80.04624939, 15.20958328], [80.04624939, 15.20930481], [80.0459671, 15.20930862], [80.0459671, 15.2084713], [80.04624939, 15.20847321], [80.04624939, 15.20819473], [80.04680634, 15.20819473], [80.04680634, 15.20791721], [80.04736328, 15.20792103], [80.04736328, 15.20764065], [80.04818726, 15.20764065], [80.04818726, 15.20736122], [80.04875183, 15.20736122], [80.04875183, 15.20708275], [80.04902649, 15.20708275], [80.04902649, 15.20680523], [80.04957581, 15.2068119], [80.04957581, 15.20653057], [80.05014038, 15.20653057], [80.05014038, 15.20597076], [80.05041504, 15.20597267], [80.05041504, 15.20569515], [80.05097198, 15.20569515], [80.05097198, 15.20513916], [80.05124664, 15.20514107], [80.05124664, 15.20486069], [80.05152893, 15.20486069], [80.05152893, 15.20458031], [80.05180359, 15.20458317], [80.05180359, 15.2043066], [80.05236053, 15.20431137], [80.05236053, 15.20403099], [80.05264282, 15.20403099], [80.05264282, 15.20374203], [80.05291748, 15.20375061], [80.05291748, 15.20319462], [80.05319214, 15.20319462], [80.05319214, 15.20291615], [80.0534668, 15.20292091], [80.0534668, 15.20264053], [80.05374908, 15.20264053], [80.05374908, 15.20236015], [80.05403137, 15.20236015], [80.05403137, 15.20208454], [80.05430603, 15.20208454], [80.05430603, 15.20180416], [80.05486298, 15.20181084], [80.05486298, 15.20153141], [80.05513763, 15.20153141], [80.05513763, 15.20125008], [80.05541992, 15.20125008], [80.05541992, 15.20068073], [80.05569458, 15.20069408], [80.05569458, 15.19986153], [80.05596924, 15.19986153], [80.05596924, 15.1995821], [80.05625153, 15.1995821], [80.05625153, 15.19930553], [80.05652618, 15.19931126], [80.05652618, 15.19903088], [80.05680847, 15.19903088], [80.05680847, 15.19847202], [80.05708313, 15.19847202], [80.05708313, 15.19819355], [80.05735779, 15.19819355], [80.05735779, 15.19791603], [80.05764008, 15.19793034], [80.05764008, 15.19764042], [80.0579071, 15.19764042], [80.0579071, 15.19736004], [80.05847168, 15.19736004], [80.05847168, 15.19707966], [80.05902863, 15.19708443], [80.05902863, 15.19680595], [80.05930328, 15.19681072], [80.05930328, 15.19653034], [80.0595932, 15.19653034], [80.0595932, 15.19624996], [80.05986023, 15.19624996], [80.05986023, 15.1956892], [80.06014252, 15.19569397], [80.06014252, 15.19541645], [80.06041718, 15.19542027], [80.06041718, 15.19514179], [80.06069183, 15.19514179], [80.06069183, 15.19487095], [80.06096649, 15.19487095], [80.06096649, 15.19458199], [80.06124878, 15.19458389], [80.06124878, 15.19430637], [80.06153107, 15.19431019], [80.06153107, 15.19402981], [80.06181335, 15.19402981], [80.06181335, 15.19375038], [80.06208038, 15.19375038], [80.06208038, 15.19319057], [80.06236267, 15.19319439], [80.06236267, 15.19291782], [80.06263733, 15.19291973], [80.06263733, 15.1926403], [80.06291962, 15.1926403], [80.06291962, 15.19236183], [80.06346893, 15.19236183], [80.06346893, 15.19208145], [80.06375122, 15.19208431], [80.06375122, 15.19152832], [80.06346893, 15.19153023], [80.06346893, 15.19125175], [80.06236267, 15.19125175], [80.06236267, 15.19153023], [80.06208038, 15.19152832], [80.06208038, 15.19180584], [80.06124878, 15.19180584], [80.06124878, 15.19152832], [80.06096649, 15.19153023], [80.06096649, 15.19125175], [80.06069183, 15.19125175], [80.06069183, 15.19069099], [80.06097412, 15.19069576], [80.06097412, 15.19041538], [80.06181335, 15.19042015], [80.06181335, 15.19013977], [80.06291962, 15.19013977], [80.06291962, 15.18985939], [80.06319427, 15.18986225], [80.06319427, 15.18958378], [80.06430817, 15.18958378], [80.06430817, 15.18930531], [80.06513977, 15.18931007], [80.06513977, 15.18873978], [80.06569672, 15.18874931], [80.06569672, 15.18847084], [80.06597137, 15.18847084], [80.06597137, 15.18819141], [80.06652832, 15.18819332], [80.06652832, 15.18763924], [80.06680298, 15.18763924], [80.06680298, 15.18708134], [80.06735992, 15.18708324], [80.06735992, 15.18680477], [80.06791687, 15.18680954], [80.06791687, 15.18653202], [80.06846619, 15.18653202], [80.06846619, 15.18625069], [80.06874847, 15.18625069], [80.06874847, 15.18597126], [80.06930542, 15.18597126], [80.06930542, 15.18569469], [80.06986237, 15.18570042], [80.06986237, 15.18542194], [80.07013702, 15.18542194], [80.07013702, 15.18514061], [80.07068634, 15.18514061], [80.07068634, 15.18486118], [80.07125092, 15.18486118], [80.07125092, 15.18458271], [80.07152557, 15.18458271], [80.07152557, 15.18430519], [80.07312012, 15.18430519], [80.07319641, 15.18430519], [80.07319641, 15.18403244], [80.07347107, 15.18403244], [80.07347107, 15.18375111], [80.07402802, 15.18375111], [80.07402802, 15.1831913], [80.07485962, 15.18319511], [80.07485962, 15.18291664], [80.07541656, 15.18293095], [80.07541656, 15.18264103], [80.07596588, 15.18264103], [80.07596588, 15.18236065], [80.07624817, 15.18236065], [80.07624817, 15.18208122], [80.07736206, 15.18208313], [80.07736206, 15.18180466], [80.07818604, 15.18180943], [80.07818604, 15.18236065], [80.07847595, 15.18236065], [80.07847595, 15.18293095], [80.07875061, 15.18291664], [80.07875061, 15.18347263], [80.0790329, 15.18347073], [80.0790329, 15.18403244], [80.07930756, 15.18402672], [80.07930756, 15.18458271], [80.07958221, 15.1845808], [80.07958221, 15.18514061], [80.07985687, 15.18514061], [80.07985687, 15.18570042], [80.08013916, 15.18569469], [80.08013916, 15.18597126], [80.08040619, 15.18597126], [80.08040619, 15.18625069], [80.08097076, 15.18625069], [80.08097076, 15.18597126], [80.08125305, 15.18597126], [80.08125305, 15.18541718], [80.08097076, 15.18542194], [80.08097076, 15.1845808], [80.08069611, 15.18458271], [80.08069611, 15.18375111], [80.08040619, 15.18375111], [80.08040619, 15.1831913], [80.08013916, 15.18319511], [80.08013916, 15.18263912], [80.07985687, 15.18264103], [80.07985687, 15.18208122], [80.07958221, 15.18208313], [80.07958221, 15.18152905], [80.07930756, 15.18153095], [80.07930756, 15.18097115], [80.07902527, 15.18097305], [80.07902527, 15.18069458], [80.07819366, 15.18069458], [80.07819366, 15.17986107], [80.07791901, 15.17986107], [80.07791901, 15.17957115], [80.07763672, 15.1795826], [80.07763672, 15.1790266], [80.07736206, 15.17903137], [80.07736206, 15.17846966], [80.07707977, 15.17847347], [80.07707977, 15.178195], [80.07680511, 15.178195], [80.07680511, 15.17763901], [80.07653046, 15.17764091], [80.07653046, 15.17708015], [80.07624817, 15.17708206], [80.07624817, 15.17652893], [80.07596588, 15.17653084], [80.07596588, 15.17597008], [80.07569122, 15.17597294], [80.07569122, 15.17541599], [80.07541656, 15.17542076], [80.07541656, 15.17486], [80.07512665, 15.17486], [80.07512665, 15.17457962], [80.07485962, 15.17458534], [80.07485962, 15.1740284], [80.07457733, 15.17403126], [80.07457733, 15.17346954], [80.07430267, 15.1734724], [80.07430267, 15.17291641], [80.07402802, 15.17292118], [80.07402802, 15.17236042], [80.07375336, 15.17236233], [80.07375336, 15.17180634], [80.07347107, 15.1718111], [80.07347107, 15.17125034], [80.07319641, 15.17125034], [80.07319641, 15.17070103], [80.07290649, 15.17070103], [80.07290649, 15.17014027], [80.07263947, 15.17014027], [80.07263947, 15.16958046], [80.07236481, 15.16958427], [80.07236481, 15.16902828], [80.07206726, 15.16903019], [80.07206726, 15.16819191], [80.07180786, 15.16819382], [80.07180786, 15.16763783], [80.07152557, 15.16763783], [80.07152557, 15.16708374], [80.07125092, 15.16708374], [80.07125092, 15.16652775], [80.07096863, 15.16652966], [80.07096863, 15.16596889], [80.07069397, 15.16597176], [80.07069397, 15.16541767], [80.07041931, 15.16541958], [80.07041931, 15.16486168], [80.07013702, 15.16486168], [80.07013702, 15.16431046], [80.06986237, 15.16431046], [80.06986237, 15.16374969], [80.06958008, 15.16374969], [80.06958008, 15.16319084], [80.06930542, 15.16319561], [80.06930542, 15.16263962], [80.06903076, 15.16263962], [80.06903076, 15.16208076], [80.06874847, 15.16208267], [80.06874847, 15.16152668], [80.06846619, 15.16152954], [80.06846619, 15.16097069], [80.06819153, 15.16097355], [80.06819153, 15.1604166], [80.06791687, 15.16042042], [80.06791687, 15.15986061], [80.06764221, 15.15986061], [80.06764221, 15.15930462], [80.06735992, 15.15931034], [80.06735992, 15.15876007], [80.0670929, 15.15876007], [80.0670929, 15.15819073], [80.06680298, 15.15819454], [80.06680298, 15.15763855], [80.06652832, 15.15764141], [80.06652832, 15.15681171], [80.06624603, 15.15681171], [80.06624603, 15.15597057], [80.06597137, 15.15597343], [80.06597137, 15.15513897], [80.06569672, 15.15514088], [80.06569672, 15.15458107], [80.06541443, 15.15458298], [80.06541443, 15.15375137], [80.06513977, 15.15375137], [80.06513977, 15.15318966], [80.06485748, 15.15319538], [80.06485748, 15.1520834], [80.06458282, 15.1520834], [80.06458282, 15.15125084], [80.06430817, 15.15125084], [80.06430817, 15.15014076], [80.06402588, 15.15014076], [80.06402588, 15.14931107], [80.06375122, 15.14931107], [80.06375122, 15.14846992], [80.06346893, 15.14847183], [80.06346893, 15.14763832], [80.06318665, 15.14764118], [80.06318665, 15.14653111], [80.06291962, 15.14653111], [80.06291962, 15.14569187], [80.06263733, 15.14569378], [80.06263733, 15.14486217], [80.06236267, 15.14486217], [80.06236267, 15.14402771], [80.06208038, 15.14402962], [80.06208038, 15.14318943], [80.06180573, 15.1431942], [80.06180573, 15.14208412], [80.06153107, 15.14208412], [80.06153107, 15.14124966], [80.06124878, 15.14124966], [80.06124878, 15.14041996], [80.06096649, 15.14041996], [80.06096649, 15.13958168], [80.06069183, 15.13958359], [80.06069183, 15.1384716], [80.06041718, 15.1384716], [80.06041718, 15.13736153], [80.06014252, 15.13736153], [80.06014252, 15.13624859], [80.05986023, 15.13624859], [80.05986023, 15.13542175], [80.0595932, 15.13542175], [80.0595932, 15.13430977], [80.05930328, 15.13430977], [80.05930328, 15.13319969], [80.05902863, 15.13319111], [80.05902863, 15.13263893], [80.05874634, 15.13264179], [80.05874634, 15.13181019], [80.05847168, 15.13181019], [80.05847168, 15.13125134], [80.05819702, 15.13125134], [80.05819702, 15.13069057], [80.05791473, 15.13069534], [80.05791473, 15.12930489], [80.05764008, 15.1293087], [80.05764008, 15.12846184], [80.05735779, 15.12847328], [80.05735779, 15.12791729], [80.05709076, 15.1279192], [80.05709076, 15.12708092], [80.05680847, 15.12708282], [80.05680847, 15.12625122], [80.05652618, 15.12625122], [80.05652618, 15.12542057], [80.05625153, 15.12542057], [80.05625153, 15.12458038], [80.05596924, 15.12458324], [80.05596924, 15.12375069], [80.05568695, 15.12375069], [80.05568695, 15.12292099], [80.05541992, 15.12292099], [80.05541992, 15.12181091], [80.05513763, 15.12181091], [80.05513763, 15.12096977], [80.05486298, 15.12097168], [80.05486298, 15.12013817], [80.05458069, 15.12014103], [80.05458069, 15.11931133], [80.05430603, 15.11931133], [80.05430603, 15.11847019], [80.05403137, 15.1184721], [80.05403137, 15.11763763], [80.05374908, 15.11763954], [80.05374908, 15.11652088], [80.05347443, 15.11652756], [80.05347443, 15.11541557], [80.05319214, 15.11542034], [80.05319214, 15.1145792], [80.05291748, 15.11458397], [80.05291748, 15.11347198], [80.05263519, 15.11347198], [80.05263519, 15.11236191], [80.05236053, 15.11236191], [80.05236053, 15.11125183], [80.05208588, 15.11125183], [80.05208588, 15.11014175], [80.05179596, 15.11014175], [80.05179596, 15.10902977], [80.05152893, 15.10902977], [80.05152893, 15.10791969], [80.05124664, 15.10791969], [80.05124664, 15.10680962], [80.05095673, 15.10680962], [80.05095673, 15.10486126], [80.05069733, 15.10486126], [80.05069733, 15.10319519], [80.05041504, 15.10319519], [80.05041504, 15.1026392], [80.05014038, 15.1026392], [80.05014038, 15.10125065], [80.04985809, 15.10125065], [80.04985809, 15.10014057], [80.04957581, 15.10014057], [80.04957581, 15.09903145], [80.04930878, 15.09903145], [80.04930878, 15.09736061], [80.04902649, 15.09736061], [80.04902649, 15.0951376], [80.04875183, 15.09514141], [80.04875183, 15.0945797], [80.04846954, 15.09458542], [80.04846954, 15.09069443], [80.04819489, 15.09069443], [80.04819489, 15.08874989], [80.04792023, 15.08875179], [80.04792023, 15.07734966], [80.04819489, 15.07736111], [80.04819489, 15.06902885], [80.04846954, 15.06903076], [80.04846954, 15.06264019], [80.04875183, 15.06264019], [80.04875183, 15.06042004], [80.04902649, 15.06042004], [80.04902649, 15.05181026], [80.04930878, 15.05181026], [80.04930878, 15.04568958], [80.04958344, 15.0456953], [80.04958344, 15.04291725], [80.04985809, 15.04292107], [80.04985809, 15.03792095], [80.05014038, 15.03792095], [80.05014038, 15.03625011], [80.05042267, 15.03625011], [80.05042267, 15.03347015], [80.05069733, 15.03347206], [80.05069733, 15.02791786], [80.05095673, 15.02791977], [80.05095673, 15.02653027], [80.05124664, 15.02653027], [80.05124664, 15.02569103], [80.05152893, 15.02569485], [80.05152893, 15.02458286], [80.05180359, 15.02458286], [80.05180359, 15.02347088], [80.05208588, 15.02347088], [80.05208588, 15.02180481], [80.05236053, 15.02180958], [80.05236053, 15.01986122], [80.05263519, 15.01986122], [80.05263519, 15.01847267], [80.05291748, 15.01847267], [80.05291748, 15.01486015], [80.05319214, 15.01486015], [80.05319214, 15.01124954], [80.0534668, 15.01126194], [80.05347443, 15.00971031], [80.05347443, 15.00847244], [80.05374908, 15.00847244], [80.05374908, 15.00680637], [80.05403137, 15.00681114], [80.05403137, 15.00569057], [80.05430603, 15.00569439], [80.05430603, 15.00319576], [80.05458069, 15.00319576], [80.05458069, 14.99986076], [80.05458069, 14.99932098], [80.05486298, 14.99932098], [80.05486298, 14.99819088], [80.05513763, 14.99819469], [80.05513763, 14.99680519], [80.05541992, 14.99681187], [80.05541992, 14.9956913], [80.05569458, 14.99569511], [80.05569458, 14.99430466], [80.05596924, 14.99430943], [80.05596924, 14.9931879], [80.05625153, 14.99319458], [80.05625153, 14.9920826], [80.05652618, 14.9920826], [80.05652618, 14.990695], [80.05680847, 14.990695], [80.05680847, 14.98958302], [80.05708313, 14.98958302], [80.05708313, 14.98819542], [80.05735779, 14.98819542], [80.05735779, 14.98708153], [80.05764008, 14.98709106], [80.05764008, 14.98569202], [80.05791473, 14.98569393], [80.05791473, 14.98430634], [80.05819702, 14.9843111], [80.05819702, 14.98264027], [80.05847168, 14.98264027], [80.05847168, 14.98124981], [80.05874634, 14.98124981], [80.05874634, 14.97986031], [80.05902863, 14.97986221], [80.05902863, 14.97847176], [80.05930328, 14.97847176], [80.05930328, 14.97680569], [80.0595932, 14.97681046], [80.0595932, 14.97542], [80.05986023, 14.97542], [80.05986023, 14.97402954], [80.06012726, 14.97402954], [80.06012726, 14.97236061], [80.06041718, 14.97236061], [80.06041718, 14.97097111], [80.06069183, 14.97097111], [80.06069183, 14.96930504], [80.06096649, 14.96931171], [80.06096649, 14.96791935], [80.06124878, 14.96791935], [80.06124878, 14.96680927], [80.06153107, 14.96680927], [80.06153107, 14.96625137], [80.06181335, 14.96625137], [80.06180573, 14.96430683], [80.06208038, 14.96431065], [80.06208038, 14.96375084], [80.06181335, 14.96375084], [80.06181335, 14.96319008], [80.06208038, 14.96319485], [80.06208038, 14.96208191], [80.06291962, 14.96208191], [80.06291962, 14.96152878], [80.06236267, 14.96153069], [80.06236267, 14.96042061], [80.06263733, 14.96042061], [80.06263733, 14.95986271], [80.06291962, 14.95986271], [80.06291962, 14.95874977], [80.06318665, 14.95874977], [80.06318665, 14.95597172], [80.06346893, 14.95597172], [80.06346893, 14.95542145], [80.06375122, 14.95542145], [80.06375122, 14.95431137], [80.06346893, 14.95431137], [80.06346893, 14.95347023], [80.06375122, 14.95347214], [80.06375122, 14.95236206], [80.06402588, 14.95236206], [80.06402588, 14.95014], [80.06430817, 14.95014191], [80.06430817, 14.94847107], [80.06458282, 14.94847107], [80.06458282, 14.94708347], [80.06485748, 14.94708347], [80.06485748, 14.94597435], [80.06513977, 14.94597435], [80.06513977, 14.9454174], [80.0654068, 14.94542027], [80.0654068, 14.94484997], [80.06569672, 14.94486141], [80.06569672, 14.94375134], [80.06597137, 14.94375134], [80.06597137, 14.94347095], [80.06652832, 14.94347095], [80.06652832, 14.94263935], [80.06624603, 14.94263935], [80.06624603, 14.94208145], [80.06597137, 14.94208336], [80.06597137, 14.94124889], [80.06624603, 14.94124889], [80.06624603, 14.9404192], [80.06652832, 14.9404192], [80.06652832, 14.93958092], [80.06680298, 14.93958282], [80.06680298, 14.93791676], [80.0670929, 14.93792057], [80.0670929, 14.93708038], [80.06735992, 14.93708324], [80.06735992, 14.93652916], [80.06764221, 14.93653107], [80.06764221, 14.93598175], [80.06791687, 14.93598175], [80.06791687, 14.93375111], [80.06764221, 14.93375111], [80.06764221, 14.93319035], [80.06791687, 14.93319416], [80.06791687, 14.93263817], [80.06819153, 14.93264103], [80.06819153, 14.93153095], [80.06846619, 14.93153095], [80.06846619, 14.92903042], [80.06874847, 14.92903042], [80.06874847, 14.92708015], [80.06903076, 14.92708397], [80.06903076, 14.92652798], [80.06932068, 14.92653275], [80.06932068, 14.92597198], [80.06958008, 14.92597198], [80.06958008, 14.9254179], [80.06986237, 14.92541981], [80.06986237, 14.92486191], [80.07013702, 14.92486191], [80.07013702, 14.92404079], [80.07041931, 14.92404079], [80.07041931, 14.92346859], [80.07069397, 14.9234724], [80.07069397, 14.92319584], [80.07096863, 14.92319584], [80.07096863, 14.92291641], [80.07125092, 14.92292023], [80.07125092, 14.92235947], [80.07152557, 14.92236233], [80.07152557, 14.92208385], [80.07180786, 14.92208385], [80.07180786, 14.92152786], [80.07206726, 14.92152977], [80.07206726, 14.92124939], [80.07235718, 14.92124939], [80.07235718, 14.92069054], [80.07263947, 14.9206934], [80.07263947, 14.92041779], [80.07290649, 14.92041969], [80.07290649, 14.92014027], [80.07319641, 14.92014027], [80.07319641, 14.91958141], [80.07347107, 14.91958332], [80.07347107, 14.91902733], [80.07375336, 14.91903019], [80.07375336, 14.91819096], [80.07402802, 14.91819477], [80.07402802, 14.91763878], [80.07430267, 14.91764164], [80.07430267, 14.91708088], [80.07458496, 14.91708279], [80.07458496, 14.91652679], [80.07485962, 14.91653156], [80.07485962, 14.91596889], [80.07514191, 14.9159708], [80.07514191, 14.91541672], [80.07541656, 14.91541862], [80.07541656, 14.91431046], [80.07569122, 14.91431046], [80.07569122, 14.91347122], [80.07597351, 14.91347313], [80.07597351, 14.91236115], [80.07624817, 14.91236115], [80.07624817, 14.91152668], [80.07653046, 14.91153145], [80.07653046, 14.91042137], [80.07681274, 14.91042137], [80.07681274, 14.90958023], [80.07707977, 14.90958309], [80.07707977, 14.90847301], [80.07736206, 14.90847301], [80.07736206, 14.9076376], [80.07763672, 14.90764141], [80.07763672, 14.90653133], [80.07791901, 14.90653133], [80.07791901, 14.90568066], [80.07819366, 14.90569401], [80.07819366, 14.90458202], [80.07847595, 14.90458202], [80.07847595, 14.90375042], [80.07875061, 14.90375042], [80.07875061, 14.90264034], [80.0790329, 14.90264034], [80.0790329, 14.90153027], [80.07930756, 14.90153027], [80.07930756, 14.90069199], [80.07958221, 14.90069389], [80.07958221, 14.89958191], [80.0798645, 14.89958191], [80.0798645, 14.89875031], [80.08013916, 14.89875031], [80.08013916, 14.89764023], [80.08040619, 14.89764023], [80.08040619, 14.89680958], [80.08069611, 14.89680958], [80.08069611, 14.89569092], [80.08097076, 14.89569569], [80.08097076, 14.8945837], [80.08125305, 14.8945837], [80.08125305, 14.89374924], [80.08152771, 14.89374924], [80.08152771, 14.89263916], [80.08180237, 14.89264202], [80.08180237, 14.89153194], [80.08207703, 14.89153194], [80.08207703, 14.89067936], [80.08235931, 14.89069462], [80.08235931, 14.88958263], [80.0826416, 14.88958263], [80.0826416, 14.88874912], [80.08291626, 14.88875103], [80.08291626, 14.88764095], [80.08319092, 14.88764095], [80.08319092, 14.88653088], [80.08347321, 14.88653088], [80.08347321, 14.88541889], [80.08374786, 14.88541889], [80.08374786, 14.88375092], [80.08403015, 14.88375092], [80.08403015, 14.88208008], [80.08430481, 14.88208294], [80.08430481, 14.88069534], [80.0845871, 14.88069534], [80.0845871, 14.87902832], [80.08486176, 14.87903118], [80.08486176, 14.87681103], [80.08513641, 14.87681103], [80.08513641, 14.87403011], [80.0854187, 14.87403011], [80.0854187, 14.87125015], [80.08569336, 14.87125015], [80.08569336, 14.86653042], [80.08598328, 14.86653042], [80.08598328, 14.85986137], [80.08625031, 14.85986137], [80.08625031, 14.85208225], [80.08652496, 14.85208225], [80.08652496, 14.84986019], [80.08680725, 14.84986019], [80.08680725, 14.84958363], [80.08708191, 14.84958363], [80.08708191, 14.84902763], [80.08735657, 14.84903145], [80.08735657, 14.84846973], [80.08708191, 14.84847164], [80.08708191, 14.84791565], [80.08680725, 14.84792137], [80.08680725, 14.84708023], [80.08652496, 14.84708405], [80.08652496, 14.84486198], [80.08680725, 14.84486198], [80.08680725, 14.84041977], [80.08706665, 14.84041977], [80.08706665, 14.83653164], [80.08735657, 14.83653164], [80.08735657, 14.83319092], [80.08708191, 14.83319473], [80.08708191, 14.83069515], [80.0873642, 14.83069515], [80.0873642, 14.82680416], [80.08763885, 14.82681084], [80.08763885, 14.82431126], [80.08790588, 14.82431126], [80.08790588, 14.82264042], [80.0881958, 14.82264042], [80.0881958, 14.8215189], [80.08763885, 14.82152843], [80.08763885, 14.82208443], [80.08735657, 14.82207966], [80.08735657, 14.82236004], [80.08706665, 14.82236004], [80.08706665, 14.82264042], [80.08651733, 14.82264042], [80.08651733, 14.8229208], [80.08598328, 14.8229208], [80.08598328, 14.82264042], [80.08429718, 14.82264042], [80.08429718, 14.8215189], [80.08513641, 14.8215189], [80.08513641, 14.82181072], [80.08680725, 14.82181072], [80.08680725, 14.82124996], [80.08706665, 14.82124996], [80.08706665, 14.82096958], [80.0873642, 14.82097244], [80.0873642, 14.82013798], [80.08706665, 14.82014179], [80.08706665, 14.81931114], [80.08735657, 14.81931114], [80.08735657, 14.81902981], [80.08763885, 14.81902981], [80.08763885, 14.81875038], [80.08790588, 14.81875038], [80.08790588, 14.81819153], [80.0881958, 14.81819439], [80.0881958, 14.81791592], [80.08847046, 14.81791973], [80.08847046, 14.8176403], [80.08875275, 14.8176403], [80.08875275, 14.81708241], [80.08847046, 14.81708431], [80.08847046, 14.81597233], [80.0881958, 14.81597233], [80.0881958, 14.81513977], [80.08847046, 14.81513977], [80.08847046, 14.81458092], [80.08875275, 14.81458378], [80.08875275, 14.81402779], [80.0890274, 14.81402969], [80.0890274, 14.81265068], [80.08875275, 14.81265068], [80.08875275, 14.81153202], [80.08790588, 14.81153202], [80.08790588, 14.81125164], [80.08706665, 14.81125164], [80.08706665, 14.81097126], [80.08625031, 14.81097126], [80.08625031, 14.81069469], [80.08513641, 14.81069469], [80.08513641, 14.81041527], [80.08429718, 14.81042194], [80.08429718, 14.81014156], [80.08347321, 14.81014156], [80.08347321, 14.80986118], [80.08180237, 14.80986118], [80.08180237, 14.81014156], [80.08069611, 14.81014156], [80.08069611, 14.81042194], [80.08041382, 14.81041527], [80.08041382, 14.81069469], [80.08013916, 14.81069469], [80.08013916, 14.81097126], [80.07985687, 14.81097126], [80.07985687, 14.81125164], [80.07930756, 14.81125164], [80.07930756, 14.81153202], [80.0790329, 14.81153202], [80.0790329, 14.81180954], [80.07875061, 14.81180477], [80.07875061, 14.81208324], [80.07847595, 14.81208134], [80.07847595, 14.81236076], [80.07818604, 14.81236076], [80.07818604, 14.81265068], [80.07763672, 14.81265068], [80.07763672, 14.81291962], [80.07736206, 14.81291771], [80.07736206, 14.81319332], [80.07707977, 14.81319141], [80.07707977, 14.81347084], [80.07680511, 14.81347084], [80.07681274, 14.81374931], [80.07653046, 14.81374931], [80.07653046, 14.81402969], [80.07624817, 14.81402969], [80.07624817, 14.81431007], [80.07569122, 14.81430626], [80.07569122, 14.81442165], [80.07569122, 14.81458378], [80.07541656, 14.81458378], [80.07541656, 14.81486225], [80.07485962, 14.81485939], [80.07485962, 14.81513977], [80.07457733, 14.81513977], [80.07457733, 14.81542015], [80.07430267, 14.81541634], [80.07430267, 14.81569576], [80.07375336, 14.81569576], [80.07375336, 14.81597233], [80.07347107, 14.81596947], [80.07347107, 14.81624985], [80.07290649, 14.81624985], [80.07290649, 14.81653023], [80.07206726, 14.81653023], [80.07206726, 14.81680965], [80.07152557, 14.81680584], [80.07152557, 14.81708431], [80.07068634, 14.81708241], [80.07068634, 14.81736183], [80.07013702, 14.81736183], [80.07013702, 14.8176403], [80.06986237, 14.8176403], [80.06986237, 14.81791973], [80.06958008, 14.81791592], [80.06958008, 14.81819439], [80.06930542, 14.81819439], [80.06930542, 14.81847191], [80.06903076, 14.81846046], [80.06903076, 14.81875038], [80.06874847, 14.81875038], [80.06874847, 14.81931114], [80.06819153, 14.81930637], [80.06819153, 14.81958199], [80.06735992, 14.81958199], [80.06735992, 14.81986237], [80.06680298, 14.81986046], [80.06680298, 14.82014179], [80.06624603, 14.82014179], [80.06624603, 14.82042122], [80.06485748, 14.82041645], [80.06485748, 14.8206892], [80.06346893, 14.82069397], [80.06346893, 14.82097244], [80.06291962, 14.82096958], [80.06291962, 14.82124996], [80.06124878, 14.82124996], [80.06124878, 14.82096958], [80.06069183, 14.82097244], [80.06069183, 14.82069397], [80.06012726, 14.8206892], [80.06014252, 14.82041645], [80.0595932, 14.82042122], [80.0595932, 14.82014179], [80.05930328, 14.82014179], [80.05930328, 14.81986046], [80.06069183, 14.81986046], [80.06069183, 14.82014179], [80.06263733, 14.82014179], [80.06263733, 14.81986046], [80.06346893, 14.81986237], [80.06346893, 14.81958199], [80.06402588, 14.81958199], [80.06402588, 14.81930637], [80.06485748, 14.81931114], [80.06485748, 14.81902981], [80.06624603, 14.81902981], [80.06624603, 14.81875038], [80.06680298, 14.81875038], [80.06680298, 14.81846046], [80.06708527, 14.81847191], [80.06708527, 14.81819439], [80.06735992, 14.81819439], [80.06735992, 14.81791592], [80.06764221, 14.81791973], [80.06764221, 14.8176403], [80.06791687, 14.8176403], [80.06791687, 14.81708241], [80.06819153, 14.81708431], [80.06819153, 14.81680584], [80.06874847, 14.81680965], [80.06874847, 14.81653023], [80.06903076, 14.81653023], [80.06903076, 14.81624985], [80.06958008, 14.81624985], [80.06958008, 14.81596947], [80.07041931, 14.81597233], [80.07041931, 14.81569576], [80.07096863, 14.81569576], [80.07096863, 14.81541634], [80.07125092, 14.81542015], [80.07125092, 14.81513977], [80.0715332, 14.81513977], [80.0715332, 14.81431007], [80.07180786, 14.81431007], [80.07180786, 14.81402969], [80.07235718, 14.81402969], [80.07235718, 14.81374931], [80.07263947, 14.81374931], [80.07263947, 14.81347084], [80.07290649, 14.81347084], [80.07290649, 14.81319141], [80.07485962, 14.81319332], [80.07485962, 14.81291771], [80.07511139, 14.81291962], [80.07512665, 14.81242085], [80.07514191, 14.81208324], [80.07541656, 14.81208324], [80.07541656, 14.81180477], [80.07518768, 14.81180477], [80.07458496, 14.81180477], [80.07458496, 14.81208324], [80.07430267, 14.81208324], [80.07430267, 14.81180477], [80.07402802, 14.81180954], [80.07402802, 14.81153202], [80.07430267, 14.81153202], [80.07430267, 14.81069088], [80.07458496, 14.81069469], [80.07458496, 14.81041527], [80.07557678, 14.81041527], [80.07597351, 14.81041527], [80.07597351, 14.81069469], [80.07624817, 14.81069469], [80.07624817, 14.81041527], [80.07707977, 14.81042194], [80.07707977, 14.81014156], [80.07763672, 14.81014156], [80.07763672, 14.80986118], [80.07819366, 14.80986118], [80.07819366, 14.80958271], [80.07902527, 14.80958271], [80.07902527, 14.80930519], [80.07958221, 14.80931187], [80.07958221, 14.80902863], [80.08013916, 14.80902863], [80.08013916, 14.8087492], [80.08040619, 14.8087492], [80.08040619, 14.80847073], [80.08097076, 14.80847263], [80.08097076, 14.80819511], [80.08152771, 14.80819511], [80.08152771, 14.80791664], [80.08180237, 14.80791855], [80.08180237, 14.80764103], [80.08291626, 14.80764103], [80.08291626, 14.80791855], [80.08319092, 14.80791664], [80.08319092, 14.80819511], [80.08569336, 14.80819511], [80.08569336, 14.80847263], [80.08625031, 14.80847263], [80.08625031, 14.80819511], [80.08652496, 14.80819511], [80.08652496, 14.80847263], [80.08706665, 14.80847073], [80.08706665, 14.8087492], [80.08735657, 14.8087492], [80.08735657, 14.80902863], [80.08790588, 14.80902863], [80.08790588, 14.80931187], [80.08930206, 14.80930519], [80.08930206, 14.80958271], [80.09041595, 14.80958271], [80.09041595, 14.80986118], [80.0909729, 14.80986118], [80.0909729, 14.81014156], [80.09124756, 14.8101387], [80.09124756, 14.81097126], [80.09208679, 14.81097126], [80.09208679, 14.81069469], [80.09236145, 14.81069469], [80.09236145, 14.81041527], [80.0929184, 14.81042194], [80.0929184, 14.81014156], [80.09320068, 14.81014156], [80.09320068, 14.80931187], [80.0934906, 14.80931187], [80.0934906, 14.80902863], [80.09263611, 14.80902863], [80.09263611, 14.8087492], [80.09236145, 14.8087492], [80.09236145, 14.80847073], [80.09263611, 14.80847263], [80.09263611, 14.80819511], [80.0929184, 14.80819511], [80.0929184, 14.80680466], [80.09263611, 14.80681038], [80.09263611, 14.80625057], [80.0929184, 14.80625057], [80.0929184, 14.80597115], [80.09319305, 14.80597305], [80.09319305, 14.80569458], [80.0929184, 14.80569458], [80.0929184, 14.80513859], [80.09320068, 14.80514145], [80.09320068, 14.80486107], [80.0929184, 14.80486107], [80.0929184, 14.80458069], [80.09319305, 14.8045826], [80.09319305, 14.80375099], [80.0929184, 14.80375099], [80.0929184, 14.80346107], [80.09319305, 14.80347347], [80.09319305, 14.803195], [80.09347534, 14.803195], [80.09347534, 14.80263901], [80.09375, 14.80264091], [80.09375, 14.80236053], [80.09402466, 14.80236053], [80.09402466, 14.80208302], [80.09375, 14.80208302], [80.09375, 14.80152893], [80.09401703, 14.80153084], [80.09401703, 14.79957962], [80.0945816, 14.79958153], [80.0945816, 14.79930687], [80.09430695, 14.79931068], [80.09430695, 14.79846954], [80.0945816, 14.7984724], [80.0945816, 14.79680634], [80.09430695, 14.7968111], [80.09430695, 14.79625034], [80.0945816, 14.79625034], [80.0945816, 14.79568958], [80.09486389, 14.79569435], [80.09486389, 14.79541588], [80.09513855, 14.79542065], [80.09513855, 14.79514027], [80.09541321, 14.79514027], [80.09541321, 14.79347038], [80.0956955, 14.79347229], [80.0956955, 14.7929163], [80.09597015, 14.79292011], [80.09597015, 14.79096985], [80.09625244, 14.79097176], [80.09625244, 14.79014015], [80.0965271, 14.79014015], [80.0965271, 14.78931046], [80.09680176, 14.78931046], [80.09680176, 14.78903008], [80.0965271, 14.78903008], [80.0965271, 14.78819084], [80.09625244, 14.7881937], [80.09625244, 14.78763962], [80.0965271, 14.78763962], [80.0965271, 14.78735924], [80.09680176, 14.7873621], [80.09680176, 14.78680611], [80.09707642, 14.78680992], [80.09707642, 14.78597069], [80.0973587, 14.78597355], [80.0973587, 14.78486061], [80.09791565, 14.78486061], [80.09791565, 14.7840271], [80.09764099, 14.78403187], [80.09764099, 14.78375244], [80.09792328, 14.78375244], [80.09792328, 14.78264236], [80.0984726, 14.78264236], [80.0984726, 14.78208065], [80.09819794, 14.78208256], [80.09819794, 14.78180504], [80.09764099, 14.78181171], [80.09764099, 14.78152943], [80.09792328, 14.78152943], [80.09792328, 14.78069115], [80.09819794, 14.78069305], [80.09819794, 14.77930546], [80.0984726, 14.77930927], [80.0984726, 14.77902889], [80.09874725, 14.77902889], [80.09874725, 14.77847099], [80.09902954, 14.7784729], [80.09902954, 14.77763939], [80.09929657, 14.7776413], [80.09929657, 14.77707958], [80.09986115, 14.7770834], [80.09986115, 14.77625084], [80.1001358, 14.77625084], [80.1001358, 14.77569008], [80.09986115, 14.77569485], [80.09986115, 14.77513885], [80.1001358, 14.77514076], [80.1001358, 14.77431107], [80.09986115, 14.77431107], [80.09986115, 14.77347946], [80.1001358, 14.77347946], [80.1001358, 14.77292061], [80.10041809, 14.77292061], [80.10041809, 14.77264118], [80.10069275, 14.77264118], [80.10069275, 14.77181053], [80.10098267, 14.77181053], [80.10098267, 14.77097034], [80.10124969, 14.77097225], [80.10124969, 14.77041626], [80.10097504, 14.77041626], [80.10097504, 14.76986027], [80.10124969, 14.76986027], [80.10124969, 14.76930618], [80.10151672, 14.76931095], [80.10151672, 14.76819038], [80.10180664, 14.7681942], [80.10180664, 14.76735973], [80.10236359, 14.76735973], [80.10236359, 14.76708412], [80.1029129, 14.76708412], [80.1029129, 14.76624966], [80.10346985, 14.76624966], [80.10346985, 14.76541996], [80.10375214, 14.76541996], [80.10375214, 14.76486015], [80.10402679, 14.76486206], [80.10402679, 14.7640276], [80.10430908, 14.76403046], [80.10430908, 14.76318932], [80.10402679, 14.76319408], [80.10402679, 14.76264], [80.10375214, 14.76264], [80.10375214, 14.7618103], [80.10402679, 14.7618103], [80.10402679, 14.76154137], [80.10430908, 14.76154137], [80.10430908, 14.76069069], [80.10458374, 14.7606926], [80.10458374, 14.76041794], [80.1048584, 14.76042175], [80.1048584, 14.76014042], [80.10514069, 14.76014042], [80.10514069, 14.75986195], [80.1054306, 14.75986195], [80.10541534, 14.75874901], [80.10597229, 14.75875187], [80.10597229, 14.75847054], [80.10569763, 14.75847054], [80.10569763, 14.75708294], [80.10597229, 14.75708294], [80.10597229, 14.75680542], [80.10624695, 14.75681019], [80.10624695, 14.75597095], [80.10652924, 14.75597095], [80.10652924, 14.75541687], [80.10680389, 14.75541687], [80.10680389, 14.75513935], [80.10736084, 14.75513935], [80.10736084, 14.75458145], [80.10708618, 14.75458336], [80.10708618, 14.75402737], [80.10736084, 14.75402927], [80.10736084, 14.75374889], [80.10764313, 14.75374889], [80.1076355, 14.75347328], [80.10791779, 14.75347328], [80.10791779, 14.75319481], [80.10819244, 14.75319481], [80.10819244, 14.75291729], [80.1084671, 14.7529192], [80.1084671, 14.75125122], [80.10874939, 14.75125122], [80.10874939, 14.75097084], [80.10901642, 14.75097084], [80.10901642, 14.75069046], [80.10930634, 14.75069523], [80.10930634, 14.75013924], [80.10958099, 14.75014114], [80.10958099, 14.74931145], [80.11013794, 14.74931145], [80.11013794, 14.74903107], [80.11042023, 14.74903107], [80.11042023, 14.74847031], [80.11069489, 14.74847317], [80.11069489, 14.74680424], [80.11096954, 14.74681091], [80.11096954, 14.74624062], [80.11125183, 14.74625111], [80.11125183, 14.74569511], [80.11152649, 14.74569511], [80.11152649, 14.74556923], [80.11152649, 14.74402809], [80.11180878, 14.74403095], [80.11180878, 14.74374962], [80.11235809, 14.74374962], [80.11235809, 14.74403095], [80.11347198, 14.74403095], [80.11347198, 14.74374962], [80.11374664, 14.74374962], [80.11374664, 14.74318123], [80.11402893, 14.74319363], [80.11402893, 14.74291611], [80.11429596, 14.74292088], [80.11429596, 14.74263954], [80.11458588, 14.74263954], [80.11458588, 14.74207973], [80.11486053, 14.74208355], [80.11486053, 14.74180603], [80.11514282, 14.7418108], [80.11514282, 14.74153137], [80.11429596, 14.74153137], [80.11429596, 14.74013996], [80.11458588, 14.74013996], [80.11458588, 14.73958015], [80.11486053, 14.73958397], [80.11486053, 14.73763847], [80.11514282, 14.73764038], [80.11514282, 14.73430061], [80.11486053, 14.73430634], [80.11486053, 14.73208427], [80.11458588, 14.73208427], [80.11458588, 14.73124886], [80.11486053, 14.73124886], [80.11486053, 14.73097134], [80.11513519, 14.73097134], [80.11513519, 14.73069572], [80.11541748, 14.73069572], [80.11541748, 14.73097134], [80.11569214, 14.73097134], [80.11569214, 14.73153019], [80.1159668, 14.73153019], [80.1159668, 14.73236179], [80.11624908, 14.73236179], [80.11624908, 14.73291969], [80.11653137, 14.73291779], [80.11653137, 14.73347092], [80.11680603, 14.73347092], [80.11680603, 14.73402977], [80.11653137, 14.73402786], [80.11653137, 14.73569584], [80.11680603, 14.73569107], [80.11680603, 14.7365303], [80.11708069, 14.7365303], [80.11708069, 14.73680973], [80.11736298, 14.73680592], [80.11736298, 14.73708439], [80.11708069, 14.73708153], [80.11708069, 14.73737144], [80.11680603, 14.73737144], [80.11680603, 14.73764038], [80.11653137, 14.73763847], [80.11653137, 14.73819447], [80.11624908, 14.73819447], [80.11624908, 14.73847198], [80.1159668, 14.73847198], [80.1159668, 14.73875046], [80.11569214, 14.73875046], [80.11569214, 14.73931122], [80.11597443, 14.73930645], [80.11597443, 14.73958397], [80.11653137, 14.73958397], [80.11653137, 14.73930645], [80.11708069, 14.73931122], [80.11708069, 14.73903275], [80.11737061, 14.73903275], [80.11737061, 14.73847198], [80.11763763, 14.73847198], [80.11763763, 14.73791599], [80.11791992, 14.73791981], [80.11791992, 14.73737144], [80.11846924, 14.73737144], [80.11846924, 14.7365303], [80.11875153, 14.7365303], [80.11875153, 14.73596859], [80.11902618, 14.7359724], [80.11902618, 14.73569584], [80.11958313, 14.73569584], [80.11958313, 14.73513985], [80.12014008, 14.73513985], [80.12014008, 14.73485947], [80.12041473, 14.73486233], [80.12041473, 14.73430634], [80.12097168, 14.73430634], [80.12097168, 14.73402786], [80.12124634, 14.73402977], [80.12124634, 14.73375034], [80.12152863, 14.73375034], [80.12152863, 14.73347092], [80.12180328, 14.73347092], [80.12180328, 14.7331934], [80.12208557, 14.7331934], [80.12208557, 14.73291779], [80.12236023, 14.73291969], [80.12236023, 14.73236179], [80.12264252, 14.73236179], [80.12264252, 14.73208141], [80.12291718, 14.73208427], [80.12291718, 14.73180485], [80.12317657, 14.73180962], [80.12317657, 14.73153019], [80.12346649, 14.73153019], [80.12346649, 14.73124027], [80.12374878, 14.73124886], [80.12374878, 14.73069572], [80.12403107, 14.73069572], [80.12403107, 14.73041534], [80.12458038, 14.73042202], [80.12458038, 14.73014164], [80.12541962, 14.73014164], [80.12541962, 14.72874928], [80.12568665, 14.72874928], [80.12568665, 14.72846889], [80.12596893, 14.7284708], [80.12596893, 14.72819519], [80.12623596, 14.72819996], [80.12623596, 14.72791958], [80.12652588, 14.72791958], [80.12652588, 14.72625065], [80.12680817, 14.72625065], [80.12680817, 14.72597122], [80.12708282, 14.72597313], [80.12708282, 14.72569466], [80.12735748, 14.72569466], [80.12735748, 14.72513866], [80.12763977, 14.72514057], [80.12763977, 14.72486115], [80.12819672, 14.72486115], [80.12819672, 14.72458267], [80.12847137, 14.72458267], [80.12847137, 14.72430515], [80.12902832, 14.72431183], [80.12902832, 14.72375107], [80.12931061, 14.72375107], [80.12931061, 14.72347069], [80.12985992, 14.7234726], [80.12985992, 14.7229166], [80.13014221, 14.72292137], [80.13014221, 14.72236061], [80.13041687, 14.72236061], [80.13041687, 14.72208023], [80.13069153, 14.72208309], [80.13069153, 14.72152901], [80.13096619, 14.72153091], [80.13096619, 14.72097015], [80.13124847, 14.72097301], [80.13124847, 14.72069454], [80.13153076, 14.72069454], [80.13153076, 14.72013855], [80.13208008, 14.72014141], [80.13208008, 14.71986008], [80.13237, 14.71986008], [80.13236237, 14.7195816], [80.13263702, 14.7195816], [80.13263702, 14.71902943], [80.13291931, 14.71903133], [80.13291931, 14.71764088], [80.13318634, 14.71764088], [80.13318634, 14.71735954], [80.13346863, 14.71736336], [80.13346863, 14.71652794], [80.13375092, 14.7165308], [80.13375092, 14.71597004], [80.13402557, 14.71597195], [80.13402557, 14.71541595], [80.13430786, 14.71542072], [80.13430786, 14.71485996], [80.13458252, 14.71485996], [80.13458252, 14.71457958], [80.13486481, 14.71458435], [80.13486481, 14.71430588], [80.13513947, 14.71431065], [80.13513947, 14.71403027], [80.13540649, 14.71403027], [80.13540649, 14.71347046], [80.13513947, 14.71347237], [80.13513947, 14.71208191], [80.13541412, 14.71208191], [80.13541412, 14.71236229], [80.13597107, 14.71236229], [80.13597107, 14.71125031], [80.13652802, 14.71125031], [80.13652802, 14.71069241], [80.13680267, 14.71069431], [80.13680267, 14.71041584], [80.13652802, 14.71041965], [80.13652802, 14.70903015], [80.13680267, 14.70903015], [80.13680267, 14.70819092], [80.13652802, 14.70819378], [80.13652802, 14.70736217], [80.13680267, 14.70736217], [80.13680267, 14.70680618], [80.13707733, 14.70681], [80.13707733, 14.70625019], [80.13735962, 14.70625019], [80.13735962, 14.70597076], [80.13791656, 14.70597076], [80.13791656, 14.70569324], [80.13819122, 14.70569324], [80.13819122, 14.70486164], [80.13791656, 14.70486164], [80.13791656, 14.70403194], [80.13764191, 14.70403194], [80.13764191, 14.70347118], [80.13735962, 14.70347118], [80.13735962, 14.7029171], [80.13707733, 14.70292187], [80.13707733, 14.70264244], [80.13680267, 14.70264244], [80.13680267, 14.70208073], [80.13652802, 14.70208263], [80.13652802, 14.70124912], [80.13625336, 14.70125961], [80.13625336, 14.70097065], [80.13569641, 14.70097256], [80.13569641, 14.70041656], [80.13540649, 14.70041943], [80.13540649, 14.70014095], [80.13513947, 14.70014095], [80.13513947, 14.69958115], [80.13486481, 14.69958305], [80.13486481, 14.69930458], [80.13458252, 14.6993103], [80.13458252, 14.69847107], [80.13430786, 14.69847298], [80.13430786, 14.69819546], [80.1340332, 14.69820023], [80.1340332, 14.69791889], [80.13375092, 14.69791889], [80.13375092, 14.69736099], [80.13346863, 14.69736099], [80.13346863, 14.69625092], [80.13318634, 14.69625092], [80.13318634, 14.6957016], [80.13291931, 14.69569016], [80.13291931, 14.69513893], [80.13236237, 14.69513893], [80.13236237, 14.69486141], [80.13208008, 14.69486141], [80.13208008, 14.69458294], [80.13180542, 14.69458294], [80.13180542, 14.69402885], [80.13124847, 14.69403076], [80.13124847, 14.69375134], [80.13096619, 14.69375134], [80.13096619, 14.69347], [80.13069153, 14.69347286], [80.13069153, 14.69319534], [80.13041687, 14.69319534], [80.13041687, 14.69291687], [80.12985992, 14.69292068], [80.12985992, 14.69264126], [80.12960052, 14.69264126], [80.12960052, 14.69207096], [80.13014221, 14.69208241], [80.13014221, 14.69180679], [80.13041687, 14.69180679], [80.13041687, 14.69208241], [80.13124847, 14.69207096], [80.13124847, 14.69235992], [80.13181305, 14.69235992], [80.13181305, 14.69264126], [80.13237, 14.69264126], [80.13237, 14.69235992], [80.13263702, 14.69235992], [80.13263702, 14.69207096], [80.13318634, 14.69207096], [80.13318634, 14.69235992], [80.1340332, 14.69235992], [80.1340332, 14.69264126], [80.13430786, 14.69264126], [80.13430786, 14.69292068], [80.13458252, 14.69291687], [80.13458252, 14.69458294], [80.13485718, 14.69458008], [80.13485718, 14.69542122], [80.13513947, 14.6954174], [80.13513947, 14.6959734], [80.13540649, 14.69597054], [80.13540649, 14.69625092], [80.13569641, 14.69625092], [80.13569641, 14.6965313], [80.13597107, 14.6965313], [80.13597107, 14.69681168], [80.13569641, 14.69681168], [80.13569641, 14.69791889], [80.13597107, 14.69791889], [80.13597107, 14.69820023], [80.13625336, 14.69820023], [80.13625336, 14.69875145], [80.13680267, 14.69875145], [80.13680267, 14.69903088], [80.13707733, 14.69903088], [80.13707733, 14.6993103], [80.13735962, 14.69930458], [80.13735962, 14.69986057], [80.13764191, 14.69986057], [80.13764191, 14.70041943], [80.13791656, 14.70041656], [80.13791656, 14.70097256], [80.13846588, 14.70097065], [80.13846588, 14.70125961], [80.13874817, 14.70125961], [80.13874817, 14.70152855], [80.13903046, 14.70152664], [80.13903046, 14.70236111], [80.13931274, 14.7023592], [80.13931274, 14.70264244], [80.13957977, 14.70264244], [80.13957977, 14.70292187], [80.13986206, 14.7029171], [80.13986206, 14.70319462], [80.14013672, 14.70319462], [80.14013672, 14.70597363], [80.13986206, 14.70597076], [80.13986206, 14.70652962], [80.13957977, 14.70652771], [80.13957977, 14.70819378], [80.13931274, 14.70819092], [80.13931274, 14.70930958], [80.13903046, 14.70930958], [80.13903046, 14.71041965], [80.13874817, 14.71041584], [80.13874817, 14.71097183], [80.13846588, 14.71097183], [80.13846588, 14.71181107], [80.13819122, 14.7118063], [80.13819122, 14.71236229], [80.13791656, 14.71236038], [80.13791656, 14.71292114], [80.13764191, 14.71291637], [80.13764191, 14.71347237], [80.13735962, 14.71347046], [80.13735962, 14.71403027], [80.13708496, 14.71402836], [80.13708496, 14.71458435], [80.13680267, 14.71457958], [80.13680267, 14.71485996], [80.13652802, 14.71485996], [80.13652802, 14.71597195], [80.13625336, 14.71597004], [80.13625336, 14.7165308], [80.13597107, 14.71652794], [80.13597107, 14.71708202], [80.13569641, 14.71708012], [80.13569641, 14.71764088], [80.13541412, 14.71763802], [80.13541412, 14.71819401], [80.13513947, 14.71819019], [80.13513947, 14.71875095], [80.13569641, 14.71875095], [80.13569641, 14.71846962], [80.13597107, 14.71847343], [80.13597107, 14.71791553], [80.13625336, 14.71792126], [80.13625336, 14.71764088], [80.13652802, 14.71764088], [80.13652802, 14.71735954], [80.13680267, 14.71736336], [80.13680267, 14.71680641], [80.13707733, 14.71681118], [80.13707733, 14.7165308], [80.13735962, 14.7165308], [80.13735962, 14.71626186], [80.13764191, 14.71626186], [80.13764191, 14.71597004], [80.13791656, 14.71597195], [80.13791656, 14.71541595], [80.13817596, 14.71542072], [80.13817596, 14.71514034], [80.13846588, 14.71514034], [80.13846588, 14.71457958], [80.13874817, 14.71458435], [80.13874817, 14.71347237], [80.13903046, 14.71347237], [80.13903046, 14.71236229], [80.13930511, 14.71236229], [80.13930511, 14.71125031], [80.13957977, 14.71125031], [80.13957977, 14.71014023], [80.13986206, 14.71014023], [80.13986206, 14.70957947], [80.14013672, 14.70958424], [80.14013672, 14.70930576], [80.14125061, 14.70930958], [80.14125061, 14.70874977], [80.14154053, 14.70874977], [80.14154053, 14.70819092], [80.14180756, 14.70819378], [80.14180756, 14.70625019], [80.14208221, 14.70625019], [80.14208221, 14.70541954], [80.14235687, 14.70541954], [80.14235687, 14.70458126], [80.14263916, 14.70458317], [80.14263916, 14.7037487], [80.14290619, 14.70375156], [80.14290619, 14.70292187], [80.14319611, 14.70292187], [80.14319611, 14.70208073], [80.14347076, 14.70208263], [80.14347076, 14.70152664], [80.14375305, 14.70152855], [80.14375305, 14.70069122], [80.14402771, 14.70069313], [80.14402771, 14.70013905], [80.14431, 14.70014095], [80.14431, 14.69958115], [80.14458466, 14.69958305], [80.14458466, 14.69902706], [80.14485931, 14.69903088], [80.14485931, 14.69875145], [80.14457703, 14.69875145], [80.14457703, 14.69820023], [80.14431, 14.69820023], [80.14431, 14.69708061], [80.14458466, 14.69708347], [80.14458466, 14.69652653], [80.14485931, 14.6965313], [80.14485931, 14.69569016], [80.1451416, 14.69569492], [80.1451416, 14.69513893], [80.14541626, 14.69513893], [80.14541626, 14.69263935], [80.1451416, 14.69264126], [80.1451416, 14.69207096], [80.14569092, 14.69208241], [80.14569092, 14.69152641], [80.14597321, 14.69153118], [80.14597321, 14.69069195], [80.14624786, 14.69069386], [80.14624786, 14.68986034], [80.14653015, 14.68986034], [80.14653015, 14.68902779], [80.14679718, 14.68903065], [80.14679718, 14.68819046], [80.1470871, 14.68819427], [80.1470871, 14.68764019], [80.1473465, 14.68764019], [80.1473465, 14.68736172], [80.1470871, 14.68736172], [80.1470871, 14.68681145], [80.14679718, 14.68681145], [80.14679718, 14.68624973], [80.1470871, 14.68624973], [80.1470871, 14.68569183], [80.14736176, 14.68569374], [80.14736176, 14.68513775], [80.14763641, 14.68513966], [80.14763641, 14.6845789], [80.1479187, 14.68458366], [80.1479187, 14.68347168], [80.14819336, 14.68347168], [80.14819336, 14.68264008], [80.14848328, 14.68264008], [80.14848328, 14.68153], [80.14875031, 14.68153], [80.14875031, 14.68041992], [80.14901733, 14.68041992], [80.14901733, 14.67931175], [80.14930725, 14.67931175], [80.14930725, 14.67847061], [80.1498642, 14.67847061], [80.1498642, 14.67791843], [80.15013885, 14.67792034], [80.15013885, 14.67736053], [80.15041351, 14.67736053], [80.15041351, 14.67680454], [80.15013885, 14.67681026], [80.15013885, 14.67569065], [80.15041351, 14.67569542], [80.15041351, 14.67486095], [80.15097046, 14.67486095], [80.15097046, 14.67402935], [80.1506958, 14.67402935], [80.1506958, 14.67347145], [80.15041351, 14.67347336], [80.15041351, 14.67291737], [80.1506958, 14.67291927], [80.1506958, 14.67263889], [80.15125275, 14.67263889], [80.15125275, 14.67236137], [80.1515274, 14.67236137], [80.1515274, 14.6712513], [80.15180206, 14.6712513], [80.15180206, 14.67068958], [80.1515274, 14.6706953], [80.1515274, 14.67041683], [80.15180206, 14.67042065], [80.15180206, 14.66903114], [80.15207672, 14.66903114], [80.15207672, 14.66819], [80.15235901, 14.66819477], [80.15235901, 14.66791725], [80.1526413, 14.66792107], [80.1526413, 14.66764069], [80.15235901, 14.66764069], [80.15235901, 14.66736126], [80.1526413, 14.66736126], [80.1526413, 14.66625118], [80.15291595, 14.66625118], [80.15291595, 14.66569042], [80.15319061, 14.66569519], [80.15319824, 14.66541672], [80.15348053, 14.66542053], [80.15348053, 14.66431141], [80.15374756, 14.66431141], [80.15374756, 14.66209126], [80.15402985, 14.66209126], [80.15402985, 14.66125011], [80.15429687, 14.66125011], [80.15429687, 14.65931129], [80.15486145, 14.65931129], [80.15486145, 14.65819168], [80.15513611, 14.65819359], [80.15513611, 14.65791798], [80.1554184, 14.65792274], [80.1554184, 14.65764046], [80.15569305, 14.65764046], [80.15569305, 14.65736198], [80.15598297, 14.65736198], [80.15597534, 14.65625], [80.15625, 14.65625], [80.15625, 14.65568924], [80.15597534, 14.65569401], [80.15597534, 14.65513992], [80.15625, 14.65513992], [80.15625, 14.65485954], [80.15652466, 14.6548624], [80.15652466, 14.65375042], [80.15625, 14.65375042], [80.15625, 14.65264034], [80.15651703, 14.65264034], [80.15651703, 14.65208054], [80.1570816, 14.65208435], [80.1570816, 14.65180588], [80.15625, 14.65180969], [80.15625, 14.65125179], [80.15651703, 14.65125179], [80.15651703, 14.65015125], [80.15680695, 14.65015125], [80.15680695, 14.64903164], [80.1570816, 14.64903164], [80.1570816, 14.64819145], [80.15736389, 14.64819527], [80.15736389, 14.64708328], [80.15763855, 14.64708328], [80.15763855, 14.64624882], [80.15791321, 14.64625072], [80.15791321, 14.64514065], [80.15820313, 14.64514065], [80.15820313, 14.64402008], [80.15847015, 14.64402676], [80.15847015, 14.64319515], [80.15875244, 14.64319515], [80.15875244, 14.64236069], [80.1590271, 14.64236069], [80.1590271, 14.64153099], [80.1592865, 14.64153099], [80.1592865, 14.64068985], [80.15958405, 14.64069462], [80.15958405, 14.64013863], [80.1598587, 14.64014053], [80.1598587, 14.63931084], [80.16014099, 14.63931084], [80.16014099, 14.6384697], [80.16041565, 14.63847256], [80.16041565, 14.63763809], [80.16069794, 14.63764095], [80.16069794, 14.63681126], [80.1609726, 14.63681126], [80.1609726, 14.63597012], [80.16124725, 14.63597202], [80.16124725, 14.63541603], [80.16152954, 14.6354208], [80.16152954, 14.63457966], [80.1618042, 14.63458443], [80.1618042, 14.63374996], [80.16208649, 14.63374996], [80.16208649, 14.63292122], [80.16234589, 14.63292122], [80.16234589, 14.63208199], [80.1626358, 14.63208199], [80.1626358, 14.63125038], [80.16291809, 14.63125038], [80.16291809, 14.63069153], [80.16319275, 14.63069439], [80.16319275, 14.62986183], [80.16348267, 14.62986183], [80.16347504, 14.62930584], [80.16374969, 14.62930965], [80.16374969, 14.62846947], [80.16402435, 14.62847233], [80.16402435, 14.62791634], [80.16430664, 14.62792015], [80.16430664, 14.62708092], [80.1645813, 14.62708378], [80.1645813, 14.62625027], [80.16485596, 14.62625027], [80.16485596, 14.62569141], [80.16513824, 14.62569332], [80.16513824, 14.62486172], [80.16542053, 14.62486172], [80.1654129, 14.62402725], [80.16570282, 14.62403202], [80.16570282, 14.62347126], [80.16596985, 14.62347126], [80.16596985, 14.6226387], [80.16625214, 14.62264156], [80.16625214, 14.62180996], [80.16652679, 14.62180996], [80.16652679, 14.6212492], [80.16680908, 14.6212492], [80.16680908, 14.6206913], [80.16708374, 14.62069321], [80.16708374, 14.62013912], [80.1673584, 14.62014103], [80.1673584, 14.61958122], [80.16764069, 14.61958313], [80.16764069, 14.61902714], [80.16792297, 14.61903191], [80.16792297, 14.61847115], [80.16819763, 14.61847305], [80.16819763, 14.61791706], [80.16847992, 14.61792183], [80.16847992, 14.61736107], [80.16874695, 14.61736107], [80.16874695, 14.61681175], [80.16902924, 14.61681175], [80.16902924, 14.61625099], [80.16929626, 14.61625099], [80.16929626, 14.61597061], [80.16958618, 14.61597347], [80.16958618, 14.61541653], [80.16986084, 14.6154213], [80.16986084, 14.61486053], [80.1701355, 14.61486053], [80.1701355, 14.61430454], [80.17041779, 14.61430931], [80.17041779, 14.61375141], [80.17069244, 14.61375141], [80.17069244, 14.6131897], [80.17097473, 14.61319542], [80.17097473, 14.61263943], [80.17124939, 14.61264133], [80.17124939, 14.61207962], [80.17152405, 14.61208153], [80.17152405, 14.61180687], [80.17180634, 14.61181068], [80.17180634, 14.61125088], [80.17208099, 14.61125088], [80.17208099, 14.60958004], [80.17236328, 14.60958195], [80.17236328, 14.60930634], [80.17263794, 14.6093111], [80.17263794, 14.60903072], [80.17318726, 14.60903072], [80.17318726, 14.60875034], [80.17346954, 14.60875034], [80.17346954, 14.60846996], [80.17375183, 14.60847187], [80.17375183, 14.60819435], [80.17402649, 14.60819435], [80.17402649, 14.60791588], [80.17458344, 14.60791588], [80.17458344, 14.60764027], [80.17485809, 14.60764027], [80.17485809, 14.60736179], [80.17514038, 14.60736179], [80.17514038, 14.60708046], [80.17541504, 14.60708427], [80.17541504, 14.6068058], [80.17597198, 14.60681057], [80.17597198, 14.60653019], [80.17624664, 14.60653019], [80.17624664, 14.60625172], [80.17679596, 14.60625172], [80.17679596, 14.60597038], [80.17708588, 14.60597229], [80.17708588, 14.60569382], [80.17763519, 14.60569382], [80.17763519, 14.6054163], [80.17791748, 14.60542107], [80.17791748, 14.60513973], [80.1784668, 14.60513973], [80.1784668, 14.6048708], [80.17903137, 14.6048708], [80.17903137, 14.60458183], [80.17930603, 14.60458374], [80.17930603, 14.60430622], [80.17986298, 14.60431099], [80.17986298, 14.60402966], [80.18041992, 14.60402966], [80.18041992, 14.60375023], [80.18096924, 14.60375023], [80.18096924, 14.60346985], [80.18152618, 14.60347176], [80.18152618, 14.60319424], [80.18208313, 14.60319424], [80.18208313, 14.60291576], [80.18235779, 14.60291958], [80.18235779, 14.60264015], [80.1829071, 14.60264015], [80.1829071, 14.60235977], [80.18345642, 14.60235977], [80.18345642, 14.60207939], [80.18430328, 14.60208416], [80.18430328, 14.60180569], [80.18541718, 14.60181046], [80.18541718, 14.60153008], [80.18596649, 14.60153008], [80.18596649, 14.60124969], [80.18681335, 14.60124969], [80.18681335, 14.60096931], [80.18736267, 14.60097218], [80.18736267, 14.6006937], [80.18763733, 14.6006937], [80.18763733, 14.60041809], [80.18791962, 14.60042], [80.18791962, 14.60013962], [80.18818665, 14.60013962], [80.18818665, 14.60042], [80.18930817, 14.60041809], [80.18930817, 14.6006937], [80.19041443, 14.6006937], [80.19041443, 14.60097218], [80.19180298, 14.60097218], [80.19180298, 14.6006937], [80.19235992, 14.6006937], [80.19235992, 14.60041809], [80.19264984, 14.60042], [80.19264984, 14.60013962], [80.19291687, 14.60013962], [80.19291687, 14.59985924], [80.19319153, 14.5998621], [80.19319153, 14.59930611], [80.19346619, 14.59930992], [80.19346619, 14.59875202], [80.19374847, 14.59875202], [80.19374847, 14.59847069], [80.19403076, 14.59847355], [80.19403076, 14.59819317], [80.19430542, 14.59819317], [80.19430542, 14.59764004], [80.19458008, 14.59764194], [80.19458008, 14.59681034], [80.19486237, 14.59681034], [80.19486237, 14.59513855], [80.19513702, 14.59513855], [80.19513702, 14.59486103], [80.19625092, 14.59486103], [80.19625092, 14.59458065], [80.19652557, 14.59458256], [80.19652557, 14.59430504], [80.19680786, 14.59431171], [80.19680786, 14.59402943], [80.19708252, 14.59402943], [80.19708252, 14.59319115], [80.19736481, 14.59319305], [80.19736481, 14.59013939], [80.19763947, 14.5901413], [80.19763947, 14.58958054], [80.19791412, 14.5895834], [80.19791412, 14.58847332], [80.19819641, 14.58847332], [80.19819641, 14.58791733], [80.19845581, 14.58791924], [80.19845581, 14.58764076], [80.19875336, 14.58764076], [80.19875336, 14.58708], [80.19902802, 14.58708286], [80.19902802, 14.5840292], [80.19875336, 14.58403111], [80.19875336, 14.58373928], [80.19819641, 14.58375072], [80.19819641, 14.58347225], [80.19791412, 14.58347225], [80.19791412, 14.58291626], [80.19763947, 14.58292103], [80.19763947, 14.58236027], [80.19736481, 14.58236027], [80.19736481, 14.5820837], [80.19763947, 14.5820837], [80.19763947, 14.58180428], [80.19790649, 14.58181095], [80.19790649, 14.58068085], [80.19763947, 14.5806942], [80.19763947, 14.57958412], [80.19736481, 14.57958412], [80.19736481, 14.57930565], [80.19708252, 14.57931137], [80.19706726, 14.57820129], [80.19680786, 14.5781889], [80.19680786, 14.57806015], [80.19680786, 14.57680607], [80.1965332, 14.57681274], [80.1965332, 14.57653046], [80.19625092, 14.57653046], [80.19625092, 14.57625198], [80.19596863, 14.57625198], [80.19596863, 14.57568932], [80.19569397, 14.57569408], [80.19569397, 14.57374954], [80.19541931, 14.57374954], [80.19541931, 14.57291985], [80.19513702, 14.57291985], [80.19513702, 14.57180119], [80.19486237, 14.57180595], [80.19486237, 14.57097054], [80.19458008, 14.57097054], [80.19458008, 14.57013988], [80.19431305, 14.57014179], [80.19431305, 14.56931019], [80.19403076, 14.56931019], [80.19403076, 14.56819057], [80.19374847, 14.56819534], [80.19374847, 14.56736088], [80.19346619, 14.56736088], [80.19346619, 14.56652927], [80.19319153, 14.56652927], [80.19319153, 14.56597137], [80.19291687, 14.56597328], [80.19291687, 14.56541729], [80.19264984, 14.5654192], [80.19264984, 14.5648613], [80.19235992, 14.5648613], [80.19235992, 14.56375122], [80.19208527, 14.56375122], [80.19208527, 14.56291676], [80.19180298, 14.56293106], [80.19180298, 14.5618124], [80.19152832, 14.5618124], [80.19152832, 14.56068993], [80.19125366, 14.56069469], [80.19125366, 14.55930519], [80.19097137, 14.55931091], [80.19097137, 14.55819035], [80.19069672, 14.55819511], [80.19069672, 14.55736256], [80.19041443, 14.5573597], [80.1904068, 14.55708027], [80.19013977, 14.55708218], [80.19013977, 14.55680656], [80.18958282, 14.55680656], [80.18958282, 14.55652905], [80.18930817, 14.55653095], [80.18930817, 14.55624962], [80.18902588, 14.55624962], [80.18902588, 14.55569172], [80.18875122, 14.55569363], [80.18875122, 14.55458355], [80.18846893, 14.55458355], [80.18846893, 14.55319405], [80.18819427, 14.55319405], [80.18819427, 14.55208206], [80.18791962, 14.55208206], [80.18791962, 14.55069447], [80.18763733, 14.55070114], [80.18763733, 14.54957867], [80.18736267, 14.54958439], [80.18736267, 14.5484724], [80.18708038, 14.5484724], [80.18708038, 14.54763985], [80.18680573, 14.54763985], [80.18680573, 14.54652786], [80.18651581, 14.54652977], [80.18651581, 14.54569054], [80.18624878, 14.54569435], [80.18624878, 14.54486179], [80.18596649, 14.54486179], [80.18596649, 14.54375172], [80.18569183, 14.54375172], [80.18569183, 14.54292202], [80.18541718, 14.54292202], [80.18541718, 14.54208088], [80.18514252, 14.54208279], [80.18514252, 14.54097271], [80.18486023, 14.5409708], [80.18486023, 14.5401392], [80.1845932, 14.5401392], [80.1845932, 14.53931046], [80.18430328, 14.53931046], [80.18430328, 14.53819275], [80.18402863, 14.53819466], [80.18402863, 14.53736115], [80.18374634, 14.53736115], [80.18374634, 14.53680515], [80.18345642, 14.53681183], [80.18345642, 14.53653145], [80.18319702, 14.53653145], [80.18319702, 14.53625107], [80.1829071, 14.53625107], [80.1829071, 14.53597069], [80.18264008, 14.5359726], [80.18264008, 14.53569508], [80.18235779, 14.53569508], [80.18235779, 14.5354166], [80.18208313, 14.53542137], [80.18208313, 14.53514099], [80.17914581, 14.53514099], [80.17874908, 14.53514099], [80.17874908, 14.53486061], [80.17847443, 14.53486061], [80.17847443, 14.53458309], [80.17791748, 14.53458309], [80.17791748, 14.53430462], [80.17764282, 14.53430939], [80.17764282, 14.53403091], [80.17708588, 14.53403091], [80.17708588, 14.53375053], [80.17679596, 14.53375053], [80.17679596, 14.53347111], [80.17624664, 14.53347301], [80.17624664, 14.53319454], [80.17542267, 14.53318977], [80.17542267, 14.53375053], [80.17514038, 14.53375053], [80.17514038, 14.53403091], [80.17485809, 14.53402901], [80.17485809, 14.53458309], [80.17457581, 14.53458023], [80.17457581, 14.53514099], [80.17430878, 14.53514099], [80.17430878, 14.53542137], [80.17402649, 14.5354166], [80.17402649, 14.53569508], [80.17263794, 14.53569508], [80.17263794, 14.53513908], [80.17236328, 14.53514099], [80.17236328, 14.53458023], [80.17263794, 14.53458309], [80.17263794, 14.53374863], [80.17292023, 14.53375053], [80.17292023, 14.53263187], [80.17319489, 14.53263855], [80.17319489, 14.53208256], [80.17346954, 14.53208256], [80.17346954, 14.53180695], [80.17402649, 14.53181076], [80.17402649, 14.53153133], [80.17652893, 14.53153133], [80.17652893, 14.53181076], [80.17819214, 14.53180695], [80.17819214, 14.53208256], [80.1784668, 14.5320797], [80.1784668, 14.53236103], [80.17874908, 14.53236103], [80.17874908, 14.53263855], [80.17903137, 14.53263855], [80.17903137, 14.53319454], [80.17930603, 14.53319454], [80.17930603, 14.53347301], [80.17958069, 14.53347111], [80.17958069, 14.53375053], [80.18068695, 14.53375053], [80.18068695, 14.53347111], [80.18096924, 14.53347301], [80.18096924, 14.53319454], [80.18125153, 14.53319454], [80.18125153, 14.53291702], [80.18152618, 14.53292084], [80.18152618, 14.53236103], [80.18180847, 14.53236103], [80.18180847, 14.53181076], [80.18208313, 14.53181076], [80.18208313, 14.53153133], [80.18264008, 14.53153133], [80.18264008, 14.53042126], [80.18235779, 14.53042126], [80.18235779, 14.52875042], [80.18208313, 14.52875042], [80.18208313, 14.52735996], [80.18180847, 14.52735996], [80.18180847, 14.52514267], [80.18152618, 14.52514267], [80.18152618, 14.52346134], [80.18125153, 14.52347183], [80.18125153, 14.52152824], [80.18096924, 14.52153015], [80.18096924, 14.51958084], [80.18069458, 14.5195837], [80.18069458, 14.51791763], [80.18041992, 14.51791954], [80.18041992, 14.51597118], [80.18013763, 14.51597118], [80.18013763, 14.51402664], [80.17986298, 14.51402855], [80.17986298, 14.51236057], [80.17958069, 14.51236057], [80.17958069, 14.50958347], [80.17930603, 14.50958347], [80.17930603, 14.50569534], [80.17903137, 14.50569534], [80.17903137, 14.50180435], [80.17874908, 14.50181103], [80.17874908, 14.49792099], [80.1784668, 14.49792099], [80.1784668, 14.49403], [80.17819214, 14.49403], [80.17819214, 14.49069118], [80.17791748, 14.49069309], [80.17791748, 14.48736095], [80.17763519, 14.48736095], [80.17763519, 14.48430538], [80.17736053, 14.48431015], [80.17736053, 14.48125076], [80.17708588, 14.48125076], [80.17708588, 14.47792053], [80.17679596, 14.47792053], [80.17679596, 14.47486019], [80.17652893, 14.47486019], [80.17652893, 14.47097206], [80.17624664, 14.47097206], [80.17624664, 14.46597195], [80.17597198, 14.46597195], [80.17597198, 14.46097088], [80.17569733, 14.46097088], [80.17569733, 14.45625114], [80.17541504, 14.45625114], [80.17541504, 14.45125103], [80.17514038, 14.45125103], [80.17514038, 14.44707966], [80.17485809, 14.44708443], [80.17485809, 14.44375038], [80.17457581, 14.44375038], [80.17457581, 14.44042015], [80.17430878, 14.44042015], [80.17430878, 14.43708134], [80.17402649, 14.4370842], [80.17402649, 14.4337492], [80.17375183, 14.4337492], [80.17375183, 14.43043137], [80.17346954, 14.43043137], [80.17346954, 14.4256897], [80.17319489, 14.42569542], [80.17319489, 14.41958427], [80.17292023, 14.41958427], [80.17292023, 14.41291809], [80.17263794, 14.41292], [80.17263794, 14.40569115], [80.17236328, 14.40569305], [80.17236328, 14.39013767], [80.17208099, 14.39013958], [80.17208099, 14.38735962], [80.17236328, 14.38736153], [80.17236328, 14.38624954], [80.17180634, 14.38624954], [80.17180634, 14.38486195], [80.17208099, 14.38486195], [80.17208099, 14.38264179], [80.17180634, 14.38264179], [80.17180634, 14.38097095], [80.17152405, 14.38097095], [80.17152405, 14.37930489], [80.17124939, 14.3793211], [80.17124939, 14.37764072], [80.1709671, 14.37764072], [80.1709671, 14.37597084], [80.17069244, 14.37597084], [80.17069244, 14.37458134], [80.17041779, 14.37458324], [80.17041779, 14.37069511], [80.17097473, 14.37069511], [80.17097473, 14.37013912], [80.17041779, 14.37013912], [80.17041779, 14.36958218], [80.1701355, 14.36958218], [80.1701355, 14.36458206], [80.16986084, 14.36458206], [80.16986084, 14.36069393], [80.16958618, 14.36069393], [80.16958618, 14.35958385], [80.16930389, 14.35958385], [80.16930389, 14.35902786], [80.16958618, 14.35902977], [80.16958618, 14.35875034], [80.16929626, 14.35875034], [80.16929626, 14.35819054], [80.16902924, 14.35819435], [80.16902924, 14.35708427], [80.16874695, 14.35708427], [80.16874695, 14.35569572], [80.16847229, 14.35569572], [80.16847229, 14.35430527], [80.16819763, 14.35431004], [80.16819763, 14.35374928], [80.16847992, 14.35374928], [80.16847229, 14.35319328], [80.16819763, 14.35319328], [80.16819763, 14.35236073], [80.16791534, 14.35236073], [80.16791534, 14.35180473], [80.16764069, 14.35181046], [80.16764069, 14.35014057], [80.1673584, 14.35014057], [80.1673584, 14.3495779], [80.16708374, 14.34958267], [80.16708374, 14.34902668], [80.16680908, 14.34902668], [80.16680908, 14.34819508], [80.16652679, 14.34819508], [80.16652679, 14.34763908], [80.16625214, 14.34764099], [80.16625214, 14.34680939], [80.16596985, 14.34680939], [80.16596985, 14.34486103], [80.16569519, 14.34486103], [80.16569519, 14.34458256], [80.1654129, 14.34458256], [80.1654129, 14.34347343], [80.16569519, 14.34347343], [80.16569519, 14.34291744], [80.16542053, 14.34292126], [80.16542053, 14.34235954], [80.16513824, 14.34235954], [80.16513824, 14.34180737], [80.16485596, 14.34181118], [80.16485596, 14.34042072], [80.1645813, 14.34042072], [80.1645813, 14.34015179], [80.16430664, 14.34015179], [80.16430664, 14.33985996], [80.16401672, 14.33985996], [80.16401672, 14.33903122], [80.16374969, 14.33903122], [80.16374969, 14.33847046], [80.16347504, 14.33847237], [80.16347504, 14.33791637], [80.16319275, 14.33792114], [80.16319275, 14.33736038], [80.16291809, 14.33736229], [80.16291809, 14.33652782], [80.1626358, 14.33652973], [80.1626358, 14.33597183], [80.16236115, 14.33597183], [80.16236115, 14.33541584], [80.16208649, 14.33541965], [80.16208649, 14.33485985], [80.16160583, 14.33485985], [80.16124725, 14.33485985], [80.16124725, 14.33402061], [80.16124725, 14.33374977], [80.16107178, 14.33374977], [80.1609726, 14.33374977], [80.1609726, 14.33360195], [80.1609726, 14.33319378], [80.16069794, 14.33319378], [80.16069794, 14.33236217], [80.16041565, 14.33236217], [80.16041565, 14.33180618], [80.16014099, 14.33181], [80.16014099, 14.33125019], [80.1598587, 14.33125019], [80.1598587, 14.33041954], [80.15957642, 14.33041954], [80.15957642, 14.32986164], [80.1592865, 14.32986164], [80.1592865, 14.32931042], [80.1590271, 14.32931042], [80.1590271, 14.32846928], [80.15875244, 14.32847118], [80.15875244, 14.32791805], [80.15847015, 14.32791996], [80.15847015, 14.3273592], [80.1581955, 14.32736111], [80.1581955, 14.32708263], [80.15791321, 14.32708263], [80.15791321, 14.32680511], [80.15763855, 14.32681179], [80.15763855, 14.32597065], [80.15736389, 14.32597256], [80.15736389, 14.32541656], [80.1570816, 14.32542038], [80.1570816, 14.32485199], [80.15680695, 14.32486057], [80.15680695, 14.32402706], [80.15651703, 14.32403183], [80.15651703, 14.32347107], [80.15625, 14.32347107], [80.15625, 14.32291698], [80.15598297, 14.32292175], [80.15598297, 14.32208061], [80.15569305, 14.32208347], [80.15569305, 14.32152653], [80.1554184, 14.3215313], [80.1554184, 14.32097054], [80.15513611, 14.3209734], [80.15513611, 14.32013893], [80.15486145, 14.32014084], [80.15486145, 14.31958008], [80.15458679, 14.31958294], [80.15458679, 14.31875134], [80.15429687, 14.31875134], [80.15429687, 14.31818962], [80.15402985, 14.31819534], [80.15402985, 14.31736088], [80.15374756, 14.31736088], [80.15374756, 14.31681061], [80.15348053, 14.31681061], [80.15348053, 14.31598186], [80.15319824, 14.31598186], [80.15319061, 14.3154211], [80.15290833, 14.3154211], [80.15291595, 14.31457996], [80.15262604, 14.31459141], [80.1526413, 14.31403065], [80.15244293, 14.31402779], [80.15235901, 14.31402779], [80.15235901, 14.31379414], [80.15235901, 14.31319427], [80.15208435, 14.31319427], [80.15208435, 14.31298923], [80.15208435, 14.31263828], [80.15196228, 14.31263828], [80.15180206, 14.31264019], [80.15180206, 14.31215954], [80.15180206, 14.31180573], [80.15167999, 14.31180859], [80.1515274, 14.31181145], [80.1515274, 14.31135273], [80.1515274, 14.31124973], [80.15125275, 14.31124973], [80.15125275, 14.31041622], [80.15116882, 14.31041813], [80.15097046, 14.31042099], [80.15097046, 14.31000996], [80.15097046, 14.30986214], [80.1506958, 14.30986214], [80.1506958, 14.30951977], [80.1506958, 14.30930614], [80.15058136, 14.30930614], [80.15040588, 14.30931091], [80.15041351, 14.30900955], [80.15041351, 14.30847168], [80.15013885, 14.30847168], [80.15013885, 14.30791569], [80.14985657, 14.30792046], [80.14985657, 14.30707932], [80.14958191, 14.30708408], [80.14958191, 14.30652809], [80.14930725, 14.30653], [80.14930725, 14.30568886], [80.14902496, 14.30569363], [80.14902496, 14.30513763], [80.14875031, 14.30513954], [80.14875031, 14.30430984], [80.14848328, 14.30430984], [80.14848328, 14.30375195], [80.14819336, 14.30375195], [80.14819336, 14.30292034], [80.1479187, 14.30292034], [80.1479187, 14.30236244], [80.14763641, 14.30236244], [80.14763641, 14.30152702], [80.1473465, 14.30153179], [80.1473465, 14.30097103], [80.1470871, 14.30097103], [80.1470871, 14.30013943], [80.14679718, 14.30013943], [80.14679718, 14.29958057], [80.14653015, 14.29958344], [80.14653015, 14.29874897], [80.14624786, 14.29875088], [80.14624786, 14.29790974], [80.14597321, 14.29791737], [80.14597321, 14.29680538], [80.14569092, 14.29681015], [80.14569092, 14.29597092], [80.14541626, 14.29597092], [80.14541626, 14.29513931], [80.1451416, 14.29514122], [80.1451416, 14.29431152], [80.14485931, 14.29431152], [80.14485931, 14.29347134], [80.14458466, 14.29347324], [80.14458466, 14.29236126], [80.14430237, 14.29236126], [80.14430237, 14.2915287], [80.14402771, 14.29153061], [80.14402771, 14.29069042], [80.14375305, 14.29069519], [80.14375305, 14.28986073], [80.14347076, 14.28986073], [80.14347076, 14.28903103], [80.14319611, 14.28903103], [80.14319611, 14.28792095], [80.14290619, 14.28792095], [80.14290619, 14.28708172], [80.14263916, 14.28708458], [80.14263916, 14.28625011], [80.14235687, 14.28625011], [80.14235687, 14.28542137], [80.14208221, 14.28542137], [80.14208221, 14.28431129], [80.14180756, 14.28431129], [80.14180756, 14.28319168], [80.14152527, 14.28319359], [80.14152527, 14.28208447], [80.14125061, 14.28208447], [80.14125061, 14.28097153], [80.14097595, 14.28097153], [80.14097595, 14.2798624], [80.14068604, 14.27987099], [80.14068604, 14.27875042], [80.14041901, 14.27875042], [80.14041901, 14.27791977], [80.14013672, 14.27791977], [80.14013672, 14.27680969], [80.13986206, 14.27680969], [80.13986206, 14.27569103], [80.13957977, 14.2756958], [80.13957977, 14.27458286], [80.13930511, 14.27458286], [80.13930511, 14.27347088], [80.13903046, 14.27347088], [80.13903046, 14.2723608], [80.13874817, 14.2723608], [80.13874817, 14.27013874], [80.13846588, 14.27014065], [80.13846588, 14.26680946], [80.13817596, 14.26680946], [80.13817596, 14.2634697], [80.13791656, 14.26347256], [80.13791656, 14.25847244], [80.13764191, 14.25847244], [80.13764191, 14.25374985], [80.13735962, 14.25374985], [80.13735962, 14.25263977], [80.13709259, 14.25263977], [80.13709259, 14.25208187], [80.13680267, 14.25208378], [80.13680267, 14.25180626], [80.13652802, 14.25181007], [80.13652802, 14.25152969], [80.13569641, 14.25152969], [80.13569641, 14.25069141], [80.13541412, 14.25069427], [80.13541412, 14.24930573], [80.13513947, 14.24930954], [80.13513947, 14.24819088], [80.13486481, 14.24819565], [80.13486481, 14.24680519], [80.13458252, 14.24680519], [80.13458252, 14.24541664], [80.13430786, 14.24542046], [80.13430786, 14.24431038], [80.1340332, 14.24431038], [80.1340332, 14.24374008], [80.13402557, 14.24291706], [80.13375092, 14.24292183], [80.13375092, 14.24236107], [80.13434601, 14.24236107], [80.13458252, 14.24236107], [80.13458252, 14.24097061], [80.13486481, 14.24097347], [80.13486481, 14.23986053], [80.13458252, 14.23986053], [80.13458252, 14.23930454], [80.13430786, 14.23930931], [80.13430786, 14.23875141], [80.13402557, 14.23875141], [80.13402557, 14.23819542], [80.13375092, 14.23819542], [80.13375092, 14.23763943], [80.13346863, 14.23763943], [80.13346863, 14.23708344], [80.13319397, 14.23708344], [80.13319397, 14.23652554], [80.13291931, 14.23653126], [80.13291931, 14.23569012], [80.13263702, 14.23569489], [80.13263702, 14.23458195], [80.13236237, 14.23458195], [80.13236237, 14.23319435], [80.13208008, 14.23319435], [80.13208008, 14.2318058], [80.13181305, 14.23182011], [80.13181305, 14.23069191], [80.13153076, 14.23069382], [80.13153076, 14.22930622], [80.13124847, 14.22931099], [80.13124847, 14.22764015], [80.13096619, 14.22764015], [80.13096619, 14.22597027], [80.13069153, 14.22597218], [80.13069153, 14.22430611], [80.13041687, 14.22430992], [80.13041687, 14.22292042], [80.13014221, 14.22292042], [80.13014221, 14.22124863], [80.12985992, 14.22124863], [80.12985992, 14.21959019], [80.12960052, 14.21959019], [80.12960052, 14.2179203], [80.12931061, 14.2179203], [80.12931061, 14.21653175], [80.12902832, 14.21653175], [80.12902832, 14.21486092], [80.12874603, 14.21486092], [80.12874603, 14.21319008], [80.12847137, 14.21319485], [80.12847137, 14.21152878], [80.12819672, 14.21153069], [80.12819672, 14.21068954], [80.12902832, 14.21069527], [80.12902832, 14.21013927], [80.12874603, 14.21014118], [80.12874603, 14.20931053], [80.12847137, 14.20931053], [80.12847137, 14.20792103], [80.12819672, 14.20792103], [80.12819672, 14.20653057], [80.1279068, 14.20653057], [80.1279068, 14.20514107], [80.12819672, 14.20514107], [80.12819672, 14.2045908], [80.12847137, 14.2045908], [80.12847137, 14.20431137], [80.12819672, 14.20431137], [80.12819672, 14.20374966], [80.1279068, 14.20374966], [80.1279068, 14.20125008], [80.12763977, 14.20125008], [80.12763977, 14.19957924], [80.12791443, 14.19958401], [80.12791443, 14.19902802], [80.12763977, 14.19902992], [80.12763977, 14.19845963], [80.12791443, 14.19847202], [80.12791443, 14.19458389], [80.12763977, 14.19458389], [80.12763977, 14.19430542], [80.12735748, 14.19431019], [80.12735748, 14.19402981], [80.12708282, 14.19402981], [80.12708282, 14.19291973], [80.12735748, 14.19291973], [80.12735748, 14.19208145], [80.12763977, 14.19208336], [80.12763977, 14.19152737], [80.12735748, 14.19153023], [80.12735748, 14.1912508], [80.12708282, 14.1912508], [80.12708282, 14.19014168], [80.12680817, 14.19014168], [80.12680817, 14.1898613], [80.12708282, 14.1898613], [80.12708282, 14.18958282], [80.12680817, 14.18958282], [80.12680817, 14.18930531], [80.12708282, 14.18931198], [80.12708282, 14.18651962], [80.12735748, 14.18652916], [80.12735748, 14.18541718], [80.12708282, 14.18542099], [80.12708282, 14.18457985], [80.12652588, 14.18458271], [80.12652588, 14.18402672], [80.12680817, 14.18403053], [80.12680817, 14.18375111], [80.12708282, 14.18375111], [80.12708282, 14.18319035], [80.12735748, 14.18319511], [80.12735748, 14.18263912], [80.12708282, 14.18264103], [80.12708282, 14.18097019], [80.12680817, 14.18097305], [80.12680817, 14.18069363], [80.12652588, 14.18069363], [80.12652588, 14.17875004], [80.12680817, 14.17875004], [80.12680817, 14.17819023], [80.12652588, 14.17819405], [80.12652588, 14.17763805], [80.12623596, 14.17763996], [80.12623596, 14.17681122], [80.12652588, 14.17681122], [80.12652588, 14.17653275], [80.12680817, 14.17653275], [80.12680817, 14.17542267], [80.12652588, 14.17542267], [80.12652588, 14.17514038], [80.12680817, 14.17514038], [80.12680817, 14.17486], [80.12652588, 14.17486], [80.12652588, 14.17457962], [80.12680817, 14.17458439], [80.12680817, 14.17374992], [80.12652588, 14.17374992], [80.12652588, 14.17319202], [80.12625122, 14.17319393], [80.12625122, 14.17125034], [80.12680817, 14.17125034], [80.12680817, 14.16958141], [80.12652588, 14.16958427], [80.12652588, 14.1693058], [80.12623596, 14.16930962], [80.12623596, 14.16903019], [80.12652588, 14.16903019], [80.12652588, 14.16875172], [80.12680817, 14.16875172], [80.12680817, 14.16792011], [80.12708282, 14.16792011], [80.12708282, 14.16763973], [80.12680817, 14.16763973], [80.12680817, 14.16681004], [80.12708282, 14.16681004], [80.12708282, 14.16652966], [80.12680817, 14.16652966], [80.12680817, 14.16624928], [80.12652588, 14.16624928], [80.12652588, 14.1645813], [80.12680817, 14.16458321], [80.12680817, 14.16374874], [80.12708282, 14.16375065], [80.12708282, 14.16264057], [80.12680817, 14.16264057], [80.12680817, 14.16207886], [80.12708282, 14.16208267], [80.12708282, 14.1604166], [80.12735748, 14.16041946], [80.12735748, 14.16014099], [80.12708282, 14.16014099], [80.12708282, 14.15986061], [80.12680817, 14.15986061], [80.12680817, 14.15958309], [80.12652588, 14.15958309], [80.12652588, 14.15902901], [80.12623596, 14.15903091], [80.12623596, 14.15875053], [80.12596893, 14.15875053], [80.12596893, 14.15847111], [80.12625122, 14.15847301], [80.12625122, 14.15791702], [80.12652588, 14.15792084], [80.12652588, 14.15736103], [80.12680817, 14.15736103], [80.12680817, 14.15596962], [80.12652588, 14.15597343], [80.12652588, 14.15430355], [80.12680817, 14.15431118], [80.12680817, 14.15292072], [80.12708282, 14.15292072], [80.12708282, 14.1526413], [80.12735748, 14.1526413], [80.12735748, 14.15207958], [80.12763977, 14.1520853], [80.12763977, 14.1501379], [80.12735748, 14.15014267], [80.12735748, 14.14958191], [80.12708282, 14.14958191], [80.12708282, 14.1493063], [80.12735748, 14.14931107], [80.12735748, 14.14875031], [80.12763977, 14.14875031], [80.12763977, 14.14792061], [80.12735748, 14.14792061], [80.12735748, 14.14764023], [80.12708282, 14.14764023], [80.12708282, 14.14681053], [80.12735748, 14.14681053], [80.12735748, 14.14653015], [80.1279068, 14.14653015], [80.1279068, 14.14542007], [80.12819672, 14.14542007], [80.12819672, 14.14375019], [80.1279068, 14.14375019], [80.1279068, 14.14291954], [80.12763977, 14.14291954], [80.12763977, 14.14236164], [80.1279068, 14.14236164], [80.1279068, 14.14208126], [80.12819672, 14.14208412], [80.12819672, 14.14069557], [80.12791443, 14.14069557], [80.12791443, 14.14041805], [80.12763977, 14.14041996], [80.12763977, 14.14013958], [80.12819672, 14.14013958], [80.12819672, 14.1398592], [80.12847137, 14.13986111], [80.12847137, 14.13930511], [80.12819672, 14.13931179], [80.12819672, 14.13903046], [80.12847137, 14.13903046], [80.12847137, 14.13792038], [80.12874603, 14.13792038], [80.12874603, 14.13764191], [80.12847137, 14.13764191], [80.12847137, 14.13736057], [80.12875366, 14.13736057], [80.12875366, 14.13569546], [80.12902832, 14.13569546], [80.12902832, 14.134305], [80.12874603, 14.13431168], [80.12874603, 14.13319016], [80.12902832, 14.13319492], [80.12902832, 14.13152885], [80.12931061, 14.13153076], [80.12931061, 14.12957954], [80.12958527, 14.12958336], [80.12958527, 14.12902641], [80.12931061, 14.12903118], [80.12931061, 14.12847042], [80.12958527, 14.12847328], [80.12958527, 14.12819481], [80.12930298, 14.12819481], [80.12930298, 14.12763786], [80.12960052, 14.12764072], [80.12960052, 14.12707996], [80.12930298, 14.12708473], [80.12930298, 14.12569427], [80.12958527, 14.12569427], [80.12958527, 14.12374973], [80.12874603, 14.12374973], [80.12874603, 14.12403107], [80.12847137, 14.12403107], [80.12847137, 14.12374973], [80.12819672, 14.12374973], [80.12819672, 14.12347031], [80.12791443, 14.12347221], [80.12791443, 14.12319374], [80.12763977, 14.12319374], [80.12763977, 14.12291622], [80.12735748, 14.12292099], [80.12735748, 14.12263966], [80.12623596, 14.12263966], [80.12623596, 14.12403107], [80.12596893, 14.12403107], [80.12596893, 14.12597179], [80.12625122, 14.12597179], [80.12625122, 14.12736034], [80.12680817, 14.12736034], [80.12680817, 14.12708473], [80.12735748, 14.12707996], [80.12735748, 14.12764072], [80.12763977, 14.12764072], [80.12763977, 14.1279211], [80.12791443, 14.12791729], [80.12791443, 14.12958336], [80.12763977, 14.12957954], [80.12763977, 14.12986088], [80.12735748, 14.12986088], [80.12735748, 14.13042068], [80.12708282, 14.13041687], [80.12708282, 14.13208294], [80.12735748, 14.13208103], [80.12735748, 14.13264084], [80.12708282, 14.13264084], [80.12708282, 14.13375092], [80.12680817, 14.13375092], [80.12680817, 14.13431168], [80.12596893, 14.13431168], [80.12596893, 14.1340313], [80.12568665, 14.1340313], [80.12568665, 14.13291931], [80.12541962, 14.13291931], [80.12541962, 14.13180923], [80.12568665, 14.13180923], [80.12568665, 14.13042068], [80.12541962, 14.13042068], [80.12541962, 14.13014126], [80.12568665, 14.13014126], [80.12568665, 14.12986088], [80.12541962, 14.12986088], [80.12541962, 14.12847042], [80.12513733, 14.12847328], [80.12513733, 14.12485981], [80.12541962, 14.12486267], [80.12541962, 14.1204319], [80.12513733, 14.1204319], [80.12513733, 14.12014008], [80.12486267, 14.12014008], [80.12486267, 14.11957932], [80.12458038, 14.11958408], [80.12458038, 14.11930561], [80.12431335, 14.11931133], [80.12431335, 14.11847019], [80.12374878, 14.1184721], [80.12374878, 14.11791801], [80.12346649, 14.11791992], [80.12346649, 14.11763954], [80.12317657, 14.11763954], [80.12317657, 14.11708164], [80.12291718, 14.11708355], [80.12291718, 14.11680603], [80.12264252, 14.11680984], [80.12264252, 14.11653042], [80.12236023, 14.11653042], [80.12236023, 14.11597157], [80.12208557, 14.11597157], [80.12208557, 14.11458397], [80.12236023, 14.11458397], [80.12236023, 14.11430645], [80.12264252, 14.11430645], [80.12264252, 14.11458397], [80.12291718, 14.1145792], [80.12291718, 14.11542034], [80.12317657, 14.11542034], [80.12317657, 14.11625195], [80.12346649, 14.11625195], [80.12346649, 14.11680984], [80.12374878, 14.11680984], [80.12374878, 14.11737061], [80.12403107, 14.11737061], [80.12403107, 14.11763954], [80.12431335, 14.11763954], [80.12431335, 14.11791992], [80.12458038, 14.11791801], [80.12458038, 14.11819363], [80.12486267, 14.11819363], [80.12486267, 14.1184721], [80.12513733, 14.11847019], [80.12513733, 14.11874962], [80.12568665, 14.11874962], [80.12568665, 14.11818886], [80.12596893, 14.11819363], [80.12596893, 14.11708355], [80.12625122, 14.11708355], [80.12625122, 14.11597157], [80.12652588, 14.11597157], [80.12652588, 14.11541462], [80.12623596, 14.11542034], [80.12623596, 14.11514187], [80.12652588, 14.11514187], [80.12652588, 14.11180973], [80.12680817, 14.11180973], [80.12680817, 14.1115303], [80.12763977, 14.1115303], [80.12763977, 14.11180973], [80.12819672, 14.11180496], [80.12819672, 14.11208344], [80.12874603, 14.11208057], [80.12874603, 14.11264038], [80.12902832, 14.11264038], [80.12902832, 14.11291981], [80.12930298, 14.1129179], [80.12930298, 14.11319256], [80.12958527, 14.11319256], [80.12958527, 14.11347103], [80.12985992, 14.11347103], [80.12985992, 14.11403179], [80.12902832, 14.11403179], [80.12902832, 14.11374855], [80.12874603, 14.11374855], [80.12874603, 14.11347103], [80.12763977, 14.11347103], [80.12763977, 14.11903], [80.12708282, 14.11903], [80.12708282, 14.1204319], [80.12735748, 14.12041569], [80.12735748, 14.12097168], [80.12763977, 14.12097168], [80.12763977, 14.12125015], [80.1279068, 14.12125015], [80.1279068, 14.12152958], [80.12960052, 14.12152958], [80.12960052, 14.12125015], [80.12985992, 14.12125015], [80.12985992, 14.1198597], [80.13014221, 14.1198597], [80.13014221, 14.11957932], [80.13097382, 14.11958408], [80.13097382, 14.1184721], [80.13124847, 14.1184721], [80.13124847, 14.11680603], [80.13096619, 14.11680984], [80.13096619, 14.11569118], [80.13124847, 14.11569405], [80.13124847, 14.11374855], [80.13153076, 14.11374855], [80.13153076, 14.11291981], [80.13181305, 14.11291981], [80.13181305, 14.11236095], [80.13153076, 14.11236095], [80.13153076, 14.11180973], [80.13181305, 14.11180973], [80.13181305, 14.10736084], [80.13208008, 14.10736084], [80.13208008, 14.10486126], [80.13236237, 14.10486126], [80.13236237, 14.10319519], [80.13263702, 14.10319519], [80.13263702, 14.1026392], [80.13291931, 14.10264111], [80.13291931, 14.10181141], [80.13263702, 14.10181141], [80.13263702, 14.10042095], [80.13291931, 14.10042095], [80.13291931, 14.09930038], [80.13319397, 14.0993042], [80.13319397, 14.09736156], [80.13346863, 14.09735966], [80.13346863, 14.09626198], [80.13375092, 14.09626198], [80.13375092, 14.09486008], [80.1340332, 14.09486008], [80.13402557, 14.09347153], [80.13430786, 14.09347153], [80.13430786, 14.0923624], [80.13458252, 14.0923624], [80.13458252, 14.09125042], [80.13485718, 14.09125042], [80.13485718, 14.09041977], [80.13513947, 14.09041977], [80.13513947, 14.08930969], [80.13540649, 14.08930969], [80.13540649, 14.08792019], [80.13569641, 14.08792019], [80.13569641, 14.08624935], [80.13597107, 14.08624935], [80.13597107, 14.08432102], [80.13625336, 14.08432102], [80.13625336, 14.0826416], [80.13652802, 14.0826416], [80.13652802, 14.08069134], [80.13680267, 14.08069515], [80.13680267, 14.07902908], [80.13707733, 14.07903099], [80.13707733, 14.07736111], [80.13735962, 14.07736111], [80.13735962, 14.07597256], [80.13764191, 14.07597256], [80.13764191, 14.07513905], [80.13791656, 14.07513905], [80.13791656, 14.07402897], [80.13817596, 14.07403088], [80.13817596, 14.07318974], [80.13847351, 14.07319546], [80.13847351, 14.07236004], [80.13817596, 14.07236004], [80.13817596, 14.07207108], [80.13847351, 14.07208538], [80.13847351, 14.07180691], [80.13874817, 14.07181072], [80.13874817, 14.0715313], [80.13903046, 14.0715313], [80.13903046, 14.07124996], [80.13931274, 14.07124996], [80.13931274, 14.07096958], [80.13957977, 14.07097244], [80.13957977, 14.07069397], [80.13986206, 14.07069397], [80.13986206, 14.07013798], [80.14013672, 14.07014275], [80.14013672, 14.06986046], [80.14097595, 14.06986237], [80.14097595, 14.0690279], [80.14125061, 14.06903267], [80.14125061, 14.06818962], [80.14152527, 14.06819439], [80.14152527, 14.06791592], [80.14125061, 14.06792068], [80.14125061, 14.06653023], [80.14154053, 14.06653023], [80.14154053, 14.06513977], [80.14125061, 14.06513977], [80.14125061, 14.06375027], [80.14097595, 14.06375027], [80.14097595, 14.06208134], [80.14125061, 14.0620842], [80.14125061, 14.06152821], [80.14097595, 14.06153202], [80.14097595, 14.06042004], [80.14125061, 14.06042004], [80.14125061, 14.06013012], [80.14152527, 14.06013966], [80.14152527, 14.05986214], [80.14180756, 14.05986214], [80.14180756, 14.05958366], [80.14208221, 14.05958366], [80.14208221, 14.05930519], [80.14235687, 14.05930996], [80.14235687, 14.05792046], [80.14263916, 14.05792046], [80.14263916, 14.05653191], [80.14235687, 14.05653191], [80.14235687, 14.05597115], [80.14291382, 14.05597115], [80.14291382, 14.05541706], [80.14263916, 14.05542183], [80.14263916, 14.05458069], [80.14291382, 14.0545826], [80.14291382, 14.0540266], [80.14319611, 14.05403233], [80.14319611, 14.05180931], [80.14347076, 14.05180931], [80.14347076, 14.0506897], [80.14375305, 14.05069542], [80.14375305, 14.05013943], [80.14402771, 14.05014133], [80.14402771, 14.04957962], [80.14430237, 14.04958344], [80.14430237, 14.04930687], [80.14457703, 14.04931068], [80.14457703, 14.04903126], [80.14485931, 14.04903126], [80.14485931, 14.04819012], [80.14458466, 14.04819489], [80.14458466, 14.04763889], [80.14431, 14.0476408], [80.14431, 14.04736042], [80.14458466, 14.04736042], [80.14458466, 14.04652882], [80.14485931, 14.04653072], [80.14485931, 14.0462513], [80.1451416, 14.0462513], [80.1451416, 14.04596996], [80.14485931, 14.04597282], [80.14485931, 14.04541588], [80.1451416, 14.04542065], [80.1451416, 14.04431057], [80.14541626, 14.04431057], [80.14541626, 14.04319191], [80.14569092, 14.04319382], [80.14569092, 14.04097176], [80.14597321, 14.04097176], [80.14597321, 14.04041576], [80.14624786, 14.04042053], [80.14624786, 14.03986168], [80.14653015, 14.03986168], [80.14653015, 14.03902054], [80.14680481, 14.03902817], [80.14680481, 14.0381937], [80.1470871, 14.0381937], [80.1470871, 14.0373621], [80.14736176, 14.0373621], [80.14736176, 14.03680611], [80.14763641, 14.03680992], [80.14763641, 14.0359602], [80.1479187, 14.03597164], [80.1479187, 14.03514004], [80.14819336, 14.03514194], [80.14819336, 14.03264046], [80.14848328, 14.03264046], [80.14848328, 14.03015137], [80.14819336, 14.03015137], [80.14819336, 14.02875137], [80.1479187, 14.02875137], [80.1479187, 14.02792168], [80.14819336, 14.02792168], [80.14819336, 14.02736092], [80.14848328, 14.02736092], [80.14847565, 14.02680492], [80.14875031, 14.02680969], [80.14875031, 14.02625084], [80.14901733, 14.02625084], [80.14901733, 14.02569008], [80.14930725, 14.02569485], [80.14930725, 14.02541733], [80.14958191, 14.02541924], [80.14958191, 14.02486134], [80.1498642, 14.02486134], [80.1498642, 14.02430534], [80.15013885, 14.02431202], [80.15013885, 14.02375126], [80.15040588, 14.02375126], [80.15040588, 14.02153111], [80.15013885, 14.02153111], [80.15013885, 14.02098179], [80.14985657, 14.02098179], [80.14985657, 14.02042103], [80.14958191, 14.02042103], [80.14958191, 14.01875114], [80.14985657, 14.01875114], [80.14985657, 14.01903057], [80.15013885, 14.01903057], [80.15013885, 14.01931095], [80.15041351, 14.01930428], [80.15041351, 14.01958466], [80.1506958, 14.01958466], [80.1506958, 14.01986027], [80.15097046, 14.01986027], [80.15097046, 14.02014065], [80.15125275, 14.02014065], [80.15125275, 14.02042103], [80.15180206, 14.02041721], [80.15180206, 14.02069473], [80.15207672, 14.02068996], [80.15207672, 14.02098179], [80.15235901, 14.02098179], [80.15235901, 14.02125072], [80.1526413, 14.02125072], [80.1526413, 14.02153111], [80.15291595, 14.02153111], [80.15291595, 14.02181053], [80.15319824, 14.02181053], [80.15319824, 14.02292061], [80.15291595, 14.02292061], [80.15291595, 14.02375126], [80.1526413, 14.02375126], [80.1526413, 14.02402687], [80.15235901, 14.02402687], [80.15235901, 14.02486134], [80.15207672, 14.02486134], [80.15207672, 14.02541924], [80.15180206, 14.02541733], [80.15180206, 14.02597332], [80.1515274, 14.02597141], [80.1515274, 14.02680969], [80.15125275, 14.02680969], [80.15125275, 14.02736092], [80.1506958, 14.02736092], [80.1506958, 14.02792168], [80.15040588, 14.02792168], [80.15040588, 14.02931023], [80.1506958, 14.02931023], [80.1506958, 14.0304203], [80.1515274, 14.0304203], [80.1515274, 14.03015137], [80.15180206, 14.03015137], [80.15180206, 14.02958107], [80.15208435, 14.02958298], [80.15208435, 14.02847099], [80.15235901, 14.02847099], [80.15235901, 14.02736092], [80.1526413, 14.02736092], [80.1526413, 14.02625084], [80.15291595, 14.02625084], [80.15291595, 14.02514076], [80.15319061, 14.02514076], [80.15319824, 14.02458096], [80.1534729, 14.02458286], [80.1534729, 14.02402687], [80.15374756, 14.02402687], [80.15374756, 14.02347279], [80.15402985, 14.02347279], [80.15402985, 14.02291679], [80.15429687, 14.02292061], [80.15429687, 14.0223608], [80.15458679, 14.0223608], [80.15458679, 14.02180672], [80.15486145, 14.02181053], [80.15486145, 14.02125072], [80.15513611, 14.02125072], [80.15513611, 14.02068996], [80.1554184, 14.02069473], [80.1554184, 14.01958466], [80.15513611, 14.01958466], [80.15513611, 14.01930428], [80.15458679, 14.01931095], [80.15458679, 14.01819038], [80.15486145, 14.0181942], [80.15486145, 14.01624966], [80.15458679, 14.01624966], [80.15458679, 14.01513958], [80.15429687, 14.01513958], [80.15429687, 14.01292038], [80.15458679, 14.01292038], [80.15458679, 14.01152992], [80.15486145, 14.01152992], [80.15486145, 14.01097202], [80.15513611, 14.01097202], [80.15513611, 14.01041794], [80.1554184, 14.01041985], [80.1554184, 14.01014042], [80.15569305, 14.01014042], [80.15569305, 14.00986195], [80.15598297, 14.00986195], [80.15597534, 14.00930595], [80.15625, 14.00930977], [80.15625, 14.00904083], [80.15651703, 14.00904083], [80.15651703, 14.00875187], [80.15680695, 14.00875187], [80.15680695, 14.00819111], [80.1570816, 14.00819397], [80.1570816, 14.00791454], [80.15735626, 14.00792027], [80.15735626, 14.00735855], [80.15763855, 14.00736237], [80.15763855, 14.0065279], [80.15791321, 14.00652981], [80.15791321, 14.00486088], [80.15763855, 14.00486088], [80.15763855, 14.00013924], [80.15791321, 14.00013924], [80.15791321, 13.99985027], [80.1581955, 13.99986076], [80.1581955, 13.99958324], [80.15847015, 13.99958324], [80.15847015, 13.99902916], [80.15866089, 13.99902916], [80.1598587, 13.99903107], [80.1598587, 13.99847126], [80.16014099, 13.99847317], [80.16014099, 13.9976387], [80.16042328, 13.99764061], [80.16042328, 13.99681187], [80.16069794, 13.99681187], [80.16069794, 13.99597073], [80.1609726, 13.99597263], [80.1609726, 13.99513912], [80.16124725, 13.99514103], [80.16124725, 13.99431133], [80.16152954, 13.99431133], [80.16152954, 13.99096966], [80.16069794, 13.99096966], [80.16069794, 13.99125004], [80.1598587, 13.99125004], [80.1598587, 13.99069023], [80.16014099, 13.99069405], [80.16014099, 13.99013805], [80.16042328, 13.99014091], [80.16042328, 13.98958015], [80.16069794, 13.98958206], [80.16069794, 13.98902798], [80.1609726, 13.98903275], [80.1609726, 13.98875046], [80.16124725, 13.98875046], [80.16124725, 13.9881897], [80.16152954, 13.98819447], [80.16152954, 13.98791599], [80.16236115, 13.98791599], [80.16236115, 13.98819447], [80.16291809, 13.98819447], [80.16291809, 13.98791599], [80.16374969, 13.98791599], [80.16374969, 13.98736], [80.16401672, 13.98736], [80.16401672, 13.98569202], [80.16374969, 13.98569393], [80.16374969, 13.98513794], [80.16319275, 13.98513985], [80.16319275, 13.98542023], [80.16291809, 13.98541641], [80.16291809, 13.98569393], [80.16236115, 13.98569393], [80.16236115, 13.98402786], [80.1626358, 13.98402977], [80.1626358, 13.98347187], [80.16291809, 13.98347187], [80.16291809, 13.98264027], [80.16319275, 13.98264027], [80.16319275, 13.98208141], [80.16347504, 13.98208427], [80.16347504, 13.98097229], [80.16374969, 13.98097229], [80.16374969, 13.97930622], [80.16401672, 13.97931004], [80.16401672, 13.97846889], [80.16430664, 13.9784708], [80.16430664, 13.97819328], [80.16486359, 13.97819328], [80.16486359, 13.97791767], [80.16513824, 13.97791958], [80.16513824, 13.9776392], [80.16542053, 13.9776392], [80.16542053, 13.97736073], [80.16596985, 13.97736073], [80.16596985, 13.9770813], [80.16625214, 13.97708321], [80.16625214, 13.97652721], [80.16652679, 13.97653198], [80.16652679, 13.97625065], [80.16680908, 13.97625065], [80.16680908, 13.9756794], [80.16708374, 13.97569466], [80.16708374, 13.97513866], [80.1673584, 13.97514153], [80.1673584, 13.97458076], [80.16764069, 13.97458267], [80.16764069, 13.97402668], [80.16792297, 13.9740324], [80.16792297, 13.97347069], [80.16819763, 13.9734726], [80.16819763, 13.97319508], [80.16847229, 13.97319508], [80.16847229, 13.9729166], [80.16902924, 13.97293091], [80.16902924, 13.97208118], [80.16930389, 13.97208309], [80.16930389, 13.97041702], [80.16958618, 13.97042084], [80.16958618, 13.96708012], [80.16986084, 13.96708298], [80.16986084, 13.96430683], [80.16958618, 13.96431065], [80.16958618, 13.9637413], [80.17041779, 13.9637413], [80.17041779, 13.96403122], [80.17069244, 13.96403122], [80.17069244, 13.96431065], [80.17097473, 13.96430683], [80.17097473, 13.96458244], [80.17124939, 13.96458244], [80.17124939, 13.96430683], [80.17151642, 13.96431065], [80.17151642, 13.96319199], [80.17180634, 13.96319389], [80.17180634, 13.96152782], [80.17208099, 13.96153069], [80.17208099, 13.96014023], [80.17292023, 13.96014023], [80.17292023, 13.96097183], [80.17318726, 13.96096992], [80.17318726, 13.96153069], [80.17375183, 13.96152782], [80.17375183, 13.96347237], [80.17346954, 13.96347046], [80.17346954, 13.96431065], [80.17318726, 13.96431065], [80.17318726, 13.9651413], [80.17292023, 13.96513844], [80.17292023, 13.9659729], [80.17263794, 13.96597004], [80.17263794, 13.96681118], [80.17236328, 13.96681118], [80.17236328, 13.96764088], [80.17208099, 13.96763897], [80.17208099, 13.96847343], [80.17180634, 13.96846962], [80.17180634, 13.96931076], [80.17151642, 13.96931076], [80.17151642, 13.97014141], [80.17124939, 13.97013855], [80.17124939, 13.97097301], [80.1709671, 13.97097111], [80.1709671, 13.97153091], [80.17069244, 13.97153091], [80.17069244, 13.97180939], [80.17041779, 13.97180462], [80.17041779, 13.97208309], [80.17014313, 13.97208118], [80.17014313, 13.97264099], [80.16986084, 13.97264099], [80.16986084, 13.97293091], [80.16958618, 13.9729166], [80.16958618, 13.97319508], [80.16929626, 13.97319126], [80.16929626, 13.97375107], [80.16958618, 13.97375107], [80.16958618, 13.97431183], [80.16986084, 13.97430515], [80.16986084, 13.97486115], [80.17014313, 13.97486115], [80.17014313, 13.97542191], [80.16902924, 13.97541714], [80.16902924, 13.97597122], [80.16874695, 13.97597122], [80.16874695, 13.97653198], [80.16847992, 13.97653198], [80.16847992, 13.97681046], [80.16819763, 13.97681046], [80.16819763, 13.97736073], [80.16792297, 13.97736073], [80.16792297, 13.97791958], [80.16764069, 13.97791767], [80.16764069, 13.97819328], [80.16791534, 13.97819328], [80.16791534, 13.9784708], [80.16819763, 13.97846889], [80.16819763, 13.97874928], [80.16874695, 13.97874928], [80.16874695, 13.97931004], [80.16847992, 13.97931004], [80.16847992, 13.98013973], [80.16819763, 13.98013973], [80.16819763, 13.98069572], [80.16792297, 13.98069096], [80.16792297, 13.98125172], [80.16764069, 13.98125172], [80.16764069, 13.98236179], [80.1673584, 13.98236179], [80.1673584, 13.98264027], [80.16707611, 13.98264027], [80.16707611, 13.98291969], [80.16652679, 13.98291969], [80.16652679, 13.98236179], [80.16625214, 13.98236179], [80.16625214, 13.98125172], [80.16596985, 13.98125172], [80.16596985, 13.98069096], [80.16569519, 13.98069572], [80.16569519, 13.98041534], [80.16513824, 13.98041534], [80.16513824, 13.98069572], [80.16485596, 13.98069096], [80.16485596, 13.98153019], [80.1645813, 13.98153019], [80.1645813, 13.98236179], [80.16486359, 13.98236179], [80.16486359, 13.98347187], [80.16513824, 13.98347187], [80.16513824, 13.98431015], [80.16542053, 13.98431015], [80.16542053, 13.98542023], [80.16569519, 13.98541641], [80.16569519, 13.9859724], [80.16596985, 13.98596954], [80.16596985, 13.98624992], [80.16625214, 13.98624992], [80.16625214, 13.98596954], [80.16680908, 13.98596954], [80.16680908, 13.9865303], [80.16652679, 13.9865303], [80.16652679, 13.98764038], [80.16625214, 13.98763847], [80.16625214, 13.98819447], [80.16596985, 13.9881897], [80.16596985, 13.98875046], [80.16570282, 13.98875046], [80.16570282, 13.98931122], [80.16542053, 13.98931122], [80.16542053, 13.99014091], [80.16513824, 13.99013805], [80.16513824, 13.99097157], [80.16485596, 13.99096966], [80.16485596, 13.99236012], [80.1645813, 13.99236012], [80.1645813, 13.99347305], [80.16430664, 13.99347019], [80.16430664, 13.99403954], [80.16402435, 13.99402905], [80.16402435, 13.99458313], [80.16374969, 13.99458027], [80.16374969, 13.99514103], [80.16347504, 13.99513912], [80.16347504, 13.99569511], [80.16319275, 13.99569511], [80.16319275, 13.99597263], [80.16291809, 13.99597073], [80.16291809, 13.99653053], [80.1626358, 13.99652672], [80.1626358, 13.99708271], [80.16234589, 13.99707985], [80.16234589, 13.99764061], [80.1626358, 13.9976387], [80.1626358, 13.99819469], [80.16234589, 13.99818993], [80.16234589, 13.99875069], [80.16208649, 13.99875069], [80.16208649, 14.00013924], [80.1618042, 14.00013924], [80.1618042, 14.00069523], [80.16152954, 14.00069141], [80.16152954, 14.00097084], [80.16124725, 14.00097084], [80.16124725, 14.00125122], [80.1609726, 14.00125122], [80.1609726, 14.00264168], [80.16069794, 14.00264168], [80.16069794, 14.00374889], [80.16042328, 14.00374889], [80.16042328, 14.00541973], [80.16014099, 14.00541973], [80.16014099, 14.00598145], [80.1598587, 14.00598145], [80.1598587, 14.00652981], [80.15958405, 14.0065279], [80.15958405, 14.00736237], [80.15930939, 14.00735855], [80.1592865, 14.00764179], [80.1590271, 14.00763988], [80.1590271, 14.00819111], [80.15875244, 14.00819969], [80.15875244, 14.00875187], [80.15847015, 14.00875187], [80.15847015, 14.00904083], [80.15820313, 14.00904083], [80.15820313, 14.00930977], [80.15791321, 14.00930595], [80.15791321, 14.00958443], [80.15763855, 14.00958157], [80.15763855, 14.00986195], [80.15736389, 14.00986195], [80.15736389, 14.01069355], [80.1570816, 14.01069355], [80.1570816, 14.01236153], [80.15680695, 14.01235962], [80.15680695, 14.01375008], [80.15652466, 14.01375008], [80.15652466, 14.01486015], [80.15625, 14.01486015], [80.15625, 14.01597214], [80.15597534, 14.01597214], [80.15597534, 14.01708221], [80.15569305, 14.01708031], [80.15569305, 14.01764107], [80.15625, 14.01764107], [80.15625, 14.01735973], [80.15651703, 14.01735973], [80.15651703, 14.01653099], [80.15680695, 14.01653099], [80.15680695, 14.01624966], [80.15735626, 14.01624966], [80.15735626, 14.01542091], [80.15763855, 14.01542091], [80.15763855, 14.01458168], [80.15791321, 14.01458359], [80.15791321, 14.0140276], [80.15820313, 14.01403046], [80.15820313, 14.0134697], [80.15847015, 14.0134716], [80.15847015, 14.01264], [80.15875244, 14.01264], [80.15875244, 14.01181126], [80.1590271, 14.01181126], [80.1590271, 14.01124954], [80.1592865, 14.01124954], [80.1592865, 14.00930977], [80.15957642, 14.00930977], [80.15957642, 14.00904083], [80.1598587, 14.00904083], [80.1598587, 14.00875187], [80.16014099, 14.00875187], [80.16014099, 14.00847244], [80.16041565, 14.00847244], [80.16041565, 14.00763988], [80.16069794, 14.00764179], [80.16069794, 14.00652981], [80.1609726, 14.00652981], [80.1609726, 14.00598145], [80.16124725, 14.00598145], [80.16124725, 14.00569057], [80.16152954, 14.00569344], [80.16152954, 14.00458336], [80.1618042, 14.00458336], [80.1618042, 14.00402737], [80.16208649, 14.00403023], [80.16208649, 14.00347137], [80.16236115, 14.00347328], [80.16236115, 14.00291729], [80.1626358, 14.00291729], [80.1626358, 14.00208282], [80.16291809, 14.00208282], [80.16291809, 14.00180531], [80.16319275, 14.00181198], [80.16319275, 14.0015316], [80.16348267, 14.0015316], [80.16348267, 14.00097084], [80.16374969, 14.00097084], [80.16374969, 13.99985027], [80.16374969, 13.99958324], [80.16402435, 13.99958324], [80.16402435, 13.99930477], [80.16430664, 13.99930859], [80.16430664, 13.99875069], [80.1645813, 13.99875069], [80.1645813, 13.99818993], [80.16486359, 13.99819469], [80.16486359, 13.99791718], [80.16513824, 13.99792099], [80.16513824, 13.99736118], [80.1654129, 13.99736118], [80.1654129, 13.99680519], [80.16570282, 13.99681187], [80.16570282, 13.99625111], [80.16596985, 13.99625111], [80.16596985, 13.99486065], [80.16625214, 13.99486065], [80.16625214, 13.99403954], [80.16652679, 13.99403954], [80.16652679, 13.99347019], [80.16680908, 13.99347305], [80.16680908, 13.99319458], [80.16708374, 13.99319458], [80.16708374, 13.99291706], [80.1673584, 13.99292088], [80.1673584, 13.99264145], [80.16764069, 13.99264145], [80.16764069, 13.99125004], [80.16792297, 13.99125004], [80.16792297, 13.99069023], [80.16819763, 13.99069405], [80.16819763, 13.99041557], [80.16847992, 13.9904213], [80.16847992, 13.99014091], [80.16874695, 13.99014091], [80.16874695, 13.98985958], [80.16902924, 13.98986244], [80.16902924, 13.98930645], [80.16929626, 13.98931122], [80.16929626, 13.98875046], [80.16958618, 13.98875046], [80.16958618, 13.98764038], [80.16929626, 13.98764038], [80.16929626, 13.98707962], [80.16958618, 13.98708439], [80.16958618, 13.98680592], [80.16986084, 13.98681068], [80.16986084, 13.9865303], [80.17014313, 13.9865303], [80.17014313, 13.98596954], [80.17041779, 13.9859724], [80.17041779, 13.98569393], [80.17069244, 13.98569393], [80.17069244, 13.98513794], [80.17041779, 13.98513985], [80.17041779, 13.98487091], [80.1709671, 13.98487091], [80.1709671, 13.98458195], [80.17124939, 13.98458385], [80.17124939, 13.98430634], [80.17151642, 13.98431015], [80.17151642, 13.98402977], [80.17180634, 13.98402977], [80.17180634, 13.98264027], [80.17208099, 13.98264027], [80.17208099, 13.98180962], [80.17236328, 13.98180962], [80.17236328, 13.98069096], [80.17263794, 13.98069572], [80.17263794, 13.98013973], [80.17292023, 13.98013973], [80.17292023, 13.97958088], [80.17319489, 13.97958374], [80.17319489, 13.97930622], [80.17346954, 13.97931004], [80.17346954, 13.97902966], [80.17375183, 13.97902966], [80.17375183, 13.97874928], [80.17402649, 13.97874928], [80.17402649, 13.97791958], [80.17430878, 13.97791958], [80.17430878, 13.97681046], [80.17457581, 13.97681046], [80.17457581, 13.97625065], [80.17485809, 13.97625065], [80.17485809, 13.9756794], [80.17514038, 13.97569466], [80.17514038, 13.97513866], [80.17542267, 13.97514153], [80.17542267, 13.97486115], [80.17597198, 13.97486115], [80.17597198, 13.97430515], [80.17624664, 13.97431183], [80.17624664, 13.97319126], [80.17652893, 13.97319508], [80.17652893, 13.97263908], [80.17679596, 13.97264099], [80.17679596, 13.97208118], [80.17708588, 13.97208309], [80.17708588, 13.97097301], [80.17736053, 13.97097301], [80.17736053, 13.97069454], [80.17763519, 13.97069454], [80.17763519, 13.97041702], [80.17791748, 13.97042084], [80.17791748, 13.96986961], [80.17819214, 13.96986961], [80.17819214, 13.96903133], [80.1784668, 13.96903133], [80.1784668, 13.96875095], [80.17874908, 13.96875095], [80.17874908, 13.96792126], [80.17903137, 13.96792126], [80.17903137, 13.96736145], [80.17930603, 13.96736145], [80.17930603, 13.96708298], [80.17958069, 13.96708298], [80.17958069, 13.96652889], [80.17986298, 13.9665308], [80.17986298, 13.96542072], [80.18013763, 13.96542072], [80.18013763, 13.96485996], [80.18041992, 13.96485996], [80.18041992, 13.96403122], [80.18068695, 13.96403122], [80.18068695, 13.96347046], [80.18096924, 13.96347237], [80.18096924, 13.96291637], [80.18125153, 13.96292114], [80.18125153, 13.96181107], [80.18096924, 13.96181107], [80.18096924, 13.96096992], [80.18125153, 13.96097183], [80.18125153, 13.96069431], [80.18152618, 13.96069431], [80.18152618, 13.96041584], [80.18180847, 13.96042061], [80.18180847, 13.95985985], [80.18208313, 13.95985985], [80.18208313, 13.95958424], [80.18235779, 13.95958424], [80.18235779, 13.95930576], [80.18264008, 13.95931053], [80.18264008, 13.95903015], [80.1829071, 13.95903015], [80.1829071, 13.95875168], [80.18319702, 13.95875168], [80.18319702, 13.95847034], [80.18347168, 13.95847225], [80.18347168, 13.95736217], [80.18374634, 13.95736217], [80.18374634, 13.95680618], [80.18402863, 13.95681], [80.18402863, 13.95596886], [80.18430328, 13.95597172], [80.18430328, 13.95541573], [80.1845932, 13.95541954], [80.1845932, 13.95458126], [80.18486023, 13.95458412], [80.18486023, 13.95402813], [80.18514252, 13.95403004], [80.18514252, 13.95346928], [80.18541718, 13.95347214], [80.18541718, 13.95263958], [80.18569183, 13.95263958], [80.18569183, 13.95208073], [80.18597412, 13.95208359], [80.18597412, 13.95124912], [80.18624878, 13.95125198], [80.18624878, 13.95069122], [80.18653107, 13.95069313], [80.18653107, 13.95013905], [80.18681335, 13.95014191], [80.18681335, 13.94764137], [80.18708038, 13.94764137], [80.18708038, 13.94708061], [80.18736267, 13.94708347], [80.18736267, 13.94652653], [80.18763733, 13.94652939], [80.18763733, 13.94625092], [80.18791962, 13.94625092], [80.18791962, 13.94569969], [80.18818665, 13.94569969], [80.18818665, 13.94430923], [80.18846893, 13.94430923], [80.18846893, 13.94375134], [80.18875122, 13.94375134], [80.18875122, 13.94347095], [80.18902588, 13.94347286], [80.18902588, 13.94319534], [80.18930817, 13.94319534], [80.18930817, 13.94263935], [80.18958282, 13.94264126], [80.18958282, 13.94181061], [80.18985748, 13.94181061], [80.18985748, 13.94097042], [80.19013977, 13.94097328], [80.19013977, 13.93958473], [80.19041443, 13.93958473], [80.19041443, 13.93902874], [80.19069672, 13.93903065], [80.19069672, 13.93875122], [80.19097137, 13.93875122], [80.19097137, 13.93819046], [80.19125366, 13.93819427], [80.19125366, 13.93763828], [80.19152832, 13.93764114], [80.19152832, 13.93708038], [80.19180298, 13.93708229], [80.19180298, 13.93569374], [80.19208527, 13.93569374], [80.19208527, 13.93513775], [80.19235992, 13.93513966], [80.19235992, 13.93431091], [80.19264984, 13.93431091], [80.19264984, 13.93292141], [80.19291687, 13.93292141], [80.19291687, 13.93208027], [80.19319153, 13.93208408], [80.19319153, 13.93152809], [80.19346619, 13.93153], [80.19346619, 13.93041992], [80.19374847, 13.93041992], [80.19374847, 13.92958164], [80.19403076, 13.92958355], [80.19403076, 13.92875004], [80.19431305, 13.92875195], [80.19431305, 13.92819118], [80.19458008, 13.92819405], [80.19458008, 13.92763996], [80.19486237, 13.92763996], [80.19486237, 13.92736244], [80.19513702, 13.92736244], [80.19513702, 13.92680645], [80.19541931, 13.92681026], [80.19541931, 13.92457199], [80.19569397, 13.92458344], [80.19569397, 13.92374897], [80.19596863, 13.92375183], [80.19596863, 13.92347145], [80.19625092, 13.92347431], [80.19625092, 13.92263889], [80.1965332, 13.92264175], [80.1965332, 13.92182064], [80.19680786, 13.92182064], [80.19680786, 13.9212513], [80.19708252, 13.9212513], [80.19708252, 13.92069054], [80.19736481, 13.9206953], [80.19736481, 13.92013931], [80.19763947, 13.92013931], [80.19763947, 13.91958141], [80.19791412, 13.91958332], [80.19791412, 13.91874886], [80.19819641, 13.9187603], [80.19819641, 13.91847134], [80.19791412, 13.91847324], [80.19791412, 13.91819477], [80.19819641, 13.91819477], [80.19819641, 13.91791725], [80.19845581, 13.91792202], [80.19845581, 13.91736126], [80.19875336, 13.91736126], [80.19875336, 13.91708279], [80.19902802, 13.91708279], [80.19902802, 13.91652679], [80.19930267, 13.91653061], [80.19930267, 13.9159708], [80.19958496, 13.91597271], [80.19958496, 13.91569519], [80.19985962, 13.91569519], [80.19985962, 13.9151392], [80.20014191, 13.91514111], [80.20014191, 13.91458035], [80.20041656, 13.91458321], [80.20041656, 13.91402912], [80.20069122, 13.91403103], [80.20069122, 13.91292095], [80.20096588, 13.91292095], [80.20096588, 13.91263199], [80.20124817, 13.91263866], [80.20124817, 13.91208458], [80.20153046, 13.91208458], [80.20153046, 13.91097164], [80.20207977, 13.91097164], [80.20207977, 13.91069412], [80.20236206, 13.91069412], [80.20236206, 13.91041565], [80.20263672, 13.91042137], [80.20263672, 13.90959072], [80.20291901, 13.90959072], [80.20291901, 13.90903091], [80.20318604, 13.90903091], [80.20318604, 13.90874958], [80.20375061, 13.90874958], [80.20375061, 13.90819168], [80.20402527, 13.90819359], [80.20402527, 13.9076376], [80.20430756, 13.90764046], [80.20430756, 13.9070797], [80.20458221, 13.90708447], [80.20458221, 13.90652847], [80.20485687, 13.90653038], [80.20485687, 13.90568924], [80.20513916, 13.90569401], [80.20513916, 13.90541553], [80.20540619, 13.9054203], [80.20540619, 13.90513992], [80.20569611, 13.90513992], [80.20569611, 13.90458202], [80.20597076, 13.90458393], [80.20597076, 13.90402794], [80.20625305, 13.90402985], [80.20625305, 13.90345955], [80.20652771, 13.90347195], [80.20652771, 13.90291786], [80.20680237, 13.90291977], [80.20680237, 13.90264034], [80.20707703, 13.90264034], [80.20707703, 13.90236187], [80.20735931, 13.90236187], [80.20735931, 13.90180969], [80.20764923, 13.90180969], [80.20764923, 13.90125179], [80.20791626, 13.90125179], [80.20791626, 13.90096855], [80.20819092, 13.90097237], [80.20819092, 13.9006958], [80.20847321, 13.9006958], [80.20847321, 13.89986229], [80.20874786, 13.89986229], [80.20874786, 13.8993063], [80.20903015, 13.89931011], [80.20903015, 13.89819145], [80.20874786, 13.89819336], [80.20874786, 13.8973608], [80.20903015, 13.8973608], [80.20903015, 13.89708328], [80.21013641, 13.89708328], [80.21013641, 13.89680481], [80.2104187, 13.89680958], [80.2104187, 13.89653015], [80.21069336, 13.89653015], [80.21069336, 13.89569092], [80.21097565, 13.89569473], [80.21097565, 13.89513874], [80.21125031, 13.8951416], [80.21125031, 13.89375114], [80.21151733, 13.89375114], [80.21151733, 13.89319134], [80.21208191, 13.89319515], [80.21208191, 13.89291668], [80.21235657, 13.89291859], [80.21235657, 13.89236069], [80.21263885, 13.89236069], [80.21263885, 13.89151955], [80.21291351, 13.89152908], [80.21291351, 13.89069462], [80.2131958, 13.89069462], [80.2131958, 13.89013863], [80.21346283, 13.89014053], [80.21346283, 13.88931179], [80.21375275, 13.88931179], [80.21375275, 13.88819027], [80.2140274, 13.88819504], [80.2140274, 13.88736057], [80.21430206, 13.88736057], [80.21430206, 13.88680458], [80.21457672, 13.88681126], [80.21457672, 13.88653088], [80.21485901, 13.88653088], [80.21485901, 13.88625145], [80.2151413, 13.88625145], [80.2151413, 13.88597012], [80.21541595, 13.88597298], [80.21541595, 13.88569546], [80.21569061, 13.88569546], [80.21569824, 13.88541698], [80.2159729, 13.8854208], [80.2159729, 13.88514137], [80.21624756, 13.88514137], [80.21624756, 13.88457966], [80.21652985, 13.88458157], [80.21652985, 13.88402939], [80.21679688, 13.8840313], [80.21679688, 13.88346958], [80.21708679, 13.88347244], [80.21708679, 13.88263798], [80.21736145, 13.88265038], [80.21736145, 13.88208199], [80.21763611, 13.88208199], [80.21763611, 13.88097191], [80.2179184, 13.88097191], [80.2179184, 13.88041592], [80.21819305, 13.88042068], [80.21819305, 13.8801403], [80.21848297, 13.8801403], [80.21848297, 13.87985992], [80.21875, 13.87985992], [80.21875, 13.87903023], [80.21901703, 13.87903023], [80.21901703, 13.87847042], [80.21930695, 13.87847233], [80.21930695, 13.87791634], [80.21958923, 13.87792015], [80.21958923, 13.87736034], [80.21986389, 13.87736225], [80.21986389, 13.87680626], [80.22013855, 13.87681007], [80.22013855, 13.87597179], [80.22041321, 13.87597179], [80.22041321, 13.87514019], [80.22070313, 13.87514019], [80.22070313, 13.87430954], [80.22097015, 13.87430954], [80.22097015, 13.87319088], [80.22125244, 13.87319565], [80.22125244, 13.87236214], [80.2215271, 13.87236214], [80.2215271, 13.87152672], [80.22180176, 13.87152958], [80.22180176, 13.8706913], [80.22208405, 13.87069321], [80.22208405, 13.86986065], [80.2223587, 13.86986065], [80.2223587, 13.86875057], [80.22263336, 13.86875057], [80.22263336, 13.86792183], [80.22292328, 13.86792183], [80.22292328, 13.86681175], [80.22319794, 13.86681175], [80.22319794, 13.86597061], [80.2234726, 13.86597347], [80.2234726, 13.86486053], [80.22374725, 13.86486053], [80.22374725, 13.86375141], [80.22402954, 13.86375141], [80.22402954, 13.86292076], [80.22429657, 13.86292076], [80.22429657, 13.86181164], [80.22458649, 13.86181164], [80.22458649, 13.86097145], [80.22486115, 13.86097336], [80.22486115, 13.85986137], [80.2251358, 13.85986137], [80.2251358, 13.85847282], [80.22541809, 13.85847855], [80.22541809, 13.85653114], [80.22569275, 13.85653114], [80.22569275, 13.85569191], [80.22597504, 13.85569382], [80.22597504, 13.85486031], [80.22624969, 13.85486031], [80.22624969, 13.85430622], [80.22651672, 13.85431099], [80.22651672, 13.85375023], [80.22680664, 13.85375023], [80.22680664, 13.85235119], [80.2270813, 13.85235977], [80.2270813, 13.85180569], [80.22735596, 13.85181141], [80.22735596, 13.85124969], [80.22763824, 13.85124969], [80.22763824, 13.8506918], [80.2279129, 13.8506937], [80.2279129, 13.85013771], [80.22820282, 13.85013962], [80.22820282, 13.84986019], [80.22846985, 13.8498621], [80.22846985, 13.84875011], [80.22875977, 13.84875202], [80.22875977, 13.84735966], [80.22902679, 13.84735966], [80.22902679, 13.84681034], [80.22930908, 13.84681034], [80.22930908, 13.84624958], [80.22957611, 13.84624958], [80.22957611, 13.8459692], [80.2298584, 13.84597206], [80.2298584, 13.84514046], [80.23014069, 13.84514046], [80.23014069, 13.84486198], [80.23042297, 13.84486198], [80.23041534, 13.84430504], [80.23069763, 13.84430981], [80.23069763, 13.84375191], [80.23097229, 13.84375191], [80.23097229, 13.84236145], [80.23124695, 13.84236145], [80.23124695, 13.84208298], [80.23152924, 13.84208298], [80.23152924, 13.84152699], [80.23179626, 13.84153175], [80.23179626, 13.84125137], [80.23208618, 13.84125137], [80.23208618, 13.84041023], [80.23236084, 13.84041691], [80.23236084, 13.83986092], [80.23264313, 13.83986092], [80.2326355, 13.83874893], [80.23291779, 13.83875084], [80.23291779, 13.83819103], [80.23319244, 13.83819485], [80.23319244, 13.83763885], [80.2334671, 13.83764076], [80.2334671, 13.8373518], [80.23374939, 13.83736134], [80.23374939, 13.83652687], [80.23401642, 13.83653069], [80.23401642, 13.83542061], [80.23430634, 13.83542061], [80.23430634, 13.83458042], [80.23458099, 13.83458328], [80.23458099, 13.8340292], [80.23486328, 13.83403111], [80.23486328, 13.83318996], [80.23513794, 13.83319473], [80.23513794, 13.83236122], [80.23542023, 13.83236122], [80.23542023, 13.83180428], [80.23568726, 13.83181095], [80.23568726, 13.83154011], [80.23596954, 13.83154011], [80.23596954, 13.83125114], [80.23625183, 13.83125114], [80.23625183, 13.8309679], [80.23680878, 13.83097267], [80.23680878, 13.8306942], [80.23708344, 13.8306942], [80.23708344, 13.83013821], [80.23735809, 13.83014107], [80.23735809, 13.82931137], [80.23763275, 13.82931137], [80.23763275, 13.82847023], [80.23791504, 13.82847214], [80.23791504, 13.82763767], [80.23819733, 13.82763958], [80.23819733, 13.82681084], [80.23847198, 13.82681084], [80.23847198, 13.82625008], [80.23874664, 13.82625008], [80.23874664, 13.8259697], [80.23902893, 13.8259716], [80.23902893, 13.82569408], [80.23930359, 13.82569408], [80.23930359, 13.82513809], [80.23958588, 13.82514], [80.23958588, 13.82485962], [80.23986053, 13.82486153], [80.23986053, 13.82458401], [80.24013519, 13.82458401], [80.24013519, 13.82430553], [80.24041748, 13.82431126], [80.24041748, 13.82402992], [80.24069977, 13.82402992], [80.24069977, 13.82374954], [80.2409668, 13.82374954], [80.2409668, 13.82347202], [80.24124908, 13.82347202], [80.24124908, 13.82319355], [80.24153137, 13.82319355], [80.24153137, 13.82291794], [80.24208069, 13.82291985], [80.24208069, 13.82264042], [80.24236298, 13.82264042], [80.24236298, 13.82237053], [80.24263763, 13.82237053], [80.24263763, 13.82208157], [80.24291992, 13.82208443], [80.24291992, 13.82180595], [80.24318695, 13.82180977], [80.24318695, 13.82153034], [80.24346924, 13.82153034], [80.24346924, 13.82097244], [80.24375153, 13.82097244], [80.24375153, 13.82069397], [80.24402618, 13.82069397], [80.24402618, 13.82041645], [80.24430847, 13.82042027], [80.24430847, 13.81985855], [80.24458313, 13.81986237], [80.24458313, 13.81958389], [80.24485779, 13.81958389], [80.24485779, 13.81708336], [80.24514008, 13.81708336], [80.24514008, 13.81402683], [80.2454071, 13.8140316], [80.2454071, 13.81236076], [80.24569702, 13.81236076], [80.24569702, 13.81068993], [80.24597168, 13.81069469], [80.24597168, 13.80930519], [80.24624634, 13.80931187], [80.24624634, 13.80847073], [80.24652863, 13.80847263], [80.24652863, 13.80763912], [80.24680328, 13.80764103], [80.24680328, 13.80681133], [80.2470932, 13.80681133], [80.2470932, 13.80597019], [80.24736023, 13.80597305], [80.24736023, 13.80513859], [80.24764252, 13.80514145], [80.24764252, 13.80403137], [80.24791718, 13.80403137], [80.24791718, 13.8029213], [80.24819183, 13.8029213], [80.24819183, 13.80153275], [80.24846649, 13.80153275], [80.24846649, 13.80042076], [80.24874878, 13.80042076], [80.24874878, 13.79957962], [80.24791718, 13.79958439], [80.24791718, 13.79930592], [80.24764252, 13.79931068], [80.24764252, 13.79846954], [80.24791718, 13.7984724], [80.24791718, 13.79819393], [80.24819183, 13.79820061], [80.24819183, 13.79792023], [80.24846649, 13.79792023], [80.24846649, 13.79763985], [80.24874878, 13.79763985], [80.24874878, 13.79736042], [80.24903107, 13.79736233], [80.24903107, 13.79708195], [80.24930573, 13.79708195], [80.24930573, 13.79625034], [80.24958038, 13.79625034], [80.24957275, 13.79569244], [80.24986267, 13.79569435], [80.24986267, 13.79514027], [80.25013733, 13.79514027], [80.25013733, 13.79374981], [80.25041962, 13.79374981], [80.25041962, 13.79069138], [80.25013733, 13.79069328], [80.25013733, 13.78930473], [80.25041962, 13.78930473], [80.25041962, 13.78819466], [80.25069427, 13.78819466], [80.25069427, 13.78708267], [80.25096893, 13.78708267], [80.25096893, 13.78624916], [80.25152588, 13.78625965], [80.25152588, 13.78541946], [80.25180817, 13.78541946], [80.25180817, 13.78430939], [80.25208282, 13.78430939], [80.25208282, 13.78292179], [80.25235748, 13.78292179], [80.25235748, 13.78097057], [80.25208282, 13.78097343], [80.25208282, 13.78041744], [80.25235748, 13.78042126], [80.25235748, 13.78014088], [80.25208282, 13.78014088], [80.25208282, 13.77875137], [80.25180817, 13.77875137], [80.25180817, 13.77792072], [80.25152588, 13.77792072], [80.25152588, 13.77597046], [80.25125122, 13.77597237], [80.25125122, 13.7751379], [80.25096893, 13.77514267], [80.25096893, 13.77486038], [80.25125122, 13.77486038], [80.25125122, 13.77458382], [80.25096893, 13.77458191], [80.25096893, 13.77375031], [80.25068665, 13.77375031], [80.25068665, 13.77318954], [80.25041962, 13.77319431], [80.25041962, 13.77152824], [80.25013733, 13.77153015], [80.25013733, 13.77097034], [80.24986267, 13.77097225], [80.24986267, 13.76847172], [80.24958038, 13.76847172], [80.24958038, 13.76791573], [80.24931335, 13.76791954], [80.24931335, 13.76707935], [80.24903107, 13.76708412], [80.24903107, 13.76597214], [80.24930573, 13.76597214], [80.24930573, 13.76458359], [80.24903107, 13.76458359], [80.24903107, 13.76263905], [80.24874878, 13.76264191], [80.24874878, 13.7618103], [80.24846649, 13.7618103], [80.24846649, 13.76153183], [80.24819183, 13.76153183], [80.24819183, 13.75986099], [80.24791718, 13.75986099], [80.24791718, 13.75932121], [80.24764252, 13.75932121], [80.24764252, 13.75791931], [80.24736023, 13.75791931], [80.24736023, 13.75736141], [80.24708557, 13.75736141], [80.24708557, 13.75680542], [80.24680328, 13.75680923], [80.24680328, 13.75625134], [80.24652863, 13.75625134], [80.24652863, 13.75568962], [80.24624634, 13.75569534], [80.24624634, 13.75458336], [80.24597168, 13.75458336], [80.24597168, 13.75402737], [80.24569702, 13.75403118], [80.24569702, 13.75319004], [80.24541473, 13.75319481], [80.24541473, 13.75208473], [80.24514008, 13.75208473], [80.24514008, 13.75097275], [80.24485779, 13.75097275], [80.24485779, 13.75042057], [80.24458313, 13.75042057], [80.24458313, 13.74958038], [80.24485779, 13.74958229], [80.24485779, 13.74874973], [80.24458313, 13.74874973], [80.24458313, 13.74818993], [80.24430847, 13.74819374], [80.24430847, 13.74791622], [80.24402618, 13.74792099], [80.24402618, 13.74736023], [80.24375153, 13.74736023], [80.24375153, 13.74708366], [80.24346924, 13.74709129], [80.24346924, 13.74653053], [80.24318695, 13.74653053], [80.24318695, 13.74431133], [80.24291992, 13.74431133], [80.24291992, 13.74374962], [80.24263763, 13.74374962], [80.24263763, 13.74347019], [80.24236298, 13.7434721], [80.24236298, 13.74319363], [80.24208069, 13.74319363], [80.24208069, 13.74180603], [80.24180603, 13.74180984], [80.24180603, 13.74042034], [80.24153137, 13.74042034], [80.24153137, 13.73903179], [80.24124908, 13.73903179], [80.24124908, 13.73764038], [80.2409668, 13.73764038], [80.2409668, 13.73736191], [80.24069214, 13.73736191], [80.24069214, 13.73597145], [80.24041748, 13.73597145], [80.24041748, 13.73402691], [80.24014282, 13.73403168], [80.24014282, 13.73347092], [80.23986053, 13.73347092], [80.23986053, 13.73152924], [80.23958588, 13.73152924], [80.23958588, 13.73125076], [80.23929596, 13.73125076], [80.23929596, 13.72958088], [80.23902893, 13.72958279], [80.23902893, 13.72791672], [80.23874664, 13.72792053], [80.23874664, 13.72653103], [80.23847198, 13.72653103], [80.23847198, 13.72486115], [80.23819733, 13.72486115], [80.23819733, 13.72319412], [80.23791504, 13.72319412], [80.23791504, 13.72263813], [80.23763275, 13.72264099], [80.23763275, 13.72181129], [80.23792267, 13.72181129], [80.23792267, 13.72042084], [80.23763275, 13.72042084], [80.23763275, 13.71903038], [80.23735809, 13.71903038], [80.23735809, 13.71681118], [80.23707581, 13.71681118], [80.23707581, 13.71597195], [80.23680878, 13.71597195], [80.23680878, 13.71374989], [80.23652649, 13.71375179], [80.23652649, 13.71319103], [80.23625183, 13.7131958], [80.23625183, 13.70930481], [80.23596954, 13.70930958], [80.23596954, 13.70875168], [80.23568726, 13.70875168], [80.23568726, 13.7068119], [80.23542023, 13.7068119], [80.23542023, 13.70347118], [80.23513794, 13.70347309], [80.23513794, 13.70125103], [80.23486328, 13.70125103], [80.23486328, 13.70042133], [80.23457336, 13.70042133], [80.23457336, 13.69818974], [80.23486328, 13.69819546], [80.23486328, 13.69763947], [80.23430634, 13.69764137], [80.23430634, 13.69736004], [80.23401642, 13.69736004], [80.23401642, 13.69707966], [80.23430634, 13.69708157], [80.23430634, 13.69513798], [80.23401642, 13.69514275], [80.23401642, 13.69403076], [80.23430634, 13.69403076], [80.23430634, 13.69318962], [80.23402405, 13.69319439], [80.23402405, 13.69180584], [80.23430634, 13.69181061], [80.23430634, 13.69069195], [80.23402405, 13.69069386], [80.23402405, 13.69041634], [80.23374939, 13.6904211], [80.23374939, 13.68931103], [80.2334671, 13.68931103], [80.2334671, 13.68902969], [80.23374939, 13.68902969], [80.23374939, 13.68624973], [80.2334671, 13.68624973], [80.2334671, 13.6837492], [80.23374939, 13.6837492], [80.23374939, 13.68292046], [80.23401642, 13.68292046], [80.23401642, 13.68264198], [80.23374939, 13.68264198], [80.23374939, 13.68181038], [80.2334671, 13.68181038], [80.2334671, 13.68153191], [80.23319244, 13.68153191], [80.23319244, 13.68097115], [80.23347473, 13.68097115], [80.23347473, 13.68041706], [80.23374939, 13.68042183], [80.23374939, 13.67764091], [80.2334671, 13.67764091], [80.2334671, 13.67736053], [80.23374939, 13.67736053], [80.23374939, 13.67569542], [80.23347473, 13.67569542], [80.23347473, 13.67319489], [80.23374939, 13.67319489], [80.23374939, 13.67291737], [80.2334671, 13.67292118], [80.2334671, 13.67208004], [80.23319244, 13.6720829], [80.23319244, 13.6706953], [80.23291779, 13.6706953], [80.23291779, 13.67041683], [80.23264313, 13.67042065], [80.23264313, 13.66958046], [80.23291779, 13.66958237], [80.23291779, 13.66930676], [80.23374939, 13.66931057], [80.23374939, 13.66903114], [80.2334671, 13.66903114], [80.2334671, 13.66874981], [80.23319244, 13.66874981], [80.23319244, 13.66764069], [80.2334671, 13.66764069], [80.2334671, 13.66736031], [80.23402405, 13.66736031], [80.23402405, 13.66652775], [80.23374939, 13.66653061], [80.23374939, 13.66596985], [80.23347473, 13.66597176], [80.23347473, 13.66541576], [80.23319244, 13.66542053], [80.23319244, 13.66458035], [80.23291779, 13.66458416], [80.23291779, 13.66374969], [80.2334671, 13.66374969], [80.2334671, 13.66347027], [80.23402405, 13.66347218], [80.23402405, 13.6631937], [80.23374939, 13.6631937], [80.23374939, 13.66152763], [80.23401642, 13.66152954], [80.23401642, 13.6598711], [80.23430634, 13.6598711], [80.23430634, 13.65792179], [80.23401642, 13.65792179], [80.23401642, 13.65597057], [80.23430634, 13.65597057], [80.23430634, 13.65513897], [80.23401642, 13.65514183], [80.23401642, 13.65486145], [80.23430634, 13.65486145], [80.23430634, 13.65402699], [80.23457336, 13.65403175], [80.23457336, 13.65263939], [80.23486328, 13.65263939], [80.23486328, 13.65152931], [80.23457336, 13.65152931], [80.23457336, 13.64986134], [80.23486328, 13.64986134], [80.23486328, 13.64875126], [80.23513794, 13.64875126], [80.23513794, 13.64818954], [80.23542023, 13.64819527], [80.23542023, 13.64708328], [80.23569489, 13.64708328], [80.23569489, 13.64513874], [80.23596954, 13.64514065], [80.23596954, 13.64153099], [80.23625183, 13.64153099], [80.23625183, 13.63986015], [80.23652649, 13.63986015], [80.23652649, 13.6384716], [80.23680878, 13.6384716], [80.23680878, 13.63763809], [80.23707581, 13.63764], [80.23707581, 13.63652992], [80.23735809, 13.63652992], [80.23735809, 13.63403034], [80.23763275, 13.63403034], [80.23763275, 13.6331892], [80.23791504, 13.63319397], [80.23791504, 13.63263988], [80.23819733, 13.63264179], [80.23819733, 13.63181019], [80.23847198, 13.63181019], [80.23847198, 13.63041973], [80.23874664, 13.63041973], [80.23874664, 13.62930965], [80.23847198, 13.62930965], [80.23847198, 13.62874889], [80.23874664, 13.62874889], [80.23874664, 13.62792015], [80.23902893, 13.62792015], [80.23902893, 13.62708092], [80.23930359, 13.62708282], [80.23930359, 13.62624931], [80.23958588, 13.62624931], [80.23958588, 13.62513924], [80.23986053, 13.62513924], [80.23986053, 13.62458134], [80.24013519, 13.62458324], [80.24013519, 13.62319469], [80.24041748, 13.62319469], [80.24041748, 13.62236118], [80.24069214, 13.62236118], [80.24069214, 13.62180519], [80.2409668, 13.62181187], [80.2409668, 13.62125111], [80.24124908, 13.62125111], [80.24124908, 13.61958027], [80.24153137, 13.61958313], [80.24153137, 13.61902905], [80.24180603, 13.61903095], [80.24180603, 13.61736107], [80.24208069, 13.61736107], [80.24208069, 13.61625099], [80.24236298, 13.61625099], [80.24236298, 13.61569023], [80.24263763, 13.61569405], [80.24263763, 13.61541557], [80.24291992, 13.6154213], [80.24291992, 13.61485958], [80.24319458, 13.6148634], [80.24319458, 13.61375046], [80.24346924, 13.61375046], [80.24346924, 13.61347008], [80.24375153, 13.61347198], [80.24375153, 13.61291599], [80.24402618, 13.61292076], [80.24402618, 13.61236], [80.24430847, 13.61236], [80.24430847, 13.61153126], [80.24458313, 13.61153126], [80.24458313, 13.61096954], [80.24485779, 13.6109724], [80.24485779, 13.61041641], [80.24514008, 13.61042118], [80.24514008, 13.60986042], [80.24541473, 13.60986233], [80.24541473, 13.60930634], [80.24569702, 13.6093111], [80.24569702, 13.60876083], [80.24597168, 13.60876083], [80.24597168, 13.60819244], [80.24624634, 13.60819435], [80.24624634, 13.60764027], [80.24652863, 13.60764027], [80.24652863, 13.60707855], [80.24680328, 13.60708427], [80.24680328, 13.60652828], [80.2470932, 13.60653019], [80.2470932, 13.60624981], [80.24736023, 13.60624981], [80.24736023, 13.60569096], [80.24764252, 13.60569382], [80.24764252, 13.60513973], [80.24791718, 13.60513973], [80.24791718, 13.60458088], [80.24819183, 13.60458374], [80.24819183, 13.60402775], [80.24846649, 13.60402966], [80.24846649, 13.60346889], [80.24874878, 13.6034708], [80.24874878, 13.60291767], [80.24903107, 13.60291958], [80.24903107, 13.60236168], [80.24931335, 13.60236168], [80.24930573, 13.60180473], [80.24957275, 13.60181046], [80.24957275, 13.6012516], [80.24986267, 13.6012516], [80.24986267, 13.60069084], [80.25013733, 13.60069466], [80.25013733, 13.60041714], [80.25041962, 13.60042191], [80.25041962, 13.59986115], [80.25069427, 13.59986115], [80.25069427, 13.59930515], [80.25096893, 13.59930992], [80.25096893, 13.59875107], [80.25125122, 13.59875107], [80.25125122, 13.59847069], [80.25152588, 13.5984726], [80.25152588, 13.5979166], [80.25180817, 13.59792042], [80.25180817, 13.59736061], [80.25208282, 13.59736061], [80.25208282, 13.59708118], [80.25235748, 13.59708309], [80.25235748, 13.5965271], [80.25263977, 13.59653187], [80.25263977, 13.59625053], [80.2529068, 13.59625053], [80.2529068, 13.59597111], [80.25319672, 13.59597301], [80.25319672, 13.59541702], [80.25347137, 13.59542179], [80.25347137, 13.59514141], [80.25374603, 13.59514141], [80.25374603, 13.59486103], [80.25347137, 13.59486103], [80.25347137, 13.59431171], [80.25374603, 13.59431171], [80.25374603, 13.59375095], [80.25402832, 13.59375095], [80.25402832, 13.59346199], [80.25375366, 13.59347343], [80.25375366, 13.59319496], [80.25402832, 13.59319496], [80.25402832, 13.59291744], [80.2545929, 13.59292126], [80.2545929, 13.59236145], [80.25485992, 13.59236145], [80.25485992, 13.59125137], [80.25514221, 13.59125137], [80.25514221, 13.59068966], [80.25541687, 13.59069538], [80.25541687, 13.58985996], [80.25569916, 13.58985996], [80.25569153, 13.58958244], [80.25597382, 13.58958244], [80.25597382, 13.58930683], [80.25624847, 13.58931065], [80.25624847, 13.58847046], [80.25653076, 13.58847237], [80.25653076, 13.58791637], [80.25681305, 13.58792114], [80.25681305, 13.58736038], [80.25708008, 13.58736038], [80.25708008, 13.5868063], [80.25736237, 13.58681107], [80.25736237, 13.58625031], [80.25763702, 13.58625031], [80.25763702, 13.58596992], [80.25791931, 13.58597183], [80.25791931, 13.58541584], [80.25818634, 13.58542061], [80.25818634, 13.58514023], [80.25846863, 13.58514023], [80.25846863, 13.58459091], [80.25874329, 13.58459091], [80.25874329, 13.58403015], [80.2590332, 13.58403015], [80.2590332, 13.58125019], [80.25930786, 13.58125019], [80.25930786, 13.58096981], [80.25958252, 13.58097172], [80.25958252, 13.58041573], [80.25985718, 13.58041954], [80.25985718, 13.57985973], [80.26013947, 13.57985973], [80.26013947, 13.57931042], [80.26040649, 13.57931042], [80.26040649, 13.57903004], [80.26069641, 13.57903004], [80.26069641, 13.57845974], [80.26097107, 13.57847214], [80.26097107, 13.57819366], [80.26125336, 13.57819366], [80.26125336, 13.57791805], [80.26152802, 13.57791996], [80.26152802, 13.5773592], [80.26180267, 13.57736206], [80.26180267, 13.5765276], [80.26207733, 13.57653046], [80.26207733, 13.57625198], [80.26235962, 13.57625198], [80.26235962, 13.57569122], [80.26264191, 13.57569313], [80.26264191, 13.57541847], [80.26291656, 13.57542038], [80.26291656, 13.57486057], [80.26319122, 13.57486057], [80.26319122, 13.57402706], [80.26346588, 13.57403183], [80.26346588, 13.5737524], [80.26374817, 13.5737524], [80.26374817, 13.57292175], [80.26403046, 13.57292175], [80.26403046, 13.57208061], [80.26430511, 13.57208347], [80.26430511, 13.57124901], [80.26457977, 13.57125092], [80.26457977, 13.57069111], [80.26486206, 13.57069302], [80.26486206, 13.57013893], [80.26513672, 13.57014084], [80.26513672, 13.56986141], [80.26541901, 13.56986141], [80.26541901, 13.56930542], [80.26568604, 13.56931019], [80.26568604, 13.56875134], [80.26597595, 13.56875134], [80.26597595, 13.56818962], [80.26625061, 13.56819534], [80.26625061, 13.56763935], [80.2665329, 13.56764126], [80.2665329, 13.56681156], [80.26680756, 13.56681156], [80.26680756, 13.5662508], [80.26708221, 13.5662508], [80.26708221, 13.56569004], [80.2673645, 13.56569481], [80.2673645, 13.56513882], [80.26763916, 13.56514072], [80.26763916, 13.56457996], [80.26791382, 13.56458473], [80.26791382, 13.56402874], [80.26819611, 13.56403065], [80.26819611, 13.56319046], [80.26847076, 13.56319523], [80.26847076, 13.56263828], [80.26875305, 13.56264114], [80.26875305, 13.56245422], [80.26431274, 13.56014061], [80.26431274, 13.56124973], [80.26403046, 13.56124973], [80.26403046, 13.56153107], [80.26374817, 13.56152916], [80.26374817, 13.56208229], [80.26346588, 13.56208038], [80.26346588, 13.56235981], [80.26319122, 13.56235981], [80.26319122, 13.56264114], [80.26291656, 13.56264114], [80.26291656, 13.56292057], [80.26264191, 13.56291676], [80.26264191, 13.56347275], [80.26235962, 13.5634613], [80.26235962, 13.56375122], [80.26207733, 13.56375122], [80.26207733, 13.56403065], [80.26180267, 13.56403065], [80.26180267, 13.56431103], [80.26152802, 13.56430531], [80.26152802, 13.56458473], [80.26125336, 13.56458473], [80.26125336, 13.5648613], [80.26097107, 13.5648613], [80.26097107, 13.56514072], [80.26069641, 13.56514072], [80.26069641, 13.5654192], [80.26013947, 13.56541729], [80.26013947, 13.56569481], [80.25986481, 13.56569481], [80.25986481, 13.56597328], [80.25958252, 13.56597137], [80.25958252, 13.5662508], [80.25930786, 13.5662508], [80.25930786, 13.56652737], [80.2590332, 13.56651974], [80.2590332, 13.56681156], [80.25875092, 13.56680489], [80.25875092, 13.56708336], [80.25846863, 13.56708145], [80.25846863, 13.56736088], [80.25818634, 13.56736088], [80.25818634, 13.56764126], [80.25791931, 13.56764126], [80.25791931, 13.56792164], [80.25736237, 13.56791687], [80.25736237, 13.56819534], [80.25708008, 13.56819534], [80.25708008, 13.56847095], [80.25680542, 13.56847095], [80.25681305, 13.56875134], [80.25624847, 13.56875134], [80.25624847, 13.56903076], [80.25596619, 13.56903076], [80.25596619, 13.56931019], [80.25569153, 13.56930542], [80.25569153, 13.56958294], [80.25541687, 13.56958294], [80.25541687, 13.56986141], [80.25514221, 13.56986141], [80.25514221, 13.57014084], [80.2545929, 13.57014084], [80.2545929, 13.57041931], [80.25430298, 13.5704174], [80.25430298, 13.57069111], [80.25402832, 13.57069492], [80.25402832, 13.5709734], [80.2529068, 13.57097054], [80.2529068, 13.57125092], [80.25208282, 13.57125092], [80.25208282, 13.57152939], [80.25096893, 13.57152939], [80.25096893, 13.57180977], [80.25041962, 13.571805], [80.25041962, 13.57208347], [80.24986267, 13.57208347], [80.24986267, 13.57347107], [80.25013733, 13.57347107], [80.25013733, 13.57486057], [80.25041962, 13.57486057], [80.25041962, 13.57514191], [80.25069427, 13.57514], [80.25069427, 13.57569313], [80.25096893, 13.57569313], [80.25096893, 13.57597065], [80.25125122, 13.57597065], [80.25125122, 13.57763958], [80.25096893, 13.57763958], [80.25096893, 13.57874966], [80.25068665, 13.57874966], [80.25068665, 13.57931042], [80.25041962, 13.57930565], [80.25041962, 13.57958412], [80.25013733, 13.57957935], [80.25013733, 13.57985973], [80.24986267, 13.57985973], [80.24986267, 13.58041954], [80.24958038, 13.58041573], [80.24958038, 13.5806942], [80.24930573, 13.5806942], [80.24930573, 13.58097172], [80.24903107, 13.58096981], [80.24903107, 13.58125019], [80.24847412, 13.58125019], [80.24847412, 13.58152771], [80.24819183, 13.58152103], [80.24819183, 13.58181095], [80.24764252, 13.58180618], [80.24764252, 13.5820837], [80.24736023, 13.5820837], [80.24736023, 13.58236217], [80.2470932, 13.58236027], [80.2470932, 13.58263969], [80.24652863, 13.58263969], [80.24652863, 13.58292103], [80.24624634, 13.58292103], [80.24624634, 13.58403015], [80.24597168, 13.58403015], [80.24597168, 13.58431053], [80.2454071, 13.58431053], [80.2454071, 13.58459091], [80.24514008, 13.58458424], [80.24514008, 13.58485985], [80.24485779, 13.58485985], [80.24485779, 13.58514023], [80.24458313, 13.58514023], [80.24458313, 13.58542061], [80.24430847, 13.58542061], [80.24430847, 13.58625031], [80.24402618, 13.58625031], [80.24402618, 13.58708191], [80.24375916, 13.58708], [80.24375916, 13.5876503], [80.24346924, 13.5876503], [80.24346924, 13.58792114], [80.24318695, 13.58792114], [80.24318695, 13.58931065], [80.24291992, 13.58931065], [80.24291992, 13.5901413], [80.24263763, 13.59013939], [80.24263763, 13.5909729], [80.24236298, 13.59097004], [80.24236298, 13.59180927], [80.24263763, 13.59180546], [80.24263763, 13.59236145], [80.24236298, 13.59236145], [80.24236298, 13.59347343], [80.24208069, 13.59347343], [80.24208069, 13.59458256], [80.24180603, 13.59458065], [80.24180603, 13.59542179], [80.24153137, 13.59541702], [80.24153137, 13.59569454], [80.24124908, 13.59569454], [80.24124908, 13.59597301], [80.2409668, 13.59597111], [80.2409668, 13.59682083], [80.24069214, 13.59680462], [80.24069214, 13.59708309], [80.24041748, 13.59708309], [80.24041748, 13.59736061], [80.24014282, 13.59736061], [80.24014282, 13.59764099], [80.23986053, 13.59764099], [80.23986053, 13.59792042], [80.23958588, 13.5979166], [80.23958588, 13.5984726], [80.23929596, 13.59847069], [80.23929596, 13.59875107], [80.23902893, 13.59875107], [80.23902893, 13.59902859], [80.23847198, 13.59902859], [80.23847198, 13.59930992], [80.23819733, 13.59930992], [80.23819733, 13.5995903], [80.23791504, 13.59958267], [80.23791504, 13.59986115], [80.23735809, 13.59986115], [80.23735809, 13.60042191], [80.23708344, 13.60041714], [80.23708344, 13.60069466], [80.23680878, 13.60069466], [80.23680878, 13.60097122], [80.23652649, 13.60097122], [80.23652649, 13.6012516], [80.23625183, 13.6012516], [80.23625183, 13.60153198], [80.23596954, 13.60153198], [80.23596954, 13.60181046], [80.23542023, 13.60180473], [80.23542023, 13.60208321], [80.23513794, 13.6020813], [80.23513794, 13.60236168], [80.23458099, 13.60236168], [80.23458099, 13.60264015], [80.23430634, 13.60262966], [80.23430634, 13.60291958], [80.23402405, 13.60291767], [80.23402405, 13.60319328], [80.23347473, 13.60319328], [80.23347473, 13.6034708], [80.23319244, 13.60346889], [80.23319244, 13.60375023], [80.23264313, 13.60375023], [80.23264313, 13.60402966], [80.2325058, 13.60402775], [80.23236084, 13.60402966], [80.23236084, 13.60431004], [80.23180389, 13.60430622], [80.23180389, 13.60458374], [80.23097229, 13.60458374], [80.23097229, 13.60486221], [80.23069763, 13.60485935], [80.23069763, 13.60513973], [80.23042297, 13.60513973], [80.23042297, 13.60542011], [80.2298584, 13.6054163], [80.2298584, 13.60569382], [80.22958374, 13.60569382], [80.22958374, 13.60597229], [80.22930908, 13.60596943], [80.22930908, 13.60624981], [80.22902679, 13.60624981], [80.22902679, 13.60653019], [80.2279129, 13.60653019], [80.2279129, 13.60680962], [80.22736359, 13.6068058], [80.22736359, 13.60708427], [80.2270813, 13.60707855], [80.2270813, 13.60736179], [80.22680664, 13.60736179], [80.22680664, 13.60764027], [80.22651672, 13.60764027], [80.22651672, 13.60791969], [80.22680664, 13.60791588], [80.22680664, 13.60819435], [80.2270813, 13.60819244], [80.2270813, 13.60876083], [80.22651672, 13.60876083], [80.22651672, 13.60903263], [80.22541809, 13.60902786], [80.22541809, 13.60986233], [80.22486115, 13.60986042], [80.22486115, 13.61182022], [80.22458649, 13.61182022], [80.22458649, 13.61264038], [80.22429657, 13.61264038], [80.22429657, 13.61292076], [80.22402954, 13.61291599], [80.22402954, 13.61347198], [80.22374725, 13.61347008], [80.22374725, 13.61375046], [80.2234726, 13.61375046], [80.2234726, 13.61403084], [80.22319794, 13.61403084], [80.22319794, 13.61431122], [80.22291565, 13.61430645], [80.22291565, 13.6148634], [80.22263336, 13.61485958], [80.22263336, 13.61514091], [80.2223587, 13.61513805], [80.2223587, 13.61597347], [80.22180939, 13.61596966], [80.22180176, 13.61625099], [80.2215271, 13.61625099], [80.2215271, 13.61708164], [80.22125244, 13.61707973], [80.22125244, 13.61792088], [80.22097015, 13.61791706], [80.22097015, 13.61847305], [80.22070313, 13.61847019], [80.22070313, 13.61931133], [80.22041321, 13.61930466], [80.22041321, 13.61958313], [80.22013855, 13.61958027], [80.22013855, 13.62014103], [80.21985626, 13.62014103], [80.21985626, 13.62070179], [80.2195816, 13.62069511], [80.2195816, 13.62097263], [80.21930695, 13.62097073], [80.21930695, 13.62125111], [80.21901703, 13.62125111], [80.21901703, 13.62153053], [80.21875, 13.62153053], [80.21875, 13.62181187], [80.21848297, 13.62181187], [80.21848297, 13.62264061], [80.21819305, 13.6226387], [80.21819305, 13.62347317], [80.21763611, 13.62347126], [80.21763611, 13.62376022], [80.21736145, 13.62376022], [80.21736145, 13.62403202], [80.21708679, 13.62403202], [80.21708679, 13.62430954], [80.2168045, 13.62430477], [80.2168045, 13.62458324], [80.21652985, 13.62458134], [80.21652985, 13.62486076], [80.21624756, 13.62486076], [80.21624756, 13.62513924], [80.2159729, 13.62513924], [80.2159729, 13.62541962], [80.21569824, 13.62541676], [80.21569824, 13.62569523], [80.21541595, 13.62569141], [80.21541595, 13.62597084], [80.2151413, 13.62597084], [80.2151413, 13.62624931], [80.21485901, 13.62624931], [80.21485901, 13.6265316], [80.21458435, 13.62652683], [80.21458435, 13.62680531], [80.21430206, 13.62680531], [80.21430206, 13.62708282], [80.2140274, 13.62708282], [80.2140274, 13.6273613], [80.21346283, 13.6273613], [80.21346283, 13.62764168], [80.21290588, 13.62764168], [80.21290588, 13.62792015], [80.2123642, 13.62791538], [80.2123642, 13.62819576], [80.21180725, 13.62819576], [80.21180725, 13.62847137], [80.21125031, 13.62847137], [80.21125031, 13.62874889], [80.21069336, 13.62874889], [80.21069336, 13.62903023], [80.2104187, 13.62903023], [80.2104187, 13.62930965], [80.20986176, 13.62930489], [80.20986176, 13.62958431], [80.20903015, 13.62957001], [80.20903015, 13.62986183], [80.20791626, 13.62986183], [80.20791626, 13.6301403], [80.20707703, 13.6301403], [80.20707703, 13.63041973], [80.20680237, 13.63041782], [80.20680237, 13.63069344], [80.20652771, 13.63069344], [80.20652771, 13.63097191], [80.20597076, 13.63097191], [80.20597076, 13.63125038], [80.20540619, 13.63125038], [80.20540619, 13.63152981], [80.20458984, 13.63152981], [80.20458984, 13.63181019], [80.20402527, 13.63180637], [80.20402527, 13.63208389], [80.20347595, 13.63208389], [80.20347595, 13.63180637], [80.20319366, 13.63180637], [80.20319366, 13.63208389], [80.20236206, 13.63208389], [80.20236206, 13.63236237], [80.20207977, 13.63236046], [80.20207977, 13.63264179], [80.20180511, 13.63263988], [80.20181274, 13.6331892], [80.20124817, 13.63319588], [80.20124817, 13.63347244], [80.20096588, 13.63346863], [80.20096588, 13.63374996], [80.20041656, 13.63374996], [80.20041656, 13.63346863], [80.19985962, 13.63346863], [80.19985962, 13.63374996], [80.19930267, 13.63374996], [80.19930267, 13.63403034], [80.19902802, 13.63403034], [80.19902802, 13.63514042], [80.19875336, 13.63514042], [80.19875336, 13.63541985], [80.19845581, 13.63541985], [80.19845581, 13.63570118], [80.19791412, 13.63569355], [80.19791412, 13.63597202], [80.19735718, 13.63597202], [80.19735718, 13.63624954], [80.19708252, 13.63624954], [80.19708252, 13.63652992], [80.1965332, 13.63652992], [80.1965332, 13.63681126], [80.19625092, 13.63680553], [80.19625092, 13.63708401], [80.19569397, 13.63708401], [80.19569397, 13.63736153], [80.19513702, 13.63735962], [80.19513702, 13.63764], [80.19486237, 13.63764], [80.19486237, 13.63792133], [80.19430542, 13.63791561], [80.19430542, 13.63819408], [80.19403076, 13.63819408], [80.19403076, 13.63875008], [80.19374847, 13.63874054], [80.19374847, 13.63931084], [80.19347382, 13.63930416], [80.19347382, 13.63958359], [80.19319153, 13.63958359], [80.19319153, 13.63986015], [80.19264984, 13.63986015], [80.19264984, 13.64013958], [80.19235992, 13.64013958], [80.19235992, 13.64042091], [80.19180298, 13.64041615], [80.19180298, 13.64097214], [80.19152832, 13.64097023], [80.19152832, 13.64124966], [80.19097137, 13.64124966], [80.19097137, 13.6418066], [80.19069672, 13.6418066], [80.19069672, 13.64208221], [80.1904068, 13.64208031], [80.1904068, 13.64235973], [80.19013977, 13.64235973], [80.19013977, 13.64264107], [80.18985748, 13.64263821], [80.18985748, 13.64319515], [80.18958282, 13.64319038], [80.18958282, 13.64375114], [80.18930817, 13.64375114], [80.18930817, 13.64403057], [80.18902588, 13.64403057], [80.18902588, 13.64431095], [80.18875122, 13.64431095], [80.18875122, 13.6448698], [80.18846893, 13.6448698], [80.18846893, 13.64681244], [80.18818665, 13.64681244], [80.18818665, 13.6479311], [80.18791962, 13.64791679], [80.18791962, 13.64819527], [80.18763733, 13.64818954], [80.18763733, 13.64931202], [80.18791962, 13.64931202], [80.18791962, 13.65152931], [80.18819427, 13.6515274], [80.18819427, 13.65375137], [80.18846893, 13.65375137], [80.18846893, 13.65458298], [80.18875122, 13.65458298], [80.18875122, 13.65569305], [80.18902588, 13.65569115], [80.18902588, 13.65653038], [80.18930817, 13.65653038], [80.18930817, 13.65792179], [80.18958282, 13.65791798], [80.18958282, 13.65819359], [80.18930817, 13.65819359], [80.18930817, 13.65847206], [80.18958282, 13.65847206], [80.18958282, 13.65958405], [80.18985748, 13.65957928], [80.18985748, 13.66014004], [80.19013977, 13.66014004], [80.19013977, 13.6623621], [80.18985748, 13.66236019], [80.18985748, 13.66263962], [80.19013977, 13.66263771], [80.19013977, 13.6631937], [80.18985748, 13.6631918], [80.18985748, 13.66431141], [80.18958282, 13.66431141], [80.18958282, 13.66486168], [80.18930817, 13.66485977], [80.18930817, 13.66597176], [80.18902588, 13.66596985], [80.18902588, 13.66681099], [80.18875122, 13.66680622], [80.18875122, 13.66736031], [80.18846893, 13.66736031], [80.18846893, 13.66764069], [80.18818665, 13.66764069], [80.18818665, 13.66792107], [80.18791962, 13.66792107], [80.18791962, 13.66874981], [80.18763733, 13.66874981], [80.18763733, 13.66903114], [80.18736267, 13.66902924], [80.18736267, 13.66958237], [80.18708038, 13.66958046], [80.18708038, 13.67014122], [80.18651581, 13.67014122], [80.18651581, 13.67042065], [80.18624878, 13.67041683], [80.18624878, 13.67097282], [80.18596649, 13.67096996], [80.18596649, 13.6712513], [80.18541718, 13.6712513], [80.18541718, 13.67153072], [80.18486023, 13.67152882], [80.18486023, 13.6720829], [80.18430328, 13.67208004], [80.18430328, 13.6726408], [80.18402863, 13.6726408], [80.18402863, 13.67292118], [80.18374634, 13.67291737], [80.18374634, 13.67347336], [80.18345642, 13.67347145], [80.18345642, 13.67375088], [80.18319702, 13.67375088], [80.18319702, 13.67431164], [80.18264008, 13.67430687], [80.18264008, 13.67458344], [80.18208313, 13.67458057], [80.18208313, 13.67486954], [80.18180847, 13.67486954], [80.18180847, 13.67514133], [80.18152618, 13.67514133], [80.18152618, 13.67542171], [80.18096924, 13.67541695], [80.18096924, 13.67569542], [80.18041992, 13.6756897], [80.18041992, 13.67625141], [80.17986298, 13.67625141], [80.17986298, 13.67653084], [80.17958069, 13.67653084], [80.17958069, 13.67681026], [80.17930603, 13.67680454], [80.17930603, 13.67708302], [80.17903137, 13.67708302], [80.17903137, 13.67791653], [80.17847443, 13.67791653], [80.17847443, 13.67847347], [80.17819214, 13.67847061], [80.17819214, 13.67875099], [80.17764282, 13.67875099], [80.17764282, 13.67902946], [80.17791748, 13.67902946], [80.17791748, 13.67931175], [80.17763519, 13.67930508], [80.17763519, 13.6795826], [80.17736053, 13.67958069], [80.17736053, 13.6801424], [80.17708588, 13.6801424], [80.17708588, 13.68042183], [80.17680359, 13.68041706], [80.17680359, 13.68069458], [80.17652893, 13.68069458], [80.17652893, 13.68097115], [80.17624664, 13.68097115], [80.17624664, 13.68125153], [80.17597198, 13.68125153], [80.17597198, 13.68153191], [80.17514038, 13.68153191], [80.17514038, 13.68181038], [80.17458344, 13.68180466], [80.17458344, 13.68208313], [80.17402649, 13.68208122], [80.17402649, 13.68236065], [80.17375183, 13.68236065], [80.17375183, 13.68319321], [80.17346954, 13.68319321], [80.17346954, 13.68347359], [80.17292023, 13.68347073], [80.17292023, 13.6837492], [80.17263794, 13.6837492], [80.17263794, 13.68486214], [80.17236328, 13.68485928], [80.17236328, 13.68542004], [80.17208099, 13.68541622], [80.17208099, 13.68597221], [80.17180634, 13.68596935], [80.17180634, 13.68624973], [80.17151642, 13.68624973], [80.17151642, 13.68735981], [80.17180634, 13.68735981], [80.17180634, 13.68791962], [80.17151642, 13.68791962], [80.17151642, 13.68847179], [80.17124939, 13.68847179], [80.17124939, 13.68875027], [80.17097473, 13.68875027], [80.17097473, 13.68958378], [80.17041779, 13.68958378], [80.17041779, 13.68986225], [80.16986084, 13.68986225], [80.16986084, 13.68958378], [80.16958618, 13.68958378], [80.16958618, 13.68930626], [80.16929626, 13.68931103], [80.16929626, 13.68819237], [80.16902924, 13.68819427], [80.16902924, 13.68735981], [80.16874695, 13.68735981], [80.16874695, 13.68680954], [80.16652679, 13.68680573], [80.16652679, 13.6870842], [80.16625214, 13.68707943], [80.16625214, 13.68764019], [80.16596985, 13.68764019], [80.16596985, 13.68819427], [80.16569519, 13.68819427], [80.16570282, 13.68875027], [80.16485596, 13.68875027], [80.16485596, 13.68902969], [80.16430664, 13.68902969], [80.16430664, 13.68931103], [80.16402435, 13.68930626], [80.16402435, 13.68958378], [80.16374969, 13.68958378], [80.16374969, 13.68986225], [80.16348267, 13.68985081], [80.16348267, 13.69014168], [80.16319275, 13.69014168], [80.16319275, 13.6904211], [80.16291809, 13.69041634], [80.16291809, 13.69069386], [80.1626358, 13.69069386], [80.1626358, 13.69097233], [80.16234589, 13.69097042], [80.16234589, 13.69153023], [80.16208649, 13.69153023], [80.16208649, 13.69181061], [80.16179657, 13.69181061], [80.16179657, 13.69431114], [80.16152954, 13.69430637], [80.16152954, 13.69458199], [80.16124725, 13.69458199], [80.16124725, 13.69486332], [80.1609726, 13.69486046], [80.1609726, 13.69514275], [80.16069794, 13.69514275], [80.16069794, 13.69542122], [80.16041565, 13.69541645], [80.16042328, 13.69569016], [80.16014099, 13.69570065], [80.16014099, 13.69625092], [80.1598587, 13.69625092], [80.1598587, 13.69681072], [80.15957642, 13.69681072], [80.15957642, 13.69736004], [80.15930939, 13.69736004], [80.1592865, 13.69764137], [80.1590271, 13.69764137], [80.1590271, 13.6979208], [80.15847015, 13.69791698], [80.15847015, 13.69819546], [80.1581955, 13.69819546], [80.1581955, 13.69847298], [80.15791321, 13.69847012], [80.15791321, 13.69904041], [80.15763855, 13.69904041], [80.15763855, 13.69931126], [80.15736389, 13.69930458], [80.15736389, 13.69986057], [80.1570816, 13.69986057], [80.1570816, 13.69995022], [80.1570816, 13.70014095], [80.15680695, 13.70014095], [80.15680695, 13.70042133], [80.15652466, 13.70041656], [80.15652466, 13.70069504], [80.15625, 13.70069504], [80.15625, 13.70097256], [80.15598297, 13.70097065], [80.15598297, 13.70125103], [80.15569305, 13.70125103], [80.15569305, 13.70153141], [80.1554184, 13.70153141], [80.1554184, 13.70181179], [80.15513611, 13.70180511], [80.15513611, 13.70208263], [80.15486145, 13.70208073], [80.15486145, 13.70264053], [80.15458679, 13.70264053], [80.15458679, 13.70292187], [80.15402985, 13.7029171], [80.15402985, 13.70319462], [80.1534729, 13.70319462], [80.1534729, 13.7029171], [80.15208435, 13.7029171], [80.15208435, 13.70319462], [80.1515274, 13.70319462], [80.1515274, 13.70263863], [80.14930725, 13.70264053], [80.14930725, 13.70292187], [80.14875031, 13.7029171], [80.14875031, 13.70319462], [80.14848328, 13.7031908], [80.14848328, 13.70375061], [80.14819336, 13.70375061], [80.14819336, 13.70403194], [80.1479187, 13.70403194], [80.1479187, 13.70431042], [80.14763641, 13.70431042], [80.14763641, 13.70403194], [80.1473465, 13.70403194], [80.1473465, 13.70375061], [80.1470871, 13.70375061], [80.1470871, 13.70264053], [80.14679718, 13.70264053], [80.14679718, 13.70208073], [80.14653015, 13.70208263], [80.14653015, 13.70152664], [80.14597321, 13.70153141], [80.14597321, 13.70125103], [80.14541626, 13.70125103], [80.14541626, 13.70097065], [80.14457703, 13.70097065], [80.14457703, 13.70125103], [80.14431, 13.70125103], [80.14431, 13.70153141], [80.14402771, 13.70152664], [80.14402771, 13.70208263], [80.14375305, 13.70208073], [80.14375305, 13.70264053], [80.14347076, 13.70263863], [80.14347076, 13.70319462], [80.14319611, 13.7031908], [80.14319611, 13.70375061], [80.14263916, 13.70375061], [80.14263916, 13.70403194], [80.14235687, 13.70403194], [80.14235687, 13.70431042], [80.14208221, 13.7043047], [80.14208221, 13.70486069], [80.14235687, 13.7048502], [80.14235687, 13.70541859], [80.14208221, 13.70541859], [80.14208221, 13.7068119], [80.14180756, 13.70680523], [80.14180756, 13.70736122], [80.14125061, 13.70736122], [80.14125061, 13.70792198], [80.14097595, 13.70791531], [80.14097595, 13.70819473], [80.14069366, 13.70819473], [80.14069366, 13.7084713], [80.14041901, 13.7084713], [80.14041901, 13.70875168], [80.14013672, 13.70874882], [80.14013672, 13.70986176], [80.13986206, 13.70985889], [80.13986206, 13.71041965], [80.14013672, 13.71041775], [80.14013672, 13.71069336], [80.14097595, 13.71069336], [80.14097595, 13.71041775], [80.14125061, 13.71041965], [80.14125061, 13.70985889], [80.14235687, 13.70985889], [80.14235687, 13.71041965], [80.14208221, 13.71041965], [80.14208221, 13.71125031], [80.14180756, 13.71125031], [80.14180756, 13.71152973], [80.14154053, 13.71152973], [80.14154053, 13.71263981], [80.14125061, 13.71263981], [80.14125061, 13.71292019], [80.14097595, 13.71291637], [80.14097595, 13.7131958], [80.14041901, 13.7131958], [80.14041901, 13.71347237], [80.13957977, 13.71347237], [80.13957977, 13.71291637], [80.13903046, 13.71291637], [80.13903046, 13.7131958], [80.13817596, 13.71319103], [80.13817596, 13.71375179], [80.13791656, 13.71374989], [80.13791656, 13.71402836], [80.13764191, 13.71402836], [80.13764191, 13.71458435], [80.13708496, 13.71458435], [80.13709259, 13.71486187], [80.13680267, 13.71486187], [80.13680267, 13.71597195], [80.13652802, 13.71597195], [80.13652802, 13.71681118], [80.13625336, 13.71680641], [80.13625336, 13.71708393], [80.13597107, 13.71708393], [80.13597107, 13.71760082], [80.13597107, 13.71875], [80.13652802, 13.71875], [80.13652802, 13.71846962], [80.13680267, 13.71847153], [80.13680267, 13.71819401], [80.13708496, 13.71819401], [80.13708496, 13.71791553], [80.13735962, 13.71792126], [80.13735962, 13.71763992], [80.13764191, 13.71763992], [80.13764191, 13.71735954], [80.13791656, 13.7173624], [80.13791656, 13.71708393], [80.13819122, 13.71708393], [80.13819122, 13.71680641], [80.13846588, 13.71681118], [80.13846588, 13.71652985], [80.13874817, 13.71652985], [80.13874817, 13.71625042], [80.13903046, 13.71625042], [80.13903046, 13.71569157], [80.13930511, 13.71569443], [80.13930511, 13.71513844], [80.13957977, 13.71514034], [80.13957977, 13.71458244], [80.13986206, 13.71458435], [80.13986206, 13.71430588], [80.14041901, 13.71430969], [80.14041901, 13.71542263], [80.14013672, 13.71541595], [80.14013672, 13.71708393], [80.14041901, 13.71708393], [80.14041901, 13.71819401], [80.14068604, 13.71818924], [80.14068604, 13.71875], [80.14235687, 13.71875], [80.14235687, 13.71846962], [80.14402771, 13.71846962], [80.14402771, 13.71875], [80.14431, 13.71875], [80.14431, 13.71903038], [80.14457703, 13.71903038], [80.14457703, 13.71931076], [80.1451416, 13.71930599], [80.1451416, 13.71958447], [80.14541626, 13.7195797], [80.14541626, 13.71986008], [80.14569092, 13.71986008], [80.14569092, 13.7201519], [80.14597321, 13.7201519], [80.14597321, 13.72042084], [80.14653015, 13.72041607], [80.14653015, 13.72069359], [80.1470871, 13.72069359], [80.1470871, 13.72097206], [80.14679718, 13.72097015], [80.14679718, 13.72153091], [80.14653015, 13.72152805], [80.14653015, 13.72208214], [80.14624786, 13.72208023], [80.14624786, 13.72235966], [80.14653015, 13.72235966], [80.14653015, 13.72292137], [80.14680481, 13.72291565], [80.14680481, 13.7234726], [80.1470871, 13.72346973], [80.1470871, 13.72431087], [80.14541626, 13.72431087], [80.14541626, 13.72403145], [80.14402771, 13.72403145], [80.14402771, 13.72375107], [80.14229584, 13.72375107], [80.14208221, 13.72375107], [80.14208221, 13.72346973], [80.14180756, 13.7234726], [80.14180756, 13.72319412], [80.14125061, 13.72319412], [80.14125061, 13.72291565], [80.14069366, 13.72291565], [80.14069366, 13.7234726], [80.14041901, 13.72346973], [80.14041901, 13.72403145], [80.14013672, 13.72403145], [80.14013672, 13.72431087], [80.14097595, 13.7243042], [80.14097595, 13.72458458], [80.14154053, 13.7245779], [80.14154053, 13.72514057], [80.14097595, 13.72514057], [80.14097595, 13.72542095], [80.13957977, 13.72541714], [80.13957977, 13.72597313], [80.13931274, 13.72596073], [80.13931274, 13.72625065], [80.13874817, 13.72625065], [80.13874817, 13.72596073], [80.13819122, 13.72597313], [80.13819122, 13.72569466], [80.13735962, 13.72569466], [80.13735962, 13.72597313], [80.13652802, 13.72596073], [80.13652802, 13.72625065], [80.13458252, 13.72625065], [80.13458252, 13.72596073], [80.13291931, 13.72597313], [80.13291931, 13.72569466], [80.13240051, 13.72569466], [80.13153076, 13.72569466], [80.13153076, 13.72458458], [80.13124847, 13.72458458], [80.13124847, 13.72375107], [80.12985992, 13.72375107], [80.12985992, 13.72235966], [80.13014221, 13.72235966], [80.13014221, 13.72208023], [80.13041687, 13.72208214], [80.13041687, 13.72180557], [80.13053894, 13.72180557], [80.13069153, 13.72181129], [80.13069153, 13.71706104], [80.13069153, 13.71347237], [80.13097382, 13.71347237], [80.13097382, 13.71291637], [80.13124847, 13.71292019], [80.13124847, 13.71263981], [80.13153076, 13.71263981], [80.13153076, 13.71208096], [80.13263702, 13.71208382], [80.13263702, 13.7118063], [80.13318634, 13.71181011], [80.13318634, 13.71152973], [80.13569641, 13.71152782], [80.13569641, 13.7131958], [80.13597107, 13.7131958], [80.13597107, 13.71347237], [80.13625336, 13.71346855], [80.13625336, 13.71375179], [80.13652802, 13.71375179], [80.13652802, 13.71319103], [80.13680267, 13.7131958], [80.13680267, 13.71291637], [80.13709259, 13.71292019], [80.13709259, 13.71263981], [80.13735962, 13.71263981], [80.13735962, 13.71208096], [80.13764191, 13.71208382], [80.13764191, 13.71152782], [80.13791656, 13.71152973], [80.13791656, 13.71041965], [80.13817596, 13.71041965], [80.13817596, 13.70875168], [80.13846588, 13.70875168], [80.13846588, 13.70792198], [80.13817596, 13.70792198], [80.13817596, 13.7068119], [80.13846588, 13.7068119], [80.13846588, 13.70624924], [80.13874817, 13.70624924], [80.13874817, 13.70597076], [80.13930511, 13.70597076], [80.13930511, 13.70569515], [80.13957977, 13.70569515], [80.13957977, 13.70458317], [80.13986206, 13.70458317], [80.13986206, 13.70236111], [80.14013672, 13.70236111], [80.14013672, 13.70069504], [80.14041901, 13.70069504], [80.14041901, 13.70041656], [80.14125061, 13.70041656], [80.14125061, 13.70097256], [80.14154053, 13.70097065], [80.14154053, 13.70153141], [80.14180756, 13.70152664], [80.14180756, 13.70208263], [80.14291382, 13.70208263], [80.14291382, 13.69902897], [80.14263916, 13.69904041], [80.14263916, 13.69875145], [80.14235687, 13.69875145], [80.14235687, 13.69847012], [80.14208221, 13.69847298], [80.14208221, 13.69791698], [80.14180756, 13.6979208], [80.14180756, 13.69570065], [80.14154053, 13.69569016], [80.14152527, 13.6940279], [80.14125061, 13.69403076], [80.14125061, 13.69318962], [80.14097595, 13.69319439], [80.14097595, 13.6926403], [80.14068604, 13.6926403], [80.14068604, 13.69207954], [80.14041901, 13.69208431], [80.14041901, 13.69180584], [80.14013672, 13.69181061], [80.14013672, 13.69124985], [80.13986206, 13.69124985], [80.13986206, 13.69069195], [80.14013672, 13.69069386], [80.14013672, 13.69041634], [80.14041901, 13.6904211], [80.14041901, 13.68985081], [80.14069366, 13.68986225], [80.14069366, 13.68902779], [80.14125061, 13.68902969], [80.14125061, 13.68819237], [80.14097595, 13.68819427], [80.14097595, 13.68764019], [80.14125061, 13.68764019], [80.14125061, 13.68624973], [80.14154053, 13.68624973], [80.14154053, 13.68430996], [80.14180756, 13.68430996], [80.14180756, 13.68292046], [80.14208221, 13.68292046], [80.14208221, 13.68258858], [80.14208221, 13.68180466], [80.14235687, 13.68181038], [80.14235687, 13.68042183], [80.14263916, 13.68042183], [80.14263916, 13.6712513], [80.14290619, 13.6712513], [80.14290619, 13.66931057], [80.14347076, 13.66931057], [80.14347076, 13.66819191], [80.14375305, 13.66819382], [80.14375305, 13.66625023], [80.14402771, 13.66625023], [80.14402771, 13.66514015], [80.14431, 13.66514015], [80.14431, 13.66486168], [80.14457703, 13.66486168], [80.14457703, 13.66458035], [80.14485931, 13.66458416], [80.14485931, 13.66430569], [80.1451416, 13.66431141], [80.1451416, 13.66403008], [80.14541626, 13.66403008], [80.14541626, 13.66374969], [80.14569092, 13.66374969], [80.14569092, 13.6631918], [80.14597321, 13.6631937], [80.14597321, 13.66291809], [80.14624786, 13.66292953], [80.14624786, 13.66263962], [80.14653015, 13.66263962], [80.14653015, 13.66236019], [80.14680481, 13.6623621], [80.14680481, 13.66180611], [80.1470871, 13.66181087], [80.1470871, 13.66068935], [80.14736176, 13.66069412], [80.14736176, 13.65958405], [80.14763641, 13.65958405], [80.14763641, 13.65819359], [80.14736176, 13.65819359], [80.14736176, 13.65597057], [80.1470871, 13.65597057], [80.1470871, 13.65458298], [80.14680481, 13.65458298], [80.14680481, 13.65375137], [80.14653015, 13.65375137], [80.14653015, 13.65291691], [80.14624786, 13.65291977], [80.14624786, 13.65236092], [80.14597321, 13.65236092], [80.14597321, 13.65152931], [80.14569092, 13.65152931], [80.14569092, 13.65068054], [80.14597321, 13.65069485], [80.14597321, 13.64986134], [80.14624786, 13.64986134], [80.14624786, 13.64902687], [80.14653015, 13.64903069], [80.14653015, 13.64847088], [80.14680481, 13.64847088], [80.14680481, 13.6473608], [80.1470871, 13.6473608], [80.1470871, 13.64625072], [80.14679718, 13.64625072], [80.14679718, 13.6459713], [80.14653015, 13.64597321], [80.14653015, 13.64569473], [80.14597321, 13.64569473], [80.14597321, 13.64541721], [80.14569092, 13.64542103], [80.14569092, 13.64514065], [80.14541626, 13.64514065], [80.14541626, 13.6448698], [80.1451416, 13.6448698], [80.1451416, 13.64458275], [80.14402771, 13.64458466], [80.14402771, 13.64069366], [80.14375305, 13.64069366], [80.14375305, 13.63986015], [80.14402771, 13.63986015], [80.14402771, 13.63958359], [80.14375305, 13.63958359], [80.14375305, 13.63763809], [80.14319611, 13.63764], [80.14319611, 13.63514042], [80.14375305, 13.63514042], [80.14375305, 13.63486195], [80.14431, 13.63486195], [80.14430237, 13.63347244], [80.14402771, 13.63347244], [80.14402771, 13.63319397], [80.14430237, 13.63319397], [80.14430237, 13.63291645], [80.14457703, 13.63293171], [80.14457703, 13.63208103], [80.14485931, 13.63208389], [80.14485931, 13.62986183], [80.14457703, 13.62986183], [80.14457703, 13.62903023], [80.14431, 13.62903023], [80.14431, 13.62764168], [80.14402771, 13.62764168], [80.14402771, 13.62708092], [80.14375305, 13.62708282], [80.14375305, 13.62652683], [80.14347076, 13.6265316], [80.14347076, 13.62513924], [80.14319611, 13.62513924], [80.14319611, 13.62403202], [80.14290619, 13.62403202], [80.14290619, 13.62319088], [80.14263916, 13.62319469], [80.14263916, 13.62291718], [80.14235687, 13.62292194], [80.14235687, 13.62236118], [80.14208221, 13.62236118], [80.14208221, 13.62208271], [80.14180756, 13.62208271], [80.14180756, 13.62180519], [80.14154053, 13.62181187], [80.14154053, 13.62125111], [80.14125061, 13.62125111], [80.14125061, 13.62097073], [80.14097595, 13.62097263], [80.14097595, 13.61902905], [80.14068604, 13.61903095], [80.14068604, 13.61875057], [80.14041901, 13.61875057], [80.14041901, 13.6181879], [80.14013672, 13.61819458], [80.14013672, 13.61763859], [80.13986206, 13.61763859], [80.13986206, 13.61652946], [80.13957977, 13.61653137], [80.13957977, 13.61569023], [80.13930511, 13.61569405], [80.13930511, 13.6148634], [80.13903046, 13.6148634], [80.13903046, 13.61430645], [80.13874817, 13.61431122], [80.13874817, 13.61347008], [80.13847351, 13.61347198], [80.13847351, 13.61291599], [80.13817596, 13.61292076], [80.13817596, 13.61264038], [80.13791656, 13.61264038], [80.13791656, 13.61236], [80.13764191, 13.61236], [80.13764191, 13.61207962], [80.13708496, 13.61208439], [80.13708496, 13.61180592], [80.13680267, 13.61182022], [80.13680267, 13.61153126], [80.13652802, 13.61153126], [80.13652802, 13.61124992], [80.13625336, 13.61124992], [80.13625336, 13.61098099], [80.13513947, 13.61096954], [80.13513947, 13.61069393], [80.13402557, 13.61069393], [80.13402557, 13.61041641], [80.13291931, 13.61042118], [80.13291931, 13.61013985], [80.13069153, 13.61013985], [80.13069153, 13.61042118], [80.13014221, 13.61041641], [80.13014221, 13.61069393], [80.12985992, 13.61069393], [80.12985992, 13.6109724], [80.12930298, 13.6109724], [80.12930298, 13.61069393], [80.12763977, 13.61069393], [80.12763977, 13.6109724], [80.12708282, 13.61096954], [80.12708282, 13.61124992], [80.12680817, 13.61124992], [80.12680817, 13.61153126], [80.1264801, 13.6115284], [80.12623596, 13.61153126], [80.12623596, 13.61182022], [80.12596893, 13.61182022], [80.12596893, 13.61236], [80.12568665, 13.61236], [80.12568665, 13.61292076], [80.12541962, 13.61291599], [80.12541962, 13.61347198], [80.12513733, 13.61347008], [80.12513733, 13.61375046], [80.12431335, 13.61375046], [80.12431335, 13.61403084], [80.12403107, 13.61403084], [80.12403107, 13.61431122], [80.12374878, 13.61430645], [80.12374878, 13.61458206], [80.12347412, 13.61458206], [80.12347412, 13.6148634], [80.12317657, 13.61485958], [80.12317657, 13.6154213], [80.12291718, 13.61541557], [80.12291718, 13.61597347], [80.12264252, 13.61596966], [80.12264252, 13.61653137], [80.12236023, 13.61653137], [80.12236023, 13.6168108], [80.12208557, 13.61680698], [80.12208557, 13.61708164], [80.12180328, 13.61708164], [80.12180328, 13.61763859], [80.12152863, 13.61763191], [80.12152863, 13.61792088], [80.12124634, 13.61791706], [80.12124634, 13.61819458], [80.12097168, 13.6181879], [80.12097168, 13.61875057], [80.12069702, 13.61875057], [80.12069702, 13.61903095], [80.1204071, 13.61903095], [80.1204071, 13.61931133], [80.12014008, 13.61931133], [80.12014008, 13.61986065], [80.11985779, 13.61986065], [80.11985779, 13.62014103], [80.11958313, 13.62014103], [80.11958313, 13.62042141], [80.11902618, 13.62042141], [80.11902618, 13.62070179], [80.11875153, 13.62069511], [80.11875153, 13.62097263], [80.11846924, 13.62097263], [80.11846924, 13.62208271], [80.11875153, 13.6220808], [80.11875153, 13.62264061], [80.11902618, 13.62264061], [80.11902618, 13.62292194], [80.11930847, 13.62292194], [80.11930847, 13.62403202], [80.11958313, 13.62403202], [80.11958313, 13.62541962], [80.11930847, 13.62541962], [80.11930847, 13.6265316], [80.11902618, 13.62652683], [80.11902618, 13.62708282], [80.11875153, 13.62708092], [80.11875153, 13.62792015], [80.11846924, 13.62791538], [80.11846924, 13.62819576], [80.11875153, 13.62819576], [80.11875153, 13.62847137], [80.11846924, 13.62847137], [80.11846924, 13.62874889], [80.11818695, 13.62874889], [80.11818695, 13.62930965], [80.11791992, 13.62930489], [80.11791992, 13.62958431], [80.11763763, 13.62957001], [80.11763763, 13.6301403], [80.11737061, 13.6301403], [80.11737061, 13.63041973], [80.11708069, 13.63041782], [80.11708069, 13.63097191], [80.11680603, 13.63097191], [80.11680603, 13.63125038], [80.11653137, 13.63125038], [80.11653137, 13.63152981], [80.1159668, 13.63152981], [80.1159668, 13.63181019], [80.11569214, 13.63180637], [80.11569214, 13.63208389], [80.11541748, 13.63208389], [80.11541748, 13.63236237], [80.11486053, 13.63236046], [80.11486053, 13.63264179], [80.11458588, 13.63264179], [80.11458588, 13.63293171], [80.11430359, 13.63291645], [80.11429596, 13.6331892], [80.11374664, 13.63319588], [80.11374664, 13.63347244], [80.11347198, 13.63347244], [80.11345673, 13.63375854], [80.1134491, 13.63403034], [80.11319733, 13.63403034], [80.11319733, 13.63431263], [80.11291504, 13.63430595], [80.11291504, 13.63458443], [80.11264038, 13.63458157], [80.11264038, 13.63514042], [80.11235809, 13.63514042], [80.11235809, 13.63541985], [80.11207581, 13.63541985], [80.11207581, 13.63570118], [80.11180878, 13.63570118], [80.11180878, 13.63652992], [80.11152649, 13.63652802], [80.11152649, 13.63708401], [80.11123657, 13.63708019], [80.11123657, 13.63764], [80.11096954, 13.63763809], [80.11096954, 13.63875008], [80.11068726, 13.63874054], [80.11068726, 13.63931084], [80.11042023, 13.63930416], [80.11042023, 13.63958359], [80.11013794, 13.63958359], [80.11013794, 13.63986015], [80.10986328, 13.63986015], [80.10986328, 13.64042091], [80.10958099, 13.64041615], [80.10958099, 13.64097214], [80.10930634, 13.64097214], [80.10930634, 13.6418066], [80.10902405, 13.6418066], [80.10902405, 13.64208221], [80.10874939, 13.64208031], [80.10874939, 13.64542103], [80.10902405, 13.64541721], [80.10902405, 13.64597321], [80.10930634, 13.6459713], [80.10930634, 13.64681244], [80.10902405, 13.64680481], [80.10902405, 13.64819527], [80.10930634, 13.64818954], [80.10930634, 13.64875126], [80.10902405, 13.64875126], [80.10902405, 13.64986134], [80.10874939, 13.64986134], [80.10874939, 13.65097332], [80.10847473, 13.65097332], [80.10847473, 13.6520834], [80.10819244, 13.6520834], [80.10819244, 13.65319538], [80.10791779, 13.65319061], [80.10791779, 13.65431023], [80.10820007, 13.65431023], [80.10820007, 13.6554203], [80.1084671, 13.6554203], [80.1084671, 13.65653038], [80.10874939, 13.65652657], [80.10874939, 13.65683079], [80.10874939, 13.65736198], [80.10901642, 13.65736198], [80.10901642, 13.65764046], [80.10958099, 13.65764046], [80.10958099, 13.65792179], [80.10986328, 13.65791798], [80.10986328, 13.65819359], [80.11235809, 13.65819359], [80.11235809, 13.65791798], [80.11402893, 13.65792179], [80.11402893, 13.65764046], [80.11624908, 13.65764046], [80.11624908, 13.65874958], [80.11818695, 13.65874958], [80.11818695, 13.65569115], [80.11791992, 13.65569305], [80.11791992, 13.6554184], [80.11763763, 13.6554203], [80.11763763, 13.65514183], [80.11737061, 13.65514183], [80.11737061, 13.65486145], [80.11708069, 13.65486145], [80.11708069, 13.65625191], [80.11541748, 13.65625191], [80.11541748, 13.65597057], [80.11513519, 13.65597057], [80.11513519, 13.65585136], [80.11513519, 13.6554184], [80.11486053, 13.6554203], [80.11486053, 13.65514183], [80.11514282, 13.65514183], [80.11514282, 13.65458107], [80.11541748, 13.65458298], [80.11541748, 13.65430546], [80.11569214, 13.65431023], [80.11569214, 13.65403175], [80.1159668, 13.65403175], [80.1159668, 13.65347099], [80.11624908, 13.65347099], [80.11624908, 13.65319538], [80.11736298, 13.65319538], [80.11736298, 13.65375137], [80.11791992, 13.65375137], [80.11791992, 13.65347099], [80.11819458, 13.65347099], [80.11819458, 13.65291691], [80.11839294, 13.65291977], [80.11846924, 13.65291691], [80.11846924, 13.65263939], [80.11875153, 13.65263939], [80.11875153, 13.65208054], [80.11902618, 13.6520834], [80.11902618, 13.6515274], [80.11930847, 13.65152931], [80.11930847, 13.65125084], [80.11958313, 13.65125084], [80.11958313, 13.65068054], [80.11985779, 13.65069485], [80.11985779, 13.65013885], [80.11958313, 13.65014076], [80.11958313, 13.64931202], [80.11930847, 13.64931202], [80.11930847, 13.64875126], [80.11902618, 13.64875126], [80.11902618, 13.64818954], [80.11875153, 13.64819527], [80.11875153, 13.64791679], [80.11818695, 13.6479311], [80.11818695, 13.64764118], [80.11791992, 13.64764118], [80.11791992, 13.6473608], [80.11763763, 13.6473608], [80.11763763, 13.64708328], [80.11736298, 13.64708328], [80.11736298, 13.64680481], [80.11680603, 13.64681244], [80.11680603, 13.64653111], [80.11653137, 13.64653111], [80.11653137, 13.64625072], [80.11624908, 13.64625072], [80.11624908, 13.6459713], [80.11582184, 13.64597321], [80.11569214, 13.64597321], [80.11569214, 13.64569473], [80.11541748, 13.64569473], [80.11541748, 13.64541721], [80.11514282, 13.64542103], [80.11514282, 13.64514065], [80.11486053, 13.64514065], [80.11486053, 13.6448698], [80.11429596, 13.6448698], [80.11429596, 13.64458275], [80.11402893, 13.64458466], [80.11402893, 13.64430428], [80.11374664, 13.64431095], [80.11374664, 13.64403057], [80.11347198, 13.64403057], [80.11347198, 13.64375114], [80.11319733, 13.64375114], [80.11319733, 13.6434679], [80.11291504, 13.64347267], [80.11291504, 13.64319515], [80.11264038, 13.64319515], [80.11264038, 13.64291573], [80.11180878, 13.64292145], [80.11180878, 13.64208031], [80.11235809, 13.64208221], [80.11235809, 13.6418066], [80.11374664, 13.6418066], [80.11374664, 13.64208221], [80.11402893, 13.64208031], [80.11402893, 13.64264107], [80.11429596, 13.64264107], [80.11429596, 13.64292145], [80.11486053, 13.64291573], [80.11486053, 13.64319515], [80.11522675, 13.64319515], [80.11541748, 13.64319515], [80.11541748, 13.64347267], [80.1159668, 13.6434679], [80.1159668, 13.64375114], [80.11653137, 13.64375114], [80.11653137, 13.64403057], [80.11708069, 13.64403057], [80.11708069, 13.64431095], [80.11791992, 13.64430428], [80.11791992, 13.64458466], [80.11846924, 13.64458275], [80.11846924, 13.6448698], [80.11902618, 13.6448698], [80.11902618, 13.64514065], [80.11958313, 13.64514065], [80.11958313, 13.64542103], [80.12014008, 13.64541721], [80.12014008, 13.64569473], [80.12069702, 13.64569473], [80.12069702, 13.64597321], [80.1204071, 13.6459713], [80.1204071, 13.64625072], [80.12014008, 13.64625072], [80.12014008, 13.64847088], [80.1204071, 13.64847088], [80.1204071, 13.64903069], [80.12069702, 13.64902687], [80.12069702, 13.64986134], [80.12097168, 13.64986134], [80.12097168, 13.65069485], [80.12124634, 13.65068054], [80.12124634, 13.65125084], [80.12152863, 13.65125084], [80.12152863, 13.65180969], [80.12180328, 13.65180969], [80.12180328, 13.65291977], [80.12152863, 13.65291691], [80.12152863, 13.65458298], [80.12124634, 13.65458298], [80.12124634, 13.65475178], [80.12124634, 13.6554203], [80.12014008, 13.6554184], [80.12014008, 13.65597057], [80.11985779, 13.65597057], [80.11985779, 13.65653038], [80.12014008, 13.65653038], [80.12014008, 13.65736198], [80.1204071, 13.65736198], [80.1204071, 13.66042042], [80.12014008, 13.66041565], [80.12014008, 13.66097164], [80.11985779, 13.66097164], [80.11985779, 13.66181087], [80.11958313, 13.66180611], [80.11958313, 13.6631937], [80.11985779, 13.6631918], [80.11985779, 13.66374969], [80.12014008, 13.66374969], [80.12014008, 13.66403008], [80.12152863, 13.66403008], [80.12152863, 13.66431141], [80.1220932, 13.66431141], [80.1220932, 13.66486168], [80.12236023, 13.66486168], [80.12236023, 13.66542053], [80.12264252, 13.66541576], [80.12264252, 13.66597176], [80.12291718, 13.66596985], [80.12291718, 13.66653061], [80.12317657, 13.66653061], [80.12317657, 13.66681099], [80.12347412, 13.66680622], [80.12347412, 13.66736031], [80.12374878, 13.66736031], [80.12374878, 13.66792107], [80.12403107, 13.6679163], [80.12403107, 13.66847229], [80.12431335, 13.66847038], [80.12431335, 13.66903114], [80.12458038, 13.66902637], [80.12458038, 13.66958237], [80.12486267, 13.66958046], [80.12486267, 13.66986275], [80.12541962, 13.66986275], [80.12541962, 13.66958046], [80.12596893, 13.66958046], [80.12596893, 13.67042065], [80.12568665, 13.67042065], [80.12568665, 13.6712513], [80.12541962, 13.6712513], [80.12541962, 13.67236137], [80.12513733, 13.67236137], [80.12513733, 13.67319489], [80.12486267, 13.67319489], [80.12486267, 13.67572021], [80.12486267, 13.67681026], [80.12458038, 13.67680454], [80.12458038, 13.67708302], [80.12431335, 13.67708111], [80.12431335, 13.67764091], [80.12403107, 13.67763901], [80.12403107, 13.67791653], [80.12236023, 13.67791653], [80.12236023, 13.67819309], [80.12041473, 13.67819309], [80.12041473, 13.67708302], [80.12069702, 13.67708302], [80.12069702, 13.67652702], [80.12097168, 13.67653084], [80.12097168, 13.67597103], [80.12124634, 13.67597294], [80.12124634, 13.67541695], [80.12152863, 13.67542171], [80.12152863, 13.67486954], [80.12180328, 13.67486954], [80.12180328, 13.67403126], [80.12152863, 13.67403126], [80.12152863, 13.6726408], [80.12124634, 13.6726408], [80.12124634, 13.67153072], [80.12097168, 13.67153072], [80.12097168, 13.67068958], [80.11958313, 13.6706953], [80.11958313, 13.67097282], [80.11875153, 13.67096996], [80.11875153, 13.6712513], [80.11791992, 13.6712513], [80.11791992, 13.67153072], [80.11763763, 13.67153072], [80.11763763, 13.6718092], [80.11736298, 13.67180538], [80.11736298, 13.6720829], [80.11680603, 13.6720829], [80.11680603, 13.67236137], [80.11653137, 13.67236137], [80.11653137, 13.6726408], [80.11624908, 13.6726408], [80.11624908, 13.67292118], [80.11597443, 13.67291737], [80.11597443, 13.67319489], [80.11569214, 13.67319012], [80.11569214, 13.67375088], [80.11541748, 13.67375088], [80.11541748, 13.67431164], [80.11514282, 13.67431164], [80.11514282, 13.67486954], [80.11486053, 13.67486954], [80.11486053, 13.67542171], [80.11458588, 13.67541695], [80.11458588, 13.67597294], [80.11347198, 13.67597294], [80.11347198, 13.67541695], [80.11319733, 13.67542171], [80.11319733, 13.67458057], [80.11291504, 13.67458344], [80.11291504, 13.67402744], [80.11264038, 13.67403126], [80.11264038, 13.67347145], [80.11235809, 13.67347336], [80.11235809, 13.67319489], [80.11208344, 13.67319489], [80.11208344, 13.67263889], [80.11180878, 13.6726408], [80.11180878, 13.67236137], [80.11152649, 13.67236137], [80.11152649, 13.67180538], [80.11123657, 13.6718092], [80.11123657, 13.67153072], [80.10901642, 13.67153072], [80.10901642, 13.6712513], [80.1084671, 13.6712513], [80.1084671, 13.6726408], [80.10819244, 13.67263889], [80.10819244, 13.67347336], [80.10764313, 13.67347145], [80.10764313, 13.67375088], [80.10736084, 13.67375088], [80.10736084, 13.67403126], [80.10679626, 13.67403126], [80.10679626, 13.67431164], [80.10736084, 13.67430687], [80.10736084, 13.67458344], [80.1076355, 13.67458344], [80.1076355, 13.67736053], [80.10736084, 13.67736053], [80.10736084, 13.67847347], [80.10764313, 13.67847061], [80.10764313, 13.67875099], [80.10791779, 13.67875099], [80.10791779, 13.67931175], [80.10819244, 13.67930508], [80.10819244, 13.67986107], [80.10847473, 13.67986107], [80.10847473, 13.68069458], [80.10820007, 13.68069077], [80.10820007, 13.68125153], [80.10791779, 13.68125153], [80.10791779, 13.68153191], [80.1076355, 13.68152714], [80.1076355, 13.68208313], [80.10736084, 13.68208122], [80.10736084, 13.68264198], [80.10708618, 13.68264008], [80.10708618, 13.68319321], [80.10680389, 13.68319321], [80.10680389, 13.68347359], [80.10652924, 13.68347073], [80.10652924, 13.6837492], [80.10624695, 13.6837492], [80.10624695, 13.68404102], [80.10652924, 13.68404102], [80.10652924, 13.68430996], [80.10847473, 13.68430614], [80.10847473, 13.68458366], [80.10874939, 13.6845789], [80.10874939, 13.68513966], [80.10902405, 13.68513966], [80.10902405, 13.68569374], [80.10874939, 13.68569088], [80.10874939, 13.68624973], [80.1084671, 13.68624973], [80.1084671, 13.68680954], [80.10819244, 13.68680573], [80.10819244, 13.68847179], [80.10847473, 13.68847179], [80.10847473, 13.68986225], [80.10874939, 13.68985081], [80.10874939, 13.69014168], [80.10901642, 13.69014168], [80.10901642, 13.6904211], [80.10930634, 13.69041634], [80.10930634, 13.69069386], [80.10958099, 13.69069386], [80.10958099, 13.69097233], [80.10986328, 13.69097042], [80.10986328, 13.69124985], [80.11013794, 13.69124985], [80.11013794, 13.69153023], [80.11068726, 13.69153023], [80.11068726, 13.69181061], [80.11096954, 13.69180584], [80.11096954, 13.69208431], [80.11123657, 13.69207954], [80.11123657, 13.6926403], [80.11152649, 13.6926403], [80.11152649, 13.69375038], [80.11125183, 13.69375038], [80.11125183, 13.69458199], [80.11096954, 13.69458199], [80.11096954, 13.69486332], [80.11068726, 13.69486046], [80.11068726, 13.69542122], [80.11042023, 13.69541645], [80.11042023, 13.69569016], [80.11013794, 13.69570065], [80.11013794, 13.69598198], [80.10986328, 13.69598198], [80.10986328, 13.69625092], [80.10958099, 13.69625092], [80.10958099, 13.69681072], [80.10930634, 13.69680691], [80.10930634, 13.69708157], [80.10901642, 13.69707966], [80.10901642, 13.69736004], [80.10874939, 13.69736004], [80.10874939, 13.6979208], [80.10847473, 13.69791698], [80.10847473, 13.69847298], [80.10820007, 13.69847012], [80.10820007, 13.69904041], [80.10791779, 13.69904041], [80.10791779, 13.69931126], [80.1076355, 13.69930458], [80.1076355, 13.69958305], [80.10736084, 13.69958305], [80.10736084, 13.69986057], [80.10708618, 13.69986057], [80.10708618, 13.70014095], [80.10680389, 13.70013905], [80.10680389, 13.70069504], [80.10708618, 13.70069027], [80.10708618, 13.70181179], [80.10736084, 13.70181179], [80.10736084, 13.70292187], [80.10764313, 13.70292187], [80.10764313, 13.70375061], [80.10791779, 13.7037487], [80.10791779, 13.70388126], [80.10791779, 13.70624924], [80.10820007, 13.70624924], [80.10820007, 13.7068119], [80.10847473, 13.70680523], [80.10847473, 13.70708275], [80.10902405, 13.70708275], [80.10902405, 13.70736122], [80.10930634, 13.70736122], [80.10930634, 13.70792198], [80.10902405, 13.70791531], [80.10902405, 13.7084713], [80.10874939, 13.7084713], [80.10874939, 13.70875168], [80.1084671, 13.70875168], [80.1084671, 13.70903015], [80.10820007, 13.70903015], [80.10820007, 13.70930958], [80.10679626, 13.70930958], [80.10679626, 13.70903015], [80.10652924, 13.70903015], [80.10652924, 13.7084713], [80.10624695, 13.7084713], [80.10624695, 13.70791531], [80.10597229, 13.70792198], [80.10597229, 13.7076416], [80.10514069, 13.7076416], [80.10514069, 13.70736122], [80.10430908, 13.70736122], [80.10430908, 13.70708275], [80.10458374, 13.70708275], [80.10458374, 13.70652676], [80.1048584, 13.70652866], [80.1048584, 13.70347118], [80.10458374, 13.70347309], [80.10458374, 13.70319462], [80.10430908, 13.70319462], [80.10430908, 13.7029171], [80.10402679, 13.70292187], [80.10402679, 13.70236111], [80.10375214, 13.70236111], [80.10375214, 13.70208263], [80.10346985, 13.70208263], [80.10346985, 13.70180511], [80.1029129, 13.70180511], [80.1029129, 13.70208263], [80.10180664, 13.70208263], [80.10180664, 13.70236111], [80.10069275, 13.70236111], [80.10069275, 13.70208263], [80.10041809, 13.70208263], [80.10041809, 13.69902897], [80.10069275, 13.69904041], [80.10069275, 13.69847012], [80.10097504, 13.69847298], [80.10097504, 13.69819546], [80.10124969, 13.69819546], [80.10124969, 13.69763947], [80.10151672, 13.69764137], [80.10151672, 13.69707966], [80.10180664, 13.69708157], [80.10180664, 13.69680691], [80.1020813, 13.69681072], [80.1020813, 13.69625092], [80.10235596, 13.69625092], [80.10235596, 13.69598198], [80.10260773, 13.69598198], [80.10263824, 13.69542122], [80.1029129, 13.69542122], [80.1029129, 13.69514275], [80.10597229, 13.69514275], [80.10597229, 13.69486046], [80.10652924, 13.69486332], [80.10652924, 13.69458199], [80.10680389, 13.69458199], [80.10680389, 13.69430637], [80.10736084, 13.69431114], [80.10736084, 13.6930418], [80.10736084, 13.69291592], [80.1076355, 13.69291592], [80.1076355, 13.69152832], [80.10736084, 13.69153023], [80.10736084, 13.69124985], [80.10679626, 13.69124985], [80.10679626, 13.69097042], [80.10652924, 13.69097233], [80.10652924, 13.69069386], [80.10624695, 13.69069386], [80.10624695, 13.69041634], [80.10569763, 13.6904211], [80.10569763, 13.69014168], [80.1054306, 13.69014168], [80.1054306, 13.68958187], [80.10514069, 13.68958378], [80.10514069, 13.68902779], [80.1048584, 13.68902969], [80.1048584, 13.68847179], [80.10457611, 13.68847179], [80.10457611, 13.68791962], [80.10430908, 13.68791962], [80.10430908, 13.68764019], [80.10375214, 13.68764019], [80.10375214, 13.68735981], [80.10319519, 13.68735981], [80.10319519, 13.6870842], [80.10263824, 13.6870842], [80.10263824, 13.68680573], [80.10180664, 13.68680573], [80.10180664, 13.6870842], [80.10097504, 13.6870842], [80.10097504, 13.6790266], [80.10124969, 13.67902946], [80.10124969, 13.67875099], [80.10098267, 13.67875099], [80.10098267, 13.67847061], [80.10069275, 13.67847347], [80.10069275, 13.67791653], [80.10097504, 13.67791653], [80.10097504, 13.67680454], [80.10124969, 13.67681026], [80.10124969, 13.67597103], [80.10152435, 13.67597294], [80.10152435, 13.67486095], [80.10180664, 13.67486954], [80.10180664, 13.67375088], [80.1020813, 13.67375088], [80.1020813, 13.6726408], [80.10235596, 13.6726408], [80.10235596, 13.66736031], [80.10263824, 13.66736031], [80.10263824, 13.66708374], [80.10346985, 13.66708374], [80.10346985, 13.66541576], [80.10375214, 13.66542053], [80.10375214, 13.66263962], [80.10402679, 13.66263962], [80.10402679, 13.66152954], [80.10430908, 13.66152954], [80.10430908, 13.66042042], [80.10457611, 13.66042042], [80.10457611, 13.65902996], [80.10430908, 13.65902996], [80.10430908, 13.65764046], [80.10402679, 13.65764046], [80.10402679, 13.65653038], [80.10375214, 13.65653038], [80.10375214, 13.65618992], [80.10375214, 13.65513897], [80.10346985, 13.65514183], [80.10346985, 13.65431023], [80.10320282, 13.65431023], [80.10320282, 13.65403175], [80.1029129, 13.65403175], [80.1029129, 13.65373993], [80.10263824, 13.65375137], [80.10263824, 13.65347099], [80.1020813, 13.65347099], [80.1020813, 13.65319538], [80.10180664, 13.65319538], [80.10180664, 13.65291691], [80.10151672, 13.65291977], [80.10151672, 13.65263939], [80.09764099, 13.65263939], [80.09764099, 13.65319538], [80.0973587, 13.65319538], [80.0973587, 13.65375137], [80.09707642, 13.65373993], [80.09707642, 13.65431023], [80.0973587, 13.65430546], [80.0973587, 13.65492058], [80.0973587, 13.6554203], [80.09764099, 13.6554203], [80.09764099, 13.65653038], [80.09792328, 13.65653038], [80.09792328, 13.65764046], [80.09819794, 13.65763664], [80.09819794, 13.65958405], [80.0984726, 13.65957928], [80.0984726, 13.66125202], [80.09819794, 13.66125202], [80.09819794, 13.66152954], [80.0973587, 13.66152954], [80.0973587, 13.66125202], [80.09707642, 13.66125202], [80.09707642, 13.66097164], [80.09680176, 13.66097164], [80.09680176, 13.66041565], [80.0965271, 13.66042042], [80.0965271, 13.6598711], [80.09626007, 13.6598711], [80.09626007, 13.65957928], [80.09597015, 13.65958405], [80.09597015, 13.65902805], [80.09570313, 13.65902996], [80.09570313, 13.65874958], [80.09541321, 13.65874958], [80.09541321, 13.65819073], [80.09513855, 13.65819359], [80.09513855, 13.65763664], [80.09485626, 13.65764046], [80.09485626, 13.65736198], [80.0945816, 13.65736198], [80.0945816, 13.65680981], [80.09430695, 13.65680981], [80.09430695, 13.65653038], [80.09401703, 13.65653038], [80.09401703, 13.65597057], [80.09375, 13.65597057], [80.09375, 13.6554184], [80.0934906, 13.6554203], [80.0934906, 13.65514183], [80.09320068, 13.65514183], [80.09320068, 13.65458107], [80.0929184, 13.65458298], [80.0929184, 13.65430546], [80.09236145, 13.65431023], [80.09236145, 13.65414143], [80.09236145, 13.65402699], [80.09179688, 13.65403175], [80.09179688, 13.65373993], [80.0890274, 13.65375137], [80.0890274, 13.65388107], [80.0890274, 13.65403175], [80.08875275, 13.65403175], [80.08875275, 13.6554203], [80.08930206, 13.6554184], [80.08930206, 13.65569305], [80.08958435, 13.65569305], [80.08958435, 13.65597057], [80.0901413, 13.65597057], [80.0901413, 13.65625191], [80.09041595, 13.65625191], [80.09041595, 13.65653038], [80.0909729, 13.65653038], [80.0909729, 13.65680981], [80.09124756, 13.65680981], [80.09124756, 13.65736198], [80.09152985, 13.65736198], [80.09152985, 13.65764046], [80.0918045, 13.65763664], [80.0918045, 13.65819359], [80.09208679, 13.65819073], [80.09208679, 13.65874958], [80.09236145, 13.65874958], [80.09236145, 13.65902996], [80.09263611, 13.65902805], [80.09263611, 13.65958405], [80.0929184, 13.65957928], [80.0929184, 13.6598711], [80.09320068, 13.6598711], [80.09320068, 13.66042042], [80.09347534, 13.66041565], [80.09347534, 13.66097164], [80.09375, 13.66097164], [80.09375, 13.66125202], [80.09401703, 13.66125202], [80.09401703, 13.66181087], [80.09430695, 13.66180611], [80.09430695, 13.66208363], [80.09541321, 13.66207886], [80.09541321, 13.66263962], [80.0956955, 13.66263771], [80.0956955, 13.6631937], [80.09597015, 13.6631918], [80.09597015, 13.66374969], [80.09626007, 13.66374969], [80.09626007, 13.66431141], [80.0965271, 13.66431141], [80.0965271, 13.66486168], [80.09680176, 13.66485977], [80.09680176, 13.66569424], [80.0965271, 13.66567993], [80.0965271, 13.66681099], [80.09626007, 13.66681099], [80.09626007, 13.66792107], [80.09597015, 13.6679163], [80.09597015, 13.66847229], [80.09570313, 13.66847038], [80.09570313, 13.66874981], [80.0945816, 13.66874981], [80.0945816, 13.66819191], [80.09430695, 13.66819382], [80.09430695, 13.66763783], [80.09401703, 13.66764069], [80.09401703, 13.66736031], [80.09347534, 13.66736031], [80.09347534, 13.66708374], [80.09319305, 13.66708374], [80.09319305, 13.66680622], [80.09263611, 13.66681099], [80.09263611, 13.66653061], [80.09236145, 13.66653061], [80.09236145, 13.66625023], [80.09208679, 13.66625023], [80.09208679, 13.66596985], [80.09152985, 13.66597176], [80.09152985, 13.66569424], [80.09124756, 13.66569424], [80.09124756, 13.66541576], [80.0909729, 13.66542053], [80.0909729, 13.66514015], [80.09041595, 13.66514015], [80.09041595, 13.66486168], [80.0901413, 13.66486168], [80.0901413, 13.66458035], [80.08930206, 13.66458035], [80.08930206, 13.66514015], [80.0890274, 13.66514015], [80.0890274, 13.66569424], [80.08791351, 13.66569424], [80.08791351, 13.66541576], [80.08763885, 13.66542053], [80.08763885, 13.66486168], [80.08735657, 13.66486168], [80.08735657, 13.66431141], [80.08706665, 13.66431141], [80.08706665, 13.66374969], [80.08680725, 13.66374969], [80.08680725, 13.66347027], [80.08652496, 13.66347218], [80.08652496, 13.66291809], [80.08625031, 13.66292953], [80.08625031, 13.66236019], [80.08597565, 13.6623621], [80.08597565, 13.66208363], [80.08569336, 13.66208363], [80.08569336, 13.66152763], [80.0854187, 13.66152954], [80.0854187, 13.66125202], [80.08513641, 13.66125202], [80.08513641, 13.66068935], [80.08430481, 13.66069412], [80.08430481, 13.65958405], [80.08403015, 13.65958405], [80.08403015, 13.65847206], [80.08374786, 13.65847206], [80.08374786, 13.65819359], [80.08347321, 13.65819359], [80.08347321, 13.65791798], [80.08291626, 13.65792179], [80.08291626, 13.65764046], [80.0826416, 13.65764046], [80.0826416, 13.65736198], [80.08235931, 13.65736198], [80.08235931, 13.65708065], [80.08208466, 13.65708447], [80.08208466, 13.65680599], [80.08180237, 13.65680981], [80.08180237, 13.65653038], [80.08126068, 13.65653038], [80.08126068, 13.65625191], [80.08097076, 13.65625191], [80.08097076, 13.65597057], [80.07930756, 13.65597057], [80.07930756, 13.65513897], [80.07958221, 13.65514183], [80.07958221, 13.65458107], [80.08013916, 13.65458298], [80.08013916, 13.65263939], [80.07985687, 13.65263939], [80.07985687, 13.65180969], [80.08013916, 13.65180969], [80.08013916, 13.65152931], [80.08040619, 13.65152931], [80.08040619, 13.65125084], [80.08069611, 13.65125084], [80.08069611, 13.65097141], [80.08097076, 13.65097332], [80.08097076, 13.65069485], [80.08125305, 13.65069485], [80.08125305, 13.65041733], [80.08235931, 13.65041733], [80.08235931, 13.65097332], [80.08319092, 13.65097332], [80.08319092, 13.65069485], [80.08374786, 13.65069485], [80.08374786, 13.65041733], [80.08403015, 13.65041924], [80.08403015, 13.65014076], [80.08735657, 13.65014076], [80.08735657, 13.65041924], [80.0901413, 13.65041733], [80.0901413, 13.65097332], [80.09069824, 13.65097141], [80.09069824, 13.65125084], [80.09124756, 13.65125084], [80.09124756, 13.65097141], [80.0918045, 13.65097332], [80.0918045, 13.64958286], [80.09152985, 13.64958286], [80.09152985, 13.64930534], [80.0909729, 13.64931202], [80.0909729, 13.64875126], [80.09320068, 13.64875126], [80.09319305, 13.64847088], [80.09375, 13.64847088], [80.09375, 13.64819527], [80.09430695, 13.64819527], [80.09430695, 13.64791679], [80.09485626, 13.6479311], [80.09485626, 13.6473608], [80.09430695, 13.6473608], [80.09430695, 13.64680481], [80.09401703, 13.64681244], [80.09401703, 13.64653111], [80.09375, 13.64653111], [80.09375, 13.64625072], [80.0934906, 13.64625072], [80.0934906, 13.6459713], [80.09236145, 13.64597321], [80.09236145, 13.64569473], [80.09152985, 13.64569473], [80.09152985, 13.64541721], [80.09108734, 13.64541721], [80.08875275, 13.64541721], [80.08875275, 13.64569473], [80.0845871, 13.64569473], [80.0845871, 13.64541721], [80.08403015, 13.64542103], [80.08403015, 13.64514065], [80.08347321, 13.64514065], [80.08347321, 13.6448698], [80.08291626, 13.6448698], [80.08291626, 13.64458275], [80.0826416, 13.64458275], [80.0826416, 13.6448698], [80.08235931, 13.6448698], [80.08235931, 13.64458275], [80.08152771, 13.64458466], [80.08152771, 13.64430428], [80.08097076, 13.64431095], [80.08097076, 13.64403057], [80.08069611, 13.64403057], [80.08069611, 13.6434679], [80.08013916, 13.64347267], [80.08013916, 13.64319515], [80.07930756, 13.64319515], [80.07930756, 13.64291573], [80.0790329, 13.64292145], [80.0790329, 13.64264107], [80.07875061, 13.64264107], [80.07875061, 13.64235973], [80.07818604, 13.64235973], [80.07818604, 13.64208031], [80.07763672, 13.64208221], [80.07763672, 13.6418066], [80.07736206, 13.6418066], [80.07736206, 13.64152813], [80.07681274, 13.64153099], [80.07681274, 13.64124966], [80.07653046, 13.64124966], [80.07653046, 13.64097023], [80.07624817, 13.64097214], [80.07624817, 13.64069366], [80.07569122, 13.64069366], [80.07569122, 13.64041615], [80.07541656, 13.64042091], [80.07541656, 13.64013958], [80.07512665, 13.64013958], [80.07512665, 13.63957977], [80.07458496, 13.63958359], [80.07458496, 13.6390276], [80.07430267, 13.63903141], [80.07430267, 13.63874054], [80.07402802, 13.63875008], [80.07402802, 13.63819408], [80.07375336, 13.63819408], [80.07375336, 13.63791561], [80.07347107, 13.63792133], [80.07347107, 13.63735962], [80.07319641, 13.63736153], [80.07319641, 13.63708401], [80.07263947, 13.63708401], [80.07263947, 13.63652802], [80.07235718, 13.63652992], [80.07235718, 13.63597202], [80.07208252, 13.63597202], [80.07208252, 13.63541794], [80.07180786, 13.63541985], [80.07180786, 13.63486195], [80.07152557, 13.63486195], [80.07152557, 13.63374996], [80.07125092, 13.63374996], [80.07125092, 13.63264179], [80.07096863, 13.63264179], [80.07096863, 13.63181019], [80.07068634, 13.63181019], [80.07068634, 13.63069057], [80.07041931, 13.63069344], [80.07041931, 13.62819576], [80.07069397, 13.62819576], [80.07069397, 13.62763882], [80.07096863, 13.62764168], [80.07096863, 13.6273613], [80.07125092, 13.6273613], [80.07125092, 13.62680531], [80.07152557, 13.62680531], [80.07152557, 13.62569523], [80.07180786, 13.62569523], [80.07180786, 13.62465096], [80.07180786, 13.62236118], [80.07152557, 13.62236118], [80.07152557, 13.62097263], [80.07125092, 13.62097263], [80.07125092, 13.61986065], [80.07096863, 13.61986065], [80.07096863, 13.61736107], [80.07125092, 13.61736107], [80.07125092, 13.61457062], [80.07180786, 13.61458206], [80.07180786, 13.61430645], [80.07235718, 13.61431122], [80.07235718, 13.61403084], [80.07430267, 13.61403084], [80.07430267, 13.61375046], [80.07485962, 13.61375046], [80.07485962, 13.61347008], [80.07514191, 13.61347198], [80.07514191, 13.61319447], [80.07541656, 13.61319447], [80.07541656, 13.61236], [80.07569122, 13.61236], [80.07569122, 13.61182022], [80.07596588, 13.61182022], [80.07596588, 13.61153126], [80.07624817, 13.61153126], [80.07624817, 13.61069202], [80.07597351, 13.61069393], [80.07597351, 13.61013794], [80.07569122, 13.61013985], [80.07569122, 13.60986042], [80.07541656, 13.60986233], [80.07541656, 13.60958195], [80.07514191, 13.60958195], [80.07514191, 13.60875034], [80.07485962, 13.60876083], [80.07485962, 13.60847187], [80.07430267, 13.60847187], [80.07430267, 13.60819435], [80.07208252, 13.60819435], [80.07208252, 13.60791588], [80.07180786, 13.60791969], [80.07180786, 13.60764027], [80.0715332, 13.60764027], [80.0715332, 13.60736179], [80.07125092, 13.60736179], [80.07125092, 13.60707855], [80.07096863, 13.60708427], [80.07096863, 13.6068058], [80.07068634, 13.60680962], [80.07068634, 13.60653019], [80.07096863, 13.60653019], [80.07096863, 13.60596943], [80.07125092, 13.60597229], [80.07125092, 13.6054163], [80.06986237, 13.60542011], [80.06986237, 13.60458088], [80.07013702, 13.60458374], [80.07013702, 13.60291767], [80.06986237, 13.60291958], [80.06986237, 13.60236168], [80.06930542, 13.60236168], [80.06930542, 13.60208321], [80.06819153, 13.60208321], [80.06819153, 13.60319328], [80.06764221, 13.60319328], [80.06764221, 13.60291767], [80.06735992, 13.60291958], [80.06735992, 13.60262966], [80.06625366, 13.60264015], [80.06625366, 13.60236168], [80.06569672, 13.60236168], [80.06569672, 13.6020813], [80.06541443, 13.60208321], [80.06541443, 13.60124874], [80.06513977, 13.6012516], [80.06513977, 13.60097122], [80.06485748, 13.60097122], [80.06485748, 13.60069466], [80.06430817, 13.60069466], [80.06430817, 13.60041714], [80.06402588, 13.60042191], [80.06402588, 13.60014153], [80.06375122, 13.60014153], [80.06375122, 13.59986115], [80.06319427, 13.59986115], [80.06319427, 13.59958267], [80.06291962, 13.5995903], [80.06291962, 13.59902859], [80.06263733, 13.59902859], [80.06263733, 13.59736061], [80.06236267, 13.59736061], [80.06236267, 13.59708309], [80.06208038, 13.59708309], [80.06208038, 13.5965271], [80.06153107, 13.59653187], [80.06153107, 13.59625053], [80.06124878, 13.59625053], [80.06124878, 13.59569073], [80.06097412, 13.59569454], [80.06097412, 13.59513855], [80.06041718, 13.59514141], [80.06041718, 13.59486103], [80.05986023, 13.59486103], [80.05986023, 13.59458256], [80.05930328, 13.59458256], [80.05930328, 13.59430695], [80.05874634, 13.59430695], [80.05874634, 13.59458256], [80.05819702, 13.59458065], [80.05819702, 13.59486103], [80.05764008, 13.59486103], [80.05764008, 13.59514141], [80.05735779, 13.59514141], [80.05735779, 13.59542179], [80.05709076, 13.59542179], [80.05709076, 13.59514141], [80.05680847, 13.59514141], [80.05680847, 13.59542179], [80.05652618, 13.59542179], [80.05652618, 13.59625053], [80.05596924, 13.59625053], [80.05596924, 13.59597111], [80.05569458, 13.59597301], [80.05569458, 13.59569454], [80.05541992, 13.59569454], [80.05541992, 13.59541702], [80.05513763, 13.59542179], [80.05513763, 13.59514141], [80.05486298, 13.59514141], [80.05486298, 13.59486103], [80.05430603, 13.59486103], [80.05430603, 13.59458065], [80.05403137, 13.59458256], [80.05403137, 13.59402657], [80.05430603, 13.59403133], [80.05430603, 13.59346199], [80.05458069, 13.59347343], [80.05458069, 13.59291744], [80.05486298, 13.59292126], [80.05486298, 13.59180927], [80.05513763, 13.59180927], [80.05513763, 13.59097004], [80.05541992, 13.5909729], [80.05541992, 13.59069538], [80.05486298, 13.59069538], [80.05486298, 13.59041691], [80.05236053, 13.59042072], [80.05236053, 13.5901413], [80.05208588, 13.5901413], [80.05208588, 13.58985996], [80.05152893, 13.58985996], [80.05152893, 13.58957958], [80.05124664, 13.58958244], [80.05124664, 13.58902645], [80.05095673, 13.58903122], [80.05095673, 13.58819199], [80.05124664, 13.58819389], [80.05124664, 13.5876379], [80.05152893, 13.5876503], [80.05152893, 13.58736038], [80.05180359, 13.58736038], [80.05180359, 13.58708191], [80.05208588, 13.58708191], [80.05208588, 13.5868063], [80.05236053, 13.58681107], [80.05236053, 13.58542061], [80.05264282, 13.58539963], [80.05263519, 13.58485985], [80.05291748, 13.58485985], [80.05291748, 13.58430576], [80.05319214, 13.58431053], [80.05319214, 13.58403015], [80.0534668, 13.58403015], [80.0534668, 13.58375168], [80.05319214, 13.58375168], [80.05319214, 13.58347034], [80.05347443, 13.58347225], [80.05347443, 13.58291626], [80.05374908, 13.58292103], [80.05374908, 13.58236027], [80.05403137, 13.58236217], [80.05403137, 13.58180618], [80.05430603, 13.58181095], [80.05430603, 13.58152103], [80.05458069, 13.58152771], [80.05458069, 13.58125019], [80.05486298, 13.58125019], [80.05486298, 13.58069229], [80.05513763, 13.5806942], [80.05513763, 13.58041573], [80.05541992, 13.58041954], [80.05541992, 13.58014011], [80.05568695, 13.58014011], [80.05568695, 13.57985973], [80.05596924, 13.57985973], [80.05596924, 13.57957935], [80.05625153, 13.57958412], [80.05625153, 13.57930565], [80.05652618, 13.57931042], [80.05652618, 13.57903004], [80.05680847, 13.57903004], [80.05680847, 13.57874966], [80.05709076, 13.57874966], [80.05709076, 13.57845974], [80.05735779, 13.57847214], [80.05735779, 13.57791805], [80.05764008, 13.57791996], [80.05764008, 13.57763958], [80.0579071, 13.57763958], [80.0579071, 13.5773592], [80.05819702, 13.57736206], [80.05819702, 13.57708359], [80.05847168, 13.57708359], [80.05847168, 13.57680607], [80.05874634, 13.57681179], [80.05874634, 13.57653046], [80.05902863, 13.57653046], [80.05902863, 13.57625198], [80.05930328, 13.57625198], [80.05930328, 13.57597065], [80.05986023, 13.57597065], [80.05986023, 13.57569313], [80.06014252, 13.57569313], [80.06014252, 13.57541847], [80.06069183, 13.57542038], [80.06069183, 13.57514191], [80.06096649, 13.57514191], [80.06096649, 13.57486057], [80.06153107, 13.57486057], [80.06153107, 13.57458305], [80.06180573, 13.57458305], [80.06180573, 13.57430458], [80.06236267, 13.5743103], [80.06236267, 13.57403183], [80.06291962, 13.57403183], [80.06291962, 13.5737524], [80.06375122, 13.5737524], [80.06375122, 13.57347107], [80.06430817, 13.57347107], [80.06430817, 13.57319546], [80.06513977, 13.57319546], [80.06513977, 13.57291698], [80.06569672, 13.57292175], [80.06569672, 13.57265091], [80.06652832, 13.57265091], [80.06652832, 13.57208061], [80.06680298, 13.57208347], [80.06680298, 13.57124901], [80.0670929, 13.57125092], [80.0670929, 13.57069111], [80.06735992, 13.57069302], [80.06735992, 13.56986141], [80.06764221, 13.56986141], [80.06764221, 13.56902695], [80.06791687, 13.56903076], [80.06791687, 13.56818962], [80.06819153, 13.56819534], [80.06819153, 13.56736088], [80.06846619, 13.56736088], [80.06846619, 13.56681156], [80.06874847, 13.56681156], [80.06874847, 13.56597137], [80.06903076, 13.56597328], [80.06903076, 13.56541729], [80.06932068, 13.5654192], [80.06932068, 13.5648613], [80.06958008, 13.5648613], [80.06958008, 13.56458473], [80.06986237, 13.56458473], [80.06986237, 13.56430531], [80.07013702, 13.56431103], [80.07013702, 13.56375122], [80.07041931, 13.56375122], [80.07041931, 13.5634613], [80.07069397, 13.56347275], [80.07069397, 13.56319523], [80.07096863, 13.56319523], [80.07096863, 13.56263828], [80.07125092, 13.56264114], [80.07125092, 13.56208038], [80.07152557, 13.56208229], [80.07152557, 13.56152916], [80.07180786, 13.56153107], [80.07180786, 13.56068993], [80.07208252, 13.56069374], [80.07208252, 13.56013775], [80.07235718, 13.56014061], [80.07235718, 13.55931091], [80.07263947, 13.55931091], [80.07263947, 13.55875015], [80.07290649, 13.55875015], [80.07290649, 13.55819035], [80.07347107, 13.55819416], [80.07347107, 13.55791569], [80.07402802, 13.55792141], [80.07402802, 13.55764008], [80.07459259, 13.55764008], [80.07459259, 13.5573597], [80.07485962, 13.5573597], [80.07485962, 13.55708027], [80.07541656, 13.55708408], [80.07541656, 13.55680561], [80.07596588, 13.55681133], [80.07596588, 13.55653], [80.07653046, 13.55653], [80.07653046, 13.55597019], [80.07680511, 13.5559721], [80.07680511, 13.55513763], [80.07707977, 13.55513954], [80.07707977, 13.55458164], [80.07736206, 13.55458355], [80.07736206, 13.55402756], [80.07847595, 13.55403042], [80.07847595, 13.55375004], [80.07985687, 13.55375004], [80.07985687, 13.55346966], [80.08097076, 13.55347157], [80.08097076, 13.55319405], [80.08208466, 13.55319405], [80.08208466, 13.55291557], [80.08319092, 13.55292034], [80.08319092, 13.55263996], [80.0845871, 13.55263996], [80.0845871, 13.55235958], [80.08569336, 13.55236244], [80.08569336, 13.55208397], [80.08625031, 13.55208397], [80.08625031, 13.55180645], [80.08653259, 13.55181026], [80.08653259, 13.5515213], [80.08708191, 13.55152798], [80.08708191, 13.55125046], [80.08735657, 13.55125046], [80.08735657, 13.55097198], [80.08791351, 13.55097198], [80.08791351, 13.55013657], [80.0881958, 13.55014038], [80.0881958, 13.54875183], [80.08847046, 13.54875183], [80.08847046, 13.54764175], [80.0881958, 13.54764175], [80.0881958, 13.54708099], [80.08847046, 13.5470829], [80.08847046, 13.54652691], [80.08875275, 13.54653168], [80.08875275, 13.54597092], [80.0890274, 13.54597092], [80.0890274, 13.5456953], [80.08930206, 13.5456953], [80.08930206, 13.54513931], [80.08957672, 13.54513931], [80.08957672, 13.54458141], [80.08985901, 13.54458332], [80.08985901, 13.54430485], [80.0901413, 13.54430962], [80.0901413, 13.54375076], [80.09041595, 13.54375076], [80.09041595, 13.54319096], [80.09069061, 13.54319477], [80.09069824, 13.54291725], [80.09152985, 13.54292202], [80.09152985, 13.54264069], [80.09208679, 13.54264069], [80.09208679, 13.54234982], [80.0929184, 13.54236126], [80.0929184, 13.54208279], [80.09347534, 13.54208279], [80.09347534, 13.54180527], [80.09430695, 13.54181194], [80.09430695, 13.54153061], [80.09513855, 13.54153061], [80.09513855, 13.54125118], [80.09570313, 13.54125118], [80.0956955, 13.5409708], [80.0965271, 13.5409708], [80.0965271, 13.54069519], [80.09680176, 13.54069519], [80.09680176, 13.5401392], [80.09707642, 13.54014111], [80.09707642, 13.53958035], [80.0973587, 13.53958321], [80.0973587, 13.53791714], [80.09764099, 13.53792095], [80.09764099, 13.53654003], [80.09819794, 13.53654003], [80.09819794, 13.53625107], [80.09902954, 13.53625107], [80.09902954, 13.53596973], [80.09958649, 13.5359726], [80.09958649, 13.53513813], [80.09929657, 13.53514099], [80.09929657, 13.53403091], [80.09902954, 13.53403091], [80.09902954, 13.53292084], [80.09874725, 13.53292084], [80.09874725, 13.53181076], [80.0984726, 13.53181076], [80.0984726, 13.53125], [80.09874725, 13.53125], [80.09874725, 13.53069019], [80.09902954, 13.53069401], [80.09902954, 13.53041553], [80.0993042, 13.53041553], [80.0993042, 13.5298624], [80.09958649, 13.5298624], [80.09958649, 13.52958202], [80.09986115, 13.52958202], [80.09986115, 13.52902794], [80.1001358, 13.52902985], [80.1001358, 13.52875042], [80.10069275, 13.52875042], [80.10069275, 13.52847195], [80.10124969, 13.52847195], [80.10124969, 13.52819443], [80.10180664, 13.52819443], [80.10180664, 13.52791595], [80.10263824, 13.52792263], [80.10263824, 13.52764034], [80.10320282, 13.52764034], [80.10320282, 13.52735138], [80.10375214, 13.52736187], [80.10375214, 13.52652836], [80.10402679, 13.52653027], [80.10402679, 13.52542019], [80.10430908, 13.52542019], [80.10430908, 13.52486038], [80.1048584, 13.52486229], [80.1048584, 13.52458382], [80.10541534, 13.52458382], [80.10541534, 13.5243063], [80.10597229, 13.52431011], [80.10597229, 13.52402973], [80.10652924, 13.52402973], [80.10652924, 13.52375031], [80.10679626, 13.52375031], [80.10679626, 13.52319145], [80.10708618, 13.52319336], [80.10708618, 13.52264023], [80.10736084, 13.52264023], [80.10736084, 13.52235889], [80.1076355, 13.52236176], [80.1076355, 13.52180481], [80.10791779, 13.52180958], [80.10791779, 13.52125168], [80.10820007, 13.52125168], [80.10820007, 13.5209713], [80.10847473, 13.5209713], [80.10847473, 13.52041531], [80.10874939, 13.52042198], [80.10874939, 13.51986122], [80.10902405, 13.51986122], [80.10902405, 13.51930523], [80.11013794, 13.51931], [80.11013794, 13.51902962], [80.11068726, 13.51902962], [80.11068726, 13.51874924], [80.11152649, 13.51874924], [80.11152649, 13.51847076], [80.11208344, 13.51847076], [80.11207581, 13.51764202], [80.11180878, 13.51764202], [80.11180878, 13.51653194], [80.11207581, 13.51653194], [80.11207581, 13.51681042], [80.11235809, 13.5168047], [80.11235809, 13.51708317], [80.11264038, 13.51708126], [80.11264038, 13.51736069], [80.11292267, 13.51736069], [80.11292267, 13.51764202], [80.11486053, 13.51764202], [80.11486053, 13.51736069], [80.1159668, 13.51736069], [80.1159668, 13.51708126], [80.11736298, 13.51708317], [80.11736298, 13.51652718], [80.11763763, 13.51653194], [80.11763763, 13.51597118], [80.11791992, 13.51597309], [80.11791992, 13.5154171], [80.11819458, 13.5154171], [80.11819458, 13.51513863], [80.11902618, 13.51514053], [80.11902618, 13.51458073], [80.11930847, 13.51458263], [80.11930847, 13.51375103], [80.11958313, 13.51375103], [80.11958313, 13.51208019], [80.11930847, 13.51208305], [80.11930847, 13.51180458], [80.11763763, 13.51180458], [80.11763763, 13.51208305], [80.11708069, 13.51208019], [80.11708069, 13.51237202], [80.11624908, 13.51237202], [80.11624908, 13.51153088], [80.1159668, 13.51153088], [80.1159668, 13.51041889], [80.11569214, 13.51041889], [80.11569214, 13.50931072], [80.11486053, 13.50931072], [80.11486053, 13.5090313], [80.11429596, 13.5090313], [80.11429596, 13.50875092], [80.11458588, 13.50875092], [80.11458588, 13.50846958], [80.11486053, 13.5084734], [80.11486053, 13.50819397], [80.11513519, 13.50819397], [80.11513519, 13.50791645], [80.11541748, 13.50792122], [80.11541748, 13.50764084], [80.1159668, 13.50764084], [80.1159668, 13.50736046], [80.11653137, 13.50736046], [80.11653137, 13.50708199], [80.11708069, 13.50708199], [80.11708069, 13.50680637], [80.11763763, 13.50680637], [80.11763763, 13.50708199], [80.11737061, 13.50708008], [80.11737061, 13.50764084], [80.11708069, 13.50763798], [80.11708069, 13.50819016], [80.11680603, 13.50819397], [80.11680603, 13.51069546], [80.11791992, 13.51069546], [80.11791992, 13.5084734], [80.11819458, 13.5084734], [80.11687469, 13.50280857], [80.10691071, 13.50394154], [80.10504913, 13.50363159], [80.10035706, 13.50520039], [80.09942627, 13.50631046], [80.09670258, 13.50821018], [80.09565735, 13.50984001], [80.09377289, 13.5135603], [80.08866882, 13.52552986], [80.0879364, 13.52595997], [80.08766937, 13.52661037], [80.08672333, 13.52724075], [80.07943726, 13.52936077], [80.07627869, 13.52612019], [80.07582092, 13.5267601], [80.07276154, 13.53392124], [80.06944275, 13.53759098], [80.06717682, 13.53592014], [80.06561279, 13.53476048], [80.05950928, 13.5325489], [80.05098724, 13.53051186], [80.04541779, 13.52198124], [80.03409576, 13.52180099], [80.0295105, 13.52359009], [80.01754761, 13.52513123], [80.01449585, 13.52849007], [80.00771332, 13.53237247], [79.994133, 13.52960014], [79.98967743, 13.5267601], [79.9892807, 13.51900005], [79.98973846, 13.51300144], [79.99017334, 13.51009083], [80.00039673, 13.51237202], [80.00623322, 13.51506233], [80.00842285, 13.50830173], [80.01361847, 13.50391197], [80.01908875, 13.50166035], [80.0256424, 13.5039711], [80.03275299, 13.50183964], [80.03697968, 13.49935055], [80.0371933, 13.49282169], [80.03604126, 13.4844799], [80.02481842, 13.48670006], [80.01885223, 13.48637199], [80.00589752, 13.48777103], [80.00440216, 13.47826004], [79.99537659, 13.45945072], [79.9907608, 13.45921993], [79.99056244, 13.46205997], [79.98747253, 13.46191025], [79.96826935, 13.45643139], [79.96186066, 13.45127964], [79.96218872, 13.44413853], [79.9630661, 13.44057274], [79.96102142, 13.42766094], [79.96322632, 13.41791058], [79.95848083, 13.41285133], [79.95085144, 13.40812016], [79.94426727, 13.41078186], [79.93595123, 13.40957165], [79.93247986, 13.40437126], [79.93557739, 13.39059067], [79.93562317, 13.38484955], [79.95028687, 13.38197136], [79.95358276, 13.37411118], [79.94803619, 13.36722088], [79.93974304, 13.36910057], [79.94064331, 13.36098099], [79.93998718, 13.35811138], [79.9287262, 13.34353065], [79.92550659, 13.33594036], [79.91713715, 13.34103966], [79.91068268, 13.34370041], [79.90628815, 13.33905125], [79.903862, 13.33327103], [79.89736176, 13.32948971], [79.8917923, 13.32461929], [79.88607788, 13.32129192], [79.88015747, 13.32043934], [79.87496185, 13.31740093], [79.87055206, 13.31175995], [79.86519623, 13.31072998], [79.8588562, 13.31374073], [79.85568237, 13.30814075], [79.85116577, 13.3034296], [79.83905792, 13.30334091], [79.8367691, 13.30299854], [79.83059692, 13.30206013], [79.82404327, 13.30231953], [79.80848694, 13.30508041], [79.80029297, 13.30432129], [79.7950058, 13.29857063], [79.79226685, 13.29164028], [79.78727722, 13.28462029], [79.77980042, 13.28207016], [79.77422333, 13.28513145], [79.76835632, 13.28962994], [79.75405884, 13.30278969], [79.75055695, 13.29881001], [79.74975586, 13.29088116], [79.74614716, 13.28000069], [79.74149323, 13.27666187], [79.72963715, 13.27507973], [79.72129059, 13.27223969], [79.72177887, 13.26573086], [79.73938751, 13.25443077], [79.74558258, 13.24821091], [79.7527771, 13.24376011], [79.77539063, 13.23411942], [79.78325653, 13.22816181], [79.78489685, 13.22348022], [79.78325653, 13.21791935], [79.77733612, 13.2171917], [79.7735672, 13.21751976], [79.76716614, 13.21333981], [79.76333618, 13.20885086], [79.75772095, 13.20557117], [79.75183105, 13.20477962], [79.74437714, 13.194911], [79.73826599, 13.19825935], [79.73750305, 13.20552063], [79.73368073, 13.21023178], [79.73252869, 13.21496105], [79.72651672, 13.21738052], [79.72283173, 13.22185135], [79.71856689, 13.2225914], [79.71570587, 13.21440029], [79.71142578, 13.21047974], [79.70568848, 13.20923138], [79.69963837, 13.20268059], [79.69243622, 13.20753098], [79.68875122, 13.20740986], [79.68943787, 13.21125031], [79.69574738, 13.2237606], [79.69603729, 13.23389053], [79.69193268, 13.23852921], [79.68456268, 13.23384953], [79.68068695, 13.22837067], [79.67331696, 13.22949028], [79.67111206, 13.23584175], [79.67376709, 13.24702072], [79.68430328, 13.25667953], [79.68161011, 13.26555061], [79.67932129, 13.26933193], [79.66853333, 13.28193092], [79.66590118, 13.27327919], [79.66256714, 13.26814175], [79.65740204, 13.2684803], [79.65338135, 13.27456856], [79.64862823, 13.2733593], [79.64376831, 13.2733593], [79.63848114, 13.2761898], [79.63250732, 13.2735424], [79.63072205, 13.26815987], [79.62956238, 13.26086044], [79.62431335, 13.26202011], [79.62075806, 13.25895023], [79.61519623, 13.26045036], [79.61075592, 13.26459122], [79.60510254, 13.26736069], [79.60114288, 13.26772976], [79.59485626, 13.26304245], [79.58867645, 13.26041126], [79.58644867, 13.25348091], [79.5854187, 13.24710083], [79.58026123, 13.24537086], [79.570961, 13.2473793], [79.56537628, 13.24940109], [79.55478668, 13.25918102], [79.54872894, 13.26712132], [79.54634094, 13.27404976], [79.54144287, 13.27893162], [79.53922272, 13.28975964], [79.53887177, 13.30092144], [79.53578186, 13.31107044], [79.52271271, 13.31593132], [79.50953674, 13.31470013], [79.49781036, 13.31482124], [79.48722839, 13.31655121], [79.47927856, 13.32145977], [79.45464325, 13.32432079], [79.42887878, 13.32356167], [79.41732025, 13.32195854], [79.40139771, 13.31575108], [79.37460327, 13.30303955], [79.38562775, 13.29470062], [79.39897919, 13.28915119], [79.40542603, 13.28541088], [79.42177582, 13.28666019], [79.42502594, 13.2813406], [79.41837311, 13.27458954], [79.41799164, 13.26906109], [79.41902161, 13.2663393], [79.41230011, 13.25751019], [79.40866852, 13.24674129], [79.407341, 13.23766136], [79.40968323, 13.22815037], [79.40865326, 13.21959019], [79.4108429, 13.21216202], [79.41699982, 13.21220112], [79.41816711, 13.21846199], [79.42690277, 13.22274017], [79.43609619, 13.2298317], [79.44245911, 13.22918034], [79.4454422, 13.2217207], [79.44550323, 13.21677113], [79.42163086, 13.20853138], [79.42315674, 13.2038002], [79.42315674, 13.19891071], [79.42156982, 13.19318104], [79.42378998, 13.1874609], [79.42059326, 13.18446159], [79.41329193, 13.18584919], [79.3979187, 13.18642235], [79.39256287, 13.18446159], [79.38437653, 13.18472099], [79.37835693, 13.18243122], [79.3690033, 13.17626095], [79.37078094, 13.16858959], [79.36717224, 13.16558075], [79.36493683, 13.16037083], [79.36120605, 13.15604115], [79.35472107, 13.16133976], [79.34777069, 13.16301918], [79.34709167, 13.15395069], [79.34783936, 13.14381981], [79.34686279, 13.14015102], [79.34674835, 13.13486099], [79.35457611, 13.12977123], [79.35009766, 13.12545013], [79.34435272, 13.12356091], [79.33779144, 13.12317085], [79.33531952, 13.12751007], [79.33068848, 13.12123108], [79.31672668, 13.11936855], [79.31239319, 13.11376953], [79.30973053, 13.10690022], [79.31002808, 13.0999403], [79.30793762, 13.09691143], [79.29747009, 13.0973711], [79.29876709, 13.11483192], [79.2881012, 13.11828041], [79.28495026, 13.12285042], [79.27751923, 13.11972046], [79.27384949, 13.12090111], [79.27266693, 13.12666035], [79.27128601, 13.13806057], [79.26741028, 13.14120102], [79.26120758, 13.14074993], [79.25646973, 13.13654041], [79.25267029, 13.14129925], [79.25137329, 13.14619923], [79.2472229, 13.14808178], [79.24423981, 13.14115143], [79.24333954, 13.13335037], [79.23670197, 13.1267519], [79.23304749, 13.12769985], [79.22635651, 13.13461018], [79.21832275, 13.13555145], [79.21466064, 13.12767029], [79.21826935, 13.12043095], [79.22244263, 13.11600971], [79.21827698, 13.1103096], [79.21827698, 13.10394192], [79.2142868, 13.0968399], [79.20744324, 13.09144115], [79.20220947, 13.09029007], [79.19332123, 13.08969021], [79.18891907, 13.08461857], [79.18699646, 13.07705021], [79.1835022, 13.07294083], [79.18065643, 13.06704044], [79.17910004, 13.060112], [79.16942596, 13.05300999], [79.17473602, 13.04967976], [79.17227173, 13.04372025], [79.17653656, 13.03827095], [79.17697144, 13.03337955], [79.17662048, 13.0297699], [79.1743927, 13.02525043], [79.17310333, 13.01928139], [79.17059326, 13.01568031], [79.16120148, 13.01179886], [79.15270233, 13.00729275], [79.14163208, 13.00981998], [79.13114929, 13.01676273], [79.11927032, 13.02256966], [79.10437775, 13.02422047], [79.08278656, 13.0124712], [79.06906891, 13.01415062], [79.06057739, 13.02083969], [79.05397797, 13.02816105], [79.05326843, 13.03799057], [79.04389191, 13.04372025], [79.03353882, 13.04566002], [79.02588654, 13.04957962], [79.02281952, 13.05640125], [79.01142883, 13.05782986], [79.00036621, 13.05788136], [78.99523926, 13.06304073], [78.98825073, 13.07265186], [78.98174286, 13.07619953], [78.97959137, 13.07651043], [78.97167969, 13.07511997], [78.96465302, 13.07279968], [78.9629364, 13.07155991], [78.95918274, 13.06544018], [78.95509338, 13.06492996], [78.95001221, 13.06608963], [78.94584656, 13.06350994], [78.93663788, 13.06997108], [78.9300766, 13.06602192], [78.91438293, 13.06776142], [78.91204071, 13.06328201], [78.9108429, 13.05610085], [78.90867615, 13.05045986], [78.90091705, 13.05210114], [78.89346313, 13.03509235], [78.89839935, 13.0316906], [78.90439606, 13.03105068], [78.91739655, 13.03254986], [78.92043304, 13.02862072], [78.92745972, 13.02346134], [78.9286499, 13.021451], [78.92463684, 13.01864147], [78.92299652, 13.02176094], [78.9159317, 13.02306175], [78.8901062, 13.01982975], [78.88191986, 13.01976204], [78.87937164, 13.02550125], [78.88088989, 13.04428101], [78.88040924, 13.06960201], [78.88352203, 13.08198929], [78.8760376, 13.08615971], [78.87032318, 13.08692074], [78.86473846, 13.08468056], [78.86068726, 13.0795002], [78.85835266, 13.07106972], [78.84393311, 13.0714798], [78.83226776, 13.06959057], [78.81342316, 13.0746479], [78.80809021, 13.07793045], [78.8008728, 13.07553005], [78.79418182, 13.06975937], [78.78659058, 13.06215191], [78.7830658, 13.05637169], [78.77752686, 13.05315971], [78.7544632, 13.04698181], [78.74601746, 13.0454092], [78.73951721, 13.04549122], [78.73217773, 13.05040264], [78.72550201, 13.05278015], [78.70244598, 13.05615139], [78.7012558, 13.04426003], [78.69597626, 13.01252079], [78.6937561, 13.00439167], [78.67935944, 13.00897026], [78.66861725, 13.01105976], [78.65110779, 13.01793194], [78.6489563, 13.0163517], [78.64505005, 13.00731087], [78.641716, 13.00161076], [78.63733673, 12.99684143], [78.62837982, 12.9897213], [78.62049866, 12.98252106], [78.61366272, 12.97889042], [78.62024689, 12.97391033], [78.63791656, 12.9544096], [78.6289978, 12.95311069], [78.63566589, 12.93834019], [78.64671326, 12.9190197], [78.63746643, 12.91588116], [78.6307373, 12.91597939], [78.62770081, 12.91792107], [78.62570953, 12.91918182], [78.62477112, 12.91418076], [78.61965179, 12.90207195], [78.61554718, 12.89321995], [78.61222839, 12.88856125], [78.60597229, 12.87369919], [78.60462189, 12.86600018], [78.60443115, 12.8574419], [78.59900665, 12.84947014], [78.59156799, 12.83854961], [78.59229279, 12.83677006], [78.59379578, 12.83300114], [78.59562683, 12.81548977], [78.59767151, 12.81107998], [78.5881958, 12.80478001], [78.59060669, 12.7979002], [78.58976746, 12.79244995], [78.58251953, 12.78532124], [78.58290863, 12.77622032], [78.5819397, 12.77077103], [78.5800705, 12.76724052], [78.57765961, 12.76585007], [78.56572723, 12.75901127], [78.56684875, 12.75214958], [78.56157684, 12.75257015], [78.5581131, 12.7516489], [78.55406189, 12.74606991], [78.55091858, 12.74680996], [78.54663086, 12.74560928], [78.54554749, 12.74391079], [78.55030823, 12.73876095], [78.54564667, 12.72861195], [78.55088806, 12.72622967], [78.55393219, 12.72606087], [78.55224609, 12.72039127], [78.54824829, 12.71498013], [78.54550934, 12.70738125], [78.54931641, 12.70070076], [78.55224609, 12.6970911], [78.55195618, 12.69433975], [78.54801178, 12.69536972], [78.54509735, 12.6926012], [78.54773712, 12.68911171], [78.54767609, 12.68559074], [78.54467773, 12.68443966], [78.54371643, 12.68460083], [78.54135895, 12.68501186], [78.53978729, 12.68422127], [78.53127289, 12.67993164], [78.52774811, 12.67900181], [78.52436829, 12.67969036], [78.52015686, 12.6870079], [78.51853943, 12.69237995], [78.52085876, 12.6971817], [78.52561188, 12.69474983], [78.52745819, 12.69730091], [78.52641296, 12.70123005], [78.51597595, 12.70352077], [78.51616669, 12.7062397], [78.51618958, 12.70640087], [78.51474762, 12.70698929], [78.51230621, 12.70800972], [78.51094055, 12.72172165], [78.5093689, 12.71979141], [78.50740814, 12.7130909], [78.50356293, 12.71337128], [78.50315857, 12.71809959], [78.50180054, 12.72150993], [78.49710083, 12.72411919], [78.4943161, 12.73037148], [78.48886108, 12.7319603], [78.48435211, 12.73478127], [78.47966003, 12.73001957], [78.48441315, 12.72305012], [78.49146271, 12.71706963], [78.49362946, 12.71116924], [78.5090332, 12.7049017], [78.51051331, 12.70176983], [78.5098114, 12.69878006], [78.5045929, 12.69800091], [78.50389099, 12.6933012], [78.49978638, 12.69685173], [78.49788666, 12.69851112], [78.49492645, 12.70372963], [78.49340057, 12.70347023], [78.494133, 12.69794083], [78.49301147, 12.69369984], [78.49090576, 12.69329166], [78.48754883, 12.69262886], [78.48631287, 12.69051075], [78.48956299, 12.68660927], [78.49357605, 12.68575001], [78.49340057, 12.68103027], [78.49740601, 12.67924976], [78.49711609, 12.67648983], [78.4940567, 12.67470074], [78.49344635, 12.66959095], [78.48855591, 12.66334248], [78.47406006, 12.65917969], [78.45765686, 12.66224957], [78.45935822, 12.63876057], [78.46292877, 12.63537025]]], [[[81.54180908, 16.35542107], [81.54180908, 16.35514069], [81.54207611, 16.35514069], [81.54207611, 16.35486031], [81.54264069, 16.35486031], [81.54264069, 16.35457993], [81.54291534, 16.35458374], [81.54291534, 16.35430527], [81.54319763, 16.35431099], [81.54319763, 16.35403061], [81.54347229, 16.35403061], [81.54347229, 16.35375023], [81.54403687, 16.35375023], [81.54402924, 16.35347176], [81.54430389, 16.35347176], [81.54430389, 16.35319519], [81.54458618, 16.35320091], [81.54458618, 16.35292053], [81.54486084, 16.35292053], [81.54486084, 16.35264015], [81.54511261, 16.35264015], [81.54541779, 16.35264015], [81.54541779, 16.35235977], [81.54569244, 16.35236168], [81.54569244, 16.35208321], [81.54597473, 16.35208321], [81.54597473, 16.35180473], [81.54624939, 16.35180473], [81.54624939, 16.35152817], [81.54651642, 16.35153008], [81.54651642, 16.35124969], [81.54680634, 16.35124969], [81.54680634, 16.35097122], [81.54708099, 16.35097313], [81.54708099, 16.35069466], [81.54736328, 16.35069466], [81.54736328, 16.34958458], [81.54708099, 16.34958458], [81.54708099, 16.34930611], [81.54680634, 16.34930992], [81.54680634, 16.34902954], [81.54624939, 16.34902954], [81.54624939, 16.34875107], [81.54541779, 16.34875107], [81.54541779, 16.3484726], [81.5451355, 16.3484726], [81.5451355, 16.34819412], [81.54373169, 16.34819412], [81.54319763, 16.34819412], [81.54319763, 16.3484726], [81.54070282, 16.3484726], [81.54070282, 16.34875107], [81.5404129, 16.34875107], [81.5404129, 16.3484726], [81.54013824, 16.3484726], [81.54013824, 16.34875107], [81.53985596, 16.34875107], [81.53985596, 16.3484726], [81.5395813, 16.3484726], [81.5395813, 16.34875107], [81.53874969, 16.34875107], [81.53874969, 16.3484726], [81.53736115, 16.3484726], [81.53736115, 16.34875107], [81.53180695, 16.34875107], [81.53180695, 16.34902954], [81.53151703, 16.34902954], [81.53151703, 16.34875107], [81.53098297, 16.34875107], [81.53098297, 16.34902954], [81.52401733, 16.34902954], [81.52401733, 16.34930992], [81.51930237, 16.34930611], [81.51930237, 16.34958458], [81.51486206, 16.34958267], [81.51486206, 16.34986115], [81.51346588, 16.34986115], [81.51346588, 16.35013962], [81.51319122, 16.35013962], [81.51319122, 16.35124969], [81.51346588, 16.35124969], [81.51346588, 16.35153008], [81.51403046, 16.35152817], [81.51403046, 16.35180473], [81.51430511, 16.35180473], [81.51430511, 16.35208321], [81.51457977, 16.35208321], [81.51457977, 16.35236168], [81.51513672, 16.35235977], [81.51513672, 16.35264015], [81.51541901, 16.35264015], [81.51541901, 16.35292053], [81.51568604, 16.35292053], [81.51568604, 16.35320091], [81.51652527, 16.35319519], [81.51652527, 16.35347176], [81.51708221, 16.35346031], [81.51708221, 16.35375023], [81.51790619, 16.35375023], [81.51790619, 16.35403061], [81.51930237, 16.35403061], [81.51930237, 16.35431099], [81.52041626, 16.35430527], [81.52041626, 16.35458374], [81.5220871, 16.35458374], [81.5220871, 16.35430527], [81.52236176, 16.35431099], [81.52236176, 16.35346031], [81.52263641, 16.35347176], [81.52263641, 16.35236168], [81.5229187, 16.35236168], [81.5229187, 16.35180473], [81.52347565, 16.35180473], [81.52347565, 16.35152817], [81.52401733, 16.35153008], [81.52401733, 16.35124969], [81.52458191, 16.35124969], [81.52458191, 16.35097122], [81.52513885, 16.35097313], [81.52513885, 16.35069466], [81.5284729, 16.35069466], [81.5284729, 16.35097313], [81.52874756, 16.35097122], [81.52874756, 16.35153008], [81.52902985, 16.35152817], [81.52902985, 16.35180473], [81.53013611, 16.35180473], [81.53013611, 16.35152817], [81.53236389, 16.35152817], [81.53236389, 16.35180473], [81.53347015, 16.35180473], [81.53347015, 16.35208321], [81.53375244, 16.35208321], [81.53375244, 16.35236168], [81.5340271, 16.35235977], [81.5340271, 16.35264015], [81.53430176, 16.35264015], [81.53430176, 16.35292053], [81.53457642, 16.35292053], [81.53457642, 16.35320091], [81.5348587, 16.35319519], [81.5348587, 16.35347176], [81.53514099, 16.35346031], [81.53514099, 16.35375023], [81.53542328, 16.35375023], [81.53542328, 16.35403061], [81.5359726, 16.35403061], [81.5359726, 16.35431099], [81.53624725, 16.35430527], [81.53624725, 16.35458374], [81.53652954, 16.35457993], [81.53652954, 16.35486031], [81.53819275, 16.35486031], [81.53819275, 16.35514069], [81.53985596, 16.35514069], [81.53985596, 16.35542107], [81.54180908, 16.35542107]]], [[[81.53514099, 16.35597229], [81.53514099, 16.35569382], [81.53541565, 16.35569382], [81.53541565, 16.35458374], [81.53514099, 16.35458374], [81.53514099, 16.35430527], [81.53486633, 16.35431099], [81.53486633, 16.35403061], [81.53457642, 16.35403061], [81.53457642, 16.35346031], [81.53430939, 16.35347176], [81.53430176, 16.35319519], [81.53375244, 16.35320091], [81.53375244, 16.35292053], [81.53347015, 16.35292053], [81.53347015, 16.35235977], [81.53263855, 16.35235977], [81.53263855, 16.35264015], [81.53151703, 16.35264015], [81.53151703, 16.35375023], [81.53180695, 16.35375023], [81.53180695, 16.35458374], [81.5320816, 16.35457993], [81.5320816, 16.35486031], [81.53235626, 16.35486031], [81.53235626, 16.35542107], [81.53291321, 16.35541725], [81.53291321, 16.35569382], [81.53347015, 16.35569382], [81.53347015, 16.35597229], [81.53514099, 16.35597229]]]]}}, {\\\"id\\\": \\\"2\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.3_1\\\", \\\"HASC_1\\\": \\\"IN.AR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Arunachal Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Agence de la Fronti\\\\u00e8re du Nord-Est(French-obsolete)|North East Frontier Agency\\\", \\\"apm25_popweighted\\\": -2.5, \\\"dalys_apm25_rate_6cod_mean_total\\\": 604.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1919.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1315.0, \\\"geo-id\\\": 2, \\\"hpm25_child_popweighted\\\": -148.4, \\\"hpm25_female_popweighted\\\": -170.6, \\\"hpm25_male_popweighted\\\": -122.8, \\\"location\\\": \\\"Arunachal Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 338.0, \\\"mort_hpm25_6cod_mean_total\\\": -970.0, \\\"mort_tpm25_6cod_mean_total\\\": -633.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[94.21111298, 27.61084175], [94.21350861, 27.60442162], [94.22292328, 27.60074043], [94.22505188, 27.59851074], [94.22531128, 27.59523964], [94.22144318, 27.58791161], [94.22547913, 27.5810585], [94.22647858, 27.57563019], [94.23414612, 27.57146072], [94.24060059, 27.57035065], [94.25650024, 27.55742836], [94.2557373, 27.55076027], [94.25686646, 27.54050064], [94.26251221, 27.52742958], [94.25972748, 27.52349091], [94.25905609, 27.52260017], [94.22167206, 27.50703049], [94.2154007, 27.5031395], [94.21232605, 27.4979496], [94.21065521, 27.49790382], [94.19522858, 27.49745941], [94.19124603, 27.49632072], [94.18689728, 27.49081039], [94.17471313, 27.48407173], [94.1679306, 27.48418808], [94.16422272, 27.48098946], [94.1572113, 27.47804832], [94.15873718, 27.47000122], [94.16020203, 27.46647072], [94.15445709, 27.46046066], [94.14080811, 27.44845963], [94.13585663, 27.44585991], [94.12333679, 27.43498039], [94.11708069, 27.43097115], [94.10652161, 27.41805077], [94.09992218, 27.41391945], [94.09329987, 27.41094017], [94.08634949, 27.40456009], [94.07244873, 27.38301277], [94.06864929, 27.37440109], [94.0631485, 27.36891174], [94.06092834, 27.36355972], [94.05483246, 27.36283112], [94.04831696, 27.35874939], [94.04164124, 27.35329056], [94.0300827, 27.34799194], [94.02583313, 27.34770012], [94.00978851, 27.33889008], [94.00000763, 27.33470917], [94.00068665, 27.33013916], [93.99780273, 27.32785988], [93.99603271, 27.32788277], [93.99018097, 27.32464981], [93.985672, 27.32057953], [93.9809494, 27.31376839], [93.97267151, 27.30834007], [93.95652008, 27.29475975], [93.93891144, 27.27327919], [93.93390656, 27.26834106], [93.91889954, 27.25714111], [93.90104675, 27.24154091], [93.89298248, 27.23097038], [93.89097595, 27.23018074], [93.88561249, 27.2243824], [93.8674469, 27.19884109], [93.85746002, 27.19110107], [93.84716797, 27.17978096], [93.8398819, 27.1734581], [93.83699799, 27.17207909], [93.82897949, 27.17064285], [93.82666016, 27.16937065], [93.8170166, 27.15824127], [93.80858612, 27.15175056], [93.80729675, 27.15014076], [93.80680847, 27.14720917], [93.80561066, 27.13779068], [93.80143738, 27.13791084], [93.79824066, 27.13716125], [93.79779816, 27.13600922], [93.7984314, 27.13439941], [93.80024719, 27.13262939], [93.80222321, 27.13286018], [93.80580902, 27.13475037], [93.80818939, 27.13286972], [93.81350708, 27.13201141], [93.81423187, 27.13082123], [93.8138504, 27.12861824], [93.81136322, 27.12626839], [93.81315613, 27.12376022], [93.81495667, 27.12260818], [93.81910706, 27.12290192], [93.82195282, 27.12203026], [93.82549286, 27.1193409], [93.82723236, 27.11194038], [93.82663727, 27.09938049], [93.83132172, 27.09243965], [93.8330307, 27.08761024], [93.83621216, 27.08647919], [93.83436584, 27.0828495], [93.83476257, 27.08205032], [93.83674622, 27.07821274], [93.83502197, 27.07499123], [93.83209991, 27.07286835], [93.82901001, 27.07212257], [93.82824707, 27.06895065], [93.82710266, 27.06884956], [93.82549286, 27.07212257], [93.82457733, 27.07217026], [93.82287598, 27.06832123], [93.81878662, 27.06493187], [93.81571198, 27.06545067], [93.81288147, 27.07068062], [93.81018829, 27.06814003], [93.80854797, 27.06257057], [93.80488586, 27.06134987], [93.80213165, 27.06176186], [93.79942322, 27.06687164], [93.79876709, 27.06968117], [93.79805756, 27.07094193], [93.79709625, 27.0708828], [93.79399872, 27.05772972], [93.7911911, 27.05456924], [93.78742218, 27.05422974], [93.78613281, 27.05537033], [93.78511047, 27.05835915], [93.78321075, 27.06719017], [93.78227234, 27.06690025], [93.78116608, 27.06081963], [93.77913666, 27.05829048], [93.77915955, 27.05334282], [93.77794647, 27.05277061], [93.7754364, 27.0562191], [93.77368164, 27.06236076], [93.7723999, 27.06230164], [93.77178955, 27.0555191], [93.77095795, 27.05455017], [93.77007294, 27.05558014], [93.76819611, 27.0555191], [93.76847839, 27.04329109], [93.74642944, 27.03240967], [93.7425766, 27.02971268], [93.73388672, 27.02723122], [93.71893311, 27.01922035], [93.70556641, 27.00832939], [93.70449829, 27.00656128], [93.70568085, 27.00368118], [93.70095062, 26.99710274], [93.69828033, 26.99479103], [93.69655609, 26.99237823], [93.67578125, 26.97107124], [93.65511322, 26.96647835], [93.64016724, 26.96478081], [93.62449646, 26.96421051], [93.59583282, 26.95518112], [93.58422089, 26.95264816], [93.57079315, 26.95412254], [93.54548645, 26.95174026], [93.52584076, 26.94863129], [93.48935699, 26.93852997], [93.48683167, 26.94309044], [93.48029327, 26.94017982], [93.46810913, 26.93889046], [93.46383667, 26.94354057], [93.44786835, 26.95415115], [93.43666077, 26.95609093], [93.39073181, 26.9600296], [93.37423706, 26.96038055], [93.34793854, 26.96324158], [93.26685333, 26.95600128], [93.22238922, 26.94914055], [93.1842804, 26.93873978], [93.10896301, 26.92728043], [93.09187317, 26.9155407], [93.07636261, 26.91994095], [93.06884003, 26.92420959], [93.06017303, 26.92118073], [93.03820801, 26.91788101], [93.01937103, 26.91683006], [92.99743652, 26.93034935], [92.9957962, 26.93032074], [92.99375916, 26.93178749], [92.98668671, 26.93383026], [92.98271942, 26.93593979], [92.98069763, 26.93562126], [92.97297668, 26.94082069], [92.96161652, 26.94588089], [92.95136261, 26.94890976], [92.93276978, 26.9569397], [92.92640686, 26.96066093], [92.92166138, 26.96190834], [92.91777039, 26.96424103], [92.91494751, 26.96976089], [92.91667938, 26.98465157], [92.89977264, 26.9962616], [92.89028931, 26.99982071], [92.88751984, 27.00022125], [92.88337708, 27.00234032], [92.87243652, 27.00769997], [92.836586, 27.0135498], [92.82441711, 27.0184803], [92.78527069, 27.0306797], [92.76909637, 27.033041], [92.72750854, 27.02840042], [92.71367645, 27.02609062], [92.70231628, 27.02758026], [92.68238831, 27.03174019], [92.65892792, 27.03852081], [92.65702057, 27.03759003], [92.65048981, 27.02477837], [92.63909912, 27.01853943], [92.64463043, 27.01004028], [92.64420319, 27.00251007], [92.64530945, 26.99561119], [92.64546204, 26.98744965], [92.58521271, 26.96186256], [92.55361176, 26.95907021], [92.53176117, 26.9633007], [92.51544189, 26.96442032], [92.50502014, 26.96677017], [92.49063873, 26.96473122], [92.48375702, 26.96474075], [92.46629333, 26.96306038], [92.45957184, 26.96331024], [92.44616699, 26.96063995], [92.44216919, 26.95502281], [92.42576599, 26.94346809], [92.41188812, 26.94419098], [92.39975739, 26.92627144], [92.36728668, 26.93155098], [92.36443329, 26.9326992], [92.35305023, 26.93556976], [92.34677887, 26.93346024], [92.3200531, 26.92838097], [92.30285645, 26.92420959], [92.30374908, 26.90954018], [92.30053711, 26.90814018], [92.29007721, 26.90546036], [92.28148651, 26.9041481], [92.27639008, 26.90246964], [92.26786804, 26.9050827], [92.2651062, 26.9076004], [92.26123047, 26.90876961], [92.25456238, 26.91222954], [92.20935059, 26.89689064], [92.19484711, 26.89100075], [92.1771698, 26.89248085], [92.16882324, 26.89191055], [92.16239929, 26.89266014], [92.14792633, 26.89088821], [92.12953949, 26.89071274], [92.12419128, 26.88976097], [92.12036896, 26.89030075], [92.1129837, 26.89238358], [92.11442566, 26.89390564], [92.11675262, 26.89645004], [92.11721039, 26.89809799], [92.11795044, 26.89937973], [92.11843109, 26.90102768], [92.11888123, 26.90300941], [92.11951447, 26.90539551], [92.11992645, 26.90775681], [92.12013245, 26.90954208], [92.11989594, 26.91101456], [92.11922455, 26.91245079], [92.11779022, 26.9137001], [92.11710358, 26.91493988], [92.11662292, 26.9167347], [92.11646271, 26.91841507], [92.11645508, 26.92025566], [92.1166153, 26.9223175], [92.1167984, 26.92402077], [92.11714935, 26.92584229], [92.11751556, 26.92727089], [92.1175766, 26.92895126], [92.11716461, 26.93087196], [92.11683655, 26.93156052], [92.11626434, 26.93274498], [92.11579895, 26.93420601], [92.1158905, 26.93604851], [92.11614227, 26.93635559], [92.11696625, 26.93736458], [92.11795807, 26.9385891], [92.11827087, 26.9409008], [92.11764526, 26.94330025], [92.11620331, 26.94451714], [92.11475372, 26.94573402], [92.11438751, 26.94753075], [92.11455536, 26.94944191], [92.11445618, 26.95111656], [92.11473846, 26.95230865], [92.1160965, 26.95360374], [92.11735535, 26.95474815], [92.11920166, 26.9555912], [92.12149811, 26.95687103], [92.12217712, 26.95793724], [92.12207031, 26.95913506], [92.1218338, 26.96093178], [92.12132263, 26.96225357], [92.12054443, 26.96334076], [92.11991882, 26.96550179], [92.11968231, 26.96729851], [92.11945343, 26.96945381], [92.11962128, 26.97136307], [92.11965942, 26.97327614], [92.11860657, 26.97412682], [92.11621857, 26.97487831], [92.11326599, 26.97564507], [92.11277008, 26.97577286], [92.11263275, 26.97586441], [92.11119843, 26.97684288], [92.10934448, 26.9783268], [92.10829163, 26.97917747], [92.10683441, 26.97979736], [92.10604095, 26.98040581], [92.10499573, 26.98173523], [92.10475922, 26.98329353], [92.10453033, 26.98509026], [92.10456848, 26.9869709], [92.10492706, 26.98744392], [92.10592651, 26.98877525], [92.10639954, 26.98932266], [92.10715485, 26.99019241], [92.10652924, 26.99271202], [92.10564423, 26.99523354], [92.10448456, 26.99740219], [92.10409546, 26.99836349], [92.10345459, 26.99956894], [92.10321045, 27.00088692], [92.10311127, 27.00391197], [92.10169983, 27.00605011], [92.10115814, 27.00679207], [92.0994873, 27.00745201], [92.09853363, 27.00800705], [92.09708405, 27.00910378], [92.09579468, 27.00973129], [92.09552002, 27.01093864], [92.09539032, 27.01151848], [92.09315491, 27.01310539], [92.09274292, 27.01323509], [92.08996582, 27.01410675], [92.08757782, 27.01497841], [92.08479309, 27.01609421], [92.08187103, 27.01673317], [92.07826233, 27.01768494], [92.07788086, 27.01846123], [92.07770538, 27.01970863], [92.0773468, 27.02041054], [92.07730865, 27.02335358], [92.07772064, 27.02636719], [92.07896423, 27.03026772], [92.08074188, 27.03173065], [92.08246613, 27.03361511], [92.08283997, 27.03464317], [92.08267975, 27.03583717], [92.08181763, 27.03704262], [92.08139038, 27.03824043], [92.08152771, 27.04121971], [92.07450867, 27.04187775], [92.07434845, 27.04196358], [92.07107544, 27.04369164], [92.06945801, 27.04432678], [92.06607056, 27.04679108], [92.06202698, 27.04826736], [92.06113434, 27.0485878], [92.06040955, 27.04890442], [92.05909729, 27.0495739], [92.05786133, 27.05020523], [92.05641937, 27.05087852], [92.05497742, 27.05139732], [92.0535202, 27.05160904], [92.04919434, 27.05155563], [92.04637146, 27.05178642], [92.04399109, 27.05164528], [92.04341888, 27.05272102], [92.0433197, 27.05378532], [92.04276276, 27.05609322], [92.03913879, 27.05959511], [92.0381012, 27.06129837], [92.03717041, 27.0623455], [92.03722382, 27.06291008], [92.03738403, 27.06449127], [92.03760529, 27.06732559], [92.03720856, 27.0692482], [92.03630066, 27.07133293], [92.03554535, 27.07226372], [92.0348587, 27.07335281], [92.03271484, 27.07675171], [92.03172302, 27.07920456], [92.03123474, 27.08041573], [92.0309906, 27.08215904], [92.03108978, 27.08359718], [92.0315094, 27.08466911], [92.03139496, 27.08574867], [92.03120422, 27.08665085], [92.03131104, 27.08868599], [92.03147888, 27.09096146], [92.03123474, 27.09204292], [92.03098297, 27.0931263], [92.03033447, 27.09433365], [92.02934265, 27.0953064], [92.02875519, 27.09591293], [92.02897644, 27.09710884], [92.02893066, 27.09830856], [92.02862549, 27.10016823], [92.02791595, 27.10155678], [92.02681732, 27.10384941], [92.02590179, 27.10506058], [92.0249176, 27.10633278], [92.02484894, 27.10771942], [92.02390289, 27.10948944], [92.02426147, 27.11124039], [92.025177, 27.11162949], [92.02557373, 27.11190224], [92.02593231, 27.11239243], [92.0262146, 27.11263657], [92.02610016, 27.11523247], [92.0269165, 27.11628723], [92.02772522, 27.11703682], [92.02857208, 27.11889648], [92.02967072, 27.12039757], [92.03110504, 27.12179375], [92.03218842, 27.12282181], [92.0328064, 27.12511253], [92.03309631, 27.12654305], [92.03339386, 27.12809181], [92.03353882, 27.12904739], [92.03410339, 27.13047218], [92.03411865, 27.13154793], [92.03420258, 27.1323967], [92.03427887, 27.13322067], [92.03442383, 27.13381577], [92.03472137, 27.13536644], [92.03514862, 27.13703346], [92.03544617, 27.13858223], [92.03572845, 27.13953972], [92.03586578, 27.14001083], [92.03560638, 27.14049149], [92.03523254, 27.14157295], [92.03394318, 27.14434052], [92.03251648, 27.14723015], [92.0321579, 27.14914703], [92.03166199, 27.15178299], [92.03130341, 27.15405846], [92.02998352, 27.15503311], [92.02947998, 27.15659523], [92.02831268, 27.15864372], [92.02780914, 27.16032219], [92.02755737, 27.16128349], [92.02745056, 27.16283798], [92.02720642, 27.16427612], [92.02709961, 27.16595078], [92.0272522, 27.16714287], [92.02682495, 27.1686039], [92.02771759, 27.17072296], [92.02960968, 27.17201233], [92.03137207, 27.1733017], [92.0343399, 27.17469597], [92.03505707, 27.17661476], [92.03531647, 27.17731094], [92.03748322, 27.17895508], [92.03939819, 27.18143654], [92.03977203, 27.1818924], [92.04007721, 27.18226433], [92.04128265, 27.18236732], [92.04302216, 27.18258286], [92.04438782, 27.18234062], [92.04449463, 27.18232155], [92.04533386, 27.18260002], [92.04624176, 27.18289566], [92.04758453, 27.18323517], [92.04852295, 27.18346214], [92.05065918, 27.18355179], [92.05188751, 27.18461037], [92.05324554, 27.18590546], [92.05406189, 27.18696976], [92.05439758, 27.1877327], [92.05467987, 27.18836021], [92.05587769, 27.19124603], [92.05641174, 27.19194412], [92.05696869, 27.1926651], [92.05900574, 27.19416237], [92.05890656, 27.19582176], [92.05838013, 27.19682884], [92.05841064, 27.19874191], [92.05857849, 27.20041275], [92.05954742, 27.2021904], [92.05970764, 27.20410156], [92.06040955, 27.20552635], [92.06053162, 27.2069664], [92.06056976, 27.20743561], [92.06113434, 27.20898247], [92.06210327, 27.21088028], [92.06304932, 27.21134567], [92.06412506, 27.21192741], [92.06461334, 27.21209145], [92.06529236, 27.21232033], [92.06650543, 27.21325111], [92.06784821, 27.21447563], [92.06895447, 27.21591759], [92.06987, 27.21925735], [92.06977844, 27.22152901], [92.06980133, 27.22296333], [92.07050323, 27.2247467], [92.07093048, 27.22617531], [92.070961, 27.22772789], [92.07097626, 27.22868347], [92.07099152, 27.22975922], [92.07077026, 27.23203278], [92.07118988, 27.2331028], [92.07107544, 27.23453903], [92.07123566, 27.23585129], [92.07084656, 27.23657417], [92.07064819, 27.23801613], [92.06996155, 27.23933601], [92.06905365, 27.24078178], [92.06826782, 27.2421093], [92.06681824, 27.2429657], [92.06584167, 27.24363899], [92.06575775, 27.24369812], [92.06404877, 27.2452755], [92.06313324, 27.24636459], [92.06245422, 27.24704552], [92.06168365, 27.2478199], [92.06090546, 27.24890518], [92.05999756, 27.2508316], [92.05948639, 27.25203323], [92.0580368, 27.2530098], [92.05631256, 27.25399017], [92.05416107, 27.25342369], [92.05216217, 27.25369072], [92.05117035, 27.25399208], [92.04803467, 27.25494385], [92.0464325, 27.25496483], [92.04389954, 27.25535965], [92.04145813, 27.25525284], [92.03853607, 27.25476074], [92.03829193, 27.25594711], [92.03863525, 27.25695038], [92.03924561, 27.25765228], [92.03987885, 27.25866699], [92.04115295, 27.26066399], [92.04145813, 27.26098633], [92.04214478, 27.26172066], [92.04386902, 27.26237106], [92.0453186, 27.26365471], [92.04529572, 27.2664547], [92.04514313, 27.26888657], [92.04708862, 27.26888657], [92.04813385, 27.26896858], [92.04899597, 27.2696228], [92.04901123, 27.27043724], [92.04991913, 27.27042389], [92.05084229, 27.27122307], [92.05174255, 27.27039909], [92.05266571, 27.27119827], [92.05357361, 27.27118492], [92.05448151, 27.27117348], [92.05539703, 27.27116013], [92.05632019, 27.2719593], [92.05722809, 27.27194786], [92.05813599, 27.27193451], [92.05904388, 27.27192116], [92.05995941, 27.27190971], [92.06088257, 27.27270889], [92.06179047, 27.27269554], [92.06271362, 27.27349663], [92.06363678, 27.27429581], [92.06455994, 27.27509689], [92.06549072, 27.27589607], [92.06586456, 27.27622223], [92.06641388, 27.27669716], [92.06732178, 27.27668381], [92.0675354, 27.27667999], [92.06822968, 27.27667046], [92.06913757, 27.2766571], [92.07003784, 27.27583313], [92.070961, 27.27663231], [92.0714798, 27.27708244], [92.07188416, 27.27743149], [92.07279205, 27.27742004], [92.07371521, 27.27821922], [92.07463074, 27.27820587], [92.07553864, 27.27819443], [92.07643127, 27.27736855], [92.07641602, 27.27655411], [92.07696533, 27.27604866], [92.07731628, 27.27572823], [92.07820892, 27.27490234], [92.07910156, 27.27407646], [92.08000183, 27.27325058], [92.08090973, 27.27323914], [92.08180237, 27.27241325], [92.08267975, 27.2723999], [92.08287048, 27.27222824], [92.08361053, 27.27157402], [92.08451843, 27.27156067], [92.08541107, 27.27073479], [92.08540344, 27.26992226], [92.08631134, 27.26990891], [92.08720398, 27.26908302], [92.08879089, 27.26965714], [92.08904266, 27.26987076], [92.08995056, 27.26985741], [92.0908432, 27.26903152], [92.0917511, 27.26901817], [92.09266663, 27.26900482], [92.09357452, 27.26899147], [92.09449768, 27.26979256], [92.09540558, 27.26977921], [92.09630585, 27.26895332], [92.09721375, 27.26893997], [92.09812164, 27.26892662], [92.09901428, 27.26810074], [92.09992981, 27.26808739], [92.10083771, 27.26807404], [92.10174561, 27.26806259], [92.1026535, 27.26804924], [92.1035614, 27.26803589], [92.10447693, 27.26802254], [92.10540009, 27.26882172], [92.10630798, 27.26880836], [92.10723114, 27.26960945], [92.1081543, 27.27040863], [92.10906982, 27.27039528], [92.10997772, 27.27038193], [92.11088562, 27.27037048], [92.11177826, 27.26954269], [92.11269379, 27.26953125], [92.11360168, 27.2695179], [92.11452484, 27.27031708], [92.11543274, 27.27030373], [92.11636353, 27.27110291], [92.11727142, 27.27108955], [92.11817932, 27.27107811], [92.11908722, 27.27106476], [92.11999512, 27.27105141], [92.1209259, 27.27185059], [92.12184906, 27.27264977], [92.12186432, 27.2734623], [92.12278748, 27.27426338], [92.12371063, 27.27506256], [92.12372589, 27.27587509], [92.12374115, 27.27668762], [92.12375641, 27.27750206], [92.12467957, 27.27830124], [92.12469482, 27.27911377], [92.12471008, 27.2799263], [92.12472534, 27.28073883], [92.12475586, 27.2823658], [92.12385559, 27.28319168], [92.12296295, 27.28401756], [92.12297821, 27.28483009], [92.12299347, 27.28564262], [92.12300873, 27.28645706], [92.12211609, 27.28728294], [92.12121582, 27.28810883], [92.12032318, 27.28893471], [92.11943054, 27.28976059], [92.1190033, 27.2901516], [92.11853027, 27.29058647], [92.11763763, 27.29141235], [92.116745, 27.29223824], [92.11582947, 27.29225159], [92.11493683, 27.29307747], [92.11402893, 27.29309082], [92.11313629, 27.2939167], [92.11223602, 27.29474258], [92.11132813, 27.29475594], [92.11043549, 27.29558182], [92.10951996, 27.29559517], [92.10862732, 27.29642105], [92.10773468, 27.29724693], [92.10681915, 27.29726028], [92.10592651, 27.29808617], [92.10503387, 27.29891205], [92.10413361, 27.29973984], [92.10324097, 27.30056572], [92.10234833, 27.3013916], [92.1014328, 27.30140305], [92.1006012, 27.30217552], [92.10054016, 27.30223083], [92.10044098, 27.30223274], [92.09963226, 27.30224228], [92.09872437, 27.30225563], [92.0978241, 27.30308151], [92.0969162, 27.30309486], [92.0960083, 27.30310822], [92.09509277, 27.30312157], [92.09420013, 27.30394745], [92.09329224, 27.3039608], [92.09237671, 27.30397224], [92.09146881, 27.3039856], [92.09056091, 27.30399895], [92.08965302, 27.3040123], [92.08875275, 27.30483818], [92.08786011, 27.30566406], [92.08696747, 27.30648994], [92.08605194, 27.3065033], [92.0851593, 27.30732918], [92.08447266, 27.30796242], [92.08425903, 27.30815506], [92.08336639, 27.30898094], [92.0824585, 27.30899239], [92.08155823, 27.30981827], [92.08066559, 27.31064415], [92.07977295, 27.31147003], [92.07885742, 27.31148338], [92.07796478, 27.31230927], [92.07707214, 27.31313515], [92.0770874, 27.31394768], [92.07618713, 27.31477356], [92.07529449, 27.31559944], [92.07530975, 27.31641197], [92.07440948, 27.31723785], [92.07351685, 27.31806374], [92.0735321, 27.31887817], [92.07263184, 27.31970215], [92.0717392, 27.32052803], [92.07084656, 27.32135391], [92.06994629, 27.32217979], [92.06903839, 27.32219315], [92.06813812, 27.32301903], [92.06724548, 27.32384491], [92.06635284, 27.32467079], [92.0663681, 27.32548332], [92.06546783, 27.3263092], [92.06548309, 27.32712173], [92.06511688, 27.32747269], [92.06506348, 27.32780457], [92.06432343, 27.3311615], [92.06357574, 27.33451843], [92.06362915, 27.3376255], [92.06304932, 27.33949661], [92.06255341, 27.34153557], [92.06178284, 27.34333801], [92.06073761, 27.34502792], [92.05968475, 27.34599876], [92.05876923, 27.34708595], [92.05705261, 27.34877205], [92.05679321, 27.34902763], [92.05342102, 27.35147095], [92.05410767, 27.35201073], [92.05490112, 27.35263634], [92.05171967, 27.35635376], [92.05042267, 27.35796928], [92.04985809, 27.35963631], [92.04811096, 27.35970688], [92.04759979, 27.35972786], [92.04723358, 27.36087227], [92.04769135, 27.36179161], [92.04806519, 27.36253548], [92.04850006, 27.36432266], [92.04839325, 27.36623573], [92.0483017, 27.36838722], [92.04834747, 27.37089729], [92.04839325, 27.37364578], [92.04911804, 27.37686157], [92.04994965, 27.37828445], [92.05049133, 27.37875366], [92.05072784, 27.37898064], [92.05106354, 27.3791256], [92.05146027, 27.37946701], [92.05221558, 27.37990379], [92.05387878, 27.3816452], [92.05477905, 27.38275909], [92.05496979, 27.38598251], [92.05487823, 27.38849449], [92.05504608, 27.39028358], [92.05508423, 27.39231491], [92.05523682, 27.39350891], [92.05513763, 27.39542198], [92.05577087, 27.39811897], [92.05825806, 27.39998055], [92.05628204, 27.40054131], [92.05511475, 27.40187454], [92.05432892, 27.40284348], [92.05327606, 27.40393257], [92.05236053, 27.40514183], [92.05037689, 27.40636444], [92.04931641, 27.40721512], [92.04773712, 27.40891075], [92.04628754, 27.41000748], [92.04497528, 27.4116993], [92.04364014, 27.41410446], [92.04347229, 27.41570854], [92.04270172, 27.41706085], [92.04123688, 27.41963768], [92.04180908, 27.42214012], [92.04375458, 27.42415237], [92.04386139, 27.42426109], [92.04406738, 27.42695427], [92.04335785, 27.42811394], [92.04299927, 27.42869568], [92.04263306, 27.43116951], [92.04251862, 27.43192863], [92.04151154, 27.43528938], [92.03894043, 27.43751144], [92.03874207, 27.43807793], [92.03795624, 27.43904495], [92.03569031, 27.43991089], [92.03408813, 27.43993378], [92.03174591, 27.43992043], [92.02902985, 27.44031525], [92.02684021, 27.44034576], [92.02503967, 27.44340706], [92.02372742, 27.44485855], [92.02266693, 27.44582939], [92.02255249, 27.44678688], [92.02203369, 27.44775009], [92.02152252, 27.44919205], [92.02114105, 27.45063019], [92.02102661, 27.45146942], [92.02080536, 27.45410156], [92.0212326, 27.45588875], [92.02140808, 27.45803642], [92.0218277, 27.45898628], [92.02145386, 27.46066475], [92.02122498, 27.46293831], [92.02113342, 27.46533012], [92.02079773, 27.46915817], [92.02017975, 27.47227478], [92.02007294, 27.47371101], [92.01965332, 27.47770309], [92.01916504, 27.47913933], [92.01876831, 27.48032379], [92.01734161, 27.48013878], [92.01670074, 27.48005486], [92.01403046, 27.47902489], [92.01071167, 27.47901154], [92.0090332, 27.47852325], [92.00153351, 27.47862434], [92.00097656, 27.47866631], [91.99765015, 27.47891808], [91.99700165, 27.47890091], [91.99650574, 27.47808647], [91.99582672, 27.47805405], [91.99489594, 27.4779129], [91.99377441, 27.47688103], [91.99330902, 27.47631454], [91.99272919, 27.47574043], [91.99227905, 27.47529793], [91.99198151, 27.4747982], [91.99183655, 27.4743824], [91.99176025, 27.47353172], [91.99183655, 27.47217941], [91.99168396, 27.47172928], [91.99150085, 27.47129631], [91.99076843, 27.46969604], [91.98980713, 27.46819687], [91.98884583, 27.4670639], [91.98828125, 27.46663094], [91.98705292, 27.46591759], [91.98577118, 27.46618652], [91.9853363, 27.46620369], [91.98492432, 27.46612167], [91.98439789, 27.46568871], [91.98394775, 27.46547318], [91.98339081, 27.46537399], [91.98282623, 27.4651413], [91.98260498, 27.4649086], [91.9821701, 27.46444321], [91.98181152, 27.46415901], [91.98113251, 27.4640274], [91.98051453, 27.46382904], [91.97982025, 27.46352959], [91.97899628, 27.46299744], [91.97787476, 27.46248245], [91.97742462, 27.46286774], [91.97746277, 27.46321869], [91.97721863, 27.46351814], [91.97673035, 27.4638195], [91.97584534, 27.46422195], [91.97483063, 27.46469116], [91.97437286, 27.46499252], [91.97406769, 27.46519279], [91.97354126, 27.46547699], [91.97292328, 27.46567917], [91.97238159, 27.46604729], [91.97180176, 27.46629715], [91.97126007, 27.46574783], [91.97101593, 27.46548843], [91.97018433, 27.46459961], [91.96941376, 27.46386719], [91.96858978, 27.46345139], [91.96734619, 27.46318626], [91.96604919, 27.46288872], [91.96434784, 27.46279144], [91.96344757, 27.4627285], [91.96237183, 27.46151161], [91.96122742, 27.46042824], [91.96073914, 27.46018028], [91.96008301, 27.45993233], [91.95954132, 27.45988274], [91.95793915, 27.46011925], [91.95706177, 27.4602375], [91.95556641, 27.46040726], [91.95487213, 27.46035767], [91.954216, 27.46014214], [91.95352936, 27.45972633], [91.953125, 27.45957756], [91.95155334, 27.45969582], [91.94936371, 27.46001625], [91.94871521, 27.46020126], [91.94777679, 27.46073914], [91.94769287, 27.46081161], [91.94701385, 27.46138954], [91.94641876, 27.46194077], [91.94603729, 27.46179199], [91.94561005, 27.46139336], [91.94496918, 27.46089363], [91.94471741, 27.46074867], [91.94430542, 27.46051025], [91.94300079, 27.459795], [91.94252777, 27.45989609], [91.94213867, 27.46016312], [91.94142151, 27.46067238], [91.94103241, 27.46094894], [91.94043732, 27.46133423], [91.93936157, 27.46190262], [91.9389267, 27.46208763], [91.93824005, 27.46247292], [91.93780518, 27.46285629], [91.93737793, 27.46349144], [91.93687439, 27.46436119], [91.93624878, 27.46497917], [91.93566895, 27.46534729], [91.93531036, 27.46568108], [91.93507385, 27.46619797], [91.93445587, 27.46651649], [91.93405914, 27.46590042], [91.93367004, 27.46549988], [91.93278503, 27.46501732], [91.93229675, 27.46491814], [91.93180084, 27.46499062], [91.9313736, 27.46505356], [91.93071747, 27.46517181], [91.93022919, 27.46549034], [91.92959595, 27.46604156], [91.92931366, 27.46650887], [91.92900085, 27.46695328], [91.9288559, 27.4674778], [91.92867279, 27.46829414], [91.92848206, 27.46876144], [91.9281311, 27.46926308], [91.92700195, 27.4703331], [91.92613983, 27.47136688], [91.92585754, 27.47185326], [91.92514801, 27.47253609], [91.9243927, 27.47335625], [91.92362976, 27.47429085], [91.92333221, 27.47527695], [91.92301178, 27.47512627], [91.92289734, 27.47480965], [91.92272186, 27.47449303], [91.92219543, 27.4739933], [91.92134857, 27.47347832], [91.92063904, 27.47326279], [91.91989136, 27.47312927], [91.91923523, 27.47296524], [91.91841888, 27.47289848], [91.91692352, 27.47281837], [91.91629028, 27.47263527], [91.91557312, 27.47228622], [91.91503143, 27.47232056], [91.9145813, 27.47238731], [91.9141922, 27.47242165], [91.91383362, 27.47247124], [91.91294861, 27.47250748], [91.91201019, 27.47195816], [91.91135406, 27.47165871], [91.91094208, 27.47165871], [91.91053009, 27.4717598], [91.90977478, 27.47202873], [91.9080658, 27.47269821], [91.90769958, 27.47264862], [91.90579224, 27.4719677], [91.90459442, 27.47171974], [91.90268707, 27.47132111], [91.90231323, 27.47138786], [91.90184021, 27.47150612], [91.90126038, 27.47152328], [91.90029907, 27.47125816], [91.89943695, 27.47104263], [91.89833832, 27.47094345], [91.89704132, 27.47091293], [91.89595795, 27.47099686], [91.89545441, 27.47113228], [91.89489746, 27.47138214], [91.8932724, 27.47233582], [91.89149475, 27.47305489], [91.88983917, 27.47365761], [91.88790894, 27.47459602], [91.88671112, 27.475214], [91.88611603, 27.47519875], [91.88561249, 27.47468185], [91.88508606, 27.47456741], [91.88469696, 27.47470093], [91.88363647, 27.4749527], [91.88214111, 27.47512054], [91.88148499, 27.47510529], [91.88092804, 27.47490501], [91.87971497, 27.47465706], [91.87864685, 27.47449112], [91.87814331, 27.47419167], [91.87769318, 27.47374153], [91.87724304, 27.47322464], [91.87696075, 27.47293091], [91.87631989, 27.47225952], [91.87586975, 27.47177505], [91.875, 27.47105789], [91.87451935, 27.47084236], [91.87329865, 27.47052765], [91.87254333, 27.47052956], [91.87201691, 27.47061348], [91.87136078, 27.47076416], [91.87078094, 27.47103119], [91.87044525, 27.47124863], [91.86999512, 27.4716835], [91.86940002, 27.4723835], [91.86910248, 27.47301865], [91.86889648, 27.47340393], [91.86877441, 27.47393608], [91.86871338, 27.47445488], [91.86873627, 27.47502136], [91.86875153, 27.47597122], [91.8686676, 27.47640991], [91.86857605, 27.47690582], [91.8684082, 27.47767448], [91.8680191, 27.47847557], [91.86751556, 27.47945976], [91.86714935, 27.47987747], [91.86619568, 27.48076248], [91.865448, 27.48138046], [91.86434174, 27.48208427], [91.86299896, 27.48290253], [91.86214447, 27.48323631], [91.8612442, 27.48343849], [91.86064911, 27.48343849], [91.85955811, 27.4832077], [91.85768127, 27.4825573], [91.85694885, 27.48228264], [91.85679626, 27.48222542], [91.85614014, 27.48204231], [91.85558319, 27.48199272], [91.85520935, 27.48197746], [91.85477448, 27.48212814], [91.85428619, 27.48237419], [91.85370636, 27.48266411], [91.85322571, 27.48296356], [91.85208893, 27.48384857], [91.8509903, 27.48465157], [91.85014343, 27.48521996], [91.84922791, 27.48578835], [91.84844208, 27.4861393], [91.84812164, 27.48625565], [91.84747314, 27.48602295], [91.84729767, 27.48568916], [91.84713745, 27.48538971], [91.84699249, 27.48453903], [91.8467865, 27.48428917], [91.84646606, 27.48397255], [91.84609222, 27.48377228], [91.84560394, 27.4833889], [91.84534454, 27.48300552], [91.84495544, 27.48223877], [91.84473419, 27.48168755], [91.84460449, 27.48128891], [91.84413147, 27.48060417], [91.84370422, 27.48005486], [91.84337616, 27.47957039], [91.84326172, 27.47920418], [91.84313202, 27.47865295], [91.84292603, 27.47810936], [91.84283447, 27.47787094], [91.84227753, 27.47722054], [91.84133911, 27.47636986], [91.84083557, 27.47605324], [91.84010315, 27.47572136], [91.83944702, 27.47537041], [91.83892822, 27.47505569], [91.83843994, 27.47463799], [91.83818817, 27.47437286], [91.83699036, 27.47353935], [91.83640289, 27.47299004], [91.83584595, 27.47232246], [91.83509064, 27.47185707], [91.83437347, 27.47154045], [91.83366394, 27.47135735], [91.83267212, 27.47109032], [91.83210754, 27.47092438], [91.8314743, 27.47065926], [91.83087158, 27.46997452], [91.83042145, 27.46925735], [91.82987976, 27.46870804], [91.82935333, 27.46839142], [91.82867432, 27.46817589], [91.82781982, 27.46806717], [91.8272171, 27.46800613], [91.8267746, 27.4679718], [91.82636261, 27.46788216], [91.82579041, 27.46767235], [91.82528687, 27.46767998], [91.82489777, 27.46743393], [91.8239212, 27.46792984], [91.82327271, 27.46849823], [91.82273102, 27.46866608], [91.82209778, 27.46886635], [91.82170105, 27.46910095], [91.82134247, 27.46941757], [91.82123566, 27.46961021], [91.82112122, 27.46981812], [91.82089996, 27.47028542], [91.82065582, 27.47083473], [91.82033539, 27.47118568], [91.81991577, 27.47122002], [91.81942749, 27.47127151], [91.81832123, 27.47145462], [91.81785583, 27.4716568], [91.81729889, 27.47185516], [91.81656647, 27.47204018], [91.81571198, 27.47239113], [91.81468201, 27.47300911], [91.81380463, 27.47359467], [91.8130722, 27.47367859], [91.81243896, 27.47359467], [91.81182098, 27.47341347], [91.81092834, 27.4731636], [91.81027985, 27.47296333], [91.80975342, 27.47289848], [91.80945587, 27.47309875], [91.8090744, 27.47323227], [91.8086853, 27.47306442], [91.80782318, 27.47274971], [91.80701447, 27.47266579], [91.80617523, 27.47266579], [91.80541992, 27.47273445], [91.80461121, 27.47286797], [91.80388641, 27.47280121], [91.80339813, 27.47265244], [91.80303955, 27.47240257], [91.80257416, 27.47203636], [91.80217743, 27.471735], [91.80141449, 27.47163582], [91.80086517, 27.47168732], [91.80039978, 27.47177124], [91.79964447, 27.47203827], [91.79889679, 27.47243881], [91.79790497, 27.47307396], [91.79754639, 27.4729557], [91.79717255, 27.47265816], [91.79685211, 27.47227478], [91.79656982, 27.47177315], [91.79623413, 27.47127342], [91.79576874, 27.47070694], [91.79517365, 27.47027588], [91.79405212, 27.46978951], [91.79291534, 27.46962357], [91.79231262, 27.46967506], [91.79195404, 27.46975136], [91.79160309, 27.46982574], [91.79100037, 27.46986008], [91.79057312, 27.4698925], [91.78990173, 27.46982574], [91.78926086, 27.46974373], [91.78862, 27.46962738], [91.78801727, 27.4695282], [91.78764343, 27.46937752], [91.78730774, 27.46914482], [91.78710175, 27.46887779], [91.78670502, 27.46866035], [91.78556824, 27.46847725], [91.78505707, 27.46832848], [91.78472137, 27.4681282], [91.78443146, 27.46787643], [91.78420258, 27.46767807], [91.78343201, 27.467062], [91.78310394, 27.46676064], [91.78257751, 27.46651077], [91.78179169, 27.46621132], [91.78113556, 27.46604538], [91.78025818, 27.46574593], [91.77952576, 27.46554565], [91.7790451, 27.46539497], [91.77831268, 27.46511269], [91.77772522, 27.46487999], [91.77690125, 27.46484756], [91.77574158, 27.46503067], [91.77557373, 27.46507263], [91.77458191, 27.46531487], [91.77352905, 27.46541595], [91.77298737, 27.46538353], [91.77189636, 27.46518517], [91.77095795, 27.46500969], [91.77063751, 27.46495056], [91.76925659, 27.46485138], [91.7673111, 27.46489716], [91.76682281, 27.46509933], [91.76667023, 27.46538162], [91.76642609, 27.46572113], [91.76641083, 27.46579933], [91.76628113, 27.46642113], [91.76625824, 27.46698952], [91.76622772, 27.46797371], [91.76643372, 27.46912384], [91.76682281, 27.47032547], [91.76721191, 27.47172546], [91.76750946, 27.47272682], [91.76758575, 27.47339439], [91.76737976, 27.47379494], [91.76670074, 27.47421074], [91.76621246, 27.47444534], [91.76560974, 27.4745121], [91.76419067, 27.47458076], [91.76331329, 27.47473145], [91.76187897, 27.47496414], [91.75967407, 27.47518349], [91.75759125, 27.47541809], [91.75623322, 27.47551918], [91.75457001, 27.47566986], [91.75335693, 27.47600365], [91.75307465, 27.47628784], [91.75254822, 27.47667122], [91.75205994, 27.47667122], [91.75163269, 27.47647095], [91.75123596, 27.47627068], [91.75088501, 27.47597122], [91.75043488, 27.47543716], [91.75006866, 27.47492027], [91.74945068, 27.47421455], [91.74920654, 27.47393608], [91.74851227, 27.47322083], [91.74808502, 27.47285271], [91.74761963, 27.4724865], [91.7472229, 27.47230339], [91.74655151, 27.47226334], [91.74544525, 27.47186089], [91.74356079, 27.47128677], [91.74060059, 27.47084427], [91.73845673, 27.47027206], [91.73522186, 27.46947289], [91.73267365, 27.46938324], [91.7314682, 27.46892166], [91.72945404, 27.46894455], [91.72866058, 27.46931267], [91.72719574, 27.46980667], [91.7260437, 27.47030067], [91.72432709, 27.47103691], [91.7196579, 27.47216606], [91.71712494, 27.47315216], [91.71437073, 27.47472191], [91.71472168, 27.47631836], [91.71542358, 27.47873688], [91.71675873, 27.48357964], [91.71703339, 27.48452377], [91.71723938, 27.48517227], [91.71496582, 27.48816109], [91.71318054, 27.49357224], [91.71240234, 27.4944706], [91.71022797, 27.49621391], [91.7071228, 27.49707985], [91.70560455, 27.49774933], [91.70402527, 27.49877357], [91.70098877, 27.49993324], [91.70015717, 27.50100327], [91.69831848, 27.50208855], [91.69773865, 27.50333977], [91.69749451, 27.50458336], [91.69664001, 27.50542259], [91.69472504, 27.5059185], [91.69312286, 27.5055809], [91.69171906, 27.50453186], [91.69078827, 27.5045433], [91.68865967, 27.50391769], [91.68751526, 27.50292397], [91.68727875, 27.50260353], [91.68622589, 27.50116348], [91.68527985, 27.49957848], [91.68553162, 27.49856949], [91.68504333, 27.49721336], [91.68402863, 27.49568748], [91.68302155, 27.49510765], [91.68182373, 27.49464798], [91.68082428, 27.4946003], [91.67856598, 27.49409294], [91.67709351, 27.49310493], [91.67562866, 27.49306107], [91.67456818, 27.49307442], [91.67284393, 27.49315262], [91.67190552, 27.49310684], [91.67092133, 27.49299812], [91.67018127, 27.49235535], [91.66931152, 27.49212837], [91.66905975, 27.491642], [91.66836548, 27.49065971], [91.66732025, 27.49071884], [91.66703796, 27.4907341], [91.66668701, 27.49030685], [91.66612244, 27.48962212], [91.66379547, 27.48800659], [91.66343689, 27.48672676], [91.66251373, 27.48668671], [91.66082001, 27.48511314], [91.65978241, 27.48507309], [91.65873718, 27.48436737], [91.65628052, 27.48435783], [91.65171051, 27.48434258], [91.65155029, 27.48538017], [91.65116119, 27.48514175], [91.6510849, 27.48621559], [91.65072632, 27.48758888], [91.65077209, 27.48853302], [91.65053558, 27.48897743], [91.64990997, 27.4898777], [91.64952087, 27.49040985], [91.64911652, 27.49106407], [91.64890289, 27.49132538], [91.64865875, 27.49154282], [91.64851379, 27.49194336], [91.64841461, 27.49236298], [91.64811707, 27.49401665], [91.64797974, 27.49475479], [91.6479187, 27.49526978], [91.64783478, 27.49573517], [91.64746094, 27.49609947], [91.64727783, 27.49653625], [91.64700317, 27.49721336], [91.64696503, 27.49801254], [91.64713287, 27.49853516], [91.64691162, 27.49955177], [91.64670563, 27.50050163], [91.6452179, 27.50140762], [91.64385986, 27.50275803], [91.64232635, 27.50421333], [91.6403656, 27.50587845], [91.63897705, 27.50655365], [91.63768768, 27.50780296], [91.63634491, 27.50938606], [91.6335144, 27.51029778], [91.63179779, 27.5112648], [91.62968445, 27.51229477], [91.62763214, 27.51285172], [91.62591553, 27.51358032], [91.62432861, 27.51395416], [91.62360382, 27.51431656], [91.62304688, 27.5177002], [91.62249756, 27.51937294], [91.62182617, 27.52050972], [91.62075043, 27.5220089], [91.61962128, 27.52346039], [91.6190033, 27.52485275], [91.61850739, 27.52634621], [91.61755371, 27.52784729], [91.61625671, 27.52986336], [91.61472321, 27.53157425], [91.61415863, 27.53255463], [91.61430359, 27.53455544], [91.61397552, 27.53609848], [91.61367035, 27.53846359], [91.61334229, 27.54005814], [91.61307526, 27.54134369], [91.61252594, 27.54335213], [91.61126709, 27.54418755], [91.60990906, 27.54399872], [91.60837555, 27.54324532], [91.60653687, 27.54310417], [91.60601807, 27.54306412], [91.60428619, 27.5428791], [91.60229492, 27.54258347], [91.59966278, 27.54195404], [91.5973587, 27.54187584], [91.59534454, 27.54254723], [91.59394836, 27.54354858], [91.59357452, 27.54408836], [91.59296417, 27.54498482], [91.59218597, 27.54642105], [91.59150696, 27.54794693], [91.58972931, 27.54992867], [91.58826447, 27.55244064], [91.58638763, 27.55415726], [91.58569336, 27.5545063], [91.58439636, 27.55515862], [91.58312225, 27.55704498], [91.58314514, 27.55883026], [91.58318329, 27.5591774], [91.58339691, 27.5610199], [91.58358765, 27.56261063], [91.58377075, 27.56353188], [91.58367157, 27.56430435], [91.58362579, 27.56512451], [91.58334351, 27.56623077], [91.58196259, 27.56731606], [91.58028412, 27.56920815], [91.57749939, 27.57039642], [91.5758667, 27.57111168], [91.57501221, 27.57189178], [91.57387543, 27.57287979], [91.57269287, 27.57453537], [91.57218933, 27.57592583], [91.57170105, 27.57875443], [91.57062531, 27.58054924], [91.56916046, 27.58196259], [91.5668869, 27.58414459], [91.56691742, 27.58645439], [91.56755829, 27.58826447], [91.56827545, 27.5900898], [91.56890869, 27.59136581], [91.56904602, 27.59165001], [91.57012177, 27.59314346], [91.5705719, 27.59474945], [91.57142639, 27.59590149], [91.57270813, 27.59737587], [91.57444763, 27.59797478], [91.57572174, 27.59873009], [91.57681274, 27.59958649], [91.57759094, 27.60019875], [91.57904816, 27.60131264], [91.5809021, 27.60231972], [91.58213806, 27.60456467], [91.58309174, 27.60686493], [91.58426666, 27.60823822], [91.58438873, 27.60890388], [91.58405304, 27.60957527], [91.58319855, 27.61035347], [91.58211517, 27.61087799], [91.58067322, 27.61264229], [91.57987976, 27.61336517], [91.57810211, 27.61481094], [91.57691956, 27.61651802], [91.57543945, 27.61831856], [91.57405853, 27.61985016], [91.57256317, 27.6200428], [91.57077789, 27.62122154], [91.56889343, 27.62249184], [91.56661224, 27.62447739], [91.56544495, 27.62716675], [91.56460571, 27.62882614], [91.56319427, 27.63074112], [91.56292725, 27.63264275], [91.56319427, 27.63530922], [91.56327057, 27.6360836], [91.56340027, 27.63746262], [91.56359863, 27.63941193], [91.56443787, 27.64196968], [91.56536865, 27.6427803], [91.56607819, 27.64400482], [91.56716156, 27.64686394], [91.5684967, 27.6484127], [91.5697403, 27.64992905], [91.57062531, 27.65156937], [91.57144928, 27.65336037], [91.57196045, 27.65535736], [91.57250977, 27.6572628], [91.57305145, 27.65868568], [91.57382965, 27.66099167], [91.57467651, 27.66172409], [91.5761795, 27.66206741], [91.57762909, 27.66266823], [91.57906342, 27.66280556], [91.58005524, 27.66289902], [91.58161163, 27.66313934], [91.58335876, 27.66419792], [91.58521271, 27.66494751], [91.5875473, 27.66704941], [91.58862305, 27.66769028], [91.58952332, 27.66823769], [91.59216309, 27.67002106], [91.59394073, 27.67090988], [91.59477234, 27.67254257], [91.59525299, 27.67387199], [91.59590149, 27.67509842], [91.59637451, 27.67678261], [91.59669495, 27.67862892], [91.59770203, 27.68040657], [91.59922791, 27.68139458], [91.60082245, 27.68226814], [91.60269165, 27.6826725], [91.60513306, 27.68413353], [91.60526276, 27.68505669], [91.60612488, 27.68718147], [91.60708618, 27.68910789], [91.60809326, 27.68979836], [91.60960388, 27.69065475], [91.61135101, 27.69161224], [91.61325836, 27.69205284], [91.61586761, 27.69294739], [91.61800385, 27.69333458], [91.61997986, 27.69408226], [91.62177277, 27.69462776], [91.62420654, 27.69547272], [91.62572479, 27.69684219], [91.62763977, 27.69855881], [91.62870026, 27.69932365], [91.62916565, 27.70038414], [91.62960815, 27.70234108], [91.62997437, 27.7038784], [91.62994385, 27.7056694], [91.63026428, 27.7075386], [91.63039398, 27.70923042], [91.63121033, 27.71029282], [91.6315155, 27.71082497], [91.63202667, 27.71144295], [91.63244629, 27.71286583], [91.6330719, 27.71482086], [91.63318634, 27.71835136], [91.63330841, 27.71959877], [91.63412476, 27.72139168], [91.63433838, 27.72292328], [91.63488007, 27.72461128], [91.63566589, 27.72691154], [91.63637543, 27.72849655], [91.63786316, 27.7300415], [91.63871002, 27.73151016], [91.63936615, 27.73314095], [91.63957977, 27.73482513], [91.63941956, 27.7358017], [91.63886261, 27.73719406], [91.63784027, 27.73843765], [91.63705444, 27.73972893], [91.63575745, 27.74154854], [91.63470459, 27.74488831], [91.63536835, 27.74698448], [91.63637543, 27.74902725], [91.63737488, 27.75019646], [91.63911438, 27.75094604], [91.64022827, 27.75190926], [91.64116669, 27.75234795], [91.64150238, 27.75261497], [91.64186096, 27.75312424], [91.64169312, 27.75384331], [91.64212036, 27.75548172], [91.64289856, 27.75711441], [91.64332581, 27.75905991], [91.64393616, 27.76110649], [91.64447021, 27.76239967], [91.64511108, 27.76364708], [91.64555359, 27.76534843], [91.64592743, 27.76744843], [91.64588928, 27.76868057], [91.64554596, 27.76924896], [91.64401245, 27.77054977], [91.64205933, 27.77129173], [91.63991547, 27.77342987], [91.63854218, 27.7754364], [91.63804626, 27.77744293], [91.63758087, 27.77863121], [91.63790894, 27.78050041], [91.63794708, 27.78317451], [91.6386795, 27.78518677], [91.63800812, 27.78688812], [91.63745117, 27.78838158], [91.63752747, 27.78986931], [91.63755035, 27.79151154], [91.63737488, 27.79245567], [91.63708496, 27.79343987], [91.63659668, 27.79424858], [91.63631439, 27.79532242], [91.63603973, 27.79737663], [91.63543701, 27.79969215], [91.63569641, 27.80150032], [91.63540649, 27.80220032], [91.63511658, 27.80291557], [91.63482666, 27.80363274], [91.63433075, 27.80426216], [91.63314056, 27.80534554], [91.63214111, 27.80562401], [91.63095093, 27.80626297], [91.6301651, 27.80725288], [91.62858582, 27.80932045], [91.62770081, 27.81048965], [91.62690735, 27.81156921], [91.62541199, 27.81185341], [91.62501526, 27.81239319], [91.62322235, 27.81339264], [91.62113953, 27.81466484], [91.61924744, 27.81593513], [91.61787415, 27.81791115], [91.61669922, 27.8199749], [91.61490631, 27.8210659], [91.6131134, 27.82206535], [91.61181641, 27.82270432], [91.61062622, 27.82352066], [91.60922241, 27.82371521], [91.60752106, 27.82373428], [91.60540771, 27.82331085], [91.60329437, 27.82288742], [91.60097504, 27.82210922], [91.60005951, 27.8212986], [91.59918976, 27.82063675], [91.59864044, 27.82022095], [91.59741974, 27.81956673], [91.59591675, 27.81868553], [91.59490967, 27.8183403], [91.59290314, 27.81836319], [91.59018707, 27.81821251], [91.58737946, 27.817976], [91.58605194, 27.81647491], [91.58451843, 27.81443977], [91.58229828, 27.8133049], [91.57978821, 27.81306458], [91.5770874, 27.81336021], [91.57665253, 27.81359291], [91.57501221, 27.81447029], [91.57379913, 27.81535721], [91.57250977, 27.81653023], [91.57135773, 27.81743431], [91.57016754, 27.8188343], [91.56891632, 27.82048988], [91.56835175, 27.82141876], [91.56761932, 27.82260704], [91.5668869, 27.82415581], [91.56620789, 27.82516098], [91.56522369, 27.82659721], [91.5644455, 27.82812309], [91.56295776, 27.8294754], [91.56237793, 27.83099747], [91.56199646, 27.83296394], [91.56142426, 27.83493233], [91.5611496, 27.83671951], [91.56096649, 27.83796883], [91.5599823, 27.83958435], [91.55918884, 27.84030724], [91.55860901, 27.84156227], [91.55770874, 27.84183884], [91.55701447, 27.84282684], [91.55574799, 27.84533691], [91.55540466, 27.84827423], [91.55482483, 27.84994507], [91.55541229, 27.85075951], [91.55739594, 27.85233116], [91.55808258, 27.85242844], [91.55941772, 27.85261536], [91.56092834, 27.85316467], [91.56295013, 27.85246086], [91.56305695, 27.85242462], [91.56369019, 27.85236549], [91.56449127, 27.85199738], [91.56580353, 27.85070038], [91.56660461, 27.85033226], [91.56855011, 27.84892654], [91.56952667, 27.84850502], [91.57015991, 27.8485508], [91.57068634, 27.84900665], [91.5712204, 27.84951401], [91.57209778, 27.85073662], [91.57266998, 27.85185242], [91.57294464, 27.85354996], [91.57350922, 27.85511208], [91.57377625, 27.85667229], [91.57433319, 27.85876083], [91.57488251, 27.86037827], [91.57595062, 27.86183548], [91.57674408, 27.86279678], [91.57776642, 27.86310005], [91.57966614, 27.86327553], [91.58264923, 27.86279678], [91.58519745, 27.86120605], [91.58690643, 27.86028099], [91.58815765, 27.8591423], [91.58851624, 27.85869408], [91.58908844, 27.85797691], [91.58985138, 27.85709381], [91.59051514, 27.85664749], [91.59166718, 27.85635376], [91.59244537, 27.85643959], [91.59356689, 27.85624123], [91.59462738, 27.85660362], [91.5956192, 27.85767937], [91.59655762, 27.85877991], [91.59793854, 27.85969353], [91.59815216, 27.85990906], [91.59928131, 27.85930824], [91.6073761, 27.85400009], [91.61492157, 27.85689163], [91.62160492, 27.85769272], [91.62658691, 27.85582924], [91.62725067, 27.85557938], [91.6318512, 27.85505867], [91.63776398, 27.85450935], [91.64185333, 27.85412979], [91.65406036, 27.85706139], [91.66195679, 27.85824013], [91.66932678, 27.85671043], [91.67959595, 27.8441391], [91.68952942, 27.82913971], [91.69412231, 27.8221302], [91.7022171, 27.81682014], [91.70957184, 27.81328964], [91.72115326, 27.81049919], [91.74627686, 27.80335045], [91.75813293, 27.80129814], [91.77112579, 27.80124092], [91.77870178, 27.80306053], [91.78859711, 27.80463982], [91.79907227, 27.80822182], [91.80412292, 27.80888939], [91.81051636, 27.80298996], [91.8152771, 27.80337906], [91.82421112, 27.81035042], [91.82794952, 27.80755043], [91.8289032, 27.79667091], [91.83136749, 27.78895187], [91.83348846, 27.77988815], [91.84519958, 27.77565956], [91.84886932, 27.76824951], [91.85119629, 27.76506042], [91.8529129, 27.75933075], [91.85759735, 27.7422905], [91.86052704, 27.73693275], [91.87043762, 27.73446083], [91.87330627, 27.73047066], [91.8757782, 27.72600937], [91.87864685, 27.7218399], [91.88844299, 27.72424126], [91.90225983, 27.72706985], [91.90281677, 27.72700119], [91.9083786, 27.72631073], [91.91500854, 27.71816063], [91.91876221, 27.71510124], [91.934021, 27.72156906], [91.94506073, 27.7286911], [91.94659424, 27.73217773], [91.94982147, 27.73953056], [91.95558929, 27.75066948], [91.96105957, 27.75097084], [91.96582794, 27.75144005], [91.9728775, 27.75990105], [91.97894287, 27.76473045], [91.9838562, 27.76999092], [91.99497223, 27.76841927], [92.00028992, 27.76746941], [92.01074219, 27.76473045], [92.03777313, 27.75720024], [92.04863739, 27.75699043], [92.05539703, 27.75913048], [92.06762695, 27.76786995], [92.08457184, 27.77977943], [92.09922028, 27.79338074], [92.11995697, 27.81060028], [92.13889313, 27.82446289], [92.15609741, 27.83702087], [92.17088318, 27.84291267], [92.18934631, 27.85205078], [92.20028687, 27.85707283], [92.21039581, 27.85898972], [92.23419189, 27.86264992], [92.23680878, 27.86283875], [92.24627686, 27.86351967], [92.25515747, 27.86216927], [92.26402283, 27.85793114], [92.26737976, 27.85393906], [92.27110291, 27.84464264], [92.27741241, 27.82518959], [92.28469086, 27.80755997], [92.30738831, 27.77923965], [92.31595612, 27.7782402], [92.32892609, 27.78354836], [92.35028076, 27.79066086], [92.36424255, 27.79363823], [92.36962891, 27.79330254], [92.37470245, 27.79367065], [92.37983704, 27.79501915], [92.38295746, 27.81557083], [92.39797974, 27.82047081], [92.40686035, 27.82208824], [92.41385651, 27.82304001], [92.42736816, 27.81200981], [92.44380951, 27.80078125], [92.45493317, 27.80326271], [92.45948792, 27.80758095], [92.46703339, 27.81521988], [92.47672272, 27.82152939], [92.48455811, 27.82863998], [92.49250793, 27.8368206], [92.50132751, 27.84150124], [92.51509094, 27.8402195], [92.52636719, 27.83113098], [92.53447723, 27.82433128], [92.54389954, 27.81747055], [92.55425262, 27.81829834], [92.56069183, 27.82104111], [92.56529999, 27.82735062], [92.57624054, 27.84181023], [92.58574677, 27.85687065], [92.60507202, 27.87750816], [92.62036133, 27.88446808], [92.6315918, 27.88729095], [92.65157318, 27.89297104], [92.66921234, 27.90013123], [92.67415619, 27.90600014], [92.68636322, 27.91948128], [92.7012558, 27.93380928], [92.71385193, 27.94927979], [92.72979736, 27.97192001], [92.73316193, 27.97793007], [92.73948669, 27.9894104], [92.73352051, 27.99570847], [92.72779083, 28.0014801], [92.72208405, 28.01447487], [92.72126007, 28.01634026], [92.70954132, 28.03327942], [92.70246887, 28.04084015], [92.69542694, 28.04837036], [92.68125153, 28.05857849], [92.67964935, 28.0589447], [92.66293335, 28.06277084], [92.66116333, 28.06770134], [92.66725922, 28.07826805], [92.67311859, 28.09670067], [92.67763519, 28.11037445], [92.68016052, 28.11800957], [92.68490601, 28.12342453], [92.68698883, 28.12579918], [92.69415283, 28.12982559], [92.69576263, 28.13072968], [92.70458221, 28.13656807], [92.72090149, 28.14497948], [92.73655701, 28.15155029], [92.737854, 28.15246582], [92.74424744, 28.15697289], [92.7583313, 28.16690063], [92.75953674, 28.16772461], [92.78302765, 28.18374062], [92.79963684, 28.20223045], [92.80754852, 28.20407867], [92.81617737, 28.2016201], [92.81932068, 28.19741058], [92.81768036, 28.18431091], [92.81861877, 28.18159676], [92.82126617, 28.17391968], [92.82646942, 28.17203522], [92.83010101, 28.17295647], [92.83937836, 28.17920494], [92.83960724, 28.17935944], [92.84729004, 28.18282127], [92.8526001, 28.18523216], [92.87275696, 28.19438934], [92.89525604, 28.20461082], [92.90532684, 28.21524048], [92.91294861, 28.23501968], [92.92288971, 28.24258041], [92.92771912, 28.24413872], [92.93347168, 28.24599075], [92.94172668, 28.2486496], [92.95552063, 28.25832939], [92.96452332, 28.2618103], [92.97447205, 28.25962067], [92.98596191, 28.25131035], [92.98686981, 28.24249077], [92.98999023, 28.23442268], [92.99465942, 28.23026085], [93.00035858, 28.23079109], [93.00994873, 28.23987007], [93.02033997, 28.25229836], [93.03378296, 28.26313019], [93.03289032, 28.26683044], [93.02565765, 28.28664017], [93.02393341, 28.29276657], [93.02262115, 28.29740524], [93.02191162, 28.29993057], [93.02366638, 28.30319977], [93.02497864, 28.30327606], [93.03224182, 28.30369949], [93.04592133, 28.30249977], [93.04624939, 28.30247116], [93.06167603, 28.30693054], [93.06266022, 28.30715179], [93.06916809, 28.30861473], [93.07203674, 28.30925941], [93.08711243, 28.30622101], [93.09535217, 28.30707932], [93.11068726, 28.31479073], [93.11213684, 28.31552124], [93.12478638, 28.32679939], [93.12906647, 28.3264904], [93.13646698, 28.32489014], [93.15496826, 28.31848145], [93.17978668, 28.31721115], [93.1937561, 28.31804085], [93.20693207, 28.3232708], [93.21897888, 28.3337307], [93.21988678, 28.33551025], [93.22145844, 28.33856964], [93.22274017, 28.34106827], [93.22029877, 28.35548973], [93.21927643, 28.36149979], [93.22225952, 28.37794113], [93.23152161, 28.40071106], [93.22586823, 28.4083004], [93.21605682, 28.41366959], [93.20461273, 28.4192791], [93.19036865, 28.42601967], [93.18106842, 28.43274117], [93.18266296, 28.439991], [93.19033813, 28.44415092], [93.20088196, 28.44899178], [93.20754242, 28.45222855], [93.21357727, 28.45816994], [93.22245026, 28.47027969], [93.22905731, 28.47795105], [93.23530579, 28.48273087], [93.23638916, 28.48324203], [93.25395966, 28.49155045], [93.26286316, 28.49690056], [93.26963043, 28.50114059], [93.27591705, 28.50482941], [93.27934265, 28.51379013], [93.28164673, 28.5212307], [93.28890991, 28.54341125], [93.29743958, 28.55758858], [93.30526733, 28.56625938], [93.3033371, 28.57687187], [93.29753876, 28.59202957], [93.29987335, 28.59955025], [93.30639648, 28.60098267], [93.31137085, 28.60375023], [93.31958008, 28.60700989], [93.32763672, 28.60828972], [93.32987976, 28.6156311], [93.33096313, 28.62347984], [93.33230591, 28.63368034], [93.33550262, 28.63817978], [93.33690643, 28.64015961], [93.34191895, 28.64011955], [93.3508606, 28.63889122], [93.36177063, 28.64082909], [93.36971283, 28.64454079], [93.38967896, 28.64946938], [93.39539337, 28.65035629], [93.40518188, 28.65187073], [93.41184235, 28.6529007], [93.42980194, 28.66230965], [93.43714142, 28.66913414], [93.43746948, 28.66943932], [93.44132996, 28.67255974], [93.44567108, 28.67604065], [93.45674896, 28.66842079], [93.46256256, 28.65703011], [93.46675873, 28.65212059], [93.47419739, 28.65365028], [93.47550201, 28.66230965], [93.47917938, 28.67498016], [93.4835968, 28.68009186], [93.48556519, 28.68110275], [93.49111938, 28.68396187], [93.49550629, 28.6840229], [93.50086975, 28.68209267], [93.50920868, 28.67984009], [93.51199341, 28.67802811], [93.51843262, 28.67383003], [93.51893616, 28.67149544], [93.52020264, 28.66564178], [93.52446747, 28.66127968], [93.53383636, 28.65884972], [93.56127167, 28.65961075], [93.606987, 28.65587807], [93.62008667, 28.6577301], [93.63487244, 28.66102028], [93.63887024, 28.6619091], [93.65364075, 28.6668396], [93.66942596, 28.67196083], [93.68551636, 28.67934036], [93.699646, 28.67992973], [93.71382141, 28.68386078], [93.72502899, 28.68821907], [93.73156738, 28.68927956], [93.74364471, 28.68462753], [93.74732971, 28.68321037], [93.76127625, 28.67460823], [93.77171326, 28.67003632], [93.775177, 28.66851807], [93.78528595, 28.67140961], [93.79736328, 28.68027115], [93.81878662, 28.69489098], [93.83555603, 28.70452118], [93.84403992, 28.70738983], [93.84966278, 28.7069912], [93.85787201, 28.70580292], [93.86527252, 28.70371246], [93.90412903, 28.67666054], [93.91960144, 28.67037964], [93.9261322, 28.67180061], [93.93456268, 28.67709923], [93.94352722, 28.68917084], [93.95697021, 28.70467949], [93.960289, 28.71306038], [93.96253967, 28.71871185], [93.96555328, 28.7232399], [93.96511078, 28.74299049], [93.96850586, 28.75138283], [93.97763062, 28.75930023], [93.99035645, 28.76563072], [93.99809265, 28.77164078], [94.0014267, 28.7755394], [94.00163269, 28.78428078], [93.99841309, 28.78804016], [93.98526764, 28.79829025], [93.98557281, 28.80677032], [93.98680115, 28.80787849], [93.99997711, 28.81977081], [93.9980011, 28.83111954], [93.99491119, 28.84136963], [94.00285339, 28.8470211], [94.01480865, 28.85118103], [94.01792145, 28.85164261], [94.03006744, 28.85345078], [94.03420258, 28.86096191], [94.04399872, 28.8738308], [94.0569458, 28.88642883], [94.0581131, 28.88755989], [94.06653595, 28.89608955], [94.07884216, 28.90582085], [94.09416199, 28.91513062], [94.12046814, 28.93028069], [94.13648987, 28.94039154], [94.15513611, 28.95476151], [94.15692139, 28.95936966], [94.15831757, 28.97406006], [94.16677094, 28.98116112], [94.17294312, 28.99182129], [94.17177582, 29.00316811], [94.17192841, 29.00700188], [94.17195892, 29.00776291], [94.17520905, 29.02049065], [94.17945862, 29.0285511], [94.18498993, 29.03912163], [94.19198608, 29.04879951], [94.1989975, 29.06010818], [94.2057724, 29.0693512], [94.21469116, 29.08408928], [94.22471619, 29.09000969], [94.233078, 29.09628105], [94.23806, 29.10045815], [94.2457962, 29.10798073], [94.2576828, 29.11679077], [94.26889038, 29.1271286], [94.27755737, 29.13539124], [94.28772736, 29.14814949], [94.29235077, 29.14962006], [94.2975769, 29.15055084], [94.30745697, 29.15088081], [94.31155396, 29.15059853], [94.31846619, 29.15011978], [94.33132935, 29.15028954], [94.35016632, 29.15020943], [94.35692596, 29.1525898], [94.35778046, 29.15317345], [94.35824585, 29.15349197], [94.36370087, 29.15722084], [94.36763, 29.16633987], [94.37008667, 29.18176079], [94.37227631, 29.19022942], [94.37684631, 29.19450188], [94.39707947, 29.20383072], [94.3995285, 29.20496941], [94.41387939, 29.21269035], [94.4257431, 29.22356033], [94.43118286, 29.2268219], [94.4338913, 29.2264595], [94.44146729, 29.22543907], [94.45465851, 29.22397041], [94.46694946, 29.22167969], [94.47006989, 29.2209034], [94.47869873, 29.21875954], [94.49446106, 29.2166729], [94.5, 29.21682167], [94.50297546, 29.21690178], [94.51400757, 29.21720123], [94.5330658, 29.21871948], [94.54580688, 29.22327042], [94.55789948, 29.22891045], [94.55995178, 29.23148346], [94.56739807, 29.24082947], [94.57208252, 29.2505703], [94.57264709, 29.25649071], [94.57344818, 29.26490021], [94.57389069, 29.27517128], [94.57775879, 29.28076935], [94.58383179, 29.28269005], [94.58895874, 29.28630066], [94.59388733, 29.2898407], [94.60536957, 29.29698944], [94.61071014, 29.30116272], [94.6190033, 29.31279945], [94.62108612, 29.32253075], [94.623703, 29.33677101], [94.62354279, 29.34559059], [94.62815857, 29.34859085], [94.6414566, 29.34692001], [94.64955139, 29.34192276], [94.66597748, 29.33177948], [94.67724609, 29.32784081], [94.68158722, 29.32380104], [94.69095612, 29.31671143], [94.69461823, 29.31394005], [94.70445251, 29.3077507], [94.71105194, 29.30434036], [94.71586609, 29.30013275], [94.73070526, 29.28716087], [94.7366333, 29.28198051], [94.74822235, 29.26625824], [94.7665329, 29.25279045], [94.7773819, 29.24111938], [94.78276825, 29.23319054], [94.79084015, 29.22619057], [94.79538727, 29.21873093], [94.79789734, 29.20998955], [94.79653168, 29.19549942], [94.79286957, 29.18036079], [94.79292297, 29.16974068], [94.79798889, 29.16460991], [94.80948639, 29.1667099], [94.82028961, 29.17095947], [94.83261871, 29.17674255], [94.84026337, 29.18016052], [94.84658813, 29.18299103], [94.85244751, 29.18371964], [94.87180328, 29.18428993], [94.88115692, 29.1817894], [94.89263153, 29.17604065], [94.90695953, 29.16652107], [94.91880035, 29.16230011], [94.92682648, 29.16275978], [94.93824005, 29.16097832], [94.93939972, 29.16094208], [94.95688629, 29.16037178], [94.96768951, 29.15975189], [94.97097778, 29.15624046], [94.9815979, 29.14995003], [94.98654938, 29.14670944], [94.99510193, 29.14096069], [95.00498199, 29.13574982], [95.0111618, 29.13340759], [95.02279663, 29.13062096], [95.02567291, 29.1335907], [95.01822662, 29.14295959], [95.01040649, 29.15185928], [95.00421906, 29.15771103], [94.99195862, 29.16581917], [94.98668671, 29.17353821], [94.99749756, 29.17301178], [95.00491333, 29.1704998], [95.01088715, 29.16707993], [95.0202713, 29.16114998], [95.02339172, 29.15980148], [95.02922821, 29.15727997], [95.03974152, 29.15242195], [95.05368042, 29.15018463], [95.05433655, 29.15007973], [95.06555939, 29.14793015], [95.07810974, 29.14560127], [95.09211731, 29.14435768], [95.0983963, 29.14380074], [95.10251617, 29.14010811], [95.10888672, 29.12902069], [95.11353302, 29.12120056], [95.12175751, 29.11625099], [95.14592743, 29.11561012], [95.15487671, 29.11334991], [95.17752075, 29.10857964], [95.19664764, 29.10758018], [95.20289612, 29.10785675], [95.21362305, 29.10833359], [95.21671295, 29.10847092], [95.24047852, 29.11071014], [95.25076294, 29.10988045], [95.24785614, 29.09377289], [95.25137329, 29.08573914], [95.25057983, 29.08135796], [95.24971008, 29.07658005], [95.25010681, 29.06857109], [95.25750732, 29.06197929], [95.26655579, 29.05764961], [95.27237701, 29.05861282], [95.27787781, 29.05953026], [95.28618622, 29.06221962], [95.29750061, 29.06319046], [95.30274963, 29.06291962], [95.30870819, 29.05931091], [95.31826782, 29.05507088], [95.33112335, 29.05145073], [95.3454895, 29.04611015], [95.37387085, 29.04129028], [95.38463593, 29.03804016], [95.39996338, 29.03540039], [95.41013336, 29.03412056], [95.41651154, 29.03816032], [95.42154694, 29.04121017], [95.42935944, 29.04128075], [95.43871307, 29.03720284], [95.44742584, 29.03601265], [95.45433807, 29.03699112], [95.45926666, 29.04310036], [95.46485901, 29.05461121], [95.47020721, 29.06089973], [95.47402954, 29.06592941], [95.48298645, 29.07113075], [95.48589325, 29.07625008], [95.48908997, 29.08974075], [95.4919281, 29.10918045], [95.49186707, 29.12368011], [95.49498749, 29.13529968], [95.49633026, 29.14031029], [95.50353241, 29.14299011], [95.51381683, 29.13891983], [95.52778625, 29.13474274], [95.53827667, 29.13056946], [95.54680634, 29.12865067], [95.54656219, 29.14575005], [95.54708099, 29.15133286], [95.54679871, 29.15871048], [95.5463028, 29.16806984], [95.5453186, 29.18058014], [95.54505157, 29.18175125], [95.54155731, 29.19697952], [95.53717804, 29.20824242], [95.53771973, 29.2140007], [95.54502869, 29.21558952], [95.56035614, 29.21653175], [95.57971954, 29.21737289], [95.58580017, 29.21799278], [95.58560944, 29.22816086], [95.58763123, 29.24237251], [95.59303284, 29.2542305], [95.59873199, 29.2618618], [95.60510254, 29.26247025], [95.62062073, 29.25494957], [95.63121796, 29.24904823], [95.63802338, 29.24983978], [95.6428833, 29.25602913], [95.65228271, 29.26049042], [95.66023254, 29.26522827], [95.67323303, 29.27109909], [95.68315125, 29.27728081], [95.69225311, 29.28652191], [95.69734192, 29.29458809], [95.70189667, 29.30042076], [95.70633698, 29.30068016], [95.71517181, 29.29829979], [95.72705078, 29.30246925], [95.74349976, 29.31624985], [95.7454071, 29.32912064], [95.76509857, 29.34459114], [95.77294922, 29.35184097], [95.77762604, 29.35639954], [95.78309631, 29.35638046], [95.78695679, 29.34736061], [95.79102325, 29.33789825], [95.7964859, 29.33633041], [95.80256653, 29.33937263], [95.80349731, 29.34007454], [95.81008148, 29.34506989], [95.81925201, 29.35205078], [95.82681274, 29.35571098], [95.84030151, 29.3537426], [95.84825897, 29.35865974], [95.85894012, 29.36750984], [95.87523651, 29.38558006], [95.88085175, 29.39149094], [95.88931274, 29.39136124], [95.8992691, 29.38975334], [95.90959167, 29.38809013], [95.93537903, 29.38425064], [95.95710754, 29.38266754], [95.96589661, 29.38739014], [95.97796631, 29.40044975], [95.98719025, 29.4068718], [95.99318695, 29.41044044], [96.00248718, 29.41207123], [96.01452637, 29.42135048], [96.02555084, 29.43342972], [96.03472137, 29.44298935], [96.04406738, 29.45046997], [96.05560303, 29.45841026], [96.06945038, 29.46227264], [96.08053589, 29.46334457], [96.08718872, 29.46161079], [96.09281921, 29.45643044], [96.10118103, 29.44531059], [96.11319733, 29.42750931], [96.12394714, 29.41761971], [96.13923645, 29.40779114], [96.14998627, 29.39925957], [96.15777588, 29.38310051], [96.1638031, 29.37668037], [96.17524719, 29.36453056], [96.18032074, 29.35550117], [96.18578339, 29.34448051], [96.185112, 29.33909988], [96.18308258, 29.30925179], [96.18840027, 29.30463028], [96.19719696, 29.29810333], [96.20323944, 29.29361916], [96.20754242, 29.28177071], [96.21005249, 29.27486038], [96.22619629, 29.25980949], [96.23416901, 29.2434597], [96.24356842, 29.23512268], [96.25083923, 29.23323822], [96.26571655, 29.23655128], [96.26613617, 29.23652077], [96.28279877, 29.23533058], [96.29299927, 29.23578835], [96.29347229, 29.23634911], [96.31260681, 29.25909996], [96.32015991, 29.26165009], [96.34533691, 29.26735115], [96.35074615, 29.27189064], [96.35838318, 29.28154182], [96.36315155, 29.28563118], [96.36902618, 29.28630066], [96.37497711, 29.28372955], [96.37548828, 29.2831974], [96.37576294, 29.28291702], [96.38208771, 29.27638054], [96.38754272, 29.26382065], [96.39280701, 29.25650024], [96.39176941, 29.24617195], [96.38867188, 29.23665237], [96.38771057, 29.23371124], [96.38021088, 29.22657967], [96.37136841, 29.21803093], [96.36935425, 29.21379852], [96.36633301, 29.2074604], [96.36302948, 29.1984005], [96.35849762, 29.18162918], [96.34635925, 29.17103004], [96.33255768, 29.16953087], [96.31004333, 29.1685009], [96.30764008, 29.16839027], [96.30641174, 29.16794014], [96.29058075, 29.16214752], [96.27246094, 29.16068077], [96.26670074, 29.16109085], [96.2602005, 29.16016006], [96.25551605, 29.15417099], [96.24890137, 29.15017128], [96.23877716, 29.14848709], [96.23808289, 29.14837074], [96.22776031, 29.14637947], [96.21749878, 29.13809967], [96.21508789, 29.13325119], [96.20868683, 29.12071037], [96.20503235, 29.11444092], [96.20033264, 29.10593033], [96.18562317, 29.09461975], [96.17980957, 29.09210014], [96.16950226, 29.08763123], [96.16316986, 29.08673859], [96.15554047, 29.08566093], [96.12420654, 29.0806694], [96.11450195, 29.07760239], [96.13671112, 29.06447029], [96.15039063, 29.05314064], [96.1608429, 29.03651047], [96.16520691, 29.02010918], [96.16883087, 29.01288033], [96.1756134, 29.00346947], [96.18022919, 28.99941063], [96.1848526, 28.98811913], [96.18454742, 28.97777939], [96.18044281, 28.96854019], [96.16220093, 28.95968056], [96.15516663, 28.95560265], [96.15406036, 28.94651031], [96.15033722, 28.94313049], [96.14524841, 28.93748856], [96.1553421, 28.92832947], [96.16297913, 28.92206001], [96.16557312, 28.91403961], [96.16652679, 28.90592957], [96.17472839, 28.90426064], [96.18599701, 28.91201019], [96.20465088, 28.91916084], [96.21546936, 28.92329979], [96.22814941, 28.92933083], [96.24829865, 28.94284058], [96.25565338, 28.9592514], [96.26065063, 28.96513939], [96.26819611, 28.97129059], [96.28186798, 28.98369026], [96.28659058, 28.99201965], [96.29370117, 28.99872971], [96.3010788, 29.00224113], [96.30912781, 29.00559044], [96.31411743, 29.00847816], [96.3215332, 29.0127697], [96.3372879, 29.02452087], [96.34139252, 29.0279007], [96.34670258, 29.03226852], [96.35740662, 29.03424072], [96.36873627, 29.03495026], [96.38896179, 29.03414154], [96.40441132, 29.03536034], [96.42086792, 29.03700066], [96.43579102, 29.03758812], [96.43855286, 29.03852081], [96.44979858, 29.04231071], [96.45001221, 29.04239273], [96.45889282, 29.04582977], [96.46492767, 29.05226707], [96.46658325, 29.05402756], [96.46943665, 29.05567741], [96.47715759, 29.06014061], [96.4798584, 29.061203], [96.49163055, 29.06583977], [96.50031281, 29.07090187], [96.50815582, 29.07377815], [96.51862335, 29.07845116], [96.52519989, 29.07928085], [96.51169586, 29.0526104], [96.50540924, 29.0418911], [96.4988327, 29.03133011], [96.49281311, 29.02033043], [96.4885788, 29.01048088], [96.48425293, 29.00534248], [96.47740173, 28.99403954], [96.48116302, 28.98230934], [96.48138428, 28.98161316], [96.48153687, 28.98113823], [96.48432922, 28.97284126], [96.48752594, 28.96533966], [96.49324799, 28.96232033], [96.4936676, 28.96239662], [96.50076294, 28.9636898], [96.51335907, 28.97031975], [96.51882935, 28.97098923], [96.52121735, 28.96520996], [96.52263641, 28.95548058], [96.52366638, 28.94800949], [96.53029633, 28.93696976], [96.53547668, 28.93000031], [96.53792572, 28.9231987], [96.53872681, 28.92098236], [96.53687286, 28.90966034], [96.53607941, 28.89717102], [96.5374527, 28.88412094], [96.54225922, 28.87920952], [96.54686737, 28.87450027], [96.55265045, 28.86408997], [96.55319977, 28.86310005], [96.55381775, 28.86242485], [96.55976868, 28.85593033], [96.56285858, 28.84799004], [96.56697845, 28.84192085], [96.57585907, 28.83049011], [96.58425903, 28.82151985], [96.59514618, 28.81520081], [96.60383606, 28.80442047], [96.60838318, 28.79807091], [96.61123657, 28.79004097], [96.61599731, 28.77857971], [96.61551666, 28.7648201], [96.61361694, 28.75979805], [96.60943604, 28.75338173], [96.59815979, 28.73801994], [96.5859375, 28.72158813], [96.57232666, 28.71471024], [96.56001282, 28.71186256], [96.53222656, 28.71149826], [96.52720642, 28.71021843], [96.52236938, 28.70898056], [96.50802612, 28.70112038], [96.49841309, 28.69256973], [96.49057007, 28.68849754], [96.48432159, 28.68829918], [96.47274017, 28.68820953], [96.47054291, 28.68455124], [96.47425079, 28.68031311], [96.47499084, 28.67947006], [96.47840118, 28.67287827], [96.4839325, 28.66526031], [96.48681641, 28.65876961], [96.4911499, 28.6507225], [96.49159241, 28.64994812], [96.49516296, 28.64376068], [96.4940567, 28.63819122], [96.48423004, 28.6315403], [96.47289276, 28.62247276], [96.45825958, 28.61387062], [96.44444275, 28.60598946], [96.4393692, 28.600811], [96.43502808, 28.59699059], [96.42807007, 28.58714104], [96.42250061, 28.5850296], [96.41507721, 28.5884304], [96.40735626, 28.59443283], [96.40091705, 28.59431076], [96.39994049, 28.59044075], [96.40615082, 28.5778904], [96.40670013, 28.57150078], [96.40660858, 28.56404114], [96.40077209, 28.5623703], [96.39421844, 28.56269836], [96.3863678, 28.56365967], [96.3707962, 28.56415176], [96.36797333, 28.56353188], [96.35460663, 28.56059074], [96.34324646, 28.55105972], [96.33481598, 28.53853035], [96.32567596, 28.53400993], [96.32430267, 28.53034019], [96.33113861, 28.52659988], [96.33220673, 28.52607346], [96.34210205, 28.52120018], [96.35299683, 28.51490021], [96.36091614, 28.50972939], [96.36660767, 28.50472832], [96.37171173, 28.49677086], [96.37296295, 28.48703957], [96.36965942, 28.48290634], [96.36695862, 28.47953033], [96.34136963, 28.47002029], [96.33506012, 28.46278], [96.32386017, 28.45504951], [96.30963898, 28.44569969], [96.29712677, 28.43914032], [96.28476715, 28.43077087], [96.27448273, 28.42401123], [96.26596069, 28.41704941], [96.26377106, 28.41337967], [96.26740265, 28.41020966], [96.27291107, 28.40944862], [96.2769928, 28.40888023], [96.28782654, 28.40870857], [96.299263, 28.40665054], [96.30464172, 28.40472031], [96.30809784, 28.40035248], [96.31030273, 28.39756966], [96.31532288, 28.3884201], [96.31987762, 28.3861599], [96.330513, 28.38777924], [96.36184692, 28.39375114], [96.37094116, 28.39430046], [96.37484741, 28.38726997], [96.38001251, 28.36409187], [96.39215088, 28.36264992], [96.39940643, 28.34449959], [96.4127121, 28.34673119], [96.42285919, 28.35097122], [96.42698669, 28.36343002], [96.4287262, 28.37251091], [96.42993164, 28.38105011], [96.4305191, 28.38609123], [96.43199921, 28.39173126], [96.43914795, 28.40102959], [96.44698334, 28.40717125], [96.4538269, 28.41564941], [96.45826721, 28.41922188], [96.46972656, 28.4228096], [96.4799881, 28.42461014], [96.49672699, 28.42355919], [96.50628662, 28.42006111], [96.51026154, 28.41830826], [96.5201416, 28.42333984], [96.53385925, 28.43464088], [96.5511322, 28.4422226], [96.55953217, 28.45302963], [96.57958984, 28.4630928], [96.59866333, 28.46623039], [96.62142181, 28.46440125], [96.63918304, 28.4641304], [96.66008759, 28.46635056], [96.66456604, 28.46577072], [96.67539978, 28.45676041], [96.68144989, 28.45120239], [96.68734741, 28.44828033], [96.70619965, 28.43746948], [96.71687317, 28.43294907], [96.7339859, 28.43078995], [96.73996735, 28.42723274], [96.75105286, 28.42171288], [96.75749207, 28.41543007], [96.76316071, 28.40421867], [96.76732635, 28.38969994], [96.77068329, 28.38076019], [96.77437592, 28.37407112], [96.78257751, 28.37038994], [96.79708862, 28.37050056], [96.81156921, 28.36810112], [96.82647705, 28.36720276], [96.85221863, 28.36836052], [96.86248779, 28.37830925], [96.86956787, 28.3808403], [96.88001251, 28.38278961], [96.89395142, 28.38614082], [96.89866638, 28.3859005], [96.90419006, 28.37990952], [96.91028595, 28.37140083], [96.91996002, 28.36334991], [96.91977692, 28.3592205], [96.92089844, 28.35218811], [96.92590332, 28.34502983], [96.94229126, 28.34206009], [96.95276642, 28.33995056], [96.96193695, 28.33202934], [96.97406006, 28.32369041], [96.97973633, 28.32228088], [96.98699188, 28.32219124], [96.99649811, 28.31623077], [97.00428772, 28.31838036], [97.02268982, 28.32625961], [97.02715302, 28.33006096], [97.03636932, 28.33867264], [97.04135132, 28.34921074], [97.04532623, 28.35411072], [97.05181885, 28.35806847], [97.06111145, 28.35832024], [97.06613159, 28.35951042], [97.07929993, 28.36508942], [97.09256744, 28.36969185], [97.0949173, 28.36877251], [97.09825134, 28.36747169], [97.10418701, 28.3629818], [97.11279297, 28.35890961], [97.12095642, 28.35798836], [97.12593842, 28.35622025], [97.12980652, 28.35140991], [97.13899231, 28.34436989], [97.1519928, 28.33403015], [97.15880585, 28.32694054], [97.16536713, 28.31301117], [97.16937256, 28.30225182], [97.17391968, 28.29906082], [97.1780014, 28.29730034], [97.1830368, 28.29632187], [97.19259644, 28.29440117], [97.2027359, 28.29560089], [97.2140274, 28.29905128], [97.22424316, 28.29989052], [97.22801971, 28.29445267], [97.23419189, 28.28079033], [97.24124146, 28.27513123], [97.25443268, 28.27646828], [97.26812744, 28.27826118], [97.28206635, 28.27626038], [97.29257202, 28.27063942], [97.30632782, 28.26396751], [97.30766296, 28.25810051], [97.31304169, 28.25183105], [97.32202911, 28.25188065], [97.32737732, 28.25082016], [97.33377075, 28.24777985], [97.34171295, 28.24217033], [97.34950256, 28.23581314], [97.35135651, 28.23430061], [97.35688782, 28.23320007], [97.36499023, 28.23159027], [97.37465668, 28.2256012], [97.37700653, 28.22341919], [97.38124847, 28.21946907], [97.38967896, 28.21236038], [97.4005661, 28.20050049], [97.40042114, 28.19351006], [97.39222717, 28.19120026], [97.38719177, 28.19450951], [97.38223267, 28.19655037], [97.37201691, 28.2003994], [97.36357117, 28.19646835], [97.36177826, 28.1931591], [97.35923004, 28.18844986], [97.35183716, 28.18153954], [97.34127045, 28.17225075], [97.33080292, 28.1629715], [97.32705688, 28.15431023], [97.3246994, 28.1482296], [97.32670593, 28.14163971], [97.33170319, 28.13572121], [97.33495331, 28.13126945], [97.33507538, 28.13110542], [97.34002686, 28.12454987], [97.33901215, 28.11954117], [97.3272171, 28.10946083], [97.31748199, 28.10099602], [97.31694031, 28.10051918], [97.31021118, 28.09325027], [97.3081131, 28.08572769], [97.30774689, 28.07710075], [97.31179047, 28.0699501], [97.31886292, 28.06706047], [97.33167267, 28.06536293], [97.34532928, 28.06659126], [97.34980011, 28.0669899], [97.35675812, 28.06760979], [97.36604309, 28.06809807], [97.3735199, 28.07023811], [97.37399292, 28.06259155], [97.3718338, 28.0589447], [97.36797333, 28.0524292], [97.37706757, 28.03909111], [97.38218689, 28.04018974], [97.38976288, 28.03738976], [97.3985672, 28.03411102], [97.40561676, 28.03004837], [97.41156006, 28.02727127], [97.41516113, 28.02408028], [97.41394806, 28.01923943], [97.41162872, 28.01514053], [97.40222168, 28.01301956], [97.40142822, 28.01294136], [97.39121246, 28.01193047], [97.38883972, 28.00620079], [97.38330841, 27.99367142], [97.38276672, 27.99245071], [97.37806702, 27.98615074], [97.37815094, 27.98179054], [97.3782196, 27.97850037], [97.37854004, 27.96321106], [97.37561798, 27.94438934], [97.3826828, 27.93610954], [97.38765717, 27.93073082], [97.38768768, 27.9265995], [97.381073, 27.92111969], [97.37856293, 27.91801071], [97.37979126, 27.91258812], [97.38755035, 27.9036808], [97.38902283, 27.89637947], [97.378479, 27.89311028], [97.37135315, 27.88693047], [97.3647995, 27.88512993], [97.3500061, 27.89133835], [97.34352112, 27.89406013], [97.33557892, 27.8931694], [97.32116699, 27.88951111], [97.32285309, 27.90341949], [97.32393646, 27.91185951], [97.32216644, 27.91620064], [97.31474304, 27.92519188], [97.30870819, 27.92996025], [97.30174255, 27.92708015], [97.28810883, 27.92177963], [97.28074646, 27.91954994], [97.25647736, 27.90953064], [97.24720001, 27.90390968], [97.24124146, 27.89545059], [97.23677063, 27.88993835], [97.22647095, 27.88216019], [97.22049713, 27.87738991], [97.21244049, 27.87199974], [97.20256042, 27.86440277], [97.19560242, 27.85639954], [97.19543457, 27.8562355], [97.19361115, 27.85520172], [97.19185638, 27.85275078], [97.18949127, 27.85045052], [97.18791962, 27.84760094], [97.1869812, 27.84589958], [97.18183136, 27.8417511], [97.18052673, 27.84116173], [97.17444611, 27.83842278], [97.16780853, 27.83625984], [97.16867828, 27.83086014], [97.16397095, 27.82677078], [97.16287994, 27.82460785], [97.16034698, 27.82259178], [97.15225983, 27.81920052], [97.14428711, 27.81696129], [97.13735199, 27.81506157], [97.13394165, 27.80647087], [97.12787628, 27.80107117], [97.12428284, 27.79850006], [97.11489105, 27.79593277], [97.10246277, 27.79342079], [97.0983963, 27.7885704], [97.09963989, 27.78440475], [97.10011292, 27.78280258], [97.10476685, 27.77518845], [97.10119629, 27.76723099], [97.09807587, 27.75728035], [97.09642029, 27.74992943], [97.09142303, 27.74846077], [97.08628082, 27.75041008], [97.08235168, 27.75189972], [97.06754303, 27.75972176], [97.06201172, 27.7574501], [97.0565567, 27.75202942], [97.04808044, 27.74933815], [97.03736115, 27.75216103], [97.02857208, 27.74912071], [97.01574707, 27.7406311], [97.01322174, 27.7353611], [97.01032257, 27.72550011], [97.00550079, 27.71549034], [97.00322723, 27.7104702], [97.00145721, 27.70820045], [96.99720764, 27.70273972], [96.9888382, 27.69689941], [96.98484802, 27.69099045], [96.9825592, 27.67976952], [96.978302, 27.67187309], [96.9776001, 27.67192268], [96.95865631, 27.67428017], [96.94876862, 27.67142868], [96.94232178, 27.66744995], [96.93887329, 27.6607399], [96.93522644, 27.65983963], [96.92896271, 27.65603256], [96.92700958, 27.64190102], [96.92556763, 27.64020157], [96.92030334, 27.63267136], [96.91944885, 27.63145065], [96.91308594, 27.62748909], [96.91208649, 27.6272316], [96.90058136, 27.62426949], [96.89758301, 27.62080193], [96.89778137, 27.61814117], [96.89910126, 27.60045815], [96.89922333, 27.59362984], [96.90299988, 27.58989906], [96.9101181, 27.58992195], [96.91403198, 27.5884304], [96.91409302, 27.58439255], [96.91324615, 27.57630157], [96.91422272, 27.56729126], [96.91542816, 27.5604496], [96.91580963, 27.55828285], [96.92034912, 27.55562019], [96.92453766, 27.55125999], [96.9286499, 27.54231071], [96.93363953, 27.53722], [96.93768311, 27.53005981], [96.93638611, 27.52325058], [96.9335022, 27.51571083], [96.93081665, 27.51188087], [96.92572021, 27.50304031], [96.92185974, 27.49936676], [96.92076874, 27.49722099], [96.91385651, 27.48841286], [96.91365051, 27.48786926], [96.91121674, 27.48152161], [96.91081238, 27.47459984], [96.91092682, 27.46801949], [96.91184998, 27.46270943], [96.91755676, 27.4588604], [96.92592621, 27.45644951], [96.93334198, 27.45051193], [96.93702698, 27.43959045], [96.94139099, 27.42695045], [96.94889069, 27.4209404], [96.96552277, 27.4153595], [96.96893311, 27.40182114], [96.97554016, 27.39600182], [96.9690094, 27.38627052], [96.97174072, 27.37895012], [96.97696686, 27.37675095], [96.98197937, 27.37371063], [96.98504639, 27.36260986], [96.9895401, 27.35852051], [96.99746704, 27.35510063], [96.99842834, 27.35086823], [97.00026703, 27.3399601], [97.00334167, 27.3299408], [97.009552, 27.32564926], [97.01686859, 27.3200798], [97.04032898, 27.30785942], [97.04358673, 27.28975105], [97.05164337, 27.28650284], [97.05667114, 27.28564072], [97.05885315, 27.27679825], [97.06331635, 27.27224922], [97.06851196, 27.2675209], [97.07366943, 27.26188087], [97.08184052, 27.2538681], [97.08937073, 27.25082016], [97.09407806, 27.24789047], [97.09597015, 27.24121094], [97.09514618, 27.22142982], [97.10050201, 27.21497917], [97.10804749, 27.21310043], [97.11669922, 27.20922089], [97.12023926, 27.20458984], [97.12390137, 27.19987106], [97.12568665, 27.19238853], [97.12729645, 27.18517113], [97.1335907, 27.1809597], [97.14031219, 27.17746925], [97.1499176, 27.17834091], [97.15289307, 27.16841125], [97.15599823, 27.16217995], [97.16720581, 27.15547943], [97.17215729, 27.14435959], [97.17173767, 27.1368103], [97.16625214, 27.13256073], [97.16590118, 27.13229179], [97.15590668, 27.12638092], [97.15236664, 27.11967087], [97.15011597, 27.11152077], [97.14693451, 27.10403252], [97.14643097, 27.10284042], [97.13994598, 27.10128975], [97.13098907, 27.10374069], [97.12233734, 27.11202049], [97.11469269, 27.11993027], [97.10855865, 27.12125969], [97.09921265, 27.11857033], [97.08925629, 27.1138401], [97.08428192, 27.11194992], [97.07910156, 27.10997963], [97.07151794, 27.10917091], [97.0630188, 27.11108208], [97.06268311, 27.11116028], [97.05889893, 27.11407089], [97.05258179, 27.11893082], [97.0479126, 27.12374115], [97.04553986, 27.12681961], [97.04199982, 27.13126945], [97.03501129, 27.13710976], [97.03022003, 27.1417408], [97.02099609, 27.14545059], [97.01315308, 27.1468811], [97.00681305, 27.14982986], [96.99900055, 27.15394974], [96.99256134, 27.16122055], [96.98465729, 27.1667099], [96.97351074, 27.17105293], [96.96372986, 27.17259026], [96.95526123, 27.17368126], [96.94467926, 27.17405128], [96.92801666, 27.17513275], [96.91841125, 27.17548943], [96.90273285, 27.1807785], [96.89689636, 27.18336105], [96.88297272, 27.19051933], [96.87563324, 27.19355965], [96.8662262, 27.19968987], [96.8640213, 27.20690155], [96.8635788, 27.21220016], [96.8633728, 27.21924019], [96.86625671, 27.22361946], [96.87409973, 27.22669029], [96.88031769, 27.23077011], [96.8852005, 27.23259926], [96.89000702, 27.23686981], [96.8914032, 27.24090958], [96.89269257, 27.24763107], [96.88703918, 27.25473022], [96.88790894, 27.25938988], [96.88877869, 27.2635994], [96.88510132, 27.26795959], [96.87507629, 27.26716042], [96.8662262, 27.2690506], [96.86171722, 27.27251053], [96.85566711, 27.28030968], [96.85378265, 27.29067039], [96.85177612, 27.30041122], [96.8497467, 27.30628014], [96.83625793, 27.31054115], [96.83125305, 27.31464005], [96.82486725, 27.32047081], [96.82160187, 27.32444954], [96.81710052, 27.32954025], [96.8127594, 27.33641815], [96.8086319, 27.34492111], [96.80584717, 27.35042953], [96.80236053, 27.35443115], [96.79483032, 27.35647964], [96.78531647, 27.35881042], [96.77960205, 27.3621006], [96.77295685, 27.36495972], [96.75979614, 27.36329079], [96.75419617, 27.36277008], [96.74775696, 27.36403084], [96.74069214, 27.36445999], [96.72844696, 27.37239075], [96.72251892, 27.37695122], [96.7125473, 27.38072968], [96.70876312, 27.37519073], [96.70638275, 27.37116051], [96.69909668, 27.36556053], [96.69374084, 27.36551857], [96.6831665, 27.36894035], [96.67619324, 27.3708992], [96.67015839, 27.3723011], [96.6608429, 27.37138939], [96.65603638, 27.36892128], [96.64611816, 27.36783028], [96.63913727, 27.36923981], [96.63037109, 27.37182999], [96.6204834, 27.3728199], [96.6125412, 27.36936951], [96.61077118, 27.36730766], [96.60894012, 27.36518288], [96.60260773, 27.36071777], [96.60251617, 27.36065102], [96.59829712, 27.35645103], [96.59793854, 27.35149956], [96.59901428, 27.34892464], [96.60080719, 27.3446312], [96.59720612, 27.34300804], [96.59632111, 27.34260941], [96.59166718, 27.34085083], [96.58592224, 27.33683968], [96.57991791, 27.33365059], [96.57543945, 27.32919121], [96.56598663, 27.32666016], [96.56182861, 27.32525253], [96.55621338, 27.32061958], [96.55046082, 27.31472015], [96.54527283, 27.3097229], [96.53759766, 27.3042984], [96.53074646, 27.29804993], [96.52233124, 27.29397011], [96.51703644, 27.30057907], [96.5118103, 27.30405045], [96.50538635, 27.30760002], [96.50003052, 27.3093605], [96.49402618, 27.30626106], [96.48603058, 27.30523109], [96.47917938, 27.30808067], [96.4707489, 27.31246185], [96.46666718, 27.31105042], [96.461586, 27.30911064], [96.45250702, 27.3098011], [96.44613647, 27.31030083], [96.43976593, 27.31035995], [96.43348694, 27.30994034], [96.42495728, 27.3061409], [96.41609192, 27.29989243], [96.40862274, 27.29994965], [96.4017334, 27.2985611], [96.39157104, 27.29458046], [96.38279724, 27.29751968], [96.373703, 27.29893112], [96.36412048, 27.30016136], [96.36151886, 27.29405975], [96.35788727, 27.2916584], [96.35520172, 27.28988266], [96.34807587, 27.28846169], [96.34771729, 27.28839111], [96.34118652, 27.2915802], [96.33574677, 27.2959404], [96.32039642, 27.29801941], [96.31083679, 27.3020401], [96.30330658, 27.29922295], [96.29042816, 27.2940712], [96.28217316, 27.28602028], [96.27865601, 27.27938271], [96.26743317, 27.27783966], [96.25421143, 27.28098106], [96.24138641, 27.28429031], [96.23432922, 27.28487968], [96.22709656, 27.28059959], [96.21810913, 27.26958084], [96.20585632, 27.26613045], [96.19632721, 27.26519012], [96.19406891, 27.26345253], [96.19187927, 27.26177025], [96.18520355, 27.25663376], [96.18209839, 27.25424957], [96.1811676, 27.25426102], [96.16368866, 27.25448036], [96.15040588, 27.24950981], [96.11450195, 27.2333107], [96.09902191, 27.23140907], [96.09213257, 27.22667122], [96.08731079, 27.21859932], [96.08638763, 27.21705055], [96.0851593, 27.2167778], [96.06897736, 27.21319008], [96.05728149, 27.20279121], [96.03643036, 27.19605064], [96.02979279, 27.18778992], [96.02700043, 27.17901802], [96.02298737, 27.16638947], [96.01693726, 27.15479088], [96.00431824, 27.14044189], [96.00325012, 27.13933182], [95.98958588, 27.12519073], [95.97918701, 27.11072922], [95.97389221, 27.10201263], [95.97193909, 27.09879112], [95.9630661, 27.08197975], [95.9571228, 27.06822014], [95.94596863, 27.05970955], [95.9402771, 27.05577278], [95.93624878, 27.05299187], [95.92318726, 27.0489006], [95.91580963, 27.04532051], [95.90923309, 27.04030037], [95.90068817, 27.03178024], [95.88918304, 27.0278511], [95.87713623, 27.02049828], [95.86747742, 27.02234077], [95.85777283, 27.02235985], [95.83796692, 27.01531029], [95.82798004, 27.01805115], [95.81529999, 27.02222061], [95.80793762, 27.02045059], [95.80486298, 27.01199913], [95.77964783, 26.98999023], [95.77294159, 26.98253059], [95.77172852, 26.97864151], [95.76705933, 26.97289085], [95.76087952, 26.96398926], [95.76158142, 26.95926094], [95.76368713, 26.94498062], [95.76056671, 26.94201088], [95.75673676, 26.94021988], [95.75254822, 26.93023109], [95.75454712, 26.92500114], [95.75724792, 26.92040062], [95.75813293, 26.91489983], [95.75499725, 26.90788841], [95.74507904, 26.90089989], [95.73596191, 26.89270973], [95.73081207, 26.88749123], [95.72113037, 26.88363075], [95.71247864, 26.88430786], [95.71156311, 26.88438034], [95.71141815, 26.88442993], [95.70349121, 26.88718987], [95.69859314, 26.89521027], [95.692276, 26.89991951], [95.68798828, 26.90189362], [95.68128967, 26.90497971], [95.67336273, 26.9102211], [95.66819763, 26.90834045], [95.66295624, 26.90492058], [95.65777588, 26.89808083], [95.6553421, 26.89295006], [95.65414429, 26.89045143], [95.65099335, 26.88384819], [95.64644623, 26.88287926], [95.64562225, 26.8829155], [95.64221954, 26.88306046], [95.6367569, 26.87928963], [95.63413239, 26.8732605], [95.63478851, 26.86768913], [95.63491821, 26.86657906], [95.63355255, 26.85514069], [95.63223267, 26.84947968], [95.62812042, 26.84384918], [95.62769318, 26.84325981], [95.62203217, 26.83723259], [95.61798096, 26.82985115], [95.61151886, 26.82121277], [95.59910583, 26.82221985], [95.59226227, 26.82303047], [95.58473206, 26.82277107], [95.57475281, 26.82567024], [95.56851196, 26.82991028], [95.56562042, 26.83378983], [95.56269836, 26.8372097], [95.55475616, 26.83956909], [95.54567719, 26.83786011], [95.53277588, 26.83120918], [95.53024292, 26.82679176], [95.52500153, 26.8199482], [95.52147675, 26.81667519], [95.52025604, 26.81554031], [95.51480103, 26.8132], [95.50650787, 26.79663086], [95.50215149, 26.78273964], [95.49590302, 26.77194023], [95.48914337, 26.76167107], [95.48348999, 26.75498962], [95.47956085, 26.75365829], [95.47585297, 26.75239944], [95.4656601, 26.75041008], [95.46141052, 26.74600029], [95.45848083, 26.73771095], [95.45453644, 26.73293877], [95.4541626, 26.7324791], [95.45343781, 26.73201752], [95.44629669, 26.72743988], [95.4419632, 26.72284126], [95.4397583, 26.71797943], [95.43733215, 26.71446037], [95.43548584, 26.7082386], [95.43238831, 26.70355988], [95.4288559, 26.70004082], [95.42330933, 26.69671249], [95.40643311, 26.69662094], [95.39463806, 26.69102097], [95.38356781, 26.68806076], [95.37814331, 26.68334961], [95.37470245, 26.68125343], [95.37151337, 26.67930984], [95.36586761, 26.67758942], [95.36543274, 26.67757034], [95.35581207, 26.67712975], [95.34664917, 26.67794037], [95.32441711, 26.66908264], [95.31788635, 26.6668396], [95.31479645, 26.66386795], [95.30841064, 26.65772057], [95.30258179, 26.65602112], [95.29992676, 26.65788841], [95.29927063, 26.65834808], [95.2931366, 26.66123009], [95.28288269, 26.66284943], [95.27202606, 26.66282082], [95.26597595, 26.6678791], [95.26204681, 26.67365074], [95.26165771, 26.68148994], [95.26003265, 26.68635178], [95.25652313, 26.68931961], [95.25078583, 26.69239044], [95.24395752, 26.69390106], [95.24044037, 26.69164085], [95.23763275, 26.68629074], [95.23597717, 26.68823051], [95.23596954, 26.69152069], [95.23369598, 26.69709969], [95.23610687, 26.7122097], [95.2296524, 26.71688271], [95.22820282, 26.72384834], [95.21614075, 26.73531914], [95.21685028, 26.74130058], [95.22097778, 26.7474308], [95.22136688, 26.75152016], [95.21926117, 26.75555038], [95.2201004, 26.75982094], [95.22408295, 26.76172256], [95.22920227, 26.76847076], [95.23317719, 26.77193069], [95.23330688, 26.77371979], [95.23163605, 26.77769279], [95.23467255, 26.78034973], [95.24253845, 26.78451157], [95.24491882, 26.78733063], [95.24172211, 26.78693008], [95.24025726, 26.78917122], [95.23501587, 26.78928947], [95.2274704, 26.79234123], [95.22157288, 26.79354095], [95.21511841, 26.7983799], [95.20684052, 26.81169128], [95.20355225, 26.82131958], [95.20258331, 26.82875061], [95.20056152, 26.83288956], [95.19904327, 26.83992958], [95.20050812, 26.84287834], [95.20641327, 26.84628105], [95.20860291, 26.85071945], [95.20423889, 26.8489399], [95.19770813, 26.85153961], [95.19732666, 26.84939194], [95.19561005, 26.84962082], [95.19304657, 26.85116959], [95.18576813, 26.85963058], [95.18450165, 26.86483002], [95.20642853, 26.87787056], [95.21135712, 26.88173294], [95.21285248, 26.88560295], [95.21782684, 26.88686943], [95.22992706, 26.88566971], [95.2338562, 26.89084053], [95.23132324, 26.89834976], [95.23377228, 26.90590286], [95.23410034, 26.9096508], [95.23208618, 26.91483116], [95.23195648, 26.91789055], [95.23396301, 26.91875267], [95.23396301, 26.92060089], [95.23184967, 26.92614174], [95.22930908, 26.93063164], [95.22556305, 26.93442917], [95.21705627, 26.93420029], [95.21444702, 26.93695068], [95.21219635, 26.94334984], [95.20923615, 26.95667076], [95.21341705, 26.95878983], [95.20851135, 26.9607296], [95.20675659, 26.96259117], [95.20883942, 26.9653511], [95.21366882, 26.96812057], [95.21504211, 26.97037125], [95.20877075, 26.97508049], [95.20655823, 26.9788208], [95.20522308, 26.9821701], [95.20996094, 26.98262978], [95.20775604, 26.98470116], [95.20043945, 26.98555946], [95.19519806, 26.98999023], [95.19626617, 26.99781036], [95.19982147, 26.99935913], [95.20008087, 27.0062294], [95.19761658, 27.01568985], [95.19785309, 27.01984024], [95.19579315, 27.03250122], [95.19551849, 27.04294968], [95.19845581, 27.04442978], [95.20094299, 27.04232979], [95.20379639, 27.04300117], [95.20768738, 27.0347805], [95.21380615, 27.03347969], [95.21969604, 27.03679085], [95.22263336, 27.04089165], [95.22598267, 27.04225922], [95.2294693, 27.04017067], [95.23214722, 27.04292107], [95.23091125, 27.04570961], [95.23471832, 27.0435791], [95.23787689, 27.04322052], [95.24371338, 27.03416061], [95.24822998, 27.03025246], [95.25219727, 27.03191948], [95.2607193, 27.03725052], [95.25994873, 27.03897285], [95.26262665, 27.0410099], [95.26669312, 27.04043961], [95.27097321, 27.04507065], [95.27762604, 27.04977036], [95.27944946, 27.05391121], [95.27783203, 27.05676842], [95.28791809, 27.06632042], [95.29662323, 27.07285118], [95.30967712, 27.08113098], [95.31317902, 27.08674049], [95.32327271, 27.089571], [95.3351059, 27.09592056], [95.34860229, 27.10476112], [95.36647034, 27.11285019], [95.37126923, 27.1114006], [95.3706665, 27.11014938], [95.36778259, 27.10971069], [95.36830139, 27.10736275], [95.37365723, 27.1079998], [95.37267303, 27.10167122], [95.37697601, 27.10218048], [95.38546753, 27.10509109], [95.38611603, 27.11170959], [95.39614868, 27.11446953], [95.40631104, 27.11832047], [95.42027283, 27.13078117], [95.42919159, 27.13405037], [95.44098663, 27.13281059], [95.44557953, 27.1342907], [95.44713593, 27.13833046], [95.45075226, 27.13883972], [95.45339966, 27.13587952], [95.45778656, 27.1356411], [95.4610672, 27.14022064], [95.46367645, 27.15036011], [95.46585083, 27.15480042], [95.46507263, 27.15760994], [95.46331787, 27.15954018], [95.4598999, 27.16041946], [95.45870972, 27.16328812], [95.46383667, 27.1670208], [95.46800995, 27.1722908], [95.46366882, 27.18212128], [95.46711731, 27.18555069], [95.46864319, 27.19050026], [95.46581268, 27.19742966], [95.46205139, 27.20301056], [95.45890045, 27.20956993], [95.45970917, 27.2134304], [95.46942902, 27.21825981], [95.47067261, 27.22321129], [95.47389984, 27.22364998], [95.47451019, 27.22686958], [95.48055267, 27.23233986], [95.48722839, 27.24603081], [95.49099731, 27.24869919], [95.50627899, 27.2546196], [95.51064301, 27.2589798], [95.51088715, 27.26626968], [95.51618195, 27.26863098], [95.52046204, 27.26374054], [95.52593231, 27.26626015], [95.52971649, 27.26906967], [95.53481293, 27.27062035], [95.55416107, 27.25934029], [95.55613708, 27.25436974], [95.56326294, 27.25250244], [95.57446289, 27.25106049], [95.57830048, 27.24714088], [95.57788086, 27.24215126], [95.59008789, 27.2295208], [95.59916687, 27.22961044], [95.60735321, 27.23137283], [95.61914063, 27.23655128], [95.63413239, 27.23981094], [95.63700104, 27.23690987], [95.67920685, 27.2539196], [95.67939758, 27.25616264], [95.68441772, 27.25741005], [95.69542694, 27.25814819], [95.70188141, 27.25564003], [95.71549225, 27.25909996], [95.72107697, 27.25760078], [95.72548676, 27.25922966], [95.73188019, 27.26654053], [95.73638916, 27.26675034], [95.7399292, 27.26988983], [95.75701141, 27.27435112], [95.78468323, 27.27913094], [95.790802, 27.28545952], [95.80075836, 27.2887001], [95.80628967, 27.29174042], [95.8065033, 27.28801155], [95.80848694, 27.28544044], [95.81019592, 27.28092003], [95.8379364, 27.28707123], [95.85022736, 27.29314995], [95.860466, 27.29421043], [95.86192322, 27.29002953], [95.86064148, 27.28342056], [95.86084747, 27.27979279], [95.86544037, 27.2766819], [95.87238312, 27.26691055], [95.87760162, 27.26740837], [95.88243103, 27.26694107], [95.88765717, 27.26332092], [95.89396667, 27.26301193], [95.89810944, 27.26431084], [95.90116119, 27.27638817], [95.90428925, 27.27985954], [95.90453339, 27.28623962], [95.90238953, 27.28783035], [95.90643311, 27.29187965], [95.91229248, 27.29314041], [95.91874695, 27.29922295], [95.94056702, 27.30958939], [95.96321869, 27.3170681], [95.96556854, 27.3216629], [95.96260834, 27.32433128], [95.96785736, 27.3245697], [95.96903229, 27.32840919], [95.96871185, 27.33183098], [95.9780426, 27.33269119], [95.98420715, 27.33434105], [95.97228241, 27.33462906], [95.97001648, 27.33698082], [95.97421265, 27.33936119], [95.9773407, 27.34230042], [95.99368286, 27.35144043], [95.99487305, 27.36024094], [95.99697113, 27.36347961], [96.00211334, 27.36412811], [96.00314331, 27.36445999], [96.01319885, 27.36403084], [96.01835632, 27.36790085], [96.02091217, 27.37125969], [96.01494598, 27.37545967], [96.01056671, 27.38128281], [96.00836945, 27.38721085], [96.00205231, 27.39349937], [96.00006866, 27.39756966], [96.00100708, 27.4034729], [95.99459076, 27.41235924], [95.99093628, 27.41457176], [95.9912262, 27.41939926], [95.98945618, 27.4217205], [95.97952271, 27.4218502], [95.97807312, 27.42533112], [95.98092651, 27.42612267], [95.98023224, 27.43021965], [95.97782898, 27.43229103], [95.9777832, 27.43549919], [95.97329712, 27.43675041], [95.97177887, 27.43037033], [95.96803284, 27.42411995], [95.96703339, 27.43666077], [95.96357727, 27.43548012], [95.96105194, 27.42871094], [95.95729065, 27.4328804], [95.95297241, 27.43328094], [95.95052338, 27.4372406], [95.95350647, 27.4407711], [95.95307159, 27.44345093], [95.94989014, 27.44502068], [95.94300079, 27.44639015], [95.93327332, 27.4466877], [95.91684723, 27.4431591], [95.91117096, 27.43996048], [95.90796661, 27.43264008], [95.90612793, 27.42326927], [95.90010071, 27.41133118], [95.89305878, 27.40604019], [95.89187622, 27.4097805], [95.89425659, 27.41438293], [95.89437866, 27.41828918], [95.89002991, 27.42641068], [95.88941956, 27.43162918], [95.89037323, 27.43967056], [95.88865662, 27.44407082], [95.88259125, 27.44408035], [95.87577057, 27.43535805], [95.86490631, 27.4290123], [95.8632431, 27.42485809], [95.86422729, 27.42131805], [95.8666687, 27.41921043], [95.86733246, 27.4171505], [95.85795593, 27.420681], [95.85761261, 27.42481995], [95.85573578, 27.42766953], [95.84934235, 27.43032074], [95.84947205, 27.43490982], [95.8529129, 27.44475937], [95.8551712, 27.44737053], [95.85955811, 27.44905281], [95.86379242, 27.45203018], [95.85945892, 27.46261024], [95.86116791, 27.46629906], [95.86606598, 27.46902275], [95.87625885, 27.47110939], [95.87843323, 27.4756012], [95.8812561, 27.48742104], [95.87915802, 27.49267006], [95.87905121, 27.49919128], [95.88046265, 27.50110054], [95.88604736, 27.50356293], [95.88964081, 27.50616837], [95.88710785, 27.51127052], [95.88179779, 27.51509094], [95.878479, 27.5198307], [95.88080597, 27.52251053], [95.87992096, 27.52979088], [95.88143921, 27.54583168], [95.8813324, 27.55323029], [95.87361908, 27.55117035], [95.86701965, 27.55109978], [95.86235809, 27.55260086], [95.85209656, 27.56565094], [95.84601593, 27.56799126], [95.83989716, 27.56661034], [95.83628845, 27.57117844], [95.83193207, 27.57888985], [95.82772827, 27.58175087], [95.82124329, 27.58172035], [95.81980896, 27.59028053], [95.82025909, 27.59557152], [95.82419586, 27.60301018], [95.82087708, 27.60472107], [95.81682587, 27.60543823], [95.80960846, 27.60527039], [95.79802704, 27.60783005], [95.79606628, 27.61819077], [95.79429626, 27.62236977], [95.787117, 27.62340927], [95.78504181, 27.62739944], [95.78734589, 27.63229942], [95.79741669, 27.63589096], [95.79734039, 27.6395607], [95.79959106, 27.64296913], [95.80145264, 27.6490097], [95.79485321, 27.65279961], [95.78623199, 27.65566063], [95.77922058, 27.66053963], [95.77784729, 27.66625977], [95.7784729, 27.67234993], [95.78044891, 27.67918968], [95.78549194, 27.68325996], [95.79453278, 27.68419075], [95.79647064, 27.68806076], [95.79312897, 27.69227028], [95.77876282, 27.69439125], [95.77455139, 27.69670105], [95.77266693, 27.69995117], [95.77336121, 27.70535088], [95.77262115, 27.71132088], [95.77052307, 27.7159996], [95.77039337, 27.72002983], [95.76304626, 27.72266006], [95.75871277, 27.72668076], [95.75821686, 27.73110962], [95.76267242, 27.73293114], [95.7718811, 27.73451042], [95.78479767, 27.73978043], [95.78777313, 27.74205017], [95.78053284, 27.75822067], [95.78882599, 27.7650528], [95.79538727, 27.77263069], [95.8009491, 27.77686119], [95.80636597, 27.78358078], [95.80757904, 27.78994942], [95.81131744, 27.79372025], [95.82312775, 27.80924988], [95.82894135, 27.81365967], [95.8349762, 27.8157711], [95.84336853, 27.82147026], [95.84599304, 27.83010101], [95.85209656, 27.83411026], [95.86633301, 27.83846092], [95.87372589, 27.83980179], [95.87657166, 27.84177017], [95.89209747, 27.85704041], [95.89422607, 27.86096001], [95.89502716, 27.86722183], [95.89763641, 27.86746979], [95.90055847, 27.86668015], [95.90722656, 27.8686409], [95.90618134, 27.87722969], [95.91137695, 27.87301826], [95.91409302, 27.87465096], [95.91291809, 27.8781395], [95.91400146, 27.88084984], [95.91866302, 27.88278008], [95.92262268, 27.88618088], [95.92127991, 27.8904705], [95.92375183, 27.89033127], [95.92735291, 27.88726044], [95.92855072, 27.89052963], [95.92392731, 27.89599991], [95.92501068, 27.90094185], [95.92864227, 27.9028511], [95.9383316, 27.90327072], [95.9393158, 27.90982056], [95.94351196, 27.91263962], [95.95249176, 27.92281914], [95.95529938, 27.92682076], [95.95381165, 27.93024063], [95.95754242, 27.9328804], [95.95755005, 27.93708038], [95.9523468, 27.93717957], [95.95155334, 27.93917084], [95.95231628, 27.94184113], [95.96520996, 27.9526329], [95.97746277, 27.96850014], [95.95688629, 27.96912956], [95.82588196, 27.97737122], [95.60674286, 27.95776939], [95.59694672, 27.95112991], [95.58866119, 27.94162941], [95.58053589, 27.94356155], [95.57121277, 27.94238091], [95.56626129, 27.93159103], [95.56504822, 27.92251968], [95.54380035, 27.91345978], [95.54206848, 27.91074181], [95.54434204, 27.9057827], [95.54353333, 27.90232277], [95.53302002, 27.90043068], [95.52622986, 27.89789963], [95.51595306, 27.88178825], [95.38433838, 27.84202194], [95.31655884, 27.87112999], [95.30847168, 27.86782074], [95.29254913, 27.86499023], [95.23654175, 27.84835052], [95.19486237, 27.83444977], [95.05182648, 27.7902298], [95.04886627, 27.78646088], [95.03875732, 27.77773094], [95.03121948, 27.77477074], [95.01914978, 27.77249908], [94.99787903, 27.77655029], [94.98703766, 27.77085114], [94.93003082, 27.75673103], [94.88394165, 27.74205971], [94.86086273, 27.73947906], [94.86602783, 27.73624039], [94.86071777, 27.73338127], [94.85357666, 27.73162079], [94.84879303, 27.71068192], [94.83938599, 27.7035408], [94.82126617, 27.6962204], [94.81803131, 27.69684029], [94.80021667, 27.69709015], [94.7975769, 27.69893265], [94.79534912, 27.69807816], [94.79405975, 27.69322014], [94.79099274, 27.6888504], [94.77645111, 27.68337822], [94.77216339, 27.6839695], [94.76693726, 27.68013954], [94.76432037, 27.67456055], [94.75955963, 27.66843987], [94.75592041, 27.66651917], [94.74266815, 27.66342163], [94.73703003, 27.66564941], [94.72767639, 27.66786003], [94.72554016, 27.67033958], [94.72070313, 27.66999054], [94.71663666, 27.6616497], [94.7130661, 27.66026115], [94.69808197, 27.66710091], [94.68940735, 27.66719055], [94.68387604, 27.66333961], [94.68650818, 27.65714264], [94.68699646, 27.65331078], [94.68251038, 27.64958954], [94.6757431, 27.65065193], [94.66911316, 27.65027809], [94.66464233, 27.64785957], [94.64842224, 27.64207077], [94.6452179, 27.63653946], [94.6397934, 27.63096046], [94.63445282, 27.62877083], [94.63069153, 27.62829018], [94.62497711, 27.63011932], [94.61406708, 27.62574005], [94.60938263, 27.62263107], [94.6040802, 27.62310028], [94.60060883, 27.62193108], [94.59577179, 27.6214695], [94.59146881, 27.62281036], [94.58629608, 27.62010956], [94.58185577, 27.61668015], [94.5735321, 27.60696983], [94.56947327, 27.60635185], [94.56389618, 27.6069603], [94.55612183, 27.60323906], [94.55171204, 27.60404968], [94.54641724, 27.60353279], [94.53659058, 27.59699059], [94.53173065, 27.59692955], [94.52628326, 27.59576988], [94.51566315, 27.58473015], [94.50940704, 27.58407021], [94.50022888, 27.57731056], [94.5, 27.57726479], [94.4909668, 27.57549286], [94.48310852, 27.57720184], [94.47915649, 27.57699013], [94.46930695, 27.56401253], [94.45973969, 27.55771065], [94.45622253, 27.56290245], [94.45346832, 27.57094002], [94.44960785, 27.57504082], [94.44238281, 27.57946014], [94.43605042, 27.58442116], [94.43058777, 27.59646034], [94.4310379, 27.60308075], [94.42092896, 27.60134125], [94.40318298, 27.58719063], [94.3948288, 27.58877945], [94.38759613, 27.58927917], [94.38437653, 27.58646011], [94.38043213, 27.58509064], [94.37583923, 27.58457756], [94.37230682, 27.57926941], [94.36749268, 27.5767498], [94.36219788, 27.58023071], [94.35569763, 27.57738113], [94.34884644, 27.57945061], [94.34507751, 27.58459091], [94.34057617, 27.58344078], [94.3381424, 27.58103943], [94.32905579, 27.58839035], [94.3237381, 27.58716965], [94.31970978, 27.59005165], [94.31240845, 27.58965111], [94.30835724, 27.59558105], [94.30164337, 27.59988022], [94.29801941, 27.60427094], [94.29289246, 27.60036087], [94.28848267, 27.59451103], [94.28765869, 27.59179115], [94.27603149, 27.59334946], [94.27520752, 27.59740067], [94.27245331, 27.60346985], [94.2618866, 27.61009979], [94.25408936, 27.61370087], [94.25710297, 27.61911964], [94.26222229, 27.62451935], [94.26716614, 27.62786293], [94.26670837, 27.63256073], [94.26278687, 27.63602066], [94.25907135, 27.6370182], [94.25598907, 27.63655281], [94.25222778, 27.64093018], [94.25006866, 27.63972092], [94.24726868, 27.63581085], [94.24507141, 27.63586998], [94.2350769, 27.63251114], [94.22595978, 27.61799049], [94.21743774, 27.60900116], [94.21111298, 27.61084175]]]}}, {\\\"id\\\": \\\"3\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.4_1\\\", \\\"HASC_1\\\": \\\"IN.AS\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Assam\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -7.0, \\\"dalys_apm25_rate_6cod_mean_total\\\": 754.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1977.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1223.0, \\\"geo-id\\\": 3, \\\"hpm25_child_popweighted\\\": -201.0, \\\"hpm25_female_popweighted\\\": -231.0, \\\"hpm25_male_popweighted\\\": -166.3, \\\"location\\\": \\\"Assam\\\", \\\"mort_apm25_6cod_mean_total\\\": 7712.0, \\\"mort_hpm25_6cod_mean_total\\\": -19627.0, \\\"mort_tpm25_6cod_mean_total\\\": -11915.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[89.83874512, 25.96647453], [89.8381424, 25.96792793], [89.83805084, 25.96814346], [89.83853912, 25.96846962], [89.83866119, 25.96846962], [89.840271, 25.96847153], [89.84041595, 25.96877861], [89.8411026, 25.97018814], [89.84141541, 25.9704113], [89.84187317, 25.97073936], [89.84549713, 25.97136688], [89.84825134, 25.97097397], [89.84980774, 25.97075272], [89.85055542, 25.97043419], [89.85138702, 25.97009277], [89.85182953, 25.96994209], [89.85231781, 25.96979523], [89.85293579, 25.96954918], [89.85355377, 25.96935654], [89.85520172, 25.968853], [89.85564423, 25.96887016], [89.85621643, 25.96889687], [89.85700989, 25.96895981], [89.85736847, 25.96899605], [89.85771179, 25.96902657], [89.8578949, 25.96903419], [89.85801697, 25.96904373], [89.85812378, 25.96906281], [89.85823059, 25.96909332], [89.85855865, 25.96917725], [89.85902405, 25.96932602], [89.85919189, 25.96936798], [89.85944366, 25.9694519], [89.85961914, 25.96953964], [89.85983276, 25.96960258], [89.85997009, 25.96965218], [89.86016083, 25.96974945], [89.8607254, 25.97003937], [89.86089325, 25.97013283], [89.86104584, 25.97020531], [89.86113739, 25.97024727], [89.86135101, 25.97036552], [89.8616333, 25.97056198], [89.86192322, 25.97074318], [89.86251068, 25.97109795], [89.8625946, 25.97118187], [89.86289978, 25.97140312], [89.86341858, 25.97167969], [89.86353302, 25.97171402], [89.86376953, 25.97178841], [89.86407471, 25.97185516], [89.86421967, 25.97188568], [89.86465454, 25.97194862], [89.86536407, 25.97203064], [89.86553192, 25.97201538], [89.86589813, 25.97204781], [89.86618805, 25.97205925], [89.86664581, 25.9720993], [89.86678314, 25.97215462], [89.86709595, 25.97234535], [89.86735535, 25.97250175], [89.86968231, 25.97347069], [89.87175751, 25.97416306], [89.8730545, 25.97569656], [89.87319946, 25.9758625], [89.87310791, 25.97602654], [89.87203217, 25.97788239], [89.87181091, 25.97829247], [89.8713913, 25.97840309], [89.87112427, 25.97847176], [89.87109375, 25.97855568], [89.87091827, 25.97901535], [89.87110138, 25.97981071], [89.87095642, 25.98057938], [89.87065887, 25.98145294], [89.87014008, 25.98161507], [89.86968231, 25.98175621], [89.86896515, 25.98130035], [89.86860657, 25.97977829], [89.86841583, 25.97963524], [89.86798096, 25.97930908], [89.86710358, 25.97948074], [89.86678314, 25.97999001], [89.86663055, 25.98022842], [89.86665344, 25.98039246], [89.86676788, 25.98114967], [89.86532593, 25.98236084], [89.86134338, 25.98441124], [89.85920715, 25.98507118], [89.85766602, 25.98558044], [89.85732269, 25.98594856], [89.85312653, 25.98754692], [89.85202026, 25.98945808], [89.85128784, 25.98963928], [89.85076141, 25.98976707], [89.85023499, 25.99020004], [89.84983063, 25.99090195], [89.84914398, 25.99209785], [89.84886932, 25.99290085], [89.84881592, 25.9929924], [89.84873962, 25.9929924], [89.84864044, 25.9932251], [89.84793854, 25.99493599], [89.84765625, 25.99603462], [89.84748077, 25.99669838], [89.84741974, 25.996912], [89.84722137, 25.99685669], [89.84723663, 25.99818993], [89.84725189, 25.99926949], [89.84758759, 26.00068474], [89.84761047, 26.0007782], [89.84618378, 26.00272942], [89.84420013, 26.00607872], [89.84405518, 26.00625038], [89.84383392, 26.00650215], [89.8430481, 26.00724411], [89.84289551, 26.00730133], [89.84237671, 26.00766182], [89.84169006, 26.00822639], [89.84137726, 26.00842667], [89.84091949, 26.00859833], [89.84034729, 26.00886726], [89.84001923, 26.00894928], [89.83961487, 26.00901985], [89.83930206, 26.00923157], [89.83898926, 26.00947762], [89.83875275, 26.00968933], [89.83747101, 26.00850105], [89.83656311, 26.00653076], [89.83650208, 26.00555992], [89.83638, 26.00390816], [89.83583069, 26.00119019], [89.8349762, 25.9995594], [89.83432007, 25.99747086], [89.83566284, 25.99500084], [89.83644104, 25.99277115], [89.83673096, 25.99158096], [89.83612061, 25.98913956], [89.83740997, 25.98718834], [89.83912659, 25.98476982], [89.83922577, 25.98323059], [89.8397522, 25.98101044], [89.83757782, 25.97944832], [89.83476257, 25.98006058], [89.8325119, 25.98084068], [89.82887268, 25.9811306], [89.82637024, 25.98219109], [89.82344055, 25.98451996], [89.8229599, 25.98490906], [89.82112122, 25.98688507], [89.82080078, 25.98722458], [89.82067871, 25.98735428], [89.82045746, 25.9875946], [89.82034302, 25.98764801], [89.82015228, 25.98774147], [89.81975555, 25.98828697], [89.81951141, 25.98859024], [89.81928253, 25.98888397], [89.81919098, 25.989048], [89.8190918, 25.98921967], [89.8188324, 25.98950577], [89.81877136, 25.98965836], [89.81873322, 25.98976135], [89.81855011, 25.99002075], [89.8175354, 25.99128532], [89.81739807, 25.9914875], [89.81728363, 25.99177742], [89.81716156, 25.99200821], [89.81700897, 25.9923172], [89.81671906, 25.99288559], [89.81653595, 25.9931469], [89.81649017, 25.99333191], [89.81627655, 25.99374771], [89.81609344, 25.99423409], [89.81575775, 25.99526978], [89.81546021, 25.99592781], [89.81539154, 25.99630356], [89.81524658, 25.99662399], [89.81510162, 25.99703598], [89.81498718, 25.99749184], [89.81491852, 25.99757576], [89.81481171, 25.99794769], [89.81490326, 25.99801636], [89.81520844, 25.9977932], [89.81573486, 25.99743271], [89.81608582, 25.99718857], [89.81645966, 25.99694633], [89.8167038, 25.99674416], [89.81687927, 25.99657631], [89.81704712, 25.99641609], [89.81746674, 25.99617958], [89.8176651, 25.99611282], [89.81803894, 25.9960289], [89.81812286, 25.99600601], [89.81826019, 25.99596786], [89.81855011, 25.9959507], [89.81890106, 25.99600601], [89.8192215, 25.99604988], [89.8194809, 25.99622536], [89.81975555, 25.99651146], [89.81987762, 25.99668121], [89.81995392, 25.99678993], [89.82012177, 25.99710846], [89.82021332, 25.99736023], [89.82029724, 25.99750328], [89.82041931, 25.99803734], [89.82046509, 25.9984684], [89.82050323, 25.9987812], [89.82055664, 25.99965286], [89.82032776, 26.00021362], [89.81998444, 26.00094604], [89.81988525, 26.00123978], [89.81968689, 26.00172615], [89.81924438, 26.00263023], [89.81900787, 26.00314903], [89.81905365, 26.00339699], [89.81912231, 26.00422096], [89.81915283, 26.00434113], [89.81918335, 26.0044651], [89.81938934, 26.00507736], [89.81945801, 26.00517654], [89.81968689, 26.00561905], [89.81980133, 26.00593567], [89.82001495, 26.00649261], [89.8201828, 26.00703621], [89.82027435, 26.00734901], [89.82038879, 26.00779724], [89.82078552, 26.00777626], [89.8213501, 26.00775528], [89.82189178, 26.00772095], [89.82196045, 26.00806236], [89.82192993, 26.00832367], [89.8219223, 26.00857544], [89.8218689, 26.00889206], [89.82183838, 26.00915909], [89.82184601, 26.00939941], [89.82188416, 26.00977135], [89.82194519, 26.01003838], [89.82151794, 26.01045036], [89.82132721, 26.01062965], [89.82131195, 26.01089287], [89.82131195, 26.01100159], [89.82130432, 26.0112381], [89.82129669, 26.01142502], [89.82126617, 26.01173019], [89.82122803, 26.01200104], [89.82118988, 26.0120697], [89.82082367, 26.01243591], [89.82050323, 26.01271629], [89.82032013, 26.01288986], [89.82000732, 26.01318741], [89.81981659, 26.01338959], [89.81971741, 26.01350212], [89.8196106, 26.01366997], [89.81954193, 26.01387787], [89.81946564, 26.01408386], [89.81931305, 26.01450539], [89.81919098, 26.01483154], [89.81905365, 26.01530075], [89.81893921, 26.01554298], [89.8188858, 26.01569366], [89.81860352, 26.01597595], [89.81820679, 26.01637268], [89.8179245, 26.01664352], [89.81773376, 26.01685715], [89.81761169, 26.01697731], [89.81747437, 26.01711655], [89.81699371, 26.01722145], [89.81666565, 26.01729774], [89.81633759, 26.01714897], [89.81613922, 26.01707458], [89.8160553, 26.01723099], [89.81576538, 26.01772308], [89.81568146, 26.0179615], [89.81557465, 26.01820564], [89.81548309, 26.01860619], [89.81539154, 26.0192337], [89.81533813, 26.01969719], [89.81529999, 26.02031136], [89.81539154, 26.02064133], [89.81543732, 26.02082253], [89.8155365, 26.02106857], [89.81563568, 26.02127457], [89.81569672, 26.02143288], [89.81589508, 26.02168846], [89.81627655, 26.02228737], [89.81647491, 26.02260399], [89.81668854, 26.02291107], [89.81700897, 26.02331161], [89.81731415, 26.02365685], [89.81748962, 26.02382469], [89.81765747, 26.02400589], [89.81782532, 26.02427673], [89.81790161, 26.02445984], [89.81829834, 26.02493668], [89.81864929, 26.02526665], [89.8192215, 26.02591515], [89.81880951, 26.02632141], [89.81859589, 26.0265274], [89.81835175, 26.02679443], [89.8181076, 26.02703476], [89.81785583, 26.02731514], [89.81735992, 26.02783394], [89.81715393, 26.0280304], [89.81686401, 26.02829933], [89.81681061, 26.02834892], [89.8164978, 26.02862167], [89.8161087, 26.02898216], [89.81578827, 26.02926826], [89.81547546, 26.02953529], [89.81522369, 26.0297699], [89.81492615, 26.03006172], [89.81480408, 26.03023338], [89.81453705, 26.03066444], [89.81430054, 26.03102493], [89.81400299, 26.03151131], [89.81378937, 26.03189468], [89.81370544, 26.03212357], [89.81364441, 26.03236389], [89.81358337, 26.03264999], [89.81356049, 26.03296089], [89.81352234, 26.03321075], [89.81347656, 26.03354645], [89.8134079, 26.03386879], [89.81334686, 26.03427505], [89.81327057, 26.03463554], [89.81322479, 26.03510284], [89.81315613, 26.03570366], [89.81311798, 26.03596306], [89.81310272, 26.03614807], [89.81291962, 26.03606224], [89.81287384, 26.03636742], [89.81279755, 26.03701591], [89.81275177, 26.03718948], [89.81253815, 26.03798485], [89.81242371, 26.03840065], [89.81231689, 26.03874969], [89.81227112, 26.03880692], [89.81197357, 26.03918648], [89.81208801, 26.03939819], [89.81201172, 26.03953552], [89.81190491, 26.03981209], [89.81170654, 26.04030991], [89.81156158, 26.04061127], [89.81138611, 26.04090118], [89.811203, 26.04115105], [89.81088257, 26.04155922], [89.81075287, 26.04169273], [89.81053925, 26.04191589], [89.81032562, 26.04211235], [89.80995178, 26.04245377], [89.80960846, 26.04276657], [89.80947113, 26.04286957], [89.80908203, 26.0431366], [89.80883026, 26.04328537], [89.80860901, 26.0434227], [89.80597687, 26.04462433], [89.80558777, 26.04457092], [89.80532074, 26.04412079], [89.80517578, 26.04386139], [89.80503845, 26.04359627], [89.80499268, 26.04349327], [89.80460358, 26.04235649], [89.80451202, 26.04200554], [89.80450439, 26.04147911], [89.80457306, 26.04128265], [89.80453491, 26.04093742], [89.80456543, 26.04066658], [89.80457306, 26.0404129], [89.80449677, 26.04011536], [89.80436707, 26.03981209], [89.80412292, 26.03966713], [89.80393982, 26.0396328], [89.8037796, 26.03963089], [89.80361176, 26.03886032], [89.80342102, 26.03786659], [89.80329895, 26.03721619], [89.80319977, 26.03664017], [89.8030777, 26.03606224], [89.80303955, 26.03581619], [89.80297852, 26.03540802], [89.80290985, 26.03507233], [89.80284882, 26.03478622], [89.80278778, 26.03450394], [89.8026886, 26.03409576], [89.80259705, 26.03363419], [89.80256653, 26.03328705], [89.80240631, 26.0327816], [89.80214691, 26.03212738], [89.80198669, 26.0317955], [89.80182648, 26.03152657], [89.80167389, 26.03134537], [89.80151367, 26.03112984], [89.80125427, 26.0308094], [89.80111694, 26.03064728], [89.80096436, 26.03042603], [89.80085754, 26.03022957], [89.80065918, 26.02986145], [89.8004837, 26.02939034], [89.80027771, 26.0288887], [89.79985046, 26.02820206], [89.79960632, 26.02774239], [89.79943085, 26.02744293], [89.79924011, 26.02709389], [89.79909515, 26.02677727], [89.79879761, 26.02624512], [89.79853058, 26.02586174], [89.79797363, 26.02505112], [89.7976532, 26.02462387], [89.79755402, 26.02450562], [89.79716492, 26.02409744], [89.79677582, 26.02369499], [89.7964859, 26.02337456], [89.79615021, 26.02312851], [89.79521942, 26.02302933], [89.79497528, 26.02327347], [89.79434204, 26.02299881], [89.79418182, 26.02239799], [89.79415894, 26.02232742], [89.79423523, 26.02228165], [89.79456329, 26.02209282], [89.79476929, 26.02205849], [89.7953186, 26.02191353], [89.7950592, 26.02174759], [89.79485321, 26.02165413], [89.79467773, 26.0215435], [89.79477692, 26.02141571], [89.79450989, 26.02115059], [89.79436493, 26.0210228], [89.79425812, 26.02087593], [89.79412079, 26.02059174], [89.79392242, 26.02036476], [89.79377747, 26.02028656], [89.79321289, 26.01963425], [89.79306793, 26.01951981], [89.79277039, 26.01918983], [89.79235077, 26.01880836], [89.79174042, 26.01835823], [89.79151917, 26.01822472], [89.7914505, 26.0181179], [89.79084778, 26.01800728], [89.79056549, 26.01789665], [89.79026794, 26.01786613], [89.79000854, 26.0178833], [89.7898941, 26.0179081], [89.78935242, 26.0181675], [89.78910065, 26.01831436], [89.78878784, 26.01848221], [89.78871155, 26.0185318], [89.78838348, 26.01882172], [89.7879715, 26.01930618], [89.78768158, 26.01973152], [89.78749847, 26.02000809], [89.7874527, 26.02018738], [89.78738403, 26.02046585], [89.78739929, 26.02062225], [89.78742218, 26.02071953], [89.7874527, 26.02086449], [89.78760529, 26.02136421], [89.78775787, 26.0214653], [89.78787994, 26.02137947], [89.78863525, 26.02083969], [89.79151917, 26.02095985], [89.79206085, 26.02116585], [89.79248047, 26.02146912], [89.79291534, 26.02176285], [89.79319, 26.02207184], [89.79367065, 26.02248764], [89.79381561, 26.02263451], [89.79387665, 26.02301788], [89.79393768, 26.02346992], [89.79334259, 26.02506256], [89.79322052, 26.02586746], [89.79330444, 26.02697945], [89.79347229, 26.02766037], [89.79366302, 26.02822495], [89.7950592, 26.02851486], [89.79512787, 26.02864647], [89.79521942, 26.02873611], [89.79536438, 26.028862], [89.79573059, 26.02923203], [89.79598236, 26.02923775], [89.79627228, 26.02928162], [89.79646301, 26.02952766], [89.79672241, 26.02973557], [89.79698944, 26.02998543], [89.79734039, 26.03035164], [89.79763794, 26.03071022], [89.79781342, 26.03095818], [89.7974472, 26.03112221], [89.79779053, 26.03160858], [89.79794312, 26.03183365], [89.79810333, 26.03210258], [89.79826355, 26.03239059], [89.7984314, 26.03268051], [89.79864502, 26.03311729], [89.79844666, 26.03318787], [89.79858398, 26.03357315], [89.79868317, 26.03398323], [89.79870605, 26.03412819], [89.79878998, 26.03435516], [89.7990799, 26.03495407], [89.79927826, 26.0353241], [89.79965973, 26.03586006], [89.80003357, 26.03629684], [89.80010986, 26.03653336], [89.80054474, 26.03679276], [89.80104065, 26.03701973], [89.80126953, 26.0371666], [89.8015976, 26.03748894], [89.80174255, 26.03764153], [89.80189514, 26.03777504], [89.80214691, 26.03810501], [89.80224609, 26.03832626], [89.80226898, 26.03860664], [89.80194855, 26.03866577], [89.80184174, 26.0390873], [89.80173492, 26.03936386], [89.80157471, 26.03962135], [89.80157471, 26.03983688], [89.80163574, 26.04002762], [89.80177307, 26.04035378], [89.8014679, 26.04052162], [89.80132294, 26.04060173], [89.80089569, 26.04084206], [89.80056763, 26.04106712], [89.80045319, 26.04107094], [89.79971313, 26.04109955], [89.79767609, 26.03982925], [89.79749298, 26.03906059], [89.79720306, 26.03784943], [89.79740906, 26.03557014], [89.79574585, 26.03388977], [89.79367065, 26.03415108], [89.79273987, 26.03495216], [89.7926178, 26.03505516], [89.79251862, 26.03523064], [89.79244995, 26.03559685], [89.79230499, 26.03523827], [89.79212189, 26.03500175], [89.79176331, 26.03472137], [89.79144287, 26.03457832], [89.7910614, 26.03447533], [89.79077148, 26.03439331], [89.79058838, 26.03437424], [89.79006958, 26.0344162], [89.7896347, 26.03458023], [89.78948212, 26.03467941], [89.7893219, 26.03483582], [89.78911591, 26.03496552], [89.78899384, 26.03506279], [89.78889465, 26.03505135], [89.78877258, 26.03512001], [89.78868866, 26.03517151], [89.78856659, 26.03516769], [89.78844452, 26.03516197], [89.7882843, 26.03509331], [89.7881012, 26.03530693], [89.7879715, 26.03550911], [89.78780365, 26.03578949], [89.7877121, 26.03593445], [89.78765106, 26.03608704], [89.78755188, 26.03633118], [89.78752899, 26.03651619], [89.78751373, 26.03662872], [89.78752136, 26.03691483], [89.78754425, 26.03709984], [89.78760529, 26.03732491], [89.78775024, 26.03764153], [89.78784943, 26.03780937], [89.78822327, 26.03823471], [89.78852844, 26.03860283], [89.78877258, 26.03891563], [89.78904724, 26.0392437], [89.78929138, 26.03949165], [89.78942871, 26.03963661], [89.78765869, 26.03970146], [89.78556824, 26.03861046], [89.78528595, 26.03833961], [89.78344727, 26.03659058], [89.78247833, 26.0351181], [89.78119659, 26.03412056], [89.78031921, 26.033741], [89.77900696, 26.03443909], [89.77793121, 26.03570557], [89.7779541, 26.03656769], [89.77776337, 26.03629875], [89.7776413, 26.0361557], [89.77739716, 26.03594589], [89.77729034, 26.03582382], [89.77700806, 26.03549004], [89.77685547, 26.03528214], [89.77671814, 26.03515434], [89.77661133, 26.0350666], [89.77651215, 26.03501701], [89.77599335, 26.0354557], [89.77586365, 26.0355835], [89.77555084, 26.03590775], [89.77510071, 26.03635979], [89.77471924, 26.03671837], [89.7743454, 26.03709602], [89.77416229, 26.03727341], [89.77398682, 26.03746033], [89.77383423, 26.03759193], [89.77357483, 26.03773117], [89.77373505, 26.03808975], [89.77380371, 26.03833771], [89.77378082, 26.03841019], [89.77386475, 26.03855324], [89.77394104, 26.03884888], [89.77405548, 26.03907967], [89.77420044, 26.03938484], [89.77435303, 26.03957367], [89.77458191, 26.03991508], [89.77466583, 26.04006004], [89.77511597, 26.04049301], [89.77529144, 26.04063606], [89.77547455, 26.04082298], [89.77574921, 26.04109001], [89.77596283, 26.04128647], [89.77627563, 26.041605], [89.77708435, 26.04240799], [89.7774353, 26.04276466], [89.77770233, 26.04309654], [89.77796173, 26.04336548], [89.77840424, 26.04379463], [89.7791748, 26.04449081], [89.77960205, 26.04469681], [89.77985382, 26.04486465], [89.78000641, 26.04495049], [89.7802124, 26.04508018], [89.78042603, 26.04512024], [89.78083801, 26.04512787], [89.78119659, 26.04510117], [89.78160858, 26.045084], [89.78197479, 26.04508781], [89.78209686, 26.04510307], [89.78253937, 26.04520798], [89.78272247, 26.04526901], [89.78298187, 26.04545403], [89.78314972, 26.04560852], [89.78348541, 26.04597092], [89.78369904, 26.04627037], [89.78378296, 26.04640007], [89.78383636, 26.0464859], [89.78396606, 26.04668999], [89.78420258, 26.04692268], [89.7843399, 26.04699707], [89.7844162, 26.04707909], [89.78456116, 26.04711342], [89.78448486, 26.04735374], [89.78445435, 26.04756737], [89.78444672, 26.04765892], [89.78488159, 26.0476017], [89.78578949, 26.04755402], [89.78781891, 26.04781342], [89.78822327, 26.04940033], [89.78812408, 26.04984474], [89.78651428, 26.05127907], [89.78625488, 26.05132294], [89.78591156, 26.05136108], [89.78536224, 26.05140686], [89.78465271, 26.0514164], [89.78468323, 26.05194855], [89.78458405, 26.05201149], [89.78453064, 26.05259705], [89.78468323, 26.05262566], [89.78479004, 26.05264854], [89.7846756, 26.05310059], [89.78462982, 26.05347061], [89.78461456, 26.0538311], [89.78462219, 26.05396652], [89.78450012, 26.05395317], [89.78424835, 26.05392647], [89.7841568, 26.05429459], [89.78443909, 26.05434036], [89.78475189, 26.05439377], [89.7846756, 26.05523109], [89.78462219, 26.05577278], [89.7845993, 26.05599594], [89.7846756, 26.05600548], [89.78509521, 26.05605698], [89.78511047, 26.05629349], [89.78516388, 26.05635262], [89.7852478, 26.05697632], [89.78570557, 26.0569458], [89.78570557, 26.05723], [89.78649902, 26.05718231], [89.78656769, 26.05696869], [89.78695679, 26.05709839], [89.7875061, 26.05712509], [89.78796387, 26.05715561], [89.78808594, 26.05685806], [89.78862762, 26.05698776], [89.78910065, 26.057127], [89.7898407, 26.05733871], [89.79026794, 26.0574379], [89.79063416, 26.0574894], [89.79078674, 26.05747223], [89.79092407, 26.05747223], [89.79108429, 26.05741882], [89.7911911, 26.05739403], [89.79135132, 26.05738449], [89.79179382, 26.05743027], [89.79212952, 26.05753136], [89.79237366, 26.05757713], [89.7926178, 26.05761528], [89.79303741, 26.05770683], [89.79341888, 26.05776215], [89.79373932, 26.0578289], [89.79447937, 26.05791473], [89.79447937, 26.05798721], [89.79504395, 26.05809593], [89.79586792, 26.05825424], [89.79576111, 26.05866623], [89.79593658, 26.05875015], [89.79592896, 26.05888939], [89.79594421, 26.05903435], [89.79595184, 26.0592308], [89.79598236, 26.05937004], [89.79592896, 26.05953979], [89.79595947, 26.05974579], [89.79633331, 26.05972672], [89.79671478, 26.05971909], [89.79706573, 26.0596714], [89.79763794, 26.05953217], [89.79769897, 26.05942345], [89.79798126, 26.05935287], [89.79786682, 26.05905151], [89.79815674, 26.05898094], [89.79872131, 26.05966377], [89.7987442, 26.06012535], [89.79873657, 26.06026268], [89.79872131, 26.06040764], [89.79866028, 26.06086731], [89.79846954, 26.06094933], [89.7983017, 26.06154251], [89.79807281, 26.06214523], [89.79795074, 26.06214333], [89.79785919, 26.06249809], [89.79782867, 26.0627594], [89.79772186, 26.06269073], [89.79756165, 26.06262398], [89.79730988, 26.06253052], [89.79727936, 26.06266594], [89.79727173, 26.06285095], [89.79724121, 26.06302071], [89.79721832, 26.06317139], [89.7973175, 26.06336594], [89.79741669, 26.06336021], [89.79759216, 26.06334877], [89.79792786, 26.06333542], [89.79798126, 26.06351089], [89.79815674, 26.06351471], [89.79820251, 26.06358337], [89.79839325, 26.0637207], [89.79847717, 26.06381035], [89.79856873, 26.06397057], [89.79862213, 26.06409264], [89.79853058, 26.06454849], [89.79849243, 26.06487083], [89.7984314, 26.06512642], [89.79803467, 26.06516457], [89.79792786, 26.06506348], [89.79777527, 26.06484985], [89.79769135, 26.06468391], [89.79759979, 26.0644989], [89.79729462, 26.0644455], [89.79698181, 26.06435394], [89.7966156, 26.06435585], [89.79628754, 26.06443405], [89.79603577, 26.0645504], [89.79590607, 26.06460762], [89.7958374, 26.06453705], [89.79548645, 26.06466103], [89.79556274, 26.06487274], [89.79558563, 26.06506157], [89.79560089, 26.06514549], [89.79563904, 26.06541252], [89.79576111, 26.06542397], [89.79579926, 26.06556129], [89.79588318, 26.06555176], [89.79605865, 26.06592751], [89.79637146, 26.06590462], [89.79647064, 26.0658989], [89.79711151, 26.06590271], [89.79709625, 26.06575012], [89.79749298, 26.06574631], [89.79764557, 26.06573105], [89.79789734, 26.06575012], [89.79807281, 26.06579781], [89.79798126, 26.06592751], [89.79788971, 26.06608391], [89.79782867, 26.06615067], [89.79776001, 26.06623077], [89.79756165, 26.06669426], [89.79746246, 26.06694984], [89.79740143, 26.06715012], [89.79728699, 26.06757164], [89.79714203, 26.06835938], [89.79720306, 26.06840515], [89.79706573, 26.06923103], [89.79695892, 26.06961632], [89.79682159, 26.07001686], [89.79675293, 26.07031822], [89.79663086, 26.07093048], [89.79624176, 26.07118607], [89.7959671, 26.07138634], [89.79559326, 26.07174301], [89.79536438, 26.07194519], [89.79518127, 26.07215691], [89.79510498, 26.07232285], [89.79497528, 26.07259941], [89.79489136, 26.07298088], [89.79488373, 26.07323456], [89.79491425, 26.07336235], [89.79493713, 26.07346916], [89.79499054, 26.07357025], [89.79510498, 26.0737133], [89.79547119, 26.07402229], [89.79572296, 26.07424927], [89.79577637, 26.07432556], [89.79538727, 26.07484055], [89.79572296, 26.07649994], [89.795578, 26.07646179], [89.79545593, 26.07693672], [89.79494476, 26.07690239], [89.79476166, 26.07714462], [89.79419708, 26.07692528], [89.79402161, 26.07685661], [89.79371643, 26.07674026], [89.79370117, 26.07641983], [89.79333496, 26.0762558], [89.7931366, 26.07603645], [89.79264069, 26.07580566], [89.79251099, 26.07573891], [89.79211426, 26.07552528], [89.79191589, 26.07541084], [89.79174042, 26.07531357], [89.79133606, 26.07505417], [89.79076385, 26.07525253], [89.79031372, 26.0755291], [89.79031372, 26.07595444], [89.79048157, 26.07631302], [89.79148865, 26.07843971], [89.79244995, 26.08015251], [89.79296875, 26.0806942], [89.79321289, 26.08093643], [89.7935791, 26.08132553], [89.79410553, 26.08190727], [89.79429626, 26.08220863], [89.79451752, 26.08254242], [89.7948761, 26.0832653], [89.79496765, 26.08348656], [89.79499817, 26.08369637], [89.79502106, 26.08378792], [89.79510498, 26.08422852], [89.7951355, 26.08454514], [89.79512024, 26.0850296], [89.79509735, 26.08538437], [89.79496765, 26.08540726], [89.79496002, 26.08597946], [89.79494476, 26.08636856], [89.79486084, 26.08727455], [89.79453278, 26.08723068], [89.79219818, 26.08493805], [89.79190826, 26.08465004], [89.78978729, 26.08218956], [89.78813171, 26.08119011], [89.78588867, 26.08320808], [89.78588867, 26.08335114], [89.78586578, 26.08461761], [89.78542328, 26.08401299], [89.78518677, 26.08364487], [89.7850647, 26.08347511], [89.78453827, 26.08343315], [89.78431702, 26.08341599], [89.78420258, 26.08340645], [89.7832489, 26.08333015], [89.78209686, 26.08324051], [89.78211975, 26.08343697], [89.78121948, 26.08355331], [89.78131104, 26.08384132], [89.78137207, 26.08418274], [89.78148651, 26.08496666], [89.78167725, 26.08497238], [89.78166962, 26.0852375], [89.78165436, 26.08551788], [89.78165436, 26.08577347], [89.7816925, 26.08611679], [89.78170776, 26.08653831], [89.78155518, 26.0873909], [89.78192139, 26.08820343], [89.78256989, 26.08965492], [89.78244781, 26.09026146], [89.78237915, 26.09057426], [89.78243256, 26.090662], [89.78266144, 26.09094238], [89.78270721, 26.09103394], [89.78277588, 26.09127045], [89.78285217, 26.09141922], [89.78296661, 26.09157372], [89.78294373, 26.09165192], [89.78285217, 26.09203911], [89.78278351, 26.09250259], [89.78282928, 26.09278488], [89.78286743, 26.09306526], [89.78291321, 26.09333038], [89.78301239, 26.09367561], [89.7831955, 26.09404373], [89.7833252, 26.09427261], [89.78343964, 26.09448433], [89.78354645, 26.09463501], [89.78374481, 26.0948391], [89.78385925, 26.09483719], [89.78448486, 26.09532928], [89.784729, 26.09549904], [89.78552246, 26.09606743], [89.78596497, 26.09641075], [89.78568268, 26.09712982], [89.78547668, 26.0976429], [89.78526306, 26.09819221], [89.78430939, 26.09880257], [89.78405762, 26.09867477], [89.78385925, 26.0986042], [89.78374481, 26.09856606], [89.783638, 26.09852791], [89.78302002, 26.09839821], [89.78253937, 26.09834099], [89.78217316, 26.09830666], [89.78173065, 26.09830093], [89.78164673, 26.09887886], [89.78156281, 26.09950829], [89.78173065, 26.09965897], [89.78178406, 26.09970856], [89.78208923, 26.09998131], [89.78224945, 26.10013962], [89.78245544, 26.10033417], [89.7828598, 26.10081482], [89.78309631, 26.10106468], [89.78331757, 26.10128021], [89.78357697, 26.10142326], [89.78374481, 26.10149193], [89.78427887, 26.10149956], [89.78439331, 26.10152245], [89.78479004, 26.10150719], [89.78495789, 26.10148811], [89.78529358, 26.1014328], [89.78573608, 26.10133934], [89.7857666, 26.10145569], [89.7857666, 26.10154724], [89.78572083, 26.10173225], [89.7855835, 26.10204506], [89.78553772, 26.10242653], [89.78553009, 26.10271835], [89.7855072, 26.1029129], [89.78530884, 26.10372925], [89.78523254, 26.10386467], [89.78509521, 26.10408211], [89.78466797, 26.10467148], [89.78440094, 26.10505676], [89.78420258, 26.10530663], [89.78411865, 26.10540009], [89.78384399, 26.10560226], [89.78326416, 26.10598755], [89.78289032, 26.10580063], [89.7802887, 26.10451126], [89.77710724, 26.10347176], [89.77410889, 26.10420036], [89.7723999, 26.10549736], [89.77219391, 26.10540581], [89.7718277, 26.10524559], [89.77159119, 26.10514832], [89.77093506, 26.10483932], [89.77056885, 26.10465431], [89.77044678, 26.10468674], [89.77030182, 26.10470009], [89.7701416, 26.1046772], [89.76988983, 26.10461617], [89.7696991, 26.10485649], [89.7695694, 26.10528564], [89.76947784, 26.10560226], [89.76928711, 26.10614204], [89.76909637, 26.10660172], [89.76902771, 26.10678673], [89.76894379, 26.10689926], [89.76870728, 26.10705948], [89.76855469, 26.10735321], [89.76849365, 26.1076622], [89.76837921, 26.10788345], [89.76828003, 26.1080761], [89.7681427, 26.10810089], [89.76803589, 26.10811996], [89.76780701, 26.10816193], [89.76744843, 26.10820198], [89.76686859, 26.10829926], [89.7652359, 26.10783958], [89.76281738, 26.10716057], [89.76104736, 26.10691071], [89.75933838, 26.10880852], [89.75912476, 26.10861588], [89.75879669, 26.10838699], [89.75843048, 26.10817528], [89.75798035, 26.10798836], [89.75760651, 26.10798264], [89.75649261, 26.10891724], [89.75642395, 26.1090126], [89.75634766, 26.10911942], [89.75611115, 26.10946846], [89.75600433, 26.10967445], [89.75588226, 26.11005592], [89.7558136, 26.11015511], [89.7556839, 26.11058617], [89.75557709, 26.11095047], [89.75545502, 26.11136055], [89.75527954, 26.11195564], [89.75521088, 26.11231613], [89.75517273, 26.1127491], [89.75519562, 26.11296463], [89.75525665, 26.11329842], [89.7552948, 26.11368942], [89.75534821, 26.11382866], [89.75539398, 26.11390686], [89.75622559, 26.11441422], [89.75707245, 26.11489868], [89.75778961, 26.11509705], [89.75778961, 26.11539078], [89.75785828, 26.11545372], [89.75803375, 26.11565971], [89.75836182, 26.1160965], [89.75879669, 26.11664963], [89.75914764, 26.11709595], [89.75941467, 26.1173954], [89.75955963, 26.11754417], [89.75974274, 26.11769104], [89.76021576, 26.11811066], [89.76060486, 26.11847115], [89.76074982, 26.1186409], [89.76113129, 26.11915779], [89.76121521, 26.11927223], [89.76138306, 26.11956978], [89.76171875, 26.12016296], [89.76196289, 26.12062263], [89.76216888, 26.12104607], [89.76246643, 26.12142372], [89.76275635, 26.12190628], [89.76307678, 26.12232018], [89.76325226, 26.12256813], [89.76338196, 26.12275887], [89.76379395, 26.12335396], [89.76402283, 26.12366104], [89.76409149, 26.12375641], [89.76439667, 26.12409973], [89.76486206, 26.12458038], [89.76506042, 26.12477493], [89.76515961, 26.12490082], [89.76530457, 26.12512398], [89.76555634, 26.12564278], [89.76564026, 26.12578964], [89.76590729, 26.12640953], [89.76615906, 26.12674904], [89.76615906, 26.1271019], [89.76636505, 26.12752914], [89.76641846, 26.12767029], [89.76643372, 26.12777138], [89.76644897, 26.12805367], [89.76646423, 26.12828445], [89.76647186, 26.1284523], [89.76651001, 26.12883186], [89.76654816, 26.129282], [89.7665329, 26.12981415], [89.76641083, 26.13033676], [89.76641846, 26.13080788], [89.76636505, 26.13098145], [89.76616669, 26.13136864], [89.76597595, 26.13175392], [89.76583862, 26.13202286], [89.76551819, 26.1326046], [89.76532745, 26.13294983], [89.76507568, 26.13337517], [89.76486969, 26.13372612], [89.76480103, 26.13387108], [89.76468658, 26.13419724], [89.76449585, 26.13474846], [89.76430511, 26.13521957], [89.76409149, 26.135746], [89.76386261, 26.1360569], [89.76356506, 26.13647461], [89.76329041, 26.13684654], [89.76319122, 26.13698006], [89.75913239, 26.13837051], [89.7589798, 26.13853264], [89.75862885, 26.13860321], [89.75823212, 26.13874245], [89.75787354, 26.13889885], [89.75759125, 26.13898277], [89.75697327, 26.13909721], [89.75647736, 26.13919067], [89.75602722, 26.13924217], [89.75575256, 26.1392765], [89.75544739, 26.13936615], [89.7550354, 26.13944244], [89.75497437, 26.13920975], [89.75437164, 26.13998604], [89.75411987, 26.14030647], [89.75434113, 26.14287758], [89.75397491, 26.14601326], [89.7537384, 26.14679146], [89.75308228, 26.14848518], [89.75265503, 26.1495018], [89.75213623, 26.15047073], [89.7517395, 26.15120888], [89.75151062, 26.15165901], [89.751297, 26.1519928], [89.75112915, 26.15226746], [89.75086212, 26.1527977], [89.75057983, 26.15316772], [89.75004578, 26.15393257], [89.74978638, 26.15431023], [89.74925232, 26.15512657], [89.74880981, 26.15579414], [89.74856567, 26.15618134], [89.74837494, 26.15642548], [89.74759674, 26.157444], [89.74662781, 26.15813828], [89.74652863, 26.15815735], [89.74593353, 26.1585083], [89.74521637, 26.15890312], [89.7444458, 26.15912056], [89.7437973, 26.15930367], [89.74355316, 26.15938187], [89.74324036, 26.15939522], [89.74297333, 26.15939331], [89.74226379, 26.15929031], [89.74193573, 26.15922546], [89.74160004, 26.15917778], [89.74110413, 26.15912628], [89.7410202, 26.15911293], [89.74073792, 26.15902901], [89.7406311, 26.15901184], [89.74006653, 26.15887451], [89.73973846, 26.15879822], [89.73928833, 26.15872955], [89.73899841, 26.15851212], [89.7390213, 26.15882492], [89.73882294, 26.15915489], [89.73825836, 26.15914345], [89.7374115, 26.15921402], [89.73743439, 26.1587429], [89.73688507, 26.15832329], [89.73639679, 26.15834236], [89.73616028, 26.15870285], [89.73565674, 26.15867424], [89.73509979, 26.15877151], [89.73480988, 26.15823746], [89.73455048, 26.15777397], [89.73419952, 26.15788841], [89.73403931, 26.157938], [89.73369598, 26.15807533], [89.73331451, 26.15812492], [89.73291016, 26.15819359], [89.73281097, 26.15823555], [89.73258972, 26.1582737], [89.73233032, 26.15831947], [89.73197174, 26.15837479], [89.73137665, 26.15832329], [89.73083496, 26.15830612], [89.73027802, 26.15825653], [89.72986603, 26.15818977], [89.72896576, 26.15811157], [89.72852325, 26.15796471], [89.7279892, 26.1577816], [89.72712708, 26.15764999], [89.72642517, 26.15754128], [89.72593689, 26.15748596], [89.72480011, 26.15730476], [89.72452545, 26.15720367], [89.72394562, 26.15698814], [89.72354126, 26.15684128], [89.72310638, 26.15653229], [89.72274017, 26.15626907], [89.72242737, 26.15604401], [89.72216797, 26.15656853], [89.72180176, 26.15629578], [89.72164154, 26.15620613], [89.7203598, 26.15639877], [89.72041321, 26.15724373], [89.72044373, 26.15791893], [89.72045898, 26.15810776], [89.72048187, 26.15844536], [89.72051239, 26.15889359], [89.72045898, 26.159338], [89.72031403, 26.16017342], [89.72015381, 26.16115952], [89.71989441, 26.16233444], [89.71981049, 26.1625824], [89.71961212, 26.16316032], [89.71946716, 26.16356468], [89.71927643, 26.1644001], [89.71912384, 26.16527367], [89.71916199, 26.16551018], [89.71918488, 26.16568565], [89.71923828, 26.16599083], [89.71930695, 26.16640663], [89.72509766, 26.16963005], [89.72509766, 26.17160988], [89.72705078, 26.17387962], [89.73293304, 26.17297173], [89.73375702, 26.17337036], [89.73417664, 26.1749897], [89.73314667, 26.1758709], [89.73023987, 26.17700005], [89.71980286, 26.17793846], [89.71705627, 26.17720985], [89.71161652, 26.1735096], [89.70652008, 26.17313004], [89.70427704, 26.1745491], [89.70253754, 26.17712021], [89.70263672, 26.17755508], [89.70266724, 26.17801094], [89.70269012, 26.17843819], [89.70269012, 26.17887878], [89.7026825, 26.17933273], [89.70269775, 26.17982674], [89.70272827, 26.18026352], [89.70278931, 26.1807003], [89.70280457, 26.18106842], [89.70278931, 26.18141174], [89.70278931, 26.18176651], [89.70269012, 26.18201637], [89.70253754, 26.18229485], [89.70237732, 26.18247795], [89.70223236, 26.18260765], [89.70204926, 26.182724], [89.70188904, 26.18282509], [89.70165253, 26.18297195], [89.70141602, 26.18311691], [89.70110321, 26.18328094], [89.70075989, 26.18341827], [89.70061493, 26.18346405], [89.70020294, 26.18482971], [89.69483948, 26.18907166], [89.69757843, 26.19086075], [89.70184326, 26.18815041], [89.70536804, 26.1880703], [89.70822144, 26.18683815], [89.71073914, 26.18856049], [89.71405029, 26.18935966], [89.71613312, 26.19132805], [89.7181015, 26.19679832], [89.71747589, 26.20012093], [89.71556091, 26.20265007], [89.71163177, 26.20319939], [89.71421814, 26.20597839], [89.7172699, 26.20561028], [89.72062683, 26.20617104], [89.7232132, 26.2053299], [89.72566223, 26.20607948], [89.73132324, 26.21076965], [89.73203278, 26.21228981], [89.73127747, 26.21491051], [89.72438049, 26.21729088], [89.71549988, 26.21478081], [89.70307922, 26.21329117], [89.70024872, 26.21376038], [89.69754791, 26.21594238], [89.69722748, 26.21722984], [89.6995697, 26.21890068], [89.70310211, 26.21730995], [89.70555878, 26.21706009], [89.71022797, 26.21914101], [89.71170807, 26.22774124], [89.7128067, 26.22896957], [89.7181778, 26.23162079], [89.72332001, 26.23292923], [89.7287674, 26.23820114], [89.72357178, 26.24353981], [89.71572113, 26.24637985], [89.71502686, 26.24897194], [89.71652222, 26.25233841], [89.71642303, 26.25526047], [89.71537018, 26.25649071], [89.71138763, 26.25803947], [89.70362091, 26.25697136], [89.7009964, 26.25918961], [89.70067596, 26.26084137], [89.7048111, 26.26990128], [89.70894623, 26.27082062], [89.71154022, 26.26958084], [89.71084595, 26.2645607], [89.71142578, 26.26326942], [89.71734619, 26.259161], [89.72521973, 26.2584095], [89.73227692, 26.26033974], [89.73345184, 26.26250076], [89.7336731, 26.26646042], [89.73745728, 26.271101], [89.72918701, 26.28293991], [89.72109222, 26.28816986], [89.71705627, 26.29305267], [89.71544647, 26.2970295], [89.71568298, 26.30198097], [89.71782684, 26.3057003], [89.72025299, 26.30813026], [89.72276306, 26.30755043], [89.71980286, 26.29863167], [89.72088623, 26.29628944], [89.72344971, 26.29475021], [89.73179626, 26.29290009], [89.74234772, 26.29520988], [89.74606323, 26.29076195], [89.74888611, 26.2894001], [89.75710297, 26.28853035], [89.75865936, 26.28932953], [89.75914001, 26.29259109], [89.75089264, 26.30624008], [89.75054169, 26.32146072], [89.75166321, 26.32216072], [89.75364685, 26.32180023], [89.76196289, 26.3170681], [89.7685318, 26.32380295], [89.77774811, 26.3277607], [89.7808609, 26.33088112], [89.78103638, 26.33584023], [89.77921295, 26.34320259], [89.77906036, 26.3474102], [89.78089142, 26.35217094], [89.78201294, 26.35327911], [89.79032135, 26.35806274], [89.80400085, 26.36234283], [89.8098526, 26.36650085], [89.81256104, 26.36700058], [89.82041931, 26.37062073], [89.81723022, 26.36610031], [89.81266785, 26.36240005], [89.81154633, 26.36071014], [89.81149292, 26.35802078], [89.81362915, 26.35317039], [89.81556702, 26.3514595], [89.82009888, 26.35038185], [89.82118988, 26.35113907], [89.82341003, 26.3552494], [89.82106018, 26.35906982], [89.82705688, 26.36664963], [89.8274231, 26.36981964], [89.82440948, 26.37689018], [89.82559204, 26.37931824], [89.82787323, 26.38112068], [89.83098602, 26.38203049], [89.83402252, 26.38126183], [89.84092712, 26.37775993], [89.84549713, 26.38402939], [89.85125732, 26.38405037], [89.85507202, 26.38203049], [89.85729218, 26.38446045], [89.85315704, 26.39599037], [89.85032654, 26.3982811], [89.84681702, 26.40274048], [89.84606171, 26.39779282], [89.84449768, 26.39435005], [89.84039307, 26.39081955], [89.83058929, 26.39019966], [89.82797241, 26.39347839], [89.82727814, 26.39647293], [89.82946777, 26.40328026], [89.8332901, 26.41229057], [89.83634186, 26.41127014], [89.84484863, 26.4102211], [89.84980774, 26.41420937], [89.84764862, 26.41982269], [89.84778595, 26.42175293], [89.84976196, 26.42225075], [89.85299683, 26.42456055], [89.85520172, 26.43404961], [89.8576889, 26.4381218], [89.86112976, 26.44042015], [89.86949921, 26.44841957], [89.86943054, 26.45728111], [89.87062073, 26.45989037], [89.87020874, 26.46397972], [89.86709595, 26.46581078], [89.86237335, 26.46607018], [89.86102295, 26.47478104], [89.85269165, 26.48777962], [89.85497284, 26.49430275], [89.85560608, 26.5051403], [89.85350037, 26.51723289], [89.85443115, 26.52107811], [89.86183929, 26.53046036], [89.86226654, 26.53729057], [89.86141968, 26.5431881], [89.86461639, 26.54829025], [89.86432648, 26.56077957], [89.86548615, 26.56583977], [89.86499786, 26.57027054], [89.86152649, 26.57456017], [89.86200714, 26.57788277], [89.86987305, 26.57950974], [89.87754822, 26.58424187], [89.8742218, 26.58921242], [89.87211609, 26.5947094], [89.87254333, 26.59757042], [89.87522125, 26.60116959], [89.87663269, 26.60634232], [89.87722778, 26.61305046], [89.87161255, 26.61495972], [89.86183167, 26.61515045], [89.85900116, 26.61721039], [89.85704041, 26.62341118], [89.85729218, 26.63208961], [89.86126709, 26.63555908], [89.87367249, 26.64351082], [89.87583923, 26.64630127], [89.87637329, 26.64949989], [89.87275696, 26.65185928], [89.86805725, 26.65661812], [89.86828613, 26.66076088], [89.86987305, 26.66267014], [89.87052155, 26.66621971], [89.86933899, 26.67094994], [89.86946869, 26.67381096], [89.87148285, 26.67921829], [89.87142944, 26.68353081], [89.86141205, 26.70034981], [89.8600769, 26.70137405], [89.86315155, 26.70065498], [89.86250305, 26.70165253], [89.86555481, 26.70597649], [89.86505127, 26.70776939], [89.86401367, 26.71076202], [89.8625946, 26.71372986], [89.8620224, 26.71652603], [89.86276245, 26.7192688], [89.86349487, 26.72217751], [89.86423492, 26.72541809], [89.86450958, 26.72724724], [89.86429596, 26.72800064], [89.86431885, 26.73056984], [89.86265564, 26.73189735], [89.8602829, 26.73395538], [89.85968781, 26.73447037], [89.8588562, 26.73521805], [89.85977936, 26.73596573], [89.8609848, 26.73638344], [89.86292267, 26.73738289], [89.89745331, 26.72444916], [89.96213531, 26.72386932], [89.96701813, 26.72382545], [89.97540283, 26.72566795], [89.99258423, 26.7294445], [89.99703217, 26.73042297], [90.00608063, 26.73204803], [90.00820923, 26.73243141], [90.00971222, 26.7323494], [90.01288605, 26.73217583], [90.01319122, 26.73215866], [90.01874542, 26.7318573], [90.04924011, 26.73070335], [90.13835144, 26.7532959], [90.18861389, 26.77130318], [90.19459534, 26.77344513], [90.18746185, 26.80699921], [90.20076752, 26.8353653], [90.22745514, 26.85688972], [90.22907257, 26.85819435], [90.23021698, 26.85911751], [90.23403168, 26.8591423], [90.24175262, 26.85918999], [90.24859619, 26.85923195], [90.25405121, 26.85819817], [90.25445557, 26.85811996], [90.25547028, 26.85792923], [90.26498413, 26.85613632], [90.28310394, 26.85271835], [90.30021667, 26.84840584], [90.31504059, 26.85682869], [90.31539154, 26.85703087], [90.322052, 26.86081505], [90.33726501, 26.86945534], [90.34696198, 26.87496376], [90.34778595, 26.87543488], [90.35005951, 26.88862419], [90.35017395, 26.88930511], [90.35644531, 26.90100861], [90.41648102, 26.90470123], [90.42024994, 26.90214539], [90.42390442, 26.89966965], [90.43824768, 26.8899498], [90.46601105, 26.87112999], [90.48187256, 26.86036873], [90.50170135, 26.84691429], [90.5089035, 26.84202766], [90.51459503, 26.83816338], [90.53340912, 26.82538414], [90.54299164, 26.81887627], [90.54585266, 26.81693649], [90.57039642, 26.80870056], [90.5849762, 26.80380821], [90.63389587, 26.79397583], [90.64320374, 26.78033638], [90.64592743, 26.7763443], [90.64685822, 26.77658844], [90.6758194, 26.78416061], [90.6890564, 26.77373314], [90.69345856, 26.77026558], [90.69584656, 26.77008247], [90.71676636, 26.76847839], [90.74058533, 26.7748394], [90.74128723, 26.77502632], [90.74291992, 26.7754631], [90.77682495, 26.77586365], [90.78678894, 26.77598], [90.81661224, 26.77632332], [90.94927216, 26.78741837], [90.95646667, 26.78801727], [90.9577179, 26.78641319], [90.95902252, 26.78475571], [90.95874786, 26.78437805], [90.95667267, 26.78152847], [90.96429443, 26.78355026], [90.97018433, 26.78511238], [90.99160004, 26.79079247], [91.01895905, 26.78665161], [91.02842712, 26.78521919], [91.03859711, 26.78367805], [91.04135895, 26.78416824], [91.046875, 26.7832222], [91.04972076, 26.78280449], [91.05221558, 26.78234673], [91.05541229, 26.78235054], [91.0569458, 26.78391647], [91.0582962, 26.78508186], [91.05979919, 26.78629303], [91.06163025, 26.78802681], [91.06342316, 26.78988838], [91.06498718, 26.79140854], [91.06814575, 26.79434395], [91.06957245, 26.79558945], [91.07261658, 26.79881477], [91.07430267, 26.80040169], [91.07616425, 26.80198479], [91.07801056, 26.80370712], [91.07844543, 26.8041153], [91.08015442, 26.805933], [91.08181763, 26.80748558], [91.08322144, 26.80865097], [91.0843811, 26.8099575], [91.08627319, 26.81155205], [91.08970642, 26.81502342], [91.0909729, 26.81624794], [91.09217834, 26.81755447], [91.09375, 26.81894684], [91.09427643, 26.81938362], [91.09608459, 26.82089233], [91.09745026, 26.82217979], [91.14580536, 26.81115341], [91.16135406, 26.81190109], [91.17836761, 26.81279755], [91.19219208, 26.81358337], [91.22182465, 26.81262016], [91.23683929, 26.81231308], [91.25099945, 26.80817986], [91.26164246, 26.80506897], [91.26284027, 26.80471992], [91.26356506, 26.80450821], [91.27677155, 26.80064774], [91.28185272, 26.79717064], [91.29641724, 26.7871933], [91.327034, 26.78258705], [91.33742523, 26.78123474], [91.35971832, 26.78951836], [91.37564087, 26.79543495], [91.39037323, 26.8159256], [91.3922348, 26.81851387], [91.40431213, 26.83528709], [91.40617371, 26.83787346], [91.40746307, 26.83965874], [91.40844727, 26.83910942], [91.44094849, 26.81533432], [91.4417572, 26.81474304], [91.44831848, 26.81108284], [91.45524597, 26.80727577], [91.46363831, 26.8026638], [91.49494171, 26.79138374], [91.52999115, 26.79682159], [91.53185272, 26.7971096], [91.54429626, 26.79895592], [91.59134674, 26.80500603], [91.60248566, 26.81035042], [91.60370636, 26.81093597], [91.60837555, 26.81317711], [91.62562561, 26.82115173], [91.64424896, 26.81701279], [91.65445709, 26.81474113], [91.68974304, 26.80688667], [91.69015503, 26.80705643], [91.70168304, 26.81181335], [91.70500946, 26.81318665], [91.72063446, 26.81192207], [91.74853516, 26.82628632], [91.76015472, 26.83221817], [91.76118469, 26.83274269], [91.76472473, 26.83455086], [91.78115845, 26.84292603], [91.80227661, 26.85367966], [91.80738831, 26.85614014], [91.81391144, 26.85927963], [91.81642914, 26.8604908], [91.82388306, 26.86437225], [91.83280182, 26.87685966], [91.85913086, 26.91370773], [91.86304474, 26.91418457], [91.87780762, 26.9159832], [91.88223267, 26.91637993], [91.88511658, 26.91671371], [91.89209747, 26.91921425], [91.90158081, 26.91477013], [91.9422226, 26.89573097], [91.95075989, 26.89094353], [91.96385193, 26.88286209], [91.97026062, 26.87055397], [91.97749329, 26.86366272], [91.983078, 26.85833931], [91.99037933, 26.85657501], [92.00010681, 26.85422707], [92.01700592, 26.85014534], [92.03614044, 26.84892273], [92.05222321, 26.84789658], [92.056633, 26.84761429], [92.08629608, 26.85959244], [92.10289001, 26.86755943], [92.10267639, 26.88149643], [92.1129837, 26.89238358], [92.12036896, 26.89030075], [92.12419128, 26.88976097], [92.12953949, 26.89071274], [92.14792633, 26.89088821], [92.16239929, 26.89266014], [92.16882324, 26.89191055], [92.1771698, 26.89248085], [92.19484711, 26.89100075], [92.20935059, 26.89689064], [92.25456238, 26.91222954], [92.26123047, 26.90876961], [92.2651062, 26.9076004], [92.26786804, 26.9050827], [92.27639008, 26.90246964], [92.28148651, 26.9041481], [92.29007721, 26.90546036], [92.30053711, 26.90814018], [92.30374908, 26.90954018], [92.30285645, 26.92420959], [92.3200531, 26.92838097], [92.34677887, 26.93346024], [92.35305023, 26.93556976], [92.36443329, 26.9326992], [92.36728668, 26.93155098], [92.39975739, 26.92627144], [92.41188812, 26.94419098], [92.42576599, 26.94346809], [92.44216919, 26.95502281], [92.44616699, 26.96063995], [92.45957184, 26.96331024], [92.46629333, 26.96306038], [92.48375702, 26.96474075], [92.49063873, 26.96473122], [92.50502014, 26.96677017], [92.51544189, 26.96442032], [92.53176117, 26.9633007], [92.55361176, 26.95907021], [92.58521271, 26.96186256], [92.64546204, 26.98744965], [92.64530945, 26.99561119], [92.64420319, 27.00251007], [92.64463043, 27.01004028], [92.63909912, 27.01853943], [92.65048981, 27.02477837], [92.65702057, 27.03759003], [92.65892792, 27.03852081], [92.68238831, 27.03174019], [92.70231628, 27.02758026], [92.71367645, 27.02609062], [92.72750854, 27.02840042], [92.76909637, 27.033041], [92.78527069, 27.0306797], [92.82441711, 27.0184803], [92.836586, 27.0135498], [92.87243652, 27.00769997], [92.88337708, 27.00234032], [92.88751984, 27.00022125], [92.89028931, 26.99982071], [92.89977264, 26.9962616], [92.91667938, 26.98465157], [92.91494751, 26.96976089], [92.91777039, 26.96424103], [92.92166138, 26.96190834], [92.92640686, 26.96066093], [92.93276978, 26.9569397], [92.95136261, 26.94890976], [92.96161652, 26.94588089], [92.97297668, 26.94082069], [92.98069763, 26.93562126], [92.98271942, 26.93593979], [92.98668671, 26.93383026], [92.99375916, 26.93178749], [92.9957962, 26.93032074], [92.99743652, 26.93034935], [93.01937103, 26.91683006], [93.03820801, 26.91788101], [93.06017303, 26.92118073], [93.06884003, 26.92420959], [93.07636261, 26.91994095], [93.09187317, 26.9155407], [93.10896301, 26.92728043], [93.1842804, 26.93873978], [93.22238922, 26.94914055], [93.26685333, 26.95600128], [93.34793854, 26.96324158], [93.37423706, 26.96038055], [93.39073181, 26.9600296], [93.43666077, 26.95609093], [93.44786835, 26.95415115], [93.46383667, 26.94354057], [93.46810913, 26.93889046], [93.48029327, 26.94017982], [93.48683167, 26.94309044], [93.48935699, 26.93852997], [93.52584076, 26.94863129], [93.54548645, 26.95174026], [93.57079315, 26.95412254], [93.58422089, 26.95264816], [93.59583282, 26.95518112], [93.62449646, 26.96421051], [93.64016724, 26.96478081], [93.65511322, 26.96647835], [93.67578125, 26.97107124], [93.69655609, 26.99237823], [93.69828033, 26.99479103], [93.70095062, 26.99710274], [93.70568085, 27.00368118], [93.70449829, 27.00656128], [93.70556641, 27.00832939], [93.71893311, 27.01922035], [93.73388672, 27.02723122], [93.7425766, 27.02971268], [93.74642944, 27.03240967], [93.76847839, 27.04329109], [93.76819611, 27.0555191], [93.77007294, 27.05558014], [93.77095795, 27.05455017], [93.77178955, 27.0555191], [93.7723999, 27.06230164], [93.77368164, 27.06236076], [93.7754364, 27.0562191], [93.77794647, 27.05277061], [93.77915955, 27.05334282], [93.77913666, 27.05829048], [93.78116608, 27.06081963], [93.78227234, 27.06690025], [93.78321075, 27.06719017], [93.78511047, 27.05835915], [93.78613281, 27.05537033], [93.78742218, 27.05422974], [93.7911911, 27.05456924], [93.79399872, 27.05772972], [93.79709625, 27.0708828], [93.79805756, 27.07094193], [93.79876709, 27.06968117], [93.79942322, 27.06687164], [93.80213165, 27.06176186], [93.80488586, 27.06134987], [93.80854797, 27.06257057], [93.81018829, 27.06814003], [93.81288147, 27.07068062], [93.81571198, 27.06545067], [93.81878662, 27.06493187], [93.82287598, 27.06832123], [93.82457733, 27.07217026], [93.82549286, 27.07212257], [93.82710266, 27.06884956], [93.82824707, 27.06895065], [93.82901001, 27.07212257], [93.83209991, 27.07286835], [93.83502197, 27.07499123], [93.83674622, 27.07821274], [93.83476257, 27.08205032], [93.83436584, 27.0828495], [93.83621216, 27.08647919], [93.8330307, 27.08761024], [93.83132172, 27.09243965], [93.82663727, 27.09938049], [93.82723236, 27.11194038], [93.82549286, 27.1193409], [93.82195282, 27.12203026], [93.81910706, 27.12290192], [93.81495667, 27.12260818], [93.81315613, 27.12376022], [93.81136322, 27.12626839], [93.8138504, 27.12861824], [93.81423187, 27.13082123], [93.81350708, 27.13201141], [93.80818939, 27.13286972], [93.80580902, 27.13475037], [93.80222321, 27.13286018], [93.80024719, 27.13262939], [93.7984314, 27.13439941], [93.79779816, 27.13600922], [93.79824066, 27.13716125], [93.80143738, 27.13791084], [93.80561066, 27.13779068], [93.80680847, 27.14720917], [93.80729675, 27.15014076], [93.80858612, 27.15175056], [93.8170166, 27.15824127], [93.82666016, 27.16937065], [93.82897949, 27.17064285], [93.83699799, 27.17207909], [93.8398819, 27.1734581], [93.84716797, 27.17978096], [93.85746002, 27.19110107], [93.8674469, 27.19884109], [93.88561249, 27.2243824], [93.89097595, 27.23018074], [93.89298248, 27.23097038], [93.90104675, 27.24154091], [93.91889954, 27.25714111], [93.93390656, 27.26834106], [93.93891144, 27.27327919], [93.95652008, 27.29475975], [93.97267151, 27.30834007], [93.9809494, 27.31376839], [93.985672, 27.32057953], [93.99018097, 27.32464981], [93.99603271, 27.32788277], [93.99780273, 27.32785988], [94.00068665, 27.33013916], [94.00000763, 27.33470917], [94.00978851, 27.33889008], [94.02583313, 27.34770012], [94.0300827, 27.34799194], [94.04164124, 27.35329056], [94.04831696, 27.35874939], [94.05483246, 27.36283112], [94.06092834, 27.36355972], [94.0631485, 27.36891174], [94.06864929, 27.37440109], [94.07244873, 27.38301277], [94.08634949, 27.40456009], [94.09329987, 27.41094017], [94.09992218, 27.41391945], [94.10652161, 27.41805077], [94.11708069, 27.43097115], [94.12333679, 27.43498039], [94.13585663, 27.44585991], [94.14080811, 27.44845963], [94.15445709, 27.46046066], [94.16020203, 27.46647072], [94.15873718, 27.47000122], [94.1572113, 27.47804832], [94.16422272, 27.48098946], [94.1679306, 27.48418808], [94.17471313, 27.48407173], [94.18689728, 27.49081039], [94.19124603, 27.49632072], [94.19522858, 27.49745941], [94.21065521, 27.49790382], [94.21232605, 27.4979496], [94.2154007, 27.5031395], [94.22167206, 27.50703049], [94.25905609, 27.52260017], [94.25972748, 27.52349091], [94.26251221, 27.52742958], [94.25686646, 27.54050064], [94.2557373, 27.55076027], [94.25650024, 27.55742836], [94.24060059, 27.57035065], [94.23414612, 27.57146072], [94.22647858, 27.57563019], [94.22547913, 27.5810585], [94.22144318, 27.58791161], [94.22531128, 27.59523964], [94.22505188, 27.59851074], [94.22292328, 27.60074043], [94.21350861, 27.60442162], [94.21111298, 27.61084175], [94.21743774, 27.60900116], [94.22595978, 27.61799049], [94.2350769, 27.63251114], [94.24507141, 27.63586998], [94.24726868, 27.63581085], [94.25006866, 27.63972092], [94.25222778, 27.64093018], [94.25598907, 27.63655281], [94.25907135, 27.6370182], [94.26278687, 27.63602066], [94.26670837, 27.63256073], [94.26716614, 27.62786293], [94.26222229, 27.62451935], [94.25710297, 27.61911964], [94.25408936, 27.61370087], [94.2618866, 27.61009979], [94.27245331, 27.60346985], [94.27520752, 27.59740067], [94.27603149, 27.59334946], [94.28765869, 27.59179115], [94.28848267, 27.59451103], [94.29289246, 27.60036087], [94.29801941, 27.60427094], [94.30164337, 27.59988022], [94.30835724, 27.59558105], [94.31240845, 27.58965111], [94.31970978, 27.59005165], [94.3237381, 27.58716965], [94.32905579, 27.58839035], [94.3381424, 27.58103943], [94.34057617, 27.58344078], [94.34507751, 27.58459091], [94.34884644, 27.57945061], [94.35569763, 27.57738113], [94.36219788, 27.58023071], [94.36749268, 27.5767498], [94.37230682, 27.57926941], [94.37583923, 27.58457756], [94.38043213, 27.58509064], [94.38437653, 27.58646011], [94.38759613, 27.58927917], [94.3948288, 27.58877945], [94.40318298, 27.58719063], [94.42092896, 27.60134125], [94.4310379, 27.60308075], [94.43058777, 27.59646034], [94.43605042, 27.58442116], [94.44238281, 27.57946014], [94.44960785, 27.57504082], [94.45346832, 27.57094002], [94.45622253, 27.56290245], [94.45973969, 27.55771065], [94.46930695, 27.56401253], [94.47915649, 27.57699013], [94.48310852, 27.57720184], [94.4909668, 27.57549286], [94.5, 27.57726479], [94.50022888, 27.57731056], [94.50940704, 27.58407021], [94.51566315, 27.58473015], [94.52628326, 27.59576988], [94.53173065, 27.59692955], [94.53659058, 27.59699059], [94.54641724, 27.60353279], [94.55171204, 27.60404968], [94.55612183, 27.60323906], [94.56389618, 27.6069603], [94.56947327, 27.60635185], [94.5735321, 27.60696983], [94.58185577, 27.61668015], [94.58629608, 27.62010956], [94.59146881, 27.62281036], [94.59577179, 27.6214695], [94.60060883, 27.62193108], [94.6040802, 27.62310028], [94.60938263, 27.62263107], [94.61406708, 27.62574005], [94.62497711, 27.63011932], [94.63069153, 27.62829018], [94.63445282, 27.62877083], [94.6397934, 27.63096046], [94.6452179, 27.63653946], [94.64842224, 27.64207077], [94.66464233, 27.64785957], [94.66911316, 27.65027809], [94.6757431, 27.65065193], [94.68251038, 27.64958954], [94.68699646, 27.65331078], [94.68650818, 27.65714264], [94.68387604, 27.66333961], [94.68940735, 27.66719055], [94.69808197, 27.66710091], [94.7130661, 27.66026115], [94.71663666, 27.6616497], [94.72070313, 27.66999054], [94.72554016, 27.67033958], [94.72767639, 27.66786003], [94.73703003, 27.66564941], [94.74266815, 27.66342163], [94.75592041, 27.66651917], [94.75955963, 27.66843987], [94.76432037, 27.67456055], [94.76693726, 27.68013954], [94.77216339, 27.6839695], [94.77645111, 27.68337822], [94.79099274, 27.6888504], [94.79405975, 27.69322014], [94.79534912, 27.69807816], [94.7975769, 27.69893265], [94.80021667, 27.69709015], [94.81803131, 27.69684029], [94.82126617, 27.6962204], [94.83938599, 27.7035408], [94.84879303, 27.71068192], [94.85357666, 27.73162079], [94.86071777, 27.73338127], [94.86602783, 27.73624039], [94.86086273, 27.73947906], [94.88394165, 27.74205971], [94.93003082, 27.75673103], [94.98703766, 27.77085114], [94.99787903, 27.77655029], [95.01914978, 27.77249908], [95.03121948, 27.77477074], [95.03875732, 27.77773094], [95.04886627, 27.78646088], [95.05182648, 27.7902298], [95.19486237, 27.83444977], [95.23654175, 27.84835052], [95.29254913, 27.86499023], [95.30847168, 27.86782074], [95.31655884, 27.87112999], [95.38433838, 27.84202194], [95.51595306, 27.88178825], [95.52622986, 27.89789963], [95.53302002, 27.90043068], [95.54353333, 27.90232277], [95.54434204, 27.9057827], [95.54206848, 27.91074181], [95.54380035, 27.91345978], [95.56504822, 27.92251968], [95.56626129, 27.93159103], [95.57121277, 27.94238091], [95.58053589, 27.94356155], [95.58866119, 27.94162941], [95.59694672, 27.95112991], [95.60674286, 27.95776939], [95.82588196, 27.97737122], [95.95688629, 27.96912956], [95.97746277, 27.96850014], [95.96520996, 27.9526329], [95.95231628, 27.94184113], [95.95155334, 27.93917084], [95.9523468, 27.93717957], [95.95755005, 27.93708038], [95.95754242, 27.9328804], [95.95381165, 27.93024063], [95.95529938, 27.92682076], [95.95249176, 27.92281914], [95.94351196, 27.91263962], [95.9393158, 27.90982056], [95.9383316, 27.90327072], [95.92864227, 27.9028511], [95.92501068, 27.90094185], [95.92392731, 27.89599991], [95.92855072, 27.89052963], [95.92735291, 27.88726044], [95.92375183, 27.89033127], [95.92127991, 27.8904705], [95.92262268, 27.88618088], [95.91866302, 27.88278008], [95.91400146, 27.88084984], [95.91291809, 27.8781395], [95.91409302, 27.87465096], [95.91137695, 27.87301826], [95.90618134, 27.87722969], [95.90722656, 27.8686409], [95.90055847, 27.86668015], [95.89763641, 27.86746979], [95.89502716, 27.86722183], [95.89422607, 27.86096001], [95.89209747, 27.85704041], [95.87657166, 27.84177017], [95.87372589, 27.83980179], [95.86633301, 27.83846092], [95.85209656, 27.83411026], [95.84599304, 27.83010101], [95.84336853, 27.82147026], [95.8349762, 27.8157711], [95.82894135, 27.81365967], [95.82312775, 27.80924988], [95.81131744, 27.79372025], [95.80757904, 27.78994942], [95.80636597, 27.78358078], [95.8009491, 27.77686119], [95.79538727, 27.77263069], [95.78882599, 27.7650528], [95.78053284, 27.75822067], [95.78777313, 27.74205017], [95.78479767, 27.73978043], [95.7718811, 27.73451042], [95.76267242, 27.73293114], [95.75821686, 27.73110962], [95.75871277, 27.72668076], [95.76304626, 27.72266006], [95.77039337, 27.72002983], [95.77052307, 27.7159996], [95.77262115, 27.71132088], [95.77336121, 27.70535088], [95.77266693, 27.69995117], [95.77455139, 27.69670105], [95.77876282, 27.69439125], [95.79312897, 27.69227028], [95.79647064, 27.68806076], [95.79453278, 27.68419075], [95.78549194, 27.68325996], [95.78044891, 27.67918968], [95.7784729, 27.67234993], [95.77784729, 27.66625977], [95.77922058, 27.66053963], [95.78623199, 27.65566063], [95.79485321, 27.65279961], [95.80145264, 27.6490097], [95.79959106, 27.64296913], [95.79734039, 27.6395607], [95.79741669, 27.63589096], [95.78734589, 27.63229942], [95.78504181, 27.62739944], [95.787117, 27.62340927], [95.79429626, 27.62236977], [95.79606628, 27.61819077], [95.79802704, 27.60783005], [95.80960846, 27.60527039], [95.81682587, 27.60543823], [95.82087708, 27.60472107], [95.82419586, 27.60301018], [95.82025909, 27.59557152], [95.81980896, 27.59028053], [95.82124329, 27.58172035], [95.82772827, 27.58175087], [95.83193207, 27.57888985], [95.83628845, 27.57117844], [95.83989716, 27.56661034], [95.84601593, 27.56799126], [95.85209656, 27.56565094], [95.86235809, 27.55260086], [95.86701965, 27.55109978], [95.87361908, 27.55117035], [95.8813324, 27.55323029], [95.88143921, 27.54583168], [95.87992096, 27.52979088], [95.88080597, 27.52251053], [95.878479, 27.5198307], [95.88179779, 27.51509094], [95.88710785, 27.51127052], [95.88964081, 27.50616837], [95.88604736, 27.50356293], [95.88046265, 27.50110054], [95.87905121, 27.49919128], [95.87915802, 27.49267006], [95.8812561, 27.48742104], [95.87843323, 27.4756012], [95.87625885, 27.47110939], [95.86606598, 27.46902275], [95.86116791, 27.46629906], [95.85945892, 27.46261024], [95.86379242, 27.45203018], [95.85955811, 27.44905281], [95.8551712, 27.44737053], [95.8529129, 27.44475937], [95.84947205, 27.43490982], [95.84934235, 27.43032074], [95.85573578, 27.42766953], [95.85761261, 27.42481995], [95.85795593, 27.420681], [95.86733246, 27.4171505], [95.8666687, 27.41921043], [95.86422729, 27.42131805], [95.8632431, 27.42485809], [95.86490631, 27.4290123], [95.87577057, 27.43535805], [95.88259125, 27.44408035], [95.88865662, 27.44407082], [95.89037323, 27.43967056], [95.88941956, 27.43162918], [95.89002991, 27.42641068], [95.89437866, 27.41828918], [95.89425659, 27.41438293], [95.89187622, 27.4097805], [95.89305878, 27.40604019], [95.90010071, 27.41133118], [95.90612793, 27.42326927], [95.90796661, 27.43264008], [95.91117096, 27.43996048], [95.91684723, 27.4431591], [95.93327332, 27.4466877], [95.94300079, 27.44639015], [95.94989014, 27.44502068], [95.95307159, 27.44345093], [95.95350647, 27.4407711], [95.95052338, 27.4372406], [95.95297241, 27.43328094], [95.95729065, 27.4328804], [95.96105194, 27.42871094], [95.96357727, 27.43548012], [95.96703339, 27.43666077], [95.96803284, 27.42411995], [95.97177887, 27.43037033], [95.97329712, 27.43675041], [95.9777832, 27.43549919], [95.97782898, 27.43229103], [95.98023224, 27.43021965], [95.98092651, 27.42612267], [95.97807312, 27.42533112], [95.97952271, 27.4218502], [95.98945618, 27.4217205], [95.9912262, 27.41939926], [95.99093628, 27.41457176], [95.99459076, 27.41235924], [96.00100708, 27.4034729], [96.00006866, 27.39756966], [96.00205231, 27.39349937], [96.00836945, 27.38721085], [96.01056671, 27.38128281], [96.01494598, 27.37545967], [96.02091217, 27.37125969], [96.01835632, 27.36790085], [96.01319885, 27.36403084], [96.00314331, 27.36445999], [96.00211334, 27.36412811], [95.99697113, 27.36347961], [95.99487305, 27.36024094], [95.99368286, 27.35144043], [95.9773407, 27.34230042], [95.97421265, 27.33936119], [95.97001648, 27.33698082], [95.97228241, 27.33462906], [95.98420715, 27.33434105], [95.9780426, 27.33269119], [95.96871185, 27.33183098], [95.96903229, 27.32840919], [95.96785736, 27.3245697], [95.96260834, 27.32433128], [95.96556854, 27.3216629], [95.96321869, 27.3170681], [95.94056702, 27.30958939], [95.91874695, 27.29922295], [95.91229248, 27.29314041], [95.90643311, 27.29187965], [95.90238953, 27.28783035], [95.90453339, 27.28623962], [95.90428925, 27.27985954], [95.90116119, 27.27638817], [95.89810944, 27.26431084], [95.89396667, 27.26301193], [95.88765717, 27.26332092], [95.88243103, 27.26694107], [95.87760162, 27.26740837], [95.87238312, 27.26691055], [95.86544037, 27.2766819], [95.86084747, 27.27979279], [95.86064148, 27.28342056], [95.86192322, 27.29002953], [95.860466, 27.29421043], [95.85022736, 27.29314995], [95.8379364, 27.28707123], [95.81019592, 27.28092003], [95.80848694, 27.28544044], [95.8065033, 27.28801155], [95.80628967, 27.29174042], [95.80075836, 27.2887001], [95.790802, 27.28545952], [95.78468323, 27.27913094], [95.75701141, 27.27435112], [95.7399292, 27.26988983], [95.73638916, 27.26675034], [95.73188019, 27.26654053], [95.72548676, 27.25922966], [95.72107697, 27.25760078], [95.71549225, 27.25909996], [95.70188141, 27.25564003], [95.69542694, 27.25814819], [95.68441772, 27.25741005], [95.67939758, 27.25616264], [95.67920685, 27.2539196], [95.63700104, 27.23690987], [95.63413239, 27.23981094], [95.61914063, 27.23655128], [95.60735321, 27.23137283], [95.59916687, 27.22961044], [95.59008789, 27.2295208], [95.57788086, 27.24215126], [95.57830048, 27.24714088], [95.57446289, 27.25106049], [95.56326294, 27.25250244], [95.55613708, 27.25436974], [95.55416107, 27.25934029], [95.53481293, 27.27062035], [95.52971649, 27.26906967], [95.52593231, 27.26626015], [95.52046204, 27.26374054], [95.51618195, 27.26863098], [95.51088715, 27.26626968], [95.51064301, 27.2589798], [95.50627899, 27.2546196], [95.49099731, 27.24869919], [95.48722839, 27.24603081], [95.48055267, 27.23233986], [95.47451019, 27.22686958], [95.47389984, 27.22364998], [95.47067261, 27.22321129], [95.46942902, 27.21825981], [95.45970917, 27.2134304], [95.45890045, 27.20956993], [95.46205139, 27.20301056], [95.46581268, 27.19742966], [95.46864319, 27.19050026], [95.46711731, 27.18555069], [95.46366882, 27.18212128], [95.46800995, 27.1722908], [95.46383667, 27.1670208], [95.45870972, 27.16328812], [95.4598999, 27.16041946], [95.46331787, 27.15954018], [95.46507263, 27.15760994], [95.46585083, 27.15480042], [95.46367645, 27.15036011], [95.4610672, 27.14022064], [95.45778656, 27.1356411], [95.45339966, 27.13587952], [95.45075226, 27.13883972], [95.44713593, 27.13833046], [95.44557953, 27.1342907], [95.44098663, 27.13281059], [95.42919159, 27.13405037], [95.42027283, 27.13078117], [95.40631104, 27.11832047], [95.39614868, 27.11446953], [95.38611603, 27.11170959], [95.38546753, 27.10509109], [95.37697601, 27.10218048], [95.37267303, 27.10167122], [95.37365723, 27.1079998], [95.36830139, 27.10736275], [95.36778259, 27.10971069], [95.3706665, 27.11014938], [95.37126923, 27.1114006], [95.36647034, 27.11285019], [95.34860229, 27.10476112], [95.3351059, 27.09592056], [95.32327271, 27.089571], [95.31317902, 27.08674049], [95.30967712, 27.08113098], [95.29662323, 27.07285118], [95.28791809, 27.06632042], [95.27783203, 27.05676842], [95.27944946, 27.05391121], [95.27762604, 27.04977036], [95.27097321, 27.04507065], [95.26669312, 27.04043961], [95.26262665, 27.0410099], [95.25994873, 27.03897285], [95.2607193, 27.03725052], [95.25219727, 27.03191948], [95.24822998, 27.03025246], [95.24371338, 27.03416061], [95.23787689, 27.04322052], [95.23471832, 27.0435791], [95.23091125, 27.04570961], [95.23214722, 27.04292107], [95.2294693, 27.04017067], [95.22598267, 27.04225922], [95.22263336, 27.04089165], [95.21969604, 27.03679085], [95.21380615, 27.03347969], [95.20768738, 27.0347805], [95.20379639, 27.04300117], [95.20094299, 27.04232979], [95.19845581, 27.04442978], [95.19551849, 27.04294968], [95.15450287, 27.00604057], [95.14948273, 26.99983978], [95.14276123, 26.99830055], [95.13698578, 26.99357986], [95.12638092, 26.98690987], [95.11694336, 26.98368073], [95.1135025, 26.97758102], [95.11322021, 26.97232056], [95.11004639, 26.96690941], [95.08686066, 26.95274162], [95.06533813, 26.94819069], [95.05464935, 26.94087982], [95.03804779, 26.93848038], [95.02855682, 26.93251038], [95.02134705, 26.92539978], [95.01657104, 26.92435265], [95.00579071, 26.92486954], [94.99946594, 26.9242897], [94.99305725, 26.92616081], [94.99118805, 26.92292023], [94.99205017, 26.91838837], [94.98944855, 26.91782951], [94.985672, 26.91824913], [94.97966003, 26.92462158], [94.97425842, 26.92760277], [94.97067261, 26.92836189], [94.96794128, 26.93148994], [94.96676636, 26.93618011], [94.96417236, 26.9406414], [94.95728302, 26.94355011], [94.94709015, 26.94020081], [94.94122314, 26.93927193], [94.93855286, 26.93797112], [94.93360138, 26.93853951], [94.92816162, 26.95210075], [94.92376709, 26.95033073], [94.91799164, 26.94514275], [94.91385651, 26.94256973], [94.90882111, 26.94227028], [94.90129089, 26.94034004], [94.89447021, 26.93733025], [94.88622284, 26.93246078], [94.88154602, 26.92671013], [94.86963654, 26.91500854], [94.86862183, 26.90989113], [94.8653183, 26.90690994], [94.85900879, 26.89328003], [94.85334778, 26.88533974], [94.85153198, 26.88134003], [94.84584045, 26.876791], [94.83878326, 26.87400055], [94.8364563, 26.8684597], [94.83226013, 26.86271095], [94.82628632, 26.85931015], [94.82108307, 26.85445976], [94.82173157, 26.84930992], [94.8210907, 26.84486961], [94.81669617, 26.84147072], [94.8154068, 26.83680916], [94.81507111, 26.8300209], [94.81305695, 26.82476044], [94.80918121, 26.82328033], [94.80671692, 26.82122993], [94.79664612, 26.81851959], [94.80161285, 26.81381035], [94.80535889, 26.81219101], [94.80220795, 26.80606079], [94.79496002, 26.80373192], [94.79078674, 26.80145264], [94.7856369, 26.79857063], [94.77308655, 26.79496193], [94.76906586, 26.79109955], [94.76832581, 26.78339767], [94.76235962, 26.77993011], [94.76003265, 26.77662849], [94.75934601, 26.7741375], [94.75637054, 26.7722683], [94.75409698, 26.77431107], [94.75071716, 26.77967072], [94.7457962, 26.78214073], [94.74236298, 26.77864075], [94.74167633, 26.77357101], [94.73773193, 26.76885033], [94.73651123, 26.76741028], [94.73188019, 26.76400948], [94.71969604, 26.75803947], [94.71140289, 26.75282288], [94.69687653, 26.73969078], [94.69148254, 26.73575974], [94.68660736, 26.73258972], [94.66513824, 26.72776031], [94.65853882, 26.72480011], [94.65338898, 26.72363091], [94.64621735, 26.72451019], [94.64028931, 26.72397041], [94.63197327, 26.71965027], [94.6282959, 26.71862984], [94.62271881, 26.71953011], [94.62108612, 26.72117043], [94.62014771, 26.72673988], [94.61740112, 26.73055077], [94.61194611, 26.73265076], [94.61044312, 26.73586082], [94.61006165, 26.74010277], [94.60414886, 26.7392807], [94.59993744, 26.73772049], [94.5951767, 26.72989082], [94.59333038, 26.72613144], [94.60048676, 26.72525978], [94.60318756, 26.7238102], [94.60463715, 26.71985245], [94.60468292, 26.71721077], [94.60372162, 26.71617126], [94.59831238, 26.71994019], [94.59616852, 26.7181797], [94.59501648, 26.71236038], [94.59493256, 26.7065506], [94.59240723, 26.70273018], [94.58898163, 26.70244026], [94.58538818, 26.70331001], [94.58278656, 26.70557976], [94.57150269, 26.69622231], [94.57469177, 26.69102097], [94.57086945, 26.69005966], [94.56608582, 26.68992805], [94.56295013, 26.69063187], [94.56233215, 26.69383049], [94.56472778, 26.70600128], [94.56343842, 26.70737076], [94.56112671, 26.70813942], [94.55467224, 26.70844078], [94.55036926, 26.71017075], [94.5450592, 26.71090126], [94.54087067, 26.70963287], [94.52776337, 26.70128059], [94.52272797, 26.70436859], [94.52009583, 26.70145035], [94.51967621, 26.69460106], [94.51550293, 26.68729973], [94.50994873, 26.68342972], [94.50714111, 26.68297958], [94.50300598, 26.67769051], [94.5, 26.67516708], [94.49826813, 26.67371178], [94.49279785, 26.67225266], [94.48574829, 26.67370033], [94.46794128, 26.66982079], [94.46452332, 26.66751099], [94.46183014, 26.66316032], [94.45857239, 26.65534973], [94.46141815, 26.64809036], [94.46166229, 26.64384079], [94.46446228, 26.64036942], [94.46482086, 26.63871002], [94.46250153, 26.6354599], [94.45681, 26.63664055], [94.45452118, 26.63902092], [94.43448639, 26.62537956], [94.40988159, 26.61643982], [94.40786743, 26.61433029], [94.40857697, 26.6097908], [94.40600586, 26.60193062], [94.41484833, 26.58328056], [94.41188049, 26.5734005], [94.40930939, 26.56899071], [94.40776062, 26.56142807], [94.41057587, 26.56059837], [94.41195679, 26.5584507], [94.40896606, 26.55713081], [94.40609741, 26.55738068], [94.40479279, 26.55523109], [94.40763855, 26.55240059], [94.40795135, 26.54971123], [94.40674591, 26.5482502], [94.40267944, 26.54686165], [94.40133667, 26.54408073], [94.40248108, 26.53880119], [94.39891815, 26.53454971], [94.39945221, 26.53232002], [94.39656067, 26.52973175], [94.39408875, 26.53264046], [94.39141083, 26.53282928], [94.37827301, 26.52526093], [94.37690735, 26.52317047], [94.37806702, 26.51716042], [94.37761688, 26.51312065], [94.36924744, 26.50999069], [94.36445618, 26.5103302], [94.35874939, 26.50914192], [94.35459137, 26.51028061], [94.35111237, 26.50862122], [94.35372162, 26.50481033], [94.35552979, 26.50345039], [94.3535614, 26.50215912], [94.3518219, 26.49920273], [94.35206604, 26.49575043], [94.34963226, 26.49284172], [94.34340668, 26.49003983], [94.33693695, 26.48481941], [94.33259583, 26.48502922], [94.32932281, 26.48384094], [94.32388306, 26.47937965], [94.32478333, 26.47220993], [94.32430267, 26.47070122], [94.31651306, 26.46293068], [94.31347656, 26.46500015], [94.31098175, 26.46606064], [94.30330658, 26.46726036], [94.29392242, 26.4807415], [94.29242706, 26.49003029], [94.29023743, 26.49596977], [94.28723907, 26.50852013], [94.28707123, 26.51496124], [94.28878784, 26.51831818], [94.2890625, 26.52517128], [94.28562164, 26.53409195], [94.28494263, 26.54029083], [94.28562164, 26.54656982], [94.28483582, 26.5553627], [94.28530884, 26.55824089], [94.28890991, 26.55990028], [94.28978729, 26.5641098], [94.2822876, 26.56353951], [94.27674103, 26.5588398], [94.26257324, 26.54394913], [94.25331879, 26.53252983], [94.25205231, 26.52773285], [94.24482727, 26.51692009], [94.23989105, 26.51143074], [94.22891998, 26.50326157], [94.22361755, 26.5005703], [94.21148682, 26.48984909], [94.20936584, 26.48372269], [94.20111847, 26.46990013], [94.18654633, 26.46051025], [94.17575836, 26.43180084], [94.1765213, 26.42807007], [94.17401123, 26.42089081], [94.17684174, 26.41341019], [94.17694092, 26.39956093], [94.17909241, 26.38872147], [94.17404938, 26.37782288], [94.17549133, 26.37445068], [94.17560577, 26.37175941], [94.17357635, 26.36757851], [94.16446686, 26.36012077], [94.1676712, 26.35330963], [94.16938019, 26.35406113], [94.17533875, 26.35513115], [94.17999268, 26.35412025], [94.17928314, 26.35083961], [94.17550659, 26.34421921], [94.17214966, 26.34440994], [94.16452026, 26.33934021], [94.15453339, 26.33998108], [94.14932251, 26.33908081], [94.14671326, 26.33542061], [94.14224243, 26.3360405], [94.14383698, 26.34020042], [94.14264679, 26.34213066], [94.13877106, 26.34155273], [94.13565826, 26.33821869], [94.12397003, 26.3359108], [94.11936951, 26.33370018], [94.11936188, 26.33049011], [94.12872314, 26.32324982], [94.1184082, 26.32271957], [94.11128998, 26.3260498], [94.10804749, 26.32640076], [94.10447693, 26.32204056], [94.10267639, 26.30869102], [94.09807587, 26.30294037], [94.09028625, 26.29713058], [94.08722687, 26.29042053], [94.08444214, 26.28860092], [94.08006287, 26.28881073], [94.07682037, 26.28520012], [94.07781982, 26.27535057], [94.07601929, 26.26923943], [94.07047272, 26.26003075], [94.06463623, 26.26177025], [94.05285645, 26.25579071], [94.0491333, 26.25021172], [94.04421997, 26.23996925], [94.04178619, 26.23389053], [94.03816986, 26.22951126], [94.04046631, 26.22351074], [94.03656006, 26.21771049], [94.03681946, 26.20972061], [94.03573608, 26.20318985], [94.03109741, 26.19939041], [94.02661896, 26.19714928], [94.0219574, 26.19145966], [94.01300049, 26.1862812], [94.00876617, 26.18053055], [94.00480652, 26.17327118], [94.00389862, 26.16938019], [94.00434875, 26.16407013], [93.99965668, 26.15824127], [94.0029068, 26.15133858], [94.00636292, 26.14723969], [94.00522614, 26.14186096], [94.00309753, 26.13902092], [93.99965668, 26.1364994], [93.99627686, 26.13741112], [93.99320221, 26.13739014], [93.99075317, 26.13387108], [93.99326324, 26.13281822], [93.99830627, 26.13097954], [93.99832916, 26.12935829], [93.99661255, 26.1281395], [93.99648285, 26.12236977], [93.99282074, 26.12026978], [93.99124146, 26.11812019], [93.99495697, 26.11570168], [93.99986267, 26.11590958], [94.00213623, 26.11486053], [94.00216675, 26.11137962], [93.99957275, 26.10847092], [93.994133, 26.10608864], [93.99217224, 26.09782982], [93.99249268, 26.09278107], [93.9909668, 26.08949089], [93.98642731, 26.0883007], [93.98602295, 26.08356857], [93.98938751, 26.07411957], [93.99111938, 26.07263947], [93.98081207, 26.0586319], [93.97450256, 26.05216026], [93.97263336, 26.04496193], [93.96588898, 26.04240036], [93.96312714, 26.0333519], [93.96266174, 26.02215958], [93.95838165, 26.01189041], [93.95488739, 26.00732994], [93.95598602, 26.00457001], [93.95897675, 26.00245857], [93.96058655, 25.99700928], [93.95804596, 25.9815712], [93.95600891, 25.97418976], [93.96920776, 25.96084023], [93.97084808, 25.95326042], [93.97109222, 25.94485283], [93.98268127, 25.92626953], [93.97939301, 25.91967964], [93.97197723, 25.9175396], [93.96916962, 25.91142273], [93.96075439, 25.90585518], [93.95983887, 25.90525055], [93.94835663, 25.90120125], [93.94019318, 25.90096092], [93.93463135, 25.8914299], [93.92385101, 25.88980293], [93.91590118, 25.88766289], [93.91382599, 25.88176918], [93.90184021, 25.87103081], [93.89861298, 25.86375046], [93.89340973, 25.86481094], [93.89161682, 25.85864067], [93.8885498, 25.85246086], [93.88273621, 25.84590912], [93.87362671, 25.85091972], [93.86872864, 25.85540962], [93.85170746, 25.86297035], [93.84233856, 25.86260986], [93.83274078, 25.85625076], [93.82430267, 25.84709167], [93.82137299, 25.83240128], [93.81884003, 25.8262291], [93.81157684, 25.82126999], [93.80758667, 25.81633759], [93.79576111, 25.81435013], [93.7913208, 25.8160305], [93.79070282, 25.82080078], [93.78875732, 25.82601929], [93.78734589, 25.82796288], [93.78452301, 25.8357811], [93.78259277, 25.8382206], [93.78108978, 25.84464073], [93.7798233, 25.84630966], [93.78380585, 25.84996033], [93.78296661, 25.85140038], [93.78359222, 25.85392952], [93.78147125, 25.8592701], [93.78528595, 25.86326027], [93.78578186, 25.86689949], [93.79181671, 25.86969185], [93.79064178, 25.8737812], [93.78827667, 25.87572098], [93.7874527, 25.87892914], [93.79145813, 25.89005852], [93.79184723, 25.89491272], [93.79514313, 25.89804077], [93.79573059, 25.90121078], [93.79811096, 25.90628815], [93.79833221, 25.90969276], [93.7963028, 25.91819191], [93.79226685, 25.92251968], [93.79360962, 25.92604065], [93.79321289, 25.93098068], [93.78862, 25.93296051], [93.7932663, 25.93674088], [93.79141998, 25.94005013], [93.79067993, 25.94419098], [93.78940582, 25.94602013], [93.78659821, 25.9474411], [93.7891922, 25.94901085], [93.78942108, 25.95258141], [93.78660583, 25.95423126], [93.78518677, 25.95829964], [93.78028107, 25.96060944], [93.77881622, 25.96325111], [93.77301788, 25.96602058], [93.76954651, 25.95799065], [93.77025604, 25.95350075], [93.76841736, 25.95504951], [93.76278687, 25.95492935], [93.7588501, 25.94869041], [93.74941254, 25.94205093], [93.75202179, 25.9396019], [93.75184631, 25.93637085], [93.75009155, 25.93728065], [93.7364502, 25.93053818], [93.72894287, 25.92839813], [93.71650696, 25.9217205], [93.71250916, 25.92267036], [93.70506287, 25.92127991], [93.69767761, 25.91706848], [93.68768311, 25.90944099], [93.68582916, 25.90493965], [93.69090271, 25.88927078], [93.70643616, 25.85329056], [93.70548248, 25.84863091], [93.70237732, 25.84699059], [93.70363617, 25.84970093], [93.70359039, 25.85350037], [93.69785309, 25.85131264], [93.69377136, 25.84724998], [93.6905365, 25.84756851], [93.6920166, 25.84412956], [93.68250275, 25.84070015], [93.68287659, 25.83575058], [93.67806244, 25.82887077], [93.67256165, 25.82812119], [93.66950989, 25.82879257], [93.66860962, 25.82463074], [93.66082764, 25.82438087], [93.65673828, 25.82635117], [93.65235901, 25.82282066], [93.64849091, 25.82397079], [93.64435577, 25.81957054], [93.64099884, 25.81792068], [93.64029694, 25.81343079], [93.63611603, 25.81368065], [93.63405609, 25.80997086], [93.63334656, 25.80524063], [93.6289978, 25.80439949], [93.62979889, 25.79998016], [93.62753296, 25.79862976], [93.62695313, 25.79160118], [93.62381744, 25.79042816], [93.6211319, 25.78523064], [93.62355804, 25.78392029], [93.62232971, 25.77983093], [93.61141205, 25.77649117], [93.60807037, 25.77687073], [93.60571289, 25.77263069], [93.60556793, 25.76745987], [93.60275269, 25.77082062], [93.5983429, 25.76836014], [93.59371185, 25.76428986], [93.59266663, 25.76624107], [93.58822632, 25.76815033], [93.58712006, 25.76555061], [93.58718872, 25.75945091], [93.58377075, 25.75774956], [93.57324982, 25.76079941], [93.57382202, 25.75966072], [93.57341766, 25.75661087], [93.56925201, 25.7550106], [93.57006073, 25.7517395], [93.56548309, 25.74134064], [93.56194305, 25.74094963], [93.55626678, 25.7419281], [93.55692291, 25.73773956], [93.54988098, 25.73244095], [93.54669952, 25.73447037], [93.54483795, 25.72697067], [93.54619598, 25.72151947], [93.5497818, 25.71897125], [93.54881287, 25.7147007], [93.54592896, 25.71018982], [93.54441833, 25.70590019], [93.54355621, 25.70170021], [93.53797913, 25.70319939], [93.53149414, 25.69400597], [93.53057098, 25.69269943], [93.52855682, 25.69376945], [93.52593994, 25.6996727], [93.52272797, 25.69320107], [93.51683807, 25.6880703], [93.51938629, 25.68597031], [93.52028656, 25.68367004], [93.51019287, 25.67102051], [93.50829315, 25.66681099], [93.50208282, 25.66201973], [93.49991608, 25.65652084], [93.49394226, 25.65526009], [93.49019623, 25.65596962], [93.49072266, 25.65343857], [93.48721313, 25.65047073], [93.4835968, 25.6517601], [93.48335266, 25.64576912], [93.47593689, 25.64798927], [93.47477722, 25.64429092], [93.46852875, 25.64376068], [93.46556854, 25.64419174], [93.46070099, 25.64154816], [93.45713806, 25.64059067], [93.45860291, 25.6384201], [93.46121979, 25.6365509], [93.46195984, 25.63339043], [93.45935822, 25.63312912], [93.45198059, 25.63747978], [93.44993591, 25.63493156], [93.4467926, 25.63881111], [93.44439697, 25.63804245], [93.44152069, 25.63478088], [93.4391861, 25.63439941], [93.43908691, 25.63233948], [93.43418121, 25.62986946], [93.43102264, 25.62920189], [93.42753601, 25.63145828], [93.42247009, 25.62226105], [93.41829681, 25.62105942], [93.41487122, 25.61664009], [93.41677856, 25.61488914], [93.41227722, 25.61367989], [93.40904999, 25.61169052], [93.40763855, 25.60942078], [93.40722656, 25.60649109], [93.40963745, 25.60410118], [93.40924835, 25.60041046], [93.40683746, 25.59647942], [93.40019989, 25.59628105], [93.3900528, 25.59472084], [93.39063263, 25.58909988], [93.38240051, 25.58475113], [93.38311005, 25.58279991], [93.38503265, 25.58119965], [93.38474274, 25.57792091], [93.38269806, 25.5761795], [93.37648773, 25.57731056], [93.37683868, 25.57374001], [93.37599182, 25.57104111], [93.37342072, 25.56917191], [93.36943817, 25.57025909], [93.36515808, 25.56976128], [93.36598206, 25.56326103], [93.36418152, 25.56064987], [93.36070251, 25.56043816], [93.35439301, 25.56520081], [93.34831238, 25.56321907], [93.34546661, 25.56112099], [93.34126282, 25.55485916], [93.33338165, 25.54902077], [93.33174133, 25.54681015], [93.33574677, 25.54541016], [93.34039307, 25.53729057], [93.3445816, 25.53607941], [93.34922791, 25.53832817], [93.3523407, 25.53757095], [93.35016632, 25.53367043], [93.35417938, 25.53119087], [93.35756683, 25.52766991], [93.36004639, 25.5203228], [93.36472321, 25.51616859], [93.36682129, 25.5128727], [93.36502075, 25.51013947], [93.36689758, 25.50786972], [93.37114716, 25.50514984], [93.37181854, 25.50113106], [93.38304138, 25.49756813], [93.3863678, 25.49335098], [93.38710022, 25.49031067], [93.39050293, 25.48562813], [93.39131165, 25.48143005], [93.39103699, 25.4780426], [93.39190674, 25.4742012], [93.39041901, 25.46916962], [93.3959198, 25.46412086], [93.40291595, 25.45918274], [93.41710663, 25.45279121], [93.42201996, 25.45479965], [93.42751312, 25.45526123], [93.43495941, 25.45477295], [93.44359589, 25.45060921], [93.45687103, 25.44194984], [93.46186829, 25.4346981], [93.46514893, 25.42340279], [93.46540833, 25.41587067], [93.46325684, 25.41096115], [93.46718597, 25.40306091], [93.47393799, 25.39311028], [93.47728729, 25.38600922], [93.47821808, 25.37988281], [93.46626282, 25.36173058], [93.46231842, 25.35886955], [93.45374298, 25.34811974], [93.45188904, 25.3441906], [93.45790863, 25.34091949], [93.46193695, 25.33658981], [93.45796967, 25.33005142], [93.45670319, 25.32526016], [93.46312714, 25.31986046], [93.46797943, 25.31381035], [93.47402191, 25.3092804], [93.46559143, 25.29905128], [93.45996857, 25.29473114], [93.45197296, 25.29474831], [93.44481659, 25.29231071], [93.43863678, 25.28655052], [93.42642975, 25.28106117], [93.42331696, 25.27791023], [93.42330933, 25.27216148], [93.4207077, 25.26626015], [93.41205597, 25.26345062], [93.40634155, 25.26408005], [93.40357208, 25.26307106], [93.39459229, 25.25029945], [93.38871765, 25.24592018], [93.38710022, 25.24239159], [93.38762665, 25.23204041], [93.38551331, 25.22855759], [93.38479614, 25.2257309], [93.38198853, 25.22386932], [93.37950134, 25.22079086], [93.3780899, 25.21610069], [93.36958313, 25.20806122], [93.37056732, 25.20359039], [93.3685379, 25.20005035], [93.36222076, 25.19560814], [93.36081696, 25.19195938], [93.35307312, 25.18180084], [93.34915161, 25.16673088], [93.3473587, 25.16389084], [93.34883881, 25.15717125], [93.34855652, 25.15349007], [93.35101318, 25.14454079], [93.34686279, 25.13770103], [93.34889984, 25.13479042], [93.34607697, 25.12986946], [93.3470459, 25.12746048], [93.34921265, 25.12540817], [93.34644318, 25.12508965], [93.34436035, 25.12133026], [93.34435272, 25.1161499], [93.34046173, 25.11441994], [93.33917236, 25.10640907], [93.33577728, 25.09584045], [93.32950592, 25.09449959], [93.32363129, 25.09167099], [93.32234192, 25.08838081], [93.31272125, 25.07795906], [93.31079102, 25.07262993], [93.30879211, 25.07059288], [93.30607605, 25.0644207], [93.30892944, 25.05852127], [93.30425262, 25.05603027], [93.30459595, 25.04799271], [93.30245972, 25.04818916], [93.30240631, 25.05194092], [93.30008698, 25.05260086], [93.29933929, 25.05046082], [93.29698181, 25.04767036], [93.29189301, 25.04709053], [93.28687286, 25.04680061], [93.28449249, 25.05154991], [93.26818085, 25.04968071], [93.26779938, 25.04880905], [93.26946259, 25.04659081], [93.26835632, 25.04409027], [93.26291656, 25.0418396], [93.26391602, 25.03890991], [93.2638092, 25.0359211], [93.25984955, 25.03207016], [93.2556076, 25.0286808], [93.25836945, 25.02519989], [93.25778961, 25.02174187], [93.25382996, 25.02135086], [93.24884033, 25.01880074], [93.25171661, 25.01601982], [93.24916077, 25.01316071], [93.24669647, 25.00416756], [93.24694824, 25.00363159], [93.24746704, 25.00328064], [93.24807739, 25.00303078], [93.24868774, 25.00290108], [93.24935913, 25.00287247], [93.25, 25.00295067], [93.25064087, 25.00316048], [93.25121307, 25.00348091], [93.2518158, 25.00418091], [93.253479, 25.00637054], [93.25521088, 25.00420952], [93.25533295, 25.00364113], [93.25580597, 25.00325966], [93.2564621, 25.00311089], [93.25710297, 25.00319099], [93.2576828, 25.00350189], [93.25800323, 25.00420952], [93.25990295, 25.00645065], [93.26245117, 25.00602913], [93.26332092, 25.00423813], [93.26143646, 25.00092125], [93.2571106, 25.00094032], [93.25567627, 25.00220108], [93.25562286, 24.99971008], [93.25705719, 24.99847031], [93.25695801, 24.99602127], [93.25525665, 24.99240112], [93.25202179, 24.98880959], [93.25325775, 24.98637009], [93.25302124, 24.98266029], [93.25152588, 24.98142052], [93.25432587, 24.97891998], [93.25287628, 24.97514915], [93.2529068, 24.97262955], [93.25871277, 24.97265053], [93.263237, 24.96637917], [93.26332855, 24.96388054], [93.2605896, 24.95887184], [93.26082611, 24.95387077], [93.26241302, 24.95137024], [93.25950623, 24.9513607], [93.25354004, 24.95508957], [93.24923706, 24.95508003], [93.24938965, 24.95259285], [93.25092316, 24.95009995], [93.25110626, 24.94634819], [93.25411987, 24.94261932], [93.24983978, 24.94260025], [93.24693298, 24.94384956], [93.24407959, 24.94384003], [93.24131775, 24.94133949], [93.2399826, 24.93884277], [93.24003601, 24.93758011], [93.24143982, 24.93758965], [93.24707794, 24.94009972], [93.24849701, 24.94009972], [93.24720001, 24.93634033], [93.24304962, 24.93132973], [93.24450684, 24.93008041], [93.25019836, 24.93008041], [93.25325775, 24.91883087], [93.25045776, 24.91506195], [93.24185944, 24.91504097], [93.24043274, 24.91628075], [93.23899078, 24.91502953], [93.24188995, 24.91127014], [93.24336243, 24.90750122], [93.24337769, 24.90374184], [93.24195099, 24.90122032], [93.23622131, 24.90245056], [93.23338318, 24.89869118], [93.23338318, 24.89491081], [93.23049164, 24.89490128], [93.23483276, 24.88989067], [93.23339081, 24.88484955], [93.22908783, 24.88484001], [93.22621918, 24.88106918], [93.22908783, 24.87730026], [93.22480774, 24.87478065], [93.22194672, 24.87099266], [93.21906281, 24.86972046], [93.21618652, 24.86469078], [93.2142868, 24.86194992], [93.21013641, 24.85904121], [93.20870209, 24.85653114], [93.20584106, 24.85526085], [93.20007324, 24.85775948], [93.19719696, 24.85649109], [93.19864655, 24.8527298], [93.20152283, 24.85021973], [93.20155334, 24.84394073], [93.19580078, 24.84644127], [93.19438171, 24.84391975], [93.19727325, 24.84016037], [93.19869995, 24.84016037], [93.20012665, 24.84143066], [93.20155334, 24.84017181], [93.19870758, 24.83638954], [93.1958313, 24.83764076], [93.19438934, 24.83764076], [93.19297028, 24.83638191], [93.19297791, 24.83386993], [93.19728851, 24.83388138], [93.19300079, 24.82632065], [93.19159698, 24.82256126], [93.19590759, 24.8162899], [93.19877625, 24.81504059], [93.19735718, 24.81126022], [93.19449615, 24.80875015], [93.19307709, 24.80623055], [93.19020081, 24.80622101], [93.18589783, 24.80495071], [93.18158722, 24.80493927], [93.18017578, 24.80241966], [93.18017578, 24.79865074], [93.17875671, 24.79614067], [93.1772995, 24.79611969], [93.1758728, 24.79738808], [93.17442322, 24.80367088], [93.16867828, 24.80112839], [93.16581726, 24.79861069], [93.16153717, 24.79734039], [93.15724182, 24.79231071], [93.15294647, 24.78977966], [93.15293121, 24.79353905], [93.15148163, 24.79605103], [93.14861298, 24.7985611], [93.14428711, 24.79980087], [93.14285278, 24.80105972], [93.13994598, 24.80480957], [93.13706207, 24.81109047], [93.13134003, 24.80604172], [93.12700653, 24.80854034], [93.12127686, 24.80853081], [93.11984253, 24.81102943], [93.12269592, 24.8148098], [93.12267303, 24.81982994], [93.11979675, 24.81731033], [93.11122131, 24.81226158], [93.10978699, 24.80974007], [93.11270142, 24.80220985], [93.10845947, 24.7908802], [93.10558319, 24.78837013], [93.10562897, 24.78460121], [93.10706329, 24.78334045], [93.10132599, 24.77831078], [93.10280609, 24.77329063], [93.10566711, 24.76953125], [93.10427856, 24.76324081], [93.10002899, 24.75444031], [93.10003662, 24.75066948], [93.10147095, 24.74941063], [93.09864044, 24.74438095], [93.10150146, 24.74188042], [93.10293579, 24.74315071], [93.10292053, 24.74690056], [93.10579681, 24.74566078], [93.1072464, 24.74189949], [93.10441589, 24.73686981], [93.09725952, 24.73180962], [93.09729004, 24.72805023], [93.09442902, 24.7242794], [93.09298706, 24.72426033], [93.09443665, 24.72050858], [93.09303284, 24.71548271], [93.08878326, 24.70919037], [93.0786972, 24.71417046], [93.0758667, 24.71039009], [93.08020782, 24.70414162], [93.08306885, 24.70164108], [93.08452606, 24.69787025], [93.09028625, 24.69286919], [93.09319305, 24.68785286], [93.09320068, 24.68408012], [93.09179688, 24.68032074], [93.09179688, 24.67781067], [93.09324646, 24.67654991], [93.09754181, 24.67782021], [93.1018219, 24.68035126], [93.10469055, 24.67910004], [93.10470581, 24.67534256], [93.103302, 24.67156029], [93.09903717, 24.66653061], [93.09763336, 24.66276169], [93.09765625, 24.6590004], [93.09626007, 24.6564827], [93.09628296, 24.6527195], [93.08912659, 24.65270996], [93.08625793, 24.65143967], [93.0848465, 24.64767075], [93.08930206, 24.63389015], [93.08938599, 24.62763023], [93.08220673, 24.62760162], [93.07935333, 24.62634087], [93.079422, 24.62132263], [93.08233643, 24.61758041], [93.08673096, 24.61382103], [93.08676147, 24.61133003], [93.07678223, 24.60377121], [93.07538605, 24.60000038], [93.07541656, 24.59622955], [93.07981873, 24.59250069], [93.08854675, 24.59003067], [93.09866333, 24.59134293], [93.10444641, 24.58760262], [93.10675049, 24.58395958], [93.10697937, 24.58356094], [93.10447693, 24.58257294], [93.09726715, 24.58254051], [93.09622955, 24.58022118], [93.08714294, 24.57118034], [93.07845306, 24.57491112], [93.07122803, 24.57613182], [93.06111908, 24.57483292], [93.07269287, 24.56109047], [93.0655365, 24.54726982], [93.06121826, 24.55477905], [93.05268097, 24.5447197], [93.05130005, 24.53718948], [93.04846954, 24.53091049], [93.05282593, 24.52466965], [93.05282593, 24.51964951], [93.04141998, 24.51459122], [93.04001617, 24.51081085], [93.04432678, 24.50580025], [93.0357666, 24.49694824], [93.04572296, 24.48181915], [93.04852295, 24.47548294], [93.04825592, 24.46396065], [93.03790283, 24.46115112], [93.03674316, 24.44394112], [93.03215027, 24.42885971], [93.03932953, 24.41756821], [93.03916931, 24.41113091], [93.02921295, 24.40633965], [93.01599121, 24.40253067], [93.00889587, 24.40537071], [93.00644684, 24.41193008], [93.00049591, 24.40327072], [92.99804688, 24.40157127], [92.99534607, 24.40195084], [92.99192047, 24.40549278], [92.98832703, 24.40764999], [92.98542786, 24.40756035], [92.98026276, 24.40969086], [92.97564697, 24.40776062], [92.97083282, 24.40121269], [92.96032715, 24.39588165], [92.95813751, 24.39805031], [92.95469666, 24.40388107], [92.95388794, 24.40462112], [92.95124817, 24.40483093], [92.94415283, 24.40183258], [92.94055176, 24.40105057], [92.93855286, 24.39902115], [92.93773651, 24.39670944], [92.93570709, 24.39554024], [92.92765045, 24.39862823], [92.92537689, 24.40221977], [92.92366028, 24.40261078], [92.92259979, 24.40415955], [92.92339325, 24.40571976], [92.91153717, 24.41290092], [92.90930939, 24.40316963], [92.9057312, 24.3990593], [92.90587616, 24.39537048], [92.90516663, 24.39445114], [92.90097809, 24.39343071], [92.8963623, 24.39430046], [92.89438629, 24.39530945], [92.89173126, 24.40179062], [92.89077759, 24.40229034], [92.88800812, 24.4016304], [92.88424683, 24.40303993], [92.87819672, 24.39888954], [92.87386322, 24.39725113], [92.87178802, 24.39705086], [92.86289978, 24.39949989], [92.85906219, 24.3984108], [92.85447693, 24.39400101], [92.85164642, 24.39237022], [92.84909058, 24.38613129], [92.84690857, 24.38229942], [92.84427643, 24.37986946], [92.8396225, 24.38080025], [92.83270264, 24.37636948], [92.82898712, 24.37776947], [92.82816315, 24.37931061], [92.82826233, 24.38557816], [92.82541656, 24.38842964], [92.82504272, 24.39049149], [92.82659912, 24.39355278], [92.83167267, 24.39934158], [92.83136749, 24.40050125], [92.8303299, 24.40175056], [92.82479095, 24.40418053], [92.82112885, 24.40678024], [92.81832886, 24.41272926], [92.81645203, 24.41225052], [92.8111496, 24.41364288], [92.81140137, 24.41537285], [92.80944061, 24.4152317], [92.80887604, 24.4168911], [92.80948639, 24.41930008], [92.80715942, 24.41986275], [92.80370331, 24.41879082], [92.80079651, 24.41905022], [92.80004883, 24.42146111], [92.80381775, 24.42172241], [92.80425262, 24.4229908], [92.80284882, 24.42728043], [92.80031586, 24.4319706], [92.7977829, 24.43470955], [92.79390717, 24.4440403], [92.78987885, 24.45607948], [92.78624725, 24.4637394], [92.78437805, 24.47120285], [92.78222656, 24.47480011], [92.77913666, 24.48649979], [92.76519775, 24.52084923], [92.76451111, 24.51883125], [92.75918579, 24.51176071], [92.75364685, 24.50704193], [92.75450134, 24.50111961], [92.75132751, 24.49436951], [92.7507782, 24.49149132], [92.74884033, 24.48854065], [92.74360657, 24.47462845], [92.73053741, 24.45275116], [92.72376251, 24.43594933], [92.71813965, 24.41621971], [92.71511841, 24.41452026], [92.71411896, 24.41296005], [92.71420288, 24.41036987], [92.71508789, 24.40876961], [92.71412659, 24.40777969], [92.71421814, 24.40532112], [92.70742035, 24.39241028], [92.70745087, 24.38701057], [92.70343781, 24.38380051], [92.70410919, 24.3762207], [92.70240784, 24.3752327], [92.69827271, 24.37496185], [92.69687653, 24.37400055], [92.69500732, 24.36956978], [92.69325256, 24.36782074], [92.69420624, 24.36495972], [92.69391632, 24.36363029], [92.69177246, 24.36216927], [92.69167328, 24.35642052], [92.6906662, 24.35480118], [92.68799591, 24.35201073], [92.684021, 24.34988976], [92.68379974, 24.34748077], [92.67964172, 24.34778023], [92.6747818, 24.34980011], [92.66699982, 24.34560966], [92.66525269, 24.34521103], [92.66410828, 24.34674072], [92.6632309, 24.34379959], [92.6622467, 24.3434391], [92.66072083, 24.34514999], [92.65847015, 24.34346008], [92.65751648, 24.34350967], [92.65759277, 24.34155083], [92.65645599, 24.33912086], [92.65239716, 24.33529091], [92.65203857, 24.33286095], [92.65184021, 24.33033943], [92.6493988, 24.33082008], [92.64978027, 24.32922173], [92.64904022, 24.32875061], [92.64524841, 24.33181], [92.64594269, 24.32923126], [92.6450119, 24.32767105], [92.64099121, 24.32871056], [92.63983917, 24.32973099], [92.63925934, 24.33175087], [92.63668823, 24.33269119], [92.63654327, 24.33423805], [92.638237, 24.33443069], [92.6377182, 24.33551979], [92.6359024, 24.33574104], [92.63063812, 24.33337021], [92.6261673, 24.33447266], [92.62428284, 24.33265114], [92.62335205, 24.33077049], [92.62310028, 24.32028961], [92.61943817, 24.31150818], [92.61963654, 24.30846024], [92.61802673, 24.30435944], [92.61830902, 24.29970932], [92.61678314, 24.29123116], [92.61723328, 24.28906059], [92.6190567, 24.28787041], [92.61940002, 24.2867794], [92.61904144, 24.28132057], [92.61682129, 24.27531052], [92.61576843, 24.2705307], [92.61550903, 24.26362038], [92.61308289, 24.25583839], [92.61158752, 24.2533493], [92.60795593, 24.25008011], [92.60595703, 24.24920082], [92.59596252, 24.24930954], [92.59356689, 24.24858856], [92.59140015, 24.24598122], [92.5880127, 24.2448616], [92.58184052, 24.24535942], [92.56455994, 24.25008965], [92.55893707, 24.24789047], [92.55063629, 24.2458992], [92.54882812, 24.24323082], [92.54709625, 24.23769951], [92.54693604, 24.23476028], [92.5477829, 24.23188972], [92.54738617, 24.2244091], [92.54574585, 24.21990013], [92.54223633, 24.21417809], [92.54242706, 24.21062088], [92.54147339, 24.20622826], [92.53726959, 24.201931], [92.53639984, 24.19989967], [92.53781891, 24.19647026], [92.53147888, 24.18346024], [92.53346252, 24.18083191], [92.53289032, 24.18053055], [92.53151703, 24.17741966], [92.52990723, 24.17641068], [92.52966309, 24.17480087], [92.52539825, 24.17292976], [92.52175903, 24.17292976], [92.51759338, 24.1762104], [92.51512909, 24.17548752], [92.51357269, 24.17358017], [92.5147934, 24.17020035], [92.51373291, 24.16926003], [92.50863647, 24.1692009], [92.51200104, 24.16481972], [92.51283264, 24.16257858], [92.50953674, 24.16288948], [92.50678253, 24.16682053], [92.50488281, 24.16731071], [92.50325775, 24.16666985], [92.50245667, 24.16211128], [92.50013733, 24.16052055], [92.49475861, 24.15994072], [92.48808289, 24.16221809], [92.48586273, 24.16220093], [92.48493958, 24.16138077], [92.48490143, 24.15930939], [92.48396301, 24.15814018], [92.48264313, 24.15709114], [92.48118591, 24.1570797], [92.48355865, 24.15393066], [92.48293304, 24.1527195], [92.48065948, 24.15229988], [92.48062897, 24.15011024], [92.47875214, 24.14871025], [92.48149872, 24.14294052], [92.48087311, 24.14132118], [92.47960663, 24.14089966], [92.474823, 24.14291], [92.47332001, 24.14203072], [92.47335052, 24.13996124], [92.46858978, 24.13800049], [92.46682739, 24.13504028], [92.4659729, 24.13475037], [92.46483612, 24.13663101], [92.4630661, 24.13636971], [92.45722198, 24.14350128], [92.45063019, 24.14369011], [92.4438858, 24.15309906], [92.44182587, 24.1528511], [92.43875885, 24.15125084], [92.43743134, 24.15135002], [92.43656921, 24.15242958], [92.43522644, 24.16257858], [92.43814087, 24.16913033], [92.43775177, 24.1704998], [92.43445587, 24.17414093], [92.43419647, 24.18138123], [92.43321228, 24.1832695], [92.42214966, 24.18852997], [92.41897583, 24.19436073], [92.41971588, 24.20247078], [92.41822052, 24.2109108], [92.42018127, 24.21788979], [92.41851807, 24.22164917], [92.42005157, 24.23520279], [92.42253113, 24.24817085], [92.42237854, 24.25311089], [92.4164505, 24.25342941], [92.40683746, 24.25193977], [92.39570618, 24.25252914], [92.37652588, 24.25131035], [92.31407166, 24.25260162], [92.3105011, 24.2513485], [92.30349731, 24.25269127], [92.29668427, 24.25174141], [92.29660797, 24.25172997], [92.29187012, 24.25128174], [92.28491211, 24.25205231], [92.28478241, 24.25206757], [92.25970459, 24.25048828], [92.25958252, 24.25049019], [92.24047852, 24.25067139], [92.21289063, 24.24932861], [92.26409912, 24.36214828], [92.26415253, 24.36226082], [92.26812744, 24.36730957], [92.2677002, 24.37329102], [92.26830292, 24.3747921], [92.27225494, 24.37768936], [92.27246857, 24.37928009], [92.27187347, 24.38003349], [92.2698822, 24.38219833], [92.26994324, 24.38228989], [92.2726593, 24.38622284], [92.27270508, 24.3862915], [92.27308655, 24.38845062], [92.27050781, 24.39093018], [92.26989746, 24.39489746], [92.26428223, 24.39770508], [92.26267242, 24.40482903], [92.26264954, 24.40491676], [92.26330566, 24.40808105], [92.26268005, 24.40981102], [92.25927734, 24.41351318], [92.25863647, 24.41464615], [92.25595856, 24.41897964], [92.25747681, 24.43251991], [92.25653076, 24.4362793], [92.25632477, 24.4364109], [92.23931885, 24.44732666], [92.23606873, 24.45027161], [92.23593903, 24.45378113], [92.23506927, 24.45643234], [92.2322998, 24.45849609], [92.23114777, 24.46041489], [92.23108673, 24.46051025], [92.23109436, 24.46081352], [92.23117065, 24.46544075], [92.22895813, 24.47200203], [92.22891998, 24.47210121], [92.23029327, 24.4800396], [92.23384094, 24.48471069], [92.23950195, 24.4899292], [92.23660278, 24.49282265], [92.23632813, 24.49432373], [92.23615265, 24.49484444], [92.23547363, 24.49688721], [92.23510742, 24.49829102], [92.23468018, 24.49932861], [92.23426819, 24.5004406], [92.23099518, 24.50409126], [92.23094177, 24.50222969], [92.230896, 24.49969482], [92.22148132, 24.50151062], [92.22113037, 24.50292969], [92.22027588, 24.50628662], [92.21714783, 24.50720024], [92.21572876, 24.50774193], [92.21632385, 24.50882339], [92.21750641, 24.51111794], [92.21864319, 24.51323318], [92.22002411, 24.51494598], [92.22006226, 24.51503181], [92.21982574, 24.51594353], [92.21994781, 24.51636696], [92.22122192, 24.51669121], [92.22336578, 24.51729584], [92.22360229, 24.51742935], [92.22428131, 24.518713], [92.2247467, 24.51991463], [92.2261734, 24.52310371], [92.22721863, 24.52541924], [92.22834778, 24.52769279], [92.22866821, 24.52854919], [92.22927094, 24.52949905], [92.22979736, 24.52984047], [92.23073578, 24.53019142], [92.23083496, 24.53022766], [92.2310257, 24.53101921], [92.23101044, 24.53403664], [92.23106384, 24.53705788], [92.23124695, 24.54734993], [92.23130035, 24.54841995], [92.23139954, 24.55059433], [92.23152161, 24.55353355], [92.23165131, 24.55656433], [92.23181152, 24.56026459], [92.23193359, 24.56314659], [92.23204803, 24.56577873], [92.23214722, 24.56814194], [92.23220062, 24.56932449], [92.23227692, 24.57108307], [92.23325348, 24.57237625], [92.23374176, 24.57370567], [92.23366547, 24.57484818], [92.2341156, 24.57512093], [92.23458099, 24.57541656], [92.23388672, 24.57657623], [92.23412323, 24.57705688], [92.23434448, 24.57749939], [92.23455048, 24.57790947], [92.233284, 24.57790756], [92.23310089, 24.57930756], [92.23330688, 24.58109093], [92.23332214, 24.581213], [92.23336792, 24.58187675], [92.23394012, 24.58321762], [92.23378754, 24.58464432], [92.23430634, 24.58588409], [92.23477936, 24.58809662], [92.23490143, 24.5888443], [92.23510742, 24.59012032], [92.23542023, 24.59146881], [92.2358551, 24.5934906], [92.23613739, 24.59585381], [92.23540497, 24.59607506], [92.23529053, 24.59763908], [92.2359314, 24.59915161], [92.23616791, 24.5991478], [92.23690033, 24.59913063], [92.23719788, 24.60014153], [92.23722839, 24.60024071], [92.23740387, 24.60156059], [92.23822021, 24.60399246], [92.2386322, 24.60528374], [92.23906708, 24.607584], [92.23997498, 24.60799217], [92.24049377, 24.60822487], [92.24050903, 24.60841751], [92.2405777, 24.60944366], [92.24113464, 24.61059189], [92.24221039, 24.61147881], [92.24186707, 24.61240578], [92.24178314, 24.61416817], [92.24211884, 24.61477661], [92.24211884, 24.61514282], [92.24274445, 24.61555862], [92.24350739, 24.61606789], [92.24363708, 24.6161499], [92.24377441, 24.61750603], [92.24395752, 24.61824989], [92.24394989, 24.61902809], [92.24430847, 24.62035751], [92.2432785, 24.62156868], [92.24333191, 24.62320137], [92.24337006, 24.62559128], [92.24404144, 24.62716293], [92.24424744, 24.62825203], [92.24437714, 24.62893867], [92.24508667, 24.6300087], [92.24610138, 24.6317234], [92.24636841, 24.63235664], [92.24661255, 24.63292503], [92.24707794, 24.63430405], [92.24732971, 24.63581085], [92.24740601, 24.63658714], [92.24742126, 24.63680077], [92.24745178, 24.63710976], [92.24810791, 24.63850975], [92.2483139, 24.63935852], [92.24838257, 24.63954735], [92.24893951, 24.64104652], [92.24897003, 24.64126968], [92.24910736, 24.64235115], [92.24922943, 24.64325333], [92.2490387, 24.64353752], [92.24848175, 24.64436722], [92.24851227, 24.64446831], [92.24905396, 24.64608383], [92.24950409, 24.64780617], [92.24980927, 24.64917564], [92.24959564, 24.64954567], [92.24917603, 24.65026855], [92.24885559, 24.65081787], [92.24814606, 24.65239525], [92.24700928, 24.65491867], [92.24774933, 24.65628433], [92.24795532, 24.65750885], [92.24855804, 24.65860748], [92.24935913, 24.65881538], [92.24967194, 24.65890884], [92.24987793, 24.66002274], [92.25153351, 24.6601181], [92.25237274, 24.66184998], [92.25299835, 24.66349411], [92.25354004, 24.66534996], [92.2539978, 24.66607475], [92.25467682, 24.66716385], [92.25498962, 24.66840363], [92.25559998, 24.66990471], [92.25611877, 24.67096901], [92.25650024, 24.67222977], [92.25701904, 24.67358589], [92.25504303, 24.67425537], [92.25437927, 24.67527199], [92.25466156, 24.67643738], [92.25484467, 24.67722321], [92.25434113, 24.67818069], [92.25505066, 24.6787262], [92.25595093, 24.67980957], [92.25654602, 24.67966843], [92.25711823, 24.67952919], [92.25830078, 24.67964745], [92.25856018, 24.68008041], [92.25932312, 24.68133163], [92.25926971, 24.68239784], [92.25846863, 24.68261909], [92.25815582, 24.68326569], [92.25840759, 24.68532753], [92.25954437, 24.68658447], [92.25963593, 24.68740273], [92.26078033, 24.68805504], [92.26154327, 24.69024467], [92.26268768, 24.69043541], [92.26345825, 24.69056511], [92.26467896, 24.69076347], [92.26506042, 24.69118309], [92.2651825, 24.69131851], [92.26531219, 24.69157219], [92.26597595, 24.69291115], [92.2666626, 24.69429207], [92.26773834, 24.69446564], [92.26785278, 24.69512177], [92.26802826, 24.69613266], [92.26833344, 24.69655418], [92.2697525, 24.69869995], [92.27036285, 24.70021248], [92.27119446, 24.70115662], [92.27129364, 24.70171165], [92.27230072, 24.70273972], [92.27436829, 24.70552254], [92.27533722, 24.70674515], [92.27606201, 24.70758629], [92.27490997, 24.70815659], [92.27546692, 24.70932961], [92.27702332, 24.71168327], [92.2786026, 24.71347809], [92.2807312, 24.7147274], [92.2820816, 24.71701622], [92.28264618, 24.71792793], [92.28465271, 24.71985817], [92.28523254, 24.72104073], [92.28713226, 24.7226944], [92.28718567, 24.72278214], [92.2872467, 24.7228756], [92.28878784, 24.72519112], [92.28919983, 24.72581863], [92.28957367, 24.72642517], [92.29004669, 24.72710419], [92.29029846, 24.72760391], [92.29117584, 24.72855568], [92.29138947, 24.72878838], [92.29152679, 24.72925758], [92.29151154, 24.72944832], [92.29206848, 24.73041725], [92.29229736, 24.73074532], [92.29239655, 24.73094559], [92.29277039, 24.73110199], [92.2929306, 24.73119164], [92.293396, 24.73145103], [92.29380035, 24.73167801], [92.29395294, 24.73188591], [92.29390717, 24.73204041], [92.29377747, 24.73213768], [92.29359436, 24.73232079], [92.29350281, 24.73252296], [92.29358673, 24.73261833], [92.29379272, 24.73264313], [92.29390717, 24.73262787], [92.29410553, 24.73260117], [92.29428101, 24.73264503], [92.29458618, 24.73292542], [92.29464722, 24.73309898], [92.2946701, 24.73335648], [92.29462433, 24.73349953], [92.29437256, 24.73363686], [92.29415894, 24.73382187], [92.29384613, 24.7342186], [92.29376221, 24.73451614], [92.2938385, 24.73469734], [92.29393768, 24.73485756], [92.29404449, 24.73497963], [92.29425812, 24.73509026], [92.29447174, 24.73520279], [92.29499054, 24.73546219], [92.29541016, 24.73567581], [92.29547119, 24.73580742], [92.29534912, 24.73620224], [92.29540253, 24.73639679], [92.29588318, 24.7366333], [92.29512787, 24.73693085], [92.2934494, 24.7375927], [92.28988647, 24.73899269], [92.28817749, 24.73966599], [92.28552246, 24.7407093], [92.28380585, 24.7413826], [92.28183746, 24.74215698], [92.28119659, 24.74245262], [92.28179169, 24.74355316], [92.27963257, 24.74448967], [92.27896118, 24.74572372], [92.28004456, 24.74556351], [92.28006744, 24.74580574], [92.28009033, 24.74598122], [92.28028107, 24.74782753], [92.27972412, 24.74830627], [92.28159332, 24.75049973], [92.28353119, 24.75278664], [92.28469849, 24.75415993], [92.28672028, 24.75653648], [92.28710938, 24.75852394], [92.28739166, 24.75974846], [92.28823853, 24.75967789], [92.28886414, 24.7611618], [92.28795624, 24.76176643], [92.28742218, 24.76212311], [92.28733826, 24.76217842], [92.28702545, 24.76234436], [92.28678894, 24.76246834], [92.28565216, 24.76306915], [92.28530121, 24.76330757], [92.28489685, 24.7635746], [92.28427124, 24.76374817], [92.28411102, 24.76379204], [92.28269958, 24.76436615], [92.28242493, 24.76488876], [92.28217316, 24.76530075], [92.28127289, 24.76576042], [92.28015137, 24.76633072], [92.28090668, 24.7673893], [92.28193665, 24.7684021], [92.28253937, 24.77059746], [92.28298187, 24.7709465], [92.28292084, 24.7734127], [92.28208923, 24.77443314], [92.28172302, 24.77545738], [92.28226471, 24.77554512], [92.28260803, 24.77559853], [92.28288269, 24.7756424], [92.28296661, 24.77559853], [92.28462982, 24.77474022], [92.28466797, 24.77514267], [92.28482819, 24.7766552], [92.28633881, 24.77699471], [92.28675079, 24.77859306], [92.28783417, 24.77932739], [92.28762054, 24.78114128], [92.28866577, 24.78150368], [92.28824615, 24.78189278], [92.28803253, 24.78209496], [92.28813171, 24.78239822], [92.2885437, 24.7837162], [92.28864288, 24.78403664], [92.28883362, 24.78463173], [92.2881546, 24.78621674], [92.2881012, 24.78635406], [92.28765869, 24.78705025], [92.28734589, 24.78754616], [92.2881012, 24.78743935], [92.28839874, 24.78819656], [92.28844452, 24.78832245], [92.28753662, 24.78860664], [92.28710938, 24.78874016], [92.28688049, 24.7889061], [92.28653717, 24.78916359], [92.28601074, 24.78918839], [92.28569031, 24.78894997], [92.28462219, 24.78905106], [92.28438568, 24.78907967], [92.2841568, 24.78910828], [92.28358459, 24.7895031], [92.2824707, 24.78999138], [92.28232574, 24.79005432], [92.28214264, 24.79003525], [92.28205109, 24.79002571], [92.28199005, 24.79006386], [92.28171539, 24.79024696], [92.28099823, 24.79074287], [92.28063965, 24.79153633], [92.2804184, 24.79210281], [92.28023529, 24.79250908], [92.28001404, 24.7928009], [92.2798996, 24.79297066], [92.27980804, 24.79305649], [92.27974701, 24.7931118], [92.27934265, 24.79337311], [92.27952576, 24.79342842], [92.27984619, 24.79366302], [92.27941132, 24.79411125], [92.27914429, 24.7942276], [92.27922058, 24.79435349], [92.27927399, 24.79442024], [92.27931213, 24.79452515], [92.2795639, 24.79496193], [92.27960968, 24.7950573], [92.27977753, 24.79567719], [92.27968597, 24.79598427], [92.27950287, 24.7964859], [92.27916718, 24.7970047], [92.27912903, 24.79706764], [92.27901459, 24.79719925], [92.27881622, 24.79753494], [92.2784729, 24.7976284], [92.27786255, 24.79779434], [92.27750397, 24.7978344], [92.27737427, 24.7978878], [92.27718353, 24.79795647], [92.27709961, 24.79794502], [92.27682495, 24.79791069], [92.27649689, 24.79814529], [92.27619934, 24.79829788], [92.27606964, 24.79836464], [92.27574158, 24.7985363], [92.2756424, 24.79858398], [92.2755661, 24.79861641], [92.27528381, 24.79868698], [92.275177, 24.7986908], [92.27496338, 24.79870033], [92.27462769, 24.79881859], [92.27437592, 24.79888535], [92.27381134, 24.79914474], [92.27349854, 24.7993145], [92.27346039, 24.79971886], [92.27326202, 24.79992676], [92.27323151, 24.80008316], [92.27326965, 24.80023193], [92.27304077, 24.80032349], [92.27311707, 24.80046844], [92.2730484, 24.8006649], [92.27301788, 24.80075264], [92.27318573, 24.80115509], [92.27331543, 24.80151176], [92.27342224, 24.80169296], [92.2735672, 24.80195427], [92.27378082, 24.80223083], [92.27388763, 24.80236435], [92.27410889, 24.80259705], [92.27436066, 24.80286598], [92.27455902, 24.80307007], [92.27481842, 24.80331039], [92.27523041, 24.80384636], [92.27498627, 24.80416489], [92.27490997, 24.80426407], [92.27431488, 24.80558968], [92.27420044, 24.80585098], [92.27416229, 24.80666924], [92.27430725, 24.80708313], [92.27436066, 24.80719185], [92.27442932, 24.80730057], [92.27436829, 24.80735779], [92.27456665, 24.80755615], [92.27468872, 24.80773163], [92.27474976, 24.80783653], [92.27490997, 24.80787849], [92.27497864, 24.80825615], [92.27516937, 24.80842209], [92.27548218, 24.8087883], [92.27555847, 24.80898285], [92.27583313, 24.80956078], [92.27607727, 24.81004143], [92.2760849, 24.81071854], [92.27603149, 24.81080818], [92.27574158, 24.81104279], [92.27533722, 24.81123352], [92.27616882, 24.81214142], [92.27584076, 24.81237793], [92.2751236, 24.81299782], [92.27485657, 24.81305313], [92.27476501, 24.81305885], [92.27426147, 24.81349945], [92.27424622, 24.81360054], [92.27419281, 24.8137207], [92.27396393, 24.81383514], [92.27378082, 24.81393051], [92.27377319, 24.81424713], [92.27403259, 24.81458855], [92.27448273, 24.81462288], [92.27458954, 24.81464577], [92.27474976, 24.81473541], [92.27513123, 24.81495285], [92.27536011, 24.81503677], [92.27575684, 24.81518936], [92.27588654, 24.81529236], [92.27619171, 24.81557083], [92.27599335, 24.81582451], [92.27587128, 24.81599617], [92.27596283, 24.81627464], [92.27542877, 24.81701469], [92.27545166, 24.81712532], [92.27549744, 24.81739044], [92.27532196, 24.81764221], [92.27526855, 24.81785583], [92.2751236, 24.81815529], [92.27497101, 24.81839943], [92.27483368, 24.81869888], [92.27481079, 24.81877136], [92.2747879, 24.81885147], [92.27461243, 24.81893158], [92.27393341, 24.81923485], [92.27391052, 24.81946754], [92.27387238, 24.81962776], [92.27379608, 24.81972122], [92.27371216, 24.81981659], [92.27361298, 24.81992531], [92.27342224, 24.82060242], [92.27335358, 24.82094193], [92.27323151, 24.82099915], [92.27282715, 24.8211422], [92.27269745, 24.82143974], [92.27266693, 24.82153511], [92.27267456, 24.82169342], [92.27268982, 24.82178879], [92.27297974, 24.82258606], [92.27288818, 24.8227005], [92.27288818, 24.82278824], [92.27288818, 24.82288551], [92.27281189, 24.82300949], [92.27267456, 24.8231926], [92.27259827, 24.82383728], [92.27256775, 24.82409286], [92.27276611, 24.8244648], [92.27294922, 24.82475281], [92.27279663, 24.82546806], [92.27276611, 24.82557869], [92.27272797, 24.82597351], [92.27272797, 24.82624817], [92.27266693, 24.82645416], [92.27264404, 24.82656288], [92.27256775, 24.82695961], [92.27298737, 24.82756996], [92.27259827, 24.82775116], [92.27235413, 24.82787704], [92.27191162, 24.82810402], [92.27100372, 24.82876396], [92.27064514, 24.82904625], [92.2702713, 24.82926369], [92.26987457, 24.82960129], [92.26977539, 24.82966614], [92.26969147, 24.82971382], [92.26960754, 24.82976532], [92.26921844, 24.82995224], [92.26889038, 24.82998466], [92.26850891, 24.83003044], [92.26838684, 24.83005142], [92.26687622, 24.83019829], [92.26621246, 24.83019447], [92.26569366, 24.83025742], [92.26443481, 24.83033371], [92.26439667, 24.83050346], [92.26335144, 24.83045387], [92.26263428, 24.8304348], [92.26178741, 24.83037949], [92.26152039, 24.83043671], [92.2609787, 24.83044624], [92.26086426, 24.83051682], [92.26049042, 24.83073425], [92.26029205, 24.83036232], [92.25852966, 24.83081436], [92.25763702, 24.83102608], [92.25675964, 24.8312397], [92.25650787, 24.83124161], [92.25611877, 24.83135414], [92.25547028, 24.83154869], [92.25502777, 24.83174515], [92.25474548, 24.83181], [92.25417328, 24.8318882], [92.25367737, 24.83203125], [92.25338745, 24.83212471], [92.25311279, 24.83222961], [92.25289917, 24.8322773], [92.25267792, 24.83158112], [92.25242615, 24.83098221], [92.25228119, 24.83096504], [92.25215912, 24.83063316], [92.25208282, 24.83064651], [92.25163269, 24.83074951], [92.25117493, 24.83074379], [92.251091, 24.8306427], [92.25079346, 24.83068466], [92.25008392, 24.83024025], [92.24958801, 24.83018494], [92.24924469, 24.83014679], [92.24919891, 24.83001709], [92.24900818, 24.82987404], [92.24887085, 24.83065224], [92.24886322, 24.83075333], [92.24878693, 24.83080292], [92.24878693, 24.83095932], [92.24866486, 24.83112717], [92.24867249, 24.83147621], [92.24865723, 24.83156586], [92.24829865, 24.83241844], [92.24868011, 24.83266258], [92.24900055, 24.83264351], [92.248909, 24.83279991], [92.24993896, 24.8331604], [92.25031281, 24.83335114], [92.25076294, 24.83364296], [92.2512207, 24.83407784], [92.25150299, 24.83423233], [92.25161743, 24.83433533], [92.25160217, 24.83463669], [92.25032806, 24.835289], [92.25025177, 24.83582115], [92.2507782, 24.83622551], [92.25180817, 24.83701897], [92.25299835, 24.83747101], [92.25399017, 24.83785057], [92.25462341, 24.83837128], [92.25487518, 24.83857727], [92.25465393, 24.83880615], [92.25392151, 24.83858871], [92.25350189, 24.83844185], [92.25328064, 24.83838654], [92.25262451, 24.83839798], [92.25228119, 24.83847427], [92.2519455, 24.83860779], [92.2516098, 24.838871], [92.25117493, 24.83948708], [92.24859619, 24.83956337], [92.24751282, 24.83968163], [92.24600983, 24.83984566], [92.24528503, 24.83992386], [92.24518585, 24.84039688], [92.24378204, 24.84049034], [92.24300385, 24.84054184], [92.24242401, 24.84057999], [92.2425766, 24.84196854], [92.24259186, 24.84207344], [92.2423172, 24.8420887], [92.24138641, 24.84214211], [92.24165344, 24.84420395], [92.24154663, 24.84427834], [92.2416153, 24.84521866], [92.24098206, 24.84540367], [92.24103546, 24.84667778], [92.24108887, 24.84710312], [92.24112701, 24.84745216], [92.24115753, 24.84788895], [92.24125671, 24.84899521], [92.2413559, 24.84954071], [92.24140167, 24.84996986], [92.24119568, 24.85006332], [92.24071503, 24.85027885], [92.24075317, 24.85110855], [92.24039459, 24.8512001], [92.24038696, 24.8521595], [92.24016571, 24.85224152], [92.24015808, 24.85262299], [92.23967743, 24.85273743], [92.23957825, 24.85391045], [92.23960114, 24.85520172], [92.23964691, 24.85654259], [92.23972321, 24.85782623], [92.23899078, 24.85824203], [92.23820496, 24.85864067], [92.23807526, 24.85868263], [92.23750305, 24.8588562], [92.23674011, 24.85899544], [92.23631287, 24.85905647], [92.23580933, 24.85912895], [92.23582458, 24.85940552], [92.23581696, 24.86017418], [92.23529053, 24.86089897], [92.23484802, 24.86150551], [92.23576355, 24.8628788], [92.23522949, 24.86386299], [92.23557281, 24.86412239], [92.2358017, 24.86429596], [92.23682404, 24.86552238], [92.23719788, 24.86616516], [92.23741913, 24.86680412], [92.23754883, 24.86742973], [92.23789215, 24.86812019], [92.23825073, 24.86837006], [92.23875427, 24.86850929], [92.23939514, 24.86847496], [92.23984528, 24.86835289], [92.24029541, 24.86822891], [92.24054718, 24.87030029], [92.24060059, 24.87065125], [92.24209595, 24.87253952], [92.24391937, 24.87265968], [92.24677277, 24.87285423], [92.24688721, 24.87445068], [92.24638367, 24.87454224], [92.24685669, 24.87763977], [92.24719238, 24.87992477], [92.24711609, 24.88055229], [92.24689484, 24.88171959], [92.24714661, 24.88212204], [92.24713135, 24.88303757], [92.24687958, 24.88301849], [92.24706268, 24.88502884], [92.24729919, 24.88502312], [92.24803162, 24.88500786], [92.24787903, 24.88541794], [92.24802399, 24.88562584], [92.24719238, 24.88585472], [92.24727631, 24.88693047], [92.24707794, 24.88693047], [92.24713135, 24.88765717], [92.24598694, 24.88817596], [92.24485779, 24.88871384], [92.24341583, 24.88896942], [92.2430191, 24.88897514], [92.24209595, 24.8889904], [92.24073029, 24.88977242], [92.23933411, 24.89015579], [92.23938751, 24.89162254], [92.23940277, 24.89203644], [92.23924255, 24.89196968], [92.2388916, 24.89193916], [92.23833466, 24.89189911], [92.23802948, 24.89192009], [92.23739624, 24.89195442], [92.23699188, 24.89200974], [92.23653412, 24.89209747], [92.23652649, 24.89255142], [92.23554993, 24.8932457], [92.23556519, 24.89334869], [92.23557281, 24.89368248], [92.23561096, 24.89385414], [92.23570251, 24.89423561], [92.23576355, 24.89432335], [92.23601532, 24.89471436], [92.23635864, 24.8949585], [92.23640442, 24.8952198], [92.23613739, 24.89536285], [92.23604584, 24.89627838], [92.23554993, 24.8964901], [92.23553467, 24.89677811], [92.23590851, 24.89691544], [92.23595428, 24.8981781], [92.23602295, 24.8991642], [92.23602295, 24.89926338], [92.2348175, 24.89942741], [92.23445892, 24.89949989], [92.23360443, 24.89966965], [92.23336792, 24.89967918], [92.2329483, 24.89991379], [92.23239899, 24.90025711], [92.23232269, 24.90030098], [92.23212433, 24.90042877], [92.23262024, 24.90205574], [92.23429108, 24.90353775], [92.23474884, 24.90394592], [92.23674774, 24.90481758], [92.23957825, 24.90553474], [92.24115753, 24.90598869], [92.24281311, 24.90667725], [92.24501801, 24.9083252], [92.24523163, 24.91024971], [92.25020599, 24.91286278], [92.25505829, 24.91393089], [92.25640106, 24.91039085], [92.25759888, 24.90727425], [92.25824738, 24.90709496], [92.25945282, 24.9072113], [92.26087189, 24.90724373], [92.26329041, 24.9074688], [92.2634964, 24.90743065], [92.26558685, 24.90704536], [92.26721191, 24.90668678], [92.26793671, 24.90622711], [92.27085876, 24.9112587], [92.27908325, 24.91003036], [92.27986145, 24.9099102], [92.27999878, 24.90969086], [92.28226471, 24.9060936], [92.28304291, 24.90616608], [92.28376007, 24.90651512], [92.28404999, 24.90716171], [92.28399658, 24.90758705], [92.28456879, 24.90839958], [92.28473663, 24.90910149], [92.28529358, 24.91064453], [92.2857666, 24.91131401], [92.28682709, 24.91208267], [92.28791809, 24.91268921], [92.28939056, 24.91337013], [92.29013062, 24.91364288], [92.29057312, 24.91380501], [92.29092407, 24.91392326], [92.29205322, 24.91448021], [92.29272461, 24.91481018], [92.29434967, 24.91574097], [92.29595947, 24.91616821], [92.29773712, 24.91619492], [92.29890442, 24.91609573], [92.30042267, 24.91572571], [92.30065155, 24.91567039], [92.30176544, 24.91520309], [92.30306244, 24.91432571], [92.30370331, 24.91363716], [92.30407715, 24.91325188], [92.30529785, 24.91303825], [92.30857086, 24.90830994], [92.31214905, 24.90785027], [92.31445313, 24.90755081], [92.31519318, 24.90384102], [92.31925201, 24.90100098], [92.3200531, 24.90043068], [92.31973267, 24.89580917], [92.31983948, 24.89585304], [92.32053375, 24.8961544], [92.32128143, 24.89653969], [92.32299805, 24.89694786], [92.3237381, 24.89712524], [92.32521057, 24.89667702], [92.32582855, 24.89631653], [92.32637787, 24.89599991], [92.32695007, 24.89536858], [92.32725525, 24.89484024], [92.32736969, 24.89450836], [92.32770538, 24.8935318], [92.32782745, 24.89317322], [92.32798004, 24.89119148], [92.32823181, 24.88978004], [92.32949829, 24.88835144], [92.3314743, 24.88639832], [92.33357239, 24.88427925], [92.33628845, 24.88141251], [92.33834839, 24.87937546], [92.33966064, 24.87834358], [92.34030914, 24.87824059], [92.34083557, 24.87815475], [92.34209442, 24.87833405], [92.34225464, 24.87835693], [92.34375763, 24.87932777], [92.34468842, 24.88082886], [92.34490967, 24.88274765], [92.34494781, 24.88488579], [92.34477997, 24.8862915], [92.34476471, 24.88644791], [92.34466553, 24.88762665], [92.34458923, 24.89033508], [92.34465027, 24.89194107], [92.3447876, 24.89243317], [92.34487915, 24.89278603], [92.34497833, 24.89318085], [92.34580994, 24.89368248], [92.34661102, 24.89364243], [92.34750366, 24.89336777], [92.34765625, 24.89323616], [92.34868622, 24.8923378], [92.34875488, 24.89217567], [92.34978485, 24.88989258], [92.35077667, 24.88861275], [92.35158539, 24.8867321], [92.35286713, 24.88376999], [92.35350037, 24.88245964], [92.35355377, 24.88251877], [92.35371399, 24.88261986], [92.35384369, 24.88273811], [92.35394287, 24.88281059], [92.35411072, 24.88294792], [92.35549164, 24.88046265], [92.36210632, 24.88264847], [92.36289215, 24.88243103], [92.36546326, 24.88170052], [92.36736298, 24.87805939], [92.3693924, 24.87416077], [92.37025452, 24.87456703], [92.37177277, 24.87494087], [92.37359619, 24.87491035], [92.37541962, 24.87448502], [92.37619781, 24.87342453], [92.37696075, 24.8714447], [92.37731171, 24.86991501], [92.37731934, 24.86972427], [92.37822723, 24.86795998], [92.37838745, 24.86783218], [92.37849426, 24.86781502], [92.37859344, 24.86777115], [92.37875366, 24.86775589], [92.37892151, 24.86775208], [92.37892151, 24.86786842], [92.38098145, 24.86759377], [92.381073, 24.86758232], [92.3813324, 24.86754799], [92.3814621, 24.86753082], [92.3815918, 24.86751366], [92.38174438, 24.86749268], [92.38182831, 24.86740685], [92.38195801, 24.86746407], [92.38205719, 24.86745071], [92.3835907, 24.86724854], [92.384552, 24.86712265], [92.38883209, 24.86155128], [92.38925171, 24.86100006], [92.38539124, 24.85720062], [92.38695526, 24.8527317], [92.38851166, 24.85218811], [92.39051056, 24.85156059], [92.39232635, 24.85123253], [92.39505768, 24.85535812], [92.4028244, 24.85489273], [92.40296173, 24.85530281], [92.40331268, 24.85605049], [92.40408325, 24.85769653], [92.40414429, 24.85778046], [92.40437317, 24.85808182], [92.4048233, 24.85867882], [92.40499878, 24.85885239], [92.40573883, 24.85959244], [92.40720367, 24.8601284], [92.40908813, 24.86026955], [92.41152954, 24.86011314], [92.41430664, 24.85938644], [92.4164505, 24.86284256], [92.42172241, 24.86133957], [92.42592621, 24.86014175], [92.42588043, 24.8599205], [92.42491913, 24.85432053], [92.42524719, 24.85412979], [92.42605591, 24.85413742], [92.42757416, 24.85442924], [92.42980957, 24.85515022], [92.43131256, 24.8559742], [92.43378448, 24.85652924], [92.43321228, 24.85954094], [92.43752289, 24.86101913], [92.44068909, 24.86370087], [92.44107819, 24.86365318], [92.44116211, 24.86400032], [92.44129944, 24.8658123], [92.44124603, 24.86616325], [92.44091797, 24.86812973], [92.44100189, 24.86920166], [92.44174957, 24.87088776], [92.44262695, 24.87182999], [92.44364929, 24.87252617], [92.44517517, 24.87309647], [92.44836426, 24.87335014], [92.4498291, 24.87329292], [92.45077515, 24.87325668], [92.45253754, 24.87336349], [92.4551239, 24.87401581], [92.4569931, 24.87438202], [92.45935822, 24.87460518], [92.45964813, 24.87458229], [92.45959473, 24.87473869], [92.45959473, 24.87492371], [92.45954132, 24.87506676], [92.4595108, 24.87531281], [92.45946503, 24.87551689], [92.4594574, 24.87569809], [92.46006775, 24.87452507], [92.46136475, 24.87434578], [92.46577454, 24.87307358], [92.46810913, 24.87213135], [92.47003174, 24.87127876], [92.47063446, 24.87101555], [92.47196198, 24.87043381], [92.47353363, 24.86975861], [92.47419739, 24.86937714], [92.47492981, 24.86886024], [92.47530365, 24.86873627], [92.47583008, 24.86857796], [92.47618103, 24.86828232], [92.47637939, 24.86886024], [92.47660065, 24.86883926], [92.4769516, 24.86985588], [92.47684479, 24.86995125], [92.47694397, 24.87059784], [92.47716522, 24.87085533], [92.47742462, 24.87123871], [92.47779846, 24.87166786], [92.47828674, 24.87205696], [92.4783783, 24.87213326], [92.47909546, 24.87253952], [92.47950745, 24.87267303], [92.47973633, 24.87274742], [92.47988892, 24.8727951], [92.48040009, 24.87287331], [92.48051453, 24.87231064], [92.48182678, 24.87229156], [92.48262787, 24.87223244], [92.48497009, 24.87199593], [92.48549652, 24.87189484], [92.48784637, 24.87143135], [92.4878006, 24.87179375], [92.48765564, 24.87292862], [92.48925781, 24.87324715], [92.48941803, 24.8728466], [92.48949432, 24.87266159], [92.4901123, 24.8733902], [92.49014282, 24.87346077], [92.49032593, 24.8739357], [92.49190521, 24.87796402], [92.49124146, 24.87998772], [92.49188232, 24.88259125], [92.49182129, 24.88288689], [92.49172211, 24.88326836], [92.49176025, 24.88396835], [92.49184418, 24.88452339], [92.49185944, 24.88524818], [92.49186707, 24.88565254], [92.49172974, 24.88660622], [92.491539, 24.8871727], [92.49150085, 24.88730049], [92.49140167, 24.88796043], [92.49123383, 24.88890076], [92.49102783, 24.89016342], [92.49098969, 24.89072418], [92.49100494, 24.89096069], [92.49105835, 24.89160538], [92.49133301, 24.89226341], [92.491745, 24.89326477], [92.49275208, 24.89497375], [92.49382019, 24.8967514], [92.493927, 24.89750481], [92.49395752, 24.89769745], [92.49460602, 24.89884949], [92.49517059, 24.89951134], [92.49551392, 24.8999157], [92.49642181, 24.90108109], [92.49678802, 24.90217209], [92.49633026, 24.90252113], [92.4957428, 24.90310478], [92.49539185, 24.90332031], [92.49491119, 24.90351105], [92.49463654, 24.90348053], [92.49414825, 24.90375519], [92.49371338, 24.90409088], [92.49333954, 24.90451431], [92.49308014, 24.9049263], [92.49302673, 24.90557861], [92.49290466, 24.90591621], [92.49282074, 24.90622902], [92.49313354, 24.90801811], [92.49350739, 24.9101162], [92.493927, 24.91118622], [92.49449158, 24.91227341], [92.49488068, 24.91413307], [92.49480438, 24.91482162], [92.49474335, 24.91531754], [92.49452209, 24.91600418], [92.49414063, 24.91663933], [92.49385071, 24.91695976], [92.49337769, 24.91748428], [92.49268341, 24.9178524], [92.49248505, 24.91795731], [92.49240875, 24.91799927], [92.49146271, 24.91850662], [92.49069977, 24.91886902], [92.48973846, 24.91932297], [92.48825073, 24.92009544], [92.48773193, 24.92054367], [92.48748779, 24.92075539], [92.48723602, 24.92115974], [92.48696899, 24.9216671], [92.48622131, 24.92306137], [92.48530579, 24.92518425], [92.48474884, 24.92649841], [92.48423767, 24.92775536], [92.48423004, 24.92814064], [92.48394012, 24.92860413], [92.4838562, 24.92923546], [92.48374176, 24.93071938], [92.48381805, 24.93228912], [92.48402405, 24.93355942], [92.4845047, 24.93545532], [92.48471069, 24.93616104], [92.4852829, 24.93761635], [92.48556519, 24.93865585], [92.48596954, 24.9398365], [92.48642731, 24.94108391], [92.48728943, 24.94274902], [92.48783875, 24.94420433], [92.48790741, 24.94479752], [92.48783112, 24.945467], [92.48775482, 24.94621849], [92.48764038, 24.94667435], [92.48725891, 24.94724655], [92.48674011, 24.94757462], [92.48619843, 24.94771004], [92.48583221, 24.94779968], [92.48527527, 24.94783401], [92.4848938, 24.94777107], [92.48434448, 24.94765663], [92.48338318, 24.94728088], [92.48285675, 24.94688225], [92.48225403, 24.94633675], [92.48158264, 24.94571495], [92.48132324, 24.94544983], [92.48112488, 24.94524765], [92.48074341, 24.94489288], [92.48014069, 24.94423485], [92.47974396, 24.94387817], [92.47958374, 24.94375038], [92.47921753, 24.9425602], [92.47744751, 24.94260216], [92.47612, 24.94219971], [92.47377777, 24.94199181], [92.4730835, 24.94177246], [92.47122192, 24.941782], [92.4699173, 24.9417057], [92.46848297, 24.94176102], [92.46704865, 24.94167709], [92.46565247, 24.94160652], [92.46421051, 24.94149208], [92.46263885, 24.94124413], [92.46166992, 24.94102859], [92.46064758, 24.94081306], [92.45951843, 24.94054413], [92.45805359, 24.94021225], [92.45623016, 24.93964195], [92.45475006, 24.93916893], [92.45300293, 24.93865204], [92.45217896, 24.93865395], [92.45136261, 24.93858147], [92.45108032, 24.93871498], [92.45085907, 24.93882179], [92.45064545, 24.93873215], [92.45031738, 24.93859291], [92.4495697, 24.93872643], [92.44915771, 24.93889999], [92.44890594, 24.93909264], [92.44877625, 24.93952179], [92.44841766, 24.94055939], [92.44814301, 24.94170189], [92.44776917, 24.94382668], [92.44785309, 24.94513512], [92.44787598, 24.94542885], [92.44798279, 24.94600105], [92.44802856, 24.94623375], [92.44812012, 24.94671249], [92.44818878, 24.94733429], [92.44839478, 24.94762611], [92.44857025, 24.94805717], [92.44965363, 24.95012474], [92.45028687, 24.95082283], [92.45128632, 24.95211792], [92.45239258, 24.95307732], [92.45348358, 24.95390701], [92.45497894, 24.95471954], [92.45665741, 24.95500755], [92.45778656, 24.95520973], [92.45955658, 24.95540619], [92.46116638, 24.95543098], [92.46296692, 24.95584869], [92.46328735, 24.95591736], [92.46470642, 24.95478058], [92.47158051, 24.9559803], [92.47371674, 24.95709991], [92.47103119, 24.96409988], [92.46711731, 24.96858025], [92.4640274, 24.97077942], [92.4605484, 24.97615051], [92.45445251, 24.97318077], [92.44940948, 24.97208977], [92.44904327, 24.97154808], [92.44590759, 24.96696281], [92.44003296, 24.96680069], [92.43515778, 24.96637917], [92.43161011, 24.97066116], [92.42849731, 24.97257996], [92.42855072, 24.97290993], [92.42948151, 24.97988129], [92.42446899, 24.98257065], [92.42363739, 24.99609947], [92.4258728, 25.00319099], [92.42945099, 25.00969124], [92.43036652, 25.01280975], [92.43105316, 25.01581955], [92.43099976, 25.0216198], [92.43219757, 25.02507973], [92.43325043, 25.02808952], [92.43284607, 25.03102112], [92.4306488, 25.03226089], [92.42782593, 25.03157043], [92.4262619, 25.03164101], [92.42590332, 25.0318203], [92.43192291, 25.03290749], [92.43788147, 25.03375244], [92.44178009, 25.03985023], [92.4465332, 25.04204178], [92.45101929, 25.04095078], [92.45420837, 25.03660965], [92.45680237, 25.03503036], [92.45976257, 25.03518105], [92.46325684, 25.03712845], [92.46466064, 25.04722977], [92.46286011, 25.05014992], [92.46015167, 25.04959106], [92.45983887, 25.0546608], [92.46203613, 25.05583], [92.46366882, 25.0555706], [92.46598816, 25.05715752], [92.46750641, 25.06137085], [92.47091675, 25.06689072], [92.474617, 25.07080078], [92.47654724, 25.07825279], [92.48017883, 25.08584023], [92.47975922, 25.09574127], [92.48031616, 25.10040855], [92.48429871, 25.10806084], [92.49910736, 25.10814857], [92.50978088, 25.10547066], [92.52651215, 25.10585022], [92.53201294, 25.10396004], [92.53804779, 25.09931183], [92.54294586, 25.09959984], [92.54081726, 25.10412979], [92.53305817, 25.11214828], [92.53132629, 25.11990166], [92.53024292, 25.1218605], [92.52522278, 25.12557983], [92.52466583, 25.14002991], [92.52746582, 25.13994026], [92.53018951, 25.13682175], [92.53562927, 25.13441277], [92.53993988, 25.13727951], [92.54312897, 25.1350193], [92.55316925, 25.1307106], [92.55784607, 25.12997055], [92.56549835, 25.1312809], [92.56803894, 25.13009071], [92.5790329, 25.13200951], [92.58168793, 25.13187027], [92.59443665, 25.12829018], [92.59842682, 25.12471008], [92.60314941, 25.12499046], [92.61003113, 25.12409973], [92.62164307, 25.11770058], [92.62470245, 25.11869049], [92.62996674, 25.12503052], [92.63079834, 25.13183975], [92.6324234, 25.13755989], [92.63800812, 25.1452198], [92.6440506, 25.15117073], [92.64826965, 25.15265274], [92.65120697, 25.15240097], [92.65571594, 25.15413094], [92.65953827, 25.15912056], [92.66081238, 25.16225243], [92.66297913, 25.1729908], [92.66433716, 25.17535973], [92.66690826, 25.17706108], [92.67224121, 25.17815971], [92.6770401, 25.18218994], [92.6794281, 25.18309021], [92.68284607, 25.18204117], [92.68762207, 25.18231964], [92.69393921, 25.18135071], [92.70461273, 25.19052124], [92.71621704, 25.19415855], [92.72416687, 25.19919968], [92.7333374, 25.20322037], [92.74202728, 25.20309067], [92.74713898, 25.20776939], [92.7516861, 25.20734978], [92.75453949, 25.20537186], [92.75889587, 25.20402908], [92.76345062, 25.20384979], [92.76764679, 25.2047596], [92.77957153, 25.20310974], [92.78775024, 25.20952988], [92.79289246, 25.21235275], [92.7984314, 25.21344948], [92.80356598, 25.21723938], [92.80442047, 25.21932983], [92.80309296, 25.22150993], [92.79434967, 25.22600937], [92.78630829, 25.23140144], [92.77223969, 25.2332592], [92.77028656, 25.24020004], [92.76464844, 25.24934959], [92.77670288, 25.2605381], [92.77617645, 25.26293945], [92.76976013, 25.26893044], [92.77947235, 25.27376175], [92.78211975, 25.27592087], [92.78913879, 25.27852249], [92.79222107, 25.28518105], [92.79222107, 25.28679848], [92.78882599, 25.29154015], [92.78691101, 25.30067062], [92.78383636, 25.30800056], [92.78473663, 25.31152916], [92.78801727, 25.31760979], [92.78437042, 25.3325386], [92.78246307, 25.33428955], [92.77245331, 25.33961105], [92.76947021, 25.33950806], [92.76326752, 25.33559036], [92.76056671, 25.33527946], [92.75875854, 25.33986092], [92.75115967, 25.34847069], [92.75009918, 25.35437965], [92.74823761, 25.35811043], [92.7456665, 25.3611393], [92.74060822, 25.36372948], [92.74009705, 25.36464119], [92.74059296, 25.36678123], [92.73610687, 25.37380981], [92.73705292, 25.38125038], [92.73480988, 25.38249969], [92.72543335, 25.38043022], [92.72136688, 25.37549019], [92.7205658, 25.37490273], [92.7181015, 25.37498283], [92.716362, 25.37934113], [92.71289825, 25.38454056], [92.70973206, 25.38611984], [92.70292664, 25.38661957], [92.70037842, 25.38779068], [92.69351959, 25.39999008], [92.68817139, 25.40442085], [92.68004608, 25.40858078], [92.67376709, 25.41714096], [92.67093658, 25.41671944], [92.66703796, 25.41407967], [92.66368866, 25.40937042], [92.66010284, 25.41036034], [92.65688324, 25.41570091], [92.65365601, 25.42394066], [92.65428162, 25.43534088], [92.65054321, 25.43166924], [92.64163208, 25.41953278], [92.63961029, 25.41963005], [92.63922882, 25.4203701], [92.63791656, 25.42266083], [92.63791656, 25.42881966], [92.63265991, 25.43314171], [92.62930298, 25.43464088], [92.62851715, 25.43061066], [92.62931061, 25.42699051], [92.62864685, 25.42502975], [92.62063599, 25.42371941], [92.6178894, 25.42202187], [92.61477661, 25.41743088], [92.61183929, 25.41612053], [92.60909271, 25.41657066], [92.60700989, 25.41853905], [92.60697174, 25.42718124], [92.60775757, 25.43035126], [92.60529327, 25.4419117], [92.60555267, 25.44836044], [92.60450745, 25.4501915], [92.60114288, 25.45239067], [92.60018921, 25.45387268], [92.59976959, 25.45705032], [92.60138702, 25.46413994], [92.59815979, 25.47165108], [92.59369659, 25.47101021], [92.58544159, 25.4675808], [92.58229065, 25.47289085], [92.5714798, 25.46407127], [92.56912994, 25.46479034], [92.56741333, 25.46747017], [92.56655121, 25.47512054], [92.56783295, 25.48077011], [92.57559204, 25.49043083], [92.58104706, 25.49515915], [92.58950043, 25.49951935], [92.59358215, 25.50308037], [92.60559082, 25.50811958], [92.60959625, 25.51260948], [92.62162781, 25.51575089], [92.62760925, 25.52221107], [92.63762665, 25.52852821], [92.6446991, 25.53744125], [92.64496613, 25.54660034], [92.64987946, 25.56001091], [92.65735626, 25.5633812], [92.66065216, 25.57031822], [92.66072083, 25.58184052], [92.66047668, 25.58506012], [92.65760803, 25.58906174], [92.65345764, 25.59218025], [92.65119171, 25.59272957], [92.64833832, 25.59235001], [92.64063263, 25.58736992], [92.63414764, 25.57888031], [92.63323212, 25.57479095], [92.63056946, 25.57066917], [92.6288681, 25.56949043], [92.62610626, 25.5680294], [92.62110138, 25.56830978], [92.61248779, 25.56550026], [92.60871124, 25.56573105], [92.60349274, 25.56108284], [92.60259247, 25.55738068], [92.59346771, 25.55393028], [92.58747864, 25.55298805], [92.58141327, 25.55977249], [92.57610321, 25.55965042], [92.57250214, 25.56042099], [92.56954193, 25.56446075], [92.56468201, 25.56825829], [92.56095886, 25.57425117], [92.56092834, 25.58273125], [92.55632019, 25.59280014], [92.55724335, 25.59621048], [92.55618286, 25.6058712], [92.55861664, 25.60895157], [92.55761719, 25.61198807], [92.55323792, 25.6138401], [92.54453278, 25.61425018], [92.54043579, 25.61777115], [92.5332489, 25.61594963], [92.51727295, 25.62008286], [92.51055145, 25.61720085], [92.50170898, 25.62293053], [92.49790192, 25.62696075], [92.49326324, 25.63613129], [92.48828888, 25.64999008], [92.48134613, 25.66389275], [92.47466278, 25.67331123], [92.47154999, 25.67494965], [92.46544647, 25.68246078], [92.45987701, 25.68297005], [92.45524597, 25.6842308], [92.45128632, 25.68661118], [92.44303894, 25.68765259], [92.44001007, 25.68922043], [92.44046783, 25.68812943], [92.43434143, 25.68753052], [92.43213654, 25.69100952], [92.43334198, 25.69523048], [92.43152618, 25.70425034], [92.42722321, 25.71041107], [92.42962646, 25.71326828], [92.43644714, 25.71560097], [92.4420166, 25.72085953], [92.4331665, 25.73145294], [92.43200684, 25.7319603], [92.42134857, 25.72945023], [92.41697693, 25.72968102], [92.41277313, 25.73298073], [92.41326141, 25.73396111], [92.41246796, 25.73739052], [92.41639709, 25.7404995], [92.41073608, 25.74312973], [92.40479279, 25.74369049], [92.39476776, 25.74147987], [92.39212799, 25.74259949], [92.38696289, 25.74311066], [92.38495636, 25.74475098], [92.38353729, 25.7474308], [92.38433838, 25.75032997], [92.38694763, 25.752491], [92.38510132, 25.75356293], [92.37146759, 25.7464695], [92.36753845, 25.74238014], [92.36830902, 25.74044037], [92.36299896, 25.73651123], [92.35179901, 25.73487091], [92.34805298, 25.73193169], [92.33901215, 25.72685051], [92.33354187, 25.72523117], [92.31768036, 25.72379112], [92.3139267, 25.72468185], [92.31150055, 25.72607994], [92.30825806, 25.72615051], [92.30610657, 25.72313118], [92.29358673, 25.71730042], [92.28797913, 25.71590042], [92.28460693, 25.71586037], [92.27052307, 25.71093178], [92.260849, 25.7103405], [92.25570679, 25.7107296], [92.25357819, 25.71012115], [92.24804688, 25.71096039], [92.23684692, 25.70839119], [92.23475647, 25.70882034], [92.23384857, 25.71006966], [92.23262787, 25.71511078], [92.22899628, 25.71620941], [92.22490692, 25.71397018], [92.21063995, 25.69592094], [92.20156097, 25.68972015], [92.2000885, 25.68728828], [92.19831085, 25.68635941], [92.19692993, 25.68695068], [92.19407654, 25.68611908], [92.19198608, 25.68632126], [92.18791962, 25.68343163], [92.18477631, 25.6811409], [92.17495728, 25.67021751], [92.17095184, 25.66687965], [92.16976166, 25.66640091], [92.16445923, 25.66931915], [92.16069794, 25.67185974], [92.1605072, 25.67329025], [92.16546631, 25.67840958], [92.16435242, 25.68485069], [92.16044617, 25.69090271], [92.16145325, 25.69598007], [92.16104889, 25.69729042], [92.15757751, 25.70103836], [92.15585327, 25.70914268], [92.15106201, 25.71183014], [92.14956665, 25.71450806], [92.15101624, 25.71936989], [92.15371704, 25.72270012], [92.15629578, 25.72481155], [92.16092682, 25.72625923], [92.16423035, 25.72873116], [92.16552734, 25.73444939], [92.1648407, 25.74475098], [92.15824127, 25.75719833], [92.15738678, 25.76197052], [92.15596771, 25.76454163], [92.15410614, 25.77292061], [92.15421295, 25.77672958], [92.15518188, 25.77864265], [92.15479279, 25.77977943], [92.15099335, 25.78364944], [92.15116882, 25.78745079], [92.15368652, 25.79549026], [92.15310669, 25.81274986], [92.15573883, 25.81659126], [92.16308594, 25.82183075], [92.16326141, 25.82575035], [92.16551971, 25.83304024], [92.16934204, 25.8353405], [92.17144012, 25.83773041], [92.17524719, 25.84654236], [92.17830658, 25.84807968], [92.18096161, 25.85136032], [92.18078613, 25.86321068], [92.17910004, 25.86791039], [92.17988586, 25.8701725], [92.1810379, 25.87162018], [92.18694305, 25.87481117], [92.19496155, 25.88126945], [92.20332336, 25.89009094], [92.20641327, 25.89145279], [92.21286011, 25.8921299], [92.21560669, 25.89384079], [92.2182312, 25.90019989], [92.22384644, 25.90068817], [92.22503662, 25.90162086], [92.22547913, 25.90704918], [92.22380066, 25.91036034], [92.22260284, 25.91131973], [92.2175293, 25.90991974], [92.20752716, 25.91053009], [92.20513916, 25.90871048], [92.20059967, 25.90824127], [92.19773102, 25.91125107], [92.19700623, 25.91366005], [92.1971817, 25.91802979], [92.19203949, 25.91578293], [92.1867218, 25.91580963], [92.18364716, 25.91283035], [92.18315125, 25.91091919], [92.18089294, 25.90859032], [92.17431641, 25.90918922], [92.16369629, 25.91179085], [92.15992737, 25.91518974], [92.16017151, 25.92596054], [92.16142273, 25.93254089], [92.15751648, 25.93927956], [92.15609741, 25.94300079], [92.15631866, 25.94479942], [92.16075897, 25.95152092], [92.16532898, 25.95395088], [92.16732788, 25.95876122], [92.16555023, 25.96443939], [92.16739655, 25.96769905], [92.17311096, 25.97219849], [92.17694092, 25.97310066], [92.18097687, 25.97523117], [92.19161987, 25.98520279], [92.20089722, 25.98560905], [92.20738983, 25.98823166], [92.2091217, 25.9896698], [92.2077179, 25.99174118], [92.21100616, 25.99465942], [92.21520233, 25.99627113], [92.2191925, 26.00078011], [92.22168732, 25.99860191], [92.22141266, 26.00225067], [92.25572205, 26.02893257], [92.30158234, 26.0764904], [92.29966736, 26.07673073], [92.2973175, 26.07914925], [92.29598236, 26.07888985], [92.29392242, 26.07779121], [92.29004669, 26.0737896], [92.29014587, 26.07279968], [92.28806305, 26.06999016], [92.2807312, 26.06918907], [92.27368927, 26.06501961], [92.27372742, 26.06589127], [92.27231598, 26.0666008], [92.26864624, 26.0679493], [92.26568604, 26.06539917], [92.25145721, 26.06436157], [92.24117279, 26.06254005], [92.22834015, 26.0676403], [92.21835327, 26.07015038], [92.21611023, 26.0692997], [92.21356201, 26.06967926], [92.21201324, 26.07097054], [92.21042633, 26.07110023], [92.2088089, 26.07065964], [92.20934296, 26.06918907], [92.20826721, 26.06856918], [92.20182037, 26.07002068], [92.1893692, 26.06688118], [92.18834686, 26.06887054], [92.18460083, 26.06918907], [92.18232727, 26.07034111], [92.18044281, 26.06850052], [92.17888641, 26.06921005], [92.18094635, 26.0761795], [92.17830658, 26.07950974], [92.16909027, 26.07759094], [92.15467834, 26.06805992], [92.15052032, 26.06489944], [92.14898682, 26.06163025], [92.14621735, 26.05855942], [92.14377594, 26.05764008], [92.13816833, 26.0528183], [92.13311768, 26.04589081], [92.12702179, 26.04590034], [92.12338257, 26.04488945], [92.1162262, 26.04655266], [92.10888672, 26.04971123], [92.0933609, 26.04852104], [92.08113098, 26.04362106], [92.0788269, 26.04178047], [92.07363129, 26.04027939], [92.07045746, 26.03784943], [92.06321716, 26.03471756], [92.05285645, 26.03283119], [92.05018616, 26.033041], [92.03961182, 26.03622055], [92.03610229, 26.0394001], [92.03475189, 26.03968811], [92.02789307, 26.03989983], [92.02387238, 26.03843117], [92.02218628, 26.03926086], [92.01761627, 26.03959084], [92.00817871, 26.03944969], [92.00337982, 26.03803062], [92.0004425, 26.03918076], [91.99765015, 26.03884125], [91.99106598, 26.04103279], [91.98739624, 26.03872108], [91.98423004, 26.03054047], [91.9781723, 26.0258503], [91.95781708, 26.01889038], [91.9524231, 26.01781273], [91.94631958, 26.01449966], [91.94129181, 26.01400185], [91.93396759, 26.01466942], [91.92681122, 26.0016098], [91.92582703, 25.9997406], [91.92209625, 25.99953079], [91.91957092, 26.0001297], [91.91953278, 26.00159073], [91.91871643, 26.0072403], [91.91565704, 26.01032829], [91.91684723, 26.01375961], [91.9169693, 26.02146149], [91.91165161, 26.02383041], [91.90746307, 26.02711105], [91.90091705, 26.02626991], [91.89195251, 26.02955246], [91.88323212, 26.03000069], [91.87016296, 26.05219078], [91.86934662, 26.05685997], [91.87523651, 26.08456039], [91.87578583, 26.09773064], [91.86470032, 26.10034752], [91.85383606, 26.10478973], [91.82655334, 26.11814117], [91.81931305, 26.11874008], [91.81555939, 26.11144066], [91.81080627, 26.1051712], [91.80805969, 26.10382271], [91.80178833, 26.10494041], [91.79036713, 26.08702087], [91.78457642, 26.08658028], [91.78042603, 26.0883007], [91.77851868, 26.09124947], [91.77206421, 26.08448219], [91.75948334, 26.07129288], [91.73126221, 26.05920982], [91.73458862, 26.05664063], [91.73295593, 26.05102921], [91.72640991, 26.04691124], [91.72318268, 26.03032112], [91.72466278, 26.02725983], [91.72276306, 26.01979828], [91.72116852, 26.00184059], [91.71977997, 25.97830009], [91.72162628, 25.96507835], [91.7201767, 25.95407104], [91.71393585, 25.94722939], [91.70816803, 25.94437027], [91.70091248, 25.94189072], [91.70197296, 25.93792915], [91.69232178, 25.92910194], [91.68641663, 25.92124939], [91.6785965, 25.91732025], [91.67598724, 25.91183281], [91.66931152, 25.90538979], [91.66723633, 25.90818977], [91.66194153, 25.90987968], [91.65688324, 25.90788078], [91.65148926, 25.90766907], [91.6479187, 25.91374016], [91.63282776, 25.92576981], [91.62275696, 25.93099022], [91.61115265, 25.93992043], [91.6109314, 25.94460106], [91.62462616, 25.94597054], [91.63011932, 25.94463921], [91.63408661, 25.96050072], [91.63794708, 25.96484947], [91.63214111, 25.97079086], [91.62802124, 25.97697067], [91.62679291, 25.98238945], [91.62471771, 25.98590279], [91.62866974, 25.99513054], [91.62671661, 25.99765015], [91.63044739, 25.99982834], [91.63207245, 26.00187111], [91.63302612, 26.00490952], [91.63210297, 26.01395988], [91.63339996, 26.01785088], [91.63215637, 26.02240944], [91.62610626, 26.02396965], [91.62029266, 26.02703094], [91.61654663, 26.02472115], [91.60186768, 26.02263069], [91.59680939, 26.02079964], [91.59706116, 26.01706123], [91.58812714, 26.03014946], [91.58409882, 26.03198051], [91.57583618, 26.03310966], [91.57003021, 26.02748108], [91.56880951, 26.02174187], [91.56971741, 26.01684189], [91.56859589, 26.01194954], [91.56513214, 26.00750923], [91.56608582, 26.00375938], [91.56536865, 26.00184059], [91.55484009, 25.98661041], [91.5512619, 25.97489929], [91.54894257, 25.97509766], [91.53727722, 25.96838951], [91.53717041, 25.96210098], [91.53240967, 25.96224022], [91.52584839, 25.96132088], [91.52379608, 25.95940971], [91.51850128, 25.95815086], [91.51818848, 25.95280266], [91.51978302, 25.94089127], [91.51628876, 25.9383297], [91.50163269, 25.92076111], [91.50334167, 25.9143219], [91.50557709, 25.91308022], [91.51078033, 25.91543007], [91.51685333, 25.92002106], [91.521698, 25.92485046], [91.5358963, 25.93400192], [91.53132629, 25.92371178], [91.52478027, 25.92078972], [91.50853729, 25.90975952], [91.50115204, 25.89846992], [91.50325775, 25.89216042], [91.49861145, 25.8924675], [91.49291992, 25.89557838], [91.48853302, 25.89484978], [91.48338318, 25.89105988], [91.47867584, 25.8846817], [91.47593689, 25.87803841], [91.47476196, 25.87123108], [91.47738647, 25.86872292], [91.49369049, 25.86552811], [91.49830627, 25.86720276], [91.50778198, 25.86744118], [91.5135498, 25.8709507], [91.51725006, 25.87467194], [91.51976776, 25.87802124], [91.5222168, 25.88593292], [91.52577972, 25.89010811], [91.52973938, 25.88968086], [91.53205872, 25.88815117], [91.53262329, 25.88406944], [91.52887726, 25.88087082], [91.52540588, 25.87289047], [91.52176666, 25.87434959], [91.51911926, 25.87312126], [91.51275635, 25.86655807], [91.50788116, 25.8647995], [91.49603271, 25.86234093], [91.48303986, 25.86289978], [91.47840118, 25.85768127], [91.47496033, 25.85719109], [91.46872711, 25.85902977], [91.45495605, 25.85131264], [91.44740295, 25.84566116], [91.44439697, 25.84102058], [91.44122314, 25.84163094], [91.43084717, 25.84776115], [91.42430115, 25.85355949], [91.41889954, 25.85472107], [91.41272736, 25.85391808], [91.40509033, 25.84988022], [91.40119171, 25.85110092], [91.38851929, 25.84729958], [91.38211823, 25.84693909], [91.3768692, 25.84487915], [91.37049866, 25.84430122], [91.36370087, 25.84049034], [91.35688782, 25.84146118], [91.35330963, 25.83773994], [91.34855652, 25.8403511], [91.3443985, 25.83943939], [91.34249115, 25.83609962], [91.33642578, 25.83840942], [91.33355713, 25.83884048], [91.33217621, 25.83370018], [91.33242798, 25.83209038], [91.32498932, 25.8237896], [91.30632782, 25.79636955], [91.29689789, 25.77824974], [91.28729248, 25.76411057], [91.27958679, 25.75666237], [91.27646637, 25.75167084], [91.27562714, 25.74694061], [91.26228333, 25.74929047], [91.25537109, 25.74782944], [91.23249817, 25.7291584], [91.22387695, 25.72341919], [91.22144318, 25.72604942], [91.21586609, 25.72390938], [91.19799805, 25.73097992], [91.19198608, 25.72958183], [91.19233704, 25.73608971], [91.18871307, 25.73892975], [91.18917847, 25.7634697], [91.18569946, 25.76687813], [91.18591309, 25.76993942], [91.18118286, 25.77334976], [91.17993164, 25.7763195], [91.18396759, 25.78259087], [91.18474579, 25.79503059], [91.18724823, 25.80328941], [91.19095612, 25.81069946], [91.18815613, 25.81557083], [91.18987274, 25.8207798], [91.19431305, 25.82640076], [91.19451904, 25.83061028], [91.20262909, 25.84054184], [91.1986618, 25.84763908], [91.19812012, 25.8548317], [91.1964798, 25.8590107], [91.19303894, 25.85523033], [91.18547058, 25.84996986], [91.1817627, 25.84412193], [91.17901611, 25.84275055], [91.16819, 25.84563065], [91.16165161, 25.84931946], [91.15286255, 25.85007286], [91.14539337, 25.84733963], [91.13790894, 25.84213066], [91.13168335, 25.84194946], [91.12634277, 25.83819962], [91.12078094, 25.83134079], [91.08135223, 25.82934189], [91.06653595, 25.82575989], [91.06326294, 25.82036972], [91.059021, 25.82226944], [91.04988098, 25.82889938], [91.05722046, 25.83204269], [91.0617981, 25.83608055], [91.06751251, 25.83630943], [91.07287598, 25.83833122], [91.07299805, 25.84247971], [91.07853699, 25.85261917], [91.06590271, 25.84642029], [91.04910278, 25.84880829], [91.0419693, 25.83940125], [91.02494049, 25.82756042], [91.02081299, 25.82262039], [91.01270294, 25.8210907], [91.00611115, 25.8207798], [91.00078583, 25.82225037], [91.00158691, 25.82579994], [91.00866699, 25.83823967], [91.01274109, 25.84884071], [91.0131073, 25.85719109], [91.01512909, 25.85906029], [91.0218277, 25.86133194], [91.02651978, 25.86662102], [91.02910614, 25.87985039], [91.02922058, 25.88804817], [91.02828979, 25.88857079], [91.02568054, 25.88838005], [91.02060699, 25.88727951], [91.01373291, 25.88431931], [91.00132751, 25.88648987], [90.99688721, 25.8886795], [90.98480225, 25.88993263], [90.97538757, 25.88945007], [90.97132874, 25.88767052], [90.967453, 25.88718033], [90.96660614, 25.89100075], [90.96730804, 25.89664078], [90.96689606, 25.90533066], [90.96063995, 25.92769814], [90.95791626, 25.93394279], [90.95384979, 25.93670273], [90.9455719, 25.93912125], [90.94274902, 25.9475708], [90.93749237, 25.94476128], [90.93466187, 25.94114113], [90.93206787, 25.93967247], [90.91834259, 25.94316101], [90.9158783, 25.94316101], [90.91629791, 25.92814064], [90.91911316, 25.913311], [90.91607666, 25.91505814], [90.91252899, 25.92029953], [90.90119171, 25.92959023], [90.89537811, 25.93151093], [90.89704132, 25.93538094], [90.89646149, 25.93746948], [90.89238739, 25.93906021], [90.88835907, 25.94362068], [90.88298035, 25.9517498], [90.88143921, 25.95063972], [90.88022614, 25.94625092], [90.87523651, 25.94911957], [90.87240601, 25.94672966], [90.87288666, 25.94292259], [90.86960602, 25.94239998], [90.85679626, 25.94433022], [90.84323883, 25.94481087], [90.84104156, 25.94317055], [90.83983612, 25.93843269], [90.83676147, 25.93819046], [90.8361969, 25.9472599], [90.83226013, 25.94528008], [90.82800293, 25.94742966], [90.82388306, 25.94510078], [90.82044983, 25.94842911], [90.80989075, 25.95215988], [90.80869293, 25.94718933], [90.79709625, 25.9414711], [90.79170227, 25.93573952], [90.78167725, 25.92124939], [90.77848816, 25.91430092], [90.77806091, 25.90829086], [90.7690506, 25.90851021], [90.75772095, 25.91107178], [90.75762939, 25.91657066], [90.75894928, 25.9216404], [90.75006104, 25.91924095], [90.74543762, 25.91229057], [90.74234009, 25.91295052], [90.74053955, 25.91521072], [90.74619293, 25.92193031], [90.75263977, 25.93395996], [90.75070953, 25.93408012], [90.74746704, 25.93231964], [90.744133, 25.93279076], [90.74030304, 25.94089127], [90.74469757, 25.94650078], [90.74378967, 25.94943047], [90.74604797, 25.95264053], [90.74743652, 25.95732117], [90.74355316, 25.95667267], [90.74028778, 25.95491028], [90.73226929, 25.95256042], [90.72540283, 25.94877052], [90.72068024, 25.94917107], [90.71774292, 25.9547081], [90.71309662, 25.95218277], [90.68604279, 25.95080948], [90.67565155, 25.93647957], [90.6701889, 25.93425941], [90.6539917, 25.9296627], [90.63783264, 25.92333031], [90.62732697, 25.91699028], [90.62686157, 25.91127014], [90.62893677, 25.90654945], [90.62671661, 25.90135956], [90.62480927, 25.89889908], [90.61419678, 25.89950943], [90.61074829, 25.90744972], [90.60809326, 25.90801811], [90.60650635, 25.91228104], [90.60756683, 25.91958046], [90.62901306, 25.93742943], [90.60539246, 25.94695091], [90.60193634, 25.95178032], [90.59185028, 25.95211983], [90.58727264, 25.95391273], [90.5824585, 25.95979118], [90.57879639, 25.9580307], [90.57277679, 25.94815063], [90.57273865, 25.94400024], [90.57137299, 25.93902969], [90.56324005, 25.93556976], [90.55335999, 25.92912102], [90.54682159, 25.91987991], [90.53917694, 25.91546059], [90.53360748, 25.90880013], [90.52548218, 25.90101051], [90.518013, 25.89648056], [90.51254272, 25.89624023], [90.51110077, 25.90014076], [90.51851654, 25.90940094], [90.52616119, 25.92827988], [90.5322113, 25.93255234], [90.53378296, 25.93629265], [90.53479767, 25.94564056], [90.53446198, 25.95802116], [90.52983856, 25.96186066], [90.52406311, 25.96990013], [90.51355743, 25.98237038], [90.5057373, 25.99602127], [90.50013733, 26.00136185], [90.49793243, 26.00365067], [90.49236298, 26.00650978], [90.48958588, 26.00963974], [90.48121643, 26.01402283], [90.47728729, 26.0152607], [90.47090149, 26.01259995], [90.46530151, 26.00722122], [90.45909882, 26.00323105], [90.45791626, 26.00134087], [90.45751953, 25.99957275], [90.44711304, 25.99653053], [90.42862701, 25.98904037], [90.41742706, 25.99234009], [90.41649628, 25.99685097], [90.41394043, 26.00131989], [90.41104126, 26.00587082], [90.40756226, 26.00756073], [90.40019226, 26.00928116], [90.39729309, 26.01222992], [90.39649963, 26.01415062], [90.39395142, 26.01410103], [90.38736725, 26.01126289], [90.38080597, 26.01164818], [90.36499023, 26.01032066], [90.3466568, 26.00295258], [90.34485626, 26.00123978], [90.33931732, 25.9968605], [90.33692169, 25.99016953], [90.32994843, 25.9885006], [90.32905579, 25.98269844], [90.32434082, 25.97438049], [90.28658295, 25.96389961], [90.27781677, 25.96317291], [90.22737122, 25.95513916], [90.21276093, 25.95388985], [90.21112061, 25.95564079], [90.20844269, 25.96157265], [90.1939621, 25.95700073], [90.18945313, 25.95323944], [90.18566895, 25.94556999], [90.18251038, 25.94445038], [90.18052673, 25.9470005], [90.17611694, 25.95708275], [90.1726532, 25.95874977], [90.16848755, 25.95738029], [90.16349792, 25.95736122], [90.15838623, 25.95825958], [90.15448761, 25.9602108], [90.15339661, 25.9647007], [90.14739227, 25.96447945], [90.14002991, 25.95813942], [90.13407898, 25.95780945], [90.12844849, 25.95877075], [90.12322998, 25.95716286], [90.12000275, 25.9577198], [90.11865234, 25.96125984], [90.11377716, 25.95743942], [90.11091614, 25.9541111], [90.10788727, 25.95059013], [90.10536957, 25.94193077], [90.10051727, 25.9420681], [90.09913635, 25.93926048], [90.09612274, 25.93951988], [90.08795929, 25.93619919], [90.09192657, 25.92876053], [90.08738708, 25.92626953], [90.08072662, 25.92452812], [90.07945251, 25.9192791], [90.07797241, 25.91768074], [90.07242584, 25.91933823], [90.06761932, 25.91616058], [90.06330872, 25.91554832], [90.05892181, 25.91027069], [90.0550766, 25.90809059], [90.05219269, 25.89868927], [90.042099, 25.89075089], [90.03450775, 25.89351082], [90.02791595, 25.89431], [90.02126312, 25.89319038], [90.01525116, 25.88862038], [90.00473785, 25.87868118], [90.00977325, 25.87573051], [90.01436615, 25.87178993], [90.01872253, 25.87137032], [90.02137756, 25.86849022], [90.02191925, 25.86552811], [90.02076721, 25.86161041], [90.01152039, 25.84967041], [90.00831604, 25.84683037], [90.00026703, 25.84860039], [89.99756622, 25.84670067], [89.99743652, 25.84420967], [89.99983215, 25.84369087], [90.00160217, 25.84224129], [89.99780273, 25.83967018], [89.99471283, 25.83876038], [89.99080658, 25.83551025], [89.97589874, 25.83403969], [89.97354889, 25.82814026], [89.96795654, 25.82615089], [89.95886993, 25.8265686], [89.95056915, 25.82487106], [89.94458008, 25.82447815], [89.94581604, 25.82023048], [89.94561768, 25.81610107], [89.94935608, 25.81442261], [89.95199585, 25.81091118], [89.95081329, 25.79198074], [89.9526062, 25.78342056], [89.95501709, 25.78164101], [89.95524597, 25.77445984], [89.95239258, 25.77017021], [89.94668579, 25.76472092], [89.94351959, 25.76054192], [89.93371582, 25.75253105], [89.93464661, 25.74753952], [89.93350983, 25.7445507], [89.92794037, 25.74135017], [89.92186737, 25.73916817], [89.9161377, 25.73919106], [89.91137695, 25.74156952], [89.899086, 25.74405098], [89.89541626, 25.74411964], [89.89261627, 25.73500061], [89.89424133, 25.72723961], [89.90487671, 25.71478081], [89.9126358, 25.70706177], [89.91427612, 25.7040081], [89.91850281, 25.70268822], [89.91954803, 25.69676971], [89.92112732, 25.69442177], [89.93235016, 25.68996048], [89.93699646, 25.68663025], [89.94172668, 25.67811966], [89.94184875, 25.67365074], [89.94695282, 25.65883064], [89.98043823, 25.63756943], [89.98230743, 25.62843132], [89.98332214, 25.62671089], [89.99529266, 25.62302971], [89.99933624, 25.62185097], [90.00138092, 25.62443161], [90.00453949, 25.62382126], [90.01844025, 25.60839081], [90.01729584, 25.60219193], [90.01106262, 25.59835052], [90.00582123, 25.58836937], [90.00212097, 25.58419037], [89.99536133, 25.58634949], [89.98950195, 25.58880997], [89.97915649, 25.59073067], [89.97505188, 25.58350945], [89.97280884, 25.57460976], [89.96646118, 25.57170105], [89.95675659, 25.57046127], [89.94937897, 25.56825066], [89.94164276, 25.56762123], [89.93583679, 25.56270981], [89.92605591, 25.56352997], [89.91809845, 25.5626297], [89.90441132, 25.55949974], [89.88636017, 25.55787086], [89.87758636, 25.54893112], [89.87380219, 25.54928017], [89.87010193, 25.54422188], [89.87015533, 25.54494286], [89.86621094, 25.54284096], [89.86273193, 25.54319382], [89.86293793, 25.54328918], [89.86383057, 25.54381371], [89.86461639, 25.54472733], [89.86535645, 25.54558372], [89.86593628, 25.54628372], [89.86605835, 25.54683876], [89.8662796, 25.54780388], [89.86629486, 25.54914856], [89.86629486, 25.54926682], [89.86631775, 25.54957008], [89.86631775, 25.54965019], [89.86633301, 25.55078697], [89.86630249, 25.55105782], [89.86629486, 25.55148315], [89.86620331, 25.55278206], [89.86615753, 25.55345345], [89.86611176, 25.55414391], [89.86618805, 25.55472183], [89.86637878, 25.55628395], [89.86644745, 25.55659676], [89.86647034, 25.55677032], [89.86651611, 25.55745506], [89.8666153, 25.55815125], [89.86671448, 25.55870628], [89.86675262, 25.55900002], [89.8667984, 25.55927086], [89.86684418, 25.55977249], [89.86690521, 25.56006241], [89.86692047, 25.5602932], [89.86709595, 25.5614872], [89.86714172, 25.56184006], [89.8671875, 25.56211662], [89.86721039, 25.56229401], [89.86739349, 25.5627079], [89.86752319, 25.56298256], [89.86763, 25.56325722], [89.86795807, 25.56401825], [89.86811066, 25.56433678], [89.86833954, 25.56489754], [89.86846161, 25.56515121], [89.86875916, 25.56587219], [89.86917877, 25.56650543], [89.86932373, 25.56674385], [89.86950684, 25.56700325], [89.86972809, 25.56733322], [89.87011719, 25.56789207], [89.87018585, 25.56798935], [89.87030029, 25.56820107], [89.8706665, 25.56835556], [89.87098694, 25.56851578], [89.87163544, 25.56883621], [89.87225342, 25.56913948], [89.87274933, 25.56941032], [89.87286377, 25.56960678], [89.87299347, 25.56995964], [89.8731308, 25.5702877], [89.87313843, 25.57043457], [89.87316895, 25.57086945], [89.87321472, 25.57147026], [89.8729248, 25.57216454], [89.87276459, 25.57254601], [89.87295532, 25.57383156], [89.87306213, 25.57458878], [89.8732605, 25.57506943], [89.87350464, 25.57579803], [89.87374115, 25.57642746], [89.87428284, 25.57768822], [89.87445831, 25.57816505], [89.87472534, 25.57871437], [89.87504578, 25.57940674], [89.87511444, 25.57957268], [89.87515259, 25.57970238], [89.87520599, 25.58002853], [89.87533569, 25.58040237], [89.87554169, 25.58107185], [89.87557983, 25.58128548], [89.87558746, 25.58280373], [89.87556458, 25.5829792], [89.87551117, 25.58311653], [89.87531281, 25.58385086], [89.87517548, 25.58431816], [89.87505341, 25.58483505], [89.87497711, 25.58498764], [89.87482452, 25.58524895], [89.87329865, 25.58794785], [89.8732605, 25.5880146], [89.87349701, 25.58883095], [89.87361908, 25.58930779], [89.8740387, 25.59088707], [89.87423706, 25.59163094], [89.87452698, 25.59273529], [89.87466431, 25.59322929], [89.87477875, 25.59366798], [89.87534332, 25.59441757], [89.87631226, 25.59648514], [89.87649536, 25.59684753], [89.87662506, 25.59715271], [89.87667847, 25.59726334], [89.87676239, 25.59748459], [89.87699127, 25.59795189], [89.87753296, 25.59906769], [89.87787628, 25.59981155], [89.87826538, 25.60063934], [89.8787384, 25.60165596], [89.87909698, 25.60305786], [89.87932587, 25.60386658], [89.87950134, 25.60464096], [89.87971497, 25.60545349], [89.87978363, 25.60567284], [89.87983704, 25.60597038], [89.88013458, 25.60720444], [89.88023376, 25.60761452], [89.88028717, 25.60783386], [89.88037109, 25.60809708], [89.8804245, 25.60840797], [89.88052368, 25.60880852], [89.88054657, 25.60912704], [89.88054657, 25.60949898], [89.88053894, 25.60978317], [89.88054657, 25.61024666], [89.88058472, 25.61059761], [89.8806076, 25.61113358], [89.88059998, 25.61126137], [89.88105011, 25.61420441], [89.88111877, 25.61456299], [89.88146973, 25.61529541], [89.8820343, 25.61650658], [89.8822937, 25.61704445], [89.88241577, 25.61730766], [89.88206482, 25.61840439], [89.88191986, 25.6188488], [89.88168335, 25.61953735], [89.8817215, 25.62094307], [89.88172913, 25.62142563], [89.88171387, 25.62181473], [89.88171387, 25.62203407], [89.88172913, 25.62236023], [89.88175964, 25.62285042], [89.88174438, 25.62314034], [89.88174438, 25.62341499], [89.88181305, 25.62481499], [89.88175201, 25.62551308], [89.88172913, 25.62597466], [89.88168335, 25.62622643], [89.88156891, 25.62700272], [89.88154602, 25.62718582], [89.88152313, 25.62754822], [89.88148499, 25.62783051], [89.88140106, 25.62831306], [89.88134003, 25.62890434], [89.88119507, 25.62989235], [89.88115692, 25.63029099], [89.8811264, 25.63059998], [89.88101196, 25.6313839], [89.88096619, 25.6317997], [89.88069153, 25.63333321], [89.8805542, 25.63386536], [89.88046265, 25.63430214], [89.88037872, 25.63476944], [89.88031006, 25.63510895], [89.88027191, 25.6353054], [89.87981415, 25.63686562], [89.879776, 25.63698006], [89.87966156, 25.63726425], [89.87957764, 25.63751793], [89.87953186, 25.63768959], [89.87941742, 25.63810921], [89.87935638, 25.63822937], [89.87838745, 25.63915253], [89.87828827, 25.63924408], [89.87813568, 25.63939095], [89.87776947, 25.64039993], [89.87763977, 25.64076424], [89.87735748, 25.64173698], [89.87698364, 25.64300346], [89.87693024, 25.64322853], [89.87687683, 25.64341354], [89.87683868, 25.64353561], [89.8766098, 25.64429474], [89.87644196, 25.6447258], [89.87638092, 25.64496422], [89.87599945, 25.64613914], [89.87574768, 25.64694023], [89.87562561, 25.64733124], [89.87557983, 25.6475296], [89.87553406, 25.64764023], [89.87548065, 25.64787483], [89.87535095, 25.64844131], [89.87506866, 25.64956665], [89.87485504, 25.65038109], [89.8746109, 25.65134811], [89.87438965, 25.65215874], [89.87415314, 25.65313911], [89.87389374, 25.65407944], [89.87382507, 25.65430832], [89.87377167, 25.6545105], [89.87372589, 25.65469933], [89.87368774, 25.65495491], [89.87364197, 25.65509987], [89.87356567, 25.65531158], [89.87335968, 25.65573692], [89.87306976, 25.65643501], [89.87298584, 25.65664864], [89.87288666, 25.65686798], [89.87277985, 25.65709496], [89.87271118, 25.65723801], [89.87264252, 25.65736961], [89.87256622, 25.65749168], [89.87250519, 25.65760612], [89.87228394, 25.65813828], [89.87216949, 25.65818024], [89.86992645, 25.65900993], [89.86750793, 25.66070175], [89.86672974, 25.66275978], [89.86663818, 25.66294861], [89.86642456, 25.66304398], [89.86625671, 25.66312218], [89.86605072, 25.66322327], [89.86591339, 25.66331291], [89.86579132, 25.66340446], [89.86566162, 25.66347885], [89.8651886, 25.66381645], [89.86505127, 25.66393471], [89.86484528, 25.66412163], [89.86465454, 25.66433334], [89.86437225, 25.66462708], [89.86421967, 25.66477394], [89.8638382, 25.66521645], [89.86355591, 25.66559982], [89.86322784, 25.6660347], [89.86318207, 25.6661129], [89.86299896, 25.66635513], [89.86286163, 25.66654778], [89.86278534, 25.66669273], [89.86260223, 25.66699028], [89.86248016, 25.66718292], [89.86208344, 25.66804314], [89.86139679, 25.66958809], [89.86118317, 25.6701355], [89.86106873, 25.67033958], [89.86086273, 25.67076492], [89.86056519, 25.67149353], [89.86042786, 25.67190742], [89.86009979, 25.67333984], [89.85977936, 25.67466927], [89.85962677, 25.67538261], [89.85934448, 25.67675972], [89.85918427, 25.67755127], [89.85915375, 25.67773247], [89.85910797, 25.67789459], [89.85904694, 25.67810822], [89.85896301, 25.67838097], [89.8589325, 25.67853737], [89.85886383, 25.67871666], [89.85874939, 25.67903709], [89.85862732, 25.67935753], [89.85852814, 25.67966461], [89.85844421, 25.67985916], [89.85801697, 25.68037605], [89.85765839, 25.68065262], [89.85730743, 25.68091774], [89.85694885, 25.68120575], [89.85655975, 25.68152428], [89.85620117, 25.68184853], [89.85569763, 25.68230629], [89.85552979, 25.68243217], [89.85480499, 25.68330574], [89.852005, 25.68668175], [89.85171509, 25.68700409], [89.85149384, 25.68734741], [89.85044861, 25.68905067], [89.84960175, 25.6904335], [89.84922791, 25.69102669], [89.84897614, 25.69138718], [89.84877014, 25.69171906], [89.84868622, 25.69183922], [89.84864807, 25.69190216], [89.84841156, 25.69234276], [89.84789276, 25.69317245], [89.84775543, 25.69342232], [89.84764862, 25.69361115], [89.84750366, 25.69384956], [89.84724426, 25.69437981], [89.84708405, 25.69473839], [89.84703064, 25.69480705], [89.84693909, 25.69497108], [89.84689331, 25.69507027], [89.84682465, 25.69524956], [89.84671021, 25.69551086], [89.84661102, 25.69571114], [89.84657288, 25.69585609], [89.84705353, 25.6964817], [89.84751892, 25.69707108], [89.84781647, 25.69742966], [89.8480072, 25.69767189], [89.8480835, 25.69775963], [89.84815216, 25.69788361], [89.84829712, 25.69812965], [89.84849548, 25.6984005], [89.84860992, 25.69863129], [89.84867859, 25.69878387], [89.84890747, 25.69958687], [89.84899902, 25.69987679], [89.84909058, 25.70029831], [89.84913635, 25.70047188], [89.84915161, 25.7005806], [89.84918213, 25.70106316], [89.84919739, 25.70144081], [89.84918976, 25.70152092], [89.8491745, 25.70169449], [89.84922028, 25.70194817], [89.84936523, 25.7021122], [89.8495636, 25.70225716], [89.84997559, 25.70261955], [89.85030365, 25.70293617], [89.85044098, 25.70310402], [89.8506546, 25.70341682], [89.85076141, 25.70360374], [89.85115051, 25.70448112], [89.85123444, 25.70473099], [89.85131836, 25.70502281], [89.85136414, 25.70521927], [89.85138702, 25.70540237], [89.85142517, 25.70570564], [89.85150146, 25.70608521], [89.85152435, 25.70640755], [89.85189056, 25.7067337], [89.85194397, 25.70750427], [89.85196686, 25.70785904], [89.85195923, 25.70804024], [89.85190582, 25.70862389], [89.85185242, 25.70897293], [89.85179901, 25.70931053], [89.85174561, 25.70949745], [89.85157776, 25.71003532], [89.85151672, 25.71017838], [89.8514328, 25.71036148], [89.85131073, 25.71082115], [89.8510437, 25.71180725], [89.85090637, 25.7121582], [89.85083008, 25.71236229], [89.8506546, 25.71268463], [89.85049438, 25.71305656], [89.84985352, 25.71408844], [89.84976196, 25.71421623], [89.8495636, 25.71453857], [89.84932709, 25.71497917], [89.84928131, 25.71507072], [89.84918213, 25.71523285], [89.84824371, 25.71525002], [89.84809875, 25.71527672], [89.84781647, 25.71525955], [89.84673309, 25.71531868], [89.84663391, 25.71531677], [89.84632874, 25.7152977], [89.84581757, 25.71534157], [89.84539032, 25.7153244], [89.8444519, 25.71531487], [89.84375763, 25.71529388], [89.84316254, 25.71525192], [89.8425293, 25.71519089], [89.84129333, 25.71501732], [89.84085846, 25.71496773], [89.84029388, 25.71489525], [89.83970642, 25.71487999], [89.8392334, 25.71484375], [89.83903503, 25.71483803], [89.8388443, 25.71484375], [89.83803558, 25.71484375], [89.83776855, 25.71485329], [89.83751678, 25.71488571], [89.8373642, 25.71491241], [89.8370285, 25.71498871], [89.83674622, 25.71504784], [89.83614349, 25.71524239], [89.83583069, 25.71541786], [89.83504486, 25.71585083], [89.83492279, 25.71594429], [89.8348465, 25.71600342], [89.83442688, 25.71635437], [89.83429718, 25.71648979], [89.83404541, 25.71680832], [89.83388519, 25.71703529], [89.83371735, 25.71722412], [89.83365631, 25.71731377], [89.83335114, 25.71780396], [89.83324432, 25.71801186], [89.83308411, 25.71836662], [89.83271027, 25.71903992], [89.83242035, 25.71972275], [89.8323288, 25.71993065], [89.83216858, 25.72030067], [89.83210754, 25.72041702], [89.83207703, 25.72048378], [89.83197784, 25.72073936], [89.83181763, 25.72114372], [89.8317337, 25.72140503], [89.83169556, 25.72152901], [89.83165741, 25.72164536], [89.83161163, 25.72178268], [89.83155823, 25.72192955], [89.83151245, 25.72205162], [89.83135986, 25.72253609], [89.83135223, 25.7226429], [89.8312912, 25.72286034], [89.83127594, 25.72294235], [89.8311615, 25.72341156], [89.83104706, 25.72389984], [89.83096313, 25.7241993], [89.83083344, 25.72460365], [89.83073425, 25.72480392], [89.83069611, 25.72487831], [89.83063507, 25.72499847], [89.83047485, 25.72529602], [89.8303833, 25.7254715], [89.83022308, 25.72565842], [89.82924652, 25.72680855], [89.82859802, 25.72792816], [89.82827759, 25.72846985], [89.82733154, 25.72995186], [89.82733154, 25.7314949], [89.82733154, 25.73163605], [89.82709503, 25.73227882], [89.826828, 25.73301125], [89.82704163, 25.73475075], [89.8273468, 25.7359314], [89.82883453, 25.74179459], [89.82901764, 25.74251366], [89.83105469, 25.74452782], [89.83255005, 25.74626923], [89.83598328, 25.75056076], [89.83605957, 25.75066185], [89.8371048, 25.75200081], [89.83781433, 25.75305176], [89.83907318, 25.75495338], [89.83924866, 25.7553196], [89.84034729, 25.75767136], [89.84108734, 25.75881577], [89.84127045, 25.75909424], [89.84111786, 25.76012039], [89.84080505, 25.76223946], [89.84078217, 25.76236343], [89.84074402, 25.76263618], [89.84072876, 25.76270866], [89.84037781, 25.7651844], [89.83994293, 25.76839256], [89.83991241, 25.76848221], [89.83987427, 25.76861191], [89.83981323, 25.76871872], [89.83977509, 25.76882935], [89.83971405, 25.76900101], [89.83969879, 25.76918983], [89.83969116, 25.76929855], [89.83969116, 25.76976585], [89.83968353, 25.76984787], [89.83966064, 25.77000427], [89.83963013, 25.77015686], [89.83959198, 25.77033234], [89.83956909, 25.77044487], [89.83955383, 25.77059174], [89.83953094, 25.77075005], [89.83893585, 25.77325821], [89.83831787, 25.77573776], [89.83664703, 25.77897072], [89.8364563, 25.77934456], [89.83390808, 25.78304863], [89.8338623, 25.78528404], [89.83395386, 25.7866478], [89.83395386, 25.78694153], [89.83394623, 25.78723907], [89.8339386, 25.78736877], [89.83391571, 25.78764725], [89.83390045, 25.78796768], [89.83387756, 25.78819084], [89.83383179, 25.78853226], [89.83350372, 25.78879547], [89.83312988, 25.7890873], [89.8327713, 25.78943443], [89.83221436, 25.78991318], [89.83180237, 25.79033661], [89.83163452, 25.79052353], [89.83137512, 25.79088211], [89.83120728, 25.79118156], [89.83113098, 25.7913723], [89.83092499, 25.79228401], [89.83083344, 25.7928772], [89.83080292, 25.7931881], [89.83071899, 25.79402542], [89.83065796, 25.79425049], [89.83059692, 25.79448128], [89.830513, 25.79477692], [89.83031464, 25.79504585], [89.8299942, 25.79541397], [89.82985687, 25.79561806], [89.8296051, 25.79609299], [89.82939911, 25.79670906], [89.82936096, 25.79683304], [89.82931519, 25.79714012], [89.82922363, 25.79783249], [89.829216, 25.79808807], [89.82920837, 25.79821396], [89.82923889, 25.79845619], [89.82926941, 25.79865265], [89.82949066, 25.7994175], [89.82956696, 25.79960251], [89.82965088, 25.79980659], [89.82977295, 25.8001709], [89.82988739, 25.80049324], [89.82991028, 25.80075264], [89.8298645, 25.8008709], [89.82969666, 25.80124092], [89.82954407, 25.80162811], [89.82950592, 25.80173874], [89.82943726, 25.80192184], [89.82920837, 25.80260277], [89.8290329, 25.80327034], [89.82884979, 25.8037014], [89.82865143, 25.80421829], [89.82850647, 25.80458832], [89.8279953, 25.80596924], [89.82713318, 25.80821609], [89.82693481, 25.80899239], [89.826828, 25.80920982], [89.8267746, 25.80950546], [89.82674408, 25.80958366], [89.82661438, 25.8098793], [89.82653046, 25.8100853], [89.8264389, 25.81028748], [89.82496643, 25.81065941], [89.82327271, 25.81114006], [89.82291412, 25.81179619], [89.82229614, 25.8126545], [89.822052, 25.81300163], [89.82174683, 25.81311798], [89.82124329, 25.81334496], [89.82090759, 25.81349754], [89.82048798, 25.81363487], [89.81996918, 25.81380844], [89.8192749, 25.81406784], [89.8190918, 25.81403923], [89.81817627, 25.81389046], [89.81694031, 25.81296158], [89.81452942, 25.81698036], [89.81504059, 25.8175106], [89.81516266, 25.81746674], [89.81530762, 25.81742668], [89.81543732, 25.81738281], [89.81552124, 25.81735611], [89.8156662, 25.81729126], [89.81580353, 25.81726074], [89.81591797, 25.81721878], [89.81604767, 25.81717682], [89.81616211, 25.81716537], [89.81626129, 25.81713676], [89.81639099, 25.81711197], [89.81649017, 25.81708527], [89.81658936, 25.81705666], [89.81671906, 25.81702995], [89.81684875, 25.81697273], [89.81708527, 25.8169117], [89.8172226, 25.81688881], [89.817276, 25.81746864], [89.81730652, 25.81783295], [89.8187561, 25.81962204], [89.82202148, 25.82364655], [89.82230377, 25.82406425], [89.8224411, 25.82426834], [89.82284546, 25.8247776], [89.82318878, 25.8252449], [89.823349, 25.82550621], [89.82367706, 25.8259182], [89.82421875, 25.82668495], [89.82450867, 25.82709122], [89.82473755, 25.82740593], [89.82512665, 25.82796097], [89.82553864, 25.82861137], [89.82570648, 25.82880783], [89.82577515, 25.82893562], [89.82587433, 25.82911682], [89.82596588, 25.82938766], [89.82603455, 25.82967186], [89.82613373, 25.82993698], [89.82634735, 25.83049583], [89.82642365, 25.83075523], [89.8265686, 25.83127403], [89.82678223, 25.83213043], [89.82691956, 25.83250999], [89.82698059, 25.83266449], [89.82713318, 25.83296585], [89.82717133, 25.83304405], [89.82746124, 25.83320808], [89.82788849, 25.83350563], [89.82859039, 25.83399963], [89.8309021, 25.83761978], [89.83039856, 25.85214043], [89.830513, 25.85329056], [89.83270264, 25.85334015], [89.83411407, 25.85341644], [89.83410645, 25.85412407], [89.83407593, 25.85601807], [89.83489227, 25.85844994], [89.83501434, 25.85881042], [89.83557892, 25.86048889], [89.8343277, 25.86520767], [89.83413696, 25.86696815], [89.83317566, 25.8691864], [89.83309174, 25.86945343], [89.83301544, 25.86962318], [89.8328476, 25.86994362], [89.83269501, 25.87028313], [89.83258057, 25.8705368], [89.83250427, 25.87071228], [89.83283997, 25.87097359], [89.83442688, 25.87239456], [89.8358078, 25.87362862], [89.83657074, 25.87427139], [89.83774567, 25.87525749], [89.8391037, 25.87680435], [89.83966827, 25.87834549], [89.84054565, 25.87982559], [89.84069061, 25.88007545], [89.84115601, 25.88057709], [89.84231567, 25.88183403], [89.84342957, 25.88303947], [89.84481812, 25.88453865], [89.84597778, 25.88578796], [89.84611511, 25.88593483], [89.84638977, 25.88611984], [89.84672546, 25.88639832], [89.84764099, 25.88719559], [89.84799194, 25.88743401], [89.84848022, 25.88776588], [89.84873199, 25.88793373], [89.84854889, 25.88847351], [89.84837341, 25.88898468], [89.84833527, 25.88909149], [89.84819794, 25.88985062], [89.8480835, 25.89147568], [89.84812927, 25.89188576], [89.84819794, 25.89211082], [89.84880829, 25.89289284], [89.84924316, 25.89327621], [89.8494339, 25.89343262], [89.84973145, 25.89362335], [89.84983063, 25.89369202], [89.85068512, 25.89419365], [89.85108948, 25.89445877], [89.85114288, 25.89455223], [89.85131836, 25.89517975], [89.8514328, 25.89562607], [89.85158539, 25.89591789], [89.85271454, 25.89685822], [89.85297394, 25.89700508], [89.85334015, 25.89726067], [89.85365295, 25.89744759], [89.85394287, 25.89761734], [89.85441589, 25.89791489], [89.85475922, 25.89813614], [89.85527039, 25.89848518], [89.8555069, 25.89866257], [89.85587311, 25.8989563], [89.85620117, 25.89925194], [89.85636902, 25.8993988], [89.85678864, 25.89978218], [89.85720825, 25.90031433], [89.85741425, 25.90065575], [89.8576889, 25.90101814], [89.85785675, 25.90122032], [89.85803986, 25.90147591], [89.85819244, 25.90174294], [89.85855103, 25.90258026], [89.85865784, 25.90280533], [89.85904694, 25.90350723], [89.85919189, 25.90378571], [89.85948944, 25.90442276], [89.85999298, 25.90539551], [89.86013031, 25.90576553], [89.86035919, 25.90651131], [89.86045074, 25.90674782], [89.86049652, 25.90685272], [89.86062622, 25.90710449], [89.86074829, 25.90743065], [89.86142731, 25.90708733], [89.86172485, 25.90693474], [89.86308289, 25.90827942], [89.86352539, 25.90875816], [89.86408234, 25.90934372], [89.86469269, 25.91004181], [89.86525726, 25.91065598], [89.86562347, 25.91108704], [89.86591339, 25.9114151], [89.86688995, 25.91242027], [89.86756134, 25.91308403], [89.86820221, 25.91370773], [89.86871338, 25.91422462], [89.86924744, 25.91478348], [89.87043762, 25.91587257], [89.87107849, 25.91651344], [89.87164307, 25.91708374], [89.8724823, 25.91794968], [89.87343597, 25.9188652], [89.87425232, 25.91966438], [89.87477112, 25.92024422], [89.87548065, 25.92112923], [89.87614441, 25.92189407], [89.87685394, 25.92276382], [89.87763977, 25.92372131], [89.87845612, 25.92428589], [89.87853241, 25.92433548], [89.87848663, 25.92466354], [89.87830353, 25.92581367], [89.87802124, 25.92649078], [89.87793732, 25.92669678], [89.87844849, 25.92764473], [89.87910461, 25.92885017], [89.87980652, 25.93157578], [89.87986755, 25.93179703], [89.88025665, 25.93265724], [89.88134003, 25.93502045], [89.88174438, 25.93598938], [89.88260651, 25.93808365], [89.88365936, 25.93987274], [89.88460541, 25.94144249], [89.884758, 25.94169044], [89.88577271, 25.94330025], [89.88594055, 25.94358063], [89.87885284, 25.94319153], [89.87732697, 25.94310951], [89.87143707, 25.94144058], [89.86519623, 25.94098091], [89.86073303, 25.94059944], [89.85713959, 25.94008064], [89.85386658, 25.93979836], [89.8526001, 25.93925095], [89.84954071, 25.93719292], [89.84731293, 25.93597984], [89.84606171, 25.9359417], [89.84407043, 25.93733978], [89.84427643, 25.93898964], [89.84397125, 25.94011307], [89.84266663, 25.94011497], [89.8396759, 25.9410038], [89.8392868, 25.94111824], [89.8391037, 25.94117165], [89.83924103, 25.94135475], [89.83975983, 25.94196701], [89.83988953, 25.94211006], [89.83677673, 25.94161034], [89.83541107, 25.94140053], [89.8319397, 25.94146156], [89.82949829, 25.94218063], [89.82820129, 25.94355965], [89.82834625, 25.94534111], [89.8283844, 25.94581223], [89.82789612, 25.9458065], [89.82749939, 25.94578743], [89.82679749, 25.94570541], [89.82630157, 25.94565773], [89.8253479, 25.9455719], [89.82519531, 25.94623756], [89.82510376, 25.94687653], [89.82506561, 25.94712448], [89.82499695, 25.94850159], [89.82498932, 25.94875526], [89.82505035, 25.94904518], [89.82522583, 25.94981384], [89.82541656, 25.95067596], [89.82563019, 25.95162582], [89.82582855, 25.95181656], [89.82900238, 25.95477867], [89.82907867, 25.95485497], [89.83100128, 25.95521545], [89.83261871, 25.95487404], [89.83540344, 25.95363045], [89.83750916, 25.95269394], [89.83828735, 25.95233727], [89.83921051, 25.95192337], [89.84037018, 25.9514122], [89.84127808, 25.95118904], [89.84216309, 25.95098877], [89.84348297, 25.95071602], [89.84427643, 25.95064735], [89.84503937, 25.95058441], [89.84619141, 25.95046616], [89.84737396, 25.94996071], [89.84909058, 25.94925499], [89.84926605, 25.94921875], [89.84867096, 25.94964027], [89.84838867, 25.94984436], [89.84815979, 25.95001411], [89.84784698, 25.95033264], [89.847435, 25.95066452], [89.84725952, 25.95083046], [89.8470459, 25.95100784], [89.84675598, 25.95129395], [89.84670258, 25.95136833], [89.84562683, 25.95271301], [89.8453598, 25.95298004], [89.8453598, 25.95320702], [89.84516907, 25.95359802], [89.84503937, 25.953825], [89.84482574, 25.9541626], [89.84464264, 25.95450211], [89.84449768, 25.95475197], [89.84443665, 25.95486832], [89.8445282, 25.95493507], [89.84473419, 25.95511246], [89.84498596, 25.95531464], [89.84525299, 25.95554161], [89.84643555, 25.95649719], [89.84664917, 25.95659447], [89.84674072, 25.95663834], [89.84689331, 25.956707], [89.84713745, 25.95681763], [89.84698486, 25.95700073], [89.84683228, 25.95728302], [89.84628296, 25.9581089], [89.84607697, 25.95842361], [89.84596252, 25.95859528], [89.8458252, 25.95878792], [89.8456955, 25.95902252], [89.8455658, 25.95927429], [89.84548187, 25.95945549], [89.84532928, 25.95970917], [89.84522247, 25.95993614], [89.84494781, 25.96032143], [89.8447876, 25.96071434], [89.84456635, 25.96108246], [89.84442902, 25.96129036], [89.84303284, 25.96397209], [89.84255981, 25.96455765], [89.84234619, 25.96465683], [89.8401947, 25.96565056], [89.83882141, 25.9662838], [89.83874512, 25.96647453]], [[89.84065247, 25.94222641], [89.84042358, 25.94219589], [89.84061432, 25.94200134], [89.84065247, 25.94222641]]]}}, {\\\"id\\\": \\\"4\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.5_1\\\", \\\"HASC_1\\\": \\\"IN.BR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Bihar\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -40.7, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1134.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -2750.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1616.0, \\\"geo-id\\\": 4, \\\"hpm25_child_popweighted\\\": -455.6, \\\"hpm25_female_popweighted\\\": -523.7, \\\"hpm25_male_popweighted\\\": -377.1, \\\"location\\\": \\\"Bihar\\\", \\\"mort_apm25_6cod_mean_total\\\": 41048.0, \\\"mort_hpm25_6cod_mean_total\\\": -100623.0, \\\"mort_tpm25_6cod_mean_total\\\": -59575.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[87.26291656, 27.85071564], [87.25248718, 27.8428669], [87.25118256, 27.84306145], [87.25131989, 27.84311485], [87.26291656, 27.85071564]]], [[[87.26721191, 27.85011673], [87.26628113, 27.84945297], [87.26291656, 27.85071564], [87.26721191, 27.85011673]]], [[[88.1054306, 26.53940773], [88.10547638, 26.53903961], [88.10504913, 26.53584862], [88.10621643, 26.53601456], [88.10202026, 26.5343895], [88.1013031, 26.53530312], [88.1006546, 26.536129], [88.10301971, 26.53923607], [88.1054306, 26.53940773]]], [[[85.38336945, 24.53519058], [85.38278198, 24.53253174], [85.37026978, 24.52958107], [85.36116028, 24.52971268], [85.34581757, 24.52799988], [85.33790588, 24.52799034], [85.3315506, 24.5262413], [85.32250214, 24.52557945], [85.31855774, 24.52462959], [85.31253052, 24.52658081], [85.29734802, 24.52864075], [85.28804779, 24.52840042], [85.28251648, 24.52668953], [85.27935791, 24.51910019], [85.27980804, 24.51388168], [85.28192902, 24.509161], [85.28237152, 24.50375938], [85.28103638, 24.49975014], [85.28196716, 24.49720001], [85.26956177, 24.49837112], [85.25444031, 24.49793053], [85.24649811, 24.49529076], [85.23941803, 24.48882294], [85.23532867, 24.47985077], [85.22853851, 24.47941017], [85.22392273, 24.4711895], [85.21578217, 24.47254944], [85.20326233, 24.47294998], [85.19924927, 24.46739006], [85.19052124, 24.46858025], [85.18260193, 24.46866035], [85.17632294, 24.46797943], [85.1698761, 24.46609116], [85.16750336, 24.46735954], [85.16323853, 24.46718979], [85.15289307, 24.46414948], [85.15067291, 24.46286964], [85.14927673, 24.45928001], [85.14990997, 24.45585251], [85.15260315, 24.45375061], [85.15872955, 24.45125008], [85.16133118, 24.44329071], [85.16372681, 24.4414196], [85.1648407, 24.43580055], [85.16625977, 24.43349075], [85.1688385, 24.4317894], [85.16938019, 24.42947006], [85.16439056, 24.42769051], [85.1578598, 24.42416], [85.15529633, 24.41801071], [85.14795685, 24.4181881], [85.12693024, 24.41151047], [85.1206665, 24.40843964], [85.11898804, 24.40913963], [85.1150589, 24.40901947], [85.10932922, 24.39882088], [85.09867096, 24.3939209], [85.09594727, 24.39077187], [85.092453, 24.38152122], [85.0894165, 24.37919998], [85.08068085, 24.38075066], [85.06548309, 24.38676071], [85.07100677, 24.39969254], [85.06919861, 24.40119934], [85.07038879, 24.40517998], [85.07302094, 24.40653992], [85.07454681, 24.40846252], [85.07375336, 24.4129982], [85.07567596, 24.42175102], [85.07615662, 24.43987083], [85.06906891, 24.43565941], [85.06461334, 24.43058968], [85.06040955, 24.42460823], [85.05748749, 24.41648293], [85.05329132, 24.41513062], [85.04223633, 24.41827965], [85.03954315, 24.42412758], [85.03573608, 24.42311287], [85.03209686, 24.42535019], [85.02066803, 24.42201996], [85.01460266, 24.41912079], [85.01069641, 24.41608047], [84.99040222, 24.41222954], [84.96856689, 24.37594986], [84.94793701, 24.37177086], [84.93495178, 24.37645912], [84.92533875, 24.37804031], [84.91297913, 24.37565041], [84.90331268, 24.37231064], [84.89803314, 24.37212944], [84.89441681, 24.37504005], [84.9005127, 24.38208008], [84.8981781, 24.39381981], [84.89190674, 24.39853096], [84.88234711, 24.41710281], [84.87789917, 24.42263031], [84.88004303, 24.43204117], [84.87805176, 24.44379044], [84.88017273, 24.46280098], [84.87625122, 24.46278954], [84.87271881, 24.46582031], [84.8674469, 24.46692085], [84.8629303, 24.4576416], [84.85974884, 24.45664024], [84.85703278, 24.45758247], [84.85733795, 24.46076965], [84.84748077, 24.46593094], [84.84198761, 24.45547104], [84.83439636, 24.45252037], [84.83062744, 24.45920944], [84.83273315, 24.46116066], [84.83345795, 24.46958923], [84.82718658, 24.47011948], [84.82792664, 24.48600006], [84.83262634, 24.51148033], [84.81949615, 24.52482033], [84.80164337, 24.52111816], [84.79532623, 24.52949142], [84.78970337, 24.52154922], [84.78367615, 24.51770973], [84.7798996, 24.50485039], [84.7629776, 24.50176811], [84.74201965, 24.49645805], [84.74006653, 24.48826981], [84.72490692, 24.47294998], [84.71750641, 24.4688282], [84.71292877, 24.46863174], [84.70652771, 24.4723587], [84.69407654, 24.46179962], [84.68405914, 24.45919991], [84.67891693, 24.4563427], [84.67401123, 24.44114113], [84.66622925, 24.43119049], [84.66584778, 24.42843056], [84.66838837, 24.42629051], [84.66779327, 24.41296005], [84.66294861, 24.4106102], [84.6601181, 24.39598083], [84.65825653, 24.39374161], [84.64305115, 24.39861107], [84.62885284, 24.40017128], [84.62288666, 24.40394974], [84.61929321, 24.40205956], [84.61521149, 24.4038105], [84.61251068, 24.40121269], [84.60096741, 24.40097809], [84.59420013, 24.40401077], [84.58992004, 24.4043808], [84.58184814, 24.40146065], [84.58006287, 24.41041946], [84.57247925, 24.41234016], [84.56539154, 24.4074707], [84.56121826, 24.40184021], [84.55912018, 24.39710808], [84.56430817, 24.38989067], [84.56578064, 24.38393974], [84.5560379, 24.3797226], [84.54585266, 24.37369919], [84.54167938, 24.37671089], [84.52152252, 24.37626076], [84.52406311, 24.36876106], [84.52796173, 24.36483002], [84.52671051, 24.36102104], [84.51882172, 24.35316086], [84.51937866, 24.34584045], [84.52548981, 24.33947945], [84.51741028, 24.33366966], [84.51419067, 24.3236084], [84.51069641, 24.3171711], [84.50319672, 24.31541061], [84.50454712, 24.30590057], [84.50123596, 24.29880905], [84.50229645, 24.29454994], [84.49688721, 24.29272079], [84.4935379, 24.28704071], [84.48420715, 24.29692078], [84.48751068, 24.29883957], [84.48874664, 24.3021698], [84.48706055, 24.30483246], [84.47856903, 24.30289078], [84.47534943, 24.30256271], [84.46839905, 24.30529022], [84.46511078, 24.30838966], [84.46196747, 24.31755066], [84.45453644, 24.33864975], [84.4466629, 24.3397007], [84.44491577, 24.33418083], [84.41742706, 24.33136177], [84.41816711, 24.34235954], [84.42253876, 24.35914993], [84.39494324, 24.36779022], [84.3997879, 24.37463951], [84.39766693, 24.37741089], [84.39202881, 24.37574959], [84.3850174, 24.37934113], [84.38221741, 24.38969994], [84.37377167, 24.39099121], [84.36725616, 24.38695908], [84.36136627, 24.38663292], [84.3553009, 24.39096069], [84.34696198, 24.39207077], [84.33586121, 24.39583015], [84.33798218, 24.40129089], [84.33162689, 24.40464973], [84.3258667, 24.41093063], [84.32779694, 24.41657066], [84.32778931, 24.4221611], [84.32486725, 24.42366982], [84.3182373, 24.42021942], [84.31505585, 24.42345238], [84.31939697, 24.42925072], [84.32749176, 24.42772865], [84.33065796, 24.42843056], [84.33039856, 24.43119049], [84.31498718, 24.44750977], [84.29321289, 24.45082283], [84.29022217, 24.45808029], [84.28526306, 24.46591949], [84.29418945, 24.48076057], [84.3082428, 24.48690033], [84.32170868, 24.48975754], [84.32565308, 24.49670982], [84.32634735, 24.50271988], [84.32168579, 24.51317978], [84.31910706, 24.52231026], [84.31284332, 24.52676964], [84.3119278, 24.53375816], [84.30944824, 24.53954124], [84.30200958, 24.54725266], [84.29743195, 24.56314278], [84.29297638, 24.56599045], [84.27997589, 24.56336021], [84.26922607, 24.56425285], [84.27189636, 24.55402184], [84.28009033, 24.55191994], [84.27828217, 24.54747009], [84.26859283, 24.54685974], [84.26944733, 24.54136848], [84.26474762, 24.54057121], [84.26274109, 24.53711128], [84.25846863, 24.53769112], [84.25714111, 24.53075027], [84.24852753, 24.53158951], [84.24994659, 24.5357399], [84.24829865, 24.53876114], [84.24108887, 24.54322052], [84.23426056, 24.5435791], [84.23500824, 24.55318069], [84.22068024, 24.55033112], [84.21749115, 24.5351696], [84.20892334, 24.53716087], [84.20620728, 24.54533005], [84.20050049, 24.54944038], [84.19991302, 24.55702019], [84.18830109, 24.55532074], [84.18695831, 24.54930115], [84.18158722, 24.54706001], [84.17288208, 24.54713058], [84.17282104, 24.54198074], [84.18239594, 24.52360916], [84.18641663, 24.52249908], [84.18225861, 24.51834106], [84.18226624, 24.51563072], [84.17926025, 24.51041985], [84.17137146, 24.50979042], [84.16114044, 24.51258278], [84.15364075, 24.51764107], [84.15589142, 24.51948166], [84.15571594, 24.52433968], [84.16440582, 24.53371239], [84.16065979, 24.53824043], [84.14955902, 24.54030037], [84.14605713, 24.54030037], [84.1362915, 24.52936172], [84.1370163, 24.51818085], [84.13996124, 24.5048008], [84.13654327, 24.50254059], [84.12901306, 24.50068092], [84.12490845, 24.49831963], [84.12258148, 24.48666954], [84.10977936, 24.48139954], [84.10092163, 24.48790169], [84.0969696, 24.49572182], [84.08909607, 24.5041275], [84.086586, 24.51463127], [84.08969116, 24.53392982], [84.08870697, 24.53607941], [84.08429718, 24.5387001], [84.07833862, 24.54500961], [84.07723999, 24.5524807], [84.07367706, 24.55758095], [84.07467651, 24.56475067], [84.07247925, 24.56960106], [84.06774139, 24.57102966], [84.06526184, 24.57505989], [84.05974579, 24.57698059], [84.06265259, 24.58371925], [84.06136322, 24.58937073], [84.05808258, 24.58836174], [84.05293274, 24.5879612], [84.05142212, 24.59152031], [84.05311584, 24.59469986], [84.04785919, 24.60650826], [84.0448761, 24.6069603], [84.04673767, 24.61228943], [84.03823853, 24.61940956], [84.0332489, 24.61895943], [84.03205109, 24.62157822], [84.0289917, 24.62264061], [84.0267868, 24.62774277], [84.02416992, 24.62906075], [84.01963806, 24.62681961], [84.01566315, 24.62760162], [84.01452637, 24.63163948], [84.00196838, 24.63540077], [83.99221039, 24.63803291], [83.97924042, 24.61512947], [83.97235107, 24.59662819], [83.9648819, 24.58764076], [83.95758057, 24.57632828], [83.94818115, 24.56651115], [83.93649292, 24.55591965], [83.93300629, 24.55174255], [83.92845917, 24.54791069], [83.92407227, 24.54620934], [83.9179306, 24.54578972], [83.90274811, 24.54244041], [83.87885284, 24.53650093], [83.86804199, 24.53288078], [83.8576889, 24.53755951], [83.84807587, 24.5363102], [83.8414917, 24.53450012], [83.82740021, 24.53314972], [83.81623077, 24.53125954], [83.80895233, 24.52894974], [83.79901123, 24.52988052], [83.794487, 24.52944946], [83.78803253, 24.52717018], [83.78174591, 24.52358055], [83.74865723, 24.51053047], [83.73073578, 24.50879097], [83.71669006, 24.50494957], [83.70236969, 24.50733948], [83.69567871, 24.51061058], [83.68245697, 24.51558113], [83.67080688, 24.51477051], [83.66252899, 24.51568031], [83.64483643, 24.51618004], [83.60015869, 24.51324081], [83.59240723, 24.51489067], [83.57121277, 24.51700974], [83.54725647, 24.52403069], [83.54244232, 24.52618027], [83.53504181, 24.52557945], [83.52384186, 24.52592087], [83.50950623, 24.52754021], [83.49816895, 24.52705956], [83.49761963, 24.52897072], [83.49320221, 24.53607941], [83.49341583, 24.54207039], [83.50495911, 24.54438972], [83.5171814, 24.54916954], [83.51793671, 24.55494118], [83.52458954, 24.5673008], [83.52400208, 24.57502174], [83.52514648, 24.58019829], [83.52498627, 24.58503914], [83.52350616, 24.58782005], [83.51999664, 24.59101105], [83.51721954, 24.59873009], [83.51743317, 24.60322952], [83.52555847, 24.61368942], [83.53453064, 24.61560059], [83.53843689, 24.62162971], [83.54171753, 24.6245594], [83.54141235, 24.62618065], [83.53890991, 24.62774277], [83.52068329, 24.6300106], [83.52419281, 24.64209938], [83.52394104, 24.64435005], [83.52169037, 24.64453125], [83.51590729, 24.64282036], [83.50717163, 24.64937019], [83.50251007, 24.64871025], [83.49971771, 24.64941025], [83.49752045, 24.65166092], [83.49704742, 24.65921974], [83.4994812, 24.66847992], [83.50218201, 24.67158127], [83.51319122, 24.67892075], [83.51370239, 24.68115044], [83.51264954, 24.68341064], [83.50917053, 24.6847496], [83.49990082, 24.69453049], [83.49571228, 24.6962204], [83.49498749, 24.70268059], [83.49205017, 24.70516014], [83.48960876, 24.70585823], [83.48589325, 24.70271111], [83.48335266, 24.70295906], [83.48071289, 24.70573235], [83.47997284, 24.70993805], [83.48036957, 24.71620941], [83.48327637, 24.72277069], [83.48332214, 24.73106956], [83.48245239, 24.73493958], [83.47984314, 24.73783112], [83.47532654, 24.73801994], [83.47174835, 24.73567009], [83.46695709, 24.73452759], [83.46243286, 24.73513031], [83.45308685, 24.73332024], [83.44467163, 24.74044991], [83.44146729, 24.74403], [83.43424225, 24.75684929], [83.42542267, 24.76311111], [83.41941833, 24.76987076], [83.41129303, 24.77532005], [83.40344238, 24.77667046], [83.39409637, 24.77947044], [83.38680267, 24.78421974], [83.38633728, 24.78659058], [83.3884964, 24.79154015], [83.39254761, 24.7971096], [83.38990021, 24.80185127], [83.39006042, 24.80442047], [83.39559937, 24.81099129], [83.39566803, 24.81559944], [83.39492798, 24.8202095], [83.39131165, 24.82315826], [83.38963318, 24.82715034], [83.39038849, 24.83308029], [83.38915253, 24.83607101], [83.38527679, 24.84007072], [83.38250732, 24.84025955], [83.38076019, 24.84303093], [83.38101959, 24.84445953], [83.37864685, 24.84613991], [83.36827087, 24.86318016], [83.35575104, 24.86865044], [83.35399628, 24.87061119], [83.3572464, 24.87352753], [83.36316681, 24.87697029], [83.36424255, 24.87858009], [83.36386871, 24.88043976], [83.36180115, 24.88233948], [83.35623169, 24.88430977], [83.35489655, 24.8855381], [83.35505676, 24.88747978], [83.35617828, 24.88921928], [83.35962677, 24.89018059], [83.36001587, 24.89184952], [83.35138702, 24.90306091], [83.35121155, 24.90623283], [83.35202789, 24.90784073], [83.35598755, 24.90983963], [83.35730743, 24.91140175], [83.35803223, 24.91399002], [83.35735321, 24.91924095], [83.35852051, 24.93740082], [83.35761261, 24.94598961], [83.35790253, 24.95162964], [83.35701752, 24.95535278], [83.34938049, 24.95952988], [83.34629822, 24.96294975], [83.34393311, 24.96388054], [83.33846283, 24.96355057], [83.34052277, 24.97481918], [83.34040833, 24.97921944], [83.34593201, 24.99209023], [83.34619904, 24.99596024], [83.34487915, 25.0026207], [83.34387207, 25.01048279], [83.34208679, 25.01146126], [83.33909607, 25.01189041], [83.32765198, 25.01632118], [83.31965637, 25.01554108], [83.31817627, 25.01732063], [83.31607056, 25.02733994], [83.3164978, 25.03838158], [83.31784058, 25.04165077], [83.32345581, 25.04805183], [83.32145691, 25.05243111], [83.3219223, 25.05583], [83.32495117, 25.05597115], [83.32624054, 25.0553894], [83.32711792, 25.0533905], [83.33016968, 25.05097961], [83.33210754, 25.05050087], [83.3338089, 25.05099106], [83.33360291, 25.05803108], [83.33123779, 25.05982971], [83.32778168, 25.06100082], [83.33120728, 25.07335281], [83.33222198, 25.0824604], [83.33351135, 25.08479118], [83.33669281, 25.08634949], [83.33802795, 25.08806038], [83.34031677, 25.09864998], [83.34012604, 25.11240005], [83.34288788, 25.11248016], [83.34783936, 25.11079979], [83.35375977, 25.11037254], [83.35736084, 25.12419128], [83.35762787, 25.12792015], [83.35212708, 25.13121986], [83.35399628, 25.14017105], [83.35343933, 25.14916039], [83.3524704, 25.15182114], [83.35080719, 25.15339088], [83.34320831, 25.15867043], [83.34509277, 25.16669083], [83.34673309, 25.16959953], [83.3481369, 25.17860031], [83.34224701, 25.17885971], [83.3380127, 25.17991066], [83.33535767, 25.18139267], [83.33586121, 25.18357086], [83.34121704, 25.18555069], [83.34394836, 25.18740273], [83.34739685, 25.19304085], [83.34960938, 25.19894028], [83.35597229, 25.1986618], [83.36026001, 25.1963501], [83.36662292, 25.20033073], [83.37210083, 25.20111084], [83.3745575, 25.20251083], [83.37770844, 25.20965958], [83.37957764, 25.21175003], [83.38173676, 25.21079826], [83.38535309, 25.20602989], [83.38822174, 25.20700836], [83.38999176, 25.2116394], [83.38990021, 25.21412086], [83.39113617, 25.21558952], [83.39505005, 25.21690941], [83.39597321, 25.22252083], [83.39727783, 25.22521019], [83.40151215, 25.23003006], [83.40233612, 25.23755074], [83.40416718, 25.24241066], [83.40690613, 25.2472496], [83.40927124, 25.24928093], [83.41706848, 25.24611092], [83.41934204, 25.24636078], [83.41854858, 25.25206947], [83.41934204, 25.25332069], [83.42251587, 25.25224113], [83.4287262, 25.24448967], [83.43136597, 25.24450111], [83.43115234, 25.25008011], [83.43321991, 25.25356102], [83.43979645, 25.25920105], [83.44294739, 25.25926018], [83.45355225, 25.25127983], [83.45729065, 25.25041008], [83.46028137, 25.25197029], [83.46325684, 25.25640869], [83.4704361, 25.26267815], [83.4719162, 25.26545906], [83.470047, 25.26922989], [83.47101593, 25.27214813], [83.48026276, 25.28240967], [83.48206329, 25.28289032], [83.48619843, 25.27950287], [83.48961639, 25.28116989], [83.4912796, 25.28659058], [83.49476624, 25.28729057], [83.49572754, 25.28440285], [83.49688721, 25.28300095], [83.49820709, 25.28297043], [83.50260162, 25.28957176], [83.5080719, 25.28619957], [83.51117706, 25.28782082], [83.51795197, 25.29323959], [83.51690674, 25.29846954], [83.51693726, 25.30060959], [83.51806641, 25.3024807], [83.52002716, 25.30332184], [83.52310181, 25.30045128], [83.52561188, 25.29953957], [83.52879333, 25.30144119], [83.53118134, 25.30451012], [83.54257965, 25.30932045], [83.54531097, 25.30985069], [83.54664612, 25.31160927], [83.5443573, 25.31314278], [83.53314972, 25.31287193], [83.53465271, 25.31520081], [83.53946686, 25.31764984], [83.54747772, 25.31585121], [83.55123138, 25.31389236], [83.55430603, 25.31406975], [83.56088257, 25.31608009], [83.56426239, 25.31585121], [83.56289673, 25.30965805], [83.56417084, 25.30814934], [83.56938171, 25.31013107], [83.57224274, 25.31761932], [83.57788086, 25.31664848], [83.5788269, 25.31726837], [83.58081818, 25.32234955], [83.58389282, 25.32489014], [83.58805847, 25.32644081], [83.60320282, 25.33156967], [83.60721588, 25.33230972], [83.61065674, 25.3325901], [83.61464691, 25.33166122], [83.62005615, 25.32858086], [83.62238312, 25.32952118], [83.62477112, 25.33493805], [83.62835693, 25.33625031], [83.62898254, 25.3379097], [83.628479, 25.34113121], [83.62996674, 25.34324074], [83.63182831, 25.34205055], [83.63877106, 25.34015274], [83.64250183, 25.34111977], [83.64440155, 25.34500122], [83.64657593, 25.34720039], [83.64351654, 25.35444069], [83.64540863, 25.35764122], [83.65022278, 25.35910034], [83.65059662, 25.36157036], [83.6496582, 25.36544037], [83.65020752, 25.36795998], [83.65616608, 25.36366081], [83.65879822, 25.36302948], [83.66020203, 25.36387062], [83.65791321, 25.3692112], [83.66020966, 25.37100029], [83.66477966, 25.36689949], [83.66908264, 25.3644619], [83.67221832, 25.36458969], [83.67899323, 25.36658096], [83.68628693, 25.36944962], [83.68897247, 25.3712883], [83.68784332, 25.37414169], [83.67681885, 25.37675095], [83.67520142, 25.37839127], [83.67626953, 25.38170052], [83.68940735, 25.38585091], [83.69277954, 25.39377022], [83.69458008, 25.39609909], [83.69628143, 25.39635086], [83.69893646, 25.38819122], [83.70140839, 25.38585091], [83.70400238, 25.38614845], [83.70947266, 25.39525032], [83.7154007, 25.39923286], [83.71806335, 25.39981079], [83.72531128, 25.39767075], [83.72717285, 25.39850044], [83.72944641, 25.40621948], [83.7325058, 25.41060066], [83.7349472, 25.40933037], [83.73784637, 25.40089035], [83.74060059, 25.40020943], [83.74198151, 25.4005909], [83.74809265, 25.40434074], [83.7507019, 25.40497017], [83.75332642, 25.40416908], [83.75805664, 25.40121078], [83.75887299, 25.40051079], [83.75195313, 25.39839172], [83.74971771, 25.39677048], [83.74973297, 25.39206123], [83.76193237, 25.38791084], [83.76225281, 25.39114189], [83.76346588, 25.39861107], [83.7651825, 25.39966011], [83.77068329, 25.40019989], [83.78227234, 25.39872932], [83.79660797, 25.40827942], [83.79936981, 25.41098022], [83.80327606, 25.41810989], [83.80522156, 25.42453003], [83.80319214, 25.42692947], [83.79270172, 25.43015862], [83.7943573, 25.43161964], [83.79670715, 25.43279266], [83.80294037, 25.43285942], [83.81762695, 25.43732071], [83.82064819, 25.43761063], [83.82408142, 25.43324089], [83.8302002, 25.43358994], [83.83837128, 25.43688965], [83.83937073, 25.43877983], [83.83943939, 25.44211006], [83.83751678, 25.44622993], [83.83338165, 25.45014954], [83.83043671, 25.45108032], [83.82150269, 25.45158005], [83.81858826, 25.45294762], [83.81381989, 25.45389938], [83.8103714, 25.45425034], [83.80793762, 25.45325279], [83.80555725, 25.45370102], [83.80671692, 25.45850945], [83.81022644, 25.46591949], [83.81233978, 25.46790123], [83.81474304, 25.46832085], [83.82256317, 25.46202278], [83.82467651, 25.46124077], [83.82935333, 25.46149063], [83.83378601, 25.4629612], [83.8478775, 25.47100258], [83.85112, 25.47372055], [83.85491943, 25.48485947], [83.85977936, 25.48920059], [83.86443329, 25.49061966], [83.86672974, 25.49349976], [83.8712616, 25.5031929], [83.86820984, 25.51163292], [83.87296295, 25.52040291], [83.87692261, 25.52140808], [83.88247681, 25.52145958], [83.8881073, 25.52321053], [83.89280701, 25.5254612], [83.89626312, 25.52827263], [83.89942169, 25.53177071], [83.91356659, 25.55434036], [83.91705322, 25.55849075], [83.92098236, 25.56172943], [83.9253006, 25.56315231], [83.93966675, 25.56543159], [83.94432068, 25.56734085], [83.95587921, 25.57542992], [83.99156952, 25.60102272], [84.00004578, 25.60771942], [84.01423645, 25.61613083], [84.02822113, 25.62273979], [84.05683136, 25.63222122], [84.07650757, 25.63753128], [84.07969666, 25.65273094], [84.07402802, 25.67250061], [84.07356262, 25.68357277], [84.06964874, 25.69561005], [84.08289337, 25.71269035], [84.09439087, 25.72038078], [84.10787201, 25.72364044], [84.12309265, 25.72394943], [84.13511658, 25.73163033], [84.13669586, 25.72754097], [84.1367569, 25.72375107], [84.13150024, 25.72393036], [84.12654877, 25.71851921], [84.12930298, 25.71735954], [84.13572693, 25.71688271], [84.14453125, 25.72060966], [84.14834595, 25.72601128], [84.14524841, 25.72860909], [84.14823151, 25.73096085], [84.15550995, 25.7259407], [84.16750336, 25.72175026], [84.17398071, 25.7157402], [84.19431305, 25.70342064], [84.19719696, 25.69223022], [84.19950867, 25.67234993], [84.20291138, 25.66963959], [84.21707916, 25.66406059], [84.23322296, 25.6639595], [84.24759674, 25.66281128], [84.26843262, 25.66325951], [84.2729187, 25.66168976], [84.28557587, 25.66152954], [84.29013062, 25.66283035], [84.2928009, 25.66852951], [84.28218842, 25.67461014], [84.28357697, 25.67713928], [84.28777313, 25.67632294], [84.29212952, 25.67704964], [84.29477692, 25.6741581], [84.29876709, 25.67179108], [84.31212616, 25.67242813], [84.31339264, 25.66890907], [84.31858826, 25.67193985], [84.32071686, 25.68208122], [84.32356262, 25.70400047], [84.32318878, 25.72313118], [84.32443237, 25.73327065], [84.32562256, 25.7371006], [84.3312912, 25.74457169], [84.33748627, 25.74513054], [84.35440826, 25.74361992], [84.36617279, 25.73843956], [84.36950684, 25.7360096], [84.37168884, 25.73830032], [84.3675766, 25.74170113], [84.36953735, 25.74373055], [84.37296295, 25.74226952], [84.38001251, 25.74868965], [84.38852692, 25.74427986], [84.38448334, 25.73768044], [84.38117218, 25.73425102], [84.39364624, 25.72890282], [84.39311981, 25.72602081], [84.39546967, 25.72439957], [84.4004364, 25.71689034], [84.39710999, 25.70907021], [84.40187836, 25.69950104], [84.4108963, 25.69847107], [84.42360687, 25.6950798], [84.42417145, 25.71171951], [84.43247223, 25.71207809], [84.43855286, 25.71068001], [84.44877625, 25.71449089], [84.44901276, 25.71138], [84.45516968, 25.71031189], [84.45865631, 25.70321083], [84.45877838, 25.69843292], [84.4631958, 25.69864273], [84.46276093, 25.6958828], [84.46031952, 25.69071007], [84.46650696, 25.68551064], [84.48934174, 25.69108963], [84.48838806, 25.67785072], [84.49903107, 25.67739105], [84.50576782, 25.68226051], [84.51638031, 25.67770958], [84.52458954, 25.68435097], [84.52794647, 25.71537018], [84.5304718, 25.72462082], [84.53586578, 25.72649002], [84.53138733, 25.69283295], [84.55233002, 25.68403053], [84.55639648, 25.68857002], [84.55860901, 25.70098114], [84.55896759, 25.72165108], [84.55562592, 25.73640823], [84.59552002, 25.73911095], [84.61306, 25.73073959], [84.62419128, 25.72790909], [84.63059998, 25.72834015], [84.62989807, 25.73311043], [84.62628174, 25.74160194], [84.62232971, 25.74731827], [84.61487579, 25.75283813], [84.60318756, 25.75757027], [84.60053253, 25.76062965], [84.60289001, 25.77243996], [84.61013794, 25.77728081], [84.6146698, 25.77242279], [84.62075043, 25.77238083], [84.6190567, 25.78897095], [84.62111664, 25.79236031], [84.62021637, 25.79409027], [84.61682892, 25.79554939], [84.61089325, 25.80065918], [84.59819794, 25.80965042], [84.5871582, 25.81960106], [84.57141876, 25.82983971], [84.55654907, 25.83751106], [84.54685211, 25.84132004], [84.54425049, 25.82998085], [84.53292084, 25.83222961], [84.52697754, 25.83432961], [84.52625275, 25.85540962], [84.51999664, 25.86115074], [84.52825928, 25.86473083], [84.53990936, 25.8603611], [84.54055023, 25.86211967], [84.53164673, 25.87272072], [84.52864075, 25.87774086], [84.50652313, 25.8723793], [84.4852829, 25.8892498], [84.47867584, 25.88836098], [84.46655273, 25.88368988], [84.46105194, 25.888731], [84.45066071, 25.89022064], [84.44371796, 25.88966942], [84.43118286, 25.89266968], [84.4276886, 25.89118958], [84.42331696, 25.89242172], [84.42417145, 25.89833832], [84.42151642, 25.90220833], [84.4175415, 25.9114399], [84.4092865, 25.92438126], [84.40830231, 25.93135071], [84.3862915, 25.93818092], [84.36501312, 25.95053291], [84.35138702, 25.95934105], [84.34880066, 25.95998192], [84.34371185, 25.9587307], [84.3138504, 25.94796944], [84.30927277, 25.94688988], [84.30310822, 25.94639015], [84.29633331, 25.94698906], [84.29155731, 25.94828033], [84.28366089, 25.95560074], [84.27536774, 25.96129036], [84.2645874, 25.96726036], [84.25466919, 25.97108841], [84.24455261, 25.97681808], [84.24048615, 25.98275948], [84.23522949, 25.98600006], [84.22344208, 25.99117088], [84.21412659, 25.99620056], [84.20181274, 26.00056076], [84.19474792, 25.99130058], [84.192276, 25.98953819], [84.17640686, 25.99775124], [84.17243958, 25.99879074], [84.17024231, 25.99166107], [84.16622925, 25.99150085], [84.166008, 26.00270081], [84.16726685, 26.02547073], [84.1590271, 26.03224182], [84.13667297, 26.04701042], [84.12792206, 26.05553055], [84.11605072, 26.0748806], [84.1071701, 26.08171272], [84.09104156, 26.09654045], [84.08113861, 26.09976959], [84.06923676, 26.09912109], [84.04905701, 26.09970093], [84.04824829, 26.10383034], [84.04514313, 26.10631943], [84.04223633, 26.11162186], [84.04361725, 26.11717033], [84.04187775, 26.12050056], [84.04524231, 26.12042046], [84.04239655, 26.13154984], [84.03362274, 26.13747978], [84.0181427, 26.14512062], [84.02363586, 26.15414047], [84.02731323, 26.1530304], [84.02841187, 26.15962029], [84.02784729, 26.16296005], [84.02289581, 26.16534805], [84.01970673, 26.1640625], [84.01381683, 26.16698074], [84.00302124, 26.17823029], [84.00406647, 26.18069077], [84.00211334, 26.19013977], [84.00901031, 26.19955826], [84.01499939, 26.19742966], [84.02044678, 26.19755936], [84.02359009, 26.2009201], [84.02323914, 26.20449066], [84.01950073, 26.20601082], [84.01902008, 26.20928955], [84.02091217, 26.21422005], [84.0242691, 26.21976089], [84.02047729, 26.22364998], [84.01676941, 26.22161293], [84.00946045, 26.22392082], [84.0082016, 26.22531128], [84.00551605, 26.23406982], [84.01091003, 26.23581123], [84.01048279, 26.23879051], [84.01152039, 26.2406826], [84.01412201, 26.24058914], [84.01838684, 26.23878098], [84.02050018, 26.24163055], [84.02400208, 26.23958969], [84.03132629, 26.23907089], [84.03115845, 26.23567009], [84.03363037, 26.23208809], [84.04680634, 26.23019028], [84.04943848, 26.22557068], [84.05726624, 26.22521019], [84.05835724, 26.22674942], [84.07357788, 26.22488022], [84.07367706, 26.22103119], [84.07936859, 26.22121048], [84.08014679, 26.22442055], [84.08190155, 26.22710037], [84.07952118, 26.23184013], [84.08738708, 26.23653984], [84.09137726, 26.23402977], [84.09229279, 26.24022102], [84.10035706, 26.2392807], [84.10135651, 26.2430706], [84.11045837, 26.24183083], [84.11270142, 26.24967957], [84.1099472, 26.25309753], [84.11234283, 26.25657272], [84.11295319, 26.26192093], [84.12375641, 26.25881958], [84.12594604, 26.26144981], [84.1414032, 26.25774956], [84.14533997, 26.26165962], [84.1534729, 26.24526978], [84.15730286, 26.24413109], [84.15934753, 26.24590111], [84.15570831, 26.25254059], [84.15512848, 26.25772095], [84.15740204, 26.26091957], [84.16365051, 26.26136971], [84.1676178, 26.26402092], [84.1713562, 26.26773071], [84.17099762, 26.27050018], [84.16815948, 26.27367973], [84.16964722, 26.27723122], [84.1709671, 26.28664017], [84.16874695, 26.29286957], [84.17150879, 26.30369186], [84.17944336, 26.31178093], [84.18173981, 26.31703949], [84.17681885, 26.32249069], [84.16720581, 26.33810997], [84.16723633, 26.36022949], [84.1696167, 26.36256027], [84.1713562, 26.37397957], [84.15634155, 26.37825966], [84.15402985, 26.37615967], [84.13078308, 26.3821907], [84.12844086, 26.38421059], [84.11675262, 26.38524818], [84.11519623, 26.38756943], [84.09654236, 26.38791084], [84.09230042, 26.39043045], [84.08970642, 26.38751984], [84.087677, 26.39011955], [84.08116913, 26.38966942], [84.08055878, 26.38622093], [84.07884216, 26.38572121], [84.0772171, 26.38396263], [84.07200623, 26.38446999], [84.07061768, 26.38689041], [84.06151581, 26.39009094], [84.06181335, 26.39427948], [84.0550766, 26.40024757], [84.05497742, 26.40204811], [84.04509735, 26.40407181], [84.04498291, 26.4052906], [84.0412674, 26.40555], [84.04087067, 26.40849113], [84.03826141, 26.41040039], [84.03618622, 26.40784073], [84.03056335, 26.41300964], [84.03318024, 26.41378021], [84.02178192, 26.4250412], [84.02052307, 26.42884064], [84.0164032, 26.43192291], [84.01494598, 26.43947029], [84.01611328, 26.44197083], [84.01098633, 26.44845963], [84.0090332, 26.44498062], [84.00170135, 26.44359016], [83.99263, 26.44761086], [83.990448, 26.44762993], [83.9834671, 26.43490028], [83.98195648, 26.4346199], [83.96129608, 26.43714905], [83.94626617, 26.43810844], [83.9360733, 26.44168091], [83.91902161, 26.44552994], [83.9081192, 26.44950104], [83.90228271, 26.45025063], [83.90302277, 26.4610405], [83.90154266, 26.46730995], [83.90323639, 26.47227097], [83.90496826, 26.49434853], [83.90746307, 26.50037956], [83.90679169, 26.50675964], [83.90175629, 26.51044083], [83.90084076, 26.51371193], [83.90220642, 26.51807976], [83.91467285, 26.52024078], [83.93048859, 26.52478027], [83.93499756, 26.52444077], [83.9392395, 26.52128029], [83.94584656, 26.51842117], [83.94352722, 26.51589966], [83.94271851, 26.51347923], [83.94565582, 26.5102005], [83.95616913, 26.50819969], [83.9625473, 26.50860023], [83.96541595, 26.51173973], [83.96655273, 26.52095032], [83.96810913, 26.52584076], [83.97054291, 26.52943993], [83.97418976, 26.53194046], [83.9835968, 26.53146172], [83.99030304, 26.53014183], [83.99835205, 26.5273819], [83.9986496, 26.52503014], [84.00068665, 26.52501106], [84.01448059, 26.53202057], [84.02004242, 26.5320797], [84.03082275, 26.53555107], [84.0430069, 26.54096031], [84.04776001, 26.54348946], [84.04878235, 26.55033112], [84.04814148, 26.55751991], [84.04931641, 26.56159019], [84.05474854, 26.5676899], [84.05690765, 26.57341003], [84.06285095, 26.57969284], [84.06772614, 26.58130074], [84.0712204, 26.58448029], [84.07028961, 26.58925819], [84.07914734, 26.59435081], [84.08252716, 26.59959984], [84.08178711, 26.60311127], [84.08476257, 26.61055946], [84.08280182, 26.61505127], [84.08352661, 26.61825943], [84.07962036, 26.6237011], [84.08213806, 26.62655067], [84.08383942, 26.6314106], [84.08059692, 26.63392067], [84.08138275, 26.63677979], [84.08042145, 26.64075279], [84.08177948, 26.64286041], [84.08448792, 26.6401329], [84.09407806, 26.63832092], [84.09493256, 26.63648033], [84.09934998, 26.63557053], [84.09934998, 26.63396835], [84.10431671, 26.63266182], [84.1060791, 26.63723183], [84.1156311, 26.63743019], [84.12146759, 26.63462067], [84.12098694, 26.63755035], [84.12413025, 26.63741112], [84.12906647, 26.63850021], [84.13742065, 26.63648033], [84.13951111, 26.63903046], [84.15203094, 26.63850021], [84.15345764, 26.63367081], [84.14853668, 26.62774849], [84.16725159, 26.6241703], [84.16779327, 26.62629128], [84.17698669, 26.62454033], [84.18467712, 26.62585068], [84.20198822, 26.62434006], [84.20388031, 26.62053108], [84.20681763, 26.6209507], [84.21569824, 26.61868095], [84.22199249, 26.61568069], [84.22305298, 26.61309052], [84.22866821, 26.61321068], [84.2309494, 26.6097908], [84.24009705, 26.61004066], [84.25063324, 26.60794067], [84.25888824, 26.60732269], [84.26291656, 26.60302162], [84.2722168, 26.59936142], [84.27346802, 26.60135078], [84.27741241, 26.60073853], [84.27934265, 26.60658073], [84.28679657, 26.60392189], [84.28919983, 26.60699081], [84.2931366, 26.60551071], [84.29502106, 26.60663033], [84.29702759, 26.61569977], [84.30267334, 26.61747169], [84.30651855, 26.6170311], [84.3107605, 26.61457253], [84.32549286, 26.61532021], [84.3300705, 26.61832047], [84.35093689, 26.62042809], [84.37059021, 26.61539078], [84.37885284, 26.62183952], [84.38343811, 26.62150955], [84.39499664, 26.62573814], [84.4005661, 26.62413025], [84.41439819, 26.62717056], [84.40737152, 26.63805962], [84.40479279, 26.64275169], [84.40223694, 26.67122269], [84.36675262, 26.67881012], [84.35484314, 26.67888069], [84.35012054, 26.6814003], [84.34480286, 26.68042946], [84.33706665, 26.68144035], [84.32566071, 26.68425751], [84.32334137, 26.68847847], [84.31851196, 26.71623039], [84.3110199, 26.73360252], [84.30561829, 26.73768044], [84.30664825, 26.73957062], [84.29802704, 26.7532711], [84.28675079, 26.75144005], [84.27861023, 26.75123978], [84.27130127, 26.74454117], [84.26677704, 26.74207115], [84.25936127, 26.74081993], [84.25528717, 26.73896027], [84.25448608, 26.73426819], [84.25234222, 26.73147011], [84.24738312, 26.72929001], [84.24227905, 26.73077011], [84.2339859, 26.73953056], [84.2332077, 26.74510956], [84.22460938, 26.75710106], [84.23548889, 26.76698112], [84.24112701, 26.77543068], [84.24848938, 26.79268074], [84.2493515, 26.8022728], [84.25229645, 26.80867958], [84.24680328, 26.81454086], [84.2485199, 26.82089806], [84.242836, 26.82181931], [84.24646759, 26.8275795], [84.25102997, 26.83069992], [84.25041962, 26.83782005], [84.25211334, 26.84492111], [84.24563599, 26.85872269], [84.2410965, 26.86243057], [84.23538208, 26.86433983], [84.2286377, 26.8698101], [84.22196198, 26.87018013], [84.22109985, 26.87223816], [84.20922089, 26.87099075], [84.19655609, 26.86118126], [84.18955994, 26.85981941], [84.18531799, 26.86009026], [84.18080902, 26.85737991], [84.1764679, 26.85334015], [84.17694855, 26.84937859], [84.17533112, 26.84593964], [84.17740631, 26.8426609], [84.17471313, 26.8357811], [84.16892242, 26.83451843], [84.15727997, 26.83636093], [84.15054321, 26.83946991], [84.13165283, 26.85569], [84.13183594, 26.87055969], [84.13929749, 26.8740406], [84.13752747, 26.87630081], [84.13861847, 26.88306999], [84.14073944, 26.88391113], [84.14083862, 26.88758087], [84.13024902, 26.88527107], [84.12301636, 26.88902092], [84.12201691, 26.8926506], [84.11164093, 26.89188957], [84.10941315, 26.89443016], [84.10640717, 26.8950901], [84.10063171, 26.90084076], [84.09922028, 26.89521027], [84.10106659, 26.89383125], [84.09986877, 26.88799095], [84.09683228, 26.88633919], [84.09262085, 26.87783051], [84.09002686, 26.87715149], [84.08651733, 26.8789196], [84.08789063, 26.88235283], [84.08550262, 26.88524246], [84.0762558, 26.87878036], [84.07155609, 26.88187027], [84.06008911, 26.88646126], [84.05905151, 26.8907795], [84.05200195, 26.89170074], [84.04898071, 26.89994049], [84.05079651, 26.90164948], [84.04737854, 26.90621948], [84.04514313, 26.90474129], [84.04239655, 26.90912819], [84.04408264, 26.90979958], [84.04924011, 26.91459084], [84.04766846, 26.93182945], [84.04521942, 26.93042183], [84.03846741, 26.93087959], [84.03655243, 26.93301964], [84.03866577, 26.93828964], [84.03630829, 26.94113159], [84.02980804, 26.93956947], [84.02880859, 26.94120026], [84.02490234, 26.94272041], [84.02636719, 26.94896126], [84.0316925, 26.94933128], [84.03514862, 26.94872093], [84.03909302, 26.95430946], [84.03862, 26.95775986], [84.04086304, 26.95745277], [84.04415894, 26.96087074], [84.04666138, 26.96194077], [84.04599762, 26.96809006], [84.04125977, 26.96801186], [84.04345703, 26.98039055], [84.04250336, 26.9815712], [84.03643036, 26.98403168], [84.03901672, 26.98801994], [84.0459671, 26.98715973], [84.0495224, 26.99081039], [84.04432678, 26.99768066], [84.04516602, 26.99973106], [84.04270172, 27.00312042], [84.03993225, 27.00587273], [84.03044891, 27.01181984], [84.03572845, 27.01931953], [84.03595734, 27.02901268], [84.04030609, 27.03530121], [84.04081726, 27.04467964], [84.0356369, 27.0465107], [84.03125763, 27.04646111], [84.0242691, 27.0447197], [84.01217651, 27.05379105], [83.99489594, 27.06125069], [83.9907608, 27.06859016], [83.9910965, 27.07129288], [84.00559235, 27.07193947], [84.01194, 27.08127975], [84.01689148, 27.08376122], [84.01831818, 27.08723831], [84.01609802, 27.09176064], [84.01892853, 27.09344101], [84.02072144, 27.09548187], [84.01422119, 27.10008049], [84.0116272, 27.10488129], [84.00531769, 27.10403061], [84.00251007, 27.10028076], [83.99751282, 27.09848022], [83.99265289, 27.10014915], [83.99017334, 27.09884071], [83.98123169, 27.09382057], [83.97786713, 27.09262085], [83.97120667, 27.09194183], [83.9549408, 27.08612061], [83.94777679, 27.08620071], [83.94409943, 27.08725166], [83.94082642, 27.08962059], [83.93942261, 27.09299278], [83.94034576, 27.10230064], [83.93856812, 27.10732079], [83.93839264, 27.11102295], [83.93955994, 27.11667061], [83.94143677, 27.11983109], [83.94766235, 27.12362099], [83.95081329, 27.12634087], [83.9524765, 27.12898254], [83.95363617, 27.13194084], [83.95079803, 27.13908005], [83.95091248, 27.14088058], [83.95864868, 27.1486702], [83.96658325, 27.1608429], [83.9683075, 27.16559982], [83.97972107, 27.17340279], [83.98419952, 27.17871094], [83.98512268, 27.1817627], [83.97878265, 27.20043945], [83.97660828, 27.20342064], [83.96457672, 27.21100998], [83.96167755, 27.21376038], [83.96031189, 27.21665955], [83.96328735, 27.22108078], [83.96411896, 27.22319031], [83.96376038, 27.22526932], [83.96153259, 27.22795105], [83.95501709, 27.23106956], [83.95585632, 27.23352051], [83.95448303, 27.23504066], [83.94814301, 27.23833084], [83.92531586, 27.24253082], [83.91175842, 27.24650192], [83.90762329, 27.24802971], [83.90190125, 27.25213051], [83.89795685, 27.25942993], [83.89549255, 27.26815033], [83.89615631, 27.277071], [83.89804077, 27.27898979], [83.90406799, 27.2811718], [83.9105072, 27.28563118], [83.91883087, 27.29265976], [83.92188263, 27.29635811], [83.92565155, 27.30418968], [83.92534637, 27.30952072], [83.92359924, 27.31643105], [83.91668701, 27.32533073], [83.90804291, 27.33039093], [83.89758301, 27.33012962], [83.89356232, 27.32905006], [83.88794708, 27.32646942], [83.87240601, 27.31620979], [83.85907745, 27.3116703], [83.85463715, 27.31122971], [83.85051727, 27.31209946], [83.84797668, 27.31397057], [83.84741974, 27.3168602], [83.84523773, 27.31965256], [83.8425293, 27.32131195], [83.83625793, 27.3194809], [83.83058929, 27.32135963], [83.8289566, 27.32275963], [83.82849121, 27.32467079], [83.82833099, 27.3259182], [83.82933807, 27.32747078], [83.84934235, 27.33560944], [83.8549881, 27.34033012], [83.85624695, 27.3477211], [83.85640717, 27.34821129], [83.85850525, 27.35096169], [83.86479187, 27.34639359], [83.8735199, 27.35161591], [83.88989258, 27.35819817], [83.89352417, 27.36254501], [83.89421844, 27.36751556], [83.89945984, 27.37000465], [83.90551758, 27.37621498], [83.90840912, 27.38429642], [83.9072876, 27.38951683], [83.88827515, 27.39061928], [83.87523651, 27.39191246], [83.8768158, 27.40031624], [83.87758636, 27.40569878], [83.87350464, 27.41226387], [83.86938477, 27.4254303], [83.87024689, 27.42850685], [83.8744812, 27.43089485], [83.88282013, 27.434515], [83.89759827, 27.43761063], [83.9154892, 27.44121361], [83.93313599, 27.44937897], [83.93326569, 27.44940567], [83.94432068, 27.44755173], [83.94526672, 27.44672585], [83.94631195, 27.44581223], [83.94532013, 27.44332695], [83.94805145, 27.44096565], [83.96470642, 27.44382286], [83.96630859, 27.4450264], [83.96818542, 27.44643402], [83.97472382, 27.44186592], [83.97481537, 27.44183922], [83.97982025, 27.44221497], [83.97961426, 27.43911552], [83.98609161, 27.44368172], [83.9936676, 27.44393158], [83.9982605, 27.4459362], [83.9988327, 27.44558907], [83.99891663, 27.44561577], [83.99894714, 27.44552231], [83.99950409, 27.44519043], [83.99983978, 27.44303131], [84.00024414, 27.44046783], [84.00063324, 27.44139671], [84.00086975, 27.44195938], [84.00191498, 27.44127655], [84.00411224, 27.44107056], [84.00447083, 27.44195938], [84.00583649, 27.44108963], [84.00757599, 27.44195938], [84.00745392, 27.44072151], [84.00874329, 27.44049263], [84.00968933, 27.44034386], [84.00978088, 27.44015503], [84.01103973, 27.4375248], [84.0140152, 27.4386158], [84.01791382, 27.43461609], [84.02101898, 27.43591499], [84.02348328, 27.43399048], [84.02510834, 27.43274689], [84.02941895, 27.43362999], [84.02940369, 27.43377304], [84.02796173, 27.43823051], [84.02897644, 27.43893242], [84.02994537, 27.43959808], [84.03077698, 27.43940735], [84.03318024, 27.43885231], [84.03347778, 27.4401226], [84.03379822, 27.44146156], [84.03778076, 27.4407177], [84.041008, 27.4424572], [84.04129028, 27.4424324], [84.04535675, 27.44208336], [84.04557037, 27.44271469], [84.04573059, 27.44320297], [84.05354309, 27.44262886], [84.05419922, 27.44262123], [84.05683136, 27.44920158], [84.0589447, 27.45116234], [84.06390381, 27.45576286], [84.06064606, 27.46097374], [84.06182098, 27.4614296], [84.06288147, 27.46184349], [84.06412506, 27.46669006], [84.06871796, 27.46941566], [84.07059479, 27.4733181], [84.07111359, 27.47911453], [84.0723114, 27.48090363], [84.07269287, 27.48148155], [84.0760498, 27.48060799], [84.07804108, 27.48212814], [84.08031464, 27.48383331], [84.08612061, 27.48309326], [84.08856964, 27.48412514], [84.09292603, 27.48596001], [84.0931778, 27.48694038], [84.09362793, 27.48869514], [84.09754944, 27.48943138], [84.10079956, 27.5023613], [84.09928894, 27.50484276], [84.10012054, 27.50511932], [84.10191345, 27.51021576], [84.09983063, 27.51678848], [84.10961151, 27.52103615], [84.11071777, 27.52151489], [84.11100006, 27.52121735], [84.11296082, 27.5192585], [84.11880493, 27.51913261], [84.11958313, 27.51412964], [84.11967468, 27.51354027], [84.12588501, 27.51080704], [84.13201904, 27.51170921], [84.14092255, 27.51764297], [84.14589691, 27.5168972], [84.14801025, 27.5186367], [84.14871979, 27.51781464], [84.15285492, 27.51666069], [84.15296936, 27.51662827], [84.15198517, 27.51229858], [84.15335083, 27.51006126], [84.15231323, 27.50960922], [84.15145111, 27.50556183], [84.15148926, 27.50409698], [84.15101624, 27.50351334], [84.15201569, 27.50061607], [84.14751434, 27.49601555], [84.14838409, 27.49527359], [84.14753723, 27.49263573], [84.15099335, 27.48881149], [84.15099335, 27.48618126], [84.15099335, 27.48570442], [84.15397644, 27.4858284], [84.15492249, 27.48481941], [84.15583801, 27.48383904], [84.16581726, 27.48361588], [84.16925812, 27.48160362], [84.16943359, 27.48061752], [84.16963196, 27.47949028], [84.1732254, 27.47887039], [84.17372131, 27.47556114], [84.17460632, 27.47514725], [84.17767334, 27.47387123], [84.1782074, 27.47364998], [84.17828369, 27.47366714], [84.18206024, 27.47451973], [84.18456268, 27.47315216], [84.18611145, 27.4723053], [84.19089508, 27.47189903], [84.19325256, 27.46904564], [84.19660187, 27.47302818], [84.19731903, 27.47241592], [84.20171356, 27.4719162], [84.20791626, 27.46941566], [84.21101379, 27.46519852], [84.20604706, 27.45935631], [84.20950317, 27.45645523], [84.20989227, 27.45612717], [84.21038818, 27.45281219], [84.20881653, 27.44641495], [84.21057892, 27.44246101], [84.21063995, 27.44233322], [84.22170258, 27.44021988], [84.22242737, 27.4414711], [84.22306824, 27.44701958], [84.22306824, 27.44742775], [84.22605896, 27.45013237], [84.2275238, 27.45045662], [84.22911835, 27.4508152], [84.23254395, 27.45471764], [84.23375702, 27.45612717], [84.23728943, 27.45433235], [84.24133301, 27.45229912], [84.24146271, 27.45232964], [84.2461853, 27.45451164], [84.24724579, 27.45370102], [84.24829865, 27.45289612], [84.25276947, 27.45326805], [84.25624847, 27.45190048], [84.25691986, 27.44921494], [84.26030731, 27.44655037], [84.26158142, 27.4455452], [84.26087952, 27.43984032], [84.26072693, 27.43860435], [84.26407623, 27.43525124], [84.26830292, 27.43412971], [84.27020264, 27.43153954], [84.27476501, 27.42866135], [84.27574158, 27.42111969], [84.28031921, 27.41521454], [84.27973938, 27.40952492], [84.28122711, 27.40641785], [84.27762604, 27.4008255], [84.27873993, 27.39523315], [84.28458405, 27.39635086], [84.28562164, 27.39531898], [84.28657532, 27.3943634], [84.2875061, 27.39145851], [84.28759766, 27.39126968], [84.28794098, 27.39089966], [84.29341125, 27.38504219], [84.29589081, 27.38417244], [84.29750824, 27.38454437], [84.29974365, 27.38864708], [84.30272675, 27.3902626], [84.30683136, 27.38765144], [84.30789948, 27.38743401], [84.31291962, 27.38640976], [84.31835938, 27.38278198], [84.31963348, 27.38193512], [84.32116699, 27.38167953], [84.33081818, 27.38011551], [84.33320618, 27.37818909], [84.33429718, 27.3773365], [84.33921814, 27.37757874], [84.33992004, 27.37761497], [84.34121704, 27.37723351], [84.34867859, 27.37504387], [84.34911346, 27.37491608], [84.35907745, 27.37352943], [84.36064148, 27.37335968], [84.36145782, 27.37346649], [84.37442017, 27.37581444], [84.37493134, 27.37646675], [84.3897171, 27.372118], [84.39001465, 27.37182617], [84.39394379, 27.3680172], [84.39916229, 27.37012863], [84.40000916, 27.36970329], [84.40823364, 27.37012863], [84.41246796, 27.36824989], [84.41621399, 27.37051582], [84.42253113, 27.36963272], [84.42638397, 27.37174416], [84.43434906, 27.3700428], [84.43740845, 27.36938858], [84.4433136, 27.3700161], [84.4460144, 27.36841583], [84.44676208, 27.36491013], [84.44771576, 27.36421204], [84.45433044, 27.36296844], [84.45959473, 27.36197662], [84.45993805, 27.36192703], [84.4640274, 27.35909653], [84.46689606, 27.35956573], [84.46725464, 27.35878181], [84.46823883, 27.35662651], [84.47172546, 27.35499573], [84.47492218, 27.35702705], [84.47509766, 27.35819817], [84.47810364, 27.36228752], [84.48802185, 27.35832405], [84.50454712, 27.35558891], [84.50509644, 27.35513878], [84.50521851, 27.35511589], [84.51216888, 27.35435295], [84.51251984, 27.3543148], [84.51673126, 27.35260773], [84.5229187, 27.35351563], [84.53570557, 27.34988403], [84.56718445, 27.34726334], [84.58867645, 27.34102631], [84.60372162, 27.33843994], [84.61091614, 27.33581543], [84.61192322, 27.33645058], [84.61660767, 27.33704567], [84.61776733, 27.33729553], [84.62201691, 27.33820724], [84.6207428, 27.33757019], [84.62447357, 27.33607864], [84.6452179, 27.30601501], [84.68412018, 27.23641586], [84.68785095, 27.22883034], [84.68760681, 27.22753906], [84.69168091, 27.22226524], [84.69161987, 27.21801567], [84.69306183, 27.21480179], [84.68941498, 27.21391487], [84.68933105, 27.21387863], [84.68897247, 27.21304703], [84.68704987, 27.21292686], [84.68946838, 27.20882225], [84.68275452, 27.20036888], [84.68571472, 27.19641495], [84.68401337, 27.18821526], [84.68251801, 27.18591499], [84.6825943, 27.18559265], [84.68362427, 27.18570709], [84.68301392, 27.18373299], [84.68473816, 27.18404579], [84.68511963, 27.18411446], [84.6852951, 27.18370628], [84.68611145, 27.18384361], [84.68585968, 27.18241882], [84.68648529, 27.18098259], [84.68735504, 27.18011475], [84.68364716, 27.17988586], [84.68586731, 27.17762947], [84.67791748, 27.17011452], [84.68183136, 27.17001915], [84.68201447, 27.17004967], [84.68312836, 27.16855812], [84.68278503, 27.1679306], [84.68238831, 27.16719055], [84.67951965, 27.1662159], [84.67919922, 27.16278839], [84.67912292, 27.1623497], [84.679245, 27.16225624], [84.68362427, 27.15898895], [84.68648529, 27.16060448], [84.68868256, 27.15864182], [84.68881989, 27.15851784], [84.68857574, 27.15820503], [84.68449402, 27.1540184], [84.68456268, 27.15317917], [84.68462372, 27.15240097], [84.68251801, 27.15181541], [84.6853714, 27.14980507], [84.6856308, 27.14512825], [84.68571472, 27.14321518], [84.68225861, 27.13574982], [84.68169403, 27.13544655], [84.68064117, 27.13488007], [84.67952728, 27.1328907], [84.68051147, 27.13269424], [84.68138885, 27.13251877], [84.6805191, 27.13029289], [84.68002319, 27.12903786], [84.6805191, 27.12811279], [84.68101501, 27.12717438], [84.67870331, 27.12412071], [84.67753601, 27.12257576], [84.67741394, 27.12046432], [84.67902374, 27.11896896], [84.67915344, 27.1188488], [84.6791153, 27.11501503], [84.67482758, 27.11388206], [84.67210388, 27.10991096], [84.67320251, 27.10704994], [84.67691803, 27.10865784], [84.67688751, 27.1085434], [84.67801666, 27.10901451], [84.67591858, 27.10517883], [84.67778778, 27.10292435], [84.67693329, 27.09995461], [84.67642212, 27.09548378], [84.6723175, 27.09801483], [84.66970825, 27.09337234], [84.66846466, 27.09380531], [84.66684723, 27.09436607], [84.66660309, 27.09225273], [84.6685791, 27.09286118], [84.67256927, 27.09088707], [84.67173004, 27.09029007], [84.67082977, 27.08964348], [84.66886902, 27.09022141], [84.6687088, 27.09021759], [84.66822052, 27.08740616], [84.66696167, 27.08806229], [84.6653595, 27.08889771], [84.66629791, 27.08731461], [84.66697693, 27.08616447], [84.66546631, 27.08656693], [84.66362, 27.08491516], [84.66041565, 27.0833168], [84.66001892, 27.08231163], [84.65727997, 27.08405113], [84.65702057, 27.08344269], [84.65628815, 27.08168983], [84.66088867, 27.08032227], [84.65865326, 27.07893944], [84.65846252, 27.07903481], [84.65556335, 27.0802784], [84.65522003, 27.07915878], [84.65529633, 27.07746506], [84.65481567, 27.07782173], [84.65429688, 27.07821083], [84.65200806, 27.07706642], [84.65183258, 27.07698441], [84.65081787, 27.07451439], [84.64970398, 27.07634735], [84.64846039, 27.07535172], [84.64958954, 27.07090759], [84.64651489, 27.06481552], [84.64746094, 27.06367111], [84.64514923, 27.05952072], [84.64511871, 27.05941582], [84.64796448, 27.05832672], [84.64733124, 27.05712509], [84.64836884, 27.05137825], [84.64846039, 27.05111885], [84.6453476, 27.05071831], [84.64659119, 27.04875565], [84.64485168, 27.04724693], [84.65419006, 27.04311752], [84.66123199, 27.04003906], [84.66150665, 27.03993416], [84.66590118, 27.03821564], [84.67518616, 27.03460693], [84.67539978, 27.03452873], [84.68412781, 27.03135872], [84.70363617, 27.02676201], [84.70800781, 27.02373505], [84.70809937, 27.0236721], [84.7117157, 27.02121544], [84.71195221, 27.02117538], [84.71618652, 27.02129364], [84.71649933, 27.02042007], [84.71871948, 27.01955414], [84.71878815, 27.01952934], [84.72052765, 27.01799202], [84.7206192, 27.01791573], [84.7208252, 27.01730156], [84.72103119, 27.01731682], [84.7215271, 27.01520348], [84.7251358, 27.01346397], [84.72543335, 27.01344681], [84.72973633, 27.01321602], [84.7308197, 27.0140152], [84.73184204, 27.01470757], [84.74017334, 27.01122665], [84.7544632, 27.0046978], [84.75893402, 27.00265121], [84.76277924, 27.00490761], [84.7628479, 27.00503922], [84.7644043, 27.00874138], [84.76408386, 27.0097065], [84.76622009, 27.01311493], [84.77309418, 27.01663589], [84.77482605, 27.01753235], [84.78466034, 27.01396179], [84.784729, 27.01370239], [84.78759003, 27.00832558], [84.78839111, 27.01073074], [84.78900909, 27.0086174], [84.79100037, 27.0086174], [84.7906723, 27.00785255], [84.79091644, 27.00781441], [84.79077911, 27.00742149], [84.78961945, 27.00401497], [84.78960419, 27.00393867], [84.79000854, 27.00290108], [84.78851318, 26.99830246], [84.79062653, 26.99855042], [84.79062653, 26.99761009], [84.79091644, 26.99751472], [84.79311371, 26.99942017], [84.79410553, 26.99780464], [84.793396, 26.9974823], [84.79273987, 26.99718475], [84.79572296, 26.99556923], [84.79582977, 26.99580765], [84.79932404, 27.00389481], [84.80029297, 27.00357437], [84.80036163, 27.00355148], [84.80119324, 27.00327301], [84.8024292, 27.0004158], [84.8028183, 27.00117302], [84.80467224, 27.00476456], [84.80549622, 27.00514984], [84.80971527, 27.00751495], [84.80969238, 27.00779724], [84.80914307, 27.00799561], [84.8088913, 27.01023293], [84.80941772, 27.01101685], [84.80989075, 27.01172447], [84.81095886, 27.01112175], [84.8122406, 27.01120949], [84.8123703, 27.01142502], [84.81265259, 27.01260567], [84.81274414, 27.01458168], [84.80912018, 27.01371574], [84.81091309, 27.01779938], [84.81274414, 27.01806259], [84.81341553, 27.018116], [84.81394196, 27.01927567], [84.81386566, 27.02029991], [84.81445313, 27.02023315], [84.81498718, 27.02017403], [84.81562042, 27.01791573], [84.81578064, 27.01804161], [84.81983185, 27.02042389], [84.82218933, 27.0204258], [84.82479858, 27.02104378], [84.83188629, 27.01930428], [84.83934021, 27.0144577], [84.84434509, 27.012537], [84.84841919, 27.01101685], [84.84973145, 27.01051331], [84.85686493, 27.00799561], [84.85703278, 27.00772476], [84.85748291, 27.00700188], [84.85546875, 27.00617218], [84.85540009, 27.00614357], [84.85421753, 27.00221443], [84.85419464, 27.0021019], [84.85487366, 27.00153351], [84.85400391, 26.99917221], [84.85348511, 26.99884033], [84.85341644, 26.99851608], [84.85620117, 26.99851608], [84.85649109, 26.99851608], [84.85997009, 26.99743271], [84.85926056, 26.99654198], [84.85897827, 26.99618912], [84.85971832, 26.99545097], [84.86022186, 26.99494743], [84.85984802, 26.99233818], [84.85971832, 26.99233246], [84.85971832, 26.99180222], [84.85971832, 26.99131584], [84.85934448, 26.99053574], [84.85959625, 26.99034882], [84.85887146, 26.9895401], [84.85748291, 26.98798752], [84.85798645, 26.98649597], [84.85997772, 26.98795128], [84.86121368, 26.98885727], [84.86115265, 26.98829842], [84.86109161, 26.98773956], [84.86842346, 26.98351479], [84.86865997, 26.98398781], [84.86933136, 26.9835968], [84.87115479, 26.98376274], [84.87115479, 26.98271751], [84.87115479, 26.98251915], [84.8731842, 26.98180962], [84.87364197, 26.9816494], [84.89079285, 26.97717667], [84.89091492, 26.97631454], [84.89103699, 26.97543716], [84.89278412, 26.97441864], [84.89241028, 26.9710865], [84.89364624, 26.96959496], [84.89501953, 26.969347], [84.8946228, 26.97080994], [84.89427185, 26.97208023], [84.89691925, 26.9726162], [84.89866638, 26.9716301], [84.90085602, 26.97046471], [84.91038513, 26.96818352], [84.91278839, 26.9676075], [84.91937256, 26.9687252], [84.9262085, 26.96735764], [84.93156433, 26.96850014], [84.94571686, 26.96361542], [84.95553589, 26.95940399], [84.95851898, 26.96064949], [84.95887756, 26.96080017], [84.96448517, 26.96027565], [84.96498108, 26.95944595], [84.96511841, 26.95941544], [84.96665192, 26.95825386], [84.96808624, 26.95803833], [84.96802521, 26.95721626], [84.97177887, 26.95186615], [84.98051453, 26.9400177], [84.97705841, 26.93927765], [84.97977448, 26.93678665], [84.97990417, 26.93652534], [84.98001862, 26.93641472], [84.98039246, 26.93554497], [84.97877502, 26.9318161], [84.97731018, 26.93174934], [84.9760437, 26.93169212], [84.97232056, 26.92871475], [84.97405243, 26.92585182], [84.9728241, 26.92529678], [84.97157288, 26.92473221], [84.97303009, 26.92297935], [84.97405243, 26.92174911], [84.97320557, 26.92096519], [84.97288513, 26.91705322], [84.97293854, 26.91677856], [84.97286224, 26.91675949], [84.96982574, 26.91603279], [84.98061371, 26.9148159], [84.99129486, 26.9133606], [84.9967804, 26.91261292], [85.00179291, 26.91189384], [85.00388336, 26.90957069], [85.00334167, 26.90909004], [85.00276184, 26.90857697], [85.00291443, 26.90621567], [85.0043869, 26.90312958], [84.99803925, 26.90633965], [84.99530792, 26.90534592], [84.99518585, 26.90391922], [84.99505615, 26.9024868], [85.00611877, 26.89478302], [85.02191925, 26.89281464], [85.02513123, 26.89142799], [85.03196716, 26.89154816], [85.04411316, 26.89116478], [85.04581451, 26.89111519], [85.05429077, 26.88899612], [85.05462646, 26.88894463], [85.05545044, 26.88881683], [85.05473328, 26.88833618], [85.05358887, 26.88757515], [85.05358887, 26.8860836], [85.05506134, 26.88640404], [85.05644989, 26.8867054], [85.05895996, 26.88579941], [85.06125641, 26.88597298], [85.0616684, 26.88707733], [85.06241608, 26.8867054], [85.06204224, 26.88508987], [85.05741882, 26.88111496], [85.05607605, 26.88446808], [85.0557251, 26.88449287], [85.05469513, 26.88456726], [85.05433655, 26.88459206], [85.05284119, 26.88297653], [85.05060577, 26.8849659], [85.05197144, 26.88210678], [85.05343628, 26.88226128], [85.05433655, 26.88235474], [85.05445862, 26.88098907], [85.04823303, 26.87830544], [85.04813385, 26.87823105], [85.04538727, 26.87937546], [85.04351807, 26.87711525], [85.04426575, 26.87490845], [85.04211426, 26.87461472], [85.04005432, 26.87728119], [85.03967285, 26.87775803], [85.03966522, 26.87755585], [85.03955078, 26.87552071], [85.03830719, 26.87477493], [85.03160858, 26.87501717], [85.03151703, 26.87502098], [85.03010559, 26.87030029], [85.03231049, 26.8674221], [85.02885437, 26.8662281], [85.02889252, 26.86602592], [85.02960205, 26.86259651], [85.03043365, 26.86231995], [85.03109741, 26.86209869], [85.03098297, 26.85918808], [85.03101349, 26.85901451], [85.02463531, 26.85625839], [85.02444458, 26.85543251], [85.02586365, 26.85510063], [85.0461731, 26.85071182], [85.05967712, 26.84892654], [85.06022644, 26.84940529], [85.0589447, 26.85230827], [85.05896759, 26.8523922], [85.05980682, 26.8556366], [85.06056976, 26.85474586], [85.06061554, 26.85481453], [85.06342316, 26.85378647], [85.06465149, 26.85526276], [85.06315613, 26.85613441], [85.06365967, 26.85687828], [85.06526947, 26.85799789], [85.06465149, 26.85613441], [85.06713867, 26.85625839], [85.06378174, 26.85352325], [85.06562042, 26.84931564], [85.06813812, 26.85071182], [85.06861877, 26.85361481], [85.06887817, 26.85369301], [85.0776062, 26.8563118], [85.07853699, 26.85659218], [85.0785675, 26.8567543], [85.07866669, 26.85668755], [85.07914734, 26.85733604], [85.07894135, 26.85762405], [85.07991791, 26.85838318], [85.08001709, 26.85851479], [85.08096313, 26.85782814], [85.08279419, 26.85649681], [85.08378601, 26.85687828], [85.08353424, 26.85606575], [85.0845108, 26.85584068], [85.08565521, 26.85638237], [85.08572388, 26.8555584], [85.08589935, 26.85352325], [85.08968353, 26.85333252], [85.08654785, 26.85514832], [85.08963013, 26.85650635], [85.08926392, 26.85748291], [85.08888245, 26.8584938], [85.09161377, 26.85971451], [85.09155273, 26.85983086], [85.08776855, 26.86508179], [85.08836365, 26.86614037], [85.08888245, 26.86706924], [85.08997345, 26.86706924], [85.09095764, 26.86763763], [85.09074402, 26.86806297], [85.09136963, 26.86787605], [85.09161377, 26.86801529], [85.09198761, 26.86794853], [85.09198761, 26.86856079], [85.09832001, 26.86681557], [85.10168457, 26.87079811], [85.11251831, 26.87141609], [85.11336517, 26.87216568], [85.12291718, 26.87131691], [85.1231842, 26.871315], [85.12685394, 26.87026978], [85.13633728, 26.86759567], [85.14331818, 26.87079811], [85.15601349, 26.87031555], [85.1676712, 26.86832237], [85.17861176, 26.86893463], [85.18689728, 26.86950874], [85.1913147, 26.86981583], [85.19770813, 26.86659431], [85.19509125, 26.86330605], [85.19501495, 26.86321449], [85.19313049, 26.84971428], [85.19361877, 26.84381485], [85.19600677, 26.84171867], [85.19262695, 26.82954407], [85.18854523, 26.82445145], [85.18842316, 26.82121277], [85.17922974, 26.814888], [85.1791153, 26.81191444], [85.17985535, 26.80803871], [85.18430328, 26.79945183], [85.18171692, 26.79809761], [85.18258667, 26.79548836], [85.19117737, 26.79379272], [85.19141388, 26.79371452], [85.19509888, 26.79079628], [85.19701385, 26.78491592], [85.19501495, 26.77933311], [85.19971466, 26.76931572], [85.20154572, 26.76888847], [85.20272064, 26.76861572], [85.20829773, 26.76105118], [85.21253967, 26.76168633], [85.2124939, 26.7611084], [85.2122879, 26.75870323], [85.21614838, 26.75792313], [85.23041534, 26.76131439], [85.2341156, 26.76321602], [85.24198151, 26.76159286], [85.2505188, 26.75983047], [85.2551651, 26.76094055], [85.25911713, 26.75891495], [85.2596283, 26.75603104], [85.25985718, 26.75600624], [85.26251984, 26.75501442], [85.2857666, 26.75365639], [85.28660583, 26.7536087], [85.2872467, 26.75354958], [85.30251312, 26.75211716], [85.30407715, 26.75238609], [85.3061142, 26.75273705], [85.32010651, 26.74889946], [85.32450867, 26.74500275], [85.32471466, 26.74481773], [85.32497406, 26.74485779], [85.32518768, 26.74493217], [85.32910156, 26.74627495], [85.32863617, 26.74554443], [85.32798767, 26.74453545], [85.33631897, 26.74141502], [85.35719299, 26.76019478], [85.35930634, 26.76094055], [85.36057281, 26.7615757], [85.36352539, 26.76305199], [85.36536407, 26.76075554], [85.36601257, 26.75994492], [85.37171936, 26.75811577], [85.37711334, 26.7606163], [85.38030243, 26.76504135], [85.38613892, 26.77401924], [85.39421844, 26.77521515], [85.39912415, 26.77800941], [85.40461731, 26.78271484], [85.40802002, 26.78902626], [85.40963745, 26.7911377], [85.41159058, 26.7909317], [85.41907501, 26.79012108], [85.42208099, 26.78856087], [85.42740631, 26.78579521], [85.4311142, 26.78621483], [85.4312973, 26.7863369], [85.43473816, 26.78989601], [85.43593597, 26.78935814], [85.43722534, 26.7887764], [85.44869995, 26.78346825], [85.4497757, 26.7837677], [85.45481873, 26.78169823], [85.45574188, 26.7823143], [85.45563507, 26.78189278], [85.46061707, 26.78411484], [85.46099091, 26.7843647], [85.46033478, 26.78492546], [85.46617889, 26.7887764], [85.46681976, 26.78831482], [85.47521973, 26.78991508], [85.4801178, 26.79321861], [85.4812088, 26.79953194], [85.48152161, 26.80135918], [85.48159027, 26.80195045], [85.48783112, 26.80050087], [85.4983139, 26.79811478], [85.49820709, 26.80015755], [85.49736786, 26.80120468], [85.49811554, 26.8020153], [85.49919128, 26.80800629], [85.49874115, 26.80915833], [85.50020599, 26.80985069], [85.50072479, 26.81081963], [85.49997711, 26.81189156], [85.50209045, 26.81313515], [85.50388336, 26.81373978], [85.5058136, 26.81501579], [85.51044464, 26.81602478], [85.5112915, 26.81624222], [85.51461029, 26.8155899], [85.52211761, 26.81411552], [85.53229523, 26.82456589], [85.53529358, 26.82768631], [85.54508972, 26.83786583], [85.54709625, 26.83713341], [85.55562592, 26.83402824], [85.55818176, 26.83980179], [85.55991364, 26.84371567], [85.5679245, 26.84073448], [85.57429504, 26.85663033], [85.57642365, 26.85923195], [85.57765198, 26.86073112], [85.5803833, 26.85921478], [85.58141327, 26.85611534], [85.58473206, 26.8584938], [85.5885849, 26.85228157], [85.58783722, 26.85129738], [85.58751678, 26.84696007], [85.5941391, 26.85004616], [85.60211945, 26.85381699], [85.60921478, 26.85701561], [85.62164307, 26.86933899], [85.6262207, 26.87341499], [85.62861633, 26.87307167], [85.63668823, 26.87190247], [85.6385498, 26.86781502], [85.64461517, 26.85291481], [85.65391541, 26.85042572], [85.68254089, 26.84296036], [85.70477295, 26.83263397], [85.72332001, 26.82001495], [85.73101807, 26.80781555], [85.73091888, 26.80261612], [85.73262024, 26.80011559], [85.73671722, 26.79561615], [85.73711395, 26.78391457], [85.73734283, 26.77771759], [85.7357254, 26.76963997], [85.7310257, 26.74975014], [85.73635101, 26.7372036], [85.73287201, 26.73558807], [85.73240662, 26.73471832], [85.73371887, 26.73041344], [85.73051453, 26.72951508], [85.73175049, 26.72502518], [85.73111725, 26.72490883], [85.73038483, 26.72477531], [85.72841644, 26.71941566], [85.73013306, 26.71744347], [85.72714233, 26.70936203], [85.72864532, 26.70576286], [85.72678375, 26.70290375], [85.72714996, 26.70004654], [85.72652435, 26.69970322], [85.7257843, 26.69930077], [85.72759247, 26.69521141], [85.72763062, 26.69512367], [85.72564697, 26.68640709], [85.7276535, 26.68463516], [85.72693634, 26.6838665], [85.72711945, 26.68351555], [85.72690582, 26.6819706], [85.72714996, 26.68177795], [85.72593689, 26.67484474], [85.72581482, 26.67394447], [85.7287674, 26.67357635], [85.72781372, 26.67011452], [85.73162842, 26.66683388], [85.73311615, 26.66711235], [85.73265076, 26.66618729], [85.73861694, 26.66365814], [85.73871613, 26.66361618], [85.73720551, 26.65718651], [85.73461914, 26.65431595], [85.73597717, 26.65281677], [85.7375946, 26.65207672], [85.73721313, 26.6514492], [85.73751831, 26.65111542], [85.73786926, 26.65077019], [85.73833466, 26.65095711], [85.74915314, 26.63964844], [85.75536346, 26.637537], [85.76194763, 26.63592148], [85.76760864, 26.63210678], [85.76909637, 26.6312027], [85.77176666, 26.62958336], [85.77603912, 26.62885094], [85.80221558, 26.62436295], [85.80383301, 26.62349319], [85.8054657, 26.61519432], [85.80557251, 26.6146698], [85.81190491, 26.60932922], [85.81832123, 26.60381889], [85.81982422, 26.6025238], [85.83262634, 26.6012516], [85.83269501, 26.60157776], [85.83353424, 26.61094093], [85.83460999, 26.61077499], [85.83515167, 26.61077881], [85.84207916, 26.61029625], [85.85331726, 26.60951614], [85.85562134, 26.604702], [85.85650635, 26.59954071], [85.85997009, 26.58958626], [85.85069275, 26.57653427], [85.85150909, 26.57193756], [85.85211945, 26.56841469], [85.8552475, 26.56959343], [85.85888672, 26.57167053], [85.85968781, 26.57126808], [85.8598175, 26.57131577], [85.85987091, 26.57117844], [85.86062622, 26.57080078], [85.86089325, 26.56857681], [85.87055206, 26.57466316], [85.87060547, 26.5747242], [85.8729248, 26.57937622], [85.87401581, 26.57891464], [85.87801361, 26.58091545], [85.8813324, 26.58250999], [85.88175201, 26.58347702], [85.88581085, 26.58246231], [85.88892365, 26.58242989], [85.89323425, 26.59454346], [85.8948288, 26.59433746], [85.89628601, 26.59466171], [85.89731598, 26.59401703], [85.90272522, 26.59454346], [85.90275574, 26.59471321], [85.90299988, 26.60037804], [85.90381622, 26.60021591], [85.91162872, 26.60416985], [85.91191101, 26.60433197], [85.91481781, 26.60401535], [85.91621399, 26.60861588], [85.91902924, 26.60931778], [85.92411804, 26.60971451], [85.92910004, 26.61031151], [85.9287262, 26.61131477], [85.93019104, 26.61278152], [85.93121338, 26.61511612], [85.93108368, 26.61628532], [85.93502045, 26.61321449], [85.94023895, 26.61582756], [85.94041443, 26.6159153], [85.94261932, 26.61291504], [85.95034027, 26.61322021], [85.94966888, 26.61600304], [85.94851685, 26.62091637], [85.95171356, 26.62436295], [85.95281982, 26.62421608], [85.95714569, 26.62893867], [85.95760345, 26.62947273], [85.95672607, 26.63310242], [85.95469666, 26.63716316], [85.95552063, 26.63811302], [85.95569611, 26.64362526], [85.95730591, 26.64561462], [85.95880127, 26.64896965], [85.95967102, 26.6488533], [85.9597168, 26.64891624], [85.9616394, 26.64995575], [85.96252441, 26.65108109], [85.96341705, 26.65091896], [85.96389771, 26.65083313], [85.96541595, 26.65021515], [85.96612549, 26.65121841], [85.96711731, 26.65261459], [85.97001648, 26.65161705], [85.97032166, 26.65203476], [85.97232056, 26.65481567], [85.97545624, 26.65455818], [85.97797394, 26.6576519], [85.97818756, 26.65791702], [85.98062897, 26.65760803], [85.98696136, 26.65680885], [85.98999023, 26.65642548], [86.00217438, 26.654562], [86.00813293, 26.65592957], [86.00823975, 26.65586853], [86.01281738, 26.65401459], [86.01468658, 26.65863419], [86.01422882, 26.65928459], [86.02059937, 26.66067505], [86.02101898, 26.66081619], [86.03073883, 26.66642189], [86.05039978, 26.66129494], [86.05722046, 26.65951538], [86.06502533, 26.65808296], [86.07201385, 26.65679932], [86.07621002, 26.64951324], [86.09001923, 26.64301491], [86.09035492, 26.64287376], [86.11997223, 26.63043404], [86.12983704, 26.62961578], [86.13150024, 26.62947845], [86.14073944, 26.62871361], [86.14321899, 26.6164093], [86.14241791, 26.61622429], [86.13911438, 26.60796738], [86.1384201, 26.6062088], [86.14483643, 26.6047287], [86.14894104, 26.60845566], [86.15742493, 26.60960579], [86.16360474, 26.61454582], [86.16931915, 26.61392403], [86.17100525, 26.6149826], [86.17391968, 26.61681557], [86.1758194, 26.61548996], [86.17721558, 26.6145153], [86.17732239, 26.61450005], [86.17826843, 26.61516762], [86.1848526, 26.61342621], [86.18860626, 26.61445045], [86.18895721, 26.61453247], [86.19454956, 26.61442184], [86.19628906, 26.61243248], [86.19566345, 26.61094093], [86.19554138, 26.61102676], [86.19521332, 26.61041451], [86.19777679, 26.60770988], [86.19889069, 26.60072899], [86.1982193, 26.59781456], [86.19902039, 26.59752083], [86.19783783, 26.59514809], [86.19781494, 26.59501457], [86.19941711, 26.59329987], [86.20170593, 26.59560776], [86.20301819, 26.5969162], [86.20375824, 26.59473801], [86.20399475, 26.59403992], [86.20796967, 26.59615326], [86.21061707, 26.59271622], [86.21369171, 26.59247208], [86.2144165, 26.59241486], [86.21721649, 26.59110832], [86.21741486, 26.59101486], [86.21755981, 26.59082222], [86.21961212, 26.58810997], [86.2230835, 26.58966255], [86.22611237, 26.59105873], [86.22626495, 26.59101486], [86.2302475, 26.59102631], [86.2312088, 26.5918026], [86.23193359, 26.59156036], [86.23339844, 26.59202385], [86.23369598, 26.59279823], [86.23681641, 26.59041595], [86.23683929, 26.59072113], [86.23731995, 26.59731483], [86.23692322, 26.59764481], [86.23808289, 26.59827995], [86.23953247, 26.60012436], [86.23965454, 26.60124779], [86.24102783, 26.60112381], [86.24245453, 26.60207558], [86.24251556, 26.60311317], [86.24551392, 26.60251617], [86.24475098, 26.60547447], [86.24576569, 26.60572624], [86.24581909, 26.60641479], [86.246315, 26.60688972], [86.24599457, 26.60758591], [86.24711609, 26.60907745], [86.24773407, 26.60823822], [86.24791718, 26.6084156], [86.25112152, 26.60900879], [86.25102997, 26.6103611], [86.25009918, 26.61206055], [86.25092316, 26.61218643], [86.25243378, 26.61344528], [86.25457001, 26.61678314], [86.25507355, 26.61557961], [86.26289368, 26.6152916], [86.27383423, 26.61655617], [86.27793121, 26.6170311], [86.28903961, 26.61437607], [86.28938293, 26.61433029], [86.29521179, 26.6129303], [86.30800629, 26.61864662], [86.3102417, 26.61964035], [86.32479095, 26.61935616], [86.32928467, 26.61930275], [86.33003998, 26.61915398], [86.34656525, 26.61590385], [86.34648132, 26.61576271], [86.34603882, 26.61504173], [86.34559631, 26.61391068], [86.34381866, 26.61151505], [86.34376526, 26.61144829], [86.34305573, 26.61168671], [86.34132385, 26.60823059], [86.3427124, 26.60647011], [86.34329987, 26.60572243], [86.35501862, 26.60431671], [86.35883331, 26.60385895], [86.3607254, 26.60333824], [86.3874588, 26.59665489], [86.39594269, 26.59453392], [86.39629364, 26.59444618], [86.39723969, 26.59528351], [86.39937592, 26.59279251], [86.39951324, 26.59271622], [86.39941406, 26.59076309], [86.39935303, 26.58869743], [86.39733887, 26.58485794], [86.43265533, 26.57266617], [86.44797516, 26.56972122], [86.45788574, 26.56781769], [86.48832703, 26.54942703], [86.50112915, 26.54159737], [86.50327301, 26.54125214], [86.51816559, 26.53884888], [86.52411652, 26.54321289], [86.52809143, 26.54275513], [86.53058624, 26.54251862], [86.53381348, 26.5405159], [86.54421997, 26.53811455], [86.54723358, 26.53463745], [86.552948, 26.52991486], [86.55410767, 26.52333832], [86.55680084, 26.52395058], [86.55817413, 26.52265358], [86.55778503, 26.52057457], [86.55804443, 26.51773643], [86.55727386, 26.51815796], [86.55722046, 26.51791573], [86.56331635, 26.50931549], [86.56376648, 26.50928497], [86.56656647, 26.50154877], [86.56690216, 26.50072289], [86.5712204, 26.49881554], [86.57204437, 26.49745941], [86.57283783, 26.49760437], [86.57277679, 26.49689484], [86.58059692, 26.49482155], [86.58289337, 26.49444008], [86.58976746, 26.49330711], [86.59035492, 26.49325371], [86.59819031, 26.49064445], [86.60549927, 26.48863029], [86.60775757, 26.48801231], [86.61470795, 26.48611832], [86.61508942, 26.48654366], [86.61759949, 26.48515511], [86.62221527, 26.48361588], [86.62341309, 26.48381042], [86.62381744, 26.48227882], [86.62474823, 26.48150444], [86.6256485, 26.4815731], [86.62581635, 26.48101425], [86.6282196, 26.48061562], [86.62926483, 26.47713089], [86.6293869, 26.47672844], [86.63050079, 26.47859001], [86.63186646, 26.47747231], [86.62987518, 26.47511101], [86.62857819, 26.46943474], [86.62851715, 26.46911621], [86.63236237, 26.46914482], [86.63114166, 26.46792793], [86.63161469, 26.46771622], [86.63179779, 26.46760941], [86.63174438, 26.46777916], [86.63261414, 26.46827507], [86.63413239, 26.46626854], [86.63630676, 26.46502113], [86.63683319, 26.46578979], [86.64093781, 26.465168], [86.64087677, 26.46436501], [86.64122009, 26.46431541], [86.67917633, 26.45368385], [86.67945862, 26.45361137], [86.69261932, 26.45061493], [86.69574738, 26.45088387], [86.69763184, 26.44891167], [86.69760895, 26.4487648], [86.69790649, 26.44859695], [86.6984787, 26.44826698], [86.69800568, 26.44443321], [86.69798279, 26.44421959], [86.69983673, 26.44307899], [86.70093536, 26.44244003], [86.70215607, 26.4372654], [86.70220184, 26.43708229], [86.71022797, 26.43610382], [86.71256256, 26.43582344], [86.72258759, 26.4346199], [86.72817993, 26.42540169], [86.72966766, 26.42440605], [86.73046875, 26.42564964], [86.73103333, 26.42651939], [86.73190308, 26.42608452], [86.73277283, 26.42564964], [86.73226166, 26.42416], [86.73165894, 26.42241859], [86.73262024, 26.42221451], [86.73352051, 26.42204475], [86.73501587, 26.42401505], [86.73948669, 26.42304039], [86.73981476, 26.42421532], [86.74010468, 26.4252758], [86.74308777, 26.4243145], [86.74571991, 26.42691612], [86.74917603, 26.42800331], [86.74954224, 26.43323135], [86.74669647, 26.43360329], [86.7464447, 26.43459702], [86.74967957, 26.43584061], [86.75241852, 26.44101524], [86.75551605, 26.44168091], [86.75588989, 26.44615555], [86.75945282, 26.44699669], [86.76272583, 26.44781494], [86.7628479, 26.45121765], [86.76303864, 26.451231], [86.76657867, 26.45087624], [86.76692963, 26.45150757], [86.76719666, 26.45199585], [86.76659393, 26.45254135], [86.76583099, 26.45323753], [86.76623535, 26.45370483], [86.76657867, 26.45410919], [86.76495361, 26.45546722], [86.76745605, 26.45818901], [86.7677002, 26.45845795], [86.77020264, 26.45887375], [86.77155304, 26.45909882], [86.78260803, 26.45435715], [86.80323792, 26.44714928], [86.82379913, 26.44181252], [86.8293457, 26.44037437], [86.83580017, 26.43869781], [86.83753967, 26.44068718], [86.83843994, 26.44026756], [86.83851624, 26.44031525], [86.84041595, 26.44221497], [86.84051514, 26.44213867], [86.84250641, 26.44143295], [86.84220123, 26.44082451], [86.84188843, 26.44018936], [86.84536743, 26.43992805], [86.84591675, 26.44074821], [86.84698486, 26.4423027], [86.84947205, 26.44205284], [86.84785461, 26.44404221], [86.84835052, 26.44789505], [86.8520813, 26.44826698], [86.85303497, 26.44781876], [86.85419464, 26.44727325], [86.8584137, 26.44814301], [86.85952759, 26.45121193], [86.85958862, 26.4513073], [86.86239624, 26.45423317], [86.86239624, 26.45497704], [86.86239624, 26.45584869], [86.86310577, 26.45594406], [86.86330414, 26.45597076], [86.86425781, 26.45609665], [86.86416626, 26.456213], [86.86338806, 26.45721436], [86.86771393, 26.45721626], [86.86724091, 26.4552269], [86.86839294, 26.45568848], [86.86910248, 26.45597267], [86.86903381, 26.45517349], [86.86898041, 26.45448112], [86.871315, 26.45411491], [86.87320709, 26.4552269], [86.87371826, 26.45420074], [86.87394714, 26.45373535], [86.87532043, 26.45373535], [86.8784256, 26.4552269], [86.87805176, 26.45627975], [86.87767792, 26.45734024], [86.88161469, 26.45673752], [86.88176727, 26.4568119], [86.88476562, 26.4593277], [86.88554382, 26.45926857], [86.88637543, 26.45920372], [86.8870163, 26.46108055], [86.89641571, 26.4617157], [86.89756012, 26.46703339], [86.89724731, 26.46792412], [86.89694214, 26.46877289], [86.89471436, 26.46891594], [86.89607239, 26.47175598], [86.89548492, 26.47181511], [86.8948288, 26.47187996], [86.89550018, 26.47288895], [86.89582062, 26.47337151], [86.89521027, 26.47434616], [86.89457703, 26.47535896], [86.89497375, 26.47553825], [86.89595032, 26.47598076], [86.89493561, 26.47598076], [86.89421082, 26.47598076], [86.89510345, 26.47773552], [86.8926239, 26.48143768], [86.89411163, 26.48578644], [86.89596558, 26.4867878], [86.89557648, 26.48728943], [86.9065094, 26.48791122], [86.93222809, 26.48931694], [86.93204498, 26.49028587], [86.93087006, 26.49648476], [86.93509674, 26.51649284], [86.94702148, 26.51674271], [86.94734955, 26.517313], [86.94916534, 26.52052498], [86.94924927, 26.52059746], [86.9495697, 26.52059937], [86.96183014, 26.52000618], [86.96265411, 26.52153778], [86.96367645, 26.52345276], [86.96839905, 26.52332878], [86.96829987, 26.522789], [86.96814728, 26.52196121], [86.97759247, 26.51972389], [86.98181915, 26.52482033], [86.99321747, 26.52283669], [86.99636841, 26.52393532], [87.00235748, 26.52614784], [87.01771545, 26.53181458], [87.02258301, 26.53973198], [87.03588104, 26.55659676], [87.04483032, 26.56794357], [87.04730988, 26.58695602], [87.05066681, 26.58681679], [87.07427979, 26.58546638], [87.07436371, 26.58443069], [87.07440186, 26.58397484], [87.0754776, 26.57730293], [87.07551575, 26.57701492], [87.07511902, 26.54161453], [87.07841492, 26.53701591], [87.08220673, 26.52294922], [87.08811951, 26.48529243], [87.09391785, 26.45001602], [87.11156464, 26.43683434], [87.13014984, 26.42302513], [87.14151001, 26.41458893], [87.16371155, 26.40441704], [87.16501617, 26.40381622], [87.17344666, 26.4030323], [87.19147491, 26.40510941], [87.18881989, 26.41401482], [87.20381927, 26.41329575], [87.20535278, 26.41322708], [87.21381378, 26.41284943], [87.21446228, 26.4101162], [87.21391296, 26.40968895], [87.21392059, 26.4094162], [87.2166748, 26.4079895], [87.21971893, 26.40641594], [87.22142029, 26.40291595], [87.22615051, 26.40557098], [87.22638702, 26.40837479], [87.22761536, 26.40850449], [87.22866058, 26.41004753], [87.22863007, 26.41048813], [87.22905731, 26.41063118], [87.22931671, 26.41101456], [87.22962189, 26.41129684], [87.22912598, 26.41160583], [87.23044586, 26.41207123], [87.23123932, 26.41235161], [87.23123932, 26.412817], [87.23123932, 26.41334724], [87.247612, 26.41398811], [87.25037384, 26.4135952], [87.25031281, 26.41251945], [87.25036621, 26.41243553], [87.2525177, 26.40911484], [87.2559433, 26.41008186], [87.25870514, 26.41086006], [87.26418304, 26.40777779], [87.26860046, 26.40529442], [87.26811218, 26.39081955], [87.26680756, 26.38627434], [87.26828766, 26.37440491], [87.26838684, 26.37361145], [87.27482605, 26.37234116], [87.28611755, 26.37307739], [87.29192352, 26.37343025], [87.29946136, 26.36871529], [87.30381012, 26.36599731], [87.30879211, 26.36829376], [87.31482697, 26.37107277], [87.31491852, 26.37111473], [87.31590271, 26.36725044], [87.32431793, 26.35990906], [87.33825684, 26.35147095], [87.34049225, 26.35011864], [87.34341431, 26.34751511], [87.34715271, 26.34960175], [87.35016632, 26.35133362], [87.35561371, 26.35614777], [87.36083221, 26.36082268], [87.35590363, 26.37183571], [87.35720062, 26.37893486], [87.35886383, 26.38787079], [87.36411285, 26.3966198], [87.37129211, 26.4077549], [87.37863922, 26.40674019], [87.38513947, 26.41302872], [87.39102936, 26.41869736], [87.41433716, 26.42152977], [87.42162323, 26.42241859], [87.42285919, 26.42236519], [87.43019867, 26.42204475], [87.43379974, 26.42453194], [87.44551086, 26.43274117], [87.4647522, 26.43892479], [87.46909332, 26.44006538], [87.48712921, 26.43698311], [87.48851013, 26.4367466], [87.49820709, 26.4350872], [87.51892853, 26.43062019], [87.53929901, 26.42068672], [87.55001831, 26.4182148], [87.55532074, 26.40541458], [87.57361603, 26.39681625], [87.59022522, 26.39221382], [87.59055328, 26.39025116], [87.59088135, 26.38799477], [87.58973694, 26.38223648], [87.58965302, 26.38181305], [87.6084137, 26.38060188], [87.61463165, 26.38982964], [87.63038635, 26.39346886], [87.63089752, 26.39358711], [87.64583588, 26.39334869], [87.65438843, 26.39321327], [87.65280914, 26.40553093], [87.68086243, 26.41545868], [87.68082428, 26.41670036], [87.68023682, 26.43509483], [87.68091583, 26.43509483], [87.68173218, 26.43509483], [87.69451904, 26.43531609], [87.70064545, 26.42834282], [87.70101929, 26.42791557], [87.70858002, 26.42739105], [87.71217346, 26.4271183], [87.71590424, 26.4252758], [87.71608734, 26.42400932], [87.71627808, 26.42266655], [87.71851349, 26.42154884], [87.71971893, 26.42180252], [87.7208786, 26.42204475], [87.72277069, 26.41982269], [87.72431183, 26.41881943], [87.72485352, 26.41893959], [87.72634125, 26.41521072], [87.72531891, 26.41221619], [87.72978973, 26.4102726], [87.73616028, 26.40750504], [87.74163055, 26.41719818], [87.7432785, 26.41747475], [87.74991608, 26.41851616], [87.75569916, 26.40894508], [87.75631714, 26.40791512], [87.76885986, 26.41209602], [87.76809692, 26.4129734], [87.77071381, 26.41496277], [87.7700882, 26.41856575], [87.77082062, 26.41849899], [87.77334595, 26.42122841], [87.7735672, 26.42154884], [87.77555847, 26.41918755], [87.77878571, 26.42154884], [87.77575684, 26.42026711], [87.77555847, 26.42018127], [87.7760849, 26.42101669], [87.77789307, 26.4251709], [87.77307129, 26.42714119], [87.77766418, 26.42690659], [87.77736664, 26.42744064], [87.77505493, 26.42975044], [87.77571869, 26.43041611], [87.77629852, 26.43099403], [87.77841949, 26.42961502], [87.77843475, 26.42971039], [87.78028107, 26.43559074], [87.77967072, 26.436203], [87.77915955, 26.43671036], [87.77806854, 26.43582726], [87.77716827, 26.43509483], [87.77630615, 26.43540192], [87.77542877, 26.43571663], [87.77703857, 26.4404068], [87.78028107, 26.4423027], [87.77902222, 26.44244194], [87.77803802, 26.44255066], [87.77912903, 26.44739723], [87.77642059, 26.4501152], [87.78152466, 26.45038033], [87.78040314, 26.45336342], [87.78487396, 26.45371246], [87.78661346, 26.45771599], [87.79018402, 26.46169472], [87.78835297, 26.46271324], [87.788414, 26.46319771], [87.78860474, 26.46479607], [87.78878021, 26.46497345], [87.78901672, 26.46611595], [87.78959656, 26.46509361], [87.79096222, 26.46392632], [87.79245758, 26.46554184], [87.79101563, 26.46596909], [87.78939819, 26.46644783], [87.78910065, 26.46653557], [87.78897858, 26.46765327], [87.79221344, 26.46891594], [87.79354095, 26.46645546], [87.79364014, 26.46660042], [87.79494476, 26.46852493], [87.81395721, 26.46156502], [87.81785583, 26.4596138], [87.81968689, 26.4587307], [87.82771301, 26.4519062], [87.83221436, 26.44991493], [87.83071899, 26.43981552], [87.84430695, 26.43742943], [87.85121918, 26.43621445], [87.853508, 26.44490433], [87.85359955, 26.44495583], [87.86372375, 26.44972801], [87.86354065, 26.45075226], [87.86512756, 26.452631], [87.86241913, 26.45371628], [87.86071014, 26.45599365], [87.86105347, 26.45882988], [87.8611908, 26.45890427], [87.86217499, 26.45945168], [87.86122894, 26.46039772], [87.86067963, 26.46094322], [87.86080933, 26.4634285], [87.86512756, 26.46405792], [87.86604309, 26.46762276], [87.88814545, 26.47622871], [87.88954926, 26.48205185], [87.89015198, 26.48455238], [87.89028931, 26.48512268], [87.89063263, 26.48641968], [87.90252686, 26.47712708], [87.90892029, 26.46431541], [87.91210175, 26.45744896], [87.90345001, 26.45026016], [87.90119934, 26.44839096], [87.9260025, 26.446455], [87.92667389, 26.4464035], [87.92816162, 26.44006538], [87.92580414, 26.43745613], [87.92266846, 26.43592072], [87.91996002, 26.43459702], [87.9198761, 26.43441582], [87.91912079, 26.43071556], [87.92415619, 26.42923355], [87.92667389, 26.42888069], [87.92743683, 26.42826843], [87.92761993, 26.42821503], [87.92763519, 26.42810822], [87.92853546, 26.42738914], [87.92926025, 26.41824532], [87.92930603, 26.41794777], [87.93499756, 26.417696], [87.96831512, 26.39681625], [87.98072815, 26.39458084], [87.99328613, 26.39247131], [87.9936142, 26.39237595], [87.99415588, 26.39221954], [87.99452209, 26.38266182], [87.99502563, 26.36935425], [87.99575806, 26.36935425], [87.99626923, 26.36935425], [87.99619293, 26.36837959], [87.99998474, 26.36501312], [88.00037384, 26.36472702], [88.00496674, 26.36624718], [88.00471497, 26.36561584], [88.00447083, 26.36487961], [88.00671387, 26.36441612], [88.00832367, 26.3614006], [88.01018524, 26.36077881], [88.03255463, 26.36463165], [88.0329361, 26.3657074], [88.03104401, 26.36834526], [88.03031921, 26.36885643], [88.02999878, 26.3698101], [88.0296936, 26.37071991], [88.03072357, 26.37127304], [88.03112793, 26.37211037], [88.03069305, 26.37333107], [88.03173828, 26.37370491], [88.03208923, 26.37494087], [88.03156281, 26.37643814], [88.0324173, 26.3761158], [88.0338974, 26.37818146], [88.03082275, 26.37870598], [88.0298233, 26.38119888], [88.0296936, 26.38153267], [88.03205872, 26.38290024], [88.03264618, 26.38249016], [88.03271484, 26.38251495], [88.03390503, 26.38465691], [88.03466797, 26.38799477], [88.03582001, 26.38811684], [88.03702545, 26.38824272], [88.03715515, 26.39172363], [88.03901672, 26.39001465], [88.04049683, 26.39271355], [88.04038239, 26.39358711], [88.0424881, 26.39383507], [88.04380035, 26.39457893], [88.04299164, 26.39507866], [88.04455566, 26.39498138], [88.04498291, 26.39495468], [88.04501343, 26.39521217], [88.04510498, 26.39594841], [88.04616547, 26.39578819], [88.04759216, 26.39557457], [88.04701996, 26.39621735], [88.04660034, 26.39669418], [88.04750061, 26.39691925], [88.0490799, 26.39731598], [88.04846954, 26.39834976], [88.0478363, 26.39942741], [88.04991913, 26.40081596], [88.05021667, 26.40074921], [88.05293274, 26.40029716], [88.05306244, 26.4001236], [88.05417633, 26.39868164], [88.05475616, 26.40021706], [88.05492401, 26.40067101], [88.05570984, 26.40060806], [88.05802917, 26.40042114], [88.05740356, 26.40130234], [88.05678558, 26.40216255], [88.05793762, 26.40273857], [88.05877686, 26.40315628], [88.05848694, 26.40423965], [88.05815125, 26.40551758], [88.0594635, 26.40592766], [88.05987549, 26.40662956], [88.05939484, 26.40750504], [88.06053162, 26.40750504], [88.06261444, 26.4094162], [88.06275177, 26.40940285], [88.06648254, 26.41036415], [88.06673431, 26.40902328], [88.06697845, 26.4077549], [88.06867218, 26.40875816], [88.06970978, 26.40937042], [88.07039642, 26.40849495], [88.07107544, 26.40762901], [88.07390594, 26.40774345], [88.07207489, 26.41284943], [88.08111572, 26.41981506], [88.08624268, 26.4258976], [88.08740234, 26.42999649], [88.08752441, 26.43040848], [88.09069061, 26.43346214], [88.0912323, 26.43398857], [88.09740448, 26.43744278], [88.09901428, 26.44304848], [88.09941101, 26.45211983], [88.09616089, 26.45900345], [88.09442902, 26.462677], [88.09550476, 26.46356773], [88.09667969, 26.46454811], [88.0969696, 26.46457672], [88.10205078, 26.46578979], [88.1059494, 26.46670723], [88.10624695, 26.46790314], [88.10041046, 26.47225189], [88.10699463, 26.47175598], [88.10709381, 26.47186661], [88.10923004, 26.47592545], [88.10289001, 26.47945976], [88.10375214, 26.48356438], [88.10832214, 26.48910713], [88.10819244, 26.48922539], [88.10580444, 26.49132919], [88.10292053, 26.49411583], [88.10301971, 26.4985981], [88.10128021, 26.50543404], [88.09518433, 26.50431442], [88.09368134, 26.50590706], [88.0929184, 26.50671577], [88.09339905, 26.50704384], [88.09911346, 26.51091576], [88.09804535, 26.51480865], [88.09770966, 26.51613235], [88.09955597, 26.51662254], [88.10551453, 26.51821518], [88.10590363, 26.52012825], [88.10717773, 26.5263195], [88.10732269, 26.52701569], [88.10749054, 26.52842331], [88.10525513, 26.53041267], [88.10614777, 26.53562355], [88.10819244, 26.5352211], [88.11030579, 26.53024101], [88.11514282, 26.53018951], [88.12354279, 26.52013969], [88.13217926, 26.51258087], [88.13765717, 26.51419258], [88.14129639, 26.51179123], [88.14539337, 26.51097107], [88.14769745, 26.51663971], [88.15090179, 26.51692009], [88.15506744, 26.51577187], [88.15744019, 26.51874161], [88.16538239, 26.52164078], [88.16602325, 26.53446007], [88.1682663, 26.53736115], [88.17063141, 26.53650284], [88.17382813, 26.53282928], [88.17868042, 26.53087044], [88.17962646, 26.53449059], [88.17913055, 26.53699112], [88.18242645, 26.5429306], [88.18573761, 26.54413986], [88.19050598, 26.54430962], [88.19668579, 26.54356003], [88.19898987, 26.54175186], [88.19924164, 26.53872108], [88.20149231, 26.53860092], [88.20405579, 26.53955078], [88.2049408, 26.53725052], [88.20742035, 26.5352211], [88.21456146, 26.53558922], [88.21534729, 26.53791046], [88.21109009, 26.53869057], [88.20966339, 26.54072189], [88.21235657, 26.54166985], [88.21689606, 26.54156113], [88.22080231, 26.54627991], [88.21922302, 26.54859161], [88.21389008, 26.55076981], [88.21539307, 26.55726814], [88.22180939, 26.55323029], [88.23120117, 26.55198288], [88.23114777, 26.53921127], [88.23336029, 26.53236961], [88.22582245, 26.52663994], [88.21865082, 26.52370071], [88.20665741, 26.51498032], [88.20635986, 26.51006126], [88.1998291, 26.51065063], [88.19386292, 26.50801086], [88.18634033, 26.50007057], [88.17920685, 26.49398041], [88.179039, 26.49057961], [88.18340302, 26.48839951], [88.18295288, 26.48526001], [88.19164276, 26.48307991], [88.1937561, 26.4720211], [88.21479034, 26.46973038], [88.21694183, 26.47265053], [88.21264648, 26.47458076], [88.21315765, 26.47777939], [88.22622681, 26.4762516], [88.22595978, 26.4720211], [88.22112274, 26.46684837], [88.21533966, 26.46573067], [88.22460175, 26.45574951], [88.22897339, 26.44715118], [88.23388672, 26.44625092], [88.23664856, 26.4493103], [88.24340057, 26.44930077], [88.24835205, 26.43880081], [88.25219727, 26.43379021], [88.25963593, 26.43066978], [88.26275635, 26.42808914], [88.26560974, 26.4233799], [88.26790619, 26.42175293], [88.26834869, 26.41792107], [88.26315308, 26.41501045], [88.25538635, 26.4158802], [88.23581696, 26.39616966], [88.23044586, 26.39396095], [88.22924805, 26.38985062], [88.23171234, 26.38490105], [88.23760986, 26.37537766], [88.24312592, 26.37409019], [88.24511719, 26.37599754], [88.25126648, 26.37585831], [88.25489807, 26.37446976], [88.26164246, 26.38002968], [88.26759338, 26.38116074], [88.26994324, 26.37887955], [88.27397919, 26.37728119], [88.2818985, 26.36013031], [88.28990173, 26.35691071], [88.29191589, 26.35391045], [88.28913879, 26.35113907], [88.28336334, 26.34930992], [88.27935028, 26.34634972], [88.28170013, 26.33980942], [88.27955627, 26.33553123], [88.27626038, 26.33249283], [88.27243805, 26.3305397], [88.26976013, 26.33268929], [88.26859283, 26.33700943], [88.26526642, 26.33649063], [88.26113129, 26.33785057], [88.25801086, 26.33423996], [88.25630951, 26.33011818], [88.25370789, 26.3277607], [88.24819946, 26.32653809], [88.24469757, 26.3162899], [88.23912811, 26.31319809], [88.2364502, 26.30540085], [88.23416138, 26.30668068], [88.23177338, 26.31035805], [88.22690582, 26.30397034], [88.22677612, 26.29664993], [88.22458649, 26.2894001], [88.22101593, 26.28821945], [88.21900177, 26.28567123], [88.21498108, 26.28493118], [88.21425629, 26.28168106], [88.21115875, 26.28000069], [88.20410156, 26.27959061], [88.19448853, 26.27412987], [88.1893692, 26.27510071], [88.1833725, 26.27468109], [88.17690277, 26.26172829], [88.16706085, 26.25720024], [88.16311646, 26.25753021], [88.15882874, 26.25691032], [88.14444733, 26.25279999], [88.14064789, 26.24963951], [88.14063263, 26.24572945], [88.13741302, 26.2437706], [88.13593292, 26.23715019], [88.13880157, 26.2308197], [88.13582611, 26.22821045], [88.13105011, 26.22681046], [88.12612915, 26.22691917], [88.12560272, 26.22789955], [88.11995697, 26.22794914], [88.11187744, 26.22620964], [88.11390686, 26.22397995], [88.11601257, 26.2229805], [88.10838318, 26.21705055], [88.10572815, 26.21640015], [88.10246277, 26.21224976], [88.09718323, 26.20643044], [88.09359741, 26.20653915], [88.08969116, 26.20323181], [88.08759308, 26.19797134], [88.08724213, 26.19444084], [88.08162689, 26.19235039], [88.07298279, 26.18539047], [88.0748291, 26.18128014], [88.07141876, 26.17879295], [88.06983185, 26.17571831], [88.06710052, 26.17762947], [88.06343079, 26.17667007], [88.05864716, 26.17375946], [88.05233002, 26.17167282], [88.04836273, 26.17464066], [88.04618073, 26.17788124], [88.04046631, 26.17681122], [88.03743744, 26.17770004], [88.03233337, 26.17351913], [88.03363037, 26.17028999], [88.02852631, 26.16728973], [88.02662659, 26.16279984], [88.01751709, 26.15555954], [88.01174164, 26.15479088], [88.01078033, 26.14929008], [88.01509094, 26.1429081], [88.01306915, 26.14087105], [88.00681305, 26.14328957], [87.99910736, 26.1403904], [87.99603271, 26.14179039], [87.98840332, 26.14861107], [87.98210907, 26.15917969], [87.97479248, 26.15286064], [87.96953583, 26.15440941], [87.96405792, 26.15197945], [87.96334076, 26.14888954], [87.96869659, 26.14787102], [87.96877289, 26.13935089], [87.97097015, 26.13714027], [87.9678421, 26.13183022], [87.95713043, 26.12886047], [87.95868683, 26.12569809], [87.96740723, 26.12537193], [87.97563171, 26.12162971], [87.96935272, 26.10931015], [87.95823669, 26.1088295], [87.95494843, 26.10568237], [87.95440674, 26.10279274], [87.95812988, 26.10085106], [87.95765686, 26.09708977], [87.96273041, 26.09472084], [87.96570587, 26.09192085], [87.96948242, 26.0916481], [87.97025299, 26.08735085], [87.97219086, 26.08485031], [87.96813202, 26.08136177], [87.96401215, 26.08325005], [87.9598465, 26.08403969], [87.95052338, 26.08304024], [87.94300842, 26.08469009], [87.93788147, 26.08446121], [87.93694305, 26.07975006], [87.93820953, 26.07676125], [87.93470001, 26.0705204], [87.93112946, 26.06895065], [87.92253876, 26.07180977], [87.92185974, 26.07687187], [87.91652679, 26.07969856], [87.91750336, 26.08801079], [87.91293335, 26.0909729], [87.89572906, 26.07987022], [87.89256287, 26.08035088], [87.88928223, 26.07509995], [87.88826752, 26.07193947], [87.88471985, 26.07151985], [87.87606049, 26.06619072], [87.87769318, 26.05791092], [87.87520599, 26.05557823], [87.86325073, 26.05610085], [87.84915161, 26.04496956], [87.84211731, 26.04448128], [87.84126282, 26.04120827], [87.84165192, 26.03230095], [87.83892822, 26.02287102], [87.84062195, 26.01976967], [87.83333588, 26.00109291], [87.83075714, 25.9921608], [87.82720184, 25.99234009], [87.82604218, 25.98831177], [87.82618713, 25.98368263], [87.82987976, 25.97187996], [87.83126068, 25.96409988], [87.83097839, 25.96223068], [87.82538605, 25.95872116], [87.82704926, 25.95358086], [87.82657623, 25.95004272], [87.82390594, 25.94645119], [87.82480621, 25.94366074], [87.82830811, 25.94111061], [87.82711029, 25.93778038], [87.82993317, 25.93545151], [87.82681274, 25.93185043], [87.82350922, 25.93135071], [87.81787109, 25.93301964], [87.80696106, 25.92991829], [87.80573273, 25.92843056], [87.80358124, 25.92072105], [87.80745697, 25.91827011], [87.80747986, 25.91583061], [87.80355835, 25.91394806], [87.80375671, 25.91214943], [87.80780029, 25.90899086], [87.81066132, 25.91399956], [87.81186676, 25.9131794], [87.81646729, 25.91270828], [87.81726074, 25.90918922], [87.81680298, 25.90487099], [87.81365967, 25.89995193], [87.81459045, 25.89884186], [87.81891632, 25.89715958], [87.82026672, 25.89376068], [87.81796265, 25.88845062], [87.81552124, 25.88796043], [87.81550598, 25.88554001], [87.81706238, 25.88334084], [87.81828308, 25.88148117], [87.81986237, 25.88097954], [87.82283783, 25.87146759], [87.83454132, 25.86874008], [87.84314728, 25.86871147], [87.85043335, 25.86707115], [87.855896, 25.86473083], [87.86528015, 25.8675518], [87.86766052, 25.86445045], [87.87068939, 25.86600113], [87.87223816, 25.85965919], [87.87874603, 25.85845947], [87.88121796, 25.85840988], [87.88481903, 25.86465263], [87.89945221, 25.85983086], [87.90138245, 25.85624123], [87.90483093, 25.85308838], [87.91091156, 25.85174942], [87.8973465, 25.83959961], [87.89742279, 25.83452034], [87.89530945, 25.83317947], [87.89261627, 25.8350811], [87.88935852, 25.83280182], [87.88764954, 25.83287048], [87.88339996, 25.82860947], [87.88433838, 25.82731056], [87.89096832, 25.82650948], [87.89379883, 25.82916069], [87.8964386, 25.82909012], [87.89795685, 25.82765007], [87.89385223, 25.8250618], [87.89874268, 25.82014084], [87.90445709, 25.81892014], [87.9105072, 25.8148098], [87.90947723, 25.81069183], [87.9076004, 25.80939293], [87.90313721, 25.81413078], [87.90200806, 25.81314087], [87.90203857, 25.81101036], [87.90119171, 25.81069946], [87.89927673, 25.81159019], [87.89672852, 25.81105995], [87.89501953, 25.80468941], [87.89907074, 25.80550194], [87.90188599, 25.80398941], [87.90305328, 25.80187035], [87.90159607, 25.80050087], [87.89919281, 25.8002491], [87.89800262, 25.79927063], [87.90094757, 25.78030968], [87.89774323, 25.77181053], [87.89846802, 25.76976013], [87.90125275, 25.76923943], [87.90497589, 25.77196121], [87.91866302, 25.77404022], [87.92862701, 25.76785088], [87.92919922, 25.77209091], [87.93239594, 25.77132034], [87.93734741, 25.76794052], [87.93752289, 25.75830078], [87.94164276, 25.75595093], [87.9420166, 25.75323105], [87.93862915, 25.74854088], [87.94386292, 25.74814034], [87.94415283, 25.74381256], [87.95102692, 25.73862076], [87.95665741, 25.73544121], [87.96047974, 25.73212051], [87.96199799, 25.72969818], [87.96099854, 25.72468185], [87.9716568, 25.72006989], [87.97966766, 25.71846008], [87.98184204, 25.72170067], [87.98779297, 25.72367096], [87.98770905, 25.72002029], [87.99256134, 25.71912956], [87.99717712, 25.71191025], [88.00196838, 25.70910072], [88.00676727, 25.70651054], [88.01667023, 25.70471191], [88.01751709, 25.70249939], [88.01431274, 25.69748116], [88.01434326, 25.6943512], [88.01615906, 25.69171906], [88.02239227, 25.6915226], [88.02677917, 25.6989212], [88.03016663, 25.69881058], [88.03219604, 25.69647026], [88.03475189, 25.69403076], [88.03985596, 25.69813919], [88.04332733, 25.69469261], [88.0451889, 25.69000053], [88.04862976, 25.69057083], [88.0508194, 25.68580055], [88.04910278, 25.68147087], [88.04467773, 25.67696953], [88.0431366, 25.67388916], [88.04538727, 25.65980148], [88.04888153, 25.6579895], [88.04876709, 25.65542984], [88.04397583, 25.65258026], [88.04537201, 25.64810944], [88.04853821, 25.64390945], [88.0473175, 25.64302254], [88.04614258, 25.64441109], [88.044487, 25.64287949], [88.04438782, 25.63965988], [88.04294586, 25.63899994], [88.04016113, 25.64191246], [88.03582001, 25.64097977], [88.03555298, 25.63683128], [88.04081726, 25.63611984], [88.04347992, 25.63207054], [88.0542984, 25.63286018], [88.04749298, 25.6276207], [88.04376984, 25.62822914], [88.03942871, 25.62730026], [88.03694153, 25.62200928], [88.03502655, 25.61705017], [88.0372467, 25.6155777], [88.04042816, 25.61046028], [88.03930664, 25.60848999], [88.04139709, 25.60549927], [88.03605652, 25.60240173], [88.02970123, 25.60003853], [88.03131104, 25.59826279], [88.03565216, 25.59698105], [88.03983307, 25.59736061], [88.03858948, 25.59504128], [88.03121948, 25.59101105], [88.03138733, 25.58749962], [88.02649689, 25.58590126], [88.02102661, 25.58692169], [88.02194214, 25.58292007], [88.03002167, 25.57434082], [88.02526855, 25.5690918], [88.02818298, 25.56631088], [88.03392792, 25.5659008], [88.03824615, 25.56388092], [88.03547668, 25.56038094], [88.03343964, 25.56145096], [88.02961731, 25.55948067], [88.03042603, 25.55754852], [88.0270462, 25.55327034], [88.0298233, 25.55039024], [88.03787994, 25.54618073], [88.0357132, 25.53672981], [88.03909302, 25.53318977], [88.04247284, 25.53206062], [88.04605103, 25.53433037], [88.04884338, 25.53333092], [88.0507431, 25.53051949], [88.05597687, 25.52993011], [88.05812073, 25.52870941], [88.05748749, 25.52567101], [88.06687927, 25.51642036], [88.06886292, 25.51304817], [88.06491089, 25.5085125], [88.0638504, 25.50617027], [88.06642914, 25.50503922], [88.07125854, 25.50488091], [88.07285309, 25.50390053], [88.06981659, 25.50188255], [88.06812286, 25.49679947], [88.06815338, 25.48984909], [88.07041168, 25.48050117], [88.06593323, 25.48115158], [88.06167603, 25.48558998], [88.05580139, 25.483881], [88.05296326, 25.48662949], [88.04947662, 25.48615074], [88.04933929, 25.48271942], [88.04633331, 25.4826107], [88.04213715, 25.48538971], [88.03660583, 25.48654175], [88.03862762, 25.49155807], [88.03450775, 25.49273109], [88.03122711, 25.48599052], [88.02754974, 25.4861412], [88.02868652, 25.4889698], [88.02028656, 25.4953804], [88.01573181, 25.50049973], [88.00994873, 25.50097084], [88.00792694, 25.50283051], [88.01167297, 25.50756073], [88.00747681, 25.51039124], [88.00377655, 25.50481987], [88.00300598, 25.49969101], [88.00424194, 25.49403954], [87.99835205, 25.49539948], [87.99276733, 25.49785042], [87.9866333, 25.50263023], [87.98496246, 25.50811005], [87.98055267, 25.51585007], [87.98780823, 25.52071953], [87.98819733, 25.52260017], [87.98764801, 25.52394104], [87.98603821, 25.52482986], [87.97225952, 25.5232296], [87.96914673, 25.52606964], [87.96408844, 25.53308105], [87.95561218, 25.5380497], [87.95239258, 25.53646088], [87.94287872, 25.53467751], [87.93804932, 25.53528976], [87.93354797, 25.5349617], [87.92604828, 25.53621292], [87.92411041, 25.53564835], [87.91963196, 25.53083992], [87.91609955, 25.53190994], [87.91440582, 25.5309391], [87.91456604, 25.52523041], [87.91374969, 25.52376938], [87.90815735, 25.52412033], [87.9030304, 25.5190506], [87.90631866, 25.51366806], [87.90271759, 25.51122093], [87.90480804, 25.50733948], [87.9005127, 25.50723076], [87.89898682, 25.50430107], [87.89585114, 25.50472069], [87.89501953, 25.5099411], [87.88815308, 25.5127697], [87.88532257, 25.51708984], [87.87921906, 25.51597023], [87.88047791, 25.51332092], [87.88136292, 25.50556946], [87.86988068, 25.50300026], [87.86872864, 25.49718285], [87.86348724, 25.49342918], [87.86086273, 25.48605156], [87.86052704, 25.47783089], [87.86390686, 25.47031975], [87.86428833, 25.46788979], [87.86347198, 25.46538925], [87.85067749, 25.46834946], [87.84955597, 25.46499062], [87.83381653, 25.46457291], [87.8338089, 25.45881081], [87.82769012, 25.45883179], [87.82559967, 25.45754051], [87.8273468, 25.45158958], [87.82496643, 25.44939041], [87.82578278, 25.445261], [87.82171631, 25.44302177], [87.82092285, 25.43977165], [87.81922913, 25.43753815], [87.80864716, 25.43419075], [87.80680084, 25.43477821], [87.79830933, 25.44186974], [87.7933197, 25.44219971], [87.79260254, 25.44561958], [87.78652191, 25.44869995], [87.78132629, 25.44465065], [87.7796402, 25.43659973], [87.77651215, 25.42897034], [87.77011108, 25.42876816], [87.76586151, 25.42429161], [87.77120209, 25.41852951], [87.77242279, 25.41491127], [87.77127075, 25.41155815], [87.76998138, 25.40983009], [87.76798248, 25.40876961], [87.76413727, 25.40897942], [87.76213837, 25.41206169], [87.75975037, 25.41008949], [87.75910187, 25.40504074], [87.76381683, 25.4048996], [87.76644897, 25.40353012], [87.76306915, 25.39561081], [87.76255798, 25.38899994], [87.76268768, 25.38623047], [87.76570129, 25.37799072], [87.77379608, 25.37195015], [87.77671814, 25.37084961], [87.78882599, 25.3722496], [87.78736115, 25.35486031], [87.78486633, 25.34460068], [87.78159332, 25.33839989], [87.78398132, 25.33242989], [87.79144287, 25.32233047], [87.79728699, 25.32208061], [87.80162811, 25.3234005], [87.8110733, 25.31916046], [87.82035065, 25.31282043], [87.82892609, 25.30342102], [87.83114624, 25.30216026], [87.84037018, 25.2983799], [87.85041046, 25.29743767], [87.85137939, 25.29249954], [87.853302, 25.28936958], [87.85501099, 25.2895298], [87.85616302, 25.28297043], [87.85652161, 25.2777729], [87.85428619, 25.26791], [87.85137939, 25.26906967], [87.84996796, 25.26728058], [87.8497467, 25.26148033], [87.85103607, 25.25796127], [87.84925079, 25.25342751], [87.84729004, 25.25225067], [87.84555054, 25.2522583], [87.84158325, 25.25358009], [87.83553314, 25.24981117], [87.83228302, 25.24464989], [87.83024597, 25.23966026], [87.82493591, 25.23655128], [87.82277679, 25.23434067], [87.83380127, 25.21336937], [87.83683777, 25.20310974], [87.83664703, 25.19926071], [87.83230591, 25.20078087], [87.82965851, 25.20405006], [87.82119751, 25.20808983], [87.81004333, 25.21173286], [87.80134583, 25.21824074], [87.7875824, 25.2204895], [87.78753662, 25.22862053], [87.78544617, 25.23631287], [87.78520203, 25.24045944], [87.78367615, 25.24299049], [87.78330994, 25.24617767], [87.76911926, 25.24665833], [87.76283264, 25.24928856], [87.73087311, 25.25315094], [87.72106171, 25.25344086], [87.70778656, 25.25640869], [87.70687103, 25.25978088], [87.70796967, 25.2713604], [87.70591736, 25.27457047], [87.70096588, 25.2777729], [87.69641113, 25.27886963], [87.69130707, 25.28139114], [87.68907166, 25.28494072], [87.69030762, 25.29121971], [87.69478607, 25.29541016], [87.69140625, 25.29860115], [87.6934967, 25.3030529], [87.68824005, 25.30476952], [87.6806488, 25.30427933], [87.68087006, 25.30767059], [87.68409729, 25.30805016], [87.6841507, 25.31013107], [87.65878296, 25.30973053], [87.6517868, 25.30724907], [87.6340332, 25.31235123], [87.63179016, 25.31186104], [87.62597656, 25.31861115], [87.6262207, 25.3157196], [87.62267303, 25.31080055], [87.61361694, 25.31553841], [87.60688019, 25.31138039], [87.59989166, 25.31466293], [87.58925629, 25.32188988], [87.5892868, 25.3237896], [87.5811615, 25.32803917], [87.58046722, 25.33232117], [87.58766174, 25.34054756], [87.5800705, 25.34839058], [87.57891846, 25.34678268], [87.57948303, 25.3439312], [87.57144165, 25.34050941], [87.56710815, 25.33389091], [87.5474472, 25.33094025], [87.54680634, 25.32365036], [87.54412079, 25.32290077], [87.54112244, 25.30425072], [87.53849792, 25.29623032], [87.53974915, 25.28161812], [87.53562927, 25.28010941], [87.52942657, 25.27961922], [87.52552032, 25.28098106], [87.51287079, 25.29214287], [87.49887085, 25.29228973], [87.49006653, 25.30520058], [87.48638153, 25.2960701], [87.48150635, 25.29517174], [87.48757935, 25.27761078], [87.49447632, 25.27543068], [87.49195862, 25.27143097], [87.49559021, 25.26530075], [87.49571991, 25.26247978], [87.49484253, 25.25969124], [87.48755646, 25.26199913], [87.47264099, 25.24088287], [87.47305298, 25.23143005], [87.47181702, 25.22237968], [87.47216034, 25.19466972], [87.46763611, 25.19314194], [87.46685791, 25.1956501], [87.46192932, 25.19515038], [87.45783234, 25.19779968], [87.45511627, 25.19750023], [87.41660309, 25.21491051], [87.40949249, 25.21513939], [87.40764618, 25.2190094], [87.40215302, 25.22141075], [87.3966217, 25.22571945], [87.39177704, 25.22751808], [87.38648224, 25.22570992], [87.38330078, 25.22347069], [87.37713623, 25.2226181], [87.37394714, 25.21853065], [87.36988831, 25.20504951], [87.36846161, 25.20689964], [87.35801697, 25.21121979], [87.35507965, 25.21340942], [87.34777832, 25.21317291], [87.33045197, 25.21706963], [87.33053589, 25.22219086], [87.32345581, 25.22309113], [87.31833649, 25.20124054], [87.315979, 25.19695091], [87.31574249, 25.19298935], [87.31711578, 25.18868065], [87.31601715, 25.18630028], [87.31064606, 25.16982079], [87.31301117, 25.16926003], [87.31437683, 25.16736984], [87.31503296, 25.16504097], [87.3143692, 25.16275978], [87.31041718, 25.16032982], [87.30963898, 25.1535511], [87.30797577, 25.15029144], [87.30229187, 25.14532089], [87.30171967, 25.14389992], [87.30343628, 25.14320946], [87.30239105, 25.14059067], [87.30342865, 25.13814163], [87.29988098, 25.13459015], [87.2979126, 25.13466072], [87.2932663, 25.11435127], [87.2948761, 25.11381912], [87.29486847, 25.1119194], [87.29280853, 25.10469055], [87.29535675, 25.09970093], [87.29110718, 25.08926964], [87.28560638, 25.09091949], [87.27488708, 25.09218979], [87.27024841, 25.09363937], [87.26444244, 25.09777832], [87.26307678, 25.10082054], [87.25875092, 25.10461044], [87.25055695, 25.10585022], [87.24923706, 25.1053791], [87.24533081, 25.09908104], [87.24106598, 25.10079956], [87.23986053, 25.0994606], [87.23387909, 25.08582115], [87.22708893, 25.08757019], [87.21795654, 25.08854294], [87.21563721, 25.09019089], [87.21135712, 25.08959961], [87.21071625, 25.08525085], [87.20832062, 25.08332062], [87.19986725, 25.07944107], [87.19747162, 25.07365036], [87.18776703, 25.06699944], [87.18431854, 25.06701088], [87.17664337, 25.06402016], [87.17384338, 25.05800247], [87.17325592, 25.05647087], [87.16847992, 25.0489502], [87.16503906, 25.04586983], [87.1649704, 25.04281998], [87.15834045, 25.03100014], [87.15232086, 25.02651978], [87.14904785, 25.0262394], [87.14676666, 25.02431107], [87.14420319, 25.01797104], [87.14388275, 25.01078987], [87.1444931, 25.00642967], [87.14597321, 25.00355911], [87.14647675, 24.9998703], [87.15368652, 24.99097061], [87.15299225, 24.9831295], [87.15203094, 24.97443962], [87.1519165, 24.96861267], [87.15258026, 24.96299934], [87.15075684, 24.95574951], [87.14877319, 24.94938087], [87.14859009, 24.9421196], [87.15213013, 24.93653107], [87.15531158, 24.93168068], [87.15461731, 24.92651749], [87.15268707, 24.9239502], [87.14971161, 24.92122269], [87.14762878, 24.9178009], [87.14650726, 24.91286278], [87.14774323, 24.9081707], [87.14877319, 24.90509033], [87.15023041, 24.90316963], [87.15432739, 24.90011024], [87.15695953, 24.89608955], [87.15822601, 24.88955116], [87.1581192, 24.88563156], [87.15653992, 24.88070107], [87.15453339, 24.87647057], [87.14964294, 24.87240028], [87.14792633, 24.86786842], [87.14733887, 24.86240768], [87.15168762, 24.86308098], [87.15097809, 24.85843086], [87.14451599, 24.8592205], [87.13881683, 24.85926056], [87.13273621, 24.85957909], [87.12980652, 24.85749054], [87.12731934, 24.85448265], [87.12333679, 24.8529911], [87.11915588, 24.85396957], [87.11447144, 24.85552979], [87.10949707, 24.85078812], [87.10604858, 24.84733009], [87.10462189, 24.84445953], [87.10240936, 24.83925819], [87.0996933, 24.83476067], [87.09754944, 24.82985115], [87.0949707, 24.82620049], [87.09121704, 24.82356071], [87.0877533, 24.82304192], [87.08423615, 24.82322121], [87.08036041, 24.8243618], [87.0785675, 24.82225037], [87.07730103, 24.81814194], [87.0776062, 24.81422043], [87.07713318, 24.81182098], [87.07730103, 24.80834961], [87.08078003, 24.80951118], [87.08138275, 24.80738068], [87.08345032, 24.80658913], [87.0863266, 24.80591011], [87.08886719, 24.8040905], [87.09072876, 24.80266953], [87.09395599, 24.80441093], [87.09660339, 24.80402756], [87.09667206, 24.80149269], [87.09568024, 24.79759979], [87.09288025, 24.79229164], [87.0912323, 24.78811073], [87.08804321, 24.78523827], [87.08560181, 24.7824707], [87.0828476, 24.77922821], [87.08254242, 24.7729702], [87.08254242, 24.76798248], [87.08339691, 24.76452065], [87.08486938, 24.7614994], [87.08631134, 24.75831985], [87.08508301, 24.75580978], [87.08309174, 24.7536602], [87.08097076, 24.75168991], [87.08120728, 24.75075912], [87.08161163, 24.74834061], [87.07982635, 24.74658966], [87.07646179, 24.74549103], [87.07454681, 24.74472046], [87.07359314, 24.7430706], [87.07398987, 24.74054909], [87.07636261, 24.7399292], [87.07576752, 24.73814964], [87.0756073, 24.73641968], [87.07704926, 24.73566055], [87.07847595, 24.73615074], [87.08040619, 24.73698044], [87.08132172, 24.73594284], [87.08119202, 24.73265076], [87.08138275, 24.72925949], [87.08235168, 24.72699928], [87.08185577, 24.72454071], [87.08029175, 24.7219696], [87.07772064, 24.71879959], [87.07660675, 24.71459961], [87.07367706, 24.7125206], [87.07264709, 24.7109108], [87.07125092, 24.70734978], [87.07138062, 24.70313072], [87.07087708, 24.69885063], [87.07063293, 24.69449997], [87.06932831, 24.69124985], [87.0670166, 24.68847275], [87.06381226, 24.68503952], [87.06131744, 24.68152046], [87.06017303, 24.67721939], [87.05892181, 24.67225075], [87.05473328, 24.67060089], [87.05532074, 24.66509056], [87.05475616, 24.66069031], [87.05237579, 24.65551186], [87.05101013, 24.64927101], [87.05039978, 24.64344025], [87.04881287, 24.63701057], [87.04580688, 24.63089752], [87.04440308, 24.62403107], [87.04592133, 24.62017059], [87.04670715, 24.61740112], [87.04673004, 24.61421013], [87.04834747, 24.61014938], [87.05046844, 24.60676956], [87.04463196, 24.60539818], [87.0430069, 24.60893059], [87.04086304, 24.61104965], [87.03872681, 24.6125412], [87.03671265, 24.61325073], [87.03592682, 24.61177063], [87.03497314, 24.61010933], [87.0326004, 24.60989761], [87.03011322, 24.60951996], [87.02751923, 24.60931969], [87.02643585, 24.61123276], [87.02646637, 24.61605072], [87.02635193, 24.62008286], [87.02435303, 24.62109947], [87.02144623, 24.61962128], [87.01670074, 24.61779976], [87.01558685, 24.61330032], [87.01291656, 24.60909271], [87.0102005, 24.6062603], [86.99260712, 24.61918068], [86.99014282, 24.62071037], [86.99008942, 24.62002945], [86.98815155, 24.6201992], [86.98549652, 24.62162971], [86.9801178, 24.62467003], [86.97119141, 24.63030052], [86.96556091, 24.63186836], [86.95842743, 24.62943077], [86.95347595, 24.62765121], [86.94550323, 24.62656021], [86.94474792, 24.63117027], [86.94754791, 24.63586807], [86.94861603, 24.64276123], [86.93884277, 24.64307022], [86.93009186, 24.64282036], [86.93344116, 24.63572121], [86.93605804, 24.63037109], [86.93414307, 24.62652016], [86.92926788, 24.62644005], [86.92386627, 24.62433052], [86.91893768, 24.61940956], [86.9189682, 24.61347961], [86.91786194, 24.61079025], [86.91001892, 24.60114288], [86.90895081, 24.59698868], [86.90467834, 24.59514046], [86.90123749, 24.5915699], [86.89807892, 24.58654022], [86.89795685, 24.58053017], [86.90065765, 24.57615089], [86.90322113, 24.57152939], [86.90122223, 24.56679916], [86.90635681, 24.56336975], [86.90644073, 24.55989075], [86.90650177, 24.55529976], [86.90629578, 24.54926109], [86.9071579, 24.54338074], [86.91117859, 24.53867912], [86.90583038, 24.54097176], [86.90117645, 24.54449272], [86.89842224, 24.54975128], [86.89308929, 24.55483818], [86.88672638, 24.55402946], [86.88414001, 24.5544796], [86.88398743, 24.56035805], [86.87909698, 24.56305122], [86.87639618, 24.56731987], [86.87320709, 24.56497955], [86.86949158, 24.56138039], [86.86161041, 24.56027031], [86.85745239, 24.55661011], [86.85463715, 24.55046082], [86.84710693, 24.55297089], [86.83880615, 24.55406952], [86.83869171, 24.55862045], [86.83857727, 24.56278038], [86.83705139, 24.56828117], [86.83152771, 24.56805038], [86.82559204, 24.56599998], [86.82147217, 24.56831932], [86.81825256, 24.56933975], [86.81358337, 24.56820107], [86.80871582, 24.56377029], [86.80499268, 24.56412125], [86.80029297, 24.5646019], [86.80018616, 24.56592941], [86.80033875, 24.56870079], [86.80120087, 24.57196808], [86.80322266, 24.57435989], [86.80761719, 24.57685089], [86.80625916, 24.58114052], [86.80488586, 24.58538055], [86.80446625, 24.59065056], [86.8057785, 24.5945015], [86.8017807, 24.59745979], [86.80018616, 24.59857941], [86.79866791, 24.60114288], [86.79808807, 24.60346985], [86.79749298, 24.60573959], [86.79660797, 24.60852051], [86.7943573, 24.61209106], [86.79184723, 24.61531067], [86.78560638, 24.61720085], [86.78585052, 24.61309242], [86.78736115, 24.61092949], [86.79032135, 24.60844994], [86.79251099, 24.60518074], [86.79429626, 24.60070038], [86.79437256, 24.59683037], [86.78690338, 24.59937096], [86.78647614, 24.60457993], [86.78407288, 24.61028099], [86.78085327, 24.61483955], [86.7771225, 24.61976051], [86.77519226, 24.61951065], [86.7755127, 24.61557961], [86.76912689, 24.61648178], [86.75405121, 24.61475945], [86.75086212, 24.61797905], [86.74459839, 24.60288048], [86.74565125, 24.58950043], [86.73950958, 24.58649254], [86.7350769, 24.58084106], [86.73158264, 24.57579994], [86.7186203, 24.57821274], [86.70990753, 24.57353973], [86.69536591, 24.5689106], [86.68663788, 24.57044029], [86.68151855, 24.5650692], [86.67767334, 24.56611252], [86.668396, 24.56064034], [86.65593719, 24.56319809], [86.64575958, 24.5672226], [86.64126587, 24.57611847], [86.63420105, 24.57667923], [86.62716675, 24.57962036], [86.61828613, 24.58449173], [86.61885834, 24.59469986], [86.60691833, 24.59435081], [86.60791779, 24.59931946], [86.60936737, 24.60192108], [86.60968018, 24.60252953], [86.60929871, 24.60741043], [86.60292053, 24.60506821], [86.59998322, 24.59949112], [86.59485626, 24.59707069], [86.58976746, 24.59268951], [86.58389282, 24.58531952], [86.58315277, 24.57278061], [86.57823944, 24.56787109], [86.56804657, 24.56279945], [86.56170654, 24.56311035], [86.55831909, 24.55928993], [86.55464172, 24.55927086], [86.55792999, 24.54847908], [86.5513382, 24.54342079], [86.54669189, 24.5350399], [86.54057312, 24.53662109], [86.53614807, 24.5364399], [86.53044891, 24.53293037], [86.52352905, 24.53574944], [86.50572205, 24.5177002], [86.49752808, 24.49797821], [86.49812317, 24.48727036], [86.49532318, 24.48527908], [86.49028015, 24.48437119], [86.49080658, 24.47875023], [86.48877716, 24.47426987], [86.48974609, 24.46760178], [86.48448944, 24.45882034], [86.49112701, 24.45405006], [86.49098969, 24.44695282], [86.49194336, 24.43930054], [86.48819733, 24.43386078], [86.48858643, 24.42500114], [86.48207855, 24.42498016], [86.4733963, 24.42276192], [86.46582794, 24.42188072], [86.46367645, 24.4185009], [86.46568298, 24.41378975], [86.46366882, 24.40775108], [86.46711731, 24.39516068], [86.46568298, 24.38500023], [86.46179962, 24.37672043], [86.45504761, 24.37396812], [86.45220947, 24.36862946], [86.44632721, 24.36844063], [86.4341507, 24.37685966], [86.43070221, 24.37613106], [86.42514801, 24.37811852], [86.41558838, 24.37920952], [86.40101624, 24.39627075], [86.3986969, 24.40028954], [86.38123322, 24.4123497], [86.37326813, 24.41585159], [86.36789703, 24.42424965], [86.36271667, 24.42679024], [86.35350037, 24.44206047], [86.35072327, 24.44371033], [86.34781647, 24.44049835], [86.33273315, 24.44019127], [86.31949615, 24.44016075], [86.31555939, 24.4439106], [86.30375671, 24.44483948], [86.29957581, 24.44898987], [86.2988205, 24.45426178], [86.30090332, 24.45680046], [86.27913666, 24.4620018], [86.28183746, 24.47047806], [86.28557587, 24.47680283], [86.29387665, 24.47643089], [86.29773712, 24.48252106], [86.29824066, 24.48899841], [86.30162811, 24.49353981], [86.30349731, 24.49827194], [86.30973053, 24.50636292], [86.31241608, 24.50847054], [86.31056213, 24.51382256], [86.30751801, 24.52635956], [86.30330658, 24.52773094], [86.3013382, 24.53197861], [86.3081665, 24.54083252], [86.30983734, 24.54734039], [86.30404663, 24.55829048], [86.30982208, 24.56310081], [86.30809784, 24.5657196], [86.31098938, 24.56818008], [86.31936646, 24.57445908], [86.318573, 24.57892036], [86.32269287, 24.58056068], [86.32286072, 24.58409119], [86.31223297, 24.58588028], [86.31005096, 24.58156013], [86.30166626, 24.58315086], [86.29263306, 24.58609009], [86.28835297, 24.58433914], [86.28040314, 24.58418083], [86.27378845, 24.58274841], [86.27612305, 24.57908058], [86.27688599, 24.57419968], [86.27348328, 24.57562065], [86.26970673, 24.57780075], [86.26625824, 24.58195114], [86.26413727, 24.57583809], [86.26152802, 24.57690048], [86.25747681, 24.58312988], [86.24855042, 24.58513069], [86.24288177, 24.59213829], [86.23874664, 24.59679985], [86.23026276, 24.60227013], [86.21737671, 24.61177063], [86.21656036, 24.60280037], [86.21570587, 24.59117126], [86.19493866, 24.58516121], [86.16565704, 24.58368111], [86.15696716, 24.58923912], [86.15226746, 24.59971046], [86.14463043, 24.60305977], [86.13329315, 24.60354042], [86.13076019, 24.60893059], [86.12558746, 24.61182022], [86.12322998, 24.61968994], [86.12200928, 24.62393188], [86.12185669, 24.63005066], [86.11824799, 24.64189148], [86.1231308, 24.64793015], [86.12631989, 24.65422058], [86.12848663, 24.66597939], [86.12594604, 24.67080116], [86.13002777, 24.6714592], [86.13359833, 24.67551041], [86.13201141, 24.6803894], [86.12909698, 24.69003105], [86.12444305, 24.70516014], [86.11863708, 24.71165085], [86.1159668, 24.7188797], [86.11094666, 24.72402763], [86.10929871, 24.73224068], [86.10553741, 24.73596954], [86.08657837, 24.74632072], [86.06318665, 24.75167084], [86.06041718, 24.74768066], [86.05503845, 24.74634933], [86.04270935, 24.74387169], [86.03907013, 24.74131966], [86.03681946, 24.74382973], [86.03601074, 24.74734116], [86.04154968, 24.74790001], [86.04535675, 24.75191116], [86.04984283, 24.75578117], [86.0530014, 24.76174927], [86.05288696, 24.76770973], [86.05264282, 24.77318954], [86.05058289, 24.77954102], [86.04788208, 24.77828979], [86.04305267, 24.77740097], [86.03897858, 24.77667046], [86.03443909, 24.77617073], [86.03179169, 24.77275276], [86.02778625, 24.77029037], [86.02275848, 24.76938057], [86.01967621, 24.76776123], [86.01397705, 24.7689991], [86.00956726, 24.76799965], [86.00611115, 24.76568031], [85.99997711, 24.75138092], [85.97725677, 24.74763107], [85.97589111, 24.74596977], [85.97271729, 24.73628998], [85.97016907, 24.73357964], [85.96613312, 24.73229027], [85.96064758, 24.7317009], [85.95030212, 24.73211861], [85.94270325, 24.73442078], [85.92767334, 24.7404995], [85.9209671, 24.74456024], [85.9105072, 24.75366974], [85.90457153, 24.76128006], [85.90168762, 24.76986122], [85.88717651, 24.78558922], [85.88967896, 24.79165077], [85.8777771, 24.80029106], [85.86402893, 24.80542946], [85.85381317, 24.80764008], [85.84194183, 24.80805969], [85.8272171, 24.80964279], [85.82257843, 24.80895042], [85.81803131, 24.80696106], [85.81260681, 24.79936028], [85.81066132, 24.79449844], [85.78572845, 24.79868126], [85.77923584, 24.80048943], [85.77723694, 24.7989502], [85.76940155, 24.8028717], [85.76859283, 24.80404091], [85.76879883, 24.80881119], [85.76544952, 24.81250954], [85.76074982, 24.81507111], [85.75827789, 24.81508827], [85.74727631, 24.81991959], [85.73674011, 24.82265091], [85.73500824, 24.82138252], [85.73252106, 24.81648254], [85.72978973, 24.80849075], [85.72830963, 24.80066109], [85.72296906, 24.79890823], [85.72099304, 24.7869606], [85.71231079, 24.78333282], [85.70980072, 24.7809906], [85.709198, 24.77563858], [85.70478058, 24.76883125], [85.70346832, 24.76349258], [85.70355988, 24.7574501], [85.70553589, 24.75162125], [85.70812988, 24.7476902], [85.70533752, 24.74005127], [85.70477295, 24.72872925], [85.70343781, 24.72537041], [85.69875336, 24.72106934], [85.69639587, 24.71725082], [85.6966629, 24.71347237], [85.6870575, 24.70089149], [85.67965698, 24.69376755], [85.6495285, 24.68704033], [85.64826202, 24.68188095], [85.65046692, 24.67924118], [85.65997314, 24.6747303], [85.65975952, 24.67031288], [85.66079712, 24.66757965], [85.66333008, 24.66471291], [85.66371918, 24.66098022], [85.66069794, 24.65060234], [85.66118622, 24.64664078], [85.66364288, 24.64447021], [85.66432953, 24.6410408], [85.66570282, 24.63626099], [85.66895294, 24.6305294], [85.67212677, 24.61940002], [85.670578, 24.59943008], [85.67238617, 24.59818077], [85.67352295, 24.59563065], [85.67324829, 24.59294128], [85.67031097, 24.5880928], [85.66470337, 24.58193016], [85.64427948, 24.57829094], [85.63279724, 24.58056068], [85.62198639, 24.58385849], [85.615448, 24.58292961], [85.60852051, 24.58503914], [85.60787964, 24.59078979], [85.59825134, 24.59757042], [85.59114075, 24.59705925], [85.58196259, 24.60009956], [85.57657623, 24.60301018], [85.56989288, 24.60021973], [85.56520081, 24.59666061], [85.56285095, 24.59127045], [85.56138611, 24.58366966], [85.56221771, 24.58098984], [85.56711578, 24.57822037], [85.56575775, 24.571661], [85.56829071, 24.56520081], [85.56445313, 24.56184959], [85.55658722, 24.56064034], [85.55625916, 24.55681992], [85.55461121, 24.55612946], [85.55233002, 24.5594101], [85.54380798, 24.56447983], [85.53901672, 24.56587029], [85.53679657, 24.56524086], [85.53646088, 24.56380081], [85.53820038, 24.56145096], [85.53987122, 24.5561409], [85.54035187, 24.55034828], [85.53646088, 24.53601074], [85.53418732, 24.53219032], [85.51830292, 24.52454948], [85.51481628, 24.52782822], [85.50435638, 24.52972984], [85.50241852, 24.53142929], [85.50319672, 24.53572273], [85.50254822, 24.5428791], [85.49997711, 24.54389], [85.49746704, 24.54688072], [85.49752045, 24.54850006], [85.49446106, 24.55061913], [85.48944092, 24.54915047], [85.48648071, 24.55075073], [85.4809494, 24.5481205], [85.47215271, 24.54779053], [85.45658875, 24.53921127], [85.44655609, 24.53997993], [85.44230652, 24.53944969], [85.44213104, 24.53938484], [85.43327332, 24.53607941], [85.42753601, 24.53729057], [85.411026, 24.54511261], [85.40661621, 24.54566193], [85.40305328, 24.54494095], [85.39517212, 24.54128075], [85.38860321, 24.53708076], [85.38336945, 24.53519058]]]]}}, {\\\"id\\\": \\\"5\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.7_1\\\", \\\"HASC_1\\\": \\\"IN.CT\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Chhattisgarh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -16.3, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1003.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1868.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -865.0, \\\"geo-id\\\": 5, \\\"hpm25_child_popweighted\\\": -204.4, \\\"hpm25_female_popweighted\\\": -235.0, \\\"hpm25_male_popweighted\\\": -169.2, \\\"location\\\": \\\"Chhattisgarh\\\", \\\"mort_apm25_6cod_mean_total\\\": 8728.0, \\\"mort_hpm25_6cod_mean_total\\\": -16566.0, \\\"mort_tpm25_6cod_mean_total\\\": -7838.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[80.98058319, 17.93985939], [80.98013306, 17.94326019], [80.97981262, 17.94573021], [80.97805786, 17.9496212], [80.9759903, 17.96291924], [80.97383881, 17.97681046], [80.9731369, 17.98635292], [80.97264099, 17.99317932], [80.97151947, 17.99736977], [80.9699173, 18.00305939], [80.96845245, 18.0118103], [80.96617126, 18.01859856], [80.96389771, 18.02444077], [80.96321106, 18.02816963], [80.96264648, 18.03117943], [80.96227264, 18.03153038], [80.96595764, 18.04346848], [80.96350098, 18.04977989], [80.95243835, 18.07188034], [80.94399261, 18.08102036], [80.94597626, 18.08424187], [80.94835663, 18.09127045], [80.94983673, 18.0983181], [80.94979858, 18.1036911], [80.94754791, 18.11683846], [80.94935608, 18.12318039], [80.96753693, 18.13799286], [80.97263336, 18.14355087], [80.97480011, 18.15192032], [80.97383881, 18.1583004], [80.97367859, 18.16814995], [80.96556854, 18.16835976], [80.95419312, 18.16698074], [80.94985962, 18.16422844], [80.94422913, 18.15709114], [80.93672943, 18.15480042], [80.93582153, 18.15253067], [80.93199158, 18.14941025], [80.9119873, 18.13850975], [80.90072632, 18.13467026], [80.89292908, 18.13445091], [80.88111877, 18.13253021], [80.8620224, 18.13266945], [80.86160278, 18.1364727], [80.86035156, 18.13750076], [80.85838318, 18.1391201], [80.8557663, 18.14293098], [80.85549927, 18.14501953], [80.85526276, 18.14678955], [80.8555069, 18.14915085], [80.85578918, 18.15168953], [80.85167694, 18.16835976], [80.85263062, 18.17850113], [80.85222626, 18.18348122], [80.84893799, 18.19318962], [80.84848022, 18.19594955], [80.84819794, 18.19765091], [80.84877777, 18.19919014], [80.84915924, 18.20021057], [80.85650635, 18.19842911], [80.86126709, 18.19869995], [80.86564636, 18.20099258], [80.86725616, 18.20318031], [80.86749268, 18.20725822], [80.86353302, 18.21718979], [80.86174774, 18.22167015], [80.85910034, 18.22600174], [80.8396225, 18.2280407], [80.83423615, 18.23328018], [80.82958984, 18.23411942], [80.82419586, 18.23357964], [80.81891632, 18.23098183], [80.81719208, 18.22521019], [80.81835175, 18.21903038], [80.81772614, 18.21276093], [80.81874847, 18.19202042], [80.81791687, 18.18712044], [80.81067657, 18.18325996], [80.81085205, 18.17847252], [80.79792786, 18.16629982], [80.79364014, 18.16546059], [80.78691864, 18.16418076], [80.76239777, 18.16296959], [80.75385284, 18.16389084], [80.74507141, 18.16483116], [80.73455811, 18.17171288], [80.73253632, 18.19419098], [80.73226166, 18.20545006], [80.73326874, 18.21879005], [80.75688934, 18.22949982], [80.76937866, 18.2364006], [80.7842865, 18.24327087], [80.78726959, 18.24656105], [80.78827667, 18.24978065], [80.78811646, 18.25403976], [80.78663635, 18.25591087], [80.78489685, 18.25809097], [80.78161621, 18.25958252], [80.77739716, 18.25974083], [80.77340698, 18.26493073], [80.76638031, 18.27823257], [80.76322174, 18.28172112], [80.76156616, 18.28210258], [80.75949097, 18.28256989], [80.75702667, 18.28470993], [80.7529068, 18.29127121], [80.75132751, 18.29747009], [80.74462128, 18.30218124], [80.7452774, 18.30508995], [80.74443817, 18.3168602], [80.74292755, 18.32216072], [80.73478699, 18.33868027], [80.72638702, 18.35025024], [80.72405243, 18.35737038], [80.72276306, 18.36131096], [80.72289276, 18.3642292], [80.72306824, 18.36790085], [80.72424316, 18.37198257], [80.7227478, 18.37580109], [80.71862793, 18.37924194], [80.71626282, 18.38294029], [80.71594238, 18.38552284], [80.71572876, 18.38729095], [80.72400665, 18.39524841], [80.72712708, 18.39999962], [80.72878265, 18.40380096], [80.72653961, 18.40899086], [80.72248077, 18.41032028], [80.71827698, 18.40979958], [80.71734619, 18.40908051], [80.71302795, 18.4057312], [80.69100952, 18.41934967], [80.69262695, 18.42885017], [80.69525909, 18.43457031], [80.69889069, 18.43600082], [80.69496918, 18.4407711], [80.69191742, 18.44045067], [80.68309021, 18.44462013], [80.68280029, 18.44716072], [80.68245697, 18.45001984], [80.6805191, 18.45355034], [80.67414856, 18.45631981], [80.67318726, 18.45831108], [80.67153168, 18.45973969], [80.66982269, 18.46121025], [80.66610718, 18.46264076], [80.66236115, 18.4657402], [80.65077972, 18.4722805], [80.64826202, 18.4790802], [80.64485168, 18.48351097], [80.63681793, 18.49394989], [80.63459015, 18.49863052], [80.63395691, 18.50125122], [80.63350677, 18.50315094], [80.63533783, 18.50572968], [80.63640594, 18.50723076], [80.63564301, 18.51158905], [80.63497925, 18.51531029], [80.63347626, 18.51761246], [80.6326828, 18.51884079], [80.62697601, 18.51816177], [80.62132263, 18.52312851], [80.61384583, 18.52605057], [80.61081696, 18.53353119], [80.60402679, 18.54071999], [80.60098267, 18.54503059], [80.5955658, 18.5490799], [80.58146667, 18.55745125], [80.56794739, 18.56145096], [80.56195068, 18.5695591], [80.55779266, 18.57275963], [80.54043579, 18.58295059], [80.53199768, 18.58605957], [80.53003693, 18.58879089], [80.52931976, 18.58980942], [80.52871704, 18.59284973], [80.52857208, 18.59370041], [80.52179718, 18.60075951], [80.518013, 18.60345078], [80.51525116, 18.6072998], [80.51383209, 18.6131382], [80.51071167, 18.61567116], [80.49812317, 18.61765289], [80.48838806, 18.62672043], [80.4834671, 18.62812042], [80.48204803, 18.62791824], [80.48005676, 18.62763977], [80.47218323, 18.62368965], [80.46774292, 18.62280083], [80.4630127, 18.6226902], [80.45524597, 18.62490273], [80.45020294, 18.6263504], [80.41755676, 18.61071968], [80.41599274, 18.60878754], [80.40703583, 18.60774994], [80.40209198, 18.60717964], [80.39325714, 18.60296059], [80.38939667, 18.59925842], [80.38558197, 18.59649086], [80.38156128, 18.59359932], [80.37052917, 18.60305977], [80.36695099, 18.6046505], [80.36251831, 18.60374069], [80.35972595, 18.60218048], [80.35749054, 18.59834099], [80.35594177, 18.59370995], [80.35289764, 18.59094048], [80.348526, 18.58848953], [80.34184265, 18.58644104], [80.33879089, 18.58820915], [80.33667755, 18.59052086], [80.33146667, 18.59659958], [80.31931305, 18.62173271], [80.31500244, 18.63628769], [80.30780792, 18.65228081], [80.29946136, 18.67921066], [80.29631042, 18.68564034], [80.28884125, 18.69500923], [80.27790833, 18.71096039], [80.27091217, 18.71350098], [80.26753998, 18.71796989], [80.25753784, 18.7312603], [80.25480652, 18.73613167], [80.24745178, 18.74355125], [80.24079895, 18.74868965], [80.23956299, 18.75221062], [80.2405014, 18.75661087], [80.24215698, 18.75974846], [80.24900055, 18.76525116], [80.25456238, 18.76595116], [80.26065063, 18.7650795], [80.26145172, 18.76497078], [80.26291656, 18.76428986], [80.26541901, 18.76316071], [80.27182007, 18.76222038], [80.27655029, 18.76485062], [80.27953339, 18.76785278], [80.29017639, 18.78625107], [80.29415894, 18.79059029], [80.29943848, 18.79353142], [80.30589294, 18.79434967], [80.31873322, 18.79598045], [80.33470154, 18.80611038], [80.34622192, 18.81108093], [80.34778595, 18.81594086], [80.34850311, 18.82394028], [80.34558105, 18.83393097], [80.33963776, 18.8483429], [80.33573151, 18.85611916], [80.32565308, 18.86996078], [80.3216629, 18.87483025], [80.31346893, 18.88117981], [80.30990601, 18.88480186], [80.30856323, 18.88616753], [80.29810333, 18.9004612], [80.29138947, 18.90759087], [80.27046967, 18.92491913], [80.26763916, 18.92878914], [80.26516724, 18.93456078], [80.26468658, 18.93732071], [80.26412964, 18.94052124], [80.26531982, 18.94699287], [80.26747894, 18.95257187], [80.26902008, 18.96416092], [80.26734924, 18.98067093], [80.26753235, 18.98396111], [80.26772308, 18.98732948], [80.27230835, 18.99744034], [80.28811646, 19.01393127], [80.29341125, 19.02159119], [80.29528809, 19.02873993], [80.2905426, 19.04001045], [80.28884125, 19.04628944], [80.29170227, 19.04980087], [80.30224609, 19.05554962], [80.31577301, 19.06458092], [80.31996155, 19.06940269], [80.32211304, 19.07487106], [80.32256317, 19.08216095], [80.31994629, 19.0882206], [80.32411957, 19.09493065], [80.33154297, 19.10107994], [80.3296814, 19.10741997], [80.32235718, 19.12022018], [80.32086182, 19.12449074], [80.32485199, 19.1415329], [80.3355484, 19.14756966], [80.33963013, 19.15302086], [80.34059143, 19.15891838], [80.34411621, 19.16180992], [80.34546661, 19.16291046], [80.36235809, 19.16932106], [80.37290192, 19.1751194], [80.38111115, 19.18073082], [80.38667297, 19.18902016], [80.38611603, 19.19563293], [80.37993622, 19.20870972], [80.37702179, 19.21736908], [80.37918091, 19.2326107], [80.38334656, 19.23913956], [80.38845062, 19.24331093], [80.39684296, 19.2462101], [80.40157318, 19.24682999], [80.40818024, 19.24770164], [80.41446686, 19.24918938], [80.41916656, 19.25028038], [80.42807007, 19.25438118], [80.43702698, 19.26107025], [80.44542694, 19.26988983], [80.45680237, 19.2991581], [80.46212769, 19.3081398], [80.46450043, 19.31395149], [80.46530151, 19.31591988], [80.47049713, 19.32892036], [80.47558594, 19.33504295], [80.48110199, 19.33782005], [80.5003891, 19.34129906], [80.50720978, 19.34359169], [80.51383972, 19.34819984], [80.51898193, 19.35400963], [80.52271271, 19.35975075], [80.52612305, 19.36721039], [80.53153992, 19.3743], [80.55934143, 19.39755249], [80.56781769, 19.40092087], [80.57084656, 19.39942169], [80.57286072, 19.39842033], [80.5839386, 19.37715912], [80.5847168, 19.3737011], [80.58226013, 19.36833954], [80.58558655, 19.35301971], [80.58862305, 19.34440041], [80.59266663, 19.3352108], [80.59568024, 19.33131981], [80.59851837, 19.3246727], [80.60006714, 19.31809044], [80.60394287, 19.31176949], [80.6101532, 19.30714035], [80.61772156, 19.30481911], [80.62549591, 19.30681038], [80.63530731, 19.3128376], [80.65788269, 19.32427979], [80.66439056, 19.32657814], [80.67189026, 19.32644844], [80.67922211, 19.32414055], [80.68419647, 19.32002831], [80.68528748, 19.31260109], [80.68180084, 19.29584122], [80.68356323, 19.28691101], [80.68860626, 19.28348923], [80.69374847, 19.28232193], [80.6987381, 19.28227043], [80.70043945, 19.2822628], [80.70918274, 19.28330994], [80.7183075, 19.28549957], [80.73065948, 19.28403091], [80.73673248, 19.2869606], [80.7434082, 19.28597069], [80.74923706, 19.28674126], [80.75505066, 19.2952404], [80.75974274, 19.29975128], [80.76397705, 19.30527115], [80.7661972, 19.30813026], [80.77809143, 19.31854057], [80.78246307, 19.3217411], [80.78790283, 19.32411194], [80.7950058, 19.32476044], [80.79934692, 19.32516289], [80.80282593, 19.33228111], [80.80634308, 19.33490944], [80.81282806, 19.33813095], [80.81649017, 19.34247017], [80.82641602, 19.34803963], [80.83908081, 19.35515022], [80.84500885, 19.36091042], [80.84282684, 19.36610985], [80.83499908, 19.37068176], [80.8232193, 19.3747406], [80.815979, 19.37907028], [80.81273651, 19.38274002], [80.80854797, 19.39703941], [80.79795074, 19.4116497], [80.79538727, 19.4187603], [80.79244995, 19.42266083], [80.78793335, 19.42670059], [80.79432678, 19.42876816], [80.80799866, 19.43161964], [80.82524872, 19.43912125], [80.83508301, 19.44238091], [80.85748291, 19.44254112], [80.86749268, 19.44346046], [80.87599945, 19.44795036], [80.88562775, 19.45650291], [80.89206696, 19.46568108], [80.89215851, 19.4815197], [80.8914032, 19.49084091], [80.88970184, 19.49925041], [80.88553619, 19.50925064], [80.87905121, 19.51902962], [80.87359619, 19.52235031], [80.86334991, 19.52194977], [80.85225677, 19.52416992], [80.84538269, 19.5291729], [80.84082794, 19.53357124], [80.83737946, 19.54063034], [80.83605194, 19.54898071], [80.83352661, 19.55597115], [80.8276062, 19.56267166], [80.8196106, 19.56540108], [80.80922699, 19.56451035], [80.78515625, 19.56040955], [80.76641083, 19.56831932], [80.76503754, 19.57426071], [80.76426697, 19.58483124], [80.75795746, 19.59017181], [80.72099304, 19.60839081], [80.7077713, 19.61045837], [80.69668579, 19.61083031], [80.6830368, 19.61060905], [80.66203308, 19.60873032], [80.65685272, 19.61226082], [80.65589142, 19.6169796], [80.6561203, 19.62515068], [80.66220093, 19.66258049], [80.66538239, 19.67296982], [80.666008, 19.68626976], [80.66455078, 19.69075012], [80.66584015, 19.69221115], [80.66133881, 19.69750023], [80.64563751, 19.7064991], [80.64029694, 19.71245956], [80.63350677, 19.7184906], [80.62020874, 19.72377014], [80.61313629, 19.72892952], [80.59033203, 19.73443031], [80.58207703, 19.73807144], [80.57868195, 19.74392128], [80.57052612, 19.75473976], [80.56765747, 19.75667953], [80.55021667, 19.76455116], [80.53967285, 19.77459908], [80.53887177, 19.78070259], [80.54244232, 19.79424286], [80.54194641, 19.80315018], [80.54424286, 19.8112011], [80.54242706, 19.81927109], [80.5353775, 19.81813049], [80.51780701, 19.82886124], [80.50750732, 19.82994843], [80.49839783, 19.82947159], [80.4907074, 19.82536125], [80.47602844, 19.82800102], [80.46916199, 19.82466125], [80.45954895, 19.8113308], [80.46290588, 19.80575943], [80.47480774, 19.8033905], [80.47714233, 19.80122948], [80.48023987, 19.79544067], [80.48207092, 19.78950119], [80.4825592, 19.78071022], [80.47808838, 19.77240944], [80.46679688, 19.78487968], [80.46176147, 19.7882328], [80.45243835, 19.79290009], [80.44953918, 19.79265976], [80.44270325, 19.7905407], [80.43579102, 19.79185104], [80.42900848, 19.7951107], [80.41768646, 19.79714012], [80.40014648, 19.7936306], [80.39470673, 19.79457855], [80.39842987, 19.80319023], [80.3975296, 19.81623077], [80.40497589, 19.81542015], [80.41731262, 19.8091507], [80.42459106, 19.80804062], [80.43165588, 19.81030083], [80.44696808, 19.82032013], [80.45511627, 19.82379913], [80.46029663, 19.82802963], [80.46363068, 19.8358326], [80.46861267, 19.83753014], [80.47103119, 19.8426609], [80.47502136, 19.85705948], [80.48764038, 19.86512947], [80.49752045, 19.86874962], [80.4969101, 19.8771801], [80.49166107, 19.89053917], [80.48983765, 19.89367294], [80.48265076, 19.89889908], [80.46895599, 19.90336037], [80.46121979, 19.90343094], [80.45278931, 19.90000916], [80.44444275, 19.89355087], [80.43579865, 19.89551926], [80.43100739, 19.8984108], [80.41474915, 19.90291977], [80.4076767, 19.90590286], [80.40265656, 19.90960121], [80.40577698, 19.92545128], [80.40629578, 19.93250084], [80.40931702, 19.93538094], [80.42059326, 19.93622971], [80.42510986, 19.93730927], [80.43100739, 19.94094086], [80.43855286, 19.9471302], [80.4437027, 19.95267105], [80.45300293, 19.94523811], [80.46450043, 19.94625092], [80.46875, 19.94026947], [80.469841, 19.93366051], [80.47289276, 19.93124962], [80.48047638, 19.92780113], [80.5017395, 19.92475128], [80.50875092, 19.92591095], [80.52037811, 19.93087959], [80.52600861, 19.94112015], [80.52628326, 19.94862747], [80.53383636, 19.95302963], [80.53237152, 19.96706009], [80.53473663, 19.97092056], [80.53775787, 19.97356033], [80.54415131, 19.98151016], [80.54554749, 19.98718071], [80.54353333, 19.99508286], [80.53994751, 19.99772072], [80.53578949, 19.99991989], [80.53253937, 20.00393295], [80.53542328, 20.01120949], [80.54158783, 20.03722191], [80.54109192, 20.04818916], [80.54522705, 20.05957031], [80.54615784, 20.06571007], [80.54183197, 20.07668114], [80.53495789, 20.08539963], [80.53523254, 20.09218025], [80.54125214, 20.10494995], [80.54036713, 20.10983276], [80.53575897, 20.11384964], [80.52880859, 20.11750031], [80.52668762, 20.12137985], [80.52359009, 20.12447166], [80.51815033, 20.12683105], [80.51053619, 20.12693024], [80.50358582, 20.1287899], [80.49803162, 20.13891983], [80.4911499, 20.14147949], [80.48293304, 20.13788986], [80.47730255, 20.13853073], [80.46678162, 20.14268112], [80.45865631, 20.14455032], [80.45133972, 20.14487076], [80.44787598, 20.14157104], [80.44413757, 20.13034248], [80.4396286, 20.12911987], [80.4319458, 20.13134003], [80.42695618, 20.13023949], [80.40149689, 20.13951111], [80.39383698, 20.14402008], [80.38762665, 20.15158081], [80.38456726, 20.15851021], [80.38601685, 20.16280937], [80.39045715, 20.16627121], [80.39190674, 20.17073059], [80.39279938, 20.17740059], [80.39459229, 20.18158913], [80.39827728, 20.18344116], [80.40406036, 20.1844101], [80.41340637, 20.18753052], [80.41398621, 20.19023132], [80.41201782, 20.20220947], [80.40982056, 20.20528984], [80.39800262, 20.21278], [80.38803864, 20.23061943], [80.38295746, 20.2417202], [80.3862381, 20.24461174], [80.40371704, 20.24769974], [80.4090271, 20.24913025], [80.41526794, 20.25229073], [80.4196167, 20.25156021], [80.42294312, 20.25260925], [80.43730927, 20.25847816], [80.44838715, 20.26388168], [80.45646667, 20.26890945], [80.46544647, 20.2716217], [80.47587585, 20.27368927], [80.49447632, 20.27479935], [80.51082611, 20.26961136], [80.52667999, 20.2847805], [80.53582001, 20.29467964], [80.53930664, 20.30039024], [80.54202271, 20.30684853], [80.55158234, 20.31153107], [80.58423615, 20.3192997], [80.60542297, 20.32019043], [80.60671234, 20.32534981], [80.61669159, 20.32574081], [80.61776733, 20.33368111], [80.61667633, 20.33761024], [80.61071014, 20.34526062], [80.61149597, 20.34934235], [80.60601044, 20.35642052], [80.60620117, 20.36079025], [80.60513306, 20.36615944], [80.60089874, 20.36919022], [80.60072327, 20.37260056], [80.60222626, 20.37644005], [80.5983963, 20.38068008], [80.59017181, 20.38434982], [80.58744049, 20.38789177], [80.58598328, 20.39204979], [80.58602142, 20.39561081], [80.58651733, 20.40072823], [80.5897522, 20.41277122], [80.59173584, 20.41505051], [80.5944519, 20.42070961], [80.5998764, 20.42692184], [80.60343933, 20.43325043], [80.60144806, 20.4373703], [80.59715271, 20.44207001], [80.59468842, 20.44642067], [80.60166931, 20.45726013], [80.60331726, 20.46241951], [80.60494232, 20.48115158], [80.60620117, 20.48707008], [80.6072464, 20.50391006], [80.60688782, 20.51254082], [80.60852814, 20.51620293], [80.61003113, 20.53198051], [80.61273956, 20.53726006], [80.61341095, 20.54157066], [80.61029816, 20.5450592], [80.61178589, 20.55096054], [80.6099472, 20.55632973], [80.6121521, 20.55958939], [80.61707306, 20.56223106], [80.61972046, 20.56731987], [80.61424255, 20.576931], [80.61746979, 20.58103752], [80.61460876, 20.58527184], [80.61286163, 20.59057808], [80.61949158, 20.59791946], [80.62232208, 20.60386276], [80.61767578, 20.60617065], [80.60896301, 20.60598946], [80.60256958, 20.60738945], [80.59246826, 20.61309814], [80.58573151, 20.61415291], [80.57866669, 20.61412048], [80.56730652, 20.61240768], [80.55903625, 20.60997963], [80.55140686, 20.59907913], [80.52983093, 20.59008026], [80.51950836, 20.58468056], [80.51190186, 20.58511925], [80.50009918, 20.58686256], [80.49717712, 20.59580994], [80.49291229, 20.60408974], [80.48419189, 20.61195946], [80.4815979, 20.61709976], [80.48095703, 20.62355042], [80.48159027, 20.62976265], [80.48484802, 20.63517952], [80.48964691, 20.6398983], [80.50203705, 20.6491909], [80.50760651, 20.65460014], [80.51891327, 20.66176033], [80.5255661, 20.66319084], [80.53742218, 20.66402054], [80.54738617, 20.67126083], [80.55271149, 20.67308998], [80.56680298, 20.67292976], [80.57279205, 20.6742897], [80.57833862, 20.67877007], [80.58011627, 20.68364143], [80.5792923, 20.68997955], [80.57772064, 20.69407082], [80.57492065, 20.69842911], [80.56394958, 20.70718956], [80.56018829, 20.71177292], [80.55587006, 20.72257042], [80.55454254, 20.74715042], [80.55200958, 20.75345039], [80.54817963, 20.75908089], [80.54553223, 20.76536942], [80.54545593, 20.78227806], [80.54334259, 20.79179955], [80.54569244, 20.80137253], [80.54889679, 20.80841064], [80.55076599, 20.81546021], [80.55589294, 20.81968117], [80.55478668, 20.82942009], [80.55036926, 20.8456707], [80.55060577, 20.85991096], [80.54891205, 20.86808968], [80.54975891, 20.88891029], [80.54618835, 20.90307999], [80.53910065, 20.92106056], [80.53813171, 20.9260807], [80.5418396, 20.93391991], [80.5352478, 20.93132019], [80.52641296, 20.93210983], [80.51062012, 20.92880058], [80.50067902, 20.92891121], [80.4912796, 20.92785072], [80.48274994, 20.92847061], [80.47392273, 20.92736053], [80.46531677, 20.92728806], [80.45909119, 20.92815018], [80.45555878, 20.93210983], [80.45658875, 20.93724823], [80.4487915, 20.94530106], [80.448349, 20.95101166], [80.4437561, 20.96103287], [80.44069672, 20.96545982], [80.43894196, 20.97155952], [80.43808746, 20.99209976], [80.43334198, 20.99975014], [80.42948914, 21.00263977], [80.42662811, 21.00505066], [80.42475128, 21.00733948], [80.42375946, 21.00959015], [80.42758179, 21.01246071], [80.42881012, 21.01357079], [80.43010712, 21.01635933], [80.43247223, 21.01713181], [80.43454742, 21.01923943], [80.43596649, 21.02205086], [80.43675995, 21.02501106], [80.43860626, 21.02717018], [80.44085693, 21.02800941], [80.44325256, 21.02918816], [80.44523621, 21.03094292], [80.4465332, 21.03362083], [80.44734192, 21.03662109], [80.44754791, 21.03961945], [80.44734955, 21.04076195], [80.44706726, 21.04432106], [80.44786835, 21.04687119], [80.44850159, 21.04961014], [80.44822693, 21.05196953], [80.44763184, 21.05448914], [80.44727325, 21.0566597], [80.44610596, 21.05998993], [80.44474792, 21.06158066], [80.44399261, 21.06324005], [80.44297791, 21.06592941], [80.44259644, 21.06698036], [80.44097137, 21.07040024], [80.44261169, 21.07246017], [80.44275665, 21.07419014], [80.44254303, 21.07743073], [80.4420166, 21.08060074], [80.44095612, 21.08325195], [80.44000244, 21.08531952], [80.43813324, 21.08880806], [80.43640137, 21.09271049], [80.43550873, 21.09518051], [80.43331909, 21.0971508], [80.43419647, 21.09802246], [80.43518066, 21.09901047], [80.4360733, 21.10104752], [80.4367218, 21.10267067], [80.43766022, 21.10453033], [80.43872833, 21.10696983], [80.4390564, 21.10917091], [80.43950653, 21.11178017], [80.44226074, 21.11186981], [80.44371796, 21.11165047], [80.44550323, 21.11125946], [80.44696045, 21.1110611], [80.44924927, 21.11194038], [80.44933319, 21.114851], [80.44914246, 21.11531067], [80.44822693, 21.1162796], [80.44618988, 21.11816978], [80.44387054, 21.11925125], [80.44037628, 21.12030983], [80.43865204, 21.12140083], [80.44072723, 21.12547112], [80.44246674, 21.12816048], [80.44402313, 21.13060951], [80.44602966, 21.13578033], [80.44696045, 21.13814926], [80.44821167, 21.14152908], [80.44921875, 21.14442825], [80.45009613, 21.14691925], [80.45157623, 21.14965057], [80.45281982, 21.15434074], [80.45391846, 21.15862274], [80.45400238, 21.16174126], [80.45426941, 21.1654377], [80.45526886, 21.16908073], [80.45729828, 21.17284012], [80.46163177, 21.17282104], [80.46418762, 21.17209053], [80.46784973, 21.17148972], [80.4733429, 21.17131042], [80.47490692, 21.17143059], [80.47709656, 21.17307091], [80.47943878, 21.17493057], [80.48181152, 21.17657089], [80.48600006, 21.17719078], [80.48953247, 21.17756081], [80.49230957, 21.17994118], [80.49549866, 21.18325806], [80.49787903, 21.18403244], [80.49989319, 21.18404007], [80.50257111, 21.18330956], [80.50453186, 21.18304062], [80.50763702, 21.18244171], [80.50932312, 21.18347931], [80.5103302, 21.18649101], [80.51081085, 21.18890953], [80.5115509, 21.19111061], [80.51316833, 21.19361115], [80.51480103, 21.1960392], [80.51624298, 21.19829941], [80.51822662, 21.20108032], [80.52073669, 21.2035408], [80.52501678, 21.2026329], [80.5279007, 21.20202065], [80.53045654, 21.20084], [80.532341, 21.20022011], [80.53498077, 21.19960976], [80.53888702, 21.19928932], [80.54187775, 21.19919014], [80.54351044, 21.20001984], [80.54656982, 21.20066833], [80.54930115, 21.20098114], [80.55063629, 21.20117188], [80.55367279, 21.20251083], [80.55779266, 21.20393944], [80.56124115, 21.20581055], [80.56402588, 21.20802116], [80.56611633, 21.21027946], [80.56661224, 21.21080971], [80.56842804, 21.21388245], [80.57183838, 21.21685028], [80.57483673, 21.21825981], [80.57810211, 21.21990013], [80.5815506, 21.22177124], [80.58447266, 21.22306061], [80.58938599, 21.22471046], [80.5923233, 21.22484016], [80.59622192, 21.22453117], [80.59889984, 21.22512817], [80.60099792, 21.22618294], [80.60344696, 21.22742271], [80.60507965, 21.22875977], [80.60608673, 21.22997093], [80.60766602, 21.23125076], [80.60868835, 21.23179054], [80.61048889, 21.23329163], [80.61170959, 21.23456955], [80.61344147, 21.23682976], [80.61572266, 21.24002075], [80.62010193, 21.24236107], [80.62464142, 21.2442894], [80.62767029, 21.24570084], [80.6322403, 21.24729919], [80.63530731, 21.25013924], [80.63735962, 21.25269127], [80.63873291, 21.25478172], [80.63948059, 21.25749969], [80.64111328, 21.26143074], [80.64190674, 21.26442909], [80.64264679, 21.2690506], [80.64340973, 21.27229118], [80.64488983, 21.27600288], [80.64676666, 21.27814293], [80.64862061, 21.28017044], [80.65080261, 21.28158951], [80.65215302, 21.28325272], [80.65368652, 21.28604126], [80.65480804, 21.28951073], [80.65808868, 21.28940964], [80.6608963, 21.28977966], [80.66332245, 21.29095078], [80.66526794, 21.29229164], [80.66828918, 21.29399109], [80.67095947, 21.29590988], [80.67295074, 21.29828835], [80.67308807, 21.30117989], [80.67237091, 21.30588913], [80.67378998, 21.30908012], [80.67273712, 21.31126976], [80.67095184, 21.31228065], [80.6680603, 21.31381989], [80.66699982, 21.31618118], [80.66654205, 21.3193512], [80.66559601, 21.32211113], [80.66355896, 21.32485962], [80.66239929, 21.32612038], [80.65986633, 21.32777023], [80.6579361, 21.3293705], [80.65653229, 21.3307724], [80.65991211, 21.3344326], [80.66130066, 21.33547974], [80.66291809, 21.3373394], [80.66494751, 21.34093285], [80.66638184, 21.34428978], [80.66845703, 21.34856987], [80.66998291, 21.35423088], [80.67150879, 21.35856056], [80.67517853, 21.36355019], [80.67827606, 21.36623001], [80.68097687, 21.36919022], [80.68416595, 21.37261009], [80.68583679, 21.37683105], [80.68781281, 21.38008118], [80.68946838, 21.3842392], [80.69165039, 21.38818169], [80.69326782, 21.3937912], [80.69335175, 21.39817047], [80.69287109, 21.40145111], [80.69507599, 21.4057312], [80.69706726, 21.40858078], [80.69814301, 21.41117859], [80.6992569, 21.41411972], [80.6985321, 21.41913033], [80.69764709, 21.42259026], [80.69754791, 21.42719841], [80.69904327, 21.42974091], [80.70162964, 21.43138123], [80.70423126, 21.43365288], [80.70818329, 21.43621063], [80.71209717, 21.43942833], [80.71482086, 21.44226074], [80.71803284, 21.44540024], [80.72120667, 21.44940186], [80.72392273, 21.45317078], [80.72624207, 21.45786095], [80.72770691, 21.46329117], [80.72911072, 21.46825981], [80.73021698, 21.47205162], [80.72891235, 21.47460175], [80.72824097, 21.4769001], [80.72727203, 21.48074913], [80.72583771, 21.48437119], [80.72426605, 21.48794174], [80.72233582, 21.49081039], [80.72197723, 21.4956398], [80.72377014, 21.49871063], [80.72464752, 21.50223923], [80.72429657, 21.50597954], [80.72426605, 21.50926018], [80.72437286, 21.51185989], [80.72442627, 21.51619148], [80.72477722, 21.51825905], [80.72583008, 21.52218819], [80.72702026, 21.52536964], [80.72833252, 21.52813911], [80.72988129, 21.53144836], [80.7308197, 21.53543091], [80.73065948, 21.53872108], [80.72972107, 21.54002953], [80.72807312, 21.54180908], [80.72583771, 21.54421043], [80.72412109, 21.54673958], [80.72087097, 21.5506897], [80.71935272, 21.55200005], [80.71492767, 21.55455971], [80.71354675, 21.55571175], [80.71383667, 21.55865097], [80.7151413, 21.5615406], [80.71608734, 21.56311035], [80.71723938, 21.56501961], [80.71922302, 21.56814957], [80.71953583, 21.57150078], [80.71884918, 21.57356071], [80.71821594, 21.57476807], [80.71689606, 21.57740974], [80.71598053, 21.57953072], [80.71369934, 21.58130074], [80.71253204, 21.58216095], [80.71164703, 21.58319092], [80.70955658, 21.58478928], [80.70923615, 21.58675003], [80.70913696, 21.58980942], [80.70905304, 21.59238815], [80.70915985, 21.59447289], [80.70935059, 21.59810066], [80.70903015, 21.60075951], [80.70939636, 21.60398102], [80.71083832, 21.60624123], [80.71351624, 21.60741043], [80.71617126, 21.60956955], [80.71781158, 21.61246109], [80.71990967, 21.61461067], [80.7216568, 21.61721992], [80.72138977, 21.62050056], [80.72245789, 21.62276077], [80.72210693, 21.62500191], [80.72117615, 21.62783051], [80.72097015, 21.63047028], [80.72025299, 21.63422012], [80.71968842, 21.63582039], [80.71955872, 21.63663292], [80.72049713, 21.64067078], [80.71910858, 21.64365959], [80.71684265, 21.64427948], [80.71463776, 21.64495087], [80.71235657, 21.64613914], [80.71121979, 21.64907074], [80.71045685, 21.65241051], [80.71050262, 21.65369034], [80.70979309, 21.65615082], [80.70909882, 21.65815926], [80.70833588, 21.66098976], [80.7078476, 21.6619606], [80.70749664, 21.66410065], [80.70944977, 21.66571045], [80.71003723, 21.66773987], [80.70874023, 21.66934967], [80.70735168, 21.67158127], [80.70923615, 21.67361069], [80.71089172, 21.67408943], [80.71190643, 21.67485046], [80.712883, 21.67584038], [80.71408844, 21.67728043], [80.71510315, 21.67867088], [80.71631622, 21.68081093], [80.71781921, 21.68307114], [80.71877289, 21.68481064], [80.72027588, 21.6877594], [80.72212982, 21.69059944], [80.72374725, 21.69360161], [80.72492218, 21.69777107], [80.72511292, 21.69828987], [80.72529602, 21.70100021], [80.72490692, 21.70433044], [80.72390747, 21.70583153], [80.72200775, 21.70730972], [80.7197113, 21.7097702], [80.71852875, 21.71186066], [80.7199173, 21.71364021], [80.72267151, 21.71447945], [80.72312927, 21.71562004], [80.72341919, 21.71747017], [80.72387695, 21.71970749], [80.72445679, 21.72249031], [80.72570801, 21.72578049], [80.72580719, 21.72948074], [80.72632599, 21.73102951], [80.72891235, 21.73516083], [80.73101044, 21.73919868], [80.73483276, 21.74764061], [80.73699951, 21.75065041], [80.73841858, 21.75354004], [80.74005127, 21.75649071], [80.74297333, 21.75796127], [80.74503326, 21.75826073], [80.74962616, 21.75773048], [80.75463867, 21.75700951], [80.75874329, 21.75715065], [80.76210022, 21.75791931], [80.76641846, 21.75513077], [80.76982117, 21.75205231], [80.7738266, 21.74982071], [80.77683258, 21.74430847], [80.77709198, 21.74086189], [80.78272247, 21.73957062], [80.78845978, 21.7412796], [80.79258728, 21.74322128], [80.79582977, 21.74427032], [80.79899597, 21.74535179], [80.80362701, 21.74605942], [80.80813599, 21.74644089], [80.811203, 21.74749184], [80.8116684, 21.7508297], [80.81033325, 21.75538063], [80.81044769, 21.75844002], [80.8106308, 21.7610302], [80.81156158, 21.7639904], [80.81355286, 21.76749992], [80.81446075, 21.76832008], [80.81682587, 21.77421761], [80.8182373, 21.77601051], [80.81918335, 21.77815819], [80.82041931, 21.78226089], [80.82081604, 21.78478813], [80.82110596, 21.78697968], [80.82388306, 21.79091072], [80.82550049, 21.79450035], [80.82797241, 21.79682159], [80.82990265, 21.80070114], [80.83170319, 21.80480957], [80.83171082, 21.80867004], [80.83183289, 21.81057167], [80.83238983, 21.81380081], [80.83304596, 21.81691933], [80.83380127, 21.8202095], [80.83558655, 21.82454109], [80.83660126, 21.82719994], [80.837677, 21.82985115], [80.83709717, 21.83176041], [80.83587646, 21.83214951], [80.83368683, 21.83479118], [80.83280945, 21.83749962], [80.83230591, 21.84013939], [80.8316803, 21.8461895], [80.83289337, 21.8490696], [80.8343277, 21.85069847], [80.837677, 21.8518219], [80.84041595, 21.85276031], [80.84117126, 21.85645294], [80.83994293, 21.85881042], [80.83702087, 21.86248016], [80.83666229, 21.86701965], [80.83763885, 21.86881256], [80.8396759, 21.87158012], [80.83959198, 21.87540054], [80.83660126, 21.87854958], [80.83406067, 21.88249969], [80.83141327, 21.88427925], [80.83010864, 21.88479042], [80.82543945, 21.88665009], [80.82405853, 21.88936043], [80.82422638, 21.89103127], [80.82456207, 21.89470863], [80.82380676, 21.89788055], [80.82544708, 21.90388107], [80.82453156, 21.9084301], [80.82620239, 21.9119606], [80.82699585, 21.91358185], [80.83006287, 21.91843033], [80.83139038, 21.92012024], [80.83251953, 21.92175102], [80.83452606, 21.92601967], [80.83589935, 21.92793083], [80.83654022, 21.93180084], [80.83656311, 21.93565941], [80.83561707, 21.93703079], [80.83502197, 21.94089127], [80.83338928, 21.94664001], [80.83184814, 21.9474411], [80.83074188, 21.94719124], [80.8289566, 21.94701958], [80.82627106, 21.94711113], [80.82338715, 21.94732094], [80.82221985, 21.94835091], [80.82115936, 21.95058823], [80.82102966, 21.95145035], [80.81958771, 21.95356941], [80.8184433, 21.95679092], [80.82022095, 21.95813179], [80.82168579, 21.95819855], [80.8245163, 21.95684052], [80.82885742, 21.95743942], [80.83178711, 21.95794106], [80.83583832, 21.95761108], [80.83938599, 21.95774078], [80.8433609, 21.95841026], [80.84577179, 21.96089935], [80.84673309, 21.96362114], [80.84745026, 21.96690941], [80.84851074, 21.97001076], [80.85037231, 21.97281075], [80.8516922, 21.97512054], [80.85253143, 21.97841072], [80.85309601, 21.98129272], [80.85312653, 21.98348045], [80.85456848, 21.9872303], [80.85546875, 21.98880959], [80.85640717, 21.99185181], [80.85719299, 21.99324036], [80.85840607, 21.99543953], [80.85929871, 21.99776077], [80.85933685, 22.0001297], [80.86859894, 22.01120949], [80.86950684, 22.01650047], [80.86894989, 22.03359032], [80.87011719, 22.03858948], [80.87735748, 22.05071259], [80.87663269, 22.0567894], [80.87895966, 22.06060028], [80.88498688, 22.06071091], [80.88844299, 22.06241035], [80.89122772, 22.06595993], [80.8947525, 22.07650948], [80.89817047, 22.1013298], [80.90608978, 22.11444092], [80.9108429, 22.1191597], [80.9171524, 22.12088966], [80.92479706, 22.12067032], [80.93891907, 22.11901093], [80.94552612, 22.11748123], [80.95052338, 22.11301041], [80.95752716, 22.0971508], [80.96553802, 22.08197975], [80.96573639, 22.07917023], [80.96208954, 22.0619297], [80.96341705, 22.05836105], [80.97181702, 22.05429077], [80.97364044, 22.05177116], [80.97885132, 22.04831123], [80.98259735, 22.04895973], [80.98776245, 22.04847908], [80.98808289, 22.05220985], [80.98972321, 22.05649757], [80.99117279, 22.05808067], [80.99282074, 22.05766106], [80.99916077, 22.06150055], [81.00427246, 22.07002068], [80.99742889, 22.08086967], [80.99991608, 22.08965111], [81.00395203, 22.0944519], [81.00369263, 22.0968895], [81.00006866, 22.10083008], [80.99282074, 22.10519028], [80.99027252, 22.10907936], [80.98725128, 22.11065102], [80.98020935, 22.11280823], [80.97666931, 22.11280823], [80.97432709, 22.11136055], [80.97226715, 22.11189079], [80.97081757, 22.11465073], [80.97175598, 22.12148094], [80.97342682, 22.12368965], [80.98670197, 22.13087082], [80.992836, 22.13153076], [81.00517273, 22.13272285], [81.01579285, 22.1327095], [81.01740265, 22.14027977], [81.01761627, 22.15384865], [81.0190506, 22.16526031], [81.01715088, 22.17103958], [81.01328278, 22.17749023], [81.01169586, 22.18400955], [81.01551056, 22.18840981], [81.02150726, 22.18703079], [81.02511597, 22.18882179], [81.02477264, 22.19313049], [81.02575684, 22.19769096], [81.02349091, 22.20282936], [81.01922607, 22.20779037], [81.01579285, 22.21410942], [81.01570892, 22.22021103], [81.01944733, 22.22919083], [81.03631592, 22.23771858], [81.04043579, 22.24057007], [81.04886627, 22.24419022], [81.05452728, 22.24387169], [81.06282043, 22.24685287], [81.06923676, 22.24625969], [81.07258606, 22.24174118], [81.08467865, 22.24674988], [81.09178162, 22.26786041], [81.09681702, 22.2774601], [81.11384583, 22.29438019], [81.11501312, 22.30323982], [81.11470032, 22.31258965], [81.11045837, 22.32149124], [81.10926819, 22.32963943], [81.1120224, 22.3346405], [81.11566162, 22.34408951], [81.11054993, 22.35300064], [81.1068573, 22.36218071], [81.10093689, 22.38323975], [81.10266113, 22.39126968], [81.1046524, 22.41080284], [81.10346985, 22.42208099], [81.10491943, 22.43279076], [81.10999298, 22.44112015], [81.12275696, 22.44762039], [81.13404083, 22.45199966], [81.14807892, 22.4558506], [81.15782166, 22.47448158], [81.16407013, 22.48191071], [81.17066193, 22.48800087], [81.18004608, 22.49015045], [81.18686676, 22.48921013], [81.19264221, 22.4824791], [81.1932373, 22.47370911], [81.19503784, 22.46775818], [81.19419098, 22.46208], [81.20214081, 22.45676994], [81.2097702, 22.45384979], [81.21839142, 22.45165062], [81.22355652, 22.45160866], [81.23310852, 22.45513153], [81.24038696, 22.45918083], [81.25551605, 22.47248268], [81.25623322, 22.48806953], [81.26045227, 22.49356079], [81.26674652, 22.49414063], [81.27146912, 22.49584961], [81.27546692, 22.49944115], [81.28019714, 22.49882126], [81.29170227, 22.48931122], [81.2977829, 22.4865799], [81.30396271, 22.48175049], [81.31591034, 22.48970985], [81.31414795, 22.4996109], [81.31481171, 22.5159111], [81.31939697, 22.51955032], [81.32293701, 22.52433014], [81.33188629, 22.52236938], [81.34794617, 22.51408958], [81.35569, 22.51324272], [81.36177826, 22.5153904], [81.36650085, 22.51436996], [81.37325287, 22.51075172], [81.3787384, 22.50530052], [81.37960815, 22.49790955], [81.37914276, 22.49339104], [81.38067627, 22.48534966], [81.38479614, 22.47784042], [81.38305664, 22.46260262], [81.38617706, 22.45116043], [81.38887024, 22.44483948], [81.39655304, 22.44132042], [81.41411591, 22.44852066], [81.41893005, 22.45421982], [81.42064667, 22.45940018], [81.41783142, 22.46515083], [81.41758728, 22.47363091], [81.42443848, 22.47923851], [81.43177795, 22.48049164], [81.43357086, 22.47771835], [81.43595886, 22.46948814], [81.44246674, 22.46615982], [81.44802856, 22.46739006], [81.45028687, 22.47256279], [81.44332886, 22.47154045], [81.44391632, 22.47867012], [81.43907928, 22.47947121], [81.44081116, 22.48464966], [81.44422913, 22.48702049], [81.43908691, 22.4910202], [81.43805695, 22.49394035], [81.44624329, 22.49586105], [81.45330811, 22.4910202], [81.46067047, 22.49435806], [81.46996307, 22.49398994], [81.47637177, 22.4921608], [81.4798584, 22.49331093], [81.48574829, 22.5033493], [81.49011993, 22.50843048], [81.49175262, 22.51733017], [81.49320984, 22.5196209], [81.50293732, 22.52679062], [81.50656128, 22.52177811], [81.51197052, 22.52352905], [81.5147171, 22.52869034], [81.51467133, 22.53403091], [81.51541901, 22.53675079], [81.51906586, 22.53998184], [81.52797699, 22.53979111], [81.53595734, 22.53324127], [81.54222107, 22.52992058], [81.54720306, 22.53126144], [81.55693054, 22.53216171], [81.56278229, 22.53417969], [81.55731201, 22.53759003], [81.55741882, 22.54689026], [81.56305695, 22.55100822], [81.5697403, 22.55005074], [81.5831604, 22.54453087], [81.58795929, 22.54403114], [81.59274292, 22.53765106], [81.59976959, 22.53570938], [81.60896301, 22.5364399], [81.61579132, 22.53902054], [81.62188721, 22.54383087], [81.62136078, 22.5477829], [81.61942291, 22.55327988], [81.61940765, 22.55855942], [81.6235733, 22.56427765], [81.63250732, 22.56199837], [81.63791656, 22.5621109], [81.64565277, 22.56589127], [81.64868927, 22.56895065], [81.64942169, 22.57608032], [81.64441681, 22.58337975], [81.64012146, 22.58654976], [81.64163208, 22.59209061], [81.64138794, 22.60754013], [81.64353943, 22.61440086], [81.64840698, 22.6199894], [81.65479279, 22.62158966], [81.65654755, 22.63200188], [81.66316223, 22.63272095], [81.6785965, 22.64888], [81.68839264, 22.64663124], [81.6988678, 22.64588165], [81.70701599, 22.64964104], [81.71411133, 22.65563011], [81.71800232, 22.66373062], [81.71962738, 22.67002106], [81.72294617, 22.6762104], [81.73014069, 22.67327118], [81.73693848, 22.66905022], [81.73934937, 22.6613903], [81.74053955, 22.64806938], [81.74893188, 22.64607048], [81.76272583, 22.66358948], [81.76506042, 22.66905975], [81.76597595, 22.67612076], [81.76288605, 22.68535995], [81.7559433, 22.69765091], [81.74833679, 22.71953964], [81.74661255, 22.72648811], [81.74912262, 22.73316956], [81.76249695, 22.73530006], [81.76277924, 22.74151039], [81.76397705, 22.74677086], [81.77815247, 22.75803947], [81.78427887, 22.76662064], [81.78128052, 22.7747097], [81.77440643, 22.78560066], [81.77590179, 22.80013847], [81.77300262, 22.8091507], [81.76159668, 22.82933044], [81.76085663, 22.83433914], [81.7648468, 22.84069061], [81.76931763, 22.85116005], [81.77005005, 22.86042976], [81.76940155, 22.87350845], [81.78592682, 22.87708092], [81.79582977, 22.88025093], [81.82065582, 22.88286018], [81.82644653, 22.88227081], [81.83142853, 22.88297081], [81.83558655, 22.88647079], [81.85634613, 22.8908596], [81.86110687, 22.89394951], [81.86194611, 22.90460968], [81.86000824, 22.91500092], [81.87050629, 22.91184044], [81.8746109, 22.91332054], [81.88027954, 22.91986084], [81.88654327, 22.9251709], [81.89488983, 22.92817116], [81.90146637, 22.93305969], [81.90567017, 22.94046021], [81.91385651, 22.94822121], [81.92344666, 22.9511795], [81.92797852, 22.95420074], [81.93327332, 22.95476151], [81.94024658, 22.95709038], [81.94256592, 22.96453094], [81.94241333, 22.97526932], [81.94120789, 22.98494911], [81.93844604, 22.99165154], [81.9385376, 23.00081062], [81.93701172, 23.00329971], [81.93721771, 23.00949287], [81.93229675, 23.01742172], [81.92679596, 23.02238083], [81.92707062, 23.02603912], [81.92597198, 23.02854156], [81.91941833, 23.03668022], [81.91842651, 23.04097939], [81.92138672, 23.04746056], [81.92394257, 23.05829811], [81.92608643, 23.06221008], [81.93501282, 23.0668602], [81.93786621, 23.06960106], [81.93747711, 23.07658005], [81.93810272, 23.07781029], [81.95262909, 23.07645035], [81.96127319, 23.08018112], [81.96507263, 23.08037186], [81.96930695, 23.0793705], [81.97215271, 23.08140945], [81.9748764, 23.08176041], [81.97997284, 23.08554268], [81.98214722, 23.08624268], [81.98545837, 23.08613014], [81.99048615, 23.08467102], [81.99253845, 23.08489037], [81.99680328, 23.08032036], [82.00218964, 23.07840919], [82.0102005, 23.08061981], [82.01278687, 23.07929993], [82.01616669, 23.07933044], [82.024086, 23.08012009], [82.02825165, 23.08166122], [82.03952026, 23.09151077], [82.04567719, 23.09910965], [82.04767609, 23.10335922], [82.06137085, 23.11594009], [82.06713104, 23.11681747], [82.06912231, 23.11488914], [82.07189178, 23.11359978], [82.07550812, 23.11215019], [82.0791626, 23.1121006], [82.08590698, 23.10925293], [82.10164642, 23.10851097], [82.10951996, 23.10548973], [82.11588287, 23.10379982], [82.11936188, 23.10746956], [82.12825012, 23.11211014], [82.12924194, 23.11403084], [82.12961578, 23.12507057], [82.13098907, 23.12895012], [82.13276672, 23.13162041], [82.15107727, 23.1417408], [82.15406799, 23.15114021], [82.15376282, 23.158041], [82.15138245, 23.16055107], [82.14494324, 23.16314125], [82.1401062, 23.16372108], [82.13732147, 23.1649704], [82.13790131, 23.16833115], [82.14170837, 23.17473984], [82.14095306, 23.17848969], [82.1374588, 23.18020058], [82.13698578, 23.18279839], [82.13765717, 23.18812943], [82.1401825, 23.19034958], [82.14057159, 23.19807053], [82.14665985, 23.20944977], [82.14634705, 23.21384048], [82.14292908, 23.22237968], [82.14248657, 23.22770119], [82.14698792, 23.23191833], [82.15371704, 23.24596977], [82.15953064, 23.24915123], [82.1598587, 23.25291824], [82.16652679, 23.26140022], [82.1681366, 23.2674408], [82.16982269, 23.27017975], [82.17402649, 23.27248955], [82.18419647, 23.27526283], [82.18638611, 23.27765846], [82.18946075, 23.28458977], [82.1869812, 23.29023933], [82.1869812, 23.29499054], [82.188797, 23.29837036], [82.18990326, 23.30348969], [82.18884277, 23.30873108], [82.18998718, 23.31153107], [82.18750763, 23.32222939], [82.18585968, 23.32538986], [82.18428802, 23.32689095], [82.179039, 23.3270607], [82.16007996, 23.33218956], [82.15808105, 23.33332062], [82.15553284, 23.33548927], [82.15358734, 23.34249115], [82.15130615, 23.3455677], [82.1452179, 23.34921074], [82.14282227, 23.35440826], [82.13783264, 23.3618412], [82.13247681, 23.36217117], [82.12905121, 23.36103821], [82.11844635, 23.35448074], [82.11444855, 23.35403061], [82.11090088, 23.35584068], [82.10788727, 23.35847092], [82.10449982, 23.36317825], [82.10546112, 23.36928177], [82.1051712, 23.38282967], [82.10411835, 23.38682175], [82.10079193, 23.3907795], [82.09876251, 23.39469147], [82.09848022, 23.39770126], [82.09488678, 23.3985405], [82.08512878, 23.39331055], [82.08364868, 23.39677238], [82.07995605, 23.39719009], [82.06929779, 23.39502907], [82.06307983, 23.39246941], [82.05677032, 23.39353943], [82.05396271, 23.39048958], [82.052742, 23.38513947], [82.04923248, 23.37873077], [82.04573822, 23.37787056], [82.03707123, 23.37955093], [82.03285217, 23.38539124], [82.02941895, 23.38755035], [82.02561188, 23.38593292], [82.02323914, 23.38376045], [82.02039337, 23.38430023], [82.01451874, 23.38791847], [82.0136261, 23.39026833], [82.01428986, 23.39351082], [82.01719666, 23.39639091], [82.01992035, 23.4009304], [82.01751709, 23.40551949], [82.01735687, 23.40806007], [82.02324677, 23.41018295], [82.01841736, 23.42111969], [82.01597595, 23.4235096], [82.00977325, 23.42052841], [81.99952698, 23.41281128], [81.99545288, 23.41559982], [81.99191284, 23.41929245], [81.98739624, 23.41951942], [81.97886658, 23.41152954], [81.97612, 23.41311073], [81.97589111, 23.41557121], [81.97360992, 23.41759109], [81.97158813, 23.41973114], [81.97054291, 23.42387009], [81.97338104, 23.42628288], [81.9750824, 23.4318409], [81.97145844, 23.44164085], [81.97190857, 23.44520187], [81.9713974, 23.44746971], [81.96821594, 23.45036125], [81.96660614, 23.45372009], [81.96124268, 23.45979118], [81.95674133, 23.46336937], [81.95033264, 23.46606064], [81.94761658, 23.4716301], [81.94702911, 23.47548103], [81.94893646, 23.49674034], [81.94471741, 23.50014114], [81.93444824, 23.50555038], [81.92829895, 23.51324081], [81.92767334, 23.51754951], [81.91635895, 23.53209114], [81.91375732, 23.53375816], [81.9094162, 23.53502274], [81.90392303, 23.53508949], [81.89997101, 23.5341301], [81.89624786, 23.53194809], [81.88448334, 23.52248001], [81.87935638, 23.51843262], [81.86968994, 23.51457024], [81.86223602, 23.51387024], [81.85507202, 23.51645088], [81.85074615, 23.51646042], [81.83410645, 23.51216125], [81.82717896, 23.5112896], [81.81653595, 23.51486015], [81.81257629, 23.51762962], [81.81006622, 23.52260971], [81.81019592, 23.52634048], [81.81150818, 23.53067017], [81.81104279, 23.53392029], [81.80461884, 23.5458107], [81.80127716, 23.54776001], [81.79756165, 23.54883194], [81.76299286, 23.55076981], [81.7563858, 23.55252075], [81.75361633, 23.55856133], [81.75060272, 23.5630703], [81.74796295, 23.5653801], [81.7407074, 23.56764984], [81.73603058, 23.5674305], [81.72923279, 23.56509972], [81.72595215, 23.56245041], [81.72344208, 23.55882835], [81.71923065, 23.55605125], [81.71675873, 23.54834938], [81.7130661, 23.5426693], [81.71034241, 23.54124069], [81.70638275, 23.53358078], [81.69309235, 23.52334023], [81.68744659, 23.5244503], [81.68187714, 23.5272007], [81.66718292, 23.53190041], [81.66203308, 23.53243828], [81.65453339, 23.53155136], [81.65309906, 23.52769279], [81.65396118, 23.5199604], [81.6536026, 23.51389122], [81.64765167, 23.50242996], [81.64398956, 23.50012016], [81.63717651, 23.49930191], [81.63524628, 23.49835968], [81.63109589, 23.49174118], [81.62822723, 23.4903698], [81.62422943, 23.49105072], [81.61721802, 23.49486923], [81.61443329, 23.49776077], [81.60704803, 23.50688934], [81.60521698, 23.51088905], [81.60632324, 23.52067947], [81.60546875, 23.5247612], [81.60665131, 23.54496956], [81.60569763, 23.55048943], [81.60227203, 23.55367279], [81.58690643, 23.55451012], [81.58392334, 23.5539608], [81.57707214, 23.55488968], [81.57550812, 23.5587101], [81.57444763, 23.56668091], [81.57042694, 23.5798111], [81.56973267, 23.58864975], [81.57077026, 23.59091949], [81.57505798, 23.59202194], [81.58024597, 23.59679031], [81.59480286, 23.59547043], [81.59984589, 23.59692192], [81.60267639, 23.60003281], [81.60108948, 23.61394119], [81.60437775, 23.62137032], [81.60652161, 23.62445831], [81.60951233, 23.63298988], [81.6132431, 23.66098022], [81.61849213, 23.66138077], [81.63500977, 23.65896988], [81.64312744, 23.66033173], [81.64640808, 23.66320992], [81.64795685, 23.66799927], [81.64949799, 23.6834507], [81.67321014, 23.69343185], [81.68464661, 23.71364021], [81.68728638, 23.72134972], [81.68688965, 23.72262001], [81.68234253, 23.72561073], [81.67749786, 23.73460007], [81.67209625, 23.74002075], [81.6733017, 23.74336052], [81.67829132, 23.74887085], [81.67408752, 23.7539711], [81.66932678, 23.75735092], [81.66178131, 23.75991058], [81.65354919, 23.76427078], [81.64415741, 23.76807976], [81.63965607, 23.77112961], [81.63816833, 23.77478981], [81.6383667, 23.77787971], [81.64348602, 23.7918396], [81.64362335, 23.79889107], [81.64256287, 23.80458069], [81.63601685, 23.81635094], [81.63053894, 23.83081055], [81.62811279, 23.83432961], [81.62570953, 23.83582115], [81.62023163, 23.8368206], [81.60942078, 23.83579063], [81.60733032, 23.83624077], [81.60582733, 23.83820915], [81.60497284, 23.84139061], [81.60456085, 23.84383965], [81.59844208, 23.85367966], [81.59738922, 23.85746002], [81.59738922, 23.86194038], [81.5983429, 23.86421967], [81.60620117, 23.86395073], [81.61142731, 23.86702919], [81.61485291, 23.87277031], [81.60874939, 23.87817955], [81.60019684, 23.88339806], [81.59757996, 23.88624191], [81.59690857, 23.88902283], [81.60338593, 23.89240074], [81.60555267, 23.89585114], [81.60756683, 23.90327072], [81.61051178, 23.90697289], [81.61444855, 23.90827942], [81.62451172, 23.90691948], [81.62921906, 23.90765953], [81.63728333, 23.91362], [81.6414566, 23.91517067], [81.64811707, 23.91616058], [81.6516571, 23.91782951], [81.65740967, 23.92456818], [81.66159821, 23.92559814], [81.66491699, 23.92207909], [81.66771698, 23.91570091], [81.67733002, 23.91024017], [81.67949677, 23.90764809], [81.68239594, 23.88978958], [81.68692017, 23.8849411], [81.6973877, 23.88596153], [81.69966888, 23.88149071], [81.69845581, 23.87799072], [81.70297241, 23.87285042], [81.70228577, 23.86898994], [81.7026825, 23.86339951], [81.71253204, 23.86296272], [81.71495056, 23.86188126], [81.72091675, 23.86082268], [81.7230072, 23.85898018], [81.72384644, 23.85688972], [81.72389221, 23.85071754], [81.72141266, 23.8490715], [81.71835327, 23.84338951], [81.71906281, 23.84042931], [81.72685242, 23.84095955], [81.7305069, 23.83936119], [81.73443604, 23.83619118], [81.74518585, 23.83092117], [81.77262878, 23.81419945], [81.78266144, 23.81184006], [81.78748322, 23.8119297], [81.79341888, 23.8144207], [81.80058289, 23.81355095], [81.80564117, 23.81043816], [81.81172943, 23.80949974], [81.81741333, 23.81124115], [81.82411957, 23.81641006], [81.82863617, 23.8170929], [81.83164978, 23.82130241], [81.85293579, 23.82431984], [81.85765839, 23.82876968], [81.86207581, 23.83481026], [81.87843323, 23.83790016], [81.88535309, 23.84173965], [81.89409637, 23.8440609], [81.89807129, 23.84828949], [81.90077972, 23.85122108], [81.90425873, 23.85852051], [81.90983582, 23.8640995], [81.91470337, 23.87187958], [81.91644287, 23.87298965], [81.93164825, 23.86791039], [81.93289948, 23.86675072], [81.93228149, 23.86261177], [81.93390656, 23.86193275], [81.93685913, 23.86206245], [81.93856049, 23.86096954], [81.94004822, 23.85777092], [81.94490051, 23.85692978], [81.95070648, 23.85289001], [81.96238708, 23.85707855], [81.97154999, 23.85835075], [81.98394012, 23.86199951], [81.99214935, 23.86264038], [82.00073242, 23.86314011], [82.00567627, 23.85880089], [82.00759888, 23.85495186], [82.01161194, 23.85227966], [82.02849579, 23.84770012], [82.03251648, 23.84507942], [82.03515625, 23.84255981], [82.03433228, 23.83867073], [82.03100586, 23.83189964], [82.03217316, 23.82930946], [82.04052734, 23.82632828], [82.04234314, 23.82496071], [82.04540253, 23.82058907], [82.06328583, 23.81911087], [82.07202148, 23.81978035], [82.07801819, 23.8170681], [82.08911133, 23.81789017], [82.10018158, 23.82010078], [82.10678864, 23.81849098], [82.10875702, 23.81868172], [82.11746216, 23.82312012], [82.12576294, 23.81966972], [82.13407898, 23.81816101], [82.14456177, 23.81925011], [82.15573883, 23.82197762], [82.16240692, 23.81995964], [82.16525269, 23.82075119], [82.1682663, 23.82269287], [82.16971588, 23.82467842], [82.17249298, 23.8379097], [82.17352295, 23.83909035], [82.17875671, 23.84204292], [82.18933868, 23.84370995], [82.19557953, 23.85038185], [82.20388794, 23.8529911], [82.20687103, 23.84404182], [82.20664978, 23.84103012], [82.20435333, 23.83712006], [82.20096588, 23.83453941], [82.1992569, 23.83192062], [82.20136261, 23.82829285], [82.21160126, 23.82393265], [82.21611023, 23.82096291], [82.22107697, 23.8100605], [82.22614288, 23.80693245], [82.22899628, 23.80667114], [82.23152924, 23.80779076], [82.24855042, 23.81979942], [82.25528717, 23.82188988], [82.26476288, 23.81874084], [82.27121735, 23.81869125], [82.27767181, 23.81713104], [82.28382874, 23.81290054], [82.29511261, 23.80854988], [82.29759216, 23.80816078], [82.30432129, 23.80986023], [82.30715942, 23.81116295], [82.31112671, 23.81118965], [82.31505585, 23.81030846], [82.32096863, 23.80874062], [82.32823181, 23.80367088], [82.33125305, 23.80536079], [82.33854675, 23.8060112], [82.3429184, 23.80389977], [82.34703064, 23.80371094], [82.35658264, 23.80833054], [82.36834717, 23.81110001], [82.37985229, 23.80704117], [82.3839798, 23.80487061], [82.38822937, 23.80137062], [82.39335632, 23.80241013], [82.40296936, 23.80277824], [82.42323303, 23.80608749], [82.43644714, 23.80470848], [82.44023895, 23.80572128], [82.44576263, 23.81085968], [82.44904327, 23.81165123], [82.46002197, 23.81139946], [82.46350861, 23.81084824], [82.46987915, 23.80764961], [82.4826889, 23.79751968], [82.48375702, 23.79057121], [82.4850769, 23.78837967], [82.49175262, 23.78570747], [82.4966507, 23.78504944], [82.50670624, 23.7854805], [82.5161972, 23.78423119], [82.52879333, 23.79134941], [82.53578949, 23.79210091], [82.54026794, 23.79120064], [82.54451752, 23.79418945], [82.54477692, 23.79831123], [82.54399109, 23.80282021], [82.54086304, 23.81015015], [82.53975677, 23.81182861], [82.53690338, 23.81249046], [82.53399658, 23.81479836], [82.53196716, 23.81982994], [82.52910614, 23.82159996], [82.52735138, 23.82407951], [82.53366089, 23.82499123], [82.53874969, 23.82410812], [82.54207611, 23.82674026], [82.54821777, 23.82690048], [82.56115723, 23.82278061], [82.56633759, 23.82472992], [82.57849121, 23.8224411], [82.58598328, 23.82286072], [82.58963776, 23.82479095], [82.60051727, 23.83391953], [82.60591125, 23.83616257], [82.6295166, 23.8390007], [82.63130188, 23.84168243], [82.6312561, 23.84633064], [82.63482666, 23.84767914], [82.63772583, 23.84988976], [82.64064026, 23.85803032], [82.64354706, 23.85962105], [82.64541626, 23.85782051], [82.65202332, 23.85650063], [82.65335846, 23.85778046], [82.65492249, 23.86271095], [82.65795898, 23.86558151], [82.66020966, 23.87033844], [82.65953064, 23.87458038], [82.65727234, 23.87815094], [82.64611816, 23.88873291], [82.64730072, 23.89499092], [82.65473938, 23.90629005], [82.65651703, 23.90786171], [82.65905762, 23.90863991], [82.66290283, 23.90867043], [82.66812134, 23.9076004], [82.67090607, 23.90977097], [82.67708588, 23.90982056], [82.68186188, 23.91226959], [82.68733978, 23.91777039], [82.68900299, 23.91953087], [82.68987274, 23.92042923], [82.70192719, 23.92493248], [82.70667267, 23.92461967], [82.71811676, 23.92144966], [82.74333191, 23.92064095], [82.74810028, 23.92228127], [82.75006866, 23.92653275], [82.75019836, 23.93005943], [82.75377655, 23.93588066], [82.77484894, 23.93857002], [82.7902832, 23.95061111], [82.79210663, 23.95570946], [82.79680634, 23.96142006], [82.79865265, 23.96218109], [82.8077774, 23.96305847], [82.82071686, 23.9649601], [82.84133911, 23.95014954], [82.84889984, 23.94683266], [82.85515594, 23.93877983], [82.86296082, 23.92552948], [82.86569214, 23.92266273], [82.87529755, 23.91641045], [82.88118744, 23.91028023], [82.89034271, 23.90456009], [82.90608215, 23.89789963], [82.91747284, 23.895401], [82.92251587, 23.89269066], [82.9251709, 23.89071083], [82.93058777, 23.88196945], [82.93308258, 23.87940025], [82.93881989, 23.87586975], [82.94950104, 23.87298965], [82.95359039, 23.87277031], [82.98396301, 23.87955284], [82.99227905, 23.87850952], [83.02052307, 23.88269806], [83.02546692, 23.88162994], [83.03643799, 23.88305092], [83.04345703, 23.87939072], [83.06104279, 23.87524033], [83.08660126, 23.87817192], [83.12741089, 23.89002037], [83.13437653, 23.89455032], [83.13526154, 23.8985405], [83.13878632, 23.90437126], [83.1452179, 23.90994263], [83.15557098, 23.91130829], [83.15785217, 23.91303062], [83.16433716, 23.91510963], [83.1678772, 23.91786957], [83.17260742, 23.91765976], [83.17756653, 23.91951942], [83.18312836, 23.91948128], [83.18956757, 23.92110062], [83.19313049, 23.92690086], [83.19135284, 23.93263054], [83.20176697, 23.94054031], [83.20323181, 23.94753265], [83.20587158, 23.95379066], [83.21121216, 23.96035767], [83.21063995, 23.96541023], [83.20835114, 23.9727993], [83.21057129, 23.97725105], [83.21562958, 23.98077965], [83.21476746, 23.9862709], [83.21602631, 23.98940277], [83.22252655, 23.99205971], [83.22677612, 23.99631119], [83.23352051, 23.99831009], [83.23692322, 24.00139046], [83.23535919, 24.00715065], [83.23697662, 24.00995827], [83.24182129, 24.013731], [83.24703217, 24.01519966], [83.25306702, 24.01213074], [83.25894928, 24.0116291], [83.26239777, 24.01366043], [83.26574707, 24.01725006], [83.27052307, 24.02026939], [83.2738266, 24.02115059], [83.27607727, 24.0232811], [83.27646637, 24.02730942], [83.279953, 24.03476906], [83.27680206, 24.04566956], [83.27748871, 24.04995918], [83.28040314, 24.05507088], [83.28417206, 24.06464958], [83.28900909, 24.07290077], [83.29242706, 24.07720947], [83.3110733, 24.09276009], [83.31344604, 24.09742928], [83.31352234, 24.10140038], [83.31491089, 24.10698128], [83.31894684, 24.10645103], [83.32356262, 24.1013298], [83.32759857, 24.09964943], [83.3457489, 24.09707069], [83.35723114, 24.10169029], [83.36197662, 24.10196114], [83.38326263, 24.09987068], [83.39240265, 24.09495163], [83.4006958, 24.08177948], [83.40309143, 24.08077812], [83.40895081, 24.08047104], [83.41467285, 24.08121109], [83.42137909, 24.08378029], [83.42536926, 24.08376122], [83.42858887, 24.07977295], [83.43013, 24.07401085], [83.43061066, 24.06904984], [83.42920685, 24.06202126], [83.43132019, 24.0579319], [83.4332428, 24.05470085], [83.44758606, 24.04248047], [83.45307922, 24.04142189], [83.45813751, 24.04191971], [83.46840668, 24.04067039], [83.4789505, 24.03854942], [83.50122833, 24.03068924], [83.50670624, 24.0282402], [83.5096283, 24.02540016], [83.51483154, 24.01576042], [83.51655579, 24.01062012], [83.50750732, 24.00139046], [83.50654602, 23.99134064], [83.50772095, 23.97945976], [83.51243591, 23.96699905], [83.5226059, 23.95216942], [83.53373718, 23.94174004], [83.53894043, 23.93350029], [83.537323, 23.91463089], [83.54284668, 23.89824104], [83.54936981, 23.89283943], [83.56050873, 23.89265823], [83.57015228, 23.89035988], [83.57615662, 23.88438034], [83.57302856, 23.87706947], [83.56369781, 23.87306023], [83.55760956, 23.86952972], [83.56121063, 23.86295128], [83.57177734, 23.86306], [83.58116913, 23.8619194], [83.59044647, 23.85649109], [83.60057068, 23.85347748], [83.61148834, 23.85336113], [83.62998962, 23.84736061], [83.63790131, 23.84703064], [83.64955139, 23.84806061], [83.65624237, 23.84364128], [83.65759277, 23.83697128], [83.65528107, 23.83201027], [83.65833282, 23.82781982], [83.66649628, 23.8259182], [83.67220306, 23.8200798], [83.67772675, 23.82266808], [83.68200684, 23.82580185], [83.68849182, 23.82393265], [83.69538879, 23.82066917], [83.69859314, 23.81646156], [83.69558716, 23.80759811], [83.69989777, 23.80163002], [83.70775604, 23.79495049], [83.71080017, 23.7895298], [83.71250153, 23.78083992], [83.71235657, 23.77233124], [83.72709656, 23.75990105], [83.72940063, 23.75473022], [83.73000336, 23.74368095], [83.72934723, 23.7318306], [83.73246002, 23.72398949], [83.73471832, 23.71355057], [83.73213959, 23.70466995], [83.72431183, 23.69678116], [83.72257996, 23.69413948], [83.71507263, 23.69024086], [83.71472931, 23.68254089], [83.72132874, 23.67374039], [83.72891235, 23.66740036], [83.74404144, 23.65913963], [83.75094604, 23.65332985], [83.75208282, 23.64898109], [83.74462128, 23.64565086], [83.74302673, 23.64046097], [83.74778748, 23.62664986], [83.76493835, 23.62148094], [83.76573944, 23.61754036], [83.76776886, 23.60908127], [83.77488708, 23.59950066], [83.78614807, 23.59818077], [83.79772186, 23.5900898], [83.80047607, 23.58317947], [83.80634308, 23.58230972], [83.81088257, 23.58885956], [83.8212204, 23.58485031], [83.83763123, 23.58135986], [83.84616089, 23.58092117], [83.85959625, 23.5783329], [83.88292694, 23.57277107], [83.89009094, 23.5759201], [83.89849091, 23.57116127], [83.9052887, 23.56950951], [83.91467285, 23.56874084], [83.92249298, 23.56504822], [83.93525696, 23.56303978], [83.92958832, 23.59367943], [83.93152618, 23.6114006], [83.9378891, 23.6224308], [83.94861603, 23.62431908], [83.962677, 23.62618828], [83.97545624, 23.63083076], [83.99267578, 23.63305283], [84.00702667, 23.63231087], [84.00771332, 23.62852097], [84.0036087, 23.62631989], [84.00177765, 23.62290955], [84.0018692, 23.62043953], [84.01257324, 23.60548019], [84.02030182, 23.60017967], [84.02233887, 23.59736061], [84.02194214, 23.59221077], [84.02411652, 23.58788109], [84.02291107, 23.57459068], [84.02511597, 23.56579018], [84.02128601, 23.54992867], [84.02266693, 23.54424095], [84.01539612, 23.52563286], [84.01274872, 23.52081108], [84.01228333, 23.5081501], [84.00875854, 23.49958038], [84.00563812, 23.49646187], [83.99724579, 23.49311066], [83.99272156, 23.4851799], [83.98889923, 23.48178101], [83.98462677, 23.47559166], [83.97914886, 23.46058083], [83.9695282, 23.4554081], [83.96972656, 23.44766808], [83.97775269, 23.4314518], [83.97944641, 23.42669106], [83.97815704, 23.42093086], [83.97805786, 23.4141407], [83.97616577, 23.40752029], [83.96778107, 23.39299011], [83.96582794, 23.38121033], [83.96688843, 23.37422943], [83.97025299, 23.36939812], [83.97486115, 23.36479187], [83.98301697, 23.35955048], [83.99276733, 23.35588264], [84.00653076, 23.35280037], [84.01145172, 23.36339951], [84.01715088, 23.37158966], [84.02073669, 23.37545967], [84.02648163, 23.37692833], [84.03803253, 23.3761692], [84.04338837, 23.37401009], [84.04722595, 23.37121964], [84.04345703, 23.36972046], [84.04444885, 23.36712074], [84.04734039, 23.36365128], [84.04860687, 23.35416031], [84.04995728, 23.35186005], [84.06051636, 23.3431797], [84.06797028, 23.33409119], [84.07025146, 23.32999039], [84.05995178, 23.30820084], [84.05938721, 23.30430031], [84.06381989, 23.29224014], [84.06304169, 23.28964043], [84.06005859, 23.28628922], [84.05906677, 23.28232002], [84.05906677, 23.27412033], [84.05126953, 23.2466011], [84.05045319, 23.24094963], [84.05400848, 23.23418045], [84.05223846, 23.2212429], [84.05236816, 23.21643066], [84.0535965, 23.21317101], [84.05802917, 23.20800018], [84.05834961, 23.20359993], [84.05612183, 23.19640923], [84.05090332, 23.18958092], [84.04399109, 23.18460083], [84.03932953, 23.1785183], [84.03380585, 23.16784096], [84.03112793, 23.16113281], [84.02909088, 23.15388107], [84.03026581, 23.14936829], [84.03336334, 23.14273071], [84.03367615, 23.13844109], [84.03595734, 23.13495064], [84.03997803, 23.1321106], [84.04527283, 23.13052177], [84.0528717, 23.12446976], [84.05560303, 23.12070084], [84.05893707, 23.11259079], [84.0614624, 23.10989952], [84.06671143, 23.10711288], [84.07646179, 23.10984993], [84.08786774, 23.10948944], [84.09736633, 23.10482025], [84.10492706, 23.09922028], [84.11026001, 23.09208107], [84.11244965, 23.08718109], [84.11618805, 23.08613968], [84.12647247, 23.08514977], [84.12937927, 23.08154106], [84.13092041, 23.07748985], [84.13170624, 23.0674305], [84.13076782, 23.06336021], [84.12587738, 23.05688286], [84.12483215, 23.05347824], [84.12335968, 23.04499245], [84.12367249, 23.03661919], [84.1246109, 23.03074837], [84.12664795, 23.02601051], [84.13169861, 23.01826286], [84.13733673, 23.00626945], [84.13835907, 22.99848938], [84.14421082, 22.9881897], [84.14511108, 22.98257065], [84.14356995, 22.97511101], [84.14800262, 22.96386909], [84.15458679, 22.96437263], [84.16786194, 22.97096062], [84.1713562, 22.97707939], [84.17059326, 22.98518944], [84.16860199, 22.99500084], [84.17314911, 22.99875069], [84.17397308, 23.00035095], [84.17259979, 23.00720024], [84.17537689, 23.01190186], [84.17668152, 23.02051926], [84.17904663, 23.02256012], [84.18992615, 23.02371979], [84.19824982, 23.01898956], [84.19993591, 23.01511955], [84.1967926, 23.00410271], [84.20107269, 22.99882126], [84.21202087, 22.98638916], [84.21494293, 22.97743034], [84.21705627, 22.97647285], [84.22680664, 22.98007011], [84.2374115, 22.98040009], [84.24150848, 22.97287941], [84.2509079, 22.97142982], [84.25461578, 22.97369957], [84.2620697, 22.9800415], [84.26789093, 22.98791122], [84.27140045, 22.98884964], [84.27111053, 22.98415947], [84.26888275, 22.97903061], [84.27192688, 22.97093964], [84.27857208, 22.9612484], [84.28933716, 22.9616394], [84.3067627, 22.96751022], [84.31449127, 22.97223091], [84.3182373, 22.97657967], [84.32515717, 22.97933006], [84.33181, 22.97913933], [84.34361267, 22.97372055], [84.34823608, 22.97587013], [84.36149597, 22.97455025], [84.3705368, 22.97507095], [84.3733902, 22.97214127], [84.37638092, 22.96630287], [84.37773132, 22.96171951], [84.37779236, 22.95191765], [84.37922668, 22.94890022], [84.38195038, 22.94573021], [84.38645935, 22.94238091], [84.38905334, 22.93873978], [84.38964844, 22.92374039], [84.38629913, 22.9168396], [84.37619019, 22.90920067], [84.37085724, 22.90160942], [84.37278748, 22.8984108], [84.37670898, 22.89772987], [84.37825775, 22.8931427], [84.37818909, 22.88786125], [84.37587738, 22.88140106], [84.37692261, 22.87589073], [84.3759613, 22.87363815], [84.37145996, 22.87212944], [84.36995697, 22.86890984], [84.36988831, 22.86450005], [84.35793304, 22.86059952], [84.34789276, 22.86316109], [84.34217834, 22.85917091], [84.33835602, 22.85904121], [84.33500671, 22.86024094], [84.32946014, 22.85955048], [84.3203125, 22.84942055], [84.31839752, 22.84375191], [84.31858826, 22.83513069], [84.32038116, 22.83603096], [84.31770325, 22.81718063], [84.31252289, 22.81035042], [84.31169128, 22.80330086], [84.30996704, 22.79898262], [84.3034668, 22.79846954], [84.30181885, 22.79507065], [84.29627991, 22.79363823], [84.29030609, 22.78716278], [84.28710938, 22.77671051], [84.28768921, 22.77090073], [84.28528595, 22.76337051], [84.28144836, 22.76011086], [84.27877808, 22.76136017], [84.27403259, 22.76559067], [84.26010132, 22.76494026], [84.25422668, 22.76297951], [84.25370789, 22.76072121], [84.25158691, 22.75807953], [84.2416687, 22.74835014], [84.2297287, 22.74015045], [84.22535706, 22.73516083], [84.22471619, 22.72735023], [84.22763062, 22.72315025], [84.22944641, 22.70523262], [84.22769165, 22.6979599], [84.23223877, 22.68857956], [84.22775269, 22.67699051], [84.22061157, 22.66891098], [84.21479034, 22.66456032], [84.20967102, 22.6629982], [84.20717621, 22.66506004], [84.20160675, 22.66518974], [84.1969986, 22.66378021], [84.19161987, 22.66025162], [84.18035126, 22.6498394], [84.16483307, 22.64532089], [84.15743256, 22.64093971], [84.14993286, 22.63442039], [84.13210297, 22.63578033], [84.11531067, 22.63525963], [84.1072464, 22.63667107], [84.09764099, 22.63301086], [84.09395599, 22.63264084], [84.08039093, 22.6365509], [84.05930328, 22.6074028], [84.05287933, 22.60260963], [84.04812622, 22.59414291], [84.04193115, 22.59218025], [84.03359222, 22.59127045], [84.02134705, 22.58723259], [84.02002716, 22.58279037], [84.01777649, 22.5789299], [84.01103973, 22.57500267], [84.00505066, 22.56956291], [84.00392914, 22.56192017], [84.00417328, 22.55486107], [84.00212097, 22.54659843], [83.99944305, 22.53950119], [84.00157928, 22.53399086], [84.00489807, 22.53013039], [84.00518036, 22.52473068], [84.00250244, 22.52086067], [83.99429321, 22.5288105], [83.99298096, 22.52737808], [83.98584747, 22.52548027], [83.98010254, 22.52201271], [83.97657013, 22.51839066], [83.97445679, 22.51398087], [83.97384644, 22.50913811], [83.97609711, 22.50221062], [83.98069, 22.49873161], [83.990448, 22.49439049], [83.99298096, 22.49398041], [83.99707794, 22.4907608], [84.01302338, 22.48524094], [84.01548767, 22.48242188], [84.02168274, 22.47205925], [84.0238266, 22.47071075], [84.03465271, 22.46989822], [84.03872681, 22.46888161], [84.04155731, 22.46410942], [84.03951263, 22.44872284], [84.04139709, 22.43792915], [84.04000854, 22.43289948], [84.03270721, 22.42603111], [84.02398682, 22.42218018], [84.02599335, 22.41909027], [84.02216339, 22.41016006], [84.01875305, 22.40678024], [84.01444244, 22.40409279], [84.01248932, 22.39889908], [84.00994873, 22.39608955], [84.00898743, 22.39139938], [84.00166321, 22.38036919], [84.00167847, 22.37585068], [84.00421143, 22.36766052], [84.00119019, 22.36967087], [83.99739838, 22.36853981], [83.99297333, 22.36923981], [83.98536682, 22.36637115], [83.97820282, 22.36510849], [83.96698761, 22.35784912], [83.95661163, 22.3610611], [83.95231628, 22.36120987], [83.9432373, 22.35845947], [83.92958069, 22.35628128], [83.92402649, 22.35749054], [83.91929626, 22.35978127], [83.9155426, 22.35967064], [83.9053421, 22.35261154], [83.89697266, 22.33968925], [83.87194824, 22.33893013], [83.86714935, 22.34102058], [83.86414337, 22.34361839], [83.86100769, 22.34378052], [83.85330963, 22.33880043], [83.84757996, 22.33083916], [83.84303284, 22.32634926], [83.82940674, 22.32394028], [83.82520294, 22.31962967], [83.82248688, 22.31563759], [83.82065582, 22.31025124], [83.82010651, 22.30508232], [83.82080841, 22.29603958], [83.81944275, 22.29245186], [83.81598663, 22.29120255], [83.80478668, 22.28988075], [83.79798889, 22.28996277], [83.79751587, 22.28948975], [83.79364777, 22.28769112], [83.79078674, 22.28464127], [83.78862762, 22.28025055], [83.77855682, 22.27450943], [83.77471924, 22.26733971], [83.77131653, 22.25733948], [83.76583862, 22.25601959], [83.76180267, 22.25415039], [83.7568512, 22.25037956], [83.75279999, 22.24286079], [83.74565125, 22.24122047], [83.71898651, 22.2432518], [83.70043182, 22.24588013], [83.69300079, 22.24550056], [83.67904663, 22.2406311], [83.67273712, 22.2374382], [83.66461945, 22.2319603], [83.65744019, 22.22479057], [83.65457153, 22.2238903], [83.64575195, 22.22458839], [83.62628174, 22.20585823], [83.61927032, 22.19635963], [83.61183929, 22.17714119], [83.60594177, 22.15760994], [83.60233307, 22.1518383], [83.59253693, 22.13998032], [83.56730652, 22.1137085], [83.56575775, 22.11285019], [83.55916595, 22.10386086], [83.55726624, 22.0999794], [83.55892181, 22.0954895], [83.56482697, 22.09397125], [83.57369995, 22.08880043], [83.58306885, 22.08049011], [83.58917999, 22.07635117], [83.60031891, 22.0655098], [83.59056854, 22.05934143], [83.58595276, 22.0555706], [83.58351135, 22.05495071], [83.56562805, 22.0567894], [83.55095673, 22.05564117], [83.5430069, 22.05939102], [83.53836823, 22.05537987], [83.53414917, 22.04343987], [83.53244781, 22.03404808], [83.5326767, 22.02863121], [83.53399658, 22.02227974], [83.53885651, 22.01437187], [83.5485611, 22.00670242], [83.54673767, 22.00335121], [83.54496765, 21.99938965], [83.54663849, 21.99827957], [83.543396, 21.99436951], [83.54083252, 21.99323273], [83.54010773, 21.98533058], [83.53544617, 21.9796505], [83.53447723, 21.97624969], [83.53517151, 21.96350098], [83.54949188, 21.95038986], [83.55771637, 21.9439106], [83.55397034, 21.9362812], [83.55335999, 21.9321804], [83.58776855, 21.92612076], [83.60047913, 21.91084099], [83.59931183, 21.90600014], [83.59263611, 21.90075111], [83.58325195, 21.89856911], [83.58151245, 21.89743042], [83.58319855, 21.89406967], [83.58333588, 21.89096069], [83.57988739, 21.88925171], [83.57670593, 21.8861599], [83.57810974, 21.87978935], [83.57330322, 21.87636948], [83.57151794, 21.87187004], [83.58405304, 21.85279274], [83.5859375, 21.84762955], [83.58447266, 21.84360123], [83.57948303, 21.83712006], [83.57489777, 21.83260155], [83.5735321, 21.82966042], [83.56453705, 21.83036995], [83.55745697, 21.83440971], [83.54853821, 21.83523178], [83.54094696, 21.83465958], [83.53124237, 21.83189964], [83.52765656, 21.82299042], [83.53639984, 21.81834984], [83.53478241, 21.80681992], [83.53866577, 21.80061913], [83.5357666, 21.79896164], [83.53656769, 21.79393005], [83.52218628, 21.79411125], [83.51412201, 21.79780006], [83.50614166, 21.80039978], [83.49771881, 21.80618095], [83.49091339, 21.81454086], [83.49133301, 21.80866051], [83.48545837, 21.80322075], [83.48404694, 21.79434013], [83.47429657, 21.78614998], [83.46717834, 21.78273964], [83.47592163, 21.77379036], [83.47789001, 21.76459122], [83.47902679, 21.75869942], [83.47541809, 21.75341034], [83.47390747, 21.7496109], [83.47733307, 21.74588966], [83.48413086, 21.74155235], [83.47986603, 21.7341404], [83.47801971, 21.7279911], [83.46692657, 21.71056938], [83.46160889, 21.70627975], [83.45762634, 21.69967079], [83.45633698, 21.69432068], [83.44970703, 21.69095993], [83.4407959, 21.69338989], [83.43183136, 21.6939106], [83.42796326, 21.69232941], [83.42488098, 21.68901062], [83.42111206, 21.68654823], [83.4197464, 21.67502022], [83.4286499, 21.66889], [83.43535614, 21.66312027], [83.44077301, 21.65517044], [83.46621704, 21.64412117], [83.47477722, 21.64121819], [83.483078, 21.63960075], [83.4833374, 21.6371727], [83.48647308, 21.63317108], [83.48454285, 21.62556267], [83.4765625, 21.62729263], [83.46990204, 21.62677002], [83.46296692, 21.60551071], [83.45275879, 21.60519028], [83.45279694, 21.60732269], [83.44872284, 21.60822105], [83.45001221, 21.61339951], [83.44993591, 21.6169796], [83.44133759, 21.61809158], [83.44142151, 21.62502289], [83.44048309, 21.62669945], [83.44139099, 21.63246155], [83.44757843, 21.64459991], [83.44123077, 21.64927292], [83.42650604, 21.64353943], [83.42405701, 21.63848114], [83.41352844, 21.63631058], [83.40862274, 21.63420105], [83.40518951, 21.63181114], [83.40180969, 21.62675095], [83.39524078, 21.62419128], [83.38981628, 21.62054062], [83.38683319, 21.61536026], [83.38072205, 21.61275101], [83.37725067, 21.60467911], [83.36818695, 21.59707069], [83.36232758, 21.57252121], [83.3633194, 21.56777954], [83.36686707, 21.55931282], [83.36692047, 21.55302048], [83.36577606, 21.54968071], [83.35426331, 21.53531837], [83.34896851, 21.51596069], [83.3458786, 21.50823975], [83.3377533, 21.50263023], [83.33589935, 21.49963951], [83.33463287, 21.49555016], [83.33561707, 21.49191093], [83.34205627, 21.48533058], [83.34197998, 21.47413063], [83.34335327, 21.46488953], [83.34732819, 21.45514107], [83.35028839, 21.44398117], [83.36094666, 21.44218063], [83.36579132, 21.43984032], [83.37014008, 21.43610001], [83.37137604, 21.42835999], [83.37393951, 21.42222023], [83.38140869, 21.40957832], [83.38967133, 21.40166283], [83.39376068, 21.39944267], [83.39308929, 21.38321114], [83.39655304, 21.37227058], [83.3963089, 21.36927032], [83.39317322, 21.36519051], [83.39415741, 21.3611412], [83.4018631, 21.3583107], [83.40444946, 21.35511971], [83.40265656, 21.34843063], [83.39385986, 21.34208107], [83.3879776, 21.33893967], [83.37663269, 21.34329987], [83.37481689, 21.3399601], [83.33460236, 21.35579109], [83.31933594, 21.35814285], [83.3095932, 21.36456108], [83.30164337, 21.36783981], [83.2872467, 21.3714695], [83.2813797, 21.37514114], [83.27614594, 21.37592125], [83.27001953, 21.37503815], [83.26951599, 21.36721039], [83.27078247, 21.35923958], [83.26609039, 21.34543037], [83.26064301, 21.33717918], [83.25495911, 21.33192062], [83.25578308, 21.32932281], [83.26085663, 21.32674026], [83.25421143, 21.31958961], [83.25409698, 21.31237984], [83.25879669, 21.30212975], [83.27268219, 21.29613113], [83.27480316, 21.29057121], [83.27455902, 21.28567123], [83.2713089, 21.28050041], [83.26767731, 21.26857758], [83.26275635, 21.27260971], [83.25730133, 21.27555084], [83.24836731, 21.27730179], [83.2424469, 21.27643967], [83.23187256, 21.26534081], [83.22489929, 21.26696968], [83.21835327, 21.26012039], [83.21414185, 21.25086975], [83.21469879, 21.24041939], [83.21906281, 21.22371101], [83.21520996, 21.22369194], [83.21438599, 21.22058105], [83.21536255, 21.21549034], [83.20757294, 21.20139122], [83.21121216, 21.19118118], [83.2100296, 21.1880703], [83.20520782, 21.18404007], [83.20201874, 21.17743111], [83.19953156, 21.17404938], [83.20007324, 21.16889954], [83.1993866, 21.16197014], [83.19373322, 21.1576519], [83.19274902, 21.13944054], [83.19010162, 21.13552856], [83.18297577, 21.13204956], [83.17662048, 21.13074112], [83.16986847, 21.13151932], [83.16139221, 21.13145065], [83.15339661, 21.12577057], [83.14875031, 21.11987114], [83.13771057, 21.1098175], [83.13400269, 21.10523033], [83.11984253, 21.10106087], [83.10827637, 21.10770035], [83.0951767, 21.1043129], [83.09208679, 21.10597038], [83.08870697, 21.10745049], [83.08156586, 21.1067009], [83.07144165, 21.10807037], [83.06436157, 21.11110115], [83.05976105, 21.11591148], [83.05139923, 21.11717033], [83.04682922, 21.12021065], [83.04058075, 21.11893082], [83.03643036, 21.1212101], [83.03275299, 21.12436295], [83.02908325, 21.12602997], [83.02954102, 21.13132286], [83.01862335, 21.13817978], [83.01589203, 21.13972092], [83.01048279, 21.14537048], [83.00772858, 21.14653015], [83.00554657, 21.14583015], [82.99912262, 21.14813995], [82.99297333, 21.15427971], [82.98342133, 21.14826965], [82.97992706, 21.15746117], [82.97161102, 21.15631104], [82.96514893, 21.15575981], [82.96363831, 21.16167068], [82.95964813, 21.17385101], [82.95606995, 21.17548943], [82.9489975, 21.16977119], [82.94232941, 21.16304016], [82.93739319, 21.16114807], [82.9280014, 21.16103172], [82.92192841, 21.15821075], [82.91442108, 21.16064072], [82.90795898, 21.1602726], [82.90231323, 21.16296959], [82.8951416, 21.15982056], [82.88741302, 21.15377235], [82.87922668, 21.14908981], [82.87285614, 21.1510582], [82.86882782, 21.15974998], [82.86367035, 21.15538025], [82.85949707, 21.15730286], [82.85402679, 21.15700912], [82.84677124, 21.1581707], [82.84712982, 21.16268158], [82.83999634, 21.1633606], [82.81247711, 21.1585598], [82.80684662, 21.15664101], [82.80381012, 21.15307045], [82.79559326, 21.1505909], [82.79176331, 21.14511108], [82.78884888, 21.13927269], [82.78208923, 21.14101982], [82.75752258, 21.1585598], [82.75229645, 21.15974045], [82.73535156, 21.15787125], [82.72724152, 21.15919113], [82.72115326, 21.15894127], [82.7114563, 21.15576935], [82.70553589, 21.15489006], [82.70053864, 21.15326118], [82.69403839, 21.15280151], [82.6919632, 21.15685081], [82.68453217, 21.15806007], [82.66204834, 21.15075111], [82.64582825, 21.15171051], [82.63594055, 21.1494503], [82.63279724, 21.14266014], [82.63408661, 21.13635063], [82.6383667, 21.13161278], [82.6446228, 21.12881088], [82.64775848, 21.12496185], [82.64531708, 21.12066841], [82.63955688, 21.11700058], [82.63710022, 21.11161995], [82.63833618, 21.10647011], [82.64502716, 21.10187912], [82.64299774, 21.09776115], [82.63536072, 21.09198952], [82.63183594, 21.08695984], [82.62587738, 21.07682037], [82.62194061, 21.07520103], [82.61524963, 21.07517052], [82.60938263, 21.07119751], [82.60912323, 21.06392097], [82.62003326, 21.04439926], [82.62230682, 21.0365696], [82.60861969, 21.01819992], [82.60772705, 21.01216125], [82.60444641, 21.00587273], [82.59514618, 20.99712944], [82.58207703, 20.98677826], [82.57813263, 20.97894096], [82.56651306, 20.96700096], [82.55294037, 20.94148064], [82.54573822, 20.93494034], [82.53585052, 20.92952156], [82.52625275, 20.92770958], [82.51924133, 20.92469025], [82.51344299, 20.91721916], [82.50309753, 20.91389084], [82.49363708, 20.90934944], [82.485672, 20.90351105], [82.48313904, 20.8996582], [82.48467255, 20.87955093], [82.48452759, 20.87289047], [82.48136902, 20.86145973], [82.48192596, 20.85531044], [82.47762299, 20.84671974], [82.46826172, 20.84263039], [82.46338654, 20.83967018], [82.45983124, 20.83564949], [82.46231079, 20.83035088], [82.46246338, 20.8275795], [82.45905304, 20.82384109], [82.45350647, 20.8212204], [82.44837189, 20.82217979], [82.44465637, 20.82406998], [82.44108582, 20.82376289], [82.43939209, 20.8271904], [82.43650055, 20.82953072], [82.42294312, 20.82600021], [82.41552734, 20.82646942], [82.4134903, 20.82956123], [82.40563202, 20.8372097], [82.40737152, 20.84349823], [82.40727997, 20.84802055], [82.40225983, 20.85328102], [82.40246582, 20.85795975], [82.40141296, 20.86243057], [82.38279724, 20.8699398], [82.37667084, 20.86692047], [82.36801147, 20.8640995], [82.35903931, 20.86654091], [82.35591888, 20.8699398], [82.35617828, 20.87635994], [82.35917664, 20.8827095], [82.34661865, 20.88384819], [82.34121704, 20.86806107], [82.33687592, 20.8492527], [82.33403778, 20.84058952], [82.3355484, 20.82783127], [82.33310699, 20.8196907], [82.33567047, 20.79737282], [82.33879089, 20.79017067], [82.33692932, 20.77930069], [82.33512878, 20.75851822], [82.3404007, 20.74671936], [82.34586334, 20.72871971], [82.33940887, 20.72583008], [82.34699249, 20.71423912], [82.34426117, 20.7095108], [82.34329987, 20.69885254], [82.3455658, 20.69491005], [82.35131836, 20.67807007], [82.35428619, 20.6750412], [82.36068726, 20.67191124], [82.36522675, 20.66376114], [82.36580658, 20.66114998], [82.36225128, 20.65047073], [82.36380005, 20.6395607], [82.36754608, 20.62957001], [82.36823273, 20.62405968], [82.36633301, 20.6202507], [82.35817719, 20.61516953], [82.35665894, 20.61136055], [82.35785675, 20.60921097], [82.35582733, 20.60349083], [82.34799957, 20.6016407], [82.3454895, 20.59790039], [82.33867645, 20.5943203], [82.33837128, 20.59082985], [82.33766937, 20.58493042], [82.3425293, 20.57522011], [82.34063721, 20.56973267], [82.33715057, 20.56517982], [82.33235168, 20.56227112], [82.32782745, 20.56196022], [82.3274765, 20.55789757], [82.32637787, 20.55657959], [82.32446289, 20.55664825], [82.32401276, 20.55388069], [82.32775879, 20.54927063], [82.33609009, 20.54323959], [82.34224701, 20.53769112], [82.34879303, 20.52293015], [82.35851288, 20.51623917], [82.36994934, 20.51394081], [82.38049316, 20.50984955], [82.38131714, 20.50777054], [82.38123322, 20.50180054], [82.38375092, 20.48266029], [82.38613129, 20.47552109], [82.38513947, 20.4704895], [82.38960266, 20.46536064], [82.39006805, 20.45939064], [82.38809204, 20.45251083], [82.39731598, 20.45191956], [82.40640259, 20.46614075], [82.41007996, 20.47330093], [82.41609955, 20.4661808], [82.41938782, 20.45728111], [82.41940308, 20.44557953], [82.41771698, 20.43830109], [82.42565155, 20.43631935], [82.427742, 20.43206978], [82.4291687, 20.42575264], [82.42295837, 20.41833115], [82.42428589, 20.41015053], [82.41768646, 20.4056282], [82.40989685, 20.40267944], [82.41274261, 20.38824272], [82.41060638, 20.38247108], [82.41040802, 20.37720108], [82.40307617, 20.36526108], [82.40251923, 20.36133003], [82.39794159, 20.35585976], [82.39795685, 20.34677124], [82.39441681, 20.34013748], [82.39377594, 20.3355217], [82.39878845, 20.33165169], [82.40029907, 20.32925034], [82.40045929, 20.32467079], [82.40717316, 20.32207108], [82.41629791, 20.31695938], [82.42243958, 20.30965996], [82.42395782, 20.29650116], [82.4283371, 20.28986168], [82.42922974, 20.2829628], [82.42804718, 20.27861023], [82.42082214, 20.27260017], [82.412323, 20.26990128], [82.4050827, 20.26353073], [82.40537262, 20.25587273], [82.41407776, 20.24155045], [82.40837097, 20.24166107], [82.40432739, 20.23960114], [82.40727997, 20.22764015], [82.40818787, 20.22063065], [82.41277313, 20.21744919], [82.41365051, 20.21327972], [82.41308594, 20.20795059], [82.41359711, 20.20227051], [82.40763092, 20.19409943], [82.40574646, 20.17898941], [82.39048767, 20.16731262], [82.38330078, 20.16045952], [82.38719177, 20.14885139], [82.37892914, 20.14463043], [82.38228607, 20.13817024], [82.38658142, 20.13338089], [82.38775635, 20.12693977], [82.39073944, 20.11905098], [82.39264679, 20.10824966], [82.39466858, 20.08916092], [82.39260101, 20.07331085], [82.39034271, 20.06423187], [82.39086151, 20.05958939], [82.39576721, 20.04899979], [82.40618896, 20.04631042], [82.41713715, 20.04534912], [82.4247818, 20.04354095], [82.43192291, 20.03897095], [82.44142914, 20.03535271], [82.45149994, 20.03526115], [82.45832825, 20.0338707], [82.46409607, 20.03154945], [82.47077179, 20.03202057], [82.47590637, 20.03005028], [82.48159027, 20.02456093], [82.49006653, 20.01857185], [82.5021286, 20.01353073], [82.52424622, 20.01044083], [82.53198242, 20.01222992], [82.54361725, 20.01213074], [82.57594299, 19.99895287], [82.57872009, 19.9956398], [82.58235931, 19.98994064], [82.59836578, 19.98563957], [82.61438751, 19.9869709], [82.61875916, 19.99156952], [82.62088776, 19.99555969], [82.62358093, 19.99764061], [82.63175964, 20.00008965], [82.63625336, 19.99829102], [82.64189911, 19.99790955], [82.65048218, 19.99940109], [82.68102264, 19.99545097], [82.68644714, 19.99463081], [82.69230652, 19.9924202], [82.69802094, 19.99273109], [82.70063019, 19.99287033], [82.70748901, 19.99021912], [82.71092987, 19.98326111], [82.70944977, 19.94667053], [82.71156311, 19.9444809], [82.71061707, 19.93947029], [82.70649719, 19.93353081], [82.70632172, 19.92685127], [82.70426178, 19.91833115], [82.70587921, 19.91123009], [82.70040894, 19.90661049], [82.70147705, 19.90073013], [82.70053101, 19.89328957], [82.70269012, 19.88584137], [82.70636749, 19.87851906], [82.70935059, 19.870121], [82.71750641, 19.87080956], [82.71385956, 19.86209106], [82.71100616, 19.84856033], [82.70471191, 19.84460068], [82.70588684, 19.8380909], [82.70271301, 19.83103943], [82.69844055, 19.82686043], [82.6905365, 19.82575989], [82.68331909, 19.82372093], [82.66913605, 19.82520294], [82.66001892, 19.82372093], [82.65410614, 19.8255291], [82.64573669, 19.82537079], [82.64179993, 19.8137207], [82.6362915, 19.80799294], [82.62890625, 19.80376053], [82.62734222, 19.79615021], [82.62296295, 19.78931046], [82.61886597, 19.78610039], [82.60813141, 19.78512955], [82.60327911, 19.78355026], [82.59900665, 19.78127289], [82.59828186, 19.7751503], [82.59513855, 19.77306938], [82.58506012, 19.7710495], [82.5812912, 19.77269173], [82.57847595, 19.77581978], [82.57791138, 19.77959061], [82.5792923, 19.78466034], [82.57781219, 19.78780937], [82.57779694, 19.79232979], [82.57927704, 19.7972126], [82.57157898, 19.80200958], [82.57303619, 19.80555916], [82.57183838, 19.80760956], [82.57382965, 19.82370949], [82.57126617, 19.82238007], [82.57182312, 19.82780838], [82.57419586, 19.83197975], [82.57894135, 19.83662987], [82.58349609, 19.83832169], [82.58149719, 19.84049034], [82.58573151, 19.8463707], [82.58982086, 19.8481884], [82.59146881, 19.85243034], [82.59738159, 19.86046982], [82.59349823, 19.8645401], [82.59076691, 19.86621857], [82.57758331, 19.86343956], [82.56674957, 19.87172127], [82.55488586, 19.86950111], [82.5508728, 19.8745594], [82.54721832, 19.87330055], [82.54428864, 19.86903], [82.53636169, 19.87689018], [82.5298996, 19.88212967], [82.52305603, 19.87278938], [82.51795959, 19.87631035], [82.51241302, 19.88412094], [82.5022583, 19.88244057], [82.49848175, 19.88516998], [82.497612, 19.8950882], [82.49423981, 19.89735985], [82.48692322, 19.89653015], [82.47569275, 19.90052986], [82.46808624, 19.89948082], [82.46556091, 19.89657974], [82.45835114, 19.89464951], [82.44239044, 19.90298271], [82.43949127, 19.90291977], [82.43225861, 19.89948082], [82.42492676, 19.89760971], [82.42090607, 19.89833069], [82.41388702, 19.89652061], [82.41043854, 19.89340019], [82.40040588, 19.8888092], [82.39700317, 19.88454056], [82.38881683, 19.88175964], [82.38617706, 19.87684059], [82.37798309, 19.86869049], [82.37725067, 19.86296844], [82.36804962, 19.85448074], [82.35845184, 19.85688019], [82.35607147, 19.85513115], [82.35736084, 19.84950066], [82.35624695, 19.84662056], [82.33944702, 19.82996178], [82.32675171, 19.83833122], [82.32511902, 19.84049034], [82.32132721, 19.85191917], [82.31794739, 19.85915947], [82.29823303, 19.883461], [82.29532623, 19.89895821], [82.28333282, 19.91806984], [82.26946259, 19.94524956], [82.26864624, 19.95792961], [82.26169586, 19.97155952], [82.25863647, 19.97174072], [82.25271606, 19.97647858], [82.23335266, 19.99587059], [82.23062897, 19.99808121], [82.22438049, 19.99587059], [82.2194519, 19.9934597], [82.21425629, 19.99334145], [82.21058655, 19.99081039], [82.2042923, 19.98033905], [82.19381714, 19.98130989], [82.18418121, 19.98116112], [82.1784668, 19.97808266], [82.17578125, 19.98553085], [82.16607666, 19.99584007], [82.16583252, 19.99814987], [82.15557861, 20.0023098], [82.14834595, 20.00300026], [82.13169861, 20.01268959], [82.12841034, 20.01258087], [82.12142181, 20.00979042], [82.1160965, 20.01040077], [82.10547638, 20.01781273], [82.10273743, 20.02082825], [82.09773254, 20.02337074], [82.0952301, 20.02680016], [82.09319305, 20.03267288], [82.08943939, 20.03454971], [82.08304596, 20.03273964], [82.07630157, 20.04404068], [82.06980133, 20.04804039], [82.05789948, 20.04986954], [82.04897308, 20.03524017], [82.03875732, 20.02891922], [82.03102875, 20.02288055], [82.03156281, 20.01666069], [82.03070068, 20.01503944], [82.02440643, 20.01004028], [82.01478577, 20.01951027], [82.01551819, 20.02683067], [82.01449585, 20.03025055], [82.014328, 20.0364399], [82.01270294, 20.04103088], [82.00995636, 20.0447998], [82.00689697, 20.04733086], [82.00102997, 20.04926109], [81.99555206, 20.04753113], [81.9927063, 20.04782104], [81.98660278, 20.05207253], [81.98329926, 20.05702972], [81.97849274, 20.06917953], [81.97357178, 20.07561111], [81.96264648, 20.08556938], [81.95477295, 20.09148026], [81.94420624, 20.10160255], [81.94135284, 20.10225105], [81.93696594, 20.10115051], [81.93392944, 20.09930992], [81.92563629, 20.09011841], [81.92188263, 20.08694839], [81.91542816, 20.07382965], [81.91027069, 20.06705093], [81.90142822, 20.05912018], [81.8941803, 20.04824829], [81.8894577, 20.04327011], [81.88504028, 20.04171944], [81.880867, 20.04241943], [81.8762207, 20.04438972], [81.87375641, 20.04618073], [81.866539, 20.03603935], [81.86611176, 20.03518105], [81.86548615, 20.03388023], [81.86458588, 20.02864075], [81.86016846, 20.02336121], [81.85891724, 20.01637077], [81.85762024, 20.00908089], [81.85546112, 20.00352097], [81.85205078, 19.99715996], [81.85161591, 19.99605942], [81.85101318, 19.98975182], [81.85031891, 19.98260117], [81.84689331, 19.9703598], [81.84026337, 19.95513916], [81.83730316, 19.95008087], [81.83895111, 19.94549942], [81.84651184, 19.94144058], [81.84883118, 19.938591], [81.84567261, 19.92295265], [81.84580994, 19.91486168], [81.84963226, 19.90805054], [81.85840607, 19.89954948], [81.86924744, 19.89281082], [81.89805603, 19.87851906], [81.92447662, 19.86872292], [81.93942261, 19.86484146], [81.96037292, 19.85473824], [81.95741272, 19.83600998], [81.9614563, 19.82443237], [81.97020721, 19.81274033], [81.98014832, 19.79578018], [81.98741913, 19.79174042], [81.99237061, 19.79442978], [81.99932098, 19.79830933], [82.00289154, 19.7985096], [82.00305176, 19.79851913], [82.00818634, 19.79656982], [82.02419281, 19.79297829], [82.02906036, 19.79219055], [82.03494263, 19.79265976], [82.04107666, 19.79219055], [82.04444122, 19.78924942], [82.04827881, 19.78841019], [82.05219269, 19.79134178], [82.05982971, 19.78309822], [82.05938721, 19.77903938], [82.05898285, 19.77507019], [82.05541992, 19.7610302], [82.05719757, 19.75341034], [82.04659271, 19.74302101], [82.04400635, 19.73768997], [82.04425812, 19.72912979], [82.04255676, 19.72313118], [82.0437088, 19.71391106], [82.04160309, 19.70828819], [82.03756714, 19.70391083], [82.03848267, 19.69277954], [82.04677582, 19.66937065], [82.04766846, 19.66268921], [82.04603577, 19.65359116], [82.04830933, 19.64937019], [82.04638672, 19.64402962], [82.04728699, 19.63828087], [82.05082703, 19.63162041], [82.05134583, 19.62444115], [82.04847717, 19.61581039], [82.04471588, 19.61079025], [82.0450592, 19.60165024], [82.03727722, 19.59791946], [82.03395844, 19.59069061], [82.03489685, 19.58327293], [82.03779602, 19.5771904], [82.0422287, 19.57092094], [82.04323578, 19.56767082], [82.04413605, 19.56479836], [82.0426178, 19.55800056], [82.04042053, 19.55220985], [82.0430069, 19.5444603], [82.04612732, 19.5386219], [82.04257202, 19.53156853], [82.04102325, 19.52570152], [82.03246307, 19.52129173], [82.0302124, 19.51420975], [82.02239227, 19.50180244], [82.05979156, 19.50364113], [82.0671463, 19.51102066], [82.07084656, 19.51592064], [82.08822632, 19.51044273], [82.09207916, 19.50984001], [82.09101868, 19.49405861], [82.09902954, 19.48957062], [82.10182953, 19.47365952], [82.09986877, 19.46606064], [82.09689331, 19.46108055], [82.10716248, 19.45261192], [82.10679626, 19.44307137], [82.11930847, 19.4239006], [82.13410187, 19.42482758], [82.16069031, 19.42951965], [82.1672287, 19.42984962], [82.17045593, 19.42949104], [82.17925262, 19.41913986], [82.18305969, 19.41761017], [82.18348694, 19.41246033], [82.17777252, 19.40557289], [82.17398071, 19.37693977], [82.16636658, 19.36593056], [82.15080261, 19.37034035], [82.14456177, 19.37011909], [82.14118195, 19.36578178], [82.14083099, 19.3619194], [82.14225769, 19.35511017], [82.14234924, 19.34817123], [82.14955139, 19.34437943], [82.15722656, 19.34284019], [82.16314697, 19.33780289], [82.16895294, 19.33723068], [82.17320251, 19.33407974], [82.17749023, 19.33237076], [82.18025208, 19.33220291], [82.1831665, 19.31970024], [82.17368317, 19.31630135], [82.17008972, 19.3024807], [82.1700058, 19.29572105], [82.16853333, 19.29066086], [82.15836334, 19.28148079], [82.15487671, 19.27477837], [82.15172577, 19.26546288], [82.15099335, 19.25842285], [82.15196228, 19.23890114], [82.15164948, 19.22356987], [82.15376282, 19.21577835], [82.16117859, 19.20838928], [82.15570831, 19.19652939], [82.15804291, 19.19317818], [82.16478729, 19.18732071], [82.17339325, 19.18431091], [82.16940308, 19.17670059], [82.17459869, 19.17358017], [82.17516327, 19.16963959], [82.17112732, 19.16827011], [82.17298126, 19.16476059], [82.17823792, 19.16147995], [82.17878723, 19.15885925], [82.17684174, 19.15497971], [82.17471313, 19.15275002], [82.1714859, 19.15390968], [82.16760254, 19.15687943], [82.16413879, 19.15463829], [82.16500092, 19.15044975], [82.17238617, 19.14764977], [82.17478943, 19.14523125], [82.17198944, 19.14249992], [82.16990662, 19.14364052], [82.1658783, 19.14314079], [82.16471863, 19.13947105], [82.1681366, 19.13384056], [82.16655731, 19.13214111], [82.16117096, 19.12975121], [82.15978241, 19.1264801], [82.16480255, 19.11469078], [82.16982269, 19.11285973], [82.17623901, 19.12506104], [82.19101715, 19.11631012], [82.19975281, 19.11746025], [82.20149994, 19.11576271], [82.19689941, 19.10115051], [82.19948578, 19.09982109], [82.1985321, 19.09416962], [82.19986725, 19.09217834], [82.21058655, 19.09225082], [82.21211243, 19.09054947], [82.21122742, 19.08575821], [82.20855713, 19.07852173], [82.19683075, 19.06786919], [82.1940918, 19.06022072], [82.22248077, 19.02111053], [82.22506714, 19.01459122], [82.22666168, 18.99398041], [82.23956299, 18.91045952], [82.23429108, 18.90526962], [82.23121643, 18.90522003], [82.22767639, 18.9066906], [82.22486115, 18.90924835], [82.21378326, 18.91213989], [82.1987381, 18.90554047], [82.18538666, 18.89698029], [82.17714691, 18.89690018], [82.17272949, 18.89528847], [82.17076874, 18.89159012], [82.17041016, 18.87757111], [82.16310883, 18.87193108], [82.15820313, 18.86945915], [82.16279602, 18.86551094], [82.16126251, 18.8577404], [82.15802765, 18.85197067], [82.16242218, 18.8451004], [82.16175079, 18.83786011], [82.16493988, 18.83020973], [82.15830994, 18.81147003], [82.15867615, 18.80920029], [82.16184235, 18.80496025], [82.16101074, 18.80356979], [82.15611267, 18.79994011], [82.15429688, 18.7963028], [82.15891266, 18.79507065], [82.16114807, 18.79096031], [82.15921783, 18.78811073], [82.15170288, 18.78380013], [82.15001678, 18.77869987], [82.14547729, 18.77327919], [82.13897705, 18.76954079], [82.13066101, 18.77009964], [82.1281662, 18.76432037], [82.12906647, 18.75765038], [82.11392212, 18.76066017], [82.10572815, 18.75844955], [82.09129333, 18.75617981], [82.08470917, 18.75839996], [82.08141327, 18.75587082], [82.08674622, 18.74693108], [82.0848999, 18.73269081], [82.08048248, 18.72274017], [82.07858276, 18.71208191], [82.07398224, 18.7130909], [82.06739044, 18.71710968], [82.06128693, 18.71800995], [82.05912781, 18.71778107], [82.05799103, 18.71251106], [82.05175781, 18.71183968], [82.04943085, 18.7175808], [82.03949738, 18.71704102], [82.03373718, 18.71879959], [82.01561737, 18.71353149], [82.00998688, 18.7105999], [81.99772644, 18.7004509], [81.99186707, 18.69769096], [81.97603607, 18.69514847], [81.96768188, 18.69061279], [81.96386719, 18.68779945], [81.95716095, 18.68341064], [81.95507813, 18.68022919], [81.96063232, 18.66772079], [81.95163727, 18.66098022], [81.9473877, 18.65571022], [81.94592285, 18.64637947], [81.94608307, 18.64048958], [81.94832611, 18.63278961], [81.9474411, 18.62882042], [81.93557739, 18.63289833], [81.91552734, 18.63582039], [81.90914154, 18.6409893], [81.9048996, 18.64639282], [81.89483643, 18.65196037], [81.89317322, 18.65388107], [81.88537598, 18.65032959], [81.89000702, 18.64347076], [81.88931274, 18.64112854], [81.88820648, 18.6373806], [81.88780212, 18.63162994], [81.88729095, 18.62438965], [81.8883667, 18.62099075], [81.89993286, 18.61960983], [81.91303253, 18.6129303], [81.92623138, 18.60322952], [81.92971802, 18.59638977], [81.9330368, 18.59465027], [81.93847656, 18.59179115], [81.94888306, 18.58954048], [81.95452881, 18.58670998], [81.94576263, 18.57491112], [81.943573, 18.56615829], [81.94534302, 18.56245041], [81.94690704, 18.5591507], [81.94625854, 18.55841064], [81.94352722, 18.55541992], [81.93624115, 18.55770111], [81.92984772, 18.55800056], [81.92545319, 18.55768013], [81.92019653, 18.55730057], [81.91639709, 18.559021], [81.91316986, 18.56118965], [81.90859985, 18.56422806], [81.90080261, 18.55717087], [81.89975739, 18.54904175], [81.89763641, 18.54271126], [81.89794159, 18.53773117], [81.89865112, 18.53615952], [81.90029144, 18.53251839], [81.8968277, 18.52839279], [81.89607239, 18.52843094], [81.88259888, 18.52918053], [81.87867737, 18.52627945], [81.87538147, 18.5214119], [81.87361908, 18.51993942], [81.8707962, 18.51758957], [81.86805725, 18.51748276], [81.86296082, 18.51727295], [81.85794067, 18.51305962], [81.85302734, 18.50732994], [81.84896088, 18.50060081], [81.84958649, 18.48904991], [81.84430695, 18.48154068], [81.82892609, 18.46895027], [81.79756927, 18.43976021], [81.76738739, 18.41477013], [81.76210022, 18.4113102], [81.76036835, 18.39982986], [81.75554657, 18.38624954], [81.74675751, 18.35550117], [81.74607849, 18.35174179], [81.74491119, 18.34535027], [81.73707581, 18.34422112], [81.71750641, 18.34320068], [81.69924164, 18.34357071], [81.68078613, 18.34103012], [81.65809631, 18.33929062], [81.65280914, 18.33667946], [81.64916992, 18.33100128], [81.64937592, 18.33057976], [81.65245819, 18.32478905], [81.6603775, 18.31575966], [81.65866852, 18.3110981], [81.64675903, 18.31150055], [81.63214111, 18.3080101], [81.62761688, 18.30487061], [81.6213913, 18.30372238], [81.61588287, 18.30084038], [81.60611725, 18.2994194], [81.59687042, 18.30211067], [81.59340668, 18.30128098], [81.59203339, 18.29747963], [81.59050751, 18.29333115], [81.58624268, 18.29215813], [81.58178711, 18.28816032], [81.57401276, 18.28116989], [81.56759644, 18.27321053], [81.54807281, 18.26213074], [81.53945923, 18.26210976], [81.52796173, 18.25908089], [81.52368164, 18.24865913], [81.52577209, 18.23652077], [81.52287292, 18.22737122], [81.51113892, 18.20194054], [81.50878906, 18.1925106], [81.504776, 18.18381119], [81.50524902, 18.17778969], [81.50892639, 18.17407036], [81.51487732, 18.17217064], [81.5226059, 18.15727043], [81.52173615, 18.14830971], [81.51580048, 18.13993073], [81.51187897, 18.1292305], [81.51072693, 18.10387993], [81.50865936, 18.09241104], [81.49684906, 18.07271194], [81.49600983, 18.07069969], [81.49516296, 18.06868935], [81.49488068, 18.06266022], [81.49465942, 18.05800056], [81.48149872, 18.04992294], [81.47751617, 18.03872108], [81.47389221, 18.02851105], [81.47750092, 18.01999283], [81.47894287, 18.00370026], [81.47767639, 17.9935112], [81.47451019, 17.98870277], [81.47307587, 17.98328972], [81.47666931, 17.97389984], [81.47688293, 17.97265053], [81.47731018, 17.97002029], [81.47644043, 17.96763039], [81.47567749, 17.96708107], [81.47325897, 17.96532059], [81.46695709, 17.95490074], [81.45479584, 17.94655991], [81.44523621, 17.92617035], [81.44510651, 17.92546844], [81.44445801, 17.92210007], [81.44592285, 17.91717911], [81.44621277, 17.91028023], [81.44806671, 17.90714073], [81.44818115, 17.9050808], [81.44827271, 17.90302086], [81.4437027, 17.89323044], [81.44274902, 17.88516045], [81.44026184, 17.87914085], [81.43725586, 17.87593842], [81.43595886, 17.87544823], [81.43450928, 17.87490082], [81.4302063, 17.87467957], [81.42312622, 17.87742043], [81.41166687, 17.88539124], [81.40376282, 17.88859177], [81.39901733, 17.88849068], [81.39585114, 17.88755989], [81.39382935, 17.88513947], [81.39050293, 17.87429047], [81.38954926, 17.8621006], [81.38987732, 17.85943031], [81.39805603, 17.84678078], [81.39736938, 17.84364128], [81.39334106, 17.83582115], [81.38442993, 17.82579041], [81.38378906, 17.82348824], [81.38300323, 17.82057953], [81.38304901, 17.81695175], [81.38310242, 17.81414032], [81.38497162, 17.80659294], [81.38413239, 17.80348969], [81.3744278, 17.80532074], [81.36760712, 17.8080883], [81.36107635, 17.80961037], [81.35749817, 17.81042099], [81.3445282, 17.81158066], [81.33537292, 17.81125069], [81.32598877, 17.81241035], [81.31505585, 17.81233978], [81.29812622, 17.80985069], [81.2633667, 17.81046295], [81.25403595, 17.81212997], [81.2279129, 17.82629013], [81.22036743, 17.82935905], [81.21349335, 17.83304977], [81.1919632, 17.84710121], [81.18730164, 17.84834099], [81.18379211, 17.84926987], [81.17637634, 17.84912109], [81.15956879, 17.85263062], [81.12124634, 17.82832909], [81.10903168, 17.82312012], [81.09770203, 17.81710052], [81.08908844, 17.81087112], [81.08708191, 17.80334282], [81.07956696, 17.79497147], [81.07647705, 17.79050064], [81.07360077, 17.78629112], [81.06910706, 17.78511047], [81.06581116, 17.78424072], [81.06128693, 17.78359032], [81.05597687, 17.78283119], [81.04522705, 17.78399086], [81.03765106, 17.78623962], [81.03244781, 17.78973007], [81.01257324, 17.81666946], [81.00434875, 17.83834839], [81.00332642, 17.8491497], [81.0018692, 17.86473083], [80.99723816, 17.89516068], [80.99433899, 17.91423035], [80.99196625, 17.91937065], [80.98464966, 17.92290115], [80.98329163, 17.93495178], [80.98058319, 17.93985939]]]}}, {\\\"id\\\": \\\"6\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.8_1\\\", \\\"HASC_1\\\": \\\"IN.DN\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Dadra and Nagar Haveli\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": \\\"DAdra et Nagar Haveli|Dadra e Nagar Haveli\\\", \\\"apm25_popweighted\\\": -7.3, \\\"dalys_apm25_rate_6cod_mean_total\\\": 982.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1565.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -582.0, \\\"geo-id\\\": 6, \\\"hpm25_child_popweighted\\\": -260.0, \\\"hpm25_female_popweighted\\\": -299.0, \\\"hpm25_male_popweighted\\\": -215.0, \\\"location\\\": \\\"Dadra and Nagar Haveli\\\", \\\"mort_apm25_6cod_mean_total\\\": 110.0, \\\"mort_hpm25_6cod_mean_total\\\": -181.0, \\\"mort_tpm25_6cod_mean_total\\\": -71.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[73.02468109, 20.09630013], [73.01954651, 20.10502052], [73.01020813, 20.11040115], [73.01499176, 20.12486076], [73.01667023, 20.13049126], [73.01702118, 20.1324501], [73.01747894, 20.13495827], [73.01051331, 20.14022255], [73.00875854, 20.13701057], [73.00763702, 20.13246918], [73.00771332, 20.12940025], [73.00778198, 20.12639046], [73.00727844, 20.12412071], [73.00665283, 20.12125015], [73.00431061, 20.11791992], [72.9941864, 20.11390114], [72.98924255, 20.11321259], [72.98532104, 20.113451], [72.97962952, 20.12529945], [72.97322845, 20.13080025], [72.98596191, 20.15752983], [72.98623657, 20.16271973], [72.98668671, 20.17131042], [72.98603821, 20.17654991], [72.97619629, 20.18001938], [72.97592163, 20.18959808], [72.97042847, 20.21232986], [72.97437286, 20.21497154], [72.97543335, 20.21920013], [72.9744873, 20.22583961], [72.96962738, 20.23394012], [72.96534729, 20.23718071], [72.95778656, 20.24115181], [72.95146942, 20.24357033], [72.94367218, 20.24488068], [72.9408493, 20.24682045], [72.92375183, 20.26819992], [72.92230988, 20.27440071], [72.92459106, 20.27865982], [72.930336, 20.28397942], [72.93811035, 20.28800964], [72.94142151, 20.29212761], [72.94597626, 20.29343033], [72.95078278, 20.2920208], [72.95749664, 20.28770065], [72.96977997, 20.27474022], [72.9744873, 20.27178001], [72.98005676, 20.27075005], [72.98409271, 20.27168083], [72.98779297, 20.27466965], [72.98947144, 20.27753067], [72.99046326, 20.29208946], [73.00357056, 20.29314041], [73.01048279, 20.29236984], [73.01728821, 20.29053116], [73.02049255, 20.29090118], [73.02179718, 20.2927475], [73.02217102, 20.29706955], [73.02056885, 20.30207825], [73.02053833, 20.30751991], [73.01760101, 20.31549263], [73.01983643, 20.31739807], [73.02226257, 20.31585121], [73.02469635, 20.31279945], [73.02696228, 20.30380058], [73.02651978, 20.29412079], [73.02979279, 20.29226112], [73.03726959, 20.29059982], [73.04197693, 20.2902298], [73.04416656, 20.2911129], [73.04586029, 20.29243279], [73.0475769, 20.3044529], [73.04767609, 20.31661034], [73.05047607, 20.32299805], [73.05512238, 20.32524109], [73.06204224, 20.32574081], [73.06668091, 20.32608032], [73.07151031, 20.32716942], [73.07525635, 20.3296299], [73.08273315, 20.32912064], [73.08628845, 20.32611084], [73.08863068, 20.32648277], [73.09089661, 20.32683945], [73.09741211, 20.33509827], [73.09916687, 20.33993912], [73.10132599, 20.35603905], [73.10212708, 20.35845947], [73.10253143, 20.35967064], [73.10338593, 20.3603611], [73.10542297, 20.36054039], [73.1073761, 20.36071014], [73.11138153, 20.35609818], [73.11425018, 20.35279083], [73.11638641, 20.34716034], [73.11801147, 20.34287071], [73.12145996, 20.3364296], [73.12195587, 20.33287811], [73.11888123, 20.32620049], [73.11650848, 20.31270981], [73.11440277, 20.3106308], [73.11286926, 20.30494118], [73.11566162, 20.30404091], [73.1291275, 20.30578041], [73.1342926, 20.30532837], [73.13931274, 20.30957985], [73.14015198, 20.31468964], [73.1417923, 20.31746101], [73.14731598, 20.31682968], [73.15242004, 20.31747055], [73.16139984, 20.31719017], [73.16551971, 20.31592941], [73.16838074, 20.31380081], [73.17073822, 20.31052971], [73.17710114, 20.31232262], [73.17801666, 20.31071091], [73.17753601, 20.30907059], [73.17710876, 20.30759811], [73.17698669, 20.30088043], [73.17954254, 20.28986168], [73.17887878, 20.28646088], [73.17578888, 20.28417015], [73.17195129, 20.28250122], [73.1690979, 20.28231812], [73.16680145, 20.28341103], [73.1654129, 20.28703117], [73.16129303, 20.29179192], [73.15820313, 20.29048157], [73.15625763, 20.28742981], [73.15519714, 20.28541946], [73.15513611, 20.28236008], [73.1542511, 20.27934837], [73.15355682, 20.2770195], [73.15254211, 20.27667999], [73.14987183, 20.28012276], [73.1469574, 20.28104973], [73.14628601, 20.28053093], [73.14270782, 20.27528954], [73.14260101, 20.26863098], [73.14095306, 20.26523018], [73.13684845, 20.26046944], [73.1280365, 20.25850105], [73.12458038, 20.25671959], [73.11331177, 20.24418068], [73.10852051, 20.23855019], [73.110466, 20.23213005], [73.10192871, 20.22894287], [73.0875473, 20.23397255], [73.08187866, 20.23281288], [73.07685852, 20.22980118], [73.07036591, 20.22145081], [73.0642395, 20.20316124], [73.0666275, 20.19787979], [73.0703125, 20.19745064], [73.07048035, 20.19737053], [73.07303619, 20.19613075], [73.07435608, 20.19252014], [73.07422638, 20.17728043], [73.07244873, 20.16345024], [73.07553101, 20.16007996], [73.08244324, 20.15658951], [73.08648682, 20.1570015], [73.08790588, 20.16575813], [73.08991241, 20.17043114], [73.09348297, 20.17389107], [73.09616089, 20.17424011], [73.09790802, 20.17334938], [73.0994873, 20.17257118], [73.10182953, 20.16410828], [73.10334015, 20.16134834], [73.10514069, 20.15996933], [73.10910034, 20.15920067], [73.11302948, 20.1584301], [73.1167984, 20.15879059], [73.11974335, 20.15906906], [73.12259674, 20.15775108], [73.12494659, 20.15666008], [73.12802887, 20.15711975], [73.12555695, 20.16109276], [73.12606049, 20.16362762], [73.13260651, 20.16777039], [73.13582611, 20.17231941], [73.13947296, 20.1731205], [73.14702606, 20.17105293], [73.15007019, 20.17284012], [73.1523819, 20.17605972], [73.15213013, 20.17974281], [73.14839935, 20.18548012], [73.14602661, 20.18739128], [73.14157104, 20.20186996], [73.1421814, 20.20438957], [73.14575195, 20.20697975], [73.14981842, 20.20560074], [73.15223694, 20.20318985], [73.15284729, 20.2027607], [73.15364075, 20.20222092], [73.16351318, 20.20146942], [73.16895294, 20.19968987], [73.17298126, 20.20132065], [73.18017578, 20.20860863], [73.18113708, 20.20240021], [73.1885376, 20.20062065], [73.19132996, 20.19860268], [73.19586945, 20.19752121], [73.20440674, 20.19832039], [73.20993042, 20.19735146], [73.21615601, 20.19278908], [73.21936798, 20.19043922], [73.2277832, 20.18704987], [73.22915649, 20.18429947], [73.22833252, 20.18009949], [73.22673035, 20.17636108], [73.2220993, 20.17142105], [73.21775055, 20.16813278], [73.19924164, 20.16164017], [73.19609833, 20.15611267], [73.19532776, 20.15093994], [73.19597626, 20.13994026], [73.20069122, 20.12969971], [73.21095276, 20.12360001], [73.21631622, 20.12199974], [73.21774292, 20.10634041], [73.21911621, 20.09749985], [73.21393585, 20.09064102], [73.20691681, 20.08371162], [73.20289612, 20.08105087], [73.19803619, 20.07781029], [73.19890594, 20.06227112], [73.18586731, 20.05290031], [73.18379974, 20.0522995], [73.18144226, 20.05162048], [73.17539215, 20.05805016], [73.17022705, 20.06560135], [73.16329956, 20.07311058], [73.15674591, 20.07395935], [73.1444931, 20.07785988], [73.13954163, 20.08427048], [73.13669586, 20.08525085], [73.13140106, 20.07942963], [73.12967682, 20.07884026], [73.12773895, 20.07816124], [73.12612152, 20.07809067], [73.1231308, 20.07793999], [73.11754608, 20.07880974], [73.11183167, 20.08301163], [73.11038208, 20.08461189], [73.10794067, 20.08732033], [73.1051712, 20.08721924], [73.09844971, 20.09366989], [73.08831787, 20.09446907], [73.07823181, 20.09527016], [73.06063843, 20.09906006], [73.05799103, 20.09673119], [73.05921173, 20.06793022], [73.05281067, 20.06767082], [73.04527283, 20.07178116], [73.03852844, 20.0780983], [73.03177643, 20.08442116], [73.02468109, 20.09630013]]]}}, {\\\"id\\\": \\\"7\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.9_1\\\", \\\"HASC_1\\\": \\\"IN.DD\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Daman and Diu\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -7.6, \\\"dalys_apm25_rate_6cod_mean_total\\\": 981.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1560.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -579.0, \\\"geo-id\\\": 7, \\\"hpm25_child_popweighted\\\": -260.0, \\\"hpm25_female_popweighted\\\": -299.0, \\\"hpm25_male_popweighted\\\": -215.0, \\\"location\\\": \\\"Daman and Diu\\\", \\\"mort_apm25_6cod_mean_total\\\": 200.0, \\\"mort_hpm25_6cod_mean_total\\\": -326.0, \\\"mort_tpm25_6cod_mean_total\\\": -127.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[72.88378143, 20.370224], [72.87988281, 20.3707695], [72.87520599, 20.3728199], [72.86501312, 20.37241173], [72.85894775, 20.37434006], [72.8353653, 20.37371254], [72.83132935, 20.36873817], [72.82649231, 20.36676025], [72.8215332, 20.3710804], [72.82178497, 20.37101936], [72.8215332, 20.37125015], [72.82125092, 20.37125015], [72.82125092, 20.37152863], [72.8215332, 20.3715229], [72.8215332, 20.37292099], [72.82180023, 20.37292099], [72.82180023, 20.37375069], [72.82208252, 20.37375069], [72.82208252, 20.37430954], [72.82235718, 20.37430954], [72.82235718, 20.37486076], [72.82263947, 20.37486076], [72.82263947, 20.37541962], [72.82290649, 20.37541962], [72.82290649, 20.37625122], [72.82319641, 20.37624931], [72.82319641, 20.37708282], [72.82347107, 20.37708282], [72.82347107, 20.37819481], [72.82375336, 20.37819099], [72.82375336, 20.37903023], [72.82402802, 20.37902641], [72.82402802, 20.37986183], [72.82430267, 20.37985992], [72.82430267, 20.38042068], [72.82458496, 20.38041878], [72.82458496, 20.38124847], [72.82485962, 20.38124847], [72.82485962, 20.38208389], [72.82514191, 20.38207817], [72.82514191, 20.38264084], [72.82541656, 20.38264084], [72.82541656, 20.38347244], [72.82569122, 20.38345909], [72.82569122, 20.38402939], [72.82597351, 20.38402748], [72.82597351, 20.38458252], [72.82624817, 20.38458252], [72.82624817, 20.38513947], [72.82653046, 20.38513947], [72.82653046, 20.3856945], [72.82680511, 20.3856945], [72.82681274, 20.38680077], [72.82707977, 20.38680649], [72.82707977, 20.38736153], [72.82763672, 20.38735962], [72.82763672, 20.38764], [72.82791901, 20.38763809], [72.82791901, 20.3884716], [72.82763672, 20.3884697], [72.82763672, 20.38903046], [72.82736206, 20.38903046], [72.82736206, 20.39014053], [72.82763672, 20.39013863], [72.82763672, 20.39069366], [72.82791901, 20.39069366], [72.82791901, 20.39208412], [72.82819366, 20.39208412], [72.82819366, 20.39458275], [72.82847595, 20.39458084], [72.82847595, 20.40042114], [72.82875061, 20.40041733], [72.82875061, 20.4034729], [72.82847595, 20.40347099], [72.82847595, 20.40513992], [72.82875061, 20.40513992], [72.82875061, 20.40624809], [72.82902527, 20.40624809], [72.82902527, 20.40708351], [72.82930756, 20.40708351], [72.82930756, 20.40819359], [72.82958221, 20.40819359], [72.82958221, 20.40847015], [72.82985687, 20.40846825], [72.82985687, 20.40903091], [72.83013916, 20.4090271], [72.83013916, 20.40958405], [72.83040619, 20.40958023], [72.83040619, 20.40986252], [72.83069611, 20.40986252], [72.83069611, 20.4101429], [72.83097076, 20.4101429], [72.83097076, 20.41041946], [72.83125305, 20.41041756], [72.83125305, 20.41122818], [72.83125305, 20.41263962], [72.83069611, 20.41263962], [72.83069611, 20.41319466], [72.83041382, 20.41319466], [72.83041382, 20.41347313], [72.83013916, 20.41347122], [72.83013916, 20.41374969], [72.8298645, 20.41374969], [72.8298645, 20.41430473], [72.82958221, 20.41430092], [72.82958221, 20.41542053], [72.82930756, 20.41542053], [72.82930756, 20.42124748], [72.82902527, 20.42124748], [72.82902527, 20.42569351], [72.82875061, 20.42569542], [72.82875061, 20.4295826], [72.82847595, 20.42958069], [72.82847595, 20.42986107], [72.82819366, 20.42986107], [72.82819366, 20.43208313], [72.82847595, 20.43208122], [72.82847595, 20.43374825], [72.82875061, 20.43374825], [72.82875061, 20.43431091], [72.8290329, 20.43431091], [72.8290329, 20.43514061], [72.82930756, 20.43514061], [72.82930756, 20.43625259], [72.82958221, 20.43625259], [72.82958221, 20.4370842], [72.82985687, 20.43708038], [72.82985687, 20.43875122], [72.83013916, 20.43874931], [72.83013916, 20.43958473], [72.83040619, 20.43958282], [72.83040619, 20.44042015], [72.83069611, 20.44041634], [72.83069611, 20.44097137], [72.83097076, 20.44096947], [72.83097076, 20.44153023], [72.83125305, 20.44152832], [72.83125305, 20.44208336], [72.83152771, 20.44207954], [72.83152771, 20.4426403], [72.83180237, 20.4426384], [72.83180237, 20.44347191], [72.83207703, 20.44347], [72.83207703, 20.44403076], [72.83235931, 20.44403076], [72.83235931, 20.44486046], [72.8326416, 20.44486046], [72.8326416, 20.44597244], [72.83291626, 20.44597054], [72.83291626, 20.44625092], [72.83347321, 20.44625092], [72.83347321, 20.44652748], [72.83374786, 20.44652748], [72.83374786, 20.44680595], [72.83403015, 20.44680023], [72.83403015, 20.44735909], [72.8345871, 20.44735909], [72.8345871, 20.44791985], [72.83486176, 20.44791603], [72.83486176, 20.4481945], [72.83513641, 20.44819069], [72.83513641, 20.44875145], [72.8354187, 20.44875145], [72.8354187, 20.44903183], [72.83569336, 20.44902992], [72.83569336, 20.44986153], [72.83598328, 20.44986153], [72.83598328, 20.45014191], [72.83625031, 20.45014191], [72.83625031, 20.45042038], [72.83652496, 20.45041656], [72.83652496, 20.45125008], [72.83679962, 20.45125008], [72.83679962, 20.45153046], [72.83708191, 20.45153046], [72.83708191, 20.45181084], [72.83735657, 20.45181084], [72.8373642, 20.45236015], [72.83763885, 20.45236015], [72.83763885, 20.45264053], [72.83791351, 20.45263863], [72.83791351, 20.45319366], [72.8381958, 20.45319366], [72.8381958, 20.45347214], [72.83847046, 20.45347023], [72.83847046, 20.45375061], [72.8390274, 20.45375061], [72.8390274, 20.45403099], [72.83930206, 20.45403099], [72.83930206, 20.45430946], [72.83957672, 20.45430946], [72.83957672, 20.45486069], [72.8401413, 20.45486069], [72.8401413, 20.45514107], [72.84041595, 20.45514107], [72.84041595, 20.45541954], [72.84069824, 20.45541954], [72.84069824, 20.45569992], [72.8409729, 20.4556942], [72.8409729, 20.45597267], [72.84123993, 20.45597076], [72.84124756, 20.45625114], [72.84152985, 20.45624924], [72.84152985, 20.45634842], [72.84152985, 20.45652962], [72.84166718, 20.45652771], [72.8418045, 20.45652771], [72.8418045, 20.45669937], [72.84179688, 20.45681], [72.84191132, 20.45680618], [72.84208679, 20.45680428], [72.84208679, 20.45708275], [72.84236145, 20.45708084], [72.84236145, 20.45736122], [72.84263611, 20.45736122], [72.84263611, 20.45775032], [72.84263611, 20.45792007], [72.84276581, 20.45791626], [72.8429184, 20.45791626], [72.8429184, 20.45819473], [72.84347534, 20.45819473], [72.84347534, 20.4584713], [72.84401703, 20.45846939], [72.84401703, 20.45902824], [72.84430695, 20.45902634], [72.84430695, 20.45930481], [72.8445816, 20.45930481], [72.8445816, 20.45958328], [72.84541321, 20.45958328], [72.84541321, 20.45986176], [72.84597015, 20.45986176], [72.84597015, 20.45958328], [72.84625244, 20.45957947], [72.84625244, 20.46013832], [72.84680176, 20.46013832], [72.84680939, 20.46042061], [72.84764099, 20.46042061], [72.84764099, 20.46069908], [72.84791565, 20.46069527], [72.84791565, 20.46097183], [72.8484726, 20.46096992], [72.8484726, 20.4612484], [72.84902954, 20.4612484], [72.84902954, 20.46153069], [72.8493042, 20.46152687], [72.8493042, 20.46180534], [72.84986115, 20.46180534], [72.84986115, 20.46208382], [72.8501358, 20.46207809], [72.8501358, 20.46264076], [72.85041809, 20.46264076], [72.85041809, 20.46292114], [72.85124969, 20.46291733], [72.85124969, 20.46319389], [72.85152435, 20.46319389], [72.85152435, 20.46347237], [72.8520813, 20.46347237], [72.8520813, 20.46319389], [72.85236359, 20.46319389], [72.85236359, 20.46347237], [72.8529129, 20.46347237], [72.8529129, 20.46375275], [72.85320282, 20.46375275], [72.85320282, 20.46403122], [72.85346985, 20.4640274], [72.85346985, 20.46458054], [72.85375214, 20.46458054], [72.85375214, 20.46487045], [72.85402679, 20.46487045], [72.85402679, 20.46513939], [72.85430908, 20.46513939], [72.85430908, 20.46569443], [72.85514069, 20.46569443], [72.85514069, 20.46597481], [72.85597229, 20.46597481], [72.85597229, 20.46569443], [72.85624695, 20.46569443], [72.85624695, 20.46541595], [72.85679626, 20.46541977], [72.85679626, 20.46513939], [72.85708618, 20.46513939], [72.85708618, 20.46487045], [72.85874939, 20.46487045], [72.85874939, 20.46458054], [72.85901642, 20.46458054], [72.85901642, 20.46487045], [72.85930634, 20.46487045], [72.85930634, 20.46541977], [72.85902405, 20.46541595], [72.85902405, 20.46569443], [72.85874939, 20.46569443], [72.85874939, 20.46597481], [72.8584671, 20.4659729], [72.8584671, 20.46681023], [72.85874939, 20.46680641], [72.85874939, 20.46708488], [72.85901642, 20.46708107], [72.85901642, 20.46763992], [72.85930634, 20.46763992], [72.85930634, 20.46820068], [72.85958099, 20.46820068], [72.85958099, 20.46875], [72.85986328, 20.46875], [72.85986328, 20.47042084], [72.86013794, 20.47041512], [72.86013794, 20.47096062], [72.86340332, 20.46883965], [72.86589813, 20.46751022], [72.8664093, 20.46469688], [72.87428284, 20.46296692], [72.88248444, 20.46276665], [72.88564301, 20.45907021], [72.88744354, 20.45333099], [72.89000702, 20.44886017], [72.89334869, 20.44538689], [72.89280701, 20.44166946], [72.88877869, 20.43915558], [72.88488007, 20.44006157], [72.87704468, 20.44462204], [72.87340546, 20.44420815], [72.86811066, 20.434412], [72.86154938, 20.42836952], [72.85932159, 20.42437363], [72.86031342, 20.41961479], [72.86510468, 20.41617584], [72.8688736, 20.41582489], [72.87956238, 20.41846848], [72.88889313, 20.41911316], [72.89583588, 20.42136002], [72.89962769, 20.41921425], [72.90261078, 20.41524124], [72.90330505, 20.41033745], [72.90042114, 20.40526772], [72.88951111, 20.3982811], [72.88632202, 20.39336777], [72.88685608, 20.38718224], [72.88873291, 20.38420105], [72.89564514, 20.38036346], [72.89637756, 20.37669563], [72.89354706, 20.37214661], [72.88378143, 20.370224]]], [[[70.96263885, 20.72938156], [70.96263885, 20.72903061], [70.96235657, 20.72903061], [70.96235657, 20.72846985], [70.96208191, 20.72847176], [70.96208191, 20.72791672], [70.96179962, 20.72792053], [70.96179962, 20.72707939], [70.96152496, 20.72708321], [70.96152496, 20.72597313], [70.96125031, 20.72597313], [70.96125031, 20.72319412], [70.96152496, 20.72319412], [70.96152496, 20.72263908], [70.96179962, 20.72264099], [70.96179962, 20.72236061], [70.96208191, 20.72236061], [70.96208191, 20.72208023], [70.9623642, 20.72208595], [70.9623642, 20.72180557], [70.96290588, 20.72180939], [70.96290588, 20.72153091], [70.96347046, 20.72153091], [70.96347046, 20.72180939], [70.96375275, 20.72180939], [70.96375275, 20.72153091], [70.9640274, 20.72153091], [70.9640274, 20.72180939], [70.9651413, 20.72180557], [70.9651413, 20.72208595], [70.96541595, 20.72208023], [70.96541595, 20.72291946], [70.96347046, 20.72291756], [70.96347046, 20.72319412], [70.96291351, 20.72319412], [70.96291351, 20.7234726], [70.96263885, 20.72347069], [70.96263885, 20.72513962], [70.96291351, 20.72513962], [70.96291351, 20.72569466], [70.9631958, 20.72569466], [70.9631958, 20.72597313], [70.96347046, 20.72597122], [70.96347046, 20.72652817], [70.96375275, 20.72652626], [70.96375275, 20.72680473], [70.9640274, 20.72680473], [70.9640274, 20.72708321], [70.96430206, 20.72708321], [70.96430206, 20.72736168], [70.96457672, 20.72735977], [70.96457672, 20.72763824], [70.96485901, 20.72763824], [70.96485901, 20.72792053], [70.9651413, 20.72792053], [70.9651413, 20.72820091], [70.96541595, 20.72819519], [70.96541595, 20.72847176], [70.96763611, 20.72847176], [70.96763611, 20.72819519], [70.96819305, 20.72820091], [70.96819305, 20.72792053], [70.96901703, 20.72792053], [70.96901703, 20.72763824], [70.97070313, 20.72763824], [70.97070313, 20.72707939], [70.97180176, 20.72708321], [70.97180176, 20.72680473], [70.9723587, 20.72680473], [70.9723587, 20.72652626], [70.97292328, 20.72652817], [70.97292328, 20.72624969], [70.97374725, 20.72624969], [70.97373962, 20.72597122], [70.97458649, 20.72597313], [70.97458649, 20.72569466], [70.97541809, 20.72569466], [70.97541809, 20.72541618], [70.97569275, 20.72541809], [70.97569275, 20.72513962], [70.97598267, 20.72513962], [70.97597504, 20.72486115], [70.97624969, 20.72486115], [70.97624969, 20.72430992], [70.97651672, 20.72430992], [70.97651672, 20.72402954], [70.97679901, 20.72402954], [70.97679901, 20.72375107], [70.9770813, 20.72375107], [70.9770813, 20.72319031], [70.97736359, 20.72319412], [70.97736359, 20.72291756], [70.97763824, 20.72291946], [70.97763824, 20.72264099], [70.9779129, 20.72264099], [70.9779129, 20.72236061], [70.97820282, 20.72236061], [70.97819519, 20.72208595], [70.97875214, 20.72208595], [70.97875214, 20.72180557], [70.97902679, 20.72180939], [70.97902679, 20.72153091], [70.97930908, 20.72153091], [70.97930908, 20.72125053], [70.97957611, 20.72125053], [70.97957611, 20.72068977], [70.9798584, 20.72069359], [70.9798584, 20.72041702], [70.98152924, 20.72042084], [70.98152924, 20.72014046], [70.98236084, 20.72014046], [70.98236084, 20.71986008], [70.9834671, 20.71986008], [70.9834671, 20.72014046], [70.98596954, 20.72014046], [70.98596954, 20.71986008], [70.98625183, 20.71986389], [70.98625183, 20.71958351], [70.98652649, 20.71958351], [70.98652649, 20.71930504], [70.98764038, 20.71931076], [70.98764038, 20.71903038], [70.98958588, 20.71903038], [70.98958588, 20.71875191], [70.99014282, 20.71875191], [70.99013519, 20.71847343], [70.99069214, 20.71847343], [70.99069214, 20.71819496], [70.9909668, 20.71820068], [70.9909668, 20.7179203], [70.99124908, 20.7179203], [70.99124908, 20.71735954], [70.99153137, 20.71735954], [70.99153137, 20.71708107], [70.99208069, 20.71708107], [70.99208069, 20.71680641], [70.99318695, 20.71681023], [70.99318695, 20.71653175], [70.99402618, 20.71653175], [70.99402618, 20.71624947], [70.9970932, 20.71624947], [70.99708557, 20.7159729], [70.99736023, 20.7159729], [70.99736023, 20.71569443], [70.99764252, 20.71569443], [70.99764252, 20.71442032], [70.99764252, 20.7140274], [70.99736023, 20.71403122], [70.99736023, 20.71347046], [70.99708557, 20.71347237], [70.99708557, 20.71319389], [70.99680328, 20.71319389], [70.99680328, 20.71291733], [70.99624634, 20.71292114], [70.99624634, 20.71236038], [70.99597168, 20.71236038], [70.99597168, 20.71208], [70.99514008, 20.71208382], [70.99514008, 20.71180534], [70.99487305, 20.71181107], [70.99487305, 20.71125031], [70.99458313, 20.71125031], [70.99458313, 20.71096992], [70.99430847, 20.71097183], [70.99430847, 20.71069527], [70.99346924, 20.71070099], [70.99346924, 20.71042061], [70.99291992, 20.71042061], [70.99291992, 20.71014023], [70.99153137, 20.71014023], [70.99153137, 20.70985985], [70.99041748, 20.70986176], [70.99041748, 20.70930672], [70.99013519, 20.70930672], [70.99013519, 20.70902824], [70.98986053, 20.70903015], [70.98986053, 20.70874977], [70.98958588, 20.70874977], [70.98958588, 20.70845985], [70.98902893, 20.70845985], [70.98902893, 20.70874977], [70.98873901, 20.70874977], [70.98873901, 20.70903015], [70.98847198, 20.70902824], [70.98847198, 20.70930672], [70.98791504, 20.70930672], [70.98791504, 20.70958328], [70.98680878, 20.70958328], [70.98680878, 20.70930672], [70.98569489, 20.70930672], [70.98569489, 20.70902824], [70.98513794, 20.70903015], [70.98513794, 20.70845985], [70.98486328, 20.7084713], [70.98486328, 20.70791626], [70.98458099, 20.70792007], [70.98458099, 20.70763969], [70.9834671, 20.70763969], [70.9834671, 20.70736122], [70.98208618, 20.70736122], [70.98208618, 20.70708275], [70.98152924, 20.70708466], [70.98152924, 20.70680618], [70.98097229, 20.70681], [70.98097229, 20.70652962], [70.98042297, 20.70652962], [70.98042297, 20.70625114], [70.98014069, 20.70625114], [70.98014069, 20.70597267], [70.97930908, 20.70597267], [70.97930908, 20.7056942], [70.97902679, 20.7056942], [70.97902679, 20.70541763], [70.97875214, 20.70541954], [70.97875214, 20.70458031], [70.97846985, 20.70458412], [70.97846985, 20.70430565], [70.97820282, 20.70430946], [70.97820282, 20.7040329], [70.9779129, 20.7040329], [70.9779129, 20.70375252], [70.97763824, 20.70375252], [70.97763824, 20.70347023], [70.97736359, 20.70347023], [70.97736359, 20.70205116], [70.97736359, 20.70180511], [70.9770813, 20.70181084], [70.9770813, 20.70153046], [70.97624969, 20.70153046], [70.97624969, 20.70181084], [70.97597504, 20.70180511], [70.97597504, 20.70197105], [70.97597504, 20.70208359], [70.97569275, 20.70207977], [70.97569275, 20.70292091], [70.97597504, 20.7029171], [70.97597504, 20.70319366], [70.97624969, 20.70318985], [70.97624969, 20.7040329], [70.97429657, 20.7040329], [70.97429657, 20.70375252], [70.97292328, 20.70375252], [70.97292328, 20.7040329], [70.97264099, 20.70402718], [70.97264099, 20.70458412], [70.9723587, 20.70458412], [70.9723587, 20.70430565], [70.97207642, 20.70430946], [70.97207642, 20.7040329], [70.9715271, 20.7040329], [70.9715271, 20.70430946], [70.9706955, 20.70430565], [70.9706955, 20.70458412], [70.97041321, 20.70458031], [70.97041321, 20.70486259], [70.96985626, 20.70486259], [70.96985626, 20.70541954], [70.97013855, 20.70541573], [70.97013855, 20.7056942], [70.97041321, 20.70569038], [70.97041321, 20.70681], [70.97013855, 20.70680618], [70.97013855, 20.70708466], [70.96736145, 20.70708466], [70.96736145, 20.70680618], [70.96679687, 20.70681], [70.96679687, 20.70652962], [70.96624756, 20.70652962], [70.96624756, 20.70625114], [70.9659729, 20.70625114], [70.9659729, 20.70597267], [70.96569824, 20.70597267], [70.96569061, 20.7056942], [70.96541595, 20.7056942], [70.96541595, 20.70541763], [70.9640274, 20.70541763], [70.9640274, 20.7056942], [70.96235657, 20.70569038], [70.96235657, 20.70625114], [70.9615097, 20.70625114], [70.9615097, 20.70652962], [70.9604187, 20.70652962], [70.9604187, 20.70681], [70.96013641, 20.70681], [70.96013641, 20.70625114], [70.95986176, 20.70625114], [70.95986176, 20.70597267], [70.95903015, 20.70597267], [70.95903015, 20.7056942], [70.95791626, 20.7056942], [70.95791626, 20.70541763], [70.95774841, 20.70541573], [70.9576416, 20.70541954], [70.9576416, 20.70514107], [70.95735931, 20.70514107], [70.95735931, 20.70486259], [70.95680237, 20.70486259], [70.95680237, 20.70458031], [70.95625305, 20.70458412], [70.95625305, 20.70430565], [70.95597076, 20.70430946], [70.95597076, 20.7040329], [70.95540619, 20.7040329], [70.95540619, 20.70375252], [70.95181274, 20.70375252], [70.95181274, 20.7040329], [70.95096588, 20.7040329], [70.95096588, 20.70430946], [70.95041656, 20.70430565], [70.95041656, 20.70458412], [70.94985962, 20.70458031], [70.94985962, 20.70486259], [70.94875336, 20.70486259], [70.94875336, 20.70514107], [70.94763947, 20.70514107], [70.94763947, 20.70541954], [70.94596863, 20.70541763], [70.94596863, 20.7056942], [70.94374847, 20.7056942], [70.94374847, 20.70597267], [70.94319153, 20.70597267], [70.94319153, 20.70625114], [70.94235992, 20.70625114], [70.94235992, 20.70652962], [70.94152832, 20.70652962], [70.94152832, 20.70681], [70.94097137, 20.70680618], [70.94097137, 20.70708466], [70.93930817, 20.70708275], [70.93930817, 20.70736122], [70.93902588, 20.70736122], [70.93902588, 20.70763969], [70.93875122, 20.70763969], [70.93875122, 20.70792007], [70.93846893, 20.70791626], [70.93846893, 20.70819473], [70.93791962, 20.70819092], [70.93791962, 20.70903015], [70.93763733, 20.70902824], [70.93763733, 20.70930672], [70.93736267, 20.70930672], [70.93736267, 20.70958328], [70.93708038, 20.70958328], [70.93708038, 20.70986176], [70.93653107, 20.70985985], [70.93653107, 20.71014023], [70.93596649, 20.71014023], [70.93596649, 20.71042061], [70.93541718, 20.71042061], [70.93541718, 20.71070099], [70.93458557, 20.71069527], [70.93458557, 20.71097183], [70.9329071, 20.71096992], [70.93291473, 20.71125031], [70.9318161, 20.71125031], [70.9318161, 20.71153069], [70.92930603, 20.71153069], [70.92930603, 20.71181107], [70.92514038, 20.71181107], [70.92514038, 20.71153069], [70.92346954, 20.71153069], [70.92346954, 20.71125031], [70.92263031, 20.71125031], [70.92263031, 20.71096992], [70.92180634, 20.71097183], [70.92180634, 20.71069527], [70.92041779, 20.71070099], [70.92041779, 20.71042061], [70.91929626, 20.71042061], [70.91929626, 20.71014023], [70.91874695, 20.71014023], [70.91874695, 20.70985985], [70.91847229, 20.70986176], [70.91847229, 20.70958328], [70.91764069, 20.70958328], [70.91764069, 20.70930672], [70.9173584, 20.70930672], [70.9173584, 20.70874977], [70.91707611, 20.70874977], [70.91707611, 20.70845985], [70.91652679, 20.7084713], [70.91652679, 20.70819473], [70.91625214, 20.70819473], [70.91625214, 20.70763969], [70.91596985, 20.70763969], [70.91596985, 20.70652962], [70.91570282, 20.70652962], [70.91570282, 20.70569038], [70.9154129, 20.7056942], [70.9154129, 20.70486259], [70.91570282, 20.70486259], [70.91569519, 20.70347023], [70.91596985, 20.70347023], [70.91596985, 20.70263863], [70.91625214, 20.70265007], [70.91625214, 20.70235825], [70.91819763, 20.70235825], [70.91819763, 20.70207977], [70.91791534, 20.70208359], [70.91791534, 20.70153046], [70.91707611, 20.70153046], [70.91707611, 20.70124817], [70.91652679, 20.70124817], [70.91652679, 20.7009697], [70.91569519, 20.7009716], [70.91569519, 20.70069504], [70.9154129, 20.70070076], [70.9154129, 20.70042038], [70.91513824, 20.70042038], [70.91513824, 20.70013809], [70.91485596, 20.70013809], [70.91485596, 20.69985962], [70.91430664, 20.69986153], [70.91430664, 20.69958305], [70.91401672, 20.69959068], [70.91401672, 20.69902992], [70.9126358, 20.69902992], [70.9126358, 20.6993103], [70.91179657, 20.6993103], [70.91179657, 20.70042038], [70.91152954, 20.70041656], [70.91152954, 20.70152092], [70.91152954, 20.70181084], [70.9106369, 20.70181084], [70.91014099, 20.70181084], [70.91014099, 20.70153046], [70.9098587, 20.70153046], [70.9098587, 20.7009697], [70.90930176, 20.7009716], [70.90930176, 20.70069504], [70.90764618, 20.70070076], [70.90764618, 20.70042038], [70.90735626, 20.70042038], [70.90735626, 20.70070076], [70.90625, 20.70070076], [70.90625, 20.70042038], [70.90513611, 20.70042038], [70.90513611, 20.70013809], [70.9034729, 20.70013809], [70.9034729, 20.69985962], [70.9026413, 20.69986153], [70.9026413, 20.69958305], [70.90151978, 20.69959068], [70.90151978, 20.6993103], [70.90125275, 20.6993103], [70.90125275, 20.69902992], [70.90013885, 20.69902992], [70.90013885, 20.69874954], [70.89930725, 20.69874954], [70.89930725, 20.69902992], [70.89901733, 20.69902992], [70.89901733, 20.6993103], [70.89875031, 20.6993103], [70.89875031, 20.69959068], [70.89847565, 20.69958305], [70.89847565, 20.69986153], [70.8979187, 20.69985962], [70.8979187, 20.70013809], [70.89736176, 20.70013809], [70.89736176, 20.70042038], [70.8970871, 20.70041656], [70.8970871, 20.7009716], [70.89736176, 20.7009697], [70.89736176, 20.70124817], [70.89763641, 20.70124817], [70.89763641, 20.70208359], [70.8979187, 20.70207977], [70.8979187, 20.70375252], [70.89763641, 20.70375252], [70.89763641, 20.70430946], [70.89736176, 20.70430946], [70.89736176, 20.70486259], [70.89653015, 20.70486259], [70.89653015, 20.70514107], [70.89624786, 20.70513916], [70.89624786, 20.7056942], [70.89597321, 20.7056942], [70.89597321, 20.70597267], [70.89576721, 20.70597267], [70.89541626, 20.70597267], [70.89541626, 20.70625114], [70.8951416, 20.70625114], [70.8951416, 20.70652962], [70.89485931, 20.70652962], [70.89485931, 20.70681], [70.89458466, 20.70680618], [70.89458466, 20.70708466], [70.89430237, 20.70708275], [70.89430237, 20.70736122], [70.89375305, 20.70736122], [70.89375305, 20.70763969], [70.89290619, 20.70763969], [70.89290619, 20.70792007], [70.89208221, 20.70791626], [70.89208221, 20.70819092], [70.89295959, 20.71302032], [70.89689636, 20.72000122], [70.89965057, 20.7238903], [70.90487671, 20.72652817], [70.92093658, 20.72891045], [70.92965698, 20.73192024], [70.93403625, 20.73595047], [70.93889618, 20.73648834], [70.94854736, 20.73374176], [70.96203613, 20.7292099], [70.96263885, 20.72938156]]]]}}, {\\\"id\\\": \\\"8\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.10_1\\\", \\\"HASC_1\\\": \\\"IN.GA\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Goa\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"G\\\\u00f4a\\\", \\\"apm25_popweighted\\\": -4.8, \\\"dalys_apm25_rate_6cod_mean_total\\\": 445.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -768.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -323.0, \\\"geo-id\\\": 8, \\\"hpm25_child_popweighted\\\": -66.9, \\\"hpm25_female_popweighted\\\": -76.9, \\\"hpm25_male_popweighted\\\": -55.4, \\\"location\\\": \\\"Goa\\\", \\\"mort_apm25_6cod_mean_total\\\": 189.0, \\\"mort_hpm25_6cod_mean_total\\\": -325.0, \\\"mort_tpm25_6cod_mean_total\\\": -135.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[73.77986145, 15.3554163], [73.77986145, 15.35569382], [73.78180695, 15.35569382], [73.78180695, 15.3554163], [73.78235626, 15.35542011], [73.78235626, 15.35513973], [73.78291321, 15.35513973], [73.78291321, 15.35486031], [73.7831955, 15.35486221], [73.7831955, 15.35458374], [73.78347015, 15.35458374], [73.78347015, 15.35430622], [73.78375244, 15.35430622], [73.78375244, 15.35402775], [73.7840271, 15.35402966], [73.7840271, 15.35375023], [73.78430176, 15.35375023], [73.78430939, 15.35346889], [73.78458405, 15.35347176], [73.78458405, 15.35236168], [73.78486633, 15.35236168], [73.7848587, 15.35152817], [73.78457642, 15.35153198], [73.78457642, 15.35124016], [73.78430939, 15.35124874], [73.78430176, 15.35097122], [73.78375244, 15.35097122], [73.78375244, 15.35069561], [73.78347015, 15.35069561], [73.78347015, 15.35041809], [73.78320313, 15.35042], [73.78320313, 15.34958076], [73.78291321, 15.34958267], [73.78291321, 15.34930515], [73.78320313, 15.34930992], [73.78320313, 15.34902954], [73.78291321, 15.34902954], [73.78291321, 15.34875202], [73.7820816, 15.34875202], [73.7820816, 15.34847069], [73.78125, 15.34847069], [73.78125, 15.34875202], [73.78013611, 15.34875202], [73.78013611, 15.34902954], [73.77986145, 15.34902668], [73.77986145, 15.34986115], [73.78013611, 15.34985924], [73.78013611, 15.35042], [73.77986145, 15.35041809], [73.77986145, 15.35069561], [73.77958679, 15.35069561], [73.77958679, 15.35097122], [73.7784729, 15.35097122], [73.7784729, 15.35069561], [73.7776413, 15.35069561], [73.7776413, 15.35041809], [73.77707672, 15.35042], [73.77707672, 15.35013962], [73.77625275, 15.35013962], [73.77625275, 15.34985924], [73.77597046, 15.34985924], [73.77597046, 15.35013962], [73.77375031, 15.35013962], [73.77375031, 15.35042], [73.77319336, 15.35042], [73.77319336, 15.35013962], [73.77236176, 15.35013962], [73.77236176, 15.34985924], [73.77153015, 15.34985924], [73.77153015, 15.35013962], [73.77097321, 15.35013962], [73.77097321, 15.35042], [73.7701416, 15.35041809], [73.7701416, 15.35069561], [73.76958466, 15.35069561], [73.76958466, 15.35097122], [73.76875305, 15.35097122], [73.76875305, 15.35124874], [73.76763916, 15.35124874], [73.76763916, 15.35097122], [73.7673645, 15.35097122], [73.7673645, 15.35069561], [73.76708221, 15.35069561], [73.76708221, 15.35041809], [73.7665329, 15.35042], [73.7665329, 15.35013962], [73.76597595, 15.35013962], [73.76597595, 15.34985924], [73.76486206, 15.34985924], [73.76486206, 15.35013962], [73.76431274, 15.35013962], [73.76431274, 15.35042], [73.76319122, 15.35041809], [73.76319122, 15.35069561], [73.76264191, 15.35069561], [73.76264191, 15.35097122], [73.76235962, 15.35097122], [73.76235962, 15.35124874], [73.76180267, 15.35124016], [73.76180267, 15.35153198], [73.76125336, 15.35153198], [73.76125336, 15.35181046], [73.76097107, 15.35180569], [73.76097107, 15.35208416], [73.76069641, 15.3520813], [73.76069641, 15.35402966], [73.76097107, 15.35402775], [73.76097107, 15.35430622], [73.76125336, 15.35430622], [73.76125336, 15.35458374], [73.76180267, 15.35458374], [73.76180267, 15.35486221], [73.76207733, 15.35486031], [73.76207733, 15.35513973], [73.76291656, 15.35513973], [73.76291656, 15.35486031], [73.76347351, 15.35486221], [73.76347351, 15.35458374], [73.76403046, 15.35458374], [73.76403046, 15.35430622], [73.76430511, 15.35430622], [73.76430511, 15.35402775], [73.76457977, 15.35402966], [73.76457977, 15.35375023], [73.76486206, 15.35375023], [73.76486206, 15.35346889], [73.76513672, 15.35347176], [73.76513672, 15.35319424], [73.76541901, 15.35319424], [73.76541901, 15.35264015], [73.76568604, 15.35264015], [73.76568604, 15.35236168], [73.76679993, 15.35236168], [73.76679993, 15.35264015], [73.76790619, 15.35264015], [73.76790619, 15.35291958], [73.76957703, 15.35291958], [73.76957703, 15.35264015], [73.76986694, 15.35264015], [73.76986694, 15.35291958], [73.77124786, 15.35291767], [73.77124786, 15.35319424], [73.7720871, 15.35319424], [73.7720871, 15.35347176], [73.7729187, 15.35347176], [73.7729187, 15.35375023], [73.77401733, 15.35375023], [73.77401733, 15.35402966], [73.77458191, 15.35402775], [73.77458191, 15.35430622], [73.77735901, 15.35430622], [73.77735901, 15.35458374], [73.77791595, 15.35458374], [73.77791595, 15.35486221], [73.77873993, 15.35486031], [73.77873993, 15.35513973], [73.77929688, 15.35513973], [73.77929688, 15.35542011], [73.77986145, 15.3554163]]], [[[73.79458618, 15.37875175], [73.79458618, 15.37903023], [73.79651642, 15.37903023], [73.79651642, 15.37875175], [73.79736328, 15.37875175], [73.79736328, 15.37847137], [73.79846954, 15.37847137], [73.79846954, 15.37819576], [73.79930878, 15.37819576], [73.79930878, 15.37763977], [73.79902649, 15.37764168], [73.79902649, 15.37569141], [73.79875183, 15.37569332], [73.79875183, 15.37430477], [73.79846954, 15.37430954], [73.79846954, 15.37403202], [73.79818726, 15.37403202], [73.79818726, 15.37375069], [73.79792023, 15.37375069], [73.79792023, 15.37347126], [73.79763794, 15.37347317], [73.79763794, 15.37319469], [73.79736328, 15.37319469], [73.79736328, 15.3726387], [73.79651642, 15.37264061], [73.79651642, 15.37236977], [73.79624939, 15.37236977], [73.79624939, 15.37264061], [73.79569244, 15.37264061], [73.79569244, 15.37292194], [73.7951355, 15.37291718], [73.7951355, 15.37319469], [73.79486084, 15.37319469], [73.79486084, 15.37347317], [73.79458618, 15.37347126], [73.79458618, 15.37375069], [73.79429626, 15.37375069], [73.79429626, 15.37403202], [73.79403687, 15.37403202], [73.79403687, 15.37430954], [73.79374695, 15.37430477], [73.79374695, 15.37458324], [73.79292297, 15.37458134], [73.79292297, 15.37513924], [73.79264069, 15.37513924], [73.79264069, 15.37681007], [73.79292297, 15.37681007], [73.79292297, 15.37764168], [73.79319763, 15.37763977], [73.79319763, 15.37819576], [73.79347229, 15.37819576], [73.79347229, 15.37847137], [73.79403687, 15.37847137], [73.79403687, 15.37875175], [73.79458618, 15.37875175]]], [[[74.04650879, 14.96652889], [74.04624939, 14.96652889], [74.04624939, 14.96708298], [74.0459671, 14.96708107], [74.0459671, 14.96791935], [74.04569244, 14.96791935], [74.04569244, 14.96875095], [74.04541779, 14.96874905], [74.04541779, 14.96958256], [74.04514313, 14.96958065], [74.04514313, 14.97042179], [74.04486084, 14.97042179], [74.04486084, 14.97125053], [74.04458618, 14.97125053], [74.04458618, 14.97181034], [74.04430389, 14.97180462], [74.04430389, 14.97236061], [74.04292297, 14.97236061], [74.04292297, 14.97430992], [74.04319763, 14.97430992], [74.04319763, 14.97653008], [74.04292297, 14.97653008], [74.04292297, 14.97681046], [74.04264069, 14.97680569], [74.04264069, 14.97708416], [74.0423584, 14.9770813], [74.0423584, 14.97764015], [74.04207611, 14.97764015], [74.04207611, 14.97875023], [74.04180908, 14.97875023], [74.04180908, 14.97902966], [74.04152679, 14.97902775], [74.04152679, 14.97958374], [74.04125214, 14.97958374], [74.04125214, 14.97986221], [74.04096985, 14.97986031], [74.04096985, 14.98013973], [74.04069519, 14.98013783], [74.04069519, 14.98069382], [74.0404129, 14.98069382], [74.0404129, 14.98097229], [74.04013824, 14.98096085], [74.04013824, 14.98124981], [74.03985596, 14.98124981], [74.03985596, 14.98153019], [74.0395813, 14.98153019], [74.0395813, 14.98181057], [74.03874969, 14.9818058], [74.03874969, 14.98208427], [74.03708649, 14.98208046], [74.03708649, 14.98236179], [74.0359726, 14.98236179], [74.0359726, 14.98264027], [74.03542328, 14.98264027], [74.03542328, 14.98236179], [74.0348587, 14.98236179], [74.0348587, 14.98264027], [74.03430939, 14.98264027], [74.03430939, 14.98375034], [74.03456879, 14.98375034], [74.03456879, 14.9843111], [74.03514099, 14.98430634], [74.03514099, 14.98458195], [74.03736115, 14.98458195], [74.03736115, 14.98486233], [74.03791809, 14.98486042], [74.03791809, 14.98514271], [74.03819275, 14.98514271], [74.03819275, 14.98542118], [74.03901672, 14.98542118], [74.03901672, 14.98486042], [74.03930664, 14.98486233], [74.03930664, 14.98430634], [74.03985596, 14.9843111], [74.03985596, 14.98403072], [74.04125214, 14.98403072], [74.04125214, 14.9843111], [74.04180908, 14.98430634], [74.04180908, 14.98458195], [74.04207611, 14.98458195], [74.04207611, 14.98514271], [74.04264069, 14.98514271], [74.04264069, 14.98542118], [74.04291534, 14.98541641], [74.04291534, 14.98569393], [74.04347229, 14.98569393], [74.04347229, 14.9859724], [74.04376221, 14.98596954], [74.04376221, 14.98709106], [74.04402924, 14.98708153], [74.04402924, 14.98847294], [74.0451355, 14.98847294], [74.0451355, 14.98819542], [74.04569244, 14.98819542], [74.04569244, 14.98791599], [74.0463028, 14.98791599], [74.04650879, 14.98792076], [74.04651642, 14.98779964], [74.04652405, 14.98763847], [74.04685974, 14.98763847], [74.04708099, 14.98764133], [74.04708099, 14.98753071], [74.04708099, 14.98736], [74.04741669, 14.98736], [74.04792023, 14.98736], [74.04794312, 14.98709106], [74.04846954, 14.98709106], [74.04849243, 14.98681068], [74.04930878, 14.98681068], [74.04930878, 14.98653126], [74.04985809, 14.98653126], [74.04985809, 14.98792076], [74.05014038, 14.98791599], [74.05014038, 14.98819542], [74.04985809, 14.98819542], [74.04985809, 14.98847294], [74.04930878, 14.98847294], [74.04930878, 14.98819542], [74.04846954, 14.98819542], [74.04846954, 14.98847294], [74.04792023, 14.98847008], [74.04792023, 14.98875141], [74.04708099, 14.98875141], [74.04708099, 14.98903084], [74.04650879, 14.98903084], [74.04650879, 14.98931122], [74.04416656, 14.98930359], [74.04402924, 14.98931122], [74.04402924, 14.98903084], [74.04292297, 14.98903084], [74.04292297, 14.98875141], [74.04069519, 14.98875141], [74.04069519, 14.98819542], [74.0404129, 14.98819542], [74.0404129, 14.98791599], [74.03985596, 14.98792076], [74.03985596, 14.98736], [74.0395813, 14.98736], [74.0395813, 14.98681068], [74.03930664, 14.98681068], [74.03930664, 14.98653126], [74.03901672, 14.98653126], [74.03901672, 14.98596954], [74.03848267, 14.98596954], [74.03848267, 14.98624992], [74.03819275, 14.98624992], [74.03819275, 14.98653126], [74.03791809, 14.98653126], [74.03791809, 14.98875141], [74.03762817, 14.98875141], [74.03762817, 14.98931122], [74.03736115, 14.98930359], [74.03736115, 14.98986053], [74.03708649, 14.98986053], [74.03708649, 14.990695], [74.03679657, 14.99069023], [74.03679657, 14.99125099], [74.03652954, 14.99125099], [74.03652954, 14.99181175], [74.03624725, 14.99181175], [74.03624725, 14.99236107], [74.0359726, 14.99236107], [74.0359726, 14.99292088], [74.03569794, 14.99291706], [74.03569794, 14.99319458], [74.03542328, 14.9931879], [74.03542328, 14.99375057], [74.03514099, 14.99375057], [74.03514099, 14.99403095], [74.0348587, 14.99402905], [74.0348587, 14.99458313], [74.03458405, 14.99458313], [74.03458405, 14.99569511], [74.03430939, 14.9956913], [74.03430176, 14.99625111], [74.0340271, 14.99625111], [74.0340271, 14.99681187], [74.03375244, 14.99680519], [74.03375244, 14.99736118], [74.03347015, 14.99736118], [74.03347015, 14.99752998], [74.03347015, 14.99792194], [74.0331955, 14.99791718], [74.0331955, 14.99847126], [74.03291321, 14.99847126], [74.03291321, 14.99903202], [74.03276062, 14.99903011], [74.03235626, 14.99903202], [74.03235626, 14.99932098], [74.03152466, 14.99930477], [74.03152466, 14.99958324], [74.03013611, 14.99958324], [74.03013611, 14.99930477], [74.02929688, 14.99932098], [74.02929688, 14.99903202], [74.02876282, 14.99903202], [74.02876282, 14.99875069], [74.0284729, 14.99875069], [74.0284729, 14.99847126], [74.02819824, 14.99847126], [74.02819061, 14.99819469], [74.02791595, 14.99819469], [74.02791595, 14.99791718], [74.02680206, 14.99791718], [74.02680206, 14.99847126], [74.0265274, 14.99847126], [74.0265274, 14.99875069], [74.02680206, 14.99875069], [74.02680206, 14.99903202], [74.02707672, 14.99903202], [74.02707672, 14.99932098], [74.0276413, 14.99930477], [74.0276413, 14.99958324], [74.02819824, 14.99958134], [74.02819824, 14.99986076], [74.02876282, 14.99986076], [74.02876282, 15.00013924], [74.02902985, 15.00013924], [74.02902985, 15.00041962], [74.02929688, 15.00041962], [74.02929688, 15.00097084], [74.02986145, 15.00097084], [74.02986145, 15.00124931], [74.02958679, 15.00124931], [74.02958679, 15.00185108], [74.02958679, 15.00208378], [74.02932739, 15.00208378], [74.02874756, 15.00208378], [74.02874756, 15.00180626], [74.0284729, 15.00181007], [74.0284729, 15.00152969], [74.02819824, 15.00152683], [74.02819824, 15.00236225], [74.0276413, 15.00235939], [74.0276413, 15.00263977], [74.02707672, 15.00263977], [74.02707672, 15.00235939], [74.02680206, 15.00236225], [74.02680206, 15.00208378], [74.0265274, 15.00208378], [74.0265274, 15.00180626], [74.02597046, 15.00181007], [74.02597046, 15.00097084], [74.02568817, 15.00097084], [74.02568817, 15.00069141], [74.02541351, 15.00069332], [74.02541351, 15.00236225], [74.02513885, 15.00235939], [74.02513885, 15.00263977], [74.02458191, 15.00263977], [74.02458191, 15.00292015], [74.02430725, 15.00291538], [74.02430725, 15.00347233], [74.02485657, 15.00346947], [74.02485657, 15.00375175], [74.02539825, 15.00375175], [74.02539825, 15.00346947], [74.02597046, 15.00346947], [74.02597046, 15.00375175], [74.02625275, 15.00375175], [74.02625275, 15.00403023], [74.0265274, 15.00402832], [74.0265274, 15.00434017], [74.0265274, 15.0051384], [74.02680206, 15.0051403], [74.02680206, 15.00569439], [74.02707672, 15.00569057], [74.02707672, 15.00652981], [74.02680206, 15.00652981], [74.02680206, 15.00681114], [74.0265274, 15.00680637], [74.0265274, 15.00736237], [74.02597046, 15.00736046], [74.02597046, 15.00792027], [74.0256958, 15.00791645], [74.0256958, 15.00847244], [74.02539825, 15.00846958], [74.02539825, 15.00874996], [74.02513885, 15.00874996], [74.02513885, 15.00903034], [74.02485657, 15.00903034], [74.02485657, 15.00931072], [74.02430725, 15.00930595], [74.02430725, 15.00958443], [74.02402496, 15.00958443], [74.02402496, 15.00986004], [74.02348328, 15.00986004], [74.02348328, 15.01014042], [74.02319336, 15.01014042], [74.02319336, 15.0104208], [74.0229187, 15.01041603], [74.0229187, 15.01069355], [74.02263641, 15.01069355], [74.02263641, 15.01097202], [74.0220871, 15.01097012], [74.0220871, 15.01126194], [74.02179718, 15.01126194], [74.02179718, 15.01153088], [74.02124786, 15.01153088], [74.02124786, 15.01181126], [74.02097321, 15.01180553], [74.02097321, 15.0120821], [74.01875305, 15.0120821], [74.01875305, 15.01236153], [74.01735687, 15.01235962], [74.01735687, 15.01264095], [74.01680756, 15.01263809], [74.01680756, 15.01319408], [74.01708221, 15.01319408], [74.01708221, 15.0134716], [74.01735687, 15.0134697], [74.01735687, 15.01375008], [74.01763916, 15.01375008], [74.01763916, 15.01403141], [74.01625061, 15.01403141], [74.01625061, 15.01375008], [74.01597595, 15.01375008], [74.01597595, 15.0134697], [74.01569366, 15.0134716], [74.01569366, 15.01291561], [74.01541901, 15.01292133], [74.01541901, 15.01264095], [74.01486206, 15.01264095], [74.01486206, 15.01208019], [74.01457977, 15.0120821], [74.01457977, 15.01152802], [74.01431274, 15.01153088], [74.01431274, 15.01068974], [74.01374817, 15.01069355], [74.01374817, 15.01013756], [74.01345825, 15.01014042], [74.01345825, 15.00986004], [74.01374817, 15.00986004], [74.01374817, 15.00957966], [74.01403046, 15.00958443], [74.01403046, 15.00930595], [74.01431274, 15.00931072], [74.01431274, 15.00652981], [74.01374817, 15.00652981], [74.01374817, 15.00681114], [74.01347351, 15.00680637], [74.01347351, 15.00708389], [74.01235962, 15.00708199], [74.01235962, 15.00764179], [74.01209259, 15.00764179], [74.01209259, 15.00792027], [74.01180267, 15.00791645], [74.01180267, 15.00847244], [74.01152802, 15.00846958], [74.01152802, 15.00931072], [74.01180267, 15.00930595], [74.01180267, 15.00958443], [74.01235962, 15.00957966], [74.01235962, 15.00986004], [74.01291656, 15.00986004], [74.01291656, 15.0104208], [74.01235962, 15.0104208], [74.01235962, 15.01153088], [74.01208496, 15.01152802], [74.01208496, 15.01236153], [74.01180267, 15.01235962], [74.01180267, 15.01264095], [74.01125336, 15.01264095], [74.01125336, 15.01292133], [74.01069641, 15.01291561], [74.01069641, 15.01319408], [74.01041412, 15.01319408], [74.01041412, 15.0134716], [74.00985718, 15.0134697], [74.00985718, 15.01375008], [74.00930786, 15.01375008], [74.00930786, 15.01403141], [74.0090332, 15.01403141], [74.0090332, 15.01432037], [74.00846863, 15.01430416], [74.00846863, 15.01458454], [74.00819397, 15.01458454], [74.00819397, 15.01569462], [74.00791931, 15.01568985], [74.00791931, 15.01625061], [74.00765228, 15.01625061], [74.00765228, 15.01681137], [74.00736237, 15.01681137], [74.00736237, 15.01792145], [74.00624847, 15.01792145], [74.00624847, 15.01764107], [74.00596619, 15.01764107], [74.00596619, 15.01736069], [74.00569153, 15.01736069], [74.00569153, 15.01707077], [74.00541687, 15.01708317], [74.00541687, 15.01652908], [74.00514221, 15.01653099], [74.00514221, 15.01597023], [74.00485992, 15.01597023], [74.00485992, 15.01625061], [74.00319672, 15.01625061], [74.00319672, 15.01653099], [74.00263977, 15.01653099], [74.00263977, 15.01792145], [74.00235748, 15.01791668], [74.00235748, 15.01819515], [74.00180817, 15.01819515], [74.00180817, 15.01847267], [74.00151825, 15.01847076], [74.00151825, 15.01875114], [74.00068665, 15.01875114], [74.00068665, 15.01847076], [74.00069427, 15.01819515], [73.99997711, 15.01819515], [73.99964142, 15.01819515], [73.99903107, 15.01819515], [73.99903107, 15.01847267], [73.99874878, 15.01847267], [73.99874878, 15.01867104], [73.99874878, 15.0193119], [73.99819183, 15.0193119], [73.99819183, 15.02042198], [73.99791718, 15.02041721], [73.99791718, 15.02069473], [73.99764252, 15.02068996], [73.99764252, 15.02125072], [73.99680328, 15.02125072], [73.99680328, 15.02042198], [73.99652863, 15.02042198], [73.99652863, 15.01970959], [73.99652863, 15.01958275], [73.99597168, 15.01958275], [73.99597168, 15.01930523], [73.99571228, 15.0193119], [73.99571228, 15.01903057], [73.99485779, 15.01903057], [73.99485779, 15.01875114], [73.99458313, 15.01875114], [73.99458313, 15.01903057], [73.99430847, 15.01903057], [73.99430847, 15.01875114], [73.99346924, 15.01875114], [73.99346924, 15.01847076], [73.99291992, 15.01847267], [73.99291992, 15.01819515], [73.99236298, 15.01819515], [73.99236298, 15.01791668], [73.99208069, 15.01791668], [73.99208069, 15.01819515], [73.99180603, 15.01819515], [73.99180603, 15.01847267], [73.99124908, 15.01847076], [73.99124908, 15.01875114], [73.9909668, 15.01875114], [73.9909668, 15.01903057], [73.99069214, 15.01902676], [73.99069214, 15.01958275], [73.99013519, 15.01958275], [73.99013519, 15.01986122], [73.98957825, 15.01986122], [73.98957825, 15.02014065], [73.98902893, 15.02014065], [73.98902893, 15.02042198], [73.98874664, 15.02042198], [73.98874664, 15.0215292], [73.98847198, 15.0215292], [73.98847198, 15.02320194], [73.98819733, 15.02320194], [73.98819733, 15.02375126], [73.98764038, 15.02375126], [73.98764038, 15.02403164], [73.98735809, 15.02403164], [73.98735809, 15.02431202], [73.98680878, 15.02430534], [73.98680878, 15.02458286], [73.98625183, 15.02458286], [73.98625183, 15.02486134], [73.98596954, 15.02486134], [73.98596954, 15.02514172], [73.98542023, 15.02514172], [73.98542023, 15.02680969], [73.98569489, 15.02680492], [73.98569489, 15.02819347], [73.98542023, 15.02819061], [73.98542023, 15.02903175], [73.98596954, 15.02902794], [73.98596954, 15.02958393], [73.98652649, 15.02958393], [73.98652649, 15.0298624], [73.98680878, 15.02985859], [73.98680878, 15.03013992], [73.98735809, 15.03013992], [73.98735809, 15.0304203], [73.98764038, 15.0304203], [73.98764038, 15.03013992], [73.98847198, 15.03013992], [73.98847198, 15.0304203], [73.98902893, 15.03041553], [73.98902893, 15.03069401], [73.98929596, 15.03069115], [73.98929596, 15.03180981], [73.98957825, 15.03180981], [73.98957825, 15.03264046], [73.98986053, 15.0326376], [73.98986053, 15.03347206], [73.99014282, 15.03347015], [73.99014282, 15.03431129], [73.98986053, 15.03430557], [73.98986053, 15.03486156], [73.98957825, 15.03485966], [73.98957825, 15.03625011], [73.98929596, 15.03625011], [73.98929596, 15.03652954], [73.98902893, 15.03652954], [73.98902893, 15.03681087], [73.98874664, 15.03680611], [73.98874664, 15.03736019], [73.98847198, 15.03736019], [73.98847198, 15.03820133], [73.98819733, 15.03820133], [73.98819733, 15.03903103], [73.98792267, 15.03903103], [73.98792267, 15.03931141], [73.98764038, 15.03930569], [73.98764038, 15.03958225], [73.98792267, 15.03958035], [73.98792267, 15.04014111], [73.98764038, 15.04013824], [73.98764038, 15.04069424], [73.98735809, 15.04069424], [73.98735809, 15.04125118], [73.98707581, 15.04124069], [73.98707581, 15.04181099], [73.98680878, 15.04181099], [73.98680878, 15.04264069], [73.98652649, 15.04263878], [73.98652649, 15.04319477], [73.98625183, 15.04319], [73.98625183, 15.04375076], [73.98596954, 15.04375076], [73.98596954, 15.04430676], [73.98569489, 15.04430676], [73.98569489, 15.04458332], [73.98542023, 15.04458046], [73.98542023, 15.04542065], [73.98513794, 15.04542065], [73.98513794, 15.0462513], [73.98486328, 15.0462513], [73.98486328, 15.04653072], [73.98458099, 15.04652691], [73.98458099, 15.0470829], [73.98430634, 15.04708099], [73.98430634, 15.04763889], [73.98402405, 15.04763889], [73.98402405, 15.04819489], [73.98374939, 15.04819107], [73.98374939, 15.04875088], [73.98348236, 15.04875088], [73.98348236, 15.04930973], [73.98319244, 15.04930973], [73.98319244, 15.04986095], [73.98291779, 15.04986095], [73.98291779, 15.05014133], [73.98236084, 15.05013943], [73.98236084, 15.05069542], [73.98208618, 15.05069542], [73.98208618, 15.05097103], [73.98179626, 15.05097103], [73.98179626, 15.05125141], [73.98152924, 15.05125141], [73.98152924, 15.05153179], [73.98097229, 15.05153179], [73.98097229, 15.05181026], [73.98041534, 15.05180454], [73.98041534, 15.05209923], [73.98041534, 15.05236053], [73.97921753, 15.05236053], [73.97819519, 15.05236053], [73.97819519, 15.05208302], [73.97763824, 15.05208302], [73.97763824, 15.05180454], [73.97735596, 15.05181026], [73.97735596, 15.05153179], [73.9770813, 15.05153179], [73.9770813, 15.05125141], [73.97651672, 15.05125141], [73.97651672, 15.05097103], [73.97624969, 15.05097103], [73.97624969, 15.05069542], [73.97569275, 15.05069542], [73.97569275, 15.05041695], [73.97458649, 15.05041695], [73.97458649, 15.05069542], [73.97402954, 15.05069542], [73.97402954, 15.05097103], [73.97264099, 15.05097103], [73.97264099, 15.05125141], [73.97207642, 15.05125141], [73.97207642, 15.05153179], [73.97180939, 15.05153179], [73.97180176, 15.05181026], [73.9715271, 15.05180454], [73.9715271, 15.05208302], [73.97125244, 15.05208302], [73.97125244, 15.05236053], [73.97097015, 15.05236053], [73.97097015, 15.05292034], [73.97070313, 15.05292034], [73.97070313, 15.05431175], [73.97097015, 15.05430508], [73.97097015, 15.0545826], [73.97125244, 15.05458069], [73.97125244, 15.05681038], [73.97097015, 15.05680561], [73.97097015, 15.05708408], [73.9706955, 15.05708408], [73.9706955, 15.0573616], [73.97041321, 15.0573616], [73.97041321, 15.05847168], [73.97013855, 15.05847168], [73.97013855, 15.05986214], [73.96985626, 15.05986023], [73.96985626, 15.06013966], [73.9695816, 15.06013966], [73.9695816, 15.06042004], [73.96902466, 15.06041622], [73.96902466, 15.06097221], [73.96875, 15.06097031], [73.96875, 15.06124973], [73.96848297, 15.06124973], [73.96848297, 15.06153011], [73.96763611, 15.06153011], [73.96763611, 15.06181145], [73.96736145, 15.06180573], [73.96736145, 15.0620842], [73.96679688, 15.06208038], [73.96679688, 15.06237125], [73.96624756, 15.06237125], [73.96624756, 15.06292057], [73.96652985, 15.0629158], [73.96652985, 15.06319427], [73.96679688, 15.06318855], [73.96679688, 15.06347179], [73.96708679, 15.06347179], [73.96708679, 15.06431103], [73.96736145, 15.06431103], [73.96736145, 15.06513977], [73.96708679, 15.06513786], [73.96708679, 15.06559181], [73.96708679, 15.06569386], [73.9668045, 15.06569386], [73.9668045, 15.06597233], [73.96627808, 15.06597233], [73.96458435, 15.06597233], [73.96458435, 15.06569386], [73.96430206, 15.06569386], [73.96430206, 15.06597233], [73.96375275, 15.06597042], [73.96375275, 15.06625271], [73.96347046, 15.06625271], [73.96347046, 15.06653118], [73.96290588, 15.06653118], [73.96290588, 15.06681061], [73.96234894, 15.06681061], [73.96234894, 15.06735992], [73.96208191, 15.06735992], [73.96208191, 15.06764126], [73.96153259, 15.06764126], [73.96153259, 15.06792068], [73.96125031, 15.06791592], [73.96125031, 15.06819439], [73.9604187, 15.06819439], [73.9604187, 15.06847286], [73.96013641, 15.06847], [73.96013641, 15.06875134], [73.95960236, 15.06875134], [73.95960236, 15.06903076], [73.95903015, 15.06902885], [73.95903015, 15.06958199], [73.95874786, 15.06958008], [73.95874786, 15.07014084], [73.9576416, 15.07014084], [73.9576416, 15.06986141], [73.95569611, 15.06986141], [73.95569611, 15.07014084], [73.95430756, 15.07014084], [73.95430756, 15.07042122], [73.95375061, 15.0704174], [73.95375061, 15.07069016], [73.95346832, 15.0707016], [73.95346832, 15.07154274], [73.95375061, 15.07154274], [73.95375061, 15.07181072], [73.9540329, 15.07181072], [73.9540329, 15.07264137], [73.95375061, 15.07264137], [73.95375061, 15.07291889], [73.95347595, 15.07291698], [73.95347595, 15.07319546], [73.95291901, 15.07319546], [73.95291901, 15.07347107], [73.95181274, 15.0734911], [73.95181274, 15.07375145], [73.95124817, 15.07375145], [73.95124817, 15.07403088], [73.95096588, 15.07403088], [73.95096588, 15.07430935], [73.95041656, 15.07430458], [73.95041656, 15.07458305], [73.95014191, 15.07458305], [73.95014191, 15.07486057], [73.94959259, 15.07486057], [73.94959259, 15.07514095], [73.94847107, 15.07514095], [73.94847107, 15.07541943], [73.94374847, 15.07541943], [73.94374847, 15.07514095], [73.94291687, 15.07514095], [73.94291687, 15.07487011], [73.94264221, 15.07486057], [73.94264221, 15.07514095], [73.94208527, 15.07513905], [73.94208527, 15.07486057], [73.94180298, 15.07486057], [73.94180298, 15.07514095], [73.94124603, 15.07514095], [73.94124603, 15.07541943], [73.94069672, 15.07541656], [73.94069672, 15.07569504], [73.94013977, 15.07569504], [73.94013977, 15.07541656], [73.93958282, 15.07541656], [73.93958282, 15.07569504], [73.93902588, 15.07569504], [73.93902588, 15.07597256], [73.93875122, 15.07597065], [73.93875122, 15.07625103], [73.93846893, 15.07625103], [73.93846893, 15.07653236], [73.93817902, 15.07653236], [73.93817902, 15.07681179], [73.93597412, 15.07680511], [73.93597412, 15.07708263], [73.93569183, 15.07708073], [73.93569183, 15.07764053], [73.93540955, 15.07764053], [73.93540955, 15.07792187], [73.93514252, 15.0779171], [73.93514252, 15.07819462], [73.93235779, 15.07819462], [73.93235779, 15.0779171], [73.93180847, 15.0779171], [73.93180847, 15.07819462], [73.93152618, 15.07819462], [73.93152618, 15.07847118], [73.93096924, 15.07847118], [73.93096924, 15.07903194], [73.93069458, 15.07902718], [73.93069458, 15.07958317], [73.93013763, 15.07958126], [73.93013763, 15.08014202], [73.92986298, 15.08013916], [73.92986298, 15.08041668], [73.92958069, 15.08041668], [73.92958069, 15.08069324], [73.92930603, 15.08069324], [73.92930603, 15.08097363], [73.92903137, 15.08097363], [73.92903137, 15.08121967], [73.92903137, 15.08152962], [73.92930603, 15.08152676], [73.92930603, 15.0820837], [73.92958069, 15.08208084], [73.92958069, 15.08263969], [73.92930603, 15.08263969], [73.92930603, 15.08348274], [73.92819214, 15.08348274], [73.92819214, 15.08375168], [73.92791748, 15.08375168], [73.92791748, 15.08348274], [73.92764282, 15.08348274], [73.92764282, 15.08375168], [73.92708588, 15.08375168], [73.92708588, 15.08430958], [73.92679596, 15.08430958], [73.92679596, 15.08486176], [73.92623901, 15.08486176], [73.92623901, 15.08541965], [73.92597198, 15.08541775], [73.92597198, 15.08569431], [73.92485809, 15.08569431], [73.92485809, 15.08597183], [73.92430878, 15.08597183], [73.92430878, 15.08569431], [73.92346954, 15.08569431], [73.92346954, 15.08541775], [73.92319489, 15.08541775], [73.92319489, 15.08569431], [73.92263794, 15.08569431], [73.92263794, 15.08597183], [73.92208099, 15.08597183], [73.92208099, 15.08569431], [73.92180634, 15.08569431], [73.92180634, 15.08514023], [73.92124939, 15.08514023], [73.92124939, 15.08458138], [73.9201355, 15.08458424], [73.9201355, 15.08430576], [73.91986084, 15.08430576], [73.91986084, 15.08458424], [73.91958618, 15.08458424], [73.91958618, 15.08430576], [73.91902924, 15.08430958], [73.91902924, 15.08403015], [73.91874695, 15.08403015], [73.91874695, 15.08375168], [73.91819763, 15.08375168], [73.91819763, 15.08348274], [73.91764069, 15.08348274], [73.91764069, 15.08319092], [73.9173584, 15.08319569], [73.9173584, 15.08291531], [73.91708374, 15.08291531], [73.91708374, 15.08319569], [73.91652679, 15.08319092], [73.91652679, 15.08403015], [73.91625214, 15.08403015], [73.91625214, 15.08430958], [73.91429901, 15.08430958], [73.91429901, 15.08403015], [73.9118042, 15.08402824], [73.9118042, 15.08458424], [73.91208649, 15.08458138], [73.91208649, 15.08541965], [73.91236115, 15.08541775], [73.91236115, 15.08569431], [73.9126358, 15.08569431], [73.9126358, 15.08597183], [73.91319275, 15.08597183], [73.91319275, 15.08625031], [73.91374969, 15.08625031], [73.91374969, 15.08653927], [73.91429901, 15.08653927], [73.91429901, 15.08681011], [73.91486359, 15.0868063], [73.91486359, 15.08708382], [73.91513824, 15.08708382], [73.91513824, 15.08736229], [73.9154129, 15.08736038], [73.9154129, 15.08763981], [73.91570282, 15.08763981], [73.91570282, 15.08792019], [73.91596985, 15.08791637], [73.91596985, 15.08819389], [73.91625214, 15.08819389], [73.91625214, 15.08847237], [73.91652679, 15.08847046], [73.91652679, 15.08875179], [73.91680908, 15.08875179], [73.91680908, 15.08903027], [73.91736603, 15.08903027], [73.91736603, 15.08931065], [73.91819763, 15.08930588], [73.91819763, 15.08958435], [73.91874695, 15.08957958], [73.91874695, 15.08985996], [73.91929626, 15.08985996], [73.91929626, 15.09014034], [73.91986084, 15.09014034], [73.91986084, 15.09042072], [73.9201355, 15.09041595], [73.9201355, 15.09069443], [73.92069244, 15.09069443], [73.92069244, 15.09097195], [73.9209671, 15.09097004], [73.9209671, 15.09125042], [73.92151642, 15.09125042], [73.92151642, 15.09153271], [73.92180634, 15.09153271], [73.92180634, 15.09181118], [73.92236328, 15.09180641], [73.92236328, 15.09208202], [73.92263794, 15.09208202], [73.92263794, 15.0923624], [73.92292023, 15.09235096], [73.92292023, 15.09263992], [73.92346954, 15.09263992], [73.92346954, 15.09292126], [73.92375183, 15.09292126], [73.92375183, 15.09375], [73.92402649, 15.09375], [73.92402649, 15.09458542], [73.92375183, 15.0945797], [73.92375183, 15.09486008], [73.92402649, 15.09486008], [73.92402649, 15.09514141], [73.92430878, 15.09514141], [73.92430878, 15.09542084], [73.92458344, 15.09541607], [73.92458344, 15.09569454], [73.92514038, 15.09569454], [73.92514038, 15.09597301], [73.92569733, 15.09597015], [73.92569733, 15.09625053], [73.92597198, 15.09625053], [73.92597198, 15.09681129], [73.92624664, 15.09680367], [73.92623901, 15.09913063], [73.92623901, 15.10014057], [73.92597198, 15.10013866], [73.92597198, 15.10097313], [73.92569733, 15.10097122], [73.92569733, 15.10180855], [73.92541504, 15.10180473], [73.92542267, 15.10236073], [73.92514038, 15.10236073], [73.92514038, 15.10319519], [73.92541504, 15.10319519], [73.92542267, 15.10375118], [73.92514038, 15.10375118], [73.92514038, 15.10431194], [73.92485809, 15.10430527], [73.92485809, 15.10458279], [73.92402649, 15.10458279], [73.92402649, 15.10486126], [73.92375183, 15.10486126], [73.92375183, 15.10514164], [73.92317963, 15.10514164], [73.92317963, 15.10542202], [73.92292023, 15.10541725], [73.92292023, 15.10569477], [73.92236328, 15.10569477], [73.92236328, 15.10597134], [73.92208099, 15.10597134], [73.92208099, 15.10625076], [73.92151642, 15.10625076], [73.92151642, 15.10736084], [73.92069244, 15.10736084], [73.92069244, 15.10708141], [73.92043304, 15.10708141], [73.92043304, 15.10736084], [73.91929626, 15.10736084], [73.91929626, 15.10708141], [73.91847229, 15.10708141], [73.91847229, 15.10736084], [73.91792297, 15.10736084], [73.91792297, 15.10763931], [73.91764069, 15.10763931], [73.91764069, 15.10791969], [73.9173584, 15.10791779], [73.9173584, 15.1081934], [73.91791534, 15.1081934], [73.91791534, 15.10847092], [73.91847229, 15.10847092], [73.91847229, 15.10874939], [73.9209671, 15.10874939], [73.9209671, 15.10902977], [73.92180634, 15.10902977], [73.92180634, 15.10931015], [73.92208099, 15.10930634], [73.92208099, 15.10958385], [73.92236328, 15.10958385], [73.92236328, 15.10986233], [73.92292023, 15.10985947], [73.92292023, 15.11014175], [73.92514038, 15.11014175], [73.92514038, 15.11042023], [73.92652893, 15.11041546], [73.92652893, 15.11069584], [73.92680359, 15.11069584], [73.92680359, 15.1109724], [73.92736053, 15.1109724], [73.92736053, 15.11125183], [73.92791748, 15.11125183], [73.92791748, 15.1115303], [73.92874908, 15.1115303], [73.92874908, 15.11180973], [73.92986298, 15.11180592], [73.92986298, 15.11208439], [73.93041992, 15.11208153], [73.93041992, 15.11236191], [73.93096924, 15.11236191], [73.93096924, 15.11264038], [73.93152618, 15.11264038], [73.93152618, 15.11291981], [73.93180847, 15.1129179], [73.93180847, 15.11319447], [73.93208313, 15.11319447], [73.93208313, 15.11347198], [73.93237305, 15.11345959], [73.93237305, 15.11375046], [73.93319702, 15.11375046], [73.93319702, 15.11345959], [73.93374634, 15.11347198], [73.93374634, 15.11319447], [73.93402863, 15.11319447], [73.93402863, 15.1129179], [73.93430328, 15.11291981], [73.93430328, 15.11264038], [73.9345932, 15.11264038], [73.9345932, 15.11236191], [73.93514252, 15.11236191], [73.93514252, 15.11264038], [73.93569183, 15.11263847], [73.93569183, 15.11319447], [73.93596649, 15.11319065], [73.93596649, 15.11431122], [73.93624878, 15.11431122], [73.93624878, 15.11625004], [73.93653107, 15.11625004], [73.93653107, 15.11652756], [73.93681335, 15.11652088], [73.93681335, 15.11763954], [73.93736267, 15.11763763], [73.93736267, 15.11819363], [73.93763733, 15.11819172], [73.93763733, 15.11874962], [73.93875122, 15.11874962], [73.93875122, 15.11903095], [73.93902588, 15.11903095], [73.93902588, 15.11931133], [73.93985748, 15.11930561], [73.93985748, 15.11958218], [73.9406662, 15.11958027], [73.94069672, 15.12153053], [73.94041443, 15.12152863], [73.94041443, 15.12208462], [73.93985748, 15.12208462], [73.93985748, 15.12458324], [73.93958282, 15.12458038], [73.93958282, 15.12597275], [73.93985748, 15.12597275], [73.93985748, 15.12653065], [73.94013977, 15.12652683], [73.94013977, 15.12708282], [73.9404068, 15.12708092], [73.9404068, 15.12764072], [73.94013977, 15.12764072], [73.94013977, 15.1279192], [73.93958282, 15.12791729], [73.93958282, 15.12819481], [73.93930817, 15.12819004], [73.93930817, 15.12874889], [73.93902588, 15.12874889], [73.93902588, 15.1293087], [73.93846893, 15.12930489], [73.93846893, 15.12958336], [73.93817902, 15.12958145], [73.93817902, 15.12986088], [73.93763733, 15.12986088], [73.93763733, 15.13014126], [73.93708038, 15.13013935], [73.93708038, 15.13152695], [73.93681335, 15.13152027], [73.93681335, 15.13181019], [73.93624878, 15.13181019], [73.93624878, 15.13152027], [73.93569183, 15.13152027], [73.93569183, 15.13181019], [73.93514252, 15.13180542], [73.93514252, 15.13236141], [73.93540955, 15.13236141], [73.93540955, 15.13292027], [73.93569183, 15.1329174], [73.93569183, 15.13319302], [73.93596649, 15.13319111], [73.93596649, 15.13375187], [73.93624878, 15.13375187], [73.93624878, 15.13403034], [73.93653107, 15.13403034], [73.93653107, 15.13430977], [73.93817902, 15.13430977], [73.93817902, 15.13459015], [73.93875122, 15.13459015], [73.93875122, 15.13486099], [73.93958282, 15.13486099], [73.93958282, 15.13514042], [73.94013977, 15.13514042], [73.94013977, 15.13542175], [73.94125366, 15.13541794], [73.94125366, 15.13569641], [73.94152832, 15.13569069], [73.94152832, 15.13624859], [73.94180298, 15.13624859], [73.94180298, 15.13652992], [73.9420929, 15.13652992], [73.9420929, 15.1368103], [73.94235992, 15.13680553], [73.94235992, 15.13736153], [73.94264221, 15.13736153], [73.94264221, 15.13792038], [73.94291687, 15.13792038], [73.94291687, 15.13903046], [73.94319153, 15.13903046], [73.94319153, 15.13931274], [73.94374847, 15.13930607], [73.94374847, 15.13958359], [73.94403076, 15.13958168], [73.94403076, 15.14013958], [73.94374847, 15.14013958], [73.94374847, 15.14041996], [73.94403076, 15.14041805], [73.94403076, 15.14097214], [73.94431305, 15.14097023], [73.94431305, 15.14124966], [73.94486237, 15.14124966], [73.94486237, 15.14153004], [73.94513702, 15.14153004], [73.94513702, 15.14181137], [73.94568634, 15.14181137], [73.94568634, 15.14235973], [73.94625092, 15.14235973], [73.94625092, 15.14264011], [73.94708252, 15.14264011], [73.94708252, 15.1431942], [73.94736481, 15.1431942], [73.94736481, 15.14375019], [73.94763947, 15.14375019], [73.94763947, 15.14431095], [73.94791412, 15.14430618], [73.94791412, 15.14486217], [73.94819641, 15.14486027], [73.94819641, 15.14542103], [73.94847107, 15.14541626], [73.94847107, 15.14597225], [73.94819641, 15.14597034], [73.94819641, 15.14736271], [73.94790649, 15.14736271], [73.94790649, 15.14792061], [73.94763947, 15.14792061], [73.94763947, 15.14903069], [73.94734955, 15.14903069], [73.94734955, 15.14931107], [73.94708252, 15.14930439], [73.94708252, 15.14986038], [73.94734955, 15.14986038], [73.94734955, 15.15014076], [73.94708252, 15.15013885], [73.94708252, 15.15097332], [73.94680786, 15.15097046], [73.94680786, 15.15181065], [73.9465332, 15.15181065], [73.9465332, 15.15292072], [73.94625092, 15.15292072], [73.94625092, 15.15375137], [73.94596863, 15.15375137], [73.94596863, 15.15514088], [73.94569397, 15.15513897], [73.94569397, 15.15569496], [73.94541931, 15.15569019], [73.94541931, 15.15625095], [73.94513702, 15.15625095], [73.94513702, 15.15681171], [73.94486237, 15.15680504], [73.94486237, 15.15708256], [73.94458008, 15.15708256], [73.94458008, 15.15819454], [73.94430542, 15.15819454], [73.94430542, 15.15847111], [73.94403076, 15.15847111], [73.94403076, 15.16182137], [73.94374847, 15.16180515], [73.94374847, 15.16208267], [73.94403076, 15.16208076], [73.94403076, 15.16263962], [73.94374847, 15.16263962], [73.94374847, 15.16374969], [73.94347382, 15.16374969], [73.94347382, 15.16458416], [73.94319153, 15.16458416], [73.94319153, 15.16569424], [73.94291687, 15.16569138], [73.94291687, 15.16681004], [73.94264221, 15.16681004], [73.94264221, 15.16903019], [73.94235992, 15.16902828], [73.94235992, 15.17097187], [73.9420929, 15.17096996], [73.9420929, 15.1718111], [73.94180298, 15.17180634], [73.94180298, 15.17236233], [73.94152832, 15.17236233], [73.94152832, 15.17319393], [73.94124603, 15.17319202], [73.94124603, 15.17403126], [73.94097137, 15.17403126], [73.94097137, 15.17514133], [73.94069672, 15.17514133], [73.94069672, 15.17625141], [73.94041443, 15.17625141], [73.94041443, 15.17736053], [73.94013977, 15.17736053], [73.94013977, 15.17875099], [73.93985748, 15.17875099], [73.93985748, 15.1795826], [73.93958282, 15.1795826], [73.93958282, 15.18097305], [73.93930817, 15.18097305], [73.93930817, 15.18208313], [73.93902588, 15.18208313], [73.93902588, 15.18319511], [73.93875122, 15.1831913], [73.93875122, 15.18403244], [73.93846893, 15.18402672], [73.93846893, 15.18458271], [73.93817902, 15.1845808], [73.93817902, 15.18514061], [73.93791962, 15.18514061], [73.93791962, 15.18625069], [73.93763733, 15.18625069], [73.93763733, 15.18736076], [73.93736267, 15.18736076], [73.93736267, 15.18902969], [73.93708038, 15.18902683], [73.93708038, 15.18958378], [73.93680573, 15.18958378], [73.93680573, 15.19097233], [73.93653107, 15.19097233], [73.93653107, 15.19180584], [73.93624878, 15.19180107], [73.93624878, 15.19291973], [73.93597412, 15.19291782], [73.93597412, 15.19458389], [73.93569183, 15.19458389], [73.93569183, 15.1956892], [73.93540955, 15.19570065], [73.93540955, 15.19681072], [73.93514252, 15.19680595], [73.93514252, 15.19847202], [73.93486023, 15.19847202], [73.93486023, 15.20069408], [73.93458557, 15.20069408], [73.93458557, 15.20236015], [73.93430328, 15.20236015], [73.93430328, 15.20292091], [73.93402863, 15.20291615], [73.93402863, 15.20347309], [73.93374634, 15.20347023], [73.93374634, 15.20431137], [73.93347168, 15.20431137], [73.93347168, 15.20486069], [73.93319702, 15.20486069], [73.93319702, 15.20569515], [73.9329071, 15.20569038], [73.9329071, 15.20625114], [73.93264008, 15.20625114], [73.93264008, 15.20653057], [73.9329071, 15.20653057], [73.9329071, 15.20792103], [73.93264008, 15.20791721], [73.93264008, 15.20847321], [73.93237305, 15.2084713], [73.93237305, 15.20930862], [73.93208313, 15.20930862], [73.93208313, 15.20987034], [73.93180847, 15.20987034], [73.93180847, 15.21042156], [73.93152618, 15.21041679], [73.93152618, 15.21097088], [73.93125153, 15.21097088], [73.93125153, 15.21153164], [73.93096924, 15.21152687], [73.93096924, 15.21319485], [73.93068695, 15.21319103], [73.93068695, 15.21541977], [73.93041992, 15.21541977], [73.93041992, 15.21653175], [73.93013763, 15.21653175], [73.93013763, 15.21764183], [73.92986298, 15.21764183], [73.92986298, 15.21875191], [73.92958069, 15.21875191], [73.92958069, 15.21986198], [73.92930603, 15.21986198], [73.92930603, 15.22042274], [73.92903137, 15.22041798], [73.92903137, 15.22097206], [73.92930603, 15.22097206], [73.92930603, 15.22236156], [73.92874908, 15.22235966], [73.92874908, 15.22292042], [73.92903137, 15.22292042], [73.92903137, 15.22402954], [73.92874908, 15.22402763], [73.92874908, 15.22458363], [73.9284668, 15.22457981], [73.9284668, 15.22624969], [73.92819214, 15.22624969], [73.92819214, 15.22681141], [73.92791748, 15.22680569], [73.92791748, 15.22708225], [73.92763519, 15.22708225], [73.92763519, 15.22735977], [73.92791748, 15.22735977], [73.92791748, 15.22791576], [73.92763519, 15.22791576], [73.92763519, 15.22847176], [73.92736053, 15.22846985], [73.92736053, 15.22903061], [73.92708588, 15.2290287], [73.92708588, 15.22958469], [73.92680359, 15.22958469], [73.92680359, 15.22986031], [73.92652893, 15.22986031], [73.92652893, 15.23042107], [73.92624664, 15.23041725], [73.92624664, 15.23097324], [73.92597198, 15.23097324], [73.92597198, 15.23208332], [73.92569733, 15.23208332], [73.92569733, 15.2331953], [73.92542267, 15.23318958], [73.92542267, 15.2343092], [73.92514038, 15.2343092], [73.92514038, 15.23541927], [73.92485809, 15.23541927], [73.92485809, 15.23625088], [73.92457581, 15.23625088], [73.92457581, 15.23736095], [73.92430878, 15.23736095], [73.92430878, 15.23819542], [73.92402649, 15.23819065], [73.92402649, 15.23931026], [73.92375183, 15.23931026], [73.92375183, 15.24042034], [73.92346954, 15.24042034], [73.92346954, 15.24153042], [73.92317963, 15.24153042], [73.92317963, 15.24263954], [73.92292023, 15.24263954], [73.92292023, 15.24347115], [73.92263794, 15.24346924], [73.92263794, 15.24403191], [73.92236328, 15.24403191], [73.92236328, 15.24542046], [73.92208099, 15.24541569], [73.92208099, 15.24736214], [73.92180634, 15.24736214], [73.92180634, 15.24819374], [73.92151642, 15.24819088], [73.92151642, 15.24931145], [73.92124939, 15.24931145], [73.92124939, 15.25014019], [73.9209671, 15.25014019], [73.9209671, 15.25097179], [73.92069244, 15.25097179], [73.92069244, 15.25208378], [73.92043304, 15.25208187], [73.92043304, 15.2529211], [73.9201355, 15.25291634], [73.9201355, 15.25319386], [73.91986084, 15.25319195], [73.91986084, 15.25375271], [73.91958618, 15.25375271], [73.91958618, 15.25514126], [73.91929626, 15.25514126], [73.91929626, 15.25625134], [73.91902924, 15.25625134], [73.91902924, 15.25819016], [73.91874695, 15.25821114], [73.91874695, 15.2590313], [73.91847229, 15.2590313], [73.91847229, 15.25986099], [73.91819763, 15.25986099], [73.91819763, 15.26069546], [73.91792297, 15.26068974], [73.91792297, 15.26180935], [73.91764069, 15.26180935], [73.91764069, 15.26264095], [73.91708374, 15.26263905], [73.91708374, 15.26319504], [73.9173584, 15.26319504], [73.9173584, 15.26347256], [73.91680908, 15.26347065], [73.91680908, 15.26431179], [73.91652679, 15.26431179], [73.91652679, 15.26542187], [73.91680908, 15.2654171], [73.91680908, 15.26597118], [73.91652679, 15.26597118], [73.91652679, 15.26653194], [73.91625214, 15.26653194], [73.91625214, 15.26736069], [73.91596985, 15.26736069], [73.91596985, 15.26791954], [73.91569519, 15.26791668], [73.91569519, 15.26847363], [73.9154129, 15.26847076], [73.9154129, 15.26931], [73.91513824, 15.26930523], [73.91513824, 15.26986217], [73.91485596, 15.26985931], [73.91485596, 15.27153015], [73.9145813, 15.27152824], [73.9145813, 15.27319431], [73.91429901, 15.27319145], [73.91429901, 15.27375031], [73.91400909, 15.27375031], [73.91400909, 15.27431011], [73.91374969, 15.2743063], [73.91374969, 15.27486229], [73.91348267, 15.27486038], [73.91348267, 15.27542019], [73.91319275, 15.27541637], [73.91319275, 15.27597237], [73.91291809, 15.27595997], [73.91291809, 15.27653027], [73.9126358, 15.27652836], [73.9126358, 15.27708435], [73.91236115, 15.27708435], [73.91236115, 15.2798624], [73.91208649, 15.2798624], [73.91208649, 15.28069401], [73.91179657, 15.28069019], [73.91179657, 15.28153133], [73.91152954, 15.28153133], [73.91152954, 15.28236008], [73.91124725, 15.28236008], [73.91124725, 15.28319359], [73.9109726, 15.28318977], [73.9109726, 15.28431129], [73.91069794, 15.28431129], [73.91069794, 15.28542137], [73.91041565, 15.2854166], [73.91041565, 15.2859726], [73.9098587, 15.2859726], [73.9098587, 15.28819466], [73.90957642, 15.28819275], [73.90957642, 15.28903103], [73.90930939, 15.28903103], [73.90930176, 15.29014111], [73.9090271, 15.2901392], [73.9090271, 15.29069519], [73.90875244, 15.29069519], [73.90875244, 15.2909708], [73.90820313, 15.29095936], [73.90820313, 15.29153156], [73.90791321, 15.29153156], [73.90791321, 15.29264069], [73.90763855, 15.29263878], [73.90763855, 15.29347324], [73.90735626, 15.29347134], [73.90735626, 15.29430962], [73.9070816, 15.29430962], [73.9070816, 15.29513931], [73.90680695, 15.29513931], [73.90680695, 15.29597092], [73.90651703, 15.29597092], [73.90651703, 15.29681015], [73.90625, 15.29681015], [73.90625, 15.29764175], [73.90598297, 15.29764175], [73.90598297, 15.29875183], [73.90569305, 15.29874992], [73.90569305, 15.29958439], [73.90542603, 15.29958057], [73.90542603, 15.30041981], [73.90513611, 15.30041981], [73.90513611, 15.30125046], [73.90486145, 15.30125046], [73.90486145, 15.30208397], [73.90458679, 15.3020792], [73.90458679, 15.30292034], [73.90429687, 15.30292034], [73.90429687, 15.30375004], [73.90402985, 15.30375004], [73.90402985, 15.30486202], [73.90374756, 15.30486202], [73.90374756, 15.30569363], [73.9034729, 15.30568981], [73.9034729, 15.30626202], [73.90319824, 15.30624962], [73.90319824, 15.30708218], [73.90291595, 15.30708027], [73.90291595, 15.30792141], [73.9026413, 15.30791569], [73.9026413, 15.30847168], [73.90235901, 15.30846977], [73.90235901, 15.30932045], [73.90206909, 15.30932045], [73.90206909, 15.31014061], [73.90180206, 15.31013775], [73.90180206, 15.31097317], [73.9015274, 15.31097031], [73.9015274, 15.31181145], [73.90125275, 15.31181145], [73.90125275, 15.31264114], [73.90097046, 15.31263924], [73.90097046, 15.31319523], [73.9006958, 15.31319046], [73.9006958, 15.31403065], [73.90041351, 15.31402874], [73.90041351, 15.3148613], [73.90013885, 15.3148613], [73.90013885, 15.3154192], [73.89985657, 15.3154192], [73.89985657, 15.31624889], [73.89958191, 15.31624889], [73.89958191, 15.31652927], [73.89930725, 15.31652737], [73.89930725, 15.31708336], [73.89958191, 15.31708145], [73.89958191, 15.31764126], [73.8998642, 15.31763935], [73.89985657, 15.3179903], [73.89985657, 15.31820202], [73.89958191, 15.31820202], [73.89958191, 15.31875134], [73.89929962, 15.31875134], [73.89929962, 15.31903172], [73.89902496, 15.31902695], [73.89902496, 15.31958294], [73.89875031, 15.31958294], [73.89875031, 15.31986141], [73.89848328, 15.31986141], [73.89848328, 15.32014179], [73.89819336, 15.32014179], [73.89819336, 15.32153034], [73.8979187, 15.32153034], [73.8979187, 15.32180977], [73.89763641, 15.32180977], [73.89763641, 15.32236099], [73.89736176, 15.32236099], [73.89736176, 15.32319641], [73.8970871, 15.32319641], [73.8970871, 15.32458401], [73.89680481, 15.32458401], [73.89680481, 15.32486153], [73.8970871, 15.32486153], [73.8970871, 15.32514191], [73.89680481, 15.32514], [73.89680481, 15.32569408], [73.89653015, 15.32569122], [73.89653015, 15.32681274], [73.89624786, 15.32680607], [73.89624786, 15.32736206], [73.89597321, 15.32736015], [73.89597321, 15.32763958], [73.89569092, 15.32763767], [73.89569092, 15.32819366], [73.89597321, 15.3281889], [73.89597321, 15.32874966], [73.89569092, 15.32874966], [73.89569092, 15.32958412], [73.89541626, 15.32957935], [73.89541626, 15.33014011], [73.8951416, 15.33014011], [73.8951416, 15.33097172], [73.89485931, 15.33096981], [73.89485931, 15.33181095], [73.89458466, 15.33180618], [73.89458466, 15.33236217], [73.89430237, 15.33236027], [73.89430237, 15.33292103], [73.89402771, 15.33291626], [73.89402771, 15.33347225], [73.89375305, 15.33347034], [73.89375305, 15.33403111], [73.89347076, 15.33402824], [73.89347076, 15.33458424], [73.89319611, 15.33458042], [73.89319611, 15.33514118], [73.89291382, 15.33513832], [73.89291382, 15.33569431], [73.89263916, 15.33568954], [73.89263916, 15.33653069], [73.8923645, 15.33652878], [73.8923645, 15.33736038], [73.89208221, 15.33736038], [73.89208221, 15.33819485], [73.89180756, 15.33819008], [73.89180756, 15.33875084], [73.89152527, 15.33875084], [73.89152527, 15.3395834], [73.89125061, 15.33957958], [73.89125061, 15.34042072], [73.89097595, 15.34041691], [73.89097595, 15.3409729], [73.89068604, 15.34097099], [73.89068604, 15.34152889], [73.89041901, 15.34152889], [73.89041901, 15.34208298], [73.89012909, 15.34208012], [73.89012909, 15.34264088], [73.88986206, 15.34263897], [73.88986206, 15.34319496], [73.88957977, 15.34319019], [73.88957977, 15.34403133], [73.88930511, 15.34402657], [73.88930511, 15.34458256], [73.88903046, 15.34458065], [73.88903046, 15.34514141], [73.88874817, 15.34513855], [73.88874817, 15.34569454], [73.88846588, 15.34569073], [73.88846588, 15.34625053], [73.88819122, 15.34624863], [73.88819122, 15.34708309], [73.88791656, 15.34708118], [73.88791656, 15.34764194], [73.88764191, 15.34764194], [73.88764191, 15.34820175], [73.88735962, 15.34820175], [73.88735962, 15.34875202], [73.8870697, 15.34875202], [73.8870697, 15.34930992], [73.88680267, 15.34930515], [73.88680267, 15.34986115], [73.88652802, 15.34985924], [73.88652802, 15.35042], [73.88625336, 15.35041809], [73.88625336, 15.35069561], [73.88597107, 15.35069561], [73.88597107, 15.35124874], [73.88569641, 15.35124016], [73.88569641, 15.35153198], [73.88541412, 15.35152817], [73.88541412, 15.35208416], [73.88513947, 15.3520813], [73.88513947, 15.35264015], [73.88486481, 15.35264015], [73.88486481, 15.35319424], [73.88458252, 15.35319138], [73.88458252, 15.35375023], [73.88430786, 15.35375023], [73.88430786, 15.35430622], [73.88402557, 15.35430622], [73.88402557, 15.35486221], [73.88375092, 15.35486031], [73.88375092, 15.35542011], [73.88346863, 15.3554163], [73.88346863, 15.35597229], [73.88318634, 15.35597038], [73.88318634, 15.35653019], [73.88291931, 15.35652828], [73.88291931, 15.35708427], [73.88263702, 15.35707855], [73.88263702, 15.35737133], [73.88236237, 15.35737133], [73.88236237, 15.35791969], [73.88208008, 15.35791588], [73.88208008, 15.35819435], [73.88180542, 15.35819435], [73.88181305, 15.35875034], [73.88153076, 15.35875034], [73.88153076, 15.35902977], [73.88124847, 15.35902786], [73.88124847, 15.35958195], [73.88097382, 15.35958195], [73.88097382, 15.35986233], [73.88069153, 15.35986042], [73.88069153, 15.36042976], [73.88041687, 15.36041641], [73.88041687, 15.36069393], [73.88014221, 15.36069202], [73.88014221, 15.36124992], [73.87985992, 15.36124992], [73.87985992, 15.36153126], [73.87958527, 15.3615284], [73.87958527, 15.36208439], [73.87930298, 15.36207962], [73.87930298, 15.36236], [73.87902832, 15.36236], [73.87902832, 15.36292076], [73.87875366, 15.36291599], [73.87875366, 15.36319447], [73.87847137, 15.36318111], [73.87847137, 15.36375141], [73.87818909, 15.36375141], [73.87818909, 15.36403084], [73.87791443, 15.36402893], [73.87791443, 15.36458206], [73.87763977, 15.36458206], [73.87763977, 15.36485958], [73.87735748, 15.36485958], [73.87735748, 15.3654213], [73.87708282, 15.36541653], [73.87708282, 15.365695], [73.87680817, 15.365695], [73.87680817, 15.36625099], [73.87652588, 15.36624241], [73.87652588, 15.36653137], [73.87625122, 15.36652565], [73.87625122, 15.3670826], [73.87596893, 15.36707973], [73.87596893, 15.36736107], [73.87568665, 15.36736107], [73.87568665, 15.36764145], [73.87541962, 15.36763859], [73.87541962, 15.36819458], [73.87513733, 15.36819458], [73.87513733, 15.36847305], [73.87486267, 15.36847115], [73.87486267, 15.36875057], [73.87458038, 15.36875057], [73.87458038, 15.36903095], [73.87431335, 15.36903095], [73.87431335, 15.36930943], [73.87403107, 15.36930466], [73.87403107, 15.36958313], [73.87374878, 15.36958122], [73.87374878, 15.36986065], [73.87346649, 15.36986065], [73.87346649, 15.37014103], [73.87264252, 15.37014103], [73.87264252, 15.37042236], [73.87208557, 15.37041664], [73.87208557, 15.37069511], [73.86985779, 15.37069511], [73.86985779, 15.37041664], [73.86875153, 15.37042236], [73.86875153, 15.37014103], [73.86818695, 15.37014103], [73.86818695, 15.36986065], [73.86458588, 15.36986065], [73.86458588, 15.36958122], [73.86319733, 15.36958313], [73.86319733, 15.36930466], [73.86292267, 15.36930943], [73.86292267, 15.36903095], [73.86264038, 15.36903095], [73.86264038, 15.36847115], [73.86291504, 15.36847305], [73.86291504, 15.36791706], [73.8631897, 15.36792088], [73.8631897, 15.36764145], [73.86264038, 15.36764145], [73.86264038, 15.36707973], [73.86235809, 15.3670826], [73.86235809, 15.36652565], [73.86207581, 15.36653137], [73.86207581, 15.36624241], [73.86180878, 15.36625099], [73.86180878, 15.36597347], [73.86096954, 15.36597347], [73.86096954, 15.365695], [73.86069489, 15.365695], [73.86069489, 15.36597347], [73.86042023, 15.36597347], [73.86042023, 15.365695], [73.85958099, 15.365695], [73.85958099, 15.36597347], [73.85902405, 15.36597347], [73.85902405, 15.36625099], [73.85402679, 15.36625099], [73.85402679, 15.36597347], [73.85375214, 15.36597347], [73.85375214, 15.365695], [73.85319519, 15.365695], [73.85319519, 15.36541653], [73.8529129, 15.3654213], [73.8529129, 15.36485958], [73.85263824, 15.36485958], [73.85263824, 15.36402893], [73.85235596, 15.36403084], [73.85235596, 15.36153126], [73.8520813, 15.36153126], [73.8520813, 15.36124992], [73.85151672, 15.36124992], [73.85151672, 15.36096954], [73.8501358, 15.3609724], [73.8501358, 15.36069393], [73.84958649, 15.36069393], [73.84958649, 15.3609724], [73.84924316, 15.3609724], [73.84764099, 15.3609724], [73.84764099, 15.36069393], [73.8465271, 15.36069393], [73.8465271, 15.36041641], [73.84319305, 15.36042976], [73.84319305, 15.36014271], [73.84179688, 15.36014271], [73.84179688, 15.36042976], [73.8409729, 15.36041641], [73.8409729, 15.36069393], [73.84069824, 15.36069393], [73.84069824, 15.3609724], [73.8401413, 15.36096954], [73.8401413, 15.36124992], [73.83985901, 15.36124992], [73.83985901, 15.36153126], [73.83957672, 15.36153126], [73.83957672, 15.36181068], [73.83875275, 15.36180592], [73.83875275, 15.36208439], [73.8381958, 15.36207962], [73.8381958, 15.36236], [73.83763885, 15.36236], [73.83763885, 15.36292076], [73.83708191, 15.36291599], [73.83708191, 15.36319447], [73.83680725, 15.36319447], [73.83680725, 15.36347198], [73.83652496, 15.36347198], [73.83652496, 15.36485958], [73.83625031, 15.36485958], [73.83625031, 15.3654213], [73.83597565, 15.36541653], [73.83597565, 15.365695], [73.83569336, 15.36569023], [73.83569336, 15.3668108], [73.8354187, 15.36680698], [73.8354187, 15.3670826], [73.83513641, 15.36707973], [73.83513641, 15.36792088], [73.83486176, 15.36791706], [73.83486176, 15.36819458], [73.8345871, 15.36819458], [73.8345871, 15.36847305], [73.83429718, 15.36847115], [73.83429718, 15.36903095], [73.83403015, 15.36902905], [73.83403015, 15.36958313], [73.83347321, 15.36958122], [73.83347321, 15.36986065], [73.83291626, 15.36986065], [73.83291626, 15.37014103], [73.83235931, 15.37014103], [73.83235931, 15.37042236], [73.83180237, 15.37041664], [73.83180237, 15.37069511], [73.83152771, 15.37069511], [73.83152771, 15.37097263], [73.83125305, 15.37097263], [73.83125305, 15.37069511], [73.83041382, 15.37069511], [73.83041382, 15.37013912], [73.83014679, 15.37014103], [73.83014679, 15.36986065], [73.82958221, 15.36986065], [73.82958221, 15.36958122], [73.82875061, 15.36958313], [73.82875061, 15.36930466], [73.82736206, 15.36930466], [73.82736206, 15.36958313], [73.82624817, 15.36958122], [73.82624817, 15.36986065], [73.82514191, 15.36986065], [73.82514191, 15.37014103], [73.82485962, 15.37014103], [73.82485962, 15.37042236], [73.82430267, 15.37041664], [73.82430267, 15.37069511], [73.82402802, 15.37069511], [73.82402802, 15.37041664], [73.82375336, 15.37041664], [73.82375336, 15.37069511], [73.82319641, 15.37069511], [73.82319641, 15.37041664], [73.82291412, 15.37041664], [73.82291412, 15.37069511], [73.82208252, 15.37069035], [73.82208252, 15.37125111], [73.82235718, 15.37125111], [73.82235718, 15.37181187], [73.82208252, 15.37180519], [73.82208252, 15.37208271], [73.82180786, 15.3720808], [73.82180786, 15.37236977], [73.8215332, 15.37236977], [73.8215332, 15.37264061], [73.82125092, 15.37264061], [73.82125092, 15.37292194], [73.82096863, 15.37291718], [73.82096863, 15.37319469], [73.81930542, 15.37319469], [73.81930542, 15.37291718], [73.81903076, 15.37291718], [73.81903076, 15.37319469], [73.81819153, 15.37319469], [73.81819153, 15.37347317], [73.81680298, 15.37347126], [73.81680298, 15.37375069], [73.81569672, 15.37375069], [73.81569672, 15.37403202], [73.81513977, 15.37403202], [73.81513977, 15.37430954], [73.81484985, 15.37430954], [73.81484985, 15.37513924], [73.81458282, 15.37513924], [73.81458282, 15.37569332], [73.81402588, 15.37569141], [73.81402588, 15.37597084], [73.81291962, 15.37597084], [73.81291962, 15.37624931], [73.81263733, 15.37624931], [73.81263733, 15.37652969], [73.81208038, 15.37652969], [73.81208038, 15.37624931], [73.81181335, 15.37624931], [73.81181335, 15.37652969], [73.81096649, 15.37652969], [73.81096649, 15.37624931], [73.81069183, 15.37624931], [73.81069183, 15.37652969], [73.80874634, 15.37652969], [73.80874634, 15.37681007], [73.80819702, 15.37680531], [73.80819702, 15.37736225], [73.8079071, 15.37735939], [73.8079071, 15.37764168], [73.80764008, 15.37764168], [73.80764008, 15.37792015], [73.80708313, 15.37791538], [73.80708313, 15.37847137], [73.80680847, 15.37847137], [73.80680847, 15.37903023], [73.80708313, 15.37903023], [73.80708313, 15.37986183], [73.80735779, 15.37986183], [73.80735779, 15.38041973], [73.80764008, 15.38041973], [73.80764008, 15.38181019], [73.80735779, 15.38180637], [73.80735779, 15.38319397], [73.80764008, 15.38319397], [73.80764008, 15.38597202], [73.80735779, 15.38597202], [73.80735779, 15.39014053], [73.80708313, 15.39013767], [73.80708313, 15.39069366], [73.80680847, 15.39068985], [73.80680847, 15.39153099], [73.80652618, 15.39152908], [73.80652618, 15.39208221], [73.80625153, 15.39208031], [73.80625153, 15.39264107], [73.80597687, 15.39264107], [73.80597687, 15.39292145], [73.80569458, 15.39291668], [73.80569458, 15.39319515], [73.80541992, 15.39319038], [73.80541992, 15.3934803], [73.80513763, 15.3934803], [73.80513763, 15.39375114], [73.80486298, 15.39375114], [73.80486298, 15.39403057], [73.80430603, 15.39402866], [73.80430603, 15.39458275], [73.80374908, 15.39458275], [73.80374908, 15.39486122], [73.80208588, 15.39486122], [73.80208588, 15.39458275], [73.80097198, 15.39458275], [73.80097198, 15.39430523], [73.79624939, 15.39430523], [73.79624939, 15.39458275], [73.79541779, 15.39458275], [73.79541779, 15.39430523], [73.79486084, 15.39431095], [73.79486084, 15.39403057], [73.79429626, 15.39403057], [73.79429626, 15.39375114], [73.79319763, 15.39375114], [73.79319763, 15.39403057], [73.79180908, 15.39403057], [73.79180908, 15.39431095], [73.79152679, 15.39431095], [73.79152679, 15.39403057], [73.79096985, 15.39403057], [73.79096985, 15.39431095], [73.79069519, 15.39430523], [73.79069519, 15.39486122], [73.79013824, 15.39486122], [73.79013824, 15.39514065], [73.78986359, 15.39513874], [73.78986359, 15.39569473], [73.7895813, 15.39569473], [73.7895813, 15.39597321], [73.78930664, 15.3959713], [73.78930664, 15.39653969], [73.78902435, 15.3965292], [73.78902435, 15.3973608], [73.78930664, 15.3973608], [73.78930664, 15.39819527], [73.7895813, 15.39819145], [73.7895813, 15.39875126], [73.78985596, 15.39875126], [73.78985596, 15.39903164], [73.79013824, 15.39902687], [73.79013824, 15.39958286], [73.7904129, 15.39958286], [73.7904129, 15.39986134], [73.79013824, 15.39986134], [73.79013824, 15.40014076], [73.78985596, 15.40014076], [73.78985596, 15.40042019], [73.78930664, 15.40041733], [73.78930664, 15.40069485], [73.78902435, 15.40069485], [73.78902435, 15.40097332], [73.78874969, 15.40097141], [73.78874969, 15.40125084], [73.78791046, 15.40125084], [73.78791046, 15.40180969], [73.7876358, 15.40180492], [73.7876358, 15.4020834], [73.78736115, 15.4020834], [73.78736115, 15.40236092], [73.78708649, 15.40235043], [73.78708649, 15.40291977], [73.78679657, 15.40291977], [73.78679657, 15.40374947], [73.78652954, 15.40374947], [73.78652954, 15.4048624], [73.78624725, 15.4048624], [73.78624725, 15.40569305], [73.7859726, 15.40569115], [73.7859726, 15.40625191], [73.78569794, 15.40625191], [73.78569794, 15.40680981], [73.78541565, 15.40680599], [73.78541565, 15.40708447], [73.78457642, 15.40708065], [73.78457642, 15.40736198], [73.7840271, 15.40736198], [73.7840271, 15.40764046], [73.78375244, 15.40764046], [73.78375244, 15.40792179], [73.78347015, 15.40792179], [73.78347015, 15.40848064], [73.78320313, 15.40848064], [73.78320313, 15.40874958], [73.78291321, 15.40874958], [73.78291321, 15.41042042], [73.78263855, 15.41041565], [73.78263855, 15.4123621], [73.78291321, 15.41236019], [73.78291321, 15.41292095], [73.7831955, 15.41291618], [73.7831955, 15.4131937], [73.78347015, 15.4131937], [73.78347015, 15.41347218], [73.78375244, 15.41347027], [73.78375244, 15.41374969], [73.7840271, 15.41374969], [73.7840271, 15.41403103], [73.78430176, 15.41403103], [73.78430939, 15.41431141], [73.78514099, 15.41430569], [73.78514099, 15.41458225], [73.78736115, 15.41458225], [73.78736115, 15.41430569], [73.78791046, 15.41431141], [73.78791046, 15.41403103], [73.78848267, 15.41403103], [73.78848267, 15.41374969], [73.78874969, 15.41374969], [73.78874969, 15.41403103], [73.78930664, 15.41403103], [73.78930664, 15.41431141], [73.78986359, 15.41430569], [73.78986359, 15.41458225], [73.79013824, 15.41458035], [73.79013824, 15.41542053], [73.7904129, 15.41542053], [73.7904129, 15.41681099], [73.79070282, 15.41681099], [73.79070282, 15.41764069], [73.79096985, 15.41764069], [73.79096985, 15.41792107], [73.79125214, 15.4179163], [73.79125214, 15.41847324], [73.79152679, 15.41847038], [73.79152679, 15.41875076], [73.79207611, 15.41875076], [73.79207611, 15.41847038], [73.7923584, 15.41847324], [73.7923584, 15.41763783], [73.79264069, 15.41764069], [73.79264069, 15.41681099], [73.79403687, 15.41681099], [73.79403687, 15.41653061], [73.79486084, 15.41653061], [73.79486084, 15.41625023], [73.79514313, 15.41625023], [73.7951355, 15.41513824], [73.79541779, 15.41514015], [73.79541779, 15.41485977], [73.79569244, 15.41485977], [73.79569244, 15.41431141], [73.7959671, 15.41431141], [73.7959671, 15.41374969], [73.79624939, 15.41374969], [73.79624939, 15.41347027], [73.79652405, 15.41347218], [73.79652405, 15.4131937], [73.79680634, 15.4131937], [73.79680634, 15.41291618], [73.79736328, 15.41292095], [73.79736328, 15.41263962], [73.79792023, 15.41263962], [73.79792023, 15.41236019], [73.80041504, 15.4123621], [73.80041504, 15.41208363], [73.80097198, 15.41208363], [73.80097198, 15.41180611], [73.80124664, 15.41181087], [73.80124664, 15.41152096], [73.80180359, 15.41152763], [73.80180359, 15.41125011], [73.80208588, 15.41125011], [73.80208588, 15.41042042], [73.80236053, 15.41042042], [73.80236053, 15.40985966], [73.80374908, 15.40985966], [73.80374908, 15.40957928], [73.80403137, 15.40958405], [73.80403137, 15.40930557], [73.80430603, 15.40931034], [73.80430603, 15.40902996], [73.80486298, 15.40902996], [73.80486298, 15.40819073], [73.80513763, 15.40819359], [73.80513763, 15.40791798], [73.80625153, 15.40792179], [73.80625153, 15.40764046], [73.80652618, 15.40764046], [73.80652618, 15.40736198], [73.80680847, 15.40736198], [73.80680847, 15.40708065], [73.80735779, 15.40708447], [73.80735779, 15.40680599], [73.80764008, 15.40680981], [73.80764008, 15.40653038], [73.8079071, 15.40653038], [73.8079071, 15.40625191], [73.80819702, 15.40625191], [73.80819702, 15.40569115], [73.80847168, 15.40569305], [73.80847168, 15.40513992], [73.80874634, 15.40514183], [73.80874634, 15.40458107], [73.80902863, 15.40458393], [73.80902863, 15.40392017], [73.80902863, 15.40263939], [73.80930328, 15.40263939], [73.80930328, 15.40097141], [73.81096649, 15.40097141], [73.81096649, 15.40125084], [73.81181335, 15.40125084], [73.81181335, 15.40152931], [73.81234741, 15.40152931], [73.81236267, 15.40180969], [73.81319427, 15.40180492], [73.81319427, 15.4020834], [73.81346893, 15.4020834], [73.81346893, 15.40236092], [73.81375122, 15.40235043], [73.81375122, 15.40263939], [73.81430817, 15.40263939], [73.81430817, 15.40291977], [73.81485748, 15.40291691], [73.81485748, 15.40319633], [73.81541443, 15.40319633], [73.81541443, 15.40347099], [73.81569672, 15.40347099], [73.81569672, 15.40374947], [73.81597137, 15.40374947], [73.81597137, 15.40403175], [73.81624603, 15.40403175], [73.81624603, 15.40431023], [73.81652832, 15.40431023], [73.81652832, 15.40514183], [73.81625366, 15.40513992], [73.81625366, 15.40708447], [73.81652832, 15.40708065], [73.81652832, 15.40764046], [73.81624603, 15.40764046], [73.81624603, 15.40848064], [73.81597137, 15.40848064], [73.81597137, 15.41042042], [73.81652832, 15.41041565], [73.81652832, 15.41069412], [73.81680298, 15.41069412], [73.81680298, 15.41097164], [73.81874847, 15.41097164], [73.81874847, 15.41069412], [73.81958008, 15.41069412], [73.81958008, 15.41041565], [73.82125092, 15.41042042], [73.82125092, 15.41014004], [73.82208252, 15.41014004], [73.82208252, 15.40957928], [73.82263947, 15.40958405], [73.82263947, 15.40930557], [73.82319641, 15.40931034], [73.82319641, 15.40819073], [73.82347107, 15.40819359], [73.82347107, 15.40791798], [73.82319641, 15.40792179], [73.82319641, 15.40764046], [73.82347107, 15.40764046], [73.82347107, 15.40569115], [73.82375336, 15.40569305], [73.82375336, 15.40541458], [73.82460022, 15.40541458], [73.82485962, 15.4054203], [73.82485962, 15.40514183], [73.82624817, 15.40514183], [73.82624817, 15.4048624], [73.82653046, 15.4048624], [73.82653046, 15.40458393], [73.82680511, 15.40458393], [73.82680511, 15.40430546], [73.82707977, 15.40431023], [73.82707977, 15.40374947], [73.82736206, 15.40374947], [73.82736206, 15.40347099], [73.82818604, 15.40347099], [73.82818604, 15.40431023], [73.82791901, 15.40430546], [73.82791901, 15.4048624], [73.82763672, 15.4048624], [73.82763672, 15.40653038], [73.82791901, 15.40653038], [73.82791901, 15.40680981], [73.82819366, 15.40680599], [73.82819366, 15.40708447], [73.82930756, 15.40708065], [73.82930756, 15.40736198], [73.82958221, 15.40736198], [73.82958221, 15.40708065], [73.83013916, 15.40708447], [73.83013916, 15.40680599], [73.83097076, 15.40680981], [73.83097076, 15.40653038], [73.83235931, 15.40653038], [73.83235931, 15.40680981], [73.83291626, 15.40680981], [73.83291626, 15.40736198], [73.83319092, 15.40736198], [73.83319092, 15.40792179], [73.83347321, 15.40791798], [73.83347321, 15.40819359], [73.83374786, 15.40819359], [73.83374786, 15.40958405], [73.83403015, 15.40957928], [73.83403015, 15.40985966], [73.8345871, 15.40985966], [73.8345871, 15.41014004], [73.83569336, 15.41014004], [73.83569336, 15.40985966], [73.83625031, 15.40985966], [73.83625031, 15.41014004], [73.83735657, 15.41014004], [73.83735657, 15.41042042], [73.8381958, 15.41041565], [73.8381958, 15.41069412], [73.83930206, 15.41069412], [73.83930206, 15.41097164], [73.83958435, 15.41097164], [73.83958435, 15.41069412], [73.84069061, 15.41069412], [73.84069824, 15.41041565], [73.84124756, 15.41042042], [73.84124756, 15.41014004], [73.84152985, 15.41014004], [73.84152985, 15.40957928], [73.8418045, 15.40958405], [73.8418045, 15.40930557], [73.84263611, 15.40931034], [73.84263611, 15.40902996], [73.84319305, 15.40902996], [73.84319305, 15.40874958], [73.84401703, 15.40874958], [73.84401703, 15.40848064], [73.84430695, 15.40848064], [73.84432983, 15.40764046], [73.8445816, 15.40764046], [73.8445816, 15.40625191], [73.84485626, 15.40625191], [73.84485626, 15.4054203], [73.84514618, 15.4054203], [73.84514618, 15.4048624], [73.84486389, 15.4048624], [73.84486389, 15.40374947], [73.84514618, 15.40374947], [73.84513855, 15.40347099], [73.8445816, 15.40347099], [73.8445816, 15.40319633], [73.84486389, 15.40319633], [73.84486389, 15.40263939], [73.8445816, 15.40263939], [73.8445816, 15.40235043], [73.84402466, 15.40236092], [73.84402466, 15.40180492], [73.84430695, 15.40180969], [73.84430695, 15.40152931], [73.8445816, 15.40152931], [73.8445816, 15.40097141], [73.84486389, 15.40097332], [73.84486389, 15.40041733], [73.84514618, 15.40042019], [73.84514618, 15.40014076], [73.84541321, 15.40014076], [73.84541321, 15.39986134], [73.84625244, 15.39986134], [73.84625244, 15.39958286], [73.84764099, 15.39958286], [73.84764099, 15.39986134], [73.84902954, 15.39986134], [73.84902954, 15.40014076], [73.84958649, 15.40013885], [73.84958649, 15.40069485], [73.84986115, 15.40069485], [73.84986115, 15.40097332], [73.8501358, 15.40097141], [73.8501358, 15.40152931], [73.85041809, 15.40152931], [73.85041809, 15.40180969], [73.85180664, 15.40180492], [73.85180664, 15.4020834], [73.85263824, 15.4020834], [73.85263824, 15.40180492], [73.85346985, 15.40180969], [73.85346985, 15.40152931], [73.85402679, 15.40152931], [73.85402679, 15.40125084], [73.8548584, 15.40125084], [73.8548584, 15.40097141], [73.85569763, 15.40097332], [73.85569763, 15.40069485], [73.85624695, 15.40069485], [73.85624695, 15.40041733], [73.85652924, 15.40042019], [73.85652924, 15.40014076], [73.85708618, 15.40014076], [73.85708618, 15.39986134], [73.8576355, 15.39986134], [73.8576355, 15.39958286], [73.85791779, 15.39958286], [73.85791779, 15.39902687], [73.85817719, 15.39903164], [73.85819244, 15.39875126], [73.8584671, 15.39875126], [73.8584671, 15.39903164], [73.85874939, 15.39903164], [73.85874939, 15.39847088], [73.85901642, 15.39847088], [73.85901642, 15.39875126], [73.85930634, 15.39875126], [73.85930634, 15.39903164], [73.85958099, 15.39903164], [73.85958099, 15.39931202], [73.85986328, 15.39930534], [73.85986328, 15.39958286], [73.86013794, 15.39958286], [73.86013794, 15.39986134], [73.86042023, 15.39986134], [73.86042023, 15.40014076], [73.86069489, 15.40013885], [73.86069489, 15.40041733], [73.86083221, 15.40041733], [73.86096954, 15.40041733], [73.86096954, 15.40069485], [73.86125183, 15.40069103], [73.86125183, 15.40125084], [73.86180878, 15.40125084], [73.86180878, 15.40152931], [73.86264038, 15.4015274], [73.86264038, 15.4020834], [73.86347198, 15.4020834], [73.86347198, 15.40236092], [73.86456299, 15.40236092], [73.86486053, 15.40236092], [73.86486053, 15.40252113], [73.86486053, 15.40291977], [73.86514282, 15.40291977], [73.86514282, 15.40263939], [73.86541748, 15.40263939], [73.86541748, 15.40235043], [73.86736298, 15.40236092], [73.86736298, 15.4020834], [73.86791992, 15.4020834], [73.86791992, 15.40180492], [73.86875153, 15.40180969], [73.86875153, 15.40152931], [73.8693161, 15.40152931], [73.8693161, 15.40125084], [73.87014008, 15.40125084], [73.87014008, 15.40069103], [73.87097168, 15.40069485], [73.87097168, 15.40041733], [73.87152863, 15.40042019], [73.87152863, 15.39986134], [73.87180328, 15.39986134], [73.87180328, 15.39875126], [73.87124634, 15.39875126], [73.87124634, 15.39847088], [73.87097168, 15.39847088], [73.87097168, 15.39791679], [73.87124634, 15.39792156], [73.87124634, 15.3973608], [73.87152863, 15.3973608], [73.87152863, 15.39708328], [73.87208557, 15.39708328], [73.87208557, 15.39680481], [73.87403107, 15.39680481], [73.87403107, 15.39708328], [73.87513733, 15.39708328], [73.87513733, 15.3973608], [73.87541962, 15.3973608], [73.87541962, 15.39708328], [73.87569427, 15.39708328], [73.87569427, 15.39680481], [73.87680817, 15.39680481], [73.87680817, 15.39708328], [73.87708282, 15.39708328], [73.87708282, 15.3973608], [73.87735748, 15.3973608], [73.87735748, 15.39792156], [73.87763977, 15.39791679], [73.87763977, 15.39819527], [73.87847137, 15.39819527], [73.87847137, 15.39847088], [73.87874603, 15.39847088], [73.87874603, 15.39875126], [73.87902832, 15.39875126], [73.87902832, 15.39903164], [73.88041687, 15.39903164], [73.88041687, 15.39875126], [73.88069153, 15.39875126], [73.88069153, 15.39847088], [73.88263702, 15.39847088], [73.88263702, 15.39875126], [73.88291931, 15.39875126], [73.88291931, 15.39903164], [73.88318634, 15.39903164], [73.88318634, 15.39931202], [73.88346863, 15.39930534], [73.88346863, 15.39958286], [73.88375092, 15.39958286], [73.88375092, 15.39986134], [73.8840332, 15.39986134], [73.8840332, 15.40014076], [73.88430786, 15.40013885], [73.88430786, 15.40069485], [73.88458252, 15.40069485], [73.88458252, 15.40097332], [73.88485718, 15.40097141], [73.88485718, 15.40125084], [73.88513947, 15.40125084], [73.88513947, 15.40152931], [73.88540649, 15.40152931], [73.88540649, 15.40180969], [73.88569641, 15.40180492], [73.88569641, 15.40236092], [73.88652802, 15.40235043], [73.88652802, 15.40263939], [73.88680267, 15.40263939], [73.88680267, 15.4048624], [73.88652802, 15.4048624], [73.88652802, 15.40597057], [73.88625336, 15.40597057], [73.88625336, 15.40625191], [73.8870697, 15.40625191], [73.8870697, 15.40653038], [73.88791656, 15.40653038], [73.88791656, 15.40764046], [73.88846588, 15.40764046], [73.88846588, 15.40792179], [73.88957977, 15.40792179], [73.88957977, 15.40764046], [73.89041901, 15.40764046], [73.89041901, 15.40792179], [73.89069366, 15.40791798], [73.89069366, 15.40819359], [73.89097595, 15.40819073], [73.89097595, 15.40848064], [73.8915329, 15.40848064], [73.8915329, 15.40874958], [73.89208221, 15.40874958], [73.89208221, 15.40848064], [73.89235687, 15.40848064], [73.89235687, 15.40874958], [73.89263916, 15.40874958], [73.89263916, 15.40848064], [73.89319611, 15.40848064], [73.89319611, 15.40819073], [73.89375305, 15.40819359], [73.89375305, 15.40791798], [73.89402771, 15.40792179], [73.89402771, 15.40764046], [73.89457703, 15.40764046], [73.89457703, 15.40736198], [73.89485931, 15.40736198], [73.89485931, 15.40819359], [73.8951416, 15.40819073], [73.8951416, 15.40931034], [73.89541626, 15.40931034], [73.89541626, 15.41042042], [73.89569092, 15.41042042], [73.89569092, 15.41125011], [73.89597321, 15.41125011], [73.89597321, 15.4123621], [73.89624786, 15.4123621], [73.89624786, 15.41347218], [73.89653015, 15.41347218], [73.89653015, 15.41458225], [73.89679718, 15.41458035], [73.89679718, 15.41485977], [73.89653015, 15.41485977], [73.89653015, 15.41514015], [73.89626312, 15.41514015], [73.89626312, 15.41542053], [73.89597321, 15.41541576], [73.89597321, 15.41597176], [73.89569092, 15.41596985], [73.89569092, 15.41653061], [73.89541626, 15.41653061], [73.89541626, 15.41681099], [73.89485931, 15.41681099], [73.89485931, 15.41764069], [73.89457703, 15.41764069], [73.89457703, 15.41792107], [73.89430237, 15.4179163], [73.89430237, 15.41847324], [73.89375305, 15.41847038], [73.89375305, 15.41875076], [73.89347076, 15.41875076], [73.89347076, 15.41903114], [73.89319611, 15.41902924], [73.89319611, 15.41958237], [73.89290619, 15.41958046], [73.89290619, 15.42042065], [73.89263916, 15.42042065], [73.89263916, 15.4212513], [73.89208221, 15.4212513], [73.89208221, 15.42236137], [73.89180756, 15.42236137], [73.89180756, 15.42291927], [73.89152527, 15.42291737], [73.89152527, 15.42347336], [73.89125061, 15.42346191], [73.89125061, 15.42403126], [73.89097595, 15.42402744], [73.89097595, 15.42458344], [73.89068604, 15.42458057], [73.89068604, 15.42486095], [73.89041901, 15.42486095], [73.89041901, 15.42514133], [73.89012909, 15.42514133], [73.89012909, 15.42570019], [73.88957977, 15.42569542], [73.88957977, 15.42607975], [73.88957977, 15.42625141], [73.88932037, 15.42625141], [73.88931274, 15.42681026], [73.88903046, 15.42680454], [73.88903046, 15.42708302], [73.88874817, 15.42708302], [73.88874817, 15.42736053], [73.88847351, 15.42736053], [73.88847351, 15.42819309], [73.88819122, 15.42819309], [73.88819122, 15.42847347], [73.88791656, 15.42847061], [73.88791656, 15.42903042], [73.88764191, 15.42903042], [73.88764191, 15.42986107], [73.88735962, 15.42986107], [73.88735962, 15.43013859], [73.88680267, 15.43013859], [73.88680267, 15.43041992], [73.88735962, 15.43041801], [73.88735962, 15.43069553], [73.88708496, 15.43069553], [73.88708496, 15.43097115], [73.88652802, 15.43096924], [73.88652802, 15.43125153], [73.88625336, 15.43125153], [73.88625336, 15.43153191], [73.88569641, 15.43153191], [73.88569641, 15.43181038], [73.88541412, 15.43180561], [73.88541412, 15.43208408], [73.88485718, 15.43208122], [73.88486481, 15.4323616], [73.88432312, 15.4323616], [73.88432312, 15.43265057], [73.88236237, 15.43265057], [73.88236237, 15.43292046], [73.88181305, 15.43292046], [73.88181305, 15.43265057], [73.88041687, 15.43265057], [73.88041687, 15.43292046], [73.88014221, 15.43292046], [73.88014221, 15.43265057], [73.8795929, 15.43265057], [73.8795929, 15.43292046], [73.87930298, 15.43292046], [73.87930298, 15.43265057], [73.87902832, 15.43265057], [73.87902832, 15.4323616], [73.87847137, 15.4323616], [73.87847137, 15.43208122], [73.87791443, 15.43208408], [73.87791443, 15.43152714], [73.87735748, 15.43153191], [73.87735748, 15.43125153], [73.87708282, 15.43125153], [73.87708282, 15.43096924], [73.87652588, 15.43097115], [73.87652588, 15.43069553], [73.87569427, 15.43069553], [73.87569427, 15.43041801], [73.87541962, 15.43041801], [73.87541962, 15.43069553], [73.87486267, 15.43069553], [73.87486267, 15.43097115], [73.87430573, 15.43097115], [73.87430573, 15.43069553], [73.87374878, 15.43069553], [73.87374878, 15.43097115], [73.87319183, 15.43096924], [73.87319183, 15.43125153], [73.87264252, 15.43125153], [73.87264252, 15.43153191], [73.87236023, 15.43153191], [73.87236023, 15.43125153], [73.8720932, 15.43125153], [73.8720932, 15.43153191], [73.87095642, 15.43152714], [73.87069702, 15.43153191], [73.87069702, 15.43125153], [73.86875153, 15.43125153], [73.86875153, 15.43096924], [73.86791992, 15.43097115], [73.86791992, 15.43069553], [73.86763763, 15.43069553], [73.86763763, 15.43041801], [73.86736298, 15.43041992], [73.86736298, 15.43013859], [73.86708069, 15.43013859], [73.86708069, 15.42958069], [73.86624908, 15.4295826], [73.86624908, 15.42930508], [73.86541748, 15.42931175], [73.86541748, 15.42903042], [73.86514282, 15.42903042], [73.86514282, 15.42875099], [73.86458588, 15.42875099], [73.86458588, 15.42847061], [73.86152649, 15.42847347], [73.86152649, 15.4295826], [73.86180878, 15.42958069], [73.86180878, 15.43041992], [73.86207581, 15.43041992], [73.86207581, 15.43125153], [73.86180878, 15.43125153], [73.86180878, 15.43265057], [73.86152649, 15.43264008], [73.86152649, 15.43319321], [73.86125183, 15.4331913], [73.86125183, 15.43375015], [73.86096954, 15.43375015], [73.86096954, 15.43402958], [73.86068726, 15.43402958], [73.86068726, 15.43430996], [73.86042023, 15.43430614], [73.86042023, 15.43486214], [73.8601532, 15.43486023], [73.8601532, 15.43764019], [73.86042023, 15.43764019], [73.86042023, 15.43791962], [73.8601532, 15.43791962], [73.8601532, 15.44013977], [73.85986328, 15.44013786], [73.85986328, 15.44097233], [73.85958099, 15.44097233], [73.85958099, 15.44152832], [73.85930634, 15.44152832], [73.85930634, 15.44208431], [73.8584671, 15.44207954], [73.8584671, 15.44235992], [73.85819244, 15.44235992], [73.85819244, 15.44264126], [73.85764313, 15.44264126], [73.85764313, 15.44292068], [73.85652924, 15.44291592], [73.85652924, 15.44347191], [73.85569763, 15.44347], [73.85569763, 15.44375038], [73.85542297, 15.44375038], [73.85542297, 15.44459057], [73.85514069, 15.44459057], [73.85514069, 15.44514084], [73.8548584, 15.44513798], [73.8548584, 15.44569016], [73.85375214, 15.44570065], [73.85375214, 15.44625092], [73.85346985, 15.44625092], [73.85346985, 15.4465313], [73.85320282, 15.4465313], [73.85320282, 15.44681072], [73.8529129, 15.44681072], [73.8529129, 15.44736099], [73.85263824, 15.44736099], [73.85263824, 15.44847298], [73.8520813, 15.44847107], [73.8520813, 15.44903088], [73.85180664, 15.44902897], [73.85180664, 15.44958305], [73.85152435, 15.44958305], [73.85152435, 15.44968987], [73.85152435, 15.44986057], [73.85124969, 15.44986057], [73.85124969, 15.45014095], [73.85098267, 15.45014095], [73.85098267, 15.45042133], [73.85069275, 15.45041656], [73.85069275, 15.45069504], [73.8501358, 15.45069027], [73.8501358, 15.45125103], [73.84986115, 15.45125103], [73.84986115, 15.45153141], [73.84929657, 15.45153141], [73.84929657, 15.45181179], [73.84902954, 15.45180511], [73.84902954, 15.45208263], [73.84764099, 15.45208263], [73.84764099, 15.45236111], [73.8465271, 15.45236111], [73.8465271, 15.45208263], [73.84597015, 15.45208263], [73.84597015, 15.45152664], [73.84570313, 15.45153141], [73.84570313, 15.45181179], [73.84541321, 15.45181179], [73.84541321, 15.45153141], [73.8445816, 15.45153141], [73.8445816, 15.45125103], [73.84401703, 15.45125103], [73.84401703, 15.45097065], [73.84319305, 15.45097256], [73.84319305, 15.45069504], [73.8429184, 15.45069504], [73.8429184, 15.45041656], [73.84263611, 15.45042133], [73.84263611, 15.44875145], [73.84236145, 15.44875145], [73.84236145, 15.44818974], [73.84208679, 15.44819546], [73.84208679, 15.44763947], [73.84069824, 15.44764996], [73.84069824, 15.4479208], [73.84041595, 15.44791698], [73.84041595, 15.44819546], [73.8401413, 15.44819546], [73.8401413, 15.44847298], [73.83957672, 15.44847107], [73.83957672, 15.44875145], [73.83930206, 15.44875145], [73.83930206, 15.44903088], [73.83875275, 15.44902897], [73.83875275, 15.44958305], [73.83847046, 15.44958305], [73.83847046, 15.44986057], [73.83875275, 15.44986057], [73.83875275, 15.45006084], [73.83875275, 15.45013905], [73.83854675, 15.45013905], [73.8381958, 15.45013905], [73.8381958, 15.45028019], [73.8381958, 15.45042133], [73.83791351, 15.45041656], [73.83791351, 15.45069504], [73.8373642, 15.45069504], [73.8373642, 15.45097256], [73.83708191, 15.45097065], [73.83708191, 15.45125103], [73.83680725, 15.45125103], [73.83680725, 15.45097065], [73.83609009, 15.45097256], [73.83597565, 15.45097256], [73.83597565, 15.45069504], [73.83569336, 15.45069504], [73.83569336, 15.45097256], [73.8354187, 15.45097256], [73.8354187, 15.45069504], [73.83513641, 15.45069504], [73.83513641, 15.45097256], [73.83486176, 15.45097256], [73.83486176, 15.45069504], [73.83403015, 15.45069027], [73.83403015, 15.45125103], [73.83291626, 15.45125103], [73.83291626, 15.45153141], [73.83235931, 15.45153141], [73.83233643, 15.45181179], [73.83208466, 15.45180511], [73.83208466, 15.45208263], [73.83152771, 15.45208263], [73.83152771, 15.45236111], [73.83097076, 15.45236111], [73.83097076, 15.45264053], [73.83069611, 15.45264053], [73.83069611, 15.45292187], [73.83013916, 15.4529171], [73.83013916, 15.45319462], [73.82958221, 15.45319462], [73.82958221, 15.45347309], [73.82930756, 15.45347309], [73.82930756, 15.45319462], [73.82875061, 15.45319462], [73.82875061, 15.4529171], [73.82736206, 15.4529171], [73.82736206, 15.45319462], [73.82680511, 15.45319462], [73.82680511, 15.45347309], [73.82624817, 15.45347118], [73.82624817, 15.45375061], [73.82569122, 15.45375061], [73.82569122, 15.45403194], [73.82485962, 15.45403194], [73.82485962, 15.45431042], [73.82457733, 15.45431042], [73.82457733, 15.45403194], [73.82430267, 15.45403194], [73.82430267, 15.45431042], [73.82290649, 15.45431042], [73.82290649, 15.45403194], [73.81874847, 15.45403194], [73.81874847, 15.45375061], [73.81819153, 15.45375061], [73.81819153, 15.45347118], [73.81791687, 15.45347309], [73.81791687, 15.45319462], [73.81764221, 15.45319462], [73.81764221, 15.45296955], [73.81764221, 15.45263863], [73.81652832, 15.45264053], [73.81652832, 15.45236111], [73.81597137, 15.45236111], [73.81597137, 15.45306969], [73.81597137, 15.45319462], [73.81569672, 15.4531908], [73.81569672, 15.45375061], [73.8154068, 15.45375061], [73.8154068, 15.45403194], [73.81513977, 15.45403194], [73.81513977, 15.45431042], [73.81485748, 15.4543047], [73.81485748, 15.45458317], [73.81430817, 15.45458126], [73.81430817, 15.45486069], [73.81402588, 15.45486069], [73.81402588, 15.45514202], [73.81346893, 15.45514202], [73.81346893, 15.45541954], [73.81236267, 15.45541668], [73.81236267, 15.45569324], [73.81208038, 15.45569324], [73.81208038, 15.45541668], [73.81124878, 15.45541954], [73.81124878, 15.45514202], [73.81069183, 15.45514202], [73.81069183, 15.45486069], [73.81041718, 15.45486069], [73.81041718, 15.45458126], [73.80986023, 15.45458126], [73.80986023, 15.45486069], [73.80958557, 15.45486069], [73.80958557, 15.45458317], [73.80930328, 15.45458317], [73.80930328, 15.4543047], [73.80903625, 15.45431042], [73.80903625, 15.45403194], [73.80819702, 15.45403194], [73.80819702, 15.45375061], [73.80708313, 15.45375061], [73.80708313, 15.45403194], [73.80652618, 15.45403194], [73.80652618, 15.45431042], [73.80513763, 15.45431042], [73.80513763, 15.45403194], [73.80374908, 15.45403194], [73.80374908, 15.4531908], [73.80347443, 15.45319462], [73.80347443, 15.45180511], [73.80374908, 15.45181179], [73.80374908, 15.45069027], [73.80403137, 15.45069504], [73.80403137, 15.44986057], [73.80319214, 15.44986057], [73.80319214, 15.45014095], [73.80290985, 15.45014095], [73.80290985, 15.45042133], [73.80236053, 15.45041656], [73.80236053, 15.45097256], [73.80208588, 15.45097065], [73.80208588, 15.45153141], [73.80152893, 15.45153141], [73.80152893, 15.45181179], [73.80124664, 15.45180511], [73.80124664, 15.45208263], [73.80069733, 15.45208263], [73.80069733, 15.45236111], [73.80097198, 15.45236111], [73.80097198, 15.45292187], [73.80069733, 15.4529171], [73.80069733, 15.45319462], [73.80041504, 15.45319462], [73.80041504, 15.45347309], [73.80014038, 15.45347118], [73.80014038, 15.45375061], [73.79875183, 15.45375061], [73.79875183, 15.45431042], [73.79792023, 15.45431042], [73.79792023, 15.45486069], [73.79736328, 15.45486069], [73.79736328, 15.45541954], [73.79708099, 15.45541668], [73.79708099, 15.45569324], [73.79624939, 15.45569324], [73.79624939, 15.45597267], [73.79569244, 15.45597076], [73.79569244, 15.45652962], [73.79541779, 15.45652962], [73.79541779, 15.45682144], [73.7951355, 15.45680523], [73.7951355, 15.45736122], [73.79458618, 15.45735931], [73.79458618, 15.45792198], [73.79402924, 15.45791531], [73.79402924, 15.45819569], [73.79374695, 15.45819569], [73.79374695, 15.4584713], [73.79319763, 15.4584713], [73.79319763, 15.45875168], [73.79292297, 15.45875168], [73.79292297, 15.45903015], [73.79207611, 15.45903015], [73.79207611, 15.45930958], [73.79152679, 15.45930958], [73.79152679, 15.45958996], [73.79125214, 15.45958996], [73.79125214, 15.46014023], [73.79096985, 15.46014023], [73.79096985, 15.46069431], [73.79069519, 15.46069431], [73.79069519, 15.46097183], [73.79013824, 15.46097183], [73.79013824, 15.46125031], [73.7895813, 15.46125031], [73.7895813, 15.46097183], [73.78901672, 15.46097183], [73.78901672, 15.46125031], [73.78791046, 15.46125031], [73.78791046, 15.46152973], [73.7876358, 15.46152782], [73.7876358, 15.46208382], [73.78736115, 15.46208191], [73.78736115, 15.46292019], [73.78708649, 15.46292019], [73.78708649, 15.46431065], [73.78736115, 15.46430588], [73.78736115, 15.46458435], [73.7876358, 15.46457863], [73.7876358, 15.46485996], [73.78819275, 15.46485996], [73.78819275, 15.46514034], [73.79013824, 15.46514034], [73.79013824, 15.46485996], [73.79070282, 15.46485996], [73.79069519, 15.46458435], [73.79125214, 15.46458435], [73.79125214, 15.46430588], [73.79152679, 15.46431065], [73.79152679, 15.46403027], [73.79207611, 15.46403027], [73.79207611, 15.46375179], [73.79264069, 15.46375179], [73.79264069, 15.46347046], [73.79291534, 15.46347237], [73.79291534, 15.46319389], [73.79319763, 15.46319389], [73.79319763, 15.46291637], [73.79347229, 15.46292019], [73.79347229, 15.46263123], [73.79430389, 15.46263981], [73.79430389, 15.46236229], [73.79458618, 15.46236229], [73.79458618, 15.46208382], [73.79486084, 15.46208382], [73.79486084, 15.4618063], [73.79514313, 15.46181011], [73.79514313, 15.46152973], [73.79569244, 15.46152973], [73.79569244, 15.46125031], [73.79624939, 15.46125031], [73.79624939, 15.46097183], [73.79680634, 15.46097183], [73.79680634, 15.46069431], [73.79708099, 15.46069431], [73.79708099, 15.46041775], [73.79792023, 15.46041965], [73.79792023, 15.46014023], [73.79875183, 15.46014023], [73.79875183, 15.46041965], [73.80014038, 15.46041775], [73.80014038, 15.46069431], [73.80097198, 15.46069431], [73.80097198, 15.46097183], [73.80124664, 15.46097183], [73.80124664, 15.46125031], [73.80152893, 15.46125031], [73.80152893, 15.46152973], [73.80179596, 15.46152973], [73.80179596, 15.46181011], [73.80208588, 15.4618063], [73.80208588, 15.46236229], [73.80236053, 15.46236229], [73.80236053, 15.46263981], [73.80264282, 15.46263123], [73.80264282, 15.46292019], [73.80291748, 15.46291637], [73.80291748, 15.46319389], [73.80319214, 15.46319103], [73.80319214, 15.46375179], [73.80347443, 15.46374989], [73.8034668, 15.46391201], [73.8034668, 15.46403027], [73.80374908, 15.46402836], [73.80374908, 15.46458435], [73.80403137, 15.46457863], [73.80403137, 15.46485996], [73.80430603, 15.46485996], [73.80430603, 15.46514034], [73.80458069, 15.46513844], [73.80458069, 15.46569443], [73.80486298, 15.46569157], [73.80486298, 15.46652985], [73.80513763, 15.46652794], [73.80513763, 15.4673624], [73.80541992, 15.46735954], [73.80541992, 15.46792126], [73.80568695, 15.46792126], [73.80568695, 15.46875858], [73.80596924, 15.46875], [73.80596924, 15.46958447], [73.80625153, 15.4695797], [73.80625153, 15.47292137], [73.80652618, 15.4729166], [73.80652618, 15.47319508], [73.80680847, 15.47319508], [73.80680847, 15.47458267], [73.80708313, 15.47458267], [73.80708313, 15.47597313], [73.80680847, 15.47597122], [73.80680847, 15.47653103], [73.80652618, 15.47653103], [73.80652618, 15.47681236], [73.80680847, 15.47681236], [73.80680847, 15.47792244], [73.80708313, 15.47792244], [73.80708313, 15.47903061], [73.80735779, 15.47903061], [73.80735779, 15.47931194], [73.80708313, 15.47930527], [73.80708313, 15.48097324], [73.80680847, 15.48097134], [73.80680847, 15.48125076], [73.80625153, 15.48124886], [73.80625153, 15.48208332], [73.80596924, 15.48208332], [73.80596924, 15.4831953], [73.80625153, 15.48319054], [73.80625153, 15.48402977], [73.80652618, 15.48402691], [73.80652618, 15.48486233], [73.80708313, 15.48486233], [73.80708313, 15.48514175], [73.80735779, 15.48513985], [73.80735779, 15.48597145], [73.80708313, 15.48597145], [73.80708313, 15.48708439], [73.80680847, 15.48708439], [73.80680847, 15.48847198], [73.80652618, 15.48847198], [73.80652618, 15.48986244], [73.80625153, 15.48986244], [73.80625153, 15.49097157], [73.80596924, 15.49097157], [73.80597687, 15.49236202], [73.80569458, 15.49236202], [73.80568695, 15.49338055], [73.80568695, 15.49374962], [73.80541992, 15.49374962], [73.80541992, 15.4948597], [73.80458069, 15.4948597], [73.80458069, 15.49514008], [73.8034668, 15.49514008], [73.8034668, 15.49542141], [73.80124664, 15.49542141], [73.80124664, 15.49570084], [73.80097198, 15.49569416], [73.80097198, 15.49597168], [73.80014038, 15.49596977], [73.80014038, 15.49625015], [73.79875183, 15.49625015], [73.79875183, 15.49681091], [73.79819489, 15.49680424], [73.79819489, 15.49708462], [73.79792023, 15.49708462], [73.79792023, 15.49736023], [73.79736328, 15.49736023], [73.79736328, 15.49764061], [73.79708099, 15.49764061], [73.79708099, 15.49792099], [73.79680634, 15.49791622], [73.79680634, 15.49819374], [73.79624939, 15.49819374], [73.79624939, 15.49847221], [73.79486084, 15.49847221], [73.79486084, 15.49819374], [73.79458618, 15.49819374], [73.79458618, 15.49847221], [73.79402924, 15.49847221], [73.79402924, 15.49875069], [73.79347229, 15.49873924], [73.79347229, 15.49903107], [73.79319763, 15.49903107], [73.79319763, 15.49931145], [73.79208374, 15.49930668], [73.79208374, 15.49958229], [73.7904129, 15.49958038], [73.7904129, 15.49985981], [73.79013824, 15.49985981], [73.79013824, 15.49958038], [73.78985596, 15.49958038], [73.78985596, 15.49985981], [73.78930664, 15.49985981], [73.78930664, 15.49958038], [73.78901672, 15.49958038], [73.78901672, 15.49985981], [73.78874969, 15.49985981], [73.78874969, 15.49958038], [73.78847504, 15.49958229], [73.78847504, 15.49930668], [73.78791046, 15.49931145], [73.78791046, 15.49903107], [73.78708649, 15.49903107], [73.78708649, 15.49873924], [73.7868042, 15.49875069], [73.7868042, 15.49847221], [73.78652954, 15.49847221], [73.78652954, 15.49819374], [73.78624725, 15.49819374], [73.78624725, 15.49763775], [73.78569794, 15.49764061], [73.78569794, 15.49707985], [73.7859726, 15.49708462], [73.7859726, 15.49652767], [73.78624725, 15.49653053], [73.78624725, 15.49625015], [73.78679657, 15.49625015], [73.78679657, 15.49596977], [73.78736115, 15.49597168], [73.78736115, 15.49569416], [73.78791046, 15.49570084], [73.78791046, 15.49542141], [73.78819275, 15.49542141], [73.78819275, 15.49514008], [73.78791046, 15.49514008], [73.78791046, 15.49431133], [73.7876358, 15.49431133], [73.7876358, 15.49403], [73.78736115, 15.49403], [73.78736115, 15.49374962], [73.78708649, 15.49374962], [73.78708649, 15.49319172], [73.78652954, 15.49319363], [73.78652954, 15.49291611], [73.78624725, 15.49293041], [73.78624725, 15.49263954], [73.78569794, 15.49263954], [73.78569794, 15.49236202], [73.78542328, 15.49236202], [73.78542328, 15.49263954], [73.78347015, 15.49263954], [73.78347015, 15.49236202], [73.78235626, 15.49236202], [73.78235626, 15.49208164], [73.78125, 15.49208355], [73.78125, 15.49180603], [73.78097534, 15.49180603], [73.78097534, 15.49208355], [73.77986145, 15.49208164], [73.77986145, 15.49263954], [73.77958679, 15.49263954], [73.77958679, 15.49236202], [73.77929688, 15.49236202], [73.77929688, 15.49263954], [73.77873993, 15.49263954], [73.77873993, 15.49236202], [73.77791595, 15.49236202], [73.77791595, 15.49208164], [73.77735901, 15.49208355], [73.77735901, 15.49180603], [73.77690125, 15.49180603], [73.77680206, 15.49180603], [73.77680206, 15.49125004], [73.7765274, 15.49125004], [73.7765274, 15.49096966], [73.77597046, 15.49097157], [73.77597046, 15.49041557], [73.7756958, 15.49042034], [73.7756958, 15.49013996], [73.77513885, 15.49013996], [73.77513885, 15.48985958], [73.77179718, 15.48985958], [73.77179718, 15.49013996], [73.77069092, 15.49013996], [73.77069092, 15.49042034], [73.76847076, 15.49041557], [73.76847076, 15.49069405], [73.76791382, 15.49069405], [73.76791382, 15.49097157], [73.76763916, 15.49096966], [73.76763916, 15.49153042], [73.76735687, 15.49153042], [73.76735687, 15.49236202], [73.76708221, 15.49236202], [73.76708221, 15.4934721], [73.76679993, 15.49347019], [73.76679993, 15.49374962], [73.76625061, 15.49374962], [73.76625061, 15.49403], [73.76513672, 15.49403], [73.76513672, 15.49431133], [73.76486206, 15.49430561], [73.76486206, 15.49458218], [73.76457977, 15.49458027], [73.76457977, 15.49514008], [73.76431274, 15.49514008], [73.76431274, 15.49653053], [73.76403046, 15.49653053], [73.76403046, 15.49681091], [73.76431274, 15.49681091], [73.76431274, 15.49792099], [73.76457977, 15.49791622], [73.76457977, 15.49819374], [73.76541901, 15.49819374], [73.76541901, 15.49847221], [73.76597595, 15.49847031], [73.76597595, 15.49903107], [73.7665329, 15.49903107], [73.7665329, 15.49931145], [73.76679993, 15.49931145], [73.76679993, 15.49985981], [73.76708221, 15.49985981], [73.76708221, 15.50042057], [73.76679993, 15.50042057], [73.76679993, 15.50153065], [73.76652527, 15.50152874], [73.7665329, 15.5037508], [73.76625061, 15.5037508], [73.76625061, 15.50431156], [73.76597595, 15.50431156], [73.76597595, 15.50514126], [73.76625061, 15.50513935], [73.76625061, 15.50569534], [73.76597595, 15.50569534], [73.76597595, 15.50597095], [73.76625061, 15.50597095], [73.76625061, 15.50653172], [73.76597595, 15.50653172], [73.76597595, 15.50681019], [73.76541901, 15.50680542], [73.76541901, 15.50708294], [73.76513672, 15.50708294], [73.76513672, 15.50736141], [73.76486206, 15.50736141], [73.76486206, 15.50958347], [73.76457977, 15.50958061], [73.76457977, 15.51013947], [73.76431274, 15.51013947], [73.76431274, 15.5112524], [73.76403046, 15.5112524], [73.76403046, 15.5118103], [73.76374817, 15.51180458], [73.76374817, 15.51236153], [73.76403046, 15.51236153], [73.76403046, 15.51264191], [73.76374054, 15.51264191], [73.76374054, 15.51403046], [73.76346588, 15.51403046], [73.76346588, 15.51513958], [73.76319122, 15.51513958], [73.76319122, 15.51653004], [73.76291656, 15.51653004], [73.76291656, 15.51735973], [73.76264191, 15.51735973], [73.76264191, 15.51764011], [73.76235962, 15.51764011], [73.76235962, 15.51791954], [73.76208496, 15.51791573], [73.76208496, 15.51847172], [73.76180267, 15.51846981], [73.76180267, 15.51875019], [73.76207733, 15.51875019], [73.76207733, 15.51987076], [73.76180267, 15.51987076], [73.76180267, 15.52042103], [73.76152802, 15.52042103], [73.76152802, 15.52153111], [73.76125336, 15.52152824], [73.76125336, 15.52208424], [73.76097107, 15.52208424], [73.76097107, 15.52319431], [73.76069641, 15.52319431], [73.76069641, 15.52458191], [73.76041412, 15.52458477], [73.76041412, 15.52486038], [73.76013947, 15.52486038], [73.76013947, 15.52569389], [73.76040649, 15.52568054], [73.76040649, 15.52625275], [73.76013947, 15.52625275], [73.76013947, 15.52653122], [73.75985718, 15.52653122], [73.75985718, 15.52681065], [73.75958252, 15.52681065], [73.75958252, 15.52875137], [73.75930786, 15.52875137], [73.75930786, 15.52958298], [73.75902557, 15.52958298], [73.75902557, 15.52986145], [73.75875092, 15.52986145], [73.75875092, 15.53069496], [73.75846863, 15.53069019], [73.75846863, 15.53125095], [73.75818634, 15.53125095], [73.75818634, 15.53292179], [73.75792694, 15.53292179], [73.75792694, 15.53375053], [73.75763702, 15.53375053], [73.75763702, 15.53542042], [73.75736237, 15.53542042], [73.75736237, 15.53625107], [73.75708008, 15.53625107], [73.75708008, 15.53652954], [73.75680542, 15.53652668], [73.75680542, 15.53708267], [73.75653076, 15.53708267], [73.75653076, 15.53847122], [73.75681305, 15.53847122], [73.75681305, 15.53931046], [73.75624847, 15.53930473], [73.75624847, 15.53958416], [73.75596619, 15.5395813], [73.75596619, 15.54041958], [73.75569153, 15.54041958], [73.75569153, 15.54181004], [73.75541687, 15.54181004], [73.75541687, 15.54292011], [73.75514221, 15.54292011], [73.75514221, 15.54374981], [73.75485992, 15.54374981], [73.75485992, 15.54569435], [73.75458527, 15.54569435], [73.7545929, 15.54625034], [73.75402832, 15.54625034], [73.75402832, 15.54763985], [73.75374603, 15.54763985], [73.75374603, 15.54874992], [73.75347137, 15.54874992], [73.75347137, 15.54903126], [73.75319672, 15.54903126], [73.75319672, 15.55014133], [73.7529068, 15.55014133], [73.7529068, 15.55125046], [73.75263977, 15.55125046], [73.75263977, 15.55208206], [73.75235748, 15.55208015], [73.75235748, 15.55264091], [73.75208282, 15.55264091], [73.75208282, 15.55375099], [73.75180054, 15.55375099], [73.75180054, 15.5543108], [73.75152588, 15.5543108], [73.75152588, 15.55486107], [73.75125122, 15.55486107], [73.75125122, 15.55708313], [73.75096893, 15.55708027], [73.75096893, 15.55764103], [73.75069427, 15.55763912], [73.75069427, 15.55847263], [73.75041962, 15.55847073], [73.75041962, 15.55904102], [73.75013733, 15.55904102], [73.75013733, 15.55931187], [73.74986267, 15.55930519], [73.74986267, 15.55986118], [73.74958038, 15.55986118], [73.74958038, 15.56042194], [73.74930573, 15.56041718], [73.74930573, 15.56069469], [73.74874115, 15.56069088], [73.74874115, 15.56125069], [73.74846649, 15.56125069], [73.74846649, 15.56153202], [73.74791718, 15.56153202], [73.74791718, 15.56180954], [73.74736023, 15.56180954], [73.74736023, 15.56153202], [73.74652863, 15.56153202], [73.74652863, 15.56125069], [73.74624634, 15.56125069], [73.74624634, 15.56097126], [73.74514008, 15.56097317], [73.74514008, 15.56069469], [73.74485779, 15.56069469], [73.74485779, 15.56097317], [73.74458313, 15.56097126], [73.74458313, 15.56125069], [73.74430847, 15.56125069], [73.74430847, 15.56153202], [73.74402618, 15.56153202], [73.74402618, 15.56180954], [73.74375153, 15.56180477], [73.74375153, 15.56208324], [73.74346924, 15.56208134], [73.74346924, 15.56236076], [73.74318695, 15.56236076], [73.74318695, 15.56263924], [73.74291992, 15.56263924], [73.74291992, 15.56291962], [73.74263763, 15.56291676], [73.74263763, 15.56319523], [73.74124908, 15.56319141], [73.74124908, 15.56347084], [73.7409668, 15.56347084], [73.7409668, 15.56431007], [73.74069214, 15.56431007], [73.74069214, 15.56514168], [73.74041748, 15.56514168], [73.74041748, 15.56542015], [73.74069214, 15.56541538], [73.74069214, 15.56569576], [73.74097443, 15.56569576], [73.74097443, 15.56597137], [73.74124908, 15.56597137], [73.74124908, 15.56625175], [73.74153137, 15.56625175], [73.74153137, 15.56653023], [73.74124908, 15.56652737], [73.74124908, 15.56708431], [73.7409668, 15.56708145], [73.7409668, 15.5676403], [73.74069214, 15.5676403], [73.74069214, 15.56819439], [73.7409668, 15.56819057], [73.7409668, 15.56931019], [73.74124908, 15.56930637], [73.74124908, 15.56986237], [73.74153137, 15.56986046], [73.74153137, 15.57014179], [73.74180603, 15.57013988], [73.74180603, 15.5706892], [73.74153137, 15.57070065], [73.74153137, 15.57124996], [73.74124908, 15.57124996], [73.74124908, 15.57153034], [73.74097443, 15.57152843], [73.74097443, 15.57208443], [73.74069214, 15.57208157], [73.74069214, 15.57291985], [73.74041748, 15.57291603], [73.74041748, 15.57319355], [73.74014282, 15.57319164], [73.74014282, 15.57374954], [73.74041748, 15.57374954], [73.74041748, 15.57402802], [73.74014282, 15.57402134], [73.74014282, 15.57514], [73.73986053, 15.57513809], [73.73986053, 15.57569408], [73.73958588, 15.57569027], [73.73958588, 15.57681084], [73.73930359, 15.57680416], [73.73930359, 15.57736015], [73.73902893, 15.57736015], [73.73902893, 15.57792091], [73.73874664, 15.57791615], [73.73874664, 15.57819366], [73.73847198, 15.57819366], [73.73847198, 15.57847214], [73.73819733, 15.57847023], [73.73819733, 15.57903099], [73.73792267, 15.57903099], [73.73792267, 15.57931137], [73.73764038, 15.5793066], [73.73764038, 15.57958221], [73.73792267, 15.57958031], [73.73792267, 15.58014965], [73.73764038, 15.58013821], [73.73764038, 15.58069515], [73.73708344, 15.58069515], [73.73708344, 15.58097267], [73.73680878, 15.58097267], [73.73680878, 15.58347321], [73.73652649, 15.5834713], [73.73652649, 15.58431244], [73.73625183, 15.58430481], [73.73625183, 15.5848608], [73.73652649, 15.5848608], [73.73652649, 15.58542156], [73.73625183, 15.58541679], [73.73625183, 15.58597088], [73.73596954, 15.58595943], [73.73596954, 15.58625126], [73.73568726, 15.58625126], [73.73568726, 15.58653069], [73.73542023, 15.58652687], [73.73542023, 15.58708286], [73.73513794, 15.58708286], [73.73513794, 15.58736134], [73.73458099, 15.58736134], [73.73458099, 15.58764076], [73.73430634, 15.58764076], [73.73430634, 15.58791924], [73.73374939, 15.58791733], [73.73374939, 15.58819485], [73.73347473, 15.58819485], [73.73347473, 15.58847332], [73.73291779, 15.58847141], [73.73291779, 15.58875084], [73.73236084, 15.58874893], [73.73236084, 15.5890274], [73.73208618, 15.58902264], [73.73208618, 15.58930969], [73.73179626, 15.58930969], [73.73179626, 15.58986092], [73.73152924, 15.58986092], [73.73152924, 15.59041977], [73.73124695, 15.59041691], [73.73124695, 15.59097099], [73.73152924, 15.59097099], [73.73152924, 15.59125233], [73.73208618, 15.59125233], [73.73208618, 15.59208965], [73.7326355, 15.59208298], [73.7326355, 15.59236145], [73.73291779, 15.59236145], [73.73291779, 15.59264183], [73.73319244, 15.59264183], [73.73319244, 15.5929203], [73.73402405, 15.5929184], [73.73402405, 15.59319305], [73.73430634, 15.59319305], [73.73430634, 15.59347057], [73.73401642, 15.59347057], [73.73401642, 15.59430981], [73.73375702, 15.59430981], [73.73375702, 15.59515095], [73.7334671, 15.59515095], [73.7334671, 15.59624958], [73.73319244, 15.59624958], [73.73319244, 15.59708405], [73.73291779, 15.59708405], [73.73291779, 15.59819412], [73.73264313, 15.59818935], [73.73264313, 15.59875202], [73.73236084, 15.59875202], [73.73236084, 15.59902954], [73.73208618, 15.59902954], [73.73208618, 15.60042095], [73.7326355, 15.60041809], [73.7326355, 15.6006937], [73.73291779, 15.6006937], [73.73291779, 15.60097218], [73.73319244, 15.60096073], [73.73319244, 15.60124969], [73.7334671, 15.60124969], [73.73347473, 15.60347176], [73.73319244, 15.60347176], [73.73319244, 15.60403061], [73.73291779, 15.60402775], [73.73291779, 15.60458374], [73.73264313, 15.60457993], [73.73264313, 15.60514069], [73.73236084, 15.60514069], [73.73236084, 15.60542107], [73.73208618, 15.6054163], [73.73208618, 15.60569382], [73.73236084, 15.60569], [73.73236084, 15.60625076], [73.73208618, 15.60625076], [73.73208618, 15.60653114], [73.73179626, 15.60653114], [73.73179626, 15.60681057], [73.73152924, 15.60681057], [73.73152924, 15.6070919], [73.73124695, 15.6070919], [73.73124695, 15.60764122], [73.73097229, 15.60763931], [73.73097229, 15.6081953], [73.73124695, 15.6081953], [73.73124695, 15.60847282], [73.73319244, 15.60847282], [73.73319244, 15.6081953], [73.73402405, 15.6081953], [73.73402405, 15.60847282], [73.73458099, 15.60846996], [73.73458099, 15.6087513], [73.73513794, 15.6087513], [73.73513794, 15.60846996], [73.73542023, 15.60846996], [73.73542023, 15.6087513], [73.73764038, 15.6087513], [73.73764038, 15.60903072], [73.73902893, 15.60903072], [73.73902893, 15.60846996], [73.73930359, 15.60847282], [73.73930359, 15.6081953], [73.73902893, 15.6081953], [73.73902893, 15.60735989], [73.73929596, 15.60736275], [73.73929596, 15.6070919], [73.74014282, 15.6070919], [73.74014282, 15.60681057], [73.74041748, 15.60681057], [73.74041748, 15.60653114], [73.7409668, 15.60653114], [73.7409668, 15.60625076], [73.74124908, 15.60625076], [73.74124908, 15.60486031], [73.74153137, 15.60486031], [73.74153137, 15.60458374], [73.74263763, 15.60458374], [73.74263763, 15.60486031], [73.74346924, 15.60486031], [73.74346924, 15.60514069], [73.74430847, 15.60514069], [73.74430847, 15.60542107], [73.74514008, 15.6054163], [73.74514008, 15.60569382], [73.74541473, 15.60569382], [73.74541473, 15.60597229], [73.74597168, 15.60597038], [73.74597168, 15.60625076], [73.74624634, 15.60625076], [73.74624634, 15.60653114], [73.74652863, 15.60653114], [73.74652863, 15.60681057], [73.74680328, 15.60681057], [73.74680328, 15.6070919], [73.7470932, 15.6070919], [73.7470932, 15.60764122], [73.74736023, 15.60764122], [73.74736023, 15.60792065], [73.74764252, 15.60791683], [73.74764252, 15.6081953], [73.74847412, 15.6081953], [73.74847412, 15.60847282], [73.74958038, 15.60846996], [73.74958038, 15.6087513], [73.75041962, 15.6087513], [73.75041962, 15.60903072], [73.75096893, 15.60903072], [73.75096893, 15.6093092], [73.75125122, 15.60930538], [73.75125122, 15.6095829], [73.75180817, 15.6095829], [73.75180817, 15.60986137], [73.75208282, 15.60986137], [73.75208282, 15.61042118], [73.75235748, 15.61042118], [73.75235748, 15.61153126], [73.75263977, 15.61153126], [73.75263977, 15.61236095], [73.75291443, 15.61236095], [73.75291443, 15.61347103], [73.75319672, 15.61347103], [73.75319672, 15.61403179], [73.75374603, 15.61403179], [73.75374603, 15.61431026], [73.75402832, 15.61430454], [73.75402832, 15.61486053], [73.75430298, 15.61486053], [73.75430298, 15.61542034], [73.75458527, 15.61541653], [73.75458527, 15.61569309], [73.75485992, 15.61569118], [73.75485992, 15.61736107], [73.75430298, 15.61736107], [73.75430298, 15.61763859], [73.75374603, 15.61763859], [73.75374603, 15.61792183], [73.75319672, 15.61791706], [73.75319672, 15.61819458], [73.75263977, 15.61819458], [73.75263977, 15.61847115], [73.75208282, 15.61847115], [73.75208282, 15.61875153], [73.75152588, 15.61875153], [73.75152588, 15.61903191], [73.75096893, 15.61903191], [73.75096893, 15.61932087], [73.75068665, 15.61932087], [73.75069427, 15.6198616], [73.75041962, 15.6198616], [73.75041962, 15.62014198], [73.74986267, 15.62014198], [73.74986267, 15.62042046], [73.74930573, 15.62041759], [73.74931335, 15.62066174], [73.74903107, 15.62069321], [73.74903107, 15.62097359], [73.74846649, 15.62097073], [73.74846649, 15.62125015], [73.74819183, 15.62125015], [73.74819183, 15.62180996], [73.74791718, 15.62180996], [73.74791718, 15.62263966], [73.74819183, 15.62263966], [73.74819183, 15.62430954], [73.74847412, 15.62430573], [73.74847412, 15.6245842], [73.74819183, 15.62457943], [73.74819183, 15.62485981], [73.74791718, 15.62485981], [73.74791718, 15.62514019], [73.74764252, 15.62513065], [73.74764252, 15.62541962], [73.74736023, 15.6254158], [73.74736023, 15.62569427], [73.74708557, 15.62569427], [73.7470932, 15.62597179], [73.74680328, 15.62597179], [73.74680328, 15.62625027], [73.74652863, 15.62625027], [73.74652863, 15.62652969], [73.74624634, 15.62652969], [73.74624634, 15.62681103], [73.74597168, 15.62681103], [73.74597168, 15.62652969], [73.7454071, 15.62652969], [73.7454071, 15.62625027], [73.74485779, 15.62625027], [73.74485779, 15.62597179], [73.74402618, 15.62597179], [73.74402618, 15.62569237], [73.74375153, 15.62569427], [73.74375153, 15.6254158], [73.74318695, 15.62541962], [73.74318695, 15.62513065], [73.74263763, 15.62514019], [73.74263763, 15.62485981], [73.74236298, 15.62485981], [73.74236298, 15.62457943], [73.74180603, 15.6245842], [73.74180603, 15.62430573], [73.74124908, 15.62430954], [73.74124908, 15.62403011], [73.74069214, 15.62403011], [73.74069214, 15.62374973], [73.74041748, 15.62374973], [73.74041748, 15.62346935], [73.74013519, 15.62347221], [73.74013519, 15.62319374], [73.73986053, 15.62319374], [73.73986053, 15.62291622], [73.73958588, 15.62292004], [73.73958588, 15.62263966], [73.73929596, 15.62263966], [73.73929596, 15.62207031], [73.73902893, 15.62208366], [73.73902893, 15.62125015], [73.73874664, 15.62125015], [73.73874664, 15.6198616], [73.73847198, 15.6198616], [73.73847198, 15.61958122], [73.73874664, 15.61958313], [73.73874664, 15.61930466], [73.73847198, 15.61930466], [73.73847198, 15.6170826], [73.73791504, 15.6170826], [73.73791504, 15.61624908], [73.73735809, 15.61626053], [73.73735809, 15.61542034], [73.73707581, 15.61542034], [73.73707581, 15.61514091], [73.73680115, 15.61514091], [73.73680115, 15.61486053], [73.73652649, 15.61486053], [73.73652649, 15.61458302], [73.73625183, 15.61458302], [73.73625183, 15.61430454], [73.73596954, 15.61430454], [73.73596954, 15.61458302], [73.73569489, 15.61458302], [73.73569489, 15.61486053], [73.73542023, 15.61486053], [73.73542023, 15.61597347], [73.73486328, 15.61597061], [73.73486328, 15.61626053], [73.73430634, 15.61626053], [73.73430634, 15.61652946], [73.73375702, 15.61652946], [73.73375702, 15.61681175], [73.73347473, 15.61680508], [73.73347473, 15.6170826], [73.73319244, 15.6170826], [73.73319244, 15.61680508], [73.73291779, 15.61681175], [73.73291779, 15.61763859], [73.73264313, 15.61763859], [73.73264313, 15.61903191], [73.73236084, 15.61902714], [73.73236084, 15.61958313], [73.73208618, 15.61958122], [73.73208618, 15.62014198], [73.73124695, 15.62014008], [73.73124695, 15.62069321], [73.73097229, 15.62069321], [73.73097229, 15.62097359], [73.73069763, 15.62097073], [73.73069763, 15.62125015], [73.73042297, 15.62125015], [73.73042297, 15.62263966], [73.73014069, 15.62263966], [73.73014069, 15.62292004], [73.7298584, 15.62291622], [73.7298584, 15.62319374], [73.72957611, 15.62319088], [73.72957611, 15.62374973], [73.72930908, 15.62374973], [73.72930908, 15.62403011], [73.72958374, 15.62402821], [73.72958374, 15.6245842], [73.72930908, 15.62457943], [73.72930908, 15.62541962], [73.72902679, 15.6254158], [73.72902679, 15.62569427], [73.72875214, 15.62569237], [73.72875214, 15.62597179], [73.72846985, 15.62597179], [73.72846985, 15.62625027], [73.72819519, 15.62625027], [73.72819519, 15.62708378], [73.7279129, 15.62708187], [73.7279129, 15.62764263], [73.72763062, 15.62764263], [73.72763062, 15.6279211], [73.72735596, 15.6279211], [73.72735596, 15.62820053], [73.72680664, 15.62819386], [73.72680664, 15.62847233], [73.72624969, 15.62847042], [73.72624969, 15.62874985], [73.72569275, 15.62874985], [73.72569275, 15.62903118], [73.7251358, 15.62903118], [73.7251358, 15.62931061], [73.72486115, 15.62930584], [73.72486115, 15.62958431], [73.72319794, 15.62957954], [73.72319794, 15.62985992], [73.72292328, 15.62985992], [73.72292328, 15.6301403], [73.72264099, 15.6301403], [73.72264099, 15.63126183], [73.72292328, 15.63126183], [73.72292328, 15.63153076], [73.72264099, 15.6315279], [73.72264099, 15.63236046], [73.7223587, 15.63236046], [73.7223587, 15.63292122], [73.72208405, 15.63291645], [73.72208405, 15.6334734], [73.72181702, 15.63346958], [73.72180176, 15.63432026], [73.7215271, 15.63432026], [73.7215271, 15.63514137], [73.72125244, 15.63513947], [73.72125244, 15.63569546], [73.72097015, 15.63568974], [73.72097015, 15.63653088], [73.7206955, 15.63652897], [73.7206955, 15.63708305], [73.72041321, 15.63708305], [73.72041321, 15.63736057], [73.72013855, 15.63736057], [73.72013855, 15.63819504], [73.71985626, 15.63819027], [73.71985626, 15.63875103], [73.7195816, 15.63875103], [73.7195816, 15.63903141], [73.71930695, 15.63903141], [73.71930695, 15.63931179], [73.71902466, 15.63930511], [73.71902466, 15.63958263], [73.71875763, 15.63958073], [73.71875763, 15.64014053], [73.71848297, 15.64014053], [73.71848297, 15.64042187], [73.71819305, 15.6404171], [73.71819305, 15.64069462], [73.7179184, 15.6406908], [73.7179184, 15.64181042], [73.71763611, 15.64181042], [73.71763611, 15.64264202], [73.71736145, 15.64264202], [73.71736145, 15.64402866], [73.71708679, 15.64402866], [73.71708679, 15.6451416], [73.71679688, 15.6451416], [73.71679688, 15.64542198], [73.71652985, 15.64542198], [73.71652985, 15.64626122], [73.71624756, 15.64626122], [73.71624756, 15.64680958], [73.71652985, 15.64680481], [73.71652985, 15.64708424], [73.71624756, 15.64708138], [73.71624756, 15.64764023], [73.7159729, 15.64764023], [73.7159729, 15.64819336], [73.71569824, 15.64819336], [73.71569824, 15.64847183], [73.71541595, 15.64847183], [73.71541595, 15.6493063], [73.7151413, 15.6493063], [73.7151413, 15.64958382], [73.71485901, 15.64958096], [73.71485901, 15.65013981], [73.7151413, 15.65013981], [73.7151413, 15.6506958], [73.71541595, 15.65069103], [73.71541595, 15.65264034], [73.71569061, 15.65264034], [73.71569061, 15.65375042], [73.71541595, 15.65375042], [73.71541595, 15.65431118], [73.7151413, 15.65430641], [73.7151413, 15.6548624], [73.71430206, 15.65485954], [73.71430206, 15.65543175], [73.71375275, 15.65541553], [73.71375275, 15.65597153], [73.71347046, 15.65596962], [73.71347046, 15.65625], [73.7131958, 15.65625], [73.7131958, 15.65681076], [73.71291351, 15.65680599], [73.71291351, 15.65847206], [73.71263885, 15.65847206], [73.71263885, 15.66125107], [73.71235657, 15.66124153], [73.71235657, 15.66181087], [73.71208191, 15.66181087], [73.71208191, 15.66264057], [73.71180725, 15.66264057], [73.71180725, 15.66375065], [73.71151733, 15.66375065], [73.71151733, 15.66403103], [73.71180725, 15.66402912], [73.71180725, 15.66458321], [73.71151733, 15.66458035], [73.71151733, 15.66514111], [73.71125031, 15.6651392], [73.71125031, 15.66569519], [73.71097565, 15.66569519], [73.71097565, 15.66708279], [73.71125031, 15.66708279], [73.71125031, 15.66847324], [73.71098328, 15.66847134], [73.71098328, 15.66875076], [73.71069336, 15.66875076], [73.71069336, 15.66902924], [73.7104187, 15.66902924], [73.7104187, 15.66930962], [73.71013641, 15.66930962], [73.71013641, 15.66986084], [73.70986176, 15.66986084], [73.70986176, 15.67043114], [73.7095871, 15.67041683], [73.7095871, 15.6706953], [73.70930481, 15.6706953], [73.70930481, 15.67097092], [73.70903015, 15.67097092], [73.70903015, 15.67124939], [73.70847321, 15.67124939], [73.70847321, 15.67153168], [73.70791626, 15.67153168], [73.70791626, 15.67181015], [73.7076416, 15.67180538], [73.7076416, 15.6720829], [73.70735931, 15.6720829], [73.70735931, 15.67236137], [73.70707703, 15.67236137], [73.70707703, 15.67292023], [73.70680237, 15.67291832], [73.70680237, 15.67347145], [73.70652771, 15.67347145], [73.70652771, 15.67430973], [73.70625305, 15.67430973], [73.70625305, 15.67486191], [73.70597076, 15.67486191], [73.70597076, 15.67514038], [73.70569611, 15.67513657], [73.70569611, 15.67569447], [73.70541382, 15.67569447], [73.70541382, 15.67625046], [73.70513916, 15.67624092], [73.70513916, 15.67653179], [73.70540619, 15.67653179], [73.70540619, 15.67681026], [73.70513916, 15.67681026], [73.70513916, 15.67875195], [73.70485687, 15.67875195], [73.70485687, 15.67903042], [73.70458221, 15.67902756], [73.70458221, 15.67958355], [73.70430756, 15.67958355], [73.70430756, 15.6809721], [73.7040329, 15.68097019], [73.7040329, 15.68181133], [73.70375061, 15.68181133], [73.70375061, 15.68236923], [73.7040329, 15.68236923], [73.7040329, 15.68264008], [73.70375061, 15.68264008], [73.70375061, 15.68431091], [73.70347595, 15.68431091], [73.70347595, 15.68514061], [73.70319366, 15.68513775], [73.70319366, 15.68569374], [73.70263672, 15.68569374], [73.70263672, 15.68597221], [73.70291901, 15.68597031], [73.70291901, 15.68653107], [73.70318604, 15.68653107], [73.70318604, 15.68681145], [73.70291901, 15.68681145], [73.70291901, 15.68764114], [73.70263672, 15.68764114], [73.70263672, 15.68792057], [73.70236206, 15.68792057], [73.70236206, 15.68875122], [73.70207977, 15.68875122], [73.70207977, 15.68931103], [73.70180511, 15.68930531], [73.70180511, 15.6898613], [73.70153046, 15.6898613], [73.70153046, 15.69069481], [73.70124817, 15.69069004], [73.70124817, 15.6912508], [73.70096588, 15.6912508], [73.70096588, 15.69154263], [73.70069122, 15.69154263], [73.70069122, 15.69181156], [73.70041656, 15.69180489], [73.70041656, 15.69208336], [73.69957733, 15.69208145], [73.69957733, 15.69236088], [73.69930267, 15.69236088], [73.69930267, 15.69208145], [73.69790649, 15.69208145], [73.69790649, 15.69431019], [73.69763947, 15.69430542], [73.69763947, 15.69486141], [73.69735718, 15.69486141], [73.69735718, 15.69541931], [73.69708252, 15.69541931], [73.69708252, 15.69680977], [73.69736481, 15.696805], [73.69736481, 15.69819546], [73.69708252, 15.69819546], [73.69708252, 15.69847107], [73.69680786, 15.69847107], [73.69680786, 15.6987524], [73.69708252, 15.6987524], [73.69708252, 15.6993103], [73.69652557, 15.69930458], [73.69652557, 15.69958305], [73.69569397, 15.69958305], [73.69569397, 15.69930458], [73.69541931, 15.69930458], [73.69541931, 15.69958305], [73.69513702, 15.69958305], [73.69513702, 15.69986057], [73.69486237, 15.69986057], [73.69486237, 15.70014191], [73.69430542, 15.70014], [73.69430542, 15.70041847], [73.69403076, 15.70041847], [73.69403076, 15.70208359], [73.69374847, 15.70208073], [73.69374847, 15.70263958], [73.69319153, 15.70263958], [73.69319153, 15.70514011], [73.69347382, 15.70514011], [73.69347382, 15.7070837], [73.69291687, 15.70708179], [73.69291687, 15.70792103], [73.69264221, 15.70792103], [73.69264221, 15.70903015], [73.69235992, 15.70903015], [73.69235992, 15.70931053], [73.69264221, 15.70931053], [73.69264221, 15.71014023], [73.6920929, 15.71014023], [73.6920929, 15.71042061], [73.69180298, 15.71041584], [73.69180298, 15.71069431], [73.69152069, 15.71068954], [73.69152069, 15.71153069], [73.69124603, 15.71153069], [73.69124603, 15.71181107], [73.69097137, 15.7118063], [73.69097137, 15.71208191], [73.69125366, 15.71208191], [73.69125366, 15.71236038], [73.69097137, 15.71235085], [73.69097137, 15.71264076], [73.69124603, 15.71264076], [73.69124603, 15.71375275], [73.69097137, 15.71375275], [73.69097137, 15.71403122], [73.69069672, 15.71403122], [73.69069672, 15.7151413], [73.69041443, 15.71513939], [73.69041443, 15.71569538], [73.69013977, 15.71568966], [73.69013977, 15.71625137], [73.68985748, 15.71625137], [73.68985748, 15.71652889], [73.68958282, 15.71652889], [73.68958282, 15.71708298], [73.68985748, 15.71708012], [73.68985748, 15.71792126], [73.69013977, 15.71792126], [73.69013977, 15.71848202], [73.68985748, 15.71848202], [73.68985748, 15.71875095], [73.68930817, 15.71875095], [73.68930817, 15.71903133], [73.68902588, 15.71903133], [73.68902588, 15.71931171], [73.68846893, 15.71930695], [73.68846893, 15.71958256], [73.68791962, 15.71958065], [73.68791962, 15.71986103], [73.68763733, 15.71986103], [73.68763733, 15.72014141], [73.68708038, 15.72014141], [73.68708038, 15.72042179], [73.68680573, 15.72041702], [73.68680573, 15.72069454], [73.68653107, 15.72069454], [73.68653107, 15.72041702], [73.68624878, 15.72042179], [73.68624878, 15.72014141], [73.68319702, 15.72014141], [73.68319702, 15.72042179], [73.6829071, 15.72042179], [73.6829071, 15.72181034], [73.68125153, 15.72181034], [73.68125153, 15.72152042], [73.68096924, 15.7215271], [73.68096924, 15.72097301], [73.68069458, 15.72097301], [73.68069458, 15.72069454], [73.67986298, 15.72069454], [73.67986298, 15.72097301], [73.67958069, 15.72097301], [73.67958069, 15.7215271], [73.67930603, 15.72152042], [73.67930603, 15.72236061], [73.67958069, 15.72236061], [73.67958069, 15.72291946], [73.67986298, 15.7229166], [73.67986298, 15.7234726], [73.68013763, 15.7234726], [73.68013763, 15.72437096], [73.68245697, 15.7252512], [73.68530273, 15.72587109], [73.69185638, 15.72690964], [73.69734192, 15.72623062], [73.70265961, 15.72491074], [73.70658875, 15.72173023], [73.71098328, 15.7202301], [73.71856689, 15.72161961], [73.72255707, 15.7228899], [73.72764587, 15.72247982], [73.73226166, 15.72058105], [73.73703766, 15.71725082], [73.7410202, 15.71872139], [73.7440567, 15.72564125], [73.74871063, 15.73057079], [73.75824738, 15.73275185], [73.77578735, 15.73053169], [73.78649139, 15.72325039], [73.79321289, 15.72366047], [73.79756927, 15.72509193], [73.80284119, 15.73219967], [73.81262207, 15.73351955], [73.81603241, 15.73526955], [73.82039642, 15.73991013], [73.83303833, 15.73775196], [73.83846283, 15.7488308], [73.84030151, 15.75620174], [73.83878326, 15.76089001], [73.84512329, 15.76336002], [73.84716797, 15.76613045], [73.84963226, 15.77602959], [73.85190582, 15.77841187], [73.856987, 15.77822971], [73.85579681, 15.78326035], [73.8600769, 15.78779125], [73.86158752, 15.79388046], [73.86548615, 15.79752922], [73.87349701, 15.79532146], [73.87593079, 15.79323101], [73.87483978, 15.78634071], [73.87509918, 15.78289986], [73.87986755, 15.779212], [73.88024902, 15.77739143], [73.88685608, 15.77029133], [73.88684082, 15.7671299], [73.88432312, 15.76462078], [73.88260651, 15.75669193], [73.88024139, 15.75255108], [73.88244629, 15.74935055], [73.8859024, 15.74726105], [73.90860748, 15.74233055], [73.91483307, 15.74549198], [73.91793823, 15.74540138], [73.92415619, 15.74282074], [73.94536591, 15.74152184], [73.94976044, 15.73263073], [73.95082092, 15.72322941], [73.95593262, 15.71692085], [73.95886993, 15.71129131], [73.95778656, 15.70735073], [73.9560318, 15.70479107], [73.9586792, 15.70125198], [73.95723724, 15.6967392], [73.96573639, 15.69502068], [73.97130585, 15.68725109], [73.97219849, 15.67669201], [73.97158813, 15.66839123], [73.97570038, 15.65978146], [73.97422791, 15.65467072], [73.97072601, 15.64966106], [73.96926117, 15.64432144], [73.97598267, 15.62894154], [73.98142242, 15.62503147], [73.98606873, 15.62338066], [73.99021149, 15.62063026], [73.99294281, 15.61631107], [73.998703, 15.61112976], [74.002388, 15.6090517], [74.00784302, 15.60829926], [74.01317596, 15.60934067], [74.02793121, 15.60459995], [74.03557587, 15.60929108], [74.03929901, 15.62085056], [74.05680084, 15.62272167], [74.06770325, 15.62471199], [74.0735321, 15.62667179], [74.08055115, 15.62617016], [74.10243988, 15.63896084], [74.10804749, 15.63887024], [74.11263275, 15.64308071], [74.12275696, 15.64522076], [74.12602997, 15.65028954], [74.12896729, 15.65023994], [74.14277649, 15.64711094], [74.14685059, 15.64866066], [74.15497589, 15.64977074], [74.1632309, 15.64859009], [74.16593933, 15.65237999], [74.1734314, 15.65205193], [74.17543793, 15.67016029], [74.17867279, 15.6714201], [74.18302917, 15.67735004], [74.19013214, 15.68098068], [74.19769287, 15.67893028], [74.19811249, 15.67365074], [74.19447327, 15.67214012], [74.19632721, 15.66491127], [74.21154022, 15.66097927], [74.21196747, 15.65849972], [74.20986176, 15.65413094], [74.21324921, 15.64902973], [74.22409058, 15.65031147], [74.22879791, 15.65296078], [74.2284317, 15.65445042], [74.22405243, 15.6588707], [74.23158264, 15.66652012], [74.23683929, 15.66189098], [74.24191284, 15.66585922], [74.24504089, 15.66563129], [74.25525665, 15.65421009], [74.25647736, 15.64680099], [74.25723267, 15.63393974], [74.2545166, 15.62961197], [74.25253296, 15.6238203], [74.25435638, 15.62313175], [74.25942993, 15.62446117], [74.26249695, 15.62291145], [74.26747131, 15.61704922], [74.26854706, 15.60958862], [74.26545715, 15.60160065], [74.26515961, 15.59016037], [74.25637054, 15.58256054], [74.25741577, 15.57549953], [74.25441742, 15.57250118], [74.25431061, 15.56583023], [74.26457977, 15.56079102], [74.26763916, 15.56343937], [74.26988983, 15.56115055], [74.27258301, 15.55426121], [74.27894592, 15.54870033], [74.28292847, 15.54157066], [74.28559875, 15.5341711], [74.28727722, 15.52600002], [74.28279877, 15.52054119], [74.28375244, 15.51945019], [74.2818985, 15.51295185], [74.2681427, 15.50592136], [74.26082611, 15.50084114], [74.25724792, 15.49676132], [74.2563324, 15.48952007], [74.27255249, 15.46523952], [74.2798996, 15.45076084], [74.28251648, 15.44312096], [74.28295898, 15.43748093], [74.27999878, 15.43593121], [74.2826767, 15.43329144], [74.27561951, 15.4239006], [74.27735901, 15.41486931], [74.28144836, 15.4090414], [74.2845459, 15.40151119], [74.28263855, 15.38862038], [74.28624725, 15.38260078], [74.28996277, 15.38121986], [74.30568695, 15.38050175], [74.31282806, 15.37488174], [74.32836914, 15.3672514], [74.32859802, 15.36547089], [74.32364655, 15.36203194], [74.32261658, 15.35725021], [74.32595062, 15.34724045], [74.32840729, 15.3434], [74.32334137, 15.3295908], [74.32797241, 15.31326962], [74.34044647, 15.29680061], [74.34165192, 15.2929306], [74.33412933, 15.28286171], [74.31841278, 15.28192043], [74.30980682, 15.28323078], [74.30230713, 15.28586102], [74.30002594, 15.28230095], [74.29554749, 15.28310966], [74.28914642, 15.27907181], [74.28295898, 15.28129959], [74.27661896, 15.27444935], [74.27275085, 15.26777172], [74.27024078, 15.26093197], [74.26793671, 15.25839138], [74.25752258, 15.25762939], [74.25926208, 15.24999046], [74.26174927, 15.24372196], [74.26351929, 15.24188137], [74.27075195, 15.2385006], [74.27867126, 15.23719025], [74.29427338, 15.23198032], [74.30213165, 15.22814178], [74.3066864, 15.2232008], [74.30670929, 15.21899986], [74.31005859, 15.2134304], [74.31066132, 15.20895195], [74.31163025, 15.20705128], [74.31445313, 15.20561028], [74.31555939, 15.20321274], [74.31577301, 15.19631195], [74.31697083, 15.1910696], [74.32190704, 15.18406963], [74.31813049, 15.17533016], [74.31086731, 15.16203117], [74.30142975, 15.14988136], [74.29782867, 15.14630985], [74.29258728, 15.14767933], [74.28956604, 15.1431303], [74.29122925, 15.13538074], [74.289711, 15.1299696], [74.29144287, 15.12329865], [74.29309082, 15.11996269], [74.2906189, 15.11663055], [74.28824615, 15.10558128], [74.28572845, 15.10373116], [74.28106689, 15.10182953], [74.2783432, 15.09589958], [74.28379059, 15.09401035], [74.28721619, 15.06936073], [74.28900909, 15.0658493], [74.29525757, 15.06269264], [74.29499054, 15.05429173], [74.30120087, 15.04407024], [74.30233765, 15.03985977], [74.29310608, 15.03374958], [74.2890625, 15.0301218], [74.28936768, 15.02656174], [74.28978729, 15.02161121], [74.28186035, 15.01557159], [74.27641296, 15.00964069], [74.27184296, 15.00249195], [74.27291107, 15.00146103], [74.27102661, 14.99880791], [74.27126312, 14.9977417], [74.27159119, 14.9977417], [74.27065277, 14.99489117], [74.26644135, 14.99295139], [74.26171112, 14.9907608], [74.27095795, 14.98042965], [74.27391052, 14.97522163], [74.27095032, 14.97153187], [74.27011871, 14.96664143], [74.2665863, 14.96682072], [74.26434326, 14.96324921], [74.2620697, 14.95755196], [74.25659943, 14.95842171], [74.25100708, 14.9608202], [74.24639893, 14.95866108], [74.24386597, 14.95748997], [74.24167633, 14.94645023], [74.22471619, 14.94134045], [74.2192688, 14.93138027], [74.21183777, 14.9214201], [74.20308685, 14.92742062], [74.20405579, 14.9321003], [74.2041626, 14.93785095], [74.19741821, 14.94326973], [74.19248199, 14.94500923], [74.1902771, 14.95171928], [74.18656158, 14.95338058], [74.18036652, 14.95304966], [74.17215729, 14.95100975], [74.16989899, 14.94729996], [74.16966248, 14.94218063], [74.16609955, 14.93944168], [74.16596222, 14.9367609], [74.17383575, 14.91794014], [74.17516327, 14.91615105], [74.17735291, 14.91320038], [74.17539215, 14.90891933], [74.16982269, 14.90927029], [74.16339111, 14.91325188], [74.15389252, 14.91726971], [74.14922333, 14.91852093], [74.14570618, 14.91743183], [74.13939667, 14.9204607], [74.13622284, 14.91966057], [74.13342285, 14.91594791], [74.13204193, 14.91265011], [74.12652588, 14.91321087], [74.1227417, 14.91264057], [74.11733246, 14.9096117], [74.11308289, 14.91116047], [74.10417175, 14.90375042], [74.10331726, 14.90147972], [74.0973587, 14.89565945], [74.09708405, 14.89569569], [74.09708405, 14.89597225], [74.09680939, 14.89596939], [74.09680176, 14.89624977], [74.0965271, 14.89624977], [74.0965271, 14.89653015], [74.09625244, 14.89652824], [74.09625244, 14.89708424], [74.09597015, 14.89708233], [74.09597015, 14.89764023], [74.09541321, 14.89764023], [74.09541321, 14.89791965], [74.0945816, 14.89791584], [74.0945816, 14.89819431], [74.09402466, 14.89819431], [74.09402466, 14.89847183], [74.09375, 14.89847183], [74.09375, 14.89875031], [74.09263611, 14.89875031], [74.09263611, 14.89902973], [74.09181213, 14.89902973], [74.09181213, 14.89931107], [74.09041595, 14.89931107], [74.09041595, 14.89902973], [74.08981323, 14.89902782], [74.08957672, 14.89902973], [74.08957672, 14.89875031], [74.0890274, 14.89875031], [74.0890274, 14.89847183], [74.08875275, 14.89847183], [74.08875275, 14.89819431], [74.0881958, 14.89819431], [74.0881958, 14.89847183], [74.08763885, 14.89847183], [74.08763885, 14.89875031], [74.08680725, 14.89875031], [74.08680725, 14.89902973], [74.08625031, 14.89902973], [74.08625031, 14.89931107], [74.08569336, 14.8993063], [74.08569336, 14.89958191], [74.08513641, 14.89958191], [74.08513641, 14.89987087], [74.08486176, 14.89987087], [74.08486176, 14.90042019], [74.0845871, 14.90041637], [74.0845871, 14.90069389], [74.08430481, 14.90069389], [74.08430481, 14.90097237], [74.08403015, 14.90097046], [74.08403015, 14.90125179], [74.08347321, 14.90125179], [74.08347321, 14.90153027], [74.08319092, 14.90153027], [74.08319092, 14.90293026], [74.08291626, 14.90291595], [74.08291626, 14.90347195], [74.0826416, 14.90347195], [74.0826416, 14.90458202], [74.08291626, 14.90458202], [74.08291626, 14.90526104], [74.08291626, 14.90569401], [74.08319092, 14.90568066], [74.08319092, 14.90653133], [74.08291626, 14.90652943], [74.08291626, 14.9070816], [74.0826416, 14.9070797], [74.0826416, 14.90764141], [74.08235931, 14.9076376], [74.08235931, 14.90819454], [74.08207703, 14.90818977], [74.08207703, 14.90875053], [74.08152771, 14.90875053], [74.08152771, 14.90903091], [74.08125305, 14.90903091], [74.08125305, 14.90931129], [74.08069611, 14.90930462], [74.08069611, 14.90958309], [74.08041382, 14.90958309], [74.08041382, 14.90986061], [74.07875061, 14.90986061], [74.07875061, 14.91014099], [74.07707977, 14.91014099], [74.07707977, 14.90986061], [74.07624817, 14.90986061], [74.07624817, 14.90958309], [74.07541656, 14.90958309], [74.07541656, 14.90930462], [74.07459259, 14.90931129], [74.07459259, 14.90903091], [74.07430267, 14.90903091], [74.07430267, 14.90931129], [74.07402802, 14.90931129], [74.07402802, 14.90903091], [74.0737381, 14.90903091], [74.0737381, 14.90875053], [74.07290649, 14.90875053], [74.07290649, 14.90847015], [74.07236481, 14.90847301], [74.07236481, 14.90819454], [74.07152557, 14.90819454], [74.07152557, 14.90791702], [74.07125092, 14.90792084], [74.07125092, 14.90764141], [74.07096863, 14.90764141], [74.07096863, 14.90736008], [74.06986237, 14.90736008], [74.06986237, 14.90792084], [74.06958008, 14.90791702], [74.06958008, 14.90847301], [74.06903076, 14.90847015], [74.06903076, 14.90875053], [74.06793213, 14.90875053], [74.06793213, 14.90818977], [74.06735992, 14.90819454], [74.06735992, 14.90791702], [74.0670929, 14.90792084], [74.0670929, 14.90736008], [74.06680298, 14.90736008], [74.06680298, 14.9070797], [74.06652832, 14.9070797], [74.06652832, 14.90736008], [74.06597137, 14.90736008], [74.06597137, 14.90764141], [74.06513977, 14.9076376], [74.06513977, 14.90819454], [74.06485748, 14.90819454], [74.06485748, 14.90847301], [74.06458282, 14.90847015], [74.06458282, 14.90903091], [74.06430817, 14.90902901], [74.06430817, 14.90958309], [74.06375122, 14.90958309], [74.06375122, 14.90986061], [74.06346893, 14.90986061], [74.06346893, 14.91042137], [74.06291962, 14.9104166], [74.06291962, 14.91069508], [74.06236267, 14.91069508], [74.06236267, 14.9104166], [74.06153107, 14.91042137], [74.06153107, 14.90986061], [74.06124878, 14.90986061], [74.06124878, 14.90958309], [74.06104279, 14.90958309], [74.06069183, 14.90958309], [74.06069183, 14.90969181], [74.06069183, 14.90986061], [74.06014252, 14.90986061], [74.06014252, 14.91014099], [74.05958557, 14.91013908], [74.05958557, 14.91069508], [74.05986023, 14.91069508], [74.05986023, 14.9109726], [74.0595932, 14.91097069], [74.0595932, 14.91264057], [74.05930328, 14.91264057], [74.05930328, 14.91292191], [74.05902863, 14.91291714], [74.05902863, 14.91347313], [74.05819702, 14.91347122], [74.05819702, 14.91375065], [74.05735779, 14.91375065], [74.05735779, 14.91403103], [74.05708313, 14.91403103], [74.05708313, 14.91431046], [74.05680847, 14.91430473], [74.05680847, 14.91458321], [74.05652618, 14.91458321], [74.05652618, 14.91430473], [74.05625153, 14.91430473], [74.05625153, 14.91458321], [74.05486298, 14.91458321], [74.05486298, 14.91430473], [74.05264282, 14.91431046], [74.05264282, 14.91403103], [74.05236053, 14.91403103], [74.05236053, 14.91431046], [74.05180359, 14.91430473], [74.05180359, 14.91458321], [74.05041504, 14.91458321], [74.05041504, 14.91486073], [74.04956818, 14.91485023], [74.04956818, 14.9151392], [74.04914856, 14.9151392], [74.04875183, 14.9151392], [74.04875183, 14.91541862], [74.04708099, 14.91541672], [74.04708099, 14.91569519], [74.04680634, 14.91569519], [74.04680634, 14.9159708], [74.04650879, 14.91596889], [74.04650879, 14.91625118], [74.04624939, 14.91625118], [74.04624939, 14.91653156], [74.0459671, 14.91653156], [74.0459671, 14.91681194], [74.04541779, 14.91680527], [74.04541779, 14.91708279], [74.0451355, 14.91708279], [74.0451355, 14.91736126], [74.04458618, 14.91736126], [74.04458618, 14.91764164], [74.04402924, 14.91763878], [74.04402924, 14.91791725], [74.04374695, 14.91791725], [74.04374695, 14.91819477], [74.04319763, 14.91819477], [74.04319763, 14.91847134], [74.04292297, 14.91847134], [74.04292297, 14.91903019], [74.04319763, 14.91903019], [74.04319763, 14.91930962], [74.04291534, 14.91930485], [74.04291534, 14.91958332], [74.04264069, 14.91958141], [74.04264069, 14.92014027], [74.0423584, 14.92014027], [74.0423584, 14.92041969], [74.04207611, 14.92041969], [74.04207611, 14.92152977], [74.0423584, 14.92152977], [74.0423584, 14.92292023], [74.04264069, 14.92291641], [74.04264069, 14.9234724], [74.04292297, 14.92346859], [74.04292297, 14.92375183], [74.04319763, 14.92375183], [74.04319763, 14.92404079], [74.04347229, 14.92404079], [74.04347229, 14.92430973], [74.04402924, 14.92430592], [74.04402924, 14.92458439], [74.04429626, 14.92458153], [74.04429626, 14.92486191], [74.04458618, 14.92486191], [74.04458618, 14.92541981], [74.04486084, 14.9254179], [74.04486084, 14.92708397], [74.04458618, 14.92708397], [74.04458618, 14.92847157], [74.04429626, 14.92846966], [74.04429626, 14.92875004], [74.04402924, 14.92875004], [74.04402924, 14.9293108], [74.04374695, 14.92930603], [74.04374695, 14.92986012], [74.04347229, 14.92986012], [74.04347229, 14.93069363], [74.04514313, 14.93069172], [74.04514313, 14.93124962], [74.04541779, 14.93124962], [74.04541779, 14.93291569], [74.04569244, 14.93291569], [74.04569244, 14.93347168], [74.0459671, 14.93346977], [74.0459671, 14.93375111], [74.04624939, 14.93375111], [74.04624939, 14.93431091], [74.04650879, 14.93431091], [74.04650879, 14.93514061], [74.04624939, 14.93514061], [74.04624939, 14.93681145], [74.04597473, 14.93680668], [74.04597473, 14.93819523], [74.04569244, 14.93819046], [74.04569244, 14.93904018], [74.04541779, 14.93902683], [74.04541779, 14.93958282], [74.0451355, 14.93958282], [74.0451355, 14.9398613], [74.04486084, 14.9398613], [74.04486084, 14.94014072], [74.04458618, 14.94014072], [74.04458618, 14.9404192], [74.04430389, 14.94041729], [74.04430389, 14.94069481], [74.04402924, 14.94069481], [74.04402924, 14.94097328], [74.04374695, 14.94097328], [74.04376221, 14.94124889], [74.04347229, 14.94124889], [74.04347229, 14.94152927], [74.04319763, 14.94152927], [74.04319763, 14.94180965], [74.04292297, 14.94180965], [74.04292297, 14.94292164], [74.04319763, 14.94291687], [74.04319763, 14.94347095], [74.04347229, 14.94347095], [74.04347229, 14.94403172], [74.04376221, 14.94403172], [74.04376221, 14.94431019], [74.04430389, 14.94430542], [74.04430389, 14.94486141], [74.04458618, 14.94484997], [74.04458618, 14.94514179], [74.04486084, 14.94514179], [74.04486084, 14.94542027], [74.0451355, 14.9454174], [74.0451355, 14.94597435], [74.04486084, 14.94597054], [74.04486084, 14.94653034], [74.04458618, 14.94653034], [74.04458618, 14.94680977], [74.04430389, 14.946805], [74.04430389, 14.94708347], [74.04319763, 14.94708061], [74.04319763, 14.94736195], [74.04291534, 14.94736195], [74.04291534, 14.9481926], [74.04319763, 14.9481926], [74.04319763, 14.94791794], [74.04374695, 14.94791794], [74.04374695, 14.94847107], [74.04347229, 14.94847107], [74.04347229, 14.94874954], [74.04319763, 14.94874954], [74.04319763, 14.9493103], [74.04347229, 14.94930553], [74.04347229, 14.94958401], [74.04402924, 14.94958401], [74.04402924, 14.94986153], [74.04624939, 14.94985867], [74.04624939, 14.95014191], [74.04708099, 14.95014191], [74.04708099, 14.95042038], [74.04763794, 14.95041561], [74.04763794, 14.95069408], [74.04736328, 14.95069122], [74.04736328, 14.95098114], [74.04679871, 14.95098114], [74.04679871, 14.95125198], [74.04650879, 14.95125198], [74.04650879, 14.95153046], [74.04624939, 14.95153046], [74.04624939, 14.95181274], [74.04652405, 14.95180607], [74.04652405, 14.95236206], [74.04679871, 14.95236015], [74.04679871, 14.95291996], [74.04708099, 14.95291805], [74.04708099, 14.95402813], [74.04736328, 14.95402813], [74.04736328, 14.95458412], [74.04763794, 14.95458031], [74.04763794, 14.95514011], [74.04792023, 14.95514011], [74.04792023, 14.9556942], [74.04818726, 14.95569038], [74.04818726, 14.95625019], [74.04846954, 14.95625019], [74.04846954, 14.9570837], [74.04930878, 14.9570837], [74.04930878, 14.95736027], [74.05124664, 14.95736027], [74.05124664, 14.9570837], [74.05180359, 14.9570837], [74.05180359, 14.95736027], [74.05347443, 14.95736027], [74.05347443, 14.95819378], [74.05319214, 14.95819378], [74.05319214, 14.95847225], [74.05291748, 14.95847034], [74.05291748, 14.95874977], [74.05236053, 14.95874977], [74.05236053, 14.95903111], [74.05179596, 14.95903111], [74.05179596, 14.95931053], [74.05069733, 14.95931053], [74.05069733, 14.95903111], [74.05042267, 14.95903111], [74.05042267, 14.95874977], [74.04985809, 14.95874977], [74.04985809, 14.95847034], [74.04958344, 14.95847225], [74.04958344, 14.95819378], [74.04875183, 14.95819187], [74.04875183, 14.95903111], [74.04902649, 14.95903111], [74.04902649, 14.96014977], [74.04875183, 14.96013832], [74.04875183, 14.96069431], [74.04846954, 14.96068954], [74.04846954, 14.96153069], [74.04819489, 14.96152878], [74.04819489, 14.96208191], [74.04792023, 14.96208], [74.04792023, 14.96292114], [74.04763794, 14.96291733], [74.04763794, 14.96347332], [74.04736328, 14.96347046], [74.04736328, 14.96431065], [74.04708099, 14.96431065], [74.04708099, 14.9651413], [74.04680634, 14.96513939], [74.04680634, 14.96569538], [74.04650879, 14.96568966], [74.04650879, 14.96652889]]], [[[73.86235809, 15.40792179], [73.86235809, 15.40848064], [73.86429596, 15.40848064], [73.86429596, 15.40819073], [73.86541748, 15.40819359], [73.86541748, 15.40736198], [73.86569214, 15.40736198], [73.86569214, 15.40653038], [73.86541748, 15.40653038], [73.86541748, 15.40431023], [73.86514282, 15.40431023], [73.86514282, 15.40403175], [73.86541748, 15.40403175], [73.86541748, 15.40374947], [73.86513519, 15.40374947], [73.86513519, 15.40347099], [73.86319733, 15.40347099], [73.86319733, 15.40319633], [73.86264038, 15.40319633], [73.86264038, 15.40347099], [73.86235809, 15.40347099], [73.86235809, 15.40374947], [73.86207581, 15.40374947], [73.86207581, 15.40431023], [73.86180878, 15.40430546], [73.86180878, 15.40458393], [73.86152649, 15.40458107], [73.86152649, 15.40514183], [73.86125183, 15.40513992], [73.86125183, 15.40597057], [73.86152649, 15.40597057], [73.86152649, 15.40708447], [73.86180878, 15.40708065], [73.86180878, 15.40792179], [73.86235809, 15.40792179]]]]}}, {\\\"id\\\": \\\"9\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.11_1\\\", \\\"HASC_1\\\": \\\"IN.GJ\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Gujarat\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Goudjerate|Gujerat|Gujerate\\\", \\\"apm25_popweighted\\\": -6.2, \\\"dalys_apm25_rate_6cod_mean_total\\\": 668.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1021.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -353.0, \\\"geo-id\\\": 9, \\\"hpm25_child_popweighted\\\": -131.5, \\\"hpm25_female_popweighted\\\": -151.1, \\\"hpm25_male_popweighted\\\": -108.8, \\\"location\\\": \\\"Gujarat\\\", \\\"mort_apm25_6cod_mean_total\\\": 12674.0, \\\"mort_hpm25_6cod_mean_total\\\": -20217.0, \\\"mort_tpm25_6cod_mean_total\\\": -7544.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[72.84597015, 20.76320076], [72.84597015, 20.76292992], [72.84625244, 20.76292992], [72.84625244, 20.76264], [72.8465271, 20.76264], [72.8465271, 20.76235962], [72.84707642, 20.76235962], [72.84707642, 20.76264], [72.84728241, 20.76264], [72.84902954, 20.76264], [72.84902954, 20.76235962], [72.84958649, 20.76236153], [72.84958649, 20.76208305], [72.85041809, 20.76208305], [72.85041809, 20.76180649], [72.8520813, 20.7618103], [72.8520813, 20.76152992], [72.8529129, 20.76152992], [72.8529129, 20.76124954], [72.85346985, 20.76124954], [72.85346985, 20.76097107], [72.85375214, 20.76097488], [72.85375214, 20.7606945], [72.85402679, 20.7606945], [72.85402679, 20.76041603], [72.85430908, 20.76041985], [72.85430908, 20.76013947], [72.85457611, 20.76013947], [72.85457611, 20.7598629], [72.85486603, 20.7598629], [72.8548584, 20.75958061], [72.85541534, 20.75958061], [72.85541534, 20.75902748], [72.85569763, 20.75902939], [72.85569763, 20.75847054], [72.85597229, 20.75847054], [72.85597229, 20.7579174], [72.85624695, 20.75792122], [72.85624695, 20.75736237], [72.85652924, 20.75736237], [72.85652924, 20.75708008], [72.85680389, 20.75708389], [72.85680389, 20.75669098], [72.85680389, 20.75597191], [72.85708618, 20.75597191], [72.85708618, 20.75541687], [72.85736084, 20.75542068], [72.85736084, 20.75402832], [72.85764313, 20.75402832], [72.85764313, 20.75263977], [72.85736084, 20.75263977], [72.85736084, 20.75235939], [72.85652924, 20.7523613], [72.85652924, 20.75208282], [72.8548584, 20.75208282], [72.8548584, 20.7523613], [72.85430908, 20.75235939], [72.85430908, 20.75263977], [72.85098267, 20.75263977], [72.85098267, 20.75291824], [72.8493042, 20.75291634], [72.8493042, 20.75319481], [72.8484726, 20.75319481], [72.8484726, 20.75347137], [72.84764099, 20.75346947], [72.84764099, 20.75375938], [72.84707642, 20.75375938], [72.84707642, 20.75402832], [72.84680176, 20.75402832], [72.84680176, 20.75430489], [72.8465271, 20.75430489], [72.8465271, 20.75458336], [72.84625244, 20.75458336], [72.84625244, 20.75486183], [72.84597015, 20.75485992], [72.84597015, 20.75542068], [72.8456955, 20.75541687], [72.8456955, 20.75597191], [72.84541321, 20.75596809], [72.84541321, 20.75624847], [72.84513855, 20.75624847], [72.84513855, 20.75680542], [72.84486389, 20.75680542], [72.84486389, 20.75708389], [72.8445816, 20.75708008], [72.8445816, 20.75764275], [72.84430695, 20.75764275], [72.84430695, 20.75875282], [72.84401703, 20.75875282], [72.84401703, 20.76152992], [72.84430695, 20.76152992], [72.84430695, 20.76292992], [72.8445816, 20.76292992], [72.8445816, 20.76320076], [72.84597015, 20.76320076]]], [[[71.51625061, 20.91430473], [71.51625061, 20.91402817], [71.5165329, 20.91402817], [71.5165329, 20.91374969], [71.5173645, 20.91374969], [71.51735687, 20.91320038], [71.51763916, 20.91320038], [71.51763916, 20.91291809], [71.51790619, 20.91291809], [71.51790619, 20.91208076], [71.51819611, 20.91208267], [71.51819611, 20.91069412], [71.51791382, 20.91069412], [71.51791382, 20.91013908], [71.51819611, 20.91014099], [71.51819611, 20.90958023], [71.51847076, 20.90958595], [71.51847076, 20.9090271], [71.51875305, 20.90903091], [71.51875305, 20.90875053], [71.51902771, 20.90875053], [71.51902771, 20.90764046], [71.51957703, 20.90764046], [71.51957703, 20.90681076], [71.5201416, 20.90681076], [71.5201416, 20.90625191], [71.52179718, 20.90625191], [71.52179718, 20.90596962], [71.52458191, 20.90597343], [71.52458191, 20.90625191], [71.52513885, 20.90625191], [71.52513885, 20.90653038], [71.52540588, 20.90653038], [71.52540588, 20.90681076], [71.52680206, 20.90681076], [71.52680206, 20.90625191], [71.52707672, 20.90625191], [71.52707672, 20.90596962], [71.52841949, 20.90597343], [71.52874756, 20.90597343], [71.52874756, 20.90569496], [71.52902985, 20.90570068], [71.52902985, 20.9054203], [71.52986145, 20.9054203], [71.52986145, 20.90514183], [71.53013611, 20.90514183], [71.53013611, 20.90485954], [71.5304184, 20.90485954], [71.5304184, 20.9034729], [71.53013611, 20.9034729], [71.53013611, 20.90319443], [71.5293045, 20.90319443], [71.5293045, 20.90291595], [71.5284729, 20.90291595], [71.5284729, 20.90319443], [71.52780914, 20.90319443], [71.5276413, 20.90319443], [71.5276413, 20.9034729], [71.52625275, 20.9034729], [71.52625275, 20.90319443], [71.52430725, 20.90319443], [71.52430725, 20.9034729], [71.52375031, 20.90346909], [71.52375031, 20.90374947], [71.52263641, 20.90374947], [71.52263641, 20.90346909], [71.52180481, 20.9034729], [71.52180481, 20.90319443], [71.51985931, 20.90319443], [71.51985931, 20.9034729], [71.51930237, 20.90346909], [71.51930237, 20.90374947], [71.51846313, 20.90374947], [71.51846313, 20.90403175], [71.51790619, 20.90403175], [71.51790619, 20.90431976], [71.51763916, 20.90430641], [71.51763916, 20.90458107], [71.51569366, 20.90458107], [71.51569366, 20.90402794], [71.51457977, 20.90403175], [71.51457977, 20.90374947], [71.51374817, 20.90374947], [71.51374817, 20.90346909], [71.51208496, 20.9034729], [71.51208496, 20.90319443], [71.51152802, 20.90319443], [71.51152802, 20.90291595], [71.51040649, 20.90292168], [71.51040649, 20.90263939], [71.51013947, 20.90263939], [71.51013947, 20.90236092], [71.50958252, 20.90236092], [71.50958252, 20.90292168], [71.50902557, 20.90291595], [71.50902557, 20.90319443], [71.50736237, 20.90319443], [71.50736237, 20.90291595], [71.50708008, 20.90291595], [71.50708008, 20.90319443], [71.50680542, 20.90319443], [71.50681305, 20.90374947], [71.50652313, 20.90374947], [71.50652313, 20.90431976], [71.50736237, 20.90430641], [71.50736237, 20.90458107], [71.50763702, 20.90457916], [71.50763702, 20.90514183], [71.50791931, 20.90514183], [71.50791931, 20.90570068], [71.50818634, 20.90570068], [71.50818634, 20.90625191], [71.50846863, 20.90625191], [71.50846863, 20.90681076], [71.50902557, 20.90680313], [71.50902557, 20.9070816], [71.50986481, 20.9070816], [71.50986481, 20.90736389], [71.51041412, 20.90736389], [71.51041412, 20.9081955], [71.51069641, 20.9081955], [71.51069641, 20.90847206], [71.51125336, 20.90847015], [71.51125336, 20.90875053], [71.51180267, 20.90875053], [71.51180267, 20.90903091], [71.51235962, 20.90903091], [71.51235962, 20.90930939], [71.51291656, 20.90930557], [71.51291656, 20.91069412], [71.51264191, 20.91069412], [71.51264954, 20.91110039], [71.51264954, 20.91125107], [71.51235962, 20.91124916], [71.51235962, 20.91208267], [71.51264191, 20.91208267], [71.51264191, 20.91236115], [71.51291656, 20.91236115], [71.51291656, 20.91263962], [71.51403046, 20.91263962], [71.51403046, 20.91291809], [71.51457977, 20.91291809], [71.51457977, 20.91320038], [71.51513672, 20.91320038], [71.51513672, 20.91374969], [71.51541901, 20.91374969], [71.51541901, 20.91402817], [71.51597595, 20.91402817], [71.51597595, 20.91430473], [71.51625061, 20.91430473]]], [[[71.38847351, 20.8670845], [71.38847351, 20.86652756], [71.38819122, 20.86652946], [71.38819122, 20.8662529], [71.38791656, 20.8662529], [71.38791656, 20.86569023], [71.38764191, 20.86569214], [71.38764191, 20.86514091], [71.38735962, 20.86515045], [71.38735962, 20.8647995], [71.38735962, 20.8643055], [71.38764191, 20.86431122], [71.38764191, 20.86346817], [71.38680267, 20.86346817], [71.38680267, 20.86375237], [71.38652802, 20.86375237], [71.38652802, 20.86403275], [71.38625336, 20.86403275], [71.38625336, 20.86431122], [71.38597107, 20.86431122], [71.38597107, 20.86541939], [71.38611603, 20.86541748], [71.38625336, 20.86541748], [71.38625336, 20.86569214], [71.38652802, 20.86569214], [71.38652802, 20.86597061], [71.38680267, 20.86597061], [71.38680267, 20.8662529], [71.38707733, 20.8662529], [71.38707733, 20.86680984], [71.38735962, 20.86680603], [71.38735962, 20.8670845], [71.38847351, 20.8670845]]], [[[71.64901733, 20.97792053], [71.64901733, 20.97735977], [71.64930725, 20.97736168], [71.64930725, 20.97652817], [71.64901733, 20.97653961], [71.64901733, 20.97624969], [71.64875031, 20.97624969], [71.64875031, 20.97597122], [71.64847565, 20.97597313], [71.64847565, 20.97458458], [71.64763641, 20.97458076], [71.64763641, 20.97486115], [71.64736176, 20.97486115], [71.64736176, 20.97513962], [71.64653015, 20.97513962], [71.64653015, 20.97486115], [71.64597321, 20.97486115], [71.64597321, 20.97458076], [71.64430237, 20.97458076], [71.64430237, 20.97513962], [71.64402771, 20.97513962], [71.64402771, 20.97569466], [71.64430237, 20.97569084], [71.64430237, 20.97624969], [71.64457703, 20.97624969], [71.64457703, 20.97653961], [71.64485931, 20.97652817], [71.64485931, 20.97680664], [71.6451416, 20.97680664], [71.6451416, 20.97708321], [71.64597321, 20.97708321], [71.64597321, 20.97736168], [71.6470871, 20.97735977], [71.6470871, 20.97764015], [71.6479187, 20.97764015], [71.6479187, 20.97792053], [71.64901733, 20.97792053]]], [[[71.68653107, 20.99652863], [71.68653107, 20.99624825], [71.68681335, 20.99624825], [71.68680573, 20.99597168], [71.68708038, 20.99597168], [71.68708038, 20.99569511], [71.68736267, 20.99570084], [71.68736267, 20.99542046], [71.68763733, 20.99542046], [71.68763733, 20.99513817], [71.68791962, 20.99513817], [71.68791962, 20.99458122], [71.68763733, 20.99458313], [71.68763733, 20.99347305], [71.68736267, 20.99347305], [71.68736267, 20.99331093], [71.68736267, 20.99152756], [71.68569183, 20.99151993], [71.68569183, 20.99180984], [71.68541718, 20.99180794], [71.68541718, 20.9920826], [71.68486023, 20.9920826], [71.68486023, 20.99180794], [71.68125153, 20.99180984], [71.68125153, 20.99151993], [71.68096924, 20.99152756], [71.68096924, 20.99124908], [71.68068695, 20.99125099], [71.68068695, 20.99097061], [71.68041992, 20.99097252], [71.68041992, 20.99069595], [71.68013763, 20.99069595], [71.68013763, 20.99041748], [71.67986298, 20.99041939], [71.67986298, 20.99014091], [71.67958069, 20.99014091], [71.67958069, 20.98986053], [71.67930603, 20.98986053], [71.67930603, 20.98958015], [71.67874908, 20.98958588], [71.67874908, 20.9893055], [71.67819214, 20.98931122], [71.67819214, 20.98903084], [71.67764282, 20.98903084], [71.67764282, 20.98875046], [71.67791748, 20.98875046], [71.67791748, 20.98847961], [71.67819214, 20.98847961], [71.67819214, 20.98792076], [71.67791748, 20.98792076], [71.67791748, 20.98764038], [71.67764282, 20.98764038], [71.67764282, 20.98736], [71.67736053, 20.98736382], [71.67736053, 20.98680305], [71.67708588, 20.98681068], [71.67708588, 20.9865303], [71.67679596, 20.9865303], [71.67679596, 20.98625183], [71.67652893, 20.98625183], [71.67652893, 20.98596954], [71.67624664, 20.98597145], [71.67624664, 20.98569489], [71.67597198, 20.98569489], [71.67597198, 20.98513794], [71.67569733, 20.98514175], [71.67569733, 20.98485947], [71.67430878, 20.98485947], [71.67430878, 20.98514175], [71.67375183, 20.98514175], [71.67375183, 20.98542023], [71.67402649, 20.98541641], [71.67402649, 20.98597145], [71.67430878, 20.98596954], [71.67430878, 20.9865303], [71.67402649, 20.9865284], [71.67402649, 20.98708153], [71.67375183, 20.98707962], [71.67375183, 20.98764038], [71.67402649, 20.98764038], [71.67402649, 20.98875046], [71.67430878, 20.98875046], [71.67430878, 20.98958588], [71.67457581, 20.98958015], [71.67457581, 20.99014091], [71.67402649, 20.99014091], [71.67402649, 20.99041939], [71.67375183, 20.99041748], [71.67375183, 20.99069595], [71.67333984, 20.99069595], [71.67319489, 20.99069595], [71.67319489, 20.99097252], [71.67292023, 20.99097061], [71.67292023, 20.99125099], [71.67318726, 20.99125099], [71.67318726, 20.99180984], [71.67346954, 20.99180794], [71.67346954, 20.9920826], [71.67375183, 20.99208069], [71.67375183, 20.99263954], [71.67402649, 20.99263954], [71.67402649, 20.99291992], [71.67458344, 20.99291611], [71.67458344, 20.99319458], [71.67514038, 20.99319458], [71.67514038, 20.99347305], [71.67541504, 20.99347305], [71.67541504, 20.99374962], [71.67597198, 20.99374962], [71.67597198, 20.99430466], [71.67652893, 20.99430466], [71.67652893, 20.99458313], [71.67736053, 20.99458313], [71.67736053, 20.9948616], [71.67791748, 20.9948597], [71.67791748, 20.99513817], [71.67874908, 20.99513817], [71.67874908, 20.99542046], [71.67986298, 20.99542046], [71.67986298, 20.99570084], [71.68069458, 20.99569511], [71.68069458, 20.99597168], [71.68180847, 20.99596977], [71.68180847, 20.99624825], [71.68264008, 20.99624825], [71.68264008, 20.99652863], [71.68653107, 20.99652863]]], [[[71.70375061, 20.99958229], [71.70375061, 20.99930573], [71.7040329, 20.99930954], [71.7040329, 20.99903107], [71.70458221, 20.99903107], [71.70458221, 20.99875259], [71.70513153, 20.99875259], [71.70513153, 20.99765015], [71.70485687, 20.99765015], [71.70485687, 20.99707985], [71.70458221, 20.99708366], [71.70458221, 20.99652863], [71.70430756, 20.99652863], [71.70430756, 20.99624825], [71.70402527, 20.99624825], [71.70402527, 20.99569511], [71.70375061, 20.99570084], [71.70375061, 20.99513817], [71.70291901, 20.99513817], [71.70291901, 20.99570084], [71.70263672, 20.99569511], [71.70263672, 20.99597168], [71.70236206, 20.99596977], [71.70236206, 20.99652863], [71.70181274, 20.99652863], [71.70181274, 20.99624825], [71.69847107, 20.99624825], [71.69847107, 20.99652863], [71.69568634, 20.99652863], [71.69568634, 20.99681091], [71.69541931, 20.99681091], [71.69541931, 20.99736023], [71.69568634, 20.99736023], [71.69568634, 20.99765015], [71.69625092, 20.99765015], [71.69625092, 20.9979229], [71.69652557, 20.99791718], [71.69652557, 20.99819374], [71.69708252, 20.99819374], [71.69708252, 20.99847031], [71.69735718, 20.99847031], [71.69735718, 20.99875259], [71.69790649, 20.99875259], [71.69790649, 20.99903107], [71.69819641, 20.99903107], [71.69819641, 20.99930954], [71.69985962, 20.99930573], [71.69985962, 20.99958229], [71.70375061, 20.99958229]]], [[[71.7104187, 20.99958229], [71.7104187, 20.99930573], [71.71153259, 20.99930954], [71.71153259, 20.99903107], [71.71263885, 20.99903107], [71.71263885, 20.99875259], [71.7140274, 20.99875259], [71.7140274, 20.99765015], [71.71347046, 20.99765015], [71.71347046, 20.99736023], [71.71290588, 20.99736023], [71.71290588, 20.99707985], [71.71125031, 20.99708366], [71.71125031, 20.99680519], [71.7104187, 20.99681091], [71.7104187, 20.99652863], [71.70819092, 20.99652863], [71.70819092, 20.99681091], [71.70735931, 20.99680519], [71.70735931, 20.99708366], [71.70625305, 20.99707985], [71.70625305, 20.99736023], [71.70597076, 20.99736023], [71.70597076, 20.99847031], [71.70652771, 20.99847031], [71.70652771, 20.99875259], [71.70735931, 20.99875259], [71.70735931, 20.99903107], [71.70791626, 20.99903107], [71.70791626, 20.99930954], [71.70847321, 20.99930573], [71.70847321, 20.99958229], [71.7104187, 20.99958229]]], [[[72.64763641, 21.07624817], [72.64763641, 21.07541847], [72.6479187, 21.07541847], [72.6479187, 21.07513809], [72.64819336, 21.07513809], [72.64819336, 21.07485962], [72.64875031, 21.07486153], [72.64875031, 21.07458305], [72.64902496, 21.07458305], [72.64902496, 21.07430649], [72.64985657, 21.0743103], [72.64985657, 21.07402992], [72.65040588, 21.07402992], [72.65040588, 21.0743103], [72.6506958, 21.0743103], [72.6506958, 21.07402992], [72.65097046, 21.07402992], [72.65097046, 21.07374954], [72.65235901, 21.07374954], [72.65235901, 21.07458305], [72.6526413, 21.07458305], [72.6526413, 21.07430649], [72.65402985, 21.0743103], [72.65402985, 21.07402992], [72.65429688, 21.07402992], [72.65429688, 21.07374954], [72.65458679, 21.07374954], [72.65458679, 21.07319069], [72.65486145, 21.0731945], [72.65486145, 21.07263947], [72.65513611, 21.07263947], [72.65513611, 21.07208061], [72.6554184, 21.07208252], [72.6554184, 21.07152748], [72.65569305, 21.07152939], [72.65569305, 21.07125092], [72.65598297, 21.07125092], [72.65597534, 21.07097244], [72.65625, 21.07097244], [72.65625, 21.07069588], [72.65652466, 21.07069588], [72.65652466, 21.06902695], [72.65625763, 21.06903076], [72.65625763, 21.06847], [72.6570816, 21.06847382], [72.6570816, 21.06791687], [72.65735626, 21.06792068], [72.65735626, 21.06707954], [72.65763855, 21.06708145], [72.65763855, 21.06680489], [72.65791321, 21.06680489], [72.65791321, 21.06569481], [72.65763855, 21.06569481], [72.65763855, 21.06541634], [72.65735626, 21.06542015], [72.65735626, 21.06514168], [72.65598297, 21.06514168], [72.65598297, 21.06542015], [72.65569305, 21.06541634], [72.65569305, 21.06569481], [72.65597534, 21.06569481], [72.65597534, 21.06624985], [72.65625, 21.06624985], [72.65625, 21.06708145], [72.65597534, 21.06708145], [72.65597534, 21.06680489], [72.65513611, 21.06680489], [72.65513611, 21.06652832], [72.65374756, 21.06653023], [72.65374756, 21.06624985], [72.65291595, 21.06624985], [72.65291595, 21.06542015], [72.65208435, 21.06541634], [72.65208435, 21.06569481], [72.6515274, 21.06569481], [72.6515274, 21.06597137], [72.65097046, 21.06597137], [72.65097046, 21.06708145], [72.65013885, 21.06708145], [72.65013885, 21.06680489], [72.64930725, 21.06680489], [72.64930725, 21.06736374], [72.64875031, 21.06735992], [72.64875031, 21.0676403], [72.64819336, 21.0676403], [72.64819336, 21.06792068], [72.6479187, 21.06792068], [72.6479187, 21.06820107], [72.64819336, 21.06819534], [72.64819336, 21.06847382], [72.64847565, 21.06847382], [72.64848328, 21.06875038], [72.64819336, 21.06875038], [72.64819336, 21.06903076], [72.6479187, 21.06902695], [72.6479187, 21.0695858], [72.64763641, 21.06957054], [72.64763641, 21.06986046], [72.6470871, 21.06986046], [72.6470871, 21.07042122], [72.64680481, 21.0704174], [72.64680481, 21.07069588], [72.64653015, 21.07069588], [72.64653015, 21.07097244], [72.64624786, 21.07097054], [72.64624786, 21.07125092], [72.64597321, 21.07125092], [72.64597321, 21.07152939], [72.64541626, 21.07152748], [72.64541626, 21.07208252], [72.64569092, 21.07208061], [72.64569092, 21.07236099], [72.64597321, 21.07236099], [72.64597321, 21.07263947], [72.64624786, 21.07263947], [72.64624786, 21.07374954], [72.64597321, 21.07374954], [72.64597321, 21.07402992], [72.64569092, 21.07402611], [72.64569092, 21.07430077], [72.64541626, 21.0743103], [72.64541626, 21.07513809], [72.64569092, 21.07513809], [72.64569092, 21.07570076], [72.64597321, 21.07570076], [72.64597321, 21.07624817], [72.64763641, 21.07624817]]], [[[72.67930603, 21.09875107], [72.67930603, 21.09819031], [72.67958069, 21.09819412], [72.67958069, 21.09795952], [72.67958069, 21.09763908], [72.68013763, 21.09764099], [72.68013763, 21.09708023], [72.68041992, 21.09708595], [72.68041992, 21.0965271], [72.68068695, 21.09653091], [72.68068695, 21.09542084], [72.68013763, 21.09541702], [72.68013763, 21.0956955], [72.67986298, 21.09568977], [72.67986298, 21.09625053], [72.67958069, 21.09625053], [72.67958069, 21.09653091], [72.67903137, 21.09653091], [72.67903137, 21.09680939], [72.67874908, 21.09680557], [72.67874908, 21.09806061], [72.67874908, 21.09819412], [72.6784668, 21.09819031], [72.6784668, 21.09875107], [72.67930603, 21.09875107]]], [[[72.67208099, 21.11514091], [72.67208099, 21.11431122], [72.67236328, 21.11431122], [72.67236328, 21.11347008], [72.67263794, 21.11347198], [72.67263794, 21.11291885], [72.67236328, 21.11292076], [72.67236328, 21.10764122], [72.67263794, 21.10764122], [72.67263794, 21.10597038], [72.67292023, 21.10597038], [72.67292023, 21.10430527], [72.67318726, 21.1043129], [72.67318726, 21.10346985], [72.67346954, 21.10347176], [72.67346954, 21.10263824], [72.67375183, 21.10263824], [72.67375183, 21.10207939], [72.67402649, 21.10208321], [72.67402649, 21.10180473], [72.67430878, 21.10180473], [72.67430878, 21.10124969], [72.67457581, 21.10124969], [72.67457581, 21.10097122], [72.67485809, 21.10097313], [72.67485809, 21.10069466], [72.67541504, 21.10069466], [72.67541504, 21.10041618], [72.67569733, 21.10041809], [72.67569733, 21.09987068], [72.67624664, 21.09987068], [72.67624664, 21.09902954], [72.67652893, 21.09902954], [72.67652893, 21.09830284], [72.67652893, 21.09791756], [72.67624664, 21.09791946], [72.67624664, 21.09708023], [72.67430115, 21.09708023], [72.67430115, 21.09764099], [72.67402649, 21.09764099], [72.67402649, 21.09875107], [72.67375183, 21.09875107], [72.67375183, 21.09902954], [72.67318726, 21.09902954], [72.67318726, 21.09930992], [72.67292023, 21.09930611], [72.67292023, 21.09958267], [72.67236328, 21.09958076], [72.67236328, 21.09987068], [72.67208099, 21.09987068], [72.67208099, 21.10013962], [72.67151642, 21.10013962], [72.67151642, 21.10041809], [72.67124939, 21.10041618], [72.67124939, 21.10097313], [72.6709671, 21.10097122], [72.6709671, 21.10124969], [72.67069244, 21.10124969], [72.67069244, 21.10180473], [72.67041779, 21.10180092], [72.67041779, 21.10320091], [72.6701355, 21.10319519], [72.6701355, 21.10347176], [72.66986084, 21.10347176], [72.66986084, 21.10458374], [72.66958618, 21.10458183], [72.66958618, 21.10486031], [72.66929626, 21.10486031], [72.66929626, 21.10542107], [72.66958618, 21.10542107], [72.66958618, 21.10791969], [72.66929626, 21.10791969], [72.66929626, 21.10931015], [72.66958618, 21.10930634], [72.66958618, 21.11097145], [72.66929626, 21.11096954], [72.66929626, 21.11124992], [72.66958618, 21.11124992], [72.66958618, 21.11208344], [72.66986084, 21.11208344], [72.66986084, 21.11347198], [72.67014313, 21.11347008], [72.67014313, 21.11403084], [72.67041779, 21.11402893], [72.67041779, 21.11486053], [72.67124176, 21.114851], [72.67124176, 21.11514091], [72.67208099, 21.11514091]]], [[[72.70207977, 21.12236023], [72.70207977, 21.12070084], [72.70236206, 21.12070084], [72.70236206, 21.11790848], [72.70263672, 21.11791611], [72.70263672, 21.11680603], [72.70291901, 21.11681175], [72.70291901, 21.11624908], [72.70318604, 21.11624908], [72.70318604, 21.11458015], [72.70291901, 21.11458397], [72.70291901, 21.11402893], [72.70263672, 21.11403084], [72.70263672, 21.11347008], [72.70236206, 21.11347198], [72.70236206, 21.11319351], [72.70207977, 21.11319351], [72.70207977, 21.11291885], [72.70181274, 21.11292076], [72.70181274, 21.11264038], [72.70069122, 21.11264038], [72.70069122, 21.11236], [72.69957733, 21.11236], [72.69957733, 21.11264038], [72.69930267, 21.11263847], [72.69930267, 21.11319351], [72.69902802, 21.11319351], [72.69902802, 21.11347198], [72.69875336, 21.11347008], [72.69875336, 21.11375046], [72.69847107, 21.11375046], [72.69847107, 21.11514091], [72.69819641, 21.1151371], [72.69819641, 21.11569405], [72.69790649, 21.11569023], [72.69790649, 21.11653137], [72.69763947, 21.11653137], [72.69763947, 21.11681175], [72.69819641, 21.11681175], [72.69819641, 21.11903191], [72.69847107, 21.11902809], [72.69847107, 21.11930466], [72.69875336, 21.11930466], [72.69875336, 21.11958122], [72.69902802, 21.11958122], [72.69902802, 21.11986351], [72.69930267, 21.1198597], [72.69930267, 21.12014008], [72.69957733, 21.12014008], [72.69957733, 21.12042046], [72.70014191, 21.12041664], [72.70014191, 21.12097359], [72.70041656, 21.12096977], [72.70041656, 21.12125015], [72.70096588, 21.12125015], [72.70096588, 21.12153053], [72.70124817, 21.12153053], [72.70124817, 21.12181091], [72.70153046, 21.12180328], [72.70153046, 21.12208557], [72.70180511, 21.12208557], [72.70180511, 21.12236023], [72.70207977, 21.12236023]]], [[[72.67652893, 21.15570068], [72.67652893, 21.1554184], [72.67764282, 21.1554184], [72.67764282, 21.15513992], [72.67874908, 21.15513992], [72.67874908, 21.15485954], [72.67930603, 21.15486145], [72.67930603, 21.15458298], [72.68013763, 21.15458298], [72.68013763, 21.15430641], [72.68042755, 21.15430832], [72.68042755, 21.15402031], [72.68069458, 21.15402794], [72.68069458, 21.15374947], [72.68096924, 21.15374947], [72.68096924, 21.15347099], [72.68180847, 21.1534729], [72.68180847, 21.15319443], [72.68208313, 21.15319443], [72.68208313, 21.15291786], [72.68264008, 21.15291977], [72.68264008, 21.15263939], [72.6829071, 21.15263939], [72.6829071, 21.15236092], [72.68486023, 21.15236092], [72.68486023, 21.15208054], [72.68569183, 21.15208244], [72.68569183, 21.15180779], [72.68624115, 21.15180969], [72.68624115, 21.15153122], [72.68736267, 21.15153122], [72.68736267, 21.15125084], [72.68818665, 21.15125084], [72.68818665, 21.15098], [72.68846893, 21.15098], [72.68846893, 21.15069008], [72.68902588, 21.1506958], [72.68902588, 21.15041733], [72.6904068, 21.15042114], [72.6904068, 21.14986038], [72.69152832, 21.14986038], [72.69152832, 21.14958], [72.69264221, 21.14958572], [72.69264221, 21.14930344], [72.69346619, 21.14931107], [72.69346619, 21.14903069], [72.69374847, 21.14903069], [72.69374847, 21.14875031], [72.69403076, 21.14875031], [72.69403076, 21.14846992], [72.69458008, 21.14847374], [72.69458008, 21.14819527], [72.69541168, 21.14821053], [72.69541168, 21.14792061], [72.69596863, 21.14792061], [72.69596863, 21.14764023], [72.69680786, 21.14764023], [72.69680786, 21.14735985], [72.69791412, 21.14736366], [72.69791412, 21.14708138], [72.69847107, 21.14708138], [72.69847107, 21.14736366], [72.69930267, 21.14736366], [72.69930267, 21.14708138], [72.69958496, 21.14708138], [72.69958496, 21.14736366], [72.69985962, 21.14736366], [72.69985962, 21.14680481], [72.70124817, 21.14680481], [72.70124817, 21.14652824], [72.70263672, 21.14653015], [72.70263672, 21.14624977], [72.70318604, 21.14624977], [72.70318604, 21.14485931], [72.70347595, 21.14485931], [72.70347595, 21.14458084], [72.70375061, 21.14458275], [72.70375061, 21.14402771], [72.70430756, 21.14403152], [72.70430756, 21.14374924], [72.70485687, 21.14374924], [72.70485687, 21.14347076], [72.70541382, 21.14347267], [72.70541382, 21.1431942], [72.70597076, 21.1431942], [72.70597076, 21.14291763], [72.70680237, 21.14292145], [72.70680237, 21.14263916], [72.70707703, 21.14263916], [72.70707703, 21.14236069], [72.7076416, 21.14236069], [72.7076416, 21.14208031], [72.70791626, 21.14208412], [72.70791626, 21.14180565], [72.70819092, 21.14180756], [72.70819092, 21.14152908], [72.70874786, 21.14152908], [72.70874786, 21.14125061], [72.70986176, 21.14125061], [72.70986176, 21.14068985], [72.7104187, 21.14069366], [72.7104187, 21.13986206], [72.71013641, 21.13986015], [72.71013641, 21.13764], [72.70986176, 21.13764], [72.70986176, 21.13735962], [72.7095871, 21.13736153], [72.7095871, 21.13680649], [72.70903015, 21.13680077], [72.70903015, 21.13652802], [72.70874786, 21.13652992], [72.70874786, 21.13598061], [72.70847321, 21.13598061], [72.70847321, 21.13569069], [72.70791626, 21.1356926], [72.70791626, 21.13541412], [72.7076416, 21.13541985], [72.7076416, 21.13513947], [72.70735168, 21.13513947], [72.70735168, 21.13402939], [72.70625305, 21.13402939], [72.70625305, 21.13375282], [72.70485687, 21.13375282], [72.70485687, 21.13347054], [72.70430756, 21.13347054], [72.70430756, 21.13319206], [72.70458221, 21.13319206], [72.70458221, 21.13236046], [72.70485687, 21.13236046], [72.70485687, 21.13208008], [72.70458221, 21.13208389], [72.70458221, 21.13152695], [72.70430756, 21.13153267], [72.70430756, 21.13042068], [72.7040329, 21.13042068], [72.7040329, 21.12957954], [72.70375061, 21.12958336], [72.70375061, 21.12874985], [72.70347595, 21.12874985], [72.70347595, 21.12846947], [72.70319366, 21.12847137], [72.70319366, 21.12791634], [72.70291901, 21.12791824], [72.70291901, 21.12763977], [72.70263672, 21.12763977], [72.70263672, 21.12708092], [72.70207977, 21.12708282], [72.70207977, 21.12652779], [72.70181274, 21.12652969], [72.70181274, 21.12347031], [72.70124817, 21.12347221], [72.70124817, 21.12319565], [72.70097351, 21.12319565], [72.70097351, 21.1226387], [72.70069122, 21.12264061], [72.70069122, 21.12236023], [72.70041656, 21.12236023], [72.70041656, 21.12207985], [72.70014191, 21.12208557], [72.70014191, 21.12180328], [72.69985962, 21.12181091], [72.69985962, 21.12125015], [72.69930267, 21.12125015], [72.69930267, 21.12096977], [72.69847107, 21.12097359], [72.69847107, 21.12069321], [72.69819641, 21.12070084], [72.69819641, 21.12014008], [72.69763947, 21.12014008], [72.69763947, 21.11958122], [72.69736481, 21.11958122], [72.69736481, 21.11930466], [72.69708252, 21.11930466], [72.69708252, 21.11874962], [72.69680786, 21.11874962], [72.69680786, 21.11597061], [72.69708252, 21.11597252], [72.69708252, 21.1143055], [72.69735718, 21.11431122], [72.69735718, 21.11403084], [72.69763947, 21.11403084], [72.69763947, 21.11375046], [72.69790649, 21.11375046], [72.69790649, 21.11292076], [72.69819641, 21.11292076], [72.69819641, 21.11042023], [72.69847107, 21.11042023], [72.69847107, 21.10902977], [72.69875336, 21.10902977], [72.69875336, 21.10819054], [72.69847107, 21.10819244], [72.69847107, 21.10791588], [72.69819641, 21.10791969], [72.69819641, 21.10764122], [72.69790649, 21.10764122], [72.69790649, 21.10736275], [72.69763947, 21.10736275], [72.69763947, 21.10708046], [72.69736481, 21.10708237], [72.69736481, 21.10625267], [72.69708252, 21.10625267], [72.69708252, 21.10568047], [72.69652557, 21.10569382], [72.69652557, 21.10486031], [72.69625092, 21.10486031], [72.69625092, 21.10403252], [72.69596863, 21.10403252], [72.69596863, 21.10374832], [72.69568634, 21.10374832], [72.69568634, 21.10346985], [72.69541931, 21.10347176], [72.69541931, 21.10319519], [72.69513702, 21.10320091], [72.69513702, 21.10290909], [72.69458008, 21.10291672], [72.69458008, 21.10180473], [72.69403076, 21.10180473], [72.69403076, 21.10124969], [72.69374847, 21.10124969], [72.69374847, 21.10097122], [72.69347382, 21.10097313], [72.69347382, 21.10013962], [72.69319153, 21.10013962], [72.69319153, 21.09958076], [72.69291687, 21.09958267], [72.69291687, 21.09874916], [72.69264221, 21.09875107], [72.69264221, 21.09819031], [72.69235992, 21.09819412], [72.69235992, 21.09791756], [72.6920929, 21.09791946], [72.6920929, 21.09764099], [72.69180298, 21.09764099], [72.69180298, 21.09708023], [72.69152832, 21.09708595], [72.69152832, 21.09669113], [72.69152832, 21.09597206], [72.69125366, 21.09597206], [72.69125366, 21.09486389], [72.69097137, 21.09486389], [72.69097137, 21.09430313], [72.69069672, 21.09431076], [72.69069672, 21.09264183], [72.6904068, 21.09264183], [72.6904068, 21.09153175], [72.69013977, 21.09153175], [72.69013977, 21.09096909], [72.68985748, 21.0909729], [72.68985748, 21.09041595], [72.68958282, 21.09042168], [72.68958282, 21.09013939], [72.68902588, 21.09013939], [72.68902588, 21.08986092], [72.68763733, 21.08986092], [72.68763733, 21.09013939], [72.68736267, 21.09013939], [72.68736267, 21.09042168], [72.68653107, 21.09041595], [72.68653107, 21.09069443], [72.68624115, 21.09068108], [72.68624115, 21.09264183], [72.68653107, 21.09264183], [72.68653107, 21.09320068], [72.68624878, 21.09319305], [72.68624878, 21.09375191], [72.68597412, 21.09375191], [72.68597412, 21.0945816], [72.68569183, 21.0945797], [72.68569183, 21.09514046], [72.68541718, 21.09514046], [72.68541718, 21.09542084], [72.68514252, 21.09541702], [72.68514252, 21.0956955], [72.68486023, 21.0956955], [72.68486023, 21.09597206], [72.68458557, 21.09597206], [72.6845932, 21.09625053], [72.68430328, 21.09625053], [72.68430328, 21.09653091], [72.68402863, 21.0965271], [72.68402863, 21.09708595], [72.68374634, 21.09708595], [72.68374634, 21.09752083], [72.68374634, 21.09764099], [72.68347168, 21.09764099], [72.68347168, 21.09791946], [72.68291473, 21.09791756], [72.68291473, 21.09819412], [72.68264008, 21.09819031], [72.68264008, 21.09875107], [72.68235779, 21.09875107], [72.68235779, 21.09902954], [72.68180847, 21.09902954], [72.68180847, 21.09930992], [72.68125153, 21.09930992], [72.68125153, 21.09987068], [72.68096924, 21.09987068], [72.68096924, 21.10013962], [72.68042755, 21.10013962], [72.68042755, 21.10041809], [72.67986298, 21.10041618], [72.67986298, 21.10069466], [72.67930603, 21.10069466], [72.67930603, 21.10097313], [72.67903137, 21.10097122], [72.67903137, 21.10124969], [72.67874908, 21.10124969], [72.67874908, 21.10152817], [72.67819214, 21.10152817], [72.67819214, 21.10180473], [72.67791748, 21.10180473], [72.67791748, 21.10208321], [72.67764282, 21.10207939], [72.67764282, 21.10263824], [72.67736053, 21.10263824], [72.67736053, 21.10347176], [72.67708588, 21.10346985], [72.67708588, 21.10374832], [72.67679596, 21.10374832], [72.67679596, 21.10403252], [72.67652893, 21.10403252], [72.67652893, 21.1043129], [72.67624664, 21.10430527], [72.67624664, 21.10458374], [72.67597198, 21.10458183], [72.67597198, 21.10514259], [72.67569733, 21.10514259], [72.67569733, 21.10625267], [72.67542267, 21.10625267], [72.67542267, 21.10653114], [72.67514038, 21.10653114], [72.67514038, 21.10736275], [72.67485809, 21.10736275], [72.67485809, 21.10847473], [72.67458344, 21.10847473], [72.67458344, 21.10986137], [72.67430115, 21.10985947], [72.67430115, 21.11013985], [72.67402649, 21.11013985], [72.67402649, 21.1115303], [72.67375183, 21.1115284], [72.67375183, 21.11319351], [72.67346954, 21.11319351], [72.67346954, 21.11847115], [72.67375183, 21.11847115], [72.67375183, 21.11930466], [72.67346954, 21.11930275], [72.67346954, 21.12042046], [72.67318726, 21.12042046], [72.67318726, 21.12153053], [72.67292023, 21.12153053], [72.67292023, 21.12264061], [72.67263794, 21.1226387], [72.67263794, 21.12319565], [72.67236328, 21.12319565], [72.67236328, 21.12347221], [72.67208099, 21.12347031], [72.67208099, 21.12375069], [72.67180634, 21.12375069], [72.67180634, 21.1245842], [72.67151642, 21.12458038], [72.67151642, 21.12680817], [72.67124939, 21.12680626], [72.67124939, 21.1273613], [72.67097473, 21.1273613], [72.67097473, 21.12819481], [72.67069244, 21.12819481], [72.67069244, 21.12847137], [72.67041779, 21.12847137], [72.67041779, 21.12986183], [72.6701355, 21.12986183], [72.6701355, 21.13097191], [72.66986084, 21.13097191], [72.66986084, 21.13181114], [72.66958618, 21.13180542], [72.66958618, 21.13208389], [72.66929626, 21.13208008], [72.66929626, 21.13236046], [72.66902924, 21.13236046], [72.66902924, 21.13264275], [72.66874695, 21.13263893], [72.66874695, 21.13319206], [72.66847229, 21.13319016], [72.66847229, 21.13402939], [72.66819763, 21.13402939], [72.66819763, 21.13513947], [72.66791534, 21.13513947], [72.66791534, 21.1356926], [72.66764069, 21.13569069], [72.66764069, 21.13598061], [72.6673584, 21.13598061], [72.6673584, 21.13624954], [72.66707611, 21.13624954], [72.66707611, 21.13652992], [72.66680908, 21.13652802], [72.66680908, 21.13736153], [72.66652679, 21.13735962], [72.66652679, 21.13820076], [72.66625214, 21.13820076], [72.66625214, 21.13903809], [72.66596985, 21.13903809], [72.66596985, 21.13986015], [72.66570282, 21.13986015], [72.66570282, 21.14152908], [72.6654129, 21.14152718], [72.6654129, 21.14208412], [72.66513824, 21.14208412], [72.66513824, 21.1431942], [72.6654129, 21.1431942], [72.6654129, 21.14347267], [72.66513824, 21.14347076], [72.66513824, 21.14403152], [72.66486359, 21.14402771], [72.66486359, 21.14847374], [72.66513824, 21.14846992], [72.66513824, 21.14875031], [72.6654129, 21.14875031], [72.6654129, 21.14931107], [72.66569519, 21.14930344], [72.66569519, 21.14958572], [72.66625214, 21.14958], [72.66625214, 21.15014076], [72.66652679, 21.15014076], [72.66652679, 21.15042114], [72.66680908, 21.15041733], [72.66680908, 21.1506958], [72.66791534, 21.1506958], [72.66791534, 21.15125084], [72.66819763, 21.15125084], [72.66819763, 21.15208244], [72.66874695, 21.15208054], [72.66874695, 21.15236092], [72.66902924, 21.15236092], [72.66902924, 21.15263939], [72.66930389, 21.15263939], [72.66930389, 21.1534729], [72.66986084, 21.15347099], [72.66986084, 21.15374947], [72.67041779, 21.15374947], [72.67041779, 21.15402794], [72.6709671, 21.15402031], [72.6709671, 21.15430832], [72.67152405, 21.15430641], [72.67152405, 21.15458298], [72.67208099, 21.15458298], [72.67208099, 21.15486145], [72.67236328, 21.15485954], [72.67236328, 21.15513992], [72.67292023, 21.15513992], [72.67292023, 21.1554184], [72.67457581, 21.1554184], [72.67457581, 21.15570068], [72.67652893, 21.15570068]]], [[[69.72374725, 21.56375122], [69.72374725, 21.56402969], [69.72429657, 21.56402969], [69.72429657, 21.56375122], [69.72458649, 21.56375122], [69.72458649, 21.56347084], [69.72486115, 21.56347466], [69.72486115, 21.56319237], [69.72458649, 21.56319237], [69.72458649, 21.5629158], [69.72429657, 21.56291962], [69.72429657, 21.56208038], [69.72402954, 21.56208229], [69.72402954, 21.56180573], [69.72374725, 21.56180954], [69.72374725, 21.56069183], [69.7234726, 21.56069374], [69.7234726, 21.56041718], [69.72319794, 21.56043053], [69.72319794, 21.55903244], [69.72292328, 21.55903244], [69.72292328, 21.55875015], [69.72264099, 21.55875015], [69.72264099, 21.55792236], [69.72292328, 21.55792236], [69.72292328, 21.55708122], [69.72264099, 21.55708313], [69.72264099, 21.55680466], [69.7223587, 21.55680466], [69.7223587, 21.55569458], [69.72208405, 21.55569458], [69.72208405, 21.5545826], [69.72180939, 21.5545826], [69.72180176, 21.55402756], [69.7195816, 21.55402756], [69.7195816, 21.55430794], [69.71930695, 21.55430794], [69.71930695, 21.5545826], [69.71901703, 21.55458069], [69.71902466, 21.55513954], [69.71875, 21.55513954], [69.71875, 21.55569458], [69.71848297, 21.55569077], [69.71848297, 21.55763817], [69.71875763, 21.55763817], [69.71875763, 21.55820274], [69.71901703, 21.55820274], [69.71901703, 21.55875015], [69.71930695, 21.55875015], [69.71930695, 21.55903244], [69.7195816, 21.55903244], [69.7195816, 21.55986023], [69.72013855, 21.55986023], [69.72013855, 21.56043053], [69.72041321, 21.56043053], [69.72041321, 21.56125069], [69.72070313, 21.56125069], [69.72070313, 21.56153107], [69.7215271, 21.56153107], [69.7215271, 21.56180954], [69.72125244, 21.56180573], [69.72125244, 21.56208229], [69.72180176, 21.56208038], [69.72180176, 21.56264114], [69.72207642, 21.56264114], [69.72207642, 21.56291962], [69.72319794, 21.56291962], [69.72319794, 21.56375122], [69.72374725, 21.56375122]]], [[[69.73373413, 21.59569359], [69.73347473, 21.59569359], [69.73347473, 21.59587097], [69.7334671, 21.59625053], [69.73319244, 21.59625053], [69.73319244, 21.59680939], [69.73291779, 21.59680939], [69.73291779, 21.59763908], [69.73264313, 21.59763908], [69.73264313, 21.59791946], [69.73236084, 21.59791946], [69.73236084, 21.59874916], [69.73208618, 21.59874916], [69.73208618, 21.59902954], [69.73179626, 21.59902954], [69.73179626, 21.59931183], [69.73152924, 21.59930611], [69.73152924, 21.59958267], [69.73179626, 21.59958076], [69.73179626, 21.59986115], [69.73152924, 21.59986115], [69.73152924, 21.60013962], [69.73124695, 21.60013962], [69.73124695, 21.60069466], [69.73097229, 21.60069275], [69.73097229, 21.60124969], [69.73042297, 21.60124969], [69.73042297, 21.60292053], [69.73014069, 21.60292053], [69.73014069, 21.60320091], [69.7298584, 21.60319328], [69.7298584, 21.60347176], [69.72957611, 21.60346985], [69.72957611, 21.60375023], [69.72930908, 21.60375023], [69.72930908, 21.60431099], [69.72902679, 21.60430336], [69.72902679, 21.60458565], [69.72930908, 21.60457993], [69.72930908, 21.60486031], [69.72846985, 21.60486031], [69.72846985, 21.60514069], [69.72820282, 21.60514069], [69.72820282, 21.60542107], [69.7279129, 21.60541534], [69.7279129, 21.60569572], [69.7270813, 21.60569], [69.7270813, 21.60625076], [69.72680664, 21.60625076], [69.72680664, 21.60680962], [69.72651672, 21.60680962], [69.72651672, 21.60736084], [69.72624969, 21.60736084], [69.72624969, 21.60791969], [69.72569275, 21.60791779], [69.72569275, 21.60819435], [69.72541809, 21.60819054], [69.72541809, 21.60848045], [69.7251358, 21.60848045], [69.7251358, 21.60874939], [69.72486115, 21.60874939], [69.72486115, 21.60902977], [69.72458649, 21.60902977], [69.72458649, 21.60986137], [69.72486115, 21.60986137], [69.72486115, 21.61069489], [69.72763824, 21.61069489], [69.72763824, 21.6115284], [69.7279129, 21.6115284], [69.7279129, 21.61208344], [69.72846985, 21.61208344], [69.72846985, 21.61180496], [69.72875214, 21.61181259], [69.72875214, 21.61152077], [69.72958374, 21.6115284], [69.72958374, 21.61124992], [69.73069763, 21.61124992], [69.73069763, 21.61096764], [69.73152924, 21.61097145], [69.73152924, 21.61069489], [69.73180389, 21.61069489], [69.73180389, 21.61041641], [69.73208618, 21.61041832], [69.73208618, 21.61013985], [69.73264313, 21.61013985], [69.73264313, 21.60985947], [69.73291779, 21.60986137], [69.73291779, 21.6095829], [69.73486328, 21.6095829], [69.73486328, 21.60902977], [69.73513794, 21.60902977], [69.73513794, 21.60819054], [69.73542023, 21.60819435], [69.73542023, 21.60736084], [69.73568726, 21.60736084], [69.73568726, 21.60653114], [69.73542023, 21.60653114], [69.73542023, 21.60597038], [69.73513794, 21.60597229], [69.73513794, 21.60486031], [69.73542023, 21.60486031], [69.73542023, 21.60403061], [69.73568726, 21.60403061], [69.73568726, 21.60346985], [69.73596954, 21.60347176], [69.73596954, 21.60291672], [69.73625183, 21.60292053], [69.73625183, 21.60264015], [69.73652649, 21.60264015], [69.73652649, 21.60207939], [69.73680878, 21.6020813], [69.73680878, 21.60180473], [69.73708344, 21.60180473], [69.73708344, 21.60124969], [69.73735809, 21.60124969], [69.73735809, 21.60097122], [69.73764038, 21.60097122], [69.73764038, 21.60069466], [69.73708344, 21.60069466], [69.73708344, 21.60013962], [69.73680115, 21.60013962], [69.73680115, 21.59902954], [69.73652649, 21.59902954], [69.73652649, 21.59568977], [69.73680878, 21.59569359], [69.73680878, 21.59541893], [69.73707581, 21.59542084], [69.73707581, 21.59514046], [69.73764038, 21.59514046], [69.73764038, 21.59486008], [69.73791504, 21.59486198], [69.73791504, 21.59458351], [69.73819733, 21.59458351], [69.73819733, 21.59402847], [69.73847198, 21.59403038], [69.73847198, 21.59375], [69.73874664, 21.59375], [69.73874664, 21.59348106], [69.73958588, 21.59348106], [69.73958588, 21.59320068], [69.73986816, 21.59320068], [69.73986816, 21.5929203], [69.74014282, 21.5929203], [69.74014282, 21.59263992], [69.73958588, 21.59263992], [69.73958588, 21.59235954], [69.73842621, 21.59233284], [69.73844147, 21.5922451], [69.73847198, 21.59208488], [69.73735809, 21.59208488], [69.73735809, 21.59236145], [69.73707581, 21.59235954], [69.73707581, 21.59263992], [69.73680115, 21.59263992], [69.73680115, 21.5929203], [69.73625183, 21.5929203], [69.73625183, 21.59320068], [69.73596954, 21.59320068], [69.73596954, 21.59348106], [69.73568726, 21.59348106], [69.73568726, 21.59403038], [69.73486328, 21.59403038], [69.73486328, 21.59431076], [69.73458099, 21.59431076], [69.73458862, 21.59514809], [69.73430634, 21.59513855], [69.73426819, 21.59536743], [69.73419952, 21.59541893], [69.73405457, 21.59548187], [69.73402405, 21.59569359], [69.73373413, 21.59569359]]], [[[72.35319519, 21.61347008], [72.35319519, 21.61291695], [72.35375214, 21.61292267], [72.35375214, 21.61264038], [72.35402679, 21.61264038], [72.35402679, 21.61236191], [72.35430908, 21.61236191], [72.35430908, 21.61097145], [72.35402679, 21.61097145], [72.35402679, 21.6095829], [72.35458374, 21.6095829], [72.35458374, 21.60930634], [72.35514069, 21.60930824], [72.35514069, 21.60902977], [72.3554306, 21.60902977], [72.3554306, 21.60874939], [72.35514069, 21.60874939], [72.35514069, 21.60848045], [72.3554306, 21.60848045], [72.3554306, 21.60736084], [72.35569763, 21.60736084], [72.35569763, 21.60708046], [72.35597229, 21.60708427], [72.35597229, 21.60625076], [72.35624695, 21.60625076], [72.35624695, 21.60597038], [72.35652924, 21.60597229], [72.35652924, 21.60513878], [72.35708618, 21.60514069], [72.35708618, 21.60486031], [72.35736084, 21.60486031], [72.35736084, 21.60403061], [72.35764313, 21.60403061], [72.35764313, 21.60375023], [72.35791779, 21.60375023], [72.35791779, 21.60346985], [72.35847473, 21.60347176], [72.35847473, 21.60319328], [72.35874939, 21.60320091], [72.35874939, 21.60292053], [72.35901642, 21.60292053], [72.35901642, 21.60235023], [72.35958099, 21.60236168], [72.35958099, 21.6020813], [72.36013794, 21.6020813], [72.36013794, 21.60236168], [72.36042023, 21.60235023], [72.36042023, 21.60264015], [72.36068726, 21.60264015], [72.36068726, 21.60292053], [72.36096954, 21.60292053], [72.36096954, 21.60264015], [72.36152649, 21.60264015], [72.36152649, 21.60235023], [72.36180878, 21.60236168], [72.36180878, 21.60180473], [72.36208344, 21.60180473], [72.36208344, 21.60152817], [72.36235809, 21.60153008], [72.36235809, 21.60124969], [72.36264038, 21.60124969], [72.36264038, 21.60097122], [72.36291504, 21.60097122], [72.36291504, 21.60069466], [72.36374664, 21.60069466], [72.36374664, 21.60041618], [72.36402893, 21.60042191], [72.36402893, 21.59958076], [72.36291504, 21.59958267], [72.36291504, 21.59930611], [72.36235809, 21.59931183], [72.36235809, 21.59902954], [72.36207581, 21.59902954], [72.36207581, 21.59847069], [72.36235809, 21.5984726], [72.36235809, 21.59819412], [72.36264038, 21.59819412], [72.36264038, 21.59791756], [72.36458588, 21.59791756], [72.36458588, 21.59819412], [72.36486053, 21.59819412], [72.36486053, 21.59763908], [72.36514282, 21.59763908], [72.36514282, 21.59625053], [72.36486053, 21.59625053], [72.36486053, 21.59596825], [72.36430359, 21.59597206], [72.36430359, 21.59319687], [72.36486053, 21.59320068], [72.36486053, 21.5929203], [72.36514282, 21.5929203], [72.36514282, 21.59263992], [72.36486053, 21.59263992], [72.36486053, 21.59208107], [72.36458588, 21.59208488], [72.36458588, 21.5918045], [72.36429596, 21.59181023], [72.36429596, 21.59152985], [72.36458588, 21.59152985], [72.36458588, 21.59124947], [72.36486053, 21.59124947], [72.36486053, 21.59069061], [72.36513519, 21.59069633], [72.36513519, 21.59013939], [72.36541748, 21.59013939], [72.36541748, 21.58986092], [72.36513519, 21.58986092], [72.36513519, 21.58791733], [72.36486053, 21.58792114], [72.36486053, 21.58764267], [72.36347198, 21.58764267], [72.36347198, 21.58735085], [72.36291504, 21.58736038], [72.36291504, 21.58708382], [72.36264038, 21.58708382], [72.36264038, 21.58683968], [72.36264038, 21.58625031], [72.36312866, 21.58625031], [72.36319733, 21.58597183], [72.36347198, 21.58597183], [72.36347198, 21.58569527], [72.36292267, 21.5857029], [72.36292267, 21.58542252], [72.36235809, 21.58542252], [72.36235809, 21.58514023], [72.36207581, 21.58514023], [72.36207581, 21.58263969], [72.36180878, 21.58263969], [72.36180878, 21.58180809], [72.36152649, 21.58180809], [72.36152649, 21.58125114], [72.35986328, 21.58125114], [72.35986328, 21.58097076], [72.35958099, 21.58097267], [72.35958099, 21.5806942], [72.35930634, 21.5806942], [72.35930634, 21.58041763], [72.35901642, 21.58041954], [72.35901642, 21.58014107], [72.35874939, 21.58014107], [72.35874939, 21.57986069], [72.35791779, 21.57986069], [72.35791779, 21.58041954], [72.35736084, 21.58041763], [72.35736084, 21.58097267], [72.35764313, 21.58097076], [72.35764313, 21.58153915], [72.3548584, 21.58152771], [72.3548584, 21.58208275], [72.35458374, 21.58208275], [72.35458374, 21.5834713], [72.35430908, 21.58346748], [72.35430908, 21.58374977], [72.35375214, 21.58374977], [72.35375214, 21.58514023], [72.35263824, 21.58514023], [72.35263824, 21.58542252], [72.35235596, 21.58542252], [72.35235596, 21.5857029], [72.3520813, 21.58569527], [72.3520813, 21.58708382], [72.35235596, 21.58708191], [72.35235596, 21.58764267], [72.3520813, 21.58763885], [72.3520813, 21.58819389], [72.35180664, 21.58819008], [72.35180664, 21.58903122], [72.35152435, 21.5890274], [72.35152435, 21.58958244], [72.35124969, 21.58958244], [72.35124969, 21.59069633], [72.35098267, 21.59069061], [72.35098267, 21.59152985], [72.35069275, 21.59152985], [72.35069275, 21.59263992], [72.35041809, 21.59263992], [72.35041809, 21.59320068], [72.3501358, 21.59320068], [72.3501358, 21.59348106], [72.35041809, 21.59348106], [72.35041809, 21.59431076], [72.3501358, 21.59430695], [72.3501358, 21.59458351], [72.34986115, 21.5945797], [72.34986115, 21.59514046], [72.3501358, 21.59513855], [72.3501358, 21.59597206], [72.3493042, 21.59597206], [72.3493042, 21.59708405], [72.34902954, 21.59707832], [72.34902954, 21.59791946], [72.34874725, 21.59791946], [72.34874725, 21.59874916], [72.3484726, 21.59874916], [72.3484726, 21.59931183], [72.34874725, 21.59930611], [72.34874725, 21.59958267], [72.3484726, 21.59958076], [72.3484726, 21.60013962], [72.34792328, 21.60013962], [72.34792328, 21.60042191], [72.3473587, 21.60041618], [72.3473587, 21.60069466], [72.34707642, 21.60069275], [72.34707642, 21.60124969], [72.3465271, 21.60124969], [72.3465271, 21.60153008], [72.34625244, 21.60152817], [72.34625244, 21.60180473], [72.34597015, 21.60180473], [72.34597015, 21.60236168], [72.34541321, 21.60235023], [72.34541321, 21.60292053], [72.34597015, 21.60292053], [72.34597015, 21.60320091], [72.34625244, 21.60319328], [72.34625244, 21.60569572], [72.3465271, 21.60569572], [72.3465271, 21.60597229], [72.34626007, 21.60597038], [72.34626007, 21.60680962], [72.34597015, 21.60680771], [72.34597015, 21.60708427], [72.34707642, 21.60708046], [72.34707642, 21.60791969], [72.34680176, 21.60791779], [72.34680176, 21.60819435], [72.3465271, 21.60819435], [72.3465271, 21.6095829], [72.34680176, 21.6095829], [72.34680176, 21.60986137], [72.34707642, 21.60985947], [72.34707642, 21.61041832], [72.3473587, 21.61041641], [72.3473587, 21.61069489], [72.34764099, 21.61069489], [72.34764099, 21.61097145], [72.34791565, 21.61097145], [72.34791565, 21.61124992], [72.34819794, 21.61124992], [72.34819794, 21.6115284], [72.3484726, 21.61152077], [72.3484726, 21.61181259], [72.35069275, 21.61180496], [72.35069275, 21.61208344], [72.35097504, 21.61208344], [72.35097504, 21.61236191], [72.35124969, 21.61236191], [72.35124969, 21.61264038], [72.35151672, 21.61264038], [72.35151672, 21.61292267], [72.35180664, 21.61291695], [72.35180664, 21.6131916], [72.35236359, 21.61319542], [72.35236359, 21.61347008], [72.3529892, 21.61347008], [72.35319519, 21.61347008]]], [[[72.61180878, 21.6320858], [72.61180878, 21.63152695], [72.61152649, 21.63153076], [72.61152649, 21.63125038], [72.61125183, 21.63125038], [72.61125183, 21.63070107], [72.61113739, 21.63070107], [72.61096191, 21.63070107], [72.61096191, 21.63042068], [72.61068726, 21.63042068], [72.61068726, 21.62985992], [72.61042023, 21.62986374], [72.61042023, 21.62958336], [72.60986328, 21.62959099], [72.60986328, 21.63042068], [72.61013794, 21.63042068], [72.61013794, 21.63125038], [72.61042023, 21.63125038], [72.61042023, 21.63153076], [72.61068726, 21.6315403], [72.61068726, 21.63181114], [72.61125183, 21.63180351], [72.61125183, 21.6320858], [72.61180878, 21.6320858]]], [[[72.60930634, 21.62874985], [72.60930634, 21.62792015], [72.60901642, 21.62792015], [72.60901642, 21.62708282], [72.60874939, 21.62708282], [72.60874939, 21.62652779], [72.60847473, 21.62652779], [72.60847473, 21.62569427], [72.60819244, 21.62569427], [72.60819244, 21.62486076], [72.60791779, 21.62486076], [72.60791779, 21.62431145], [72.60764313, 21.62431145], [72.60764313, 21.62402916], [72.60791779, 21.62402916], [72.60791779, 21.62291908], [72.60764313, 21.62291908], [72.60764313, 21.62236023], [72.60736084, 21.62236023], [72.60736084, 21.62181091], [72.60764313, 21.62181091], [72.60764313, 21.62096977], [72.60791779, 21.62097168], [72.60791779, 21.62069511], [72.60764313, 21.62070847], [72.60764313, 21.62014008], [72.60736084, 21.62014008], [72.60736084, 21.61903], [72.60680389, 21.61902618], [72.60680389, 21.61930656], [72.60624695, 21.61930656], [72.60624695, 21.61958313], [72.60514832, 21.61958122], [72.60514832, 21.62014008], [72.60541534, 21.62013626], [72.60541534, 21.62097168], [72.60514832, 21.62096977], [72.60514832, 21.62181091], [72.6048584, 21.62180519], [72.6048584, 21.62319374], [72.60514832, 21.62318993], [72.60514832, 21.62402916], [72.60541534, 21.62402725], [72.60541534, 21.62486076], [72.60569763, 21.62486076], [72.60569763, 21.62569427], [72.60597229, 21.62569427], [72.60597229, 21.6273613], [72.60624695, 21.6273613], [72.60624695, 21.62847137], [72.60791779, 21.62846947], [72.60791779, 21.62874985], [72.60819244, 21.62874985], [72.60819244, 21.62903023], [72.60958099, 21.62903023], [72.60958099, 21.62874985], [72.60930634, 21.62874985]]], [[[72.5845871, 21.62903023], [72.5845871, 21.62708282], [72.58430481, 21.62708282], [72.58430481, 21.62624931], [72.58402252, 21.62625122], [72.58402252, 21.62597084], [72.58152771, 21.62597084], [72.58152771, 21.62625122], [72.58125305, 21.62624931], [72.58125305, 21.62708282], [72.58152771, 21.62708282], [72.58152771, 21.6273613], [72.58207703, 21.62735939], [72.58207703, 21.62763977], [72.58235931, 21.62763977], [72.58235931, 21.62792015], [72.5826416, 21.62791634], [72.5826416, 21.62819481], [72.58319092, 21.6281929], [72.58319092, 21.62874985], [72.58347321, 21.62874985], [72.58347321, 21.62903023], [72.5845871, 21.62903023]]], [[[72.59570313, 21.63903046], [72.59570313, 21.63875008], [72.59597015, 21.63875008], [72.59596252, 21.63763809], [72.59570313, 21.63763809], [72.59570313, 21.63735962], [72.59541321, 21.63736153], [72.59541321, 21.63652992], [72.59513855, 21.63652992], [72.59513855, 21.63569069], [72.59486389, 21.6356945], [72.59486389, 21.63541794], [72.5945816, 21.63541985], [72.5945816, 21.63486099], [72.59430695, 21.63486099], [72.59430695, 21.63458061], [72.59375, 21.63458252], [72.59375, 21.63430786], [72.5945816, 21.63430977], [72.5945816, 21.63402939], [72.59513855, 21.63402939], [72.59513855, 21.63319016], [72.59541321, 21.63319588], [72.59541321, 21.63306808], [72.59541321, 21.63069344], [72.59570313, 21.63070107], [72.59570313, 21.63042068], [72.59596252, 21.63042068], [72.59596252, 21.6301403], [72.5973587, 21.6301384], [72.5973587, 21.63097191], [72.59764099, 21.63097], [72.59764099, 21.63125038], [72.59792328, 21.63125038], [72.59792328, 21.63153076], [72.59874725, 21.63153076], [72.59874725, 21.63125038], [72.59902191, 21.63125038], [72.59902191, 21.63153076], [72.59937286, 21.63153076], [72.59958649, 21.63153076], [72.59958649, 21.63181114], [72.59986115, 21.63181114], [72.59986115, 21.63236046], [72.60098267, 21.63236046], [72.60097504, 21.6320858], [72.60124969, 21.6320858], [72.60124969, 21.63125038], [72.60069275, 21.63125038], [72.60069275, 21.63100052], [72.60069275, 21.63069344], [72.60148621, 21.63069344], [72.6020813, 21.63069344], [72.6020813, 21.63097191], [72.60235596, 21.63097], [72.60235596, 21.63125038], [72.60263824, 21.63125038], [72.60263824, 21.63153076], [72.60320282, 21.63153076], [72.60320282, 21.63125038], [72.60346985, 21.63125038], [72.60346985, 21.63097], [72.60375214, 21.63097], [72.60375214, 21.63181114], [72.60402679, 21.63180351], [72.60402679, 21.6320858], [72.60430908, 21.63208008], [72.60430908, 21.63236046], [72.60457611, 21.63236046], [72.60457611, 21.63265038], [72.60514832, 21.63265038], [72.60514832, 21.63292122], [72.60541534, 21.6329174], [72.60541534, 21.63319588], [72.60569763, 21.63319588], [72.60569763, 21.63347244], [72.60541534, 21.63347244], [72.60541534, 21.63458252], [72.60708618, 21.63458061], [72.60708618, 21.63486099], [72.60791779, 21.63486099], [72.60791779, 21.63513947], [72.6084671, 21.63513947], [72.6084671, 21.63486099], [72.60874939, 21.63486099], [72.60874939, 21.63513947], [72.60901642, 21.63513947], [72.60901642, 21.63486099], [72.60958099, 21.63486099], [72.60958099, 21.63513947], [72.60986328, 21.63513947], [72.60986328, 21.63541985], [72.61069489, 21.63541794], [72.61069489, 21.6356945], [72.61152649, 21.6356945], [72.61152649, 21.63486099], [72.61125183, 21.63486099], [72.61125183, 21.63458061], [72.61096954, 21.63458252], [72.61096954, 21.63430786], [72.61068726, 21.63430977], [72.61068726, 21.63347054], [72.61042023, 21.63347244], [72.61042023, 21.63319588], [72.61013794, 21.63319588], [72.61013794, 21.63263893], [72.60930634, 21.63265038], [72.60930634, 21.63292122], [72.60819244, 21.63292122], [72.60819244, 21.63265038], [72.60764313, 21.63265038], [72.60764313, 21.63236046], [72.60736084, 21.63236046], [72.60736084, 21.63208008], [72.60680389, 21.6320858], [72.60680389, 21.63180351], [72.60652924, 21.63181114], [72.60652924, 21.63153076], [72.60624695, 21.63153076], [72.60624695, 21.63125038], [72.60597229, 21.63125038], [72.60597229, 21.63097], [72.60569763, 21.63097191], [72.60569763, 21.63069344], [72.60514832, 21.63070107], [72.60514832, 21.63042068], [72.6048584, 21.63042068], [72.6048584, 21.6301403], [72.60457611, 21.6301403], [72.60457611, 21.62985992], [72.60430908, 21.62986374], [72.60430908, 21.62958336], [72.60346985, 21.62959099], [72.60346985, 21.62903023], [72.60320282, 21.62903023], [72.60320282, 21.62846947], [72.6029129, 21.62847137], [72.6029129, 21.62791634], [72.60263824, 21.62792015], [72.60263824, 21.62763977], [72.60235596, 21.62763977], [72.60235596, 21.62735939], [72.6020813, 21.6273613], [72.6020813, 21.62680626], [72.60151672, 21.62681007], [72.60151672, 21.62625122], [72.60180664, 21.62625122], [72.60180664, 21.62568855], [72.6020813, 21.62569427], [72.6020813, 21.6245842], [72.60236359, 21.6245842], [72.60236359, 21.62402725], [72.6029129, 21.62402916], [72.6029129, 21.62346077], [72.60263824, 21.62347221], [72.60263824, 21.62319374], [72.6029129, 21.62319374], [72.6029129, 21.62152863], [72.60263824, 21.62153053], [72.60263824, 21.62042046], [72.60235596, 21.62042046], [72.60235596, 21.62014008], [72.60208893, 21.62014008], [72.60208893, 21.61958122], [72.60180664, 21.61958313], [72.60180664, 21.61930656], [72.60124969, 21.61930656], [72.60124969, 21.61902618], [72.60098267, 21.61903], [72.60098267, 21.61874962], [72.60041809, 21.61874962], [72.60041809, 21.61847115], [72.59986115, 21.61847305], [72.59986115, 21.61819649], [72.59958649, 21.61819649], [72.59958649, 21.61763954], [72.59902191, 21.61765099], [72.59902191, 21.61736107], [72.5984726, 21.61736107], [72.5984726, 21.61765099], [72.59764099, 21.61765099], [72.59764099, 21.61791992], [72.5973587, 21.6179142], [72.5973587, 21.61819649], [72.59708405, 21.61819649], [72.59708405, 21.61958313], [72.59625244, 21.61958313], [72.59625244, 21.61930656], [72.5956955, 21.61930656], [72.5956955, 21.61902618], [72.59541321, 21.61903], [72.59541321, 21.61874962], [72.59430695, 21.61874962], [72.59430695, 21.61903], [72.59375, 21.61903], [72.59375, 21.61874962], [72.59319305, 21.61874962], [72.59319305, 21.61903], [72.59263611, 21.61902618], [72.59263611, 21.61930656], [72.59208679, 21.61930656], [72.59208679, 21.61958313], [72.5918045, 21.61958313], [72.5918045, 21.6198616], [72.59152985, 21.6198597], [72.59152985, 21.62014008], [72.59124756, 21.62014008], [72.59124756, 21.62042046], [72.59069824, 21.62042046], [72.59069061, 21.62070847], [72.59041595, 21.62070847], [72.59041595, 21.62181091], [72.5901413, 21.62180519], [72.5901413, 21.62208366], [72.58985901, 21.62207985], [72.58985901, 21.62236023], [72.59014893, 21.62236023], [72.59014893, 21.62291908], [72.59041595, 21.62291718], [72.59041595, 21.62319374], [72.5909729, 21.62318993], [72.5909729, 21.62375069], [72.59124756, 21.62375069], [72.59124756, 21.6245842], [72.5909729, 21.62457848], [72.5909729, 21.62513924], [72.59069824, 21.62513924], [72.59069061, 21.62597275], [72.59041595, 21.62597275], [72.59041595, 21.62652779], [72.59014893, 21.62652016], [72.59014893, 21.62681007], [72.58930206, 21.62680626], [72.58930206, 21.6273613], [72.5890274, 21.62735939], [72.5890274, 21.62792015], [72.58875275, 21.62792015], [72.58875275, 21.62903023], [72.58847046, 21.62903023], [72.58847046, 21.62959099], [72.5881958, 21.62959099], [72.5881958, 21.6301403], [72.58790588, 21.6301403], [72.58790588, 21.63070107], [72.5881958, 21.63070107], [72.5881958, 21.63236046], [72.58847046, 21.63236046], [72.58847046, 21.63292122], [72.58875275, 21.6329174], [72.58875275, 21.63319588], [72.5890274, 21.63319016], [72.5890274, 21.63375092], [72.58930206, 21.63375092], [72.58930206, 21.63402939], [72.59041595, 21.63402557], [72.59041595, 21.63417053], [72.59041595, 21.63541985], [72.5909729, 21.63541794], [72.5909729, 21.6356945], [72.59124756, 21.6356945], [72.59124756, 21.63597298], [72.59152985, 21.63597107], [72.59152985, 21.63624954], [72.59208679, 21.63624954], [72.59208679, 21.6368084], [72.59236145, 21.6368084], [72.59236145, 21.63820267], [72.59263611, 21.63819504], [72.59263611, 21.6384716], [72.59375, 21.63845825], [72.59375, 21.63875008], [72.59401703, 21.63875008], [72.59401703, 21.63903046], [72.59570313, 21.63903046]]], [[[72.72264099, 21.66597176], [72.72264099, 21.66569519], [72.72374725, 21.66569519], [72.72374725, 21.66541672], [72.72402954, 21.66542244], [72.72402954, 21.66514015], [72.72429657, 21.66514015], [72.72429657, 21.66485977], [72.72458649, 21.66486168], [72.72458649, 21.66458321], [72.7251358, 21.66458321], [72.7251358, 21.66430473], [72.72541809, 21.66430473], [72.72541809, 21.66374969], [72.72598267, 21.66374969], [72.72597504, 21.66347313], [72.72624969, 21.66347313], [72.72624969, 21.66319466], [72.72680664, 21.66319466], [72.72680664, 21.66291618], [72.72735596, 21.66291809], [72.72735596, 21.66263008], [72.7279129, 21.66263962], [72.7279129, 21.66236115], [72.72847748, 21.66236115], [72.72846985, 21.66208267], [72.72902679, 21.66208267], [72.72902679, 21.66180611], [72.72957611, 21.66180992], [72.72957611, 21.66152954], [72.7298584, 21.66152954], [72.7298584, 21.66097069], [72.73124695, 21.66097069], [72.73124695, 21.66125107], [72.73264313, 21.66125107], [72.73264313, 21.66097069], [72.73374939, 21.6609726], [72.73374939, 21.66069412], [72.73430634, 21.66069412], [72.73430634, 21.66041756], [72.73596954, 21.66041946], [72.73596954, 21.66014099], [72.73680878, 21.66014099], [72.73680878, 21.65986061], [72.73735809, 21.65986061], [72.73735809, 21.65958977], [72.73792267, 21.65958977], [72.73792267, 21.65903091], [72.73902893, 21.65903091], [72.73902893, 21.65930939], [72.7409668, 21.65930939], [72.7409668, 21.65903091], [72.74180603, 21.65903091], [72.74180603, 21.65875053], [72.74236298, 21.65875053], [72.74236298, 21.65847015], [72.74291992, 21.65847015], [72.74291992, 21.65875053], [72.74318695, 21.65875053], [72.74318695, 21.65818977], [72.74402618, 21.65818977], [72.74402618, 21.65875053], [72.74511719, 21.65875053], [72.74597168, 21.65875053], [72.74597168, 21.65847015], [72.74652863, 21.65847206], [72.74652863, 21.65819359], [72.74680328, 21.65819359], [72.74680328, 21.65791512], [72.74736023, 21.65792084], [72.74736023, 21.65764046], [72.74819183, 21.65764046], [72.74819183, 21.65736008], [72.74847412, 21.65736389], [72.74847412, 21.65708542], [72.74874878, 21.65708542], [72.74874878, 21.65680313], [72.74931335, 21.6568203], [72.74931335, 21.65653038], [72.74958038, 21.65653038], [72.74958038, 21.65625], [72.74986267, 21.65625], [72.74986267, 21.65596962], [72.75013733, 21.65597153], [72.75013733, 21.65569305], [72.75068665, 21.65570068], [72.75068665, 21.65458107], [72.75096893, 21.65458107], [72.75096893, 21.65291595], [72.75041962, 21.65292168], [72.75041962, 21.65236092], [72.75013733, 21.65236092], [72.75013733, 21.65208054], [72.74986267, 21.65208244], [72.74986267, 21.6515274], [72.74931335, 21.65152931], [72.74931335, 21.65125084], [72.74903107, 21.65125084], [72.74903107, 21.65097046], [72.74874878, 21.65097237], [72.74874878, 21.65069389], [72.74847412, 21.65069389], [72.74847412, 21.65041733], [72.74819183, 21.65041924], [72.74819183, 21.65014076], [72.74791718, 21.65014076], [72.74791718, 21.64930916], [72.74736023, 21.64930916], [72.74736023, 21.64903069], [72.7470932, 21.64903069], [72.7470932, 21.64846992], [72.74680328, 21.64847183], [72.74680328, 21.64819527], [72.746521, 21.64819908], [72.746521, 21.64764977], [72.74597168, 21.64764977], [72.74597168, 21.64680099], [72.74569702, 21.64680672], [72.74569702, 21.64652824], [72.7454071, 21.64653015], [72.7454071, 21.64624977], [72.74458313, 21.64624977], [72.74458313, 21.64596939], [72.74430847, 21.6459713], [72.74430847, 21.64569664], [72.74346924, 21.64569664], [72.74346924, 21.64541435], [72.74236298, 21.64542007], [72.74236298, 21.64513969], [72.74208069, 21.64513969], [72.74208069, 21.64486122], [72.73986053, 21.64486122], [72.73986053, 21.64459038], [72.73902893, 21.64459038], [72.73902893, 21.64431], [72.73847198, 21.64431], [72.73847198, 21.64402962], [72.73792267, 21.64402962], [72.73792267, 21.64375114], [72.73735809, 21.64375114], [72.73735809, 21.64402962], [72.73707581, 21.64402962], [72.73707581, 21.64375114], [72.73625183, 21.64375114], [72.73625183, 21.64513969], [72.73680878, 21.64513969], [72.73680878, 21.64624977], [72.73596954, 21.64624977], [72.73596954, 21.64708328], [72.73542023, 21.64708328], [72.73542023, 21.64680672], [72.73374939, 21.64680672], [72.73374939, 21.64652824], [72.73291779, 21.64653015], [72.73291779, 21.64624977], [72.73236084, 21.64624977], [72.73236084, 21.64596939], [72.73069763, 21.6459713], [72.73069763, 21.64569664], [72.73041534, 21.64569664], [72.73041534, 21.64541435], [72.73014069, 21.64542007], [72.73014069, 21.64513969], [72.72957611, 21.64513969], [72.72957611, 21.64486122], [72.72930908, 21.64486122], [72.72930908, 21.64513969], [72.72902679, 21.64513969], [72.72902679, 21.64486122], [72.72875214, 21.64486122], [72.72875214, 21.64459038], [72.72847748, 21.64459038], [72.72847748, 21.64431], [72.72820282, 21.64431], [72.72820282, 21.64402962], [72.72680664, 21.64402962], [72.72680664, 21.64375114], [72.72486115, 21.64375114], [72.72486115, 21.64347076], [72.72429657, 21.64347076], [72.72429657, 21.64375114], [72.72402954, 21.64375114], [72.72402954, 21.64347076], [72.7234726, 21.64347458], [72.7234726, 21.64319229], [72.72180176, 21.64319229], [72.72180176, 21.64347458], [72.72125244, 21.64347076], [72.72125244, 21.64375114], [72.72041321, 21.64375114], [72.72041321, 21.64402962], [72.71985626, 21.64402962], [72.71985626, 21.64431], [72.71930695, 21.64431], [72.71930695, 21.64459038], [72.71679688, 21.64459038], [72.71679688, 21.64513969], [72.71624756, 21.64513969], [72.71624756, 21.64542007], [72.7159729, 21.64541435], [72.7159729, 21.64569664], [72.71569824, 21.64569664], [72.71569061, 21.6459713], [72.71541595, 21.64596939], [72.71541595, 21.64764977], [72.71569061, 21.64764977], [72.71569824, 21.64819908], [72.7159729, 21.64819527], [72.7159729, 21.64958382], [72.71624756, 21.64958382], [72.71624756, 21.65097237], [72.7159729, 21.65097046], [72.7159729, 21.65125084], [72.71569824, 21.65125084], [72.71569061, 21.65152931], [72.71541595, 21.65152931], [72.71541595, 21.6518116], [72.7151413, 21.65180588], [72.7151413, 21.65208244], [72.71485901, 21.65208054], [72.71485901, 21.65236092], [72.71430206, 21.65236092], [72.71430206, 21.65263939], [72.71375275, 21.65263939], [72.71375275, 21.65292168], [72.71347046, 21.65291595], [72.71347046, 21.65319443], [72.7131958, 21.65319443], [72.7131958, 21.6534729], [72.71290588, 21.6534729], [72.71290588, 21.65374947], [72.71263885, 21.65374947], [72.71263885, 21.65431023], [72.7123642, 21.65430641], [72.7123642, 21.65486145], [72.71208191, 21.65485954], [72.71208191, 21.65570068], [72.71180725, 21.65570068], [72.71180725, 21.65625], [72.71151733, 21.65625], [72.71151733, 21.65653038], [72.71097565, 21.65652847], [72.71097565, 21.65736389], [72.71069336, 21.65736008], [72.71069336, 21.65764046], [72.7104187, 21.65763855], [72.7104187, 21.65819359], [72.71013641, 21.65818977], [72.71013641, 21.65903091], [72.71041107, 21.65903091], [72.71041107, 21.65986061], [72.71069336, 21.65986061], [72.71069336, 21.66014099], [72.71098328, 21.66014099], [72.71098328, 21.66041946], [72.71125031, 21.66041756], [72.71125031, 21.66069412], [72.71152496, 21.66069412], [72.71152496, 21.6609726], [72.71180725, 21.66097069], [72.71180725, 21.66125107], [72.71235657, 21.66125107], [72.71235657, 21.66152954], [72.71263885, 21.66152763], [72.71263885, 21.66208267], [72.71290588, 21.66208076], [72.71290588, 21.66236115], [72.7131958, 21.66236115], [72.7131958, 21.66263962], [72.71347046, 21.66263008], [72.71347046, 21.66291809], [72.71375275, 21.66291618], [72.71375275, 21.66319466], [72.7140274, 21.66319466], [72.7140274, 21.66347313], [72.71457672, 21.66347122], [72.71457672, 21.66374969], [72.71485901, 21.66374969], [72.71485901, 21.66402817], [72.71541595, 21.66402817], [72.71541595, 21.66430473], [72.7159729, 21.66430473], [72.7159729, 21.66458321], [72.71652985, 21.66458321], [72.71652985, 21.66486168], [72.71679688, 21.66485977], [72.71679688, 21.66514015], [72.71736145, 21.66514015], [72.71736145, 21.66542244], [72.71819305, 21.66541672], [72.71819305, 21.66569519], [72.72041321, 21.66569519], [72.72041321, 21.66597176], [72.72264099, 21.66597176]]], [[[72.61708069, 21.6384716], [72.61708069, 21.63763809], [72.61680603, 21.63763809], [72.61680603, 21.63735962], [72.61653137, 21.63736153], [72.61653137, 21.63708305], [72.61624908, 21.63708305], [72.61624908, 21.63680649], [72.6159668, 21.63680077], [72.61597443, 21.63624954], [72.61569214, 21.63624954], [72.61569214, 21.63597107], [72.61541748, 21.63597298], [72.61541748, 21.6356945], [72.61513519, 21.6356945], [72.61513519, 21.63541794], [72.61458588, 21.63541794], [72.61458588, 21.63597298], [72.61429596, 21.63597107], [72.61429596, 21.63652992], [72.61458588, 21.63652992], [72.61458588, 21.6368084], [72.61486053, 21.63680649], [72.61486053, 21.63708305], [72.61541748, 21.63708305], [72.61541748, 21.63736153], [72.61569214, 21.63735962], [72.61569214, 21.63763809], [72.6159668, 21.63763809], [72.6159668, 21.63791847], [72.61653137, 21.63791847], [72.61653137, 21.63820267], [72.61680603, 21.63819504], [72.61680603, 21.6384716], [72.61708069, 21.6384716]]], [[[72.61958313, 21.63958359], [72.61958313, 21.63930511], [72.62014771, 21.63931274], [72.62014771, 21.63903046], [72.61902618, 21.63903046], [72.61902618, 21.63875008], [72.61846924, 21.63875008], [72.61846924, 21.63845825], [72.61763763, 21.63845825], [72.61763763, 21.63903046], [72.61708069, 21.63902855], [72.61708069, 21.63958359], [72.61736298, 21.63958359], [72.61736298, 21.63930511], [72.61902618, 21.63930511], [72.61902618, 21.63958359], [72.61958313, 21.63958359]]], [[[72.60236359, 21.64097023], [72.60236359, 21.64069366], [72.60263824, 21.64069366], [72.60263824, 21.63986015], [72.6020813, 21.63986015], [72.6020813, 21.63930511], [72.60180664, 21.63931274], [72.60180664, 21.63875008], [72.6001358, 21.63875008], [72.6001358, 21.63845825], [72.59986115, 21.6384716], [72.59986115, 21.63819504], [72.59958649, 21.63820267], [72.59958649, 21.63791847], [72.59929657, 21.63791847], [72.59929657, 21.63735962], [72.59958649, 21.63736153], [72.59958649, 21.63708305], [72.59874725, 21.63708305], [72.59874725, 21.63736153], [72.59819794, 21.63735962], [72.59819794, 21.63763809], [72.59791565, 21.63763809], [72.59791565, 21.6384716], [72.59764099, 21.63845825], [72.59764099, 21.63875008], [72.5973587, 21.63875008], [72.5973587, 21.63903046], [72.59708405, 21.63902855], [72.59708405, 21.63958359], [72.59680176, 21.63958168], [72.59680176, 21.64014053], [72.59625244, 21.64014053], [72.59625244, 21.64042282], [72.59597015, 21.6404171], [72.59597015, 21.64069366], [72.5956955, 21.64069366], [72.5956955, 21.64097023], [72.59596252, 21.64097023], [72.59596252, 21.64125061], [72.5965271, 21.64125061], [72.5965271, 21.64097023], [72.59764099, 21.64097023], [72.59764099, 21.64069366], [72.59791565, 21.64069366], [72.59791565, 21.6404171], [72.59819794, 21.64042282], [72.59819794, 21.64014053], [72.5984726, 21.64014053], [72.5984726, 21.63986015], [72.59958649, 21.63986015], [72.59958649, 21.63958359], [72.59986115, 21.63958359], [72.59986115, 21.63986015], [72.6001358, 21.63986015], [72.6001358, 21.64014053], [72.60098267, 21.64014053], [72.60098267, 21.64042282], [72.6020813, 21.6404171], [72.6020813, 21.64125061], [72.60263824, 21.64125061], [72.60263824, 21.64097023], [72.60236359, 21.64097023]]], [[[72.27430725, 21.74958229], [72.27430725, 21.74930573], [72.27458191, 21.74930954], [72.27458191, 21.74903107], [72.27485657, 21.74903107], [72.27485657, 21.7479229], [72.27513885, 21.7479229], [72.27513885, 21.74708176], [72.27541351, 21.74708366], [72.27541351, 21.74652863], [72.2756958, 21.74653053], [72.2756958, 21.74625015], [72.27597046, 21.74625015], [72.27597046, 21.74542236], [72.27625275, 21.74542236], [72.27625275, 21.7448597], [72.2765274, 21.7448616], [72.2765274, 21.74458313], [72.27680206, 21.74458313], [72.27680206, 21.74430466], [72.27708435, 21.74430466], [72.27708435, 21.74402809], [72.27735901, 21.74403954], [72.27735901, 21.74374962], [72.2776413, 21.74374962], [72.2776413, 21.74347115], [72.27819824, 21.74347305], [72.27819824, 21.74319458], [72.2784729, 21.74319458], [72.2784729, 21.74291611], [72.27874756, 21.74291992], [72.27874756, 21.74263954], [72.27902985, 21.74263954], [72.27902985, 21.74236107], [72.27929688, 21.74236107], [72.27929688, 21.74208069], [72.27958679, 21.7420826], [72.27958679, 21.74152565], [72.27986145, 21.74152946], [72.27986145, 21.74041939], [72.28015137, 21.74041939], [72.28015137, 21.73986053], [72.2804184, 21.73986053], [72.2804184, 21.73931122], [72.28069305, 21.73931122], [72.28069305, 21.73875046], [72.28098297, 21.73875046], [72.28097534, 21.73819351], [72.28125, 21.7381897], [72.28125, 21.73597145], [72.28152466, 21.73597145], [72.28152466, 21.73541641], [72.28180695, 21.73542023], [72.28180695, 21.73513985], [72.2820816, 21.73513985], [72.2820816, 21.73485184], [72.28236389, 21.73486137], [72.28236389, 21.7345829], [72.28263855, 21.7345829], [72.28263855, 21.73347282], [72.28236389, 21.73347282], [72.28236389, 21.73263931], [72.2820816, 21.73263931], [72.2820816, 21.73097038], [72.28180695, 21.73097229], [72.28180695, 21.72958374], [72.28152466, 21.72958374], [72.28152466, 21.7290287], [72.28125, 21.72903061], [72.28125, 21.72875023], [72.28069305, 21.72875023], [72.28069305, 21.72735977], [72.28097534, 21.72736168], [72.28097534, 21.72652626], [72.28125, 21.72653008], [72.28125, 21.72597122], [72.28152466, 21.72597313], [72.28152466, 21.7234726], [72.28180695, 21.7234726], [72.28180695, 21.72208214], [72.28236389, 21.72208214], [72.28236389, 21.72097015], [72.28263855, 21.72097015], [72.28263855, 21.72069359], [72.28291321, 21.72069359], [72.28291321, 21.72041702], [72.28321075, 21.72042274], [72.28321075, 21.72014046], [72.28347015, 21.72014046], [72.28347015, 21.71986961], [72.28375244, 21.71986961], [72.28375244, 21.71875191], [72.2840271, 21.71875191], [72.2840271, 21.71707916], [72.28430176, 21.71708298], [72.28430939, 21.71680641], [72.28457642, 21.71680832], [72.28457642, 21.71624947], [72.2848587, 21.71624947], [72.2848587, 21.71541977], [72.28457642, 21.71541977], [72.28457642, 21.71513939], [72.2848587, 21.71513939], [72.2848587, 21.71458054], [72.28514099, 21.71458244], [72.28514099, 21.71375084], [72.28541565, 21.71375084], [72.28541565, 21.7131958], [72.28569794, 21.7131958], [72.28569794, 21.71263885], [72.28595734, 21.71264076], [72.28595734, 21.71181107], [72.28624725, 21.71181107], [72.28624725, 21.71125031], [72.28652954, 21.71125031], [72.28652954, 21.71070099], [72.28679657, 21.71070099], [72.28679657, 21.71014023], [72.28708649, 21.71014023], [72.28708649, 21.70957947], [72.28736115, 21.70958328], [72.28736115, 21.70874977], [72.2876358, 21.70874977], [72.2876358, 21.70819283], [72.28791809, 21.70819473], [72.28791809, 21.70763969], [72.2876358, 21.70763969], [72.2876358, 21.70736122], [72.28736115, 21.70736122], [72.28736115, 21.70763969], [72.28708649, 21.70763969], [72.28708649, 21.70792961], [72.2868042, 21.70791626], [72.2868042, 21.70819473], [72.28652954, 21.70819473], [72.28652954, 21.7084713], [72.28624725, 21.70846939], [72.28624725, 21.70874977], [72.28595734, 21.70874977], [72.28595734, 21.70903015], [72.28569794, 21.70902824], [72.28569794, 21.70930481], [72.28541565, 21.70930481], [72.28541565, 21.70986176], [72.28514099, 21.70985985], [72.28514099, 21.71014023], [72.2848587, 21.71014023], [72.2848587, 21.71070099], [72.28458405, 21.71069336], [72.28458405, 21.71097183], [72.28430176, 21.71096992], [72.28430176, 21.71125031], [72.2840271, 21.71125031], [72.2840271, 21.71181107], [72.28375244, 21.71181107], [72.28375244, 21.71236038], [72.28347015, 21.71236038], [72.28347015, 21.71264076], [72.2831955, 21.71263885], [72.2831955, 21.7131958], [72.28263855, 21.7131958], [72.28263855, 21.71375084], [72.28235626, 21.7137394], [72.28235626, 21.71403122], [72.2820816, 21.71403122], [72.2820816, 21.71486092], [72.28180695, 21.71486092], [72.28180695, 21.71541977], [72.28151703, 21.71541977], [72.28151703, 21.71680832], [72.28125, 21.71680641], [72.28125, 21.71708298], [72.28097534, 21.71708298], [72.28097534, 21.71736145], [72.28069305, 21.71735954], [72.28069305, 21.7179184], [72.2804184, 21.7179184], [72.2804184, 21.71820259], [72.27958679, 21.71819496], [72.27958679, 21.71847153], [72.27929688, 21.71847153], [72.27929688, 21.71875191], [72.27902985, 21.71875191], [72.27902985, 21.71931267], [72.27874756, 21.71931267], [72.27874756, 21.71986961], [72.2784729, 21.71986961], [72.2784729, 21.72014046], [72.27819824, 21.72013855], [72.27819061, 21.72069359], [72.27791595, 21.72069359], [72.27791595, 21.72097015], [72.2776413, 21.72097015], [72.2776413, 21.72153282], [72.27707672, 21.72153282], [72.27707672, 21.72236061], [72.2767868, 21.72236061], [72.2767868, 21.7226429], [72.2765274, 21.72263908], [72.2765274, 21.72291756], [72.27625275, 21.72291756], [72.27625275, 21.72319221], [72.27597046, 21.72319031], [72.27597046, 21.72430992], [72.2756958, 21.7243042], [72.2756958, 21.72458267], [72.27540588, 21.72458076], [72.27540588, 21.72486115], [72.27485657, 21.72486115], [72.27485657, 21.72513962], [72.27458191, 21.72513962], [72.27458191, 21.72542], [72.27430725, 21.72541428], [72.27430725, 21.72597313], [72.27401733, 21.72597122], [72.27401733, 21.72624969], [72.27375031, 21.72624969], [72.27375031, 21.72653008], [72.27347565, 21.72652626], [72.27347565, 21.72736168], [72.27319336, 21.72735977], [72.27319336, 21.72764015], [72.2729187, 21.72764015], [72.2729187, 21.72792053], [72.27263641, 21.72792053], [72.27263641, 21.72820091], [72.27236176, 21.72819519], [72.27236176, 21.72847176], [72.2720871, 21.72846985], [72.2720871, 21.72875023], [72.27179718, 21.72875023], [72.27179718, 21.72903061], [72.27153015, 21.7290287], [72.27153015, 21.72958374], [72.27124786, 21.72957993], [72.27124786, 21.73041916], [72.27097321, 21.73041725], [72.27097321, 21.73069382], [72.27069092, 21.73069382], [72.27069092, 21.73097229], [72.27041626, 21.73097038], [72.27041626, 21.73152924], [72.2701416, 21.73152924], [72.2701416, 21.73263931], [72.26957703, 21.73263931], [72.26957703, 21.73291969], [72.26930237, 21.73291588], [72.26930237, 21.73319435], [72.26902771, 21.73318863], [72.26902771, 21.73402977], [72.26875305, 21.73402786], [72.26875305, 21.7345829], [72.26847076, 21.7345829], [72.26847076, 21.73597145], [72.26819611, 21.73596954], [72.26819611, 21.73624992], [72.26792145, 21.73624992], [72.26792145, 21.7365303], [72.26763916, 21.7365303], [72.26763916, 21.73903084], [72.26791382, 21.73902512], [72.26792145, 21.73986053], [72.26763916, 21.73986053], [72.26763916, 21.74069595], [72.26791382, 21.74069595], [72.26791382, 21.74097252], [72.26847076, 21.74097061], [72.26847076, 21.74125099], [72.26902771, 21.74125099], [72.26902771, 21.74152946], [72.26930237, 21.74152946], [72.26930237, 21.74180984], [72.26958466, 21.74180794], [72.26958466, 21.7420826], [72.26985931, 21.74208069], [72.26985931, 21.74263954], [72.2701416, 21.74263954], [72.2701416, 21.74291992], [72.27041626, 21.74291611], [72.27041626, 21.74319458], [72.27069092, 21.74319458], [72.27069092, 21.74347305], [72.27097321, 21.74347305], [72.27097321, 21.74374962], [72.27124786, 21.74374962], [72.27124786, 21.74430466], [72.27153015, 21.74430466], [72.27153015, 21.7448616], [72.27179718, 21.7448597], [72.27179718, 21.74570274], [72.2720871, 21.74570274], [72.2720871, 21.74681282], [72.27236176, 21.74681282], [72.27236176, 21.7479229], [72.27263641, 21.74791718], [72.27263641, 21.74847221], [72.2729187, 21.74847031], [72.2729187, 21.74875069], [72.27319336, 21.74875069], [72.27319336, 21.74903107], [72.27348328, 21.74903107], [72.27348328, 21.74930954], [72.27375031, 21.74930573], [72.27375031, 21.74958229], [72.27430725, 21.74958229]]], [[[72.58790588, 21.33930969], [72.58790588, 21.33792114], [72.58763885, 21.33792114], [72.58763885, 21.33681107], [72.58735657, 21.33681107], [72.58735657, 21.33625031], [72.58598328, 21.33625031], [72.58598328, 21.33653069], [72.58569336, 21.33653069], [72.58569336, 21.33681107], [72.5854187, 21.33680344], [72.5854187, 21.33708572], [72.58569336, 21.33708], [72.58569336, 21.33736038], [72.58598328, 21.33736038], [72.58598328, 21.3376503], [72.58625031, 21.33763885], [72.58625031, 21.3381958], [72.58652496, 21.3381958], [72.58652496, 21.33847237], [72.58680725, 21.33847046], [72.58680725, 21.33903122], [72.58708191, 21.33903122], [72.58708191, 21.33986092], [72.5881958, 21.33986092], [72.5881958, 21.33930969], [72.58790588, 21.33930969]]], [[[72.58319092, 21.36541939], [72.58319092, 21.36514091], [72.58374786, 21.36514091], [72.58374786, 21.36457062], [72.58347321, 21.36458588], [72.58347321, 21.36375046], [72.58319092, 21.36375046], [72.58319092, 21.36292076], [72.58291626, 21.36292076], [72.58291626, 21.36236], [72.58235931, 21.36236382], [72.58235931, 21.36208153], [72.58208466, 21.36208153], [72.58208466, 21.36180305], [72.58152771, 21.36182022], [72.58152771, 21.3615303], [72.58125305, 21.3615303], [72.58125305, 21.36124992], [72.58069611, 21.36124992], [72.58069611, 21.36096954], [72.58041382, 21.36097145], [72.58041382, 21.36069489], [72.5798645, 21.36069489], [72.5798645, 21.36041641], [72.57958221, 21.36042023], [72.57958221, 21.36013985], [72.57875061, 21.36013985], [72.57875061, 21.36042023], [72.57902527, 21.36041641], [72.57902527, 21.36097145], [72.57930756, 21.36096954], [72.57930756, 21.36182022], [72.57958221, 21.36182022], [72.57958221, 21.36431122], [72.58013916, 21.36430359], [72.58013916, 21.36458588], [72.58097076, 21.36458588], [72.58097076, 21.36486053], [72.58152771, 21.36486053], [72.58152771, 21.36514091], [72.58207703, 21.36514091], [72.58207703, 21.36541939], [72.58319092, 21.36541939]]], [[[72.1029129, 21.27431107], [72.1029129, 21.27403069], [72.10346985, 21.27403069], [72.10346985, 21.27264023], [72.10320282, 21.27264023], [72.10320282, 21.27042007], [72.1029129, 21.27042007], [72.1029129, 21.27013969], [72.10263824, 21.27013969], [72.10263824, 21.26958084], [72.10236359, 21.26958466], [72.10236359, 21.26930618], [72.1020813, 21.26931], [72.1020813, 21.26902962], [72.10180664, 21.26902962], [72.10180664, 21.26847076], [72.10152435, 21.26847458], [72.10152435, 21.26819229], [72.10124969, 21.26819229], [72.10124969, 21.26791573], [72.10098267, 21.26791954], [72.10098267, 21.26736069], [72.10069275, 21.26736069], [72.10069275, 21.26708031], [72.10041809, 21.26708221], [72.10041809, 21.26680565], [72.1001358, 21.26680946], [72.1001358, 21.26597023], [72.09986115, 21.26597023], [72.09986115, 21.26569366], [72.09958649, 21.26569366], [72.09958649, 21.2654171], [72.09902954, 21.26540947], [72.09902954, 21.26625061], [72.09928894, 21.26625061], [72.09928894, 21.26680946], [72.09958649, 21.26680565], [72.09958649, 21.26736069], [72.09986115, 21.26736069], [72.09986115, 21.26791954], [72.1001358, 21.26791763], [72.1001358, 21.26847458], [72.10041809, 21.26847076], [72.10041809, 21.26902962], [72.10069275, 21.26902962], [72.10069275, 21.26931], [72.10097504, 21.26930618], [72.10097504, 21.26958466], [72.10124969, 21.26958084], [72.10124969, 21.27013969], [72.10151672, 21.27013969], [72.10151672, 21.27042007], [72.10180664, 21.27041435], [72.10180664, 21.27069664], [72.1020813, 21.27069092], [72.1020813, 21.27292061], [72.10234833, 21.27292061], [72.10234833, 21.27403069], [72.10263824, 21.27403069], [72.10263824, 21.27431107], [72.1029129, 21.27431107]]], [[[72.60041809, 21.38708115], [72.60041809, 21.38375092], [72.6001358, 21.38375092], [72.6001358, 21.37930107], [72.59986115, 21.37930679], [72.59986115, 21.37791443], [72.59958649, 21.37792015], [72.59958649, 21.37763977], [72.59929657, 21.37763977], [72.59929657, 21.37735939], [72.59902954, 21.3773613], [72.59902954, 21.37708473], [72.59874725, 21.37708473], [72.59874725, 21.37680626], [72.5984726, 21.37680626], [72.5984726, 21.37652779], [72.59819794, 21.37652969], [72.59819794, 21.37625122], [72.59792328, 21.37625122], [72.59792328, 21.37597084], [72.59764099, 21.37597466], [72.59764099, 21.37569237], [72.5973587, 21.37569237], [72.5973587, 21.3754158], [72.59707642, 21.37541962], [72.59707642, 21.37514114], [72.59680939, 21.37514114], [72.59680176, 21.37486076], [72.59625244, 21.37486076], [72.59625244, 21.37458038], [72.59597015, 21.37458229], [72.59597015, 21.37430573], [72.59570313, 21.37430954], [72.59570313, 21.37403107], [72.59541321, 21.37403107], [72.59541321, 21.37376022], [72.59513855, 21.37376022], [72.59513855, 21.37347031], [72.59486389, 21.37347031], [72.59486389, 21.37319374], [72.5945816, 21.37319374], [72.5945816, 21.37291718], [72.59430695, 21.3729229], [72.59430695, 21.37264252], [72.59401703, 21.37264252], [72.59401703, 21.37236023], [72.59375, 21.37236023], [72.59375, 21.37208176], [72.59347534, 21.37208366], [72.59347534, 21.37180519], [72.59319305, 21.37181282], [72.59319305, 21.37153244], [72.5929184, 21.37153244], [72.5929184, 21.37125015], [72.59263611, 21.37125015], [72.59263611, 21.37096977], [72.59236145, 21.37097168], [72.59236145, 21.37069511], [72.59208679, 21.37070084], [72.59208679, 21.37041855], [72.59179688, 21.37041855], [72.59179688, 21.37013817], [72.59152985, 21.37013817], [72.59152985, 21.3698597], [72.59124756, 21.3698616], [72.59124756, 21.36958313], [72.5909729, 21.36958313], [72.5909729, 21.36930466], [72.59041595, 21.36930466], [72.59041595, 21.36902809], [72.59014893, 21.36902809], [72.59014893, 21.36874962], [72.58985901, 21.36874962], [72.58985901, 21.36847115], [72.58958435, 21.36847305], [72.58958435, 21.36819458], [72.58930206, 21.36819458], [72.58930206, 21.36791611], [72.5890274, 21.36791992], [72.5890274, 21.36763], [72.58875275, 21.36763954], [72.58875275, 21.36736107], [72.58763885, 21.36736107], [72.58763885, 21.36763954], [72.58790588, 21.36763], [72.58790588, 21.36791992], [72.5881958, 21.36791611], [72.5881958, 21.36819458], [72.58847046, 21.36819458], [72.58847046, 21.36847305], [72.58875275, 21.36847115], [72.58875275, 21.36874962], [72.5890274, 21.36874962], [72.5890274, 21.36902809], [72.58930206, 21.36902809], [72.58930206, 21.36930466], [72.58958435, 21.36930466], [72.58958435, 21.36958313], [72.58985901, 21.36958122], [72.58985901, 21.37013817], [72.59014893, 21.37013817], [72.59014893, 21.37041855], [72.59041595, 21.37041855], [72.59041595, 21.37070084], [72.59069061, 21.37069511], [72.59069824, 21.37097168], [72.5909729, 21.37096977], [72.5909729, 21.37125015], [72.59124756, 21.37125015], [72.59124756, 21.37153244], [72.59152985, 21.37153244], [72.59152985, 21.37181282], [72.5918045, 21.37180519], [72.5918045, 21.37208366], [72.5909729, 21.37208176], [72.5909729, 21.37236023], [72.59014893, 21.37236023], [72.59014893, 21.37264252], [72.58930206, 21.37264252], [72.58930206, 21.3729229], [72.58958435, 21.37291718], [72.58958435, 21.37347031], [72.58985901, 21.37347031], [72.58985901, 21.37403107], [72.59014893, 21.37403107], [72.59014893, 21.37430954], [72.59041595, 21.37430954], [72.59041595, 21.37486076], [72.59069061, 21.37486076], [72.59069824, 21.37541962], [72.5909729, 21.3754158], [72.5909729, 21.37597466], [72.59124756, 21.37597084], [72.59124756, 21.37625122], [72.59152985, 21.37624931], [72.59152985, 21.37680626], [72.5918045, 21.37680626], [72.5918045, 21.3773613], [72.59208679, 21.37735939], [72.59208679, 21.37763977], [72.59236145, 21.37763977], [72.59236145, 21.37819672], [72.59263611, 21.37819099], [72.59263611, 21.37874985], [72.5929184, 21.37874985], [72.5929184, 21.37930679], [72.59319305, 21.37930679], [72.59319305, 21.37958336], [72.59348297, 21.37957001], [72.59348297, 21.3801403], [72.59375, 21.3801403], [72.59375, 21.38070107], [72.59402466, 21.38069534], [72.59402466, 21.38097191], [72.59430695, 21.38096809], [72.59430695, 21.38125038], [72.5945816, 21.38125038], [72.5945816, 21.38180923], [72.59486389, 21.38180542], [72.59486389, 21.38208389], [72.59513855, 21.38207817], [72.59513855, 21.38236046], [72.59541321, 21.38236046], [72.59541321, 21.38293266], [72.5956955, 21.3829174], [72.5956955, 21.38319397], [72.59597015, 21.38319397], [72.59597015, 21.38347244], [72.59625244, 21.38347054], [72.59625244, 21.38402939], [72.5965271, 21.38402939], [72.5965271, 21.38431168], [72.59680176, 21.38430595], [72.59680176, 21.38458252], [72.59707642, 21.38458061], [72.59707642, 21.38513947], [72.5973587, 21.38513947], [72.5973587, 21.38542175], [72.59764099, 21.38542175], [72.59764099, 21.38570023], [72.59791565, 21.3856945], [72.59791565, 21.38624954], [72.59819794, 21.38624954], [72.59819794, 21.38653183], [72.59902191, 21.38653183], [72.59902191, 21.3868103], [72.59986115, 21.38680649], [72.59986115, 21.38708115], [72.60041809, 21.38708115]]], [[[72.62819672, 21.41736031], [72.62819672, 21.41681099], [72.62847137, 21.41681099], [72.62847137, 21.41625023], [72.62819672, 21.41625023], [72.62819672, 21.41542053], [72.6279068, 21.41542053], [72.6279068, 21.41485977], [72.62763977, 21.41486359], [72.62763977, 21.41402817], [72.62735748, 21.41403008], [72.62735748, 21.41319275], [72.62708282, 21.41319466], [72.62708282, 21.41235924], [72.62680817, 21.41235924], [72.62680817, 21.41181183], [72.62652588, 21.41181183], [72.62652588, 21.41097069], [72.62625122, 21.4109726], [72.62625122, 21.41041756], [72.62596893, 21.41041946], [72.62596893, 21.40987015], [72.62568665, 21.40987015], [72.62568665, 21.40957832], [72.62541962, 21.40958405], [72.62541962, 21.4090271], [72.62513733, 21.40903091], [72.62513733, 21.40847015], [72.62486267, 21.40847206], [72.62486267, 21.40819359], [72.62458038, 21.40819359], [72.62458038, 21.40763855], [72.62431335, 21.40764046], [72.62431335, 21.40736008], [72.62403107, 21.40736198], [72.62403107, 21.40680695], [72.62374878, 21.40681076], [72.62374878, 21.40625], [72.62346649, 21.40625], [72.62346649, 21.40596962], [72.62319183, 21.40597153], [72.62319183, 21.40541649], [72.62291718, 21.4054203], [72.62291718, 21.40513992], [72.62264252, 21.40513992], [72.62264252, 21.40458107], [72.62236023, 21.40458488], [72.62236023, 21.40402794], [72.6220932, 21.40402985], [72.6220932, 21.40373993], [72.62180328, 21.40374947], [72.62180328, 21.40319252], [72.62152863, 21.40319252], [72.62152863, 21.40291405], [72.62124634, 21.40291977], [72.62124634, 21.40263939], [72.62097168, 21.40263939], [72.62097168, 21.40236092], [72.6204071, 21.40236092], [72.6204071, 21.40208054], [72.62014008, 21.40208244], [72.62014008, 21.40180588], [72.61985779, 21.40180969], [72.61985779, 21.40153122], [72.61958313, 21.40153122], [72.61958313, 21.40125275], [72.61902618, 21.40125275], [72.61902618, 21.40097046], [72.61875153, 21.40097237], [72.61875153, 21.40069389], [72.61846924, 21.40069389], [72.61846924, 21.40041733], [72.61818695, 21.40042114], [72.61818695, 21.40014267], [72.61763763, 21.40014267], [72.61763763, 21.39986038], [72.61736298, 21.39986038], [72.61736298, 21.39958191], [72.61708069, 21.39958382], [72.61708069, 21.39930534], [72.61680603, 21.39931107], [72.61680603, 21.39875031], [72.61653137, 21.39875031], [72.61653137, 21.3982029], [72.61624908, 21.3982029], [72.61624908, 21.39763832], [72.6159668, 21.39763832], [72.6159668, 21.39707756], [72.61569214, 21.39708328], [72.61569214, 21.39652824], [72.61541748, 21.39652824], [72.61541748, 21.39624977], [72.61513519, 21.39624977], [72.61513519, 21.3959713], [72.61486053, 21.3959713], [72.61486053, 21.39569473], [72.61264038, 21.39569473], [72.61264038, 21.3959713], [72.61235809, 21.39596748], [72.61235809, 21.39652824], [72.61208344, 21.39652824], [72.61208344, 21.39708328], [72.61235809, 21.39707756], [72.61235809, 21.39793015], [72.61264038, 21.39791679], [72.61264038, 21.39847183], [72.61292267, 21.39847183], [72.61292267, 21.39903259], [72.61319733, 21.39903259], [72.61319733, 21.39931107], [72.61347198, 21.39931107], [72.61347198, 21.39986038], [72.61374664, 21.39986038], [72.61374664, 21.40014267], [72.61402893, 21.40013885], [72.61402893, 21.40069389], [72.61430359, 21.40069389], [72.61430359, 21.40097237], [72.61458588, 21.40097046], [72.61458588, 21.40153122], [72.61486053, 21.40153122], [72.61486053, 21.40180969], [72.61513519, 21.40180588], [72.61513519, 21.40208244], [72.61541748, 21.40208054], [72.61541748, 21.40263939], [72.61569214, 21.40263939], [72.61569214, 21.40291977], [72.61597443, 21.40291405], [72.61597443, 21.40347481], [72.61624908, 21.40347481], [72.61624908, 21.40374947], [72.61653137, 21.40373993], [72.61653137, 21.40431023], [72.61680603, 21.40430641], [72.61680603, 21.40458488], [72.61708832, 21.40458107], [72.61708832, 21.40513992], [72.61736298, 21.40513992], [72.61736298, 21.4054203], [72.61763763, 21.4054203], [72.61763763, 21.40570068], [72.61819458, 21.40569687], [72.61819458, 21.40597153], [72.61846924, 21.40596962], [72.61846924, 21.40625], [72.61875153, 21.40625], [72.61875153, 21.40653038], [72.61930847, 21.40653038], [72.61930847, 21.40681076], [72.61958313, 21.40680695], [72.61958313, 21.40708351], [72.61985779, 21.40708351], [72.61985779, 21.40736198], [72.62014771, 21.40736008], [72.62014771, 21.40764046], [72.62069702, 21.40764046], [72.62069702, 21.40792084], [72.62097168, 21.40791893], [72.62097168, 21.40819359], [72.62124634, 21.40818977], [72.62124634, 21.40875053], [72.62152863, 21.40875053], [72.62152863, 21.40930748], [72.62180328, 21.40930557], [72.62180328, 21.40958405], [72.6220932, 21.40957832], [72.6220932, 21.41013908], [72.62236023, 21.41013908], [72.62236023, 21.41069412], [72.62264252, 21.41069412], [72.62264252, 21.4109726], [72.62291718, 21.41097069], [72.62291718, 21.41124916], [72.62319183, 21.41124916], [72.62319183, 21.41181183], [72.62347412, 21.41180611], [72.62347412, 21.41208267], [72.62374878, 21.41208076], [72.62374878, 21.41235924], [72.62403107, 21.41235924], [72.62403107, 21.41291618], [72.62430573, 21.41291618], [72.62430573, 21.41319466], [72.62513733, 21.41319466], [72.62513733, 21.41291618], [72.62541962, 21.41291618], [72.62541962, 21.41263962], [72.62596893, 21.41263962], [72.62596893, 21.41319466], [72.62625122, 21.41319275], [72.62625122, 21.41403008], [72.62652588, 21.41402817], [72.62652588, 21.41486359], [72.62680817, 21.41485977], [72.62680817, 21.41542053], [72.62708282, 21.41542053], [72.62708282, 21.41625023], [72.62735748, 21.41625023], [72.62735748, 21.41708565], [72.62763977, 21.41707993], [72.62763977, 21.41736031], [72.62819672, 21.41736031]]], [[[72.63597107, 21.41764069], [72.63597107, 21.41736031], [72.63680267, 21.41736031], [72.63680267, 21.41681099], [72.63707733, 21.41681099], [72.63707733, 21.41596985], [72.63680267, 21.41597176], [72.63680267, 21.41541672], [72.63652802, 21.41542053], [72.63652802, 21.41485977], [72.63625336, 21.41486359], [72.63625336, 21.41430473], [72.63597107, 21.41430473], [72.63597107, 21.41374969], [72.63569641, 21.41374969], [72.63569641, 21.41319275], [72.63541412, 21.41319466], [72.63541412, 21.41291618], [72.63486481, 21.41291618], [72.63486481, 21.41263962], [72.63458252, 21.41263962], [72.63458252, 21.41235924], [72.63402557, 21.41235924], [72.63402557, 21.41208267], [72.63375092, 21.41208267], [72.63375092, 21.41180611], [72.63153076, 21.41180611], [72.63153076, 21.41208267], [72.63180542, 21.41208267], [72.63180542, 21.41263962], [72.63208008, 21.41263962], [72.63208008, 21.41319466], [72.63236237, 21.41319275], [72.63236237, 21.41374969], [72.63263702, 21.41374969], [72.63263702, 21.41403008], [72.63291931, 21.41402817], [72.63291931, 21.41430473], [72.63319397, 21.41430473], [72.63319397, 21.4145813], [72.63346863, 21.4145813], [72.63346863, 21.41486359], [72.63375092, 21.41485977], [72.63375092, 21.41514015], [72.6340332, 21.41514015], [72.6340332, 21.41542053], [72.63430786, 21.41542053], [72.63430786, 21.41570091], [72.63458252, 21.41569328], [72.63458252, 21.41597176], [72.63513184, 21.41596985], [72.63513184, 21.41764069], [72.63597107, 21.41764069]]], [[[72.67597198, 21.44680977], [72.67597198, 21.44598007], [72.67624664, 21.44598007], [72.67624664, 21.44431114], [72.67597198, 21.44431114], [72.67597198, 21.44320107], [72.67569733, 21.44320107], [72.67569733, 21.44292068], [72.67485809, 21.44292068], [72.67485809, 21.4426403], [72.67457581, 21.4426403], [72.67457581, 21.44235992], [72.67402649, 21.44236374], [72.67402649, 21.44208145], [72.67375183, 21.44208145], [72.67375183, 21.44180489], [72.67346954, 21.44180489], [72.67346954, 21.44124985], [72.67318726, 21.44124985], [72.67318726, 21.4406929], [72.67292023, 21.44069481], [72.67292023, 21.44041634], [72.67263794, 21.44042015], [72.67263794, 21.44013977], [72.67180634, 21.44013977], [72.67180634, 21.43985176], [72.67097473, 21.4398613], [72.67097473, 21.43958282], [72.67041779, 21.43958282], [72.67041779, 21.43902779], [72.66879272, 21.43902969], [72.66819763, 21.43902969], [72.66819763, 21.43874931], [72.66764069, 21.43874931], [72.66764069, 21.43847084], [72.66625214, 21.43847275], [72.66625214, 21.43819427], [72.66596985, 21.43819427], [72.66596985, 21.43847275], [72.66570282, 21.43847084], [72.66570282, 21.43874931], [72.66513824, 21.43874931], [72.66513824, 21.43931007], [72.66486359, 21.43930626], [72.66486359, 21.43958282], [72.66374969, 21.43958282], [72.66374969, 21.44097137], [72.66401672, 21.44096947], [72.66401672, 21.44153023], [72.66430664, 21.44152832], [72.66430664, 21.44180489], [72.6645813, 21.44180489], [72.6645813, 21.44208145], [72.66486359, 21.44208145], [72.66486359, 21.44236374], [72.66513824, 21.44235992], [72.66513824, 21.44292068], [72.6654129, 21.44292068], [72.6654129, 21.44320107], [72.66596985, 21.44319344], [72.66596985, 21.44347382], [72.66707611, 21.44347], [72.66707611, 21.44375038], [72.66764069, 21.44375038], [72.66764069, 21.44403076], [72.66792297, 21.44403076], [72.66792297, 21.44431114], [72.66847229, 21.44430351], [72.66847229, 21.4445858], [72.66902924, 21.44458008], [72.66902924, 21.44514084], [72.66958618, 21.44514084], [72.66958618, 21.44542122], [72.67041779, 21.4454174], [72.67041779, 21.44569588], [72.67069244, 21.44569016], [72.67069244, 21.44598007], [72.67124176, 21.44598007], [72.67124176, 21.44625092], [72.67514038, 21.44625092], [72.67514038, 21.44652939], [72.67569733, 21.44652939], [72.67569733, 21.44680977], [72.67597198, 21.44680977]]], [[[72.47264099, 22.20819473], [72.47264099, 22.20791435], [72.47319794, 22.20792007], [72.47319794, 22.20763969], [72.47291565, 22.20763969], [72.47291565, 22.20708275], [72.47264099, 22.20708275], [72.47264099, 22.20680428], [72.47207642, 22.20681], [72.47207642, 22.20597076], [72.4723587, 22.20597267], [72.4723587, 22.20513916], [72.47207642, 22.20514107], [72.47207642, 22.20375061], [72.4723587, 22.20375061], [72.4723587, 22.20318985], [72.47097015, 22.20319366], [72.47097015, 22.20347214], [72.4695816, 22.20347214], [72.46958923, 22.20375061], [72.46930695, 22.20375061], [72.46930695, 22.20318985], [72.46902466, 22.20319366], [72.46902466, 22.20263863], [72.46875, 22.20264053], [72.46875, 22.20236015], [72.4679184, 22.20236015], [72.4679184, 22.20541954], [72.46875, 22.20541954], [72.46875, 22.20514107], [72.46930695, 22.20513916], [72.46930695, 22.20597267], [72.46958923, 22.20597076], [72.46958923, 22.20625114], [72.46985626, 22.20625114], [72.46985626, 22.20652962], [72.47041321, 22.20652962], [72.47041321, 22.20681], [72.4706955, 22.20680428], [72.4706955, 22.20708275], [72.47097015, 22.20708275], [72.47097015, 22.20736122], [72.4715271, 22.20734978], [72.4715271, 22.20763969], [72.47180176, 22.20763969], [72.47180176, 22.20792007], [72.47208405, 22.20791435], [72.47208405, 22.20819473], [72.47264099, 22.20819473]]], [[[72.38430786, 22.21569443], [72.38430786, 22.21541595], [72.38540649, 22.21541977], [72.38540649, 22.21513939], [72.38625336, 22.21513939], [72.38625336, 22.21486282], [72.38735962, 22.21486282], [72.38735962, 22.21458244], [72.38819122, 22.21458244], [72.38819122, 22.21430588], [72.38874817, 22.21430969], [72.38874817, 22.21403122], [72.38903046, 22.21403122], [72.38903046, 22.21375084], [72.38957977, 22.21375084], [72.38957977, 22.2134819], [72.39013672, 22.2134819], [72.39013672, 22.21318817], [72.39041901, 22.21319389], [72.39041901, 22.21264076], [72.39068604, 22.21264076], [72.39068604, 22.21235847], [72.39097595, 22.21235847], [72.39097595, 22.21180916], [72.39125061, 22.21180916], [72.39125061, 22.21153069], [72.3915329, 22.21153069], [72.3915329, 22.21125031], [72.39180756, 22.21125031], [72.39180756, 22.21069908], [72.39208221, 22.21069908], [72.39208221, 22.21041107], [72.39180756, 22.2104187], [72.39180756, 22.21013641], [72.38764191, 22.21013641], [72.38764191, 22.2104187], [72.38735962, 22.21041107], [72.38735962, 22.21069908], [72.38764191, 22.21069527], [72.38764191, 22.21097183], [72.38791656, 22.21096992], [72.38791656, 22.21125031], [72.38817596, 22.21125031], [72.38817596, 22.21153069], [72.38846588, 22.21153069], [72.38846588, 22.21180916], [72.38819122, 22.21180534], [72.38819122, 22.21208382], [72.38791656, 22.21207809], [72.38791656, 22.21235847], [72.38764191, 22.21235847], [72.38764191, 22.21291924], [72.38735962, 22.21291733], [72.38735962, 22.21319389], [72.38707733, 22.21318817], [72.38707733, 22.2134819], [72.38652802, 22.2134819], [72.38652802, 22.21375084], [72.38597107, 22.21375084], [72.38597107, 22.21403122], [72.38540649, 22.21403122], [72.38540649, 22.21430969], [72.38486481, 22.21430588], [72.38486481, 22.21458244], [72.38430786, 22.21458244], [72.38430786, 22.21486282], [72.38375092, 22.21486282], [72.38375092, 22.21513939], [72.38318634, 22.21513939], [72.38318634, 22.21541977], [72.38263702, 22.21541595], [72.38263702, 22.21569443], [72.38430786, 22.21569443]]], [[[72.37069702, 22.23513985], [72.37069702, 22.23402977], [72.3704071, 22.23402977], [72.3704071, 22.23319054], [72.37014008, 22.23319435], [72.37014008, 22.23291588], [72.36985779, 22.23291969], [72.36985779, 22.23264122], [72.36958313, 22.23264122], [72.36958313, 22.23236084], [72.36930847, 22.23236084], [72.36930847, 22.23180962], [72.36902618, 22.23180962], [72.36902618, 22.23125076], [72.36875153, 22.23125076], [72.36875153, 22.23069191], [72.36902618, 22.23069382], [72.36902618, 22.23041725], [72.36930847, 22.23042107], [72.36930847, 22.23014069], [72.36985779, 22.23014069], [72.36985779, 22.22986031], [72.37014008, 22.22986031], [72.37014008, 22.22958183], [72.37041473, 22.22958374], [72.37041473, 22.2290287], [72.37014008, 22.22903061], [72.37014008, 22.22820282], [72.36985779, 22.22820282], [72.36985779, 22.22764015], [72.37069702, 22.22764015], [72.37069702, 22.22680092], [72.37041473, 22.22680473], [72.37041473, 22.2262516], [72.36846924, 22.2262516], [72.36846924, 22.22513962], [72.36818695, 22.22513962], [72.36818695, 22.22402954], [72.36846924, 22.22402954], [72.36846924, 22.22375107], [72.36902618, 22.22375107], [72.36902618, 22.22347069], [72.36930847, 22.2234726], [72.36930847, 22.22319412], [72.36985779, 22.22319412], [72.36985779, 22.22291946], [72.37014008, 22.22291946], [72.37014008, 22.22014046], [72.3704071, 22.22014046], [72.37041473, 22.21750069], [72.37041473, 22.21680641], [72.37069702, 22.21681023], [72.37069702, 22.21513939], [72.37097168, 22.21513939], [72.37097168, 22.21403122], [72.37124634, 22.21403122], [72.37124634, 22.2134819], [72.37152863, 22.2134819], [72.37152863, 22.21291924], [72.37180328, 22.21291924], [72.37180328, 22.21235847], [72.3720932, 22.21235847], [72.37208557, 22.21180534], [72.37236023, 22.21180916], [72.37236023, 22.21125031], [72.37264252, 22.21125031], [72.37264252, 22.21069908], [72.37291718, 22.21069908], [72.37291718, 22.21014023], [72.37317657, 22.21014023], [72.37317657, 22.20985985], [72.37347412, 22.20986176], [72.37347412, 22.20958328], [72.37374878, 22.20958328], [72.37374878, 22.20930481], [72.37403107, 22.20930481], [72.37403107, 22.20902634], [72.37431335, 22.20903015], [72.37431335, 22.20874977], [72.37458038, 22.20874977], [72.37458038, 22.20846939], [72.37486267, 22.2084713], [72.37486267, 22.20819473], [72.37513733, 22.20819473], [72.37513733, 22.20791435], [72.37541962, 22.20792007], [72.37541962, 22.20763969], [72.37568665, 22.20763969], [72.37568665, 22.20734978], [72.37596893, 22.20736122], [72.37596893, 22.20708275], [72.37625122, 22.20708275], [72.37625122, 22.20541763], [72.37652588, 22.20541954], [72.37652588, 22.20375061], [72.37513733, 22.20375061], [72.37513733, 22.20403099], [72.37486267, 22.20403099], [72.37486267, 22.20430946], [72.37430573, 22.20430565], [72.37430573, 22.20458221], [72.37346649, 22.20458031], [72.37346649, 22.20486069], [72.37264252, 22.20486069], [72.37264252, 22.20514107], [72.3720932, 22.20514107], [72.3720932, 22.20541954], [72.37152863, 22.20541573], [72.37152863, 22.2056942], [72.37124634, 22.2056942], [72.37124634, 22.20597267], [72.37069702, 22.20597076], [72.37069702, 22.20625114], [72.36958313, 22.20625114], [72.36958313, 22.20652962], [72.36875153, 22.20652962], [72.36875153, 22.20681], [72.36819458, 22.20680428], [72.36819458, 22.20708275], [72.36791992, 22.20708275], [72.36791992, 22.20736122], [72.36736298, 22.20736122], [72.36737061, 22.20763969], [72.36680603, 22.20763969], [72.36680603, 22.20792007], [72.36624908, 22.20791435], [72.36624908, 22.20819473], [72.36597443, 22.20819473], [72.36597443, 22.2084713], [72.36541748, 22.20846939], [72.36541748, 22.20903015], [72.36513519, 22.20902634], [72.36513519, 22.20958328], [72.36486053, 22.20957947], [72.36486053, 22.21014023], [72.36458588, 22.21013641], [72.36458588, 22.21097183], [72.36486053, 22.21096992], [72.36486053, 22.21153069], [72.36458588, 22.21152878], [72.36458588, 22.21175957], [72.36458588, 22.21208382], [72.36429596, 22.21207809], [72.36429596, 22.21264076], [72.36402893, 22.21264076], [72.36402893, 22.21319389], [72.36374664, 22.21318817], [72.36374664, 22.21403122], [72.36347198, 22.2140274], [72.36347198, 22.2234726], [72.36374664, 22.22347069], [72.36374664, 22.22402954], [72.36402893, 22.22402954], [72.36402893, 22.22430992], [72.36429596, 22.22430992], [72.36429596, 22.22485924], [72.36458588, 22.22485924], [72.36458588, 22.22541809], [72.36486053, 22.22541809], [72.36486053, 22.22653008], [72.36514282, 22.22653008], [72.36514282, 22.22792053], [72.36541748, 22.22792053], [72.36541748, 22.22903061], [72.3659668, 22.22903061], [72.3659668, 22.2293129], [72.36708069, 22.2293129], [72.36708069, 22.22986031], [72.36736298, 22.22986031], [72.36736298, 22.23069382], [72.36708069, 22.23069382], [72.36708069, 22.23097229], [72.36680603, 22.23097229], [72.36680603, 22.23152733], [72.36653137, 22.2315197], [72.36653137, 22.23180962], [72.36680603, 22.2318058], [72.36680603, 22.23208427], [72.36708069, 22.23208046], [72.36708069, 22.23236084], [72.36737061, 22.23236084], [72.36737061, 22.23264122], [72.36763763, 22.23264122], [72.36763763, 22.23291969], [72.36791992, 22.23291588], [72.36791992, 22.23319435], [72.36818695, 22.23319054], [72.36818695, 22.23374939], [72.36846924, 22.23374939], [72.36846924, 22.23402977], [72.36875153, 22.23402977], [72.36875153, 22.23431015], [72.36902618, 22.23430443], [72.36902618, 22.2345829], [72.36930847, 22.2345829], [72.36930847, 22.23486137], [72.36958313, 22.23485947], [72.36958313, 22.23513985], [72.37069702, 22.23513985]]], [[[69.31041718, 22.30625153], [69.31041718, 22.30596924], [69.31069183, 22.30597305], [69.31069183, 22.30513763], [69.31096649, 22.30513763], [69.31096649, 22.30485916], [69.31124878, 22.30485916], [69.31124878, 22.30458069], [69.31153107, 22.3045826], [69.31153107, 22.30430794], [69.31181335, 22.30430984], [69.31181335, 22.30402946], [69.31208038, 22.30402946], [69.31208038, 22.30347061], [69.31180573, 22.30347252], [69.31180573, 22.30319405], [69.31041718, 22.30319405], [69.31041718, 22.30347252], [69.31014252, 22.30347061], [69.31014252, 22.30376053], [69.30986023, 22.30376053], [69.30986023, 22.30402946], [69.30958557, 22.30402946], [69.30958557, 22.3045826], [69.30928802, 22.30458069], [69.30928802, 22.30513763], [69.30958557, 22.30513763], [69.30958557, 22.30569458], [69.30986023, 22.30569458], [69.30986023, 22.30597305], [69.31014252, 22.30596924], [69.31014252, 22.30625153], [69.31041718, 22.30625153]]], [[[69.45263672, 22.35819435], [69.45263672, 22.35791588], [69.45319366, 22.35791588], [69.45319366, 22.35763741], [69.45404053, 22.35764122], [69.45404053, 22.35736084], [69.45430756, 22.35736084], [69.45430756, 22.35708046], [69.45458221, 22.35708427], [69.45458221, 22.3568058], [69.45513916, 22.35680962], [69.45513916, 22.35653114], [69.45540619, 22.35653114], [69.45540619, 22.35625076], [69.45597076, 22.35625076], [69.45597076, 22.35597038], [69.45652771, 22.35597229], [69.45652771, 22.35569382], [69.45708466, 22.35569382], [69.45708466, 22.35513878], [69.45735931, 22.35514069], [69.45735931, 22.35485077], [69.4576416, 22.35486031], [69.4576416, 22.35430527], [69.45791626, 22.35431099], [69.45791626, 22.35403061], [69.45819092, 22.35403061], [69.45819092, 22.35346985], [69.45847321, 22.35347176], [69.45847321, 22.35263824], [69.45819092, 22.35264015], [69.45819092, 22.35207939], [69.45735931, 22.35208321], [69.45735931, 22.35180473], [69.45569611, 22.35181046], [69.45569611, 22.35153008], [69.45485687, 22.35153008], [69.45485687, 22.35124969], [69.45402527, 22.35124969], [69.45402527, 22.35097313], [69.45375061, 22.35097313], [69.45375061, 22.35069466], [69.44985962, 22.35069466], [69.44985962, 22.35097313], [69.44875336, 22.35097122], [69.44875336, 22.35124969], [69.44790649, 22.35124969], [69.44790649, 22.35153008], [69.44680786, 22.35153008], [69.44680786, 22.35181046], [69.44596863, 22.35180473], [69.44596863, 22.35208321], [69.44486237, 22.35208321], [69.44486237, 22.35236168], [69.44403076, 22.35235977], [69.44403076, 22.35264015], [69.44319153, 22.35264015], [69.44319153, 22.35292053], [69.44235992, 22.35292053], [69.44235992, 22.35320091], [69.44152832, 22.35319328], [69.44152832, 22.35347176], [69.44069672, 22.35346985], [69.44069672, 22.35375023], [69.43985748, 22.35375023], [69.43985748, 22.35403061], [69.43958282, 22.35403061], [69.43958282, 22.35375023], [69.43902588, 22.35375023], [69.43902588, 22.35403061], [69.43818665, 22.35403061], [69.43818665, 22.35431099], [69.43736267, 22.35430527], [69.43736267, 22.35458374], [69.43763733, 22.35457993], [69.43763733, 22.35514069], [69.43791962, 22.35514069], [69.43791962, 22.35542107], [69.43819427, 22.35541534], [69.43819427, 22.35569382], [69.43846893, 22.35569382], [69.43846893, 22.35597229], [69.43873596, 22.35597038], [69.43873596, 22.35625076], [69.43930817, 22.35625076], [69.43930817, 22.35653114], [69.43958282, 22.35653114], [69.43958282, 22.35680962], [69.44097137, 22.3568058], [69.44097137, 22.35708427], [69.44347382, 22.35708427], [69.44347382, 22.3568058], [69.44486237, 22.3568058], [69.44486237, 22.35708427], [69.44541931, 22.35708427], [69.44541931, 22.3568058], [69.44568634, 22.35680962], [69.44568634, 22.35653114], [69.44708252, 22.35653114], [69.44708252, 22.35680962], [69.44791412, 22.3568058], [69.44791412, 22.35708427], [69.44819641, 22.35708046], [69.44819641, 22.35736084], [69.44875336, 22.35736084], [69.44875336, 22.35764122], [69.44930267, 22.35763741], [69.44930267, 22.35791588], [69.45014191, 22.35791588], [69.45014191, 22.35819435], [69.45263672, 22.35819435]]], [[[69.18402863, 22.36763954], [69.18402863, 22.36736107], [69.18486023, 22.36736107], [69.18486023, 22.36708069], [69.18569183, 22.3670826], [69.18569183, 22.36513901], [69.18541718, 22.36514091], [69.18541718, 22.36404037], [69.18430328, 22.36404037], [69.18430328, 22.36431122], [69.18402863, 22.36431122], [69.18402863, 22.36486053], [69.18374634, 22.36486053], [69.18374634, 22.36541939], [69.18347168, 22.36541748], [69.18347168, 22.36569595], [69.18321228, 22.36569023], [69.18321228, 22.36625099], [69.18292236, 22.36625099], [69.18292236, 22.36680984], [69.18264008, 22.36680984], [69.18264008, 22.36736107], [69.18291473, 22.36736107], [69.18291473, 22.36763954], [69.18402863, 22.36763954]]], [[[72.35679626, 21.93180084], [72.35680389, 21.93124962], [72.35708618, 21.93124962], [72.35708618, 21.93041992], [72.35736084, 21.93041992], [72.35736084, 21.92930984], [72.35764313, 21.92930984], [72.35764313, 21.92847061], [72.35791779, 21.92847252], [72.35791779, 21.9276371], [72.35820007, 21.92765045], [72.35820007, 21.92708015], [72.35874939, 21.92708588], [72.35874939, 21.9268074], [72.35901642, 21.92681122], [72.35901642, 21.92653084], [72.35958099, 21.92653084], [72.35958099, 21.92625046], [72.35986328, 21.92625046], [72.35986328, 21.92597008], [72.36042023, 21.92597198], [72.36042023, 21.92458344], [72.35874939, 21.92458344], [72.35874939, 21.92486191], [72.35736084, 21.92486], [72.35736084, 21.92514038], [72.35624695, 21.92514038], [72.35624695, 21.92542076], [72.35597229, 21.92541695], [72.35597229, 21.92597198], [72.35569763, 21.92597008], [72.35569763, 21.92653084], [72.35541534, 21.92652512], [72.35541534, 21.92708588], [72.35514069, 21.92708015], [72.35514069, 21.92765045], [72.3548584, 21.9276371], [72.3548584, 21.92819595], [72.35457611, 21.92819023], [72.35457611, 21.92875099], [72.35430908, 21.92875099], [72.35430908, 21.92930984], [72.35402679, 21.92930984], [72.35402679, 21.92847061], [72.35375214, 21.92847252], [72.35375214, 21.9276371], [72.35346985, 21.92765045], [72.35346985, 21.92708015], [72.35319519, 21.92708588], [72.35319519, 21.92652512], [72.3529129, 21.92653084], [72.3529129, 21.92597008], [72.35263824, 21.92597198], [72.35263824, 21.92541695], [72.35180664, 21.92541695], [72.35180664, 21.92569351], [72.35152435, 21.92569351], [72.35152435, 21.92597198], [72.35124969, 21.92597008], [72.35124969, 21.92625046], [72.35098267, 21.92625046], [72.35098267, 21.92681122], [72.35069275, 21.9268074], [72.35069275, 21.92708588], [72.35041809, 21.92708015], [72.35041809, 21.92736053], [72.3501358, 21.92736053], [72.3501358, 21.92765045], [72.34958649, 21.92765045], [72.34958649, 21.92791939], [72.3493042, 21.92791557], [72.3493042, 21.92819595], [72.34792328, 21.92819023], [72.34792328, 21.92902946], [72.34764099, 21.92902946], [72.34764099, 21.92986107], [72.34792328, 21.92986107], [72.34792328, 21.93041992], [72.34819794, 21.93041611], [72.34819794, 21.93097305], [72.3484726, 21.93097115], [72.3484726, 21.93152809], [72.34874725, 21.93152809], [72.34874725, 21.93208313], [72.34902954, 21.93207932], [72.34902954, 21.93264008], [72.34929657, 21.93264008], [72.34929657, 21.93292046], [72.34958649, 21.93291664], [72.34958649, 21.93347168], [72.34986115, 21.93345833], [72.34986115, 21.93403053], [72.3501358, 21.93402863], [72.3501358, 21.93458366], [72.35041809, 21.93458176], [72.35041809, 21.93514061], [72.35069275, 21.9351387], [72.35069275, 21.93569374], [72.35098267, 21.93569183], [72.35098267, 21.93764114], [72.35124969, 21.93764114], [72.35124969, 21.93959045], [72.35151672, 21.93959045], [72.35151672, 21.94042015], [72.35180664, 21.94041443], [72.35180664, 21.94097137], [72.35206604, 21.94096947], [72.35206604, 21.94153023], [72.35236359, 21.94152641], [72.35236359, 21.94208336], [72.3529129, 21.94208336], [72.3529129, 21.94236183], [72.35320282, 21.94235992], [72.35320282, 21.94264984], [72.35375214, 21.94264984], [72.35375214, 21.94292068], [72.35402679, 21.94292068], [72.35402679, 21.94319916], [72.3548584, 21.94319916], [72.3548584, 21.94292068], [72.35514069, 21.94292068], [72.35514069, 21.94235992], [72.35541534, 21.94236183], [72.35541534, 21.94180679], [72.35569763, 21.94180679], [72.35569763, 21.94097137], [72.35597229, 21.94097137], [72.35597229, 21.94041443], [72.35624695, 21.94042015], [72.35624695, 21.93985939], [72.35652924, 21.9398613], [72.35652924, 21.93930435], [72.35679626, 21.93931007], [72.35679626, 21.9354229], [72.35708618, 21.9354229], [72.35708618, 21.93431282], [72.35736084, 21.93431282], [72.35736084, 21.93375015], [72.35764313, 21.93375015], [72.3576355, 21.93291664], [72.35791779, 21.93292046], [72.35791779, 21.93207932], [72.35819244, 21.93208313], [72.35819244, 21.93152809], [72.3584671, 21.93152809], [72.3584671, 21.93069077], [72.35819244, 21.93069458], [72.35819244, 21.93041611], [72.3576355, 21.93041611], [72.3576355, 21.93097305], [72.35736084, 21.93097115], [72.35736084, 21.93152809], [72.35708618, 21.93152809], [72.35708618, 21.93180466], [72.35679626, 21.93180084]]], [[[72.2140274, 22.00542068], [72.2140274, 22.00485992], [72.21375275, 22.00486183], [72.21375275, 22.00458336], [72.21347046, 22.00458336], [72.21347046, 22.00430489], [72.21291351, 22.00430489], [72.21291351, 22.00402832], [72.21263885, 22.00403023], [72.21263885, 22.00374985], [72.21235657, 22.00374985], [72.21235657, 22.00346947], [72.21263885, 22.00347137], [72.21263885, 22.00291634], [72.2131958, 22.00292969], [72.2131958, 22.00263977], [72.21373749, 22.00263977], [72.21373749, 22.00292969], [72.21430206, 22.00291634], [72.21430206, 22.00319481], [72.21458435, 22.00319481], [72.21458435, 22.00291634], [72.21485901, 22.00291634], [72.21485901, 22.00319481], [72.21541595, 22.00319481], [72.21541595, 22.00347137], [72.21569061, 22.00346947], [72.21569824, 22.00374985], [72.2159729, 22.00374985], [72.2159729, 22.00346947], [72.21624756, 22.00347137], [72.21624756, 22.00263977], [72.2159729, 22.00263977], [72.2159729, 22.00208282], [72.2151413, 22.00208282], [72.2151413, 22.00180626], [72.21457672, 22.00181007], [72.21457672, 22.00152969], [72.21430206, 22.00152969], [72.21430206, 22.00125122], [72.21347046, 22.00125122], [72.21347046, 22.00152969], [72.2131958, 22.00152969], [72.2131958, 22.00181007], [72.21291351, 22.00180626], [72.21291351, 22.00208282], [72.2123642, 22.00208282], [72.2123642, 22.0023613], [72.21180725, 22.00235939], [72.21180725, 22.00263977], [72.21151733, 22.00263977], [72.21151733, 22.00292969], [72.21069336, 22.00291634], [72.21069336, 22.00319481], [72.2104187, 22.0031929], [72.2104187, 22.00374985], [72.2106781, 22.00374985], [72.2106781, 22.00403023], [72.21097565, 22.00402832], [72.21097565, 22.00430489], [72.21152496, 22.00430489], [72.21152496, 22.00458336], [72.21180725, 22.00458336], [72.21180725, 22.00486183], [72.21208191, 22.00485992], [72.21208191, 22.0051403], [72.21235657, 22.0051403], [72.21235657, 22.00542068], [72.2140274, 22.00542068]]], [[[68.21624756, 23.59124947], [68.21624756, 23.59069061], [68.21652985, 23.59069443], [68.21652985, 23.59013939], [68.21681213, 23.59013939], [68.2168045, 23.58819389], [68.21708679, 23.58819389], [68.21708679, 23.58763885], [68.21736145, 23.58764076], [68.21736145, 23.58707809], [68.21763611, 23.58708382], [68.21763611, 23.58680534], [68.21736145, 23.58680916], [68.21736145, 23.58653069], [68.21710205, 23.58653069], [68.21710205, 23.58625031], [68.21652985, 23.58625031], [68.21652985, 23.58653069], [68.2159729, 23.58653069], [68.2159729, 23.58680916], [68.21541595, 23.58680534], [68.21541595, 23.58708382], [68.2151413, 23.58707809], [68.2151413, 23.58736038], [68.21541595, 23.58736038], [68.21541595, 23.58819389], [68.2151413, 23.58818817], [68.2151413, 23.5893116], [68.21485901, 23.58930588], [68.21485901, 23.59069443], [68.2151413, 23.59069061], [68.2151413, 23.59124947], [68.21624756, 23.59124947]]], [[[68.2234726, 23.58625031], [68.2234726, 23.58596992], [68.22569275, 23.58597183], [68.22569275, 23.58569527], [68.22651672, 23.58569908], [68.22651672, 23.58542061], [68.22735596, 23.58542061], [68.22735596, 23.58514023], [68.2279129, 23.58514023], [68.2279129, 23.58485985], [68.22819519, 23.58486176], [68.22819519, 23.58430672], [68.2279129, 23.58430672], [68.2279129, 23.58402824], [68.22680664, 23.58403015], [68.22680664, 23.58374977], [68.2251358, 23.58374977], [68.2251358, 23.58403015], [68.22402954, 23.58402824], [68.22402954, 23.58430672], [68.22374725, 23.58430672], [68.22374725, 23.58458328], [68.22319794, 23.58458328], [68.22319794, 23.58486176], [68.22290802, 23.58485985], [68.22290802, 23.58514023], [68.22264099, 23.58514023], [68.22264099, 23.58542061], [68.2223587, 23.5854187], [68.2223587, 23.58597183], [68.22264099, 23.58596992], [68.22264099, 23.58625031], [68.2234726, 23.58625031]]], [[[68.25514221, 23.59013939], [68.25514221, 23.58986092], [68.25541687, 23.58986092], [68.25541687, 23.58902931], [68.25569153, 23.58902931], [68.25569153, 23.58791924], [68.25595856, 23.58791924], [68.25595856, 23.58764076], [68.25624847, 23.58764076], [68.25624847, 23.58625031], [68.25595856, 23.58625031], [68.25595856, 23.58542061], [68.25681305, 23.58542061], [68.25681305, 23.58569908], [68.25791931, 23.58569908], [68.25791931, 23.58514023], [68.25763702, 23.58514023], [68.25763702, 23.58485985], [68.25736237, 23.58486176], [68.25736237, 23.58430672], [68.25708008, 23.58430672], [68.25708008, 23.58402824], [68.25569153, 23.58402824], [68.25569153, 23.58430672], [68.25485992, 23.58430672], [68.25485992, 23.58374977], [68.25514221, 23.58374977], [68.25514221, 23.58291054], [68.25430298, 23.58291435], [68.25430298, 23.58263969], [68.25402832, 23.58263969], [68.25402832, 23.58236122], [68.25347137, 23.58236122], [68.25347137, 23.58208084], [68.25235748, 23.58208084], [68.25235748, 23.58236122], [68.25180817, 23.58236122], [68.25180817, 23.58263969], [68.25152588, 23.58263969], [68.25152588, 23.58291435], [68.24986267, 23.58291435], [68.24986267, 23.58319664], [68.24958038, 23.58319092], [68.24958038, 23.58374977], [68.24986267, 23.58374977], [68.24986267, 23.58403015], [68.25013733, 23.58402824], [68.25013733, 23.58430672], [68.25041962, 23.58430672], [68.25041962, 23.58458328], [68.25068665, 23.58457947], [68.25068665, 23.58542061], [68.25096893, 23.58542061], [68.25096893, 23.58653069], [68.25125122, 23.58653069], [68.25125122, 23.58680916], [68.25068665, 23.58680916], [68.25068665, 23.58736038], [68.24846649, 23.58736038], [68.24846649, 23.58707809], [68.24485779, 23.58707809], [68.24485779, 23.58764076], [68.24514008, 23.58764076], [68.24514008, 23.58875084], [68.24597168, 23.58875084], [68.24597168, 23.58902931], [68.24736023, 23.58902931], [68.24736023, 23.58847046], [68.24764252, 23.58847046], [68.24764252, 23.58902931], [68.24791718, 23.5890274], [68.24791718, 23.58958244], [68.24930573, 23.58958244], [68.24930573, 23.58986092], [68.25402832, 23.58986092], [68.25402832, 23.59013939], [68.25514221, 23.59013939]]], [[[68.4779129, 23.72236061], [68.4779129, 23.72207832], [68.47902679, 23.72208405], [68.47902679, 23.72180557], [68.48042297, 23.72180939], [68.48042297, 23.72153091], [68.48069763, 23.72153091], [68.48069763, 23.721241], [68.48152924, 23.72125053], [68.48152924, 23.72097206], [68.48236084, 23.72097206], [68.48236084, 23.72041893], [68.48208618, 23.72042084], [68.48208618, 23.71986008], [68.48180389, 23.71986198], [68.48180389, 23.71958351], [68.48152924, 23.71958351], [68.48152924, 23.71930695], [68.48097229, 23.71931076], [68.48097229, 23.71903038], [68.48069763, 23.71903038], [68.48069763, 23.71875], [68.48014069, 23.71875], [68.48014069, 23.71846962], [68.4798584, 23.71847153], [68.4798584, 23.71791458], [68.47957611, 23.7179203], [68.47957611, 23.71763992], [68.47930908, 23.71763992], [68.47930908, 23.71747971], [68.47930908, 23.71736145], [68.47846985, 23.71736145], [68.47846985, 23.71708488], [68.47763824, 23.71708488], [68.47763824, 23.7168045], [68.4770813, 23.71681023], [68.4770813, 23.71652985], [68.47680664, 23.71652985], [68.47680664, 23.71624947], [68.47624969, 23.71624947], [68.47624969, 23.71597099], [68.47569275, 23.71597481], [68.47569275, 23.71569633], [68.47541809, 23.71569633], [68.47541809, 23.71541405], [68.47486115, 23.71543121], [68.47486115, 23.71513939], [68.47458649, 23.71513939], [68.47458649, 23.71486092], [68.47374725, 23.71486092], [68.47374725, 23.71458054], [68.47264099, 23.71458054], [68.47264099, 23.71486092], [68.4723587, 23.71486092], [68.4723587, 23.71543121], [68.47208405, 23.71541405], [68.47208405, 23.71569633], [68.47180176, 23.71569633], [68.47180176, 23.71597481], [68.4715271, 23.71597099], [68.4715271, 23.71624947], [68.47125244, 23.71624947], [68.47125244, 23.71652985], [68.4715271, 23.71652794], [68.4715271, 23.71680069], [68.4715271, 23.71708488], [68.47180176, 23.71708488], [68.47180176, 23.71736145], [68.47207642, 23.71735954], [68.47207642, 23.7179203], [68.4723587, 23.71791458], [68.4723587, 23.71847153], [68.47264099, 23.71846962], [68.47264099, 23.71903038], [68.47291565, 23.71902847], [68.47291565, 23.71986198], [68.47319794, 23.71986008], [68.47319794, 23.72042084], [68.4734726, 23.72041893], [68.4734726, 23.72097206], [68.47374725, 23.72097206], [68.47374725, 23.72125053], [68.47402954, 23.721241], [68.47402954, 23.72153091], [68.47486115, 23.72153091], [68.47486115, 23.72180939], [68.47569275, 23.72180557], [68.47569275, 23.72208405], [68.4770813, 23.72207832], [68.4770813, 23.72236061], [68.4779129, 23.72236061]]], [[[68.40791321, 23.45792007], [68.40791321, 23.45735931], [68.40820313, 23.45735931], [68.4081955, 23.45708275], [68.40791321, 23.45708275], [68.40791321, 23.45680618], [68.40763855, 23.4568119], [68.40763855, 23.45597076], [68.40736389, 23.45597267], [68.40736389, 23.4556942], [68.4070816, 23.4556942], [68.4070816, 23.45513916], [68.40680695, 23.45513916], [68.40680695, 23.45458031], [68.40652466, 23.45458412], [68.40652466, 23.45402718], [68.40625, 23.45402908], [68.40625, 23.45318985], [68.40652466, 23.45319366], [68.40652466, 23.45263863], [68.40625, 23.45264053], [68.40625, 23.45236015], [68.40569305, 23.45236015], [68.40569305, 23.45207977], [68.4054184, 23.45207977], [68.4054184, 23.45236015], [68.40513611, 23.45236015], [68.40513611, 23.45264053], [68.40458679, 23.45264053], [68.40458679, 23.45236015], [68.4043045, 23.45236015], [68.40429688, 23.45207977], [68.40291595, 23.45207977], [68.40291595, 23.45236015], [68.4026413, 23.45236015], [68.4026413, 23.45264053], [68.40235901, 23.45264053], [68.40235901, 23.45292091], [68.40208435, 23.4529171], [68.40208435, 23.45319366], [68.40180206, 23.45318985], [68.40180206, 23.45347977], [68.4015274, 23.45347977], [68.4015274, 23.45375061], [68.40125275, 23.45375061], [68.40125275, 23.45513916], [68.40207672, 23.45513916], [68.40207672, 23.45542145], [68.40486145, 23.45541763], [68.40486145, 23.4556942], [68.40513611, 23.4556942], [68.40513611, 23.45597267], [68.4054184, 23.45597076], [68.4054184, 23.45624924], [68.40598297, 23.45624924], [68.40598297, 23.45654106], [68.40625, 23.45654106], [68.40625, 23.4568119], [68.40652466, 23.45680618], [68.40652466, 23.45691109], [68.40652466, 23.45708275], [68.40680695, 23.45708084], [68.40680695, 23.45735931], [68.4070816, 23.45735931], [68.4070816, 23.45763969], [68.40735626, 23.45763969], [68.40735626, 23.45792007], [68.40791321, 23.45792007]]], [[[68.3998642, 23.42847252], [68.3998642, 23.42819405], [68.40013885, 23.42819405], [68.40013885, 23.42791748], [68.40042114, 23.42791939], [68.40042114, 23.42736053], [68.4006958, 23.42736053], [68.4006958, 23.4268055], [68.40097046, 23.42681122], [68.40097046, 23.42542076], [68.40125275, 23.42542076], [68.40125275, 23.42317963], [68.40097046, 23.42319679], [68.40097046, 23.42263794], [68.40071106, 23.42263985], [68.40071106, 23.42208099], [68.39958191, 23.42208481], [68.39958191, 23.42180634], [68.39819336, 23.42180634], [68.39819336, 23.42236137], [68.3979187, 23.42236137], [68.3979187, 23.42319679], [68.39819336, 23.42317963], [68.39819336, 23.4240303], [68.39847565, 23.4240284], [68.39847565, 23.42486191], [68.39875031, 23.42486191], [68.39875031, 23.42597198], [68.39847565, 23.42597198], [68.39847565, 23.42708397], [68.39875031, 23.42707825], [68.39875031, 23.42764091], [68.39902496, 23.4276371], [68.39902496, 23.42819405], [68.39930725, 23.42819405], [68.39930725, 23.42847252], [68.3998642, 23.42847252]]], [[[68.40042114, 23.42124939], [68.40041351, 23.42097473], [68.4006958, 23.42097473], [68.4006958, 23.42041588], [68.40097046, 23.42043114], [68.40097046, 23.42014122], [68.40125275, 23.42014122], [68.40125275, 23.41986084], [68.40180206, 23.41986084], [68.40180206, 23.41958046], [68.40208435, 23.41958237], [68.40208435, 23.4193058], [68.40235901, 23.41930962], [68.40235901, 23.41847038], [68.4026413, 23.41847038], [68.4026413, 23.41791725], [68.40235901, 23.41792107], [68.40235901, 23.41736984], [68.40207672, 23.41736984], [68.40207672, 23.41653252], [68.40180206, 23.41653252], [68.40180206, 23.41597176], [68.40041351, 23.41597176], [68.40042114, 23.41625023], [68.40013885, 23.41625023], [68.40013885, 23.41653252], [68.3998642, 23.4165287], [68.3998642, 23.41708374], [68.39958191, 23.41708183], [68.39958191, 23.41736984], [68.39930725, 23.41736984], [68.39930725, 23.41792107], [68.39902496, 23.41791725], [68.39902496, 23.41847038], [68.39875031, 23.41847038], [68.39875031, 23.41903114], [68.39848328, 23.41903114], [68.39848328, 23.42014122], [68.39875031, 23.42014122], [68.39875031, 23.42043114], [68.39902496, 23.42041588], [68.39902496, 23.42097473], [68.39985657, 23.42097092], [68.39985657, 23.42124939], [68.40042114, 23.42124939]]], [[[68.40208435, 23.42319679], [68.40208435, 23.42263985], [68.40235901, 23.42263985], [68.40235901, 23.42181015], [68.4026413, 23.42181015], [68.4026413, 23.42069054], [68.40235901, 23.42069244], [68.40235901, 23.42041588], [68.40180206, 23.42041588], [68.40180206, 23.42069244], [68.4015274, 23.42069244], [68.4015274, 23.42097473], [68.40125275, 23.42097092], [68.40125275, 23.42292023], [68.4015274, 23.42291641], [68.4015274, 23.42319679], [68.40208435, 23.42319679]]], [[[68.4090271, 23.40930939], [68.4090271, 23.40903091], [68.4092865, 23.40903091], [68.40930939, 23.40847015], [68.40958405, 23.40847206], [68.40958405, 23.40791702], [68.4098587, 23.40792084], [68.4098587, 23.40570068], [68.40958405, 23.40569305], [68.40958405, 23.40597153], [68.4092865, 23.40596962], [68.4092865, 23.40625], [68.4090271, 23.40625], [68.4090271, 23.40792084], [68.40875244, 23.40792084], [68.40875244, 23.40930939], [68.4090271, 23.40930939]]], [[[68.46098328, 23.40514183], [68.46098328, 23.40485954], [68.46125031, 23.40486145], [68.46125031, 23.40458107], [68.46208191, 23.40458107], [68.46208191, 23.40430641], [68.46235657, 23.40431023], [68.46235657, 23.40403175], [68.46290588, 23.40403175], [68.46290588, 23.40374947], [68.46380615, 23.40374947], [68.4651413, 23.40374947], [68.4651413, 23.40346909], [68.46624756, 23.40346909], [68.46624756, 23.40374947], [68.46679688, 23.40374947], [68.46679688, 23.40403175], [68.46736145, 23.40403175], [68.46736145, 23.40431023], [68.4679184, 23.40431023], [68.4679184, 23.40403175], [68.46848297, 23.40403175], [68.46848297, 23.40374947], [68.46902466, 23.40374947], [68.46901703, 23.40346909], [68.46847534, 23.4034729], [68.46847534, 23.40319443], [68.46708679, 23.40319443], [68.46708679, 23.40291595], [68.46569824, 23.40292168], [68.46569824, 23.40263939], [68.46430206, 23.40263939], [68.46430206, 23.40236092], [68.4625473, 23.40236092], [68.46208191, 23.40236092], [68.46208191, 23.40263939], [68.46153259, 23.40263939], [68.46153259, 23.40292168], [68.46097565, 23.40291595], [68.46097565, 23.4034729], [68.46070099, 23.40346909], [68.46070099, 23.40431023], [68.4604187, 23.40431023], [68.4604187, 23.40514183], [68.46098328, 23.40514183]]], [[[68.4145813, 23.40986061], [68.4145813, 23.40958023], [68.41486359, 23.40958595], [68.41486359, 23.40930557], [68.41513824, 23.40930939], [68.41513824, 23.40903091], [68.41542053, 23.40903091], [68.41542053, 23.40875053], [68.41596985, 23.40875053], [68.41596985, 23.40847015], [68.41625214, 23.40847206], [68.41625214, 23.4081955], [68.41652679, 23.4081955], [68.41652679, 23.40791702], [68.41680908, 23.40792084], [68.41680908, 23.40764046], [68.41707611, 23.40764046], [68.41707611, 23.4070797], [68.4173584, 23.40708542], [68.4173584, 23.40652847], [68.41764069, 23.40653038], [68.41764069, 23.40570068], [68.41792297, 23.40570068], [68.41792297, 23.40542984], [68.41845703, 23.40542984], [68.41845703, 23.40570068], [68.41874695, 23.40569305], [68.41874695, 23.40597153], [68.41845703, 23.40596962], [68.41845703, 23.40681076], [68.41930389, 23.40680313], [68.41930389, 23.40708542], [68.41958618, 23.40708542], [68.41958618, 23.40680313], [68.42014313, 23.40681076], [68.42014313, 23.40653038], [68.41986084, 23.40653038], [68.41986084, 23.40596962], [68.41930389, 23.40597153], [68.41930389, 23.40569305], [68.41902924, 23.40570068], [68.41902924, 23.40485954], [68.41930389, 23.40486145], [68.41930389, 23.40430641], [68.41958618, 23.40431023], [68.41958618, 23.40374947], [68.41929626, 23.40374947], [68.41929626, 23.40319061], [68.41902924, 23.40319443], [68.41902924, 23.40291595], [68.41958618, 23.40292168], [68.41958618, 23.40263939], [68.42014313, 23.40263939], [68.4201355, 23.40236092], [68.42041779, 23.40236092], [68.42041779, 23.4018116], [68.42069244, 23.4018116], [68.42069244, 23.40152931], [68.4209671, 23.40152931], [68.4209671, 23.40125084], [68.42151642, 23.40125084], [68.42151642, 23.40152931], [68.42180634, 23.4015274], [68.42180634, 23.40208244], [68.42208099, 23.40208054], [68.42208099, 23.40236092], [68.42180634, 23.40236092], [68.42180634, 23.40263939], [68.42151642, 23.40263939], [68.42151642, 23.40292168], [68.42124939, 23.40292168], [68.42124939, 23.40403175], [68.42097473, 23.40402794], [68.42097473, 23.40486145], [68.42124939, 23.40485954], [68.42124939, 23.40514183], [68.42236328, 23.40514183], [68.42236328, 23.40458107], [68.42263794, 23.40458107], [68.42263794, 23.40430641], [68.42292023, 23.40431023], [68.42292023, 23.40403175], [68.42318726, 23.40403175], [68.42318726, 23.40346909], [68.42346954, 23.4034729], [68.42346954, 23.40319443], [68.42375183, 23.40319443], [68.42375183, 23.40291595], [68.42402649, 23.40292168], [68.42402649, 23.40152931], [68.42375183, 23.40152931], [68.42375183, 23.40125084], [68.42346954, 23.40125084], [68.42346954, 23.40068817], [68.42236328, 23.40069389], [68.42236328, 23.40013885], [68.42208099, 23.40014076], [68.42208099, 23.40041924], [68.42097473, 23.40041733], [68.42097473, 23.40069389], [68.41958618, 23.40069389], [68.41958618, 23.40041733], [68.41874695, 23.40041733], [68.41874695, 23.40069389], [68.41819763, 23.40069389], [68.41819763, 23.40097237], [68.41764069, 23.40097046], [68.41764069, 23.40125084], [68.41680908, 23.40125084], [68.41680908, 23.40208244], [68.41596985, 23.40208054], [68.41596985, 23.40236092], [68.4154129, 23.40236092], [68.41542053, 23.40263939], [68.41513824, 23.40263939], [68.41513824, 23.40292168], [68.4145813, 23.40291595], [68.4145813, 23.40319443], [68.41374969, 23.40319443], [68.41374969, 23.4034729], [68.41347504, 23.4034729], [68.41348267, 23.40374947], [68.41319275, 23.40374947], [68.41319275, 23.40486145], [68.41291809, 23.40485954], [68.41291809, 23.40514183], [68.41430664, 23.40514183], [68.41430664, 23.40458107], [68.4145813, 23.40458107], [68.4145813, 23.40430641], [68.41485596, 23.40431023], [68.41485596, 23.40403175], [68.41542053, 23.40403175], [68.41542053, 23.40431023], [68.41569519, 23.40430641], [68.41569519, 23.40486145], [68.41542053, 23.40485954], [68.41542053, 23.40542984], [68.41513824, 23.40542984], [68.41513824, 23.40570068], [68.41485596, 23.40570068], [68.41485596, 23.40625], [68.4145813, 23.40625], [68.4145813, 23.40653038], [68.41430664, 23.40653038], [68.41430664, 23.40625], [68.41319275, 23.40625], [68.41319275, 23.40653038], [68.41348267, 23.40653038], [68.41348267, 23.40764046], [68.41319275, 23.40763855], [68.41319275, 23.40958595], [68.41347504, 23.40958595], [68.41347504, 23.40986061], [68.4145813, 23.40986061]]], [[[68.42986298, 23.40708542], [68.42986298, 23.40680313], [68.43096924, 23.40681076], [68.43096924, 23.40653038], [68.43125153, 23.40653038], [68.43125153, 23.40625], [68.43152618, 23.40625], [68.43152618, 23.40596962], [68.43180847, 23.40597153], [68.43180847, 23.40569305], [68.43235779, 23.40570068], [68.43235779, 23.40485954], [68.43125153, 23.40485954], [68.43125153, 23.40514183], [68.43096924, 23.40514183], [68.43096924, 23.40542984], [68.43041992, 23.40542984], [68.43041992, 23.40570068], [68.43013763, 23.40569305], [68.43013763, 23.40597153], [68.42958069, 23.40596962], [68.42958069, 23.40625], [68.42930603, 23.40625], [68.42930603, 23.40653038], [68.42903137, 23.40653038], [68.42903137, 23.40681076], [68.42930603, 23.40680313], [68.42930603, 23.40708542], [68.42986298, 23.40708542]]], [[[68.4631958, 23.40903091], [68.4631958, 23.40681076], [68.46347046, 23.40681076], [68.46347046, 23.40625], [68.46376038, 23.40625], [68.46375275, 23.40597153], [68.4640274, 23.40597153], [68.4640274, 23.40569305], [68.46430206, 23.40570068], [68.46430206, 23.40542984], [68.46457672, 23.40542984], [68.46457672, 23.40514183], [68.4631958, 23.40514183], [68.4631958, 23.40542984], [68.46235657, 23.40542984], [68.46235657, 23.40570068], [68.46208191, 23.40569305], [68.46208191, 23.40597153], [68.46180725, 23.40596962], [68.46180725, 23.40625], [68.46153259, 23.40625], [68.46153259, 23.40681076], [68.46180725, 23.40681076], [68.46180725, 23.40764046], [68.46208191, 23.40763855], [68.46208191, 23.4081955], [68.46235657, 23.40818024], [68.46235657, 23.40875053], [68.46263885, 23.40875053], [68.46263885, 23.40903091], [68.4631958, 23.40903091]]], [[[68.46069336, 23.41263962], [68.46069336, 23.41236115], [68.46180725, 23.41236115], [68.46180725, 23.41208076], [68.46208191, 23.41208267], [68.46208191, 23.41180611], [68.46235657, 23.41180992], [68.46235657, 23.41152954], [68.46263885, 23.41152954], [68.46263885, 23.41123962], [68.46291351, 23.41124916], [68.46291351, 23.4109726], [68.46125031, 23.4109726], [68.46125031, 23.41124916], [68.46070099, 23.41123962], [68.46070099, 23.41152954], [68.46013641, 23.41152954], [68.46013641, 23.41180992], [68.45996094, 23.41180611], [68.45929718, 23.41180992], [68.45929718, 23.41152954], [68.45903015, 23.41152954], [68.45903015, 23.41123962], [68.45791626, 23.41124916], [68.45791626, 23.41208267], [68.45847321, 23.41208076], [68.45847321, 23.41236115], [68.45903015, 23.41236115], [68.45903015, 23.41263962], [68.46024323, 23.41263962], [68.46069336, 23.41263962]]], [[[68.31346893, 23.5834713], [68.30986023, 23.5834713], [68.30986023, 23.58319664], [68.30902863, 23.58319664], [68.30902863, 23.58291435], [68.30847168, 23.58291435], [68.30847168, 23.58319664], [68.30874634, 23.58319664], [68.30874634, 23.5834713], [68.30902863, 23.58346939], [68.30902863, 23.58374977], [68.30930328, 23.58374977], [68.30930328, 23.58403015], [68.30986023, 23.58402824], [68.30986023, 23.58430672], [68.31014252, 23.58430672], [68.31014252, 23.58486176], [68.30986023, 23.58485985], [68.30986023, 23.58569908], [68.30958557, 23.58569527], [68.30958557, 23.58597183], [68.30930328, 23.58596992], [68.30930328, 23.58625031], [68.30902863, 23.58625031], [68.30902863, 23.58653069], [68.30819702, 23.58653069], [68.30819702, 23.58680916], [68.30706787, 23.58680916], [68.30706787, 23.58653069], [68.30652618, 23.58653069], [68.30652618, 23.58736038], [68.30625153, 23.58736038], [68.30625153, 23.58847237], [68.30596924, 23.58847237], [68.30596924, 23.58958244], [68.30569458, 23.58958244], [68.30569458, 23.59069443], [68.30541992, 23.59069061], [68.30541992, 23.59153175], [68.30513763, 23.59152794], [68.30513763, 23.59208107], [68.30486298, 23.59208107], [68.30486298, 23.59263992], [68.30458069, 23.59263802], [68.30458069, 23.5956955], [68.30432129, 23.59568977], [68.30432129, 23.59653091], [68.30374908, 23.59653091], [68.30374908, 23.59597015], [68.30347443, 23.59597206], [68.30347443, 23.59541512], [68.30319214, 23.59542084], [68.30319214, 23.59485054], [68.30291748, 23.59486389], [68.30291748, 23.59458542], [68.30263519, 23.59458542], [68.30263519, 23.59402847], [68.30236053, 23.59403038], [68.30236053, 23.59375], [68.30208588, 23.59375], [68.30208588, 23.59346962], [68.30152893, 23.59347153], [68.30152893, 23.59319305], [68.3012619, 23.59320068], [68.3012619, 23.5929203], [68.30069733, 23.5929203], [68.30069733, 23.59263992], [68.30042267, 23.59263992], [68.30042267, 23.59208107], [68.30014038, 23.59208107], [68.30014038, 23.59180641], [68.29985809, 23.59181023], [68.29985809, 23.59124947], [68.29957581, 23.59124947], [68.29957581, 23.59069061], [68.29985809, 23.59069443], [68.29985809, 23.59013939], [68.30014038, 23.59013939], [68.30014038, 23.5893116], [68.30042267, 23.5893116], [68.30042267, 23.58875084], [68.30014038, 23.58875084], [68.30014038, 23.58847046], [68.29985809, 23.58847237], [68.29985809, 23.58819389], [68.29958344, 23.58819389], [68.29958344, 23.58791733], [68.29985809, 23.58791924], [68.29985809, 23.58736038], [68.30014038, 23.58736038], [68.30014038, 23.58707809], [68.30041504, 23.58708382], [68.30041504, 23.58680534], [68.30069733, 23.58680916], [68.30069733, 23.58653069], [68.30180359, 23.58652878], [68.30180359, 23.58708382], [68.30263519, 23.58708382], [68.30263519, 23.58680534], [68.30291748, 23.58680916], [68.30291748, 23.58653069], [68.30432129, 23.58653069], [68.30432129, 23.58514023], [68.30458069, 23.58514023], [68.30458069, 23.58485985], [68.30735779, 23.58486176], [68.30735779, 23.58430672], [68.30764008, 23.58430672], [68.30764008, 23.58402824], [68.30706787, 23.58403015], [68.30706787, 23.58374977], [68.30625153, 23.58374977], [68.30625153, 23.58346939], [68.30458069, 23.58346939], [68.30458069, 23.58374977], [68.3034668, 23.58374977], [68.3034668, 23.58403015], [68.30263519, 23.58402824], [68.30263519, 23.58430672], [68.30069733, 23.58430672], [68.30069733, 23.58208466], [68.30041504, 23.58208466], [68.30041504, 23.58180428], [68.30014038, 23.58181], [68.30014038, 23.58152962], [68.29985809, 23.58152962], [68.29985809, 23.58125114], [68.29957581, 23.58125114], [68.29957581, 23.58097076], [68.29930878, 23.58097458], [68.29930878, 23.58069229], [68.29846954, 23.58069229], [68.29846954, 23.58041573], [68.29792023, 23.58041954], [68.29792023, 23.58014107], [68.29708099, 23.58014107], [68.29708099, 23.57987022], [68.29651642, 23.57987022], [68.29651642, 23.57958031], [68.29597473, 23.57958221], [68.29597473, 23.57930565], [68.29541779, 23.57930946], [68.29541779, 23.5790329], [68.29486084, 23.5790329], [68.29486084, 23.57875061], [68.29096985, 23.57875061], [68.29096985, 23.5790329], [68.28903198, 23.5790329], [68.28903198, 23.57930946], [68.28819275, 23.57930565], [68.28819275, 23.57958221], [68.2876358, 23.57958031], [68.2876358, 23.57987022], [68.28679657, 23.57987022], [68.28679657, 23.58014107], [68.28624725, 23.58014107], [68.28624725, 23.58041954], [68.28569794, 23.58041573], [68.28569794, 23.58069229], [68.28541565, 23.58069229], [68.28541565, 23.58097458], [68.2848587, 23.58097076], [68.2848587, 23.58125114], [68.28457642, 23.58125114], [68.28457642, 23.58152962], [68.28430176, 23.58152771], [68.28430176, 23.58208466], [68.2840271, 23.58208084], [68.2840271, 23.58263969], [68.28347015, 23.58263969], [68.28347015, 23.58291435], [68.2831955, 23.58291435], [68.2831955, 23.58319664], [68.28289795, 23.58319092], [68.28289795, 23.58374977], [68.28235626, 23.58374977], [68.28235626, 23.58291054], [68.2820816, 23.58291435], [68.2820816, 23.58236122], [68.28069305, 23.58236122], [68.28069305, 23.58263969], [68.2804184, 23.58263969], [68.2804184, 23.58291435], [68.28013611, 23.58291435], [68.28013611, 23.58319664], [68.27986145, 23.58319664], [68.27986145, 23.5834713], [68.27958679, 23.58346939], [68.27958679, 23.58374977], [68.27902985, 23.58374977], [68.27902985, 23.58403015], [68.27874756, 23.58402824], [68.27874756, 23.58430672], [68.2784729, 23.58430672], [68.2784729, 23.58458328], [68.27819824, 23.58458328], [68.27819061, 23.58486176], [68.27791595, 23.58485985], [68.27791595, 23.58514023], [68.2776413, 23.58514023], [68.2776413, 23.58542061], [68.27735901, 23.58542061], [68.27735901, 23.58569908], [68.27708435, 23.58569527], [68.27709198, 23.58625031], [68.27680206, 23.58625031], [68.27680206, 23.58653069], [68.2765274, 23.58653069], [68.2765274, 23.58680916], [68.27625275, 23.58680916], [68.27625275, 23.58736038], [68.27597046, 23.58736038], [68.27597046, 23.58847237], [68.2756958, 23.58847046], [68.2756958, 23.58902931], [68.27541351, 23.5890274], [68.27541351, 23.58958244], [68.27513885, 23.58958054], [68.27513885, 23.59013939], [68.2748642, 23.59013939], [68.2748642, 23.59069443], [68.27458191, 23.59069061], [68.27458191, 23.59181023], [68.27430725, 23.59181023], [68.27430725, 23.59375], [68.27458191, 23.59375], [68.27458191, 23.59431076], [68.27485657, 23.59431076], [68.27485657, 23.59542084], [68.27513885, 23.59541512], [68.27513885, 23.5956955], [68.27540588, 23.59568977], [68.27540588, 23.59625053], [68.2756958, 23.59625053], [68.2756958, 23.59653091], [68.27597046, 23.59652519], [68.27597046, 23.59708595], [68.27625275, 23.59708023], [68.27625275, 23.59736061], [68.27819824, 23.59736061], [68.27819824, 23.59708023], [68.27902985, 23.59708595], [68.27902985, 23.59652519], [68.27929688, 23.59653091], [68.27929688, 23.59542084], [68.27958679, 23.59542084], [68.27958679, 23.5945797], [68.2793045, 23.59458542], [68.2793045, 23.59375], [68.27902985, 23.59375], [68.27902985, 23.5929203], [68.27874756, 23.5929203], [68.27874756, 23.59181023], [68.2784729, 23.59181023], [68.2784729, 23.59069061], [68.27819824, 23.59069443], [68.27819824, 23.58986092], [68.2784729, 23.58986092], [68.2784729, 23.58958054], [68.27902985, 23.58958244], [68.27902985, 23.58930588], [68.27929688, 23.5893116], [68.27929688, 23.58902931], [68.27958679, 23.58902931], [68.27958679, 23.58875084], [68.28013611, 23.58875084], [68.28015137, 23.59013939], [68.27986145, 23.59013939], [68.27986145, 23.59153175], [68.28015137, 23.59153175], [68.28015137, 23.59263992], [68.2804184, 23.59263992], [68.2804184, 23.59375], [68.28069305, 23.59375], [68.28069305, 23.59458542], [68.28098297, 23.5945797], [68.28098297, 23.59542084], [68.28125, 23.59541512], [68.28125, 23.59597206], [68.28152466, 23.59597206], [68.28152466, 23.59708595], [68.28180695, 23.59708595], [68.28180695, 23.5984726], [68.2820816, 23.59847069], [68.2820816, 23.59930992], [68.28236389, 23.59930611], [68.28236389, 23.59958267], [68.28263855, 23.59958076], [68.28263855, 23.60013962], [68.28289795, 23.60013962], [68.28289795, 23.60041809], [68.2831955, 23.60041618], [68.2831955, 23.60069466], [68.28375244, 23.60069084], [68.28375244, 23.60098076], [68.2840271, 23.60098076], [68.2840271, 23.60124969], [68.28708649, 23.60124969], [68.28708649, 23.60098076], [68.28819275, 23.60098076], [68.28819275, 23.60069084], [68.28902435, 23.60069466], [68.28902435, 23.60041618], [68.2895813, 23.60041809], [68.2895813, 23.60013962], [68.2904129, 23.60013962], [68.2904129, 23.59986115], [68.29096985, 23.59986115], [68.29096985, 23.59958076], [68.2923584, 23.59958076], [68.2923584, 23.60013962], [68.29264069, 23.60013962], [68.29264069, 23.60069466], [68.2923584, 23.60069084], [68.2923584, 23.60098076], [68.29096985, 23.60098076], [68.29096985, 23.60152817], [68.29069519, 23.60152817], [68.29069519, 23.60208321], [68.2904129, 23.60207748], [68.2904129, 23.60263824], [68.2893219, 23.60263824], [68.2893219, 23.60292244], [68.28848267, 23.60292244], [68.28848267, 23.60320282], [68.28819275, 23.60319519], [68.28819275, 23.60347176], [68.28791809, 23.60347176], [68.28791809, 23.60375023], [68.2876358, 23.60375023], [68.2876358, 23.60404015], [68.28736115, 23.60404015], [68.28736115, 23.6043129], [68.2868042, 23.60430527], [68.2868042, 23.60458374], [68.28652954, 23.60458183], [68.28652954, 23.60486031], [68.28624725, 23.60486031], [68.28624725, 23.60514259], [68.28457642, 23.60514259], [68.28457642, 23.60542107], [68.28430176, 23.60541725], [68.28430176, 23.60569382], [68.28347015, 23.60569382], [68.28347015, 23.60597229], [68.28289795, 23.60597038], [68.28289795, 23.60625076], [68.28125, 23.60625076], [68.28125, 23.60653114], [68.28151703, 23.60653114], [68.28151703, 23.60736084], [68.28180695, 23.60736084], [68.28180695, 23.60764122], [68.28235626, 23.60764122], [68.28235626, 23.60736084], [68.28347015, 23.60736084], [68.28347015, 23.60764122], [68.28375244, 23.60764122], [68.28375244, 23.60791969], [68.28514099, 23.60791969], [68.28514099, 23.60764122], [68.28542328, 23.60764122], [68.28542328, 23.60736084], [68.2859726, 23.60736084], [68.2859726, 23.60708046], [68.28624725, 23.60708237], [68.28624725, 23.6068058], [68.28679657, 23.60680962], [68.28679657, 23.60653114], [68.28708649, 23.60653114], [68.28708649, 23.60625076], [68.2876358, 23.60625076], [68.2876358, 23.60597038], [68.28819275, 23.60597038], [68.28819275, 23.60625076], [68.28791809, 23.60625076], [68.28791809, 23.60708237], [68.2876358, 23.60708046], [68.2876358, 23.60764122], [68.28736115, 23.60763931], [68.28736115, 23.60847473], [68.28652954, 23.60847092], [68.28652954, 23.60874939], [68.2859726, 23.60874939], [68.2859726, 23.60902977], [68.28569794, 23.60902786], [68.28569794, 23.61097145], [68.2848587, 23.61097145], [68.2848587, 23.61069679], [68.28430176, 23.61069107], [68.28430176, 23.61181068], [68.28375244, 23.61181068], [68.28375244, 23.6115303], [68.28347015, 23.6115303], [68.28347015, 23.61124992], [68.28289795, 23.61124992], [68.28289795, 23.6115303], [68.28263855, 23.6115303], [68.28263855, 23.61264038], [68.28235626, 23.61264038], [68.28235626, 23.61375046], [68.2820816, 23.61375046], [68.2820816, 23.61403084], [68.28125, 23.61403084], [68.28125, 23.61346817], [68.28097534, 23.61347198], [68.28097534, 23.61291885], [68.28069305, 23.61292076], [68.28069305, 23.61236], [68.2804184, 23.61236191], [68.2804184, 23.61180687], [68.27958679, 23.61181068], [68.27958679, 23.6115303], [68.27929688, 23.6115303], [68.27929688, 23.61124992], [68.27874756, 23.61124992], [68.27874756, 23.61096954], [68.2784729, 23.61097145], [68.2784729, 23.61069679], [68.27819824, 23.61069679], [68.27819824, 23.60986137], [68.27791595, 23.60986137], [68.27791595, 23.61097145], [68.2776413, 23.61096954], [68.2776413, 23.61124992], [68.27735901, 23.61124992], [68.27735901, 23.6115303], [68.27709198, 23.6115303], [68.27709198, 23.61181068], [68.27680206, 23.61180687], [68.27680206, 23.61208344], [68.2765274, 23.61208344], [68.2765274, 23.61236191], [68.27625275, 23.61236], [68.27625275, 23.61264038], [68.27597046, 23.61264038], [68.27597046, 23.61292076], [68.2756958, 23.61291885], [68.2756958, 23.61319351], [68.27540588, 23.6131897], [68.27540588, 23.61375046], [68.27513885, 23.61375046], [68.27513885, 23.61430931], [68.27485657, 23.61430931], [68.27485657, 23.61486053], [68.27458191, 23.61486053], [68.27458191, 23.61541939], [68.27430725, 23.61541939], [68.27430725, 23.61598015], [68.27403259, 23.61598015], [68.27403259, 23.61624908], [68.27375031, 23.61624908], [68.27375031, 23.61681175], [68.27347565, 23.61680603], [68.27348328, 23.61735916], [68.27319336, 23.61735916], [68.27319336, 23.61792183], [68.2729187, 23.61792183], [68.2729187, 23.61874962], [68.27263641, 23.61874962], [68.27263641, 23.62070084], [68.2729187, 23.62070084], [68.2729187, 23.62181091], [68.27319336, 23.62180328], [68.27319336, 23.62208557], [68.27348328, 23.62207985], [68.27348328, 23.62264061], [68.27375031, 23.6226387], [68.27375031, 23.62319565], [68.27402496, 23.62319565], [68.27402496, 23.62375069], [68.27430725, 23.62375069], [68.27430725, 23.62430954], [68.27458191, 23.62430954], [68.27458191, 23.62486076], [68.27485657, 23.62486076], [68.27485657, 23.62541962], [68.27513885, 23.62541771], [68.27513885, 23.62569427], [68.27541351, 23.62569427], [68.27541351, 23.62597275], [68.2756958, 23.62597084], [68.2756958, 23.62652969], [68.27597046, 23.62652969], [68.27597046, 23.62680817], [68.27625275, 23.62680626], [68.27625275, 23.6273613], [68.2765274, 23.6273613], [68.2765274, 23.62819481], [68.27680206, 23.62818909], [68.27680206, 23.62874985], [68.27708435, 23.62874985], [68.27708435, 23.62930489], [68.27735901, 23.62930489], [68.27735901, 23.62986183], [68.2776413, 23.62986183], [68.2776413, 23.63042259], [68.27791595, 23.63042259], [68.27791595, 23.63125038], [68.2784729, 23.63125038], [68.2784729, 23.63097954], [68.27902985, 23.63097954], [68.27902985, 23.63070107], [68.27958679, 23.63070107], [68.27958679, 23.63042259], [68.28015137, 23.63042259], [68.28015137, 23.6301403], [68.28069305, 23.6301403], [68.28069305, 23.62986183], [68.28097534, 23.62986183], [68.28097534, 23.62958336], [68.28152466, 23.62958336], [68.28152466, 23.62930489], [68.2820816, 23.62930489], [68.2820816, 23.62902832], [68.28263855, 23.62902832], [68.28263855, 23.62874985], [68.28289795, 23.62874985], [68.28289795, 23.62846756], [68.28347015, 23.62847137], [68.28347015, 23.62819481], [68.28458405, 23.62819481], [68.28458405, 23.62791634], [68.28542328, 23.62791824], [68.28542328, 23.62763977], [68.28652954, 23.62763977], [68.28652954, 23.62735939], [68.2895813, 23.62735939], [68.2895813, 23.62763977], [68.29096985, 23.62763977], [68.29096985, 23.62791824], [68.2923584, 23.62791634], [68.2923584, 23.62819481], [68.29347229, 23.62819481], [68.29347229, 23.62847137], [68.29429626, 23.62846756], [68.29429626, 23.62874985], [68.29541779, 23.62874985], [68.29541779, 23.62902832], [68.29708099, 23.62902832], [68.29708099, 23.62930489], [68.29846954, 23.62930489], [68.29846954, 23.62958336], [68.30014038, 23.62958336], [68.30014038, 23.62986183], [68.30152893, 23.62986183], [68.30152893, 23.6301403], [68.30458069, 23.6301403], [68.30458069, 23.62986183], [68.30541992, 23.62986183], [68.30541992, 23.62958336], [68.30625153, 23.62958336], [68.30625153, 23.62930489], [68.30652618, 23.62930489], [68.30652618, 23.62874985], [68.30680847, 23.62874985], [68.30680847, 23.62791824], [68.30706787, 23.62791824], [68.30706787, 23.62763977], [68.30735779, 23.62763977], [68.30735779, 23.62735939], [68.30764008, 23.6273613], [68.30764008, 23.62708282], [68.30791473, 23.62708282], [68.30791473, 23.62680626], [68.30819702, 23.62680817], [68.30819702, 23.62652969], [68.30847168, 23.62652969], [68.30847168, 23.62625122], [68.30902863, 23.62625122], [68.30902863, 23.62597084], [68.30930328, 23.62597275], [68.30930328, 23.62541771], [68.3095932, 23.62541962], [68.3095932, 23.62514114], [68.31012726, 23.62514114], [68.31012726, 23.62486076], [68.31069183, 23.62486076], [68.31069183, 23.62458038], [68.31124878, 23.6245842], [68.31124878, 23.62430763], [68.31153107, 23.62430954], [68.31153107, 23.62403107], [68.31181335, 23.62403107], [68.31181335, 23.62375069], [68.31208038, 23.62375069], [68.31208038, 23.62347031], [68.31236267, 23.62347221], [68.31236267, 23.62319565], [68.31263733, 23.62319565], [68.31263733, 23.62291527], [68.31291962, 23.62292099], [68.31291962, 23.62264061], [68.3132019, 23.62264061], [68.3132019, 23.62236023], [68.31375122, 23.62236023], [68.31375122, 23.62264061], [68.31402588, 23.62264061], [68.31402588, 23.62292099], [68.31375122, 23.62291527], [68.31375122, 23.62319565], [68.31319427, 23.62319565], [68.3132019, 23.62375069], [68.31291962, 23.62375069], [68.31291962, 23.62403107], [68.31263733, 23.62403107], [68.31263733, 23.62430954], [68.31236267, 23.62430763], [68.31236267, 23.6245842], [68.31180573, 23.6245842], [68.31181335, 23.62486076], [68.31153107, 23.62486076], [68.31153107, 23.62514114], [68.31124878, 23.62514114], [68.31124878, 23.62541962], [68.31069183, 23.62541771], [68.31069183, 23.62569427], [68.31014252, 23.62569427], [68.31014252, 23.62597275], [68.30986023, 23.62597084], [68.30986023, 23.62652969], [68.3095932, 23.62652969], [68.3095932, 23.62680817], [68.30902863, 23.62680626], [68.30902863, 23.62708282], [68.30874634, 23.62708282], [68.30874634, 23.6273613], [68.30847168, 23.62735939], [68.30847168, 23.62763977], [68.30819702, 23.62763977], [68.30819702, 23.62791824], [68.30791473, 23.62791634], [68.30791473, 23.62819481], [68.30764008, 23.62818909], [68.30764008, 23.62874985], [68.30735779, 23.62874985], [68.30735779, 23.62930489], [68.30706787, 23.62929916], [68.30706787, 23.6301403], [68.30680847, 23.6301403], [68.30680847, 23.63070107], [68.30403137, 23.63070107], [68.30403137, 23.63097954], [68.3012619, 23.63097954], [68.3012619, 23.63070107], [68.29818726, 23.63070107], [68.29818726, 23.63042259], [68.29736328, 23.63042259], [68.29736328, 23.6301403], [68.29651642, 23.6301403], [68.29651642, 23.62986183], [68.29541779, 23.62986183], [68.29541779, 23.62958336], [68.29430389, 23.62958336], [68.29430389, 23.62930489], [68.29347229, 23.62930489], [68.29347229, 23.62902832], [68.2923584, 23.62902832], [68.2923584, 23.62874985], [68.28819275, 23.62874985], [68.28819275, 23.62902832], [68.28736115, 23.62902832], [68.28736115, 23.62930489], [68.28652954, 23.62930489], [68.28652954, 23.62958336], [68.2859726, 23.62958336], [68.2859726, 23.62986183], [68.28514099, 23.62986183], [68.28514099, 23.6301403], [68.28457642, 23.6301403], [68.28457642, 23.63042259], [68.2840271, 23.63042259], [68.2840271, 23.63070107], [68.28347015, 23.63070107], [68.28347015, 23.63097954], [68.28318787, 23.63097954], [68.28318787, 23.63125038], [68.28263855, 23.63125038], [68.28263855, 23.63153267], [68.2820816, 23.63153267], [68.2820816, 23.63181114], [68.28152466, 23.63180542], [68.28152466, 23.63208389], [68.28013611, 23.63208389], [68.28015137, 23.63236046], [68.27958679, 23.63236046], [68.27958679, 23.63264275], [68.27709198, 23.63264275], [68.27709198, 23.63236046], [68.27680206, 23.63236046], [68.27680206, 23.63208008], [68.2765274, 23.63208389], [68.2765274, 23.63180542], [68.27625275, 23.63181114], [68.27625275, 23.63153267], [68.27597046, 23.63153267], [68.27597046, 23.63070107], [68.2756958, 23.63070107], [68.2756958, 23.62929916], [68.27597046, 23.62930489], [68.27597046, 23.62874985], [68.2756958, 23.62874985], [68.2756958, 23.62818909], [68.27541351, 23.62819481], [68.27541351, 23.62791634], [68.27513885, 23.62791824], [68.27513885, 23.62763977], [68.27485657, 23.62763977], [68.27485657, 23.62735939], [68.27430725, 23.6273613], [68.27430725, 23.62708282], [68.27402496, 23.62708282], [68.27402496, 23.62680626], [68.27375031, 23.62680817], [68.27375031, 23.62652969], [68.27263641, 23.62652969], [68.27263641, 23.62625122], [68.2720871, 23.62625122], [68.2720871, 23.62597084], [68.27153015, 23.62597275], [68.27153015, 23.62569427], [68.27124786, 23.62569427], [68.27124786, 23.62541771], [68.27069092, 23.62541962], [68.27069092, 23.62514114], [68.2701416, 23.62514114], [68.2701416, 23.62486076], [68.26985931, 23.62486076], [68.26985931, 23.62430954], [68.26957703, 23.62430954], [68.26957703, 23.62403107], [68.26930237, 23.62403107], [68.26930237, 23.62347031], [68.26902771, 23.62347221], [68.26902771, 23.62291527], [68.26875305, 23.62292099], [68.26875305, 23.62236023], [68.26847076, 23.62236023], [68.26847076, 23.62181091], [68.26821136, 23.62181091], [68.26821136, 23.62096977], [68.26791382, 23.62097168], [68.26791382, 23.62069321], [68.26763916, 23.62070084], [68.26763916, 23.62042046], [68.26735687, 23.62042046], [68.26735687, 23.62014008], [68.26708221, 23.62014008], [68.26708221, 23.6198597], [68.2673645, 23.6198616], [68.2673645, 23.61958122], [68.26791382, 23.61958122], [68.26791382, 23.61930466], [68.26819611, 23.61930466], [68.26819611, 23.61819458], [68.26847076, 23.61819458], [68.26847076, 23.61680603], [68.26875305, 23.61681175], [68.26875305, 23.61514091], [68.26902771, 23.61514091], [68.26902771, 23.61403084], [68.26930237, 23.61403084], [68.26930237, 23.61292076], [68.26957703, 23.61292076], [68.26957703, 23.60984993], [68.26930237, 23.60986137], [68.26930237, 23.60874939], [68.26902771, 23.60874939], [68.26902771, 23.60764122], [68.26875305, 23.60764122], [68.26875305, 23.60708046], [68.26847076, 23.60708237], [68.26847076, 23.6068058], [68.26821136, 23.60680962], [68.26821136, 23.60653114], [68.26763916, 23.60653114], [68.26763916, 23.60625076], [68.26735687, 23.60625076], [68.26735687, 23.60597038], [68.26708221, 23.60597229], [68.26708221, 23.60569382], [68.26680756, 23.60569382], [68.26680756, 23.60541725], [68.2665329, 23.60542107], [68.2665329, 23.60514259], [68.26625061, 23.60514259], [68.26625061, 23.60486031], [68.26597595, 23.60486031], [68.26597595, 23.60458183], [68.26569366, 23.60458374], [68.26569366, 23.60430527], [68.26541901, 23.6043129], [68.26541901, 23.60375023], [68.26513672, 23.60375023], [68.26513672, 23.60347176], [68.26486206, 23.60347176], [68.26486206, 23.60319519], [68.26457977, 23.60320282], [68.26457977, 23.60292244], [68.26431274, 23.60292244], [68.26431274, 23.60263824], [68.26403046, 23.60263824], [68.26403046, 23.60235977], [68.25986481, 23.60236168], [68.25986481, 23.60208321], [68.25902557, 23.60208321], [68.25902557, 23.60180473], [68.25819397, 23.60180473], [68.25819397, 23.60152817], [68.25736237, 23.60152817], [68.25736237, 23.60124969], [68.25653076, 23.60124969], [68.25653076, 23.60069084], [68.25624847, 23.60069466], [68.25624847, 23.60041618], [68.25569153, 23.60041618], [68.25569153, 23.60069466], [68.2545929, 23.60069084], [68.2545929, 23.60098076], [68.25402832, 23.60098076], [68.25402832, 23.60124969], [68.25347137, 23.60124969], [68.25347137, 23.60152817], [68.25291443, 23.60152817], [68.25291443, 23.60180473], [68.25235748, 23.60180473], [68.25235748, 23.60208321], [68.25180817, 23.60208321], [68.25180817, 23.60236168], [68.25125122, 23.60235977], [68.25125122, 23.60263824], [68.25068665, 23.60263824], [68.25068665, 23.60292244], [68.24958038, 23.60292244], [68.24958038, 23.60320282], [68.24847412, 23.60319519], [68.24847412, 23.60347176], [68.24736023, 23.60347176], [68.24736023, 23.60375023], [68.24652863, 23.60375023], [68.24652863, 23.60404015], [68.2454071, 23.60404015], [68.2454071, 23.6043129], [68.24514008, 23.6043129], [68.24514008, 23.60514259], [68.24485779, 23.60514259], [68.24485779, 23.60542107], [68.24458313, 23.60541725], [68.24458313, 23.60569382], [68.24485779, 23.60569382], [68.24485779, 23.60597229], [68.24514008, 23.60597038], [68.24514008, 23.60625076], [68.2454071, 23.60625076], [68.2454071, 23.60653114], [68.24375153, 23.60653114], [68.24375153, 23.60625076], [68.24208069, 23.60625076], [68.24208069, 23.60597038], [68.24263763, 23.60597229], [68.24263763, 23.60569382], [68.24319458, 23.60569382], [68.24319458, 23.60541725], [68.24263763, 23.60542107], [68.24263763, 23.60514259], [68.24180603, 23.60514259], [68.24180603, 23.60458183], [68.24208069, 23.60458374], [68.24208069, 23.60430527], [68.24236298, 23.6043129], [68.24236298, 23.60375023], [68.24208069, 23.60375023], [68.24208069, 23.60347176], [68.24180603, 23.60347176], [68.24180603, 23.60319519], [68.24153137, 23.60320282], [68.24153137, 23.60292244], [68.24124908, 23.60292244], [68.24124908, 23.60263824], [68.24098206, 23.60263824], [68.24098206, 23.60235977], [68.24069214, 23.60236168], [68.24069214, 23.60208321], [68.24041748, 23.60208321], [68.24041748, 23.60180473], [68.24013519, 23.60180473], [68.24013519, 23.60124969], [68.23986053, 23.60124969], [68.23986053, 23.60098076], [68.23958588, 23.60098076], [68.23958588, 23.60069084], [68.23930359, 23.60069466], [68.23930359, 23.60041618], [68.23958588, 23.60041809], [68.23958588, 23.60013962], [68.23986053, 23.60013962], [68.23986053, 23.59986115], [68.24041748, 23.59986115], [68.24041748, 23.59958076], [68.24069214, 23.59958267], [68.24069214, 23.59930611], [68.24124908, 23.59930992], [68.24124908, 23.59902954], [68.24153137, 23.59902954], [68.24153137, 23.59875107], [68.24180603, 23.59875107], [68.24180603, 23.59847069], [68.24236298, 23.5984726], [68.24236298, 23.59819412], [68.24263763, 23.59819412], [68.24263763, 23.59791756], [68.24319458, 23.59791756], [68.24319458, 23.59763908], [68.24346924, 23.59764099], [68.24346924, 23.59736061], [68.24401855, 23.59736061], [68.24401855, 23.59708023], [68.24430847, 23.59708595], [68.24430847, 23.59680367], [68.24458313, 23.59680939], [68.24458313, 23.59653091], [68.24514008, 23.59653091], [68.24514008, 23.59625053], [68.2454071, 23.59625053], [68.2454071, 23.59597015], [68.24597168, 23.59597206], [68.24597168, 23.5956955], [68.24624634, 23.5956955], [68.24624634, 23.59541512], [68.24678802, 23.59542084], [68.24678802, 23.59514046], [68.24707794, 23.59514046], [68.24707794, 23.59485054], [68.24764252, 23.59486389], [68.24764252, 23.59458542], [68.24791718, 23.59458542], [68.24791718, 23.59430313], [68.24846649, 23.59431076], [68.24846649, 23.59403038], [68.24874878, 23.59403038], [68.24874878, 23.59375], [68.25096893, 23.59375], [68.25096893, 23.59403038], [68.25125122, 23.59403038], [68.25125122, 23.59431076], [68.25152588, 23.59430313], [68.25152588, 23.59486389], [68.25180817, 23.59485054], [68.25180817, 23.59514046], [68.25208282, 23.59514046], [68.25208282, 23.59542084], [68.25235748, 23.59541512], [68.25235748, 23.5956955], [68.25263977, 23.5956955], [68.25263977, 23.59597206], [68.25319672, 23.59597206], [68.25319672, 23.59625053], [68.25347137, 23.59625053], [68.25347137, 23.59653091], [68.25374603, 23.59653091], [68.25374603, 23.59680939], [68.25541687, 23.59680939], [68.25541687, 23.59625053], [68.25569153, 23.59625053], [68.25569153, 23.59568977], [68.25624847, 23.5956955], [68.25624847, 23.59458542], [68.25569153, 23.59458542], [68.25569153, 23.59402847], [68.25541687, 23.59403038], [68.25541687, 23.59375], [68.25514221, 23.59375], [68.25514221, 23.59346962], [68.25485992, 23.59347153], [68.25485992, 23.59319305], [68.2545929, 23.59320068], [68.2545929, 23.5929203], [68.25430298, 23.5929203], [68.25430298, 23.59263992], [68.25402832, 23.59263992], [68.25402832, 23.59235954], [68.25319672, 23.59236145], [68.25319672, 23.59208107], [68.25235748, 23.59208107], [68.25235748, 23.59180641], [68.25180817, 23.59181023], [68.25180817, 23.59153175], [68.25125122, 23.59153175], [68.25125122, 23.59124947], [68.25068665, 23.59124947], [68.25068665, 23.59096909], [68.25013733, 23.5909729], [68.25013733, 23.59069443], [68.24736023, 23.59069443], [68.24736023, 23.59041595], [68.24485779, 23.59041595], [68.24485779, 23.59069443], [68.24458313, 23.59069443], [68.24458313, 23.5909729], [68.24430847, 23.59096909], [68.24430847, 23.59153175], [68.24458313, 23.59152794], [68.24458313, 23.59208107], [68.24430847, 23.59208107], [68.24430847, 23.59236145], [68.24401855, 23.59235954], [68.24401855, 23.5929203], [68.24375153, 23.5929203], [68.24375153, 23.59320068], [68.24346924, 23.59319305], [68.24346924, 23.59347153], [68.24318695, 23.59346962], [68.24318695, 23.59375], [68.24236298, 23.59375], [68.24236298, 23.59346962], [68.24180603, 23.59347153], [68.24180603, 23.59319305], [68.24098206, 23.59320068], [68.24098206, 23.5929203], [68.23986053, 23.5929203], [68.23986053, 23.59263992], [68.23902893, 23.59263992], [68.23902893, 23.59235954], [68.23847198, 23.59235954], [68.23847198, 23.59375], [68.23819733, 23.59375], [68.23819733, 23.59431076], [68.23791504, 23.59430313], [68.23791504, 23.59486389], [68.23819733, 23.59485054], [68.23819733, 23.59542084], [68.23764038, 23.59541512], [68.23764038, 23.5956955], [68.23680878, 23.5956955], [68.23680878, 23.59319305], [68.23652649, 23.59320068], [68.23652649, 23.59124947], [68.23625183, 23.59124947], [68.23625183, 23.59069061], [68.23542023, 23.59069443], [68.23542023, 23.59041595], [68.23430634, 23.59041595], [68.23430634, 23.59069443], [68.23401642, 23.59069061], [68.23401642, 23.59124947], [68.2334671, 23.59124947], [68.2334671, 23.59096909], [68.23319244, 23.5909729], [68.23319244, 23.59013939], [68.2334671, 23.59013939], [68.2334671, 23.58791924], [68.23319244, 23.58791924], [68.23319244, 23.58707809], [68.23291779, 23.58707809], [68.23291779, 23.58736038], [68.23264313, 23.58736038], [68.23264313, 23.58764076], [68.23236084, 23.58764076], [68.23236084, 23.58791924], [68.23180389, 23.58791733], [68.23180389, 23.58819389], [68.23152924, 23.58819389], [68.23152924, 23.58847237], [68.23097229, 23.58847046], [68.23097229, 23.58875084], [68.23069763, 23.58875084], [68.23069763, 23.58902931], [68.22735596, 23.58902931], [68.22735596, 23.5893116], [68.2270813, 23.58930588], [68.2270813, 23.58958244], [68.2251358, 23.58958244], [68.2251358, 23.58930588], [68.22458649, 23.5893116], [68.22458649, 23.58902931], [68.22290802, 23.58902931], [68.22290802, 23.5893116], [68.2223587, 23.58930588], [68.2223587, 23.58958244], [68.22180176, 23.58958054], [68.22180176, 23.58986092], [68.22125244, 23.58986092], [68.22125244, 23.59013939], [68.22097015, 23.59013939], [68.22097015, 23.59042168], [68.2206955, 23.59041595], [68.2206955, 23.59069443], [68.22041321, 23.59069443], [68.22041321, 23.5909729], [68.22013855, 23.59096909], [68.22013855, 23.59124947], [68.21984863, 23.59124947], [68.21984863, 23.59181023], [68.22013855, 23.59180641], [68.22013855, 23.59236145], [68.22041321, 23.59235954], [68.22041321, 23.59263992], [68.22070313, 23.59263992], [68.22070313, 23.59320068], [68.22097015, 23.59319305], [68.22097015, 23.59347153], [68.22125244, 23.59346962], [68.22125244, 23.59375], [68.2215271, 23.59375], [68.2215271, 23.59431076], [68.22180176, 23.59430313], [68.22180176, 23.59486389], [68.22207642, 23.59485054], [68.22207642, 23.59542084], [68.2223587, 23.59541512], [68.2223587, 23.5956955], [68.22264099, 23.5956955], [68.22264099, 23.59597206], [68.22290802, 23.59597015], [68.22290802, 23.59625053], [68.2234726, 23.59625053], [68.2234726, 23.59653091], [68.22402954, 23.59653091], [68.22402954, 23.59680939], [68.2243042, 23.59680367], [68.2243042, 23.59708595], [68.22486115, 23.59708023], [68.22486115, 23.59736061], [68.2251358, 23.59736061], [68.2251358, 23.59764099], [68.22541809, 23.59763908], [68.22541809, 23.59791756], [68.22569275, 23.59791756], [68.22569275, 23.5984726], [68.22541809, 23.59847069], [68.22541809, 23.59875107], [68.22486115, 23.59875107], [68.22486115, 23.59902954], [68.22458649, 23.59902954], [68.22458649, 23.59930992], [68.2243042, 23.59930611], [68.2243042, 23.59958267], [68.22402954, 23.59958076], [68.22402954, 23.59986115], [68.2234726, 23.59986115], [68.2234726, 23.60013962], [68.22374725, 23.60013962], [68.22374725, 23.60041809], [68.22402954, 23.60041809], [68.22402954, 23.60098076], [68.22429657, 23.60098076], [68.22429657, 23.60152817], [68.22402954, 23.60152817], [68.22402954, 23.60208321], [68.22374725, 23.60207748], [68.22374725, 23.60375023], [68.22402954, 23.60375023], [68.22402954, 23.60404015], [68.22458649, 23.60404015], [68.22458649, 23.6043129], [68.22486115, 23.60430527], [68.22486115, 23.60458374], [68.22624969, 23.60458374], [68.22624969, 23.60430527], [68.22651672, 23.6043129], [68.22651672, 23.60404015], [68.22763824, 23.60404015], [68.22763824, 23.6043129], [68.2279129, 23.60430527], [68.2279129, 23.60458374], [68.22763824, 23.60458183], [68.22763824, 23.60514259], [68.22736359, 23.60513878], [68.22736359, 23.60569382], [68.2270813, 23.60569382], [68.2270813, 23.60597229], [68.22680664, 23.60597038], [68.22680664, 23.60625076], [68.22624969, 23.60625076], [68.22624969, 23.60653114], [68.22598267, 23.60653114], [68.22598267, 23.60680962], [68.22486115, 23.60680962], [68.22486115, 23.60653114], [68.2223587, 23.60653114], [68.2223587, 23.60597038], [68.22264099, 23.60597229], [68.22264099, 23.60541725], [68.2223587, 23.60542107], [68.2223587, 23.60514259], [68.22207642, 23.60514259], [68.22207642, 23.60458183], [68.22180939, 23.60458374], [68.22180176, 23.60430527], [68.2215271, 23.6043129], [68.2215271, 23.60404015], [68.22097015, 23.60404015], [68.22097015, 23.60375023], [68.2195816, 23.60375023], [68.2195816, 23.6043129], [68.21930695, 23.60430527], [68.21930695, 23.60458374], [68.21901703, 23.60458183], [68.21901703, 23.60514259], [68.21875, 23.60514259], [68.21875, 23.60542107], [68.21819305, 23.60541725], [68.21819305, 23.60569382], [68.2179184, 23.60569382], [68.2179184, 23.60597229], [68.21736145, 23.60597038], [68.21736145, 23.60625076], [68.21652985, 23.60625076], [68.21652985, 23.60320282], [68.21624756, 23.60320282], [68.21624756, 23.60235977], [68.2159729, 23.60236168], [68.2159729, 23.60180473], [68.21569824, 23.60180473], [68.21569824, 23.60152817], [68.21541595, 23.60152817], [68.21541595, 23.60124969], [68.2151413, 23.60124969], [68.2151413, 23.60098076], [68.21457672, 23.60098076], [68.21457672, 23.60069084], [68.21404266, 23.60069084], [68.21404266, 23.60098076], [68.2123642, 23.60097313], [68.2123642, 23.60236168], [68.21152496, 23.60236168], [68.21152496, 23.60208321], [68.21125031, 23.60208321], [68.21125031, 23.60180473], [68.21069336, 23.60180473], [68.21069336, 23.60152817], [68.21013641, 23.60152817], [68.21013641, 23.60124969], [68.20929718, 23.60124969], [68.20929718, 23.60098076], [68.20874786, 23.60098076], [68.20874786, 23.60041809], [68.20903015, 23.60041809], [68.20903015, 23.59986115], [68.20790863, 23.59986115], [68.20790863, 23.60041809], [68.2076416, 23.60041809], [68.2076416, 23.60124969], [68.20735931, 23.60124969], [68.20735931, 23.60180473], [68.20708466, 23.60180473], [68.20708466, 23.60208321], [68.20541382, 23.60208321], [68.20541382, 23.60097313], [68.20569611, 23.60098076], [68.20569611, 23.59958076], [68.20541382, 23.59958267], [68.20541382, 23.59902763], [68.20569611, 23.59902954], [68.20569611, 23.59819031], [68.20541382, 23.59819412], [68.20541382, 23.59763908], [68.20513916, 23.59764099], [68.20513916, 23.59625053], [68.2048645, 23.59625053], [68.2048645, 23.59597206], [68.20458221, 23.59597206], [68.20458221, 23.5956955], [68.20430756, 23.5956955], [68.20430756, 23.59541512], [68.2040329, 23.59542084], [68.2040329, 23.59514046], [68.20375061, 23.59514046], [68.20375061, 23.59485054], [68.20347595, 23.59486389], [68.20347595, 23.59458542], [68.20236206, 23.59458542], [68.20236206, 23.59486389], [68.20181274, 23.59485054], [68.20181274, 23.59514046], [68.20153046, 23.59514046], [68.20153046, 23.59542084], [68.20097351, 23.59541512], [68.20097351, 23.5956955], [68.20069122, 23.5956955], [68.20069122, 23.59597206], [68.20014191, 23.59597015], [68.20014191, 23.59625053], [68.19985962, 23.59625053], [68.19985962, 23.59653091], [68.19902802, 23.59653091], [68.19902802, 23.59625053], [68.19847107, 23.59625053], [68.19847107, 23.59653091], [68.19790649, 23.59653091], [68.19790649, 23.59680939], [68.19763947, 23.59680367], [68.19763947, 23.59708595], [68.19708252, 23.59708595], [68.19708252, 23.59791756], [68.19735718, 23.59790993], [68.19735718, 23.59902954], [68.19708252, 23.59902954], [68.19708252, 23.59930992], [68.19680786, 23.59930611], [68.19680786, 23.59958267], [68.1965332, 23.59958076], [68.1965332, 23.60041809], [68.19625092, 23.60041809], [68.19625092, 23.60152817], [68.19596863, 23.60152817], [68.19596863, 23.60180473], [68.19569397, 23.60180473], [68.19569397, 23.60236168], [68.19541931, 23.60235977], [68.19541931, 23.60375023], [68.19513702, 23.60375023], [68.19513702, 23.60404015], [68.19486237, 23.60404015], [68.19486237, 23.6043129], [68.19430542, 23.60430527], [68.19431305, 23.60625076], [68.19403076, 23.60625076], [68.19403076, 23.60680962], [68.19374847, 23.6068058], [68.19374847, 23.60708237], [68.19346619, 23.60708046], [68.19346619, 23.60736084], [68.19319153, 23.60736084], [68.19319153, 23.60764122], [68.19264221, 23.60764122], [68.19264221, 23.60736084], [68.19208527, 23.60736084], [68.19208527, 23.60708237], [68.19124603, 23.60708046], [68.19124603, 23.60736084], [68.19097137, 23.60736084], [68.19097137, 23.60764122], [68.19069672, 23.60764122], [68.19069672, 23.60791969], [68.19041443, 23.60791588], [68.19041443, 23.60819244], [68.19013977, 23.60819244], [68.19013977, 23.60847473], [68.18985748, 23.60847473], [68.18987274, 23.60874939], [68.18958282, 23.60874939], [68.18958282, 23.60902977], [68.18930817, 23.60902977], [68.18930817, 23.60931015], [68.18902588, 23.60930634], [68.18902588, 23.60986137], [68.18875122, 23.60984993], [68.18875122, 23.61042023], [68.18846893, 23.61042023], [68.18846893, 23.61013985], [68.18818665, 23.61013985], [68.18818665, 23.61042023], [68.18791962, 23.61041451], [68.18791962, 23.61069679], [68.18763733, 23.61069679], [68.18763733, 23.61097145], [68.18736267, 23.61097145], [68.18736267, 23.61208344], [68.18708038, 23.61207962], [68.18708038, 23.61486053], [68.1867981, 23.61486053], [68.1867981, 23.61598015], [68.18653107, 23.61598015], [68.18653107, 23.61874962], [68.18624878, 23.61874962], [68.18624878, 23.62097168], [68.18653107, 23.62096977], [68.18653107, 23.62292099], [68.18624878, 23.62292099], [68.18624878, 23.62430954], [68.18653107, 23.62430954], [68.18653107, 23.62486076], [68.1867981, 23.62486076], [68.1867981, 23.62514114], [68.18708038, 23.62513924], [68.18708038, 23.62569427], [68.18736267, 23.62569427], [68.18736267, 23.62597275], [68.18763733, 23.62597084], [68.18763733, 23.62652969], [68.18791962, 23.62652779], [68.18791962, 23.62708282], [68.18819427, 23.62708282], [68.18819427, 23.62847137], [68.18846893, 23.62846756], [68.18846893, 23.62874985], [68.18875122, 23.62874985], [68.18875122, 23.62902832], [68.18902588, 23.62902832], [68.18902588, 23.62958336], [68.18930817, 23.62957764], [68.18930817, 23.6301403], [68.18958282, 23.6301403], [68.18958282, 23.63042259], [68.18987274, 23.63042259], [68.18987274, 23.63070107], [68.19013977, 23.63070107], [68.19013977, 23.63125038], [68.1904068, 23.63125038], [68.1904068, 23.63153267], [68.19069672, 23.63153267], [68.19069672, 23.63181114], [68.19097137, 23.63180542], [68.19097137, 23.63208389], [68.19124603, 23.63208008], [68.19124603, 23.63236046], [68.19152832, 23.63236046], [68.19152832, 23.63264275], [68.19180298, 23.63263893], [68.19180298, 23.63319206], [68.19208527, 23.63319206], [68.19208527, 23.63347244], [68.19235992, 23.63347054], [68.19235992, 23.63375282], [68.19264221, 23.63375282], [68.19264221, 23.63402748], [68.19293213, 23.63401985], [68.19293213, 23.63430977], [68.19319153, 23.63430405], [68.19319153, 23.63458252], [68.19291687, 23.63458252], [68.19291687, 23.63513947], [68.19346619, 23.63513947], [68.19346619, 23.63541985], [68.19403076, 23.63541412], [68.19403076, 23.63569641], [68.19430542, 23.63569641], [68.19430542, 23.63624954], [68.19458008, 23.63624954], [68.19458008, 23.6368103], [68.19486237, 23.63680649], [68.19486237, 23.63708305], [68.19513702, 23.63708305], [68.19513702, 23.63736153], [68.19567871, 23.63735962], [68.19567871, 23.63764], [68.19596863, 23.63763618], [68.19596863, 23.6384716], [68.19625092, 23.6384697], [68.19625092, 23.63875008], [68.1965332, 23.63875008], [68.1965332, 23.63903046], [68.19680786, 23.63903046], [68.19680786, 23.63931084], [68.19708252, 23.63930511], [68.19708252, 23.63958359], [68.19736481, 23.63958359], [68.19736481, 23.63986206], [68.19819641, 23.63986015], [68.19819641, 23.64014816], [68.19875336, 23.64013863], [68.19875336, 23.64069366], [68.19902802, 23.64068985], [68.19902802, 23.64152908], [68.19959259, 23.64152908], [68.19959259, 23.64181137], [68.19985962, 23.64180565], [68.19985962, 23.64208412], [68.20041656, 23.6420784], [68.20041656, 23.64236069], [68.20069122, 23.64236069], [68.20069122, 23.64291954], [68.20097351, 23.64291763], [68.20097351, 23.6431942], [68.20124817, 23.64318848], [68.20124817, 23.64374924], [68.20153046, 23.64374924], [68.20153046, 23.6443119], [68.20124817, 23.6443119], [68.20124817, 23.64486122], [68.20153046, 23.64486122], [68.20153046, 23.64513969], [68.20181274, 23.64513969], [68.20181274, 23.64542007], [68.20236206, 23.64541626], [68.20236206, 23.64569473], [68.20263672, 23.64569473], [68.20263672, 23.6459713], [68.20318604, 23.64596176], [68.20318604, 23.64653015], [68.20347595, 23.64652824], [68.20347595, 23.64680481], [68.20375061, 23.64680481], [68.20375061, 23.64708138], [68.20430756, 23.64708138], [68.20430756, 23.64736366], [68.20458221, 23.64735985], [68.20458221, 23.64764023], [68.20625305, 23.64764023], [68.20625305, 23.64735985], [68.2076416, 23.64736366], [68.2076416, 23.64680481], [68.20791626, 23.64680481], [68.20791626, 23.6459713], [68.20735931, 23.6459713], [68.20735931, 23.64569473], [68.20708466, 23.64569473], [68.20708466, 23.64541626], [68.20680237, 23.64542007], [68.20680237, 23.64513969], [68.20652771, 23.64513969], [68.20652771, 23.64486122], [68.20569611, 23.64486122], [68.20569611, 23.64458275], [68.2048645, 23.64458275], [68.2048645, 23.64430618], [68.20513916, 23.6443119], [68.20513916, 23.64402962], [68.20540619, 23.64402962], [68.20540619, 23.64374924], [68.20597076, 23.64374924], [68.20597076, 23.64347076], [68.20625305, 23.64347267], [68.20625305, 23.6431942], [68.20652771, 23.6431942], [68.20652771, 23.64291763], [68.20680237, 23.64291954], [68.20680237, 23.64236069], [68.20707703, 23.64236069], [68.20707703, 23.6420784], [68.20735931, 23.64208412], [68.20735931, 23.64180565], [68.20791626, 23.64180565], [68.20791626, 23.64208412], [68.20819092, 23.6420784], [68.20819092, 23.64263916], [68.20847321, 23.64263916], [68.20847321, 23.64291954], [68.20903015, 23.64291763], [68.20903015, 23.6431942], [68.2095871, 23.6431942], [68.2095871, 23.64347267], [68.21152496, 23.64347267], [68.21152496, 23.64291573], [68.21125031, 23.64291954], [68.21125031, 23.64236069], [68.21096802, 23.64236069], [68.21096802, 23.64181137], [68.2106781, 23.64181137], [68.2106781, 23.64125061], [68.2104187, 23.64125061], [68.2104187, 23.64068985], [68.21013641, 23.64069366], [68.21013641, 23.6404171], [68.21208191, 23.6404171], [68.21208191, 23.64069366], [68.2123642, 23.64069366], [68.2123642, 23.64097214], [68.21263885, 23.64097023], [68.21263885, 23.64152908], [68.21290588, 23.64152908], [68.21290588, 23.64181137], [68.2131958, 23.64180565], [68.2131958, 23.64208412], [68.21347046, 23.6420784], [68.21347046, 23.64263916], [68.21375275, 23.64263916], [68.21375275, 23.64291954], [68.2140274, 23.64291763], [68.2140274, 23.6431942], [68.21430206, 23.6431942], [68.21430206, 23.64291763], [68.21624756, 23.64291763], [68.21624756, 23.6431942], [68.21847534, 23.6431942], [68.21847534, 23.64347267], [68.21930695, 23.64347076], [68.21930695, 23.64374924], [68.21901703, 23.64374924], [68.21901703, 23.6443119], [68.21875, 23.64430618], [68.21875, 23.64458275], [68.21930695, 23.64458275], [68.21930695, 23.64486122], [68.2195816, 23.64486122], [68.2195816, 23.64513969], [68.21984863, 23.64513969], [68.21984863, 23.64542007], [68.22013855, 23.64541626], [68.22013855, 23.64569473], [68.22041321, 23.64569473], [68.22041321, 23.6459713], [68.22097015, 23.64596176], [68.22097015, 23.64624977], [68.2215271, 23.64624977], [68.2215271, 23.64653015], [68.22180176, 23.64652824], [68.22180176, 23.64680481], [68.2223587, 23.64680481], [68.2223587, 23.64708138], [68.22319794, 23.64708138], [68.22319794, 23.64680481], [68.2234726, 23.64680481], [68.2234726, 23.64624977], [68.22374725, 23.64624977], [68.22374725, 23.64596176], [68.22402954, 23.6459713], [68.22402954, 23.64541626], [68.22429657, 23.64542007], [68.22429657, 23.64486122], [68.22458649, 23.64486122], [68.22458649, 23.6443119], [68.2251358, 23.6443119], [68.2251358, 23.64402962], [68.22541809, 23.64402962], [68.22541809, 23.64374924], [68.22598267, 23.64374924], [68.22598267, 23.64347076], [68.22624969, 23.64347267], [68.22624969, 23.6431942], [68.22652435, 23.6431942], [68.22652435, 23.64291763], [68.2270813, 23.64291954], [68.2270813, 23.64263916], [68.22735596, 23.64263916], [68.22735596, 23.64236069], [68.2279129, 23.64236069], [68.2279129, 23.6420784], [68.22875214, 23.64208412], [68.22875214, 23.64180565], [68.22930908, 23.64181137], [68.22930908, 23.64152908], [68.23374939, 23.64152908], [68.23374939, 23.64125061], [68.23625183, 23.64125061], [68.23625183, 23.64152908], [68.23819733, 23.64152908], [68.23819733, 23.64181137], [68.23986053, 23.64180565], [68.23986053, 23.64208412], [68.24069214, 23.6420784], [68.24069214, 23.64236069], [68.24153137, 23.64236069], [68.24153137, 23.64263916], [68.24346924, 23.64263916], [68.24346924, 23.64236069], [68.24375153, 23.64236069], [68.24375153, 23.6420784], [68.24430847, 23.64208412], [68.24430847, 23.64180565], [68.24514008, 23.64181137], [68.24514008, 23.64291954], [68.24569702, 23.64291763], [68.24569702, 23.6431942], [68.24624634, 23.6431942], [68.24624634, 23.64347267], [68.24707794, 23.64347076], [68.24707794, 23.64374924], [68.24764252, 23.64374924], [68.24764252, 23.64402962], [68.24819183, 23.64402962], [68.24819183, 23.6443119], [68.25069427, 23.64430618], [68.25069427, 23.64458275], [68.25235748, 23.64458275], [68.25235748, 23.64486122], [68.25514221, 23.64486122], [68.25514221, 23.64513969], [68.25595856, 23.64513969], [68.25595856, 23.64458275], [68.25624847, 23.64458275], [68.25624847, 23.64402771], [68.25653076, 23.64402962], [68.25653076, 23.64347076], [68.25680542, 23.64347267], [68.25680542, 23.64263916], [68.25708008, 23.64263916], [68.25708008, 23.6420784], [68.25736237, 23.64208412], [68.25736237, 23.64152718], [68.25763702, 23.64152908], [68.25763702, 23.64125061], [68.25791931, 23.64125061], [68.25791931, 23.64097023], [68.25819397, 23.64097214], [68.25819397, 23.6404171], [68.25846863, 23.64042091], [68.25846863, 23.64014816], [68.25875092, 23.64014816], [68.25875092, 23.63986015], [68.26013947, 23.63986015], [68.26013947, 23.64014816], [68.25985718, 23.64014816], [68.25985718, 23.64042091], [68.25958252, 23.6404171], [68.25958252, 23.64069366], [68.25930786, 23.64069366], [68.25930786, 23.64097214], [68.25901794, 23.64097023], [68.25901794, 23.64125061], [68.25875092, 23.64125061], [68.25875092, 23.64152908], [68.25846863, 23.64152908], [68.25846863, 23.64181137], [68.25818634, 23.64181137], [68.25818634, 23.64486122], [68.25985718, 23.64486122], [68.25985718, 23.64513969], [68.26152802, 23.64513969], [68.26152802, 23.64542007], [68.26486206, 23.64541626], [68.26486206, 23.64569473], [68.26597595, 23.64569473], [68.26597595, 23.6459713], [68.26680756, 23.64596176], [68.26680756, 23.64624977], [68.27069092, 23.64624977], [68.27069092, 23.64653015], [68.27180481, 23.64652824], [68.27180481, 23.64680481], [68.2729187, 23.64680481], [68.2729187, 23.64708138], [68.27375031, 23.64708138], [68.27375031, 23.64736366], [68.27485657, 23.64735985], [68.27485657, 23.64764023], [68.2756958, 23.64764023], [68.2756958, 23.64792061], [68.2765274, 23.64792061], [68.2765274, 23.64820099], [68.2776413, 23.64819336], [68.2776413, 23.64847183], [68.2784729, 23.64846992], [68.2784729, 23.64875031], [68.27986145, 23.64875031], [68.27986145, 23.64902687], [68.28430176, 23.64902687], [68.28430939, 23.64875031], [68.28569794, 23.64875031], [68.28569794, 23.64846992], [68.28736115, 23.64847183], [68.28736115, 23.64819336], [68.28848267, 23.64820099], [68.28848267, 23.64792061], [68.2893219, 23.64792061], [68.2893219, 23.64764023], [68.2904129, 23.64764023], [68.2904129, 23.64735985], [68.29957581, 23.64735985], [68.29957581, 23.64764023], [68.30208588, 23.64764023], [68.30208588, 23.64792061], [68.30432129, 23.64792061], [68.30432129, 23.64820099], [68.30847168, 23.64819336], [68.30847168, 23.64847183], [68.30902863, 23.64846992], [68.30902863, 23.64875031], [68.30958557, 23.64875031], [68.30958557, 23.64902687], [68.31012726, 23.64902115], [68.31012726, 23.64931107], [68.31041718, 23.64930344], [68.31041718, 23.64958572], [68.31069183, 23.64958], [68.31069183, 23.64986038], [68.31096649, 23.64986038], [68.31096649, 23.65014076], [68.31181335, 23.65014076], [68.31181335, 23.65042114], [68.31153107, 23.65041733], [68.31153107, 23.65097237], [68.31124878, 23.65097046], [68.31124878, 23.65153122], [68.31096649, 23.65153122], [68.31096649, 23.65208817], [68.31041718, 23.65208817], [68.31041718, 23.65125084], [68.31012726, 23.65125084], [68.31012726, 23.65069008], [68.30986023, 23.6506958], [68.30986023, 23.65041733], [68.30930328, 23.65042114], [68.30930328, 23.65014076], [68.30902863, 23.65014076], [68.30902863, 23.64986038], [68.30819702, 23.64986038], [68.30819702, 23.64958], [68.30735779, 23.64958572], [68.30735779, 23.64930344], [68.30652618, 23.64931107], [68.30652618, 23.64902115], [68.30291748, 23.64902687], [68.30291748, 23.64875031], [68.30097198, 23.64875031], [68.30097198, 23.64846992], [68.29930878, 23.64847183], [68.29930878, 23.64819336], [68.28986359, 23.64819336], [68.28986359, 23.64847183], [68.2895813, 23.64846992], [68.2895813, 23.64875031], [68.28930664, 23.64875031], [68.28930664, 23.64902687], [68.28874969, 23.64902115], [68.28874969, 23.64931107], [68.28847504, 23.64930344], [68.28847504, 23.64958572], [68.28819275, 23.64958], [68.28819275, 23.64986038], [68.2876358, 23.64986038], [68.2876358, 23.65014076], [68.28736115, 23.65014076], [68.28736115, 23.65042114], [68.2868042, 23.65041733], [68.2868042, 23.6506958], [68.28652954, 23.6506958], [68.28652954, 23.65097237], [68.28569794, 23.65097046], [68.28569794, 23.65125084], [68.28514099, 23.65125084], [68.28514099, 23.65153122], [68.28430176, 23.65153122], [68.28430176, 23.65180969], [68.28318787, 23.65180969], [68.28318787, 23.65208817], [68.2804184, 23.65208817], [68.2804184, 23.65180969], [68.27986145, 23.65180969], [68.27986145, 23.65153122], [68.27929688, 23.65153122], [68.27929688, 23.65125084], [68.27902985, 23.65125084], [68.27902985, 23.65097046], [68.2784729, 23.65097237], [68.2784729, 23.6506958], [68.27791595, 23.6506958], [68.27791595, 23.65041733], [68.27735901, 23.65042114], [68.27735901, 23.65014076], [68.2765274, 23.65014076], [68.2765274, 23.64986038], [68.27597046, 23.64986038], [68.27597046, 23.64958], [68.27513885, 23.64958572], [68.27513885, 23.64930344], [68.27458191, 23.64931107], [68.27458191, 23.64902115], [68.27319336, 23.64902687], [68.27319336, 23.64875031], [68.2720871, 23.64875031], [68.2720871, 23.64846992], [68.27069092, 23.64847183], [68.27069092, 23.64819336], [68.26875305, 23.64820099], [68.26875305, 23.64792061], [68.2665329, 23.64792061], [68.2665329, 23.64764023], [68.26568604, 23.64764023], [68.26568604, 23.64735985], [68.26457977, 23.64736366], [68.26457977, 23.64708138], [68.26374817, 23.64708138], [68.26374817, 23.64680481], [68.26208496, 23.64680481], [68.26208496, 23.64652824], [68.26013947, 23.64653015], [68.26013947, 23.64624977], [68.25930786, 23.64624977], [68.25930786, 23.64596176], [68.25485992, 23.6459713], [68.25485992, 23.64569473], [68.25180817, 23.64569473], [68.25180817, 23.64541626], [68.24764252, 23.64542007], [68.24764252, 23.64513969], [68.24678802, 23.64513969], [68.24678802, 23.64486122], [68.24597168, 23.64486122], [68.24597168, 23.64458275], [68.24485779, 23.64458275], [68.24485779, 23.64430618], [68.24401855, 23.6443119], [68.24401855, 23.64402962], [68.24208069, 23.64402962], [68.24208069, 23.64374924], [68.24014282, 23.64374924], [68.24014282, 23.64347076], [68.23902893, 23.64347267], [68.23902893, 23.6431942], [68.23764038, 23.6431942], [68.23764038, 23.64291573], [68.23568726, 23.64291954], [68.23568726, 23.64263916], [68.23291779, 23.64263916], [68.23291779, 23.64291954], [68.23124695, 23.64291573], [68.23124695, 23.64347267], [68.23178864, 23.64347076], [68.23178864, 23.64374924], [68.23207855, 23.64374924], [68.23207855, 23.64402962], [68.23264313, 23.64402962], [68.23264313, 23.6443119], [68.23319244, 23.64430618], [68.23319244, 23.64458275], [68.2334671, 23.64458275], [68.2334671, 23.64486122], [68.23707581, 23.64486122], [68.23707581, 23.64542007], [68.23735809, 23.64541626], [68.23735809, 23.6459713], [68.23764038, 23.6459713], [68.23764038, 23.64680481], [68.23791504, 23.64680481], [68.23791504, 23.64736366], [68.23819733, 23.64735985], [68.23819733, 23.64792061], [68.23847198, 23.64792061], [68.23847198, 23.64764023], [68.23874664, 23.64764023], [68.23874664, 23.64735985], [68.23902893, 23.64736366], [68.23902893, 23.64708138], [68.23958588, 23.64708138], [68.23958588, 23.64680481], [68.24153137, 23.64680481], [68.24153137, 23.64708138], [68.24208069, 23.64708138], [68.24208069, 23.64736366], [68.24375153, 23.64735985], [68.24375153, 23.64764023], [68.24485779, 23.64764023], [68.24485779, 23.64735985], [68.24597168, 23.64736366], [68.24597168, 23.64708138], [68.24847412, 23.64708138], [68.24847412, 23.64736366], [68.24986267, 23.64736366], [68.24986267, 23.64708138], [68.25041962, 23.64708138], [68.25041962, 23.64680481], [68.25319672, 23.64680481], [68.25319672, 23.64708138], [68.25430298, 23.64708138], [68.25430298, 23.64736366], [68.25514221, 23.64735985], [68.25514221, 23.64764023], [68.25846863, 23.64764023], [68.25846863, 23.64792061], [68.26069641, 23.64792061], [68.26069641, 23.64820099], [68.26208496, 23.64819336], [68.26208496, 23.64847183], [68.26346588, 23.64846992], [68.26346588, 23.64875031], [68.26319122, 23.64875031], [68.26319122, 23.64902687], [68.26291656, 23.64902687], [68.26291656, 23.64958572], [68.26264191, 23.64958], [68.26264191, 23.64986038], [68.26374817, 23.64986038], [68.26374817, 23.65014076], [68.26597595, 23.65014076], [68.26597595, 23.64986038], [68.26625061, 23.64986038], [68.26625061, 23.64958], [68.26652527, 23.64958572], [68.26652527, 23.64930344], [68.26847076, 23.64930344], [68.26847076, 23.64958572], [68.26957703, 23.64958], [68.26957703, 23.64986038], [68.26930237, 23.64986038], [68.26930237, 23.65042114], [68.26902771, 23.65041733], [68.26902771, 23.65097237], [68.26875305, 23.65097046], [68.26875305, 23.65153122], [68.26902771, 23.65153122], [68.26902771, 23.65180969], [68.26930237, 23.65180969], [68.26930237, 23.65208817], [68.26957703, 23.65208817], [68.26957703, 23.65236092], [68.26985931, 23.65236092], [68.26985931, 23.65263939], [68.2701416, 23.65263939], [68.2701416, 23.65291977], [68.27041626, 23.65291786], [68.27041626, 23.65319443], [68.27069092, 23.65319443], [68.27069092, 23.6534729], [68.27095795, 23.65347099], [68.27095795, 23.65374947], [68.27124786, 23.65374947], [68.27124786, 23.65430832], [68.27153015, 23.65430641], [68.27153015, 23.65486145], [68.27179718, 23.65485954], [68.27179718, 23.65570068], [68.2720871, 23.65570068], [68.2720871, 23.65653038], [68.27236176, 23.65652847], [68.27236176, 23.65708351], [68.27263641, 23.6570816], [68.27263641, 23.65792274], [68.2729187, 23.65791702], [68.2729187, 23.65847015], [68.27319336, 23.65847015], [68.27319336, 23.65875053], [68.27348328, 23.65875053], [68.27348328, 23.65930939], [68.27375031, 23.65930557], [68.27375031, 23.65958214], [68.27402496, 23.65958214], [68.27402496, 23.65986061], [68.27430725, 23.65986061], [68.27430725, 23.66041946], [68.27458191, 23.66041756], [68.27458191, 23.66069221], [68.2748642, 23.66069221], [68.2748642, 23.6609745], [68.27513885, 23.66096115], [68.27513885, 23.66125107], [68.27540588, 23.66125107], [68.27540588, 23.66152954], [68.27708435, 23.66152763], [68.27708435, 23.66236115], [68.27735901, 23.66236115], [68.27735901, 23.66319656], [68.27791595, 23.66319656], [68.27791595, 23.66291428], [68.27902985, 23.66292], [68.27902985, 23.66263962], [68.28015137, 23.66263962], [68.28015137, 23.66403008], [68.2804184, 23.66403008], [68.2804184, 23.66514015], [68.28069305, 23.66514015], [68.28069305, 23.66653061], [68.28097534, 23.6665287], [68.28098297, 23.66736031], [68.28069305, 23.66736031], [68.28069305, 23.66764069], [68.2804184, 23.66764069], [68.2804184, 23.66791916], [68.28069305, 23.66791725], [68.28069305, 23.66847229], [68.28098297, 23.66847038], [68.28098297, 23.66931152], [68.28125, 23.66931152], [68.28125, 23.66986084], [68.28152466, 23.66986084], [68.28152466, 23.67013931], [68.28180695, 23.67012978], [68.28180695, 23.6704216], [68.2820816, 23.67041588], [68.2820816, 23.67069435], [68.28263855, 23.67069435], [68.28263855, 23.67097282], [68.28289795, 23.67097092], [68.28289795, 23.67124939], [68.28318787, 23.67124939], [68.28318787, 23.67152977], [68.28347015, 23.67152977], [68.28347015, 23.67181015], [68.28430176, 23.67180634], [68.28430176, 23.6720829], [68.28457642, 23.6720829], [68.28457642, 23.67263985], [68.28514099, 23.67263985], [68.28514099, 23.67292023], [68.28541565, 23.67291641], [68.28541565, 23.67319489], [68.2859726, 23.67319489], [68.2859726, 23.67347145], [68.28624725, 23.67346954], [68.28624725, 23.67374992], [68.28679657, 23.67374992], [68.28679657, 23.6740303], [68.28708649, 23.6740303], [68.28708649, 23.67431068], [68.2876358, 23.67430305], [68.2876358, 23.67458534], [68.28791809, 23.67458534], [68.28791809, 23.67486382], [68.28848267, 23.67486], [68.28848267, 23.67514038], [68.28874969, 23.67514038], [68.28874969, 23.67542076], [68.28902435, 23.67541695], [68.28903198, 23.6756897], [68.28930664, 23.67569351], [68.28930664, 23.67597198], [68.2895813, 23.67597008], [68.2895813, 23.67625999], [68.28985596, 23.67625999], [68.28985596, 23.67653084], [68.2904129, 23.67653084], [68.2904129, 23.67681122], [68.29069519, 23.67680359], [68.29069519, 23.67708588], [68.29096985, 23.67708015], [68.29096985, 23.67736053], [68.29125214, 23.67736053], [68.29125214, 23.67764091], [68.29180908, 23.67764091], [68.29180908, 23.67791939], [68.29208374, 23.67791748], [68.29208374, 23.67819595], [68.2923584, 23.67819595], [68.2923584, 23.67847252], [68.29402924, 23.67847061], [68.29402924, 23.67875099], [68.29429626, 23.67875099], [68.29429626, 23.67902946], [68.29486084, 23.67902946], [68.29486084, 23.67875099], [68.2959671, 23.67875099], [68.2959671, 23.67902946], [68.29624939, 23.67902946], [68.29624939, 23.67931747], [68.29652405, 23.67930794], [68.29652405, 23.6795826], [68.29708099, 23.67958069], [68.29708099, 23.67986107], [68.29792023, 23.67986107], [68.29792023, 23.67958069], [68.29930878, 23.6795826], [68.29930878, 23.67930794], [68.30042267, 23.67931747], [68.30042267, 23.67902946], [68.30152893, 23.67902946], [68.30152893, 23.67875099], [68.30291748, 23.67875099], [68.30291748, 23.67902946], [68.30432129, 23.67902946], [68.30432129, 23.67931747], [68.30458069, 23.67930794], [68.30458069, 23.6795826], [68.30486298, 23.67958069], [68.30486298, 23.68013954], [68.30513763, 23.68013954], [68.30513763, 23.68069458], [68.30569458, 23.68069458], [68.30569458, 23.68097305], [68.30596924, 23.68097115], [68.30596924, 23.68124962], [68.30625153, 23.68124962], [68.30625153, 23.68152809], [68.30596924, 23.68152809], [68.30596924, 23.68180466], [68.30541992, 23.68180466], [68.30541992, 23.68152809], [68.30486298, 23.68152809], [68.30486298, 23.68124962], [68.30458069, 23.68124962], [68.30458069, 23.68069077], [68.30430603, 23.68069458], [68.30430603, 23.68013954], [68.30403137, 23.68013954], [68.30403137, 23.67986107], [68.30263519, 23.67986107], [68.30263519, 23.6795826], [68.30152893, 23.67958069], [68.30152893, 23.67986107], [68.30069733, 23.67986107], [68.30069733, 23.68013954], [68.29985809, 23.68013954], [68.29985809, 23.68041992], [68.29958344, 23.68041611], [68.29958344, 23.68069458], [68.29902649, 23.68069458], [68.29902649, 23.68097305], [68.29875183, 23.68097115], [68.29875183, 23.68124962], [68.29846954, 23.68124962], [68.29846954, 23.68180466], [68.29819489, 23.68180466], [68.29819489, 23.68208313], [68.29792023, 23.68208313], [68.29792023, 23.6823616], [68.29763794, 23.6823597], [68.29763794, 23.68292236], [68.29736328, 23.68292236], [68.29736328, 23.68403244], [68.29763794, 23.68402863], [68.29763794, 23.68458366], [68.29792023, 23.68458366], [68.29792023, 23.6851387], [68.29818726, 23.68512917], [68.29818726, 23.6854229], [68.29846954, 23.68541718], [68.29846954, 23.68569374], [68.29875183, 23.68569374], [68.29875183, 23.68597221], [68.29930878, 23.68597031], [68.29930878, 23.68625069], [68.29957581, 23.68625069], [68.29957581, 23.68653107], [68.29985809, 23.68653107], [68.29985809, 23.68680954], [68.30014038, 23.68680573], [68.30014038, 23.68708229], [68.30041504, 23.68708229], [68.30041504, 23.68736076], [68.30069733, 23.68736076], [68.30069733, 23.68764114], [68.30097198, 23.68764114], [68.30097198, 23.68791962], [68.30124664, 23.6879158], [68.30124664, 23.68847466], [68.30152893, 23.68847084], [68.30152893, 23.68875122], [68.30179596, 23.68875122], [68.30179596, 23.68902969], [68.30208588, 23.68902969], [68.30208588, 23.68931007], [68.30236053, 23.68930435], [68.30236053, 23.68958282], [68.30263519, 23.68958282], [68.30263519, 23.6898613], [68.30291748, 23.68985939], [68.30291748, 23.69042015], [68.30319214, 23.69041443], [68.30319214, 23.69069672], [68.30347443, 23.69069672], [68.30347443, 23.69097137], [68.30374908, 23.69096947], [68.30374908, 23.69125938], [68.30403137, 23.69125938], [68.30403137, 23.69153023], [68.30430603, 23.69152832], [68.30430603, 23.69180679], [68.30458069, 23.69180679], [68.30458069, 23.69208336], [68.30513763, 23.69208336], [68.30513763, 23.69236183], [68.30541992, 23.69235992], [68.30541992, 23.6926403], [68.30568695, 23.6926403], [68.30568695, 23.69292068], [68.30596924, 23.69292068], [68.30596924, 23.69319916], [68.30625153, 23.69319534], [68.30625153, 23.69347191], [68.30652618, 23.69346809], [68.30652618, 23.69403076], [68.30680847, 23.69402885], [68.30680847, 23.69430542], [68.30708313, 23.69430542], [68.30708313, 23.69458389], [68.30735779, 23.69457817], [68.30735779, 23.69486046], [68.30764008, 23.69486046], [68.30764008, 23.69541931], [68.30791473, 23.6954174], [68.30791473, 23.69569397], [68.30819702, 23.69569397], [68.30819702, 23.69597244], [68.30847168, 23.69597054], [68.30847168, 23.69652939], [68.30874634, 23.69652939], [68.30874634, 23.69681168], [68.30902863, 23.69680595], [68.30902863, 23.69708252], [68.30930328, 23.69706917], [68.30930328, 23.69763947], [68.3095932, 23.69763947], [68.3095932, 23.69792175], [68.30986023, 23.69791603], [68.30986023, 23.69847107], [68.31012726, 23.69847107], [68.31012726, 23.69903183], [68.31041718, 23.69903183], [68.31041718, 23.6993103], [68.31069183, 23.69930649], [68.31069183, 23.69986153], [68.31096649, 23.69985962], [68.31096649, 23.70042038], [68.31124878, 23.70041656], [68.31124878, 23.7009716], [68.31153107, 23.7009697], [68.31153107, 23.70125008], [68.31181335, 23.70125008], [68.31181335, 23.70181084], [68.31208038, 23.70180321], [68.31208038, 23.70236206], [68.31236267, 23.70236015], [68.31236267, 23.70319939], [68.31263733, 23.70319939], [68.31263733, 23.70430946], [68.31291962, 23.70430946], [68.31291962, 23.70541954], [68.31319427, 23.70541763], [68.31319427, 23.70597267], [68.31346893, 23.70597267], [68.31346893, 23.70708275], [68.31375122, 23.70708275], [68.31375122, 23.7084713], [68.31346893, 23.7084713], [68.31346893, 23.70986176], [68.31319427, 23.70986176], [68.31319427, 23.71097183], [68.31346893, 23.71097183], [68.31346893, 23.71208382], [68.31375122, 23.71208191], [68.31375122, 23.71264267], [68.31402588, 23.71263885], [68.31402588, 23.71319389], [68.31430817, 23.71319008], [68.31430817, 23.71375084], [68.31458282, 23.71375084], [68.31458282, 23.71430969], [68.31485748, 23.71430588], [68.31485748, 23.71458244], [68.31513977, 23.71458054], [68.31513977, 23.71486092], [68.3154068, 23.71486092], [68.3154068, 23.71513939], [68.31569672, 23.71513939], [68.31569672, 23.71543121], [68.31597137, 23.71541405], [68.31597137, 23.71569633], [68.31625366, 23.71569633], [68.31625366, 23.71597481], [68.31680298, 23.71597099], [68.31680298, 23.71624947], [68.3170929, 23.71624947], [68.3170929, 23.71652985], [68.31735992, 23.71652985], [68.31735992, 23.71681023], [68.31764221, 23.7168045], [68.31764221, 23.71708488], [68.31791687, 23.71708107], [68.31791687, 23.71763992], [68.31819153, 23.71763992], [68.31819153, 23.7179203], [68.31846619, 23.7179203], [68.31846619, 23.71820068], [68.31903076, 23.71819687], [68.31903076, 23.71847153], [68.31929779, 23.71846962], [68.31929779, 23.71875], [68.31986237, 23.71875], [68.31986237, 23.71903038], [68.32013702, 23.71903038], [68.32013702, 23.71931076], [68.32069397, 23.71930695], [68.32069397, 23.71958351], [68.32096863, 23.71958351], [68.32096863, 23.71986198], [68.3215332, 23.71986008], [68.3215332, 23.72014046], [68.32206726, 23.72014046], [68.32206726, 23.72042084], [68.32236481, 23.72041893], [68.32236481, 23.72069359], [68.32291412, 23.72069359], [68.32291412, 23.72097206], [68.32347107, 23.72097206], [68.32347107, 23.72125053], [68.32402802, 23.721241], [68.32402802, 23.72153091], [68.32485962, 23.72153091], [68.32485962, 23.72180939], [68.32541656, 23.72180557], [68.32541656, 23.72208405], [68.32596588, 23.72207832], [68.32596588, 23.72236061], [68.32624817, 23.72236061], [68.32624817, 23.72263908], [68.32681274, 23.72263908], [68.32681274, 23.72291946], [68.32707977, 23.72291756], [68.32707977, 23.72319412], [68.32763672, 23.72319412], [68.32763672, 23.7234726], [68.32820129, 23.72347069], [68.32820129, 23.72374916], [68.32958221, 23.72374916], [68.32958221, 23.72263908], [68.32985687, 23.72263908], [68.32985687, 23.72236061], [68.32958221, 23.72236061], [68.32958221, 23.72068977], [68.3298645, 23.72069359], [68.3298645, 23.71986198], [68.33013916, 23.71986198], [68.33013916, 23.71958351], [68.33041382, 23.71958351], [68.33041382, 23.71902847], [68.33069611, 23.71903038], [68.33069611, 23.71875], [68.33097076, 23.71875], [68.33097076, 23.71820068], [68.33123779, 23.71820068], [68.33123779, 23.7179203], [68.33152771, 23.7179203], [68.33152771, 23.71763992], [68.33207703, 23.71763992], [68.33207703, 23.71735954], [68.33235931, 23.71736145], [68.33235931, 23.71708488], [68.3326416, 23.71708488], [68.3326416, 23.71624947], [68.33291626, 23.71624947], [68.33291626, 23.71543121], [68.33319092, 23.71543121], [68.33319092, 23.71347046], [68.33347321, 23.71347237], [68.33347321, 23.71236038], [68.33319092, 23.71236038], [68.33319092, 23.71097183], [68.33347321, 23.71097183], [68.33347321, 23.71069527], [68.33374786, 23.71069527], [68.33374786, 23.71097183], [68.33403015, 23.71097183], [68.33403015, 23.71236038], [68.33429718, 23.71236038], [68.33429718, 23.71375084], [68.33403015, 23.71375084], [68.33403015, 23.71543121], [68.33374786, 23.71543121], [68.33374786, 23.71624947], [68.33347321, 23.71624947], [68.33347321, 23.71708488], [68.33319092, 23.71708488], [68.33319092, 23.71736145], [68.33291626, 23.71735954], [68.33291626, 23.71763992], [68.3326416, 23.71763992], [68.3326416, 23.7179203], [68.33235931, 23.7179203], [68.33235931, 23.71820068], [68.33208466, 23.71819687], [68.33208466, 23.71847153], [68.33180237, 23.71846962], [68.33180237, 23.71875], [68.33152771, 23.71875], [68.33152771, 23.71903038], [68.33125305, 23.71902847], [68.33125305, 23.71958351], [68.33097076, 23.7195797], [68.33097076, 23.72014046], [68.33069611, 23.72013855], [68.33069611, 23.72069359], [68.33040619, 23.72068977], [68.33040619, 23.72236061], [68.33069611, 23.72236061], [68.33069611, 23.72319412], [68.33097076, 23.7231884], [68.33097076, 23.72374916], [68.33125305, 23.72374916], [68.33125305, 23.72430611], [68.33152771, 23.72430611], [68.33152771, 23.72458267], [68.33207703, 23.72458267], [68.33207703, 23.72486115], [68.33235931, 23.72486115], [68.33235931, 23.72513962], [68.3345871, 23.72513962], [68.3345871, 23.72542191], [68.33486176, 23.72541618], [68.33486176, 23.72569466], [68.3354187, 23.72569466], [68.3354187, 23.72597122], [68.33569336, 23.72597122], [68.33569336, 23.72653008], [68.33597565, 23.72652817], [68.33597565, 23.7270813], [68.33625031, 23.72707939], [68.33625031, 23.72764015], [68.33653259, 23.72764015], [68.33653259, 23.72820091], [68.33680725, 23.72819328], [68.33680725, 23.72847176], [68.33708191, 23.72846985], [68.33708191, 23.72875023], [68.33737183, 23.72875023], [68.33737183, 23.72903061], [68.33763885, 23.7290287], [68.33763885, 23.72958565], [68.33790588, 23.72957993], [68.33790588, 23.7304306], [68.3381958, 23.7304306], [68.3381958, 23.73125076], [68.33847046, 23.73125076], [68.33847046, 23.73208427], [68.33875275, 23.73208046], [68.33875275, 23.73291969], [68.3390274, 23.73291969], [68.3390274, 23.73430824], [68.33930206, 23.73430634], [68.33930206, 23.73597145], [68.3390274, 23.73596764], [68.3390274, 23.73792267], [68.33930206, 23.73792267], [68.33930206, 23.74263954], [68.33957672, 23.74263954], [68.33957672, 23.74291992], [68.3401413, 23.74291992], [68.3401413, 23.74263954], [68.34069824, 23.74263954], [68.34069824, 23.74237061], [68.34124756, 23.74237061], [68.34124756, 23.74208069], [68.34236145, 23.7420826], [68.34236145, 23.74180412], [68.34263611, 23.74180984], [68.34263611, 23.74152946], [68.3434906, 23.74152946], [68.3434906, 23.7412529], [68.34401703, 23.7412529], [68.34401703, 23.74097061], [68.34486389, 23.74097252], [68.34486389, 23.74041748], [68.34513855, 23.74041939], [68.34513855, 23.74014282], [68.34541321, 23.74014282], [68.34541321, 23.73986053], [68.34570313, 23.73986053], [68.3456955, 23.73791695], [68.34597015, 23.73792267], [68.34597015, 23.73764038], [68.34623718, 23.73764038], [68.34623718, 23.73708153], [68.3465271, 23.73708344], [68.3465271, 23.73541641], [68.34680176, 23.73541832], [68.34680939, 23.73485947], [68.34708405, 23.73486137], [68.34708405, 23.7345829], [68.3473587, 23.7345829], [68.3473587, 23.73402977], [68.34764099, 23.73402977], [68.34764099, 23.73374939], [68.34792328, 23.73374939], [68.34791565, 23.73319435], [68.34819794, 23.73319435], [68.34819794, 23.73263931], [68.3484726, 23.73264122], [68.3484726, 23.73236084], [68.34874725, 23.73236084], [68.34874725, 23.73208046], [68.34902954, 23.73208427], [68.34902954, 23.73180771], [68.34986115, 23.73180771], [68.34986115, 23.73208427], [68.3501358, 23.73208046], [68.3501358, 23.73291969], [68.34986115, 23.73291779], [68.34986115, 23.73347282], [68.34958649, 23.73347092], [68.34958649, 23.73374939], [68.34931183, 23.73374939], [68.34931183, 23.73430824], [68.34902954, 23.73430634], [68.34902954, 23.73486137], [68.34874725, 23.73485947], [68.34874725, 23.73513985], [68.3484726, 23.73513985], [68.3484726, 23.73819351], [68.34819794, 23.7381916], [68.34819794, 23.73931122], [68.34792328, 23.73931122], [68.34792328, 23.74014282], [68.3473587, 23.74013901], [68.3473587, 23.74069214], [68.34708405, 23.74069214], [68.34708405, 23.74097252], [68.3473587, 23.74097061], [68.3473587, 23.7412529], [68.34764099, 23.7412529], [68.34764099, 23.74152946], [68.34792328, 23.74152946], [68.34792328, 23.74180984], [68.3493042, 23.74180412], [68.3493042, 23.7420826], [68.34958649, 23.74208069], [68.34958649, 23.74237061], [68.35069275, 23.74237061], [68.35069275, 23.74263954], [68.35151672, 23.74263954], [68.35151672, 23.74291992], [68.35180664, 23.74291992], [68.35180664, 23.74374962], [68.35151672, 23.74374962], [68.35151672, 23.74403], [68.3501358, 23.74403], [68.3501358, 23.74374962], [68.34902954, 23.74374962], [68.34902954, 23.74347115], [68.3484726, 23.74347305], [68.3484726, 23.74319649], [68.3473587, 23.74319649], [68.3473587, 23.7429142], [68.34680939, 23.74291992], [68.34680176, 23.74263954], [68.34597015, 23.74263954], [68.34597015, 23.74291992], [68.34486389, 23.7429142], [68.34486389, 23.74319649], [68.34430695, 23.74319649], [68.34430695, 23.74347305], [68.34401703, 23.74347115], [68.34401703, 23.74374962], [68.34375, 23.74374962], [68.34375, 23.74403], [68.34319305, 23.74402618], [68.34319305, 23.74430656], [68.3429184, 23.74430656], [68.3429184, 23.74458313], [68.34236145, 23.74458313], [68.34236145, 23.7448616], [68.3409729, 23.7448597], [68.3409729, 23.74791908], [68.34124756, 23.74791718], [68.34124756, 23.7495842], [68.3409729, 23.74957848], [68.3409729, 23.75013924], [68.34152985, 23.75013924], [68.34152985, 23.75069427], [68.34179688, 23.75068855], [68.34179688, 23.75125122], [68.3429184, 23.75125122], [68.3429184, 23.75154114], [68.34319305, 23.75152779], [68.34319305, 23.7523613], [68.3429184, 23.75235939], [68.3429184, 23.75263977], [68.3409729, 23.75263977], [68.3409729, 23.75235939], [68.34069824, 23.7523613], [68.34069824, 23.75208282], [68.34041595, 23.75208282], [68.34041595, 23.75180626], [68.33985901, 23.75181007], [68.33985901, 23.75154114], [68.3390274, 23.75154114], [68.3390274, 23.75181007], [68.33847046, 23.75180626], [68.33847046, 23.75208282], [68.33791351, 23.75208282], [68.33791351, 23.7523613], [68.33763885, 23.75235939], [68.33763885, 23.75263977], [68.33790588, 23.75263977], [68.33790588, 23.75292015], [68.3381958, 23.75291634], [68.3381958, 23.75319481], [68.33847046, 23.75319481], [68.33847046, 23.75347137], [68.3381958, 23.75346947], [68.3381958, 23.75374985], [68.33790588, 23.75374985], [68.33790588, 23.75431061], [68.3373642, 23.75430489], [68.3373642, 23.75458336], [68.33708191, 23.75458336], [68.33708191, 23.75486183], [68.33680725, 23.75485992], [68.33680725, 23.75542068], [68.33653259, 23.75542068], [68.33653259, 23.75570107], [68.33625031, 23.75569344], [68.33625031, 23.75597191], [68.33569336, 23.75597], [68.33569336, 23.75625038], [68.33486176, 23.75625038], [68.33486176, 23.75875092], [68.33513641, 23.75875092], [68.33513641, 23.75930977], [68.3354187, 23.75930786], [68.3354187, 23.75958252], [68.33569336, 23.75958061], [68.33569336, 23.76013947], [68.33597565, 23.76013947], [68.33597565, 23.76041794], [68.33625031, 23.76041794], [68.33625031, 23.76097298], [68.33653259, 23.76097107], [68.33653259, 23.76152992], [68.33680725, 23.76152992], [68.33680725, 23.7618084], [68.33708191, 23.76180649], [68.33708191, 23.76208305], [68.3373642, 23.76208305], [68.3373642, 23.76236153], [68.33763885, 23.76235962], [68.33763885, 23.76263809], [68.33790588, 23.76263809], [68.33790588, 23.76291847], [68.3381958, 23.76291847], [68.3381958, 23.76320267], [68.33847046, 23.76320267], [68.33847046, 23.76375008], [68.33875275, 23.76375008], [68.33875275, 23.76403046], [68.3390274, 23.76403046], [68.3390274, 23.76431274], [68.33930206, 23.76430511], [68.33930206, 23.76458359], [68.33957672, 23.76458168], [68.33957672, 23.76514053], [68.33985901, 23.76514053], [68.33985901, 23.76542282], [68.3401413, 23.7654171], [68.3401413, 23.76597023], [68.34043121, 23.76597023], [68.34043121, 23.76654053], [68.34069061, 23.76654053], [68.34069824, 23.76680946], [68.3409729, 23.76680946], [68.3409729, 23.76736069], [68.34124756, 23.76736069], [68.34124756, 23.76791954], [68.34152985, 23.76791763], [68.34152985, 23.76819229], [68.34179688, 23.76819038], [68.34179688, 23.76875114], [68.34208679, 23.76875114], [68.34208679, 23.76931], [68.34236145, 23.76931], [68.34236145, 23.76986122], [68.34263611, 23.76986122], [68.34263611, 23.77042007], [68.3429184, 23.77041435], [68.3429184, 23.7709713], [68.3431778, 23.77096939], [68.3431778, 23.77153015], [68.34347534, 23.77152824], [68.34347534, 23.77208328], [68.34375, 23.77207947], [68.34375, 23.77264023], [68.34401703, 23.77264023], [68.34401703, 23.77319908], [68.34430695, 23.77319908], [68.34430695, 23.77375031], [68.3445816, 23.77375031], [68.3445816, 23.77403069], [68.34486389, 23.77402878], [68.34486389, 23.77458382], [68.34513855, 23.77457809], [68.34513855, 23.77514076], [68.34541321, 23.77514076], [68.34541321, 23.77541924], [68.3456955, 23.77541733], [68.3456955, 23.77597237], [68.34597015, 23.77597046], [68.34597015, 23.77652931], [68.34625244, 23.7765274], [68.34625244, 23.77708244], [68.3465271, 23.77708054], [68.3465271, 23.77763939], [68.34680176, 23.77763939], [68.34680176, 23.77848053], [68.34707642, 23.77848053], [68.34707642, 23.77902985], [68.3473587, 23.77902794], [68.3473587, 23.77958107], [68.34764099, 23.77958107], [68.34764099, 23.78013992], [68.34792328, 23.78013992], [68.34792328, 23.78070068], [68.34819794, 23.78070068], [68.34819794, 23.78125], [68.3484726, 23.78125], [68.3484726, 23.78152847], [68.34874725, 23.78152847], [68.34874725, 23.78236389], [68.34902954, 23.78236389], [68.34902954, 23.78458595], [68.3493042, 23.78458595], [68.3493042, 23.78874969], [68.34958649, 23.78874969], [68.34958649, 23.79071045], [68.34986115, 23.79069519], [68.34986115, 23.79208374], [68.35041809, 23.79208183], [68.35041809, 23.79292107], [68.3501358, 23.79291725], [68.3501358, 23.79347229], [68.34986115, 23.79346275], [68.34986115, 23.79430962], [68.34958649, 23.7943058], [68.34958649, 23.79652786], [68.34986115, 23.79652786], [68.34986115, 23.79847145], [68.3501358, 23.79846954], [68.3501358, 23.79959106], [68.35041809, 23.79958344], [68.35041809, 23.8006897], [68.35152435, 23.80069542], [68.35152435, 23.80097198], [68.35180664, 23.80096817], [68.35180664, 23.80153084], [68.3520813, 23.80152893], [68.3520813, 23.80208397], [68.35236359, 23.80208397], [68.35236359, 23.80236053], [68.35263824, 23.80236053], [68.35263824, 23.80265045], [68.3529129, 23.80265045], [68.3529129, 23.80291939], [68.35319519, 23.80291748], [68.35319519, 23.80319405], [68.35346985, 23.80319405], [68.35346985, 23.80347252], [68.35375214, 23.80347061], [68.35375214, 23.80374908], [68.35402679, 23.80374908], [68.35402679, 23.80402946], [68.35457611, 23.80402946], [68.35457611, 23.80431175], [68.3548584, 23.80430603], [68.3548584, 23.8045826], [68.35540771, 23.80458069], [68.35540771, 23.80486107], [68.35679626, 23.80486107], [68.35679626, 23.80513954], [68.3584671, 23.80513954], [68.3584671, 23.80486107], [68.35930634, 23.80486107], [68.35930634, 23.80458069], [68.36042023, 23.8045826], [68.36042023, 23.80430603], [68.36125183, 23.80431175], [68.36125183, 23.80402946], [68.36180878, 23.80402946], [68.36180878, 23.80374908], [68.36235809, 23.80374908], [68.36235809, 23.80347061], [68.36264038, 23.80347252], [68.36264038, 23.80319405], [68.36319733, 23.80319405], [68.36319733, 23.80291748], [68.36374664, 23.80291939], [68.36374664, 23.80265045], [68.36431122, 23.80265045], [68.36431122, 23.80236053], [68.36458588, 23.80236053], [68.36458588, 23.80208397], [68.36486053, 23.80208397], [68.36486053, 23.8018055], [68.36514282, 23.80180931], [68.36514282, 23.80153084], [68.36569214, 23.80153084], [68.36569214, 23.80125046], [68.3659668, 23.80125046], [68.3659668, 23.80096817], [68.36624908, 23.80097198], [68.36624908, 23.80069542], [68.36653137, 23.8006897], [68.36653137, 23.80041885], [68.36680603, 23.80042076], [68.36680603, 23.80014038], [68.36708069, 23.80014038], [68.36708069, 23.79985809], [68.36736298, 23.79986191], [68.36736298, 23.79958344], [68.36763763, 23.79959106], [68.36763763, 23.79931068], [68.36791992, 23.79931068], [68.36791992, 23.7990303], [68.36818695, 23.7990303], [68.36818695, 23.79874992], [68.36846924, 23.79874992], [68.36846924, 23.79846954], [68.36875153, 23.79847145], [68.36875153, 23.79819679], [68.36902618, 23.79819679], [68.36902618, 23.79791451], [68.36930847, 23.79792023], [68.36930847, 23.79735947], [68.36958313, 23.79736137], [68.36958313, 23.7970829], [68.36985779, 23.7970829], [68.36985779, 23.79680443], [68.37014008, 23.79681015], [68.37014008, 23.79652023], [68.37041473, 23.79652786], [68.37041473, 23.79624939], [68.37069702, 23.79624939], [68.37069702, 23.79597092], [68.37124634, 23.79597473], [68.37124634, 23.79569244], [68.37152863, 23.79569244], [68.37152863, 23.79541588], [68.37180328, 23.79541969], [68.37180328, 23.79514122], [68.3720932, 23.79514122], [68.3720932, 23.79486084], [68.37264252, 23.79486084], [68.37264252, 23.79458046], [68.37319183, 23.79458237], [68.37319183, 23.7943058], [68.37374878, 23.79430962], [68.37374878, 23.79403114], [68.37403107, 23.79403114], [68.37403107, 23.79375076], [68.37458038, 23.79375076], [68.37458038, 23.79346275], [68.37513733, 23.79347229], [68.37513733, 23.79319382], [68.37541962, 23.79319382], [68.37541962, 23.79291725], [68.37596893, 23.79292107], [68.37596893, 23.79264069], [68.37654114, 23.79264069], [68.37654114, 23.79236031], [68.37680817, 23.79236031], [68.37680817, 23.79208183], [68.37708282, 23.79208374], [68.37708282, 23.79180527], [68.37763977, 23.7918129], [68.37763977, 23.79153252], [68.37819672, 23.79153252], [68.37819672, 23.79125023], [68.37874603, 23.79125023], [68.37874603, 23.79097176], [68.37930298, 23.79097176], [68.37930298, 23.79069519], [68.37985992, 23.79071045], [68.37985992, 23.79042244], [68.38069153, 23.79042244], [68.38069153, 23.79014015], [68.38124847, 23.79014015], [68.38124847, 23.78986168], [68.38236237, 23.78986168], [68.38236237, 23.78958321], [68.38346863, 23.78958321], [68.38346863, 23.78930473], [68.38402557, 23.78930473], [68.38402557, 23.78902817], [68.38485718, 23.78902817], [68.38485718, 23.78874969], [68.38764191, 23.78874969], [68.38764191, 23.78847122], [68.38847351, 23.78847313], [68.38847351, 23.78819466], [68.38930511, 23.78819466], [68.38930511, 23.78791618], [68.38986206, 23.78791809], [68.38986206, 23.78764915], [68.39068604, 23.78764915], [68.39068604, 23.78736115], [68.39154053, 23.78736115], [68.39152527, 23.78708267], [68.3923645, 23.78708267], [68.3923645, 23.78680611], [68.39319611, 23.78680992], [68.39319611, 23.78652954], [68.39402771, 23.78652954], [68.39402771, 23.78625107], [68.39485931, 23.78625107], [68.39485931, 23.78597069], [68.39569092, 23.7859726], [68.39569092, 23.78569412], [68.39624786, 23.78569412], [68.39624786, 23.78541756], [68.3970871, 23.78541946], [68.3970871, 23.78514099], [68.3979187, 23.78514099], [68.3979187, 23.78486061], [68.40125275, 23.78486061], [68.40125275, 23.78514099], [68.40207672, 23.78514099], [68.40207672, 23.78541946], [68.4026413, 23.78541756], [68.4026413, 23.78569412], [68.40291595, 23.78569412], [68.40291595, 23.7859726], [68.40348053, 23.78597069], [68.40348053, 23.78625107], [68.40458679, 23.78625107], [68.40458679, 23.78652954], [68.4054184, 23.78652954], [68.4054184, 23.78680992], [68.40597534, 23.78680611], [68.40597534, 23.78708267], [68.40625, 23.78708076], [68.40625, 23.78736115], [68.40680695, 23.78736115], [68.40680695, 23.78764915], [68.40735626, 23.78764915], [68.40735626, 23.78791809], [68.40763855, 23.78791618], [68.40763855, 23.78819466], [68.4081955, 23.78819466], [68.4081955, 23.78847313], [68.40847015, 23.78847122], [68.40847015, 23.78874969], [68.4090271, 23.78874969], [68.4090271, 23.78930473], [68.40930176, 23.78930473], [68.40930176, 23.78958321], [68.40957642, 23.78957748], [68.40957642, 23.79014015], [68.41014099, 23.79014015], [68.41014099, 23.79042244], [68.41042328, 23.79042244], [68.41042328, 23.79071045], [68.41069794, 23.79071045], [68.41069794, 23.79125023], [68.4109726, 23.79125023], [68.4109726, 23.7918129], [68.41124725, 23.7918129], [68.41124725, 23.79264069], [68.41152954, 23.79264069], [68.41152954, 23.79292107], [68.4118042, 23.79291725], [68.4118042, 23.79347229], [68.41236115, 23.79346275], [68.41236115, 23.79375076], [68.41291809, 23.79375076], [68.41291809, 23.79403114], [68.41374969, 23.79403114], [68.41374969, 23.79430962], [68.41430664, 23.7943058], [68.41430664, 23.79458237], [68.41513824, 23.79458046], [68.41513824, 23.79486084], [68.41625214, 23.79486084], [68.41625214, 23.79514122], [68.41845703, 23.79514122], [68.41845703, 23.79486084], [68.41902924, 23.79486084], [68.41902924, 23.79458046], [68.42151642, 23.79458046], [68.42151642, 23.79486084], [68.42208099, 23.79486084], [68.42208099, 23.79514122], [68.42263794, 23.79514122], [68.42263794, 23.79541969], [68.42319489, 23.79541588], [68.42319489, 23.79569244], [68.42346954, 23.79569054], [68.42346954, 23.79624939], [68.42375183, 23.79624939], [68.42375183, 23.79652786], [68.42402649, 23.79652023], [68.42402649, 23.79681015], [68.42430878, 23.79680443], [68.42430878, 23.7970829], [68.42514038, 23.7970829], [68.42514038, 23.79680443], [68.42542267, 23.79681015], [68.42542267, 23.79624939], [68.42569733, 23.79624939], [68.42569733, 23.79597092], [68.42597198, 23.79597473], [68.42597198, 23.79486084], [68.42624664, 23.79486084], [68.42624664, 23.79292107], [68.42597198, 23.79292107], [68.42597198, 23.79236031], [68.42569733, 23.79236031], [68.42569733, 23.79153252], [68.42542267, 23.79153252], [68.42542267, 23.79014015], [68.42514038, 23.79014015], [68.42514038, 23.78957748], [68.42541504, 23.78958321], [68.42541504, 23.78874969], [68.42569733, 23.78874969], [68.42569733, 23.78541946], [68.42542267, 23.78541946], [68.42542267, 23.78514099], [68.42569733, 23.78514099], [68.42569733, 23.78486061], [68.42541504, 23.78486061], [68.42541504, 23.78430748], [68.42569733, 23.78430939], [68.42569733, 23.78375053], [68.42541504, 23.78375053], [68.42541504, 23.78319359], [68.42569733, 23.78319359], [68.42569733, 23.78180313], [68.42542267, 23.78181076], [68.42542267, 23.78096962], [68.42514038, 23.78097153], [68.42514038, 23.77986145], [68.42485809, 23.77986145], [68.42485809, 23.7784729], [68.42459106, 23.77848053], [68.42459106, 23.77708054], [68.42430878, 23.77708244], [68.42430878, 23.7765274], [68.42375183, 23.77652931], [68.42375183, 23.77625084], [68.42346954, 23.77625084], [68.42346954, 23.77597046], [68.42292023, 23.77597237], [68.42292023, 23.77569389], [68.42263794, 23.77569389], [68.42263794, 23.77541733], [68.42236328, 23.77541924], [68.42236328, 23.77514076], [68.42208099, 23.77514076], [68.42208099, 23.77486038], [68.42180634, 23.77486038], [68.42180634, 23.77457809], [68.42152405, 23.77458382], [68.42152405, 23.77375031], [68.42124939, 23.77375031], [68.42124939, 23.77346992], [68.42097473, 23.77347183], [68.42097473, 23.7729187], [68.42069244, 23.77292061], [68.42069244, 23.77180099], [68.42041779, 23.77180672], [68.42041779, 23.77152824], [68.42014313, 23.77153015], [68.42014313, 23.77069092], [68.41986084, 23.77069664], [68.41986084, 23.77013969], [68.41958618, 23.77013969], [68.41958618, 23.76986122], [68.41929626, 23.76986122], [68.41929626, 23.76875114], [68.41902924, 23.76875114], [68.41902924, 23.76708031], [68.41930389, 23.76708221], [68.41930389, 23.76680565], [68.41902924, 23.76680946], [68.41902924, 23.76597023], [68.41874695, 23.76597023], [68.41874695, 23.76486015], [68.41847229, 23.76486015], [68.41845703, 23.76348114], [68.41819763, 23.76348114], [68.41819763, 23.76320267], [68.41792297, 23.76320267], [68.41792297, 23.76291847], [68.41819763, 23.76291847], [68.41819763, 23.76263809], [68.41792297, 23.76263809], [68.41792297, 23.76235962], [68.41764069, 23.76236153], [68.41764069, 23.76208305], [68.4173584, 23.76208305], [68.4173584, 23.76180649], [68.41430664, 23.76180649], [68.41430664, 23.76208305], [68.41374969, 23.76208305], [68.41374969, 23.76180649], [68.41265106, 23.76180077], [68.4126358, 23.76152992], [68.41152954, 23.76152992], [68.41152954, 23.76124954], [68.41124725, 23.76124954], [68.41124725, 23.76097107], [68.41152954, 23.76097298], [68.41152954, 23.7606945], [68.4109726, 23.7606945], [68.4109726, 23.76041794], [68.41041565, 23.76041794], [68.41041565, 23.75986099], [68.41014099, 23.75986099], [68.41014099, 23.75958061], [68.4098587, 23.75958252], [68.4098587, 23.75930786], [68.40930939, 23.75930977], [68.4092865, 23.75902939], [68.40847015, 23.75902939], [68.40847015, 23.75875092], [68.40791321, 23.75875092], [68.40791321, 23.75847054], [68.40763855, 23.75847244], [68.40763855, 23.75819588], [68.40736389, 23.75819588], [68.40736389, 23.7579174], [68.4070816, 23.75792122], [68.4070816, 23.75764084], [68.40680695, 23.75764084], [68.40680695, 23.75735092], [68.40625, 23.75736046], [68.40625, 23.7570858], [68.40597534, 23.7570858], [68.40597534, 23.75680351], [68.4054184, 23.75681114], [68.4054184, 23.75653076], [68.40513611, 23.75653076], [68.40513611, 23.75625038], [68.40486145, 23.75625038], [68.40486145, 23.75597], [68.40458679, 23.75597191], [68.40458679, 23.75569344], [68.40402985, 23.75570107], [68.40402985, 23.75542068], [68.40374756, 23.75542068], [68.40374756, 23.7551403], [68.40348053, 23.7551403], [68.40348053, 23.75457954], [68.40319824, 23.75458336], [68.40319824, 23.75374985], [68.40291595, 23.75374985], [68.40291595, 23.7531929], [68.4026413, 23.75319481], [68.4026413, 23.75291634], [68.40235901, 23.75292015], [68.40235901, 23.75263977], [68.40207672, 23.75263977], [68.40207672, 23.75235939], [68.40180206, 23.7523613], [68.40180206, 23.75208282], [68.4015274, 23.75208282], [68.4015274, 23.75180626], [68.40097046, 23.75181007], [68.40097046, 23.75154114], [68.40042114, 23.75154114], [68.40042114, 23.75125122], [68.39958191, 23.75125122], [68.39958191, 23.75097084], [68.39930725, 23.75097275], [68.39930725, 23.7504158], [68.39958191, 23.75041962], [68.39958191, 23.75013924], [68.39985657, 23.75013924], [68.39985657, 23.75041962], [68.40041351, 23.7504158], [68.40041351, 23.75069427], [68.40097046, 23.75069427], [68.40097046, 23.75097275], [68.4015274, 23.75097084], [68.4015274, 23.75125122], [68.40180206, 23.75125122], [68.40180206, 23.75154114], [68.40207672, 23.75154114], [68.40207672, 23.75181007], [68.4034729, 23.75180626], [68.4034729, 23.75208282], [68.40402985, 23.75208282], [68.40402985, 23.7523613], [68.40458679, 23.75235939], [68.40458679, 23.75263977], [68.40486145, 23.75263977], [68.40486145, 23.75292015], [68.40513611, 23.75291634], [68.40513611, 23.75319481], [68.4054184, 23.7531929], [68.4054184, 23.75403023], [68.40513611, 23.75403023], [68.40513611, 23.75542068], [68.4054184, 23.75542068], [68.4054184, 23.75570107], [68.40569305, 23.75569344], [68.40569305, 23.75597191], [68.40625, 23.75597], [68.40625, 23.75625038], [68.40651703, 23.75625038], [68.40651703, 23.75653076], [68.40680695, 23.75653076], [68.40680695, 23.75681114], [68.4070816, 23.75680351], [68.4070816, 23.7570858], [68.40736389, 23.7570858], [68.40736389, 23.75736046], [68.40763855, 23.75735092], [68.40763855, 23.75764084], [68.40820313, 23.75764084], [68.40820313, 23.75792122], [68.40847015, 23.7579174], [68.40847015, 23.75819588], [68.40930176, 23.75819588], [68.40930176, 23.75847244], [68.4098587, 23.75847054], [68.4098587, 23.75875092], [68.41042328, 23.75875092], [68.41042328, 23.75902939], [68.41069794, 23.75902939], [68.41069794, 23.75930977], [68.4109726, 23.75930786], [68.4109726, 23.75958252], [68.41124725, 23.75958061], [68.41124725, 23.75986099], [68.41179657, 23.75986099], [68.41179657, 23.76013947], [68.41236115, 23.76013947], [68.41236115, 23.76041794], [68.41319275, 23.76041794], [68.41319275, 23.7606945], [68.41430664, 23.7606945], [68.41430664, 23.76097298], [68.41680908, 23.76097298], [68.41680908, 23.7606945], [68.41708374, 23.7606945], [68.41708374, 23.76041794], [68.4173584, 23.76041794], [68.4173584, 23.75875092], [68.41707611, 23.75875092], [68.41707611, 23.75708008], [68.41680908, 23.7570858], [68.41680908, 23.75652695], [68.41652679, 23.75653076], [68.41652679, 23.75597], [68.41625214, 23.75597191], [68.41625214, 23.75541687], [68.41596985, 23.75542068], [68.41596985, 23.75346947], [68.41569519, 23.75347137], [68.41569519, 23.7504158], [68.41542053, 23.75041962], [68.41542053, 23.74791908], [68.41571045, 23.74791908], [68.41571045, 23.74596977], [68.41596985, 23.74597168], [68.41596985, 23.74319649], [68.41625214, 23.74319649], [68.41625214, 23.74013901], [68.41652679, 23.74014282], [68.41652679, 23.73764038], [68.41680908, 23.73764038], [68.41680908, 23.73596764], [68.41708374, 23.73597145], [68.41708374, 23.73513985], [68.4173584, 23.73513985], [68.4173584, 23.73402977], [68.41764069, 23.73402977], [68.41764069, 23.73264122], [68.41792297, 23.73264122], [68.41792297, 23.73125076], [68.41819763, 23.73125076], [68.41819763, 23.72875023], [68.41845703, 23.72875023], [68.41845703, 23.72429848], [68.41819763, 23.72430611], [68.41819763, 23.7234726], [68.41791534, 23.7234726], [68.41791534, 23.72291756], [68.41764069, 23.72291946], [68.41764069, 23.72236061], [68.4173584, 23.72236061], [68.4173584, 23.72207832], [68.41708374, 23.72208405], [68.41708374, 23.71958351], [68.41680908, 23.71958351], [68.41680908, 23.71819687], [68.41652679, 23.71820068], [68.41652679, 23.7179203], [68.41625214, 23.7179203], [68.41625214, 23.71763992], [68.41596985, 23.71763992], [68.41596985, 23.71735954], [68.41569519, 23.71736145], [68.41569519, 23.71708488], [68.4154129, 23.71708488], [68.4154129, 23.71597481], [68.41513824, 23.71597481], [68.41513824, 23.71513939], [68.41485596, 23.71513939], [68.41485596, 23.71430969], [68.4145813, 23.71430969], [68.4145813, 23.71347046], [68.41430664, 23.71347237], [68.41430664, 23.71263885], [68.41401672, 23.71264267], [68.41401672, 23.71208191], [68.41374969, 23.71208382], [68.41374969, 23.71152687], [68.41348267, 23.71153259], [68.41348267, 23.71097183], [68.41319275, 23.71097183], [68.41319275, 23.71041679], [68.41291809, 23.71042252], [68.41291809, 23.71014023], [68.41265106, 23.71014023], [68.41265106, 23.70986176], [68.41236115, 23.70986176], [68.41236115, 23.70958328], [68.41208649, 23.70958328], [68.41208649, 23.70930481], [68.4118042, 23.70930481], [68.4118042, 23.70902824], [68.41152954, 23.70902824], [68.41152954, 23.70846748], [68.41124725, 23.7084713], [68.41124725, 23.70791626], [68.4109726, 23.70791817], [68.4109726, 23.70736122], [68.41069794, 23.70736122], [68.41069794, 23.70680809], [68.41042328, 23.70680809], [68.41042328, 23.7062397], [68.41014099, 23.70624924], [68.41014099, 23.70597267], [68.4098587, 23.70597267], [68.4098587, 23.70541763], [68.40957642, 23.70541954], [68.40957642, 23.70486069], [68.40930939, 23.70486069], [68.4092865, 23.70430946], [68.4090271, 23.70430946], [68.4090271, 23.70375061], [68.40875244, 23.70375061], [68.40875244, 23.70319939], [68.40847015, 23.70319939], [68.40847015, 23.70264053], [68.40820313, 23.70264053], [68.40820313, 23.70207977], [68.40791321, 23.70208549], [68.40791321, 23.69874954], [68.40763855, 23.69874954], [68.40763855, 23.69763947], [68.40735626, 23.69763947], [68.40735626, 23.69652939], [68.4070816, 23.69652939], [68.4070816, 23.69541931], [68.40680695, 23.69541931], [68.40680695, 23.6942997], [68.40652466, 23.69430542], [68.40652466, 23.69319534], [68.40625, 23.69319916], [68.40625, 23.69207954], [68.40597534, 23.69208336], [68.40597534, 23.69152832], [68.40569305, 23.69153023], [68.40569305, 23.69096947], [68.4054184, 23.69097137], [68.4054184, 23.69013977], [68.40513611, 23.69013977], [68.40513611, 23.68958092], [68.40486145, 23.68958282], [68.40486145, 23.68902779], [68.40458679, 23.68902969], [68.40458679, 23.68847084], [68.4043045, 23.68847466], [68.4043045, 23.6879158], [68.40402985, 23.68791962], [68.40402985, 23.68764114], [68.40374756, 23.68764114], [68.40374756, 23.68736076], [68.4034729, 23.68736076], [68.4034729, 23.68680573], [68.40319824, 23.68680954], [68.40319824, 23.68625069], [68.40291595, 23.68625069], [68.40291595, 23.68569183], [68.4026413, 23.68569374], [68.4026413, 23.68486023], [68.40235901, 23.68486023], [68.40235901, 23.68431282], [68.40207672, 23.68431282], [68.40207672, 23.68320274], [68.40180206, 23.68320274], [68.40180206, 23.68206978], [68.4015274, 23.68208313], [68.4015274, 23.68097305], [68.40125275, 23.68097305], [68.40125275, 23.68013954], [68.40097046, 23.68013954], [68.40097046, 23.67931747], [68.40071106, 23.67931747], [68.40071106, 23.67875099], [68.40042114, 23.67875099], [68.40042114, 23.67819023], [68.40013885, 23.67819595], [68.40013885, 23.67763901], [68.39985657, 23.67764091], [68.39985657, 23.67708015], [68.39958191, 23.67708588], [68.39958191, 23.67652512], [68.39930725, 23.67653084], [68.39930725, 23.67597008], [68.39902496, 23.67597198], [68.39902496, 23.67513847], [68.39875031, 23.67514038], [68.39875031, 23.6740303], [68.39848328, 23.6740303], [68.39848328, 23.67319107], [68.39819336, 23.67319489], [68.39819336, 23.6720829], [68.3979187, 23.6720829], [68.3979187, 23.67152786], [68.39763641, 23.67152977], [68.39763641, 23.67097092], [68.39736176, 23.67097282], [68.39736176, 23.67069435], [68.3970871, 23.67069435], [68.3970871, 23.67041588], [68.39679718, 23.6704216], [68.39679718, 23.66986084], [68.39653015, 23.66986084], [68.39653015, 23.66931152], [68.39624786, 23.66931152], [68.39624786, 23.66875076], [68.39597321, 23.66875076], [68.39597321, 23.66791916], [68.39569092, 23.66791916], [68.39569092, 23.66736031], [68.39541626, 23.66736031], [68.39541626, 23.66680908], [68.3951416, 23.66680908], [68.3951416, 23.66625023], [68.39541626, 23.66625023], [68.39541626, 23.66596985], [68.39569092, 23.66597176], [68.39569092, 23.66430664], [68.3951416, 23.66430664], [68.3951416, 23.66319656], [68.39485931, 23.66319656], [68.39485931, 23.66291428], [68.39428711, 23.66292], [68.39428711, 23.66236115], [68.39457703, 23.66236115], [68.39457703, 23.66152954], [68.39428711, 23.66152954], [68.39428711, 23.66125107], [68.39402771, 23.66125107], [68.39402771, 23.66096115], [68.39375305, 23.6609745], [68.39375305, 23.66069221], [68.39319611, 23.66069221], [68.39319611, 23.66041756], [68.39290619, 23.66041946], [68.39290619, 23.6601429], [68.39263916, 23.6601429], [68.39263916, 23.65986061], [68.39235687, 23.65986061], [68.39235687, 23.6601429], [68.39097595, 23.6601429], [68.39097595, 23.65847015], [68.39069366, 23.65847015], [68.39069366, 23.65791702], [68.39041901, 23.65792274], [68.39041901, 23.6570816], [68.39069366, 23.65708351], [68.39069366, 23.65486145], [68.39041901, 23.65486145], [68.39041901, 23.65430641], [68.39013672, 23.65430832], [68.39013672, 23.65402985], [68.38986206, 23.65402985], [68.38986206, 23.65374947], [68.38957977, 23.65374947], [68.38957977, 23.65347099], [68.38930511, 23.6534729], [68.38930511, 23.65319443], [68.38903046, 23.65319443], [68.38903046, 23.65291786], [68.38874817, 23.65291977], [68.38874817, 23.65236092], [68.38847351, 23.65236092], [68.38847351, 23.65208244], [68.38819122, 23.65208817], [68.38819122, 23.65180969], [68.38791656, 23.65180969], [68.38791656, 23.65153122], [68.38764191, 23.65153122], [68.38764191, 23.65125084], [68.38735962, 23.65125084], [68.38735962, 23.65069008], [68.38708496, 23.6506958], [68.38708496, 23.65041733], [68.38680267, 23.65042114], [68.38680267, 23.65014076], [68.38652802, 23.65014076], [68.38652802, 23.64986038], [68.38625336, 23.64986038], [68.38625336, 23.64958], [68.38597107, 23.64958572], [68.38597107, 23.64930344], [68.38569641, 23.64931107], [68.38569641, 23.64875031], [68.38540649, 23.64875031], [68.38540649, 23.64846992], [68.38513947, 23.64847183], [68.38513947, 23.64819336], [68.38485718, 23.64820099], [68.38485718, 23.64764023], [68.38458252, 23.64764023], [68.38458252, 23.64707947], [68.38430786, 23.64708138], [68.38430786, 23.64652824], [68.3840332, 23.64653015], [68.3840332, 23.64624977], [68.38375092, 23.64624977], [68.38375092, 23.64596176], [68.38346863, 23.6459713], [68.38346863, 23.64569473], [68.38291931, 23.64569473], [68.38291931, 23.64541626], [68.38263702, 23.64542007], [68.38263702, 23.64513969], [68.38234711, 23.64513969], [68.38234711, 23.64486122], [68.38208008, 23.64486122], [68.38208008, 23.64458275], [68.38153076, 23.64458275], [68.38153076, 23.64430618], [68.38124847, 23.6443119], [68.38124847, 23.64402962], [68.38041687, 23.64402962], [68.38041687, 23.64374924], [68.37960052, 23.64374924], [68.37960052, 23.64347076], [68.37875366, 23.64347267], [68.37875366, 23.6431942], [68.37791443, 23.6431942], [68.37791443, 23.64291573], [68.37652588, 23.64291573], [68.37652588, 23.6431942], [68.37541962, 23.64318848], [68.37541962, 23.6443119], [68.37569427, 23.64430618], [68.37569427, 23.64708138], [68.37596893, 23.64707947], [68.37596893, 23.64820099], [68.37625122, 23.64819336], [68.37625122, 23.64902687], [68.37652588, 23.64902687], [68.37652588, 23.6506958], [68.37680817, 23.65069008], [68.37680817, 23.65153122], [68.37708282, 23.65153122], [68.37708282, 23.65180969], [68.37735748, 23.65180969], [68.37735748, 23.65236092], [68.37763977, 23.65236092], [68.37763977, 23.65263939], [68.37791443, 23.65263939], [68.37791443, 23.65319443], [68.37819672, 23.65319443], [68.37819672, 23.6534729], [68.37847137, 23.65347099], [68.37847137, 23.65402985], [68.37874603, 23.65402985], [68.37874603, 23.65430832], [68.37902832, 23.65430641], [68.37902832, 23.65458298], [68.37928772, 23.65458107], [68.37928772, 23.65514946], [68.37960052, 23.65514946], [68.37960052, 23.6554184], [68.37985992, 23.65541649], [68.37985992, 23.65597153], [68.38014221, 23.65596962], [68.38014221, 23.65653038], [68.38041687, 23.65653038], [68.38041687, 23.65681267], [68.38069153, 23.65681267], [68.38069153, 23.65764046], [68.38096619, 23.65764046], [68.38096619, 23.65792274], [68.38124847, 23.65791702], [68.38124847, 23.65847015], [68.38153076, 23.65847015], [68.38153076, 23.65903282], [68.38181305, 23.65903282], [68.38181305, 23.65930939], [68.38208008, 23.65930939], [68.38208008, 23.65986061], [68.38234711, 23.65986061], [68.38234711, 23.66041946], [68.38263702, 23.66041756], [68.38263702, 23.6609745], [68.38291931, 23.66096115], [68.38291931, 23.66152954], [68.38319397, 23.66152763], [68.38319397, 23.66208267], [68.38346863, 23.66208267], [68.38346863, 23.66319656], [68.38375092, 23.66319084], [68.38375092, 23.66374969], [68.38402557, 23.66374969], [68.38402557, 23.66430664], [68.38430786, 23.66430664], [68.38430786, 23.66486168], [68.38458252, 23.66485977], [68.38458252, 23.66570091], [68.38485718, 23.66570091], [68.38485718, 23.66625023], [68.38513947, 23.66625023], [68.38513947, 23.66653061], [68.38540649, 23.66653061], [68.38540649, 23.66708755], [68.38569641, 23.66708755], [68.38569641, 23.66764069], [68.38597107, 23.66764069], [68.38597107, 23.66875076], [68.38625336, 23.66875076], [68.38625336, 23.66958427], [68.38652802, 23.66958427], [68.38652802, 23.67013931], [68.38625336, 23.67012978], [68.38625336, 23.67124939], [68.38652802, 23.67124939], [68.38652802, 23.67236137], [68.38680267, 23.67235947], [68.38680267, 23.67374992], [68.38709259, 23.67374992], [68.38709259, 23.67542076], [68.38735962, 23.67541695], [68.38735962, 23.67597198], [68.38764191, 23.67597008], [68.38764191, 23.67653084], [68.38791656, 23.67652512], [68.38791656, 23.67708588], [68.38819122, 23.67708588], [68.38819122, 23.67819595], [68.38848114, 23.67819023], [68.38848114, 23.67931747], [68.38874817, 23.67931747], [68.38874817, 23.68041992], [68.38903046, 23.68041611], [68.38903046, 23.6823616], [68.38930511, 23.6823616], [68.38930511, 23.68347168], [68.38957977, 23.68347168], [68.38957977, 23.68403244], [68.38986206, 23.68403244], [68.38986206, 23.68486023], [68.39013672, 23.68486023], [68.39013672, 23.68569374], [68.38986206, 23.68569374], [68.38986206, 23.68597221], [68.38957977, 23.68597221], [68.38957977, 23.68569374], [68.38930511, 23.68569374], [68.38930511, 23.6851387], [68.38903046, 23.6851387], [68.38903046, 23.68430519], [68.38874817, 23.68431282], [68.38874817, 23.68375015], [68.38847351, 23.68375015], [68.38847351, 23.6823616], [68.38819122, 23.6823616], [68.38819122, 23.68041611], [68.38791656, 23.68041992], [68.38791656, 23.67931747], [68.38764191, 23.67931747], [68.38764191, 23.67819023], [68.38735962, 23.67819595], [68.38735962, 23.67708588], [68.38708496, 23.67708588], [68.38708496, 23.67652512], [68.38680267, 23.67653084], [68.38680267, 23.67597008], [68.38652802, 23.67597198], [68.38652802, 23.67541695], [68.38625336, 23.67542076], [68.38625336, 23.67374992], [68.38597107, 23.67374992], [68.38597107, 23.67235947], [68.38569641, 23.67236137], [68.38569641, 23.67124939], [68.38540649, 23.67124939], [68.38540649, 23.67012978], [68.38513947, 23.67013931], [68.38513947, 23.6693058], [68.38485718, 23.66931152], [68.38485718, 23.66847038], [68.38458252, 23.66847229], [68.38458252, 23.66791725], [68.38430786, 23.66791916], [68.38430786, 23.66736031], [68.38402557, 23.66736031], [68.38402557, 23.66569519], [68.38375092, 23.66570091], [68.38375092, 23.66542053], [68.38346863, 23.66542053], [68.38346863, 23.66457939], [68.38319397, 23.66458321], [68.38319397, 23.66430664], [68.38291931, 23.66430664], [68.38291931, 23.66347313], [68.38263702, 23.66347313], [68.38263702, 23.66263962], [68.38234711, 23.66263962], [68.38234711, 23.66180992], [68.38208008, 23.66180992], [68.38208008, 23.66125107], [68.38181305, 23.66125107], [68.38181305, 23.66069031], [68.38153076, 23.66069221], [68.38153076, 23.66013908], [68.38124847, 23.6601429], [68.38124847, 23.65958023], [68.38097382, 23.65958214], [68.38097382, 23.65930557], [68.38069153, 23.65930939], [68.38069153, 23.65847015], [68.38041687, 23.65847015], [68.38041687, 23.65819359], [68.38014221, 23.65819359], [68.38014221, 23.65763855], [68.37985992, 23.65764046], [68.37985992, 23.65681267], [68.37960052, 23.65681267], [68.37960052, 23.65653038], [68.37928772, 23.65653038], [68.37928772, 23.65596962], [68.37902832, 23.65597153], [68.37902832, 23.65541649], [68.37874603, 23.6554184], [68.37874603, 23.65514946], [68.37847137, 23.65514946], [68.37847137, 23.65485954], [68.37819672, 23.65486145], [68.37819672, 23.65430641], [68.3779068, 23.65430832], [68.3779068, 23.65402985], [68.37763977, 23.65402985], [68.37763977, 23.65347099], [68.37735748, 23.6534729], [68.37735748, 23.65319443], [68.37708282, 23.65319443], [68.37708282, 23.65263939], [68.37680817, 23.65263939], [68.37680817, 23.65236092], [68.37652588, 23.65236092], [68.37652588, 23.65208244], [68.37625122, 23.65208817], [68.37625122, 23.65153122], [68.37596893, 23.65153122], [68.37596893, 23.65069008], [68.37569427, 23.6506958], [68.37569427, 23.64902687], [68.37541962, 23.64902687], [68.37541962, 23.64819336], [68.37513733, 23.64820099], [68.37513733, 23.64707947], [68.37486267, 23.64708138], [68.37486267, 23.64430618], [68.37458038, 23.6443119], [68.37458038, 23.64181137], [68.37486267, 23.64181137], [68.37486267, 23.64014816], [68.37458038, 23.64014816], [68.37458038, 23.63931084], [68.37403107, 23.63931084], [68.37403107, 23.63903046], [68.37346649, 23.63903046], [68.37346649, 23.63875008], [68.37291718, 23.63875008], [68.37291718, 23.63735962], [68.37264252, 23.63736153], [68.37264252, 23.63680649], [68.37236023, 23.63680077], [68.37236023, 23.63624954], [68.37208557, 23.63624954], [68.37208557, 23.63569641], [68.37180328, 23.63569641], [68.37180328, 23.63513947], [68.37152863, 23.63513947], [68.37152863, 23.63486099], [68.37124634, 23.63486099], [68.37124634, 23.63458061], [68.37097168, 23.63458252], [68.37097168, 23.63430405], [68.37069702, 23.63430977], [68.37069702, 23.63401985], [68.37041473, 23.63402748], [68.37041473, 23.63375282], [68.36985779, 23.63375282], [68.36985779, 23.63347054], [68.36930847, 23.63347244], [68.36930847, 23.63319206], [68.36875153, 23.63319206], [68.36875153, 23.6329174], [68.36818695, 23.63292122], [68.36818695, 23.63264275], [68.36763763, 23.63264275], [68.36763763, 23.63236046], [68.36708069, 23.63236046], [68.36708069, 23.63125038], [68.36680603, 23.63125038], [68.36680603, 23.63097954], [68.36624908, 23.63097954], [68.36624908, 23.63070107], [68.36569214, 23.63070107], [68.36569214, 23.63042259], [68.36514282, 23.63042259], [68.36514282, 23.6301403], [68.36460114, 23.6301403], [68.36460114, 23.62986183], [68.36402893, 23.62986183], [68.36402893, 23.62958336], [68.36347198, 23.62958336], [68.36347198, 23.62930489], [68.36208344, 23.62930489], [68.36208344, 23.62847137], [68.36180878, 23.62847137], [68.36180878, 23.62791634], [68.36152649, 23.62791824], [68.36152649, 23.62763977], [68.36096954, 23.62763977], [68.36096954, 23.62735939], [68.36069489, 23.6273613], [68.36069489, 23.62708282], [68.35986328, 23.62708282], [68.35986328, 23.6273613], [68.35958099, 23.62735939], [68.35958099, 23.62763977], [68.35874939, 23.62763977], [68.35874939, 23.62708092], [68.35847473, 23.62708282], [68.35847473, 23.62624931], [68.35817719, 23.62625122], [68.35817719, 23.62430954], [68.35791779, 23.62430954], [68.35791779, 23.62375069], [68.3576355, 23.62375069], [68.3576355, 23.62347221], [68.35736084, 23.62347221], [68.35736084, 23.62291527], [68.35708618, 23.62292099], [68.35708618, 23.62264061], [68.35679626, 23.62264061], [68.35679626, 23.62207985], [68.35652924, 23.62208557], [68.35652924, 23.62152863], [68.35320282, 23.62153053], [68.35320282, 23.61681175], [68.35041809, 23.61681175], [68.35041809, 23.61652946], [68.34986115, 23.61652946], [68.34986115, 23.61624908], [68.34819794, 23.61624908], [68.34819794, 23.61598015], [68.34792328, 23.61598015], [68.34792328, 23.61486053], [68.34819794, 23.61486053], [68.34819794, 23.61457825], [68.3484726, 23.61458397], [68.3484726, 23.6143055], [68.34874725, 23.61430931], [68.34874725, 23.61375046], [68.34902954, 23.61375046], [68.34902954, 23.61292076], [68.34931183, 23.61292076], [68.34931183, 23.61207962], [68.34958649, 23.61208344], [68.34958649, 23.61097145], [68.34986115, 23.61097145], [68.34986115, 23.61041451], [68.3501358, 23.61042023], [68.3501358, 23.61013985], [68.35041809, 23.61013985], [68.35041809, 23.60958099], [68.35069275, 23.60958481], [68.35069275, 23.60930634], [68.35098267, 23.60931015], [68.35098267, 23.60847092], [68.35124969, 23.60847473], [68.35124969, 23.60486031], [68.35097504, 23.60486031], [68.35097504, 23.60430527], [68.35069275, 23.6043129], [68.35069275, 23.60375023], [68.35041809, 23.60375023], [68.35041809, 23.60320282], [68.3501358, 23.60320282], [68.3501358, 23.60292244], [68.34986115, 23.60292244], [68.34986115, 23.60263824], [68.34958649, 23.60263824], [68.34958649, 23.60235977], [68.34902954, 23.60236168], [68.34902954, 23.60208321], [68.34874725, 23.60208321], [68.34874725, 23.60152817], [68.3484726, 23.60152817], [68.3484726, 23.60098076], [68.34819794, 23.60098076], [68.34819794, 23.60069084], [68.34791565, 23.60069466], [68.34791565, 23.60013962], [68.34764099, 23.60013962], [68.34764099, 23.59958076], [68.3473587, 23.59958267], [68.3473587, 23.59930611], [68.34707642, 23.59930992], [68.34707642, 23.59875107], [68.34680939, 23.59875107], [68.34680176, 23.59819031], [68.3465271, 23.59819412], [68.3465271, 23.59791756], [68.34625244, 23.59791756], [68.34625244, 23.59763908], [68.34570313, 23.59764099], [68.34570313, 23.59736061], [68.34541321, 23.59736061], [68.34541321, 23.59708023], [68.34486389, 23.59708595], [68.34486389, 23.59680367], [68.34430695, 23.59680939], [68.34430695, 23.59653091], [68.34401703, 23.59653091], [68.34401703, 23.59625053], [68.34347534, 23.59625053], [68.34347534, 23.59597206], [68.3429184, 23.59597206], [68.3429184, 23.5956955], [68.3418045, 23.5956955], [68.3418045, 23.59541512], [68.34069824, 23.59542084], [68.34069824, 23.59514046], [68.33957672, 23.59514046], [68.33957672, 23.59485054], [68.33930206, 23.59486389], [68.33930206, 23.59430313], [68.3390274, 23.59431076], [68.3390274, 23.59403038], [68.33847046, 23.59403038], [68.33847046, 23.59375], [68.33763885, 23.59375], [68.33763885, 23.59346962], [68.33708191, 23.59347153], [68.33708191, 23.59319305], [68.33625031, 23.59320068], [68.33625031, 23.5929203], [68.33569336, 23.5929203], [68.33569336, 23.59263992], [68.3354187, 23.59263992], [68.3354187, 23.59208107], [68.33569336, 23.59208107], [68.33569336, 23.59180641], [68.33429718, 23.59181023], [68.33429718, 23.59153175], [68.33374786, 23.59153175], [68.33374786, 23.59124947], [68.33291626, 23.59124947], [68.33291626, 23.59096909], [68.33235931, 23.5909729], [68.33235931, 23.59041595], [68.33207703, 23.59042168], [68.33207703, 23.58986092], [68.33180237, 23.58986092], [68.33180237, 23.58958054], [68.33125305, 23.58958244], [68.33125305, 23.58930588], [68.33040619, 23.5893116], [68.33040619, 23.58902931], [68.32736206, 23.58902931], [68.32736206, 23.5893116], [68.32596588, 23.5893116], [68.32596588, 23.58902931], [68.32569122, 23.58902931], [68.32569122, 23.58818817], [68.32402802, 23.58819389], [68.32402802, 23.58847237], [68.32319641, 23.58847046], [68.32319641, 23.58875084], [68.32263947, 23.58875084], [68.32263947, 23.58902931], [68.31819153, 23.58902931], [68.31819153, 23.5893116], [68.31597137, 23.58930588], [68.31597137, 23.58958244], [68.3154068, 23.58958054], [68.3154068, 23.58986092], [68.31458282, 23.58986092], [68.31458282, 23.58875084], [68.31430817, 23.58875084], [68.31430817, 23.58764076], [68.3154068, 23.58764076], [68.3154068, 23.58736038], [68.31569672, 23.58736038], [68.31569672, 23.58707809], [68.31597137, 23.58708382], [68.31597137, 23.58652878], [68.31626129, 23.58653069], [68.31626129, 23.58596992], [68.31652832, 23.58597183], [68.31652832, 23.5854187], [68.31680298, 23.58542061], [68.31680298, 23.58514023], [68.3170929, 23.58514023], [68.3170929, 23.58403015], [68.31626129, 23.58403015], [68.31626129, 23.58374977], [68.31569672, 23.58374977], [68.31569672, 23.58346939], [68.31485748, 23.5834713], [68.31485748, 23.58319664], [68.31346893, 23.58319664], [68.31346893, 23.5834713]]], [[[68.43736267, 23.50041962], [68.43736267, 23.50014114], [68.43791962, 23.50014114], [68.43791962, 23.49986076], [68.43818665, 23.49986076], [68.43818665, 23.49958038], [68.43930817, 23.49958229], [68.43930817, 23.49930573], [68.43959045, 23.49930954], [68.43959045, 23.49875069], [68.43930817, 23.49875069], [68.43930817, 23.49846077], [68.43846893, 23.49846077], [68.43846893, 23.49875069], [68.43791962, 23.49875069], [68.43791962, 23.49903107], [68.43736267, 23.49903107], [68.43736267, 23.49930954], [68.43708038, 23.49930573], [68.43708038, 23.49958229], [68.43682098, 23.49958038], [68.43682098, 23.50014114], [68.43708038, 23.50014114], [68.43708038, 23.50041962], [68.43736267, 23.50041962]]], [[[68.4679184, 23.52403259], [68.4679184, 23.5232029], [68.46819305, 23.5232029], [68.46819305, 23.52292252], [68.46848297, 23.52292252], [68.46848297, 23.52263069], [68.46875, 23.52263832], [68.46875, 23.52208328], [68.46902466, 23.52208328], [68.46902466, 23.52180481], [68.46930695, 23.52180481], [68.46930695, 23.52152824], [68.47041321, 23.52152824], [68.47041321, 23.52124977], [68.47070313, 23.52124977], [68.4706955, 23.52041626], [68.47041321, 23.52041817], [68.47041321, 23.51875114], [68.47013855, 23.51875114], [68.47013855, 23.51819038], [68.46986389, 23.5181942], [68.46986389, 23.51791763], [68.4695816, 23.51791763], [68.4695816, 23.51847267], [68.46930695, 23.51847076], [68.46930695, 23.51875114], [68.46901703, 23.51875114], [68.46901703, 23.51902962], [68.46848297, 23.51902962], [68.46848297, 23.51875114], [68.46819305, 23.51875114], [68.46819305, 23.51819038], [68.4679184, 23.5181942], [68.4679184, 23.51763916], [68.46736145, 23.51763916], [68.46736145, 23.51847267], [68.46763611, 23.51847076], [68.46763611, 23.51902962], [68.4679184, 23.51902962], [68.4679184, 23.51930809], [68.46819305, 23.51930618], [68.46819305, 23.51958275], [68.46847534, 23.51958275], [68.46848297, 23.51986122], [68.46763611, 23.51986122], [68.46763611, 23.5195694], [68.4668045, 23.51958275], [68.4668045, 23.51930618], [68.46652985, 23.51930809], [68.46652985, 23.51875114], [68.46624756, 23.51875114], [68.46624756, 23.51819038], [68.4659729, 23.5181942], [68.4659729, 23.51625061], [68.4651413, 23.51625061], [68.4651413, 23.51597023], [68.4651413, 23.5154171], [68.46430206, 23.5154171], [68.46430206, 23.51569557], [68.4640274, 23.51569557], [68.4640274, 23.51597214], [68.46375275, 23.51597214], [68.46376038, 23.51625061], [68.46347046, 23.51625061], [68.46347046, 23.5168705], [68.46347046, 23.51764107], [68.4631958, 23.51764107], [68.4631958, 23.51875114], [68.46376038, 23.51875114], [68.46376038, 23.51847076], [68.4640274, 23.51847267], [68.4640274, 23.5181942], [68.46458435, 23.5181942], [68.46458435, 23.51847267], [68.46485901, 23.51847076], [68.46485901, 23.51875114], [68.4651413, 23.51874924], [68.4651413, 23.51958275], [68.46541595, 23.5195694], [68.46541595, 23.52013969], [68.46569061, 23.52013969], [68.46569824, 23.52041817], [68.4659729, 23.52041626], [68.4659729, 23.52069473], [68.46624756, 23.52069092], [68.46624756, 23.52152824], [68.46652985, 23.52152824], [68.46652985, 23.52263832], [68.46624756, 23.52263069], [68.46624756, 23.52292252], [68.46652985, 23.52291679], [68.46652985, 23.52347183], [68.46708679, 23.52347183], [68.46708679, 23.52375031], [68.46736145, 23.52375031], [68.46736145, 23.52403259], [68.4679184, 23.52403259]]], [[[68.45847321, 23.60041809], [68.45847321, 23.60013962], [68.46153259, 23.60013962], [68.46152496, 23.59986115], [68.46291351, 23.59986115], [68.46290588, 23.59958076], [68.46347046, 23.59958267], [68.46347046, 23.59930611], [68.46430206, 23.59930992], [68.46430206, 23.59902954], [68.46485901, 23.59902954], [68.46485901, 23.59875107], [68.4651413, 23.59875107], [68.4651413, 23.59847069], [68.46569824, 23.5984726], [68.46569824, 23.59819412], [68.4659729, 23.59819412], [68.4659729, 23.59763908], [68.46624756, 23.59764099], [68.46624756, 23.59542084], [68.46652985, 23.59542084], [68.46652985, 23.59320068], [68.46679688, 23.59320068], [68.46679688, 23.5929203], [68.46708679, 23.5929203], [68.46708679, 23.59263992], [68.46736145, 23.59263992], [68.46736145, 23.59208107], [68.46763611, 23.59208107], [68.46763611, 23.59180641], [68.46736145, 23.59181023], [68.46736145, 23.59153175], [68.46708679, 23.59153175], [68.46708679, 23.59096909], [68.4668045, 23.5909729], [68.4668045, 23.59041595], [68.46652985, 23.59042168], [68.46652985, 23.58986092], [68.46624756, 23.58986092], [68.46624756, 23.58958054], [68.4659729, 23.58958244], [68.4659729, 23.5890274], [68.46569824, 23.58902931], [68.46569824, 23.58875084], [68.46541595, 23.58875084], [68.46541595, 23.58818817], [68.4651413, 23.58819389], [68.4651413, 23.58763885], [68.46485901, 23.58764076], [68.46485901, 23.58707809], [68.46458435, 23.58708382], [68.46458435, 23.58652878], [68.46430206, 23.58653069], [68.46430206, 23.58596992], [68.46375275, 23.58597183], [68.46375275, 23.58569527], [68.46347046, 23.58569908], [68.46347046, 23.58542061], [68.4631958, 23.58542061], [68.4631958, 23.58514023], [68.46290588, 23.58514023], [68.46290588, 23.58485985], [68.46263885, 23.58486176], [68.46263885, 23.58458328], [68.4623642, 23.58458328], [68.4623642, 23.58402824], [68.46208191, 23.58403015], [68.46208191, 23.58374977], [68.46180725, 23.58374977], [68.46180725, 23.58346939], [68.46152496, 23.5834713], [68.46152496, 23.58208466], [68.46125031, 23.58208466], [68.46125031, 23.58152771], [68.46153259, 23.58152962], [68.46153259, 23.57958031], [68.46180725, 23.57958221], [68.46180725, 23.57930565], [68.46208191, 23.57930946], [68.46208191, 23.5790329], [68.46235657, 23.5790329], [68.46235657, 23.57847023], [68.46263885, 23.57847023], [68.46263885, 23.5779171], [68.46235657, 23.57792282], [68.46235657, 23.57736015], [68.46208191, 23.57736015], [68.46208191, 23.57681274], [68.46180725, 23.57681274], [68.46180725, 23.57653236], [68.46125031, 23.57653236], [68.46125031, 23.57625008], [68.46069336, 23.57625008], [68.46069336, 23.5759716], [68.45930481, 23.5759716], [68.45930481, 23.57569504], [68.45847321, 23.57570076], [68.45847321, 23.57541847], [68.45735931, 23.57541847], [68.45735931, 23.57513809], [68.45652771, 23.57513809], [68.45652771, 23.57485962], [68.45541382, 23.57486153], [68.45541382, 23.57458305], [68.45402527, 23.57458305], [68.45402527, 23.57486153], [68.45318604, 23.57485962], [68.45318604, 23.57513809], [68.45236206, 23.57513809], [68.45236206, 23.57541847], [68.45182037, 23.57541847], [68.45182037, 23.5743084], [68.45207977, 23.5743084], [68.45207977, 23.57374001], [68.45236206, 23.57374954], [68.45236206, 23.5731945], [68.45124817, 23.5731945], [68.45124817, 23.57347298], [68.45041656, 23.57347298], [68.45041656, 23.57374954], [68.44985962, 23.57374001], [68.44985962, 23.57402992], [68.44902802, 23.57402992], [68.44902802, 23.57430077], [68.44819641, 23.57430649], [68.44819641, 23.57458305], [68.44791412, 23.57458305], [68.44791412, 23.57486153], [68.44735718, 23.57485962], [68.44735718, 23.57513809], [68.44708252, 23.57513809], [68.44708252, 23.57541847], [68.44680786, 23.57541847], [68.44680786, 23.57570076], [68.44625092, 23.57569504], [68.44625092, 23.5759716], [68.44596863, 23.5759697], [68.44596863, 23.57625008], [68.44541931, 23.57625008], [68.44541931, 23.57653236], [68.44513702, 23.57653236], [68.44513702, 23.57681274], [68.44486237, 23.57681274], [68.44486237, 23.57736015], [68.44458008, 23.57736015], [68.44458008, 23.57764053], [68.44430542, 23.57763863], [68.44430542, 23.57819366], [68.44458008, 23.57819176], [68.44458008, 23.57875061], [68.44486237, 23.57875061], [68.44486237, 23.57930946], [68.44541931, 23.57930565], [68.44541931, 23.57958221], [68.44568634, 23.57958031], [68.44568634, 23.58041954], [68.44625092, 23.58041763], [68.44625092, 23.58069229], [68.44680786, 23.58069229], [68.44680786, 23.58097458], [68.44708252, 23.58097458], [68.44708252, 23.58069229], [68.44763947, 23.58069229], [68.44763947, 23.58013916], [68.44957733, 23.58014107], [68.44957733, 23.57958031], [68.44985962, 23.57958221], [68.44985962, 23.57902718], [68.45014191, 23.5790329], [68.45014191, 23.57764053], [68.45041656, 23.57764053], [68.45041656, 23.57708168], [68.45124817, 23.57708359], [68.45124817, 23.57736015], [68.45207977, 23.57736015], [68.45207977, 23.57764053], [68.45291901, 23.57764053], [68.45291901, 23.57792282], [68.45319366, 23.5779171], [68.45319366, 23.57847023], [68.45347595, 23.57847023], [68.45347595, 23.5790329], [68.45375061, 23.5790329], [68.45375061, 23.57987022], [68.4540329, 23.57987022], [68.4540329, 23.58041954], [68.45430756, 23.58041763], [68.45430756, 23.58097458], [68.45456696, 23.58097076], [68.45456696, 23.58125114], [68.45485687, 23.58125114], [68.45485687, 23.58181], [68.45513916, 23.58181], [68.45513916, 23.58236122], [68.45541382, 23.58236122], [68.45541382, 23.5834713], [68.45597076, 23.58346939], [68.45597076, 23.58374977], [68.45625305, 23.58374977], [68.45625305, 23.58486176], [68.45652771, 23.58485985], [68.45652771, 23.58625031], [68.45680237, 23.58625031], [68.45680237, 23.58708382], [68.45707703, 23.58707809], [68.45707703, 23.58764076], [68.45680237, 23.58764076], [68.45680237, 23.58791924], [68.45513916, 23.58791733], [68.45513916, 23.58847237], [68.45375061, 23.58847237], [68.45375061, 23.58819389], [68.45291901, 23.58819389], [68.45291901, 23.58847237], [68.45263672, 23.58847237], [68.45263672, 23.5909729], [68.45291901, 23.59096909], [68.45291901, 23.59153175], [68.45319366, 23.59152794], [68.45319366, 23.59208107], [68.45291901, 23.59208107], [68.45291901, 23.59236145], [68.45263672, 23.59235954], [68.45263672, 23.59263992], [68.45236206, 23.59263992], [68.45236206, 23.59320068], [68.45263672, 23.59320068], [68.45263672, 23.59431076], [68.45236206, 23.59431076], [68.45236206, 23.59542084], [68.45263672, 23.59541512], [68.45263672, 23.59597206], [68.45291901, 23.59597015], [68.45291901, 23.59625053], [68.45318604, 23.59625053], [68.45318604, 23.59680939], [68.45347595, 23.59680367], [68.45347595, 23.59791756], [68.45375061, 23.59790993], [68.45375061, 23.59875107], [68.4540329, 23.59875107], [68.4540329, 23.59930992], [68.45430756, 23.59930611], [68.45430756, 23.59958267], [68.45485687, 23.59958076], [68.45485687, 23.59986115], [68.45513916, 23.59986115], [68.45513916, 23.60013962], [68.45569611, 23.60013962], [68.45569611, 23.60041809], [68.45847321, 23.60041809]]], [[[68.45625305, 23.62486076], [68.45625305, 23.62458038], [68.45708466, 23.6245842], [68.45708466, 23.62430763], [68.45819092, 23.62430954], [68.45819092, 23.62403107], [68.45874786, 23.62403107], [68.45874786, 23.62375069], [68.46180725, 23.62375069], [68.46180725, 23.62347031], [68.4623642, 23.62347221], [68.4623642, 23.62319565], [68.4631958, 23.62319565], [68.4631958, 23.62291527], [68.46485901, 23.62292099], [68.46485901, 23.62264061], [68.4651413, 23.62264061], [68.4651413, 23.62236023], [68.46541595, 23.62236023], [68.46541595, 23.62181091], [68.46569824, 23.62181091], [68.46569824, 23.62153053], [68.4659729, 23.62153053], [68.4659729, 23.62070084], [68.46624756, 23.62070084], [68.46624756, 23.61958122], [68.46652985, 23.61958122], [68.46652985, 23.61847115], [68.4668045, 23.61847115], [68.4668045, 23.6170826], [68.46652985, 23.6170826], [68.46652985, 23.61597252], [68.46624756, 23.61598015], [68.46624756, 23.61540031], [68.46624756, 23.6143055], [68.4659729, 23.61430931], [68.4659729, 23.61264038], [68.46569824, 23.61264038], [68.46569824, 23.60736084], [68.4659729, 23.60736084], [68.4659729, 23.60542107], [68.46624756, 23.60542107], [68.46624756, 23.60375023], [68.46652985, 23.60375023], [68.46652985, 23.60207748], [68.46624756, 23.60208321], [68.46624756, 23.60124969], [68.46652985, 23.60124969], [68.46652985, 23.60098076], [68.46569824, 23.60098076], [68.46569061, 23.60152817], [68.46375275, 23.60152817], [68.46375275, 23.60180473], [68.46291351, 23.60180473], [68.46291351, 23.60208321], [68.4623642, 23.60208321], [68.4623642, 23.60236168], [68.46180725, 23.60235977], [68.46180725, 23.60263824], [68.46153259, 23.60263824], [68.46153259, 23.60292244], [68.46098328, 23.60292244], [68.46098328, 23.60320282], [68.4604187, 23.60319519], [68.4604187, 23.60347176], [68.45986176, 23.60347176], [68.45986176, 23.60375023], [68.45929718, 23.60375023], [68.45929718, 23.60404015], [68.45874786, 23.60404015], [68.45874786, 23.6043129], [68.45762634, 23.6043129], [68.45762634, 23.60404015], [68.45735931, 23.60404015], [68.45735931, 23.60375023], [68.45680237, 23.60375023], [68.45680237, 23.60404015], [68.45625305, 23.60404015], [68.45625305, 23.6043129], [68.45485687, 23.6043129], [68.45485687, 23.60404015], [68.45430756, 23.60404015], [68.45430756, 23.60375023], [68.45375061, 23.60375023], [68.45375061, 23.60347176], [68.45319366, 23.60347176], [68.45319366, 23.60319519], [68.45263672, 23.60320282], [68.45263672, 23.60292244], [68.45182037, 23.60292244], [68.45182037, 23.60263824], [68.45153046, 23.60263824], [68.45153046, 23.60235977], [68.45124817, 23.60236168], [68.45124817, 23.60208321], [68.45069122, 23.60208321], [68.45069122, 23.60180473], [68.45014191, 23.60180473], [68.45014191, 23.60152817], [68.44957733, 23.60152817], [68.44957733, 23.60124969], [68.44930267, 23.60124969], [68.44930267, 23.60069084], [68.44875336, 23.60069466], [68.44875336, 23.60041618], [68.44847107, 23.60041809], [68.44847107, 23.59986115], [68.44819641, 23.59986115], [68.44819641, 23.59902954], [68.44790649, 23.59902954], [68.44790649, 23.59847069], [68.44763947, 23.5984726], [68.44763947, 23.59736061], [68.44735718, 23.59736061], [68.44735718, 23.59625053], [68.44708252, 23.59625053], [68.44708252, 23.59514046], [68.44680786, 23.59514046], [68.44680786, 23.59431076], [68.4465332, 23.59431076], [68.4465332, 23.59320068], [68.44625092, 23.59320068], [68.44625092, 23.59153175], [68.44596863, 23.59153175], [68.44596863, 23.59069061], [68.44569397, 23.59069443], [68.44569397, 23.59041595], [68.44513702, 23.59042168], [68.44513702, 23.59013939], [68.44458008, 23.59013939], [68.44458008, 23.58958054], [68.44513702, 23.58958244], [68.44513702, 23.58930588], [68.44541931, 23.5893116], [68.44541931, 23.58902931], [68.44568634, 23.58902931], [68.44568634, 23.58847046], [68.44235992, 23.58847237], [68.44235992, 23.58819389], [68.44180298, 23.58819389], [68.44180298, 23.58791733], [68.44124603, 23.58791924], [68.44124603, 23.58653069], [68.4404068, 23.58653069], [68.4404068, 23.58680916], [68.44013977, 23.58680916], [68.44013977, 23.58736038], [68.43985748, 23.58736038], [68.43985748, 23.58791924], [68.43958282, 23.58791733], [68.43958282, 23.58819389], [68.44041443, 23.58819389], [68.44041443, 23.58847237], [68.44013977, 23.58847046], [68.44013977, 23.58902931], [68.43846893, 23.58902931], [68.43846893, 23.5893116], [68.43875122, 23.5893116], [68.43875122, 23.59013939], [68.43902588, 23.59013939], [68.43902588, 23.59236145], [68.43930817, 23.59235954], [68.43930817, 23.59263992], [68.43985748, 23.59263992], [68.43985748, 23.5929203], [68.44013977, 23.59291649], [68.44013977, 23.59347153], [68.4404068, 23.59346962], [68.4404068, 23.59403038], [68.44069672, 23.59402847], [68.44069672, 23.59486389], [68.44097137, 23.59485054], [68.44097137, 23.59542084], [68.44125366, 23.59541512], [68.44125366, 23.59708595], [68.44152832, 23.59708023], [68.44152832, 23.59764099], [68.44125366, 23.59763908], [68.44125366, 23.5984726], [68.44152832, 23.59847069], [68.44152832, 23.59930992], [68.44125366, 23.59930611], [68.44125366, 23.59958267], [68.44097137, 23.59958267], [68.44097137, 23.60069466], [68.44069672, 23.60069466], [68.44069672, 23.60208321], [68.44097137, 23.60208321], [68.44097137, 23.60347176], [68.44069672, 23.60347176], [68.44069672, 23.60375023], [68.4404068, 23.60375023], [68.4404068, 23.60404015], [68.44013977, 23.60404015], [68.44013977, 23.60486031], [68.43985748, 23.60486031], [68.43985748, 23.60542107], [68.44013977, 23.60541725], [68.44013977, 23.60569382], [68.44041443, 23.60569382], [68.44041443, 23.60597229], [68.44013977, 23.60597038], [68.44013977, 23.60625076], [68.43985748, 23.60625076], [68.43985748, 23.60653114], [68.43959045, 23.60653114], [68.43959045, 23.60680962], [68.43769836, 23.6068058], [68.43708038, 23.6068058], [68.43708038, 23.60708237], [68.43680573, 23.60708237], [68.43680573, 23.60819244], [68.43708038, 23.60819244], [68.43708038, 23.60847473], [68.43736267, 23.60847092], [68.43736267, 23.60931015], [68.43708038, 23.60931015], [68.43708038, 23.61042023], [68.43680573, 23.61041451], [68.43682098, 23.61124992], [68.43653107, 23.61124992], [68.43653107, 23.61208344], [68.43624878, 23.61207962], [68.43624878, 23.61264038], [68.43597412, 23.61263847], [68.43597412, 23.61347198], [68.43569183, 23.61346817], [68.43569183, 23.61403084], [68.43541718, 23.61402893], [68.43541718, 23.61458397], [68.43514252, 23.61457825], [68.43514252, 23.61514091], [68.43486023, 23.61514091], [68.43486023, 23.61569405], [68.4345932, 23.61568832], [68.4345932, 23.61624908], [68.43486023, 23.61624908], [68.43486023, 23.61681175], [68.43514252, 23.61681175], [68.43514252, 23.61735916], [68.43541718, 23.61735916], [68.43541718, 23.61763954], [68.43624878, 23.61763954], [68.43624878, 23.61903954], [68.43653107, 23.61902809], [68.43653107, 23.61930466], [68.43763733, 23.61930466], [68.43763733, 23.61847115], [68.43818665, 23.61847115], [68.43818665, 23.61874962], [68.43846893, 23.61874962], [68.43846893, 23.61930466], [68.43875122, 23.61930466], [68.43875122, 23.61958122], [68.43958282, 23.61958122], [68.43958282, 23.6198616], [68.43985748, 23.6198597], [68.43985748, 23.62042046], [68.44124603, 23.62042046], [68.44124603, 23.61958122], [68.44374847, 23.61958122], [68.44374847, 23.62125015], [68.44403076, 23.62125015], [68.44403076, 23.62153053], [68.44431305, 23.62153053], [68.44431305, 23.62181091], [68.44819641, 23.62180328], [68.44819641, 23.62208557], [68.44847107, 23.62207985], [68.44847107, 23.62236023], [68.44876099, 23.62236023], [68.44876099, 23.62292099], [68.44902802, 23.62291527], [68.44902802, 23.62319565], [68.45096588, 23.62318993], [68.45096588, 23.62403107], [68.45182037, 23.62403107], [68.45182037, 23.62430954], [68.45207977, 23.62430954], [68.45207977, 23.62403107], [68.45291901, 23.62403107], [68.45291901, 23.62375069], [68.45541382, 23.62375069], [68.45541382, 23.6245842], [68.45569611, 23.62458038], [68.45569611, 23.62486076], [68.45625305, 23.62486076]]], [[[68.2765274, 23.79597473], [68.27708435, 23.79597473], [68.27708435, 23.79624939], [68.27735901, 23.79624939], [68.27735901, 23.79652786], [68.27791595, 23.79652023], [68.27791595, 23.79681015], [68.27902985, 23.79680443], [68.27902985, 23.7970829], [68.28013611, 23.7970829], [68.28013611, 23.79736137], [68.2804184, 23.79735947], [68.2804184, 23.79763985], [68.28069305, 23.79763985], [68.28069305, 23.79792023], [68.28097534, 23.79791451], [68.28097534, 23.79819679], [68.28236389, 23.79819679], [68.28236389, 23.79847145], [68.28375244, 23.79846954], [68.28375244, 23.79874992], [68.28514099, 23.79874992], [68.28514099, 23.7990303], [68.28624725, 23.7990303], [68.28624725, 23.79931068], [68.2876358, 23.79931068], [68.2876358, 23.79959106], [68.28874969, 23.79958344], [68.28874969, 23.79986191], [68.29069519, 23.79986191], [68.29069519, 23.80097198], [68.29152679, 23.80096817], [68.29152679, 23.80125046], [68.29264069, 23.80125046], [68.29264069, 23.80153084], [68.29374695, 23.80153084], [68.29374695, 23.80180931], [68.29430389, 23.8018055], [68.29430389, 23.80208397], [68.29486084, 23.80207825], [68.29486084, 23.80236053], [68.29541779, 23.80236053], [68.29541779, 23.80265045], [68.2959671, 23.80265045], [68.2959671, 23.80291939], [68.29652405, 23.80291748], [68.29652405, 23.80319405], [68.29708099, 23.80319405], [68.29708099, 23.80347252], [68.29763794, 23.80347061], [68.29763794, 23.80374908], [68.29819489, 23.80374908], [68.29819489, 23.8045826], [68.29792023, 23.80458069], [68.29792023, 23.81014061], [68.29763794, 23.8101387], [68.29763794, 23.81097221], [68.29736328, 23.81097031], [68.29736328, 23.81153107], [68.29708099, 23.81152534], [68.29708099, 23.8120842], [68.29680634, 23.81208038], [68.29680634, 23.81236076], [68.29624939, 23.81236076], [68.29624939, 23.81264114], [68.29569244, 23.81264114], [68.29569244, 23.81291962], [68.29486084, 23.81291771], [68.29486084, 23.81319427], [68.29430389, 23.81319427], [68.29430389, 23.81347275], [68.29402924, 23.81347084], [68.29402924, 23.81375122], [68.29264069, 23.81375122], [68.29264069, 23.81402969], [68.2923584, 23.81402969], [68.2923584, 23.81430817], [68.29209137, 23.81430817], [68.29209137, 23.81459045], [68.29180908, 23.81458282], [68.29180908, 23.8148613], [68.29152679, 23.81485748], [68.29152679, 23.81513977], [68.29096985, 23.81513977], [68.29096985, 23.81541824], [68.29069519, 23.81541634], [68.29069519, 23.81569481], [68.2904129, 23.81569481], [68.2904129, 23.81597137], [68.29013824, 23.81597137], [68.29013824, 23.81680489], [68.29069519, 23.81680489], [68.29069519, 23.81708336], [68.29125214, 23.81708336], [68.29125214, 23.81736183], [68.29180908, 23.81736183], [68.29180908, 23.81764984], [68.29209137, 23.81764984], [68.29209137, 23.81792259], [68.29264069, 23.81792259], [68.29264069, 23.81820107], [68.29319763, 23.81819534], [68.29319763, 23.81847191], [68.29347229, 23.81847191], [68.29347229, 23.81875038], [68.29402924, 23.81875038], [68.29402924, 23.81903267], [68.29458618, 23.81903267], [68.29458618, 23.81931114], [68.29569244, 23.81930542], [68.29569244, 23.81958389], [68.29651642, 23.81958008], [68.29651642, 23.81986046], [68.29736328, 23.81986046], [68.29736328, 23.82014275], [68.29763794, 23.82014275], [68.29763794, 23.82042122], [68.29846954, 23.8204174], [68.29846954, 23.82069206], [68.29902649, 23.82069206], [68.29902649, 23.82097244], [68.29985809, 23.82097054], [68.29985809, 23.82125092], [68.30042267, 23.82125092], [68.30042267, 23.82152939], [68.30097198, 23.82152939], [68.30097198, 23.82180977], [68.30152893, 23.82180405], [68.30152893, 23.82208252], [68.30236053, 23.82208061], [68.30236053, 23.82236099], [68.3034668, 23.82236099], [68.3034668, 23.82263947], [68.30374908, 23.82263947], [68.30374908, 23.82291985], [68.30430603, 23.82291412], [68.30430603, 23.82319641], [68.30569458, 23.82319641], [68.30569458, 23.82347488], [68.30680847, 23.82347107], [68.30680847, 23.82374954], [68.3079071, 23.82374954], [68.3079071, 23.82347107], [68.30958557, 23.82347488], [68.30958557, 23.82319641], [68.31014252, 23.82319641], [68.31014252, 23.82291412], [68.31069183, 23.82291985], [68.31069183, 23.82263947], [68.31096649, 23.82263947], [68.31096649, 23.82236099], [68.31124878, 23.82236099], [68.31124878, 23.82208061], [68.31153107, 23.82208252], [68.31153107, 23.82180405], [68.31181335, 23.82180977], [68.31181335, 23.82152939], [68.31263733, 23.82152939], [68.31263733, 23.82125092], [68.31291962, 23.82125092], [68.31291962, 23.82069016], [68.31319427, 23.82069206], [68.31319427, 23.8204174], [68.31346893, 23.82042122], [68.31346893, 23.81986046], [68.31375122, 23.81986046], [68.31375122, 23.81931114], [68.31402588, 23.81931114], [68.31402588, 23.81820107], [68.31430817, 23.81820107], [68.31430817, 23.81792259], [68.31458282, 23.81792259], [68.31458282, 23.81764984], [68.31485748, 23.81764984], [68.31485748, 23.81736183], [68.31513977, 23.81736183], [68.31513977, 23.81652832], [68.3154068, 23.81653023], [68.3154068, 23.81568909], [68.31569672, 23.81569481], [68.31569672, 23.81513977], [68.31597137, 23.81513977], [68.31597137, 23.81430817], [68.31626129, 23.81430817], [68.31626129, 23.81402969], [68.31652832, 23.81402969], [68.31652832, 23.81291962], [68.31680298, 23.81291962], [68.31680298, 23.81236076], [68.3170929, 23.81236076], [68.31708527, 23.81152534], [68.31735992, 23.81153107], [68.31735992, 23.81014061], [68.31764221, 23.81014061], [68.31764221, 23.80875015], [68.31791687, 23.80875015], [68.31791687, 23.80820084], [68.31819153, 23.80820084], [68.31819153, 23.80764008], [68.31846619, 23.80764008], [68.31846619, 23.8073597], [68.31874847, 23.8073616], [68.31874847, 23.80708122], [68.31903076, 23.80708122], [68.31903076, 23.80680466], [68.31930542, 23.80680466], [68.31930542, 23.80652809], [68.31958008, 23.80653191], [68.31958008, 23.80624962], [68.32013702, 23.80624962], [68.32013702, 23.80597115], [68.32041931, 23.80597115], [68.32041931, 23.80569458], [68.32069397, 23.80569458], [68.32069397, 23.80541611], [68.3215332, 23.80542183], [68.3215332, 23.80486107], [68.32236481, 23.80486107], [68.32235718, 23.80431175], [68.32206726, 23.80431175], [68.32206726, 23.80374908], [68.32180786, 23.80374908], [68.32180786, 23.80318832], [68.32152557, 23.80319405], [68.32152557, 23.80291748], [68.32125092, 23.80291939], [68.32125092, 23.80236053], [68.32096863, 23.80236053], [68.32096863, 23.80180931], [68.32068634, 23.80180931], [68.32068634, 23.80125046], [68.32041931, 23.80125046], [68.32041931, 23.8006897], [68.32013702, 23.80069351], [68.32013702, 23.80041885], [68.31986237, 23.80042076], [68.31986237, 23.79985809], [68.31958008, 23.79986191], [68.31958008, 23.79930687], [68.31929779, 23.79931068], [68.31929779, 23.7990303], [68.31903076, 23.7990303], [68.31903076, 23.79846954], [68.31874847, 23.79847145], [68.31874847, 23.79819679], [68.31847382, 23.79819679], [68.31847382, 23.79763794], [68.31819153, 23.79763985], [68.31819153, 23.79708099], [68.31791687, 23.7970829], [68.31791687, 23.79624939], [68.31764221, 23.79624939], [68.31764221, 23.79514122], [68.31735992, 23.79514122], [68.31735992, 23.79430962], [68.3170929, 23.79430962], [68.3170929, 23.79346275], [68.31680298, 23.79347229], [68.31680298, 23.79291725], [68.31652832, 23.79292107], [68.31652832, 23.79236031], [68.31625366, 23.79236031], [68.31625366, 23.7915287], [68.31597137, 23.79153252], [68.31597137, 23.79071045], [68.31569672, 23.79071045], [68.31569672, 23.79014015], [68.3154068, 23.79014015], [68.3154068, 23.78930092], [68.31513977, 23.78930473], [68.31513977, 23.78874969], [68.31485748, 23.78874969], [68.31485748, 23.78847122], [68.31458282, 23.78847313], [68.31458282, 23.78819466], [68.31430817, 23.78819466], [68.31430817, 23.78763962], [68.31458282, 23.78764915], [68.31458282, 23.78736115], [68.31430817, 23.78736115], [68.31430817, 23.78708076], [68.31375122, 23.78708267], [68.31375122, 23.78680611], [68.31402588, 23.78680992], [68.31402588, 23.78569031], [68.31430817, 23.78569412], [68.31430817, 23.78513908], [68.31458282, 23.78514099], [68.31458282, 23.78347015], [68.31430817, 23.78347206], [68.31430817, 23.78097153], [68.31402588, 23.78097153], [68.31402588, 23.77930641], [68.31430817, 23.77931023], [68.31430817, 23.77792168], [68.31458282, 23.77792168], [68.31458282, 23.77042007], [68.31485748, 23.77042007], [68.31485748, 23.76847076], [68.31513977, 23.76847267], [68.31513977, 23.76652718], [68.3154068, 23.76654053], [68.3154068, 23.76458168], [68.31569672, 23.76458359], [68.31569672, 23.76319504], [68.31597137, 23.76320267], [68.31597137, 23.76235962], [68.31625366, 23.76236153], [68.31625366, 23.76124954], [68.31652832, 23.76124954], [68.31652832, 23.76041031], [68.31680298, 23.76041794], [68.31680298, 23.75958252], [68.31708527, 23.75958252], [68.31708527, 23.75875092], [68.31735992, 23.75875092], [68.31735992, 23.75764084], [68.31764221, 23.75764084], [68.31764221, 23.75681114], [68.31791687, 23.75681114], [68.31791687, 23.75597], [68.31819153, 23.75597191], [68.31819153, 23.7551384], [68.31846619, 23.7551403], [68.31846619, 23.75431061], [68.31874847, 23.75431061], [68.31874847, 23.75346947], [68.31903076, 23.75347137], [68.31903076, 23.75263977], [68.31929779, 23.75263977], [68.31929779, 23.75181007], [68.31958008, 23.75181007], [68.31958008, 23.75097084], [68.31986237, 23.75097275], [68.31986237, 23.74791718], [68.32013702, 23.74791908], [68.32013702, 23.74596977], [68.32041931, 23.74597168], [68.32041931, 23.74541855], [68.32069397, 23.74541855], [68.32069397, 23.74513626], [68.32096863, 23.74514008], [68.32096863, 23.7448597], [68.32125092, 23.7448616], [68.32125092, 23.74430656], [68.32152557, 23.74430656], [68.32152557, 23.74347305], [68.32180786, 23.74347305], [68.32180786, 23.74263954], [68.32206726, 23.74263954], [68.32206726, 23.74208069], [68.32236481, 23.7420826], [68.32236481, 23.74124908], [68.32263947, 23.7412529], [68.32263947, 23.74041939], [68.32290649, 23.74041939], [68.32290649, 23.73986053], [68.32319641, 23.73986053], [68.32319641, 23.73931122], [68.32347107, 23.73931122], [68.32347107, 23.73792267], [68.32375336, 23.73792267], [68.32375336, 23.7365303], [68.32402802, 23.7365303], [68.32402802, 23.73513985], [68.32430267, 23.73513985], [68.32430267, 23.73430824], [68.32402802, 23.73430824], [68.32402802, 23.73402977], [68.32180786, 23.73402977], [68.32180786, 23.733181], [68.32152557, 23.73319435], [68.32152557, 23.73291779], [68.32096863, 23.73291969], [68.32096863, 23.73264122], [68.32013702, 23.73264122], [68.32013702, 23.73236084], [68.31929779, 23.73236084], [68.31929779, 23.73208046], [68.31819153, 23.73208237], [68.31819153, 23.73180771], [68.31458282, 23.73180771], [68.31458282, 23.73208237], [68.31375122, 23.73208237], [68.31375122, 23.73152542], [68.31346893, 23.73153114], [68.31346893, 23.73097038], [68.31319427, 23.73097229], [68.31319427, 23.73069572], [68.31291962, 23.73069572], [68.31291962, 23.73041534], [68.30735779, 23.7304306], [68.30735779, 23.73014069], [68.30625153, 23.73014069], [68.30625153, 23.72986031], [68.30486298, 23.72986031], [68.30486298, 23.72957993], [68.30374908, 23.72958565], [68.30374908, 23.72930336], [68.30291748, 23.72931099], [68.30291748, 23.72903061], [68.30236053, 23.72903061], [68.30236053, 23.72875023], [68.30152893, 23.72875023], [68.30152893, 23.72846985], [68.29985809, 23.72847176], [68.29985809, 23.72819328], [68.29930878, 23.72820091], [68.29930878, 23.72792053], [68.29875183, 23.72792053], [68.29875183, 23.72764015], [68.29818726, 23.72764015], [68.29818726, 23.72737122], [68.29792023, 23.72737122], [68.29792023, 23.72707939], [68.29763794, 23.7270813], [68.29763794, 23.72680473], [68.29708099, 23.72680473], [68.29708099, 23.72652817], [68.29680634, 23.72653008], [68.29680634, 23.72624969], [68.29651642, 23.72624969], [68.29651642, 23.72597122], [68.29624939, 23.72597122], [68.29624939, 23.72624969], [68.29512787, 23.72624969], [68.29512787, 23.72653008], [68.29430389, 23.72652817], [68.29430389, 23.72680473], [68.29347229, 23.72680473], [68.29347229, 23.7270813], [68.29292297, 23.72707939], [68.29292297, 23.72737122], [68.29209137, 23.72737122], [68.29209137, 23.72764015], [68.29125214, 23.72764015], [68.29125214, 23.72792053], [68.29096985, 23.72792053], [68.29096985, 23.72820091], [68.2904129, 23.72819328], [68.2904129, 23.72847176], [68.28985596, 23.72846985], [68.28985596, 23.72875023], [68.2895813, 23.72875023], [68.2895813, 23.72903061], [68.2893219, 23.72903061], [68.2893219, 23.72931099], [68.28902435, 23.72930336], [68.28902435, 23.72958565], [68.28847504, 23.72958565], [68.28848267, 23.72986031], [68.28819275, 23.72986031], [68.28819275, 23.7304306], [68.28791809, 23.73041534], [68.28791809, 23.73069572], [68.2876358, 23.73069572], [68.2876358, 23.73097229], [68.28736115, 23.73097038], [68.28736115, 23.73125076], [68.2868042, 23.73125076], [68.2868042, 23.73208237], [68.28652954, 23.73208046], [68.28652954, 23.73264122], [68.28624725, 23.73264122], [68.28624725, 23.73374939], [68.28652954, 23.73374939], [68.28652954, 23.7345829], [68.2868042, 23.7345829], [68.2868042, 23.73486137], [68.28708649, 23.73485947], [68.28708649, 23.73513985], [68.28736115, 23.73513985], [68.28736115, 23.73541832], [68.2876358, 23.73541641], [68.2876358, 23.73569489], [68.28819275, 23.73569489], [68.28819275, 23.73597145], [68.28847504, 23.73597145], [68.28847504, 23.73624992], [68.28985596, 23.73624039], [68.28985596, 23.7365303], [68.29070282, 23.7365303], [68.29070282, 23.73681259], [68.29152679, 23.73680496], [68.29152679, 23.73708344], [68.29180908, 23.73708344], [68.29180908, 23.73736191], [68.29264069, 23.73736191], [68.29264069, 23.73764038], [68.29292297, 23.73764038], [68.29292297, 23.73792267], [68.29319763, 23.73791695], [68.29319763, 23.73847008], [68.29347229, 23.73847008], [68.29347229, 23.73875046], [68.29374695, 23.73875046], [68.29374695, 23.73903275], [68.29402924, 23.73903275], [68.29402924, 23.73931122], [68.29429626, 23.73931122], [68.29429626, 23.73986053], [68.29458618, 23.73986053], [68.29458618, 23.7412529], [68.29429626, 23.7412529], [68.29429626, 23.74237061], [68.29402924, 23.74237061], [68.29402924, 23.74291992], [68.29374695, 23.7429142], [68.29374695, 23.74319649], [68.29347229, 23.74319649], [68.29347229, 23.74347305], [68.29319763, 23.74347115], [68.29319763, 23.74403], [68.29291534, 23.74402618], [68.29291534, 23.74430656], [68.29264069, 23.74430656], [68.29264069, 23.74458313], [68.2923584, 23.74458313], [68.2923584, 23.7448616], [68.29209137, 23.7448597], [68.29209137, 23.74514008], [68.29180908, 23.74513626], [68.29180908, 23.74541855], [68.29152679, 23.74541092], [68.29152679, 23.74570084], [68.29125214, 23.74569511], [68.29125214, 23.74597168], [68.29096985, 23.74596977], [68.29096985, 23.74625015], [68.29070282, 23.74625015], [68.29070282, 23.74653053], [68.2904129, 23.74653053], [68.2904129, 23.74681091], [68.29013824, 23.74681091], [68.29013824, 23.74736023], [68.28985596, 23.74736023], [68.28985596, 23.74764061], [68.2895813, 23.74764061], [68.2895813, 23.74791908], [68.28902435, 23.74791718], [68.28902435, 23.74847221], [68.28874969, 23.74847031], [68.28874969, 23.74931145], [68.28847504, 23.74930573], [68.28847504, 23.7495842], [68.28819275, 23.74957848], [68.28819275, 23.74986076], [68.28791809, 23.74986076], [68.28791809, 23.75069427], [68.2876358, 23.75069427], [68.2876358, 23.75097275], [68.28736115, 23.75097084], [68.28736115, 23.75181007], [68.28708649, 23.75180626], [68.28708649, 23.75319481], [68.2868042, 23.75319481], [68.2868042, 23.75347137], [68.28708649, 23.75346947], [68.28708649, 23.75431061], [68.28652954, 23.75430489], [68.28652954, 23.75458336], [68.28569794, 23.75458336], [68.28569794, 23.75430489], [68.28542328, 23.75431061], [68.28542328, 23.75235939], [68.28569794, 23.7523613], [68.28569794, 23.75124931], [68.2859726, 23.75125122], [68.2859726, 23.75013924], [68.28624725, 23.75013924], [68.28624725, 23.74957848], [68.28652954, 23.7495842], [68.28652954, 23.74875069], [68.28679657, 23.74875069], [68.28679657, 23.74847031], [68.28708649, 23.74847221], [68.28708649, 23.74819374], [68.28736115, 23.74819374], [68.28736115, 23.74708366], [68.2876358, 23.74708366], [68.2876358, 23.74652863], [68.28791809, 23.74653053], [68.28791809, 23.74625015], [68.28819275, 23.74625015], [68.28819275, 23.74570084], [68.28848267, 23.74570084], [68.28848267, 23.74541092], [68.28874969, 23.74541855], [68.28874969, 23.74513626], [68.28903198, 23.74514008], [68.28903198, 23.7448597], [68.2895813, 23.7448616], [68.2895813, 23.74458313], [68.28986359, 23.74458313], [68.28986359, 23.74430656], [68.29013824, 23.74430656], [68.29013824, 23.74402618], [68.29070282, 23.74403], [68.29070282, 23.74374962], [68.29152679, 23.74374962], [68.29152679, 23.74319077], [68.29180908, 23.74319649], [68.29180908, 23.74263954], [68.29209137, 23.74263954], [68.29208374, 23.74236107], [68.2923584, 23.74237061], [68.2923584, 23.74208069], [68.29264069, 23.7420826], [68.29264069, 23.74180412], [68.29292297, 23.74180984], [68.29292297, 23.74069023], [68.29319763, 23.74069214], [68.29319763, 23.74041748], [68.29292297, 23.74041939], [68.29292297, 23.74014282], [68.29264069, 23.74014282], [68.29264069, 23.73986053], [68.2923584, 23.73986053], [68.2923584, 23.73958015], [68.29208374, 23.73958206], [68.29208374, 23.7393055], [68.29152679, 23.73931122], [68.29152679, 23.73903275], [68.29096985, 23.73903275], [68.29096985, 23.73875046], [68.29013824, 23.73875046], [68.29013824, 23.73847008], [68.28930664, 23.73847008], [68.28930664, 23.73819351], [68.28902435, 23.73819351], [68.28902435, 23.73791695], [68.28848267, 23.73792267], [68.28848267, 23.73764038], [68.28791809, 23.73764038], [68.28791809, 23.73736191], [68.2876358, 23.73736191], [68.2876358, 23.73708344], [68.28708649, 23.73708344], [68.28708649, 23.73680496], [68.28679657, 23.73681259], [68.28679657, 23.7365303], [68.28652954, 23.7365303], [68.28652954, 23.73624039], [68.28624725, 23.73624992], [68.28624725, 23.73597145], [68.28569794, 23.73597145], [68.28569794, 23.73569489], [68.28541565, 23.73569489], [68.28541565, 23.73513985], [68.28514099, 23.73513985], [68.28514099, 23.73457909], [68.2848587, 23.7345829], [68.2848587, 23.73208427], [68.28514099, 23.73208427], [68.28514099, 23.73152542], [68.28542328, 23.73153114], [68.28542328, 23.73069], [68.28569794, 23.73069572], [68.28569794, 23.73041534], [68.2859726, 23.7304306], [68.2859726, 23.73014069], [68.28624725, 23.73014069], [68.28624725, 23.72986031], [68.28652954, 23.72986031], [68.28652954, 23.72957993], [68.2868042, 23.72958565], [68.2868042, 23.72930336], [68.28708649, 23.72931099], [68.28708649, 23.72903061], [68.28736115, 23.72903061], [68.28736115, 23.72875023], [68.2876358, 23.72875023], [68.2876358, 23.72846985], [68.28791809, 23.72847176], [68.28791809, 23.72819328], [68.28819275, 23.72820091], [68.28819275, 23.72792053], [68.28848267, 23.72792053], [68.28848267, 23.72764015], [68.28874969, 23.72764015], [68.28874969, 23.72737122], [68.2893219, 23.72737122], [68.2893219, 23.72707939], [68.28986359, 23.7270813], [68.28986359, 23.72680473], [68.2904129, 23.72680473], [68.2904129, 23.72652817], [68.29070282, 23.72653008], [68.29070282, 23.72624969], [68.29152679, 23.72624969], [68.29152679, 23.72597122], [68.2923584, 23.72597122], [68.2923584, 23.72569466], [68.29291534, 23.72569466], [68.29291534, 23.72541618], [68.29347229, 23.72542191], [68.29347229, 23.72513962], [68.29374695, 23.72513962], [68.29374695, 23.72486115], [68.29429626, 23.72486115], [68.29429626, 23.72402954], [68.29458618, 23.72402954], [68.29458618, 23.7231884], [68.29430389, 23.72319412], [68.29430389, 23.72236061], [68.29402924, 23.72236061], [68.29402924, 23.72207832], [68.29374695, 23.72208405], [68.29374695, 23.72180557], [68.29347229, 23.72180939], [68.29347229, 23.72153091], [68.29292297, 23.72153091], [68.29292297, 23.721241], [68.29264069, 23.72125053], [68.29264069, 23.72097206], [68.2923584, 23.72097206], [68.2923584, 23.72069359], [68.29208374, 23.72069359], [68.29208374, 23.72041893], [68.29180908, 23.72042084], [68.29180908, 23.72014046], [68.29152679, 23.72014046], [68.29152679, 23.7195797], [68.29125214, 23.71958351], [68.29125214, 23.71930695], [68.29096985, 23.71931076], [68.29096985, 23.71903038], [68.28985596, 23.71903038], [68.28985596, 23.71875], [68.28930664, 23.71875], [68.28930664, 23.71791458], [68.28903198, 23.7179203], [68.28903198, 23.71735954], [68.28874969, 23.71736145], [68.28874969, 23.71708488], [68.28847504, 23.71708488], [68.28847504, 23.71652794], [68.28819275, 23.71652985], [68.28819275, 23.71624947], [68.28791809, 23.71624947], [68.28791809, 23.71597099], [68.2876358, 23.71597481], [68.2876358, 23.71541405], [68.28736115, 23.71543121], [68.28736115, 23.71513939], [68.28679657, 23.71513939], [68.28679657, 23.71486092], [68.28652954, 23.71486092], [68.28652954, 23.71458054], [68.28624725, 23.71458244], [68.28624725, 23.71430588], [68.2859726, 23.71430969], [68.2859726, 23.71403122], [68.28569794, 23.71403122], [68.28569794, 23.71347046], [68.28541565, 23.71347237], [68.28541565, 23.71319389], [68.28514099, 23.71319389], [68.28514099, 23.71263885], [68.2848587, 23.71264267], [68.2848587, 23.71236038], [68.28457642, 23.71236038], [68.28457642, 23.71181107], [68.28430939, 23.71181107], [68.28430176, 23.71153259], [68.2840271, 23.71153259], [68.2840271, 23.71097183], [68.28375244, 23.71097183], [68.28375244, 23.71069527], [68.28347015, 23.7107029], [68.28347015, 23.71042252], [68.28318787, 23.71042252], [68.28318787, 23.70986176], [68.28263855, 23.70986176], [68.28263855, 23.71014023], [68.28235626, 23.71014023], [68.28235626, 23.71042252], [68.28180695, 23.71042252], [68.28180695, 23.7107029], [68.28152466, 23.71069527], [68.28152466, 23.71097183], [68.28125, 23.71097183], [68.28125, 23.71125031], [68.28013611, 23.71125031], [68.28013611, 23.71097183], [68.27986145, 23.71097183], [68.27986145, 23.71041679], [68.27958679, 23.71042252], [68.27958679, 23.71014023], [68.27929688, 23.71014023], [68.27929688, 23.70986176], [68.27902985, 23.70986176], [68.27902985, 23.70930481], [68.27874756, 23.70930481], [68.27874756, 23.70902824], [68.2784729, 23.70902824], [68.2784729, 23.70874977], [68.27819824, 23.70874977], [68.27819824, 23.70819092], [68.27791595, 23.70819473], [68.27791595, 23.70791626], [68.2776413, 23.70791817], [68.2776413, 23.70763969], [68.27735901, 23.70763969], [68.27735901, 23.70736122], [68.27680206, 23.70736122], [68.27680206, 23.70763969], [68.27708435, 23.70763969], [68.27708435, 23.7084713], [68.27735901, 23.70846748], [68.27735901, 23.70902824], [68.2776413, 23.70902824], [68.2776413, 23.70930481], [68.27791595, 23.70930481], [68.27791595, 23.70958328], [68.27819061, 23.70957756], [68.27819061, 23.71014023], [68.2776413, 23.71014023], [68.2776413, 23.70986176], [68.27735901, 23.70986176], [68.27735901, 23.70958328], [68.27708435, 23.70958328], [68.27708435, 23.70930481], [68.2765274, 23.70930481], [68.2765274, 23.70902824], [68.27597046, 23.70902824], [68.27597046, 23.70874977], [68.27540588, 23.70874977], [68.27540588, 23.70846748], [68.2748642, 23.7084713], [68.2748642, 23.70791626], [68.27458191, 23.70791817], [68.27458191, 23.70708084], [68.27402496, 23.70708275], [68.27402496, 23.70819473], [68.2729187, 23.70819473], [68.2729187, 23.70791626], [68.27263641, 23.70791817], [68.27263641, 23.70763969], [68.2720871, 23.70763969], [68.2720871, 23.70708084], [68.27180481, 23.70708275], [68.27180481, 23.7056942], [68.27153015, 23.7056942], [68.27153015, 23.70486069], [68.27236176, 23.70486069], [68.27236176, 23.70514107], [68.27263641, 23.70514107], [68.27263641, 23.70541954], [68.2729187, 23.70541763], [68.2729187, 23.7056942], [68.27347565, 23.7056942], [68.27347565, 23.70597267], [68.27375031, 23.70597267], [68.27375031, 23.70624924], [68.27402496, 23.70624924], [68.27402496, 23.7056942], [68.27375031, 23.7056942], [68.27375031, 23.70541763], [68.27348328, 23.70541954], [68.27348328, 23.70486069], [68.27319336, 23.70486069], [68.27319336, 23.70430946], [68.2729187, 23.70430946], [68.2729187, 23.70375061], [68.27319336, 23.70375061], [68.27319336, 23.70347023], [68.27347565, 23.70347214], [68.27347565, 23.70291519], [68.27375031, 23.70292091], [68.27375031, 23.70264053], [68.27403259, 23.70264053], [68.27403259, 23.70236015], [68.27430725, 23.70236206], [68.27430725, 23.70180321], [68.27458191, 23.70181084], [68.27458191, 23.70125008], [68.27403259, 23.70125008], [68.27403259, 23.70153046], [68.27375031, 23.70153046], [68.27375031, 23.70181084], [68.27347565, 23.70180321], [68.27347565, 23.70208549], [68.27319336, 23.70207977], [68.27319336, 23.70236015], [68.2729187, 23.70236015], [68.2729187, 23.70264053], [68.27263641, 23.70264053], [68.27263641, 23.70292091], [68.27236176, 23.70292091], [68.27236176, 23.70319939], [68.2720871, 23.70319366], [68.2720871, 23.70347214], [68.27179718, 23.70347023], [68.27179718, 23.70375061], [68.27069092, 23.70375061], [68.27069092, 23.70347023], [68.27041626, 23.70347023], [68.27041626, 23.70375061], [68.2701416, 23.70375061], [68.2701416, 23.70403099], [68.26985931, 23.70403099], [68.26985931, 23.70430946], [68.26875305, 23.70430756], [68.26875305, 23.70458412], [68.26763916, 23.70458031], [68.26763916, 23.70486069], [68.26735687, 23.70486069], [68.26735687, 23.70514107], [68.26708221, 23.70514107], [68.26708221, 23.70541954], [68.26680756, 23.70541763], [68.26680756, 23.7056942], [68.26652527, 23.7056942], [68.26652527, 23.70597267], [68.26625061, 23.70597267], [68.26625061, 23.70624924], [68.26597595, 23.7062397], [68.26597595, 23.70652962], [68.26568604, 23.70652962], [68.26568604, 23.70680809], [68.26541901, 23.70680618], [68.26541901, 23.70708275], [68.26513672, 23.70708275], [68.26515198, 23.70736122], [68.26486206, 23.70736122], [68.26486206, 23.70763969], [68.26457977, 23.70763969], [68.26457977, 23.70791817], [68.26430511, 23.70791626], [68.26430511, 23.70819473], [68.26403046, 23.70819473], [68.26403046, 23.7084713], [68.26374817, 23.70846748], [68.26374817, 23.70874977], [68.26346588, 23.70874977], [68.26346588, 23.70902824], [68.26319122, 23.70902824], [68.26319122, 23.70930481], [68.26291656, 23.70930481], [68.26291656, 23.70958328], [68.26264191, 23.70958328], [68.26264191, 23.70986176], [68.26235962, 23.70986176], [68.26235962, 23.71014023], [68.26207733, 23.71014023], [68.26207733, 23.7107029], [68.26180267, 23.71069527], [68.26180267, 23.71097183], [68.26152802, 23.71097183], [68.26152802, 23.71125031], [68.26125336, 23.71125031], [68.26125336, 23.71153259], [68.26097107, 23.71153259], [68.26097107, 23.71181107], [68.26069641, 23.71180534], [68.26069641, 23.71208382], [68.26040649, 23.71208191], [68.26040649, 23.71236038], [68.26013947, 23.71236038], [68.26013947, 23.71264267], [68.25986481, 23.71263885], [68.25986481, 23.71319389], [68.25958252, 23.71319389], [68.25958252, 23.71347237], [68.25930786, 23.71347046], [68.25930786, 23.71375084], [68.25901794, 23.71375084], [68.25901794, 23.71403122], [68.25875092, 23.7140274], [68.25875092, 23.71458244], [68.25846863, 23.71458054], [68.25846863, 23.71486092], [68.25818634, 23.71486092], [68.25818634, 23.71513939], [68.25791931, 23.71513939], [68.25791931, 23.71569633], [68.25763702, 23.71569633], [68.25763702, 23.71597481], [68.25736237, 23.71597481], [68.25736237, 23.71708488], [68.25763702, 23.71708107], [68.25763702, 23.71763992], [68.25791931, 23.71763992], [68.25791931, 23.7179203], [68.25819397, 23.71791458], [68.25819397, 23.71847153], [68.25846863, 23.71846962], [68.25846863, 23.71875], [68.25875092, 23.71875], [68.25875092, 23.71903038], [68.25901794, 23.71903038], [68.25901794, 23.71931076], [68.25930786, 23.71930695], [68.25930786, 23.71958351], [68.25958252, 23.71958351], [68.25958252, 23.71986198], [68.25985718, 23.71986008], [68.25985718, 23.72014046], [68.26040649, 23.72014046], [68.26040649, 23.72042084], [68.26069641, 23.72041893], [68.26069641, 23.72069359], [68.26097107, 23.72069359], [68.26097107, 23.72097206], [68.26125336, 23.72097206], [68.26125336, 23.72125053], [68.26152802, 23.721241], [68.26152802, 23.72153091], [68.26180267, 23.72153091], [68.26180267, 23.72180939], [68.26208496, 23.72180557], [68.26208496, 23.72208405], [68.26235962, 23.72207832], [68.26235962, 23.72236061], [68.26264191, 23.72236061], [68.26264191, 23.72263908], [68.26291656, 23.72263908], [68.26291656, 23.72291946], [68.26319122, 23.72291756], [68.26319122, 23.72319412], [68.26346588, 23.7231884], [68.26346588, 23.72374916], [68.26374817, 23.72374916], [68.26374817, 23.72430611], [68.26403046, 23.72429848], [68.26403046, 23.72486115], [68.26430511, 23.72486115], [68.26430511, 23.72513962], [68.26457977, 23.72513962], [68.26457977, 23.72569466], [68.26486206, 23.72569275], [68.26486206, 23.72624969], [68.26513672, 23.72624969], [68.26513672, 23.72680473], [68.26541901, 23.72680283], [68.26541901, 23.72875023], [68.26569366, 23.72875023], [68.26569366, 23.72958565], [68.26597595, 23.72958565], [68.26597595, 23.73097229], [68.26568604, 23.73097038], [68.26568604, 23.73264122], [68.26541901, 23.73263931], [68.26541901, 23.73347282], [68.26515198, 23.73347092], [68.26515198, 23.73430824], [68.26486206, 23.73430634], [68.26486206, 23.73486137], [68.26457977, 23.73485947], [68.26457977, 23.73541832], [68.26430511, 23.73541641], [68.26430511, 23.73569489], [68.26403046, 23.73569489], [68.26403046, 23.73624992], [68.26374817, 23.73624992], [68.26374817, 23.73708344], [68.26347351, 23.73708344], [68.26347351, 23.73847008], [68.26374817, 23.73847008], [68.26374817, 23.73931122], [68.26403046, 23.7393055], [68.26403046, 23.73958206], [68.26431274, 23.73958015], [68.26431274, 23.74014282], [68.26457977, 23.74014282], [68.26457977, 23.74041939], [68.26486206, 23.74041748], [68.26486206, 23.74069214], [68.26513672, 23.74069214], [68.26513672, 23.74097252], [68.26541901, 23.74097061], [68.26541901, 23.7412529], [68.26597595, 23.7412529], [68.26597595, 23.74152946], [68.26625061, 23.74152946], [68.26625061, 23.74180984], [68.26680756, 23.74180412], [68.26680756, 23.7420826], [68.26708221, 23.74208069], [68.26708221, 23.74237061], [68.26763916, 23.74237061], [68.26763916, 23.74263954], [68.26791382, 23.74263954], [68.26791382, 23.74319649], [68.26763916, 23.74319077], [68.26763916, 23.74403], [68.26789856, 23.74403], [68.26789856, 23.74514008], [68.26819611, 23.74513626], [68.26819611, 23.74597168], [68.26847076, 23.74597168], [68.26847076, 23.74708366], [68.26875305, 23.74708366], [68.26875305, 23.74819374], [68.26902771, 23.74818993], [68.26902771, 23.74931145], [68.26930237, 23.74931145], [68.26930237, 23.74986076], [68.26902771, 23.74986076], [68.26902771, 23.75013924], [68.26875305, 23.75013924], [68.26875305, 23.75154114], [68.26847076, 23.75152779], [68.26847076, 23.75208282], [68.26763916, 23.75208282], [68.26763916, 23.75124931], [68.26735687, 23.75125122], [68.26735687, 23.75154114], [68.2665329, 23.75154114], [68.2665329, 23.75181007], [68.26597595, 23.75180626], [68.26597595, 23.75208282], [68.26569366, 23.75208282], [68.26569366, 23.7523613], [68.26541901, 23.75235939], [68.26541901, 23.75292015], [68.26513672, 23.75291634], [68.26513672, 23.75347137], [68.26486206, 23.75346947], [68.26486206, 23.75403023], [68.26457977, 23.75403023], [68.26457977, 23.75653076], [68.26430511, 23.75652695], [68.26430511, 23.75986099], [68.26457977, 23.75986099], [68.26457977, 23.76041794], [68.26486206, 23.76041794], [68.26486206, 23.76097298], [68.26515198, 23.76097107], [68.26515198, 23.76152992], [68.26541901, 23.76152992], [68.26541901, 23.76208305], [68.26568604, 23.76208115], [68.26568604, 23.76263809], [68.26597595, 23.76263809], [68.26597595, 23.76320267], [68.26625061, 23.76320267], [68.26625061, 23.76403046], [68.26652527, 23.76402855], [68.26652527, 23.76486015], [68.26680756, 23.76486015], [68.26680756, 23.76542282], [68.26708221, 23.76542282], [68.26708221, 23.76764107], [68.26735687, 23.76764107], [68.26735687, 23.77124977], [68.26763916, 23.77124977], [68.26763916, 23.77236176], [68.26789856, 23.77235031], [68.26789856, 23.77264023], [68.26821136, 23.77264023], [68.26821136, 23.77292061], [68.26847076, 23.7729187], [68.26847076, 23.77347183], [68.26875305, 23.77346992], [68.26875305, 23.77403069], [68.26902771, 23.77402878], [68.26902771, 23.77458382], [68.26930237, 23.77457809], [68.26930237, 23.77514076], [68.26957703, 23.77514076], [68.26957703, 23.77541924], [68.26985931, 23.77541733], [68.26985931, 23.77597237], [68.2701416, 23.77597046], [68.2701416, 23.7768116], [68.27041626, 23.7768116], [68.27041626, 23.77792168], [68.27069092, 23.77792168], [68.27069092, 23.77848053], [68.27095795, 23.77848053], [68.27095795, 23.77931023], [68.27124786, 23.77930641], [68.27124786, 23.77986145], [68.27153015, 23.77986145], [68.27153015, 23.78236389], [68.27179718, 23.78236008], [68.27179718, 23.78430939], [68.2720871, 23.78430939], [68.2720871, 23.78625107], [68.27236176, 23.78624725], [68.27236176, 23.78847313], [68.27263641, 23.78847313], [68.27263641, 23.78958321], [68.2729187, 23.78957748], [68.2729187, 23.79071045], [68.27319336, 23.79071045], [68.27319336, 23.79153252], [68.27348328, 23.79153252], [68.27348328, 23.79264069], [68.27375031, 23.79264069], [68.27375031, 23.79292107], [68.27430725, 23.79291725], [68.27430725, 23.79347229], [68.27458191, 23.79346275], [68.27458191, 23.79375076], [68.27485657, 23.79375076], [68.27485657, 23.79430962], [68.27513885, 23.7943058], [68.27513885, 23.79458237], [68.27540588, 23.79458046], [68.27540588, 23.79514122], [68.2756958, 23.79514122], [68.2756958, 23.79541969], [68.27625275, 23.79541588], [68.27625275, 23.79569244], [68.2765274, 23.79569244], [68.2765274, 23.79597473]]], [[[68.21652985, 23.77931023], [68.21652985, 23.77874947], [68.21736145, 23.77874947], [68.21736145, 23.77848053], [68.2179184, 23.77848053], [68.2179184, 23.77819252], [68.21847534, 23.77819443], [68.21847534, 23.77791595], [68.21901703, 23.77792168], [68.21901703, 23.77763939], [68.2195816, 23.77763939], [68.2195816, 23.77736092], [68.21984863, 23.77736092], [68.21984863, 23.7768116], [68.22013855, 23.7768116], [68.22013855, 23.77652931], [68.22041321, 23.77652931], [68.22041321, 23.77625084], [68.22070313, 23.77625084], [68.2206955, 23.77569389], [68.22097015, 23.77569389], [68.22097015, 23.77541733], [68.22125244, 23.77541924], [68.22125244, 23.77375031], [68.2215271, 23.77375031], [68.2215271, 23.77319908], [68.22180176, 23.77319908], [68.22180939, 23.77292061], [68.22207642, 23.77292061], [68.22207642, 23.77264023], [68.2223587, 23.77264023], [68.2223587, 23.77235031], [68.22264099, 23.77236176], [68.22264099, 23.77013969], [68.22290802, 23.77013969], [68.22290802, 23.76847076], [68.22319794, 23.76847267], [68.22319794, 23.76652718], [68.2234726, 23.76654053], [68.2234726, 23.76514053], [68.22374725, 23.76514053], [68.22374725, 23.76403046], [68.22402954, 23.76403046], [68.22402954, 23.76320267], [68.22374725, 23.76320267], [68.22374725, 23.76208115], [68.2234726, 23.76208305], [68.2234726, 23.76180649], [68.22319794, 23.76180077], [68.22319794, 23.76124954], [68.22290802, 23.76124954], [68.22290802, 23.76097107], [68.22264099, 23.76097298], [68.22264099, 23.7606945], [68.2223587, 23.7606945], [68.2223587, 23.76041794], [68.22208405, 23.76041794], [68.22208405, 23.76013947], [68.22180939, 23.76013947], [68.22180176, 23.75986099], [68.22125244, 23.75986099], [68.22125244, 23.75958061], [68.22097015, 23.75958252], [68.22097015, 23.75930786], [68.22070313, 23.75930977], [68.22070313, 23.75902939], [68.22041321, 23.75902939], [68.22041321, 23.75875092], [68.22013855, 23.75875092], [68.22013855, 23.75847054], [68.21986389, 23.75847244], [68.21986389, 23.75819588], [68.2195816, 23.75819588], [68.2195816, 23.7579174], [68.21930695, 23.75792122], [68.21930695, 23.75764084], [68.21901703, 23.75764084], [68.21901703, 23.75735092], [68.21875, 23.75736046], [68.21875, 23.7570858], [68.21847534, 23.7570858], [68.21847534, 23.75652695], [68.21819305, 23.75653076], [68.21819305, 23.75625038], [68.2179184, 23.75625038], [68.2179184, 23.75597], [68.21763611, 23.75597191], [68.21763611, 23.75569344], [68.2168045, 23.75569344], [68.2168045, 23.75597191], [68.21652985, 23.75597], [68.21652985, 23.75625038], [68.21624756, 23.75625038], [68.21624756, 23.75653076], [68.2159729, 23.75653076], [68.2159729, 23.75681114], [68.21569824, 23.75680351], [68.21569061, 23.7570858], [68.21541595, 23.75708008], [68.21541595, 23.75764084], [68.2151413, 23.75763893], [68.2151413, 23.75819588], [68.21485901, 23.75819588], [68.21485901, 23.75958252], [68.2151413, 23.75958252], [68.2151413, 23.7606945], [68.21541595, 23.76069069], [68.21541595, 23.76124954], [68.21569061, 23.76124954], [68.21569824, 23.7618084], [68.2159729, 23.7618084], [68.2159729, 23.76291847], [68.21624756, 23.76291656], [68.21624756, 23.76486015], [68.21652985, 23.76486015], [68.21652985, 23.76569366], [68.21624756, 23.76569176], [68.21624756, 23.76680946], [68.2159729, 23.76680565], [68.2159729, 23.76708221], [68.21569824, 23.76708031], [68.21569061, 23.76736069], [68.21541595, 23.76736069], [68.21541595, 23.76764107], [68.2151413, 23.76764107], [68.2151413, 23.76791954], [68.21485901, 23.76791573], [68.21485901, 23.76819229], [68.21457672, 23.76819038], [68.21457672, 23.76902962], [68.21485901, 23.76902771], [68.21485901, 23.77347183], [68.2151413, 23.77346992], [68.2151413, 23.77541924], [68.21541595, 23.77541924], [68.21541595, 23.77736092], [68.2151413, 23.77736092], [68.2151413, 23.77848053], [68.21541595, 23.77848053], [68.21541595, 23.77874947], [68.2159729, 23.77874947], [68.2159729, 23.77902985], [68.21624756, 23.77902985], [68.21624756, 23.77931023], [68.21652985, 23.77931023]]], [[[68.44957733, 23.73233986], [68.44958496, 23.73152542], [68.44985962, 23.73153114], [68.44985962, 23.73180962], [68.45014191, 23.73180771], [68.45014191, 23.73208427], [68.45069122, 23.73208427], [68.45069122, 23.73125076], [68.45041656, 23.73125076], [68.45041656, 23.73097038], [68.45014191, 23.73097229], [68.45014191, 23.73041534], [68.44875336, 23.73041534], [68.44875336, 23.73060226], [68.44875336, 23.73069572], [68.44847107, 23.73069572], [68.44847107, 23.73097229], [68.44790649, 23.73097038], [68.44790649, 23.73125076], [68.44763947, 23.73125076], [68.44763947, 23.73180962], [68.44735718, 23.73180962], [68.44735718, 23.73236084], [68.44763947, 23.73236084], [68.44763947, 23.73264122], [68.44847107, 23.73264122], [68.44847107, 23.73236084], [68.44957733, 23.73233986]]], [[[68.46736145, 23.73986053], [68.46736145, 23.73958015], [68.4679184, 23.73958206], [68.4679184, 23.7393055], [68.46875, 23.73931122], [68.46875, 23.73903275], [68.46930695, 23.73903275], [68.46930695, 23.73875046], [68.46985626, 23.73875046], [68.46985626, 23.73847008], [68.47041321, 23.73847008], [68.47041321, 23.73819542], [68.47070313, 23.7381916], [68.4706955, 23.73791695], [68.47125244, 23.73792267], [68.47125244, 23.73764038], [68.4715271, 23.73764038], [68.4715271, 23.73736191], [68.47208405, 23.73736191], [68.47208405, 23.73708344], [68.4723587, 23.73708344], [68.4723587, 23.73680496], [68.47292328, 23.73681259], [68.47292328, 23.7365303], [68.47319794, 23.7365303], [68.47319794, 23.73624039], [68.47374725, 23.73624992], [68.47374725, 23.73597145], [68.4743042, 23.73597145], [68.4743042, 23.73569489], [68.47458649, 23.73569489], [68.47458649, 23.73541641], [68.4751358, 23.73541832], [68.4751358, 23.73513985], [68.47570038, 23.73513985], [68.47570038, 23.73485947], [68.47624969, 23.73486137], [68.47624969, 23.7345829], [68.47680664, 23.7345829], [68.47680664, 23.73430634], [68.47735596, 23.73430824], [68.47735596, 23.73402977], [68.4779129, 23.73402977], [68.4779129, 23.73374939], [68.47902679, 23.73374939], [68.47902679, 23.73347092], [68.4798584, 23.73347282], [68.4798584, 23.73319435], [68.48097229, 23.73319435], [68.48097229, 23.73291779], [68.48401642, 23.73291969], [68.48401642, 23.73264122], [68.48458099, 23.73264122], [68.48458099, 23.73236084], [68.48513794, 23.73236084], [68.48513794, 23.73208046], [68.48542023, 23.73208427], [68.48542023, 23.73180771], [68.48596954, 23.73180962], [68.48596954, 23.73153114], [68.48625183, 23.73153114], [68.48625183, 23.73125076], [68.48680878, 23.73125076], [68.48680878, 23.73097038], [68.48708344, 23.73097229], [68.48708344, 23.73069572], [68.48735809, 23.73069572], [68.48735809, 23.72986031], [68.48764038, 23.72986031], [68.48764038, 23.72903061], [68.48735809, 23.72903061], [68.48735809, 23.72875023], [68.48707581, 23.72875023], [68.48707581, 23.72846985], [68.48680878, 23.72847176], [68.48680878, 23.72819328], [68.48430634, 23.72820091], [68.48430634, 23.72792053], [68.47820282, 23.72792053], [68.47820282, 23.72820091], [68.47736359, 23.72819328], [68.47736359, 23.72847176], [68.47651672, 23.72846985], [68.47651672, 23.72875023], [68.4734726, 23.72875023], [68.4734726, 23.72846985], [68.4723587, 23.72847176], [68.4723587, 23.72819328], [68.47041321, 23.72819328], [68.47041321, 23.72847176], [68.46708679, 23.72847176], [68.46708679, 23.72819328], [68.46652985, 23.72820091], [68.46652985, 23.72792053], [68.46569824, 23.72792053], [68.46569824, 23.72764015], [68.4651413, 23.72764015], [68.4651413, 23.72737122], [68.46485901, 23.72737122], [68.46485901, 23.72764015], [68.4631958, 23.72764015], [68.4631958, 23.72737122], [68.46290588, 23.72737122], [68.46290588, 23.72707939], [68.4623642, 23.7270813], [68.4623642, 23.72680473], [68.46208191, 23.72680473], [68.46208191, 23.72652817], [68.46153259, 23.72653008], [68.46153259, 23.72624969], [68.46125031, 23.72624969], [68.46125031, 23.72597122], [68.46069336, 23.72597122], [68.46069336, 23.72569466], [68.4604187, 23.72569466], [68.4604187, 23.72541618], [68.45986176, 23.72542191], [68.45986176, 23.72513962], [68.4595871, 23.72513962], [68.4595871, 23.72486115], [68.45929718, 23.72486115], [68.45929718, 23.72653008], [68.45903015, 23.72652817], [68.45903015, 23.72847176], [68.45874786, 23.72847176], [68.45874786, 23.72958565], [68.45903015, 23.72957993], [68.45903015, 23.73014069], [68.45930481, 23.73013878], [68.45930481, 23.73069572], [68.4595871, 23.73069], [68.4595871, 23.73125076], [68.45929718, 23.73125076], [68.45929718, 23.73153114], [68.45903015, 23.73153114], [68.45903015, 23.73180962], [68.45874786, 23.73180771], [68.45874786, 23.73208237], [68.45847321, 23.73208046], [68.45847321, 23.73236084], [68.45819092, 23.73236084], [68.45819092, 23.73264122], [68.45791626, 23.73264122], [68.45791626, 23.73291969], [68.4576416, 23.73291779], [68.4576416, 23.73319435], [68.45735931, 23.73319435], [68.45735931, 23.73347282], [68.45707703, 23.73347092], [68.45707703, 23.73374939], [68.45735931, 23.73374939], [68.45735931, 23.73402977], [68.4576416, 23.73402977], [68.4576416, 23.7345829], [68.45791626, 23.73457909], [68.45791626, 23.73513985], [68.45819092, 23.73513985], [68.45819092, 23.73569489], [68.45847321, 23.73569489], [68.45847321, 23.73624992], [68.45874786, 23.73624039], [68.45874786, 23.73681259], [68.45903015, 23.73680496], [68.45903015, 23.73708344], [68.4595871, 23.73708344], [68.4595871, 23.73736191], [68.45986176, 23.73736191], [68.45986176, 23.73764038], [68.46013641, 23.73764038], [68.46013641, 23.73792267], [68.4604187, 23.73791695], [68.4604187, 23.7381916], [68.46069336, 23.73819542], [68.46069336, 23.73847008], [68.46097565, 23.73847008], [68.46097565, 23.73875046], [68.46180725, 23.73875046], [68.46180725, 23.73903275], [68.46263885, 23.73903275], [68.46263885, 23.73931122], [68.4631958, 23.7393055], [68.4631958, 23.73958206], [68.4640274, 23.73958015], [68.4640274, 23.73986053], [68.46736145, 23.73986053]]], [[[68.48680878, 23.74597168], [68.48680878, 23.74513626], [68.48652649, 23.74514008], [68.48652649, 23.74319077], [68.48625183, 23.74319649], [68.48625183, 23.74124908], [68.48596954, 23.7412529], [68.48596954, 23.74014282], [68.48568726, 23.74014282], [68.48568726, 23.73931122], [68.48542023, 23.73931122], [68.48542023, 23.73875046], [68.48513794, 23.73875046], [68.48513794, 23.7381916], [68.48486328, 23.73819351], [68.48486328, 23.73763847], [68.48458099, 23.73764038], [68.48458099, 23.73736191], [68.48430634, 23.73736191], [68.48430634, 23.73708344], [68.48402405, 23.73708344], [68.48402405, 23.73680496], [68.48374939, 23.73681259], [68.48374939, 23.7365303], [68.4834671, 23.7365303], [68.4834671, 23.73624039], [68.48319244, 23.73624992], [68.48319244, 23.73597145], [68.48236084, 23.73597145], [68.48236084, 23.73624992], [68.48179626, 23.73624039], [68.48179626, 23.7365303], [68.48152924, 23.7365284], [68.48152924, 23.73708344], [68.48124695, 23.73708153], [68.48124695, 23.73764038], [68.48152924, 23.73763847], [68.48152924, 23.7381916], [68.48179626, 23.73820114], [68.48179626, 23.73903275], [68.48208618, 23.73902702], [68.48208618, 23.73958206], [68.48236084, 23.73958015], [68.48236084, 23.74014282], [68.4826355, 23.74013901], [68.4826355, 23.74069214], [68.48291779, 23.74069023], [68.48291779, 23.7412529], [68.48319244, 23.7412529], [68.48319244, 23.74180984], [68.4834671, 23.74180984], [68.4834671, 23.74237061], [68.48374939, 23.74237061], [68.48374939, 23.74263954], [68.48402405, 23.74263954], [68.48402405, 23.74319649], [68.48430634, 23.74319649], [68.48430634, 23.74347305], [68.48458099, 23.74347115], [68.48458099, 23.74403], [68.48486328, 23.74402618], [68.48486328, 23.74458313], [68.48513794, 23.74458313], [68.48513794, 23.7448616], [68.48596954, 23.7448597], [68.48596954, 23.74514008], [68.48625183, 23.74514008], [68.48625183, 23.74570084], [68.48652649, 23.74569511], [68.48652649, 23.74597168], [68.48680878, 23.74597168]]], [[[68.51790619, 23.77736092], [68.51819611, 23.77736092], [68.51819611, 23.77708054], [68.51902771, 23.77708244], [68.51902771, 23.77680588], [68.51985931, 23.7768116], [68.51985931, 23.77652931], [68.52068329, 23.77652931], [68.52068329, 23.77625084], [68.52097321, 23.77625084], [68.52097321, 23.77597046], [68.52124786, 23.77597237], [68.52124786, 23.77569389], [68.52180481, 23.77569389], [68.52180481, 23.77541733], [68.52236176, 23.77541924], [68.52236176, 23.77514076], [68.5220871, 23.77514076], [68.5220871, 23.77069092], [68.52180481, 23.77069664], [68.52180481, 23.76958275], [68.52153015, 23.76958275], [68.52153015, 23.76874924], [68.52124786, 23.76875114], [68.52124786, 23.76791954], [68.52097321, 23.76791954], [68.52097321, 23.76708031], [68.52069092, 23.76708221], [68.52069092, 23.76597023], [68.52041626, 23.76597023], [68.52041626, 23.76513863], [68.5201416, 23.76514053], [68.5201416, 23.76431274], [68.51985931, 23.76431274], [68.51985931, 23.76348114], [68.51957703, 23.76348114], [68.51957703, 23.76263809], [68.51930237, 23.76263809], [68.51930237, 23.7618084], [68.51902771, 23.76180077], [68.51902771, 23.76097298], [68.51875305, 23.76097298], [68.51875305, 23.76041794], [68.51819611, 23.76041794], [68.51819611, 23.76013947], [68.51790619, 23.76013947], [68.51790619, 23.75958061], [68.51763916, 23.75958252], [68.51763916, 23.75680351], [68.51735687, 23.75681114], [68.51735687, 23.75597], [68.51708221, 23.75597191], [68.51708221, 23.7551384], [68.51680756, 23.7551403], [68.51680756, 23.75457954], [68.51652527, 23.75458336], [68.51652527, 23.75430489], [68.51625061, 23.75431061], [68.51625061, 23.75403023], [68.51597595, 23.75403023], [68.51597595, 23.75346947], [68.51569366, 23.75347137], [68.51569366, 23.75319481], [68.51541901, 23.75319481], [68.51541901, 23.75291634], [68.51513672, 23.75292015], [68.51513672, 23.75263977], [68.51486206, 23.75263977], [68.51486206, 23.7523613], [68.51430511, 23.7523613], [68.51430511, 23.75208282], [68.51291656, 23.75208282], [68.51291656, 23.75180626], [68.51264191, 23.75181007], [68.51264191, 23.75154114], [68.51207733, 23.75154114], [68.51207733, 23.75125122], [68.5118103, 23.75125122], [68.5118103, 23.75097084], [68.51013947, 23.75097084], [68.51013947, 23.75125122], [68.5090332, 23.75125122], [68.5090332, 23.75154114], [68.50846863, 23.75154114], [68.50846863, 23.75181007], [68.50819397, 23.75180626], [68.50819397, 23.75208282], [68.50763702, 23.75208282], [68.50763702, 23.7523613], [68.50736237, 23.75235939], [68.50736237, 23.75263977], [68.50708008, 23.75263977], [68.50708008, 23.75292015], [68.50680542, 23.75291634], [68.50680542, 23.75319481], [68.50624847, 23.75319481], [68.50624847, 23.75347137], [68.50596619, 23.75346947], [68.50596619, 23.75374985], [68.50567627, 23.75374985], [68.50567627, 23.75403023], [68.50541687, 23.75403023], [68.50541687, 23.75431061], [68.50485992, 23.75430489], [68.50485992, 23.75458336], [68.50458527, 23.75458336], [68.50458527, 23.75486183], [68.50430298, 23.75485992], [68.50430298, 23.7551403], [68.50347137, 23.7551403], [68.50347137, 23.75542068], [68.50263977, 23.75542068], [68.50263977, 23.75570107], [68.50208282, 23.75569344], [68.50208282, 23.75597191], [68.50125122, 23.75597], [68.50125122, 23.75625038], [68.50041962, 23.75625038], [68.50041962, 23.75653076], [68.49958038, 23.75653076], [68.49958038, 23.75681114], [68.49847412, 23.75680351], [68.49847412, 23.7570858], [68.49764252, 23.7570858], [68.49764252, 23.75736046], [68.49652863, 23.75735092], [68.49652863, 23.75764084], [68.49514008, 23.75764084], [68.49514008, 23.75792122], [68.49402618, 23.7579174], [68.49402618, 23.75819588], [68.49319458, 23.75819588], [68.49319458, 23.75847244], [68.49236298, 23.75847054], [68.49236298, 23.75875092], [68.4909668, 23.75875092], [68.4909668, 23.75902939], [68.49041748, 23.75902939], [68.49041748, 23.75930977], [68.49013519, 23.75930786], [68.49013519, 23.75958252], [68.48958588, 23.75958252], [68.48958588, 23.75902557], [68.48986053, 23.75902939], [68.48986053, 23.75847054], [68.49041748, 23.75847244], [68.49041748, 23.75819588], [68.49097443, 23.75819588], [68.49097443, 23.7579174], [68.49180603, 23.75792122], [68.49180603, 23.75764084], [68.49236298, 23.75764084], [68.49236298, 23.75735092], [68.49319458, 23.75736046], [68.49319458, 23.7570858], [68.49430847, 23.7570858], [68.49430847, 23.75680351], [68.49514008, 23.75681114], [68.49514008, 23.75653076], [68.49624634, 23.75653076], [68.49624634, 23.75625038], [68.4970932, 23.75625038], [68.49708557, 23.75597191], [68.49819183, 23.75597191], [68.49819183, 23.75569344], [68.49903107, 23.75570107], [68.49903107, 23.75542068], [68.50013733, 23.75542068], [68.50013733, 23.7551403], [68.50096893, 23.7551403], [68.50096893, 23.75485992], [68.50152588, 23.75486183], [68.50152588, 23.75458336], [68.50235748, 23.75458336], [68.50235748, 23.75430489], [68.5029068, 23.75431061], [68.5029068, 23.75403023], [68.50319672, 23.75403023], [68.50319672, 23.75374985], [68.50374603, 23.75374985], [68.50374603, 23.75346947], [68.50402832, 23.75347137], [68.50402832, 23.75319481], [68.50458527, 23.75319481], [68.50458527, 23.75291634], [68.50485992, 23.75292015], [68.50485992, 23.75263977], [68.50514221, 23.75263977], [68.50514221, 23.75235939], [68.50541687, 23.7523613], [68.50541687, 23.75180626], [68.50567627, 23.75181007], [68.50567627, 23.75154114], [68.50596619, 23.75154114], [68.50596619, 23.75125122], [68.50624847, 23.75125122], [68.50624847, 23.75068855], [68.50653076, 23.75069427], [68.50653076, 23.75013924], [68.50681305, 23.75013924], [68.50681305, 23.74957848], [68.50708008, 23.7495842], [68.50708008, 23.74902725], [68.50736237, 23.74902916], [68.50736237, 23.74847031], [68.50708008, 23.74847221], [68.50708008, 23.7476387], [68.50681305, 23.74764061], [68.50681305, 23.74707985], [68.50653076, 23.74708366], [68.50653076, 23.74680519], [68.50596619, 23.74681091], [68.50596619, 23.74653053], [68.50567627, 23.74653053], [68.50567627, 23.74625015], [68.50541687, 23.74625015], [68.50541687, 23.74596977], [68.50485992, 23.74597168], [68.50485992, 23.74569511], [68.5045929, 23.74570084], [68.5045929, 23.74541092], [68.50430298, 23.74541855], [68.50430298, 23.74513626], [68.50374603, 23.74514008], [68.50374603, 23.7448597], [68.50347137, 23.7448616], [68.50347137, 23.74458313], [68.50291443, 23.74458313], [68.50291443, 23.74430656], [68.50263977, 23.74430656], [68.50263977, 23.74402618], [68.50208282, 23.74403], [68.50208282, 23.74374962], [68.50180817, 23.74374962], [68.50180817, 23.74347115], [68.50125122, 23.74347305], [68.50125122, 23.74319649], [68.50069427, 23.74319649], [68.50069427, 23.7429142], [68.4998703, 23.74291992], [68.4998703, 23.74263954], [68.49958038, 23.74263954], [68.49958038, 23.74237061], [68.49931335, 23.74237061], [68.49931335, 23.74208069], [68.49903107, 23.7420826], [68.49903107, 23.74180412], [68.49874878, 23.74180984], [68.49874878, 23.7412529], [68.49846649, 23.7412529], [68.49846649, 23.74097061], [68.49819183, 23.74097252], [68.49819183, 23.74069214], [68.49791718, 23.74069214], [68.49791718, 23.74041748], [68.49764252, 23.74041939], [68.49764252, 23.74014282], [68.49736023, 23.74014282], [68.49736023, 23.73986053], [68.49708557, 23.73986053], [68.49708557, 23.73958206], [68.49680328, 23.73958206], [68.49680328, 23.7393055], [68.49652863, 23.73931122], [68.49652863, 23.73903275], [68.49624634, 23.73903275], [68.49624634, 23.73875046], [68.49597168, 23.73875046], [68.49597168, 23.73847008], [68.49569702, 23.73847008], [68.49569702, 23.73819351], [68.49541473, 23.73819351], [68.49541473, 23.73791695], [68.49514008, 23.73792267], [68.49514008, 23.73764038], [68.49485779, 23.73764038], [68.49485779, 23.73736191], [68.49153137, 23.73736191], [68.49153137, 23.73764038], [68.48958588, 23.73764038], [68.48958588, 23.73736191], [68.48874664, 23.73736191], [68.48874664, 23.73708344], [68.48764038, 23.73708153], [68.48764038, 23.73903275], [68.48791504, 23.73902702], [68.48791504, 23.74069214], [68.48819733, 23.74069023], [68.48819733, 23.7412529], [68.48847198, 23.7412529], [68.48847198, 23.74237061], [68.48874664, 23.74236107], [68.48874664, 23.74597168], [68.48847198, 23.74596977], [68.48847198, 23.74653053], [68.4879303, 23.74653053], [68.4879303, 23.74681091], [68.48764038, 23.74681091], [68.48764038, 23.74764061], [68.48791504, 23.7476387], [68.48791504, 23.74819374], [68.48819733, 23.74819374], [68.48819733, 23.74847221], [68.48791504, 23.74847221], [68.4879303, 23.74875069], [68.48764038, 23.74875069], [68.48764038, 23.74931145], [68.48735809, 23.74930573], [68.48735809, 23.7495842], [68.48707581, 23.74957848], [68.48707581, 23.74986076], [68.48680878, 23.74986076], [68.48680878, 23.75013924], [68.48652649, 23.75013924], [68.48652649, 23.75041962], [68.48596954, 23.7504158], [68.48596954, 23.75069427], [68.48569489, 23.75069427], [68.48569489, 23.75097275], [68.48542023, 23.75097084], [68.48542023, 23.75125122], [68.48513794, 23.75125122], [68.48513794, 23.75154114], [68.48458099, 23.75154114], [68.48458099, 23.75181007], [68.48430634, 23.75180626], [68.48430634, 23.75208282], [68.48374939, 23.75208282], [68.48374939, 23.7523613], [68.4834671, 23.75235939], [68.4834671, 23.75263977], [68.48124695, 23.75263977], [68.48124695, 23.75292015], [68.47652435, 23.75291634], [68.47652435, 23.75319481], [68.47569275, 23.75319481], [68.47569275, 23.75347137], [68.47458649, 23.75346947], [68.47458649, 23.75374985], [68.47402954, 23.75374985], [68.47402954, 23.75403023], [68.4734726, 23.75403023], [68.4734726, 23.75431061], [68.47291565, 23.75430489], [68.47291565, 23.75458336], [68.4723587, 23.75458336], [68.4723587, 23.75486183], [68.47180176, 23.75485992], [68.47180176, 23.7551403], [68.4715271, 23.7551403], [68.4715271, 23.75570107], [68.47125244, 23.75569344], [68.47125244, 23.75597191], [68.47097015, 23.75597], [68.47097015, 23.75625038], [68.47070313, 23.75625038], [68.47070313, 23.75681114], [68.47041321, 23.75680351], [68.47041321, 23.7570858], [68.47013855, 23.7570858], [68.47013855, 23.75736046], [68.46985626, 23.75735092], [68.46985626, 23.75792122], [68.4695816, 23.7579174], [68.4695816, 23.75847244], [68.46930695, 23.75847054], [68.46930695, 23.75902939], [68.46902466, 23.75902557], [68.46902466, 23.75958252], [68.46875, 23.75958061], [68.46875, 23.76013947], [68.46847534, 23.76013947], [68.46847534, 23.7606945], [68.46819305, 23.76069069], [68.46819305, 23.76124954], [68.4679184, 23.76124954], [68.4679184, 23.76180077], [68.46763611, 23.7618084], [68.46763611, 23.76320267], [68.46708679, 23.76320267], [68.46708679, 23.76375008], [68.4668045, 23.76375008], [68.4668045, 23.76458359], [68.46652985, 23.76458168], [68.46652985, 23.76542282], [68.46624756, 23.76542282], [68.46624756, 23.76625061], [68.4659729, 23.76625061], [68.4659729, 23.76680946], [68.46569824, 23.76680946], [68.46569061, 23.76764107], [68.46541595, 23.76763916], [68.46541595, 23.76847267], [68.46569061, 23.76847267], [68.46569061, 23.76874924], [68.46569824, 23.76902962], [68.4659729, 23.76902962], [68.4659729, 23.76986122], [68.46624756, 23.76986122], [68.46624756, 23.77042007], [68.46652985, 23.77041435], [68.46652985, 23.77208328], [68.46679688, 23.77207947], [68.46679688, 23.77403069], [68.46652985, 23.77403069], [68.46652985, 23.77486038], [68.46624756, 23.77486038], [68.46624756, 23.77541924], [68.46541595, 23.77541924], [68.46541595, 23.77457809], [68.46569824, 23.77458382], [68.46569824, 23.77263641], [68.46541595, 23.77264023], [68.46541595, 23.77096939], [68.4651413, 23.7709713], [68.4651413, 23.77013969], [68.46485901, 23.77013969], [68.46485901, 23.76958084], [68.46458435, 23.76958275], [68.46458435, 23.76874924], [68.46430206, 23.76875114], [68.46430206, 23.76791954], [68.4640274, 23.76791954], [68.4640274, 23.76625061], [68.46430206, 23.76625061], [68.46430206, 23.76569176], [68.46458435, 23.76569366], [68.46458435, 23.76486015], [68.46485901, 23.76486015], [68.46485901, 23.76430511], [68.4651413, 23.76431274], [68.4651413, 23.76348114], [68.46541595, 23.76348114], [68.46541595, 23.76291847], [68.46569824, 23.76291847], [68.46569824, 23.76235962], [68.4659729, 23.76236153], [68.4659729, 23.76152992], [68.46624756, 23.76152992], [68.46624756, 23.76097107], [68.46652985, 23.76097298], [68.46652985, 23.76041794], [68.4668045, 23.76041794], [68.4668045, 23.75986099], [68.46708679, 23.75986099], [68.46708679, 23.75930977], [68.46736145, 23.75930977], [68.46736145, 23.75875092], [68.46763611, 23.75875092], [68.46763611, 23.75847054], [68.4679184, 23.75847244], [68.4679184, 23.7579174], [68.46819305, 23.75792122], [68.46819305, 23.75764084], [68.46848297, 23.75764084], [68.46848297, 23.75708008], [68.46875, 23.7570858], [68.46875, 23.75680351], [68.46901703, 23.75681114], [68.46901703, 23.75625038], [68.46930695, 23.75625038], [68.46930695, 23.75570107], [68.46956635, 23.75570107], [68.46956635, 23.7551403], [68.46985626, 23.7551403], [68.46985626, 23.75457954], [68.47013855, 23.75458336], [68.47013855, 23.75374985], [68.47041321, 23.75374985], [68.47041321, 23.75292015], [68.47070313, 23.75292015], [68.47070313, 23.75235939], [68.47097015, 23.7523613], [68.47097015, 23.75208282], [68.47125244, 23.75208282], [68.47125244, 23.75180626], [68.4715271, 23.75181007], [68.4715271, 23.75154114], [68.47180176, 23.75154114], [68.47180939, 23.75125122], [68.47207642, 23.75125122], [68.47207642, 23.75097084], [68.4723587, 23.75097275], [68.4723587, 23.75069427], [68.47264099, 23.75069427], [68.47264099, 23.7504158], [68.47292328, 23.75041962], [68.47292328, 23.75013924], [68.4734726, 23.75013924], [68.4734726, 23.74986076], [68.47402954, 23.74986076], [68.47402954, 23.74957848], [68.47458649, 23.7495842], [68.47458649, 23.74930573], [68.4751358, 23.74931145], [68.4751358, 23.74902916], [68.47570038, 23.74902916], [68.47570038, 23.74875069], [68.47652435, 23.74875069], [68.47651672, 23.74847031], [68.4770813, 23.74847221], [68.4770813, 23.74819374], [68.47763824, 23.74819374], [68.47763824, 23.74791718], [68.4779129, 23.74791908], [68.4779129, 23.74764061], [68.47846985, 23.74764061], [68.47846985, 23.74653053], [68.47875977, 23.74653053], [68.47875977, 23.74514008], [68.47902679, 23.74514008], [68.47902679, 23.74430084], [68.47875214, 23.74430656], [68.47875214, 23.74374962], [68.47846985, 23.74374962], [68.47846985, 23.74319077], [68.47819519, 23.74319649], [68.47819519, 23.74263954], [68.4779129, 23.74263954], [68.4779129, 23.74237061], [68.47763824, 23.74237061], [68.47763824, 23.74180984], [68.47735596, 23.74180984], [68.47735596, 23.74152946], [68.4770813, 23.74152946], [68.4770813, 23.7412529], [68.47680664, 23.7412529], [68.47680664, 23.74069023], [68.47486115, 23.74069214], [68.47486115, 23.74041748], [68.47292328, 23.74041939], [68.47292328, 23.74014282], [68.47041321, 23.74014282], [68.47041321, 23.74041939], [68.46986389, 23.74041748], [68.46986389, 23.74069214], [68.46902466, 23.74069214], [68.46902466, 23.74097252], [68.46848297, 23.74097061], [68.46848297, 23.7412529], [68.4679184, 23.7412529], [68.4679184, 23.74152946], [68.46763611, 23.74152946], [68.46763611, 23.74180984], [68.46708679, 23.74180412], [68.46708679, 23.7420826], [68.46679688, 23.74208069], [68.46679688, 23.74237061], [68.46624756, 23.74237061], [68.46624756, 23.74263954], [68.4659729, 23.74263954], [68.4659729, 23.74291992], [68.46541595, 23.7429142], [68.46541595, 23.74319649], [68.46458435, 23.74319649], [68.46458435, 23.74347305], [68.45874786, 23.74347305], [68.45874786, 23.74319649], [68.45819092, 23.74319649], [68.45819092, 23.7429142], [68.45680237, 23.74291992], [68.45680237, 23.74263954], [68.45625305, 23.74263954], [68.45625305, 23.74237061], [68.45569611, 23.74237061], [68.45569611, 23.74208069], [68.4548645, 23.7420826], [68.4548645, 23.74180412], [68.45153046, 23.74180984], [68.45153046, 23.74152946], [68.45069122, 23.74152946], [68.45069122, 23.7412529], [68.44790649, 23.7412529], [68.44790649, 23.74097061], [68.44708252, 23.74097252], [68.44708252, 23.74069214], [68.44652557, 23.74069214], [68.44652557, 23.74041748], [68.44625092, 23.74041939], [68.44625092, 23.74014282], [68.44596863, 23.74014282], [68.44596863, 23.73986053], [68.44541931, 23.73986053], [68.44541931, 23.73958015], [68.44513702, 23.73958206], [68.44513702, 23.7393055], [68.44403076, 23.7393055], [68.44403076, 23.73958206], [68.44374847, 23.73958015], [68.44374847, 23.73986053], [68.44319153, 23.73986053], [68.44319153, 23.74014282], [68.44291687, 23.74014282], [68.44291687, 23.74041939], [68.44069672, 23.74041939], [68.44069672, 23.74014282], [68.44013977, 23.74014282], [68.44013977, 23.73986053], [68.43958282, 23.73986053], [68.43958282, 23.73958206], [68.43819427, 23.73958206], [68.43819427, 23.7393055], [68.43736267, 23.73931122], [68.43736267, 23.73986053], [68.43708038, 23.73986053], [68.43708038, 23.74069214], [68.43680573, 23.74069214], [68.43680573, 23.7420826], [68.43708038, 23.7420826], [68.43708038, 23.74319649], [68.43736267, 23.74319649], [68.43736267, 23.74347305], [68.43763733, 23.74347115], [68.43763733, 23.74403], [68.43791962, 23.74402618], [68.43791962, 23.74430656], [68.43819427, 23.74430656], [68.43819427, 23.74458313], [68.43846893, 23.74458122], [68.43846893, 23.74514008], [68.43875122, 23.74513626], [68.43875122, 23.74541855], [68.43902588, 23.74541092], [68.43902588, 23.74570084], [68.43930817, 23.74569511], [68.43930817, 23.74597168], [68.43959045, 23.74596977], [68.43959045, 23.74681091], [68.43985748, 23.74681091], [68.43985748, 23.74791908], [68.44013977, 23.74791718], [68.44013977, 23.74819374], [68.4404068, 23.74818993], [68.4404068, 23.74875069], [68.44069672, 23.74875069], [68.44069672, 23.74902916], [68.44097137, 23.74902916], [68.44097137, 23.74931145], [68.44125366, 23.74930573], [68.44125366, 23.7495842], [68.44152832, 23.74957848], [68.44152832, 23.75013924], [68.44180298, 23.75013924], [68.44180298, 23.75041962], [68.44208527, 23.7504158], [68.44208527, 23.75097275], [68.44235992, 23.75097084], [68.44235992, 23.75154114], [68.44264221, 23.75152779], [68.44264221, 23.7523613], [68.44291687, 23.7523613], [68.44291687, 23.75347137], [68.44346619, 23.75346947], [68.44346619, 23.75374985], [68.44374847, 23.75374985], [68.44374847, 23.75403023], [68.44403076, 23.75403023], [68.44403076, 23.75431061], [68.44430542, 23.75430489], [68.44430542, 23.75486183], [68.44458008, 23.75485992], [68.44458008, 23.7551403], [68.44486237, 23.7551403], [68.44486237, 23.75542068], [68.44513702, 23.75542068], [68.44513702, 23.75570107], [68.44541931, 23.75569344], [68.44541931, 23.75597191], [68.44568634, 23.75597], [68.44568634, 23.75653076], [68.44596863, 23.75653076], [68.44596863, 23.75681114], [68.44625092, 23.75680351], [68.44625092, 23.7570858], [68.44652557, 23.7570858], [68.44652557, 23.75736046], [68.44680786, 23.75735092], [68.44680786, 23.75764084], [68.44708252, 23.75763893], [68.44708252, 23.75819588], [68.44736481, 23.75819588], [68.44736481, 23.75847244], [68.44763947, 23.75847054], [68.44763947, 23.75875092], [68.44790649, 23.75875092], [68.44790649, 23.75930977], [68.44819641, 23.75930977], [68.44819641, 23.76013947], [68.44847107, 23.76013947], [68.44847107, 23.76097298], [68.44876099, 23.76097107], [68.44876099, 23.76152992], [68.44902802, 23.76152992], [68.44902802, 23.76208305], [68.44930267, 23.76208115], [68.44930267, 23.76403046], [68.44958496, 23.76402855], [68.44958496, 23.76458359], [68.44985962, 23.76458168], [68.44985962, 23.76514053], [68.45014191, 23.76513863], [68.45014191, 23.76569366], [68.45041656, 23.76569176], [68.45041656, 23.76625061], [68.45069122, 23.76625061], [68.45069122, 23.76654053], [68.45097351, 23.76652718], [68.45097351, 23.76708221], [68.45124817, 23.76708031], [68.45124817, 23.76736069], [68.45153046, 23.76736069], [68.45153046, 23.76764107], [68.45180511, 23.76763916], [68.45180511, 23.76819229], [68.45207977, 23.76819229], [68.45207977, 23.76847267], [68.45236206, 23.76847076], [68.45236206, 23.76875114], [68.45291901, 23.76875114], [68.45291901, 23.76902962], [68.45319366, 23.76902771], [68.45319366, 23.76958275], [68.45347595, 23.76958084], [68.45347595, 23.77013969], [68.45375061, 23.77013969], [68.45375061, 23.77042007], [68.45402527, 23.77041435], [68.45402527, 23.77069664], [68.45430756, 23.77069092], [68.45430756, 23.77124977], [68.45456696, 23.77124977], [68.45456696, 23.77153015], [68.4548645, 23.77152824], [68.4548645, 23.77180672], [68.45541382, 23.77180672], [68.45541382, 23.77208328], [68.45569611, 23.77208328], [68.45569611, 23.77236176], [68.45597076, 23.77235031], [68.45597076, 23.77319908], [68.45625305, 23.77319908], [68.45625305, 23.77403069], [68.45652771, 23.77402878], [68.45652771, 23.77458382], [68.45597076, 23.77457809], [68.45597076, 23.77541924], [68.45569611, 23.77541924], [68.45569611, 23.7768116], [68.45541382, 23.77680588], [68.45541382, 23.77819443], [68.45513916, 23.77819252], [68.45513916, 23.78125], [68.45485687, 23.78125], [68.45485687, 23.78403091], [68.45458221, 23.78402519], [68.45458221, 23.7859726], [68.45430756, 23.78597069], [68.45430756, 23.78652954], [68.4540329, 23.78652954], [68.4540329, 23.78680992], [68.45319366, 23.78680611], [68.45319366, 23.78708267], [68.45263672, 23.78708076], [68.45263672, 23.78736115], [68.45236206, 23.78736115], [68.45236206, 23.78819466], [68.45207977, 23.78819084], [68.45207977, 23.78874969], [68.45182037, 23.78874969], [68.45182037, 23.78902817], [68.45124817, 23.78902817], [68.45124817, 23.78930473], [68.45097351, 23.78930473], [68.45097351, 23.78958321], [68.45069122, 23.78958321], [68.45069122, 23.78986168], [68.45041656, 23.78986168], [68.45041656, 23.79014015], [68.45014191, 23.79014015], [68.45014191, 23.79042244], [68.44985962, 23.79042244], [68.44985962, 23.79071045], [68.44957733, 23.79071045], [68.44957733, 23.79236031], [68.44930267, 23.79236031], [68.44930267, 23.79292107], [68.44957733, 23.79292107], [68.44957733, 23.79375076], [68.44985962, 23.79375076], [68.44985962, 23.79514122], [68.45014191, 23.79514122], [68.45014191, 23.79624939], [68.44985962, 23.79624939], [68.44985962, 23.7970829], [68.45014191, 23.7970829], [68.45014191, 23.79736137], [68.44985962, 23.79735947], [68.44985962, 23.79763985], [68.45014191, 23.79763985], [68.45014191, 23.79819679], [68.44985962, 23.79819107], [68.44985962, 23.79874992], [68.44957733, 23.79874992], [68.44957733, 23.79959106], [68.44902802, 23.79958344], [68.44902802, 23.80097198], [68.44875336, 23.80097198], [68.44875336, 23.80208397], [68.44847107, 23.80207825], [68.44847107, 23.80291939], [68.44819641, 23.80291939], [68.44819641, 23.80402946], [68.44790649, 23.80402946], [68.44790649, 23.80513954], [68.44763947, 23.80513954], [68.44763947, 23.80597115], [68.44790649, 23.80597115], [68.44790649, 23.80653191], [68.44819641, 23.80652809], [68.44819641, 23.80680466], [68.44847107, 23.80680466], [68.44847107, 23.80708122], [68.44902802, 23.80708122], [68.44902802, 23.8073616], [68.44930267, 23.8073597], [68.44930267, 23.80764008], [68.44985962, 23.80764008], [68.44985962, 23.80792046], [68.45014191, 23.80792046], [68.45014191, 23.80820084], [68.45097351, 23.80819321], [68.45097351, 23.80847168], [68.45207977, 23.80846024], [68.45207977, 23.80875015], [68.45291901, 23.80875015], [68.45291901, 23.80903053], [68.45375061, 23.80903053], [68.45375061, 23.80875015], [68.4540329, 23.80875015], [68.45402527, 23.80847168], [68.45430756, 23.80847168], [68.45430756, 23.80763817], [68.45456696, 23.80764008], [68.45456696, 23.8073597], [68.4548645, 23.8073616], [68.4548645, 23.80708122], [68.45513916, 23.80708122], [68.45513916, 23.8073616], [68.45540619, 23.8073597], [68.45540619, 23.80792046], [68.45513916, 23.80791664], [68.45513916, 23.80847168], [68.45485687, 23.80846024], [68.45485687, 23.80903053], [68.45458221, 23.80902863], [68.45458221, 23.80958557], [68.45430756, 23.80958557], [68.45430756, 23.81347275], [68.45456696, 23.81347084], [68.45456696, 23.81402969], [68.45485687, 23.81402969], [68.45485687, 23.81459045], [68.45513916, 23.81459045], [68.45513916, 23.81513977], [68.45540619, 23.81513977], [68.45540619, 23.81541824], [68.45569611, 23.81541634], [68.45569611, 23.81569481], [68.45597076, 23.81569481], [68.45597076, 23.81597137], [68.45625305, 23.81596756], [68.45625305, 23.81624985], [68.45680237, 23.81624985], [68.45680237, 23.81653023], [68.45708466, 23.81652832], [68.45708466, 23.81680489], [68.45735931, 23.81680489], [68.45735931, 23.81708336], [68.4576416, 23.81708336], [68.4576416, 23.81736183], [68.45819092, 23.81736183], [68.45819092, 23.81764984], [68.45903015, 23.81764984], [68.45903015, 23.81792259], [68.4595871, 23.81792259], [68.4595871, 23.81820107], [68.46013641, 23.81819534], [68.46013641, 23.81847191], [68.46097565, 23.81847191], [68.46097565, 23.81875038], [68.46153259, 23.81875038], [68.46153259, 23.81903267], [68.46290588, 23.81903267], [68.46290588, 23.81931114], [68.46430206, 23.81930542], [68.46430206, 23.81958389], [68.4706955, 23.81958389], [68.4706955, 23.81986046], [68.47207642, 23.81986046], [68.47207642, 23.82014275], [68.47319794, 23.82014275], [68.47319794, 23.82042122], [68.47402954, 23.8204174], [68.47402954, 23.82069206], [68.4751358, 23.82069206], [68.4751358, 23.82097244], [68.47569275, 23.82097244], [68.47569275, 23.82125092], [68.47651672, 23.82125092], [68.47651672, 23.82152939], [68.4770813, 23.82152939], [68.4770813, 23.82180977], [68.47763824, 23.82180405], [68.47763824, 23.82208252], [68.47819519, 23.82208252], [68.47819519, 23.82236099], [68.47875214, 23.82236099], [68.47875214, 23.82263947], [68.47930908, 23.82263947], [68.47930908, 23.82291985], [68.47958374, 23.82291412], [68.47958374, 23.82319641], [68.48014069, 23.82319641], [68.48014069, 23.82347488], [68.48069763, 23.82347107], [68.48069763, 23.82374954], [68.48097229, 23.82374954], [68.48097229, 23.82402992], [68.48124695, 23.82402992], [68.48124695, 23.8243103], [68.48152924, 23.82430458], [68.48152924, 23.82458305], [68.48208618, 23.82458305], [68.48208618, 23.82486153], [68.48236084, 23.82485962], [68.48236084, 23.82514], [68.48264313, 23.82514], [68.48264313, 23.82542038], [68.48291779, 23.82542038], [68.48291779, 23.82570076], [68.48319244, 23.82569695], [68.48319244, 23.8259716], [68.4834671, 23.8259697], [68.4834671, 23.82625008], [68.48374939, 23.82625008], [68.48374939, 23.82653046], [68.48430634, 23.82653046], [68.48430634, 23.82681847], [68.48458099, 23.82680511], [68.48458099, 23.82708359], [68.48486328, 23.82708359], [68.48486328, 23.82736206], [68.48513794, 23.82736015], [68.48513794, 23.82764053], [68.48542023, 23.82764053], [68.48542023, 23.82792091], [68.48596954, 23.8279171], [68.48596954, 23.82819366], [68.48625183, 23.82819366], [68.48625183, 23.82847214], [68.48680878, 23.82846832], [68.48680878, 23.82875061], [68.48707581, 23.82875061], [68.48707581, 23.82902908], [68.48764038, 23.82902908], [68.48764038, 23.82930946], [68.48819733, 23.82930565], [68.48819733, 23.82958412], [68.48874664, 23.82957077], [68.48874664, 23.82986069], [68.48929596, 23.82986069], [68.48929596, 23.83013916], [68.48986053, 23.83013916], [68.48986053, 23.83041954], [68.49346924, 23.83041763], [68.49346924, 23.8306942], [68.49458313, 23.8306942], [68.49458313, 23.83097267], [68.49652863, 23.83097267], [68.49652863, 23.8306942], [68.49791718, 23.8306942], [68.49791718, 23.83041763], [68.49931335, 23.83041954], [68.49931335, 23.83013916], [68.50013733, 23.83013916], [68.50013733, 23.82986069], [68.50096893, 23.82986069], [68.50096893, 23.82957077], [68.50180817, 23.82958412], [68.50180817, 23.82930565], [68.50263977, 23.82930946], [68.50263977, 23.82902908], [68.50347137, 23.82902908], [68.50347137, 23.82875061], [68.50402832, 23.82875061], [68.50402832, 23.82846832], [68.50430298, 23.82847214], [68.50430298, 23.82819366], [68.50485992, 23.82819366], [68.50485992, 23.8279171], [68.50514221, 23.82792091], [68.50514221, 23.82764053], [68.50541687, 23.82764053], [68.50541687, 23.82736015], [68.50569153, 23.82736206], [68.50569153, 23.82708359], [68.50624847, 23.82708359], [68.50624847, 23.82680511], [68.50708008, 23.82681847], [68.50708008, 23.82653046], [68.50736237, 23.82653046], [68.50736237, 23.82625008], [68.50791931, 23.82625008], [68.50791931, 23.8259697], [68.50819397, 23.8259716], [68.50819397, 23.82569695], [68.50846863, 23.82570076], [68.50846863, 23.82485962], [68.50875092, 23.82486153], [68.50875092, 23.82430458], [68.5090332, 23.8243103], [68.5090332, 23.82374954], [68.50930786, 23.82374954], [68.50930786, 23.82347107], [68.50958252, 23.82347488], [68.50958252, 23.82319641], [68.50986481, 23.82319641], [68.50986481, 23.82291412], [68.51040649, 23.82291985], [68.51040649, 23.82263947], [68.51069641, 23.82263947], [68.51069641, 23.82236099], [68.51125336, 23.82236099], [68.51125336, 23.82208061], [68.51180267, 23.82208252], [68.51180267, 23.82152748], [68.51235962, 23.82152939], [68.51235962, 23.82125092], [68.51264191, 23.82125092], [68.51264191, 23.82097054], [68.51291656, 23.82097244], [68.51291656, 23.82069206], [68.51319122, 23.82069206], [68.51319122, 23.82013893], [68.51346588, 23.82014275], [68.51346588, 23.81986046], [68.51374817, 23.81986046], [68.51374817, 23.81931114], [68.51403046, 23.81931114], [68.51403046, 23.81903267], [68.51431274, 23.81903267], [68.51431274, 23.81847191], [68.51513672, 23.81847191], [68.51513672, 23.81875038], [68.51568604, 23.81875038], [68.51568604, 23.81903267], [68.51735687, 23.81903267], [68.51735687, 23.81875038], [68.51819611, 23.81875038], [68.51819611, 23.81847191], [68.51930237, 23.81847191], [68.51930237, 23.81819534], [68.51957703, 23.81820107], [68.51957703, 23.81792259], [68.51985931, 23.81792259], [68.51985931, 23.81596756], [68.51958466, 23.81597137], [68.51958466, 23.81458282], [68.51930237, 23.81459045], [68.51930237, 23.81375122], [68.51902771, 23.81375122], [68.51902771, 23.81097031], [68.51930237, 23.81097221], [68.51930237, 23.81041527], [68.51957703, 23.81042099], [68.51957703, 23.80986023], [68.51985931, 23.80986023], [68.51985931, 23.80903053], [68.5201416, 23.80903053], [68.5201416, 23.80792046], [68.52041626, 23.80792046], [68.52041626, 23.8073597], [68.52069092, 23.8073616], [68.52069092, 23.80680466], [68.52097321, 23.80680466], [68.52097321, 23.80624962], [68.52124786, 23.80624962], [68.52124786, 23.80597115], [68.52153015, 23.80597115], [68.52153015, 23.80569458], [68.52180481, 23.80569458], [68.52180481, 23.80513954], [68.5220871, 23.80513954], [68.5220871, 23.80486107], [68.52236176, 23.80486107], [68.52236176, 23.80431175], [68.52263641, 23.80431175], [68.52263641, 23.80374908], [68.5229187, 23.80374908], [68.5229187, 23.80236053], [68.52263641, 23.80236053], [68.52263641, 23.80207825], [68.52236176, 23.80208397], [68.52236176, 23.8018055], [68.5220871, 23.80180931], [68.5220871, 23.80153084], [68.52179718, 23.80153084], [68.52179718, 23.8006897], [68.52041626, 23.80069351], [68.52041626, 23.80041885], [68.51985931, 23.80042076], [68.51985931, 23.80014038], [68.51930237, 23.80014038], [68.51930237, 23.79985809], [68.51902771, 23.79986191], [68.51902771, 23.79958344], [68.51875305, 23.79959106], [68.51875305, 23.7990303], [68.51847076, 23.7990303], [68.51847076, 23.79874992], [68.51790619, 23.79874992], [68.51790619, 23.79846954], [68.51763916, 23.79847145], [68.51763916, 23.79819679], [68.5173645, 23.79819679], [68.5173645, 23.79791451], [68.51708221, 23.79792023], [68.51708221, 23.79763985], [68.51680756, 23.79763985], [68.51680756, 23.79681015], [68.51625061, 23.79681015], [68.51625061, 23.79652023], [68.51597595, 23.79652786], [68.51597595, 23.79597473], [68.51541901, 23.79597473], [68.51541901, 23.79569244], [68.51513672, 23.79569244], [68.51513672, 23.79513931], [68.51486969, 23.79514122], [68.51486969, 23.79458046], [68.51457977, 23.79458237], [68.51457977, 23.79402733], [68.51431274, 23.79403114], [68.51431274, 23.79346275], [68.51403046, 23.79347229], [68.51403046, 23.79319382], [68.51374817, 23.79319382], [68.51374817, 23.79263878], [68.51346588, 23.79264069], [68.51346588, 23.79208183], [68.51319122, 23.79208374], [68.51319122, 23.79097176], [68.51291656, 23.79097176], [68.51291656, 23.79041672], [68.51264191, 23.79042244], [68.51264191, 23.78957748], [68.51235962, 23.78958321], [68.51235962, 23.78874969], [68.51152802, 23.78874969], [68.51152802, 23.78902817], [68.51041412, 23.78902817], [68.51041412, 23.78930473], [68.50986481, 23.78930473], [68.50986481, 23.78958321], [68.50902557, 23.78958321], [68.50902557, 23.78986168], [68.50846863, 23.78986168], [68.50846863, 23.79014015], [68.50791931, 23.79014015], [68.50791931, 23.79042244], [68.50763702, 23.79042244], [68.50763702, 23.79071045], [68.50736237, 23.79069519], [68.50736237, 23.79097176], [68.50708008, 23.79097176], [68.50708008, 23.79125023], [68.50681305, 23.79125023], [68.50681305, 23.7918129], [68.50653076, 23.79180527], [68.50653076, 23.79208374], [68.50596619, 23.79208183], [68.50596619, 23.79236031], [68.50567627, 23.79236031], [68.50567627, 23.79264069], [68.50514221, 23.79264069], [68.50514221, 23.79292107], [68.50485992, 23.79291725], [68.50485992, 23.79319382], [68.50458527, 23.79319382], [68.50458527, 23.79347229], [68.50430298, 23.79346275], [68.50430298, 23.79375076], [68.50402832, 23.79375076], [68.50402832, 23.79403114], [68.50263977, 23.79403114], [68.50263977, 23.79430962], [68.50152588, 23.7943058], [68.50152588, 23.79458237], [68.50013733, 23.79458046], [68.50013733, 23.79486084], [68.49874878, 23.79486084], [68.49874878, 23.79458046], [68.49847412, 23.79458237], [68.49847412, 23.79375076], [68.49874878, 23.79375076], [68.49874878, 23.79346275], [68.49958038, 23.79347229], [68.49958038, 23.79319382], [68.50096893, 23.79319382], [68.50096893, 23.79291725], [68.50208282, 23.79292107], [68.50208282, 23.79264069], [68.50319672, 23.79264069], [68.50319672, 23.79236031], [68.50347137, 23.79236031], [68.50347137, 23.79208183], [68.50375366, 23.79208374], [68.50375366, 23.79180527], [68.50402832, 23.7918129], [68.50402832, 23.79153252], [68.5045929, 23.79153252], [68.5045929, 23.79125023], [68.50514221, 23.79125023], [68.50514221, 23.79097176], [68.50541687, 23.79097176], [68.50541687, 23.79069519], [68.50567627, 23.79071045], [68.50567627, 23.79042244], [68.50596619, 23.79042244], [68.50596619, 23.79014015], [68.50624847, 23.79014015], [68.50624847, 23.78957748], [68.50653076, 23.78958321], [68.50653076, 23.78930473], [68.50680542, 23.78930473], [68.50680542, 23.78902817], [68.50736237, 23.78902817], [68.50736237, 23.78874969], [68.50791931, 23.78874969], [68.50791931, 23.78847122], [68.50846863, 23.78847313], [68.50846863, 23.78819466], [68.50930786, 23.78819466], [68.50930786, 23.78791618], [68.50985718, 23.78791809], [68.50985718, 23.78764915], [68.51097107, 23.78764915], [68.51097107, 23.78736115], [68.51264191, 23.78736115], [68.51264191, 23.78652954], [68.51291656, 23.78652954], [68.51291656, 23.78486061], [68.51319122, 23.78486061], [68.51319122, 23.78375053], [68.51403046, 23.78375053], [68.51403046, 23.78318977], [68.51430511, 23.78319359], [68.51430511, 23.78208351], [68.51457977, 23.78208351], [68.51457977, 23.78152847], [68.51486206, 23.78152847], [68.51486206, 23.78125], [68.51513672, 23.78125], [68.51513672, 23.7804203], [68.51541901, 23.7804203], [68.51541901, 23.77985954], [68.51569366, 23.77986145], [68.51569366, 23.77930641], [68.51597595, 23.77931023], [68.51597595, 23.77902985], [68.51625061, 23.77902985], [68.51625061, 23.77874947], [68.5165329, 23.77874947], [68.51652527, 23.7784729], [68.51680756, 23.77848053], [68.51680756, 23.77819252], [68.5173645, 23.77819443], [68.5173645, 23.77763939], [68.51790619, 23.77763939], [68.51790619, 23.77736092]]], [[[68.34931183, 23.80014038], [68.34931183, 23.7990303], [68.34902954, 23.7990303], [68.34902954, 23.79319191], [68.34874725, 23.79319382], [68.34874725, 23.79069519], [68.3484726, 23.79071045], [68.3484726, 23.78791809], [68.34819794, 23.78791809], [68.34819794, 23.78569031], [68.34791565, 23.78569412], [68.34791565, 23.78402519], [68.34764099, 23.78403091], [68.34764099, 23.78264046], [68.3473587, 23.78264046], [68.3473587, 23.78181076], [68.34707642, 23.78181076], [68.34707642, 23.78096962], [68.34680939, 23.78097153], [68.34680176, 23.78013802], [68.3465271, 23.78013992], [68.3465271, 23.77958107], [68.34625244, 23.77958107], [68.34625244, 23.77930641], [68.34597015, 23.77931023], [68.34597015, 23.77902985], [68.34570313, 23.77902985], [68.34570313, 23.77874947], [68.34541321, 23.77874947], [68.34541321, 23.77848053], [68.34513855, 23.77848053], [68.34513855, 23.77819252], [68.34486389, 23.77819443], [68.34486389, 23.77791595], [68.3445816, 23.77792168], [68.3445816, 23.77763939], [68.34401703, 23.77763939], [68.34401703, 23.77736092], [68.34236145, 23.77736092], [68.34236145, 23.77708054], [68.34041595, 23.77708244], [68.34043121, 23.77763939], [68.3401413, 23.77763939], [68.3401413, 23.77792168], [68.33985901, 23.77792168], [68.33985901, 23.77848053], [68.33957672, 23.77848053], [68.33957672, 23.77931023], [68.33985901, 23.77931023], [68.33985901, 23.78264046], [68.3401413, 23.78263855], [68.3401413, 23.78319359], [68.34043121, 23.78318977], [68.34043121, 23.78403091], [68.34069061, 23.78403091], [68.34069824, 23.78514099], [68.3409729, 23.78514099], [68.3409729, 23.78625107], [68.34124756, 23.78625107], [68.34124756, 23.78736115], [68.34152985, 23.78736115], [68.34152985, 23.78847313], [68.3418045, 23.78847313], [68.3418045, 23.78930473], [68.34208679, 23.78930473], [68.34208679, 23.78986168], [68.34236145, 23.78986168], [68.34236145, 23.79042244], [68.34263611, 23.79041672], [68.34263611, 23.79097176], [68.3429184, 23.79097176], [68.3429184, 23.79153252], [68.3431778, 23.79153252], [68.3431778, 23.79236031], [68.3434906, 23.79236031], [68.3434906, 23.79292107], [68.34375, 23.79291725], [68.34375, 23.79347229], [68.34401703, 23.79346275], [68.34401703, 23.79403114], [68.34430695, 23.79402733], [68.34430695, 23.79458237], [68.3445816, 23.79458046], [68.3445816, 23.79514122], [68.34486389, 23.79513931], [68.34486389, 23.79569244], [68.34513855, 23.79569054], [68.34513855, 23.79624939], [68.34541321, 23.79624939], [68.34541321, 23.79681015], [68.3456955, 23.79680443], [68.3456955, 23.79736137], [68.34597015, 23.79735947], [68.34597015, 23.79792023], [68.34625244, 23.79791451], [68.34625244, 23.79847145], [68.3465271, 23.79846954], [68.3465271, 23.79874992], [68.34680176, 23.79874992], [68.34680176, 23.7990303], [68.34707642, 23.7990303], [68.34707642, 23.79959106], [68.3473587, 23.79958344], [68.3473587, 23.79986191], [68.34764099, 23.79985809], [68.34764099, 23.80014038], [68.34902954, 23.80014038], [68.34902954, 23.80042076], [68.34958649, 23.80042076], [68.34958649, 23.80014038], [68.34931183, 23.80014038]]], [[[68.60514069, 23.80958557], [68.60514069, 23.80930328], [68.60569763, 23.80931091], [68.60569763, 23.80875015], [68.60597229, 23.80875015], [68.60597229, 23.80792046], [68.60624695, 23.80792046], [68.60624695, 23.80708122], [68.60652924, 23.80708122], [68.60652924, 23.80652809], [68.60736084, 23.80653191], [68.60736084, 23.80624962], [68.60791779, 23.80624962], [68.60791779, 23.80569267], [68.6076355, 23.80569458], [68.6076355, 23.80541611], [68.60736084, 23.80542183], [68.60736084, 23.80486107], [68.60708618, 23.80486107], [68.60708618, 23.80458069], [68.60680389, 23.8045826], [68.60680389, 23.80347252], [68.60624695, 23.80347252], [68.60624695, 23.80319405], [68.60597229, 23.80319405], [68.60597229, 23.80264091], [68.60569763, 23.80265045], [68.60569763, 23.80236053], [68.60541534, 23.80236053], [68.60541534, 23.80208397], [68.60514069, 23.80208397], [68.60514069, 23.80152893], [68.6048584, 23.80153084], [68.6048584, 23.80125046], [68.60457611, 23.80125046], [68.60457611, 23.80096817], [68.60430908, 23.80097198], [68.60430908, 23.80069351], [68.60375214, 23.80069351], [68.60375214, 23.80041885], [68.60346985, 23.80042076], [68.60346985, 23.79985809], [68.60319519, 23.79986191], [68.60319519, 23.79958344], [68.6029129, 23.79959106], [68.6029129, 23.79931068], [68.60263824, 23.79931068], [68.60263824, 23.7990303], [68.60208893, 23.7990303], [68.60208893, 23.79874992], [68.60180664, 23.79874992], [68.60180664, 23.79792023], [68.60208893, 23.79792023], [68.60208893, 23.79681015], [68.60180664, 23.79681015], [68.60180664, 23.79624939], [68.60151672, 23.79624939], [68.60151672, 23.79597092], [68.60124969, 23.79597092], [68.60124969, 23.79624939], [68.60041809, 23.79624939], [68.60041809, 23.79652786], [68.59874725, 23.79652023], [68.59874725, 23.79681015], [68.59819794, 23.79681015], [68.59819794, 23.79652023], [68.59791565, 23.79652786], [68.59791565, 23.79624939], [68.59764099, 23.79624939], [68.59764099, 23.79569054], [68.59708405, 23.79569244], [68.59708405, 23.79597473], [68.59680176, 23.79597092], [68.59680176, 23.79624939], [68.5965271, 23.79624939], [68.5965271, 23.79652786], [68.59625244, 23.79652023], [68.59625244, 23.79681015], [68.59513855, 23.79680443], [68.59513855, 23.79736137], [68.59486389, 23.79736137], [68.59486389, 23.79819679], [68.5945816, 23.79819107], [68.5945816, 23.79874992], [68.59430695, 23.79874992], [68.59430695, 23.79931068], [68.59402466, 23.79930687], [68.59402466, 23.79986191], [68.59375, 23.79986191], [68.59375, 23.8006897], [68.59401703, 23.80069923], [68.59401703, 23.80125046], [68.59430695, 23.80125046], [68.59430695, 23.80180931], [68.59401703, 23.80180931], [68.59401703, 23.80236053], [68.59375, 23.80236053], [68.59375, 23.80291939], [68.59347534, 23.80291748], [68.59347534, 23.80347252], [68.59401703, 23.80347061], [68.59401703, 23.80374908], [68.59570313, 23.80374908], [68.59570313, 23.80402946], [68.59707642, 23.80402946], [68.59707642, 23.80431175], [68.59874725, 23.80430603], [68.59874725, 23.8045826], [68.59902954, 23.80458069], [68.59902954, 23.80513954], [68.5993042, 23.80513954], [68.5993042, 23.80569458], [68.59958649, 23.80569267], [68.59958649, 23.80624962], [68.59986115, 23.80624962], [68.59986115, 23.80653191], [68.6001358, 23.80652809], [68.6001358, 23.80708122], [68.60041809, 23.80708122], [68.60041809, 23.80764008], [68.60069275, 23.80764008], [68.60069275, 23.80792046], [68.60098267, 23.80792046], [68.60098267, 23.80820084], [68.60152435, 23.80819321], [68.60152435, 23.80847168], [68.60180664, 23.80846024], [68.60180664, 23.80875015], [68.60208893, 23.80875015], [68.60208893, 23.80903053], [68.6029129, 23.80903053], [68.6029129, 23.80931091], [68.60402679, 23.80930328], [68.60402679, 23.80958557], [68.60514069, 23.80958557]]], [[[68.5965271, 23.81264114], [68.5965271, 23.81208038], [68.59625244, 23.8120842], [68.59625244, 23.81180763], [68.59597015, 23.81180954], [68.59597015, 23.81153107], [68.59570313, 23.81153107], [68.59570313, 23.81068993], [68.59541321, 23.81069374], [68.59541321, 23.8101387], [68.59430695, 23.8101387], [68.59430695, 23.81069374], [68.59401703, 23.81068993], [68.59401703, 23.81125069], [68.59375, 23.81125069], [68.59375, 23.81153107], [68.59347534, 23.81152534], [68.59347534, 23.8120842], [68.59401703, 23.81208038], [68.59401703, 23.81236076], [68.59513855, 23.81236076], [68.59513855, 23.81264114], [68.5965271, 23.81264114]]], [[[68.3434906, 23.83792114], [68.34375, 23.83791542], [68.34375, 23.83847237], [68.34401703, 23.83847046], [68.34401703, 23.83876038], [68.34430695, 23.83876038], [68.34430695, 23.83930969], [68.3445816, 23.83930779], [68.3445816, 23.83958244], [68.34485626, 23.83958054], [68.34485626, 23.83986092], [68.34513855, 23.83986092], [68.34513855, 23.84013939], [68.34541321, 23.84013939], [68.34541321, 23.84041977], [68.3456955, 23.84041786], [68.3456955, 23.84069443], [68.34597015, 23.84069443], [68.34597015, 23.8409729], [68.3465271, 23.84097099], [68.3465271, 23.84124947], [68.34680176, 23.84124947], [68.34680176, 23.84152985], [68.34707642, 23.84152985], [68.34707642, 23.84182167], [68.34764099, 23.84180641], [68.34764099, 23.84208298], [68.34819794, 23.84208298], [68.34819794, 23.84236145], [68.34902954, 23.84235954], [68.34902954, 23.84263992], [68.34958649, 23.84263992], [68.34958649, 23.8429184], [68.3501358, 23.8429184], [68.3501358, 23.84320259], [68.35124969, 23.84319496], [68.35124969, 23.84347153], [68.35180664, 23.84347153], [68.35180664, 23.84375191], [68.35237122, 23.84375191], [68.35237122, 23.84403038], [68.35263824, 23.84403038], [68.35263824, 23.84431267], [68.35319519, 23.84430504], [68.35319519, 23.84458351], [68.35346985, 23.84458351], [68.35346985, 23.84486008], [68.35402679, 23.84486008], [68.35402679, 23.84514046], [68.35430908, 23.84514046], [68.35430908, 23.84542274], [68.35458374, 23.84541702], [68.35458374, 23.84569359], [68.35514069, 23.84569359], [68.35514069, 23.84597015], [68.35541534, 23.84597015], [68.35541534, 23.84708214], [68.35569763, 23.84708023], [68.35569763, 23.84791946], [68.35597229, 23.84791756], [68.35597229, 23.84819221], [68.35624695, 23.84819031], [68.35624695, 23.84875107], [68.35652924, 23.84875107], [68.35652924, 23.84902954], [68.35679626, 23.84902954], [68.35679626, 23.84930992], [68.35708618, 23.8493042], [68.35708618, 23.84958267], [68.3576355, 23.84958267], [68.3576355, 23.84986115], [68.35791779, 23.84986115], [68.35791779, 23.85013962], [68.3584671, 23.85013962], [68.3584671, 23.85042], [68.35901642, 23.85042], [68.35901642, 23.85070038], [68.35958099, 23.85069656], [68.35958099, 23.85097313], [68.36013794, 23.85097122], [68.36013794, 23.85124969], [68.36068726, 23.85124969], [68.36068726, 23.85153008], [68.36125183, 23.85152626], [68.36125183, 23.85180664], [68.36180878, 23.85180664], [68.36180878, 23.85208321], [68.36235809, 23.85208321], [68.36235809, 23.85236168], [68.36292267, 23.85235977], [68.36292267, 23.85264015], [68.36431122, 23.85264015], [68.36431122, 23.85292053], [68.36458588, 23.85291862], [68.36458588, 23.85347176], [68.36486053, 23.85346985], [68.36486053, 23.85375977], [68.36569214, 23.85375977], [68.36569214, 23.85403061], [68.36653137, 23.85403061], [68.36653137, 23.85430908], [68.36708069, 23.85430527], [68.36708069, 23.85458374], [68.36791992, 23.85457993], [68.36791992, 23.85486031], [68.36846924, 23.85486031], [68.36846924, 23.85514069], [68.36902618, 23.85514069], [68.36902618, 23.85541916], [68.36958313, 23.85541725], [68.36958313, 23.85569382], [68.37014008, 23.85569382], [68.37014008, 23.85597229], [68.37069702, 23.85597038], [68.37069702, 23.85625076], [68.37097168, 23.85625076], [68.37097168, 23.85652924], [68.37124634, 23.85652733], [68.37124634, 23.8568058], [68.37152863, 23.8568058], [68.37152863, 23.85708427], [68.37180328, 23.85707855], [68.37180328, 23.85736084], [68.3720932, 23.85736084], [68.3720932, 23.85763931], [68.37236023, 23.85763931], [68.37236023, 23.85791969], [68.37291718, 23.85791969], [68.37291718, 23.85763931], [68.37319183, 23.85763931], [68.37319183, 23.85736084], [68.37346649, 23.85736084], [68.37346649, 23.85707855], [68.37374878, 23.85708427], [68.37374878, 23.8568058], [68.37403107, 23.8568058], [68.37403107, 23.85652733], [68.37486267, 23.85652733], [68.37486267, 23.85708427], [68.37513733, 23.85707855], [68.37513733, 23.85736084], [68.37568665, 23.85736084], [68.37568665, 23.85763931], [68.37596893, 23.85763931], [68.37596893, 23.85791969], [68.37708282, 23.85791588], [68.37708282, 23.85847282], [68.37568665, 23.85847282], [68.37568665, 23.85874939], [68.37458038, 23.85874939], [68.37458038, 23.85902977], [68.37431335, 23.85902977], [68.37431335, 23.85931015], [68.37403107, 23.85930634], [68.37403107, 23.8595829], [68.37374878, 23.85957146], [68.37374878, 23.86013985], [68.37403107, 23.86013985], [68.37403107, 23.8615303], [68.37431335, 23.8615303], [68.37431335, 23.86431122], [68.37458038, 23.86431122], [68.37458038, 23.86541939], [68.37486267, 23.86541939], [68.37486267, 23.86680984], [68.37513733, 23.86680984], [68.37513733, 23.86763954], [68.37541962, 23.86763954], [68.37541962, 23.86847305], [68.37569427, 23.86847305], [68.37569427, 23.86958313], [68.37596893, 23.86958122], [68.37596893, 23.87042236], [68.37625122, 23.87042236], [68.37625122, 23.87153053], [68.37652588, 23.87152863], [68.37652588, 23.87236023], [68.37680817, 23.87236023], [68.37680817, 23.8729229], [68.37708282, 23.87291718], [68.37708282, 23.87319374], [68.37735748, 23.87319374], [68.37735748, 23.87347221], [68.37763977, 23.87347031], [68.37763977, 23.87403107], [68.3779068, 23.87403107], [68.3779068, 23.87430954], [68.37847137, 23.87430573], [68.37847137, 23.87458229], [68.37874603, 23.87458038], [68.37874603, 23.8748703], [68.38014221, 23.8748703], [68.38014221, 23.87458038], [68.38180542, 23.87458229], [68.38180542, 23.87430573], [68.38318634, 23.87430954], [68.38318634, 23.87403107], [68.38764191, 23.87403107], [68.38764191, 23.87430954], [68.38874817, 23.87430573], [68.38874817, 23.87458229], [68.38957977, 23.87458038], [68.38957977, 23.8748703], [68.39013672, 23.8748703], [68.39013672, 23.87514114], [68.39041901, 23.87514114], [68.39041901, 23.87541962], [68.39069366, 23.8754158], [68.39069366, 23.87569237], [68.39097595, 23.87569237], [68.39097595, 23.87597275], [68.39154053, 23.87597084], [68.39154053, 23.87625122], [68.39180756, 23.87625122], [68.39180756, 23.87652969], [68.39235687, 23.87652969], [68.39235687, 23.87681007], [68.39263916, 23.87680435], [68.39263916, 23.87708282], [68.39319611, 23.87708282], [68.39319611, 23.8773613], [68.39347076, 23.87735939], [68.39347076, 23.87763977], [68.39375305, 23.87763977], [68.39375305, 23.87792969], [68.39402771, 23.87791443], [68.39402771, 23.87819672], [68.39569092, 23.87819672], [68.39569092, 23.87791443], [68.39624786, 23.87792969], [68.39624786, 23.87763977], [68.39679718, 23.87763977], [68.39679718, 23.87735939], [68.3970871, 23.8773613], [68.3970871, 23.87708282], [68.39763641, 23.87708282], [68.39763641, 23.87680435], [68.39819336, 23.87681007], [68.39819336, 23.87652969], [68.39875031, 23.87652969], [68.39875031, 23.87625122], [68.39958191, 23.87625122], [68.39958191, 23.87597084], [68.40013885, 23.87597275], [68.40013885, 23.87569237], [68.40097046, 23.87569237], [68.40097046, 23.8754158], [68.4015274, 23.87541962], [68.4015274, 23.87514114], [68.40235901, 23.87514114], [68.40235901, 23.8748703], [68.40291595, 23.8748703], [68.40291595, 23.87458038], [68.4034729, 23.87458229], [68.4034729, 23.87430573], [68.40429688, 23.87430954], [68.40429688, 23.87403107], [68.40486145, 23.87403107], [68.40486145, 23.87375069], [68.4054184, 23.87375069], [68.4054184, 23.87347031], [68.40597534, 23.87347221], [68.40597534, 23.87319374], [68.40652466, 23.87319374], [68.40652466, 23.87291718], [68.4070816, 23.8729229], [68.4070816, 23.87264061], [68.40791321, 23.87264061], [68.40791321, 23.87236023], [68.40847015, 23.87236023], [68.40847015, 23.87208176], [68.4090271, 23.87208366], [68.4090271, 23.87180519], [68.4109726, 23.87180519], [68.4109726, 23.87152863], [68.41236115, 23.87153053], [68.41236115, 23.87125015], [68.41348267, 23.87125015], [68.41347504, 23.87097168], [68.41486359, 23.87097168], [68.41486359, 23.87069511], [68.41680908, 23.87070274], [68.41680908, 23.87042236], [68.4173584, 23.87042236], [68.4173584, 23.87014008], [68.41792297, 23.87014008], [68.41792297, 23.8698597], [68.41819763, 23.8698616], [68.41819763, 23.86958313], [68.41874695, 23.86958313], [68.41874695, 23.86930466], [68.41930389, 23.86930466], [68.41930389, 23.86902809], [68.41986084, 23.86902809], [68.41986084, 23.86874008], [68.4201355, 23.86874962], [68.4201355, 23.86847305], [68.42069244, 23.86847305], [68.42069244, 23.86819458], [68.42097473, 23.86819458], [68.42097473, 23.86791611], [68.42124939, 23.86791992], [68.42124939, 23.86763954], [68.42151642, 23.86763954], [68.42151642, 23.86736107], [68.42180634, 23.86736107], [68.42180634, 23.86708069], [68.42208099, 23.8670826], [68.42208099, 23.86680794], [68.42236328, 23.86680984], [68.42236328, 23.86652946], [68.42263794, 23.86652946], [68.42263794, 23.86625099], [68.42292023, 23.86625099], [68.42292023, 23.86597061], [68.42319489, 23.86597252], [68.42319489, 23.86569595], [68.42346954, 23.86569977], [68.42346954, 23.86541939], [68.42375183, 23.86541939], [68.42375183, 23.86514091], [68.42402649, 23.86514091], [68.42402649, 23.86486053], [68.42459106, 23.86486053], [68.42458344, 23.86319351], [68.42485809, 23.8631897], [68.42485809, 23.86291695], [68.42514038, 23.8629303], [68.42514038, 23.86236], [68.42541504, 23.86236191], [68.42541504, 23.8615284], [68.42569733, 23.8615303], [68.42569733, 23.85985947], [68.42541504, 23.85986137], [68.42541504, 23.85819435], [68.42514038, 23.85819435], [68.42514038, 23.85736084], [68.42485809, 23.85736084], [68.42485809, 23.85625076], [68.42458344, 23.85625076], [68.42458344, 23.85541725], [68.42485809, 23.85541916], [68.42485809, 23.85486031], [68.42514038, 23.85486031], [68.42514038, 23.85430908], [68.42542267, 23.85430908], [68.42542267, 23.85375977], [68.42569733, 23.85375977], [68.42569733, 23.85320091], [68.42597198, 23.85320091], [68.42597198, 23.85264015], [68.42624664, 23.85264015], [68.42624664, 23.85207939], [68.42652893, 23.85208321], [68.42652893, 23.85152626], [68.42679596, 23.85153008], [68.42679596, 23.85097122], [68.42708588, 23.85097313], [68.42708588, 23.85041428], [68.42736053, 23.85042], [68.42736053, 23.85013962], [68.42765045, 23.85013962], [68.42763519, 23.84986115], [68.42791748, 23.84986115], [68.42791748, 23.84930992], [68.42819214, 23.84930992], [68.42819214, 23.84902954], [68.4284668, 23.84902954], [68.4284668, 23.84875107], [68.42874908, 23.84875107], [68.42874908, 23.84819031], [68.42903137, 23.84819221], [68.42903137, 23.84791756], [68.42930603, 23.84791946], [68.42930603, 23.84762955], [68.42903137, 23.84763908], [68.42903137, 23.84708214], [68.42930603, 23.84708214], [68.42930603, 23.84680557], [68.42874908, 23.84680939], [68.42874908, 23.84597015], [68.42958069, 23.84597015], [68.42958069, 23.84625053], [68.43068695, 23.84625053], [68.43068695, 23.84597015], [68.43125153, 23.84597015], [68.43125153, 23.84569359], [68.43152618, 23.84569359], [68.43152618, 23.84541702], [68.43180847, 23.84542274], [68.43180847, 23.84514046], [68.43208313, 23.84514046], [68.43208313, 23.84486008], [68.43235779, 23.84486008], [68.43235779, 23.84458351], [68.43264008, 23.84458351], [68.43264008, 23.84430504], [68.4329071, 23.84431267], [68.4329071, 23.84403038], [68.43319702, 23.84403038], [68.43319702, 23.84375191], [68.43345642, 23.84375191], [68.43345642, 23.84347153], [68.43374634, 23.84347153], [68.43374634, 23.84319496], [68.43402863, 23.84320259], [68.43402863, 23.8429184], [68.4345932, 23.8429184], [68.4345932, 23.84263992], [68.43486023, 23.84263992], [68.43486023, 23.84235954], [68.43514252, 23.84236145], [68.43514252, 23.84208298], [68.43541718, 23.84208298], [68.43541718, 23.84180641], [68.43596649, 23.84182167], [68.43596649, 23.84152985], [68.43624878, 23.84152985], [68.43624878, 23.84124947], [68.43653107, 23.84124947], [68.43653107, 23.84097099], [68.43708038, 23.8409729], [68.43708038, 23.84069443], [68.43736267, 23.84069443], [68.43736267, 23.84041786], [68.43763733, 23.84041977], [68.43763733, 23.84013939], [68.43791962, 23.84013939], [68.43791962, 23.83986092], [68.43818665, 23.83986092], [68.43818665, 23.83958054], [68.43846893, 23.83958244], [68.43846893, 23.83930779], [68.43902588, 23.83930969], [68.43902588, 23.83903122], [68.43930817, 23.83903122], [68.43930817, 23.83792114], [68.43902588, 23.83792114], [68.43902588, 23.83542061], [68.43875122, 23.83542061], [68.43875122, 23.8343029], [68.43846893, 23.83430481], [68.43846893, 23.83374977], [68.43818665, 23.83374977], [68.43818665, 23.83319283], [68.43791962, 23.83319473], [68.43791962, 23.83291626], [68.43763733, 23.83292007], [68.43763733, 23.83236122], [68.43736267, 23.83236122], [68.43736267, 23.83208275], [68.43708038, 23.83208275], [68.43708038, 23.83152771], [68.43682098, 23.83152962], [68.43682098, 23.83097076], [68.43653107, 23.83097267], [68.43653107, 23.83041573], [68.43624878, 23.83041954], [68.43624878, 23.82986069], [68.43596649, 23.82986069], [68.43596649, 23.82930946], [68.43569183, 23.82930946], [68.43569183, 23.82902908], [68.43541718, 23.82902908], [68.43541718, 23.82846832], [68.43514252, 23.82847214], [68.43514252, 23.8279171], [68.43486023, 23.82792091], [68.43486023, 23.82764053], [68.4345932, 23.82764053], [68.4345932, 23.82707977], [68.43430328, 23.82708359], [68.43430328, 23.82680511], [68.43374634, 23.82681847], [68.43374634, 23.82653046], [68.43345642, 23.82653046], [68.43345642, 23.82625008], [68.4329071, 23.82625008], [68.4329071, 23.82570076], [68.43264008, 23.82570076], [68.43264008, 23.82514], [68.43235779, 23.82514], [68.43235779, 23.82485962], [68.43208313, 23.82486153], [68.43208313, 23.82458305], [68.43152618, 23.82458305], [68.43152618, 23.82430458], [68.43125153, 23.82430077], [68.43125153, 23.82402611], [68.43096924, 23.82402992], [68.43096924, 23.82347107], [68.43069458, 23.82347488], [68.43069458, 23.82319641], [68.43041992, 23.82319641], [68.43041992, 23.82291412], [68.43013763, 23.82291985], [68.43013763, 23.82236099], [68.42986298, 23.82236099], [68.42986298, 23.82208061], [68.42958069, 23.82208252], [68.42958069, 23.82152748], [68.42930603, 23.82152939], [68.42930603, 23.82097054], [68.42903137, 23.82097244], [68.42903137, 23.8204174], [68.42874908, 23.82042122], [68.42874908, 23.81986046], [68.4284668, 23.81986046], [68.4284668, 23.81931114], [68.42819214, 23.81931114], [68.42819214, 23.81875038], [68.42791748, 23.81875038], [68.42791748, 23.81792259], [68.42765045, 23.81792259], [68.42765045, 23.81679916], [68.42736053, 23.81680489], [68.42736053, 23.81569481], [68.42708588, 23.81569481], [68.42708588, 23.81458282], [68.42679596, 23.81459045], [68.42679596, 23.81291962], [68.42652893, 23.81291962], [68.42652893, 23.81042099], [68.42569733, 23.81042099], [68.42569733, 23.81014061], [68.42485809, 23.81014061], [68.42485809, 23.80986023], [68.42430878, 23.80986023], [68.42430878, 23.80957985], [68.42402649, 23.80958557], [68.42402649, 23.80930328], [68.42346954, 23.80931091], [68.42346954, 23.80903053], [68.42292023, 23.80903053], [68.42292023, 23.80875015], [68.42263794, 23.80875015], [68.42263794, 23.80846024], [68.42208099, 23.80847168], [68.42208099, 23.80819321], [68.42151642, 23.80820084], [68.42151642, 23.80792046], [68.4209671, 23.80792046], [68.4209671, 23.80764008], [68.42069244, 23.80764008], [68.42069244, 23.8073597], [68.4201355, 23.8073616], [68.4201355, 23.80708122], [68.41986084, 23.80708122], [68.41986084, 23.80680466], [68.41958618, 23.80680466], [68.41958618, 23.80652809], [68.41902924, 23.80653191], [68.41902924, 23.80624962], [68.41874695, 23.80624962], [68.41874695, 23.80597115], [68.41847229, 23.80597115], [68.41847229, 23.80569458], [68.41819763, 23.80569458], [68.41819763, 23.80541611], [68.41792297, 23.80542183], [68.41792297, 23.80513954], [68.41764069, 23.80513954], [68.41764069, 23.80569458], [68.41708374, 23.80569458], [68.41708374, 23.80597115], [68.41652679, 23.80597115], [68.41652679, 23.80624962], [68.41596985, 23.80624962], [68.41596985, 23.80653191], [68.41569519, 23.80652809], [68.41569519, 23.80680466], [68.41513824, 23.80680466], [68.41513824, 23.80708122], [68.41430664, 23.80708122], [68.41430664, 23.8073616], [68.41348267, 23.8073597], [68.41348267, 23.80764008], [68.41291809, 23.80764008], [68.41291809, 23.80792046], [68.41265106, 23.80792046], [68.41265106, 23.80820084], [68.41208649, 23.80819321], [68.41208649, 23.80847168], [68.41152954, 23.80846024], [68.41152954, 23.80875015], [68.41069794, 23.80875015], [68.41069794, 23.80903053], [68.41014099, 23.80903053], [68.41014099, 23.80931091], [68.4098587, 23.80931091], [68.4098587, 23.80986023], [68.40957642, 23.80986023], [68.40957642, 23.81014061], [68.4092865, 23.81014061], [68.4092865, 23.81042099], [68.4090271, 23.81041527], [68.4090271, 23.81069374], [68.40875244, 23.81069374], [68.40875244, 23.81097221], [68.40847015, 23.81097031], [68.40847015, 23.81180954], [68.4081955, 23.81180763], [68.40820313, 23.81236076], [68.40791321, 23.81236076], [68.40791321, 23.81430817], [68.4081955, 23.81430626], [68.4081955, 23.81513977], [68.40875244, 23.81513977], [68.40875244, 23.81541824], [68.4090271, 23.81541634], [68.4090271, 23.81597137], [68.40957642, 23.81596756], [68.40957642, 23.81624985], [68.4098587, 23.81624985], [68.4098587, 23.81653023], [68.41014099, 23.81652832], [68.41014099, 23.81680489], [68.41041565, 23.81680489], [68.41041565, 23.81708336], [68.41069794, 23.81708336], [68.41069794, 23.81736183], [68.4109726, 23.81736183], [68.4109726, 23.81792259], [68.41124725, 23.81792259], [68.41124725, 23.81820107], [68.41152954, 23.81819534], [68.41152954, 23.81847191], [68.41179657, 23.81847191], [68.41179657, 23.81875038], [68.41208649, 23.81875038], [68.41208649, 23.81903267], [68.41236115, 23.81903267], [68.41236115, 23.81931114], [68.4126358, 23.81930542], [68.4126358, 23.81958389], [68.41291809, 23.81958389], [68.41291809, 23.82069206], [68.4126358, 23.82069206], [68.4126358, 23.82097244], [68.41152954, 23.82097244], [68.41152954, 23.8204174], [68.41124725, 23.82042122], [68.41124725, 23.81986046], [68.41069794, 23.81986046], [68.41069794, 23.81958008], [68.41041565, 23.81958389], [68.41041565, 23.81930542], [68.41014099, 23.81931114], [68.41014099, 23.81875038], [68.4098587, 23.81875038], [68.4098587, 23.81847191], [68.40958405, 23.81847191], [68.40958405, 23.81791687], [68.4090271, 23.81792259], [68.4090271, 23.81764984], [68.40875244, 23.81764984], [68.40875244, 23.81736183], [68.40847015, 23.81736183], [68.40847015, 23.81708336], [68.4081955, 23.81708336], [68.4081955, 23.81680489], [68.40791321, 23.81680489], [68.40791321, 23.81652832], [68.40763855, 23.81653023], [68.40763855, 23.81624985], [68.40735626, 23.81624985], [68.40735626, 23.81596756], [68.4070816, 23.81597137], [68.4070816, 23.81569481], [68.40680695, 23.81569481], [68.40680695, 23.81513977], [68.40651703, 23.81513977], [68.40651703, 23.81180954], [68.40680695, 23.81180954], [68.40680695, 23.81125069], [68.4070816, 23.81125069], [68.4070816, 23.81014061], [68.40735626, 23.81014061], [68.40735626, 23.80986023], [68.40763855, 23.80986023], [68.40763855, 23.80957985], [68.40791321, 23.80958557], [68.40791321, 23.80930328], [68.40820313, 23.80931091], [68.40820313, 23.80903053], [68.40847015, 23.80903053], [68.40847015, 23.80875015], [68.40875244, 23.80875015], [68.40875244, 23.80846024], [68.4090271, 23.80847168], [68.4090271, 23.80819321], [68.4092865, 23.80820084], [68.40930939, 23.80792046], [68.40957642, 23.80792046], [68.40957642, 23.80764008], [68.41014099, 23.80764008], [68.41014099, 23.8073597], [68.4109726, 23.8073616], [68.4109726, 23.80708122], [68.41152954, 23.80708122], [68.41152954, 23.80680466], [68.41208649, 23.80680466], [68.41208649, 23.80652809], [68.41236115, 23.80653191], [68.41236115, 23.80624962], [68.41291809, 23.80624962], [68.41291809, 23.80597115], [68.41347504, 23.80597115], [68.41347504, 23.80569458], [68.41374969, 23.80569458], [68.41374969, 23.80541611], [68.41430664, 23.80542183], [68.41430664, 23.80513954], [68.41485596, 23.80513954], [68.41485596, 23.80486107], [68.41513824, 23.80486107], [68.41513824, 23.80431175], [68.41542053, 23.80431175], [68.41542053, 23.80374908], [68.41596985, 23.80374908], [68.41596985, 23.80207825], [68.41569519, 23.80208397], [68.41569519, 23.80152893], [68.41542053, 23.80153084], [68.41542053, 23.80125046], [68.41513824, 23.80125046], [68.41513824, 23.80096817], [68.41486359, 23.80097198], [68.41486359, 23.80069351], [68.4145813, 23.80069351], [68.4145813, 23.80013847], [68.41430664, 23.80014038], [68.41430664, 23.79985809], [68.41402435, 23.79986191], [68.41402435, 23.79958344], [68.41374969, 23.79959106], [68.41374969, 23.79931068], [68.41348267, 23.79931068], [68.41348267, 23.7990303], [68.41319275, 23.7990303], [68.41319275, 23.79874992], [68.41291809, 23.79874992], [68.41291809, 23.79846954], [68.4126358, 23.79847145], [68.4126358, 23.79819679], [68.41236115, 23.79819679], [68.41236115, 23.79791451], [68.41208649, 23.79792023], [68.41208649, 23.79735947], [68.4118042, 23.79736137], [68.4118042, 23.79680443], [68.41152954, 23.79681015], [68.41152954, 23.79652023], [68.41124725, 23.79652786], [68.41124725, 23.79624939], [68.4109726, 23.79624939], [68.4109726, 23.79569054], [68.41014099, 23.79569244], [68.41014099, 23.79541588], [68.4098587, 23.79541969], [68.4098587, 23.79514122], [68.40957642, 23.79514122], [68.40957642, 23.79486084], [68.4090271, 23.79486084], [68.4090271, 23.79458046], [68.40847015, 23.79458237], [68.40847015, 23.7943058], [68.40820313, 23.79430962], [68.40820313, 23.79403114], [68.40763855, 23.79403114], [68.40763855, 23.79375076], [68.4070816, 23.79375076], [68.4070816, 23.79346275], [68.40625, 23.79347229], [68.40625, 23.79319382], [68.4054184, 23.79319191], [68.4054184, 23.79375076], [68.40513611, 23.79375076], [68.40513611, 23.79403114], [68.40486145, 23.79403114], [68.40486145, 23.79430962], [68.4043045, 23.7943058], [68.4043045, 23.79458237], [68.40402985, 23.79458046], [68.40402985, 23.79486084], [68.40319824, 23.79486084], [68.40319061, 23.79514122], [68.40291595, 23.79514122], [68.40291595, 23.79541969], [68.40235901, 23.79541588], [68.40235901, 23.79569244], [68.40180206, 23.79569244], [68.40180206, 23.79597473], [68.4015274, 23.79597092], [68.4015274, 23.79624939], [68.40125275, 23.79624939], [68.40125275, 23.79681015], [68.40097046, 23.79680443], [68.40097046, 23.7970829], [68.4006958, 23.7970829], [68.4006958, 23.79736137], [68.40042114, 23.79735947], [68.40042114, 23.79763985], [68.40013885, 23.79763794], [68.40013885, 23.79819679], [68.3998642, 23.79819679], [68.3998642, 23.79847145], [68.39958191, 23.79846954], [68.39958191, 23.79874992], [68.39930725, 23.79874992], [68.39930725, 23.7990303], [68.39903259, 23.7990303], [68.39903259, 23.79959106], [68.39875031, 23.79958344], [68.39875031, 23.79986191], [68.39819336, 23.79985809], [68.39819336, 23.80014038], [68.3979187, 23.80013847], [68.3979187, 23.80069351], [68.39763641, 23.80069351], [68.39763641, 23.80097198], [68.3973465, 23.80096817], [68.3973465, 23.80125046], [68.3970871, 23.80125046], [68.3970871, 23.80180931], [68.39680481, 23.8018055], [68.39680481, 23.80208397], [68.39653015, 23.80207825], [68.39653015, 23.80236053], [68.39624786, 23.80236053], [68.39624786, 23.80291939], [68.39597321, 23.80291748], [68.39597321, 23.80319405], [68.39569092, 23.80319405], [68.39569092, 23.80347252], [68.39541626, 23.80347061], [68.39541626, 23.80374908], [68.3951416, 23.80374908], [68.3951416, 23.80402946], [68.39485931, 23.80402946], [68.39485931, 23.80431175], [68.39457703, 23.80431175], [68.39457703, 23.80486107], [68.39428711, 23.80486107], [68.39428711, 23.80542183], [68.39402771, 23.80541611], [68.39402771, 23.80597115], [68.39375305, 23.80597115], [68.39375305, 23.80624962], [68.39347076, 23.80624962], [68.39347076, 23.80653191], [68.39319611, 23.80652809], [68.39319611, 23.80708122], [68.39290619, 23.80708122], [68.39290619, 23.80764008], [68.39263916, 23.80763817], [68.39263916, 23.80847168], [68.39235687, 23.80846024], [68.39235687, 23.80875015], [68.39208221, 23.80875015], [68.39208221, 23.80903053], [68.39180756, 23.80902863], [68.39180756, 23.80958557], [68.39208221, 23.80958557], [68.39208221, 23.81097221], [68.39180756, 23.81097221], [68.39180756, 23.8120842], [68.39152527, 23.8120842], [68.39152527, 23.81319427], [68.39125061, 23.81319046], [68.39125061, 23.81430817], [68.39097595, 23.81430626], [68.39097595, 23.81597137], [68.39068604, 23.81596756], [68.39068604, 23.81792259], [68.39097595, 23.81792259], [68.39097595, 23.81986046], [68.39125061, 23.81986046], [68.39125061, 23.82347488], [68.39154053, 23.82347107], [68.39154053, 23.82542038], [68.39180756, 23.82541847], [68.39180756, 23.82819366], [68.39154053, 23.82818985], [68.39154053, 23.82902908], [68.39125061, 23.82902908], [68.39125061, 23.82930946], [68.39097595, 23.82930946], [68.39097595, 23.82986069], [68.39068604, 23.82986069], [68.39068604, 23.83041954], [68.39041901, 23.83041573], [68.39041901, 23.83097267], [68.39013672, 23.83097076], [68.39013672, 23.83152962], [68.38986206, 23.83152771], [68.38986206, 23.83208275], [68.38957977, 23.83208275], [68.38957977, 23.83236122], [68.38931274, 23.83236122], [68.38931274, 23.83292007], [68.38903046, 23.83291626], [68.38903046, 23.8334713], [68.38874817, 23.83346939], [68.38874817, 23.83374977], [68.38847351, 23.83374977], [68.38847351, 23.83430481], [68.38819122, 23.83430481], [68.38819122, 23.83458328], [68.38791656, 23.83458328], [68.38791656, 23.83486176], [68.38764191, 23.83485985], [68.38764191, 23.83514023], [68.38735962, 23.83514023], [68.38735962, 23.83542061], [68.38680267, 23.83541679], [68.38680267, 23.83569336], [68.38652802, 23.83569336], [68.38652802, 23.83597183], [68.38597107, 23.83596992], [68.38597107, 23.83625031], [68.38540649, 23.83625031], [68.38540649, 23.83653069], [68.38513947, 23.83653069], [68.38513947, 23.83681107], [68.38458252, 23.83680344], [68.38458252, 23.83708572], [68.38430786, 23.83708], [68.38430786, 23.83736038], [68.38375092, 23.83736038], [68.38375092, 23.83764076], [68.38263702, 23.83764076], [68.38263702, 23.83792114], [68.38180542, 23.83791542], [68.38180542, 23.8381958], [68.37958527, 23.8381958], [68.37958527, 23.83708572], [68.38014221, 23.83708572], [68.38014221, 23.83680344], [68.38096619, 23.83681107], [68.38096619, 23.83653069], [68.38181305, 23.83653069], [68.38181305, 23.83625031], [68.38263702, 23.83625031], [68.38263702, 23.83596992], [68.38375092, 23.83597183], [68.38375092, 23.83569336], [68.38402557, 23.83569336], [68.38402557, 23.83541679], [68.38458252, 23.83542061], [68.38458252, 23.83514023], [68.38513947, 23.83514023], [68.38513947, 23.83485985], [68.38569641, 23.83486176], [68.38569641, 23.83458328], [68.38625336, 23.83458328], [68.38625336, 23.83430481], [68.38680267, 23.83430481], [68.38680267, 23.83402824], [68.38707733, 23.83403015], [68.38707733, 23.83346939], [68.38735962, 23.8334713], [68.38735962, 23.83319473], [68.38764191, 23.83319473], [68.38764191, 23.83291626], [68.38791656, 23.83292007], [68.38791656, 23.83236122], [68.38819122, 23.83236122], [68.38819122, 23.8318119], [68.38848114, 23.8318119], [68.38848114, 23.83152962], [68.38874817, 23.83152962], [68.38874817, 23.83097076], [68.38903046, 23.83097267], [68.38903046, 23.83041763], [68.38931274, 23.83041954], [68.38931274, 23.82930946], [68.38957977, 23.82930946], [68.38957977, 23.82818985], [68.38986206, 23.82819366], [68.38986206, 23.81930542], [68.38957977, 23.81931114], [68.38957977, 23.81624985], [68.38930511, 23.81624985], [68.38930511, 23.81430626], [68.38957977, 23.81430817], [68.38957977, 23.81180954], [68.38986206, 23.81180954], [68.38986206, 23.81068993], [68.39013672, 23.81069374], [68.39013672, 23.80958557], [68.39041901, 23.80958557], [68.39041901, 23.80902863], [68.39068604, 23.80903053], [68.39068604, 23.80875015], [68.39097595, 23.80875015], [68.39097595, 23.80764008], [68.39125061, 23.80764008], [68.39125061, 23.8073597], [68.39152527, 23.8073616], [68.39152527, 23.80680466], [68.39180756, 23.80680466], [68.39180756, 23.80624962], [68.39208221, 23.80624962], [68.39208221, 23.80542183], [68.39235687, 23.80542183], [68.39235687, 23.80486107], [68.39263916, 23.80486107], [68.39263916, 23.80458069], [68.39291382, 23.8045826], [68.39291382, 23.80430603], [68.39319611, 23.80431175], [68.39319611, 23.80402946], [68.39347076, 23.80402946], [68.39347076, 23.80374908], [68.39375305, 23.80374908], [68.39375305, 23.80318832], [68.39402771, 23.80319405], [68.39402771, 23.80291748], [68.39428711, 23.80291939], [68.39428711, 23.80236053], [68.39457703, 23.80236053], [68.39457703, 23.80180931], [68.39485931, 23.80180931], [68.39485931, 23.80153084], [68.3951416, 23.80153084], [68.3951416, 23.80096817], [68.39541626, 23.80097198], [68.39541626, 23.80041885], [68.39569092, 23.80042076], [68.39569092, 23.80014038], [68.39597321, 23.80014038], [68.39597321, 23.79985809], [68.39624786, 23.79986191], [68.39624786, 23.79958344], [68.39653015, 23.79959106], [68.39653015, 23.79931068], [68.3970871, 23.79931068], [68.3970871, 23.7990303], [68.3973465, 23.7990303], [68.3973465, 23.79874992], [68.39763641, 23.79874992], [68.39763641, 23.79846954], [68.3979187, 23.79847145], [68.3979187, 23.79819679], [68.39819336, 23.79819679], [68.39819336, 23.79791451], [68.39848328, 23.79792023], [68.39848328, 23.79735947], [68.39875031, 23.79736137], [68.39875031, 23.7970829], [68.39902496, 23.7970829], [68.39902496, 23.79680443], [68.39930725, 23.79681015], [68.39930725, 23.79624939], [68.39958191, 23.79624939], [68.39958191, 23.79569054], [68.3998642, 23.79569244], [68.3998642, 23.79541588], [68.40013885, 23.79541969], [68.40013885, 23.79486084], [68.40042114, 23.79486084], [68.40041351, 23.79458237], [68.4006958, 23.79458237], [68.4006958, 23.79402733], [68.40097046, 23.79403114], [68.40097046, 23.79319191], [68.40125275, 23.79319382], [68.40125275, 23.79291725], [68.4015274, 23.79292107], [68.4015274, 23.79264069], [68.40180206, 23.79264069], [68.40180206, 23.79097176], [68.4015274, 23.79097176], [68.4015274, 23.79041672], [68.40125275, 23.79042244], [68.40125275, 23.79014015], [68.40071106, 23.79014015], [68.40071106, 23.78986168], [68.40013885, 23.78986168], [68.40013885, 23.78958321], [68.39902496, 23.78958321], [68.39902496, 23.78986168], [68.3970871, 23.78986168], [68.3970871, 23.79014015], [68.39541626, 23.79014015], [68.39541626, 23.79042244], [68.39402771, 23.79042244], [68.39402771, 23.79071045], [68.39263916, 23.79069519], [68.39263916, 23.79097176], [68.39125061, 23.79097176], [68.39125061, 23.79125023], [68.38986206, 23.79125023], [68.38986206, 23.79153252], [68.38903046, 23.7915287], [68.38903046, 23.79208374], [68.38764191, 23.79208183], [68.38764191, 23.79236031], [68.38707733, 23.79236031], [68.38707733, 23.79264069], [68.38652802, 23.79264069], [68.38652802, 23.79292107], [68.38569641, 23.79291725], [68.38569641, 23.79319382], [68.38513947, 23.79319382], [68.38513947, 23.79347229], [68.38458252, 23.79346275], [68.38458252, 23.79375076], [68.38375092, 23.79375076], [68.38375092, 23.79403114], [68.38318634, 23.79403114], [68.38318634, 23.79430962], [68.38236237, 23.7943058], [68.38236237, 23.79458237], [68.38180542, 23.79458237], [68.38181305, 23.79486084], [68.38096619, 23.79486084], [68.38096619, 23.79514122], [68.38014221, 23.79514122], [68.38014221, 23.79541969], [68.37875366, 23.79541588], [68.37875366, 23.79569244], [68.37847137, 23.79569244], [68.37847137, 23.79597473], [68.37819672, 23.79597092], [68.37819672, 23.79624939], [68.37791443, 23.79624939], [68.37791443, 23.79652786], [68.37763977, 23.79652786], [68.37763977, 23.7970829], [68.37708282, 23.7970829], [68.37708282, 23.79986191], [68.37680817, 23.79985809], [68.37680817, 23.80125046], [68.37652588, 23.80125046], [68.37652588, 23.80208397], [68.37625122, 23.80208397], [68.37625122, 23.80319405], [68.37596893, 23.80318832], [68.37596893, 23.80374908], [68.37541962, 23.80374908], [68.37541962, 23.80431175], [68.37513733, 23.80430603], [68.37513733, 23.8045826], [68.37486267, 23.80458069], [68.37486267, 23.80486107], [68.37458038, 23.80486107], [68.37458038, 23.80513954], [68.37431335, 23.80513954], [68.37431335, 23.80542183], [68.37403107, 23.80541611], [68.37403107, 23.80569458], [68.37347412, 23.80569458], [68.37347412, 23.80597115], [68.37319183, 23.80597115], [68.37319183, 23.80624962], [68.37291718, 23.80624962], [68.37291718, 23.80653191], [68.37264252, 23.80652809], [68.37264252, 23.80680466], [68.37208557, 23.80680466], [68.37208557, 23.80708122], [68.37180328, 23.80708122], [68.37180328, 23.8073616], [68.37152863, 23.8073597], [68.37152863, 23.80764008], [68.37097168, 23.80764008], [68.37097168, 23.80820084], [68.37069702, 23.80819321], [68.37069702, 23.80847168], [68.3704071, 23.80846024], [68.3704071, 23.80875015], [68.36985779, 23.80875015], [68.36985779, 23.80931091], [68.36958313, 23.80930328], [68.36958313, 23.80958557], [68.36818695, 23.80957985], [68.36818695, 23.80986023], [68.36708069, 23.80986023], [68.36708069, 23.80957985], [68.36653137, 23.80957985], [68.36653137, 23.80986023], [68.36541748, 23.80986023], [68.36541748, 23.81014061], [68.36486053, 23.81014061], [68.36486053, 23.80986023], [68.36431122, 23.80986023], [68.36431122, 23.81014061], [68.36292267, 23.81014061], [68.36292267, 23.80986023], [68.36264038, 23.80986023], [68.36264038, 23.81014061], [68.36207581, 23.81014061], [68.36207581, 23.81042099], [68.36069489, 23.81041527], [68.36069489, 23.81069374], [68.36013794, 23.81069374], [68.36013794, 23.81041527], [68.35958099, 23.81041527], [68.35958099, 23.81069374], [68.35930634, 23.81069374], [68.35930634, 23.81041527], [68.35847473, 23.81041527], [68.35847473, 23.81069374], [68.35736084, 23.81069374], [68.35736084, 23.81097221], [68.35514069, 23.81097221], [68.35514069, 23.81069374], [68.35375214, 23.81069374], [68.35375214, 23.81041527], [68.35320282, 23.81042099], [68.35320282, 23.81014061], [68.35237122, 23.81014061], [68.35237122, 23.80986023], [68.35124969, 23.80986023], [68.35124969, 23.80957985], [68.35041809, 23.80958557], [68.35041809, 23.80930328], [68.34931183, 23.80931091], [68.34931183, 23.80903053], [68.34902954, 23.80903053], [68.34902954, 23.80875015], [68.34874725, 23.80875015], [68.34874725, 23.80846024], [68.3484726, 23.80847168], [68.3484726, 23.80819321], [68.34819794, 23.80820084], [68.34819794, 23.80792046], [68.34764099, 23.80792046], [68.34764099, 23.80764008], [68.34680939, 23.80764008], [68.34680176, 23.8073597], [68.3465271, 23.8073616], [68.3465271, 23.80708122], [68.34625244, 23.80708122], [68.34625244, 23.80680466], [68.3456955, 23.80680466], [68.3456955, 23.80652809], [68.34541321, 23.80653191], [68.34541321, 23.80624962], [68.34513855, 23.80624962], [68.34513855, 23.80569267], [68.34486389, 23.80569458], [68.34486389, 23.80541611], [68.34430695, 23.80542183], [68.34430695, 23.80513954], [68.34401703, 23.80513954], [68.34401703, 23.80486107], [68.34375, 23.80486107], [68.34375, 23.80458069], [68.3429184, 23.8045826], [68.3429184, 23.80430603], [68.34263611, 23.80431175], [68.34263611, 23.80402946], [68.34236145, 23.80402946], [68.34236145, 23.80374908], [68.34208679, 23.80374908], [68.34208679, 23.80347061], [68.34152985, 23.80347252], [68.34152985, 23.80319405], [68.34124756, 23.80319405], [68.34124756, 23.80291748], [68.3409729, 23.80291939], [68.3409729, 23.80265045], [68.34069824, 23.80265045], [68.34069824, 23.80236053], [68.3401413, 23.80236053], [68.3401413, 23.80207825], [68.34041595, 23.80208397], [68.34041595, 23.8018055], [68.3401413, 23.80180931], [68.3401413, 23.80153084], [68.33930206, 23.80153084], [68.33930206, 23.80125046], [68.3390274, 23.80125046], [68.3390274, 23.80096817], [68.33847046, 23.80097198], [68.33847046, 23.80069351], [68.3381958, 23.80069351], [68.3381958, 23.79986191], [68.33791351, 23.79986191], [68.33791351, 23.79958344], [68.33737183, 23.79959106], [68.33737183, 23.79931068], [68.33708191, 23.79931068], [68.33708191, 23.7990303], [68.33680725, 23.7990303], [68.33680725, 23.79874992], [68.33652496, 23.79874992], [68.33652496, 23.79819679], [68.33597565, 23.79819679], [68.33597565, 23.79791451], [68.33569336, 23.79792023], [68.33569336, 23.79735947], [68.3354187, 23.79736137], [68.3354187, 23.7970829], [68.33513641, 23.7970829], [68.33513641, 23.79680443], [68.33486176, 23.79681015], [68.33486176, 23.79624939], [68.3345871, 23.79624939], [68.3345871, 23.79541969], [68.33429718, 23.79541969], [68.33429718, 23.79486084], [68.33403015, 23.79486084], [68.33403015, 23.79430962], [68.33374786, 23.79430962], [68.33374786, 23.79375076], [68.33347321, 23.79375076], [68.33347321, 23.79346275], [68.33374786, 23.79347229], [68.33374786, 23.79319382], [68.33347321, 23.79319382], [68.33347321, 23.79180527], [68.33319092, 23.7918129], [68.33319092, 23.79125023], [68.33291626, 23.79125023], [68.33291626, 23.79097176], [68.3326416, 23.79097176], [68.3326416, 23.78986168], [68.33235931, 23.78986168], [68.33235931, 23.78958321], [68.33208466, 23.78958321], [68.33208466, 23.78930473], [68.33180237, 23.78930473], [68.33180237, 23.78902817], [68.33152771, 23.78902817], [68.33152771, 23.78847122], [68.33125305, 23.78847313], [68.33125305, 23.78736115], [68.33013916, 23.78736115], [68.33013916, 23.78764915], [68.32985687, 23.78764915], [68.32985687, 23.78791809], [68.32958221, 23.78791618], [68.32958221, 23.78847313], [68.32930756, 23.78847122], [68.32930756, 23.78874969], [68.32847595, 23.78874969], [68.32847595, 23.78930473], [68.32819366, 23.78930473], [68.32819366, 23.78958321], [68.32791901, 23.78957748], [68.32791901, 23.79042244], [68.32763672, 23.79042244], [68.32763672, 23.79125023], [68.32736206, 23.79125023], [68.32736206, 23.7918129], [68.32707977, 23.7918129], [68.32707977, 23.79236031], [68.32681274, 23.79236031], [68.32681274, 23.79264069], [68.32653046, 23.79263878], [68.32653046, 23.79319382], [68.32624817, 23.79319191], [68.32624817, 23.79375076], [68.32596588, 23.79375076], [68.32596588, 23.79430962], [68.32569122, 23.7943058], [68.32569122, 23.79458237], [68.32541656, 23.79458237], [68.32543182, 23.79486084], [68.32514191, 23.79486084], [68.32514191, 23.79514122], [68.32485962, 23.79514122], [68.32485962, 23.79541969], [68.32514191, 23.79541588], [68.32514191, 23.79597473], [68.32485962, 23.79597473], [68.32485962, 23.7970829], [68.32514191, 23.79708099], [68.32514191, 23.79792023], [68.32569122, 23.79791451], [68.32569122, 23.79847145], [68.32596588, 23.79846954], [68.32596588, 23.7990303], [68.32624817, 23.7990303], [68.32624817, 23.79931068], [68.32653046, 23.79931068], [68.32653046, 23.79959106], [68.32680511, 23.79958344], [68.32680511, 23.79986191], [68.32707977, 23.79985809], [68.32707977, 23.80014038], [68.32763672, 23.80014038], [68.32763672, 23.80042076], [68.32791901, 23.80041885], [68.32791901, 23.8006897], [68.32847595, 23.80069542], [68.32847595, 23.80097198], [68.32875061, 23.80096817], [68.32875061, 23.80125046], [68.3290329, 23.80125046], [68.3290329, 23.80153084], [68.32930756, 23.80153084], [68.32930756, 23.80180931], [68.3298645, 23.8018055], [68.3298645, 23.80208397], [68.33013916, 23.80207825], [68.33013916, 23.80236053], [68.33069611, 23.80236053], [68.33069611, 23.80265045], [68.33097076, 23.80265045], [68.33097076, 23.80291939], [68.33125305, 23.80291748], [68.33125305, 23.80319405], [68.33152771, 23.80319405], [68.33152771, 23.80347252], [68.33180237, 23.80347061], [68.33180237, 23.80374908], [68.33207703, 23.80374908], [68.33207703, 23.80402946], [68.33235931, 23.80402946], [68.33235931, 23.80431175], [68.3326416, 23.80431175], [68.3326416, 23.80486107], [68.33291626, 23.80486107], [68.33291626, 23.80513954], [68.33319092, 23.80513954], [68.33319092, 23.80542183], [68.33347321, 23.80541611], [68.33347321, 23.80569458], [68.33374786, 23.80569458], [68.33374786, 23.80597115], [68.33403015, 23.80597115], [68.33403015, 23.80624962], [68.33429718, 23.80624962], [68.33429718, 23.80653191], [68.3345871, 23.80652809], [68.3345871, 23.80680466], [68.33486176, 23.80680466], [68.33486176, 23.80708122], [68.33513641, 23.80708122], [68.33513641, 23.8073616], [68.3354187, 23.8073597], [68.3354187, 23.80764008], [68.33569336, 23.80764008], [68.33569336, 23.80792046], [68.33598328, 23.80792046], [68.33598328, 23.80820084], [68.33625031, 23.80819321], [68.33625031, 23.80847168], [68.33680725, 23.80846024], [68.33680725, 23.80875015], [68.33708191, 23.80875015], [68.33708191, 23.80903053], [68.33737183, 23.80903053], [68.33737183, 23.80931091], [68.33763885, 23.80930328], [68.33763885, 23.80958557], [68.33790588, 23.80957985], [68.33790588, 23.80986023], [68.3381958, 23.80986023], [68.3381958, 23.81014061], [68.33847046, 23.81014061], [68.33847046, 23.81042099], [68.33875275, 23.81041527], [68.33875275, 23.81069374], [68.3390274, 23.81069374], [68.3390274, 23.81097221], [68.33930206, 23.81097031], [68.33930206, 23.81125069], [68.33985901, 23.81125069], [68.33985901, 23.81153107], [68.3401413, 23.81153107], [68.3401413, 23.81180954], [68.34041595, 23.81180763], [68.34041595, 23.8120842], [68.3409729, 23.81208038], [68.3409729, 23.81236076], [68.34124756, 23.81236076], [68.34124756, 23.81264114], [68.34152985, 23.81264114], [68.34152985, 23.81291962], [68.34208679, 23.81291771], [68.34208679, 23.81319427], [68.34236145, 23.81319427], [68.34236145, 23.81347275], [68.34263611, 23.81347084], [68.34263611, 23.81375122], [68.3429184, 23.81375122], [68.3429184, 23.81402969], [68.3431778, 23.81402969], [68.3431778, 23.81430817], [68.3434906, 23.81430817], [68.3434906, 23.81459045], [68.34375, 23.81458282], [68.34375, 23.8148613], [68.34401703, 23.81485748], [68.34401703, 23.81541824], [68.34430695, 23.81541634], [68.34430695, 23.81569481], [68.3445816, 23.81569481], [68.3445816, 23.81597137], [68.34485626, 23.81596756], [68.34485626, 23.81624985], [68.34513855, 23.81624985], [68.34513855, 23.81653023], [68.34541321, 23.81652832], [68.34541321, 23.81680489], [68.3456955, 23.81680489], [68.3456955, 23.81708336], [68.34597015, 23.81708145], [68.34597015, 23.81764984], [68.34623718, 23.81764984], [68.34623718, 23.81792259], [68.3465271, 23.81792259], [68.3465271, 23.81820107], [68.34680176, 23.81820107], [68.34680176, 23.81875038], [68.34708405, 23.81875038], [68.34708405, 23.81958389], [68.3473587, 23.81958389], [68.3473587, 23.82097244], [68.34764099, 23.82097054], [68.34764099, 23.82263947], [68.34791565, 23.82263947], [68.34791565, 23.82458305], [68.34764099, 23.82458115], [68.34764099, 23.82514], [68.3473587, 23.82514], [68.3473587, 23.82570076], [68.34707642, 23.82570076], [68.34707642, 23.82625008], [68.34680176, 23.82625008], [68.34680176, 23.82681847], [68.3465271, 23.82681847], [68.3465271, 23.82736015], [68.34623718, 23.82736015], [68.34623718, 23.82792091], [68.34597015, 23.8279171], [68.34597015, 23.82847214], [68.3456955, 23.82847214], [68.34570313, 23.82875061], [68.34541321, 23.82875061], [68.34541321, 23.82902908], [68.3445816, 23.82902908], [68.3445816, 23.82930946], [68.34402466, 23.82930565], [68.34402466, 23.82958412], [68.34375, 23.82957077], [68.34375, 23.83013916], [68.34347534, 23.83013916], [68.34347534, 23.8306942], [68.3431778, 23.83068848], [68.3431778, 23.83124924], [68.3429184, 23.83124924], [68.3429184, 23.83569336], [68.34263611, 23.83568954], [68.34263611, 23.83653069], [68.3429184, 23.83652687], [68.3429184, 23.83708572], [68.3431778, 23.83708], [68.3431778, 23.83764076], [68.3434906, 23.83764076], [68.3434906, 23.83792114]]], [[[68.26430511, 23.74902725], [68.26457977, 23.74902916], [68.26457977, 23.74875069], [68.26486206, 23.74875069], [68.26486206, 23.74818993], [68.26513672, 23.74819374], [68.26513672, 23.7476387], [68.26541901, 23.74764061], [68.26541901, 23.74707985], [68.26569366, 23.74708366], [68.26569366, 23.74652863], [68.26597595, 23.74653053], [68.26597595, 23.74625015], [68.26568604, 23.74625015], [68.26568604, 23.74570084], [68.26541901, 23.74570084], [68.26541901, 23.74541092], [68.26513672, 23.74541855], [68.26513672, 23.74513626], [68.26486206, 23.74514008], [68.26486206, 23.7448597], [68.26457977, 23.7448616], [68.26457977, 23.74458313], [68.26430511, 23.74458313], [68.26430511, 23.74430656], [68.26403046, 23.74430656], [68.26403046, 23.74402618], [68.26374817, 23.74403], [68.26374817, 23.74374962], [68.26346588, 23.74374962], [68.26346588, 23.74347115], [68.26319122, 23.74347305], [68.26319122, 23.74319649], [68.26291656, 23.74319649], [68.26291656, 23.74263954], [68.26264191, 23.74263954], [68.26264191, 23.74208069], [68.26235962, 23.7420826], [68.26235962, 23.74152756], [68.26207733, 23.74152946], [68.26207733, 23.74097061], [68.26180267, 23.74097252], [68.26180267, 23.74013901], [68.26152802, 23.74014282], [68.26152802, 23.73903275], [68.26125336, 23.73903275], [68.26125336, 23.73764038], [68.26097107, 23.73764038], [68.26097107, 23.73568916], [68.26125336, 23.73569489], [68.26125336, 23.73402977], [68.26152802, 23.73402977], [68.26152802, 23.73291969], [68.26180267, 23.73291969], [68.26180267, 23.73208046], [68.26208496, 23.73208427], [68.26208496, 23.73152542], [68.26235962, 23.73153114], [68.26235962, 23.73097038], [68.26264191, 23.73097229], [68.26264191, 23.73013878], [68.26235962, 23.73014069], [68.26235962, 23.72931099], [68.26207733, 23.72931099], [68.26207733, 23.72846985], [68.26180267, 23.72847176], [68.26180267, 23.72736168], [68.26152802, 23.72737122], [68.26152802, 23.72653008], [68.26125336, 23.72653008], [68.26125336, 23.72597122], [68.26097107, 23.72597122], [68.26097107, 23.72541618], [68.26069641, 23.72542191], [68.26069641, 23.72513962], [68.26040649, 23.72513962], [68.26040649, 23.72486115], [68.26013947, 23.72486115], [68.26013947, 23.72458267], [68.25986481, 23.72458267], [68.25986481, 23.72430611], [68.25958252, 23.72430611], [68.25958252, 23.72402763], [68.25930786, 23.72402954], [68.25930786, 23.72347069], [68.25902557, 23.7234726], [68.25902557, 23.72319412], [68.25875092, 23.72319412], [68.25875092, 23.72291756], [68.25846863, 23.72291946], [68.25846863, 23.72263908], [68.25818634, 23.72263908], [68.25818634, 23.72236061], [68.25791931, 23.72236061], [68.25791931, 23.72207832], [68.25763702, 23.72208405], [68.25763702, 23.72180557], [68.25736237, 23.72180939], [68.25736237, 23.72153091], [68.25708008, 23.72153091], [68.25708008, 23.721241], [68.25680542, 23.72125053], [68.25680542, 23.72097206], [68.25653076, 23.72097206], [68.25653076, 23.72069359], [68.25624847, 23.72069359], [68.25624847, 23.72041893], [68.25595856, 23.72042084], [68.25595856, 23.72014046], [68.25569153, 23.72014046], [68.25569153, 23.71986008], [68.25541687, 23.71986198], [68.25541687, 23.71958351], [68.25514221, 23.71958351], [68.25514221, 23.71930695], [68.25402832, 23.71931076], [68.25402832, 23.71875], [68.25430298, 23.71875], [68.25430298, 23.71763992], [68.2545929, 23.71763992], [68.2545929, 23.71652985], [68.25485992, 23.71652985], [68.25485992, 23.71375084], [68.25514221, 23.71375084], [68.25514221, 23.71264267], [68.25541687, 23.71264267], [68.25541687, 23.71181107], [68.25514221, 23.71181107], [68.25514221, 23.71125031], [68.25569153, 23.71125031], [68.25569153, 23.71097183], [68.25624847, 23.71097183], [68.25624847, 23.71069527], [68.25681305, 23.7107029], [68.25681305, 23.71042252], [68.25708008, 23.71042252], [68.25708008, 23.70986176], [68.25736237, 23.70986176], [68.25736237, 23.70958328], [68.25763702, 23.70958328], [68.25763702, 23.70930481], [68.25819397, 23.70930481], [68.25819397, 23.70902824], [68.25875092, 23.70902824], [68.25875092, 23.70846748], [68.25902557, 23.7084713], [68.25902557, 23.70819473], [68.25930786, 23.70819473], [68.25930786, 23.70791626], [68.25958252, 23.70791817], [68.25958252, 23.70763969], [68.25985718, 23.70763969], [68.25985718, 23.70736122], [68.26013947, 23.70736122], [68.26013947, 23.70652962], [68.26040649, 23.70652962], [68.26040649, 23.70569038], [68.26069641, 23.7056942], [68.26069641, 23.70513916], [68.26040649, 23.70514107], [68.26040649, 23.70486069], [68.26013947, 23.70486069], [68.26013947, 23.70458031], [68.26097107, 23.70458412], [68.26097107, 23.70430756], [68.26180267, 23.70430946], [68.26180267, 23.70403099], [68.26207733, 23.70403099], [68.26207733, 23.70375061], [68.26235962, 23.70375061], [68.26235962, 23.70347023], [68.26264191, 23.70347214], [68.26264191, 23.70319366], [68.26291656, 23.70319939], [68.26291656, 23.70264053], [68.26319122, 23.70264053], [68.26319122, 23.70207977], [68.26347351, 23.70208549], [68.26347351, 23.70152855], [68.26374817, 23.70153046], [68.26374817, 23.70125008], [68.26403046, 23.70125008], [68.26403046, 23.7009697], [68.26457977, 23.7009716], [68.26457977, 23.70069313], [68.26486206, 23.70070076], [68.26486206, 23.70014], [68.26515198, 23.70014], [68.26515198, 23.6993103], [68.26541901, 23.6993103], [68.26541901, 23.69847107], [68.26569366, 23.69847107], [68.26569366, 23.69791603], [68.26597595, 23.69792175], [68.26597595, 23.69735909], [68.26625061, 23.69735909], [68.26625061, 23.69681168], [68.2665329, 23.69681168], [68.2665329, 23.69625092], [68.26680756, 23.69625092], [68.26680756, 23.69568825], [68.26708221, 23.69569397], [68.26708221, 23.69430542], [68.26680756, 23.69430542], [68.26680756, 23.69180679], [68.26652527, 23.69180679], [68.26652527, 23.69097137], [68.26625061, 23.69097137], [68.26625061, 23.69041443], [68.26597595, 23.69042015], [68.26597595, 23.68985939], [68.26569366, 23.6898613], [68.26569366, 23.68930435], [68.26541901, 23.68931007], [68.26541901, 23.68875122], [68.26515198, 23.68875122], [68.26515198, 23.68847084], [68.26486206, 23.68847466], [68.26486206, 23.68819237], [68.26403046, 23.6882], [68.26403046, 23.68791962], [68.26374817, 23.68791962], [68.26374817, 23.68736076], [68.26346588, 23.68736076], [68.26346588, 23.68708038], [68.26319122, 23.68708229], [68.26319122, 23.68625069], [68.26291656, 23.68625069], [68.26291656, 23.68597031], [68.26264191, 23.68597221], [68.26264191, 23.68569374], [68.26235962, 23.68569374], [68.26235962, 23.68541718], [68.26207733, 23.6854229], [68.26207733, 23.68512917], [68.26180267, 23.6851387], [68.26180267, 23.68486023], [68.26152802, 23.68486023], [68.26152802, 23.68431282], [68.26125336, 23.68431282], [68.26125336, 23.68403244], [68.26097107, 23.68403244], [68.26097107, 23.68375015], [68.26069641, 23.68375015], [68.26069641, 23.68347168], [68.26041412, 23.68347168], [68.26041412, 23.68319511], [68.26013947, 23.68320274], [68.26013947, 23.68263817], [68.25875092, 23.68263817], [68.25875092, 23.6823597], [68.25846863, 23.6823616], [68.25846863, 23.68180466], [68.25819397, 23.68180466], [68.25819397, 23.68152809], [68.25791931, 23.68152809], [68.25791931, 23.68124962], [68.25763702, 23.68124962], [68.25763702, 23.68069077], [68.25736237, 23.68069458], [68.25736237, 23.68041611], [68.25708008, 23.68041992], [68.25708008, 23.68013954], [68.25653076, 23.68013954], [68.25653076, 23.67986107], [68.25595856, 23.67986107], [68.25595856, 23.67958069], [68.25208282, 23.67958069], [68.25208282, 23.67986107], [68.25180817, 23.67986107], [68.25180817, 23.68069458], [68.25096893, 23.68069458], [68.25096893, 23.68041611], [68.25041962, 23.68041992], [68.25041962, 23.68013954], [68.25013733, 23.68013954], [68.25013733, 23.67986107], [68.24958038, 23.67986107], [68.24958038, 23.67958069], [68.24903107, 23.6795826], [68.24903107, 23.67930794], [68.24708557, 23.67930794], [68.24708557, 23.6795826], [68.24652863, 23.6795826], [68.24652863, 23.67930794], [68.24597168, 23.67931747], [68.24597168, 23.67902946], [68.24514008, 23.67902756], [68.24514008, 23.6795826], [68.24485779, 23.67958069], [68.24485779, 23.68013954], [68.24458313, 23.68013954], [68.24458313, 23.68041992], [68.24402618, 23.68041611], [68.24402618, 23.68069458], [68.24319458, 23.68069458], [68.24319458, 23.68097305], [68.24263763, 23.68097305], [68.24263763, 23.68069458], [68.24236298, 23.68069458], [68.24236298, 23.68097305], [68.23847198, 23.68097115], [68.23847198, 23.68124962], [68.23792267, 23.68124962], [68.23792267, 23.68152809], [68.23764038, 23.68152809], [68.23764038, 23.68180466], [68.23735809, 23.68180466], [68.23735809, 23.68208313], [68.23680878, 23.68208313], [68.23680878, 23.6823616], [68.23652649, 23.6823597], [68.23652649, 23.68263817], [68.23625183, 23.68263817], [68.23625183, 23.68292236], [68.23568726, 23.68292236], [68.23568726, 23.68320274], [68.23542023, 23.68319511], [68.23542023, 23.68347168], [68.23513794, 23.68347168], [68.23513794, 23.68375015], [68.23458099, 23.68375015], [68.23458099, 23.68403244], [68.23430634, 23.68403244], [68.23430634, 23.68431282], [68.23374939, 23.68430519], [68.23374939, 23.68458366], [68.2334671, 23.68458176], [68.2334671, 23.68486023], [68.23291779, 23.68486023], [68.23291779, 23.6851387], [68.23236084, 23.68512917], [68.23236084, 23.6854229], [68.23208618, 23.68541718], [68.23208618, 23.68569374], [68.23180389, 23.68569374], [68.23180389, 23.68597221], [68.23152924, 23.68597031], [68.23152924, 23.68653107], [68.23124695, 23.68653107], [68.23124695, 23.68680954], [68.23097229, 23.68680954], [68.23097229, 23.68764114], [68.23069763, 23.68763924], [68.23069763, 23.68847466], [68.23042297, 23.68847084], [68.23042297, 23.68875122], [68.2298584, 23.68875122], [68.2298584, 23.68902969], [68.22930908, 23.68902969], [68.22930908, 23.68931007], [68.22875214, 23.68930435], [68.22875214, 23.68958282], [68.22736359, 23.68958282], [68.22736359, 23.6898613], [68.2270813, 23.68985939], [68.2270813, 23.69013977], [68.22680664, 23.69013977], [68.22680664, 23.69125938], [68.22652435, 23.69124985], [68.22652435, 23.69208336], [68.22624969, 23.69208336], [68.22624969, 23.69236183], [68.22597504, 23.69236183], [68.22597504, 23.69347191], [68.22569275, 23.69346809], [68.22569275, 23.69486046], [68.22598267, 23.69486046], [68.22598267, 23.69514084], [68.22763824, 23.69514084], [68.22763824, 23.69763947], [68.2279129, 23.69763947], [68.2279129, 23.6981945], [68.22819519, 23.6981945], [68.22819519, 23.69874954], [68.22846985, 23.69874954], [68.22846985, 23.69958115], [68.22820282, 23.69958115], [68.22820282, 23.70042038], [68.22846985, 23.70042038], [68.22846985, 23.70070076], [68.22875214, 23.70069313], [68.22875214, 23.7009716], [68.22902679, 23.7009716], [68.22902679, 23.70069313], [68.22930908, 23.70070076], [68.22930908, 23.70125008], [68.22957611, 23.70125008], [68.22958374, 23.70236015], [68.22930908, 23.70236015], [68.22930908, 23.70292091], [68.22904205, 23.70292091], [68.22904205, 23.70264053], [68.22735596, 23.70264053], [68.22735596, 23.70236015], [68.2270813, 23.70236015], [68.2270813, 23.70125008], [68.22597504, 23.70125008], [68.22597504, 23.7009716], [68.22624969, 23.7009716], [68.22624969, 23.70069313], [68.22598267, 23.70070076], [68.22598267, 23.70042038], [68.22569275, 23.70042038], [68.22569275, 23.70014], [68.22541809, 23.70014], [68.22541809, 23.69985962], [68.2243042, 23.69986153], [68.2243042, 23.69958115], [68.21986389, 23.69958115], [68.21986389, 23.69986153], [68.21901703, 23.69985962], [68.21901703, 23.70014], [68.21875, 23.70014], [68.21875, 23.70042038], [68.21848297, 23.70042038], [68.21848297, 23.70070076], [68.21819305, 23.70069313], [68.21819305, 23.7009716], [68.2179184, 23.7009697], [68.2179184, 23.70125008], [68.21763611, 23.70125008], [68.21763611, 23.70153046], [68.21710205, 23.70153046], [68.21710205, 23.70181084], [68.2159729, 23.70180321], [68.2159729, 23.70208549], [68.21541595, 23.70207977], [68.21541595, 23.70236015], [68.21485901, 23.70236015], [68.21485901, 23.70264053], [68.21430206, 23.70264053], [68.21430206, 23.70292091], [68.21404266, 23.70292091], [68.21404266, 23.70319939], [68.21347046, 23.70319366], [68.21347046, 23.70347214], [68.21290588, 23.70347023], [68.21290588, 23.70375061], [68.21235657, 23.70375061], [68.21235657, 23.70403099], [68.21208191, 23.70403099], [68.21208191, 23.70430946], [68.21152496, 23.70430756], [68.21152496, 23.70458412], [68.21096802, 23.70458031], [68.21096802, 23.70486069], [68.21069336, 23.70486069], [68.21069336, 23.7056942], [68.2104187, 23.70569038], [68.2104187, 23.70652962], [68.20903015, 23.70652962], [68.20903015, 23.70680809], [68.2076416, 23.70680618], [68.2076416, 23.70708275], [68.20735931, 23.70708084], [68.20735931, 23.70736122], [68.20707703, 23.70736122], [68.20707703, 23.70763969], [68.20680237, 23.70763969], [68.20680237, 23.70874977], [68.20652771, 23.70874977], [68.20652771, 23.70930481], [68.20680237, 23.70930481], [68.20680237, 23.70986176], [68.20652771, 23.70986176], [68.20652771, 23.71042252], [68.20625305, 23.71041679], [68.20625305, 23.71097183], [68.20597076, 23.71097183], [68.20597076, 23.71153259], [68.20569611, 23.71153259], [68.20569611, 23.71181107], [68.20541382, 23.71180534], [68.20541382, 23.71208382], [68.20513916, 23.71208191], [68.20513916, 23.71236038], [68.20487213, 23.71236038], [68.20487213, 23.71264267], [68.20458221, 23.71264267], [68.20458221, 23.71292114], [68.20430756, 23.71291733], [68.20430756, 23.71347237], [68.20402527, 23.71347237], [68.2040329, 23.71375084], [68.20375061, 23.71375084], [68.20375061, 23.71430969], [68.20347595, 23.71430588], [68.20347595, 23.71458244], [68.20318604, 23.71458054], [68.20318604, 23.71486092], [68.20291901, 23.71486092], [68.20291901, 23.71513939], [68.20263672, 23.71513939], [68.20263672, 23.71652985], [68.20236206, 23.71652985], [68.20236206, 23.71681023], [68.20207977, 23.7168045], [68.20207977, 23.71722984], [68.20207977, 23.71736145], [68.20181274, 23.71735954], [68.20181274, 23.71763992], [68.20153046, 23.71763992], [68.20153046, 23.71820068], [68.20124817, 23.71820068], [68.20124817, 23.71875], [68.20096588, 23.71875], [68.20096588, 23.71931076], [68.20069122, 23.71930695], [68.20069122, 23.71986198], [68.20041656, 23.71986198], [68.20041656, 23.72125053], [68.20014191, 23.721241], [68.20014191, 23.72153091], [68.19985962, 23.72153091], [68.19985962, 23.72180939], [68.19958496, 23.72180557], [68.19958496, 23.72208405], [68.19930267, 23.72207832], [68.19930267, 23.72236061], [68.1987381, 23.72236061], [68.1987381, 23.72263908], [68.19847107, 23.72263908], [68.19847107, 23.72291946], [68.19819641, 23.72291756], [68.19819641, 23.72319412], [68.19791412, 23.72319412], [68.19791412, 23.7234726], [68.19763947, 23.72347069], [68.19763947, 23.72374916], [68.19735718, 23.72374916], [68.19735718, 23.72402954], [68.19708252, 23.72402763], [68.19708252, 23.72430611], [68.19680786, 23.72430611], [68.19680786, 23.72458267], [68.19652557, 23.72458267], [68.1965332, 23.72513962], [68.19625092, 23.72513962], [68.19625092, 23.72542191], [68.19596863, 23.72541618], [68.19596863, 23.72569466], [68.19569397, 23.72569466], [68.19569397, 23.72597122], [68.19541931, 23.72597122], [68.19541931, 23.72624969], [68.19513702, 23.72624969], [68.19513702, 23.72680473], [68.19486237, 23.72680473], [68.19486237, 23.7270813], [68.19458008, 23.72707939], [68.19458008, 23.72764015], [68.19431305, 23.72764015], [68.19431305, 23.72820091], [68.19403076, 23.72820091], [68.19403076, 23.72875023], [68.19374847, 23.72875023], [68.19374847, 23.72931099], [68.19346619, 23.72931099], [68.19346619, 23.72986031], [68.19319153, 23.72986031], [68.19319153, 23.7304306], [68.19291687, 23.73041534], [68.19291687, 23.73097229], [68.19264221, 23.73097038], [68.19264221, 23.73236084], [68.19293213, 23.73236084], [68.19293213, 23.73291969], [68.19264221, 23.73291779], [68.19264221, 23.73319435], [68.19235992, 23.733181], [68.19235992, 23.73402977], [68.19264221, 23.73402977], [68.19264221, 23.7345829], [68.19293213, 23.73457909], [68.19293213, 23.73513985], [68.19319153, 23.73513985], [68.19319153, 23.73569489], [68.19347382, 23.73569489], [68.19347382, 23.73597145], [68.19374847, 23.73597145], [68.19374847, 23.73624992], [68.19431305, 23.73624039], [68.19431305, 23.7365303], [68.19458008, 23.7365303], [68.19458008, 23.73681259], [68.19513702, 23.73680496], [68.19513702, 23.73708344], [68.19541931, 23.73708344], [68.19541931, 23.73736191], [68.19567871, 23.73736191], [68.19567871, 23.73764038], [68.19625092, 23.73764038], [68.19625092, 23.73792267], [68.19652557, 23.73791695], [68.19652557, 23.73847008], [68.19680786, 23.73847008], [68.19680786, 23.73931122], [68.19708252, 23.73931122], [68.19708252, 23.73986053], [68.19735718, 23.73986053], [68.19735718, 23.74041939], [68.19763947, 23.74041748], [68.19763947, 23.74097252], [68.19790649, 23.74097061], [68.19790649, 23.74152946], [68.19819641, 23.74152946], [68.19819641, 23.74180984], [68.19847107, 23.74180412], [68.19847107, 23.7420826], [68.1987381, 23.74208069], [68.1987381, 23.74237061], [68.19902802, 23.74237061], [68.19902802, 23.74263954], [68.19930267, 23.74263954], [68.19930267, 23.74291992], [68.19958496, 23.7429142], [68.19958496, 23.74319649], [68.19985962, 23.74319649], [68.19985962, 23.74347305], [68.20014191, 23.74347115], [68.20014191, 23.74374962], [68.20041656, 23.74374962], [68.20041656, 23.74403], [68.20069122, 23.74402618], [68.20069122, 23.74430656], [68.20097351, 23.74430656], [68.20097351, 23.74458313], [68.20124817, 23.74458313], [68.20124817, 23.7448616], [68.20153046, 23.7448597], [68.20153046, 23.74570084], [68.20097351, 23.74569511], [68.20097351, 23.74597168], [68.20014191, 23.74596977], [68.20014191, 23.74625015], [68.19985962, 23.74625015], [68.19985962, 23.74681091], [68.20014191, 23.74681091], [68.20014191, 23.74736023], [68.20041656, 23.74736023], [68.20041656, 23.74764061], [68.20096588, 23.74764061], [68.20096588, 23.74791908], [68.20124817, 23.74791718], [68.20124817, 23.74819374], [68.20207977, 23.74819374], [68.20207977, 23.74847221], [68.20236206, 23.74847031], [68.20236206, 23.74902916], [68.20263672, 23.74902916], [68.20263672, 23.74931145], [68.20291901, 23.74930573], [68.20291901, 23.7495842], [68.20318604, 23.74957848], [68.20318604, 23.75013924], [68.20347595, 23.75013924], [68.20347595, 23.75069427], [68.20375061, 23.75068855], [68.20375061, 23.75125122], [68.20402527, 23.75124931], [68.20402527, 23.75208282], [68.20430756, 23.75208282], [68.20430756, 23.75263977], [68.20458221, 23.75263977], [68.20458221, 23.75319481], [68.2048645, 23.75319481], [68.2048645, 23.75374985], [68.20513916, 23.75374985], [68.20513916, 23.75403023], [68.20541382, 23.75402832], [68.20541382, 23.75458336], [68.20569611, 23.75458336], [68.20569611, 23.75486183], [68.20652771, 23.75485992], [68.20652771, 23.7551403], [68.20707703, 23.7551403], [68.20707703, 23.75542068], [68.20735931, 23.75541687], [68.20735931, 23.75597191], [68.2076416, 23.75597], [68.2076416, 23.75653076], [68.20791626, 23.75652695], [68.20791626, 23.7570858], [68.20819092, 23.75708008], [68.20819092, 23.75764084], [68.20847321, 23.75764084], [68.20847321, 23.75792122], [68.20903015, 23.7579174], [68.20903015, 23.75819588], [68.20930481, 23.75819588], [68.20930481, 23.75847244], [68.2095871, 23.75847054], [68.2095871, 23.75902939], [68.20986176, 23.75902557], [68.20986176, 23.75958252], [68.21013641, 23.75958061], [68.21013641, 23.76013947], [68.2104187, 23.76013947], [68.2104187, 23.7606945], [68.2106781, 23.76069069], [68.2106781, 23.76124954], [68.21096802, 23.76124954], [68.21096802, 23.76152992], [68.21125031, 23.76152992], [68.21125031, 23.76208305], [68.21152496, 23.76208305], [68.21152496, 23.76236153], [68.21180725, 23.76235962], [68.21180725, 23.76291847], [68.21208191, 23.76291847], [68.21208191, 23.76320267], [68.21180725, 23.76320267], [68.21180725, 23.76348114], [68.21263885, 23.76348114], [68.21263885, 23.76263809], [68.21290588, 23.76263809], [68.21290588, 23.76097107], [68.2131958, 23.76097298], [68.2131958, 23.75875092], [68.21290588, 23.75875092], [68.21290588, 23.75764084], [68.2131958, 23.75764084], [68.2131958, 23.75653076], [68.21347046, 23.75653076], [68.21347046, 23.75597], [68.21375275, 23.75597191], [68.21375275, 23.75541687], [68.21404266, 23.75542068], [68.21404266, 23.7551403], [68.21457672, 23.7551403], [68.21457672, 23.75485992], [68.2151413, 23.75486183], [68.2151413, 23.75458336], [68.21569824, 23.75458336], [68.21569824, 23.75430489], [68.21819305, 23.75430489], [68.21819305, 23.75458336], [68.21902466, 23.75458336], [68.21902466, 23.75486183], [68.2195816, 23.75485992], [68.2195816, 23.7551403], [68.21984863, 23.7551403], [68.21984863, 23.75542068], [68.22013855, 23.75542068], [68.22013855, 23.75570107], [68.22041321, 23.75569344], [68.22041321, 23.75597191], [68.2206955, 23.75597191], [68.2206955, 23.75625038], [68.22097015, 23.75625038], [68.22097015, 23.75681114], [68.22125244, 23.75680351], [68.22125244, 23.7570858], [68.2215271, 23.7570858], [68.2215271, 23.75736046], [68.22180176, 23.75735092], [68.22180176, 23.75764084], [68.22207642, 23.75764084], [68.22207642, 23.75792122], [68.2223587, 23.7579174], [68.2223587, 23.75819588], [68.22264099, 23.75819588], [68.22264099, 23.75847244], [68.22290802, 23.75847054], [68.22290802, 23.75902939], [68.22319794, 23.75902939], [68.22319794, 23.75930977], [68.2234726, 23.75930786], [68.2234726, 23.75958252], [68.22374725, 23.75958061], [68.22374725, 23.75986099], [68.22402954, 23.75986099], [68.22402954, 23.76013947], [68.2243042, 23.76013947], [68.2243042, 23.76041794], [68.22458649, 23.76041794], [68.22458649, 23.7606945], [68.22486115, 23.7606945], [68.22486115, 23.76097298], [68.2251358, 23.76097107], [68.2251358, 23.76152992], [68.22541809, 23.76152992], [68.22541809, 23.76208305], [68.22569275, 23.76208115], [68.22569275, 23.76263809], [68.22598267, 23.76263809], [68.22598267, 23.76403046], [68.22569275, 23.76403046], [68.22569275, 23.76486015], [68.22541809, 23.76486015], [68.22541809, 23.76585007], [68.22541809, 23.76597023], [68.2251358, 23.76597023], [68.2251358, 23.76736069], [68.22486115, 23.76736069], [68.22486115, 23.76902962], [68.22458649, 23.76902771], [68.22458649, 23.77069664], [68.22429657, 23.77069092], [68.22429657, 23.77124977], [68.22458649, 23.77124977], [68.22458649, 23.77180672], [68.2251358, 23.77180672], [68.2251358, 23.77208328], [68.22541809, 23.77208328], [68.22541809, 23.77236176], [68.22569275, 23.77236176], [68.22569275, 23.77208328], [68.22593689, 23.77208328], [68.22819519, 23.77208328], [68.22819519, 23.77236176], [68.22957611, 23.77235031], [68.22957611, 23.77264023], [68.23014069, 23.77264023], [68.23014069, 23.77292061], [68.23097229, 23.77292061], [68.23097229, 23.77319908], [68.23124695, 23.77319527], [68.23124695, 23.77347183], [68.23152924, 23.77346992], [68.23152924, 23.77375031], [68.23178864, 23.77375031], [68.23178864, 23.77403069], [68.23208618, 23.77402878], [68.23208618, 23.77458382], [68.23236084, 23.77457809], [68.23236084, 23.77486038], [68.23291779, 23.77486038], [68.23291779, 23.77457809], [68.23401642, 23.77457809], [68.23401642, 23.77486038], [68.23430634, 23.77486038], [68.23430634, 23.77569389], [68.23402405, 23.77569389], [68.23402405, 23.77597237], [68.23374939, 23.77597046], [68.23374939, 23.77625084], [68.23319244, 23.77625084], [68.23319244, 23.77763939], [68.23347473, 23.77763939], [68.23347473, 23.77819443], [68.23374939, 23.77819252], [68.23374939, 23.77874947], [68.23401642, 23.77874947], [68.23401642, 23.77902985], [68.23430634, 23.77902985], [68.23430634, 23.78013992], [68.23401642, 23.78013992], [68.23401642, 23.7804203], [68.23347473, 23.78041649], [68.23347473, 23.78097153], [68.23319244, 23.78096962], [68.23319244, 23.78181076], [68.2326355, 23.78180313], [68.2326355, 23.78208351], [68.23180389, 23.78208351], [68.23180389, 23.78041649], [68.23207855, 23.7804203], [68.23207855, 23.77902985], [68.23178864, 23.77902985], [68.23178864, 23.77708054], [68.23152924, 23.77708244], [68.23152924, 23.77625084], [68.23124695, 23.77625084], [68.23124695, 23.77568817], [68.23097229, 23.77569389], [68.23097229, 23.77541733], [68.23069763, 23.77541924], [68.23069763, 23.77514076], [68.23042297, 23.77514076], [68.23042297, 23.77486038], [68.23014069, 23.77486038], [68.23014069, 23.77457809], [68.2298584, 23.77458382], [68.2298584, 23.77430534], [68.22957611, 23.77430916], [68.22957611, 23.77403069], [68.22875214, 23.77403069], [68.22875214, 23.77375031], [68.2270813, 23.77375031], [68.2270813, 23.77403069], [68.22579193, 23.77402878], [68.22569275, 23.77402878], [68.22569275, 23.77430916], [68.22458649, 23.77430916], [68.22458649, 23.77403069], [68.22429657, 23.77403069], [68.22429657, 23.77346992], [68.22374725, 23.77346992], [68.22374725, 23.77403069], [68.2234726, 23.77402878], [68.2234726, 23.77458382], [68.22319794, 23.77457809], [68.22319794, 23.77514076], [68.22291565, 23.77514076], [68.22291565, 23.77569389], [68.22264099, 23.77568817], [68.22264099, 23.77652931], [68.2223587, 23.77652931], [68.2223587, 23.77736092], [68.22207642, 23.77736092], [68.22207642, 23.77763939], [68.22180176, 23.77763939], [68.22180176, 23.77792168], [68.2215271, 23.77791595], [68.2215271, 23.77819443], [68.22125244, 23.77819252], [68.22125244, 23.77848053], [68.22097015, 23.77848053], [68.22097015, 23.77902985], [68.22070313, 23.77902985], [68.22070313, 23.77931023], [68.22041321, 23.77930641], [68.22041321, 23.77958107], [68.22013855, 23.77958107], [68.22013855, 23.77986145], [68.21984863, 23.77985954], [68.21984863, 23.78013992], [68.21930695, 23.78013992], [68.21930695, 23.7804203], [68.21875, 23.7804203], [68.21875, 23.78070068], [68.21847534, 23.78069305], [68.21848297, 23.78125], [68.2179184, 23.78125], [68.2179184, 23.78236389], [68.21763611, 23.78236389], [68.21763611, 23.78347206], [68.2179184, 23.78347206], [68.2179184, 23.78569412], [68.21763611, 23.78569031], [68.21763611, 23.78652954], [68.21736145, 23.78652954], [68.21736145, 23.78680992], [68.2168045, 23.78680611], [68.2168045, 23.78708267], [68.21652985, 23.78708267], [68.21652985, 23.78847313], [68.21624756, 23.78847313], [68.21624756, 23.79319382], [68.2159729, 23.79319382], [68.2159729, 23.79347229], [68.21569824, 23.79346275], [68.21569061, 23.79375076], [68.21541595, 23.79375076], [68.21541595, 23.79430962], [68.2151413, 23.79430962], [68.2151413, 23.79514122], [68.21485901, 23.79513931], [68.21485901, 23.79569244], [68.21458435, 23.79569244], [68.21458435, 23.79652786], [68.21430206, 23.79652786], [68.21430206, 23.7970829], [68.21404266, 23.79708099], [68.21404266, 23.79763985], [68.21375275, 23.79763794], [68.21375275, 23.79847145], [68.21347046, 23.79846954], [68.21347046, 23.7990303], [68.2131958, 23.7990284], [68.2131958, 23.79986191], [68.21291351, 23.79986191], [68.21291351, 23.80069351], [68.21263885, 23.8006897], [68.21263885, 23.80153084], [68.2123642, 23.80152893], [68.2123642, 23.80208397], [68.21208191, 23.80207825], [68.21208191, 23.80291939], [68.21180725, 23.80291748], [68.21180725, 23.80347252], [68.21153259, 23.80347061], [68.21153259, 23.80431175], [68.21125031, 23.80431175], [68.21125031, 23.80513954], [68.21097565, 23.80513954], [68.21097565, 23.80569458], [68.2106781, 23.80569267], [68.2106781, 23.80653191], [68.2104187, 23.80653191], [68.2104187, 23.80764008], [68.21013641, 23.80764008], [68.21013641, 23.80875015], [68.20986176, 23.80875015], [68.20986176, 23.80986023], [68.2095871, 23.80986023], [68.2095871, 23.81097221], [68.20929718, 23.81097031], [68.20929718, 23.81264114], [68.2095871, 23.81264114], [68.2095871, 23.81541824], [68.20986176, 23.81541824], [68.20986176, 23.81903267], [68.21013641, 23.81903267], [68.21013641, 23.82180977], [68.2104187, 23.82180405], [68.2104187, 23.82347488], [68.21069336, 23.82347488], [68.21069336, 23.82819366], [68.21097565, 23.82819366], [68.21097565, 23.82958412], [68.21125031, 23.82957077], [68.21125031, 23.83041954], [68.21152496, 23.83041763], [68.21152496, 23.83097267], [68.21180725, 23.83097076], [68.21180725, 23.83152962], [68.21208191, 23.83152771], [68.21208191, 23.83208275], [68.21235657, 23.83208275], [68.21235657, 23.83292007], [68.21263885, 23.83292007], [68.21263885, 23.83374977], [68.21291351, 23.83374977], [68.21291351, 23.83458328], [68.2131958, 23.83458328], [68.2131958, 23.83486176], [68.21375275, 23.83485985], [68.21375275, 23.83514023], [68.21430206, 23.83514023], [68.21430206, 23.83542061], [68.21485901, 23.83541679], [68.21485901, 23.83569336], [68.21541595, 23.83569336], [68.21541595, 23.83597183], [68.2159729, 23.83596992], [68.2159729, 23.83625031], [68.2195816, 23.83625031], [68.2195816, 23.83596992], [68.2215271, 23.83597183], [68.2215271, 23.83569336], [68.22264099, 23.83569336], [68.22264099, 23.83541679], [68.22374725, 23.83542061], [68.22374725, 23.83514023], [68.22486115, 23.83514023], [68.22486115, 23.83485985], [68.22728729, 23.83485985], [68.23014069, 23.83485985], [68.23014069, 23.83514023], [68.23152924, 23.83514023], [68.23152924, 23.83542061], [68.23208618, 23.83541679], [68.23208618, 23.83569336], [68.2326355, 23.83569336], [68.2326355, 23.83597183], [68.23458099, 23.83596992], [68.23458099, 23.83625031], [68.23484802, 23.83625031], [68.23484802, 23.83681107], [68.23513794, 23.83681107], [68.23513794, 23.83736038], [68.23542023, 23.83736038], [68.23542023, 23.83792114], [68.23569489, 23.83791542], [68.23569489, 23.8381958], [68.23596954, 23.8381958], [68.23596954, 23.83847237], [68.23625183, 23.83847046], [68.23625183, 23.83903122], [68.23652649, 23.83903122], [68.23652649, 23.83930969], [68.23680878, 23.83930779], [68.23680878, 23.83958244], [68.23707581, 23.83958054], [68.23707581, 23.84013939], [68.23735809, 23.84013939], [68.23735809, 23.8409729], [68.23764038, 23.84097099], [68.23764038, 23.84152985], [68.23792267, 23.84152985], [68.23792267, 23.84182167], [68.23764038, 23.84180641], [68.23764038, 23.84236145], [68.23792267, 23.84235954], [68.23792267, 23.8429184], [68.23819733, 23.84291649], [68.23819733, 23.84347153], [68.23847198, 23.84347153], [68.23847198, 23.84403038], [68.23874664, 23.84402847], [68.23874664, 23.84458351], [68.23902893, 23.84456825], [68.23902893, 23.84514046], [68.23930359, 23.84513855], [68.23930359, 23.84569359], [68.23958588, 23.84569168], [68.23958588, 23.84625053], [68.23986053, 23.84625053], [68.23986053, 23.84680939], [68.24013519, 23.84680557], [68.24013519, 23.84736061], [68.24041748, 23.84736061], [68.24041748, 23.84791946], [68.24069214, 23.84791756], [68.24069214, 23.8484726], [68.24098206, 23.84847069], [68.24098206, 23.84902954], [68.24124908, 23.84902763], [68.24124908, 23.84958267], [68.24153137, 23.84958076], [68.24153137, 23.84986115], [68.24180603, 23.84986115], [68.24180603, 23.85042], [68.24208069, 23.85042], [68.24208069, 23.85070038], [68.24236298, 23.85070038], [68.24236298, 23.85124969], [68.24263763, 23.85124969], [68.24263763, 23.85153008], [68.24291992, 23.85152626], [68.24291992, 23.85208321], [68.24319458, 23.85208321], [68.24319458, 23.85236168], [68.24346924, 23.85235977], [68.24346924, 23.85264015], [68.24375153, 23.85264015], [68.24375153, 23.85292053], [68.24401855, 23.85292053], [68.24401855, 23.85320091], [68.24430847, 23.85319519], [68.24430847, 23.85347176], [68.2454071, 23.85346985], [68.2454071, 23.85375977], [68.24624634, 23.85375977], [68.24624634, 23.85346985], [68.24652863, 23.85347176], [68.24652863, 23.85291862], [68.24678802, 23.85292053], [68.24678802, 23.85235977], [68.24708557, 23.85236168], [68.24708557, 23.85124969], [68.24736023, 23.85124969], [68.24736023, 23.85013962], [68.24764252, 23.85013962], [68.24764252, 23.84958076], [68.24791718, 23.84958267], [68.24791718, 23.84902763], [68.24819183, 23.84902954], [68.24819183, 23.84847069], [68.24847412, 23.8484726], [68.24847412, 23.84791756], [68.24874878, 23.84791946], [68.24874878, 23.84736061], [68.24903107, 23.84736061], [68.24903107, 23.84708023], [68.24930573, 23.84708214], [68.24930573, 23.84680557], [68.24958038, 23.84680939], [68.24958038, 23.84653282], [68.25013733, 23.84653282], [68.25013733, 23.84625053], [68.25041962, 23.84625053], [68.25041962, 23.84597015], [68.25069427, 23.84597015], [68.25069427, 23.84569359], [68.25458527, 23.84569359], [68.25458527, 23.84541702], [68.25514221, 23.84542274], [68.25514221, 23.84514046], [68.25595856, 23.84514046], [68.25595856, 23.84486008], [68.25653076, 23.84486008], [68.25653076, 23.84458351], [68.25708008, 23.84458351], [68.25708008, 23.84375191], [68.25736237, 23.84375191], [68.25736237, 23.8429184], [68.25763702, 23.8429184], [68.25763702, 23.84207916], [68.25791931, 23.84208298], [68.25791931, 23.8409729], [68.25819397, 23.8409729], [68.25819397, 23.83986092], [68.25846863, 23.83986092], [68.25846863, 23.83876038], [68.25875092, 23.83876038], [68.25875092, 23.83764076], [68.25901794, 23.83764076], [68.25901794, 23.83681107], [68.25930786, 23.83681107], [68.25930786, 23.83457947], [68.25958252, 23.83458328], [68.25958252, 23.83430481], [68.25930786, 23.83430481], [68.25930786, 23.83152771], [68.25958252, 23.83152962], [68.25958252, 23.83041954], [68.25985718, 23.83041954], [68.25985718, 23.82986069], [68.26013947, 23.82986069], [68.26013947, 23.82846832], [68.26041412, 23.82847214], [68.26041412, 23.82736206], [68.26069641, 23.82736206], [68.26069641, 23.82680511], [68.26040649, 23.82681847], [68.26040649, 23.82485962], [68.26180267, 23.82485962], [68.26180267, 23.82625008], [68.26207733, 23.82625008], [68.26207733, 23.82792091], [68.26180267, 23.82792091], [68.26180267, 23.82902908], [68.26152802, 23.82902908], [68.26152802, 23.83041954], [68.26125336, 23.83041954], [68.26125336, 23.83124924], [68.26097107, 23.83124924], [68.26097107, 23.83208275], [68.26069641, 23.83208275], [68.26069641, 23.8334713], [68.26097107, 23.83346939], [68.26097107, 23.83514023], [68.26069641, 23.83514023], [68.26069641, 23.83681107], [68.26097107, 23.83681107], [68.26097107, 23.83736038], [68.26125336, 23.83736038], [68.26125336, 23.83708], [68.26180267, 23.83708572], [68.26180267, 23.83680344], [68.26291656, 23.83681107], [68.26291656, 23.83653069], [68.26486206, 23.83653069], [68.26486206, 23.83681107], [68.26875305, 23.83681107], [68.26875305, 23.83653069], [68.26930237, 23.83653069], [68.26930237, 23.83625031], [68.26985931, 23.83625031], [68.26985931, 23.83596992], [68.27069092, 23.83597183], [68.27069092, 23.83569336], [68.27124786, 23.83569336], [68.27124786, 23.83541679], [68.27153015, 23.83542061], [68.27153015, 23.83514023], [68.27179718, 23.83514023], [68.27179718, 23.83485985], [68.2720871, 23.83486176], [68.2720871, 23.83458328], [68.27263641, 23.83458328], [68.27263641, 23.83430481], [68.27735901, 23.83430481], [68.27735901, 23.83458328], [68.27791595, 23.83458328], [68.27791595, 23.83486176], [68.27819061, 23.83485985], [68.27819824, 23.83514023], [68.2784729, 23.83514023], [68.2784729, 23.83542061], [68.27874756, 23.83541679], [68.27874756, 23.83597183], [68.27902985, 23.83596992], [68.27902985, 23.83653069], [68.27929688, 23.83653069], [68.27929688, 23.83681107], [68.27958679, 23.83680344], [68.27958679, 23.83708572], [68.27986145, 23.83708], [68.27986145, 23.83764076], [68.28015137, 23.83764076], [68.28015137, 23.83792114], [68.2804184, 23.83791542], [68.2804184, 23.8381958], [68.28069305, 23.8381958], [68.28069305, 23.83847237], [68.28125, 23.83847046], [68.28125, 23.83876038], [68.28151703, 23.83876038], [68.28151703, 23.83903122], [68.28180695, 23.83903122], [68.28180695, 23.83930969], [68.2820816, 23.83930779], [68.2820816, 23.83958244], [68.28235626, 23.83958054], [68.28235626, 23.83986092], [68.28289795, 23.83986092], [68.28289795, 23.84013939], [68.28375244, 23.84013939], [68.28375244, 23.84041977], [68.28457642, 23.84041977], [68.28457642, 23.84013939], [68.28542328, 23.84013939], [68.28541565, 23.83986092], [68.2859726, 23.83986092], [68.2859726, 23.83958054], [68.28624725, 23.83958244], [68.28624725, 23.83930779], [68.28736115, 23.83930779], [68.28736115, 23.83958244], [68.2876358, 23.83958054], [68.2876358, 23.84041977], [68.28736115, 23.84041786], [68.28736115, 23.84069443], [68.28708649, 23.84069443], [68.28708649, 23.8409729], [68.28679657, 23.84097099], [68.28679657, 23.84124947], [68.2859726, 23.84124947], [68.2859726, 23.84152985], [68.28514099, 23.84152985], [68.28514099, 23.84182167], [68.28318787, 23.84182167], [68.28318787, 23.84152985], [68.28235626, 23.84152985], [68.28235626, 23.84124947], [68.28151703, 23.84124947], [68.28151703, 23.84097099], [68.28125, 23.8409729], [68.28125, 23.84041786], [68.28098297, 23.84041977], [68.28098297, 23.84013939], [68.28069305, 23.84013939], [68.28069305, 23.83986092], [68.28013611, 23.83986092], [68.28013611, 23.83958244], [68.27958679, 23.83958244], [68.27958679, 23.83930779], [68.27929688, 23.83930969], [68.27929688, 23.83903122], [68.27902985, 23.83903122], [68.27902985, 23.83847046], [68.27874756, 23.83847237], [68.27874756, 23.8381958], [68.2784729, 23.8381958], [68.2784729, 23.83763885], [68.27819824, 23.83764076], [68.27819824, 23.83736038], [68.27791595, 23.83736038], [68.27791595, 23.83708], [68.2776413, 23.83708572], [68.2776413, 23.83652687], [68.27735901, 23.83653069], [68.27735901, 23.83596992], [68.27680206, 23.83597183], [68.27680206, 23.83569336], [68.27319336, 23.83568954], [68.27319336, 23.83625031], [68.2729187, 23.83625031], [68.2729187, 23.83681107], [68.27263641, 23.83680344], [68.27263641, 23.83708572], [68.27236176, 23.83708], [68.27236176, 23.83736038], [68.2720871, 23.83736038], [68.2720871, 23.83764076], [68.27124786, 23.83764076], [68.27124786, 23.83792114], [68.26930237, 23.83791542], [68.26930237, 23.8381958], [68.26403046, 23.8381958], [68.26403046, 23.83791542], [68.26347351, 23.83791542], [68.26347351, 23.8381958], [68.26264191, 23.83819008], [68.26264191, 23.83876038], [68.26097107, 23.83876038], [68.26097107, 23.83930969], [68.26069641, 23.83930969], [68.26069641, 23.83986092], [68.26040649, 23.83986092], [68.26040649, 23.84013939], [68.26013947, 23.84013939], [68.26013947, 23.84069443], [68.25985718, 23.84069061], [68.25985718, 23.84124947], [68.25958252, 23.84124947], [68.25958252, 23.84182167], [68.25930786, 23.84182167], [68.25930786, 23.8429184], [68.25902557, 23.84291649], [68.25902557, 23.84347153], [68.25875092, 23.84347153], [68.25875092, 23.84403038], [68.25846863, 23.84402847], [68.25846863, 23.84458351], [68.25818634, 23.84456825], [68.25818634, 23.84514046], [68.25791931, 23.84514046], [68.25791931, 23.84542274], [68.25736237, 23.84541702], [68.25736237, 23.84569359], [68.25708008, 23.84569359], [68.25708008, 23.84597015], [68.25680542, 23.84597015], [68.25681305, 23.84625053], [68.25569153, 23.84625053], [68.25569153, 23.84653282], [68.25485992, 23.84653282], [68.25485992, 23.84680939], [68.25402832, 23.84680557], [68.25402832, 23.84708214], [68.25319672, 23.84708214], [68.25321198, 23.84736061], [68.25208282, 23.84736061], [68.25208282, 23.84763908], [68.25125122, 23.84762955], [68.25125122, 23.84791946], [68.25041962, 23.84791756], [68.25041962, 23.84819221], [68.25013733, 23.84819221], [68.25013733, 23.8484726], [68.24986267, 23.84847069], [68.24986267, 23.84875107], [68.24958038, 23.84874916], [68.24958038, 23.85236168], [68.24931335, 23.85235977], [68.24931335, 23.85320091], [68.24903107, 23.85320091], [68.24903107, 23.85375977], [68.24874878, 23.85375977], [68.24874878, 23.85403061], [68.24931335, 23.85403061], [68.24931335, 23.85430908], [68.24958038, 23.85430527], [68.24958038, 23.85458374], [68.24986267, 23.85457993], [68.24986267, 23.85486031], [68.25013733, 23.85486031], [68.25013733, 23.85514069], [68.25041962, 23.85514069], [68.25041962, 23.85541916], [68.25069427, 23.85541725], [68.25069427, 23.85569382], [68.25125122, 23.85569382], [68.25125122, 23.85597229], [68.25152588, 23.85597038], [68.25152588, 23.85625076], [68.25180817, 23.85625076], [68.25180817, 23.85652924], [68.25208282, 23.85652733], [68.25208282, 23.8568058], [68.25235748, 23.8568058], [68.25235748, 23.85708427], [68.25263977, 23.85707855], [68.25263977, 23.85736084], [68.25292206, 23.85736084], [68.25292206, 23.85763931], [68.25321198, 23.85763931], [68.25321198, 23.85791969], [68.25347137, 23.85791588], [68.25347137, 23.85819435], [68.25375366, 23.85819435], [68.25375366, 23.85847282], [68.25402832, 23.85847282], [68.25402832, 23.85874939], [68.25430298, 23.85874939], [68.25430298, 23.85902977], [68.25402832, 23.85902977], [68.25402832, 23.85931015], [68.25430298, 23.85930634], [68.25430298, 23.85986137], [68.2545929, 23.85985947], [68.2545929, 23.86042023], [68.25485992, 23.86041641], [68.25485992, 23.86097145], [68.25514221, 23.86096954], [68.25514221, 23.86124992], [68.25541687, 23.86124992], [68.25541687, 23.86181068], [68.25569153, 23.86180305], [68.25569153, 23.86208344], [68.25597382, 23.86208344], [68.25597382, 23.86236191], [68.25624847, 23.86236], [68.25624847, 23.86264038], [68.25653076, 23.86263847], [68.25653076, 23.8631897], [68.25681305, 23.86320114], [68.25681305, 23.86403084], [68.25708008, 23.86402512], [68.25708008, 23.86458588], [68.25736237, 23.86458015], [68.25736237, 23.86514091], [68.25763702, 23.8651371], [68.25763702, 23.86918259], [68.25763702, 23.86930466], [68.2578125, 23.86930275], [68.25791931, 23.86930084], [68.25791931, 23.87070274], [68.25819397, 23.87069511], [68.25819397, 23.87097168], [68.25846863, 23.87097168], [68.25846863, 23.87125015], [68.25875092, 23.87125015], [68.25875092, 23.87153053], [68.25930786, 23.87152863], [68.25930786, 23.87180519], [68.26097107, 23.87180519], [68.26097107, 23.87152863], [68.26125336, 23.87152863], [68.26264191, 23.87153053], [68.26264191, 23.87125015], [68.26515198, 23.87125015], [68.26513672, 23.87097168], [68.26819611, 23.87097168], [68.26819611, 23.87069511], [68.27124786, 23.87070274], [68.27124786, 23.87042236], [68.2720871, 23.87042236], [68.2720871, 23.87014008], [68.27263641, 23.87014008], [68.27263641, 23.8698597], [68.2729187, 23.8698616], [68.2729187, 23.86958313], [68.27347565, 23.86958313], [68.27347565, 23.86930466], [68.27402496, 23.86930466], [68.27402496, 23.86902809], [68.27430725, 23.86902809], [68.27430725, 23.86874008], [68.2748642, 23.86874962], [68.2748642, 23.86847305], [68.27541351, 23.86847305], [68.27541351, 23.86819458], [68.27708435, 23.86819458], [68.27708435, 23.86791611], [68.2804184, 23.86791611], [68.2804184, 23.86819458], [68.28152466, 23.86819458], [68.28152466, 23.86847305], [68.28291321, 23.86847305], [68.28291321, 23.86874962], [68.28318787, 23.86874008], [68.28318787, 23.86902809], [68.28347015, 23.86902809], [68.28347015, 23.86930466], [68.28430176, 23.86930466], [68.28430176, 23.86958313], [68.28458405, 23.86958313], [68.28458405, 23.8698616], [68.2848587, 23.8698597], [68.2848587, 23.87014008], [68.28569794, 23.87014008], [68.28569794, 23.87042236], [68.28624725, 23.87042236], [68.28624725, 23.87070274], [68.28652954, 23.87069511], [68.28652954, 23.87097168], [68.28708649, 23.87097168], [68.28708649, 23.87125015], [68.28736115, 23.87125015], [68.28736115, 23.87153053], [68.28791809, 23.87152863], [68.28791809, 23.87180519], [68.28847504, 23.87180519], [68.28847504, 23.87208366], [68.28874969, 23.87208176], [68.28874969, 23.87236023], [68.2895813, 23.87236023], [68.2895813, 23.87264061], [68.29013824, 23.87264061], [68.29013824, 23.8729229], [68.29319763, 23.8729229], [68.29319763, 23.87264061], [68.29374695, 23.87264061], [68.29374695, 23.87236023], [68.29402924, 23.87236023], [68.29402924, 23.87179947], [68.29430389, 23.87180519], [68.29430389, 23.87125015], [68.29458618, 23.87125015], [68.29458618, 23.87097168], [68.29486084, 23.87097168], [68.29486084, 23.87069511], [68.29512787, 23.87070274], [68.29512787, 23.87042236], [68.29541779, 23.87042236], [68.29541779, 23.8698597], [68.29569244, 23.8698616], [68.29569244, 23.86958313], [68.29597473, 23.86958313], [68.29597473, 23.86930466], [68.29624939, 23.86930466], [68.29624939, 23.86902809], [68.29651642, 23.86902809], [68.29651642, 23.86874008], [68.29680634, 23.86874962], [68.29680634, 23.86847305], [68.29736328, 23.86847305], [68.29736328, 23.86819458], [68.29763794, 23.86819458], [68.29763794, 23.86791611], [68.29818726, 23.86791992], [68.29818726, 23.86763954], [68.29875183, 23.86763954], [68.29875183, 23.86736107], [68.29930878, 23.86736107], [68.29930878, 23.86708069], [68.29985809, 23.8670826], [68.29985809, 23.86680794], [68.30042267, 23.86680984], [68.30042267, 23.86652946], [68.30097198, 23.86652946], [68.30097198, 23.86625099], [68.30152893, 23.86625099], [68.30152893, 23.86597061], [68.30208588, 23.86597252], [68.30208588, 23.86569595], [68.30513763, 23.86569595], [68.30513763, 23.86597252], [68.30541992, 23.86597061], [68.30541992, 23.86625099], [68.30568695, 23.86625099], [68.30568695, 23.86652946], [68.30596924, 23.86652946], [68.30596924, 23.86680984], [68.30625153, 23.86680794], [68.30625153, 23.8670826], [68.30652618, 23.86708069], [68.30652618, 23.86763954], [68.30680847, 23.86763954], [68.30680847, 23.86819458], [68.30708313, 23.86819458], [68.30708313, 23.86847305], [68.30735779, 23.86847115], [68.30735779, 23.86902809], [68.30764008, 23.86902809], [68.30764008, 23.86958313], [68.30791473, 23.86958313], [68.30791473, 23.8698616], [68.30819702, 23.8698597], [68.30819702, 23.87014008], [68.30847168, 23.87014008], [68.30847168, 23.87125015], [68.30874634, 23.87125015], [68.30874634, 23.87208366], [68.30902863, 23.87208176], [68.30902863, 23.87264061], [68.30930328, 23.8726387], [68.30930328, 23.87319374], [68.3095932, 23.87319183], [68.3095932, 23.87403107], [68.30986023, 23.87403107], [68.30986023, 23.8748703], [68.31014252, 23.87486076], [68.31014252, 23.87569237], [68.31041718, 23.87569046], [68.31041718, 23.87625122], [68.31069183, 23.87625122], [68.31069183, 23.87652969], [68.31097412, 23.87652779], [68.31097412, 23.87708282], [68.31124878, 23.87708092], [68.31124878, 23.87763977], [68.31153107, 23.87763977], [68.31153107, 23.87792969], [68.31180573, 23.87791443], [68.31180573, 23.87819672], [68.31208038, 23.87819672], [68.31208038, 23.87847137], [68.31236267, 23.87846947], [68.31236267, 23.87874985], [68.31346893, 23.87874985], [68.31346893, 23.87903023], [68.31430817, 23.87902832], [68.31430817, 23.87930679], [68.31513977, 23.87930679], [68.31513977, 23.87958336], [68.31680298, 23.87958336], [68.31680298, 23.87930679], [68.31764221, 23.87930107], [68.31764221, 23.88042068], [68.31735992, 23.88042068], [68.31735992, 23.88069916], [68.31708527, 23.88069534], [68.3170929, 23.88125038], [68.31680298, 23.88125038], [68.31680298, 23.88153076], [68.31513977, 23.88153076], [68.31513977, 23.88125038], [68.31430817, 23.88125038], [68.31430817, 23.88096809], [68.31346893, 23.88097191], [68.31346893, 23.88069534], [68.31263733, 23.88069916], [68.31263733, 23.88042068], [68.31208038, 23.88042068], [68.31208038, 23.8801403], [68.31153107, 23.8801403], [68.31153107, 23.87985992], [68.31097412, 23.87986183], [68.31097412, 23.87958336], [68.31041718, 23.87958336], [68.31041718, 23.87930679], [68.31014252, 23.87930679], [68.31014252, 23.87902832], [68.3095932, 23.87903023], [68.3095932, 23.87874985], [68.30930328, 23.87874985], [68.30930328, 23.87846947], [68.30902863, 23.87847137], [68.30902863, 23.87819672], [68.30874634, 23.87819672], [68.30874634, 23.87763977], [68.30847168, 23.87763977], [68.30847168, 23.87708092], [68.30819702, 23.87708282], [68.30819702, 23.87680435], [68.3079071, 23.87681007], [68.3079071, 23.87625122], [68.30767059, 23.87625122], [68.30766296, 23.87612724], [68.30764008, 23.87569237], [68.30747986, 23.87569237], [68.30735779, 23.87569237], [68.30735779, 23.8754158], [68.30706787, 23.87541962], [68.3070755, 23.87462044], [68.30708313, 23.87430573], [68.30696106, 23.87430573], [68.30680847, 23.87430954], [68.30680847, 23.87375069], [68.30652618, 23.87375069], [68.30652618, 23.87264061], [68.30625153, 23.87264061], [68.30625153, 23.87125015], [68.30596924, 23.87125015], [68.30596924, 23.87070274], [68.30568695, 23.87070274], [68.30568695, 23.8698597], [68.30541992, 23.8698616], [68.30541992, 23.86847305], [68.30513763, 23.86847305], [68.30513763, 23.86819458], [68.30486298, 23.86819458], [68.30486298, 23.86763954], [68.30430603, 23.86763954], [68.30430603, 23.86736107], [68.30374908, 23.86736107], [68.30374908, 23.86708069], [68.30236053, 23.86708069], [68.30236053, 23.86736107], [68.30179596, 23.86736107], [68.30180359, 23.86763954], [68.30124664, 23.86763954], [68.30124664, 23.86819458], [68.29985809, 23.86819458], [68.29985809, 23.86847305], [68.29930878, 23.86847305], [68.29930878, 23.86874962], [68.29902649, 23.86874008], [68.29902649, 23.86902809], [68.29875183, 23.86902809], [68.29875183, 23.86930466], [68.29846954, 23.86930466], [68.29846954, 23.8698616], [68.29818726, 23.8698597], [68.29818726, 23.87014008], [68.29792023, 23.87014008], [68.29792023, 23.87042236], [68.29763794, 23.87041664], [68.29763794, 23.87097168], [68.29736328, 23.87097168], [68.29736328, 23.87125015], [68.29708099, 23.87125015], [68.29708099, 23.87153053], [68.29680634, 23.87152863], [68.29680634, 23.87180519], [68.29652405, 23.87180519], [68.29652405, 23.87208366], [68.29624939, 23.87208176], [68.29624939, 23.87264061], [68.2959671, 23.87264061], [68.2959671, 23.8729229], [68.29569244, 23.87291718], [68.29569244, 23.87319374], [68.29541779, 23.87319374], [68.29541779, 23.87347221], [68.29512787, 23.87347031], [68.29512787, 23.87375069], [68.29486084, 23.87375069], [68.29486084, 23.87403107], [68.29458618, 23.87403107], [68.29458618, 23.87430954], [68.29430389, 23.87430573], [68.29430389, 23.87458229], [68.29374695, 23.87458038], [68.29374695, 23.8748703], [68.29319763, 23.8748703], [68.29319763, 23.87514114], [68.29180908, 23.87514114], [68.29180908, 23.8748703], [68.29096985, 23.8748703], [68.29096985, 23.87458038], [68.29070282, 23.87458038], [68.29070282, 23.8748703], [68.28985596, 23.8748703], [68.28985596, 23.87458038], [68.28874969, 23.87458229], [68.28874969, 23.87430573], [68.28819275, 23.87430954], [68.28819275, 23.87403107], [68.2876358, 23.87403107], [68.2876358, 23.87375069], [68.28679657, 23.87375069], [68.28679657, 23.87347031], [68.28624725, 23.87347221], [68.28624725, 23.87319374], [68.2859726, 23.87319374], [68.2859726, 23.87291718], [68.28569794, 23.8729229], [68.28569794, 23.87264061], [68.28514099, 23.87264061], [68.28514099, 23.87236023], [68.28457642, 23.87236023], [68.28457642, 23.87208176], [68.28430939, 23.87208366], [68.28430176, 23.87180519], [68.28375244, 23.87180519], [68.28375244, 23.87125015], [68.28318787, 23.87125015], [68.28318787, 23.87097168], [68.28263855, 23.87097168], [68.28263855, 23.87069511], [68.28235626, 23.87070274], [68.28235626, 23.87042236], [68.28180695, 23.87042236], [68.28180695, 23.87014008], [68.27874756, 23.87014008], [68.27874756, 23.87042236], [68.27791595, 23.87042236], [68.27791595, 23.87070274], [68.27708435, 23.87069511], [68.27708435, 23.87097168], [68.2765274, 23.87097168], [68.2765274, 23.87125015], [68.2756958, 23.87125015], [68.2756958, 23.87153053], [68.27541351, 23.87152863], [68.27541351, 23.87180519], [68.27402496, 23.87180519], [68.27402496, 23.87208366], [68.2729187, 23.87208176], [68.2729187, 23.87236023], [68.27179718, 23.87236023], [68.27179718, 23.87264061], [68.27153015, 23.87264061], [68.27153015, 23.8729229], [68.27097321, 23.87291718], [68.27097321, 23.87319374], [68.27041626, 23.87319374], [68.27041626, 23.87347221], [68.26985931, 23.87347031], [68.26985931, 23.87375069], [68.26930237, 23.87375069], [68.26930237, 23.87403107], [68.26847076, 23.87403107], [68.26847076, 23.87430954], [68.26791382, 23.87430573], [68.26791382, 23.87458229], [68.26735687, 23.87458038], [68.26735687, 23.8748703], [68.2664032, 23.87486839], [68.26625061, 23.8748703], [68.26625061, 23.87514114], [68.26541901, 23.87514114], [68.26541901, 23.87541962], [68.26430511, 23.8754158], [68.26430511, 23.87569237], [68.26097107, 23.87569237], [68.26097107, 23.8754158], [68.26040649, 23.87541962], [68.26040649, 23.87514114], [68.25901794, 23.87514114], [68.25901794, 23.87541962], [68.25875092, 23.8754158], [68.25875092, 23.87569237], [68.25846863, 23.87569237], [68.25846863, 23.87847137], [68.25818634, 23.87846947], [68.25818634, 23.87903023], [68.25846863, 23.87903023], [68.25846863, 23.88042068], [68.25875092, 23.88041878], [68.25875092, 23.88097191], [68.25901794, 23.88096809], [68.25901794, 23.88153076], [68.25930786, 23.88153076], [68.25930786, 23.88236046], [68.25958252, 23.88236046], [68.25958252, 23.88291931], [68.25986481, 23.8829174], [68.25986481, 23.88347244], [68.26013947, 23.88347244], [68.26013947, 23.88375092], [68.26040649, 23.88373947], [68.26040649, 23.88402939], [68.26069641, 23.88402748], [68.26069641, 23.88458252], [68.26097107, 23.88458061], [68.26097107, 23.88513947], [68.26125336, 23.88513947], [68.26125336, 23.88652992], [68.26152802, 23.88652992], [68.26152802, 23.8868103], [68.26180267, 23.88680649], [68.26180267, 23.88708115], [68.26208496, 23.88708115], [68.26208496, 23.88736153], [68.26319122, 23.88735962], [68.26319122, 23.88764], [68.26346588, 23.88764], [68.26346588, 23.88792038], [68.26374817, 23.88792038], [68.26374817, 23.88820076], [68.26430511, 23.88819313], [68.26430511, 23.8884716], [68.26457977, 23.8884697], [68.26457977, 23.88875008], [68.26486206, 23.88875008], [68.26486206, 23.88903046], [68.26515198, 23.88903046], [68.26515198, 23.88931084], [68.26541901, 23.88930321], [68.26541901, 23.88958359], [68.26568604, 23.88957977], [68.26568604, 23.88986969], [68.26597595, 23.88986969], [68.26597595, 23.89014053], [68.26625061, 23.89013863], [68.26625061, 23.89069366], [68.26652527, 23.89069366], [68.26652527, 23.89097214], [68.26680756, 23.89097023], [68.26680756, 23.89125061], [68.26708221, 23.89125061], [68.26708221, 23.89153099], [68.26789856, 23.89153099], [68.26789856, 23.89180946], [68.26847076, 23.89180756], [68.26847076, 23.89208412], [68.26930237, 23.89208031], [68.26930237, 23.89236069], [68.26985931, 23.89236069], [68.26985931, 23.89264107], [68.27069092, 23.89263916], [68.27069092, 23.89291763], [68.2701416, 23.89291], [68.2701416, 23.89430809], [68.27041626, 23.89430809], [68.27041626, 23.89486122], [68.27124786, 23.89486122], [68.27124786, 23.89513969], [68.27179718, 23.89513969], [68.27179718, 23.89541817], [68.2720871, 23.89541626], [68.2720871, 23.89569473], [68.27236176, 23.89569473], [68.27236176, 23.8959713], [68.27263641, 23.89596748], [68.27263641, 23.89624977], [68.2729187, 23.89624977], [68.2729187, 23.89652824], [68.27319336, 23.89652824], [68.27319336, 23.89680481], [68.27347565, 23.89680481], [68.27347565, 23.89708328], [68.27402496, 23.89708328], [68.27402496, 23.89736176], [68.27430725, 23.89736176], [68.27430725, 23.89764023], [68.27458191, 23.89764023], [68.27458191, 23.89792252], [68.27485657, 23.89792252], [68.27485657, 23.8982029], [68.27513885, 23.89819527], [68.27513885, 23.89847183], [68.27540588, 23.89847183], [68.27540588, 23.89931107], [68.2756958, 23.89931107], [68.2756958, 23.89986038], [68.27597046, 23.89986038], [68.27597046, 23.90042114], [68.27625275, 23.90041733], [68.27625275, 23.90097237], [68.2765274, 23.90097046], [68.2765274, 23.90153122], [68.27680206, 23.90153122], [68.27680206, 23.90180969], [68.27735901, 23.90180588], [68.27735901, 23.90208244], [68.27819061, 23.90208054], [68.27819824, 23.90236092], [68.2784729, 23.90236092], [68.2784729, 23.90402985], [68.27819824, 23.90402794], [68.27819061, 23.90458298], [68.27791595, 23.90458298], [68.27791595, 23.90486145], [68.2776413, 23.90485001], [68.2776413, 23.9054203], [68.27735901, 23.90541458], [68.27735901, 23.90791893], [68.2776413, 23.90790939], [68.2776413, 23.91013908], [68.27791595, 23.91013908], [68.27791595, 23.91124916], [68.27819061, 23.91124916], [68.27819824, 23.91236115], [68.2784729, 23.91236115], [68.2784729, 23.91292191], [68.27819824, 23.91291618], [68.27819061, 23.91319466], [68.27791595, 23.91319466], [68.27791595, 23.91347122], [68.2776413, 23.91347122], [68.2776413, 23.91374969], [68.27735901, 23.91374969], [68.27735901, 23.91403961], [68.27708435, 23.91402817], [68.27708435, 23.91486168], [68.2776413, 23.91485977], [68.2776413, 23.91514015], [68.27791595, 23.91514015], [68.27791595, 23.91542053], [68.2784729, 23.91542053], [68.2784729, 23.91570091], [68.27874756, 23.91569328], [68.27874756, 23.91597176], [68.27902985, 23.91596985], [68.27902985, 23.91625023], [68.27929688, 23.91625023], [68.27929688, 23.91653061], [68.27958679, 23.91653061], [68.27958679, 23.91681099], [68.27986145, 23.91680336], [68.27986145, 23.91708565], [68.28013611, 23.91708565], [68.28013611, 23.91736031], [68.2804184, 23.91736031], [68.2804184, 23.91764069], [68.28069305, 23.91763878], [68.28069305, 23.91819382], [68.28097534, 23.91819382], [68.28097534, 23.91847229], [68.28125, 23.91847038], [68.28125, 23.91875076], [68.28151703, 23.91875076], [68.28151703, 23.91903114], [68.28180695, 23.91903114], [68.28180695, 23.91930962], [68.28236389, 23.91930771], [68.28236389, 23.91958427], [68.28263855, 23.91958427], [68.28263855, 23.91986084], [68.28318787, 23.9198494], [68.28318787, 23.92014122], [68.28347015, 23.92014122], [68.28347015, 23.92041969], [68.28430176, 23.92041779], [68.28430176, 23.92069435], [68.28514099, 23.92069435], [68.28514099, 23.92097282], [68.28652954, 23.92097092], [68.28652954, 23.92124939], [68.2876358, 23.92124939], [68.2876358, 23.92152977], [68.28903198, 23.92152977], [68.28903198, 23.92180824], [68.29209137, 23.92180824], [68.29209137, 23.92152977], [68.29374695, 23.92152977], [68.29374695, 23.92124939], [68.29541779, 23.92124939], [68.29541779, 23.92097092], [68.29708099, 23.92097282], [68.29708099, 23.92069435], [68.29819489, 23.92069435], [68.29819489, 23.92041779], [68.29930878, 23.92041969], [68.29930878, 23.92014122], [68.30042267, 23.92014122], [68.30042267, 23.9198494], [68.30132294, 23.91985512], [68.30180359, 23.91986084], [68.30180359, 23.91958427], [68.30291748, 23.91958427], [68.30291748, 23.91930771], [68.30403137, 23.91930962], [68.30403137, 23.91903114], [68.30513763, 23.91903114], [68.30513763, 23.91875076], [68.30625153, 23.91875076], [68.30625153, 23.91847038], [68.30735779, 23.91847229], [68.30735779, 23.91819382], [68.30847168, 23.91819382], [68.30847168, 23.91791534], [68.3095932, 23.91792107], [68.3095932, 23.91764069], [68.31096649, 23.91764069], [68.31096649, 23.91736031], [68.31430817, 23.91736031], [68.31430817, 23.91707993], [68.31485748, 23.91708565], [68.31485748, 23.91680336], [68.3154068, 23.91681099], [68.3154068, 23.91653061], [68.31597137, 23.91653061], [68.31597137, 23.91625023], [68.31652832, 23.91625023], [68.31652832, 23.91596985], [68.31708527, 23.91597176], [68.31708527, 23.91569328], [68.317276, 23.9156971], [68.31791687, 23.91570091], [68.31791687, 23.91542053], [68.31874847, 23.91542053], [68.31874847, 23.91514015], [68.31958008, 23.91514015], [68.31958008, 23.91485977], [68.32152557, 23.91486168], [68.32152557, 23.91458321], [68.32485962, 23.91458321], [68.32485962, 23.91430473], [68.32624817, 23.91430473], [68.32624817, 23.91458321], [68.32736206, 23.91458321], [68.32736206, 23.91486168], [68.32820129, 23.91485977], [68.32820129, 23.91514015], [68.3290329, 23.91514015], [68.3290329, 23.91542053], [68.32958221, 23.91542053], [68.32958221, 23.91570091], [68.33041382, 23.91569328], [68.33041382, 23.91597176], [68.33097076, 23.91596985], [68.33097076, 23.91625023], [68.33180237, 23.91625023], [68.33180237, 23.91653061], [68.33235931, 23.91653061], [68.33235931, 23.91681099], [68.33291626, 23.91680336], [68.33291626, 23.91708565], [68.33347321, 23.91707993], [68.33347321, 23.91736031], [68.33403015, 23.91736031], [68.33403015, 23.91764069], [68.3345871, 23.91764069], [68.3345871, 23.91792107], [68.33486176, 23.91791534], [68.33486176, 23.91819382], [68.3354187, 23.91819382], [68.3354187, 23.91847229], [68.33569336, 23.91847038], [68.33569336, 23.91875076], [68.33598328, 23.91875076], [68.33598328, 23.91903114], [68.33625031, 23.91903114], [68.33625031, 23.91930962], [68.33680725, 23.91930771], [68.33680725, 23.91958427], [68.33708191, 23.91958427], [68.33708191, 23.91986084], [68.33737183, 23.9198494], [68.33737183, 23.92014122], [68.33763885, 23.92014122], [68.33763885, 23.92041969], [68.3381958, 23.92041779], [68.3381958, 23.92069435], [68.33847046, 23.92069435], [68.33847046, 23.92097282], [68.33875275, 23.92097092], [68.33875275, 23.92124939], [68.3390274, 23.92124939], [68.3390274, 23.92152977], [68.33930206, 23.92152977], [68.33930206, 23.92180824], [68.33958435, 23.92180634], [68.33958435, 23.9220829], [68.33985901, 23.92207909], [68.33985901, 23.9240303], [68.3409729, 23.9240303], [68.3409729, 23.92431259], [68.3418045, 23.92430496], [68.3418045, 23.92458344], [68.34236145, 23.92458153], [68.34236145, 23.92625046], [68.34263611, 23.92625046], [68.34263611, 23.92764091], [68.34236145, 23.92763901], [68.34236145, 23.92847252], [68.34263611, 23.92847061], [68.34263611, 23.92875099], [68.3431778, 23.92875099], [68.3431778, 23.92904091], [68.3434906, 23.92904091], [68.3434906, 23.92930984], [68.34375, 23.92930412], [68.34375, 23.9295826], [68.34401703, 23.92958069], [68.34401703, 23.92986107], [68.3445816, 23.92986107], [68.3445816, 23.93013954], [68.34485626, 23.93013954], [68.34485626, 23.93041992], [68.34513855, 23.93041992], [68.34513855, 23.93124962], [68.34541321, 23.93124962], [68.34541321, 23.93208313], [68.34570313, 23.93208122], [68.34570313, 23.93264008], [68.34597015, 23.93264008], [68.34597015, 23.93320084], [68.34570313, 23.93320084], [68.34570313, 23.93514061], [68.34597015, 23.93514061], [68.34597015, 23.93625069], [68.34623718, 23.93625069], [68.34623718, 23.93736076], [68.3465271, 23.93736076], [68.3465271, 23.94292068], [68.34625244, 23.94291687], [68.34625244, 23.9445858], [68.34597015, 23.94458008], [68.34597015, 23.94791985], [68.34625244, 23.94791794], [68.34625244, 23.94958305], [68.34597015, 23.94957924], [68.34597015, 23.95070267], [68.34570313, 23.95070267], [68.34570313, 23.95181274], [68.34541321, 23.95181274], [68.34541321, 23.95292282], [68.34513855, 23.9529171], [68.34513855, 23.95347214], [68.34485626, 23.95347023], [68.34485626, 23.95430946], [68.34513855, 23.95430565], [68.34513855, 23.95569229], [68.34541321, 23.95569229], [68.34541321, 23.95708275], [68.3456955, 23.95708275], [68.3456955, 23.95819664], [68.34597015, 23.95819664], [68.34597015, 23.95930672], [68.34623718, 23.95930099], [68.34623718, 23.96042061], [68.3465271, 23.9604187], [68.3465271, 23.96097183], [68.34680176, 23.96096992], [68.34680176, 23.96153069], [68.34707642, 23.96153069], [68.34707642, 23.96180916], [68.3473587, 23.96180916], [68.3473587, 23.96236038], [68.34764099, 23.96236038], [68.34764099, 23.96291924], [68.34791565, 23.96291733], [68.34791565, 23.96319389], [68.34819794, 23.96318817], [68.34819794, 23.96375084], [68.3484726, 23.96375084], [68.3484726, 23.96402931], [68.34874725, 23.96402931], [68.34874725, 23.9643116], [68.34902954, 23.9643116], [68.34902954, 23.96486092], [68.34931183, 23.96486092], [68.34931183, 23.96515274], [68.34958649, 23.96515274], [68.34958649, 23.96541977], [68.34986115, 23.96541595], [68.34986115, 23.9659729], [68.3501358, 23.9659729], [68.3501358, 23.96624947], [68.35041809, 23.96624947], [68.35041809, 23.96652985], [68.35069275, 23.96652985], [68.35069275, 23.96681023], [68.35097504, 23.96680641], [68.35097504, 23.96736145], [68.35124969, 23.96735954], [68.35124969, 23.9679203], [68.35152435, 23.96791649], [68.35152435, 23.96819305], [68.35180664, 23.96819305], [68.35180664, 23.96847153], [68.35236359, 23.96847153], [68.35236359, 23.96875], [68.35263824, 23.96875], [68.35263824, 23.96903038], [68.3529129, 23.96903038], [68.3529129, 23.96931076], [68.35319519, 23.96930313], [68.35319519, 23.96958351], [68.35346985, 23.96958351], [68.35346985, 23.96986198], [68.35375214, 23.96986008], [68.35375214, 23.97014046], [68.35402679, 23.97014046], [68.35402679, 23.97042084], [68.35430908, 23.97041512], [68.35430908, 23.97069359], [68.35514069, 23.97069359], [68.35514069, 23.97097206], [68.35569763, 23.97096062], [68.35569763, 23.97125053], [68.35679626, 23.97125053], [68.35679626, 23.97153091], [68.35708618, 23.97153091], [68.35708618, 23.97180939], [68.35736084, 23.97180939], [68.35736084, 23.97236061], [68.3576355, 23.97236061], [68.3576355, 23.97258186], [68.3576355, 23.97319412], [68.35791779, 23.97319031], [68.35791779, 23.97375107], [68.35819244, 23.97374725], [68.35819244, 23.97458267], [68.3584671, 23.97458076], [68.3584671, 23.97541809], [68.35874939, 23.97541618], [68.35874939, 23.97597313], [68.35901642, 23.97597122], [68.35901642, 23.97652817], [68.35930634, 23.97652817], [68.35930634, 23.97680473], [68.35958099, 23.97680473], [68.35958099, 23.97736168], [68.35986328, 23.97736168], [68.35986328, 23.97764015], [68.36042023, 23.97764015], [68.36042023, 23.97792244], [68.36068726, 23.97792244], [68.36068726, 23.97820282], [68.36125183, 23.97819519], [68.36125183, 23.97847176], [68.36180878, 23.97847176], [68.36180878, 23.97875023], [68.36235809, 23.97875023], [68.36235809, 23.97903061], [68.36264038, 23.97903061], [68.36264038, 23.9793129], [68.36319733, 23.97930527], [68.36319733, 23.97958374], [68.36374664, 23.97958183], [68.36374664, 23.97986031], [68.36430359, 23.97986031], [68.36430359, 23.98013878], [68.36486053, 23.98013115], [68.36486053, 23.98042107], [68.36541748, 23.98041725], [68.36541748, 23.98069382], [68.36569214, 23.98069382], [68.36569214, 23.98097229], [68.36624908, 23.98097038], [68.36624908, 23.98125076], [68.36680603, 23.98125076], [68.36680603, 23.98153114], [68.36763763, 23.98153114], [68.36763763, 23.98180962], [68.36819458, 23.9818058], [68.36819458, 23.98208237], [68.36902618, 23.98208046], [68.36902618, 23.98236084], [68.36958313, 23.98236084], [68.36958313, 23.98264122], [68.3704071, 23.98264122], [68.3704071, 23.98291969], [68.37124634, 23.98291588], [68.37124634, 23.98319435], [68.37208557, 23.98319435], [68.37208557, 23.98347282], [68.37264252, 23.98347092], [68.37264252, 23.98374939], [68.37346649, 23.98374939], [68.37346649, 23.98402977], [68.37431335, 23.98402977], [68.37431335, 23.98431015], [68.37513733, 23.98430443], [68.37513733, 23.9845829], [68.37541962, 23.9845829], [68.37541962, 23.98430443], [68.37625122, 23.98431015], [68.37625122, 23.98402977], [68.37654114, 23.98402977], [68.37654114, 23.98374939], [68.37680817, 23.98374939], [68.37680817, 23.98347092], [68.37708282, 23.98347282], [68.37708282, 23.98319435], [68.37735748, 23.98319435], [68.37735748, 23.98291588], [68.37763977, 23.98291969], [68.37763977, 23.98264122], [68.3779068, 23.98264122], [68.3779068, 23.98208046], [68.37819672, 23.98208237], [68.37819672, 23.9818058], [68.37847137, 23.98180962], [68.37847137, 23.98153114], [68.37874603, 23.98153114], [68.37874603, 23.98097038], [68.37902832, 23.98097229], [68.37902832, 23.97986031], [68.37928772, 23.97986031], [68.37928772, 23.97875023], [68.37960052, 23.97875023], [68.37958527, 23.97763824], [68.37985992, 23.97764015], [68.37985992, 23.97652817], [68.38014221, 23.97652817], [68.38014221, 23.97513962], [68.38041687, 23.97513962], [68.38041687, 23.97347069], [68.38069153, 23.9734726], [68.38069153, 23.97208595], [68.38097382, 23.97208595], [68.38097382, 23.97180748], [68.38124847, 23.97180939], [68.38124847, 23.97125053], [68.38153076, 23.97125053], [68.38153076, 23.97096062], [68.38180542, 23.97097206], [68.38180542, 23.97041512], [68.38208008, 23.97042084], [68.38208008, 23.9695797], [68.38236237, 23.96958351], [68.38236237, 23.96902847], [68.38263702, 23.96903038], [68.38263702, 23.96875], [68.38291931, 23.96875], [68.38291931, 23.96846962], [68.38319397, 23.96847153], [68.38319397, 23.96819305], [68.38346863, 23.96819305], [68.38346863, 23.96791649], [68.3840332, 23.9679203], [68.3840332, 23.96763992], [68.38430786, 23.96763992], [68.38430786, 23.96735954], [68.38486481, 23.96736145], [68.38486481, 23.96680641], [68.38513947, 23.96681023], [68.38513947, 23.96624947], [68.38540649, 23.96624947], [68.38540649, 23.9659729], [68.38597107, 23.9659729], [68.38597107, 23.96569443], [68.38625336, 23.96569443], [68.38625336, 23.96541595], [68.38680267, 23.96541977], [68.38680267, 23.96515274], [68.38735962, 23.96515274], [68.38735962, 23.96486092], [68.38903046, 23.96486092], [68.38903046, 23.96457863], [68.39208221, 23.96457863], [68.39208221, 23.96486092], [68.39375305, 23.96486092], [68.39375305, 23.96515274], [68.39485931, 23.96515274], [68.39485931, 23.96541977], [68.39597321, 23.96541595], [68.39597321, 23.96569443], [68.39653015, 23.96569443], [68.39653015, 23.9659729], [68.39679718, 23.9659729], [68.39679718, 23.96624947], [68.3973465, 23.96624947], [68.3973465, 23.96652985], [68.3979187, 23.96652985], [68.3979187, 23.96681023], [68.39819336, 23.96680641], [68.39819336, 23.96708107], [68.39902496, 23.96708107], [68.39902496, 23.96736145], [68.39930725, 23.96735954], [68.39930725, 23.96763992], [68.39985657, 23.96763992], [68.39985657, 23.9679203], [68.40013885, 23.96791649], [68.40013885, 23.96819305], [68.40041351, 23.96819305], [68.40041351, 23.96847153], [68.4006958, 23.96847153], [68.4006958, 23.96875], [68.40125275, 23.96875], [68.40125275, 23.96903038], [68.4015274, 23.96903038], [68.4015274, 23.96931076], [68.40180206, 23.96930313], [68.40180206, 23.96958351], [68.40207672, 23.9695797], [68.40207672, 23.97014046], [68.40235901, 23.97014046], [68.40235901, 23.97042084], [68.4026413, 23.97041512], [68.4026413, 23.97069359], [68.40291595, 23.97069359], [68.40291595, 23.97097206], [68.40319061, 23.97096062], [68.40319824, 23.97125053], [68.40374756, 23.97125053], [68.40374756, 23.97153091], [68.40402985, 23.97153091], [68.40402985, 23.97180939], [68.4043045, 23.97180748], [68.4043045, 23.97208595], [68.40458679, 23.97208023], [68.40458679, 23.97236061], [68.40486145, 23.97236061], [68.40486145, 23.97291946], [68.40513611, 23.97291756], [68.40513611, 23.97319412], [68.4054184, 23.97319412], [68.4054184, 23.9734726], [68.40569305, 23.97347069], [68.40569305, 23.97402954], [68.40598297, 23.97402954], [68.40598297, 23.97431946], [68.40625, 23.97431946], [68.40625, 23.97486115], [68.40651703, 23.97486115], [68.40651703, 23.97513962], [68.40680695, 23.97513962], [68.40680695, 23.97569466], [68.4070816, 23.97569466], [68.4070816, 23.97597313], [68.40735626, 23.97597122], [68.40735626, 23.97624969], [68.40763855, 23.97624969], [68.40763855, 23.97652817], [68.4081955, 23.97652817], [68.4081955, 23.97680473], [68.40847015, 23.97680092], [68.40847015, 23.97709274], [68.40875244, 23.97708321], [68.40875244, 23.97736168], [68.4092865, 23.97736168], [68.4092865, 23.97764015], [68.4098587, 23.97764015], [68.4098587, 23.97792244], [68.41042328, 23.97792244], [68.41042328, 23.97820282], [68.41069794, 23.97819519], [68.41069794, 23.97847176], [68.4109726, 23.97847176], [68.4109726, 23.97875023], [68.41124725, 23.97875023], [68.41124725, 23.9793129], [68.41152954, 23.97930527], [68.41152954, 23.97958374], [68.41179657, 23.97958183], [68.41179657, 23.97986031], [68.41208649, 23.97986031], [68.41208649, 23.98013878], [68.41236115, 23.98013115], [68.41236115, 23.98042107], [68.4126358, 23.98041725], [68.4126358, 23.98069382], [68.41291809, 23.98069382], [68.41291809, 23.98097229], [68.41319275, 23.98097038], [68.41319275, 23.98125076], [68.41348267, 23.98125076], [68.41348267, 23.98153114], [68.41374969, 23.98152733], [68.41374969, 23.98208237], [68.41401672, 23.98208046], [68.41401672, 23.98236084], [68.41430664, 23.98236084], [68.41430664, 23.98264122], [68.4145813, 23.98264122], [68.4145813, 23.98291969], [68.41486359, 23.98291588], [68.41486359, 23.98319435], [68.41513824, 23.98319435], [68.41513824, 23.98347282], [68.41542053, 23.98347092], [68.41542053, 23.98402977], [68.41569519, 23.98402786], [68.41569519, 23.9845829], [68.41596985, 23.9845829], [68.41596985, 23.98486137], [68.41625214, 23.98485947], [68.41625214, 23.98542023], [68.41652679, 23.98541451], [68.41652679, 23.98597145], [68.41680908, 23.98596954], [68.41680908, 23.98625946], [68.41707611, 23.98625946], [68.41707611, 23.98681068], [68.4173584, 23.98680687], [68.4173584, 23.98708344], [68.41764069, 23.98708344], [68.41764069, 23.98736191], [68.41792297, 23.98735809], [68.41792297, 23.98792076], [68.41819763, 23.98791885], [68.41819763, 23.9881897], [68.41845703, 23.98819923], [68.41845703, 23.98875046], [68.41874695, 23.98875046], [68.41874695, 23.98903084], [68.41902924, 23.98902893], [68.41902924, 23.98958397], [68.41929626, 23.98957825], [68.41929626, 23.98986053], [68.41958618, 23.98986053], [68.41958618, 23.99014091], [68.41986084, 23.99014091], [68.41986084, 23.99069405], [68.4201355, 23.99069405], [68.4201355, 23.99097252], [68.42041779, 23.99097061], [68.42041779, 23.99124908], [68.42069244, 23.99124908], [68.42069244, 23.99152946], [68.4209671, 23.99152946], [68.4209671, 23.99181175], [68.42152405, 23.99180603], [68.42152405, 23.9920826], [68.42180634, 23.99206924], [68.42180634, 23.99236107], [68.42208099, 23.99236107], [68.42208099, 23.99263954], [68.42236328, 23.99263954], [68.42236328, 23.99291992], [68.42292023, 23.99291611], [68.42292023, 23.99319458], [68.42346954, 23.99319458], [68.42346954, 23.99347115], [68.42375183, 23.99347115], [68.42375183, 23.99374962], [68.42430878, 23.99374962], [68.42430878, 23.99403], [68.42485809, 23.99402809], [68.42485809, 23.99430466], [68.42569733, 23.99430466], [68.42569733, 23.99458313], [68.42624664, 23.99458313], [68.42624664, 23.9948616], [68.42708588, 23.9948616], [68.42708588, 23.99513817], [68.4284668, 23.99513054], [68.4284668, 23.99542046], [68.43013763, 23.99542046], [68.43013763, 23.99513054], [68.43041992, 23.99513817], [68.43041992, 23.9948616], [68.43069458, 23.9948616], [68.43069458, 23.99458313], [68.43096924, 23.99458313], [68.43096924, 23.99430466], [68.43125153, 23.99430466], [68.43125153, 23.99402809], [68.43152618, 23.99403], [68.43152618, 23.99374962], [68.43180847, 23.99374962], [68.43180847, 23.99347115], [68.43208313, 23.99347115], [68.43208313, 23.99319458], [68.43235779, 23.99319458], [68.43235779, 23.99263954], [68.43264008, 23.99263954], [68.43264008, 23.99236107], [68.4329071, 23.99236107], [68.4329071, 23.99206924], [68.43319702, 23.9920826], [68.43319702, 23.99180603], [68.43345642, 23.99181175], [68.43345642, 23.99152946], [68.43374634, 23.99152946], [68.43374634, 23.99124908], [68.43402863, 23.99124908], [68.43402863, 23.99097061], [68.43430328, 23.99097252], [68.43430328, 23.99041748], [68.4345932, 23.99041939], [68.4345932, 23.99014091], [68.43486023, 23.99014091], [68.43486023, 23.98986053], [68.43514252, 23.98986053], [68.43514252, 23.98932266], [68.43541718, 23.98932266], [68.43541718, 23.98903084], [68.43569183, 23.98903084], [68.43569183, 23.98875046], [68.43596649, 23.98875046], [68.43596649, 23.98819923], [68.43624878, 23.9881897], [68.43624878, 23.98791885], [68.43653107, 23.98792076], [68.43653107, 23.98764038], [68.43682098, 23.98764038], [68.43682098, 23.9865303], [68.43653107, 23.9865303], [68.43653107, 23.98513985], [68.43624878, 23.98513985], [68.43624878, 23.98402977], [68.43596649, 23.98402977], [68.43596649, 23.98319054], [68.43569183, 23.98319435], [68.43569183, 23.98208237], [68.43541718, 23.98208237], [68.43541718, 23.98097229], [68.43514252, 23.98097229], [68.43514252, 23.97958374], [68.43486023, 23.97958374], [68.43486023, 23.97791672], [68.4345932, 23.97792244], [68.4345932, 23.97680092], [68.43430328, 23.97680473], [68.43430328, 23.96819305], [68.43402863, 23.96819305], [68.43402863, 23.9659729], [68.43374634, 23.9659729], [68.43374634, 23.9640274], [68.43345642, 23.96402931], [68.43345642, 23.96388435], [68.43347168, 23.96319389], [68.43319702, 23.96319389], [68.43319702, 23.96236038], [68.4329071, 23.96236038], [68.4329071, 23.96153069], [68.43264008, 23.96153069], [68.43264008, 23.96096992], [68.43235779, 23.96097183], [68.43235779, 23.96013641], [68.43264008, 23.96014023], [68.43264008, 23.95985985], [68.43208313, 23.95986176], [68.43208313, 23.95958328], [68.43125153, 23.95958328], [68.43125153, 23.95930672], [68.43096924, 23.95930672], [68.43096924, 23.95902634], [68.43069458, 23.95902634], [68.43069458, 23.9584713], [68.43041992, 23.9584713], [68.43041992, 23.95819664], [68.43013763, 23.95819664], [68.43013763, 23.95791435], [68.42986298, 23.95792007], [68.42986298, 23.95763969], [68.42958069, 23.95763969], [68.42958069, 23.95708084], [68.42930603, 23.95708275], [68.42930603, 23.95680428], [68.42903137, 23.95681], [68.42903137, 23.95652962], [68.42874908, 23.95652962], [68.42874908, 23.95625114], [68.4284668, 23.95625114], [68.4284668, 23.95596123], [68.42819214, 23.95597267], [68.42819214, 23.95541573], [68.42791748, 23.95541954], [68.42791748, 23.95514107], [68.42765045, 23.95514107], [68.42765045, 23.95486069], [68.42736053, 23.95486069], [68.42736053, 23.95458031], [68.42708588, 23.95458221], [68.42708588, 23.95402718], [68.42679596, 23.9540329], [68.42679596, 23.95375061], [68.42652893, 23.95375061], [68.42652893, 23.95347023], [68.42624664, 23.95347214], [68.42624664, 23.95319366], [68.42597198, 23.95319366], [68.42597198, 23.9529171], [68.42569733, 23.95292282], [68.42569733, 23.95236015], [68.42541504, 23.95236015], [68.42541504, 23.95180511], [68.42514038, 23.95181274], [68.42514038, 23.9509716], [68.42485809, 23.9509716], [68.42485809, 23.95041656], [68.42459106, 23.95042038], [68.42459106, 23.94957924], [68.42430878, 23.94958305], [68.42430878, 23.94902992], [68.42402649, 23.94902992], [68.42402649, 23.94819069], [68.42375183, 23.9481945], [68.42375183, 23.94763947], [68.42346954, 23.94763947], [68.42346954, 23.94688988], [68.42346954, 23.94680786], [68.42318726, 23.94680977], [68.42318726, 23.94597054], [68.42292023, 23.94597244], [68.42292023, 23.9454155], [68.42263794, 23.94542122], [68.42263794, 23.94431114], [68.42236328, 23.94431114], [68.42236328, 23.94320107], [68.42208099, 23.94320107], [68.42208099, 23.94207954], [68.42180634, 23.94208336], [68.42180634, 23.94152832], [68.42151642, 23.94153023], [68.42151642, 23.9406929], [68.42124939, 23.94069481], [68.42124939, 23.94013977], [68.4209671, 23.94013977], [68.4209671, 23.93931007], [68.42069244, 23.93931007], [68.42069244, 23.93875122], [68.42041779, 23.93875122], [68.42041779, 23.93818855], [68.4201355, 23.93819427], [68.4201355, 23.93736076], [68.41986084, 23.93736076], [68.41986084, 23.93680954], [68.41958618, 23.93680954], [68.41958618, 23.9359684], [68.41930389, 23.93597221], [68.41930389, 23.9351387], [68.41902924, 23.93514061], [68.41902924, 23.93457985], [68.41874695, 23.93458366], [68.41874695, 23.93402863], [68.41845703, 23.93403053], [68.41845703, 23.93375015], [68.41819763, 23.93375015], [68.41819763, 23.93346977], [68.41791534, 23.93347168], [68.41791534, 23.93319511], [68.41764069, 23.93320084], [68.41764069, 23.93292046], [68.4173584, 23.93292046], [68.4173584, 23.9323597], [68.41708374, 23.9323616], [68.41708374, 23.93208313], [68.41680908, 23.93208313], [68.41680908, 23.93180466], [68.41652679, 23.93180466], [68.41652679, 23.93152618], [68.41625214, 23.93153], [68.41625214, 23.93124962], [68.41596985, 23.93124962], [68.41596985, 23.93097115], [68.41569519, 23.93097305], [68.41569519, 23.93069649], [68.4154129, 23.93069649], [68.4154129, 23.93013954], [68.41513824, 23.93013954], [68.41513824, 23.92986107], [68.41485596, 23.92986107], [68.41485596, 23.92958069], [68.4145813, 23.9295826], [68.4145813, 23.92930412], [68.41374969, 23.92930984], [68.41374969, 23.92904091], [68.41348267, 23.92904091], [68.41348267, 23.92847061], [68.41319275, 23.92847252], [68.41319275, 23.92791748], [68.41291809, 23.92791939], [68.41291809, 23.92736053], [68.4126358, 23.92736053], [68.4126358, 23.92708206], [68.41236115, 23.92708206], [68.41236115, 23.9268055], [68.41208649, 23.92681122], [68.41208649, 23.92653275], [68.41179657, 23.92653275], [68.41179657, 23.92625046], [68.41152954, 23.92625046], [68.41152954, 23.92597961], [68.4109726, 23.92597961], [68.4109726, 23.9256916], [68.41069794, 23.92569351], [68.41069794, 23.92541695], [68.41014099, 23.92542267], [68.41014099, 23.92514038], [68.4098587, 23.92514038], [68.4098587, 23.92486191], [68.40930939, 23.92486191], [68.40930176, 23.92458344], [68.4090271, 23.92458344], [68.4090271, 23.92430496], [68.40847015, 23.92431259], [68.40847015, 23.9240303], [68.40791321, 23.9240303], [68.40791321, 23.92375183], [68.40735626, 23.92375183], [68.40735626, 23.92347145], [68.40652466, 23.92347145], [68.40652466, 23.92319489], [68.40597534, 23.92319489], [68.40597534, 23.92291641], [68.40402985, 23.92291832], [68.40402985, 23.92207909], [68.40374756, 23.9220829], [68.40374756, 23.92152977], [68.40348053, 23.92152977], [68.40348053, 23.92124939], [68.40291595, 23.92124939], [68.40291595, 23.92097092], [68.4026413, 23.92097282], [68.4026413, 23.92069435], [68.40097046, 23.92069435], [68.40097046, 23.92041779], [68.40013885, 23.92041969], [68.40013885, 23.92014122], [68.39848328, 23.92014122], [68.39848328, 23.9198494], [68.3979187, 23.91986084], [68.3979187, 23.91958427], [68.39763641, 23.91958237], [68.39763641, 23.91930771], [68.3970871, 23.91930962], [68.3970871, 23.91903114], [68.39653015, 23.91903114], [68.39653015, 23.91875076], [68.39624786, 23.91875076], [68.39624786, 23.91847038], [68.39569092, 23.91847229], [68.39569092, 23.91819382], [68.39319611, 23.91819382], [68.39319611, 23.91791534], [68.39263916, 23.91792107], [68.39263916, 23.91764069], [68.39208221, 23.91764069], [68.39208221, 23.91736031], [68.39152527, 23.91736031], [68.39152527, 23.91708565], [68.39097595, 23.91708565], [68.39097595, 23.91680336], [68.39068604, 23.91681099], [68.39068604, 23.91653061], [68.39013672, 23.91653061], [68.39013672, 23.91625023], [68.38986206, 23.91625023], [68.38986206, 23.91596985], [68.38930511, 23.91597176], [68.38930511, 23.91569328], [68.38903046, 23.91570091], [68.38903046, 23.91542053], [68.38848114, 23.91542053], [68.38848114, 23.91514015], [68.38791656, 23.91514015], [68.38791656, 23.91485977], [68.38764191, 23.91486168], [68.38764191, 23.91458321], [68.38708496, 23.91458321], [68.38708496, 23.91430473], [68.38569641, 23.91430473], [68.38569641, 23.91458321], [68.38458252, 23.91458321], [68.38458252, 23.91486168], [68.38375092, 23.91485977], [68.38375092, 23.91514015], [68.37708282, 23.91514015], [68.37708282, 23.91542053], [68.37680817, 23.91542053], [68.37680817, 23.91625023], [68.37654114, 23.91625023], [68.37654114, 23.91653061], [68.37625122, 23.91653061], [68.37625122, 23.91903114], [68.37652588, 23.91902542], [68.37652588, 23.91958427], [68.37708282, 23.91958427], [68.37708282, 23.91930771], [68.37847137, 23.91930771], [68.37847137, 23.91958427], [68.37875366, 23.91958427], [68.37875366, 23.91986084], [68.37847137, 23.9198494], [68.37847137, 23.92014122], [68.37735748, 23.92014122], [68.37735748, 23.92041969], [68.37625122, 23.92041969], [68.37625122, 23.92014122], [68.37596893, 23.92014122], [68.37596893, 23.9198494], [68.37569427, 23.91986084], [68.37569427, 23.91930771], [68.37541962, 23.91930962], [68.37541962, 23.91653061], [68.37568665, 23.91653061], [68.37568665, 23.91596985], [68.37596893, 23.91597176], [68.37596893, 23.91541672], [68.37625122, 23.91542053], [68.37625122, 23.91514015], [68.37654114, 23.91514015], [68.37654114, 23.91485977], [68.37541962, 23.91486168], [68.37541962, 23.91458321], [68.3737793, 23.91458321], [68.37069702, 23.91458321], [68.37069702, 23.91430473], [68.36985779, 23.91430473], [68.36985779, 23.91402817], [68.36902618, 23.91403961], [68.36902618, 23.91374969], [68.36818695, 23.91374969], [68.36818695, 23.91347122], [68.36791992, 23.91347122], [68.36791992, 23.91319466], [68.36680603, 23.91319466], [68.36680603, 23.91347122], [68.3659668, 23.91347122], [68.3659668, 23.91374969], [68.36347198, 23.91374969], [68.36347198, 23.91347122], [68.36264038, 23.91347122], [68.36264038, 23.91319466], [68.36208344, 23.91319466], [68.36208344, 23.91291618], [68.36125183, 23.91292191], [68.36125183, 23.91263962], [68.36042023, 23.91263962], [68.36042023, 23.91236115], [68.35930634, 23.91236115], [68.35930634, 23.91208267], [68.35791779, 23.91208267], [68.35791779, 23.91180611], [68.35736084, 23.91181183], [68.35736084, 23.91152954], [68.35652924, 23.91152954], [68.35652924, 23.91124916], [68.35597229, 23.91124916], [68.35597229, 23.91098022], [68.35540771, 23.91098022], [68.35540771, 23.9106884], [68.3548584, 23.91069412], [68.3548584, 23.91041756], [68.35430908, 23.91041946], [68.35430908, 23.91013908], [68.35375214, 23.91013908], [68.35375214, 23.90986061], [68.35319519, 23.90986061], [68.35319519, 23.90958405], [68.35263824, 23.90958405], [68.35263824, 23.90930557], [68.3520813, 23.90930939], [68.3520813, 23.90903091], [68.35151672, 23.90903091], [68.35151672, 23.90875053], [68.35097504, 23.90875053], [68.35097504, 23.90847206], [68.35041809, 23.90847206], [68.35041809, 23.90819359], [68.3501358, 23.90819359], [68.3501358, 23.90791893], [68.34986115, 23.90791893], [68.34986115, 23.90763855], [68.34958649, 23.90764046], [68.34958649, 23.90735817], [68.3493042, 23.90736198], [68.3493042, 23.90708351], [68.34902954, 23.90708351], [68.34902954, 23.90652847], [68.34874725, 23.90653038], [68.34874725, 23.90625], [68.3484726, 23.90625], [68.3484726, 23.90596962], [68.34819794, 23.90597153], [68.34819794, 23.90569687], [68.34792328, 23.90570068], [68.34792328, 23.9054203], [68.34764099, 23.9054203], [68.34764099, 23.90485001], [68.3473587, 23.90486145], [68.3473587, 23.90458298], [68.34708405, 23.90458298], [68.34708405, 23.9043045], [68.34680939, 23.90431023], [68.34680176, 23.90402985], [68.3465271, 23.90402985], [68.3465271, 23.90347099], [68.34625244, 23.90347481], [68.34625244, 23.90291405], [68.34597015, 23.90291977], [68.34597015, 23.90236092], [68.3456955, 23.90236092], [68.3456955, 23.90208244], [68.34541321, 23.90208244], [68.34541321, 23.9015274], [68.34513855, 23.90153122], [68.34513855, 23.90125084], [68.34485626, 23.90125084], [68.34485626, 23.90014076], [68.3445816, 23.90014076], [68.3445816, 23.89931107], [68.34430695, 23.89931107], [68.34430695, 23.89792252], [68.34401703, 23.89792252], [68.34401703, 23.89652824], [68.34375, 23.89652824], [68.34375, 23.89541817], [68.3434906, 23.89541817], [68.3434906, 23.89402962], [68.3431778, 23.89402962], [68.3431778, 23.89291], [68.3429184, 23.89291763], [68.3429184, 23.89180756], [68.34263611, 23.89180946], [68.34263611, 23.89068985], [68.34236145, 23.89069366], [68.34236145, 23.88986206], [68.34263611, 23.88986969], [68.34263611, 23.88931084], [68.3429184, 23.88931084], [68.3429184, 23.88903046], [68.3431778, 23.88903046], [68.3431778, 23.88875008], [68.3434906, 23.88875008], [68.34347534, 23.88819313], [68.34375, 23.88820076], [68.34375, 23.88792038], [68.34401703, 23.88792038], [68.34401703, 23.88735962], [68.34430695, 23.88736153], [68.34430695, 23.88680649], [68.3445816, 23.8868103], [68.3445816, 23.88624954], [68.34485626, 23.88624954], [68.34485626, 23.8856926], [68.34513855, 23.8856945], [68.34513855, 23.88513947], [68.34541321, 23.88513947], [68.34541321, 23.88458061], [68.3456955, 23.88458252], [68.3456955, 23.88375092], [68.34597015, 23.88375092], [68.34597015, 23.88319397], [68.34625244, 23.88319397], [68.34625244, 23.88264084], [68.3465271, 23.88264084], [68.3465271, 23.88236046], [68.34680176, 23.88236046], [68.34680939, 23.88180923], [68.34707642, 23.88180923], [68.34707642, 23.88096809], [68.3473587, 23.88097191], [68.3473587, 23.87958336], [68.34764099, 23.87958336], [68.34764099, 23.87819672], [68.34791565, 23.87819672], [68.34791565, 23.87708282], [68.34819794, 23.87708282], [68.34819794, 23.87597275], [68.3484726, 23.87597275], [68.3484726, 23.87375069], [68.34819794, 23.87375069], [68.34819794, 23.86763954], [68.3484726, 23.86763954], [68.3484726, 23.86652946], [68.34874725, 23.86652946], [68.34874725, 23.86514091], [68.3484726, 23.86514091], [68.3484726, 23.86375046], [68.34819794, 23.86375046], [68.34819794, 23.86264038], [68.34792328, 23.86264038], [68.34792328, 23.8615303], [68.34764099, 23.8615303], [68.34764099, 23.86042023], [68.3473587, 23.86042023], [68.3473587, 23.85957146], [68.34708405, 23.8595829], [68.34708405, 23.85902786], [68.34680939, 23.85902977], [68.34680176, 23.85819244], [68.3465271, 23.85819435], [68.3465271, 23.85763931], [68.34623718, 23.85763931], [68.34623718, 23.85707855], [68.34597015, 23.85708237], [68.34597015, 23.85625076], [68.3456955, 23.85625076], [68.3456955, 23.85569382], [68.34541321, 23.85569382], [68.34541321, 23.85486031], [68.34513855, 23.85486031], [68.34513855, 23.85430908], [68.34485626, 23.85430908], [68.34485626, 23.85375977], [68.3445816, 23.85375977], [68.3445816, 23.85320091], [68.34430695, 23.85320091], [68.34430695, 23.85264015], [68.34401703, 23.85264015], [68.34401703, 23.85207939], [68.34375, 23.85208321], [68.34375, 23.85152626], [68.3434906, 23.85153008], [68.3434906, 23.85097122], [68.34319305, 23.85097313], [68.34319305, 23.85013962], [68.3429184, 23.85013962], [68.3429184, 23.84958076], [68.34263611, 23.84958267], [68.34263611, 23.84902763], [68.34236145, 23.84902954], [68.34236145, 23.84819031], [68.34208679, 23.84819221], [68.34208679, 23.84763908], [68.3418045, 23.84763908], [68.3418045, 23.84708214], [68.34152985, 23.84708214], [68.34152985, 23.84680557], [68.34124756, 23.84680939], [68.34124756, 23.84625053], [68.3409729, 23.84625053], [68.3409729, 23.84569168], [68.34069824, 23.84569359], [68.34069824, 23.84541702], [68.34043121, 23.84542274], [68.34043121, 23.84486008], [68.3401413, 23.84486008], [68.3401413, 23.84430504], [68.33985901, 23.84431267], [68.33985901, 23.84375191], [68.33957672, 23.84375191], [68.33957672, 23.84347153], [68.33930206, 23.84347153], [68.33930206, 23.84319496], [68.3390274, 23.84320259], [68.3390274, 23.84263992], [68.33875275, 23.84263992], [68.33875275, 23.84235954], [68.33847046, 23.84236145], [68.33847046, 23.84208298], [68.3381958, 23.84208298], [68.3381958, 23.84180641], [68.33790588, 23.84182167], [68.33790588, 23.84124947], [68.33763885, 23.84124947], [68.33763885, 23.84069061], [68.3373642, 23.84069443], [68.3373642, 23.84041786], [68.33708191, 23.84041977], [68.33708191, 23.83986092], [68.33680725, 23.83986092], [68.33680725, 23.83930969], [68.33653259, 23.83930969], [68.33653259, 23.83876038], [68.33625031, 23.83876038], [68.33625031, 23.83596992], [68.33652496, 23.83597183], [68.33652496, 23.83152771], [68.33680725, 23.83152962], [68.33680725, 23.82818985], [68.33708191, 23.82819366], [68.33708191, 23.82486153], [68.3373642, 23.82486153], [68.3373642, 23.82208252], [68.33763885, 23.82208252], [68.33763885, 23.81930542], [68.33737183, 23.81931114], [68.33737183, 23.81903267], [68.33680725, 23.81903267], [68.33680725, 23.81875038], [68.33652496, 23.81875038], [68.33652496, 23.81847191], [68.33597565, 23.81847191], [68.33597565, 23.81819534], [68.3354187, 23.81820107], [68.3354187, 23.81792259], [68.33513641, 23.81792259], [68.33513641, 23.81764984], [68.3345871, 23.81764984], [68.3345871, 23.81736183], [68.33403015, 23.81736183], [68.33403015, 23.81708336], [68.33347321, 23.81708336], [68.33347321, 23.81680489], [68.33291626, 23.81680489], [68.33291626, 23.81652832], [68.33235931, 23.81653023], [68.33235931, 23.81624985], [68.33180237, 23.81624985], [68.33180237, 23.81596756], [68.33125305, 23.81597137], [68.33125305, 23.81569481], [68.33097076, 23.81569481], [68.33097076, 23.81541634], [68.33040619, 23.81541824], [68.33040619, 23.81513977], [68.33013916, 23.81513977], [68.33013916, 23.81485748], [68.32958221, 23.8148613], [68.32958221, 23.81458282], [68.32930756, 23.81459045], [68.32930756, 23.81430817], [68.3290329, 23.81430817], [68.3290329, 23.81402969], [68.32875061, 23.81402969], [68.32875061, 23.81375122], [68.32849121, 23.81375122], [68.32849121, 23.81347084], [68.32819366, 23.81347275], [68.32819366, 23.81319427], [68.32791901, 23.81319427], [68.32791901, 23.81291771], [68.32763672, 23.81291962], [68.32763672, 23.81264114], [68.32736206, 23.81264114], [68.32736206, 23.81236076], [68.32707977, 23.81236076], [68.32707977, 23.81208038], [68.32680511, 23.8120842], [68.32680511, 23.81180763], [68.32653046, 23.81180954], [68.32653046, 23.81125069], [68.32624817, 23.81125069], [68.32624817, 23.81097031], [68.32597351, 23.81097221], [68.32597351, 23.81069374], [68.32569122, 23.81069374], [68.32569122, 23.81041527], [68.32543182, 23.81042099], [68.32543182, 23.81014061], [68.32514191, 23.81014061], [68.32514191, 23.80957985], [68.32485962, 23.80958557], [68.32485962, 23.80930328], [68.32457733, 23.80931091], [68.32457733, 23.80903053], [68.32430267, 23.80903053], [68.32430267, 23.80875015], [68.32402802, 23.80875015], [68.32402802, 23.80846024], [68.32375336, 23.80847168], [68.32375336, 23.80819321], [68.32347107, 23.80820084], [68.32347107, 23.80764008], [68.32319641, 23.80764008], [68.32319641, 23.8073597], [68.32125092, 23.8073616], [68.32125092, 23.80708122], [68.32096863, 23.80708122], [68.32096863, 23.8073616], [68.32068634, 23.8073597], [68.32068634, 23.80764008], [68.32013702, 23.80764008], [68.32013702, 23.80792046], [68.31986237, 23.80792046], [68.31986237, 23.80820084], [68.31958008, 23.80820084], [68.31958008, 23.80875015], [68.31929779, 23.80875015], [68.31929779, 23.80931091], [68.31903076, 23.80930328], [68.31903076, 23.81069374], [68.31874847, 23.81068993], [68.31874847, 23.81264114], [68.31846619, 23.81264114], [68.31846619, 23.81375122], [68.31819153, 23.81375122], [68.31819153, 23.81402969], [68.31791687, 23.81402969], [68.31791687, 23.8148613], [68.31764221, 23.8148613], [68.31764221, 23.81569481], [68.31735992, 23.81569481], [68.31735992, 23.81597137], [68.3170929, 23.81596756], [68.3170929, 23.81653023], [68.31680298, 23.81652832], [68.31680298, 23.81708336], [68.31652832, 23.81708145], [68.31652832, 23.81792259], [68.31626129, 23.81792259], [68.31626129, 23.81820107], [68.31597137, 23.81819534], [68.31597137, 23.81847191], [68.31569672, 23.81847191], [68.31569672, 23.81875038], [68.3154068, 23.81875038], [68.3154068, 23.81986046], [68.31513977, 23.81986046], [68.31513977, 23.82042122], [68.31485748, 23.8204174], [68.31485748, 23.82097244], [68.31458282, 23.82097054], [68.31458282, 23.82125092], [68.31430817, 23.82125092], [68.31430817, 23.82180977], [68.31402588, 23.82180405], [68.31402588, 23.82208252], [68.31430817, 23.82208061], [68.31430817, 23.82236099], [68.31458282, 23.82236099], [68.31458282, 23.82402992], [68.31430817, 23.82402611], [68.31430817, 23.82430458], [68.31346893, 23.82430458], [68.31346893, 23.82402611], [68.3132019, 23.82402992], [68.3132019, 23.82319069], [68.31291962, 23.82319641], [68.31291962, 23.82291412], [68.31236267, 23.82291412], [68.31236267, 23.82319641], [68.31208038, 23.82319069], [68.31208038, 23.82374954], [68.31181335, 23.82374954], [68.31181335, 23.82402992], [68.31124878, 23.82402611], [68.31124878, 23.82430077], [68.31069183, 23.82430458], [68.31069183, 23.82458305], [68.31014252, 23.82458305], [68.31014252, 23.82486153], [68.30847168, 23.82485962], [68.30847168, 23.82514], [68.30625153, 23.82514], [68.30625153, 23.82485962], [68.30486298, 23.82486153], [68.30486298, 23.82458305], [68.30374908, 23.82458305], [68.30374908, 23.82430458], [68.30319214, 23.82430077], [68.30319214, 23.82402611], [68.30264282, 23.82402992], [68.30264282, 23.82374954], [68.30179596, 23.82374954], [68.30179596, 23.82347107], [68.30097198, 23.82347488], [68.30097198, 23.82319641], [68.30041504, 23.82319641], [68.30041504, 23.82291412], [68.29985809, 23.82291985], [68.29985809, 23.82263947], [68.29930878, 23.82263947], [68.29930878, 23.82236099], [68.29846954, 23.82236099], [68.29846954, 23.82208061], [68.29792023, 23.82208252], [68.29792023, 23.82180405], [68.29708099, 23.82180977], [68.29708099, 23.82152939], [68.29651642, 23.82152939], [68.29651642, 23.82125092], [68.2959671, 23.82125092], [68.2959671, 23.82097054], [68.2951355, 23.82097244], [68.2951355, 23.82069206], [68.29402924, 23.82069206], [68.29402924, 23.8204174], [68.29347229, 23.82042122], [68.29347229, 23.82014275], [68.29292297, 23.82014275], [68.29292297, 23.81986046], [68.2923584, 23.81986046], [68.2923584, 23.81958008], [68.29208374, 23.81958389], [68.29208374, 23.81930542], [68.29125214, 23.81931114], [68.29125214, 23.81903267], [68.29096985, 23.81903267], [68.29096985, 23.81875038], [68.29069519, 23.81875038], [68.29069519, 23.81847191], [68.29013824, 23.81847191], [68.29013824, 23.81819534], [68.2895813, 23.81820107], [68.2895813, 23.81792259], [68.2893219, 23.81792259], [68.2893219, 23.81764984], [68.28903198, 23.81764984], [68.28903198, 23.81736183], [68.28874969, 23.81736183], [68.28874969, 23.8148613], [68.28902435, 23.8148613], [68.28902435, 23.81458282], [68.2893219, 23.81459045], [68.2893219, 23.81430817], [68.28985596, 23.81430817], [68.28985596, 23.81402969], [68.2904129, 23.81402969], [68.2904129, 23.81375122], [68.29070282, 23.81375122], [68.29070282, 23.81347084], [68.29125214, 23.81347275], [68.29125214, 23.81319427], [68.29180908, 23.81319427], [68.29180908, 23.81291771], [68.29209137, 23.81291962], [68.29209137, 23.81264114], [68.29264069, 23.81264114], [68.29264069, 23.81236076], [68.29319763, 23.81236076], [68.29319763, 23.81208038], [68.29402924, 23.8120842], [68.29402924, 23.81180763], [68.29458618, 23.81180954], [68.29458618, 23.81153107], [68.29486084, 23.81153107], [68.29486084, 23.81125069], [68.29541779, 23.81125069], [68.29541779, 23.81097031], [68.29569244, 23.81097221], [68.29569244, 23.81041527], [68.2959671, 23.81042099], [68.2959671, 23.80903053], [68.29624939, 23.80903053], [68.29624939, 23.80708122], [68.29652405, 23.80708122], [68.29652405, 23.80652809], [68.29624939, 23.80653191], [68.29624939, 23.80569267], [68.29597473, 23.80569458], [68.29597473, 23.80486107], [68.29569244, 23.80486107], [68.29569244, 23.80431175], [68.29512787, 23.80431175], [68.29512787, 23.80402946], [68.29458618, 23.80402946], [68.29458618, 23.80374908], [68.29374695, 23.80374908], [68.29374695, 23.80347061], [68.29319763, 23.80347252], [68.29319763, 23.80319405], [68.29264069, 23.80319405], [68.29264069, 23.80291748], [68.29180908, 23.80291939], [68.29180908, 23.80265045], [68.29125214, 23.80265045], [68.29125214, 23.80236053], [68.2895813, 23.80236053], [68.2895813, 23.80207825], [68.28847504, 23.80208397], [68.28847504, 23.8018055], [68.2876358, 23.80180931], [68.2876358, 23.80153084], [68.28652954, 23.80153084], [68.28652954, 23.80125046], [68.28541565, 23.80125046], [68.28541565, 23.80097198], [68.2848587, 23.80097198], [68.2848587, 23.80069351], [68.28430939, 23.80069351], [68.28430176, 23.80041885], [68.28180695, 23.80042076], [68.28180695, 23.80014038], [68.28098297, 23.80014038], [68.28098297, 23.79985809], [68.2804184, 23.79986191], [68.2804184, 23.79958344], [68.27929688, 23.79959106], [68.27929688, 23.79931068], [68.27874756, 23.79931068], [68.27874756, 23.7990303], [68.27819824, 23.7990303], [68.27819824, 23.79874992], [68.27680206, 23.79874992], [68.27680206, 23.79846954], [68.27625275, 23.79847145], [68.27625275, 23.79819679], [68.2756958, 23.79819679], [68.2756958, 23.79791451], [68.27540588, 23.79792023], [68.27540588, 23.79763985], [68.27485657, 23.79763985], [68.27485657, 23.79735947], [68.27430725, 23.79736137], [68.27430725, 23.7970829], [68.27402496, 23.7970829], [68.27402496, 23.79680443], [68.27375031, 23.79681015], [68.27375031, 23.79652023], [68.27347565, 23.79652786], [68.27347565, 23.79597473], [68.27319336, 23.79597473], [68.27319336, 23.79569244], [68.2729187, 23.79569244], [68.2729187, 23.79541588], [68.27263641, 23.79541969], [68.27263641, 23.79486084], [68.27236176, 23.79486084], [68.27236176, 23.79375076], [68.2720871, 23.79375076], [68.2720871, 23.79292107], [68.27179718, 23.79292107], [68.27179718, 23.79208183], [68.27153015, 23.79208374], [68.27153015, 23.7915287], [68.27124786, 23.79153252], [68.27124786, 23.78957748], [68.27097321, 23.78958321], [68.27097321, 23.78763962], [68.27069092, 23.78764915], [68.27069092, 23.78652954], [68.27041626, 23.78652954], [68.27041626, 23.78569031], [68.26985931, 23.78569031], [68.26985931, 23.78625107], [68.26957703, 23.78625107], [68.26957703, 23.78680992], [68.26930237, 23.78680992], [68.26930237, 23.78764915], [68.26902771, 23.78763962], [68.26902771, 23.78847313], [68.26875305, 23.78847122], [68.26875305, 23.78874969], [68.26847076, 23.78874969], [68.26847076, 23.78902817], [68.26821136, 23.78902817], [68.26821136, 23.79014015], [68.26789856, 23.79014015], [68.26789856, 23.79071045], [68.26763916, 23.79071045], [68.26763916, 23.79125023], [68.26735687, 23.79125023], [68.26735687, 23.7918129], [68.26708221, 23.7918129], [68.26708221, 23.79292107], [68.26680756, 23.79291725], [68.26680756, 23.79319382], [68.26597595, 23.79319382], [68.26597595, 23.79291725], [68.26568604, 23.79292107], [68.26568604, 23.79125023], [68.26597595, 23.79125023], [68.26597595, 23.79042244], [68.26625061, 23.79042244], [68.26625061, 23.79014015], [68.2665329, 23.79014015], [68.2665329, 23.78930092], [68.26680756, 23.78930473], [68.26680756, 23.78847313], [68.26708221, 23.78847313], [68.26708221, 23.78791618], [68.26735687, 23.78791809], [68.26735687, 23.78736115], [68.26763916, 23.78736115], [68.26763916, 23.78652954], [68.26789856, 23.78652954], [68.26789856, 23.78569031], [68.26819611, 23.78569412], [68.26819611, 23.78513908], [68.26847076, 23.78514099], [68.26847076, 23.78430939], [68.26875305, 23.78430939], [68.26875305, 23.78347015], [68.26930237, 23.78347206], [68.26930237, 23.78263855], [68.26957703, 23.78264046], [68.26957703, 23.78181076], [68.26985931, 23.78181076], [68.26985931, 23.78096962], [68.26958466, 23.78097153], [68.26958466, 23.78041649], [68.26930237, 23.7804203], [68.26930237, 23.77985954], [68.26902771, 23.77986145], [68.26902771, 23.77930641], [68.26875305, 23.77931023], [68.26875305, 23.77874947], [68.26847076, 23.77874947], [68.26847076, 23.77819252], [68.26819611, 23.77819443], [68.26819611, 23.77763939], [68.26789856, 23.77763939], [68.26789856, 23.77708054], [68.26763916, 23.77708244], [68.26763916, 23.7765274], [68.26735687, 23.77652931], [68.26735687, 23.77597046], [68.26708221, 23.77597237], [68.26708221, 23.77541733], [68.26680756, 23.77541924], [68.26680756, 23.77486038], [68.26652527, 23.77486038], [68.26652527, 23.77430534], [68.26625061, 23.77430916], [68.26625061, 23.77346992], [68.26597595, 23.77347183], [68.26597595, 23.77263641], [68.26568604, 23.77264023], [68.26568604, 23.77235031], [68.26541901, 23.77236176], [68.26541901, 23.77180672], [68.26569366, 23.77180672], [68.26569366, 23.77152824], [68.26597595, 23.77153015], [68.26597595, 23.77042007], [68.26568604, 23.77042007], [68.26568604, 23.76931], [68.26541901, 23.76931], [68.26541901, 23.76875114], [68.26515198, 23.76875114], [68.26515198, 23.76819038], [68.26486206, 23.76819229], [68.26486206, 23.76763916], [68.26457977, 23.76764107], [68.26457977, 23.76708031], [68.26430511, 23.76708221], [68.26430511, 23.76652718], [68.26403046, 23.76654053], [68.26403046, 23.76597023], [68.26374817, 23.76597023], [68.26374817, 23.7654171], [68.26346588, 23.76542282], [68.26346588, 23.76458168], [68.26319122, 23.76458359], [68.26319122, 23.76375008], [68.26291656, 23.76375008], [68.26291656, 23.76291847], [68.26264191, 23.76291847], [68.26264191, 23.76069069], [68.26235962, 23.7606945], [68.26235962, 23.76013947], [68.26207733, 23.76013947], [68.26207733, 23.75625038], [68.26235962, 23.75625038], [68.26235962, 23.75346947], [68.26264191, 23.75347137], [68.26264191, 23.7523613], [68.26291656, 23.7523613], [68.26291656, 23.75152779], [68.26319122, 23.75154114], [68.26319122, 23.75097084], [68.26347351, 23.75097275], [68.26347351, 23.7504158], [68.26374817, 23.75041962], [68.26374817, 23.74986076], [68.26403046, 23.74986076], [68.26403046, 23.74957848], [68.26430511, 23.7495842], [68.26430511, 23.74902725]]], [[[68.24819183, 23.88042068], [68.24819183, 23.8801403], [68.24931335, 23.8801403], [68.24931335, 23.87985992], [68.25013733, 23.87986183], [68.25013733, 23.87958336], [68.25125122, 23.87958336], [68.25125122, 23.87930679], [68.25152588, 23.87930679], [68.25152588, 23.87902832], [68.25180817, 23.87903023], [68.25180817, 23.87874985], [68.25208282, 23.87874985], [68.25208282, 23.87819099], [68.25235748, 23.87819672], [68.25235748, 23.87791443], [68.25263977, 23.87792969], [68.25263977, 23.87763977], [68.25292206, 23.87763977], [68.25291443, 23.8773613], [68.25319672, 23.8773613], [68.25319672, 23.87708282], [68.25347137, 23.87708282], [68.25347137, 23.87680435], [68.25374603, 23.87681007], [68.25374603, 23.87652969], [68.25402832, 23.87652969], [68.25402832, 23.87625122], [68.25430298, 23.87625122], [68.25430298, 23.87569046], [68.25458527, 23.87569237], [68.25458527, 23.87513924], [68.25485992, 23.87514114], [68.25485992, 23.87375069], [68.25458527, 23.87375069], [68.25458527, 23.8726387], [68.25430298, 23.87264061], [68.25430298, 23.87179947], [68.25402832, 23.87180519], [68.25402832, 23.87097168], [68.25375366, 23.87097168], [68.25375366, 23.8698616], [68.25347137, 23.8698616], [68.25347137, 23.86902809], [68.25321198, 23.86902809], [68.25321198, 23.86791992], [68.25292206, 23.86791992], [68.25292206, 23.86683273], [68.2527771, 23.86681938], [68.25263977, 23.86680984], [68.25263977, 23.86625099], [68.25235748, 23.86625099], [68.25235748, 23.86541939], [68.25208282, 23.86541939], [68.25208282, 23.86403084], [68.25180817, 23.86403084], [68.25180817, 23.86236], [68.25152588, 23.86236191], [68.25152588, 23.86208344], [68.25096893, 23.86208344], [68.25096893, 23.86180305], [68.25068665, 23.86181068], [68.25068665, 23.8615303], [68.25041962, 23.8615303], [68.25041962, 23.86124992], [68.25013733, 23.86124992], [68.25013733, 23.86096954], [68.24958038, 23.86097145], [68.24958038, 23.86069489], [68.24930573, 23.86069489], [68.24930573, 23.86041641], [68.24903107, 23.86042023], [68.24903107, 23.86013985], [68.24846649, 23.86013985], [68.24846649, 23.85985947], [68.24819183, 23.85986137], [68.24819183, 23.8595829], [68.24791718, 23.8595829], [68.24791718, 23.85930634], [68.24736023, 23.85931015], [68.24736023, 23.85902977], [68.24707794, 23.85902977], [68.24707794, 23.85874939], [68.24678802, 23.85874939], [68.24678802, 23.85847282], [68.24624634, 23.85847282], [68.24624634, 23.85819435], [68.24597168, 23.85819435], [68.24597168, 23.85791588], [68.24569702, 23.85791969], [68.24569702, 23.85763931], [68.24514008, 23.85763931], [68.24514008, 23.85736084], [68.24485779, 23.85736084], [68.24485779, 23.85707855], [68.24458313, 23.85708237], [68.24458313, 23.8568058], [68.24402618, 23.8568058], [68.24402618, 23.85652733], [68.24375153, 23.85652924], [68.24375153, 23.85625076], [68.24318695, 23.85625076], [68.24318695, 23.85597038], [68.24291992, 23.85597229], [68.24291992, 23.85569382], [68.24263763, 23.85569382], [68.24263763, 23.85541725], [68.24208069, 23.85541916], [68.24208069, 23.85514069], [68.24180603, 23.85514069], [68.24180603, 23.85486031], [68.24153137, 23.85486031], [68.24153137, 23.85457993], [68.24097443, 23.85458374], [68.24097443, 23.85430527], [68.24069214, 23.85430908], [68.24069214, 23.85403061], [68.24041748, 23.85403061], [68.24041748, 23.85375977], [68.23986053, 23.85375977], [68.23986053, 23.85346985], [68.23958588, 23.85347176], [68.23958588, 23.85319519], [68.23929596, 23.85320091], [68.23929596, 23.85292053], [68.23902893, 23.85292053], [68.23902893, 23.85235977], [68.23874664, 23.85236168], [68.23874664, 23.85208321], [68.23847198, 23.85208321], [68.23847198, 23.85180664], [68.23819733, 23.85180664], [68.23819733, 23.85124969], [68.23791504, 23.85124969], [68.23791504, 23.85097313], [68.23764038, 23.85097313], [68.23764038, 23.85041428], [68.23735809, 23.85042], [68.23735809, 23.84986115], [68.23707581, 23.84986115], [68.23707581, 23.84930992], [68.23680878, 23.84930992], [68.23680878, 23.84875107], [68.23652649, 23.84875107], [68.23652649, 23.84819031], [68.23625183, 23.84819221], [68.23625183, 23.84763908], [68.23569489, 23.84763908], [68.23569489, 23.8465271], [68.23542023, 23.84653282], [68.23542023, 23.84625053], [68.23513794, 23.84625053], [68.23513794, 23.84597015], [68.23486328, 23.84597015], [68.23486328, 23.84458351], [68.23458099, 23.84458351], [68.23458099, 23.84430504], [68.23430634, 23.84431267], [68.23430634, 23.84347153], [68.23402405, 23.84347153], [68.23402405, 23.84291649], [68.23374939, 23.8429184], [68.23374939, 23.84263992], [68.2334671, 23.84263992], [68.2334671, 23.84235954], [68.23291779, 23.84235954], [68.23291779, 23.84263992], [68.23236084, 23.84263992], [68.23236084, 23.8429184], [68.23207855, 23.8429184], [68.23207855, 23.84320259], [68.23152924, 23.84319496], [68.23152924, 23.84347153], [68.23124695, 23.84347153], [68.23124695, 23.84375191], [68.23014069, 23.84375191], [68.23014069, 23.84403038], [68.22930908, 23.84403038], [68.22930908, 23.84430504], [68.2292099, 23.84430504], [68.22846985, 23.84430504], [68.22846985, 23.84458351], [68.2279129, 23.84458351], [68.2279129, 23.84486008], [68.2270813, 23.84486008], [68.2270813, 23.84514046], [68.22680664, 23.84514046], [68.22680664, 23.84542274], [68.22652435, 23.84541702], [68.22652435, 23.84569359], [68.22597504, 23.84569359], [68.22597504, 23.84597015], [68.22569275, 23.84597015], [68.22569275, 23.84625053], [68.22541809, 23.84625053], [68.22541809, 23.84653282], [68.22458649, 23.84653282], [68.22458649, 23.84680939], [68.22402954, 23.84680557], [68.22402954, 23.84708214], [68.21847534, 23.84708214], [68.21847534, 23.84736061], [68.21708679, 23.84736061], [68.21708679, 23.84763908], [68.2159729, 23.84762955], [68.2159729, 23.84875107], [68.21569824, 23.84875107], [68.21569824, 23.85070038], [68.2159729, 23.85069656], [68.2159729, 23.85208321], [68.21569824, 23.85208321], [68.21569824, 23.85347176], [68.2159729, 23.85346985], [68.2159729, 23.85430908], [68.21569824, 23.85430527], [68.21569824, 23.85569382], [68.2159729, 23.85569382], [68.2159729, 23.8568058], [68.21624756, 23.85679817], [68.21624756, 23.85736084], [68.2159729, 23.85736084], [68.2159729, 23.85791969], [68.21569824, 23.85791588], [68.21569061, 23.85847282], [68.21541595, 23.85847282], [68.21541595, 23.85931015], [68.21569061, 23.85930634], [68.21569061, 23.85986137], [68.21541595, 23.85985947], [68.21541595, 23.86042023], [68.2151413, 23.86041641], [68.2151413, 23.86069489], [68.21485901, 23.86069489], [68.21485901, 23.86097145], [68.21457672, 23.86096954], [68.21457672, 23.8615303], [68.21430206, 23.8615303], [68.21430206, 23.86181068], [68.21375275, 23.86181068], [68.21375275, 23.86264038], [68.21404266, 23.86264038], [68.21404266, 23.8629303], [68.21430206, 23.86291695], [68.21430206, 23.86347198], [68.21457672, 23.86347008], [68.21457672, 23.86403084], [68.21485901, 23.86403084], [68.21485901, 23.86486053], [68.2151413, 23.86486053], [68.2151413, 23.86541939], [68.21541595, 23.86541748], [68.21541595, 23.86597252], [68.21569061, 23.86597061], [68.21569824, 23.86652946], [68.2159729, 23.86652946], [68.2159729, 23.86680984], [68.21624756, 23.86680794], [68.21624756, 23.8670826], [68.21652985, 23.86708069], [68.21652985, 23.86736107], [68.2168045, 23.86736107], [68.2168045, 23.86763954], [68.2179184, 23.86763954], [68.2179184, 23.86791992], [68.21875, 23.86791611], [68.21875, 23.86819458], [68.21986389, 23.86819458], [68.21986389, 23.86847305], [68.22013855, 23.86847305], [68.22013855, 23.86874962], [68.22041321, 23.86874008], [68.22041321, 23.86902809], [68.2206955, 23.86902809], [68.2206955, 23.86930466], [68.2223587, 23.86930466], [68.2223587, 23.86958313], [68.22291565, 23.86958313], [68.22291565, 23.8698616], [68.22374725, 23.8698597], [68.22374725, 23.87014008], [68.22429657, 23.87014008], [68.22429657, 23.87042236], [68.22486115, 23.87042236], [68.22486115, 23.87070274], [68.22541809, 23.87069511], [68.22541809, 23.87097168], [68.22624969, 23.87097168], [68.22624969, 23.87125015], [68.22680664, 23.87125015], [68.22680664, 23.87153053], [68.22736359, 23.87152863], [68.22736359, 23.87180519], [68.22846985, 23.87180519], [68.22846985, 23.87208366], [68.22930908, 23.87208176], [68.22930908, 23.87236023], [68.2298584, 23.87236023], [68.2298584, 23.87264061], [68.23042297, 23.87264061], [68.23042297, 23.8729229], [68.23097229, 23.87291718], [68.23097229, 23.87319374], [68.23152924, 23.87319374], [68.23152924, 23.87347221], [68.23236084, 23.87347031], [68.23236084, 23.87375069], [68.23319244, 23.87375069], [68.23319244, 23.87403107], [68.23374939, 23.87403107], [68.23374939, 23.87430954], [68.23458099, 23.87430573], [68.23458099, 23.87458229], [68.23542023, 23.87458038], [68.23542023, 23.8748703], [68.23596954, 23.8748703], [68.23596954, 23.87514114], [68.23652649, 23.87514114], [68.23652649, 23.87541962], [68.23708344, 23.8754158], [68.23708344, 23.87569237], [68.23764038, 23.87569237], [68.23764038, 23.87597275], [68.23847198, 23.87597084], [68.23847198, 23.87625122], [68.23902893, 23.87625122], [68.23902893, 23.87652969], [68.23958588, 23.87652969], [68.23958588, 23.87681007], [68.24013519, 23.87680435], [68.24013519, 23.87708282], [68.24069214, 23.87708282], [68.24069214, 23.8773613], [68.24124908, 23.87735939], [68.24124908, 23.87763977], [68.24180603, 23.87763977], [68.24180603, 23.87792969], [68.24208069, 23.87791443], [68.24208069, 23.87819672], [68.24263763, 23.87819672], [68.24263763, 23.87847137], [68.24291992, 23.87846947], [68.24291992, 23.87874985], [68.24318695, 23.87874985], [68.24318695, 23.87903023], [68.24346924, 23.87902832], [68.24346924, 23.87930679], [68.24375153, 23.87930679], [68.24375153, 23.87958336], [68.24402618, 23.87958336], [68.24402618, 23.87986183], [68.24458313, 23.87985992], [68.24458313, 23.8801403], [68.24485779, 23.8801403], [68.24485779, 23.88042068], [68.24819183, 23.88042068]]], [[[68.70707703, 23.85124969], [68.70707703, 23.85097122], [68.70874786, 23.85097313], [68.70874786, 23.85069656], [68.70929718, 23.85070038], [68.70929718, 23.85042], [68.7095871, 23.85042], [68.7095871, 23.85013962], [68.71013641, 23.85013962], [68.71013641, 23.84986115], [68.71069336, 23.84986115], [68.71069336, 23.84930992], [68.7104187, 23.84930992], [68.7104187, 23.84875107], [68.71013641, 23.84875107], [68.71013641, 23.84930992], [68.70874786, 23.8493042], [68.70874786, 23.84958267], [68.70819092, 23.84958267], [68.70819092, 23.8493042], [68.70735168, 23.84930992], [68.70735168, 23.84902954], [68.70540619, 23.84902954], [68.70540619, 23.84847069], [68.70513916, 23.84847069], [68.70513916, 23.84875107], [68.70485687, 23.84875107], [68.70485687, 23.84902954], [68.70458221, 23.84902763], [68.70458221, 23.84958267], [68.70375061, 23.84958076], [68.70375061, 23.84986115], [68.70318604, 23.84986115], [68.70318604, 23.85013962], [68.70291901, 23.85013962], [68.70291901, 23.85042], [68.70263672, 23.85041428], [68.70263672, 23.85097313], [68.70652771, 23.85097122], [68.70652771, 23.85124969], [68.70707703, 23.85124969]]], [[[68.69930267, 23.85320091], [68.69930267, 23.85292053], [68.70014191, 23.85292053], [68.70014191, 23.85264015], [68.70041656, 23.85264015], [68.70041656, 23.85235977], [68.70069122, 23.85236168], [68.70069122, 23.85180664], [68.70041656, 23.85180664], [68.70041656, 23.85152626], [68.69985962, 23.85153008], [68.69985962, 23.85124969], [68.69957733, 23.85124969], [68.69957733, 23.85097122], [68.69930267, 23.85097313], [68.69930267, 23.85069656], [68.69875336, 23.85070038], [68.69875336, 23.85042], [68.6984787, 23.85042], [68.6984787, 23.85013962], [68.69790649, 23.85013962], [68.69790649, 23.84986115], [68.69763947, 23.84986115], [68.69763947, 23.84958076], [68.69708252, 23.84958267], [68.69708252, 23.8493042], [68.69680786, 23.84930992], [68.69680786, 23.84902954], [68.69541168, 23.84902954], [68.69541168, 23.84930992], [68.69486237, 23.84930992], [68.69486237, 23.85042], [68.69513702, 23.85042], [68.69513702, 23.85153008], [68.69596863, 23.85152626], [68.69596863, 23.85180664], [68.69625092, 23.85180664], [68.69625092, 23.85208321], [68.69680786, 23.85208321], [68.69680786, 23.85236168], [68.69708252, 23.85235977], [68.69708252, 23.85264015], [68.69763947, 23.85264015], [68.69763947, 23.85292053], [68.69790649, 23.85292053], [68.69790649, 23.85320091], [68.69930267, 23.85320091]]], [[[68.53320312, 23.87375069], [68.5331955, 23.8726387], [68.53347015, 23.87264061], [68.53347015, 23.87236023], [68.53375244, 23.87236023], [68.53375244, 23.87208176], [68.5340271, 23.87208366], [68.5340271, 23.87180519], [68.53430176, 23.87180519], [68.53430939, 23.87013817], [68.53457642, 23.87014008], [68.53457642, 23.86569977], [68.5348587, 23.86569977], [68.5348587, 23.86486053], [68.53291321, 23.86486053], [68.53291321, 23.86403084], [68.53263855, 23.86403084], [68.53263855, 23.8631897], [68.5320816, 23.86319351], [68.5320816, 23.86291695], [68.53151703, 23.8629303], [68.53151703, 23.86264038], [68.53125, 23.86264038], [68.53125, 23.86236], [68.53069305, 23.86236191], [68.53069305, 23.86208344], [68.53013611, 23.86208344], [68.53013611, 23.86180305], [68.52958679, 23.86181068], [68.52958679, 23.8615303], [68.52902985, 23.8615303], [68.52902985, 23.86124992], [68.52874756, 23.86124992], [68.52874756, 23.86096954], [68.5284729, 23.86097145], [68.5284729, 23.86041641], [68.52819824, 23.86042023], [68.52819824, 23.86013985], [68.52791595, 23.86013985], [68.52791595, 23.85985947], [68.5276413, 23.85986137], [68.5276413, 23.8595829], [68.52735901, 23.8595829], [68.52735901, 23.85930634], [68.5256958, 23.85931015], [68.5256958, 23.85874939], [68.52540588, 23.85874939], [68.52540588, 23.85847282], [68.52402496, 23.85847282], [68.52402496, 23.8595829], [68.52430725, 23.85957146], [68.52430725, 23.86013985], [68.52458191, 23.86013985], [68.52458191, 23.86042023], [68.5248642, 23.86041641], [68.5248642, 23.86069489], [68.52513885, 23.86069107], [68.52513885, 23.86124992], [68.52540588, 23.86124992], [68.52540588, 23.8615303], [68.5256958, 23.8615303], [68.5256958, 23.86181068], [68.52597046, 23.86180305], [68.52597046, 23.86236191], [68.52625275, 23.86236], [68.52625275, 23.86264038], [68.5265274, 23.86264038], [68.5265274, 23.8629303], [68.52680206, 23.86291695], [68.52680206, 23.86347198], [68.52707672, 23.86347008], [68.52707672, 23.86375046], [68.52735901, 23.86375046], [68.52735901, 23.86403084], [68.5276413, 23.86402512], [68.5276413, 23.86458588], [68.52791595, 23.86458015], [68.52791595, 23.86514091], [68.52819061, 23.86514091], [68.52819824, 23.86569977], [68.5284729, 23.86569595], [68.5284729, 23.86597252], [68.52874756, 23.86597061], [68.52874756, 23.86680984], [68.52902985, 23.86680794], [68.52902985, 23.8670826], [68.5293045, 23.8670826], [68.5293045, 23.86819458], [68.52958679, 23.86819077], [68.52958679, 23.86902809], [68.52986145, 23.86902809], [68.52986145, 23.86958313], [68.53013611, 23.86958122], [68.53013611, 23.87014008], [68.5304184, 23.87013817], [68.5304184, 23.87097168], [68.53069305, 23.87097168], [68.53069305, 23.87125015], [68.53098297, 23.87125015], [68.53098297, 23.87153053], [68.53125, 23.87152863], [68.53125, 23.87180519], [68.53151703, 23.87179947], [68.53151703, 23.87236023], [68.53180695, 23.87236023], [68.53180695, 23.8729229], [68.5320816, 23.87291718], [68.5320816, 23.87319374], [68.53236389, 23.87319374], [68.53236389, 23.87347221], [68.53263855, 23.87347031], [68.53263855, 23.87375069], [68.53320312, 23.87375069]]], [[[68.41571045, 23.88986969], [68.41596985, 23.88986969], [68.41596985, 23.89014053], [68.41680908, 23.89014053], [68.41680908, 23.89042091], [68.41708374, 23.89041519], [68.41708374, 23.89069366], [68.41764069, 23.89069366], [68.41764069, 23.89097214], [68.41791534, 23.89097214], [68.41791534, 23.89125061], [68.41819763, 23.89125061], [68.41819763, 23.89153099], [68.41845703, 23.89153099], [68.41845703, 23.89180946], [68.41874695, 23.89180756], [68.41874695, 23.89208412], [68.41986084, 23.89208031], [68.41986084, 23.89236069], [68.42069244, 23.89236069], [68.42069244, 23.89264107], [68.42152405, 23.89263916], [68.42152405, 23.89291763], [68.42236328, 23.89291763], [68.42236328, 23.8931942], [68.42292023, 23.8931942], [68.42292023, 23.89347267], [68.42542267, 23.89347076], [68.42542267, 23.89375114], [68.42679596, 23.89375114], [68.42679596, 23.89402962], [68.42765045, 23.89402962], [68.42765045, 23.89430809], [68.42847443, 23.89430618], [68.42847443, 23.89458275], [68.42903137, 23.89458084], [68.42903137, 23.89486122], [68.42930603, 23.89486122], [68.42930603, 23.8959713], [68.42903137, 23.89596748], [68.42903137, 23.89624977], [68.42819214, 23.89624977], [68.42819214, 23.89596748], [68.42791748, 23.8959713], [68.42791748, 23.89569473], [68.42680359, 23.89569473], [68.42680359, 23.89541626], [68.42624664, 23.89541817], [68.42624664, 23.89513969], [68.42458344, 23.89513969], [68.42458344, 23.89486122], [68.42236328, 23.89486122], [68.42236328, 23.89458084], [68.42180634, 23.89458275], [68.42180634, 23.89430618], [68.4209671, 23.89430809], [68.4209671, 23.89402962], [68.42014313, 23.89402962], [68.42014313, 23.89375114], [68.41929626, 23.89375114], [68.41929626, 23.89347076], [68.41819763, 23.89347267], [68.41819763, 23.8931942], [68.41791534, 23.8931942], [68.41791534, 23.89291763], [68.41764069, 23.89291763], [68.41764069, 23.89263916], [68.4173584, 23.89264107], [68.4173584, 23.89236069], [68.41707611, 23.89236069], [68.41707611, 23.89208031], [68.41652679, 23.89208412], [68.41652679, 23.89180756], [68.41625214, 23.89180946], [68.41625214, 23.89153099], [68.41542053, 23.89153099], [68.41542053, 23.89125061], [68.41485596, 23.89125061], [68.41485596, 23.89097023], [68.4145813, 23.89097214], [68.4145813, 23.89041519], [68.41430664, 23.89042091], [68.41430664, 23.89014053], [68.41401672, 23.89014053], [68.41401672, 23.88986969], [68.41374969, 23.88986969], [68.41374969, 23.88957977], [68.41347504, 23.88958359], [68.41347504, 23.88930321], [68.41319275, 23.88931084], [68.41319275, 23.88903046], [68.41291809, 23.88903046], [68.41291809, 23.88875008], [68.4126358, 23.88875008], [68.4126358, 23.8884716], [68.41236115, 23.8884716], [68.41236115, 23.88819313], [68.41179657, 23.88820076], [68.41179657, 23.88792038], [68.41124725, 23.88792038], [68.41124725, 23.88764], [68.41069794, 23.88764], [68.41069794, 23.88735962], [68.41041565, 23.88736153], [68.41041565, 23.88708115], [68.41014099, 23.88708115], [68.41014099, 23.88680649], [68.4098587, 23.8868103], [68.4098587, 23.88652992], [68.40957642, 23.88652992], [68.40957642, 23.88624954], [68.40930939, 23.88624954], [68.4092865, 23.8856926], [68.4090271, 23.8856945], [68.4090271, 23.88541603], [68.40875244, 23.88542175], [68.40875244, 23.88513947], [68.40847015, 23.88513947], [68.40847015, 23.88402939], [68.40875244, 23.88402939], [68.40875244, 23.88347054], [68.4090271, 23.88347244], [68.4090271, 23.88319397], [68.40930176, 23.88319397], [68.40930939, 23.8829174], [68.40957642, 23.88291931], [68.40957642, 23.88264084], [68.41042328, 23.88264084], [68.41042328, 23.88236046], [68.41124725, 23.88236046], [68.41124725, 23.88207817], [68.41208649, 23.88208389], [68.41208649, 23.88180542], [68.41236115, 23.88180923], [68.41236115, 23.88153076], [68.41291809, 23.88153076], [68.41291809, 23.88125038], [68.41319275, 23.88125038], [68.41319275, 23.88096809], [68.41347504, 23.88097191], [68.41347504, 23.88069534], [68.41401672, 23.88069916], [68.41401672, 23.88042068], [68.41430664, 23.88042068], [68.41430664, 23.8801403], [68.4145813, 23.8801403], [68.4145813, 23.87985992], [68.41486359, 23.87986183], [68.41486359, 23.87958336], [68.4154129, 23.87958336], [68.4154129, 23.87930679], [68.41569519, 23.87930679], [68.41569519, 23.87902832], [68.41596985, 23.87903023], [68.41596985, 23.87874985], [68.41625214, 23.87874985], [68.41625214, 23.87846947], [68.41652679, 23.87847137], [68.41652679, 23.87819672], [68.41680908, 23.87819672], [68.41680908, 23.87763977], [68.41707611, 23.87763977], [68.41707611, 23.87735939], [68.4173584, 23.8773613], [68.4173584, 23.87708282], [68.41764069, 23.87708282], [68.41764069, 23.87680435], [68.41792297, 23.87681007], [68.41792297, 23.87625122], [68.41819763, 23.87625122], [68.41819763, 23.87514114], [68.41792297, 23.87514114], [68.41792297, 23.87430954], [68.41764069, 23.87430954], [68.41764069, 23.87375069], [68.4173584, 23.87375069], [68.4173584, 23.8729229], [68.41707611, 23.8729229], [68.41707611, 23.87236023], [68.41513824, 23.87236023], [68.41513824, 23.87264061], [68.41430664, 23.87264061], [68.41430664, 23.8729229], [68.4109726, 23.87291718], [68.4109726, 23.87319374], [68.41014099, 23.87319374], [68.41014099, 23.87347221], [68.4092865, 23.87347031], [68.4092865, 23.87375069], [68.40847015, 23.87375069], [68.40847015, 23.87403107], [68.40820313, 23.87403107], [68.40820313, 23.87430954], [68.40763855, 23.87430573], [68.40763855, 23.87458229], [68.40680695, 23.87458038], [68.40680695, 23.8748703], [68.40651703, 23.8748703], [68.40651703, 23.87514114], [68.40598297, 23.87514114], [68.40598297, 23.87541962], [68.4054184, 23.8754158], [68.4054184, 23.87569237], [68.40486145, 23.87569237], [68.40486145, 23.87597275], [68.40402985, 23.87597084], [68.40402985, 23.87625122], [68.40319824, 23.87625122], [68.40319061, 23.87652969], [68.40235901, 23.87652969], [68.40235901, 23.87681007], [68.40208435, 23.87680435], [68.40208435, 23.87708282], [68.4015274, 23.87708282], [68.4015274, 23.8773613], [68.4006958, 23.8773613], [68.40071106, 23.87763977], [68.40013885, 23.87763977], [68.40013885, 23.87792969], [68.39958191, 23.87791443], [68.39958191, 23.87819672], [68.39847565, 23.87819672], [68.39847565, 23.87847137], [68.39763641, 23.87846947], [68.39763641, 23.87874985], [68.3970871, 23.87874985], [68.3970871, 23.87903023], [68.39653015, 23.87902832], [68.39653015, 23.87930679], [68.39569092, 23.87930679], [68.39569092, 23.87958336], [68.39375305, 23.87957954], [68.39375305, 23.8801403], [68.39347076, 23.8801403], [68.39347076, 23.88042068], [68.39263916, 23.88042068], [68.39263916, 23.8801403], [68.39235687, 23.8801403], [68.39235687, 23.87957954], [68.39208221, 23.87958336], [68.39208221, 23.87902832], [68.39125061, 23.87903023], [68.39125061, 23.87874985], [68.39097595, 23.87874985], [68.39097595, 23.87846947], [68.39069366, 23.87847137], [68.39069366, 23.8773613], [68.39041901, 23.8773613], [68.39041901, 23.87708282], [68.38986206, 23.87708282], [68.38986206, 23.87680435], [68.38957977, 23.87681007], [68.38957977, 23.87652969], [68.38903046, 23.87652969], [68.38903046, 23.87625122], [68.38848114, 23.87625122], [68.38848114, 23.87597084], [68.38625336, 23.87597084], [68.38625336, 23.87625122], [68.37847137, 23.87625122], [68.37847137, 23.87652969], [68.37735748, 23.87652969], [68.37735748, 23.87625122], [68.37708282, 23.87625122], [68.37708282, 23.87597084], [68.37680817, 23.87597275], [68.37680817, 23.87569237], [68.37625122, 23.87569237], [68.37625122, 23.8754158], [68.37596893, 23.87541962], [68.37596893, 23.87514114], [68.37568665, 23.87514114], [68.37568665, 23.87458038], [68.37541962, 23.87458229], [68.37541962, 23.87402725], [68.37513733, 23.87403107], [68.37513733, 23.87347031], [68.37486267, 23.87347221], [68.37486267, 23.87291718], [68.37458038, 23.8729229], [68.37458038, 23.87236023], [68.37430573, 23.87236023], [68.37430573, 23.87180519], [68.37403107, 23.87180519], [68.37403107, 23.87097168], [68.37374878, 23.87097168], [68.37374878, 23.87013817], [68.37346649, 23.87014008], [68.37346649, 23.86958122], [68.37319183, 23.86958313], [68.37319183, 23.86874962], [68.37291718, 23.86874962], [68.37291718, 23.86597252], [68.37264252, 23.86597252], [68.37264252, 23.8615284], [68.37236023, 23.8615303], [68.37236023, 23.85957146], [68.37208557, 23.8595829], [68.37208557, 23.85930634], [68.37180328, 23.85931015], [68.37180328, 23.85902977], [68.37152863, 23.85902977], [68.37152863, 23.85874939], [68.37124634, 23.85874939], [68.37124634, 23.85847282], [68.37069702, 23.85847282], [68.37069702, 23.85819435], [68.37041473, 23.85819435], [68.37041473, 23.85791588], [68.37014008, 23.85791969], [68.37014008, 23.85763931], [68.36958313, 23.85763931], [68.36958313, 23.85736084], [68.36930847, 23.85736084], [68.36930847, 23.85707855], [68.36875153, 23.85708237], [68.36875153, 23.8568058], [68.36846924, 23.8568058], [68.36846924, 23.85652733], [68.36791992, 23.85652924], [68.36791992, 23.85625076], [68.36708069, 23.85625076], [68.36708069, 23.85597038], [68.36653137, 23.85597229], [68.36653137, 23.85569382], [68.36597443, 23.85569382], [68.36597443, 23.85541725], [68.36514282, 23.85541916], [68.36514282, 23.85514069], [68.36431122, 23.85514069], [68.36431122, 23.85486031], [68.36374664, 23.85486031], [68.36374664, 23.85457993], [68.36347198, 23.85458374], [68.36347198, 23.85430527], [68.36292267, 23.85430908], [68.36292267, 23.85403061], [68.36235809, 23.85403061], [68.36235809, 23.85375977], [68.36180878, 23.85375977], [68.36180878, 23.85346985], [68.36125183, 23.85347176], [68.36125183, 23.85319519], [68.36068726, 23.85320091], [68.36068726, 23.85292053], [68.36042023, 23.85292053], [68.36042023, 23.85264015], [68.35986328, 23.85264015], [68.35986328, 23.85235977], [68.35930634, 23.85236168], [68.35930634, 23.85208321], [68.35874939, 23.85208321], [68.35874939, 23.85180664], [68.35819244, 23.85180664], [68.35819244, 23.85152626], [68.35791779, 23.85153008], [68.35791779, 23.85124969], [68.35736084, 23.85124969], [68.35736084, 23.85097122], [68.35708618, 23.85097313], [68.35708618, 23.85069656], [68.35652924, 23.85070038], [68.35652924, 23.85013962], [68.35624695, 23.85013962], [68.35624695, 23.84986115], [68.35597229, 23.84986115], [68.35597229, 23.84958076], [68.35569763, 23.84958267], [68.35569763, 23.8493042], [68.35540771, 23.84930992], [68.35540771, 23.84902954], [68.35514069, 23.84902954], [68.35514069, 23.84847069], [68.3548584, 23.8484726], [68.3548584, 23.84791756], [68.35457611, 23.84791946], [68.35457611, 23.84762955], [68.35430908, 23.84763908], [68.35430908, 23.84736061], [68.35375214, 23.84736061], [68.35375214, 23.84680939], [68.35346985, 23.84680939], [68.35346985, 23.84625053], [68.3529129, 23.84625053], [68.3529129, 23.84597015], [68.35236359, 23.84597015], [68.35236359, 23.84569359], [68.35069275, 23.84569359], [68.35069275, 23.84597015], [68.3501358, 23.84597015], [68.3501358, 23.84625053], [68.34986115, 23.84625053], [68.34986115, 23.84736061], [68.3501358, 23.84736061], [68.3501358, 23.84819221], [68.35041809, 23.84819221], [68.35041809, 23.8484726], [68.35069275, 23.84847069], [68.35069275, 23.84875107], [68.35098267, 23.84875107], [68.35098267, 23.85042], [68.35124969, 23.85041428], [68.35124969, 23.85097313], [68.35152435, 23.85097313], [68.35152435, 23.85180664], [68.35180664, 23.85180092], [68.35180664, 23.85292053], [68.3520813, 23.85291862], [68.3520813, 23.85347176], [68.35237122, 23.85346985], [68.35237122, 23.85375977], [68.35263824, 23.85375977], [68.35263824, 23.85403061], [68.3529129, 23.85403061], [68.3529129, 23.85430908], [68.35319519, 23.85430527], [68.35319519, 23.85486031], [68.35346985, 23.85486031], [68.35346985, 23.85541916], [68.35375214, 23.85541725], [68.35375214, 23.85597229], [68.35402679, 23.85597038], [68.35402679, 23.85652924], [68.35430908, 23.85652733], [68.35430908, 23.85708427], [68.35457611, 23.85707855], [68.35457611, 23.85763931], [68.3548584, 23.85763931], [68.3548584, 23.85847282], [68.35514069, 23.85847282], [68.35514069, 23.85931015], [68.35541534, 23.85930634], [68.35541534, 23.85986137], [68.35569763, 23.85986137], [68.35569763, 23.86097145], [68.35597229, 23.86097145], [68.35597229, 23.86208344], [68.35624695, 23.86208344], [68.35624695, 23.8631897], [68.35652924, 23.86320114], [68.35652924, 23.86569977], [68.35680389, 23.86569595], [68.35680389, 23.87208366], [68.35652924, 23.87208176], [68.35652924, 23.87430954], [68.35624695, 23.87430954], [68.35624695, 23.87625122], [68.35597229, 23.87624931], [68.35597229, 23.8773613], [68.35569763, 23.8773613], [68.35569763, 23.87847137], [68.35541534, 23.87847137], [68.35541534, 23.87930679], [68.35514069, 23.87930679], [68.35514069, 23.87986183], [68.3548584, 23.87985992], [68.3548584, 23.88042068], [68.35458374, 23.88041878], [68.35458374, 23.88208389], [68.3548584, 23.88207817], [68.3548584, 23.88264084], [68.35514069, 23.88264084], [68.35514069, 23.88319397], [68.35541534, 23.88319397], [68.35541534, 23.88347244], [68.35569763, 23.88347244], [68.35569763, 23.88375092], [68.35597229, 23.88373947], [68.35597229, 23.88402939], [68.35624695, 23.88402939], [68.35624695, 23.88431168], [68.35652924, 23.88431168], [68.35652924, 23.88513947], [68.35624695, 23.88513947], [68.35624695, 23.88597107], [68.35597229, 23.88597107], [68.35597229, 23.88708115], [68.35569763, 23.88708115], [68.35569763, 23.88736153], [68.35540771, 23.88735962], [68.35540771, 23.88764], [68.35514069, 23.88764], [68.35514069, 23.88792038], [68.35541534, 23.88791656], [68.35541534, 23.8884716], [68.35569763, 23.8884697], [68.35569763, 23.88931084], [68.35597229, 23.88931084], [68.35597229, 23.89014053], [68.35624695, 23.89013863], [68.35624695, 23.89069366], [68.35652924, 23.89069366], [68.35652924, 23.89097214], [68.35679626, 23.89097023], [68.35679626, 23.89153099], [68.35708618, 23.89153099], [68.35708618, 23.89180946], [68.35736084, 23.89180756], [68.35736084, 23.89208412], [68.35764313, 23.89208031], [68.35764313, 23.89264107], [68.35791779, 23.89263916], [68.35791779, 23.89291763], [68.35847473, 23.89291763], [68.35847473, 23.8931942], [68.35986328, 23.8931942], [68.35986328, 23.89291763], [68.36096954, 23.89291763], [68.36096954, 23.89263916], [68.36180878, 23.89264107], [68.36180878, 23.89236069], [68.36486053, 23.89236069], [68.36486053, 23.89208031], [68.36541748, 23.89208412], [68.36541748, 23.89180756], [68.36569214, 23.89180946], [68.36569214, 23.89153099], [68.36624908, 23.89153099], [68.36624908, 23.89125061], [68.36653137, 23.89125061], [68.36653137, 23.89097023], [68.36680603, 23.89097214], [68.36680603, 23.89069366], [68.36708069, 23.89069366], [68.36708069, 23.89041519], [68.36736298, 23.89041519], [68.36736298, 23.89069366], [68.36763763, 23.89069366], [68.36763763, 23.89097214], [68.36734772, 23.89097023], [68.36734772, 23.89153099], [68.36708069, 23.89153099], [68.36708069, 23.89180946], [68.36680603, 23.89180756], [68.36680603, 23.89208412], [68.36624908, 23.89208031], [68.36624908, 23.89236069], [68.36734772, 23.89236069], [68.36734772, 23.89264107], [68.36763763, 23.89263916], [68.36763763, 23.89291763], [68.36736298, 23.89291763], [68.36736298, 23.8931942], [68.36624908, 23.8931942], [68.36624908, 23.89291763], [68.36597443, 23.89291763], [68.36597443, 23.8931942], [68.36180878, 23.8931942], [68.36180878, 23.89347267], [68.36096954, 23.89347076], [68.36096954, 23.89375114], [68.35986328, 23.89375114], [68.35986328, 23.89402962], [68.3584671, 23.89402962], [68.3584671, 23.89375114], [68.35791779, 23.89375114], [68.35791779, 23.89347076], [68.35736084, 23.89347267], [68.35736084, 23.8931942], [68.35708618, 23.8931942], [68.35708618, 23.89263916], [68.35679626, 23.89264107], [68.35679626, 23.89236069], [68.35652924, 23.89236069], [68.35652924, 23.89208031], [68.35624695, 23.89208412], [68.35624695, 23.89152527], [68.35597229, 23.89153099], [68.35597229, 23.89097023], [68.35569763, 23.89097214], [68.35569763, 23.89069366], [68.35541534, 23.89069366], [68.35541534, 23.89013863], [68.35514069, 23.89014053], [68.35514069, 23.88957977], [68.3548584, 23.88958359], [68.3548584, 23.8884716], [68.35458374, 23.8884716], [68.35458374, 23.88819313], [68.35430908, 23.88820076], [68.35430908, 23.88764], [68.35457611, 23.88764], [68.35457611, 23.88735962], [68.3548584, 23.88736153], [68.3548584, 23.88680649], [68.35514069, 23.8868103], [68.35514069, 23.88597107], [68.35541534, 23.88597107], [68.35541534, 23.8848629], [68.35569763, 23.8848629], [68.35569763, 23.88458061], [68.35514069, 23.88458252], [68.35514069, 23.88430595], [68.35430908, 23.88431168], [68.35430908, 23.88402939], [68.35402679, 23.88402939], [68.35402679, 23.88373947], [68.35320282, 23.88373947], [68.35320282, 23.88431168], [68.3529129, 23.88431168], [68.3529129, 23.88542175], [68.35263824, 23.88542175], [68.35263824, 23.88652992], [68.35237122, 23.88652992], [68.35237122, 23.88764], [68.3520813, 23.88764], [68.3520813, 23.88820076], [68.35180664, 23.88820076], [68.35180664, 23.88875008], [68.35151672, 23.88875008], [68.35151672, 23.88931084], [68.35124969, 23.88931084], [68.35124969, 23.88986969], [68.35098267, 23.88986969], [68.35098267, 23.89042091], [68.35069275, 23.89042091], [68.35069275, 23.89125061], [68.35041809, 23.89125061], [68.35041809, 23.89624977], [68.35069275, 23.89624977], [68.35069275, 23.89652824], [68.35097504, 23.89652824], [68.35097504, 23.89708328], [68.35124969, 23.89708328], [68.35124969, 23.89736176], [68.35151672, 23.89736176], [68.35151672, 23.89764023], [68.35180664, 23.89764023], [68.35180664, 23.8982029], [68.3520813, 23.8982029], [68.3520813, 23.89875031], [68.35237122, 23.89875031], [68.35237122, 23.89931107], [68.35263824, 23.89931107], [68.35263824, 23.89986038], [68.3529129, 23.89986038], [68.3529129, 23.90069389], [68.35375214, 23.90069389], [68.35375214, 23.90097237], [68.35402679, 23.90097046], [68.35402679, 23.90125084], [68.35430908, 23.90125084], [68.35430908, 23.90153122], [68.35457611, 23.90153122], [68.35457611, 23.90180969], [68.35514069, 23.90180588], [68.35514069, 23.90208244], [68.35540771, 23.90208054], [68.35540771, 23.90236092], [68.35569763, 23.90236092], [68.35569763, 23.90263939], [68.35597229, 23.90263939], [68.35597229, 23.90291977], [68.35652924, 23.90291405], [68.35652924, 23.90319443], [68.35708618, 23.90319443], [68.35708618, 23.90347481], [68.35791779, 23.90347099], [68.35791779, 23.90374947], [68.3584671, 23.90374947], [68.3584671, 23.90402985], [68.35901642, 23.90402985], [68.35901642, 23.90431023], [68.35986328, 23.9043045], [68.35986328, 23.90458298], [68.36069489, 23.90458298], [68.36069489, 23.90486145], [68.36152649, 23.90485001], [68.36152649, 23.90513992], [68.36235809, 23.90513992], [68.36235809, 23.9054203], [68.36292267, 23.9054203], [68.36292267, 23.90570068], [68.36374664, 23.90569687], [68.36374664, 23.90597153], [68.3659668, 23.90596962], [68.3659668, 23.90625], [68.36791992, 23.90625], [68.36791992, 23.90653038], [68.36958313, 23.90653038], [68.36958313, 23.90625], [68.3704071, 23.90625], [68.3704071, 23.90653038], [68.37124634, 23.90653038], [68.37124634, 23.90681076], [68.37291718, 23.90681076], [68.37291718, 23.90653038], [68.37596893, 23.90653038], [68.37596893, 23.90625], [68.37847137, 23.90625], [68.37847137, 23.90596962], [68.38180542, 23.90597153], [68.38180542, 23.90625], [68.38625336, 23.90625], [68.38625336, 23.90653038], [68.38735962, 23.90653038], [68.38735962, 23.90681076], [68.38874817, 23.90680695], [68.38874817, 23.90708351], [68.38986206, 23.90708351], [68.38986206, 23.90736198], [68.39068604, 23.90735817], [68.39068604, 23.90764046], [68.39152527, 23.90763855], [68.39152527, 23.90791893], [68.3923645, 23.90791893], [68.3923645, 23.90819359], [68.39319611, 23.90819359], [68.39319611, 23.90847206], [68.39347076, 23.90846825], [68.39347076, 23.90875053], [68.39402771, 23.90875053], [68.39402771, 23.90903091], [68.39428711, 23.90903091], [68.39428711, 23.90930939], [68.39458466, 23.90930557], [68.39458466, 23.90958405], [68.39485931, 23.90957832], [68.39485931, 23.90986061], [68.39653015, 23.90986061], [68.39653015, 23.91013908], [68.3973465, 23.91013908], [68.3973465, 23.91041946], [68.3979187, 23.91041756], [68.3979187, 23.91069412], [68.39930725, 23.9106884], [68.39930725, 23.91098022], [68.39985657, 23.91098022], [68.39985657, 23.91124916], [68.40042114, 23.91124916], [68.40042114, 23.91152954], [68.40125275, 23.91152954], [68.40125275, 23.91181183], [68.40180206, 23.91180611], [68.40180206, 23.91208267], [68.4026413, 23.91208267], [68.4026413, 23.91236115], [68.40513611, 23.91236115], [68.40513611, 23.91263962], [68.4054184, 23.91263962], [68.4054184, 23.91292191], [68.40597534, 23.91291618], [68.40597534, 23.91319466], [68.40625, 23.91319466], [68.40625, 23.91347122], [68.40680695, 23.91347122], [68.40680695, 23.91374969], [68.4070816, 23.91374969], [68.4070816, 23.91403961], [68.40763855, 23.91402817], [68.40763855, 23.91430473], [68.4081955, 23.91430473], [68.4081955, 23.91458321], [68.4090271, 23.91458321], [68.4090271, 23.91486168], [68.40957642, 23.91485977], [68.40957642, 23.91514015], [68.41014099, 23.91514015], [68.41014099, 23.91542053], [68.41069794, 23.91542053], [68.41069794, 23.91570091], [68.41124725, 23.91569328], [68.41124725, 23.91597176], [68.41152954, 23.91596985], [68.41152954, 23.91625023], [68.4126358, 23.91625023], [68.4126358, 23.91708565], [68.41319275, 23.91707993], [68.41319275, 23.91736031], [68.41485596, 23.91736031], [68.41485596, 23.91764069], [68.41542053, 23.91764069], [68.41542053, 23.91792107], [68.41569519, 23.91791534], [68.41569519, 23.91819382], [68.41596985, 23.91819382], [68.41596985, 23.91847229], [68.41625214, 23.91847038], [68.41625214, 23.91875076], [68.41680908, 23.91875076], [68.41680908, 23.91903114], [68.41707611, 23.91903114], [68.41707611, 23.91930962], [68.41764069, 23.91930771], [68.41764069, 23.91958427], [68.41791534, 23.91958427], [68.41791534, 23.91986084], [68.41845703, 23.9198494], [68.41845703, 23.92014122], [68.41874695, 23.92014122], [68.41874695, 23.92041969], [68.41930389, 23.92041779], [68.41930389, 23.92069435], [68.41958618, 23.92069435], [68.41958618, 23.92097282], [68.4201355, 23.92097282], [68.4201355, 23.92124939], [68.42041779, 23.92124939], [68.42041779, 23.92152977], [68.42069244, 23.92152977], [68.42069244, 23.92180824], [68.42097473, 23.92180634], [68.42097473, 23.9220829], [68.42124939, 23.92207909], [68.42124939, 23.92263985], [68.42152405, 23.92263985], [68.42152405, 23.92319489], [68.42180634, 23.92318916], [68.42180634, 23.92375183], [68.42208099, 23.92375183], [68.42208099, 23.92431259], [68.42236328, 23.92430496], [68.42236328, 23.92486191], [68.42263794, 23.92486191], [68.42263794, 23.92514038], [68.42292023, 23.92513847], [68.42292023, 23.9256916], [68.42318726, 23.92570114], [68.42318726, 23.92597961], [68.42346954, 23.92597961], [68.42346954, 23.92653275], [68.42375183, 23.92653275], [68.42375183, 23.92681122], [68.42402649, 23.92681122], [68.42402649, 23.92736053], [68.42430878, 23.92736053], [68.42430878, 23.92764091], [68.42458344, 23.92763901], [68.42458344, 23.92819214], [68.42485809, 23.92819214], [68.42485809, 23.92847252], [68.42514038, 23.92847061], [68.42514038, 23.92904091], [68.42542267, 23.92904091], [68.42542267, 23.92930984], [68.42569733, 23.92930984], [68.42569733, 23.92986107], [68.42597198, 23.92986107], [68.42597198, 23.93041992], [68.42624664, 23.9304142], [68.42624664, 23.93097305], [68.42680359, 23.93097305], [68.42680359, 23.93180466], [68.42708588, 23.9317894], [68.42708588, 23.93292046], [68.42736053, 23.93291855], [68.42736053, 23.93347168], [68.42791748, 23.93346977], [68.42791748, 23.93375015], [68.4284668, 23.93375015], [68.4284668, 23.93403053], [68.42930603, 23.93403053], [68.42930603, 23.93431091], [68.42986298, 23.93430519], [68.42986298, 23.93458366], [68.43152618, 23.93457985], [68.43152618, 23.93486023], [68.43264008, 23.93486023], [68.43264008, 23.93514061], [68.43345642, 23.93514061], [68.43345642, 23.93541908], [68.43458557, 23.93541718], [68.43458557, 23.93569374], [68.43624878, 23.93569374], [68.43624878, 23.93597221], [68.43680573, 23.93597221], [68.43680573, 23.93569374], [68.43819427, 23.93569374], [68.43819427, 23.93541718], [68.43875122, 23.93541908], [68.43875122, 23.93514061], [68.43959045, 23.93514061], [68.43959045, 23.93486023], [68.43985748, 23.93486023], [68.43985748, 23.93457985], [68.44097137, 23.93457985], [68.44097137, 23.93486023], [68.44180298, 23.93486023], [68.44180298, 23.93514061], [68.44235992, 23.93514061], [68.44235992, 23.93541908], [68.44319153, 23.93541718], [68.44319153, 23.93569374], [68.44374847, 23.93569374], [68.44374847, 23.93597221], [68.44458008, 23.9359684], [68.44458008, 23.93625069], [68.44513702, 23.93625069], [68.44513702, 23.93652916], [68.44568634, 23.93652916], [68.44568634, 23.93680954], [68.44596863, 23.93680573], [68.44596863, 23.9370842], [68.44625092, 23.93707848], [68.44625092, 23.93736076], [68.4465332, 23.93736076], [68.4465332, 23.93763924], [68.44680786, 23.93763924], [68.44680786, 23.93791962], [68.44708252, 23.9379158], [68.44708252, 23.93819427], [68.44736481, 23.93819427], [68.44736481, 23.93847275], [68.44930267, 23.93847275], [68.44930267, 23.93819427], [68.45069122, 23.93819427], [68.45069122, 23.9379158], [68.45096588, 23.93791962], [68.45096588, 23.93763924], [68.45153046, 23.93763924], [68.45153046, 23.93736076], [68.45182037, 23.93736076], [68.45180511, 23.9370842], [68.45236206, 23.9370842], [68.45236206, 23.93680573], [68.45291901, 23.93680954], [68.45291901, 23.93652916], [68.45318604, 23.93652916], [68.45318604, 23.93625069], [68.45347595, 23.93625069], [68.45347595, 23.9359684], [68.45375061, 23.93597221], [68.45375061, 23.93569374], [68.45430756, 23.93569374], [68.45430756, 23.93541718], [68.45456696, 23.93541908], [68.45456696, 23.93514061], [68.45485687, 23.93514061], [68.45485687, 23.93486023], [68.45513916, 23.93486023], [68.45513916, 23.93457985], [68.45569611, 23.93458366], [68.45569611, 23.93430519], [68.45597076, 23.93431091], [68.45597076, 23.93346977], [68.45652771, 23.93347168], [68.45652771, 23.93291855], [68.45680237, 23.93292046], [68.45680237, 23.9323597], [68.45708466, 23.9323616], [68.45708466, 23.93180466], [68.45735931, 23.93180466], [68.45735931, 23.93152618], [68.45819092, 23.93153], [68.45819092, 23.93124962], [68.45874786, 23.93124962], [68.45874786, 23.93069077], [68.45847321, 23.93069649], [68.45847321, 23.9304142], [68.45735931, 23.93041992], [68.45735931, 23.93013954], [68.45625305, 23.93013954], [68.45625305, 23.92986107], [68.45569611, 23.92986107], [68.45569611, 23.92958069], [68.4548645, 23.9295826], [68.4548645, 23.92930412], [68.45456696, 23.92930984], [68.45456696, 23.92875099], [68.45430756, 23.92875099], [68.45430756, 23.92791939], [68.4540329, 23.92791939], [68.4540329, 23.92681122], [68.45375061, 23.92681122], [68.45375061, 23.9256916], [68.45347595, 23.92569351], [68.45347595, 23.92458344], [68.45319366, 23.92458344], [68.45319366, 23.9240284], [68.45291901, 23.9240303], [68.45291901, 23.92318916], [68.45263672, 23.92319489], [68.45263672, 23.92291641], [68.45236206, 23.92291832], [68.45236206, 23.92263985], [68.45207977, 23.92263985], [68.45207977, 23.92235756], [68.45180511, 23.92236137], [68.45180511, 23.9220829], [68.45153046, 23.9220829], [68.45153046, 23.92180634], [68.45124817, 23.92180824], [68.45124817, 23.92152977], [68.45096588, 23.92152977], [68.45096588, 23.92124939], [68.45041656, 23.92124939], [68.45041656, 23.92097092], [68.44958496, 23.92097282], [68.44958496, 23.92069435], [68.44930267, 23.92069435], [68.44930267, 23.92041779], [68.44819641, 23.92041969], [68.44819641, 23.92014122], [68.44763947, 23.92014122], [68.44763947, 23.9198494], [68.44458008, 23.91986084], [68.44458008, 23.91958427], [68.44430542, 23.91958237], [68.44430542, 23.91930771], [68.44403076, 23.91930962], [68.44403076, 23.91903114], [68.44431305, 23.91903114], [68.44431305, 23.91875076], [68.44458008, 23.91875076], [68.44458008, 23.91819], [68.44486237, 23.91819382], [68.44486237, 23.91791534], [68.44458008, 23.91792107], [68.44458008, 23.91736031], [68.44513702, 23.91736031], [68.44513702, 23.91764069], [68.44541931, 23.91764069], [68.44541931, 23.91792107], [68.44596863, 23.91791534], [68.44596863, 23.91819382], [68.44652557, 23.91819382], [68.44652557, 23.91847229], [68.44708252, 23.91847038], [68.44708252, 23.91875076], [68.44735718, 23.91875076], [68.44735718, 23.91903114], [68.44790649, 23.91903114], [68.44790649, 23.91930962], [68.44875336, 23.91930771], [68.44875336, 23.91958427], [68.44902802, 23.91958427], [68.44902802, 23.91930771], [68.44930267, 23.91930962], [68.44930267, 23.91875076], [68.44957733, 23.91875076], [68.44957733, 23.91847038], [68.44985962, 23.91847229], [68.44985962, 23.91819382], [68.45014191, 23.91819382], [68.45014191, 23.91763878], [68.45041656, 23.91764069], [68.45041656, 23.91736031], [68.45096588, 23.91736031], [68.45096588, 23.91707993], [68.45124817, 23.91708565], [68.45124817, 23.9165287], [68.45153046, 23.91653061], [68.45153046, 23.91596985], [68.45180511, 23.91597176], [68.45180511, 23.91486168], [68.45153046, 23.91486168], [68.45153046, 23.91430473], [68.45097351, 23.91430473], [68.45097351, 23.91458321], [68.45069122, 23.91458321], [68.45069122, 23.91486168], [68.45041656, 23.91485977], [68.45041656, 23.91542053], [68.44930267, 23.91542053], [68.44930267, 23.91514015], [68.44819641, 23.91514015], [68.44819641, 23.91457939], [68.44763947, 23.91458321], [68.44763947, 23.91486168], [68.44735718, 23.91485977], [68.44735718, 23.91542053], [68.44708252, 23.91542053], [68.44708252, 23.91570091], [68.44625092, 23.91570091], [68.44625092, 23.91542053], [68.44596863, 23.91542053], [68.44596863, 23.91457939], [68.44625092, 23.91458321], [68.44625092, 23.91402817], [68.44568634, 23.91403961], [68.44568634, 23.91374969], [68.44541931, 23.91374969], [68.44541931, 23.91347122], [68.44486237, 23.91347122], [68.44486237, 23.91319466], [68.44430542, 23.91319466], [68.44430542, 23.91263962], [68.44486237, 23.91263962], [68.44486237, 23.91292191], [68.44596863, 23.91291618], [68.44596863, 23.91319466], [68.44680786, 23.91319466], [68.44680786, 23.91347122], [68.44930267, 23.91347122], [68.44930267, 23.91374969], [68.45124817, 23.91374969], [68.45124817, 23.91347122], [68.45153046, 23.91347122], [68.45153046, 23.91291618], [68.45182037, 23.91292191], [68.45182037, 23.91124916], [68.45153046, 23.91124916], [68.45153046, 23.90903091], [68.45124817, 23.90903091], [68.45124817, 23.90790939], [68.45097351, 23.90791893], [68.45097351, 23.90680695], [68.45069122, 23.90681076], [68.45069122, 23.90570068], [68.45041656, 23.90570068], [68.45041656, 23.9054203], [68.44957733, 23.9054203], [68.44957733, 23.90570068], [68.44708252, 23.90570068], [68.44708252, 23.90625], [68.44680786, 23.90625], [68.44680786, 23.90653038], [68.4465332, 23.90653038], [68.4465332, 23.90681076], [68.44596863, 23.90681076], [68.44596863, 23.90764046], [68.44569397, 23.90763855], [68.44569397, 23.90791893], [68.44541931, 23.90791893], [68.44541931, 23.90763855], [68.44513702, 23.90764046], [68.44513702, 23.9070797], [68.44486237, 23.90708351], [68.44486237, 23.90736198], [68.44458008, 23.90735817], [68.44458008, 23.90764046], [68.44430542, 23.90763855], [68.44430542, 23.90791893], [68.44458008, 23.90791893], [68.44458008, 23.90819359], [68.44486237, 23.90818977], [68.44486237, 23.90875053], [68.44458008, 23.90875053], [68.44458008, 23.90903091], [68.44431305, 23.90903091], [68.44431305, 23.90930939], [68.44319153, 23.90930939], [68.44319153, 23.90903091], [68.44291687, 23.90903091], [68.44291687, 23.90818977], [68.44319153, 23.90819359], [68.44319153, 23.90791893], [68.44347382, 23.90791893], [68.44347382, 23.90763855], [68.44374847, 23.90764046], [68.44374847, 23.9070797], [68.44403076, 23.90708351], [68.44403076, 23.90680695], [68.44431305, 23.90681076], [68.44431305, 23.90596962], [68.44458008, 23.90597153], [68.44458008, 23.90569687], [68.44513702, 23.90570068], [68.44513702, 23.9054203], [68.44596863, 23.9054203], [68.44596863, 23.90513992], [68.44680786, 23.90513992], [68.44680786, 23.90485001], [68.44958496, 23.90486145], [68.44958496, 23.90458298], [68.45041656, 23.90458298], [68.45041656, 23.90374947], [68.45069122, 23.90374947], [68.45069122, 23.90208054], [68.45097351, 23.90208244], [68.45097351, 23.90013885], [68.44902802, 23.90014076], [68.44902802, 23.89903259], [68.44876099, 23.89903259], [68.44876099, 23.89847183], [68.44847107, 23.89847183], [68.44847107, 23.89819527], [68.44819641, 23.89819527], [68.44819641, 23.89847183], [68.44790649, 23.89847183], [68.44790649, 23.89875031], [68.44763947, 23.89875031], [68.44763947, 23.89903259], [68.44680786, 23.89903259], [68.44680786, 23.89875031], [68.44708252, 23.89875031], [68.44708252, 23.8982029], [68.44735718, 23.8982029], [68.44735718, 23.89792252], [68.44763947, 23.89792252], [68.44763947, 23.89764023], [68.44819641, 23.89764023], [68.44819641, 23.89708138], [68.44847107, 23.89708328], [68.44847107, 23.89291763], [68.44875336, 23.89291763], [68.44875336, 23.89208412], [68.44902802, 23.89208412], [68.44902802, 23.89180756], [68.44876099, 23.89180946], [68.44876099, 23.89153099], [68.44902802, 23.89153099], [68.44902802, 23.89125061], [68.44930267, 23.89125061], [68.44930267, 23.89042091], [68.44957733, 23.89042091], [68.44957733, 23.88986969], [68.44985962, 23.88986969], [68.44985962, 23.88792038], [68.45014191, 23.88792038], [68.45014191, 23.88735962], [68.45041656, 23.88736153], [68.45041656, 23.88680649], [68.45069122, 23.8868103], [68.45069122, 23.88624954], [68.45096588, 23.88624954], [68.45096588, 23.88513947], [68.45124817, 23.88513947], [68.45124817, 23.88431168], [68.45153046, 23.88431168], [68.45153046, 23.88373947], [68.45180511, 23.88375092], [68.45180511, 23.8829174], [68.45207977, 23.88291931], [68.45207977, 23.88180923], [68.45182037, 23.88180923], [68.45182037, 23.88153076], [68.45153046, 23.88153076], [68.45153046, 23.88125038], [68.45096588, 23.88125038], [68.45096588, 23.88096809], [68.45014191, 23.88097191], [68.45014191, 23.88069534], [68.44985962, 23.88069916], [68.44985962, 23.88042068], [68.44957733, 23.88042068], [68.44957733, 23.8801403], [68.44930267, 23.8801403], [68.44930267, 23.87985992], [68.44902802, 23.87986183], [68.44902802, 23.87958336], [68.44736481, 23.87958336], [68.44736481, 23.87930679], [68.44625092, 23.87930679], [68.44625092, 23.87902832], [68.44568634, 23.87903023], [68.44568634, 23.87874985], [68.44541931, 23.87874985], [68.44541931, 23.87846947], [68.44486237, 23.87847137], [68.44486237, 23.87819672], [68.44430542, 23.87819672], [68.44430542, 23.87847137], [68.44374847, 23.87847137], [68.44374847, 23.87791443], [68.44346619, 23.87792969], [68.44346619, 23.87763977], [68.44374847, 23.87763977], [68.44374847, 23.87681007], [68.44346619, 23.87681007], [68.44346619, 23.87652969], [68.44319153, 23.87652969], [68.44319153, 23.87569046], [68.44291687, 23.87569237], [68.44291687, 23.87513924], [68.44262695, 23.87514114], [68.44262695, 23.8748703], [68.4420929, 23.8748703], [68.4420929, 23.87430954], [68.44235992, 23.87430954], [68.44235992, 23.87403107], [68.4420929, 23.87403107], [68.4420929, 23.87125015], [68.44235992, 23.87125015], [68.44235992, 23.87070274], [68.4420929, 23.87070274], [68.4420929, 23.87042236], [68.44124603, 23.87042236], [68.44124603, 23.87014008], [68.44069672, 23.87014008], [68.44069672, 23.8698597], [68.44013977, 23.8698616], [68.44013977, 23.86958313], [68.43930817, 23.86958313], [68.43930817, 23.86930466], [68.43875122, 23.86930466], [68.43875122, 23.86902809], [68.43791962, 23.86902809], [68.43791962, 23.86874008], [68.43736267, 23.86874962], [68.43736267, 23.86847305], [68.43653107, 23.86847305], [68.43653107, 23.86819458], [68.43597412, 23.86819458], [68.43597412, 23.86791611], [68.43514252, 23.86791992], [68.43514252, 23.86763954], [68.43430328, 23.86763954], [68.43430328, 23.86736107], [68.43374634, 23.86736107], [68.43374634, 23.86708069], [68.43291473, 23.8670826], [68.43291473, 23.86680794], [68.43152618, 23.86680984], [68.43152618, 23.86652946], [68.43013763, 23.86652946], [68.43013763, 23.86625099], [68.42903137, 23.86625099], [68.42903137, 23.86597061], [68.42874908, 23.86597252], [68.42874908, 23.86569595], [68.42819214, 23.86569977], [68.42819214, 23.86541939], [68.42791748, 23.86541939], [68.42791748, 23.86514091], [68.42736053, 23.86514091], [68.42736053, 23.86486053], [68.42708588, 23.86486053], [68.42708588, 23.86458015], [68.42597198, 23.86458015], [68.42597198, 23.86486053], [68.42569733, 23.86486053], [68.42569733, 23.86514091], [68.42597198, 23.86514091], [68.42597198, 23.86541939], [68.42569733, 23.86541748], [68.42569733, 23.86597252], [68.42542267, 23.86597061], [68.42542267, 23.86625099], [68.42514038, 23.86625099], [68.42514038, 23.86680984], [68.42485809, 23.86680794], [68.42485809, 23.8670826], [68.42458344, 23.8670826], [68.42459106, 23.86736107], [68.42430878, 23.86736107], [68.42430878, 23.86763954], [68.42402649, 23.86763954], [68.42402649, 23.86791992], [68.42375183, 23.86791611], [68.42375183, 23.86819458], [68.42346954, 23.86819458], [68.42346954, 23.86847305], [68.42319489, 23.86847305], [68.42319489, 23.86874962], [68.42292023, 23.86874008], [68.42292023, 23.86902809], [68.42236328, 23.86902809], [68.42236328, 23.86930466], [68.42208099, 23.86930466], [68.42208099, 23.86958313], [68.42152405, 23.86958313], [68.42152405, 23.8698616], [68.42124939, 23.8698597], [68.42124939, 23.87014008], [68.42069244, 23.87014008], [68.42069244, 23.87042236], [68.42014313, 23.87042236], [68.42014313, 23.87070274], [68.41986084, 23.87069511], [68.41986084, 23.87097168], [68.41958618, 23.87097168], [68.41958618, 23.87208366], [68.41929626, 23.87208176], [68.41929626, 23.87236023], [68.41958618, 23.87236023], [68.41958618, 23.87264061], [68.41986084, 23.87264061], [68.41986084, 23.8729229], [68.4201355, 23.87291718], [68.4201355, 23.87347221], [68.42041779, 23.87347221], [68.42041779, 23.87458229], [68.42069244, 23.87458229], [68.42069244, 23.87708282], [68.42041779, 23.87708282], [68.42041779, 23.8773613], [68.4201355, 23.8773613], [68.42014313, 23.87763977], [68.41986084, 23.87763977], [68.41986084, 23.87792969], [68.41958618, 23.87791443], [68.41958618, 23.87819672], [68.41930389, 23.87819672], [68.41930389, 23.87847137], [68.41902924, 23.87846947], [68.41902924, 23.87874985], [68.41874695, 23.87874985], [68.41874695, 23.87903023], [68.41847229, 23.87902832], [68.41847229, 23.87930679], [68.41819763, 23.87930679], [68.41819763, 23.87958336], [68.41791534, 23.87958336], [68.41791534, 23.87986183], [68.41764069, 23.87985992], [68.41764069, 23.8801403], [68.4173584, 23.8801403], [68.4173584, 23.88042068], [68.41707611, 23.88042068], [68.41707611, 23.88069916], [68.41680908, 23.88069534], [68.41680908, 23.88097191], [68.41652679, 23.88096809], [68.41652679, 23.88125038], [68.41571045, 23.88125038], [68.41571045, 23.88153076], [68.41513824, 23.88153076], [68.41513824, 23.88180923], [68.41430664, 23.88180542], [68.41430664, 23.88208389], [68.41374969, 23.88207817], [68.41374969, 23.88236046], [68.41348267, 23.88236046], [68.41348267, 23.88264084], [68.41319275, 23.88264084], [68.41319275, 23.88291931], [68.41291809, 23.8829174], [68.41291809, 23.88319397], [68.4126358, 23.88319397], [68.4126358, 23.88347244], [68.41236115, 23.88347244], [68.41236115, 23.88375092], [68.41208649, 23.88373947], [68.41208649, 23.88402939], [68.41179657, 23.88402939], [68.41179657, 23.88431168], [68.41124725, 23.88430595], [68.41124725, 23.88458252], [68.4109726, 23.88458061], [68.4109726, 23.8848629], [68.41069794, 23.8848629], [68.41069794, 23.88542175], [68.4109726, 23.88541603], [68.4109726, 23.88597107], [68.41124725, 23.88597107], [68.41124725, 23.88624954], [68.41179657, 23.88624954], [68.41179657, 23.88652992], [68.41236115, 23.88652992], [68.41236115, 23.8868103], [68.41291809, 23.88680649], [68.41291809, 23.88708115], [68.41347504, 23.88708115], [68.41347504, 23.88736153], [68.41374969, 23.88735962], [68.41374969, 23.88764], [68.41401672, 23.88764], [68.41401672, 23.88820076], [68.41430664, 23.88819313], [68.41430664, 23.8884716], [68.41485596, 23.8884697], [68.41485596, 23.88875008], [68.41513824, 23.88875008], [68.41513824, 23.88903046], [68.4154129, 23.88902855], [68.4154129, 23.88958359], [68.41571045, 23.88957977], [68.41571045, 23.88986969]]], [[[68.5220871, 23.85625076], [68.52097321, 23.85625076], [68.52097321, 23.85652924], [68.52069092, 23.85652733], [68.52069092, 23.8568058], [68.51763916, 23.8568058], [68.51763916, 23.85652733], [68.51708221, 23.85652733], [68.51708221, 23.8568058], [68.51625061, 23.8568058], [68.51625061, 23.85708237], [68.51513672, 23.85707855], [68.51513672, 23.85736084], [68.51457977, 23.85736084], [68.51457977, 23.85763931], [68.51431274, 23.85763931], [68.51431274, 23.85791969], [68.51403046, 23.85791588], [68.51403046, 23.85819435], [68.51374817, 23.85819435], [68.51374817, 23.85847282], [68.51346588, 23.85847282], [68.51346588, 23.85931015], [68.51374817, 23.85931015], [68.51374817, 23.85902977], [68.51403046, 23.85902977], [68.51403046, 23.85931015], [68.51430511, 23.85930634], [68.51430511, 23.8595829], [68.51403046, 23.8595829], [68.51403046, 23.85986137], [68.51374817, 23.85985947], [68.51374817, 23.86013985], [68.51346588, 23.86013985], [68.51346588, 23.86042023], [68.51319122, 23.86041641], [68.51319122, 23.86069489], [68.51291656, 23.86069489], [68.51291656, 23.86097145], [68.51264191, 23.86096954], [68.51264191, 23.86124992], [68.51235962, 23.86124992], [68.51235962, 23.8615303], [68.51207733, 23.8615303], [68.51207733, 23.86181068], [68.51125336, 23.86180305], [68.51125336, 23.86208344], [68.51069641, 23.86208344], [68.51069641, 23.86236191], [68.51040649, 23.86236], [68.51040649, 23.86264038], [68.51013947, 23.86263847], [68.51013947, 23.86319351], [68.50986481, 23.86319351], [68.50986481, 23.86347198], [68.50930786, 23.86347198], [68.50930786, 23.86319351], [68.50902557, 23.86319351], [68.50902557, 23.86347198], [68.50874329, 23.86347008], [68.50874329, 23.86375046], [68.50818634, 23.86375046], [68.50818634, 23.86403084], [68.50763702, 23.86403084], [68.50763702, 23.86431122], [68.50569153, 23.8643074], [68.50569153, 23.86458588], [68.50541687, 23.86458015], [68.50541687, 23.86486053], [68.50485992, 23.86486053], [68.50485992, 23.86514091], [68.5045929, 23.86514091], [68.5045929, 23.86541939], [68.50402832, 23.86541939], [68.50402832, 23.86569977], [68.50319672, 23.86569595], [68.50319672, 23.86597252], [68.50263977, 23.86597061], [68.50263977, 23.86625099], [68.50125122, 23.86625099], [68.50125122, 23.86652946], [68.50041962, 23.86652946], [68.50041962, 23.86763954], [68.50013733, 23.86763954], [68.50013733, 23.86847305], [68.50041962, 23.86847115], [68.50041962, 23.87264061], [68.50069427, 23.8726387], [68.50069427, 23.87319374], [68.50096893, 23.87319374], [68.50096893, 23.87347221], [68.50125122, 23.87347031], [68.50125122, 23.87375069], [68.50180817, 23.87375069], [68.50180817, 23.87403107], [68.50208282, 23.87403107], [68.50208282, 23.87430954], [68.50235748, 23.87430954], [68.50235748, 23.87514114], [68.50208282, 23.87514114], [68.50208282, 23.87541962], [68.50125122, 23.87541962], [68.50125122, 23.87514114], [68.50068665, 23.87514114], [68.50068665, 23.8748703], [68.50013733, 23.8748703], [68.50013733, 23.87458038], [68.49986267, 23.87458229], [68.49986267, 23.87430573], [68.49958038, 23.87430954], [68.49958038, 23.87375069], [68.49930573, 23.87375069], [68.49930573, 23.87347221], [68.49903107, 23.87347221], [68.49903107, 23.87125015], [68.49874878, 23.87125015], [68.49874878, 23.87042236], [68.49903107, 23.87042236], [68.49903107, 23.86930084], [68.49874878, 23.86930466], [68.49874878, 23.86874962], [68.49847412, 23.86874962], [68.49847412, 23.86847305], [68.49819183, 23.86847305], [68.49819183, 23.86819458], [68.49791718, 23.86819458], [68.49791718, 23.86791611], [68.49736023, 23.86791992], [68.49736023, 23.86763954], [68.49708557, 23.86763954], [68.49708557, 23.8670826], [68.49514008, 23.8670826], [68.49514008, 23.86680794], [68.49373627, 23.86680984], [68.49373627, 23.86652946], [68.49291992, 23.86652946], [68.49291992, 23.86625099], [68.49263763, 23.86625099], [68.49263763, 23.86597061], [68.49236298, 23.86597252], [68.49236298, 23.86569595], [68.49208069, 23.86569595], [68.49208069, 23.86597252], [68.49153137, 23.86597061], [68.49153137, 23.86625099], [68.4909668, 23.86625099], [68.4909668, 23.86680984], [68.49069214, 23.86680794], [68.49069977, 23.86736107], [68.49041748, 23.86736107], [68.49041748, 23.86874962], [68.49013519, 23.86874962], [68.49013519, 23.86930466], [68.48986053, 23.86930466], [68.48986053, 23.87097168], [68.48958588, 23.87097168], [68.48958588, 23.87153053], [68.48929596, 23.87153053], [68.48929596, 23.87236023], [68.48902893, 23.87236023], [68.48902893, 23.8748703], [68.48874664, 23.87486076], [68.48874664, 23.87597275], [68.48847198, 23.87597275], [68.48847198, 23.87708282], [68.48819733, 23.87708282], [68.48819733, 23.87847137], [68.4879303, 23.87846947], [68.4879303, 23.87903023], [68.48764038, 23.87903023], [68.48764038, 23.8801403], [68.48735809, 23.88013649], [68.48735809, 23.88097191], [68.48708344, 23.88097191], [68.48708344, 23.88458252], [68.48680878, 23.88458061], [68.48680878, 23.8848629], [68.48652649, 23.8848629], [68.48652649, 23.8856945], [68.48625183, 23.8856926], [68.48625183, 23.88764], [68.48596954, 23.88764], [68.48596954, 23.88986969], [68.48625183, 23.88986969], [68.48625183, 23.89042091], [68.48652649, 23.89041519], [68.48652649, 23.89069366], [68.48680878, 23.89069366], [68.48680878, 23.89097214], [68.48764038, 23.89097023], [68.48764038, 23.89125061], [68.48819733, 23.89125061], [68.48819733, 23.89153099], [68.48902893, 23.89153099], [68.48902893, 23.89180946], [68.48958588, 23.89180756], [68.48958588, 23.89208412], [68.49041748, 23.89208031], [68.49041748, 23.89236069], [68.4909668, 23.89236069], [68.4909668, 23.89264107], [68.49180603, 23.89263916], [68.49180603, 23.89291763], [68.49236298, 23.89291763], [68.49236298, 23.8931942], [68.49319458, 23.8931942], [68.49319458, 23.89347267], [68.49373627, 23.89347076], [68.49373627, 23.89375114], [68.49430847, 23.89375114], [68.49430847, 23.89402962], [68.49485779, 23.89402962], [68.49485779, 23.89430809], [68.49541473, 23.89430618], [68.49541473, 23.89458275], [68.49597168, 23.89458084], [68.49597168, 23.89486122], [68.49652863, 23.89486122], [68.49652863, 23.89513969], [68.49736023, 23.89513969], [68.49736023, 23.89541817], [68.49791718, 23.89541626], [68.49791718, 23.89569473], [68.49847412, 23.89569473], [68.49847412, 23.8959713], [68.49903107, 23.89596748], [68.49903107, 23.89624977], [68.49958038, 23.89624977], [68.49958038, 23.89652824], [68.50013733, 23.89652824], [68.50013733, 23.89680481], [68.50041962, 23.89680481], [68.50041962, 23.89708328], [68.50096893, 23.89708328], [68.50096893, 23.89736176], [68.50125122, 23.89736176], [68.50125122, 23.89764023], [68.50180817, 23.89764023], [68.50180817, 23.89792252], [68.50208282, 23.89792252], [68.50208282, 23.8982029], [68.50263977, 23.89819527], [68.50263977, 23.89847183], [68.5029068, 23.89847183], [68.5029068, 23.89875031], [68.50319672, 23.89875031], [68.50319672, 23.89903259], [68.50347137, 23.89903259], [68.50347137, 23.89931107], [68.50375366, 23.89930534], [68.50375366, 23.89958382], [68.50402832, 23.89958191], [68.50402832, 23.89986038], [68.5045929, 23.89986038], [68.5045929, 23.90014076], [68.50485992, 23.90014076], [68.50485992, 23.90042114], [68.50514221, 23.90041733], [68.50514221, 23.90069389], [68.50541687, 23.90069389], [68.50541687, 23.90097237], [68.50567627, 23.90097046], [68.50567627, 23.90125084], [68.50596619, 23.90125084], [68.50596619, 23.90153122], [68.50653076, 23.90153122], [68.50653076, 23.90180969], [68.50708008, 23.90180588], [68.50708008, 23.90208244], [68.50736237, 23.90208054], [68.50736237, 23.90236092], [68.50791931, 23.90236092], [68.50791931, 23.90263939], [68.51097107, 23.90263939], [68.51097107, 23.90291977], [68.51208496, 23.90291405], [68.51208496, 23.90319443], [68.51347351, 23.90319443], [68.51347351, 23.90291405], [68.51374817, 23.90291977], [68.51374817, 23.90263939], [68.51403046, 23.90263939], [68.51403046, 23.90236092], [68.51431274, 23.90236092], [68.51430511, 23.90208244], [68.51457977, 23.90208244], [68.51457977, 23.90180588], [68.51513672, 23.90180969], [68.51513672, 23.90153122], [68.51541901, 23.90153122], [68.51541901, 23.90125084], [68.51568604, 23.90125084], [68.51568604, 23.90097046], [68.51597595, 23.90097237], [68.51597595, 23.90041733], [68.51568604, 23.90042114], [68.51568604, 23.90014076], [68.51597595, 23.90014076], [68.51597595, 23.89986038], [68.51625061, 23.89986038], [68.51625061, 23.89958191], [68.51680756, 23.89958382], [68.51680756, 23.89930534], [68.51708221, 23.89931107], [68.51708221, 23.89903259], [68.51735687, 23.89903259], [68.51735687, 23.89875031], [68.51763916, 23.89875031], [68.51763916, 23.89847183], [68.51791382, 23.89847183], [68.51791382, 23.89819527], [68.51819611, 23.8982029], [68.51819611, 23.89792252], [68.51847076, 23.89792252], [68.51847076, 23.89764023], [68.51875305, 23.89764023], [68.51875305, 23.89736176], [68.51902771, 23.89736176], [68.51902771, 23.89708328], [68.51958466, 23.89708328], [68.51958466, 23.89680481], [68.51985931, 23.89680481], [68.51985931, 23.89652824], [68.5201416, 23.89652824], [68.5201416, 23.89596748], [68.52041626, 23.8959713], [68.52041626, 23.89541626], [68.52068329, 23.89541817], [68.52068329, 23.89486122], [68.52097321, 23.89486122], [68.52097321, 23.89430809], [68.52236176, 23.89430809], [68.52236176, 23.89402962], [68.52348328, 23.89402962], [68.52348328, 23.89375114], [68.52404022, 23.89375114], [68.52404022, 23.89319038], [68.52430725, 23.8931942], [68.52430725, 23.89263916], [68.52458191, 23.89264107], [68.52458191, 23.89236069], [68.52540588, 23.89236069], [68.52540588, 23.89264107], [68.5256958, 23.89264107], [68.5256958, 23.89375114], [68.52541351, 23.89374733], [68.52541351, 23.89458275], [68.52513885, 23.89458084], [68.52513885, 23.89486122], [68.52458191, 23.89486122], [68.52458191, 23.89513969], [68.52430725, 23.89513969], [68.52430725, 23.89541817], [68.52319336, 23.89541626], [68.52319336, 23.89569473], [68.5229187, 23.89569473], [68.5229187, 23.8959713], [68.52263641, 23.89596748], [68.52263641, 23.89624977], [68.52236176, 23.89624977], [68.52236176, 23.89652824], [68.5220871, 23.89652824], [68.5220871, 23.89680481], [68.52180481, 23.89680481], [68.52180481, 23.89708328], [68.52153015, 23.89708138], [68.52153015, 23.89764023], [68.52097321, 23.89764023], [68.52097321, 23.89792252], [68.52069092, 23.89791679], [68.52069092, 23.89847183], [68.52041626, 23.89847183], [68.52041626, 23.89875031], [68.5201416, 23.89875031], [68.5201416, 23.89931107], [68.51985931, 23.89930534], [68.51985931, 23.89958382], [68.51957703, 23.89958191], [68.51957703, 23.89986038], [68.51930237, 23.89986038], [68.51930237, 23.90014076], [68.51902771, 23.90013885], [68.51902771, 23.90069389], [68.51875305, 23.90069389], [68.51875305, 23.90097237], [68.51847076, 23.90097046], [68.51847076, 23.90125084], [68.51819611, 23.90125084], [68.51819611, 23.90180969], [68.51791382, 23.90180588], [68.51791382, 23.90208244], [68.51763916, 23.90208054], [68.51763916, 23.90236092], [68.51708221, 23.90236092], [68.51708221, 23.90208054], [68.51597595, 23.90208054], [68.51597595, 23.90236092], [68.51568604, 23.90236092], [68.51568604, 23.90291977], [68.51541901, 23.90291405], [68.51541901, 23.90347481], [68.51486206, 23.90347481], [68.51486206, 23.90374947], [68.51431274, 23.90374947], [68.51431274, 23.90402985], [68.51403046, 23.90402794], [68.51403046, 23.90458298], [68.51430511, 23.90458298], [68.51430511, 23.90486145], [68.51457977, 23.90485001], [68.51457977, 23.90513992], [68.51513672, 23.90513992], [68.51513672, 23.9054203], [68.51541901, 23.9054203], [68.51541901, 23.90570068], [68.51597595, 23.90569687], [68.51597595, 23.90597153], [68.51680756, 23.90596962], [68.51680756, 23.90625], [68.51735687, 23.90625], [68.51735687, 23.90653038], [68.51763916, 23.90653038], [68.51763916, 23.90681076], [68.51791382, 23.90680695], [68.51791382, 23.90708351], [68.51847076, 23.90708351], [68.51847076, 23.90736198], [68.51875305, 23.90735817], [68.51875305, 23.90764046], [68.51902771, 23.90763855], [68.51902771, 23.90791893], [68.51930237, 23.90791893], [68.51930237, 23.90819359], [68.51985931, 23.90819359], [68.51985931, 23.90847206], [68.5201416, 23.90846825], [68.5201416, 23.90875053], [68.52041626, 23.90875053], [68.52041626, 23.90903091], [68.52097321, 23.90903091], [68.52097321, 23.90930939], [68.52153015, 23.90930557], [68.52153015, 23.90958405], [68.52179718, 23.90957832], [68.52179718, 23.90986061], [68.5220871, 23.90986061], [68.5220871, 23.91013908], [68.52236176, 23.91013908], [68.52236176, 23.91041946], [68.52263641, 23.91041756], [68.52263641, 23.91069412], [68.52319336, 23.9106884], [68.52319336, 23.91098022], [68.52348328, 23.91098022], [68.52348328, 23.91124916], [68.52404022, 23.91124916], [68.52404022, 23.91152954], [68.52430725, 23.91152954], [68.52430725, 23.91181183], [68.5248642, 23.91180611], [68.5248642, 23.91208267], [68.52513885, 23.91208267], [68.52513885, 23.91236115], [68.52540588, 23.91236115], [68.52540588, 23.91292191], [68.5256958, 23.91291618], [68.5256958, 23.91319466], [68.52597046, 23.91319275], [68.52597046, 23.91374969], [68.52625275, 23.91374969], [68.52625275, 23.91403961], [68.5265274, 23.91402817], [68.5265274, 23.91430473], [68.52680206, 23.91430473], [68.52680206, 23.91458321], [68.52708435, 23.91458321], [68.52708435, 23.91486168], [68.52735901, 23.91485977], [68.52735901, 23.91514015], [68.52874756, 23.91514015], [68.52874756, 23.91570091], [68.52902985, 23.91570091], [68.52902985, 23.91625023], [68.52929688, 23.91625023], [68.52929688, 23.91653061], [68.52958679, 23.91653061], [68.52958679, 23.91681099], [68.53013611, 23.91680336], [68.53013611, 23.91708565], [68.5304184, 23.91707993], [68.5304184, 23.91764069], [68.53069305, 23.91764069], [68.53069305, 23.91792107], [68.53097534, 23.91791534], [68.53097534, 23.91847229], [68.53125, 23.91847038], [68.53125, 23.91903114], [68.53152466, 23.91902542], [68.53152466, 23.91958427], [68.53180695, 23.91958046], [68.53180695, 23.92014122], [68.5320816, 23.92014122], [68.5320816, 23.92263985], [68.53180695, 23.92263985], [68.53180695, 23.92347145], [68.5320816, 23.92347145], [68.5320816, 23.92319489], [68.53236389, 23.92319489], [68.53236389, 23.92263985], [68.53263855, 23.92263985], [68.53263855, 23.92180824], [68.53291321, 23.92180824], [68.53291321, 23.92124939], [68.53320312, 23.92124939], [68.5331955, 23.92097282], [68.53347015, 23.92097282], [68.53347015, 23.92041779], [68.53375244, 23.92041969], [68.53375244, 23.92014122], [68.5340271, 23.92014122], [68.5340271, 23.91930962], [68.53430176, 23.91930962], [68.53430939, 23.91903114], [68.53457642, 23.91903114], [68.53457642, 23.91875076], [68.53514099, 23.91875076], [68.53514099, 23.91847038], [68.53541565, 23.91847229], [68.53541565, 23.91819382], [68.53569794, 23.91819382], [68.53569794, 23.91791534], [68.53598022, 23.91792107], [68.53598022, 23.91764069], [68.53652954, 23.91764069], [68.53652954, 23.91736031], [68.53736115, 23.91736031], [68.53736115, 23.91764069], [68.5376358, 23.91763878], [68.5376358, 23.91847229], [68.53736115, 23.91847038], [68.53736115, 23.91875076], [68.53708649, 23.91875076], [68.53708649, 23.91903114], [68.53652954, 23.91902542], [68.53652954, 23.91958237], [68.53624725, 23.91958427], [68.53624725, 23.91986084], [68.53569794, 23.9198494], [68.53569794, 23.92014122], [68.53541565, 23.92013931], [68.53541565, 23.92069435], [68.53514099, 23.92069435], [68.53514099, 23.92097282], [68.5348587, 23.92097092], [68.5348587, 23.92152977], [68.53457642, 23.92152977], [68.53457642, 23.92180824], [68.53430176, 23.92180634], [68.53430176, 23.92236137], [68.5340271, 23.92236137], [68.5340271, 23.92319489], [68.53375244, 23.92318916], [68.53375244, 23.9240303], [68.53347015, 23.9240303], [68.53347015, 23.92431259], [68.53291321, 23.92430496], [68.53291321, 23.92458344], [68.53235626, 23.92458153], [68.53235626, 23.92736053], [68.5320816, 23.92736053], [68.5320816, 23.93013954], [68.53180695, 23.93013954], [68.53180695, 23.93153], [68.53152466, 23.93152618], [68.53152466, 23.93208313], [68.53125, 23.93208122], [68.53125, 23.93320084], [68.53097534, 23.93319511], [68.53097534, 23.93347168], [68.53069305, 23.93346977], [68.53069305, 23.93375015], [68.5304184, 23.93375015], [68.5304184, 23.93403053], [68.53013611, 23.93403053], [68.53013611, 23.93431091], [68.52986145, 23.93430519], [68.52986145, 23.93458366], [68.52958679, 23.93457985], [68.52958679, 23.93486023], [68.52902985, 23.93486023], [68.52902985, 23.93514061], [68.52874756, 23.93514061], [68.52874756, 23.93541908], [68.5284729, 23.93541718], [68.5284729, 23.93569374], [68.52819824, 23.93568993], [68.52819061, 23.93625069], [68.52791595, 23.93625069], [68.52791595, 23.93652916], [68.5276413, 23.93652916], [68.5276413, 23.93680954], [68.52735901, 23.93680954], [68.52735901, 23.93736076], [68.52680969, 23.93736076], [68.52680969, 23.93763924], [68.5265274, 23.93763924], [68.5265274, 23.93875122], [68.52625275, 23.93875122], [68.52625275, 23.93931007], [68.52597046, 23.93930626], [68.52597046, 23.9398613], [68.5256958, 23.93985939], [68.5256958, 23.94013977], [68.52541351, 23.94013977], [68.52541351, 23.94069481], [68.5256958, 23.9406929], [68.5256958, 23.94098091], [68.52625275, 23.94098091], [68.52625275, 23.94124985], [68.5265274, 23.94124985], [68.5265274, 23.94153023], [68.52680206, 23.94152832], [68.52680206, 23.94180489], [68.52708435, 23.94180489], [68.52708435, 23.94236183], [68.52735901, 23.94235992], [68.52735901, 23.9426403], [68.5276413, 23.9426403], [68.5276413, 23.94292068], [68.52819061, 23.94292068], [68.52819824, 23.94320107], [68.5284729, 23.94319344], [68.5284729, 23.94347191], [68.52874756, 23.94347], [68.52874756, 23.94375038], [68.5293045, 23.94375038], [68.5293045, 23.94402695], [68.52958679, 23.94402122], [68.52958679, 23.94431114], [68.52986145, 23.94430733], [68.52986145, 23.9445858], [68.53180695, 23.94458008], [68.53180695, 23.94486046], [68.53235626, 23.94486046], [68.53235626, 23.94514084], [68.53263855, 23.94514084], [68.53263855, 23.94542122], [68.53291321, 23.9454155], [68.53291321, 23.94569588], [68.5348587, 23.94569588], [68.5348587, 23.94597244], [68.53541565, 23.94597244], [68.53541565, 23.94402695], [68.53624725, 23.94402695], [68.53624725, 23.94375038], [68.53708649, 23.94375038], [68.53708649, 23.94320107], [68.53736115, 23.94320107], [68.53736115, 23.9426403], [68.5376358, 23.9426403], [68.5376358, 23.94180107], [68.53791809, 23.94180489], [68.53791809, 23.94124985], [68.53819275, 23.94124985], [68.53819275, 23.94042015], [68.53848267, 23.94042015], [68.53848267, 23.93985939], [68.53874969, 23.9398613], [68.53874969, 23.93930626], [68.53901672, 23.93931007], [68.53901672, 23.93875122], [68.53930664, 23.93875122], [68.53930664, 23.93847275], [68.5395813, 23.93847275], [68.5395813, 23.9379158], [68.53985596, 23.93791962], [68.53985596, 23.93763924], [68.54013824, 23.93763924], [68.54013824, 23.93736076], [68.5404129, 23.93736076], [68.5404129, 23.93680954], [68.54070282, 23.93680954], [68.54070282, 23.93652916], [68.54096985, 23.93652916], [68.54096985, 23.9359684], [68.54125214, 23.93597221], [68.54125214, 23.93569374], [68.54152679, 23.93569374], [68.54152679, 23.9351387], [68.54180908, 23.93514061], [68.54180908, 23.93457985], [68.54208374, 23.93458366], [68.54208374, 23.93402863], [68.5423584, 23.93403053], [68.5423584, 23.93375015], [68.54292297, 23.93375015], [68.54291534, 23.93347168], [68.54374695, 23.93347168], [68.54374695, 23.93319511], [68.54429626, 23.93320084], [68.54429626, 23.93292046], [68.54514313, 23.93292046], [68.54514313, 23.93264008], [68.54680634, 23.93264008], [68.54680634, 23.9323597], [68.54846954, 23.9323616], [68.54846954, 23.93208313], [68.55180359, 23.93208313], [68.55180359, 23.93180466], [68.55708313, 23.93180466], [68.55708313, 23.93152618], [68.55735779, 23.93153], [68.55735779, 23.93124962], [68.55764008, 23.93124962], [68.55764008, 23.93097115], [68.55819702, 23.93097305], [68.55819702, 23.93069649], [68.55847168, 23.93069649], [68.55847168, 23.9304142], [68.55874634, 23.93041992], [68.55874634, 23.92958069], [68.55902863, 23.9295826], [68.55902863, 23.92847252], [68.55874634, 23.92847252], [68.55874634, 23.92763901], [68.55847168, 23.92764091], [68.55847168, 23.92708015], [68.55819702, 23.92708206], [68.55819702, 23.92625046], [68.5579071, 23.92625046], [68.5579071, 23.92375183], [68.55819702, 23.92375183], [68.55819702, 23.92347145], [68.55847168, 23.92347145], [68.55847168, 23.92319489], [68.55958557, 23.92319489], [68.55958557, 23.92291641], [68.56153107, 23.92291832], [68.56153107, 23.92263985], [68.56485748, 23.92263985], [68.56485748, 23.92291832], [68.57125092, 23.92291641], [68.57125092, 23.92319489], [68.57236481, 23.92319489], [68.57236481, 23.92347145], [68.57958221, 23.92347145], [68.57958221, 23.92319489], [68.58097076, 23.92319489], [68.58097076, 23.92291641], [68.5826416, 23.92291832], [68.5826416, 23.92263985], [68.58374786, 23.92263985], [68.58374786, 23.92235756], [68.5845871, 23.92236137], [68.5845871, 23.9220829], [68.5854187, 23.9220829], [68.5854187, 23.92180634], [68.58569336, 23.92180824], [68.58569336, 23.92152977], [68.58625031, 23.92152977], [68.58625031, 23.92124939], [68.58680725, 23.92124939], [68.58680725, 23.92152977], [68.58790588, 23.92152977], [68.58790588, 23.92014122], [68.5881958, 23.92014122], [68.5881958, 23.91958046], [68.58847046, 23.91958427], [68.58847046, 23.91875076], [68.58875275, 23.91875076], [68.58875275, 23.91681099], [68.58847046, 23.91681099], [68.58847046, 23.91653061], [68.58763885, 23.91653061], [68.58763885, 23.91625023], [68.58652496, 23.91625023], [68.58652496, 23.91597176], [68.5854187, 23.91597176], [68.5854187, 23.91569328], [68.58429718, 23.91570091], [68.58429718, 23.91542053], [68.58319092, 23.91542053], [68.58319092, 23.91514015], [68.58207703, 23.91514015], [68.58207703, 23.91485977], [68.58152771, 23.91486168], [68.58152771, 23.91458321], [68.58125305, 23.91458321], [68.58125305, 23.91430473], [68.58069611, 23.91430473], [68.58069611, 23.91402817], [68.58013916, 23.91403961], [68.58013916, 23.91374969], [68.57958221, 23.91374969], [68.57958221, 23.91347122], [68.57930756, 23.91347122], [68.57930756, 23.91319466], [68.57875061, 23.91319466], [68.57875061, 23.91291618], [68.57847595, 23.91292191], [68.57847595, 23.91263962], [68.57791901, 23.91263962], [68.57791901, 23.91236115], [68.57763672, 23.91236115], [68.57763672, 23.91208267], [68.57736206, 23.91208267], [68.57736206, 23.91180611], [68.57707977, 23.91181183], [68.57707977, 23.91152954], [68.57653046, 23.91152954], [68.57653046, 23.91124916], [68.57624817, 23.91124916], [68.57624817, 23.91098022], [68.57596588, 23.91098022], [68.57596588, 23.9106884], [68.57541656, 23.91069412], [68.57541656, 23.91041756], [68.57514954, 23.91041946], [68.57514954, 23.91013908], [68.57485962, 23.91013908], [68.57485962, 23.90986061], [68.57457733, 23.90986061], [68.57457733, 23.90957832], [68.57430267, 23.90958405], [68.57430267, 23.90930557], [68.57375336, 23.90930939], [68.57375336, 23.90903091], [68.57319641, 23.90903091], [68.57319641, 23.90875053], [68.57263947, 23.90875053], [68.57263947, 23.90846825], [68.57208252, 23.90847206], [68.57208252, 23.90819359], [68.57180786, 23.90819359], [68.57180786, 23.90791893], [68.57152557, 23.90791893], [68.57152557, 23.90736198], [68.57125092, 23.90736198], [68.57125092, 23.90708351], [68.57069397, 23.90708351], [68.57069397, 23.90680695], [68.57041931, 23.90681076], [68.57041931, 23.90653038], [68.57013702, 23.90653038], [68.57013702, 23.90596962], [68.56958008, 23.90597153], [68.56958008, 23.90569687], [68.56931305, 23.90570068], [68.56931305, 23.9054203], [68.56902313, 23.9054203], [68.56902313, 23.90513992], [68.56874847, 23.90513992], [68.56874847, 23.90458107], [68.56819153, 23.90458298], [68.56819153, 23.9043045], [68.56791687, 23.90431023], [68.56791687, 23.90402985], [68.56764221, 23.90402985], [68.56764221, 23.90374947], [68.56735992, 23.90374947], [68.56735992, 23.90347099], [68.56708527, 23.90347481], [68.56708527, 23.90263939], [68.56680298, 23.90263939], [68.56680298, 23.90236092], [68.56652832, 23.90236092], [68.56652832, 23.90208054], [68.56625366, 23.90208244], [68.56625366, 23.9015274], [68.56595612, 23.90153122], [68.56595612, 23.90125084], [68.56569672, 23.90125084], [68.56569672, 23.90042114], [68.5654068, 23.90042114], [68.5654068, 23.90014076], [68.56595612, 23.90014076], [68.56595612, 23.89986038], [68.56624603, 23.89986038], [68.56624603, 23.89958191], [68.56680298, 23.89958382], [68.56680298, 23.89930534], [68.5670929, 23.89931107], [68.5670929, 23.89903259], [68.56735992, 23.89903259], [68.56735992, 23.89875031], [68.56708527, 23.89875031], [68.56708527, 23.89819527], [68.56680298, 23.8982029], [68.56680298, 23.89764023], [68.56652832, 23.89764023], [68.56652832, 23.89708138], [68.56625366, 23.89708328], [68.56625366, 23.89680481], [68.56597137, 23.89680481], [68.56597137, 23.89624977], [68.56569672, 23.89624977], [68.56569672, 23.89567947], [68.56541443, 23.89569473], [68.56541443, 23.89541626], [68.56513977, 23.89541817], [68.56513977, 23.89486122], [68.56485748, 23.89486122], [68.56485748, 23.89430809], [68.56458282, 23.89430809], [68.56458282, 23.89375114], [68.56430817, 23.89375114], [68.56430817, 23.89347076], [68.56402588, 23.89347267], [68.56402588, 23.8931942], [68.56375122, 23.8931942], [68.56375122, 23.89291763], [68.56319427, 23.89291763], [68.56319427, 23.89263916], [68.56291962, 23.89264107], [68.56291962, 23.89236069], [68.56263733, 23.89236069], [68.56263733, 23.89208031], [68.56236267, 23.89208412], [68.56236267, 23.89180756], [68.56181335, 23.89180946], [68.56181335, 23.89153099], [68.56153107, 23.89153099], [68.56153107, 23.89125061], [68.56124878, 23.89125061], [68.56124878, 23.89097023], [68.56097412, 23.89097214], [68.56097412, 23.89041519], [68.56069183, 23.89042091], [68.56069183, 23.89014053], [68.56041718, 23.89014053], [68.56041718, 23.88986969], [68.56014252, 23.88986969], [68.56014252, 23.88931084], [68.55986023, 23.88931084], [68.55986023, 23.88903046], [68.5595932, 23.88903046], [68.5595932, 23.88875008], [68.55930328, 23.88875008], [68.55930328, 23.8884697], [68.55902863, 23.8884716], [68.55902863, 23.88791656], [68.55874634, 23.88792038], [68.55874634, 23.88764], [68.55847168, 23.88764], [68.55847168, 23.88735962], [68.55819702, 23.88736153], [68.55819702, 23.88708115], [68.55791473, 23.88708115], [68.55791473, 23.88680649], [68.55764008, 23.8868103], [68.55764008, 23.88652992], [68.55735779, 23.88652992], [68.55735779, 23.88597107], [68.55708313, 23.88597107], [68.55708313, 23.8856945], [68.55680847, 23.8856945], [68.55680847, 23.88541603], [68.55652618, 23.88542175], [68.55652618, 23.88513947], [68.55625153, 23.88513947], [68.55625153, 23.88458061], [68.55596924, 23.88458252], [68.55596924, 23.88402748], [68.55568695, 23.88402939], [68.55568695, 23.88347054], [68.55541992, 23.88347244], [68.55541992, 23.8829174], [68.55513763, 23.88291931], [68.55513763, 23.88264084], [68.55486298, 23.88264084], [68.55486298, 23.88236046], [68.55458069, 23.88236046], [68.55458069, 23.88180923], [68.55430603, 23.88180923], [68.55430603, 23.88153076], [68.55401611, 23.88153076], [68.55401611, 23.88125038], [68.55374908, 23.88125038], [68.55374908, 23.88096809], [68.55319214, 23.88097191], [68.55319214, 23.88069534], [68.55291748, 23.88069916], [68.55291748, 23.88042068], [68.55264282, 23.88042068], [68.55264282, 23.8801403], [68.55208588, 23.8801403], [68.55208588, 23.87985992], [68.55180359, 23.87986183], [68.55180359, 23.87958336], [68.55152893, 23.87958336], [68.55152893, 23.87930679], [68.55097198, 23.87930679], [68.55097198, 23.87902832], [68.55069733, 23.87903023], [68.55069733, 23.87874985], [68.55014038, 23.87874985], [68.55014038, 23.87846947], [68.54930878, 23.87847137], [68.54930878, 23.87569237], [68.54902649, 23.87569237], [68.54902649, 23.87513924], [68.54875183, 23.87514114], [68.54875183, 23.8748703], [68.54846954, 23.8748703], [68.54846954, 23.87458038], [68.54819489, 23.87458229], [68.54819489, 23.87430573], [68.54792023, 23.87430954], [68.54792023, 23.87403107], [68.54763794, 23.87403107], [68.54763794, 23.87375069], [68.54736328, 23.87375069], [68.54736328, 23.87347031], [68.54708099, 23.87347221], [68.54708099, 23.87319374], [68.54680634, 23.87319374], [68.54680634, 23.87291718], [68.54624939, 23.8729229], [68.54624939, 23.87264061], [68.54569244, 23.87264061], [68.54569244, 23.87236023], [68.5451355, 23.87236023], [68.5451355, 23.87208366], [68.54486084, 23.87208366], [68.54486084, 23.87180519], [68.54319763, 23.87180519], [68.54319763, 23.87208366], [68.54264069, 23.87208366], [68.54264069, 23.87180519], [68.5423584, 23.87180519], [68.5423584, 23.87152863], [68.54207611, 23.87153053], [68.54207611, 23.87125015], [68.54180908, 23.87125015], [68.54180908, 23.87097168], [68.54152679, 23.87097168], [68.54152679, 23.87069511], [68.54125214, 23.87070274], [68.54125214, 23.87042236], [68.54096985, 23.87042236], [68.54096985, 23.87014008], [68.54070282, 23.87014008], [68.54070282, 23.8698597], [68.5404129, 23.8698616], [68.5404129, 23.86958313], [68.54013824, 23.86958313], [68.54013824, 23.86930466], [68.53986359, 23.86930466], [68.53986359, 23.86902809], [68.5395813, 23.86902809], [68.5395813, 23.86874008], [68.53930664, 23.86874962], [68.53930664, 23.86847305], [68.53874969, 23.86847305], [68.53874969, 23.86819458], [68.53847504, 23.86819458], [68.53847504, 23.86791611], [68.53819275, 23.86791992], [68.53819275, 23.86763954], [68.53791809, 23.86763954], [68.53791809, 23.86736107], [68.53708649, 23.86736107], [68.53708649, 23.86958313], [68.53736115, 23.86958122], [68.53736115, 23.87070274], [68.5376358, 23.87069511], [68.5376358, 23.87097168], [68.53624725, 23.87097168], [68.53624725, 23.87180519], [68.53598022, 23.87179947], [68.53598022, 23.8729229], [68.53624725, 23.8729229], [68.53624725, 23.87403107], [68.53652954, 23.87403107], [68.53652954, 23.87430954], [68.5368042, 23.87430573], [68.5368042, 23.87458229], [68.53652954, 23.87458038], [68.53652954, 23.8748703], [68.53679657, 23.8748703], [68.53679657, 23.87541962], [68.5359726, 23.8754158], [68.5359726, 23.87569237], [68.53569794, 23.87569046], [68.53569794, 23.87625122], [68.53263855, 23.87625122], [68.53263855, 23.87597084], [68.53236389, 23.87597275], [68.53236389, 23.87569237], [68.5320816, 23.87569237], [68.5320816, 23.8754158], [68.53180695, 23.87541962], [68.53180695, 23.8748703], [68.53125, 23.8748703], [68.53125, 23.87458038], [68.53097534, 23.87458229], [68.53097534, 23.87375069], [68.53069305, 23.87375069], [68.53069305, 23.87347031], [68.5304184, 23.87347221], [68.5304184, 23.87291718], [68.53013611, 23.8729229], [68.53013611, 23.87264061], [68.52984619, 23.87264061], [68.52984619, 23.87236023], [68.52958679, 23.87236023], [68.52958679, 23.87208176], [68.5293045, 23.87208366], [68.5293045, 23.87152863], [68.52902985, 23.87153053], [68.52902985, 23.87070274], [68.52874756, 23.87070274], [68.52874756, 23.87014008], [68.5284729, 23.87014008], [68.5284729, 23.86958122], [68.52819824, 23.86958313], [68.52819824, 23.86874962], [68.52791595, 23.86874962], [68.52791595, 23.86763954], [68.5276413, 23.86763954], [68.5276413, 23.86736107], [68.52735901, 23.86736107], [68.52735901, 23.86680984], [68.52707672, 23.86680984], [68.52707672, 23.86625099], [68.52680969, 23.86625099], [68.52680969, 23.86597061], [68.5265274, 23.86597252], [68.5265274, 23.8651371], [68.52625275, 23.86514091], [68.52625275, 23.86486053], [68.52597046, 23.86486053], [68.52597046, 23.86458015], [68.5256958, 23.86458588], [68.5256958, 23.86402512], [68.52540588, 23.86403084], [68.52540588, 23.86375046], [68.52513885, 23.86375046], [68.52513885, 23.86347008], [68.5248642, 23.86347198], [68.5248642, 23.86319351], [68.52458191, 23.86319351], [68.52458191, 23.86263847], [68.52430725, 23.86264038], [68.52430725, 23.86236], [68.52402496, 23.86236191], [68.52402496, 23.86180305], [68.52375031, 23.86181068], [68.52375031, 23.8615303], [68.52348328, 23.8615303], [68.52348328, 23.86124992], [68.52319336, 23.86124992], [68.52319336, 23.86069107], [68.5229187, 23.86069489], [68.5229187, 23.86013794], [68.52263641, 23.86013985], [68.52263641, 23.85957146], [68.52236176, 23.8595829], [68.52236176, 23.85874939], [68.52263641, 23.85874939], [68.52263641, 23.85847282], [68.52236176, 23.85847282], [68.52236176, 23.85736084], [68.5220871, 23.85736084], [68.5220871, 23.85625076]]], [[[68.47930908, 23.88820076], [68.47902679, 23.88820076], [68.47902679, 23.88708115], [68.47875214, 23.88708115], [68.47875214, 23.88624954], [68.47846985, 23.88624954], [68.47846985, 23.88291931], [68.47820282, 23.88291931], [68.47820282, 23.88207817], [68.4779129, 23.88208389], [68.4779129, 23.88152885], [68.47763824, 23.88153076], [68.47763824, 23.88096809], [68.47736359, 23.88097191], [68.47736359, 23.88041878], [68.4770813, 23.88042068], [68.4770813, 23.87957954], [68.47680664, 23.87958336], [68.47680664, 23.87874985], [68.47651672, 23.87874985], [68.47651672, 23.87819099], [68.47624969, 23.87819672], [68.47624969, 23.8773613], [68.47597504, 23.8773613], [68.47597504, 23.87652779], [68.47570038, 23.87652969], [68.47570038, 23.87597084], [68.47541809, 23.87597275], [68.47541809, 23.87513924], [68.4751358, 23.87514114], [68.4751358, 23.87403107], [68.47486115, 23.87403107], [68.47486115, 23.8729229], [68.47458649, 23.8729229], [68.47458649, 23.87179947], [68.4743042, 23.87180519], [68.4743042, 23.87069511], [68.47402954, 23.87070274], [68.47402954, 23.86930084], [68.47374725, 23.86930466], [68.47374725, 23.86819458], [68.4734726, 23.86819458], [68.4734726, 23.86763954], [68.47319794, 23.86763954], [68.47319794, 23.86680984], [68.47292328, 23.86680984], [68.47292328, 23.8629303], [68.47264099, 23.8629303], [68.47264099, 23.86264038], [68.4723587, 23.86264038], [68.4723587, 23.86207962], [68.47208405, 23.86208344], [68.47208405, 23.86180305], [68.47180939, 23.86181068], [68.47180176, 23.8615303], [68.46848297, 23.8615303], [68.46848297, 23.86124992], [68.4679184, 23.86124992], [68.4679184, 23.86096954], [68.46736145, 23.86097145], [68.46736145, 23.86069489], [68.46485901, 23.86069489], [68.46485901, 23.86041641], [68.46376038, 23.86042023], [68.46376038, 23.86013985], [68.46347046, 23.86013985], [68.46347046, 23.85985947], [68.4631958, 23.85986137], [68.4631958, 23.8595829], [68.46263885, 23.8595829], [68.46263885, 23.85930634], [68.46208191, 23.85931015], [68.46208191, 23.85902977], [68.46125031, 23.85902977], [68.46125031, 23.85874939], [68.4604187, 23.85874939], [68.4604187, 23.85847282], [68.46013641, 23.85847282], [68.46013641, 23.85819435], [68.45986176, 23.85819435], [68.45986176, 23.85736084], [68.4595871, 23.85736084], [68.4595871, 23.85707855], [68.45930481, 23.85708237], [68.45930481, 23.85652733], [68.45874786, 23.85652924], [68.45874786, 23.85625076], [68.45707703, 23.85625076], [68.45707703, 23.85597038], [68.45625305, 23.85597229], [68.45625305, 23.85569382], [68.45541382, 23.85569382], [68.45541382, 23.85541725], [68.45485687, 23.85541916], [68.45485687, 23.85514069], [68.45430756, 23.85514069], [68.45430756, 23.85486031], [68.45347595, 23.85486031], [68.45347595, 23.85457993], [68.45291901, 23.85458374], [68.45291901, 23.85430527], [68.45236206, 23.85430908], [68.45236206, 23.85403061], [68.45207977, 23.85403061], [68.45207977, 23.85375977], [68.45153046, 23.85375977], [68.45153046, 23.85346985], [68.45097351, 23.85347176], [68.45097351, 23.85319519], [68.45069122, 23.85320091], [68.45069122, 23.85292053], [68.45041656, 23.85292053], [68.45041656, 23.85264015], [68.45014191, 23.85264015], [68.45014191, 23.85235977], [68.44985962, 23.85236168], [68.44985962, 23.85180664], [68.44930267, 23.85180664], [68.44930267, 23.85124969], [68.44902802, 23.85124969], [68.44902802, 23.85070038], [68.44847107, 23.85069656], [68.44847107, 23.85097313], [68.44708252, 23.85097313], [68.44708252, 23.85069656], [68.44625092, 23.85070038], [68.44625092, 23.85042], [68.44596863, 23.85042], [68.44596863, 23.85013962], [68.44541931, 23.85013962], [68.44541931, 23.84986115], [68.44486237, 23.84986115], [68.44486237, 23.84958076], [68.44458008, 23.84958267], [68.44458008, 23.8493042], [68.44431305, 23.84930992], [68.44431305, 23.84902954], [68.44403076, 23.84902954], [68.44403076, 23.84847069], [68.44346619, 23.84847069], [68.44346619, 23.84875107], [68.44291687, 23.84875107], [68.44291687, 23.84902954], [68.44235992, 23.84902954], [68.44235992, 23.84930992], [68.44208527, 23.8493042], [68.44208527, 23.84958267], [68.44152832, 23.84958076], [68.44152832, 23.84986115], [68.44097137, 23.84986115], [68.44097137, 23.85013962], [68.4404068, 23.85013962], [68.4404068, 23.85042], [68.44013977, 23.85042], [68.44013977, 23.85070038], [68.43902588, 23.85069656], [68.43902588, 23.85097313], [68.43791962, 23.85097122], [68.43791962, 23.85124969], [68.43708038, 23.85124969], [68.43708038, 23.85153008], [68.43653107, 23.85152626], [68.43653107, 23.85180664], [68.43569183, 23.85180664], [68.43569183, 23.85208321], [68.43235779, 23.85208321], [68.43235779, 23.85236168], [68.43208313, 23.85235977], [68.43208313, 23.85264015], [68.43180847, 23.85264015], [68.43180847, 23.85292053], [68.43152618, 23.85292053], [68.43152618, 23.85320091], [68.43125153, 23.85320091], [68.43125153, 23.85403061], [68.43096924, 23.85403061], [68.43096924, 23.85486031], [68.43069458, 23.85486031], [68.43069458, 23.85569382], [68.43041992, 23.8556881], [68.43041992, 23.85625076], [68.43013763, 23.85625076], [68.43013763, 23.85708237], [68.42986298, 23.85707855], [68.42986298, 23.85763931], [68.42958069, 23.85763931], [68.42958069, 23.85791969], [68.42930603, 23.85791588], [68.42930603, 23.85819435], [68.42903137, 23.85819435], [68.42903137, 23.85847282], [68.42874908, 23.85847282], [68.42874908, 23.85931015], [68.42847443, 23.85930634], [68.42847443, 23.85986137], [68.42819214, 23.85985947], [68.42819214, 23.86181068], [68.42874908, 23.86180305], [68.42874908, 23.86208344], [68.42903137, 23.86208344], [68.42903137, 23.86236191], [68.42986298, 23.86236], [68.42986298, 23.86264038], [68.43041992, 23.86264038], [68.43041992, 23.8629303], [68.43125153, 23.86291695], [68.43125153, 23.8631897], [68.43180847, 23.86319351], [68.43180847, 23.86347198], [68.43235779, 23.86347008], [68.43235779, 23.86375046], [68.43402863, 23.86375046], [68.43402863, 23.86403084], [68.43430328, 23.86403084], [68.43430328, 23.86431122], [68.43486023, 23.8643074], [68.43486023, 23.86458588], [68.43541718, 23.86458015], [68.43541718, 23.86486053], [68.43569183, 23.86486053], [68.43569183, 23.86514091], [68.43624878, 23.86514091], [68.43624878, 23.86541939], [68.43653107, 23.86541939], [68.43653107, 23.86569977], [68.43708038, 23.86569595], [68.43708038, 23.86597252], [68.43763733, 23.86597061], [68.43763733, 23.86625099], [68.43930817, 23.86625099], [68.43930817, 23.86652946], [68.43985748, 23.86652946], [68.43985748, 23.86680984], [68.44013977, 23.86680794], [68.44013977, 23.8670826], [68.4404068, 23.86708069], [68.4404068, 23.86736107], [68.44097137, 23.86736107], [68.44097137, 23.86763954], [68.44124603, 23.86763954], [68.44124603, 23.86791992], [68.44152832, 23.86791611], [68.44152832, 23.86819458], [68.44208527, 23.86819458], [68.44208527, 23.86847305], [68.44235992, 23.86847305], [68.44235992, 23.86874962], [68.44262695, 23.86874008], [68.44262695, 23.86902809], [68.44291687, 23.86902809], [68.44291687, 23.86930466], [68.44319153, 23.86930466], [68.44319153, 23.86958313], [68.44347382, 23.86958313], [68.44347382, 23.8698616], [68.44374847, 23.8698597], [68.44374847, 23.87014008], [68.44430542, 23.87013817], [68.44430542, 23.87097168], [68.44458008, 23.87097168], [68.44458008, 23.87347221], [68.44486237, 23.87347031], [68.44486237, 23.8748703], [68.44513702, 23.8748703], [68.44513702, 23.87541962], [68.44541931, 23.87541962], [68.44541931, 23.87625122], [68.44596863, 23.87625122], [68.44596863, 23.87652969], [68.44680786, 23.87652779], [68.44680786, 23.87708282], [68.44902802, 23.87708282], [68.44902802, 23.8773613], [68.44985962, 23.87735939], [68.44985962, 23.87763977], [68.45069122, 23.87763977], [68.45069122, 23.87792969], [68.45124817, 23.87791443], [68.45124817, 23.87819672], [68.45153046, 23.87819672], [68.45153046, 23.87847137], [68.45182037, 23.87846947], [68.45182037, 23.87903023], [68.45236206, 23.87902832], [68.45236206, 23.87930679], [68.45263672, 23.87930679], [68.45263672, 23.87958336], [68.45291901, 23.87958336], [68.45291901, 23.87986183], [68.45318604, 23.87985992], [68.45318604, 23.88153076], [68.45347595, 23.88153076], [68.45347595, 23.88180923], [68.45375061, 23.88180542], [68.45375061, 23.88458252], [68.45347595, 23.88458061], [68.45347595, 23.8848629], [68.45318604, 23.8848629], [68.45318604, 23.88542175], [68.45291901, 23.88542175], [68.45291901, 23.88624954], [68.45263672, 23.88624954], [68.45263672, 23.88708115], [68.45236206, 23.88708115], [68.45236206, 23.88820076], [68.45207977, 23.88820076], [68.45207977, 23.88903046], [68.45182037, 23.88903046], [68.45182037, 23.88931084], [68.45153046, 23.88930321], [68.45153046, 23.89069366], [68.45124817, 23.89068985], [68.45124817, 23.89236069], [68.45097351, 23.89236069], [68.45097351, 23.89291763], [68.45069122, 23.89291763], [68.45069122, 23.8931942], [68.45041656, 23.8931942], [68.45041656, 23.89347267], [68.45069122, 23.89347076], [68.45069122, 23.89430809], [68.45096588, 23.89430809], [68.45096588, 23.89513969], [68.45124817, 23.89513969], [68.45124817, 23.89569473], [68.45153046, 23.89569473], [68.45153046, 23.8959713], [68.45182037, 23.89596748], [68.45182037, 23.89652824], [68.45207977, 23.89652824], [68.45207977, 23.89708328], [68.45236206, 23.89708138], [68.45236206, 23.89792252], [68.45263672, 23.89792252], [68.45263672, 23.89931107], [68.45291901, 23.89931107], [68.45291901, 23.90042114], [68.45318604, 23.90042114], [68.45318604, 23.90125084], [68.45291901, 23.90125084], [68.45291901, 23.90374947], [68.45263672, 23.90374947], [68.45263672, 23.9054203], [68.45291901, 23.90541458], [68.45291901, 23.90791893], [68.45319366, 23.90791893], [68.45319366, 23.90847206], [68.45347595, 23.90846825], [68.45347595, 23.90875053], [68.45430756, 23.90875053], [68.45430756, 23.90903091], [68.45485687, 23.90903091], [68.45485687, 23.90930939], [68.45513916, 23.90930557], [68.45513916, 23.90958405], [68.45540619, 23.90957832], [68.45540619, 23.90986061], [68.45652771, 23.90986061], [68.45652771, 23.90957832], [68.45762634, 23.90957832], [68.45762634, 23.90986061], [68.45735931, 23.90986061], [68.45735931, 23.91013908], [68.45680237, 23.91013908], [68.45680237, 23.91041946], [68.45652771, 23.91041756], [68.45652771, 23.91069412], [68.45680237, 23.9106884], [68.45680237, 23.91098022], [68.45707703, 23.91098022], [68.45707703, 23.91124916], [68.45735931, 23.91124916], [68.45735931, 23.91152954], [68.45762634, 23.91152954], [68.45762634, 23.91181183], [68.45791626, 23.91180611], [68.45791626, 23.91208267], [68.45819092, 23.91208267], [68.45819092, 23.91458321], [68.45791626, 23.91457939], [68.45791626, 23.91570091], [68.45735931, 23.91570091], [68.45735931, 23.91514015], [68.45707703, 23.91514015], [68.45707703, 23.91457939], [68.45680237, 23.91458321], [68.45680237, 23.91374969], [68.45652771, 23.91374969], [68.45652771, 23.91319275], [68.45625305, 23.91319466], [68.45625305, 23.91291618], [68.45569611, 23.91292191], [68.45569611, 23.91263962], [68.45540619, 23.91263962], [68.45540619, 23.91236115], [68.45485687, 23.91236115], [68.45485687, 23.91208267], [68.45430756, 23.91208267], [68.45430756, 23.91236115], [68.4540329, 23.91236115], [68.4540329, 23.91292191], [68.45430756, 23.91292191], [68.45430756, 23.91374969], [68.4540329, 23.91374969], [68.4540329, 23.91403961], [68.45375061, 23.91403961], [68.45375061, 23.91570091], [68.45402527, 23.91569328], [68.45402527, 23.91597176], [68.45456696, 23.91596985], [68.45456696, 23.91625023], [68.45485687, 23.91625023], [68.45485687, 23.91681099], [68.4540329, 23.91681099], [68.4540329, 23.91653061], [68.45347595, 23.91653061], [68.45347595, 23.91625023], [68.45291901, 23.91625023], [68.45291901, 23.91596985], [68.45263672, 23.91596985], [68.45263672, 23.91625023], [68.45236206, 23.91625023], [68.45236206, 23.91653061], [68.45207977, 23.91653061], [68.45207977, 23.91681099], [68.45180511, 23.91680336], [68.45180511, 23.91708565], [68.45153046, 23.91707993], [68.45153046, 23.91764069], [68.45124817, 23.91763878], [68.45124817, 23.91986084], [68.45153046, 23.9198494], [68.45153046, 23.92041969], [68.45207977, 23.92041779], [68.45207977, 23.92069435], [68.45263672, 23.92069435], [68.45263672, 23.92097282], [68.45318604, 23.92097092], [68.45318604, 23.92124939], [68.45347595, 23.92124939], [68.45347595, 23.92180824], [68.45375061, 23.92180634], [68.45375061, 23.9220829], [68.4540329, 23.92207909], [68.4540329, 23.92291832], [68.45430756, 23.92291641], [68.45430756, 23.92458344], [68.45456696, 23.92458153], [68.45456696, 23.92625046], [68.45485687, 23.92625046], [68.45485687, 23.92681122], [68.45513916, 23.92681122], [68.45513916, 23.92764091], [68.45541382, 23.92763901], [68.45541382, 23.92819214], [68.45569611, 23.92819023], [68.45569611, 23.92875099], [68.45652771, 23.92875099], [68.45652771, 23.92904091], [68.45791626, 23.92904091], [68.45791626, 23.92930984], [68.45903015, 23.92930412], [68.45903015, 23.9295826], [68.4595871, 23.92958069], [68.4595871, 23.92986107], [68.45986176, 23.92986107], [68.45986176, 23.93013954], [68.4604187, 23.93013954], [68.4604187, 23.93069649], [68.46013641, 23.93069077], [68.46013641, 23.93153], [68.4604187, 23.93152618], [68.4604187, 23.93180466], [68.46291351, 23.93180466], [68.46291351, 23.93208313], [68.46208191, 23.93208313], [68.46208191, 23.9323616], [68.46125031, 23.9323597], [68.46125031, 23.93264008], [68.46098328, 23.93264008], [68.46098328, 23.93320084], [68.46069336, 23.93319511], [68.46069336, 23.93347168], [68.4595871, 23.93346977], [68.4595871, 23.93375015], [68.45874786, 23.93375015], [68.45874786, 23.93403053], [68.45735931, 23.93403053], [68.45735931, 23.93431091], [68.45652771, 23.93430519], [68.45652771, 23.93458366], [68.45625305, 23.93457985], [68.45625305, 23.93486023], [68.45597076, 23.93486023], [68.45597076, 23.93514061], [68.45569611, 23.93514061], [68.45569611, 23.93541908], [68.45541382, 23.93541718], [68.45541382, 23.93569374], [68.45513916, 23.93569374], [68.45513916, 23.93597221], [68.45485687, 23.9359684], [68.45485687, 23.93625069], [68.45456696, 23.93625069], [68.45456696, 23.93652916], [68.45430756, 23.93652725], [68.45430756, 23.9370842], [68.45402527, 23.9370842], [68.4540329, 23.93736076], [68.45347595, 23.93736076], [68.45347595, 23.93763924], [68.45291901, 23.93763924], [68.45291901, 23.93791962], [68.45236206, 23.9379158], [68.45236206, 23.93819427], [68.45180511, 23.93819427], [68.45180511, 23.93847275], [68.45124817, 23.93847275], [68.45124817, 23.93875122], [68.45041656, 23.93875122], [68.45041656, 23.93902969], [68.44985962, 23.93902969], [68.44985962, 23.93931007], [68.44902802, 23.93930626], [68.44902802, 23.93958282], [68.44875336, 23.93958282], [68.44876099, 23.94013977], [68.44847107, 23.94013977], [68.44847107, 23.93985939], [68.44819641, 23.9398613], [68.44819641, 23.93958282], [68.44763947, 23.93958282], [68.44763947, 23.93930626], [68.44708252, 23.93931007], [68.44708252, 23.93902969], [68.4465332, 23.93902969], [68.4465332, 23.93875122], [68.44568634, 23.93875122], [68.44568634, 23.93847275], [68.44513702, 23.93847275], [68.44513702, 23.93819427], [68.44486237, 23.93819427], [68.44486237, 23.9379158], [68.44458008, 23.93791962], [68.44458008, 23.93763924], [68.44403076, 23.93763924], [68.44403076, 23.93736076], [68.44374847, 23.93736076], [68.44374847, 23.93707848], [68.44319153, 23.9370842], [68.44319153, 23.93680573], [68.44235992, 23.93680954], [68.44235992, 23.93652916], [68.44180298, 23.93652916], [68.44180298, 23.93625069], [68.44097137, 23.93625069], [68.44097137, 23.93652916], [68.43930817, 23.93652916], [68.43930817, 23.93680954], [68.43875122, 23.93680573], [68.43875122, 23.9370842], [68.43791962, 23.93707848], [68.43791962, 23.93736076], [68.43682098, 23.93736076], [68.43682098, 23.93763924], [68.43430328, 23.93763924], [68.43430328, 23.93736076], [68.43345642, 23.93736076], [68.43345642, 23.93707848], [68.43264008, 23.9370842], [68.43264008, 23.93680573], [68.43180847, 23.93680954], [68.43180847, 23.93652916], [68.43096924, 23.93652916], [68.43096924, 23.93625069], [68.42903137, 23.93625069], [68.42903137, 23.93652916], [68.42819214, 23.93652916], [68.42819214, 23.93791962], [68.42847443, 23.9379158], [68.42847443, 23.93847275], [68.42874908, 23.93847275], [68.42874908, 23.93902969], [68.42903137, 23.93902779], [68.42903137, 23.93958282], [68.42930603, 23.93958282], [68.42930603, 23.94042015], [68.42958069, 23.94041634], [68.42958069, 23.94069481], [68.42986298, 23.9406929], [68.42986298, 23.94098091], [68.43013763, 23.94097137], [68.43013763, 23.94208336], [68.43041992, 23.94207954], [68.43041992, 23.9426403], [68.43068695, 23.9426403], [68.43068695, 23.94320107], [68.43096924, 23.94320107], [68.43096924, 23.94375038], [68.43125153, 23.94375038], [68.43125153, 23.94402695], [68.43180847, 23.94402122], [68.43180847, 23.94431114], [68.43208313, 23.94431114], [68.43208313, 23.94486046], [68.43235779, 23.94486046], [68.43235779, 23.94597244], [68.43264008, 23.94597054], [68.43264008, 23.94680977], [68.43291473, 23.94680786], [68.43291473, 23.94708252], [68.43319702, 23.94708061], [68.43319702, 23.94736099], [68.43347168, 23.94736099], [68.43347168, 23.94753265], [68.43345642, 23.94791985], [68.43374634, 23.94791985], [68.43374634, 23.94874954], [68.43402863, 23.94874954], [68.43402863, 23.94986153], [68.43430328, 23.94986153], [68.43430328, 23.9509716], [68.4345932, 23.9509716], [68.4345932, 23.95153046], [68.43486023, 23.95152855], [68.43486023, 23.95236015], [68.43514252, 23.95236015], [68.43514252, 23.95430946], [68.43541718, 23.95430946], [68.43541718, 23.95486069], [68.43569183, 23.95486069], [68.43569183, 23.95514107], [68.43597412, 23.95513916], [68.43597412, 23.95569229], [68.43624878, 23.95569038], [68.43624878, 23.95625114], [68.43653107, 23.95625114], [68.43653107, 23.95681], [68.43680573, 23.95680428], [68.43680573, 23.95736122], [68.43708038, 23.95736122], [68.43708038, 23.95763969], [68.43736267, 23.95763969], [68.43736267, 23.95792007], [68.43763733, 23.95791435], [68.43763733, 23.95819664], [68.43791962, 23.95819664], [68.43791962, 23.9584713], [68.43818665, 23.95846939], [68.43818665, 23.95874977], [68.43846893, 23.95874977], [68.43846893, 23.95902634], [68.43875122, 23.95902634], [68.43875122, 23.95930672], [68.43902588, 23.95930672], [68.43902588, 23.95958328], [68.43930817, 23.95958328], [68.43930817, 23.95986176], [68.43959045, 23.95985985], [68.43959045, 23.96014023], [68.43985748, 23.96014023], [68.43985748, 23.96042061], [68.44013977, 23.96042061], [68.44013977, 23.96069908], [68.4404068, 23.96069908], [68.4404068, 23.96125031], [68.44069672, 23.96125031], [68.44069672, 23.96153069], [68.44097137, 23.96153069], [68.44097137, 23.96180916], [68.44124603, 23.96180916], [68.44124603, 23.96209145], [68.44152832, 23.96209145], [68.44152832, 23.96264076], [68.4420929, 23.96264076], [68.4420929, 23.96209145], [68.44291687, 23.96209145], [68.44291687, 23.96180916], [68.44374847, 23.96180916], [68.44374847, 23.96153069], [68.44431305, 23.96153069], [68.44431305, 23.96125031], [68.44513702, 23.96125031], [68.44513702, 23.96096992], [68.44569397, 23.96097183], [68.44569397, 23.96069527], [68.44625092, 23.96069908], [68.44625092, 23.96042061], [68.4465332, 23.96042061], [68.4465332, 23.96014023], [68.44708252, 23.96014023], [68.44708252, 23.95985985], [68.44763947, 23.95986176], [68.44763947, 23.95958328], [68.44902802, 23.95958328], [68.44902802, 23.96097183], [68.44819641, 23.96096992], [68.44819641, 23.96125031], [68.44735718, 23.96125031], [68.44735718, 23.96153069], [68.44680786, 23.96153069], [68.44680786, 23.96180916], [68.44625092, 23.96180916], [68.44625092, 23.96209145], [68.44596863, 23.96209145], [68.44596863, 23.96236038], [68.44541931, 23.96236038], [68.44541931, 23.96264076], [68.44513702, 23.96264076], [68.44513702, 23.96291924], [68.44458008, 23.96291733], [68.44458008, 23.96319389], [68.44403076, 23.96319389], [68.44403076, 23.96347237], [68.44374847, 23.96347046], [68.44374847, 23.96375084], [68.44348907, 23.9638195], [68.44346619, 23.96402931], [68.44262695, 23.96402931], [68.44262695, 23.96486092], [68.44291687, 23.96486092], [68.44291687, 23.9659729], [68.44319153, 23.9659729], [68.44319153, 23.96708107], [68.44346619, 23.96708107], [68.44346619, 23.96763992], [68.44374847, 23.96763992], [68.44374847, 23.96875], [68.44403076, 23.96875], [68.44403076, 23.96903038], [68.44430542, 23.96902847], [68.44430542, 23.97208595], [68.44458008, 23.97208023], [68.44458008, 23.97236061], [68.44486237, 23.97236061], [68.44486237, 23.97291946], [68.44513702, 23.97291756], [68.44513702, 23.9734726], [68.44541931, 23.97347069], [68.44541931, 23.97402954], [68.44569397, 23.97402954], [68.44569397, 23.97458267], [68.44596863, 23.97458076], [68.44596863, 23.97513962], [68.44625092, 23.97513962], [68.44625092, 23.97624969], [68.4465332, 23.97624969], [68.4465332, 23.97709274], [68.44680786, 23.97708321], [68.44680786, 23.97736168], [68.44708252, 23.97736168], [68.44708252, 23.97820282], [68.44735718, 23.97820282], [68.44735718, 23.97903061], [68.44763947, 23.9790287], [68.44763947, 23.98069382], [68.44791412, 23.98069382], [68.44791412, 23.98097229], [68.44819641, 23.98097038], [68.44819641, 23.98125076], [68.44876099, 23.98125076], [68.44876099, 23.98153114], [68.44930267, 23.98153114], [68.44930267, 23.98180962], [68.44958496, 23.9818058], [68.44958496, 23.98208237], [68.44985962, 23.98208046], [68.44985962, 23.98236084], [68.45041656, 23.98236084], [68.45041656, 23.98264122], [68.45069122, 23.98264122], [68.45069122, 23.98291969], [68.45097351, 23.98291588], [68.45097351, 23.98319435], [68.45124817, 23.98319435], [68.45124817, 23.98347282], [68.45153046, 23.98347092], [68.45153046, 23.98374939], [68.45182037, 23.98374939], [68.45182037, 23.98402977], [68.45207977, 23.98402977], [68.45207977, 23.98431015], [68.45236206, 23.98430443], [68.45236206, 23.9845829], [68.45263672, 23.9845829], [68.45263672, 23.98486137], [68.45291901, 23.98485947], [68.45291901, 23.98513985], [68.45375061, 23.98513985], [68.45375061, 23.98542023], [68.45402527, 23.98541451], [68.45402527, 23.98597145], [68.45430756, 23.98596954], [68.45430756, 23.9865303], [68.45485687, 23.9865303], [68.45485687, 23.98681068], [68.45541382, 23.98680687], [68.45541382, 23.98708344], [68.45569611, 23.98708344], [68.45569611, 23.98736191], [68.45625305, 23.98735809], [68.45625305, 23.98764038], [68.45652771, 23.98764038], [68.45652771, 23.98792076], [68.45680237, 23.98791885], [68.45680237, 23.9881897], [68.45708466, 23.98819542], [68.45708466, 23.98847198], [68.45735931, 23.98846817], [68.45735931, 23.98875046], [68.45762634, 23.98875046], [68.45762634, 23.98903084], [68.45791626, 23.98903084], [68.45791626, 23.98932266], [68.45819092, 23.9893055], [68.45819092, 23.98958397], [68.45847321, 23.98957825], [68.45847321, 23.98986053], [68.45874786, 23.98986053], [68.45874786, 23.99014091], [68.45903015, 23.99014091], [68.45903015, 23.99041939], [68.45930481, 23.99041748], [68.45930481, 23.99069405], [68.45986176, 23.99069405], [68.45986176, 23.99097252], [68.4604187, 23.99097061], [68.4604187, 23.99124908], [68.46125031, 23.99124908], [68.46125031, 23.99152946], [68.46180725, 23.99152946], [68.46180725, 23.99181175], [68.4631958, 23.99180603], [68.4631958, 23.9920826], [68.4668045, 23.9920826], [68.4668045, 23.99180603], [68.46930695, 23.99180603], [68.46930695, 23.9920826], [68.47041321, 23.99206924], [68.47041321, 23.99236107], [68.4734726, 23.99236107], [68.4734726, 23.99263954], [68.47429657, 23.99263954], [68.47429657, 23.99236107], [68.47486115, 23.99236107], [68.47486115, 23.99206924], [68.47541809, 23.99206924], [68.47541809, 23.99236107], [68.4770813, 23.99236107], [68.4770813, 23.99263954], [68.48208618, 23.99263954], [68.48208618, 23.99236107], [68.48458099, 23.99236107], [68.48458099, 23.99206924], [68.48652649, 23.9920826], [68.48652649, 23.99180603], [68.48680878, 23.99181175], [68.48680878, 23.99152946], [68.48707581, 23.99152946], [68.48707581, 23.99124908], [68.48735809, 23.99124908], [68.48735809, 23.99097061], [68.48764038, 23.99097252], [68.48764038, 23.99069405], [68.48791504, 23.99069405], [68.48791504, 23.99041748], [68.48819733, 23.99041939], [68.48819733, 23.99014091], [68.48847198, 23.99014091], [68.48847198, 23.98986053], [68.48874664, 23.98986053], [68.48874664, 23.98957825], [68.48902893, 23.98958397], [68.48902893, 23.9893055], [68.48929596, 23.98932266], [68.48929596, 23.98903084], [68.48958588, 23.98903084], [68.48958588, 23.98846817], [68.48986053, 23.98847198], [68.48986053, 23.98819542], [68.49014282, 23.9881897], [68.49013519, 23.98791885], [68.49041748, 23.98792076], [68.49041748, 23.98764038], [68.49069977, 23.98764038], [68.49069977, 23.98735809], [68.49097443, 23.98736191], [68.49097443, 23.98708344], [68.49124908, 23.98708344], [68.49124908, 23.98680687], [68.49153137, 23.98681068], [68.49153137, 23.9865303], [68.49180603, 23.9865303], [68.49180603, 23.98625946], [68.49208069, 23.98625946], [68.49208069, 23.98596954], [68.49236298, 23.98597145], [68.49236298, 23.98569679], [68.49263763, 23.98569679], [68.49263763, 23.98541451], [68.49291992, 23.98542023], [68.49291992, 23.98513985], [68.49318695, 23.98513985], [68.49318695, 23.98485947], [68.49346924, 23.98486137], [68.49346924, 23.9845829], [68.49375153, 23.9845829], [68.49375153, 23.98430443], [68.49402618, 23.98431015], [68.49402618, 23.98402977], [68.49430847, 23.98402977], [68.49430847, 23.98374939], [68.49458313, 23.98374939], [68.49458313, 23.98347092], [68.49485779, 23.98347282], [68.49485779, 23.98291588], [68.49514008, 23.98291969], [68.49514008, 23.98264122], [68.49569702, 23.98264122], [68.49569702, 23.98236084], [68.49597168, 23.98236084], [68.49597168, 23.98208046], [68.49624634, 23.98208237], [68.49624634, 23.9818058], [68.49652863, 23.98180962], [68.49652863, 23.98153114], [68.49680328, 23.98153114], [68.49680328, 23.98125076], [68.49736023, 23.98125076], [68.49736023, 23.98097038], [68.49764252, 23.98097229], [68.49764252, 23.98069382], [68.49791718, 23.98069382], [68.49791718, 23.98041725], [68.49819183, 23.98042107], [68.49819183, 23.98013115], [68.49930573, 23.98013878], [68.49930573, 23.97986031], [68.49986267, 23.97986031], [68.49986267, 23.97958374], [68.50069427, 23.97958374], [68.50069427, 23.97930527], [68.50125122, 23.9793129], [68.50125122, 23.97903061], [68.50152588, 23.97903061], [68.50152588, 23.97875023], [68.50208282, 23.97875023], [68.50208282, 23.97847176], [68.50235748, 23.97847176], [68.50235748, 23.97763824], [68.50263977, 23.97764015], [68.50263977, 23.97541809], [68.50235748, 23.97541809], [68.50235748, 23.97458076], [68.50208282, 23.97458267], [68.50208282, 23.97374725], [68.50180817, 23.97375107], [68.50180817, 23.97264099], [68.50152588, 23.97264099], [68.50152588, 23.97180939], [68.50125122, 23.97180939], [68.50125122, 23.97125053], [68.50096893, 23.97125053], [68.50096893, 23.97068977], [68.50041962, 23.97069359], [68.50041962, 23.97041512], [68.50013733, 23.97042084], [68.50013733, 23.97014046], [68.49958038, 23.97014046], [68.49958038, 23.96986008], [68.49930573, 23.96986198], [68.49930573, 23.96958351], [68.49903107, 23.96958351], [68.49903107, 23.96930313], [68.49874878, 23.96931076], [68.49874878, 23.96903038], [68.49846649, 23.96903038], [68.49846649, 23.96875], [68.49819183, 23.96875], [68.49819183, 23.96819115], [68.49791718, 23.96819305], [68.49791718, 23.96791649], [68.49764252, 23.9679203], [68.49764252, 23.96735954], [68.49736023, 23.96736145], [68.49736023, 23.96708107], [68.49680328, 23.96708107], [68.49680328, 23.96652794], [68.49652863, 23.96652985], [68.49652863, 23.9659729], [68.49624634, 23.9659729], [68.49624634, 23.96347237], [68.49597168, 23.96352005], [68.49597168, 23.96236038], [68.49569702, 23.96236038], [68.49569702, 23.95957947], [68.49597168, 23.95958328], [68.49597168, 23.95819664], [68.49624634, 23.95819664], [68.49624634, 23.95791435], [68.49597168, 23.95792007], [68.49597168, 23.95763969], [68.49624634, 23.95763969], [68.49624634, 23.95681], [68.49652863, 23.95681], [68.49652863, 23.95569038], [68.49680328, 23.95569229], [68.49680328, 23.95486069], [68.4970932, 23.95486069], [68.49708557, 23.95402718], [68.49736023, 23.9540329], [68.49736023, 23.95319176], [68.49764252, 23.95319366], [68.49764252, 23.95236015], [68.49791718, 23.95236015], [68.49791718, 23.95180511], [68.49819183, 23.95181274], [68.49819183, 23.95125008], [68.49846649, 23.95125008], [68.49846649, 23.95070267], [68.49874878, 23.95070267], [68.49874878, 23.95014954], [68.49903107, 23.95014954], [68.49903107, 23.94985962], [68.49930573, 23.94986153], [68.49930573, 23.94948959], [68.49930573, 23.94930649], [68.49958038, 23.9493084], [68.49958038, 23.94874954], [68.4998703, 23.94874954], [68.49986267, 23.94847298], [68.50013733, 23.94847298], [68.50013733, 23.9481945], [68.50069427, 23.9481945], [68.50069427, 23.94791794], [68.50096893, 23.94791985], [68.50096893, 23.94763947], [68.50125122, 23.94763947], [68.50125122, 23.94736099], [68.50152588, 23.94736099], [68.50152588, 23.94708061], [68.50180817, 23.94708252], [68.50180817, 23.94680786], [68.50208282, 23.94680977], [68.50208282, 23.94652939], [68.50235748, 23.94652939], [68.50235748, 23.94625092], [68.50263977, 23.94625092], [68.50263977, 23.94597054], [68.50319672, 23.94597244], [68.50319672, 23.94569588], [68.50402832, 23.94569588], [68.50402832, 23.9454155], [68.5045929, 23.94542122], [68.5045929, 23.94514084], [68.50485992, 23.94514084], [68.50485992, 23.94486046], [68.50567627, 23.94486046], [68.50567627, 23.94458008], [68.50653076, 23.9445858], [68.50653076, 23.94430733], [68.50708008, 23.94431114], [68.50708008, 23.94402122], [68.50846863, 23.94402695], [68.50846863, 23.94375038], [68.50930786, 23.94375038], [68.50930786, 23.94347], [68.51097107, 23.94347191], [68.51097107, 23.94319344], [68.51264191, 23.94320107], [68.51264191, 23.94292068], [68.51319122, 23.94292068], [68.51319122, 23.9426403], [68.51403046, 23.9426403], [68.51403046, 23.94235992], [68.51457977, 23.94235992], [68.51457977, 23.9426403], [68.51541901, 23.9426403], [68.51541901, 23.94235992], [68.51652527, 23.94236183], [68.51652527, 23.94208336], [68.5173645, 23.94208336], [68.5173645, 23.94180489], [68.51763916, 23.94180489], [68.51763916, 23.94152832], [68.51790619, 23.94153023], [68.51790619, 23.94124985], [68.51819611, 23.94124985], [68.51819611, 23.94098091], [68.51847076, 23.94098091], [68.51847076, 23.9406929], [68.51875305, 23.94069481], [68.51875305, 23.93902779], [68.51902771, 23.93902969], [68.51902771, 23.93818855], [68.51652527, 23.93819427], [68.51652527, 23.9379158], [68.51625061, 23.9379158], [68.51625061, 23.93819427], [68.51513672, 23.93819427], [68.51513672, 23.93847275], [68.51457977, 23.93847275], [68.51457977, 23.93875122], [68.51403046, 23.93875122], [68.51403046, 23.93902969], [68.51374817, 23.93902969], [68.51374817, 23.93931007], [68.51180267, 23.93930626], [68.51180267, 23.93958282], [68.51125336, 23.93958282], [68.51125336, 23.9398613], [68.51040649, 23.93985939], [68.51040649, 23.94013977], [68.50930786, 23.94013977], [68.50930786, 23.94042015], [68.50875092, 23.94041634], [68.50875092, 23.94069481], [68.50818634, 23.9406929], [68.50818634, 23.94098091], [68.50791931, 23.94098091], [68.50791931, 23.94124985], [68.50736237, 23.94124985], [68.50736237, 23.94153023], [68.50680542, 23.94152832], [68.50680542, 23.94180489], [68.50569153, 23.94180489], [68.50569153, 23.94041634], [68.50596619, 23.94042015], [68.50596619, 23.94013977], [68.50681305, 23.94013977], [68.50680542, 23.9398613], [68.50736237, 23.9398613], [68.50736237, 23.93958282], [68.50763702, 23.93958282], [68.50763702, 23.93930626], [68.50818634, 23.93931007], [68.50818634, 23.93902969], [68.50874329, 23.93902969], [68.50874329, 23.93875122], [68.50985718, 23.93875122], [68.50985718, 23.93847275], [68.51069641, 23.93847275], [68.51069641, 23.93819427], [68.51125336, 23.93819427], [68.51125336, 23.9379158], [68.51319122, 23.93791962], [68.51319122, 23.93763924], [68.51346588, 23.93763924], [68.51346588, 23.93736076], [68.51403046, 23.93736076], [68.51403046, 23.93707848], [68.51457977, 23.9370842], [68.51457977, 23.93680573], [68.51568604, 23.93680954], [68.51568604, 23.93652916], [68.51680756, 23.93652916], [68.51680756, 23.93625069], [68.51708221, 23.93625069], [68.51708221, 23.9359684], [68.51819611, 23.93597221], [68.51819611, 23.93569374], [68.51847076, 23.93569374], [68.51847076, 23.92430496], [68.51819611, 23.92431259], [68.51819611, 23.9240303], [68.51790619, 23.9240303], [68.51790619, 23.92375183], [68.51735687, 23.92375183], [68.51735687, 23.92347145], [68.51708221, 23.92347145], [68.51708221, 23.92319489], [68.51680756, 23.92319489], [68.51680756, 23.92291641], [68.5165329, 23.92291832], [68.5165329, 23.92263985], [68.51625061, 23.92263985], [68.51625061, 23.92235756], [68.51597595, 23.92236137], [68.51597595, 23.9220829], [68.51569366, 23.9220829], [68.51569366, 23.92180634], [68.51513672, 23.92180824], [68.51513672, 23.92152977], [68.51486969, 23.92152977], [68.51486969, 23.92124939], [68.51457977, 23.92124939], [68.51457977, 23.92097092], [68.51430511, 23.92097282], [68.51430511, 23.92069435], [68.51403046, 23.92069435], [68.51403046, 23.92041779], [68.51346588, 23.92041969], [68.51346588, 23.92014122], [68.51319122, 23.92014122], [68.51319122, 23.9198494], [68.51264191, 23.9198494], [68.51264191, 23.92041969], [68.51235962, 23.92041779], [68.51235962, 23.92069435], [68.51208496, 23.92069435], [68.51208496, 23.92097282], [68.51152802, 23.92097092], [68.51152802, 23.92180824], [68.51125336, 23.92180634], [68.51125336, 23.92319489], [68.51097107, 23.92319489], [68.51097107, 23.92347145], [68.51013947, 23.92347145], [68.51013947, 23.92319489], [68.50986481, 23.92319489], [68.50986481, 23.92124939], [68.51013947, 23.92124939], [68.51013947, 23.92041969], [68.51040649, 23.92041969], [68.51040649, 23.91958046], [68.51069641, 23.91958427], [68.51069641, 23.91902542], [68.51097107, 23.91903114], [68.51097107, 23.91847038], [68.51125336, 23.91847229], [68.51125336, 23.91791534], [68.51097107, 23.91792107], [68.51097107, 23.91681099], [68.51069641, 23.91681099], [68.51069641, 23.91653061], [68.51040649, 23.91653061], [68.51040649, 23.91625023], [68.51013947, 23.91625023], [68.51013947, 23.91570091], [68.50985718, 23.91570091], [68.50985718, 23.91542053], [68.50958252, 23.91542053], [68.50958252, 23.91514015], [68.50930786, 23.91514015], [68.50930786, 23.91485977], [68.50902557, 23.91486168], [68.50902557, 23.91458321], [68.50875092, 23.91458321], [68.50875092, 23.91402817], [68.50846863, 23.91403961], [68.50846863, 23.91374969], [68.50818634, 23.91374969], [68.50818634, 23.91347122], [68.50791931, 23.91347122], [68.50791931, 23.91319466], [68.50763702, 23.91319466], [68.50763702, 23.91291618], [68.50736237, 23.91292191], [68.50736237, 23.91263962], [68.50708008, 23.91263962], [68.50708008, 23.91208267], [68.50680542, 23.91208267], [68.50680542, 23.91180611], [68.50653076, 23.91181183], [68.50653076, 23.91152954], [68.50624847, 23.91152954], [68.50624847, 23.91124916], [68.50596619, 23.91124916], [68.50596619, 23.9106884], [68.50569153, 23.91069412], [68.50569153, 23.91013908], [68.50541687, 23.91013908], [68.50541687, 23.90957832], [68.50514221, 23.90958405], [68.50514221, 23.90930557], [68.50485992, 23.90930939], [68.50485992, 23.90875053], [68.50458527, 23.90875053], [68.50458527, 23.90847206], [68.50375366, 23.90847206], [68.50375366, 23.90819359], [68.50347137, 23.90819359], [68.50347137, 23.90791893], [68.50319672, 23.90791893], [68.50319672, 23.90736198], [68.50291443, 23.90736198], [68.50291443, 23.90708351], [68.50235748, 23.90708351], [68.50235748, 23.90680695], [68.50096893, 23.90681076], [68.50096893, 23.90653038], [68.4998703, 23.90653038], [68.4998703, 23.90625], [68.49903107, 23.90625], [68.49903107, 23.90596962], [68.49847412, 23.90597153], [68.49847412, 23.90569687], [68.49819183, 23.90570068], [68.49819183, 23.9054203], [68.49680328, 23.9054203], [68.49680328, 23.90513992], [68.49597168, 23.90513992], [68.49597168, 23.90485001], [68.49514008, 23.90486145], [68.49514008, 23.90458298], [68.49375153, 23.90458298], [68.49375153, 23.9043045], [68.49346924, 23.90431023], [68.49346924, 23.90402985], [68.49318695, 23.90402985], [68.49318695, 23.90374947], [68.49263763, 23.90374947], [68.49263763, 23.90347099], [68.49180603, 23.90347481], [68.49180603, 23.90319443], [68.49097443, 23.90319443], [68.49097443, 23.90291405], [68.49041748, 23.90291977], [68.49041748, 23.90263939], [68.48986053, 23.90263939], [68.48986053, 23.90236092], [68.48958588, 23.90236092], [68.48958588, 23.90208054], [68.48902893, 23.90208244], [68.48902893, 23.90180588], [68.48847198, 23.90180969], [68.48847198, 23.90153122], [68.4879303, 23.90153122], [68.4879303, 23.90125084], [68.48764038, 23.90125084], [68.48764038, 23.90097046], [68.48735809, 23.90097237], [68.48735809, 23.90069389], [68.48708344, 23.90069389], [68.48708344, 23.90041733], [68.48680878, 23.90042114], [68.48680878, 23.90014076], [68.48652649, 23.90014076], [68.48652649, 23.89986038], [68.48625183, 23.89986038], [68.48625183, 23.89958191], [68.48596954, 23.89958382], [68.48596954, 23.89930534], [68.48568726, 23.89931107], [68.48568726, 23.89903259], [68.48542023, 23.89903259], [68.48542023, 23.89847183], [68.48513794, 23.89847183], [68.48513794, 23.89819527], [68.48486328, 23.8982029], [68.48486328, 23.89764023], [68.48458099, 23.89764023], [68.48458099, 23.89736176], [68.48430634, 23.89736176], [68.48430634, 23.89680481], [68.48402405, 23.89680481], [68.48402405, 23.89652824], [68.48374939, 23.89652824], [68.48374939, 23.89596748], [68.48347473, 23.8959713], [68.48347473, 23.89541626], [68.48319244, 23.89541817], [68.48319244, 23.89486122], [68.48291779, 23.89486122], [68.48291779, 23.89458084], [68.4826355, 23.89458275], [68.4826355, 23.89402962], [68.48236084, 23.89402962], [68.48236084, 23.89347076], [68.48208618, 23.89347267], [68.48208618, 23.8931942], [68.48180389, 23.8931942], [68.48180389, 23.89263916], [68.48152924, 23.89264107], [68.48152924, 23.89236069], [68.48124695, 23.89236069], [68.48124695, 23.89180946], [68.48097229, 23.89180946], [68.48097229, 23.89153099], [68.48069763, 23.89153099], [68.48069763, 23.89097023], [68.48041534, 23.89097214], [68.48041534, 23.89041519], [68.47958374, 23.89041519], [68.47958374, 23.89069366], [68.47875214, 23.89069366], [68.47875214, 23.89097214], [68.47735596, 23.89097023], [68.47735596, 23.89125061], [68.47651672, 23.89125061], [68.47651672, 23.89153099], [68.47541809, 23.89153099], [68.47541809, 23.89180946], [68.4743042, 23.89180756], [68.4743042, 23.89208412], [68.4734726, 23.89208031], [68.4734726, 23.89236069], [68.47292328, 23.89236069], [68.47292328, 23.89264107], [68.47208405, 23.89263916], [68.47208405, 23.89291763], [68.47125244, 23.89291763], [68.47125244, 23.8931942], [68.47097015, 23.8931942], [68.47097015, 23.89347267], [68.47070313, 23.89347076], [68.47070313, 23.89375114], [68.47041321, 23.89375114], [68.47041321, 23.89402962], [68.46985626, 23.89402962], [68.46985626, 23.89430809], [68.46930695, 23.89430618], [68.46930695, 23.89458275], [68.46875, 23.89458084], [68.46875, 23.89486122], [68.46763611, 23.89486122], [68.46763611, 23.89458084], [68.46736145, 23.89458275], [68.46736145, 23.89374733], [68.46763611, 23.89375114], [68.46763611, 23.89347076], [68.46819305, 23.89347267], [68.46819305, 23.8931942], [68.46875, 23.8931942], [68.46875, 23.89291763], [68.46902466, 23.89291763], [68.46902466, 23.89263916], [68.46956635, 23.89264107], [68.46956635, 23.89236069], [68.47013855, 23.89236069], [68.47013855, 23.89208031], [68.47041321, 23.89208412], [68.47041321, 23.89180756], [68.47070313, 23.89180946], [68.47070313, 23.89153099], [68.4715271, 23.89153099], [68.4715271, 23.89125061], [68.4723587, 23.89125061], [68.4723587, 23.89097023], [68.47291565, 23.89097214], [68.47291565, 23.89069366], [68.4734726, 23.89069366], [68.4734726, 23.89041519], [68.47486115, 23.89042091], [68.47486115, 23.89014053], [68.4759903, 23.89014053], [68.4759903, 23.88986969], [68.47680664, 23.88986969], [68.47680664, 23.88957977], [68.47819519, 23.88958359], [68.47819519, 23.88930321], [68.47875977, 23.88931084], [68.47875977, 23.88903046], [68.47957611, 23.88903046], [68.47957611, 23.88875008], [68.47930908, 23.88875008], [68.47930908, 23.88820076]]], [[[68.51457977, 23.94958305], [68.5256958, 23.94952965], [68.5256958, 23.94930649], [68.52597046, 23.94930077], [68.52597046, 23.94847298], [68.5256958, 23.94847298], [68.5256958, 23.9481945], [68.52513885, 23.9481945], [68.52513885, 23.94763947], [68.52485657, 23.94763947], [68.52485657, 23.94736099], [68.52458191, 23.94736099], [68.52458191, 23.94708061], [68.52430725, 23.94708252], [68.52430725, 23.94680786], [68.52375031, 23.94680977], [68.52375031, 23.94625092], [68.52347565, 23.94625092], [68.52347565, 23.94597244], [68.52319336, 23.94597244], [68.52319336, 23.94569588], [68.5229187, 23.94569588], [68.5229187, 23.9454155], [68.52153015, 23.9454155], [68.52153015, 23.94597244], [68.52124786, 23.94597054], [68.52124786, 23.94625092], [68.52068329, 23.94625092], [68.52068329, 23.94652939], [68.51985931, 23.94652939], [68.51985931, 23.94680977], [68.51958466, 23.94680786], [68.51958466, 23.94708252], [68.51930237, 23.94708061], [68.51930237, 23.94736099], [68.51875305, 23.94736099], [68.51875305, 23.94763947], [68.51847076, 23.94763947], [68.51847076, 23.94791985], [68.51791382, 23.94791794], [68.51791382, 23.9481945], [68.51763916, 23.9481945], [68.51763916, 23.94847298], [68.51680756, 23.94847107], [68.51680756, 23.94874954], [68.51597595, 23.94874954], [68.51597595, 23.94902992], [68.51541901, 23.94902992], [68.51541901, 23.9493084], [68.51457977, 23.94930649], [68.51457977, 23.94958305]]], [[[70.45513916, 22.99570084], [70.45513916, 22.99430084], [70.4548645, 22.99430466], [70.4548645, 22.99152756], [70.45458221, 22.99152946], [70.45458221, 22.99097061], [70.45430756, 22.99097061], [70.45430756, 22.99069214], [70.45458221, 22.99069214], [70.45458221, 22.99014091], [70.45430756, 22.99014282], [70.45430756, 22.98984909], [70.45402527, 22.98986053], [70.45402527, 22.9893055], [70.45375061, 22.98931122], [70.45375061, 22.98903275], [70.45347595, 22.98903275], [70.45347595, 22.98846817], [70.45319366, 22.98847008], [70.45319366, 22.98819351], [70.45291901, 22.98819351], [70.45291901, 22.98791695], [70.45236206, 22.98792076], [70.45236206, 22.98763847], [70.45207977, 22.98763847], [70.45207977, 22.98735809], [70.45180511, 22.98736191], [70.45180511, 22.98680496], [70.45153046, 22.98681068], [70.45153046, 22.9865284], [70.45124817, 22.9865284], [70.45124817, 22.98624992], [70.45096588, 22.98624992], [70.45096588, 22.98596954], [70.45041656, 22.98597145], [70.45041656, 22.98569489], [70.45014191, 22.98569489], [70.45014191, 22.98541641], [70.44959259, 22.98541832], [70.44959259, 22.98513985], [70.44930267, 22.98513985], [70.44930267, 22.98485947], [70.44902802, 22.98486137], [70.44902802, 22.9845829], [70.44847107, 22.9845829], [70.44847107, 22.98430634], [70.44819641, 22.98431015], [70.44819641, 22.98404121], [70.44763947, 22.98404121], [70.44763947, 22.98374939], [70.44708252, 22.98374939], [70.44708252, 22.98347282], [70.44680786, 22.98347282], [70.44680786, 22.98319435], [70.44625092, 22.98319435], [70.44625092, 22.98291779], [70.44596863, 22.98291969], [70.44596863, 22.98264122], [70.44541931, 22.98264122], [70.44541931, 22.98236084], [70.44513702, 22.98236084], [70.44513702, 22.98208046], [70.44486237, 22.98208237], [70.44486237, 22.9818058], [70.44431305, 22.98180962], [70.44431305, 22.98153114], [70.44403076, 22.98153114], [70.44403076, 22.98125076], [70.44346619, 22.98125076], [70.44346619, 22.98097992], [70.44319153, 22.98097992], [70.44319153, 22.98069], [70.44291687, 22.98069572], [70.44291687, 22.98041725], [70.44264221, 22.98042107], [70.44264221, 22.98014069], [70.4420929, 22.98014069], [70.4420929, 22.97986031], [70.44152832, 22.97986031], [70.44152832, 22.97957993], [70.44097137, 22.97958565], [70.44097137, 22.97930527], [70.4404068, 22.97931099], [70.4404068, 22.97903061], [70.43985748, 22.97903061], [70.43985748, 22.97875023], [70.43930817, 22.97875023], [70.43930817, 22.97846985], [70.43875122, 22.97847366], [70.43875122, 22.97819519], [70.43763733, 22.97819519], [70.43763733, 22.97847366], [70.43374634, 22.97846985], [70.43374634, 22.97875023], [70.43264008, 22.97875023], [70.43264008, 22.97958565], [70.4329071, 22.97957993], [70.4329071, 22.98014069], [70.43319702, 22.98014069], [70.43319702, 22.98042107], [70.43347168, 22.98041725], [70.43347168, 22.98069572], [70.43374634, 22.98069], [70.43374634, 22.98097992], [70.43402863, 22.98097992], [70.43402863, 22.98180962], [70.43430328, 22.98180962], [70.43430328, 22.98236084], [70.43486023, 22.98236084], [70.43486023, 22.98264122], [70.43515015, 22.98264122], [70.43515015, 22.98291969], [70.43541718, 22.98291779], [70.43541718, 22.98319435], [70.43569183, 22.98319054], [70.43569183, 22.98374939], [70.43653107, 22.98374939], [70.43653107, 22.98404121], [70.43708038, 22.98404121], [70.43708038, 22.98431015], [70.43763733, 22.98430634], [70.43763733, 22.9845829], [70.43791962, 22.9845829], [70.43791962, 22.98486137], [70.43846893, 22.98485947], [70.43846893, 22.98513985], [70.43902588, 22.98513985], [70.43902588, 22.98541832], [70.43930817, 22.98541641], [70.43930817, 22.98569489], [70.43958282, 22.98569489], [70.43958282, 22.98597145], [70.43985748, 22.98596954], [70.43985748, 22.98624992], [70.44013977, 22.98624992], [70.44013977, 22.9865284], [70.44069672, 22.9865284], [70.44069672, 22.98681068], [70.44097137, 22.98680496], [70.44097137, 22.98708344], [70.44125366, 22.98708344], [70.44125366, 22.98736191], [70.4420929, 22.98735809], [70.4420929, 22.98763847], [70.44264221, 22.98763847], [70.44264221, 22.98792076], [70.44291687, 22.98791695], [70.44291687, 22.9881897], [70.44347382, 22.98819542], [70.44347382, 22.98847008], [70.44374847, 22.98846817], [70.44374847, 22.98875237], [70.44403076, 22.98875237], [70.44403076, 22.98903275], [70.44458008, 22.98903275], [70.44458008, 22.98931122], [70.44513702, 22.9893055], [70.44513702, 22.98958206], [70.44541931, 22.98958206], [70.44541931, 22.98986053], [70.44596863, 22.98984909], [70.44596863, 22.99014282], [70.44680786, 22.99014282], [70.44680786, 22.99041939], [70.44736481, 22.99041748], [70.44736481, 22.99069214], [70.44763947, 22.99069023], [70.44763947, 22.9912529], [70.44819641, 22.9912529], [70.44819641, 22.99152946], [70.44847107, 22.99152946], [70.44847107, 22.99180984], [70.44875336, 22.99180984], [70.44875336, 22.99152946], [70.44902802, 22.99152946], [70.44902802, 22.99180984], [70.44930267, 22.99180603], [70.44930267, 22.9920845], [70.44958496, 22.9920845], [70.44958496, 22.99236107], [70.44985962, 22.99236107], [70.44985962, 22.99263954], [70.45014954, 22.99263954], [70.45014954, 22.99291992], [70.45097351, 22.99291611], [70.45097351, 22.99319458], [70.45153046, 22.99319458], [70.45153046, 22.99347305], [70.45180511, 22.99347305], [70.45180511, 22.99374962], [70.45207977, 22.99374962], [70.45207977, 22.99403], [70.45263672, 22.99402809], [70.45263672, 22.99430466], [70.45319366, 22.99430466], [70.45319366, 22.99458313], [70.45347595, 22.99458313], [70.45347595, 22.9948616], [70.45375061, 22.9948597], [70.45375061, 22.99514008], [70.4540329, 22.99514008], [70.4540329, 22.99542046], [70.45485687, 22.99542046], [70.45485687, 22.99570084], [70.45513916, 22.99570084]]], [[[70.44124603, 23.04624939], [70.44124603, 23.04681015], [70.44152832, 23.04681015], [70.44152832, 23.04709053], [70.44180298, 23.04708481], [70.44180298, 23.04736137], [70.4420929, 23.04735947], [70.4420929, 23.04763985], [70.44235992, 23.04763794], [70.44235992, 23.04819679], [70.44264221, 23.04819679], [70.44264221, 23.04847145], [70.44291687, 23.04846954], [70.44291687, 23.04874992], [70.44346619, 23.04874992], [70.44346619, 23.0490303], [70.44403076, 23.0490303], [70.44403076, 23.04931068], [70.44430542, 23.04930687], [70.44430542, 23.04986191], [70.44458008, 23.04986191], [70.44458008, 23.05013847], [70.44486237, 23.05013084], [70.44486237, 23.05042076], [70.44541931, 23.05041695], [70.44541931, 23.05069351], [70.44596863, 23.05069351], [70.44596863, 23.05097198], [70.44652557, 23.05097198], [70.44652557, 23.05125046], [70.44709015, 23.05125046], [70.44709015, 23.05153084], [70.44763947, 23.05153084], [70.44763947, 23.05181122], [70.44819641, 23.0518055], [70.44819641, 23.05208397], [70.44847107, 23.05208397], [70.44847107, 23.0518055], [70.44875336, 23.05181122], [70.44875336, 23.05125046], [70.44902802, 23.05125046], [70.44902802, 23.05097008], [70.44875336, 23.05097198], [70.44875336, 23.05041695], [70.44847107, 23.05042076], [70.44847107, 23.05022812], [70.44847107, 23.05013847], [70.44829559, 23.05013847], [70.44819641, 23.05013847], [70.44819641, 23.04986191], [70.44791412, 23.04986191], [70.44791412, 23.04930687], [70.44763947, 23.04931068], [70.44763947, 23.04763985], [70.44735718, 23.04763985], [70.44735718, 23.04709053], [70.44709015, 23.04709053], [70.44709015, 23.04681015], [70.44680786, 23.04681015], [70.44680786, 23.04624939], [70.44652557, 23.04624939], [70.44652557, 23.04569244], [70.44625092, 23.04569244], [70.44625092, 23.04486275], [70.44596863, 23.04486275], [70.44596863, 23.04432106], [70.44568634, 23.04432106], [70.44568634, 23.04347038], [70.44541931, 23.04347038], [70.44541931, 23.04291725], [70.44513702, 23.04292107], [70.44513702, 23.04208183], [70.44486237, 23.04208374], [70.44486237, 23.04153061], [70.44458008, 23.04153061], [70.44458008, 23.04070091], [70.44431305, 23.04070091], [70.44431305, 23.04013824], [70.44403076, 23.04013824], [70.44403076, 23.03874969], [70.44374847, 23.03874969], [70.44374847, 23.03736115], [70.44346619, 23.03736115], [70.44346619, 23.03652954], [70.44319153, 23.03652954], [70.44319153, 23.03569031], [70.44291687, 23.03569412], [70.44291687, 23.03486061], [70.44264221, 23.03486061], [70.44264221, 23.03445053], [70.44264221, 23.0340271], [70.44235992, 23.03403091], [70.44235992, 23.03347015], [70.44208527, 23.03347206], [70.44208527, 23.03291702], [70.44180298, 23.03292084], [70.44180298, 23.03236008], [70.44152832, 23.03236389], [70.44152832, 23.03180313], [70.44124603, 23.03181076], [70.44124603, 23.03096962], [70.44097137, 23.03097343], [70.44097137, 23.03013802], [70.44069672, 23.03014183], [70.44069672, 23.02957916], [70.44041443, 23.02958107], [70.44041443, 23.02874947], [70.44013977, 23.02874947], [70.44013977, 23.02792168], [70.43985748, 23.02792168], [70.43985748, 23.02708054], [70.43958282, 23.02708244], [70.43958282, 23.02625084], [70.43930817, 23.02625084], [70.43930817, 23.02542114], [70.43902588, 23.02542114], [70.43902588, 23.02458], [70.43875122, 23.02458382], [70.43875122, 23.02402687], [70.43846893, 23.02403069], [70.43846893, 23.02321053], [70.43818665, 23.02321053], [70.43818665, 23.02235985], [70.43791962, 23.02236176], [70.43791962, 23.02152824], [70.43763733, 23.02153015], [70.43763733, 23.02069092], [70.43736267, 23.02069473], [70.43736267, 23.02013969], [70.43708038, 23.02015114], [70.43708038, 23.01958084], [70.43680573, 23.01958466], [70.43680573, 23.01902771], [70.43653107, 23.01902962], [70.43653107, 23.01847076], [70.43624878, 23.01847458], [70.43624878, 23.01791763], [70.43596649, 23.01791954], [70.43596649, 23.01736259], [70.43569183, 23.01736259], [70.43569183, 23.0165329], [70.43541718, 23.0165329], [70.43541718, 23.01597023], [70.43514252, 23.01597023], [70.43514252, 23.0154171], [70.43486023, 23.01542282], [70.43486023, 23.01485825], [70.43458557, 23.01486015], [70.43458557, 23.01430511], [70.43430328, 23.01431084], [70.43430328, 23.01374817], [70.43402863, 23.01374817], [70.43402863, 23.0134697], [70.43374634, 23.0134716], [70.43374634, 23.01291656], [70.43347168, 23.01292038], [70.43347168, 23.01235962], [70.43319702, 23.01236153], [70.43319702, 23.01208305], [70.43291473, 23.01208305], [70.43291473, 23.01152611], [70.43264008, 23.01152992], [70.43264008, 23.01098061], [70.43235779, 23.01098061], [70.43235779, 23.01069069], [70.43208313, 23.0106945], [70.43208313, 23.01013947], [70.43180847, 23.01013947], [70.43180847, 23.00986099], [70.43152618, 23.00986099], [70.43152618, 23.00930977], [70.43125153, 23.00930977], [70.43125153, 23.00875092], [70.43096924, 23.00875092], [70.43096924, 23.00847054], [70.43069458, 23.00847244], [70.43069458, 23.0079174], [70.43041992, 23.00792122], [70.43041992, 23.00736046], [70.43013763, 23.00736046], [70.43013763, 23.00708008], [70.42986298, 23.0070858], [70.42986298, 23.00652695], [70.42958069, 23.00653076], [70.42958069, 23.00597], [70.42930603, 23.00597382], [70.42930603, 23.00541687], [70.42901611, 23.00542068], [70.42901611, 23.00485992], [70.42874908, 23.00486374], [70.42874908, 23.00458145], [70.42847443, 23.00458145], [70.42847443, 23.00430489], [70.42819214, 23.00430489], [70.42819214, 23.00402832], [70.42764282, 23.00403023], [70.42764282, 23.00375175], [70.42736053, 23.00375175], [70.42736053, 23.00346947], [70.42708588, 23.00347137], [70.42708588, 23.00319481], [70.42680359, 23.00319481], [70.42680359, 23.00264168], [70.42652893, 23.00264168], [70.42652893, 23.00235939], [70.42624664, 23.00235939], [70.42624664, 23.00208282], [70.42597198, 23.00208282], [70.42597198, 23.00180626], [70.42569733, 23.00181007], [70.42569733, 23.00124931], [70.42542267, 23.00124931], [70.42542267, 23.00069046], [70.42514038, 23.00069427], [70.42514038, 23.0004158], [70.42457581, 23.00042152], [70.42457581, 23.00013924], [70.42457581, 22.99958038], [70.42430878, 22.9995842], [70.42430878, 22.99930573], [70.42402649, 22.99930954], [70.42402649, 22.9990406], [70.42375183, 22.9990406], [70.42375183, 22.99875069], [70.42346954, 22.99875069], [70.42346954, 22.99818993], [70.42319489, 22.99819374], [70.42319489, 22.99791718], [70.42292023, 22.99792099], [70.42292023, 22.99736023], [70.4225769, 22.99736023], [70.42236328, 22.99736023], [70.42236328, 22.99707985], [70.42208099, 22.99708366], [70.42208099, 22.99680519], [70.42180634, 22.99681091], [70.42180634, 22.99653053], [70.42151642, 22.99653053], [70.42151642, 22.99625015], [70.42124939, 22.99625015], [70.42124939, 22.99598122], [70.4209671, 22.99598122], [70.4209671, 22.99542046], [70.42069244, 22.99542046], [70.42069244, 22.99514008], [70.42041779, 22.99514008], [70.42041779, 22.9948597], [70.4201355, 22.9948616], [70.4201355, 22.99458313], [70.41958618, 22.99458313], [70.41958618, 22.99430466], [70.41930389, 22.99430466], [70.41930389, 22.99402809], [70.41874695, 22.99403], [70.41874695, 22.99374962], [70.41819763, 22.99374962], [70.41819763, 22.99347115], [70.41791534, 22.99347305], [70.41791534, 22.99319458], [70.41764069, 22.99319458], [70.41764069, 22.99263954], [70.41707611, 22.99263954], [70.41707611, 22.99208069], [70.41680908, 22.9920845], [70.41680908, 22.99180603], [70.41652679, 22.99180984], [70.41652679, 22.99152946], [70.41625214, 22.99152946], [70.41625214, 22.99097061], [70.41596985, 22.99097061], [70.41596985, 22.99069214], [70.41569519, 22.99069214], [70.41569519, 22.99041748], [70.4154129, 22.99041939], [70.4154129, 22.99014282], [70.41485596, 22.99014282], [70.41485596, 22.98984909], [70.41374969, 22.98984909], [70.41374969, 22.99014282], [70.41348267, 22.99014282], [70.41348267, 22.99041939], [70.41319275, 22.99041748], [70.41319275, 22.99069214], [70.41291809, 22.99069023], [70.41291809, 22.9912529], [70.4126358, 22.9912529], [70.4126358, 22.99291992], [70.41236115, 22.99291992], [70.41236115, 22.99374962], [70.41208649, 22.99374962], [70.41208649, 22.99458313], [70.41179657, 22.99458122], [70.41179657, 22.99542046], [70.41152954, 22.99542046], [70.41152954, 22.99625015], [70.41124725, 22.99625015], [70.41124725, 22.99708366], [70.4109726, 22.99708366], [70.4109726, 22.99819374], [70.41069794, 22.99819374], [70.41069794, 22.99847221], [70.41042328, 22.99847031], [70.41042328, 22.9990406], [70.41069794, 22.9990406], [70.41069794, 22.99930954], [70.41041565, 22.99930573], [70.41041565, 22.9995842], [70.41069794, 22.99958038], [70.41069794, 22.99986076], [70.41069794, 23.00069427], [70.41098022, 23.00069046], [70.41098022, 23.00292015], [70.41124725, 23.00292015], [70.41124725, 23.0051403], [70.41152954, 23.0051403], [70.41152954, 23.00625038], [70.4118042, 23.00625038], [70.4118042, 23.00847244], [70.41208649, 23.00847054], [70.41208649, 23.01098061], [70.41236115, 23.01098061], [70.41236115, 23.01263809], [70.4126358, 23.01263809], [70.4126358, 23.01431084], [70.41291809, 23.01430511], [70.41291809, 23.01569366], [70.41319275, 23.01569176], [70.41319275, 23.0165329], [70.41347504, 23.01652718], [70.41347504, 23.01708221], [70.41374969, 23.01708031], [70.41374969, 23.01764107], [70.41402435, 23.01763916], [70.41402435, 23.01819229], [70.41430664, 23.01819038], [70.41430664, 23.01875114], [70.4145813, 23.01875114], [70.4145813, 23.01931], [70.41486359, 23.01930618], [70.41486359, 23.01958466], [70.41513824, 23.01958084], [70.41513824, 23.02015114], [70.4154129, 23.02015114], [70.4154129, 23.02042007], [70.41569519, 23.02041626], [70.41569519, 23.02069473], [70.41596985, 23.02069092], [70.41596985, 23.02124977], [70.41625214, 23.02124977], [70.41625214, 23.02153015], [70.41652679, 23.02152824], [70.41652679, 23.02180672], [70.41680908, 23.02180672], [70.41680908, 23.02236176], [70.41707611, 23.02235985], [70.41707611, 23.02264023], [70.4173584, 23.02264023], [70.4173584, 23.02292061], [70.41764069, 23.02291679], [70.41764069, 23.02347183], [70.41791534, 23.02347183], [70.41791534, 23.02375031], [70.41819763, 23.02375031], [70.41819763, 23.02403069], [70.41847229, 23.02402687], [70.41847229, 23.02458382], [70.41874695, 23.02458], [70.41874695, 23.02486038], [70.41902924, 23.02486038], [70.41902924, 23.02514076], [70.41929626, 23.02514076], [70.41929626, 23.02542114], [70.41958618, 23.02541733], [70.41958618, 23.02569389], [70.41986084, 23.02569008], [70.41986084, 23.02625084], [70.42014313, 23.02625084], [70.42014313, 23.02653122], [70.42041779, 23.02653122], [70.42041779, 23.02680969], [70.42069244, 23.02680588], [70.42069244, 23.02708244], [70.4209671, 23.02708054], [70.4209671, 23.02736092], [70.42151642, 23.02736092], [70.42151642, 23.02763939], [70.42180634, 23.02763939], [70.42180634, 23.02792168], [70.42236328, 23.02791595], [70.42236328, 23.02819443], [70.42263794, 23.02819443], [70.42263794, 23.0284729], [70.42318726, 23.02846909], [70.42318726, 23.02874947], [70.42375183, 23.02874947], [70.42375183, 23.02902794], [70.42402649, 23.0290184], [70.42402649, 23.02931023], [70.42430878, 23.02930641], [70.42430878, 23.02958107], [70.42485809, 23.02958107], [70.42485809, 23.02985954], [70.42514038, 23.02985954], [70.42514038, 23.03014183], [70.42542267, 23.03014183], [70.42542267, 23.0304203], [70.42569733, 23.0304203], [70.42569733, 23.03070068], [70.42624664, 23.03069305], [70.42624664, 23.03097343], [70.42652893, 23.03096962], [70.42652893, 23.03125191], [70.42679596, 23.03125191], [70.42679596, 23.03153038], [70.42736053, 23.03153038], [70.42736053, 23.03181076], [70.42764282, 23.03181076], [70.42764282, 23.03209114], [70.42819214, 23.0320816], [70.42819214, 23.03236389], [70.4284668, 23.03236008], [70.4284668, 23.03264046], [70.42874908, 23.03264046], [70.42874908, 23.03292084], [70.42930603, 23.03291702], [70.42930603, 23.0331955], [70.42958069, 23.0331955], [70.42958069, 23.03347206], [70.42986298, 23.03347015], [70.42986298, 23.03375053], [70.43013763, 23.03375053], [70.43013763, 23.03403091], [70.43041992, 23.03403091], [70.43041992, 23.03430939], [70.43069458, 23.03430557], [70.43069458, 23.03458595], [70.43096924, 23.03458023], [70.43096924, 23.03486061], [70.43125153, 23.03486061], [70.43125153, 23.03515053], [70.43152618, 23.03513908], [70.43152618, 23.03569412], [70.43180847, 23.03569412], [70.43180847, 23.0359726], [70.43209076, 23.03597069], [70.43209076, 23.03625107], [70.43235779, 23.03625107], [70.43235779, 23.03652954], [70.43264008, 23.03652954], [70.43264008, 23.03680992], [70.43291473, 23.03680611], [70.43291473, 23.03708267], [70.43319702, 23.03708076], [70.43319702, 23.03736115], [70.43347168, 23.03736115], [70.43347168, 23.03763962], [70.43374634, 23.03763962], [70.43374634, 23.03791809], [70.43402863, 23.03791618], [70.43402863, 23.03847313], [70.43430328, 23.03847122], [70.43430328, 23.03874969], [70.4345932, 23.03874969], [70.4345932, 23.03902817], [70.43486023, 23.03902817], [70.43486023, 23.03958321], [70.43514252, 23.03958321], [70.43514252, 23.03986168], [70.43541718, 23.03985977], [70.43541718, 23.04013824], [70.43569183, 23.04013824], [70.43569183, 23.04042053], [70.43596649, 23.04042053], [70.43596649, 23.04070091], [70.43624878, 23.04069519], [70.43624878, 23.04097176], [70.43653107, 23.04096031], [70.43653107, 23.04153061], [70.43681335, 23.04153061], [70.43681335, 23.0418129], [70.43708038, 23.04180527], [70.43708038, 23.04208374], [70.43736267, 23.04208183], [70.43736267, 23.04236031], [70.43763733, 23.04236031], [70.43763733, 23.04264259], [70.43791962, 23.04264259], [70.43791962, 23.04292107], [70.43819427, 23.04291725], [70.43819427, 23.04319382], [70.43846893, 23.04319382], [70.43846893, 23.04347038], [70.43875122, 23.04347038], [70.43875122, 23.04375267], [70.43902588, 23.04375267], [70.43902588, 23.04403114], [70.43930817, 23.04403114], [70.43930817, 23.04432106], [70.43958282, 23.0443058], [70.43958282, 23.04458046], [70.43985748, 23.04458046], [70.43985748, 23.04486275], [70.44013977, 23.04486275], [70.44013977, 23.04514122], [70.44041443, 23.04513931], [70.44041443, 23.04569244], [70.44069672, 23.04569244], [70.44069672, 23.04597473], [70.44095612, 23.04597282], [70.44095612, 23.04624939], [70.44124603, 23.04624939]]], [[[70.44152832, 23.04958344], [70.44152832, 23.04819679], [70.44125366, 23.04819679], [70.44125366, 23.04763794], [70.44095612, 23.04763985], [70.44095612, 23.04735947], [70.44069672, 23.04736137], [70.44069672, 23.04708481], [70.4404068, 23.04709053], [70.4404068, 23.04681015], [70.44013977, 23.04681015], [70.44013977, 23.04652977], [70.43985748, 23.04652977], [70.43985748, 23.04624939], [70.43958282, 23.04624939], [70.43958282, 23.04597282], [70.43930817, 23.04597473], [70.43930817, 23.04569244], [70.43902588, 23.04569244], [70.43902588, 23.04541588], [70.43875122, 23.04541969], [70.43875122, 23.04514122], [70.43846893, 23.04514122], [70.43846893, 23.04486275], [70.43818665, 23.04486275], [70.43818665, 23.04458046], [70.43791962, 23.04458046], [70.43791962, 23.0443058], [70.43763733, 23.04432106], [70.43763733, 23.04403114], [70.43736267, 23.04403114], [70.43736267, 23.04375267], [70.43708038, 23.04375267], [70.43708038, 23.04319191], [70.43680573, 23.04319382], [70.43680573, 23.04291725], [70.43653107, 23.04292107], [70.43653107, 23.04236031], [70.43624878, 23.04236031], [70.43624878, 23.04208183], [70.43597412, 23.04208374], [70.43597412, 23.04180527], [70.43569183, 23.0418129], [70.43569183, 23.04153061], [70.43541718, 23.04153061], [70.43541718, 23.04124832], [70.43514252, 23.04124832], [70.43514252, 23.04097176], [70.43486023, 23.04097176], [70.43486023, 23.04069519], [70.4345932, 23.04070091], [70.4345932, 23.04042053], [70.43430328, 23.04042053], [70.43430328, 23.03985977], [70.43402863, 23.03986168], [70.43402863, 23.03930473], [70.43374634, 23.03930473], [70.43374634, 23.03902817], [70.43347168, 23.03902817], [70.43347168, 23.03874969], [70.4329071, 23.03874969], [70.4329071, 23.03847122], [70.43264008, 23.03847313], [70.43264008, 23.03819466], [70.43235779, 23.03819466], [70.43235779, 23.03763962], [70.43208313, 23.03763962], [70.43208313, 23.03736115], [70.43180847, 23.03736115], [70.43180847, 23.03680992], [70.43152618, 23.03680992], [70.43152618, 23.03652954], [70.43125153, 23.03652954], [70.43125153, 23.03625107], [70.43096924, 23.03625107], [70.43096924, 23.03597069], [70.43069458, 23.0359726], [70.43069458, 23.03569412], [70.43041992, 23.03569412], [70.43041992, 23.03541756], [70.43013763, 23.03541946], [70.43013763, 23.03515053], [70.42986298, 23.03515053], [70.42986298, 23.03486061], [70.42958069, 23.03486061], [70.42958069, 23.03458023], [70.42903137, 23.03458595], [70.42903137, 23.03430557], [70.42874908, 23.03430939], [70.42874908, 23.03403091], [70.4284668, 23.03403091], [70.4284668, 23.03375053], [70.42791748, 23.03375053], [70.42791748, 23.03347015], [70.42763519, 23.03347206], [70.42763519, 23.0331955], [70.42708588, 23.0331955], [70.42708588, 23.03291702], [70.42679596, 23.03292084], [70.42679596, 23.03264046], [70.42652893, 23.03264046], [70.42652893, 23.03236008], [70.42597198, 23.03236389], [70.42597198, 23.0320816], [70.42569733, 23.03209114], [70.42569733, 23.03181076], [70.42542267, 23.03181076], [70.42542267, 23.03153038], [70.42485809, 23.03153038], [70.42485809, 23.03125191], [70.42457581, 23.03125191], [70.42457581, 23.03096962], [70.42402649, 23.03097343], [70.42402649, 23.03069305], [70.42375183, 23.03070068], [70.42375183, 23.0304203], [70.42318726, 23.0304203], [70.42318726, 23.03014183], [70.42292023, 23.03014183], [70.42292023, 23.02985954], [70.42236328, 23.02985954], [70.42236328, 23.02958107], [70.42208099, 23.02958107], [70.42208099, 23.02930641], [70.42151642, 23.02931023], [70.42151642, 23.02874947], [70.42124939, 23.02874947], [70.42124939, 23.02846909], [70.42097473, 23.0284729], [70.42097473, 23.02819443], [70.42041779, 23.02819443], [70.42041779, 23.02791595], [70.42014313, 23.02792168], [70.42014313, 23.02763939], [70.41986084, 23.02763939], [70.41986084, 23.02736092], [70.41958618, 23.02736092], [70.41958618, 23.02708054], [70.41930389, 23.02708244], [70.41930389, 23.02680588], [70.41874695, 23.02680969], [70.41874695, 23.02653122], [70.41847229, 23.02653122], [70.41847229, 23.02625084], [70.41819763, 23.02625084], [70.41819763, 23.02596092], [70.41791534, 23.02597237], [70.41791534, 23.02569389], [70.41764069, 23.02569389], [70.41764069, 23.02541733], [70.4173584, 23.02542114], [70.4173584, 23.02486038], [70.41707611, 23.02486038], [70.41707611, 23.02458], [70.41680908, 23.02458382], [70.41680908, 23.02430534], [70.41652679, 23.02431107], [70.41652679, 23.02403069], [70.41625214, 23.02403069], [70.41625214, 23.02375031], [70.41596985, 23.02375031], [70.41596985, 23.02321053], [70.41570282, 23.02321053], [70.41570282, 23.02292061], [70.4154129, 23.02292061], [70.4154129, 23.02264023], [70.4145813, 23.02263832], [70.4145813, 23.02458382], [70.41485596, 23.02458], [70.41485596, 23.02653122], [70.41506195, 23.0265274], [70.41513824, 23.0265274], [70.41513824, 23.02792168], [70.4154129, 23.02791595], [70.4154129, 23.02902794], [70.41569519, 23.02902794], [70.41569519, 23.02958107], [70.41596985, 23.02957916], [70.41596985, 23.0304203], [70.41625214, 23.03041649], [70.41625214, 23.03097343], [70.41652679, 23.03096962], [70.41652679, 23.03153038], [70.41680908, 23.03153038], [70.41681671, 23.03209114], [70.41708374, 23.0320816], [70.41708374, 23.03226089], [70.41708374, 23.03236389], [70.41720581, 23.03236389], [70.4173584, 23.03236389], [70.4173584, 23.03244972], [70.4173584, 23.03292084], [70.41764069, 23.03291702], [70.41764069, 23.03347206], [70.41791534, 23.03347206], [70.41791534, 23.03375053], [70.41819763, 23.03375053], [70.41819763, 23.03430939], [70.41847229, 23.03430557], [70.41847229, 23.03458595], [70.41819763, 23.03458023], [70.41819763, 23.03486061], [70.41847229, 23.03486061], [70.41847229, 23.03515053], [70.41874695, 23.03515053], [70.41874695, 23.03541946], [70.41902924, 23.03541756], [70.41902924, 23.0359726], [70.41929626, 23.03597069], [70.41929626, 23.03625107], [70.41958618, 23.03625107], [70.41958618, 23.03652954], [70.41986084, 23.03652954], [70.41986084, 23.03680992], [70.4200058, 23.03680611], [70.4201355, 23.03680611], [70.4201355, 23.03717041], [70.4201355, 23.03736115], [70.42035675, 23.03736115], [70.42041779, 23.03763962], [70.42069244, 23.03763962], [70.42069244, 23.03791809], [70.42097473, 23.03791618], [70.42097473, 23.03819466], [70.42124939, 23.03819466], [70.42124939, 23.03847313], [70.42151642, 23.03847122], [70.42151642, 23.03902817], [70.42180634, 23.03902817], [70.42180634, 23.03930473], [70.42208099, 23.03930473], [70.42208099, 23.03958321], [70.42236328, 23.03958321], [70.42236328, 23.03986168], [70.42263794, 23.03985977], [70.42263794, 23.04013824], [70.42292023, 23.04013824], [70.42292023, 23.04042053], [70.42318726, 23.04042053], [70.42318726, 23.04070091], [70.42346954, 23.04069519], [70.42346954, 23.04097176], [70.42375183, 23.04096031], [70.42375183, 23.04124832], [70.42430878, 23.04124832], [70.42430878, 23.04153061], [70.42457581, 23.04153061], [70.42457581, 23.0418129], [70.42485809, 23.04180527], [70.42485809, 23.04208374], [70.42514038, 23.04208183], [70.42514038, 23.04236031], [70.42542267, 23.04236031], [70.42542267, 23.04264259], [70.42569733, 23.04264259], [70.42569733, 23.04292107], [70.42597198, 23.04291725], [70.42597198, 23.04319382], [70.42624664, 23.04319382], [70.42624664, 23.04347038], [70.42652893, 23.04347038], [70.42652893, 23.04375267], [70.42708588, 23.04375267], [70.42708588, 23.04403114], [70.42736053, 23.04403114], [70.42736053, 23.04432106], [70.42763519, 23.0443058], [70.42763519, 23.04458427], [70.42791748, 23.04458046], [70.42791748, 23.04514122], [70.42819214, 23.04514122], [70.42819214, 23.04541969], [70.42847443, 23.04541588], [70.42847443, 23.04569244], [70.42874908, 23.04569054], [70.42874908, 23.04624939], [70.42901611, 23.04624939], [70.42901611, 23.04652977], [70.42958069, 23.04652977], [70.42958069, 23.04681015], [70.43013763, 23.04681015], [70.43013763, 23.04709053], [70.43069458, 23.04708481], [70.43069458, 23.04736137], [70.43125153, 23.04735947], [70.43125153, 23.04763985], [70.43180847, 23.04763985], [70.43180847, 23.04792023], [70.43235779, 23.04791641], [70.43235779, 23.04819679], [70.43291473, 23.04819679], [70.43291473, 23.04847145], [70.43430328, 23.04846954], [70.43430328, 23.04874992], [70.43596649, 23.04874992], [70.43596649, 23.0490303], [70.43736267, 23.0490303], [70.43736267, 23.04931068], [70.44097137, 23.04930687], [70.44097137, 23.04958344], [70.44152832, 23.04958344]]], [[[70.48236084, 23.06541824], [70.48236084, 23.06485939], [70.4826355, 23.0648613], [70.4826355, 23.06374931], [70.48236084, 23.06375122], [70.48236084, 23.06264114], [70.48208618, 23.06264114], [70.48208618, 23.06207085], [70.48180389, 23.0620842], [70.48180389, 23.06152725], [70.48152924, 23.06153107], [70.48152924, 23.06097031], [70.48124695, 23.06097221], [70.48124695, 23.06069565], [70.48097229, 23.06069565], [70.48097229, 23.0601387], [70.48069763, 23.06014061], [70.48069763, 23.05986023], [70.48041534, 23.05986023], [70.48041534, 23.05958366], [70.48014069, 23.05958366], [70.48014069, 23.05930328], [70.4798584, 23.05932045], [70.4798584, 23.05903053], [70.47957611, 23.05903053], [70.47957611, 23.05881119], [70.47930908, 23.05875015], [70.47930908, 23.05820084], [70.47902679, 23.05820084], [70.47902679, 23.05792046], [70.47875214, 23.05792046], [70.47875214, 23.05764008], [70.47846985, 23.05764008], [70.47846985, 23.0573597], [70.47819519, 23.05736351], [70.47819519, 23.05708122], [70.4779129, 23.05708122], [70.4779129, 23.05680466], [70.47736359, 23.05680466], [70.47736359, 23.05652809], [70.47706604, 23.05653191], [70.47706604, 23.05626106], [70.47651672, 23.05626106], [70.47651672, 23.05596924], [70.47624969, 23.05597115], [70.47624969, 23.05569458], [70.47569275, 23.05569458], [70.47569275, 23.05541611], [70.47541809, 23.05542183], [70.47541809, 23.05514145], [70.47486115, 23.05514145], [70.47486115, 23.05485916], [70.47458649, 23.05485916], [70.47458649, 23.05458069], [70.4743042, 23.0545826], [70.4743042, 23.05430603], [70.47374725, 23.05431175], [70.47374725, 23.05403137], [70.4734726, 23.05403137], [70.4734726, 23.05374908], [70.47319794, 23.05374908], [70.47319794, 23.05347061], [70.47291565, 23.05347252], [70.47291565, 23.05319405], [70.4723587, 23.05319405], [70.4723587, 23.05291748], [70.47207642, 23.05291748], [70.47207642, 23.05264091], [70.47180939, 23.05264091], [70.47180176, 23.05236053], [70.4715271, 23.05236053], [70.4715271, 23.05208015], [70.47097015, 23.05208397], [70.47097015, 23.0518055], [70.47070313, 23.05181122], [70.47070313, 23.05153084], [70.47041321, 23.05153084], [70.47041321, 23.05125046], [70.47013855, 23.05125046], [70.47013855, 23.05097008], [70.4695816, 23.05097198], [70.4695816, 23.05069351], [70.46930695, 23.05069351], [70.46930695, 23.05041695], [70.46901703, 23.05042076], [70.46901703, 23.05013084], [70.46875, 23.05013847], [70.46875, 23.04986191], [70.46847534, 23.04986191], [70.46847534, 23.04958344], [70.4679184, 23.04958344], [70.4679184, 23.04930687], [70.46763611, 23.04931068], [70.46763611, 23.0490303], [70.46736145, 23.0490303], [70.46736145, 23.04874992], [70.46708679, 23.04874992], [70.46708679, 23.04846954], [70.46652985, 23.04847145], [70.46652985, 23.04819679], [70.46624756, 23.04819679], [70.46624756, 23.04791641], [70.46569824, 23.04792023], [70.46569824, 23.04763985], [70.46541595, 23.04763985], [70.46541595, 23.04735947], [70.4651413, 23.04736137], [70.4651413, 23.04708481], [70.46485901, 23.04709053], [70.46485901, 23.04681015], [70.46457672, 23.04681015], [70.46457672, 23.04652977], [70.46430206, 23.04652977], [70.46430206, 23.04624939], [70.4640274, 23.04624939], [70.4640274, 23.04597282], [70.46375275, 23.04597473], [70.46375275, 23.04569244], [70.46347046, 23.04569244], [70.46347046, 23.04541588], [70.4631958, 23.04541969], [70.4631958, 23.04514122], [70.46290588, 23.04514122], [70.46290588, 23.04486275], [70.46263885, 23.04486275], [70.46263885, 23.04458046], [70.4623642, 23.04458046], [70.4623642, 23.0443058], [70.46208954, 23.04432106], [70.46208954, 23.04403114], [70.46180725, 23.04403114], [70.46180725, 23.04375267], [70.46152496, 23.04375267], [70.46152496, 23.04347038], [70.46125031, 23.04347038], [70.46125031, 23.04319382], [70.46097565, 23.04319382], [70.46097565, 23.04291725], [70.46069336, 23.04292107], [70.46069336, 23.04264259], [70.4604187, 23.04264259], [70.4604187, 23.04292107], [70.46013641, 23.04291725], [70.46013641, 23.04319382], [70.45986176, 23.04319191], [70.45986176, 23.04432106], [70.4595871, 23.04432106], [70.4595871, 23.04124832], [70.45929718, 23.04124832], [70.45929718, 23.04096031], [70.45903015, 23.04097176], [70.45903015, 23.04041672], [70.45874786, 23.04042053], [70.45874786, 23.03985977], [70.45847321, 23.03986168], [70.45847321, 23.03930473], [70.45819092, 23.03930473], [70.45819092, 23.03902817], [70.45791626, 23.03902817], [70.45791626, 23.03874969], [70.4576416, 23.03874969], [70.4576416, 23.03819084], [70.45735931, 23.03819466], [70.45735931, 23.03763962], [70.45707703, 23.03763962], [70.45707703, 23.03708076], [70.45680237, 23.03708267], [70.45680237, 23.03652763], [70.45652771, 23.03652954], [70.45652771, 23.03625107], [70.45625305, 23.03625107], [70.45625305, 23.03569031], [70.45597076, 23.03569412], [70.45597076, 23.03513908], [70.45569611, 23.03515053], [70.45569611, 23.03486061], [70.45540619, 23.03486061], [70.45540619, 23.03430939], [70.45527649, 23.03430939], [70.45513916, 23.03430939], [70.45513916, 23.03403091], [70.45485687, 23.03403091], [70.45485687, 23.03347015], [70.45458221, 23.03347206], [70.45458221, 23.03291702], [70.45430756, 23.03292084], [70.45430756, 23.03236008], [70.45402527, 23.03236389], [70.45402527, 23.0320816], [70.45375061, 23.03209114], [70.45375061, 23.03153038], [70.45347595, 23.03153038], [70.45347595, 23.03096962], [70.45319366, 23.03097343], [70.45319366, 23.03041649], [70.45291901, 23.0304203], [70.45291901, 23.02931023], [70.45263672, 23.02931023], [70.45263672, 23.02846909], [70.45236206, 23.0284729], [70.45236206, 23.02763939], [70.45207977, 23.02763939], [70.45207977, 23.02708054], [70.45180511, 23.02708244], [70.45180511, 23.0265274], [70.45153046, 23.02653122], [70.45153046, 23.02625084], [70.45096588, 23.02625084], [70.45096588, 23.02596092], [70.45069122, 23.02597237], [70.45069122, 23.02569389], [70.45014191, 23.02569389], [70.45014191, 23.02541733], [70.44875336, 23.02542114], [70.44875336, 23.02514076], [70.44625092, 23.02513885], [70.44625092, 23.02569389], [70.4465332, 23.02569008], [70.4465332, 23.02680969], [70.44680786, 23.02680969], [70.44680786, 23.02792168], [70.44708252, 23.02791595], [70.44708252, 23.0284729], [70.44735718, 23.02846909], [70.44735718, 23.02931023], [70.44763947, 23.02931023], [70.44763947, 23.03014183], [70.44790649, 23.03014183], [70.44790649, 23.03070068], [70.44819641, 23.03070068], [70.44819641, 23.03125191], [70.44847107, 23.03125191], [70.44847107, 23.03181076], [70.44875336, 23.03180313], [70.44875336, 23.03236389], [70.44902802, 23.03236008], [70.44902802, 23.03292084], [70.44930267, 23.03291702], [70.44930267, 23.03347206], [70.44959259, 23.03347015], [70.44959259, 23.03403091], [70.44985962, 23.0340271], [70.44985962, 23.03458595], [70.45014954, 23.03458023], [70.45014954, 23.03515053], [70.45041656, 23.03513908], [70.45041656, 23.03569412], [70.45069122, 23.03569031], [70.45069122, 23.03652954], [70.45097351, 23.03652763], [70.45097351, 23.03708267], [70.45124817, 23.03708076], [70.45124817, 23.03791809], [70.45153046, 23.03791618], [70.45153046, 23.03847313], [70.45180511, 23.03847313], [70.45180511, 23.03866005], [70.45180511, 23.03930473], [70.45207977, 23.03930473], [70.45207977, 23.03986168], [70.45236206, 23.03985977], [70.45236206, 23.04070091], [70.45263672, 23.04070091], [70.45263672, 23.04153061], [70.45291901, 23.04153061], [70.45291901, 23.04236031], [70.45318604, 23.04236031], [70.45318604, 23.04292107], [70.45347595, 23.04291725], [70.45347595, 23.04347038], [70.45375061, 23.04347038], [70.45375061, 23.04375267], [70.4540329, 23.04375267], [70.4540329, 23.04403114], [70.45430756, 23.04402733], [70.45430756, 23.04458427], [70.45458221, 23.04458046], [70.45458221, 23.04486275], [70.45485687, 23.04486275], [70.45485687, 23.04541969], [70.45513916, 23.04541588], [70.45513916, 23.04569244], [70.45540619, 23.04569054], [70.45540619, 23.04624939], [70.45569611, 23.04624939], [70.45569611, 23.04652977], [70.45597076, 23.04652977], [70.45597076, 23.04709053], [70.45625305, 23.04708481], [70.45625305, 23.04736137], [70.45652771, 23.04735947], [70.45652771, 23.04792023], [70.45680237, 23.04791641], [70.45680237, 23.04819679], [70.45708466, 23.04819679], [70.45708466, 23.04847145], [70.45735931, 23.04846954], [70.45735931, 23.04874992], [70.4576416, 23.04874992], [70.4576416, 23.0490303], [70.45791626, 23.0490303], [70.45791626, 23.04931068], [70.45819092, 23.04930687], [70.45819092, 23.04986191], [70.45874786, 23.04986191], [70.45874786, 23.0490284], [70.45903015, 23.0490303], [70.45903015, 23.04763985], [70.4595871, 23.04763985], [70.4595871, 23.04652977], [70.45986176, 23.04652786], [70.45986176, 23.04847145], [70.4595871, 23.04847145], [70.4595871, 23.04986191], [70.45930481, 23.04986191], [70.45930481, 23.05013847], [70.4595871, 23.05013084], [70.4595871, 23.05042076], [70.45986176, 23.05041695], [70.45986176, 23.05097198], [70.46013641, 23.05097008], [70.46013641, 23.05153084], [70.4604187, 23.05152893], [70.4604187, 23.05208397], [70.46069336, 23.05208015], [70.46069336, 23.05236053], [70.46098328, 23.05236053], [70.46098328, 23.05264091], [70.46125031, 23.05264091], [70.46125031, 23.05291748], [70.46152496, 23.05291748], [70.46152496, 23.05319405], [70.46180725, 23.05319023], [70.46180725, 23.05374908], [70.46208954, 23.05374908], [70.46208954, 23.05403137], [70.46235657, 23.05403137], [70.46235657, 23.05431175], [70.46263885, 23.05430603], [70.46263885, 23.0545826], [70.46290588, 23.05458069], [70.46290588, 23.05485916], [70.4631958, 23.05485916], [70.4631958, 23.05514145], [70.46375275, 23.05514145], [70.46375275, 23.05542183], [70.4640274, 23.05541611], [70.4640274, 23.05569458], [70.46430206, 23.05569458], [70.46430206, 23.05597115], [70.46457672, 23.05596924], [70.46457672, 23.05626106], [70.46512604, 23.05626106], [70.46512604, 23.05653191], [70.46569061, 23.05652809], [70.46569824, 23.05680466], [70.46624756, 23.05680466], [70.46624756, 23.05708122], [70.4668045, 23.05708122], [70.4668045, 23.05736351], [70.46736145, 23.0573597], [70.46736145, 23.05764008], [70.46875, 23.05764008], [70.46875, 23.05792046], [70.46902466, 23.05791664], [70.46902466, 23.05804062], [70.46901703, 23.05820084], [70.4695816, 23.05819511], [70.4695816, 23.05847359], [70.46985626, 23.05846977], [70.46985626, 23.05875015], [70.47013855, 23.05875015], [70.47013855, 23.05903053], [70.47070313, 23.05903053], [70.47070313, 23.05932045], [70.47097015, 23.05930328], [70.47097015, 23.05958366], [70.47126007, 23.05957985], [70.47126007, 23.06014061], [70.4715271, 23.06014061], [70.4715271, 23.06042099], [70.47180176, 23.06041718], [70.47180176, 23.06069565], [70.4723587, 23.06069565], [70.4723587, 23.06097221], [70.47291565, 23.06097221], [70.47291565, 23.06125069], [70.4734726, 23.06125069], [70.4734726, 23.06153107], [70.47402954, 23.06153107], [70.47402954, 23.06180954], [70.47458649, 23.06180573], [70.47458649, 23.0620842], [70.4751358, 23.06207085], [70.4751358, 23.06236076], [70.47541809, 23.06236076], [70.47541809, 23.06264114], [70.47598267, 23.06264114], [70.47598267, 23.06291962], [70.47624969, 23.06291771], [70.47624969, 23.06319427], [70.47680664, 23.06319427], [70.47680664, 23.06347275], [70.47706604, 23.06347084], [70.47706604, 23.06375122], [70.4779129, 23.06375122], [70.4779129, 23.06402969], [70.47846985, 23.06402969], [70.47846985, 23.06430817], [70.47930908, 23.06430626], [70.47930908, 23.06458282], [70.48014069, 23.06458282], [70.48014069, 23.0648613], [70.48069763, 23.0648613], [70.48069763, 23.06513977], [70.48152924, 23.06513023], [70.48152924, 23.06541824], [70.48236084, 23.06541824]]], [[[70.45903015, 23.05764008], [70.45903015, 23.05708122], [70.45930481, 23.05708122], [70.45930481, 23.05652809], [70.45903015, 23.05653191], [70.45903015, 23.05626106], [70.45929718, 23.05626106], [70.45929718, 23.05596924], [70.46013641, 23.05597115], [70.46013641, 23.05558968], [70.46013641, 23.05541611], [70.4604187, 23.05542183], [70.4604187, 23.05514145], [70.46013641, 23.05514145], [70.46013641, 23.05485916], [70.45986176, 23.05485916], [70.45986176, 23.05458069], [70.4595871, 23.0545826], [70.4595871, 23.05430603], [70.45929718, 23.05431175], [70.45929718, 23.05403137], [70.45903015, 23.05403137], [70.45903015, 23.05374908], [70.45874786, 23.05374908], [70.45874786, 23.05319023], [70.45847321, 23.05319405], [70.45847321, 23.05291748], [70.45819092, 23.05291748], [70.45819092, 23.05264091], [70.45791626, 23.05264091], [70.45791626, 23.05236053], [70.4576416, 23.05236053], [70.4576416, 23.05208015], [70.45708466, 23.05208397], [70.45708466, 23.0518055], [70.45680237, 23.05181122], [70.45680237, 23.05153084], [70.45625305, 23.05153084], [70.45625305, 23.05097008], [70.45652771, 23.05097008], [70.45652771, 23.05125046], [70.45707703, 23.05125046], [70.45707703, 23.05153084], [70.45735931, 23.05153084], [70.45735931, 23.05181122], [70.4576416, 23.05181122], [70.4576416, 23.0506897], [70.45735931, 23.05069351], [70.45735931, 23.05013847], [70.45708466, 23.05013847], [70.45708466, 23.04986191], [70.45680237, 23.04986191], [70.45680237, 23.04958344], [70.45652771, 23.04958344], [70.45652771, 23.04930687], [70.45625305, 23.04931068], [70.45625305, 23.0490303], [70.45597076, 23.0490303], [70.45597076, 23.04874992], [70.45569611, 23.04874992], [70.45569611, 23.04846954], [70.45541382, 23.04847145], [70.45541382, 23.04819679], [70.4548645, 23.04819679], [70.4548645, 23.04791641], [70.45458221, 23.04792023], [70.45458221, 23.04763985], [70.4540329, 23.04763985], [70.4540329, 23.04735947], [70.45375061, 23.04736137], [70.45375061, 23.04708481], [70.45347595, 23.04709053], [70.45347595, 23.04681015], [70.45291901, 23.04681015], [70.45291901, 23.04652977], [70.45263672, 23.04652977], [70.45263672, 23.04624939], [70.45236206, 23.04624939], [70.45236206, 23.04597282], [70.45207977, 23.04597473], [70.45207977, 23.04569244], [70.45180511, 23.04569244], [70.45180511, 23.04541588], [70.45153046, 23.04541969], [70.45153046, 23.04514122], [70.45124817, 23.04514122], [70.45124817, 23.04486275], [70.45096588, 23.04486275], [70.45096588, 23.04458046], [70.45069122, 23.04458046], [70.45069122, 23.04402733], [70.45041656, 23.04403114], [70.45041656, 23.04347038], [70.45014191, 23.04347038], [70.45014191, 23.04319382], [70.44958496, 23.04319382], [70.44958496, 23.04375267], [70.44985962, 23.04375267], [70.44985962, 23.04486275], [70.45014954, 23.04486275], [70.45014954, 23.04541969], [70.45041656, 23.04541588], [70.45041656, 23.04597473], [70.45069122, 23.04597282], [70.45069122, 23.04652977], [70.45096588, 23.04652977], [70.45096588, 23.04681015], [70.45153046, 23.04681015], [70.45153046, 23.04709053], [70.45181274, 23.04709053], [70.45181274, 23.04763985], [70.45153046, 23.04763985], [70.45153046, 23.04792023], [70.45207977, 23.04791641], [70.45207977, 23.04819679], [70.45236206, 23.04819107], [70.45236206, 23.0490303], [70.45207977, 23.0490303], [70.45207977, 23.04931068], [70.45153046, 23.04931068], [70.45153046, 23.0490303], [70.45096588, 23.0490303], [70.45096588, 23.04931068], [70.45124817, 23.04930687], [70.45124817, 23.04958344], [70.45153046, 23.04958344], [70.45153046, 23.04986191], [70.45207977, 23.04986191], [70.45207977, 23.05013847], [70.45236206, 23.05013847], [70.45236206, 23.0506897], [70.45263672, 23.05070114], [70.45263672, 23.05153084], [70.45318604, 23.05153084], [70.45318604, 23.05181122], [70.45347595, 23.0518055], [70.45347595, 23.05208397], [70.45375061, 23.05208015], [70.45375061, 23.05236053], [70.4540329, 23.05236053], [70.4540329, 23.05264091], [70.45430756, 23.05264091], [70.45430756, 23.05291748], [70.45458221, 23.05291748], [70.45458221, 23.05319405], [70.4548645, 23.05319405], [70.4548645, 23.05347252], [70.45513916, 23.05347061], [70.45513916, 23.05374908], [70.45541382, 23.05374718], [70.45540619, 23.05391121], [70.45540619, 23.05403137], [70.45581055, 23.05404472], [70.45597076, 23.05405045], [70.45597076, 23.05431175], [70.45652771, 23.05430603], [70.45652771, 23.0545826], [70.45680237, 23.05458069], [70.45680237, 23.05485916], [70.45735931, 23.05485916], [70.45735931, 23.05514145], [70.45652771, 23.05514145], [70.45652771, 23.05485916], [70.45540619, 23.05485916], [70.45540619, 23.05514145], [70.45485687, 23.05514145], [70.45485687, 23.05485916], [70.45458221, 23.05485916], [70.45458221, 23.05458069], [70.45430756, 23.0545826], [70.45430756, 23.05430603], [70.45375061, 23.05431175], [70.45375061, 23.05403137], [70.45318604, 23.05403137], [70.45318604, 23.05374908], [70.45291901, 23.05374908], [70.45291901, 23.05347061], [70.45236206, 23.05347252], [70.45236206, 23.05319405], [70.45207977, 23.05319405], [70.45207977, 23.05291748], [70.45181274, 23.05291748], [70.45181274, 23.05264091], [70.45041656, 23.05264091], [70.45041656, 23.05236053], [70.44959259, 23.05236053], [70.44959259, 23.05264091], [70.44985962, 23.05264091], [70.44985962, 23.05291748], [70.45041656, 23.05291748], [70.45041656, 23.05319405], [70.45069122, 23.05319405], [70.45069122, 23.05347252], [70.45096588, 23.05347061], [70.45096588, 23.05374908], [70.45124817, 23.05374908], [70.45124817, 23.05403137], [70.45153046, 23.05403137], [70.45153046, 23.05431175], [70.45180511, 23.05430603], [70.45180511, 23.0545826], [70.45236206, 23.05458069], [70.45236206, 23.05485916], [70.45263672, 23.05485916], [70.45263672, 23.05514145], [70.45291901, 23.05514145], [70.45291901, 23.05542183], [70.45375061, 23.05541611], [70.45375061, 23.05569458], [70.45430756, 23.05569458], [70.45430756, 23.05597115], [70.45458221, 23.05596924], [70.45458221, 23.05626106], [70.45513916, 23.05626106], [70.45513916, 23.05653191], [70.45541382, 23.05652809], [70.45541382, 23.05680466], [70.45680237, 23.05680466], [70.45680237, 23.05708122], [70.45791626, 23.05708122], [70.45791626, 23.05736351], [70.45819092, 23.0573597], [70.45819092, 23.05764008], [70.45903015, 23.05764008]]], [[[70.45236206, 23.05236053], [70.45236206, 23.05208015], [70.45207977, 23.05208397], [70.45207977, 23.05152893], [70.45181274, 23.05153084], [70.45181274, 23.05097008], [70.45153046, 23.05097198], [70.45153046, 23.05069351], [70.45124817, 23.05069351], [70.45124817, 23.05041695], [70.45041656, 23.05042076], [70.45041656, 23.05013084], [70.45014191, 23.05013847], [70.45014191, 23.05097198], [70.45041656, 23.05097008], [70.45041656, 23.05125046], [70.45069122, 23.05125046], [70.45069122, 23.05153084], [70.45097351, 23.05152893], [70.45097351, 23.0518055], [70.45114136, 23.0518055], [70.45153046, 23.0518055], [70.45153046, 23.05200005], [70.45153046, 23.05236053], [70.45207977, 23.05236053], [70.45207977, 23.05264091], [70.45236206, 23.05264091], [70.45236206, 23.05291748], [70.45263672, 23.05291748], [70.45263672, 23.05319405], [70.45347595, 23.05319405], [70.45347595, 23.05291748], [70.45333099, 23.05291748], [70.45318604, 23.05291748], [70.45318604, 23.05264091], [70.45291901, 23.05264091], [70.45291901, 23.05236053], [70.45236206, 23.05236053]]], [[[70.4695816, 23.06125069], [70.4695816, 23.06097031], [70.47013855, 23.06097221], [70.47013855, 23.06069565], [70.46986389, 23.06069565], [70.46986389, 23.06041718], [70.46930695, 23.06042099], [70.46930695, 23.06014061], [70.46901703, 23.06014061], [70.46901703, 23.05986023], [70.46847534, 23.05986023], [70.46847534, 23.05930328], [70.46819305, 23.05932045], [70.46819305, 23.05875015], [70.46679688, 23.05875015], [70.46679688, 23.05846977], [70.46624756, 23.05847359], [70.46624756, 23.05819511], [70.4659729, 23.05820084], [70.4659729, 23.05792046], [70.46541595, 23.05792046], [70.46541595, 23.05764008], [70.46485901, 23.05764008], [70.46482849, 23.05737114], [70.46430206, 23.0573597], [70.46430206, 23.05721092], [70.46430206, 23.05708122], [70.46388245, 23.05708122], [70.46347046, 23.05708122], [70.46347046, 23.05696106], [70.46347046, 23.05680466], [70.46291351, 23.05680466], [70.46291351, 23.05652809], [70.46235657, 23.05653191], [70.46235657, 23.05626106], [70.46208954, 23.05626106], [70.46208954, 23.05596924], [70.46152496, 23.05597115], [70.46152496, 23.05569458], [70.46097565, 23.05569458], [70.46097565, 23.05541611], [70.46069336, 23.05541611], [70.46069336, 23.05569077], [70.4604187, 23.05570984], [70.4604187, 23.05626106], [70.46013641, 23.05626106], [70.46013641, 23.05653191], [70.46069336, 23.05652809], [70.46069336, 23.05680466], [70.46098328, 23.05680084], [70.46098328, 23.05764008], [70.46125031, 23.05764008], [70.46125031, 23.05792046], [70.46208954, 23.05792046], [70.46208954, 23.05820084], [70.46263885, 23.05819511], [70.46263885, 23.05847359], [70.4631958, 23.05846977], [70.4631958, 23.05875015], [70.46375275, 23.05875015], [70.46375275, 23.05903053], [70.46457672, 23.05903053], [70.46457672, 23.05932045], [70.4651413, 23.05930328], [70.4651413, 23.05958366], [70.46541595, 23.05957985], [70.46541595, 23.05986023], [70.4659729, 23.05986023], [70.4659729, 23.06014061], [70.46652985, 23.06014061], [70.46652985, 23.06042099], [70.46708679, 23.06041718], [70.46708679, 23.06069565], [70.46763611, 23.06069565], [70.46763611, 23.06097221], [70.46819305, 23.06097031], [70.46819305, 23.06125069], [70.4695816, 23.06125069]]], [[[70.45207977, 23.06069565], [70.45207977, 23.06041718], [70.45236206, 23.06042099], [70.45236206, 23.05986023], [70.45207977, 23.05986023], [70.45207977, 23.05932045], [70.45124817, 23.05932045], [70.45124817, 23.05903053], [70.45069122, 23.05903053], [70.45069122, 23.05875015], [70.45014191, 23.05875015], [70.45014191, 23.05847359], [70.44958496, 23.05847359], [70.44958496, 23.05819511], [70.44902802, 23.05820084], [70.44902802, 23.05792046], [70.44625092, 23.05792046], [70.44625092, 23.05820084], [70.44596863, 23.05819511], [70.44596863, 23.05847359], [70.44625092, 23.05846977], [70.44625092, 23.05875015], [70.44680786, 23.05875015], [70.44680786, 23.05903053], [70.44709015, 23.05903053], [70.44709015, 23.05932045], [70.44819641, 23.05930328], [70.44819641, 23.05958366], [70.44902802, 23.05957985], [70.44902802, 23.05986023], [70.45014954, 23.05986023], [70.45014954, 23.06014061], [70.45096588, 23.06014061], [70.45096588, 23.06042099], [70.45153046, 23.06041718], [70.45153046, 23.06069565], [70.45207977, 23.06069565]]], [[[68.47319794, 23.35680962], [68.47319794, 23.35653114], [68.4734726, 23.35653114], [68.4734726, 23.35625076], [68.47402954, 23.35625076], [68.47402954, 23.35597038], [68.4743042, 23.35597229], [68.4743042, 23.35569572], [68.4751358, 23.35569572], [68.4751358, 23.35486031], [68.47541809, 23.35486031], [68.47541809, 23.35514069], [68.47570038, 23.35514069], [68.47570038, 23.35542107], [68.47651672, 23.35542107], [68.47651672, 23.35403061], [68.47624969, 23.35403061], [68.47624969, 23.35346985], [68.47486115, 23.35346985], [68.47486115, 23.35375023], [68.47402954, 23.35375023], [68.47402954, 23.35403061], [68.4734726, 23.3540287], [68.4734726, 23.35458565], [68.47374725, 23.35457993], [68.47374725, 23.35514069], [68.47207642, 23.35514069], [68.47207642, 23.35542107], [68.47180176, 23.35541725], [68.47180176, 23.35569572], [68.4715271, 23.35569572], [68.4715271, 23.35597229], [68.47097015, 23.35597038], [68.47097015, 23.35625076], [68.47125244, 23.35625076], [68.47125244, 23.35680962], [68.47319794, 23.35680962]]], [[[68.53514099, 23.38763809], [68.53514099, 23.3870697], [68.5348587, 23.38708305], [68.5348587, 23.38652992], [68.53457642, 23.38652992], [68.53457642, 23.38597107], [68.53430939, 23.38597298], [68.53430176, 23.38541794], [68.5340271, 23.38541985], [68.5340271, 23.38486099], [68.53375244, 23.38486099], [68.53375244, 23.38513947], [68.53235626, 23.38513947], [68.53235626, 23.38458061], [68.5320816, 23.38458252], [68.5320816, 23.38263893], [68.53235626, 23.38264084], [68.53235626, 23.38208008], [68.53263855, 23.3820858], [68.53263855, 23.38152695], [68.53291321, 23.38153076], [68.53291321, 23.38125992], [68.53263855, 23.38125992], [68.53263855, 23.38097], [68.5320816, 23.38097382], [68.5320816, 23.38069534], [68.53235626, 23.38070107], [68.53235626, 23.38042068], [68.5340271, 23.38042068], [68.5340271, 23.37957954], [68.53375244, 23.37958145], [68.53375244, 23.37874985], [68.53430176, 23.37874985], [68.53430176, 23.37792015], [68.53347015, 23.37792015], [68.53347015, 23.37763977], [68.53291321, 23.37763977], [68.53291321, 23.37708092], [68.53263855, 23.37708282], [68.53263855, 23.37680626], [68.5348587, 23.37680626], [68.5348587, 23.37708282], [68.53531647, 23.37708282], [68.5359726, 23.37708282], [68.5359726, 23.3773613], [68.53624725, 23.37735939], [68.53624725, 23.37763977], [68.53652954, 23.37763977], [68.53652954, 23.37735939], [68.5368042, 23.3773613], [68.5368042, 23.37652779], [68.53652954, 23.3765316], [68.53652954, 23.37624931], [68.53514099, 23.37624931], [68.53514099, 23.37597084], [68.53457642, 23.37597084], [68.53457642, 23.37624931], [68.53430939, 23.37624931], [68.53430176, 23.37597084], [68.5340271, 23.37597275], [68.5340271, 23.37559128], [68.5340271, 23.37486076], [68.53375244, 23.37486076], [68.53375244, 23.37431145], [68.5340271, 23.37431145], [68.5340271, 23.37375069], [68.53457642, 23.37375069], [68.53457642, 23.37431145], [68.5348587, 23.37431145], [68.5348587, 23.37486076], [68.53514099, 23.37486076], [68.53514099, 23.37542152], [68.53569794, 23.37542152], [68.53569794, 23.37486076], [68.53652954, 23.37486076], [68.53652954, 23.37431145], [68.53679657, 23.37431145], [68.53679657, 23.37402916], [68.53624725, 23.37402916], [68.53624725, 23.37375069], [68.53652954, 23.37375069], [68.53652954, 23.37347031], [68.5368042, 23.37347221], [68.5368042, 23.3726387], [68.53652954, 23.37264061], [68.53652954, 23.37236023], [68.53624725, 23.37236023], [68.53624725, 23.37207031], [68.5359726, 23.37208366], [68.5359726, 23.37180519], [68.53569794, 23.37181091], [68.53569794, 23.37153053], [68.53542328, 23.37153053], [68.53542328, 23.37125015], [68.53430176, 23.37125015], [68.53430176, 23.37153053], [68.53347015, 23.37153053], [68.53347015, 23.37181091], [68.53291321, 23.37180519], [68.53291321, 23.37208366], [68.53320312, 23.37207031], [68.53320312, 23.37264061], [68.53291321, 23.3726387], [68.53291321, 23.37297058], [68.53291321, 23.37319374], [68.53263855, 23.37318993], [68.53263855, 23.37375069], [68.53235626, 23.37375069], [68.53235626, 23.37486076], [68.5320816, 23.37486076], [68.5320816, 23.37624931], [68.53180695, 23.37624931], [68.53180695, 23.37847137], [68.53151703, 23.37846947], [68.53151703, 23.38042068], [68.53125, 23.38042068], [68.53125, 23.38125992], [68.53097534, 23.38125038], [68.53097534, 23.3820858], [68.53069305, 23.38208008], [68.53069305, 23.38292122], [68.5304184, 23.3829174], [68.5304184, 23.38319588], [68.53069305, 23.38319016], [68.53069305, 23.38486099], [68.53125, 23.38486099], [68.53125, 23.38513947], [68.53180695, 23.38513947], [68.53180695, 23.38541985], [68.5320816, 23.38541794], [68.5320816, 23.3856945], [68.53263855, 23.3856945], [68.53263855, 23.38597298], [68.5331955, 23.38597298], [68.5331955, 23.38624954], [68.53347015, 23.38624954], [68.53347015, 23.38652992], [68.53375244, 23.38652992], [68.53375244, 23.3868084], [68.5340271, 23.38680649], [68.5340271, 23.38736153], [68.53430176, 23.38735962], [68.53430176, 23.38763809], [68.53514099, 23.38763809]]], [[[68.50291443, 23.38347244], [68.50291443, 23.38319588], [68.50319672, 23.38319588], [68.50319672, 23.38263893], [68.50347137, 23.38264084], [68.50347137, 23.38236046], [68.50319672, 23.38236046], [68.50319672, 23.38208008], [68.50291443, 23.3820858], [68.50291443, 23.38097382], [68.50319672, 23.38097382], [68.50319672, 23.38069534], [68.50347137, 23.38070107], [68.50347137, 23.38042068], [68.50374603, 23.38042068], [68.50374603, 23.3801403], [68.50430298, 23.3801403], [68.50430298, 23.37985992], [68.50514221, 23.37986374], [68.50514221, 23.37902832], [68.50541687, 23.37903023], [68.50541687, 23.37874985], [68.50514221, 23.37874985], [68.50514221, 23.37799072], [68.50514221, 23.3773613], [68.50430298, 23.37735939], [68.50430298, 23.37763977], [68.50374603, 23.37763977], [68.50374603, 23.37792015], [68.50319672, 23.37791634], [68.50319672, 23.37808037], [68.50319672, 23.37820053], [68.50291443, 23.37819481], [68.50291443, 23.37847137], [68.50263977, 23.37846947], [68.50263977, 23.37903023], [68.50291443, 23.37902832], [68.50291443, 23.37930489], [68.50263977, 23.37930489], [68.50263977, 23.37986374], [68.50235748, 23.37985992], [68.50235748, 23.38042068], [68.50208282, 23.38041687], [68.50208282, 23.38097382], [68.50180817, 23.38097382], [68.50180817, 23.3820858], [68.50235748, 23.38208008], [68.50235748, 23.38236046], [68.50263977, 23.38236046], [68.50263977, 23.38347244], [68.50291443, 23.38347244]]], [[[68.50597382, 23.34236145], [68.50597382, 23.34208488], [68.50624847, 23.34209061], [68.50624847, 23.34152985], [68.50653076, 23.34152985], [68.50653076, 23.34097099], [68.50875092, 23.34097481], [68.50875092, 23.34069252], [68.50961304, 23.34069252], [68.51041412, 23.34069252], [68.51041412, 23.34041405], [68.51097107, 23.34041977], [68.51097107, 23.34013939], [68.51152802, 23.34013939], [68.51152802, 23.33986282], [68.51235962, 23.33986282], [68.51235962, 23.33958054], [68.51291656, 23.33958244], [68.51291656, 23.33930588], [68.51374817, 23.33930588], [68.51374817, 23.33958244], [68.51457977, 23.33958054], [68.51457977, 23.33986282], [68.51513672, 23.33986282], [68.51513672, 23.34013939], [68.51541901, 23.34013939], [68.51541901, 23.34041977], [68.51569366, 23.34041405], [68.51569366, 23.34097481], [68.51597595, 23.34097099], [68.51597595, 23.34124947], [68.5167923, 23.34124947], [68.51790619, 23.34124947], [68.51790619, 23.34152985], [68.51930237, 23.34152985], [68.51930237, 23.34124947], [68.51985931, 23.34124947], [68.51985931, 23.34097099], [68.5201416, 23.34097481], [68.5201416, 23.34069252], [68.52069092, 23.34069252], [68.52069092, 23.33930588], [68.52041626, 23.33930969], [68.52041626, 23.33875275], [68.52153015, 23.33875275], [68.52153015, 23.33708191], [68.52180481, 23.33708382], [68.52180481, 23.33680534], [68.52236176, 23.33681107], [68.52236176, 23.33653259], [68.52263641, 23.33653259], [68.52263641, 23.33736038], [68.5229187, 23.33736038], [68.5229187, 23.33792114], [68.5256958, 23.33792114], [68.5256958, 23.33736038], [68.52597046, 23.33736038], [68.52597046, 23.33708191], [68.5276413, 23.33708382], [68.5276413, 23.33652687], [68.52791595, 23.33653259], [68.52791595, 23.3354187], [68.52819824, 23.3354187], [68.52819824, 23.33457756], [68.5284729, 23.33458328], [68.5284729, 23.3334713], [68.52874756, 23.3334713], [68.52874756, 23.33263969], [68.5284729, 23.33263969], [68.5284729, 23.33152962], [68.52819824, 23.33152962], [68.52819824, 23.33097076], [68.52735901, 23.33097267], [68.52735901, 23.3306942], [68.5265274, 23.3306942], [68.5265274, 23.33041763], [68.5256958, 23.33041954], [68.5256958, 23.3301506], [68.52597046, 23.3301506], [68.52597046, 23.32958031], [68.52625275, 23.32958412], [68.52625275, 23.32902718], [68.5265274, 23.32903099], [68.5265274, 23.32875061], [68.52680969, 23.32875061], [68.52680206, 23.32819557], [68.52708435, 23.32819557], [68.52708435, 23.3279171], [68.52735901, 23.32792091], [68.52735901, 23.32764053], [68.5276413, 23.32764053], [68.5276413, 23.32736015], [68.52791595, 23.32736206], [68.52791595, 23.32708549], [68.52819824, 23.32708549], [68.52819824, 23.32680321], [68.5284729, 23.32681084], [68.5284729, 23.32653046], [68.52874756, 23.32653046], [68.52874756, 23.32625008], [68.52902985, 23.32625008], [68.52902985, 23.3259697], [68.52986145, 23.3259716], [68.52986145, 23.32569313], [68.5304184, 23.32570076], [68.5304184, 23.32542038], [68.53125, 23.32542038], [68.53125, 23.32514191], [68.53180695, 23.32514191], [68.53180695, 23.32485962], [68.53375244, 23.32486343], [68.53375244, 23.32458115], [68.5340271, 23.32458115], [68.5340271, 23.32430649], [68.53430176, 23.3243103], [68.53430939, 23.32401848], [68.5348587, 23.32402802], [68.5348587, 23.32374954], [68.53514099, 23.32374954], [68.53514099, 23.32346916], [68.53541565, 23.32347107], [68.53541565, 23.3231945], [68.53569794, 23.3231945], [68.53569794, 23.32291603], [68.53598022, 23.32292175], [68.53598022, 23.32263947], [68.53624725, 23.32263947], [68.53624725, 23.32235909], [68.53679657, 23.32235909], [68.53679657, 23.32208061], [68.53708649, 23.32208252], [68.53708649, 23.32180595], [68.53736115, 23.32181168], [68.53736115, 23.32068825], [68.53624725, 23.32068825], [68.53624725, 23.32125092], [68.53598022, 23.32125092], [68.53598022, 23.32181168], [68.53569794, 23.32180595], [68.53569794, 23.32208252], [68.53541565, 23.32208252], [68.53541565, 23.32180595], [68.5348587, 23.32181168], [68.5348587, 23.32152939], [68.53457642, 23.32152939], [68.53457642, 23.32125092], [68.53430939, 23.32125092], [68.53430176, 23.32068825], [68.5340271, 23.32069397], [68.5340271, 23.3204174], [68.53430176, 23.32041931], [68.53430939, 23.31986046], [68.53624725, 23.31986046], [68.53624725, 23.31957817], [68.53652954, 23.31958389], [68.53652954, 23.31930542], [68.53679657, 23.31931114], [68.53679657, 23.31903076], [68.53736115, 23.31903076], [68.53736115, 23.31875038], [68.5376358, 23.31875038], [68.5376358, 23.31847], [68.53736115, 23.31847191], [68.53736115, 23.31819534], [68.53708649, 23.3182106], [68.53708649, 23.31792068], [68.53652954, 23.31792068], [68.53652954, 23.3176403], [68.53624725, 23.3176403], [68.53624725, 23.31735992], [68.5359726, 23.31736183], [68.5359726, 23.31680679], [68.53569794, 23.31680679], [68.53569794, 23.31652832], [68.5304184, 23.31652832], [68.5304184, 23.31680679], [68.52791595, 23.31680679], [68.52791595, 23.31708336], [68.51930237, 23.31708336], [68.51930237, 23.31736183], [68.51763916, 23.31735992], [68.51763916, 23.3176403], [68.51625061, 23.3176403], [68.51625061, 23.31792068], [68.51513672, 23.31792068], [68.51513672, 23.3182106], [68.51319122, 23.31819534], [68.51319122, 23.31847191], [68.51152802, 23.31847], [68.51152802, 23.31875038], [68.51097107, 23.31875038], [68.51097107, 23.31903076], [68.51040649, 23.31903076], [68.51040649, 23.31931114], [68.50958252, 23.31930542], [68.50958252, 23.31958389], [68.50902557, 23.31958389], [68.5090332, 23.31986046], [68.50846863, 23.31986046], [68.50846863, 23.32014084], [68.50791931, 23.32014084], [68.50791931, 23.32041931], [68.50763702, 23.3204174], [68.50763702, 23.32069397], [68.50708008, 23.32068825], [68.50708008, 23.32098007], [68.50680542, 23.32097244], [68.50681305, 23.32125092], [68.50653076, 23.32125092], [68.50653076, 23.32152939], [68.50624847, 23.32152939], [68.50624847, 23.32181168], [68.50569153, 23.32180595], [68.50569153, 23.32208252], [68.50541687, 23.32208061], [68.50541687, 23.32235909], [68.50514221, 23.32235909], [68.50514221, 23.32263947], [68.5045929, 23.32263947], [68.5045929, 23.32292175], [68.50402832, 23.32291603], [68.50402832, 23.3231945], [68.50347137, 23.3231945], [68.50347137, 23.32347107], [68.5029068, 23.32346916], [68.5029068, 23.32374954], [68.50235748, 23.32374954], [68.50235748, 23.32402802], [68.5029068, 23.32401848], [68.5029068, 23.3243103], [68.50319672, 23.32430649], [68.50319672, 23.32458115], [68.50347137, 23.32458115], [68.50347137, 23.32486343], [68.50374603, 23.32485962], [68.50374603, 23.32542038], [68.50402832, 23.32542038], [68.50402832, 23.32570076], [68.50430298, 23.32570076], [68.50430298, 23.32792091], [68.5045929, 23.32792091], [68.5045929, 23.32707977], [68.50514221, 23.32707977], [68.50514221, 23.32903099], [68.50485992, 23.32902718], [68.50485992, 23.32958412], [68.50541687, 23.32958031], [68.50541687, 23.32986069], [68.50514221, 23.32986069], [68.50514221, 23.3306942], [68.50541687, 23.3306942], [68.50541687, 23.33097267], [68.50596619, 23.33097076], [68.50596619, 23.33125114], [68.50681305, 23.33125114], [68.50681305, 23.33152962], [68.50708008, 23.33152771], [68.50708008, 23.33208275], [68.50680542, 23.33208275], [68.50681305, 23.33236122], [68.50653076, 23.33236122], [68.50653076, 23.33263969], [68.50624847, 23.33263969], [68.50624847, 23.33291817], [68.50596619, 23.33291817], [68.50596619, 23.33374977], [68.50653076, 23.33374977], [68.50653076, 23.3354187], [68.50596619, 23.3354187], [68.50596619, 23.33513832], [68.50567627, 23.33513832], [68.50567627, 23.33429909], [68.50541687, 23.33430481], [68.50541687, 23.3334713], [68.50514221, 23.3334713], [68.50514221, 23.33319473], [68.50485992, 23.33319473], [68.50485992, 23.33291626], [68.5045929, 23.33291817], [68.5045929, 23.33180809], [68.50430298, 23.33180618], [68.50430298, 23.33208275], [68.50319672, 23.33208084], [68.50319672, 23.33291817], [68.50291443, 23.33291626], [68.50291443, 23.33430481], [68.50319672, 23.33430481], [68.50319672, 23.33458328], [68.50347137, 23.33457756], [68.50347137, 23.3357029], [68.50319672, 23.3357029], [68.50319672, 23.33736038], [68.50291443, 23.33736038], [68.50291443, 23.3390274], [68.50263977, 23.33902168], [68.50263977, 23.34041977], [68.50291443, 23.34041405], [68.50291443, 23.34097481], [68.50319672, 23.34097099], [68.50319672, 23.34124947], [68.50347137, 23.34124947], [68.50347137, 23.34152985], [68.50374603, 23.34152985], [68.50374603, 23.34209061], [68.50402832, 23.34208488], [68.50402832, 23.34236145], [68.50597382, 23.34236145]]], [[[68.52513885, 23.34403038], [68.52513885, 23.34375], [68.52902985, 23.34375], [68.52902985, 23.34346962], [68.52958679, 23.34347153], [68.52958679, 23.34319687], [68.5304184, 23.34320068], [68.5304184, 23.3429203], [68.53098297, 23.3429203], [68.53098297, 23.34263992], [68.53125, 23.34263992], [68.53125, 23.34235954], [68.53180695, 23.34236145], [68.53180695, 23.34208488], [68.5320816, 23.34209061], [68.5320816, 23.34181023], [68.53235626, 23.34181023], [68.53235626, 23.34152985], [68.53263855, 23.34152985], [68.53263855, 23.34097099], [68.53236389, 23.34097481], [68.53236389, 23.34069252], [68.5320816, 23.34069252], [68.5320816, 23.33930588], [68.53069305, 23.33930969], [68.53069305, 23.34013939], [68.5304184, 23.34013939], [68.5304184, 23.34097481], [68.5293045, 23.34097481], [68.5293045, 23.34041405], [68.52874756, 23.34041405], [68.52874756, 23.34069252], [68.52819824, 23.34069252], [68.52819061, 23.34097481], [68.5276413, 23.34097099], [68.5276413, 23.34124947], [68.52707672, 23.34124947], [68.52707672, 23.34152985], [68.52597046, 23.34152985], [68.52597046, 23.34181023], [68.52513885, 23.34181023], [68.52513885, 23.34209061], [68.52402496, 23.34208488], [68.52402496, 23.34236145], [68.52319336, 23.34235954], [68.52319336, 23.34263992], [68.52124786, 23.34263802], [68.52124786, 23.34347153], [68.52319336, 23.34346962], [68.52319336, 23.34375], [68.52375031, 23.34375], [68.52375031, 23.34403038], [68.52513885, 23.34403038]]], [[[68.60901642, 23.23125267], [68.60901642, 23.23097038], [68.60958099, 23.23097038], [68.60958099, 23.23069382], [68.60986328, 23.23069954], [68.60986328, 23.23042107], [68.61013794, 23.23042107], [68.61013794, 23.22986031], [68.61042023, 23.22986031], [68.61042023, 23.22958183], [68.61069489, 23.22958374], [68.61069489, 23.22930527], [68.61096954, 23.2293129], [68.61096954, 23.22874832], [68.61125946, 23.22874832], [68.61125183, 23.22819519], [68.61152649, 23.22820091], [68.61152649, 23.22763062], [68.61180878, 23.22763824], [68.61180878, 23.22680473], [68.61208344, 23.22680473], [68.61208344, 23.22569466], [68.61235809, 23.22569466], [68.61235809, 23.22458267], [68.61264038, 23.22458267], [68.61264038, 23.22402763], [68.61292267, 23.22402954], [68.61292267, 23.22347069], [68.61319733, 23.2234726], [68.61319733, 23.22263908], [68.61347198, 23.22264099], [68.61347198, 23.22208023], [68.61374664, 23.22208595], [68.61374664, 23.22180557], [68.61347198, 23.22182083], [68.61347198, 23.22153091], [68.61292267, 23.22153091], [68.61292267, 23.22125053], [68.61235809, 23.22125053], [68.61235809, 23.22153091], [68.61208344, 23.2215271], [68.61208344, 23.22208595], [68.61180878, 23.22208595], [68.61180878, 23.22180557], [68.61013794, 23.22180557], [68.61013794, 23.22208595], [68.60986328, 23.22208023], [68.60986328, 23.22236061], [68.60847473, 23.22236061], [68.6084671, 23.22344017], [68.6084671, 23.22402954], [68.60819244, 23.22402954], [68.60819244, 23.2232914], [68.60819244, 23.22319412], [68.60801697, 23.22319412], [68.60791779, 23.22319412], [68.60791779, 23.22263908], [68.60764313, 23.22264099], [68.60764313, 23.22236061], [68.60643768, 23.22236061], [68.60597229, 23.22236061], [68.60597229, 23.22264099], [68.60569763, 23.22264099], [68.60569763, 23.22291946], [68.60541534, 23.22291756], [68.60541534, 23.22319412], [68.60514069, 23.22319412], [68.60514069, 23.2234726], [68.6048584, 23.22347069], [68.6048584, 23.22375107], [68.60458374, 23.22374916], [68.60458374, 23.22458267], [68.60430908, 23.22457123], [68.60430908, 23.22486115], [68.60402679, 23.22486115], [68.60402679, 23.22513962], [68.60375214, 23.22513962], [68.60375214, 23.22569466], [68.60346985, 23.22569466], [68.60346985, 23.22680473], [68.60319519, 23.22680473], [68.60319519, 23.22847176], [68.60346985, 23.22846985], [68.60346985, 23.22903252], [68.60375214, 23.22903252], [68.60375214, 23.22986031], [68.60402679, 23.22986031], [68.60402679, 23.23069954], [68.60569763, 23.23069382], [68.60569763, 23.23097038], [68.60652924, 23.23097038], [68.60652924, 23.23125267], [68.60901642, 23.23125267]]], [[[68.59430695, 23.26208305], [68.59430695, 23.26180649], [68.59485626, 23.2618103], [68.59485626, 23.26152992], [68.59541321, 23.26152992], [68.59541321, 23.26068115], [68.59764099, 23.2606926], [68.59764099, 23.26013947], [68.5973587, 23.26013947], [68.5973587, 23.2598629], [68.59707642, 23.2598629], [68.59707642, 23.25958061], [68.59680939, 23.25958443], [68.59680176, 23.25930405], [68.59625244, 23.25930405], [68.59625244, 23.25958443], [68.5945816, 23.25958061], [68.5945816, 23.2598629], [68.59430695, 23.2598629], [68.59430695, 23.26013947], [68.59402466, 23.26013947], [68.59402466, 23.2606926], [68.59375, 23.2606926], [68.59375, 23.26208305], [68.59430695, 23.26208305]]], [[[68.65847015, 23.27124977], [68.65847015, 23.27096939], [68.65875244, 23.2709713], [68.65875244, 23.27069473], [68.6590271, 23.27069473], [68.6590271, 23.27041626], [68.65930939, 23.27042007], [68.65930939, 23.26987267], [68.6590271, 23.26987267], [68.6590271, 23.26958084], [68.65875244, 23.26958275], [68.65875244, 23.26930618], [68.65957642, 23.2693119], [68.65957642, 23.26903152], [68.66014099, 23.26903152], [68.66014099, 23.26874924], [68.66042328, 23.26874924], [68.66042328, 23.26847076], [68.66014099, 23.26847267], [68.66014099, 23.26791573], [68.65875244, 23.26791573], [68.65875244, 23.2681942], [68.65847015, 23.2681942], [68.65847015, 23.26847267], [68.65735626, 23.26847076], [68.65735626, 23.26874924], [68.6570816, 23.26874924], [68.6570816, 23.2693119], [68.65680695, 23.2693119], [68.65680695, 23.26987267], [68.6570816, 23.26987267], [68.6570816, 23.27013969], [68.65735626, 23.27013969], [68.65735626, 23.27042007], [68.65763855, 23.27041626], [68.65763855, 23.27069473], [68.65791321, 23.27069473], [68.65791321, 23.2709713], [68.6581955, 23.2709713], [68.6581955, 23.27124977], [68.65847015, 23.27124977]]], [[[68.55819702, 23.31375122], [68.55819702, 23.31347084], [68.55847168, 23.31347466], [68.55847168, 23.31319237], [68.55874634, 23.31319237], [68.55874634, 23.3129158], [68.55902863, 23.31291962], [68.55902863, 23.31264114], [68.55930328, 23.31264114], [68.55930328, 23.31208038], [68.55958557, 23.31208229], [68.55958557, 23.31152725], [68.55986023, 23.31153107], [68.55986023, 23.31097031], [68.56014252, 23.31097031], [68.56014252, 23.31041718], [68.56041718, 23.3104229], [68.56041718, 23.30986023], [68.56069183, 23.30986023], [68.56069183, 23.30904007], [68.56096649, 23.30904007], [68.56096649, 23.30846977], [68.56124878, 23.30847168], [68.56124878, 23.30763817], [68.56153107, 23.30763817], [68.56153107, 23.30680084], [68.56180573, 23.30680466], [68.56180573, 23.30597305], [68.56208038, 23.30598068], [68.56208038, 23.30541992], [68.56236267, 23.30541992], [68.56236267, 23.30458069], [68.56263733, 23.3045826], [68.56263733, 23.30374908], [68.56291962, 23.30375099], [68.56291962, 23.30319023], [68.56319427, 23.30319595], [68.56319427, 23.30263901], [68.56346893, 23.30264091], [68.56346893, 23.30181122], [68.56375122, 23.30181122], [68.56375122, 23.30125046], [68.56402588, 23.30125046], [68.56402588, 23.30070114], [68.56430817, 23.30070114], [68.56430817, 23.30153084], [68.56458282, 23.30152512], [68.56458282, 23.30208588], [68.56680298, 23.30208588], [68.56680298, 23.3018055], [68.56735992, 23.30181122], [68.56735992, 23.30153084], [68.56764221, 23.30153084], [68.56764221, 23.30125046], [68.56791687, 23.30125046], [68.56791687, 23.30097008], [68.56874847, 23.30097389], [68.56874847, 23.30069542], [68.56986237, 23.3006897], [68.56986237, 23.30041695], [68.57041931, 23.30042076], [68.57041931, 23.29931068], [68.57068634, 23.29931068], [68.57068634, 23.29764175], [68.57096863, 23.29764175], [68.57096863, 23.29707909], [68.57125092, 23.2970829], [68.57125092, 23.29624939], [68.5715332, 23.29624939], [68.57152557, 23.29597282], [68.57180786, 23.29597282], [68.57180786, 23.29569435], [68.57236481, 23.29569435], [68.57236481, 23.29541588], [68.57263947, 23.2954216], [68.57263947, 23.29513931], [68.57290649, 23.29513931], [68.57290649, 23.29486084], [68.57347107, 23.29486084], [68.57347107, 23.29458046], [68.57402802, 23.29458427], [68.57402802, 23.2943058], [68.57485962, 23.2943058], [68.57485962, 23.29458427], [68.57514954, 23.29458046], [68.57514954, 23.29513931], [68.57485962, 23.29513931], [68.57485962, 23.29569435], [68.57457733, 23.29569054], [68.57457733, 23.29624939], [68.57430267, 23.29624939], [68.57430267, 23.29653168], [68.57402802, 23.29653168], [68.57402802, 23.29681015], [68.57375336, 23.29680634], [68.57375336, 23.2970829], [68.57347107, 23.2970829], [68.57347107, 23.29736137], [68.57319641, 23.29735947], [68.57319641, 23.29792023], [68.57291412, 23.29791641], [68.57291412, 23.29819489], [68.57263947, 23.29819489], [68.57263947, 23.29958153], [68.57235718, 23.29957962], [68.57235718, 23.30014038], [68.57208252, 23.30014038], [68.57208252, 23.30042076], [68.57180786, 23.30041695], [68.57180786, 23.30097389], [68.5715332, 23.30097008], [68.5715332, 23.30153084], [68.57180786, 23.30153084], [68.57180786, 23.30236053], [68.57208252, 23.30236053], [68.57208252, 23.30347252], [68.57235718, 23.30347061], [68.57235718, 23.30375099], [68.57514954, 23.30375099], [68.57514954, 23.30347061], [68.57569122, 23.30347252], [68.57569122, 23.30319595], [68.57624817, 23.30319595], [68.57624817, 23.30291748], [68.57707977, 23.30291939], [68.57707977, 23.30264091], [68.57763672, 23.30264091], [68.57763672, 23.30236053], [68.57818604, 23.30236053], [68.57818604, 23.30208015], [68.57958221, 23.30208588], [68.57958221, 23.3018055], [68.58040619, 23.30181122], [68.58040619, 23.30153084], [68.58096313, 23.30153084], [68.58096313, 23.30125046], [68.58180237, 23.30125046], [68.58180237, 23.30097008], [68.58235931, 23.30097389], [68.58235931, 23.30069542], [68.5826416, 23.3006897], [68.5826416, 23.30041695], [68.58291626, 23.30042076], [68.58291626, 23.30014038], [68.58347321, 23.30014038], [68.58347321, 23.29985046], [68.58486176, 23.29986382], [68.58486176, 23.29958153], [68.58513641, 23.29958153], [68.58513641, 23.29930305], [68.5854187, 23.29931068], [68.5854187, 23.2990303], [68.58569336, 23.2990303], [68.58569336, 23.29819107], [68.58597565, 23.29819489], [68.58597565, 23.29680634], [68.58625031, 23.29681015], [68.58625031, 23.29648018], [68.58625031, 23.29624939], [68.58653259, 23.29624939], [68.58652496, 23.29569435], [68.58680725, 23.29569435], [68.58680725, 23.29541588], [68.58708954, 23.2954216], [68.58708954, 23.29513931], [68.58735657, 23.29513931], [68.58735657, 23.29486084], [68.58763885, 23.29486084], [68.58766174, 23.29513931], [68.58790588, 23.29513931], [68.58790588, 23.2954216], [68.5881958, 23.29541588], [68.5881958, 23.29597282], [68.58847046, 23.29597092], [68.58847046, 23.29653168], [68.58875275, 23.29653168], [68.58875275, 23.29764175], [68.58847046, 23.29764175], [68.58847046, 23.29792023], [68.5881958, 23.29791641], [68.5881958, 23.29819489], [68.58790588, 23.29819107], [68.58790588, 23.29874992], [68.58763885, 23.29874992], [68.58763885, 23.29958153], [68.5873642, 23.29958153], [68.5873642, 23.30097389], [68.58708191, 23.30097389], [68.58708954, 23.30125046], [68.58680725, 23.30125046], [68.58680725, 23.30153084], [68.58652496, 23.30152512], [68.58652496, 23.30208588], [68.58597565, 23.30208588], [68.58597565, 23.30152512], [68.5854187, 23.30153084], [68.5854187, 23.30181122], [68.58486176, 23.3018055], [68.58486176, 23.30208588], [68.5845871, 23.30208015], [68.5845871, 23.30264091], [68.58429718, 23.30264091], [68.58429718, 23.30486107], [68.58403015, 23.30486107], [68.58403015, 23.30513954], [68.58347321, 23.30513954], [68.58347321, 23.30541992], [68.58319092, 23.30541611], [68.58319092, 23.30569458], [68.5826416, 23.30569077], [68.5826416, 23.30598068], [68.58235931, 23.30598068], [68.58235931, 23.30624962], [68.58207703, 23.30624962], [68.58207703, 23.30763817], [68.58180237, 23.30763817], [68.58180237, 23.30847168], [68.58207703, 23.30846977], [68.58207703, 23.30904007], [68.58180237, 23.30902863], [68.58180237, 23.30958366], [68.58207703, 23.30958176], [68.58207703, 23.31014252], [68.58235931, 23.31014252], [68.58235931, 23.30986023], [68.58291626, 23.30986023], [68.58291626, 23.30958176], [68.58319092, 23.30958366], [68.58319092, 23.30930519], [68.58347321, 23.30931282], [68.58347321, 23.30874825], [68.58374786, 23.30874825], [68.58374786, 23.30846977], [68.58430481, 23.30847168], [68.58430481, 23.30819511], [68.5845871, 23.30820084], [68.5845871, 23.30791855], [68.58513641, 23.30791855], [68.58513641, 23.30763817], [68.5854187, 23.30763817], [68.5854187, 23.3073597], [68.58597565, 23.3073616], [68.58597565, 23.30708313], [68.58652496, 23.30708313], [68.58652496, 23.30680466], [68.58680725, 23.30680466], [68.58680725, 23.30652809], [68.58735657, 23.30652809], [68.58735657, 23.30624962], [68.5881958, 23.30624962], [68.5881958, 23.30598068], [68.5890274, 23.30598068], [68.5890274, 23.30569077], [68.58930206, 23.30569458], [68.58930206, 23.30541611], [68.58957672, 23.30541992], [68.58957672, 23.30513954], [68.58985901, 23.30513954], [68.58985901, 23.30486107], [68.59014893, 23.30486107], [68.5901413, 23.30430794], [68.59069824, 23.30430984], [68.59069824, 23.30402946], [68.5909729, 23.30402946], [68.5909729, 23.30375099], [68.59152985, 23.30375099], [68.59152985, 23.30347061], [68.5918045, 23.30347252], [68.5918045, 23.30319595], [68.59208679, 23.30319595], [68.59208679, 23.30291748], [68.59236145, 23.30291939], [68.59236145, 23.30264091], [68.5929184, 23.30264091], [68.5929184, 23.30236053], [68.59319305, 23.30236053], [68.59319305, 23.30208015], [68.59347534, 23.30208588], [68.59347534, 23.3018055], [68.59375, 23.30181122], [68.59375, 23.30153084], [68.59430695, 23.30153084], [68.59430695, 23.30125046], [68.5945816, 23.30125046], [68.5945816, 23.30097008], [68.59486389, 23.30097389], [68.59486389, 23.30069542], [68.59513855, 23.3006897], [68.59513855, 23.30041695], [68.59541321, 23.30042076], [68.59541321, 23.29985046], [68.5956955, 23.29986382], [68.5956955, 23.29958153], [68.59625244, 23.29957962], [68.59625244, 23.30014038], [68.5965271, 23.30014038], [68.5965271, 23.30042076], [68.59680176, 23.30042076], [68.59680939, 23.30014038], [68.59731293, 23.30014038], [68.59749603, 23.30014038], [68.59874725, 23.30014038], [68.59874725, 23.29985046], [68.60236359, 23.29986382], [68.60236359, 23.29930305], [68.60263824, 23.29931068], [68.60263824, 23.2990303], [68.60320282, 23.2990303], [68.60320282, 23.29931068], [68.60457611, 23.29931068], [68.60457611, 23.2990303], [68.60513306, 23.2990303], [68.60513306, 23.29874992], [68.60569763, 23.29874992], [68.60569763, 23.29846954], [68.6062088, 23.29846954], [68.60708618, 23.29847145], [68.60708618, 23.29764175], [68.60764313, 23.29764175], [68.60764313, 23.29735947], [68.60874939, 23.29736137], [68.60874939, 23.2970829], [68.60986328, 23.2970829], [68.60986328, 23.29680634], [68.61152649, 23.29681015], [68.61152649, 23.29653168], [68.61207581, 23.29653168], [68.61207581, 23.29569054], [68.60819244, 23.29569435], [68.60819244, 23.29541588], [68.60736084, 23.2954216], [68.60736084, 23.29486084], [68.60764313, 23.29486084], [68.6076355, 23.29458427], [68.60791779, 23.29458427], [68.60791779, 23.2943058], [68.6084671, 23.29431152], [68.6084671, 23.29404259], [68.60930634, 23.29404259], [68.60930634, 23.29375076], [68.60986328, 23.29375076], [68.60986328, 23.29347038], [68.61013794, 23.29347229], [68.61013794, 23.29291725], [68.61042023, 23.29291916], [68.61042023, 23.29264069], [68.61125946, 23.29264069], [68.61125946, 23.29236031], [68.61180878, 23.29236031], [68.61180878, 23.29207993], [68.61208344, 23.29208374], [68.61208344, 23.2915287], [68.61180878, 23.29153061], [68.61180878, 23.29125023], [68.61152649, 23.29125023], [68.61152649, 23.29070091], [68.61125946, 23.29070091], [68.61125946, 23.29042053], [68.61096954, 23.29042053], [68.61096954, 23.28985977], [68.61069489, 23.28986168], [68.61069489, 23.28958321], [68.61042023, 23.28958321], [68.61042023, 23.28902817], [68.61068726, 23.28903008], [68.61068726, 23.28819084], [68.61042023, 23.28819466], [68.61042023, 23.28708458], [68.61013794, 23.28708458], [68.61013794, 23.28541756], [68.61042023, 23.28541946], [68.61042023, 23.28375053], [68.61068726, 23.28375053], [68.61068726, 23.28264236], [68.61096954, 23.28264236], [68.61096954, 23.2820797], [68.61125183, 23.28208351], [68.61125183, 23.28152847], [68.61152649, 23.28152847], [68.61152649, 23.28096962], [68.61180878, 23.28097153], [68.61180878, 23.28013992], [68.61207581, 23.28013992], [68.61207581, 23.27958107], [68.61235809, 23.27958298], [68.61235809, 23.27902794], [68.61264038, 23.27902985], [68.61264038, 23.27847099], [68.61291504, 23.2784729], [68.61291504, 23.27791786], [68.61319733, 23.27791977], [68.61319733, 23.27736092], [68.61347198, 23.27736092], [68.61347198, 23.27680969], [68.61374664, 23.27680969], [68.61374664, 23.27625084], [68.61402893, 23.27625084], [68.61402893, 23.27568054], [68.61430359, 23.2756958], [68.61430359, 23.27458572], [68.61458588, 23.27458572], [68.61458588, 23.27375031], [68.61486053, 23.27375031], [68.61486053, 23.27153015], [68.61429596, 23.27153015], [68.61429596, 23.27124977], [68.61207581, 23.27124977], [68.61207581, 23.27153015], [68.61125183, 23.27152824], [68.61125183, 23.27180481], [68.61096954, 23.27180481], [68.61096954, 23.27208138], [68.61069489, 23.27208138], [68.61069489, 23.27236366], [68.61042023, 23.27235985], [68.61042023, 23.27264023], [68.61013794, 23.27263832], [68.61013794, 23.27291679], [68.60986328, 23.27291107], [68.60986328, 23.27320099], [68.60736084, 23.27319527], [68.60736084, 23.27347374], [68.60624695, 23.27347374], [68.60624695, 23.27319527], [68.60652924, 23.27320099], [68.60652924, 23.27291107], [68.60680389, 23.27291679], [68.60680389, 23.27263832], [68.60708618, 23.27264023], [68.60708618, 23.27207947], [68.60736084, 23.27208138], [68.60736084, 23.27152824], [68.60764313, 23.27153015], [68.60764313, 23.27069283], [68.60736084, 23.27069473], [68.60736084, 23.26958275], [68.60708618, 23.26958275], [68.60708618, 23.26902771], [68.60679626, 23.26903152], [68.60679626, 23.26874924], [68.60624695, 23.26874924], [68.60624695, 23.26847076], [68.60597229, 23.26847267], [68.60597229, 23.2681942], [68.60236359, 23.2681942], [68.60236359, 23.26847267], [68.60208893, 23.26847076], [68.60208893, 23.26903152], [68.60180664, 23.26902771], [68.60180664, 23.26958275], [68.60151672, 23.26958084], [68.60151672, 23.27042007], [68.60124969, 23.27041626], [68.60124969, 23.27236366], [68.60097504, 23.27236366], [68.60097504, 23.27291679], [68.59986115, 23.27291679], [68.59986115, 23.27208138], [68.59958649, 23.27208138], [68.59958649, 23.27124977], [68.59986115, 23.27124977], [68.59986115, 23.27013969], [68.59958649, 23.27013969], [68.59958649, 23.26958084], [68.5993042, 23.26958275], [68.5993042, 23.26902771], [68.59902954, 23.26903152], [68.59902954, 23.26874924], [68.59874725, 23.26874924], [68.59874725, 23.26847076], [68.5984726, 23.26847267], [68.5984726, 23.2681942], [68.5956955, 23.2681942], [68.5956955, 23.26763916], [68.59513855, 23.26763916], [68.59513855, 23.26736069], [68.5945816, 23.26736069], [68.5945816, 23.26708031], [68.59208679, 23.26708412], [68.59208679, 23.26680565], [68.59152985, 23.26680756], [68.59152985, 23.26652908], [68.5909729, 23.26652908], [68.5909729, 23.26625061], [68.59069824, 23.26625061], [68.59069824, 23.26597023], [68.5901413, 23.26597214], [68.5901413, 23.26569366], [68.58958435, 23.26569366], [68.58958435, 23.2654171], [68.58930206, 23.26542091], [68.58930206, 23.26514053], [68.58875275, 23.26514053], [68.58875275, 23.26486015], [68.58847046, 23.26486015], [68.58847046, 23.26457977], [68.58791351, 23.26458359], [68.58791351, 23.26430511], [68.58763885, 23.26431084], [68.58763885, 23.26403046], [68.58653259, 23.26403046], [68.58653259, 23.26374054], [68.5854187, 23.26375008], [68.5854187, 23.2634716], [68.5845871, 23.2634716], [68.5845871, 23.26319695], [68.58347321, 23.26320076], [68.58347321, 23.26292038], [68.58235931, 23.26292038], [68.58235931, 23.26264], [68.58013916, 23.26264], [68.58013916, 23.26235962], [68.57819366, 23.26236153], [68.57819366, 23.26208305], [68.57597351, 23.26208305], [68.57597351, 23.26180649], [68.57514954, 23.26180077], [68.57514191, 23.26152802], [68.57375336, 23.26152992], [68.57375336, 23.26124954], [68.57290649, 23.26124954], [68.57290649, 23.26097107], [68.57236481, 23.26097488], [68.57236481, 23.2606926], [68.57208252, 23.2606926], [68.57208252, 23.26041412], [68.57180786, 23.26041985], [68.57180786, 23.2598629], [68.57152557, 23.2598629], [68.57152557, 23.25930405], [68.57125092, 23.25930977], [68.57125092, 23.25902939], [68.57096863, 23.25902939], [68.57096863, 23.25764275], [68.57180786, 23.25764275], [68.57180786, 23.25708008], [68.57402802, 23.25708008], [68.57402802, 23.25736046], [68.57485962, 23.25736046], [68.57485962, 23.25764275], [68.57763672, 23.25764275], [68.57763672, 23.25570107], [68.57791901, 23.25570107], [68.57791901, 23.25542068], [68.57847595, 23.25542068], [68.57847595, 23.2551384], [68.5790329, 23.2551384], [68.5790329, 23.25486946], [68.58096313, 23.25486946], [68.58096313, 23.2551384], [68.58152771, 23.2551384], [68.58152771, 23.25542068], [68.5826416, 23.25542068], [68.5826416, 23.2551384], [68.58319092, 23.2551384], [68.58319092, 23.25457954], [68.58347321, 23.25458336], [68.58347321, 23.25430489], [68.58374786, 23.25430489], [68.58374786, 23.25402832], [68.58403015, 23.25402832], [68.58403015, 23.25374985], [68.58429718, 23.25374985], [68.58429718, 23.25291824], [68.58403015, 23.25291824], [68.58403015, 23.25263977], [68.58374786, 23.25263977], [68.58374786, 23.25235939], [68.58347321, 23.2523613], [68.58347321, 23.25208282], [68.58319092, 23.25208282], [68.58319092, 23.25180626], [68.58125305, 23.25180626], [68.58125305, 23.25208282], [68.58069611, 23.25208282], [68.58069611, 23.2523613], [68.57958221, 23.2523613], [68.57958221, 23.25208282], [68.57875061, 23.25208282], [68.57875061, 23.25180626], [68.57597351, 23.25180626], [68.57597351, 23.25152779], [68.57347107, 23.25152969], [68.57347107, 23.25125122], [68.57290649, 23.25125122], [68.57290649, 23.25041962], [68.57319641, 23.25041962], [68.57319641, 23.24958038], [68.57347107, 23.2495842], [68.57347107, 23.24930573], [68.57514954, 23.24930954], [68.57514954, 23.24903107], [68.57541656, 23.24903107], [68.57541656, 23.24874115], [68.57569122, 23.24875069], [68.57569122, 23.2476387], [68.57514954, 23.24764061], [68.57514191, 23.24641037], [68.57514191, 23.24625015], [68.57485962, 23.24625015], [68.57485962, 23.24570084], [68.57402802, 23.24570084], [68.57402802, 23.24514008], [68.57319641, 23.24514008], [68.57319641, 23.24542046], [68.57290649, 23.24542046], [68.57290649, 23.24570084], [68.57236481, 23.24569321], [68.57236481, 23.24597359], [68.57180786, 23.24596977], [68.57180786, 23.24625015], [68.5715332, 23.24625015], [68.5715332, 23.24653053], [68.57096863, 23.24653053], [68.57096863, 23.24681091], [68.57041931, 23.24680328], [68.57041931, 23.24708557], [68.57013702, 23.24707985], [68.57013702, 23.24736023], [68.56986237, 23.24736023], [68.56986237, 23.2475605], [68.56986237, 23.2476387], [68.56958008, 23.2476387], [68.56958008, 23.24819565], [68.56930542, 23.24819565], [68.56930542, 23.24847221], [68.56903076, 23.24847221], [68.56903076, 23.24875069], [68.56874847, 23.24874115], [68.56874847, 23.24903107], [68.56902313, 23.24903107], [68.56902313, 23.25014114], [68.56874847, 23.25014114], [68.56874847, 23.25041962], [68.56847382, 23.25041771], [68.56847382, 23.25069427], [68.56819153, 23.25069427], [68.56819153, 23.25097275], [68.56764221, 23.25097084], [68.56764221, 23.25125122], [68.56680298, 23.25125122], [68.56680298, 23.25152969], [68.56597137, 23.25152779], [68.56597137, 23.25180626], [68.56513977, 23.25180626], [68.56513977, 23.25208282], [68.56375122, 23.25208282], [68.56375122, 23.2523613], [68.56236267, 23.25235939], [68.56236267, 23.25263977], [68.56181335, 23.25263977], [68.56181335, 23.25291824], [68.56124878, 23.25291634], [68.56124878, 23.25319481], [68.56051636, 23.25319481], [68.56014252, 23.25319481], [68.56014252, 23.25347137], [68.55874634, 23.25346947], [68.55874634, 23.25374985], [68.55847168, 23.25374985], [68.55847168, 23.25430489], [68.55819702, 23.25430489], [68.55819702, 23.25458336], [68.55764008, 23.25457954], [68.55764008, 23.25486946], [68.55735779, 23.25486946], [68.55735779, 23.2551384], [68.55708313, 23.2551384], [68.55708313, 23.25570107], [68.55735779, 23.25570107], [68.55735779, 23.25625038], [68.55708313, 23.25625038], [68.55708313, 23.25653267], [68.55652618, 23.25653267], [68.55652618, 23.25681114], [68.55625153, 23.25680542], [68.55625153, 23.25708389], [68.55568695, 23.25708008], [68.55568695, 23.25736046], [68.55513763, 23.25736046], [68.55513763, 23.25764275], [68.55458069, 23.25764275], [68.55458069, 23.25793076], [68.55430603, 23.2579174], [68.55430603, 23.25819206], [68.55403137, 23.25819206], [68.55403137, 23.25847054], [68.5534668, 23.25847054], [68.5534668, 23.25875282], [68.55319214, 23.25875282], [68.55319214, 23.25902939], [68.55264282, 23.25902939], [68.55264282, 23.25930977], [68.55208588, 23.25930405], [68.55208588, 23.25958443], [68.55179596, 23.25958061], [68.55179596, 23.2598629], [68.55069733, 23.2598629], [68.55069733, 23.26013947], [68.55014038, 23.26013947], [68.55014038, 23.26041985], [68.54985809, 23.26041412], [68.54985809, 23.2606926], [68.54958344, 23.2606926], [68.54958344, 23.26097488], [68.54902649, 23.26097107], [68.54902649, 23.26124954], [68.54846954, 23.26124954], [68.54846954, 23.26152992], [68.54763794, 23.26152802], [68.54763794, 23.26180077], [68.54736328, 23.26180649], [68.54736328, 23.26208305], [68.54708099, 23.26208115], [68.54708099, 23.26264], [68.54680634, 23.26264], [68.54680634, 23.26292038], [68.54651642, 23.26292038], [68.54651642, 23.26320076], [68.54624939, 23.26319695], [68.54624939, 23.2634716], [68.5459671, 23.2634697], [68.5459671, 23.26514053], [68.54569244, 23.26514053], [68.54569244, 23.26542091], [68.5451355, 23.2654171], [68.5451355, 23.26569366], [68.54319763, 23.26569366], [68.54319763, 23.26513863], [68.54207611, 23.26514053], [68.54207611, 23.26542091], [68.54180908, 23.2654171], [68.54180908, 23.26569366], [68.54096985, 23.26569366], [68.54096985, 23.26597214], [68.54070282, 23.26597023], [68.54070282, 23.26652908], [68.5404129, 23.26652908], [68.5404129, 23.2693119], [68.54013824, 23.2693119], [68.54013824, 23.26987267], [68.53985596, 23.26987267], [68.53985596, 23.27042007], [68.53930664, 23.27041626], [68.53930664, 23.27069473], [68.53902435, 23.27069473], [68.53902435, 23.2709713], [68.53847504, 23.2709713], [68.53848267, 23.27124977], [68.53819275, 23.27124977], [68.53819275, 23.27291679], [68.53791809, 23.27291679], [68.53791809, 23.27458572], [68.53819275, 23.27458], [68.53819275, 23.27514076], [68.53847504, 23.27513885], [68.53847504, 23.2756958], [68.53874969, 23.2756958], [68.53874969, 23.27958298], [68.53901672, 23.27958107], [68.53901672, 23.28013992], [68.53930664, 23.28013992], [68.53930664, 23.28070068], [68.5395813, 23.28070068], [68.5395813, 23.28124809], [68.53985596, 23.28124809], [68.53985596, 23.28264236], [68.54013824, 23.28263855], [68.54013824, 23.28347015], [68.5404129, 23.28347015], [68.5404129, 23.28430939], [68.54069519, 23.28430557], [68.54069519, 23.28486061], [68.54096985, 23.28484917], [68.54096985, 23.2851429], [68.54207611, 23.2851429], [68.54207611, 23.28484917], [68.5423584, 23.28484917], [68.5423584, 23.2851429], [68.54264069, 23.2851429], [68.54264069, 23.28541946], [68.54319763, 23.28541756], [68.54319763, 23.2859745], [68.54402924, 23.2859745], [68.54402924, 23.28569221], [68.54430389, 23.28569221], [68.54430389, 23.28541756], [68.54458618, 23.28541946], [68.54458618, 23.28484917], [68.54486084, 23.28486061], [68.54486084, 23.28430557], [68.54514313, 23.28430939], [68.54514313, 23.28403282], [68.54541779, 23.28403282], [68.54541779, 23.28347015], [68.54569244, 23.28347015], [68.54569244, 23.28319359], [68.54624939, 23.28319359], [68.54624939, 23.28291702], [68.54736328, 23.28292274], [68.54736328, 23.28264236], [68.54792023, 23.28264236], [68.54792023, 23.28236008], [68.54624939, 23.28236008], [68.54624939, 23.28208351], [68.54541779, 23.28208351], [68.54541779, 23.27902794], [68.54569244, 23.27902985], [68.54569244, 23.27874947], [68.5459671, 23.27874947], [68.5459671, 23.27819061], [68.54624939, 23.27819443], [68.54624939, 23.27791786], [68.54736328, 23.27791977], [68.54736328, 23.27763939], [68.54818726, 23.27763939], [68.54818726, 23.27736092], [68.54985809, 23.27736092], [68.54985809, 23.27763939], [68.55042267, 23.27763939], [68.55042267, 23.27791977], [68.55152893, 23.27791977], [68.55152893, 23.27763939], [68.55208588, 23.27763939], [68.55208588, 23.27736092], [68.55236053, 23.27736092], [68.55236053, 23.27708054], [68.55263519, 23.27708244], [68.55263519, 23.27680779], [68.55291748, 23.27680969], [68.55291748, 23.27625084], [68.55303192, 23.27625084], [68.55319214, 23.27625084], [68.55319214, 23.27597046], [68.55347443, 23.27597237], [68.55347443, 23.2756958], [68.55374908, 23.2756958], [68.55374908, 23.27541733], [68.55430603, 23.27542114], [68.55430603, 23.27486038], [68.55486298, 23.27486038], [68.55486298, 23.27458], [68.55513763, 23.27458572], [68.55513763, 23.27430344], [68.55625153, 23.27431107], [68.55625153, 23.27403069], [68.55735779, 23.27403069], [68.55735779, 23.27431107], [68.55764008, 23.27431107], [68.55764008, 23.27680969], [68.55791473, 23.27680779], [68.55791473, 23.27708244], [68.55819702, 23.27708054], [68.55819702, 23.27763939], [68.55902863, 23.27763939], [68.55902863, 23.27736092], [68.5595932, 23.27736092], [68.55958557, 23.27708244], [68.56041718, 23.27708244], [68.56041718, 23.27680779], [68.56069183, 23.27680969], [68.56069183, 23.27653122], [68.56096649, 23.27653122], [68.56096649, 23.27680969], [68.56124878, 23.27680779], [68.56124878, 23.27708244], [68.56180573, 23.27708244], [68.56180573, 23.27736092], [68.56208038, 23.27736092], [68.56208038, 23.27763939], [68.56263733, 23.27763939], [68.56263733, 23.27791977], [68.56291962, 23.27791786], [68.56291962, 23.27819443], [68.56346893, 23.27819443], [68.56346893, 23.2784729], [68.56430817, 23.27847099], [68.56430817, 23.28070068], [68.56402588, 23.28069496], [68.56402588, 23.28097153], [68.56375122, 23.28096962], [68.56375122, 23.28124809], [68.56346893, 23.28124809], [68.56346893, 23.28181076], [68.56402588, 23.28180504], [68.56402588, 23.28208351], [68.56430817, 23.28208351], [68.56430817, 23.28236008], [68.56458282, 23.28236008], [68.56458282, 23.28264236], [68.56485748, 23.28263855], [68.56485748, 23.28347015], [68.56513977, 23.28347015], [68.56513977, 23.28375053], [68.56624603, 23.28375053], [68.56624603, 23.28319168], [68.56652832, 23.28319359], [68.56652832, 23.28059959], [68.56652832, 23.28041649], [68.56680298, 23.2804184], [68.56680298, 23.28070068], [68.56735992, 23.28069496], [68.56735992, 23.28097153], [68.56764221, 23.28096962], [68.56764221, 23.28124809], [68.56791687, 23.28124809], [68.56791687, 23.28208351], [68.56819153, 23.28208351], [68.56819153, 23.28297806], [68.56819153, 23.28486061], [68.56735992, 23.28484917], [68.56735992, 23.2851429], [68.5670929, 23.2851429], [68.5670929, 23.28541946], [68.56680298, 23.28541756], [68.56680298, 23.28569221], [68.56652832, 23.28569221], [68.56652832, 23.2859745], [68.56624603, 23.28597069], [68.56624603, 23.28625107], [68.56595612, 23.28625107], [68.56595612, 23.28680992], [68.56513977, 23.28680992], [68.56513977, 23.28652954], [68.56346893, 23.28652954], [68.56346893, 23.28680992], [68.56069183, 23.28680611], [68.56069183, 23.28708458], [68.55958557, 23.28708458], [68.5595932, 23.28736115], [68.55930328, 23.28736115], [68.55930328, 23.28763962], [68.55902863, 23.28763962], [68.55902863, 23.28791428], [68.55874634, 23.28791428], [68.55874634, 23.28819466], [68.55847168, 23.28819466], [68.55847168, 23.28847313], [68.55819702, 23.28847122], [68.55819702, 23.28874969], [68.5579071, 23.28874969], [68.5579071, 23.28903008], [68.55764008, 23.28902817], [68.55764008, 23.28930664], [68.55735779, 23.28930664], [68.55735779, 23.28958321], [68.55708313, 23.28958321], [68.55708313, 23.28986168], [68.55680847, 23.28985977], [68.55680847, 23.29042053], [68.55652618, 23.29042053], [68.55652618, 23.29097939], [68.55625153, 23.29097939], [68.55625153, 23.29153061], [68.55596924, 23.2915287], [68.55596924, 23.29208374], [68.55568695, 23.29207993], [68.55568695, 23.29264069], [68.55541992, 23.29263878], [68.55541992, 23.29319382], [68.55513763, 23.2931881], [68.55513763, 23.29375076], [68.55486298, 23.29375076], [68.55486298, 23.29431152], [68.55458069, 23.2943058], [68.55458069, 23.29458237], [68.55430603, 23.29458046], [68.55430603, 23.29513931], [68.55403137, 23.29513931], [68.55403137, 23.29569435], [68.55374908, 23.29569054], [68.55374908, 23.29624939], [68.5534668, 23.29624939], [68.5534668, 23.29681015], [68.55319214, 23.29681015], [68.55319214, 23.29764175], [68.55347443, 23.29764175], [68.55347443, 23.29958153], [68.55374908, 23.29957962], [68.55374908, 23.30153084], [68.55401611, 23.30153084], [68.55401611, 23.30375099], [68.55430603, 23.30375099], [68.55430603, 23.30624962], [68.55458069, 23.30624962], [68.55458069, 23.30874825], [68.55486298, 23.30874825], [68.55486298, 23.30986023], [68.55513763, 23.30986023], [68.55513763, 23.31069374], [68.55541992, 23.31069183], [68.55541992, 23.31180954], [68.55568695, 23.31180954], [68.55568695, 23.31236076], [68.55596924, 23.31236076], [68.55596924, 23.31264114], [68.55625153, 23.31264114], [68.55625153, 23.31291962], [68.55652618, 23.3129158], [68.55652618, 23.31319237], [68.55680847, 23.31319237], [68.55680847, 23.31347466], [68.55708313, 23.31347084], [68.55708313, 23.31375122], [68.55819702, 23.31375122]]], [[[68.62874603, 23.29014015], [68.62874603, 23.28957939], [68.62902832, 23.28958321], [68.62902832, 23.28902817], [68.62930298, 23.28903008], [68.62930298, 23.28708076], [68.62902832, 23.28708458], [68.62902832, 23.28541756], [68.62847137, 23.28541756], [68.62847137, 23.2859745], [68.62819672, 23.28597069], [68.62819672, 23.28652954], [68.62791443, 23.28652763], [68.62791443, 23.28930664], [68.62819672, 23.28930092], [68.62819672, 23.29014015], [68.62874603, 23.29014015]]], [[[68.58847046, 23.31903076], [68.58847046, 23.31875038], [68.59041595, 23.31875038], [68.59041595, 23.31847], [68.59069824, 23.31847191], [68.59069824, 23.31825066], [68.59069824, 23.31791878], [68.5909729, 23.31792068], [68.5909729, 23.3176403], [68.59124756, 23.3176403], [68.59124756, 23.31707954], [68.59152985, 23.31708336], [68.59152985, 23.31680679], [68.59236145, 23.31680679], [68.59236145, 23.31569672], [68.59263611, 23.31569672], [68.59263611, 23.31513977], [68.5929184, 23.31513977], [68.5929184, 23.31485939], [68.59375, 23.3148613], [68.59375, 23.31458473], [68.59486389, 23.31458473], [68.59486389, 23.3148613], [68.5965271, 23.31485939], [68.5965271, 23.31513977], [68.59680176, 23.31513977], [68.59680176, 23.31569672], [68.59708405, 23.31569672], [68.59708405, 23.31597137], [68.59819794, 23.31597137], [68.59819794, 23.31569672], [68.59986115, 23.31569672], [68.59986115, 23.31541634], [68.60069275, 23.31542015], [68.60069275, 23.31513977], [68.60180664, 23.31513977], [68.60180664, 23.31485939], [68.6020813, 23.3148613], [68.6020813, 23.31458473], [68.60263824, 23.31458473], [68.60263824, 23.31430626], [68.6029129, 23.31431007], [68.6029129, 23.31402969], [68.60375214, 23.31402969], [68.60375214, 23.31319046], [68.60402679, 23.31319237], [68.60402679, 23.31263924], [68.6048584, 23.31264114], [68.6048584, 23.31236076], [68.60513306, 23.31236076], [68.60513306, 23.31208038], [68.60541534, 23.31208229], [68.60541534, 23.31180573], [68.60569763, 23.31180954], [68.60569763, 23.31153107], [68.60597229, 23.31153107], [68.60597229, 23.31125259], [68.60624695, 23.31125259], [68.60624695, 23.31097031], [68.60652924, 23.31097031], [68.60652924, 23.31069374], [68.60708618, 23.31069374], [68.60708618, 23.31041718], [68.60736084, 23.3104229], [68.60736084, 23.31014252], [68.60791779, 23.31014252], [68.60791779, 23.30986023], [68.60874939, 23.30986023], [68.60874939, 23.3104229], [68.60847473, 23.31041718], [68.60847473, 23.31097031], [68.60819244, 23.31097031], [68.60819244, 23.31153107], [68.60791779, 23.31153107], [68.60791779, 23.31180954], [68.60708618, 23.31180573], [68.60708618, 23.31208229], [68.60652924, 23.31208038], [68.60652924, 23.31236076], [68.60597229, 23.31236076], [68.60597229, 23.31264114], [68.60542297, 23.31264114], [68.60542297, 23.31375122], [68.60514069, 23.31374931], [68.60514069, 23.3148613], [68.60542297, 23.31485939], [68.60542297, 23.31542015], [68.60569763, 23.31541634], [68.60569763, 23.31597137], [68.60597229, 23.31596947], [68.60597229, 23.31653023], [68.60847473, 23.31652832], [68.60847473, 23.31680679], [68.60930634, 23.31680679], [68.60930634, 23.31652832], [68.60958099, 23.31653023], [68.60958099, 23.31624985], [68.60930634, 23.31624985], [68.60930634, 23.31596947], [68.60902405, 23.31597137], [68.60902405, 23.31569672], [68.60874939, 23.31569672], [68.60874939, 23.31513977], [68.6084671, 23.31513977], [68.6084671, 23.31485939], [68.60819244, 23.3148613], [68.60819244, 23.31458473], [68.60847473, 23.31458473], [68.60847473, 23.31402779], [68.60874939, 23.31402969], [68.60874939, 23.31347084], [68.60902405, 23.31347466], [68.60902405, 23.3129158], [68.60930634, 23.31291962], [68.60930634, 23.31264114], [68.60958099, 23.31264114], [68.60958099, 23.31236076], [68.60986328, 23.31236076], [68.60986328, 23.31208038], [68.61013794, 23.31208229], [68.61013794, 23.31069374], [68.61042023, 23.31069374], [68.61042023, 23.31041718], [68.61096954, 23.3104229], [68.61096954, 23.31014252], [68.61125946, 23.31014252], [68.61125946, 23.30986023], [68.61152649, 23.30986023], [68.61152649, 23.30931282], [68.61180878, 23.30931282], [68.61180878, 23.30904007], [68.61207581, 23.30904007], [68.61207581, 23.30874825], [68.61235809, 23.30874825], [68.61235809, 23.30846977], [68.61264038, 23.30847168], [68.61264038, 23.30791664], [68.61292267, 23.30791855], [68.61292267, 23.30763817], [68.61319733, 23.30763817], [68.61319733, 23.30708122], [68.61347198, 23.30708313], [68.61347198, 23.30680466], [68.61374664, 23.30680466], [68.61374664, 23.30624962], [68.61402893, 23.30624962], [68.61402893, 23.30598068], [68.61429596, 23.30598068], [68.61430359, 23.30553055], [68.61430359, 23.30541611], [68.61458588, 23.30541992], [68.61458588, 23.30486107], [68.61486053, 23.30486107], [68.61486053, 23.30430984], [68.61514282, 23.30430984], [68.61514282, 23.30375099], [68.61541748, 23.30375099], [68.61541748, 23.30319023], [68.61569214, 23.30319595], [68.61569214, 23.30263901], [68.6159668, 23.30264091], [68.6159668, 23.30208015], [68.61653137, 23.30208588], [68.61653137, 23.30347252], [68.61708069, 23.30347252], [68.61708069, 23.30291748], [68.61736298, 23.30291939], [68.61736298, 23.30236053], [68.61763763, 23.30236053], [68.61763763, 23.30181122], [68.61791992, 23.30181122], [68.61791992, 23.30125046], [68.61818695, 23.30125046], [68.61818695, 23.30097008], [68.61846924, 23.30097389], [68.61846924, 23.30041695], [68.61875153, 23.30042076], [68.61875153, 23.29931068], [68.61846924, 23.29931068], [68.61846924, 23.2990303], [68.61818695, 23.2990303], [68.61818695, 23.29874992], [68.61763763, 23.29874992], [68.61763763, 23.29846954], [68.61708069, 23.29847145], [68.61708069, 23.29819489], [68.61680603, 23.29819489], [68.61680603, 23.29791641], [68.61653137, 23.29792023], [68.61653137, 23.29764175], [68.61624908, 23.29764175], [68.61624908, 23.29735947], [68.6159668, 23.29735947], [68.6159668, 23.29764175], [68.61514282, 23.29764175], [68.61514282, 23.29792023], [68.61458588, 23.29791641], [68.61458588, 23.29819489], [68.61402893, 23.29819489], [68.61402893, 23.29847145], [68.61347198, 23.29846954], [68.61347198, 23.29874992], [68.61292267, 23.29874992], [68.61292267, 23.2990303], [68.61235809, 23.2990303], [68.61235809, 23.29931068], [68.61180878, 23.29930305], [68.61180878, 23.29958153], [68.61013794, 23.29958153], [68.61013794, 23.29930305], [68.60874939, 23.29930305], [68.60874939, 23.29958153], [68.6076355, 23.29958153], [68.6076355, 23.29986382], [68.60679626, 23.29985046], [68.60679626, 23.30014038], [68.60597229, 23.30014038], [68.60597229, 23.30042076], [68.60541534, 23.30041695], [68.60541534, 23.30058098], [68.60541534, 23.30069542], [68.60458374, 23.30069542], [68.60458374, 23.30097389], [68.60346985, 23.30097008], [68.60346985, 23.30125046], [68.60041809, 23.30125046], [68.60041809, 23.30153084], [68.59986115, 23.30153084], [68.59986115, 23.30181122], [68.5993042, 23.3018055], [68.5993042, 23.30208588], [68.5984726, 23.30208015], [68.5984726, 23.30236053], [68.59819794, 23.30236053], [68.59819794, 23.30264091], [68.59792328, 23.30264091], [68.59792328, 23.30291939], [68.59764099, 23.30291748], [68.59764099, 23.30347252], [68.5973587, 23.30347061], [68.5973587, 23.30375099], [68.59707642, 23.30375099], [68.59707642, 23.30402946], [68.59680176, 23.30402946], [68.59680176, 23.30430984], [68.5973587, 23.30430794], [68.5973587, 23.3045826], [68.59764099, 23.30458069], [68.59764099, 23.30486107], [68.59819794, 23.30486107], [68.59819794, 23.30513954], [68.5984726, 23.30513954], [68.5984726, 23.30541992], [68.5973587, 23.30541992], [68.5973587, 23.30513954], [68.59680939, 23.30513954], [68.59680176, 23.30486107], [68.59541321, 23.30486107], [68.59541321, 23.30458069], [68.59485626, 23.30458069], [68.59485626, 23.30486107], [68.59430695, 23.30486107], [68.59430695, 23.30513954], [68.59401703, 23.30513954], [68.59401703, 23.30541992], [68.59375, 23.30541611], [68.59375, 23.30680466], [68.59402466, 23.30680466], [68.59402466, 23.3073616], [68.59430695, 23.3073597], [68.59430695, 23.30791855], [68.59401703, 23.30791855], [68.59401703, 23.30931282], [68.59430695, 23.30930519], [68.59430695, 23.30958366], [68.59347534, 23.30958366], [68.59347534, 23.30930519], [68.5929184, 23.30930519], [68.5929184, 23.30958366], [68.59179688, 23.30958176], [68.59179688, 23.30986023], [68.5909729, 23.30986023], [68.5909729, 23.31014252], [68.59041595, 23.31014252], [68.59041595, 23.3104229], [68.5901413, 23.31041718], [68.5901413, 23.31069374], [68.58958435, 23.31069374], [68.58958435, 23.31097031], [68.5890274, 23.31097031], [68.5890274, 23.31125259], [68.58847046, 23.31125259], [68.58847046, 23.31153107], [68.58790588, 23.31153107], [68.58790588, 23.31180954], [68.58763885, 23.31180573], [68.58763885, 23.31208229], [68.58708191, 23.31208229], [68.58708954, 23.31236076], [68.58680725, 23.31236076], [68.58680725, 23.31264114], [68.58653259, 23.31264114], [68.58653259, 23.31291962], [68.58625031, 23.3129158], [68.58625031, 23.31319237], [68.58597565, 23.31319237], [68.58597565, 23.31347466], [68.58569336, 23.31347084], [68.58569336, 23.31375122], [68.58513641, 23.31375122], [68.58513641, 23.31402969], [68.5845871, 23.31402969], [68.5845871, 23.31431007], [68.58403015, 23.31430626], [68.58403015, 23.31458473], [68.58347321, 23.31458473], [68.58347321, 23.3148613], [68.58319092, 23.31485939], [68.58319092, 23.31513977], [68.58291626, 23.31513977], [68.58291626, 23.31569672], [68.5826416, 23.31569672], [68.5826416, 23.31597137], [68.58291626, 23.31596947], [68.58291626, 23.31653023], [68.58319092, 23.31652832], [68.58319092, 23.31708336], [68.58347321, 23.31708336], [68.58347321, 23.31736183], [68.58374786, 23.31735992], [68.58374786, 23.3176403], [68.58403015, 23.3176403], [68.58403015, 23.31792068], [68.58486176, 23.31792068], [68.58486176, 23.3182106], [68.58569336, 23.31819534], [68.58569336, 23.31847191], [68.58652496, 23.31847191], [68.58652496, 23.31875038], [68.58698273, 23.31875038], [68.58708954, 23.31875038], [68.58708954, 23.31903076], [68.58847046, 23.31903076]]], [[[68.70513916, 23.31180954], [68.70513916, 23.31153107], [68.70597076, 23.31153107], [68.70597076, 23.31125259], [68.70707703, 23.31125259], [68.70707703, 23.31097031], [68.70735931, 23.31097031], [68.70735931, 23.31069374], [68.70791626, 23.31069374], [68.70791626, 23.31041718], [68.70819092, 23.3104229], [68.70819092, 23.30986023], [68.70847321, 23.30986023], [68.70847321, 23.30958176], [68.70874786, 23.30958366], [68.70874786, 23.30930519], [68.70819092, 23.30930519], [68.70819092, 23.30958366], [68.70735931, 23.30958366], [68.70735931, 23.30930519], [68.70680237, 23.30931282], [68.70680237, 23.30904007], [68.70735168, 23.30904007], [68.70735168, 23.30874825], [68.70819092, 23.30874825], [68.70819092, 23.30846977], [68.70847321, 23.30847168], [68.70847321, 23.30819511], [68.70874786, 23.30820084], [68.70874786, 23.30680084], [68.70847321, 23.30680466], [68.70847321, 23.30652809], [68.70791626, 23.30652809], [68.70791626, 23.30680466], [68.70680237, 23.30680466], [68.70680237, 23.30708313], [68.70625305, 23.30708313], [68.70625305, 23.3073616], [68.70597076, 23.3073597], [68.70597076, 23.30763817], [68.70540619, 23.30763817], [68.70540619, 23.30791855], [68.70485687, 23.30791855], [68.70485687, 23.30820084], [68.70430756, 23.30819511], [68.70430756, 23.30847168], [68.70347595, 23.30846977], [68.70347595, 23.30874825], [68.70263672, 23.30874825], [68.70263672, 23.30904007], [68.70096588, 23.30904007], [68.70096588, 23.30931282], [68.69985962, 23.30931282], [68.69985962, 23.31014252], [68.70041656, 23.31014252], [68.70041656, 23.3104229], [68.70181274, 23.3104229], [68.70181274, 23.31014252], [68.70319366, 23.3101387], [68.70319366, 23.31069374], [68.70347595, 23.31069374], [68.70347595, 23.31097031], [68.70375061, 23.31097031], [68.70375061, 23.31125259], [68.70347595, 23.31125259], [68.70347595, 23.31153107], [68.70318604, 23.31153107], [68.70318604, 23.31180954], [68.70513916, 23.31180954]]], [[[68.64263916, 23.31402969], [68.64263916, 23.31375122], [68.64290619, 23.31375122], [68.64290619, 23.31347084], [68.64347076, 23.31347466], [68.64347076, 23.31302834], [68.64347076, 23.31263924], [68.64375305, 23.31264114], [68.64375305, 23.31208038], [68.64402771, 23.31208229], [68.64402771, 23.31152725], [68.64430237, 23.31153107], [68.64430237, 23.3111496], [68.64430237, 23.31097031], [68.64458466, 23.31097031], [68.64458466, 23.31041718], [68.64485931, 23.3104229], [68.64485931, 23.31014252], [68.6451416, 23.31014252], [68.6451416, 23.30958176], [68.64541626, 23.30958366], [68.64541626, 23.30902863], [68.64569092, 23.30904007], [68.64569092, 23.30846977], [68.64597321, 23.30847168], [68.64597321, 23.30791664], [68.64624786, 23.30791855], [68.64624786, 23.3073597], [68.64569092, 23.3073597], [68.64569092, 23.30763817], [68.64541626, 23.30763817], [68.64541626, 23.30791855], [68.6451416, 23.30791855], [68.6451416, 23.30820084], [68.64458466, 23.30819511], [68.64458466, 23.30847168], [68.64430237, 23.30846977], [68.64430237, 23.30874825], [68.64347076, 23.30874825], [68.64347076, 23.30904007], [68.64190674, 23.30903816], [68.6415329, 23.30904007], [68.6415329, 23.30931282], [68.64097595, 23.30930519], [68.64097595, 23.30958366], [68.64041901, 23.30958176], [68.64041901, 23.30986023], [68.64013672, 23.30986023], [68.64013672, 23.31014252], [68.63957977, 23.31014252], [68.63957977, 23.3104229], [68.63874817, 23.3104229], [68.63874817, 23.31014252], [68.63819885, 23.31014252], [68.63819885, 23.3104229], [68.63791656, 23.31041718], [68.63791656, 23.31069374], [68.63735962, 23.31069374], [68.63735962, 23.3101387], [68.63764191, 23.31014252], [68.63764191, 23.30958176], [68.63791656, 23.30958366], [68.63791656, 23.30874825], [68.63764191, 23.30874825], [68.63764191, 23.30820084], [68.63735962, 23.30820084], [68.63735962, 23.30791855], [68.63707733, 23.30791855], [68.63707733, 23.3073597], [68.63680267, 23.3073616], [68.63680267, 23.30708313], [68.63652802, 23.30708313], [68.63652802, 23.30680466], [68.63625336, 23.30680466], [68.63625336, 23.30708313], [68.63569641, 23.30708313], [68.63569641, 23.3073616], [68.63540649, 23.3073597], [68.63540649, 23.30763817], [68.63346863, 23.30763817], [68.63346863, 23.30791855], [68.63318634, 23.30791855], [68.63318634, 23.30904007], [68.63291931, 23.30902863], [68.63291931, 23.30937958], [68.63291931, 23.30958366], [68.63263702, 23.30958176], [68.63263702, 23.31014252], [68.63236237, 23.31014252], [68.63236237, 23.3104229], [68.63208008, 23.31041718], [68.63208008, 23.31097031], [68.63236237, 23.31097031], [68.63236237, 23.31069374], [68.63375092, 23.31069374], [68.63375092, 23.31097031], [68.6340332, 23.31097031], [68.6340332, 23.31153107], [68.63375092, 23.31152725], [68.63375092, 23.31208229], [68.63346863, 23.31208038], [68.63346863, 23.31264114], [68.63375092, 23.31263924], [68.63375092, 23.31319237], [68.63402557, 23.31319237], [68.63402557, 23.31347466], [68.63430786, 23.31347084], [68.63430786, 23.31375122], [68.63485718, 23.31375122], [68.63485718, 23.31347084], [68.63541412, 23.31347466], [68.63541412, 23.31319237], [68.63569641, 23.31319237], [68.63569641, 23.3129158], [68.63625336, 23.31291962], [68.63625336, 23.31264114], [68.63652802, 23.31264114], [68.63652802, 23.31208038], [68.63680267, 23.31208229], [68.63680267, 23.31175995], [68.63680267, 23.31152725], [68.63764191, 23.31152725], [68.63764191, 23.31208229], [68.63777924, 23.31208229], [68.63957977, 23.31208229], [68.63957977, 23.31180573], [68.63986206, 23.31180954], [68.63986206, 23.31153107], [68.64069366, 23.31152725], [68.64069366, 23.31270981], [68.64069366, 23.31319237], [68.64180756, 23.31319237], [68.64180756, 23.31347466], [68.64208221, 23.31347084], [68.64208221, 23.31402969], [68.64263916, 23.31402969]]], [[[68.62708282, 23.32181168], [68.62708282, 23.32152939], [68.62763977, 23.32152939], [68.62763977, 23.32125092], [68.62847137, 23.32125092], [68.62847137, 23.32098007], [68.62874603, 23.32098007], [68.62874603, 23.32068825], [68.62902832, 23.32069397], [68.62902832, 23.31986046], [68.62930298, 23.31986046], [68.62930298, 23.31847], [68.62958527, 23.31847191], [68.62958527, 23.31569672], [68.62985992, 23.31569672], [68.62985992, 23.31374931], [68.62902832, 23.31375122], [68.62902832, 23.31347084], [68.62875366, 23.31347466], [68.62875366, 23.31319237], [68.62847137, 23.31319237], [68.62847137, 23.3129158], [68.62874603, 23.31291962], [68.62874603, 23.31236076], [68.62847137, 23.31236076], [68.62847137, 23.31208038], [68.62819672, 23.31208229], [68.62819672, 23.31180573], [68.6279068, 23.31180954], [68.6279068, 23.31153107], [68.62747955, 23.31153107], [68.62735748, 23.31153107], [68.62735748, 23.31264114], [68.62680817, 23.31264114], [68.62680817, 23.31236076], [68.62652588, 23.31236076], [68.62652588, 23.31208038], [68.62568665, 23.31208038], [68.62568665, 23.31291962], [68.62596893, 23.3129158], [68.62596893, 23.31319237], [68.62625885, 23.31319046], [68.62625885, 23.31375122], [68.62652588, 23.31375122], [68.62652588, 23.31402969], [68.62680817, 23.31402969], [68.62680817, 23.31431007], [68.62708282, 23.31430626], [68.62708282, 23.3148613], [68.62735748, 23.31485939], [68.62735748, 23.31513977], [68.62763977, 23.31513977], [68.62763977, 23.31569672], [68.62735748, 23.31569099], [68.62735748, 23.31624985], [68.62708282, 23.31624985], [68.62708282, 23.3182106], [68.62735748, 23.3182106], [68.62735748, 23.31875038], [68.62708282, 23.31875038], [68.62708282, 23.31931114], [68.62680817, 23.31930542], [68.62680817, 23.31958389], [68.62652588, 23.31957817], [68.62652588, 23.31986046], [68.62625122, 23.31986046], [68.62625122, 23.32125092], [68.62652588, 23.32125092], [68.62652588, 23.32152939], [68.62680817, 23.32152939], [68.62680817, 23.32181168], [68.62708282, 23.32181168]]], [[[68.63986206, 23.31847191], [68.63986206, 23.31819534], [68.64013672, 23.3182106], [68.64013672, 23.31792068], [68.64041901, 23.31792068], [68.64041901, 23.31735992], [68.64069366, 23.31736183], [68.64069366, 23.31708336], [68.64125061, 23.31708336], [68.64125061, 23.31736183], [68.64097595, 23.31735992], [68.64097595, 23.3182106], [68.6415329, 23.3182106], [68.6415329, 23.31735992], [68.64180756, 23.31736183], [68.64180756, 23.31680679], [68.64263916, 23.31680107], [68.64263916, 23.3176403], [68.64290619, 23.3176403], [68.64290619, 23.3182106], [68.64347076, 23.3182106], [68.64347076, 23.31792068], [68.64375305, 23.31792068], [68.64375305, 23.31735992], [68.64347076, 23.31736183], [68.64347076, 23.31680679], [68.64319611, 23.31680679], [68.64319611, 23.31652832], [68.64290619, 23.31653023], [68.64290619, 23.31624985], [68.64319611, 23.31624985], [68.64319611, 23.31542015], [68.64180756, 23.31541634], [68.64180756, 23.31597137], [68.64013672, 23.31596947], [68.64013672, 23.31624985], [68.63957977, 23.31624985], [68.63957977, 23.31653023], [68.63930511, 23.31652832], [68.63930511, 23.31847191], [68.63986206, 23.31847191]]], [[[68.63263702, 23.3176403], [68.63263702, 23.31707954], [68.63291931, 23.31708336], [68.63291931, 23.31624985], [68.63318634, 23.31624985], [68.63318634, 23.31596947], [68.63375092, 23.31597137], [68.63375092, 23.31569672], [68.63402557, 23.31569672], [68.63402557, 23.31402779], [68.63375092, 23.31402969], [68.63375092, 23.31375122], [68.63346863, 23.31375122], [68.63346863, 23.31347084], [68.63319397, 23.31347466], [68.63319397, 23.31319237], [68.63291931, 23.31319237], [68.63291931, 23.3129158], [68.63263702, 23.31291962], [68.63263702, 23.31264114], [68.63207245, 23.31264114], [68.63207245, 23.31236076], [68.63180542, 23.31236076], [68.63180542, 23.31208229], [68.63124847, 23.31208038], [68.63124847, 23.31236076], [68.63069153, 23.31236076], [68.63069153, 23.31291962], [68.63041687, 23.3129158], [68.63041687, 23.31319237], [68.63069153, 23.31319046], [68.63069153, 23.31375122], [68.63096619, 23.31375122], [68.63096619, 23.31431007], [68.63124847, 23.31430626], [68.63124847, 23.31569672], [68.63153076, 23.31569099], [68.63153076, 23.3176403], [68.63263702, 23.3176403]]], [[[68.63181305, 23.32125092], [68.63180542, 23.32013893], [68.63207245, 23.32014084], [68.63207245, 23.31931114], [68.63236237, 23.31931114], [68.63236237, 23.31875038], [68.63153076, 23.31875038], [68.63153076, 23.31958389], [68.63124847, 23.31957817], [68.63124847, 23.32098007], [68.63153076, 23.32098007], [68.63153076, 23.32125092], [68.63181305, 23.32125092]]], [[[68.57347107, 23.36041832], [68.57347107, 23.36013031], [68.57375336, 23.36013985], [68.57375336, 23.35986137], [68.57402802, 23.35986137], [68.57402802, 23.3595829], [68.57430267, 23.3595829], [68.57430267, 23.35902786], [68.57457733, 23.35902977], [68.57457733, 23.35791969], [68.57402802, 23.35791969], [68.57402802, 23.35764122], [68.57375336, 23.35764122], [68.57375336, 23.35736084], [68.57402802, 23.35736084], [68.57402802, 23.35709], [68.57430267, 23.35709], [68.57430267, 23.35653114], [68.57457733, 23.35653114], [68.57457733, 23.35597038], [68.57430267, 23.35597229], [68.57430267, 23.35569572], [68.57458496, 23.35569572], [68.57458496, 23.35541725], [68.57485962, 23.35542107], [68.57485962, 23.35486031], [68.57514954, 23.35486031], [68.57514191, 23.35430336], [68.57541656, 23.35432053], [68.57541656, 23.35375023], [68.57569122, 23.35375023], [68.57569122, 23.35235977], [68.57457733, 23.35235977], [68.57457733, 23.35264015], [68.57347107, 23.35263824], [68.57347107, 23.35347366], [68.57319641, 23.35346985], [68.57319641, 23.35432053], [68.57290649, 23.35432053], [68.57290649, 23.35486031], [68.57263947, 23.35486031], [68.57263947, 23.35514069], [68.57235718, 23.35514069], [68.57235718, 23.35542107], [68.57096863, 23.35542107], [68.57096863, 23.35653114], [68.57068634, 23.35653114], [68.57068634, 23.35736084], [68.57041931, 23.35736084], [68.57041931, 23.35764122], [68.57013702, 23.35763931], [68.57013702, 23.35819435], [68.56986237, 23.35819054], [68.56986237, 23.35874939], [68.56958008, 23.35874939], [68.56958008, 23.35902977], [68.56986237, 23.35902786], [68.56986237, 23.3595829], [68.57041931, 23.3595829], [68.57041931, 23.35986137], [68.57096863, 23.35986137], [68.57096863, 23.3595829], [68.57125092, 23.3595829], [68.57125092, 23.35930634], [68.5715332, 23.35930824], [68.5715332, 23.35902977], [68.57180786, 23.35902977], [68.57180786, 23.35874939], [68.57236481, 23.35874939], [68.57236481, 23.3595829], [68.57263947, 23.35958099], [68.57263947, 23.36041832], [68.57347107, 23.36041832]]], [[[68.59791565, 23.36097145], [68.59791565, 23.36069489], [68.59902954, 23.36069489], [68.59902954, 23.36041641], [68.59929657, 23.36041832], [68.59929657, 23.36013031], [68.59958649, 23.36013985], [68.59958649, 23.3595829], [68.5993042, 23.3595829], [68.5993042, 23.35930634], [68.5984726, 23.35930634], [68.5984726, 23.3595829], [68.59819794, 23.3595829], [68.59819794, 23.35986137], [68.59708405, 23.35986137], [68.59708405, 23.3595829], [68.59680939, 23.3595829], [68.59680176, 23.35930634], [68.59625244, 23.35930634], [68.59625244, 23.3595829], [68.59597015, 23.35958099], [68.59597015, 23.36041832], [68.59625244, 23.36041641], [68.59625244, 23.36069489], [68.59708405, 23.36069489], [68.59708405, 23.36097145], [68.59791565, 23.36097145]]], [[[68.54070282, 23.37763977], [68.54069519, 23.3773613], [68.54096985, 23.3773613], [68.54096985, 23.37708282], [68.54069519, 23.37708282], [68.54069519, 23.37680626], [68.5404129, 23.37681007], [68.5404129, 23.37624931], [68.54013824, 23.37624931], [68.54013824, 23.37597084], [68.53986359, 23.37597275], [68.53986359, 23.3754158], [68.5395813, 23.37542152], [68.5395813, 23.3751297], [68.53930664, 23.37513924], [68.53930664, 23.37486076], [68.53819275, 23.37486076], [68.53819275, 23.37513924], [68.53791809, 23.3751297], [68.53791809, 23.37542152], [68.53819275, 23.3754158], [68.53819275, 23.37569427], [68.53847504, 23.37569427], [68.53847504, 23.37597275], [68.53874969, 23.37597084], [68.53874969, 23.3765316], [68.53902435, 23.37652779], [68.53902435, 23.37708282], [68.5395813, 23.37708282], [68.5395813, 23.3773613], [68.54013824, 23.37735939], [68.54013824, 23.37763977], [68.54070282, 23.37763977]]], [[[68.62680817, 23.3259716], [68.62680817, 23.32569313], [68.62763977, 23.32570076], [68.62763977, 23.32542038], [68.6279068, 23.32542038], [68.6279068, 23.32514191], [68.62819672, 23.32514191], [68.62819672, 23.32485962], [68.62847137, 23.32486343], [68.62847137, 23.32430649], [68.62874603, 23.3243103], [68.62874603, 23.32374954], [68.62902832, 23.32374954], [68.62902832, 23.32319069], [68.62930298, 23.3231945], [68.62930298, 23.32235909], [68.62902832, 23.32235909], [68.62902832, 23.32152939], [68.62875366, 23.32152748], [68.62875366, 23.32208252], [68.62847137, 23.32208061], [68.62847137, 23.32235909], [68.62819672, 23.32235909], [68.62819672, 23.32263947], [68.6279068, 23.32263947], [68.6279068, 23.32292175], [68.62763977, 23.32291603], [68.62763977, 23.32347107], [68.62735748, 23.32346916], [68.62735748, 23.32374954], [68.62708282, 23.32374954], [68.62708282, 23.32430458], [68.62625122, 23.32430458], [68.62625122, 23.32374954], [68.62596893, 23.32374954], [68.62596893, 23.32402802], [68.62541962, 23.32402802], [68.62541962, 23.32430267], [68.62513733, 23.32430649], [68.62513733, 23.32486343], [68.62486267, 23.32486343], [68.62486267, 23.3259716], [68.62541962, 23.3259716], [68.62541962, 23.32569313], [68.62625122, 23.32569313], [68.62625122, 23.3259716], [68.62680817, 23.3259716]]], [[[68.54207611, 23.34152985], [68.54207611, 23.34124947], [68.5423584, 23.34124947], [68.5423584, 23.33902168], [68.54264069, 23.33902168], [68.54264069, 23.33930969], [68.54429626, 23.33930969], [68.54429626, 23.33902168], [68.54458618, 23.3390274], [68.54458618, 23.33847046], [68.54430389, 23.33847046], [68.54430389, 23.33819389], [68.54208374, 23.33819389], [68.54208374, 23.33736038], [68.54180908, 23.33736038], [68.54180908, 23.33708191], [68.54152679, 23.33708191], [68.54152679, 23.33736038], [68.54125214, 23.33736038], [68.54125214, 23.33819389], [68.54152679, 23.33819389], [68.54152679, 23.33847046], [68.54125214, 23.33847046], [68.54125214, 23.33875275], [68.54152679, 23.33875275], [68.54152679, 23.33930969], [68.54125214, 23.33930969], [68.54125214, 23.33902168], [68.54096985, 23.3390274], [68.54096985, 23.33875275], [68.54069519, 23.33875275], [68.54069519, 23.3390274], [68.5404129, 23.33902168], [68.5404129, 23.33930969], [68.54069519, 23.33930588], [68.54069519, 23.33986282], [68.54096985, 23.33986282], [68.54096985, 23.34013939], [68.54125214, 23.34013939], [68.54125214, 23.34041977], [68.54152679, 23.34041977], [68.54152679, 23.34124947], [68.54180908, 23.34124947], [68.54180908, 23.34152985], [68.54207611, 23.34152985]]], [[[68.55014038, 23.34152985], [68.55014038, 23.34124947], [68.55042267, 23.34124947], [68.55041504, 23.34097481], [68.55069733, 23.34097481], [68.55069733, 23.34013939], [68.55097961, 23.34013939], [68.55097198, 23.33958244], [68.55069733, 23.33958244], [68.55069733, 23.33930588], [68.54875183, 23.33930969], [68.54875183, 23.33902168], [68.54792023, 23.3390274], [68.54792023, 23.33875275], [68.5459671, 23.33875275], [68.5459671, 23.33847046], [68.54541779, 23.33847046], [68.54541779, 23.33875275], [68.5451355, 23.33875275], [68.5451355, 23.34013939], [68.54541779, 23.34013939], [68.54541779, 23.34041977], [68.5459671, 23.34041977], [68.5459671, 23.34013939], [68.54624939, 23.34013939], [68.54624939, 23.33986282], [68.5459671, 23.33986282], [68.5459671, 23.33958054], [68.54763794, 23.33958054], [68.54763794, 23.33986282], [68.54846954, 23.33986282], [68.54846954, 23.34013939], [68.54985809, 23.34013939], [68.54985809, 23.34069252], [68.54957581, 23.34069061], [68.54957581, 23.34124947], [68.54985809, 23.34124947], [68.54985809, 23.34152985], [68.55014038, 23.34152985]]], [[[68.55680847, 23.34181023], [68.55680847, 23.34167099], [68.55680847, 23.34152794], [68.55625153, 23.34152985], [68.55625153, 23.34124947], [68.55541992, 23.34124947], [68.55541992, 23.33902168], [68.55513763, 23.33902168], [68.55513763, 23.33930969], [68.55403137, 23.33930588], [68.55403137, 23.33958244], [68.55374908, 23.33958054], [68.55374908, 23.33986282], [68.55319214, 23.33986282], [68.55319214, 23.34069252], [68.55291748, 23.34069252], [68.55291748, 23.34097481], [68.55319214, 23.34097099], [68.55319214, 23.34124947], [68.5534668, 23.34124947], [68.5534668, 23.34152985], [68.55374908, 23.34152985], [68.55374908, 23.34181023], [68.55647278, 23.34180641], [68.55680847, 23.34181023]]], [[[68.56375122, 23.34486198], [68.56375122, 23.34458351], [68.56430817, 23.34458351], [68.56430817, 23.34430695], [68.56458282, 23.34431076], [68.56458282, 23.34403038], [68.56485748, 23.34403038], [68.56485748, 23.3429203], [68.56513977, 23.3429203], [68.56513977, 23.34263992], [68.56458282, 23.34263992], [68.56458282, 23.34235954], [68.56346893, 23.34236145], [68.56346893, 23.34208488], [68.56263733, 23.34209061], [68.56263733, 23.34181023], [68.56124878, 23.34181023], [68.56124878, 23.34209061], [68.56096649, 23.34209061], [68.56096649, 23.3429203], [68.56124878, 23.3429203], [68.56124878, 23.34320068], [68.56153107, 23.34319687], [68.56153107, 23.34347153], [68.56180573, 23.34347153], [68.56180573, 23.34375], [68.56208038, 23.34375], [68.56208038, 23.34403038], [68.56236267, 23.34403038], [68.56236267, 23.34431076], [68.56263733, 23.34430695], [68.56263733, 23.34458351], [68.56319427, 23.34458351], [68.56319427, 23.34486198], [68.56375122, 23.34486198]]], [[[68.63153076, 23.35180473], [68.63153076, 23.35152817], [68.63181305, 23.35153008], [68.63181305, 23.35096169], [68.63208008, 23.35097122], [68.63208008, 23.34985924], [68.63236237, 23.34985924], [68.63236237, 23.34847069], [68.63263702, 23.3484726], [68.63263702, 23.34791756], [68.63291931, 23.34792137], [68.63291931, 23.34763908], [68.63318634, 23.34763908], [68.63318634, 23.34708023], [68.63346863, 23.34708405], [68.63346863, 23.34680557], [68.63430786, 23.34680748], [68.63430786, 23.34568977], [68.63486481, 23.34569359], [68.63486481, 23.34541893], [68.63569641, 23.34542084], [68.63569641, 23.34375], [68.63540649, 23.34375], [68.63540649, 23.34346962], [68.63513947, 23.34347153], [68.63513947, 23.34291649], [68.63485718, 23.3429203], [68.63485718, 23.34263992], [68.63430786, 23.34263992], [68.63430786, 23.34235954], [68.6340332, 23.34235954], [68.6340332, 23.34263992], [68.63346863, 23.34263992], [68.63346863, 23.3429203], [68.63291931, 23.34291649], [68.63291931, 23.34347153], [68.63318634, 23.34346962], [68.63318634, 23.34375], [68.63236237, 23.34375], [68.63236237, 23.34431076], [68.63069153, 23.34431076], [68.63069153, 23.34514809], [68.63096619, 23.34514809], [68.63096619, 23.34542084], [68.63124847, 23.34541893], [68.63124847, 23.34569359], [68.63153076, 23.34569359], [68.63153076, 23.34597206], [68.63263702, 23.34597015], [68.63263702, 23.34653091], [68.63236237, 23.34653091], [68.63236237, 23.34680748], [68.63180542, 23.34680557], [68.63180542, 23.34708405], [68.63153076, 23.34708023], [68.63153076, 23.34763908], [68.63180542, 23.34763908], [68.63180542, 23.3484726], [68.63096619, 23.34847069], [68.63096619, 23.34874916], [68.63124847, 23.34874916], [68.63124847, 23.34902954], [68.63153076, 23.34902954], [68.63153076, 23.34931183], [68.63124847, 23.34930611], [68.63124847, 23.34958267], [68.63096619, 23.34958076], [68.63096619, 23.34985924], [68.63041687, 23.34985924], [68.63041687, 23.34958076], [68.63014221, 23.34958267], [68.63014221, 23.34930611], [68.62985992, 23.34931183], [68.62985992, 23.34902954], [68.6295929, 23.34902954], [68.6295929, 23.34874916], [68.62930298, 23.34874916], [68.62930298, 23.34847069], [68.62874603, 23.34847069], [68.62874603, 23.34874916], [68.62847137, 23.34874916], [68.62847137, 23.35097122], [68.62985992, 23.35096169], [68.62985992, 23.35124969], [68.63041687, 23.35124969], [68.63041687, 23.35153008], [68.63097382, 23.35152817], [68.63097382, 23.35180473], [68.63153076, 23.35180473]]], [[[68.60346985, 23.33402824], [68.60346985, 23.33458328], [68.60320282, 23.33457756], [68.60320282, 23.33513832], [68.60208893, 23.33513832], [68.60208893, 23.33457756], [68.60152435, 23.33458328], [68.60152435, 23.33486176], [68.60124969, 23.33485985], [68.60124969, 23.3354187], [68.60098267, 23.3354187], [68.60098267, 23.3357029], [68.60069275, 23.33569527], [68.60069275, 23.33597183], [68.60041809, 23.33596039], [68.60041809, 23.33625031], [68.6001358, 23.33625031], [68.6001358, 23.33653259], [68.59986115, 23.33653259], [68.59986115, 23.33681107], [68.59958649, 23.33680534], [68.59958649, 23.33708382], [68.59819794, 23.33708191], [68.59819794, 23.33764267], [68.59792328, 23.33764267], [68.59792328, 23.33792114], [68.59764099, 23.33791733], [68.59764099, 23.33819389], [68.5973587, 23.33819389], [68.5973587, 23.33847046], [68.59597015, 23.33847046], [68.59597015, 23.33875275], [68.59541321, 23.33875275], [68.59541321, 23.33847046], [68.59485626, 23.33847046], [68.59485626, 23.33875275], [68.59430695, 23.33875275], [68.59430695, 23.33930969], [68.59401703, 23.33930969], [68.59401703, 23.33986282], [68.59375, 23.33986282], [68.59375, 23.34041977], [68.5929184, 23.34041405], [68.5929184, 23.34069252], [68.59263611, 23.34069061], [68.59263611, 23.34124947], [68.59179688, 23.34124947], [68.59179688, 23.34152985], [68.5909729, 23.34152985], [68.5909729, 23.34263992], [68.59069824, 23.34263992], [68.59069061, 23.34320068], [68.59041595, 23.34319687], [68.59041595, 23.34347153], [68.5901413, 23.34347153], [68.59014893, 23.34375], [68.58985901, 23.34375], [68.58985901, 23.34403038], [68.58958435, 23.34402847], [68.58958435, 23.34458351], [68.58930206, 23.3445797], [68.58930206, 23.34514809], [68.5890274, 23.34513855], [68.5890274, 23.34569359], [68.58875275, 23.34568977], [68.58872986, 23.34625053], [68.58847046, 23.34625053], [68.58847046, 23.34680748], [68.5881958, 23.34680557], [68.5881958, 23.34708405], [68.58790588, 23.34708023], [68.58790588, 23.34736061], [68.58763885, 23.34736061], [68.58763885, 23.34763908], [68.5873642, 23.34763908], [68.5873642, 23.34819412], [68.58708191, 23.34819412], [68.58708191, 23.3484726], [68.58680725, 23.34847069], [68.58680725, 23.34874916], [68.58653259, 23.34874916], [68.58653259, 23.34902954], [68.58625031, 23.34902763], [68.58625031, 23.34958267], [68.58597565, 23.34958267], [68.58598328, 23.35013962], [68.58569336, 23.35013962], [68.58569336, 23.35069466], [68.5854187, 23.35069275], [68.5854187, 23.35124969], [68.58513641, 23.35124969], [68.58513641, 23.35180473], [68.58486176, 23.35180473], [68.58486176, 23.3520813], [68.5845871, 23.35207939], [68.5845871, 23.35264015], [68.58429718, 23.35264015], [68.58429718, 23.35320091], [68.58403015, 23.35319328], [68.58403015, 23.35347366], [68.58347321, 23.35346985], [68.58347321, 23.35375023], [68.58235931, 23.35375023], [68.58235931, 23.35346985], [68.58152771, 23.35347366], [68.58152771, 23.35319328], [68.58069611, 23.35320091], [68.58069611, 23.35292053], [68.58040619, 23.35292053], [68.58040619, 23.35153008], [68.57985687, 23.35153008], [68.57985687, 23.35124969], [68.5790329, 23.35124969], [68.5790329, 23.35153008], [68.57847595, 23.35152817], [68.57847595, 23.35180473], [68.57819366, 23.35180473], [68.57819366, 23.3520813], [68.57791901, 23.3520813], [68.57791901, 23.35236359], [68.57763672, 23.35235977], [68.57763672, 23.35264015], [68.57791901, 23.35264015], [68.57791901, 23.35292053], [68.57763672, 23.35291672], [68.57763672, 23.35347366], [68.57736206, 23.35346985], [68.57736206, 23.35403061], [68.57707977, 23.35403061], [68.57707977, 23.35514069], [68.57736206, 23.35513878], [68.57736206, 23.35597229], [68.57707977, 23.35597038], [68.57707977, 23.35653114], [68.57736206, 23.35653114], [68.57736206, 23.35625076], [68.57763672, 23.35625076], [68.57763672, 23.35597038], [68.57791901, 23.35597229], [68.57791901, 23.35541725], [68.57818604, 23.35542107], [68.57818604, 23.35486031], [68.57847595, 23.35486031], [68.57847595, 23.35432053], [68.57875061, 23.35432053], [68.57875061, 23.35403061], [68.5790329, 23.35403061], [68.5790329, 23.35375023], [68.57930756, 23.35375023], [68.57930756, 23.35346985], [68.58013916, 23.35346985], [68.58013916, 23.35375023], [68.58040619, 23.35375023], [68.58040619, 23.35432053], [68.57985687, 23.35432053], [68.57985687, 23.35486031], [68.57958221, 23.35486031], [68.57958221, 23.35542107], [68.57930756, 23.35541725], [68.57930756, 23.35597229], [68.5790329, 23.35597038], [68.5790329, 23.35653114], [68.57958221, 23.35653114], [68.57958221, 23.35680962], [68.57985687, 23.35680962], [68.57985687, 23.35791969], [68.57958221, 23.35791969], [68.57958221, 23.35874939], [68.57930756, 23.35874939], [68.57930756, 23.35902977], [68.57902527, 23.35902786], [68.57902527, 23.3595829], [68.57930756, 23.3595829], [68.57930756, 23.36013985], [68.5790329, 23.36013031], [68.5790329, 23.36041832], [68.57875061, 23.36041641], [68.57875061, 23.36097145], [68.57847595, 23.36096954], [68.57847595, 23.36124992], [68.57791901, 23.36124992], [68.57791901, 23.3615284], [68.57763672, 23.3615284], [68.57763672, 23.36208344], [68.57736206, 23.36207962], [68.57736206, 23.36264038], [68.57707977, 23.36264038], [68.57707977, 23.36292267], [68.57680511, 23.36291695], [68.57680511, 23.36319351], [68.57653046, 23.36319351], [68.57653046, 23.36347008], [68.57597351, 23.36347008], [68.57597351, 23.36319351], [68.57569122, 23.36319351], [68.57569122, 23.36291695], [68.57485962, 23.36292267], [68.57485962, 23.36181068], [68.57514954, 23.36181068], [68.57514954, 23.36041832], [68.57485962, 23.36041641], [68.57485962, 23.36069489], [68.57430267, 23.36069489], [68.57430267, 23.36097145], [68.57402802, 23.36096954], [68.57402802, 23.3615284], [68.57375336, 23.3615284], [68.57375336, 23.36208344], [68.57319641, 23.36208344], [68.57319641, 23.36236191], [68.57290649, 23.36235809], [68.57290649, 23.36264038], [68.57263947, 23.36264038], [68.57263947, 23.36292267], [68.57236481, 23.36291695], [68.57236481, 23.36319351], [68.57208252, 23.3631916], [68.57208252, 23.36375046], [68.57180786, 23.36375046], [68.57180786, 23.36403275], [68.57152557, 23.36402702], [68.57152557, 23.36458206], [68.57125092, 23.36458015], [68.57125092, 23.36514282], [68.57096863, 23.36513901], [68.57096863, 23.36597443], [68.57068634, 23.36597061], [68.57068634, 23.36652946], [68.57041931, 23.36652946], [68.57041931, 23.36763954], [68.57013702, 23.36763954], [68.57013702, 23.36874962], [68.56986237, 23.36874962], [68.56986237, 23.36930656], [68.57068634, 23.36930084], [68.57068634, 23.37014008], [68.57041931, 23.37013817], [68.57041931, 23.37097168], [68.56986237, 23.37096977], [68.56986237, 23.37125015], [68.56931305, 23.37125015], [68.56931305, 23.37153053], [68.56874847, 23.37153053], [68.56874847, 23.37181091], [68.56819153, 23.37180519], [68.56819153, 23.37208366], [68.56791687, 23.37207031], [68.56791687, 23.37236023], [68.56819153, 23.37236023], [68.56819153, 23.37264061], [68.56846619, 23.37264061], [68.56846619, 23.37291908], [68.56874847, 23.37291718], [68.56874847, 23.37319374], [68.56958008, 23.37319374], [68.56958008, 23.37347221], [68.57068634, 23.37347031], [68.57068634, 23.37375069], [68.57180786, 23.37375069], [68.57180786, 23.37347031], [68.57263947, 23.37347221], [68.57263947, 23.37319374], [68.57347107, 23.37319374], [68.57347107, 23.37291718], [68.57458496, 23.37291718], [68.57458496, 23.37319374], [68.57485962, 23.37319374], [68.57485962, 23.37347221], [68.57541656, 23.37347221], [68.57541656, 23.37319374], [68.57653046, 23.37319374], [68.57653046, 23.37291718], [68.57818604, 23.37291908], [68.57818604, 23.37236023], [68.57847595, 23.37236023], [68.57847595, 23.37181091], [68.58013916, 23.37181091], [68.58013916, 23.37153053], [68.58096313, 23.37153053], [68.58096313, 23.37125015], [68.58152771, 23.37125015], [68.58152771, 23.37153053], [68.58180237, 23.37153053], [68.58180237, 23.37181091], [68.58152771, 23.37180519], [68.58152771, 23.37208366], [68.58180237, 23.37207031], [68.58180237, 23.37264061], [68.58208466, 23.3726387], [68.58208466, 23.37319374], [68.58235931, 23.37319374], [68.58235931, 23.37347221], [68.58625031, 23.37347221], [68.58625031, 23.37291718], [68.58653259, 23.37291908], [68.58653259, 23.37264061], [68.58763885, 23.37264061], [68.58763885, 23.37181091], [68.58735657, 23.37181091], [68.58735657, 23.37125015], [68.58680725, 23.37125015], [68.58680725, 23.37070084], [68.58653259, 23.37070084], [68.58653259, 23.37014008], [68.58625031, 23.37014008], [68.58625031, 23.3698597], [68.58652496, 23.3698616], [68.58652496, 23.36930656], [68.58680725, 23.36930656], [68.58680725, 23.36902809], [68.58708954, 23.36903], [68.58708954, 23.36874962], [68.5873642, 23.36874962], [68.58735657, 23.36847115], [68.58791351, 23.36847305], [68.58791351, 23.36930656], [68.5881958, 23.36930656], [68.5881958, 23.37097168], [68.58847046, 23.37096977], [68.58847046, 23.37125015], [68.58875275, 23.37125015], [68.58875275, 23.37153053], [68.5890274, 23.37153053], [68.5890274, 23.37181091], [68.58930206, 23.37181091], [68.58930206, 23.37236023], [68.58957672, 23.37236023], [68.58957672, 23.37291908], [68.58930206, 23.37291718], [68.58930206, 23.37319374], [68.58875275, 23.37318993], [68.58875275, 23.37431145], [68.5890274, 23.37431145], [68.5890274, 23.37402916], [68.58957672, 23.37402916], [68.58957672, 23.37375069], [68.58985901, 23.37375069], [68.58985901, 23.37347031], [68.5901413, 23.37347221], [68.5901413, 23.37291718], [68.59041595, 23.37291908], [68.59041595, 23.37236023], [68.5909729, 23.37236023], [68.5909729, 23.37207031], [68.59124756, 23.37208366], [68.59124756, 23.37180519], [68.59179688, 23.37181091], [68.59179688, 23.37153053], [68.59208679, 23.37153053], [68.59208679, 23.37125015], [68.59263611, 23.37125015], [68.59263611, 23.37096977], [68.5929184, 23.37097168], [68.5929184, 23.37041664], [68.59319305, 23.37042046], [68.59319305, 23.37014008], [68.59348297, 23.37014008], [68.59348297, 23.3698597], [68.59375, 23.3698616], [68.59375, 23.36958313], [68.59402466, 23.36958313], [68.59402466, 23.36930656], [68.59430695, 23.36930656], [68.59430695, 23.36902809], [68.5945816, 23.36903], [68.5945816, 23.36874962], [68.59485626, 23.36874962], [68.59485626, 23.36791992], [68.59513855, 23.36791992], [68.59513855, 23.36763954], [68.59541321, 23.36763954], [68.59541321, 23.36708069], [68.5956955, 23.3670845], [68.5956955, 23.36652756], [68.59597015, 23.36652946], [68.59597015, 23.36626053], [68.59625244, 23.36626053], [68.59625244, 23.36597061], [68.5965271, 23.36597443], [68.5965271, 23.36569214], [68.59680176, 23.36569214], [68.59680939, 23.36513901], [68.59707642, 23.36514282], [68.59707642, 23.36486053], [68.5973587, 23.36486053], [68.5973587, 23.36458015], [68.59764099, 23.36458206], [68.59764099, 23.36402702], [68.59792328, 23.36403275], [68.59792328, 23.3631916], [68.59819794, 23.36319351], [68.59819794, 23.36263847], [68.59792328, 23.36264038], [68.59792328, 23.36235809], [68.59764099, 23.36236191], [68.59764099, 23.36208344], [68.5973587, 23.36208344], [68.5973587, 23.36180496], [68.59707642, 23.36181068], [68.59707642, 23.3615284], [68.59680939, 23.3615284], [68.59680176, 23.36124992], [68.59570313, 23.36124992], [68.59570313, 23.3615284], [68.59430695, 23.3615284], [68.59430695, 23.36096954], [68.5945816, 23.36097145], [68.5945816, 23.36041641], [68.59485626, 23.36041832], [68.59485626, 23.35902977], [68.59513855, 23.35902977], [68.59513855, 23.35874939], [68.59570313, 23.35874939], [68.5956955, 23.35847282], [68.5965271, 23.35847282], [68.5965271, 23.35819435], [68.59680176, 23.35819435], [68.59680939, 23.35791779], [68.59707642, 23.35791969], [68.59707642, 23.35764122], [68.5973587, 23.35764122], [68.5973587, 23.35736084], [68.59764099, 23.35736084], [68.59764099, 23.35709], [68.59874725, 23.35709], [68.59874725, 23.35736084], [68.59902954, 23.35736084], [68.59902954, 23.35791969], [68.59986115, 23.35791779], [68.59986115, 23.35819435], [68.6020813, 23.35819435], [68.6020813, 23.35791779], [68.60263824, 23.35791969], [68.60263824, 23.35764122], [68.60375214, 23.35764122], [68.60375214, 23.35709], [68.60346985, 23.35709], [68.60346985, 23.35653114], [68.60375214, 23.35653114], [68.60375214, 23.35625076], [68.60430908, 23.35625076], [68.60430908, 23.35597038], [68.60458374, 23.35597229], [68.60458374, 23.35569572], [68.6048584, 23.35569572], [68.6048584, 23.35541725], [68.60542297, 23.35542107], [68.60542297, 23.35514069], [68.60569763, 23.35514069], [68.60569763, 23.35486031], [68.60597229, 23.35486031], [68.60597229, 23.35432053], [68.60624695, 23.35432053], [68.60624695, 23.35403061], [68.60652924, 23.35403061], [68.60652924, 23.35375023], [68.60679626, 23.35375023], [68.60679626, 23.35346985], [68.60708618, 23.35347366], [68.60708618, 23.35319328], [68.60736084, 23.35320091], [68.60736084, 23.35292053], [68.6084671, 23.35292053], [68.6084671, 23.35264015], [68.60901642, 23.35264015], [68.60901642, 23.35235977], [68.60958099, 23.35236359], [68.60958099, 23.3520813], [68.61013794, 23.3520813], [68.61013794, 23.35180473], [68.61069489, 23.35180473], [68.61069489, 23.3520813], [68.61042023, 23.35207939], [68.61042023, 23.35264015], [68.61013794, 23.35264015], [68.61013794, 23.35320091], [68.60986328, 23.35320091], [68.60986328, 23.35375023], [68.61013794, 23.35375023], [68.61013794, 23.35514069], [68.60986328, 23.35513878], [68.60986328, 23.35569572], [68.60958099, 23.35569572], [68.60958099, 23.35597229], [68.60930634, 23.35597038], [68.60930634, 23.35653114], [68.60902405, 23.35652733], [68.60902405, 23.35819435], [68.60930634, 23.35819054], [68.60930634, 23.35930824], [68.60902405, 23.35930634], [68.60902405, 23.36013985], [68.60874939, 23.36013985], [68.60874939, 23.36069489], [68.6084671, 23.36069107], [68.6084671, 23.36124992], [68.60791779, 23.36124992], [68.60791779, 23.3615284], [68.60764313, 23.3615284], [68.60764313, 23.36292267], [68.60736084, 23.36291695], [68.60736084, 23.36347008], [68.60708618, 23.36347008], [68.60708618, 23.36375046], [68.60679626, 23.36375046], [68.60679626, 23.36403275], [68.60708618, 23.36402702], [68.60708618, 23.36458206], [68.60736084, 23.36458206], [68.60736084, 23.3643055], [68.60874939, 23.36431122], [68.60874939, 23.36375046], [68.60901642, 23.36375046], [68.60901642, 23.36292267], [68.60930634, 23.36292267], [68.60930634, 23.36207962], [68.60958099, 23.36208344], [68.60958099, 23.3615284], [68.61013794, 23.3615284], [68.61013794, 23.36096954], [68.61042023, 23.36097145], [68.61042023, 23.35874939], [68.61068726, 23.35874939], [68.61068726, 23.35764122], [68.61152649, 23.35764122], [68.61152649, 23.35736084], [68.61180878, 23.35736084], [68.61180878, 23.35709], [68.61235809, 23.35709], [68.61235809, 23.35653114], [68.61264038, 23.35653114], [68.61264038, 23.35597038], [68.61291504, 23.35597229], [68.61291504, 23.35569572], [68.61347198, 23.35569572], [68.61347198, 23.35541725], [68.61402893, 23.35542107], [68.61402893, 23.35514069], [68.61486053, 23.35514069], [68.61486053, 23.35486031], [68.6159668, 23.35486031], [68.6159668, 23.35457993], [68.61680603, 23.35458565], [68.61680603, 23.35430336], [68.61736298, 23.35432053], [68.61736298, 23.35403061], [68.61791992, 23.35403061], [68.61791992, 23.35346985], [68.61819458, 23.35347366], [68.61819458, 23.35291672], [68.61846924, 23.35292053], [68.61846924, 23.35124969], [68.61818695, 23.35124969], [68.61818695, 23.35069275], [68.61791992, 23.35069466], [68.61791992, 23.34985924], [68.61763763, 23.34985924], [68.61763763, 23.34902954], [68.61736298, 23.34902954], [68.61736298, 23.34847069], [68.61680603, 23.34847069], [68.61680603, 23.34874916], [68.61653137, 23.34874916], [68.61653137, 23.34931183], [68.61624908, 23.34930611], [68.61624908, 23.34958267], [68.6159668, 23.34958076], [68.6159668, 23.34985924], [68.61569214, 23.34985924], [68.61569214, 23.35042191], [68.61486053, 23.35042191], [68.61486053, 23.34985924], [68.61514282, 23.34985924], [68.61513519, 23.34930611], [68.61541748, 23.34931183], [68.61541748, 23.34847069], [68.61569214, 23.3484726], [68.61569214, 23.34791756], [68.6159668, 23.34792137], [68.6159668, 23.34736061], [68.61624908, 23.34736061], [68.61624908, 23.34708023], [68.61653137, 23.34708405], [68.61653137, 23.3465271], [68.61680603, 23.34653091], [68.61680603, 23.34568977], [68.61708069, 23.34569359], [68.61708069, 23.34458351], [68.61736298, 23.34458351], [68.61736298, 23.34319687], [68.61763763, 23.34320068], [68.61763763, 23.34181023], [68.61791992, 23.34181023], [68.61791992, 23.34041977], [68.61818695, 23.34041977], [68.61818695, 23.33958054], [68.61846924, 23.33958244], [68.61846924, 23.33930588], [68.61875153, 23.33930969], [68.61875153, 23.33902168], [68.61902618, 23.3390274], [68.61902618, 23.33875275], [68.61930847, 23.33875275], [68.61930847, 23.33847046], [68.61958313, 23.33847046], [68.61958313, 23.33791733], [68.61985779, 23.33792114], [68.61985779, 23.33736038], [68.62013245, 23.33736038], [68.62013245, 23.33681107], [68.6204071, 23.33681107], [68.6204071, 23.33291817], [68.62013245, 23.33291817], [68.62013245, 23.33180809], [68.61985779, 23.33180809], [68.61985779, 23.33069038], [68.61958313, 23.3306942], [68.61958313, 23.33013916], [68.61930847, 23.3301506], [68.61930847, 23.32958031], [68.61902618, 23.32958412], [68.61902618, 23.32902718], [68.61875153, 23.32903099], [68.61875153, 23.32875061], [68.61846924, 23.32875061], [68.61846924, 23.32847023], [68.61819458, 23.32847214], [68.61819458, 23.32819557], [68.61763763, 23.32819557], [68.61763763, 23.3279171], [68.61736298, 23.32792091], [68.61736298, 23.32764053], [68.61707306, 23.32764053], [68.61707306, 23.32792091], [68.61680603, 23.3279171], [68.61680603, 23.32819557], [68.61653137, 23.32819557], [68.61653137, 23.32958412], [68.61624908, 23.32958031], [68.61624908, 23.33291817], [68.61653137, 23.33291817], [68.61653137, 23.33402824], [68.61569214, 23.33402824], [68.61569214, 23.33374977], [68.61429596, 23.33374977], [68.61429596, 23.33402824], [68.61347198, 23.33402824], [68.61347198, 23.33374977], [68.61374664, 23.33374977], [68.61374664, 23.33319092], [68.61402893, 23.33319473], [68.61402893, 23.33263969], [68.61374664, 23.33263969], [68.61374664, 23.33236122], [68.61152649, 23.33236122], [68.61152649, 23.33263969], [68.61068726, 23.33263969], [68.61068726, 23.33402824], [68.61042023, 23.33402824], [68.61042023, 23.3354187], [68.61068726, 23.3354187], [68.61068726, 23.33513832], [68.61096954, 23.33513832], [68.61096954, 23.33485985], [68.61125183, 23.33486176], [68.61125183, 23.33458328], [68.61180878, 23.33457756], [68.61180878, 23.3357029], [68.61152649, 23.33569527], [68.61152649, 23.33597183], [68.61096954, 23.33596039], [68.61096954, 23.33625031], [68.61068726, 23.33625031], [68.61068726, 23.33653259], [68.61042023, 23.33653259], [68.61042023, 23.33681107], [68.61013794, 23.33680534], [68.61013794, 23.33708382], [68.60986328, 23.33708191], [68.60986328, 23.33736038], [68.60958099, 23.33736038], [68.60958099, 23.33764267], [68.60930634, 23.33763885], [68.60930634, 23.33819389], [68.60902405, 23.33819389], [68.60902405, 23.33847046], [68.60874939, 23.33847046], [68.60874939, 23.33875275], [68.60791779, 23.33875275], [68.60791779, 23.3390274], [68.60736084, 23.33902168], [68.60736084, 23.33930969], [68.60708618, 23.33930588], [68.60708618, 23.33958244], [68.60652924, 23.33958054], [68.60652924, 23.33986282], [68.60624695, 23.33986282], [68.60624695, 23.34013939], [68.60597229, 23.34013939], [68.60597229, 23.34041977], [68.60569763, 23.34041405], [68.60569763, 23.34069252], [68.60541534, 23.34069252], [68.60541534, 23.34097481], [68.60513306, 23.34097099], [68.60513306, 23.34124947], [68.60430908, 23.34124947], [68.60430908, 23.34097099], [68.60402679, 23.34097099], [68.60402679, 23.34152985], [68.60375214, 23.34152794], [68.60375214, 23.34236145], [68.60346985, 23.34235954], [68.60346985, 23.3429203], [68.6029129, 23.3429203], [68.6029129, 23.34320068], [68.60236359, 23.34319687], [68.60236359, 23.34347153], [68.60180664, 23.34346962], [68.60180664, 23.34375], [68.60151672, 23.34375], [68.60151672, 23.34403038], [68.60124969, 23.34403038], [68.60124969, 23.34431076], [68.60069275, 23.34430695], [68.60069275, 23.34458351], [68.60041809, 23.34458351], [68.60041809, 23.34486198], [68.6001358, 23.34486008], [68.6001358, 23.34542084], [68.59986115, 23.34541893], [68.59986115, 23.34569359], [68.5993042, 23.34569359], [68.5993042, 23.34597206], [68.59874725, 23.34597015], [68.59874725, 23.34625053], [68.59819794, 23.34625053], [68.59819794, 23.34653091], [68.59764099, 23.34653091], [68.59764099, 23.34680748], [68.59680939, 23.34680748], [68.59680939, 23.34625053], [68.59707642, 23.34625053], [68.59707642, 23.34568977], [68.5973587, 23.34569359], [68.5973587, 23.34513855], [68.59764099, 23.34514809], [68.59764099, 23.3445797], [68.59791565, 23.34458351], [68.59791565, 23.34430695], [68.59819794, 23.34431076], [68.59819794, 23.34403038], [68.59874725, 23.34403038], [68.59874725, 23.34375], [68.59902954, 23.34375], [68.59902954, 23.34346962], [68.59958649, 23.34347153], [68.59958649, 23.34319687], [68.59986115, 23.34320068], [68.59986115, 23.3429203], [68.60041809, 23.3429203], [68.60041809, 23.34263992], [68.60069275, 23.34263992], [68.60069275, 23.34209061], [68.60098267, 23.34209061], [68.60098267, 23.34181023], [68.60124969, 23.34181023], [68.60124969, 23.34097099], [68.60152435, 23.34097481], [68.60152435, 23.34013939], [68.60180664, 23.34013939], [68.60180664, 23.33986282], [68.60208893, 23.33986282], [68.6020813, 23.33958244], [68.60236359, 23.33958244], [68.60236359, 23.33930588], [68.60263824, 23.33930969], [68.60263824, 23.33902168], [68.6029129, 23.3390274], [68.6029129, 23.33875275], [68.60346985, 23.33875275], [68.60346985, 23.33847046], [68.60375214, 23.33847046], [68.60375214, 23.33819389], [68.60402679, 23.33819389], [68.60402679, 23.33763885], [68.60430908, 23.33764267], [68.60430908, 23.33736038], [68.60457611, 23.33736038], [68.60457611, 23.33681107], [68.6048584, 23.33681107], [68.6048584, 23.33625031], [68.60513306, 23.33625031], [68.60513306, 23.33596039], [68.60541534, 23.33597183], [68.60541534, 23.33541679], [68.60569763, 23.3354187], [68.60569763, 23.33485985], [68.60541534, 23.33486176], [68.60541534, 23.33458328], [68.60569763, 23.33458328], [68.60569763, 23.33402824], [68.60597229, 23.33402824], [68.60597229, 23.33346939], [68.60624695, 23.3334713], [68.60624695, 23.33319473], [68.60652924, 23.33319473], [68.60652924, 23.33291626], [68.60679626, 23.33291817], [68.60679626, 23.33263969], [68.60708618, 23.33263969], [68.60708618, 23.33236122], [68.60736084, 23.33236122], [68.60736084, 23.33180809], [68.60652924, 23.33180618], [68.60652924, 23.33208275], [68.60597229, 23.33208084], [68.60597229, 23.33236122], [68.60569763, 23.33236122], [68.60569763, 23.33263969], [68.60513306, 23.33263969], [68.60513306, 23.33291817], [68.6048584, 23.33291626], [68.6048584, 23.33319473], [68.60430908, 23.33319473], [68.60430908, 23.3334713], [68.60402679, 23.33346939], [68.60402679, 23.33374977], [68.60375214, 23.33374977], [68.60375214, 23.33402824], [68.60346985, 23.33402824]]], [[[68.50458527, 23.38458252], [68.50458527, 23.38430786], [68.50485992, 23.38430786], [68.50485992, 23.38375092], [68.50514221, 23.38375092], [68.50514221, 23.38125992], [68.50485992, 23.38125992], [68.50485992, 23.38097], [68.50430298, 23.38097], [68.50430298, 23.38125992], [68.5045929, 23.38125992], [68.5045929, 23.38181114], [68.50430298, 23.38181114], [68.50430298, 23.38264084], [68.5045929, 23.38264084], [68.5045929, 23.38292122], [68.50430298, 23.3829174], [68.50430298, 23.38319588], [68.50375366, 23.38319588], [68.50375366, 23.38430786], [68.50430298, 23.38430786], [68.50430298, 23.38458252], [68.50458527, 23.38458252]]], [[[68.57930756, 23.38541985], [68.57930756, 23.38513947], [68.58013916, 23.38513947], [68.58013916, 23.38486099], [68.58069611, 23.38486099], [68.58069611, 23.38458061], [68.58125305, 23.38458252], [68.58125305, 23.38430786], [68.58152771, 23.38430786], [68.58152771, 23.38402748], [68.58180237, 23.38402939], [68.58180237, 23.38375092], [68.58207703, 23.38375092], [68.58207703, 23.38347054], [68.58235931, 23.38347244], [68.58235931, 23.38319588], [68.5826416, 23.38319588], [68.5826416, 23.3829174], [68.58319092, 23.38292122], [68.58319092, 23.38264084], [68.58347321, 23.38264084], [68.58347321, 23.38236046], [68.58374786, 23.38236046], [68.58374786, 23.38208008], [68.58403015, 23.3820858], [68.58403015, 23.38152695], [68.58429718, 23.38153076], [68.58429718, 23.38125992], [68.58486176, 23.38125992], [68.58486176, 23.38097], [68.5854187, 23.38097382], [68.5854187, 23.38041687], [68.58598328, 23.38042068], [68.58598328, 23.3801403], [68.58625031, 23.3801403], [68.58625031, 23.37903023], [68.58653259, 23.37903023], [68.58653259, 23.37874985], [68.58680725, 23.37874985], [68.58680725, 23.37846947], [68.58708191, 23.37847137], [68.58708191, 23.37791634], [68.58735657, 23.37792015], [68.58735657, 23.37624931], [68.58708954, 23.37624931], [68.58708954, 23.37597084], [68.58652496, 23.37597275], [68.58652496, 23.37569427], [68.58625031, 23.37569427], [68.58625031, 23.37597275], [68.58569336, 23.37597275], [68.58569336, 23.37708282], [68.5854187, 23.37708092], [68.5854187, 23.37763977], [68.58486176, 23.37763977], [68.58486176, 23.37792015], [68.5845871, 23.37792015], [68.5845871, 23.37820053], [68.58429718, 23.37820053], [68.58429718, 23.37903023], [68.58374786, 23.37903023], [68.58374786, 23.37874985], [68.58319092, 23.37874985], [68.58319092, 23.37930489], [68.58291626, 23.37930489], [68.58291626, 23.37986374], [68.58319092, 23.37985992], [68.58319092, 23.3801403], [68.58374786, 23.3801403], [68.58374786, 23.38042068], [68.58347321, 23.38042068], [68.58347321, 23.38070107], [68.58319092, 23.38069534], [68.58319092, 23.38097382], [68.58291626, 23.38097], [68.58291626, 23.38125992], [68.58235931, 23.38125992], [68.58235931, 23.38153076], [68.58207703, 23.38153076], [68.58207703, 23.38181114], [68.58125305, 23.38180351], [68.58125305, 23.3820858], [68.58069611, 23.38208008], [68.58069611, 23.38236046], [68.58040619, 23.38236046], [68.58040619, 23.38264084], [68.58013916, 23.38264084], [68.58013916, 23.38292122], [68.5798645, 23.3829174], [68.5798645, 23.38319588], [68.57902527, 23.38319588], [68.57902527, 23.38347244], [68.57847595, 23.38347054], [68.57847595, 23.38375092], [68.57818604, 23.38375092], [68.57818604, 23.38402939], [68.57791901, 23.38402939], [68.57791901, 23.38513947], [68.57818604, 23.38513947], [68.57818604, 23.38541985], [68.57930756, 23.38541985]]], [[[68.53624725, 23.38541985], [68.53624725, 23.38458061], [68.53652954, 23.38458252], [68.53652954, 23.38375092], [68.53624725, 23.38375092], [68.53624725, 23.38319016], [68.5359726, 23.38319588], [68.5359726, 23.3829174], [68.53624725, 23.38292122], [68.53624725, 23.38264084], [68.53652954, 23.38264084], [68.53652954, 23.38236046], [68.53779602, 23.38236046], [68.53874969, 23.38236046], [68.53874969, 23.38264084], [68.53901672, 23.38264084], [68.53901672, 23.38236046], [68.53985596, 23.38236046], [68.53985596, 23.38208008], [68.54069519, 23.3820858], [68.54069519, 23.38180351], [68.54152679, 23.38181114], [68.54152679, 23.38153076], [68.54207611, 23.38153076], [68.54207611, 23.38125992], [68.5423584, 23.38125992], [68.5423584, 23.38097], [68.54291534, 23.38097382], [68.54291534, 23.3801384], [68.54264069, 23.3801403], [68.54264069, 23.37985992], [68.5423584, 23.37986374], [68.5423584, 23.37958145], [68.54208374, 23.37958145], [68.54208374, 23.37930489], [68.54125214, 23.37930489], [68.54125214, 23.37958145], [68.54069519, 23.37958145], [68.54069519, 23.37986374], [68.54013824, 23.37985992], [68.54013824, 23.3801403], [68.5395813, 23.3801403], [68.5395813, 23.38042068], [68.53848267, 23.38042068], [68.53848267, 23.38070107], [68.53791809, 23.38069534], [68.53791809, 23.38097382], [68.53708649, 23.38097382], [68.53708649, 23.38069534], [68.53736115, 23.38070107], [68.53736115, 23.38042068], [68.5376358, 23.38042068], [68.5376358, 23.3801403], [68.53708649, 23.3801403], [68.53708649, 23.38042068], [68.53652954, 23.38042068], [68.53652954, 23.38070107], [68.53617859, 23.38069725], [68.53542328, 23.38070107], [68.53542328, 23.38125992], [68.53624725, 23.38125992], [68.53624725, 23.38153076], [68.53598022, 23.38153076], [68.53598022, 23.38181114], [68.53569794, 23.38180351], [68.53569794, 23.3820858], [68.53541565, 23.3820858], [68.53542328, 23.38236046], [68.53514099, 23.38236046], [68.53514099, 23.38264084], [68.5348587, 23.38263893], [68.5348587, 23.38319588], [68.53457642, 23.38319016], [68.53457642, 23.38402939], [68.5348587, 23.38402939], [68.5348587, 23.38513947], [68.53514099, 23.38513947], [68.53514099, 23.38541985], [68.53624725, 23.38541985]]], [[[68.47097015, 23.40570068], [68.47097015, 23.40542984], [68.4723587, 23.40542984], [68.4723587, 23.40485954], [68.47208405, 23.40486145], [68.47208405, 23.40458107], [68.47125244, 23.40458107], [68.47125244, 23.40430641], [68.47206879, 23.40430641], [68.47292328, 23.40431023], [68.47292328, 23.40403175], [68.47402954, 23.40403175], [68.47402954, 23.40374947], [68.47486115, 23.40374947], [68.47486115, 23.40403175], [68.47570038, 23.40403175], [68.47570038, 23.40346909], [68.47597504, 23.4034729], [68.47597504, 23.40291595], [68.47402954, 23.40291595], [68.47402954, 23.40319443], [68.47291565, 23.40319443], [68.47291565, 23.4034729], [68.4723587, 23.40346909], [68.4723587, 23.40374947], [68.47180176, 23.40374947], [68.47180176, 23.40395164], [68.47180176, 23.40402794], [68.47097015, 23.40403175], [68.47097015, 23.40431023], [68.47041321, 23.40430641], [68.47041321, 23.40458107], [68.46985626, 23.40458107], [68.46985626, 23.40514183], [68.46956635, 23.40514183], [68.46956635, 23.40570068], [68.47097015, 23.40570068]]], [[[68.55680847, 23.37181091], [68.55708313, 23.37181091], [68.55708313, 23.37264061], [68.55735779, 23.3726387], [68.55735779, 23.37319374], [68.55764008, 23.37319374], [68.55764008, 23.37347221], [68.55819702, 23.37347031], [68.55819702, 23.37375069], [68.55874634, 23.37375069], [68.55874634, 23.37402916], [68.55930328, 23.37402916], [68.55930328, 23.37431145], [68.55958557, 23.37430573], [68.55958557, 23.3745842], [68.56014252, 23.37458038], [68.56014252, 23.37486076], [68.56069183, 23.37486076], [68.56069183, 23.37542152], [68.56041718, 23.3754158], [68.56041718, 23.37569427], [68.56014252, 23.37569427], [68.56014252, 23.37597275], [68.5595932, 23.37597084], [68.5595932, 23.37624931], [68.55652618, 23.37624931], [68.55652618, 23.3765316], [68.55625153, 23.3765316], [68.55625153, 23.37681007], [68.55596924, 23.37680626], [68.55596924, 23.37708282], [68.55513763, 23.37708282], [68.55513763, 23.37680626], [68.55430603, 23.37680626], [68.55430603, 23.37708282], [68.55403137, 23.37708282], [68.55403137, 23.37847137], [68.55430603, 23.37846947], [68.55430603, 23.3801403], [68.55401611, 23.3801403], [68.55401611, 23.38070107], [68.55374908, 23.38069534], [68.55374908, 23.38097382], [68.5534668, 23.38097], [68.5534668, 23.38153076], [68.55319214, 23.38153076], [68.55319214, 23.38181114], [68.55291748, 23.38180351], [68.55291748, 23.3820858], [68.55263519, 23.3820858], [68.55264282, 23.38236046], [68.55236053, 23.38236046], [68.55236053, 23.38430786], [68.55152893, 23.38430023], [68.55152893, 23.38541985], [68.55179596, 23.38541985], [68.55179596, 23.38513947], [68.55263519, 23.38513947], [68.55263519, 23.3856945], [68.55236053, 23.38569069], [68.55236053, 23.38624954], [68.55208588, 23.38624954], [68.55208588, 23.38652992], [68.55124664, 23.38652992], [68.55124664, 23.38624954], [68.55069733, 23.38624954], [68.55069733, 23.38652992], [68.55041504, 23.38652992], [68.55042267, 23.38680077], [68.55014038, 23.38680649], [68.55014038, 23.38736153], [68.54985809, 23.38735962], [68.54985809, 23.38763809], [68.54957581, 23.38763809], [68.54957581, 23.38791847], [68.54930878, 23.38791847], [68.54930878, 23.38902855], [68.54902649, 23.38902855], [68.54902649, 23.39031029], [68.54902649, 23.39069366], [68.54875183, 23.39069176], [68.54875183, 23.39180946], [68.54846954, 23.39180946], [68.54846954, 23.39264107], [68.54792023, 23.39264107], [68.54792023, 23.39291954], [68.54736328, 23.39291954], [68.54736328, 23.39319992], [68.54708099, 23.39319992], [68.54708099, 23.39375114], [68.54680634, 23.39375114], [68.54680634, 23.39431], [68.54569244, 23.39430618], [68.54569244, 23.39458466], [68.54541779, 23.39458084], [68.54541779, 23.39513969], [68.54569244, 23.39513969], [68.54569244, 23.39542007], [68.54652405, 23.39541435], [68.54652405, 23.39624977], [68.54624939, 23.39624977], [68.54624939, 23.39680672], [68.54541779, 23.39680672], [68.54541779, 23.39652824], [68.54514313, 23.39653015], [68.54514313, 23.39596939], [68.54486084, 23.3959713], [68.54486084, 23.39569664], [68.54458618, 23.39569664], [68.54458618, 23.39541435], [68.54319763, 23.39542007], [68.54319763, 23.39513969], [68.54264069, 23.39513969], [68.54264069, 23.39458084], [68.54291534, 23.39458466], [68.54291534, 23.39402771], [68.54319763, 23.39402962], [68.54319763, 23.39347076], [68.54291534, 23.39347458], [68.54291534, 23.39319229], [68.54264069, 23.39319992], [68.54264069, 23.39291954], [68.54207611, 23.39291954], [68.54207611, 23.39264107], [68.5423584, 23.39264107], [68.5423584, 23.39236069], [68.54292297, 23.39236069], [68.54291534, 23.39152718], [68.54319763, 23.3915329], [68.54319763, 23.39069176], [68.54347229, 23.39069366], [68.54347229, 23.39013863], [68.54402924, 23.39014244], [68.54402924, 23.38986015], [68.54430389, 23.38986015], [68.54430389, 23.38930511], [68.54402924, 23.38931274], [68.54402924, 23.38874817], [68.54374695, 23.38874817], [68.54374695, 23.38820076], [68.54291534, 23.38819504], [68.54291534, 23.3884716], [68.5423584, 23.3884697], [68.5423584, 23.38874817], [68.54207611, 23.38874817], [68.54207611, 23.38902855], [68.54180908, 23.38902855], [68.54180908, 23.38958359], [68.54208374, 23.38958359], [68.54208374, 23.38986015], [68.5423584, 23.38986015], [68.5423584, 23.39042282], [68.54264069, 23.39042282], [68.54264069, 23.39125061], [68.5423584, 23.39125061], [68.5423584, 23.39180946], [68.54125214, 23.39180565], [68.54125214, 23.39208221], [68.54096985, 23.39208031], [68.54096985, 23.39236069], [68.54070282, 23.39236069], [68.54070282, 23.39264107], [68.5404129, 23.39264107], [68.5404129, 23.39291954], [68.54013824, 23.39291954], [68.54013824, 23.39319992], [68.5395813, 23.39319229], [68.5395813, 23.39347458], [68.53930664, 23.39347076], [68.53930664, 23.39375114], [68.53985596, 23.39375114], [68.53985596, 23.39402962], [68.5404129, 23.39402962], [68.5404129, 23.39431], [68.5423584, 23.39431], [68.5423584, 23.39486122], [68.54207611, 23.39486122], [68.54207611, 23.39542007], [68.54152679, 23.39541435], [68.54152679, 23.39569664], [68.54125214, 23.39569664], [68.54125214, 23.39680672], [68.5423584, 23.39680672], [68.5423584, 23.39708328], [68.54291534, 23.39708328], [68.54291534, 23.39736176], [68.54429626, 23.39735985], [68.54429626, 23.39792061], [68.54402924, 23.39791679], [68.54402924, 23.39847183], [68.54374695, 23.39846992], [68.54374695, 23.39903069], [68.54347229, 23.39902878], [68.54347229, 23.39958382], [68.5423584, 23.39957809], [68.5423584, 23.39986038], [68.54207611, 23.39986038], [68.54207611, 23.40014076], [68.54180908, 23.40014076], [68.54180908, 23.40041924], [68.54152679, 23.40041733], [68.54152679, 23.40069389], [68.54125214, 23.40068817], [68.54125214, 23.40125084], [68.54035187, 23.40125084], [68.53985596, 23.40125084], [68.53985596, 23.40068817], [68.5395813, 23.40069389], [68.5395813, 23.40013885], [68.53930664, 23.40014076], [68.53930664, 23.39982986], [68.53930664, 23.39958382], [68.53902435, 23.39958382], [68.53902435, 23.39947891], [68.53902435, 23.39875031], [68.53874969, 23.39875031], [68.53874969, 23.39846992], [68.53847504, 23.39847183], [68.53847504, 23.39791679], [68.53874969, 23.39792061], [68.53874969, 23.39680099], [68.53847504, 23.39680672], [68.53847504, 23.39652824], [68.53819275, 23.39653015], [68.53819275, 23.39624023], [68.5376358, 23.39624977], [68.5376358, 23.3959713], [68.53736115, 23.3959713], [68.53736115, 23.39569664], [68.53708649, 23.39569664], [68.53708649, 23.39541435], [68.53652954, 23.39542007], [68.53652954, 23.39513969], [68.53624725, 23.39513969], [68.53624725, 23.39486122], [68.5359726, 23.39486122], [68.5359726, 23.39458466], [68.5348587, 23.39458466], [68.5348587, 23.39430618], [68.53430939, 23.39431], [68.53430176, 23.39402962], [68.5340271, 23.39402962], [68.5340271, 23.39375114], [68.53347015, 23.39375114], [68.53347015, 23.39319992], [68.53291321, 23.39319992], [68.53291321, 23.39264107], [68.53263855, 23.39264107], [68.53263855, 23.39208031], [68.53291321, 23.39208221], [68.53291321, 23.39180565], [68.53320312, 23.39180946], [68.53320312, 23.3915329], [68.53347015, 23.3915329], [68.53347015, 23.39125061], [68.5340271, 23.39125061], [68.5340271, 23.39097023], [68.53430176, 23.39097023], [68.53430176, 23.39069366], [68.5340271, 23.39069366], [68.5340271, 23.39013863], [68.53375244, 23.39014244], [68.53375244, 23.38986015], [68.53347015, 23.38986015], [68.53347015, 23.38958168], [68.5331955, 23.38958359], [68.5331955, 23.38986015], [68.53291321, 23.38986015], [68.53291321, 23.39014244], [68.53263855, 23.39013863], [68.53263855, 23.39097023], [68.5293045, 23.39097023], [68.5293045, 23.39069366], [68.52819824, 23.39069176], [68.52819061, 23.39180946], [68.52791595, 23.39180946], [68.52791595, 23.39236069], [68.52819061, 23.39236069], [68.52819824, 23.39291954], [68.52902985, 23.39291954], [68.52902985, 23.39319992], [68.52874756, 23.39319229], [68.52874756, 23.39347458], [68.52902985, 23.39347076], [68.52902985, 23.39402962], [68.52929688, 23.39402962], [68.52929688, 23.39431], [68.52984619, 23.39431], [68.52984619, 23.39402962], [68.53125, 23.39402962], [68.53125, 23.39431], [68.53152466, 23.39430618], [68.53152466, 23.39458466], [68.53180695, 23.39458084], [68.53180695, 23.39486122], [68.5320816, 23.39486122], [68.5320816, 23.39458084], [68.53263855, 23.39458084], [68.53263855, 23.39486122], [68.53291321, 23.39486122], [68.53291321, 23.39513969], [68.53320312, 23.39513969], [68.53320312, 23.39542007], [68.53430176, 23.39541435], [68.53430176, 23.39569664], [68.5348587, 23.39569664], [68.5348587, 23.3959713], [68.53514099, 23.3959713], [68.53514099, 23.39624977], [68.53542328, 23.39624023], [68.53542328, 23.39653015], [68.53569794, 23.39652824], [68.53569794, 23.39680672], [68.5359726, 23.39680672], [68.53598022, 23.39723969], [68.53598022, 23.39764023], [68.53569794, 23.39763832], [68.53569794, 23.39847183], [68.53541565, 23.39847183], [68.53542328, 23.39986038], [68.53514099, 23.39986038], [68.53514099, 23.40069389], [68.53542328, 23.40068817], [68.53542328, 23.40152931], [68.53569794, 23.40152931], [68.53569794, 23.40125084], [68.53598022, 23.40125084], [68.5359726, 23.40069389], [68.53652954, 23.40069389], [68.53652954, 23.40041733], [68.53708649, 23.40041924], [68.53708649, 23.40014076], [68.53736115, 23.40014076], [68.53736115, 23.39986038], [68.5376358, 23.39986038], [68.5376358, 23.39957809], [68.53819275, 23.39957809], [68.53819275, 23.40014076], [68.53848267, 23.40014076], [68.53848267, 23.40041924], [68.53874969, 23.40041733], [68.53874969, 23.40097237], [68.53901672, 23.40097046], [68.53901672, 23.40125084], [68.53930664, 23.40125084], [68.53930664, 23.40208244], [68.5395813, 23.40208054], [68.5395813, 23.40292168], [68.53902435, 23.40291595], [68.53902435, 23.40319443], [68.53930664, 23.40319443], [68.53930664, 23.4034729], [68.53791809, 23.40346909], [68.53791809, 23.40374947], [68.5376358, 23.40374947], [68.5376358, 23.40403175], [68.53708649, 23.40402794], [68.53708649, 23.40486145], [68.53736115, 23.40486145], [68.53736115, 23.40458107], [68.54165649, 23.40458107], [68.54208374, 23.40458107], [68.54208374, 23.40430641], [68.54264069, 23.40431023], [68.54264069, 23.40403175], [68.54292297, 23.40403175], [68.54292297, 23.40374947], [68.54347229, 23.40374947], [68.54347229, 23.40346909], [68.54374695, 23.4034729], [68.54374695, 23.40319443], [68.54430389, 23.40319443], [68.54430389, 23.40291595], [68.54485321, 23.40292168], [68.54485321, 23.40263939], [68.54541779, 23.40263939], [68.54541779, 23.40236092], [68.54569244, 23.40236092], [68.54569244, 23.40208054], [68.54624939, 23.40208244], [68.54624939, 23.40180588], [68.54680634, 23.4018116], [68.54680634, 23.40152931], [68.54736328, 23.40152931], [68.54736328, 23.40125084], [68.54792023, 23.40125084], [68.54792023, 23.40097046], [68.54894257, 23.40097237], [68.54902649, 23.40097237], [68.54902649, 23.40152931], [68.54930878, 23.40152931], [68.54930878, 23.4018116], [68.54958344, 23.40180588], [68.54958344, 23.40208244], [68.55041504, 23.40208244], [68.55041504, 23.40236092], [68.55069733, 23.40236092], [68.55069733, 23.40208054], [68.55097198, 23.40208244], [68.55097198, 23.40180588], [68.55124664, 23.4018116], [68.55124664, 23.40068817], [68.55097198, 23.40069389], [68.55097198, 23.40041733], [68.55042267, 23.40041924], [68.55042267, 23.40014076], [68.54985809, 23.40014076], [68.54985809, 23.39986038], [68.55014038, 23.39986038], [68.55014038, 23.39957809], [68.55041504, 23.39958382], [68.55041504, 23.39930534], [68.55069733, 23.39930534], [68.55069733, 23.39902878], [68.55180359, 23.39902878], [68.55180359, 23.39930534], [68.55236053, 23.39930534], [68.55236053, 23.39958382], [68.55291748, 23.39958382], [68.55291748, 23.39930534], [68.55374908, 23.39930534], [68.55374908, 23.39902878], [68.55401611, 23.39903069], [68.55401611, 23.39820099], [68.55430603, 23.39820099], [68.55430603, 23.39764023], [68.55458069, 23.39764023], [68.55458069, 23.39707947], [68.55486298, 23.39708328], [68.55486298, 23.3959713], [68.55458069, 23.3959713], [68.55458069, 23.39486122], [68.55430603, 23.39486122], [68.55430603, 23.39431], [68.55401611, 23.39431], [68.55401611, 23.39402962], [68.55374908, 23.39402962], [68.55374908, 23.39375114], [68.5534668, 23.39375114], [68.5534668, 23.39319992], [68.55319214, 23.39319992], [68.55319214, 23.39266968], [68.55319214, 23.39152718], [68.5534668, 23.3915329], [68.5534668, 23.39097023], [68.55374908, 23.39097023], [68.55374908, 23.3904171], [68.55401611, 23.39042282], [68.55401611, 23.38986015], [68.55430603, 23.38986015], [68.55430603, 23.38930511], [68.55452728, 23.38930702], [68.55486298, 23.38931274], [68.55486298, 23.38902855], [68.55568695, 23.38902855], [68.55568695, 23.38874817], [68.55596924, 23.38874817], [68.55596924, 23.38820076], [68.55625153, 23.38820076], [68.55625153, 23.38763809], [68.55652618, 23.38763809], [68.55652618, 23.3870697], [68.55680847, 23.38708305], [68.55680847, 23.38652992], [68.55708313, 23.38652992], [68.55708313, 23.38624954], [68.55735779, 23.38624954], [68.55735779, 23.38569069], [68.55764008, 23.3856945], [68.55764008, 23.38513947], [68.5579071, 23.38513947], [68.5579071, 23.38486099], [68.55819702, 23.38486099], [68.55819702, 23.38430023], [68.55847168, 23.38430786], [68.55847168, 23.38375092], [68.55874634, 23.38375092], [68.55874634, 23.38347054], [68.55902863, 23.38347244], [68.55902863, 23.3829174], [68.55930328, 23.38292122], [68.55930328, 23.38181114], [68.55902863, 23.38181114], [68.55902863, 23.38153076], [68.55819702, 23.38153076], [68.55819702, 23.38125992], [68.55735779, 23.38125992], [68.55735779, 23.38153076], [68.55708313, 23.38152695], [68.55708313, 23.3820858], [68.55680847, 23.38208008], [68.55680847, 23.38236046], [68.55652618, 23.38236046], [68.55652618, 23.38264084], [68.55541992, 23.38264084], [68.55541992, 23.38292122], [68.55486298, 23.3829174], [68.55486298, 23.38319588], [68.55403137, 23.38319588], [68.55403137, 23.3829174], [68.55430603, 23.38292122], [68.55430603, 23.38236046], [68.55458069, 23.38236046], [68.55458069, 23.38181114], [68.55486298, 23.38181114], [68.55486298, 23.38153076], [68.55513763, 23.38153076], [68.55513763, 23.38097], [68.55541992, 23.38097382], [68.55541992, 23.38069534], [68.55568695, 23.38070107], [68.55568695, 23.3801403], [68.55596924, 23.3801403], [68.55596924, 23.37957954], [68.55625153, 23.37958145], [68.55625153, 23.37902832], [68.55652618, 23.37903023], [68.55652618, 23.37874985], [68.5579071, 23.37874985], [68.5579071, 23.37846947], [68.55902863, 23.37847137], [68.55902863, 23.37819481], [68.56014252, 23.37820053], [68.56014252, 23.37792015], [68.56181335, 23.37792015], [68.56181335, 23.37763977], [68.56319427, 23.37763977], [68.56318665, 23.37735939], [68.56375122, 23.3773613], [68.56375122, 23.37708282], [68.56458282, 23.37708282], [68.56458282, 23.37680626], [68.56513977, 23.37681007], [68.56513977, 23.3765316], [68.56680298, 23.3765316], [68.56680298, 23.37624931], [68.5670929, 23.37624931], [68.5670929, 23.37597084], [68.56735992, 23.37597275], [68.56735992, 23.37513924], [68.56708527, 23.37513924], [68.56708527, 23.37486076], [68.56680298, 23.37486076], [68.56680298, 23.37458038], [68.56625366, 23.3745842], [68.56625366, 23.37430573], [68.56595612, 23.37431145], [68.56595612, 23.37402916], [68.56569672, 23.37402916], [68.56569672, 23.37375069], [68.5654068, 23.37375069], [68.5654068, 23.37318993], [68.56513977, 23.37319374], [68.56513977, 23.3726387], [68.56402588, 23.37264061], [68.56402588, 23.37236023], [68.56375122, 23.37236023], [68.56375122, 23.37181091], [68.56346893, 23.37181091], [68.56346893, 23.37153053], [68.56318665, 23.37153053], [68.56318665, 23.37125015], [68.56291962, 23.37125015], [68.56291962, 23.37096977], [68.56263733, 23.37097168], [68.56263733, 23.37069511], [68.56236267, 23.37070084], [68.56236267, 23.37042046], [68.56208038, 23.37042046], [68.56208038, 23.3698597], [68.56180573, 23.3698616], [68.56180573, 23.36958313], [68.56153107, 23.36958313], [68.56153107, 23.36902809], [68.56124878, 23.36903], [68.56124878, 23.36847115], [68.56097412, 23.36847305], [68.56097412, 23.36819267], [68.56069183, 23.36819267], [68.56069183, 23.36763954], [68.56041718, 23.36763954], [68.56041718, 23.36736107], [68.56014252, 23.36736107], [68.56014252, 23.36680984], [68.55986023, 23.36680984], [68.55986023, 23.36626053], [68.5595932, 23.36626053], [68.5595932, 23.36569023], [68.55930328, 23.36569214], [68.55930328, 23.36486053], [68.55902863, 23.36486053], [68.55902863, 23.36347008], [68.55874634, 23.36347008], [68.55874634, 23.36263847], [68.55847168, 23.36264038], [68.55847168, 23.36235809], [68.55791473, 23.36236191], [68.55791473, 23.36208344], [68.55764008, 23.36208344], [68.55764008, 23.36180496], [68.55735779, 23.36181068], [68.55735779, 23.3615284], [68.55680847, 23.3615284], [68.55680847, 23.36124992], [68.55652618, 23.36124992], [68.55652618, 23.36096954], [68.55625153, 23.36097145], [68.55625153, 23.36069489], [68.55569458, 23.36069489], [68.55569458, 23.36041641], [68.55430603, 23.36041832], [68.55430603, 23.36013031], [68.55319214, 23.36013031], [68.55319214, 23.36041832], [68.55291748, 23.36041641], [68.55291748, 23.36069489], [68.55264282, 23.36069107], [68.55264282, 23.3615284], [68.55291748, 23.3615284], [68.55291748, 23.36181068], [68.55347443, 23.36180496], [68.55347443, 23.36208344], [68.55374908, 23.36208344], [68.55374908, 23.36236191], [68.55319214, 23.36236191], [68.55319214, 23.36319351], [68.55291748, 23.3631916], [68.55291748, 23.36652946], [68.55208588, 23.36652946], [68.55208588, 23.36458015], [68.55179596, 23.36458015], [68.55179596, 23.36486053], [68.55152893, 23.36486053], [68.55152893, 23.36514282], [68.55124664, 23.36513901], [68.55124664, 23.36569214], [68.55014038, 23.36569214], [68.55014038, 23.36597443], [68.54957581, 23.36597061], [68.54957581, 23.36626053], [68.54985809, 23.36624908], [68.54985809, 23.3670845], [68.55069733, 23.36708069], [68.55069733, 23.37014008], [68.55042267, 23.37014008], [68.55042267, 23.37070084], [68.55014038, 23.37070084], [68.55014038, 23.37125015], [68.55042267, 23.37125015], [68.55042267, 23.37153053], [68.55069733, 23.37153053], [68.55069733, 23.37125015], [68.55152893, 23.37125015], [68.55152893, 23.37096977], [68.55180359, 23.37097168], [68.55180359, 23.37069511], [68.55236053, 23.37070084], [68.55236053, 23.37042046], [68.55264282, 23.37042046], [68.55264282, 23.37014008], [68.55319214, 23.37014008], [68.55319214, 23.3698597], [68.55347443, 23.3698616], [68.55347443, 23.36958313], [68.55403137, 23.36958313], [68.55403137, 23.36930656], [68.55430603, 23.36930656], [68.55430603, 23.36902809], [68.55513763, 23.36902809], [68.55513763, 23.36930656], [68.55541992, 23.36930656], [68.55541992, 23.36958313], [68.55596924, 23.36958313], [68.55596924, 23.3698616], [68.55652618, 23.3698597], [68.55652618, 23.37070084], [68.55680847, 23.37070084], [68.55680847, 23.37181091]]], [[[68.52347565, 23.40458107], [68.52347565, 23.40402794], [68.52458191, 23.40403175], [68.52458191, 23.40346909], [68.52430725, 23.4034729], [68.52430725, 23.40319443], [68.52402496, 23.40319443], [68.52402496, 23.40236092], [68.52375031, 23.40236092], [68.52375031, 23.40097046], [68.52402496, 23.40097237], [68.52402496, 23.40069389], [68.52541351, 23.40069389], [68.52541351, 23.40013885], [68.5256958, 23.40014076], [68.5256958, 23.39929962], [68.52513885, 23.39930534], [68.52513885, 23.39958382], [68.52430725, 23.39958382], [68.52430725, 23.39902878], [68.52458191, 23.39903069], [68.52458191, 23.39875031], [68.52597046, 23.39875031], [68.52597046, 23.39903069], [68.52735901, 23.39903069], [68.52735901, 23.39792061], [68.5265274, 23.39792061], [68.5265274, 23.39764023], [68.52625275, 23.39764023], [68.52625275, 23.39735985], [68.5265274, 23.39736176], [68.5265274, 23.39708328], [68.52680206, 23.39708328], [68.52680206, 23.39680672], [68.52708435, 23.39680672], [68.52708435, 23.39624977], [68.5265274, 23.39624023], [68.5265274, 23.39653015], [68.52625275, 23.39652824], [68.52625275, 23.39680672], [68.52597046, 23.39680672], [68.52597046, 23.39708328], [68.52513885, 23.39708328], [68.52513885, 23.39612007], [68.52513885, 23.39541435], [68.52540588, 23.39542007], [68.52540588, 23.39486122], [68.5256958, 23.39486122], [68.5256958, 23.39458084], [68.52597046, 23.39458466], [68.52597046, 23.39402771], [68.5256958, 23.39402962], [68.5256958, 23.39319992], [68.52597046, 23.39319992], [68.52597046, 23.39264107], [68.52625275, 23.39264107], [68.52625275, 23.39236069], [68.5265274, 23.39236069], [68.5265274, 23.39208031], [68.52708435, 23.39208221], [68.52708435, 23.39069366], [68.52735901, 23.39069366], [68.52735901, 23.38986015], [68.52708435, 23.38986015], [68.52707672, 23.38820076], [68.52735901, 23.38820076], [68.52735901, 23.38791847], [68.5276413, 23.38791847], [68.5276413, 23.38763809], [68.52791595, 23.38763809], [68.52791595, 23.3868084], [68.52735901, 23.38680077], [68.52735901, 23.38624954], [68.52680969, 23.38624954], [68.52680969, 23.38652992], [68.52625275, 23.38652992], [68.52625275, 23.38680077], [68.52597046, 23.38680649], [68.52597046, 23.38736153], [68.52540588, 23.38735962], [68.52540588, 23.38763809], [68.52513885, 23.38763809], [68.52513885, 23.38791847], [68.52458191, 23.38791847], [68.52458191, 23.38820076], [68.52430725, 23.38819504], [68.52430725, 23.3884716], [68.52402496, 23.3884716], [68.52404022, 23.38874817], [68.52375031, 23.38874817], [68.52375031, 23.38931274], [68.52347565, 23.38930511], [68.52347565, 23.38958359], [68.52319336, 23.38958168], [68.52319336, 23.39014244], [68.5229187, 23.39014244], [68.5229187, 23.39042282], [68.52263641, 23.3904171], [68.52263641, 23.39097023], [68.52236176, 23.39097023], [68.52236176, 23.39125061], [68.5220871, 23.39125061], [68.5220871, 23.39180946], [68.52180481, 23.39180565], [68.52180481, 23.39208221], [68.52153015, 23.39208031], [68.52153015, 23.39264107], [68.52124786, 23.39264107], [68.52124786, 23.39291954], [68.52097321, 23.39291573], [68.52097321, 23.39347458], [68.52068329, 23.39347076], [68.52068329, 23.39402962], [68.52041626, 23.39402962], [68.52041626, 23.39542007], [68.5201416, 23.39541435], [68.5201416, 23.39882088], [68.5201416, 23.39930534], [68.52041626, 23.39929962], [68.52041626, 23.40041924], [68.52069092, 23.40041733], [68.52069092, 23.40097237], [68.52097321, 23.40097046], [68.52097321, 23.40125084], [68.52124786, 23.40125084], [68.52124786, 23.40152931], [68.52153015, 23.40152931], [68.52153015, 23.4018116], [68.5220871, 23.40180588], [68.5220871, 23.40208244], [68.52236176, 23.40208054], [68.52236176, 23.40236092], [68.5229187, 23.40236092], [68.5229187, 23.40319443], [68.52263641, 23.40319061], [68.52263641, 23.40374947], [68.5229187, 23.40374947], [68.5229187, 23.40458107], [68.52319336, 23.40458107], [68.52319336, 23.40514183], [68.52375031, 23.40514183], [68.52375031, 23.40458107], [68.52347565, 23.40458107]]], [[[68.55401611, 23.40403175], [68.55401611, 23.40374947], [68.55652618, 23.40374947], [68.55652618, 23.40319061], [68.55680847, 23.40319443], [68.55680847, 23.40263939], [68.55430603, 23.40263939], [68.55430603, 23.40236092], [68.55401611, 23.40236092], [68.55401611, 23.40208054], [68.55291748, 23.40208054], [68.55291748, 23.40236092], [68.55263519, 23.40236092], [68.55263519, 23.4034729], [68.55291748, 23.40346909], [68.55291748, 23.40403175], [68.55401611, 23.40403175]]], [[[68.55764008, 23.40875053], [68.55764008, 23.40818024], [68.55735779, 23.4081955], [68.55735779, 23.40763855], [68.55708313, 23.40764046], [68.55708313, 23.4070797], [68.55680847, 23.40708542], [68.55680847, 23.40680313], [68.55652618, 23.40681076], [68.55652618, 23.40653038], [68.55625153, 23.40653038], [68.55625153, 23.40625], [68.55596924, 23.40625], [68.55596924, 23.40570068], [68.55568695, 23.40570068], [68.55568695, 23.40542984], [68.55541992, 23.40542984], [68.55541992, 23.40514183], [68.55401611, 23.40514183], [68.55401611, 23.40485954], [68.55374908, 23.40486145], [68.55374908, 23.40458107], [68.55319214, 23.40458107], [68.55319214, 23.40430641], [68.55124664, 23.40430641], [68.55124664, 23.40486145], [68.55152893, 23.40485954], [68.55152893, 23.40514183], [68.55236053, 23.40514183], [68.55236053, 23.40542984], [68.55291748, 23.40542984], [68.55291748, 23.40570068], [68.55319214, 23.40569305], [68.55319214, 23.40597153], [68.5534668, 23.40596962], [68.5534668, 23.40625], [68.55374908, 23.40625], [68.55374908, 23.40596962], [68.55458069, 23.40596962], [68.55458069, 23.40653038], [68.55513763, 23.40653038], [68.55513763, 23.40681076], [68.55541992, 23.40680313], [68.55541992, 23.40708542], [68.55596924, 23.40708542], [68.55596924, 23.40736389], [68.55625153, 23.40736008], [68.55625153, 23.40764046], [68.55652618, 23.40763855], [68.55652618, 23.4081955], [68.55680847, 23.4081955], [68.55680847, 23.40847206], [68.55708313, 23.40847015], [68.55708313, 23.40875053], [68.55735779, 23.40875053], [68.55735779, 23.40930939], [68.5579071, 23.40930939], [68.5579071, 23.40875053], [68.55764008, 23.40875053]]], [[[68.54957581, 23.41374969], [68.54957581, 23.41319084], [68.54930878, 23.41319466], [68.54930878, 23.41291618], [68.54902649, 23.41291809], [68.54902649, 23.41236115], [68.54875183, 23.41236115], [68.54875183, 23.41208076], [68.54846954, 23.41208267], [68.54846954, 23.41152763], [68.54818726, 23.41152954], [68.54818726, 23.41097069], [68.54792023, 23.4109726], [68.54792023, 23.41041756], [68.54780579, 23.41041756], [68.54763794, 23.41041946], [68.54763794, 23.41014099], [68.54736328, 23.41014099], [68.54736328, 23.40986061], [68.54680634, 23.40986061], [68.54680634, 23.40958595], [68.54652405, 23.40958595], [68.54652405, 23.40930557], [68.54624939, 23.40930939], [68.54624939, 23.40903091], [68.5459671, 23.40903091], [68.5459671, 23.40875053], [68.54541779, 23.40875053], [68.54541779, 23.40847015], [68.5451355, 23.40847206], [68.5451355, 23.4081955], [68.54486084, 23.4081955], [68.54486084, 23.40791702], [68.54458618, 23.40792084], [68.54458618, 23.40764046], [68.54429626, 23.40764046], [68.54429626, 23.40736008], [68.54402924, 23.40736389], [68.54402924, 23.40708542], [68.54374695, 23.40708542], [68.54374695, 23.40680313], [68.54347229, 23.40681076], [68.54347229, 23.40653038], [68.54319763, 23.40653038], [68.54319763, 23.40625], [68.54291534, 23.40625], [68.54291534, 23.40597153], [68.54264069, 23.40597153], [68.54264069, 23.40569305], [68.5423584, 23.40570068], [68.5423584, 23.40542984], [68.54199219, 23.40542984], [68.54152679, 23.40542984], [68.54152679, 23.40625], [68.54180908, 23.40625], [68.54180908, 23.40653038], [68.54207611, 23.40653038], [68.54207611, 23.40681076], [68.5423584, 23.40680313], [68.5423584, 23.40708542], [68.54264069, 23.40708542], [68.54264069, 23.40736389], [68.54292297, 23.40736008], [68.54292297, 23.40764046], [68.54319763, 23.40764046], [68.54319763, 23.40792084], [68.54347229, 23.40791702], [68.54347229, 23.4081955], [68.54374695, 23.4081955], [68.54374695, 23.40847206], [68.54402924, 23.40847015], [68.54402924, 23.40875053], [68.54429626, 23.40875053], [68.54429626, 23.40903091], [68.54458618, 23.40903091], [68.54458618, 23.40930939], [68.54486084, 23.40930557], [68.54486084, 23.40958595], [68.5451355, 23.40958595], [68.5451355, 23.40986061], [68.54569244, 23.40986061], [68.54569244, 23.41014099], [68.5459671, 23.41014099], [68.5459671, 23.41041946], [68.54652405, 23.41041756], [68.54652405, 23.41069412], [68.54680634, 23.41069412], [68.54680634, 23.4109726], [68.54708099, 23.41097069], [68.54708099, 23.41152954], [68.54736328, 23.41152763], [68.54736328, 23.41208267], [68.54763794, 23.41208076], [68.54763794, 23.41263962], [68.54792023, 23.41263962], [68.54792023, 23.41291809], [68.54819489, 23.41291618], [68.54819489, 23.41319466], [68.54875183, 23.41319466], [68.54875183, 23.41347313], [68.54902649, 23.41347122], [68.54902649, 23.41374969], [68.54930878, 23.41374969], [68.54930878, 23.41430473], [68.54958344, 23.41430473], [68.54958344, 23.41486168], [68.54985809, 23.41486168], [68.54985809, 23.41374969], [68.54957581, 23.41374969]]], [[[68.50125122, 23.45347977], [68.50125122, 23.45292091], [68.50152588, 23.45292091], [68.50152588, 23.45236015], [68.50180817, 23.45236206], [68.50180817, 23.45125008], [68.50208282, 23.45125008], [68.50208282, 23.45014], [68.50235748, 23.45014], [68.50235748, 23.44958115], [68.50152588, 23.44958305], [68.50152588, 23.44902802], [68.50125122, 23.44902992], [68.50125122, 23.44847107], [68.50096893, 23.44847488], [68.50096893, 23.44763947], [68.50068665, 23.44763947], [68.50068665, 23.44652939], [68.50041962, 23.44652939], [68.50041962, 23.44569016], [68.50013733, 23.44569206], [68.50013733, 23.44513893], [68.4998703, 23.44514275], [68.4998703, 23.44458008], [68.49903107, 23.44458389], [68.49903107, 23.44402695], [68.49819183, 23.44403267], [68.49819183, 23.44431114], [68.4970932, 23.44431114], [68.4970932, 23.44403267], [68.49680328, 23.44402695], [68.49680328, 23.44569206], [68.4970932, 23.44569016], [68.4970932, 23.44652939], [68.49569702, 23.44652939], [68.49569702, 23.44763947], [68.49597168, 23.44763947], [68.49597168, 23.44847488], [68.49624634, 23.44847107], [68.49624634, 23.44874954], [68.49652863, 23.44874954], [68.49652863, 23.44902992], [68.49680328, 23.44902802], [68.49680328, 23.44958305], [68.4970932, 23.44958115], [68.4970932, 23.45014], [68.49764252, 23.45013809], [68.49764252, 23.45041656], [68.49819183, 23.45041084], [68.49819183, 23.45070076], [68.49874878, 23.45069695], [68.49874878, 23.4509716], [68.49930573, 23.4509716], [68.49930573, 23.45125008], [68.4998703, 23.45125008], [68.4998703, 23.45153046], [68.50013733, 23.45153046], [68.50013733, 23.45181084], [68.50069427, 23.45180511], [68.50069427, 23.45208359], [68.50096893, 23.45207977], [68.50096893, 23.45264053], [68.50068665, 23.45264053], [68.50068665, 23.45292091], [68.50096893, 23.45292091], [68.50096893, 23.45347977], [68.50125122, 23.45347977]]], [[[68.46652985, 23.4979229], [68.46652985, 23.49764252], [68.46708679, 23.49764252], [68.46708679, 23.49736023], [68.4679184, 23.49736023], [68.4679184, 23.49708176], [68.46847534, 23.49708366], [68.46847534, 23.49680519], [68.46930695, 23.49681282], [68.46930695, 23.49653244], [68.46956635, 23.49653244], [68.46956635, 23.49596977], [68.47013855, 23.49597168], [68.47013855, 23.49319458], [68.4706955, 23.49319458], [68.4706955, 23.49347305], [68.47097015, 23.49347115], [68.47097015, 23.49402809], [68.47125244, 23.49402809], [68.47125244, 23.49374962], [68.4715271, 23.49374962], [68.4715271, 23.49319077], [68.47180176, 23.49319458], [68.47180939, 23.49291611], [68.47207642, 23.49291992], [68.47207642, 23.49236107], [68.47180939, 23.49236107], [68.47180176, 23.49208069], [68.4715271, 23.4920826], [68.4715271, 23.49180794], [68.47264099, 23.49180984], [68.47264099, 23.49097061], [68.47291565, 23.49097252], [68.47291565, 23.48708534], [68.47264099, 23.48708534], [68.47264099, 23.48569489], [68.4723587, 23.48569489], [68.4723587, 23.48486137], [68.47180176, 23.48485947], [68.47180176, 23.48542023], [68.4715271, 23.48541641], [68.4715271, 23.48597145], [68.4706955, 23.48597145], [68.4706955, 23.48541641], [68.47041321, 23.48542023], [68.47041321, 23.48485947], [68.47013855, 23.48486137], [68.47013855, 23.48430634], [68.46985626, 23.48431015], [68.46985626, 23.48374939], [68.47013855, 23.48374939], [68.47013855, 23.48319054], [68.47041321, 23.48319435], [68.47041321, 23.48236084], [68.47070313, 23.48236084], [68.4706955, 23.48152733], [68.47097015, 23.48152924], [68.47097015, 23.48097038], [68.47125244, 23.48097229], [68.47125244, 23.48041725], [68.47097015, 23.48041916], [68.47097015, 23.48014069], [68.47070313, 23.48014069], [68.47070313, 23.47986031], [68.47041321, 23.47986031], [68.47041321, 23.47957993], [68.47013855, 23.47958374], [68.47013855, 23.47930527], [68.46956635, 23.47930908], [68.46956635, 23.47903061], [68.46848297, 23.47903061], [68.46848297, 23.47930908], [68.46819305, 23.47930527], [68.46819305, 23.47958374], [68.4679184, 23.47957993], [68.4679184, 23.47986031], [68.46736145, 23.47986031], [68.46736145, 23.48014069], [68.46679688, 23.48014069], [68.46679688, 23.48041916], [68.46376038, 23.48041916], [68.46376038, 23.47986031], [68.46347046, 23.47986031], [68.46347046, 23.48014069], [68.46235657, 23.48014069], [68.46235657, 23.47957993], [68.4595871, 23.47958374], [68.4595871, 23.47984123], [68.45929718, 23.47986031], [68.45929718, 23.48152924], [68.4595871, 23.48152924], [68.4595871, 23.48181152], [68.45986176, 23.4818058], [68.45986176, 23.48208237], [68.45929718, 23.48208046], [68.45929718, 23.48236084], [68.45903015, 23.48236084], [68.45903015, 23.48319435], [68.45929718, 23.48319054], [68.45929718, 23.48431015], [68.45903015, 23.48430634], [68.45903015, 23.4845829], [68.45874786, 23.4845829], [68.45874786, 23.48736382], [68.45903015, 23.48736], [68.45903015, 23.48792076], [68.45986176, 23.48792076], [68.45986176, 23.48764038], [68.4604187, 23.48763847], [68.4604187, 23.48847389], [68.46070099, 23.48847008], [68.46070099, 23.48931122], [68.46097565, 23.48930359], [68.46097565, 23.48986053], [68.46125031, 23.48986053], [68.46125031, 23.49041939], [68.46208191, 23.49041939], [68.46208191, 23.49014091], [68.46263885, 23.49014091], [68.46263885, 23.48986053], [68.4631958, 23.48986053], [68.4631958, 23.48958969], [68.46347046, 23.48958969], [68.46347046, 23.48931122], [68.46376038, 23.48931122], [68.46376038, 23.48903084], [68.4640274, 23.48903084], [68.4640274, 23.48875046], [68.46457672, 23.48875046], [68.46457672, 23.48903084], [68.46485901, 23.48903084], [68.46485901, 23.48986053], [68.46457672, 23.48986053], [68.46457672, 23.49014091], [68.46430206, 23.49014091], [68.46430206, 23.49041939], [68.46485901, 23.49041748], [68.46485901, 23.49069595], [68.46541595, 23.49069595], [68.46541595, 23.49097252], [68.46569061, 23.49097061], [68.46569061, 23.49125099], [68.46541595, 23.49125099], [68.46541595, 23.49152946], [68.4651413, 23.49152946], [68.4651413, 23.49180984], [68.46485901, 23.49180794], [68.46485901, 23.4920826], [68.46457672, 23.49208069], [68.46457672, 23.49236107], [68.46430206, 23.49236107], [68.46430206, 23.49264908], [68.4640274, 23.49263954], [68.4640274, 23.49347305], [68.46376038, 23.49347115], [68.46376038, 23.49653244], [68.46430206, 23.49653244], [68.46430206, 23.49625015], [68.46485901, 23.49625015], [68.46485901, 23.49653244], [68.4651413, 23.49653244], [68.4651413, 23.49681282], [68.46541595, 23.49680519], [68.46541595, 23.49708366], [68.46569061, 23.49708176], [68.46569824, 23.49736023], [68.4659729, 23.49736023], [68.4659729, 23.49764252], [68.46569824, 23.49764252], [68.46569824, 23.4979229], [68.46627808, 23.49791908], [68.46652985, 23.4979229]]], [[[68.49903107, 23.47597313], [68.49903107, 23.47541428], [68.49931335, 23.47542], [68.49931335, 23.47402954], [68.49958038, 23.47402954], [68.49958038, 23.47319031], [68.49903107, 23.47319221], [68.49903107, 23.47291756], [68.49819183, 23.47291946], [68.49819183, 23.4726429], [68.49846649, 23.4726429], [68.49846649, 23.46931267], [68.49874878, 23.46931267], [68.49874878, 23.46874809], [68.49903107, 23.46874809], [68.49903107, 23.4679184], [68.49931335, 23.4679184], [68.49931335, 23.46735954], [68.49958038, 23.46736145], [68.49958038, 23.46680641], [68.4998703, 23.46680832], [68.4998703, 23.46652985], [68.50041962, 23.46652985], [68.50041962, 23.46624947], [68.50125122, 23.46624947], [68.50125122, 23.46541977], [68.4998703, 23.46541977], [68.4998703, 23.46486092], [68.49958038, 23.46486092], [68.49958038, 23.46375084], [68.50013733, 23.46375084], [68.50013733, 23.46347046], [68.50125122, 23.46347237], [68.50125122, 23.46291733], [68.50096893, 23.46292114], [68.50096893, 23.46235085], [68.50125122, 23.46236038], [68.50125122, 23.46180344], [68.50152588, 23.46181107], [68.50152588, 23.46125031], [68.50180817, 23.46125031], [68.50180817, 23.46042061], [68.50208282, 23.46042061], [68.50208282, 23.45819283], [68.50235748, 23.45819473], [68.50235748, 23.45763969], [68.50208282, 23.45763969], [68.50208282, 23.45708084], [68.50180817, 23.45708275], [68.50180817, 23.45680618], [68.50152588, 23.4568119], [68.50152588, 23.45624924], [68.50125122, 23.45624924], [68.50125122, 23.45597076], [68.50096893, 23.45597267], [68.50096893, 23.4556942], [68.50069427, 23.4556942], [68.50069427, 23.45541573], [68.50013733, 23.45542145], [68.50013733, 23.45513916], [68.4998703, 23.45513916], [68.4998703, 23.45654106], [68.49958038, 23.45654106], [68.49958038, 23.45792007], [68.49903107, 23.45791626], [68.49903107, 23.45986366], [68.4998703, 23.45985985], [68.4998703, 23.46042061], [68.49931335, 23.46042061], [68.49931335, 23.46070099], [68.49903107, 23.46070099], [68.49903107, 23.46181107], [68.49930573, 23.46180344], [68.49930573, 23.46236038], [68.49846649, 23.46235085], [68.49846649, 23.46292114], [68.49819183, 23.46292114], [68.49819183, 23.46486092], [68.49846649, 23.46486092], [68.49846649, 23.46513939], [68.49874878, 23.46513939], [68.49874878, 23.46541977], [68.49846649, 23.46541977], [68.49846649, 23.46652985], [68.49819183, 23.46652985], [68.49819183, 23.46763992], [68.49791718, 23.46763992], [68.49791718, 23.46874809], [68.49764252, 23.46874809], [68.49764252, 23.46986008], [68.49736023, 23.46986008], [68.49736023, 23.47069359], [68.49708557, 23.47069359], [68.49708557, 23.47097015], [68.49680328, 23.47097015], [68.49680328, 23.47125053], [68.49652863, 23.47125053], [68.49652863, 23.4715271], [68.49624634, 23.4715271], [68.49624634, 23.47208214], [68.49597168, 23.47208023], [68.49597168, 23.47291946], [68.49569702, 23.47291756], [68.49569702, 23.4734745], [68.4954071, 23.47347069], [68.4954071, 23.47402954], [68.49514008, 23.47402954], [68.49514008, 23.47542], [68.49569702, 23.47541428], [68.49569702, 23.47569656], [68.49597168, 23.47569656], [68.49597168, 23.47597313], [68.49903107, 23.47597313]]], [[[68.49846649, 23.48903084], [68.49846649, 23.48847008], [68.49819183, 23.48847389], [68.49819183, 23.48791695], [68.49791718, 23.48792076], [68.49791718, 23.48707962], [68.49764252, 23.48708534], [68.49764252, 23.48624992], [68.49736023, 23.48624992], [68.49736023, 23.48569107], [68.49708557, 23.48569489], [68.49708557, 23.48319435], [68.49736023, 23.48319435], [68.49736023, 23.48152733], [68.49764252, 23.48152924], [68.49764252, 23.47986031], [68.49736023, 23.47986031], [68.49736023, 23.47930908], [68.4970932, 23.47930908], [68.4970932, 23.47875023], [68.49680328, 23.47875023], [68.49680328, 23.47846985], [68.49652863, 23.47847176], [68.49652863, 23.47791672], [68.49624634, 23.47792053], [68.49624634, 23.47764969], [68.49597168, 23.47764969], [68.49597168, 23.47735977], [68.49541473, 23.47736168], [68.49541473, 23.47708321], [68.49514008, 23.47708321], [68.49514008, 23.47680664], [68.49458313, 23.47680664], [68.49458313, 23.47652817], [68.49402618, 23.47653008], [68.49402618, 23.47624969], [68.49346924, 23.47624969], [68.49346924, 23.47597122], [68.49124908, 23.47597313], [68.49124908, 23.47569656], [68.49069214, 23.47569656], [68.49069214, 23.47541428], [68.49041748, 23.47542], [68.49041748, 23.47513962], [68.48986053, 23.47513962], [68.48986053, 23.47486115], [68.48958588, 23.47486115], [68.48958588, 23.47458076], [68.48930359, 23.47458458], [68.48930359, 23.4743042], [68.48874664, 23.47430992], [68.48874664, 23.47402954], [68.48847198, 23.47402954], [68.48847198, 23.47375107], [68.48819733, 23.47375107], [68.48819733, 23.47347069], [68.48707581, 23.47347069], [68.48707581, 23.47430992], [68.48680878, 23.4743042], [68.48680878, 23.47458458], [68.48652649, 23.47458076], [68.48652649, 23.47513962], [68.48625183, 23.47513962], [68.48625183, 23.47542], [68.48596954, 23.47541428], [68.48596954, 23.47569656], [68.48569489, 23.47569656], [68.48569489, 23.47597313], [68.48542023, 23.47597122], [68.48542023, 23.47624969], [68.48513794, 23.47624969], [68.48513794, 23.47653008], [68.48458099, 23.47652817], [68.48458099, 23.47680664], [68.48402405, 23.47680664], [68.48402405, 23.47708321], [68.48374939, 23.47708321], [68.48374939, 23.47736168], [68.48319244, 23.47735977], [68.48319244, 23.47764969], [68.48291779, 23.47764969], [68.48291779, 23.47792053], [68.48208618, 23.47792053], [68.48208618, 23.47820091], [68.48236084, 23.47820091], [68.48236084, 23.47875023], [68.48264313, 23.47875023], [68.48264313, 23.47930908], [68.48291779, 23.47930908], [68.48291779, 23.47986031], [68.48319244, 23.47986031], [68.48319244, 23.48014069], [68.4834671, 23.48014069], [68.4834671, 23.48041916], [68.48374939, 23.48041725], [68.48374939, 23.48069382], [68.48401642, 23.4806881], [68.48401642, 23.48152924], [68.48430634, 23.48152924], [68.48430634, 23.48181152], [68.48458099, 23.4818058], [68.48458099, 23.48208427], [68.48486328, 23.48208046], [68.48486328, 23.48236084], [68.48513794, 23.48236084], [68.48513794, 23.48263931], [68.48542023, 23.48263931], [68.48542023, 23.48319435], [68.48569489, 23.48319435], [68.48569489, 23.48347282], [68.48596954, 23.48345757], [68.48596954, 23.48403168], [68.48625183, 23.48402786], [68.48625183, 23.48431015], [68.48625183, 23.4845829], [68.48652649, 23.4845829], [68.48652649, 23.48486137], [68.48680878, 23.48485947], [68.48680878, 23.48542023], [68.48708344, 23.48541641], [68.48708344, 23.48569489], [68.48791504, 23.48569489], [68.48791504, 23.48597145], [68.48847198, 23.48596954], [68.48847198, 23.48624992], [68.48986053, 23.48624992], [68.48986053, 23.4865284], [68.49124908, 23.48652267], [68.49124908, 23.48681068], [68.49195862, 23.48680878], [68.49514008, 23.48680305], [68.49514008, 23.48708534], [68.49624634, 23.48708534], [68.49624634, 23.48736382], [68.49652863, 23.48736], [68.49652863, 23.48764038], [68.49680328, 23.48764038], [68.49680328, 23.48792076], [68.49708557, 23.48791695], [68.4970932, 23.4881897], [68.49736023, 23.48819542], [68.49736023, 23.48847389], [68.49764252, 23.48847008], [68.49764252, 23.48903084], [68.49791718, 23.48903084], [68.49791718, 23.48931122], [68.49874878, 23.48931122], [68.49874878, 23.48903084], [68.49846649, 23.48903084]]], [[[68.50180817, 23.43208122], [68.50180817, 23.43124962], [68.50152588, 23.43124962], [68.50152588, 23.43069077], [68.50125122, 23.43069458], [68.50125122, 23.43013954], [68.50041962, 23.43013954], [68.50041962, 23.43124962], [68.50096893, 23.43124962], [68.50096893, 23.43153191], [68.50125122, 23.43152809], [68.50125122, 23.43208122], [68.50152588, 23.43208122], [68.50152588, 23.43237114], [68.50208282, 23.43237114], [68.50208282, 23.43208122], [68.50180817, 23.43208122]]], [[[68.51680756, 23.43292046], [68.51680756, 23.43264008], [68.51708221, 23.43264008], [68.51708221, 23.43153191], [68.51680756, 23.43153191], [68.51680756, 23.43097115], [68.51652527, 23.43097115], [68.51652527, 23.43041611], [68.51625061, 23.43042183], [68.51625061, 23.42985916], [68.51597595, 23.42985916], [68.51597595, 23.43013954], [68.51568604, 23.43013954], [68.51568604, 23.43042183], [68.51541901, 23.43041611], [68.51541901, 23.43069458], [68.51430511, 23.43069458], [68.51430511, 23.43041611], [68.51374817, 23.43041611], [68.51374817, 23.43097115], [68.51403046, 23.43097115], [68.51403046, 23.43153191], [68.51374817, 23.43152809], [68.51374817, 23.43208122], [68.51403046, 23.43208122], [68.51403046, 23.43264008], [68.51457977, 23.43264008], [68.51457977, 23.43292046], [68.51680756, 23.43292046]]], [[[68.50068665, 23.43625069], [68.50068665, 23.43597031], [68.50096893, 23.43597221], [68.50096893, 23.43541718], [68.49958038, 23.43541718], [68.49958038, 23.4351387], [68.49931335, 23.43514061], [68.49931335, 23.43486023], [68.49874878, 23.43486023], [68.49874878, 23.43457985], [68.49819183, 23.43458557], [68.49819183, 23.43430328], [68.49791718, 23.43430328], [68.49791718, 23.43458557], [68.49680328, 23.43457985], [68.49680328, 23.43486023], [68.49736023, 23.43486023], [68.49736023, 23.43541718], [68.49791718, 23.43541718], [68.49791718, 23.43569565], [68.49819183, 23.43569565], [68.49819183, 23.43597221], [68.49874878, 23.43597031], [68.49874878, 23.43625069], [68.50068665, 23.43625069]]], [[[68.50125122, 23.44375038], [68.50125122, 23.44347191], [68.50208282, 23.44347191], [68.50208282, 23.44319534], [68.50180817, 23.44320107], [68.50180817, 23.4426403], [68.50152588, 23.4426403], [68.50152588, 23.44154167], [68.50125122, 23.44154167], [68.50125122, 23.43930817], [68.50096893, 23.43930817], [68.50096893, 23.43902969], [68.50068665, 23.43902969], [68.50068665, 23.44041824], [68.50041962, 23.44041634], [68.50041962, 23.44097137], [68.50013733, 23.44096947], [68.50013733, 23.44154167], [68.49958038, 23.44152832], [68.49958038, 23.44180489], [68.49930573, 23.44180489], [68.49930573, 23.44236183], [68.50013733, 23.44235992], [68.50013733, 23.4426403], [68.50041962, 23.4426403], [68.50041962, 23.44292259], [68.50069427, 23.44291687], [68.50069427, 23.44347191], [68.50096893, 23.44347191], [68.50096893, 23.44375038], [68.50125122, 23.44375038]]], [[[68.50681305, 23.45654106], [68.50681305, 23.45624924], [68.50708008, 23.45624924], [68.50708008, 23.45597076], [68.50736237, 23.45597267], [68.50736237, 23.4556942], [68.50763702, 23.4556942], [68.50763702, 23.45541763], [68.50791931, 23.45542145], [68.50791931, 23.45513916], [68.50846863, 23.45513916], [68.50846863, 23.45486069], [68.50874329, 23.45486069], [68.50874329, 23.45431137], [68.5090332, 23.45431137], [68.5090332, 23.45402908], [68.51013947, 23.45402908], [68.51013947, 23.45264053], [68.51097107, 23.45264053], [68.51097107, 23.45236015], [68.51125336, 23.45236206], [68.51125336, 23.45208359], [68.51180267, 23.45208359], [68.51180267, 23.45180511], [68.51152802, 23.45181084], [68.51152802, 23.45153046], [68.51346588, 23.45153046], [68.51346588, 23.45125008], [68.51374817, 23.45125008], [68.51374817, 23.4509697], [68.51403046, 23.4509716], [68.51403046, 23.45069695], [68.51431274, 23.45070076], [68.51431274, 23.45041084], [68.51513672, 23.45041656], [68.51513672, 23.45013809], [68.51597595, 23.45014], [68.51599884, 23.44985962], [68.51680756, 23.44986153], [68.51680756, 23.44958305], [68.51763916, 23.44958305], [68.51763916, 23.44930649], [68.51819611, 23.4493103], [68.51819611, 23.44902992], [68.51902771, 23.44902992], [68.51902771, 23.44847107], [68.51930237, 23.44847488], [68.51930237, 23.44791412], [68.51957703, 23.44791985], [68.51957703, 23.44763947], [68.51985931, 23.44763947], [68.51985931, 23.44708061], [68.5201416, 23.44708252], [68.5201416, 23.44652748], [68.52041626, 23.44652939], [68.52041626, 23.44597054], [68.52069092, 23.44597435], [68.52069092, 23.4454174], [68.52097321, 23.44542122], [68.52097321, 23.44514275], [68.52124786, 23.44514275], [68.52124786, 23.44486046], [68.52179718, 23.44486046], [68.52179718, 23.44458008], [68.52263641, 23.44458389], [68.52263641, 23.44430542], [68.52319336, 23.44431114], [68.52319336, 23.44403267], [68.52375031, 23.44403267], [68.52375031, 23.44375038], [68.52458191, 23.44375038], [68.52458191, 23.44347191], [68.5248642, 23.44347191], [68.5248642, 23.44319534], [68.52513885, 23.44320107], [68.52513885, 23.4426403], [68.52540588, 23.4426403], [68.52540588, 23.44235992], [68.5256958, 23.44236183], [68.5256958, 23.44208336], [68.52597046, 23.44208336], [68.52597046, 23.44124985], [68.52625275, 23.44124985], [68.52625275, 23.43985939], [68.5265274, 23.4398613], [68.5265274, 23.43819427], [68.52625275, 23.43819427], [68.52625275, 23.4370842], [68.52597046, 23.4370842], [68.52597046, 23.43652725], [68.5256958, 23.43653107], [68.5256958, 23.43625069], [68.52513885, 23.43625069], [68.52513885, 23.43653107], [68.52485657, 23.43653107], [68.52485657, 23.43736076], [68.52458191, 23.43736076], [68.52458191, 23.43875122], [68.52430725, 23.43875122], [68.52430725, 23.44041824], [68.52404022, 23.44041824], [68.52404022, 23.44154167], [68.52375031, 23.44152832], [68.52375031, 23.44236183], [68.5229187, 23.44235992], [68.5229187, 23.44320107], [68.5220871, 23.44319534], [68.5220871, 23.44347191], [68.52097321, 23.44347191], [68.52097321, 23.44375038], [68.52068329, 23.44375038], [68.52068329, 23.44403267], [68.5201416, 23.44403267], [68.5201416, 23.44431114], [68.51985931, 23.44430542], [68.51985931, 23.44458389], [68.51957703, 23.44458008], [68.51957703, 23.44486046], [68.51930237, 23.44486046], [68.51930237, 23.44514275], [68.51875305, 23.44514275], [68.51875305, 23.44542122], [68.51790619, 23.44542122], [68.51790619, 23.44625282], [68.51763916, 23.44625282], [68.51763916, 23.44680977], [68.5173645, 23.44680405], [68.5173645, 23.44708252], [68.51708221, 23.44708252], [68.51708221, 23.4473629], [68.51680756, 23.44734955], [68.51680756, 23.44763947], [68.5165329, 23.44763947], [68.5165329, 23.44791985], [68.51582336, 23.44791412], [68.51346588, 23.44791985], [68.51346588, 23.44734955], [68.51374817, 23.4473629], [68.51374817, 23.44708252], [68.51430511, 23.44708252], [68.51430511, 23.44680405], [68.51457977, 23.44680977], [68.51457977, 23.44652939], [68.51486969, 23.44652939], [68.51486969, 23.44625282], [68.51541901, 23.44625282], [68.51541901, 23.44569016], [68.51513672, 23.44569206], [68.51513672, 23.44486046], [68.5165329, 23.44486046], [68.5165329, 23.44514275], [68.51711273, 23.44513893], [68.51735687, 23.44514275], [68.5173645, 23.44482994], [68.51763916, 23.44486046], [68.51757813, 23.44431114], [68.51790619, 23.44431114], [68.51786041, 23.44372559], [68.51819611, 23.44375038], [68.51819611, 23.44347191], [68.51902771, 23.44347191], [68.51902771, 23.44319534], [68.51930237, 23.44320107], [68.51930237, 23.44292259], [68.51957703, 23.44292259], [68.51957703, 23.44235992], [68.51985931, 23.44236183], [68.51985931, 23.44208336], [68.52069092, 23.44208336], [68.52069092, 23.44180489], [68.52097321, 23.44180489], [68.52097321, 23.44152832], [68.52124786, 23.44154167], [68.52124786, 23.44013977], [68.52153015, 23.44013977], [68.52153015, 23.43875122], [68.52124786, 23.43875122], [68.52124786, 23.43764114], [68.52097321, 23.43764114], [68.52097321, 23.43708038], [68.52069092, 23.4370842], [68.52069092, 23.43680763], [68.51985931, 23.43680763], [68.51985931, 23.4370842], [68.51957703, 23.43708038], [68.51957703, 23.43736076], [68.51930237, 23.43736076], [68.51930237, 23.43930817], [68.51902771, 23.43930626], [68.51902771, 23.4398613], [68.51875305, 23.43985939], [68.51875305, 23.44041824], [68.51847076, 23.44041634], [68.51847076, 23.44097137], [68.51819611, 23.44096947], [68.51819611, 23.44154167], [68.51791382, 23.44152832], [68.51791382, 23.44208336], [68.51708221, 23.44208336], [68.51708221, 23.44069481], [68.5173645, 23.44069481], [68.5173645, 23.44013977], [68.51763916, 23.44013977], [68.51763916, 23.43902969], [68.51790619, 23.43902969], [68.51790619, 23.43708038], [68.51819611, 23.4370842], [68.51819611, 23.43625069], [68.51790619, 23.43625069], [68.51790619, 23.43597031], [68.51708221, 23.43597221], [68.51708221, 23.43569565], [68.51680756, 23.43569565], [68.51680756, 23.43541718], [68.51569366, 23.43541718], [68.51569366, 23.43347168], [68.51541901, 23.43346977], [68.51541901, 23.43375015], [68.51513672, 23.43375015], [68.51513672, 23.43680954], [68.51403046, 23.43680763], [68.51403046, 23.4370842], [68.51235962, 23.4370842], [68.51235962, 23.43680763], [68.51207733, 23.43680954], [68.51207733, 23.43653107], [68.51152802, 23.43653107], [68.51152802, 23.43680954], [68.51125336, 23.43680763], [68.51125336, 23.4370842], [68.51097107, 23.43708038], [68.51097107, 23.43764114], [68.51069641, 23.43763924], [68.51069641, 23.43847275], [68.51040649, 23.43847084], [68.51040649, 23.43875122], [68.50985718, 23.43875122], [68.50985718, 23.43819046], [68.51013947, 23.43819427], [68.51013947, 23.43736076], [68.51040649, 23.43736076], [68.51040649, 23.43680954], [68.51069641, 23.43680954], [68.51069641, 23.43625069], [68.51097107, 23.43625069], [68.51097107, 23.43568993], [68.51125336, 23.43569565], [68.51125336, 23.43541718], [68.51152802, 23.43541718], [68.51152802, 23.4351387], [68.51207733, 23.43514061], [68.51207733, 23.43431091], [68.51235962, 23.43431091], [68.51235962, 23.43346977], [68.51208496, 23.43347168], [68.51208496, 23.43291664], [68.5118103, 23.43292046], [68.5118103, 23.43208122], [68.51152802, 23.43208122], [68.51152802, 23.43041611], [68.51041412, 23.43041611], [68.51041412, 23.43069458], [68.51013947, 23.43069458], [68.51013947, 23.43097115], [68.50985718, 23.43097115], [68.50985718, 23.43124962], [68.50958252, 23.43124962], [68.50958252, 23.43153191], [68.50930786, 23.43152809], [68.50930786, 23.43180466], [68.50819397, 23.43180466], [68.50819397, 23.43152809], [68.50708008, 23.43153191], [68.50708008, 23.43124962], [68.50596619, 23.43124962], [68.50596619, 23.43097115], [68.50541687, 23.43097115], [68.50541687, 23.43069458], [68.50514221, 23.43069458], [68.50514221, 23.43041611], [68.5045929, 23.43042183], [68.5045929, 23.43013954], [68.50430298, 23.43013954], [68.50430298, 23.42985916], [68.50374603, 23.42985916], [68.50374603, 23.42958069], [68.50347137, 23.4295826], [68.50347137, 23.42930603], [68.5029068, 23.42931175], [68.5029068, 23.43042183], [68.50319672, 23.43041611], [68.50319672, 23.43069458], [68.50347137, 23.43069458], [68.50347137, 23.43097115], [68.50430298, 23.43097115], [68.50430298, 23.43180466], [68.5045929, 23.43180275], [68.5045929, 23.43264008], [68.50430298, 23.43264008], [68.50430298, 23.43320084], [68.50402832, 23.43320084], [68.50402832, 23.43375015], [68.50374603, 23.43375015], [68.50374603, 23.43431091], [68.50402832, 23.43431091], [68.50402832, 23.43403053], [68.50514221, 23.43403053], [68.50514221, 23.43680954], [68.50569153, 23.43680763], [68.50569153, 23.4370842], [68.50541687, 23.43708038], [68.50541687, 23.43764114], [68.50514221, 23.43764114], [68.50514221, 23.43930817], [68.50485992, 23.43930626], [68.50485992, 23.44069481], [68.50458527, 23.44069481], [68.5045929, 23.44124985], [68.50430298, 23.44124985], [68.50430298, 23.4426403], [68.50402832, 23.4426403], [68.50402832, 23.44375038], [68.50374603, 23.44375038], [68.50374603, 23.44486046], [68.50347137, 23.44486046], [68.50347137, 23.44597435], [68.50319672, 23.44597435], [68.50319672, 23.44708252], [68.5029068, 23.44708061], [68.5029068, 23.44791985], [68.50319672, 23.44791412], [68.50319672, 23.4481926], [68.50347137, 23.4481926], [68.50347137, 23.44847488], [68.50402832, 23.44847107], [68.50402832, 23.44874954], [68.5045929, 23.44874954], [68.5045929, 23.44902992], [68.50514221, 23.44902992], [68.50514221, 23.4493103], [68.50541687, 23.44930649], [68.50541687, 23.44958305], [68.50597382, 23.44958305], [68.50597382, 23.44986153], [68.50624847, 23.44985962], [68.50624847, 23.45014], [68.50653076, 23.45013809], [68.50653076, 23.45041656], [68.50680542, 23.45041656], [68.50680542, 23.4509716], [68.50624847, 23.4509697], [68.50624847, 23.45125008], [68.50597382, 23.45125008], [68.50597382, 23.45208359], [68.50485992, 23.45207977], [68.50485992, 23.45236015], [68.50430298, 23.45236015], [68.50430298, 23.45347977], [68.50458527, 23.45347214], [68.5045929, 23.45375061], [68.50430298, 23.45375061], [68.50430298, 23.45402908], [68.50402832, 23.45402718], [68.50402832, 23.45458412], [68.50374603, 23.45458031], [68.50374603, 23.45486069], [68.50347137, 23.45486069], [68.50347137, 23.45542145], [68.50319672, 23.45541573], [68.50319672, 23.45597267], [68.50402832, 23.45597076], [68.50402832, 23.45624924], [68.5045929, 23.45624924], [68.5045929, 23.45654106], [68.5061264, 23.45652962], [68.50681305, 23.45654106]]], [[[68.43125153, 23.43985939], [68.43152618, 23.4398613], [68.43152618, 23.43958282], [68.43345642, 23.43958092], [68.43345642, 23.44041824], [68.43374634, 23.44041634], [68.43374634, 23.44069481], [68.43430328, 23.44069481], [68.43430328, 23.44041634], [68.43486023, 23.44041634], [68.43486023, 23.44069481], [68.43514252, 23.44068909], [68.43514252, 23.44124985], [68.43486023, 23.44124985], [68.43486023, 23.44154167], [68.43430328, 23.44152832], [68.43430328, 23.44208336], [68.43458557, 23.44208336], [68.43458557, 23.44236183], [68.43514252, 23.44235992], [68.43514252, 23.4426403], [68.43541718, 23.4426403], [68.43541718, 23.44207764], [68.43596649, 23.44207764], [68.43596649, 23.44292259], [68.43624878, 23.44291687], [68.43624878, 23.44347191], [68.43569183, 23.44347191], [68.43569183, 23.44375038], [68.43541718, 23.44375038], [68.43541718, 23.44514275], [68.43458557, 23.44513893], [68.43458557, 23.44597435], [68.43430328, 23.44597054], [68.43430328, 23.44625282], [68.43402863, 23.44625282], [68.43402863, 23.44652939], [68.43374634, 23.44652748], [68.43374634, 23.44708252], [68.43319702, 23.44708252], [68.43319702, 23.4481926], [68.43347168, 23.4481926], [68.43347168, 23.44847488], [68.43319702, 23.44847107], [68.43319702, 23.44874954], [68.4329071, 23.44874954], [68.4329071, 23.44902992], [68.43264008, 23.44902992], [68.43264008, 23.45014], [68.4329071, 23.45014], [68.4329071, 23.44985962], [68.43402863, 23.44986153], [68.43402863, 23.44958305], [68.43430328, 23.44958305], [68.43430328, 23.44930649], [68.4345932, 23.4493103], [68.4345932, 23.44902992], [68.43541718, 23.44902802], [68.43541718, 23.44958305], [68.43569183, 23.44958305], [68.43569183, 23.44986153], [68.43624878, 23.44985962], [68.43624878, 23.45014], [68.43653107, 23.45014], [68.43653107, 23.45125008], [68.43682098, 23.45125008], [68.43682098, 23.45181084], [68.43596649, 23.45181084], [68.43596649, 23.45292091], [68.43624878, 23.45292091], [68.43624878, 23.45264053], [68.43680573, 23.45263863], [68.43680573, 23.45319366], [68.43708038, 23.45318985], [68.43708038, 23.45375061], [68.43763733, 23.45375061], [68.43763733, 23.45402908], [68.43985748, 23.45402908], [68.43985748, 23.45375061], [68.44013977, 23.45375061], [68.44013977, 23.45347977], [68.44097137, 23.45347977], [68.44097137, 23.45375061], [68.44124603, 23.45375061], [68.44124603, 23.45402908], [68.44152832, 23.45402718], [68.44152832, 23.45458412], [68.44235992, 23.45458412], [68.44235992, 23.45430565], [68.44271851, 23.45430565], [68.44319153, 23.45430565], [68.44319153, 23.45490074], [68.44319153, 23.45597267], [68.44420624, 23.45597267], [68.44541931, 23.45597076], [68.44541931, 23.4568119], [68.44569397, 23.45680618], [68.44569397, 23.45753098], [68.44568634, 23.45763969], [68.44580078, 23.45763969], [68.44930267, 23.45763969], [68.44930267, 23.45792007], [68.44985962, 23.45791626], [68.44985962, 23.45819473], [68.45014191, 23.45819473], [68.45014191, 23.4584713], [68.45041656, 23.45846939], [68.45041656, 23.45903015], [68.45069122, 23.45902824], [68.45069122, 23.45930481], [68.45097351, 23.45930481], [68.45097351, 23.45958138], [68.45124817, 23.45957947], [68.45124817, 23.46014023], [68.45153046, 23.46014023], [68.45153046, 23.46042061], [68.45182037, 23.46042061], [68.45182037, 23.46070099], [68.45236206, 23.46069336], [68.45236206, 23.46097374], [68.45263672, 23.46096992], [68.45263672, 23.46125031], [68.45236206, 23.46125031], [68.45236206, 23.46181107], [68.45263672, 23.46180344], [68.45263672, 23.46236038], [68.45291901, 23.46235085], [68.45291901, 23.46264076], [68.45318604, 23.46264076], [68.45318604, 23.46375084], [68.45236206, 23.46375084], [68.45236206, 23.46347046], [68.45207977, 23.46347237], [68.45207977, 23.4631958], [68.45180511, 23.4631958], [68.45180511, 23.46291733], [68.45153046, 23.46292114], [68.45153046, 23.46264076], [68.45096588, 23.46264076], [68.45096588, 23.46235085], [68.45069122, 23.46236038], [68.45069122, 23.46208572], [68.45041656, 23.46208572], [68.45041656, 23.46180344], [68.45014191, 23.46181107], [68.45014191, 23.46153069], [68.44985962, 23.46153069], [68.44985962, 23.46125031], [68.44957733, 23.46125031], [68.44957733, 23.46096992], [68.44896698, 23.46096992], [68.44819641, 23.46096992], [68.44819641, 23.46125031], [68.44708252, 23.46125031], [68.44708252, 23.46153069], [68.44596863, 23.46153069], [68.44596863, 23.46181107], [68.44486237, 23.46180344], [68.44486237, 23.46208572], [68.44458008, 23.46208], [68.44458008, 23.46264076], [68.44486237, 23.46263885], [68.44486237, 23.4631958], [68.44458008, 23.46319008], [68.44458008, 23.46430969], [68.44430542, 23.46430779], [68.44430542, 23.46458244], [68.44403076, 23.46458054], [68.44403076, 23.46652985], [68.44458008, 23.46652985], [68.44458008, 23.46680832], [68.44486237, 23.46680641], [68.44486237, 23.46708298], [68.44513702, 23.46708107], [68.44513702, 23.4679184], [68.44708252, 23.4679184], [68.44708252, 23.46820068], [68.44735718, 23.46820068], [68.44735718, 23.46763992], [68.44819641, 23.46763992], [68.44819641, 23.46820068], [68.44847107, 23.46820068], [68.44847107, 23.46874809], [68.44876099, 23.46874809], [68.44876099, 23.46902847], [68.44930267, 23.46902847], [68.44930267, 23.46847916], [68.44985962, 23.46847916], [68.44985962, 23.46902847], [68.45014191, 23.46902847], [68.45014191, 23.46931267], [68.45041656, 23.46930504], [68.45041656, 23.46958351], [68.45124817, 23.46958351], [68.45124817, 23.46986008], [68.45153046, 23.46986008], [68.45153046, 23.46958351], [68.45207977, 23.46958351], [68.45207977, 23.46930504], [68.45291901, 23.46930504], [68.45291901, 23.46958351], [68.45319366, 23.46958351], [68.45319366, 23.46986008], [68.45375061, 23.46986008], [68.45375061, 23.46958351], [68.45458221, 23.46958351], [68.45458221, 23.46986008], [68.45430756, 23.46986008], [68.45430756, 23.47069359], [68.45458221, 23.47069359], [68.45458221, 23.47041702], [68.45513916, 23.47042274], [68.45513916, 23.47014046], [68.45540619, 23.47014046], [68.45540619, 23.46986008], [68.45569611, 23.46986008], [68.45569611, 23.46930504], [68.45597076, 23.46931267], [68.45597076, 23.46902847], [68.45625305, 23.46902847], [68.45625305, 23.46874809], [68.45652771, 23.46874809], [68.45652771, 23.4679184], [68.45680237, 23.4679184], [68.45680237, 23.46763992], [68.45735931, 23.46763992], [68.45735931, 23.46820068], [68.45707703, 23.46820068], [68.45707703, 23.46874809], [68.45680237, 23.46874809], [68.45680237, 23.46958351], [68.45652771, 23.46958351], [68.45652771, 23.46986008], [68.45625305, 23.46986008], [68.45625305, 23.47014046], [68.45597076, 23.47013855], [68.45597076, 23.47069359], [68.45625305, 23.47069359], [68.45625305, 23.47097015], [68.45708466, 23.47097015], [68.45708466, 23.47069359], [68.45735931, 23.47069359], [68.45735931, 23.47041702], [68.45762634, 23.47042274], [68.45762634, 23.47014046], [68.45791626, 23.47014046], [68.45791626, 23.46986008], [68.45819092, 23.46986008], [68.45819092, 23.46958351], [68.45847321, 23.46958351], [68.45847321, 23.46930504], [68.45874786, 23.46931267], [68.45874786, 23.46902847], [68.45903015, 23.46902847], [68.45903015, 23.46874809], [68.45929718, 23.46874809], [68.45929718, 23.46847916], [68.46013641, 23.46847153], [68.46013641, 23.46899033], [68.46013641, 23.46986008], [68.4604187, 23.46986008], [68.4604187, 23.47458458], [68.46013641, 23.47458076], [68.46013641, 23.47486115], [68.4604187, 23.47486115], [68.4604187, 23.47513962], [68.46070099, 23.47513962], [68.46070099, 23.47542], [68.46125031, 23.47542], [68.46125031, 23.47624969], [68.46098328, 23.47624969], [68.46098328, 23.47653008], [68.4604187, 23.47652817], [68.4604187, 23.47736168], [68.45874786, 23.47736168], [68.45874786, 23.47708321], [68.45847321, 23.47708321], [68.45847321, 23.47680664], [68.45791626, 23.47680664], [68.45791626, 23.47736168], [68.4576416, 23.47736168], [68.45762634, 23.47817993], [68.45735931, 23.47819519], [68.45735931, 23.47847176], [68.45707703, 23.47846985], [68.45707703, 23.47875023], [68.45832825, 23.47875023], [68.45986176, 23.47875023], [68.45986176, 23.47846985], [68.46069336, 23.47847176], [68.46069336, 23.47875023], [68.4640274, 23.47875023], [68.4640274, 23.47903061], [68.4651413, 23.47903061], [68.4651413, 23.47875023], [68.46652985, 23.47875023], [68.46652985, 23.47846985], [68.4668045, 23.47847176], [68.4668045, 23.47819519], [68.4679184, 23.47819519], [68.4679184, 23.47847176], [68.46819305, 23.47847176], [68.46819305, 23.47819519], [68.46909332, 23.47819519], [68.47013855, 23.47819519], [68.47013855, 23.47847176], [68.47041321, 23.47846985], [68.47041321, 23.47875023], [68.47070313, 23.47875023], [68.47070313, 23.47930908], [68.47097015, 23.47930527], [68.47097015, 23.47958374], [68.47109222, 23.47958374], [68.4715271, 23.47958374], [68.4715271, 23.47986031], [68.47167969, 23.47986031], [68.47180176, 23.47986031], [68.47180176, 23.48014069], [68.47226715, 23.48013878], [68.4723587, 23.48013878], [68.4723587, 23.48041916], [68.47286224, 23.48041916], [68.47292328, 23.48014069], [68.4734726, 23.48014069], [68.4734726, 23.47986031], [68.47429657, 23.47986031], [68.47429657, 23.47957993], [68.47486115, 23.47958374], [68.47486115, 23.47930527], [68.4751358, 23.47930908], [68.4751358, 23.47903061], [68.47570038, 23.47903061], [68.47570038, 23.47875023], [68.47624969, 23.47875023], [68.47624969, 23.47846985], [68.47652435, 23.47847176], [68.47652435, 23.47819519], [68.4770813, 23.47820091], [68.4770813, 23.47792053], [68.4779129, 23.47792053], [68.4779129, 23.47764969], [68.47846985, 23.47764969], [68.47846985, 23.47735977], [68.47930908, 23.47736168], [68.47930908, 23.47708321], [68.4826355, 23.47708321], [68.4826355, 23.47680664], [68.48319244, 23.47680664], [68.48319244, 23.47652817], [68.48374939, 23.47653008], [68.48374939, 23.47624969], [68.48401642, 23.47624969], [68.48401642, 23.47597122], [68.48430634, 23.47597313], [68.48430634, 23.47569656], [68.48513794, 23.47569656], [68.48513794, 23.47541428], [68.48542023, 23.47542], [68.48542023, 23.47486115], [68.48568726, 23.47486115], [68.48568726, 23.47430992], [68.48596954, 23.47430992], [68.48596954, 23.47402954], [68.48625183, 23.47402954], [68.48625183, 23.47347069], [68.48652649, 23.4734745], [68.48652649, 23.47319221], [68.48680878, 23.47319221], [68.48680878, 23.47263908], [68.48707581, 23.4726429], [68.48707581, 23.47208023], [68.48680878, 23.47208214], [68.48680878, 23.47180557], [68.48652649, 23.47180939], [68.48652649, 23.47097015], [68.48625183, 23.47097015], [68.48625183, 23.47041702], [68.48652649, 23.47042274], [68.48652649, 23.46874809], [68.48680878, 23.46874809], [68.48680878, 23.46735954], [68.48708344, 23.46736145], [68.48708344, 23.46680641], [68.48735809, 23.46680832], [68.48735809, 23.46624947], [68.48764038, 23.46624947], [68.48764038, 23.46597099], [68.48791504, 23.4659729], [68.48791504, 23.46569443], [68.48819733, 23.46569443], [68.48819733, 23.46541786], [68.48847198, 23.46541977], [68.48847198, 23.46486092], [68.48902893, 23.46486092], [68.48902893, 23.46458054], [68.48930359, 23.46458244], [68.48930359, 23.46430779], [68.48958588, 23.46430969], [68.48958588, 23.46375084], [68.48986053, 23.46375084], [68.48986053, 23.46319008], [68.49013519, 23.4631958], [68.49013519, 23.46263885], [68.49041748, 23.46264076], [68.49041748, 23.46235085], [68.49069214, 23.46236038], [68.49069214, 23.46180344], [68.4909668, 23.46181107], [68.4909668, 23.46153069], [68.49153137, 23.46153069], [68.49153137, 23.46125031], [68.49180603, 23.46125031], [68.49180603, 23.46042061], [68.49208069, 23.46042061], [68.49208069, 23.45985985], [68.49236298, 23.45986366], [68.49236298, 23.45958138], [68.49263763, 23.45958138], [68.49263763, 23.45874977], [68.49291992, 23.45874977], [68.49291992, 23.45846939], [68.49319458, 23.4584713], [68.49319458, 23.45819473], [68.49346924, 23.45819473], [68.49346924, 23.45791626], [68.49373627, 23.45792007], [68.49373627, 23.45763969], [68.49430847, 23.45763969], [68.49430847, 23.45735931], [68.49458313, 23.45735931], [68.49458313, 23.45597076], [68.49485779, 23.45597267], [68.49485779, 23.45513916], [68.49458313, 23.45513916], [68.49458313, 23.45486069], [68.49485779, 23.45486069], [68.49485779, 23.45458031], [68.49458313, 23.45458412], [68.49458313, 23.45319366], [68.49430847, 23.45319366], [68.49430847, 23.45263863], [68.49402618, 23.45264053], [68.49402618, 23.45236015], [68.49375153, 23.45236015], [68.49373627, 23.45125008], [68.49346924, 23.45125008], [68.49346924, 23.4509697], [68.49319458, 23.4509716], [68.49319458, 23.45041656], [68.49291992, 23.45041656], [68.49291992, 23.44986153], [68.49263763, 23.44986153], [68.49263763, 23.44930649], [68.49236298, 23.44930077], [68.49236298, 23.44874954], [68.49208069, 23.44874954], [68.49208069, 23.44819069], [68.49180603, 23.4481926], [68.49180603, 23.4473629], [68.49153137, 23.4473629], [68.49153137, 23.44625282], [68.49124908, 23.44625282], [68.49124908, 23.44514275], [68.49069977, 23.44514275], [68.49069977, 23.44458008], [68.49041748, 23.44458389], [68.49041748, 23.43874931], [68.49014282, 23.43875122], [68.49014282, 23.43708038], [68.48986053, 23.4370842], [68.48986053, 23.43680763], [68.49014282, 23.43680954], [68.49014282, 23.43597031], [68.48986053, 23.43597221], [68.48986053, 23.43541718], [68.49013519, 23.43541718], [68.49013519, 23.43458557], [68.48986053, 23.43458557], [68.48986053, 23.43402863], [68.48958588, 23.43403053], [68.48958588, 23.43264008], [68.48986053, 23.43264008], [68.48986053, 23.42736053], [68.48958588, 23.42736053], [68.48958588, 23.42542076], [68.48929596, 23.42542076], [68.48929596, 23.42457962], [68.48902893, 23.42458344], [68.48902893, 23.42347145], [68.48874664, 23.42347145], [68.48874664, 23.42263794], [68.48847198, 23.42263985], [68.48847198, 23.42069054], [68.48819733, 23.42069244], [68.48819733, 23.41986084], [68.48791504, 23.41986084], [68.48791504, 23.41902733], [68.48764038, 23.41903114], [68.48764038, 23.41819191], [68.48735809, 23.41819382], [68.48735809, 23.41625023], [68.48707581, 23.41625023], [68.48707581, 23.41541862], [68.48680878, 23.41541862], [68.48680878, 23.41457748], [68.48652649, 23.41458321], [68.48652649, 23.41180611], [68.48625183, 23.41180992], [68.48625183, 23.41097069], [68.48596954, 23.4109726], [68.48596954, 23.41013908], [68.48568726, 23.41014099], [68.48568726, 23.40792084], [68.48542023, 23.40792084], [68.48542023, 23.40570068], [68.48513794, 23.40570068], [68.48513794, 23.40542984], [68.48542023, 23.40542984], [68.48542023, 23.40458107], [68.48513794, 23.40458107], [68.48513794, 23.40430641], [68.48486328, 23.40431023], [68.48486328, 23.40374947], [68.48458099, 23.40374947], [68.48458099, 23.40319061], [68.48374939, 23.40319443], [68.48374939, 23.40291595], [68.48208618, 23.40291595], [68.48208618, 23.40319443], [68.48152924, 23.40319443], [68.48152924, 23.4034729], [68.48069763, 23.40346909], [68.48069763, 23.40374947], [68.48014069, 23.40374947], [68.48014069, 23.40403175], [68.47930908, 23.40403175], [68.47930908, 23.40431023], [68.4779129, 23.40431023], [68.4779129, 23.40403175], [68.47763824, 23.40403175], [68.47763824, 23.40346909], [68.4770813, 23.40346909], [68.4770813, 23.40374947], [68.47680664, 23.40374947], [68.47680664, 23.40403175], [68.47628021, 23.40403175], [68.47624969, 23.40431023], [68.47569275, 23.40430641], [68.47569275, 23.40458107], [68.4751358, 23.40458107], [68.4751358, 23.40486145], [68.47458649, 23.40485954], [68.47458649, 23.40514183], [68.47402954, 23.40514183], [68.47402954, 23.40542984], [68.4734726, 23.40542984], [68.4734726, 23.40570068], [68.47310638, 23.40569305], [68.47291565, 23.40569305], [68.47291565, 23.40597153], [68.4723587, 23.40596962], [68.4723587, 23.40625], [68.47180176, 23.40625], [68.47180176, 23.40653038], [68.47070313, 23.40653038], [68.47070313, 23.40625], [68.46956635, 23.40625], [68.46956635, 23.40653038], [68.46901703, 23.40653038], [68.46901703, 23.40625], [68.46819305, 23.40625], [68.46819305, 23.40596962], [68.46679688, 23.40596962], [68.4668045, 23.40625], [68.46608734, 23.40625], [68.4659729, 23.40625], [68.4659729, 23.40708542], [68.46347046, 23.40708542], [68.46347046, 23.40736389], [68.46375275, 23.40736389], [68.46375275, 23.4081955], [68.46458435, 23.4081955], [68.46458435, 23.40847206], [68.46485901, 23.40847015], [68.46485901, 23.40875053], [68.46457672, 23.40875053], [68.46457672, 23.40903091], [68.46485901, 23.40902519], [68.46485901, 23.40958595], [68.4651413, 23.40958023], [68.4651413, 23.40986061], [68.46541595, 23.40986061], [68.46541595, 23.41041946], [68.46569061, 23.41041756], [68.46569824, 23.41069412], [68.4659729, 23.41069412], [68.4659729, 23.4109726], [68.46624756, 23.41097069], [68.46624756, 23.41152954], [68.46652985, 23.41152954], [68.46652985, 23.41180992], [68.46569824, 23.41180611], [68.46569061, 23.41208267], [68.4651413, 23.41208076], [68.4651413, 23.41236115], [68.46457672, 23.41236115], [68.46457672, 23.41263962], [68.46430206, 23.41263962], [68.46430206, 23.41291809], [68.46375275, 23.41291618], [68.46375275, 23.41319466], [68.46347046, 23.41319466], [68.46347046, 23.41347313], [68.46290588, 23.41347122], [68.46290588, 23.41374969], [68.46208191, 23.41374969], [68.46208191, 23.41402817], [68.46152496, 23.41402817], [68.46152496, 23.41430473], [68.46097565, 23.41430473], [68.46097565, 23.41486168], [68.46070099, 23.41485977], [68.46070099, 23.41541862], [68.45986176, 23.41541862], [68.45986176, 23.41570282], [68.4595871, 23.41570282], [68.4595871, 23.41625023], [68.45929718, 23.41625023], [68.45929718, 23.41653252], [68.45903015, 23.4165287], [68.45903015, 23.41708374], [68.45874786, 23.41708183], [68.45874786, 23.41764259], [68.45847321, 23.41764259], [68.45847321, 23.41792107], [68.45819092, 23.41791725], [68.45819092, 23.41819382], [68.45847321, 23.41819191], [68.45847321, 23.41875267], [68.45874786, 23.41875267], [68.45874786, 23.41930962], [68.45903015, 23.4193058], [68.45903015, 23.41958237], [68.45929718, 23.41958046], [68.45929718, 23.41986084], [68.46153259, 23.41986084], [68.46152496, 23.41958237], [68.4623642, 23.41958237], [68.4623642, 23.4193058], [68.46291351, 23.4193058], [68.46291351, 23.41958237], [68.4631958, 23.41958046], [68.4631958, 23.41986084], [68.46347046, 23.41986084], [68.46347046, 23.42014122], [68.46375275, 23.42013931], [68.46375275, 23.42048073], [68.46375275, 23.42069244], [68.4640274, 23.42069244], [68.4640274, 23.42097473], [68.46430206, 23.42097092], [68.46430206, 23.42124939], [68.46457672, 23.42124939], [68.46457672, 23.42152977], [68.4640274, 23.42152977], [68.4640274, 23.42181015], [68.46375275, 23.42180634], [68.46375275, 23.42208481], [68.46347046, 23.42208481], [68.46347046, 23.42236137], [68.4631958, 23.42235947], [68.4631958, 23.42292023], [68.46291351, 23.42291641], [68.46291351, 23.42347145], [68.46263885, 23.42346954], [68.46263885, 23.42374992], [68.46235657, 23.42374992], [68.46235657, 23.42431068], [68.46208191, 23.42431068], [68.46208191, 23.42514038], [68.46180725, 23.42514038], [68.46180725, 23.42653084], [68.46235657, 23.42653084], [68.46235657, 23.42681122], [68.4631958, 23.4268055], [68.4631958, 23.42708397], [68.46375275, 23.42708397], [68.46375275, 23.42736053], [68.4640274, 23.42736053], [68.4640274, 23.42764091], [68.46376038, 23.42764091], [68.46376038, 23.42791939], [68.4631958, 23.42791748], [68.4631958, 23.42819405], [68.46180725, 23.42819405], [68.46180725, 23.42847252], [68.46153259, 23.42847061], [68.46153259, 23.42902946], [68.46125031, 23.42902756], [68.46125031, 23.4295826], [68.46208191, 23.42958069], [68.46208191, 23.42985916], [68.46152496, 23.42985916], [68.46153259, 23.43013954], [68.46125031, 23.43013954], [68.46125031, 23.43042183], [68.46097565, 23.43041611], [68.46097565, 23.43069458], [68.46125031, 23.43069458], [68.46125031, 23.43097115], [68.46152496, 23.43097115], [68.46152496, 23.43124962], [68.46180725, 23.43124962], [68.46180725, 23.43208122], [68.46208191, 23.43208122], [68.46208191, 23.43292046], [68.4595871, 23.43292046], [68.4595871, 23.43320084], [68.45903015, 23.43319321], [68.45903015, 23.43347168], [68.45874786, 23.43346977], [68.45874786, 23.43403053], [68.45903015, 23.43403053], [68.45903015, 23.43431091], [68.4595871, 23.43431091], [68.4595871, 23.43486023], [68.45986176, 23.43486023], [68.45986176, 23.43680954], [68.46013641, 23.43680954], [68.46013641, 23.43736076], [68.46125031, 23.43736076], [68.46125031, 23.43764114], [68.46235657, 23.43764114], [68.46235657, 23.43791962], [68.46263885, 23.43791771], [68.46263885, 23.43819427], [68.46291351, 23.43819427], [68.46291351, 23.43847275], [68.4631958, 23.43847084], [68.4631958, 23.43875122], [68.46347046, 23.43875122], [68.46347046, 23.43902969], [68.46457672, 23.43902969], [68.46457672, 23.43930817], [68.46485901, 23.43930626], [68.46485901, 23.43958282], [68.46541595, 23.43958282], [68.46541595, 23.4398613], [68.46569061, 23.43985939], [68.46569824, 23.44013977], [68.4659729, 23.44013977], [68.4659729, 23.44069481], [68.46624756, 23.44068909], [68.46624756, 23.44124985], [68.46679688, 23.44124985], [68.46679688, 23.44154167], [68.46708679, 23.44152832], [68.46708679, 23.44180489], [68.46736145, 23.44180489], [68.46736145, 23.44208336], [68.46763611, 23.44208336], [68.46763611, 23.44236183], [68.46736145, 23.44235992], [68.46736145, 23.4426403], [68.46652985, 23.4426403], [68.46652985, 23.44292259], [68.4640274, 23.44292259], [68.4640274, 23.44320107], [68.46263885, 23.44319534], [68.46263885, 23.44347191], [68.46152496, 23.44347191], [68.46152496, 23.44375038], [68.46070099, 23.44375038], [68.46070099, 23.44403267], [68.4604187, 23.44402695], [68.4604187, 23.44458389], [68.46125031, 23.44458008], [68.46125031, 23.44486046], [68.46153259, 23.44486046], [68.46153259, 23.44514275], [68.46125031, 23.44513893], [68.46125031, 23.44569206], [68.46097565, 23.44569206], [68.46097565, 23.44625282], [68.46125031, 23.44625282], [68.46125031, 23.44652939], [68.46153259, 23.44652939], [68.46153259, 23.44680977], [68.46069336, 23.44680405], [68.46069336, 23.44763947], [68.46097565, 23.44763947], [68.46097565, 23.44847488], [68.46125031, 23.44847107], [68.46125031, 23.44902992], [68.46152496, 23.44902802], [68.46152496, 23.44958305], [68.46180725, 23.44958305], [68.46180725, 23.44986153], [68.46208191, 23.44986153], [68.46208191, 23.45015907], [68.46208191, 23.45125008], [68.46180725, 23.45125008], [68.46180725, 23.45181084], [68.46152496, 23.45180511], [68.46152496, 23.45236206], [68.46180725, 23.45236015], [68.46180725, 23.45347977], [68.46208191, 23.45347977], [68.46208191, 23.45375061], [68.46235657, 23.45375061], [68.46235657, 23.45402908], [68.46290588, 23.45402908], [68.46290588, 23.45431137], [68.46347046, 23.45430565], [68.46347046, 23.45458412], [68.46485901, 23.45458031], [68.46485901, 23.45486069], [68.46569824, 23.45486069], [68.46569824, 23.45458031], [68.4668045, 23.45458412], [68.4668045, 23.45430565], [68.46736145, 23.45431137], [68.46736145, 23.45402908], [68.46819305, 23.45402908], [68.46819305, 23.45375061], [68.46901703, 23.45375061], [68.46901703, 23.45347977], [68.46956635, 23.45347977], [68.46956635, 23.45318985], [68.47070313, 23.45318985], [68.47070313, 23.45347977], [68.47125244, 23.45347977], [68.47125244, 23.45375061], [68.4715271, 23.45375061], [68.4715271, 23.45402908], [68.47180176, 23.45402908], [68.47180176, 23.45431137], [68.47208405, 23.45430565], [68.47208405, 23.45458412], [68.4723587, 23.45458031], [68.4723587, 23.45486069], [68.47264099, 23.45486069], [68.47264099, 23.4556942], [68.47291565, 23.4556942], [68.47291565, 23.45763969], [68.47319794, 23.45763969], [68.47319794, 23.45819473], [68.4734726, 23.45819283], [68.4734726, 23.45874977], [68.47402954, 23.45874977], [68.47402954, 23.45903015], [68.47429657, 23.45903015], [68.47429657, 23.45874977], [68.47486115, 23.45874977], [68.47486115, 23.45903015], [68.4751358, 23.45902824], [68.4751358, 23.45930481], [68.47486115, 23.45930481], [68.47486115, 23.45958138], [68.47458649, 23.45958138], [68.47458649, 23.45986366], [68.47402954, 23.45986366], [68.47402954, 23.45958138], [68.47291565, 23.45958138], [68.47291565, 23.45930481], [68.47264099, 23.45930481], [68.47264099, 23.4584713], [68.4723587, 23.4584713], [68.4723587, 23.45763969], [68.47207642, 23.45763969], [68.47207642, 23.45568848], [68.47180939, 23.4556942], [68.47180176, 23.45513916], [68.4715271, 23.45513916], [68.4715271, 23.45486069], [68.47125244, 23.45486069], [68.47125244, 23.45458031], [68.47097015, 23.45458412], [68.47097015, 23.45430565], [68.47041321, 23.45431137], [68.47041321, 23.45402908], [68.46956635, 23.45402908], [68.46956635, 23.45431137], [68.46902466, 23.45430565], [68.46902466, 23.45458412], [68.46847534, 23.45458412], [68.46848297, 23.45486069], [68.46763611, 23.45486069], [68.46763611, 23.45513916], [68.46736145, 23.45513916], [68.46736145, 23.45542145], [68.46708679, 23.45541573], [68.46708679, 23.4556942], [68.4668045, 23.4556942], [68.4668045, 23.45597267], [68.46708679, 23.45597076], [68.46708679, 23.45654106], [68.46736145, 23.45652771], [68.46736145, 23.45708275], [68.46763611, 23.45708084], [68.46763611, 23.45735931], [68.4679184, 23.45735931], [68.4679184, 23.45792007], [68.46819305, 23.45791626], [68.46819305, 23.4584713], [68.4679184, 23.45846939], [68.4679184, 23.45874977], [68.46763611, 23.45874977], [68.46763611, 23.45846939], [68.46736145, 23.4584713], [68.46736145, 23.45819473], [68.46708679, 23.45819473], [68.46708679, 23.45763969], [68.46679688, 23.45763969], [68.46679688, 23.45708084], [68.46652985, 23.45708275], [68.46652985, 23.45680618], [68.46624756, 23.4568119], [68.46624756, 23.45624924], [68.4659729, 23.45624924], [68.4659729, 23.45568848], [68.46485901, 23.4556942], [68.46485901, 23.45541573], [68.46405029, 23.45541573], [68.46347046, 23.45542145], [68.46347046, 23.45513916], [68.46290588, 23.45513916], [68.46290588, 23.45486069], [68.46235657, 23.45486069], [68.46235657, 23.45458031], [68.46208191, 23.45458412], [68.46208191, 23.45430565], [68.46153259, 23.45431137], [68.46153259, 23.45402908], [68.4604187, 23.45402908], [68.4604187, 23.45375061], [68.45929718, 23.45375061], [68.45929718, 23.45347977], [68.45847321, 23.45347977], [68.45847321, 23.45318985], [68.45819092, 23.45319366], [68.45819092, 23.45263863], [68.45791626, 23.45264053], [68.45791626, 23.45207977], [68.4576416, 23.45208359], [68.4576416, 23.45180511], [68.45652771, 23.45181084], [68.45652771, 23.45153046], [68.45456696, 23.45153046], [68.45456696, 23.45125008], [68.45375061, 23.45125008], [68.45375061, 23.4509697], [68.45347595, 23.4509716], [68.45347595, 23.45069695], [68.45291901, 23.45070076], [68.45291901, 23.45041084], [68.45097351, 23.45041656], [68.45097351, 23.45013809], [68.45041656, 23.45014], [68.45041656, 23.44985962], [68.44930267, 23.44985962], [68.44930267, 23.45014], [68.44876099, 23.45014], [68.44876099, 23.4493103], [68.44847107, 23.44930077], [68.44847107, 23.44874954], [68.44819641, 23.44874954], [68.44819641, 23.44763947], [68.44790649, 23.44763947], [68.44790649, 23.44734955], [68.44736481, 23.4473629], [68.44736481, 23.44708252], [68.44708252, 23.44708252], [68.44708252, 23.44680405], [68.44680786, 23.44680977], [68.44680786, 23.44652939], [68.44625092, 23.44652939], [68.44625092, 23.44625282], [68.44596863, 23.44625282], [68.44596863, 23.44597054], [68.44513702, 23.44597054], [68.44513702, 23.44652939], [68.44486237, 23.44652939], [68.44486237, 23.44680977], [68.44346619, 23.44680977], [68.44346619, 23.44542122], [68.44403076, 23.44542122], [68.44403076, 23.44458008], [68.44347382, 23.44458389], [68.44347382, 23.44430542], [68.44291687, 23.44431114], [68.44291687, 23.44403267], [68.44235992, 23.44403267], [68.44235992, 23.44375038], [68.44180298, 23.44375038], [68.44180298, 23.44403267], [68.44152832, 23.44403267], [68.44152832, 23.44431114], [68.44097137, 23.44430542], [68.44097137, 23.44458389], [68.44069672, 23.44458008], [68.44069672, 23.44486046], [68.44013977, 23.44486046], [68.44013977, 23.44458008], [68.44041443, 23.44458389], [68.44041443, 23.44402695], [68.44069672, 23.44403267], [68.44069672, 23.44347191], [68.44097137, 23.44347191], [68.44097137, 23.44325066], [68.44097137, 23.44291687], [68.44124603, 23.44292259], [68.44124603, 23.44154167], [68.44097137, 23.44154167], [68.44097137, 23.44096947], [68.44041443, 23.44097137], [68.44041443, 23.44069481], [68.44013977, 23.44069481], [68.44013977, 23.44041634], [68.43985748, 23.44041824], [68.43985748, 23.44013977], [68.43958282, 23.44013977], [68.43958282, 23.4398613], [68.43930817, 23.4398613], [68.43930817, 23.43958282], [68.43902588, 23.43958282], [68.43902588, 23.43930626], [68.43930817, 23.43930817], [68.43930817, 23.43902969], [68.43985748, 23.43902969], [68.43985748, 23.43930817], [68.4404068, 23.43930817], [68.4404068, 23.43902969], [68.44013977, 23.43902969], [68.44013977, 23.43847084], [68.43985748, 23.43847275], [68.43985748, 23.43819427], [68.43958282, 23.43819427], [68.43958282, 23.43791771], [68.43930817, 23.43791962], [68.43930817, 23.43764114], [68.43902588, 23.43764114], [68.43902588, 23.43736076], [68.43875122, 23.43736076], [68.43875122, 23.43625069], [68.43846893, 23.43625069], [68.43846893, 23.43597031], [68.43819427, 23.43597221], [68.43819427, 23.43541718], [68.43791962, 23.43541718], [68.43791962, 23.43569565], [68.43763733, 23.43569565], [68.43763733, 23.43597221], [68.43736267, 23.43597031], [68.43733978, 23.43625069], [68.43708038, 23.43625069], [68.43708038, 23.43653107], [68.43653107, 23.43653107], [68.43653107, 23.43625069], [68.43624878, 23.43625069], [68.43624878, 23.43597031], [68.43597412, 23.43597221], [68.43597412, 23.43541718], [68.43624878, 23.43541718], [68.43624878, 23.43430328], [68.43596649, 23.43431091], [68.43596649, 23.43403053], [68.43569183, 23.43403053], [68.43569183, 23.43375015], [68.43514252, 23.43375015], [68.43514252, 23.43346977], [68.43486023, 23.43347168], [68.43486023, 23.43319321], [68.43152618, 23.43320084], [68.43152618, 23.43375015], [68.43125153, 23.43375015], [68.43125153, 23.43431091], [68.43013763, 23.43431091], [68.43013763, 23.43264008], [68.43041992, 23.43264008], [68.43041992, 23.43124962], [68.42986298, 23.43124962], [68.42986298, 23.43180466], [68.42958069, 23.43180275], [68.42958069, 23.43264008], [68.42930603, 23.43263817], [68.42930603, 23.43347168], [68.42903137, 23.43346977], [68.42903137, 23.43375015], [68.42847443, 23.43375015], [68.42847443, 23.4372406], [68.42847443, 23.43736076], [68.42765045, 23.43736076], [68.42765045, 23.43764114], [68.42708588, 23.43764114], [68.42708588, 23.43791962], [68.42680359, 23.43791771], [68.42680359, 23.43819427], [68.42624664, 23.43819427], [68.42624664, 23.43847275], [68.42597198, 23.43847084], [68.42597198, 23.43875122], [68.42542267, 23.43875122], [68.42542267, 23.43902969], [68.42514038, 23.43902969], [68.42514038, 23.43930817], [68.42458344, 23.43930626], [68.42458344, 23.43958282], [68.42430878, 23.43958282], [68.42430878, 23.4398613], [68.4201355, 23.4398613], [68.42014313, 23.44013977], [68.41874695, 23.44013977], [68.41874695, 23.43985939], [68.41819763, 23.4398613], [68.41819763, 23.43930626], [68.41845703, 23.43930817], [68.41845703, 23.43875122], [68.41874695, 23.43875122], [68.41874695, 23.43819046], [68.41902924, 23.43819427], [68.41902924, 23.43736076], [68.41929626, 23.43736076], [68.41931915, 23.43653107], [68.41958618, 23.43653107], [68.41958618, 23.43597031], [68.41986084, 23.43597221], [68.41986084, 23.43541718], [68.4201355, 23.43541718], [68.4201355, 23.4351387], [68.42041779, 23.43514061], [68.42041779, 23.43486023], [68.42069244, 23.43486023], [68.42069244, 23.43457985], [68.41958618, 23.43458557], [68.41958618, 23.43402863], [68.41986084, 23.43403053], [68.41986084, 23.43375015], [68.42014313, 23.43375015], [68.4201355, 23.43347168], [68.42152405, 23.43347168], [68.42152405, 23.43319321], [68.42430878, 23.43320084], [68.42430878, 23.43375015], [68.42459106, 23.43375015], [68.42459106, 23.43431091], [68.42624664, 23.43431091], [68.42624664, 23.43403053], [68.42682648, 23.43402863], [68.42708588, 23.43403053], [68.42708588, 23.43375015], [68.42765045, 23.43375015], [68.42763519, 23.43347168], [68.42819214, 23.43347168], [68.42819214, 23.43319321], [68.4284668, 23.43320084], [68.4284668, 23.43264008], [68.42874908, 23.43264008], [68.42874908, 23.43153191], [68.42903137, 23.43153191], [68.42903137, 23.43097115], [68.42874908, 23.43097115], [68.42874908, 23.43069458], [68.42791748, 23.43069458], [68.42791748, 23.43041611], [68.42765045, 23.43042183], [68.42765045, 23.43013954], [68.42736053, 23.43013954], [68.42736053, 23.42985916], [68.42708588, 23.42985916], [68.42708588, 23.42958069], [68.42680359, 23.4295826], [68.42680359, 23.42930603], [68.42652893, 23.42931175], [68.42652893, 23.42902946], [68.42624664, 23.42902946], [68.42624664, 23.42874908], [68.42597198, 23.42874908], [68.42597198, 23.42847061], [68.42541504, 23.42847252], [68.42541504, 23.42819405], [68.42514038, 23.42819405], [68.42514038, 23.42708397], [68.42485809, 23.42708397], [68.42485809, 23.4268055], [68.42459106, 23.42681122], [68.42459106, 23.42653084], [68.42402649, 23.42653084], [68.42402649, 23.42624092], [68.42208099, 23.42625046], [68.42208099, 23.42597198], [68.42180634, 23.42597198], [68.42180634, 23.42569351], [68.42152405, 23.42569351], [68.42152405, 23.42541885], [68.42124939, 23.42542076], [68.42124939, 23.42486], [68.42097473, 23.42486191], [68.42097473, 23.42430687], [68.42124939, 23.42431068], [68.42124939, 23.42374992], [68.42151642, 23.42374992], [68.42151642, 23.42346954], [68.42180634, 23.42347145], [68.42180634, 23.42319679], [68.42208099, 23.42319679], [68.42208099, 23.42236137], [68.42180634, 23.42236137], [68.42180634, 23.42180634], [68.42151642, 23.42181015], [68.42151642, 23.42152977], [68.42124939, 23.42152977], [68.42124939, 23.42124939], [68.42151642, 23.42124939], [68.42151642, 23.42069054], [68.42180634, 23.42069244], [68.42180634, 23.42041588], [68.42151642, 23.42043114], [68.42151642, 23.42014122], [68.42124939, 23.42014122], [68.42124939, 23.42043114], [68.42097473, 23.42041588], [68.42097473, 23.42069244], [68.42069244, 23.42069244], [68.42069244, 23.42097473], [68.42041779, 23.42097092], [68.42041779, 23.42124939], [68.42014313, 23.42124939], [68.42014313, 23.42152977], [68.41986084, 23.42152786], [68.41986084, 23.42208481], [68.41958618, 23.42208481], [68.41958618, 23.42236137], [68.41929626, 23.42235947], [68.41929626, 23.42292023], [68.41902924, 23.42291641], [68.41902924, 23.42347145], [68.41874695, 23.42347145], [68.41874695, 23.42486191], [68.41929626, 23.42486], [68.41929626, 23.42514038], [68.41958618, 23.42514038], [68.41958618, 23.42542076], [68.41986084, 23.42541885], [68.41986084, 23.42597198], [68.41958618, 23.42597198], [68.41958618, 23.42621994], [68.41958618, 23.42681122], [68.41986084, 23.42681122], [68.41986084, 23.42931175], [68.41911316, 23.42930603], [68.41680908, 23.42930603], [68.41680908, 23.4295826], [68.41707611, 23.42958069], [68.41707611, 23.42985916], [68.41625214, 23.42985916], [68.41625214, 23.42958069], [68.41596985, 23.4295826], [68.41596985, 23.42930603], [68.41513824, 23.42930603], [68.41513824, 23.4295826], [68.4154129, 23.4295826], [68.4154129, 23.43013954], [68.41571045, 23.43013954], [68.41571045, 23.43042183], [68.41596985, 23.43041611], [68.41596985, 23.43069458], [68.41486359, 23.43069458], [68.41486359, 23.43041611], [68.41430664, 23.43042183], [68.41430664, 23.43013954], [68.41385651, 23.43013954], [68.41374969, 23.43013954], [68.41374969, 23.43069458], [68.41347504, 23.43069458], [68.41348267, 23.43124962], [68.41319275, 23.43124962], [68.41319275, 23.43153191], [68.41291809, 23.43152809], [68.41291809, 23.43208122], [68.41265106, 23.43208122], [68.41265106, 23.43237114], [68.41291809, 23.43237114], [68.41291809, 23.43264008], [68.41319275, 23.43264008], [68.41319275, 23.43320084], [68.41347504, 23.43319321], [68.41347504, 23.43458557], [68.41374969, 23.43458557], [68.41374969, 23.43569565], [68.41347504, 23.43569565], [68.41348267, 23.43625069], [68.41319275, 23.43625069], [68.41319275, 23.43653107], [68.41401672, 23.43653107], [68.41401672, 23.43764114], [68.41374969, 23.43764114], [68.41374969, 23.43791962], [68.41347504, 23.43791771], [68.41347504, 23.43819427], [68.41319275, 23.43819046], [68.41319275, 23.43902969], [68.41291809, 23.43902969], [68.41291809, 23.44013977], [68.41265106, 23.44013977], [68.41265106, 23.44041824], [68.41236115, 23.44041634], [68.41236115, 23.44069481], [68.41208649, 23.44068909], [68.41208649, 23.44124985], [68.41179657, 23.44124985], [68.41179657, 23.44154167], [68.41152954, 23.44152832], [68.41152954, 23.44180489], [68.41208649, 23.44180489], [68.41208649, 23.44347191], [68.4126358, 23.44347191], [68.4126358, 23.44375038], [68.41319275, 23.44375038], [68.41319275, 23.44347191], [68.41347504, 23.44347191], [68.41347504, 23.44319534], [68.41430664, 23.44320107], [68.41430664, 23.44375038], [68.4145813, 23.44375038], [68.4145813, 23.44431114], [68.41530609, 23.44430733], [68.41569519, 23.44430542], [68.41569519, 23.44458389], [68.41625214, 23.44458008], [68.41625214, 23.44486046], [68.41652679, 23.44486046], [68.41652679, 23.44514275], [68.41680908, 23.44514275], [68.41680908, 23.44542122], [68.41708374, 23.4454174], [68.41708374, 23.44597435], [68.41791534, 23.44597435], [68.41791534, 23.44569206], [68.41847229, 23.44569206], [68.41847229, 23.4454174], [68.41874695, 23.44542122], [68.41874695, 23.44514275], [68.41929626, 23.44514275], [68.41929626, 23.44486046], [68.41986084, 23.44486046], [68.41986084, 23.44597435], [68.4201355, 23.44597435], [68.4201355, 23.44569206], [68.42041779, 23.44569206], [68.42041779, 23.4454174], [68.42069244, 23.44542122], [68.42069244, 23.44458008], [68.42124939, 23.44458008], [68.42124939, 23.44486046], [68.42152405, 23.44486046], [68.42152405, 23.44569206], [68.42208099, 23.44569206], [68.42208099, 23.44513893], [68.42236328, 23.44514275], [68.42236328, 23.44431114], [68.42292023, 23.44430542], [68.42292023, 23.44458389], [68.42319489, 23.44458389], [68.42319489, 23.44672966], [68.42319489, 23.4473629], [68.42375183, 23.4473629], [68.42375183, 23.44680405], [68.42402649, 23.44680977], [68.42402649, 23.44625282], [68.42458344, 23.44625282], [68.42458344, 23.44763947], [68.42485809, 23.44763947], [68.42485809, 23.44734955], [68.42514038, 23.4473629], [68.42514038, 23.44680405], [68.42542267, 23.44680977], [68.42542267, 23.44652939], [68.42569733, 23.44652939], [68.42569733, 23.44597054], [68.42597198, 23.44597435], [68.42597198, 23.44569206], [68.42624664, 23.44569206], [68.42624664, 23.44513893], [68.42652893, 23.44514275], [68.42652893, 23.44486046], [68.42679596, 23.44486046], [68.42679596, 23.44431114], [68.42708588, 23.44431114], [68.42708588, 23.44320107], [68.42736053, 23.44320107], [68.42736053, 23.44292259], [68.42791748, 23.44292259], [68.42791748, 23.4426403], [68.4284668, 23.4426403], [68.4284668, 23.44235992], [68.42874908, 23.44236183], [68.42874908, 23.44069481], [68.42903137, 23.44069481], [68.42903137, 23.44041634], [68.42930603, 23.44041824], [68.42930603, 23.44013977], [68.42986298, 23.44013977], [68.42986298, 23.44041824], [68.43004608, 23.44041824], [68.43125153, 23.44041824], [68.43125153, 23.43985939]]], [[[68.48069763, 23.50125122], [68.48069763, 23.50097084], [68.48124695, 23.50097466], [68.48124695, 23.50069237], [68.48180389, 23.50069237], [68.48180389, 23.5004158], [68.48236084, 23.50041962], [68.48236084, 23.50014114], [68.48264313, 23.50014114], [68.48264313, 23.49986076], [68.48291779, 23.49986076], [68.48291779, 23.49930954], [68.48319244, 23.49930954], [68.48319244, 23.49903107], [68.4834671, 23.49903107], [68.4834671, 23.49875069], [68.48374939, 23.49875069], [68.48374939, 23.49819183], [68.48402405, 23.49819374], [68.48402405, 23.49736023], [68.48430634, 23.49736023], [68.48430634, 23.49653244], [68.48458099, 23.49653244], [68.48458099, 23.49625015], [68.48486328, 23.49625015], [68.48486328, 23.49596977], [68.48513794, 23.49597168], [68.48513794, 23.49569511], [68.48542023, 23.49571037], [68.48542023, 23.49541855], [68.48568726, 23.49541855], [68.48568726, 23.4948597], [68.48542023, 23.4948616], [68.48542023, 23.49430466], [68.48513794, 23.49430466], [68.48513794, 23.49291611], [68.48542023, 23.49291992], [68.48542023, 23.49264908], [68.48568726, 23.49264908], [68.48568726, 23.49125099], [68.48542023, 23.49125099], [68.48542023, 23.49069023], [68.48513794, 23.49069595], [68.48513794, 23.48875046], [68.48542023, 23.48875046], [68.48542023, 23.48820114], [68.48568726, 23.4881897], [68.48569489, 23.48763847], [68.48596954, 23.48764038], [68.48596954, 23.48707962], [68.48625183, 23.48708534], [68.48625183, 23.4865284], [68.48652649, 23.4865284], [68.48652649, 23.48624992], [68.48680878, 23.48624992], [68.48680878, 23.48596954], [68.48652649, 23.48597145], [68.48652649, 23.48569489], [68.48625183, 23.48569489], [68.48625183, 23.48541641], [68.48596954, 23.48542023], [68.48596954, 23.48513985], [68.48568726, 23.48513985], [68.48568726, 23.48485947], [68.48542023, 23.48486137], [68.48542023, 23.48430634], [68.48513794, 23.48431015], [68.48513794, 23.4840107], [68.48513794, 23.48347282], [68.48486328, 23.48347282], [68.48486328, 23.48319435], [68.48458099, 23.48319435], [68.48458099, 23.48291588], [68.48430634, 23.4829216], [68.48430634, 23.48263931], [68.48401642, 23.48263931], [68.48401642, 23.48236084], [68.48374939, 23.48236084], [68.48374939, 23.48208046], [68.48347473, 23.48208237], [68.48347473, 23.48152733], [68.48319244, 23.48152924], [68.48319244, 23.48097038], [68.48291779, 23.48097229], [68.48291779, 23.48069382], [68.4826355, 23.48069382], [68.4826355, 23.48041725], [68.48236084, 23.48041916], [68.48236084, 23.47986031], [68.48208618, 23.47986031], [68.48208618, 23.47957993], [68.48180389, 23.47958374], [68.48180389, 23.4790287], [68.48152924, 23.47903061], [68.48152924, 23.47846985], [68.48124695, 23.47847176], [68.48124695, 23.47791672], [68.47957611, 23.47792053], [68.47957611, 23.47820091], [68.47875214, 23.47819519], [68.47875214, 23.47847176], [68.4779129, 23.47846985], [68.4779129, 23.47875023], [68.4770813, 23.47875023], [68.4770813, 23.47903061], [68.47680664, 23.47903061], [68.47680664, 23.47930908], [68.47624969, 23.47930527], [68.47624969, 23.47958374], [68.47597504, 23.47958374], [68.4759903, 23.47986031], [68.47541809, 23.47986031], [68.47541809, 23.48014069], [68.4751358, 23.48014069], [68.4751358, 23.48041916], [68.47458649, 23.48041725], [68.47458649, 23.48069382], [68.4743042, 23.48069382], [68.4743042, 23.48097229], [68.47403717, 23.48097038], [68.47402954, 23.48152924], [68.47374725, 23.48152924], [68.47374725, 23.48181152], [68.47458649, 23.4818058], [68.47458649, 23.48208427], [68.47486115, 23.48208046], [68.47486115, 23.48236084], [68.47541809, 23.48236084], [68.47541809, 23.48263931], [68.47570038, 23.48263931], [68.47570038, 23.4829216], [68.47541809, 23.4829216], [68.47541809, 23.48403168], [68.4751358, 23.48403168], [68.4751358, 23.48513985], [68.47541809, 23.48513985], [68.47541809, 23.48569489], [68.47597504, 23.48569489], [68.47597504, 23.48597145], [68.47624969, 23.48596954], [68.47624969, 23.48624992], [68.4770813, 23.48624992], [68.4770813, 23.48596954], [68.47763824, 23.48597145], [68.47763824, 23.48569489], [68.4798584, 23.48569107], [68.4798584, 23.48624992], [68.48097229, 23.48624992], [68.48097229, 23.4865284], [68.48124695, 23.4865284], [68.48124695, 23.48624992], [68.48152924, 23.48624992], [68.48152924, 23.48596954], [68.48180389, 23.48597145], [68.48180389, 23.48569489], [68.48208618, 23.48569489], [68.48208618, 23.48541641], [68.48374939, 23.48542023], [68.48374939, 23.48513985], [68.48458099, 23.48513985], [68.48458099, 23.48569489], [68.48486328, 23.48569107], [68.48486328, 23.48624992], [68.48513794, 23.48624992], [68.48513794, 23.48764038], [68.48486328, 23.48763847], [68.48486328, 23.48819542], [68.48458099, 23.4881897], [68.48458099, 23.48903084], [68.48430634, 23.48902512], [68.48430634, 23.49069595], [68.48401642, 23.49069023], [68.48401642, 23.49125099], [68.48374939, 23.49125099], [68.48374939, 23.49152946], [68.48264313, 23.49152946], [68.48264313, 23.49041939], [68.48236084, 23.49041939], [68.48236084, 23.48986053], [68.48208618, 23.48986053], [68.48208618, 23.48931122], [68.48179626, 23.48931122], [68.48179626, 23.48903084], [68.48097229, 23.48903084], [68.48097229, 23.48875046], [68.47763824, 23.48875046], [68.47763824, 23.48847008], [68.47680664, 23.48847389], [68.47680664, 23.48791695], [68.47651672, 23.48792076], [68.47651672, 23.48736], [68.47624969, 23.48736382], [68.47624969, 23.48708534], [68.47569275, 23.48708534], [68.47569275, 23.48680305], [68.4751358, 23.48681068], [68.4751358, 23.48652267], [68.47486115, 23.48652267], [68.47486115, 23.48681068], [68.47458649, 23.48680305], [68.47458649, 23.48736382], [68.4743042, 23.48736382], [68.4743042, 23.48847389], [68.47458649, 23.48847008], [68.47458649, 23.48903084], [68.47486115, 23.48903084], [68.47486115, 23.48986053], [68.47429657, 23.48986053], [68.47429657, 23.48958969], [68.47402954, 23.48958969], [68.47402954, 23.49236107], [68.47374725, 23.49236107], [68.47374725, 23.49264908], [68.4734726, 23.49263954], [68.4734726, 23.49319458], [68.47319794, 23.49319077], [68.47319794, 23.49374962], [68.47292328, 23.49374962], [68.47292328, 23.49402809], [68.47319794, 23.49402809], [68.47319794, 23.4948616], [68.4734726, 23.4948597], [68.4734726, 23.49625015], [68.47374725, 23.49625015], [68.47374725, 23.49596977], [68.47402954, 23.49597168], [68.47402954, 23.49569511], [68.47429657, 23.49571037], [68.47429657, 23.49541855], [68.47458649, 23.49541855], [68.47458649, 23.49513817], [68.4751358, 23.49513817], [68.4751358, 23.4948597], [68.47680664, 23.4948616], [68.47680664, 23.49458313], [68.4770813, 23.49458313], [68.4770813, 23.49347305], [68.47736359, 23.49347305], [68.47736359, 23.49291611], [68.47763824, 23.49291992], [68.47763824, 23.49236107], [68.47846985, 23.49236107], [68.47846985, 23.49208069], [68.47902679, 23.4920826], [68.47902679, 23.49180794], [68.4798584, 23.49180984], [68.4798584, 23.49152946], [68.48152924, 23.49152946], [68.48152924, 23.49180984], [68.48124695, 23.49180984], [68.48124695, 23.49236107], [68.48152924, 23.49236107], [68.48152924, 23.49291992], [68.48180389, 23.49291611], [68.48180389, 23.49347305], [68.48208618, 23.49347115], [68.48208618, 23.49402809], [68.48236084, 23.49402809], [68.48236084, 23.49541855], [68.48124695, 23.49541855], [68.48124695, 23.49571037], [68.48069763, 23.49569511], [68.48069763, 23.49597168], [68.48014069, 23.49596977], [68.48014069, 23.49625015], [68.47930908, 23.49625015], [68.47930908, 23.49653244], [68.47875977, 23.49653244], [68.47875977, 23.49681282], [68.47846985, 23.49681282], [68.47846985, 23.49736023], [68.47875977, 23.49736023], [68.47875977, 23.4979229], [68.47846985, 23.49791718], [68.47846985, 23.49819374], [68.47819519, 23.49819374], [68.47819519, 23.49875069], [68.47846985, 23.49875069], [68.47846985, 23.49903107], [68.47875977, 23.49903107], [68.47875977, 23.49930954], [68.4798584, 23.49930573], [68.4798584, 23.49958229], [68.48014069, 23.49958038], [68.48014069, 23.50041962], [68.48042297, 23.50041962], [68.48042297, 23.50125122], [68.48069763, 23.50125122]]], [[[68.48680878, 23.49541855], [68.48680878, 23.49513817], [68.48707581, 23.49513817], [68.48707581, 23.4948597], [68.48735809, 23.4948616], [68.48735809, 23.49458313], [68.48764038, 23.49458313], [68.48764038, 23.49402809], [68.4879303, 23.49402809], [68.4879303, 23.49319077], [68.48764038, 23.49319458], [68.48764038, 23.49236107], [68.48847198, 23.49236107], [68.48847198, 23.49291992], [68.48874664, 23.49291611], [68.48874664, 23.49319458], [68.48902893, 23.49319458], [68.48902893, 23.49347305], [68.48929596, 23.49347115], [68.48929596, 23.49374962], [68.48958588, 23.49374962], [68.48958588, 23.49180984], [68.48929596, 23.49180984], [68.48929596, 23.49097061], [68.48902893, 23.49097252], [68.48902893, 23.49013901], [68.48874664, 23.49014091], [68.48874664, 23.48931122], [68.48847198, 23.48931122], [68.48847198, 23.4881897], [68.48819733, 23.48819542], [68.48819733, 23.48736382], [68.48791504, 23.48736382], [68.48791504, 23.48680305], [68.48764038, 23.48681068], [68.48764038, 23.48652267], [68.48708344, 23.4865284], [68.48708344, 23.48736382], [68.48680878, 23.48736], [68.48680878, 23.48764038], [68.48652649, 23.48763847], [68.48652649, 23.48847389], [68.48625183, 23.48847008], [68.48625183, 23.48903084], [68.48596954, 23.48903084], [68.48596954, 23.49041939], [68.48625183, 23.49041748], [68.48625183, 23.49097252], [68.48652649, 23.49097061], [68.48652649, 23.49264908], [68.48625183, 23.49263954], [68.48625183, 23.49319458], [68.48596954, 23.49319077], [68.48596954, 23.49402809], [68.48625183, 23.49402809], [68.48625183, 23.4948616], [68.48652649, 23.4948597], [68.48652649, 23.49541855], [68.48680878, 23.49541855]]], [[[68.50653076, 23.49264908], [68.50653076, 23.49236107], [68.50736237, 23.49236107], [68.50736237, 23.49208069], [68.50763702, 23.4920826], [68.50763702, 23.49180794], [68.50791931, 23.49180984], [68.50791931, 23.49152946], [68.50818634, 23.49152946], [68.50818634, 23.49125099], [68.50846863, 23.49125099], [68.50846863, 23.49097061], [68.50875092, 23.49097252], [68.50875092, 23.49069595], [68.50902557, 23.49069595], [68.50902557, 23.49041748], [68.50680542, 23.49041748], [68.50680542, 23.49097252], [68.50653076, 23.49097061], [68.50653076, 23.49125099], [68.50624847, 23.49124908], [68.50624847, 23.4920826], [68.50596619, 23.49208069], [68.50596619, 23.49264908], [68.50653076, 23.49264908]]], [[[68.51097107, 23.49264908], [68.51097107, 23.49236107], [68.51152802, 23.49236107], [68.51152802, 23.49125099], [68.51125336, 23.49125099], [68.51125336, 23.49069023], [68.51069641, 23.49069595], [68.51069641, 23.49097252], [68.51013947, 23.49097061], [68.51013947, 23.49152946], [68.50985718, 23.49152946], [68.50985718, 23.49180984], [68.50958252, 23.49180794], [68.50958252, 23.4920826], [68.50930786, 23.49208069], [68.50930786, 23.49264908], [68.51097107, 23.49264908]]], [[[68.4751358, 23.52876091], [68.4751358, 23.52847099], [68.47597504, 23.52847481], [68.47597504, 23.52791405], [68.47624969, 23.52791977], [68.47624969, 23.52763939], [68.47541809, 23.52763939], [68.47541809, 23.52736092], [68.47486115, 23.52736092], [68.47486115, 23.52708054], [68.47458649, 23.52708244], [68.47458649, 23.52680588], [68.47429657, 23.52680969], [68.47429657, 23.52653122], [68.47402954, 23.52653122], [68.47402954, 23.52625275], [68.47429657, 23.52625275], [68.47429657, 23.52597046], [68.47402954, 23.52597237], [68.47402954, 23.52541733], [68.47429657, 23.52542114], [68.47429657, 23.52403259], [68.47458649, 23.52403259], [68.47458649, 23.52207756], [68.47374725, 23.52208328], [68.47374725, 23.52152824], [68.4734726, 23.52152824], [68.4734726, 23.52180481], [68.47319794, 23.52180481], [68.47319794, 23.52208328], [68.47264099, 23.52208328], [68.47264099, 23.52124977], [68.47207642, 23.52124977], [68.47207642, 23.52096748], [68.47180939, 23.5209713], [68.47180176, 23.52069473], [68.4715271, 23.52069092], [68.4715271, 23.52152824], [68.47125244, 23.52152824], [68.47125244, 23.52180481], [68.47097015, 23.52180481], [68.47097015, 23.52208328], [68.4706955, 23.52208328], [68.4706955, 23.52236176], [68.46986389, 23.52236176], [68.46986389, 23.52263832], [68.46956635, 23.52263069], [68.46956635, 23.52292252], [68.46930695, 23.52292252], [68.46930695, 23.5232029], [68.46901703, 23.5232029], [68.46901703, 23.52403259], [68.46875, 23.52402687], [68.46875, 23.52458382], [68.4695816, 23.52458382], [68.4695816, 23.52430534], [68.46985626, 23.52431107], [68.46985626, 23.52403259], [68.47041321, 23.52402687], [68.47041321, 23.52458382], [68.46986389, 23.52458382], [68.46986389, 23.52569389], [68.47013855, 23.52569008], [68.47013855, 23.52625275], [68.47041321, 23.52625275], [68.47041321, 23.52680969], [68.4706955, 23.52680588], [68.4706955, 23.52708244], [68.47180176, 23.52708244], [68.47180939, 23.5265274], [68.47207642, 23.52653122], [68.47207642, 23.52625275], [68.47264099, 23.52625275], [68.47264099, 23.52736092], [68.4723587, 23.52736092], [68.4723587, 23.52763939], [68.47207642, 23.52763939], [68.47207642, 23.52791977], [68.47180176, 23.52791405], [68.47180176, 23.52847481], [68.4723587, 23.52847099], [68.4723587, 23.52876091], [68.4751358, 23.52876091]]], [[[68.4734726, 23.53708267], [68.4734726, 23.53652763], [68.47374725, 23.53652954], [68.47374725, 23.53624916], [68.47402954, 23.53624916], [68.47402954, 23.53597069], [68.4743042, 23.5359726], [68.4743042, 23.53513908], [68.47458649, 23.53513908], [68.47458649, 23.53457069], [68.47486115, 23.53458405], [68.47486115, 23.53430557], [68.4751358, 23.53430748], [68.4751358, 23.53403091], [68.47486115, 23.53403091], [68.47486115, 23.53292084], [68.47569275, 23.53291893], [68.47569275, 23.53319359], [68.47624969, 23.53319359], [68.47624969, 23.53291893], [68.47651672, 23.53292084], [68.47651672, 23.5320797], [68.47624969, 23.53208351], [68.47624969, 23.53180695], [68.4759903, 23.53181839], [68.4759903, 23.53153038], [68.47570038, 23.53153038], [68.47570038, 23.53096962], [68.4751358, 23.53097153], [68.4751358, 23.53069687], [68.47486115, 23.53070068], [68.47486115, 23.5304203], [68.47319794, 23.5304203], [68.47319794, 23.53070068], [68.47291565, 23.53069687], [68.47291565, 23.53097153], [68.47207642, 23.53096962], [68.47207642, 23.53125], [68.4723587, 23.53125], [68.4723587, 23.53181839], [68.47264099, 23.53180695], [68.47264099, 23.53236198], [68.47319794, 23.53236008], [68.47319794, 23.53264046], [68.4734726, 23.53264046], [68.4734726, 23.53292084], [68.47319794, 23.53291893], [68.47319794, 23.53319359], [68.47207642, 23.53318977], [68.47207642, 23.53375053], [68.47180176, 23.53375053], [68.47180176, 23.53458405], [68.47208405, 23.53458405], [68.47208405, 23.53569412], [68.47180176, 23.5356884], [68.47180176, 23.53624916], [68.47264099, 23.53624916], [68.47264099, 23.53652954], [68.47291565, 23.53652763], [68.47291565, 23.53708267], [68.4734726, 23.53708267]]], [[[68.47930908, 23.55541992], [68.47930908, 23.55486107], [68.47957611, 23.55486107], [68.47957611, 23.55430984], [68.4798584, 23.55430984], [68.4798584, 23.5537529], [68.48069763, 23.5537529], [68.48069763, 23.55402946], [68.48097229, 23.55402946], [68.48097229, 23.5537529], [68.48124695, 23.5537529], [68.48124695, 23.55347061], [68.48152924, 23.55347443], [68.48152924, 23.55125046], [68.48124695, 23.55125046], [68.48124695, 23.55014038], [68.48097229, 23.55014038], [68.48097229, 23.54931259], [68.47930908, 23.54931259], [68.47930908, 23.54791832], [68.4798584, 23.54791832], [68.4798584, 23.54597092], [68.48014069, 23.54597282], [68.48014069, 23.54513931], [68.47902679, 23.54514122], [68.47902679, 23.54458046], [68.47875214, 23.54458237], [68.47875214, 23.54347229], [68.47846985, 23.54347229], [68.47846985, 23.54291725], [68.47763824, 23.54291725], [68.47763824, 23.54319572], [68.4770813, 23.54319572], [68.4770813, 23.54347229], [68.47624969, 23.54347229], [68.47624969, 23.54291725], [68.47651672, 23.54292107], [68.47651672, 23.54236031], [68.47680664, 23.54236031], [68.47680664, 23.54207993], [68.4770813, 23.54208565], [68.4770813, 23.54180336], [68.47735596, 23.54181099], [68.47735596, 23.54096985], [68.47680664, 23.54097176], [68.47680664, 23.54041672], [68.47651672, 23.54042053], [68.47651672, 23.53985977], [68.47624969, 23.53986359], [68.47624969, 23.53930473], [68.47597504, 23.53930473], [68.47597504, 23.53902817], [68.47570038, 23.53903008], [68.47570038, 23.53874969], [68.47541809, 23.53874969], [68.47541809, 23.53847122], [68.47486115, 23.53847122], [68.47486115, 23.53819466], [68.4743042, 23.53819466], [68.4743042, 23.53791618], [68.47402954, 23.53791618], [68.47402954, 23.53819466], [68.47374725, 23.53819466], [68.47374725, 23.53847122], [68.47264099, 23.53847122], [68.47264099, 23.53819466], [68.47208405, 23.53819466], [68.47208405, 23.53847122], [68.47180176, 23.53847122], [68.47180176, 23.53874969], [68.4706955, 23.53874969], [68.4706955, 23.53847122], [68.47041321, 23.53847122], [68.47041321, 23.53874969], [68.46956635, 23.53874969], [68.46956635, 23.53819275], [68.46902466, 23.53819466], [68.46902466, 23.53791618], [68.46875, 23.53792191], [68.46875, 23.53762817], [68.46819305, 23.53763962], [68.46819305, 23.53735924], [68.46763611, 23.53735924], [68.46763611, 23.53708076], [68.46736145, 23.53708267], [68.46736145, 23.53680611], [68.46708679, 23.53681183], [68.46708679, 23.53652954], [68.46652985, 23.53652954], [68.46652985, 23.53624916], [68.4659729, 23.53624916], [68.4659729, 23.53597069], [68.46569824, 23.5359726], [68.46569824, 23.53569412], [68.4651413, 23.53569412], [68.4651413, 23.53513908], [68.46457672, 23.53513908], [68.46457672, 23.53541946], [68.46430206, 23.53541756], [68.46430206, 23.5359726], [68.46375275, 23.5359726], [68.46375275, 23.53541756], [68.46347046, 23.53541946], [68.46347046, 23.53513908], [68.46290588, 23.53513908], [68.46290588, 23.53486061], [68.46263885, 23.53486061], [68.46263885, 23.53430748], [68.46290588, 23.53430748], [68.46290588, 23.53375053], [68.46263885, 23.53375053], [68.46263885, 23.53347015], [68.4623642, 23.53347206], [68.4623642, 23.53319359], [68.46180725, 23.53319359], [68.46180725, 23.53263855], [68.46125031, 23.53264046], [68.46125031, 23.53236008], [68.46097565, 23.53236198], [68.46097565, 23.53208351], [68.4604187, 23.53208351], [68.4604187, 23.53152847], [68.45986176, 23.53153038], [68.45986176, 23.53125], [68.4595871, 23.53125], [68.4595871, 23.53096962], [68.45903015, 23.53097153], [68.45903015, 23.53069687], [68.45874786, 23.53069687], [68.45874786, 23.53097153], [68.45819092, 23.53097153], [68.45819092, 23.53069687], [68.45680237, 23.53070068], [68.45680237, 23.53013992], [68.45652771, 23.53013992], [68.45652771, 23.5304203], [68.45597076, 23.5304203], [68.45597076, 23.53013992], [68.45485687, 23.53013992], [68.45485687, 23.52985954], [68.45458221, 23.52986145], [68.45458221, 23.52958488], [68.45430756, 23.52958488], [68.45430756, 23.52930641], [68.45375061, 23.52931023], [68.45375061, 23.52876091], [68.45319366, 23.52874947], [68.45319366, 23.52986145], [68.45347595, 23.52985954], [68.45347595, 23.5304203], [68.45375061, 23.5304203], [68.45375061, 23.53070068], [68.45402527, 23.53069687], [68.45402527, 23.53125], [68.45458221, 23.53125], [68.45456696, 23.53096962], [68.45625305, 23.53096962], [68.45625305, 23.53153038], [68.45707703, 23.53153038], [68.45707703, 23.53181839], [68.45735931, 23.53180695], [68.45735931, 23.53208351], [68.45762634, 23.5320797], [68.45762634, 23.53292084], [68.45735931, 23.53291893], [68.45735931, 23.53347206], [68.45762634, 23.53347015], [68.45762634, 23.53403091], [68.45819092, 23.53403091], [68.45819092, 23.5320797], [68.45874786, 23.53208351], [68.45874786, 23.53236198], [68.45903015, 23.53236008], [68.45903015, 23.53264046], [68.45929718, 23.53264046], [68.45929718, 23.53292084], [68.4595871, 23.53292084], [68.4595871, 23.53236008], [68.46013641, 23.53236008], [68.46013641, 23.53292084], [68.4604187, 23.53291893], [68.4604187, 23.53347206], [68.46013641, 23.53347206], [68.46013641, 23.53458405], [68.46069336, 23.53458405], [68.46069336, 23.5340271], [68.46098328, 23.53403091], [68.46098328, 23.53375053], [68.46180725, 23.53375053], [68.46180725, 23.53458405], [68.46153259, 23.53457069], [68.46153259, 23.53513908], [68.46098328, 23.53513908], [68.46098328, 23.53541946], [68.4604187, 23.53541756], [68.4604187, 23.53569412], [68.4595871, 23.53569412], [68.4595871, 23.5359726], [68.45929718, 23.53597069], [68.45929718, 23.53624916], [68.45903015, 23.53624916], [68.45903015, 23.53681183], [68.45819092, 23.53681183], [68.45819092, 23.53652954], [68.45762634, 23.53652954], [68.45762634, 23.53624916], [68.45680237, 23.53624916], [68.45680237, 23.53597069], [68.45597076, 23.5359726], [68.45597076, 23.53569412], [68.4548645, 23.53569412], [68.4548645, 23.53541756], [68.45458221, 23.53541756], [68.45458221, 23.53569412], [68.45430756, 23.5356884], [68.45430756, 23.53624916], [68.4540329, 23.53624916], [68.4540329, 23.53652954], [68.45375061, 23.53652954], [68.45375061, 23.53681183], [68.45347595, 23.53681183], [68.45347595, 23.53792191], [68.45456696, 23.53792191], [68.45456696, 23.53762817], [68.4548645, 23.53763962], [68.4548645, 23.53735924], [68.45513916, 23.53735924], [68.45513916, 23.53708076], [68.45652771, 23.53708076], [68.45652771, 23.53735924], [68.45708466, 23.53735924], [68.45708466, 23.53763962], [68.45735931, 23.53763962], [68.45735931, 23.53819466], [68.4576416, 23.53819466], [68.4576416, 23.5395813], [68.45847321, 23.5395813], [68.45847321, 23.53986359], [68.45874786, 23.53985977], [68.45874786, 23.54014015], [68.45903015, 23.54014015], [68.45903015, 23.54042053], [68.45791626, 23.54042053], [68.45791626, 23.54070091], [68.45735931, 23.54070091], [68.45735931, 23.54125023], [68.45708466, 23.54125023], [68.45708466, 23.54208565], [68.45735931, 23.54207993], [68.45735931, 23.54264069], [68.45791626, 23.54264069], [68.45791626, 23.54292107], [68.45903015, 23.54291725], [68.45903015, 23.54319572], [68.4595871, 23.54319572], [68.4595871, 23.54347229], [68.46013641, 23.54347038], [68.46013641, 23.5437603], [68.4604187, 23.5437603], [68.4604187, 23.54403114], [68.46098328, 23.54403114], [68.46098328, 23.54430962], [68.46125031, 23.54430771], [68.46125031, 23.54458427], [68.46180725, 23.54458046], [68.46180725, 23.54486084], [68.46235657, 23.54486084], [68.46235657, 23.54514122], [68.46290588, 23.54514122], [68.46290588, 23.54541969], [68.46347046, 23.54541779], [68.46347046, 23.54569435], [68.46430206, 23.54569435], [68.46430206, 23.54597282], [68.46457672, 23.54597092], [68.46457672, 23.54652977], [68.46485901, 23.54652977], [68.46485901, 23.54680634], [68.4651413, 23.54680634], [68.4651413, 23.5470829], [68.46569061, 23.5470829], [68.46569824, 23.54736137], [68.4659729, 23.54735947], [68.4659729, 23.54763985], [68.46652985, 23.54763985], [68.46652985, 23.54791832], [68.4668045, 23.54791641], [68.4668045, 23.54819489], [68.46736145, 23.54819489], [68.46736145, 23.54847145], [68.4679184, 23.54846954], [68.4679184, 23.54874992], [68.46875, 23.54874992], [68.46875, 23.54846954], [68.46956635, 23.54846954], [68.46956635, 23.5490284], [68.46930695, 23.5490284], [68.46930695, 23.55014038], [68.4695816, 23.55013847], [68.46956635, 23.5506916], [68.46985626, 23.55070114], [68.46985626, 23.55125046], [68.47013855, 23.55125046], [68.47013855, 23.55236053], [68.47041321, 23.55236053], [68.47041321, 23.55347443], [68.4715271, 23.55347061], [68.4715271, 23.5537529], [68.47319794, 23.5537529], [68.47319794, 23.55402946], [68.47374725, 23.55402946], [68.47374725, 23.55430984], [68.47458649, 23.55430412], [68.47458649, 23.5545826], [68.47541809, 23.55458069], [68.47541809, 23.55486107], [68.4759903, 23.55486107], [68.47597504, 23.5545826], [68.4770813, 23.55458069], [68.4770813, 23.55486107], [68.47763824, 23.55486107], [68.47763824, 23.55513954], [68.47875977, 23.55513954], [68.47875977, 23.55541992], [68.47930908, 23.55541992]]], [[[68.48236084, 23.55042267], [68.48236084, 23.54986191], [68.4826355, 23.54986191], [68.4826355, 23.54958344], [68.48291779, 23.54958344], [68.48291779, 23.54930496], [68.48319244, 23.54931259], [68.48319244, 23.54874992], [68.48291779, 23.54874992], [68.48291779, 23.54735947], [68.4826355, 23.54736137], [68.4826355, 23.5470829], [68.48208618, 23.5470829], [68.48208618, 23.54736137], [68.48180389, 23.54736137], [68.48180389, 23.54819489], [68.48152924, 23.54818916], [68.48152924, 23.54874992], [68.48180389, 23.54874992], [68.48180389, 23.54958344], [68.48208618, 23.54956818], [68.48208618, 23.55042267], [68.48236084, 23.55042267]]], [[[68.4734726, 23.56292152], [68.4734726, 23.56236076], [68.47374725, 23.56236076], [68.47374725, 23.5617981], [68.47402954, 23.56180573], [68.47402954, 23.56152725], [68.47429657, 23.56152916], [68.47429657, 23.56041908], [68.47458649, 23.56041908], [68.47458649, 23.55931091], [68.47429657, 23.55931091], [68.47429657, 23.55874062], [68.47402954, 23.55875015], [68.47402954, 23.55819511], [68.47374725, 23.55820084], [68.47374725, 23.55792046], [68.47319794, 23.55792046], [68.47319794, 23.55764008], [68.47125244, 23.55764008], [68.47125244, 23.55792046], [68.47097015, 23.55792046], [68.47097015, 23.55820084], [68.46875, 23.55820084], [68.46875, 23.55708122], [68.46902466, 23.55708313], [68.46902466, 23.55652809], [68.47070313, 23.55653], [68.47070313, 23.55624962], [68.47125244, 23.55624962], [68.47125244, 23.5557003], [68.47097015, 23.5557003], [68.47097015, 23.55541992], [68.47070313, 23.55541992], [68.47070313, 23.55513954], [68.47013855, 23.55513954], [68.47013855, 23.55486107], [68.46956635, 23.55486107], [68.46956635, 23.55458069], [68.46930695, 23.5545826], [68.46930695, 23.55430412], [68.46901703, 23.55430984], [68.46901703, 23.55402946], [68.46875, 23.55402946], [68.46875, 23.5537529], [68.46848297, 23.5537529], [68.46848297, 23.55319023], [68.46819305, 23.55319214], [68.46819305, 23.55291748], [68.46763611, 23.55293083], [68.46763611, 23.55264282], [68.46736145, 23.55264282], [68.46736145, 23.55236053], [68.46679688, 23.55236053], [68.46679688, 23.55208015], [68.46652985, 23.55208206], [68.46652985, 23.5518055], [68.46624756, 23.55181122], [68.46624756, 23.55153275], [68.46541595, 23.55153275], [68.46541595, 23.55125046], [68.46485901, 23.55125046], [68.46485901, 23.55097008], [68.46430206, 23.55097008], [68.46430206, 23.55069351], [68.46347046, 23.55069351], [68.46347046, 23.55097008], [68.4631958, 23.55097008], [68.4631958, 23.5537529], [68.46290588, 23.5537529], [68.46290588, 23.55402946], [68.46180725, 23.55402946], [68.46180725, 23.55236053], [68.46208191, 23.55236053], [68.46208191, 23.55125046], [68.46097565, 23.55125046], [68.46097565, 23.55097008], [68.46125031, 23.55097008], [68.46125031, 23.55041695], [68.46153259, 23.55042267], [68.46153259, 23.54986191], [68.46125031, 23.54986191], [68.46125031, 23.54930496], [68.46098328, 23.54931259], [68.46098328, 23.5490284], [68.46070099, 23.5490284], [68.46070099, 23.54874992], [68.46013641, 23.54874992], [68.46013641, 23.54846954], [68.45986176, 23.54847145], [68.45986176, 23.54819489], [68.4595871, 23.54819489], [68.4595871, 23.54791641], [68.45903015, 23.54791832], [68.45903015, 23.54763985], [68.45819092, 23.54763985], [68.45819092, 23.54735947], [68.4576416, 23.54736137], [68.4576416, 23.5470829], [68.45708466, 23.5470829], [68.45708466, 23.54680634], [68.45680237, 23.54680634], [68.45680237, 23.54652977], [68.45625305, 23.54652977], [68.45625305, 23.54624939], [68.45569611, 23.54624939], [68.45569611, 23.54597092], [68.4548645, 23.54597282], [68.4548645, 23.54569435], [68.45430756, 23.54569435], [68.45430756, 23.54541779], [68.4540329, 23.54541969], [68.4540329, 23.54514122], [68.45375061, 23.54514122], [68.45375061, 23.54486084], [68.45347595, 23.54486084], [68.45347595, 23.54458046], [68.45319366, 23.54458237], [68.45319366, 23.54430771], [68.45291901, 23.54430962], [68.45291901, 23.54403114], [68.45263672, 23.54403114], [68.45263672, 23.54347038], [68.45236206, 23.54347229], [68.45236206, 23.54319572], [68.45207977, 23.54319572], [68.45207977, 23.54291725], [68.45153046, 23.54292107], [68.45153046, 23.54264069], [68.45096588, 23.54264069], [68.45096588, 23.54236031], [68.45014191, 23.54236031], [68.45014191, 23.54207993], [68.44958496, 23.54208565], [68.44958496, 23.54180336], [68.44902802, 23.54181099], [68.44902802, 23.54153061], [68.44847107, 23.54153061], [68.44847107, 23.54125023], [68.44819641, 23.54125023], [68.44819641, 23.54096985], [68.44791412, 23.54097176], [68.44791412, 23.54069328], [68.44735718, 23.54070091], [68.44735718, 23.54042053], [68.44625092, 23.54042053], [68.44625092, 23.54014015], [68.44596863, 23.54014015], [68.44596863, 23.53957939], [68.44569397, 23.5395813], [68.44569397, 23.53902817], [68.44541931, 23.53903008], [68.44541931, 23.53847122], [68.44513702, 23.53847122], [68.44513702, 23.53819466], [68.44486237, 23.53819466], [68.44486237, 23.53791618], [68.44458008, 23.53792191], [68.44458008, 23.53762817], [68.44430542, 23.53763962], [68.44430542, 23.53735924], [68.44403076, 23.53735924], [68.44403076, 23.53708076], [68.44374847, 23.53708267], [68.44374847, 23.53680611], [68.44346619, 23.53681183], [68.44346619, 23.53624916], [68.44319153, 23.53624916], [68.44319153, 23.53597069], [68.44291687, 23.5359726], [68.44291687, 23.53569412], [68.44264221, 23.53569412], [68.44264221, 23.53513908], [68.44235992, 23.53513908], [68.44235992, 23.53486061], [68.44208527, 23.53486061], [68.44208527, 23.5340271], [68.44180298, 23.53403091], [68.44180298, 23.53292084], [68.44152832, 23.53292084], [68.44152832, 23.53236008], [68.44125366, 23.53236198], [68.44125366, 23.53152847], [68.44097137, 23.53153038], [68.44097137, 23.53096962], [68.44069672, 23.53097153], [68.44069672, 23.53013611], [68.4404068, 23.53013992], [68.4404068, 23.52931023], [68.44013977, 23.52931023], [68.44013977, 23.52876091], [68.43985748, 23.52876091], [68.43985748, 23.52847099], [68.43902588, 23.52847481], [68.43902588, 23.52819252], [68.43930817, 23.52819252], [68.43930817, 23.52791405], [68.43959045, 23.52791977], [68.43959045, 23.52736092], [68.43985748, 23.52736092], [68.43985748, 23.52653122], [68.43959045, 23.52653122], [68.43959045, 23.52597046], [68.43930817, 23.52597237], [68.43930817, 23.52569389], [68.43902588, 23.52569389], [68.43902588, 23.52541733], [68.43875122, 23.52542114], [68.43875122, 23.52514267], [68.43846893, 23.52514267], [68.43846893, 23.52486038], [68.43736267, 23.52486038], [68.43736267, 23.52458191], [68.43791962, 23.52458382], [68.43791962, 23.52402687], [68.43818665, 23.52403259], [68.43818665, 23.52375031], [68.43791962, 23.52375031], [68.43791962, 23.52347183], [68.43763733, 23.52347183], [68.43763733, 23.52319527], [68.43514252, 23.5232029], [68.43514252, 23.52235985], [68.43486023, 23.52236176], [68.43486023, 23.52263832], [68.4345932, 23.52263069], [68.4345932, 23.52292252], [68.43430328, 23.52292252], [68.43430328, 23.5232029], [68.43345642, 23.5232029], [68.43345642, 23.52292252], [68.43374634, 23.52292252], [68.43374634, 23.52235985], [68.43402863, 23.52236176], [68.43402863, 23.52180481], [68.43430328, 23.52180481], [68.43430328, 23.52124977], [68.43402863, 23.52124977], [68.43402863, 23.52096748], [68.43347168, 23.5209713], [68.43347168, 23.52041626], [68.43374634, 23.52041817], [68.43374634, 23.51902962], [68.43345642, 23.51902962], [68.43345642, 23.51653099], [68.43319702, 23.51653099], [68.43319702, 23.51542091], [68.4329071, 23.51542091], [68.4329071, 23.51320076], [68.43264008, 23.51320076], [68.43264008, 23.50765038], [68.43235779, 23.50765038], [68.43235779, 23.50791931], [68.43125153, 23.50791931], [68.43125153, 23.50765038], [68.43078613, 23.50765038], [68.43041992, 23.50765038], [68.43041992, 23.50791931], [68.43013763, 23.5079174], [68.43013763, 23.50819397], [68.42986298, 23.50819397], [68.42986298, 23.50847244], [68.42958069, 23.50847244], [68.42958069, 23.50958252], [68.42930603, 23.50958061], [68.42930603, 23.51013947], [68.42903137, 23.51013947], [68.42903137, 23.5106945], [68.42874908, 23.5106945], [68.42874908, 23.5134716], [68.42903137, 23.5134697], [68.42903137, 23.51486015], [68.42874908, 23.51486015], [68.42874908, 23.51542091], [68.42903137, 23.5154171], [68.42903137, 23.51569557], [68.42930603, 23.51569557], [68.42930603, 23.51597214], [68.42958069, 23.51597023], [68.42958069, 23.51625061], [68.42930603, 23.51625061], [68.42930603, 23.51653099], [68.42958069, 23.51653099], [68.42958069, 23.51682091], [68.42986298, 23.51682091], [68.42986298, 23.51736069], [68.43013763, 23.51736069], [68.43013763, 23.51875114], [68.43041992, 23.51875114], [68.43041992, 23.51930809], [68.43069458, 23.51930618], [68.43069458, 23.51958275], [68.43096924, 23.5195694], [68.43096924, 23.51986122], [68.43125153, 23.51986122], [68.43125153, 23.52013969], [68.43152618, 23.52013969], [68.43152618, 23.52041817], [68.43180847, 23.52041817], [68.43180847, 23.52124977], [68.43152618, 23.52124977], [68.43152618, 23.52152824], [68.43069458, 23.52152824], [68.43069458, 23.52180481], [68.43041992, 23.52180481], [68.43041992, 23.52208328], [68.43013763, 23.52208328], [68.43013763, 23.52236176], [68.42986298, 23.52236176], [68.42986298, 23.52263832], [68.42958069, 23.52263069], [68.42958069, 23.52292252], [68.42930603, 23.52291679], [68.42930603, 23.52347183], [68.42958069, 23.52347183], [68.42958069, 23.52403259], [68.43041992, 23.52402687], [68.43041992, 23.52569389], [68.43068695, 23.52569008], [68.43068695, 23.52680969], [68.43096924, 23.52680969], [68.43096924, 23.52931023], [68.43125153, 23.52930641], [68.43125153, 23.52958488], [68.43152618, 23.52958488], [68.43152618, 23.52986145], [68.43180847, 23.52985954], [68.43180847, 23.53013992], [68.43208313, 23.53013992], [68.43208313, 23.5304203], [68.43152618, 23.5304203], [68.43152618, 23.53070068], [68.43125153, 23.53070068], [68.43125153, 23.53125], [68.43096924, 23.53125], [68.43096924, 23.53181839], [68.43041992, 23.53180695], [68.43041992, 23.53208351], [68.43013763, 23.5320797], [68.43013763, 23.53264046], [68.42986298, 23.53264046], [68.42986298, 23.53375053], [68.43041992, 23.53375053], [68.43041992, 23.53347015], [68.43069458, 23.53347206], [68.43069458, 23.53319359], [68.43125153, 23.53319359], [68.43125153, 23.53347206], [68.43096924, 23.53347015], [68.43096924, 23.53403091], [68.43069458, 23.5340271], [68.43069458, 23.53458405], [68.43041992, 23.53457069], [68.43041992, 23.53513908], [68.43013763, 23.53513908], [68.43013763, 23.54292107], [68.43041992, 23.54291725], [68.43041992, 23.54319572], [68.43096924, 23.54319572], [68.43096924, 23.54347229], [68.43125153, 23.54347038], [68.43125153, 23.5437603], [68.43152618, 23.5437603], [68.43152618, 23.54430962], [68.43180847, 23.54430771], [68.43180847, 23.54458427], [68.43235779, 23.54458046], [68.43235779, 23.54486084], [68.43264008, 23.54486084], [68.43264008, 23.54514122], [68.43319702, 23.54514122], [68.43319702, 23.54541969], [68.43347168, 23.54541779], [68.43347168, 23.54569435], [68.43374634, 23.54569435], [68.43374634, 23.54597282], [68.43430328, 23.54597092], [68.43430328, 23.54624939], [68.4345932, 23.54624939], [68.4345932, 23.54652977], [68.43514252, 23.54652977], [68.43514252, 23.54680634], [68.43541718, 23.54680634], [68.43541718, 23.54736137], [68.43514252, 23.54736137], [68.43514252, 23.54847145], [68.43541718, 23.54846954], [68.43541718, 23.5490284], [68.43569183, 23.5490284], [68.43569183, 23.54958344], [68.43583679, 23.54958344], [68.43597412, 23.54958344], [68.43597412, 23.54986191], [68.43582153, 23.54986191], [68.43514252, 23.54986191], [68.43514252, 23.55014038], [68.4345932, 23.55014038], [68.4345932, 23.55042267], [68.43430328, 23.55041695], [68.43430328, 23.55069351], [68.43374634, 23.55069351], [68.43374634, 23.55097008], [68.43345642, 23.55097008], [68.43345642, 23.55125046], [68.43374634, 23.55125046], [68.43374634, 23.55153275], [68.43402863, 23.55153275], [68.43402863, 23.55181122], [68.43430328, 23.5518055], [68.43430328, 23.55208206], [68.43458557, 23.55208206], [68.43458557, 23.55319214], [68.43430328, 23.55319214], [68.43430328, 23.55347443], [68.43402863, 23.55347061], [68.43402863, 23.5537529], [68.43430328, 23.55374908], [68.43430328, 23.5545826], [68.4345932, 23.55458069], [68.4345932, 23.55541992], [68.43486023, 23.5554142], [68.43486023, 23.55597305], [68.43512726, 23.55597115], [68.43514252, 23.55653], [68.43541718, 23.55652809], [68.43541718, 23.55708313], [68.43653107, 23.55708313], [68.43653107, 23.5573616], [68.43682098, 23.5573597], [68.43682098, 23.55764008], [68.43708038, 23.55763626], [68.43708038, 23.55847168], [68.43736267, 23.55846977], [68.43736267, 23.55931091], [68.43763733, 23.55931091], [68.43763733, 23.55986023], [68.43902588, 23.55986023], [68.43902588, 23.55957985], [68.43930817, 23.55958366], [68.43930817, 23.55930519], [68.43959045, 23.55931091], [68.43959045, 23.55903053], [68.43985748, 23.55903053], [68.43985748, 23.55874062], [68.44013977, 23.55875015], [68.44013977, 23.55847168], [68.44125366, 23.55847168], [68.44125366, 23.55875015], [68.44097137, 23.55874062], [68.44097137, 23.55931091], [68.44069672, 23.55930519], [68.44069672, 23.55958366], [68.44013977, 23.55957985], [68.44013977, 23.55986023], [68.43985748, 23.55986023], [68.43985748, 23.56041908], [68.44013977, 23.56041718], [68.44013977, 23.56069374], [68.44041443, 23.56069374], [68.44041443, 23.56097221], [68.44125366, 23.56097221], [68.44125366, 23.56069374], [68.44180298, 23.56069374], [68.44180298, 23.56097221], [68.44208527, 23.56097221], [68.44208527, 23.5620842], [68.44235992, 23.56208038], [68.44235992, 23.56263924], [68.44208527, 23.56263924], [68.44208527, 23.56347275], [68.44319153, 23.56347084], [68.44319153, 23.56374931], [68.44431305, 23.56374931], [68.44431305, 23.56347084], [68.44486237, 23.56347084], [68.44486237, 23.56374931], [68.44596863, 23.56374931], [68.44596863, 23.56402969], [68.44625092, 23.56402779], [68.44625092, 23.56458282], [68.4465332, 23.56458282], [68.4465332, 23.56487083], [68.44680786, 23.56487083], [68.44680786, 23.56513977], [68.44708252, 23.56513977], [68.44708252, 23.56542015], [68.44819641, 23.56541634], [68.44819641, 23.56569481], [68.44985962, 23.56569481], [68.44985962, 23.56541634], [68.45041656, 23.56542015], [68.45041656, 23.56513977], [68.45096588, 23.56513977], [68.45096588, 23.56402969], [68.45124817, 23.56402969], [68.45124817, 23.56347084], [68.45153046, 23.56347275], [68.45153046, 23.56236076], [68.45182037, 23.56236076], [68.45180511, 23.56152725], [68.45263672, 23.56152916], [68.45263672, 23.56125069], [68.45318604, 23.56125069], [68.45318604, 23.56152916], [68.45347595, 23.56152725], [68.45347595, 23.56180573], [68.45375061, 23.56180573], [68.45375061, 23.56347275], [68.45402527, 23.56347275], [68.45402527, 23.56458282], [68.45375061, 23.56458282], [68.45375061, 23.56487083], [68.45347595, 23.56487083], [68.45347595, 23.56513977], [68.45318604, 23.56513977], [68.45318604, 23.56542015], [68.45291901, 23.56541634], [68.45291901, 23.56597137], [68.45263672, 23.56596947], [68.45263672, 23.56624985], [68.45291901, 23.56624985], [68.45291901, 23.56680489], [68.45319366, 23.56680489], [68.45319366, 23.56736374], [68.45456696, 23.56735992], [68.45456696, 23.56820107], [68.45430756, 23.56820107], [68.45430756, 23.56875038], [68.4540329, 23.56875038], [68.4540329, 23.56903076], [68.45485687, 23.56903076], [68.45485687, 23.57014084], [68.45513916, 23.57014084], [68.45513916, 23.57152939], [68.45541382, 23.57152748], [68.45541382, 23.57208252], [68.45569611, 23.57208061], [68.45569611, 23.57236099], [68.45625305, 23.57236099], [68.45625305, 23.57263947], [68.45680237, 23.57263947], [68.45680237, 23.57291985], [68.45735931, 23.57291794], [68.45735931, 23.5731945], [68.4576416, 23.5731945], [68.4576416, 23.57347298], [68.45819092, 23.57347298], [68.45819092, 23.57374954], [68.45903015, 23.57374001], [68.45903015, 23.57402992], [68.4595871, 23.57402992], [68.4595871, 23.5743084], [68.45986176, 23.57430649], [68.45986176, 23.57458305], [68.46013641, 23.57458115], [68.46013641, 23.57513809], [68.4604187, 23.57513809], [68.4604187, 23.57541847], [68.46235657, 23.57541847], [68.46235657, 23.57570076], [68.4640274, 23.57569504], [68.4640274, 23.5759716], [68.46430206, 23.5759697], [68.46430206, 23.57625008], [68.46457672, 23.57625008], [68.46457672, 23.57653236], [68.46485901, 23.57653236], [68.46485901, 23.57681274], [68.46569824, 23.57681274], [68.46569824, 23.57653236], [68.4679184, 23.57653236], [68.4679184, 23.57681274], [68.46763611, 23.57681274], [68.46763611, 23.57792282], [68.46819305, 23.5779171], [68.46819305, 23.57819366], [68.46930695, 23.57819366], [68.46930695, 23.57847023], [68.47041321, 23.57847023], [68.47041321, 23.57875061], [68.47070313, 23.57875061], [68.4706955, 23.57847023], [68.47180176, 23.57847023], [68.47180939, 23.57819366], [68.47291565, 23.57819366], [68.47291565, 23.57847023], [68.47264099, 23.57847023], [68.47264099, 23.57875061], [68.4723587, 23.57875061], [68.4723587, 23.5790329], [68.47207642, 23.5790329], [68.47207642, 23.57930946], [68.4715271, 23.57930565], [68.4715271, 23.57958221], [68.47125244, 23.57958031], [68.47125244, 23.58014107], [68.47097015, 23.58014107], [68.47097015, 23.58041954], [68.47041321, 23.58041573], [68.47041321, 23.58069229], [68.47013855, 23.58069229], [68.47013855, 23.58097458], [68.46985626, 23.58097076], [68.46985626, 23.58152962], [68.4695816, 23.58152771], [68.4695816, 23.58291435], [68.46875, 23.58291435], [68.46875, 23.58263969], [68.4679184, 23.58263969], [68.4679184, 23.58291435], [68.46708679, 23.58291435], [68.46708679, 23.58208466], [68.46736145, 23.58208466], [68.46736145, 23.58124924], [68.46763611, 23.58125114], [68.46763611, 23.57987022], [68.46624756, 23.57987022], [68.46624756, 23.57958031], [68.46541595, 23.57958221], [68.46541595, 23.57930565], [68.46485901, 23.57930946], [68.46485901, 23.5790329], [68.4640274, 23.5790329], [68.4640274, 23.57930946], [68.46375275, 23.57930565], [68.46375275, 23.57958221], [68.46347046, 23.57958031], [68.46347046, 23.57987022], [68.4631958, 23.57987022], [68.4631958, 23.58041954], [68.46291351, 23.58041573], [68.46291351, 23.58097458], [68.46263885, 23.58097076], [68.46263885, 23.58152962], [68.4623642, 23.58152771], [68.4623642, 23.58319664], [68.46263885, 23.58319664], [68.46263885, 23.5834713], [68.46290588, 23.58346939], [68.46290588, 23.58374977], [68.4631958, 23.58374977], [68.4631958, 23.58430672], [68.46347046, 23.58430672], [68.46347046, 23.58458328], [68.46375275, 23.58458328], [68.46375275, 23.58486176], [68.4640274, 23.58485985], [68.4640274, 23.58514023], [68.46430206, 23.58514023], [68.46430206, 23.58542061], [68.46457672, 23.58542061], [68.46457672, 23.58569908], [68.46485901, 23.58569527], [68.46485901, 23.58597183], [68.4651413, 23.58596992], [68.4651413, 23.58653069], [68.46541595, 23.58652878], [68.46541595, 23.58708382], [68.46569061, 23.58708382], [68.46569824, 23.58745384], [68.46569824, 23.58764076], [68.4659729, 23.58763885], [68.4659729, 23.58819389], [68.46624756, 23.58818817], [68.46624756, 23.58875084], [68.46652985, 23.58875084], [68.46652985, 23.58902931], [68.4668045, 23.5890274], [68.4668045, 23.58958244], [68.46708679, 23.58958054], [68.46708679, 23.58986092], [68.46736145, 23.58986092], [68.46736145, 23.59042168], [68.46763611, 23.59041595], [68.46763611, 23.5909729], [68.4679184, 23.59096909], [68.4679184, 23.59153175], [68.46819305, 23.59153175], [68.46819305, 23.59181023], [68.46847534, 23.59180641], [68.46847534, 23.59208107], [68.46902466, 23.59208107], [68.46902466, 23.59236145], [68.46985626, 23.59235954], [68.46985626, 23.59263992], [68.47041321, 23.59263992], [68.47041321, 23.5929203], [68.47207642, 23.5929203], [68.47207642, 23.59320068], [68.4734726, 23.59320068], [68.4734726, 23.5929203], [68.47429657, 23.5929203], [68.47429657, 23.59263992], [68.47458649, 23.59263992], [68.47458649, 23.59235954], [68.4751358, 23.59236145], [68.4751358, 23.59180641], [68.47541809, 23.59181023], [68.47541809, 23.59153175], [68.47570038, 23.59153175], [68.47570038, 23.59124947], [68.47624969, 23.59124947], [68.47624969, 23.59096909], [68.47652435, 23.5909729], [68.47652435, 23.59069443], [68.4770813, 23.59069443], [68.4770813, 23.59041595], [68.4779129, 23.59042168], [68.4779129, 23.59013939], [68.47846985, 23.59013939], [68.47846985, 23.58986092], [68.47957611, 23.58986092], [68.47957611, 23.59013939], [68.48014069, 23.59013939], [68.48014069, 23.59042168], [68.48041534, 23.59041595], [68.48041534, 23.59069443], [68.48069763, 23.59069061], [68.48069763, 23.59153175], [68.48097229, 23.59153175], [68.48097229, 23.59320068], [68.48069763, 23.59320068], [68.48069763, 23.59375], [68.48042297, 23.59375], [68.48042297, 23.59680939], [68.48208618, 23.59680939], [68.48208618, 23.59653091], [68.48236084, 23.59653091], [68.48236084, 23.59625053], [68.48264313, 23.59625053], [68.4826355, 23.59597206], [68.48291779, 23.59597206], [68.48291779, 23.5956955], [68.48319244, 23.5956955], [68.48319244, 23.59541512], [68.4834671, 23.59542084], [68.4834671, 23.59514046], [68.48374939, 23.59514046], [68.48374939, 23.59485054], [68.48402405, 23.59486389], [68.48402405, 23.59458542], [68.48430634, 23.59458542], [68.48430634, 23.59430313], [68.48458099, 23.59431076], [68.48458099, 23.59346962], [68.48486328, 23.59347153], [68.48486328, 23.59263802], [68.48513794, 23.59263992], [68.48513794, 23.59181023], [68.48542023, 23.59181023], [68.48542023, 23.58875084], [68.48568726, 23.58875084], [68.48568726, 23.58764076], [68.48542023, 23.58764076], [68.48542023, 23.58680916], [68.48513794, 23.58680916], [68.48513794, 23.58625031], [68.48486328, 23.58625031], [68.48486328, 23.58596992], [68.48458099, 23.58597183], [68.48458099, 23.58486176], [68.48430634, 23.58486176], [68.48430634, 23.58430672], [68.48402405, 23.58430672], [68.48402405, 23.58374977], [68.48374939, 23.58374977], [68.48374939, 23.58041954], [68.48401642, 23.58041954], [68.48401642, 23.57958031], [68.48430634, 23.57958221], [68.48430634, 23.57902718], [68.48458099, 23.5790329], [68.48458099, 23.57847023], [68.48486328, 23.57847023], [68.48486328, 23.57763863], [68.48513794, 23.57764053], [68.48513794, 23.57625008], [68.48542023, 23.57625008], [68.48542023, 23.57513809], [68.48513794, 23.57513809], [68.48513794, 23.57485962], [68.48486328, 23.57486153], [68.48486328, 23.57458305], [68.48458099, 23.57458305], [68.48458099, 23.57402992], [68.48401642, 23.57402992], [68.48401642, 23.57347107], [68.48374939, 23.57347298], [68.48374939, 23.5731945], [68.48347473, 23.5731945], [68.48347473, 23.57291794], [68.48319244, 23.57291985], [68.48319244, 23.57263947], [68.48291779, 23.57263947], [68.48291779, 23.57236099], [68.48236084, 23.57236099], [68.48236084, 23.57208061], [68.48208618, 23.57208252], [68.48208618, 23.57152748], [68.48179626, 23.57152939], [68.48179626, 23.57097054], [68.48152924, 23.57097244], [68.48152924, 23.5704174], [68.48124695, 23.57042122], [68.48124695, 23.57014084], [68.48097229, 23.57014084], [68.48097229, 23.56958008], [68.48069763, 23.5695858], [68.48069763, 23.56902695], [68.48042297, 23.56903076], [68.48042297, 23.56847], [68.48014069, 23.56847382], [68.48014069, 23.56791687], [68.4798584, 23.56793022], [68.4798584, 23.56624985], [68.48014069, 23.56624985], [68.48014069, 23.56542015], [68.48042297, 23.56542015], [68.48042297, 23.56513977], [68.48097229, 23.56513977], [68.48097229, 23.56458282], [68.48124695, 23.56458282], [68.48124695, 23.56402779], [68.48152924, 23.56402969], [68.48152924, 23.56374931], [68.48124695, 23.56374931], [68.48124695, 23.56318855], [68.48097229, 23.56319427], [68.48097229, 23.5620842], [68.48124695, 23.5620842], [68.48124695, 23.56125069], [68.48069763, 23.56125069], [68.48069763, 23.56097031], [68.47930908, 23.56097031], [68.47930908, 23.56125069], [68.47875977, 23.56125069], [68.47875977, 23.56152916], [68.47846985, 23.56152725], [68.47846985, 23.56180573], [68.47902679, 23.56180573], [68.47902679, 23.5620842], [68.47930908, 23.56208038], [68.47930908, 23.56263924], [68.47763824, 23.56263924], [68.47763824, 23.56292152], [68.4770813, 23.5629158], [68.4770813, 23.56319427], [68.47680664, 23.56318855], [68.47680664, 23.56402969], [68.47651672, 23.56402969], [68.47651672, 23.56431007], [68.4759903, 23.56431007], [68.4759903, 23.56402969], [68.47541809, 23.56402969], [68.47541809, 23.56374931], [68.4751358, 23.56374931], [68.4751358, 23.56347084], [68.47458649, 23.56347275], [68.47458649, 23.56319427], [68.47402954, 23.56319427], [68.47402954, 23.5629158], [68.4734726, 23.56292152]]], [[[68.48208618, 23.60653114], [68.48208618, 23.60642052], [68.48208618, 23.60625076], [68.48227692, 23.60625076], [68.48291779, 23.60625076], [68.48291779, 23.60597038], [68.48347473, 23.60597229], [68.48347473, 23.60569382], [68.48374939, 23.60569382], [68.48374939, 23.60541725], [68.48401642, 23.60542107], [68.48401642, 23.60514259], [68.48430634, 23.60514259], [68.48430634, 23.60486031], [68.48458099, 23.60486031], [68.48458099, 23.60458183], [68.48486328, 23.60458374], [68.48486328, 23.60430527], [68.48500061, 23.60430717], [68.48542023, 23.6043129], [68.48542023, 23.60406113], [68.48652649, 23.60404015], [68.48652649, 23.60349083], [68.48652649, 23.60319519], [68.48596954, 23.60320282], [68.48596954, 23.60263824], [68.48568726, 23.60263824], [68.48568726, 23.60235977], [68.48542023, 23.60236168], [68.48542023, 23.60208321], [68.48486328, 23.60208321], [68.48486328, 23.60180473], [68.48458099, 23.60180473], [68.48458099, 23.60152817], [68.48430634, 23.60152817], [68.48430634, 23.60124969], [68.48401642, 23.60124969], [68.48401642, 23.60098076], [68.48374939, 23.60098076], [68.48374939, 23.60069084], [68.48347473, 23.60069466], [68.48347473, 23.60041618], [68.48319244, 23.60041809], [68.48319244, 23.59986115], [68.48291779, 23.59986115], [68.48291779, 23.59930992], [68.48264313, 23.59930992], [68.48264313, 23.59875107], [68.48208618, 23.59875107], [68.48208618, 23.59847069], [68.48152924, 23.5984726], [68.48152924, 23.59819412], [68.48014069, 23.59819031], [68.48014069, 23.59875107], [68.4798584, 23.59875107], [68.4798584, 23.59930992], [68.47957611, 23.59930992], [68.47957611, 23.59986115], [68.47930908, 23.59986115], [68.47930908, 23.60013962], [68.47875977, 23.60013962], [68.47875977, 23.60263824], [68.47902679, 23.60263824], [68.47902679, 23.60404015], [68.47930908, 23.60404015], [68.47930908, 23.60514259], [68.47958374, 23.60513878], [68.47958374, 23.60569382], [68.4798584, 23.60569382], [68.4798584, 23.60597229], [68.48041534, 23.60597229], [68.48041534, 23.60625076], [68.48097229, 23.60625076], [68.48097229, 23.60653114], [68.48195648, 23.60652733], [68.48208618, 23.60653114]]], [[[68.48458099, 23.62791824], [68.48458099, 23.62763977], [68.48680878, 23.62763977], [68.48680878, 23.62735939], [68.48708344, 23.6273613], [68.48708344, 23.62708282], [68.48680878, 23.62708282], [68.48680878, 23.62652779], [68.48652649, 23.62652969], [68.48652649, 23.62625122], [68.48625183, 23.62625122], [68.48625183, 23.62569046], [68.48596954, 23.62569427], [68.48596954, 23.62513924], [68.48568726, 23.62514114], [68.48568726, 23.62458038], [68.48542023, 23.6245842], [68.48542023, 23.62430763], [68.48513794, 23.62430954], [68.48513794, 23.62375069], [68.48486328, 23.62375069], [68.48486328, 23.62347031], [68.48458099, 23.62347221], [68.48458099, 23.62319565], [68.48430634, 23.62319565], [68.48430634, 23.62291527], [68.48401642, 23.62292099], [68.48401642, 23.62264061], [68.48374939, 23.62264061], [68.48374939, 23.62236023], [68.4834671, 23.62236023], [68.4834671, 23.62181091], [68.48319244, 23.62181091], [68.48319244, 23.62153053], [68.48401642, 23.62153053], [68.48401642, 23.62181091], [68.48430634, 23.62180328], [68.48430634, 23.62208557], [68.48458099, 23.62207985], [68.48458099, 23.62236023], [68.48486328, 23.62236023], [68.48486328, 23.62292099], [68.48513794, 23.62291527], [68.48513794, 23.62347221], [68.48568726, 23.62347031], [68.48568726, 23.62375069], [68.48625183, 23.62375069], [68.48625183, 23.62403107], [68.48652649, 23.62403107], [68.48652649, 23.62430954], [68.48680878, 23.62430763], [68.48680878, 23.6245842], [68.48707581, 23.62458038], [68.48707581, 23.62486076], [68.48735809, 23.62486076], [68.48735809, 23.62514114], [68.4879303, 23.62514114], [68.4879303, 23.62541962], [68.48847198, 23.62541771], [68.48847198, 23.62569427], [68.48930359, 23.62569427], [68.48930359, 23.62541771], [68.48958588, 23.62541962], [68.48958588, 23.62514114], [68.48986053, 23.62514114], [68.48986053, 23.62486076], [68.49014282, 23.62486076], [68.49013519, 23.62430763], [68.49041748, 23.62430954], [68.49041748, 23.62264061], [68.49069977, 23.62264061], [68.49069977, 23.62207985], [68.49097443, 23.62208557], [68.49097443, 23.62152863], [68.49069977, 23.62153053], [68.49069977, 23.62096977], [68.49041748, 23.62097168], [68.49041748, 23.62041664], [68.49014282, 23.62042046], [68.49014282, 23.61930275], [68.48986053, 23.61930466], [68.48986053, 23.61819458], [68.48958588, 23.61819458], [68.48958588, 23.6170826], [68.48930359, 23.6170826], [68.48930359, 23.6143055], [68.48958588, 23.61430931], [68.48958588, 23.61320114], [68.48986053, 23.6131897], [68.48986053, 23.61208344], [68.49013519, 23.61208344], [68.49013519, 23.61173058], [68.49013519, 23.61097145], [68.49041748, 23.61097145], [68.49041748, 23.60986137], [68.49069214, 23.60986137], [68.49069214, 23.60902786], [68.4909668, 23.60902977], [68.4909668, 23.60791969], [68.49124908, 23.60791969], [68.49124908, 23.60569191], [68.49097443, 23.60569382], [68.49097443, 23.60430527], [68.49069977, 23.6043129], [68.49069977, 23.60375023], [68.49041748, 23.60375023], [68.49041748, 23.60347176], [68.48929596, 23.60347176], [68.48929596, 23.60375023], [68.48874664, 23.60375023], [68.48874664, 23.60404015], [68.48819733, 23.60404015], [68.48819733, 23.6043129], [68.48764038, 23.60430527], [68.48764038, 23.60458374], [68.48625183, 23.60458183], [68.48625183, 23.60486031], [68.48596954, 23.60486031], [68.48596954, 23.60514259], [68.48568726, 23.60514259], [68.48568726, 23.60542107], [68.48513794, 23.60541725], [68.48513794, 23.60569382], [68.48486328, 23.60569382], [68.48486328, 23.60597229], [68.48430634, 23.60597038], [68.48430634, 23.60625076], [68.48401642, 23.60625076], [68.48401642, 23.60653114], [68.48374939, 23.60653114], [68.48374939, 23.60680962], [68.48319244, 23.6068058], [68.48319244, 23.60708237], [68.4826355, 23.60708237], [68.4826355, 23.60736084], [68.48100281, 23.60736084], [68.48041534, 23.60736084], [68.48041534, 23.60708237], [68.4798584, 23.60708237], [68.4798584, 23.6068058], [68.47957611, 23.60680962], [68.47957611, 23.60653114], [68.47930908, 23.60653114], [68.47930908, 23.60625076], [68.47902679, 23.60625076], [68.47902679, 23.60653114], [68.47875977, 23.60653114], [68.47875977, 23.60625076], [68.47846985, 23.60625076], [68.47846985, 23.60486031], [68.47819519, 23.60486031], [68.47819519, 23.60458374], [68.4779129, 23.60458374], [68.4779129, 23.60375023], [68.47820282, 23.60375023], [68.47819519, 23.60319519], [68.4779129, 23.60320282], [68.4779129, 23.60013962], [68.47820282, 23.60013962], [68.47819519, 23.59902763], [68.47846985, 23.59902954], [68.47846985, 23.59847069], [68.47875214, 23.5984726], [68.47875214, 23.59819412], [68.47902679, 23.59819412], [68.47902679, 23.59791756], [68.47958374, 23.59791756], [68.47958374, 23.59680367], [68.47930908, 23.59680939], [68.47930908, 23.59653091], [68.47957611, 23.59653091], [68.47957611, 23.59375], [68.4798584, 23.59375], [68.4798584, 23.5929203], [68.48014069, 23.5929203], [68.48014069, 23.59153175], [68.4798584, 23.59153175], [68.4798584, 23.59096909], [68.47958374, 23.5909729], [68.47958374, 23.59069443], [68.47846985, 23.59069443], [68.47846985, 23.5909729], [68.4779129, 23.59096909], [68.4779129, 23.59124947], [68.4770813, 23.59124947], [68.4770813, 23.59153175], [68.47651672, 23.59153175], [68.47651672, 23.59181023], [68.47624969, 23.59180641], [68.47624969, 23.59208107], [68.47597504, 23.59208107], [68.47597504, 23.59236145], [68.47570038, 23.59235954], [68.47570038, 23.59263992], [68.47541809, 23.59263992], [68.47541809, 23.5929203], [68.4751358, 23.5929203], [68.4751358, 23.59320068], [68.47458649, 23.59319305], [68.47458649, 23.59347153], [68.47429657, 23.59346962], [68.47429657, 23.59375], [68.4734726, 23.59375], [68.4734726, 23.59403038], [68.47180939, 23.59403038], [68.47180176, 23.59375], [68.47041321, 23.59375], [68.47041321, 23.59346962], [68.4695816, 23.59347153], [68.4695816, 23.59319305], [68.46901703, 23.59320068], [68.46901703, 23.5929203], [68.46848297, 23.5929203], [68.46848297, 23.59263992], [68.46819305, 23.59263992], [68.46819305, 23.5929203], [68.4679184, 23.5929203], [68.4679184, 23.59320068], [68.46763611, 23.59319305], [68.46763611, 23.59347153], [68.46736145, 23.59346962], [68.46736145, 23.59542084], [68.46708679, 23.59542084], [68.46708679, 23.59680939], [68.46736145, 23.59680939], [68.46736145, 23.59764099], [68.46763611, 23.59763908], [68.46763611, 23.59819412], [68.4679184, 23.59819031], [68.4679184, 23.59875107], [68.46819305, 23.59875107], [68.46819305, 23.59930992], [68.46847534, 23.59930611], [68.46847534, 23.60013962], [68.46875, 23.60013962], [68.46875, 23.60098076], [68.46901703, 23.60098076], [68.46901703, 23.60124969], [68.46930695, 23.60124969], [68.46930695, 23.60152817], [68.46956635, 23.60152817], [68.46956635, 23.60486031], [68.46930695, 23.60486031], [68.46930695, 23.60597229], [68.46901703, 23.60597038], [68.46901703, 23.60653114], [68.46875, 23.60653114], [68.46875, 23.60680962], [68.46848297, 23.60680962], [68.46848297, 23.60791969], [68.46875, 23.60791588], [68.46875, 23.60819244], [68.46847534, 23.60819244], [68.46847534, 23.60986137], [68.46819305, 23.60986137], [68.46819305, 23.61097145], [68.46847534, 23.61097145], [68.46847534, 23.61124992], [68.46875, 23.61124992], [68.46875, 23.61264038], [68.46901703, 23.61264038], [68.46901703, 23.61403084], [68.46927643, 23.61403084], [68.46930695, 23.61514091], [68.46956635, 23.61514091], [68.46956635, 23.61624908], [68.46985626, 23.61624908], [68.46985626, 23.61681175], [68.47041321, 23.61680603], [68.47041321, 23.6170826], [68.4706955, 23.6170826], [68.4706955, 23.61735916], [68.47125244, 23.61735916], [68.47125244, 23.61763954], [68.47180176, 23.61763954], [68.47180176, 23.61792183], [68.4723587, 23.61791611], [68.4723587, 23.61819458], [68.47291565, 23.61819458], [68.47291565, 23.61847115], [68.47319794, 23.61847115], [68.47319794, 23.61930466], [68.4734726, 23.61930275], [68.4734726, 23.62014008], [68.47458649, 23.62014008], [68.47458649, 23.6198597], [68.47486115, 23.6198616], [68.47486115, 23.61930466], [68.47570038, 23.61930275], [68.47570038, 23.62014008], [68.47583008, 23.62013817], [68.47957611, 23.62014008], [68.47957611, 23.62070084], [68.4798584, 23.62070084], [68.4798584, 23.62125015], [68.48042297, 23.62125015], [68.48042297, 23.62153053], [68.48069763, 23.62153053], [68.48069763, 23.62181091], [68.48097229, 23.62181091], [68.48097229, 23.62236023], [68.48124695, 23.62236023], [68.48124695, 23.62319565], [68.48152924, 23.62318993], [68.48152924, 23.62375069], [68.48124695, 23.62375069], [68.48124695, 23.62430954], [68.48097229, 23.62430954], [68.48097229, 23.62486076], [68.48069763, 23.62486076], [68.48069763, 23.62569427], [68.48097229, 23.62569046], [68.48097229, 23.62652969], [68.48124695, 23.62652779], [68.48124695, 23.62708282], [68.48152924, 23.62708282], [68.48152924, 23.6273613], [68.48179626, 23.62735939], [68.48179626, 23.62763977], [68.48208618, 23.62763977], [68.48208618, 23.62791824], [68.48458099, 23.62791824]]], [[[69.21318817, 22.38485909], [69.21318817, 22.38458061], [69.2140274, 22.38458252], [69.2140274, 22.38430786], [69.21485901, 22.38430977], [69.21485901, 22.38402748], [69.2151413, 22.38402748], [69.2151413, 22.38319016], [69.21485901, 22.38319397], [69.21485901, 22.3829155], [69.21457672, 22.38292122], [69.21457672, 22.38264084], [69.21430206, 22.38264084], [69.21430206, 22.38236046], [69.21347046, 22.38236046], [69.21347046, 22.38319397], [69.2131958, 22.38319397], [69.2131958, 22.38347244], [69.21289825, 22.38347054], [69.21289825, 22.38375092], [69.21263885, 22.38375092], [69.21263885, 22.38402748], [69.2123642, 22.38402748], [69.2123642, 22.38458252], [69.21263885, 22.38458061], [69.21263885, 22.38485909], [69.21318817, 22.38485909]]], [[[69.20095825, 22.38625145], [69.20095825, 22.38569069], [69.20069122, 22.3856945], [69.20069122, 22.38485909], [69.20041656, 22.38485909], [69.20041656, 22.38458061], [69.20014191, 22.38458252], [69.20014191, 22.38430786], [69.19985962, 22.38430977], [69.19985962, 22.38402748], [69.19957733, 22.38402748], [69.19957733, 22.38430977], [69.19930267, 22.38430977], [69.19930267, 22.38541985], [69.19958496, 22.38541603], [69.19958496, 22.3856945], [69.19930267, 22.3856945], [69.19930267, 22.38597298], [69.19958496, 22.38597298], [69.19958496, 22.38708305], [69.19985962, 22.38708305], [69.19985962, 22.38736153], [69.20014191, 22.38736153], [69.20014191, 22.38764191], [69.20236206, 22.38764191], [69.20236206, 22.38653183], [69.20207977, 22.38653183], [69.20207977, 22.38625145], [69.20095825, 22.38625145]]], [[[69.28013611, 22.41792107], [69.28013611, 22.41764069], [69.2804184, 22.41764069], [69.2804184, 22.41736031], [69.28069305, 22.41736031], [69.28069305, 22.41653061], [69.28098297, 22.41653061], [69.28098297, 22.41597176], [69.28069305, 22.41597366], [69.28069305, 22.41569519], [69.28013611, 22.41569519], [69.28013611, 22.41597366], [69.27986145, 22.41597366], [69.27986145, 22.41541672], [69.27958679, 22.41542053], [69.27958679, 22.41514969], [69.27902985, 22.41514969], [69.27902985, 22.41542053], [69.27819824, 22.41542053], [69.27819061, 22.41570282], [69.27791595, 22.41569519], [69.27791595, 22.41597366], [69.2776413, 22.41597366], [69.2776413, 22.41708374], [69.27791595, 22.41708183], [69.27791595, 22.41764069], [69.27819061, 22.41764069], [69.27819824, 22.41792107], [69.28013611, 22.41792107]]], [[[69.48319244, 22.3987484], [69.48319244, 22.39846992], [69.48374939, 22.39847183], [69.48374939, 22.39819527], [69.48430634, 22.39819908], [69.48430634, 22.39792061], [69.48458099, 22.39792061], [69.48458099, 22.39763832], [69.48513794, 22.39763832], [69.48513794, 22.39735985], [69.48542023, 22.39736176], [69.48542023, 22.39708328], [69.48625183, 22.39708328], [69.48625183, 22.39652634], [69.48652649, 22.39653015], [69.48652649, 22.39624977], [69.48680878, 22.39624977], [69.48680878, 22.39596939], [69.48708344, 22.3959713], [69.48708344, 22.39569473], [69.48735809, 22.39569473], [69.48735809, 22.39541626], [69.48764038, 22.39542007], [69.48764038, 22.39458084], [69.48791504, 22.39458275], [69.48791504, 22.39430428], [69.48819733, 22.39431], [69.48819733, 22.39402008], [69.48847198, 22.39402771], [69.48847198, 22.39374924], [69.48874664, 22.39375114], [69.48874664, 22.39291954], [69.48902893, 22.39291954], [69.48902893, 22.39153099], [69.48874664, 22.39153099], [69.48874664, 22.39068985], [69.48847198, 22.39069366], [69.48847198, 22.3904171], [69.48819733, 22.39042091], [69.48819733, 22.38986015], [69.48764038, 22.38986015], [69.48764038, 22.38957977], [69.48735809, 22.38958359], [69.48735809, 22.38902855], [69.48707581, 22.38903046], [69.48707581, 22.38875008], [69.48680878, 22.38875008], [69.48680878, 22.3884716], [69.48625183, 22.3884716], [69.48625183, 22.38819504], [69.48596954, 22.3882103], [69.48596954, 22.38792038], [69.48458099, 22.38792038], [69.48458099, 22.38764191], [69.48374939, 22.38764191], [69.48374939, 22.38792038], [69.48291779, 22.38792038], [69.48291779, 22.3882103], [69.48097229, 22.38819504], [69.48097229, 22.3884716], [69.48042297, 22.3884716], [69.48042297, 22.39014053], [69.48014069, 22.39013863], [69.48014069, 22.39069366], [69.48042297, 22.39068985], [69.48042297, 22.39180946], [69.48069763, 22.39180946], [69.48069763, 22.39375114], [69.48097229, 22.39374924], [69.48097229, 22.39402771], [69.48152924, 22.39402008], [69.48152924, 22.39431], [69.48179626, 22.39431], [69.48179626, 22.39486122], [69.48208618, 22.39486122], [69.48208618, 22.39569473], [69.48236084, 22.39569473], [69.48236084, 22.3959713], [69.4826355, 22.3959713], [69.4826355, 22.3987484], [69.48319244, 22.3987484]]], [[[69.27931213, 22.42014122], [69.27931213, 22.41986084], [69.27958679, 22.41986084], [69.27958679, 22.41930962], [69.27931213, 22.41930962], [69.27931213, 22.41903114], [69.27819824, 22.41903114], [69.27819824, 22.41847038], [69.27791595, 22.41847229], [69.27791595, 22.41819382], [69.2765274, 22.41819382], [69.2765274, 22.41847229], [69.27597046, 22.41847038], [69.27597046, 22.41875076], [69.27540588, 22.41875076], [69.27540588, 22.41903114], [69.27513885, 22.41903114], [69.27513885, 22.41930962], [69.27541351, 22.4193058], [69.27541351, 22.41958427], [69.2756958, 22.41958046], [69.2756958, 22.41986084], [69.27707672, 22.41986084], [69.27707672, 22.41958046], [69.27735901, 22.41958046], [69.27735901, 22.41986084], [69.27791595, 22.41986084], [69.27791595, 22.42014122], [69.27874756, 22.42014122], [69.27874756, 22.41986084], [69.27902985, 22.41986084], [69.27902985, 22.42014122], [69.27931213, 22.42014122]]], [[[69.60708618, 22.41875076], [69.60679626, 22.41875076], [69.60679626, 22.41903114], [69.60652924, 22.41903114], [69.60652924, 22.41930962], [69.60624695, 22.4193058], [69.60624695, 22.41958237], [69.60597229, 22.41958046], [69.60597229, 22.41986084], [69.60569763, 22.41986084], [69.60569763, 22.42014122], [69.60514069, 22.42014122], [69.60514069, 22.42041969], [69.6048584, 22.42041588], [69.6048584, 22.42069435], [69.60458374, 22.42069435], [69.60458374, 22.42097282], [69.60430908, 22.42095947], [69.60430908, 22.42124939], [69.60402679, 22.42124939], [69.60402679, 22.42152977], [69.60375214, 22.42152977], [69.60375214, 22.42181015], [69.60346985, 22.42180634], [69.60346985, 22.4220829], [69.60319519, 22.4220829], [69.60319519, 22.42236137], [69.6029129, 22.42236137], [69.6029129, 22.42319489], [69.60236359, 22.42319489], [69.60236359, 22.42291641], [69.6020813, 22.42292023], [69.6020813, 22.42235947], [69.6001358, 22.42235947], [69.6001358, 22.42263985], [69.59986115, 22.42263985], [69.59986115, 22.42292023], [69.59902954, 22.42291641], [69.59902954, 22.42319489], [69.59874725, 22.42319489], [69.59874725, 22.42347145], [69.5984726, 22.42346954], [69.5984726, 22.42374992], [69.59819794, 22.42374992], [69.59819794, 22.4240303], [69.59764099, 22.4240303], [69.59764099, 22.42432022], [69.5973587, 22.42430496], [69.5973587, 22.42458344], [69.59597015, 22.42458344], [69.59597015, 22.42486191], [69.59570313, 22.42485809], [69.59570313, 22.42514038], [69.59541321, 22.42514038], [69.59541321, 22.42542076], [69.59513855, 22.42541885], [69.59513855, 22.42569351], [69.59486389, 22.42569351], [69.59486389, 22.42597008], [69.5945816, 22.42596817], [69.5945816, 22.42624855], [69.59401703, 22.42624855], [69.59401703, 22.42653084], [69.59375, 22.42653084], [69.59375, 22.42680931], [69.59348297, 22.42680931], [69.59348297, 22.42708969], [69.59319305, 22.42708969], [69.59319305, 22.42735863], [69.5929184, 22.42735863], [69.5929184, 22.42764282], [69.59263611, 22.42764282], [69.59263611, 22.42791939], [69.59236145, 22.42791748], [69.59236145, 22.42819405], [69.59208679, 22.42819405], [69.59208679, 22.43069458], [69.59152985, 22.43069458], [69.59152985, 22.43180466], [69.59124756, 22.43180084], [69.59124756, 22.43292046], [69.59069824, 22.43291664], [69.59069061, 22.43347168], [69.5901413, 22.43346977], [69.5901413, 22.43486023], [69.58985901, 22.43486023], [69.58985901, 22.43514061], [69.5890274, 22.43514061], [69.5890274, 22.43542099], [69.58875275, 22.43541527], [69.58875275, 22.43597221], [69.58847046, 22.43597221], [69.58847046, 22.4370842], [69.5881958, 22.43708038], [69.5881958, 22.43875122], [69.58847046, 22.43875122], [69.58847046, 22.43931961], [69.58875275, 22.43930626], [69.58875275, 22.43958282], [69.58930206, 22.43958282], [69.58930206, 22.43985939], [69.58957672, 22.43985939], [69.58957672, 22.44014168], [69.58985901, 22.44014168], [69.58985901, 22.44153023], [69.5901413, 22.44152832], [69.5901413, 22.44180489], [69.59041595, 22.44180489], [69.59041595, 22.44208336], [69.59069061, 22.44208336], [69.59069824, 22.44236183], [69.59124756, 22.44236183], [69.59124756, 22.44320107], [69.59179688, 22.44320107], [69.59179688, 22.44375038], [69.59236908, 22.44375038], [69.59236908, 22.44403076], [69.59263611, 22.44402695], [69.59263611, 22.44458389], [69.5929184, 22.44458008], [69.5929184, 22.44486046], [69.59319305, 22.44486046], [69.59319305, 22.44513893], [69.59348297, 22.44512939], [69.59348297, 22.44542122], [69.59402466, 22.4454174], [69.59402466, 22.44569588], [69.59486389, 22.44569588], [69.59486389, 22.44597244], [69.59541321, 22.44597054], [69.59541321, 22.44625092], [69.59625244, 22.44625092], [69.59625244, 22.44652939], [69.59680176, 22.44652939], [69.59680176, 22.44680977], [69.59764099, 22.44680405], [69.59764099, 22.44708252], [69.59819794, 22.44708061], [69.59819794, 22.44736099], [69.59902954, 22.44736099], [69.59902954, 22.44763947], [69.6001358, 22.44763947], [69.6001358, 22.44791985], [69.60069275, 22.44791985], [69.60069275, 22.44820023], [69.6020813, 22.4481945], [69.6020813, 22.44847298], [69.60263824, 22.44847107], [69.60263824, 22.44874954], [69.60320282, 22.44874954], [69.60320282, 22.44902992], [69.60375214, 22.44902992], [69.60375214, 22.4493103], [69.60430908, 22.44930649], [69.60430908, 22.44958305], [69.6048584, 22.44958305], [69.6048584, 22.44986153], [69.60542297, 22.44985962], [69.60542297, 22.45013809], [69.60597229, 22.45013809], [69.60597229, 22.45042038], [69.60652924, 22.45042038], [69.60652924, 22.45070076], [69.60708618, 22.45069504], [69.60708618, 22.4509716], [69.60791779, 22.4509697], [69.60791779, 22.45126152], [69.61125183, 22.45126152], [69.61125183, 22.4509697], [69.61180878, 22.4509716], [69.61180878, 22.45069504], [69.61291504, 22.45069504], [69.61291504, 22.4509716], [69.61319733, 22.4509697], [69.61319733, 22.45153046], [69.61347198, 22.45153046], [69.61347198, 22.45181084], [69.61374664, 22.45180511], [69.61374664, 22.45236206], [69.61402893, 22.45235825], [69.61402893, 22.45264053], [69.61430359, 22.45264053], [69.61430359, 22.45347023], [69.61458588, 22.45346832], [69.61458588, 22.45375061], [69.61486053, 22.45375061], [69.61486053, 22.45402908], [69.61513519, 22.45402718], [69.61513519, 22.45430565], [69.61569214, 22.45430565], [69.61569214, 22.45458412], [69.6159668, 22.45458031], [69.6159668, 22.45486259], [69.616539, 22.45486259], [69.616539, 22.45514107], [69.61680603, 22.45514107], [69.61680603, 22.45541954], [69.61736298, 22.45541763], [69.61736298, 22.4556942], [69.61819458, 22.4556942], [69.61819458, 22.45597267], [69.61846924, 22.45597267], [69.61846924, 22.45625114], [69.61875153, 22.45625114], [69.61875153, 22.45681], [69.61958313, 22.45680618], [69.61958313, 22.45708275], [69.62014008, 22.4570694], [69.62014008, 22.45736122], [69.62069702, 22.45736122], [69.62069702, 22.45763969], [69.62152863, 22.45763969], [69.62152863, 22.45792007], [69.62236023, 22.45791626], [69.62236023, 22.45819473], [69.62291718, 22.45819473], [69.62291718, 22.4584713], [69.62374878, 22.45846939], [69.62374878, 22.45874977], [69.62403107, 22.45874977], [69.62403107, 22.45903015], [69.62486267, 22.45902824], [69.62486267, 22.45930481], [69.62541962, 22.45930481], [69.62541962, 22.45958328], [69.62763977, 22.45958328], [69.62763977, 22.45930481], [69.62819672, 22.45930481], [69.62819672, 22.45902824], [69.62874603, 22.45903015], [69.62874603, 22.45874977], [69.62902832, 22.45874977], [69.62902832, 22.45846939], [69.62930298, 22.4584713], [69.62930298, 22.45791626], [69.6295929, 22.45792007], [69.6295929, 22.45763969], [69.63041687, 22.45763969], [69.63041687, 22.45736122], [69.63069153, 22.45736122], [69.63069153, 22.4570694], [69.63097382, 22.45708275], [69.63097382, 22.45680618], [69.63181305, 22.45681], [69.63181305, 22.45652962], [69.63208008, 22.45652962], [69.63208008, 22.45625114], [69.63263702, 22.45625114], [69.63263702, 22.45597267], [69.63346863, 22.45597267], [69.63346863, 22.4556942], [69.63430786, 22.4556942], [69.63430786, 22.45513916], [69.63458252, 22.45514107], [69.63458252, 22.45486259], [69.63485718, 22.45486259], [69.63485718, 22.45429993], [69.63513947, 22.45430565], [69.63513947, 22.45402718], [69.63569641, 22.45402908], [69.63569641, 22.45375061], [69.63625336, 22.45375061], [69.63625336, 22.45346832], [69.63708496, 22.45347023], [69.63708496, 22.45319366], [69.63764191, 22.45319366], [69.63764191, 22.4529171], [69.63819122, 22.45292091], [69.63819122, 22.45264053], [69.63874817, 22.45264053], [69.63874817, 22.45235825], [69.63903046, 22.45236206], [69.63903046, 22.45208359], [69.63930511, 22.45208359], [69.63930511, 22.45180511], [69.63957977, 22.45181084], [69.63957977, 22.45153046], [69.64013672, 22.45153046], [69.64013672, 22.45126152], [69.64041901, 22.45126152], [69.64041901, 22.4509697], [69.64069366, 22.4509716], [69.64069366, 22.45069504], [69.64180756, 22.45069504], [69.64180756, 22.4509716], [69.64263916, 22.4509716], [69.64263916, 22.45069504], [69.64319611, 22.45070076], [69.64319611, 22.45013809], [69.64347839, 22.45013809], [69.64347839, 22.4493103], [69.64375305, 22.4493103], [69.64375305, 22.44874954], [69.64402771, 22.44874954], [69.64402771, 22.44820023], [69.64430237, 22.44820023], [69.64430237, 22.44763947], [69.64457703, 22.44763947], [69.64457703, 22.44708061], [69.64485931, 22.44708252], [69.64485931, 22.44652748], [69.6451416, 22.44652939], [69.6451416, 22.44597054], [69.64541626, 22.44597244], [69.64541626, 22.4454174], [69.64569092, 22.44542122], [69.64569092, 22.44486046], [69.64597321, 22.44486046], [69.64597321, 22.44431114], [69.64624786, 22.44431114], [69.64624786, 22.44375038], [69.64652252, 22.44375038], [69.64652252, 22.44320107], [69.64679718, 22.44320107], [69.64679718, 22.4426403], [69.6470871, 22.4426403], [69.6470871, 22.4420681], [69.64736176, 22.44208336], [69.64736176, 22.44096947], [69.6470871, 22.44096947], [69.6470871, 22.44014168], [69.64736176, 22.44014168], [69.64736176, 22.43985939], [69.6470871, 22.43985939], [69.6470871, 22.43930626], [69.64736176, 22.43931961], [69.64736176, 22.43902969], [69.64763641, 22.43902969], [69.64763641, 22.43875122], [69.6479187, 22.43875122], [69.6479187, 22.43847084], [69.64819336, 22.43847275], [69.64819336, 22.43819427], [69.64847565, 22.43819427], [69.64847565, 22.4370842], [69.64819336, 22.4370842], [69.64819336, 22.43652725], [69.6479187, 22.43653107], [69.6479187, 22.43597031], [69.64763641, 22.43597221], [69.64763641, 22.43541527], [69.6470871, 22.43542099], [69.6470871, 22.43514061], [69.64597321, 22.43514061], [69.64597321, 22.43486023], [69.6451416, 22.43486023], [69.6451416, 22.43457985], [69.64485931, 22.43458366], [69.64485931, 22.43402863], [69.6451416, 22.43403053], [69.6451416, 22.43375015], [69.64541626, 22.43375015], [69.64541626, 22.43346977], [69.64569092, 22.43347168], [69.64569092, 22.43291664], [69.64597321, 22.43292046], [69.64597321, 22.43264008], [69.64679718, 22.43264008], [69.64679718, 22.4323597], [69.64763641, 22.4323616], [69.64763641, 22.43208313], [69.6498642, 22.43208313], [69.6498642, 22.43180466], [69.6506958, 22.43180466], [69.6506958, 22.43152809], [69.65180206, 22.43153], [69.65180206, 22.43124962], [69.65235901, 22.43124962], [69.65235901, 22.43153], [69.6534729, 22.43153], [69.6534729, 22.43124962], [69.65429688, 22.43124962], [69.65429688, 22.43069267], [69.65458679, 22.43069458], [69.65458679, 22.43013954], [69.65486145, 22.43013954], [69.65486145, 22.4295826], [69.65513611, 22.4295826], [69.65513611, 22.42930603], [69.65569305, 22.42930984], [69.65569305, 22.42902946], [69.65598297, 22.42902946], [69.65598297, 22.4287529], [69.65651703, 22.4287529], [69.65651703, 22.42847252], [69.65680695, 22.42847252], [69.65680695, 22.42819405], [69.6570816, 22.42819405], [69.6570816, 22.42624855], [69.65680695, 22.42624855], [69.65680695, 22.4256897], [69.65652466, 22.42569351], [69.65652466, 22.42514038], [69.65625, 22.42514038], [69.65625, 22.42485809], [69.65597534, 22.42486191], [69.65597534, 22.42458344], [69.6554184, 22.42458344], [69.6554184, 22.42430496], [69.65513611, 22.42432022], [69.65513611, 22.4240303], [69.65486145, 22.4240303], [69.65486145, 22.42374992], [69.65458679, 22.42374992], [69.65458679, 22.42346954], [69.65374756, 22.42347145], [69.65374756, 22.42319489], [69.65319824, 22.42319489], [69.65319824, 22.42291641], [69.65264893, 22.42292023], [69.65264893, 22.42263985], [69.65207672, 22.42263985], [69.65207672, 22.42235947], [69.6515274, 22.42236137], [69.6515274, 22.4220829], [69.65125275, 22.4220829], [69.65125275, 22.42180634], [69.64958191, 22.42180634], [69.64958191, 22.4220829], [69.64930725, 22.4220829], [69.64930725, 22.42180634], [69.64903259, 22.42181015], [69.64903259, 22.42152977], [69.64848328, 22.42152977], [69.64848328, 22.42095947], [69.64819336, 22.42097282], [69.64819336, 22.42069435], [69.6479187, 22.42069435], [69.6479187, 22.42041588], [69.64763641, 22.42041969], [69.64763641, 22.41986084], [69.64736176, 22.41986084], [69.64736176, 22.41958046], [69.6470871, 22.41958237], [69.6470871, 22.41875076], [69.64679718, 22.41875076], [69.64679718, 22.41819], [69.64653015, 22.41819382], [69.64653015, 22.41763878], [69.64569092, 22.41764069], [69.64569092, 22.41736031], [69.64541626, 22.41736031], [69.64541626, 22.4168129], [69.64485931, 22.4168129], [69.64485931, 22.41653061], [69.64457703, 22.41653061], [69.64457703, 22.41625023], [69.64430237, 22.41625023], [69.64430237, 22.41597176], [69.64347076, 22.41597366], [69.64347076, 22.41569519], [69.64235687, 22.41570282], [69.64235687, 22.41542053], [69.64208221, 22.41542053], [69.64208221, 22.41514969], [69.64180756, 22.41514969], [69.64180756, 22.41319084], [69.64152527, 22.41319466], [69.64152527, 22.41291618], [69.64125061, 22.41292191], [69.64125061, 22.41235924], [69.64097595, 22.41235924], [69.64097595, 22.41208839], [69.64068604, 22.41208839], [69.64068604, 22.41180992], [69.64041901, 22.41180992], [69.64041901, 22.41152954], [69.64013672, 22.41152954], [69.64013672, 22.41124916], [69.63986206, 22.41124916], [69.63986206, 22.41069031], [69.63957977, 22.41069412], [69.63957977, 22.41041946], [69.63931274, 22.41041946], [69.63931274, 22.41014099], [69.63903046, 22.41014099], [69.63903046, 22.40986061], [69.63874817, 22.40986061], [69.63874817, 22.40875053], [69.63846588, 22.40875053], [69.63846588, 22.40818977], [69.63819122, 22.40819359], [69.63819122, 22.40791512], [69.63791656, 22.40792084], [69.63791656, 22.40764046], [69.63735199, 22.40764046], [69.63735199, 22.40736008], [69.63708496, 22.40736198], [69.63708496, 22.40708351], [69.63680267, 22.40708351], [69.63680267, 22.40680695], [69.63652802, 22.40681076], [69.63652802, 22.40653038], [69.63458252, 22.40653038], [69.63458252, 22.40681076], [69.63291931, 22.40680695], [69.63291931, 22.40708351], [69.63236237, 22.40708351], [69.63236237, 22.40736198], [69.63181305, 22.40736008], [69.63181305, 22.40764046], [69.63124847, 22.40764046], [69.63124847, 22.40792084], [69.63097382, 22.40791512], [69.63097382, 22.40819359], [69.63069153, 22.40819359], [69.63069153, 22.40847206], [69.63041687, 22.40847015], [69.63041687, 22.40875053], [69.62930298, 22.40875053], [69.62930298, 22.40902519], [69.62902832, 22.40901947], [69.62902832, 22.40930939], [69.62819672, 22.40930557], [69.62819672, 22.40958405], [69.62735748, 22.40958023], [69.62735748, 22.40986061], [69.62680817, 22.40986061], [69.62680817, 22.41014099], [69.62596893, 22.41014099], [69.62596893, 22.41041946], [69.62541962, 22.41041946], [69.62541962, 22.41069412], [69.62513733, 22.41069412], [69.62458038, 22.41069412], [69.62458038, 22.4109726], [69.62403107, 22.41097069], [69.62403107, 22.41124916], [69.62319183, 22.41124916], [69.62319183, 22.41152954], [69.6223526, 22.41152954], [69.6223526, 22.41180992], [69.62180328, 22.41180992], [69.62180328, 22.41208839], [69.62097168, 22.41208839], [69.62097168, 22.41235924], [69.6204071, 22.41235924], [69.6204071, 22.41263771], [69.61958313, 22.41263771], [69.61958313, 22.41292191], [69.61902618, 22.41291618], [69.61902618, 22.41319466], [69.61819458, 22.41319466], [69.61819458, 22.41347313], [69.61763763, 22.41346931], [69.61763763, 22.4137516], [69.61708069, 22.4137516], [69.61708069, 22.41403008], [69.61624908, 22.41402817], [69.61624908, 22.41430473], [69.61569214, 22.41430473], [69.61569214, 22.41458321], [69.61514282, 22.41457939], [69.61514282, 22.41570282], [69.61486053, 22.41569519], [69.61486053, 22.41597366], [69.61458588, 22.41597176], [69.61458588, 22.41625023], [69.61429596, 22.41625023], [69.61429596, 22.41653061], [69.61207581, 22.41653061], [69.61207581, 22.4168129], [69.61042023, 22.41680527], [69.61042023, 22.41708374], [69.60986328, 22.41708183], [69.60986328, 22.41736031], [69.60874939, 22.41736031], [69.60874939, 22.41764069], [69.60791779, 22.41764069], [69.60791779, 22.41792107], [69.6076355, 22.41791725], [69.6076355, 22.41847229], [69.60708618, 22.41847038], [69.60708618, 22.41875076]]], [[[69.0901413, 22.43847275], [69.09069061, 22.43847084], [69.09069824, 22.43875122], [69.09152985, 22.43875122], [69.09152985, 22.43902969], [69.09208679, 22.43902969], [69.09208679, 22.43931961], [69.09236145, 22.43930626], [69.09236145, 22.43958282], [69.09263611, 22.43958282], [69.09263611, 22.43985939], [69.09319305, 22.43985939], [69.09319305, 22.44014168], [69.09430695, 22.44014168], [69.09430695, 22.44042015], [69.09513855, 22.44041634], [69.09513855, 22.44069481], [69.09541321, 22.44069481], [69.09541321, 22.44096947], [69.0956955, 22.44096947], [69.0956955, 22.44125175], [69.09597015, 22.44125175], [69.09597015, 22.44236183], [69.09513855, 22.44236183], [69.09513855, 22.44292068], [69.09486389, 22.44291687], [69.09486389, 22.44347382], [69.09513855, 22.44347191], [69.09513855, 22.44431114], [69.09541321, 22.44430542], [69.09541321, 22.44597244], [69.09401703, 22.44597054], [69.09402466, 22.44625092], [69.09348297, 22.44625092], [69.09348297, 22.44680977], [69.09319305, 22.44680977], [69.09319305, 22.44736099], [69.0929184, 22.44736099], [69.0929184, 22.44791985], [69.09263611, 22.44791412], [69.09263611, 22.44847298], [69.09236145, 22.44847107], [69.09236145, 22.44902992], [69.09263611, 22.44902992], [69.09263611, 22.4493103], [69.09319305, 22.44930649], [69.09319305, 22.44958305], [69.09348297, 22.44958115], [69.09348297, 22.45013809], [69.09375, 22.45013809], [69.09375, 22.45042038], [69.09401703, 22.45042038], [69.09401703, 22.45126152], [69.09263611, 22.45126152], [69.09263611, 22.45153046], [69.09236145, 22.45153046], [69.09236145, 22.45208359], [69.09375, 22.45208359], [69.09375, 22.45153046], [69.09401703, 22.45153046], [69.09401703, 22.45402908], [69.09375, 22.45402718], [69.09375, 22.45430565], [69.09347534, 22.45430565], [69.09347534, 22.45458412], [69.09319305, 22.45458031], [69.09319305, 22.45486259], [69.0929184, 22.45486259], [69.0929184, 22.45541954], [69.09263611, 22.45541573], [69.09263611, 22.4556942], [69.09236145, 22.45569038], [69.09236145, 22.45652962], [69.09208679, 22.45652962], [69.09208679, 22.45736122], [69.09236145, 22.45736122], [69.09236145, 22.45903015], [69.09263611, 22.45902824], [69.09263611, 22.45958328], [69.0929184, 22.45958328], [69.0929184, 22.45986176], [69.09319305, 22.45985985], [69.09319305, 22.46014023], [69.09348297, 22.46014023], [69.09348297, 22.46153069], [69.09597015, 22.46153069], [69.09597015, 22.46181107], [69.0984726, 22.46180534], [69.0984726, 22.46208382], [69.09958649, 22.46208], [69.09958649, 22.46236038], [69.1001358, 22.46236038], [69.1001358, 22.46264076], [69.10069275, 22.46264076], [69.10069275, 22.46292114], [69.10124969, 22.46292114], [69.10124969, 22.46319962], [69.10152435, 22.46319389], [69.10152435, 22.46347237], [69.1020813, 22.46347046], [69.1020813, 22.46375084], [69.10235596, 22.46375084], [69.10235596, 22.46403122], [69.1029129, 22.46403122], [69.1029129, 22.46430969], [69.10319519, 22.46430588], [69.10319519, 22.46458244], [69.10375214, 22.46458054], [69.10375214, 22.46486092], [69.10402679, 22.46486092], [69.10402679, 22.46513748], [69.10457611, 22.46513748], [69.10457611, 22.46541977], [69.1048584, 22.46541595], [69.1048584, 22.46569443], [69.10541534, 22.46569443], [69.10541534, 22.4659729], [69.10569763, 22.4659729], [69.10569763, 22.46625137], [69.10665131, 22.46624565], [69.10793304, 22.46623993], [69.10793304, 22.46653175], [69.10958099, 22.46653175], [69.10958099, 22.46681023], [69.11013794, 22.46680641], [69.11013794, 22.46708107], [69.11069489, 22.46708107], [69.11069489, 22.46736145], [69.11125183, 22.46736145], [69.11125183, 22.46764183], [69.11152649, 22.46764183], [69.11152649, 22.4679203], [69.11207581, 22.4679203], [69.11207581, 22.46820259], [69.11264038, 22.46819496], [69.11264038, 22.46846962], [69.11319733, 22.46846962], [69.11319733, 22.46875191], [69.11347198, 22.46875191], [69.11347198, 22.46903038], [69.11402893, 22.46902847], [69.11402893, 22.46930504], [69.11458588, 22.46930504], [69.11458588, 22.46958351], [69.11486053, 22.46958351], [69.11486053, 22.46986389], [69.11541748, 22.46986008], [69.11541748, 22.47014046], [69.11624908, 22.47014046], [69.11624908, 22.47042084], [69.11653137, 22.47041702], [69.11653137, 22.47069359], [69.11708069, 22.47069359], [69.11708069, 22.47097206], [69.11763763, 22.47097015], [69.11763763, 22.47125053], [69.11818695, 22.47125053], [69.11818695, 22.47153091], [69.11902618, 22.47153091], [69.11902618, 22.47180939], [69.11958313, 22.47180557], [69.11958313, 22.47208595], [69.12014008, 22.47208023], [69.12014008, 22.47236061], [69.12124634, 22.47236061], [69.12124634, 22.47264099], [69.12152863, 22.47264099], [69.12152863, 22.47291946], [69.12208557, 22.47291756], [69.12208557, 22.47319412], [69.12236023, 22.47319412], [69.12236023, 22.4734726], [69.12293243, 22.47347069], [69.12293243, 22.47375107], [69.12319183, 22.47375107], [69.12319183, 22.47402954], [69.12374878, 22.47402954], [69.12374878, 22.47430992], [69.12403107, 22.4743042], [69.12403107, 22.47458267], [69.12458038, 22.47458076], [69.12458038, 22.47486115], [69.12486267, 22.47486115], [69.12486267, 22.47513962], [69.12513733, 22.47513962], [69.12513733, 22.47542953], [69.12569427, 22.47541618], [69.12569427, 22.47569466], [69.12875366, 22.47569466], [69.12875366, 22.47597313], [69.12985992, 22.47597122], [69.12985992, 22.47624969], [69.13096619, 22.47624969], [69.13096619, 22.47652817], [69.13180542, 22.47652626], [69.13180542, 22.47680473], [69.13291931, 22.47680473], [69.13291931, 22.47708321], [69.13402557, 22.47708321], [69.13402557, 22.47736168], [69.13513947, 22.47735977], [69.13513947, 22.47763824], [69.13680267, 22.47763824], [69.13680267, 22.47735977], [69.13735962, 22.47736168], [69.13735962, 22.47708321], [69.13764191, 22.47708321], [69.13764191, 22.47680473], [69.13791656, 22.47680473], [69.13791656, 22.47708321], [69.1423645, 22.47708321], [69.1423645, 22.47736168], [69.14319611, 22.47736168], [69.14319611, 22.47708321], [69.14347076, 22.47708321], [69.14347076, 22.47652626], [69.14375305, 22.47652817], [69.14375305, 22.47624969], [69.14404297, 22.47624969], [69.14402771, 22.47541618], [69.14430237, 22.47542953], [69.14430237, 22.47513962], [69.14485931, 22.47513962], [69.14485931, 22.47486115], [69.14541626, 22.47486115], [69.14541626, 22.47458076], [69.14680481, 22.47458267], [69.14680481, 22.4743042], [69.14763641, 22.47430992], [69.14763641, 22.47402954], [69.14848328, 22.47402954], [69.14848328, 22.47153091], [69.14875031, 22.47153091], [69.14875031, 22.47125053], [69.14903259, 22.47125053], [69.14902496, 22.47097206], [69.14930725, 22.47097206], [69.14930725, 22.47069359], [69.14958191, 22.47069359], [69.14958191, 22.47041702], [69.15013885, 22.47042084], [69.15013885, 22.47014046], [69.15040588, 22.47014046], [69.15040588, 22.46875191], [69.15013885, 22.46875191], [69.15013885, 22.46846962], [69.1498642, 22.46846962], [69.1498642, 22.46819496], [69.14958191, 22.46820259], [69.14958191, 22.4679203], [69.14930725, 22.4679203], [69.14930725, 22.46764183], [69.14903259, 22.46764183], [69.14903259, 22.46736145], [69.14875031, 22.46736145], [69.14875031, 22.46708107], [69.1479187, 22.46708107], [69.1479187, 22.46680641], [69.14736176, 22.46681023], [69.14736176, 22.46653175], [69.14710236, 22.46653175], [69.14710236, 22.46596909], [69.14680481, 22.4659729], [69.14680481, 22.46513748], [69.1470871, 22.46513748], [69.1470871, 22.46458244], [69.14680481, 22.46458244], [69.14680481, 22.46319389], [69.14653015, 22.46319962], [69.14653015, 22.46292114], [69.14624786, 22.46292114], [69.14624786, 22.46264076], [69.14569092, 22.46264076], [69.14569092, 22.46236038], [69.14485931, 22.46236038], [69.14485931, 22.46208], [69.14430237, 22.46208], [69.14430237, 22.46236038], [69.14404297, 22.46236038], [69.14404297, 22.46264076], [69.14347076, 22.46264076], [69.14347076, 22.46319962], [69.14319611, 22.46319389], [69.14319611, 22.46347237], [69.14290619, 22.46347046], [69.14290619, 22.46375084], [69.14235687, 22.46375084], [69.14235687, 22.46403122], [69.1415329, 22.46403122], [69.1415329, 22.46430969], [69.14069366, 22.46430588], [69.14069366, 22.46458244], [69.13986206, 22.46458244], [69.13986206, 22.46291542], [69.13957977, 22.46292114], [69.13957977, 22.46264076], [69.13903046, 22.46264076], [69.13903046, 22.46236038], [69.13735962, 22.46236038], [69.13735962, 22.46264076], [69.13708496, 22.46263885], [69.13708496, 22.46347237], [69.13680267, 22.46347046], [69.13680267, 22.46403122], [69.13652802, 22.46403122], [69.13652802, 22.46430969], [69.13625336, 22.46430588], [69.13625336, 22.46458244], [69.13540649, 22.46458054], [69.13540649, 22.46486092], [69.13513947, 22.46486092], [69.13513947, 22.46541977], [69.13486481, 22.46541595], [69.13486481, 22.46569443], [69.13458252, 22.46569443], [69.13458252, 22.4659729], [69.13402557, 22.4659729], [69.13402557, 22.46569443], [69.13346863, 22.46569443], [69.13346863, 22.4659729], [69.13291931, 22.4659729], [69.13291931, 22.46625137], [69.13263702, 22.46623993], [69.13263702, 22.46653175], [69.13208008, 22.46653175], [69.13208008, 22.46623993], [69.13180542, 22.46625137], [69.13180542, 22.4659729], [69.13153076, 22.4659729], [69.13153076, 22.46569443], [69.13124847, 22.46569443], [69.13124847, 22.46541595], [69.12985992, 22.46541595], [69.12985992, 22.46569443], [69.12847137, 22.46569443], [69.12847137, 22.46541595], [69.12652588, 22.46541595], [69.12652588, 22.46569443], [69.12625122, 22.46569443], [69.12625122, 22.46625137], [69.12596893, 22.46623993], [69.12596893, 22.46681023], [69.12569427, 22.46680641], [69.12569427, 22.46708107], [69.12513733, 22.46708107], [69.12513733, 22.46736145], [69.12458038, 22.46736145], [69.12458038, 22.46764183], [69.12431335, 22.46764183], [69.12431335, 22.4679203], [69.12374878, 22.4679203], [69.12374878, 22.46820259], [69.12319183, 22.46819496], [69.12319183, 22.46846962], [69.12236023, 22.46846962], [69.12236023, 22.46819496], [69.12124634, 22.46820259], [69.12124634, 22.4679203], [69.12097168, 22.4679203], [69.12097168, 22.46764183], [69.11987305, 22.46764183], [69.11987305, 22.46736145], [69.11846924, 22.46736145], [69.11846924, 22.46708107], [69.11791992, 22.46708107], [69.11791992, 22.46680641], [69.11736298, 22.46681023], [69.11736298, 22.46653175], [69.11708069, 22.46653175], [69.11708069, 22.46623993], [69.11653137, 22.46625137], [69.11653137, 22.4659729], [69.11597443, 22.4659729], [69.11597443, 22.46569443], [69.11430359, 22.46569443], [69.11430359, 22.46541595], [69.11373901, 22.46541977], [69.11373901, 22.46513748], [69.11319733, 22.46513748], [69.11319733, 22.46486092], [69.11264038, 22.46486092], [69.11264038, 22.46458054], [69.11208344, 22.46458244], [69.11208344, 22.46430588], [69.11152649, 22.46430969], [69.11152649, 22.46403122], [69.11096954, 22.46403122], [69.11096954, 22.46375084], [69.11067963, 22.46375084], [69.11067963, 22.46347046], [69.11042023, 22.46347237], [69.11042023, 22.46319389], [69.11013794, 22.46319962], [69.11013794, 22.46264076], [69.10986328, 22.46264076], [69.10986328, 22.46236038], [69.10930634, 22.46236038], [69.10930634, 22.46181107], [69.10874939, 22.46181107], [69.10874939, 22.46125031], [69.1084671, 22.46125031], [69.1084671, 22.46070099], [69.10819244, 22.46070099], [69.10819244, 22.45792007], [69.1084671, 22.45792007], [69.1084671, 22.45652962], [69.10874939, 22.45652962], [69.10874939, 22.45569038], [69.10902405, 22.4556942], [69.10902405, 22.45402718], [69.10930634, 22.45402908], [69.10930634, 22.45235825], [69.10902405, 22.45235825], [69.10901642, 22.45207977], [69.10874939, 22.45208359], [69.10874939, 22.44874954], [69.1084671, 22.44874954], [69.1084671, 22.44847107], [69.10819244, 22.44847298], [69.10819244, 22.44791412], [69.10793304, 22.44791985], [69.10793304, 22.44708061], [69.1076355, 22.44708252], [69.1076355, 22.44597244], [69.10736084, 22.44597244], [69.10736084, 22.44486046], [69.10708618, 22.44486046], [69.10708618, 22.44236183], [69.10736084, 22.44236183], [69.10736084, 22.44180489], [69.1076355, 22.44180489], [69.1076355, 22.44069481], [69.10736084, 22.44069481], [69.10736084, 22.43930626], [69.10764313, 22.43931961], [69.10764313, 22.43875122], [69.10793304, 22.43875122], [69.10793304, 22.43791962], [69.10819244, 22.43791962], [69.10819244, 22.43764114], [69.1084671, 22.43764114], [69.1084671, 22.43736076], [69.10791779, 22.43736076], [69.10791779, 22.4370842], [69.10708618, 22.4370842], [69.10708618, 22.43680573], [69.10679626, 22.43680954], [69.10679626, 22.43653107], [69.10652924, 22.43653107], [69.10652924, 22.43625832], [69.10624695, 22.43625832], [69.10624695, 22.43514061], [69.10597229, 22.43514061], [69.10597229, 22.43486023], [69.10569763, 22.43486023], [69.10569763, 22.43457985], [69.10514069, 22.43458366], [69.10514069, 22.43430519], [69.1048584, 22.43431091], [69.1048584, 22.43403053], [69.10457611, 22.43403053], [69.10457611, 22.43375015], [69.10430908, 22.43375015], [69.10430908, 22.43346977], [69.10402679, 22.43347168], [69.10402679, 22.43291664], [69.10375214, 22.43292046], [69.10375214, 22.43264008], [69.10150909, 22.43264008], [69.10150909, 22.43292046], [69.10097504, 22.43291664], [69.10097504, 22.43319321], [69.1001358, 22.43319321], [69.1001358, 22.43291664], [69.09958649, 22.43292046], [69.09958649, 22.43264008], [69.09929657, 22.43264008], [69.09929657, 22.4323597], [69.09902954, 22.4323616], [69.09902954, 22.43180466], [69.0984726, 22.43180466], [69.0984726, 22.43152809], [69.09597015, 22.43153], [69.09597015, 22.43124962], [69.09513855, 22.43124962], [69.09513855, 22.43097115], [69.09486389, 22.43097305], [69.09486389, 22.43069458], [69.09430695, 22.43069458], [69.09430695, 22.43041611], [69.09401703, 22.43041992], [69.09401703, 22.43013191], [69.09347534, 22.43013954], [69.09347534, 22.42986107], [69.09319305, 22.42986107], [69.09319305, 22.4295826], [69.09263611, 22.4295826], [69.09263611, 22.42930603], [69.09236145, 22.42930984], [69.09236145, 22.42902946], [69.09179688, 22.42902946], [69.09179688, 22.4287529], [69.09152985, 22.4287529], [69.09152985, 22.42847252], [69.09124756, 22.42847252], [69.09124756, 22.42819405], [69.09069824, 22.42819405], [69.09069824, 22.42791748], [69.09041595, 22.42791939], [69.09041595, 22.42735863], [69.0901413, 22.42735863], [69.0901413, 22.42680931], [69.08985901, 22.42680931], [69.08985901, 22.42653084], [69.08956909, 22.42653084], [69.08956909, 22.42596817], [69.08930206, 22.42597008], [69.08930206, 22.42374992], [69.0890274, 22.42374992], [69.0890274, 22.42346954], [69.08875275, 22.42347145], [69.08875275, 22.42319489], [69.08847046, 22.42319489], [69.08847046, 22.42263794], [69.0881958, 22.42263985], [69.0881958, 22.42208099], [69.08791351, 22.4220829], [69.08791351, 22.42180634], [69.08735657, 22.42181015], [69.08735657, 22.42152977], [69.08653259, 22.42152977], [69.08653259, 22.42124939], [69.08597565, 22.42124939], [69.08597565, 22.42097282], [69.08486176, 22.42095947], [69.08486176, 22.42124939], [69.0845871, 22.42124939], [69.0845871, 22.42152977], [69.08430481, 22.42152786], [69.08430481, 22.4220829], [69.08376312, 22.42208099], [69.08376312, 22.42263985], [69.08347321, 22.42263985], [69.08347321, 22.42374992], [69.08376312, 22.42374992], [69.08376312, 22.42542076], [69.08403015, 22.42542076], [69.08403015, 22.42653084], [69.0845871, 22.42653084], [69.0845871, 22.42680931], [69.08486176, 22.42680931], [69.08486176, 22.42735863], [69.08513641, 22.42735863], [69.08513641, 22.4287529], [69.0854187, 22.4287529], [69.0854187, 22.42902946], [69.08569336, 22.42902946], [69.08569336, 22.42930984], [69.08597565, 22.42930603], [69.08597565, 22.4295826], [69.08569336, 22.4295826], [69.08569336, 22.43041992], [69.0854187, 22.43041611], [69.0854187, 22.43097115], [69.0854187, 22.43124962], [69.08513641, 22.43124962], [69.08513641, 22.43180466], [69.08486176, 22.43180466], [69.08486176, 22.43208313], [69.08513641, 22.43208122], [69.08513641, 22.43264008], [69.0854187, 22.43264008], [69.0854187, 22.43292046], [69.08652496, 22.43291664], [69.08652496, 22.43319321], [69.08708191, 22.43319321], [69.08708191, 22.43347168], [69.08763885, 22.43346977], [69.08763885, 22.43375015], [69.0881958, 22.43375015], [69.0881958, 22.43403053], [69.08875275, 22.43403053], [69.08875275, 22.43431091], [69.08930206, 22.43431091], [69.08930206, 22.43486023], [69.08956909, 22.43486023], [69.08956909, 22.43542099], [69.08985901, 22.43541527], [69.08985901, 22.43569374], [69.09041595, 22.43569374], [69.09041595, 22.43597221], [69.09069061, 22.43597031], [69.09069061, 22.43625069], [69.09069824, 22.43680954], [69.0909729, 22.43680954], [69.0909729, 22.43736076], [69.09069824, 22.43736076], [69.09069061, 22.43791962], [69.0901413, 22.4379158], [69.0901413, 22.43847275]]], [[[69.14208221, 22.45763969], [69.14208221, 22.4570694], [69.14180756, 22.45708275], [69.14180756, 22.45560837], [69.14180756, 22.45430565], [69.14208221, 22.45430565], [69.14208221, 22.45375061], [69.14235687, 22.45375061], [69.14235687, 22.45346832], [69.14263916, 22.45347023], [69.14263916, 22.4529171], [69.14180756, 22.4529171], [69.14180756, 22.45319366], [69.14152527, 22.45319366], [69.14152527, 22.45347023], [69.14125061, 22.45346832], [69.14125061, 22.45402908], [69.14097595, 22.45402718], [69.14097595, 22.45458412], [69.14069366, 22.45458412], [69.14069366, 22.4550209], [69.14069366, 22.45597267], [69.14096832, 22.45597267], [69.14096832, 22.45681], [69.14125061, 22.45681], [69.14125061, 22.45736122], [69.14152527, 22.45736122], [69.14152527, 22.45763969], [69.14208221, 22.45763969]]], [[[69.0890274, 22.49069405], [69.0890274, 22.49041939], [69.08930206, 22.49043083], [69.08930206, 22.49014091], [69.0890274, 22.49014091], [69.0890274, 22.48986053], [69.08875275, 22.48986053], [69.08875275, 22.48931122], [69.08847046, 22.48931122], [69.08847046, 22.48875046], [69.0881958, 22.48875046], [69.0881958, 22.48847008], [69.08791351, 22.48847198], [69.08791351, 22.48819351], [69.08763885, 22.48819351], [69.08763885, 22.48791695], [69.08682251, 22.48792076], [69.08682251, 22.48736954], [69.08653259, 22.48736954], [69.08653259, 22.48707962], [69.08680725, 22.48708344], [69.08680725, 22.48680305], [69.08653259, 22.48681068], [69.08653259, 22.4865303], [69.08625031, 22.4865303], [69.08625031, 22.48624992], [69.08597565, 22.48624992], [69.08597565, 22.48597145], [69.0854187, 22.48597145], [69.0854187, 22.48569489], [69.08513641, 22.48569489], [69.08513641, 22.48541641], [69.08486176, 22.48542023], [69.08486176, 22.48513985], [69.08403015, 22.48513794], [69.08403015, 22.48569489], [69.08430481, 22.48569489], [69.08430481, 22.48597145], [69.0845871, 22.48597145], [69.0845871, 22.48708344], [69.08486176, 22.48707962], [69.08486176, 22.48764038], [69.08513641, 22.48763847], [69.08513641, 22.4881897], [69.0854187, 22.48819542], [69.0854187, 22.48847198], [69.08569336, 22.48847008], [69.08569336, 22.48875046], [69.08598328, 22.48875046], [69.08598328, 22.48903084], [69.08653259, 22.48903084], [69.08653259, 22.48931122], [69.08680725, 22.4893055], [69.08680725, 22.48958397], [69.08708191, 22.48958015], [69.08708191, 22.48986053], [69.08735657, 22.48986053], [69.08735657, 22.49014091], [69.08790588, 22.49014091], [69.08790588, 22.49043083], [69.08847046, 22.49041939], [69.08847046, 22.49069405], [69.0890274, 22.49069405]]], [[[69.32428741, 22.52763939], [69.32428741, 22.52736092], [69.32485962, 22.52736092], [69.32485962, 22.52708054], [69.32541656, 22.52708244], [69.32541656, 22.52680588], [69.32596588, 22.52680969], [69.32596588, 22.52654076], [69.32624817, 22.52654076], [69.32624817, 22.52625084], [69.32681274, 22.52625084], [69.32680511, 22.52597237], [69.32736206, 22.52597237], [69.32736206, 22.5256958], [69.32791901, 22.5256958], [69.32791901, 22.52541733], [69.32875061, 22.52542114], [69.32875061, 22.52514076], [69.3290329, 22.52514076], [69.3290329, 22.52486038], [69.32930756, 22.52486038], [69.32930756, 22.52458191], [69.33013916, 22.52458382], [69.33013916, 22.52430534], [69.33097076, 22.52430534], [69.33097076, 22.52458382], [69.33125305, 22.52458191], [69.33125305, 22.52486038], [69.33180237, 22.52486038], [69.33180237, 22.52514076], [69.33207703, 22.52514076], [69.33207703, 22.52542114], [69.33235931, 22.52541733], [69.33235931, 22.5256958], [69.33291626, 22.5256958], [69.33291626, 22.52597237], [69.33403015, 22.52597237], [69.33403015, 22.5256958], [69.33985901, 22.5256958], [69.33985901, 22.52541733], [69.34041595, 22.52542114], [69.34041595, 22.52514076], [69.34319305, 22.52514076], [69.34319305, 22.52542114], [69.34347534, 22.52541733], [69.34347534, 22.52597237], [69.34401703, 22.52597046], [69.34401703, 22.52625084], [69.34430695, 22.52625084], [69.34430695, 22.52654076], [69.34485626, 22.52654076], [69.34485626, 22.52680969], [69.3456955, 22.52680588], [69.3456955, 22.52708244], [69.3484726, 22.52708244], [69.3484726, 22.52680588], [69.34874725, 22.52680969], [69.34874725, 22.52625084], [69.34929657, 22.52625084], [69.34929657, 22.52597046], [69.34958649, 22.52597237], [69.34958649, 22.52541733], [69.34986115, 22.52541733], [69.34986115, 22.5256958], [69.3501358, 22.52569008], [69.3501358, 22.52625084], [69.35041809, 22.52625084], [69.35041809, 22.52654076], [69.35124969, 22.52654076], [69.35124969, 22.52625084], [69.35151672, 22.52625084], [69.35151672, 22.52597046], [69.35180664, 22.52597237], [69.35180664, 22.5256958], [69.3520813, 22.5256958], [69.3520813, 22.52541733], [69.35235596, 22.52542114], [69.35235596, 22.52514076], [69.35263824, 22.52514076], [69.35263824, 22.52486038], [69.35320282, 22.52486038], [69.35319519, 22.52458382], [69.35346985, 22.52458382], [69.35346985, 22.52430534], [69.35402679, 22.52431107], [69.35402679, 22.52403069], [69.35459137, 22.52403069], [69.35459137, 22.52375031], [69.3548584, 22.52375031], [69.3548584, 22.52347946], [69.35514069, 22.52347946], [69.35514069, 22.5232029], [69.35542297, 22.5232029], [69.35542297, 22.52292061], [69.35597229, 22.52292061], [69.35597229, 22.52264023], [69.35624695, 22.52264023], [69.35624695, 22.52236176], [69.35652924, 22.52236176], [69.35652924, 22.52208328], [69.35680389, 22.52208328], [69.35680389, 22.52180481], [69.35708618, 22.52180481], [69.35708618, 22.52125168], [69.35736084, 22.52125168], [69.35736084, 22.52096939], [69.3576355, 22.52096939], [69.3576355, 22.52069473], [69.35791779, 22.52069473], [69.35791779, 22.5201416], [69.35819244, 22.5201416], [69.35819244, 22.51985931], [69.3584671, 22.51985931], [69.3584671, 22.51958084], [69.35874939, 22.51958275], [69.35874939, 22.51930618], [69.35901642, 22.51930809], [69.35901642, 22.51874924], [69.35930634, 22.51874924], [69.35930634, 22.51847076], [69.35958099, 22.51847267], [69.35958099, 22.5181942], [69.35986328, 22.5181942], [69.35986328, 22.51763725], [69.36013794, 22.51764107], [69.36013794, 22.51708031], [69.36042023, 22.51708412], [69.36042023, 22.51652527], [69.36068726, 22.51653099], [69.36068726, 22.51625061], [69.36096954, 22.51625061], [69.36096954, 22.51568985], [69.36125183, 22.51569366], [69.36125183, 22.51513863], [69.36235809, 22.51514053], [69.36235809, 22.51486015], [69.36264038, 22.51486206], [69.36264038, 22.51458359], [69.36291504, 22.51458359], [69.36291504, 22.51375008], [69.36347198, 22.51375008], [69.36345673, 22.51320076], [69.36374664, 22.51320076], [69.36374664, 22.51300049], [69.36374664, 22.51236153], [69.36347198, 22.51236153], [69.36347198, 22.51180649], [69.36319733, 22.51180077], [69.36319733, 22.51152802], [69.36264038, 22.51153946], [69.36264038, 22.51124954], [69.36235809, 22.51124954], [69.36235809, 22.51097107], [69.36180878, 22.51097488], [69.36180878, 22.5106945], [69.36125183, 22.5106945], [69.36125183, 22.51041603], [69.36013794, 22.51041985], [69.36013794, 22.51013947], [69.35930634, 22.51013947], [69.35930634, 22.5098629], [69.35819244, 22.5098629], [69.35819244, 22.50958252], [69.35708618, 22.50958252], [69.35708618, 22.50930595], [69.35652924, 22.50930977], [69.35652924, 22.50902939], [69.35624695, 22.50902939], [69.35624695, 22.50847244], [69.35597229, 22.50847244], [69.35597229, 22.50819397], [69.35569763, 22.50819397], [69.35569763, 22.5079174], [69.35542297, 22.50792122], [69.35542297, 22.50764275], [69.35514069, 22.50764275], [69.35514069, 22.50735855], [69.35458374, 22.50735855], [69.35458374, 22.50708389], [69.35430908, 22.50708389], [69.35430908, 22.50680542], [69.35402679, 22.50680923], [69.35402679, 22.50653076], [69.35375214, 22.50653076], [69.35375214, 22.50624847], [69.35346985, 22.50624847], [69.35346985, 22.50596809], [69.35319519, 22.50597191], [69.35319519, 22.50569534], [69.35263824, 22.50569916], [69.35263824, 22.50541115], [69.35236359, 22.50541878], [69.35236359, 22.5051384], [69.3520813, 22.5051384], [69.3520813, 22.50485992], [69.35152435, 22.50486183], [69.35152435, 22.50458336], [69.35041809, 22.50458336], [69.35041809, 22.50430489], [69.3501358, 22.50430489], [69.3501358, 22.50402641], [69.3493042, 22.50402641], [69.3493042, 22.50430489], [69.3484726, 22.50430489], [69.3484726, 22.50402641], [69.34708405, 22.50402641], [69.34708405, 22.50430489], [69.3465271, 22.50430489], [69.3465271, 22.50458336], [69.34625244, 22.50458336], [69.34625244, 22.50486183], [69.34542084, 22.50485992], [69.34542084, 22.5051384], [69.34486389, 22.5051384], [69.34486389, 22.50541878], [69.34401703, 22.50541115], [69.34401703, 22.50569916], [69.34347534, 22.50569534], [69.34347534, 22.50597191], [69.3429184, 22.50596809], [69.3429184, 22.50624847], [69.34236145, 22.50624847], [69.34236145, 22.50653076], [69.34152985, 22.50653076], [69.34152985, 22.50680923], [69.3409729, 22.50680542], [69.3409729, 22.50708389], [69.34041595, 22.50707817], [69.34041595, 22.50735855], [69.33970642, 22.50735855], [69.33513641, 22.50735855], [69.33513641, 22.50764275], [69.3345871, 22.50764275], [69.3345871, 22.50792122], [69.33403015, 22.5079174], [69.33403015, 22.50819397], [69.33347321, 22.50819397], [69.33347321, 22.50847244], [69.33291626, 22.50847244], [69.33291626, 22.50875282], [69.3326416, 22.50875282], [69.3326416, 22.50902939], [69.33207703, 22.50902939], [69.33207703, 22.50930977], [69.33152771, 22.50930595], [69.33152771, 22.50958252], [69.33097076, 22.50958252], [69.33097076, 22.5098629], [69.33041382, 22.5098629], [69.33042145, 22.51013947], [69.32985687, 22.51013947], [69.32985687, 22.51041985], [69.32958221, 22.51041603], [69.32958221, 22.5106945], [69.32902527, 22.5106945], [69.32902527, 22.51097488], [69.32875061, 22.51097107], [69.32875061, 22.51124954], [69.32818604, 22.51124954], [69.32818604, 22.51153946], [69.32791901, 22.51152802], [69.32791901, 22.51180077], [69.32736206, 22.51180649], [69.32736206, 22.51208305], [69.32707977, 22.51208305], [69.32707977, 22.51236153], [69.32653046, 22.51235962], [69.32653046, 22.51264], [69.32624817, 22.51264], [69.32624817, 22.51292038], [69.32569122, 22.51292038], [69.32569122, 22.51320076], [69.32514191, 22.51319313], [69.32514191, 22.5134716], [69.32485962, 22.5134697], [69.32485962, 22.51375008], [69.32428741, 22.51375008], [69.32428741, 22.51403046], [69.32402802, 22.51403046], [69.32402802, 22.51431084], [69.32347107, 22.51430511], [69.32347107, 22.51458359], [69.32319641, 22.51457977], [69.32319641, 22.51486015], [69.32263947, 22.51486015], [69.32263947, 22.51514053], [69.32235718, 22.51514053], [69.32235718, 22.51542091], [69.32180786, 22.51541519], [69.32180786, 22.51569366], [69.32152557, 22.51569366], [69.32152557, 22.51597214], [69.32125092, 22.51597023], [69.32125092, 22.51625061], [69.32068634, 22.51625061], [69.32068634, 22.51653099], [69.32041931, 22.51653099], [69.32041931, 22.51680946], [69.32013702, 22.51680565], [69.32013702, 22.51708412], [69.31986237, 22.51708412], [69.31986237, 22.51736069], [69.31931305, 22.51735115], [69.31931305, 22.51764107], [69.31903076, 22.51764107], [69.31903076, 22.51791954], [69.31874847, 22.51791573], [69.31874847, 22.5181942], [69.31819153, 22.5181942], [69.31819153, 22.51847267], [69.31791687, 22.51847076], [69.31791687, 22.51874924], [69.31764221, 22.51874924], [69.31764221, 22.51902962], [69.3170929, 22.51902962], [69.3170929, 22.51930809], [69.31652832, 22.51930618], [69.31652832, 22.51958275], [69.31597137, 22.51958084], [69.31597137, 22.51985931], [69.31569672, 22.51985931], [69.31569672, 22.52069473], [69.3154068, 22.52069092], [69.3154068, 22.52292061], [69.31569672, 22.52292061], [69.31569672, 22.52347946], [69.31597137, 22.52347946], [69.31597137, 22.52403069], [69.31625366, 22.52402687], [69.31625366, 22.52458382], [69.31652832, 22.52458191], [69.31652832, 22.52486038], [69.31680298, 22.52486038], [69.31680298, 22.52514076], [69.3170929, 22.52514076], [69.3170929, 22.52542114], [69.31735992, 22.52541733], [69.31735992, 22.5256958], [69.31791687, 22.5256958], [69.31791687, 22.52597237], [69.31930542, 22.52597237], [69.31930542, 22.52625084], [69.31986237, 22.52625084], [69.31986237, 22.52654076], [69.32041931, 22.52654076], [69.32041931, 22.52680969], [69.32069397, 22.52680588], [69.32069397, 22.52708244], [69.32125092, 22.52708054], [69.32125092, 22.52736092], [69.32180786, 22.52736092], [69.32180786, 22.52763939], [69.32428741, 22.52763939]]], [[[69.30208588, 22.47402954], [69.30208588, 22.47347069], [69.30236053, 22.4734726], [69.30236053, 22.47319412], [69.30263519, 22.47319412], [69.30263519, 22.47236061], [69.30291748, 22.47236061], [69.30291748, 22.47208023], [69.30319214, 22.47208595], [69.30319214, 22.47180557], [69.3034668, 22.47180939], [69.3034668, 22.47125053], [69.30374908, 22.47125053], [69.30374908, 22.47042084], [69.30403137, 22.47042084], [69.30403137, 22.46986008], [69.30430603, 22.46986389], [69.30430603, 22.46958351], [69.30486298, 22.46958351], [69.30486298, 22.46986389], [69.30513763, 22.46986008], [69.30513763, 22.47042084], [69.30486298, 22.47041702], [69.30486298, 22.47069359], [69.30458069, 22.47068977], [69.30458069, 22.47153091], [69.30486298, 22.47153091], [69.30486298, 22.47180939], [69.30708313, 22.47180557], [69.30708313, 22.47208595], [69.30902863, 22.47208595], [69.30902863, 22.47180557], [69.31291962, 22.47180557], [69.31291962, 22.47208595], [69.31513977, 22.47208023], [69.31513977, 22.47236061], [69.31874847, 22.47236061], [69.31874847, 22.47208023], [69.31930542, 22.47208595], [69.31930542, 22.47180557], [69.31986237, 22.47180939], [69.31986237, 22.47153091], [69.32041931, 22.47153091], [69.32041931, 22.47125053], [69.32096863, 22.47125053], [69.32096863, 22.47097015], [69.32180786, 22.47097206], [69.32180786, 22.47069359], [69.32236481, 22.47069359], [69.32236481, 22.47041702], [69.32290649, 22.47042084], [69.32290649, 22.47014046], [69.32347107, 22.47014046], [69.32347107, 22.46986008], [69.32402802, 22.46986389], [69.32402802, 22.46958351], [69.32458496, 22.46958351], [69.32458496, 22.46902847], [69.32485962, 22.46903038], [69.32485962, 22.46820259], [69.32514191, 22.46820259], [69.32514191, 22.4679203], [69.32485962, 22.4679203], [69.32485962, 22.46764183], [69.32514191, 22.46764183], [69.32514191, 22.46736145], [69.32541656, 22.46736145], [69.32541656, 22.46708107], [69.32569122, 22.46708107], [69.32569122, 22.46680641], [69.32596588, 22.46681023], [69.32596588, 22.46623993], [69.32624817, 22.46625137], [69.32624817, 22.46513748], [69.32653046, 22.46513748], [69.32653046, 22.46458054], [69.32680511, 22.46458244], [69.32680511, 22.46430588], [69.32707977, 22.46430969], [69.32707977, 22.46403122], [69.3273468, 22.46403122], [69.3273468, 22.46375084], [69.32763672, 22.46375084], [69.32763672, 22.46347046], [69.32791901, 22.46347237], [69.32791901, 22.46208382], [69.32763672, 22.46208382], [69.32763672, 22.46041679], [69.3273468, 22.46042061], [69.3273468, 22.45874977], [69.32707977, 22.45874977], [69.32707977, 22.45763969], [69.32680511, 22.45763969], [69.32680511, 22.45708275], [69.32653046, 22.45708275], [69.32653046, 22.45680618], [69.32624817, 22.45681], [69.32624817, 22.45652962], [69.32596588, 22.45652962], [69.32596588, 22.45625114], [69.32569122, 22.45625114], [69.32569122, 22.45597267], [69.32541656, 22.45597267], [69.32541656, 22.4556942], [69.32514191, 22.4556942], [69.32514191, 22.45541573], [69.32485962, 22.45541954], [69.32485962, 22.45514107], [69.32457733, 22.45514107], [69.32457733, 22.45486259], [69.32428741, 22.45486259], [69.32428741, 22.45458031], [69.32402802, 22.45458412], [69.32402802, 22.45430565], [69.32375336, 22.45430565], [69.32375336, 22.45402718], [69.32347107, 22.45402908], [69.32347107, 22.45375061], [69.32319641, 22.45375061], [69.32319641, 22.45346832], [69.32291412, 22.45347023], [69.32291412, 22.45319366], [69.32263947, 22.45319366], [69.32263947, 22.45264053], [69.32208252, 22.45264053], [69.32208252, 22.45235825], [69.32180786, 22.45235825], [69.32180786, 22.45207977], [69.32152557, 22.45208359], [69.32152557, 22.45153046], [69.32068634, 22.45153046], [69.32068634, 22.45126152], [69.32041931, 22.45126152], [69.32041931, 22.4509697], [69.31819153, 22.4509697], [69.31819153, 22.45126152], [69.31735992, 22.45126152], [69.31735992, 22.45153046], [69.31624603, 22.45153046], [69.31624603, 22.45126152], [69.31597137, 22.45126152], [69.31597137, 22.45153046], [69.31532288, 22.45153046], [69.31069183, 22.45153046], [69.31069183, 22.45208359], [69.31041718, 22.45208359], [69.31041718, 22.45180511], [69.31014252, 22.45181084], [69.31014252, 22.45153046], [69.30960083, 22.45153046], [69.30960083, 22.45181084], [69.30847168, 22.45180511], [69.30847168, 22.45208359], [69.30764008, 22.45207977], [69.30764008, 22.45235825], [69.30654144, 22.45235825], [69.30654144, 22.45264053], [69.30568695, 22.45264053], [69.30568695, 22.45292091], [69.30541992, 22.4529171], [69.30541992, 22.45319366], [69.30430603, 22.45319366], [69.30430603, 22.45347023], [69.30347443, 22.45347023], [69.30347443, 22.45319366], [69.30263519, 22.45319366], [69.30263519, 22.4529171], [69.30124664, 22.4529171], [69.30124664, 22.45319366], [69.30097198, 22.45319366], [69.30097198, 22.45347023], [69.30069733, 22.45346832], [69.30069733, 22.45375061], [69.30014038, 22.45375061], [69.30014038, 22.45430565], [69.29985809, 22.45429993], [69.29985809, 22.45541954], [69.29958344, 22.45541573], [69.29958344, 22.4556942], [69.29930878, 22.45569038], [69.29930878, 22.45625114], [69.29902649, 22.45625114], [69.29902649, 22.45652962], [69.29818726, 22.45652962], [69.29818726, 22.45681], [69.29792023, 22.45680618], [69.29792023, 22.45708275], [69.29734802, 22.4570694], [69.29734802, 22.45736122], [69.29708099, 22.45736122], [69.29708099, 22.45763969], [69.29624939, 22.45763969], [69.29624939, 22.45792007], [69.29597473, 22.45791626], [69.29597473, 22.45819473], [69.2951355, 22.45819473], [69.2951355, 22.4584713], [69.29402924, 22.45846939], [69.29402924, 22.45874977], [69.29291534, 22.45874977], [69.29291534, 22.45930481], [69.29319763, 22.45930481], [69.29319763, 22.45986176], [69.29347229, 22.45985985], [69.29347229, 22.46042061], [69.29374695, 22.46041679], [69.29374695, 22.46097183], [69.29402924, 22.46096992], [69.29402924, 22.46153069], [69.29430389, 22.46152687], [69.29430389, 22.46208382], [69.29460144, 22.46208], [69.29460144, 22.46264076], [69.29486084, 22.46264076], [69.29486084, 22.46292114], [69.2951355, 22.46291542], [69.2951355, 22.46347237], [69.29541779, 22.46347046], [69.29541779, 22.46375084], [69.29569244, 22.46375084], [69.29569244, 22.46486092], [69.2959671, 22.46486092], [69.2959671, 22.46541977], [69.29624939, 22.46541595], [69.29624939, 22.46569443], [69.29651642, 22.46569061], [69.29651642, 22.46653175], [69.29680634, 22.46653175], [69.29680634, 22.46681023], [69.29708099, 22.46680641], [69.29708099, 22.46736145], [69.29734802, 22.46736145], [69.29734802, 22.4679203], [69.29763794, 22.4679203], [69.29763794, 22.46820259], [69.29792023, 22.46820259], [69.29792023, 22.46903038], [69.29819489, 22.46902847], [69.29819489, 22.46986389], [69.29846954, 22.46986389], [69.29846954, 22.47069359], [69.29875183, 22.47068977], [69.29875183, 22.47125053], [69.29902649, 22.47125053], [69.29902649, 22.47153091], [69.29930878, 22.47153091], [69.29930878, 22.47180939], [69.29957581, 22.47180939], [69.29957581, 22.47236061], [69.29985809, 22.47236061], [69.29985809, 22.47264099], [69.30014038, 22.47264099], [69.30014038, 22.47291946], [69.30041504, 22.47291756], [69.30041504, 22.47319412], [69.30069733, 22.47319031], [69.30069733, 22.47375107], [69.30124664, 22.47375107], [69.30124664, 22.47402954], [69.30208588, 22.47402954]]], [[[69.40513611, 22.53264046], [69.40513611, 22.5320797], [69.4054184, 22.53208351], [69.4054184, 22.53097153], [69.40569305, 22.53097153], [69.40569305, 22.52902794], [69.4059906, 22.52902985], [69.4059906, 22.52847099], [69.40625, 22.5284729], [69.40625, 22.52791405], [69.40651703, 22.52791977], [69.40651703, 22.52708054], [69.40625, 22.52708244], [69.40625, 22.5265274], [69.4059906, 22.52654076], [69.4059906, 22.52542114], [69.40570068, 22.52542114], [69.40570068, 22.52514076], [69.40513611, 22.52514076], [69.40513611, 22.52486038], [69.40458679, 22.52486038], [69.40458679, 22.52458191], [69.4043045, 22.52458382], [69.4043045, 22.52430534], [69.40319824, 22.52430534], [69.40319061, 22.52458382], [69.40291595, 22.52458191], [69.40291595, 22.52486038], [69.4026413, 22.52486038], [69.4026413, 22.52514076], [69.40235901, 22.52514076], [69.40235901, 22.52542114], [69.40207672, 22.52542114], [69.40207672, 22.52625084], [69.40180206, 22.52625084], [69.40180206, 22.52819443], [69.40207672, 22.52819061], [69.40207672, 22.52902985], [69.40235901, 22.52902794], [69.40235901, 22.52986145], [69.4026413, 22.52985954], [69.4026413, 22.5304203], [69.40291595, 22.5304203], [69.40291595, 22.53124809], [69.40319061, 22.53124809], [69.40319824, 22.53208351], [69.4034729, 22.53208351], [69.4034729, 22.53236008], [69.40374756, 22.53235054], [69.40374756, 22.53264046], [69.40513611, 22.53264046]]], [[[69.91124725, 22.54792023], [69.91124725, 22.54875183], [69.91152954, 22.54875183], [69.91152954, 22.54931068], [69.91124725, 22.54930496], [69.91124725, 22.54958344], [69.9109726, 22.54958344], [69.9109726, 22.54986382], [69.90958405, 22.54986382], [69.90958405, 22.54958344], [69.90791321, 22.54958344], [69.90791321, 22.54986382], [69.90763855, 22.54986191], [69.90763855, 22.55042076], [69.90735626, 22.55042076], [69.90735626, 22.55153084], [69.90875244, 22.55153084], [69.90875244, 22.55181122], [69.91041565, 22.5518055], [69.91041565, 22.55208206], [69.91152954, 22.55208015], [69.91152954, 22.55236053], [69.9126358, 22.55236053], [69.9126358, 22.55264091], [69.91348267, 22.55264091], [69.91348267, 22.55291939], [69.9145813, 22.55291939], [69.9145813, 22.55264091], [69.91570282, 22.55264091], [69.91570282, 22.55291939], [69.91680908, 22.55291748], [69.91680908, 22.55319595], [69.91874695, 22.55319595], [69.91874695, 22.55291748], [69.91902924, 22.55291939], [69.91902924, 22.55264091], [69.91929626, 22.55264091], [69.91929626, 22.55236053], [69.91986084, 22.55236053], [69.91986084, 22.55208015], [69.9201355, 22.55208206], [69.9201355, 22.5518055], [69.92041016, 22.55181122], [69.92041016, 22.55153084], [69.92069244, 22.55153084], [69.92069244, 22.55125046], [69.92124939, 22.55125046], [69.92124939, 22.55097008], [69.92152405, 22.55097389], [69.92152405, 22.55069542], [69.92180634, 22.5506897], [69.92180634, 22.55041695], [69.92208099, 22.55042076], [69.92208099, 22.55014038], [69.92236328, 22.55014038], [69.92236328, 22.54986191], [69.92263794, 22.54986382], [69.92263794, 22.54958344], [69.92319489, 22.54958344], [69.92319489, 22.54930496], [69.92346954, 22.54931068], [69.92346954, 22.5490303], [69.92402649, 22.5490303], [69.92402649, 22.54875183], [69.92430878, 22.54875183], [69.92430878, 22.54846954], [69.92485809, 22.54846954], [69.92485809, 22.54819489], [69.92514038, 22.54819489], [69.92514038, 22.54791641], [69.92569733, 22.54792023], [69.92569733, 22.54764938], [69.92653656, 22.54764938], [69.92653656, 22.54735947], [69.92708588, 22.54735947], [69.92708588, 22.5470829], [69.92791748, 22.5470829], [69.92791748, 22.54680634], [69.9284668, 22.54681015], [69.9284668, 22.54653168], [69.92930603, 22.54653168], [69.92930603, 22.54624748], [69.92986298, 22.54624748], [69.92986298, 22.54597092], [69.93069458, 22.54597282], [69.93069458, 22.54569435], [69.93125153, 22.54569435], [69.93125153, 22.54541588], [69.93180847, 22.54541969], [69.93180847, 22.54486084], [69.93208313, 22.54486084], [69.93208313, 22.54458046], [69.93235779, 22.54458427], [69.93235779, 22.54208374], [69.93208313, 22.54208374], [69.93208313, 22.54041672], [69.93264008, 22.54042053], [69.93264008, 22.54014015], [69.93319702, 22.54014015], [69.93319702, 22.53992081], [69.93319702, 22.53902817], [69.9329071, 22.53903008], [69.9329071, 22.53763962], [69.93208313, 22.53763962], [69.93208313, 22.53652954], [69.93374634, 22.53652954], [69.93374634, 22.5359726], [69.93402863, 22.5359726], [69.93402863, 22.53541756], [69.93430328, 22.53541946], [69.93430328, 22.53403091], [69.93402863, 22.53403091], [69.93402863, 22.53374863], [69.93374634, 22.53374863], [69.93374634, 22.53346825], [69.93319702, 22.53347015], [69.93319702, 22.53319359], [69.93291473, 22.53319359], [69.93291473, 22.53291893], [69.93208313, 22.53292084], [69.93208313, 22.53264046], [69.93125153, 22.53264046], [69.93125153, 22.53235054], [69.93096924, 22.53236008], [69.93096924, 22.53208351], [69.93041992, 22.53208351], [69.93041992, 22.53180504], [69.92986298, 22.53181076], [69.92986298, 22.53153038], [69.92958069, 22.53153038], [69.92958069, 22.53070068], [69.93152618, 22.53070068], [69.93152618, 22.53124809], [69.93235016, 22.53124809], [69.93235016, 22.53153038], [69.9329071, 22.53153038], [69.9329071, 22.53181076], [69.93319702, 22.53180504], [69.93319702, 22.53208351], [69.93347168, 22.53208351], [69.93347168, 22.53236008], [69.93402863, 22.53235054], [69.93402863, 22.53264046], [69.93430328, 22.53264046], [69.93430328, 22.53292084], [69.93458557, 22.53291893], [69.93458557, 22.53319359], [69.93486023, 22.53319359], [69.93486023, 22.53347015], [69.93569183, 22.53347015], [69.93569183, 22.53319359], [69.93597412, 22.53319359], [69.93597412, 22.52791405], [69.93569183, 22.52791977], [69.93569183, 22.52736092], [69.93540955, 22.52736092], [69.93540955, 22.52680969], [69.93514252, 22.52680969], [69.93514252, 22.52625084], [69.93486023, 22.52625084], [69.93486023, 22.52569008], [69.93458557, 22.5256958], [69.93458557, 22.52541733], [69.93514252, 22.52542114], [69.93514252, 22.52514076], [69.93569183, 22.52514076], [69.93569183, 22.52542114], [69.93597412, 22.52541733], [69.93597412, 22.5256958], [69.93624878, 22.52569008], [69.93624878, 22.52654076], [69.93653107, 22.52654076], [69.93653107, 22.52680969], [69.93681335, 22.52680969], [69.93681335, 22.52902985], [69.93708038, 22.52902794], [69.93708038, 22.52958298], [69.93680573, 22.52958298], [69.93680573, 22.52986145], [69.93708038, 22.52985954], [69.93708038, 22.53181076], [69.93763733, 22.53181076], [69.93763733, 22.53153038], [69.93791962, 22.53153038], [69.93791962, 22.53124809], [69.93847656, 22.53124809], [69.93846893, 22.53097153], [69.93875122, 22.53097153], [69.93875122, 22.53069496], [69.93930817, 22.53070068], [69.93930817, 22.5304203], [69.93958282, 22.5304203], [69.93958282, 22.53013992], [69.9404068, 22.53013992], [69.9404068, 22.52985954], [69.94069672, 22.52986145], [69.94069672, 22.52958298], [69.94097137, 22.52958298], [69.94097137, 22.52930641], [69.94153595, 22.52931023], [69.94153595, 22.52874947], [69.94208527, 22.52874947], [69.94208527, 22.52819443], [69.94235992, 22.52819443], [69.94235992, 22.52763939], [69.94291687, 22.52763939], [69.94291687, 22.52680969], [69.94319153, 22.52680969], [69.94319153, 22.52569008], [69.94347382, 22.5256958], [69.94347382, 22.52486038], [69.94374847, 22.52486038], [69.94374847, 22.52403069], [69.94403076, 22.52403069], [69.94403076, 22.52347946], [69.94431305, 22.52347946], [69.94431305, 22.52292061], [69.94403076, 22.52292061], [69.94403076, 22.52179909], [69.94374847, 22.52180481], [69.94374847, 22.52096939], [69.94347382, 22.52096939], [69.94347382, 22.52041626], [69.94319153, 22.52041626], [69.94319153, 22.51985931], [69.94291687, 22.51985931], [69.94291687, 22.51958084], [69.94264221, 22.51958275], [69.94264221, 22.51902962], [69.94235992, 22.51902962], [69.94235992, 22.51874924], [69.9420929, 22.51874924], [69.9420929, 22.51847076], [69.94180298, 22.51847267], [69.94180298, 22.5181942], [69.94152832, 22.5181942], [69.94152832, 22.51791573], [69.94041443, 22.51791573], [69.94041443, 22.5181942], [69.93791962, 22.5181942], [69.93791962, 22.51847267], [69.93708038, 22.51847076], [69.93708038, 22.51874924], [69.93653107, 22.51874924], [69.93653107, 22.51847076], [69.93374634, 22.51847076], [69.93374634, 22.51874924], [69.93319702, 22.51874924], [69.93319702, 22.51902962], [69.9329071, 22.51902962], [69.9329071, 22.51985931], [69.93264008, 22.51985931], [69.93264008, 22.5201416], [69.93125153, 22.5201416], [69.93125153, 22.51958084], [69.93096924, 22.51958275], [69.93096924, 22.51902962], [69.93068695, 22.51902962], [69.93068695, 22.51791954], [69.93013763, 22.51791954], [69.93013763, 22.51764107], [69.92958069, 22.51764107], [69.92958069, 22.51735115], [69.92903137, 22.51736069], [69.92903137, 22.51708412], [69.92819214, 22.51708412], [69.92819214, 22.51680565], [69.92764282, 22.51680946], [69.92764282, 22.51653099], [69.92708588, 22.51653099], [69.92708588, 22.51625061], [69.92597198, 22.51625061], [69.92597198, 22.51597023], [69.92541504, 22.51597214], [69.92541504, 22.51569366], [69.92514038, 22.51569366], [69.92514038, 22.51541519], [69.92457581, 22.51542091], [69.92457581, 22.51514053], [69.92375183, 22.51514053], [69.92375183, 22.51486015], [69.92319489, 22.51486015], [69.92318726, 22.51457977], [69.92236328, 22.51458359], [69.92236328, 22.51430511], [69.92151642, 22.51431084], [69.92151642, 22.51403046], [69.9209671, 22.51403046], [69.9209671, 22.51375008], [69.9201355, 22.51375008], [69.9201355, 22.5134716], [69.91930389, 22.5134716], [69.91930389, 22.51319313], [69.91847229, 22.51320076], [69.91847229, 22.51292038], [69.91792297, 22.51292038], [69.91792297, 22.51264], [69.91707611, 22.51264], [69.91707611, 22.51235962], [69.91625214, 22.51236153], [69.91625214, 22.51208305], [69.91569519, 22.51208305], [69.91569519, 22.51180649], [69.91236115, 22.51180649], [69.91236115, 22.51208305], [69.91042328, 22.51208115], [69.91042328, 22.51264], [69.90957642, 22.51264], [69.90957642, 22.51292038], [69.90847015, 22.51292038], [69.90847015, 22.51320076], [69.90791321, 22.51319313], [69.90791321, 22.5134716], [69.90541077, 22.5134697], [69.90541077, 22.51375008], [69.90374756, 22.51375008], [69.90374756, 22.51403046], [69.9034729, 22.51403046], [69.9034729, 22.51431084], [69.9006958, 22.51431084], [69.9006958, 22.51403046], [69.89736176, 22.51403046], [69.89736176, 22.51375008], [69.8970871, 22.51375008], [69.8970871, 22.51264], [69.89736176, 22.51264], [69.89736176, 22.5118103], [69.89653015, 22.51180649], [69.89653015, 22.51208305], [69.89597321, 22.51208305], [69.89597321, 22.51236153], [69.8951416, 22.51235962], [69.8951416, 22.51264], [69.89457703, 22.51264], [69.89457703, 22.51292038], [69.89375305, 22.51292038], [69.89375305, 22.51320076], [69.89319611, 22.51319313], [69.89319611, 22.5134716], [69.89263916, 22.5134697], [69.89263916, 22.51375008], [69.89235687, 22.51375008], [69.89235687, 22.51403046], [69.89180756, 22.51403046], [69.89180756, 22.51431084], [69.89069366, 22.51430511], [69.89069366, 22.51458359], [69.89041901, 22.51458359], [69.89041901, 22.51486015], [69.89013672, 22.51486015], [69.89013672, 22.51514053], [69.88986206, 22.51514053], [69.88986206, 22.51542091], [69.88903046, 22.51541519], [69.88903046, 22.51569366], [69.88819122, 22.51569366], [69.88819122, 22.51597214], [69.88764191, 22.51597023], [69.88764191, 22.51680946], [69.88735962, 22.51680565], [69.88735962, 22.51708412], [69.88652802, 22.51708412], [69.88652802, 22.51736069], [69.88597107, 22.51735115], [69.88597107, 22.51764107], [69.88485718, 22.51764107], [69.88485718, 22.51791954], [69.88430023, 22.51791954], [69.88430023, 22.51902962], [69.88458252, 22.51902962], [69.88458252, 22.51958275], [69.88430023, 22.51958084], [69.88430023, 22.51985931], [69.88346863, 22.51985931], [69.88346863, 22.5201416], [69.88124847, 22.5201416], [69.88124847, 22.52041626], [69.88041687, 22.52041626], [69.88041687, 22.52069473], [69.87954712, 22.52069473], [69.87625122, 22.52069473], [69.87625122, 22.52096939], [69.87403107, 22.52096939], [69.87403107, 22.52125168], [69.87319183, 22.52125168], [69.87319183, 22.52153015], [69.87281036, 22.52152824], [69.87264252, 22.52152824], [69.87264252, 22.52180481], [69.87152863, 22.52180481], [69.87152863, 22.52208328], [69.87041473, 22.52208328], [69.87041473, 22.52236176], [69.87014008, 22.52236176], [69.87014008, 22.52264023], [69.86930084, 22.52264023], [69.86930084, 22.52292061], [69.86902618, 22.52292061], [69.86902618, 22.5232029], [69.86878967, 22.52319717], [69.86846924, 22.5232029], [69.86846924, 22.52347946], [69.86763763, 22.52347946], [69.86763763, 22.52375031], [69.86736298, 22.52375031], [69.86736298, 22.52403069], [69.86680603, 22.52403069], [69.86680603, 22.52431107], [69.86653137, 22.52430534], [69.86653137, 22.52458382], [69.86624908, 22.52458382], [69.86624908, 22.52430534], [69.86597443, 22.52430534], [69.86597443, 22.52458382], [69.86541748, 22.52458191], [69.86541748, 22.52486038], [69.86486053, 22.52486038], [69.86486053, 22.52514076], [69.86458588, 22.52514076], [69.86458588, 22.52542114], [69.86430359, 22.52541733], [69.86430359, 22.5256958], [69.86402893, 22.5256958], [69.86402893, 22.52597237], [69.86347198, 22.52597046], [69.86347198, 22.52625084], [69.86319733, 22.52625084], [69.86319733, 22.52654076], [69.86292267, 22.52654076], [69.86292267, 22.52680969], [69.86264038, 22.52680588], [69.86264038, 22.52708244], [69.86235809, 22.52708054], [69.86235809, 22.52931023], [69.86319733, 22.52930641], [69.86319733, 22.52958298], [69.86430359, 22.52958298], [69.86430359, 22.52986145], [69.86458588, 22.52985954], [69.86458588, 22.5304203], [69.86486053, 22.5304203], [69.86486053, 22.53070068], [69.86513519, 22.53069496], [69.86513519, 22.53097153], [69.86541748, 22.53096962], [69.86541748, 22.53124809], [69.86569214, 22.53124809], [69.86569214, 22.53096962], [69.86736298, 22.53097153], [69.86736298, 22.53069496], [69.86846924, 22.53070068], [69.86846924, 22.5304203], [69.86958313, 22.5304203], [69.86958313, 22.53013992], [69.8704071, 22.53013992], [69.8704071, 22.52985954], [69.87097168, 22.52986145], [69.87097168, 22.52958298], [69.87291718, 22.52958298], [69.87291718, 22.52930641], [69.87374878, 22.52931023], [69.87374878, 22.52903938], [69.87458038, 22.52902985], [69.87458038, 22.52874947], [69.87542725, 22.52874947], [69.87541962, 22.5284729], [69.87680817, 22.5284729], [69.87680817, 22.52819443], [69.87763977, 22.52819443], [69.87763977, 22.52791405], [69.87819672, 22.52791977], [69.87819672, 22.52763939], [69.87874603, 22.52763939], [69.87902832, 22.52763939], [69.87902832, 22.52736092], [69.8795929, 22.52736092], [69.87958527, 22.52708244], [69.88041687, 22.52708244], [69.88041687, 22.52680588], [69.88124084, 22.52680969], [69.88124084, 22.52654076], [69.88181305, 22.52654076], [69.88181305, 22.52625084], [69.88263702, 22.52625084], [69.88263702, 22.52569008], [69.88346863, 22.5256958], [69.88346863, 22.52541733], [69.8840332, 22.52542114], [69.8840332, 22.52514076], [69.88458252, 22.52514076], [69.88458252, 22.52486038], [69.88540649, 22.52486038], [69.88540649, 22.52458191], [69.88625336, 22.52458382], [69.88625336, 22.52430534], [69.88819122, 22.52431107], [69.88819122, 22.52403069], [69.88931274, 22.52403069], [69.88931274, 22.52375031], [69.88986206, 22.52375031], [69.88986206, 22.52347946], [69.89041901, 22.52347374], [69.89041901, 22.52375031], [69.89097595, 22.52375031], [69.89097595, 22.52403069], [69.89180756, 22.52403069], [69.89180756, 22.52431107], [69.8923645, 22.52430534], [69.8923645, 22.52458382], [69.89290619, 22.52458191], [69.89290619, 22.52486038], [69.89319611, 22.52486038], [69.89319611, 22.52514076], [69.89347076, 22.52514076], [69.89347076, 22.52347946], [69.89375305, 22.52347946], [69.89375305, 22.5232029], [69.89457703, 22.5232029], [69.89457703, 22.52292061], [69.8951416, 22.52292061], [69.8951416, 22.5232029], [69.89541626, 22.5232029], [69.89541626, 22.52347946], [69.89569092, 22.52347946], [69.89569092, 22.52375031], [69.89597321, 22.52375031], [69.89597321, 22.52403069], [69.89624023, 22.52403069], [69.89624023, 22.52431107], [69.89680481, 22.52430534], [69.89680481, 22.52458382], [69.89763641, 22.52458191], [69.89763641, 22.52486038], [69.89875031, 22.52486038], [69.89875031, 22.52514076], [69.89903259, 22.52514076], [69.89903259, 22.52542114], [69.89930725, 22.52541733], [69.89930725, 22.5256958], [69.89958191, 22.5256958], [69.89958191, 22.52597237], [69.89930725, 22.52597046], [69.89930725, 22.52680969], [69.89958191, 22.52680588], [69.89958191, 22.52708244], [69.9006958, 22.52708054], [69.9006958, 22.52736092], [69.90097046, 22.52736092], [69.90097046, 22.52763939], [69.90125275, 22.52763939], [69.90125275, 22.5284729], [69.90040588, 22.52847099], [69.90040588, 22.52874947], [69.89819336, 22.52874947], [69.89819336, 22.53013992], [69.89848328, 22.53013992], [69.89848328, 22.5304203], [69.89819336, 22.53041649], [69.89819336, 22.53097153], [69.89847565, 22.53097153], [69.89847565, 22.53374863], [69.89958191, 22.53374863], [69.89958191, 22.53403091], [69.89985657, 22.53403091], [69.89985657, 22.53486252], [69.89958191, 22.53486252], [69.89958191, 22.53541946], [69.89930725, 22.53541756], [69.89930725, 22.53569412], [69.89903259, 22.53569031], [69.89903259, 22.53625107], [69.89875031, 22.53624916], [69.89875031, 22.53819466], [69.89903259, 22.53819275], [69.89903259, 22.53848076], [69.90013885, 22.53848076], [69.90013885, 22.53874969], [69.90040588, 22.53874969], [69.90040588, 22.53903008], [69.9006958, 22.53902817], [69.9006958, 22.54097176], [69.90040588, 22.54096985], [69.90040588, 22.54236031], [69.90013885, 22.54236031], [69.90013885, 22.54375076], [69.89985657, 22.54375076], [69.89985657, 22.54514122], [69.90013885, 22.54513741], [69.90013885, 22.54569435], [69.90040588, 22.54569054], [69.90040588, 22.54624748], [69.9006958, 22.54624748], [69.9006958, 22.54653168], [69.90097046, 22.54653168], [69.90097046, 22.54681015], [69.90125275, 22.54680634], [69.90125275, 22.5470829], [69.9015274, 22.5470829], [69.9015274, 22.54735947], [69.90207672, 22.54735947], [69.90207672, 22.54764938], [69.90236664, 22.54764938], [69.90236664, 22.54792023], [69.90319061, 22.54791641], [69.90319824, 22.54828644], [69.90319824, 22.54846954], [69.90374756, 22.54846954], [69.90374756, 22.5490303], [69.90486145, 22.5490303], [69.90486145, 22.54931068], [69.90651703, 22.54931068], [69.90651703, 22.5490303], [69.90680695, 22.5490303], [69.90680695, 22.54846954], [69.90652466, 22.54846954], [69.90652466, 22.54819489], [69.90680695, 22.54819489], [69.90680695, 22.54597282], [69.9081955, 22.54597282], [69.9081955, 22.54624748], [69.90875244, 22.54624748], [69.90875244, 22.54653168], [69.91014099, 22.54653168], [69.91014099, 22.54681015], [69.91041565, 22.54680634], [69.91041565, 22.5470829], [69.91069794, 22.5470829], [69.91069794, 22.54735947], [69.9109726, 22.54735947], [69.9109726, 22.54792023], [69.91124725, 22.54792023]]], [[[69.94486237, 22.53236008], [69.94486237, 22.53208351], [69.94569397, 22.53208351], [69.94569397, 22.53180504], [69.9465332, 22.53181076], [69.9465332, 22.53153038], [69.94708252, 22.53153038], [69.94708252, 22.53124809], [69.94734955, 22.53124809], [69.94734955, 22.53096962], [69.94763947, 22.53097153], [69.94763947, 22.53041649], [69.94734955, 22.5304203], [69.94734955, 22.53013992], [69.94680786, 22.53013992], [69.94680786, 22.52985954], [69.94625092, 22.52986145], [69.94625092, 22.52958298], [69.94541931, 22.52958298], [69.94541931, 22.52986145], [69.94458008, 22.52985954], [69.94458008, 22.53013992], [69.94403076, 22.53013992], [69.94403076, 22.5304203], [69.94347382, 22.53041649], [69.94347382, 22.53208351], [69.94374847, 22.53208351], [69.94374847, 22.53236008], [69.94486237, 22.53236008]]], [[[70.02430725, 22.55319595], [70.02430725, 22.55291748], [70.02458191, 22.55291939], [70.02458191, 22.55181122], [70.02403259, 22.55181122], [70.02403259, 22.55153084], [70.02375031, 22.55153084], [70.02375031, 22.55125046], [70.02347565, 22.55125046], [70.02347565, 22.55097389], [70.02319336, 22.55097389], [70.02319336, 22.55069351], [70.0229187, 22.55069351], [70.0229187, 22.55041695], [70.02263641, 22.55042076], [70.02263641, 22.55014038], [70.02236176, 22.55014038], [70.02236176, 22.54986191], [70.0220871, 22.54986382], [70.0220871, 22.54958344], [70.02153015, 22.54958344], [70.02153015, 22.54930496], [70.02097321, 22.54931068], [70.02097321, 22.5490303], [70.02069092, 22.5490303], [70.02069092, 22.54875183], [70.02041626, 22.54875183], [70.02041626, 22.54818916], [70.01985931, 22.54819489], [70.01985931, 22.54791641], [70.01790619, 22.54792023], [70.01790619, 22.54764938], [70.01763916, 22.54764938], [70.01763916, 22.54792023], [70.01569366, 22.54791641], [70.01569366, 22.54819489], [70.01457977, 22.54819489], [70.01457977, 22.54846954], [70.01374817, 22.54846954], [70.0137558, 22.54875183], [70.01291656, 22.54875183], [70.01291656, 22.5490303], [70.01235962, 22.5490303], [70.01235962, 22.54931068], [70.01180267, 22.54930496], [70.01180267, 22.54958344], [70.01152802, 22.54958344], [70.01152802, 22.54986382], [70.01235962, 22.54986191], [70.01235962, 22.55014038], [70.01291656, 22.55014038], [70.01291656, 22.55042076], [70.01374817, 22.55041695], [70.0137558, 22.5506897], [70.01457977, 22.55069542], [70.01457977, 22.55097389], [70.01513672, 22.55097008], [70.01513672, 22.55125046], [70.01597595, 22.55125046], [70.01597595, 22.55153084], [70.01790619, 22.55153084], [70.01790619, 22.55181122], [70.01985931, 22.5518055], [70.01985931, 22.55208206], [70.02097321, 22.55208015], [70.02097321, 22.55236053], [70.02179718, 22.55236053], [70.02179718, 22.55264091], [70.0229187, 22.55264091], [70.0229187, 22.55291939], [70.02375031, 22.55291748], [70.02375031, 22.55319595], [70.02430725, 22.55319595]]], [[[69.95735931, 22.5359726], [69.95735931, 22.53541756], [69.9576416, 22.53541946], [69.9576416, 22.5351429], [69.95735931, 22.5351429], [69.95735931, 22.53486252], [69.95722961, 22.53486252], [69.95707703, 22.53486252], [69.95707703, 22.53430939], [69.95680237, 22.53430939], [69.95680237, 22.53403091], [69.95540619, 22.53403091], [69.95540619, 22.53374863], [69.95513916, 22.53374863], [69.95513916, 22.53346825], [69.95430756, 22.53347015], [69.95430756, 22.53319359], [69.95402527, 22.53319359], [69.95402527, 22.53291893], [69.95375061, 22.53292084], [69.95375061, 22.53264046], [69.95236969, 22.53264046], [69.95236206, 22.53292084], [69.95263672, 22.53291893], [69.95263672, 22.53347015], [69.95291901, 22.53346825], [69.95291901, 22.53374863], [69.95318604, 22.53374863], [69.95318604, 22.53403091], [69.95347595, 22.5340271], [69.95347595, 22.53458405], [69.95375061, 22.53458023], [69.95375061, 22.53486252], [69.9540329, 22.53486252], [69.9540329, 22.5351429], [69.95458221, 22.5351429], [69.95458221, 22.53541946], [69.9548645, 22.53541756], [69.9548645, 22.53569412], [69.95513916, 22.53569412], [69.95513916, 22.5359726], [69.95707703, 22.5359726], [69.95735931, 22.5359726]]], [[[69.9604187, 22.54375076], [69.9604187, 22.54347038], [69.96097565, 22.54347229], [69.96097565, 22.54319382], [69.96180725, 22.54319382], [69.96180725, 22.54291534], [69.96264648, 22.54292107], [69.96264648, 22.54264069], [69.96290588, 22.54264069], [69.96290588, 22.54236031], [69.96347046, 22.54236031], [69.96347046, 22.54181099], [69.9631958, 22.54181099], [69.9631958, 22.54152107], [69.96263885, 22.5415287], [69.96263885, 22.54125023], [69.96251678, 22.54125023], [69.96180725, 22.54125023], [69.96180725, 22.54114151], [69.96180725, 22.54097176], [69.96152496, 22.54097176], [69.96152496, 22.54069519], [69.96098328, 22.54070091], [69.96098328, 22.54042053], [69.96069336, 22.54042053], [69.96069336, 22.54014015], [69.9604187, 22.54014015], [69.9604187, 22.53985977], [69.95986176, 22.53986168], [69.95986176, 22.53958321], [69.9595871, 22.53958321], [69.9595871, 22.53930473], [69.95930481, 22.53930473], [69.95930481, 22.53902817], [69.95903015, 22.53903008], [69.95903015, 22.53848076], [69.95819092, 22.53848076], [69.95819092, 22.53819275], [69.9576416, 22.53819466], [69.9576416, 22.53806114], [69.9576416, 22.53791618], [69.95752716, 22.53791618], [69.95652008, 22.53792], [69.95652008, 22.53763962], [69.95625305, 22.53763962], [69.95625305, 22.53736115], [69.95597076, 22.53736115], [69.95597076, 22.53708267], [69.95541382, 22.53708267], [69.95541382, 22.53680611], [69.95513916, 22.53680992], [69.95513916, 22.53652954], [69.95485687, 22.53652954], [69.95485687, 22.53625107], [69.95458221, 22.53625107], [69.95458221, 22.5359726], [69.9540329, 22.5359726], [69.9540329, 22.53652954], [69.95430756, 22.53652954], [69.95430756, 22.53680992], [69.95458221, 22.53680611], [69.95458221, 22.53708267], [69.95485687, 22.53708267], [69.95485687, 22.53763962], [69.95540619, 22.53763962], [69.95540619, 22.53792], [69.95569611, 22.53792], [69.95569611, 22.53848076], [69.95597076, 22.53848076], [69.95597076, 22.53903008], [69.95625305, 22.53902817], [69.95625305, 22.53930473], [69.95652771, 22.53930473], [69.95652771, 22.53986168], [69.95680237, 22.53985977], [69.95680237, 22.54014015], [69.95707703, 22.54014015], [69.95707703, 22.54070091], [69.95735931, 22.54070091], [69.95735931, 22.54125023], [69.9576416, 22.54125023], [69.9576416, 22.5415287], [69.95791626, 22.5415287], [69.95791626, 22.54208374], [69.95819092, 22.54207993], [69.95819092, 22.54264069], [69.95847321, 22.54264069], [69.95847321, 22.54292107], [69.95874786, 22.54291534], [69.95874786, 22.54319382], [69.95903015, 22.54319382], [69.95903015, 22.54347229], [69.95929718, 22.54347038], [69.95929718, 22.54375076], [69.9604187, 22.54375076]]], [[[69.95207977, 22.55125046], [69.95207977, 22.55097008], [69.95236206, 22.55097389], [69.95236206, 22.55069542], [69.95263672, 22.5506897], [69.95263672, 22.55041695], [69.95291901, 22.55042076], [69.95291901, 22.55014038], [69.95318604, 22.55014038], [69.95318604, 22.54986191], [69.95347595, 22.54986382], [69.95347595, 22.54958344], [69.95375061, 22.54958344], [69.95375061, 22.54930496], [69.9540329, 22.54931068], [69.9540329, 22.5490303], [69.95430756, 22.5490303], [69.95430756, 22.54875183], [69.95458221, 22.54875183], [69.95458221, 22.54846954], [69.9548645, 22.54846954], [69.9548645, 22.54819489], [69.95513916, 22.54819489], [69.95513916, 22.54791641], [69.95540619, 22.54792023], [69.95540619, 22.54764938], [69.95569611, 22.54764938], [69.95569611, 22.54707909], [69.95597076, 22.5470829], [69.95597076, 22.54680634], [69.95625305, 22.54681015], [69.95625305, 22.54653168], [69.95652008, 22.54653168], [69.95652008, 22.54624748], [69.95680237, 22.54624748], [69.95680237, 22.54597092], [69.95708466, 22.54597282], [69.95708466, 22.54569435], [69.95735931, 22.54569435], [69.95735931, 22.54513741], [69.9576416, 22.54514122], [69.9576416, 22.54403114], [69.95735931, 22.54403114], [69.95735931, 22.54375076], [69.95707703, 22.54375076], [69.95707703, 22.54347038], [69.95680237, 22.54347229], [69.95680237, 22.54291534], [69.95652008, 22.54292107], [69.95652008, 22.54264069], [69.95625305, 22.54264069], [69.95625305, 22.54236031], [69.95597076, 22.54236031], [69.95597076, 22.54181099], [69.95569611, 22.54181099], [69.95569611, 22.54152107], [69.95541382, 22.5415287], [69.95541382, 22.54125023], [69.95513916, 22.54125023], [69.95513916, 22.54070091], [69.95485687, 22.54070091], [69.95485687, 22.54014015], [69.95458221, 22.54014015], [69.95458221, 22.53930092], [69.95430756, 22.53930473], [69.95430756, 22.53847313], [69.9540329, 22.53848076], [69.9540329, 22.53792], [69.95375061, 22.53792], [69.95375061, 22.53736115], [69.95347595, 22.53736115], [69.95347595, 22.53708267], [69.95319366, 22.53708267], [69.95319366, 22.53680611], [69.95263672, 22.53680992], [69.95263672, 22.53652954], [69.95207977, 22.53652954], [69.95207977, 22.53625107], [69.95124817, 22.53625107], [69.95124817, 22.5359726], [69.95069122, 22.5359726], [69.95069122, 22.53569412], [69.95014191, 22.53569412], [69.95014191, 22.53541756], [69.94819641, 22.53541756], [69.94819641, 22.53569412], [69.94652557, 22.53569412], [69.94652557, 22.5359726], [69.94568634, 22.5359726], [69.94568634, 22.53625107], [69.94458008, 22.53625107], [69.94458008, 22.53652954], [69.94374847, 22.53652954], [69.94374847, 22.53680992], [69.94291687, 22.53680611], [69.94291687, 22.53708267], [69.94208527, 22.53708267], [69.94208527, 22.53736115], [69.94152832, 22.53736115], [69.94153595, 22.53763962], [69.94069672, 22.53763962], [69.94069672, 22.53792], [69.94013977, 22.53791618], [69.94013977, 22.53819466], [69.93985748, 22.53819275], [69.93985748, 22.53848076], [69.93875122, 22.53848076], [69.93875122, 22.53903008], [69.93846893, 22.53902817], [69.93846893, 22.53958321], [69.93819427, 22.53958321], [69.93819427, 22.54154015], [69.93819427, 22.54208374], [69.93846893, 22.54208374], [69.93846893, 22.54569435], [69.93875122, 22.54569054], [69.93875122, 22.54624748], [69.93902588, 22.54624748], [69.93902588, 22.54681015], [69.93930817, 22.54681015], [69.93930817, 22.54764938], [69.93958282, 22.54764175], [69.93958282, 22.54819489], [69.93985748, 22.54819489], [69.93985748, 22.54846954], [69.94013977, 22.54846954], [69.94013977, 22.54875183], [69.94069672, 22.54875183], [69.94069672, 22.5490303], [69.94097137, 22.5490303], [69.94097137, 22.54931068], [69.94125366, 22.54930496], [69.94125366, 22.54958344], [69.94152832, 22.54958344], [69.94152832, 22.54986382], [69.94180298, 22.54986191], [69.94180298, 22.55042076], [69.94264221, 22.55041695], [69.94264221, 22.5506897], [69.94291687, 22.55069542], [69.94291687, 22.55097389], [69.94430542, 22.55097389], [69.94430542, 22.55125046], [69.95207977, 22.55125046]]], [[[70.0395813, 22.56792068], [70.0395813, 22.5676403], [70.03985596, 22.5676403], [70.03985596, 22.56735992], [70.04013824, 22.56736183], [70.04013824, 22.56680489], [70.0404129, 22.56680489], [70.0404129, 22.56652832], [70.04096985, 22.56653023], [70.04096985, 22.56513977], [70.04069519, 22.56513977], [70.04069519, 22.56458473], [70.0404129, 22.56458473], [70.0404129, 22.56430626], [70.03874969, 22.56430626], [70.03874969, 22.56458473], [70.03847504, 22.56458473], [70.03847504, 22.56680489], [70.03874969, 22.56680489], [70.03874969, 22.56708336], [70.03902435, 22.56708336], [70.03902435, 22.56736183], [70.03930664, 22.56735992], [70.03930664, 22.56792068], [70.0395813, 22.56792068]]], [[[70.01125336, 22.55375099], [70.01125336, 22.55346107], [70.01152802, 22.55347252], [70.01152802, 22.55319595], [70.01180267, 22.55319595], [70.01180267, 22.55291748], [70.01235962, 22.55291939], [70.01235962, 22.55264091], [70.01264191, 22.55264091], [70.01264191, 22.55236053], [70.01207733, 22.55236053], [70.01207733, 22.55208015], [70.01152802, 22.55208206], [70.01152802, 22.5518055], [70.01097107, 22.55181122], [70.01097107, 22.55153084], [70.01040649, 22.55153084], [70.01040649, 22.55125046], [70.01013947, 22.55125046], [70.01013947, 22.55097008], [70.00958252, 22.55097389], [70.00958252, 22.55069542], [70.0090332, 22.5506897], [70.00902557, 22.55041695], [70.00818634, 22.55042076], [70.00818634, 22.55014038], [70.00708008, 22.55014038], [70.00708008, 22.54986191], [70.00624847, 22.54986382], [70.00624847, 22.54958344], [70.00569153, 22.54958344], [70.00569153, 22.54930496], [70.00485992, 22.54931068], [70.00485992, 22.5490303], [70.00041962, 22.5490303], [70.00041962, 22.54875183], [69.99986267, 22.54875183], [69.99874878, 22.54875183], [69.99874878, 22.54846954], [69.99624634, 22.54846954], [69.99624634, 22.54875183], [69.99597168, 22.54875183], [69.99597168, 22.54931068], [69.99624634, 22.54930496], [69.99624634, 22.54958344], [69.99652863, 22.54958344], [69.99652863, 22.54986382], [69.9970932, 22.54986191], [69.9970932, 22.55014038], [69.99736023, 22.55014038], [69.99736023, 22.55042076], [69.99791718, 22.55041695], [69.99791718, 22.55069351], [69.99874878, 22.55069351], [69.99874878, 22.55097389], [69.99903107, 22.55097008], [69.99903107, 22.55125046], [69.99958038, 22.55125046], [69.99958038, 22.55153084], [69.99986267, 22.55153084], [69.99986267, 22.55181122], [70.00013733, 22.55181122], [70.00041962, 22.5518055], [70.00041962, 22.55208206], [70.00068665, 22.55208015], [70.00068665, 22.55236053], [70.00208282, 22.55236053], [70.00208282, 22.55208015], [70.00375366, 22.55208206], [70.00375366, 22.5518055], [70.00818634, 22.55181122], [70.00818634, 22.55264091], [70.00846863, 22.55264091], [70.00846863, 22.55291939], [70.00902557, 22.55291748], [70.00902557, 22.55319595], [70.00930786, 22.55319595], [70.00930786, 22.55347252], [70.00958252, 22.55346107], [70.00958252, 22.55375099], [70.01125336, 22.55375099]]], [[[70.02347565, 22.55847168], [70.02347565, 22.55819511], [70.02403259, 22.55820084], [70.02403259, 22.55792046], [70.02430725, 22.55792046], [70.02430725, 22.55763817], [70.02485657, 22.55763817], [70.02485657, 22.55680084], [70.02513885, 22.55680466], [70.02513885, 22.55597305], [70.0248642, 22.55597305], [70.0248642, 22.55541611], [70.02458191, 22.55541992], [70.02458191, 22.55513954], [70.02375031, 22.55513954], [70.02375031, 22.55486107], [70.02319336, 22.55486107], [70.02319336, 22.55458069], [70.02236176, 22.5545826], [70.02236176, 22.55430412], [70.02153015, 22.55430984], [70.02153015, 22.55402946], [70.02041626, 22.55402946], [70.02041626, 22.55375099], [70.0195694, 22.55375099], [70.0195694, 22.55346107], [70.01763916, 22.55347252], [70.01763916, 22.55319595], [70.01569366, 22.55319595], [70.01569366, 22.55291748], [70.01403046, 22.55291939], [70.01403046, 22.55264091], [70.01347351, 22.55263901], [70.01347351, 22.55319595], [70.01319122, 22.55319023], [70.01319122, 22.55375099], [70.01291656, 22.55375099], [70.01291656, 22.55402946], [70.01264191, 22.55402756], [70.01264191, 22.5545826], [70.01291656, 22.55458069], [70.01291656, 22.55486107], [70.01319122, 22.55486107], [70.01319122, 22.55513954], [70.01346588, 22.55513954], [70.01346588, 22.55541992], [70.01374817, 22.55541611], [70.01374817, 22.55569458], [70.01403046, 22.55569458], [70.01403046, 22.55597305], [70.01430511, 22.55597305], [70.01430511, 22.55624962], [70.01457977, 22.55624962], [70.01457977, 22.55652618], [70.01513672, 22.55652618], [70.01513672, 22.55680466], [70.01541901, 22.55680466], [70.01541901, 22.55708313], [70.01597595, 22.55708313], [70.01597595, 22.5573616], [70.01625061, 22.5573597], [70.01625061, 22.55763817], [70.01682281, 22.55763817], [70.01682281, 22.55792046], [70.01763916, 22.55792046], [70.01763916, 22.55820084], [70.01847076, 22.55819511], [70.01847076, 22.55847168], [70.02347565, 22.55847168]]], [[[70.0090332, 22.59320068], [70.0090332, 22.5929203], [70.00958252, 22.5929203], [70.00958252, 22.59263039], [70.01013947, 22.59263802], [70.01013947, 22.59236145], [70.01097107, 22.59236145], [70.01097107, 22.59208488], [70.01152802, 22.59208488], [70.01152802, 22.59180641], [70.01207733, 22.59181023], [70.01207733, 22.59152985], [70.01291656, 22.59152985], [70.01291656, 22.59124947], [70.01403046, 22.59124947], [70.01403046, 22.5909729], [70.01486206, 22.59097481], [70.01486206, 22.59069443], [70.01569366, 22.59069443], [70.01569366, 22.59041595], [70.01682281, 22.59041977], [70.01682281, 22.59013939], [70.01763916, 22.59013939], [70.01763916, 22.58986282], [70.01819611, 22.58986282], [70.01819611, 22.58956909], [70.01875305, 22.58958054], [70.01875305, 22.58930588], [70.01930237, 22.58930969], [70.01930237, 22.58903122], [70.01985931, 22.58903122], [70.01985931, 22.58875275], [70.02236176, 22.58875275], [70.02236176, 22.58847237], [70.02263641, 22.58847237], [70.02263641, 22.58819389], [70.0229187, 22.58819389], [70.0229187, 22.58791733], [70.02319336, 22.58792114], [70.02319336, 22.58764076], [70.02348328, 22.58764076], [70.02348328, 22.58735847], [70.02375031, 22.58735847], [70.02375031, 22.58707809], [70.02402496, 22.58708382], [70.02402496, 22.58680534], [70.02430725, 22.5868206], [70.02430725, 22.58653069], [70.02458191, 22.58653069], [70.02458191, 22.5862484], [70.02485657, 22.5862484], [70.02485657, 22.58513832], [70.02513885, 22.58513832], [70.02513885, 22.58374977], [70.02540588, 22.58374977], [70.02540588, 22.58292007], [70.0256958, 22.58292007], [70.0256958, 22.58208084], [70.02597046, 22.58208275], [70.02597046, 22.58124924], [70.02625275, 22.58125114], [70.02625275, 22.58041954], [70.0265274, 22.58041954], [70.0265274, 22.58014107], [70.0265274, 22.57958412], [70.02680206, 22.57958412], [70.02680206, 22.57875061], [70.02707672, 22.57875061], [70.02707672, 22.57792091], [70.02735901, 22.57792091], [70.02735901, 22.57707977], [70.0276413, 22.57708359], [70.0276413, 22.57597351], [70.02791595, 22.57597351], [70.02791595, 22.57513809], [70.02819061, 22.57514191], [70.02819061, 22.57346916], [70.02791595, 22.57347298], [70.02791595, 22.57069397], [70.0276413, 22.57069397], [70.0276413, 22.56902695], [70.02735901, 22.56903076], [70.02735901, 22.56846046], [70.02708435, 22.56847191], [70.02708435, 22.56791687], [70.0265274, 22.56792068], [70.0265274, 22.56820107], [70.02513885, 22.56820107], [70.02513885, 22.5676403], [70.02485657, 22.5676403], [70.02485657, 22.56680107], [70.02458191, 22.56680489], [70.02458191, 22.56624985], [70.02430725, 22.56624985], [70.02430725, 22.5656929], [70.02402496, 22.56569481], [70.02402496, 22.56541634], [70.02348328, 22.56542015], [70.02348328, 22.56513977], [70.02319336, 22.56513977], [70.02319336, 22.56485939], [70.0229187, 22.5648613], [70.0229187, 22.56458473], [70.02236176, 22.56458473], [70.02236176, 22.56430626], [70.0220871, 22.56431007], [70.0220871, 22.56402969], [70.02179718, 22.56402969], [70.02179718, 22.56375122], [70.02153015, 22.56375122], [70.02153015, 22.56347275], [70.02097321, 22.56347275], [70.02097321, 22.56319427], [70.02069092, 22.56319427], [70.02069092, 22.5629158], [70.02041626, 22.56291962], [70.02041626, 22.56265068], [70.01985931, 22.56265068], [70.01985931, 22.56236267], [70.0195694, 22.56236267], [70.0195694, 22.56208038], [70.01902771, 22.5620842], [70.01902771, 22.56180573], [70.01847076, 22.56180954], [70.01847076, 22.56153107], [70.01819611, 22.56153107], [70.01819611, 22.56125259], [70.01790619, 22.56125259], [70.01790619, 22.5609684], [70.01763916, 22.56097031], [70.01763916, 22.56069374], [70.01708221, 22.56069374], [70.01708221, 22.56041718], [70.01682281, 22.56041908], [70.01682281, 22.56014061], [70.0165329, 22.56014061], [70.0165329, 22.55985832], [70.01597595, 22.55985832], [70.01597595, 22.55958939], [70.01568604, 22.55958939], [70.01568604, 22.55931091], [70.01541901, 22.55931091], [70.01541901, 22.55903053], [70.01513672, 22.55903053], [70.01513672, 22.55874825], [70.01457977, 22.55874825], [70.01457977, 22.55846977], [70.01430511, 22.55847168], [70.01430511, 22.55819511], [70.01403046, 22.55820084], [70.01403046, 22.55792046], [70.01346588, 22.55792046], [70.01346588, 22.55763817], [70.01207733, 22.55763817], [70.01207733, 22.5573597], [70.01180267, 22.5573616], [70.01180267, 22.55708313], [70.01125336, 22.55708313], [70.01125336, 22.55680466], [70.01097107, 22.55680466], [70.01097107, 22.55652618], [70.01069641, 22.55652618], [70.01069641, 22.55624962], [70.01040649, 22.55624962], [70.01040649, 22.55597115], [70.00986481, 22.55597305], [70.00986481, 22.55569458], [70.00958252, 22.55569458], [70.00958252, 22.55541611], [70.00930786, 22.55541992], [70.00930786, 22.55513954], [70.00902557, 22.55513954], [70.00902557, 22.55486107], [70.00846863, 22.55486107], [70.00846863, 22.55458069], [70.00819397, 22.5545826], [70.00819397, 22.55430412], [70.00791931, 22.55430984], [70.00791931, 22.55402946], [70.00681305, 22.55402946], [70.00681305, 22.55375099], [70.00152588, 22.55375099], [70.00152588, 22.55346107], [70.00041962, 22.55347252], [70.00041962, 22.55319595], [69.99986267, 22.55319595], [69.99874878, 22.55319595], [69.99874878, 22.55236053], [69.99791718, 22.55236053], [69.99791718, 22.55208015], [69.99764252, 22.55208206], [69.99764252, 22.5518055], [69.99736023, 22.55181122], [69.99736023, 22.55153084], [69.9970932, 22.55153084], [69.9970932, 22.55125046], [69.99680328, 22.55125046], [69.99680328, 22.55097008], [69.99514008, 22.55097389], [69.99514008, 22.55069542], [69.99485779, 22.5506897], [69.99485779, 22.55013847], [69.99514008, 22.55014038], [69.99514008, 22.54986191], [69.99485779, 22.54986382], [69.99485779, 22.54958344], [69.99430847, 22.54958344], [69.99430847, 22.54930496], [69.99402618, 22.54931068], [69.99402618, 22.5490303], [69.99346924, 22.5490303], [69.99346924, 22.54875183], [69.99318695, 22.54875183], [69.99318695, 22.54846954], [69.99263763, 22.54846954], [69.99263763, 22.54819489], [69.99041748, 22.54819489], [69.99041748, 22.54791641], [69.98958588, 22.54792023], [69.98958588, 22.54764938], [69.98874664, 22.54764938], [69.98874664, 22.54735947], [69.98764038, 22.54735947], [69.98764038, 22.5470829], [69.98680878, 22.5470829], [69.98680878, 22.54680634], [69.98596954, 22.54681015], [69.98596954, 22.54653168], [69.98430634, 22.54653168], [69.98430634, 22.54624748], [69.98401642, 22.54624748], [69.98401642, 22.54653168], [69.98264313, 22.54653168], [69.98264313, 22.54681015], [69.98152924, 22.54680634], [69.98152924, 22.5470829], [69.97930908, 22.5470829], [69.97930908, 22.54680634], [69.97902679, 22.54681015], [69.97902679, 22.54624748], [69.97820282, 22.54624748], [69.97820282, 22.54653168], [69.9779129, 22.54652977], [69.9779129, 22.5470829], [69.97764587, 22.54707909], [69.97764587, 22.54764938], [69.97735596, 22.54764938], [69.97735596, 22.54792023], [69.9751358, 22.54792023], [69.9751358, 22.54764938], [69.97473907, 22.54764938], [69.97458649, 22.54764938], [69.97458649, 22.54735947], [69.97402954, 22.54735947], [69.97402954, 22.5470829], [69.97264099, 22.5470829], [69.97264099, 22.54680634], [69.97207642, 22.54681015], [69.97207642, 22.54653168], [69.97180176, 22.54653168], [69.97180176, 22.54624748], [69.97041321, 22.54624748], [69.97041321, 22.54597092], [69.96847534, 22.54597282], [69.96847534, 22.54569435], [69.96736145, 22.54569435], [69.96736145, 22.54597282], [69.9668045, 22.54597282], [69.9668045, 22.54569435], [69.96624756, 22.54569435], [69.96624756, 22.54541588], [69.96375275, 22.54541588], [69.96375275, 22.54569435], [69.96291351, 22.54569435], [69.96291351, 22.54597282], [69.96263885, 22.54597282], [69.96264648, 22.54624748], [69.96180725, 22.54624748], [69.96180725, 22.54653168], [69.96153259, 22.54653168], [69.96153259, 22.54681015], [69.96125031, 22.54680634], [69.96125031, 22.54735947], [69.96098328, 22.54735947], [69.96098328, 22.54764938], [69.96069336, 22.54764938], [69.96069336, 22.54792023], [69.9604187, 22.54791641], [69.9604187, 22.54819489], [69.96013641, 22.54819489], [69.96013641, 22.54846954], [69.95986176, 22.54846954], [69.95986176, 22.54875183], [69.95957947, 22.54875183], [69.95957947, 22.5490303], [69.95929718, 22.5490303], [69.95929718, 22.54875183], [69.95903015, 22.54875183], [69.95903015, 22.5490303], [69.95874786, 22.5490303], [69.95874786, 22.54931068], [69.95847321, 22.54930496], [69.95847321, 22.54958344], [69.95791626, 22.54957962], [69.95791626, 22.55014038], [69.9576416, 22.55013847], [69.9576416, 22.5506897], [69.95735931, 22.55071068], [69.95735931, 22.55125046], [69.95707703, 22.55125046], [69.95707703, 22.55375099], [69.95680237, 22.55375099], [69.95680237, 22.55486107], [69.95652771, 22.55486107], [69.95652771, 22.55708313], [69.95680237, 22.55708122], [69.95680237, 22.55820084], [69.95707703, 22.55820084], [69.95707703, 22.55958939], [69.95680237, 22.55958366], [69.95680237, 22.56069374], [69.95707703, 22.56068993], [69.95707703, 22.56153107], [69.95735931, 22.56153107], [69.95735931, 22.56265068], [69.9576416, 22.56265068], [69.9576416, 22.56375122], [69.95791626, 22.56374931], [69.95791626, 22.56458473], [69.95819092, 22.56458282], [69.95819092, 22.56542015], [69.95847321, 22.56542015], [69.95847321, 22.56624985], [69.95874786, 22.56624985], [69.95874786, 22.56680489], [69.95903015, 22.56680489], [69.95903015, 22.56736183], [69.95929718, 22.56735992], [69.95929718, 22.56792068], [69.95957947, 22.56792068], [69.95957947, 22.56875038], [69.95986176, 22.56875038], [69.95986176, 22.56931114], [69.96013641, 22.56931114], [69.96013641, 22.56986046], [69.9604187, 22.56986046], [69.9604187, 22.57042122], [69.96069336, 22.5704174], [69.96069336, 22.57097244], [69.96098328, 22.57097054], [69.96098328, 22.57152748], [69.96125031, 22.57152748], [69.96125031, 22.57208252], [69.96153259, 22.57208061], [69.96153259, 22.57292175], [69.96180725, 22.57291603], [69.96180725, 22.57347298], [69.96208191, 22.57346916], [69.96208191, 22.57403183], [69.96235657, 22.57403183], [69.96235657, 22.57459259], [69.96264648, 22.57459259], [69.96264648, 22.57514191], [69.96290588, 22.57514191], [69.96290588, 22.57570267], [69.9631958, 22.57569504], [69.9631958, 22.57597351], [69.96347046, 22.5759697], [69.96347046, 22.57625008], [69.96375275, 22.57625008], [69.96375275, 22.57653046], [69.9640274, 22.57653046], [69.9640274, 22.57681084], [69.96430206, 22.57680511], [69.96430206, 22.57708359], [69.96457672, 22.57707977], [69.96458435, 22.57736015], [69.96485901, 22.57736015], [69.96485901, 22.57765007], [69.9651413, 22.57765007], [69.9651413, 22.57792091], [69.9659729, 22.5779171], [69.9659729, 22.57819366], [69.96652985, 22.57819366], [69.96652985, 22.57847214], [69.96875, 22.57847214], [69.96875, 22.57819366], [69.96902466, 22.57819366], [69.96902466, 22.5779171], [69.97013855, 22.5779171], [69.97013855, 22.57819366], [69.97291565, 22.57819366], [69.97291565, 22.57847214], [69.9734726, 22.57847023], [69.9734726, 22.57875061], [69.97374725, 22.57875061], [69.97374725, 22.57903099], [69.97429657, 22.57903099], [69.97429657, 22.57930946], [69.97486115, 22.57930565], [69.97486115, 22.57958412], [69.9751358, 22.57958031], [69.9751358, 22.58014107], [69.97541809, 22.58013916], [69.97541809, 22.5806942], [69.97819519, 22.5806942], [69.97819519, 22.58097267], [69.97902679, 22.58097076], [69.97902679, 22.58125114], [69.97957611, 22.58125114], [69.97957611, 22.58152962], [69.98097229, 22.58152962], [69.98097229, 22.58181], [69.98124695, 22.58181], [69.98124695, 22.58152962], [69.98179626, 22.58152962], [69.98179626, 22.58181], [69.9826355, 22.58180428], [69.9826355, 22.58208275], [69.98319244, 22.58208084], [69.98319244, 22.58236122], [69.98401642, 22.58236122], [69.98401642, 22.58263969], [69.98458099, 22.58263969], [69.98458099, 22.58292007], [69.98486328, 22.58291626], [69.98486328, 22.58319473], [69.98513794, 22.58319473], [69.98513794, 22.5834713], [69.98542023, 22.58346939], [69.98542023, 22.58374977], [69.98596954, 22.58374977], [69.98596954, 22.58346939], [69.98680878, 22.5834713], [69.98680878, 22.58319473], [69.98735809, 22.58319473], [69.98735809, 22.5834713], [69.98764038, 22.58346939], [69.98764038, 22.58374977], [69.98847198, 22.58374977], [69.98847198, 22.58346939], [69.98902893, 22.58346939], [69.98902893, 22.58374977], [69.98929596, 22.58374977], [69.98929596, 22.58402824], [69.98958588, 22.58402634], [69.98958588, 22.58430481], [69.98986053, 22.58430481], [69.98986053, 22.58458328], [69.99097443, 22.58458328], [69.99097443, 22.58430481], [69.99208069, 22.58430481], [69.99208069, 22.58458328], [69.99291992, 22.58458328], [69.99291992, 22.58486176], [69.99318695, 22.58485985], [69.99318695, 22.58542061], [69.99346924, 22.58541679], [69.99346924, 22.58597183], [69.99375153, 22.58596992], [69.99375153, 22.58653069], [69.99402618, 22.58652687], [69.99402618, 22.58708382], [69.99430847, 22.58707809], [69.99430847, 22.58764076], [69.99458313, 22.58764076], [69.99458313, 22.58792114], [69.99485779, 22.58791733], [69.99485779, 22.58819389], [69.99514008, 22.58819389], [69.99514008, 22.58847237], [69.99539948, 22.58847237], [69.99539948, 22.58875275], [69.99624634, 22.58875275], [69.99624634, 22.58930969], [69.99708557, 22.58930588], [69.99708557, 22.58958054], [69.99736023, 22.58958054], [69.99736023, 22.58847237], [69.99791718, 22.58847237], [69.99791718, 22.58903122], [69.99819183, 22.58903122], [69.99819183, 22.58930969], [69.99847412, 22.58930588], [69.99847412, 22.58958054], [69.99874878, 22.58958054], [69.99874878, 22.58986282], [69.99931335, 22.58986282], [69.99931335, 22.59041977], [69.99958038, 22.59041595], [69.99958038, 22.59069443], [70.00013733, 22.59069443], [70.00041962, 22.59069443], [70.00041962, 22.59097481], [70.00096893, 22.5909729], [70.00096893, 22.59124947], [70.00125122, 22.59124947], [70.00125122, 22.59152985], [70.00152588, 22.59152985], [70.00152588, 22.59181023], [70.00208282, 22.59180641], [70.00208282, 22.59208488], [70.00235748, 22.59208488], [70.00235748, 22.59236145], [70.00291443, 22.59236145], [70.00291443, 22.59263802], [70.00319672, 22.59263039], [70.00319672, 22.5929203], [70.00374603, 22.5929203], [70.00374603, 22.59320068], [70.0090332, 22.59320068]]], [[[70.04458618, 22.57235909], [70.04458618, 22.57208061], [70.04486084, 22.57208252], [70.04486084, 22.57180595], [70.04514313, 22.57180977], [70.04514313, 22.57152748], [70.04541779, 22.57152748], [70.04541779, 22.57125092], [70.0459671, 22.57125092], [70.0459671, 22.56986046], [70.04569244, 22.56986046], [70.04569244, 22.56958008], [70.04541779, 22.56958389], [70.04541779, 22.56902695], [70.04514313, 22.56903076], [70.04514313, 22.56875038], [70.04486084, 22.56875038], [70.04486084, 22.56846046], [70.04458618, 22.56847191], [70.04458618, 22.56791687], [70.04429626, 22.56792068], [70.04429626, 22.5676403], [70.04402924, 22.5676403], [70.04402924, 22.56735992], [70.04374695, 22.56736183], [70.04374695, 22.56708336], [70.04347229, 22.56708336], [70.04347229, 22.56736183], [70.04207611, 22.56735992], [70.04207611, 22.57014084], [70.0423584, 22.57014084], [70.0423584, 22.57042122], [70.04264069, 22.5704174], [70.04264069, 22.57069397], [70.04291534, 22.57069397], [70.04291534, 22.57097244], [70.04319763, 22.57097054], [70.04319763, 22.57125092], [70.04347229, 22.57125092], [70.04347229, 22.57152748], [70.04374695, 22.57152748], [70.04374695, 22.57208252], [70.04402924, 22.57208061], [70.04402924, 22.57235909], [70.04458618, 22.57235909]]], [[[70.18180847, 22.58374977], [70.18180847, 22.58346939], [70.18208313, 22.5834713], [70.18208313, 22.58319473], [70.18235779, 22.58319473], [70.18235779, 22.58291626], [70.18264008, 22.58292007], [70.18264008, 22.58263969], [70.18319702, 22.58263969], [70.18319702, 22.58097076], [70.18096924, 22.58097076], [70.18096924, 22.58125114], [70.18068695, 22.58125114], [70.18068695, 22.58152962], [70.18013763, 22.58152962], [70.18013763, 22.58263969], [70.18041992, 22.58263969], [70.18041992, 22.58292007], [70.18069458, 22.58291626], [70.18069458, 22.5834713], [70.18125153, 22.58346939], [70.18125153, 22.58374977], [70.18180847, 22.58374977]]], [[[70.1904068, 22.59985924], [70.1904068, 22.59958076], [70.19069672, 22.59958267], [70.19069672, 22.59930611], [70.19097137, 22.59930992], [70.19097137, 22.59902763], [70.1912384, 22.59902763], [70.1912384, 22.5987606], [70.19152832, 22.5987606], [70.19152832, 22.59847069], [70.19180298, 22.5984726], [70.19180298, 22.59819412], [70.19152832, 22.59819412], [70.19152832, 22.59791946], [70.1912384, 22.59791946], [70.1912384, 22.59763908], [70.18930817, 22.59763908], [70.18930817, 22.59791946], [70.18902588, 22.59791946], [70.18902588, 22.5984726], [70.18875122, 22.5984726], [70.18875122, 22.59958267], [70.18930817, 22.59958076], [70.18930817, 22.59985924], [70.1904068, 22.59985924]]], [[[69.94847107, 22.60625076], [69.94847107, 22.60597038], [69.94875336, 22.60597229], [69.94875336, 22.60569572], [69.94985962, 22.60569572], [69.94985962, 22.60541725], [69.95041656, 22.60542107], [69.95041656, 22.60514069], [69.95069122, 22.60514069], [69.95069122, 22.60486031], [69.95096588, 22.60486031], [69.95096588, 22.60457039], [69.95153046, 22.60457039], [69.95153046, 22.60514069], [69.95181274, 22.60514069], [69.95181274, 22.60542107], [69.95207977, 22.60541725], [69.95207977, 22.60569572], [69.95291901, 22.60569572], [69.95291901, 22.60541725], [69.9540329, 22.60542107], [69.9540329, 22.60514069], [69.95485687, 22.60514069], [69.95485687, 22.60486031], [69.95569611, 22.60486031], [69.95569611, 22.60457039], [69.95625305, 22.60458374], [69.95625305, 22.60430527], [69.95680237, 22.6043129], [69.95680237, 22.60403061], [69.95707703, 22.60403061], [69.95707703, 22.60375023], [69.95819092, 22.60375023], [69.95819092, 22.60347176], [69.95874786, 22.60347366], [69.95874786, 22.60319519], [69.95929718, 22.60320282], [69.95929718, 22.60292053], [69.95957947, 22.60292053], [69.95957947, 22.60236168], [69.96013641, 22.60236168], [69.96013641, 22.60208321], [69.9604187, 22.60208321], [69.9604187, 22.60180473], [69.96097565, 22.60180473], [69.96097565, 22.60152817], [69.96153259, 22.60153008], [69.96153259, 22.6012516], [69.96180725, 22.6012516], [69.96180725, 22.60096931], [69.96263885, 22.60097313], [69.96263885, 22.60069466], [69.96291351, 22.60069466], [69.96291351, 22.60041618], [69.9631958, 22.60042191], [69.9631958, 22.60014153], [69.96375275, 22.60014153], [69.96375275, 22.59902763], [69.96347046, 22.59902763], [69.96347046, 22.5987606], [69.96290588, 22.5987606], [69.96290588, 22.59847069], [69.96263885, 22.5984726], [69.96263885, 22.59819412], [69.9623642, 22.59819412], [69.9623642, 22.59791946], [69.96153259, 22.59791946], [69.96153259, 22.59763908], [69.96098328, 22.59763908], [69.96098328, 22.59736061], [69.9604187, 22.59736061], [69.9604187, 22.59708023], [69.96013641, 22.59708405], [69.96013641, 22.59680557], [69.95986176, 22.59680939], [69.95986176, 22.59625053], [69.95957947, 22.59625053], [69.95957947, 22.59597015], [69.95819092, 22.59597206], [69.95819092, 22.59569359], [69.9576416, 22.59569359], [69.9576416, 22.59541512], [69.95707703, 22.59542084], [69.95707703, 22.59514046], [69.95680237, 22.59514046], [69.95680237, 22.59486008], [69.95458221, 22.59486008], [69.95458221, 22.59514046], [69.9540329, 22.59514046], [69.9540329, 22.59542084], [69.95319366, 22.59541512], [69.95319366, 22.59569359], [69.95291901, 22.59569359], [69.95291901, 22.59597206], [69.95207977, 22.59597015], [69.95207977, 22.59625053], [69.95181274, 22.59625053], [69.95181274, 22.59653091], [69.95153046, 22.59653091], [69.95153046, 22.59680939], [69.95124817, 22.59680557], [69.95124817, 22.59708405], [69.95096588, 22.59708023], [69.95096588, 22.59763908], [69.95069122, 22.59763908], [69.95069122, 22.59791946], [69.95041656, 22.59791946], [69.95041656, 22.59819412], [69.94957733, 22.59819031], [69.94957733, 22.5987606], [69.94902802, 22.5987606], [69.94902802, 22.59902763], [69.94875336, 22.59902763], [69.94875336, 22.60153008], [69.94902802, 22.60153008], [69.94902802, 22.60375023], [69.94875336, 22.60375023], [69.94875336, 22.60403061], [69.94847107, 22.60403061], [69.94847107, 22.6043129], [69.94819641, 22.60430527], [69.94819641, 22.60458374], [69.94790649, 22.60457039], [69.94790649, 22.60514069], [69.94763947, 22.60513878], [69.94763947, 22.60569572], [69.94790649, 22.60569], [69.94790649, 22.60625076], [69.94847107, 22.60625076]]], [[[70.2159729, 22.64681053], [70.2159729, 22.64653015], [70.21624756, 22.64653015], [70.21624756, 22.64624977], [70.21708679, 22.64624977], [70.21708679, 22.64596939], [70.21736145, 22.64596939], [70.21736145, 22.64624977], [70.2179184, 22.64624977], [70.2179184, 22.64596939], [70.21819305, 22.6459713], [70.21819305, 22.64541626], [70.21846771, 22.64542007], [70.21846771, 22.64486122], [70.21875, 22.64486122], [70.21875, 22.64458275], [70.2195816, 22.64458466], [70.2195816, 22.64430618], [70.21985626, 22.64431], [70.21985626, 22.64374161], [70.22013855, 22.64374924], [70.22013855, 22.64347267], [70.22097015, 22.64347267], [70.22097015, 22.6431942], [70.21930695, 22.6431942], [70.21930695, 22.64291573], [70.21901703, 22.64291954], [70.21901703, 22.64236259], [70.21930695, 22.64236259], [70.21930695, 22.64208031], [70.2195816, 22.64208412], [70.2195816, 22.64125252], [70.21985626, 22.64125252], [70.21985626, 22.64096832], [70.22013855, 22.64097023], [70.22013855, 22.64069366], [70.22041321, 22.64069366], [70.22041321, 22.64014053], [70.22013855, 22.64014053], [70.22013855, 22.64042091], [70.21986389, 22.6404171], [70.21986389, 22.64069366], [70.2179184, 22.64068031], [70.2179184, 22.64180946], [70.2181778, 22.64180946], [70.2181778, 22.64264107], [70.21736145, 22.64264107], [70.21736145, 22.64236259], [70.21708679, 22.64236259], [70.21708679, 22.64208031], [70.2168045, 22.64208412], [70.2168045, 22.6431942], [70.21708679, 22.64319038], [70.21708679, 22.64513969], [70.21679688, 22.64513969], [70.21679688, 22.64542007], [70.21541595, 22.64541626], [70.21541595, 22.64569473], [70.21569061, 22.64569283], [70.21569824, 22.64681053], [70.2159729, 22.64681053]]], [[[69.19541931, 22.3745842], [69.19541931, 22.37430573], [69.19596863, 22.37430954], [69.19596863, 22.37235832], [69.19625092, 22.37235832], [69.19625092, 22.37070084], [69.19596863, 22.37070084], [69.19596863, 22.37013817], [69.19568634, 22.37013817], [69.19568634, 22.36903], [69.19541931, 22.36903], [69.19541931, 22.36847115], [69.19513702, 22.36847305], [69.19513702, 22.36819458], [69.19486237, 22.36819458], [69.19486237, 22.3679142], [69.19458008, 22.36791992], [69.19458008, 22.36763954], [69.19403076, 22.36763954], [69.19403076, 22.36791992], [69.19374847, 22.36791992], [69.19374847, 22.36874962], [69.19319153, 22.36874962], [69.19319153, 22.36903], [69.19291687, 22.36902618], [69.19291687, 22.36930466], [69.18985748, 22.36930466], [69.18985748, 22.36958313], [69.19013977, 22.36958122], [69.19013977, 22.37013817], [69.19097137, 22.37013817], [69.19097137, 22.37042046], [69.19152832, 22.37042046], [69.19152832, 22.37070084], [69.19208527, 22.37069511], [69.19208527, 22.37097168], [69.19264221, 22.37096977], [69.19264221, 22.37124825], [69.19291687, 22.37124825], [69.19291687, 22.37153053], [69.19319153, 22.37153053], [69.19319153, 22.37208366], [69.19374847, 22.37207985], [69.19374847, 22.37264061], [69.19430542, 22.37264061], [69.19430542, 22.37319374], [69.19458008, 22.37319374], [69.19458008, 22.3745842], [69.19541931, 22.3745842]]], [[[69.3354187, 22.38903046], [69.3354187, 22.38875008], [69.33598328, 22.38875008], [69.33597565, 22.3884716], [69.33680725, 22.3884716], [69.33680725, 22.38763809], [69.33708191, 22.38764191], [69.33708191, 22.38736153], [69.33763885, 22.38736153], [69.33763885, 22.38708305], [69.33791351, 22.38708305], [69.33791351, 22.38680649], [69.3381958, 22.38680649], [69.3381958, 22.38708305], [69.33847046, 22.38708305], [69.33847046, 22.38736153], [69.3390274, 22.38736153], [69.3390274, 22.38708305], [69.33930206, 22.38708305], [69.33930206, 22.38680649], [69.33957672, 22.3868103], [69.33957672, 22.38625145], [69.33985901, 22.38625145], [69.33985901, 22.38430977], [69.33957672, 22.38430977], [69.33957672, 22.38236046], [69.33985901, 22.38236046], [69.33985901, 22.38208008], [69.34041595, 22.38208389], [69.34041595, 22.38097191], [69.3401413, 22.38097191], [69.3401413, 22.38069534], [69.33985901, 22.38070107], [69.33985901, 22.38042068], [69.3381958, 22.38042068], [69.3381958, 22.3801403], [69.33763885, 22.3801403], [69.33763885, 22.37985992], [69.3373642, 22.37986183], [69.3373642, 22.37930489], [69.33708191, 22.37930489], [69.33708191, 22.37874985], [69.33680725, 22.37874985], [69.33680725, 22.3781929], [69.33652496, 22.37819481], [69.33652496, 22.37763977], [69.33486176, 22.37763977], [69.33486176, 22.37735939], [69.33403015, 22.3773613], [69.33403015, 22.37708282], [69.33347321, 22.37708282], [69.33347321, 22.37624931], [69.33319092, 22.37625122], [69.33319092, 22.37541962], [69.33291626, 22.37541962], [69.33291626, 22.37486267], [69.33319092, 22.37486267], [69.33319092, 22.37375069], [69.33348083, 22.37375069], [69.33347321, 22.37347221], [69.33374786, 22.37347221], [69.33374786, 22.37319374], [69.33347321, 22.37319374], [69.33347321, 22.37264061], [69.33207703, 22.37264061], [69.33207703, 22.37291908], [69.33180237, 22.37291718], [69.33180237, 22.37319374], [69.33152771, 22.37318993], [69.33152771, 22.37375069], [69.33125305, 22.37375069], [69.33125305, 22.37486267], [69.3290329, 22.37486267], [69.3290329, 22.37514114], [69.32791901, 22.37514114], [69.32791901, 22.37541962], [69.32763672, 22.3754158], [69.32763672, 22.37569427], [69.3273468, 22.37569046], [69.3273468, 22.37598038], [69.32707977, 22.37598038], [69.32707977, 22.37625122], [69.32681274, 22.37625122], [69.32681274, 22.37652969], [69.32624817, 22.37652969], [69.32624817, 22.37681007], [69.32597351, 22.37680626], [69.32597351, 22.37708282], [69.32569122, 22.37708282], [69.32569122, 22.3773613], [69.32541656, 22.37735939], [69.32541656, 22.37763977], [69.32514191, 22.37763977], [69.32514191, 22.37819481], [69.32457733, 22.3781929], [69.32457733, 22.37874985], [69.32430267, 22.37874985], [69.32430267, 22.37958336], [69.32402802, 22.37958336], [69.32402802, 22.37986183], [69.32375336, 22.37985992], [69.32375336, 22.3801403], [69.32263947, 22.3801384], [69.32263947, 22.38097191], [69.32290649, 22.38097], [69.32290649, 22.38236046], [69.32347107, 22.38236046], [69.32347107, 22.38264084], [69.32402802, 22.38263893], [69.32402802, 22.38319397], [69.32430267, 22.38319397], [69.32430267, 22.38347244], [69.32485962, 22.38347054], [69.32485962, 22.38375092], [69.32847595, 22.38375092], [69.32847595, 22.38347054], [69.32902527, 22.38347244], [69.32902527, 22.38319397], [69.33013916, 22.38319397], [69.33013916, 22.38347244], [69.33041382, 22.38347244], [69.33041382, 22.38375092], [69.33069611, 22.38375092], [69.33069611, 22.38485909], [69.33042145, 22.38485909], [69.33042145, 22.38541985], [69.33013916, 22.38541985], [69.33013916, 22.38625145], [69.33152771, 22.38625145], [69.33152771, 22.38596916], [69.3326416, 22.38596916], [69.3326416, 22.38625145], [69.33430481, 22.38625145], [69.33430481, 22.38736153], [69.33374786, 22.38736153], [69.33374786, 22.38764191], [69.33348083, 22.38764191], [69.33348083, 22.38792038], [69.33374786, 22.38792038], [69.33374786, 22.3882103], [69.33430481, 22.38819504], [69.33430481, 22.3884716], [69.3345871, 22.3884716], [69.3345871, 22.38875008], [69.33486176, 22.38875008], [69.33486176, 22.38903046], [69.3354187, 22.38903046]]], [[[70.85456085, 20.75208282], [70.85736084, 20.75208282], [70.85736084, 20.7523613], [70.85819244, 20.75235939], [70.85819244, 20.75263977], [70.85958099, 20.75263977], [70.85958099, 20.75291824], [70.85986328, 20.75291824], [70.85986328, 20.75263977], [70.86042023, 20.75263977], [70.86042023, 20.75291824], [70.86096954, 20.75291824], [70.86096954, 20.75263977], [70.86152649, 20.75263977], [70.86152649, 20.75235939], [70.86180878, 20.7523613], [70.86180878, 20.75208282], [70.86235809, 20.75208282], [70.86235809, 20.7495842], [70.86180878, 20.7495842], [70.86180878, 20.74902725], [70.86152649, 20.74903107], [70.86152649, 20.74875069], [70.86096954, 20.74875069], [70.86096954, 20.74847031], [70.86042023, 20.74847221], [70.86042023, 20.74791718], [70.85986328, 20.74792099], [70.85986328, 20.74763107], [70.85958099, 20.7476387], [70.85958099, 20.74736023], [70.85874939, 20.74736023], [70.85874939, 20.74707985], [70.85847473, 20.74708366], [70.85847473, 20.74680519], [70.85819244, 20.74681091], [70.85819244, 20.74625015], [70.85791779, 20.74625015], [70.85791779, 20.74570084], [70.85764313, 20.74570084], [70.85764313, 20.74542046], [70.85736084, 20.74542046], [70.85736084, 20.74319077], [70.8576355, 20.74319458], [70.8576355, 20.7420826], [70.85791779, 20.7420826], [70.85791779, 20.74180603], [70.85874939, 20.74181938], [70.85874939, 20.74097061], [70.85902405, 20.74097252], [70.85902405, 20.74069405], [70.85930634, 20.74069405], [70.85930634, 20.7401371], [70.85958099, 20.74014091], [70.85958099, 20.73931122], [70.85986328, 20.73931122], [70.85986328, 20.73875809], [70.86013794, 20.73875809], [70.86013794, 20.73792076], [70.86042023, 20.73792076], [70.86042023, 20.7365303], [70.86068726, 20.7365303], [70.86068726, 20.73624992], [70.86096954, 20.73624992], [70.86096954, 20.73485947], [70.86125183, 20.73486137], [70.86125183, 20.73402786], [70.86152649, 20.73402977], [70.86152649, 20.73347282], [70.86180878, 20.73347473], [70.86180878, 20.73319435], [70.86208344, 20.73319435], [70.86208344, 20.73291588], [70.86235046, 20.73291969], [70.86235046, 20.73236275], [70.86264038, 20.73236275], [70.86264038, 20.73208046], [70.86291504, 20.73208046], [70.86291504, 20.73152733], [70.86319733, 20.73153114], [70.86319733, 20.73125267], [70.86347198, 20.73125267], [70.86347198, 20.73069191], [70.86374664, 20.73069382], [70.86374664, 20.73041725], [70.86402893, 20.73042107], [70.86402893, 20.7298584], [70.86429596, 20.7298584], [70.86429596, 20.72958946], [70.86458588, 20.72958946], [70.86458588, 20.72930908], [70.86486053, 20.72930908], [70.86486053, 20.72903061], [70.86540985, 20.72903061], [70.86540985, 20.72874832], [70.86569214, 20.72874832], [70.86569214, 20.72846985], [70.86597443, 20.72847176], [70.86597443, 20.72819519], [70.86653137, 20.72820091], [70.86653137, 20.72792053], [70.86680603, 20.72792053], [70.86680603, 20.72763824], [70.86736298, 20.72763824], [70.86736298, 20.72735977], [70.86763763, 20.72736168], [70.86763763, 20.72708321], [70.86846924, 20.72708321], [70.86846924, 20.72680473], [70.86930847, 20.72680473], [70.86930847, 20.72652626], [70.86958313, 20.72652817], [70.86958313, 20.72624969], [70.86985779, 20.72624969], [70.86985779, 20.72597122], [70.87069702, 20.72597313], [70.87069702, 20.72569466], [70.87152863, 20.72569466], [70.87152863, 20.72541618], [70.87180328, 20.72541809], [70.87180328, 20.72513962], [70.8720932, 20.72513962], [70.87208557, 20.72458267], [70.87236023, 20.72458267], [70.87236023, 20.72430611], [70.87264252, 20.72430992], [70.87264252, 20.72319031], [70.87236023, 20.72319412], [70.87236023, 20.72291756], [70.8720932, 20.72291946], [70.8720932, 20.72236061], [70.87180328, 20.72236061], [70.87180328, 20.72180939], [70.87153625, 20.72180939], [70.87153625, 20.72153091], [70.87124634, 20.72153091], [70.87124634, 20.72042084], [70.87097168, 20.72042084], [70.87097168, 20.71986008], [70.87069702, 20.71986389], [70.87069702, 20.71930504], [70.8704071, 20.71931076], [70.8704071, 20.71871948], [70.87041473, 20.71541595], [70.87014008, 20.71542168], [70.87014008, 20.71486092], [70.86930847, 20.71486092], [70.86930847, 20.71458817], [70.86875153, 20.71458817], [70.86875153, 20.71403122], [70.86847687, 20.71403122], [70.86847687, 20.71375084], [70.86818695, 20.71375084], [70.86818695, 20.71319008], [70.86791992, 20.71319389], [70.86791992, 20.71263885], [70.86847687, 20.71264076], [70.86847687, 20.71153069], [70.86902618, 20.71153069], [70.86902618, 20.71125031], [70.86875153, 20.71125031], [70.86875153, 20.71070099], [70.86902618, 20.71070099], [70.86902618, 20.70874977], [70.86875153, 20.70874977], [70.86875153, 20.70736122], [70.86902618, 20.70736122], [70.86902618, 20.70625114], [70.86930847, 20.70625114], [70.86930847, 20.70597267], [70.87208557, 20.70597267], [70.87208557, 20.7056942], [70.87374878, 20.7056942], [70.87374878, 20.70541573], [70.87403107, 20.70541954], [70.87403107, 20.70513153], [70.87403107, 20.70486259], [70.87374878, 20.70486259], [70.87374878, 20.70458031], [70.87291718, 20.70458412], [70.87291718, 20.70430565], [70.87264252, 20.70430946], [70.87264252, 20.7040329], [70.87014008, 20.7040329], [70.87014008, 20.70375252], [70.86791992, 20.70375252], [70.86791992, 20.7040329], [70.86708069, 20.7040329], [70.86708069, 20.70430946], [70.86653137, 20.70430565], [70.86653137, 20.70458412], [70.86624908, 20.70458031], [70.86624908, 20.70486259], [70.86540985, 20.70486259], [70.86540985, 20.70514107], [70.86486053, 20.70514107], [70.86486053, 20.70541954], [70.86374664, 20.70541763], [70.86374664, 20.7056942], [70.86152649, 20.7056942], [70.86152649, 20.70597267], [70.85874939, 20.70597267], [70.85874939, 20.70625114], [70.85819244, 20.70625114], [70.85819244, 20.70652962], [70.85736084, 20.70652962], [70.85736084, 20.70681], [70.85680389, 20.70680618], [70.85680389, 20.70708466], [70.85652924, 20.70708466], [70.85653687, 20.70763969], [70.85624695, 20.70763969], [70.85624695, 20.70792007], [70.8548584, 20.70791626], [70.8548584, 20.70819473], [70.85124969, 20.70819473], [70.85124969, 20.70791626], [70.84958649, 20.70792007], [70.84958649, 20.70763969], [70.84735107, 20.70763969], [70.84735107, 20.70736122], [70.84485626, 20.70736122], [70.84485626, 20.70714951], [70.8445816, 20.70708275], [70.8445816, 20.70680618], [70.84348297, 20.70681], [70.84348297, 20.70652962], [70.8429184, 20.70652962], [70.8429184, 20.70625114], [70.84208679, 20.70625114], [70.84208679, 20.70597267], [70.84124756, 20.70597267], [70.84124756, 20.7056942], [70.8409729, 20.7056942], [70.8409729, 20.70541763], [70.84041595, 20.70541954], [70.84041595, 20.70514107], [70.83957672, 20.70514107], [70.83957672, 20.70486259], [70.8390274, 20.70486259], [70.8390274, 20.70458031], [70.83875275, 20.70458412], [70.83875275, 20.70430565], [70.83847046, 20.70430946], [70.83847046, 20.7040329], [70.8381958, 20.7040329], [70.8381958, 20.70375252], [70.83790588, 20.70375252], [70.83790588, 20.70347023], [70.83763885, 20.70347023], [70.83763885, 20.70319366], [70.83680725, 20.70319366], [70.83680725, 20.7029171], [70.83651733, 20.70292091], [70.83651733, 20.70265007], [70.83625031, 20.70265007], [70.83625031, 20.70207977], [70.83597565, 20.70208359], [70.83597565, 20.70153046], [70.83569336, 20.70153046], [70.83569336, 20.70124817], [70.83541107, 20.70124817], [70.83541107, 20.7009697], [70.83513641, 20.7009716], [70.83513641, 20.70069504], [70.83486176, 20.70070076], [70.83486176, 20.70013809], [70.8345871, 20.70013809], [70.8345871, 20.69959068], [70.83429718, 20.69959068], [70.83429718, 20.6993103], [70.83403015, 20.6993103], [70.83403015, 20.69874954], [70.83429718, 20.69874954], [70.83429718, 20.69763947], [70.8345871, 20.69763947], [70.8345871, 20.69733047], [70.8345871, 20.69652748], [70.83486176, 20.69652748], [70.83486176, 20.69625092], [70.83541107, 20.69625092], [70.83541107, 20.69458008], [70.83569336, 20.6945858], [70.83569336, 20.69402695], [70.83598328, 20.69403076], [70.83598328, 20.69320107], [70.83680725, 20.69320107], [70.83680725, 20.69292068], [70.83790588, 20.69292068], [70.83790588, 20.6926403], [70.8381958, 20.6926403], [70.8381958, 20.69180107], [70.83847046, 20.69180489], [70.83847046, 20.69041634], [70.8381958, 20.69042015], [70.8381958, 20.69014168], [70.83708191, 20.69014168], [70.83708191, 20.69042015], [70.83651733, 20.69042015], [70.83648682, 20.69014168], [70.83625031, 20.69014168], [70.83625031, 20.6902504], [70.83625031, 20.69042015], [70.83597565, 20.69041634], [70.83598328, 20.69125175], [70.83486176, 20.69125175], [70.83486176, 20.69096947], [70.83347321, 20.69096947], [70.83347321, 20.69069481], [70.83180237, 20.69069481], [70.83180237, 20.69096947], [70.8298645, 20.69096947], [70.8298645, 20.69069481], [70.82958221, 20.69069481], [70.82958221, 20.69041634], [70.8290329, 20.69042015], [70.8290329, 20.69014168], [70.82763672, 20.69014168], [70.82763672, 20.69042015], [70.82597351, 20.69041634], [70.82597351, 20.69069481], [70.82541656, 20.69069481], [70.82541656, 20.69096947], [70.82485962, 20.69096947], [70.82485962, 20.69125175], [70.82375336, 20.69125175], [70.82375336, 20.69096947], [70.82235718, 20.69096947], [70.82235718, 20.69125175], [70.82180786, 20.69125175], [70.82180786, 20.69153023], [70.82152557, 20.69152832], [70.82152557, 20.69236374], [70.82180786, 20.69236183], [70.82180786, 20.69320107], [70.82152557, 20.69319534], [70.8215332, 20.69375038], [70.82013702, 20.69375038], [70.82013702, 20.69403076], [70.81958008, 20.69403076], [70.81958008, 20.69375038], [70.81903076, 20.69375038], [70.81903076, 20.69403076], [70.81874847, 20.69403076], [70.81874847, 20.69431114], [70.81847382, 20.69430542], [70.81847382, 20.6945858], [70.81819153, 20.69458008], [70.81819153, 20.69486046], [70.81764221, 20.69486046], [70.81764221, 20.69514084], [70.81736755, 20.69514084], [70.81736755, 20.69542122], [70.81708527, 20.6954174], [70.8170929, 20.69625092], [70.81680298, 20.69625092], [70.81680298, 20.69652748], [70.81652832, 20.69651985], [70.81652832, 20.69680977], [70.81597137, 20.69680405], [70.81597137, 20.69708252], [70.8154068, 20.69708061], [70.8154068, 20.69736099], [70.81513977, 20.69736099], [70.81513977, 20.69763947], [70.81485748, 20.69763947], [70.81485748, 20.69791985], [70.81430817, 20.69791794], [70.81430817, 20.6981945], [70.81402588, 20.6981945], [70.81402588, 20.69847298], [70.81375122, 20.69847107], [70.81375122, 20.69874954], [70.81291962, 20.69874954], [70.81291962, 20.69902992], [70.81263733, 20.69902992], [70.81263733, 20.6993103], [70.81236267, 20.6993103], [70.81236267, 20.69959068], [70.81208038, 20.69958305], [70.81208038, 20.69986153], [70.81124115, 20.69985962], [70.81124115, 20.70013809], [70.80930328, 20.70013809], [70.80930328, 20.69985962], [70.80902863, 20.69986153], [70.80902863, 20.69958305], [70.80847168, 20.69958305], [70.80847168, 20.69986153], [70.80764008, 20.69985962], [70.80764008, 20.70013809], [70.80735779, 20.70013809], [70.80735779, 20.70070076], [70.80764008, 20.70069504], [70.80764008, 20.7009716], [70.81014252, 20.7009697], [70.81014252, 20.70124817], [70.81069183, 20.70124817], [70.81069183, 20.70153046], [70.81124115, 20.70153046], [70.81124115, 20.70124817], [70.81236267, 20.70124817], [70.81236267, 20.70153046], [70.81487274, 20.70153046], [70.81513977, 20.70153046], [70.81513977, 20.70181084], [70.81569672, 20.70181084], [70.81569672, 20.70153046], [70.81736755, 20.70153046], [70.81736755, 20.70181084], [70.82013702, 20.70181084], [70.82013702, 20.70153046], [70.82042694, 20.70153046], [70.82042694, 20.70124817], [70.82069397, 20.70124817], [70.82068634, 20.69985962], [70.82041931, 20.69986153], [70.82041931, 20.69958305], [70.82013702, 20.69959068], [70.82013702, 20.6993103], [70.81958008, 20.6993103], [70.81955719, 20.69902992], [70.81931305, 20.69902992], [70.81931305, 20.69819069], [70.82041931, 20.6981945], [70.82041931, 20.69847298], [70.82402802, 20.69847298], [70.82402802, 20.6981945], [70.82514191, 20.6981945], [70.82514191, 20.69791794], [70.82541656, 20.69791985], [70.82541656, 20.69763947], [70.82596588, 20.69763947], [70.82596588, 20.69736099], [70.82736206, 20.69736099], [70.82736206, 20.69791985], [70.82763672, 20.69791985], [70.82763672, 20.69874954], [70.82707977, 20.69874954], [70.82707977, 20.70153046], [70.82736206, 20.70153046], [70.82736206, 20.70181084], [70.82763672, 20.70181084], [70.82763672, 20.70265007], [70.82791901, 20.70265007], [70.82791901, 20.70430946], [70.82819366, 20.70430565], [70.82819366, 20.70708466], [70.82847595, 20.70708466], [70.82847595, 20.7084713], [70.82875061, 20.7084713], [70.82875061, 20.70930672], [70.82819366, 20.70930672], [70.82819366, 20.70958328], [70.82791901, 20.70957947], [70.82791901, 20.71014023], [70.82763672, 20.71014023], [70.82763672, 20.71042061], [70.82791901, 20.71041679], [70.82791901, 20.71097183], [70.82763672, 20.71096992], [70.82763672, 20.71125031], [70.82736206, 20.71125031], [70.82736206, 20.71153069], [70.82707977, 20.71152687], [70.82707977, 20.71208382], [70.82680511, 20.71208382], [70.82681274, 20.71236038], [70.82402802, 20.71236038], [70.82402802, 20.71264076], [70.82375336, 20.71264076], [70.82375336, 20.71292114], [70.82347107, 20.71291733], [70.82347107, 20.71319389], [70.82125092, 20.71319389], [70.82125092, 20.71347237], [70.82041931, 20.71347237], [70.82042694, 20.71375084], [70.81958008, 20.71375084], [70.81958008, 20.71403122], [70.81903076, 20.71403122], [70.81903076, 20.71430969], [70.81791687, 20.71430969], [70.81791687, 20.71458817], [70.81708527, 20.71458244], [70.8170929, 20.71486092], [70.8154068, 20.71486092], [70.8154068, 20.7151413], [70.81513977, 20.7151413], [70.81513977, 20.71542168], [70.81541443, 20.71541595], [70.81541443, 20.71569443], [70.81569672, 20.71569443], [70.81569672, 20.7159729], [70.81597137, 20.71596909], [70.81597137, 20.71653175], [70.81625366, 20.71652985], [70.81625366, 20.71708107], [70.81652832, 20.71708107], [70.81652832, 20.71735954], [70.81680298, 20.71735954], [70.81680298, 20.71847343], [70.81652832, 20.71846962], [70.81652832, 20.71903038], [70.81569672, 20.71903038], [70.81569672, 20.71931076], [70.81485748, 20.71931076], [70.81485748, 20.71903038], [70.81402588, 20.71903038], [70.81402588, 20.71875191], [70.81346893, 20.71875191], [70.81346893, 20.71846962], [70.81331635, 20.71847343], [70.81319427, 20.71847343], [70.81319427, 20.71819496], [70.81291962, 20.71820068], [70.81291962, 20.71764946], [70.81263733, 20.71764946], [70.81263733, 20.71707916], [70.81291962, 20.71708107], [70.81291962, 20.71624947], [70.81318665, 20.71624947], [70.81318665, 20.71596909], [70.81346893, 20.7159729], [70.81346893, 20.7151413], [70.81318665, 20.7151413], [70.81318665, 20.71486092], [70.81096649, 20.71486092], [70.81096649, 20.71458817], [70.81069183, 20.71458817], [70.81069183, 20.71430969], [70.81041718, 20.71430969], [70.81041718, 20.71375084], [70.81014252, 20.71375084], [70.81014252, 20.71181107], [70.80986023, 20.71181107], [70.80986023, 20.71096992], [70.80958557, 20.71097183], [70.80958557, 20.71069527], [70.80930328, 20.71070099], [70.80930328, 20.71042061], [70.80902863, 20.71042061], [70.80902863, 20.71014023], [70.80874634, 20.71014023], [70.80874634, 20.71042061], [70.80847168, 20.71042061], [70.80847168, 20.71070099], [70.80652618, 20.71070099], [70.80652618, 20.71042061], [70.80596924, 20.71042061], [70.80596924, 20.70874977], [70.80625153, 20.70874977], [70.80625153, 20.70845985], [70.80652618, 20.7084713], [70.80652618, 20.70819473], [70.80596924, 20.70819473], [70.80596924, 20.70736122], [70.80568695, 20.70736122], [70.80568695, 20.70652962], [70.80596924, 20.70652962], [70.80596924, 20.70625114], [70.80625153, 20.70625114], [70.80625153, 20.70597267], [70.80652618, 20.70597267], [70.80652618, 20.70581055], [70.80652618, 20.7056942], [70.80674744, 20.7056942], [70.80735779, 20.7056942], [70.80735779, 20.70541573], [70.80819702, 20.70541954], [70.80819702, 20.70514107], [70.80847168, 20.70514107], [70.80847168, 20.70486259], [70.81014252, 20.70486259], [70.81014252, 20.70458031], [70.81069183, 20.70458412], [70.81069183, 20.70430565], [70.81096649, 20.70430946], [70.81096649, 20.70375252], [70.81069183, 20.70375252], [70.81069183, 20.70347023], [70.81014252, 20.70347023], [70.81014252, 20.70319366], [70.80958557, 20.70319366], [70.80958557, 20.7029171], [70.80930328, 20.70292091], [70.80930328, 20.70265007], [70.80902863, 20.70265007], [70.80902863, 20.70235825], [70.80791473, 20.70236015], [70.80791473, 20.70180511], [70.80708313, 20.70180511], [70.80708313, 20.70208359], [70.80625153, 20.70208359], [70.80625153, 20.70236015], [70.80541992, 20.70236015], [70.80541992, 20.70208359], [70.80458069, 20.70208359], [70.80458069, 20.70069504], [70.80374908, 20.70069504], [70.80374908, 20.7009716], [70.8034668, 20.7009697], [70.8034668, 20.70124817], [70.80319214, 20.70124817], [70.80319214, 20.70153046], [70.80291748, 20.70153046], [70.80291748, 20.70181084], [70.80236053, 20.70180511], [70.80236053, 20.70208359], [70.80180359, 20.70208359], [70.80180359, 20.70236015], [70.80124664, 20.70235825], [70.80124664, 20.70292091], [70.80097198, 20.7029171], [70.80097198, 20.70319366], [70.80069733, 20.70319366], [70.80069733, 20.70347023], [70.80041504, 20.70347023], [70.80042267, 20.70375252], [70.79985809, 20.70375252], [70.79985809, 20.7040329], [70.79930115, 20.7040329], [70.79930115, 20.70430946], [70.79902649, 20.70430565], [70.79902649, 20.70458412], [70.79875183, 20.70458031], [70.79875183, 20.70486259], [70.79846954, 20.70486259], [70.79846954, 20.70514107], [70.79792023, 20.70514107], [70.79792023, 20.70541954], [70.79763794, 20.70541763], [70.79763794, 20.7056942], [70.79736328, 20.7056942], [70.79736328, 20.70597267], [70.79708099, 20.70597267], [70.79708099, 20.70625114], [70.79680634, 20.70625114], [70.79680634, 20.70652962], [70.79651642, 20.70652962], [70.79651642, 20.70681], [70.79624939, 20.70680618], [70.79624939, 20.70708466], [70.7959671, 20.70708275], [70.7959671, 20.70736122], [70.79569244, 20.70736122], [70.79569244, 20.70792007], [70.79541779, 20.70791626], [70.79541779, 20.70819473], [70.79514313, 20.70819092], [70.79514313, 20.70903015], [70.79486084, 20.70902824], [70.79486084, 20.70930672], [70.79458618, 20.70930672], [70.79458618, 20.70958328], [70.79430389, 20.70958328], [70.79430389, 20.70986176], [70.79402924, 20.70985985], [70.79402924, 20.71042061], [70.79374695, 20.71041679], [70.79374695, 20.71097183], [70.79347229, 20.71096992], [70.79347229, 20.71125031], [70.79319763, 20.71125031], [70.79319763, 20.71153069], [70.79292297, 20.71153069], [70.79292297, 20.71181107], [70.79264069, 20.71180534], [70.79264069, 20.71208382], [70.79208374, 20.71208382], [70.79208374, 20.71236038], [70.7919693, 20.71236038], [70.79070282, 20.71236038], [70.79070282, 20.71264076], [70.78848267, 20.71264076], [70.78848267, 20.71292114], [70.78624725, 20.71291733], [70.78624725, 20.71319389], [70.7859726, 20.71319008], [70.7859726, 20.71375084], [70.78569794, 20.71375084], [70.78569794, 20.7140274], [70.78557587, 20.7140274], [70.78430176, 20.71403122], [70.78430176, 20.71375084], [70.78347015, 20.71375084], [70.78347015, 20.71403122], [70.78291321, 20.71403122], [70.78291321, 20.71430969], [70.78235626, 20.71430969], [70.78235626, 20.71458817], [70.77986145, 20.71458817], [70.77986145, 20.71486092], [70.77929687, 20.71486092], [70.77929687, 20.7151413], [70.7784729, 20.7151413], [70.7784729, 20.71542168], [70.77791595, 20.71541595], [70.77791595, 20.71569443], [70.77735901, 20.71569443], [70.77735901, 20.71581078], [70.77735901, 20.7159729], [70.7765274, 20.71596909], [70.7765274, 20.71624947], [70.77625275, 20.71624947], [70.77625275, 20.71653175], [70.77375031, 20.71653175], [70.77375031, 20.71681023], [70.77319336, 20.71680641], [70.77319336, 20.71708107], [70.77263641, 20.71708107], [70.77263641, 20.71735954], [70.77236176, 20.71735954], [70.77236176, 20.71764946], [70.77179718, 20.71764946], [70.77179718, 20.7179203], [70.77153015, 20.7179203], [70.77153015, 20.71820068], [70.77124786, 20.71819496], [70.77124786, 20.71847343], [70.77069092, 20.71846962], [70.77069092, 20.71875191], [70.76957703, 20.71875191], [70.76957703, 20.71903038], [70.76902771, 20.71903038], [70.76902771, 20.71931076], [70.76875305, 20.71930504], [70.76875305, 20.71958351], [70.76847076, 20.71958351], [70.76847076, 20.71986389], [70.76819611, 20.71986008], [70.76819611, 20.72014046], [70.76763916, 20.72014046], [70.76763916, 20.72042084], [70.7673645, 20.72041702], [70.7673645, 20.72069359], [70.76652527, 20.72069359], [70.76652527, 20.72097206], [70.76625061, 20.72097015], [70.76625061, 20.72125053], [70.76486206, 20.72125053], [70.76486206, 20.72153091], [70.76207733, 20.72153091], [70.76207733, 20.72180939], [70.76097107, 20.72180557], [70.76097107, 20.72208595], [70.76069641, 20.72208595], [70.76069641, 20.72180557], [70.76041412, 20.72180557], [70.76041412, 20.72208595], [70.75930786, 20.72208023], [70.75930786, 20.72236061], [70.75846863, 20.72236061], [70.75846863, 20.72264099], [70.75653076, 20.72264099], [70.75653076, 20.72236061], [70.75541687, 20.72236061], [70.75541687, 20.72208023], [70.75514221, 20.72208595], [70.75514221, 20.72180557], [70.75485992, 20.72180939], [70.75485992, 20.72153091], [70.75347137, 20.72153091], [70.75347137, 20.72126007], [70.75263977, 20.72125053], [70.75263977, 20.72097015], [70.75235748, 20.72097206], [70.75235748, 20.72069359], [70.75180817, 20.72069359], [70.75180817, 20.72041702], [70.75041962, 20.72042084], [70.75041962, 20.72014046], [70.74986267, 20.72014046], [70.74986267, 20.71986008], [70.74958038, 20.71986389], [70.74958038, 20.71958351], [70.74930573, 20.71958351], [70.74930573, 20.71930504], [70.74708557, 20.71930504], [70.74708557, 20.71958351], [70.74680328, 20.71958351], [70.74680328, 20.71986389], [70.74652863, 20.71986008], [70.74652863, 20.72014046], [70.74514771, 20.72014046], [70.74514771, 20.71986008], [70.74485779, 20.71986008], [70.74485779, 20.72014046], [70.74430847, 20.72014046], [70.74430847, 20.71986008], [70.74375153, 20.71986008], [70.74375153, 20.72014046], [70.74346924, 20.72014046], [70.74346924, 20.72042084], [70.74319458, 20.72041702], [70.74319458, 20.72069359], [70.74236298, 20.72069359], [70.74236298, 20.72097206], [70.74208069, 20.72097206], [70.74208832, 20.72125053], [70.74180603, 20.72125053], [70.74180603, 20.72153091], [70.7409668, 20.72153091], [70.7409668, 20.72180939], [70.74013519, 20.72180557], [70.74013519, 20.72208595], [70.73986053, 20.72208023], [70.73986053, 20.72236061], [70.73929596, 20.72236061], [70.73929596, 20.72264099], [70.73847198, 20.72264099], [70.73847198, 20.72291946], [70.73791504, 20.72291756], [70.73791504, 20.72319412], [70.73735809, 20.72319412], [70.73735809, 20.7234726], [70.73680878, 20.72347069], [70.73680878, 20.72375107], [70.73625183, 20.72375107], [70.73625183, 20.72402954], [70.73542023, 20.72402954], [70.73542023, 20.72430992], [70.73513794, 20.72430992], [70.73513794, 20.72486115], [70.73486328, 20.72486115], [70.73486328, 20.72513962], [70.73430634, 20.72513962], [70.73430634, 20.72541809], [70.73402405, 20.72541618], [70.73402405, 20.72569466], [70.73374939, 20.72569466], [70.73374939, 20.72597313], [70.7334671, 20.72597122], [70.7334671, 20.72624969], [70.73319244, 20.72624969], [70.73319244, 20.72652817], [70.73291779, 20.72652626], [70.73291779, 20.72680473], [70.73236084, 20.72680473], [70.73236084, 20.72708321], [70.73180389, 20.72708321], [70.73180389, 20.72736168], [70.73152924, 20.72735977], [70.73152924, 20.72763824], [70.73097229, 20.72763824], [70.73097229, 20.72792053], [70.73069763, 20.72792053], [70.73069763, 20.72820091], [70.73014069, 20.72819519], [70.73014069, 20.72847176], [70.72875214, 20.72846985], [70.72875214, 20.72874832], [70.72846985, 20.72874832], [70.72846985, 20.72846985], [70.72819519, 20.72847176], [70.72820282, 20.72874832], [70.72735596, 20.72874832], [70.72735596, 20.72903061], [70.72680664, 20.72903061], [70.72680664, 20.72930908], [70.72624969, 20.72930908], [70.72624969, 20.72958946], [70.72458649, 20.72958946], [70.72458649, 20.7298584], [70.72402191, 20.7298584], [70.72402191, 20.73014259], [70.7234726, 20.73014259], [70.7234726, 20.73042107], [70.72319794, 20.73041725], [70.72319794, 20.73069382], [70.72264099, 20.73069382], [70.72264099, 20.73097038], [70.72207642, 20.73097038], [70.72207642, 20.73125267], [70.72180939, 20.73125267], [70.72180176, 20.73153114], [70.72097778, 20.73153114], [70.72097778, 20.73180962], [70.71986389, 20.7318058], [70.71986389, 20.73208427], [70.7195816, 20.73208046], [70.7195816, 20.73236275], [70.71902466, 20.73236275], [70.71902466, 20.73263931], [70.71848297, 20.73263168], [70.71848297, 20.73291969], [70.7179184, 20.73291588], [70.7179184, 20.73319435], [70.71736145, 20.73319435], [70.71736145, 20.73347473], [70.71679688, 20.73347282], [70.71679688, 20.73374939], [70.71624756, 20.73374939], [70.71624756, 20.73402977], [70.71569824, 20.73402977], [70.71569824, 20.73431015], [70.71485901, 20.73430634], [70.71485901, 20.73458481], [70.71430206, 20.73458481], [70.71430206, 20.73486137], [70.7140274, 20.73485947], [70.7140274, 20.73513985], [70.71347046, 20.73513985], [70.71347046, 20.73542023], [70.7131958, 20.73541641], [70.7131958, 20.73569489], [70.71291351, 20.73569489], [70.71291351, 20.73597145], [70.71208191, 20.73596954], [70.71208191, 20.73624992], [70.71125031, 20.73624992], [70.71125031, 20.7365303], [70.71098328, 20.7365303], [70.71098328, 20.73681068], [70.71013641, 20.73680687], [70.71013641, 20.73708344], [70.7095871, 20.73708344], [70.7095871, 20.73736191], [70.70929718, 20.73736], [70.70929718, 20.73764038], [70.70819092, 20.73764038], [70.70819092, 20.73792076], [70.70708466, 20.73791695], [70.70708466, 20.73819351], [70.70513916, 20.73819351], [70.70513916, 20.73791695], [70.70347595, 20.73791695], [70.70347595, 20.7381897], [70.70318604, 20.73820114], [70.70318604, 20.73875809], [70.70263672, 20.73875809], [70.70263672, 20.73903084], [70.70236206, 20.73903084], [70.70236206, 20.73931122], [70.70207977, 20.7393055], [70.70207977, 20.73958397], [70.70181274, 20.73958015], [70.70181274, 20.74014091], [70.70124817, 20.74014091], [70.70124817, 20.74041748], [70.70097351, 20.74041748], [70.70097351, 20.74069405], [70.70069122, 20.74069023], [70.70069122, 20.74124908], [70.70014191, 20.74124908], [70.70014191, 20.74152756], [70.69957733, 20.74152756], [70.69957733, 20.74181938], [70.69930267, 20.74180603], [70.69930267, 20.7420826], [70.69902802, 20.74208069], [70.69902802, 20.74235916], [70.69875336, 20.74235916], [70.69875336, 20.74264145], [70.69819641, 20.74264145], [70.69819641, 20.74292183], [70.69791412, 20.74291611], [70.69791412, 20.74319458], [70.69763947, 20.74319458], [70.69763947, 20.74347115], [70.69735718, 20.74346924], [70.69735718, 20.74375153], [70.69680786, 20.74375153], [70.69680786, 20.74403191], [70.69625092, 20.74402809], [70.69625092, 20.74430466], [70.69596863, 20.74430466], [70.69596863, 20.74486351], [70.69568634, 20.7448597], [70.69568634, 20.74514008], [70.69513702, 20.74514008], [70.69513702, 20.74542046], [70.69458008, 20.74542046], [70.69458008, 20.74570084], [70.69403076, 20.74569511], [70.69403076, 20.74597359], [70.69346619, 20.74596977], [70.69346619, 20.74625015], [70.69319153, 20.74625015], [70.69319153, 20.74653053], [70.69291687, 20.74653053], [70.69291687, 20.74681091], [70.69235992, 20.74680519], [70.69235992, 20.74708366], [70.69152832, 20.74707985], [70.69152832, 20.74736023], [70.69097137, 20.74736023], [70.69097137, 20.7476387], [70.68930817, 20.74763107], [70.68930817, 20.74792099], [70.68846893, 20.74791718], [70.68846893, 20.74819565], [70.68791962, 20.74819565], [70.68791962, 20.74847221], [70.68736267, 20.74847031], [70.68736267, 20.74875069], [70.68681335, 20.74875069], [70.68681335, 20.74903107], [70.68624878, 20.74903107], [70.68624878, 20.74930954], [70.68597412, 20.74930573], [70.68597412, 20.7495842], [70.68569183, 20.74958038], [70.68569183, 20.74986076], [70.68514252, 20.74986076], [70.68514252, 20.75014114], [70.68486786, 20.75014114], [70.68486786, 20.75041962], [70.68430328, 20.75041962], [70.68430328, 20.7507], [70.68402863, 20.75069427], [70.68402863, 20.75097275], [70.68347168, 20.75097084], [70.68347168, 20.75125122], [70.68319702, 20.75125122], [70.68319702, 20.75152969], [70.6829071, 20.75152969], [70.6829071, 20.75181007], [70.68235779, 20.75180626], [70.68235779, 20.75208282], [70.68208313, 20.75208092], [70.68208313, 20.75263977], [70.68180847, 20.75263977], [70.68180847, 20.75291824], [70.68152618, 20.75291634], [70.68152618, 20.75319481], [70.68125153, 20.75319481], [70.68125153, 20.75338173], [70.68125153, 20.75347137], [70.68096924, 20.75346947], [70.68096924, 20.75375938], [70.68068695, 20.75375938], [70.68068695, 20.75402832], [70.68041992, 20.75402832], [70.68041992, 20.75430489], [70.68013763, 20.75430489], [70.68013763, 20.75458336], [70.67903137, 20.75458336], [70.67903137, 20.75486183], [70.67819214, 20.75485992], [70.67819214, 20.7551384], [70.67764282, 20.7551384], [70.67764282, 20.75542068], [70.67736053, 20.75542068], [70.67736053, 20.75569916], [70.67708588, 20.75569534], [70.67708588, 20.75597191], [70.67679596, 20.75596809], [70.67679596, 20.75624847], [70.67652893, 20.75624847], [70.67652893, 20.75653076], [70.67624664, 20.75652695], [70.67624664, 20.75680542], [70.67541504, 20.75680542], [70.67541504, 20.75708389], [70.67514038, 20.75708008], [70.67514038, 20.75736237], [70.67457581, 20.75736237], [70.67457581, 20.75764275], [70.67430878, 20.75764084], [70.67430878, 20.75819206], [70.67402649, 20.75819016], [70.67402649, 20.75930977], [70.67430878, 20.75930977], [70.67430878, 20.7598629], [70.67402649, 20.7598629], [70.67402649, 20.76013947], [70.67375183, 20.76013947], [70.67375183, 20.76097488], [70.67346954, 20.76097488], [70.67346954, 20.76180077], [70.67375183, 20.76180649], [70.67375183, 20.7634716], [70.67346954, 20.7634716], [70.67346954, 20.76458359], [70.67263794, 20.76458359], [70.67263794, 20.76349068], [70.67263794, 20.76319695], [70.67292786, 20.76320076], [70.67292786, 20.76235962], [70.67263794, 20.76236153], [70.67263794, 20.76208305], [70.67236328, 20.76208305], [70.67236328, 20.76180649], [70.67208099, 20.7618103], [70.67208099, 20.76152992], [70.67180634, 20.76152992], [70.67180634, 20.76124954], [70.67151642, 20.76124954], [70.67151642, 20.76097107], [70.6701355, 20.76097488], [70.67014313, 20.76124954], [70.66929626, 20.76124954], [70.66929626, 20.76152992], [70.66707611, 20.76152992], [70.66707611, 20.76124954], [70.66625214, 20.76124954], [70.66625214, 20.76152992], [70.66596985, 20.76152992], [70.66596985, 20.7618103], [70.6654129, 20.7618084], [70.66374969, 20.76180649], [70.66374969, 20.76208305], [70.66291809, 20.76208305], [70.66291809, 20.76152802], [70.6626358, 20.76152992], [70.6626358, 20.76097107], [70.66347504, 20.76097488], [70.66347504, 20.7606945], [70.66374969, 20.7606945], [70.66374969, 20.76013947], [70.66401672, 20.76013947], [70.66401672, 20.75956917], [70.66430664, 20.75958061], [70.66430664, 20.75902748], [70.6645813, 20.75902939], [70.6645813, 20.75854111], [70.6645813, 20.7579174], [70.66513824, 20.75792122], [70.66513824, 20.75736237], [70.6654129, 20.75736237], [70.6654129, 20.75708008], [70.66569519, 20.75708389], [70.66569519, 20.75652695], [70.66596985, 20.75653076], [70.66596985, 20.75596809], [70.66652679, 20.75597191], [70.66652679, 20.75486183], [70.66680908, 20.75486183], [70.66680908, 20.75263977], [70.66652679, 20.75263977], [70.66652679, 20.75235939], [70.66625214, 20.75235939], [70.66625214, 20.75263977], [70.66570282, 20.75263977], [70.66570282, 20.75291824], [70.6654129, 20.75291634], [70.6654129, 20.75319481], [70.66485596, 20.75319099], [70.66485596, 20.75402832], [70.66513824, 20.75402832], [70.66513824, 20.75430489], [70.66485596, 20.75430107], [70.66485596, 20.7551384], [70.6645813, 20.7551384], [70.6645813, 20.75569916], [70.66430664, 20.75569534], [70.66430664, 20.75597191], [70.66401672, 20.75596809], [70.66402435, 20.75624847], [70.66347504, 20.75624847], [70.66347504, 20.75597191], [70.66319275, 20.75596809], [70.66319275, 20.75624847], [70.66291809, 20.75624847], [70.66291809, 20.75819206], [70.6626358, 20.75819206], [70.6626358, 20.75847054], [70.66236115, 20.75847054], [70.66236115, 20.75819206], [70.66152954, 20.75819206], [70.66152954, 20.75847054], [70.66069794, 20.75847054], [70.66069794, 20.75875282], [70.6598587, 20.75875282], [70.6598587, 20.75902939], [70.65763855, 20.75902748], [70.65763855, 20.75958061], [70.65736389, 20.75958061], [70.65736389, 20.7598629], [70.65714264, 20.7598629], [70.65680695, 20.7598629], [70.65680695, 20.76013947], [70.65652466, 20.76013947], [70.65652466, 20.76097488], [70.65680695, 20.76097107], [70.65680695, 20.7618103], [70.65625, 20.76180649], [70.65625, 20.76236153], [70.65680695, 20.76235962], [70.65680695, 20.76264], [70.6570816, 20.76264], [70.6570816, 20.76292992], [70.65735626, 20.76292992], [70.65735626, 20.76431084], [70.6570816, 20.76430511], [70.6570816, 20.76458359], [70.65537262, 20.76458359], [70.65458679, 20.76458359], [70.65458679, 20.76402855], [70.65486145, 20.76403046], [70.65486145, 20.76320076], [70.6543045, 20.76319695], [70.6543045, 20.7634716], [70.65402985, 20.7634697], [70.65402985, 20.76375008], [70.65374756, 20.76375008], [70.65374756, 20.76403046], [70.65319824, 20.76403046], [70.65319824, 20.76431084], [70.65207672, 20.76431084], [70.65207672, 20.76403046], [70.65180206, 20.76403046], [70.65180206, 20.76375008], [70.6515274, 20.76375008], [70.6515274, 20.7634697], [70.64763641, 20.7634716], [70.64763641, 20.76319695], [70.6470871, 20.76320076], [70.6470871, 20.76292992], [70.64653015, 20.76292992], [70.64653015, 20.76320076], [70.6451416, 20.76319695], [70.6451416, 20.7634716], [70.64430237, 20.7634697], [70.64430237, 20.76375008], [70.64402771, 20.76375008], [70.64402771, 20.76403046], [70.64347076, 20.76403046], [70.64347076, 20.76431084], [70.64291382, 20.76430511], [70.64291382, 20.76458359], [70.6423645, 20.76458359], [70.6423645, 20.76486206], [70.64180756, 20.76486015], [70.64180756, 20.76514053], [70.6415329, 20.76514053], [70.6415329, 20.76542091], [70.64125061, 20.76541519], [70.64125061, 20.76597214], [70.64068604, 20.76597023], [70.64068604, 20.76625061], [70.64041901, 20.76625061], [70.64041901, 20.76652908], [70.64013672, 20.76652908], [70.64013672, 20.76680946], [70.63986206, 20.76680565], [70.63986206, 20.76708412], [70.63957214, 20.76708031], [70.63957214, 20.76736069], [70.63874817, 20.76736069], [70.63874817, 20.76763916], [70.63819122, 20.76763916], [70.63819122, 20.76791763], [70.63791656, 20.76791763], [70.63791656, 20.7681942], [70.63735962, 20.7681942], [70.63735962, 20.76874924], [70.63680267, 20.7687397], [70.63680267, 20.76903152], [70.63597107, 20.76903152], [70.63597107, 20.7693119], [70.63541412, 20.76930618], [70.63541412, 20.76958275], [70.63375092, 20.76958275], [70.63375092, 20.76930618], [70.63346863, 20.7693119], [70.63346863, 20.76903152], [70.63318634, 20.76903152], [70.63318634, 20.7687397], [70.63291931, 20.76874924], [70.63291931, 20.7681942], [70.63263702, 20.7681942], [70.63263702, 20.76791763], [70.63208008, 20.76791763], [70.63208008, 20.7681942], [70.63057709, 20.7681942], [70.63014221, 20.7681942], [70.63014221, 20.76847267], [70.62875366, 20.76847267], [70.62875366, 20.7681942], [70.62847137, 20.7681942], [70.62847137, 20.76791763], [70.62735748, 20.76791763], [70.62735748, 20.7681942], [70.62680817, 20.7681942], [70.62680817, 20.76847267], [70.62652588, 20.76847267], [70.62652588, 20.76874924], [70.62625122, 20.7687397], [70.62625122, 20.76903152], [70.62596893, 20.76903152], [70.62596893, 20.7693119], [70.62430573, 20.76930618], [70.62430573, 20.76958275], [70.62346649, 20.76958084], [70.62346649, 20.76985931], [70.62319183, 20.76985931], [70.62319183, 20.7701416], [70.62291718, 20.7701416], [70.62291718, 20.77042007], [70.62264252, 20.77041626], [70.62264252, 20.77069473], [70.62208557, 20.77069473], [70.62208557, 20.77096939], [70.62180328, 20.77096939], [70.62180328, 20.77125168], [70.62097168, 20.77125168], [70.62097168, 20.77153015], [70.61736298, 20.77152824], [70.61736298, 20.77180481], [70.61680603, 20.77180481], [70.61680603, 20.77152824], [70.61624908, 20.77152824], [70.61624908, 20.77180481], [70.61597443, 20.77180481], [70.61597443, 20.77152824], [70.61569214, 20.77153015], [70.61569214, 20.77125168], [70.61541748, 20.77125168], [70.61541748, 20.77096939], [70.61569214, 20.77096939], [70.61569214, 20.7701416], [70.61541748, 20.7701416], [70.61541748, 20.76985931], [70.61458588, 20.76985931], [70.61458588, 20.7701416], [70.61429596, 20.7701416], [70.61429596, 20.77042007], [70.61374664, 20.77041626], [70.61374664, 20.77069473], [70.61347198, 20.77069473], [70.61347198, 20.77096939], [70.61180878, 20.77096939], [70.61180878, 20.77125168], [70.61152649, 20.77125168], [70.61152649, 20.77208138], [70.61180878, 20.77208138], [70.61180878, 20.77236366], [70.61263275, 20.77236176], [70.61263275, 20.77264023], [70.61292267, 20.77264023], [70.61292267, 20.77403069], [70.61264038, 20.77402687], [70.61264038, 20.77458572], [70.61207581, 20.77458], [70.61207581, 20.77486992], [70.61180878, 20.77486992], [70.61180878, 20.77514076], [70.61068726, 20.77514076], [70.61068726, 20.77542114], [70.61042023, 20.77541733], [70.61042023, 20.7756958], [70.61013794, 20.7756958], [70.61013794, 20.77597237], [70.60986328, 20.77597046], [70.60986328, 20.77625084], [70.60901642, 20.77625084], [70.60901642, 20.77653122], [70.6084671, 20.77653122], [70.6084671, 20.77680969], [70.6076355, 20.77680588], [70.6076355, 20.77708244], [70.60736084, 20.77708054], [70.60736084, 20.77736092], [70.60679626, 20.77736092], [70.60679626, 20.77708054], [70.60541534, 20.77708244], [70.60541534, 20.77680588], [70.60514069, 20.77680969], [70.60514069, 20.77653122], [70.60457611, 20.77653122], [70.60457611, 20.77680969], [70.60430908, 20.77680588], [70.60430908, 20.77708244], [70.60402679, 20.77708054], [70.60402679, 20.77736092], [70.60319519, 20.77736092], [70.60320282, 20.77763939], [70.60263824, 20.77763939], [70.60263824, 20.77793121], [70.60180664, 20.77793121], [70.60180664, 20.77763939], [70.60151672, 20.77763939], [70.60151672, 20.77736092], [70.60097504, 20.77736092], [70.60098267, 20.77763939], [70.59929657, 20.77763939], [70.59929657, 20.77793121], [70.59874725, 20.77791786], [70.59874725, 20.77819443], [70.5984726, 20.77819443], [70.5984726, 20.7784729], [70.59791565, 20.7784729], [70.59792328, 20.77874947], [70.59680939, 20.77874947], [70.59680176, 20.77902985], [70.5965271, 20.77902985], [70.5965271, 20.77931023], [70.59541321, 20.77930641], [70.59541321, 20.77958298], [70.59513855, 20.77958298], [70.59513855, 20.77986145], [70.59430695, 20.77985954], [70.59430695, 20.78013992], [70.59401703, 20.78013992], [70.59401703, 20.7804203], [70.59319305, 20.7804203], [70.59319305, 20.78070068], [70.59236145, 20.78069496], [70.59236145, 20.78097153], [70.59179688, 20.78096962], [70.59179688, 20.78124809], [70.59152222, 20.78124809], [70.59152222, 20.78152847], [70.59069824, 20.78152847], [70.59069824, 20.78181076], [70.58985901, 20.78180504], [70.58985901, 20.78208351], [70.58847046, 20.78208351], [70.58847046, 20.78180504], [70.58790588, 20.78181076], [70.58790588, 20.78152847], [70.58763885, 20.78152847], [70.58763885, 20.78124809], [70.58651733, 20.78124809], [70.58651733, 20.78152847], [70.5854187, 20.78152847], [70.5854187, 20.78208351], [70.58513641, 20.78208351], [70.58513641, 20.78236008], [70.58486176, 20.78235817], [70.58486176, 20.78263855], [70.5845871, 20.78263855], [70.5845871, 20.78292084], [70.58430481, 20.78291702], [70.58430481, 20.78347015], [70.58403015, 20.78347015], [70.58403015, 20.78403282], [70.58374786, 20.78403282], [70.58374786, 20.78430939], [70.58347321, 20.78430557], [70.58347321, 20.78458405], [70.58319092, 20.78458023], [70.58319092, 20.78486252], [70.58291626, 20.78486252], [70.58291626, 20.7851429], [70.58235931, 20.7851429], [70.58235931, 20.78541946], [70.58208466, 20.78541756], [70.58208466, 20.78569221], [70.58180237, 20.78569221], [70.58180237, 20.7859726], [70.58152771, 20.7859726], [70.58152771, 20.78625107], [70.58125305, 20.78625107], [70.58125305, 20.78652954], [70.58097076, 20.78652954], [70.58097076, 20.78680992], [70.58069611, 20.78680611], [70.58069611, 20.78708458], [70.58013916, 20.78708076], [70.58013916, 20.78736115], [70.57985687, 20.78736115], [70.57985687, 20.78763962], [70.57958221, 20.78763962], [70.57958221, 20.78792], [70.57930756, 20.78791618], [70.57930756, 20.78847313], [70.57875061, 20.78847122], [70.57875061, 20.78874969], [70.57818604, 20.78874969], [70.57818604, 20.78903008], [70.57763672, 20.78902817], [70.57763672, 20.78930473], [70.57707977, 20.78930473], [70.57707977, 20.78958321], [70.57681274, 20.78957939], [70.57681274, 20.78987122], [70.57652283, 20.78987122], [70.57652283, 20.79014015], [70.57541656, 20.79014015], [70.57541656, 20.79042053], [70.57514191, 20.79042053], [70.57514191, 20.79070091], [70.57458496, 20.79069519], [70.57458496, 20.79097176], [70.57402802, 20.79096985], [70.57402802, 20.79125023], [70.57375336, 20.79125023], [70.57375336, 20.79153061], [70.57290649, 20.79153061], [70.57290649, 20.79181099], [70.57236481, 20.79180527], [70.57236481, 20.79208374], [70.57180786, 20.79207993], [70.57180786, 20.79236031], [70.5715332, 20.79236031], [70.5715332, 20.79264069], [70.57096863, 20.79263878], [70.57096863, 20.79291725], [70.57013702, 20.79291725], [70.57013702, 20.79319382], [70.56680298, 20.79319382], [70.56680298, 20.79347229], [70.56597137, 20.79347229], [70.56597137, 20.79319382], [70.56541443, 20.79319382], [70.56541443, 20.79347229], [70.56375122, 20.79347229], [70.56375122, 20.79291725], [70.56346893, 20.79291725], [70.56346893, 20.79263878], [70.56318665, 20.79264069], [70.56318665, 20.79236031], [70.56291962, 20.79236031], [70.56291962, 20.79264069], [70.56208038, 20.79263878], [70.56208038, 20.79291725], [70.56180573, 20.79291725], [70.56180573, 20.79319382], [70.56208038, 20.79319382], [70.56208038, 20.79347229], [70.56153107, 20.79347229], [70.5615387, 20.79375076], [70.56124878, 20.79375076], [70.56124878, 20.79403114], [70.56096649, 20.79403114], [70.56096649, 20.79430962], [70.56069183, 20.7943058], [70.56069183, 20.79458427], [70.56014252, 20.79458046], [70.56014252, 20.79486084], [70.55986023, 20.79486084], [70.55986023, 20.79513931], [70.5595932, 20.79513931], [70.5595932, 20.7954216], [70.55930328, 20.79541588], [70.55930328, 20.79569435], [70.55902863, 20.79569435], [70.55902863, 20.79735947], [70.55930328, 20.79735947], [70.55930328, 20.79823112], [70.55930328, 20.79847336], [70.55902863, 20.79846954], [70.55902863, 20.79875183], [70.55874634, 20.79875183], [70.55874634, 20.7990303], [70.55847931, 20.7990303], [70.55847931, 20.79931068], [70.55791473, 20.79930305], [70.55791473, 20.79958344], [70.55735779, 20.79958344], [70.55735779, 20.79986382], [70.55708313, 20.79986191], [70.55708313, 20.80042076], [70.55680847, 20.80041695], [70.55680847, 20.80097389], [70.55652618, 20.80097008], [70.55652618, 20.80125046], [70.55568695, 20.80125046], [70.55568695, 20.80153084], [70.55541229, 20.80153084], [70.55541229, 20.80181122], [70.55486298, 20.80181122], [70.55486298, 20.80236053], [70.55458069, 20.80236053], [70.55458069, 20.80264091], [70.55403137, 20.80264091], [70.55403137, 20.80291939], [70.55374908, 20.80291748], [70.55374908, 20.80319595], [70.55347443, 20.80319595], [70.55347443, 20.80347252], [70.55208588, 20.80347061], [70.55208588, 20.80375099], [70.55152893, 20.80375099], [70.55152893, 20.80402946], [70.55097198, 20.80402946], [70.55097198, 20.80430984], [70.55041504, 20.80430794], [70.55041504, 20.8045826], [70.54902649, 20.8045826], [70.54902649, 20.80430794], [70.54763794, 20.80430984], [70.54763794, 20.80402946], [70.54736328, 20.80402946], [70.54736328, 20.80359268], [70.54736328, 20.80347252], [70.54708099, 20.80347252], [70.54708099, 20.80319595], [70.54624939, 20.80319595], [70.54624939, 20.80291748], [70.54458618, 20.80291748], [70.54458618, 20.80319595], [70.54402924, 20.80319595], [70.54402924, 20.80291748], [70.54374695, 20.80291748], [70.54374695, 20.80319595], [70.54347229, 20.80319595], [70.54347229, 20.80291748], [70.54319763, 20.80291939], [70.54319763, 20.80236053], [70.54291534, 20.80236053], [70.54291534, 20.80208588], [70.54264069, 20.80208588], [70.54264069, 20.8018055], [70.5423584, 20.80181122], [70.5423584, 20.80153084], [70.54180908, 20.80153084], [70.54180908, 20.80181122], [70.54152679, 20.8018055], [70.54152679, 20.80208588], [70.54096985, 20.80208015], [70.54096985, 20.80236053], [70.54013824, 20.80236053], [70.54013824, 20.80264091], [70.5395813, 20.80264091], [70.5395813, 20.80291939], [70.53930664, 20.80291748], [70.53930664, 20.80319595], [70.53874969, 20.80319595], [70.53874969, 20.80347252], [70.53848267, 20.80347061], [70.53848267, 20.80375099], [70.53791809, 20.80375099], [70.53791809, 20.80402946], [70.53708649, 20.80402946], [70.53708649, 20.80430984], [70.53652954, 20.80430984], [70.53652954, 20.80402946], [70.53624725, 20.80402946], [70.53624725, 20.80430984], [70.5359726, 20.80430794], [70.5359726, 20.8045826], [70.53569794, 20.80458069], [70.53569794, 20.80513954], [70.53541565, 20.80513954], [70.53541565, 20.80597305], [70.53514099, 20.80597115], [70.53514099, 20.80624962], [70.5348587, 20.80624962], [70.5348587, 20.80652809], [70.53430939, 20.80652618], [70.53430176, 20.80680466], [70.5340271, 20.80680084], [70.5340271, 20.80763817], [70.53375244, 20.80763817], [70.53375244, 20.80791664], [70.5331955, 20.80791664], [70.5331955, 20.80847168], [70.53291321, 20.80846977], [70.53291321, 20.80874825], [70.53263855, 20.80874825], [70.53263855, 20.80903053], [70.53235626, 20.80903053], [70.53235626, 20.80931091], [70.53069305, 20.80930519], [70.53069305, 20.80958366], [70.52958679, 20.80957985], [70.52958679, 20.80985832], [70.52929688, 20.80985832], [70.52929688, 20.81014252], [70.5284729, 20.81014252], [70.5284729, 20.8104229], [70.5276413, 20.81041718], [70.5276413, 20.81069374], [70.52375031, 20.81069374], [70.52375031, 20.81097031], [70.52348328, 20.81097031], [70.52348328, 20.81153107], [70.52319336, 20.81152725], [70.52319336, 20.8120842], [70.52263641, 20.81208038], [70.52263641, 20.81236267], [70.52124786, 20.81236267], [70.52124786, 20.81264114], [70.52069092, 20.81264114], [70.52069092, 20.81291962], [70.5201416, 20.8129158], [70.5201416, 20.81319427], [70.51985931, 20.81319427], [70.51985931, 20.81347466], [70.51957703, 20.81347275], [70.51957703, 20.81375122], [70.51902771, 20.81375122], [70.51902771, 20.81404114], [70.51875305, 20.81402779], [70.51875305, 20.8148613], [70.51819611, 20.81485939], [70.51819611, 20.81513977], [70.51790619, 20.81513977], [70.51790619, 20.81542015], [70.51763916, 20.81542015], [70.51763916, 20.81624985], [70.51735687, 20.81624985], [70.51735687, 20.81653023], [70.51708221, 20.81652832], [70.51708221, 20.81680679], [70.51680756, 20.81680679], [70.51680756, 20.81708336], [70.51652527, 20.81708336], [70.51652527, 20.81736183], [70.51624298, 20.81735992], [70.51624298, 20.8176403], [70.51568604, 20.8176403], [70.51568604, 20.81792068], [70.51457977, 20.81792068], [70.51457977, 20.81820107], [70.51291656, 20.81819534], [70.51291656, 20.81847191], [70.51264191, 20.81847], [70.51264191, 20.81875038], [70.51235962, 20.81875038], [70.51235962, 20.81931114], [70.51208496, 20.81930542], [70.51208496, 20.81986046], [70.51152802, 20.81985092], [70.51152802, 20.82014084], [70.51125336, 20.82014084], [70.51125336, 20.82042122], [70.51097107, 20.8204174], [70.51097107, 20.82069397], [70.51069641, 20.82069397], [70.51069641, 20.82097244], [70.51013947, 20.82097054], [70.51013947, 20.82125092], [70.50958252, 20.82125092], [70.50958252, 20.82152748], [70.5090332, 20.82152748], [70.5090332, 20.82180977], [70.50846863, 20.82180595], [70.50846863, 20.82208252], [70.50763702, 20.82208061], [70.50763702, 20.82235909], [70.50680542, 20.82235909], [70.50681305, 20.82264137], [70.50402832, 20.82264137], [70.50402832, 20.82291603], [70.50291443, 20.82291603], [70.50291443, 20.8231945], [70.50208282, 20.8231945], [70.50208282, 20.82347107], [70.50096893, 20.82346916], [70.50096893, 20.82374954], [70.50041962, 20.82374954], [70.50041962, 20.82403183], [70.49986267, 20.82403183], [70.49986267, 20.8243103], [70.49958038, 20.82430649], [70.49958038, 20.82458115], [70.49903107, 20.82458115], [70.49903107, 20.82485962], [70.49846649, 20.82485962], [70.49846649, 20.82514191], [70.49791718, 20.82514191], [70.49791718, 20.82542038], [70.49764252, 20.82542038], [70.49764252, 20.82570076], [70.49736023, 20.82570076], [70.49736023, 20.82598114], [70.49680328, 20.82598114], [70.49680328, 20.82625008], [70.49652863, 20.82625008], [70.49652863, 20.82653046], [70.49597168, 20.82653046], [70.49597168, 20.82681084], [70.49485779, 20.82680321], [70.49485779, 20.82708359], [70.49430847, 20.82708359], [70.49430847, 20.82736206], [70.49402618, 20.82736015], [70.49402618, 20.82764053], [70.49375153, 20.82764053], [70.49375153, 20.82792091], [70.49346924, 20.8279171], [70.49346924, 20.82819557], [70.49291992, 20.82819557], [70.49291992, 20.82847214], [70.49236298, 20.82847023], [70.49236298, 20.82875061], [70.49013519, 20.82875061], [70.49013519, 20.82847214], [70.48986053, 20.82847214], [70.48986053, 20.82819557], [70.48874664, 20.82818985], [70.48874664, 20.82930946], [70.48847198, 20.82930946], [70.48847198, 20.82986069], [70.48819733, 20.82986069], [70.48819733, 20.83041954], [70.48791504, 20.83041763], [70.48791504, 20.8306942], [70.48819733, 20.83069038], [70.48819733, 20.83125114], [70.48791504, 20.83124924], [70.48792267, 20.83236122], [70.48764038, 20.83236122], [70.48764038, 20.83271027], [70.48764038, 20.83319473], [70.48735809, 20.83319473], [70.48735809, 20.83430481], [70.48708344, 20.83430481], [70.48708344, 20.83458328], [70.48652649, 20.83458328], [70.48652649, 20.83486176], [70.48596954, 20.83485985], [70.48596954, 20.83513832], [70.48320007, 20.83513832], [70.48320007, 20.83542061], [70.48236084, 20.83542061], [70.48236084, 20.83569908], [70.48152924, 20.83569527], [70.48152924, 20.83597183], [70.48069763, 20.83596992], [70.48069763, 20.8362484], [70.48042297, 20.8362484], [70.48042297, 20.83653069], [70.48013306, 20.83653069], [70.48013306, 20.83681107], [70.4798584, 20.83680534], [70.4798584, 20.83708382], [70.47957611, 20.83708191], [70.47957611, 20.83736038], [70.47930908, 20.83736038], [70.47930908, 20.83764267], [70.47902679, 20.83764267], [70.47902679, 20.83792114], [70.47875214, 20.83791733], [70.47875214, 20.83819389], [70.47819519, 20.83819389], [70.47819519, 20.83847046], [70.4779129, 20.83847046], [70.4779129, 20.83875275], [70.47763824, 20.83875275], [70.47763824, 20.83903122], [70.47735596, 20.83903122], [70.47735596, 20.83930969], [70.47680664, 20.83930588], [70.47680664, 20.83958054], [70.47651672, 20.83958054], [70.47651672, 20.84041977], [70.47569275, 20.84041405], [70.47569275, 20.84069443], [70.4751358, 20.84069061], [70.4751358, 20.84098053], [70.47402954, 20.84098053], [70.47402954, 20.84069061], [70.4734726, 20.84069443], [70.4734726, 20.84041405], [70.4723587, 20.84041977], [70.4723587, 20.83986282], [70.47207642, 20.83986282], [70.47207642, 20.83975029], [70.47208405, 20.83930588], [70.47180176, 20.83930969], [70.47180176, 20.83903122], [70.4715271, 20.83903122], [70.4715271, 20.83875275], [70.47125244, 20.83875275], [70.47125244, 20.83847046], [70.47097015, 20.83847046], [70.47097015, 20.83819389], [70.46902466, 20.83819389], [70.46902466, 20.83847046], [70.46847534, 20.83847046], [70.46848297, 20.83875275], [70.4679184, 20.83875275], [70.4679184, 20.83903122], [70.46736145, 20.83903122], [70.46736145, 20.83930969], [70.46652985, 20.83930588], [70.46652985, 20.83958054], [70.46624756, 20.83958054], [70.46624756, 20.83986282], [70.4659729, 20.83986282], [70.4659729, 20.84013939], [70.46569824, 20.84013939], [70.46569824, 20.84041977], [70.46541595, 20.84041405], [70.46541595, 20.84069443], [70.46512604, 20.84069061], [70.46512604, 20.84098053], [70.4640274, 20.84098053], [70.4640274, 20.84124947], [70.46290588, 20.84124947], [70.46290588, 20.84152985], [70.46235657, 20.84152985], [70.46235657, 20.84181023], [70.46208191, 20.84180641], [70.46208191, 20.84236145], [70.46180725, 20.84235954], [70.46180725, 20.84263992], [70.46151733, 20.84263992], [70.46151733, 20.84320068], [70.46125031, 20.84319687], [70.46125031, 20.84347153], [70.46097565, 20.84347153], [70.46098328, 20.84375], [70.45986176, 20.84375], [70.45986176, 20.84402847], [70.4595871, 20.84402084], [70.4595871, 20.84431076], [70.45903015, 20.84430695], [70.45903015, 20.84458351], [70.45874786, 20.84458351], [70.45874786, 20.84486198], [70.45847321, 20.84486008], [70.45847321, 20.84514046], [70.45791626, 20.84514046], [70.45791626, 20.84542084], [70.45708466, 20.84541512], [70.45708466, 20.84569359], [70.45625305, 20.84569359], [70.45625305, 20.84597206], [70.45540619, 20.84597015], [70.45540619, 20.84625053], [70.45513916, 20.84625053], [70.45513916, 20.84653091], [70.45458221, 20.84653091], [70.45458221, 20.84680748], [70.45402527, 20.84680557], [70.45402527, 20.84708405], [70.45375061, 20.84708023], [70.45375061, 20.84791756], [70.45347595, 20.84791756], [70.45347595, 20.84819412], [70.45319366, 20.84819412], [70.45319366, 20.8484726], [70.45236206, 20.84847069], [70.45236206, 20.84874916], [70.45181274, 20.84874916], [70.45181274, 20.84903145], [70.45041656, 20.84903145], [70.45041656, 20.84874916], [70.45014954, 20.84874916], [70.45014954, 20.84847069], [70.44985962, 20.8484726], [70.44985962, 20.84819412], [70.44958496, 20.84819412], [70.44958496, 20.84791756], [70.44930267, 20.84791756], [70.44930267, 20.84763908], [70.44847107, 20.84763908], [70.44847107, 20.84791756], [70.44736481, 20.84791756], [70.44736481, 20.84819412], [70.44709015, 20.84819031], [70.44709015, 20.84874916], [70.44735718, 20.84874916], [70.44735718, 20.84903145], [70.44763947, 20.84903145], [70.44763947, 20.84985924], [70.44735718, 20.84985924], [70.44735718, 20.85015106], [70.44709015, 20.85015106], [70.44709015, 20.85042191], [70.44652557, 20.85041618], [70.44652557, 20.85069466], [70.44596863, 20.85069466], [70.44596863, 20.85097122], [70.44568634, 20.85096931], [70.44568634, 20.8512516], [70.44541931, 20.8512516], [70.44541931, 20.85153008], [70.44513702, 20.85152817], [70.44513702, 20.85180473], [70.44486237, 20.85180473], [70.44486237, 20.8520813], [70.44458008, 20.8520813], [70.44458008, 20.85236359], [70.44403076, 20.85235977], [70.44403076, 20.85264015], [70.44374847, 20.85264015], [70.44374847, 20.85292053], [70.44346619, 20.85292053], [70.44346619, 20.85321045], [70.44319153, 20.85319519], [70.44319153, 20.85347366], [70.44291687, 20.85346985], [70.44291687, 20.85403061], [70.44264221, 20.85403061], [70.44264221, 20.85431099], [70.4420929, 20.85431099], [70.4420929, 20.85403061], [70.44180298, 20.85403061], [70.44180298, 20.85375023], [70.44152832, 20.85375023], [70.44152832, 20.85346985], [70.44069672, 20.85347366], [70.44069672, 20.85291672], [70.4404068, 20.85292053], [70.4404068, 20.85264015], [70.43902588, 20.85264015], [70.43902588, 20.85292053], [70.43875122, 20.85292053], [70.43875122, 20.85321045], [70.43846893, 20.85319519], [70.43846893, 20.85347366], [70.43818665, 20.85346985], [70.43818665, 20.85375023], [70.43763733, 20.85375023], [70.43763733, 20.85403061], [70.43736267, 20.85403061], [70.43736267, 20.85431099], [70.43708038, 20.85430527], [70.43708038, 20.85458374], [70.43653107, 20.85457993], [70.43653107, 20.85486031], [70.43624878, 20.85486031], [70.43624878, 20.85514069], [70.43596649, 20.85514069], [70.43596649, 20.85542107], [70.43569183, 20.85541725], [70.43569183, 20.85569572], [70.43514252, 20.85569572], [70.43514252, 20.85597229], [70.43486023, 20.85596085], [70.43486023, 20.85625076], [70.43430328, 20.85625076], [70.43430328, 20.85653114], [70.43374634, 20.85653114], [70.43374634, 20.85680962], [70.43347168, 20.8568058], [70.43347168, 20.85708427], [70.43319702, 20.85708046], [70.43319702, 20.85736084], [70.4329071, 20.85736084], [70.4329071, 20.85764122], [70.43235779, 20.85764122], [70.43235779, 20.85791969], [70.43208313, 20.85791779], [70.43208313, 20.85819435], [70.43180847, 20.85819435], [70.43180847, 20.85902786], [70.43152618, 20.85902786], [70.43152618, 20.8595829], [70.43125153, 20.8595829], [70.43125153, 20.85986137], [70.43096924, 20.85985947], [70.43096924, 20.86013985], [70.43068695, 20.86013985], [70.43068695, 20.86041832], [70.43041992, 20.86041641], [70.43041992, 20.86069489], [70.43013763, 20.86069107], [70.43013763, 20.86124992], [70.42986298, 20.86124992], [70.42986298, 20.8615284], [70.42930603, 20.8615284], [70.42930603, 20.86181068], [70.42874908, 20.86181068], [70.42874908, 20.86208916], [70.42819214, 20.86208344], [70.42819214, 20.86236191], [70.42791748, 20.86235809], [70.42791748, 20.86263847], [70.42736053, 20.86263847], [70.42736053, 20.86235809], [70.42679596, 20.86235809], [70.42679596, 20.86263847], [70.42624664, 20.86263847], [70.42624664, 20.86292076], [70.42541504, 20.86291695], [70.42542267, 20.8631897], [70.42485809, 20.86319542], [70.42485809, 20.86347008], [70.42457581, 20.86346817], [70.42457581, 20.86403275], [70.42430878, 20.86402702], [70.42430878, 20.86458206], [70.42402649, 20.86458015], [70.42402649, 20.86486244], [70.42375183, 20.86486244], [70.42375183, 20.86515045], [70.42346954, 20.86515045], [70.42346954, 20.86541939], [70.42319489, 20.86541748], [70.42319489, 20.86569214], [70.42292023, 20.86569214], [70.42292023, 20.86597061], [70.42263794, 20.86597061], [70.42263794, 20.8662529], [70.42236328, 20.8662529], [70.42236328, 20.86652946], [70.42208099, 20.86652946], [70.42208099, 20.86680984], [70.42180634, 20.86680984], [70.42180634, 20.86736107], [70.42151642, 20.86736107], [70.42151642, 20.86763954], [70.42124939, 20.86763954], [70.42124939, 20.86791992], [70.42097473, 20.86791611], [70.42097473, 20.86819458], [70.42069244, 20.86819458], [70.42069244, 20.86847305], [70.4201355, 20.86847305], [70.42014313, 20.86874962], [70.41986084, 20.86874962], [70.41986084, 20.86903], [70.41958618, 20.86902809], [70.41958618, 20.86930466], [70.41930389, 20.86930466], [70.41930389, 20.8698616], [70.41902924, 20.8698597], [70.41902924, 20.87042046], [70.41874695, 20.87042046], [70.41874695, 20.87070084], [70.41847229, 20.87069511], [70.41847229, 20.87097168], [70.41819763, 20.87096024], [70.41819763, 20.87125015], [70.41792297, 20.87125015], [70.41792297, 20.87153053], [70.41764069, 20.87153053], [70.41764069, 20.87181091], [70.41708374, 20.87180519], [70.41708374, 20.87208366], [70.41680908, 20.87207985], [70.41680908, 20.87236023], [70.41652679, 20.87236023], [70.41652679, 20.87264061], [70.41625214, 20.87264061], [70.41625214, 20.87292099], [70.41596985, 20.87291718], [70.41596985, 20.87319374], [70.41569519, 20.87319374], [70.41569519, 20.87347221], [70.4154129, 20.87347031], [70.4154129, 20.87375069], [70.41513824, 20.87375069], [70.41513824, 20.87402916], [70.4145813, 20.87402916], [70.4145813, 20.87431908], [70.41430664, 20.87430573], [70.41430664, 20.8745842], [70.41401672, 20.87458038], [70.41402435, 20.87486076], [70.41348267, 20.87486076], [70.41348267, 20.87513924], [70.41319275, 20.87513924], [70.41319275, 20.87542152], [70.41291809, 20.8754158], [70.41291809, 20.87597275], [70.4126358, 20.87597084], [70.4126358, 20.87624931], [70.41236115, 20.87624931], [70.41236115, 20.8765316], [70.41208649, 20.87652779], [70.41208649, 20.87735939], [70.41152954, 20.87735939], [70.41152954, 20.87764168], [70.41124725, 20.87764168], [70.41124725, 20.8801384], [70.41152954, 20.88013268], [70.41152954, 20.88042068], [70.41179657, 20.88042068], [70.41179657, 20.88070107], [70.41208649, 20.88069534], [70.41208649, 20.88097382], [70.41291809, 20.88097], [70.41291809, 20.88125038], [70.41374969, 20.88125038], [70.41374969, 20.88181114], [70.41402435, 20.88180542], [70.41402435, 20.8820858], [70.41430664, 20.88208008], [70.41430664, 20.88236046], [70.4154129, 20.88236046], [70.4154129, 20.88264084], [70.41707611, 20.88264084], [70.41707611, 20.88236046], [70.41764069, 20.88236046], [70.41764069, 20.88208008], [70.41791534, 20.8820858], [70.41791534, 20.88180542], [70.41819763, 20.88181114], [70.41819763, 20.88153076], [70.41958618, 20.88152695], [70.41958618, 20.8820858], [70.41874695, 20.88208008], [70.41874695, 20.88236046], [70.41819763, 20.88236046], [70.41819763, 20.88264084], [70.41791534, 20.88263893], [70.41791534, 20.88363838], [70.41792297, 20.88486099], [70.41764069, 20.88486099], [70.41764069, 20.88597298], [70.4173584, 20.88597107], [70.4173584, 20.88652992], [70.41708374, 20.88652611], [70.41708374, 20.88708305], [70.41680908, 20.88708305], [70.41680908, 20.88680649], [70.41625214, 20.8868103], [70.41625214, 20.88625908], [70.41652679, 20.88625908], [70.41652679, 20.88597107], [70.41680908, 20.88597298], [70.41680908, 20.88486099], [70.41707611, 20.88486099], [70.41708374, 20.88412094], [70.41708374, 20.88347244], [70.41680908, 20.88347244], [70.41680908, 20.88319588], [70.41402435, 20.88319588], [70.41402435, 20.88347244], [70.41374969, 20.88347054], [70.41374969, 20.88375092], [70.41319275, 20.88375092], [70.41319275, 20.88402939], [70.4126358, 20.88402939], [70.4126358, 20.88375092], [70.41124725, 20.88375092], [70.41124725, 20.88347054], [70.41041565, 20.88347244], [70.41041565, 20.88319588], [70.4098587, 20.88319588], [70.4098587, 20.8829174], [70.40957642, 20.88292122], [70.40957642, 20.88236046], [70.40735626, 20.88236046], [70.40735626, 20.88264084], [70.40651703, 20.88264084], [70.40651703, 20.88292122], [70.40625, 20.8829174], [70.40625, 20.88319588], [70.40597534, 20.88319588], [70.40597534, 20.88347244], [70.40569305, 20.88347054], [70.40569305, 20.88375092], [70.4054184, 20.88375092], [70.4054184, 20.88402939], [70.40513611, 20.88402939], [70.40513611, 20.88430977], [70.40486145, 20.88430786], [70.40486145, 20.88458252], [70.40458679, 20.88458061], [70.40458679, 20.88486099], [70.40402985, 20.88486099], [70.40402985, 20.88513947], [70.4034729, 20.88513947], [70.4034729, 20.88541985], [70.40291595, 20.88541794], [70.40291595, 20.8856945], [70.40235901, 20.88569069], [70.40235901, 20.88625908], [70.40207672, 20.88625908], [70.40207672, 20.88652992], [70.4017868, 20.88652992], [70.4017868, 20.8868103], [70.4015274, 20.88680649], [70.4015274, 20.88708305], [70.40097046, 20.88708305], [70.40097046, 20.88736153], [70.4006958, 20.88735962], [70.4006958, 20.88763809], [70.40040588, 20.88763809], [70.40040588, 20.88792038], [70.39985657, 20.88792038], [70.39985657, 20.88820076], [70.39958191, 20.88819504], [70.39958191, 20.8884716], [70.39930725, 20.8884697], [70.39930725, 20.88874817], [70.39901733, 20.88874817], [70.39901733, 20.88902855], [70.39875031, 20.88902855], [70.39875031, 20.88958359], [70.39847565, 20.88958359], [70.39847565, 20.88986015], [70.39819336, 20.88985825], [70.39819336, 20.89013863], [70.3979187, 20.89013863], [70.3979187, 20.89042282], [70.39763641, 20.8904171], [70.39763641, 20.89069366], [70.39736176, 20.89069176], [70.39736176, 20.89125252], [70.3970871, 20.89125252], [70.3970871, 20.8915329], [70.39679718, 20.8915329], [70.39679718, 20.89180946], [70.39624786, 20.89180565], [70.39624786, 20.89208412], [70.39597321, 20.89208412], [70.39598083, 20.89236259], [70.39569092, 20.89236259], [70.39569092, 20.89264107], [70.3951416, 20.89264107], [70.3951416, 20.89291954], [70.39458466, 20.89291763], [70.39458466, 20.89347458], [70.39430237, 20.89347076], [70.39430237, 20.89375114], [70.39402771, 20.89375114], [70.39402771, 20.89402962], [70.39347076, 20.89402962], [70.39347076, 20.89431], [70.39180756, 20.89430618], [70.39180756, 20.89458466], [70.39152527, 20.89458466], [70.3915329, 20.89486122], [70.38957977, 20.89486122], [70.38957977, 20.89513969], [70.38874817, 20.89513016], [70.38874817, 20.89542007], [70.38819122, 20.89541626], [70.38819122, 20.89569473], [70.38791656, 20.89569473], [70.38791656, 20.89541626], [70.38735962, 20.89541626], [70.38735962, 20.89569473], [70.38707733, 20.89569092], [70.38708496, 20.89624977], [70.3868103, 20.89624977], [70.3868103, 20.89653015], [70.38625336, 20.89652824], [70.38625336, 20.89680672], [70.38597107, 20.89680672], [70.38597107, 20.89736176], [70.38513947, 20.89735985], [70.38513947, 20.89764023], [70.38485718, 20.89764023], [70.38485718, 20.89792061], [70.38375092, 20.89792061], [70.38375092, 20.89820099], [70.38263702, 20.89819527], [70.38263702, 20.89847183], [70.38236237, 20.89846992], [70.38236237, 20.89875031], [70.38208008, 20.89875031], [70.38208008, 20.89903069], [70.38101959, 20.89902687], [70.38069153, 20.89902687], [70.38069153, 20.89929008], [70.38069153, 20.89958382], [70.38041687, 20.89958], [70.38041687, 20.89986038], [70.38014221, 20.89986038], [70.38014221, 20.90014076], [70.37961578, 20.90013885], [70.37930298, 20.90013885], [70.37928772, 20.9004097], [70.37875366, 20.90041733], [70.37875366, 20.90069389], [70.37763977, 20.90069389], [70.37763977, 20.90097237], [70.37652588, 20.90097046], [70.37652588, 20.90125847], [70.37625122, 20.90125847], [70.37625122, 20.90153122], [70.37568665, 20.90153122], [70.37568665, 20.90180969], [70.37458038, 20.90180588], [70.37458038, 20.90208244], [70.37346649, 20.90208054], [70.37346649, 20.90236092], [70.37264252, 20.90236092], [70.37264252, 20.90263939], [70.37097168, 20.90263939], [70.37097168, 20.90236092], [70.37069702, 20.90236092], [70.37069702, 20.90153122], [70.37097168, 20.90153122], [70.37097168, 20.90069008], [70.37069702, 20.90069389], [70.37069702, 20.89986038], [70.37097168, 20.89986038], [70.37097168, 20.89931107], [70.37152863, 20.89931107], [70.37152863, 20.89875031], [70.37210083, 20.89875031], [70.37208557, 20.89847183], [70.37236023, 20.89847183], [70.37236023, 20.89763832], [70.37264252, 20.89764023], [70.37264252, 20.89735985], [70.37291718, 20.89736176], [70.37291718, 20.89708328], [70.37319183, 20.89708328], [70.37319183, 20.89680672], [70.37347412, 20.89680672], [70.37347412, 20.89652824], [70.37403107, 20.89653015], [70.37403107, 20.89624977], [70.37458038, 20.89624977], [70.37458038, 20.89486122], [70.37374878, 20.89486122], [70.37374878, 20.89542007], [70.37347412, 20.89541626], [70.37347412, 20.89569473], [70.37236023, 20.89569092], [70.37236023, 20.89624977], [70.37210083, 20.89624977], [70.37210083, 20.89653015], [70.37180328, 20.89652824], [70.37180328, 20.89680672], [70.37152863, 20.89680672], [70.37152863, 20.89708328], [70.37097168, 20.89708328], [70.37097168, 20.89736176], [70.37069702, 20.89735985], [70.37069702, 20.89820099], [70.37041473, 20.89819527], [70.37041473, 20.89847183], [70.37014008, 20.89846992], [70.37014008, 20.89875031], [70.36958313, 20.89875031], [70.36958313, 20.89903069], [70.36930847, 20.89903069], [70.36930847, 20.89931107], [70.36902618, 20.89930534], [70.36902618, 20.89958382], [70.36818695, 20.89958], [70.36818695, 20.89986038], [70.36708069, 20.89986038], [70.36708069, 20.90014076], [70.36653137, 20.90014076], [70.36653137, 20.90042114], [70.36541748, 20.90041733], [70.36541748, 20.90069389], [70.36486053, 20.90069389], [70.36486053, 20.90097237], [70.36458588, 20.90097046], [70.36458588, 20.90125847], [70.36429596, 20.90125847], [70.36429596, 20.90153122], [70.36402893, 20.90153122], [70.36402893, 20.90180969], [70.36374664, 20.90180588], [70.36374664, 20.90208244], [70.36347198, 20.90208054], [70.36347198, 20.90236092], [70.36291504, 20.90236092], [70.3629303, 20.90263939], [70.36264038, 20.90263939], [70.36264038, 20.90292168], [70.36235809, 20.90291595], [70.36235809, 20.90319443], [70.36152649, 20.90319443], [70.36152649, 20.9034729], [70.36096954, 20.90346909], [70.36096954, 20.90374947], [70.36068726, 20.90374947], [70.36068726, 20.90403175], [70.35930634, 20.90403175], [70.35930634, 20.90431976], [70.35902405, 20.90430641], [70.35902405, 20.90458107], [70.35874939, 20.90458107], [70.35874939, 20.90485954], [70.3584671, 20.90485954], [70.3584671, 20.90514183], [70.35819244, 20.90514183], [70.35819244, 20.9054203], [70.35736084, 20.9054203], [70.35736084, 20.90570068], [70.35708618, 20.90569496], [70.35708618, 20.90597343], [70.35652924, 20.90596962], [70.35652924, 20.90653038], [70.35624695, 20.90653038], [70.35624695, 20.90681076], [70.35597229, 20.90680313], [70.35597229, 20.9070816], [70.35542297, 20.90707016], [70.35542297, 20.90764046], [70.3548584, 20.90764046], [70.3548584, 20.90792084], [70.35430908, 20.90791702], [70.35430908, 20.9081955], [70.35402679, 20.9081955], [70.35402679, 20.90847206], [70.35346985, 20.90847015], [70.35346985, 20.90875053], [70.3529129, 20.90875053], [70.3529129, 20.90903091], [70.35263824, 20.90903091], [70.35263824, 20.90930939], [70.3520813, 20.90930557], [70.3520813, 20.90958595], [70.35180664, 20.90958023], [70.35180664, 20.90986061], [70.35151672, 20.90986061], [70.35151672, 20.91014099], [70.35124969, 20.91014099], [70.35124969, 20.91041946], [70.35097504, 20.91041756], [70.35097504, 20.9109726], [70.35067749, 20.91097069], [70.35067749, 20.91152954], [70.35041809, 20.91152763], [70.35041809, 20.91208267], [70.34986115, 20.91208076], [70.34986115, 20.91236115], [70.34958649, 20.91236115], [70.34958649, 20.91263962], [70.34929657, 20.91263962], [70.34929657, 20.91320038], [70.34902954, 20.91319466], [70.34902954, 20.91347313], [70.34874725, 20.91347122], [70.34874725, 20.91402817], [70.3484726, 20.91402817], [70.3484726, 20.91430473], [70.34791565, 20.91430473], [70.34791565, 20.91458321], [70.34764099, 20.91458321], [70.34764099, 20.91486168], [70.3473587, 20.91485977], [70.3473587, 20.91513824], [70.34708405, 20.91513824], [70.34708405, 20.91624832], [70.3473587, 20.91624069], [70.3473587, 20.9168129], [70.34764099, 20.9168129], [70.34764099, 20.91736031], [70.34793091, 20.91736031], [70.34793091, 20.91764259], [70.34819794, 20.91764259], [70.34819794, 20.91792107], [70.3484726, 20.91791725], [70.3484726, 20.91819382], [70.34874725, 20.91819382], [70.34874725, 20.91847038], [70.34958649, 20.91847038], [70.34958649, 20.91875267], [70.34986115, 20.91875267], [70.34986115, 20.91903114], [70.3501358, 20.91902733], [70.3501358, 20.9193058], [70.35041809, 20.9193058], [70.35041809, 20.91958046], [70.3509903, 20.91958046], [70.3509903, 20.92014122], [70.35124969, 20.92013931], [70.35124969, 20.92069244], [70.35069275, 20.92069244], [70.35069275, 20.92041588], [70.35041809, 20.92041969], [70.35041809, 20.92014122], [70.3501358, 20.92014122], [70.3501358, 20.91986275], [70.34986115, 20.91986275], [70.34986115, 20.91958046], [70.3493042, 20.91958427], [70.3493042, 20.91941071], [70.3493042, 20.9193058], [70.34902954, 20.9193058], [70.34902954, 20.91902733], [70.34764099, 20.91902733], [70.34764099, 20.9193058], [70.34707642, 20.91930008], [70.34707642, 20.91986275], [70.3473587, 20.91986275], [70.3473587, 20.92041969], [70.34764099, 20.92041588], [70.34764099, 20.92054939], [70.34764099, 20.92152977], [70.34707642, 20.92152977], [70.34708405, 20.92093086], [70.34708405, 20.92069244], [70.34680176, 20.92069244], [70.34680176, 20.92013931], [70.3465271, 20.92014122], [70.3465271, 20.91736031], [70.34625244, 20.91736031], [70.34625244, 20.91596985], [70.34597015, 20.91597176], [70.34597015, 20.91569519], [70.34513855, 20.91569519], [70.34513855, 20.91597176], [70.34402466, 20.91597176], [70.34402466, 20.91624832], [70.34319305, 20.91624069], [70.34319305, 20.91653061], [70.3429184, 20.91653061], [70.3429184, 20.9168129], [70.34208679, 20.91680527], [70.34208679, 20.91708374], [70.34179688, 20.91708183], [70.34179688, 20.91736031], [70.34124756, 20.91736031], [70.34124756, 20.91764259], [70.34041595, 20.91764259], [70.34041595, 20.91792107], [70.33985901, 20.91791725], [70.33985901, 20.91819382], [70.33958435, 20.91819382], [70.33958435, 20.91847038], [70.33930206, 20.91847038], [70.33930206, 20.91875267], [70.3390274, 20.91875267], [70.3390274, 20.91903114], [70.33847046, 20.91902733], [70.33847046, 20.9193058], [70.33791351, 20.9193058], [70.33791351, 20.91958427], [70.33735657, 20.91958046], [70.33735657, 20.91986275], [70.33708191, 20.91986275], [70.33708191, 20.92014122], [70.33651733, 20.92014122], [70.33651733, 20.92041969], [70.33597565, 20.92041588], [70.33597565, 20.92069244], [70.33569336, 20.92069244], [70.33569336, 20.92097473], [70.3354187, 20.92097282], [70.3354187, 20.92124939], [70.33486176, 20.92124939], [70.33486176, 20.92152977], [70.33429718, 20.92152977], [70.33429718, 20.92181015], [70.33374786, 20.92180634], [70.33374786, 20.92208481], [70.33291626, 20.92208481], [70.33291626, 20.92236137], [70.3326416, 20.92235947], [70.3326416, 20.92263985], [70.33207703, 20.92263985], [70.33207703, 20.92292023], [70.33180237, 20.92291641], [70.33180237, 20.92319679], [70.33097076, 20.92319679], [70.33097076, 20.92347145], [70.33013916, 20.92346954], [70.33013916, 20.92374992], [70.32985687, 20.92374992], [70.32985687, 20.9240303], [70.32956696, 20.9240303], [70.32956696, 20.92431068], [70.32902527, 20.92430687], [70.32902527, 20.92458344], [70.32819366, 20.92458344], [70.32819366, 20.92486191], [70.32736206, 20.92486], [70.32736206, 20.92514038], [70.32596588, 20.92514038], [70.32596588, 20.9254303], [70.32569122, 20.92541695], [70.32569122, 20.9256897], [70.32541656, 20.92569542], [70.32541656, 20.92597198], [70.32514191, 20.92597008], [70.32514191, 20.92625046], [70.32457733, 20.92625046], [70.32457733, 20.92681122], [70.32347107, 20.92681122], [70.32347107, 20.92653084], [70.32263947, 20.92653084], [70.32263947, 20.92681122], [70.32235718, 20.92681122], [70.32236481, 20.92736053], [70.3207016, 20.92736053], [70.3207016, 20.92764091], [70.32041931, 20.92764091], [70.32041931, 20.92791748], [70.32013702, 20.92791748], [70.32013702, 20.92819405], [70.31986237, 20.92818069], [70.31986237, 20.92874908], [70.31958008, 20.92874908], [70.31958008, 20.92903137], [70.31930542, 20.92902756], [70.31930542, 20.9295826], [70.31903076, 20.92958069], [70.31903076, 20.93014145], [70.31874847, 20.93014145], [70.31874847, 20.93042183], [70.31847382, 20.93041611], [70.31847382, 20.93069458], [70.31819153, 20.93069458], [70.31819153, 20.93097115], [70.31791687, 20.93097115], [70.31791687, 20.93124962], [70.31764221, 20.93124962], [70.31764221, 20.93180466], [70.31735992, 20.93180466], [70.31735992, 20.93236351], [70.3170929, 20.9323597], [70.3170929, 20.93264008], [70.31680298, 20.93264008], [70.31680298, 20.93292046], [70.31652832, 20.93292046], [70.31652832, 20.93320084], [70.31625366, 20.93319511], [70.31625366, 20.93347359], [70.31597137, 20.93346977], [70.31597137, 20.93375015], [70.31569672, 20.93375015], [70.31569672, 20.93403053], [70.31541443, 20.93402863], [70.31541443, 20.93430328], [70.31513977, 20.93430328], [70.31513977, 20.93458366], [70.31318665, 20.93457985], [70.31318665, 20.93486023], [70.31208038, 20.93486023], [70.31208038, 20.93514061], [70.31153107, 20.93514061], [70.31153107, 20.93542099], [70.31124878, 20.93541718], [70.31124878, 20.93569565], [70.31096649, 20.93568993], [70.31096649, 20.93625069], [70.31069183, 20.93625069], [70.31069183, 20.9370842], [70.31041718, 20.93708038], [70.31041718, 20.9373703], [70.31014252, 20.9373703], [70.31014252, 20.93764114], [70.30958557, 20.93763924], [70.30958557, 20.93847275], [70.30930328, 20.93847084], [70.30930328, 20.93902969], [70.3087616, 20.93902969], [70.3087616, 20.93930817], [70.30819702, 20.93930626], [70.30819702, 20.93958282], [70.30791473, 20.93958282], [70.30791473, 20.9398613], [70.30735779, 20.93985939], [70.30735779, 20.94013977], [70.30680847, 20.94013977], [70.30680847, 20.94043159], [70.30652618, 20.94041634], [70.30652618, 20.94069481], [70.30569458, 20.94069481], [70.30569458, 20.94097137], [70.30541992, 20.94096947], [70.30541992, 20.94124985], [70.30513763, 20.94124985], [70.30513763, 20.94152832], [70.30403137, 20.94152832], [70.30403137, 20.94180489], [70.30374908, 20.94180489], [70.30374908, 20.94208336], [70.30319214, 20.94208336], [70.30319214, 20.94236183], [70.30291748, 20.94235992], [70.30291748, 20.9426384], [70.30262756, 20.9426384], [70.30262756, 20.94292068], [70.30208588, 20.94292068], [70.30208588, 20.94319916], [70.30152893, 20.94319534], [70.30152893, 20.94347191], [70.30097198, 20.94346809], [70.30097198, 20.94375229], [70.30069733, 20.94375229], [70.30069733, 20.94431114], [70.30014038, 20.94430542], [70.30014038, 20.94458389], [70.29985809, 20.94458008], [70.29985809, 20.94486046], [70.29959106, 20.94486046], [70.29959106, 20.94514275], [70.29902649, 20.94514275], [70.29902649, 20.94542122], [70.29846954, 20.9454174], [70.29846954, 20.94569206], [70.29763794, 20.94569206], [70.29763794, 20.94597054], [70.29736328, 20.94597054], [70.29736328, 20.94625282], [70.29682159, 20.94623947], [70.29682159, 20.94652939], [70.2959671, 20.94652939], [70.2959671, 20.94680977], [70.29541779, 20.94680595], [70.29541779, 20.94708443], [70.29486084, 20.94708061], [70.29486084, 20.9473629], [70.29458618, 20.9473629], [70.29458618, 20.94763947], [70.29374695, 20.94763947], [70.29374695, 20.94791985], [70.29347229, 20.94791412], [70.29347229, 20.94847488], [70.29319763, 20.94847107], [70.29319763, 20.94874954], [70.29264069, 20.94874954], [70.29264069, 20.94902992], [70.29207611, 20.94902992], [70.29207611, 20.9493103], [70.29180908, 20.94930649], [70.29180908, 20.94986153], [70.29152679, 20.94985962], [70.29152679, 20.95014], [70.29096985, 20.95014], [70.29096985, 20.95042038], [70.29068756, 20.95042038], [70.29068756, 20.95070076], [70.2904129, 20.95069695], [70.2904129, 20.9509716], [70.29013824, 20.9509697], [70.29013824, 20.95125008], [70.28985596, 20.95125008], [70.28985596, 20.95153046], [70.28930664, 20.95153046], [70.28930664, 20.95181084], [70.28874969, 20.95180511], [70.28874969, 20.95208359], [70.28848267, 20.95207977], [70.28848267, 20.95236969], [70.28819275, 20.95236969], [70.28819275, 20.95264053], [70.28765106, 20.95264053], [70.28765106, 20.95292091], [70.28736115, 20.9529171], [70.28736115, 20.95319366], [70.2868042, 20.95319366], [70.2868042, 20.95347214], [70.28624725, 20.95347023], [70.28624725, 20.95375061], [70.28569794, 20.95375061], [70.28569794, 20.95402908], [70.28514099, 20.95402908], [70.28514099, 20.95430756], [70.2848587, 20.95430565], [70.2848587, 20.95458412], [70.28430939, 20.95458031], [70.28430176, 20.95486069], [70.28375244, 20.95486069], [70.28375244, 20.95513916], [70.28347015, 20.95513725], [70.28347015, 20.95541573], [70.28236389, 20.95541763], [70.28236389, 20.9556942], [70.2820816, 20.9556942], [70.2820816, 20.95597267], [70.28180695, 20.95597076], [70.28180695, 20.95624924], [70.28151703, 20.95624924], [70.28151703, 20.95653152], [70.28125, 20.95653152], [70.28125, 20.9568119], [70.28069305, 20.95680618], [70.28069305, 20.95708275], [70.2804184, 20.95708084], [70.2804184, 20.95735931], [70.27986145, 20.95735931], [70.27986145, 20.9576416], [70.27958679, 20.9576416], [70.27958679, 20.95792007], [70.2793045, 20.95791626], [70.2793045, 20.95819473], [70.27902985, 20.95819473], [70.27902985, 20.95846939], [70.27874756, 20.95846939], [70.27874756, 20.95930481], [70.2784729, 20.95930481], [70.2784729, 20.95958138], [70.27819824, 20.95958138], [70.27819824, 20.95986366], [70.2776413, 20.95985985], [70.2776413, 20.96014023], [70.27735901, 20.96014023], [70.27735901, 20.96042061], [70.27680206, 20.96042061], [70.27680206, 20.96070099], [70.2765274, 20.96070099], [70.2765274, 20.96125031], [70.27625275, 20.96125031], [70.27625275, 20.96181107], [70.27597046, 20.96180534], [70.27597046, 20.96208572], [70.27485657, 20.96208], [70.27485657, 20.96236038], [70.27458191, 20.96236038], [70.27458191, 20.96264076], [70.27401733, 20.96264076], [70.27401733, 20.96292114], [70.27319336, 20.96291733], [70.27319336, 20.9631958], [70.27263641, 20.9631958], [70.27263641, 20.96347237], [70.27236176, 20.96347046], [70.27236176, 20.96375084], [70.2720871, 20.96375084], [70.2720871, 20.96403122], [70.27179718, 20.96403122], [70.27179718, 20.96430969], [70.27124786, 20.96430588], [70.27124786, 20.96458244], [70.27097321, 20.96458054], [70.27097321, 20.96486092], [70.27069092, 20.96486092], [70.27069092, 20.96513939], [70.26985931, 20.96513939], [70.26985931, 20.96541977], [70.26930237, 20.96541786], [70.26930237, 20.96569443], [70.26902771, 20.96569443], [70.26902771, 20.9659729], [70.26875305, 20.96597099], [70.26875305, 20.96624947], [70.26847076, 20.96624947], [70.26847076, 20.96652985], [70.26790619, 20.96652985], [70.26790619, 20.96681023], [70.26763916, 20.96680641], [70.26763916, 20.96708298], [70.2673645, 20.96708298], [70.2673645, 20.96736145], [70.26680756, 20.96735001], [70.26680756, 20.96763992], [70.26651764, 20.96763992], [70.26651764, 20.9679184], [70.26625061, 20.9679184], [70.26625061, 20.96820068], [70.26597595, 20.96819496], [70.26597595, 20.96847153], [70.26513672, 20.96846962], [70.26513672, 20.96874809], [70.26457977, 20.96874809], [70.26457977, 20.96902847], [70.26431274, 20.96902847], [70.26431274, 20.96931076], [70.26374817, 20.96930504], [70.26374817, 20.96958351], [70.26347351, 20.96958351], [70.26347351, 20.96986008], [70.26319122, 20.96985817], [70.26319122, 20.97013855], [70.26291656, 20.97013855], [70.26291656, 20.97041702], [70.26264191, 20.97041702], [70.26264191, 20.97069359], [70.26235962, 20.97069359], [70.26235962, 20.97097015], [70.26180267, 20.97097015], [70.26180267, 20.97125244], [70.26125336, 20.97125244], [70.26125336, 20.97153282], [70.26097107, 20.97153282], [70.26097107, 20.97180939], [70.26069641, 20.97180557], [70.26069641, 20.97208214], [70.26013947, 20.97208023], [70.26013947, 20.97236061], [70.25985718, 20.97236061], [70.25985718, 20.9726429], [70.25818634, 20.9726429], [70.25818634, 20.97291946], [70.25791931, 20.97291946], [70.25791931, 20.97348022], [70.25763702, 20.97348022], [70.25763702, 20.97375107], [70.25734711, 20.97375107], [70.25734711, 20.97430992], [70.25708008, 20.97430611], [70.25708008, 20.97458458], [70.25680542, 20.97458458], [70.25681305, 20.97486115], [70.25653076, 20.97486115], [70.25653076, 20.97513962], [70.25624847, 20.97513962], [70.25624847, 20.97542], [70.25597382, 20.97541618], [70.25596619, 20.97565079], [70.25541687, 20.97569466], [70.25541687, 20.97597313], [70.25514221, 20.97597122], [70.25514221, 20.97624969], [70.25485992, 20.97624969], [70.25485992, 20.97653961], [70.25458527, 20.97652817], [70.25458527, 20.97680664], [70.25430298, 20.97680664], [70.25430298, 20.97708321], [70.25402832, 20.97708321], [70.25402832, 20.97736168], [70.25374603, 20.97735977], [70.25374603, 20.97764015], [70.25347137, 20.97764015], [70.25347137, 20.97820091], [70.25263977, 20.97819519], [70.25263977, 20.97847176], [70.25235748, 20.97846985], [70.25235748, 20.97875023], [70.25208282, 20.97875023], [70.25208282, 20.97903061], [70.25152588, 20.9790287], [70.25152588, 20.98069382], [70.25125122, 20.98069382], [70.25125122, 20.98097229], [70.25096893, 20.98097038], [70.25096893, 20.98125076], [70.25068665, 20.98125076], [70.25068665, 20.98152924], [70.25013733, 20.98152924], [70.25013733, 20.98180962], [70.24986267, 20.9818058], [70.24986267, 20.98236084], [70.24958038, 20.9823494], [70.24958038, 20.9829216], [70.24930573, 20.98291588], [70.24930573, 20.98319435], [70.24903107, 20.98319435], [70.24903107, 20.98347282], [70.24874878, 20.98347092], [70.24874878, 20.98403168], [70.24848175, 20.98403168], [70.24848175, 20.98431015], [70.24819183, 20.98430634], [70.24819183, 20.9845829], [70.24791718, 20.9845829], [70.24791718, 20.98485947], [70.24764252, 20.98485947], [70.24764252, 20.98513794], [70.2470932, 20.98514175], [70.2470932, 20.98542023], [70.24680328, 20.98541641], [70.24680328, 20.98569489], [70.24624634, 20.98569489], [70.24624634, 20.98597145], [70.24597168, 20.98596954], [70.24597168, 20.98625183], [70.2454071, 20.98625183], [70.2454071, 20.9865303], [70.24514008, 20.9865303], [70.24514008, 20.98681068], [70.24485779, 20.98680305], [70.24485779, 20.98708153], [70.24458313, 20.98708153], [70.24458313, 20.98736382], [70.24430847, 20.98736], [70.24430847, 20.98764038], [70.24402618, 20.98764038], [70.24402618, 20.98792076], [70.24375153, 20.98791695], [70.24375153, 20.9881897], [70.24346924, 20.98820114], [70.24346924, 20.98847961], [70.24318695, 20.98847961], [70.24318695, 20.98875046], [70.24291992, 20.98875046], [70.24291992, 20.98931122], [70.24263763, 20.9893055], [70.24263763, 20.98958588], [70.24234772, 20.98958015], [70.24234772, 20.98986053], [70.24208069, 20.98986053], [70.24208069, 20.99041939], [70.24097443, 20.99041748], [70.24097443, 20.99097252], [70.24069214, 20.99097061], [70.24069214, 20.99125099], [70.24041748, 20.99125099], [70.24041748, 20.99180984], [70.24013519, 20.99180794], [70.24014282, 20.99236107], [70.23986053, 20.99236107], [70.23986053, 20.99263954], [70.23958588, 20.99263954], [70.23958588, 20.99319458], [70.23986053, 20.99319458], [70.23986053, 20.99347305], [70.24013519, 20.99347305], [70.24013519, 20.99374962], [70.24041748, 20.99374962], [70.24041748, 20.99402809], [70.24124908, 20.99402618], [70.24124908, 20.99430466], [70.24153137, 20.99430466], [70.24153137, 20.9948616], [70.24208069, 20.9948597], [70.24208069, 20.99513817], [70.24234772, 20.99513817], [70.24234772, 20.99542046], [70.24263763, 20.99542046], [70.24263763, 20.99570084], [70.24291992, 20.99569511], [70.24291992, 20.99597168], [70.24318695, 20.99596977], [70.24318695, 20.99624825], [70.24346924, 20.99624825], [70.24346924, 20.99652863], [70.24375153, 20.99652863], [70.24375153, 20.99681091], [70.24402618, 20.99680519], [70.24402618, 20.99708366], [70.24430847, 20.99707985], [70.24430847, 20.99736023], [70.24458313, 20.99736023], [70.24458313, 20.99765015], [70.24514008, 20.99765015], [70.24514008, 20.9979229], [70.24541473, 20.99791718], [70.24541473, 20.99819374], [70.24597168, 20.99819374], [70.24597168, 20.99847031], [70.24624634, 20.99847031], [70.24624634, 20.99875259], [70.24652863, 20.99875259], [70.24652863, 20.99930954], [70.24680328, 20.99930763], [70.24708557, 20.99930573], [70.24708557, 20.99958229], [70.24764252, 20.99958038], [70.24764252, 20.99986267], [70.24764252, 21.00014114], [70.24764252, 21.00041962], [70.24708557, 21.0004158], [70.24708557, 21.00069237], [70.24652863, 21.00069237], [70.24652863, 21.0004158], [70.24652863, 21.00014114], [70.24652863, 20.99986267], [70.24624634, 20.99986267], [70.24624634, 20.99958992], [70.24597168, 20.99958038], [70.24597168, 20.99930573], [70.24569702, 20.99930954], [70.24569702, 20.99903107], [70.24514008, 20.99903107], [70.24514008, 20.99875259], [70.24485779, 20.99875259], [70.24485779, 20.99847031], [70.24458313, 20.99847031], [70.24458313, 20.99819374], [70.24430847, 20.99819374], [70.24430847, 20.99791718], [70.24402618, 20.9979229], [70.24402618, 20.99765015], [70.24346924, 20.99765015], [70.24346924, 20.99736023], [70.24263763, 20.99736023], [70.24263763, 20.99707985], [70.24208069, 20.99708366], [70.24208069, 20.99680519], [70.24180603, 20.99681091], [70.24180603, 20.99652863], [70.24153137, 20.99652863], [70.24153137, 20.99596977], [70.24124908, 20.99597168], [70.24124908, 20.99569511], [70.24041748, 20.99570084], [70.24041748, 20.99542046], [70.23960114, 20.99542046], [70.23960114, 20.9948597], [70.23902893, 20.9948616], [70.23902893, 20.99458313], [70.23874664, 20.99458313], [70.23874664, 20.99402618], [70.23819733, 20.99402809], [70.23819733, 20.99374962], [70.23792267, 20.99374962], [70.23792267, 20.99402809], [70.23708344, 20.99402618], [70.23708344, 20.99430466], [70.23652649, 20.99430466], [70.23652649, 20.99458313], [70.23625183, 20.99458122], [70.23625183, 20.99570084], [70.23652649, 20.99569511], [70.23652649, 20.99597168], [70.23680878, 20.99596977], [70.23680878, 20.99624825], [70.23707581, 20.99624825], [70.23707581, 20.99652863], [70.23735809, 20.99652863], [70.23735809, 20.99681091], [70.23764038, 20.99680519], [70.23764038, 20.99708366], [70.23791504, 20.99708366], [70.23791504, 20.99736023], [70.23819733, 20.99736023], [70.23819733, 20.99765015], [70.23847198, 20.99765015], [70.23847198, 20.9979229], [70.23874664, 20.99791718], [70.23874664, 20.99819374], [70.23902893, 20.99819374], [70.23902893, 20.99847031], [70.23960114, 20.99847031], [70.23960114, 20.99903107], [70.23986053, 20.99903107], [70.23986053, 20.99930954], [70.24041748, 20.99930573], [70.24041748, 20.99958229], [70.23930359, 20.99958229], [70.23930359, 20.99930573], [70.23874664, 20.99930954], [70.23874664, 20.99903107], [70.23819733, 20.99903107], [70.23819733, 20.99875259], [70.23791504, 20.99875259], [70.23791504, 20.99847031], [70.23764038, 20.99847031], [70.23764038, 20.99819374], [70.23735809, 20.99819374], [70.23735809, 20.99791718], [70.23707581, 20.9979229], [70.23707581, 20.99736023], [70.23652649, 20.99736023], [70.23652649, 20.99708366], [70.23625183, 20.99708366], [70.23625183, 20.99652863], [70.23596954, 20.99652863], [70.23596954, 20.99624825], [70.23513794, 20.99624825], [70.23513794, 20.99652863], [70.23486328, 20.99652863], [70.23486328, 20.99681091], [70.23430634, 20.99680519], [70.23430634, 20.99708366], [70.23374939, 20.99707985], [70.23374939, 20.99736023], [70.2334671, 20.99736023], [70.2334671, 20.99765015], [70.23291779, 20.99765015], [70.23291779, 20.9979229], [70.23236084, 20.99791718], [70.23236084, 20.99819374], [70.23180389, 20.99819374], [70.23180389, 20.99847031], [70.23152924, 20.99847031], [70.23152924, 20.99875259], [70.22680664, 20.99875259], [70.22680664, 20.99903107], [70.22624969, 20.99902725], [70.22624969, 20.99958229], [70.22598267, 20.99958038], [70.22598267, 21.00014114], [70.22598267, 21.00041962], [70.22569275, 21.0004158], [70.22569275, 21.00069237], [70.22541809, 21.00069237], [70.22541809, 21.00097466], [70.2251358, 21.00097084], [70.2251358, 21.00152969], [70.22460175, 21.00152969], [70.22460175, 21.00181007], [70.22402954, 21.00180626], [70.22402954, 21.00208473], [70.22374725, 21.00208092], [70.22374725, 21.00263977], [70.2234726, 21.00263977], [70.2234726, 21.00292015], [70.22319794, 21.00291634], [70.22319794, 21.00319672], [70.22264099, 21.00319672], [70.22264099, 21.00291634], [70.2223587, 21.00292015], [70.2223587, 21.00263977], [70.22125244, 21.00263977], [70.22125244, 21.00292015], [70.22097015, 21.00292015], [70.22097015, 21.00374985], [70.22125244, 21.00374985], [70.22125244, 21.00458336], [70.22097015, 21.00458336], [70.22097015, 21.00486183], [70.22070313, 21.00485992], [70.22070313, 21.0051403], [70.22041321, 21.0051384], [70.22041321, 21.00597191], [70.22013855, 21.00597], [70.22013855, 21.00625038], [70.21902466, 21.00625038], [70.21902466, 21.00652885], [70.21875, 21.00652122], [70.21875, 21.00681114], [70.21819305, 21.00680542], [70.21819305, 21.00708389], [70.21763611, 21.00708389], [70.21763611, 21.00680542], [70.21652985, 21.00681114], [70.21652985, 21.00736046], [70.21624756, 21.00736046], [70.21624756, 21.00764084], [70.2159729, 21.00764084], [70.2159729, 21.00792122], [70.21569824, 21.0079174], [70.21569824, 21.00819397], [70.21541595, 21.00819397], [70.21541595, 21.00847244], [70.2151413, 21.00847054], [70.2151413, 21.00875092], [70.21485901, 21.00875092], [70.21485901, 21.0090313], [70.21457672, 21.0090313], [70.21457672, 21.00931168], [70.21430206, 21.00931168], [70.21430206, 21.00985909], [70.2140274, 21.00985909], [70.2140274, 21.01013947], [70.21347046, 21.01013947], [70.21347046, 21.01042175], [70.21237183, 21.01042175], [70.21237183, 21.01013947], [70.21208191, 21.01013947], [70.21208191, 21.01042175], [70.21152496, 21.01041603], [70.21152496, 21.0106945], [70.21125031, 21.01069069], [70.21125031, 21.0118103], [70.21097565, 21.01180649], [70.21097565, 21.01236343], [70.2104187, 21.01235962], [70.2104187, 21.01264954], [70.21013641, 21.01264954], [70.21013641, 21.01235962], [70.2095871, 21.01235962], [70.2095871, 21.01264954], [70.20931244, 21.01264954], [70.20931244, 21.01292038], [70.20903015, 21.01292038], [70.20903015, 21.01320076], [70.20874786, 21.01320076], [70.20874786, 21.01403046], [70.20847321, 21.01403046], [70.20847321, 21.01431084], [70.20819092, 21.01430321], [70.20819092, 21.01486206], [70.20791626, 21.01486015], [70.20791626, 21.01514053], [70.20707703, 21.01514053], [70.20707703, 21.01542091], [70.20652771, 21.0154171], [70.20652771, 21.01569557], [70.20625305, 21.01569557], [70.20625305, 21.01597214], [70.20597076, 21.01597023], [70.20597076, 21.01625061], [70.20540619, 21.01625061], [70.20540619, 21.01653099], [70.20513916, 21.01653099], [70.20513916, 21.01680946], [70.2048645, 21.01680565], [70.2048645, 21.01708412], [70.20458221, 21.01708031], [70.20458221, 21.01764107], [70.20430756, 21.01764107], [70.20430756, 21.01791954], [70.20402527, 21.01791763], [70.20402527, 21.0181942], [70.20375061, 21.0181942], [70.20375061, 21.01847267], [70.20346832, 21.01846123], [70.20346832, 21.01875114], [70.20317841, 21.01875114], [70.20317841, 21.01902962], [70.20263672, 21.01902962], [70.20263672, 21.01930809], [70.20236206, 21.01930618], [70.20236206, 21.01958275], [70.20180511, 21.01958275], [70.20181274, 21.01986122], [70.20153046, 21.01986122], [70.20153046, 21.02013969], [70.20124817, 21.02013969], [70.20124817, 21.02041817], [70.20097351, 21.02041626], [70.20097351, 21.02069473], [70.20041656, 21.02069473], [70.20043182, 21.02124977], [70.20014191, 21.02124977], [70.20014191, 21.02152824], [70.19985962, 21.02152824], [70.19985962, 21.02180481], [70.19930267, 21.02180481], [70.19930267, 21.02208328], [70.19902802, 21.02207947], [70.19902802, 21.02263832], [70.19875336, 21.02263832], [70.19875336, 21.02292061], [70.19847107, 21.02292061], [70.19847107, 21.02319908], [70.19791412, 21.02319527], [70.19791412, 21.02347183], [70.19736481, 21.02347183], [70.19737244, 21.0237484], [70.19708252, 21.0237484], [70.19708252, 21.02403259], [70.19680786, 21.02403259], [70.19680786, 21.02431107], [70.19596863, 21.02431107], [70.19596863, 21.02514267], [70.19541931, 21.02514267], [70.19541931, 21.02542114], [70.19458008, 21.02541733], [70.19458008, 21.02569389], [70.19374847, 21.02569008], [70.19374847, 21.02625275], [70.19346619, 21.02625275], [70.19346619, 21.02736282], [70.19264221, 21.02736282], [70.19264221, 21.02765083], [70.19235992, 21.02765083], [70.19235992, 21.02791977], [70.19208527, 21.02791405], [70.19208527, 21.02819252], [70.19152832, 21.02819252], [70.19152832, 21.02847481], [70.1912384, 21.0284729], [70.1912384, 21.02874947], [70.19013977, 21.02874947], [70.19013977, 21.02902985], [70.18985748, 21.02902985], [70.18985748, 21.02931023], [70.18930817, 21.02930641], [70.18930817, 21.02958488], [70.18902588, 21.02958488], [70.18902588, 21.02986145], [70.18878174, 21.02985954], [70.18875122, 21.03013992], [70.18736267, 21.03013802], [70.18736267, 21.03069687], [70.18708038, 21.03069115], [70.18708038, 21.03153038], [70.18680573, 21.03152847], [70.18680573, 21.03208351], [70.18624878, 21.03208351], [70.18624878, 21.03180695], [70.18597412, 21.03180695], [70.18597412, 21.03208351], [70.18541718, 21.03208351], [70.18541718, 21.03236198], [70.18514252, 21.03236008], [70.18514252, 21.03264046], [70.18486023, 21.03263855], [70.18486023, 21.03319359], [70.18458557, 21.03319359], [70.18458557, 21.03347206], [70.18430328, 21.03347015], [70.18430328, 21.03375053], [70.18347168, 21.03375053], [70.18347168, 21.03403091], [70.18319702, 21.03403091], [70.18319702, 21.03430748], [70.18291473, 21.03430557], [70.18291473, 21.03458405], [70.18235779, 21.03458023], [70.18235779, 21.03486061], [70.18180847, 21.03486061], [70.18180847, 21.03513908], [70.18152618, 21.03513908], [70.18152618, 21.03541756], [70.18096924, 21.03541756], [70.18096924, 21.03569412], [70.18041992, 21.03569412], [70.18041992, 21.0359726], [70.18013763, 21.03597069], [70.18013763, 21.03624916], [70.18041992, 21.03624916], [70.18041992, 21.03681946], [70.18013763, 21.03680611], [70.18013763, 21.03708267], [70.17986298, 21.03708076], [70.17986298, 21.03735924], [70.1792984, 21.03735924], [70.1792984, 21.03764153], [70.17874908, 21.03764153], [70.17874908, 21.03792191], [70.17847443, 21.03791618], [70.17847443, 21.03847122], [70.17819214, 21.03846931], [70.17819214, 21.03874969], [70.17679596, 21.03874969], [70.17679596, 21.03903008], [70.17736053, 21.03902817], [70.17736053, 21.03930473], [70.17764282, 21.03930283], [70.17764282, 21.04014015], [70.17736053, 21.04014015], [70.17736053, 21.04042053], [70.17652893, 21.04042053], [70.17652893, 21.04070091], [70.17597198, 21.04069519], [70.17597198, 21.04097366], [70.17569733, 21.04096985], [70.17569733, 21.04125023], [70.17542267, 21.04125023], [70.17542267, 21.04153061], [70.17514038, 21.04153061], [70.17514038, 21.04181099], [70.17458344, 21.04180336], [70.17458344, 21.04208565], [70.17430878, 21.04208565], [70.17430878, 21.04263878], [70.17402649, 21.04263878], [70.17402649, 21.04347229], [70.17375183, 21.04347038], [70.17375183, 21.04375076], [70.17263794, 21.04375076], [70.17263794, 21.04403114], [70.17236328, 21.04403114], [70.17236328, 21.04486084], [70.17180634, 21.04486084], [70.17180634, 21.04514122], [70.17151642, 21.04514122], [70.17151642, 21.04541969], [70.17124939, 21.04541779], [70.17124939, 21.04569435], [70.17097473, 21.04569435], [70.17097473, 21.04597282], [70.17069244, 21.04597092], [70.17069244, 21.04624939], [70.17041779, 21.04624939], [70.17041779, 21.04652977], [70.16986084, 21.04652977], [70.16986084, 21.04680824], [70.16930389, 21.04680634], [70.16930389, 21.0470829], [70.16902924, 21.0470829], [70.16902924, 21.04736137], [70.16874695, 21.04735947], [70.16874695, 21.04763985], [70.16847229, 21.04763985], [70.16847229, 21.04791832], [70.16791534, 21.04791641], [70.16791534, 21.04847145], [70.16764069, 21.04846954], [70.16764069, 21.04875946], [70.16706848, 21.04875946], [70.16706848, 21.0490284], [70.16652679, 21.0490284], [70.16652679, 21.04931068], [70.16625214, 21.04930496], [70.16625214, 21.04958344], [70.16596985, 21.04957962], [70.16596985, 21.05013847], [70.16570282, 21.05013847], [70.16570282, 21.05042267], [70.16485596, 21.05042267], [70.16485596, 21.05013847], [70.16348267, 21.05013847], [70.16348267, 21.05042267], [70.16319275, 21.05042267], [70.16319275, 21.05125046], [70.16374969, 21.05125046], [70.16374969, 21.05153275], [70.16402435, 21.05152702], [70.16402435, 21.05208206], [70.16374969, 21.05208015], [70.16374969, 21.05236053], [70.16319275, 21.05236053], [70.16319275, 21.05264282], [70.16179657, 21.05264282], [70.16179657, 21.05291939], [70.16152954, 21.05291748], [70.16152954, 21.05319214], [70.16124725, 21.05319214], [70.16124725, 21.05347443], [70.16014099, 21.05347061], [70.16014099, 21.0537529], [70.1598587, 21.0537529], [70.1598587, 21.05430984], [70.15958405, 21.05430603], [70.15958405, 21.0545845], [70.15930939, 21.05457115], [70.15930176, 21.05486107], [70.15875244, 21.05486107], [70.15875244, 21.05513954], [70.15847015, 21.05513954], [70.15847015, 21.05541992], [70.15791321, 21.05541992], [70.15791321, 21.05624962], [70.15763855, 21.05624962], [70.15763855, 21.05653], [70.15736389, 21.05652809], [70.15736389, 21.05680656], [70.1570816, 21.05680656], [70.1570816, 21.05708313], [70.15680695, 21.05708313], [70.15680695, 21.0573616], [70.15652466, 21.0573616], [70.15652466, 21.05763817], [70.15625, 21.05763054], [70.15625, 21.05792046], [70.15598297, 21.05792046], [70.15598297, 21.05820084], [70.1554184, 21.05819511], [70.1554184, 21.05847168], [70.15512848, 21.05846977], [70.15512848, 21.05875015], [70.15486145, 21.05875015], [70.15486145, 21.05903053], [70.15458679, 21.05903053], [70.15458679, 21.05931091], [70.1543045, 21.05930519], [70.1543045, 21.05958366], [70.15402985, 21.05957985], [70.15402985, 21.06014061], [70.15374756, 21.06014061], [70.15374756, 21.06041908], [70.1534729, 21.06041908], [70.1534729, 21.06069946], [70.15319824, 21.06069946], [70.15319824, 21.06125069], [70.1526413, 21.06125069], [70.1526413, 21.06180763], [70.15208435, 21.06180573], [70.15208435, 21.0620842], [70.15125275, 21.06208038], [70.15125275, 21.06263924], [70.15097046, 21.06263924], [70.15097046, 21.06292152], [70.1506958, 21.0629158], [70.1506958, 21.06347275], [70.15013885, 21.06347084], [70.15013885, 21.06376266], [70.14985657, 21.06376266], [70.14985657, 21.06431007], [70.14958191, 21.06430626], [70.14958191, 21.06458282], [70.14930725, 21.06458282], [70.14930725, 21.06485939], [70.14902496, 21.06485939], [70.14903259, 21.06514168], [70.14875031, 21.06514168], [70.14875031, 21.06542015], [70.14847565, 21.06541634], [70.14847565, 21.06569481], [70.14819336, 21.06569481], [70.14819336, 21.06597137], [70.14763641, 21.06596947], [70.14763641, 21.06624985], [70.14736176, 21.06624985], [70.14736176, 21.06653023], [70.1470871, 21.06652832], [70.1470871, 21.06680489], [70.14680481, 21.06680489], [70.14680481, 21.06708145], [70.14653015, 21.06708145], [70.14653015, 21.06736374], [70.14430237, 21.06735992], [70.14430237, 21.0676403], [70.14402771, 21.0676403], [70.14402771, 21.06792068], [70.14347076, 21.06792068], [70.14347076, 21.06820107], [70.14319611, 21.06819534], [70.14319611, 21.06847382], [70.14289856, 21.06847], [70.14289856, 21.06875038], [70.14263916, 21.06875038], [70.14263916, 21.06903076], [70.14235687, 21.06903076], [70.14235687, 21.06931114], [70.14208221, 21.06930542], [70.14208221, 21.07069588], [70.14180756, 21.07069016], [70.14180756, 21.07263947], [70.1415329, 21.07263947], [70.1415329, 21.07292747], [70.14125061, 21.07292747], [70.14125061, 21.07374954], [70.14097595, 21.07374954], [70.14097595, 21.0743103], [70.14069366, 21.07430649], [70.14069366, 21.07458305], [70.14041901, 21.07458305], [70.14041901, 21.07486153], [70.14015198, 21.07485962], [70.14015198, 21.07513809], [70.13986206, 21.07513809], [70.13986206, 21.07541847], [70.13930511, 21.07541656], [70.13930511, 21.0759716], [70.13874817, 21.0759697], [70.13874817, 21.07652855], [70.13846588, 21.07652855], [70.13846588, 21.07681084], [70.13819122, 21.07680511], [70.13819122, 21.07736015], [70.13791656, 21.07736015], [70.13791656, 21.07792282], [70.13819122, 21.0779171], [70.13819122, 21.07819366], [70.13847351, 21.07819366], [70.13847351, 21.07875252], [70.13874817, 21.07873917], [70.13874817, 21.07930946], [70.13903046, 21.07930946], [70.13903046, 21.07986069], [70.14041901, 21.07986069], [70.14041901, 21.07958031], [70.14152527, 21.07958221], [70.1415329, 21.08024025], [70.1415329, 21.08041954], [70.1414032, 21.08041954], [70.14125061, 21.08041763], [70.14125061, 21.08069229], [70.14097595, 21.08069229], [70.14097595, 21.08097458], [70.14041901, 21.08097076], [70.14041901, 21.08125114], [70.14015198, 21.08125114], [70.14015198, 21.08152962], [70.13986206, 21.08152771], [70.13986206, 21.08180618], [70.14013672, 21.08180618], [70.14013672, 21.08208466], [70.14125061, 21.08208466], [70.14125061, 21.08180618], [70.14208221, 21.08180618], [70.14208221, 21.08152771], [70.14263916, 21.08152962], [70.14263916, 21.08125114], [70.14289856, 21.08125114], [70.14289856, 21.08097076], [70.14347076, 21.08097458], [70.14347076, 21.08069229], [70.14430237, 21.08069229], [70.14430237, 21.08041573], [70.14485931, 21.08041954], [70.14485931, 21.08014107], [70.1451416, 21.08014107], [70.1451416, 21.07986069], [70.14569092, 21.07986069], [70.14569092, 21.07958031], [70.14597321, 21.07958221], [70.14597321, 21.07930565], [70.14624786, 21.07930946], [70.14624786, 21.0790329], [70.14653015, 21.0790329], [70.14653015, 21.07873917], [70.14680481, 21.07875252], [70.14680481, 21.07847023], [70.14763641, 21.07847023], [70.14763641, 21.0790329], [70.14736176, 21.07902718], [70.14736176, 21.07958221], [70.1470871, 21.07958031], [70.1470871, 21.07986069], [70.14679718, 21.07986069], [70.14679718, 21.08014107], [70.14653015, 21.08014107], [70.14653015, 21.08041954], [70.14624786, 21.08041763], [70.14624786, 21.08069229], [70.14569092, 21.08069229], [70.14569092, 21.08097458], [70.14541626, 21.08097076], [70.14541626, 21.08125114], [70.14485931, 21.08125114], [70.14485931, 21.08152962], [70.14458466, 21.08152771], [70.14458466, 21.08180618], [70.14402771, 21.08180618], [70.14402771, 21.08208466], [70.14347076, 21.08208084], [70.14347076, 21.08236122], [70.14318848, 21.08236122], [70.14318848, 21.08263969], [70.14289856, 21.08263969], [70.14289856, 21.08292007], [70.14208221, 21.08291626], [70.14208221, 21.08319664], [70.14125061, 21.08319664], [70.14125061, 21.0834713], [70.14069366, 21.0834713], [70.14069366, 21.08430672], [70.14041901, 21.08430672], [70.14041901, 21.08458328], [70.14015198, 21.08457947], [70.14015198, 21.08486938], [70.13903046, 21.08486938], [70.13903046, 21.08514023], [70.13846588, 21.08514023], [70.13846588, 21.08542061], [70.13791656, 21.08542061], [70.13791656, 21.08570099], [70.13661194, 21.08569527], [70.13597107, 21.08570099], [70.13597107, 21.08514023], [70.13569641, 21.08514023], [70.13569641, 21.08319092], [70.13597107, 21.08319664], [70.13597107, 21.08291626], [70.13625336, 21.08292007], [70.13625336, 21.08263969], [70.13597107, 21.08263969], [70.13597107, 21.08208084], [70.13569641, 21.08208084], [70.13569641, 21.08236122], [70.13540649, 21.08236122], [70.13540649, 21.08208084], [70.13513947, 21.08208466], [70.13513947, 21.08124924], [70.13485718, 21.08125114], [70.13485718, 21.08097076], [70.13458252, 21.08097458], [70.13458252, 21.08041763], [70.13430786, 21.08041954], [70.13430786, 21.08014107], [70.1340332, 21.08014107], [70.1340332, 21.07986069], [70.13346863, 21.07986069], [70.13346863, 21.07958031], [70.13291931, 21.07958031], [70.13291931, 21.07986069], [70.13236237, 21.07986069], [70.13236237, 21.08014107], [70.13208008, 21.08013916], [70.13208008, 21.08069229], [70.13180542, 21.08069229], [70.13180542, 21.08097458], [70.13124847, 21.08097076], [70.13124847, 21.08125114], [70.13095856, 21.08125114], [70.13095856, 21.08152962], [70.13069153, 21.08152771], [70.13069153, 21.08180618], [70.13014221, 21.08180618], [70.13014221, 21.08208466], [70.12985992, 21.08208084], [70.12985992, 21.08263969], [70.12958527, 21.08263969], [70.12958527, 21.08319664], [70.12930298, 21.08319664], [70.12930298, 21.0834713], [70.12902832, 21.08346939], [70.12902832, 21.08374977], [70.12847137, 21.08374977], [70.12847137, 21.08403015], [70.12791443, 21.08402824], [70.12791443, 21.08430672], [70.12763977, 21.08430672], [70.12763977, 21.08458328], [70.12735748, 21.08457947], [70.12735748, 21.08486938], [70.12680817, 21.08486938], [70.12680817, 21.08542061], [70.12652588, 21.08541679], [70.12652588, 21.08597183], [70.12625122, 21.08596992], [70.12625122, 21.08625031], [70.12568665, 21.08625031], [70.12568665, 21.08653069], [70.12513733, 21.08652878], [70.12515259, 21.08736038], [70.12346649, 21.08736038], [70.12346649, 21.08764076], [70.12319183, 21.08764076], [70.12319183, 21.08793068], [70.12291718, 21.08791733], [70.12291718, 21.08819389], [70.12236023, 21.08819389], [70.12236023, 21.08847237], [70.12208557, 21.08847237], [70.1220932, 21.08875084], [70.12180328, 21.08875084], [70.12180328, 21.08902931], [70.12152863, 21.08902931], [70.12152863, 21.0893116], [70.12124634, 21.0893116], [70.12124634, 21.08986092], [70.12097168, 21.08986092], [70.12097168, 21.09013939], [70.12041473, 21.09013939], [70.12041473, 21.09069443], [70.12014008, 21.09069443], [70.12014008, 21.0909729], [70.11985779, 21.09096909], [70.11985779, 21.09124947], [70.11930847, 21.09124947], [70.11930847, 21.09153175], [70.11901855, 21.09153175], [70.11901855, 21.09181023], [70.11819458, 21.09180641], [70.11819458, 21.09208107], [70.11791992, 21.09208107], [70.11791992, 21.09236336], [70.11763763, 21.09235954], [70.11763763, 21.09264183], [70.11736298, 21.09264183], [70.11736298, 21.0929203], [70.11708069, 21.0929203], [70.11708069, 21.09320068], [70.11653137, 21.09319305], [70.11653137, 21.09347153], [70.11597443, 21.09347153], [70.11597443, 21.09375191], [70.11541748, 21.09374046], [70.11541748, 21.09403038], [70.11513519, 21.09402847], [70.11513519, 21.0945816], [70.11486053, 21.0945816], [70.11486053, 21.09486389], [70.11458588, 21.09486008], [70.11458588, 21.09514046], [70.11429596, 21.09514046], [70.11429596, 21.09542084], [70.11402893, 21.09541702], [70.11402893, 21.0956955], [70.11347198, 21.09568977], [70.11347198, 21.09625053], [70.11321259, 21.09625053], [70.11321259, 21.09653091], [70.11292267, 21.09653091], [70.11292267, 21.09680939], [70.11235809, 21.09680557], [70.11235809, 21.09708595], [70.11207581, 21.09708023], [70.11207581, 21.09736061], [70.11180878, 21.09736061], [70.11180878, 21.09764099], [70.11125183, 21.09764099], [70.11125183, 21.09791946], [70.11096954, 21.09791756], [70.11096954, 21.0984726], [70.11042023, 21.09847069], [70.11042023, 21.09875107], [70.11013794, 21.09875107], [70.11013794, 21.09930992], [70.10986328, 21.09930611], [70.10986328, 21.09958267], [70.10958099, 21.09958076], [70.10958099, 21.09987068], [70.10930634, 21.09987068], [70.10930634, 21.10013962], [70.10901642, 21.10013962], [70.10901642, 21.10041809], [70.10874939, 21.10041809], [70.10874939, 21.10124969], [70.1076355, 21.10124969], [70.1076355, 21.10180473], [70.10736084, 21.10180473], [70.10736084, 21.10208321], [70.10708618, 21.10208321], [70.10708618, 21.10236168], [70.10652924, 21.10235977], [70.10652924, 21.10263824], [70.10569763, 21.10263824], [70.10569763, 21.1043129], [70.10541534, 21.10430527], [70.10542297, 21.10486031], [70.10514069, 21.10486031], [70.10514069, 21.10542107], [70.1048584, 21.10541725], [70.1048584, 21.10569382], [70.10263824, 21.10569382], [70.10263824, 21.10541725], [70.10124969, 21.10542107], [70.10124969, 21.10514259], [70.10041809, 21.10514259], [70.10041809, 21.10458183], [70.09958649, 21.10458183], [70.09958649, 21.10486031], [70.09929657, 21.10486031], [70.09929657, 21.10514259], [70.09902954, 21.10514259], [70.09902954, 21.10542107], [70.09874725, 21.10541725], [70.09874725, 21.10569382], [70.0984726, 21.10568047], [70.0984726, 21.10625267], [70.09819794, 21.10625267], [70.09819794, 21.10708237], [70.09792328, 21.10708046], [70.09792328, 21.10764122], [70.09764099, 21.10764122], [70.09764099, 21.10791969], [70.0973587, 21.10791588], [70.0973587, 21.10819244], [70.09708405, 21.10819244], [70.09708405, 21.10847473], [70.0965271, 21.10847092], [70.0965271, 21.10874939], [70.09597015, 21.10874939], [70.09597015, 21.10902977], [70.09570312, 21.10902977], [70.09570312, 21.10931015], [70.09541321, 21.10930634], [70.09541321, 21.10958481], [70.09513855, 21.10958099], [70.09513855, 21.11042023], [70.09486389, 21.11041641], [70.09486389, 21.11069679], [70.0945816, 21.11069679], [70.0945816, 21.11097145], [70.09401703, 21.11096954], [70.09401703, 21.11124992], [70.09375, 21.11124992], [70.09375, 21.11181068], [70.09347534, 21.11180687], [70.09347534, 21.11208344], [70.09319305, 21.11208344], [70.09319305, 21.11236191], [70.09263611, 21.11236], [70.09263611, 21.11264038], [70.09236145, 21.11263847], [70.09236145, 21.1131897], [70.0918045, 21.11319542], [70.0918045, 21.11347198], [70.09152985, 21.11347008], [70.09152985, 21.11403084], [70.09124756, 21.11403084], [70.09124756, 21.11431122], [70.0909729, 21.1143055], [70.0909729, 21.11458397], [70.09069824, 21.11458397], [70.09069824, 21.11486053], [70.09041595, 21.114851], [70.09041595, 21.11514091], [70.08985901, 21.11514091], [70.08985901, 21.11541748], [70.08958435, 21.11541748], [70.08958435, 21.11569405], [70.08930206, 21.11569405], [70.08930206, 21.11597252], [70.08904266, 21.11597061], [70.08904266, 21.11624908], [70.08875275, 21.11624908], [70.08875275, 21.11653137], [70.08847046, 21.11653137], [70.08847046, 21.11681175], [70.0881958, 21.11680603], [70.0881958, 21.1170826], [70.08790588, 21.11708069], [70.08790588, 21.11735916], [70.08763885, 21.11735916], [70.08763885, 21.11763954], [70.0873642, 21.11763954], [70.0873642, 21.11791611], [70.08680725, 21.11791611], [70.08680725, 21.11819458], [70.08652496, 21.11819458], [70.08652496, 21.11791611], [70.08625031, 21.11790848], [70.08625031, 21.11874962], [70.08598328, 21.11874962], [70.08598328, 21.11903191], [70.08569336, 21.11902809], [70.08569336, 21.11958122], [70.0854187, 21.11958122], [70.0854187, 21.11986351], [70.0845871, 21.1198597], [70.0845871, 21.12014008], [70.08429718, 21.12014008], [70.08429718, 21.12042046], [70.08403015, 21.12042046], [70.08403015, 21.12070084], [70.08374786, 21.12069321], [70.08374786, 21.12097359], [70.08347321, 21.12096977], [70.08347321, 21.12125015], [70.08290863, 21.12125015], [70.08290863, 21.12153053], [70.0826416, 21.12153053], [70.0826416, 21.12181091], [70.08208466, 21.12180328], [70.08208466, 21.12208557], [70.08152771, 21.12207985], [70.08152771, 21.12292099], [70.08097076, 21.12291718], [70.08097076, 21.12319565], [70.08069611, 21.12319565], [70.08069611, 21.12347221], [70.08040619, 21.12347031], [70.08040619, 21.12375069], [70.08013916, 21.12375069], [70.08013916, 21.1240406], [70.07984924, 21.1240406], [70.07984924, 21.12430954], [70.07930756, 21.12430573], [70.07930756, 21.1245842], [70.07902527, 21.1245842], [70.0790329, 21.12486076], [70.07875061, 21.12486076], [70.07875061, 21.12514114], [70.07847595, 21.12514114], [70.07847595, 21.12541962], [70.07819366, 21.12541771], [70.07819366, 21.12569427], [70.07791901, 21.12569046], [70.07791901, 21.12625122], [70.07763672, 21.12625122], [70.07763672, 21.12652969], [70.07736206, 21.12652969], [70.07736206, 21.12680817], [70.07707977, 21.12680626], [70.07707977, 21.12708282], [70.07680511, 21.12708282], [70.07680511, 21.1273613], [70.07653046, 21.12735939], [70.07653046, 21.12763977], [70.07624817, 21.12763977], [70.07624817, 21.12791824], [70.07597351, 21.12791634], [70.07597351, 21.12819481], [70.07569122, 21.12819481], [70.07569122, 21.12847137], [70.07541656, 21.12846947], [70.07541656, 21.12902832], [70.07514191, 21.12902832], [70.07514191, 21.12930489], [70.07458496, 21.12930489], [70.07458496, 21.12958336], [70.07430267, 21.12958336], [70.07430267, 21.12986183], [70.07375336, 21.12985039], [70.07375336, 21.13042068], [70.07347107, 21.13041687], [70.07347107, 21.13097191], [70.07290649, 21.13097191], [70.07290649, 21.13125038], [70.07208252, 21.13125038], [70.07208252, 21.13153267], [70.07180786, 21.13153267], [70.07180786, 21.13181114], [70.07152557, 21.13180542], [70.07152557, 21.13208389], [70.07125092, 21.13208008], [70.07125092, 21.13236046], [70.07096863, 21.13236046], [70.07096863, 21.13264275], [70.07069397, 21.13263893], [70.07069397, 21.13319206], [70.07041931, 21.13319016], [70.07041931, 21.13375282], [70.07013702, 21.13375282], [70.07013702, 21.13513947], [70.06958008, 21.13513947], [70.06958008, 21.13541985], [70.06931305, 21.13541985], [70.06931305, 21.13598061], [70.06874847, 21.13598061], [70.06874847, 21.13764], [70.06790924, 21.13764], [70.06790924, 21.13792038], [70.06764221, 21.13791656], [70.06764221, 21.1384716], [70.06735992, 21.1384697], [70.06735992, 21.13875008], [70.06652832, 21.13875008], [70.06652832, 21.13903809], [70.06513977, 21.13903809], [70.06513977, 21.13931084], [70.06485748, 21.13930511], [70.06485748, 21.13958359], [70.06375122, 21.13958359], [70.06375122, 21.13986206], [70.06346893, 21.13986015], [70.06346893, 21.14042091], [70.06319427, 21.1404171], [70.06319427, 21.14097214], [70.06291962, 21.14097023], [70.06291962, 21.14125061], [70.06263733, 21.14125061], [70.06263733, 21.14152908], [70.06236267, 21.14152908], [70.06236267, 21.14180756], [70.06180573, 21.14180565], [70.06180573, 21.14208412], [70.06096649, 21.14208031], [70.06096649, 21.14236069], [70.06041718, 21.14236069], [70.06041718, 21.14292145], [70.06014252, 21.14291763], [70.06014252, 21.14347267], [70.05986023, 21.14347076], [70.05986023, 21.14374924], [70.0595932, 21.14374924], [70.0595932, 21.14403152], [70.05902863, 21.14403152], [70.05902863, 21.1443119], [70.05874634, 21.14430618], [70.05874634, 21.14458275], [70.05847168, 21.14458084], [70.05847168, 21.14485931], [70.05819702, 21.14485931], [70.05819702, 21.14513969], [70.05791473, 21.14513969], [70.05791473, 21.14569473], [70.05735779, 21.14569473], [70.05735779, 21.1459713], [70.05708313, 21.14596939], [70.05708313, 21.14624977], [70.05680847, 21.14624977], [70.05680847, 21.14653015], [70.05652618, 21.14652824], [70.05652618, 21.14708138], [70.05625153, 21.14708138], [70.05625153, 21.14847374], [70.05596924, 21.14846992], [70.05596924, 21.14875031], [70.05458069, 21.14875031], [70.05458069, 21.14903069], [70.05430603, 21.14903069], [70.05430603, 21.14931107], [70.05458069, 21.14930344], [70.05458069, 21.14958572], [70.05430603, 21.14958], [70.05430603, 21.14986038], [70.05403137, 21.14986038], [70.05403137, 21.15014076], [70.05347443, 21.15013885], [70.05347443, 21.1506958], [70.05319214, 21.15069008], [70.05319214, 21.15125084], [70.05293274, 21.15125084], [70.05293274, 21.15153122], [70.05236053, 21.1515274], [70.05236053, 21.15208244], [70.05208588, 21.15208054], [70.05208588, 21.15236092], [70.05179596, 21.15236092], [70.05179596, 21.15263939], [70.05069733, 21.15263939], [70.05069733, 21.15291977], [70.05041504, 21.15291786], [70.05041504, 21.15319443], [70.05014038, 21.15319443], [70.05014038, 21.1534729], [70.04985809, 21.1534729], [70.04987335, 21.15374947], [70.04958344, 21.15374947], [70.04958344, 21.15402794], [70.04930878, 21.15402794], [70.04930878, 21.15458298], [70.04902649, 21.15458107], [70.04902649, 21.1554184], [70.04875183, 21.1554184], [70.04875183, 21.15570068], [70.04819489, 21.15569496], [70.04819489, 21.15597153], [70.04763794, 21.15596962], [70.04763794, 21.15624809], [70.04679871, 21.15624809], [70.04679871, 21.15652847], [70.04652405, 21.15652847], [70.04652405, 21.15847015], [70.04624939, 21.15847015], [70.04624939, 21.15903282], [70.04569244, 21.15903282], [70.04569244, 21.15930939], [70.04541779, 21.15930557], [70.04541779, 21.15958214], [70.04514313, 21.15958023], [70.04514313, 21.16015053], [70.04486084, 21.16013908], [70.04486084, 21.16069221], [70.04458618, 21.16069221], [70.04458618, 21.1609745], [70.04429626, 21.16097069], [70.04429626, 21.16125107], [70.04373932, 21.16125107], [70.04373932, 21.16152954], [70.04347229, 21.16152954], [70.04347229, 21.16180992], [70.04291534, 21.16180611], [70.04291534, 21.16208458], [70.04264069, 21.16208076], [70.04264069, 21.16236115], [70.0423584, 21.16236115], [70.0423584, 21.16263962], [70.04207611, 21.16263962], [70.04207611, 21.16292], [70.04180908, 21.16292], [70.04180908, 21.16374969], [70.04152679, 21.16374969], [70.04152679, 21.16403008], [70.04125214, 21.16402817], [70.04125214, 21.16430664], [70.04096985, 21.16430664], [70.04096985, 21.16458321], [70.04070282, 21.16457939], [70.04070282, 21.16514015], [70.0404129, 21.16514015], [70.0404129, 21.16542053], [70.04013824, 21.16542053], [70.04013824, 21.16570091], [70.03986359, 21.16569519], [70.03986359, 21.16597176], [70.0395813, 21.16596031], [70.0395813, 21.16653061], [70.03930664, 21.16653061], [70.03930664, 21.16681099], [70.03902435, 21.16680527], [70.03902435, 21.16708374], [70.03874969, 21.16707993], [70.03874969, 21.16736031], [70.03848267, 21.16736031], [70.03848267, 21.16764069], [70.03819275, 21.16764069], [70.03819275, 21.16791916], [70.03791809, 21.16791725], [70.03791809, 21.16819382], [70.0376358, 21.16819382], [70.0376358, 21.16847229], [70.03736115, 21.16847038], [70.03736115, 21.16875076], [70.03708649, 21.16875076], [70.03708649, 21.16931152], [70.0368042, 21.1693058], [70.0368042, 21.16958427], [70.03624725, 21.16958046], [70.03624725, 21.17013931], [70.0359726, 21.17013931], [70.0359726, 21.17069435], [70.03569794, 21.17069435], [70.03569794, 21.17097282], [70.03541565, 21.17097282], [70.03542328, 21.17124939], [70.03514099, 21.17124939], [70.03514099, 21.17153168], [70.0348587, 21.17153168], [70.0348587, 21.17209053], [70.03458405, 21.1720829], [70.03458405, 21.17236137], [70.03430939, 21.17235947], [70.03430176, 21.17264175], [70.0340271, 21.17264175], [70.0340271, 21.17292023], [70.03375244, 21.17291641], [70.03375244, 21.17319489], [70.03347015, 21.17319489], [70.03347015, 21.17347145], [70.03320313, 21.17346954], [70.03320313, 21.1740303], [70.0320816, 21.1740284], [70.0320816, 21.17458153], [70.03179932, 21.17457962], [70.03179932, 21.17514992], [70.0320816, 21.17513847], [70.0320816, 21.17569542], [70.03236389, 21.17569542], [70.03236389, 21.17597389], [70.03263855, 21.17597008], [70.03263855, 21.17625046], [70.03291321, 21.17625046], [70.03291321, 21.17653084], [70.0331955, 21.17652512], [70.0331955, 21.17708588], [70.03347015, 21.17708015], [70.03347015, 21.17764091], [70.03375244, 21.17763901], [70.03375244, 21.17819595], [70.0340271, 21.17819595], [70.0340271, 21.17847252], [70.0348587, 21.17847061], [70.0348587, 21.17875099], [70.03514099, 21.17875099], [70.03514099, 21.17902946], [70.03542328, 21.17902946], [70.03542328, 21.17930984], [70.03569794, 21.17930984], [70.03569794, 21.17986107], [70.0359726, 21.17986107], [70.0359726, 21.18013954], [70.03624725, 21.18013954], [70.03624725, 21.18041992], [70.03652954, 21.18041611], [70.03652954, 21.18069458], [70.0368042, 21.18069458], [70.0368042, 21.18097305], [70.03708649, 21.1809597], [70.03708649, 21.18124962], [70.03736115, 21.18124962], [70.03736115, 21.18152809], [70.0376358, 21.18152809], [70.0376358, 21.18208313], [70.03793335, 21.18208122], [70.03793335, 21.18263817], [70.03819275, 21.18263817], [70.03819275, 21.18347168], [70.03791809, 21.18347168], [70.03791809, 21.18319511], [70.0376358, 21.18320084], [70.0376358, 21.18291855], [70.03708649, 21.18291855], [70.03708649, 21.18263817], [70.03679657, 21.18263817], [70.03679657, 21.1823597], [70.03652954, 21.1823616], [70.03652954, 21.18208313], [70.03624725, 21.18208313], [70.03624725, 21.18180466], [70.0359726, 21.18180466], [70.0359726, 21.18152809], [70.03569794, 21.18152809], [70.03569794, 21.1809597], [70.03541565, 21.18097305], [70.03541565, 21.18069458], [70.03514099, 21.18069458], [70.03514099, 21.18041611], [70.0348587, 21.18041992], [70.0348587, 21.18013954], [70.03347015, 21.18013954], [70.03347015, 21.17986107], [70.0331955, 21.17986107], [70.0331955, 21.17902756], [70.03263855, 21.17902946], [70.03263855, 21.17875099], [70.0320816, 21.17875099], [70.0320816, 21.17847061], [70.02929688, 21.17847061], [70.02929688, 21.17875099], [70.0284729, 21.17875099], [70.0284729, 21.17930984], [70.02819824, 21.17930794], [70.02819824, 21.1795826], [70.02791595, 21.17958069], [70.02791595, 21.17986107], [70.0276413, 21.17986107], [70.0276413, 21.18013954], [70.02735901, 21.18013954], [70.02735901, 21.18041992], [70.02708435, 21.18041611], [70.02708435, 21.18069458], [70.0265274, 21.18069458], [70.0265274, 21.18097305], [70.0256958, 21.1809597], [70.0256958, 21.18124962], [70.02540588, 21.18124962], [70.02540588, 21.18152809], [70.02513885, 21.18152809], [70.02513885, 21.18180466], [70.0248642, 21.18180466], [70.0248642, 21.18208313], [70.02458191, 21.18208313], [70.02458191, 21.1823616], [70.02430725, 21.1823597], [70.02430725, 21.18291855], [70.02375031, 21.18291855], [70.02375031, 21.18320084], [70.02319336, 21.18320084], [70.02319336, 21.18374825], [70.0229187, 21.18374825], [70.0229187, 21.18403244], [70.0220871, 21.18402863], [70.0220871, 21.18458366], [70.02179718, 21.18458176], [70.02179718, 21.18514252], [70.02153015, 21.1851387], [70.02153015, 21.18569374], [70.02097321, 21.18569374], [70.02097321, 21.18597031], [70.02041626, 21.18597031], [70.02041626, 21.18625259], [70.0201416, 21.18625259], [70.0201416, 21.18653107], [70.01985931, 21.18653107], [70.01985931, 21.18708992], [70.0195694, 21.18708992], [70.0195694, 21.18736076], [70.01930237, 21.18736076], [70.01930237, 21.18764114], [70.01902771, 21.18764114], [70.01902771, 21.18791962], [70.01875305, 21.1879158], [70.01875305, 21.18819237], [70.01847076, 21.18819237], [70.01847076, 21.18847466], [70.01790619, 21.18847084], [70.01790619, 21.18902969], [70.01763916, 21.18902779], [70.01763916, 21.18958473], [70.01708221, 21.18958473], [70.01708221, 21.1898613], [70.01680756, 21.1898613], [70.01680756, 21.19013977], [70.01652527, 21.19013977], [70.01652527, 21.19069672], [70.01625061, 21.19069099], [70.01625061, 21.19124985], [70.01597595, 21.19124985], [70.01597595, 21.19153023], [70.01569366, 21.19152832], [70.01569366, 21.19180679], [70.01457977, 21.19180679], [70.01457977, 21.19208336], [70.01374817, 21.19208336], [70.01374817, 21.19236183], [70.01346588, 21.19235992], [70.01346588, 21.1926403], [70.01291656, 21.1926403], [70.01291656, 21.19292068], [70.01264191, 21.19292068], [70.01264191, 21.19431114], [70.01235962, 21.19430542], [70.01235962, 21.19458389], [70.01152802, 21.19458008], [70.01152802, 21.19486046], [70.01125336, 21.19486046], [70.01125336, 21.19514084], [70.01069641, 21.19514084], [70.01069641, 21.19542122], [70.01013947, 21.1954174], [70.01013947, 21.19569397], [70.00986481, 21.19569397], [70.00986481, 21.19597244], [70.00930786, 21.19597054], [70.00930786, 21.19626236], [70.0090332, 21.19626236], [70.0090332, 21.19652939], [70.00875092, 21.19652748], [70.00875092, 21.19708252], [70.00846863, 21.19708061], [70.00846863, 21.19763947], [70.00791931, 21.19763947], [70.00791931, 21.19792175], [70.00763702, 21.19791603], [70.00763702, 21.1981945], [70.00736237, 21.1981945], [70.00736237, 21.19847107], [70.00708008, 21.19846916], [70.00708008, 21.19874954], [70.00681305, 21.19874954], [70.00681305, 21.19931984], [70.00653076, 21.19930649], [70.00653076, 21.19986343], [70.00624847, 21.19985962], [70.00624847, 21.20014191], [70.00596619, 21.20014191], [70.00596619, 21.20070076], [70.00569153, 21.20070076], [70.00569153, 21.20125008], [70.00541687, 21.20125008], [70.00541687, 21.20181084], [70.00514221, 21.20180321], [70.00514221, 21.20208549], [70.00485992, 21.20208549], [70.00485992, 21.20236206], [70.00430298, 21.20236015], [70.00430298, 21.20264053], [70.00374603, 21.20264053], [70.00374603, 21.20292091], [70.00319672, 21.2029171], [70.00319672, 21.20319557], [70.0029068, 21.20318985], [70.0029068, 21.20375061], [70.00263977, 21.20375061], [70.00263977, 21.20403099], [70.00208282, 21.20403099], [70.00208282, 21.20430946], [70.00180817, 21.20430565], [70.00180817, 21.20458412], [70.00152588, 21.20458031], [70.00152588, 21.20486069], [70.00096893, 21.20486069], [70.00096893, 21.20513916], [70.00068665, 21.20512962], [70.00068665, 21.20541954], [70.00041962, 21.20541763], [70.00041962, 21.2056942], [70.00013733, 21.20569038], [70.00013733, 21.20625114], [69.99958038, 21.20625114], [69.99958038, 21.20680809], [69.99930573, 21.20680618], [69.99930573, 21.20708275], [69.99903107, 21.20708084], [69.99903107, 21.20736122], [69.99884796, 21.20736122], [69.99846649, 21.20736122], [69.99846649, 21.20791817], [69.99819183, 21.20791626], [69.99819183, 21.2084713], [69.99791718, 21.20846939], [69.99791718, 21.20874977], [69.99764252, 21.20874977], [69.99764252, 21.20902824], [69.99736023, 21.20902824], [69.99736023, 21.20930481], [69.99708557, 21.20930481], [69.99708557, 21.20958328], [69.99680328, 21.20957756], [69.99680328, 21.21013832], [69.99652863, 21.21013832], [69.99652863, 21.2104187], [69.99624634, 21.2104187], [69.99624634, 21.2107029], [69.99597168, 21.21069527], [69.99597168, 21.21097183], [69.99568939, 21.21097183], [69.99568939, 21.21125984], [69.99539948, 21.21125984], [69.99539948, 21.21153259], [69.99514008, 21.21153259], [69.99514008, 21.21181107], [69.99485779, 21.21181107], [69.99485779, 21.21236038], [69.99458313, 21.21236038], [69.99458313, 21.21264267], [69.99430847, 21.21264267], [69.99430847, 21.21292114], [69.99402618, 21.21291733], [69.99402618, 21.21319389], [69.99375153, 21.21319389], [69.99375153, 21.21347046], [69.99346924, 21.21347046], [69.99346924, 21.21375275], [69.99318695, 21.21375275], [69.99318695, 21.21403122], [69.99291992, 21.21403122], [69.99291992, 21.21432114], [69.99263763, 21.21430588], [69.99263763, 21.21458244], [69.99236298, 21.21458054], [69.99236298, 21.21486282], [69.99208069, 21.21486282], [69.99208069, 21.21513939], [69.99153137, 21.21513939], [69.99153137, 21.21541977], [69.99124908, 21.21541405], [69.99124908, 21.21569252], [69.99069214, 21.21569252], [69.99069214, 21.21597481], [69.99041748, 21.21597099], [69.99041748, 21.21652985], [69.99014282, 21.21652985], [69.99014282, 21.21763992], [69.98986053, 21.21763992], [69.98986053, 21.2179203], [69.98958588, 21.2179203], [69.98958588, 21.21820068], [69.98930359, 21.21819687], [69.98930359, 21.21847153], [69.98902893, 21.21846962], [69.98902893, 21.21875], [69.98874664, 21.21875], [69.98874664, 21.21931076], [69.98847198, 21.21930695], [69.98847198, 21.21958351], [69.98819733, 21.21958351], [69.98819733, 21.21986198], [69.98792267, 21.21986008], [69.98792267, 21.22014046], [69.98764038, 21.22014046], [69.98764038, 21.22042084], [69.98735809, 21.22041893], [69.98735809, 21.22069359], [69.98708344, 21.22069359], [69.98708344, 21.22097206], [69.98680878, 21.22097206], [69.98681641, 21.22125053], [69.98652649, 21.22125053], [69.98652649, 21.22153091], [69.98625183, 21.2215271], [69.98625183, 21.22208405], [69.98596954, 21.22208023], [69.98596954, 21.22236061], [69.98568726, 21.22236061], [69.98568726, 21.22263908], [69.98542023, 21.22263908], [69.98542023, 21.22292137], [69.98513794, 21.22292137], [69.98513794, 21.22320175], [69.98486328, 21.22319412], [69.98486328, 21.2234726], [69.98458099, 21.22347069], [69.98458099, 21.22374916], [69.98430634, 21.22374916], [69.98430634, 21.22431183], [69.98402405, 21.22430611], [69.98402405, 21.22458267], [69.98374939, 21.22458076], [69.98374939, 21.22485924], [69.98345947, 21.22485924], [69.98345947, 21.22513962], [69.98319244, 21.22513962], [69.98319244, 21.22542191], [69.98291779, 21.22541618], [69.98291779, 21.22569466], [69.9826355, 21.22569466], [69.9826355, 21.22624969], [69.98236084, 21.22624016], [69.98236084, 21.22653008], [69.98208618, 21.22652817], [69.98208618, 21.22680473], [69.98180389, 21.22680473], [69.98180389, 21.2270813], [69.98152924, 21.2270813], [69.98152924, 21.22736359], [69.98097229, 21.22735977], [69.98097229, 21.22764015], [69.98069, 21.22764015], [69.98069, 21.22792053], [69.98041534, 21.22791672], [69.98041534, 21.22847366], [69.98014069, 21.22846985], [69.98014069, 21.22875023], [69.9798584, 21.22875023], [69.9798584, 21.22903061], [69.97958374, 21.2290287], [69.97958374, 21.22930336], [69.97930908, 21.22930336], [69.97930908, 21.22958565], [69.97902679, 21.22957993], [69.97902679, 21.22986031], [69.97875214, 21.22986031], [69.97875214, 21.23042107], [69.97846985, 21.23041725], [69.97846985, 21.23069572], [69.97819519, 21.23069572], [69.97819519, 21.23097229], [69.9779129, 21.23097038], [69.9779129, 21.23125076], [69.97764587, 21.23125076], [69.97764587, 21.23153114], [69.97735596, 21.23153114], [69.97735596, 21.23180962], [69.9770813, 21.23180771], [69.9770813, 21.23208427], [69.97680664, 21.23208046], [69.97680664, 21.23236084], [69.97651672, 21.23236084], [69.97651672, 21.23264122], [69.97624969, 21.23264122], [69.97624969, 21.23291969], [69.97597504, 21.23291779], [69.97597504, 21.23319435], [69.97569275, 21.23319054], [69.97569275, 21.23374939], [69.97541809, 21.23374939], [69.97541809, 21.23402977], [69.9751358, 21.23402977], [69.9751358, 21.23430824], [69.97486115, 21.23430634], [69.97486115, 21.2345829], [69.97458649, 21.2345829], [69.97458649, 21.23486137], [69.97429657, 21.23485947], [69.97429657, 21.23513985], [69.97402954, 21.23513985], [69.97402954, 21.23543167], [69.97374725, 21.23541641], [69.97374725, 21.23569489], [69.9734726, 21.23569489], [69.9734726, 21.23597145], [69.97319794, 21.23596954], [69.97319794, 21.23624992], [69.97292328, 21.23624992], [69.97292328, 21.2365284], [69.97264099, 21.2365284], [69.97264099, 21.23681068], [69.9723587, 21.23680496], [69.9723587, 21.23708344], [69.97207642, 21.23707962], [69.97207642, 21.23764038], [69.97180939, 21.23763847], [69.97180176, 21.23817825], [69.97125244, 21.23819542], [69.97125244, 21.23847008], [69.97097015, 21.23847008], [69.97097015, 21.23875046], [69.97070313, 21.23875046], [69.97070313, 21.23903275], [69.97041321, 21.23903275], [69.97041321, 21.23931122], [69.97013855, 21.2393055], [69.97013855, 21.23958206], [69.96985626, 21.23958015], [69.96985626, 21.23986053], [69.9695816, 21.23986053], [69.9695816, 21.24014282], [69.96930695, 21.24014282], [69.96930695, 21.24041939], [69.96902466, 21.24041748], [69.96902466, 21.24069214], [69.96875, 21.24069214], [69.96875, 21.24097443], [69.96847534, 21.24097443], [69.96847534, 21.24124908], [69.96819305, 21.24123955], [69.96819305, 21.24152946], [69.9679184, 21.24152946], [69.9679184, 21.24180984], [69.96763611, 21.24180984], [69.96763611, 21.24236107], [69.96736145, 21.24236107], [69.96736145, 21.24263954], [69.96708679, 21.24263954], [69.96708679, 21.24291992], [69.9668045, 21.2429142], [69.9668045, 21.24319267], [69.96652985, 21.24319267], [69.96652985, 21.24347305], [69.96624756, 21.24347115], [69.96624756, 21.24374962], [69.9659729, 21.24374962], [69.9659729, 21.24403], [69.96569824, 21.24402809], [69.96569824, 21.24430656], [69.96541595, 21.24430656], [69.96541595, 21.2448616], [69.9651413, 21.2448597], [69.9651413, 21.24514008], [69.96485901, 21.24514008], [69.96485901, 21.24542046], [69.96457672, 21.24542046], [69.96457672, 21.24570084], [69.96430206, 21.24569511], [69.96430206, 21.24597168], [69.9640274, 21.24596977], [69.9640274, 21.24625015], [69.96375275, 21.24625015], [69.96375275, 21.24653053], [69.96347046, 21.24653053], [69.96347046, 21.24681091], [69.9631958, 21.24680519], [69.9631958, 21.24708366], [69.96290588, 21.24707985], [69.96290588, 21.24736977], [69.96264648, 21.24736977], [69.96264648, 21.24764061], [69.9623642, 21.2476387], [69.9623642, 21.24819374], [69.96208191, 21.24819374], [69.96208191, 21.24847221], [69.96180725, 21.24847031], [69.96180725, 21.24875069], [69.96153259, 21.24875069], [69.96153259, 21.24902916], [69.96125031, 21.24902916], [69.96125031, 21.24931145], [69.96097565, 21.24930573], [69.96097565, 21.2495842], [69.96069336, 21.24958038], [69.96069336, 21.24986076], [69.9604187, 21.24986076], [69.9604187, 21.25043106], [69.96013641, 21.2504158], [69.96013641, 21.25069427], [69.95986176, 21.25069427], [69.95986176, 21.25097275], [69.95957947, 21.25097084], [69.95957947, 21.25124931], [69.95929718, 21.25124931], [69.95929718, 21.2515316], [69.95903015, 21.2515316], [69.95903015, 21.25181007], [69.95874786, 21.25180626], [69.95874786, 21.25208282], [69.95847321, 21.25208282], [69.95847321, 21.2523613], [69.95819092, 21.25235939], [69.95819092, 21.25292015], [69.95791626, 21.25291634], [69.95791626, 21.25319481], [69.9576416, 21.25319481], [69.9576416, 21.25347137], [69.95735931, 21.25346947], [69.95735931, 21.25374985], [69.95707703, 21.25374985], [69.95707703, 21.25403023], [69.95680237, 21.25402832], [69.95680237, 21.25430489], [69.95652771, 21.25430489], [69.95652771, 21.25486374], [69.95625305, 21.25485992], [69.95625305, 21.2551403], [69.95597076, 21.2551403], [69.95597076, 21.25542068], [69.95569611, 21.25542068], [69.95569611, 21.25570107], [69.95541382, 21.25569534], [69.95541382, 21.25597382], [69.95513916, 21.25597], [69.95513916, 21.25653076], [69.95485687, 21.25653076], [69.95485687, 21.25681114], [69.95458221, 21.25680351], [69.95458221, 21.2570858], [69.95430756, 21.25708008], [69.95430756, 21.25736046], [69.9540329, 21.25736046], [69.9540329, 21.25764084], [69.95375061, 21.25763893], [69.95375061, 21.25819588], [69.95347595, 21.25819588], [69.95347595, 21.25847244], [69.95318604, 21.25847054], [69.95318604, 21.25875092], [69.95291901, 21.25875092], [69.95291901, 21.25902939], [69.95263672, 21.25902748], [69.95263672, 21.25958252], [69.95236206, 21.25958061], [69.95236206, 21.25986099], [69.95207977, 21.25986099], [69.95207977, 21.26013947], [69.95181274, 21.26013947], [69.95181274, 21.26041985], [69.95153046, 21.26041794], [69.95153046, 21.2606945], [69.95124817, 21.26069069], [69.95124817, 21.26124954], [69.95096588, 21.26124954], [69.95096588, 21.26152992], [69.95069122, 21.26152992], [69.95069122, 21.2618084], [69.95041656, 21.26180649], [69.95041656, 21.26208305], [69.95014191, 21.26208115], [69.95014191, 21.26236916], [69.94985962, 21.26236916], [69.94985962, 21.26291847], [69.94959259, 21.26291847], [69.94959259, 21.26320076], [69.94930267, 21.26319504], [69.94930267, 21.2634716], [69.94902802, 21.2634697], [69.94902802, 21.26374817], [69.94875336, 21.26374817], [69.94875336, 21.26402855], [69.94847107, 21.26402855], [69.94847107, 21.26458359], [69.94819641, 21.26458359], [69.94819641, 21.26486015], [69.94790649, 21.26486015], [69.94790649, 21.26514244], [69.94763947, 21.26513863], [69.94763947, 21.2654171], [69.94736481, 21.2654171], [69.94736481, 21.26569366], [69.94708252, 21.26569366], [69.94708252, 21.26597023], [69.94680786, 21.26597023], [69.94680786, 21.2665329], [69.9465332, 21.2665329], [69.9465332, 21.26680946], [69.94625092, 21.26680565], [69.94625092, 21.26708221], [69.94596863, 21.26708031], [69.94596863, 21.26736069], [69.94568634, 21.26736069], [69.94568634, 21.26764107], [69.94541931, 21.26764107], [69.94541931, 21.26791954], [69.94513702, 21.26791763], [69.94513702, 21.26847458], [69.94486237, 21.26847076], [69.94486237, 21.26875114], [69.94458008, 21.26875114], [69.94458008, 21.26902962], [69.94431305, 21.26902962], [69.94431305, 21.26931], [69.94403076, 21.26930618], [69.94403076, 21.26958466], [69.94374847, 21.26958084], [69.94374847, 21.26986122], [69.94346619, 21.26986122], [69.94346619, 21.27042007], [69.94319153, 21.27041435], [69.94319153, 21.27069664], [69.94291687, 21.27069664], [69.94291687, 21.2709713], [69.94264221, 21.27096939], [69.94264221, 21.27124977], [69.94235992, 21.27124977], [69.94235992, 21.27153969], [69.94208527, 21.27152824], [69.94208527, 21.27180672], [69.94180298, 21.27180672], [69.94180298, 21.27236176], [69.94153595, 21.27235985], [69.94153595, 21.27264023], [69.94124603, 21.27264023], [69.94124603, 21.27292061], [69.94097137, 21.27292061], [69.94097137, 21.27320099], [69.94069672, 21.27319527], [69.94069672, 21.27347183], [69.9404068, 21.27346992], [69.9404068, 21.27375031], [69.94013977, 21.27375031], [69.94013977, 21.27403069], [69.93985748, 21.27403069], [69.93985748, 21.27431107], [69.93958282, 21.27430534], [69.93958282, 21.27458382], [69.93930817, 21.27457809], [69.93930817, 21.27486038], [69.93902588, 21.27486038], [69.93902588, 21.27541924], [69.93875122, 21.27541733], [69.93875122, 21.27569389], [69.93846893, 21.27569389], [69.93846893, 21.27597237], [69.93818665, 21.27597046], [69.93818665, 21.27625084], [69.93791962, 21.27625084], [69.93791962, 21.27652931], [69.93763733, 21.27652931], [69.93763733, 21.2768116], [69.93736267, 21.27680588], [69.93736267, 21.27708244], [69.93708038, 21.27708244], [69.93708038, 21.27736092], [69.93680573, 21.27736092], [69.93681335, 21.27763939], [69.93653107, 21.27763939], [69.93653107, 21.27792168], [69.93624878, 21.27791595], [69.93624878, 21.27819443], [69.93597412, 21.27819443], [69.93597412, 21.2784729], [69.93569183, 21.27846909], [69.93569183, 21.27874947], [69.93540955, 21.27874947], [69.93540955, 21.27931023], [69.93514252, 21.27930641], [69.93514252, 21.27958107], [69.93486023, 21.27958107], [69.93486023, 21.27986145], [69.9345932, 21.27985954], [69.9345932, 21.28014183], [69.93430328, 21.28013802], [69.93430328, 21.28041649], [69.93402863, 21.28041267], [69.93402863, 21.28070068], [69.93374634, 21.28069305], [69.93374634, 21.28097153], [69.93347168, 21.28096962], [69.93347168, 21.28125], [69.93319702, 21.28125], [69.93319702, 21.28153038], [69.9329071, 21.28153038], [69.9329071, 21.28181076], [69.93264008, 21.28180313], [69.93264008, 21.28208542], [69.93235779, 21.28208542], [69.93235779, 21.28236389], [69.93208313, 21.28236008], [69.93208313, 21.28264046], [69.93180847, 21.28264046], [69.93180847, 21.28292084], [69.93152618, 21.28291702], [69.93152618, 21.2831955], [69.93125153, 21.28318977], [69.93125153, 21.28347969], [69.93096924, 21.28347969], [69.93096924, 21.28375053], [69.93068695, 21.28375053], [69.93068695, 21.28403091], [69.93041992, 21.28403091], [69.93041992, 21.28430939], [69.93013763, 21.28430557], [69.93013763, 21.28458595], [69.92986298, 21.28458023], [69.92986298, 21.28486061], [69.92958069, 21.28486061], [69.92958069, 21.28514099], [69.92930603, 21.28514099], [69.92930603, 21.28541946], [69.92903137, 21.28541756], [69.92903137, 21.28569412], [69.92874908, 21.28569412], [69.92874908, 21.2859726], [69.9284668, 21.28597069], [69.9284668, 21.28653908], [69.92819214, 21.28653908], [69.92819214, 21.28680992], [69.92791748, 21.28680611], [69.92791748, 21.28708267], [69.92763519, 21.28708267], [69.92764282, 21.28736115], [69.92736053, 21.28736115], [69.92736053, 21.28763962], [69.92708588, 21.28763962], [69.92708588, 21.28791809], [69.92680359, 21.28791618], [69.92680359, 21.28819466], [69.92652893, 21.28819466], [69.92652893, 21.28847313], [69.92624664, 21.28847122], [69.92624664, 21.28874969], [69.92597198, 21.28874969], [69.92597198, 21.28902817], [69.92569733, 21.28902817], [69.92569733, 21.28930473], [69.92541504, 21.28930473], [69.92541504, 21.28958321], [69.92514038, 21.28958321], [69.92514038, 21.28986168], [69.92485809, 21.28985977], [69.92485809, 21.29013824], [69.92457581, 21.29013824], [69.92457581, 21.29041862], [69.92430878, 21.29041862], [69.92430878, 21.29070282], [69.92402649, 21.29069519], [69.92402649, 21.29097176], [69.92375183, 21.29097176], [69.92375183, 21.29125023], [69.92346954, 21.29125023], [69.92346954, 21.29153252], [69.92318726, 21.29153252], [69.92318726, 21.2918129], [69.92292023, 21.29180527], [69.92292023, 21.29236031], [69.92263794, 21.29235077], [69.92263794, 21.29264259], [69.92236328, 21.29264259], [69.92236328, 21.29292107], [69.92208099, 21.29291725], [69.92208099, 21.29319382], [69.92180634, 21.29319382], [69.92180634, 21.29347038], [69.92151642, 21.29347038], [69.92151642, 21.29403114], [69.92124939, 21.29403114], [69.92124939, 21.29430962], [69.92097473, 21.2943058], [69.92097473, 21.29458237], [69.92069244, 21.29458046], [69.92069244, 21.29486084], [69.92041016, 21.29486084], [69.92041016, 21.29514122], [69.9201355, 21.29513931], [69.9201355, 21.29569244], [69.91986084, 21.29569244], [69.91986084, 21.29597473], [69.91958618, 21.29597092], [69.91958618, 21.29624939], [69.91929626, 21.29624939], [69.91929626, 21.29652977], [69.91902924, 21.29652977], [69.91902924, 21.29681015], [69.91874695, 21.29680634], [69.91874695, 21.29736137], [69.91847229, 21.29735947], [69.91847229, 21.29763985], [69.91819763, 21.29763985], [69.91819763, 21.29792023], [69.91791534, 21.29791641], [69.91791534, 21.29819679], [69.91764069, 21.29819107], [69.91764069, 21.29848099], [69.91735077, 21.29848099], [69.91735077, 21.2990303], [69.91707611, 21.2990303], [69.91707611, 21.29931068], [69.91680908, 21.29930687], [69.91680908, 21.29958344], [69.91652679, 21.29958344], [69.91652679, 21.29986191], [69.91625214, 21.29986], [69.91625214, 21.30014038], [69.91596985, 21.30013847], [69.91596985, 21.3006897], [69.91569519, 21.30069542], [69.91569519, 21.30097198], [69.9154129, 21.30097008], [69.9154129, 21.30125046], [69.91513824, 21.30125046], [69.91513824, 21.30152893], [69.91485596, 21.30151939], [69.91485596, 21.30181122], [69.9145813, 21.30181122], [69.9145813, 21.30236053], [69.91430664, 21.30236053], [69.91430664, 21.30264091], [69.91401672, 21.30264091], [69.91401672, 21.30291939], [69.91374969, 21.30291748], [69.91374969, 21.30319405], [69.91347504, 21.30319405], [69.91347504, 21.30347252], [69.91319275, 21.30347061], [69.91319275, 21.30402946], [69.91291809, 21.30402946], [69.91291809, 21.30431175], [69.9126358, 21.30430603], [69.9126358, 21.3045826], [69.91236115, 21.30458069], [69.91236115, 21.30485916], [69.91208649, 21.30485916], [69.91208649, 21.30542183], [69.9118042, 21.30541611], [69.9118042, 21.30569458], [69.91152954, 21.30569458], [69.91152954, 21.30597115], [69.91124725, 21.30597115], [69.91124725, 21.30624962], [69.9109726, 21.30624962], [69.9109726, 21.30653191], [69.91069794, 21.30652809], [69.91069794, 21.30708122], [69.91041565, 21.30708122], [69.91041565, 21.30736351], [69.91014099, 21.3073597], [69.91014099, 21.30764961], [69.9098587, 21.30764961], [69.9098587, 21.30792046], [69.90958405, 21.30791664], [69.90958405, 21.30847168], [69.90930939, 21.30846977], [69.90930176, 21.30875015], [69.9090271, 21.30875015], [69.9090271, 21.30903053], [69.90875244, 21.30903053], [69.90875244, 21.30931091], [69.90847015, 21.30930328], [69.90847015, 21.30958557], [69.90820313, 21.30957985], [69.90820313, 21.31014061], [69.90791321, 21.31014061], [69.90791321, 21.31042099], [69.90763855, 21.31041718], [69.90763855, 21.31069565], [69.90736389, 21.31069565], [69.90736389, 21.31097221], [69.9070816, 21.31097031], [69.9070816, 21.31125069], [69.90680695, 21.31125069], [69.90680695, 21.31153107], [69.90651703, 21.31153107], [69.90651703, 21.31180954], [69.90625, 21.31180763], [69.90625, 21.3120842], [69.90598297, 21.31208038], [69.90598297, 21.31264114], [69.90569305, 21.31264114], [69.90569305, 21.31291962], [69.9054184, 21.31291771], [69.9054184, 21.31319427], [69.90513611, 21.31319427], [69.90513611, 21.31347275], [69.90486145, 21.3134594], [69.90486145, 21.31375122], [69.90458679, 21.31375122], [69.90458679, 21.31402969], [69.90429688, 21.31402969], [69.90429688, 21.31430817], [69.90402985, 21.31430626], [69.90402985, 21.31458282], [69.90374756, 21.31458282], [69.90374756, 21.3148613], [69.9034729, 21.31485939], [69.9034729, 21.31513977], [69.90319824, 21.31513977], [69.90319824, 21.31541824], [69.90291595, 21.31541634], [69.90291595, 21.31597137], [69.9026413, 21.31596947], [69.9026413, 21.31624985], [69.90235901, 21.31624985], [69.90235901, 21.31652832], [69.90208435, 21.31652832], [69.90208435, 21.31680489], [69.90180206, 21.31680489], [69.90180206, 21.31708336], [69.9015274, 21.31708336], [69.9015274, 21.31736183], [69.90125275, 21.31735992], [69.90125275, 21.3176403], [69.90097046, 21.3176403], [69.90097046, 21.31792259], [69.9006958, 21.31792259], [69.9006958, 21.31820107], [69.90041351, 21.31819534], [69.90041351, 21.31847191], [69.90013885, 21.31847191], [69.90013885, 21.31875038], [69.89985657, 21.31875038], [69.89985657, 21.31931114], [69.89958191, 21.31931114], [69.89958191, 21.31958961], [69.89930725, 21.31958961], [69.89930725, 21.31986046], [69.89903259, 21.31986046], [69.89903259, 21.32014275], [69.89875031, 21.32014275], [69.89875031, 21.32042122], [69.89847565, 21.3204174], [69.89847565, 21.32069206], [69.89819336, 21.32069206], [69.89819336, 21.32097435], [69.8979187, 21.32097054], [69.8979187, 21.32125282], [69.89763641, 21.32125282], [69.89763641, 21.32152939], [69.89736176, 21.32152939], [69.89736176, 21.32180977], [69.8970871, 21.32180405], [69.8970871, 21.32208252], [69.89679718, 21.32208061], [69.89679718, 21.32265091], [69.89653015, 21.32265091], [69.89653015, 21.32291985], [69.89624786, 21.32291412], [69.89624786, 21.3231926], [69.89597321, 21.3231926], [69.89597321, 21.32347488], [69.89569092, 21.32347107], [69.89569092, 21.32374954], [69.89541626, 21.32374954], [69.89541626, 21.32402992], [69.8951416, 21.32402992], [69.8951416, 21.3243103], [69.89485931, 21.32430649], [69.89485931, 21.32458305], [69.89458466, 21.32458305], [69.89458466, 21.32486153], [69.89430237, 21.32485962], [69.89430237, 21.32542038], [69.89402771, 21.32542038], [69.89402771, 21.3257103], [69.89375305, 21.32569695], [69.89375305, 21.3259716], [69.89347076, 21.3259697], [69.89347076, 21.32625008], [69.89319611, 21.32625008], [69.89319611, 21.32653046], [69.89290619, 21.32653046], [69.89290619, 21.32681084], [69.89263916, 21.32680511], [69.89263916, 21.32708359], [69.89235687, 21.32707977], [69.89235687, 21.32764053], [69.89208221, 21.32764053], [69.89208221, 21.32792091], [69.89180756, 21.3279171], [69.89180756, 21.32819366], [69.89152527, 21.32819366], [69.89152527, 21.32847214], [69.89125061, 21.32846069], [69.89125061, 21.32875061], [69.89097595, 21.32875061], [69.89097595, 21.32902908], [69.89069366, 21.32902718], [69.89069366, 21.32958412], [69.89041901, 21.32958412], [69.89042664, 21.32986069], [69.89013672, 21.32986069], [69.89013672, 21.33013916], [69.88986206, 21.33013916], [69.88986206, 21.33042145], [69.88957977, 21.33041763], [69.88957977, 21.3306942], [69.88931274, 21.33068848], [69.88931274, 21.33124924], [69.88903046, 21.33124924], [69.88903046, 21.33152962], [69.88874817, 21.33152962], [69.88874817, 21.3318119], [69.88847351, 21.33180618], [69.88847351, 21.33208275], [69.88819122, 21.33208084], [69.88819122, 21.33235931], [69.88791656, 21.33235931], [69.88791656, 21.33292007], [69.88764191, 21.33291626], [69.88764191, 21.33319473], [69.88735962, 21.33319473], [69.88735962, 21.3334713], [69.88708496, 21.3334713], [69.88709259, 21.33374977], [69.88680267, 21.33374977], [69.88680267, 21.33430481], [69.88652802, 21.3343029], [69.88652802, 21.33459091], [69.88625336, 21.33458138], [69.88625336, 21.33486366], [69.88597107, 21.33485985], [69.88597107, 21.33514023], [69.88569641, 21.33514023], [69.88569641, 21.33542061], [69.88541412, 21.33541679], [69.88541412, 21.33597374], [69.88513947, 21.33596992], [69.88513947, 21.33625031], [69.88485718, 21.33625031], [69.88485718, 21.33653069], [69.88458252, 21.33653069], [69.88458252, 21.33681107], [69.88430023, 21.33681107], [69.88430786, 21.33736038], [69.8840332, 21.33736038], [69.8840332, 21.3376503], [69.88375092, 21.3376503], [69.88375092, 21.33792114], [69.88346863, 21.33791733], [69.88346863, 21.3381958], [69.88319397, 21.3381958], [69.88319397, 21.33847237], [69.88291931, 21.33847046], [69.88291931, 21.33903122], [69.88263702, 21.33903122], [69.88263702, 21.33930969], [69.88236237, 21.33930779], [69.88236237, 21.33958244], [69.88208008, 21.33958054], [69.88208008, 21.33986092], [69.88180542, 21.33986092], [69.88181305, 21.34013939], [69.88153076, 21.34013939], [69.88153076, 21.34041977], [69.88124847, 21.34041786], [69.88124847, 21.34069443], [69.88096619, 21.34069061], [69.88096619, 21.34124947], [69.88069153, 21.34124947], [69.88069153, 21.34152985], [69.88041687, 21.34152985], [69.88041687, 21.34180832], [69.88014221, 21.34180641], [69.88014221, 21.34208298], [69.87985992, 21.34208298], [69.87985992, 21.34236145], [69.8795929, 21.34235954], [69.8795929, 21.34263992], [69.87930298, 21.34263992], [69.87930298, 21.3429184], [69.87902832, 21.3429184], [69.87902832, 21.34320068], [69.87875366, 21.34319496], [69.87875366, 21.34347153], [69.87847137, 21.34346962], [69.87847137, 21.34402847], [69.87819672, 21.34402847], [69.87819672, 21.34431267], [69.87791443, 21.34430504], [69.87791443, 21.34458351], [69.87763977, 21.34458351], [69.87763977, 21.34486008], [69.87735748, 21.34486008], [69.87735748, 21.34514046], [69.87708282, 21.34514046], [69.87708282, 21.34542274], [69.87680817, 21.34541702], [69.87680817, 21.34569359], [69.87652588, 21.34569359], [69.87652588, 21.34597015], [69.87625122, 21.34597015], [69.87625122, 21.34625053], [69.87596893, 21.34625053], [69.87596893, 21.34682083], [69.87569427, 21.34680557], [69.87569427, 21.34708214], [69.87541962, 21.34708214], [69.87542725, 21.34736061], [69.87513733, 21.34736061], [69.87513733, 21.3476429], [69.87486267, 21.3476429], [69.87486267, 21.34791946], [69.87458038, 21.34791756], [69.87458038, 21.34819221], [69.87430573, 21.34819221], [69.87430573, 21.3484745], [69.87403107, 21.34847069], [69.87403107, 21.34875107], [69.87374878, 21.34875107], [69.87374878, 21.34902954], [69.87346649, 21.34902954], [69.87346649, 21.3495903], [69.87319183, 21.3495903], [69.87319183, 21.34986115], [69.87291718, 21.34986115], [69.87291718, 21.35013962], [69.87264252, 21.35013962], [69.87264252, 21.35042], [69.87236023, 21.35041428], [69.87236023, 21.35069656], [69.87208557, 21.35069656], [69.87208557, 21.35097313], [69.87180328, 21.35097122], [69.87180328, 21.35124969], [69.87152863, 21.35124969], [69.87152863, 21.35153008], [69.87124634, 21.35152817], [69.87124634, 21.35180664], [69.87097168, 21.35180664], [69.87097168, 21.35236168], [69.87069702, 21.35236168], [69.87069702, 21.35263824], [69.8704071, 21.35263062], [69.8704071, 21.35292053], [69.87014008, 21.35292053], [69.87014008, 21.35320091], [69.86985779, 21.35319519], [69.86985779, 21.35347176], [69.86958313, 21.35346985], [69.86958313, 21.35375023], [69.86930084, 21.35375023], [69.86930084, 21.35403061], [69.86902618, 21.35403061], [69.86902618, 21.35430908], [69.86875153, 21.35430527], [69.86875153, 21.35458374], [69.86846924, 21.35457993], [69.86846924, 21.35514069], [69.86818695, 21.35514069], [69.86818695, 21.35541916], [69.86791992, 21.35541725], [69.86791992, 21.35569382], [69.86763763, 21.35569382], [69.86763763, 21.35597229], [69.86736298, 21.35597038], [69.86736298, 21.35625076], [69.86708069, 21.35625076], [69.86708069, 21.35652924], [69.86680603, 21.35652924], [69.86680603, 21.35681152], [69.86653137, 21.35681152], [69.86653137, 21.35736084], [69.86625671, 21.35736084], [69.86625671, 21.35763931], [69.8659668, 21.35763931], [69.8659668, 21.3579216], [69.86569214, 21.35791588], [69.86569214, 21.35819435], [69.86541748, 21.35819435], [69.86541748, 21.35847282], [69.86514282, 21.35847092], [69.86514282, 21.35876274], [69.86486053, 21.35876274], [69.86486053, 21.35903168], [69.86458588, 21.35902786], [69.86458588, 21.3595829], [69.86430359, 21.3595829], [69.86430359, 21.35986137], [69.86402893, 21.35985947], [69.86402893, 21.36013985], [69.86374664, 21.36013985], [69.86374664, 21.36042023], [69.86347198, 21.36041641], [69.86347198, 21.36069489], [69.86319733, 21.36069489], [69.86319733, 21.36097145], [69.86291504, 21.36097145], [69.86292267, 21.36124992], [69.86264038, 21.36124992], [69.86264038, 21.3615303], [69.86235809, 21.3615284], [69.86235809, 21.36208153], [69.86208344, 21.36208153], [69.86208344, 21.36236382], [69.86180878, 21.36236], [69.86180878, 21.36264038], [69.86152649, 21.36264038], [69.86152649, 21.36292076], [69.86125183, 21.36291695], [69.86125183, 21.3631897], [69.86096954, 21.36319542], [69.86096954, 21.36347389], [69.86068726, 21.36347008], [69.86068726, 21.36375046], [69.86042023, 21.36375046], [69.86042023, 21.36431122], [69.86013794, 21.36430359], [69.86013794, 21.36458588], [69.85986328, 21.36457062], [69.85986328, 21.36486053], [69.85958099, 21.36486053], [69.85958099, 21.36514091], [69.85930634, 21.36514091], [69.85930634, 21.36541939], [69.85902405, 21.36541748], [69.85902405, 21.36569595], [69.85874939, 21.36569595], [69.85874939, 21.36597252], [69.8584671, 21.36597061], [69.8584671, 21.36652946], [69.85819244, 21.36652946], [69.85819244, 21.36680984], [69.85791779, 21.36680794], [69.85791779, 21.3670826], [69.8576355, 21.3670826], [69.85764313, 21.36736107], [69.85736084, 21.36736107], [69.85736084, 21.36763954], [69.85708618, 21.36763], [69.85708618, 21.36791992], [69.85680389, 21.36791611], [69.85680389, 21.36819458], [69.85652924, 21.36819077], [69.85652924, 21.36874962], [69.85624695, 21.36874962], [69.85624695, 21.36902809], [69.85597229, 21.36902809], [69.85597229, 21.36930466], [69.85569763, 21.36930466], [69.85569763, 21.36958313], [69.85541534, 21.36958313], [69.85541534, 21.3698616], [69.85514069, 21.3698597], [69.85514069, 21.37013817], [69.8548584, 21.37013817], [69.8548584, 21.37070084], [69.85458374, 21.37069511], [69.85458374, 21.37097168], [69.85430908, 21.37097168], [69.85431671, 21.37125015], [69.85402679, 21.37125015], [69.85402679, 21.37153244], [69.85375214, 21.37153244], [69.85375214, 21.37181282], [69.85346985, 21.37180519], [69.85346985, 21.37208366], [69.85320282, 21.37208176], [69.85320282, 21.37264252], [69.8529129, 21.37264252], [69.8529129, 21.3729229], [69.85263824, 21.37291718], [69.85263824, 21.37319374], [69.85236359, 21.37319374], [69.85236359, 21.37347031], [69.8520813, 21.37347031], [69.8520813, 21.37376022], [69.85180664, 21.37376022], [69.85180664, 21.37403107], [69.85152435, 21.37402725], [69.85152435, 21.37458229], [69.85124969, 21.37458229], [69.85124969, 21.37486076], [69.85098267, 21.37486076], [69.85098267, 21.37514114], [69.85069275, 21.37514114], [69.85069275, 21.37541962], [69.85041809, 21.3754158], [69.85041809, 21.37569237], [69.8501358, 21.37569237], [69.8501358, 21.37597466], [69.84986115, 21.37597084], [69.84986115, 21.37625122], [69.84958649, 21.37624931], [69.84958649, 21.37680626], [69.8493042, 21.37680626], [69.8493042, 21.37708473], [69.84902954, 21.37708473], [69.84902954, 21.3773613], [69.84874725, 21.37735939], [69.84874725, 21.37763977], [69.8484726, 21.37763977], [69.8484726, 21.37792015], [69.84819794, 21.37791443], [69.84819794, 21.37819672], [69.84791565, 21.37819672], [69.84792328, 21.37874985], [69.84764099, 21.37874985], [69.84764099, 21.37903023], [69.8473587, 21.37902832], [69.8473587, 21.37930679], [69.84708405, 21.37930679], [69.84708405, 21.37958336], [69.84680939, 21.37958336], [69.84680176, 21.37986183], [69.8465271, 21.37985992], [69.8465271, 21.3801403], [69.84625244, 21.3801403], [69.84625244, 21.38070107], [69.84597015, 21.38069534], [69.84597015, 21.38097191], [69.8456955, 21.38097191], [69.84570313, 21.38125038], [69.84541321, 21.38125038], [69.84541321, 21.38153076], [69.84513092, 21.38153076], [69.84513092, 21.38180923], [69.84486389, 21.38180542], [69.84486389, 21.38208389], [69.8445816, 21.38207817], [69.8445816, 21.38264084], [69.84430695, 21.38264084], [69.84430695, 21.38293266], [69.84402466, 21.3829174], [69.84402466, 21.38319397], [69.84375, 21.38319397], [69.84375, 21.38347244], [69.84347534, 21.38347244], [69.84348297, 21.38375092], [69.84319305, 21.38375092], [69.84319305, 21.38402939], [69.8429184, 21.38402939], [69.8429184, 21.38431168], [69.84263611, 21.38431168], [69.84263611, 21.38485909], [69.84236145, 21.38485909], [69.84236145, 21.38513947], [69.84208679, 21.38513947], [69.84208679, 21.38542175], [69.84179688, 21.38542175], [69.84179688, 21.38570023], [69.84152985, 21.3856945], [69.84152985, 21.38597107], [69.84124756, 21.38597107], [69.84124756, 21.38624954], [69.8409729, 21.38624954], [69.8409729, 21.38653183], [69.84069824, 21.38652802], [69.84069824, 21.38708115], [69.84041595, 21.38708115], [69.84041595, 21.38736153], [69.8401413, 21.38735962], [69.8401413, 21.38764191], [69.83985901, 21.38764191], [69.83985901, 21.38792038], [69.83957672, 21.38792038], [69.83957672, 21.38820076], [69.83930206, 21.38819313], [69.83930206, 21.3884716], [69.8390274, 21.3884716], [69.8390274, 21.38875008], [69.83875275, 21.38874054], [69.83875275, 21.38931084], [69.83847046, 21.38930321], [69.83847046, 21.38958549], [69.8381958, 21.38958549], [69.8381958, 21.38986206], [69.83790588, 21.38986015], [69.83790588, 21.39014053], [69.83763885, 21.39014053], [69.83763885, 21.39042091], [69.8373642, 21.3904171], [69.8373642, 21.39069557], [69.83708191, 21.39069557], [69.83708191, 21.39097214], [69.83680725, 21.39097023], [69.83680725, 21.39153099], [69.83652496, 21.39152527], [69.83652496, 21.39180756], [69.83625031, 21.39180756], [69.83625031, 21.39208412], [69.83597565, 21.39208412], [69.83598328, 21.39236069], [69.83569336, 21.39236069], [69.83569336, 21.39264107], [69.8354187, 21.39264107], [69.8354187, 21.39291954], [69.83513641, 21.39291763], [69.83513641, 21.3931942], [69.83486176, 21.39319038], [69.83486176, 21.39375114], [69.8345871, 21.39375114], [69.8345871, 21.39402962], [69.83429718, 21.39402962], [69.83429718, 21.39430809], [69.83403015, 21.39430618], [69.83403015, 21.39458275], [69.83374786, 21.39458084], [69.83374786, 21.39487076], [69.83347321, 21.39487076], [69.83347321, 21.39513969], [69.83319092, 21.39513969], [69.83319092, 21.39541817], [69.83291626, 21.39541626], [69.83291626, 21.3959713], [69.8326416, 21.39596748], [69.8326416, 21.39624977], [69.83235931, 21.39624977], [69.83235931, 21.39652824], [69.83208466, 21.39652824], [69.83208466, 21.39680481], [69.83180237, 21.39680481], [69.83180237, 21.39708328], [69.83152771, 21.39708328], [69.83152771, 21.39736176], [69.83125305, 21.39735985], [69.83125305, 21.39763832], [69.83097076, 21.39763832], [69.83097076, 21.3982029], [69.83069611, 21.39819527], [69.83069611, 21.39847183], [69.83040619, 21.39847183], [69.83041382, 21.39875031], [69.83014679, 21.39875031], [69.83014679, 21.39903259], [69.82985687, 21.39903259], [69.82985687, 21.39931107], [69.82958221, 21.39930534], [69.82958221, 21.39958382], [69.82930756, 21.39958191], [69.82930756, 21.39986038], [69.8290329, 21.39986038], [69.8290329, 21.40014267], [69.82875061, 21.40013885], [69.82875061, 21.40069389], [69.82847595, 21.40069389], [69.82847595, 21.40097237], [69.82818604, 21.40097046], [69.82818604, 21.40125275], [69.82791901, 21.40125275], [69.82791901, 21.40153122], [69.82763672, 21.40153122], [69.82763672, 21.40180969], [69.82736206, 21.40180588], [69.82736206, 21.40208244], [69.82707977, 21.40208244], [69.82707977, 21.40236092], [69.82680511, 21.40236092], [69.82681274, 21.40263939], [69.82653046, 21.40263939], [69.82653046, 21.40319252], [69.82624817, 21.40319252], [69.82624817, 21.40347481], [69.82597351, 21.40347481], [69.82597351, 21.40374947], [69.82569122, 21.40373993], [69.82569122, 21.40402985], [69.82541656, 21.40402985], [69.82541656, 21.40431023], [69.82514191, 21.40430641], [69.82514191, 21.40458488], [69.82485962, 21.40458488], [69.82485962, 21.40486145], [69.82459259, 21.40485954], [69.82459259, 21.4054203], [69.82430267, 21.4054203], [69.82430267, 21.40570068], [69.82402802, 21.40569687], [69.82402802, 21.40597153], [69.82375336, 21.40596962], [69.82375336, 21.40625], [69.82347107, 21.40625], [69.82347107, 21.40653038], [69.82319641, 21.40653038], [69.82319641, 21.40681076], [69.82291412, 21.40680695], [69.82291412, 21.40708351], [69.82263947, 21.40708351], [69.82263947, 21.40736198], [69.82235718, 21.40736008], [69.82235718, 21.40792084], [69.82208252, 21.40791893], [69.82208252, 21.40819359], [69.82180786, 21.40819359], [69.82180786, 21.40847206], [69.82152557, 21.40847206], [69.8215332, 21.40875053], [69.82125092, 21.40875053], [69.82125092, 21.40903091], [69.820961, 21.40903091], [69.820961, 21.40930748], [69.82069397, 21.40930557], [69.82069397, 21.40958405], [69.82041931, 21.40957832], [69.82041931, 21.40987015], [69.82013702, 21.40987015], [69.82013702, 21.41041946], [69.81986237, 21.41041756], [69.81986237, 21.41069412], [69.81958008, 21.41069412], [69.81958008, 21.4109726], [69.81931305, 21.41097069], [69.81931305, 21.41124916], [69.81903076, 21.41124916], [69.81903076, 21.41152954], [69.81874847, 21.41152954], [69.81874847, 21.41181183], [69.81847382, 21.41180611], [69.81847382, 21.41208267], [69.81819153, 21.41208076], [69.81819153, 21.41263962], [69.81791687, 21.41263962], [69.81791687, 21.41291618], [69.81764221, 21.41291618], [69.81764221, 21.41319466], [69.81735992, 21.41319466], [69.81735992, 21.41347122], [69.81708527, 21.41347122], [69.8170929, 21.41374969], [69.81680298, 21.41374969], [69.81680298, 21.41403008], [69.81652832, 21.41402817], [69.81652832, 21.41430473], [69.81625366, 21.41430473], [69.81625366, 21.41486359], [69.81597137, 21.41485977], [69.81597137, 21.41514015], [69.81569672, 21.41514015], [69.81569672, 21.41542053], [69.8154068, 21.41542053], [69.8154068, 21.41570091], [69.81513977, 21.41569328], [69.81513977, 21.41597176], [69.81485748, 21.41596985], [69.81485748, 21.41625023], [69.81458282, 21.41625023], [69.81458282, 21.41653061], [69.81430817, 21.4165287], [69.81430817, 21.41708565], [69.81402588, 21.41707993], [69.81402588, 21.41736031], [69.81375122, 21.41736031], [69.81375122, 21.41764069], [69.81346893, 21.41764069], [69.81346893, 21.41792107], [69.81319427, 21.41791725], [69.81319427, 21.41819572], [69.81291962, 21.41819572], [69.81291962, 21.41847229], [69.81263733, 21.41847038], [69.81263733, 21.41875076], [69.81236267, 21.41875076], [69.81236267, 21.41930962], [69.81208038, 21.41930771], [69.81208038, 21.41958427], [69.81180573, 21.41958427], [69.81181335, 21.41986084], [69.81153107, 21.41986084], [69.81153107, 21.42014122], [69.81124878, 21.42014122], [69.81124878, 21.42041969], [69.81097412, 21.42041779], [69.81097412, 21.42069435], [69.81069183, 21.42069435], [69.81069183, 21.42097282], [69.81041718, 21.42097092], [69.81041718, 21.42152977], [69.81014252, 21.42152977], [69.81014252, 21.42180824], [69.80986023, 21.42180634], [69.80986023, 21.4220829], [69.80958557, 21.4220829], [69.80958557, 21.42236137], [69.80930328, 21.42235947], [69.80930328, 21.42263985], [69.809021, 21.42263985], [69.809021, 21.42291832], [69.80874634, 21.42291641], [69.80874634, 21.42319489], [69.80847168, 21.42319489], [69.80847168, 21.42347145], [69.80819702, 21.42346954], [69.80819702, 21.42374992], [69.8079071, 21.42374992], [69.8079071, 21.42431259], [69.80764008, 21.42430496], [69.80764008, 21.42458344], [69.80735779, 21.42458344], [69.80735779, 21.42486191], [69.80708313, 21.42485046], [69.80708313, 21.42514038], [69.80680847, 21.42514038], [69.80680847, 21.42542267], [69.80652618, 21.42541695], [69.80652618, 21.4256916], [69.80625153, 21.42569542], [69.80625153, 21.42597008], [69.80596161, 21.42597008], [69.80596161, 21.42625046], [69.80568695, 21.42625046], [69.80568695, 21.42681122], [69.80541992, 21.4268055], [69.80541992, 21.42708206], [69.80513763, 21.42708015], [69.80513763, 21.42736053], [69.80486298, 21.42736053], [69.80486298, 21.42764282], [69.80458069, 21.42763901], [69.80458069, 21.42791748], [69.80430603, 21.42791748], [69.80430603, 21.42819214], [69.80403137, 21.42819214], [69.80403137, 21.42847443], [69.80374908, 21.42847061], [69.80374908, 21.4287529], [69.8034668, 21.4287529], [69.8034668, 21.42902946], [69.80319214, 21.42902946], [69.80319214, 21.42930984], [69.80291748, 21.42930412], [69.80291748, 21.4295826], [69.80263519, 21.4295826], [69.80264282, 21.43013954], [69.80236053, 21.43013954], [69.80236053, 21.43041992], [69.80208588, 21.4304142], [69.80208588, 21.43069649], [69.80180359, 21.43069649], [69.80180359, 21.43097305], [69.80152893, 21.43097115], [69.80152893, 21.43124962], [69.80124664, 21.43124962], [69.80124664, 21.43153], [69.80097198, 21.43152809], [69.80097198, 21.43180656], [69.80069733, 21.43180656], [69.80069733, 21.43208313], [69.80041504, 21.43208313], [69.80041504, 21.4323616], [69.80014038, 21.4323597], [69.80014038, 21.43264008], [69.79985809, 21.43264008], [69.79985809, 21.43320084], [69.79958344, 21.43319511], [69.79958344, 21.43347168], [69.79930878, 21.43346977], [69.79930878, 21.43375015], [69.79902649, 21.43375015], [69.79902649, 21.43403816], [69.79875183, 21.43403816], [69.79875183, 21.43431091], [69.79846954, 21.43430519], [69.79846954, 21.43458366], [69.79818726, 21.43457985], [69.79818726, 21.43486023], [69.79792023, 21.43486023], [69.79792023, 21.43514061], [69.79763794, 21.43514061], [69.79763794, 21.43541908], [69.79736328, 21.43541718], [69.79736328, 21.43597221], [69.79708099, 21.43597031], [69.79708099, 21.43625069], [69.79680634, 21.43625069], [69.79680634, 21.43652916], [69.79651642, 21.43652916], [69.79651642, 21.43681145], [69.79624939, 21.43680573], [69.79624939, 21.4370842], [69.7959671, 21.43708038], [69.7959671, 21.43736076], [69.79569244, 21.43736076], [69.79569244, 21.43792152], [69.79541779, 21.4379158], [69.79541779, 21.43819427], [69.7951355, 21.43819427], [69.7951355, 21.43847275], [69.79486084, 21.43847084], [69.79486084, 21.43874931], [69.79458618, 21.43874931], [69.79458618, 21.43902969], [69.79429626, 21.43902969], [69.79429626, 21.43931007], [69.79402924, 21.43930626], [69.79402924, 21.43958282], [69.79374695, 21.43958282], [69.79374695, 21.4398613], [69.79347229, 21.43985176], [69.79347229, 21.44013977], [69.79319763, 21.44013977], [69.79319763, 21.44042015], [69.79291534, 21.44041634], [69.79291534, 21.44069481], [69.79264069, 21.44069481], [69.79264069, 21.44097137], [69.7923584, 21.44096947], [69.7923584, 21.44153023], [69.79208374, 21.44152832], [69.79208374, 21.44180489], [69.79180908, 21.44180489], [69.79180908, 21.44208145], [69.79152679, 21.44208145], [69.79152679, 21.44236374], [69.79125214, 21.44235992], [69.79125214, 21.4426403], [69.79097748, 21.4426403], [69.79097748, 21.44292068], [69.79070282, 21.44292068], [69.79070282, 21.44320107], [69.7904129, 21.44319344], [69.7904129, 21.44347382], [69.79013824, 21.44347], [69.79013824, 21.44375038], [69.78985596, 21.44375038], [69.78985596, 21.44431114], [69.7895813, 21.44430351], [69.7895813, 21.4445858], [69.78930664, 21.44458008], [69.78930664, 21.44486046], [69.78901672, 21.44486046], [69.78901672, 21.44514084], [69.78874969, 21.44514084], [69.78874969, 21.44542122], [69.78847504, 21.4454174], [69.78847504, 21.44569588], [69.78819275, 21.44569016], [69.78819275, 21.44598007], [69.78791809, 21.44598007], [69.78791809, 21.44625092], [69.7876358, 21.44625092], [69.7876358, 21.44652939], [69.78736115, 21.44652939], [69.78736115, 21.44680977], [69.78708649, 21.44680977], [69.78708649, 21.44736099], [69.78679657, 21.44736099], [69.78679657, 21.44763947], [69.78652954, 21.44763947], [69.78652954, 21.44791985], [69.78624725, 21.44791794], [69.78624725, 21.4481945], [69.7859726, 21.4481945], [69.7859726, 21.44847298], [69.78569794, 21.44847107], [69.78569794, 21.44874954], [69.78542328, 21.44874954], [69.78542328, 21.44903946], [69.78514099, 21.44903946], [69.78514099, 21.4493084], [69.7848587, 21.44930649], [69.7848587, 21.44958305], [69.78457642, 21.44958115], [69.78457642, 21.45013809], [69.78430939, 21.45013809], [69.78430176, 21.45041847], [69.7840271, 21.45041847], [69.7840271, 21.45070076], [69.78375244, 21.45069504], [69.78375244, 21.4509716], [69.78347015, 21.4509697], [69.78347015, 21.45125008], [69.78320313, 21.45125008], [69.78320313, 21.45153236], [69.78291321, 21.45153236], [69.78291321, 21.45181274], [69.78263855, 21.45180511], [69.78263855, 21.45236015], [69.78235626, 21.45236015], [69.78235626, 21.45264053], [69.78180695, 21.45264053], [69.78180695, 21.45292282], [69.78152466, 21.4529171], [69.78152466, 21.45319366], [69.78125, 21.45319366], [69.78125, 21.45347023], [69.78097534, 21.45347023], [69.78098297, 21.45375061], [69.78069305, 21.45375061], [69.78069305, 21.4540329], [69.7804184, 21.4540329], [69.7804184, 21.45430946], [69.78013611, 21.45430565], [69.78013611, 21.45458221], [69.77986145, 21.45458031], [69.77986145, 21.45486069], [69.77958679, 21.45486069], [69.77958679, 21.45514107], [69.77929688, 21.45514107], [69.77929688, 21.45541954], [69.78013611, 21.45541573], [69.78013611, 21.45597458], [69.77986145, 21.45597076], [69.77986145, 21.45652962], [69.77958679, 21.45652771], [69.77958679, 21.45708466], [69.77902985, 21.45708466], [69.77903748, 21.45736122], [69.77874756, 21.45736122], [69.77874756, 21.45763969], [69.7784729, 21.45763969], [69.7784729, 21.45792007], [69.77819824, 21.45791435], [69.77819824, 21.4584713], [69.7784729, 21.45846939], [69.7784729, 21.45874977], [69.77874756, 21.45874977], [69.77874756, 21.45846939], [69.77902985, 21.4584713], [69.77902985, 21.45819664], [69.7793045, 21.45819664], [69.7793045, 21.45791435], [69.77986145, 21.45792007], [69.77986145, 21.45763969], [69.78013611, 21.45763969], [69.78013611, 21.45736122], [69.7804184, 21.45736122], [69.7804184, 21.45681], [69.78069305, 21.45681], [69.78069305, 21.45625114], [69.78098297, 21.45625114], [69.78098297, 21.45569038], [69.78125, 21.45569229], [69.78125, 21.45541573], [69.78180695, 21.45541954], [69.78180695, 21.45514107], [69.7820816, 21.45514107], [69.7820816, 21.45486069], [69.78263855, 21.45486069], [69.78263855, 21.45458031], [69.78291321, 21.45458221], [69.78291321, 21.45430565], [69.78320313, 21.45430946], [69.78320313, 21.4540329], [69.78347015, 21.4540329], [69.78347015, 21.45375061], [69.78375244, 21.45375061], [69.78375244, 21.45347023], [69.7840271, 21.45347023], [69.7840271, 21.45319366], [69.78430176, 21.45319366], [69.78430176, 21.4529171], [69.78485107, 21.45292282], [69.78485107, 21.45264053], [69.78542328, 21.45264053], [69.78542328, 21.45236015], [69.78624725, 21.45236015], [69.78624725, 21.45208168], [69.7868042, 21.45208359], [69.7868042, 21.45180511], [69.7876358, 21.45181274], [69.7876358, 21.45153236], [69.79152679, 21.45153236], [69.79152679, 21.45125008], [69.79402161, 21.45125008], [69.79402161, 21.45153236], [69.79651642, 21.45153236], [69.79651642, 21.45181274], [69.79792023, 21.45180511], [69.79792023, 21.45208359], [69.79878998, 21.45208168], [69.79985809, 21.45208168], [69.79985809, 21.45236015], [69.80014038, 21.45236015], [69.80014038, 21.45319366], [69.80097198, 21.45319366], [69.80097198, 21.45347023], [69.80014038, 21.45347023], [69.80014038, 21.45375061], [69.79957581, 21.45375061], [69.79957581, 21.4540329], [69.79985809, 21.4540329], [69.79985809, 21.45430946], [69.80014038, 21.45430565], [69.80014038, 21.45458221], [69.80041504, 21.45458221], [69.80041504, 21.45486069], [69.80097198, 21.45486069], [69.80097198, 21.45514107], [69.80152893, 21.45514107], [69.80152893, 21.45541954], [69.80180359, 21.45541573], [69.80180359, 21.45569229], [69.80208588, 21.45569229], [69.80208588, 21.45541573], [69.80264282, 21.45541954], [69.80264282, 21.45514107], [69.80319214, 21.45514107], [69.80319214, 21.45486069], [69.80458069, 21.45486069], [69.80458069, 21.45597458], [69.80319214, 21.45597076], [69.80319214, 21.45625114], [69.80152893, 21.45625114], [69.80152893, 21.45597076], [69.80097198, 21.45597458], [69.80097198, 21.45708466], [69.80124664, 21.45708084], [69.80124664, 21.45792007], [69.80152893, 21.45792007], [69.80152893, 21.45874977], [69.80180359, 21.45874977], [69.80180359, 21.45930672], [69.80208588, 21.45930672], [69.80208588, 21.45986176], [69.80236053, 21.45985985], [69.80236053, 21.46014023], [69.80264282, 21.46014023], [69.80264282, 21.46069908], [69.80291748, 21.46069908], [69.80291748, 21.46125031], [69.80319214, 21.46125031], [69.80319214, 21.46180916], [69.80347443, 21.46180534], [69.80347443, 21.46208382], [69.80374908, 21.46207809], [69.80374908, 21.46264076], [69.80403137, 21.46264076], [69.80403137, 21.46291924], [69.80430603, 21.46291733], [69.80430603, 21.46319389], [69.80486298, 21.46319389], [69.80486298, 21.46347237], [69.80513763, 21.46347046], [69.80513763, 21.46375084], [69.80486298, 21.46375084], [69.80486298, 21.4640274], [69.80430603, 21.4640274], [69.80430603, 21.46375084], [69.80403137, 21.46375084], [69.80403137, 21.46347046], [69.80374908, 21.46347237], [69.80374908, 21.46319389], [69.80319214, 21.46319389], [69.80319214, 21.46291733], [69.80291748, 21.46291924], [69.80291748, 21.46264076], [69.80264282, 21.46264076], [69.80264282, 21.46236038], [69.80236053, 21.46236038], [69.80236053, 21.46180916], [69.80208588, 21.46180916], [69.80208588, 21.46125031], [69.80179596, 21.46125031], [69.80179596, 21.46069908], [69.80152893, 21.46069908], [69.80152893, 21.46014023], [69.80124664, 21.46014023], [69.80124664, 21.45957947], [69.80097198, 21.45958328], [69.80097198, 21.45902824], [69.80069733, 21.45903015], [69.80069733, 21.45846939], [69.80041504, 21.4584713], [69.80041504, 21.45763969], [69.80014038, 21.45763969], [69.80014038, 21.45652962], [69.79985809, 21.45652962], [69.79985809, 21.45569038], [69.79958344, 21.45569229], [69.79958344, 21.45513916], [69.79930878, 21.45514107], [69.79930878, 21.45486069], [69.79902649, 21.45486069], [69.79902649, 21.45458031], [69.79875183, 21.45458221], [69.79875183, 21.45430565], [69.79846954, 21.45430946], [69.79846954, 21.4540329], [69.79792023, 21.4540329], [69.79792023, 21.45375061], [69.79763794, 21.45375061], [69.79763794, 21.45347023], [69.79708099, 21.45347023], [69.79708099, 21.45319366], [69.79624939, 21.45319366], [69.79624939, 21.4529171], [69.79569244, 21.45292282], [69.79569244, 21.45264053], [69.79347229, 21.45264053], [69.79347229, 21.45292282], [69.79180908, 21.4529171], [69.79180908, 21.45319366], [69.79125214, 21.45319366], [69.79125214, 21.45347023], [69.7859726, 21.45347023], [69.7859726, 21.45375061], [69.78514099, 21.45375061], [69.78514099, 21.45458221], [69.78485107, 21.45458031], [69.78485107, 21.45514107], [69.78430939, 21.45514107], [69.78430176, 21.45541954], [69.7840271, 21.45541763], [69.7840271, 21.45569229], [69.78375244, 21.45569229], [69.78375244, 21.45597458], [69.78347015, 21.45597076], [69.78347015, 21.45625114], [69.78320313, 21.45625114], [69.78320313, 21.45652962], [69.78291321, 21.45652962], [69.78291321, 21.45681], [69.7820816, 21.45680428], [69.7820816, 21.45708466], [69.78180695, 21.45708084], [69.78180695, 21.45736122], [69.78151703, 21.45736122], [69.78151703, 21.45763969], [69.78125, 21.45763969], [69.78125, 21.45792007], [69.78097534, 21.45791435], [69.78097534, 21.4584713], [69.78069305, 21.45846939], [69.78069305, 21.45874977], [69.77958679, 21.45874977], [69.77958679, 21.45930672], [69.7793045, 21.45930672], [69.7793045, 21.45986176], [69.77903748, 21.45985985], [69.77903748, 21.46042061], [69.77819824, 21.46042061], [69.77819824, 21.46069908], [69.77735901, 21.46069908], [69.77735901, 21.46097946], [69.77707672, 21.46097946], [69.77707672, 21.46125031], [69.77735901, 21.46125031], [69.77735901, 21.46153069], [69.7776413, 21.46153069], [69.7776413, 21.46180916], [69.7784729, 21.46180916], [69.7784729, 21.46236038], [69.77819824, 21.46236038], [69.77819824, 21.46291924], [69.77680206, 21.46291733], [69.77680206, 21.46319389], [69.7748642, 21.46319389], [69.7748642, 21.46263885], [69.77458191, 21.46264076], [69.77458191, 21.46207809], [69.7748642, 21.46208382], [69.7748642, 21.46125031], [69.77513885, 21.46125031], [69.77513885, 21.46069908], [69.77540588, 21.46069908], [69.77540588, 21.46042061], [69.7756958, 21.46042061], [69.7756958, 21.45985985], [69.77513885, 21.45985985], [69.77513885, 21.46014023], [69.77485657, 21.46014023], [69.77485657, 21.46042061], [69.77458191, 21.46042061], [69.77458191, 21.46069908], [69.77430725, 21.46069908], [69.77430725, 21.46125031], [69.77403259, 21.46125031], [69.77403259, 21.46153069], [69.77375031, 21.46153069], [69.77375031, 21.46180916], [69.77347565, 21.46180534], [69.77348328, 21.46236038], [69.77319336, 21.46236038], [69.77319336, 21.46264076], [69.77291107, 21.46264076], [69.77291107, 21.46291924], [69.77263641, 21.46291733], [69.77263641, 21.46347237], [69.77236176, 21.46347046], [69.77236176, 21.46375084], [69.7720871, 21.46375084], [69.7720871, 21.4640274], [69.77180481, 21.4640274], [69.77180481, 21.46458244], [69.77153015, 21.46458054], [69.77153015, 21.46486092], [69.77124786, 21.46486092], [69.77124786, 21.46542168], [69.77097321, 21.46541595], [69.77097321, 21.46569443], [69.77069092, 21.46569443], [69.77069092, 21.4659729], [69.77041626, 21.46596909], [69.77041626, 21.46624947], [69.7701416, 21.46624947], [69.7701416, 21.46653175], [69.76985931, 21.46652794], [69.76985931, 21.46708107], [69.76958466, 21.46708107], [69.76958466, 21.46736145], [69.76930237, 21.46735954], [69.76930237, 21.46763992], [69.76902771, 21.46763992], [69.76902771, 21.4679203], [69.76875305, 21.4679203], [69.76875305, 21.46820068], [69.76847076, 21.46819305], [69.76847076, 21.46847153], [69.76819611, 21.46846962], [69.76819611, 21.46875], [69.76790619, 21.46875], [69.76790619, 21.46903038], [69.76763916, 21.46903038], [69.76763916, 21.46931076], [69.7673645, 21.46930313], [69.7673645, 21.46958542], [69.76708221, 21.46958542], [69.76708221, 21.46986389], [69.76680756, 21.46986008], [69.76680756, 21.47014999], [69.7665329, 21.47014999], [69.7665329, 21.47042084], [69.76625061, 21.47041512], [69.76625061, 21.4706955], [69.76597595, 21.4706955], [69.76597595, 21.47097206], [69.76568604, 21.47097015], [69.76568604, 21.47153091], [69.76541901, 21.47153091], [69.76541901, 21.47180939], [69.76513672, 21.47180367], [69.76513672, 21.47208595], [69.76486206, 21.47208023], [69.76486206, 21.47236061], [69.76457977, 21.47236061], [69.76457977, 21.47264099], [69.76431274, 21.47264099], [69.76431274, 21.47291946], [69.76403046, 21.47291756], [69.76403046, 21.47319412], [69.76374817, 21.47319412], [69.76374817, 21.4734726], [69.76346588, 21.47347069], [69.76346588, 21.47375107], [69.76319122, 21.47375107], [69.76319122, 21.47402954], [69.76291656, 21.47402954], [69.76291656, 21.47430992], [69.76264191, 21.47430611], [69.76264191, 21.47458267], [69.76235962, 21.47458076], [69.76235962, 21.47486115], [69.76208496, 21.47486115], [69.76209259, 21.47513962], [69.76180267, 21.47513962], [69.76180267, 21.47541809], [69.76152802, 21.47541618], [69.76152802, 21.47569466], [69.76125336, 21.47569466], [69.76125336, 21.47597313], [69.76097107, 21.47595978], [69.76097107, 21.47624969], [69.76069641, 21.47624969], [69.76069641, 21.47680473], [69.76041412, 21.47680473], [69.76041412, 21.47708321], [69.76013947, 21.47708321], [69.76013947, 21.47736168], [69.75985718, 21.47735977], [69.75985718, 21.47763824], [69.75958252, 21.47763824], [69.75958252, 21.47792244], [69.75930786, 21.47792244], [69.75930786, 21.47820282], [69.75902557, 21.47819519], [69.75902557, 21.47847176], [69.75875092, 21.47847176], [69.75875092, 21.47875023], [69.75846863, 21.47875023], [69.75846863, 21.4790287], [69.75818634, 21.47901917], [69.75818634, 21.4793129], [69.75791931, 21.47930527], [69.75791931, 21.47958374], [69.75763702, 21.47958183], [69.75763702, 21.47986031], [69.75736237, 21.47986031], [69.75736237, 21.48014259], [69.75708008, 21.48014259], [69.75708008, 21.48042107], [69.75680542, 21.48041725], [69.75680542, 21.48069382], [69.75653076, 21.48069382], [69.75653076, 21.48097229], [69.75624847, 21.48097038], [69.75624847, 21.48125076], [69.75596619, 21.48125076], [69.75596619, 21.48153114], [69.75569153, 21.48153114], [69.75569153, 21.48180962], [69.75541687, 21.48180962], [69.75541687, 21.48209], [69.75514221, 21.48209], [69.75514221, 21.48264122], [69.75486755, 21.48264122], [69.75486755, 21.48291969], [69.75458527, 21.48291588], [69.75458527, 21.48319244], [69.75430298, 21.48319244], [69.75430298, 21.48347473], [69.75402832, 21.48347092], [69.75402832, 21.48374939], [69.75374603, 21.48374939], [69.75374603, 21.48402977], [69.75347137, 21.48402977], [69.75347137, 21.48431015], [69.75319672, 21.48430634], [69.75319672, 21.48458481], [69.75291443, 21.48458481], [69.75291443, 21.48486137], [69.75263977, 21.48485947], [69.75263977, 21.48514938], [69.75235748, 21.48514938], [69.75235748, 21.48542023], [69.75208282, 21.48541451], [69.75208282, 21.48569679], [69.75180817, 21.48569679], [69.75180817, 21.48597145], [69.75152588, 21.48596954], [69.75152588, 21.48624992], [69.75125122, 21.48624992], [69.75125122, 21.4865303], [69.75096893, 21.4865303], [69.75096893, 21.48681068], [69.75069427, 21.48680687], [69.75069427, 21.48736191], [69.75041962, 21.48736], [69.75041962, 21.48764038], [69.75013733, 21.48764038], [69.75013733, 21.48792076], [69.74986267, 21.48791885], [69.74986267, 21.48819351], [69.74958038, 21.48819542], [69.74958038, 21.48847198], [69.74930573, 21.48847198], [69.74931335, 21.48875046], [69.74903107, 21.48875046], [69.74903107, 21.48903084], [69.74874115, 21.48903084], [69.74874115, 21.48930931], [69.74847412, 21.4893055], [69.74847412, 21.48958397], [69.74819183, 21.48957825], [69.74819183, 21.48986053], [69.74791718, 21.48986053], [69.74791718, 21.49014091], [69.74764252, 21.49014091], [69.74764252, 21.49041939], [69.74736023, 21.49041748], [69.74736023, 21.49069405], [69.7470932, 21.49068832], [69.7470932, 21.49124908], [69.74680328, 21.49124908], [69.74680328, 21.49152946], [69.74652863, 21.49152946], [69.74652863, 21.49181175], [69.74624634, 21.49180603], [69.74624634, 21.4920826], [69.74597168, 21.49208069], [69.74597168, 21.49235916], [69.74569702, 21.49235916], [69.74569702, 21.49263954], [69.7454071, 21.49263954], [69.7454071, 21.49292183], [69.74514008, 21.49291611], [69.74514008, 21.49319458], [69.74485779, 21.49319458], [69.74485779, 21.49347115], [69.74458313, 21.49347115], [69.74458313, 21.49374962], [69.74430847, 21.49374962], [69.74430847, 21.49403191], [69.74402618, 21.49402809], [69.74402618, 21.49430466], [69.74375153, 21.49430466], [69.74375153, 21.49458122], [69.74346924, 21.49458122], [69.74346924, 21.49514008], [69.74318695, 21.49514008], [69.74318695, 21.49542046], [69.74292755, 21.49542046], [69.74292755, 21.49570084], [69.74263763, 21.49569321], [69.74263763, 21.49597168], [69.74236298, 21.49596977], [69.74236298, 21.49625015], [69.74208069, 21.49625015], [69.74208069, 21.49653053], [69.74180603, 21.49653053], [69.74180603, 21.49681091], [69.74153137, 21.49681091], [69.74153137, 21.49708939], [69.74124908, 21.49708939], [69.74124908, 21.49736023], [69.7409668, 21.49736023], [69.7409668, 21.49764061], [69.74069214, 21.49764061], [69.74069214, 21.49792099], [69.74041748, 21.49791718], [69.74041748, 21.49819565], [69.74013519, 21.49819565], [69.74013519, 21.49847221], [69.73986816, 21.49847031], [69.73986816, 21.49903107], [69.73958588, 21.49903107], [69.73958588, 21.49930954], [69.73930359, 21.49930763], [69.73930359, 21.4995842], [69.73902893, 21.49958038], [69.73902893, 21.49986076], [69.73874664, 21.49986076], [69.73874664, 21.50013924], [69.73847198, 21.5001297], [69.73847198, 21.50041962], [69.73819733, 21.50041771], [69.73819733, 21.50069427], [69.73791504, 21.50069427], [69.73791504, 21.50097275], [69.73764038, 21.50097084], [69.73764038, 21.50152969], [69.73735809, 21.50152969], [69.73735809, 21.50180817], [69.73708344, 21.50180626], [69.73708344, 21.50208282], [69.73680878, 21.50208282], [69.73680878, 21.5023613], [69.73652649, 21.50235939], [69.73652649, 21.50291824], [69.73625183, 21.50291634], [69.73625183, 21.50319481], [69.73596954, 21.50319481], [69.73596954, 21.50347137], [69.73568726, 21.50346756], [69.73568726, 21.50374985], [69.73542023, 21.50374985], [69.73542023, 21.50402832], [69.73513794, 21.50402832], [69.73513794, 21.50458336], [69.73486328, 21.50458336], [69.73486328, 21.50486183], [69.73458099, 21.50486183], [69.73458099, 21.5051403], [69.73430634, 21.5051403], [69.73430634, 21.50542259], [69.73402405, 21.50541687], [69.73402405, 21.50597191], [69.73374176, 21.50597191], [69.73374176, 21.50625992], [69.7334671, 21.50625992], [69.7334671, 21.50653267], [69.73319244, 21.50653267], [69.73319244, 21.50681114], [69.73291779, 21.50681114], [69.73291779, 21.50736046], [69.73236084, 21.50736046], [69.73236084, 21.50764275], [69.73208618, 21.50763893], [69.73208618, 21.50819206], [69.73179626, 21.50819016], [69.73179626, 21.50875282], [69.73152924, 21.50875282], [69.73152924, 21.50902939], [69.73124695, 21.50902939], [69.73124695, 21.50932121], [69.73097229, 21.50930405], [69.73097229, 21.50958252], [69.73069763, 21.50958061], [69.73069763, 21.50986099], [69.73041534, 21.50986099], [69.73042297, 21.51013947], [69.7298584, 21.51013947], [69.7298584, 21.51097488], [69.72957611, 21.51097107], [69.72957611, 21.51124954], [69.72930908, 21.51124954], [69.72930908, 21.5118103], [69.72902679, 21.51180649], [69.72902679, 21.51208305], [69.72875214, 21.51208305], [69.72875214, 21.51236153], [69.72846985, 21.51235962], [69.72846985, 21.51264], [69.72820282, 21.51264], [69.72820282, 21.51292038], [69.7279129, 21.51292038], [69.7279129, 21.51320076], [69.72763824, 21.51319695], [69.72763824, 21.5134716], [69.72735596, 21.5134697], [69.72735596, 21.51375008], [69.7270813, 21.51375008], [69.7270813, 21.51403046], [69.72680664, 21.51403046], [69.72680664, 21.51431084], [69.72652435, 21.51430511], [69.72652435, 21.51458359], [69.72624969, 21.51458359], [69.72624969, 21.51486206], [69.72597504, 21.51486206], [69.72597504, 21.51513863], [69.72569275, 21.515131], [69.72569275, 21.51542091], [69.72541809, 21.5154171], [69.72541809, 21.51569366], [69.7251358, 21.51569366], [69.7251358, 21.51597214], [69.72486115, 21.51597023], [69.72486115, 21.51625061], [69.72458649, 21.51625061], [69.72458649, 21.51652908], [69.72429657, 21.51652908], [69.72429657, 21.51681137], [69.72402954, 21.51680565], [69.72402954, 21.51708412], [69.72319794, 21.5170784], [69.72319794, 21.51791954], [69.72292328, 21.51791954], [69.72292328, 21.51820183], [69.72264099, 21.5181942], [69.72264099, 21.51847267], [69.7223587, 21.51847076], [69.7223587, 21.51874924], [69.72207642, 21.51874924], [69.72207642, 21.5193119], [69.72180939, 21.51930618], [69.72180176, 21.51958275], [69.7215271, 21.51958275], [69.7215271, 21.51986122], [69.72125244, 21.51986122], [69.72125244, 21.52013969], [69.72097015, 21.52013969], [69.72097015, 21.52042007], [69.7206955, 21.52041626], [69.7206955, 21.52069473], [69.72041321, 21.52069473], [69.72041321, 21.5209713], [69.72013855, 21.52096939], [69.72013855, 21.52126122], [69.71985626, 21.52126122], [69.71985626, 21.52153015], [69.7195816, 21.52152824], [69.7195816, 21.52180481], [69.71930695, 21.52180481], [69.71930695, 21.52208138], [69.71902466, 21.52208138], [69.71902466, 21.52236366], [69.71875763, 21.52235985], [69.71875763, 21.52264023], [69.71848297, 21.52264023], [69.71848297, 21.52292061], [69.71819305, 21.52292061], [69.71819305, 21.52320099], [69.7179184, 21.52319336], [69.7179184, 21.52347183], [69.71763611, 21.52346992], [69.71763611, 21.52375031], [69.71736145, 21.52375031], [69.71736145, 21.52403069], [69.71708679, 21.52402687], [69.71708679, 21.52430344], [69.71652985, 21.52430344], [69.71652985, 21.52458572], [69.71624756, 21.52458], [69.71624756, 21.52514076], [69.7159729, 21.52514076], [69.7159729, 21.52542114], [69.71569824, 21.52541733], [69.71569824, 21.5256958], [69.71541595, 21.5256958], [69.71541595, 21.52597237], [69.7151413, 21.52597046], [69.7151413, 21.52625084], [69.71485901, 21.52625084], [69.71485901, 21.52680969], [69.71458435, 21.52680779], [69.71458435, 21.52708244], [69.71430206, 21.527071], [69.71430206, 21.52736092], [69.7140274, 21.52736092], [69.7140274, 21.52763939], [69.71375275, 21.52763939], [69.71375275, 21.52791977], [69.71347046, 21.52791786], [69.71347046, 21.52819443], [69.7131958, 21.52819443], [69.7131958, 21.5284729], [69.71290588, 21.52847099], [69.71290588, 21.52902985], [69.71263885, 21.52902985], [69.71263885, 21.52930832], [69.7123642, 21.52930641], [69.7123642, 21.52986145], [69.71208191, 21.52985954], [69.71208191, 21.5304184], [69.71180725, 21.53041649], [69.71180725, 21.53097153], [69.71152496, 21.53097153], [69.71153259, 21.53124809], [69.71125031, 21.53124809], [69.71125031, 21.53208351], [69.71097565, 21.53208351], [69.71097565, 21.53236008], [69.71153259, 21.53236008], [69.71153259, 21.53264046], [69.71180725, 21.53264046], [69.71180725, 21.53292274], [69.71208191, 21.53292274], [69.71208191, 21.53320122], [69.7123642, 21.53319359], [69.7123642, 21.53347015], [69.71291351, 21.53347015], [69.71291351, 21.53319359], [69.71347046, 21.53319359], [69.71347046, 21.53347015], [69.71375275, 21.53347015], [69.71375275, 21.53375053], [69.71485901, 21.53375053], [69.71485901, 21.53403282], [69.71541595, 21.53403282], [69.71541595, 21.53430939], [69.7159729, 21.53430557], [69.7159729, 21.53458214], [69.71708679, 21.53458023], [69.71708679, 21.5351429], [69.71819305, 21.5351429], [69.71819305, 21.53541946], [69.71930695, 21.53541756], [69.71930695, 21.53569221], [69.71971893, 21.53569221], [69.71986389, 21.53569221], [69.71986389, 21.5359745], [69.72041321, 21.5359745], [69.72041321, 21.53624916], [69.72070313, 21.53623962], [69.72070313, 21.53680992], [69.72097015, 21.53680992], [69.72097015, 21.53763962], [69.72125244, 21.53763962], [69.72125244, 21.53792], [69.7215271, 21.53792], [69.7215271, 21.53903008], [69.72208405, 21.53902817], [69.72208405, 21.53958321], [69.7223587, 21.53957939], [69.7223587, 21.54070091], [69.72291565, 21.54069519], [69.72291565, 21.54125023], [69.7234726, 21.54125023], [69.7234726, 21.54180908], [69.7251358, 21.54180527], [69.7251358, 21.54208374], [69.72541809, 21.54208374], [69.72541809, 21.54180527], [69.72597504, 21.54180527], [69.72597504, 21.54208374], [69.72624969, 21.54208374], [69.72624969, 21.54180527], [69.7270813, 21.54180908], [69.7270813, 21.54153061], [69.72875214, 21.54153061], [69.72875214, 21.54180908], [69.72902679, 21.54180527], [69.72902679, 21.54208374], [69.72957611, 21.54207993], [69.72957611, 21.54291916], [69.72930908, 21.54291916], [69.72930908, 21.54431152], [69.72902679, 21.54431152], [69.72902679, 21.54486084], [69.72875214, 21.54486084], [69.72875214, 21.54569435], [69.72846985, 21.54568863], [69.72846985, 21.54652977], [69.72819519, 21.54652786], [69.72819519, 21.5470829], [69.7279129, 21.5470829], [69.7279129, 21.54792023], [69.72763824, 21.54792023], [69.72763824, 21.54874992], [69.72736359, 21.54874992], [69.72736359, 21.54958534], [69.7270813, 21.54958534], [69.7270813, 21.5506897], [69.72680664, 21.55070114], [69.72680664, 21.55153084], [69.72651672, 21.55153084], [69.72651672, 21.55264091], [69.72624969, 21.55263901], [69.72624969, 21.55347252], [69.72597504, 21.55347252], [69.72597504, 21.5545826], [69.72569275, 21.55458069], [69.72569275, 21.55541992], [69.72597504, 21.55541611], [69.72597504, 21.55569458], [69.72651672, 21.55569077], [69.72651672, 21.55652809], [69.7270813, 21.55652809], [69.7270813, 21.55680466], [69.72736359, 21.55680466], [69.72736359, 21.55708313], [69.7279129, 21.55708122], [69.7279129, 21.55736923], [69.72820282, 21.55736923], [69.72820282, 21.55792236], [69.72875214, 21.55791664], [69.72875214, 21.55847168], [69.72930908, 21.55847168], [69.72930908, 21.55875015], [69.72957611, 21.55875015], [69.72957611, 21.55903244], [69.73042297, 21.55903244], [69.73042297, 21.55931282], [69.73124695, 21.55930519], [69.73124695, 21.55958366], [69.73152924, 21.55958176], [69.73152924, 21.55986023], [69.73179626, 21.55986023], [69.73179626, 21.56014061], [69.73208618, 21.56014061], [69.73208618, 21.56043053], [69.73319244, 21.56041718], [69.73319244, 21.56069374], [69.73347473, 21.56069374], [69.73347473, 21.56097221], [69.73401642, 21.56097031], [69.73401642, 21.56125069], [69.73458099, 21.56125069], [69.73458099, 21.56153107], [69.73513794, 21.56153107], [69.73513794, 21.56125069], [69.73568726, 21.56125069], [69.73568726, 21.56180954], [69.73596954, 21.56180573], [69.73596954, 21.56208229], [69.73735809, 21.56208038], [69.73735809, 21.56236076], [69.73764038, 21.56236076], [69.73764038, 21.56208038], [69.73819733, 21.56208038], [69.73819733, 21.56236076], [69.73929596, 21.56236076], [69.73929596, 21.56208038], [69.74013519, 21.56208229], [69.74013519, 21.56180573], [69.7409668, 21.56180954], [69.7409668, 21.56153107], [69.74180603, 21.56153107], [69.74180603, 21.56180954], [69.74263763, 21.56180573], [69.74263763, 21.56208229], [69.74318695, 21.56208038], [69.74318695, 21.56236076], [69.74346924, 21.56236076], [69.74346924, 21.56208038], [69.74401855, 21.56215477], [69.74402618, 21.56236076], [69.74485779, 21.56236076], [69.74485779, 21.56264114], [69.7454071, 21.56264114], [69.7454071, 21.56236076], [69.74652863, 21.56236076], [69.74652863, 21.56208038], [69.74736023, 21.56208229], [69.74736023, 21.56180573], [69.7470932, 21.56180954], [69.7470932, 21.56153107], [69.74764252, 21.56153107], [69.74764252, 21.56125069], [69.74819183, 21.56125069], [69.74819183, 21.56153107], [69.74874115, 21.56153107], [69.74874115, 21.56125069], [69.74931335, 21.56125069], [69.74931335, 21.56153107], [69.74958038, 21.56153107], [69.74958038, 21.56180954], [69.74986267, 21.56180573], [69.74986267, 21.56208229], [69.75013733, 21.56208038], [69.75013733, 21.56236076], [69.75041962, 21.56236076], [69.75041962, 21.56264114], [69.75068665, 21.56264114], [69.75068665, 21.56291962], [69.75096893, 21.5629158], [69.75096893, 21.56319237], [69.75125122, 21.56318283], [69.75125122, 21.56431007], [69.75096893, 21.56430435], [69.75096893, 21.56458473], [69.75069427, 21.56458473], [69.75069427, 21.5648613], [69.75013733, 21.56485939], [69.75013733, 21.56542015], [69.74986267, 21.56541443], [69.74986267, 21.56569672], [69.74958038, 21.56569672], [69.74958038, 21.56680679], [69.74930573, 21.56680679], [69.74930573, 21.56708336], [69.74903107, 21.56707954], [69.74903107, 21.56792068], [69.74874115, 21.56792068], [69.74874115, 21.56903076], [69.74819183, 21.56903076], [69.74819183, 21.56930923], [69.74791718, 21.56930923], [69.74791718, 21.56986046], [69.74764252, 21.56986046], [69.74764252, 21.57014084], [69.74736023, 21.57014084], [69.74736023, 21.57097244], [69.74708557, 21.57097244], [69.74708557, 21.57125092], [69.74736023, 21.57125092], [69.74736023, 21.57152939], [69.7470932, 21.57152939], [69.7470932, 21.57292175], [69.74736023, 21.57291603], [69.74736023, 21.57347107], [69.74764252, 21.57347107], [69.74764252, 21.57403183], [69.74791718, 21.57402802], [69.74791718, 21.57486153], [69.74847412, 21.57486153], [69.74847412, 21.57458115], [69.74874878, 21.57458115], [69.74874878, 21.57402802], [69.74903107, 21.57403183], [69.74903107, 21.57347107], [69.74930573, 21.57347107], [69.74930573, 21.5731945], [69.75096893, 21.5731945], [69.75096893, 21.57347107], [69.75152588, 21.57347107], [69.75152588, 21.57625008], [69.75180817, 21.57625008], [69.75180817, 21.57653046], [69.75208282, 21.57653046], [69.75208282, 21.57681084], [69.75235748, 21.57680321], [69.75235748, 21.57708549], [69.75263977, 21.57707977], [69.75263977, 21.57736015], [69.75347137, 21.57736015], [69.75347137, 21.57764053], [69.75430298, 21.57764053], [69.75430298, 21.57792091], [69.75624847, 21.57792091], [69.75624847, 21.57764053], [69.75653076, 21.57764053], [69.75653076, 21.57736015], [69.75708008, 21.57736015], [69.75708008, 21.57707977], [69.75818634, 21.57707977], [69.75818634, 21.57792091], [69.75846863, 21.57792091], [69.75846863, 21.57903099], [69.75875092, 21.57903099], [69.75875092, 21.57930946], [69.75930786, 21.57930756], [69.75930786, 21.57958412], [69.75958252, 21.57958412], [69.75958252, 21.57930756], [69.75985718, 21.57930946], [69.75985718, 21.57903099], [69.76013947, 21.57903099], [69.76013947, 21.57930946], [69.76125336, 21.57930756], [69.76125336, 21.57958412], [69.76208496, 21.57958412], [69.76208496, 21.57930756], [69.76235962, 21.57930946], [69.76235962, 21.57903099], [69.76264191, 21.57903099], [69.76264191, 21.57875061], [69.76291656, 21.57875061], [69.76291656, 21.57847023], [69.76403046, 21.57847214], [69.76403046, 21.57875061], [69.76431274, 21.57875061], [69.76431274, 21.58014107], [69.76403046, 21.58013916], [69.76403046, 21.58208275], [69.76374817, 21.58208084], [69.76374817, 21.58402824], [69.76403046, 21.58402824], [69.76403046, 21.58458328], [69.76431274, 21.58457756], [69.76431274, 21.58514023], [69.76457977, 21.58514023], [69.76457977, 21.58625031], [69.76486206, 21.58625031], [69.76486206, 21.58903122], [69.76431274, 21.58903122], [69.76431274, 21.58930969], [69.76374817, 21.58930969], [69.76374817, 21.59013939], [69.76347351, 21.59013939], [69.76347351, 21.59208488], [69.76374817, 21.59208107], [69.76374817, 21.59375], [69.76403046, 21.59375], [69.76403046, 21.59486198], [69.76374817, 21.59486198], [69.76374817, 21.59597206], [69.76347351, 21.59597206], [69.76347351, 21.59569359], [69.76235962, 21.59569359], [69.76235962, 21.59597206], [69.76125336, 21.59597206], [69.76125336, 21.59569359], [69.75958252, 21.59569359], [69.75958252, 21.59541893], [69.7590332, 21.59542084], [69.7590332, 21.59514046], [69.75818634, 21.59514046], [69.75818634, 21.59431076], [69.75763702, 21.59431076], [69.75763702, 21.59375], [69.75791168, 21.59375], [69.75791168, 21.59263992], [69.75708008, 21.59263992], [69.75708008, 21.5929203], [69.75681305, 21.5929203], [69.75681305, 21.59320068], [69.75653076, 21.59320068], [69.75653076, 21.59348106], [69.75681305, 21.59348106], [69.75681305, 21.59403038], [69.75653076, 21.59403038], [69.75653076, 21.59375], [69.75624847, 21.59375], [69.75624847, 21.59348106], [69.75596619, 21.59348106], [69.75596619, 21.59375], [69.75569153, 21.59375], [69.75569153, 21.59431076], [69.75597382, 21.59430695], [69.75597382, 21.59458351], [69.75569153, 21.5945797], [69.75569153, 21.59542084], [69.75624847, 21.59541893], [69.75624847, 21.59569359], [69.75597382, 21.59569359], [69.75597382, 21.59819412], [69.75569153, 21.5981884], [69.75569153, 21.59902954], [69.75541687, 21.59902954], [69.75541687, 21.59931183], [69.75569153, 21.59931183], [69.75569153, 21.60013962], [69.75514221, 21.60013962], [69.75514221, 21.60042191], [69.75541687, 21.60042191], [69.75541687, 21.60153008], [69.75569153, 21.60152817], [69.75569153, 21.60569572], [69.75541687, 21.60569572], [69.75541687, 21.60708427], [69.75430298, 21.60708046], [69.75430298, 21.60736084], [69.75402832, 21.60736084], [69.75402832, 21.60764122], [69.75374603, 21.60764122], [69.75374603, 21.60791969], [69.75347137, 21.60791779], [69.75347137, 21.60819435], [69.75319672, 21.60819054], [69.75319672, 21.60848045], [69.75235748, 21.60848045], [69.75235748, 21.60874939], [69.75180817, 21.60874939], [69.75180817, 21.60902977], [69.75208282, 21.60902977], [69.75208282, 21.6095829], [69.75180817, 21.6095829], [69.75180817, 21.60986137], [69.75152588, 21.60985947], [69.75152588, 21.61013985], [69.75096893, 21.61013985], [69.75096893, 21.61041832], [69.75069427, 21.61041641], [69.75069427, 21.61208344], [69.75096893, 21.61208344], [69.75096893, 21.6131916], [69.75013733, 21.61319542], [69.75013733, 21.61347008], [69.74958038, 21.61347008], [69.74958038, 21.61431122], [69.74986267, 21.61431122], [69.74986267, 21.61680984], [69.75013733, 21.61680412], [69.75013733, 21.6170826], [69.75041962, 21.61708069], [69.75041962, 21.61736107], [69.75096893, 21.61736107], [69.75096893, 21.61765099], [69.75125122, 21.61765099], [69.75125122, 21.61791992], [69.75152588, 21.6179142], [69.75152588, 21.61819649], [69.75180817, 21.61819649], [69.75180817, 21.61847305], [69.75152588, 21.61847115], [69.75152588, 21.61874962], [69.75068665, 21.61874962], [69.75068665, 21.61847115], [69.75013733, 21.61847305], [69.75013733, 21.61819649], [69.74986267, 21.61819649], [69.74986267, 21.61763954], [69.74958038, 21.61763954], [69.74958038, 21.61819649], [69.74930573, 21.61819649], [69.74930573, 21.61847305], [69.74903107, 21.61847115], [69.74903107, 21.61874962], [69.74846649, 21.61874962], [69.74846649, 21.61903], [69.74819183, 21.61902618], [69.74819183, 21.61930656], [69.74791718, 21.61930656], [69.74791718, 21.6198616], [69.74764252, 21.6198597], [69.74764252, 21.62042046], [69.74736023, 21.62041855], [69.74736023, 21.62097168], [69.7470932, 21.62096977], [69.7470932, 21.62153053], [69.74680328, 21.62152863], [69.74680328, 21.62208366], [69.74652863, 21.62207985], [69.74652863, 21.62291908], [69.74624634, 21.62291908], [69.74624634, 21.62375069], [69.74597168, 21.62375069], [69.74597168, 21.62431145], [69.74569702, 21.62431145], [69.74569702, 21.62513924], [69.74541473, 21.62513924], [69.74541473, 21.6273613], [69.74569702, 21.6273613], [69.74569702, 21.63097191], [69.7454071, 21.63097], [69.7454071, 21.63265038], [69.74514008, 21.63263893], [69.74514008, 21.63319588], [69.74485779, 21.63319016], [69.74485779, 21.63375092], [69.74458313, 21.63375092], [69.74458313, 21.63430977], [69.74430847, 21.63430977], [69.74430847, 21.63486099], [69.74402618, 21.63486099], [69.74402618, 21.63541985], [69.74375153, 21.63541794], [69.74375153, 21.63597298], [69.74346924, 21.63597107], [69.74346924, 21.63624954], [69.74318695, 21.63624954], [69.74318695, 21.63652992], [69.74291992, 21.63652992], [69.74291992, 21.63708305], [69.74263763, 21.63708305], [69.74263763, 21.63736153], [69.74236298, 21.63735962], [69.74236298, 21.63763809], [69.74208069, 21.63763809], [69.74208069, 21.63820267], [69.74180603, 21.63819504], [69.74180603, 21.6384716], [69.74153137, 21.63845825], [69.74153137, 21.63875008], [69.74124908, 21.63875008], [69.74124908, 21.63903046], [69.7409668, 21.63903046], [69.7409668, 21.63931274], [69.74069214, 21.63930511], [69.74069214, 21.63958359], [69.73902893, 21.63958359], [69.73902893, 21.63930511], [69.73764038, 21.63930511], [69.73764038, 21.63986015], [69.73735809, 21.63986015], [69.73735809, 21.64042282], [69.73708344, 21.6404171], [69.73708344, 21.64208221], [69.73680878, 21.64208221], [69.73680878, 21.64347458], [69.73707581, 21.64347076], [69.73707581, 21.64375114], [69.73764038, 21.64375114], [69.73764038, 21.64347076], [69.73792267, 21.64347076], [69.73792267, 21.64402962], [69.73735809, 21.64402962], [69.73735809, 21.64459038], [69.73708344, 21.64458275], [69.73708344, 21.6459713], [69.73680878, 21.6459713], [69.73680878, 21.64736176], [69.73707581, 21.64735985], [69.73707581, 21.64792061], [69.73735809, 21.6479187], [69.73735809, 21.64847183], [69.73764038, 21.64846992], [69.73764038, 21.65041924], [69.73680878, 21.65041733], [69.73680878, 21.65069389], [69.73625183, 21.65069389], [69.73625183, 21.65097237], [69.73569489, 21.65097237], [69.73569489, 21.65069389], [69.73430634, 21.65069389], [69.73430634, 21.64986038], [69.73401642, 21.64986038], [69.73401642, 21.64930916], [69.73430634, 21.64930916], [69.73430634, 21.64875031], [69.73458099, 21.64875031], [69.73458099, 21.64819908], [69.73513794, 21.64819908], [69.73513794, 21.64764977], [69.73486328, 21.64764977], [69.73486328, 21.64735985], [69.73458099, 21.64736176], [69.73458099, 21.64680672], [69.73430634, 21.64680672], [69.73430634, 21.64652824], [69.73401642, 21.64653015], [69.73401642, 21.64624977], [69.73374176, 21.64624977], [69.73374176, 21.64596939], [69.73347473, 21.6459713], [69.73347473, 21.64569664], [69.73319244, 21.64569664], [69.73319244, 21.64541435], [69.73264313, 21.64542007], [69.73264313, 21.64513969], [69.73236084, 21.64513969], [69.73236084, 21.64431], [69.73208618, 21.64431], [69.73208618, 21.64319038], [69.73152924, 21.64319229], [69.73152924, 21.64291573], [69.73179626, 21.64291954], [69.73179626, 21.64236069], [69.73152924, 21.64236069], [69.73152924, 21.6415329], [69.73124695, 21.6415329], [69.73124695, 21.64125061], [69.73069763, 21.64125061], [69.73069763, 21.64097023], [69.73041534, 21.64097023], [69.73041534, 21.64069366], [69.72958374, 21.64069366], [69.72958374, 21.64097023], [69.72902679, 21.64097023], [69.72902679, 21.64125061], [69.72820282, 21.64125061], [69.72820282, 21.6415329], [69.72763824, 21.6415329], [69.72763824, 21.64180946], [69.72680664, 21.64180946], [69.72680664, 21.6415329], [69.72651672, 21.6415329], [69.72651672, 21.64069176], [69.72680664, 21.64069366], [69.72680664, 21.63986015], [69.7270813, 21.63986015], [69.7270813, 21.63931274], [69.72735596, 21.63931274], [69.72735596, 21.63845825], [69.72763824, 21.6384716], [69.72763824, 21.63819504], [69.72820282, 21.63820267], [69.72820282, 21.63791847], [69.7298584, 21.63791847], [69.7298584, 21.63763809], [69.73014069, 21.63763809], [69.73014069, 21.63735962], [69.73041534, 21.63736153], [69.73041534, 21.63708305], [69.73069763, 21.63708305], [69.73069763, 21.63652992], [69.73014069, 21.63652992], [69.73014069, 21.63597107], [69.7298584, 21.63597298], [69.7298584, 21.6356945], [69.72930908, 21.6356945], [69.72930908, 21.63541794], [69.72902679, 21.63541985], [69.72902679, 21.63402939], [69.72846985, 21.63402939], [69.72846985, 21.63375092], [69.72819519, 21.63375092], [69.72819519, 21.63347244], [69.7279129, 21.63347244], [69.7279129, 21.63319588], [69.7270813, 21.63319588], [69.7270813, 21.6329174], [69.72624969, 21.63292122], [69.72624969, 21.63265038], [69.72541809, 21.63265038], [69.72541809, 21.63236046], [69.72458649, 21.63236046], [69.72458649, 21.63265038], [69.72429657, 21.63265038], [69.72429657, 21.63292122], [69.72402954, 21.6329174], [69.72402954, 21.63319588], [69.72374725, 21.63319588], [69.72374725, 21.63347244], [69.7234726, 21.63347054], [69.7234726, 21.63375092], [69.72319794, 21.63375092], [69.72319794, 21.63402939], [69.72292328, 21.63402939], [69.72292328, 21.63430977], [69.7223587, 21.63430786], [69.7223587, 21.63458252], [69.72180176, 21.63458061], [69.72180176, 21.63486099], [69.7215271, 21.63486099], [69.7215271, 21.63513947], [69.72097015, 21.63513947], [69.72097015, 21.63541985], [69.72013855, 21.63541794], [69.72013855, 21.6356945], [69.7195816, 21.6356945], [69.7195816, 21.63597298], [69.71875, 21.63597298], [69.71875763, 21.63624954], [69.71819305, 21.63624954], [69.71819305, 21.6368084], [69.7179184, 21.6368084], [69.7179184, 21.63763809], [69.71819305, 21.63763809], [69.71819305, 21.63903046], [69.7179184, 21.63902855], [69.7179184, 21.63986015], [69.71736145, 21.63986015], [69.71736145, 21.64014053], [69.71485901, 21.64014053], [69.71485901, 21.63986015], [69.71458435, 21.63986015], [69.71458435, 21.63819504], [69.71485901, 21.63820267], [69.71485901, 21.6368084], [69.7151413, 21.63680077], [69.7151413, 21.63624954], [69.71541595, 21.63624954], [69.71541595, 21.63597107], [69.71569061, 21.63597298], [69.71569824, 21.63541794], [69.7159729, 21.63541985], [69.7159729, 21.63513947], [69.71736145, 21.63513947], [69.71736145, 21.63319016], [69.71708679, 21.63319588], [69.71708679, 21.6329174], [69.71679688, 21.63292122], [69.71679688, 21.63265038], [69.71652985, 21.63265038], [69.71652985, 21.63236046], [69.71457672, 21.63236046], [69.71457672, 21.63208008], [69.71347046, 21.63208008], [69.71347046, 21.63292122], [69.71375275, 21.63292122], [69.71375275, 21.63402939], [69.71347046, 21.63402939], [69.71347046, 21.63430977], [69.7131958, 21.63430977], [69.7131958, 21.63486099], [69.71347046, 21.63486099], [69.71347046, 21.63513947], [69.7131958, 21.63513947], [69.7131958, 21.63541985], [69.71291351, 21.63541794], [69.71291351, 21.6356945], [69.71263885, 21.63569069], [69.71263885, 21.63624954], [69.71235657, 21.63624954], [69.71235657, 21.6368084], [69.71208191, 21.63680649], [69.71208191, 21.63708305], [69.71180725, 21.63708115], [69.71180725, 21.63763809], [69.70986176, 21.63763809], [69.70986176, 21.63735962], [69.7095871, 21.63736153], [69.7095871, 21.63708305], [69.70929718, 21.63708115], [69.70929718, 21.63791847], [69.70903015, 21.63791847], [69.70903015, 21.63820267], [69.70929718, 21.63820267], [69.70929718, 21.63903046], [69.7095871, 21.63903046], [69.7095871, 21.63875008], [69.70986176, 21.63875008], [69.70986176, 21.63986015], [69.7095871, 21.63986015], [69.7095871, 21.64014053], [69.70986176, 21.64014053], [69.70986176, 21.64042282], [69.7095871, 21.6404171], [69.7095871, 21.64069366], [69.70874786, 21.64069176], [69.70874786, 21.6415329], [69.70680237, 21.64152718], [69.70680237, 21.64319229], [69.7076416, 21.64319229], [69.7076416, 21.64347458], [69.70819092, 21.64347076], [69.70819092, 21.64375114], [69.70847321, 21.64375114], [69.70847321, 21.64431], [69.70791626, 21.64431], [69.70791626, 21.64459038], [69.70735931, 21.64459038], [69.70735931, 21.64513969], [69.70708466, 21.64513969], [69.70708466, 21.64569664], [69.70680237, 21.64569092], [69.70680237, 21.64624977], [69.70625305, 21.64624977], [69.70625305, 21.64653015], [69.70597076, 21.64652824], [69.70597076, 21.64680672], [69.70541382, 21.64680672], [69.70541382, 21.64708328], [69.70513916, 21.64708328], [69.70513916, 21.64736176], [69.70375061, 21.64736176], [69.70375061, 21.64708328], [69.70347595, 21.64708328], [69.70347595, 21.64680672], [69.70319366, 21.64680672], [69.70319366, 21.64652824], [69.70291901, 21.64653015], [69.70291901, 21.64624977], [69.70263672, 21.64624977], [69.70263672, 21.64596939], [69.70207977, 21.6459713], [69.70207977, 21.64569664], [69.70124817, 21.64569664], [69.70124817, 21.64541435], [69.70069885, 21.64542007], [69.70069885, 21.64513969], [69.69985962, 21.64513969], [69.69985962, 21.64486122], [69.69875336, 21.64486122], [69.69875336, 21.64459038], [69.69819641, 21.64459038], [69.69819641, 21.64431], [69.69763184, 21.64431], [69.69763184, 21.64402962], [69.69735718, 21.64402962], [69.69735718, 21.64347076], [69.69708252, 21.64347458], [69.69708252, 21.64319229], [69.69680786, 21.64319229], [69.69680786, 21.64263916], [69.6965332, 21.64264107], [69.6965332, 21.64236069], [69.69625092, 21.64236069], [69.69625092, 21.64208031], [69.69569397, 21.64208221], [69.69569397, 21.64152718], [69.69541931, 21.6415329], [69.69541931, 21.64097023], [69.69569397, 21.64097023], [69.69569397, 21.64069366], [69.69625092, 21.64069366], [69.69625092, 21.6404171], [69.6965332, 21.64042282], [69.6965332, 21.63986015], [69.69625092, 21.63986015], [69.69625092, 21.63958359], [69.69403076, 21.63958359], [69.69403076, 21.63930511], [69.69374847, 21.63931274], [69.69374847, 21.63903046], [69.69346619, 21.63903046], [69.69346619, 21.63875008], [69.69235992, 21.63875008], [69.69235992, 21.63903046], [69.6920929, 21.63903046], [69.6920929, 21.64042282], [69.6904068, 21.64042282], [69.6904068, 21.64014053], [69.69013977, 21.64014053], [69.69013977, 21.63986015], [69.68985748, 21.63986015], [69.68985748, 21.63958359], [69.68958282, 21.63958359], [69.68958282, 21.63930511], [69.68930817, 21.63931274], [69.68930817, 21.63903046], [69.68875885, 21.63903046], [69.68875885, 21.63875008], [69.68791962, 21.63875008], [69.68791962, 21.63845825], [69.68763733, 21.6384716], [69.68763733, 21.63791656], [69.68736267, 21.63791847], [69.68736267, 21.63763809], [69.68708038, 21.63763809], [69.68708038, 21.63735962], [69.68680573, 21.63736153], [69.68680573, 21.63708305], [69.68653107, 21.63708305], [69.68653107, 21.63680649], [69.68624878, 21.6368084], [69.68624878, 21.63652992], [69.68319702, 21.63652992], [69.68319702, 21.63624954], [69.68208313, 21.63624954], [69.68208313, 21.63569069], [69.68152618, 21.6356945], [69.68152618, 21.63597298], [69.68068695, 21.63597107], [69.68068695, 21.63624954], [69.68013763, 21.63624954], [69.68013763, 21.6368084], [69.67986298, 21.63680649], [69.67986298, 21.63736153], [69.67958832, 21.63735962], [69.67958832, 21.63791847], [69.67930603, 21.63791847], [69.67930603, 21.63820267], [69.67903137, 21.63819504], [69.67903137, 21.6384716], [69.6784668, 21.63845825], [69.6784668, 21.63875008], [69.67819214, 21.63875008], [69.67819214, 21.63903046], [69.67791748, 21.63903046], [69.67791748, 21.63931274], [69.67652893, 21.63931274], [69.67652893, 21.63845825], [69.67624664, 21.63845825], [69.67624664, 21.63875008], [69.67569733, 21.63875008], [69.67569733, 21.63845825], [69.67597198, 21.6384716], [69.67597198, 21.63819504], [69.67652893, 21.63820267], [69.67652893, 21.63791847], [69.67679596, 21.63791847], [69.67679596, 21.63763809], [69.67708588, 21.63763809], [69.67708588, 21.63708115], [69.67736053, 21.63708305], [69.67736053, 21.63680649], [69.67791748, 21.63680077], [69.67791748, 21.63652992], [69.6784668, 21.63652992], [69.6784668, 21.63597107], [69.67874908, 21.63597298], [69.67874908, 21.63513947], [69.67903137, 21.63513947], [69.67903137, 21.6356945], [69.67930603, 21.6356945], [69.67930603, 21.63541794], [69.67958832, 21.63541985], [69.67958832, 21.63513947], [69.67986298, 21.63513947], [69.67986298, 21.63458061], [69.68013763, 21.63458252], [69.68013763, 21.63430786], [69.68041992, 21.63430977], [69.68041992, 21.63402939], [69.68096924, 21.63402939], [69.68096924, 21.63375092], [69.68125153, 21.63375092], [69.68125153, 21.63347054], [69.68180847, 21.63347244], [69.68180847, 21.63319588], [69.68208313, 21.63319588], [69.68208313, 21.6329174], [69.68235779, 21.63292122], [69.68235779, 21.63265038], [69.6829071, 21.63265038], [69.6829071, 21.63236046], [69.68319702, 21.63236046], [69.68319702, 21.63208008], [69.68347168, 21.6320858], [69.68347168, 21.63180351], [69.68402863, 21.63181114], [69.68402863, 21.63167953], [69.68402863, 21.63152695], [69.68430328, 21.63153076], [69.68430328, 21.63125038], [69.68486023, 21.63125038], [69.68486023, 21.63097], [69.68541718, 21.63097191], [69.68541718, 21.63069344], [69.68596649, 21.63070107], [69.68596649, 21.63042068], [69.68653107, 21.63042068], [69.68653107, 21.6301403], [69.68763733, 21.6301403], [69.68763733, 21.62985992], [69.68875122, 21.62986374], [69.68875122, 21.62958336], [69.69152832, 21.62959099], [69.69152832, 21.62930107], [69.69180298, 21.62930489], [69.69180298, 21.62902832], [69.6920929, 21.62903023], [69.6920929, 21.62846947], [69.69235992, 21.62847137], [69.69235992, 21.62819481], [69.69264221, 21.62819481], [69.69264221, 21.62791634], [69.69291687, 21.62792015], [69.69291687, 21.62735939], [69.69319153, 21.6273613], [69.69319153, 21.62708282], [69.69347382, 21.62708282], [69.69347382, 21.62652779], [69.69374847, 21.62652779], [69.69374847, 21.62597275], [69.69403076, 21.62597275], [69.69403076, 21.62569427], [69.69430542, 21.62569427], [69.69430542, 21.62513924], [69.69457245, 21.62513924], [69.69457245, 21.62486076], [69.69486237, 21.62486076], [69.69486237, 21.62431145], [69.69513702, 21.62431145], [69.69513702, 21.62346077], [69.69541931, 21.62347221], [69.69541931, 21.62319374], [69.69569397, 21.62319374], [69.69569397, 21.6226387], [69.69596863, 21.62264061], [69.69596863, 21.62236023], [69.69625092, 21.62236023], [69.69625092, 21.62207985], [69.69652557, 21.62208366], [69.69652557, 21.62152863], [69.69680786, 21.62153053], [69.69680786, 21.62125015], [69.69708252, 21.62125015], [69.69708252, 21.62096977], [69.69736481, 21.62097168], [69.69736481, 21.62041855], [69.69763184, 21.62042046], [69.69763184, 21.62014008], [69.69790649, 21.62014008], [69.69790649, 21.6198597], [69.69819641, 21.6198616], [69.69819641, 21.61930656], [69.69847107, 21.61930656], [69.69847107, 21.61902618], [69.69875336, 21.61903], [69.69875336, 21.61874962], [69.69902802, 21.61874962], [69.69902802, 21.61819077], [69.69930267, 21.61819649], [69.69930267, 21.6179142], [69.69957733, 21.61791992], [69.69957733, 21.61765099], [69.69985962, 21.61765099], [69.69985962, 21.61708069], [69.70014191, 21.6170826], [69.70014191, 21.61680412], [69.70041656, 21.61680984], [69.70041656, 21.61652946], [69.70096588, 21.61652946], [69.70096588, 21.6162529], [69.70153046, 21.6162529], [69.70153046, 21.61597061], [69.70207977, 21.61597252], [69.70207977, 21.61569214], [69.70291901, 21.61569214], [69.70291901, 21.61541748], [69.70347595, 21.61541939], [69.70347595, 21.61514282], [69.7040329, 21.61514282], [69.7040329, 21.61458015], [69.70430756, 21.61458206], [69.70430756, 21.61375046], [69.70458221, 21.61375046], [69.70458221, 21.6131916], [69.70513916, 21.61319351], [69.70513916, 21.61291695], [69.70540619, 21.61292267], [69.70540619, 21.61264038], [69.70597076, 21.61264038], [69.70597076, 21.61236191], [69.70625305, 21.61236191], [69.70625305, 21.61208344], [69.70680237, 21.61208344], [69.70680237, 21.61180496], [69.70707703, 21.61181259], [69.70707703, 21.61152077], [69.7076416, 21.6115284], [69.7076416, 21.61124992], [69.70847321, 21.61124992], [69.70847321, 21.61096764], [69.7095871, 21.61097145], [69.7095871, 21.61069489], [69.7104187, 21.61069489], [69.7104187, 21.61041641], [69.71069336, 21.61041832], [69.71069336, 21.61013985], [69.71153259, 21.61013985], [69.71153259, 21.60985947], [69.7123642, 21.60986137], [69.7123642, 21.60930634], [69.71290588, 21.60930824], [69.71290588, 21.60902977], [69.7131958, 21.60902977], [69.7131958, 21.60848045], [69.71347046, 21.60848045], [69.71347046, 21.60791969], [69.71375275, 21.60791969], [69.71375275, 21.60764122], [69.7140274, 21.60764122], [69.7140274, 21.60708046], [69.71430206, 21.60708237], [69.71430206, 21.60680771], [69.71457672, 21.60680962], [69.71457672, 21.60653114], [69.71485901, 21.60653114], [69.71485901, 21.60625076], [69.7151413, 21.60625076], [69.7151413, 21.60569], [69.71541595, 21.60569572], [69.71541595, 21.60541534], [69.71569824, 21.60542107], [69.71569824, 21.60514069], [69.7159729, 21.60514069], [69.7159729, 21.60486031], [69.71624756, 21.60486031], [69.71624756, 21.60431099], [69.71652985, 21.60431099], [69.71652985, 21.60375023], [69.71679688, 21.60375023], [69.71679688, 21.60320091], [69.71708679, 21.60320091], [69.71708679, 21.60264015], [69.71736145, 21.60264015], [69.71736145, 21.60207939], [69.71708679, 21.6020813], [69.71708679, 21.60124969], [69.71679688, 21.60124969], [69.71679688, 21.60042191], [69.71652985, 21.60042191], [69.71652985, 21.59958076], [69.71624756, 21.59958267], [69.71624756, 21.59902763], [69.71430206, 21.59902954], [69.71430206, 21.59931183], [69.7131958, 21.59930611], [69.7131958, 21.59958267], [69.71208191, 21.59958076], [69.71208191, 21.59986115], [69.71125031, 21.59986115], [69.71125031, 21.60013962], [69.7104187, 21.60013962], [69.7104187, 21.60042191], [69.7095871, 21.60041618], [69.7095871, 21.60069466], [69.70874786, 21.60069466], [69.70874786, 21.60097122], [69.70819092, 21.60097122], [69.70819092, 21.60124969], [69.70735931, 21.60124969], [69.70735931, 21.60153008], [69.70652771, 21.60152817], [69.70652771, 21.60180473], [69.70430756, 21.60180473], [69.70430756, 21.6020813], [69.70291901, 21.6020813], [69.70291901, 21.60180473], [69.70236206, 21.60180473], [69.70236206, 21.60152817], [69.70153046, 21.60153008], [69.70153046, 21.60097122], [69.70097351, 21.60097122], [69.70097351, 21.60041618], [69.70069885, 21.60042191], [69.70069885, 21.60013962], [69.70014191, 21.60013962], [69.70014191, 21.59986115], [69.69985962, 21.59986115], [69.69985962, 21.59958076], [69.69930267, 21.59958267], [69.69930267, 21.59930611], [69.69902802, 21.59931183], [69.69902802, 21.59874916], [69.69875336, 21.59874916], [69.69875336, 21.59763908], [69.69847107, 21.59763908], [69.69847107, 21.59680939], [69.69819641, 21.59680939], [69.69819641, 21.59486008], [69.69791412, 21.59486198], [69.69791412, 21.59347153], [69.69763184, 21.59348106], [69.69763184, 21.59320068], [69.69680786, 21.59320068], [69.69680786, 21.5929203], [69.69541931, 21.5929203], [69.69541931, 21.59320068], [69.69457245, 21.59320068], [69.69457245, 21.59348106], [69.69431305, 21.59348106], [69.69431305, 21.59403038], [69.69403076, 21.59403038], [69.69403076, 21.59431076], [69.69347382, 21.59430695], [69.69347382, 21.59486198], [69.69374847, 21.59486198], [69.69374847, 21.59569359], [69.69346619, 21.59568977], [69.69346619, 21.59625053], [69.69291687, 21.59625053], [69.69291687, 21.59654236], [69.69319153, 21.59654236], [69.69319153, 21.59680939], [69.69346619, 21.59680939], [69.69346619, 21.59736061], [69.69319153, 21.59736061], [69.69319153, 21.59763908], [69.69291687, 21.59763908], [69.69291687, 21.5984726], [69.69319153, 21.5984726], [69.69319153, 21.60236168], [69.69346619, 21.60235023], [69.69346619, 21.60292053], [69.69374847, 21.60291672], [69.69374847, 21.60347176], [69.69403076, 21.60346985], [69.69403076, 21.60375023], [69.69541931, 21.60375023], [69.69541931, 21.60346985], [69.69596863, 21.60347176], [69.69596863, 21.60319328], [69.6965332, 21.60320091], [69.6965332, 21.60292053], [69.69735718, 21.60292053], [69.69735718, 21.60264015], [69.69790649, 21.60264015], [69.69790649, 21.60207939], [69.69819641, 21.6020813], [69.69819641, 21.60097122], [69.69847107, 21.60097122], [69.69847107, 21.60041618], [69.69902802, 21.60041618], [69.69902802, 21.60069466], [69.69958496, 21.60069466], [69.69958496, 21.60097122], [69.69985962, 21.60097122], [69.69985962, 21.60124969], [69.70041656, 21.60124969], [69.70041656, 21.60153008], [69.70069122, 21.60152817], [69.70069122, 21.6020813], [69.70096588, 21.60207939], [69.70096588, 21.60264015], [69.70124817, 21.60264015], [69.70124817, 21.60320091], [69.70097351, 21.60319328], [69.70097351, 21.60347176], [69.70069122, 21.60347176], [69.70069885, 21.60375023], [69.70041656, 21.60375023], [69.70041656, 21.60403061], [69.70014191, 21.6040287], [69.70014191, 21.60458565], [69.69985962, 21.60457993], [69.69985962, 21.60486031], [69.69957733, 21.60486031], [69.69957733, 21.60514069], [69.69930267, 21.60514069], [69.69930267, 21.60542107], [69.69847107, 21.60541534], [69.69847107, 21.60569572], [69.69736481, 21.60569572], [69.69736481, 21.60597229], [69.69708252, 21.60597038], [69.69708252, 21.60625076], [69.69680786, 21.60625076], [69.69680786, 21.60653114], [69.6965332, 21.60653114], [69.6965332, 21.60680962], [69.69625092, 21.60680771], [69.69625092, 21.60708427], [69.69596863, 21.60708046], [69.69596863, 21.60764122], [69.69569397, 21.60763931], [69.69569397, 21.60819435], [69.69541931, 21.60819054], [69.69541931, 21.60848045], [69.69513702, 21.60848045], [69.69513702, 21.60874939], [69.69486237, 21.60874939], [69.69486237, 21.6095829], [69.69457245, 21.60957909], [69.69457245, 21.61041832], [69.69403076, 21.61041641], [69.69403076, 21.61069489], [69.69374847, 21.61069489], [69.69374847, 21.61097145], [69.69346619, 21.61096764], [69.69346619, 21.61181259], [69.69319153, 21.61180496], [69.69319153, 21.61208344], [69.69291687, 21.61208344], [69.69291687, 21.61236191], [69.69264221, 21.61236191], [69.69264221, 21.61292267], [69.69235992, 21.61291695], [69.69235992, 21.61347008], [69.6920929, 21.61347008], [69.6920929, 21.61403275], [69.69180298, 21.61403275], [69.69180298, 21.61431122], [69.69125366, 21.6143055], [69.69125366, 21.61458206], [69.69097137, 21.61458015], [69.69097137, 21.61486053], [69.6904068, 21.61486053], [69.6904068, 21.61514282], [69.68958282, 21.61514282], [69.68958282, 21.61541939], [69.68902588, 21.61541748], [69.68902588, 21.61597252], [69.68818665, 21.61597061], [69.68818665, 21.6162529], [69.68791962, 21.6162529], [69.68791962, 21.61652946], [69.68736267, 21.61652946], [69.68736267, 21.61680984], [69.68680573, 21.61680412], [69.68680573, 21.6170826], [69.68653107, 21.6170826], [69.68653107, 21.61680412], [69.68624878, 21.61680412], [69.68624878, 21.6170826], [69.68569183, 21.61708069], [69.68569183, 21.61736107], [69.68514252, 21.61736107], [69.68514252, 21.61765099], [69.68430328, 21.61765099], [69.68430328, 21.61791992], [69.68402863, 21.6179142], [69.68402863, 21.61819649], [69.68374634, 21.61819649], [69.68374634, 21.61847305], [69.68347168, 21.61847115], [69.68347168, 21.61903], [69.68291473, 21.61902618], [69.68291473, 21.61930656], [69.68264008, 21.61930656], [69.68264008, 21.61958313], [69.68208313, 21.61958313], [69.68208313, 21.6198616], [69.68180847, 21.6198597], [69.68180847, 21.62014008], [69.68152618, 21.62014008], [69.68152618, 21.62042046], [69.68096924, 21.62042046], [69.68096924, 21.62070847], [69.68069458, 21.62069511], [69.68069458, 21.62097168], [69.68041992, 21.62096977], [69.68041992, 21.62125015], [69.68013763, 21.62125015], [69.68013763, 21.62153053], [69.67986298, 21.62153053], [69.67986298, 21.62181091], [69.67958069, 21.62180519], [69.67958069, 21.62208366], [69.67874908, 21.62207985], [69.67874908, 21.62236023], [69.67736053, 21.62236023], [69.67736053, 21.62291908], [69.67597198, 21.62291718], [69.67597198, 21.62319374], [69.67541504, 21.62319374], [69.67541504, 21.62347221], [69.67457581, 21.62346077], [69.67457581, 21.62375069], [69.67402649, 21.62375069], [69.67402649, 21.62402916], [69.67346191, 21.62402916], [69.67346191, 21.62431145], [69.67263794, 21.62430573], [69.67263794, 21.6245842], [69.67208099, 21.62457848], [69.67208099, 21.62486076], [69.67124939, 21.62486076], [69.67124939, 21.62513924], [69.67041779, 21.62513924], [69.67041779, 21.62541962], [69.66986084, 21.6254158], [69.66986084, 21.62569427], [69.66902924, 21.62569427], [69.66902924, 21.62597275], [69.66402435, 21.62597275], [69.66402435, 21.62569427], [69.66374969, 21.62569427], [69.66374969, 21.6254158], [69.66348267, 21.62541962], [69.66348267, 21.62513924], [69.66319275, 21.62513924], [69.66319275, 21.62486076], [69.66291809, 21.62486076], [69.66291809, 21.62457848], [69.6609726, 21.62457848], [69.6609726, 21.62486076], [69.66152191, 21.62486076], [69.66152191, 21.62541962], [69.6609726, 21.6254158], [69.6609726, 21.62597275], [69.66014099, 21.62597275], [69.66014099, 21.62569427], [69.6598587, 21.62569427], [69.6598587, 21.62597275], [69.65930939, 21.62597084], [69.65930176, 21.62625122], [69.6590271, 21.62624931], [69.6590271, 21.62652779], [69.65791321, 21.62652779], [69.65791321, 21.62708282], [69.65763855, 21.62708282], [69.65763855, 21.6273613], [69.65735626, 21.62735939], [69.65735626, 21.62763977], [69.6570816, 21.62763977], [69.6570816, 21.62792015], [69.65680695, 21.62791634], [69.65680695, 21.62847137], [69.65651703, 21.62846947], [69.65651703, 21.62874985], [69.65625, 21.62874985], [69.65625, 21.62903023], [69.65597534, 21.62902832], [69.65597534, 21.62930489], [69.65569305, 21.62930107], [69.65569305, 21.62959099], [69.6554184, 21.62959099], [69.6554184, 21.6301403], [69.65513611, 21.6301403], [69.65513611, 21.63042068], [69.65486145, 21.63042068], [69.65486145, 21.63070107], [69.65458679, 21.63069344], [69.65458679, 21.63097191], [69.65429688, 21.63097], [69.65429688, 21.63125038], [69.65374756, 21.63125038], [69.65374756, 21.63153076], [69.65319824, 21.63153076], [69.65319824, 21.63181114], [69.6526413, 21.63180351], [69.6526413, 21.6320858], [69.6515274, 21.63208008], [69.6515274, 21.63236046], [69.65040588, 21.63236046], [69.65040588, 21.63265038], [69.64958191, 21.63265038], [69.64958191, 21.63292122], [69.64847565, 21.6329174], [69.64847565, 21.63319588], [69.6479187, 21.63319588], [69.6479187, 21.63347244], [69.64763641, 21.63347054], [69.64763641, 21.63375092], [69.6470871, 21.63375092], [69.6470871, 21.63402939], [69.64652252, 21.63402939], [69.64652252, 21.63430977], [69.64624786, 21.63430786], [69.64624786, 21.63458252], [69.64569092, 21.63458061], [69.64569092, 21.63486099], [69.64541626, 21.63486099], [69.64541626, 21.63513947], [69.64485931, 21.63513947], [69.64485931, 21.63541985], [69.64458466, 21.63541794], [69.64458466, 21.6356945], [69.64402771, 21.6356945], [69.64402771, 21.63597298], [69.64375305, 21.63597107], [69.64375305, 21.63624954], [69.64319611, 21.63624954], [69.64319611, 21.63652992], [69.64290619, 21.63652992], [69.64290619, 21.6368084], [69.6423645, 21.63680649], [69.6423645, 21.63708305], [69.64208221, 21.63708305], [69.64208221, 21.63736153], [69.6415329, 21.63735962], [69.6415329, 21.63763809], [69.64125061, 21.63763809], [69.64125061, 21.63791847], [69.64068604, 21.63791847], [69.64068604, 21.63820267], [69.64041901, 21.63819504], [69.64041901, 21.6384716], [69.63986206, 21.63845825], [69.63986206, 21.63875008], [69.63957977, 21.63875008], [69.63957977, 21.63903046], [69.63931274, 21.63903046], [69.63931274, 21.63931274], [69.63903046, 21.63930511], [69.63903046, 21.63958359], [69.63874817, 21.63958359], [69.63874817, 21.63986015], [69.63846588, 21.63986015], [69.63846588, 21.64014053], [69.63819122, 21.64014053], [69.63819122, 21.64042282], [69.63791656, 21.6404171], [69.63791656, 21.64069366], [69.63764191, 21.64069366], [69.63764191, 21.64097023], [69.63735199, 21.64097023], [69.63735199, 21.64125061], [69.63707733, 21.64125061], [69.63707733, 21.6415329], [69.63680267, 21.6415329], [69.63680267, 21.64180946], [69.63652802, 21.64180565], [69.63652802, 21.64208221], [69.63625336, 21.64208031], [69.63625336, 21.64264107], [69.63597107, 21.64264107], [69.63597107, 21.64291954], [69.63569641, 21.64291763], [69.63569641, 21.64319229], [69.63541412, 21.64319229], [69.63541412, 21.64347458], [69.63291931, 21.64347458], [69.63291931, 21.64291763], [69.63263702, 21.64291954], [69.63263702, 21.64208031], [69.63291931, 21.64208221], [69.63291931, 21.64152718], [69.63318634, 21.6415329], [69.63318634, 21.64125061], [69.63346863, 21.64125061], [69.63346863, 21.64069176], [69.63375092, 21.64069366], [69.63375092, 21.6404171], [69.6340332, 21.64042282], [69.6340332, 21.64014053], [69.63430786, 21.64014053], [69.63430786, 21.63986015], [69.63458252, 21.63986015], [69.63458252, 21.63958168], [69.63486481, 21.63958359], [69.63486481, 21.63930511], [69.63513947, 21.63931274], [69.63513947, 21.63903046], [69.63569641, 21.63903046], [69.63569641, 21.63875008], [69.63597107, 21.63875008], [69.63597107, 21.63845825], [69.63625336, 21.6384716], [69.63625336, 21.63819504], [69.63652802, 21.63820267], [69.63652802, 21.63791847], [69.63680267, 21.63791847], [69.63680267, 21.63763809], [69.63707733, 21.63763809], [69.63707733, 21.63735962], [69.63735962, 21.63736153], [69.63735962, 21.63708305], [69.63791656, 21.63708305], [69.63791656, 21.63680649], [69.63819122, 21.63680077], [69.63819122, 21.63652992], [69.63846588, 21.63652992], [69.63846588, 21.63624954], [69.63903046, 21.63624954], [69.63903046, 21.63597107], [69.63930511, 21.63597298], [69.63930511, 21.6356945], [69.63957977, 21.6356945], [69.63957977, 21.63541794], [69.64013672, 21.63541985], [69.64013672, 21.63513947], [69.64041901, 21.63513947], [69.64041901, 21.63486099], [69.64097595, 21.63486099], [69.64097595, 21.63458061], [69.64125061, 21.63458252], [69.64125061, 21.63430786], [69.6415329, 21.63430977], [69.6415329, 21.63402939], [69.64208221, 21.63402939], [69.64208221, 21.63375092], [69.64235687, 21.63375092], [69.64235687, 21.63347054], [69.64291382, 21.63347244], [69.64291382, 21.63319588], [69.64375305, 21.63319588], [69.64375305, 21.6329174], [69.64402771, 21.63292122], [69.64402771, 21.63265038], [69.64430237, 21.63265038], [69.64430237, 21.63236046], [69.64457703, 21.63236046], [69.64457703, 21.63208008], [69.64485931, 21.6320858], [69.64485931, 21.63180351], [69.6451416, 21.63181114], [69.6451416, 21.63153076], [69.64541626, 21.63153076], [69.64541626, 21.63125038], [69.64569092, 21.63125038], [69.64569092, 21.63097], [69.64597321, 21.63097191], [69.64597321, 21.63069344], [69.64624786, 21.63070107], [69.64624786, 21.63042068], [69.64652252, 21.63042068], [69.64652252, 21.6301403], [69.64679718, 21.6301403], [69.64679718, 21.62985992], [69.6470871, 21.62986374], [69.6470871, 21.62902832], [69.6479187, 21.62903023], [69.6479187, 21.62874985], [69.64819336, 21.62874985], [69.64819336, 21.62846947], [69.64847565, 21.62847137], [69.64847565, 21.62819481], [69.64875031, 21.62819481], [69.64875031, 21.62791634], [69.64903259, 21.62792015], [69.64903259, 21.62763977], [69.64930725, 21.62763977], [69.64930725, 21.62735939], [69.64958191, 21.6273613], [69.64958191, 21.62708282], [69.6498642, 21.62708282], [69.6498642, 21.62680626], [69.6506958, 21.62681007], [69.6506958, 21.62652016], [69.6515274, 21.62652779], [69.6515274, 21.62624931], [69.65207672, 21.62625122], [69.65207672, 21.62597084], [69.6526413, 21.62597275], [69.6526413, 21.62569427], [69.65291595, 21.62569427], [69.65291595, 21.6254158], [69.6534729, 21.62541962], [69.6534729, 21.62513924], [69.65458679, 21.62513924], [69.65458679, 21.62457848], [69.65513611, 21.62457848], [69.65513611, 21.62486076], [69.6554184, 21.62486076], [69.6554184, 21.62457848], [69.65597534, 21.6245842], [69.65597534, 21.62430573], [69.65651703, 21.62431145], [69.65651703, 21.62402916], [69.65735626, 21.62402916], [69.65735626, 21.62375069], [69.65791321, 21.62375069], [69.65791321, 21.62346077], [69.6590271, 21.62347221], [69.6590271, 21.62319374], [69.66041565, 21.62319374], [69.66041565, 21.62291718], [69.66069794, 21.62291908], [69.66069794, 21.62264061], [69.66291809, 21.62264061], [69.66291809, 21.62236023], [69.66319275, 21.62236023], [69.66319275, 21.62207985], [69.66374969, 21.62208366], [69.66374969, 21.62180519], [69.66430664, 21.62181091], [69.66430664, 21.62153053], [69.66458893, 21.62153053], [69.66458893, 21.62125015], [69.66513824, 21.62125015], [69.66513824, 21.62096977], [69.6654129, 21.62097168], [69.6654129, 21.62069511], [69.66596985, 21.62070847], [69.66596985, 21.62042046], [69.66625214, 21.62042046], [69.66625214, 21.62014008], [69.66680908, 21.62014008], [69.66680908, 21.6198597], [69.66708374, 21.6198616], [69.66708374, 21.61958313], [69.6673584, 21.61958313], [69.6673584, 21.61902618], [69.66764832, 21.61903], [69.66764832, 21.61874962], [69.66791534, 21.61874962], [69.66791534, 21.61819649], [69.66819763, 21.61819649], [69.66819763, 21.6179142], [69.66847229, 21.61791992], [69.66847229, 21.61765099], [69.66874695, 21.61765099], [69.66874695, 21.61708069], [69.66902924, 21.6170826], [69.66902924, 21.61680412], [69.66929626, 21.61680984], [69.66929626, 21.6162529], [69.66958618, 21.6162529], [69.66958618, 21.61569023], [69.66986084, 21.61569214], [69.66986084, 21.61513901], [69.67014313, 21.61514282], [69.67014313, 21.61458015], [69.67041779, 21.61458206], [69.67041779, 21.61402702], [69.67069244, 21.61403275], [69.67069244, 21.61347008], [69.67097473, 21.61347008], [69.67097473, 21.61291695], [69.67124939, 21.61292267], [69.67124939, 21.61236191], [69.67152405, 21.61236191], [69.67152405, 21.61208344], [69.67208099, 21.61208344], [69.67208099, 21.61180496], [69.67319489, 21.61180496], [69.67319489, 21.61236191], [69.67346191, 21.61236191], [69.67346191, 21.61264038], [69.67375183, 21.61264038], [69.67375183, 21.61292267], [69.67402649, 21.61291695], [69.67402649, 21.61347008], [69.67430878, 21.61347008], [69.67430878, 21.61263847], [69.67485809, 21.61264038], [69.67485809, 21.61152077], [69.67597198, 21.6115284], [69.67597198, 21.61124992], [69.67624664, 21.61124992], [69.67624664, 21.61068916], [69.67652893, 21.61069489], [69.67652893, 21.61013985], [69.67679596, 21.61013985], [69.67679596, 21.60985947], [69.67708588, 21.60986137], [69.67708588, 21.6095829], [69.67680359, 21.6095829], [69.67680359, 21.60930634], [69.67736053, 21.60930824], [69.67736053, 21.60902977], [69.67679596, 21.60902977], [69.67679596, 21.60874939], [69.67624664, 21.60874939], [69.67624664, 21.60764122], [69.67597198, 21.60764122], [69.67597198, 21.60653114], [69.67624664, 21.60653114], [69.67624664, 21.60597038], [69.67652893, 21.60597229], [69.67652893, 21.60541534], [69.67679596, 21.60542107], [69.67679596, 21.60486031], [69.67708588, 21.60486031], [69.67708588, 21.60457993], [69.67736053, 21.60458565], [69.67736053, 21.6040287], [69.67764282, 21.60403061], [69.67764282, 21.60346985], [69.67791748, 21.60347176], [69.67791748, 21.60319328], [69.6784668, 21.60320091], [69.6784668, 21.60292053], [69.67874908, 21.60292053], [69.67874908, 21.60264015], [69.67930603, 21.60264015], [69.67930603, 21.60235023], [69.67958069, 21.60236168], [69.67958069, 21.6020813], [69.68013763, 21.6020813], [69.68013763, 21.60180473], [69.68041992, 21.60180473], [69.68041992, 21.60152817], [69.68096924, 21.60153008], [69.68096924, 21.60124969], [69.68125153, 21.60124969], [69.68125153, 21.60097122], [69.68180847, 21.60097122], [69.68180847, 21.60013962], [69.68208313, 21.60013962], [69.68208313, 21.59958076], [69.68235779, 21.59958267], [69.68235779, 21.59930611], [69.68263245, 21.59931183], [69.68263245, 21.59902954], [69.6829071, 21.59902954], [69.6829071, 21.59874916], [69.68319702, 21.59874916], [69.68319702, 21.59847069], [69.68347168, 21.5984726], [69.68347168, 21.59819412], [69.68374634, 21.59819412], [69.68374634, 21.59791756], [69.68402863, 21.59791946], [69.68402863, 21.59763908], [69.68430328, 21.59763908], [69.68430328, 21.59736061], [69.6845932, 21.59736061], [69.68458557, 21.59708405], [69.68486023, 21.59708405], [69.68486023, 21.59680557], [69.68514252, 21.59680939], [69.68514252, 21.59654236], [69.68541718, 21.59654236], [69.68541718, 21.59625053], [69.68569183, 21.59625053], [69.68569183, 21.59596825], [69.68597412, 21.59597206], [69.68597412, 21.59569359], [69.68708038, 21.59569359], [69.68708038, 21.59541893], [69.68791962, 21.59542084], [69.68791962, 21.59514046], [69.68902588, 21.59514046], [69.68902588, 21.59486008], [69.69013977, 21.59486198], [69.69013977, 21.59458351], [69.69041443, 21.59458351], [69.69041443, 21.59486198], [69.69069672, 21.59486008], [69.69069672, 21.59514046], [69.69097137, 21.59514046], [69.69097137, 21.59486008], [69.69124603, 21.59486008], [69.69124603, 21.59514046], [69.69152832, 21.59514046], [69.69152832, 21.59542084], [69.6920929, 21.59542084], [69.6920929, 21.59431076], [69.69235992, 21.59431076], [69.69235992, 21.59348106], [69.6920929, 21.59348106], [69.6920929, 21.5929203], [69.69291687, 21.5929203], [69.69291687, 21.59263992], [69.69319153, 21.59263992], [69.69319153, 21.59235954], [69.69347382, 21.59236145], [69.69347382, 21.5918045], [69.69513702, 21.59181023], [69.69513702, 21.59152985], [69.69568634, 21.59152985], [69.69568634, 21.59124947], [69.69680786, 21.59124947], [69.69680786, 21.59097099], [69.69763184, 21.59097099], [69.69763184, 21.59124947], [69.69790649, 21.59124947], [69.69790649, 21.58986092], [69.69875336, 21.58986092], [69.69875336, 21.58958054], [69.70458221, 21.58958244], [69.70458221, 21.58930588], [69.70513916, 21.58930969], [69.70513916, 21.58903122], [69.70569611, 21.58903122], [69.70569611, 21.58875084], [69.70625305, 21.58875084], [69.70625305, 21.58847046], [69.70680237, 21.58847237], [69.70680237, 21.58819389], [69.70735931, 21.58819389], [69.70735931, 21.58791733], [69.7076416, 21.58792114], [69.7076416, 21.58764267], [69.70791626, 21.58764267], [69.70791626, 21.58735085], [69.70819092, 21.58736038], [69.70819092, 21.58680534], [69.70847321, 21.58681107], [69.70847321, 21.58653259], [69.70874786, 21.58653259], [69.70874786, 21.58625031], [69.70903015, 21.58625031], [69.70903015, 21.58597183], [69.70930481, 21.58597183], [69.70930481, 21.58569527], [69.7095871, 21.5857029], [69.7095871, 21.58542252], [69.70986176, 21.58542252], [69.70986176, 21.58514023], [69.71013641, 21.58514023], [69.71013641, 21.58457756], [69.7104187, 21.58458328], [69.7104187, 21.58430481], [69.71069336, 21.58430862], [69.71069336, 21.58402824], [69.71098328, 21.58402824], [69.71098328, 21.58374977], [69.71125031, 21.58374977], [69.71125031, 21.58346748], [69.71152496, 21.5834713], [69.71152496, 21.58319473], [69.71180725, 21.58319473], [69.71180725, 21.58291626], [69.71208191, 21.58291817], [69.71208191, 21.58263969], [69.71235657, 21.58263969], [69.71235657, 21.58236122], [69.71263885, 21.58236122], [69.71263885, 21.58208084], [69.7131958, 21.58208275], [69.7131958, 21.58180618], [69.71347046, 21.58180809], [69.71347046, 21.58153915], [69.71375275, 21.58153915], [69.71375275, 21.58125114], [69.7140274, 21.58125114], [69.7140274, 21.58097076], [69.71430206, 21.58097267], [69.71430206, 21.5806942], [69.71458435, 21.5806942], [69.71458435, 21.58041763], [69.71485901, 21.58041954], [69.71485901, 21.58014107], [69.7151413, 21.58014107], [69.7151413, 21.57986069], [69.71541595, 21.57986069], [69.71541595, 21.57958031], [69.71569061, 21.57958412], [69.71569824, 21.57930756], [69.7159729, 21.57930946], [69.7159729, 21.57903099], [69.71624756, 21.57903099], [69.71624756, 21.57875061], [69.71652985, 21.57875061], [69.71652985, 21.57847023], [69.7168045, 21.57847214], [69.7168045, 21.57819557], [69.71736145, 21.57819557], [69.71736145, 21.57791519], [69.71763611, 21.57792091], [69.71763611, 21.57764053], [69.7179184, 21.57764053], [69.7179184, 21.57736015], [69.71819305, 21.57736015], [69.71819305, 21.57707977], [69.71847534, 21.57708549], [69.71847534, 21.57680321], [69.71875763, 21.57681084], [69.71875763, 21.57653046], [69.71901703, 21.57653046], [69.71901703, 21.57625008], [69.71930695, 21.57625008], [69.71930695, 21.5759697], [69.7195816, 21.5759716], [69.7195816, 21.57569313], [69.71985626, 21.57570076], [69.71985626, 21.57541275], [69.72013855, 21.57541656], [69.72013855, 21.57513809], [69.72041321, 21.57514], [69.72041321, 21.57485962], [69.7206955, 21.57486153], [69.7206955, 21.57458115], [69.72097015, 21.57458115], [69.72097015, 21.57430649], [69.7215271, 21.57430267], [69.7215271, 21.57402802], [69.72180176, 21.57403183], [69.72180176, 21.57374954], [69.72207642, 21.57374954], [69.72207642, 21.57347107], [69.7223587, 21.57347107], [69.7223587, 21.5731945], [69.72264099, 21.5731945], [69.72264099, 21.57291603], [69.72292328, 21.57292175], [69.72292328, 21.57263947], [69.72319794, 21.57263947], [69.72319794, 21.57237053], [69.7234726, 21.57237053], [69.7234726, 21.57181168], [69.72374725, 21.57181168], [69.72374725, 21.57152939], [69.72402954, 21.57152939], [69.72402954, 21.57125092], [69.72429657, 21.57125092], [69.72429657, 21.57068825], [69.72458649, 21.57069397], [69.72458649, 21.5704174], [69.72486115, 21.57041931], [69.72486115, 21.56986046], [69.72458649, 21.56986046], [69.72458649, 21.56930923], [69.72429657, 21.56930923], [69.72429657, 21.56846809], [69.72402954, 21.56847191], [69.72402954, 21.56791878], [69.72374725, 21.56792068], [69.72374725, 21.56596947], [69.7234726, 21.56597137], [69.7234726, 21.56624985], [69.72319794, 21.56624985], [69.72319794, 21.56597137], [69.72291565, 21.56597137], [69.72291565, 21.56569672], [69.72264099, 21.56569672], [69.72264099, 21.56541443], [69.7223587, 21.56542015], [69.7223587, 21.56513977], [69.72207642, 21.56513977], [69.72207642, 21.56485939], [69.7215271, 21.5648613], [69.7215271, 21.56458473], [69.72125244, 21.56458473], [69.72125244, 21.56430435], [69.72097015, 21.56431007], [69.72097015, 21.56375122], [69.72070313, 21.56375122], [69.72070313, 21.56347084], [69.72013855, 21.56347466], [69.72013855, 21.56319237], [69.71930695, 21.56319237], [69.71930695, 21.56236076], [69.71901703, 21.56236076], [69.71901703, 21.56180954], [69.71875763, 21.56180954], [69.71875763, 21.56097031], [69.71847534, 21.56097221], [69.71847534, 21.56069374], [69.71819305, 21.56069374], [69.71819305, 21.5601387], [69.7179184, 21.56014061], [69.7179184, 21.55958176], [69.71763611, 21.55958366], [69.71763611, 21.55930519], [69.71736145, 21.55931282], [69.71736145, 21.55875015], [69.71708679, 21.55875015], [69.71708679, 21.55820274], [69.71679688, 21.55820274], [69.71679688, 21.55763817], [69.71652985, 21.55763817], [69.71652985, 21.55708122], [69.71624756, 21.55708313], [69.71624756, 21.55597305], [69.7159729, 21.55597305], [69.7159729, 21.55486107], [69.71569824, 21.55486107], [69.71569824, 21.55402946], [69.71541595, 21.55402946], [69.71541595, 21.55124092], [69.71569061, 21.55125046], [69.71569824, 21.55097389], [69.7159729, 21.55097389], [69.7159729, 21.55069351], [69.71624756, 21.55069351], [69.71624756, 21.55041695], [69.71652985, 21.55042076], [69.71652985, 21.55014038], [69.71679688, 21.55014038], [69.71679688, 21.54986], [69.71708679, 21.54986382], [69.71708679, 21.54958534], [69.71736145, 21.54958534], [69.71736145, 21.5490284], [69.71763611, 21.5490303], [69.71763611, 21.54874992], [69.7179184, 21.54874992], [69.7179184, 21.54818153], [69.71819305, 21.54819489], [69.71819305, 21.54791641], [69.71848297, 21.54792023], [69.71848297, 21.5470829], [69.7195816, 21.5470829], [69.7195816, 21.54652786], [69.71985626, 21.54652977], [69.71985626, 21.54513931], [69.7195816, 21.54513931], [69.7195816, 21.54458046], [69.71986389, 21.54458237], [69.71986389, 21.54375076], [69.72013855, 21.54375076], [69.72013855, 21.54347038], [69.7195816, 21.54347229], [69.7195816, 21.54291725], [69.71930695, 21.54291916], [69.71930695, 21.54236031], [69.71875, 21.54236031], [69.71875, 21.54208374], [69.71847534, 21.54208374], [69.71847534, 21.54180527], [69.71819305, 21.54180527], [69.71819305, 21.54208374], [69.71763611, 21.54208374], [69.71763611, 21.54180527], [69.71736145, 21.54180908], [69.71736145, 21.54153061], [69.71708679, 21.54153061], [69.71708679, 21.54125023], [69.71652985, 21.54125023], [69.71652985, 21.54096985], [69.7159729, 21.54097176], [69.7159729, 21.54069519], [69.71569824, 21.54070091], [69.71569824, 21.54042053], [69.71530151, 21.54042053], [69.71457672, 21.54042053], [69.71457672, 21.54070091], [69.71430206, 21.54070091], [69.71430206, 21.54042053], [69.71290588, 21.54042053], [69.71290588, 21.54014015], [69.71235657, 21.54014015], [69.71235657, 21.54042053], [69.71208191, 21.54042053], [69.71208191, 21.53985977], [69.71180725, 21.53986168], [69.71180725, 21.53958321], [69.71069336, 21.53958321], [69.71069336, 21.53930664], [69.71013641, 21.53930664], [69.71013641, 21.53958321], [69.70930481, 21.53958321], [69.70930481, 21.53986168], [69.70819092, 21.53985977], [69.70819092, 21.54014015], [69.70735931, 21.54014015], [69.70735931, 21.53985977], [69.7076416, 21.53986168], [69.7076416, 21.53930664], [69.70708466, 21.53930664], [69.70708466, 21.53902817], [69.70680237, 21.53903008], [69.70680237, 21.53874969], [69.70625305, 21.53874969], [69.70625305, 21.53847122], [69.70597076, 21.53847122], [69.70597076, 21.53874969], [69.70569611, 21.53874969], [69.70569611, 21.53903008], [69.70513916, 21.53902817], [69.70513916, 21.53930664], [69.70458221, 21.53930664], [69.70458221, 21.53958321], [69.70430756, 21.53958321], [69.70430756, 21.53986168], [69.70375824, 21.53985977], [69.70375824, 21.54014015], [69.70318604, 21.54014015], [69.70318604, 21.54042053], [69.70263672, 21.54042053], [69.70263672, 21.54070091], [69.70236206, 21.54069519], [69.70236206, 21.54097176], [69.70207977, 21.54096985], [69.70207977, 21.54125023], [69.70181274, 21.54125023], [69.70181274, 21.54153061], [69.70124817, 21.54153061], [69.70124817, 21.54125023], [69.70096588, 21.54125023], [69.70096588, 21.54153061], [69.70069885, 21.54153061], [69.70069885, 21.54180908], [69.70041656, 21.54180527], [69.70041656, 21.54208374], [69.70014191, 21.54207993], [69.70014191, 21.54236031], [69.69957733, 21.54236031], [69.69957733, 21.54264069], [69.69930267, 21.54264069], [69.69930267, 21.54291916], [69.69902802, 21.54291725], [69.69902802, 21.54319382], [69.69875336, 21.54319382], [69.69875336, 21.54347229], [69.69819641, 21.54347038], [69.69819641, 21.54375076], [69.69790649, 21.54375076], [69.69790649, 21.54402924], [69.69763184, 21.54402924], [69.69763184, 21.54431152], [69.69736481, 21.5443058], [69.69736481, 21.54458427], [69.69708252, 21.54458046], [69.69708252, 21.54486084], [69.6965332, 21.54486084], [69.6965332, 21.54513931], [69.69625092, 21.54513931], [69.69625092, 21.54543114], [69.69596863, 21.54541588], [69.69596863, 21.54569435], [69.69569397, 21.54569435], [69.69569397, 21.54597282], [69.69541931, 21.54597092], [69.69541931, 21.54624939], [69.69486237, 21.54624939], [69.69486237, 21.54652977], [69.69457245, 21.54652977], [69.69457245, 21.54681015], [69.69430542, 21.54680634], [69.69430542, 21.5470829], [69.69403076, 21.5470829], [69.69403076, 21.54736137], [69.69291687, 21.54735947], [69.69291687, 21.54763985], [69.69264221, 21.54763985], [69.69264221, 21.54792023], [69.69235992, 21.54791641], [69.69235992, 21.54819489], [69.69208527, 21.54819489], [69.69208527, 21.54847145], [69.69180298, 21.54846954], [69.69180298, 21.54874992], [69.69124603, 21.54874992], [69.69124603, 21.5490303], [69.69097137, 21.5490303], [69.69097137, 21.54931068], [69.69041443, 21.54930305], [69.69041443, 21.54958534], [69.69013977, 21.54958534], [69.69013977, 21.54986382], [69.68958282, 21.54986], [69.68958282, 21.55014038], [69.68846893, 21.55013847], [69.68846893, 21.55125046], [69.68791962, 21.55124092], [69.68791962, 21.55153084], [69.68763733, 21.55153084], [69.68763733, 21.55181122], [69.68736267, 21.55180359], [69.68736267, 21.55208588], [69.68680573, 21.55208588], [69.68681335, 21.55236053], [69.68653107, 21.55236053], [69.68653107, 21.55291939], [69.68624878, 21.55291748], [69.68624878, 21.55319595], [69.68597412, 21.55319595], [69.68597412, 21.55347252], [69.68569183, 21.55347061], [69.68569183, 21.55375099], [69.68541718, 21.55375099], [69.68541718, 21.55402946], [69.68514252, 21.55402756], [69.68514252, 21.55430794], [69.68486023, 21.55430794], [69.68486023, 21.5545826], [69.68458557, 21.5545826], [69.6845932, 21.55486107], [69.68430328, 21.55486107], [69.68430328, 21.55513954], [69.68402863, 21.55513954], [69.68402863, 21.55541992], [69.68347168, 21.55541611], [69.68347168, 21.55569458], [69.68319702, 21.55569458], [69.68319702, 21.55597305], [69.6829071, 21.55597115], [69.6829071, 21.55624962], [69.68263245, 21.55624962], [69.68263245, 21.55652809], [69.68235779, 21.55652809], [69.68235779, 21.55680466], [69.68208313, 21.55680466], [69.68208313, 21.55708313], [69.68180847, 21.55708122], [69.68180847, 21.55736923], [69.68152618, 21.55736923], [69.68152618, 21.55763817], [69.68125153, 21.55763817], [69.68125153, 21.55792236], [69.68096924, 21.55792236], [69.68096924, 21.55820274], [69.68069458, 21.55819511], [69.68069458, 21.55847168], [69.68041992, 21.55847168], [69.68041992, 21.55875015], [69.68013763, 21.55875015], [69.68013763, 21.55903244], [69.67986298, 21.55903244], [69.67986298, 21.55931282], [69.67958069, 21.55930519], [69.67958069, 21.55958366], [69.67930603, 21.55958176], [69.67930603, 21.55986023], [69.67903137, 21.55986023], [69.67903137, 21.56014061], [69.67874908, 21.5601387], [69.67874908, 21.56069374], [69.67847443, 21.56069374], [69.67847443, 21.56097221], [69.67819214, 21.56097031], [69.67819214, 21.56125069], [69.67791748, 21.56125069], [69.67791748, 21.56153107], [69.67764282, 21.56153107], [69.67764282, 21.56180954], [69.67736053, 21.56180573], [69.67736053, 21.56208229], [69.67708588, 21.56208038], [69.67708588, 21.56236076], [69.67679596, 21.56236076], [69.67679596, 21.56264114], [69.67652893, 21.56264114], [69.67652893, 21.56291962], [69.67597198, 21.5629158], [69.67597198, 21.56319237], [69.67569733, 21.56319237], [69.67569733, 21.56347466], [69.67542267, 21.56347084], [69.67542267, 21.56375122], [69.67514038, 21.56375122], [69.67514038, 21.56402969], [69.67457581, 21.56402969], [69.67457581, 21.56431007], [69.67430878, 21.56430435], [69.67430878, 21.56458473], [69.67402649, 21.56458473], [69.67402649, 21.5648613], [69.67375183, 21.56485939], [69.67375183, 21.56513977], [69.67318726, 21.56513977], [69.67318726, 21.56542015], [69.67292023, 21.56541443], [69.67292023, 21.56569672], [69.67263794, 21.56569672], [69.67263794, 21.56597137], [69.67236328, 21.56597137], [69.67236328, 21.56624985], [69.67180634, 21.56624031], [69.67180634, 21.56653023], [69.67152405, 21.56652832], [69.67152405, 21.56680679], [69.67124939, 21.56680679], [69.67124939, 21.56708336], [69.67097473, 21.56708336], [69.67097473, 21.56736183], [69.67069244, 21.56735992], [69.67069244, 21.5676403], [69.67041779, 21.5676403], [69.67041779, 21.56792068], [69.67014313, 21.56792068], [69.67014313, 21.56819916], [69.66986084, 21.56819534], [69.66986084, 21.56847191], [69.66958618, 21.56846809], [69.66958618, 21.56875038], [69.66929626, 21.56875038], [69.66929626, 21.56903076], [69.66902924, 21.56903076], [69.66902924, 21.56930923], [69.66874695, 21.56930542], [69.66874695, 21.56958389], [69.66847229, 21.56957817], [69.66847229, 21.56986046], [69.66819763, 21.56986046], [69.66819763, 21.57014084], [69.66791534, 21.57014084], [69.66791534, 21.57069397], [69.66764069, 21.57069397], [69.66764069, 21.57097244], [69.6673584, 21.57097054], [69.6673584, 21.57125092], [69.66707611, 21.57125092], [69.66707611, 21.57152939], [69.66680908, 21.57152939], [69.66680908, 21.57181168], [69.66652679, 21.57180595], [69.66652679, 21.57208252], [69.66625214, 21.57208061], [69.66625214, 21.57237053], [69.66596985, 21.57237053], [69.66596985, 21.57263947], [69.66570282, 21.57263947], [69.66570282, 21.57292175], [69.6654129, 21.57291603], [69.6654129, 21.5731945], [69.66513824, 21.5731945], [69.66513824, 21.57347107], [69.66485596, 21.57347107], [69.66486359, 21.57374954], [69.66458893, 21.57374954], [69.66458893, 21.57403183], [69.66430664, 21.57403183], [69.66430664, 21.5743103], [69.66402435, 21.57430649], [69.66402435, 21.57458115], [69.66374969, 21.57458115], [69.66374969, 21.57486153], [69.66348267, 21.57485962], [69.66348267, 21.57514], [69.66319275, 21.57513809], [69.66319275, 21.57541656], [69.66291809, 21.57541275], [69.66291809, 21.57570076], [69.6626358, 21.57569313], [69.6626358, 21.5759716], [69.66236115, 21.5759697], [69.66236115, 21.57653046], [69.66208649, 21.57653046], [69.66208649, 21.57681084], [69.6618042, 21.57680321], [69.6618042, 21.57708549], [69.66152954, 21.57708549], [69.66152954, 21.57736206], [69.66124725, 21.57736015], [69.66124725, 21.57764053], [69.6609726, 21.57764053], [69.6609726, 21.57792091], [69.66069794, 21.57791519], [69.66069794, 21.57819557], [69.66041565, 21.57819557], [69.66041565, 21.57847214], [69.66014099, 21.57847023], [69.66014099, 21.57875061], [69.6598587, 21.57875061], [69.6598587, 21.57903099], [69.65957642, 21.57903099], [69.65957642, 21.57930946], [69.65930939, 21.57930756], [69.65930176, 21.57958412], [69.6590271, 21.57958031], [69.6590271, 21.57986069], [69.65875244, 21.57986069], [69.65875244, 21.58014107], [69.65846252, 21.58014107], [69.65846252, 21.58041954], [69.6581955, 21.58041763], [69.6581955, 21.5806942], [69.65791321, 21.58069038], [69.65791321, 21.58125114], [69.65763855, 21.58125114], [69.65763855, 21.58153915], [69.65735626, 21.58153915], [69.65735626, 21.58180809], [69.6570816, 21.58180618], [69.6570816, 21.58208275], [69.65680695, 21.58208084], [69.65680695, 21.58236122], [69.65651703, 21.58236122], [69.65651703, 21.58263969], [69.65625, 21.58263969], [69.65625, 21.58291817], [69.65597534, 21.58291626], [69.65597534, 21.58319473], [69.65569305, 21.58319473], [69.65569305, 21.5834713], [69.6554184, 21.58346748], [69.6554184, 21.58374977], [69.65513611, 21.58374977], [69.65513611, 21.58402824], [69.65486145, 21.58402824], [69.65486145, 21.58430862], [69.65458679, 21.58430481], [69.65458679, 21.58458328], [69.6543045, 21.58458328], [69.6543045, 21.58486176], [69.65402985, 21.58486176], [69.65402985, 21.58514023], [69.65374756, 21.58514023], [69.65374756, 21.5857029], [69.6534729, 21.58569527], [69.6534729, 21.58597183], [69.65319824, 21.58597183], [69.65319824, 21.58625031], [69.65291595, 21.58625031], [69.65291595, 21.58653259], [69.65264893, 21.58653259], [69.65264893, 21.58681107], [69.65235901, 21.58680534], [69.65235901, 21.58708382], [69.65208435, 21.58708382], [69.65208435, 21.58736038], [69.65180206, 21.58735085], [69.65180206, 21.58764267], [69.6515274, 21.58764267], [69.6515274, 21.58792114], [69.65125275, 21.58791733], [69.65125275, 21.58819389], [69.65097046, 21.58819389], [69.65097046, 21.58847237], [69.6506958, 21.58847046], [69.6506958, 21.58875084], [69.65040588, 21.58875084], [69.65040588, 21.58903122], [69.65013885, 21.58903122], [69.65013885, 21.58930969], [69.6498642, 21.58930588], [69.6498642, 21.58958244], [69.64958191, 21.58958054], [69.64958191, 21.58986092], [69.64930725, 21.58986092], [69.64930725, 21.59041405], [69.64902496, 21.59041405], [69.64902496, 21.59069633], [69.64875031, 21.59069633], [69.64875031, 21.59097481], [69.64847565, 21.59097481], [69.64848328, 21.59124947], [69.64819336, 21.59124947], [69.64819336, 21.59152985], [69.6479187, 21.59152794], [69.6479187, 21.59208488], [69.64763641, 21.59208488], [69.64763641, 21.59236145], [69.64736176, 21.59235954], [69.64736176, 21.59263992], [69.64679718, 21.59263992], [69.64679718, 21.5929203], [69.64652252, 21.5929203], [69.64652252, 21.59320068], [69.64624786, 21.59320068], [69.64624786, 21.59348106], [69.64597321, 21.59348106], [69.64597321, 21.59375], [69.64569092, 21.59375], [69.64569092, 21.59403038], [69.64541626, 21.59403038], [69.64541626, 21.59431076], [69.6451416, 21.59430695], [69.6451416, 21.59486198], [69.64485931, 21.59486008], [69.64485931, 21.59514046], [69.64457703, 21.59514046], [69.64457703, 21.59542084], [69.64430237, 21.59541893], [69.64430237, 21.59569359], [69.64402771, 21.59569359], [69.64402771, 21.59597206], [69.64375305, 21.59596825], [69.64375305, 21.59625053], [69.64347839, 21.59625053], [69.64347839, 21.59654236], [69.64319611, 21.59654236], [69.64319611, 21.59680939], [69.64291382, 21.59680557], [69.64291382, 21.59708405], [69.64263916, 21.59707832], [69.64263916, 21.59736061], [69.64235687, 21.59736061], [69.64235687, 21.59763908], [69.64208221, 21.59763908], [69.64208221, 21.59791946], [69.64180756, 21.59791756], [69.64180756, 21.59819412], [69.64152527, 21.59819412], [69.64152527, 21.5984726], [69.64125061, 21.59847069], [69.64125061, 21.59874916], [69.64068604, 21.59874916], [69.64068604, 21.59902954], [69.64041901, 21.59902954], [69.64041901, 21.59931183], [69.64013672, 21.59930611], [69.64013672, 21.59958267], [69.63986206, 21.59958076], [69.63986206, 21.59986115], [69.63957977, 21.59986115], [69.63957977, 21.60013962], [69.63931274, 21.60013962], [69.63931274, 21.60042191], [69.63903046, 21.60041618], [69.63903046, 21.60069466], [69.63874817, 21.60069466], [69.63874817, 21.60097122], [69.63846588, 21.60097122], [69.63846588, 21.60124969], [69.63819122, 21.60124969], [69.63819122, 21.60153008], [69.63791656, 21.60152817], [69.63791656, 21.60180473], [69.63764191, 21.60180473], [69.63764191, 21.6020813], [69.63735962, 21.6020813], [69.63735962, 21.60236168], [69.63707733, 21.60235023], [69.63707733, 21.60264015], [69.63680267, 21.60264015], [69.63680267, 21.60320091], [69.63652802, 21.60319328], [69.63652802, 21.60347176], [69.63625336, 21.60346985], [69.63625336, 21.60375023], [69.63597107, 21.60375023], [69.63597107, 21.60403061], [69.63569641, 21.60403061], [69.63569641, 21.60431099], [69.63541412, 21.60430336], [69.63541412, 21.60458565], [69.63513947, 21.60457993], [69.63513947, 21.60486031], [69.63485718, 21.60486031], [69.63485718, 21.60514069], [69.63458252, 21.60514069], [69.63458252, 21.60542107], [69.63430786, 21.60541534], [69.63430786, 21.60569572], [69.63402557, 21.60569572], [69.63402557, 21.60597229], [69.63375092, 21.60597038], [69.63375092, 21.60625076], [69.63346863, 21.60625076], [69.63346863, 21.60653114], [69.63319397, 21.60652542], [69.63319397, 21.60708427], [69.63291931, 21.60708046], [69.63291931, 21.60736084], [69.63263702, 21.60736084], [69.63263702, 21.60764122], [69.63236237, 21.60764122], [69.63236237, 21.60791969], [69.63208008, 21.60791779], [69.63208008, 21.60819435], [69.63181305, 21.60819054], [69.63181305, 21.60848045], [69.63153076, 21.60847282], [69.63153839, 21.60874939], [69.63124847, 21.60874939], [69.63124847, 21.60902977], [69.63096619, 21.60902977], [69.63096619, 21.60930824], [69.63069153, 21.60930634], [69.63069153, 21.6095829], [69.63041687, 21.6095829], [69.63041687, 21.60986137], [69.63014221, 21.60985947], [69.63014221, 21.61013985], [69.62985992, 21.61013985], [69.62985992, 21.61041832], [69.62958527, 21.61041641], [69.62958527, 21.61097145], [69.62930298, 21.61096764], [69.62930298, 21.61124992], [69.62902832, 21.61124992], [69.62902832, 21.6115284], [69.62874603, 21.61152077], [69.62874603, 21.61181259], [69.62847137, 21.61180496], [69.62847137, 21.61208344], [69.62819672, 21.61208344], [69.62819672, 21.61236191], [69.6279068, 21.61236191], [69.6279068, 21.61264038], [69.62763977, 21.61264038], [69.62763977, 21.61292267], [69.62735748, 21.61291695], [69.62735748, 21.6131916], [69.62708282, 21.61319542], [69.62708282, 21.61347008], [69.62680817, 21.61347008], [69.62680817, 21.61375046], [69.62652588, 21.61375046], [69.62652588, 21.61431122], [69.62625122, 21.61431122], [69.62625122, 21.61486053], [69.62596893, 21.61486053], [69.62596893, 21.61541939], [69.62569427, 21.61541748], [69.62569427, 21.61569214], [69.62541962, 21.61569214], [69.62541962, 21.61597252], [69.62486267, 21.61597061], [69.62486267, 21.6162529], [69.62458038, 21.6162529], [69.62458038, 21.61652946], [69.62431335, 21.61652946], [69.62431335, 21.61680984], [69.62403107, 21.61680412], [69.62403107, 21.6170826], [69.62346649, 21.61708069], [69.62346649, 21.61736107], [69.62319183, 21.61736107], [69.62319183, 21.61765099], [69.62291718, 21.61765099], [69.62291718, 21.61791992], [69.62264252, 21.6179142], [69.62264252, 21.61819649], [69.62208557, 21.61819649], [69.62208557, 21.61847305], [69.62180328, 21.61847115], [69.62180328, 21.61874962], [69.62152863, 21.61874962], [69.62152863, 21.61903], [69.62124634, 21.61902618], [69.62124634, 21.61930656], [69.62097168, 21.61930656], [69.62097168, 21.61958313], [69.62069702, 21.61958122], [69.62069702, 21.62014008], [69.6204071, 21.62014008], [69.6204071, 21.62042046], [69.62014008, 21.62042046], [69.62014008, 21.62070847], [69.61985779, 21.62069511], [69.61985779, 21.62097168], [69.61958313, 21.62096977], [69.61958313, 21.62125015], [69.61930847, 21.62125015], [69.61930847, 21.62181091], [69.61902618, 21.62180519], [69.61902618, 21.62208366], [69.61875153, 21.62207985], [69.61875153, 21.62236023], [69.61846924, 21.62236023], [69.61846924, 21.62264061], [69.61818695, 21.62264061], [69.61818695, 21.62291908], [69.61763763, 21.62291718], [69.61763763, 21.62319374], [69.61736298, 21.62319374], [69.61736298, 21.62347221], [69.61680603, 21.62346077], [69.61680603, 21.62375069], [69.616539, 21.62375069], [69.616539, 21.62402916], [69.61624908, 21.62402916], [69.61624908, 21.62431145], [69.61597443, 21.62430573], [69.61597443, 21.6245842], [69.61569214, 21.62457848], [69.61569214, 21.62486076], [69.61541748, 21.62486076], [69.61541748, 21.62513924], [69.61486053, 21.62513924], [69.61486053, 21.62541962], [69.61458588, 21.6254158], [69.61458588, 21.62597275], [69.61429596, 21.62597084], [69.61429596, 21.62625122], [69.61402893, 21.62625122], [69.61402893, 21.62681007], [69.61374664, 21.62680626], [69.61374664, 21.62708282], [69.61402893, 21.62708282], [69.61402893, 21.6273613], [69.61374664, 21.62735939], [69.61374664, 21.62763977], [69.61319733, 21.62763977], [69.61319733, 21.62792015], [69.61264038, 21.62791634], [69.61264038, 21.62819481], [69.61152649, 21.62819481], [69.61152649, 21.62847137], [69.61125183, 21.62846947], [69.61125183, 21.62874985], [69.6104126, 21.62874985], [69.6104126, 21.62846947], [69.61013794, 21.62846947], [69.61013794, 21.62903023], [69.60986328, 21.62902832], [69.60986328, 21.62930489], [69.60958099, 21.62930489], [69.60958099, 21.62986374], [69.60930634, 21.62986374], [69.60930634, 21.63010979], [69.60874939, 21.6301384], [69.60874939, 21.63043976], [69.60874939, 21.63070107], [69.60847473, 21.63069344], [69.60847473, 21.63097191], [69.60819244, 21.63097], [69.60819244, 21.63125038], [69.60791779, 21.63125038], [69.60791779, 21.63181114], [69.6076355, 21.63180351], [69.6076355, 21.6320858], [69.60735321, 21.63208008], [69.60735321, 21.63265038], [69.60624695, 21.63265038], [69.60624695, 21.63292122], [69.60569763, 21.6329174], [69.60569763, 21.63347244], [69.60514069, 21.63347054], [69.60514069, 21.63375092], [69.6048584, 21.63375092], [69.6048584, 21.63430977], [69.60402679, 21.63430786], [69.60402679, 21.63458252], [69.60319519, 21.63458252], [69.60320282, 21.63513947], [69.6029129, 21.63513947], [69.6029129, 21.63597298], [69.60263824, 21.63597107], [69.60263824, 21.63652992], [69.60235596, 21.63652992], [69.60235596, 21.6368084], [69.6020813, 21.63680649], [69.6020813, 21.63736153], [69.60069275, 21.63735962], [69.60069275, 21.63763809], [69.59902954, 21.63763809], [69.59902954, 21.63791847], [69.59784698, 21.63791847], [69.59485626, 21.63791847], [69.59485626, 21.63820267], [69.5945816, 21.63820267], [69.5945816, 21.63791847], [69.59430695, 21.63791847], [69.59430695, 21.63820267], [69.59263611, 21.63819504], [69.59263611, 21.6384716], [69.5909729, 21.6384716], [69.5909729, 21.63791656], [69.59069824, 21.63791847], [69.59069061, 21.63735962], [69.58985901, 21.63736153], [69.58985901, 21.63708305], [69.5901413, 21.63708305], [69.5901413, 21.63680649], [69.59041595, 21.63680077], [69.59041595, 21.63652992], [69.5909729, 21.63652992], [69.5909729, 21.63624954], [69.59124756, 21.63624954], [69.59124756, 21.63597107], [69.59152985, 21.63597298], [69.59152985, 21.6356945], [69.59236145, 21.6356945], [69.59236145, 21.63541794], [69.59263611, 21.63541985], [69.59263611, 21.63513947], [69.59319305, 21.63513947], [69.59319305, 21.63402939], [69.59348297, 21.63402939], [69.59348297, 21.63319016], [69.59319305, 21.63319588], [69.59319305, 21.6329174], [69.59236908, 21.63292122], [69.59236908, 21.63236046], [69.59208679, 21.63236046], [69.59208679, 21.63153076], [69.59236908, 21.63153076], [69.59236908, 21.63042068], [69.5929184, 21.63042068], [69.5929184, 21.62985992], [69.59319305, 21.62986374], [69.59319305, 21.62930489], [69.5918045, 21.62930489], [69.5918045, 21.62902832], [69.59152985, 21.62903023], [69.59152985, 21.62874985], [69.59124756, 21.62874985], [69.59124756, 21.62846947], [69.5909729, 21.62847137], [69.5909729, 21.62791634], [69.59069824, 21.62792015], [69.59069824, 21.62735939], [69.59124756, 21.6273613], [69.59124756, 21.62708282], [69.59152985, 21.62708282], [69.59152985, 21.62624931], [69.59179688, 21.62625122], [69.59179688, 21.62541962], [69.59124756, 21.6254158], [69.59124756, 21.62597275], [69.58930206, 21.62597275], [69.58930206, 21.62430573], [69.58985901, 21.62431145], [69.58985901, 21.62402916], [69.5901413, 21.62402916], [69.5901413, 21.62375069], [69.5909729, 21.62375069], [69.5909729, 21.62346077], [69.59069824, 21.62347221], [69.59069061, 21.62291718], [69.59041595, 21.62291908], [69.59041595, 21.62236023], [69.5901413, 21.62236023], [69.5901413, 21.62042046], [69.58957672, 21.62042046], [69.58957672, 21.62070847], [69.58930969, 21.62070847], [69.58930969, 21.62042046], [69.5890274, 21.62042046], [69.5890274, 21.62070847], [69.58847046, 21.62069511], [69.58847046, 21.62097168], [69.58763885, 21.62096977], [69.58763885, 21.62153053], [69.5873642, 21.62152863], [69.5873642, 21.62319374], [69.58763885, 21.62318993], [69.58763885, 21.62431145], [69.58790588, 21.62431145], [69.58790588, 21.62486076], [69.5881958, 21.62486076], [69.5881958, 21.62569427], [69.58847046, 21.62569427], [69.58847046, 21.62652779], [69.58875275, 21.62652779], [69.58875275, 21.6273613], [69.5890274, 21.6273613], [69.5890274, 21.62847137], [69.58930969, 21.62846947], [69.58930969, 21.62903023], [69.58957672, 21.62903023], [69.58957672, 21.62959099], [69.58985901, 21.62958336], [69.58985901, 21.62986374], [69.5901413, 21.62985992], [69.5901413, 21.6301403], [69.59041595, 21.6301403], [69.59041595, 21.63070107], [69.59069824, 21.63069344], [69.59069824, 21.63097191], [69.5909729, 21.63097], [69.5909729, 21.63153076], [69.59124756, 21.63153076], [69.59124756, 21.63236046], [69.59152985, 21.63236046], [69.59152985, 21.63319588], [69.59179688, 21.63319016], [69.59179688, 21.63430977], [69.59152985, 21.63430977], [69.59152985, 21.63486099], [69.59124756, 21.63486099], [69.59124756, 21.63513947], [69.5909729, 21.63513947], [69.5909729, 21.63541985], [69.59041595, 21.63541794], [69.59041595, 21.6356945], [69.58985901, 21.6356945], [69.58985901, 21.63597298], [69.58957672, 21.63597107], [69.58957672, 21.63624954], [69.58847046, 21.63624954], [69.58847046, 21.63652992], [69.58708191, 21.63652992], [69.58708191, 21.6368084], [69.58625031, 21.63680649], [69.58625031, 21.63708305], [69.58569336, 21.63708305], [69.58569336, 21.63736153], [69.58486176, 21.63735962], [69.58486176, 21.63763809], [69.5845871, 21.63763809], [69.5845871, 21.63791847], [69.58403015, 21.63791847], [69.58403015, 21.63820267], [69.58374786, 21.63819504], [69.58374786, 21.6384716], [69.58347321, 21.63845825], [69.58347321, 21.63875008], [69.58318329, 21.63875008], [69.58318329, 21.63903046], [69.58291626, 21.63903046], [69.58291626, 21.63931274], [69.5826416, 21.63930511], [69.5826416, 21.63958359], [69.58235931, 21.63958359], [69.58235931, 21.63986015], [69.58207703, 21.63986015], [69.58207703, 21.64014053], [69.58180237, 21.64014053], [69.58180237, 21.64042282], [69.58125305, 21.6404171], [69.58125305, 21.64069366], [69.58097076, 21.64069366], [69.58097076, 21.64097023], [69.58040619, 21.64097023], [69.58040619, 21.64125061], [69.58013916, 21.64125061], [69.58013916, 21.6415329], [69.57958221, 21.6415329], [69.57958221, 21.64180946], [69.57930756, 21.64180565], [69.57930756, 21.64208221], [69.57875061, 21.64208031], [69.57875061, 21.64236069], [69.57847595, 21.64236069], [69.57847595, 21.64264107], [69.57791901, 21.64264107], [69.57791901, 21.64291954], [69.57763672, 21.64291763], [69.57763672, 21.64319229], [69.57736206, 21.64319229], [69.57736206, 21.64347458], [69.57681274, 21.64347076], [69.57681274, 21.64375114], [69.57653046, 21.64375114], [69.57653046, 21.64402962], [69.57624817, 21.64402962], [69.57624817, 21.64431], [69.57596588, 21.64431], [69.57596588, 21.64459038], [69.57541656, 21.64459038], [69.57541656, 21.64486122], [69.57514191, 21.64486122], [69.57514191, 21.64624977], [69.57430267, 21.64624977], [69.57430267, 21.64596939], [69.57375336, 21.64596939], [69.57375336, 21.64624977], [69.57347107, 21.64624977], [69.57347107, 21.64653015], [69.57236481, 21.64652824], [69.57236481, 21.64680672], [69.57152557, 21.64680672], [69.57152557, 21.64708328], [69.57125092, 21.64708328], [69.57125092, 21.64736176], [69.57096863, 21.64735985], [69.57096863, 21.64764977], [69.57068634, 21.64764977], [69.57068634, 21.64819908], [69.57041931, 21.64819527], [69.57041931, 21.64847183], [69.57013702, 21.64846992], [69.57013702, 21.64875031], [69.56986237, 21.64875031], [69.56986237, 21.64903069], [69.56958008, 21.64903069], [69.56958008, 21.64930916], [69.56930542, 21.64930534], [69.56931305, 21.64986038], [69.56903076, 21.64986038], [69.56903076, 21.65014076], [69.56874847, 21.65014076], [69.56874847, 21.65041924], [69.56819153, 21.65041733], [69.56819153, 21.65069389], [69.56791687, 21.65069389], [69.56791687, 21.65097237], [69.56764221, 21.65097046], [69.56764221, 21.65125084], [69.56735992, 21.65125084], [69.56735992, 21.65152931], [69.5670929, 21.65152931], [69.5670929, 21.6518116], [69.56735992, 21.65180588], [69.56735992, 21.65208244], [69.56708527, 21.65208244], [69.5670929, 21.65236092], [69.56624603, 21.65236092], [69.56624603, 21.65263939], [69.5654068, 21.65263939], [69.5654068, 21.65292168], [69.56458282, 21.65291595], [69.56458282, 21.65319443], [69.56402588, 21.65319443], [69.56402588, 21.6534729], [69.56375122, 21.6534729], [69.56375122, 21.65374947], [69.56318665, 21.65374947], [69.56318665, 21.65402985], [69.56263733, 21.65402985], [69.56263733, 21.65431023], [69.56236267, 21.65430641], [69.56236267, 21.65458107], [69.56180573, 21.65458107], [69.56180573, 21.65486145], [69.56124878, 21.65485954], [69.56124878, 21.65513992], [69.56096649, 21.65513992], [69.56096649, 21.6554203], [69.56041718, 21.6554203], [69.56041718, 21.65570068], [69.56014252, 21.65570068], [69.56014252, 21.65625], [69.55986023, 21.65625], [69.55986023, 21.65653038], [69.5595932, 21.65653038], [69.5595932, 21.6568203], [69.55930328, 21.65680313], [69.55930328, 21.65736389], [69.55902863, 21.65736008], [69.55902863, 21.65764046], [69.55874634, 21.65764046], [69.55874634, 21.65792084], [69.55847168, 21.65791512], [69.55847168, 21.65847206], [69.55819702, 21.65847015], [69.55819702, 21.65875053], [69.5579071, 21.65875053], [69.5579071, 21.65903091], [69.55764008, 21.65903091], [69.55764008, 21.65930939], [69.55735779, 21.65930939], [69.55735779, 21.65958977], [69.55708313, 21.65958977], [69.55708313, 21.65986061], [69.55680847, 21.65986061], [69.55680847, 21.66014099], [69.55652618, 21.66013908], [69.55652618, 21.66069412], [69.55596924, 21.66069412], [69.55596924, 21.6609726], [69.55568695, 21.66097069], [69.55568695, 21.66125107], [69.55513763, 21.66125107], [69.55513763, 21.66152954], [69.55486298, 21.66152954], [69.55486298, 21.66180992], [69.55458069, 21.66180611], [69.55458069, 21.66208267], [69.55430603, 21.66208076], [69.55430603, 21.66236115], [69.55403137, 21.66236115], [69.55403137, 21.66263962], [69.5534668, 21.66263008], [69.5534668, 21.66291809], [69.55319214, 21.66291618], [69.55319214, 21.66319466], [69.55291748, 21.66319466], [69.55291748, 21.66347313], [69.55263519, 21.66347313], [69.55264282, 21.66374969], [69.55236053, 21.66374969], [69.55236053, 21.66402817], [69.55208588, 21.66402817], [69.55208588, 21.66430473], [69.55180359, 21.66430473], [69.55180359, 21.66458321], [69.55152893, 21.66458321], [69.55152893, 21.66486168], [69.55124664, 21.66485977], [69.55124664, 21.66514015], [69.55069733, 21.66514015], [69.55069733, 21.66542244], [69.55041504, 21.66541672], [69.55041504, 21.66569519], [69.55014038, 21.66569519], [69.55014038, 21.66597176], [69.54985809, 21.66597176], [69.54985809, 21.66625023], [69.54957581, 21.66625023], [69.54957581, 21.66653252], [69.54930878, 21.66653252], [69.54930878, 21.6668129], [69.54902649, 21.66680527], [69.54902649, 21.66708374], [69.54846954, 21.66708183], [69.54846954, 21.66736031], [69.54818726, 21.66736031], [69.54818726, 21.66764069], [69.54792023, 21.66764069], [69.54792023, 21.66792107], [69.54763794, 21.66791725], [69.54763794, 21.66819382], [69.54736328, 21.66819382], [69.54736328, 21.66847229], [69.54680634, 21.66847038], [69.54680634, 21.6687603], [69.54651642, 21.6687603], [69.54651642, 21.66903114], [69.54624939, 21.66903114], [69.54624939, 21.66930962], [69.54597473, 21.6693058], [69.54597473, 21.66958237], [69.54569244, 21.66958046], [69.54569244, 21.66986084], [69.54514313, 21.66986084], [69.54514313, 21.67014122], [69.54486084, 21.67014122], [69.54486084, 21.67041969], [69.54458618, 21.67041588], [69.54458618, 21.67069244], [69.54430389, 21.67069244], [69.54430389, 21.67097473], [69.54402924, 21.67097092], [69.54402924, 21.67124939], [69.54374695, 21.67124939], [69.54374695, 21.67152977], [69.54347229, 21.67152786], [69.54347229, 21.6720829], [69.54319763, 21.6720829], [69.54319763, 21.67236137], [69.54292297, 21.67235947], [69.54292297, 21.67263985], [69.54264069, 21.67263985], [69.54264069, 21.67292023], [69.5423584, 21.67291451], [69.5423584, 21.67319679], [69.54208374, 21.67319679], [69.54208374, 21.67347145], [69.54180908, 21.67346954], [69.54180908, 21.67374992], [69.54152679, 21.67374992], [69.54152679, 21.6740303], [69.54125977, 21.6740303], [69.54125977, 21.67431068], [69.5404129, 21.67430687], [69.5404129, 21.67458344], [69.53986359, 21.67458344], [69.53986359, 21.67486191], [69.5395813, 21.67485809], [69.5395813, 21.67514038], [69.53930664, 21.67514038], [69.53930664, 21.67542076], [69.53902435, 21.67541885], [69.53901672, 21.6756897], [69.53874969, 21.67569542], [69.53874969, 21.67597198], [69.53819275, 21.67596817], [69.53819275, 21.67625046], [69.5376358, 21.67625046], [69.5376358, 21.67653084], [69.53736115, 21.67653084], [69.53736115, 21.67680931], [69.53708649, 21.6768055], [69.53708649, 21.67708397], [69.53679657, 21.67707825], [69.53679657, 21.67736053], [69.53652954, 21.67736053], [69.53652954, 21.67764091], [69.53624725, 21.67762947], [69.53624725, 21.67791939], [69.5359726, 21.67791748], [69.5359726, 21.67819405], [69.53569794, 21.67819405], [69.53569794, 21.67847252], [69.53513336, 21.67847061], [69.53513336, 21.67874908], [69.5348587, 21.67874908], [69.5348587, 21.67902946], [69.53457642, 21.67902946], [69.53457642, 21.67931175], [69.53430939, 21.67931175], [69.53430176, 21.68013954], [69.5340271, 21.68013954], [69.5340271, 21.6807003], [69.53347015, 21.68069458], [69.53347015, 21.68097115], [69.53263855, 21.68097115], [69.53263855, 21.68124962], [69.53208923, 21.68124962], [69.53208923, 21.68153191], [69.53180695, 21.68152809], [69.53180695, 21.68180466], [69.53152466, 21.68180466], [69.53152466, 21.68208122], [69.53125, 21.68208122], [69.53125, 21.6823616], [69.53098297, 21.6823597], [69.53098297, 21.68264008], [69.53069305, 21.68264008], [69.53069305, 21.68292046], [69.5304184, 21.68292046], [69.5304184, 21.68320084], [69.53013611, 21.68319321], [69.53013611, 21.68347168], [69.52986145, 21.68346977], [69.52986145, 21.68375969], [69.52958679, 21.68375969], [69.52958679, 21.68403053], [69.52902985, 21.68403053], [69.52902985, 21.68431091], [69.52874756, 21.68430328], [69.52874756, 21.68458557], [69.5284729, 21.68457985], [69.5284729, 21.68486023], [69.52819824, 21.68486023], [69.52819824, 21.68514061], [69.52791595, 21.68514061], [69.52791595, 21.68542099], [69.5276413, 21.68541527], [69.5276413, 21.68569374], [69.52735901, 21.68569374], [69.52735901, 21.68597221], [69.52707672, 21.68597031], [69.52707672, 21.68625069], [69.52680206, 21.68625069], [69.52680206, 21.68653107], [69.5265274, 21.68652534], [69.5265274, 21.68680763], [69.52625275, 21.68680763], [69.52625275, 21.6870842], [69.52597046, 21.68708038], [69.52597046, 21.68736076], [69.5256958, 21.68736076], [69.5256958, 21.68764114], [69.52540588, 21.68764114], [69.52540588, 21.68791962], [69.5248642, 21.68791771], [69.5248642, 21.68819427], [69.52458191, 21.68819427], [69.52458191, 21.68847275], [69.52430725, 21.68847084], [69.52430725, 21.68875122], [69.52403259, 21.68875122], [69.52403259, 21.68902969], [69.52375031, 21.68902969], [69.52375031, 21.68930817], [69.52347565, 21.68930626], [69.52347565, 21.68958282], [69.52319336, 21.68958282], [69.52319336, 21.6898613], [69.5229187, 21.68985748], [69.5229187, 21.69013977], [69.52263641, 21.69013977], [69.52263641, 21.69041824], [69.52236176, 21.69041634], [69.52236176, 21.69069481], [69.5220871, 21.69069481], [69.5220871, 21.69097137], [69.52179718, 21.69096756], [69.52179718, 21.69124985], [69.52153015, 21.69124985], [69.52153015, 21.69153023], [69.52124786, 21.69152832], [69.52124786, 21.69180489], [69.52069092, 21.69180489], [69.52069092, 21.69208336], [69.52041626, 21.69208336], [69.52041626, 21.69236183], [69.52014923, 21.69236183], [69.52014923, 21.6926403], [69.51985931, 21.6926403], [69.51985931, 21.69293022], [69.51957703, 21.69293022], [69.51957703, 21.69320107], [69.51930237, 21.69319534], [69.51930237, 21.69347191], [69.51902771, 21.69347191], [69.51902771, 21.69375038], [69.51875305, 21.69375038], [69.51875305, 21.69403267], [69.51847076, 21.69403267], [69.51847076, 21.69431114], [69.51819611, 21.69430542], [69.51819611, 21.69458389], [69.51790619, 21.69458008], [69.51790619, 21.69486046], [69.51763916, 21.69486046], [69.51763916, 21.69514275], [69.51708984, 21.69514275], [69.51708984, 21.69542122], [69.51680756, 21.69542122], [69.51680756, 21.69569969], [69.51652527, 21.69569206], [69.51652527, 21.69597244], [69.51625061, 21.69597054], [69.51625061, 21.69625092], [69.51597595, 21.69625092], [69.51597595, 21.69652939], [69.51568604, 21.69652939], [69.51568604, 21.69680977], [69.51541901, 21.69680405], [69.51541901, 21.69708252], [69.51513672, 21.69708061], [69.51513672, 21.69736099], [69.51486206, 21.69736099], [69.51486206, 21.69763947], [69.51457977, 21.69763947], [69.51457977, 21.69791985], [69.51430511, 21.69791412], [69.51430511, 21.69819641], [69.51403046, 21.69819641], [69.51403046, 21.69847488], [69.51374817, 21.69847488], [69.51374817, 21.69874954], [69.51319122, 21.69874001], [69.51319122, 21.69902992], [69.51291656, 21.69902992], [69.51291656, 21.6993103], [69.51264191, 21.69930458], [69.51264191, 21.69958305], [69.51235962, 21.69958305], [69.51235962, 21.69986153], [69.51207733, 21.69985962], [69.51207733, 21.70014], [69.51180267, 21.70014], [69.51180267, 21.70042038], [69.51152802, 21.70042038], [69.51152802, 21.70070076], [69.51125336, 21.70069695], [69.51125336, 21.7009716], [69.51095581, 21.7009697], [69.51095581, 21.70125008], [69.51069641, 21.70125008], [69.51069641, 21.70153046], [69.51041412, 21.70152855], [69.51041412, 21.70180511], [69.51013947, 21.70180511], [69.51013947, 21.70208359], [69.50986481, 21.70208359], [69.50986481, 21.70236206], [69.50958252, 21.70236015], [69.50958252, 21.70292091], [69.50930786, 21.7029171], [69.50930786, 21.70319366], [69.50902557, 21.70319366], [69.50902557, 21.70347214], [69.50875092, 21.70346832], [69.50875092, 21.70375061], [69.50846863, 21.70375061], [69.50846863, 21.70402908], [69.50818634, 21.70402908], [69.50818634, 21.70430946], [69.50763702, 21.70430565], [69.50763702, 21.70458412], [69.50736237, 21.7045784], [69.50736237, 21.70487022], [69.50708008, 21.70487022], [69.50708008, 21.70513916], [69.50681305, 21.70513916], [69.50681305, 21.70541954], [69.50653076, 21.70541763], [69.50653076, 21.7056942], [69.50597382, 21.7056942], [69.50597382, 21.70597267], [69.50569153, 21.70597076], [69.50569153, 21.70624924], [69.50541687, 21.70624924], [69.50541687, 21.70652962], [69.50514984, 21.70652962], [69.50514984, 21.7068119], [69.50485992, 21.70680618], [69.50485992, 21.70708275], [69.50458527, 21.70708275], [69.5045929, 21.70736122], [69.50430298, 21.70736122], [69.50430298, 21.70763969], [69.50374603, 21.70763969], [69.50374603, 21.70792961], [69.50347137, 21.70791626], [69.50347137, 21.70819473], [69.50319672, 21.70819473], [69.50319672, 21.7084713], [69.5029068, 21.70846939], [69.5029068, 21.70874977], [69.50263977, 21.70874977], [69.50263977, 21.70903015], [69.50235748, 21.70902824], [69.50235748, 21.70930481], [69.50208282, 21.70930481], [69.50208282, 21.70958328], [69.50180817, 21.70958328], [69.50180817, 21.70986176], [69.50152588, 21.70985985], [69.50152588, 21.71014023], [69.50125122, 21.71014023], [69.50125122, 21.71042061], [69.50068665, 21.71042061], [69.50068665, 21.71070099], [69.50041962, 21.71069336], [69.50041962, 21.71097183], [69.50013733, 21.71096992], [69.50013733, 21.71125031], [69.49986267, 21.71125031], [69.49986267, 21.71153069], [69.49958038, 21.71153069], [69.49958038, 21.71181107], [69.49930573, 21.71180344], [69.49930573, 21.71208572], [69.49901581, 21.71208], [69.49901581, 21.71236038], [69.49874878, 21.71236038], [69.49874878, 21.71264076], [69.49846649, 21.71264076], [69.49846649, 21.71292114], [69.49819183, 21.71291542], [69.49819183, 21.7131958], [69.49791718, 21.7131958], [69.49791718, 21.71347237], [69.49764252, 21.71347237], [69.49764252, 21.71375084], [69.49736023, 21.7137394], [69.49736023, 21.71403122], [69.4970932, 21.71403122], [69.4970932, 21.71430969], [69.49680328, 21.71430779], [69.49680328, 21.71458244], [69.49652863, 21.71458054], [69.49652863, 21.71486092], [69.49624634, 21.71486092], [69.49624634, 21.71513939], [69.49595642, 21.71513939], [69.49595642, 21.71541977], [69.49569702, 21.71541786], [69.49569702, 21.71569443], [69.49541473, 21.71569443], [69.49541473, 21.7159729], [69.49514008, 21.71597099], [69.49514008, 21.71624947], [69.49485779, 21.71624947], [69.49485779, 21.71652985], [69.49458313, 21.71652985], [69.49458313, 21.71680832], [69.49430847, 21.71680641], [69.49430847, 21.71708298], [69.49402618, 21.71707916], [69.49402618, 21.71763992], [69.49375153, 21.71763992], [69.49375153, 21.7179184], [69.49346924, 21.7179184], [69.49346924, 21.71820259], [69.49319458, 21.71819496], [69.49319458, 21.71847153], [69.49291992, 21.71847153], [69.49291992, 21.71875191], [69.49263763, 21.71875191], [69.49263763, 21.71903038], [69.49236298, 21.71903038], [69.49236298, 21.71931267], [69.49208069, 21.71930504], [69.49208069, 21.71958351], [69.49180603, 21.7195816], [69.49180603, 21.71986961], [69.49153137, 21.71986961], [69.49153137, 21.72014046], [69.49124908, 21.72014046], [69.49124908, 21.72042274], [69.49097443, 21.72041702], [69.49097443, 21.72069359], [69.49069214, 21.72069359], [69.49069214, 21.72097015], [69.49041748, 21.72097015], [69.49041748, 21.72125053], [69.49014282, 21.72125053], [69.49014282, 21.72153282], [69.48986053, 21.72153282], [69.48986053, 21.72180939], [69.48958588, 21.72180557], [69.48958588, 21.72208214], [69.48929596, 21.72208023], [69.48929596, 21.72236061], [69.48902893, 21.72236061], [69.48902893, 21.7226429], [69.48874664, 21.72263908], [69.48874664, 21.72291756], [69.48847198, 21.72291756], [69.48847198, 21.7234726], [69.48819733, 21.72347069], [69.48819733, 21.72402954], [69.48791504, 21.72402763], [69.48791504, 21.72458267], [69.48764038, 21.72458076], [69.48764038, 21.72513962], [69.48735809, 21.72513962], [69.48735809, 21.72542], [69.48680878, 21.72541428], [69.48680878, 21.72569656], [69.48652649, 21.72569656], [69.48652649, 21.72597313], [69.48568726, 21.72597122], [69.48568726, 21.72624969], [69.48542023, 21.72624969], [69.48542023, 21.72653008], [69.48513794, 21.72652626], [69.48513794, 21.72680664], [69.48486328, 21.72680664], [69.48486328, 21.72708321], [69.48458099, 21.72708321], [69.48458099, 21.72736168], [69.48401642, 21.72735977], [69.48401642, 21.72764015], [69.48374939, 21.72764015], [69.48374939, 21.72792053], [69.4834671, 21.72792053], [69.4834671, 21.72820091], [69.48319244, 21.72819519], [69.48319244, 21.72847176], [69.48291779, 21.72846985], [69.48291779, 21.72875023], [69.48264313, 21.72875023], [69.48264313, 21.72903061], [69.48236084, 21.7290287], [69.48236084, 21.72958374], [69.48208618, 21.72957993], [69.48208618, 21.72986031], [69.48179626, 21.72986031], [69.48179626, 21.73014069], [69.48152924, 21.73014069], [69.48152924, 21.73069382], [69.48124695, 21.73069382], [69.48124695, 21.73097229], [69.48097229, 21.73097229], [69.48097992, 21.73125076], [69.48069763, 21.73125076], [69.48069763, 21.73152924], [69.48042297, 21.73152924], [69.48042297, 21.73181152], [69.48014069, 21.7318058], [69.48014069, 21.73208427], [69.4798584, 21.73207855], [69.4798584, 21.73236084], [69.47957611, 21.73236084], [69.47957611, 21.73291969], [69.47930908, 21.73291588], [69.47930908, 21.73319435], [69.47902679, 21.73319435], [69.47902679, 21.73347282], [69.47875214, 21.73347282], [69.47875214, 21.73374939], [69.47846985, 21.73374939], [69.47846985, 21.73402977], [69.47820282, 21.73402977], [69.47820282, 21.73431015], [69.4779129, 21.73430634], [69.4779129, 21.7345829], [69.47763824, 21.7345829], [69.47763824, 21.73486137], [69.4770813, 21.73485184], [69.4770813, 21.73513985], [69.47680664, 21.73513985], [69.47680664, 21.73542023], [69.47652435, 21.73541641], [69.47652435, 21.73569489], [69.47624969, 21.73569489], [69.47624969, 21.73597145], [69.47597504, 21.73597145], [69.47598267, 21.73624992], [69.47541809, 21.73624992], [69.47541809, 21.7365303], [69.4751358, 21.7365303], [69.4751358, 21.73681068], [69.47486115, 21.73680305], [69.47486115, 21.73708344], [69.47458649, 21.73708344], [69.47458649, 21.73736191], [69.47429657, 21.73736], [69.47429657, 21.73764038], [69.47402954, 21.73763847], [69.47402954, 21.73791695], [69.4734726, 21.73791695], [69.4734726, 21.7381897], [69.47319794, 21.73819351], [69.47319794, 21.73847198], [69.47291565, 21.73847198], [69.47292328, 21.73875046], [69.4723587, 21.73875046], [69.4723587, 21.73903084], [69.47207642, 21.73903084], [69.47207642, 21.73931122], [69.47180939, 21.7393074], [69.47180176, 21.73958588], [69.4715271, 21.73958015], [69.4715271, 21.74014091], [69.47125244, 21.74014091], [69.47125244, 21.74041939], [69.47097015, 21.74041748], [69.47097015, 21.74069595], [69.4706955, 21.74069595], [69.4706955, 21.74097252], [69.47013855, 21.74097061], [69.47013855, 21.74125099], [69.4695816, 21.74125099], [69.4695816, 21.74152946], [69.46930695, 21.74152946], [69.46930695, 21.74180984], [69.46875, 21.74180794], [69.46875, 21.7420826], [69.46819305, 21.74208069], [69.46819305, 21.74236107], [69.46763611, 21.74236107], [69.46763611, 21.74263954], [69.46708679, 21.74263954], [69.46708679, 21.74291992], [69.46652985, 21.74291611], [69.46652985, 21.74319458], [69.46624756, 21.74319458], [69.46624756, 21.74347305], [69.46569824, 21.74347115], [69.46569824, 21.74374962], [69.4651413, 21.74374962], [69.4651413, 21.74403954], [69.46458435, 21.74402809], [69.46458435, 21.74430466], [69.46430206, 21.74430466], [69.46430206, 21.74458313], [69.46375275, 21.74458313], [69.46375275, 21.7448616], [69.4631958, 21.7448597], [69.4631958, 21.74514008], [69.46290588, 21.74514008], [69.46290588, 21.74542236], [69.46235657, 21.74542236], [69.46235657, 21.74570274], [69.46180725, 21.74569511], [69.46180725, 21.74597168], [69.46152496, 21.74597168], [69.46152496, 21.74625015], [69.46098328, 21.74625015], [69.46098328, 21.74653053], [69.4604187, 21.74653053], [69.4604187, 21.74681282], [69.45986176, 21.74680519], [69.45986176, 21.74708366], [69.4595871, 21.74708176], [69.4595871, 21.74736023], [69.45903015, 21.74736023], [69.45903015, 21.74764061], [69.45847321, 21.74764061], [69.45847321, 21.7479229], [69.45819092, 21.74791718], [69.45819092, 21.74819374], [69.4576416, 21.74819374], [69.4576416, 21.74847221], [69.45707703, 21.74847031], [69.45708466, 21.74875069], [69.45681, 21.74875069], [69.45681, 21.74903107], [69.45625305, 21.74903107], [69.45625305, 21.74930954], [69.45569611, 21.74930573], [69.45569611, 21.74958229], [69.45541382, 21.74958229], [69.45541382, 21.74986076], [69.45485687, 21.74985123], [69.45485687, 21.75014114], [69.45458221, 21.75014114], [69.45458221, 21.75041962], [69.45402527, 21.7504158], [69.45402527, 21.75069237], [69.45375061, 21.75069237], [69.45375061, 21.75097275], [69.45318604, 21.75097084], [69.45318604, 21.75125122], [69.45291901, 21.75125122], [69.45291901, 21.75152969], [69.45236206, 21.75152969], [69.45236206, 21.75181007], [69.45207977, 21.75180435], [69.45207977, 21.75208282], [69.45153046, 21.75208282], [69.45153046, 21.7523613], [69.45124817, 21.75235939], [69.45124817, 21.75263977], [69.45069122, 21.75263977], [69.45069122, 21.75319672], [69.45041656, 21.75319672], [69.45041656, 21.75347137], [69.45014191, 21.75346947], [69.45014191, 21.75374985], [69.44985962, 21.75374985], [69.44985962, 21.75403023], [69.44958496, 21.75402832], [69.44958496, 21.75430679], [69.44930267, 21.75430679], [69.44930267, 21.75458336], [69.44902802, 21.75458336], [69.44902802, 21.75486183], [69.44875336, 21.75485992], [69.44875336, 21.7551403], [69.44847107, 21.7551403], [69.44847107, 21.75542068], [69.44819641, 21.75542068], [69.44819641, 21.75569916], [69.44790649, 21.75569916], [69.44790649, 21.75597763], [69.44735718, 21.75597763], [69.44735718, 21.75625038], [69.44708252, 21.75625038], [69.44708252, 21.75653076], [69.44680786, 21.75653076], [69.44680786, 21.75680923], [69.44652557, 21.75680542], [69.44652557, 21.75708389], [69.44625092, 21.75707817], [69.44625092, 21.75736046], [69.44568634, 21.75736046], [69.44568634, 21.75764084], [69.44541931, 21.75764084], [69.44541931, 21.75791931], [69.44513702, 21.7579174], [69.44513702, 21.75819397], [69.44486237, 21.75819397], [69.44487, 21.75875092], [69.44458008, 21.75875092], [69.44458008, 21.75904274], [69.44431305, 21.75904274], [69.44431305, 21.75931168], [69.44403076, 21.75931168], [69.44403076, 21.76013947], [69.44210052, 21.76013947], [69.44210052, 21.76042175], [69.44097137, 21.76041603], [69.44097137, 21.7606945], [69.44013977, 21.7606945], [69.44013977, 21.76097107], [69.43985748, 21.76097107], [69.43985748, 21.76124954], [69.43958282, 21.76124954], [69.43958282, 21.7618103], [69.43930817, 21.7618103], [69.43930817, 21.76264], [69.43818665, 21.76264], [69.43818665, 21.76292038], [69.43791962, 21.76292038], [69.43791962, 21.76320076], [69.43763733, 21.76319313], [69.43763733, 21.7634716], [69.43736267, 21.7634697], [69.43736267, 21.76403046], [69.43708038, 21.76403046], [69.43708038, 21.76431084], [69.43680573, 21.76430321], [69.43680573, 21.76458359], [69.43624878, 21.76458359], [69.43624878, 21.76486206], [69.43567657, 21.76486015], [69.43567657, 21.76514053], [69.43541718, 21.76514053], [69.43541718, 21.76542091], [69.43486023, 21.76541519], [69.43486023, 21.76569366], [69.43430328, 21.76569366], [69.43430328, 21.76597214], [69.43402863, 21.76597023], [69.43402863, 21.76625061], [69.43374634, 21.76625061], [69.43374634, 21.76653099], [69.43347168, 21.76653099], [69.43347168, 21.76680946], [69.43319702, 21.76680756], [69.43319702, 21.76708412], [69.4329071, 21.76708031], [69.4329071, 21.76736069], [69.43235779, 21.76736069], [69.43235779, 21.76764107], [69.43208313, 21.76764107], [69.43208313, 21.76791954], [69.43180847, 21.76791763], [69.43180847, 21.7681942], [69.43152618, 21.7681942], [69.43152618, 21.76847267], [69.43125153, 21.76847076], [69.43125153, 21.76875114], [69.43096924, 21.76875114], [69.43096924, 21.76902962], [69.43068695, 21.76902962], [69.43068695, 21.76930809], [69.43041992, 21.76930618], [69.43041992, 21.76958275], [69.43013763, 21.76958084], [69.43013763, 21.76986122], [69.42986298, 21.76986122], [69.42987061, 21.77013969], [69.42930603, 21.77013969], [69.42930603, 21.77041817], [69.42903137, 21.77041626], [69.42903137, 21.77069473], [69.42874908, 21.77069092], [69.42874908, 21.77098083], [69.4284668, 21.77098083], [69.4284668, 21.77124977], [69.42819214, 21.77124977], [69.42819214, 21.77152824], [69.42791748, 21.77152824], [69.42791748, 21.77180481], [69.42763519, 21.77180481], [69.42763519, 21.77208328], [69.42736053, 21.77208328], [69.42736053, 21.77236176], [69.42708588, 21.77236176], [69.42708588, 21.77264023], [69.42679596, 21.77264023], [69.42679596, 21.77292252], [69.42652893, 21.77292252], [69.42652893, 21.7732029], [69.42624664, 21.77319527], [69.42624664, 21.77347183], [69.42597198, 21.77347183], [69.42597198, 21.77375031], [69.42569733, 21.77375031], [69.42569733, 21.77402687], [69.42542267, 21.77401924], [69.42542267, 21.77431107], [69.42514038, 21.77431107], [69.42514038, 21.77486038], [69.42485809, 21.77486038], [69.42485809, 21.77514076], [69.42457581, 21.77514076], [69.42457581, 21.77542114], [69.42430878, 21.77541733], [69.42430878, 21.77569389], [69.42402649, 21.77569389], [69.42402649, 21.77597237], [69.42373657, 21.77597046], [69.42373657, 21.77625084], [69.42346954, 21.77625084], [69.42346954, 21.77653122], [69.42318726, 21.77653122], [69.42318726, 21.77680969], [69.42292023, 21.77680588], [69.42292023, 21.77708244], [69.42263794, 21.77708054], [69.42263794, 21.77736092], [69.42236328, 21.77736092], [69.42236328, 21.77763939], [69.42208099, 21.77763939], [69.42208099, 21.77791977], [69.42180634, 21.77791405], [69.42180634, 21.77819443], [69.42152405, 21.77819443], [69.42152405, 21.77847481], [69.42124939, 21.77847099], [69.42124939, 21.77874947], [69.4209671, 21.77874947], [69.4209671, 21.77902985], [69.42067719, 21.77902985], [69.42067719, 21.77931023], [69.42041779, 21.7793045], [69.42041779, 21.77958298], [69.4201355, 21.77958298], [69.4201355, 21.77986145], [69.41986084, 21.77985954], [69.41986084, 21.78014946], [69.41958618, 21.78014946], [69.41958618, 21.7804203], [69.41929626, 21.7804203], [69.41929626, 21.78070068], [69.41902924, 21.78069687], [69.41902924, 21.78097153], [69.41874695, 21.78096962], [69.41874695, 21.78125], [69.41847229, 21.78125], [69.41847229, 21.78153038], [69.41819763, 21.78153038], [69.41819763, 21.78181076], [69.41791534, 21.78180695], [69.41791534, 21.78208351], [69.41764069, 21.78208351], [69.41764069, 21.78236198], [69.4173584, 21.78235817], [69.4173584, 21.78264046], [69.41707611, 21.78264046], [69.41707611, 21.78292084], [69.41680908, 21.78291893], [69.41680908, 21.78319359], [69.41652679, 21.78319359], [69.41652679, 21.78347206], [69.41625214, 21.78346825], [69.41625214, 21.78375053], [69.41596985, 21.78375053], [69.41596985, 21.78403091], [69.41570282, 21.78403091], [69.41570282, 21.78430939], [69.4154129, 21.78430557], [69.4154129, 21.78458405], [69.41485596, 21.78457832], [69.41485596, 21.78486061], [69.4145813, 21.78486061], [69.4145813, 21.78513908], [69.41430664, 21.78513908], [69.41430664, 21.78541946], [69.41402435, 21.78541756], [69.41402435, 21.78569412], [69.41374969, 21.78569412], [69.41374969, 21.7859726], [69.41348267, 21.78596115], [69.41348267, 21.78624916], [69.41319275, 21.78624916], [69.41319275, 21.78652954], [69.41291809, 21.78652954], [69.41291809, 21.78681183], [69.4126358, 21.78680611], [69.4126358, 21.78708267], [69.41236115, 21.78708267], [69.41236115, 21.78736115], [69.41208649, 21.78736115], [69.41208649, 21.78763962], [69.41179657, 21.78763962], [69.41179657, 21.78792191], [69.41152954, 21.78791618], [69.41152954, 21.78819466], [69.4109726, 21.78819466], [69.4109726, 21.78847122], [69.41069794, 21.78847122], [69.41069794, 21.78874969], [69.41041565, 21.78874969], [69.41041565, 21.78902817], [69.41014099, 21.78902817], [69.41014099, 21.78930473], [69.4098587, 21.78930473], [69.4098587, 21.78958321], [69.40958405, 21.78958321], [69.40958405, 21.78986168], [69.4090271, 21.78985977], [69.4090271, 21.79014015], [69.40876007, 21.79014015], [69.40876007, 21.79042053], [69.40847015, 21.79042053], [69.40847015, 21.79070091], [69.4081955, 21.79069328], [69.4081955, 21.79097176], [69.40791321, 21.79096985], [69.40791321, 21.79125023], [69.40735626, 21.79125023], [69.40735626, 21.79153061], [69.4070816, 21.79153061], [69.4070816, 21.79181099], [69.40680695, 21.79181099], [69.40680695, 21.79208946], [69.40651703, 21.79208946], [69.40651703, 21.79236031], [69.40625, 21.79236031], [69.40625, 21.79264069], [69.4059906, 21.79264069], [69.4059906, 21.79292107], [69.4054184, 21.79291534], [69.4054184, 21.79319382], [69.40513611, 21.79319382], [69.40513611, 21.79347229], [69.40486145, 21.79347038], [69.40486145, 21.79375076], [69.40458679, 21.79375076], [69.40458679, 21.79403114], [69.40402985, 21.79403114], [69.40402985, 21.79430962], [69.40374756, 21.79430771], [69.40374756, 21.79458427], [69.4034729, 21.79458046], [69.4034729, 21.79486084], [69.40291595, 21.79486084], [69.40291595, 21.79515076], [69.4026413, 21.79515076], [69.4026413, 21.79541969], [69.40235901, 21.79541779], [69.40235901, 21.79569435], [69.40180206, 21.79569435], [69.40180206, 21.79597282], [69.4015274, 21.79597092], [69.4015274, 21.79624939], [69.40125275, 21.79624939], [69.40125275, 21.79652977], [69.4006958, 21.79652977], [69.4006958, 21.79680824], [69.40041351, 21.79680634], [69.40041351, 21.7970829], [69.40013885, 21.7970829], [69.40013885, 21.79736137], [69.39985657, 21.79735756], [69.39985657, 21.79763985], [69.39956665, 21.79763985], [69.39956665, 21.79791832], [69.39930725, 21.79791641], [69.39930725, 21.79819489], [69.39902496, 21.79819489], [69.39903259, 21.79875183], [69.39875031, 21.79875183], [69.39875031, 21.7990303], [69.39848328, 21.7990303], [69.39848328, 21.79931259], [69.39819336, 21.79930496], [69.39819336, 21.79958344], [69.3979187, 21.79958344], [69.3979187, 21.79986191], [69.39763641, 21.79986191], [69.39763641, 21.80014038], [69.39736176, 21.80014038], [69.39736176, 21.80042267], [69.3970871, 21.80041695], [69.3970871, 21.8006916], [69.39680481, 21.80069542], [69.39680481, 21.80097008], [69.39653015, 21.80095863], [69.39653015, 21.80125046], [69.39624786, 21.80125046], [69.39620209, 21.80181122], [69.39597321, 21.8018055], [69.39597321, 21.80208206], [69.39569092, 21.80208015], [69.39569092, 21.80236053], [69.39541626, 21.80236053], [69.39541626, 21.80264282], [69.3951416, 21.80264282], [69.3951416, 21.80291939], [69.39485931, 21.80291748], [69.39485931, 21.80319214], [69.39458466, 21.80319214], [69.39458466, 21.80347252], [69.39430237, 21.80347061], [69.39430237, 21.80402946], [69.39402771, 21.80402946], [69.39402771, 21.80431938], [69.39375305, 21.80430412], [69.39375305, 21.8045826], [69.39347076, 21.80458069], [69.39347076, 21.80486107], [69.39319611, 21.80486107], [69.39319611, 21.80513954], [69.39291382, 21.80513954], [69.39291382, 21.80569649], [69.39263916, 21.80569649], [69.39263916, 21.80597305], [69.39235687, 21.80597115], [69.39235687, 21.80624962], [69.39208221, 21.80624962], [69.39208221, 21.80653], [69.39180756, 21.80652618], [69.39180756, 21.80680466], [69.39152527, 21.80680466], [69.39152527, 21.8073616], [69.39125061, 21.8073597], [69.39125061, 21.80764008], [69.39097595, 21.80764008], [69.39097595, 21.80792046], [69.39070129, 21.80792046], [69.39070129, 21.80820084], [69.39041901, 21.80819511], [69.39041901, 21.80847168], [69.39013672, 21.80846977], [69.39013672, 21.80903053], [69.38986206, 21.80903053], [69.38986206, 21.80931091], [69.38957977, 21.80930519], [69.38957977, 21.80958366], [69.38930511, 21.80958366], [69.38931274, 21.80986023], [69.38903046, 21.80986023], [69.38903046, 21.8101387], [69.38874817, 21.8101387], [69.38874817, 21.81069374], [69.38847351, 21.81069374], [69.38847351, 21.81097221], [69.38819122, 21.8109684], [69.38819122, 21.81125069], [69.38791656, 21.81125069], [69.38791656, 21.81152916], [69.38762665, 21.81152916], [69.38762665, 21.81180954], [69.38735962, 21.81180954], [69.38735962, 21.81236076], [69.38707733, 21.81236076], [69.38707733, 21.81263924], [69.38680267, 21.81263924], [69.38680267, 21.81291962], [69.38652802, 21.8129158], [69.38652802, 21.81319427], [69.38625336, 21.81319427], [69.38625336, 21.81347275], [69.38597107, 21.81347275], [69.38597107, 21.81402969], [69.38569641, 21.81402969], [69.38569641, 21.81431007], [69.38541412, 21.81430626], [69.38541412, 21.81458282], [69.38513947, 21.81458282], [69.38513947, 21.8148613], [69.38485718, 21.81485939], [69.38485718, 21.81513977], [69.38458252, 21.81513977], [69.38458252, 21.81569481], [69.38430786, 21.81569481], [69.38430786, 21.81597137], [69.3840332, 21.81596947], [69.3840332, 21.81625938], [69.38375092, 21.81625938], [69.38375092, 21.81653023], [69.38346863, 21.81652832], [69.38346863, 21.81680489], [69.38319397, 21.81680489], [69.38319397, 21.81736183], [69.38291931, 21.81735992], [69.38291931, 21.8176403], [69.38263702, 21.8176403], [69.38263702, 21.81792068], [69.38236237, 21.81791687], [69.38236237, 21.81847191], [69.38208008, 21.81847], [69.38208008, 21.81875038], [69.38182068, 21.81875038], [69.38182068, 21.81903076], [69.38153076, 21.81902695], [69.38153076, 21.8195858], [69.38124847, 21.81958008], [69.38124847, 21.81986046], [69.38096619, 21.81986046], [69.38096619, 21.82014084], [69.38069153, 21.82013893], [69.38069153, 21.82069588], [69.38041687, 21.82069588], [69.38041687, 21.82097244], [69.38014221, 21.82097054], [69.38014221, 21.82125092], [69.37985992, 21.82125092], [69.37985992, 21.82152939], [69.37958527, 21.82152557], [69.37958527, 21.82208252], [69.37930298, 21.82207108], [69.37930298, 21.82236099], [69.37902832, 21.82236099], [69.37902832, 21.82263947], [69.37876129, 21.82263947], [69.37876129, 21.82291985], [69.37847137, 21.82291794], [69.37847137, 21.8231945], [69.37819672, 21.82319069], [69.37819672, 21.82374954], [69.3779068, 21.82374954], [69.3779068, 21.82402992], [69.37763977, 21.82402992], [69.37763977, 21.8243084], [69.37735748, 21.82430649], [69.37735748, 21.82458305], [69.37708282, 21.82458305], [69.37708282, 21.82513809], [69.37680817, 21.82513046], [69.37680817, 21.82542038], [69.37652588, 21.82542038], [69.37652588, 21.82570267], [69.37625122, 21.82569504], [69.37625122, 21.8259716], [69.37596893, 21.8259716], [69.37596893, 21.82625008], [69.37568665, 21.82625008], [69.37568665, 21.82653046], [69.37513733, 21.82653046], [69.37513733, 21.82681274], [69.37486267, 21.82680511], [69.37486267, 21.82708359], [69.37458038, 21.82708359], [69.37458038, 21.82736015], [69.37431335, 21.82736015], [69.37431335, 21.82764053], [69.37403107, 21.82764053], [69.37403107, 21.82792282], [69.37374878, 21.82792282], [69.37374878, 21.82819939], [69.37319183, 21.82819366], [69.37319183, 21.82847214], [69.37291718, 21.82847023], [69.37291718, 21.82875061], [69.37262726, 21.82875061], [69.37262726, 21.8290329], [69.37236023, 21.8290329], [69.37236023, 21.82930946], [69.37180328, 21.82930565], [69.37180328, 21.82958221], [69.37152863, 21.82958031], [69.37152863, 21.82986069], [69.37124634, 21.82986069], [69.37124634, 21.83014107], [69.37097168, 21.83014107], [69.37097168, 21.83041954], [69.37041473, 21.83041763], [69.37041473, 21.83069229], [69.37014008, 21.83069229], [69.37014008, 21.83097267], [69.36985779, 21.83097076], [69.36985779, 21.83126068], [69.36959076, 21.83126068], [69.36959076, 21.83152962], [69.36902618, 21.83152962], [69.36902618, 21.83181], [69.36875153, 21.83180428], [69.36875153, 21.83208275], [69.36846924, 21.83208084], [69.36846924, 21.83236122], [69.36791992, 21.83236122], [69.36791992, 21.83263969], [69.36736298, 21.83263969], [69.36736298, 21.83292007], [69.36680603, 21.83291435], [69.36680603, 21.83319664], [69.36624908, 21.83319664], [69.36624908, 21.8334713], [69.36569214, 21.83346939], [69.36569214, 21.83374977], [69.36514282, 21.83374977], [69.36514282, 21.83403015], [69.36458588, 21.83402634], [69.36458588, 21.83430672], [69.36402893, 21.83430672], [69.36402893, 21.83458328], [69.36347198, 21.83458328], [69.36347198, 21.83486176], [69.36292267, 21.83485985], [69.36292267, 21.83514023], [69.36152649, 21.83514023], [69.36152649, 21.83542061], [69.36096954, 21.83542061], [69.36096954, 21.83569908], [69.36042023, 21.83569908], [69.36042023, 21.83625031], [69.36013794, 21.83625031], [69.36013794, 21.83653069], [69.35958099, 21.83653069], [69.35958099, 21.83680916], [69.35902405, 21.83680534], [69.35902405, 21.83708382], [69.35819244, 21.83707047], [69.35819244, 21.83736038], [69.35597229, 21.83736038], [69.35597229, 21.83764076], [69.35514069, 21.83764076], [69.35514069, 21.83791924], [69.35430908, 21.83791733], [69.35430908, 21.83819389], [69.35375214, 21.83819389], [69.35375214, 21.83847237], [69.3529129, 21.83847046], [69.3529129, 21.83875084], [69.3520813, 21.83875084], [69.3520813, 21.83902931], [69.35180664, 21.83902931], [69.35180664, 21.8393116], [69.35152435, 21.83930588], [69.35152435, 21.83958244], [69.35097504, 21.83958244], [69.35098267, 21.83986092], [69.35069275, 21.83986092], [69.35069275, 21.84013939], [69.35041809, 21.84013939], [69.35041809, 21.84041977], [69.3501358, 21.84041595], [69.3501358, 21.84069443], [69.34958649, 21.84069443], [69.34958649, 21.8409729], [69.34929657, 21.8409729], [69.34929657, 21.84124947], [69.34902954, 21.84124947], [69.34902954, 21.84152985], [69.34874725, 21.84152985], [69.34874725, 21.84181023], [69.3484726, 21.84180641], [69.3484726, 21.84208107], [69.34791565, 21.84208107], [69.34791565, 21.84236145], [69.34764099, 21.84235954], [69.34764099, 21.84263992], [69.3473587, 21.84263992], [69.3473587, 21.8429203], [69.34707642, 21.8429203], [69.34707642, 21.84320068], [69.3465271, 21.84319305], [69.3465271, 21.84347153], [69.34625244, 21.84346962], [69.34625244, 21.84375], [69.34597015, 21.84375], [69.34597015, 21.84403038], [69.34571075, 21.84403038], [69.34571075, 21.84431076], [69.34541321, 21.84430313], [69.34541321, 21.84458351], [69.34486389, 21.84458351], [69.34486389, 21.84486198], [69.3445816, 21.84486008], [69.3445816, 21.84514046], [69.34430695, 21.84514046], [69.34430695, 21.84542084], [69.34402466, 21.84541512], [69.34402466, 21.84569359], [69.34375, 21.84569359], [69.34375, 21.84597206], [69.34319305, 21.84597206], [69.34319305, 21.84625053], [69.3429184, 21.846241], [69.3429184, 21.84653091], [69.34265137, 21.84653091], [69.34265137, 21.84680939], [69.34236145, 21.84680748], [69.34236145, 21.84708595], [69.34179688, 21.84708023], [69.34179688, 21.84736061], [69.34152985, 21.84736061], [69.34152985, 21.84764099], [69.34124756, 21.84764099], [69.34124756, 21.84791946], [69.3409729, 21.84791756], [69.3409729, 21.84819412], [69.34041595, 21.84819412], [69.34041595, 21.8484726], [69.3401413, 21.84847069], [69.3401413, 21.84875107], [69.33985901, 21.84875107], [69.33985901, 21.84902954], [69.33930206, 21.84902954], [69.33930206, 21.84930611], [69.3390274, 21.84930611], [69.3390274, 21.84958267], [69.33847046, 21.84958076], [69.33847046, 21.84986115], [69.3381958, 21.84986115], [69.3381958, 21.85013962], [69.33790588, 21.85013962], [69.33790588, 21.85041809], [69.3373642, 21.85041618], [69.3373642, 21.85069466], [69.33708191, 21.85069466], [69.33708191, 21.85097313], [69.33680725, 21.85097122], [69.33680725, 21.85124969], [69.33625031, 21.85124969], [69.33625031, 21.85152817], [69.33597565, 21.85152817], [69.33597565, 21.85180473], [69.33569336, 21.85180473], [69.33569336, 21.85208321], [69.33513641, 21.85208321], [69.33513641, 21.85236168], [69.33486176, 21.85236168], [69.33486176, 21.85264015], [69.33429718, 21.85264015], [69.33429718, 21.85292244], [69.33403015, 21.85292244], [69.33403015, 21.85320282], [69.33374786, 21.85319519], [69.33374786, 21.85347176], [69.33319092, 21.85347176], [69.33319092, 21.85375023], [69.33291626, 21.85375023], [69.33291626, 21.85403061], [69.3326416, 21.85403061], [69.3326416, 21.8543129], [69.33208466, 21.85430527], [69.33208466, 21.85458374], [69.33180237, 21.85458183], [69.33180237, 21.85486031], [69.33152771, 21.85486031], [69.33152771, 21.85514069], [69.33125305, 21.85514069], [69.33125305, 21.8554306], [69.33069611, 21.85541725], [69.33069611, 21.85569382], [69.33041382, 21.85569382], [69.33041382, 21.85597229], [69.33013916, 21.85597038], [69.33013916, 21.85625076], [69.32985687, 21.85625076], [69.32985687, 21.85653114], [69.32930756, 21.85653114], [69.32930756, 21.85680962], [69.32902527, 21.8568058], [69.32902527, 21.85708237], [69.32875061, 21.85708046], [69.32875061, 21.85736084], [69.32847595, 21.85736084], [69.32847595, 21.85764122], [69.32791901, 21.85764122], [69.32791901, 21.85791969], [69.32763672, 21.85791588], [69.32763672, 21.85819435], [69.32736206, 21.85819435], [69.32736206, 21.85847282], [69.32707977, 21.85847092], [69.32707977, 21.85874939], [69.32653046, 21.85874939], [69.32653046, 21.85902977], [69.32624817, 21.85902977], [69.32624817, 21.85931015], [69.32597351, 21.85930443], [69.32597351, 21.8595829], [69.32569122, 21.8595829], [69.32569122, 21.85986137], [69.32514191, 21.85985947], [69.32514191, 21.86013985], [69.32485962, 21.86013985], [69.32485962, 21.86042023], [69.32458496, 21.86041451], [69.32458496, 21.86069679], [69.32430267, 21.86069679], [69.32430267, 21.86097145], [69.32375336, 21.86097145], [69.32375336, 21.86124992], [69.32347107, 21.86124039], [69.32347107, 21.8615303], [69.32319641, 21.8615303], [69.32319641, 21.86181068], [69.32291412, 21.86180687], [69.32291412, 21.86208344], [69.32263947, 21.86208344], [69.32263947, 21.86236191], [69.32235718, 21.86235809], [69.32235718, 21.86264038], [69.32208252, 21.86264038], [69.32208252, 21.86292076], [69.32180786, 21.86291885], [69.32180786, 21.8631897], [69.32152557, 21.86319542], [69.32152557, 21.86347198], [69.32125092, 21.86346817], [69.32125092, 21.86375046], [69.32096863, 21.86375046], [69.32096863, 21.86403084], [69.32069397, 21.86402893], [69.32069397, 21.8643055], [69.32041931, 21.8643055], [69.32041931, 21.86458397], [69.31986237, 21.86457825], [69.31986237, 21.86486053], [69.31958008, 21.86486053], [69.31958008, 21.86514091], [69.31931305, 21.86514091], [69.31931305, 21.86541939], [69.31903076, 21.86541748], [69.31903076, 21.86569405], [69.31874847, 21.86569405], [69.31874847, 21.86597252], [69.31848145, 21.86597061], [69.31848145, 21.86624908], [69.31819153, 21.86624908], [69.31819153, 21.86652946], [69.31791687, 21.86652946], [69.31791687, 21.86681175], [69.31764221, 21.86680603], [69.31764221, 21.8670826], [69.31735992, 21.8670826], [69.31735992, 21.86737061], [69.31708527, 21.86736107], [69.3170929, 21.86763954], [69.31680298, 21.86763954], [69.31680298, 21.86792183], [69.31652832, 21.86791611], [69.31652832, 21.86819458], [69.31597137, 21.86819458], [69.31597137, 21.86847115], [69.31569672, 21.86847115], [69.31569672, 21.86874962], [69.3154068, 21.86874962], [69.3154068, 21.86903], [69.31513977, 21.86902809], [69.31513977, 21.86930466], [69.31458282, 21.86930466], [69.31458282, 21.86958122], [69.31430817, 21.86958122], [69.31430817, 21.8698616], [69.31402588, 21.8698597], [69.31402588, 21.87014008], [69.31346893, 21.87014008], [69.31346893, 21.87042999], [69.31318665, 21.87042999], [69.31318665, 21.87070084], [69.31291962, 21.87069321], [69.31291962, 21.87097168], [69.31263733, 21.87096977], [69.31263733, 21.87125015], [69.31208038, 21.87125015], [69.31208038, 21.87153053], [69.31181335, 21.87153053], [69.31181335, 21.87181091], [69.31153107, 21.87180328], [69.31153107, 21.87208366], [69.31124878, 21.87207985], [69.31124878, 21.87236023], [69.31069183, 21.87236023], [69.31069183, 21.87264061], [69.31041718, 21.87264061], [69.31041718, 21.87292099], [69.31014252, 21.87291527], [69.31014252, 21.87319374], [69.30958557, 21.87319374], [69.30958557, 21.87347221], [69.30928802, 21.87347031], [69.30928802, 21.87375069], [69.30902863, 21.87375069], [69.30902863, 21.87403107], [69.30819702, 21.87402534], [69.30819702, 21.8745842], [69.3079071, 21.87458038], [69.3079071, 21.87486076], [69.30764008, 21.87486076], [69.30764008, 21.87514114], [69.30735779, 21.87514114], [69.30735779, 21.87541962], [69.30680847, 21.87541771], [69.30680847, 21.87569427], [69.30652618, 21.87569427], [69.30652618, 21.87597275], [69.30625153, 21.87597275], [69.30625153, 21.87624741], [69.30596924, 21.87623978], [69.30596924, 21.87652969], [69.30568695, 21.87652969], [69.30568695, 21.87680817], [69.30513763, 21.87680626], [69.30513763, 21.87708282], [69.30486298, 21.87708282], [69.30486298, 21.8773613], [69.30458069, 21.87735748], [69.30458069, 21.87763977], [69.30430603, 21.87763977], [69.30430603, 21.87791824], [69.30403137, 21.87791634], [69.30403137, 21.87819481], [69.30374908, 21.87819481], [69.30374908, 21.87847137], [69.30319214, 21.87846756], [69.30319214, 21.87875175], [69.30291748, 21.87875175], [69.30291748, 21.87903023], [69.30264282, 21.87903023], [69.30264282, 21.87931252], [69.30236053, 21.87930489], [69.30236053, 21.87958336], [69.30208588, 21.87958336], [69.30208588, 21.87986183], [69.30179596, 21.87986183], [69.30179596, 21.8801403], [69.30152893, 21.8801403], [69.30152893, 21.88042259], [69.30097198, 21.88042259], [69.30097198, 21.88070107], [69.30069733, 21.88069534], [69.30069733, 21.88097191], [69.30040741, 21.88097191], [69.30040741, 21.88125038], [69.30014038, 21.88125038], [69.30014038, 21.88153267], [69.29985809, 21.88153267], [69.29985809, 21.88181114], [69.29958344, 21.88180542], [69.29958344, 21.88208389], [69.29930878, 21.88208389], [69.29930878, 21.88180542], [69.29875183, 21.88180542], [69.29875183, 21.88208389], [69.29846954, 21.88208008], [69.29846954, 21.88237], [69.29818726, 21.88237], [69.29818726, 21.88264084], [69.29846954, 21.88264084], [69.29846954, 21.88292122], [69.29819489, 21.8829174], [69.29819489, 21.88319206], [69.29792023, 21.88319206], [69.29792023, 21.88347244], [69.29763794, 21.88347054], [69.29763794, 21.88375092], [69.29734802, 21.88375092], [69.29734802, 21.88402939], [69.29708099, 21.88402939], [69.29708099, 21.88430977], [69.29624939, 21.88430405], [69.29624939, 21.88458252], [69.2959671, 21.88458061], [69.2959671, 21.88486099], [69.29569244, 21.88486099], [69.29569244, 21.88513947], [69.29541779, 21.88513947], [69.29541779, 21.8856945], [69.2951355, 21.8856945], [69.2951355, 21.88597488], [69.29486084, 21.88597107], [69.29486084, 21.88624954], [69.29460144, 21.88624954], [69.29460144, 21.88652992], [69.29431152, 21.88652992], [69.29431152, 21.8868103], [69.29402924, 21.88680458], [69.29402924, 21.88708305], [69.29347229, 21.88708305], [69.29347229, 21.88736153], [69.29319763, 21.88735962], [69.29319763, 21.88764], [69.29292297, 21.88764], [69.29292297, 21.88792038], [69.29264069, 21.88792038], [69.29264069, 21.88820076], [69.2923584, 21.88819695], [69.2923584, 21.8884716], [69.29207611, 21.8884697], [69.29207611, 21.88875008], [69.29180908, 21.88875008], [69.29180908, 21.88903046], [69.29125214, 21.88903046], [69.29125214, 21.88931084], [69.29096985, 21.88930511], [69.29096985, 21.88958359], [69.29069519, 21.88958359], [69.29069519, 21.88986206], [69.2904129, 21.88985825], [69.2904129, 21.89014053], [69.29013824, 21.89014053], [69.29013824, 21.89042091], [69.2895813, 21.8904171], [69.2895813, 21.89069366], [69.28930664, 21.89069366], [69.28930664, 21.89097214], [69.28874969, 21.89096832], [69.28874969, 21.89125061], [69.28846741, 21.89125061], [69.28846741, 21.89154053], [69.28791809, 21.89154053], [69.28791809, 21.89180946], [69.2876358, 21.89180565], [69.2876358, 21.89208412], [69.28708649, 21.8920784], [69.28708649, 21.89236069], [69.28679657, 21.89236069], [69.28679657, 21.89263916], [69.28624725, 21.89263916], [69.28624725, 21.89291954], [69.2859726, 21.89291763], [69.2859726, 21.8931942], [69.28569794, 21.8931942], [69.28569794, 21.89347267], [69.28514099, 21.89347267], [69.28514099, 21.89375114], [69.2848587, 21.89375114], [69.2848587, 21.89402962], [69.28430939, 21.89402962], [69.28430176, 21.8943119], [69.2840271, 21.89430618], [69.2840271, 21.89458275], [69.2831955, 21.89458275], [69.28320313, 21.89486122], [69.28291321, 21.89486122], [69.28291321, 21.89542007], [69.28263855, 21.89541626], [69.28263855, 21.89569473], [69.28236389, 21.89569473], [69.28237152, 21.89624977], [69.2820816, 21.89624977], [69.2820816, 21.89653015], [69.28180695, 21.89652824], [69.28180695, 21.89680481], [69.28152466, 21.89680481], [69.28152466, 21.89708328], [69.28125, 21.89708328], [69.28125, 21.89736176], [69.28098297, 21.89735031], [69.28098297, 21.89764023], [69.28069305, 21.89764023], [69.28069305, 21.89792061], [69.2804184, 21.89792061], [69.2804184, 21.89820099], [69.28013611, 21.89819336], [69.28013611, 21.89847183], [69.27986145, 21.89846992], [69.27986145, 21.89875031], [69.27958679, 21.89875031], [69.27958679, 21.89903069], [69.27931213, 21.89903069], [69.27931213, 21.89931107], [69.27902985, 21.89930534], [69.27902985, 21.89958572], [69.27874756, 21.89958], [69.27874756, 21.89986038], [69.2784729, 21.89986038], [69.2784729, 21.90014076], [69.27819824, 21.90013885], [69.27819824, 21.90041542], [69.27791595, 21.90041542], [69.27791595, 21.90069389], [69.2776413, 21.90069008], [69.2776413, 21.90125084], [69.27735901, 21.90125084], [69.27735901, 21.90153122], [69.27707672, 21.90153122], [69.27707672, 21.90180969], [69.27680206, 21.90180779], [69.27680206, 21.90208244], [69.2765274, 21.90208054], [69.2765274, 21.90236092], [69.27623749, 21.90236092], [69.27623749, 21.90263939], [69.27597046, 21.90263939], [69.27597046, 21.90291977], [69.2756958, 21.90291786], [69.2756958, 21.90319443], [69.27540588, 21.90319061], [69.27540588, 21.90348053], [69.27513885, 21.90348053], [69.27513885, 21.90374947], [69.27458191, 21.90374947], [69.27458191, 21.90402985], [69.27430725, 21.90402985], [69.27430725, 21.90430832], [69.27402496, 21.90430641], [69.27402496, 21.90458298], [69.27375031, 21.90458298], [69.27375031, 21.90486145], [69.27349091, 21.90485764], [69.27349091, 21.90513992], [69.2731781, 21.90513992], [69.2731781, 21.9054203], [69.2729187, 21.9054203], [69.2729187, 21.90570259], [69.27263641, 21.90569496], [69.27263641, 21.90597153], [69.2720871, 21.90597153], [69.2720871, 21.90625191], [69.27153015, 21.90625191], [69.27153015, 21.90653992], [69.27097321, 21.90653992], [69.27097321, 21.90681267], [69.27041626, 21.90680504], [69.27041626, 21.90708351], [69.26985931, 21.90708351], [69.26985931, 21.90736008], [69.26957703, 21.90736008], [69.26957703, 21.90764046], [69.26930237, 21.90764046], [69.26930237, 21.90792274], [69.26902771, 21.90791702], [69.26902771, 21.90819359], [69.26875305, 21.90819359], [69.26875305, 21.90847206], [69.26819611, 21.90847015], [69.26819611, 21.90875053], [69.26790619, 21.90875053], [69.26790619, 21.90903282], [69.26763916, 21.90903282], [69.26763916, 21.90930939], [69.2673645, 21.90930557], [69.2673645, 21.90958214], [69.26708221, 21.90958023], [69.26708221, 21.90986061], [69.26680756, 21.90986061], [69.26680756, 21.91014099], [69.2665329, 21.91014099], [69.2665329, 21.91041946], [69.26625061, 21.91041756], [69.26625061, 21.91069221], [69.26597595, 21.91069221], [69.26597595, 21.9109726], [69.26568604, 21.91097069], [69.26568604, 21.91125107], [69.26541901, 21.91125107], [69.26541901, 21.91152954], [69.26513672, 21.91152954], [69.26513672, 21.91180992], [69.26486206, 21.9118042], [69.26486206, 21.91208267], [69.26457977, 21.91208267], [69.26457977, 21.91236115], [69.26429749, 21.9123497], [69.26429749, 21.91263962], [69.26403046, 21.91263962], [69.26403046, 21.91319656], [69.26374817, 21.91319656], [69.26374817, 21.91347313], [69.26346588, 21.91347122], [69.26346588, 21.91374969], [69.26319122, 21.91374969], [69.26319122, 21.91403008], [69.26291656, 21.91402626], [69.26291656, 21.91430473], [69.26264191, 21.91430473], [69.26264191, 21.91458321], [69.26235962, 21.91458321], [69.26235962, 21.91486168], [69.26207733, 21.91485977], [69.26207733, 21.91514015], [69.26180267, 21.91514015], [69.26180267, 21.91542053], [69.2612381, 21.91542053], [69.2612381, 21.91570854], [69.26097107, 21.91570854], [69.26097107, 21.91625023], [69.26069641, 21.91625023], [69.26069641, 21.91653061], [69.26013947, 21.91653061], [69.26013947, 21.91680908], [69.25986481, 21.91680527], [69.25986481, 21.91708374], [69.25958252, 21.91707993], [69.25958252, 21.91736031], [69.25930786, 21.91736031], [69.25930786, 21.91764069], [69.25875092, 21.91764069], [69.25875092, 21.91791916], [69.25846863, 21.91791725], [69.25846863, 21.91819382], [69.2582016, 21.9181881], [69.2582016, 21.91848183], [69.25791931, 21.91848183], [69.25791931, 21.91875076], [69.25736237, 21.91875076], [69.25736237, 21.91930962], [69.25708008, 21.9193058], [69.25708008, 21.91958427], [69.25680542, 21.91958427], [69.25681305, 21.91986084], [69.25653076, 21.91986084], [69.25653076, 21.92014122], [69.25624847, 21.92014122], [69.25624847, 21.92041969], [69.25597382, 21.92041588], [69.25597382, 21.92097282], [69.25569153, 21.92097282], [69.25569153, 21.92124939], [69.25541687, 21.92124939], [69.25541687, 21.92152786], [69.25485992, 21.92152023], [69.25485992, 21.92181015], [69.25458527, 21.92180634], [69.25458527, 21.9220829], [69.25430298, 21.9220829], [69.25430298, 21.92236137], [69.25402832, 21.92235947], [69.25402832, 21.92263985], [69.25374603, 21.92263985], [69.25374603, 21.92292023], [69.25347137, 21.92291641], [69.25347137, 21.92319489], [69.25319672, 21.92319489], [69.25319672, 21.92347145], [69.2529068, 21.92346954], [69.2529068, 21.92374992], [69.25263977, 21.92374992], [69.25263977, 21.9240303], [69.25235748, 21.9240303], [69.25235748, 21.92431068], [69.25208282, 21.92430305], [69.25208282, 21.92458344], [69.25180817, 21.92458344], [69.25180817, 21.92486191], [69.25152588, 21.92486], [69.25152588, 21.92514038], [69.25125122, 21.92514038], [69.25125122, 21.92542076], [69.25096893, 21.92541695], [69.25096893, 21.9256897], [69.25068665, 21.92570114], [69.25068665, 21.92653084], [69.25041962, 21.92652512], [69.25041962, 21.92708588], [69.25013733, 21.92708015], [69.25013733, 21.92736053], [69.24986267, 21.92736053], [69.24986267, 21.92791939], [69.24958038, 21.92791557], [69.24958038, 21.92819595], [69.24930573, 21.92819595], [69.24930573, 21.92847252], [69.24903107, 21.92847061], [69.24903107, 21.92875099], [69.24874878, 21.92875099], [69.24874878, 21.92902946], [69.24846649, 21.92902946], [69.24846649, 21.92930984], [69.24819183, 21.92930794], [69.24819183, 21.9295826], [69.24791718, 21.92958069], [69.24791718, 21.92986107], [69.24736023, 21.92986107], [69.24736023, 21.93013954], [69.2470932, 21.93013954], [69.2470932, 21.93041992], [69.24680328, 21.93041611], [69.24680328, 21.93069458], [69.24652863, 21.93069458], [69.24652863, 21.93097305], [69.24624634, 21.93097305], [69.2462616, 21.93124962], [69.24569702, 21.93124962], [69.24569702, 21.93152809], [69.24541473, 21.93152809], [69.24541473, 21.93180466], [69.24514008, 21.93180466], [69.24514008, 21.93208313], [69.24485779, 21.93208313], [69.24485779, 21.9323616], [69.24458313, 21.9323616], [69.24458313, 21.93264008], [69.24402618, 21.93264008], [69.24402618, 21.93292046], [69.24375153, 21.93292046], [69.24375153, 21.93320274], [69.24346924, 21.93319511], [69.24346924, 21.93347168], [69.24319458, 21.93347168], [69.24320221, 21.93375015], [69.24263763, 21.93375015], [69.24263763, 21.93403053], [69.24236298, 21.93403053], [69.24236298, 21.93431282], [69.24208069, 21.93430519], [69.24208069, 21.93458366], [69.24124908, 21.93458176], [69.24124908, 21.93486023], [69.24069214, 21.93486023], [69.24069214, 21.93514061], [69.24041748, 21.93514061], [69.24041748, 21.9354229], [69.24013519, 21.93541718], [69.24013519, 21.93569374], [69.23986053, 21.93569183], [69.23986053, 21.93625069], [69.23958588, 21.93625069], [69.23958588, 21.93652725], [69.23929596, 21.93651962], [69.23929596, 21.93680954], [69.23902893, 21.93680573], [69.23902893, 21.93708229], [69.23874664, 21.93708038], [69.23874664, 21.93736076], [69.23819733, 21.93736076], [69.23819733, 21.93764114], [69.23792267, 21.93764114], [69.23792267, 21.93791962], [69.23708344, 21.9379158], [69.23708344, 21.93819427], [69.23652649, 21.93819427], [69.23652649, 21.93847275], [69.23625183, 21.93847084], [69.23625183, 21.93931007], [69.23596954, 21.93931007], [69.23596954, 21.93959045], [69.23568726, 21.93959045], [69.23568726, 21.94013977], [69.23486328, 21.94013977], [69.23486328, 21.94042015], [69.23458099, 21.94041443], [69.23458099, 21.94069672], [69.23430634, 21.94069672], [69.23430634, 21.94097137], [69.23402405, 21.94097137], [69.23403168, 21.94124985], [69.23374939, 21.94124985], [69.23374939, 21.94153023], [69.23347473, 21.94152641], [69.23347473, 21.94180679], [69.23319244, 21.94180679], [69.23319244, 21.94208336], [69.23291779, 21.94208336], [69.23291779, 21.94236183], [69.23264313, 21.94235992], [69.23264313, 21.94264984], [69.23208618, 21.94264984], [69.23208618, 21.94292068], [69.23179626, 21.94292068], [69.23179626, 21.94319916], [69.23152924, 21.94319534], [69.23152924, 21.94347191], [69.23124695, 21.94347191], [69.23126221, 21.94375038], [69.23097229, 21.94375038], [69.23097229, 21.94403076], [69.23069763, 21.94403076], [69.23069763, 21.94430923], [69.23041534, 21.94430542], [69.23042297, 21.94486046], [69.23014069, 21.94486046], [69.23014069, 21.94541931], [69.2298584, 21.9454174], [69.2298584, 21.94597244], [69.22957611, 21.94597054], [69.22957611, 21.94625092], [69.22930908, 21.94625092], [69.22930908, 21.94652939], [69.22902679, 21.94652939], [69.22902679, 21.94681168], [69.22875214, 21.94680595], [69.22875214, 21.94708252], [69.22846985, 21.94708252], [69.22846985, 21.9473629], [69.22818756, 21.9473629], [69.22818756, 21.94763947], [69.2279129, 21.94763947], [69.2279129, 21.94791985], [69.22763824, 21.94791603], [69.22763824, 21.9481945], [69.22736359, 21.9481945], [69.22736359, 21.94847107], [69.2270813, 21.94846153], [69.2270813, 21.94902992], [69.22680664, 21.94902992], [69.22680664, 21.9493103], [69.22652435, 21.94930649], [69.22652435, 21.94958115], [69.22624969, 21.94958115], [69.22624969, 21.94986153], [69.22598267, 21.94985962], [69.22598267, 21.95014], [69.22569275, 21.95014], [69.22569275, 21.95042038], [69.22541809, 21.95042038], [69.22541809, 21.95070076], [69.22486115, 21.95069313], [69.22486115, 21.9509716], [69.22458649, 21.9509697], [69.22458649, 21.95125008], [69.22429657, 21.95125008], [69.22429657, 21.95153046], [69.22402954, 21.95153046], [69.22402954, 21.95181084], [69.22374725, 21.95180321], [69.22374725, 21.95208359], [69.2234726, 21.95208359], [69.2234726, 21.95236206], [69.22319794, 21.95236015], [69.22319794, 21.95264053], [69.22292328, 21.95264053], [69.22292328, 21.95292091], [69.22264099, 21.95291519], [69.22264099, 21.95319366], [69.2223587, 21.95319366], [69.2223587, 21.95347214], [69.22208405, 21.95347214], [69.22209167, 21.95375061], [69.22180939, 21.95375061], [69.22180176, 21.95403099], [69.2215271, 21.95403099], [69.2215271, 21.95430946], [69.22125244, 21.95430946], [69.22125244, 21.95458984], [69.22097015, 21.95458984], [69.22097015, 21.95486069], [69.22070313, 21.95486069], [69.22070313, 21.95514107], [69.22041321, 21.95514107], [69.22041321, 21.95541954], [69.22013855, 21.95541763], [69.22013855, 21.9556942], [69.21986389, 21.9556942], [69.21986389, 21.95597267], [69.2195816, 21.95597076], [69.2195816, 21.95625114], [69.2193222, 21.95625114], [69.2193222, 21.95652962], [69.21903229, 21.95652962], [69.21903229, 21.95680809], [69.21875, 21.95680618], [69.21875, 21.95708275], [69.21847534, 21.95708275], [69.21848297, 21.95736122], [69.21819305, 21.95736122], [69.21819305, 21.95764923], [69.2179184, 21.95764923], [69.2179184, 21.95791817], [69.21763611, 21.95791626], [69.21763611, 21.95819473], [69.21679687, 21.95819092], [69.21679687, 21.95875168], [69.21652985, 21.95875168], [69.21652985, 21.95903015], [69.21624756, 21.95902824], [69.21624756, 21.95930481], [69.2159729, 21.95930481], [69.2159729, 21.95958328], [69.21569824, 21.95958328], [69.21569824, 21.95986176], [69.21541595, 21.95986176], [69.21541595, 21.96014023], [69.2151413, 21.96014023], [69.2151413, 21.96042252], [69.21485901, 21.96041679], [69.21485901, 21.96069527], [69.21458435, 21.96069527], [69.21458435, 21.96097183], [69.21430206, 21.96097183], [69.21430206, 21.96125031], [69.2140274, 21.96125031], [69.2140274, 21.96153069], [69.21375275, 21.96152687], [69.21375275, 21.96208382], [69.21347046, 21.96208191], [69.21347046, 21.96236038], [69.21318817, 21.96236038], [69.21318817, 21.96264076], [69.21289825, 21.96264076], [69.21289825, 21.96292114], [69.21263885, 21.96291733], [69.21263885, 21.96319389], [69.2123642, 21.96319389], [69.2123642, 21.96347237], [69.21208191, 21.96347046], [69.21208191, 21.96375084], [69.21153259, 21.96375084], [69.21153259, 21.96403122], [69.21125031, 21.96403122], [69.21125031, 21.96430969], [69.21097565, 21.96430588], [69.21098328, 21.96486092], [69.21069336, 21.96486092], [69.21069336, 21.96513939], [69.2104187, 21.96513939], [69.2104187, 21.96541977], [69.21013641, 21.96541405], [69.21013641, 21.96569443], [69.20986176, 21.96569443], [69.20986176, 21.9659729], [69.2095871, 21.96597099], [69.2095871, 21.96624947], [69.20929718, 21.96624947], [69.20929718, 21.96652985], [69.20903015, 21.96652794], [69.20903015, 21.96708298], [69.20874786, 21.96708298], [69.20874786, 21.96736145], [69.20847321, 21.96735954], [69.20847321, 21.96763992], [69.20819092, 21.96763992], [69.20819092, 21.96820068], [69.20791626, 21.96819687], [69.20791626, 21.96847153], [69.2076416, 21.96846962], [69.2076416, 21.96874809], [69.20735931, 21.96874809], [69.20735931, 21.96903038], [69.20709229, 21.96903038], [69.20709229, 21.96958923], [69.20680237, 21.96958351], [69.20680237, 21.96986198], [69.20652771, 21.96985817], [69.20652771, 21.97014046], [69.20625305, 21.97014046], [69.20625305, 21.97042084], [69.20597076, 21.97041893], [69.20597076, 21.97097206], [69.20569611, 21.97096825], [69.20569611, 21.97125053], [69.20540619, 21.97125053], [69.20540619, 21.97153091], [69.20513916, 21.9715271], [69.20513916, 21.97208405], [69.20485687, 21.97207832], [69.20485687, 21.97236061], [69.20458221, 21.97236061], [69.20458221, 21.97263908], [69.20430756, 21.97262955], [69.20430756, 21.97291946], [69.20402527, 21.97291756], [69.20402527, 21.9734726], [69.20375061, 21.97347069], [69.20375061, 21.97375107], [69.20347595, 21.97375107], [69.20347595, 21.97402954], [69.20319366, 21.97402763], [69.20319366, 21.97458267], [69.20291901, 21.97458267], [69.20291901, 21.97486115], [69.20263672, 21.97486115], [69.20263672, 21.97513962], [69.20236206, 21.97513962], [69.20236206, 21.97569466], [69.20207977, 21.97569466], [69.20207977, 21.97597122], [69.20198059, 21.97597122], [69.20180511, 21.97597122], [69.20181274, 21.97624969], [69.20153046, 21.97624969], [69.20153046, 21.97680473], [69.20124817, 21.97680473], [69.20124817, 21.97708321], [69.20095825, 21.97707939], [69.20095825, 21.97764015], [69.20069122, 21.97764015], [69.20069122, 21.97792053], [69.20041656, 21.97792053], [69.20041656, 21.97820091], [69.20014191, 21.97819328], [69.20014191, 21.97847176], [69.19985962, 21.97846985], [69.19985962, 21.97903061], [69.19959259, 21.97903061], [69.19959259, 21.97931099], [69.19930267, 21.97930336], [69.19930267, 21.97958374], [69.19902802, 21.97957993], [69.19902802, 21.97986031], [69.19875336, 21.97986031], [69.19875336, 21.98042107], [69.19847107, 21.98042107], [69.19847107, 21.98014069], [69.19821167, 21.98014069], [69.19821167, 21.98042107], [69.19763947, 21.98041534], [69.19763947, 21.98069382], [69.19736481, 21.98069382], [69.19736481, 21.98097229], [69.19763947, 21.98097038], [69.19763947, 21.98125076], [69.19789886, 21.98125076], [69.19789886, 21.98181915], [69.19847107, 21.98180771], [69.19847107, 21.98208237], [69.19875336, 21.98208046], [69.19875336, 21.98236084], [69.19902802, 21.98236084], [69.19902802, 21.98264122], [69.19930267, 21.98264122], [69.19930267, 21.98236084], [69.19985962, 21.98236084], [69.19985962, 21.98264122], [69.20041656, 21.98264122], [69.20041656, 21.98291969], [69.20097351, 21.98291779], [69.20097351, 21.98319435], [69.20124817, 21.98319054], [69.20124817, 21.98402977], [69.20153046, 21.98402977], [69.20153046, 21.9845829], [69.20124817, 21.9845829], [69.20124817, 21.98486137], [69.19985962, 21.98486137], [69.19985962, 21.9845829], [69.19930267, 21.9845829], [69.19930267, 21.98374748], [69.19902802, 21.98374748], [69.19902802, 21.98347092], [69.19789886, 21.98347092], [69.19789886, 21.98374748], [69.19708252, 21.98374748], [69.19708252, 21.98347092], [69.19568634, 21.98347092], [69.19568634, 21.98374748], [69.19291687, 21.98374748], [69.19291687, 21.98402977], [69.19264221, 21.98402977], [69.19264221, 21.98430824], [69.19235992, 21.98430634], [69.19235992, 21.9845829], [69.19208527, 21.9845829], [69.19208527, 21.98486137], [69.19180298, 21.98485756], [69.19180298, 21.98513985], [69.19152832, 21.98513985], [69.19152832, 21.98542023], [69.19125366, 21.98541641], [69.19125366, 21.98569489], [69.19097137, 21.98569489], [69.19097137, 21.98597145], [69.1904068, 21.98597145], [69.1904068, 21.98625183], [69.19013977, 21.98625183], [69.19013977, 21.9865303], [69.18985748, 21.9865303], [69.18985748, 21.98681259], [69.18958282, 21.98680496], [69.18958282, 21.98708344], [69.18930817, 21.98708344], [69.18930817, 21.98736191], [69.18902588, 21.98736191], [69.18902588, 21.98763847], [69.18875122, 21.98763084], [69.18875122, 21.98792267], [69.18846893, 21.98791695], [69.18846893, 21.9881897], [69.18819427, 21.98819542], [69.18819427, 21.98847389], [69.18791962, 21.98847008], [69.18791962, 21.98875046], [69.18763733, 21.98875046], [69.18763733, 21.98903084], [69.18736267, 21.98902702], [69.18736267, 21.98958206], [69.18708038, 21.98958015], [69.18708038, 21.98986053], [69.18681335, 21.98986053], [69.18681335, 21.99014091], [69.18653107, 21.99014091], [69.18653107, 21.99041939], [69.18624878, 21.99041939], [69.18624878, 21.99069977], [69.18597412, 21.99069214], [69.18597412, 21.99097252], [69.18569183, 21.99097061], [69.18569183, 21.99125099], [69.18541718, 21.99125099], [69.18541718, 21.99180984], [69.18514252, 21.99180412], [69.18514252, 21.9920826], [69.18486023, 21.99208069], [69.18486023, 21.99236107], [69.18458557, 21.99236107], [69.1845932, 21.99263954], [69.18430328, 21.99263954], [69.18430328, 21.99291992], [69.18402863, 21.9929142], [69.18402863, 21.99319458], [69.18374634, 21.99319077], [69.18374634, 21.99376106], [69.18347168, 21.99376106], [69.18347168, 21.99403], [69.18319702, 21.99402618], [69.18319702, 21.99430466], [69.18291473, 21.99430466], [69.18291473, 21.99458313], [69.18264008, 21.99458313], [69.18264008, 21.9948616], [69.18235779, 21.9948597], [69.18235779, 21.99514008], [69.18208313, 21.99514008], [69.18208313, 21.99542046], [69.18180847, 21.99542046], [69.18180847, 21.99570084], [69.18152618, 21.99569511], [69.18152618, 21.99597168], [69.18125153, 21.99596977], [69.18125153, 21.99625015], [69.18096924, 21.99625015], [69.18096924, 21.99653053], [69.18069458, 21.99652863], [69.18069458, 21.99708366], [69.18041992, 21.99707985], [69.18041992, 21.99735832], [69.18013763, 21.99735832], [69.18013763, 21.99764061], [69.17986298, 21.99764061], [69.17986298, 21.99791908], [69.17958069, 21.99791718], [69.17958069, 21.99819374], [69.17930603, 21.99819374], [69.17930603, 21.99847221], [69.17903137, 21.9984684], [69.17903137, 21.99875069], [69.17874908, 21.99875069], [69.17874908, 21.99902916], [69.1784668, 21.99902916], [69.1784668, 21.99930954], [69.17819214, 21.99930573], [69.17819214, 21.9995842], [69.17707825, 21.99957085], [69.17707825, 22.00014114], [69.17678833, 22.00014114], [69.17678833, 22.00041962], [69.17652893, 22.0004158], [69.17652893, 22.00097275], [69.17624664, 22.00097275], [69.17624664, 22.00125122], [69.17597198, 22.00125122], [69.17597198, 22.00152969], [69.17569733, 22.00152779], [69.17569733, 22.00208282], [69.17541504, 22.00208282], [69.17541504, 22.0023613], [69.17514038, 22.00235939], [69.17514038, 22.00263977], [69.17485809, 22.00263977], [69.17485809, 22.00319481], [69.17458344, 22.00319481], [69.17458344, 22.00347137], [69.17430878, 22.00346947], [69.17430878, 22.00374985], [69.17401886, 22.00374985], [69.17401886, 22.00403023], [69.17375183, 22.00402832], [69.17375183, 22.00430489], [69.17319489, 22.00430489], [69.17319489, 22.00458336], [69.17292023, 22.00458336], [69.17292023, 22.00486183], [69.17263794, 22.00485992], [69.17263794, 22.0051403], [69.17236328, 22.0051403], [69.17236328, 22.00542068], [69.17208099, 22.00542068], [69.17208099, 22.00570107], [69.17180634, 22.00569344], [69.17180634, 22.00597191], [69.17151642, 22.00597], [69.17151642, 22.00625038], [69.17124939, 22.00625038], [69.17124939, 22.00653076], [69.17098236, 22.00653076], [69.17098236, 22.00681114], [69.17069244, 22.00680542], [69.17069244, 22.0070858], [69.17041779, 22.00708008], [69.17041779, 22.00736046], [69.17014313, 22.00736046], [69.17014313, 22.00764084], [69.16986084, 22.00764084], [69.16986084, 22.00792122], [69.1701355, 22.0079155], [69.1701355, 22.00819397], [69.16986084, 22.00819397], [69.16986084, 22.00847244], [69.16958618, 22.00847244], [69.16958618, 22.00875092], [69.16929626, 22.00873947], [69.16929626, 22.00902939], [69.16902924, 22.00902939], [69.16902924, 22.00930977], [69.16874695, 22.00930786], [69.16874695, 22.00958252], [69.16847229, 22.00958061], [69.16847229, 22.00986099], [69.16819763, 22.00986099], [69.16819763, 22.01041985], [69.16791534, 22.01041794], [69.16791534, 22.01097298], [69.16764069, 22.01096916], [69.16764069, 22.01124954], [69.16680908, 22.01124954], [69.16680908, 22.01208305], [69.16652679, 22.01208305], [69.16652679, 22.01236153], [69.16625214, 22.01236153], [69.16625214, 22.01264191], [69.16596985, 22.01264191], [69.16596985, 22.01292038], [69.16570282, 22.01292038], [69.16570282, 22.01320267], [69.1654129, 22.01319504], [69.1654129, 22.0134716], [69.16513824, 22.0134716], [69.16513824, 22.01403046], [69.16484833, 22.01403046], [69.16484833, 22.01431274], [69.1645813, 22.01431274], [69.1645813, 22.01486969], [69.16430664, 22.01486969], [69.16430664, 22.01514053], [69.16348267, 22.01514053], [69.16348267, 22.01542282], [69.16291809, 22.0154171], [69.16291809, 22.01569366], [69.1626358, 22.01569366], [69.1626358, 22.01597214], [69.16236115, 22.01597023], [69.16236115, 22.01625061], [69.16207886, 22.01625061], [69.16207886, 22.0165329], [69.16178894, 22.0165329], [69.16178894, 22.01680946], [69.16152954, 22.01680565], [69.16152954, 22.01708221], [69.16124725, 22.01708031], [69.16124725, 22.01736069], [69.1609726, 22.01736069], [69.1609726, 22.01764107], [69.16069794, 22.01764107], [69.16069794, 22.01793098], [69.16041565, 22.01791763], [69.16041565, 22.0181942], [69.16014099, 22.0181942], [69.16014099, 22.01847267], [69.1598587, 22.01847076], [69.1598587, 22.01875114], [69.15958405, 22.01874924], [69.15958405, 22.01958275], [69.15930939, 22.01958084], [69.15930176, 22.01986122], [69.15904236, 22.01986122], [69.15904236, 22.02042007], [69.15875244, 22.02041435], [69.15875244, 22.02069664], [69.1581955, 22.02069664], [69.1581955, 22.0209713], [69.15791321, 22.02096939], [69.15791321, 22.02124977], [69.15763855, 22.02124977], [69.15763855, 22.02180481], [69.15736389, 22.02180481], [69.15736389, 22.02208328], [69.1570816, 22.02208328], [69.1570816, 22.02236176], [69.15680695, 22.02235985], [69.15680695, 22.02292061], [69.15651703, 22.02292061], [69.15651703, 22.02319908], [69.15625, 22.02319527], [69.15625, 22.02375031], [69.15598297, 22.02374077], [69.15598297, 22.02430916], [69.15569305, 22.02430916], [69.15569305, 22.02486038], [69.1554184, 22.02486038], [69.1554184, 22.02514076], [69.15513611, 22.02514076], [69.15513611, 22.02541924], [69.15486145, 22.02541733], [69.15486145, 22.02569389], [69.15458679, 22.02569389], [69.15458679, 22.02597237], [69.15429688, 22.02596855], [69.15429688, 22.02652931], [69.15402985, 22.02652931], [69.15402985, 22.02680969], [69.15319824, 22.02680588], [69.15319824, 22.02708244], [69.15207672, 22.02708244], [69.15207672, 22.02736282], [69.15180206, 22.02736282], [69.15180206, 22.02763939], [69.1515274, 22.02763939], [69.1515274, 22.02791977], [69.15125275, 22.02791595], [69.15125275, 22.02819443], [69.15097046, 22.02819443], [69.15097046, 22.0284729], [69.1506958, 22.0284729], [69.1506958, 22.02902985], [69.15040588, 22.02902985], [69.15040588, 22.02931023], [69.15013885, 22.02930641], [69.15013885, 22.02958107], [69.14984894, 22.02958107], [69.14984894, 22.02987099], [69.14958191, 22.02987099], [69.14958191, 22.03013992], [69.14930725, 22.03013992], [69.14930725, 22.0304203], [69.14903259, 22.0304203], [69.14903259, 22.03070068], [69.14875031, 22.03069305], [69.14875031, 22.03097153], [69.14847565, 22.03097153], [69.14848328, 22.03125], [69.14819336, 22.03125], [69.14819336, 22.03153038], [69.1479187, 22.03153038], [69.1479187, 22.03181076], [69.14763641, 22.03180313], [69.14763641, 22.03236198], [69.14736176, 22.03236008], [69.14736176, 22.03264046], [69.1470871, 22.03263855], [69.1470871, 22.03291512], [69.14680481, 22.03291512], [69.14680481, 22.03319359], [69.14653015, 22.03319359], [69.14653015, 22.03347206], [69.14624786, 22.03347015], [69.14624786, 22.03375053], [69.14597321, 22.03375053], [69.14597321, 22.03403091], [69.14569092, 22.03403091], [69.14569092, 22.03430939], [69.14541626, 22.03430748], [69.14541626, 22.03458595], [69.1451416, 22.03458023], [69.1451416, 22.03486061], [69.14485931, 22.03486061], [69.14485931, 22.03514099], [69.14457703, 22.03514099], [69.14457703, 22.03541946], [69.14430237, 22.03541565], [69.14430237, 22.03569412], [69.14402771, 22.03569412], [69.14402771, 22.0359726], [69.14375305, 22.03597069], [69.14375305, 22.03625107], [69.14347076, 22.03625107], [69.14347076, 22.03680992], [69.14319611, 22.03680611], [69.14319611, 22.03708267], [69.14290619, 22.03708076], [69.14290619, 22.03736115], [69.14263916, 22.03736115], [69.14263916, 22.03763962], [69.14235687, 22.03763962], [69.14235687, 22.03791809], [69.14208221, 22.03791618], [69.14208221, 22.03819466], [69.14180756, 22.03819466], [69.14180756, 22.03847313], [69.14152527, 22.03847313], [69.1415329, 22.03874969], [69.14125061, 22.03874969], [69.14125061, 22.03903008], [69.14097595, 22.03902817], [69.14097595, 22.03930473], [69.14069366, 22.03930473], [69.14069366, 22.03958321], [69.14041901, 22.03958321], [69.14041901, 22.03986168], [69.13986206, 22.03986168], [69.13986206, 22.04014015], [69.13957977, 22.04014015], [69.13957977, 22.04042053], [69.13931274, 22.04042053], [69.13931274, 22.04070282], [69.13903046, 22.04069519], [69.13903046, 22.04097176], [69.13874817, 22.04097176], [69.13874817, 22.04125023], [69.13846588, 22.04125023], [69.13846588, 22.0418129], [69.13819122, 22.04180527], [69.13819122, 22.04208374], [69.13790894, 22.04208183], [69.13790894, 22.04236031], [69.13764191, 22.04236031], [69.13764191, 22.04264069], [69.13735962, 22.04264069], [69.13735962, 22.04292107], [69.13680267, 22.04291725], [69.13680267, 22.04319382], [69.13652802, 22.04319191], [69.13652802, 22.04375076], [69.13625336, 22.04375076], [69.13625336, 22.04403114], [69.13597107, 22.04403114], [69.13597107, 22.04430962], [69.13569641, 22.0443058], [69.13569641, 22.04458237], [69.13540649, 22.04458046], [69.13540649, 22.04514122], [69.13513947, 22.04514122], [69.13513947, 22.04541969], [69.13486481, 22.04541588], [69.13486481, 22.04569435], [69.13458252, 22.04569435], [69.13458252, 22.04597282], [69.13430786, 22.04597092], [69.13430786, 22.04624939], [69.1340332, 22.04624939], [69.1340332, 22.04652977], [69.13375092, 22.04652977], [69.13375092, 22.04681015], [69.13346863, 22.04680443], [69.13346863, 22.0470829], [69.13318634, 22.04708099], [69.13318634, 22.04763985], [69.13291931, 22.04763985], [69.13291931, 22.04819679], [69.13263702, 22.04819679], [69.13263702, 22.04847145], [69.13236237, 22.04846954], [69.13236237, 22.04874992], [69.13208008, 22.04874992], [69.13208008, 22.0490303], [69.13181305, 22.0490303], [69.13181305, 22.04931068], [69.13153076, 22.04930687], [69.13153076, 22.04958344], [69.13124847, 22.04958344], [69.13124847, 22.04986191], [69.13069153, 22.04985809], [69.13069153, 22.05014038], [69.13041687, 22.05014038], [69.13041687, 22.05042076], [69.13014221, 22.05041885], [69.13014221, 22.0506897], [69.12985992, 22.05069542], [69.12985992, 22.05097198], [69.12958527, 22.05097198], [69.1295929, 22.05125046], [69.12930298, 22.05125046], [69.12930298, 22.05153084], [69.12902832, 22.05153084], [69.12902832, 22.05180931], [69.12875366, 22.0518055], [69.12875366, 22.05208397], [69.12847137, 22.05207825], [69.12847137, 22.05264091], [69.12819672, 22.05264091], [69.12819672, 22.05291939], [69.12791443, 22.05291748], [69.12791443, 22.05319405], [69.12763977, 22.05319405], [69.12763977, 22.05347252], [69.12735748, 22.0534687], [69.12735748, 22.0537529], [69.12680817, 22.0537529], [69.12680817, 22.05404282], [69.12652588, 22.05404282], [69.12652588, 22.05430984], [69.12625122, 22.05430603], [69.12625122, 22.0545826], [69.12596893, 22.0545826], [69.12596893, 22.05486107], [69.12569427, 22.05486107], [69.12569427, 22.05569458], [69.12541962, 22.05569458], [69.12541962, 22.05597115], [69.12513733, 22.05597115], [69.12513733, 22.05624962], [69.12486267, 22.05624962], [69.12486267, 22.05653], [69.12458038, 22.05652809], [69.12458038, 22.05680466], [69.12430573, 22.05680466], [69.12430573, 22.05708313], [69.12403107, 22.05708313], [69.12403107, 22.0573616], [69.12374878, 22.0573597], [69.12374878, 22.05764008], [69.12346649, 22.05764008], [69.12346649, 22.05792046], [69.12319183, 22.05792046], [69.12319183, 22.05820084], [69.12291718, 22.05819321], [69.12291718, 22.05847168], [69.12264252, 22.05846977], [69.12264252, 22.05903053], [69.12236023, 22.05903053], [69.12236023, 22.05931091], [69.12208557, 22.05930328], [69.12208557, 22.05958366], [69.12124634, 22.05958366], [69.12124634, 22.05986023], [69.12097168, 22.05985069], [69.12097168, 22.06014061], [69.12069702, 22.06014061], [69.12069702, 22.06042099], [69.12041473, 22.06041527], [69.12041473, 22.06069374], [69.12014008, 22.06068993], [69.12014008, 22.06125069], [69.11987305, 22.06125069], [69.11987305, 22.06153107], [69.11958313, 22.06153107], [69.11958313, 22.06180954], [69.11930847, 22.06180763], [69.11930847, 22.0620842], [69.11902618, 22.06208038], [69.11902618, 22.06236076], [69.11875153, 22.06236076], [69.11875153, 22.06264114], [69.11846924, 22.06264114], [69.11846924, 22.06291962], [69.11819458, 22.06291771], [69.11819458, 22.06319427], [69.11791992, 22.06319427], [69.11791992, 22.06347275], [69.11763763, 22.06347084], [69.11763763, 22.06375122], [69.11736298, 22.06374741], [69.11736298, 22.0648613], [69.11708069, 22.06485748], [69.11708069, 22.06513977], [69.1167984, 22.06513977], [69.1167984, 22.06542015], [69.11597443, 22.06541634], [69.11597443, 22.06569481], [69.11569214, 22.06568909], [69.11569214, 22.06598282], [69.11541748, 22.06598282], [69.11541748, 22.06625175], [69.11514282, 22.06625175], [69.11514282, 22.06653023], [69.11486053, 22.06652832], [69.11486053, 22.06680489], [69.11458588, 22.06680489], [69.11458588, 22.06708336], [69.11430359, 22.06708336], [69.11430359, 22.06736183], [69.11402893, 22.06736183], [69.11402893, 22.0676403], [69.11373901, 22.0676403], [69.11373901, 22.06792068], [69.11347198, 22.06792068], [69.11347198, 22.06820107], [69.11319733, 22.06820107], [69.11319733, 22.06875038], [69.11292267, 22.06875038], [69.11292267, 22.0690403], [69.11264038, 22.0690403], [69.11264038, 22.06931114], [69.11235809, 22.06930542], [69.11235809, 22.06958389], [69.11207581, 22.06958008], [69.11207581, 22.06986046], [69.11235809, 22.06986046], [69.11235809, 22.07014084], [69.11207581, 22.07014084], [69.11207581, 22.07042122], [69.11180878, 22.0704174], [69.11180878, 22.07097244], [69.11152649, 22.07097054], [69.11152649, 22.07125092], [69.11125183, 22.07125092], [69.11125183, 22.07097054], [69.11096954, 22.07097054], [69.11096954, 22.07125092], [69.11067963, 22.07125092], [69.11067963, 22.07180977], [69.11042023, 22.07180977], [69.11042023, 22.07236099], [69.11013794, 22.07236099], [69.11013794, 22.07263947], [69.10986328, 22.07263947], [69.10986328, 22.07291985], [69.10958099, 22.07291412], [69.10958099, 22.0731945], [69.10902405, 22.0731945], [69.10902405, 22.07291412], [69.10874939, 22.07291412], [69.10874939, 22.0731945], [69.10847473, 22.0731945], [69.10847473, 22.07347298], [69.10819244, 22.07347107], [69.10819244, 22.07402992], [69.10791779, 22.07402611], [69.10791779, 22.07458305], [69.1076355, 22.07458305], [69.1076355, 22.07486153], [69.10708618, 22.07485962], [69.10708618, 22.07514], [69.10679626, 22.07514], [69.10679626, 22.07570076], [69.10652924, 22.07570076], [69.10652924, 22.07624817], [69.10624695, 22.07624817], [69.10624695, 22.07653046], [69.10597229, 22.07652855], [69.10597229, 22.07708359], [69.10569763, 22.07708359], [69.10569763, 22.07736206], [69.10542297, 22.07735825], [69.10542297, 22.07764053], [69.10514069, 22.07764053], [69.10514069, 22.07792091], [69.1048584, 22.0779171], [69.1048584, 22.07847214], [69.10457611, 22.07846832], [69.10457611, 22.07875061], [69.10430908, 22.07875061], [69.10430908, 22.07902908], [69.10402679, 22.07902908], [69.10402679, 22.07930946], [69.10375214, 22.07930946], [69.10375214, 22.07986069], [69.10346985, 22.07986069], [69.10346985, 22.08013916], [69.10320282, 22.08013916], [69.10320282, 22.08041954], [69.1029129, 22.08041763], [69.1029129, 22.0806942], [69.10263824, 22.08069038], [69.10263824, 22.08125114], [69.10235596, 22.08125114], [69.10235596, 22.08152962], [69.1020813, 22.08152962], [69.1020813, 22.0818119], [69.10180664, 22.08180618], [69.10180664, 22.08208275], [69.10150909, 22.08208275], [69.10150909, 22.08263969], [69.10124969, 22.08263969], [69.10124969, 22.08292007], [69.10097504, 22.08291626], [69.10097504, 22.08319473], [69.10069275, 22.08319283], [69.10069275, 22.08374977], [69.10041809, 22.08374977], [69.10041809, 22.08402824], [69.1001358, 22.08402824], [69.1001358, 22.08430481], [69.09986115, 22.08430481], [69.09986115, 22.08486176], [69.09958649, 22.08485985], [69.09958649, 22.08514023], [69.09929657, 22.08514023], [69.09929657, 22.08570099], [69.09902954, 22.08569336], [69.09902954, 22.08597183], [69.09876251, 22.08596992], [69.09876251, 22.08653069], [69.0984726, 22.08653069], [69.0984726, 22.08681107], [69.09819794, 22.08680534], [69.09819794, 22.08708382], [69.09792328, 22.08708], [69.09792328, 22.08764076], [69.09764099, 22.08764076], [69.09764099, 22.08792114], [69.0973587, 22.08791542], [69.0973587, 22.08819389], [69.09708405, 22.08819389], [69.09708405, 22.08847237], [69.09680939, 22.08847046], [69.09680176, 22.08903122], [69.0965271, 22.08903122], [69.0965271, 22.08930969], [69.09625244, 22.08930779], [69.09625244, 22.08958244], [69.09597015, 22.08958054], [69.09597015, 22.08986092], [69.09570313, 22.08986092], [69.09570313, 22.09015083], [69.09541321, 22.09013939], [69.09541321, 22.09069443], [69.09513855, 22.09069443], [69.09513855, 22.0909729], [69.09485626, 22.09096909], [69.09485626, 22.09124756], [69.0945816, 22.09124756], [69.0945816, 22.09152985], [69.09430695, 22.09152985], [69.09430695, 22.09180832], [69.09402466, 22.09180641], [69.09402466, 22.09236145], [69.09375, 22.09236145], [69.09375, 22.09264183], [69.09348297, 22.09264183], [69.09348297, 22.0929203], [69.09319305, 22.09291649], [69.09319305, 22.09347153], [69.0929184, 22.09347153], [69.0929184, 22.09375191], [69.09263611, 22.09375191], [69.09263611, 22.09403038], [69.09236145, 22.09403038], [69.09236145, 22.09431267], [69.09208679, 22.09430504], [69.09208679, 22.09458351], [69.0918045, 22.09458351], [69.0918045, 22.09486008], [69.09152985, 22.09486008], [69.09152985, 22.09514046], [69.09124756, 22.09513855], [69.09124756, 22.09569359], [69.0909729, 22.09569359], [69.0909729, 22.09597206], [69.09069824, 22.09596252], [69.09069824, 22.09625053], [69.09041595, 22.09625053], [69.09041595, 22.09653091], [69.0901413, 22.09653091], [69.0901413, 22.09680939], [69.08985901, 22.09680557], [69.08985901, 22.09708214], [69.08956909, 22.09708023], [69.08956909, 22.09764099], [69.08930206, 22.09764099], [69.08930206, 22.09791946], [69.0890274, 22.09791756], [69.0890274, 22.09819412], [69.08875275, 22.09819412], [69.08875275, 22.0984726], [69.08847046, 22.09847069], [69.08847046, 22.09875107], [69.0881958, 22.09874916], [69.0881958, 22.09902763], [69.08790588, 22.09902], [69.08790588, 22.09930992], [69.08763885, 22.09930992], [69.08763885, 22.09986115], [69.08735657, 22.09986115], [69.08735657, 22.10013962], [69.08708191, 22.10013962], [69.08708191, 22.10042], [69.08680725, 22.10041428], [69.08680725, 22.10069466], [69.08652496, 22.10069466], [69.08652496, 22.10097313], [69.08625031, 22.10097122], [69.08625031, 22.10124969], [69.08598328, 22.10124969], [69.08598328, 22.10153008], [69.0854187, 22.10152626], [69.0854187, 22.10180473], [69.08513641, 22.10180092], [69.08513641, 22.10209084], [69.08486176, 22.10208321], [69.08486176, 22.10236168], [69.0845871, 22.10235977], [69.0845871, 22.10264015], [69.08429718, 22.10264015], [69.08429718, 22.10292053], [69.08403015, 22.10292053], [69.08403015, 22.10320091], [69.08374786, 22.10319519], [69.08374786, 22.10347176], [69.08347321, 22.10346985], [69.08347321, 22.10375023], [69.08291626, 22.10375023], [69.08291626, 22.10403061], [69.0826416, 22.10403061], [69.0826416, 22.10430908], [69.08235931, 22.10430527], [69.08235931, 22.10458374], [69.08207703, 22.10457993], [69.08207703, 22.1048584], [69.08180237, 22.1048584], [69.08180237, 22.10515022], [69.08152771, 22.10515022], [69.08152771, 22.10541916], [69.08125305, 22.10541725], [69.08125305, 22.10569382], [69.08097076, 22.10569382], [69.08097076, 22.10597229], [69.08040619, 22.10596848], [69.08040619, 22.10625076], [69.08013916, 22.10625076], [69.08013916, 22.10652924], [69.07985687, 22.10652924], [69.07985687, 22.10680962], [69.07958221, 22.1068058], [69.07958221, 22.10708427], [69.07930756, 22.10707855], [69.07930756, 22.10736275], [69.0790329, 22.10736275], [69.0790329, 22.10764122], [69.07875061, 22.10764122], [69.07875061, 22.10791969], [69.07847595, 22.10791588], [69.07847595, 22.10819435], [69.07791901, 22.10819435], [69.07791901, 22.10847282], [69.07762909, 22.10847282], [69.07762909, 22.10874939], [69.07736206, 22.10874939], [69.07736206, 22.10902977], [69.07707977, 22.10902977], [69.07707977, 22.10931015], [69.07680511, 22.10930634], [69.07680511, 22.1095829], [69.07653046, 22.1095829], [69.07653046, 22.10986137], [69.07624817, 22.10985947], [69.07624817, 22.11013985], [69.07596588, 22.11013985], [69.07596588, 22.11042023], [69.07541656, 22.11041641], [69.07541656, 22.11069489], [69.07514191, 22.11069489], [69.07514191, 22.11097145], [69.07485962, 22.11096191], [69.07485962, 22.11124992], [69.07459259, 22.11124992], [69.07459259, 22.1115303], [69.07430267, 22.1115303], [69.07430267, 22.11181068], [69.07402802, 22.11180305], [69.07402802, 22.11208344], [69.07375336, 22.11208344], [69.07375336, 22.11236191], [69.07347107, 22.11236], [69.07347107, 22.11264038], [69.07290649, 22.11264038], [69.07290649, 22.11292076], [69.07263947, 22.11291695], [69.07263947, 22.1131897], [69.07236481, 22.11319733], [69.07236481, 22.11347198], [69.07208252, 22.11347008], [69.07208252, 22.11375046], [69.07182312, 22.11375046], [69.07182312, 22.11403084], [69.0715332, 22.11403084], [69.0715332, 22.11432076], [69.07125092, 22.1143055], [69.07125092, 22.11458588], [69.07096863, 22.11458015], [69.07096863, 22.11486053], [69.07041931, 22.11486053], [69.07041931, 22.11514091], [69.07013702, 22.11514091], [69.07013702, 22.11541939], [69.06986237, 22.11541557], [69.06986237, 22.11569405], [69.06958008, 22.11569405], [69.06958008, 22.11597252], [69.06931305, 22.11597061], [69.06931305, 22.11625099], [69.06903076, 22.11625099], [69.06903076, 22.11652946], [69.0687561, 22.11652946], [69.0687561, 22.11680984], [69.06846619, 22.11680984], [69.06846619, 22.11708832], [69.06791687, 22.11708832], [69.06791687, 22.11736107], [69.06764221, 22.11736107], [69.06764221, 22.11763954], [69.06735992, 22.11763954], [69.06735992, 22.11791992], [69.06708527, 22.11791611], [69.06708527, 22.11819458], [69.06680298, 22.11819458], [69.06680298, 22.11847305], [69.06652832, 22.11846924], [69.06652832, 22.11874962], [69.06624603, 22.11874962], [69.06624603, 22.11903191], [69.06597137, 22.11902809], [69.06597137, 22.11930466], [69.06569672, 22.11930466], [69.06569672, 22.11958313], [69.06541443, 22.11958313], [69.06541443, 22.1198616], [69.06513977, 22.1198616], [69.06513977, 22.12013817], [69.06485748, 22.12013054], [69.06485748, 22.12070274], [69.06458282, 22.12069511], [69.06458282, 22.12097168], [69.06430817, 22.12097168], [69.06430817, 22.12125015], [69.06402588, 22.12125015], [69.06402588, 22.12153053], [69.06375122, 22.12153053], [69.06375122, 22.12181282], [69.06346893, 22.12180519], [69.06346893, 22.12208366], [69.06318665, 22.12208176], [69.06318665, 22.12236023], [69.06291962, 22.12236023], [69.06291962, 22.12264061], [69.0626297, 22.12264061], [69.0626297, 22.1229229], [69.06208038, 22.12291718], [69.06208038, 22.12319374], [69.06180573, 22.12319374], [69.06180573, 22.12347221], [69.06124878, 22.12347031], [69.06124878, 22.12375069], [69.06096649, 22.12375069], [69.06096649, 22.12403107], [69.06041718, 22.12403107], [69.06041718, 22.12430954], [69.06014252, 22.12430573], [69.06014252, 22.12458229], [69.05958557, 22.12458229], [69.0595932, 22.12486076], [69.05930328, 22.12486076], [69.05930328, 22.12514114], [69.05874634, 22.12514114], [69.05874634, 22.12541962], [69.05847168, 22.1254158], [69.05847168, 22.12569427], [69.05791473, 22.12569427], [69.05791473, 22.12597275], [69.05764008, 22.12597084], [69.05764008, 22.12626076], [69.05735779, 22.12626076], [69.05735779, 22.12652969], [69.05708313, 22.12652969], [69.05708313, 22.12681007], [69.05680847, 22.12680435], [69.05680847, 22.12708282], [69.05652618, 22.12708282], [69.05652618, 22.1273613], [69.05625153, 22.12735939], [69.05625153, 22.12763977], [69.05596924, 22.12763977], [69.05596924, 22.12792015], [69.05569458, 22.12791634], [69.05569458, 22.12819672], [69.05541992, 22.12819672], [69.05541992, 22.12847137], [69.05513763, 22.12846947], [69.05513763, 22.12903023], [69.05486298, 22.12902641], [69.05486298, 22.12930489], [69.05458069, 22.12930489], [69.05458069, 22.12958336], [69.05430603, 22.12957954], [69.05430603, 22.1301403], [69.05403137, 22.1301403], [69.05403137, 22.13069916], [69.05374908, 22.13069534], [69.05374908, 22.13097191], [69.05345917, 22.13096809], [69.05345917, 22.13125038], [69.05291748, 22.13125038], [69.05291748, 22.13180923], [69.05263519, 22.13180542], [69.05263519, 22.13208389], [69.05208588, 22.13207054], [69.05208588, 22.13235855], [69.05179596, 22.13235855], [69.05179596, 22.13291931], [69.05152893, 22.1329174], [69.05152893, 22.13319397], [69.05124664, 22.13318825], [69.05124664, 22.13375282], [69.05097198, 22.13375282], [69.05097198, 22.13402939], [69.05069733, 22.13402748], [69.05069733, 22.13458252], [69.05041504, 22.13458252], [69.05042267, 22.1348629], [69.05014038, 22.1348629], [69.05014038, 22.13513947], [69.04985809, 22.13513184], [69.04985809, 22.13541985], [69.04958344, 22.13541603], [69.04958344, 22.1356945], [69.04902649, 22.1356945], [69.04902649, 22.13597107], [69.04875183, 22.13597107], [69.04875183, 22.13624954], [69.04846954, 22.13624954], [69.04846954, 22.13652992], [69.04818726, 22.13652992], [69.04818726, 22.1368103], [69.04792023, 22.13680649], [69.04792023, 22.13708305], [69.0476532, 22.13708115], [69.0476532, 22.13764], [69.04736328, 22.13764], [69.04736328, 22.13820076], [69.04708099, 22.13820076], [69.04708099, 22.13875008], [69.04680634, 22.13875008], [69.04680634, 22.13903046], [69.04651642, 22.13903046], [69.04651642, 22.13931084], [69.04624939, 22.13931084], [69.04624939, 22.13903046], [69.0459671, 22.13903046], [69.0459671, 22.13931084], [69.04569244, 22.13930321], [69.04569244, 22.13958359], [69.04597473, 22.13958359], [69.04597473, 22.13986206], [69.04569244, 22.13986015], [69.04569244, 22.14014053], [69.04541779, 22.14014053], [69.04541779, 22.14042091], [69.0451355, 22.14041519], [69.0451355, 22.14097214], [69.04486084, 22.14097023], [69.04486084, 22.14126015], [69.04458618, 22.14126015], [69.04458618, 22.14153099], [69.04429626, 22.14153099], [69.04429626, 22.14180946], [69.04374695, 22.14180756], [69.04374695, 22.14208412], [69.04347229, 22.14208031], [69.04347229, 22.14236069], [69.04319763, 22.14236069], [69.04319763, 22.14264107], [69.04291534, 22.14263725], [69.04291534, 22.1431942], [69.04264069, 22.1431942], [69.04264069, 22.14347267], [69.0423584, 22.14347076], [69.0423584, 22.14402962], [69.04208374, 22.14402962], [69.04208374, 22.14430618], [69.04180908, 22.14430046], [69.04180908, 22.14486122], [69.04151917, 22.14486122], [69.04151917, 22.14513969], [69.04125214, 22.14513969], [69.04125214, 22.14541817], [69.04096985, 22.14541626], [69.04096985, 22.14569473], [69.04069519, 22.14569473], [69.04069519, 22.14596939], [69.0404129, 22.14596939], [69.0404129, 22.14625168], [69.04013824, 22.14625168], [69.04013824, 22.14736176], [69.03985596, 22.14736176], [69.03985596, 22.14764023], [69.0395813, 22.14764023], [69.0395813, 22.14792061], [69.03930664, 22.14792061], [69.03930664, 22.1482029], [69.03901672, 22.1482029], [69.03901672, 22.14903069], [69.03874969, 22.14903069], [69.03874969, 22.14931107], [69.03847504, 22.14930534], [69.03847504, 22.14958382], [69.03819275, 22.14958191], [69.03819275, 22.15014076], [69.03791809, 22.15014076], [69.03791809, 22.15042114], [69.0376358, 22.15041733], [69.0376358, 22.15069389], [69.03736115, 22.15069389], [69.03736115, 22.15097237], [69.03708649, 22.15097046], [69.03708649, 22.15125084], [69.03679657, 22.15125084], [69.03679657, 22.15153122], [69.03652954, 22.15153122], [69.03652954, 22.15180969], [69.0359726, 22.15180588], [69.0359726, 22.15208244], [69.03569794, 22.15208244], [69.03569794, 22.15236092], [69.03541565, 22.15236092], [69.03542328, 22.15263939], [69.03514099, 22.15263939], [69.03514099, 22.15291977], [69.0348587, 22.15291405], [69.0348587, 22.1534729], [69.03457642, 22.15347099], [69.03457642, 22.15374947], [69.03430939, 22.15374947], [69.03430176, 22.15402985], [69.03375244, 22.15402985], [69.03375244, 22.15431023], [69.03347015, 22.1543045], [69.03347015, 22.15458298], [69.03320313, 22.15458107], [69.03320313, 22.15513992], [69.03291321, 22.15513992], [69.03291321, 22.1554203], [69.03264618, 22.1554203], [69.03264618, 22.15570068], [69.03236389, 22.15569687], [69.03236389, 22.15597153], [69.0320816, 22.15597153], [69.0320816, 22.15624809], [69.03180695, 22.15624046], [69.03180695, 22.15653038], [69.03151703, 22.15653038], [69.03151703, 22.15681076], [69.03125, 22.15680695], [69.03125, 22.15708351], [69.03097534, 22.15708351], [69.03097534, 22.15736198], [69.03069305, 22.15735817], [69.03069305, 22.15764046], [69.0304184, 22.15764046], [69.0304184, 22.15847206], [69.03069305, 22.15846825], [69.03069305, 22.15903091], [69.0304184, 22.1590271], [69.0304184, 22.15930557], [69.02986145, 22.15930557], [69.02986145, 22.15958405], [69.02957916, 22.15957832], [69.02957916, 22.15986061], [69.02929688, 22.15986061], [69.02929688, 22.16013908], [69.02902985, 22.16013908], [69.02902985, 22.16041946], [69.02874756, 22.16041756], [69.02874756, 22.16069412], [69.0284729, 22.16069412], [69.0284729, 22.1609726], [69.02819824, 22.1609726], [69.02819824, 22.16125107], [69.02791595, 22.16125107], [69.02791595, 22.16152954], [69.0276413, 22.16152763], [69.0276413, 22.16208267], [69.02735901, 22.16208267], [69.02735901, 22.16236115], [69.02707672, 22.16236115], [69.02707672, 22.16263962], [69.02680206, 22.16263962], [69.02680206, 22.16292], [69.0265274, 22.16291618], [69.0265274, 22.16319466], [69.02625275, 22.16319466], [69.02625275, 22.16347313], [69.02597046, 22.16347122], [69.02597046, 22.16403008], [69.02541351, 22.16402817], [69.02541351, 22.16458321], [69.02513885, 22.16458321], [69.02513885, 22.16486168], [69.02485657, 22.16485977], [69.02485657, 22.16543007], [69.02458191, 22.16543007], [69.02458191, 22.16570091], [69.02430725, 22.16569328], [69.02430725, 22.16597176], [69.02402496, 22.16597176], [69.02403259, 22.16625023], [69.02375031, 22.16625023], [69.02375031, 22.16681099], [69.02347565, 22.16680527], [69.02347565, 22.16708374], [69.02319336, 22.16707993], [69.02319336, 22.16736031], [69.0229187, 22.16736031], [69.0229187, 22.16792107], [69.02263641, 22.16791534], [69.02263641, 22.16819382], [69.02236176, 22.16819382], [69.02236176, 22.16847229], [69.0220871, 22.16847038], [69.0220871, 22.16875076], [69.02179718, 22.16875076], [69.02179718, 22.16903114], [69.02153015, 22.16903114], [69.02153015, 22.16930962], [69.02124786, 22.16930771], [69.02124786, 22.16958427], [69.02097321, 22.16958046], [69.02097321, 22.16986084], [69.02069092, 22.16986084], [69.02069092, 22.17014122], [69.0201416, 22.17014122], [69.0201416, 22.17041969], [69.01985931, 22.17041779], [69.01985931, 22.17069435], [69.01958466, 22.17069435], [69.01958466, 22.17097282], [69.01930237, 22.17097282], [69.01930237, 22.17124748], [69.01902771, 22.17123985], [69.01902771, 22.17152977], [69.01875305, 22.17152977], [69.01875305, 22.17180824], [69.01847076, 22.17180634], [69.01847076, 22.1720829], [69.01819611, 22.17207909], [69.01819611, 22.17264175], [69.01790619, 22.17264175], [69.01790619, 22.17292023], [69.01763916, 22.17291641], [69.01763916, 22.17319489], [69.0173645, 22.17319489], [69.0173645, 22.17347145], [69.01708221, 22.17347145], [69.01708221, 22.17375183], [69.01680756, 22.17375183], [69.01680756, 22.17430496], [69.01652527, 22.17430496], [69.01652527, 22.17458344], [69.01625061, 22.17458344], [69.01625061, 22.17486191], [69.01597595, 22.17486191], [69.01597595, 22.17514038], [69.01513672, 22.17514038], [69.01513672, 22.17542076], [69.01457977, 22.17541695], [69.01457977, 22.1756897], [69.01403046, 22.17569542], [69.01403046, 22.17597389], [69.01374817, 22.17597008], [69.01374817, 22.17625046], [69.01346588, 22.17625046], [69.01346588, 22.17681122], [69.01319122, 22.1768055], [69.01319122, 22.17708206], [69.01291656, 22.17708015], [69.01291656, 22.17737007], [69.01264191, 22.17737007], [69.01264191, 22.17764091], [69.01235962, 22.17764091], [69.01235962, 22.17791939], [69.01208496, 22.17791748], [69.01208496, 22.17819214], [69.01180267, 22.17819214], [69.01180267, 22.17847252], [69.01154327, 22.17847061], [69.01154327, 22.17875099], [69.01097107, 22.17875099], [69.01097107, 22.17902946], [69.01069641, 22.17902946], [69.01069641, 22.17930984], [69.01041412, 22.17930412], [69.01041412, 22.1795826], [69.00985718, 22.17958069], [69.00985718, 22.17986107], [69.00958252, 22.17986107], [69.00958252, 22.18013954], [69.00930786, 22.18013954], [69.00930786, 22.18042946], [69.00875092, 22.1804142], [69.00875092, 22.18069458], [69.00846863, 22.18069458], [69.00846863, 22.18097305], [69.00818634, 22.18097115], [69.00818634, 22.18124962], [69.00791931, 22.18124962], [69.00791931, 22.18153], [69.00763702, 22.18152618], [69.00763702, 22.18208313], [69.00736237, 22.18208313], [69.00736237, 22.1823616], [69.00708008, 22.1823597], [69.00708008, 22.18264008], [69.00681305, 22.18264008], [69.00681305, 22.18292046], [69.00653076, 22.18292046], [69.00653076, 22.18320084], [69.00624847, 22.18319511], [69.00624847, 22.18347168], [69.00596619, 22.18346977], [69.00596619, 22.18374825], [69.00569153, 22.18374825], [69.00569153, 22.18431091], [69.00541687, 22.18430519], [69.00541687, 22.18458366], [69.00514221, 22.18457985], [69.00514221, 22.18485832], [69.00485992, 22.18485832], [69.00485992, 22.18514061], [69.0045929, 22.18514061], [69.0045929, 22.18541908], [69.00430298, 22.18541718], [69.00430298, 22.18597221], [69.00402832, 22.18597221], [69.00402832, 22.18625069], [69.00374603, 22.18624115], [69.00374603, 22.18652916], [69.00347137, 22.18652916], [69.00347137, 22.18680954], [69.00319672, 22.18680954], [69.00319672, 22.18736267], [69.0029068, 22.18736267], [69.0029068, 22.18764114], [69.00263977, 22.18764114], [69.00263977, 22.18791962], [69.00235748, 22.1879158], [69.00235748, 22.18819427], [69.00208282, 22.18819046], [69.00208282, 22.18875122], [69.00180817, 22.18875122], [69.00180817, 22.18902969], [69.00152588, 22.18902969], [69.00152588, 22.18931007], [69.00125122, 22.18930626], [69.00125122, 22.18958282], [69.00096893, 22.18958282], [69.00096893, 22.19013977], [69.00068665, 22.19013977], [69.00068665, 22.19042015], [69.00013733, 22.19042015], [68.99986267, 22.19041634], [68.99986267, 22.19069481], [68.99958038, 22.19069481], [68.99958038, 22.19097137], [68.99930573, 22.19097137], [68.99931335, 22.19124985], [68.99903107, 22.19124985], [68.99903107, 22.19180489], [68.99874878, 22.19180489], [68.99874878, 22.19208336], [68.99846649, 22.19207954], [68.99846649, 22.1926403], [68.99819183, 22.1926403], [68.99819183, 22.19292068], [68.99791718, 22.19292068], [68.99791718, 22.19320107], [68.99764252, 22.19319534], [68.99764252, 22.19347191], [68.99736023, 22.19347], [68.99736023, 22.19375038], [68.9970932, 22.19375038], [68.9970932, 22.19431114], [68.99680328, 22.19430542], [68.99680328, 22.19458389], [68.99652863, 22.19458389], [68.99653625, 22.19486046], [68.99624634, 22.19486046], [68.99624634, 22.19514084], [68.99597168, 22.19513893], [68.99597168, 22.1954155], [68.99569702, 22.1954155], [68.99569702, 22.19569397], [68.99541473, 22.19569397], [68.99541473, 22.19597244], [68.99514008, 22.19597054], [68.99514008, 22.19652939], [68.99485779, 22.19652939], [68.99485779, 22.19680977], [68.99458313, 22.19680786], [68.99458313, 22.19708252], [68.99430847, 22.19708061], [68.99430847, 22.19735909], [68.99402618, 22.19735909], [68.99402618, 22.19763947], [68.99375153, 22.19763947], [68.99375153, 22.19791985], [68.99346924, 22.19791794], [68.99346924, 22.1981945], [68.99319458, 22.1981945], [68.99319458, 22.19847298], [68.99291992, 22.19846916], [68.99291992, 22.19874763], [68.99263763, 22.19874763], [68.99263763, 22.19903183], [68.99236298, 22.19903183], [68.99236298, 22.1993103], [68.99208069, 22.19930649], [68.99208069, 22.19986153], [68.99180603, 22.19986153], [68.99180603, 22.20014191], [68.99153137, 22.20014191], [68.99153137, 22.20042038], [68.99124908, 22.20042038], [68.99124908, 22.20070267], [68.99097443, 22.20069504], [68.99097443, 22.2009716], [68.99069214, 22.2009716], [68.99069214, 22.20125008], [68.99040985, 22.20125008], [68.99040985, 22.20153999], [68.99014282, 22.20153999], [68.99014282, 22.20181274], [68.98986053, 22.20180511], [68.98986053, 22.20236206], [68.98958588, 22.20236015], [68.98958588, 22.20264053], [68.98929596, 22.20264053], [68.98929596, 22.20292282], [68.98902893, 22.2029171], [68.98902893, 22.20319366], [68.98874664, 22.20319366], [68.98874664, 22.20347214], [68.98847198, 22.20347023], [68.98847198, 22.20375061], [68.98819733, 22.20375061], [68.98819733, 22.20403099], [68.98791504, 22.20402718], [68.98791504, 22.20458221], [68.98764038, 22.20458031], [68.98764038, 22.20486069], [68.98735046, 22.20486069], [68.98735046, 22.20514107], [68.98707581, 22.20514107], [68.98707581, 22.20541954], [68.98652649, 22.20541763], [68.98652649, 22.2056942], [68.98625183, 22.20569038], [68.98625183, 22.20625114], [68.98596954, 22.20624924], [68.98596954, 22.20708275], [68.98569489, 22.20708275], [68.98569489, 22.20736122], [68.98542023, 22.20734978], [68.98542023, 22.20763969], [68.98513794, 22.20763969], [68.98513794, 22.20792007], [68.98486328, 22.20791435], [68.98486328, 22.2084713], [68.98458099, 22.20846939], [68.98458099, 22.20874977], [68.98402405, 22.20874977], [68.98402405, 22.20930481], [68.98347473, 22.20930481], [68.98347473, 22.20986176], [68.98291779, 22.20985985], [68.98291779, 22.21014023], [68.9826355, 22.21013641], [68.9826355, 22.2104187], [68.98236084, 22.21041107], [68.98236084, 22.21069908], [68.98208618, 22.21069527], [68.98208618, 22.21097183], [68.98179626, 22.21096992], [68.98179626, 22.21125031], [68.98152924, 22.21125031], [68.98152924, 22.21153069], [68.98124695, 22.21153069], [68.98124695, 22.21180916], [68.98097229, 22.21180916], [68.98097229, 22.21235847], [68.98069763, 22.21235847], [68.98069763, 22.21264076], [68.98041534, 22.21264076], [68.98041534, 22.21319389], [68.98014069, 22.21318817], [68.98014069, 22.21375084], [68.9798584, 22.21375084], [68.9798584, 22.21403122], [68.97957611, 22.21403122], [68.97957611, 22.21541977], [68.97930908, 22.21541595], [68.97930908, 22.21569443], [68.97902679, 22.21569252], [68.97902679, 22.21681023], [68.97875214, 22.21680641], [68.97875214, 22.21708488], [68.97846985, 22.21708488], [68.97846985, 22.21736145], [68.97820282, 22.21735954], [68.97820282, 22.21763992], [68.9779129, 22.21763992], [68.9779129, 22.21820068], [68.97763824, 22.21819305], [68.97763824, 22.21847153], [68.97735596, 22.21846962], [68.97735596, 22.21875], [68.9770813, 22.21875], [68.9770813, 22.21903038], [68.97680664, 22.21902847], [68.97680664, 22.21958351], [68.97652435, 22.21958351], [68.97652435, 22.21986198], [68.97624969, 22.21986008], [68.97624969, 22.22014046], [68.97597504, 22.22013855], [68.97597504, 22.22069359], [68.97569275, 22.22069359], [68.97569275, 22.22097206], [68.97541046, 22.22097015], [68.97541046, 22.22125053], [68.9751358, 22.22125053], [68.9751358, 22.22180939], [68.97486115, 22.22180557], [68.97486115, 22.22208595], [68.97458649, 22.22208595], [68.97458649, 22.22236061], [68.97429657, 22.22235107], [68.97429657, 22.22291946], [68.97402954, 22.22291946], [68.97402954, 22.22319412], [68.97374725, 22.22319412], [68.97374725, 22.2234726], [68.9734726, 22.22347069], [68.9734726, 22.22402954], [68.97319794, 22.22402954], [68.97319794, 22.22430992], [68.97291565, 22.22430611], [68.97291565, 22.22485924], [68.9723587, 22.22485924], [68.97236633, 22.22513962], [68.97207642, 22.22513962], [68.97207642, 22.22541809], [68.97180939, 22.22541618], [68.97180176, 22.22569466], [68.9715271, 22.22569466], [68.9715271, 22.22597313], [68.97125244, 22.22597313], [68.97125244, 22.22680473], [68.97097015, 22.22680092], [68.97097015, 22.22820282], [68.97070313, 22.22820282], [68.97070313, 22.22847939], [68.97041321, 22.22847939], [68.97041321, 22.22986031], [68.97013855, 22.22986031], [68.97013855, 22.23014069], [68.9695816, 22.23013878], [68.9695816, 22.23069382], [68.96930695, 22.23069191], [68.96930695, 22.23125076], [68.96901703, 22.23125076], [68.96901703, 22.23180962], [68.96819305, 22.23180962], [68.96819305, 22.23264122], [68.96763611, 22.23264122], [68.96763611, 22.23291969], [68.96736145, 22.23291588], [68.96736145, 22.23319435], [68.96708679, 22.23319435], [68.96708679, 22.23347282], [68.96679688, 22.23347092], [68.96679688, 22.23374939], [68.96652985, 22.23374939], [68.96652985, 22.23402977], [68.9659729, 22.23402977], [68.9659729, 22.23431015], [68.96569824, 22.23430443], [68.96569824, 22.2345829], [68.96541595, 22.2345829], [68.96541595, 22.23486137], [68.96485901, 22.23485947], [68.96485901, 22.23513985], [68.96458435, 22.23513985], [68.96458435, 22.23569679], [68.9640274, 22.23569107], [68.9640274, 22.23624992], [68.96375275, 22.23624992], [68.96375275, 22.2365303], [68.96347046, 22.23652649], [68.96347046, 22.23708344], [68.9631958, 22.23708344], [68.9631958, 22.23736191], [68.96235657, 22.23735809], [68.96235657, 22.23765182], [68.96153259, 22.23765182], [68.96153259, 22.23792076], [68.96069336, 22.23791885], [68.96069336, 22.23819351], [68.95930481, 22.23819351], [68.95930481, 22.23791885], [68.95903015, 22.23792076], [68.95903015, 22.23765182], [68.95847321, 22.23765182], [68.95847321, 22.23707962], [68.95819092, 22.23708344], [68.95819092, 22.23736191], [68.95791626, 22.23735809], [68.95791626, 22.23765182], [68.95736694, 22.23765182], [68.95736694, 22.23792076], [68.9576416, 22.23791885], [68.9576416, 22.23847008], [68.95735931, 22.23847008], [68.95736694, 22.23875046], [68.95707703, 22.23875046], [68.95707703, 22.23985863], [68.95680237, 22.23985863], [68.95680237, 22.24041939], [68.95625305, 22.24041748], [68.95625305, 22.24097252], [68.95597076, 22.24097252], [68.95597076, 22.24180984], [68.95569611, 22.24180984], [68.95569611, 22.24236107], [68.95540619, 22.24236107], [68.95540619, 22.24263954], [68.95513916, 22.24263954], [68.95513916, 22.24291992], [68.9548645, 22.24291611], [68.9548645, 22.24347115], [68.95458221, 22.24346161], [68.95458221, 22.24374962], [68.9540329, 22.24374962], [68.9540329, 22.24403], [68.95430756, 22.24402809], [68.95430756, 22.2448616], [68.9540329, 22.2448597], [68.9540329, 22.24542046], [68.95375061, 22.24541664], [68.95375061, 22.24597168], [68.95319366, 22.24597168], [68.95319366, 22.24708366], [68.95291901, 22.24708366], [68.95291901, 22.24847221], [68.95263672, 22.24847031], [68.95263672, 22.25125122], [68.95291901, 22.25124741], [68.95291901, 22.2523613], [68.95318604, 22.25235748], [68.95318604, 22.25265121], [68.95375061, 22.25265121], [68.95375061, 22.25292015], [68.95402527, 22.25291634], [68.95402527, 22.25319481], [68.95430756, 22.25319481], [68.95430756, 22.25346947], [68.95458221, 22.25346947], [68.95458221, 22.25375175], [68.95485687, 22.25375175], [68.95485687, 22.25403023], [68.95541382, 22.25402832], [68.95541382, 22.25458336], [68.95569611, 22.25457954], [68.95569611, 22.2551403], [68.95597076, 22.2551403], [68.95597076, 22.25542068], [68.95625305, 22.25542068], [68.95625305, 22.2557106], [68.95680237, 22.2557106], [68.95680237, 22.25542068], [68.95708466, 22.25541687], [68.95708466, 22.25597382], [68.9576416, 22.25597191], [68.9576416, 22.25736046], [68.95791626, 22.25736046], [68.95791626, 22.25792122], [68.9576416, 22.2579174], [68.9576416, 22.25819206], [68.95735931, 22.25819206], [68.95735931, 22.25847244], [68.95707703, 22.25846291], [68.95707703, 22.25930977], [68.95680237, 22.25930977], [68.95680237, 22.26013947], [68.95652771, 22.26013947], [68.95652771, 22.2606945], [68.95597076, 22.26069069], [68.95597076, 22.26152992], [68.95569611, 22.26152611], [68.95569611, 22.26208305], [68.95513916, 22.26208115], [68.95513916, 22.26263809], [68.95485687, 22.26263809], [68.95485687, 22.26292038], [68.95458221, 22.26292038], [68.95458221, 22.26374817], [68.95429993, 22.26374817], [68.95429993, 22.26403046], [68.9540329, 22.26403046], [68.9540329, 22.26458931], [68.95430756, 22.26458359], [68.95430756, 22.26486206], [68.9540329, 22.26485825], [68.9540329, 22.26514053], [68.95375061, 22.26514053], [68.95375061, 22.26569366], [68.95347595, 22.26568985], [68.95347595, 22.26625061], [68.95318604, 22.26625061], [68.95318604, 22.26680946], [68.95291901, 22.26680946], [68.95291901, 22.26736259], [68.95263672, 22.26736259], [68.95263672, 22.2681942], [68.95236206, 22.26819038], [68.95236206, 22.26875114], [68.95207977, 22.26875114], [68.95207977, 22.26931], [68.95181274, 22.26931], [68.95181274, 22.27042007], [68.95153046, 22.27041626], [68.95153046, 22.27069473], [68.95124054, 22.27069283], [68.95124054, 22.27153015], [68.95097351, 22.27152824], [68.95097351, 22.27236176], [68.95069122, 22.27235985], [68.95069122, 22.27320099], [68.95041656, 22.27319336], [68.95041656, 22.27347183], [68.95014191, 22.27346992], [68.95014191, 22.27375031], [68.94985962, 22.27375031], [68.94985962, 22.27403069], [68.94959259, 22.27403069], [68.94959259, 22.27431107], [68.94930267, 22.27431107], [68.94930267, 22.27514076], [68.94902802, 22.27513885], [68.94902802, 22.27569389], [68.94875336, 22.27569008], [68.94875336, 22.27625084], [68.94847107, 22.27625084], [68.94847107, 22.27681923], [68.94819641, 22.27681923], [68.94819641, 22.27736092], [68.94790649, 22.27736092], [68.94790649, 22.27791977], [68.94763947, 22.27791595], [68.94763947, 22.2784729], [68.94735718, 22.27846909], [68.94735718, 22.27902985], [68.94708252, 22.27902985], [68.94708252, 22.27959251], [68.94680786, 22.27958298], [68.94680786, 22.27986145], [68.9465332, 22.27986145], [68.9465332, 22.2804203], [68.94625092, 22.2804203], [68.94625092, 22.28070259], [68.94596863, 22.28069496], [68.94596863, 22.28097153], [68.94568634, 22.28097153], [68.94568634, 22.28153038], [68.94542694, 22.28153038], [68.94542694, 22.28181267], [68.94513702, 22.28180504], [68.94513702, 22.28236389], [68.94486237, 22.28236008], [68.94486237, 22.28292084], [68.94458008, 22.28291702], [68.94458008, 22.28347206], [68.94431305, 22.28347015], [68.94431305, 22.28403091], [68.94403076, 22.2840271], [68.94403076, 22.28458214], [68.94374847, 22.28458023], [68.94374847, 22.28514099], [68.94347382, 22.28513908], [68.94347382, 22.2859726], [68.94319153, 22.28597069], [68.94319153, 22.28680992], [68.94291687, 22.28680992], [68.94291687, 22.28792], [68.94264221, 22.28792], [68.94264221, 22.28876114], [68.94235992, 22.28874969], [68.94235992, 22.28930473], [68.94208527, 22.28930473], [68.9420929, 22.29124832], [68.94180298, 22.29124832], [68.94180298, 22.29182243], [68.94152832, 22.29182243], [68.94152832, 22.2923584], [68.94124603, 22.2923584], [68.94124603, 22.29291916], [68.94097137, 22.29291725], [68.94097137, 22.29319382], [68.94069672, 22.2931881], [68.94069672, 22.29403114], [68.9404068, 22.29403114], [68.9404068, 22.29486275], [68.94013977, 22.29486275], [68.94013977, 22.29597282], [68.93985748, 22.29597282], [68.93985748, 22.29652977], [68.93930817, 22.29652786], [68.93930817, 22.29708481], [68.93902588, 22.2970829], [68.93902588, 22.29931068], [68.93875122, 22.29931068], [68.93875122, 22.30042076], [68.93846893, 22.30042076], [68.93846893, 22.30070114], [68.93818665, 22.30070114], [68.93818665, 22.30125046], [68.93791962, 22.30125046], [68.93791962, 22.30181122], [68.93763733, 22.30181122], [68.93763733, 22.30264091], [68.93736267, 22.3026371], [68.93736267, 22.30319405], [68.93708038, 22.30319023], [68.93708038, 22.30430984], [68.93680573, 22.30430794], [68.93680573, 22.30597305], [68.93653107, 22.30596924], [68.93653107, 22.30764008], [68.93625641, 22.30764008], [68.93625641, 22.31014061], [68.93597412, 22.3101387], [68.93597412, 22.3120842], [68.93624878, 22.3120842], [68.93624878, 22.31319427], [68.93653107, 22.31319046], [68.93653107, 22.31431007], [68.93680573, 22.31430435], [68.93680573, 22.3148613], [68.93708038, 22.31485939], [68.93708038, 22.31542015], [68.93736267, 22.31542015], [68.93736267, 22.31570053], [68.93763733, 22.31570053], [68.93763733, 22.31624985], [68.93791962, 22.31624985], [68.93791962, 22.31653023], [68.93819427, 22.31652641], [68.93819427, 22.31708336], [68.93846893, 22.31708336], [68.93846893, 22.31847191], [68.93875122, 22.31846809], [68.93875122, 22.32041931], [68.93902588, 22.3204174], [68.93902588, 22.32097244], [68.93930054, 22.32097244], [68.93930054, 22.32125282], [68.93958282, 22.32125282], [68.93958282, 22.3223629], [68.93985748, 22.3223629], [68.93985748, 22.32374954], [68.94013977, 22.32374954], [68.94013977, 22.32487106], [68.94041443, 22.32486153], [68.94041443, 22.3259716], [68.94069672, 22.3259716], [68.94069672, 22.32708359], [68.94097137, 22.32708359], [68.94097137, 22.32819366], [68.94124603, 22.32818985], [68.94124603, 22.32930946], [68.94152832, 22.32930946], [68.94152832, 22.33041954], [68.94180298, 22.33041954], [68.94180298, 22.33125114], [68.9420929, 22.33125114], [68.9420929, 22.33180809], [68.94235992, 22.33180809], [68.94235992, 22.33235931], [68.94264221, 22.33235931], [68.94264221, 22.33292007], [68.94291687, 22.33291626], [68.94291687, 22.33319473], [68.94347382, 22.33319473], [68.94347382, 22.33291626], [68.94431305, 22.33292007], [68.94431305, 22.3326416], [68.94486237, 22.3326416], [68.94486237, 22.33235931], [68.94513702, 22.33235931], [68.94513702, 22.33208084], [68.94569397, 22.33208275], [68.94569397, 22.33180618], [68.94625092, 22.33180809], [68.94625092, 22.33152962], [68.94902802, 22.33152962], [68.94902802, 22.33180809], [68.95041656, 22.33180618], [68.95041656, 22.33208275], [68.95180511, 22.33208275], [68.95180511, 22.33235931], [68.95236206, 22.33235931], [68.95236206, 22.33292007], [68.95319366, 22.33291626], [68.95319366, 22.33319473], [68.95347595, 22.33319473], [68.95347595, 22.33346939], [68.95375061, 22.33346939], [68.95375061, 22.33375168], [68.9540329, 22.33373833], [68.9540329, 22.33403015], [68.95430756, 22.33402824], [68.95430756, 22.33430481], [68.95458221, 22.33430481], [68.95458221, 22.33458328], [68.95485687, 22.33457947], [68.95485687, 22.33514023], [68.95513916, 22.33513832], [68.95513916, 22.33597374], [68.95540619, 22.33597183], [68.95540619, 22.33625031], [68.95513916, 22.33625031], [68.95513916, 22.33708382], [68.95540619, 22.33708191], [68.95540619, 22.33764076], [68.95569611, 22.33764076], [68.95569611, 22.33792114], [68.95625305, 22.33791733], [68.95625305, 22.33819389], [68.95652771, 22.33819008], [68.95652771, 22.33930969], [68.95680237, 22.33930969], [68.95680237, 22.34124947], [68.95652771, 22.34124947], [68.95652771, 22.34263992], [68.95625305, 22.34263992], [68.95625305, 22.34320068], [68.95597076, 22.34320068], [68.95597076, 22.34514046], [68.95569611, 22.34514046], [68.95569611, 22.34569359], [68.95597076, 22.34568024], [68.95597076, 22.34625053], [68.95625305, 22.34625053], [68.95625305, 22.34680939], [68.95652771, 22.34680939], [68.95652771, 22.3473587], [68.95680237, 22.3473587], [68.95680237, 22.34791946], [68.95708466, 22.34791756], [68.95708466, 22.3484726], [68.95736694, 22.3484726], [68.95736694, 22.34902954], [68.9576416, 22.34902954], [68.9576416, 22.34930992], [68.95791626, 22.34930992], [68.95791626, 22.34986115], [68.95819092, 22.34986115], [68.95819092, 22.35013962], [68.95791626, 22.35013962], [68.95791626, 22.35097313], [68.95847321, 22.35097122], [68.95847321, 22.35153008], [68.95874786, 22.35153008], [68.95874786, 22.35181046], [68.95903015, 22.35180473], [68.95903015, 22.35347176], [68.95874786, 22.35346985], [68.95874786, 22.35431099], [68.95847321, 22.35430527], [68.95847321, 22.35458374], [68.95819092, 22.35457993], [68.95819092, 22.35514069], [68.95791626, 22.35513878], [68.95791626, 22.35569382], [68.95819092, 22.35569], [68.95819092, 22.35902977], [68.95791626, 22.35902977], [68.95791626, 22.35986137], [68.9576416, 22.35986137], [68.9576416, 22.36069489], [68.95735931, 22.36069489], [68.95736694, 22.36125183], [68.95708466, 22.36125183], [68.95708466, 22.36208344], [68.95680237, 22.36208344], [68.95680237, 22.36236382], [68.95708466, 22.36236382], [68.95707703, 22.3631897], [68.95680237, 22.36320114], [68.95680237, 22.36375046], [68.95652771, 22.36375046], [68.95652771, 22.36486053], [68.95680237, 22.36486053], [68.95680237, 22.36652946], [68.95708466, 22.36652756], [68.95708466, 22.3670826], [68.95735931, 22.3670826], [68.95735931, 22.36763954], [68.9576416, 22.36763954], [68.9576416, 22.36791992], [68.95791626, 22.3679142], [68.95791626, 22.36847305], [68.95819092, 22.36847115], [68.95819092, 22.36903], [68.95847321, 22.36902618], [68.95847321, 22.36930466], [68.95874786, 22.36930466], [68.95874786, 22.3698616], [68.95903015, 22.36985016], [68.95903015, 22.37042046], [68.95929718, 22.37042046], [68.95929718, 22.37070084], [68.9595871, 22.37070084], [68.9595871, 22.37124825], [68.95986176, 22.37124825], [68.95986176, 22.37181091], [68.96013641, 22.37181091], [68.96013641, 22.37235832], [68.96042633, 22.37235832], [68.96042633, 22.37291908], [68.96069336, 22.37291718], [68.96069336, 22.37347221], [68.96098328, 22.3734684], [68.96098328, 22.37402916], [68.96125031, 22.37402725], [68.96125031, 22.3745842], [68.96152496, 22.3745842], [68.96152496, 22.37486267], [68.96180725, 22.37486267], [68.96180725, 22.37541962], [68.96208191, 22.3754158], [68.96208191, 22.37569427], [68.96235657, 22.37569046], [68.96235657, 22.37625122], [68.96263885, 22.37625122], [68.96263885, 22.37652969], [68.96291351, 22.37652779], [68.96291351, 22.37708282], [68.9631958, 22.37708282], [68.9631958, 22.3773613], [68.96347046, 22.37735939], [68.96347046, 22.37792015], [68.96375275, 22.37791634], [68.96375275, 22.37819481], [68.9640274, 22.37819481], [68.9640274, 22.37847137], [68.96457672, 22.37846947], [68.96457672, 22.37874985], [68.96485901, 22.37874985], [68.96485901, 22.37903976], [68.9651413, 22.37902832], [68.9651413, 22.37986183], [68.96541595, 22.37985992], [68.96541595, 22.3801403], [68.96569824, 22.3801403], [68.96569824, 22.38042068], [68.9659729, 22.38042068], [68.9659729, 22.38070107], [68.96624756, 22.38069534], [68.96624756, 22.38097191], [68.96652985, 22.38097], [68.96652985, 22.38125038], [68.96679688, 22.38125038], [68.96679688, 22.38236046], [68.96708679, 22.38236046], [68.96708679, 22.38402748], [68.96736145, 22.38402748], [68.96736145, 22.38513756], [68.96763611, 22.38513756], [68.96763611, 22.38597298], [68.9679184, 22.38597298], [68.9679184, 22.38708305], [68.96819305, 22.38707924], [68.96819305, 22.38792038], [68.96848297, 22.38792038], [68.96848297, 22.38903046], [68.96875, 22.38903046], [68.96875, 22.38986015], [68.96901703, 22.38986015], [68.96901703, 22.39097977], [68.96930695, 22.39097977], [68.96930695, 22.39153099], [68.96985626, 22.39153099], [68.96985626, 22.39180946], [68.97013855, 22.39180565], [68.97013855, 22.39208412], [68.9706955, 22.39208412], [68.9706955, 22.39236069], [68.97097015, 22.39236069], [68.97097015, 22.39291954], [68.97125244, 22.39291573], [68.97125244, 22.3931942], [68.9715271, 22.39319038], [68.9715271, 22.39375114], [68.97180176, 22.39375114], [68.97180939, 22.39431], [68.97208405, 22.39430428], [68.97208405, 22.39458275], [68.9723587, 22.39458275], [68.9723587, 22.39513969], [68.97264099, 22.39513969], [68.97264099, 22.39542007], [68.97291565, 22.39541626], [68.97291565, 22.3959713], [68.97319794, 22.39596939], [68.97319794, 22.39624977], [68.9734726, 22.39624977], [68.9734726, 22.39680481], [68.97374725, 22.39680481], [68.97374725, 22.39736176], [68.97402954, 22.39735985], [68.97402954, 22.39763832], [68.97429657, 22.39763832], [68.97429657, 22.39819908], [68.97458649, 22.39819527], [68.97458649, 22.39847183], [68.9751358, 22.39846992], [68.9751358, 22.39903069], [68.97541809, 22.39902687], [68.97541809, 22.39958382], [68.97569275, 22.39957809], [68.97569275, 22.4001503], [68.97597504, 22.40014076], [68.97597504, 22.40069389], [68.97624969, 22.40068817], [68.97624969, 22.40125275], [68.97651672, 22.40125275], [68.97651672, 22.40153122], [68.97680664, 22.4015274], [68.97680664, 22.40208244], [68.9770813, 22.40208244], [68.9770813, 22.40236282], [68.97735596, 22.40236282], [68.97735596, 22.40291977], [68.97763824, 22.40291595], [68.97763824, 22.40319443], [68.9779129, 22.40319061], [68.9779129, 22.40374947], [68.97820282, 22.40374947], [68.97820282, 22.40431023], [68.97846985, 22.40430641], [68.97846985, 22.40458488], [68.97875214, 22.40458107], [68.97875214, 22.40513992], [68.97902679, 22.40513992], [68.97902679, 22.4054203], [68.97930908, 22.40541649], [68.97930908, 22.40597153], [68.97957611, 22.40596008], [68.97957611, 22.40625], [68.9798584, 22.40625], [68.9798584, 22.40681076], [68.98014069, 22.40680695], [68.98014069, 22.40708351], [68.98042297, 22.4070797], [68.98042297, 22.40764046], [68.98069763, 22.40764046], [68.98069763, 22.40792084], [68.98097229, 22.40791512], [68.98097229, 22.40847206], [68.98124695, 22.40847015], [68.98124695, 22.40875053], [68.98152924, 22.40875053], [68.98152924, 22.40930939], [68.98180389, 22.40930557], [68.98180389, 22.40958405], [68.98208618, 22.40958023], [68.98208618, 22.41014099], [68.98236084, 22.41014099], [68.98236084, 22.41041946], [68.9826355, 22.41041946], [68.9826355, 22.4109726], [68.98291779, 22.41097069], [68.98291779, 22.41124916], [68.98319244, 22.41124916], [68.98319244, 22.41180992], [68.9834671, 22.41180992], [68.9834671, 22.41235924], [68.98374939, 22.41235924], [68.98374939, 22.41263771], [68.98402405, 22.41263771], [68.98402405, 22.41319466], [68.98430634, 22.41319084], [68.98430634, 22.4137516], [68.98458099, 22.4137516], [68.98458099, 22.41430473], [68.98486328, 22.41430473], [68.98486328, 22.41458321], [68.98513794, 22.41458321], [68.98513794, 22.41486168], [68.98568726, 22.41486168], [68.98568726, 22.41514969], [68.98596954, 22.41514969], [68.98596954, 22.41542053], [68.98652649, 22.41542053], [68.98652649, 22.41570282], [68.98680878, 22.41569519], [68.98680878, 22.41597366], [68.98735046, 22.41597176], [68.98735046, 22.41625023], [68.98764038, 22.41625023], [68.98764038, 22.41653061], [68.98792267, 22.41653061], [68.98792267, 22.4168129], [68.98819733, 22.4168129], [68.98819733, 22.41653061], [68.98874664, 22.41653061], [68.98874664, 22.4168129], [68.98902893, 22.41680527], [68.98902893, 22.41708374], [68.98958588, 22.41708183], [68.98958588, 22.41764069], [68.98986053, 22.41764069], [68.98986053, 22.41792107], [68.99041748, 22.41791725], [68.99041748, 22.41819382], [68.99069214, 22.41819382], [68.99069214, 22.41847229], [68.99153137, 22.41847038], [68.99153137, 22.41903114], [68.99180603, 22.41903114], [68.99180603, 22.41930962], [68.99208069, 22.4193058], [68.99208069, 22.41958237], [68.99263763, 22.41958046], [68.99263763, 22.41986084], [68.99291992, 22.41986084], [68.99291992, 22.42041969], [68.99346924, 22.42041588], [68.99346924, 22.42097282], [68.99375153, 22.42095947], [68.99375153, 22.42152977], [68.99402618, 22.42152786], [68.99402618, 22.4220829], [68.99430847, 22.4220829], [68.99430847, 22.42236137], [68.99458313, 22.42236137], [68.99458313, 22.42319489], [68.99485779, 22.42319107], [68.99485779, 22.42374992], [68.99514008, 22.42374992], [68.99514008, 22.4240303], [68.99541473, 22.42402649], [68.99541473, 22.42458344], [68.99485779, 22.42458344], [68.99485779, 22.42486191], [68.99514008, 22.42485809], [68.99514008, 22.42514038], [68.9954071, 22.42514038], [68.9954071, 22.42542076], [68.99597168, 22.42541885], [68.99597168, 22.42569351], [68.99624634, 22.42569351], [68.99624634, 22.42597008], [68.99652863, 22.42597008], [68.99652863, 22.42624855], [68.99680328, 22.42624855], [68.99680328, 22.42653084], [68.9970932, 22.42653084], [68.9970932, 22.42680931], [68.99736023, 22.42680931], [68.99736023, 22.42708969], [68.99764252, 22.42708969], [68.99764252, 22.42735863], [68.99791718, 22.42735863], [68.99791718, 22.42764282], [68.99819183, 22.42764282], [68.99819183, 22.42791939], [68.99874878, 22.42791748], [68.99874878, 22.42819405], [68.99903107, 22.42819405], [68.99903107, 22.42847252], [68.99931335, 22.42847252], [68.99931335, 22.4287529], [68.99958038, 22.4287529], [68.99958038, 22.42902946], [68.99986267, 22.42902946], [68.99986267, 22.42930984], [69.00013733, 22.42930984], [69.00041962, 22.42930603], [69.00041962, 22.43013954], [69.00068665, 22.43013191], [69.00068665, 22.43041992], [69.00096893, 22.43041611], [69.00096893, 22.43069458], [69.00125122, 22.43069458], [69.00125122, 22.43097305], [69.00152588, 22.43097115], [69.00152588, 22.43124962], [69.00180817, 22.43124962], [69.00180817, 22.43180466], [69.00208282, 22.43180466], [69.00208282, 22.43208313], [69.00235748, 22.43208313], [69.00235748, 22.4323616], [69.00263977, 22.4323597], [69.00263977, 22.43264008], [69.00291443, 22.43263817], [69.00291443, 22.43319321], [69.00319672, 22.43319321], [69.00319672, 22.43347168], [69.00347137, 22.43346977], [69.00347137, 22.43403053], [69.00402832, 22.43403053], [69.00402832, 22.43375015], [69.00485992, 22.43375015], [69.00485992, 22.43403053], [69.00514221, 22.43403053], [69.00514221, 22.43542099], [69.00540924, 22.43542099], [69.00540924, 22.43653107], [69.00569153, 22.43653107], [69.00569153, 22.43764114], [69.00597382, 22.43763733], [69.00597382, 22.43819427], [69.00624847, 22.43819427], [69.00624847, 22.43847275], [69.00653076, 22.43847084], [69.00653076, 22.43875122], [69.00708008, 22.43875122], [69.00708008, 22.43902969], [69.00736237, 22.43902969], [69.00736237, 22.43931961], [69.00763702, 22.43930626], [69.00763702, 22.43958282], [69.00791931, 22.43958282], [69.00791931, 22.43985939], [69.00875092, 22.43985939], [69.00875092, 22.44014168], [69.0090332, 22.44014168], [69.0090332, 22.44042015], [69.00958252, 22.44041634], [69.00958252, 22.44069481], [69.01041412, 22.44069481], [69.01041412, 22.44096947], [69.01069641, 22.44096947], [69.01069641, 22.44125175], [69.01097107, 22.44125175], [69.01097107, 22.44180489], [69.01125336, 22.44180489], [69.01125336, 22.44208336], [69.01180267, 22.44208336], [69.01180267, 22.44236183], [69.01264191, 22.44236183], [69.01264191, 22.4426403], [69.01291656, 22.4426403], [69.01291656, 22.44292068], [69.01319122, 22.44292068], [69.01319122, 22.44320107], [69.01374817, 22.44319534], [69.01374817, 22.44347382], [69.01403046, 22.44347382], [69.01403046, 22.44319534], [69.01457977, 22.44319534], [69.01457977, 22.44347382], [69.01486206, 22.44347191], [69.01486206, 22.44403076], [69.01513672, 22.44403076], [69.01513672, 22.44431114], [69.01541901, 22.44430542], [69.01541901, 22.44458389], [69.01568604, 22.44458008], [69.01568604, 22.44486046], [69.01597595, 22.44486046], [69.01597595, 22.44513893], [69.01625061, 22.44512939], [69.01625061, 22.44542122], [69.0173645, 22.4454174], [69.0173645, 22.44569588], [69.01763916, 22.44569016], [69.01763916, 22.44652939], [69.01790619, 22.44652939], [69.01790619, 22.44680977], [69.01847076, 22.44680405], [69.01847076, 22.44708252], [69.0201416, 22.44708061], [69.0201416, 22.44736099], [69.02069092, 22.44736099], [69.02069092, 22.44763947], [69.02153015, 22.44763947], [69.02153015, 22.44791985], [69.0220871, 22.44791985], [69.0220871, 22.44820023], [69.0229187, 22.4481945], [69.0229187, 22.44847298], [69.02319336, 22.44847107], [69.02319336, 22.44874954], [69.02347565, 22.44874954], [69.02348328, 22.44930077], [69.02375031, 22.44930649], [69.02375031, 22.44958305], [69.0256958, 22.44958305], [69.0256958, 22.44986153], [69.02625275, 22.44985962], [69.02625275, 22.45013809], [69.02680206, 22.45013809], [69.02680206, 22.45042038], [69.02735901, 22.45042038], [69.02735901, 22.45070076], [69.02791595, 22.45070076], [69.02791595, 22.45126152], [69.02819824, 22.45126152], [69.02819824, 22.45153046], [69.0284729, 22.45153046], [69.0284729, 22.45208359], [69.02874756, 22.45207977], [69.02874756, 22.45235825], [69.02902985, 22.45235825], [69.02902985, 22.45264053], [69.02957916, 22.45264053], [69.02957916, 22.45292091], [69.03013611, 22.4529171], [69.03013611, 22.45319366], [69.0304184, 22.45319366], [69.0304184, 22.45347023], [69.03125, 22.45346832], [69.03125, 22.45375061], [69.03152466, 22.45375061], [69.03152466, 22.45430565], [69.03180695, 22.45430565], [69.03180695, 22.45458412], [69.0320816, 22.45458031], [69.0320816, 22.45486259], [69.0340271, 22.45486259], [69.0340271, 22.45514107], [69.03430176, 22.45514107], [69.03430939, 22.45541954], [69.03514099, 22.45541573], [69.03514099, 22.4556942], [69.03541565, 22.4556942], [69.03541565, 22.45597267], [69.0359726, 22.45597267], [69.0359726, 22.45625114], [69.03708649, 22.45625114], [69.03708649, 22.45652962], [69.03791809, 22.45652962], [69.03791809, 22.45681], [69.03847504, 22.45680618], [69.03847504, 22.45708275], [69.03874969, 22.4570694], [69.03874969, 22.45736122], [69.0395813, 22.45736122], [69.0395813, 22.45763969], [69.03985596, 22.45763969], [69.03985596, 22.45792007], [69.0404129, 22.45791626], [69.0404129, 22.45819473], [69.04096985, 22.45819473], [69.04096985, 22.4584713], [69.04151917, 22.45846939], [69.04151917, 22.45874977], [69.04180908, 22.45874977], [69.04180908, 22.45846939], [69.04207611, 22.45846939], [69.04207611, 22.45874977], [69.04264069, 22.45874977], [69.04264069, 22.45903015], [69.04291534, 22.45902824], [69.04291534, 22.45930481], [69.04319763, 22.45930481], [69.04319763, 22.45958328], [69.04374695, 22.45958328], [69.04374695, 22.45986176], [69.04402924, 22.45985985], [69.04402924, 22.46014023], [69.04458618, 22.46014023], [69.04458618, 22.46042061], [69.04514313, 22.46042061], [69.04514313, 22.46070099], [69.04569244, 22.46069527], [69.04569244, 22.46097183], [69.04651642, 22.46096992], [69.04651642, 22.46125031], [69.04680634, 22.46125031], [69.04680634, 22.46153069], [69.04708099, 22.46153069], [69.04708099, 22.46181107], [69.04763794, 22.46180534], [69.04763794, 22.46208382], [69.04846954, 22.46208], [69.04846954, 22.46236038], [69.04902649, 22.46236038], [69.04902649, 22.46264076], [69.04957581, 22.46264076], [69.04957581, 22.46292114], [69.05014038, 22.46292114], [69.05014038, 22.46319962], [69.05097198, 22.46319389], [69.05097198, 22.46347237], [69.05152893, 22.46347046], [69.05152893, 22.46375084], [69.05208588, 22.46375084], [69.05208588, 22.46403122], [69.05264282, 22.46403122], [69.05264282, 22.46430969], [69.05319214, 22.46430588], [69.05319214, 22.46458244], [69.05374908, 22.46458054], [69.05374908, 22.46486092], [69.05430603, 22.46486092], [69.05430603, 22.46513748], [69.05486298, 22.46513748], [69.05486298, 22.46541977], [69.05541992, 22.46541595], [69.05541992, 22.46569443], [69.05596924, 22.46569443], [69.05596924, 22.4659729], [69.05652618, 22.4659729], [69.05652618, 22.46625137], [69.05735779, 22.46623993], [69.05735779, 22.46653175], [69.05819702, 22.46653175], [69.05819702, 22.46681023], [69.05874634, 22.46680641], [69.05874634, 22.46708107], [69.05930328, 22.46708107], [69.05930328, 22.46736145], [69.05986023, 22.46736145], [69.05986023, 22.46764183], [69.06014252, 22.46764183], [69.06014252, 22.46875191], [69.06041718, 22.46875191], [69.06041718, 22.46903038], [69.06097412, 22.46902847], [69.06097412, 22.46930504], [69.06124878, 22.46930504], [69.06124878, 22.46958351], [69.06180573, 22.46958351], [69.06180573, 22.46986389], [69.06208038, 22.46986008], [69.06208038, 22.47014046], [69.0626297, 22.47014046], [69.0626297, 22.47042084], [69.06291962, 22.47041702], [69.06291962, 22.47069359], [69.06346893, 22.47068977], [69.06346893, 22.47153091], [69.06375122, 22.4715271], [69.06375122, 22.47208595], [69.06402588, 22.47208023], [69.06402588, 22.47264099], [69.06430817, 22.47263908], [69.06430817, 22.47319412], [69.06458282, 22.47319031], [69.06458282, 22.47375107], [69.06485748, 22.47375107], [69.06485748, 22.47402954], [69.06513977, 22.47402954], [69.06513977, 22.47430992], [69.06541443, 22.4743042], [69.06541443, 22.47458267], [69.06568909, 22.47458076], [69.06568909, 22.47486115], [69.06597137, 22.47486115], [69.06597137, 22.47513962], [69.06624603, 22.47513962], [69.06624603, 22.47542953], [69.06652832, 22.47542953], [69.06652832, 22.47624969], [69.06680298, 22.47624969], [69.06680298, 22.47680473], [69.06735992, 22.47680473], [69.06735992, 22.47708321], [69.06624603, 22.47707939], [69.06624603, 22.47763824], [69.06652832, 22.47763824], [69.06652832, 22.47903061], [69.06680298, 22.47903061], [69.06680298, 22.47930908], [69.06708527, 22.47930527], [69.06708527, 22.47958374], [69.06735992, 22.47957993], [69.06735992, 22.48014069], [69.06791687, 22.48014069], [69.06791687, 22.4798584], [69.0687561, 22.4798584], [69.06874847, 22.47930527], [69.06903076, 22.47930908], [69.06903076, 22.47820091], [69.06931305, 22.47820091], [69.06931305, 22.47792053], [69.06958008, 22.47792053], [69.06958008, 22.47763824], [69.06986237, 22.47763824], [69.06986237, 22.47735977], [69.07125092, 22.47735977], [69.07125092, 22.47763824], [69.07182312, 22.47763824], [69.07182312, 22.47792053], [69.07208252, 22.47792053], [69.07208252, 22.47820091], [69.07514191, 22.47819519], [69.07514191, 22.47847176], [69.07707977, 22.47846985], [69.07707977, 22.47874832], [69.07791901, 22.47874832], [69.07791901, 22.47903061], [69.07875061, 22.47903061], [69.07875061, 22.47930908], [69.07930756, 22.47930908], [69.07930756, 22.47903061], [69.07985687, 22.47903061], [69.07985687, 22.47846985], [69.08013916, 22.47847176], [69.08013916, 22.47819519], [69.07985687, 22.47820091], [69.07985687, 22.47792053], [69.08013916, 22.47792053], [69.08013916, 22.47680092], [69.08041382, 22.47680473], [69.08041382, 22.47569466], [69.08097076, 22.47569466], [69.08097076, 22.47541618], [69.08152771, 22.47542953], [69.08152771, 22.47513962], [69.08291626, 22.47513962], [69.08291626, 22.47458076], [69.08319092, 22.47458267], [69.08319092, 22.4743042], [69.08403015, 22.47430992], [69.08403015, 22.47402954], [69.08513641, 22.47402954], [69.08513641, 22.47291946], [69.0854187, 22.47291946], [69.0854187, 22.47236061], [69.08513641, 22.47236061], [69.08513641, 22.47180939], [69.08486176, 22.47180939], [69.08486176, 22.47153091], [69.08347321, 22.47153091], [69.08347321, 22.47125053], [69.08319092, 22.47125053], [69.08319092, 22.47097015], [69.08291626, 22.47097206], [69.08291626, 22.47069359], [69.0826416, 22.47069359], [69.0826416, 22.46986389], [69.08235931, 22.46986389], [69.08235931, 22.46930504], [69.08208466, 22.46930504], [69.08208466, 22.46902847], [69.08097076, 22.46903038], [69.08097076, 22.46875191], [69.08069611, 22.46875191], [69.08069611, 22.46846962], [69.08041382, 22.46846962], [69.08041382, 22.46791649], [69.08013916, 22.4679203], [69.08013916, 22.46764183], [69.07985687, 22.46764183], [69.07985687, 22.46736145], [69.07958221, 22.46736145], [69.07958221, 22.46708107], [69.07930756, 22.46708107], [69.07930756, 22.46680641], [69.0790329, 22.46681023], [69.0790329, 22.46653175], [69.07875061, 22.46653175], [69.07875061, 22.46596909], [69.07847595, 22.4659729], [69.07847595, 22.46569443], [69.07791901, 22.46569443], [69.07791901, 22.46541595], [69.07762909, 22.46541977], [69.07762909, 22.46513748], [69.07736206, 22.46513748], [69.07736206, 22.46486092], [69.07707977, 22.46486092], [69.07707977, 22.46458054], [69.07680511, 22.46458244], [69.07680511, 22.46319389], [69.07653046, 22.46319962], [69.07653046, 22.46264076], [69.07624817, 22.46264076], [69.07624817, 22.46181107], [69.07596588, 22.46181107], [69.07596588, 22.46096992], [69.07569122, 22.46097183], [69.07569122, 22.46013832], [69.07541656, 22.46014023], [69.07541656, 22.4593029], [69.07514191, 22.45930481], [69.07514191, 22.45874977], [69.07485962, 22.45874977], [69.07485962, 22.45792007], [69.07459259, 22.45792007], [69.07459259, 22.45736122], [69.07430267, 22.45736122], [69.07430267, 22.45681], [69.07459259, 22.45681], [69.07459259, 22.45541954], [69.07485962, 22.45541954], [69.07485962, 22.45429993], [69.07458496, 22.45430565], [69.07458496, 22.45402718], [69.07430267, 22.45402908], [69.07430267, 22.45375061], [69.07402802, 22.45375061], [69.07402802, 22.45346832], [69.07375336, 22.45347023], [69.07375336, 22.45264053], [69.07347107, 22.45264053], [69.07347107, 22.45207977], [69.07208252, 22.45208359], [69.07208252, 22.45180511], [69.07182312, 22.45181084], [69.07182312, 22.45153046], [69.0715332, 22.45153046], [69.0715332, 22.45126152], [69.06958008, 22.45126152], [69.06958008, 22.45153046], [69.06903076, 22.45153046], [69.06903076, 22.45181084], [69.06874847, 22.45180511], [69.06874847, 22.45208359], [69.06764221, 22.45208359], [69.06764221, 22.45180511], [69.0670929, 22.45181084], [69.0670929, 22.45153046], [69.06680298, 22.45153046], [69.06680298, 22.45126152], [69.06652832, 22.45126152], [69.06652832, 22.4509697], [69.06625366, 22.4509716], [69.06625366, 22.45069504], [69.06597137, 22.45070076], [69.06597137, 22.45013809], [69.06539917, 22.45013809], [69.06539917, 22.44985962], [69.06430817, 22.44986153], [69.06430817, 22.44958305], [69.06402588, 22.44958305], [69.06402588, 22.44930649], [69.06346893, 22.4493103], [69.06346893, 22.44902992], [69.06318665, 22.44902992], [69.06318665, 22.44874954], [69.06291962, 22.44874954], [69.06291962, 22.44847107], [69.06236267, 22.44847298], [69.06236267, 22.4481945], [69.06208038, 22.44820023], [69.06208038, 22.44791985], [69.06181335, 22.44791985], [69.06181335, 22.44763947], [69.06153107, 22.44763947], [69.06153107, 22.44708061], [69.06124878, 22.44708252], [69.06124878, 22.44652748], [69.06069183, 22.44652939], [69.06069183, 22.44597054], [69.06014252, 22.44597244], [69.06014252, 22.44569588], [69.05958557, 22.44569588], [69.05958557, 22.4454174], [69.05930328, 22.44542122], [69.05930328, 22.44512939], [69.05874634, 22.44513893], [69.05874634, 22.44486046], [69.05819702, 22.44486046], [69.05819702, 22.44458008], [69.05791473, 22.44458389], [69.05791473, 22.44430542], [69.05735779, 22.44431114], [69.05735779, 22.44403076], [69.05708313, 22.44403076], [69.05708313, 22.44375038], [69.05680847, 22.44375038], [69.05680847, 22.44347382], [69.05652618, 22.44347382], [69.05652618, 22.44319534], [69.05596924, 22.44320107], [69.05596924, 22.44292068], [69.05568695, 22.44292068], [69.05568695, 22.4426403], [69.05541992, 22.4426403], [69.05541992, 22.44236183], [69.05486298, 22.44236183], [69.05486298, 22.44208336], [69.05458069, 22.44208336], [69.05458069, 22.44180489], [69.05430603, 22.44180489], [69.05430603, 22.44152832], [69.05403137, 22.44153023], [69.05403137, 22.44125175], [69.05345917, 22.44125175], [69.05345917, 22.44096947], [69.05319214, 22.44096947], [69.05319214, 22.44069481], [69.05291748, 22.44069481], [69.05291748, 22.44041634], [69.05264282, 22.44042015], [69.05264282, 22.44014168], [69.05208588, 22.44014168], [69.05208588, 22.43985939], [69.05180359, 22.43985939], [69.05180359, 22.43958282], [69.05152893, 22.43958282], [69.05152893, 22.43902969], [69.05124664, 22.43902969], [69.05124664, 22.43875122], [69.05097198, 22.43875122], [69.05097198, 22.43819046], [69.05069733, 22.43819427], [69.05069733, 22.43763733], [69.05042267, 22.43764114], [69.05042267, 22.43736076], [69.05014038, 22.43736076], [69.05014038, 22.43680954], [69.04652405, 22.43680573], [69.04652405, 22.4370842], [69.04597473, 22.4370842], [69.04597473, 22.43680573], [69.04514313, 22.43680954], [69.04514313, 22.43653107], [69.04486084, 22.43653107], [69.04486084, 22.43597031], [69.04458618, 22.43597221], [69.04458618, 22.43569374], [69.04430389, 22.43569374], [69.04430389, 22.43541527], [69.04402924, 22.43542099], [69.04402924, 22.43457985], [69.04374695, 22.43458366], [69.04374695, 22.43263817], [69.04402924, 22.43264008], [69.04402924, 22.43213272], [69.04402924, 22.43124962], [69.04429626, 22.43124962], [69.04429626, 22.43041992], [69.04458618, 22.43041992], [69.04458618, 22.42986107], [69.04486084, 22.42986107], [69.04486084, 22.42930984], [69.04514313, 22.42930984], [69.04514313, 22.4287529], [69.04541779, 22.4287529], [69.04541779, 22.42819023], [69.04569244, 22.42819405], [69.04569244, 22.42764091], [69.0459671, 22.42764282], [69.0459671, 22.42708969], [69.04624939, 22.42708969], [69.04624939, 22.42653084], [69.04651642, 22.42653084], [69.04651642, 22.42596817], [69.04680634, 22.42597008], [69.04680634, 22.42541885], [69.04708099, 22.42542076], [69.04708099, 22.42485809], [69.04736328, 22.42486191], [69.04736328, 22.42430496], [69.0476532, 22.42432022], [69.0476532, 22.4240303], [69.04792023, 22.4240303], [69.04792023, 22.42346954], [69.04819489, 22.42347145], [69.04819489, 22.42291641], [69.04846954, 22.42292023], [69.04846954, 22.42263985], [69.04875183, 22.42263985], [69.04875183, 22.42208099], [69.04902649, 22.4220829], [69.04902649, 22.42180634], [69.04930878, 22.42181015], [69.04930878, 22.42124939], [69.04957581, 22.42124939], [69.04957581, 22.42095947], [69.04985809, 22.42097282], [69.04985809, 22.42041588], [69.05014038, 22.42041969], [69.05014038, 22.41986084], [69.05042267, 22.41986084], [69.05041504, 22.4193058], [69.0506897, 22.41930962], [69.0506897, 22.41875076], [69.05097198, 22.41875076], [69.05097198, 22.41847038], [69.05124664, 22.41847229], [69.05124664, 22.41791725], [69.05152893, 22.41792107], [69.05152893, 22.41736031], [69.05179596, 22.41736031], [69.05179596, 22.4168129], [69.05208588, 22.4168129], [69.05208588, 22.41625023], [69.05236053, 22.41625023], [69.05236053, 22.41570282], [69.05264282, 22.41570282], [69.05264282, 22.41486168], [69.05291748, 22.41486168], [69.05291748, 22.41430473], [69.05319214, 22.41430473], [69.05319214, 22.4137516], [69.05345917, 22.4137516], [69.05345917, 22.41319084], [69.05374908, 22.41319466], [69.05374908, 22.41263771], [69.05403137, 22.41263771], [69.05403137, 22.41235924], [69.05430603, 22.41235924], [69.05430603, 22.41180992], [69.05458069, 22.41180992], [69.05458069, 22.41124916], [69.05486298, 22.41124916], [69.05486298, 22.41069031], [69.05513763, 22.41069412], [69.05513763, 22.41041946], [69.05541992, 22.41041946], [69.05541992, 22.41014099], [69.05596924, 22.41014099], [69.05596924, 22.40986061], [69.05625153, 22.40986061], [69.05625153, 22.40958023], [69.05680847, 22.40958405], [69.05680847, 22.40930557], [69.05708313, 22.40930939], [69.05708313, 22.40901947], [69.05847168, 22.40902519], [69.05847168, 22.40875053], [69.05930328, 22.40875053], [69.05930328, 22.40847015], [69.05986023, 22.40847206], [69.05986023, 22.40819359], [69.06014252, 22.40819359], [69.06014252, 22.40791512], [69.06041718, 22.40792084], [69.06041718, 22.40764046], [69.06069183, 22.40764046], [69.06069183, 22.40736008], [69.06124878, 22.40736198], [69.06124878, 22.40652847], [69.06153107, 22.40653038], [69.06153107, 22.40513992], [69.06181335, 22.40513992], [69.06181335, 22.40402985], [69.06208038, 22.40402985], [69.06208038, 22.40208244], [69.06263733, 22.40208244], [69.06263733, 22.40180588], [69.06291962, 22.40180969], [69.06291962, 22.40153122], [69.06318665, 22.40153122], [69.06318665, 22.40125275], [69.06346893, 22.40125275], [69.06346893, 22.40097237], [69.06375122, 22.40097237], [69.06375122, 22.40069389], [69.06402588, 22.40069389], [69.06402588, 22.40041733], [69.06430817, 22.40041924], [69.06430817, 22.4001503], [69.06458282, 22.4001503], [69.06458282, 22.39985847], [69.06485748, 22.39985847], [69.06485748, 22.39957809], [69.06513977, 22.39958382], [69.06513977, 22.39930534], [69.06539917, 22.39930916], [69.06539917, 22.39903069], [69.06597137, 22.39903069], [69.06597137, 22.3987484], [69.06623077, 22.3987484], [69.06624603, 22.39846992], [69.06652832, 22.39847183], [69.06652832, 22.39819527], [69.06680298, 22.39819908], [69.06680298, 22.39792061], [69.0670929, 22.39792061], [69.0670929, 22.39763832], [69.06735992, 22.39763832], [69.06735992, 22.39735985], [69.06764221, 22.39736176], [69.06764221, 22.39708328], [69.06791687, 22.39708328], [69.06791687, 22.39680481], [69.06819153, 22.39680481], [69.06819153, 22.39652634], [69.06846619, 22.39653015], [69.06846619, 22.39624977], [69.0687561, 22.39624977], [69.06874847, 22.3959713], [69.06930542, 22.3959713], [69.06930542, 22.39569473], [69.07013702, 22.39569473], [69.07013702, 22.39541626], [69.07068634, 22.39542007], [69.07068634, 22.39513969], [69.07115173, 22.39513969], [69.07125092, 22.39513969], [69.07125092, 22.39486122], [69.07208252, 22.39486122], [69.07208252, 22.39458084], [69.07263947, 22.39458275], [69.07263947, 22.39430428], [69.07319641, 22.39431], [69.07319641, 22.39402008], [69.07402802, 22.39402771], [69.07402802, 22.39374924], [69.07459259, 22.39375114], [69.07459259, 22.39347076], [69.07597351, 22.39347267], [69.07597351, 22.3931942], [69.07736206, 22.3931942], [69.07736206, 22.39291573], [69.07847595, 22.39291954], [69.07847595, 22.39264107], [69.07985687, 22.39264107], [69.07985687, 22.39236069], [69.0826416, 22.39236069], [69.0826416, 22.39264107], [69.08376312, 22.39264107], [69.08376312, 22.39291954], [69.08486176, 22.39291573], [69.08486176, 22.3931942], [69.08597565, 22.3931942], [69.08597565, 22.39347267], [69.08682251, 22.39347076], [69.08682251, 22.39375114], [69.08791351, 22.39374924], [69.08791351, 22.39402771], [69.08875275, 22.39402008], [69.08875275, 22.39431], [69.08956909, 22.39431], [69.08956909, 22.39402008], [69.08985901, 22.39402008], [69.08985901, 22.39431], [69.09041595, 22.39430428], [69.09041595, 22.39458275], [69.09152985, 22.39458084], [69.09152985, 22.39486122], [69.09179688, 22.39486122], [69.09179688, 22.39513969], [69.09236145, 22.39513969], [69.09236145, 22.39542007], [69.0929184, 22.39541626], [69.0929184, 22.39569473], [69.09347534, 22.39569473], [69.09347534, 22.3959713], [69.09375, 22.39596939], [69.09375, 22.39653015], [69.09402466, 22.39652634], [69.09402466, 22.39708328], [69.09430695, 22.39708328], [69.09430695, 22.39736176], [69.09485626, 22.39735985], [69.09485626, 22.39763832], [69.09541321, 22.39763832], [69.09541321, 22.39792061], [69.0973587, 22.39792061], [69.0973587, 22.39819908], [69.09764099, 22.39819527], [69.09764099, 22.39847183], [69.09819794, 22.39846992], [69.09819794, 22.3987484], [69.0984726, 22.3987484], [69.0984726, 22.39903069], [69.09874725, 22.39902687], [69.09874725, 22.39958382], [69.09902954, 22.39957809], [69.09902954, 22.40041924], [69.0993042, 22.40041733], [69.0993042, 22.40097237], [69.09958649, 22.40097237], [69.09958649, 22.40208244], [69.09929657, 22.40208244], [69.09929657, 22.40291977], [69.09874725, 22.40291595], [69.09874725, 22.40319443], [69.0984726, 22.40319061], [69.0984726, 22.40374947], [69.09819794, 22.40374947], [69.09819794, 22.40431023], [69.0984726, 22.40431023], [69.0984726, 22.40513992], [69.09874725, 22.40513802], [69.09874725, 22.40819359], [69.0993042, 22.40819359], [69.0993042, 22.40847206], [69.09958649, 22.40847015], [69.09958649, 22.40875053], [69.1001358, 22.40875053], [69.1001358, 22.40902519], [69.10069275, 22.40901947], [69.10069275, 22.40930939], [69.10152435, 22.40930557], [69.10152435, 22.40958405], [69.1020813, 22.40958023], [69.1020813, 22.40986061], [69.10263824, 22.40986061], [69.10263824, 22.41014099], [69.1029129, 22.41014099], [69.1029129, 22.40986061], [69.10320282, 22.40986061], [69.10319519, 22.40958405], [69.10375214, 22.40958405], [69.10375214, 22.40930557], [69.10597229, 22.40930557], [69.10597229, 22.40958405], [69.10652924, 22.40958023], [69.10652924, 22.40986061], [69.10762024, 22.40986061], [69.10958099, 22.40986061], [69.10958099, 22.41014099], [69.10986328, 22.41014099], [69.10986328, 22.40986061], [69.11013794, 22.40986061], [69.11013794, 22.40958023], [69.11069489, 22.40958405], [69.11069489, 22.40930557], [69.11152649, 22.40930939], [69.11152649, 22.40901947], [69.11180878, 22.40902519], [69.11180878, 22.40875053], [69.11207581, 22.40875053], [69.11208344, 22.4072628], [69.11208344, 22.40708351], [69.11235809, 22.40708351], [69.11235809, 22.40652847], [69.11264038, 22.40653038], [69.11264038, 22.40625], [69.11292267, 22.40625], [69.11291504, 22.40597153], [69.11319733, 22.40597153], [69.11319733, 22.40569305], [69.11347198, 22.40570068], [69.11347198, 22.4054203], [69.11373901, 22.4054203], [69.11373901, 22.40513992], [69.11402893, 22.40513992], [69.11402893, 22.40485954], [69.11541748, 22.40485954], [69.11541748, 22.40513992], [69.11708069, 22.40513992], [69.11708069, 22.40485954], [69.11875153, 22.40486145], [69.11875153, 22.40458488], [69.11930847, 22.40458488], [69.11930847, 22.40430641], [69.11958313, 22.40431023], [69.11958313, 22.40402985], [69.11987305, 22.40402985], [69.11987305, 22.40374947], [69.12014008, 22.40374947], [69.12014008, 22.4034729], [69.12041473, 22.4034729], [69.12041473, 22.40319443], [69.12069702, 22.40319443], [69.12069702, 22.40291595], [69.12097168, 22.40291977], [69.12097168, 22.40263939], [69.12124634, 22.40263939], [69.12124634, 22.40208244], [69.12152863, 22.40208244], [69.12152863, 22.40180588], [69.12180328, 22.40180969], [69.12180328, 22.40153122], [69.12236023, 22.40153122], [69.12236023, 22.40125275], [69.12293243, 22.40125275], [69.12291718, 22.40097237], [69.12319183, 22.40097237], [69.12319183, 22.40069389], [69.12347412, 22.40069389], [69.12347412, 22.40041733], [69.12374878, 22.40041924], [69.12374878, 22.4001503], [69.12403107, 22.4001503], [69.12403107, 22.39985847], [69.12541962, 22.39985847], [69.12541962, 22.39957809], [69.12625122, 22.39958382], [69.12625122, 22.39930534], [69.12680817, 22.39930916], [69.12680817, 22.39903069], [69.12708282, 22.39903069], [69.12708282, 22.3987484], [69.12735748, 22.3987484], [69.12735748, 22.39846992], [69.12763977, 22.39847183], [69.12763977, 22.39819527], [69.12847137, 22.39819908], [69.12847137, 22.39792061], [69.12902832, 22.39792061], [69.12902832, 22.39819908], [69.12930298, 22.39819527], [69.12930298, 22.39847183], [69.1295929, 22.39846992], [69.1295929, 22.40041924], [69.12985992, 22.40041733], [69.12985992, 22.40069389], [69.13014221, 22.40069389], [69.13014221, 22.40097237], [69.13041687, 22.40097237], [69.13041687, 22.40153122], [69.13069153, 22.40153122], [69.13069153, 22.40291977], [69.13263702, 22.40291595], [69.13263702, 22.40319443], [69.13291931, 22.40319443], [69.13291931, 22.40291595], [69.13318634, 22.40291977], [69.13318634, 22.40236282], [69.13346863, 22.40236282], [69.13346863, 22.40208244], [69.13486481, 22.40208244], [69.13486481, 22.40236282], [69.13569641, 22.40236282], [69.13569641, 22.40263939], [69.13597107, 22.40263939], [69.13597107, 22.40291977], [69.13625336, 22.40291595], [69.13625336, 22.40319443], [69.13652802, 22.40319443], [69.13652802, 22.4034729], [69.13680267, 22.4034729], [69.13680267, 22.40374947], [69.13986206, 22.40374947], [69.13986206, 22.4034729], [69.1423645, 22.4034729], [69.1423645, 22.40319443], [69.14430237, 22.40319443], [69.14430237, 22.40291595], [69.14653015, 22.40291977], [69.14653015, 22.40263939], [69.14848328, 22.40263939], [69.14848328, 22.40291977], [69.14875031, 22.40291595], [69.14875031, 22.4034729], [69.14902496, 22.4034729], [69.14902496, 22.40374947], [69.14930725, 22.40374947], [69.14930725, 22.40402985], [69.14984894, 22.40402985], [69.14984894, 22.40431023], [69.15013885, 22.40430641], [69.15013885, 22.40458488], [69.1506958, 22.40458488], [69.1506958, 22.40486145], [69.15125275, 22.40485954], [69.15125275, 22.40513992], [69.1515274, 22.40513992], [69.1515274, 22.40570068], [69.15208435, 22.40569305], [69.15208435, 22.40597153], [69.15235901, 22.40596008], [69.15235901, 22.40625], [69.1526413, 22.40625], [69.1526413, 22.40653038], [69.15290833, 22.40653038], [69.15290833, 22.40681076], [69.1534729, 22.40680695], [69.1534729, 22.40708351], [69.15374756, 22.40708351], [69.15374756, 22.40736198], [69.15402985, 22.40736008], [69.15402985, 22.40764046], [69.1543045, 22.40763855], [69.1543045, 22.40819359], [69.15458679, 22.40819359], [69.15458679, 22.40847206], [69.15486145, 22.40847015], [69.15486145, 22.40875053], [69.15513611, 22.40875053], [69.15513611, 22.40930939], [69.1554184, 22.40930557], [69.1554184, 22.4109726], [69.15569305, 22.41097069], [69.15569305, 22.41180992], [69.15598297, 22.41180992], [69.15598297, 22.41208839], [69.15680695, 22.41208839], [69.15680695, 22.41235924], [69.15735626, 22.41235924], [69.15735626, 22.41263771], [69.15875244, 22.41263771], [69.15875244, 22.41319466], [69.15930176, 22.41319466], [69.15930939, 22.41347313], [69.15957642, 22.41346931], [69.15957642, 22.4137516], [69.16014099, 22.4137516], [69.16014099, 22.41403008], [69.16041565, 22.41402817], [69.16041565, 22.41430473], [69.1609726, 22.41430473], [69.1609726, 22.41458321], [69.16152954, 22.41458321], [69.16152954, 22.41486168], [69.16207886, 22.41486168], [69.16207886, 22.41514969], [69.16236115, 22.41514969], [69.16236115, 22.41486168], [69.1626358, 22.41486168], [69.1626358, 22.41458321], [69.16319275, 22.41458321], [69.16319275, 22.41430473], [69.16374969, 22.41430473], [69.16374969, 22.41402817], [69.16401672, 22.41403008], [69.16401672, 22.4137516], [69.1645813, 22.4137516], [69.1645813, 22.41346931], [69.16486359, 22.41347313], [69.16486359, 22.41319466], [69.16513824, 22.41319466], [69.16513824, 22.41291618], [69.1654129, 22.41292191], [69.1654129, 22.41263771], [69.16625214, 22.41263771], [69.16625214, 22.41292191], [69.16652679, 22.41292191], [69.16652679, 22.4137516], [69.16680908, 22.4137516], [69.16680908, 22.41403008], [69.16791534, 22.41402817], [69.16791534, 22.41430473], [69.16986084, 22.41430473], [69.16986084, 22.41597366], [69.17041779, 22.41597176], [69.17041779, 22.41625023], [69.17069244, 22.41625023], [69.17069244, 22.41653061], [69.17098236, 22.41653061], [69.17098236, 22.4168129], [69.17236328, 22.41680527], [69.17236328, 22.41708374], [69.17263794, 22.41708183], [69.17263794, 22.41736031], [69.17292023, 22.41736031], [69.17292023, 22.41792107], [69.17319489, 22.41791725], [69.17319489, 22.41819382], [69.17292023, 22.41819382], [69.17292023, 22.41847229], [69.17152405, 22.41847229], [69.17152405, 22.41958427], [69.17124939, 22.41958046], [69.17124939, 22.41986084], [69.16929626, 22.41986084], [69.16929626, 22.42014122], [69.16986084, 22.42014122], [69.16986084, 22.42041969], [69.1701355, 22.42041588], [69.1701355, 22.42097282], [69.17041779, 22.42095947], [69.17041779, 22.42181015], [69.17069244, 22.42180634], [69.17069244, 22.4220829], [69.17208099, 22.4220829], [69.17208099, 22.42180634], [69.17292023, 22.42180634], [69.17292023, 22.4220829], [69.17319489, 22.4220829], [69.17319489, 22.42180634], [69.17346954, 22.42180634], [69.17346954, 22.4220829], [69.17375183, 22.42208099], [69.17375183, 22.42263985], [69.17401886, 22.42263985], [69.17401886, 22.42292023], [69.17458344, 22.42291641], [69.17458344, 22.42319489], [69.17514038, 22.42319489], [69.17514038, 22.42347145], [69.17541504, 22.42347145], [69.17541504, 22.42374992], [69.17569733, 22.42374992], [69.17569733, 22.42432022], [69.17678833, 22.42432022], [69.17678833, 22.4240303], [69.17707825, 22.4240303], [69.17707825, 22.42374992], [69.17736053, 22.42374992], [69.17736053, 22.42346954], [69.17763519, 22.42347145], [69.17763519, 22.42236137], [69.17791748, 22.42236137], [69.17791748, 22.4220829], [69.17847443, 22.4220829], [69.17847443, 22.42180634], [69.17958069, 22.42181015], [69.17958069, 22.42152977], [69.18208313, 22.42152977], [69.18208313, 22.42124939], [69.18292236, 22.42124939], [69.18291473, 22.42097282], [69.18653107, 22.42095947], [69.18653107, 22.42124939], [69.18681335, 22.42124939], [69.18681335, 22.42152977], [69.18875122, 22.42152977], [69.18875122, 22.42181015], [69.19013977, 22.42180634], [69.19013977, 22.4220829], [69.19125366, 22.4220829], [69.19125366, 22.42236137], [69.19152832, 22.42235947], [69.19152832, 22.42263985], [69.19207764, 22.42263985], [69.19207764, 22.42292023], [69.19235992, 22.42291641], [69.19235992, 22.42319489], [69.19291687, 22.42319489], [69.19291687, 22.42347145], [69.19346619, 22.42346954], [69.19346619, 22.42374992], [69.19403076, 22.42374992], [69.19403076, 22.42319107], [69.19430542, 22.42319489], [69.19430542, 22.42152786], [69.19458008, 22.42152977], [69.19458008, 22.42124939], [69.19515228, 22.42124939], [69.19513702, 22.42069435], [69.19486237, 22.42069435], [69.19486237, 22.42041588], [69.19431305, 22.42041969], [69.19431305, 22.42014122], [69.19403076, 22.42014122], [69.19403076, 22.41958046], [69.19374847, 22.41958427], [69.19374847, 22.41875076], [69.19346619, 22.41875076], [69.19346619, 22.41847038], [69.19319153, 22.41847229], [69.19319153, 22.41819382], [69.19291687, 22.41819382], [69.19291687, 22.41736031], [69.19264221, 22.41736031], [69.19264221, 22.41625023], [69.19235992, 22.41625023], [69.19235992, 22.4137516], [69.19264221, 22.4137516], [69.19264221, 22.41235924], [69.19291687, 22.41235924], [69.19291687, 22.41097069], [69.19319153, 22.4109726], [69.19319153, 22.40986061], [69.19346619, 22.40986061], [69.19346619, 22.40875053], [69.19374847, 22.40875053], [69.19374847, 22.40818977], [69.19403076, 22.40819359], [69.19403076, 22.40763855], [69.19431305, 22.40764046], [69.19431305, 22.4070797], [69.19458008, 22.40708351], [69.19458008, 22.40680695], [69.19486237, 22.40681076], [69.19486237, 22.40625], [69.19515228, 22.40625], [69.19513702, 22.40597153], [69.19541931, 22.40597153], [69.19541931, 22.40541649], [69.19568634, 22.4054203], [69.19568634, 22.40485954], [69.19596863, 22.40486145], [69.19596863, 22.40458488], [69.19612122, 22.40458488], [69.19652557, 22.40458488], [69.19652557, 22.40430641], [69.19708252, 22.40431023], [69.19708252, 22.40402985], [69.19789886, 22.40402985], [69.19789886, 22.40374947], [69.19847107, 22.40374947], [69.19847107, 22.4034729], [69.19902802, 22.4034729], [69.19902802, 22.40319443], [69.19985962, 22.40319443], [69.19985962, 22.4034729], [69.20014191, 22.4034729], [69.20014191, 22.40458488], [69.20069122, 22.40458488], [69.20069122, 22.40430641], [69.20347595, 22.40431023], [69.20347595, 22.40402985], [69.20318604, 22.40402985], [69.20318604, 22.40374947], [69.20347595, 22.40374947], [69.20347595, 22.4034729], [69.20375061, 22.4034729], [69.20375061, 22.40319443], [69.20402527, 22.40319443], [69.20402527, 22.40308952], [69.20402527, 22.40291595], [69.20430756, 22.40291977], [69.20430756, 22.40180969], [69.20281219, 22.40180588], [69.20236206, 22.40180969], [69.20236206, 22.40153122], [69.20207977, 22.40153122], [69.20207977, 22.40125275], [69.20153046, 22.40125275], [69.20153046, 22.40097237], [69.20069122, 22.40097237], [69.20069122, 22.40069389], [69.19958496, 22.40069389], [69.19958496, 22.40014076], [69.19930267, 22.4001503], [69.19930267, 22.39957809], [69.19902802, 22.39958382], [69.19902802, 22.39902687], [69.19875336, 22.39903069], [69.19875336, 22.3987484], [69.19847107, 22.3987484], [69.19847107, 22.39819908], [69.19821167, 22.39819908], [69.19820404, 22.39792061], [69.19819641, 22.39763641], [69.19789886, 22.39763832], [69.19789886, 22.39747047], [69.19791412, 22.39652634], [69.19821167, 22.39653015], [69.19821167, 22.39596939], [69.19875336, 22.3959713], [69.19875336, 22.39486122], [69.19847107, 22.39486122], [69.19847107, 22.39458084], [69.19791412, 22.39458275], [69.19791412, 22.39402771], [69.19819641, 22.39402771], [69.19819641, 22.39374924], [69.19930267, 22.39375114], [69.19930267, 22.39347076], [69.19985962, 22.39347267], [69.19985962, 22.39236069], [69.20014191, 22.39236069], [69.20014191, 22.39180946], [69.20041656, 22.39180946], [69.20041656, 22.39068985], [69.20014191, 22.39069366], [69.20014191, 22.3904171], [69.19958496, 22.3904171], [69.19958496, 22.39069366], [69.19819641, 22.39069366], [69.19819641, 22.3904171], [69.19789886, 22.39042091], [69.19789886, 22.38957977], [69.19819641, 22.38958359], [69.19819641, 22.3884716], [69.19847107, 22.3884716], [69.19847107, 22.38791656], [69.19821167, 22.38792038], [69.19821167, 22.38764191], [69.19735718, 22.38764191], [69.19735718, 22.38736153], [69.19596863, 22.38736153], [69.19596863, 22.38708305], [69.19486237, 22.38708305], [69.19486237, 22.38680649], [69.19180298, 22.3868103], [69.19180298, 22.38653183], [69.19069672, 22.38653183], [69.19069672, 22.38625145], [69.18930817, 22.38625145], [69.18930817, 22.38596916], [69.18819427, 22.38597298], [69.18819427, 22.38541603], [69.18791962, 22.38541985], [69.18791962, 22.38513756], [69.18763733, 22.38513756], [69.18763733, 22.38485909], [69.18708038, 22.38485909], [69.18708038, 22.38458061], [69.18680573, 22.38458252], [69.18680573, 22.38430786], [69.18653107, 22.38430977], [69.18653107, 22.38402748], [69.18595886, 22.38402748], [69.18595886, 22.38375092], [69.18569183, 22.38375092], [69.18569183, 22.38347054], [69.18514252, 22.38347244], [69.18514252, 22.38319397], [69.18486023, 22.38319397], [69.18486023, 22.3829155], [69.1845932, 22.38292122], [69.1845932, 22.38264084], [69.18402863, 22.38264084], [69.18402863, 22.38236046], [69.18374634, 22.38236046], [69.18374634, 22.38181114], [69.18347168, 22.38181114], [69.18347168, 22.38153076], [69.18321228, 22.38153076], [69.18321228, 22.38097], [69.18291473, 22.38097191], [69.18291473, 22.38069534], [69.18264008, 22.38070107], [69.18264008, 22.3801403], [69.18235779, 22.3801403], [69.18235779, 22.37957954], [69.18208313, 22.37958336], [69.18208313, 22.37930489], [69.18180847, 22.37930489], [69.18180847, 22.37874985], [69.18152618, 22.37874985], [69.18152618, 22.37846947], [69.18041992, 22.37847137], [69.18041992, 22.37819481], [69.17958069, 22.37819481], [69.17958069, 22.37791634], [69.17874908, 22.37792015], [69.17874908, 22.37598038], [69.17903137, 22.37598038], [69.17903137, 22.37569046], [69.17930603, 22.37569427], [69.17930603, 22.3754158], [69.17986298, 22.37541962], [69.17986298, 22.37514114], [69.18013763, 22.37514114], [69.18013763, 22.37486267], [69.18180847, 22.37486267], [69.18180847, 22.37514114], [69.18208313, 22.37514114], [69.18208313, 22.37541962], [69.18235779, 22.37541962], [69.18235779, 22.37625122], [69.18292236, 22.37625122], [69.18292236, 22.37430954], [69.18321228, 22.37430954], [69.18321228, 22.37291908], [69.18292236, 22.37291908], [69.18292236, 22.37181091], [69.18264008, 22.37181091], [69.18264008, 22.37124825], [69.18235779, 22.37124825], [69.18235779, 22.37070084], [69.18180847, 22.37070084], [69.18180847, 22.37042046], [69.18125153, 22.37042046], [69.18125153, 22.36958122], [69.18096924, 22.36958313], [69.18096924, 22.36930466], [69.18069458, 22.36930466], [69.18069458, 22.36847305], [69.18041992, 22.36847305], [69.18041992, 22.36680412], [69.17986298, 22.36680412], [69.17986298, 22.3670826], [69.17930603, 22.36708069], [69.17930603, 22.36736107], [69.17874908, 22.36736107], [69.17874908, 22.36763954], [69.1784668, 22.36763954], [69.1784668, 22.36791992], [69.17736053, 22.36791992], [69.17736053, 22.36763954], [69.17707825, 22.36763954], [69.17707825, 22.36597061], [69.17680359, 22.36597252], [69.17680359, 22.36569595], [69.17624664, 22.36569595], [69.17624664, 22.36541748], [69.17652893, 22.36541939], [69.17652893, 22.36431122], [69.17624664, 22.36431122], [69.17624664, 22.36404037], [69.17569733, 22.36404037], [69.17569733, 22.36375046], [69.17485809, 22.36375046], [69.17485809, 22.36347008], [69.17402649, 22.36347389], [69.17402649, 22.36291695], [69.17375183, 22.36292076], [69.17375183, 22.36264038], [69.17346954, 22.36264038], [69.17346954, 22.36207962], [69.17375183, 22.36208344], [69.17375183, 22.36180496], [69.17430878, 22.36181068], [69.17430878, 22.36068916], [69.17402649, 22.36069489], [69.17402649, 22.3595829], [69.17292023, 22.3595829], [69.17292023, 22.35902977], [69.17263794, 22.35902977], [69.17263794, 22.35764122], [69.17292023, 22.35764122], [69.17292023, 22.35736084], [69.17318726, 22.35736084], [69.17318726, 22.35680962], [69.17375183, 22.35680962], [69.17375183, 22.35653114], [69.17401886, 22.35653114], [69.17401886, 22.35625076], [69.17485809, 22.35625076], [69.17485809, 22.35597038], [69.17569733, 22.35597038], [69.17569733, 22.35625076], [69.17652893, 22.35625076], [69.17652893, 22.35653114], [69.17764282, 22.35653114], [69.17764282, 22.35625076], [69.17791748, 22.35625076], [69.17791748, 22.35597038], [69.17763519, 22.35597229], [69.17763519, 22.35513878], [69.17736053, 22.35514069], [69.17736053, 22.35485077], [69.17708588, 22.35486031], [69.17708588, 22.35458374], [69.17680359, 22.35458374], [69.17680359, 22.3540287], [69.17652893, 22.35403061], [69.17652893, 22.35375023], [69.17624664, 22.35375023], [69.17624664, 22.35346985], [69.17597198, 22.35347176], [69.17597198, 22.35319328], [69.17569733, 22.35320091], [69.17569733, 22.35292053], [69.17514038, 22.35292053], [69.17514038, 22.35264015], [69.17485809, 22.35264015], [69.17485809, 22.35235977], [69.17458344, 22.35236168], [69.17458344, 22.35208321], [69.17430878, 22.35208321], [69.17430878, 22.35152817], [69.17401886, 22.35153008], [69.17401886, 22.35069275], [69.17375183, 22.35069466], [69.17375183, 22.3484726], [69.17402649, 22.3484726], [69.17402649, 22.34819412], [69.17624664, 22.34819412], [69.17624664, 22.34763908], [69.17597198, 22.3476429], [69.17597198, 22.3473587], [69.17569733, 22.3473587], [69.17569733, 22.34680939], [69.17541504, 22.34680557], [69.17541504, 22.34708405], [69.17514038, 22.34708405], [69.17514038, 22.34680557], [69.17457581, 22.34680939], [69.17457581, 22.34653091], [69.17346954, 22.34653091], [69.17346954, 22.34680939], [69.17263794, 22.34680557], [69.17263794, 22.34708405], [69.17180634, 22.34707832], [69.17180634, 22.3476429], [69.17152405, 22.34763908], [69.17152405, 22.34819412], [69.17124939, 22.34819412], [69.17124939, 22.3484726], [69.17041779, 22.3484726], [69.17041779, 22.34819412], [69.1701355, 22.34819412], [69.1701355, 22.34791756], [69.16986084, 22.34791946], [69.16986084, 22.3476429], [69.16958618, 22.3476429], [69.16958618, 22.34707832], [69.16930389, 22.34708405], [69.16930389, 22.34680557], [69.16902924, 22.34680939], [69.16902924, 22.34653091], [69.16874695, 22.34653091], [69.16874695, 22.34568024], [69.16819763, 22.34569359], [69.16819763, 22.34541893], [69.16792297, 22.34542084], [69.16792297, 22.34514046], [69.16764069, 22.34514046], [69.16764069, 22.34485817], [69.16791534, 22.34486198], [69.16791534, 22.34458351], [69.16819763, 22.34458351], [69.16819763, 22.34430504], [69.16847229, 22.34431076], [69.16847229, 22.34403038], [69.16874695, 22.34403038], [69.16874695, 22.34374809], [69.16902924, 22.34374809], [69.16902924, 22.34291077], [69.16930389, 22.34291649], [69.16930389, 22.34263611], [69.16958618, 22.34263992], [69.16958618, 22.34124947], [69.16929626, 22.34124947], [69.16929626, 22.34069061], [69.16902924, 22.34069443], [69.16902924, 22.33986092], [69.16874695, 22.33987045], [69.16874695, 22.33930969], [69.16847229, 22.33930969], [69.16847229, 22.33792114], [69.16902924, 22.33792114], [69.16902924, 22.33764076], [69.16986084, 22.33764076], [69.16986084, 22.33708191], [69.16958618, 22.33708382], [69.16958618, 22.33541679], [69.16929626, 22.33542061], [69.16929626, 22.33514023], [69.16902924, 22.33514023], [69.16902924, 22.33457947], [69.16874695, 22.33458328], [69.16874695, 22.33402824], [69.16902924, 22.33403015], [69.16902924, 22.3326416], [69.16874695, 22.3326416], [69.16874695, 22.33235931], [69.16847229, 22.33235931], [69.16847229, 22.33125114], [69.16819763, 22.33125114], [69.16819763, 22.33014107], [69.16792297, 22.33014107], [69.16792297, 22.32818985], [69.16819763, 22.32819366], [69.16819763, 22.32652855], [69.16764069, 22.32653046], [69.16764069, 22.32625008], [69.1673584, 22.32625008], [69.1673584, 22.3259697], [69.16680908, 22.3259716], [69.16680908, 22.32569313], [69.16652679, 22.32570076], [69.16652679, 22.32542038], [69.16625214, 22.32542038], [69.16625214, 22.32374954], [69.16596985, 22.32374954], [69.16596985, 22.3231926], [69.1654129, 22.3231945], [69.1654129, 22.32291603], [69.16430664, 22.32291985], [69.16430664, 22.32263947], [69.16401672, 22.32263947], [69.16401672, 22.32208252], [69.16374969, 22.32208252], [69.16374969, 22.32180595], [69.16347504, 22.32180595], [69.16347504, 22.32152748], [69.16319275, 22.32152939], [69.16319275, 22.32125282], [69.1626358, 22.32125282], [69.1626358, 22.32097244], [69.16236115, 22.32097244], [69.16236115, 22.3204174], [69.16207886, 22.32041931], [69.16207886, 22.32014084], [69.16178894, 22.32014084], [69.16178894, 22.31957817], [69.16124725, 22.31958389], [69.16124725, 22.31902885], [69.1609726, 22.31903076], [69.1609726, 22.31874084], [69.16069794, 22.31874847], [69.16069794, 22.31847191], [69.16041565, 22.31847191], [69.16041565, 22.31791878], [69.16014099, 22.31792068], [69.16014099, 22.3176403], [69.15957642, 22.3176403], [69.15957642, 22.31735992], [69.15930176, 22.31736183], [69.15930176, 22.31680489], [69.1590271, 22.31680489], [69.1590271, 22.31652641], [69.15875244, 22.31653023], [69.15875244, 22.31624985], [69.1581955, 22.31624985], [69.1581955, 22.31597137], [69.15791321, 22.31597137], [69.15791321, 22.3129158], [69.15820313, 22.31293106], [69.15820313, 22.31180954], [69.15847015, 22.31180954], [69.15847015, 22.31068993], [69.15875244, 22.31069374], [69.15875244, 22.30986023], [69.15904236, 22.30986023], [69.1590271, 22.30930519], [69.15930176, 22.30931282], [69.15930176, 22.30875015], [69.15957642, 22.30875015], [69.15957642, 22.30820274], [69.1598587, 22.30820274], [69.1598587, 22.30764008], [69.16014099, 22.30764008], [69.16014099, 22.30707932], [69.16041565, 22.30708313], [69.16041565, 22.30652809], [69.16069794, 22.30653191], [69.16069794, 22.30625153], [69.1609726, 22.30625153], [69.1609726, 22.30569077], [69.16124725, 22.30569458], [69.16124725, 22.30541611], [69.16152954, 22.30541992], [69.16152954, 22.30485916], [69.16178894, 22.30485916], [69.16178894, 22.30458069], [69.16208649, 22.3045826], [69.16208649, 22.30402946], [69.16236115, 22.30402946], [69.16236115, 22.30376053], [69.1626358, 22.30376053], [69.1626358, 22.30319023], [69.16291809, 22.30319405], [69.16291809, 22.30291939], [69.16319275, 22.30291939], [69.16319275, 22.30236053], [69.16348267, 22.30236053], [69.16347504, 22.30208397], [69.16374969, 22.30208397], [69.16374969, 22.3018055], [69.16401672, 22.30181122], [69.16401672, 22.30125046], [69.16430664, 22.30125046], [69.16430664, 22.30097008], [69.1645813, 22.30097198], [69.1645813, 22.30041695], [69.16484833, 22.30042076], [69.16484833, 22.30014038], [69.16513824, 22.30014038], [69.16513824, 22.29986], [69.1654129, 22.29986191], [69.1654129, 22.29930305], [69.16570282, 22.29931068], [69.16570282, 22.2990303], [69.16596985, 22.2990303], [69.16596985, 22.29874992], [69.16625214, 22.29874992], [69.16625214, 22.29846954], [69.16652679, 22.29847145], [69.16652679, 22.29819489], [69.16680908, 22.29819489], [69.16680908, 22.29763794], [69.16708374, 22.29763794], [69.16708374, 22.29736137], [69.1673584, 22.29736137], [69.1673584, 22.29708481], [69.16764069, 22.29708481], [69.16764069, 22.29680634], [69.16792297, 22.29681015], [69.16792297, 22.29652977], [69.16819763, 22.29652977], [69.16819763, 22.29597282], [69.16847229, 22.29597282], [69.16847229, 22.29569435], [69.16874695, 22.29569435], [69.16874695, 22.29541588], [69.16902924, 22.29541969], [69.16902924, 22.29514122], [69.16929626, 22.29514122], [69.16929626, 22.29486275], [69.16958618, 22.29486275], [69.16958618, 22.29430962], [69.16986084, 22.29430962], [69.16986084, 22.29403114], [69.17014313, 22.29403114], [69.17014313, 22.29375076], [69.17041779, 22.29375076], [69.17041779, 22.29346848], [69.17069244, 22.29347229], [69.17069244, 22.29319382], [69.17097473, 22.29319382], [69.17097473, 22.29291725], [69.17124939, 22.29291916], [69.17124939, 22.29264069], [69.17180634, 22.29264069], [69.17180634, 22.2923584], [69.17208099, 22.2923584], [69.17208099, 22.29207993], [69.17236328, 22.29208374], [69.17236328, 22.29180527], [69.17263794, 22.29182243], [69.17263794, 22.29153061], [69.17292023, 22.29153061], [69.17292023, 22.29124832], [69.17318726, 22.29124832], [69.17318726, 22.29096985], [69.17346954, 22.29097176], [69.17346954, 22.29069519], [69.17375183, 22.29070091], [69.17375183, 22.29042053], [69.17401886, 22.29042053], [69.17401886, 22.29014015], [69.17430878, 22.29014015], [69.17430878, 22.28985977], [69.17485809, 22.28986168], [69.17485809, 22.28958321], [69.17514038, 22.28958321], [69.17514038, 22.28930473], [69.17541504, 22.28930473], [69.17541504, 22.28902626], [69.17569733, 22.28903008], [69.17569733, 22.28876114], [69.17597198, 22.28876114], [69.17597198, 22.28847122], [69.17624664, 22.28847313], [69.17624664, 22.28819466], [69.17652893, 22.28819466], [69.17652893, 22.28791428], [69.17678833, 22.28792], [69.17678833, 22.28763962], [69.17707825, 22.28763962], [69.17707825, 22.28736115], [69.17736053, 22.28736115], [69.17736053, 22.28708076], [69.17763519, 22.28708267], [69.17763519, 22.2868042], [69.17819214, 22.28680992], [69.17819214, 22.28652954], [69.1784668, 22.28652954], [69.1784668, 22.28625107], [69.17874908, 22.28625107], [69.17874908, 22.28597069], [69.17903137, 22.2859726], [69.17903137, 22.28569412], [69.17930603, 22.28569412], [69.17930603, 22.28541756], [69.17958069, 22.28541946], [69.17958069, 22.28514099], [69.17986298, 22.28514099], [69.17986298, 22.28486061], [69.18013763, 22.28486061], [69.18013763, 22.28458023], [69.18069458, 22.28458214], [69.18069458, 22.28430557], [69.18096924, 22.28430939], [69.18096924, 22.28403091], [69.18125153, 22.28403091], [69.18125153, 22.28375053], [69.18152618, 22.28375053], [69.18152618, 22.28347015], [69.18180847, 22.28347206], [69.18180847, 22.28319359], [69.18208313, 22.28319359], [69.18208313, 22.28291702], [69.18235779, 22.28292084], [69.18235779, 22.28263283], [69.18264008, 22.28263855], [69.18264008, 22.28236389], [69.18319702, 22.28236389], [69.18319702, 22.28208351], [69.18347168, 22.28208351], [69.18347168, 22.28180504], [69.18374634, 22.28181267], [69.18374634, 22.28153038], [69.18402863, 22.28153038], [69.18402863, 22.28125191], [69.18430328, 22.28125191], [69.18430328, 22.28097153], [69.18458557, 22.28097153], [69.18458557, 22.28069496], [69.18474579, 22.28069496], [69.18486023, 22.28070259], [69.18486023, 22.2804203], [69.18514252, 22.2804203], [69.18514252, 22.28014183], [69.18541718, 22.28014183], [69.18541718, 22.27986145], [69.18569183, 22.27986145], [69.18569183, 22.27958298], [69.18595886, 22.27959251], [69.18595886, 22.27931023], [69.18653107, 22.27931023], [69.18653107, 22.27902985], [69.18681335, 22.27902985], [69.18681335, 22.27874756], [69.18763733, 22.27874756], [69.18763733, 22.27846909], [69.18791962, 22.2784729], [69.18791962, 22.27819443], [69.18846893, 22.27819443], [69.18846893, 22.27791595], [69.18875122, 22.27791977], [69.18875122, 22.27763748], [69.18901825, 22.27763748], [69.18901825, 22.27736092], [69.18958282, 22.27736092], [69.18958282, 22.27708054], [69.18985748, 22.27708244], [69.18985748, 22.27680779], [69.19013977, 22.27681923], [69.19013977, 22.27653122], [69.1904068, 22.27653122], [69.1904068, 22.27625084], [69.19069672, 22.27625084], [69.19069672, 22.27597046], [69.19125366, 22.27597237], [69.19125366, 22.27569389], [69.19152832, 22.27569389], [69.19152832, 22.27541542], [69.19180298, 22.27542114], [69.19180298, 22.27514076], [69.19207764, 22.27514076], [69.19207764, 22.27486038], [69.19235992, 22.27486038], [69.19235992, 22.27458], [69.19264221, 22.27458382], [69.19264221, 22.27430534], [69.19291687, 22.27431107], [69.19291687, 22.27403069], [69.19374847, 22.27403069], [69.19374847, 22.27375031], [69.19403076, 22.27375031], [69.19403076, 22.27346992], [69.19430542, 22.27347183], [69.19430542, 22.27319336], [69.19458008, 22.27320099], [69.19458008, 22.27292061], [69.19486237, 22.27292061], [69.19486237, 22.27264023], [69.19515228, 22.27264023], [69.19515228, 22.27235985], [69.19541931, 22.27236176], [69.19541931, 22.27208328], [69.19569397, 22.27208328], [69.19569397, 22.27180481], [69.19596863, 22.27180481], [69.19596863, 22.27152824], [69.19625092, 22.27153015], [69.19625092, 22.27124977], [69.19680786, 22.27124977], [69.19680786, 22.27096939], [69.19736481, 22.2709713], [69.19736481, 22.27069473], [69.19791412, 22.27069473], [69.19791412, 22.27041626], [69.19821167, 22.27042007], [69.19821167, 22.27013969], [69.19875336, 22.27013969], [69.19875336, 22.26986122], [69.19902802, 22.26986122], [69.19902802, 22.26958275], [69.19930267, 22.26958275], [69.19930267, 22.26930618], [69.19959259, 22.26931], [69.19959259, 22.26902962], [69.20014191, 22.26902962], [69.20014191, 22.26875114], [69.20041656, 22.26875114], [69.20041656, 22.26847267], [69.20069122, 22.26847267], [69.20069122, 22.2681942], [69.20097351, 22.2681942], [69.20097351, 22.26791573], [69.20124817, 22.26791954], [69.20124817, 22.2676506], [69.20181274, 22.2676506], [69.20181274, 22.26736259], [69.20207977, 22.26736259], [69.20207977, 22.2670784], [69.20236206, 22.26708412], [69.20236206, 22.26680565], [69.20263672, 22.26680946], [69.20263672, 22.26652908], [69.20318604, 22.26652908], [69.20318604, 22.26625061], [69.2040329, 22.26625061], [69.20402527, 22.26597214], [69.20430756, 22.26597214], [69.20430756, 22.26569366], [69.2048645, 22.26569366], [69.2048645, 22.2654171], [69.20513916, 22.26542091], [69.20513916, 22.26514053], [69.20569611, 22.26514053], [69.20569611, 22.26485825], [69.20597076, 22.26485825], [69.20597076, 22.26458931], [69.20652771, 22.26458931], [69.20652771, 22.26431084], [69.20819092, 22.26431084], [69.20819092, 22.26403046], [69.20874786, 22.26403046], [69.20874786, 22.26374817], [69.20929718, 22.26374817], [69.20929718, 22.2634697], [69.21013641, 22.2634716], [69.21013641, 22.26319695], [69.21069336, 22.26320076], [69.21069336, 22.26292038], [69.21125031, 22.26292038], [69.21125031, 22.26263809], [69.21180725, 22.26263809], [69.21180725, 22.26235962], [69.2123642, 22.26236153], [69.2123642, 22.26208305], [69.21291351, 22.26208305], [69.21291351, 22.2618084], [69.21347046, 22.26180077], [69.21347046, 22.26152611], [69.21430206, 22.26152992], [69.21430206, 22.26124954], [69.21485901, 22.26124954], [69.21485901, 22.26097107], [69.2151413, 22.26097298], [69.2151413, 22.2606945], [69.21624756, 22.2606945], [69.21624756, 22.26041412], [69.21708679, 22.26041985], [69.21708679, 22.26013947], [69.2179184, 22.26013947], [69.2179184, 22.25986099], [69.21875, 22.25986099], [69.21875, 22.25958061], [69.2195816, 22.25958252], [69.2195816, 22.25930405], [69.2201767, 22.25930405], [69.22041321, 22.25930977], [69.22041321, 22.25918007], [69.22041321, 22.25902748], [69.22068787, 22.25902748], [69.2215271, 22.25902939], [69.2215271, 22.25875092], [69.22180176, 22.25875092], [69.22180176, 22.25846291], [69.22264099, 22.25847244], [69.22264099, 22.25819206], [69.2234726, 22.25819206], [69.2234726, 22.2579174], [69.22652435, 22.2579174], [69.22652435, 22.25819206], [69.2279129, 22.25819206], [69.2279129, 22.2579174], [69.23124695, 22.2579174], [69.23124695, 22.25819206], [69.23180389, 22.25819206], [69.23180389, 22.2579174], [69.2326355, 22.2579174], [69.2326355, 22.25819206], [69.23374939, 22.25819206], [69.23374939, 22.25847244], [69.23513794, 22.25846291], [69.23513794, 22.25875092], [69.23652649, 22.25875092], [69.23652649, 22.25902939], [69.23764038, 22.25902939], [69.23764038, 22.25930977], [69.23874664, 22.25930977], [69.23874664, 22.25986099], [69.23902893, 22.25986099], [69.23902893, 22.26013947], [69.23929596, 22.26013947], [69.23929596, 22.26041985], [69.23986053, 22.26041412], [69.23986053, 22.2606945], [69.24013519, 22.2606945], [69.24013519, 22.26097298], [69.24041748, 22.26097107], [69.24041748, 22.26152992], [69.24069214, 22.26152611], [69.24069214, 22.26208305], [69.24124908, 22.26208115], [69.24124908, 22.26263809], [69.24069214, 22.26263809], [69.24069214, 22.26292038], [69.24041748, 22.26292038], [69.24041748, 22.26320076], [69.24069214, 22.26320076], [69.24069214, 22.26374817], [69.24153137, 22.26374817], [69.24153137, 22.26458931], [69.24208069, 22.26458931], [69.24208069, 22.26485825], [69.24320221, 22.26485825], [69.24319458, 22.26458359], [69.2454071, 22.26458931], [69.24541473, 22.26485825], [69.24569702, 22.26485825], [69.24569702, 22.26514053], [69.24652863, 22.26514053], [69.24652863, 22.26431084], [69.24680328, 22.26431084], [69.24680328, 22.26374817], [69.2470932, 22.26374817], [69.24708557, 22.2634716], [69.24736023, 22.2634716], [69.24736023, 22.26319695], [69.24764252, 22.26320076], [69.24764252, 22.26292038], [69.24791718, 22.26292038], [69.24791718, 22.26263809], [69.24819183, 22.26263809], [69.24819183, 22.26235962], [69.24874878, 22.26236153], [69.24874878, 22.26208305], [69.24930573, 22.26208305], [69.24930573, 22.2618084], [69.24958038, 22.26180077], [69.24958038, 22.26152611], [69.24986267, 22.26152992], [69.24986267, 22.26097107], [69.25041962, 22.26097107], [69.25041962, 22.26124954], [69.25069427, 22.26124954], [69.25069427, 22.26208305], [69.25096893, 22.26208115], [69.25096893, 22.26292038], [69.25125122, 22.26292038], [69.25125122, 22.26320076], [69.25152588, 22.26320076], [69.25152588, 22.26403046], [69.25180817, 22.26402664], [69.25180817, 22.26486206], [69.25069427, 22.26486206], [69.25069427, 22.26458359], [69.25013733, 22.26458931], [69.25013733, 22.26431084], [69.24958038, 22.26431084], [69.24958038, 22.26542091], [69.24930573, 22.2654171], [69.24930573, 22.26597214], [69.24903107, 22.26597214], [69.24903107, 22.26708412], [69.24986267, 22.26708412], [69.24986267, 22.26680565], [69.25068665, 22.26680946], [69.25068665, 22.26652908], [69.25152588, 22.26652908], [69.25152588, 22.26680946], [69.25235748, 22.26680565], [69.25235748, 22.26708412], [69.25263977, 22.2670784], [69.25263977, 22.26736259], [69.25319672, 22.26736259], [69.25319672, 22.2676506], [69.25402832, 22.2676506], [69.25402832, 22.26791954], [69.25458527, 22.26791573], [69.25458527, 22.2681942], [69.25541687, 22.2681942], [69.25541687, 22.26847267], [69.25653076, 22.26847267], [69.25653076, 22.26875114], [69.25708008, 22.26875114], [69.25708008, 22.26902962], [69.25791931, 22.26902962], [69.25791931, 22.26875114], [69.2582016, 22.26875114], [69.2582016, 22.26902962], [69.26152802, 22.26902962], [69.26152802, 22.26875114], [69.26319122, 22.26875114], [69.26319122, 22.26902962], [69.26346588, 22.26902962], [69.26346588, 22.26931], [69.26319122, 22.26931], [69.26319122, 22.26986122], [69.26346588, 22.26986122], [69.26346588, 22.27013969], [69.26790619, 22.27013969], [69.26790619, 22.27042007], [69.26902771, 22.27042007], [69.26902771, 22.27013969], [69.26985931, 22.27013969], [69.26985931, 22.27042007], [69.27124786, 22.27041626], [69.27124786, 22.27069473], [69.27236176, 22.27069473], [69.27236176, 22.2709713], [69.27347565, 22.2709713], [69.27347565, 22.27069473], [69.27375031, 22.27069473], [69.27375031, 22.27041626], [69.27403259, 22.27042007], [69.27403259, 22.26902962], [69.27540588, 22.26902962], [69.27540588, 22.26931], [69.2756958, 22.26931], [69.2756958, 22.26986122], [69.27597046, 22.26986122], [69.27597046, 22.27042007], [69.2765274, 22.27041626], [69.2765274, 22.2709713], [69.27707672, 22.27096939], [69.27707672, 22.27124977], [69.27738953, 22.27124977], [69.2776413, 22.27124977], [69.2776413, 22.27153015], [69.27819824, 22.27152824], [69.27819824, 22.27180481], [69.27874756, 22.27180481], [69.27874756, 22.27152824], [69.2793045, 22.27152824], [69.2793045, 22.27180481], [69.28013611, 22.27180481], [69.28013611, 22.27152824], [69.2804184, 22.27153015], [69.2804184, 22.27124977], [69.28125, 22.27124977], [69.28125, 22.27153015], [69.2820816, 22.27152824], [69.2820816, 22.27180481], [69.28291321, 22.27180481], [69.28291321, 22.27208328], [69.28375244, 22.27208328], [69.28375244, 22.27236176], [69.28430176, 22.27235985], [69.28430939, 22.27264023], [69.28457642, 22.27264023], [69.28457642, 22.27292061], [69.2848587, 22.27292061], [69.2848587, 22.27375031], [69.28514099, 22.27375031], [69.28514099, 22.27403069], [69.28679657, 22.27403069], [69.28679657, 22.27431107], [69.28708649, 22.27430534], [69.28708649, 22.27458382], [69.2876358, 22.27458], [69.2876358, 22.27486038], [69.28930664, 22.27486038], [69.28930664, 22.27514076], [69.29013824, 22.27514076], [69.29013824, 22.27542114], [69.2904129, 22.27541542], [69.2904129, 22.27569389], [69.29096985, 22.27569389], [69.29096985, 22.27597237], [69.29125214, 22.27597046], [69.29125214, 22.27625084], [69.29152679, 22.27625084], [69.29152679, 22.27653122], [69.29180908, 22.27653122], [69.29180908, 22.27681923], [69.29207611, 22.27681923], [69.29207611, 22.27736092], [69.2923584, 22.27736092], [69.2923584, 22.27763748], [69.29264069, 22.27763748], [69.29264069, 22.27791977], [69.29319763, 22.27791595], [69.29319763, 22.27819443], [69.29347229, 22.27819443], [69.29347229, 22.2784729], [69.29374695, 22.27846909], [69.29374695, 22.27874756], [69.29402924, 22.27874756], [69.29402924, 22.27902985], [69.29431152, 22.27902985], [69.29431152, 22.27931023], [69.29460144, 22.27931023], [69.29460144, 22.27959251], [69.29486084, 22.27958298], [69.29486084, 22.27986145], [69.29514313, 22.27986145], [69.29514313, 22.28181267], [69.29486084, 22.28180504], [69.29486084, 22.28208351], [69.29458618, 22.28208351], [69.29458618, 22.28236389], [69.29374695, 22.28236389], [69.29374695, 22.28319359], [69.29347229, 22.28318977], [69.29347229, 22.28403091], [69.29319763, 22.2840271], [69.29319763, 22.28458214], [69.29264069, 22.28458023], [69.29264069, 22.28541946], [69.2923584, 22.28541756], [69.2923584, 22.28569412], [69.29208374, 22.28569412], [69.29208374, 22.2859726], [69.2923584, 22.28597069], [69.2923584, 22.28625107], [69.29347229, 22.28625107], [69.29347229, 22.28597069], [69.29486084, 22.2859726], [69.29486084, 22.28569412], [69.2951355, 22.28569412], [69.2951355, 22.28513908], [69.29541779, 22.28514099], [69.29541779, 22.28430939], [69.29514313, 22.28430939], [69.29514313, 22.28375053], [69.29541779, 22.28375053], [69.29541779, 22.28347015], [69.29624939, 22.28347015], [69.29624939, 22.28403091], [69.29680634, 22.2840271], [69.29680634, 22.28458214], [69.29708099, 22.28458214], [69.29708099, 22.28569412], [69.29680634, 22.28569031], [69.29680634, 22.28625107], [69.29708099, 22.28625107], [69.29708099, 22.28652954], [69.29736328, 22.28652763], [69.29736328, 22.28708267], [69.29763794, 22.28708076], [69.29763794, 22.28736115], [69.29792023, 22.28736115], [69.29792023, 22.28763962], [69.29957581, 22.28763962], [69.29957581, 22.28792], [69.30097198, 22.28792], [69.30097198, 22.28763962], [69.3034668, 22.28763962], [69.3034668, 22.28792], [69.30374908, 22.28792], [69.30374908, 22.28763962], [69.30625153, 22.28763962], [69.30625153, 22.28736115], [69.30708313, 22.28736115], [69.30708313, 22.28708076], [69.30791473, 22.28708267], [69.30791473, 22.2868042], [69.30819702, 22.28680992], [69.30819702, 22.28652954], [69.30874634, 22.28652954], [69.30874634, 22.28680992], [69.30930328, 22.2868042], [69.30930328, 22.28708267], [69.31014252, 22.28708076], [69.31014252, 22.28736115], [69.31041718, 22.28736115], [69.31041718, 22.28763962], [69.31153107, 22.28763962], [69.31153107, 22.28736115], [69.31234741, 22.28736115], [69.31234741, 22.28763962], [69.31291962, 22.28763962], [69.31291962, 22.28792], [69.31319427, 22.28791428], [69.31319427, 22.28819466], [69.31375122, 22.28819466], [69.31375122, 22.28986168], [69.31318665, 22.28985977], [69.31318665, 22.29014015], [69.31291962, 22.29014015], [69.31291962, 22.29042053], [69.31263733, 22.29041862], [69.31263733, 22.29097176], [69.31234741, 22.29096985], [69.31234741, 22.29124832], [69.31208038, 22.29124832], [69.31208038, 22.29182243], [69.31375122, 22.29182243], [69.31375122, 22.29153061], [69.31402588, 22.29153061], [69.31402588, 22.29070091], [69.31541443, 22.29069519], [69.31541443, 22.29097176], [69.31652832, 22.29097176], [69.31652832, 22.29069519], [69.31847382, 22.29069519], [69.31847382, 22.29097176], [69.31874847, 22.29096985], [69.31874847, 22.29124832], [69.31986237, 22.29124832], [69.31986237, 22.29153061], [69.32013702, 22.29153061], [69.32013702, 22.29182243], [69.32041931, 22.29180527], [69.32041931, 22.29208374], [69.32068634, 22.29207993], [69.32068634, 22.2923584], [69.32125092, 22.2923584], [69.32125092, 22.29264069], [69.32154083, 22.29264069], [69.32154083, 22.29291916], [69.32180786, 22.29291725], [69.32180786, 22.29319382], [69.32208252, 22.29319382], [69.32208252, 22.29347229], [69.32235718, 22.29346848], [69.32235718, 22.29375076], [69.32263947, 22.29375076], [69.32263947, 22.29403114], [69.32290649, 22.29403114], [69.32290649, 22.29430962], [69.32347107, 22.2943058], [69.32347107, 22.29458237], [69.32402802, 22.29457092], [69.32402802, 22.29486275], [69.32428741, 22.29486275], [69.32428741, 22.29514122], [69.32457733, 22.29514122], [69.32457733, 22.29541969], [69.32485962, 22.29541969], [69.32485962, 22.29652977], [69.32458496, 22.29652786], [69.32458496, 22.29736137], [69.32430267, 22.29736137], [69.32430267, 22.29847145], [69.32457733, 22.29846954], [69.32457733, 22.29931068], [69.32541656, 22.29930305], [69.32541656, 22.29958344], [69.32569122, 22.29957962], [69.32569122, 22.30042076], [69.32597351, 22.30041695], [69.32597351, 22.30097198], [69.32624817, 22.30097008], [69.32624817, 22.30153084], [69.32541656, 22.30153084], [69.32541656, 22.30181122], [69.32430267, 22.3018055], [69.32430267, 22.30208397], [69.32402802, 22.30208015], [69.32402802, 22.30264091], [69.32375336, 22.3026371], [69.32375336, 22.30347252], [69.32402802, 22.30347061], [69.32402802, 22.30376053], [69.32428741, 22.30376053], [69.32428741, 22.30402946], [69.32596588, 22.30402946], [69.32596588, 22.30236053], [69.32624817, 22.30236053], [69.32624817, 22.30208015], [69.32653046, 22.30208015], [69.32653046, 22.30236053], [69.32681274, 22.30236053], [69.32681274, 22.30264091], [69.32707977, 22.30264091], [69.32707977, 22.30402946], [69.3290329, 22.30402946], [69.3290329, 22.30376053], [69.32985687, 22.30376053], [69.32985687, 22.30319023], [69.33013916, 22.30319405], [69.33013916, 22.30291939], [69.33125305, 22.30291939], [69.33125305, 22.30319405], [69.33208466, 22.30319405], [69.33208466, 22.30347252], [69.3326416, 22.30347061], [69.3326416, 22.30376053], [69.33319092, 22.30376053], [69.33319092, 22.30402946], [69.33348083, 22.30402946], [69.33348083, 22.30430984], [69.33403015, 22.30430794], [69.33403015, 22.3045826], [69.33429718, 22.30458069], [69.33429718, 22.30485916], [69.3345871, 22.30485916], [69.3345871, 22.30513763], [69.33486176, 22.30513763], [69.33486176, 22.30569458], [69.33513641, 22.30569458], [69.33513641, 22.30680466], [69.3354187, 22.30680466], [69.3354187, 22.30708313], [69.33569336, 22.30708313], [69.33569336, 22.3073616], [69.33598328, 22.3073616], [69.33598328, 22.30820274], [69.33625031, 22.30819511], [69.33625031, 22.30958366], [69.33651733, 22.30957031], [69.33651733, 22.31014061], [69.33680725, 22.3101387], [69.33680725, 22.31097221], [69.33708191, 22.31097031], [69.33708191, 22.31125069], [69.33735657, 22.31125069], [69.33735657, 22.31180954], [69.33763885, 22.31180573], [69.33763885, 22.31597137], [69.33791351, 22.31597137], [69.33791351, 22.31680489], [69.33763885, 22.31680107], [69.33763885, 22.3176403], [69.33735657, 22.3176403], [69.33735657, 22.31819916], [69.33708191, 22.31819534], [69.33708191, 22.31847191], [69.33680725, 22.31847191], [69.33680725, 22.31874847], [69.33651733, 22.31874084], [69.33651733, 22.31903076], [69.33625031, 22.31902885], [69.33625031, 22.31958389], [69.33598328, 22.31957817], [69.33598328, 22.32014084], [69.33569336, 22.32014084], [69.33569336, 22.32041931], [69.3354187, 22.32041931], [69.3354187, 22.32125282], [69.33513641, 22.32125282], [69.33513641, 22.32152939], [69.33319092, 22.32152939], [69.33319092, 22.32125282], [69.33235931, 22.32125282], [69.33235931, 22.32152939], [69.33207703, 22.32152939], [69.33207703, 22.32263947], [69.33180237, 22.32263947], [69.33180237, 22.3231945], [69.33152771, 22.3231945], [69.33152771, 22.32347107], [69.33097076, 22.32347107], [69.33097076, 22.3243103], [69.33071136, 22.3243103], [69.33071136, 22.32542038], [69.33097076, 22.32542038], [69.33097076, 22.32570076], [69.33125305, 22.32570076], [69.33125305, 22.32625008], [69.33152771, 22.32625008], [69.33152771, 22.32653046], [69.33180237, 22.32653046], [69.33180237, 22.32681084], [69.33097076, 22.32680511], [69.33097076, 22.32708359], [69.33071136, 22.32707977], [69.33071136, 22.32764053], [69.33041382, 22.32763863], [69.33041382, 22.32819366], [69.33069611, 22.32819366], [69.33069611, 22.32791519], [69.33097076, 22.32791519], [69.33097076, 22.32819366], [69.33208466, 22.32819366], [69.33208466, 22.32847214], [69.33291626, 22.32847023], [69.33291626, 22.32875061], [69.33348083, 22.32875061], [69.33348083, 22.32930946], [69.33374786, 22.32930946], [69.33374786, 22.32986069], [69.33403015, 22.32986069], [69.33403015, 22.33014107], [69.33429718, 22.33014107], [69.33429718, 22.33041954], [69.33569336, 22.33041954], [69.33569336, 22.33014107], [69.33625031, 22.33014107], [69.33625031, 22.32986069], [69.33875275, 22.32986069], [69.33875275, 22.33014107], [69.3390274, 22.33014107], [69.3390274, 22.33041954], [69.3401413, 22.33041954], [69.3401413, 22.33014107], [69.34041595, 22.33014107], [69.34041595, 22.32986069], [69.3409729, 22.32986069], [69.3409729, 22.32958031], [69.34152985, 22.32958412], [69.34152985, 22.32930565], [69.34179688, 22.32930946], [69.34179688, 22.32903099], [69.34236145, 22.32903099], [69.34236145, 22.32875061], [69.34265137, 22.32875061], [69.34263611, 22.32847214], [69.34402466, 22.32847214], [69.34402466, 22.32819366], [69.34541321, 22.32819366], [69.34541321, 22.32791519], [69.34680176, 22.32793045], [69.34680176, 22.32764053], [69.34819794, 22.32764053], [69.34819794, 22.32736015], [69.34958649, 22.32736015], [69.34958649, 22.32707977], [69.35069275, 22.32708359], [69.35069275, 22.32680511], [69.35320282, 22.32681084], [69.35320282, 22.32653046], [69.35375214, 22.32653046], [69.35375214, 22.32625008], [69.35402679, 22.32625008], [69.35402679, 22.3259697], [69.35430908, 22.3259716], [69.35430908, 22.32541656], [69.35459137, 22.32542038], [69.35459137, 22.32487106], [69.35542297, 22.32487106], [69.35542297, 22.32458115], [69.35624695, 22.32458305], [69.35624695, 22.32430649], [69.35708618, 22.32430077], [69.35708618, 22.32402802], [69.35791779, 22.32402992], [69.35791779, 22.32374954], [69.35874939, 22.32374954], [69.35874939, 22.32347107], [69.35930634, 22.32347107], [69.35930634, 22.3231945], [69.36013794, 22.3231945], [69.36013794, 22.32291603], [69.36096954, 22.32291985], [69.36096954, 22.32263947], [69.36180878, 22.32263947], [69.36180878, 22.3223629], [69.36264038, 22.3223629], [69.36264038, 22.32208252], [69.36653137, 22.32208252], [69.36653137, 22.32180595], [69.36708069, 22.32180595], [69.36708069, 22.32152748], [69.36736298, 22.32152939], [69.36736298, 22.31957817], [69.36708069, 22.31958389], [69.36708069, 22.31902885], [69.36682129, 22.31903076], [69.36682129, 22.31874084], [69.36653137, 22.31874847], [69.36653137, 22.31847191], [69.36624908, 22.31847191], [69.36624908, 22.31819534], [69.3659668, 22.31819916], [69.3659668, 22.31792068], [69.36541748, 22.31792068], [69.36541748, 22.3176403], [69.36429596, 22.3176403], [69.36429596, 22.31680107], [69.36458588, 22.31680489], [69.36458588, 22.31652641], [69.36680603, 22.31652641], [69.36680603, 22.31680489], [69.36763763, 22.31680489], [69.36763763, 22.31708336], [69.36875153, 22.31708336], [69.36875153, 22.31736183], [69.3704071, 22.31735992], [69.3704071, 22.3176403], [69.37097168, 22.3176403], [69.37097168, 22.31792068], [69.3720932, 22.31792068], [69.3720932, 22.31819916], [69.37291718, 22.31819534], [69.37291718, 22.31847191], [69.37347412, 22.31847191], [69.37347412, 22.31874847], [69.37403107, 22.31874084], [69.37403107, 22.31903076], [69.37458038, 22.31903076], [69.37458038, 22.31930923], [69.37513733, 22.31930542], [69.37513733, 22.31958389], [69.37568665, 22.31957817], [69.37568665, 22.31985855], [69.37625122, 22.31985855], [69.37625122, 22.32097244], [69.37596893, 22.32097244], [69.37596893, 22.32125282], [69.37569427, 22.32125282], [69.37569427, 22.32180595], [69.37596893, 22.32180595], [69.37596893, 22.32208252], [69.37735748, 22.32208252], [69.37735748, 22.32180595], [69.37902832, 22.32180595], [69.37902832, 22.32208252], [69.38041687, 22.32208252], [69.38041687, 22.3223629], [69.38318634, 22.3223629], [69.38318634, 22.32208252], [69.38402557, 22.32208252], [69.38402557, 22.32180595], [69.38513947, 22.32180595], [69.38513947, 22.32152748], [69.38540649, 22.32152939], [69.38540649, 22.32097244], [69.38569641, 22.32097244], [69.38569641, 22.31902885], [69.38597107, 22.31903076], [69.38597107, 22.31874084], [69.38625336, 22.31874847], [69.38625336, 22.31847191], [69.38680267, 22.31846809], [69.38680267, 22.31903076], [69.38707733, 22.31903076], [69.38707733, 22.31930923], [69.38735962, 22.31930923], [69.38735962, 22.31985855], [69.38762665, 22.31985855], [69.38762665, 22.32014084], [69.38791656, 22.32014084], [69.38791656, 22.32041931], [69.38819122, 22.3204174], [69.38819122, 22.32069397], [69.38847351, 22.32069397], [69.38847351, 22.32097244], [69.38903046, 22.32097244], [69.38903046, 22.32125282], [69.38986206, 22.32125282], [69.38986206, 22.32152939], [69.39013672, 22.32152939], [69.39013672, 22.32125282], [69.39070129, 22.32125282], [69.39069366, 22.32097244], [69.39680481, 22.32097244], [69.39680481, 22.32069397], [69.3979187, 22.32069397], [69.3979187, 22.3204174], [69.39903259, 22.32041931], [69.39903259, 22.32014084], [69.40013885, 22.32014084], [69.40013885, 22.31985855], [69.40040588, 22.31985855], [69.40040588, 22.31957817], [69.40097046, 22.31958389], [69.40097046, 22.31902885], [69.40125275, 22.31903076], [69.40125275, 22.31846809], [69.4015274, 22.31847191], [69.4015274, 22.31791878], [69.40180206, 22.31792068], [69.40180206, 22.31735992], [69.40208435, 22.31736183], [69.40208435, 22.31680489], [69.40235901, 22.31680489], [69.40235901, 22.31624985], [69.4026413, 22.31624985], [69.4026413, 22.31596947], [69.40319824, 22.31596947], [69.40319824, 22.31624985], [69.40930176, 22.31624985], [69.40930176, 22.31596947], [69.4173584, 22.31597137], [69.4173584, 22.31569481], [69.41930389, 22.31569481], [69.41930389, 22.31597137], [69.4201355, 22.31597137], [69.4201355, 22.31624985], [69.42124939, 22.31624985], [69.42124939, 22.31653023], [69.42263794, 22.31652641], [69.42263794, 22.31680489], [69.42346954, 22.31680489], [69.42346954, 22.31708336], [69.42402649, 22.31708336], [69.42402649, 22.31736183], [69.42457581, 22.31735992], [69.42457581, 22.3176403], [69.42485809, 22.3176403], [69.42485809, 22.31792068], [69.42542267, 22.31792068], [69.42542267, 22.31819916], [69.42597198, 22.31819534], [69.42597198, 22.31847191], [69.42652893, 22.31847191], [69.42652893, 22.31874847], [69.42679596, 22.31874084], [69.42679596, 22.31903076], [69.42764282, 22.31903076], [69.42764282, 22.31930923], [69.42819214, 22.31930542], [69.42819214, 22.31958389], [69.42874908, 22.31957817], [69.42874908, 22.31985855], [69.42930603, 22.31985855], [69.42930603, 22.32041931], [69.42958069, 22.3204174], [69.42958069, 22.32069397], [69.42986298, 22.32069397], [69.42986298, 22.32097244], [69.43041992, 22.32097244], [69.43041992, 22.32069397], [69.43069458, 22.32069397], [69.43069458, 22.32014084], [69.43125153, 22.32014084], [69.43125153, 22.32041931], [69.43180847, 22.3204174], [69.43180847, 22.32069397], [69.43208313, 22.32069397], [69.43208313, 22.32097244], [69.43235779, 22.32097244], [69.43235779, 22.32125282], [69.43319702, 22.32125282], [69.43319702, 22.32152939], [69.43402863, 22.32152748], [69.43402863, 22.32180595], [69.43486023, 22.32180595], [69.43486023, 22.32208252], [69.43567657, 22.32208252], [69.43567657, 22.3223629], [69.43596649, 22.3223629], [69.43596649, 22.32263947], [69.43653107, 22.32263947], [69.43653107, 22.32291985], [69.43708038, 22.32291603], [69.43708038, 22.3231945], [69.43736267, 22.3231926], [69.43736267, 22.32402992], [69.43708038, 22.32402802], [69.43708038, 22.32458305], [69.43736267, 22.32458115], [69.43736267, 22.32514], [69.43763733, 22.32514], [69.43763733, 22.32542038], [69.43791962, 22.32542038], [69.43791962, 22.32570076], [69.43846893, 22.32569313], [69.43846893, 22.3259716], [69.43873596, 22.3259697], [69.43873596, 22.32625008], [69.43902588, 22.32625008], [69.43902588, 22.32653046], [69.43930817, 22.32653046], [69.43930817, 22.32681084], [69.43958282, 22.32680511], [69.43958282, 22.32708359], [69.43985748, 22.32707977], [69.43985748, 22.32736015], [69.44013977, 22.32736015], [69.44013977, 22.32764053], [69.4404068, 22.32764053], [69.4404068, 22.32793045], [69.44069672, 22.32791519], [69.44069672, 22.32819366], [69.4404068, 22.32818985], [69.4404068, 22.32930946], [69.44152832, 22.32930946], [69.44152832, 22.32986069], [69.44181061, 22.32986069], [69.44181061, 22.33041954], [69.44235992, 22.33041573], [69.44235992, 22.3306942], [69.44291687, 22.3306942], [69.44291687, 22.33097267], [69.44625092, 22.33097076], [69.44625092, 22.33125114], [69.44735718, 22.33125114], [69.44735718, 22.33152962], [69.44875336, 22.33152962], [69.44875336, 22.33180809], [69.44930267, 22.33180618], [69.44930267, 22.33208275], [69.44985962, 22.33208084], [69.44985962, 22.33235931], [69.45041656, 22.33235931], [69.45041656, 22.3326416], [69.45124817, 22.3326416], [69.45124817, 22.33292007], [69.45153046, 22.33291626], [69.45153046, 22.33319473], [69.45207977, 22.33319473], [69.45207977, 22.33346939], [69.45236206, 22.33346939], [69.45236206, 22.33403015], [69.45263672, 22.33402824], [69.45263672, 22.33458328], [69.45291901, 22.33458328], [69.45291901, 22.33486176], [69.45318604, 22.33486176], [69.45318604, 22.33514023], [69.45375061, 22.33514023], [69.45375061, 22.33542061], [69.45430756, 22.33542061], [69.45430756, 22.3357029], [69.45485687, 22.3357029], [69.45485687, 22.33542061], [69.45513916, 22.33542061], [69.45513916, 22.33514023], [69.45540619, 22.33514023], [69.45540619, 22.33486176], [69.45569611, 22.33486176], [69.45569611, 22.33458328], [69.45597076, 22.33458328], [69.45597076, 22.33430481], [69.45625305, 22.33430481], [69.45625305, 22.33402824], [69.45652771, 22.33403015], [69.45652771, 22.33373833], [69.45680237, 22.33375168], [69.45680237, 22.33346939], [69.45708466, 22.33346939], [69.45708466, 22.33319473], [69.45735931, 22.33319473], [69.45735931, 22.33291626], [69.4576416, 22.33292007], [69.4576416, 22.33235931], [69.45847321, 22.33235931], [69.45847321, 22.33292007], [69.45903015, 22.33291626], [69.45903015, 22.33319473], [69.45930481, 22.33319473], [69.45930481, 22.33346939], [69.4595871, 22.33346939], [69.4595871, 22.33375168], [69.4604187, 22.33375168], [69.4604187, 22.33346939], [69.46069336, 22.33346939], [69.46069336, 22.33319473], [69.46097565, 22.33319473], [69.46097565, 22.33291626], [69.46125031, 22.33292007], [69.46125031, 22.33208084], [69.46152496, 22.33208275], [69.46152496, 22.33152962], [69.46180725, 22.33152962], [69.46180725, 22.33125114], [69.46235657, 22.33125114], [69.46235657, 22.33097076], [69.4631958, 22.33097267], [69.4631958, 22.3306942], [69.46458435, 22.3306942], [69.46458435, 22.33041573], [69.4651413, 22.33041954], [69.4651413, 22.33014107], [69.46736145, 22.33014107], [69.46736145, 22.33041954], [69.4679184, 22.33041573], [69.4679184, 22.3306942], [69.46819305, 22.3306942], [69.46819305, 22.33097267], [69.46875, 22.33097076], [69.46875, 22.33125114], [69.46901703, 22.33125114], [69.46901703, 22.33152962], [69.46930695, 22.33152962], [69.46930695, 22.33180809], [69.4695816, 22.33180618], [69.4695816, 22.33208275], [69.46985626, 22.33208084], [69.46985626, 22.33235931], [69.47013855, 22.33235931], [69.47013855, 22.3326416], [69.47041321, 22.3326416], [69.47041321, 22.33292007], [69.4734726, 22.33291626], [69.4734726, 22.33319473], [69.47486115, 22.33319473], [69.47486115, 22.33346939], [69.47597504, 22.33346939], [69.47597504, 22.33375168], [69.47680664, 22.33373833], [69.47680664, 22.33403015], [69.4770813, 22.33402824], [69.4770813, 22.33458328], [69.47735596, 22.33457947], [69.47735596, 22.33514023], [69.47792053, 22.33514023], [69.47792053, 22.33486176], [69.47875214, 22.33486176], [69.47875214, 22.33458328], [69.47902679, 22.33458328], [69.47902679, 22.33430481], [69.47958374, 22.33430481], [69.47958374, 22.33402824], [69.48041534, 22.33402824], [69.48041534, 22.33430481], [69.48069763, 22.33430481], [69.48069763, 22.33458328], [69.48208618, 22.33458328], [69.48208618, 22.33486176], [69.48264313, 22.33486176], [69.48264313, 22.33514023], [69.48319244, 22.33514023], [69.48319244, 22.33542061], [69.48401642, 22.33542061], [69.48401642, 22.3357029], [69.48458099, 22.33569527], [69.48458099, 22.33597374], [69.48513794, 22.33597183], [69.48513794, 22.33625031], [69.48542023, 22.33625031], [69.48542023, 22.33653069], [69.48568726, 22.33653069], [69.48568726, 22.33681107], [69.48596954, 22.33680534], [69.48596954, 22.33708382], [69.48625183, 22.33708191], [69.48625183, 22.33736038], [69.48680878, 22.33736038], [69.48680878, 22.33764076], [69.48764038, 22.33764076], [69.48764038, 22.33792114], [69.48791504, 22.33791733], [69.48791504, 22.33819389], [69.48819733, 22.33819389], [69.48819733, 22.33791733], [69.48847198, 22.33791733], [69.48847198, 22.33819389], [69.48874664, 22.33819389], [69.48874664, 22.33864975], [69.48874664, 22.33987045], [69.48847198, 22.33987045], [69.48847198, 22.34263992], [69.48819733, 22.34263992], [69.48819733, 22.3476429], [69.48791504, 22.34763908], [69.48791504, 22.3484726], [69.48819733, 22.3484726], [69.48819733, 22.34875107], [69.48847198, 22.34875107], [69.48847198, 22.34902954], [69.48874664, 22.34902954], [69.48874664, 22.34930992], [69.48902893, 22.34930992], [69.48902893, 22.35181046], [69.48929596, 22.35181046], [69.48929596, 22.35292053], [69.48958588, 22.35292053], [69.48958588, 22.35403061], [69.48986053, 22.3540287], [69.48986053, 22.35486031], [69.49013519, 22.35486031], [69.49013519, 22.35569382], [69.49041748, 22.35569382], [69.49041748, 22.35597229], [69.49069214, 22.35597038], [69.49069214, 22.35625076], [69.4909668, 22.35625076], [69.4909668, 22.35653114], [69.49124908, 22.35653114], [69.49124908, 22.35680962], [69.49180603, 22.3568058], [69.49180603, 22.35708237], [69.49208069, 22.35708046], [69.49208069, 22.35764122], [69.49236298, 22.35763741], [69.49236298, 22.35819435], [69.49263763, 22.35819054], [69.49263763, 22.35902977], [69.49318695, 22.35902977], [69.49318695, 22.35931015], [69.49346924, 22.35930634], [69.49346924, 22.3595829], [69.49375153, 22.35957909], [69.49375153, 22.36014175], [69.49402618, 22.36014175], [69.49402618, 22.36042023], [69.49430847, 22.36041641], [69.49430847, 22.36069489], [69.49485779, 22.36069489], [69.49485779, 22.36096954], [69.49514008, 22.36096954], [69.49514008, 22.36125183], [69.4954071, 22.36125183], [69.4954071, 22.3615303], [69.49569702, 22.3615284], [69.49569702, 22.36208344], [69.49595642, 22.36207962], [69.49595642, 22.36264038], [69.49624634, 22.36264038], [69.49624634, 22.36292076], [69.49652863, 22.36291695], [69.49652863, 22.36319351], [69.49680328, 22.3631897], [69.49680328, 22.36375046], [69.4970932, 22.36375046], [69.4970932, 22.36404037], [69.49736023, 22.36404037], [69.49736023, 22.36431122], [69.49764252, 22.3643055], [69.49764252, 22.36458206], [69.49791718, 22.36458015], [69.49791718, 22.36486053], [69.49819183, 22.36486053], [69.49819183, 22.36514091], [69.49846649, 22.36514091], [69.49846649, 22.36541939], [69.49874878, 22.36541748], [69.49874878, 22.36569595], [69.49903107, 22.36569595], [69.49903107, 22.36597252], [69.49958038, 22.36597061], [69.49958038, 22.36625099], [69.49986267, 22.36625099], [69.49986267, 22.36652946], [69.50041962, 22.36652946], [69.50041962, 22.36680984], [69.50069427, 22.36680412], [69.50069427, 22.3670826], [69.50152588, 22.36708069], [69.50152588, 22.36736107], [69.50235748, 22.36736107], [69.50235748, 22.36763954], [69.5029068, 22.36763954], [69.5029068, 22.36791992], [69.50375366, 22.3679142], [69.50375366, 22.36819458], [69.50514221, 22.36819458], [69.50514221, 22.36847305], [69.50596619, 22.36847115], [69.50596619, 22.36874962], [69.50708008, 22.36874962], [69.50708008, 22.36903], [69.50763702, 22.36902618], [69.50763702, 22.36930466], [69.50819397, 22.36930466], [69.50819397, 22.36958313], [69.50875092, 22.36958313], [69.50875092, 22.3698616], [69.50930786, 22.36985016], [69.50930786, 22.37013817], [69.50985718, 22.37013817], [69.50985718, 22.37042046], [69.51040649, 22.37042046], [69.51040649, 22.37070084], [69.51069641, 22.37069511], [69.51069641, 22.37097168], [69.51125336, 22.37096977], [69.51125336, 22.37124825], [69.51152802, 22.37124825], [69.51152802, 22.37153053], [69.51207733, 22.37153053], [69.51207733, 22.37181091], [69.51235962, 22.37180519], [69.51235962, 22.37208366], [69.51291656, 22.37207985], [69.51291656, 22.37235832], [69.51319122, 22.37235832], [69.51319122, 22.37264061], [69.51374817, 22.37264061], [69.51374817, 22.37291908], [69.51403046, 22.37291718], [69.51403046, 22.37347221], [69.51430511, 22.37347221], [69.51430511, 22.37375069], [69.51457977, 22.37375069], [69.51457977, 22.37402916], [69.51486206, 22.37402916], [69.51486206, 22.37430954], [69.51541901, 22.37430573], [69.51541901, 22.3745842], [69.51597595, 22.37458038], [69.51597595, 22.37486267], [69.51625061, 22.37486267], [69.51625061, 22.37514114], [69.5165329, 22.37514114], [69.5165329, 22.37541962], [69.51680756, 22.3754158], [69.51680756, 22.37569427], [69.51708984, 22.37569046], [69.51708984, 22.37598038], [69.51735687, 22.37598038], [69.51735687, 22.37625122], [69.51763916, 22.37625122], [69.51763916, 22.37652969], [69.51790619, 22.37652969], [69.51790619, 22.37681007], [69.51819611, 22.37680626], [69.51819611, 22.37708282], [69.51847076, 22.37708282], [69.51847076, 22.3773613], [69.51875305, 22.37735939], [69.51875305, 22.37792015], [69.51902771, 22.37791634], [69.51902771, 22.37819481], [69.51930237, 22.37819481], [69.51930237, 22.37847137], [69.51957703, 22.37846947], [69.51957703, 22.37874985], [69.51985931, 22.37874985], [69.51985931, 22.37903976], [69.5201416, 22.37902832], [69.5201416, 22.37930489], [69.52124786, 22.37930107], [69.52124786, 22.3801403], [69.52153015, 22.3801403], [69.52153015, 22.38070107], [69.52180481, 22.38069534], [69.52180481, 22.38208389], [69.5220871, 22.38208008], [69.5220871, 22.38236046], [69.52236176, 22.38236046], [69.52236176, 22.38292122], [69.52263641, 22.3829155], [69.52263641, 22.38347244], [69.5229187, 22.38347244], [69.5229187, 22.38458252], [69.52319336, 22.38458061], [69.52319336, 22.38485909], [69.52347565, 22.38485909], [69.52347565, 22.3856945], [69.52375031, 22.3856945], [69.52375031, 22.38736153], [69.52347565, 22.38736153], [69.52348328, 22.38875008], [69.52319336, 22.38875008], [69.52319336, 22.38903046], [69.5229187, 22.38903046], [69.5229187, 22.38931274], [69.52263641, 22.38930511], [69.52263641, 22.38958359], [69.52236176, 22.38958359], [69.52236176, 22.38986206], [69.5220871, 22.38986015], [69.5220871, 22.39014053], [69.52179718, 22.39014053], [69.52179718, 22.39042091], [69.52153015, 22.3904171], [69.52153015, 22.39069366], [69.52124786, 22.39068985], [69.52124786, 22.39097977], [69.52097321, 22.39097977], [69.52097321, 22.39125061], [69.52069092, 22.39125061], [69.52069092, 22.39153099], [69.52041626, 22.39153099], [69.52041626, 22.39180946], [69.5201416, 22.39180565], [69.5201416, 22.39208412], [69.51902771, 22.39208031], [69.51902771, 22.39236069], [69.51847076, 22.39236069], [69.51847076, 22.39264107], [69.51819611, 22.39264107], [69.51819611, 22.39291954], [69.51791382, 22.39291763], [69.51791382, 22.3931942], [69.51763916, 22.3931942], [69.51763916, 22.39347267], [69.51735687, 22.39347076], [69.51735687, 22.39375114], [69.51680756, 22.39375114], [69.51680756, 22.39431], [69.51652527, 22.39430428], [69.51652527, 22.39458275], [69.51625061, 22.39458084], [69.51625061, 22.39513969], [69.51597595, 22.39513969], [69.51597595, 22.39958382], [69.51569366, 22.39958382], [69.51569366, 22.40486145], [69.51597595, 22.40485954], [69.51597595, 22.4054203], [69.51568604, 22.4054203], [69.51568604, 22.40570068], [69.51625061, 22.40570068], [69.51625061, 22.40625], [69.5165329, 22.40625], [69.5165329, 22.40681076], [69.51680756, 22.40680695], [69.51680756, 22.40736198], [69.51708984, 22.40736008], [69.51708984, 22.40792084], [69.5173645, 22.40791512], [69.5173645, 22.40847206], [69.51763916, 22.40847206], [69.51763916, 22.40902519], [69.51791382, 22.40902519], [69.51791382, 22.4109726], [69.51763916, 22.41097069], [69.51763916, 22.41152954], [69.51735687, 22.41152954], [69.51735687, 22.41208839], [69.51708221, 22.41208267], [69.51708984, 22.41263771], [69.51680756, 22.41263771], [69.51680756, 22.41292191], [69.51652527, 22.41291618], [69.51652527, 22.41347313], [69.51625061, 22.41346931], [69.51625061, 22.41403008], [69.51597595, 22.41402817], [69.51597595, 22.41458321], [69.51569366, 22.41458321], [69.51569366, 22.41486168], [69.51541901, 22.41486168], [69.51541901, 22.41597366], [69.51513672, 22.41597176], [69.51513672, 22.4168129], [69.51457977, 22.41680527], [69.51457977, 22.41708374], [69.51403046, 22.41708183], [69.51403046, 22.41736031], [69.51152802, 22.41736031], [69.51152802, 22.41764069], [69.51095581, 22.41764069], [69.51095581, 22.41792107], [69.51069641, 22.41791725], [69.51069641, 22.41819382], [69.51041412, 22.41819382], [69.51041412, 22.41847229], [69.51013947, 22.41847038], [69.51013947, 22.41903114], [69.50986481, 22.41902733], [69.50986481, 22.41958237], [69.51013947, 22.41958046], [69.51013947, 22.42041969], [69.50986481, 22.42041588], [69.50986481, 22.42069435], [69.50958252, 22.42069435], [69.50958252, 22.42097282], [69.50930786, 22.42097282], [69.50930786, 22.42236137], [69.50708008, 22.42236137], [69.50708008, 22.4220829], [69.50653076, 22.4220829], [69.50653076, 22.42236137], [69.50624847, 22.42235947], [69.50624847, 22.42263985], [69.50541687, 22.42263985], [69.50541687, 22.42292023], [69.50514221, 22.42291641], [69.50514221, 22.42347145], [69.50485992, 22.42346954], [69.50485992, 22.42374992], [69.50402832, 22.42374992], [69.50402832, 22.42432022], [69.50347137, 22.42430496], [69.50347137, 22.42458344], [69.50319672, 22.42457962], [69.50319672, 22.42514038], [69.50291443, 22.42514038], [69.5029068, 22.4256897], [69.50263977, 22.42569923], [69.50263977, 22.42624855], [69.50235748, 22.42624855], [69.50235748, 22.42680931], [69.50209045, 22.42680931], [69.50209045, 22.4287529], [69.50180817, 22.42874908], [69.50180817, 22.4295826], [69.50152588, 22.4295826], [69.50152588, 22.43153], [69.50125122, 22.43152809], [69.50125122, 22.43180466], [69.50069427, 22.43180466], [69.50069427, 22.43208313], [69.50041962, 22.43208313], [69.50041962, 22.4323616], [69.50013733, 22.4323597], [69.50013733, 22.43264008], [69.49986267, 22.43264008], [69.49986267, 22.43292046], [69.49958038, 22.43291664], [69.49958038, 22.43319321], [69.49930573, 22.43319321], [69.49930573, 22.43347168], [69.49901581, 22.43346977], [69.49901581, 22.43375015], [69.49874878, 22.43375015], [69.49874878, 22.43403053], [69.49846649, 22.43403053], [69.49846649, 22.43514061], [69.49819183, 22.4351387], [69.49819183, 22.43569374], [69.49874878, 22.43569374], [69.49874878, 22.43541527], [69.49931335, 22.43542099], [69.49931335, 22.43514061], [69.49958038, 22.43514061], [69.49958038, 22.43486023], [69.49986267, 22.43486023], [69.49986267, 22.43457985], [69.50041962, 22.43458366], [69.50041962, 22.43430519], [69.50096893, 22.43431091], [69.50096893, 22.43403053], [69.50125122, 22.43403053], [69.50125122, 22.43375015], [69.50209045, 22.43375015], [69.50208282, 22.43347168], [69.50235748, 22.43347168], [69.50235748, 22.43319321], [69.50263977, 22.43319321], [69.50263977, 22.4323616], [69.50291443, 22.4323616], [69.50291443, 22.43208313], [69.50319672, 22.43208313], [69.50319672, 22.42986107], [69.50347137, 22.42986107], [69.50347137, 22.42791939], [69.50374603, 22.42791939], [69.50374603, 22.42735863], [69.50402832, 22.42735863], [69.50402832, 22.42653084], [69.5045929, 22.42653084], [69.5045929, 22.42680931], [69.50485992, 22.42680931], [69.50485992, 22.42708969], [69.50541687, 22.42708969], [69.50541687, 22.42735863], [69.50681305, 22.42735863], [69.50680542, 22.42624855], [69.50708008, 22.42624855], [69.50708008, 22.42596817], [69.50736237, 22.42597008], [69.50736237, 22.42541885], [69.50624847, 22.42542076], [69.50624847, 22.42485809], [69.50653076, 22.42486191], [69.50653076, 22.42458344], [69.50680542, 22.42458344], [69.50680542, 22.42402649], [69.50708008, 22.4240303], [69.50708008, 22.42374992], [69.50763702, 22.42374992], [69.50763702, 22.42432022], [69.50791931, 22.42430496], [69.50791931, 22.42486191], [69.50818634, 22.42485809], [69.50818634, 22.42514038], [69.50846863, 22.42514038], [69.50846863, 22.42542076], [69.50902557, 22.42541885], [69.50902557, 22.42569351], [69.51457977, 22.42569351], [69.51457977, 22.42541885], [69.51513672, 22.42541885], [69.51513672, 22.42569351], [69.51708221, 22.42569351], [69.51708221, 22.42597008], [69.51875305, 22.42596817], [69.51875305, 22.42624855], [69.51957703, 22.42624855], [69.51957703, 22.42653084], [69.5229187, 22.42653084], [69.5229187, 22.42624855], [69.52319336, 22.42624855], [69.52319336, 22.42485809], [69.52347565, 22.42486191], [69.52347565, 22.42458344], [69.52375031, 22.42458344], [69.52375031, 22.42430496], [69.52430725, 22.42432022], [69.52430725, 22.4240303], [69.52458191, 22.4240303], [69.52458191, 22.42374992], [69.52680206, 22.42374992], [69.52680206, 22.42346954], [69.52708435, 22.42347145], [69.52708435, 22.42319489], [69.5276413, 22.42319489], [69.5276413, 22.42291641], [69.52791595, 22.42292023], [69.52791595, 22.42263985], [69.5284729, 22.42263985], [69.5284729, 22.42235947], [69.52874756, 22.42236137], [69.52874756, 22.4220829], [69.52902985, 22.4220829], [69.52902985, 22.42180634], [69.52958679, 22.42181015], [69.52958679, 22.42152977], [69.52986145, 22.42152977], [69.52986145, 22.42124939], [69.5304184, 22.42124939], [69.5304184, 22.42095947], [69.53069305, 22.42097282], [69.53069305, 22.42069435], [69.53097534, 22.42069435], [69.53097534, 22.42041588], [69.53151703, 22.42041969], [69.53151703, 22.42014122], [69.53180695, 22.42014122], [69.53180695, 22.41986084], [69.53208923, 22.41986084], [69.5320816, 22.41958427], [69.53236389, 22.41958237], [69.53236389, 22.4193058], [69.53263855, 22.41930962], [69.53263855, 22.41903114], [69.53291321, 22.41903114], [69.53291321, 22.41847038], [69.5331955, 22.41847229], [69.5331955, 22.41819382], [69.53347015, 22.41819382], [69.53347015, 22.41763878], [69.53375244, 22.41764069], [69.53375244, 22.41708183], [69.5340271, 22.41708374], [69.5340271, 22.41680527], [69.53430176, 22.4168129], [69.53430176, 22.41597176], [69.53458405, 22.41597366], [69.53458405, 22.41513824], [69.5348587, 22.41514969], [69.5348587, 22.41486168], [69.53541565, 22.41486168], [69.53541565, 22.41458321], [69.53569794, 22.41458321], [69.53569794, 22.41402817], [69.5359726, 22.41403008], [69.5359726, 22.41349983], [69.5359726, 22.41319466], [69.53569794, 22.41319466], [69.53569794, 22.41180611], [69.53542328, 22.41180992], [69.53542328, 22.41069031], [69.53569794, 22.41069412], [69.53569794, 22.41041946], [69.5359726, 22.41041946], [69.5359726, 22.41014099], [69.53624725, 22.41014099], [69.53624725, 22.40986061], [69.53652954, 22.40986061], [69.53652954, 22.41014099], [69.53679657, 22.41014099], [69.53679657, 22.41041946], [69.53708649, 22.41041946], [69.53708649, 22.41014099], [69.53930664, 22.41014099], [69.53930664, 22.40958023], [69.5395813, 22.40958405], [69.5395813, 22.40902519], [69.53986359, 22.40902519], [69.53986359, 22.40875053], [69.54152679, 22.40875053], [69.54152679, 22.40847015], [69.54208374, 22.40847206], [69.54208374, 22.40819359], [69.5423584, 22.40819359], [69.5423584, 22.40791512], [69.54292297, 22.40792084], [69.54292297, 22.40764046], [69.54319763, 22.40764046], [69.54319763, 22.40736008], [69.54374695, 22.40736198], [69.54374695, 22.40708351], [69.54402924, 22.40708351], [69.54402924, 22.40680695], [69.54458618, 22.40681076], [69.54458618, 22.40653038], [69.54514313, 22.40653038], [69.54514313, 22.40625], [69.54541779, 22.40625], [69.54541779, 22.40596008], [69.54597473, 22.40597153], [69.54597473, 22.40569305], [69.54624939, 22.40570068], [69.54624939, 22.4054203], [69.54736328, 22.4054203], [69.54736328, 22.40513992], [69.54818726, 22.40513992], [69.54818726, 22.40485954], [69.54875183, 22.40486145], [69.54875183, 22.40458488], [69.54985809, 22.40458488], [69.54985809, 22.40486145], [69.55013275, 22.40485954], [69.55013275, 22.40513992], [69.55042267, 22.40513992], [69.55042267, 22.40485954], [69.55069733, 22.40486145], [69.55069733, 22.40430641], [69.55097198, 22.40431023], [69.55097198, 22.4034729], [69.55124664, 22.4034729], [69.55124664, 22.40291595], [69.55152893, 22.40291977], [69.55152893, 22.40236282], [69.55179596, 22.40236282], [69.55179596, 22.40208244], [69.55208588, 22.40208244], [69.55208588, 22.40125275], [69.55236053, 22.40125275], [69.55236053, 22.40068817], [69.55263519, 22.40069389], [69.55263519, 22.40014076], [69.55291748, 22.4001503], [69.55291748, 22.39957809], [69.55319214, 22.39958382], [69.55319214, 22.3987484], [69.55291748, 22.3987484], [69.55291748, 22.39792061], [69.55264282, 22.39792061], [69.55264282, 22.39707947], [69.55236053, 22.39708328], [69.55236053, 22.39624977], [69.55208588, 22.39624977], [69.55208588, 22.39542007], [69.55179596, 22.39542007], [69.55179596, 22.39458084], [69.55152893, 22.39458275], [69.55152893, 22.39374924], [69.55097198, 22.39374924], [69.55097198, 22.39402771], [69.55042267, 22.39402008], [69.55042267, 22.39431], [69.54958344, 22.39430428], [69.54958344, 22.39458275], [69.54875183, 22.39458275], [69.54875183, 22.39402771], [69.54902649, 22.39402771], [69.54902649, 22.39374924], [69.54930878, 22.39375114], [69.54930878, 22.39319038], [69.54958344, 22.3931942], [69.54958344, 22.39291573], [69.55013275, 22.39291954], [69.55013275, 22.39264107], [69.55042267, 22.39264107], [69.55042267, 22.39236069], [69.55069733, 22.39236069], [69.55069733, 22.39208031], [69.55097198, 22.39208412], [69.55097198, 22.39180565], [69.55124664, 22.39180946], [69.55124664, 22.39153099], [69.55152893, 22.39153099], [69.55152893, 22.39125061], [69.55179596, 22.39125061], [69.55179596, 22.39097977], [69.55208588, 22.39097977], [69.55208588, 22.39068985], [69.55236053, 22.39069366], [69.55236053, 22.39013863], [69.55264282, 22.39014053], [69.55264282, 22.38986015], [69.55291748, 22.38986015], [69.55291748, 22.38957977], [69.55319214, 22.38958359], [69.55319214, 22.38930511], [69.5534668, 22.38931274], [69.5534668, 22.38903046], [69.55374908, 22.38903046], [69.55374908, 22.38875008], [69.55486298, 22.38875008], [69.55486298, 22.38903046], [69.55513763, 22.38903046], [69.55513763, 22.38875008], [69.55568695, 22.38875008], [69.55568695, 22.3884716], [69.55596924, 22.3884716], [69.55596924, 22.38680649], [69.55625916, 22.38680077], [69.55625153, 22.38402748], [69.55652618, 22.38402748], [69.55652618, 22.38153076], [69.55680847, 22.38153076], [69.55680847, 22.38042068], [69.55708313, 22.38042068], [69.55708313, 22.37930107], [69.55735779, 22.37930489], [69.55735779, 22.37902832], [69.55708313, 22.37903976], [69.55708313, 22.37763977], [69.55735779, 22.37763977], [69.55735779, 22.37541962], [69.55069733, 22.37541962], [69.55069733, 22.37514114], [69.55042267, 22.37514114], [69.55042267, 22.37486267], [69.55013275, 22.37486267], [69.55013275, 22.37430954], [69.55042267, 22.37430954], [69.55042267, 22.37402916], [69.55097198, 22.37402916], [69.55097198, 22.37375069], [69.55152893, 22.37375069], [69.55152893, 22.3734684], [69.55124664, 22.37347221], [69.55124664, 22.37319374], [69.55069733, 22.37319374], [69.55069733, 22.37264061], [69.55042267, 22.37264061], [69.55042267, 22.37235832], [69.55069733, 22.37235832], [69.55069733, 22.37181091], [69.55124664, 22.37181091], [69.55124664, 22.37153053], [69.55179596, 22.37153053], [69.55179596, 22.37124825], [69.55236053, 22.37124825], [69.55236053, 22.37096977], [69.55291748, 22.37097168], [69.55291748, 22.37069511], [69.5534668, 22.37070084], [69.5534668, 22.37042046], [69.55430603, 22.37042046], [69.55430603, 22.37013817], [69.55486298, 22.37013817], [69.55486298, 22.36985016], [69.55541992, 22.3698616], [69.55541992, 22.36958313], [69.55596924, 22.36958313], [69.55596924, 22.36930466], [69.55652618, 22.36930466], [69.55652618, 22.36902618], [69.55708313, 22.36903], [69.55708313, 22.36874962], [69.55764008, 22.36874962], [69.55764008, 22.36847115], [69.55791473, 22.36847305], [69.55791473, 22.36819458], [69.55819702, 22.36819458], [69.55819702, 22.3679142], [69.55847168, 22.36791992], [69.55847168, 22.36763954], [69.55874634, 22.36763954], [69.55874634, 22.36736107], [69.55930328, 22.36736107], [69.55930328, 22.36708069], [69.55958557, 22.3670826], [69.55958557, 22.36680412], [69.55986023, 22.36680984], [69.55986023, 22.36404037], [69.5595932, 22.36404037], [69.5595932, 22.36375046], [69.55986023, 22.36375046], [69.55986023, 22.3631897], [69.56014252, 22.36319351], [69.56014252, 22.36263847], [69.56041718, 22.36264038], [69.56041718, 22.36236191], [69.56069183, 22.36236382], [69.56069183, 22.36180496], [69.56096649, 22.36181068], [69.56096649, 22.3615303], [69.56124878, 22.3615303], [69.56124878, 22.36096954], [69.56153107, 22.36096954], [69.56153107, 22.36041641], [69.56181335, 22.36042023], [69.56181335, 22.35986137], [69.56263733, 22.35986137], [69.56263733, 22.35930634], [69.56291962, 22.35931015], [69.56291962, 22.35902977], [69.56318665, 22.35902977], [69.56318665, 22.35819054], [69.56291962, 22.35819435], [69.56291962, 22.35791588], [69.56236267, 22.35791588], [69.56236267, 22.35736084], [69.56207275, 22.35736084], [69.56207275, 22.35680962], [69.56124878, 22.35680962], [69.56124878, 22.35653114], [69.56153107, 22.35653114], [69.56153107, 22.35625076], [69.56181335, 22.35625076], [69.56180573, 22.35569382], [69.56263733, 22.35569382], [69.56263733, 22.35597229], [69.56318665, 22.35597038], [69.56318665, 22.35625076], [69.56375122, 22.35625076], [69.56375122, 22.35653114], [69.56458282, 22.35653114], [69.56458282, 22.35680962], [69.56513977, 22.3568058], [69.56513977, 22.35708237], [69.56569672, 22.35708046], [69.56569672, 22.35736084], [69.56624603, 22.35736084], [69.56624603, 22.35764122], [69.56652832, 22.35763741], [69.56652832, 22.35791588], [69.56680298, 22.35791588], [69.56680298, 22.35819435], [69.56708527, 22.35819435], [69.56708527, 22.35874748], [69.56735992, 22.35874748], [69.56735992, 22.35902977], [69.56764221, 22.35902977], [69.56764221, 22.35931015], [69.56791687, 22.35930634], [69.56791687, 22.3595829], [69.56819153, 22.3595829], [69.56819153, 22.35986137], [69.56846619, 22.35986137], [69.56846619, 22.36042023], [69.56874847, 22.36042023], [69.56874847, 22.3615303], [69.5688858, 22.3615303], [69.56903076, 22.3615303], [69.56903076, 22.36292076], [69.56930542, 22.36291695], [69.56930542, 22.3631115], [69.56930542, 22.36347389], [69.56958008, 22.36347008], [69.56958008, 22.36375046], [69.56986237, 22.36375046], [69.56986237, 22.36404037], [69.57013702, 22.36404037], [69.57013702, 22.36431122], [69.57041931, 22.3643055], [69.57041931, 22.36458206], [69.57068634, 22.36458015], [69.57068634, 22.36486053], [69.57096863, 22.36486053], [69.57096863, 22.36514091], [69.57124329, 22.36514091], [69.57124329, 22.36541939], [69.57152557, 22.36541748], [69.57152557, 22.36569595], [69.57208252, 22.36569595], [69.57208252, 22.36597252], [69.57235718, 22.36597061], [69.57235718, 22.36625099], [69.57263947, 22.36625099], [69.57263947, 22.36652946], [69.57290649, 22.36652946], [69.57290649, 22.36680984], [69.57347107, 22.36680412], [69.57347107, 22.3670826], [69.57375336, 22.36708069], [69.57375336, 22.36736107], [69.57402802, 22.36736107], [69.57402802, 22.36791992], [69.57458496, 22.3679142], [69.57458496, 22.36819458], [69.57569122, 22.36819458], [69.57569122, 22.36847305], [69.57679749, 22.36847305], [69.57819366, 22.36847305], [69.57819366, 22.36819458], [69.57875061, 22.36819458], [69.57875061, 22.3679142], [69.5790329, 22.36791992], [69.5790329, 22.36763954], [69.57958221, 22.36763954], [69.57958221, 22.36736107], [69.58013916, 22.36736107], [69.58013916, 22.36708069], [69.58041382, 22.3670826], [69.58041382, 22.36680412], [69.58097076, 22.36680984], [69.58097076, 22.36597061], [69.58125305, 22.36597252], [69.58125305, 22.36541748], [69.58152771, 22.36541939], [69.58152771, 22.36486053], [69.58180237, 22.36486053], [69.58180237, 22.36458015], [69.58208466, 22.36458206], [69.58208466, 22.36402702], [69.58235931, 22.36404037], [69.58235931, 22.36347008], [69.5826416, 22.36347389], [69.5826416, 22.36319351], [69.58291626, 22.36319351], [69.58291626, 22.36263847], [69.58318329, 22.36264038], [69.58318329, 22.36207962], [69.58291626, 22.36208344], [69.58291626, 22.3615284], [69.58486176, 22.3615303], [69.58486176, 22.36181068], [69.58569336, 22.36181068], [69.58569336, 22.3615303], [69.58680725, 22.3615284], [69.58680725, 22.36208344], [69.58763885, 22.36208344], [69.58763885, 22.36236382], [69.58790588, 22.36236191], [69.58790588, 22.36264038], [69.58875275, 22.36264038], [69.58875275, 22.36236191], [69.5890274, 22.36236382], [69.5890274, 22.36208344], [69.58958435, 22.36208344], [69.58958435, 22.36180496], [69.58985901, 22.36181068], [69.58985901, 22.3615303], [69.59041595, 22.3615303], [69.59041595, 22.36125183], [69.59069061, 22.36125183], [69.59069824, 22.36096954], [69.59124756, 22.36096954], [69.59124756, 22.36041641], [69.59152985, 22.36042023], [69.59152985, 22.35986137], [69.5918045, 22.35986137], [69.5918045, 22.35930634], [69.59208679, 22.35931015], [69.59208679, 22.35874748], [69.59236908, 22.35874748], [69.59236145, 22.3568058], [69.59208679, 22.35680962], [69.59208679, 22.35625076], [69.59179688, 22.35625076], [69.59179688, 22.35597038], [69.59152985, 22.35597229], [69.59152985, 22.35541534], [69.59124756, 22.35542107], [69.59124756, 22.35485077], [69.5909729, 22.35486031], [69.5909729, 22.35458374], [69.59069824, 22.35458374], [69.59069061, 22.3540287], [69.59041595, 22.35403061], [69.59041595, 22.35375023], [69.5901413, 22.35375023], [69.5901413, 22.35346985], [69.58958435, 22.35347176], [69.58958435, 22.35319328], [69.58930969, 22.35320091], [69.58930969, 22.35292053], [69.58875275, 22.35292053], [69.58875275, 22.35264015], [69.58847046, 22.35264015], [69.58847046, 22.35235977], [69.58791351, 22.35236168], [69.58791351, 22.35208321], [69.5873642, 22.35208321], [69.5873642, 22.35180473], [69.58680725, 22.35181046], [69.58680725, 22.35153008], [69.58624268, 22.35153008], [69.58624268, 22.35124969], [69.58569336, 22.35124969], [69.58569336, 22.35097122], [69.58486176, 22.35097313], [69.58486176, 22.35069466], [69.58430481, 22.35069466], [69.58430481, 22.35041618], [69.58403015, 22.35042], [69.58403015, 22.35013962], [69.58374786, 22.35013962], [69.58374786, 22.34986115], [69.58347321, 22.34986115], [69.58347321, 22.34958267], [69.58319092, 22.34958267], [69.58319092, 22.34930611], [69.58291626, 22.34930992], [69.58291626, 22.34902954], [69.58235931, 22.34902954], [69.58235931, 22.34875107], [69.58207703, 22.34875107], [69.58207703, 22.3484726], [69.58180237, 22.3484726], [69.58180237, 22.34819412], [69.58125305, 22.34819412], [69.58125305, 22.34791756], [69.58097076, 22.34791946], [69.58097076, 22.3476429], [69.58040619, 22.3476429], [69.58040619, 22.3473587], [69.58013916, 22.3473587], [69.58013916, 22.34707832], [69.5798645, 22.34708405], [69.5798645, 22.34680557], [69.57958221, 22.34680939], [69.57958221, 22.34625053], [69.57930756, 22.34625053], [69.57930756, 22.3445797], [69.57902527, 22.34458351], [69.57902527, 22.34347153], [69.57875061, 22.34347153], [69.57875061, 22.34263611], [69.5790329, 22.34263992], [69.5790329, 22.34097099], [69.57930756, 22.3409729], [69.57930756, 22.33986092], [69.5790329, 22.33987045], [69.5790329, 22.33875084], [69.57875061, 22.33875084], [69.57875061, 22.33819008], [69.57819366, 22.33819389], [69.57819366, 22.33791733], [69.57763672, 22.33792114], [69.57763672, 22.33764076], [69.57707977, 22.33764076], [69.57707977, 22.33736038], [69.57596588, 22.33736038], [69.57596588, 22.33708191], [69.57458496, 22.33708382], [69.57458496, 22.33652687], [69.57430267, 22.33653069], [69.57430267, 22.33625031], [69.57375336, 22.33625031], [69.57375336, 22.33597183], [69.57347107, 22.33597374], [69.57347107, 22.33569527], [69.57319641, 22.3357029], [69.57319641, 22.33543968], [69.57290649, 22.33542061], [69.57290649, 22.33514023], [69.57235718, 22.33514023], [69.57235718, 22.33486176], [69.57208252, 22.33486176], [69.57208252, 22.33430481], [69.57180786, 22.33430481], [69.57180786, 22.33097267], [69.57208252, 22.33097267], [69.57208252, 22.33041573], [69.57235718, 22.33041954], [69.57235718, 22.32986069], [69.57263947, 22.32986069], [69.57263947, 22.32930946], [69.57290649, 22.32930946], [69.57290649, 22.32903099], [69.57319641, 22.32903099], [69.57319641, 22.32847023], [69.57347107, 22.32847214], [69.57347107, 22.32791519], [69.57375336, 22.32793045], [69.57375336, 22.32736015], [69.57402802, 22.32736015], [69.57402802, 22.32653046], [69.57430267, 22.32653046], [69.57430267, 22.32625008], [69.57457733, 22.32625008], [69.57457733, 22.32542038], [69.57485962, 22.32542038], [69.57485962, 22.3243103], [69.57514191, 22.32430077], [69.57514191, 22.32347107], [69.57541656, 22.32347107], [69.57541656, 22.3204174], [69.57514191, 22.32041931], [69.57514191, 22.31930923], [69.57485962, 22.31930923], [69.57485962, 22.31903076], [69.57569122, 22.31903076], [69.57569122, 22.31930923], [69.57597351, 22.31930542], [69.57597351, 22.31958389], [69.57624817, 22.31957817], [69.57624817, 22.32014084], [69.57653046, 22.32014084], [69.57653046, 22.32263947], [69.57681274, 22.32263947], [69.57681274, 22.32291985], [69.57653046, 22.32291985], [69.57653046, 22.32487106], [69.57624817, 22.32487106], [69.57624817, 22.32542038], [69.57596588, 22.32542038], [69.57596588, 22.32653046], [69.57569122, 22.32652855], [69.57569122, 22.32708359], [69.57541656, 22.32708359], [69.57541656, 22.32819366], [69.57514191, 22.32819366], [69.57514191, 22.32847214], [69.57485962, 22.32847023], [69.57485962, 22.32875061], [69.57457733, 22.32875061], [69.57457733, 22.32930946], [69.57430267, 22.32930565], [69.57430267, 22.32958412], [69.57402802, 22.32958031], [69.57402802, 22.33014107], [69.57375336, 22.33013725], [69.57375336, 22.33097267], [69.57347107, 22.33097076], [69.57347107, 22.33152962], [69.57319641, 22.33152962], [69.57319641, 22.33235931], [69.57291412, 22.33235931], [69.57291412, 22.33319473], [69.57319641, 22.33319473], [69.57319641, 22.33346939], [69.57347107, 22.33346939], [69.57347107, 22.33403015], [69.57375336, 22.33402824], [69.57375336, 22.33430481], [69.57402802, 22.33430481], [69.57402802, 22.33458328], [69.57458496, 22.33458328], [69.57458496, 22.33470917], [69.57457733, 22.33514023], [69.57514191, 22.33514023], [69.57514191, 22.33542061], [69.57541656, 22.33542061], [69.57541656, 22.3357029], [69.57569122, 22.33569527], [69.57569122, 22.33597374], [69.57596588, 22.33597183], [69.57596588, 22.33625031], [69.57681274, 22.33625031], [69.57681274, 22.33653069], [69.57875061, 22.33653069], [69.57875061, 22.33681107], [69.57930756, 22.33680534], [69.57930756, 22.33708382], [69.57958221, 22.33708191], [69.57958221, 22.33736038], [69.57985687, 22.33736038], [69.57985687, 22.33764076], [69.58013916, 22.33763885], [69.58013916, 22.33819389], [69.58041382, 22.33819389], [69.58041382, 22.33958244], [69.58069611, 22.33958054], [69.58069611, 22.34263992], [69.58040619, 22.34263992], [69.58040619, 22.34374809], [69.58069611, 22.34374809], [69.58069611, 22.34486198], [69.58097076, 22.34485817], [69.58097076, 22.34514046], [69.58125305, 22.34514046], [69.58125305, 22.34542084], [69.58152771, 22.34541893], [69.58152771, 22.34569359], [69.58180237, 22.34568024], [69.58180237, 22.34625053], [69.58235931, 22.34625053], [69.58235931, 22.34653091], [69.58291626, 22.34653091], [69.58291626, 22.34680939], [69.58347321, 22.34680557], [69.58347321, 22.34708405], [69.58403015, 22.34707832], [69.58403015, 22.3473587], [69.58513641, 22.3473587], [69.58513641, 22.3476429], [69.58569336, 22.3476429], [69.58569336, 22.34791946], [69.58652496, 22.34791756], [69.58652496, 22.34819412], [69.58708191, 22.34819412], [69.58708191, 22.3484726], [69.58763885, 22.3484726], [69.58763885, 22.34875107], [69.5881958, 22.34875107], [69.5881958, 22.34902954], [69.5890274, 22.34902954], [69.5890274, 22.34930992], [69.58958435, 22.34930611], [69.58958435, 22.34958267], [69.5901413, 22.34958267], [69.5901413, 22.34986115], [69.59069824, 22.34986115], [69.59069824, 22.35013962], [69.5909729, 22.35013962], [69.5909729, 22.35042], [69.59152985, 22.35041618], [69.59152985, 22.35069466], [69.59208679, 22.35069466], [69.59208679, 22.35097313], [69.59263611, 22.35097122], [69.59263611, 22.35124969], [69.5929184, 22.35124969], [69.5929184, 22.35153008], [69.59348297, 22.35153008], [69.59348297, 22.35181046], [69.59402466, 22.35180473], [69.59402466, 22.35208321], [69.59430695, 22.35208321], [69.59430695, 22.35236168], [69.59486389, 22.35236168], [69.59486389, 22.35208321], [69.59541321, 22.35208321], [69.59541321, 22.35152817], [69.59570313, 22.35153008], [69.59570313, 22.35097122], [69.59597015, 22.35097313], [69.59597015, 22.35013962], [69.59625244, 22.35013962], [69.59625244, 22.34791946], [69.59707642, 22.34791946], [69.59707642, 22.34875107], [69.5973587, 22.34875107], [69.5973587, 22.34902954], [69.59764099, 22.34902763], [69.59764099, 22.34958267], [69.59819794, 22.34958267], [69.59819794, 22.34986115], [69.5984726, 22.34986115], [69.5984726, 22.35013962], [69.59874725, 22.35013962], [69.59874725, 22.35042], [69.59902954, 22.35041618], [69.59902954, 22.35069466], [69.5993042, 22.35069466], [69.5993042, 22.35041618], [69.59986115, 22.35042], [69.59986115, 22.34958267], [69.6001358, 22.34958267], [69.6001358, 22.34874916], [69.60041809, 22.34875107], [69.60041809, 22.3484726], [69.60069275, 22.3484726], [69.60069275, 22.34819412], [69.60097504, 22.34819412], [69.60097504, 22.34763908], [69.60124969, 22.3476429], [69.60124969, 22.3473587], [69.60151672, 22.3473587], [69.60151672, 22.34707832], [69.6020813, 22.34707832], [69.6020813, 22.3473587], [69.60236359, 22.3473587], [69.60236359, 22.34819412], [69.6020813, 22.34819412], [69.6020813, 22.3484726], [69.60180664, 22.3484726], [69.60180664, 22.34902954], [69.60151672, 22.34902954], [69.60151672, 22.34986115], [69.60124969, 22.34986115], [69.60124969, 22.35042], [69.60151672, 22.35042], [69.60151672, 22.35124969], [69.6020813, 22.35124969], [69.6020813, 22.35097122], [69.60236359, 22.35097313], [69.60236359, 22.35069466], [69.60375214, 22.35069466], [69.60375214, 22.35097313], [69.60457611, 22.35097122], [69.60457611, 22.35124969], [69.6048584, 22.35124969], [69.6048584, 22.35097122], [69.60514069, 22.35097313], [69.60514069, 22.35069466], [69.60541534, 22.35069466], [69.60541534, 22.34986115], [69.60569763, 22.34986115], [69.60569763, 22.34958267], [69.60597229, 22.34958267], [69.60597229, 22.34708405], [69.60541534, 22.34708405], [69.60541534, 22.3465271], [69.60597229, 22.34653091], [69.60597229, 22.34625053], [69.60624695, 22.34625053], [69.60624695, 22.34374809], [69.60597229, 22.34374809], [69.60597229, 22.34235954], [69.60569763, 22.34236145], [69.60569763, 22.3409729], [69.60597229, 22.3409729], [69.60597229, 22.34069443], [69.60624695, 22.34069443], [69.60624695, 22.33986092], [69.60652924, 22.33987045], [69.60652924, 22.33974075], [69.60652924, 22.33875084], [69.60679626, 22.33875084], [69.60679626, 22.33847046], [69.60735321, 22.33847046], [69.60735321, 22.33930969], [69.60708618, 22.33930969], [69.60708618, 22.34013939], [69.60692596, 22.34013939], [69.60679626, 22.34013939], [69.60679626, 22.34181023], [69.60652924, 22.34180832], [69.60652924, 22.34347153], [69.60679626, 22.34346962], [69.60679626, 22.34791946], [69.60708618, 22.34791946], [69.60708618, 22.34902954], [69.60735321, 22.34902954], [69.60735321, 22.34930992], [69.60901642, 22.34930992], [69.60901642, 22.34819031], [69.60930634, 22.34819412], [69.60930634, 22.34763908], [69.60958099, 22.3476429], [69.60958099, 22.34707832], [69.60986328, 22.34708405], [69.60986328, 22.34625053], [69.61013794, 22.34625053], [69.61013794, 22.34568024], [69.61042023, 22.34569359], [69.61042023, 22.34515953], [69.61042023, 22.34486198], [69.61069489, 22.34486198], [69.61069489, 22.34430504], [69.61096954, 22.34431076], [69.61096954, 22.34374809], [69.61125183, 22.34374809], [69.61125183, 22.34291077], [69.61152649, 22.34291649], [69.61152649, 22.34236145], [69.61180878, 22.34236145], [69.61180878, 22.34180832], [69.61207581, 22.34181023], [69.61207581, 22.34152985], [69.61235809, 22.34152985], [69.61235809, 22.34085846], [69.61235809, 22.34041405], [69.61207581, 22.34041977], [69.61207581, 22.33958054], [69.61180878, 22.33958244], [69.61180878, 22.33875084], [69.61152649, 22.33875084], [69.61152649, 22.33819008], [69.61125183, 22.33819389], [69.61125183, 22.33763885], [69.61096954, 22.33764076], [69.61096954, 22.33681107], [69.61068726, 22.33681107], [69.61068726, 22.33597183], [69.61042023, 22.33597374], [69.61042023, 22.33486176], [69.61013794, 22.33486176], [69.61013794, 22.33235931], [69.60986328, 22.33235931], [69.60986328, 22.33152962], [69.60958099, 22.33152962], [69.60958099, 22.33097076], [69.60930634, 22.33097267], [69.60930634, 22.3306942], [69.60902405, 22.3306942], [69.60902405, 22.33013725], [69.6084671, 22.33014107], [69.6084671, 22.32958031], [69.60819244, 22.32958412], [69.60819244, 22.32930565], [69.60791779, 22.32930946], [69.60791779, 22.32875061], [69.6076355, 22.32875061], [69.6076355, 22.32819366], [69.60708618, 22.32819366], [69.60708618, 22.32763863], [69.60679626, 22.32764053], [69.60679626, 22.32736015], [69.60652924, 22.32736206], [69.60652924, 22.32708359], [69.60624695, 22.32708359], [69.60624695, 22.32569313], [69.60680389, 22.32569313], [69.60680389, 22.3259716], [69.60708618, 22.3259697], [69.60708618, 22.32625008], [69.60736084, 22.32625008], [69.60736084, 22.32708359], [69.6076355, 22.32708359], [69.6076355, 22.32736015], [69.60791779, 22.32736015], [69.60791779, 22.32793045], [69.60819244, 22.32791519], [69.60819244, 22.32819366], [69.60847473, 22.32819366], [69.60847473, 22.32847214], [69.60874939, 22.32847023], [69.60874939, 22.32875061], [69.60901642, 22.32875061], [69.60901642, 22.32903099], [69.60930634, 22.32903099], [69.60930634, 22.32930946], [69.60958099, 22.32930946], [69.60958099, 22.33041954], [69.60986328, 22.33041573], [69.60986328, 22.3306942], [69.61013794, 22.33068085], [69.61013794, 22.33125114], [69.61042023, 22.33124733], [69.61042023, 22.33208275], [69.61068726, 22.33208084], [69.61068726, 22.3326416], [69.61096954, 22.3326416], [69.61096954, 22.33458328], [69.61125183, 22.33457947], [69.61125183, 22.3357029], [69.61152649, 22.3357029], [69.61152649, 22.33625031], [69.61180878, 22.33625031], [69.61180878, 22.33681107], [69.61208344, 22.33680534], [69.61208344, 22.33708382], [69.61235809, 22.33708191], [69.61235809, 22.33764076], [69.61264038, 22.33764076], [69.61264038, 22.33792114], [69.61319733, 22.33792114], [69.61319733, 22.33764076], [69.61402893, 22.33764076], [69.61402893, 22.33792114], [69.61429596, 22.33792114], [69.61429596, 22.33903122], [69.61458588, 22.3390274], [69.61458588, 22.33958244], [69.61486053, 22.33958054], [69.61486053, 22.34013939], [69.61513519, 22.34013939], [69.61513519, 22.34069443], [69.61541748, 22.34069443], [69.61541748, 22.3409729], [69.61569214, 22.3409729], [69.61569214, 22.34208298], [69.61541748, 22.34208298], [69.61541748, 22.34236145], [69.61569214, 22.34235954], [69.61569214, 22.34320068], [69.6159668, 22.34320068], [69.6159668, 22.34431076], [69.616539, 22.34431076], [69.616539, 22.34514046], [69.61680603, 22.34514046], [69.61680603, 22.34569359], [69.61708069, 22.34568024], [69.61708069, 22.34625053], [69.61736298, 22.34625053], [69.61736298, 22.34680939], [69.61708069, 22.34680557], [69.61708069, 22.34708405], [69.61695862, 22.34708023], [69.61680603, 22.34707832], [69.61680603, 22.3476429], [69.616539, 22.3476429], [69.616539, 22.34791946], [69.61680603, 22.34791756], [69.61680603, 22.34819412], [69.61708069, 22.34819412], [69.61708069, 22.3484726], [69.61736298, 22.3484726], [69.61736298, 22.34875107], [69.61763763, 22.34875107], [69.61763763, 22.34930992], [69.61791992, 22.34930992], [69.61791992, 22.35042], [69.61763763, 22.35041618], [69.61763763, 22.35097313], [69.61736298, 22.35097122], [69.61736298, 22.35153008], [69.61708069, 22.35152817], [69.61708069, 22.35208321], [69.61680603, 22.35208321], [69.61680603, 22.35458374], [69.61708069, 22.35457993], [69.61708069, 22.35542107], [69.61736298, 22.35541534], [69.61736298, 22.35569382], [69.61763763, 22.35569], [69.61763763, 22.35625076], [69.61791992, 22.35625076], [69.61791992, 22.35653114], [69.61818695, 22.35653114], [69.61818695, 22.35680962], [69.61875153, 22.3568058], [69.61875153, 22.35708237], [69.61985779, 22.35708046], [69.61985779, 22.35764122], [69.61958313, 22.35763741], [69.61958313, 22.35847282], [69.61930847, 22.35847092], [69.61930847, 22.35902977], [69.61902618, 22.35902977], [69.61902618, 22.35931015], [69.61846924, 22.35930634], [69.61846924, 22.3595829], [69.61819458, 22.3595829], [69.61819458, 22.35986137], [69.61791992, 22.35986137], [69.61791992, 22.36181068], [69.61763763, 22.36181068], [69.61763763, 22.36375046], [69.61736298, 22.36375046], [69.61736298, 22.36458206], [69.61708069, 22.36458015], [69.61708069, 22.36514091], [69.61680603, 22.36514091], [69.61680603, 22.36680984], [69.61708069, 22.36680984], [69.61708069, 22.36736107], [69.61736298, 22.36736107], [69.61736298, 22.36763954], [69.61763763, 22.36763954], [69.61763763, 22.36819458], [69.61791992, 22.36819458], [69.61791992, 22.36847305], [69.62014008, 22.36847305], [69.62014008, 22.36819458], [69.62069702, 22.36819458], [69.62069702, 22.3679142], [69.62152863, 22.36791992], [69.62152863, 22.36763954], [69.62180328, 22.36763954], [69.62180328, 22.36736107], [69.6220932, 22.36736107], [69.62208557, 22.3670826], [69.62264252, 22.36708069], [69.62264252, 22.36736107], [69.62291718, 22.36736107], [69.62291718, 22.36708069], [69.62347412, 22.3670826], [69.62347412, 22.36652756], [69.62374878, 22.36652946], [69.62374878, 22.36486053], [69.62403107, 22.36486053], [69.62403107, 22.36458015], [69.62430573, 22.36458206], [69.62430573, 22.3643055], [69.62486267, 22.36431122], [69.62486267, 22.36404037], [69.62568665, 22.36404037], [69.62568665, 22.36375046], [69.62680817, 22.36375046], [69.62680817, 22.36347008], [69.62763977, 22.36347389], [69.62763977, 22.36319351], [69.62791443, 22.36319351], [69.62791443, 22.36291695], [69.62847137, 22.36291695], [69.62847137, 22.36319351], [69.62958527, 22.36319351], [69.62958527, 22.36291695], [69.63014221, 22.36292076], [69.63014221, 22.36264038], [69.63069153, 22.36264038], [69.63069153, 22.36236191], [69.63097382, 22.36236382], [69.63097382, 22.36208344], [69.63153076, 22.36208344], [69.63153076, 22.36180496], [69.63208008, 22.36181068], [69.63208008, 22.3615303], [69.63263702, 22.3615303], [69.63263702, 22.36125183], [69.63318634, 22.36125183], [69.63318634, 22.36096954], [69.63346863, 22.36096954], [69.63346863, 22.36069489], [69.63402557, 22.36069489], [69.63402557, 22.36041641], [69.63430786, 22.36042023], [69.63430786, 22.36014175], [69.63485718, 22.36014175], [69.63485718, 22.35986137], [69.63513947, 22.35986137], [69.63513947, 22.35930634], [69.63540649, 22.35931015], [69.63540649, 22.35902977], [69.63597107, 22.35902977], [69.63597107, 22.35874748], [69.63625336, 22.35874748], [69.63625336, 22.35847092], [69.63903046, 22.35847092], [69.63903046, 22.35874748], [69.63957977, 22.35874748], [69.63957977, 22.35902977], [69.64068604, 22.35902977], [69.64068604, 22.35874748], [69.64125061, 22.35874748], [69.64125061, 22.35847092], [69.64152527, 22.35847282], [69.64152527, 22.35819435], [69.64180756, 22.35819435], [69.64180756, 22.35763741], [69.64208221, 22.35764122], [69.64208221, 22.35736084], [69.64235687, 22.35736084], [69.64235687, 22.35708046], [69.64263916, 22.35708237], [69.64263916, 22.35652733], [69.64290619, 22.35653114], [69.64290619, 22.35625076], [69.64319611, 22.35625076], [69.64319611, 22.35597038], [69.64457703, 22.35597038], [69.64457703, 22.35653114], [69.64485931, 22.35653114], [69.64485931, 22.35680962], [69.6451416, 22.35680962], [69.6451416, 22.35736084], [69.64569092, 22.35736084], [69.64569092, 22.35791588], [69.64624786, 22.35791588], [69.64624786, 22.35736084], [69.64679718, 22.35736084], [69.64679718, 22.35764122], [69.64763641, 22.35763741], [69.64763641, 22.35819435], [69.64930725, 22.35819435], [69.64930725, 22.35847282], [69.65125275, 22.35847092], [69.65125275, 22.35874748], [69.65291595, 22.35874748], [69.65291595, 22.35902977], [69.65458679, 22.35902977], [69.65458679, 22.3595829], [69.65486145, 22.3595829], [69.65486145, 22.35986137], [69.65569305, 22.35986137], [69.65569305, 22.36014175], [69.65598297, 22.36014175], [69.65598297, 22.36042023], [69.65651703, 22.36042023], [69.65651703, 22.36181068], [69.65680695, 22.36181068], [69.65680695, 22.36375046], [69.6570816, 22.36375046], [69.6570816, 22.36458206], [69.65680695, 22.36458015], [69.65680695, 22.36486053], [69.65651703, 22.36486053], [69.65651703, 22.36514091], [69.65625, 22.36514091], [69.65625, 22.36541939], [69.65598297, 22.36541939], [69.65598297, 22.36625099], [69.65569305, 22.36625099], [69.65569305, 22.36736107], [69.6554184, 22.36736107], [69.6554184, 22.3698616], [69.65598297, 22.36985016], [69.65598297, 22.37013817], [69.65625, 22.37013817], [69.65625, 22.37042046], [69.65651703, 22.37042046], [69.65651703, 22.37070084], [69.65680695, 22.37070084], [69.65680695, 22.37181091], [69.6570816, 22.37181091], [69.6570816, 22.37430954], [69.65680695, 22.37430954], [69.65680695, 22.37486267], [69.65652466, 22.37486267], [69.65652466, 22.37569427], [69.65625, 22.37569046], [69.65625, 22.37625122], [69.65598297, 22.37625122], [69.65598297, 22.37681007], [69.65625, 22.37680626], [69.65625, 22.37708282], [69.65651703, 22.37708282], [69.65651703, 22.37763977], [69.65680695, 22.37763977], [69.65680695, 22.37792015], [69.6570816, 22.37791634], [69.6570816, 22.37819481], [69.65763855, 22.37819481], [69.65763855, 22.37847137], [69.65791321, 22.37846947], [69.65791321, 22.37874985], [69.65846252, 22.37874985], [69.65846252, 22.37903976], [69.65875244, 22.37902832], [69.65875244, 22.37930489], [69.6590271, 22.37930107], [69.6590271, 22.38264084], [69.65930176, 22.38263893], [69.65930939, 22.38319397], [69.65958405, 22.38319397], [69.65958405, 22.38347244], [69.6598587, 22.38347054], [69.6598587, 22.38402748], [69.66014099, 22.38402748], [69.66014099, 22.38458252], [69.66041565, 22.38458252], [69.66042328, 22.38485909], [69.66014099, 22.38485909], [69.66014099, 22.38792038], [69.66069794, 22.38792038], [69.66069794, 22.3882103], [69.66124725, 22.38819504], [69.66124725, 22.3884716], [69.6626358, 22.3884716], [69.6626358, 22.38875008], [69.66319275, 22.38875008], [69.66319275, 22.38903046], [69.66347504, 22.38902855], [69.66347504, 22.38958359], [69.66374969, 22.38957977], [69.66374969, 22.39042091], [69.66401672, 22.39042091], [69.66401672, 22.39375114], [69.66485596, 22.39375114], [69.66485596, 22.39347076], [69.6654129, 22.39347267], [69.6654129, 22.3931942], [69.66625214, 22.3931942], [69.66625214, 22.39291573], [69.66680908, 22.39291954], [69.66680908, 22.39264107], [69.6673584, 22.39264107], [69.6673584, 22.39291954], [69.66791534, 22.39291573], [69.66791534, 22.3931942], [69.66847229, 22.3931942], [69.66847229, 22.39347267], [69.66874695, 22.39347076], [69.66874695, 22.39375114], [69.66930389, 22.39374924], [69.66930389, 22.39402771], [69.66958618, 22.39402008], [69.66958618, 22.39431], [69.66986084, 22.39430428], [69.66986084, 22.39458275], [69.6701355, 22.39458275], [69.6701355, 22.39486122], [69.67069244, 22.39486122], [69.67069244, 22.39513969], [69.6709671, 22.39513969], [69.6709671, 22.39542007], [69.67124939, 22.39542007], [69.67124939, 22.39513969], [69.67151642, 22.39513969], [69.67151642, 22.39486122], [69.67180634, 22.39486122], [69.67180634, 22.39458084], [69.67208099, 22.39458084], [69.67208099, 22.39486122], [69.67236328, 22.39486122], [69.67236328, 22.39458084], [69.67263794, 22.39458275], [69.67263794, 22.39430428], [69.67292023, 22.39431], [69.67292023, 22.39402008], [69.67318726, 22.39402008], [69.67318726, 22.39431], [69.67375183, 22.39430428], [69.67375183, 22.39458275], [69.67430878, 22.39458084], [69.67430878, 22.39486122], [69.67514038, 22.39486122], [69.67514038, 22.39458084], [69.67652893, 22.39458275], [69.67652893, 22.39430428], [69.67708588, 22.39431], [69.67708588, 22.39402008], [69.67791748, 22.39402008], [69.67791748, 22.39431], [69.67930603, 22.39430428], [69.67930603, 22.39458275], [69.68013763, 22.39458084], [69.68013763, 22.39486122], [69.68041992, 22.39486122], [69.68041992, 22.39513969], [69.68125153, 22.39513969], [69.68125153, 22.39542007], [69.68681335, 22.39542007], [69.68681335, 22.39513969], [69.68875122, 22.39513969], [69.68875122, 22.39486122], [69.69346619, 22.39486122], [69.69346619, 22.39513969], [69.69568634, 22.39513969], [69.69568634, 22.39542007], [69.69736481, 22.39541626], [69.69736481, 22.39569473], [69.69902802, 22.39569473], [69.69902802, 22.3959713], [69.69930267, 22.39596939], [69.69930267, 22.39653015], [69.69958496, 22.39652634], [69.69958496, 22.39708328], [69.69985962, 22.39707947], [69.69985962, 22.39763832], [69.70014191, 22.39763641], [69.70014191, 22.39847183], [69.69958496, 22.39847183], [69.69958496, 22.3979187], [69.69930267, 22.39792061], [69.69930267, 22.39819908], [69.69902802, 22.39819527], [69.69902802, 22.39847183], [69.69847107, 22.39846992], [69.69847107, 22.3987484], [69.69819641, 22.3987484], [69.69819641, 22.39903069], [69.69791412, 22.39902687], [69.69791412, 22.4034729], [69.69763947, 22.4034729], [69.69763947, 22.40902519], [69.69736481, 22.40902519], [69.69736481, 22.40958405], [69.69708252, 22.40958405], [69.69708252, 22.4109726], [69.69680786, 22.41097069], [69.69680786, 22.41152954], [69.6965332, 22.41152954], [69.6965332, 22.41208839], [69.69625092, 22.41208839], [69.69625092, 22.41235924], [69.69596863, 22.41235924], [69.69596863, 22.41263771], [69.69568634, 22.41263771], [69.69568634, 22.4137516], [69.69513702, 22.4137516], [69.69513702, 22.41403008], [69.69486237, 22.41402817], [69.69486237, 22.41458321], [69.69457245, 22.41457939], [69.69457245, 22.41570282], [69.69430542, 22.41569519], [69.69430542, 22.41597366], [69.69403076, 22.41597176], [69.69403076, 22.41625023], [69.69374847, 22.41625023], [69.69374847, 22.4168129], [69.69403076, 22.41680527], [69.69403076, 22.41708374], [69.69374847, 22.41708183], [69.69374847, 22.41764069], [69.69346619, 22.41764069], [69.69346619, 22.41792107], [69.69319153, 22.41792107], [69.69319153, 22.41875076], [69.69291687, 22.41875076], [69.69291687, 22.41958427], [69.69264221, 22.41958046], [69.69264221, 22.41986084], [69.69235992, 22.41986084], [69.69235992, 22.42014122], [69.69264221, 22.42014122], [69.69264221, 22.42041969], [69.69235992, 22.42041969], [69.69235992, 22.42124939], [69.69264221, 22.42124939], [69.69264221, 22.42152977], [69.69291687, 22.42152977], [69.69291687, 22.42181015], [69.69347382, 22.42180634], [69.69347382, 22.4220829], [69.69374847, 22.42208099], [69.69374847, 22.42263985], [69.69403076, 22.42263794], [69.69403076, 22.42319489], [69.69430542, 22.42319489], [69.69430542, 22.42374992], [69.69457245, 22.42374992], [69.69457245, 22.42432022], [69.69486237, 22.42430496], [69.69486237, 22.42458344], [69.69513702, 22.42457962], [69.69513702, 22.42514038], [69.69541931, 22.42514038], [69.69541931, 22.42569351], [69.69568634, 22.4256897], [69.69568634, 22.42624855], [69.69596863, 22.42624855], [69.69596863, 22.42680931], [69.69625092, 22.42680931], [69.69625092, 22.42735863], [69.6965332, 22.42735863], [69.6965332, 22.42764282], [69.69680786, 22.42764091], [69.69680786, 22.42819405], [69.69708252, 22.42819405], [69.69708252, 22.42847252], [69.69735718, 22.42847252], [69.69735718, 22.4287529], [69.69763184, 22.4287529], [69.69763184, 22.42902946], [69.69790649, 22.42902946], [69.69790649, 22.42930984], [69.69847107, 22.42930603], [69.69847107, 22.4295826], [69.69875336, 22.4295826], [69.69875336, 22.43013954], [69.69902802, 22.43013191], [69.69902802, 22.43041992], [69.69930267, 22.43041611], [69.69930267, 22.43097305], [69.69957733, 22.43097115], [69.69957733, 22.43124962], [69.69985962, 22.43124962], [69.69985962, 22.43153], [69.70014191, 22.43152809], [69.70014191, 22.43208313], [69.70041656, 22.43208313], [69.70041656, 22.4323616], [69.70069885, 22.4323597], [69.70069885, 22.43264008], [69.70096588, 22.43264008], [69.70096588, 22.43292046], [69.70124817, 22.43291664], [69.70124817, 22.43319321], [69.70153046, 22.43319321], [69.70153046, 22.43347168], [69.70180511, 22.43347168], [69.70180511, 22.43375015], [69.70207977, 22.43375015], [69.70207977, 22.43403053], [69.70181274, 22.43403053], [69.70181274, 22.43431091], [69.70153046, 22.43430519], [69.70153046, 22.43458366], [69.70124817, 22.43457985], [69.70124817, 22.43514061], [69.70096588, 22.43514061], [69.70096588, 22.43542099], [69.70069122, 22.43541527], [69.70069122, 22.43569374], [69.70041656, 22.43569374], [69.70041656, 22.43597221], [69.70014191, 22.43597031], [69.70014191, 22.43653107], [69.69985962, 22.43652725], [69.69985962, 22.4370842], [69.69957733, 22.43708038], [69.69957733, 22.43764114], [69.69930267, 22.43763733], [69.69930267, 22.43819427], [69.69902802, 22.43819427], [69.69902802, 22.43847275], [69.69875336, 22.43847084], [69.69875336, 22.43902969], [69.69847107, 22.43902969], [69.69847107, 22.43958282], [69.69819641, 22.43958092], [69.69819641, 22.44014168], [69.69791412, 22.44014168], [69.69791412, 22.44069481], [69.69763947, 22.44069481], [69.69763947, 22.44096947], [69.69736481, 22.44096947], [69.69736481, 22.44236183], [69.69763184, 22.44236183], [69.69763184, 22.4426403], [69.69790649, 22.4426403], [69.69790649, 22.44292068], [69.69708252, 22.44292068], [69.69708252, 22.44320107], [69.68013763, 22.44320107], [69.68013763, 22.44292068], [69.67930603, 22.44292068], [69.67930603, 22.4426403], [69.67903137, 22.4426403], [69.67903137, 22.44236183], [69.67874908, 22.44236183], [69.67874908, 22.44208336], [69.67847443, 22.44208336], [69.67847443, 22.44180489], [69.67819214, 22.44180489], [69.67819214, 22.44125175], [69.67791748, 22.44125175], [69.67791748, 22.44068909], [69.67763519, 22.44069481], [69.67763519, 22.43958282], [69.67652893, 22.43958282], [69.67652893, 22.43930626], [69.67458344, 22.43930626], [69.67458344, 22.43985939], [69.67430878, 22.43985939], [69.67430878, 22.44014168], [69.67402649, 22.44014168], [69.67402649, 22.44042015], [69.67318726, 22.44042015], [69.67318726, 22.44014168], [69.67292023, 22.44014168], [69.67292023, 22.43958092], [69.67236328, 22.43958282], [69.67236328, 22.43930626], [69.67180634, 22.43930626], [69.67180634, 22.43958282], [69.67208099, 22.43958282], [69.67208099, 22.43985939], [69.67180634, 22.43985939], [69.67180634, 22.44042015], [69.67151642, 22.44042015], [69.67151642, 22.44125175], [69.67263794, 22.44125175], [69.67263794, 22.44153023], [69.67375183, 22.44152832], [69.67375183, 22.44180489], [69.67346954, 22.44180489], [69.67346954, 22.44236183], [69.67318726, 22.44236183], [69.67318726, 22.44292068], [69.67292023, 22.44291687], [69.67292023, 22.44347382], [69.67263794, 22.44347191], [69.67263794, 22.44403076], [69.67236328, 22.44402695], [69.67236328, 22.44458389], [69.67208099, 22.44458389], [69.67208099, 22.44513893], [69.67180634, 22.44512939], [69.67180634, 22.44680977], [69.67152405, 22.44680405], [69.67152405, 22.44958305], [69.67180634, 22.44958115], [69.67180634, 22.45070076], [69.67208099, 22.45070076], [69.67208099, 22.45042038], [69.67263794, 22.45042038], [69.67263794, 22.45013809], [69.67318726, 22.45013809], [69.67318726, 22.44985962], [69.67346954, 22.44986153], [69.67346954, 22.44902611], [69.67318726, 22.44902992], [69.67318726, 22.44847107], [69.67292023, 22.44847298], [69.67292023, 22.4481945], [69.67263794, 22.44820023], [69.67263794, 22.44512939], [69.67292023, 22.44513893], [69.67292023, 22.44486046], [69.67318726, 22.44486046], [69.67318726, 22.44431114], [69.67346191, 22.44431114], [69.67346191, 22.44403076], [69.67375183, 22.44403076], [69.67375183, 22.44320107], [69.67402649, 22.44320107], [69.67402649, 22.4426403], [69.67430878, 22.4426403], [69.67430878, 22.44236183], [69.67485809, 22.44236183], [69.67485809, 22.44208336], [69.67541504, 22.44208336], [69.67541504, 22.44236183], [69.67597198, 22.44236183], [69.67597198, 22.4426403], [69.67652893, 22.4426403], [69.67652893, 22.44292068], [69.67679596, 22.44292068], [69.67679596, 22.44320107], [69.67736053, 22.44319534], [69.67736053, 22.44347382], [69.67819214, 22.44347191], [69.67819214, 22.44375038], [69.67930603, 22.44375038], [69.67930603, 22.44403076], [69.68235779, 22.44403076], [69.68235779, 22.44431114], [69.68708038, 22.44430542], [69.68708038, 22.44458389], [69.68763733, 22.44458389], [69.68763733, 22.44430542], [69.68819427, 22.44430542], [69.68819427, 22.44458389], [69.68846893, 22.44458389], [69.68846893, 22.44513893], [69.68818665, 22.44512939], [69.68818665, 22.44542122], [69.68791962, 22.44542122], [69.68791962, 22.44652939], [69.68763733, 22.44652748], [69.68763733, 22.44708252], [69.68791962, 22.44708061], [69.68791962, 22.44736099], [69.68818665, 22.44736099], [69.68818665, 22.44763947], [69.68875885, 22.44763947], [69.68875885, 22.44820023], [69.68902588, 22.4481945], [69.68902588, 22.44847298], [69.68930817, 22.44847107], [69.68930817, 22.44902992], [69.68958282, 22.44902611], [69.68958282, 22.44930077], [69.68985748, 22.44930649], [69.68985748, 22.44958305], [69.69013977, 22.44958115], [69.69013977, 22.45013809], [69.6904068, 22.45013809], [69.6904068, 22.45042038], [69.69069672, 22.45041656], [69.69069672, 22.4509716], [69.69097137, 22.4509697], [69.69097137, 22.45126152], [69.69152832, 22.45126152], [69.69152832, 22.45153046], [69.69180298, 22.45153046], [69.69180298, 22.45181084], [69.69235992, 22.45180511], [69.69235992, 22.45208359], [69.69291687, 22.45207977], [69.69291687, 22.45235825], [69.69346619, 22.45235825], [69.69346619, 22.45264053], [69.69374847, 22.45264053], [69.69374847, 22.45292091], [69.69430542, 22.4529171], [69.69430542, 22.45319366], [69.69541931, 22.45319366], [69.69541931, 22.45347023], [69.69652557, 22.45347023], [69.69652557, 22.45375061], [69.69735718, 22.45375061], [69.69735718, 22.45402908], [69.69819641, 22.45402718], [69.69819641, 22.45458412], [69.69847107, 22.45458031], [69.69847107, 22.45486259], [69.69875336, 22.45486259], [69.69875336, 22.45514107], [69.69902802, 22.45513916], [69.69902802, 22.4556942], [69.69930267, 22.4556942], [69.69930267, 22.45597267], [69.69957733, 22.45597267], [69.69957733, 22.45625114], [69.69985962, 22.45625114], [69.69985962, 22.45652962], [69.70014191, 22.45652962], [69.70014191, 22.45681], [69.70041656, 22.45681], [69.70041656, 22.45736122], [69.70096588, 22.45736122], [69.70096588, 22.45625114], [69.70124817, 22.45625114], [69.70124817, 22.45541954], [69.70096588, 22.45541954], [69.70096588, 22.45486259], [69.70069122, 22.45486259], [69.70069122, 22.45458412], [69.70014191, 22.45458412], [69.70014191, 22.45347023], [69.70041656, 22.45347023], [69.70041656, 22.45236206], [69.70069122, 22.45235825], [69.70069122, 22.45153046], [69.70096588, 22.45153046], [69.70096588, 22.45042038], [69.70069885, 22.45042038], [69.70069885, 22.44958115], [69.70041656, 22.44958305], [69.70041656, 22.44874954], [69.69985962, 22.44874954], [69.69985962, 22.44791985], [69.70014191, 22.44791985], [69.70014191, 22.44763947], [69.70041656, 22.44763947], [69.70041656, 22.44708061], [69.70347595, 22.44708061], [69.70347595, 22.44736099], [69.70402527, 22.44736099], [69.70402527, 22.44763947], [69.70430756, 22.44763947], [69.70430756, 22.44820023], [69.70458221, 22.44820023], [69.70458221, 22.44874954], [69.70485687, 22.44874954], [69.70485687, 22.44902992], [69.70513916, 22.44902611], [69.70513916, 22.44958305], [69.70540619, 22.44958115], [69.70540619, 22.45013809], [69.70569611, 22.45013809], [69.70569611, 22.45126152], [69.70597076, 22.45124817], [69.70597076, 22.45208359], [69.70625305, 22.45207977], [69.70625305, 22.45235825], [69.70652771, 22.45235825], [69.70652771, 22.45292091], [69.70680237, 22.4529171], [69.70680237, 22.45319366], [69.70708466, 22.45319366], [69.70708466, 22.45347023], [69.70735931, 22.45346832], [69.70735931, 22.45402908], [69.7076416, 22.45402718], [69.7076416, 22.45458412], [69.70791626, 22.45458031], [69.70791626, 22.45486259], [69.70819092, 22.45486259], [69.70819092, 22.45514107], [69.70847321, 22.45514107], [69.70847321, 22.45541954], [69.70874786, 22.45541573], [69.70874786, 22.4556942], [69.70903015, 22.4556942], [69.70903015, 22.45597267], [69.70929718, 22.45597267], [69.70929718, 22.45625114], [69.7095871, 22.45625114], [69.7095871, 22.45681], [69.70986176, 22.45680618], [69.70986176, 22.45708275], [69.7104187, 22.4570694], [69.7104187, 22.45736122], [69.71069336, 22.45736122], [69.71069336, 22.45763969], [69.71098328, 22.45763969], [69.71098328, 22.45792007], [69.71152496, 22.45791626], [69.71152496, 22.45819473], [69.71180725, 22.45819473], [69.71180725, 22.4584713], [69.71208191, 22.45846939], [69.71208191, 22.45874977], [69.71235657, 22.45874977], [69.71235657, 22.45903015], [69.71291351, 22.45902824], [69.71291351, 22.45930481], [69.71347046, 22.45930481], [69.71347046, 22.45958328], [69.7140274, 22.45958328], [69.7140274, 22.45986176], [69.71430206, 22.45985985], [69.71430206, 22.46014023], [69.71485901, 22.46014023], [69.71485901, 22.46042061], [69.71541595, 22.46042061], [69.71541595, 22.46070099], [69.71652985, 22.46069527], [69.71652985, 22.46097183], [69.71736145, 22.46096992], [69.71736145, 22.46125031], [69.71848297, 22.46125031], [69.71848297, 22.46153069], [69.7195816, 22.46153069], [69.7195816, 22.46181107], [69.72041321, 22.46180534], [69.72041321, 22.46208382], [69.7206955, 22.46208382], [69.7206955, 22.46236038], [69.72097015, 22.46236038], [69.72097015, 22.46264076], [69.7215271, 22.46264076], [69.7215271, 22.46292114], [69.72207642, 22.46292114], [69.72207642, 22.46319962], [69.7223587, 22.46319962], [69.7223587, 22.46375084], [69.72264099, 22.46375084], [69.72264099, 22.46458244], [69.7251358, 22.46458054], [69.7251358, 22.46541977], [69.72541809, 22.46541977], [69.72541809, 22.46681023], [69.72458649, 22.46680641], [69.72458649, 22.46708107], [69.72374725, 22.46708107], [69.72374725, 22.46736145], [69.72292328, 22.46736145], [69.72292328, 22.46764183], [69.72264099, 22.46763992], [69.72264099, 22.46846962], [69.7223587, 22.46846962], [69.7223587, 22.46875191], [69.72264099, 22.46875191], [69.72264099, 22.46903038], [69.72319794, 22.46902847], [69.72319794, 22.46930504], [69.7234726, 22.46930504], [69.7234726, 22.46958351], [69.72402954, 22.46958351], [69.72402954, 22.46986389], [69.72458649, 22.46986008], [69.72458649, 22.47042084], [69.7251358, 22.47041702], [69.7251358, 22.47069359], [69.72541809, 22.47069359], [69.72541809, 22.47097206], [69.72569275, 22.47097015], [69.72569275, 22.47125053], [69.72598267, 22.47125053], [69.72598267, 22.47153091], [69.72624969, 22.47153091], [69.72624969, 22.47180939], [69.72652435, 22.47180557], [69.72652435, 22.47208595], [69.72680664, 22.47208023], [69.72680664, 22.47236061], [69.7270813, 22.47236061], [69.7270813, 22.47264099], [69.72736359, 22.47263908], [69.72736359, 22.47319412], [69.7279129, 22.47319412], [69.7279129, 22.4734726], [69.72820282, 22.47347069], [69.72820282, 22.47375107], [69.72902679, 22.47375107], [69.72902679, 22.47402954], [69.72930908, 22.47402954], [69.72930908, 22.47375107], [69.72957611, 22.47375107], [69.72957611, 22.47402954], [69.73014069, 22.47402954], [69.73014069, 22.47375107], [69.73069763, 22.47375107], [69.73069763, 22.47347069], [69.73097229, 22.4734726], [69.73097229, 22.47319412], [69.73124695, 22.47319412], [69.73124695, 22.47236061], [69.73152924, 22.47236061], [69.73152924, 22.47208023], [69.73180389, 22.47208595], [69.73180389, 22.47180557], [69.73208618, 22.47180939], [69.73208618, 22.47153091], [69.73236084, 22.47153091], [69.73236084, 22.47125053], [69.73264313, 22.47125053], [69.7326355, 22.47069359], [69.73291779, 22.47069359], [69.73291779, 22.47041702], [69.73374176, 22.47042084], [69.73374176, 22.47014046], [69.73401642, 22.47014046], [69.73401642, 22.46986008], [69.73430634, 22.46986389], [69.73430634, 22.46958351], [69.73486328, 22.46958351], [69.73486328, 22.46930504], [69.73542023, 22.46930504], [69.73542023, 22.46902847], [69.73568726, 22.46903038], [69.73568726, 22.46875191], [69.73596954, 22.46875191], [69.73596954, 22.4679203], [69.73625183, 22.4679203], [69.73625183, 22.46707916], [69.73652649, 22.46708107], [69.73652649, 22.46625137], [69.73680878, 22.46625137], [69.73680878, 22.4659729], [69.73708344, 22.4659729], [69.73708344, 22.46569443], [69.73735809, 22.46569443], [69.73735809, 22.46541595], [69.73764038, 22.46541977], [69.73764038, 22.46458054], [69.73791504, 22.46458244], [69.73791504, 22.46347237], [69.73819733, 22.46347237], [69.73819733, 22.46319389], [69.73847198, 22.46319962], [69.73847198, 22.46264076], [69.73874664, 22.46264076], [69.73874664, 22.46153069], [69.73902893, 22.46153069], [69.73902893, 22.46070099], [69.73929596, 22.46070099], [69.73929596, 22.46042061], [69.73958588, 22.46042061], [69.73958588, 22.45957947], [69.73986053, 22.45958328], [69.73986053, 22.45930481], [69.74013519, 22.45930481], [69.74013519, 22.45902824], [69.74041748, 22.45903015], [69.74041748, 22.45819283], [69.74069214, 22.45819473], [69.74069214, 22.45736122], [69.74085999, 22.45736122], [69.74097443, 22.45736122], [69.7409668, 22.45486259], [69.74069214, 22.45486259], [69.74069214, 22.4529171], [69.74041748, 22.45292091], [69.74041748, 22.45264053], [69.74014282, 22.45264053], [69.74014282, 22.44902992], [69.73986816, 22.44902992], [69.73986816, 22.44847107], [69.73764038, 22.44847298], [69.73764038, 22.4481945], [69.73735809, 22.44820023], [69.73735809, 22.44791985], [69.73764038, 22.44791985], [69.73764038, 22.44763947], [69.73792267, 22.44763947], [69.73791504, 22.44736099], [69.73819733, 22.44736099], [69.73819733, 22.44652939], [69.73847198, 22.44652939], [69.73847198, 22.44597054], [69.73819733, 22.44597244], [69.73819733, 22.44569588], [69.73791504, 22.44569588], [69.73791504, 22.4454174], [69.73735809, 22.44542122], [69.73735809, 22.44512939], [69.73708344, 22.44513893], [69.73708344, 22.44486046], [69.73652649, 22.44486046], [69.73652649, 22.44458008], [69.73542023, 22.44458389], [69.73542023, 22.44430542], [69.73486328, 22.44431114], [69.73486328, 22.44375038], [69.73513794, 22.44375038], [69.73513794, 22.44347191], [69.73795319, 22.44347382], [69.73819733, 22.44347382], [69.73819733, 22.44319534], [69.73874664, 22.44320107], [69.73874664, 22.44292068], [69.73929596, 22.44292068], [69.73929596, 22.44096947], [69.73958588, 22.44096947], [69.73958588, 22.44014168], [69.74069214, 22.44014168], [69.74069214, 22.43985939], [69.74153137, 22.43985939], [69.74153137, 22.43958282], [69.74236298, 22.43958282], [69.74236298, 22.43930626], [69.74263763, 22.43931961], [69.74263763, 22.43708038], [69.74375153, 22.4370842], [69.74375153, 22.43652725], [69.74402618, 22.43653107], [69.74402618, 22.43625832], [69.74430847, 22.43625832], [69.74430847, 22.43542099], [69.74458313, 22.43542099], [69.74458313, 22.43514061], [69.74485779, 22.43514061], [69.74485779, 22.43486023], [69.74514008, 22.43486023], [69.74514008, 22.43457985], [69.74569702, 22.43458366], [69.74569702, 22.43430519], [69.74597168, 22.43431091], [69.74597168, 22.43375015], [69.74624634, 22.43375015], [69.74624634, 22.43264008], [69.74597168, 22.43264008], [69.74597168, 22.4323597], [69.74569702, 22.4323616], [69.74569702, 22.43180466], [69.74514008, 22.43180466], [69.74514008, 22.43152809], [69.74485779, 22.43153], [69.74485779, 22.43124962], [69.74458313, 22.43124962], [69.74458313, 22.43069267], [69.74485779, 22.43069458], [69.74485779, 22.43041611], [69.74569702, 22.43041992], [69.74569702, 22.42986107], [69.74597168, 22.42986107], [69.74597168, 22.42930984], [69.74624634, 22.42930984], [69.74624634, 22.42902946], [69.74680328, 22.42902946], [69.74680328, 22.42930984], [69.74764252, 22.42930603], [69.74764252, 22.4295826], [69.74819183, 22.4295826], [69.74819183, 22.42986107], [69.74874878, 22.42986107], [69.74874878, 22.43013954], [69.74903107, 22.43013954], [69.74903107, 22.42986107], [69.74931335, 22.42986107], [69.74930573, 22.42902756], [69.74958038, 22.42902946], [69.74958038, 22.4287529], [69.74986267, 22.4287529], [69.74986267, 22.42819023], [69.75013733, 22.42819405], [69.75013733, 22.42791748], [69.75041962, 22.42791939], [69.75041962, 22.42764282], [69.75068665, 22.42764282], [69.75068665, 22.42735863], [69.75263977, 22.42735863], [69.75263977, 22.42708969], [69.75319672, 22.42708969], [69.75319672, 22.42680931], [69.75347137, 22.42680931], [69.75347137, 22.42653084], [69.75402832, 22.42653084], [69.75402832, 22.42624855], [69.75430298, 22.42624855], [69.75430298, 22.42596817], [69.75514221, 22.42596817], [69.75514221, 22.42624855], [69.75569153, 22.42624855], [69.75569153, 22.42653084], [69.75596619, 22.42653084], [69.75596619, 22.42735863], [69.75569153, 22.42735863], [69.75569153, 22.43013954], [69.75541687, 22.43013954], [69.75541687, 22.43180466], [69.75569153, 22.43180466], [69.75569153, 22.43208313], [69.75597382, 22.43208313], [69.75597382, 22.43347168], [69.75624847, 22.43347168], [69.75624847, 22.43458366], [69.75653076, 22.43458366], [69.75653076, 22.43569374], [69.75681305, 22.43568993], [69.75681305, 22.43680954], [69.75708008, 22.43680954], [69.75708008, 22.43764114], [69.75736237, 22.43764114], [69.75736237, 22.43791962], [69.75763702, 22.43791962], [69.75763702, 22.43931961], [69.75791168, 22.43931961], [69.75791168, 22.44042015], [69.75818634, 22.44042015], [69.75818634, 22.44153023], [69.75875092, 22.44152832], [69.75875092, 22.44180489], [69.75902557, 22.44180489], [69.75902557, 22.44152832], [69.75958252, 22.44153023], [69.75958252, 22.44125175], [69.75985718, 22.44125175], [69.75985718, 22.44096947], [69.76013947, 22.44096947], [69.76013947, 22.44069481], [69.76041412, 22.44069481], [69.76041412, 22.44041634], [69.76069641, 22.44042015], [69.76069641, 22.43985939], [69.76097107, 22.43985939], [69.76097107, 22.43902969], [69.76125336, 22.43902969], [69.76125336, 22.43764114], [69.76152802, 22.43764114], [69.76152802, 22.43597031], [69.76180267, 22.43597221], [69.76180267, 22.43263817], [69.76207733, 22.43264008], [69.76207733, 22.43208122], [69.76235962, 22.43208313], [69.76235962, 22.43180466], [69.76264191, 22.43180466], [69.76264191, 22.43152809], [69.76291656, 22.43153], [69.76291656, 22.43124962], [69.76319122, 22.43124962], [69.76319122, 22.43097115], [69.76347351, 22.43097305], [69.76347351, 22.43069458], [69.76374817, 22.43069458], [69.76374817, 22.43041611], [69.76403809, 22.43041992], [69.76403809, 22.43013191], [69.76430511, 22.43013954], [69.76430511, 22.42986107], [69.76457977, 22.42986107], [69.76457977, 22.4295826], [69.76486206, 22.4295826], [69.76486206, 22.42930603], [69.76513672, 22.42930984], [69.76513672, 22.42902946], [69.76568604, 22.42902946], [69.76568604, 22.4287529], [69.76597595, 22.4287529], [69.76597595, 22.42847252], [69.76625061, 22.42847252], [69.76625061, 22.42791748], [69.7665329, 22.42791939], [69.7665329, 22.42764282], [69.76680756, 22.42764282], [69.76680756, 22.42735863], [69.76708221, 22.42735863], [69.76708221, 22.42708969], [69.76735687, 22.42708969], [69.76735687, 22.42680931], [69.76819611, 22.42680931], [69.76819611, 22.42653084], [69.76847076, 22.42653084], [69.76847076, 22.42624855], [69.76875305, 22.42624855], [69.76875305, 22.42596817], [69.76930237, 22.42597008], [69.76930237, 22.42569351], [69.76958466, 22.42569351], [69.76958466, 22.42541885], [69.76985168, 22.42542076], [69.76985168, 22.42514038], [69.77041626, 22.42514038], [69.77041626, 22.42485809], [69.77069092, 22.42486191], [69.77069092, 22.42458344], [69.77097321, 22.42458344], [69.77097321, 22.42430496], [69.77153015, 22.42432022], [69.77153015, 22.4240303], [69.77179718, 22.4240303], [69.77179718, 22.42374992], [69.7720871, 22.42374992], [69.7720871, 22.42346954], [69.77263641, 22.42347145], [69.77263641, 22.42319489], [69.7729187, 22.42319489], [69.7729187, 22.42291641], [69.77319336, 22.42292023], [69.77319336, 22.42263985], [69.77348328, 22.42263985], [69.77348328, 22.42181015], [69.77375031, 22.42181015], [69.77375031, 22.42152977], [69.77403259, 22.42152977], [69.77403259, 22.42124939], [69.77430725, 22.42124939], [69.77430725, 22.42041969], [69.77458191, 22.42041969], [69.77458191, 22.41958046], [69.7748642, 22.41958237], [69.7748642, 22.41875076], [69.77513885, 22.41875076], [69.77513885, 22.41847038], [69.77597046, 22.41847229], [69.77597046, 22.41819382], [69.77625275, 22.41819382], [69.77625275, 22.41791725], [69.7765274, 22.41792107], [69.7765274, 22.41764069], [69.77680206, 22.41764069], [69.77680206, 22.41736031], [69.77707672, 22.41736031], [69.77707672, 22.41708183], [69.7776413, 22.41708374], [69.7776413, 22.41680527], [69.77791595, 22.4168129], [69.77791595, 22.41597176], [69.77819061, 22.41597366], [69.77819824, 22.41430473], [69.7784729, 22.41430473], [69.7784729, 22.41402817], [69.77874756, 22.41403008], [69.77874756, 22.41319084], [69.77902985, 22.41319466], [69.77902985, 22.41263771], [69.7793045, 22.41263771], [69.77929688, 22.41235924], [69.77986145, 22.41235924], [69.77986145, 22.41208839], [69.78151703, 22.41208839], [69.78151703, 22.41180992], [69.78235626, 22.41180992], [69.78235626, 22.41152954], [69.78320313, 22.41152954], [69.78320313, 22.41124916], [69.7840271, 22.41124916], [69.7840271, 22.41097069], [69.78430176, 22.4109726], [69.78430176, 22.41069412], [69.78458405, 22.41069412], [69.78458405, 22.41041946], [69.78485107, 22.41041946], [69.78485107, 22.41014099], [69.78514099, 22.41014099], [69.78514099, 22.40818977], [69.78541565, 22.40819359], [69.78541565, 22.40791512], [69.7859726, 22.40792084], [69.7859726, 22.40764046], [69.78679657, 22.40764046], [69.78679657, 22.40792084], [69.78736115, 22.40791512], [69.78736115, 22.40819359], [69.7876358, 22.40819359], [69.7876358, 22.40847206], [69.78791809, 22.40847015], [69.78791809, 22.40875053], [69.78930664, 22.40875053], [69.78930664, 22.40818977], [69.78902435, 22.40819359], [69.78902435, 22.40791512], [69.78874969, 22.40792084], [69.78874969, 22.40764046], [69.78848267, 22.40764046], [69.78848267, 22.4070797], [69.78819275, 22.40708351], [69.78819275, 22.40652847], [69.78848267, 22.40653038], [69.78848267, 22.40625], [69.78819275, 22.40625], [69.78819275, 22.40570068], [69.78901672, 22.40570068], [69.78901672, 22.4054203], [69.7895813, 22.4054203], [69.7895813, 22.40513992], [69.7904129, 22.40513992], [69.7904129, 22.40485954], [69.79125214, 22.40486145], [69.79125214, 22.40458488], [69.79180908, 22.40458488], [69.79180908, 22.40430641], [69.79207611, 22.40431023], [69.79207611, 22.40402985], [69.7923584, 22.40402985], [69.7923584, 22.40374947], [69.79264069, 22.40374947], [69.79264069, 22.4034729], [69.79360962, 22.4034729], [69.79458618, 22.4034729], [69.79458618, 22.40374947], [69.79486084, 22.40374947], [69.79486084, 22.40402985], [69.79569244, 22.40402985], [69.79569244, 22.40374947], [69.79624939, 22.40374947], [69.79624939, 22.40263939], [69.79651642, 22.40263939], [69.79651642, 22.40097237], [69.79680634, 22.40097237], [69.79680634, 22.40014076], [69.79708099, 22.4001503], [69.79708099, 22.39985847], [69.79763794, 22.39985847], [69.79763794, 22.4001503], [69.79792023, 22.4001503], [69.79792023, 22.40041924], [69.79819489, 22.40041733], [69.79819489, 22.40097237], [69.79846954, 22.40097237], [69.79846954, 22.40125275], [69.79875183, 22.40125275], [69.79875183, 22.40153122], [69.79902649, 22.4015274], [69.79902649, 22.40208244], [69.79930878, 22.40208244], [69.79930878, 22.40374947], [69.79957581, 22.40374947], [69.79957581, 22.40402985], [69.79985809, 22.40402985], [69.79985809, 22.40431023], [69.80041504, 22.40430641], [69.80041504, 22.40458488], [69.80124664, 22.40458488], [69.80124664, 22.40486145], [69.80152893, 22.40485954], [69.80152893, 22.40513992], [69.80208588, 22.40513992], [69.80208588, 22.40485954], [69.80347443, 22.40486145], [69.80347443, 22.40458488], [69.80458069, 22.40458488], [69.80458069, 22.40430641], [69.80486298, 22.40431023], [69.80486298, 22.40402985], [69.80541992, 22.40402985], [69.80541992, 22.40374947], [69.80568695, 22.40374947], [69.80568695, 22.40402985], [69.80596161, 22.40402985], [69.80596161, 22.40431023], [69.80625153, 22.40430641], [69.80625153, 22.40458488], [69.80647278, 22.40458488], [69.80680847, 22.40458488], [69.80680847, 22.40486145], [69.80708313, 22.40486145], [69.80708313, 22.40597153], [69.8079071, 22.40596008], [69.8079071, 22.40625], [69.80819702, 22.40625], [69.80819702, 22.40653038], [69.80847168, 22.40653038], [69.80847168, 22.40681076], [69.80874634, 22.40680695], [69.80874634, 22.40736198], [69.809021, 22.40736008], [69.809021, 22.40764046], [69.80930328, 22.40764046], [69.80930328, 22.40792084], [69.80958557, 22.40791512], [69.80958557, 22.40819359], [69.80986023, 22.40819359], [69.80986023, 22.40847206], [69.81014252, 22.40847206], [69.81014252, 22.40819359], [69.81069183, 22.40819359], [69.81069183, 22.40847206], [69.81097412, 22.40847206], [69.81097412, 22.40902519], [69.81069183, 22.40901947], [69.81069183, 22.40986061], [69.81096649, 22.40986061], [69.81096649, 22.41041946], [69.81124878, 22.41041946], [69.81124878, 22.41124916], [69.81153107, 22.41124916], [69.81153107, 22.41292191], [69.81180573, 22.41291618], [69.81180573, 22.41347313], [69.81208038, 22.41347313], [69.81208038, 22.4137516], [69.81236267, 22.4137516], [69.81236267, 22.41430473], [69.81291962, 22.41430473], [69.81291962, 22.41458321], [69.81375122, 22.41458321], [69.81375122, 22.41486168], [69.81430817, 22.41486168], [69.81430817, 22.41514969], [69.81485748, 22.41514969], [69.81485748, 22.41542053], [69.8151474, 22.41542053], [69.8151474, 22.41570282], [69.81541443, 22.41569519], [69.81541443, 22.41597366], [69.81569672, 22.41597176], [69.81569672, 22.4168129], [69.81597137, 22.41680527], [69.81597137, 22.41708374], [69.81624603, 22.41708183], [69.81624603, 22.41736031], [69.81652832, 22.41736031], [69.81652832, 22.41764069], [69.81680298, 22.41764069], [69.81680298, 22.41792107], [69.81708527, 22.41791725], [69.81708527, 22.41819382], [69.81764221, 22.41819], [69.81764221, 22.41930962], [69.81791687, 22.41930962], [69.81791687, 22.41986084], [69.81819153, 22.41986084], [69.81819153, 22.42041969], [69.81846619, 22.42041969], [69.81846619, 22.42152977], [69.81874847, 22.42152977], [69.81874847, 22.42181015], [69.81847382, 22.42180634], [69.81847382, 22.42236137], [69.81819153, 22.42235947], [69.81819153, 22.42263985], [69.81791687, 22.42263985], [69.81791687, 22.42292023], [69.81735992, 22.42291641], [69.81735992, 22.42347145], [69.81819153, 22.42347145], [69.81819153, 22.42319489], [69.81874847, 22.42319489], [69.81874847, 22.42291641], [69.81958008, 22.42291641], [69.81958008, 22.42347145], [69.81986237, 22.42346954], [69.81986237, 22.42542076], [69.82069397, 22.42541885], [69.82069397, 22.42569351], [69.82096863, 22.42569351], [69.82096863, 22.42597008], [69.82125092, 22.42596817], [69.82125092, 22.42624855], [69.82180786, 22.42624855], [69.82180786, 22.42653084], [69.82208252, 22.42653084], [69.82208252, 22.42680931], [69.82235718, 22.42680931], [69.82235718, 22.42708969], [69.82263947, 22.42708969], [69.82263947, 22.42735863], [69.82291412, 22.42735863], [69.82291412, 22.42847252], [69.82319641, 22.42847252], [69.82319641, 22.42930984], [69.82347107, 22.42930984], [69.82347107, 22.43041992], [69.82375336, 22.43041611], [69.82375336, 22.43097305], [69.82402802, 22.43097305], [69.82402802, 22.43208313], [69.82375336, 22.43208122], [69.82375336, 22.43264008], [69.82347107, 22.43263817], [69.82347107, 22.43319321], [69.82319641, 22.43318939], [69.82319641, 22.43403053], [69.82291412, 22.43402863], [69.82291412, 22.43458366], [69.82263947, 22.43457985], [69.82263947, 22.43514061], [69.82290649, 22.43514061], [69.82290649, 22.43542099], [69.82319641, 22.43541527], [69.82319641, 22.43569374], [69.82347107, 22.43569374], [69.82347107, 22.43597221], [69.82375336, 22.43597031], [69.82375336, 22.43653107], [69.82402802, 22.43653107], [69.82402802, 22.43680954], [69.82430267, 22.43680954], [69.82430267, 22.43764114], [69.82457733, 22.43764114], [69.82457733, 22.43791962], [69.82485962, 22.43791962], [69.82485962, 22.43902969], [69.82514191, 22.43902969], [69.82514191, 22.43958282], [69.82569122, 22.43958282], [69.82569122, 22.43930626], [69.82597351, 22.43930626], [69.82597351, 22.43958282], [69.82624817, 22.43958282], [69.82624817, 22.43985939], [69.82680511, 22.43985939], [69.82680511, 22.44014168], [69.8270874, 22.44014168], [69.8270874, 22.44042015], [69.82736206, 22.44041634], [69.82736206, 22.44069481], [69.82763672, 22.44068909], [69.82763672, 22.44125175], [69.82791901, 22.44125175], [69.82791901, 22.44153023], [69.82819366, 22.44152832], [69.82819366, 22.44208336], [69.82847595, 22.4420681], [69.82847595, 22.4426403], [69.82875061, 22.4426403], [69.82875061, 22.44292068], [69.82902527, 22.44291687], [69.8290329, 22.44486046], [69.82875061, 22.44486046], [69.82875061, 22.44542122], [69.82847595, 22.44542122], [69.82847595, 22.44625092], [69.82818604, 22.44625092], [69.82818604, 22.44680977], [69.82791901, 22.44680405], [69.82791901, 22.44708252], [69.82736206, 22.44708061], [69.82736206, 22.44763947], [69.8270874, 22.44763947], [69.8270874, 22.44791985], [69.82681274, 22.44791985], [69.82681274, 22.44820023], [69.82653046, 22.4481945], [69.82653046, 22.44847298], [69.82596588, 22.44847107], [69.82596588, 22.44874954], [69.82569122, 22.44874954], [69.82569122, 22.44902992], [69.82514191, 22.44902992], [69.82514191, 22.4493103], [69.82458496, 22.44930649], [69.82458496, 22.44958305], [69.82430267, 22.44958305], [69.82430267, 22.44986153], [69.82347107, 22.44985962], [69.82347107, 22.45013809], [69.82319641, 22.45013809], [69.82319641, 22.45042038], [69.82263947, 22.45042038], [69.82263947, 22.45070076], [69.82180786, 22.45069504], [69.82180786, 22.4509716], [69.82125092, 22.4509697], [69.82125092, 22.45126152], [69.82041931, 22.45126152], [69.82041931, 22.45153046], [69.81958008, 22.45153046], [69.81958008, 22.45181084], [69.81903076, 22.45180511], [69.81903076, 22.45208359], [69.81819153, 22.45208359], [69.81819153, 22.45236206], [69.81764221, 22.45235825], [69.81764221, 22.45264053], [69.81680298, 22.45264053], [69.81680298, 22.45292091], [69.81597137, 22.4529171], [69.81597137, 22.45319366], [69.81541443, 22.45319366], [69.81541443, 22.45347023], [69.81458282, 22.45346832], [69.81458282, 22.45375061], [69.81402588, 22.45375061], [69.81402588, 22.45402908], [69.81319427, 22.45402718], [69.81319427, 22.45430565], [69.81263733, 22.45430565], [69.81263733, 22.45458412], [69.81180573, 22.45458412], [69.81181335, 22.45486259], [69.81124878, 22.45486259], [69.81124878, 22.45514107], [69.81041718, 22.45514107], [69.81041718, 22.45541954], [69.80986023, 22.45541763], [69.80986023, 22.4556942], [69.80930328, 22.4556942], [69.80930328, 22.45597267], [69.80847168, 22.45597267], [69.80847168, 22.45625114], [69.8079071, 22.45625114], [69.8079071, 22.45652962], [69.80735779, 22.45652962], [69.80735779, 22.45681], [69.80652618, 22.45680618], [69.80652618, 22.45708275], [69.80596161, 22.4570694], [69.80596161, 22.45736122], [69.80513763, 22.45736122], [69.80513763, 22.45763969], [69.80319214, 22.45763969], [69.80319214, 22.45736122], [69.80152893, 22.45736122], [69.80152893, 22.4570694], [69.80069733, 22.45708275], [69.80069733, 22.45680618], [69.79957581, 22.45681], [69.79957581, 22.45652962], [69.79875183, 22.45652962], [69.79875183, 22.45569038], [69.79763794, 22.4556942], [69.79763794, 22.45597267], [69.79736328, 22.45597267], [69.79736328, 22.45652962], [69.79708099, 22.45652771], [69.79708099, 22.45708275], [69.79763794, 22.4570694], [69.79763794, 22.45736122], [69.79875183, 22.45736122], [69.79875183, 22.45763969], [69.80014038, 22.45763969], [69.80014038, 22.45792007], [69.80124664, 22.45791626], [69.80124664, 22.45819473], [69.80263519, 22.45819473], [69.80263519, 22.4584713], [69.80374908, 22.45846939], [69.80374908, 22.45874977], [69.80513763, 22.45874977], [69.80513763, 22.45846939], [69.80569458, 22.4584713], [69.80569458, 22.45819473], [69.80625153, 22.45819473], [69.80625153, 22.45791626], [69.80680847, 22.45792007], [69.80680847, 22.45763969], [69.80735779, 22.45763969], [69.80735779, 22.45736122], [69.80819702, 22.45736122], [69.80819702, 22.4570694], [69.80874634, 22.45708275], [69.80874634, 22.45680618], [69.80930328, 22.45681], [69.80930328, 22.45652962], [69.80986023, 22.45652962], [69.80986023, 22.45625114], [69.81069183, 22.45625114], [69.81069183, 22.45597267], [69.81124878, 22.45597267], [69.81124878, 22.4556942], [69.81180573, 22.4556942], [69.81180573, 22.45541573], [69.81263733, 22.45541954], [69.81263733, 22.45514107], [69.81318665, 22.45514107], [69.81318665, 22.45486259], [69.81402588, 22.45486259], [69.81402588, 22.45458031], [69.81485748, 22.45458412], [69.81485748, 22.45430565], [69.81541443, 22.45430565], [69.81541443, 22.45402718], [69.81624603, 22.45402908], [69.81624603, 22.45375061], [69.8170929, 22.45375061], [69.81708527, 22.45347023], [69.81791687, 22.45347023], [69.81791687, 22.45319366], [69.81847382, 22.45319366], [69.81847382, 22.4529171], [69.81931305, 22.45292091], [69.81931305, 22.45264053], [69.81986237, 22.45264053], [69.81986237, 22.45235825], [69.82069397, 22.45235825], [69.82068634, 22.45207977], [69.82125092, 22.45207977], [69.82125092, 22.45264053], [69.8215332, 22.45264053], [69.8215332, 22.45292091], [69.82180786, 22.4529171], [69.82180786, 22.45319366], [69.82208252, 22.45318985], [69.82208252, 22.45402908], [69.82235718, 22.45402908], [69.82235718, 22.45514107], [69.82263947, 22.45513916], [69.82263947, 22.4556942], [69.82319641, 22.4556942], [69.82319641, 22.45597267], [69.82347107, 22.45597267], [69.82347107, 22.45652962], [69.82375336, 22.45652962], [69.82375336, 22.45681], [69.82402802, 22.45680618], [69.82402802, 22.45708275], [69.82430267, 22.4570694], [69.82430267, 22.45736122], [69.82485962, 22.45736122], [69.82485962, 22.45763969], [69.82514191, 22.45763969], [69.82514191, 22.45792007], [69.82707977, 22.45791626], [69.82707977, 22.45819473], [69.82763672, 22.45819473], [69.82763672, 22.45652771], [69.82736206, 22.45652962], [69.82736206, 22.45597267], [69.82763672, 22.45597267], [69.82763672, 22.4556942], [69.82819366, 22.4556942], [69.82819366, 22.45375061], [69.82847595, 22.45375061], [69.82847595, 22.45153046], [69.8290329, 22.45153046], [69.8290329, 22.4509697], [69.82930756, 22.4509716], [69.82930756, 22.45069504], [69.82958221, 22.45070076], [69.82958221, 22.45013809], [69.82985687, 22.45013809], [69.82985687, 22.44985962], [69.83069611, 22.44986153], [69.83069611, 22.4509716], [69.8326416, 22.4509716], [69.8326416, 22.45208359], [69.83291626, 22.45207977], [69.83291626, 22.45235825], [69.83319092, 22.45235825], [69.83319092, 22.45264053], [69.83347321, 22.45264053], [69.83347321, 22.45292091], [69.83374786, 22.4529171], [69.83374786, 22.45319366], [69.83429718, 22.45318985], [69.83429718, 22.45402908], [69.8345871, 22.45402908], [69.8345871, 22.45541954], [69.83429718, 22.45541954], [69.83429718, 22.45652962], [69.83403015, 22.45652771], [69.83403015, 22.45708275], [69.83347321, 22.4570694], [69.83347321, 22.45792007], [69.83430481, 22.45791626], [69.83430481, 22.45930481], [69.8345871, 22.4593029], [69.8345871, 22.46764183], [69.83486176, 22.46763992], [69.83486176, 22.47097206], [69.83513641, 22.47097015], [69.83513641, 22.47291946], [69.83486176, 22.47291756], [69.83486176, 22.4734726], [69.8345871, 22.47347069], [69.8345871, 22.47375107], [69.83429718, 22.47375107], [69.83429718, 22.47430992], [69.83403015, 22.4743042], [69.83403015, 22.47458267], [69.83429718, 22.47458076], [69.83429718, 22.47486115], [69.8345871, 22.47486115], [69.8345871, 22.47542953], [69.8354187, 22.47542953], [69.8354187, 22.47513962], [69.83569336, 22.47513962], [69.83569336, 22.47458076], [69.83597565, 22.47458267], [69.83597565, 22.4743042], [69.83625031, 22.47430992], [69.83625031, 22.47236061], [69.83597565, 22.47236061], [69.83597565, 22.46430588], [69.83569336, 22.46430969], [69.83569336, 22.46014023], [69.8354187, 22.46014023], [69.8354187, 22.45792007], [69.83597565, 22.45791626], [69.83597565, 22.45819473], [69.83625031, 22.45819283], [69.83625031, 22.46014023], [69.83653259, 22.46014023], [69.83653259, 22.46292114], [69.83680725, 22.46291542], [69.83680725, 22.46458244], [69.83708191, 22.46458244], [69.83708191, 22.46625137], [69.83735657, 22.46623993], [69.83735657, 22.46820259], [69.83763885, 22.46819496], [69.83763885, 22.46986389], [69.83790588, 22.46986008], [69.83790588, 22.47180939], [69.8381958, 22.47180557], [69.8381958, 22.4734726], [69.83847046, 22.47347069], [69.83847046, 22.47513962], [69.83875275, 22.47513962], [69.83875275, 22.47708321], [69.8390274, 22.47707939], [69.8390274, 22.47874832], [69.83930206, 22.47874832], [69.83930206, 22.48069382], [69.83957672, 22.4806881], [69.83957672, 22.48236275], [69.83985901, 22.48236275], [69.83985901, 22.48402977], [69.8401413, 22.48402786], [69.8401413, 22.48597145], [69.84041595, 22.48596954], [69.84041595, 22.48764038], [69.84069824, 22.48763847], [69.84069824, 22.48958397], [69.8409729, 22.48958015], [69.8409729, 22.49124908], [69.84124756, 22.49124908], [69.84124756, 22.49292183], [69.84152985, 22.49292183], [69.84152985, 22.49403191], [69.84124756, 22.49402809], [69.84124756, 22.49430466], [69.8409729, 22.49430466], [69.8409729, 22.49458313], [69.84069824, 22.49458313], [69.84069824, 22.4948616], [69.84041595, 22.4948616], [69.84041595, 22.49514008], [69.8401413, 22.49514008], [69.8401413, 22.49542046], [69.83985901, 22.49542046], [69.83985901, 22.49570274], [69.83958435, 22.49569511], [69.83958435, 22.49597359], [69.83930206, 22.49597359], [69.83930206, 22.49625015], [69.8381958, 22.49624252], [69.8381958, 22.49681282], [69.83790588, 22.49681282], [69.83790588, 22.49736023], [69.83763885, 22.49736023], [69.83763885, 22.49764061], [69.83708191, 22.49764061], [69.83708191, 22.49736023], [69.83680725, 22.49736023], [69.83680725, 22.49764061], [69.83653259, 22.49764061], [69.83653259, 22.49792099], [69.83625031, 22.49791718], [69.83625031, 22.49819374], [69.83597565, 22.49819374], [69.83597565, 22.49847221], [69.83569336, 22.49847031], [69.83569336, 22.49875069], [69.8354187, 22.49875069], [69.8354187, 22.49903107], [69.83513641, 22.49903107], [69.83513641, 22.49930954], [69.83486176, 22.49930573], [69.83486176, 22.4995842], [69.8345871, 22.49958038], [69.8345871, 22.49986076], [69.83430481, 22.49986076], [69.83430481, 22.50069427], [69.83597565, 22.50069427], [69.83597565, 22.5004158], [69.83653259, 22.50041962], [69.83653259, 22.49958038], [69.83680725, 22.4995842], [69.83680725, 22.49930573], [69.83708191, 22.49930954], [69.83708191, 22.49903107], [69.83735657, 22.49903107], [69.83735657, 22.49875069], [69.83790588, 22.49875069], [69.83790588, 22.49847031], [69.83847046, 22.49847031], [69.83847046, 22.49875069], [69.8390274, 22.49875069], [69.8390274, 22.49847031], [69.83930206, 22.49847221], [69.83930206, 22.4976387], [69.83957672, 22.49764061], [69.83957672, 22.49736023], [69.8401413, 22.49736023], [69.8401413, 22.49707985], [69.84041595, 22.49708366], [69.84041595, 22.49680519], [69.8409729, 22.49681282], [69.8409729, 22.49597168], [69.84124756, 22.49597359], [69.84124756, 22.49569511], [69.84179688, 22.49570274], [69.84179688, 22.49542046], [69.84208679, 22.49542046], [69.84208679, 22.49514008], [69.84236145, 22.49514008], [69.84236145, 22.49542046], [69.84263611, 22.49542046], [69.84263611, 22.49514008], [69.8429184, 22.49514008], [69.8429184, 22.4948616], [69.84319305, 22.4948616], [69.84319305, 22.49430466], [69.8429184, 22.49430466], [69.8429184, 22.49402809], [69.84263611, 22.49403191], [69.84263611, 22.49292183], [69.84236145, 22.49292183], [69.84236145, 22.49124908], [69.84208679, 22.49124908], [69.84208679, 22.48958015], [69.8418045, 22.48958397], [69.8418045, 22.48847198], [69.84152985, 22.48847198], [69.84152985, 22.48819542], [69.84124756, 22.4881897], [69.84124756, 22.48430634], [69.8409729, 22.48430634], [69.8409729, 22.48236275], [69.84069824, 22.48236275], [69.84069061, 22.4806881], [69.84041595, 22.48069382], [69.84041595, 22.48041725], [69.8401413, 22.48041916], [69.8401413, 22.4798584], [69.84041595, 22.4798584], [69.84041595, 22.47930908], [69.8401413, 22.47930908], [69.8401413, 22.47707939], [69.83985901, 22.47708321], [69.83985901, 22.47541618], [69.83957672, 22.47542953], [69.83957672, 22.47375107], [69.83930206, 22.47375107], [69.83930206, 22.47180939], [69.8390274, 22.47180939], [69.8390274, 22.47014046], [69.83875275, 22.47014046], [69.83875275, 22.46846962], [69.83847046, 22.46846962], [69.83847046, 22.46625137], [69.8381958, 22.46625137], [69.8381958, 22.46486092], [69.83790588, 22.46486092], [69.83790588, 22.46264076], [69.83763885, 22.46264076], [69.83763885, 22.46125031], [69.83735657, 22.46125031], [69.83735657, 22.45957947], [69.83708191, 22.45958328], [69.83708191, 22.45819473], [69.83680725, 22.45819473], [69.83680725, 22.45708275], [69.83652496, 22.45708275], [69.83652496, 22.45513916], [69.83625031, 22.45514107], [69.83625031, 22.45402908], [69.83680725, 22.45402718], [69.83680725, 22.45458412], [69.83763885, 22.45458031], [69.83763885, 22.45486259], [69.83847046, 22.45486259], [69.83847046, 22.45458031], [69.83930206, 22.45458031], [69.83930206, 22.45486259], [69.83985901, 22.45486259], [69.83985901, 22.45514107], [69.84069824, 22.45513916], [69.84069824, 22.4556942], [69.8409729, 22.4556942], [69.8409729, 22.45597267], [69.8418045, 22.45597267], [69.8418045, 22.4556942], [69.84263611, 22.4556942], [69.84263611, 22.45541573], [69.84348297, 22.45541954], [69.84348297, 22.45514107], [69.84375, 22.45514107], [69.84375, 22.45486259], [69.84541321, 22.45486259], [69.84541321, 22.45429993], [69.8473587, 22.45430565], [69.8473587, 22.45458412], [69.84764099, 22.45458412], [69.84764099, 22.45430565], [69.84874725, 22.45430565], [69.84874725, 22.45402718], [69.84986115, 22.45402908], [69.84986115, 22.45375061], [69.85041809, 22.45375061], [69.85041809, 22.45346832], [69.85097504, 22.45347023], [69.85097504, 22.45319366], [69.85124969, 22.45319366], [69.85124969, 22.4529171], [69.85180664, 22.45292091], [69.85180664, 22.45264053], [69.85235596, 22.45264053], [69.85235596, 22.45207977], [69.85263824, 22.45208359], [69.85263824, 22.45180511], [69.85320282, 22.45181084], [69.85320282, 22.45153046], [69.85346985, 22.45153046], [69.85346985, 22.45126152], [69.85402679, 22.45126152], [69.85402679, 22.4509697], [69.85430908, 22.4509716], [69.85430908, 22.45069504], [69.8548584, 22.45070076], [69.8548584, 22.45042038], [69.85542297, 22.45042038], [69.85542297, 22.45013809], [69.85569763, 22.45013809], [69.85569763, 22.44985962], [69.85597229, 22.44986153], [69.85597229, 22.44958305], [69.85624695, 22.44958305], [69.85624695, 22.44930649], [69.85652924, 22.44930077], [69.85652924, 22.44902611], [69.85679626, 22.44902992], [69.85679626, 22.44874954], [69.85764313, 22.44874954], [69.8576355, 22.44847298], [69.85791779, 22.44847298], [69.85791779, 22.4481945], [69.85874939, 22.44820023], [69.85874939, 22.44791985], [69.85930634, 22.44791985], [69.85930634, 22.44763947], [69.85958099, 22.44763947], [69.85958099, 22.44736099], [69.86013031, 22.44736099], [69.86013031, 22.44708061], [69.86042023, 22.44708252], [69.86042023, 22.44680405], [69.86235809, 22.44680405], [69.86235809, 22.44708252], [69.86264038, 22.44708252], [69.86264038, 22.44680405], [69.86430359, 22.44680405], [69.86430359, 22.44708252], [69.86513519, 22.44708252], [69.86513519, 22.44736099], [69.86680603, 22.44736099], [69.86680603, 22.44708061], [69.86736298, 22.44708252], [69.86736298, 22.44680405], [69.86763763, 22.44680977], [69.86763763, 22.44652939], [69.87014008, 22.44652939], [69.87014008, 22.44680977], [69.87152863, 22.44680405], [69.87152863, 22.44708252], [69.87264252, 22.44708061], [69.87264252, 22.44736099], [69.87374878, 22.44736099], [69.87374878, 22.44820023], [69.87347412, 22.4481945], [69.87346649, 22.44930077], [69.87374878, 22.44930649], [69.87374878, 22.44958305], [69.87403107, 22.44958305], [69.87403107, 22.44930649], [69.87431335, 22.44930077], [69.87430573, 22.44874954], [69.87458038, 22.44874954], [69.87458038, 22.44820023], [69.87486267, 22.44820023], [69.87486267, 22.44791985], [69.87542725, 22.44791985], [69.87542725, 22.44820023], [69.87596893, 22.4481945], [69.87596893, 22.44847298], [69.87625122, 22.44847107], [69.87625122, 22.44874954], [69.87680817, 22.44874954], [69.87680817, 22.44902992], [69.87708282, 22.44902611], [69.87708282, 22.44930077], [69.87763977, 22.44930649], [69.87763977, 22.44958305], [69.87791443, 22.44958305], [69.87791443, 22.44986153], [69.87847137, 22.44985962], [69.87847137, 22.45013809], [69.87874603, 22.45013809], [69.87874603, 22.45042038], [69.87902832, 22.45042038], [69.87902832, 22.45070076], [69.87930298, 22.45069504], [69.87930298, 22.4509716], [69.8795929, 22.4509697], [69.8795929, 22.45126152], [69.87985992, 22.45126152], [69.87985992, 22.45181084], [69.88014221, 22.45180511], [69.88014221, 22.45208359], [69.88041687, 22.45207977], [69.88041687, 22.45235825], [69.88069153, 22.45235825], [69.88069153, 22.45264053], [69.88096619, 22.45264053], [69.88096619, 22.45292091], [69.88153076, 22.4529171], [69.88153076, 22.45319366], [69.88180542, 22.45319366], [69.88180542, 22.45347023], [69.88208008, 22.45346832], [69.88208008, 22.45375061], [69.88236237, 22.45375061], [69.88236237, 22.45402908], [69.88208008, 22.45402718], [69.88208008, 22.45430565], [69.88181305, 22.45429993], [69.88181305, 22.45541954], [69.88208008, 22.45541573], [69.88208008, 22.4556942], [69.88236237, 22.45569038], [69.88236237, 22.45625114], [69.88263702, 22.45625114], [69.88263702, 22.45652962], [69.88291931, 22.45652771], [69.88291931, 22.45708275], [69.88318634, 22.4570694], [69.88318634, 22.45763969], [69.88346863, 22.45763969], [69.88346863, 22.45792007], [69.88486481, 22.45791626], [69.88486481, 22.45819473], [69.88597107, 22.45819473], [69.88597107, 22.4584713], [69.88735962, 22.4584713], [69.88735962, 22.45874977], [69.88791656, 22.45874977], [69.88791656, 22.45903015], [69.88847351, 22.45902824], [69.88847351, 22.45930481], [69.88930511, 22.45930481], [69.88930511, 22.46097183], [69.88957977, 22.46096992], [69.88957977, 22.46125031], [69.89013672, 22.46125031], [69.89013672, 22.46153069], [69.89068604, 22.46153069], [69.89068604, 22.46181107], [69.89097595, 22.46181107], [69.89097595, 22.46236038], [69.89125061, 22.46236038], [69.89125061, 22.46292114], [69.8915329, 22.46292114], [69.8915329, 22.46319962], [69.89180756, 22.46319389], [69.89180756, 22.46347237], [69.89208221, 22.46347046], [69.89208221, 22.46375084], [69.89235687, 22.46375084], [69.89235687, 22.46403122], [69.89290619, 22.46403122], [69.89290619, 22.46430969], [69.89319611, 22.46430588], [69.89319611, 22.46458244], [69.89347076, 22.46458054], [69.89347076, 22.46486092], [69.89402771, 22.46486092], [69.89402771, 22.46513748], [69.89430237, 22.46513748], [69.89430237, 22.46541977], [69.8951416, 22.46541595], [69.8951416, 22.46569443], [69.89597321, 22.46569443], [69.89597321, 22.4659729], [69.8970871, 22.4659729], [69.8970871, 22.46625137], [69.89848328, 22.46623993], [69.89848328, 22.46653175], [69.89930725, 22.46652985], [69.89930725, 22.46736145], [69.89958191, 22.46736145], [69.89958191, 22.46764183], [69.90040588, 22.46764183], [69.90040588, 22.4679203], [69.90236664, 22.4679203], [69.90236664, 22.46764183], [69.90319824, 22.46764183], [69.90319824, 22.4679203], [69.90374756, 22.4679203], [69.90374756, 22.46736145], [69.9043045, 22.46736145], [69.9043045, 22.46708107], [69.90458679, 22.46708107], [69.90458679, 22.46680641], [69.90486145, 22.46681023], [69.90486145, 22.46623993], [69.9043045, 22.46625137], [69.9043045, 22.4659729], [69.90374756, 22.4659729], [69.90374756, 22.46430588], [69.90402985, 22.46430969], [69.90402985, 22.46403122], [69.90429688, 22.46403122], [69.90429688, 22.46319962], [69.90458679, 22.46319962], [69.90458679, 22.46292114], [69.90486145, 22.46292114], [69.90486145, 22.46264076], [69.90541077, 22.46264076], [69.90541077, 22.46292114], [69.90598297, 22.46292114], [69.90598297, 22.46264076], [69.90680695, 22.46264076], [69.90680695, 22.46236038], [69.90763855, 22.46236038], [69.90763855, 22.46208], [69.90791321, 22.46208382], [69.90791321, 22.46125031], [69.90763855, 22.46125031], [69.90763855, 22.46070099], [69.90735626, 22.46070099], [69.90735626, 22.46042061], [69.90791321, 22.46042061], [69.90791321, 22.46014023], [69.90820313, 22.46014023], [69.90820313, 22.45985985], [69.90847015, 22.45985985], [69.90847015, 22.46014023], [69.90875244, 22.46014023], [69.90875244, 22.45985985], [69.91014099, 22.45986176], [69.91014099, 22.45958328], [69.91041565, 22.45958328], [69.91041565, 22.45902824], [69.91069794, 22.45903015], [69.91069794, 22.45874977], [69.9109726, 22.45874977], [69.9109726, 22.45819283], [69.91124725, 22.45819473], [69.91124725, 22.45763969], [69.91152954, 22.45763969], [69.91152954, 22.45736122], [69.91179657, 22.45736122], [69.91179657, 22.4570694], [69.91208649, 22.45708275], [69.91208649, 22.45680618], [69.91236115, 22.45681], [69.91236115, 22.45652962], [69.9126358, 22.45652962], [69.9126358, 22.45625114], [69.91402435, 22.45624924], [69.91402435, 22.45708275], [69.91374969, 22.4570694], [69.91374969, 22.45736122], [69.91347504, 22.45736122], [69.91348267, 22.45763969], [69.91319275, 22.45763969], [69.91319275, 22.45792007], [69.91291809, 22.45791626], [69.91291809, 22.45819473], [69.9126358, 22.45819473], [69.9126358, 22.45930481], [69.91236115, 22.45930481], [69.91236115, 22.45986176], [69.91208649, 22.45985985], [69.91208649, 22.46014023], [69.9118042, 22.46013832], [69.9118042, 22.46097183], [69.91152954, 22.46097183], [69.91152954, 22.46208382], [69.91124725, 22.46208], [69.91124725, 22.46264076], [69.9109726, 22.46263885], [69.9109726, 22.46347237], [69.91069794, 22.46347046], [69.91069794, 22.46430969], [69.91042328, 22.46430969], [69.91042328, 22.46541977], [69.91014099, 22.46541595], [69.91014099, 22.46625137], [69.9098587, 22.46625137], [69.9098587, 22.46708107], [69.90957642, 22.46707916], [69.90957642, 22.4679203], [69.9098587, 22.4679203], [69.9098587, 22.46764183], [69.91014099, 22.46764183], [69.91014099, 22.46736145], [69.91041565, 22.46736145], [69.91041565, 22.46708107], [69.9109726, 22.46708107], [69.9109726, 22.46736145], [69.91124725, 22.46736145], [69.91124725, 22.46820259], [69.9109726, 22.46820259], [69.9109726, 22.47042084], [69.91124725, 22.47041702], [69.91124725, 22.47097206], [69.9109726, 22.47097015], [69.9109726, 22.47236061], [69.91069794, 22.47236061], [69.91069794, 22.47291946], [69.91041565, 22.47291756], [69.91041565, 22.47319412], [69.91014099, 22.47319031], [69.91014099, 22.47375107], [69.9098587, 22.47375107], [69.9098587, 22.47542953], [69.91014099, 22.47541618], [69.91014099, 22.47569466], [69.91069794, 22.47569466], [69.91069794, 22.47597313], [69.9109726, 22.47597122], [69.9109726, 22.47792053], [69.91124725, 22.47791672], [69.91124725, 22.47847176], [69.91152954, 22.47846985], [69.91152954, 22.47874832], [69.91179657, 22.47874832], [69.91179657, 22.47930908], [69.91208649, 22.47930527], [69.91208649, 22.48069382], [69.91179657, 22.4806881], [69.91179657, 22.48291969], [69.91208649, 22.48291969], [69.91208649, 22.48513985], [69.91236115, 22.48513985], [69.91236115, 22.4865303], [69.9126358, 22.4865284], [69.9126358, 22.48819351], [69.91291809, 22.4881897], [69.91291809, 22.48903084], [69.91319275, 22.48902512], [69.91319275, 22.48958397], [69.91374969, 22.48958015], [69.91374969, 22.48986053], [69.91401672, 22.48986053], [69.91401672, 22.49014091], [69.91430664, 22.49014091], [69.91430664, 22.49043083], [69.9145813, 22.49041939], [69.9145813, 22.49069405], [69.91486359, 22.49069405], [69.91486359, 22.49097252], [69.91513824, 22.49097061], [69.91513824, 22.49124908], [69.9154129, 22.49124908], [69.9154129, 22.49152756], [69.91570282, 22.49152756], [69.91570282, 22.49180984], [69.91596985, 22.49180794], [69.91596985, 22.4920826], [69.91625214, 22.49208069], [69.91625214, 22.49235916], [69.91680908, 22.49235916], [69.91680908, 22.49263763], [69.91735077, 22.49263763], [69.91735077, 22.49292183], [69.91791534, 22.49291611], [69.91791534, 22.49319458], [69.91819763, 22.49319458], [69.91819763, 22.49347305], [69.91847229, 22.49346924], [69.91847229, 22.49375153], [69.91874695, 22.49375153], [69.91874695, 22.49458313], [69.91847229, 22.49458313], [69.91847229, 22.4948616], [69.91874695, 22.4948616], [69.91874695, 22.49570274], [69.91902924, 22.49569511], [69.91902924, 22.49597359], [69.91930389, 22.49597359], [69.91930389, 22.49625015], [69.91986084, 22.49624252], [69.91986084, 22.49653053], [69.92014313, 22.49653053], [69.92014313, 22.49764061], [69.92041016, 22.49764061], [69.92041016, 22.49792099], [69.92069244, 22.49791718], [69.92069244, 22.49847221], [69.9209671, 22.49847031], [69.9209671, 22.49903107], [69.92124939, 22.49902725], [69.92124939, 22.4995842], [69.92151642, 22.49958038], [69.92151642, 22.50014114], [69.92180634, 22.50014114], [69.92180634, 22.50041962], [69.92208099, 22.5004158], [69.92208099, 22.50097275], [69.92236328, 22.50097084], [69.92236328, 22.50152969], [69.92263794, 22.50152779], [69.92263794, 22.50208282], [69.92292023, 22.50208092], [69.92292023, 22.50292015], [69.92319489, 22.50291634], [69.92319489, 22.50319481], [69.92346954, 22.50319481], [69.92346954, 22.50347137], [69.92375183, 22.50347137], [69.92375183, 22.50363159], [69.92375183, 22.50374985], [69.92402649, 22.50374985], [69.92402649, 22.50403023], [69.92430878, 22.50402641], [69.92430878, 22.50458336], [69.92458344, 22.50458336], [69.92458344, 22.50486183], [69.92485809, 22.50485992], [69.92485809, 22.5051384], [69.92514038, 22.5051384], [69.92514038, 22.50541878], [69.92569733, 22.50541115], [69.92569733, 22.50569916], [69.92597198, 22.50569534], [69.92597198, 22.50597191], [69.92624664, 22.50596809], [69.92624664, 22.50624847], [69.92653656, 22.50624847], [69.92653656, 22.50653076], [69.92708588, 22.50653076], [69.92708588, 22.50680923], [69.92736053, 22.50680542], [69.92736053, 22.50708389], [69.92763519, 22.50708389], [69.92763519, 22.50735855], [69.92791748, 22.50735855], [69.92791748, 22.50764275], [69.9284668, 22.50764275], [69.9284668, 22.50792122], [69.92874908, 22.5079174], [69.92874908, 22.50819397], [69.92903137, 22.50819397], [69.92903137, 22.50847244], [69.92958069, 22.50847244], [69.92958069, 22.50875282], [69.92986298, 22.50875282], [69.92986298, 22.50902939], [69.93041992, 22.50902939], [69.93041992, 22.50930977], [69.93069458, 22.50930595], [69.93069458, 22.50958252], [69.93125153, 22.50958252], [69.93125153, 22.5098629], [69.93152618, 22.5098629], [69.93152618, 22.51013947], [69.93264008, 22.51013947], [69.93264008, 22.51041985], [69.93319702, 22.51041985], [69.93319702, 22.51013947], [69.93374634, 22.51013947], [69.93374634, 22.51041985], [69.93402863, 22.51041603], [69.93402863, 22.51097488], [69.93430328, 22.51097107], [69.93430328, 22.51153946], [69.93458557, 22.51152802], [69.93458557, 22.51208305], [69.93486023, 22.51208115], [69.93486023, 22.51264], [69.93596649, 22.51264], [69.93596649, 22.51292038], [69.93681335, 22.51292038], [69.93681335, 22.51320076], [69.93736267, 22.51319313], [69.93736267, 22.5134716], [69.93818665, 22.5134697], [69.93818665, 22.51375008], [69.93958282, 22.51375008], [69.93958282, 22.5134697], [69.94069672, 22.5134716], [69.94069672, 22.51319313], [69.94124603, 22.51320076], [69.94124603, 22.51292038], [69.94153595, 22.51292038], [69.94153595, 22.51264], [69.9420929, 22.51264], [69.9420929, 22.51235962], [69.94235992, 22.51236153], [69.94235992, 22.51208305], [69.94291687, 22.51208305], [69.94291687, 22.51180649], [69.94346619, 22.51180077], [69.94347382, 22.51152802], [69.94374847, 22.51153946], [69.94374847, 22.51124954], [69.94403076, 22.51124954], [69.94403076, 22.51097107], [69.94430542, 22.51097488], [69.94430542, 22.5106945], [69.94458008, 22.5106945], [69.94458008, 22.51041603], [69.94486237, 22.51041985], [69.94486237, 22.51013947], [69.94513702, 22.51013947], [69.94513702, 22.5098629], [69.94541931, 22.5098629], [69.94541931, 22.50958252], [69.94569397, 22.50958252], [69.94569397, 22.50930595], [69.94596863, 22.50930977], [69.94596863, 22.50902939], [69.94625092, 22.50902939], [69.94625092, 22.50875282], [69.9465332, 22.50875282], [69.94652557, 22.50847244], [69.94680786, 22.50847244], [69.94680786, 22.50819397], [69.94708252, 22.50819397], [69.94708252, 22.5079174], [69.94734955, 22.50792122], [69.94734955, 22.50764275], [69.94745636, 22.50764275], [69.94763947, 22.50764275], [69.94763947, 22.50735855], [69.94790649, 22.50735855], [69.94790649, 22.50707817], [69.94875336, 22.50708389], [69.94875336, 22.50680542], [69.94902802, 22.50680923], [69.94902802, 22.50653076], [69.94957733, 22.50653076], [69.94957733, 22.50624847], [69.95014191, 22.50624847], [69.95014191, 22.50596809], [69.95097351, 22.50597191], [69.95097351, 22.50569534], [69.95153046, 22.50569916], [69.95153046, 22.50541115], [69.95291901, 22.50541878], [69.95291901, 22.5051384], [69.95318604, 22.5051384], [69.95318604, 22.50485992], [69.95375061, 22.50486183], [69.95375061, 22.50458336], [69.95402527, 22.50458336], [69.95402527, 22.50430489], [69.95430756, 22.50430489], [69.95430756, 22.50402641], [69.95513916, 22.50403023], [69.95513916, 22.50346947], [69.95541382, 22.50347137], [69.95541382, 22.5023613], [69.95569611, 22.50237083], [69.95569611, 22.50208092], [69.95597076, 22.50208282], [69.95597076, 22.50152779], [69.95625305, 22.50152969], [69.95625305, 22.50125122], [69.95597076, 22.50125122], [69.95597076, 22.5002594], [69.95597076, 22.50013924], [69.95625305, 22.50014114], [69.95625305, 22.49958038], [69.95652771, 22.4995842], [69.95652771, 22.49652863], [69.95625305, 22.49653053], [69.95625305, 22.49542046], [69.95735931, 22.49541664], [69.95735931, 22.49597359], [69.9576416, 22.49597168], [69.9576416, 22.50014114], [69.95735931, 22.50013924], [69.95735931, 22.50056076], [69.95735931, 22.50125122], [69.95708466, 22.50124931], [69.95708466, 22.50208282], [69.95680237, 22.50208092], [69.95680237, 22.50263977], [69.95652008, 22.50263977], [69.95652008, 22.50292015], [69.95625305, 22.50291634], [69.95625305, 22.50347137], [69.95597076, 22.50346947], [69.95597076, 22.50403023], [69.95569611, 22.50402641], [69.95569611, 22.50430489], [69.95541382, 22.50430489], [69.95541382, 22.50458336], [69.95569611, 22.50458336], [69.95569611, 22.50541878], [69.95597076, 22.50541878], [69.95597076, 22.50597191], [69.95625305, 22.50596809], [69.95625305, 22.50653076], [69.95652771, 22.50652695], [69.95652771, 22.50708389], [69.95680237, 22.50707817], [69.95680237, 22.50735855], [69.95707703, 22.50735855], [69.95707703, 22.50764275], [69.95791626, 22.50764275], [69.95791626, 22.50792122], [69.95874786, 22.5079174], [69.95874786, 22.50819397], [69.95903015, 22.50819016], [69.95903015, 22.50930977], [69.95874786, 22.50930595], [69.95874786, 22.50942039], [69.95874786, 22.50958252], [69.95819092, 22.50958252], [69.95819092, 22.50930595], [69.9576416, 22.50930977], [69.9576416, 22.50875282], [69.95707703, 22.50875282], [69.95707703, 22.50847244], [69.95625305, 22.50847244], [69.95625305, 22.50819397], [69.95569611, 22.50819397], [69.95569611, 22.50847244], [69.95347595, 22.50847244], [69.95347595, 22.50875282], [69.95291901, 22.50875282], [69.95291901, 22.50902939], [69.95181274, 22.50902939], [69.95181274, 22.50930977], [69.95124817, 22.50930595], [69.95124817, 22.50958252], [69.95096588, 22.50958252], [69.95096588, 22.5098629], [69.95069122, 22.5098629], [69.95069122, 22.51041985], [69.95041656, 22.51041985], [69.95041656, 22.51124954], [69.95014191, 22.51124954], [69.95014191, 22.51153946], [69.94985962, 22.51152802], [69.94985962, 22.51208305], [69.94958496, 22.51208305], [69.94958496, 22.51236153], [69.94930267, 22.51235962], [69.94930267, 22.51264], [69.94902802, 22.51264], [69.94902802, 22.51292038], [69.94790649, 22.51292038], [69.94790649, 22.51320076], [69.94736481, 22.51319313], [69.94736481, 22.5134716], [69.94708252, 22.5134697], [69.94708252, 22.51375008], [69.9465332, 22.51375008], [69.9465332, 22.51403046], [69.94625092, 22.51403046], [69.94625092, 22.51431084], [69.94569397, 22.51430511], [69.94569397, 22.51458359], [69.94541931, 22.51458359], [69.94541931, 22.51486206], [69.94486237, 22.51486015], [69.94486237, 22.51542091], [69.94458008, 22.51542091], [69.94458008, 22.51653099], [69.94430542, 22.51652527], [69.94430542, 22.51736069], [69.94458008, 22.51735115], [69.94458008, 22.51791954], [69.94486237, 22.51791573], [69.94486237, 22.51847267], [69.94513702, 22.51847076], [69.94513702, 22.51874924], [69.94541931, 22.51874924], [69.94541931, 22.51930809], [69.94568634, 22.51930809], [69.94568634, 22.51985931], [69.94596863, 22.51985931], [69.94596863, 22.5201416], [69.94625092, 22.5201416], [69.94625092, 22.51985931], [69.9465332, 22.51985931], [69.94652557, 22.51958275], [69.94736481, 22.51958275], [69.94736481, 22.52041626], [69.94708252, 22.52041626], [69.94708252, 22.52069473], [69.94680786, 22.52069473], [69.94680786, 22.52180481], [69.9465332, 22.52179909], [69.9465332, 22.52347946], [69.94625092, 22.52347374], [69.94625092, 22.52597237], [69.94596863, 22.52597237], [69.94596863, 22.5284729], [69.94652557, 22.5284729], [69.94652557, 22.52874947], [69.94734955, 22.52874947], [69.94734955, 22.52902985], [69.94847107, 22.52902985], [69.94847107, 22.52931023], [69.94930267, 22.52930641], [69.94930267, 22.52958298], [69.95014191, 22.52958298], [69.95014191, 22.52986145], [69.95265198, 22.52985954], [69.9540329, 22.52985954], [69.9540329, 22.53013992], [69.95430756, 22.53013992], [69.95430756, 22.53070068], [69.95458221, 22.53069496], [69.95458221, 22.53097153], [69.95513916, 22.53096962], [69.95513916, 22.53124809], [69.95540619, 22.53124809], [69.95540619, 22.53153038], [69.95597076, 22.53153038], [69.95597076, 22.53181076], [69.95625305, 22.53180504], [69.95625305, 22.53208351], [69.95652771, 22.53208351], [69.95652771, 22.53236008], [69.95707703, 22.53235054], [69.95707703, 22.53264046], [69.95735931, 22.53264046], [69.95735931, 22.53292084], [69.95749664, 22.53292084], [69.95791626, 22.53291893], [69.95791626, 22.53319359], [69.95819092, 22.53319359], [69.95819092, 22.53347015], [69.95847321, 22.53346825], [69.95847321, 22.53374863], [69.95903015, 22.53374863], [69.95903015, 22.53403091], [69.95929718, 22.53403091], [69.95929718, 22.53430939], [69.95986176, 22.53430557], [69.95986176, 22.53458405], [69.96013641, 22.53458023], [69.96013641, 22.53486252], [69.9604187, 22.53486252], [69.9604187, 22.5351429], [69.96098328, 22.5351429], [69.96098328, 22.53541946], [69.96125031, 22.53541756], [69.96125031, 22.53569412], [69.96152496, 22.53569412], [69.96152496, 22.5359726], [69.96208191, 22.5359726], [69.96208191, 22.53625107], [69.96235657, 22.53625107], [69.96235657, 22.53652954], [69.96263885, 22.53652763], [69.96263885, 22.53708267], [69.96290588, 22.53708267], [69.96290588, 22.53736115], [69.96375275, 22.53736115], [69.96375275, 22.53763962], [69.96430206, 22.53763962], [69.96430206, 22.53792], [69.9651413, 22.53791618], [69.9651413, 22.53819466], [69.96570587, 22.53819275], [69.96570587, 22.53848076], [69.96652985, 22.53848076], [69.96652985, 22.53874969], [69.96736145, 22.53874969], [69.96736145, 22.53903008], [69.96847534, 22.53902817], [69.96847534, 22.53930473], [69.9695816, 22.53930473], [69.9695816, 22.53958321], [69.97041321, 22.53958321], [69.97041321, 22.53986168], [69.97097015, 22.53985977], [69.97097015, 22.54014015], [69.97207642, 22.54014015], [69.97207642, 22.54042053], [69.97264862, 22.54042053], [69.9734726, 22.54042053], [69.9734726, 22.54070091], [69.97374725, 22.54070091], [69.97374725, 22.54042053], [69.97680664, 22.54042053], [69.97680664, 22.54014015], [69.97764587, 22.54014015], [69.97764587, 22.54042053], [69.97875214, 22.54042053], [69.97875214, 22.54014015], [69.9798584, 22.54014015], [69.9798584, 22.54042053], [69.98014069, 22.54042053], [69.98014069, 22.54070091], [69.98069763, 22.54069519], [69.98069763, 22.54097176], [69.98124695, 22.54096985], [69.98124695, 22.54125023], [69.98180389, 22.54125023], [69.98180389, 22.5415287], [69.98226166, 22.54152107], [69.98236084, 22.5415287], [69.98236084, 22.54181099], [69.98319244, 22.54180527], [69.98319244, 22.54208374], [69.98347473, 22.54208374], [69.98347473, 22.54180527], [69.98401642, 22.54181099], [69.98401642, 22.54152107], [69.98430634, 22.5415287], [69.98430634, 22.54097176], [69.98458099, 22.54097176], [69.98458099, 22.54069519], [69.98486328, 22.54070091], [69.98486328, 22.54043961], [69.98486328, 22.53958321], [69.98458099, 22.53958321], [69.98458099, 22.53874969], [69.98430634, 22.53874969], [69.98430634, 22.53819275], [69.98402405, 22.53819466], [69.98402405, 22.53763962], [69.98374939, 22.53763962], [69.98374939, 22.53736115], [69.98345947, 22.53736115], [69.98345947, 22.53708267], [69.98319244, 22.53708267], [69.98319244, 22.53652763], [69.98291779, 22.53652954], [69.98291779, 22.53625107], [69.98236084, 22.53625107], [69.98236084, 22.5359726], [69.98208618, 22.5359726], [69.98208618, 22.53569412], [69.98180389, 22.53569412], [69.98180389, 22.53541756], [69.98152924, 22.53541946], [69.98152924, 22.5351429], [69.98206329, 22.5351429], [69.98208618, 22.53486252], [69.98291779, 22.53486252], [69.98291779, 22.53513145], [69.98319244, 22.5351429], [69.98319244, 22.53541946], [69.98347473, 22.53541756], [69.98347473, 22.53569412], [69.98374939, 22.53569412], [69.98374939, 22.5359726], [69.98401642, 22.5359726], [69.98401642, 22.53652954], [69.98430634, 22.53652954], [69.98430634, 22.53680992], [69.98458099, 22.53680611], [69.98458099, 22.53708267], [69.98486328, 22.53708267], [69.98486328, 22.53763962], [69.98513794, 22.53763962], [69.98513794, 22.53792], [69.98542023, 22.53792], [69.98542023, 22.53848076], [69.98569489, 22.53847313], [69.98569489, 22.53930473], [69.98596954, 22.53930473], [69.98596954, 22.54031944], [69.98596954, 22.54042053], [69.98569489, 22.54041672], [69.98569489, 22.5415287], [69.98542023, 22.54152107], [69.98542023, 22.54181099], [69.98513794, 22.54180527], [69.98513794, 22.54208374], [69.98486328, 22.54207993], [69.98486328, 22.54236031], [69.98430634, 22.54236031], [69.98430634, 22.54264069], [69.98401642, 22.54264069], [69.98401642, 22.54292107], [69.98236084, 22.54292107], [69.98236084, 22.54264069], [69.98152924, 22.54264069], [69.98152924, 22.54236031], [69.98097229, 22.54236031], [69.98097229, 22.54222107], [69.98097229, 22.54208374], [69.98041534, 22.54208374], [69.98041534, 22.54180527], [69.98014069, 22.54181099], [69.98014069, 22.54152107], [69.9770813, 22.5415287], [69.9770813, 22.54125023], [69.97569275, 22.54125023], [69.97569275, 22.5415287], [69.97541809, 22.54152107], [69.97541809, 22.54181099], [69.9751358, 22.54180527], [69.9751358, 22.54208374], [69.97486115, 22.54207993], [69.97486115, 22.54236031], [69.9751358, 22.54236031], [69.9751358, 22.54264069], [69.97569275, 22.54264069], [69.97569275, 22.54292107], [69.97624969, 22.54291534], [69.97624969, 22.54319382], [69.9779129, 22.54319382], [69.9779129, 22.54347229], [69.97866821, 22.54347229], [69.97957611, 22.54347038], [69.97957611, 22.54375076], [69.98319244, 22.54375076], [69.98319244, 22.54403114], [69.98374939, 22.54403114], [69.98374939, 22.54430962], [69.98542023, 22.5443058], [69.98542023, 22.54458237], [69.98680878, 22.54458427], [69.98680878, 22.54486084], [69.98819733, 22.54486084], [69.98819733, 22.54514122], [69.98958588, 22.54514122], [69.98958588, 22.54541969], [69.99069214, 22.54541588], [69.99069214, 22.54569435], [69.99208069, 22.54569435], [69.99208069, 22.54597282], [69.99318695, 22.54597092], [69.99318695, 22.54624748], [69.99430847, 22.54624748], [69.99430847, 22.54653168], [69.99568939, 22.54653168], [69.99568939, 22.54681015], [69.99708557, 22.54680634], [69.99708557, 22.5470829], [69.99874878, 22.5470829], [69.99874878, 22.54735947], [70.0, 22.54735947], [70.00125122, 22.54735947], [70.00125122, 22.5470829], [70.00152588, 22.5470829], [70.00152588, 22.54680634], [70.00208282, 22.54681015], [70.00208282, 22.54653168], [70.00263977, 22.54653168], [70.00263977, 22.54597092], [70.00291443, 22.54597282], [70.00291443, 22.5443058], [70.00402832, 22.5443058], [70.00402832, 22.54569435], [70.00430298, 22.54569054], [70.00430298, 22.54653168], [70.00485992, 22.54653168], [70.00485992, 22.54681015], [70.00541687, 22.54680634], [70.00541687, 22.5470829], [70.00597382, 22.5470829], [70.00597382, 22.54735947], [70.00681305, 22.54735947], [70.00681305, 22.54764938], [70.00762939, 22.54764938], [70.00762939, 22.54792023], [70.00875092, 22.54791641], [70.00875092, 22.54819489], [70.00958252, 22.54819489], [70.00958252, 22.54846954], [70.01040649, 22.54846954], [70.01040649, 22.54875183], [70.01097107, 22.54875183], [70.01097107, 22.54846954], [70.01152802, 22.54846954], [70.01152802, 22.54819489], [70.01180267, 22.54819489], [70.01180267, 22.54791641], [70.01264191, 22.54792023], [70.01264191, 22.54764938], [70.01346588, 22.54764938], [70.01346588, 22.54735947], [70.01430511, 22.54735947], [70.01430511, 22.5470829], [70.01486206, 22.5470829], [70.01486206, 22.54680634], [70.01985931, 22.54680634], [70.01985931, 22.5470829], [70.02041626, 22.5470829], [70.02041626, 22.54735947], [70.02069092, 22.54735947], [70.02069092, 22.54764938], [70.02097321, 22.54764938], [70.02097321, 22.54792023], [70.02124786, 22.54791641], [70.02124786, 22.54819489], [70.02153015, 22.54819489], [70.02153015, 22.54846954], [70.0220871, 22.54846954], [70.0220871, 22.54875183], [70.02236176, 22.54875183], [70.02236176, 22.5490303], [70.02263641, 22.5490303], [70.02263641, 22.54931068], [70.02347565, 22.54930496], [70.02347565, 22.54958344], [70.02375031, 22.54958344], [70.02375031, 22.54986382], [70.02403259, 22.54986191], [70.02403259, 22.55042076], [70.02430725, 22.55041695], [70.02430725, 22.55069351], [70.0248642, 22.55069351], [70.0248642, 22.55097389], [70.02680206, 22.55097389], [70.02680206, 22.55069351], [70.02708435, 22.55069351], [70.02708435, 22.55041695], [70.02735901, 22.55042076], [70.02735901, 22.55014038], [70.02791595, 22.55014038], [70.02791595, 22.54986191], [70.02819061, 22.54986382], [70.02819824, 22.54958344], [70.0284729, 22.54958344], [70.0284729, 22.54819489], [70.02819824, 22.54819489], [70.02819061, 22.54680634], [70.02791595, 22.54681015], [70.02791595, 22.54653168], [70.0276413, 22.54653168], [70.0276413, 22.54624748], [70.02735901, 22.54624748], [70.02735901, 22.54597092], [70.02708435, 22.54597282], [70.02708435, 22.54569435], [70.0265274, 22.54569435], [70.0265274, 22.54541588], [70.02625275, 22.54541969], [70.02625275, 22.54514122], [70.02597046, 22.54514122], [70.02597046, 22.54486084], [70.0256958, 22.54486084], [70.0256958, 22.54458046], [70.02513885, 22.54458427], [70.02513885, 22.5443058], [70.02485657, 22.54430962], [70.02484894, 22.54404068], [70.02458191, 22.54403114], [70.02458191, 22.54388046], [70.02458191, 22.54375076], [70.02430725, 22.54375076], [70.02430725, 22.54347229], [70.02388763, 22.54347229], [70.02375031, 22.54347229], [70.02375031, 22.54319382], [70.02347565, 22.54319382], [70.02347565, 22.54263878], [70.02319336, 22.54264069], [70.02319336, 22.54207993], [70.0229187, 22.54208374], [70.0229187, 22.5415287], [70.02263641, 22.5415287], [70.02263641, 22.54097176], [70.02236176, 22.54097176], [70.02236176, 22.54041672], [70.0220871, 22.54042053], [70.0220871, 22.53957939], [70.02347565, 22.53958321], [70.02347565, 22.53986168], [70.02375031, 22.53985977], [70.02375031, 22.54042053], [70.02403259, 22.54042053], [70.02403259, 22.54070091], [70.02430725, 22.54069519], [70.02430725, 22.54097176], [70.02458191, 22.54096985], [70.02458191, 22.54125023], [70.0248642, 22.54125023], [70.0248642, 22.5415287], [70.02513885, 22.5415287], [70.02513885, 22.54208374], [70.02540588, 22.54207993], [70.02540588, 22.54236031], [70.0256958, 22.54236031], [70.0256958, 22.54264069], [70.02597046, 22.54264069], [70.02597046, 22.54292107], [70.02625275, 22.54291534], [70.02625275, 22.54319382], [70.02680206, 22.54319382], [70.02680206, 22.54347229], [70.02735901, 22.54347038], [70.02735901, 22.54375076], [70.02791595, 22.54375076], [70.02791595, 22.54403114], [70.02819824, 22.54403114], [70.02819824, 22.54430962], [70.02874756, 22.5443058], [70.02874756, 22.54458237], [70.02929688, 22.54458046], [70.02929688, 22.54514122], [70.02958679, 22.54513741], [70.02958679, 22.54569435], [70.02986145, 22.54569054], [70.02986145, 22.54624748], [70.03013611, 22.54624748], [70.03013611, 22.5471611], [70.03013611, 22.54792023], [70.0304184, 22.54792023], [70.0304184, 22.55181122], [70.03069305, 22.55181122], [70.03069305, 22.55236053], [70.03098297, 22.55236053], [70.03098297, 22.55291939], [70.03125, 22.55291748], [70.03125, 22.55347252], [70.0315094, 22.55346107], [70.0315094, 22.55375099], [70.03179932, 22.55375099], [70.03179932, 22.55430984], [70.0320816, 22.55430412], [70.0320816, 22.5545826], [70.03235626, 22.55458069], [70.03235626, 22.55486107], [70.03263855, 22.55486107], [70.03263855, 22.55541992], [70.03291321, 22.55541611], [70.03291321, 22.55569458], [70.0331955, 22.55569458], [70.0331955, 22.55597305], [70.03347015, 22.55597305], [70.03347015, 22.55652618], [70.03375244, 22.55652618], [70.03375244, 22.55680466], [70.0340271, 22.55680466], [70.0340271, 22.55708313], [70.03430176, 22.55708313], [70.03430939, 22.5573616], [70.03457642, 22.5573597], [70.03457642, 22.55763817], [70.03514099, 22.55763817], [70.03514099, 22.55792046], [70.03542328, 22.55792046], [70.03542328, 22.55820084], [70.03569794, 22.55819511], [70.03569794, 22.55847168], [70.0359726, 22.55846977], [70.0359726, 22.55874825], [70.03652954, 22.55874825], [70.03652954, 22.55903053], [70.04013824, 22.55903053], [70.04013824, 22.55958939], [70.03985596, 22.55958939], [70.03985596, 22.56041908], [70.0395813, 22.56041718], [70.0395813, 22.56069374], [70.03930664, 22.56069374], [70.03930664, 22.56097031], [70.03901672, 22.5609684], [70.03901672, 22.56291962], [70.0404129, 22.56291962], [70.0404129, 22.56236267], [70.04070282, 22.56236267], [70.04069519, 22.5620842], [70.04096985, 22.5620842], [70.04096985, 22.56180573], [70.04125214, 22.56180954], [70.04125214, 22.56125259], [70.04152679, 22.56125259], [70.04152679, 22.56041908], [70.04180908, 22.56041908], [70.04180908, 22.55985832], [70.04207611, 22.55985832], [70.04207611, 22.55931091], [70.0423584, 22.55931091], [70.0423584, 22.55874825], [70.04264069, 22.55874825], [70.04264069, 22.55820084], [70.04292297, 22.55820084], [70.04292297, 22.55792046], [70.04319763, 22.55792046], [70.04319763, 22.5573597], [70.04347229, 22.5573616], [70.04347229, 22.55708313], [70.04374695, 22.55708313], [70.04374695, 22.55680466], [70.04430389, 22.55680466], [70.04430389, 22.55652618], [70.04458618, 22.55652618], [70.04458618, 22.55624962], [70.04514313, 22.55624962], [70.0451355, 22.55597305], [70.04569244, 22.55597305], [70.04569244, 22.55569458], [70.04624939, 22.55569458], [70.04624939, 22.55541611], [70.04679871, 22.55541992], [70.04679871, 22.55513954], [70.04708099, 22.55513954], [70.04708099, 22.55486107], [70.04763794, 22.55486107], [70.04763794, 22.55458069], [70.04819489, 22.5545826], [70.04819489, 22.55430412], [70.04902649, 22.55430984], [70.04902649, 22.55402946], [70.04987335, 22.55402946], [70.04987335, 22.55375099], [70.05069733, 22.55375099], [70.05069733, 22.55346107], [70.05152893, 22.55347252], [70.05152893, 22.55319595], [70.05236053, 22.55319595], [70.05236053, 22.55291748], [70.05319214, 22.55291939], [70.05319214, 22.55264091], [70.05403137, 22.55264091], [70.05403137, 22.55236053], [70.05486298, 22.55236053], [70.05486298, 22.55208015], [70.05596924, 22.55208206], [70.05596924, 22.5518055], [70.05708313, 22.55181122], [70.05708313, 22.55153084], [70.05847168, 22.55153084], [70.05847168, 22.55125046], [70.0595932, 22.55125046], [70.05958557, 22.55097389], [70.06014252, 22.55097389], [70.06014252, 22.55069351], [70.06041718, 22.55069351], [70.06041718, 22.55041695], [70.06096649, 22.55042076], [70.06096649, 22.55014038], [70.06153107, 22.55014038], [70.06153107, 22.54986191], [70.06208038, 22.54986382], [70.06208038, 22.54958344], [70.06236267, 22.54958344], [70.06236267, 22.54930496], [70.06291962, 22.54931068], [70.06291962, 22.5490303], [70.06318665, 22.5490303], [70.06318665, 22.54875183], [70.06346893, 22.54875183], [70.06346893, 22.54846954], [70.06375122, 22.54846954], [70.06375122, 22.54791641], [70.06402588, 22.54792023], [70.06402588, 22.54735947], [70.06430817, 22.54735947], [70.06430817, 22.5470829], [70.06458282, 22.5470829], [70.06458282, 22.54680634], [70.06513977, 22.54680634], [70.06513977, 22.5470829], [70.06569672, 22.5470829], [70.06569672, 22.54735947], [70.06597137, 22.54735947], [70.06597137, 22.54764938], [70.06652832, 22.54764938], [70.06652832, 22.54792023], [70.06680298, 22.54791641], [70.06680298, 22.54819489], [70.06708527, 22.54819489], [70.06708527, 22.54846954], [70.06735992, 22.54846954], [70.06735992, 22.54875183], [70.06790924, 22.5487709], [70.06790924, 22.5490303], [70.06846619, 22.5490303], [70.06846619, 22.54931068], [70.06903076, 22.54930496], [70.06903076, 22.54958344], [70.06958008, 22.54958344], [70.06958008, 22.54986382], [70.07041931, 22.54986191], [70.07041931, 22.55014038], [70.07263947, 22.55014038], [70.07263947, 22.54986191], [70.07430267, 22.54986382], [70.07430267, 22.54958344], [70.07541656, 22.54958344], [70.07541656, 22.54930496], [70.07653046, 22.54931068], [70.07653046, 22.5490303], [70.07736206, 22.5490303], [70.07736206, 22.54875183], [70.07847595, 22.54875183], [70.07847595, 22.54846954], [70.07958221, 22.54846954], [70.07958221, 22.54819489], [70.08069611, 22.54819489], [70.08069611, 22.54791641], [70.08152771, 22.54792023], [70.08152771, 22.54764938], [70.0826416, 22.54764938], [70.0826416, 22.54735947], [70.08319092, 22.54735947], [70.08319092, 22.5470829], [70.08374786, 22.5470829], [70.08374786, 22.54680634], [70.08429718, 22.54681015], [70.08429718, 22.54597092], [70.0845871, 22.54597282], [70.0845871, 22.54541588], [70.08486176, 22.54541969], [70.08486176, 22.54514122], [70.08569336, 22.54514122], [70.08569336, 22.54486084], [70.08735657, 22.54486084], [70.08735657, 22.54541969], [70.08763885, 22.54541588], [70.08763885, 22.54597282], [70.08930206, 22.54597092], [70.08930206, 22.54624748], [70.09069824, 22.54624748], [70.09069824, 22.54653168], [70.09541321, 22.54653168], [70.09541321, 22.54681015], [70.0973587, 22.54680634], [70.0973587, 22.5470829], [70.10124969, 22.5470829], [70.10124969, 22.54680634], [70.10375214, 22.54681015], [70.10375214, 22.54653168], [70.10542297, 22.54653168], [70.10542297, 22.54597092], [70.10624695, 22.54597092], [70.10624695, 22.54624748], [70.10652924, 22.54624748], [70.10652924, 22.54653168], [70.10678864, 22.54653168], [70.10678864, 22.54681015], [70.11152649, 22.54680634], [70.11152649, 22.5470829], [70.11486053, 22.5470829], [70.11486053, 22.54735947], [70.11569214, 22.54735947], [70.11569214, 22.54764938], [70.11624908, 22.54764938], [70.11624908, 22.54792023], [70.11680603, 22.54791641], [70.11680603, 22.54819489], [70.11763763, 22.54819489], [70.11763763, 22.54791641], [70.11846924, 22.54792023], [70.11846924, 22.54764938], [70.11930847, 22.54764938], [70.11930847, 22.54735947], [70.11958313, 22.54735947], [70.11958313, 22.5470829], [70.11985779, 22.5470829], [70.11985779, 22.54652977], [70.12014008, 22.54653168], [70.12014008, 22.54624748], [70.1204071, 22.54624748], [70.1204071, 22.54597092], [70.12124634, 22.54597282], [70.12124634, 22.54569435], [70.12180328, 22.54569435], [70.12180328, 22.54597282], [70.12264252, 22.54597092], [70.12264252, 22.54624748], [70.12291718, 22.54624748], [70.12291718, 22.54653168], [70.12319183, 22.54653168], [70.12319183, 22.54681015], [70.12374878, 22.54680634], [70.12374878, 22.5470829], [70.12403107, 22.5470829], [70.12403107, 22.54735947], [70.12431335, 22.54735947], [70.12431335, 22.54764938], [70.12735748, 22.54764938], [70.12735748, 22.54792023], [70.12875366, 22.54791641], [70.12875366, 22.54819489], [70.12895203, 22.54819489], [70.13764191, 22.54819489], [70.13764191, 22.54846954], [70.13791656, 22.54846954], [70.13791656, 22.54875183], [70.13846588, 22.54875183], [70.13846588, 22.5490303], [70.13874817, 22.5490303], [70.13874817, 22.54931068], [70.13903046, 22.54930496], [70.13903046, 22.54958344], [70.13930511, 22.54958344], [70.13930511, 22.54986382], [70.13986206, 22.54986191], [70.13986206, 22.55014038], [70.14015198, 22.55014038], [70.14015198, 22.55042076], [70.14097595, 22.55042076], [70.14097595, 22.55014038], [70.14180756, 22.55014038], [70.14180756, 22.54986191], [70.14263916, 22.54986382], [70.14263916, 22.54958344], [70.14347076, 22.54957962], [70.14347076, 22.55042076], [70.14375305, 22.55042076], [70.14375305, 22.55153084], [70.14402771, 22.55152702], [70.14402771, 22.55208206], [70.14457703, 22.55208015], [70.14457703, 22.55236053], [70.14485931, 22.55236053], [70.14485931, 22.55264091], [70.14541626, 22.55264091], [70.14541626, 22.55291939], [70.14653015, 22.55291748], [70.14653015, 22.55319595], [70.14736176, 22.55319595], [70.14736176, 22.55347252], [70.14930725, 22.55347252], [70.14930725, 22.55319595], [70.1506958, 22.55319595], [70.1506958, 22.55291748], [70.15374756, 22.55291748], [70.15374756, 22.55319595], [70.15458679, 22.55319595], [70.15458679, 22.55347252], [70.15513611, 22.55347252], [70.15513611, 22.55319595], [70.15625, 22.55319595], [70.15625, 22.55291748], [70.15651703, 22.55291939], [70.15651703, 22.55264091], [70.1570816, 22.55264091], [70.1570816, 22.55236053], [70.15735626, 22.55236053], [70.15735626, 22.55208015], [70.15818787, 22.55208015], [70.15818787, 22.55264091], [70.15847015, 22.55264091], [70.15847015, 22.55291939], [70.15875244, 22.55291939], [70.15875244, 22.55264091], [70.15957642, 22.55264091], [70.15957642, 22.55236053], [70.16069794, 22.55236053], [70.16069794, 22.55208015], [70.16124725, 22.55208206], [70.16124725, 22.5518055], [70.16179657, 22.55181122], [70.16179657, 22.55153084], [70.16291809, 22.55153084], [70.16291809, 22.55181122], [70.16319275, 22.5518055], [70.16319275, 22.55208206], [70.16403198, 22.55208015], [70.16403198, 22.55291939], [70.1645813, 22.55291748], [70.1645813, 22.55319595], [70.16486359, 22.55319595], [70.16486359, 22.55347252], [70.1654129, 22.55346107], [70.1654129, 22.55375099], [70.16570282, 22.55375099], [70.16570282, 22.55402946], [70.16596985, 22.55402946], [70.16596985, 22.55430984], [70.16625214, 22.55430984], [70.16625214, 22.55486107], [70.16652679, 22.55486107], [70.16652679, 22.55513954], [70.16680908, 22.55513954], [70.16680908, 22.55541992], [70.16764069, 22.55541611], [70.16764069, 22.55569458], [70.16819763, 22.55569458], [70.16819763, 22.55597305], [70.16902924, 22.55597115], [70.16902924, 22.55624962], [70.16930389, 22.55624962], [70.16930389, 22.55652618], [70.16958618, 22.55652618], [70.16958618, 22.55680466], [70.16986084, 22.55680466], [70.16986084, 22.55708313], [70.17124939, 22.55708122], [70.17124939, 22.55763817], [70.17151642, 22.55763817], [70.17151642, 22.55792046], [70.17180634, 22.55791664], [70.17180634, 22.55847168], [70.17208099, 22.55846977], [70.17208099, 22.55903053], [70.17180634, 22.55903053], [70.17180634, 22.55958939], [70.17208099, 22.55958939], [70.17208099, 22.56014061], [70.17236328, 22.56014061], [70.17236328, 22.56069374], [70.17292023, 22.56069374], [70.17292023, 22.56097031], [70.17319489, 22.56097031], [70.17319489, 22.56125259], [70.17346954, 22.56125259], [70.17346954, 22.56153107], [70.17402649, 22.56153107], [70.17402649, 22.56180954], [70.17430878, 22.56180954], [70.17430878, 22.56236267], [70.17457581, 22.56236267], [70.17457581, 22.56291962], [70.17485809, 22.56291962], [70.17485809, 22.56375122], [70.17514038, 22.56375122], [70.17514038, 22.56431007], [70.17485809, 22.56430626], [70.17485809, 22.56458473], [70.17458344, 22.56458473], [70.17458344, 22.5648613], [70.17430878, 22.56485939], [70.17430878, 22.56513977], [70.17402649, 22.56513977], [70.17402649, 22.56542015], [70.17430878, 22.56541634], [70.17430878, 22.56569481], [70.17457581, 22.5656929], [70.17457581, 22.56624985], [70.17485809, 22.56624985], [70.17485809, 22.56708336], [70.17514038, 22.56707954], [70.17514038, 22.5676403], [70.17541504, 22.5676384], [70.17541504, 22.56847191], [70.17569733, 22.56846046], [70.17569733, 22.56903076], [70.17597198, 22.56903076], [70.17597198, 22.56931114], [70.17624664, 22.56930542], [70.17624664, 22.56986046], [70.17652893, 22.56986046], [70.17652893, 22.57014084], [70.17679596, 22.57014084], [70.17679596, 22.57042122], [70.17736053, 22.5704174], [70.17736053, 22.57069397], [70.17903137, 22.57069397], [70.17903137, 22.57097244], [70.1792984, 22.57097054], [70.1792984, 22.57125092], [70.17958069, 22.57125092], [70.17958069, 22.57180977], [70.17986298, 22.57180977], [70.17986298, 22.57263756], [70.18013763, 22.57263756], [70.18013763, 22.57375145], [70.18041992, 22.57375145], [70.18041992, 22.57459259], [70.18068695, 22.57459259], [70.18068695, 22.57542038], [70.18125153, 22.57542038], [70.18125153, 22.57514191], [70.18152618, 22.57514191], [70.18152618, 22.57486153], [70.18235779, 22.57486153], [70.18235779, 22.57514191], [70.18264008, 22.57514191], [70.18264008, 22.57570267], [70.1829071, 22.57570267], [70.1829071, 22.57625008], [70.18319702, 22.57625008], [70.18319702, 22.57681084], [70.18347168, 22.57681084], [70.18347168, 22.57736015], [70.18374634, 22.57736015], [70.18374634, 22.58041954], [70.18486023, 22.58041573], [70.18486023, 22.5806942], [70.18569183, 22.5806942], [70.18569183, 22.58097267], [70.18624878, 22.58097076], [70.18624878, 22.58125114], [70.18653107, 22.58125114], [70.18653107, 22.58152962], [70.18681335, 22.58152962], [70.18681335, 22.58181], [70.18708038, 22.58180428], [70.18708038, 22.58208275], [70.18736267, 22.58208084], [70.18736267, 22.58374977], [70.18846893, 22.58374977], [70.18846893, 22.58402824], [70.18819427, 22.58402634], [70.18819427, 22.58458328], [70.18791962, 22.58457947], [70.18791962, 22.58513832], [70.1882019, 22.58513832], [70.1882019, 22.58542061], [70.18985748, 22.58542061], [70.18985748, 22.58513832], [70.1904068, 22.58513832], [70.1904068, 22.58485985], [70.19069672, 22.58486176], [70.19069672, 22.58458328], [70.19097137, 22.58458328], [70.19097137, 22.58430481], [70.19125366, 22.58430481], [70.19125366, 22.58402634], [70.1920929, 22.58402824], [70.1920929, 22.58292007], [70.19430542, 22.58291626], [70.19430542, 22.58430481], [70.19458008, 22.58430481], [70.19458008, 22.58486176], [70.19486237, 22.58485985], [70.19486237, 22.58542061], [70.19513702, 22.58542061], [70.19513702, 22.5862484], [70.19541931, 22.5862484], [70.19541931, 22.5868206], [70.19568634, 22.5868206], [70.19568634, 22.58764076], [70.19596863, 22.58764076], [70.19596863, 22.58903122], [70.19458008, 22.58903122], [70.19458008, 22.58735847], [70.19429779, 22.58735847], [70.19429779, 22.5868206], [70.19403076, 22.5868206], [70.19403076, 22.58596992], [70.19319153, 22.58596992], [70.19319153, 22.58653069], [70.19291687, 22.58653069], [70.19291687, 22.58930969], [70.19319153, 22.58930588], [70.19319153, 22.59097481], [70.19347382, 22.59097481], [70.19347382, 22.59236145], [70.19374847, 22.59235954], [70.19374847, 22.5929203], [70.19403076, 22.59291649], [70.19403076, 22.59486198], [70.19374847, 22.59486198], [70.19374847, 22.59597206], [70.19346619, 22.59597015], [70.19346619, 22.59680939], [70.19319153, 22.59680557], [70.19319153, 22.59819412], [70.19346619, 22.59819031], [70.19346619, 22.5987606], [70.19458008, 22.5987606], [70.19458008, 22.59930992], [70.19430542, 22.59930611], [70.19430542, 22.59958267], [70.19458008, 22.59958076], [70.19458008, 22.60014153], [70.19486237, 22.60014153], [70.19486237, 22.60069466], [70.19458008, 22.60069466], [70.19458008, 22.60097313], [70.19429779, 22.60096931], [70.19429779, 22.6012516], [70.19403076, 22.6012516], [70.19403076, 22.60180473], [70.19430542, 22.60180473], [70.19430542, 22.60208321], [70.19486237, 22.60208321], [70.19486237, 22.60180473], [70.19569397, 22.60180473], [70.19569397, 22.60236168], [70.19541931, 22.60236168], [70.19541931, 22.60264015], [70.19486237, 22.60264015], [70.19486237, 22.60292053], [70.19458008, 22.60292053], [70.19458008, 22.60320282], [70.19429779, 22.60320282], [70.19429779, 22.60375023], [70.19513702, 22.60375023], [70.19513702, 22.6043129], [70.19541931, 22.6043129], [70.19541931, 22.60486031], [70.19568634, 22.60486031], [70.19568634, 22.60542107], [70.19541931, 22.60541725], [70.19541931, 22.60597229], [70.19625092, 22.60597229], [70.19625092, 22.60486031], [70.19680786, 22.60486031], [70.19680786, 22.60514069], [70.19737244, 22.60514069], [70.19737244, 22.60542107], [70.19791412, 22.60541725], [70.19791412, 22.60569572], [70.19847107, 22.60569572], [70.19847107, 22.60541725], [70.19875336, 22.60542107], [70.19875336, 22.60514069], [70.19930267, 22.60514069], [70.19930267, 22.60457039], [70.19958496, 22.60458374], [70.19958496, 22.60375023], [70.20069122, 22.60375023], [70.20069122, 22.60486031], [70.20041656, 22.60486031], [70.20041656, 22.60569572], [70.20097351, 22.60569572], [70.20097351, 22.60513878], [70.20124817, 22.60514069], [70.20124817, 22.60457039], [70.20207977, 22.60457039], [70.20207977, 22.60542107], [70.20236206, 22.60542107], [70.20236206, 22.60486031], [70.20291901, 22.60486031], [70.20291901, 22.60542107], [70.20317841, 22.60542107], [70.20317841, 22.60653114], [70.20291901, 22.60653114], [70.20291901, 22.60680962], [70.20263672, 22.60680962], [70.20263672, 22.60736084], [70.20236206, 22.60736084], [70.20236206, 22.60791969], [70.20153046, 22.60791969], [70.20153046, 22.60762978], [70.20069122, 22.60763931], [70.20069122, 22.60736084], [70.20014191, 22.60736084], [70.20014191, 22.60708046], [70.19985962, 22.60708427], [70.19985962, 22.6068058], [70.19875336, 22.60680962], [70.19875336, 22.60653114], [70.19847107, 22.60653114], [70.19847107, 22.60874939], [70.19902802, 22.60874939], [70.19902802, 22.60902977], [70.19930267, 22.60902977], [70.19930267, 22.60931015], [70.19958496, 22.60930634], [70.19958496, 22.6095829], [70.19985962, 22.6095829], [70.19985962, 22.60986137], [70.19959259, 22.60985947], [70.19959259, 22.61013985], [70.19902802, 22.61013985], [70.19902802, 22.61070061], [70.19875336, 22.61069489], [70.19875336, 22.61097145], [70.19819641, 22.61096954], [70.19819641, 22.61124992], [70.19763947, 22.61124992], [70.19763947, 22.6115303], [70.19680786, 22.6115303], [70.19680786, 22.61124992], [70.19596863, 22.61124992], [70.19596863, 22.61070061], [70.19513702, 22.61070061], [70.19513702, 22.61124992], [70.19486237, 22.61124992], [70.19486237, 22.61236191], [70.19513702, 22.61235809], [70.19513702, 22.61292076], [70.19569397, 22.61291885], [70.19569397, 22.61319351], [70.19625092, 22.61319351], [70.19625092, 22.61291885], [70.1965332, 22.61292076], [70.1965332, 22.61263847], [70.19680786, 22.61263847], [70.19680786, 22.61235809], [70.19737244, 22.61235809], [70.19737244, 22.61292076], [70.19847107, 22.61291885], [70.19847107, 22.6131897], [70.19819641, 22.61319923], [70.19819641, 22.6137619], [70.19790649, 22.6137619], [70.19790649, 22.61430931], [70.19819641, 22.61430931], [70.19819641, 22.61541939], [70.19791412, 22.61541748], [70.19791412, 22.61597252], [70.19763947, 22.61597252], [70.19763947, 22.6162529], [70.19736481, 22.61624908], [70.19736481, 22.61680603], [70.19763947, 22.61680603], [70.19763947, 22.6170826], [70.19791412, 22.6170826], [70.19791412, 22.61652756], [70.19819641, 22.61652946], [70.19819641, 22.61597252], [70.19875336, 22.61597252], [70.19875336, 22.61541748], [70.19958496, 22.61541748], [70.19958496, 22.61597252], [70.19930267, 22.61597252], [70.19930267, 22.6162529], [70.19902802, 22.61624908], [70.19902802, 22.61680603], [70.19930267, 22.61680031], [70.19930267, 22.61736107], [70.20014191, 22.61736107], [70.20014191, 22.61763954], [70.20069122, 22.61763954], [70.20069122, 22.61791992], [70.20097351, 22.61791611], [70.20097351, 22.61819458], [70.20153046, 22.61819458], [70.20153046, 22.61847305], [70.20181274, 22.61847115], [70.20181274, 22.61903], [70.20153046, 22.61902809], [70.20153046, 22.61958313], [70.20180511, 22.61958313], [70.20180511, 22.6198616], [70.20236206, 22.6198597], [70.20236206, 22.62014008], [70.20317841, 22.62014008], [70.20317841, 22.61956978], [70.2040329, 22.61956978], [70.2040329, 22.62014008], [70.20540619, 22.62014008], [70.20540619, 22.62042046], [70.20597076, 22.62042046], [70.20597076, 22.62070084], [70.20625305, 22.62069511], [70.20625305, 22.62097168], [70.20707703, 22.62096977], [70.20707703, 22.62125015], [70.2076416, 22.62125015], [70.2076416, 22.62153053], [70.20791626, 22.62153053], [70.20791626, 22.62181091], [70.20847321, 22.62180519], [70.20847321, 22.62208366], [70.20874786, 22.62207985], [70.20874786, 22.62236023], [70.20903015, 22.62236023], [70.20903015, 22.62319374], [70.20847321, 22.62318993], [70.20847321, 22.62403107], [70.20819092, 22.62403107], [70.20819092, 22.62430954], [70.20791626, 22.62430954], [70.20791626, 22.62514114], [70.20819092, 22.62514114], [70.20819092, 22.62541962], [70.20847321, 22.62541962], [70.20847321, 22.62514114], [70.21013641, 22.62514114], [70.21013641, 22.62486076], [70.20986176, 22.62486076], [70.20986176, 22.62403107], [70.21013641, 22.62403107], [70.21013641, 22.62375069], [70.2104187, 22.62375069], [70.2104187, 22.62318993], [70.21152496, 22.62319374], [70.21152496, 22.62347221], [70.21180725, 22.62347031], [70.21180725, 22.62403107], [70.21208191, 22.62402725], [70.21208191, 22.6245842], [70.2123642, 22.6245842], [70.2123642, 22.62486076], [70.21263885, 22.62486076], [70.21263885, 22.62624931], [70.21208191, 22.62624931], [70.21208191, 22.62597084], [70.21180725, 22.62597084], [70.21180725, 22.62624931], [70.21153259, 22.62624931], [70.21153259, 22.6265316], [70.21180725, 22.6265316], [70.21180725, 22.62681007], [70.21208191, 22.62681007], [70.21208191, 22.62764168], [70.21153259, 22.62764168], [70.21153259, 22.62792015], [70.21125031, 22.62792015], [70.21125031, 22.62903023], [70.21069336, 22.62902832], [70.21069336, 22.62930489], [70.21152496, 22.62930489], [70.21152496, 22.62986374], [70.21208191, 22.62986183], [70.21208191, 22.6301403], [70.21347046, 22.6301403], [70.21347046, 22.62986183], [70.21375275, 22.62986374], [70.21375275, 22.62930489], [70.2140274, 22.62930489], [70.2140274, 22.62791634], [70.21485901, 22.62791634], [70.21485901, 22.62819481], [70.2151413, 22.62819481], [70.2151413, 22.62791634], [70.21540833, 22.62792015], [70.21540833, 22.62764168], [70.21652985, 22.62764168], [70.21652985, 22.62792015], [70.21763611, 22.62791634], [70.21763611, 22.62930489], [70.2179184, 22.62929916], [70.2179184, 22.6301403], [70.21846771, 22.6301403], [70.21846771, 22.62986183], [70.21875, 22.62986374], [70.21875, 22.62958336], [70.21985626, 22.62957954], [70.21985626, 22.6301403], [70.2195816, 22.6301384], [70.2195816, 22.63208389], [70.21985626, 22.63208008], [70.21985626, 22.63236046], [70.22013855, 22.63236046], [70.22013855, 22.63402939], [70.22041321, 22.63402939], [70.22041321, 22.63430977], [70.22013855, 22.63430405], [70.22013855, 22.63458252], [70.21875, 22.63458252], [70.21875, 22.63430405], [70.2181778, 22.63430977], [70.2181778, 22.63402939], [70.21846771, 22.63402939], [70.21846771, 22.63347054], [70.2181778, 22.63347054], [70.2181778, 22.63375092], [70.2179184, 22.63375092], [70.2179184, 22.63402939], [70.21763611, 22.63402939], [70.21763611, 22.63430977], [70.21652985, 22.63430977], [70.21652985, 22.63487053], [70.2159729, 22.63487053], [70.2159729, 22.63458061], [70.21569824, 22.63458252], [70.21569061, 22.63430405], [70.21569061, 22.63402748], [70.21540833, 22.63402939], [70.21540833, 22.63347054], [70.21457672, 22.63347054], [70.21457672, 22.63375092], [70.21430206, 22.63375092], [70.21430206, 22.63402939], [70.21375275, 22.63402939], [70.21375275, 22.63430977], [70.2140274, 22.63430977], [70.2140274, 22.63487053], [70.21430206, 22.63487053], [70.21430206, 22.63541985], [70.21458435, 22.63541794], [70.21458435, 22.6356945], [70.21569824, 22.6356945], [70.21569824, 22.63597298], [70.21679688, 22.63597107], [70.21679688, 22.63624954], [70.21763611, 22.63624954], [70.21763611, 22.63652992], [70.2179184, 22.63652611], [70.2179184, 22.63736153], [70.21736145, 22.63735962], [70.21736145, 22.63820076], [70.21679688, 22.63820076], [70.21679688, 22.63793182], [70.21652985, 22.63793182], [70.21652985, 22.63903046], [70.2159729, 22.63903046], [70.2159729, 22.63931084], [70.21541595, 22.63930511], [70.21541595, 22.63958359], [70.21569824, 22.63957977], [70.21569824, 22.64042091], [70.2159729, 22.6404171], [70.2159729, 22.64097023], [70.21624756, 22.64096832], [70.21624756, 22.6415329], [70.21652985, 22.6415329], [70.21652985, 22.64096832], [70.2168045, 22.64097023], [70.2168045, 22.6404171], [70.21708679, 22.64042091], [70.21708679, 22.64014053], [70.21736145, 22.64014053], [70.21736145, 22.63957977], [70.21763611, 22.63958359], [70.21763611, 22.63874817], [70.21846771, 22.63874817], [70.21846771, 22.63820076], [70.21901703, 22.63820076], [70.21901703, 22.63931084], [70.21930695, 22.63931084], [70.21930695, 22.63903046], [70.2195816, 22.63903046], [70.2195816, 22.63874817], [70.21985626, 22.63874817], [70.21985626, 22.6384697], [70.2195816, 22.6384716], [70.2195816, 22.63819504], [70.21930695, 22.63820076], [70.21930695, 22.63735962], [70.22013855, 22.63735962], [70.22013855, 22.63793182], [70.22070313, 22.63793182], [70.22070313, 22.63820076], [70.22125244, 22.63819504], [70.22125244, 22.6384716], [70.2215271, 22.6384697], [70.2215271, 22.63874817], [70.22207642, 22.63874817], [70.22207642, 22.63903046], [70.2223587, 22.63903046], [70.2223587, 22.6384697], [70.2234726, 22.6384697], [70.2234726, 22.63874817], [70.22374725, 22.63874817], [70.22374725, 22.63903046], [70.22431183, 22.63903046], [70.22431183, 22.63931084], [70.22486115, 22.63930511], [70.22486115, 22.63958359], [70.2251358, 22.63957977], [70.2251358, 22.63985825], [70.22598267, 22.63985825], [70.22598267, 22.64042091], [70.22569275, 22.6404171], [70.22569275, 22.64069366], [70.22541809, 22.64069366], [70.22541809, 22.64097023], [70.2251358, 22.64097023], [70.2251358, 22.64208412], [70.22541809, 22.64208031], [70.22541809, 22.64264107], [70.22598267, 22.64264107], [70.22598267, 22.64291954], [70.22652435, 22.64291573], [70.22652435, 22.6431942], [70.2270813, 22.64319038], [70.2270813, 22.64402962], [70.22651672, 22.64402962], [70.22651672, 22.64431], [70.22680664, 22.64430618], [70.22680664, 22.64458466], [70.22734833, 22.64458275], [70.22734833, 22.64486122], [70.22763824, 22.64486122], [70.22763824, 22.64513969], [70.2279129, 22.64513969], [70.2279129, 22.64542007], [70.22819519, 22.64541626], [70.22819519, 22.6459713], [70.22875214, 22.6459713], [70.22875214, 22.64569473], [70.22930908, 22.64569473], [70.22930908, 22.6459713], [70.22958374, 22.6459713], [70.22958374, 22.64569473], [70.23014069, 22.64569283], [70.23014069, 22.64624977], [70.23040771, 22.64624977], [70.23040771, 22.64681053], [70.23069763, 22.64681053], [70.23069763, 22.64764023], [70.23040771, 22.64764023], [70.23040771, 22.64903069], [70.23069763, 22.64902687], [70.23069763, 22.64958382], [70.23097229, 22.64958], [70.23097229, 22.64986992], [70.23152924, 22.64986992], [70.23152924, 22.65014076], [70.23236084, 22.65014076], [70.23236084, 22.64986992], [70.23208618, 22.64986992], [70.23208618, 22.64958], [70.23180389, 22.64958382], [70.23180389, 22.64930534], [70.23236084, 22.64930534], [70.23236084, 22.64958382], [70.23291779, 22.64958382], [70.23291779, 22.64902687], [70.23458099, 22.64903069], [70.23458099, 22.64931107], [70.23486328, 22.64931107], [70.23486328, 22.64986992], [70.23513794, 22.64986992], [70.23513794, 22.65042114], [70.23486328, 22.65041733], [70.23486328, 22.65069389], [70.23430634, 22.65069389], [70.23430634, 22.65208244], [70.23401642, 22.65208054], [70.23401642, 22.65236092], [70.23374939, 22.65236092], [70.23374939, 22.65263748], [70.2326355, 22.65263748], [70.2326355, 22.6515274], [70.23208618, 22.65153122], [70.23208618, 22.65263748], [70.23124695, 22.65263748], [70.23124695, 22.6534729], [70.2298584, 22.65346909], [70.2298584, 22.65375137], [70.22957611, 22.65375137], [70.22957611, 22.65514183], [70.22930908, 22.65514183], [70.22930908, 22.6554203], [70.22902679, 22.65541649], [70.22902679, 22.65596962], [70.22930908, 22.65596962], [70.22930908, 22.65653038], [70.22902679, 22.65652847], [70.22902679, 22.65736389], [70.22930908, 22.65736389], [70.22930908, 22.65708351], [70.23014069, 22.65708351], [70.23014069, 22.65680504], [70.23069763, 22.65681076], [70.23069763, 22.65653038], [70.23124695, 22.65653038], [70.23124695, 22.65596962], [70.23208618, 22.65596962], [70.23208618, 22.65569496], [70.23236084, 22.65570068], [70.23236084, 22.6554203], [70.23264313, 22.6554203], [70.23264313, 22.65485954], [70.23401642, 22.65485954], [70.23401642, 22.65514183], [70.23458099, 22.65514183], [70.23458099, 22.6554203], [70.23486328, 22.6554203], [70.23486328, 22.65570068], [70.23569489, 22.65569496], [70.23569489, 22.65596962], [70.23596954, 22.65596962], [70.23596954, 22.65708351], [70.23569489, 22.65708351], [70.23569489, 22.65736389], [70.23542023, 22.65736008], [70.23542023, 22.65792084], [70.23513794, 22.65791702], [70.23513794, 22.65819359], [70.23486328, 22.65818977], [70.23486328, 22.65903091], [70.23458099, 22.6590271], [70.23458099, 22.65958595], [70.23486328, 22.65958023], [70.23486328, 22.65986061], [70.23542023, 22.65986061], [70.23542023, 22.66014099], [70.23568726, 22.66014099], [70.23568726, 22.66041946], [70.23625183, 22.66041756], [70.23625183, 22.66069412], [70.23652649, 22.66069412], [70.23652649, 22.6609726], [70.23791504, 22.6609726], [70.23791504, 22.66069412], [70.23847198, 22.66069412], [70.23847198, 22.6609726], [70.23874664, 22.66097069], [70.23874664, 22.66125107], [70.23902893, 22.66125107], [70.23902893, 22.66152954], [70.23928833, 22.66152954], [70.23928833, 22.66180992], [70.23958588, 22.6618042], [70.23958588, 22.66208267], [70.23986053, 22.66208076], [70.23986053, 22.66236115], [70.2409668, 22.66236115], [70.2409668, 22.66263962], [70.24291992, 22.66263962], [70.24291992, 22.66291809], [70.24263763, 22.66291618], [70.24263763, 22.66319466], [70.24236298, 22.66319466], [70.24236298, 22.66347313], [70.24208069, 22.66347122], [70.24208069, 22.66374969], [70.24180603, 22.66374969], [70.24180603, 22.66402817], [70.24153137, 22.66402626], [70.24153137, 22.66430473], [70.24124908, 22.66430473], [70.24124908, 22.66486168], [70.2409668, 22.66485023], [70.2409668, 22.66513824], [70.24069214, 22.66513824], [70.24069214, 22.66542053], [70.24041748, 22.66542053], [70.24041748, 22.66570091], [70.24014282, 22.66570091], [70.24014282, 22.66653061], [70.24041748, 22.66653061], [70.24041748, 22.66708374], [70.24069214, 22.66707993], [70.24069214, 22.6673584], [70.24097443, 22.6673584], [70.24097443, 22.66819382], [70.24069214, 22.66819382], [70.24069214, 22.66847038], [70.2409668, 22.66847038], [70.2409668, 22.66903114], [70.24124908, 22.66903114], [70.24124908, 22.66875267], [70.24153137, 22.66875267], [70.24153137, 22.66958046], [70.24208069, 22.66958046], [70.24208069, 22.6693058], [70.24236298, 22.6693058], [70.24236298, 22.66958046], [70.24263763, 22.66958046], [70.24263763, 22.6693058], [70.24346924, 22.66930962], [70.24346924, 22.66986275], [70.24375153, 22.66986275], [70.24375153, 22.67014122], [70.24458313, 22.67014122], [70.24458313, 22.67041969], [70.24485779, 22.67041969], [70.24485779, 22.66986275], [70.2454071, 22.66986275], [70.2454071, 22.67124939], [70.24514008, 22.67124939], [70.24514008, 22.67152977], [70.24485779, 22.67152977], [70.24485779, 22.67181015], [70.24458313, 22.67180634], [70.24458313, 22.67236137], [70.24485779, 22.67236137], [70.24485779, 22.67208481], [70.24541473, 22.67208481], [70.24541473, 22.67180634], [70.24569702, 22.67180634], [70.24569702, 22.67208481], [70.24597168, 22.67208481], [70.24597168, 22.67180634], [70.24624634, 22.67181015], [70.24624634, 22.67124939], [70.24652863, 22.67124939], [70.24652863, 22.67152977], [70.24680328, 22.67152977], [70.24680328, 22.67181015], [70.24652863, 22.67180634], [70.24652863, 22.67236137], [70.24624634, 22.67235947], [70.24624634, 22.67263985], [70.24597168, 22.67263985], [70.24597168, 22.67319489], [70.24541473, 22.67319489], [70.24541473, 22.67458344], [70.24485779, 22.67458344], [70.24485779, 22.67430687], [70.24430847, 22.67430687], [70.24430847, 22.67458344], [70.24375153, 22.67457962], [70.24375153, 22.67514038], [70.24402618, 22.67514038], [70.24402618, 22.67542076], [70.24430847, 22.67542076], [70.24430847, 22.67486], [70.24485779, 22.67486], [70.24485779, 22.67514038], [70.24514008, 22.67514038], [70.24514008, 22.67542076], [70.24485779, 22.67541695], [70.24485779, 22.67597198], [70.24375153, 22.67597198], [70.24375153, 22.67569542], [70.24318695, 22.6756897], [70.24319458, 22.67513847], [70.24291992, 22.67514038], [70.24291992, 22.67486], [70.24263763, 22.67486], [70.24263763, 22.67514038], [70.24208069, 22.67513847], [70.24208069, 22.6756897], [70.24124908, 22.67569542], [70.24124908, 22.67597198], [70.2409668, 22.67597008], [70.2409668, 22.67625046], [70.24069214, 22.67625046], [70.24069214, 22.67653084], [70.24041748, 22.67653084], [70.24041748, 22.67681122], [70.24013519, 22.6768055], [70.24013519, 22.67708397], [70.23874664, 22.67708397], [70.23874664, 22.67819405], [70.23930359, 22.67819405], [70.23930359, 22.67847252], [70.23960114, 22.67847061], [70.23960114, 22.67874908], [70.23986053, 22.67874908], [70.23986053, 22.67902756], [70.24013519, 22.67902756], [70.24013519, 22.6795826], [70.24041748, 22.67958069], [70.24041748, 22.68014145], [70.24069214, 22.68014145], [70.24069214, 22.67984962], [70.24124908, 22.67984962], [70.24124908, 22.68042183], [70.24153137, 22.68042183], [70.24153137, 22.68153191], [70.24180603, 22.68152809], [70.24180603, 22.68180466], [70.24291992, 22.68180466], [70.24291992, 22.68152809], [70.24318695, 22.68153191], [70.24318695, 22.68125153], [70.24291992, 22.68125153], [70.24291992, 22.68096924], [70.24263763, 22.68097305], [70.24263763, 22.68069458], [70.24236298, 22.68069458], [70.24236298, 22.68041611], [70.24208069, 22.68042183], [70.24208069, 22.67984962], [70.24291992, 22.67985916], [70.24291992, 22.67930603], [70.24318695, 22.67930984], [70.24318695, 22.67902756], [70.24375153, 22.67902756], [70.24375153, 22.67847061], [70.24458313, 22.67847061], [70.24458313, 22.67930984], [70.2454071, 22.67930984], [70.2454071, 22.68042183], [70.24514008, 22.68042183], [70.24514008, 22.68125153], [70.2454071, 22.68125153], [70.2454071, 22.68153191], [70.24514008, 22.68152809], [70.24514008, 22.6823616], [70.2454071, 22.6823616], [70.2454071, 22.68264008], [70.24569702, 22.68264008], [70.24569702, 22.68292046], [70.24597168, 22.68292046], [70.24597168, 22.68320274], [70.24624634, 22.68319511], [70.24624634, 22.68347359], [70.24819183, 22.68346977], [70.24819183, 22.68375015], [70.24874878, 22.68375015], [70.24874878, 22.68431091], [70.24903107, 22.68431091], [70.24903107, 22.68514061], [70.24931335, 22.68514061], [70.24931335, 22.68542099], [70.24903107, 22.68542099], [70.24903107, 22.68764114], [70.24931335, 22.68764114], [70.24931335, 22.68791962], [70.24958038, 22.6879158], [70.24958038, 22.68819427], [70.24986267, 22.68819046], [70.24986267, 22.68904114], [70.24847412, 22.68902779], [70.24847412, 22.6898613], [70.24930573, 22.6898613], [70.24930573, 22.69013977], [70.24958038, 22.69013977], [70.24958038, 22.68985939], [70.25068665, 22.68985939], [70.25068665, 22.69013977], [70.25096893, 22.69013977], [70.25096893, 22.69042015], [70.24930573, 22.69041634], [70.24930573, 22.69069481], [70.24903107, 22.69069481], [70.24903107, 22.69097137], [70.24986267, 22.69096947], [70.24986267, 22.69124985], [70.25013733, 22.69124985], [70.25013733, 22.69152832], [70.25125122, 22.69152641], [70.25125122, 22.69180489], [70.25152588, 22.69180489], [70.25152588, 22.69069481], [70.25180817, 22.69069481], [70.25180817, 22.69097137], [70.25235748, 22.69096947], [70.25235748, 22.69152832], [70.25208282, 22.69152641], [70.25208282, 22.69208336], [70.25263977, 22.69207954], [70.25263977, 22.6926384], [70.25319672, 22.6926384], [70.25319672, 22.69292068], [70.25208282, 22.69292068], [70.25208282, 22.69319916], [70.25180817, 22.69319534], [70.25180817, 22.69347191], [70.25208282, 22.69346809], [70.25208282, 22.69374847], [70.25180817, 22.69374847], [70.25180817, 22.69403076], [70.25154114, 22.69403076], [70.25154114, 22.69292068], [70.25125122, 22.69292068], [70.25125122, 22.69319916], [70.25096893, 22.69319534], [70.25096893, 22.69347191], [70.25068665, 22.69346809], [70.25068665, 22.69430923], [70.25041962, 22.69430923], [70.25041962, 22.69486237], [70.25068665, 22.69486237], [70.25068665, 22.69457817], [70.25096893, 22.69457817], [70.25096893, 22.69486237], [70.25125122, 22.69486237], [70.25125122, 22.69430923], [70.25152588, 22.69430542], [70.25152588, 22.69458389], [70.25180817, 22.69457817], [70.25180817, 22.69486237], [70.25208282, 22.69486237], [70.25208282, 22.69514275], [70.25180817, 22.69514275], [70.25180817, 22.69625282], [70.25152588, 22.69625282], [70.25152588, 22.69597244], [70.25125122, 22.69597244], [70.25125122, 22.69569206], [70.25096893, 22.69569206], [70.25096893, 22.6954174], [70.25068665, 22.69542122], [70.25068665, 22.69514275], [70.24986267, 22.69514275], [70.24986267, 22.69542122], [70.24930573, 22.6954174], [70.24930573, 22.69569206], [70.24903107, 22.69569016], [70.24903107, 22.69625282], [70.24874878, 22.69625282], [70.24874878, 22.69652939], [70.24848175, 22.69652939], [70.24848175, 22.69597244], [70.24764252, 22.69597244], [70.24764252, 22.69625282], [70.2470932, 22.69625282], [70.2470932, 22.69652939], [70.24652863, 22.69652939], [70.24652863, 22.69597244], [70.24597168, 22.69597244], [70.24597168, 22.69652939], [70.24569702, 22.69652939], [70.24569702, 22.69625282], [70.24485779, 22.69625282], [70.24485779, 22.69652939], [70.24514008, 22.69652939], [70.24514008, 22.69680977], [70.24458313, 22.69680977], [70.24458313, 22.69652939], [70.24318695, 22.69652939], [70.24318695, 22.69625282], [70.24208069, 22.69625282], [70.24208069, 22.69652939], [70.24153137, 22.69652939], [70.24153137, 22.69625282], [70.24069214, 22.69625282], [70.24069214, 22.69569016], [70.23958588, 22.69569206], [70.23958588, 22.69597244], [70.23902893, 22.69597244], [70.23902893, 22.69625282], [70.23874664, 22.69625282], [70.23874664, 22.69680977], [70.23902893, 22.69680977], [70.23902893, 22.69763947], [70.23928833, 22.69763947], [70.23928833, 22.69791985], [70.23960114, 22.69791985], [70.23960114, 22.69902992], [70.23930359, 22.69902802], [70.23930359, 22.69958305], [70.23902893, 22.69958115], [70.23902893, 22.70014], [70.23874664, 22.70014], [70.23874664, 22.70042038], [70.23847198, 22.70042038], [70.23847198, 22.70181084], [70.23874664, 22.70181084], [70.23874664, 22.70236015], [70.23928833, 22.70236015], [70.23928833, 22.70207977], [70.23958588, 22.70208359], [70.23958588, 22.70236015], [70.23986053, 22.70236015], [70.23986053, 22.70264053], [70.24041748, 22.70264053], [70.24041748, 22.70292091], [70.24124908, 22.70291519], [70.24124908, 22.70319366], [70.24236298, 22.70319366], [70.24236298, 22.70347214], [70.24291992, 22.70347214], [70.24291992, 22.70402718], [70.24319458, 22.70402718], [70.24319458, 22.70458412], [70.24346924, 22.70458031], [70.24346924, 22.70486069], [70.24430847, 22.70486069], [70.24430847, 22.70513916], [70.24485779, 22.70513725], [70.24485779, 22.70597267], [70.24514008, 22.70597076], [70.24514008, 22.70653152], [70.24485779, 22.70653152], [70.24485779, 22.7068119], [70.24375153, 22.7068119], [70.24375153, 22.70653152], [70.24346924, 22.70653152], [70.24346924, 22.70624924], [70.24318695, 22.70624924], [70.24318695, 22.70597076], [70.24291992, 22.70597267], [70.24291992, 22.7056942], [70.24236298, 22.7056942], [70.24236298, 22.70541954], [70.24208069, 22.70541954], [70.24208069, 22.70513916], [70.24180603, 22.70513916], [70.24180603, 22.70486069], [70.24153137, 22.70486069], [70.24153137, 22.70430946], [70.24124908, 22.70430946], [70.24124908, 22.70401955], [70.2409668, 22.70401955], [70.2409668, 22.70430946], [70.24069214, 22.70430565], [70.24069214, 22.70458412], [70.24041748, 22.70458031], [70.24041748, 22.70513916], [70.24069214, 22.70513725], [70.24069214, 22.70597267], [70.24124908, 22.70597076], [70.24124908, 22.70624924], [70.24153137, 22.70624924], [70.24153137, 22.7068119], [70.24124908, 22.7068119], [70.24124908, 22.70735931], [70.24153137, 22.70735931], [70.24153137, 22.70792007], [70.24180603, 22.70791626], [70.24180603, 22.70819473], [70.24208069, 22.70819473], [70.24208069, 22.70846939], [70.24263763, 22.70846939], [70.24263763, 22.70903015], [70.24291992, 22.70902824], [70.24291992, 22.70930481], [70.24319458, 22.70930481], [70.24319458, 22.70902824], [70.24346924, 22.70902824], [70.24346924, 22.70930481], [70.24375153, 22.70930481], [70.24375153, 22.70958328], [70.24402618, 22.70958328], [70.24402618, 22.70986366], [70.24430847, 22.70986176], [70.24430847, 22.71042061], [70.24597168, 22.71041679], [70.24597168, 22.71097374], [70.24624634, 22.71097183], [70.24624634, 22.71125031], [70.24652863, 22.71125031], [70.24652863, 22.71153069], [70.24764252, 22.71153069], [70.24764252, 22.71181107], [70.24874878, 22.71180534], [70.24874878, 22.71208382], [70.24930573, 22.71208382], [70.24930573, 22.71069527], [70.24903107, 22.7107029], [70.24903107, 22.70875168], [70.24958038, 22.70875168], [70.24958038, 22.70735931], [70.24930573, 22.70735931], [70.24930573, 22.70680618], [70.24903107, 22.7068119], [70.24903107, 22.70513916], [70.24931335, 22.70513916], [70.24931335, 22.70486069], [70.25013733, 22.70486069], [70.25013733, 22.70541954], [70.25041962, 22.70541573], [70.25041962, 22.70597267], [70.25069427, 22.70597267], [70.25069427, 22.7056942], [70.25096893, 22.7056942], [70.25096893, 22.70541573], [70.25125122, 22.70541954], [70.25125122, 22.70513916], [70.25180817, 22.70513916], [70.25180817, 22.70486069], [70.25319672, 22.70486069], [70.25319672, 22.70597267], [70.25428772, 22.70597076], [70.25428772, 22.70624924], [70.25485992, 22.70624924], [70.25485992, 22.70653152], [70.25514221, 22.70653152], [70.25514221, 22.70735931], [70.25485992, 22.70735931], [70.25485992, 22.7076416], [70.25514221, 22.7076416], [70.25514221, 22.70792007], [70.25541687, 22.70791626], [70.25541687, 22.70846939], [70.25514221, 22.70846939], [70.25514221, 22.71042061], [70.25485992, 22.71042061], [70.25485992, 22.71153069], [70.25514221, 22.71153069], [70.25514221, 22.71236038], [70.25541687, 22.71236038], [70.25541687, 22.71264076], [70.25485992, 22.71264076], [70.25485992, 22.71292114], [70.25402832, 22.71291733], [70.25402832, 22.7131958], [70.25347137, 22.7131958], [70.25347137, 22.71458244], [70.25402832, 22.71458054], [70.25402832, 22.71486092], [70.25428772, 22.71486092], [70.25428772, 22.71430969], [70.25514221, 22.71430969], [70.25514221, 22.71513939], [70.25485992, 22.71513939], [70.25485992, 22.7159729], [70.25458527, 22.7159729], [70.25458527, 22.71708298], [70.25428772, 22.71708107], [70.25428772, 22.71763992], [70.25402832, 22.71763611], [70.25402832, 22.71847153], [70.25374603, 22.71846962], [70.25374603, 22.71931076], [70.25347137, 22.71930504], [70.25347137, 22.71986008], [70.25374603, 22.71985817], [70.25374603, 22.72042084], [70.25402832, 22.72041893], [70.25402832, 22.72097015], [70.25428772, 22.72096825], [70.25428772, 22.72153282], [70.25485992, 22.72153282], [70.25485992, 22.72180939], [70.25541687, 22.72180939], [70.25541687, 22.72236252], [70.25514221, 22.72236252], [70.25514221, 22.7226429], [70.25458527, 22.72263908], [70.25458527, 22.72319412], [70.25485992, 22.72319031], [70.25485992, 22.72402954], [70.25514221, 22.72402954], [70.25514221, 22.72430992], [70.25541687, 22.72430992], [70.25541687, 22.72402954], [70.25569153, 22.72402954], [70.25569153, 22.72375107], [70.25596619, 22.72375107], [70.25596619, 22.7234726], [70.25791931, 22.7234726], [70.25791931, 22.72430992], [70.25846863, 22.72430992], [70.25846863, 22.72515106], [70.25875092, 22.72515106], [70.25875092, 22.72653008], [70.25819397, 22.72652817], [70.25819397, 22.72680473], [70.25736237, 22.72680473], [70.25736237, 22.72652817], [70.25653076, 22.72653008], [70.25653076, 22.72624969], [70.25457764, 22.72624969], [70.25457764, 22.72597122], [70.25430298, 22.72597313], [70.25430298, 22.72430611], [70.25402832, 22.72430992], [70.25402832, 22.72402954], [70.25374603, 22.72402954], [70.25374603, 22.72375107], [70.25208282, 22.72375107], [70.25208282, 22.72430992], [70.25125122, 22.72430611], [70.25125122, 22.72458458], [70.25096893, 22.72458458], [70.25096893, 22.72569466], [70.25152588, 22.72569466], [70.25152588, 22.72597313], [70.25180817, 22.72597122], [70.25180817, 22.72624969], [70.25208282, 22.72624969], [70.25208282, 22.72653008], [70.25291443, 22.72652817], [70.25291443, 22.72680473], [70.25375366, 22.72680473], [70.25375366, 22.72708321], [70.25402832, 22.72707939], [70.25402832, 22.72764015], [70.25430298, 22.72763824], [70.25430298, 22.72819519], [70.25402832, 22.72818947], [70.25402832, 22.72875023], [70.25374603, 22.72875023], [70.25374603, 22.72931099], [70.25319672, 22.72931099], [70.25319672, 22.73014069], [70.25347137, 22.73014069], [70.25347137, 22.72986031], [70.25374603, 22.72986031], [70.25374603, 22.72957993], [70.25402832, 22.72958374], [70.25402832, 22.72930527], [70.25428772, 22.72931099], [70.25428772, 22.72903061], [70.25457764, 22.72903061], [70.25457764, 22.72875023], [70.25541687, 22.72875023], [70.25541687, 22.72903061], [70.25569153, 22.72903061], [70.25569153, 22.72931099], [70.25541687, 22.72931099], [70.25541687, 22.72986031], [70.25458527, 22.72986031], [70.25458527, 22.73069382], [70.25430298, 22.73069382], [70.25430298, 22.73097229], [70.25402832, 22.73096085], [70.25402832, 22.73236084], [70.25319672, 22.73236084], [70.25319672, 22.73291969], [70.25291443, 22.73291588], [70.25291443, 22.73347282], [70.25319672, 22.73347092], [70.25319672, 22.73374939], [70.25402832, 22.73374939], [70.25402832, 22.73319054], [70.25430298, 22.73319435], [70.25430298, 22.73263741], [70.25457764, 22.73264122], [70.25457764, 22.73236084], [70.25514221, 22.73236084], [70.25514221, 22.73180962], [70.25541687, 22.73180962], [70.25541687, 22.73069], [70.25569153, 22.73069382], [70.25569153, 22.73041725], [70.25624847, 22.73042107], [70.25624847, 22.73014069], [70.25846863, 22.73014069], [70.25846863, 22.73042107], [70.25902557, 22.73041725], [70.25902557, 22.73069382], [70.25958252, 22.73069382], [70.25958252, 22.73097229], [70.25985718, 22.73096085], [70.25985718, 22.73125076], [70.26042175, 22.73125076], [70.26041412, 22.73097229], [70.26071167, 22.73096085], [70.26071167, 22.73264122], [70.26097107, 22.73264122], [70.26097107, 22.73291969], [70.26152802, 22.73291588], [70.26152802, 22.73319435], [70.26208496, 22.73319435], [70.26208496, 22.73347282], [70.26180267, 22.73347282], [70.26180267, 22.7345829], [70.26208496, 22.7345829], [70.26208496, 22.73485947], [70.26235962, 22.73485947], [70.26235962, 22.73513794], [70.26208496, 22.73514175], [70.26208496, 22.73569489], [70.26264191, 22.73569489], [70.26264191, 22.73736382], [70.26291656, 22.73736191], [70.26291656, 22.73764038], [70.26319122, 22.73764038], [70.26319122, 22.73792076], [70.26403046, 22.73791695], [70.26403046, 22.73819351], [70.26457977, 22.73819351], [70.26457977, 22.73763847], [70.26431274, 22.73764038], [70.26431274, 22.73736191], [70.26403046, 22.73736382], [70.26403046, 22.73680496], [70.26431274, 22.73681068], [70.26431274, 22.73625183], [70.26597595, 22.73625183], [70.26597595, 22.7365303], [70.26625061, 22.7365303], [70.26625061, 22.73681068], [70.26651764, 22.73681068], [70.26651764, 22.73709106], [70.26680756, 22.73708344], [70.26680756, 22.73736382], [70.2673645, 22.73736382], [70.2673645, 22.73708344], [70.26763916, 22.73709106], [70.26763916, 22.7365303], [70.26819611, 22.7365303], [70.26819611, 22.73625183], [70.26875305, 22.73625183], [70.26875305, 22.73596954], [70.26930237, 22.73596954], [70.26930237, 22.73569489], [70.26958466, 22.73569489], [70.26958466, 22.73541641], [70.26985931, 22.73542023], [70.26985931, 22.73485947], [70.26958466, 22.73485947], [70.26958466, 22.73430634], [70.26930237, 22.73431969], [70.26930237, 22.73403168], [70.2701416, 22.73403168], [70.2701416, 22.73374939], [70.27041626, 22.73374939], [70.27041626, 22.73319054], [70.27097321, 22.73319054], [70.27097321, 22.73374939], [70.27124786, 22.73374939], [70.27124786, 22.73347092], [70.27153015, 22.73347282], [70.27153015, 22.73263741], [70.2720871, 22.73263741], [70.2720871, 22.73319435], [70.27263641, 22.73319435], [70.27263641, 22.73347282], [70.27430725, 22.73347282], [70.27430725, 22.73319435], [70.27458191, 22.73319435], [70.27458191, 22.73236084], [70.27485657, 22.73236084], [70.27485657, 22.73208046], [70.27513885, 22.73208237], [70.27513885, 22.7318058], [70.27542114, 22.73180962], [70.27542114, 22.73125076], [70.27597046, 22.73125076], [70.27597046, 22.73208427], [70.2756958, 22.73208427], [70.2756958, 22.73347282], [70.27541351, 22.73347282], [70.27541351, 22.7345829], [70.27625275, 22.7345829], [70.27625275, 22.73485947], [70.2765274, 22.73485947], [70.2765274, 22.73514175], [70.27707672, 22.73514175], [70.27707672, 22.73542023], [70.27735901, 22.73541641], [70.27735901, 22.73569489], [70.2776413, 22.73568916], [70.2776413, 22.73681068], [70.27791595, 22.73680496], [70.27791595, 22.73736382], [70.27819824, 22.73736191], [70.27819824, 22.73764038], [70.27958679, 22.73764038], [70.27958679, 22.73792076], [70.27986145, 22.73791695], [70.27986145, 22.73847389], [70.27958679, 22.73847008], [70.27958679, 22.73931122], [70.27986145, 22.7393055], [70.27986145, 22.73958588], [70.28013611, 22.73958015], [70.28013611, 22.73986053], [70.2804184, 22.73986053], [70.2804184, 22.74013901], [70.28069305, 22.74013901], [70.28069305, 22.74069595], [70.28125, 22.74069595], [70.28125, 22.74013901], [70.28236389, 22.74013901], [70.28236389, 22.74069595], [70.28263855, 22.74069023], [70.28263855, 22.74125099], [70.28320312, 22.74125099], [70.28320312, 22.74152946], [70.28347015, 22.74152946], [70.28347015, 22.74180984], [70.2840271, 22.74180412], [70.2840271, 22.7420826], [70.28430176, 22.74208069], [70.28430939, 22.74263954], [70.2848587, 22.74263954], [70.2848587, 22.74291992], [70.28514099, 22.74291992], [70.28514099, 22.74263954], [70.28569794, 22.74263954], [70.28569794, 22.74319458], [70.2859726, 22.74319077], [70.2859726, 22.74374962], [70.28624725, 22.74374962], [70.28624725, 22.74430466], [70.28652954, 22.74430466], [70.28652954, 22.74458313], [70.2868042, 22.74458313], [70.2868042, 22.7448616], [70.28708649, 22.7448616], [70.28708649, 22.74430466], [70.28765106, 22.74430084], [70.28765106, 22.74513817], [70.28791809, 22.74513817], [70.28791809, 22.74542046], [70.28819275, 22.74542046], [70.28819275, 22.74570084], [70.28847504, 22.74569511], [70.28847504, 22.74597168], [70.28874969, 22.74596977], [70.28874969, 22.74681091], [70.28819275, 22.74681091], [70.28819275, 22.74653053], [70.28791809, 22.74653053], [70.28791809, 22.74596977], [70.28765106, 22.74596977], [70.28765106, 22.7462616], [70.28736115, 22.7462616], [70.28736115, 22.74653053], [70.28542328, 22.74653053], [70.28542328, 22.74681091], [70.28375244, 22.74680519], [70.28375244, 22.74708366], [70.28320312, 22.74707985], [70.28320312, 22.74764061], [70.28291321, 22.74764061], [70.28291321, 22.74791908], [70.2820816, 22.74791718], [70.2820816, 22.74819374], [70.28236389, 22.74819374], [70.28236389, 22.74847031], [70.28263855, 22.74847031], [70.28263855, 22.74875259], [70.28320312, 22.74875259], [70.2831955, 22.74847031], [70.2840271, 22.74847031], [70.2840271, 22.74819374], [70.28430176, 22.74819374], [70.28430176, 22.74791718], [70.2848587, 22.74791908], [70.2848587, 22.74764061], [70.28514099, 22.74764061], [70.28514099, 22.74735832], [70.28542328, 22.74735832], [70.28541565, 22.74708366], [70.28652954, 22.74707985], [70.28652954, 22.74735832], [70.28679657, 22.74735832], [70.28679657, 22.74764061], [70.28765106, 22.74764061], [70.28765106, 22.74791908], [70.28902435, 22.74791718], [70.28902435, 22.74819374], [70.28930664, 22.74819374], [70.28930664, 22.74847031], [70.2895813, 22.74847031], [70.2895813, 22.74875259], [70.28985596, 22.74875259], [70.28985596, 22.74847031], [70.29013824, 22.74847031], [70.29013824, 22.74819374], [70.29180908, 22.74818993], [70.29180908, 22.74875259], [70.2923584, 22.74875259], [70.2923584, 22.74932289], [70.29264069, 22.74932289], [70.29264069, 22.74903107], [70.29292297, 22.74903107], [70.29292297, 22.74875259], [70.29345703, 22.74875259], [70.29345703, 22.74932289], [70.29319763, 22.74930573], [70.29319763, 22.7495842], [70.29374695, 22.74958038], [70.29374695, 22.74986267], [70.29458618, 22.74986267], [70.29458618, 22.75041962], [70.29486084, 22.7504158], [70.29486084, 22.75097275], [70.29458618, 22.75097275], [70.29458618, 22.75125122], [70.29402924, 22.75125122], [70.29402924, 22.75263977], [70.29514313, 22.75263977], [70.29514313, 22.75292015], [70.29569244, 22.75292015], [70.29569244, 22.75235939], [70.29624939, 22.7523613], [70.29624939, 22.75208473], [70.29652405, 22.75208473], [70.29652405, 22.75180626], [70.29708099, 22.75181007], [70.29708099, 22.75263977], [70.29682159, 22.75263977], [70.29682159, 22.75292015], [70.29708099, 22.75291634], [70.29708099, 22.75347137], [70.29763794, 22.75346947], [70.29763794, 22.75374985], [70.29818726, 22.75374985], [70.29818726, 22.75403023], [70.29846954, 22.75403023], [70.29846954, 22.75374985], [70.29902649, 22.75374985], [70.29902649, 22.75458336], [70.29930878, 22.75458336], [70.29930878, 22.75486183], [70.29846954, 22.75486183], [70.29846954, 22.7551384], [70.29818726, 22.75513077], [70.29818726, 22.75542068], [70.29792023, 22.75542068], [70.29792023, 22.75653076], [70.29818726, 22.75653076], [70.29818726, 22.75736046], [70.29875183, 22.75736046], [70.29875183, 22.75681114], [70.29930878, 22.75680542], [70.29930878, 22.75708389], [70.29959106, 22.75708008], [70.29959106, 22.75764084], [70.29985809, 22.75763893], [70.29985809, 22.75847244], [70.30041504, 22.75847244], [70.30041504, 22.75875092], [70.30069733, 22.75875092], [70.30069733, 22.75930977], [70.30097198, 22.75930977], [70.30097198, 22.75985909], [70.30124664, 22.75985909], [70.30124664, 22.76014137], [70.30179596, 22.76014137], [70.30179596, 22.75930977], [70.30152893, 22.75930977], [70.30152893, 22.75847054], [70.30124664, 22.75847244], [70.30124664, 22.75763893], [70.30319214, 22.75763893], [70.30319214, 22.75847244], [70.30291748, 22.75847054], [70.30291748, 22.75985909], [70.30262756, 22.75985909], [70.30262756, 22.76042175], [70.30236053, 22.76041603], [70.30236053, 22.7606945], [70.30208588, 22.7606945], [70.30208588, 22.76097107], [70.30180359, 22.76097107], [70.30180359, 22.76235962], [70.30208588, 22.76235962], [70.30208588, 22.76430511], [70.30180359, 22.76430511], [70.30180359, 22.76458359], [70.30208588, 22.76457977], [70.30208588, 22.76514053], [70.30262756, 22.76514053], [70.30262756, 22.76542091], [70.30291748, 22.7654171], [70.30291748, 22.76597214], [70.30236053, 22.76597023], [70.30236053, 22.76625061], [70.30208588, 22.76625061], [70.30208588, 22.76653099], [70.30179596, 22.76653099], [70.30179596, 22.76680946], [70.30291748, 22.76680565], [70.30291748, 22.76708412], [70.30319214, 22.76708412], [70.30319214, 22.76680565], [70.3034668, 22.76680946], [70.3034668, 22.76597023], [70.30374908, 22.76597214], [70.30374908, 22.7654171], [70.30403137, 22.76542091], [70.30403137, 22.76514053], [70.30458069, 22.76513863], [70.30458069, 22.76569366], [70.30486298, 22.76569366], [70.30486298, 22.76597214], [70.30513763, 22.76597023], [70.30513763, 22.76625061], [70.30541992, 22.76625061], [70.30541992, 22.76680946], [70.30486298, 22.76680565], [70.30486298, 22.76708412], [70.30458069, 22.76707077], [70.30458069, 22.76736069], [70.30430603, 22.76736069], [70.30430603, 22.76764107], [70.30458069, 22.76763916], [70.30458069, 22.76847267], [70.30430603, 22.76847076], [70.30430603, 22.76875114], [70.30374908, 22.76875114], [70.30374908, 22.76847076], [70.30291748, 22.76847076], [70.30291748, 22.76931], [70.30263519, 22.76930618], [70.30263519, 22.76958275], [70.30124664, 22.76958275], [70.30124664, 22.76930618], [70.30069733, 22.76930618], [70.30069733, 22.76958275], [70.30041504, 22.76958275], [70.30041504, 22.77069473], [70.30097198, 22.77069473], [70.30097198, 22.7709713], [70.30124664, 22.77096939], [70.30124664, 22.77124977], [70.30097198, 22.77124977], [70.30097198, 22.77152824], [70.30124664, 22.77152634], [70.30124664, 22.77180481], [70.30152893, 22.77180481], [70.30152893, 22.77152634], [70.30263519, 22.77152634], [70.30263519, 22.77236176], [70.30291748, 22.77235985], [70.30291748, 22.77263832], [70.3034668, 22.77263832], [70.3034668, 22.77235985], [70.30403137, 22.77235985], [70.30403137, 22.77263832], [70.30374908, 22.77263832], [70.30374908, 22.77319908], [70.30430603, 22.77319908], [70.30430603, 22.7737484], [70.30458069, 22.7737484], [70.30458069, 22.77430916], [70.30513763, 22.77430534], [70.30513763, 22.77458382], [70.30568695, 22.77457809], [70.30568695, 22.77514267], [70.30541992, 22.77514267], [70.30541992, 22.77542114], [70.30569458, 22.77541733], [70.30569458, 22.77597046], [70.30596924, 22.77597046], [70.30596924, 22.77625275], [70.30680847, 22.7762394], [70.30680847, 22.77736282], [70.30708313, 22.77736282], [70.30708313, 22.77763939], [70.30680847, 22.77763939], [70.30680847, 22.77791977], [70.30708313, 22.77791595], [70.30708313, 22.77847481], [70.30680847, 22.7784729], [70.30680847, 22.78013992], [70.30568695, 22.78013992], [70.30568695, 22.77985954], [70.30541992, 22.77986145], [70.30541992, 22.77958488], [70.30486298, 22.77958488], [70.30486298, 22.77930641], [70.30403137, 22.77930641], [70.30403137, 22.77902794], [70.30374908, 22.77902985], [70.30374908, 22.77874947], [70.30319214, 22.77874947], [70.30319214, 22.7784729], [70.30263519, 22.77847481], [70.30263519, 22.77819443], [70.30152893, 22.77819443], [70.30152893, 22.77791595], [70.30124664, 22.77791977], [70.30124664, 22.77763939], [70.30097198, 22.77763939], [70.30097198, 22.77791977], [70.30041504, 22.77791595], [70.30041504, 22.77819443], [70.30097198, 22.77819443], [70.30097198, 22.77847481], [70.30152893, 22.7784729], [70.30152893, 22.77874947], [70.30179596, 22.77874947], [70.30179596, 22.77902985], [70.30208588, 22.77902794], [70.30208588, 22.77930641], [70.30236053, 22.77930641], [70.30236053, 22.77986145], [70.30262756, 22.77985954], [70.30262756, 22.7804203], [70.30319214, 22.7804203], [70.30319214, 22.78070068], [70.30403137, 22.78069305], [70.30403137, 22.78097153], [70.30458069, 22.78096962], [70.30458069, 22.78125], [70.30486298, 22.78125], [70.30486298, 22.78153038], [70.30541992, 22.78153038], [70.30541992, 22.78181076], [70.30569458, 22.78180695], [70.30569458, 22.78208351], [70.30596924, 22.78208351], [70.30596924, 22.78236198], [70.30764008, 22.78236198], [70.30764008, 22.78347206], [70.30735779, 22.78347015], [70.30735779, 22.78403091], [70.30764008, 22.78403091], [70.30764008, 22.78430939], [70.30874634, 22.78430557], [70.30874634, 22.78458405], [70.30902863, 22.78458023], [70.30902863, 22.78486061], [70.3095932, 22.78486061], [70.3095932, 22.78513908], [70.30986023, 22.78513718], [70.30986023, 22.7859726], [70.31014252, 22.78597069], [70.31014252, 22.78624916], [70.31041718, 22.78624916], [70.31041718, 22.78652763], [70.31069183, 22.78652763], [70.31069183, 22.78681183], [70.31182098, 22.78681183], [70.31182098, 22.78652763], [70.31208038, 22.78652763], [70.31208038, 22.78569031], [70.31291962, 22.78569412], [70.31291962, 22.78708267], [70.31263733, 22.78708076], [70.31263733, 22.78792191], [70.31236267, 22.78792191], [70.31236267, 22.7887516], [70.31208038, 22.7887516], [70.31208038, 22.78986359], [70.31180573, 22.78986359], [70.31180573, 22.79125023], [70.31124878, 22.7912426], [70.31124878, 22.79153061], [70.31097412, 22.7915287], [70.31097412, 22.79208374], [70.31069183, 22.79207993], [70.31069183, 22.79236031], [70.30986023, 22.79236031], [70.30986023, 22.79207993], [70.3095932, 22.79207993], [70.3095932, 22.79264069], [70.30986023, 22.79264069], [70.30986023, 22.79292107], [70.31014252, 22.79291725], [70.31014252, 22.79319572], [70.31069183, 22.79319572], [70.31069183, 22.79347229], [70.31096649, 22.79347038], [70.31096649, 22.79403114], [70.31069183, 22.79402733], [70.31069183, 22.7943058], [70.30986023, 22.79430008], [70.30986023, 22.79486084], [70.30930328, 22.79486084], [70.30930328, 22.79514122], [70.30902863, 22.79514122], [70.30902863, 22.79541969], [70.30930328, 22.79541588], [70.30930328, 22.79597282], [70.31041718, 22.79597092], [70.31041718, 22.79624939], [70.31096649, 22.79624939], [70.31096649, 22.79652977], [70.31208038, 22.79652977], [70.31208038, 22.79597092], [70.31236267, 22.79597282], [70.31236267, 22.79541588], [70.31319427, 22.79541588], [70.31319427, 22.79597282], [70.31375122, 22.79597092], [70.31375122, 22.79624939], [70.31485748, 22.79624939], [70.31485748, 22.79652977], [70.31569672, 22.79652786], [70.31569672, 22.7970829], [70.31625366, 22.7970829], [70.31625366, 22.79680634], [70.31652832, 22.79681015], [70.31652832, 22.79652977], [70.3170929, 22.79652977], [70.3170929, 22.79681015], [70.31735992, 22.79681015], [70.31735992, 22.79737091], [70.31791687, 22.79737091], [70.31791687, 22.79708099], [70.31819153, 22.7970829], [70.31819153, 22.79680634], [70.31846619, 22.79681015], [70.31846619, 22.79652977], [70.31986237, 22.79652977], [70.31986237, 22.79681015], [70.32013702, 22.79681015], [70.32013702, 22.79737091], [70.32041931, 22.79737091], [70.32041931, 22.79763985], [70.32069397, 22.79763794], [70.32069397, 22.79819489], [70.32096863, 22.79819107], [70.32096863, 22.79874992], [70.32013702, 22.79874992], [70.32013702, 22.7990284], [70.31819153, 22.7990284], [70.31819153, 22.79846954], [70.31791687, 22.79846954], [70.31791687, 22.7990284], [70.31762695, 22.7990284], [70.31762695, 22.79931068], [70.31680298, 22.79931068], [70.31680298, 22.79874992], [70.31625366, 22.79874992], [70.31625366, 22.79986191], [70.31652832, 22.79985809], [70.31652832, 22.8004303], [70.31680298, 22.80041695], [70.31680298, 22.80069351], [70.31762695, 22.8006897], [70.31762695, 22.80153275], [70.31708527, 22.80152702], [70.31708527, 22.80208397], [70.31735992, 22.80208015], [70.31735992, 22.80264282], [70.31762695, 22.80264282], [70.31762695, 22.80291939], [70.31791687, 22.80291939], [70.31791687, 22.8037529], [70.31819153, 22.80374908], [70.31819153, 22.8045845], [70.31846619, 22.80458069], [70.31846619, 22.80541992], [70.31874847, 22.80541611], [70.31874847, 22.80569458], [70.31903076, 22.80569458], [70.31903076, 22.80597305], [70.31986237, 22.80597115], [70.31986237, 22.80653], [70.32013702, 22.80652809], [70.32013702, 22.80708313], [70.32069397, 22.80708313], [70.32069397, 22.8073616], [70.32096863, 22.8073597], [70.32096863, 22.80764008], [70.32125092, 22.80764008], [70.32125092, 22.80792046], [70.3215332, 22.80792046], [70.3215332, 22.80541992], [70.32180786, 22.80541992], [70.32180786, 22.80513954], [70.32208252, 22.80513954], [70.32208252, 22.80486107], [70.32235718, 22.80486107], [70.32235718, 22.80458069], [70.32263947, 22.8045845], [70.32263947, 22.80319214], [70.32291412, 22.80319214], [70.32291412, 22.80291748], [70.32347107, 22.80291748], [70.32347107, 22.80319214], [70.32375336, 22.80319214], [70.32375336, 22.8045845], [70.32402802, 22.80458069], [70.32402802, 22.80513954], [70.32430267, 22.80513954], [70.32430267, 22.80541992], [70.32458496, 22.80541611], [70.32458496, 22.80569458], [70.32485962, 22.80569458], [70.32485962, 22.80597305], [70.32514191, 22.80597305], [70.32514191, 22.80680466], [70.32541656, 22.80680084], [70.32541656, 22.80792046], [70.32514191, 22.80791664], [70.32514191, 22.80847168], [70.32430267, 22.80846977], [70.32430267, 22.80903053], [70.32402802, 22.80903053], [70.32402802, 22.81014061], [70.32459259, 22.81014061], [70.32459259, 22.81042099], [70.32485962, 22.81041718], [70.32485962, 22.81069374], [70.32514191, 22.81069374], [70.32514191, 22.81041718], [70.32569122, 22.81041718], [70.32569122, 22.81097221], [70.32596588, 22.81097031], [70.32596588, 22.81153107], [70.32624817, 22.81153107], [70.32624817, 22.81236839], [70.32653046, 22.81236076], [70.32653046, 22.81319427], [70.32682037, 22.81319046], [70.32682037, 22.81374931], [70.32736206, 22.81374931], [70.32736206, 22.8140316], [70.32791901, 22.8140316], [70.32791901, 22.81431007], [70.32847595, 22.81430626], [70.32847595, 22.81458282], [70.32902527, 22.81458282], [70.32902527, 22.81485939], [70.32930756, 22.81485939], [70.32930756, 22.81541634], [70.33125305, 22.81541634], [70.33125305, 22.81596947], [70.33097076, 22.81596947], [70.33097076, 22.81653023], [70.33069611, 22.81653023], [70.33069611, 22.8176403], [70.33097076, 22.8176403], [70.33097076, 22.81792068], [70.33125305, 22.81792068], [70.33125305, 22.81820107], [70.33152771, 22.81819534], [70.33152771, 22.81847382], [70.33180237, 22.81847382], [70.33180237, 22.8195858], [70.33207703, 22.81958008], [70.33207703, 22.81986046], [70.33235931, 22.81986046], [70.33235931, 22.82014084], [70.3326416, 22.82013893], [70.3326416, 22.82069588], [70.33291626, 22.82069016], [70.33291626, 22.82180977], [70.3326416, 22.82180405], [70.3326416, 22.82208252], [70.33291626, 22.82208061], [70.33291626, 22.82236099], [70.33347321, 22.82236099], [70.33347321, 22.82208061], [70.33513641, 22.82208061], [70.33513641, 22.82236099], [70.3354187, 22.82236099], [70.3354187, 22.82263947], [70.33569336, 22.82263947], [70.33569336, 22.8231945], [70.33597565, 22.8231945], [70.33597565, 22.82347298], [70.33513641, 22.82347107], [70.33513641, 22.8243103], [70.3354187, 22.82430649], [70.3354187, 22.82458305], [70.33735657, 22.82458115], [70.33735657, 22.82542038], [70.33708191, 22.82542038], [70.33708191, 22.82624817], [70.3373642, 22.82624817], [70.3373642, 22.82708359], [70.33791351, 22.82708359], [70.33791351, 22.82735825], [70.3381958, 22.82735062], [70.3381958, 22.82763863], [70.33875275, 22.82763863], [70.33875275, 22.82819366], [70.33847046, 22.82818985], [70.33847046, 22.82930946], [70.33875275, 22.82930565], [70.33875275, 22.83041573], [70.3390274, 22.83041191], [70.3390274, 22.83152962], [70.33847046, 22.83152771], [70.33847046, 22.83208466], [70.33876038, 22.83208084], [70.33876038, 22.83292007], [70.3381958, 22.83291626], [70.3381958, 22.83319473], [70.33790588, 22.83319092], [70.33790588, 22.83348083], [70.33763885, 22.83348083], [70.33763885, 22.83374977], [70.3373642, 22.83374977], [70.3373642, 22.83430672], [70.33708191, 22.83430672], [70.33708191, 22.83486176], [70.33735657, 22.83485985], [70.33735657, 22.83542061], [70.33763885, 22.83541679], [70.33763885, 22.83597183], [70.33735657, 22.83596992], [70.33735657, 22.83736038], [70.33763885, 22.83736038], [70.33763885, 22.83903122], [70.33790588, 22.83903122], [70.33790588, 22.8401413], [70.3381958, 22.8401413], [70.3381958, 22.8409729], [70.33847046, 22.84096909], [70.33847046, 22.84181023], [70.33876038, 22.84181023], [70.33876038, 22.84264183], [70.3390274, 22.84263802], [70.3390274, 22.84347343], [70.33930206, 22.84346962], [70.33930206, 22.84403038], [70.33958435, 22.84402847], [70.33958435, 22.84458351], [70.33985901, 22.8445797], [70.33985901, 22.84542084], [70.3401413, 22.84541702], [70.3401413, 22.84597206], [70.34041595, 22.84597015], [70.34041595, 22.84680939], [70.34069824, 22.84680939], [70.34069824, 22.84736061], [70.3409729, 22.84736061], [70.3409729, 22.84791946], [70.34124756, 22.84791946], [70.34124756, 22.84848022], [70.34152985, 22.84848022], [70.34152985, 22.84875107], [70.34179688, 22.84875107], [70.34179688, 22.84902954], [70.34208679, 22.84902954], [70.34208679, 22.84930992], [70.34236145, 22.84930611], [70.34236145, 22.84958267], [70.3429184, 22.84958076], [70.3429184, 22.84986115], [70.34319305, 22.84986115], [70.34319305, 22.85013962], [70.34348297, 22.85013962], [70.34348297, 22.85041809], [70.34375, 22.85041618], [70.34375, 22.85069466], [70.34402466, 22.85069466], [70.34402466, 22.85097313], [70.34430695, 22.85097313], [70.34430695, 22.85152626], [70.3445816, 22.85152626], [70.3445816, 22.85208321], [70.34485626, 22.85207939], [70.34485626, 22.85263824], [70.34513855, 22.85263824], [70.34513855, 22.85320091], [70.34541321, 22.85320091], [70.34541321, 22.85374832], [70.34570313, 22.85374832], [70.34570313, 22.85403061], [70.34597015, 22.85403061], [70.34597015, 22.85430908], [70.34625244, 22.85430908], [70.34625244, 22.8548584], [70.3465271, 22.8548584], [70.3465271, 22.85514259], [70.34680176, 22.85514069], [70.34680939, 22.85569382], [70.34708405, 22.85569382], [70.34708405, 22.85597038], [70.3473587, 22.85597038], [70.3473587, 22.85625267], [70.34764099, 22.85625267], [70.34764099, 22.85680962], [70.34791565, 22.8568058], [70.34791565, 22.85708046], [70.34819794, 22.85708427], [70.34819794, 22.85847473], [70.3484726, 22.85847282], [70.3484726, 22.85931015], [70.34874725, 22.85930634], [70.34874725, 22.85958481], [70.3493042, 22.85958481], [70.3493042, 22.85986137], [70.34958649, 22.85985947], [70.34958649, 22.86013985], [70.34986115, 22.86013985], [70.34986115, 22.86042023], [70.35041809, 22.86042023], [70.35041809, 22.86181068], [70.35069275, 22.86180687], [70.35069275, 22.86236191], [70.3509903, 22.86236], [70.3509903, 22.86292076], [70.35124969, 22.86291695], [70.35124969, 22.86319351], [70.35151672, 22.8631897], [70.35151672, 22.86375046], [70.35180664, 22.86375046], [70.35180664, 22.86431122], [70.3520813, 22.86431122], [70.3520813, 22.86486053], [70.35235596, 22.86486053], [70.35235596, 22.86541748], [70.3529129, 22.86541748], [70.3529129, 22.86569405], [70.35319519, 22.86569405], [70.35319519, 22.86652756], [70.3529129, 22.86652756], [70.3529129, 22.8670826], [70.35319519, 22.8670826], [70.35319519, 22.86764145], [70.35346985, 22.86764145], [70.35346985, 22.86819458], [70.35373688, 22.86819077], [70.35373688, 22.86875153], [70.35402679, 22.86875153], [70.35402679, 22.86986351], [70.35373688, 22.8698597], [70.35373688, 22.87070084], [70.35430908, 22.87069511], [70.35430908, 22.87097359], [70.35457611, 22.87096977], [70.35457611, 22.87125015], [70.35597229, 22.87125015], [70.35597229, 22.87153053], [70.35624695, 22.87152863], [70.35624695, 22.87208366], [70.35679626, 22.87207985], [70.35679626, 22.87236023], [70.35708618, 22.87236023], [70.35708618, 22.87265015], [70.35736084, 22.87265015], [70.35736084, 22.87375069], [70.35764313, 22.87375069], [70.35764313, 22.87403107], [70.35791779, 22.87403107], [70.35791779, 22.87430954], [70.35819244, 22.87430573], [70.35819244, 22.8745842], [70.3584671, 22.87458038], [70.3584671, 22.87486076], [70.35874939, 22.87486076], [70.35874939, 22.87514114], [70.35902405, 22.87513924], [70.35902405, 22.87569427], [70.35930634, 22.87569427], [70.35930634, 22.87597275], [70.35958099, 22.87597084], [70.35958099, 22.87625122], [70.35987091, 22.87625122], [70.35987091, 22.87681007], [70.36013794, 22.87680626], [70.36013794, 22.87708282], [70.36042023, 22.87708282], [70.36042023, 22.8773613], [70.36068726, 22.87735939], [70.36068726, 22.87791824], [70.36096954, 22.87791634], [70.36096954, 22.87819481], [70.36125183, 22.87819099], [70.36125183, 22.87874985], [70.36152649, 22.87874985], [70.36152649, 22.87902832], [70.36180878, 22.87902832], [70.36180878, 22.87930489], [70.36208344, 22.87930489], [70.36208344, 22.87986183], [70.36235809, 22.87985992], [70.36235809, 22.8801384], [70.36264038, 22.8801384], [70.36264038, 22.88069916], [70.36291504, 22.88069534], [70.36291504, 22.88097191], [70.36319733, 22.88096809], [70.36319733, 22.88124847], [70.36347198, 22.88124847], [70.36347198, 22.88181114], [70.36374664, 22.88180542], [70.36374664, 22.88208389], [70.36402893, 22.88208008], [70.36402893, 22.88236237], [70.36429596, 22.88236237], [70.36429596, 22.88264275], [70.36458588, 22.88264084], [70.36458588, 22.88319206], [70.36486053, 22.88319206], [70.36486053, 22.88347054], [70.36513519, 22.88347054], [70.36513519, 22.88375282], [70.36541748, 22.88375282], [70.36541748, 22.88402939], [70.36567688, 22.88402939], [70.36567688, 22.88459015], [70.3659668, 22.88459015], [70.3659668, 22.8848629], [70.36624908, 22.8848629], [70.36624908, 22.88513947], [70.36653137, 22.88513947], [70.36653137, 22.8856945], [70.36680603, 22.8856945], [70.36680603, 22.88597488], [70.36708069, 22.88597107], [70.36708069, 22.88652992], [70.36736298, 22.88652802], [70.36736298, 22.88680077], [70.36763763, 22.88680649], [70.36763763, 22.88708305], [70.36791992, 22.88708115], [70.36791992, 22.88764954], [70.36818695, 22.88764954], [70.36818695, 22.88792038], [70.36846924, 22.88791656], [70.36846924, 22.8884716], [70.36873627, 22.8884697], [70.36873627, 22.88875008], [70.36902618, 22.88875008], [70.36902618, 22.88931084], [70.36930847, 22.88930511], [70.36930847, 22.88958359], [70.36958313, 22.88957977], [70.36958313, 22.89014053], [70.36985779, 22.89014053], [70.36985779, 22.89042091], [70.37014008, 22.89041519], [70.37014008, 22.89069366], [70.3704071, 22.89068985], [70.3704071, 22.89125061], [70.37069702, 22.89125061], [70.37069702, 22.89152908], [70.37097168, 22.89152908], [70.37097168, 22.89180946], [70.37124634, 22.89180946], [70.37124634, 22.89236069], [70.37152863, 22.89236069], [70.37152863, 22.89263916], [70.37180328, 22.89263725], [70.37180328, 22.8931942], [70.37208557, 22.8931942], [70.37208557, 22.89347267], [70.37236023, 22.89347076], [70.37236023, 22.89374924], [70.37264252, 22.89374924], [70.37264252, 22.8943119], [70.37291718, 22.89430618], [70.37291718, 22.89458275], [70.37319183, 22.89458084], [70.37319183, 22.89485931], [70.37346649, 22.89485931], [70.37346649, 22.89542007], [70.37374878, 22.89541626], [70.37374878, 22.89569473], [70.37403107, 22.89569473], [70.37403107, 22.89596939], [70.37431335, 22.89596939], [70.37431335, 22.89653015], [70.37458038, 22.89652824], [70.37458038, 22.89680481], [70.37486267, 22.89680481], [70.37486267, 22.89708138], [70.37513733, 22.89707947], [70.37513733, 22.89764023], [70.37541962, 22.89764023], [70.37541962, 22.89792061], [70.37568665, 22.89792061], [70.37568665, 22.8982029], [70.37596893, 22.8982029], [70.37596893, 22.89875031], [70.37625122, 22.89875031], [70.37625122, 22.89903069], [70.37652588, 22.89903069], [70.37652588, 22.89931107], [70.37680817, 22.89931107], [70.37680817, 22.89986038], [70.37708282, 22.89986038], [70.37708282, 22.90014076], [70.37735748, 22.90014076], [70.37735748, 22.90042114], [70.37763977, 22.90041733], [70.37763977, 22.9006958], [70.37791443, 22.9006958], [70.37791443, 22.90097237], [70.37819672, 22.90097046], [70.37819672, 22.90153122], [70.37847137, 22.90153122], [70.37847137, 22.90180969], [70.37875366, 22.90180588], [70.37875366, 22.90208244], [70.37902832, 22.90208054], [70.37902832, 22.90236092], [70.37930298, 22.90236092], [70.37930298, 22.90263939], [70.37958527, 22.90263939], [70.37958527, 22.90319443], [70.37985992, 22.90319443], [70.37985992, 22.9034729], [70.38014221, 22.90347099], [70.38014221, 22.90374947], [70.38041687, 22.90374947], [70.38041687, 22.90402985], [70.38067627, 22.90402985], [70.38067627, 22.90431023], [70.38097382, 22.90430641], [70.38097382, 22.90458298], [70.38124847, 22.90458298], [70.38124847, 22.90486145], [70.38153076, 22.90485954], [70.38153076, 22.90513992], [70.38181305, 22.90513992], [70.38181305, 22.9054203], [70.38208008, 22.90541649], [70.38208008, 22.90569496], [70.38236237, 22.90569496], [70.38236237, 22.90597153], [70.38263702, 22.90596962], [70.38263702, 22.90652847], [70.38291931, 22.90652847], [70.38291931, 22.90681076], [70.38319397, 22.90680504], [70.38319397, 22.90708351], [70.38346863, 22.9070797], [70.38346863, 22.90763855], [70.38375092, 22.90763855], [70.38375092, 22.90792084], [70.38402557, 22.90791702], [70.38402557, 22.90819359], [70.38430786, 22.90818977], [70.38430786, 22.90876007], [70.38458252, 22.90876007], [70.38458252, 22.90930939], [70.38486481, 22.90930557], [70.38486481, 22.90958405], [70.38513947, 22.90958023], [70.38513947, 22.90986252], [70.38597107, 22.90986252], [70.38597107, 22.90958023], [70.38652802, 22.90958405], [70.38652802, 22.90930557], [70.38761902, 22.90930557], [70.38791656, 22.90930557], [70.38791656, 22.90958405], [70.38846588, 22.90958023], [70.38846588, 22.90986252], [70.38903046, 22.90986252], [70.38903046, 22.9101429], [70.38957977, 22.9101429], [70.38957977, 22.91041946], [70.39013672, 22.91041756], [70.39013672, 22.91069221], [70.39069366, 22.91069221], [70.39069366, 22.91097069], [70.39125061, 22.91097069], [70.39125061, 22.91125107], [70.39180756, 22.91125107], [70.39180756, 22.91152954], [70.39235687, 22.91152954], [70.39235687, 22.91181946], [70.39291382, 22.91180611], [70.39291382, 22.91208458], [70.39347076, 22.91208076], [70.39347076, 22.91236115], [70.39402771, 22.91236115], [70.39402771, 22.91263962], [70.39457703, 22.91263962], [70.39457703, 22.91292], [70.39541626, 22.91291618], [70.39541626, 22.91319466], [70.39597321, 22.91319466], [70.39597321, 22.91347313], [70.39679718, 22.91347122], [70.39679718, 22.91374969], [70.39736176, 22.91374969], [70.39736176, 22.91403008], [70.39819336, 22.91402817], [70.39819336, 22.91430473], [70.39875031, 22.91430473], [70.39875031, 22.91458321], [70.39930725, 22.91458321], [70.39930725, 22.91486168], [70.40013885, 22.91485977], [70.40013885, 22.91514015], [70.4006958, 22.91514015], [70.4006958, 22.91542053], [70.4015274, 22.91542053], [70.4015274, 22.91570091], [70.40208435, 22.91569519], [70.40208435, 22.91597176], [70.40291595, 22.91596985], [70.40291595, 22.91625023], [70.4034729, 22.91625023], [70.4034729, 22.91653061], [70.40429688, 22.91653061], [70.40429688, 22.91681099], [70.40486145, 22.91680527], [70.40486145, 22.91708374], [70.40513611, 22.91707993], [70.40513611, 22.91736031], [70.40569305, 22.91736031], [70.40569305, 22.91763878], [70.40598297, 22.91763115], [70.40598297, 22.91792107], [70.40652466, 22.91791725], [70.40652466, 22.91819382], [70.40680695, 22.91819382], [70.40680695, 22.91791725], [70.40736389, 22.91791725], [70.40736389, 22.91819382], [70.40763855, 22.91819382], [70.40763855, 22.91847229], [70.4081955, 22.91847229], [70.4081955, 22.91875076], [70.40875244, 22.91875076], [70.40875244, 22.91903114], [70.4090271, 22.91903114], [70.4090271, 22.91930962], [70.40957642, 22.91930962], [70.40957642, 22.92070007], [70.41014099, 22.92070007], [70.41014099, 22.9204216], [70.41042328, 22.9204216], [70.41042328, 22.91986084], [70.4118042, 22.91986084], [70.41179657, 22.91930962], [70.41208649, 22.91930962], [70.41208649, 22.91875076], [70.41236115, 22.91875076], [70.41236115, 22.91819], [70.41347504, 22.91819382], [70.41347504, 22.91847229], [70.41319275, 22.91847038], [70.41319275, 22.91903114], [70.41291809, 22.91902733], [70.41291809, 22.91958427], [70.4126358, 22.91958046], [70.4126358, 22.92013931], [70.41236115, 22.92013741], [70.41236115, 22.92235947], [70.4126358, 22.92235947], [70.4126358, 22.92292023], [70.41319275, 22.92292023], [70.41319275, 22.92264175], [70.41374969, 22.92263794], [70.41374969, 22.92319489], [70.41402435, 22.92319489], [70.41402435, 22.92347336], [70.41430664, 22.92346954], [70.41430664, 22.92375946], [70.4145813, 22.92375946], [70.4145813, 22.9240303], [70.41485596, 22.9240303], [70.41485596, 22.92431068], [70.41513824, 22.92430305], [70.41513824, 22.92458153], [70.4154129, 22.92458153], [70.4154129, 22.92486382], [70.41570282, 22.92486191], [70.41570282, 22.92542076], [70.41596985, 22.92541695], [70.41596985, 22.9256916], [70.41625214, 22.9256916], [70.41625214, 22.92597389], [70.41652679, 22.92597008], [70.41652679, 22.92625046], [70.41680908, 22.92625046], [70.41680908, 22.92653084], [70.41708374, 22.92652702], [70.41708374, 22.9268055], [70.4173584, 22.9268055], [70.4173584, 22.92708588], [70.41791534, 22.92708588], [70.41791534, 22.92736053], [70.41819763, 22.92736053], [70.41819763, 22.92791939], [70.41847229, 22.92791748], [70.41847229, 22.92819595], [70.41874695, 22.92819595], [70.41874695, 22.92847252], [70.41902924, 22.92847061], [70.41902924, 22.92875099], [70.41929626, 22.92875099], [70.41929626, 22.92902946], [70.41958618, 22.92902756], [70.41958618, 22.9295826], [70.41986084, 22.92957115], [70.41986084, 22.92986107], [70.4201355, 22.92986107], [70.4201355, 22.93013954], [70.42041779, 22.93013954], [70.42041779, 22.93041992], [70.42069244, 22.93041611], [70.42069244, 22.93069458], [70.4209671, 22.93069077], [70.4209671, 22.93124962], [70.42124939, 22.93124962], [70.42124939, 22.93152809], [70.42180634, 22.93152618], [70.42180634, 22.93180466], [70.42208099, 22.93180466], [70.42208099, 22.93208313], [70.42236328, 22.93208313], [70.42236328, 22.9323616], [70.42318726, 22.9323597], [70.42318726, 22.93263817], [70.42346954, 22.93263817], [70.42346954, 22.93320084], [70.42375183, 22.93320084], [70.42375183, 22.93374825], [70.42402649, 22.93374825], [70.42402649, 22.93431091], [70.42430878, 22.93431091], [70.42430878, 22.93485832], [70.42457581, 22.93485832], [70.42457581, 22.9354229], [70.42485809, 22.93541718], [70.42485809, 22.93597031], [70.42514038, 22.93597031], [70.42514038, 22.93653107], [70.42541504, 22.93652725], [70.42541504, 22.9370842], [70.42569733, 22.93708038], [70.42569733, 22.93764114], [70.42597198, 22.93763924], [70.42597198, 22.93819237], [70.42624664, 22.93819046], [70.42624664, 22.93931007], [70.42652893, 22.93931007], [70.42652893, 22.94013977], [70.42680359, 22.94013977], [70.42680359, 22.94097137], [70.42652893, 22.94096947], [70.42652893, 22.94153023], [70.42624664, 22.94152832], [70.42624664, 22.94208336], [70.42595673, 22.94207954], [70.42595673, 22.94292068], [70.42624664, 22.94291687], [70.42624664, 22.94347191], [70.42652893, 22.94347], [70.42652893, 22.94431114], [70.42679596, 22.94431114], [70.42679596, 22.94486809], [70.42708588, 22.94486046], [70.42708588, 22.94569397], [70.42736053, 22.94569016], [70.42736053, 22.94681168], [70.42763519, 22.94680595], [70.42763519, 22.94764137], [70.42791748, 22.94764137], [70.42791748, 22.9481945], [70.42819214, 22.94819069], [70.42819214, 22.94874954], [70.42847443, 22.94874954], [70.42847443, 22.95097351], [70.42874908, 22.9509697], [70.42874908, 22.95292091], [70.42903137, 22.9529171], [70.42903137, 22.95347214], [70.42930603, 22.95347023], [70.42930603, 22.95403099], [70.42958069, 22.95403099], [70.42958069, 22.95486069], [70.42986298, 22.95486069], [70.42986298, 22.95597267], [70.43013763, 22.95597076], [70.43013763, 22.95680809], [70.43041992, 22.95680809], [70.43041992, 22.95791817], [70.43069458, 22.95791626], [70.43069458, 22.9584713], [70.43096924, 22.95846939], [70.43096924, 22.95902824], [70.43125153, 22.95902824], [70.43125153, 22.95930481], [70.43152618, 22.95930481], [70.43152618, 22.95958328], [70.43180847, 22.95957947], [70.43180847, 22.95986938], [70.43209076, 22.95986938], [70.43209076, 22.96042061], [70.43264008, 22.96042061], [70.43264008, 22.96069908], [70.43291473, 22.96069527], [70.43291473, 22.96097183], [70.43319702, 22.96096992], [70.43319702, 22.9612484], [70.43374634, 22.9612484], [70.43374634, 22.96153069], [70.43430328, 22.96153069], [70.43430328, 22.9612484], [70.43515015, 22.9612484], [70.43515015, 22.96181107], [70.43541718, 22.96181107], [70.43541718, 22.96236038], [70.43569183, 22.96236038], [70.43569183, 22.96291733], [70.43597412, 22.96291733], [70.43597412, 22.96347046], [70.43624878, 22.96347046], [70.43624878, 22.96375275], [70.43653107, 22.96377945], [70.43653107, 22.96430969], [70.43680573, 22.96430588], [70.43680573, 22.96486282], [70.43708038, 22.96486282], [70.43708038, 22.96541977], [70.43736267, 22.96541405], [70.43736267, 22.96597481], [70.43763733, 22.9659729], [70.43763733, 22.96624947], [70.43791962, 22.96624947], [70.43791962, 22.96681023], [70.43819427, 22.96680641], [70.43819427, 22.96736145], [70.43846893, 22.96735954], [70.43846893, 22.9679203], [70.43875122, 22.96791649], [70.43875122, 22.96847153], [70.43902588, 22.96846962], [70.43902588, 22.96875], [70.43930817, 22.96875], [70.43930817, 22.96931076], [70.43958282, 22.96930695], [70.43958282, 22.96986198], [70.43985748, 22.96986008], [70.43985748, 22.97042084], [70.44013977, 22.97041512], [70.44013977, 22.97097206], [70.4404068, 22.97097015], [70.4404068, 22.97153091], [70.44069672, 22.97153091], [70.44069672, 22.97180748], [70.44095612, 22.97180748], [70.44095612, 22.97236061], [70.44124603, 22.97236061], [70.44124603, 22.97291756], [70.44152832, 22.97291756], [70.44152832, 22.9734726], [70.44180298, 22.97347069], [70.44180298, 22.97403145], [70.4420929, 22.97403145], [70.4420929, 22.97431183], [70.44235992, 22.97430611], [70.44235992, 22.97485924], [70.44264221, 22.9748497], [70.44264221, 22.97514153], [70.44152832, 22.97514153], [70.44152832, 22.97542191], [70.44124603, 22.97542191], [70.44124603, 22.97514153], [70.43985748, 22.97514153], [70.43985748, 22.9748497], [70.43930817, 22.97485924], [70.43930817, 22.97458267], [70.43763733, 22.97458076], [70.43763733, 22.97514153], [70.43791962, 22.97514153], [70.43791962, 22.97542191], [70.43846893, 22.97541618], [70.43846893, 22.97569466], [70.43958282, 22.97569466], [70.43958282, 22.97597122], [70.44124603, 22.97596931], [70.44124603, 22.9762516], [70.44180298, 22.9762516], [70.44180298, 22.97653008], [70.44235992, 22.97652817], [70.44235992, 22.97680473], [70.44264221, 22.97680473], [70.44264221, 22.9770813], [70.44319153, 22.9770813], [70.44319153, 22.97736359], [70.44346619, 22.97735977], [70.44346619, 22.97764015], [70.44374847, 22.97763824], [70.44374847, 22.97791672], [70.44431305, 22.9779129], [70.44431305, 22.97820091], [70.44458008, 22.97819519], [70.44458008, 22.97847366], [70.44486237, 22.97846985], [70.44486237, 22.97875023], [70.44513702, 22.97875023], [70.44513702, 22.97903061], [70.44541931, 22.97903061], [70.44541931, 22.97931099], [70.44596863, 22.97930527], [70.44596863, 22.97958565], [70.44625092, 22.97957993], [70.44625092, 22.97986031], [70.4465332, 22.97986031], [70.4465332, 22.98014069], [70.44680786, 22.98014069], [70.44680786, 22.98042107], [70.44736481, 22.98041725], [70.44736481, 22.98069572], [70.44763947, 22.98069], [70.44763947, 22.98097992], [70.44819641, 22.98097992], [70.44819641, 22.98125076], [70.44875336, 22.98125076], [70.44875336, 22.98153114], [70.44902802, 22.98153114], [70.44902802, 22.98180962], [70.44930267, 22.9818058], [70.44930267, 22.98208237], [70.44958496, 22.98208427], [70.44958496, 22.98236084], [70.45014954, 22.98236084], [70.45014954, 22.98264122], [70.45041656, 22.98264122], [70.45041656, 22.98291969], [70.45124817, 22.98291779], [70.45124817, 22.98319435], [70.45180511, 22.98319435], [70.45180511, 22.98374939], [70.45236206, 22.98374939], [70.45236206, 22.98404121], [70.45263672, 22.98404121], [70.45263672, 22.98431015], [70.45319366, 22.98430634], [70.45319366, 22.9845829], [70.45375061, 22.9845829], [70.45375061, 22.98486137], [70.4540329, 22.98485947], [70.4540329, 22.98513985], [70.45430756, 22.98513794], [70.45430756, 22.98569489], [70.45458221, 22.98569489], [70.45458221, 22.98597145], [70.45485687, 22.98596954], [70.45485687, 22.98624992], [70.45513916, 22.98624992], [70.45513916, 22.9865284], [70.45540619, 22.9865284], [70.45540619, 22.98681068], [70.45569611, 22.98680496], [70.45569611, 22.98708344], [70.45597076, 22.98707962], [70.45597076, 22.98763847], [70.45625305, 22.98763847], [70.45625305, 22.98792076], [70.45652771, 22.98792076], [70.45652771, 22.98875237], [70.45680237, 22.98875237], [70.45680237, 22.98903275], [70.45707703, 22.98903275], [70.45707703, 22.98931122], [70.45735931, 22.9893055], [70.45735931, 22.98958206], [70.4576416, 22.98958015], [70.4576416, 22.99041939], [70.45791626, 22.99041939], [70.45791626, 22.9912529], [70.45819092, 22.9912529], [70.45819092, 22.99180984], [70.45847321, 22.99180984], [70.45847321, 22.99236107], [70.45874786, 22.99236107], [70.45874786, 22.99291992], [70.45903015, 22.99291611], [70.45903015, 22.99319458], [70.45929718, 22.99319077], [70.45929718, 22.99403], [70.4595871, 22.99402809], [70.4595871, 22.99458313], [70.45986176, 22.99458313], [70.45986176, 22.9948616], [70.46013641, 22.9948597], [70.46013641, 22.99542046], [70.4604187, 22.99542046], [70.4604187, 22.99570084], [70.46069336, 22.99570084], [70.46069336, 22.99653053], [70.46098328, 22.99653053], [70.46098328, 22.99681091], [70.46125031, 22.99681091], [70.46125031, 22.99736023], [70.46153259, 22.99736023], [70.46153259, 22.99764061], [70.46180725, 22.9976387], [70.46180725, 22.99819374], [70.46208954, 22.99818993], [70.46208954, 22.9990406], [70.4623642, 22.99902725], [70.4623642, 22.9995842], [70.46263885, 22.99958038], [70.46263885, 22.99986076], [70.46290588, 22.99986076], [70.46290588, 23.00042152], [70.46375275, 23.0004158], [70.46375275, 23.00069427], [70.4640274, 23.00069427], [70.4640274, 23.00097275], [70.46430206, 23.00097084], [70.46430206, 23.0015316], [70.46457672, 23.0015316], [70.46457672, 23.00181007], [70.46485901, 23.00180626], [70.46485901, 23.00235939], [70.46512604, 23.00235939], [70.46512604, 23.00264168], [70.46541595, 23.00264168], [70.46541595, 23.00319481], [70.46569824, 23.00318909], [70.46569824, 23.00375175], [70.4659729, 23.00375175], [70.4659729, 23.00430489], [70.46652985, 23.00430489], [70.46652985, 23.00458145], [70.46679688, 23.00457954], [70.46679688, 23.0051403], [70.46708679, 23.0051403], [70.46708679, 23.00570107], [70.46736145, 23.00570107], [70.46736145, 23.00625038], [70.46763611, 23.00625038], [70.46763611, 23.00681114], [70.4679184, 23.00681114], [70.4679184, 23.00736046], [70.46819305, 23.00736046], [70.46819305, 23.00792122], [70.46847534, 23.0079174], [70.46847534, 23.00819588], [70.46875, 23.00819016], [70.46875, 23.00875092], [70.46901703, 23.00875092], [70.46901703, 23.00902939], [70.46930695, 23.00902748], [70.46930695, 23.00958252], [70.4695816, 23.00958061], [70.4695816, 23.00986099], [70.46985626, 23.00986099], [70.46985626, 23.01013947], [70.47013855, 23.01013947], [70.47013855, 23.01041985], [70.47041321, 23.01041794], [70.47041321, 23.0106945], [70.4706955, 23.0106945], [70.4706955, 23.01124954], [70.47097015, 23.01124954], [70.47097015, 23.01180077], [70.47125244, 23.01180649], [70.47125244, 23.01236153], [70.4715271, 23.01235962], [70.4715271, 23.01320076], [70.47180176, 23.01319504], [70.47180939, 23.01402855], [70.47208405, 23.01402855], [70.47208405, 23.01458359], [70.4723587, 23.01457977], [70.4723587, 23.01542282], [70.47264099, 23.01542282], [70.47264099, 23.01625252], [70.47292328, 23.01625252], [70.47292328, 23.01680946], [70.47319794, 23.01680946], [70.47319794, 23.01764107], [70.4734726, 23.01763916], [70.4734726, 23.01819229], [70.47374725, 23.01819038], [70.47374725, 23.01875114], [70.47402954, 23.01875114], [70.47402954, 23.01931], [70.47429657, 23.01931], [70.47429657, 23.01986122], [70.47458649, 23.01986122], [70.47458649, 23.02042007], [70.47486115, 23.02041626], [70.47486115, 23.0209713], [70.4751358, 23.02096939], [70.4751358, 23.02153015], [70.47541809, 23.02152824], [70.47541809, 23.02236176], [70.47569275, 23.02235985], [70.47569275, 23.02321053], [70.47598267, 23.02321053], [70.47598267, 23.02403069], [70.47624969, 23.02403069], [70.47624969, 23.02486038], [70.47652435, 23.02486038], [70.47652435, 23.02569389], [70.47680664, 23.02569008], [70.47680664, 23.02653122], [70.47706604, 23.02653122], [70.47706604, 23.02736092], [70.47735596, 23.02736092], [70.47735596, 23.02792168], [70.47763824, 23.02791595], [70.47763824, 23.0284729], [70.4779129, 23.0284729], [70.4779129, 23.02902794], [70.47819519, 23.02902794], [70.47819519, 23.02958107], [70.47846985, 23.02957916], [70.47846985, 23.03014183], [70.47875214, 23.03014183], [70.47875214, 23.03070068], [70.47902679, 23.03070068], [70.47902679, 23.03125191], [70.47930908, 23.03125191], [70.47930908, 23.03209114], [70.47957611, 23.03209114], [70.47957611, 23.03292084], [70.4798584, 23.03292084], [70.4798584, 23.03403091], [70.48014069, 23.0340271], [70.48014069, 23.03458595], [70.48041534, 23.03458595], [70.48041534, 23.03486061], [70.48069763, 23.03486061], [70.48069763, 23.03515053], [70.48097229, 23.03515053], [70.48097229, 23.03541946], [70.48124695, 23.03541946], [70.48124695, 23.03625107], [70.48152924, 23.03625107], [70.48152924, 23.03736115], [70.48180389, 23.03736115], [70.48180389, 23.03819466], [70.48208618, 23.03819084], [70.48208618, 23.03902817], [70.48236084, 23.03902817], [70.48236084, 23.03986168], [70.48264313, 23.03985977], [70.48264313, 23.04042053], [70.48291779, 23.04042053], [70.48291779, 23.04124832], [70.48320007, 23.04124832], [70.48320007, 23.0418129], [70.4834671, 23.0418129], [70.4834671, 23.04236031], [70.48374939, 23.04236031], [70.48374939, 23.04319382], [70.48401642, 23.04319191], [70.48401642, 23.04375267], [70.48430634, 23.04375267], [70.48430634, 23.04432106], [70.48458099, 23.04432106], [70.48458099, 23.04486275], [70.48486328, 23.04486275], [70.48486328, 23.04569244], [70.48513794, 23.04569054], [70.48513794, 23.04681015], [70.48542023, 23.04680634], [70.48542023, 23.04736137], [70.48569489, 23.04736137], [70.48569489, 23.04819679], [70.48596954, 23.04819107], [70.48596954, 23.04874992], [70.48625946, 23.04874992], [70.48625946, 23.04931068], [70.48652649, 23.04930687], [70.48652649, 23.04986191], [70.48680878, 23.04986], [70.48680878, 23.05042076], [70.48707581, 23.05042076], [70.48707581, 23.05181122], [70.48735809, 23.0518055], [70.48735809, 23.05208397], [70.48764038, 23.05208397], [70.48764038, 23.05319405], [70.48791504, 23.05319405], [70.48791504, 23.0545826], [70.48819733, 23.05458069], [70.48819733, 23.05514145], [70.48847198, 23.05514145], [70.48847198, 23.05597115], [70.48874664, 23.05596924], [70.48874664, 23.05653191], [70.48902893, 23.05652809], [70.48902893, 23.05736351], [70.48929596, 23.0573597], [70.48929596, 23.05792046], [70.48958588, 23.05792046], [70.48958588, 23.05875015], [70.48986053, 23.05875015], [70.48986053, 23.05932045], [70.49014282, 23.05932045], [70.49014282, 23.06014061], [70.49041748, 23.0601387], [70.49041748, 23.06097221], [70.49069214, 23.06097221], [70.49069214, 23.06174088], [70.49093628, 23.06180954], [70.4909668, 23.06264114], [70.49124908, 23.06264114], [70.49124908, 23.06430817], [70.49153137, 23.06430626], [70.49153137, 23.06569481], [70.49180603, 23.06569099], [70.49180603, 23.06624985], [70.49208069, 23.06624985], [70.49208069, 23.06847191], [70.49236298, 23.06846809], [70.49236298, 23.0723629], [70.49263763, 23.0723629], [70.49263763, 23.07291985], [70.49291992, 23.07291412], [70.49291992, 23.07347488], [70.49318695, 23.07347107], [70.49318695, 23.07402992], [70.49346924, 23.07402992], [70.49346924, 23.07514], [70.49263763, 23.07514], [70.49263763, 23.07542038], [70.49153137, 23.07542038], [70.49153137, 23.07570076], [70.49041748, 23.07569695], [70.49041748, 23.0759716], [70.48929596, 23.0759697], [70.48929596, 23.07625008], [70.48819733, 23.07625008], [70.48819733, 23.07653046], [70.48707581, 23.07653046], [70.48707581, 23.07681084], [70.48596954, 23.07680511], [70.48596954, 23.07708359], [70.48486328, 23.07708359], [70.48486328, 23.07736206], [70.48458099, 23.07736206], [70.48458099, 23.07708359], [70.48458099, 23.07680511], [70.48430634, 23.07681084], [70.48430634, 23.07653046], [70.48401642, 23.07653046], [70.48401642, 23.0759697], [70.48374939, 23.0759716], [70.48374939, 23.07569695], [70.4834671, 23.07570076], [70.4834671, 23.07514], [70.48320007, 23.07514], [70.48320007, 23.07458115], [70.48291779, 23.07458305], [70.48291779, 23.07402802], [70.48264313, 23.07402992], [70.48264313, 23.07374954], [70.48236084, 23.07374954], [70.48236084, 23.07347107], [70.48208618, 23.07347488], [70.48208618, 23.0731945], [70.48180389, 23.0731945], [70.48180389, 23.07291412], [70.48152924, 23.07291985], [70.48152924, 23.0723629], [70.48124695, 23.0723629], [70.48124695, 23.07208061], [70.48069763, 23.07208443], [70.48069763, 23.07180595], [70.48042297, 23.07180977], [70.48042297, 23.07152939], [70.4798584, 23.07152939], [70.4798584, 23.07126045], [70.47930908, 23.07126045], [70.47930908, 23.07097054], [70.47875214, 23.07097054], [70.47875214, 23.07069206], [70.47819519, 23.07069206], [70.47819519, 23.0704174], [70.47735596, 23.07042122], [70.47735596, 23.07014275], [70.47680664, 23.07014275], [70.47680664, 23.06986046], [70.47597504, 23.06986046], [70.47597504, 23.06958389], [70.47486115, 23.06958389], [70.47486115, 23.06930542], [70.47374725, 23.06931114], [70.47374725, 23.06903267], [70.4723587, 23.06903267], [70.4723587, 23.06875229], [70.47125244, 23.06875229], [70.47125244, 23.06847191], [70.46875, 23.06847191], [70.46875, 23.06819534], [70.46763611, 23.06819916], [70.46763611, 23.06792068], [70.46652985, 23.06792068], [70.46652985, 23.0676384], [70.46512604, 23.0676384], [70.46512604, 23.06735992], [70.4640274, 23.06736183], [70.4640274, 23.06708336], [70.46263885, 23.06708336], [70.46263885, 23.06680489], [70.46069336, 23.06680489], [70.46069336, 23.06652832], [70.45874786, 23.06652832], [70.45874786, 23.06624985], [70.45458221, 23.06624985], [70.45458221, 23.06596947], [70.45402527, 23.06597137], [70.45402527, 23.06569481], [70.45375061, 23.06569481], [70.45375061, 23.06541634], [70.44875336, 23.06541824], [70.44875336, 23.06513023], [70.44625092, 23.06513977], [70.44625092, 23.0648613], [70.44596863, 23.0648613], [70.44596863, 23.06513977], [70.44569397, 23.06513977], [70.44569397, 23.0648613], [70.44486237, 23.0648613], [70.44486237, 23.06458282], [70.44319153, 23.06458282], [70.44319153, 23.06430626], [70.44264221, 23.06430817], [70.44264221, 23.06402969], [70.44180298, 23.06402969], [70.44180298, 23.06375122], [70.44095612, 23.06375122], [70.44095612, 23.06347084], [70.44013977, 23.06347275], [70.44013977, 23.06319427], [70.43930817, 23.06319427], [70.43930817, 23.06291771], [70.43875122, 23.06291962], [70.43875122, 23.06264114], [70.43791962, 23.06264114], [70.43791962, 23.06236076], [70.43736267, 23.06236076], [70.43736267, 23.06207085], [70.43708038, 23.0620842], [70.43708038, 23.06180573], [70.43653107, 23.06180954], [70.43653107, 23.06153107], [70.43624878, 23.06153107], [70.43624878, 23.06125069], [70.43569183, 23.06125069], [70.43569183, 23.06097031], [70.43541718, 23.06097221], [70.43541718, 23.06069565], [70.43514252, 23.06069565], [70.43514252, 23.06041718], [70.4345932, 23.06042099], [70.4345932, 23.06014061], [70.43430328, 23.06014061], [70.43430328, 23.05986023], [70.43374634, 23.05986023], [70.43374634, 23.05957985], [70.43319702, 23.05958366], [70.43319702, 23.05930328], [70.4329071, 23.05932045], [70.4329071, 23.05903053], [70.43264008, 23.05903053], [70.43264008, 23.05875015], [70.43235779, 23.05875015], [70.43235779, 23.05846977], [70.43180847, 23.05847359], [70.43180847, 23.05819511], [70.43152618, 23.05820084], [70.43152618, 23.05792046], [70.43125153, 23.05792046], [70.43125153, 23.05764008], [70.43096924, 23.05764008], [70.43096924, 23.0573597], [70.43041992, 23.05736351], [70.43041992, 23.05708122], [70.43013763, 23.05708122], [70.43013763, 23.05680466], [70.42986298, 23.05680466], [70.42986298, 23.05652809], [70.42930603, 23.05653191], [70.42930603, 23.05626106], [70.42901611, 23.05626106], [70.42901611, 23.05596924], [70.42874908, 23.05597115], [70.42874908, 23.05569458], [70.42847443, 23.05569458], [70.42847443, 23.05541611], [70.42791748, 23.05542183], [70.42791748, 23.05514145], [70.42763519, 23.05514145], [70.42763519, 23.05485916], [70.42736053, 23.05485916], [70.42736053, 23.05458069], [70.42708588, 23.0545826], [70.42708588, 23.05430603], [70.42679596, 23.05431175], [70.42679596, 23.05403137], [70.42652893, 23.05403137], [70.42652893, 23.05374908], [70.42595673, 23.05374908], [70.42595673, 23.05347061], [70.42569733, 23.05347252], [70.42569733, 23.05319405], [70.42541504, 23.05319405], [70.42541504, 23.05291748], [70.42514038, 23.05291748], [70.42514038, 23.05264091], [70.42485809, 23.05264091], [70.42485809, 23.05236053], [70.42402649, 23.05236053], [70.42402649, 23.05208015], [70.42375183, 23.05208397], [70.42375183, 23.0518055], [70.42346954, 23.05181122], [70.42346954, 23.05125046], [70.42318726, 23.05125046], [70.42318726, 23.05098915], [70.42263794, 23.05097008], [70.42263794, 23.05041695], [70.42180634, 23.05042076], [70.42180634, 23.04986], [70.42152405, 23.04986191], [70.42152405, 23.04958344], [70.42124939, 23.04958344], [70.42124939, 23.04930687], [70.4209671, 23.04931068], [70.4209671, 23.0490303], [70.42041779, 23.0490303], [70.42041779, 23.04874992], [70.4201355, 23.04874992], [70.4201355, 23.04847145], [70.41986084, 23.04847145], [70.41986084, 23.04819679], [70.41930389, 23.04819679], [70.41930389, 23.04763985], [70.41874695, 23.04763985], [70.41874695, 23.04681015], [70.41847229, 23.04681015], [70.41847229, 23.04652977], [70.41819763, 23.04652977], [70.41819763, 23.04624939], [70.41791534, 23.04624939], [70.41791534, 23.04597473], [70.41764069, 23.04597473], [70.41764069, 23.04569244], [70.4173584, 23.04569244], [70.4173584, 23.04513931], [70.41707611, 23.04514122], [70.41707611, 23.04486275], [70.41680908, 23.04486275], [70.41680908, 23.04458046], [70.41652679, 23.04458427], [70.41652679, 23.04402733], [70.41625214, 23.04403114], [70.41625214, 23.04375267], [70.41596985, 23.04375267], [70.41596985, 23.04347038], [70.41569519, 23.04347038], [70.41569519, 23.04291725], [70.4154129, 23.04292107], [70.4154129, 23.04264259], [70.41513824, 23.04264259], [70.41513824, 23.04236031], [70.41485596, 23.04236031], [70.41485596, 23.04208183], [70.4145813, 23.04208374], [70.4145813, 23.04180527], [70.41430664, 23.0418129], [70.41430664, 23.04153061], [70.41401672, 23.04153061], [70.41401672, 23.04124832], [70.41374969, 23.04124832], [70.41374969, 23.04096031], [70.41319275, 23.04097176], [70.41319275, 23.04069519], [70.41291809, 23.04070091], [70.41291809, 23.04013824], [70.4126358, 23.04013824], [70.4126358, 23.03957939], [70.41236115, 23.03958321], [70.41236115, 23.03930473], [70.41208649, 23.03930473], [70.41208649, 23.03902817], [70.41179657, 23.03902817], [70.41179657, 23.03874969], [70.41152954, 23.03874969], [70.41152954, 23.03847122], [70.4109726, 23.03847313], [70.4109726, 23.03791618], [70.41042328, 23.03791809], [70.41042328, 23.03763962], [70.41014099, 23.03763962], [70.41014099, 23.03736115], [70.4098587, 23.03736115], [70.4098587, 23.03708076], [70.40958405, 23.03708267], [70.40958405, 23.03680611], [70.4090271, 23.03680992], [70.4090271, 23.03652954], [70.40875244, 23.03652954], [70.40875244, 23.03625107], [70.40847015, 23.03625107], [70.40847015, 23.03597069], [70.4081955, 23.0359726], [70.4081955, 23.03569412], [70.40763855, 23.03569412], [70.40763855, 23.03541756], [70.40735626, 23.03541946], [70.40735626, 23.03515053], [70.40722656, 23.03515053], [70.4070816, 23.03515053], [70.4070816, 23.03486061], [70.40680695, 23.03486061], [70.40680695, 23.03458023], [70.40652466, 23.03458595], [70.40652466, 23.03430557], [70.40625, 23.03430939], [70.40625, 23.03403091], [70.40598297, 23.03403091], [70.40598297, 23.03375053], [70.40569305, 23.03375053], [70.40569305, 23.03347015], [70.4054184, 23.03347206], [70.4054184, 23.0331955], [70.40513611, 23.0331955], [70.40513611, 23.03263855], [70.40484619, 23.03264046], [70.40484619, 23.03209114], [70.40458679, 23.03209114], [70.40458679, 23.03181076], [70.40429688, 23.03181076], [70.40429688, 23.03125191], [70.40402985, 23.03125191], [70.40402985, 23.03096962], [70.40374756, 23.03097343], [70.40374756, 23.03069305], [70.4034729, 23.03070068], [70.4034729, 23.0304203], [70.40319824, 23.0304203], [70.40319061, 23.02985954], [70.40291595, 23.02985954], [70.40291595, 23.02958107], [70.4026413, 23.02958107], [70.4026413, 23.02930641], [70.40235901, 23.02931023], [70.40235901, 23.0290184], [70.40208435, 23.02902794], [70.40208435, 23.02958107], [70.4017868, 23.02957916], [70.4017868, 23.03014183], [70.4015274, 23.03014183], [70.4015274, 23.03070068], [70.40125275, 23.03070068], [70.40125275, 23.0304203], [70.40097046, 23.0304203], [70.40097046, 23.03014183], [70.4006958, 23.03014183], [70.4006958, 23.02985954], [70.40041351, 23.02985954], [70.40041351, 23.02930641], [70.40013885, 23.02931023], [70.40013885, 23.0290184], [70.3998642, 23.02902794], [70.3998642, 23.02874947], [70.39958191, 23.02874947], [70.39958191, 23.02846909], [70.39930725, 23.0284729], [70.39930725, 23.02819443], [70.39902496, 23.02819443], [70.39902496, 23.02791595], [70.39875031, 23.02792168], [70.39875031, 23.02763939], [70.39847565, 23.02763939], [70.39847565, 23.02736092], [70.39819336, 23.02736092], [70.39819336, 23.02708054], [70.3979187, 23.02708244], [70.3979187, 23.02680588], [70.39763641, 23.02680969], [70.39763641, 23.02653122], [70.39736176, 23.02653122], [70.39736176, 23.02625084], [70.3970871, 23.02625084], [70.3970871, 23.02596092], [70.39680481, 23.02597237], [70.39680481, 23.02569389], [70.39653015, 23.02569389], [70.39653015, 23.02541733], [70.39624786, 23.02542114], [70.39624786, 23.02458], [70.39653015, 23.02458382], [70.39653015, 23.02124977], [70.39624786, 23.02124977], [70.39624786, 23.02015114], [70.39598083, 23.02015114], [70.39598083, 23.01708031], [70.39624786, 23.01708221], [70.39624786, 23.01569366], [70.39597321, 23.01569366], [70.39597321, 23.01458359], [70.39569092, 23.01458359], [70.39569092, 23.01319504], [70.39541626, 23.01320076], [70.39541626, 23.01152992], [70.3951416, 23.01152992], [70.3951416, 23.00986099], [70.39485931, 23.00986099], [70.39485931, 23.00819016], [70.39458466, 23.00819588], [70.39458466, 23.00652695], [70.39430237, 23.00653076], [70.39430237, 23.0051403], [70.39402771, 23.0051403], [70.39402771, 23.00403023], [70.39375305, 23.00403023], [70.39375305, 23.00346947], [70.39347076, 23.00347137], [70.39347076, 23.00319481], [70.39319611, 23.00319481], [70.39319611, 23.00264168], [70.39347076, 23.00264168], [70.39347076, 23.00208092], [70.39375305, 23.00208282], [70.39375305, 23.00152779], [70.39290619, 23.0015316], [70.39290619, 23.00124931], [70.39235687, 23.00124931], [70.39235687, 23.00097084], [70.39208221, 23.00097275], [70.39208221, 23.00069427], [70.39125061, 23.00069427], [70.39125061, 23.0004158], [70.38957977, 23.00042152], [70.38957977, 23.00013924], [70.38957977, 22.99958038], [70.38930511, 22.9995842], [70.38930511, 22.99930573], [70.38874817, 22.99930954], [70.38874817, 22.9990406], [70.38819122, 22.9990406], [70.38819122, 22.99875069], [70.38764191, 22.99875069], [70.38764191, 22.99847031], [70.38680267, 22.99847221], [70.38680267, 22.99819374], [70.38513947, 22.99819374], [70.38513947, 22.99847221], [70.38402557, 22.99847221], [70.38402557, 22.99819374], [70.38291931, 22.99819374], [70.38291931, 22.99791718], [70.38263702, 22.99792099], [70.38263702, 22.99764061], [70.38291931, 22.99764061], [70.38291931, 22.99736023], [70.38404083, 22.99736023], [70.38404083, 22.99764061], [70.38513947, 22.99764061], [70.38513947, 22.99736023], [70.3868103, 22.99736023], [70.3868103, 22.99764061], [70.38874817, 22.99764061], [70.38874817, 22.99792099], [70.39235687, 22.99792099], [70.39235687, 22.99764061], [70.39263916, 22.99764061], [70.39263916, 22.99736023], [70.39290619, 22.99736023], [70.39290619, 22.99707985], [70.39319611, 22.99708366], [70.39319611, 22.99680519], [70.39347076, 22.99681091], [70.39347076, 22.99653053], [70.39375305, 22.99653053], [70.39375305, 22.99625015], [70.39402771, 22.99625015], [70.39402771, 22.99598122], [70.39430237, 22.99598122], [70.39430237, 22.99542046], [70.39457703, 22.99542046], [70.39457703, 22.99152946], [70.39485931, 22.99152946], [70.39485931, 22.98735809], [70.39458466, 22.98736191], [70.39458466, 22.9734726], [70.39430237, 22.9734726], [70.39430237, 22.96958351], [70.39402771, 22.96958351], [70.39402771, 22.96763802], [70.39375305, 22.96763992], [70.39375305, 22.96568108], [70.39347076, 22.96569443], [70.39347076, 22.96319389], [70.39319611, 22.96319389], [70.39319611, 22.96264076], [70.39290619, 22.96264267], [70.39290619, 22.96208191], [70.39263916, 22.96208382], [70.39263916, 22.96152687], [70.39235687, 22.96153069], [70.39235687, 22.96096992], [70.39208221, 22.96097183], [70.39208221, 22.96041679], [70.39180756, 22.96042061], [70.39180756, 22.95986938], [70.3915329, 22.95986938], [70.3915329, 22.95930099], [70.39125061, 22.95930481], [70.39125061, 22.95874977], [70.39097595, 22.95874977], [70.39097595, 22.95791817], [70.39068604, 22.95791817], [70.39068604, 22.95736122], [70.39041901, 22.95736122], [70.39041901, 22.95680809], [70.39013672, 22.95680809], [70.39013672, 22.95597076], [70.38986206, 22.95597267], [70.38986206, 22.95541763], [70.38957977, 22.95541954], [70.38957977, 22.95486069], [70.38930511, 22.95486069], [70.38930511, 22.95430565], [70.38903046, 22.95430946], [70.38903046, 22.95374107], [70.38874817, 22.95375061], [70.38874817, 22.95347214], [70.38847351, 22.95347214], [70.38847351, 22.9529171], [70.38819122, 22.95292091], [70.38819122, 22.95236015], [70.38791656, 22.95236206], [70.38791656, 22.95208359], [70.38764191, 22.95208359], [70.38764191, 22.95152855], [70.38735962, 22.95153046], [70.38735962, 22.9509697], [70.38708496, 22.95097351], [70.38708496, 22.94874954], [70.38680267, 22.94874954], [70.38680267, 22.9481945], [70.38652802, 22.9481945], [70.38652802, 22.94791603], [70.38625336, 22.94792938], [70.38625336, 22.94735909], [70.38597107, 22.94735909], [70.38597107, 22.94708061], [70.38569641, 22.94708252], [70.38569641, 22.94652748], [70.38540649, 22.94652748], [70.38540649, 22.94625092], [70.38513947, 22.94625092], [70.38513947, 22.94597054], [70.38486481, 22.94597244], [70.38486481, 22.94569397], [70.38458252, 22.94569397], [70.38458252, 22.9454174], [70.38430786, 22.94542122], [70.38430786, 22.94514084], [70.38404083, 22.94514084], [70.38404083, 22.94486809], [70.38375092, 22.94486809], [70.38375092, 22.94458008], [70.38319397, 22.94458389], [70.38319397, 22.94430542], [70.38291931, 22.94431114], [70.38291931, 22.94403076], [70.38236237, 22.94403076], [70.38236237, 22.94375038], [70.38180542, 22.94375038], [70.38180542, 22.94347191], [70.38124847, 22.94347191], [70.38124847, 22.94319534], [70.38067627, 22.94320107], [70.38067627, 22.94292068], [70.37874603, 22.94292068], [70.37874603, 22.9426403], [70.37819672, 22.9426403], [70.37819672, 22.94235992], [70.37763977, 22.94236183], [70.37763977, 22.94208336], [70.37708282, 22.94208336], [70.37708282, 22.94180679], [70.37652588, 22.94180679], [70.37652588, 22.94152832], [70.37596893, 22.94153023], [70.37596893, 22.94124985], [70.37513733, 22.94124985], [70.37513733, 22.94096947], [70.37458038, 22.94097137], [70.37458038, 22.94069481], [70.37374878, 22.94069481], [70.37374878, 22.94041634], [70.37319183, 22.94042015], [70.37319183, 22.94013977], [70.37236023, 22.94013977], [70.37236023, 22.93985939], [70.37208557, 22.9398613], [70.37208557, 22.93958473], [70.37152863, 22.93958473], [70.37152863, 22.93930626], [70.37124634, 22.93931007], [70.37124634, 22.93902969], [70.37069702, 22.93902969], [70.37069702, 22.93873978], [70.37041473, 22.93874931], [70.37041473, 22.93847466], [70.36985779, 22.93847466], [70.36985779, 22.93819237], [70.36958313, 22.93819237], [70.36958313, 22.9379158], [70.36873627, 22.93791962], [70.36873627, 22.93764114], [70.36818695, 22.93764114], [70.36818695, 22.93736267], [70.36736298, 22.93736267], [70.36736298, 22.93708038], [70.36680603, 22.9370842], [70.36680603, 22.93680573], [70.3659668, 22.93680954], [70.3659668, 22.93653107], [70.36541748, 22.93653107], [70.36541748, 22.93625259], [70.36486053, 22.93625259], [70.36486053, 22.93597031], [70.36402893, 22.93597031], [70.36402893, 22.93569374], [70.36347198, 22.93569946], [70.36347198, 22.9354229], [70.36235809, 22.9354229], [70.36235809, 22.93514252], [70.36096954, 22.93514252], [70.36096954, 22.93485832], [70.35986328, 22.93485832], [70.35986328, 22.93458366], [70.35847473, 22.93458366], [70.35847473, 22.93430519], [70.35791779, 22.93431091], [70.35791779, 22.93403053], [70.35708618, 22.93403053], [70.35708618, 22.93374825], [70.35652924, 22.93374825], [70.35652924, 22.93346977], [70.35597229, 22.93347168], [70.35597229, 22.93319511], [70.35514069, 22.93320084], [70.35514069, 22.9329319], [70.35457611, 22.9329319], [70.35457611, 22.93263817], [70.35402679, 22.93263817], [70.35402679, 22.9323597], [70.35319519, 22.9323616], [70.35319519, 22.93208313], [70.35263824, 22.93208313], [70.35263824, 22.93180466], [70.35180664, 22.93180466], [70.35180664, 22.93152618], [70.35124969, 22.93152809], [70.35124969, 22.93124962], [70.35067749, 22.93124962], [70.35067749, 22.93097115], [70.34764099, 22.93097305], [70.34764099, 22.93041611], [70.34513855, 22.93041611], [70.34513855, 22.93069458], [70.34347534, 22.93069458], [70.34347534, 22.93097305], [70.34208679, 22.93097115], [70.34208679, 22.93124962], [70.34041595, 22.93124962], [70.34041595, 22.93152809], [70.33958435, 22.93152618], [70.33958435, 22.93180466], [70.33875275, 22.93180466], [70.33875275, 22.93208313], [70.33763885, 22.93208313], [70.33763885, 22.9323616], [70.33680725, 22.9323597], [70.33680725, 22.93263817], [70.33599091, 22.93263817], [70.33599091, 22.9329319], [70.33513641, 22.9329319], [70.33513641, 22.93320084], [70.33430481, 22.93319511], [70.33430481, 22.93347168], [70.33347321, 22.93346977], [70.33347321, 22.93374825], [70.33235931, 22.93374825], [70.33235931, 22.93403053], [70.33152771, 22.93403053], [70.33152771, 22.93431091], [70.33069611, 22.93430519], [70.33069611, 22.93458366], [70.32956696, 22.93457985], [70.32956696, 22.93485832], [70.32847595, 22.93485832], [70.32847595, 22.93514252], [70.32763672, 22.93514252], [70.32763672, 22.9354229], [70.32653046, 22.9354229], [70.32653046, 22.93569946], [70.32541656, 22.93569374], [70.32541656, 22.93597031], [70.32458496, 22.93597031], [70.32458496, 22.93625259], [70.32376099, 22.93625259], [70.32376099, 22.93653107], [70.32290649, 22.93653107], [70.32290649, 22.93680954], [70.32208252, 22.93680573], [70.32208252, 22.9370842], [70.32152557, 22.9370842], [70.3215332, 22.93736267], [70.32096863, 22.93736267], [70.32096863, 22.93764114], [70.3207016, 22.93764114], [70.3207016, 22.93791962], [70.32013702, 22.9379158], [70.32013702, 22.93819237], [70.31986237, 22.93819237], [70.31986237, 22.93847466], [70.31930542, 22.93847466], [70.31930542, 22.93874931], [70.31903076, 22.93873978], [70.31903076, 22.93902969], [70.31680298, 22.93902969], [70.31680298, 22.93931007], [70.31652832, 22.93930626], [70.31652832, 22.93958473], [70.31625366, 22.93958473], [70.31625366, 22.9398613], [70.31597137, 22.93985939], [70.31597137, 22.94013977], [70.31569672, 22.94013977], [70.31569672, 22.94042015], [70.31541443, 22.94041634], [70.31541443, 22.94069481], [70.31485748, 22.94069481], [70.31485748, 22.94097137], [70.31456757, 22.94096947], [70.31456757, 22.94124985], [70.31318665, 22.94124985], [70.31318665, 22.94153023], [70.31291962, 22.94152832], [70.31291962, 22.94208336], [70.31153107, 22.94208336], [70.31153107, 22.94180679], [70.31124878, 22.94180679], [70.31124878, 22.94152832], [70.31014252, 22.94152832], [70.31014252, 22.94180679], [70.30986023, 22.94180679], [70.30986023, 22.94208336], [70.3095932, 22.94207954], [70.3095932, 22.9426403], [70.30930328, 22.9426384], [70.30930328, 22.94347191], [70.30902863, 22.94347], [70.30902863, 22.94375038], [70.3087616, 22.94375038], [70.3087616, 22.94403076], [70.30819702, 22.94403076], [70.30819702, 22.94431114], [70.30791473, 22.94430542], [70.30791473, 22.94458389], [70.30764008, 22.94458008], [70.30764008, 22.94486809], [70.30735779, 22.94486809], [70.30735779, 22.94514084], [70.30708313, 22.94514084], [70.30708313, 22.94542122], [70.30680847, 22.9454174], [70.30680847, 22.94597244], [70.30652618, 22.94597054], [70.30652618, 22.94625092], [70.30625153, 22.94625092], [70.30625153, 22.94681168], [70.30596924, 22.94681168], [70.30596924, 22.94874954], [70.30625153, 22.94874954], [70.30625153, 22.94930077], [70.30652618, 22.94930649], [70.30652618, 22.94958115], [70.30680847, 22.94958115], [70.30680847, 22.94985962], [70.30708313, 22.94985962], [70.30708313, 22.95042038], [70.30735779, 22.95042038], [70.30735779, 22.95125008], [70.30458069, 22.95125008], [70.30458069, 22.9509697], [70.30403137, 22.95097351], [70.30403137, 22.95069504], [70.3034668, 22.95070076], [70.3034668, 22.95042038], [70.30291748, 22.95042038], [70.30291748, 22.95014191], [70.30208588, 22.95014191], [70.30208588, 22.94985962], [70.30152893, 22.94985962], [70.30152893, 22.94958115], [70.30097198, 22.94958115], [70.30097198, 22.94930649], [70.30042267, 22.9493103], [70.30042267, 22.94903183], [70.29985809, 22.94903183], [70.29985809, 22.94874954], [70.29959106, 22.94874954], [70.29959106, 22.94903183], [70.29930878, 22.94903183], [70.29930878, 22.94874954], [70.29792023, 22.94874954], [70.29792023, 22.94846916], [70.29763794, 22.94847107], [70.29763794, 22.9481945], [70.29736328, 22.9481945], [70.29736328, 22.94791603], [70.29708099, 22.94792938], [70.29708099, 22.94764137], [70.29652405, 22.94764137], [70.29652405, 22.94735909], [70.29624939, 22.94735909], [70.29624939, 22.94708061], [70.29569244, 22.94708252], [70.29569244, 22.94680595], [70.29514313, 22.94681168], [70.29514313, 22.94652748], [70.29458618, 22.94652748], [70.29458618, 22.94625092], [70.29429626, 22.94625092], [70.29429626, 22.94597054], [70.29374695, 22.94597244], [70.29374695, 22.94569397], [70.29319763, 22.94569397], [70.29319763, 22.9454174], [70.29180908, 22.94542122], [70.29180908, 22.94514084], [70.29096985, 22.94514084], [70.29096985, 22.94486809], [70.2895813, 22.94486809], [70.2895813, 22.94514084], [70.28874969, 22.94514084], [70.28874969, 22.94542122], [70.28819275, 22.94542122], [70.28819275, 22.94514084], [70.28791809, 22.94514084], [70.28791809, 22.94542122], [70.28736115, 22.9454174], [70.28736115, 22.94569397], [70.28708649, 22.94569397], [70.28708649, 22.94597244], [70.28652954, 22.94597054], [70.28652954, 22.94625092], [70.28624725, 22.94625092], [70.28624725, 22.94652748], [70.2859726, 22.94652748], [70.2859726, 22.94681168], [70.28569794, 22.94680595], [70.28569794, 22.94708252], [70.28541565, 22.94708252], [70.28541565, 22.94680595], [70.28514099, 22.94680595], [70.28514099, 22.94708252], [70.28430939, 22.94708061], [70.28430176, 22.94735909], [70.2840271, 22.94735909], [70.2840271, 22.94764137], [70.28320312, 22.94764137], [70.28320312, 22.94792938], [70.28263855, 22.94791603], [70.28263855, 22.9481945], [70.2820816, 22.9481945], [70.2820816, 22.94847107], [70.28097534, 22.94847107], [70.28098297, 22.94874954], [70.27929688, 22.94874954], [70.27929688, 22.94903183], [70.27986145, 22.94903183], [70.27986145, 22.9493103], [70.27958679, 22.94930649], [70.27958679, 22.94985962], [70.27929688, 22.94985962], [70.27929688, 22.95070076], [70.27902985, 22.95069504], [70.27902985, 22.95097351], [70.2784729, 22.95097351], [70.2784729, 22.95041656], [70.27819824, 22.95041656], [70.27819824, 22.95097351], [70.2776413, 22.9509697], [70.2776413, 22.95125008], [70.27707672, 22.95125008], [70.27707672, 22.95153046], [70.27571106, 22.95153046], [70.27571106, 22.95181084], [70.27541351, 22.95180321], [70.27541351, 22.95208359], [70.2756958, 22.95208359], [70.2756958, 22.95236015], [70.27597046, 22.95236015], [70.27597046, 22.95264053], [70.27485657, 22.95264053], [70.27485657, 22.95236015], [70.27458191, 22.95236206], [70.27458191, 22.95180321], [70.27430725, 22.95180321], [70.27430725, 22.95236206], [70.27403259, 22.95236015], [70.27403259, 22.95264053], [70.27348328, 22.95264053], [70.27348328, 22.95292091], [70.27319336, 22.9529171], [70.27319336, 22.95319557], [70.2729187, 22.95319557], [70.2729187, 22.95347214], [70.27236176, 22.95347214], [70.27236176, 22.95375061], [70.2720871, 22.95374107], [70.2720871, 22.95403099], [70.27179718, 22.95403099], [70.27179718, 22.95430946], [70.27153015, 22.95430565], [70.27153015, 22.95458412], [70.27124786, 22.95458031], [70.27124786, 22.95514107], [70.2701416, 22.95514107], [70.2701416, 22.95541954], [70.26875305, 22.95541763], [70.26875305, 22.9556942], [70.26902771, 22.95569038], [70.26902771, 22.95625114], [70.26847076, 22.95625114], [70.26847076, 22.95652962], [70.26819611, 22.95652962], [70.26819611, 22.95625114], [70.26791382, 22.95624924], [70.26791382, 22.95708275], [70.26763916, 22.95708084], [70.26763916, 22.95736122], [70.26735687, 22.95736122], [70.26735687, 22.95763969], [70.26708221, 22.95763969], [70.26708221, 22.95819473], [70.26680756, 22.95819473], [70.26680756, 22.9584713], [70.26651764, 22.95846939], [70.26651764, 22.95902824], [70.26625061, 22.95902824], [70.26625061, 22.95930481], [70.26597595, 22.95930481], [70.26597595, 22.95958328], [70.26568604, 22.95957947], [70.26568604, 22.96013832], [70.26541901, 22.96013832], [70.26541901, 22.96042061], [70.26569366, 22.96041679], [70.26569366, 22.96097183], [70.26597595, 22.96096992], [70.26597595, 22.9612484], [70.26625061, 22.9612484], [70.26625061, 22.96153069], [70.26597595, 22.96153069], [70.26597595, 22.96181107], [70.26569366, 22.96180534], [70.26569366, 22.96208382], [70.26541901, 22.96208191], [70.26541901, 22.96236038], [70.26486206, 22.96236038], [70.26486206, 22.96264267], [70.26347351, 22.96264076], [70.26347351, 22.96291733], [70.26264191, 22.96291733], [70.26264191, 22.96319389], [70.26208496, 22.96319389], [70.26208496, 22.96347046], [70.26180267, 22.96347046], [70.26180267, 22.96375275], [70.26152802, 22.96375275], [70.26152802, 22.96403122], [70.26125336, 22.96403122], [70.26125336, 22.96430969], [70.26097107, 22.96430588], [70.26097107, 22.96458054], [70.26069641, 22.96458054], [70.26069641, 22.96486282], [70.26042175, 22.96486282], [70.26039124, 22.96513939], [70.26013947, 22.96513939], [70.26013947, 22.96541977], [70.25986481, 22.96541405], [70.25986481, 22.96569443], [70.25958252, 22.96569443], [70.25958252, 22.96597481], [70.25930786, 22.9659729], [70.25930786, 22.96624947], [70.2590332, 22.96624947], [70.2590332, 22.96652985], [70.25875092, 22.96652985], [70.25875092, 22.96681023], [70.25846863, 22.96680641], [70.25846863, 22.96708488], [70.25791931, 22.96708488], [70.25791931, 22.96736145], [70.25763702, 22.96735954], [70.25763702, 22.96763992], [70.25734711, 22.96763992], [70.25734711, 22.9679203], [70.25708008, 22.9679203], [70.25708008, 22.96820068], [70.25680542, 22.96819687], [70.25680542, 22.96847153], [70.25653076, 22.96846962], [70.25653076, 22.96875], [70.25624847, 22.96875], [70.25624847, 22.96903038], [70.25596619, 22.96903038], [70.25596619, 22.96931076], [70.25541687, 22.96930695], [70.25541687, 22.96958351], [70.25514221, 22.96958351], [70.25514221, 22.96986198], [70.25485992, 22.96986008], [70.25485992, 22.97014046], [70.25457764, 22.97014046], [70.25457764, 22.97042084], [70.25430298, 22.97041512], [70.25430298, 22.97069359], [70.25402832, 22.97069359], [70.25402832, 22.97097206], [70.25347137, 22.97097015], [70.25347137, 22.97125053], [70.25319672, 22.97125053], [70.25319672, 22.97153091], [70.2529068, 22.97153091], [70.2529068, 22.97180748], [70.25235748, 22.97180557], [70.25235748, 22.97208405], [70.25208282, 22.97208023], [70.25208282, 22.97236061], [70.25180817, 22.97236061], [70.25180817, 22.97263908], [70.25125122, 22.97263908], [70.25125122, 22.97291756], [70.25096893, 22.97291756], [70.25096893, 22.97319412], [70.25069427, 22.97319412], [70.25069427, 22.9734726], [70.24986267, 22.9734726], [70.24986267, 22.97319412], [70.24930573, 22.97319412], [70.24930573, 22.97291756], [70.24847412, 22.97291756], [70.24847412, 22.97306061], [70.24847412, 22.97319412], [70.24819183, 22.97319412], [70.24819183, 22.97348022], [70.24819183, 22.97374916], [70.24791718, 22.97374916], [70.24791718, 22.97388077], [70.24791718, 22.97403145], [70.24781036, 22.97402763], [70.24736023, 22.97403145], [70.24736023, 22.97431183], [70.24708557, 22.97430611], [70.24708557, 22.97458267], [70.24652863, 22.97458267], [70.24652863, 22.97485924], [70.24624634, 22.9748497], [70.24624634, 22.97514153], [70.24569702, 22.97514153], [70.24569702, 22.97542191], [70.24541473, 22.97541618], [70.24541473, 22.97569466], [70.24485779, 22.97569466], [70.24485779, 22.97597122], [70.24458313, 22.97596931], [70.24458313, 22.9762516], [70.24430847, 22.9762516], [70.24430847, 22.97653008], [70.24375153, 22.97652817], [70.24375153, 22.97680473], [70.24346924, 22.97680473], [70.24346924, 22.9770813], [70.24291992, 22.9770813], [70.24291992, 22.97736359], [70.24263763, 22.97735977], [70.24263763, 22.97764015], [70.24208069, 22.97763824], [70.24208069, 22.97791672], [70.24180603, 22.9779129], [70.24180603, 22.97820091], [70.24069214, 22.97819519], [70.24069214, 22.97847366], [70.23986053, 22.97846985], [70.23986053, 22.97875023], [70.23874664, 22.97875023], [70.23874664, 22.97903061], [70.23792267, 22.97903061], [70.23792267, 22.97931099], [70.23764038, 22.97930527], [70.23764038, 22.97958565], [70.23652649, 22.97958565], [70.23654175, 22.97986031], [70.23625183, 22.97986031], [70.23625183, 22.97957993], [70.23542023, 22.97958565], [70.23542023, 22.97930527], [70.23486328, 22.97931099], [70.23486328, 22.97903061], [70.23401642, 22.97903061], [70.23401642, 22.97875023], [70.2334671, 22.97875023], [70.2334671, 22.97846985], [70.2326355, 22.97847366], [70.2326355, 22.97819519], [70.23179626, 22.97820091], [70.23179626, 22.9779129], [70.23124695, 22.97791672], [70.23124695, 22.97763824], [70.23040771, 22.97764015], [70.23040771, 22.97735977], [70.2298584, 22.97736359], [70.2298584, 22.9770813], [70.22930908, 22.9770813], [70.22930908, 22.97569466], [70.22958374, 22.97569466], [70.22958374, 22.97458267], [70.2298584, 22.97458267], [70.2298584, 22.97208405], [70.23014069, 22.97208405], [70.23014069, 22.96986198], [70.2298584, 22.96986198], [70.2298584, 22.96819687], [70.22957611, 22.96820068], [70.22957611, 22.96681023], [70.22930908, 22.96681023], [70.22930908, 22.96624947], [70.22902679, 22.96624947], [70.22902679, 22.9659729], [70.2270813, 22.9659729], [70.2270813, 22.96624947], [70.22680664, 22.96624947], [70.22680664, 22.96652985], [70.22651672, 22.96652985], [70.22651672, 22.96681023], [70.22624969, 22.96680641], [70.22624969, 22.96708488], [70.22597504, 22.96708488], [70.22597504, 22.96736145], [70.22541809, 22.96735954], [70.22541809, 22.96763992], [70.2251358, 22.96763992], [70.2251358, 22.9679203], [70.22486115, 22.9679203], [70.22486115, 22.96820068], [70.22458649, 22.96819687], [70.22458649, 22.96847153], [70.2243042, 22.96847153], [70.22431183, 22.96875], [70.22402954, 22.96875], [70.22402954, 22.96903038], [70.22374725, 22.96903038], [70.22374725, 22.96931076], [70.2234726, 22.96930695], [70.2234726, 22.96958351], [70.22291565, 22.96958351], [70.22291565, 22.96986198], [70.22264099, 22.96986008], [70.22264099, 22.97014046], [70.2223587, 22.97014046], [70.2223587, 22.97042084], [70.22180939, 22.97041512], [70.22180176, 22.97069359], [70.2215271, 22.97069359], [70.2215271, 22.97097206], [70.22125244, 22.97097015], [70.22125244, 22.97125053], [70.22070313, 22.97125053], [70.22070313, 22.97153091], [70.22041321, 22.97153091], [70.22041321, 22.97180748], [70.22013855, 22.97180557], [70.22013855, 22.97208405], [70.2195816, 22.97208023], [70.2195816, 22.97236061], [70.21930695, 22.97236061], [70.21930695, 22.97263908], [70.21875, 22.97263908], [70.21875, 22.97291756], [70.21847534, 22.97291756], [70.21847534, 22.97319412], [70.2179184, 22.97319412], [70.2179184, 22.9734726], [70.21763611, 22.97347069], [70.21763611, 22.97374916], [70.21736145, 22.97374916], [70.21736145, 22.97403145], [70.21679688, 22.97403145], [70.21679688, 22.97431183], [70.21652985, 22.97430611], [70.21652985, 22.97458267], [70.2159729, 22.97458267], [70.2159729, 22.97485924], [70.21569824, 22.9748497], [70.21569824, 22.97514153], [70.2151413, 22.97514153], [70.2151413, 22.97542191], [70.21458435, 22.97541618], [70.21458435, 22.97569466], [70.2140274, 22.97569466], [70.2140274, 22.97597122], [70.21347046, 22.97596931], [70.21347046, 22.9762516], [70.2131958, 22.9762516], [70.2131958, 22.97653008], [70.21263885, 22.97652817], [70.21263885, 22.97680473], [70.21208191, 22.97680473], [70.21208191, 22.9770813], [70.21152496, 22.9770813], [70.21152496, 22.97736359], [70.21098328, 22.97735977], [70.21098328, 22.97764015], [70.2104187, 22.97763824], [70.2104187, 22.97791672], [70.20986176, 22.9779129], [70.20986176, 22.97820091], [70.2095871, 22.97819519], [70.2095871, 22.97847366], [70.20903015, 22.97846985], [70.20903015, 22.97875023], [70.20847321, 22.97875023], [70.20847321, 22.97903061], [70.20791626, 22.97903061], [70.20791626, 22.97931099], [70.2076416, 22.97930527], [70.2076416, 22.97958565], [70.20707703, 22.97957993], [70.20707703, 22.97986031], [70.20652771, 22.97986031], [70.20652771, 22.98014069], [70.20623779, 22.98014069], [70.20623779, 22.98042107], [70.20597076, 22.98041725], [70.20597076, 22.98069572], [70.20569611, 22.98069], [70.20569611, 22.98125076], [70.20540619, 22.98125076], [70.20540619, 22.98153114], [70.20513916, 22.98153114], [70.20513916, 22.98180962], [70.2048645, 22.9818058], [70.2048645, 22.98208427], [70.20458221, 22.98208046], [70.20458221, 22.98236084], [70.20430756, 22.98236084], [70.20430756, 22.98291969], [70.20402527, 22.98291779], [70.20402527, 22.98319435], [70.20375061, 22.98319435], [70.20375061, 22.98347282], [70.20349884, 22.98347092], [70.20346832, 22.98404121], [70.20319366, 22.98402786], [70.20319366, 22.98486137], [70.20291901, 22.98486137], [70.20291901, 22.98569489], [70.20263672, 22.98569107], [70.20263672, 22.9865284], [70.20236206, 22.9865284], [70.20236206, 22.98748016], [70.20236206, 22.98763847], [70.20207977, 22.98763847], [70.20207977, 22.98875237], [70.20181274, 22.98875237], [70.20181274, 22.99014282], [70.20153046, 22.99014282], [70.20153046, 22.99152946], [70.20124817, 22.99152946], [70.20124817, 22.99263954], [70.20097351, 22.99263954], [70.20097351, 22.99347305], [70.20069122, 22.99347115], [70.20069122, 22.99403], [70.20041656, 22.99402809], [70.20041656, 22.99458313], [70.20014191, 22.99458122], [70.20014191, 22.99514008], [70.19985962, 22.99514008], [70.19985962, 22.99542046], [70.19959259, 22.99542046], [70.19959259, 22.99570084], [70.19930267, 22.99570084], [70.19930267, 22.99598122], [70.19902802, 22.99598122], [70.19902802, 22.99653053], [70.19875336, 22.99653053], [70.19875336, 22.99681091], [70.19847107, 22.99681091], [70.19847107, 22.99736023], [70.19819641, 22.99736023], [70.19819641, 22.99792099], [70.19791412, 22.99791718], [70.19791412, 22.99847221], [70.19403076, 22.99847221], [70.19403076, 22.99819374], [70.19319153, 22.99819374], [70.19319153, 22.99791718], [70.1912384, 22.99792099], [70.1912384, 22.99764061], [70.18902588, 22.99764061], [70.18902588, 22.99736023], [70.18875122, 22.99736023], [70.18875122, 22.99707985], [70.18846893, 22.99708366], [70.18846893, 22.99680519], [70.1882019, 22.99681091], [70.1882019, 22.99653053], [70.18791962, 22.99653053], [70.18791962, 22.99625015], [70.18763733, 22.99625015], [70.18763733, 22.99570084], [70.18736267, 22.99570084], [70.18736267, 22.99542046], [70.18708038, 22.99542046], [70.18708038, 22.9948597], [70.18680573, 22.9948616], [70.18680573, 22.99430466], [70.18653107, 22.99430466], [70.18653107, 22.99374962], [70.18624878, 22.99374962], [70.18624878, 22.99180984], [70.18653107, 22.99180984], [70.18653107, 22.9912529], [70.18708038, 22.9912529], [70.18708038, 22.99180984], [70.18736267, 22.99180603], [70.18736267, 22.99347305], [70.18763733, 22.99347305], [70.18763733, 22.99458313], [70.18875122, 22.99458313], [70.18875122, 22.9948616], [70.18985748, 22.9948597], [70.18985748, 22.99514008], [70.19264221, 22.99514008], [70.19264221, 22.99542046], [70.19319916, 22.99542046], [70.19568634, 22.99542046], [70.19568634, 22.99514008], [70.19625092, 22.99514008], [70.19625092, 22.9948597], [70.19652557, 22.9948616], [70.19652557, 22.99458313], [70.19708252, 22.99458313], [70.19708252, 22.99430466], [70.19763947, 22.99430466], [70.19763947, 22.99402809], [70.19790649, 22.99403], [70.19790649, 22.99347115], [70.19819641, 22.99347305], [70.19819641, 22.99319458], [70.19847107, 22.99319458], [70.19847107, 22.99180603], [70.19819641, 22.99180984], [70.19819641, 22.99069023], [70.19791412, 22.99069214], [70.19791412, 22.98958206], [70.19819641, 22.98958206], [70.19819641, 22.98875237], [70.19847107, 22.98875237], [70.19847107, 22.98792076], [70.19875336, 22.98792076], [70.19875336, 22.98707962], [70.19902802, 22.98708344], [70.19902802, 22.98624992], [70.19930267, 22.98624992], [70.19930267, 22.98485947], [70.19958496, 22.98486137], [70.19958496, 22.98374939], [70.19985962, 22.98374939], [70.19985962, 22.98319054], [70.20014191, 22.98319435], [70.20014191, 22.98263931], [70.20043182, 22.98264122], [70.20043182, 22.98208046], [70.20069122, 22.98208237], [70.20069122, 22.98152733], [70.20096588, 22.98153114], [70.20096588, 22.98125076], [70.20124817, 22.98125076], [70.20124817, 22.98097992], [70.20153046, 22.98097992], [70.20153046, 22.98069], [70.20180511, 22.98069572], [70.20180511, 22.98041725], [70.20207977, 22.98042107], [70.20207977, 22.98014069], [70.20236206, 22.98014069], [70.20236206, 22.97957993], [70.20263672, 22.97958565], [70.20263672, 22.97930527], [70.20291901, 22.97931099], [70.20291901, 22.97903061], [70.20317841, 22.97903061], [70.20317841, 22.97875023], [70.20346832, 22.97875023], [70.20346832, 22.97846985], [70.20375061, 22.97847366], [70.20375061, 22.97819519], [70.2040329, 22.97820091], [70.2040329, 22.9779129], [70.20458221, 22.97791672], [70.20458221, 22.97763824], [70.20485687, 22.97764015], [70.20485687, 22.97735977], [70.20513916, 22.97736359], [70.20513916, 22.9770813], [70.20569611, 22.9770813], [70.20569611, 22.97680473], [70.20597076, 22.97680473], [70.20597076, 22.97652817], [70.20623779, 22.97653008], [70.20623779, 22.9762516], [70.20680237, 22.9762516], [70.20680237, 22.97596931], [70.20708466, 22.97597122], [70.20708466, 22.97569466], [70.20819092, 22.97569466], [70.20819092, 22.97541618], [70.20868683, 22.97541618], [70.20931244, 22.97542191], [70.20931244, 22.97514153], [70.2104187, 22.97514153], [70.2104187, 22.9748497], [70.21069336, 22.97485924], [70.21069336, 22.97458267], [70.21125031, 22.97458267], [70.21125031, 22.97430611], [70.21153259, 22.97431183], [70.21153259, 22.97403145], [70.21180725, 22.97403145], [70.21180725, 22.97374916], [70.21237183, 22.97374916], [70.21237183, 22.97347069], [70.21263885, 22.9734726], [70.21263885, 22.97319412], [70.21291351, 22.97319412], [70.21291351, 22.97291756], [70.21347046, 22.97291756], [70.21347046, 22.97263908], [70.21375275, 22.97263908], [70.21375275, 22.97236061], [70.21430206, 22.97236061], [70.21430206, 22.97208023], [70.21458435, 22.97208405], [70.21458435, 22.97180557], [70.21485901, 22.97180748], [70.21485901, 22.97153091], [70.21540833, 22.97153091], [70.21540833, 22.97125053], [70.21569061, 22.97125053], [70.21569824, 22.97097015], [70.2159729, 22.97097206], [70.2159729, 22.97069359], [70.21652985, 22.97069359], [70.21652985, 22.97041512], [70.21679688, 22.97042084], [70.21679688, 22.97014046], [70.21736145, 22.97014046], [70.21736145, 22.96986008], [70.21763611, 22.96986198], [70.21763611, 22.96958351], [70.2179184, 22.96958351], [70.2179184, 22.96930695], [70.21846771, 22.96931076], [70.21846771, 22.96903038], [70.21875, 22.96903038], [70.21875, 22.96875], [70.21901703, 22.96875], [70.21901703, 22.96846962], [70.2195816, 22.96847153], [70.2195816, 22.96819687], [70.22013855, 22.96820068], [70.22013855, 22.9679203], [70.22070313, 22.9679203], [70.22070313, 22.96735954], [70.22097015, 22.96736145], [70.22097015, 22.96708488], [70.22125244, 22.96708488], [70.22125244, 22.96680641], [70.2215271, 22.96681023], [70.2215271, 22.96652985], [70.22180176, 22.96652985], [70.22180176, 22.96624947], [70.22207642, 22.96624947], [70.22207642, 22.96568108], [70.2223587, 22.96569443], [70.2223587, 22.96541405], [70.22264099, 22.96541977], [70.22264099, 22.96513939], [70.22292328, 22.96513939], [70.22291565, 22.96458054], [70.22319794, 22.96458054], [70.22319794, 22.96430588], [70.2234726, 22.96430969], [70.2234726, 22.96403122], [70.22374725, 22.96403122], [70.22374725, 22.96347046], [70.22402954, 22.96347046], [70.22402954, 22.96319389], [70.2243042, 22.96319389], [70.2243042, 22.96264076], [70.22460175, 22.96264267], [70.22460175, 22.96153069], [70.22486115, 22.96153069], [70.22486115, 22.96069908], [70.2251358, 22.96069908], [70.2251358, 22.96013832], [70.22486115, 22.96013832], [70.22486115, 22.95986938], [70.22431183, 22.95986938], [70.22431183, 22.95957947], [70.22402954, 22.95958328], [70.22402954, 22.95930481], [70.2234726, 22.95930481], [70.2234726, 22.95902824], [70.22319794, 22.95902824], [70.22319794, 22.95874977], [70.22264099, 22.95874977], [70.22264099, 22.95846939], [70.2223587, 22.9584713], [70.2223587, 22.95819473], [70.22180176, 22.95819473], [70.22180176, 22.95791626], [70.2215271, 22.95791817], [70.2215271, 22.95763969], [70.22097015, 22.95763969], [70.22097015, 22.95736122], [70.22041321, 22.95736122], [70.22041321, 22.95708084], [70.22013855, 22.95708275], [70.22013855, 22.95680618], [70.21985626, 22.95680809], [70.21985626, 22.95652962], [70.21932983, 22.95652962], [70.2193222, 22.95642853], [70.21930695, 22.95624924], [70.21875, 22.95625114], [70.21875, 22.95597076], [70.21763611, 22.95597267], [70.21763611, 22.9556942], [70.21708679, 22.9556942], [70.21708679, 22.95541763], [70.21624756, 22.95541954], [70.21624756, 22.95486069], [70.2159729, 22.95486069], [70.2159729, 22.95458031], [70.21457672, 22.95458031], [70.21457672, 22.95486069], [70.21430206, 22.95486069], [70.21430206, 22.95514107], [70.21375275, 22.95514107], [70.21375275, 22.95458031], [70.21347046, 22.95458412], [70.21347046, 22.95402718], [70.21290588, 22.95403099], [70.21290588, 22.95374107], [70.2123642, 22.95375061], [70.2123642, 22.9529171], [70.21153259, 22.95292091], [70.21153259, 22.95264053], [70.2104187, 22.95264053], [70.2104187, 22.95236015], [70.2095871, 22.95236206], [70.2095871, 22.95208359], [70.20874786, 22.95208359], [70.20874786, 22.95180321], [70.20707703, 22.95181084], [70.20707703, 22.95153046], [70.20569611, 22.95153046], [70.20569611, 22.95125008], [70.20549011, 22.95125008], [70.20402527, 22.95125008], [70.20402527, 22.95097351], [70.20236206, 22.95097351], [70.20236206, 22.95069504], [70.20097351, 22.95069504], [70.20097351, 22.95097351], [70.19875336, 22.95097351], [70.19875336, 22.95069504], [70.19819641, 22.95070076], [70.19819641, 22.95042038], [70.19790649, 22.95042038], [70.19790649, 22.95014191], [70.19708252, 22.95014191], [70.19708252, 22.95042038], [70.19737244, 22.95042038], [70.19737244, 22.95070076], [70.19708252, 22.95069504], [70.19708252, 22.95097351], [70.19680786, 22.9509697], [70.19680786, 22.95125008], [70.19625092, 22.95125008], [70.19625092, 22.9509697], [70.19541931, 22.95097351], [70.19541931, 22.95069504], [70.19458008, 22.95070076], [70.19458008, 22.95042038], [70.19486237, 22.95042038], [70.19486237, 22.95014191], [70.18985748, 22.95014191], [70.18985748, 22.95070076], [70.18958282, 22.95069504], [70.18958282, 22.95097351], [70.18902588, 22.95097351], [70.18902588, 22.95069504], [70.18708038, 22.95070076], [70.18708038, 22.95042038], [70.18264008, 22.95042038], [70.18264008, 22.95070076], [70.18126678, 22.95069504], [70.18069458, 22.95069504], [70.18069458, 22.95097351], [70.17736053, 22.9509697], [70.17736053, 22.95125008], [70.17624664, 22.95125008], [70.17624664, 22.95097351], [70.17569733, 22.95097351], [70.17569733, 22.95069504], [70.17542267, 22.95070076], [70.17542267, 22.95014191], [70.17457581, 22.95014191], [70.17457581, 22.95042038], [70.17375183, 22.95042038], [70.17375183, 22.95070076], [70.17346954, 22.95070076], [70.17346954, 22.95042038], [70.17292023, 22.95042038], [70.17292023, 22.95014191], [70.17263794, 22.95014191], [70.17263794, 22.94985962], [70.17236328, 22.94985962], [70.17236328, 22.94958115], [70.17208099, 22.94958115], [70.17208099, 22.94930649], [70.17180634, 22.9493103], [70.17180634, 22.94903183], [70.17124939, 22.94903183], [70.17124939, 22.94874954], [70.1709671, 22.94874954], [70.1709671, 22.94846916], [70.17069244, 22.94847107], [70.17069244, 22.9481945], [70.17041779, 22.9481945], [70.17041779, 22.94791603], [70.16902924, 22.94791603], [70.16902924, 22.9481945], [70.16874695, 22.9481945], [70.16874695, 22.94791603], [70.16819763, 22.94792938], [70.16819763, 22.94764137], [70.16791534, 22.94764137], [70.16791534, 22.94735909], [70.16764069, 22.94735909], [70.16764069, 22.94708061], [70.1673584, 22.94708252], [70.1673584, 22.94652748], [70.16706848, 22.94652748], [70.16706848, 22.94625092], [70.16680908, 22.94625092], [70.16680908, 22.94569016], [70.16652679, 22.94569397], [70.16652679, 22.9454174], [70.16625214, 22.94542122], [70.16625214, 22.94514084], [70.16596985, 22.94514084], [70.16596985, 22.94486809], [70.16570282, 22.94486809], [70.16570282, 22.94458008], [70.1654129, 22.94458389], [70.1654129, 22.94402885], [70.16513824, 22.94403076], [70.16513824, 22.94347], [70.16347504, 22.94347191], [70.16347504, 22.94319534], [70.16319275, 22.94320107], [70.16319275, 22.94292068], [70.16291809, 22.94292068], [70.16291809, 22.9426403], [70.16179657, 22.9426403], [70.16179657, 22.94292068], [70.16126251, 22.94292068], [70.16126251, 22.94320107], [70.16069794, 22.94319534], [70.16069794, 22.94347191], [70.16041565, 22.94347191], [70.16041565, 22.94458389], [70.15957642, 22.94458008], [70.15957642, 22.94486809], [70.1598587, 22.94486809], [70.1598587, 22.94514084], [70.15957642, 22.94514084], [70.15957642, 22.94542122], [70.1590271, 22.9454174], [70.1590271, 22.94569397], [70.15875244, 22.94569397], [70.15875244, 22.94597244], [70.15847015, 22.94597054], [70.15847015, 22.94625092], [70.15791321, 22.94625092], [70.15791321, 22.94597054], [70.15763855, 22.94597054], [70.15763855, 22.94625092], [70.15680695, 22.94625092], [70.15680695, 22.94652748], [70.15625, 22.94652748], [70.15625, 22.94681168], [70.15486145, 22.94680595], [70.15486145, 22.94708252], [70.1543045, 22.94708252], [70.1543045, 22.94680595], [70.15374756, 22.94680595], [70.15374756, 22.94708252], [70.1534729, 22.94708061], [70.1534729, 22.94735909], [70.15319824, 22.94735909], [70.15319824, 22.94764137], [70.15291595, 22.94764137], [70.15291595, 22.94792938], [70.1526413, 22.94791603], [70.1526413, 22.94847107], [70.15208435, 22.94847107], [70.15209198, 22.94874954], [70.1515274, 22.94874954], [70.1515274, 22.94903183], [70.15097046, 22.94903183], [70.15097046, 22.9493103], [70.1506958, 22.94930649], [70.1506958, 22.94958115], [70.15013885, 22.94958115], [70.15013885, 22.94985962], [70.14985657, 22.94985962], [70.14985657, 22.95014191], [70.14932251, 22.95014191], [70.14932251, 22.95042038], [70.14903259, 22.95042038], [70.14903259, 22.95070076], [70.1451416, 22.95069504], [70.1451416, 22.95097351], [70.14457703, 22.9509697], [70.14457703, 22.95125008], [70.14375305, 22.95125008], [70.14375305, 22.95153046], [70.14318848, 22.95153046], [70.14318848, 22.95181084], [70.14263916, 22.95180321], [70.14263916, 22.95208359], [70.14208221, 22.95208359], [70.14208221, 22.95236206], [70.1415329, 22.95236015], [70.1415329, 22.95264053], [70.14125061, 22.95264053], [70.14125061, 22.95292091], [70.14097595, 22.9529171], [70.14097595, 22.95319557], [70.14069366, 22.95319557], [70.14069366, 22.95347214], [70.14041901, 22.95347214], [70.14041901, 22.95375061], [70.14015198, 22.95374107], [70.14015198, 22.95403099], [70.13986206, 22.95403099], [70.13986206, 22.95430946], [70.13957977, 22.95430565], [70.13957977, 22.95458412], [70.13930511, 22.95458412], [70.13931274, 22.95486069], [70.13903046, 22.95486069], [70.13903046, 22.95514107], [70.13874817, 22.95514107], [70.13874817, 22.95541954], [70.13847351, 22.95541763], [70.13847351, 22.9556942], [70.13819122, 22.9556942], [70.13819122, 22.95597267], [70.13791656, 22.95597076], [70.13791656, 22.95625114], [70.13764191, 22.95625114], [70.13764191, 22.95652962], [70.13735962, 22.95652962], [70.13735962, 22.95680809], [70.13708496, 22.95680618], [70.13708496, 22.95708275], [70.13680267, 22.95708084], [70.13680267, 22.95736122], [70.13652802, 22.95736122], [70.13652802, 22.95763969], [70.13625336, 22.95763969], [70.13625336, 22.95791817], [70.13569641, 22.95791626], [70.13569641, 22.95819473], [70.13541412, 22.95819473], [70.13541412, 22.9584713], [70.13513947, 22.95846939], [70.13513947, 22.95874977], [70.13485718, 22.95874977], [70.13485718, 22.95902824], [70.13458252, 22.95902824], [70.13458252, 22.95930481], [70.13430786, 22.95930481], [70.13430786, 22.95958328], [70.13375092, 22.95957947], [70.13375092, 22.95986938], [70.13346863, 22.95986938], [70.13346863, 22.96013832], [70.13318634, 22.96013832], [70.13318634, 22.96042061], [70.13263702, 22.96042061], [70.13263702, 22.96069908], [70.13236237, 22.96069527], [70.13236237, 22.96097183], [70.13180542, 22.96097183], [70.13181305, 22.9612484], [70.13014221, 22.9612484], [70.13014221, 22.96153069], [70.12902832, 22.96153069], [70.12902832, 22.9612484], [70.12680817, 22.9612484], [70.12680817, 22.96096992], [70.12652588, 22.96097183], [70.12652588, 22.96069527], [70.12319183, 22.96069527], [70.12319183, 22.96097183], [70.12291718, 22.96096992], [70.12291718, 22.9612484], [70.12236023, 22.9612484], [70.12236023, 22.96153069], [70.12180328, 22.96153069], [70.12180328, 22.96181107], [70.12124634, 22.96181107], [70.12124634, 22.96236038], [70.12097168, 22.96236038], [70.12097168, 22.96291733], [70.12069702, 22.96291733], [70.12069702, 22.96347046], [70.1204071, 22.96347046], [70.1204071, 22.96403122], [70.12014008, 22.9640274], [70.12014008, 22.96458054], [70.11985779, 22.96458054], [70.11985779, 22.96569443], [70.12014008, 22.96569443], [70.12014008, 22.96736145], [70.12041473, 22.96736145], [70.12041473, 22.96847153], [70.12069702, 22.96846962], [70.12069702, 22.96903038], [70.12097168, 22.96902847], [70.12097168, 22.96958351], [70.12124634, 22.96958351], [70.12124634, 22.96982193], [70.12124634, 22.97014046], [70.12152863, 22.97013855], [70.12152863, 22.97069359], [70.12180328, 22.97068977], [70.12180328, 22.97125053], [70.1220932, 22.97125053], [70.1220932, 22.97180748], [70.12236023, 22.97180748], [70.12236023, 22.97236061], [70.12264252, 22.97236061], [70.12264252, 22.97263908], [70.12319183, 22.97263908], [70.12319183, 22.97291756], [70.12374878, 22.97291756], [70.12374878, 22.97319412], [70.12403107, 22.97319412], [70.12403107, 22.9734726], [70.12458038, 22.97347069], [70.12458038, 22.97374916], [70.12515259, 22.97374916], [70.12515259, 22.97403145], [70.12541962, 22.97403145], [70.12541962, 22.97431183], [70.12596893, 22.97430611], [70.12596893, 22.97458267], [70.12625122, 22.97458267], [70.12625122, 22.97485924], [70.12680817, 22.9748497], [70.12680817, 22.97514153], [70.12708282, 22.97514153], [70.12708282, 22.97542191], [70.12763977, 22.97541618], [70.12763977, 22.97569466], [70.12791443, 22.97569466], [70.12791443, 22.97597122], [70.12847137, 22.97596931], [70.12847137, 22.9762516], [70.1287384, 22.97627068], [70.12874603, 22.97653008], [70.12889862, 22.97652817], [70.12930298, 22.97652817], [70.12930298, 22.97680473], [70.12958527, 22.97680473], [70.12958527, 22.9770813], [70.12985992, 22.97707939], [70.12985992, 22.97764015], [70.13014221, 22.97763824], [70.13014221, 22.97791672], [70.13041687, 22.97791672], [70.13041687, 22.97847366], [70.13069153, 22.97846985], [70.13069153, 22.97903061], [70.13095856, 22.97903061], [70.13095856, 22.97931099], [70.13124847, 22.97931099], [70.13124847, 22.97986031], [70.13153076, 22.97986031], [70.13153076, 22.98075294], [70.13153076, 22.98125076], [70.13181305, 22.98125076], [70.13181305, 22.98291969], [70.13236237, 22.98291779], [70.13236237, 22.98319435], [70.13291931, 22.98319435], [70.13291931, 22.98347282], [70.13318634, 22.98347092], [70.13318634, 22.98404121], [70.13346863, 22.98404121], [70.13346863, 22.98431015], [70.13375092, 22.98430634], [70.13375092, 22.98486137], [70.13402557, 22.98486137], [70.13402557, 22.98569489], [70.13319397, 22.98569489], [70.13319397, 22.98597145], [70.13263702, 22.98596954], [70.13263702, 22.98624992], [70.13208008, 22.98624992], [70.13208008, 22.9865284], [70.13153076, 22.9865284], [70.13153076, 22.98681068], [70.13097382, 22.98680496], [70.13097382, 22.98708344], [70.13041687, 22.98708344], [70.13041687, 22.98736191], [70.12985992, 22.98735809], [70.12985992, 22.98792076], [70.12958527, 22.98791695], [70.1295929, 22.9881897], [70.12930298, 22.98819923], [70.12930298, 22.98875237], [70.12902832, 22.98875237], [70.12902832, 22.98931122], [70.12874603, 22.98931122], [70.12874603, 22.99041939], [70.12902832, 22.99041748], [70.12902832, 22.9920845], [70.12930298, 22.99208069], [70.12930298, 22.99263954], [70.12958527, 22.99263954], [70.12958527, 22.99319458], [70.12985992, 22.99319077], [70.12985992, 22.99374962], [70.13014221, 22.99374962], [70.13014221, 22.99430466], [70.13041687, 22.99430466], [70.13041687, 22.9948616], [70.13069153, 22.9948597], [70.13069153, 22.99542046], [70.13095856, 22.99542046], [70.13095856, 22.99598122], [70.13124847, 22.99598122], [70.13124847, 22.99625015], [70.13153076, 22.99625015], [70.13153076, 22.99681091], [70.13180542, 22.99680519], [70.13180542, 22.99736023], [70.13208008, 22.99736023], [70.13208008, 22.99792099], [70.13236237, 22.99791718], [70.13236237, 22.99847221], [70.13263702, 22.99847031], [70.13263702, 22.99875069], [70.13291931, 22.99875069], [70.13291931, 22.9990406], [70.13319397, 22.99902725], [70.13319397, 22.9995842], [70.13291931, 22.9995842], [70.13291931, 22.99995041], [70.13291931, 23.00013924], [70.13318634, 23.00013924], [70.13318634, 23.00042152], [70.13375092, 23.0004158], [70.13375092, 23.00069427], [70.13402557, 23.00069427], [70.13402557, 23.00097275], [70.13430786, 23.00097084], [70.13430786, 23.00124931], [70.13485718, 23.00124931], [70.13485718, 23.0015316], [70.13513947, 23.0015316], [70.13513947, 23.00181007], [70.13541412, 23.00180626], [70.13541412, 23.00208282], [70.13569641, 23.00208282], [70.13569641, 23.00235939], [70.13597107, 23.00235939], [70.13597107, 23.00264168], [70.13625336, 23.00264168], [70.13625336, 23.00292015], [70.13652802, 23.00291634], [70.13652802, 23.00319481], [70.13680267, 23.00319481], [70.13680267, 23.00347137], [70.13735962, 23.00346947], [70.13735962, 23.00375175], [70.13764191, 23.00375175], [70.13764191, 23.00403023], [70.13791656, 23.00402832], [70.13791656, 23.00430489], [70.13819122, 23.00430489], [70.13819122, 23.00458145], [70.13847351, 23.00458145], [70.13847351, 23.00486374], [70.13874817, 23.00485992], [70.13874817, 23.0051403], [70.13903046, 23.0051403], [70.13903046, 23.00542068], [70.13931274, 23.00542068], [70.13931274, 23.00570107], [70.13957977, 23.00569534], [70.13957977, 23.00597382], [70.14013672, 23.00597382], [70.14013672, 23.00625038], [70.14041901, 23.00625038], [70.14041901, 23.00653076], [70.14068604, 23.00653076], [70.14068604, 23.00681114], [70.14097595, 23.00680542], [70.14097595, 23.0070858], [70.14152527, 23.0070858], [70.14152527, 23.00736046], [70.14180756, 23.00736046], [70.14180756, 23.00764084], [70.14208221, 23.00764084], [70.14208221, 23.00792122], [70.1423645, 23.0079174], [70.1423645, 23.00819588], [70.14263916, 23.00819588], [70.14263916, 23.00847244], [70.14289856, 23.00847054], [70.14289856, 23.00875092], [70.14318848, 23.00875092], [70.14318848, 23.00902939], [70.14347076, 23.00902939], [70.14347076, 23.01013947], [70.14375305, 23.01013947], [70.14375305, 23.01180077], [70.14402771, 23.0118103], [70.14402771, 23.01320076], [70.14430237, 23.01320076], [70.14430237, 23.01374817], [70.14457703, 23.01374817], [70.14457703, 23.01431084], [70.14485931, 23.01431084], [70.14485931, 23.01485825], [70.1451416, 23.01485825], [70.1451416, 23.01542282], [70.14541626, 23.0154171], [70.14541626, 23.01597023], [70.14569092, 23.01597023], [70.14569092, 23.0165329], [70.14597321, 23.01652718], [70.14597321, 23.01708221], [70.14653015, 23.01708031], [70.14653015, 23.01736259], [70.14679718, 23.01736259], [70.14679718, 23.01764107], [70.1470871, 23.01764107], [70.1470871, 23.01791954], [70.14736176, 23.01791573], [70.14736176, 23.01819229], [70.14763641, 23.01819229], [70.14763641, 23.01847458], [70.1479187, 23.01847076], [70.1479187, 23.01875114], [70.14819336, 23.01875114], [70.14819336, 23.01902962], [70.14848328, 23.01902962], [70.14848328, 23.01931], [70.14875031, 23.01930618], [70.14875031, 23.01958466], [70.14902496, 23.01958466], [70.14902496, 23.01986122], [70.14932251, 23.01986122], [70.14932251, 23.02015114], [70.14958191, 23.02015114], [70.14958191, 23.02042007], [70.1498642, 23.02041626], [70.1498642, 23.02069473], [70.15013885, 23.02069473], [70.15013885, 23.0209713], [70.15040588, 23.02096939], [70.15040588, 23.02124977], [70.1506958, 23.02124977], [70.1506958, 23.02153015], [70.15097046, 23.02152824], [70.15097046, 23.02180672], [70.15125275, 23.02180672], [70.15125275, 23.02236176], [70.1515274, 23.02235985], [70.1515274, 23.02292061], [70.15180206, 23.02292061], [70.15180206, 23.02321053], [70.15235901, 23.02319527], [70.15235901, 23.02347183], [70.1526413, 23.02346992], [70.1526413, 23.02431107], [70.15291595, 23.02431107], [70.15291595, 23.02514076], [70.15319824, 23.02514076], [70.15319824, 23.02625084], [70.1534729, 23.02625084], [70.1534729, 23.02708244], [70.15374756, 23.02708244], [70.15374756, 23.02819443], [70.15402985, 23.02819061], [70.15402985, 23.02931023], [70.15374756, 23.02930641], [70.15374756, 23.02958107], [70.15319824, 23.02958107], [70.15319824, 23.02930641], [70.15319061, 23.0290184], [70.15291595, 23.02902794], [70.15291595, 23.0284729], [70.1526413, 23.0284729], [70.1526413, 23.02791595], [70.15235901, 23.02792168], [70.15235901, 23.02708054], [70.15208435, 23.02708244], [70.15208435, 23.02597237], [70.15180206, 23.02597237], [70.15180206, 23.02513885], [70.1515274, 23.02514076], [70.1515274, 23.02458], [70.15041351, 23.02458382], [70.15041351, 23.02430534], [70.15013885, 23.02431107], [70.15013885, 23.02403069], [70.14985657, 23.02403069], [70.14985657, 23.02375031], [70.14930725, 23.02375031], [70.14930725, 23.02347183], [70.14902496, 23.02347183], [70.14902496, 23.02319527], [70.14875031, 23.02321053], [70.14875031, 23.02292061], [70.14848328, 23.02292061], [70.14848328, 23.02264023], [70.1479187, 23.02264023], [70.1479187, 23.02235985], [70.14763641, 23.02236176], [70.14763641, 23.02208328], [70.14736176, 23.02208328], [70.14736176, 23.02180672], [70.1470871, 23.02180672], [70.1470871, 23.02152824], [70.14653015, 23.02153015], [70.14653015, 23.02124977], [70.14624786, 23.02124977], [70.14624786, 23.02096939], [70.14597321, 23.0209713], [70.14597321, 23.02069473], [70.14569092, 23.02069473], [70.14569092, 23.02013969], [70.14541626, 23.02015114], [70.14541626, 23.01986122], [70.1451416, 23.01986122], [70.1451416, 23.01958084], [70.14485931, 23.01958466], [70.14485931, 23.01930618], [70.14457703, 23.01931], [70.14457703, 23.01902962], [70.14430237, 23.01902962], [70.14430237, 23.01847076], [70.14402771, 23.01847458], [70.14402771, 23.01819229], [70.14375305, 23.01819229], [70.14375305, 23.01791763], [70.14347076, 23.01791954], [70.14347076, 23.01736259], [70.14318848, 23.01736259], [70.14318848, 23.01680946], [70.14289856, 23.01680946], [70.14289856, 23.01625252], [70.14263916, 23.01625252], [70.14263916, 23.01542282], [70.14235687, 23.01542282], [70.14235687, 23.01485825], [70.14208221, 23.01486015], [70.14208221, 23.01430511], [70.14180756, 23.01431084], [70.14180756, 23.0134697], [70.14152527, 23.0134716], [70.14152527, 23.01263809], [70.14125061, 23.01263809], [70.14125061, 23.0118103], [70.14097595, 23.0118103], [70.14097595, 23.01098061], [70.14068604, 23.01098061], [70.14068604, 23.01013947], [70.14041901, 23.01013947], [70.14041901, 23.00930977], [70.14015198, 23.00930977], [70.14015198, 23.00875092], [70.13986206, 23.00875092], [70.13986206, 23.00847054], [70.13930511, 23.00847244], [70.13930511, 23.00819588], [70.13903046, 23.00819588], [70.13903046, 23.0079174], [70.13846588, 23.00792122], [70.13846588, 23.00764084], [70.13819122, 23.00764084], [70.13819122, 23.00736046], [70.13791656, 23.00736046], [70.13791656, 23.00708008], [70.13764191, 23.0070858], [70.13764191, 23.00680542], [70.13709259, 23.00681114], [70.13709259, 23.00653076], [70.13680267, 23.00653076], [70.13680267, 23.00625038], [70.13652802, 23.00625038], [70.13652802, 23.00597], [70.13625336, 23.00597382], [70.13625336, 23.00569534], [70.13597107, 23.00570107], [70.13597107, 23.00542068], [70.13540649, 23.00542068], [70.13540649, 23.0051403], [70.13485718, 23.0051403], [70.13485718, 23.00485992], [70.13402557, 23.00486374], [70.13402557, 23.00458145], [70.13375092, 23.00458145], [70.13375092, 23.00430489], [70.13346863, 23.00430489], [70.13346863, 23.00402832], [70.13318634, 23.00403023], [70.13318634, 23.00375175], [70.13263702, 23.00375175], [70.13263702, 23.00346947], [70.13208008, 23.00347137], [70.13208008, 23.00319481], [70.13180542, 23.00319481], [70.13180542, 23.00291634], [70.13153076, 23.00292015], [70.13153076, 23.00235939], [70.13124847, 23.00235939], [70.13124847, 23.00208282], [70.13097382, 23.00208282], [70.13097382, 23.00180626], [70.13069153, 23.00181007], [70.13069153, 23.00124931], [70.13041687, 23.00124931], [70.13041687, 23.00097084], [70.13014221, 23.00097275], [70.13014221, 23.00069427], [70.12985992, 23.00069427], [70.12985992, 23.00013733], [70.1295929, 23.00013924], [70.1295929, 22.99986076], [70.12958527, 22.99930573], [70.12930298, 22.99930954], [70.12930298, 22.99875069], [70.12902832, 22.99875069], [70.12902832, 22.99847031], [70.12875366, 22.99847221], [70.12875366, 22.99791718], [70.12847137, 22.99792099], [70.12847137, 22.99707985], [70.12819672, 22.99708366], [70.12819672, 22.99652863], [70.12789917, 22.99653053], [70.12789917, 22.99625015], [70.12763977, 22.99625015], [70.12763977, 22.99570084], [70.12735748, 22.99570084], [70.12735748, 22.99542046], [70.12708282, 22.99542046], [70.12708282, 22.99514008], [70.12680817, 22.99514008], [70.12680817, 22.9948597], [70.12652588, 22.9948616], [70.12652588, 22.99430466], [70.12625122, 22.99430466], [70.12625122, 22.99402809], [70.12596893, 22.99403], [70.12596893, 22.99374962], [70.12568665, 22.99374962], [70.12568665, 22.99319077], [70.12541962, 22.99319458], [70.12541962, 22.9920845], [70.12513733, 22.9920845], [70.12513733, 22.99152756], [70.12486267, 22.99152946], [70.12486267, 22.99014282], [70.12458038, 22.99014282], [70.12458038, 22.98735809], [70.12430573, 22.98736191], [70.12430573, 22.98624992], [70.12403107, 22.98624992], [70.12403107, 22.98513985], [70.12374878, 22.98513985], [70.12374878, 22.98374939], [70.12346649, 22.98374939], [70.12346649, 22.98264122], [70.12319183, 22.98264122], [70.12319183, 22.98208046], [70.12236023, 22.98208427], [70.12236023, 22.9818058], [70.12097168, 22.98180962], [70.12097168, 22.98097992], [70.12069702, 22.98097992], [70.12069702, 22.98042107], [70.1204071, 22.98042107], [70.1204071, 22.98014069], [70.12014008, 22.98014069], [70.12014008, 22.97957993], [70.11985779, 22.97958565], [70.11985779, 22.97930527], [70.11958313, 22.97931099], [70.11958313, 22.97903061], [70.11930847, 22.97903061], [70.11930847, 22.97875023], [70.11901855, 22.97875023], [70.11901855, 22.97846985], [70.11875153, 22.97847366], [70.11875153, 22.97791672], [70.11846924, 22.97791672], [70.11846924, 22.97763824], [70.11818695, 22.97764015], [70.11818695, 22.97735977], [70.11791992, 22.97736359], [70.11791992, 22.9770813], [70.11736298, 22.9770813], [70.11736298, 22.97680473], [70.11708069, 22.97680473], [70.11708069, 22.97652817], [70.11653137, 22.97653008], [70.11653137, 22.9762516], [70.11624908, 22.9762516], [70.11624908, 22.97596931], [70.11569214, 22.97597122], [70.11569214, 22.97569466], [70.11541748, 22.97569466], [70.11541748, 22.97541618], [70.11486053, 22.97542191], [70.11486053, 22.97514153], [70.11458588, 22.97514153], [70.11458588, 22.9748497], [70.11430359, 22.97485924], [70.11430359, 22.97458267], [70.11402893, 22.97458267], [70.11402893, 22.97430611], [70.11374664, 22.97431183], [70.11374664, 22.97403145], [70.11321259, 22.97403145], [70.11321259, 22.97374916], [70.11292267, 22.97374916], [70.11292267, 22.97347069], [70.11264038, 22.9734726], [70.11264038, 22.97263718], [70.11235809, 22.97263908], [70.11235809, 22.97153091], [70.11207581, 22.97153091], [70.11207581, 22.97014046], [70.11180878, 22.97014046], [70.11180878, 22.96875], [70.11152649, 22.96875], [70.11152649, 22.96805954], [70.11152649, 22.96763802], [70.11125183, 22.96763992], [70.11125183, 22.96624947], [70.11096954, 22.96624947], [70.11096954, 22.96486282], [70.11068726, 22.96486282], [70.11068726, 22.96347046], [70.11042023, 22.96347046], [70.11042023, 22.96208382], [70.11069489, 22.96208382], [70.11069489, 22.96097183], [70.11096954, 22.96097183], [70.11096954, 22.96013832], [70.11125183, 22.96013832], [70.11125183, 22.95986938], [70.11152649, 22.95986938], [70.11152649, 22.95930099], [70.11180878, 22.95930481], [70.11180878, 22.95902824], [70.11207581, 22.95902824], [70.11207581, 22.95874977], [70.11235809, 22.95874977], [70.11235809, 22.95819092], [70.11264038, 22.95819473], [70.11264038, 22.95791626], [70.11292267, 22.95791817], [70.11292267, 22.95763969], [70.11347198, 22.95763969], [70.11347198, 22.95736122], [70.11374664, 22.95736122], [70.11374664, 22.95708084], [70.11430359, 22.95708275], [70.11430359, 22.95680618], [70.11486053, 22.95680809], [70.11486053, 22.95652962], [70.11514282, 22.95652962], [70.11514282, 22.95625114], [70.11569214, 22.95625114], [70.11569214, 22.95597076], [70.11624908, 22.95597267], [70.11624908, 22.9556942], [70.11653137, 22.9556942], [70.11653137, 22.95541573], [70.11708069, 22.95541954], [70.11708069, 22.95514107], [70.11736298, 22.95514107], [70.11736298, 22.95486069], [70.11763763, 22.95486069], [70.11763763, 22.95458031], [70.11819458, 22.95458412], [70.11819458, 22.95430565], [70.11846924, 22.95430946], [70.11846924, 22.95403099], [70.11875153, 22.95403099], [70.11875153, 22.95374107], [70.11902618, 22.95375061], [70.11902618, 22.95347214], [70.11930847, 22.95347214], [70.11930847, 22.95319557], [70.11985779, 22.95319557], [70.11985779, 22.9529171], [70.12014008, 22.95292091], [70.12014008, 22.95264053], [70.1204071, 22.95264053], [70.1204071, 22.95236015], [70.12097168, 22.95236015], [70.12097168, 22.95207977], [70.12124634, 22.95208359], [70.12124634, 22.95180321], [70.12180328, 22.95181084], [70.12180328, 22.95153046], [70.12236023, 22.95153046], [70.12236023, 22.95125008], [70.12264252, 22.95125008], [70.12264252, 22.9509697], [70.12319183, 22.95097351], [70.12319183, 22.95069504], [70.12374878, 22.95070076], [70.12374878, 22.95042038], [70.12403107, 22.95042038], [70.12403107, 22.95014191], [70.12458038, 22.95014191], [70.12458038, 22.94985962], [70.12513733, 22.94985962], [70.12513733, 22.94958115], [70.12569427, 22.94958115], [70.12569427, 22.94930649], [70.12625122, 22.94930077], [70.12625122, 22.94680595], [70.12652588, 22.94681168], [70.12652588, 22.94652748], [70.12431335, 22.94652748], [70.12431335, 22.94681168], [70.12319183, 22.94680595], [70.12319183, 22.94708252], [70.12180328, 22.94708061], [70.12180328, 22.94735909], [70.12124634, 22.94735909], [70.12124634, 22.94764137], [70.12097168, 22.94764137], [70.12097168, 22.94792938], [70.12041473, 22.94791603], [70.12041473, 22.9481945], [70.11985779, 22.9481945], [70.11985779, 22.94847107], [70.11958313, 22.94846916], [70.11958313, 22.94874954], [70.11901855, 22.94874954], [70.11901855, 22.94903183], [70.11875153, 22.94903183], [70.11875153, 22.9493103], [70.11819458, 22.94930649], [70.11819458, 22.94958115], [70.11763763, 22.94958115], [70.11763763, 22.94985962], [70.11736298, 22.94985962], [70.11736298, 22.95014191], [70.11680603, 22.95014191], [70.11680603, 22.95042038], [70.11653137, 22.95042038], [70.11653137, 22.95070076], [70.11597443, 22.95069504], [70.11597443, 22.95097351], [70.11569214, 22.9509697], [70.11569214, 22.95125008], [70.11514282, 22.95125008], [70.11514282, 22.95153046], [70.11458588, 22.95153046], [70.11458588, 22.95181084], [70.11402893, 22.95180321], [70.11402893, 22.95208359], [70.11347198, 22.95208359], [70.11347198, 22.95236206], [70.11292267, 22.95236015], [70.11292267, 22.95264053], [70.11096954, 22.95264053], [70.11096954, 22.95236015], [70.10958099, 22.95236206], [70.10958099, 22.95208359], [70.10930634, 22.95208359], [70.10930634, 22.95180321], [70.10901642, 22.95181084], [70.10901642, 22.95153046], [70.10874939, 22.95153046], [70.10874939, 22.95125008], [70.10819244, 22.95125008], [70.10819244, 22.9509697], [70.10791779, 22.95097351], [70.10791779, 22.95069504], [70.10764313, 22.95070076], [70.10764313, 22.95042038], [70.10736084, 22.95042038], [70.10736084, 22.94985962], [70.10708618, 22.94985962], [70.10708618, 22.94902992], [70.10678864, 22.94903183], [70.10678864, 22.94819069], [70.10652924, 22.9481945], [70.10652924, 22.94764137], [70.10624695, 22.94764137], [70.10624695, 22.94708061], [70.10597229, 22.94708252], [70.10597229, 22.94625092], [70.10569763, 22.94625092], [70.10569763, 22.94569016], [70.10541534, 22.94569397], [70.10541534, 22.94513893], [70.10514069, 22.94514084], [70.10514069, 22.94458008], [70.1048584, 22.94458389], [70.1048584, 22.94375038], [70.10457611, 22.94375038], [70.10457611, 22.94320107], [70.10430908, 22.94320107], [70.10430908, 22.9426403], [70.10401917, 22.9426403], [70.10401917, 22.94207954], [70.10375214, 22.94208336], [70.10375214, 22.94180679], [70.10124969, 22.94180679], [70.10124969, 22.94208336], [70.09986115, 22.94208336], [70.09986115, 22.94236183], [70.09819794, 22.94235992], [70.09819794, 22.9426403], [70.09764099, 22.9426403], [70.09764099, 22.94292068], [70.0973587, 22.94292068], [70.0973587, 22.94375038], [70.09707642, 22.94375038], [70.09707642, 22.94542122], [70.09680939, 22.9454174], [70.09680176, 22.94708252], [70.0965271, 22.94708252], [70.0965271, 22.9481945], [70.09625244, 22.94819069], [70.09625244, 22.94874954], [70.09597015, 22.94874954], [70.09597015, 22.9493103], [70.0956955, 22.94930649], [70.0956955, 22.94958115], [70.09541321, 22.94957924], [70.09541321, 22.95014191], [70.09570312, 22.95014191], [70.09570312, 22.95042038], [70.09541321, 22.95041656], [70.09541321, 22.95097351], [70.09513855, 22.9509697], [70.09513855, 22.95125008], [70.0945816, 22.95125008], [70.0945816, 22.95153046], [70.09430695, 22.95153046], [70.09430695, 22.95181084], [70.09347534, 22.95180321], [70.09347534, 22.95208359], [70.09263611, 22.95208359], [70.09263611, 22.95236206], [70.09178925, 22.95236015], [70.09178925, 22.95264053], [70.0909729, 22.95264053], [70.0909729, 22.95207977], [70.09124756, 22.95208359], [70.09124756, 22.95180321], [70.09178925, 22.95181084], [70.09178925, 22.95153046], [70.09236145, 22.95153046], [70.09236145, 22.95125008], [70.09348297, 22.95125008], [70.09347534, 22.95097351], [70.09375, 22.95097351], [70.09375, 22.95041656], [70.09401703, 22.95042038], [70.09401703, 22.94903183], [70.09430695, 22.94903183], [70.09430695, 22.94652748], [70.0945816, 22.94652748], [70.0945816, 22.94542122], [70.09484863, 22.94542122], [70.09484863, 22.94514084], [70.09513855, 22.94514084], [70.09513855, 22.94486809], [70.09541321, 22.94486809], [70.09541321, 22.94431114], [70.09570312, 22.94431114], [70.09570312, 22.94403076], [70.09597015, 22.94403076], [70.09597015, 22.94375038], [70.09625244, 22.94375038], [70.09625244, 22.94347], [70.0965271, 22.94347191], [70.0965271, 22.94291687], [70.09680176, 22.94292068], [70.09680176, 22.9426403], [70.09707642, 22.9426403], [70.09707642, 22.94235992], [70.0973587, 22.94236183], [70.0973587, 22.94180679], [70.09764099, 22.94180679], [70.09764099, 22.94152832], [70.09792328, 22.94153023], [70.09792328, 22.94096947], [70.09819794, 22.94097137], [70.09819794, 22.94041634], [70.0984726, 22.94042015], [70.0984726, 22.94013977], [70.09874725, 22.94013977], [70.09874725, 22.93958092], [70.09902954, 22.93958473], [70.09902954, 22.93930626], [70.09929657, 22.93931007], [70.09929657, 22.93902969], [70.09958649, 22.93902969], [70.09958649, 22.93847275], [70.09986115, 22.93847466], [70.09986115, 22.93819237], [70.10097504, 22.93819237], [70.10097504, 22.93847466], [70.10180664, 22.93847466], [70.10180664, 22.93874931], [70.10235596, 22.93873978], [70.10235596, 22.93902969], [70.10263824, 22.93902969], [70.10263824, 22.93931007], [70.10319519, 22.93930626], [70.10319519, 22.93958473], [70.10346985, 22.93958473], [70.10346985, 22.9398613], [70.10375214, 22.93985939], [70.10375214, 22.94013977], [70.10401917, 22.94013977], [70.10401917, 22.94042015], [70.10458374, 22.94041634], [70.10458374, 22.94069481], [70.1048584, 22.94069481], [70.1048584, 22.94097137], [70.10514069, 22.94096947], [70.10514069, 22.94124985], [70.10541534, 22.94124985], [70.10541534, 22.94180679], [70.10569763, 22.94180679], [70.10569763, 22.94208336], [70.10597229, 22.94208336], [70.10597229, 22.94236183], [70.10624695, 22.94235992], [70.10624695, 22.9426403], [70.10652924, 22.9426403], [70.10652924, 22.94320107], [70.10680389, 22.94319534], [70.10680389, 22.94347191], [70.10707855, 22.94347], [70.10707855, 22.94375038], [70.10736084, 22.94375038], [70.10736084, 22.94431114], [70.1076355, 22.94430542], [70.1076355, 22.94458389], [70.10791779, 22.94458008], [70.10791779, 22.94486809], [70.10819244, 22.94486809], [70.10819244, 22.94542122], [70.10847473, 22.9454174], [70.10847473, 22.94569397], [70.10874939, 22.94569397], [70.10874939, 22.94597244], [70.10901642, 22.94597054], [70.10901642, 22.94652748], [70.10930634, 22.94652748], [70.10930634, 22.94681168], [70.10958099, 22.94681168], [70.10958099, 22.94735909], [70.10986328, 22.94735909], [70.10986328, 22.94764137], [70.11013794, 22.94764137], [70.11013794, 22.94792938], [70.11042023, 22.94791603], [70.11042023, 22.94847107], [70.11068726, 22.94846916], [70.11068726, 22.94874954], [70.11096954, 22.94874954], [70.11096954, 22.94930077], [70.11125183, 22.94930649], [70.11125183, 22.94958115], [70.11264038, 22.94958115], [70.11264038, 22.94930649], [70.11321259, 22.94930077], [70.11319733, 22.94902992], [70.11347198, 22.94903183], [70.11347198, 22.94874954], [70.11402893, 22.94874954], [70.11402893, 22.94846916], [70.11430359, 22.94847107], [70.11430359, 22.9481945], [70.11458588, 22.9481945], [70.11458588, 22.94791603], [70.11486053, 22.94792938], [70.11486053, 22.94764137], [70.11541748, 22.94764137], [70.11541748, 22.94735909], [70.11569214, 22.94735909], [70.11569214, 22.94708061], [70.11597443, 22.94708252], [70.11597443, 22.94680595], [70.11653137, 22.94681168], [70.11653137, 22.94652748], [70.11680603, 22.94652748], [70.11680603, 22.94625092], [70.11736298, 22.94625092], [70.11736298, 22.94597054], [70.11791992, 22.94597244], [70.11791992, 22.94569397], [70.11819458, 22.94569397], [70.11819458, 22.9454174], [70.11875153, 22.94542122], [70.11875153, 22.94514084], [70.11985779, 22.94514084], [70.11985779, 22.94486809], [70.12124634, 22.94486809], [70.12124634, 22.94458008], [70.12236023, 22.94458389], [70.12236023, 22.94430542], [70.12403107, 22.94431114], [70.12403107, 22.94403076], [70.12596893, 22.94403076], [70.12596893, 22.94375038], [70.13153076, 22.94375038], [70.13153076, 22.94347], [70.13458252, 22.94347191], [70.13458252, 22.94319534], [70.13513947, 22.94320107], [70.13513947, 22.94292068], [70.13569641, 22.94292068], [70.13569641, 22.9426403], [70.13625336, 22.9426403], [70.13625336, 22.94235992], [70.13680267, 22.94236183], [70.13680267, 22.94208336], [70.13735962, 22.94208336], [70.13735962, 22.94180679], [70.13764191, 22.94180679], [70.13764191, 22.94152832], [70.13819122, 22.94153023], [70.13819122, 22.94124985], [70.13903046, 22.94124985], [70.13903046, 22.94069099], [70.13930511, 22.94069481], [70.13930511, 22.93763924], [70.13903046, 22.93764114], [70.13903046, 22.93320084], [70.13874817, 22.93320084], [70.13874817, 22.9323597], [70.13847351, 22.9323616], [70.13847351, 22.93180466], [70.13819122, 22.93180466], [70.13819122, 22.93124962], [70.13791656, 22.93124962], [70.13791656, 22.93097115], [70.13764191, 22.93097305], [70.13764191, 22.93069458], [70.13735962, 22.93069458], [70.13735962, 22.93013954], [70.13708496, 22.93013954], [70.13708496, 22.9295826], [70.13680267, 22.9295826], [70.13680267, 22.92930794], [70.13652802, 22.92930984], [70.13652802, 22.92902946], [70.13625336, 22.92902946], [70.13625336, 22.92875099], [70.13597107, 22.92875099], [70.13597107, 22.92819023], [70.13569641, 22.92819595], [70.13569641, 22.92763901], [70.13540649, 22.92764091], [70.13540649, 22.92736053], [70.13485718, 22.92736053], [70.13485718, 22.92708015], [70.13458252, 22.92708588], [70.13458252, 22.9268055], [70.13402557, 22.9268055], [70.13402557, 22.92652702], [70.13375092, 22.92653084], [70.13375092, 22.92625046], [70.13346863, 22.92625046], [70.13346863, 22.92597008], [70.13319397, 22.92597389], [70.13319397, 22.92569542], [70.13291931, 22.9256897], [70.13291931, 22.92541695], [70.13263702, 22.92542076], [70.13263702, 22.92514038], [70.13236237, 22.92514038], [70.13236237, 22.92486191], [70.13208008, 22.92486382], [70.13208008, 22.92458153], [70.13153076, 22.92458153], [70.13153076, 22.92430305], [70.13095856, 22.92431068], [70.13095856, 22.9240303], [70.13014221, 22.9240303], [70.13014221, 22.92375946], [70.1295929, 22.92375946], [70.1295929, 22.92346954], [70.12902832, 22.92347336], [70.12902832, 22.92319489], [70.12847137, 22.92319489], [70.12847137, 22.92291641], [70.12789917, 22.92292023], [70.12789917, 22.92264175], [70.12735748, 22.92264175], [70.12735748, 22.92235947], [70.12680817, 22.92235947], [70.12680817, 22.9220829], [70.12596893, 22.9220829], [70.12596893, 22.92180634], [70.12541962, 22.92181015], [70.12541962, 22.92153168], [70.12486267, 22.92153168], [70.12486267, 22.92124939], [70.12430573, 22.92124939], [70.12430573, 22.92097282], [70.12319183, 22.92097282], [70.12319183, 22.92069435], [70.12264252, 22.92070007], [70.12264252, 22.9204216], [70.1220932, 22.9204216], [70.1220932, 22.92013931], [70.12180328, 22.92013931], [70.12180328, 22.91958046], [70.12152863, 22.91958427], [70.12152863, 22.9193058], [70.12124634, 22.91930962], [70.12124634, 22.91903114], [70.12097168, 22.91903114], [70.12097168, 22.91847038], [70.12069702, 22.91847229], [70.12069702, 22.91819382], [70.12041473, 22.91819382], [70.12041473, 22.91791725], [70.12014008, 22.91792107], [70.12014008, 22.91763115], [70.11985779, 22.91763878], [70.11985779, 22.91736031], [70.11958313, 22.91736031], [70.11958313, 22.91707993], [70.11819458, 22.91708374], [70.11819458, 22.91680527], [70.11791992, 22.91681099], [70.11791992, 22.91653061], [70.11763763, 22.91653061], [70.11763763, 22.91625023], [70.11736298, 22.91625023], [70.11736298, 22.91596985], [70.11708069, 22.91597176], [70.11708069, 22.91569519], [70.11680603, 22.91570091], [70.11680603, 22.91557121], [70.11680603, 22.91541672], [70.11624908, 22.91542053], [70.11624908, 22.91514015], [70.11595917, 22.91514015], [70.11595917, 22.91485977], [70.11458588, 22.91486168], [70.11458588, 22.91430473], [70.11430359, 22.91430473], [70.11430359, 22.91402817], [70.11374664, 22.91403008], [70.11374664, 22.91374969], [70.11291504, 22.91374969], [70.11291504, 22.91319466], [70.11264038, 22.91319466], [70.11264038, 22.91263962], [70.11207581, 22.91263962], [70.11207581, 22.91236115], [70.11152649, 22.91236115], [70.11152649, 22.91208076], [70.11096954, 22.91208458], [70.11096954, 22.91180611], [70.11068726, 22.91181946], [70.11068726, 22.91152954], [70.11013794, 22.91152954], [70.11013794, 22.91125107], [70.10958099, 22.91125107], [70.10958099, 22.91097069], [70.10902405, 22.91097069], [70.10902405, 22.91069221], [70.10847473, 22.91069221], [70.10847473, 22.91041756], [70.10819244, 22.91041946], [70.10819244, 22.9101429], [70.10764313, 22.9101429], [70.10764313, 22.90986252], [70.10707855, 22.90986252], [70.10707855, 22.90958023], [70.10652924, 22.90958405], [70.10652924, 22.90930557], [70.10597229, 22.90930939], [70.10597229, 22.90903282], [70.10457611, 22.90903282], [70.10457611, 22.90876007], [70.10346985, 22.90876007], [70.10346985, 22.90847015], [70.1020813, 22.90847015], [70.1020813, 22.90819359], [70.1001358, 22.90819359], [70.1001358, 22.90791702], [70.09792328, 22.90792084], [70.09792328, 22.90763855], [70.08875275, 22.90763855], [70.08875275, 22.90792084], [70.08708191, 22.90791702], [70.08708191, 22.90819359], [70.0854187, 22.90819359], [70.0854187, 22.90847015], [70.08429718, 22.90847015], [70.08429718, 22.90876007], [70.08403015, 22.90876007], [70.08403015, 22.90903282], [70.0826416, 22.90903282], [70.0826416, 22.90876007], [70.08180237, 22.90876007], [70.08180237, 22.90818977], [70.08208466, 22.90819359], [70.08208466, 22.90763855], [70.08235931, 22.90763855], [70.08235931, 22.90735817], [70.0826416, 22.90736008], [70.0826416, 22.90708351], [70.08291626, 22.90708351], [70.08291626, 22.90680504], [70.0826416, 22.90681076], [70.0826416, 22.90652847], [70.08235931, 22.90652847], [70.08235931, 22.90624809], [70.08207703, 22.90624809], [70.08207703, 22.90596962], [70.08152771, 22.90596962], [70.08152771, 22.90624809], [70.08125305, 22.90624809], [70.08125305, 22.90681076], [70.07847595, 22.90681076], [70.07847595, 22.90652847], [70.07791901, 22.90652847], [70.07791901, 22.90624809], [70.07736206, 22.90624809], [70.07736206, 22.90596962], [70.07624817, 22.90597153], [70.07624817, 22.90569496], [70.07597351, 22.90569496], [70.07597351, 22.90597153], [70.07569122, 22.90597153], [70.07569122, 22.90569496], [70.07541656, 22.90569496], [70.07541656, 22.90541649], [70.07290649, 22.9054203], [70.07290649, 22.90513992], [70.07208252, 22.90513992], [70.07208252, 22.90485954], [70.07125092, 22.90486145], [70.07125092, 22.90458298], [70.06930542, 22.90458298], [70.06930542, 22.90430641], [70.06903076, 22.90431023], [70.06903076, 22.90402985], [70.06764221, 22.90402985], [70.06764221, 22.90431023], [70.06652832, 22.90431023], [70.06652832, 22.90402985], [70.06624603, 22.90402985], [70.06624603, 22.90374947], [70.06597137, 22.90374947], [70.06597137, 22.90347099], [70.06485748, 22.9034729], [70.06487274, 22.90374947], [70.06458282, 22.90374947], [70.06458282, 22.90402985], [70.06375122, 22.90402985], [70.06375122, 22.90431023], [70.06236267, 22.90431023], [70.06236267, 22.90402985], [70.06041718, 22.90402985], [70.06041718, 22.90374947], [70.05708313, 22.90374947], [70.05708313, 22.90402985], [70.05596924, 22.90402985], [70.05596924, 22.90431023], [70.05458069, 22.90431023], [70.05458069, 22.90402985], [70.05374908, 22.90402985], [70.05374908, 22.90374947], [70.05319214, 22.90374947], [70.05319214, 22.90347099], [70.05263519, 22.9034729], [70.05263519, 22.90319443], [70.05236053, 22.90319443], [70.05236053, 22.90291786], [70.05179596, 22.90291977], [70.05179596, 22.90262985], [70.05152893, 22.90263939], [70.05152893, 22.90236092], [70.05097198, 22.90236092], [70.05097198, 22.90208054], [70.05014038, 22.90208244], [70.05014038, 22.90125084], [70.05042267, 22.90125084], [70.05041504, 22.9006958], [70.05014038, 22.9006958], [70.05014038, 22.90041733], [70.04987335, 22.90042114], [70.04987335, 22.90014076], [70.04957581, 22.90014076], [70.04957581, 22.89986038], [70.04902649, 22.89986038], [70.04902649, 22.89957047], [70.04846954, 22.89958572], [70.04846954, 22.89930534], [70.04458618, 22.89931107], [70.04458618, 22.89903069], [70.04373932, 22.89903069], [70.04373932, 22.89875031], [70.04291534, 22.89875031], [70.04291534, 22.89847374], [70.0423584, 22.89847374], [70.0423584, 22.89819527], [70.04152679, 22.8982029], [70.04152679, 22.89792061], [70.03901672, 22.89792061], [70.03901672, 22.89764023], [70.03569794, 22.89764023], [70.03569794, 22.89735985], [70.03430176, 22.89736366], [70.03430176, 22.89708138], [70.03347015, 22.89708138], [70.03347015, 22.89680481], [70.03291321, 22.89680481], [70.03291321, 22.89625168], [70.03263855, 22.89625168], [70.03263855, 22.89542007], [70.0320816, 22.89541626], [70.0320816, 22.89569473], [70.03180695, 22.89569473], [70.03180695, 22.89596939], [70.0315094, 22.89596939], [70.0315094, 22.89625168], [70.03125, 22.89625168], [70.03125, 22.89708138], [70.03097534, 22.89708138], [70.03097534, 22.89736366], [70.03013611, 22.89735985], [70.03013611, 22.89764023], [70.02958679, 22.89763832], [70.02958679, 22.89847374], [70.02929688, 22.89846992], [70.0293045, 22.89875031], [70.02876282, 22.89875031], [70.02876282, 22.89903069], [70.0276413, 22.89903069], [70.0276413, 22.89931107], [70.02735901, 22.89930534], [70.02735901, 22.89958572], [70.0265274, 22.89957047], [70.0265274, 22.89986038], [70.02625275, 22.89986038], [70.02625275, 22.90014076], [70.02597046, 22.90014076], [70.02597046, 22.90042114], [70.02541351, 22.90041733], [70.02541351, 22.9006958], [70.0248642, 22.9006958], [70.0248642, 22.90097237], [70.02458191, 22.90097237], [70.02458191, 22.90125084], [70.02403259, 22.90125084], [70.02403259, 22.90153122], [70.02124786, 22.90153122], [70.02124786, 22.90125084], [70.02069092, 22.90125084], [70.02069092, 22.90069008], [70.02097321, 22.9006958], [70.02097321, 22.90057945], [70.02097321, 22.90041733], [70.02069092, 22.90042114], [70.02069092, 22.90014076], [70.0201416, 22.90014076], [70.0201416, 22.89957047], [70.01985931, 22.89958572], [70.01985931, 22.89930534], [70.01902771, 22.89930534], [70.01902771, 22.89958572], [70.01847076, 22.89958572], [70.01847076, 22.89930534], [70.01791382, 22.89930534], [70.01791382, 22.89958572], [70.01763916, 22.89957047], [70.01763916, 22.90014076], [70.01819611, 22.90013885], [70.01819611, 22.9006958], [70.01847076, 22.90069008], [70.01847076, 22.90125084], [70.01819611, 22.90125084], [70.01819611, 22.90153122], [70.01735687, 22.90153122], [70.01735687, 22.90125084], [70.01708221, 22.90125084], [70.01708221, 22.90069008], [70.01680756, 22.9006958], [70.01680756, 22.90041733], [70.01569366, 22.90041733], [70.01569366, 22.9006958], [70.01541901, 22.90069008], [70.01541901, 22.90125084], [70.01513672, 22.90125084], [70.01513672, 22.90208244], [70.01486206, 22.90208244], [70.01486206, 22.90097237], [70.01346588, 22.90097046], [70.01346588, 22.90125084], [70.01264191, 22.90125084], [70.01264191, 22.90097046], [70.01235962, 22.90097237], [70.01235962, 22.9006958], [70.01291656, 22.9006958], [70.01291656, 22.90041733], [70.01319122, 22.90042114], [70.01319122, 22.89986038], [70.01264191, 22.89986038], [70.01264191, 22.89957047], [70.01208496, 22.89958572], [70.01209259, 22.89986038], [70.01180267, 22.89986038], [70.01180267, 22.90014076], [70.01125336, 22.90013885], [70.01125336, 22.9006958], [70.01069641, 22.90069008], [70.01069641, 22.90125084], [70.01125336, 22.90125084], [70.01125336, 22.90208244], [70.01041412, 22.90208244], [70.01041412, 22.90180588], [70.01013947, 22.90180969], [70.01013947, 22.90069008], [70.00958252, 22.9006958], [70.00958252, 22.90041733], [70.00875092, 22.90042114], [70.00875092, 22.90014076], [70.00846863, 22.90014076], [70.00846863, 22.89957047], [70.00819397, 22.89958572], [70.00819397, 22.89930534], [70.00736237, 22.89930534], [70.00736237, 22.89958572], [70.00624847, 22.89957047], [70.00624847, 22.89986038], [70.00569153, 22.89986038], [70.00569153, 22.90014076], [70.00514221, 22.90014076], [70.00514221, 22.90042114], [70.00485992, 22.90042114], [70.00485992, 22.90014076], [70.00402832, 22.90014076], [70.00402832, 22.89986038], [70.00374603, 22.89986038], [70.00374603, 22.90014076], [70.00235748, 22.90014076], [70.00235748, 22.89986038], [70.00121307, 22.89986038], [70.00068665, 22.89986038], [70.00068665, 22.90014076], [70.00041962, 22.90014076], [70.00041962, 22.90042114], [70.00013733, 22.90042114], [70.00013733, 22.90291977], [69.99986267, 22.90291977], [69.99597168, 22.90291977], [69.99597168, 22.90262985], [69.99541473, 22.90263939], [69.99541473, 22.90236092], [69.99485779, 22.90236092], [69.99485779, 22.90208054], [69.99430847, 22.90208244], [69.99430847, 22.90180588], [69.99346924, 22.90180969], [69.99346924, 22.90153122], [69.99291992, 22.90153122], [69.99291992, 22.90125084], [69.99208069, 22.90125084], [69.99208069, 22.90097046], [69.99153137, 22.90097237], [69.99153137, 22.9006958], [69.99069214, 22.9006958], [69.99069214, 22.90041733], [69.99014282, 22.90042114], [69.99014282, 22.90014076], [69.98958588, 22.90014076], [69.98958588, 22.89986038], [69.98791504, 22.89986038], [69.98791504, 22.89958572], [69.98596954, 22.89958572], [69.98596954, 22.89930534], [69.98542023, 22.89931107], [69.98542023, 22.89903069], [69.98401642, 22.89903069], [69.98401642, 22.89875031], [69.98291779, 22.89875031], [69.98291779, 22.89846992], [69.98152924, 22.89847374], [69.98152924, 22.89819527], [69.98014069, 22.8982029], [69.98014069, 22.89792061], [69.97820282, 22.89792061], [69.97820282, 22.89764023], [69.97624969, 22.89764023], [69.97624969, 22.89735985], [69.97402954, 22.89736366], [69.97402954, 22.89708138], [69.97208405, 22.89708138], [69.97208405, 22.89680481], [69.96986389, 22.89680481], [69.96986389, 22.89652824], [69.96875, 22.89653015], [69.96875, 22.89625168], [69.96736145, 22.89625168], [69.96736145, 22.89596939], [69.96624756, 22.89596939], [69.96624756, 22.89569473], [69.96485901, 22.89569473], [69.96485901, 22.89541626], [69.96347046, 22.89542007], [69.96347046, 22.8951416], [69.96180725, 22.8951416], [69.96180725, 22.89485931], [69.96013641, 22.89485931], [69.96013641, 22.8943119], [69.95903015, 22.89430618], [69.95903015, 22.89458275], [69.95847321, 22.89458084], [69.95847321, 22.89485931], [69.95819092, 22.89485931], [69.95819092, 22.8951416], [69.9576416, 22.8951416], [69.9576416, 22.89542007], [69.95735931, 22.89541626], [69.95735931, 22.89569473], [69.95625305, 22.89569473], [69.95625305, 22.89596939], [69.95597076, 22.89596939], [69.95597076, 22.89569473], [69.95569611, 22.89569473], [69.95569611, 22.89541626], [69.95540619, 22.89542007], [69.95540619, 22.8943119], [69.9540329, 22.8943119], [69.9540329, 22.89403152], [69.95153046, 22.89403152], [69.95153046, 22.89319038], [69.95124817, 22.8931942], [69.95124817, 22.89291763], [69.94790649, 22.89291763], [69.94790649, 22.89263916], [69.94680786, 22.89263916], [69.94680786, 22.89291763], [69.94596863, 22.89291763], [69.94596863, 22.89263916], [69.94458008, 22.89263916], [69.94458008, 22.89236069], [69.94403076, 22.89236069], [69.94403076, 22.89263916], [69.9404068, 22.89263916], [69.9404068, 22.89291763], [69.93736267, 22.89291763], [69.93736267, 22.8931942], [69.93708038, 22.8931942], [69.93708038, 22.89291763], [69.93681335, 22.89291763], [69.93681335, 22.89208031], [69.93653107, 22.89208412], [69.93653107, 22.89152718], [69.93624878, 22.89152908], [69.93624878, 22.89014053], [69.93596649, 22.89014053], [69.93596649, 22.88986015], [69.93569183, 22.88986206], [69.93569183, 22.88763809], [69.93540955, 22.88764954], [69.93540955, 22.88708115], [69.93514252, 22.88708305], [69.93514252, 22.88652802], [69.93486023, 22.88652992], [69.93486023, 22.88624954], [69.93458557, 22.88624954], [69.93458557, 22.8856945], [69.93430328, 22.8856945], [69.93430328, 22.88541603], [69.93402863, 22.88541985], [69.93402863, 22.88513947], [69.93347168, 22.88513947], [69.93347168, 22.8848629], [69.93319702, 22.8848629], [69.93319702, 22.88459015], [69.9329071, 22.88459015], [69.9329071, 22.88430977], [69.93235016, 22.88430977], [69.93235016, 22.88402939], [69.93208313, 22.88402939], [69.93208313, 22.88375282], [69.93180847, 22.88375282], [69.93180847, 22.88347054], [69.93152618, 22.88347054], [69.93152618, 22.88319206], [69.93096924, 22.88319206], [69.93096924, 22.8829174], [69.93068695, 22.88292122], [69.93068695, 22.88264275], [69.93041992, 22.88264275], [69.93041992, 22.88236237], [69.92986298, 22.88236237], [69.92986298, 22.88208008], [69.92958069, 22.88208389], [69.92958069, 22.88180542], [69.92930603, 22.88181114], [69.92930603, 22.88153076], [69.92903137, 22.88153076], [69.92903137, 22.88124847], [69.92874908, 22.88124847], [69.92874908, 22.88096809], [69.92847443, 22.88097191], [69.92847443, 22.88069534], [69.92819214, 22.88069916], [69.92819214, 22.88042068], [69.92791748, 22.88042068], [69.92791748, 22.8801384], [69.92679596, 22.8801384], [69.92679596, 22.87985992], [69.92624664, 22.87986183], [69.92624664, 22.87958336], [69.92597198, 22.87958336], [69.92597198, 22.87930489], [69.92569733, 22.87930489], [69.92569733, 22.87902832], [69.92542267, 22.87902832], [69.92542267, 22.87874985], [69.92485809, 22.87874985], [69.92485809, 22.87845993], [69.92458344, 22.87847137], [69.92458344, 22.87819481], [69.92402649, 22.87819481], [69.92402649, 22.87791634], [69.92375183, 22.87791824], [69.92375183, 22.87763977], [69.92346954, 22.87763977], [69.92346954, 22.87735939], [69.92319489, 22.8773613], [69.92319489, 22.87708282], [69.92292023, 22.87708282], [69.92292023, 22.87680626], [69.92236328, 22.87681007], [69.92236328, 22.87652969], [69.92208099, 22.87652969], [69.92208099, 22.87625122], [69.92151642, 22.87625122], [69.92151642, 22.87597084], [69.92124939, 22.87597275], [69.92124939, 22.87569427], [69.92069244, 22.87569427], [69.92069244, 22.8754158], [69.92041016, 22.87541962], [69.92041016, 22.87514114], [69.91986084, 22.87514114], [69.91986084, 22.87486076], [69.91958618, 22.87486076], [69.91958618, 22.87458038], [69.91902924, 22.8745842], [69.91902924, 22.87430573], [69.91874695, 22.87430954], [69.91874695, 22.87403107], [69.91847229, 22.87403107], [69.91847229, 22.87347031], [69.91819763, 22.87347221], [69.91819763, 22.87291718], [69.91764069, 22.87291718], [69.91764069, 22.87319565], [69.9126358, 22.87319565], [69.9126358, 22.87291718], [69.91179657, 22.87292099], [69.91179657, 22.87236023], [69.91152954, 22.87236023], [69.91152954, 22.87014008], [69.91124725, 22.87014008], [69.91124725, 22.86959267], [69.9109726, 22.86959267], [69.9109726, 22.86930084], [69.9098587, 22.86930466], [69.9098587, 22.86902809], [69.90930176, 22.86903191], [69.90930176, 22.86875153], [69.90875244, 22.86875153], [69.90875244, 22.86819077], [69.90847015, 22.86819458], [69.90847015, 22.86791611], [69.90820313, 22.86792183], [69.90820313, 22.86764145], [69.90791321, 22.86764145], [69.90791321, 22.86735916], [69.90735626, 22.86735916], [69.90735626, 22.86708069], [69.90652466, 22.8670826], [69.90652466, 22.86680603], [69.90569305, 22.86681175], [69.90569305, 22.86624908], [69.9043045, 22.86624718], [69.9043045, 22.86652756], [69.90291595, 22.86652756], [69.90291595, 22.86624718], [69.90236664, 22.86624908], [69.90236664, 22.86597061], [69.90208435, 22.86597252], [69.90208435, 22.86569405], [69.90180206, 22.86569405], [69.90180206, 22.86541748], [69.9015274, 22.86541748], [69.9015274, 22.86514091], [69.90040588, 22.86514091], [69.90040588, 22.86541748], [69.89736176, 22.86541748], [69.89736176, 22.86514091], [69.8970871, 22.86514091], [69.8970871, 22.86541748], [69.89541626, 22.86541748], [69.89541626, 22.86569405], [69.89291382, 22.86569405], [69.89291382, 22.86597252], [69.8915329, 22.86597061], [69.8915329, 22.86624908], [69.89041901, 22.86624718], [69.89041901, 22.86652756], [69.88986206, 22.86651993], [69.88986206, 22.86681175], [69.88957977, 22.86680603], [69.88957977, 22.8670826], [69.88903046, 22.86708069], [69.88903046, 22.86764145], [69.88874817, 22.86764145], [69.88874817, 22.86792183], [69.88847351, 22.86791611], [69.88847351, 22.86819458], [69.88791656, 22.86819458], [69.88791656, 22.86847115], [69.88764191, 22.86846924], [69.88764191, 22.86875153], [69.88736725, 22.86875153], [69.88736725, 22.86903191], [69.88709259, 22.86903191], [69.88709259, 22.86959267], [69.88652802, 22.86958122], [69.88652802, 22.86986351], [69.88597107, 22.8698597], [69.88597107, 22.87014008], [69.88513947, 22.87014008], [69.88513947, 22.87042046], [69.88458252, 22.87042046], [69.88458252, 22.87070084], [69.88375092, 22.87069511], [69.88375092, 22.87097359], [69.88180542, 22.87097359], [69.88181305, 22.87125015], [69.88069153, 22.87125015], [69.88069153, 22.87153053], [69.8795929, 22.87153053], [69.8795929, 22.87181091], [69.87847137, 22.87180519], [69.87847137, 22.87208366], [69.87735748, 22.87207985], [69.87735748, 22.87236023], [69.87568665, 22.87236023], [69.87568665, 22.87207985], [69.87347412, 22.87208366], [69.87347412, 22.87180519], [69.87124634, 22.87181091], [69.87124634, 22.87153053], [69.86875153, 22.87153053], [69.86875153, 22.87181091], [69.86819458, 22.87180519], [69.86819458, 22.87208366], [69.86791992, 22.87207985], [69.86791992, 22.87292099], [69.86680603, 22.87292099], [69.86680603, 22.87265015], [69.86569214, 22.87265015], [69.86569214, 22.87236023], [69.86513519, 22.87236023], [69.86513519, 22.87208366], [69.86458588, 22.87208366], [69.86458588, 22.87180519], [69.86374664, 22.87181091], [69.86374664, 22.87153053], [69.86292267, 22.87153053], [69.86292267, 22.87125015], [69.86207581, 22.87125015], [69.86207581, 22.87096977], [69.86125183, 22.87097359], [69.86125183, 22.87069511], [69.86068726, 22.87070084], [69.86068726, 22.87042046], [69.85986328, 22.87042046], [69.85986328, 22.87014008], [69.85901642, 22.87014008], [69.85901642, 22.8698597], [69.85819244, 22.86986351], [69.85819244, 22.86958122], [69.85736084, 22.86959267], [69.85736084, 22.86764145], [69.85764313, 22.86764145], [69.8576355, 22.86680603], [69.85819244, 22.86681175], [69.85819244, 22.86651993], [69.85847473, 22.86652756], [69.85847473, 22.86624718], [69.85874939, 22.86624908], [69.85874939, 22.86541748], [69.85901642, 22.86541748], [69.85901642, 22.86514091], [69.85958099, 22.86514091], [69.85958099, 22.86458015], [69.86013794, 22.86458397], [69.86013794, 22.86263847], [69.86042023, 22.86264038], [69.86042023, 22.8615303], [69.86068726, 22.8615303], [69.86068726, 22.86124992], [69.86096954, 22.86124992], [69.86096954, 22.86069107], [69.86125183, 22.86069489], [69.86125183, 22.86013794], [69.86152649, 22.86013985], [69.86152649, 22.8595829], [69.86180878, 22.85958481], [69.86180878, 22.85902786], [69.86207581, 22.85902977], [69.86207581, 22.85847282], [69.86125183, 22.85847282], [69.86125183, 22.85874939], [69.86096954, 22.85874939], [69.86096954, 22.85902977], [69.86068726, 22.85902977], [69.86068726, 22.85931015], [69.86042023, 22.85930634], [69.86042023, 22.85986137], [69.86013031, 22.85985947], [69.86013031, 22.86013985], [69.85986328, 22.86013985], [69.85986328, 22.86069489], [69.85958099, 22.86069107], [69.85958099, 22.8615303], [69.85930634, 22.8615284], [69.85930634, 22.86236191], [69.85901642, 22.86236], [69.85901642, 22.86264038], [69.85874939, 22.86264038], [69.85874939, 22.86375046], [69.8584671, 22.86375046], [69.8584671, 22.86403084], [69.85819244, 22.86402893], [69.85819244, 22.86458397], [69.85791779, 22.86458015], [69.85791779, 22.86541748], [69.8576355, 22.86541748], [69.8576355, 22.86569405], [69.85708618, 22.86569405], [69.85708618, 22.86597252], [69.85680389, 22.86597252], [69.85680389, 22.86652756], [69.85652924, 22.86652756], [69.85652924, 22.8670826], [69.85624695, 22.86708069], [69.85624695, 22.86764145], [69.85597229, 22.86764145], [69.85597229, 22.86792183], [69.85569763, 22.86791611], [69.85569763, 22.86819458], [69.85375214, 22.86819458], [69.85375214, 22.86791611], [69.8529129, 22.86792183], [69.8529129, 22.86764145], [69.8520813, 22.86764145], [69.8520813, 22.86735916], [69.85069275, 22.86735916], [69.85069275, 22.86708069], [69.84986115, 22.8670826], [69.84986115, 22.86680603], [69.84902954, 22.86681175], [69.84902954, 22.86651993], [69.84819794, 22.86652756], [69.84819794, 22.86624718], [69.8473587, 22.86624908], [69.8473587, 22.86597061], [69.8465271, 22.86597252], [69.8465271, 22.86569405], [69.8456955, 22.86569405], [69.8456955, 22.86541748], [69.84485626, 22.86541748], [69.84485626, 22.86514091], [69.84401703, 22.86514091], [69.84401703, 22.86486053], [69.84319305, 22.86486053], [69.84319305, 22.86458015], [69.84236145, 22.86458397], [69.84236145, 22.8643055], [69.84124756, 22.86431122], [69.84124756, 22.86403084], [69.8409729, 22.86403084], [69.8409729, 22.86375046], [69.84041595, 22.86375046], [69.84041595, 22.86346054], [69.83985901, 22.86347198], [69.83985901, 22.86319542], [69.83957672, 22.8631897], [69.83958435, 22.86291695], [69.83847046, 22.86292076], [69.83847046, 22.86264038], [69.83763885, 22.86264038], [69.83763885, 22.86236], [69.83708191, 22.86236191], [69.83708191, 22.86208344], [69.83652496, 22.86208344], [69.83652496, 22.86180687], [69.83598328, 22.86181068], [69.83598328, 22.8615303], [69.83513641, 22.8615303], [69.83513641, 22.86124992], [69.8345871, 22.86124992], [69.8345871, 22.86096954], [69.83403015, 22.86097145], [69.83403015, 22.86069489], [69.83347321, 22.86069489], [69.83347321, 22.86041641], [69.83291626, 22.86042023], [69.83291626, 22.86013985], [69.83235931, 22.86013985], [69.83235931, 22.85985947], [69.83180237, 22.85986137], [69.83180237, 22.85958481], [69.83125305, 22.85958481], [69.83125305, 22.85930634], [69.83040619, 22.85931015], [69.83040619, 22.85902977], [69.82985687, 22.85902977], [69.82985687, 22.85874939], [69.82930756, 22.85874939], [69.82930756, 22.85847282], [69.82875061, 22.85847473], [69.82875061, 22.85819435], [69.82819366, 22.85819435], [69.82819366, 22.85791588], [69.82791901, 22.85791969], [69.82791901, 22.85765076], [69.82736206, 22.85765076], [69.82736206, 22.85736275], [69.82680511, 22.85736275], [69.82680511, 22.85708427], [69.82624817, 22.85708427], [69.82624817, 22.8568058], [69.82596588, 22.85680962], [69.82596588, 22.85653114], [69.82541656, 22.85653114], [69.82541656, 22.85625267], [69.82485962, 22.85625267], [69.82485962, 22.85597038], [69.82430267, 22.85597038], [69.82430267, 22.85569382], [69.82402802, 22.85569382], [69.82402802, 22.85541725], [69.82347107, 22.85542107], [69.82347107, 22.85514259], [69.82290649, 22.85514259], [69.82290649, 22.8548584], [69.82235718, 22.8548584], [69.82235718, 22.85457993], [69.82208252, 22.85458374], [69.82208252, 22.85430527], [69.82125092, 22.85430908], [69.82125092, 22.85403061], [69.82013702, 22.85403061], [69.82013702, 22.85374832], [69.81903076, 22.85374832], [69.81903076, 22.85320091], [69.81846619, 22.85320091], [69.81846619, 22.85292053], [69.81819153, 22.85292053], [69.81819153, 22.85263824], [69.8170929, 22.85263824], [69.8170929, 22.85235977], [69.81680298, 22.85236168], [69.81680298, 22.85208321], [69.81485748, 22.85207939], [69.81485748, 22.85263824], [69.81318665, 22.85263824], [69.81318665, 22.85292053], [69.81096649, 22.85292053], [69.81096649, 22.85263824], [69.80930328, 22.85263824], [69.80930328, 22.85235977], [69.80735779, 22.85236168], [69.80735779, 22.85208321], [69.80569458, 22.85208321], [69.80569458, 22.85180473], [69.80374908, 22.85180473], [69.80374908, 22.85152626], [69.80208588, 22.85152626], [69.80208588, 22.85124969], [69.80014038, 22.85124969], [69.80014038, 22.85097122], [69.79930878, 22.85097313], [69.79930878, 22.85069466], [69.79846954, 22.85069466], [69.79846954, 22.85041618], [69.79792023, 22.85041809], [69.79792023, 22.84986115], [69.79763794, 22.84986115], [69.79763794, 22.84958076], [69.79708099, 22.84958267], [69.79708099, 22.84930611], [69.79680634, 22.84930992], [69.79680634, 22.84902954], [69.79651642, 22.84902954], [69.79651642, 22.84875107], [69.79624939, 22.84875107], [69.79624939, 22.84848022], [69.7959671, 22.84848022], [69.7959671, 22.84819031], [69.79541779, 22.84819412], [69.79541779, 22.84791756], [69.79514313, 22.84791946], [69.79514313, 22.84764099], [69.79486084, 22.84764099], [69.79486084, 22.84736061], [69.79458618, 22.84736061], [69.79458618, 22.84708023], [69.79430389, 22.84708595], [69.79430389, 22.84680557], [69.79402161, 22.84680939], [69.79402161, 22.84625053], [69.79374695, 22.84625053], [69.79374695, 22.84597015], [69.79347229, 22.84597206], [69.79347229, 22.84569168], [69.79319763, 22.84569168], [69.79319763, 22.84541702], [69.7923584, 22.84542084], [69.7923584, 22.84514046], [69.79207611, 22.84514046], [69.79207611, 22.84486008], [69.79152679, 22.84486389], [69.79152679, 22.84430504], [69.79125214, 22.84431076], [69.79125214, 22.84403038], [69.79070282, 22.84403038], [69.79070282, 22.84375191], [69.7904129, 22.84375191], [69.7904129, 22.84346962], [69.78930664, 22.84347343], [69.78930664, 22.84319496], [69.78848267, 22.84320068], [69.78848267, 22.8429203], [69.78819275, 22.8429203], [69.78819275, 22.84264183], [69.7876358, 22.84264183], [69.7876358, 22.8423481], [69.78736115, 22.84235954], [69.78736115, 22.84208107], [69.7868042, 22.84208107], [69.7868042, 22.84180641], [69.78652954, 22.84181023], [69.78652954, 22.84153175], [69.7859726, 22.84153175], [69.7859726, 22.84124947], [69.78569794, 22.84124947], [69.78569794, 22.84096909], [69.78514099, 22.8409729], [69.78514099, 22.84069443], [69.7848587, 22.84069443], [69.7848587, 22.84041595], [69.78430176, 22.84042168], [69.78430176, 22.8401413], [69.7840271, 22.8401413], [69.7840271, 22.83986092], [69.78347015, 22.83986092], [69.78347015, 22.83958054], [69.7831955, 22.83958244], [69.7831955, 22.83930588], [69.78263855, 22.83930969], [69.78263855, 22.83903122], [69.7820816, 22.83903122], [69.7820816, 22.83875084], [69.78180695, 22.83875084], [69.78180695, 22.83847046], [69.78125, 22.83847237], [69.78125, 22.83819389], [69.78069305, 22.83819389], [69.78069305, 22.83791733], [69.7804184, 22.83792114], [69.7804184, 22.83764076], [69.77986145, 22.83764076], [69.77986145, 22.83736038], [69.77929688, 22.83736038], [69.77929688, 22.83708], [69.77902985, 22.83708382], [69.77902985, 22.83680534], [69.7784729, 22.83681107], [69.7784729, 22.83653831], [69.77791595, 22.83653831], [69.77791595, 22.83625031], [69.7776413, 22.83625031], [69.7776413, 22.83596992], [69.77708435, 22.83597183], [69.77708435, 22.83569527], [69.7765274, 22.83570099], [69.7765274, 22.83542061], [69.77625275, 22.83542061], [69.77625275, 22.83514023], [69.7756958, 22.83514023], [69.7756958, 22.83485985], [69.77513885, 22.83486176], [69.77513885, 22.83458328], [69.7748642, 22.83458328], [69.7748642, 22.83430672], [69.77430725, 22.83430672], [69.77430725, 22.83402824], [69.77403259, 22.83403015], [69.77403259, 22.83374977], [69.77347565, 22.83374977], [69.77347565, 22.8334713], [69.77319336, 22.83348083], [69.77319336, 22.83292007], [69.77291107, 22.83292007], [69.77291107, 22.83236122], [69.77263641, 22.83236122], [69.77263641, 22.83152962], [69.77291107, 22.83152962], [69.77291107, 22.83125114], [69.77375031, 22.83125114], [69.77375031, 22.83152962], [69.77403259, 22.83152962], [69.77403259, 22.83181], [69.77458191, 22.83180618], [69.77458191, 22.83208466], [69.77540588, 22.83208084], [69.77540588, 22.83236122], [69.77625275, 22.83236122], [69.77625275, 22.83208084], [69.77597046, 22.83208466], [69.77597046, 22.83180618], [69.7756958, 22.83181], [69.7756958, 22.83152962], [69.77513885, 22.83152962], [69.77513885, 22.83125114], [69.77485657, 22.83125114], [69.77485657, 22.83097267], [69.77458191, 22.83097267], [69.77458191, 22.8306942], [69.77375031, 22.8306942], [69.77375031, 22.83041763], [69.77263641, 22.83041573], [69.77263641, 22.82986259], [69.77236176, 22.82986259], [69.77236176, 22.82958031], [69.77180481, 22.82958412], [69.77180481, 22.82930565], [69.77153015, 22.82930946], [69.77153015, 22.82875252], [69.77097321, 22.82875252], [69.77097321, 22.82847023], [69.77041626, 22.82847023], [69.77041626, 22.82819366], [69.76985931, 22.82819366], [69.76985931, 22.8279171], [69.76819611, 22.82792091], [69.76819611, 22.82763863], [69.76763916, 22.82763863], [69.76763916, 22.82735062], [69.7673645, 22.82736015], [69.7673645, 22.82708359], [69.76708221, 22.82708359], [69.76708221, 22.82653046], [69.76680756, 22.82653046], [69.76680756, 22.82624817], [69.76625061, 22.82624817], [69.76625061, 22.8259697], [69.76569366, 22.8259716], [69.76569366, 22.82569504], [69.76486206, 22.82570076], [69.76486206, 22.82542038], [69.76403809, 22.82542038], [69.76403809, 22.82513809], [69.76235962, 22.82513809], [69.76235962, 22.82485962], [69.76152802, 22.82486153], [69.76152802, 22.82458305], [69.76069641, 22.82458305], [69.76069641, 22.82430649], [69.75985718, 22.8243103], [69.75985718, 22.82402992], [69.7590332, 22.82402992], [69.7590332, 22.82374954], [69.75846863, 22.82374954], [69.75846863, 22.82347107], [69.75819397, 22.82347298], [69.75819397, 22.8231945], [69.75791931, 22.8231945], [69.75791931, 22.82291794], [69.75763702, 22.82291985], [69.75763702, 22.82263947], [69.75708008, 22.82263947], [69.75708008, 22.82236099], [69.75653076, 22.82236099], [69.75653076, 22.82208061], [69.75624847, 22.82208252], [69.75624847, 22.82180405], [69.75596619, 22.82180977], [69.75596619, 22.82154083], [69.75541687, 22.82154083], [69.75541687, 22.82125092], [69.75514221, 22.82125092], [69.75514221, 22.82097054], [69.75458527, 22.82097244], [69.75458527, 22.82069588], [69.75402832, 22.82069588], [69.75402832, 22.8204174], [69.75347137, 22.82042122], [69.75347137, 22.82014084], [69.75319672, 22.82014084], [69.75319672, 22.81986046], [69.75263977, 22.81986046], [69.75263977, 22.81958008], [69.75235748, 22.8195858], [69.75235748, 22.81902695], [69.75208282, 22.81903076], [69.75208282, 22.81847], [69.75180817, 22.81847382], [69.75180817, 22.81819534], [69.75152588, 22.81820107], [69.75152588, 22.8176403], [69.75125122, 22.8176403], [69.75125122, 22.81707954], [69.75096893, 22.81708336], [69.75096893, 22.81680489], [69.75069427, 22.81680489], [69.75069427, 22.81625175], [69.75041962, 22.81625175], [69.75041962, 22.81568909], [69.75013733, 22.81569481], [69.75013733, 22.81541634], [69.74986267, 22.81541634], [69.74986267, 22.81485939], [69.74958038, 22.81485939], [69.74958038, 22.81430626], [69.74931335, 22.81431007], [69.74931335, 22.81347084], [69.74903107, 22.81347275], [69.74903107, 22.8129158], [69.74874115, 22.81291962], [69.74874115, 22.81236839], [69.74846649, 22.81236839], [69.74846649, 22.81180954], [69.74819183, 22.81180954], [69.74819183, 22.81153107], [69.74791718, 22.81153107], [69.74791718, 22.81042099], [69.74764252, 22.81042099], [69.74764252, 22.80903053], [69.74736023, 22.80903053], [69.74736023, 22.80846977], [69.74708557, 22.80847168], [69.74708557, 22.80791664], [69.74680328, 22.80792046], [69.74680328, 22.8073597], [69.74652863, 22.8073616], [69.74652863, 22.80680466], [69.74624634, 22.80680466], [69.74624634, 22.80624962], [69.74597168, 22.80624962], [69.74597168, 22.80569458], [69.74569702, 22.80569458], [69.74569702, 22.80513954], [69.7454071, 22.80513954], [69.7454071, 22.80458069], [69.74514008, 22.8045845], [69.74514008, 22.80402756], [69.74485779, 22.80402946], [69.74485779, 22.80347252], [69.74458313, 22.80347252], [69.74458313, 22.80208397], [69.74485779, 22.80208397], [69.74485779, 22.8018055], [69.74514008, 22.80181122], [69.74514008, 22.80069923], [69.74485779, 22.8006897], [69.74485779, 22.80013847], [69.74514008, 22.80013847], [69.74514008, 22.79931068], [69.7454071, 22.79931068], [69.7454071, 22.79874992], [69.74569702, 22.79874992], [69.74569702, 22.79819107], [69.74597168, 22.79819489], [69.74597168, 22.79791641], [69.74624634, 22.79792023], [69.74624634, 22.79652977], [69.74652863, 22.79652977], [69.74652863, 22.79624939], [69.74680328, 22.79624939], [69.74680328, 22.79597092], [69.74652863, 22.79597282], [69.74652863, 22.79458427], [69.74680328, 22.79458237], [69.74680328, 22.79375076], [69.74624634, 22.79375076], [69.74624634, 22.79347038], [69.74597168, 22.79347229], [69.74597168, 22.79319572], [69.74569702, 22.79319572], [69.74569702, 22.79291725], [69.74514008, 22.79292107], [69.74514008, 22.79264069], [69.74485779, 22.79264069], [69.74485779, 22.79236031], [69.74458313, 22.79236031], [69.74458313, 22.79264069], [69.74430847, 22.79264069], [69.74430847, 22.79236031], [69.74402618, 22.79236031], [69.74402618, 22.7912426], [69.74375153, 22.79125023], [69.74375153, 22.79063034], [69.74375153, 22.79041672], [69.74346924, 22.79042053], [69.74346924, 22.78903008], [69.74318695, 22.78903008], [69.74318695, 22.7881794], [69.74291992, 22.78819466], [69.74291992, 22.78791618], [69.74263763, 22.78792191], [69.74263763, 22.78735924], [69.74236298, 22.78735924], [69.74236298, 22.78708076], [69.74208069, 22.78708267], [69.74208069, 22.78652763], [69.74180603, 22.78652763], [69.74180603, 22.78513908], [69.74153137, 22.78513908], [69.74153137, 22.78486061], [69.74069214, 22.78486061], [69.74069214, 22.78458023], [69.74041748, 22.78458405], [69.74041748, 22.78430557], [69.74014282, 22.78430939], [69.74014282, 22.78375053], [69.73986053, 22.78375053], [69.73986053, 22.78347206], [69.73958588, 22.78347206], [69.73958588, 22.78319359], [69.73930359, 22.78319359], [69.73930359, 22.78291512], [69.73902893, 22.78292084], [69.73902893, 22.78264046], [69.73874664, 22.78264046], [69.73874664, 22.78236008], [69.73847198, 22.78236198], [69.73847198, 22.78208351], [69.73819733, 22.78208351], [69.73819733, 22.78152847], [69.73792267, 22.78153038], [69.73792267, 22.78125], [69.73764038, 22.78125], [69.73764038, 22.78096962], [69.73735809, 22.78097153], [69.73735809, 22.78069305], [69.73569489, 22.78069305], [69.73569489, 22.78097153], [69.73542023, 22.78096962], [69.73542023, 22.78125], [69.73430634, 22.78125], [69.73430634, 22.78096962], [69.73402405, 22.78097153], [69.73402405, 22.77902794], [69.73374176, 22.77902985], [69.73374176, 22.77874947], [69.73361206, 22.77874947], [69.7334671, 22.77874947], [69.7334671, 22.77819061], [69.73319244, 22.77819443], [69.73319244, 22.77791595], [69.73291779, 22.77791977], [69.73291779, 22.77708054], [69.7326355, 22.77708054], [69.7326355, 22.77680588], [69.73236084, 22.77680969], [69.73236084, 22.77581978], [69.73236084, 22.77486229], [69.73208618, 22.77486229], [69.73208618, 22.77430916], [69.73179626, 22.77430916], [69.73179626, 22.7737484], [69.73152924, 22.7737484], [69.73152924, 22.77319908], [69.73124695, 22.77319908], [69.73124695, 22.77263832], [69.73097229, 22.77263832], [69.73097229, 22.77235985], [69.73041534, 22.77236176], [69.73041534, 22.77208328], [69.73014069, 22.77208328], [69.73014069, 22.77180481], [69.7298584, 22.77180481], [69.7298584, 22.77124977], [69.72957611, 22.77124977], [69.72957611, 22.77096939], [69.72902679, 22.7709713], [69.72902679, 22.77069473], [69.72875214, 22.77069473], [69.72875214, 22.77013969], [69.72846985, 22.77013969], [69.72846985, 22.76986122], [69.72819519, 22.76986122], [69.72819519, 22.76958275], [69.7279129, 22.76958275], [69.7279129, 22.76930618], [69.72763824, 22.76931], [69.72763824, 22.76875114], [69.72735596, 22.76875114], [69.72735596, 22.76847076], [69.7270813, 22.76847267], [69.7270813, 22.7681942], [69.72680664, 22.7681942], [69.72680664, 22.76736069], [69.72651672, 22.76736069], [69.72651672, 22.76707077], [69.72624969, 22.76708412], [69.72624969, 22.76652718], [69.72598267, 22.76653099], [69.72598267, 22.76625061], [69.72569275, 22.76625061], [69.72569275, 22.76597023], [69.72486115, 22.76597214], [69.72486115, 22.76569366], [69.72458649, 22.76569366], [69.72458649, 22.76513863], [69.72429657, 22.76514053], [69.72429657, 22.76403046], [69.72402954, 22.76403046], [69.72402954, 22.76375008], [69.7234726, 22.76375008], [69.7234726, 22.7634697], [69.72319794, 22.76347351], [69.72319794, 22.76291656], [69.72292328, 22.76292038], [69.72292328, 22.76264191], [69.72207642, 22.76264191], [69.72207642, 22.76292038], [69.72070313, 22.76292038], [69.72070313, 22.76264191], [69.72041321, 22.76264191], [69.72041321, 22.76235962], [69.72013855, 22.76235962], [69.72013855, 22.76014137], [69.71985626, 22.76014137], [69.71985626, 22.75930977], [69.7195816, 22.75930977], [69.7195816, 22.75875092], [69.71930695, 22.75875092], [69.71930695, 22.75819969], [69.71901703, 22.75819969], [69.71901703, 22.75792122], [69.71875763, 22.75792122], [69.71875763, 22.75708008], [69.71847534, 22.75708389], [69.71847534, 22.75652695], [69.71819305, 22.75653076], [69.71819305, 22.75625038], [69.7179184, 22.75625038], [69.7179184, 22.75597], [69.71763611, 22.75597191], [69.71763611, 22.75541687], [69.71736145, 22.75542068], [69.71736145, 22.75457954], [69.71708679, 22.75458336], [69.71708679, 22.75430679], [69.7168045, 22.75430679], [69.7168045, 22.75402832], [69.71652985, 22.75403023], [69.71652985, 22.75346947], [69.71624756, 22.75347137], [69.71624756, 22.75319481], [69.7159729, 22.75319481], [69.7159729, 22.75291634], [69.71569824, 22.75292015], [69.71569824, 22.75235939], [69.71541595, 22.7523613], [69.71541595, 22.75180626], [69.7151413, 22.75181007], [69.7151413, 22.75152969], [69.7140274, 22.75152969], [69.7140274, 22.75097275], [69.71430206, 22.75097275], [69.71430206, 22.75069427], [69.71485901, 22.75069427], [69.71485901, 22.7504158], [69.7151413, 22.75041962], [69.7151413, 22.75014114], [69.71541595, 22.75014114], [69.71541595, 22.74958038], [69.71569061, 22.7495842], [69.71569061, 22.74819374], [69.71541595, 22.74819374], [69.71541595, 22.74569511], [69.7151413, 22.74570084], [69.7151413, 22.7448597], [69.71541595, 22.7448616], [69.71541595, 22.74458313], [69.71569061, 22.74458313], [69.71569824, 22.74374962], [69.7159729, 22.74374962], [69.7159729, 22.74180984], [69.71624756, 22.74180984], [69.71624756, 22.74125099], [69.71569824, 22.74125099], [69.71569824, 22.74097061], [69.71457672, 22.74097061], [69.71457672, 22.74125099], [69.71347046, 22.74125099], [69.71347046, 22.74097061], [69.7131958, 22.74097252], [69.7131958, 22.74069595], [69.71347046, 22.74069595], [69.71347046, 22.74013901], [69.71375275, 22.74013901], [69.71375275, 22.7393055], [69.7131958, 22.73931122], [69.7131958, 22.73903084], [69.71208191, 22.73903084], [69.71208191, 22.73875046], [69.71152496, 22.73875046], [69.71152496, 22.73847389], [69.71125031, 22.73847389], [69.71125031, 22.73819542], [69.70930481, 22.73819542], [69.70930481, 22.73847389], [69.70874786, 22.73847008], [69.70874786, 22.73875046], [69.70847321, 22.73875046], [69.70847321, 22.73820114], [69.70819092, 22.7381897], [69.70819092, 22.73791695], [69.70791626, 22.73792076], [69.70791626, 22.73736191], [69.7076416, 22.73736382], [69.7076416, 22.73596954], [69.70735931, 22.73596954], [69.70735931, 22.73514175], [69.70707703, 22.73514175], [69.70707703, 22.73485947], [69.70680237, 22.73485947], [69.70680237, 22.73374939], [69.70652771, 22.73374939], [69.70652771, 22.73236084], [69.70680237, 22.73236084], [69.70683289, 22.73069], [69.70708466, 22.73069382], [69.70708466, 22.73041725], [69.70745087, 22.73041725], [69.70819092, 22.73041725], [69.70819092, 22.73069382], [69.70874786, 22.73069382], [69.70874786, 22.73097229], [69.70930481, 22.73097229], [69.70930481, 22.73069382], [69.71013641, 22.73069382], [69.71013641, 22.72986031], [69.7095871, 22.72986031], [69.7095871, 22.72957993], [69.7092514, 22.72958183], [69.70847321, 22.72958374], [69.70847321, 22.72930527], [69.70707703, 22.72931099], [69.70707703, 22.72903061], [69.70597076, 22.72903061], [69.70597076, 22.72875023], [69.70569611, 22.72875023], [69.70569611, 22.72846985], [69.70541382, 22.72847176], [69.70541382, 22.72819519], [69.70513916, 22.72819519], [69.70513916, 22.72791672], [69.70347595, 22.72791672], [69.70347595, 22.72819519], [69.70319366, 22.72819519], [69.70319366, 22.72847176], [69.70291901, 22.72846985], [69.70291901, 22.72903061], [69.70318604, 22.72903061], [69.70318604, 22.72931099], [69.70347595, 22.72930527], [69.70347595, 22.72958374], [69.70485687, 22.72957993], [69.70485687, 22.72986031], [69.70513916, 22.72986031], [69.70513916, 22.73014069], [69.70540619, 22.73014069], [69.70540619, 22.73042107], [69.70569611, 22.73041725], [69.70569611, 22.73124123], [69.70569611, 22.73347282], [69.70597076, 22.73347282], [69.70597076, 22.7345829], [69.70625305, 22.7345829], [69.70625305, 22.73569489], [69.70652771, 22.73568916], [69.70652771, 22.73986053], [69.70625305, 22.73986053], [69.70625305, 22.74013901], [69.70597076, 22.74012947], [69.70597076, 22.74041939], [69.70541382, 22.74041748], [69.70541382, 22.74069595], [69.70375061, 22.74069595], [69.70375061, 22.74097252], [69.70291901, 22.74097252], [69.70291901, 22.74069595], [69.70180511, 22.74069595], [69.70180511, 22.74097252], [69.70041656, 22.74097061], [69.70041656, 22.74125099], [69.69819641, 22.74125099], [69.69819641, 22.74152946], [69.69763184, 22.74152946], [69.69763184, 22.74180984], [69.69708252, 22.74180412], [69.69708252, 22.7420826], [69.69680786, 22.74208069], [69.69680786, 22.74236107], [69.69457245, 22.74236107], [69.69457245, 22.74263954], [69.69374847, 22.74263954], [69.69374847, 22.74291992], [69.69291687, 22.74291611], [69.69291687, 22.74319458], [69.69264221, 22.74319458], [69.69264221, 22.74347305], [69.69208527, 22.74347305], [69.6920929, 22.74374962], [69.69180298, 22.74374962], [69.69180298, 22.74402809], [69.69097137, 22.74402618], [69.69097137, 22.74430466], [69.69041443, 22.74430466], [69.69041443, 22.74458313], [69.68985748, 22.74458313], [69.68985748, 22.7448616], [69.68958282, 22.7448597], [69.68958282, 22.74513817], [69.68930817, 22.74513817], [69.68930817, 22.74542046], [69.68875885, 22.74542046], [69.68875885, 22.74570084], [69.68846893, 22.74569511], [69.68846893, 22.74597168], [69.68818665, 22.74596977], [69.68818665, 22.7462616], [69.68736267, 22.7462616], [69.68736267, 22.74653053], [69.68681335, 22.74653053], [69.68681335, 22.74681091], [69.68653107, 22.74680519], [69.68653107, 22.74708366], [69.68624878, 22.74707985], [69.68624878, 22.74764061], [69.68597412, 22.74764061], [69.68597412, 22.74819374], [69.68486023, 22.74819374], [69.68486023, 22.74847031], [69.68458557, 22.74847031], [69.6845932, 22.74875259], [69.68430328, 22.74875259], [69.68430328, 22.74903107], [69.68402863, 22.74903107], [69.68402863, 22.74932289], [69.68374634, 22.74930573], [69.68374634, 22.7495842], [69.68347168, 22.74958038], [69.68347168, 22.74986267], [69.68319702, 22.74986267], [69.68319702, 22.75014114], [69.6829071, 22.75014114], [69.6829071, 22.75041962], [69.68235779, 22.7504158], [69.68235779, 22.75069427], [69.68208313, 22.75069427], [69.68208313, 22.75097275], [69.68152618, 22.75097275], [69.68152618, 22.75125122], [69.68125153, 22.75125122], [69.68125153, 22.75152969], [69.68096924, 22.75152969], [69.68096924, 22.75181007], [69.68068695, 22.75181007], [69.68068695, 22.75152969], [69.68041992, 22.75152969], [69.68041992, 22.75125122], [69.67958832, 22.75125122], [69.67958832, 22.75152969], [69.67930603, 22.75152969], [69.67930603, 22.75181007], [69.67903137, 22.75180626], [69.67903137, 22.75208473], [69.67874908, 22.75206947], [69.67874908, 22.75263977], [69.6784668, 22.75263977], [69.6784668, 22.75374985], [69.67819214, 22.75374985], [69.67819214, 22.75403023], [69.67791748, 22.75402832], [69.67791748, 22.75430679], [69.67763519, 22.75430679], [69.67763519, 22.75458336], [69.67736053, 22.75458336], [69.67736053, 22.75486183], [69.67708588, 22.75486183], [69.67708588, 22.7551384], [69.67624664, 22.75513077], [69.67624664, 22.75542068], [69.67514038, 22.75542068], [69.67514038, 22.75570107], [69.67485809, 22.75569534], [69.67485809, 22.75597191], [69.67402649, 22.75597], [69.67402649, 22.75625038], [69.67346954, 22.75625038], [69.67346954, 22.75708389], [69.67152405, 22.75708389], [69.67152405, 22.75680542], [69.66986084, 22.75680542], [69.66986084, 22.75708389], [69.66902924, 22.75708389], [69.66902924, 22.75680542], [69.66847229, 22.75681114], [69.66847229, 22.75653076], [69.66792297, 22.75653076], [69.66792297, 22.75625038], [69.66764069, 22.75625038], [69.66764069, 22.75597191], [69.66596985, 22.75597], [69.66596985, 22.75625038], [69.66513824, 22.75625038], [69.66513824, 22.75597], [69.66374969, 22.75597], [69.66374969, 22.75625038], [69.66319275, 22.75625038], [69.66319275, 22.75653076], [69.6626358, 22.75653076], [69.6626358, 22.75681114], [69.66236115, 22.75680542], [69.66236115, 22.75958252], [69.6626358, 22.75958061], [69.6626358, 22.76042175], [69.66291809, 22.76041603], [69.66291809, 22.76097107], [69.66319275, 22.76096916], [69.66319275, 22.76126289], [69.66347504, 22.76125145], [69.66348267, 22.76180077], [69.66374969, 22.76180649], [69.66374969, 22.76208115], [69.66401672, 22.76207924], [69.66401672, 22.76264191], [69.66430664, 22.76264191], [69.66430664, 22.76320076], [69.66458893, 22.76320076], [69.66458893, 22.76403046], [69.66486359, 22.76402855], [69.66486359, 22.76458359], [69.66513824, 22.76458359], [69.66513824, 22.76597214], [69.6654129, 22.76597023], [69.6654129, 22.76653099], [69.66569519, 22.76652718], [69.66569519, 22.7709713], [69.66596985, 22.7709713], [69.66596985, 22.77236176], [69.66569519, 22.77236176], [69.66569519, 22.77347183], [69.66596985, 22.77346992], [69.66596985, 22.77403069], [69.66625214, 22.77403069], [69.66625214, 22.77486229], [69.66652679, 22.77486229], [69.66652679, 22.77569389], [69.66680908, 22.77569389], [69.66680908, 22.77597046], [69.66708374, 22.77597046], [69.66708374, 22.77625275], [69.6673584, 22.7762394], [69.6673584, 22.77653122], [69.66708374, 22.7765274], [69.66708374, 22.77708054], [69.66680908, 22.77708054], [69.66680908, 22.77736282], [69.66625214, 22.77736282], [69.66625214, 22.77708054], [69.66569519, 22.77708054], [69.66569519, 22.77680588], [69.6654129, 22.77680969], [69.6654129, 22.77653122], [69.66513824, 22.77653122], [69.66513824, 22.7762394], [69.6645813, 22.77625275], [69.6645813, 22.77597046], [69.66430664, 22.77597046], [69.66430664, 22.77402687], [69.66401672, 22.77403069], [69.66401672, 22.77069092], [69.66430664, 22.77069473], [69.66430664, 22.76874924], [69.66401672, 22.76875114], [69.66401672, 22.76653099], [69.66374969, 22.76653099], [69.66374969, 22.76568985], [69.66347504, 22.76569366], [69.66347504, 22.76486206], [69.66319275, 22.76486206], [69.66319275, 22.76402855], [69.66291809, 22.76403046], [69.66291809, 22.7634697], [69.6626358, 22.76347351], [69.6626358, 22.76291656], [69.66236115, 22.76292038], [69.66236115, 22.76235962], [69.66208649, 22.76235962], [69.66208649, 22.76180649], [69.66179657, 22.7618103], [69.66179657, 22.76153183], [69.66152191, 22.76153183], [69.66152191, 22.76096916], [69.66124725, 22.76097107], [69.66124725, 22.76041603], [69.6609726, 22.76042175], [69.6609726, 22.75985909], [69.66069794, 22.75985909], [69.66069794, 22.75847054], [69.66014099, 22.75847244], [69.66014099, 22.75819397], [69.6598587, 22.75819969], [69.6598587, 22.75792122], [69.65957642, 22.75792122], [69.65957642, 22.75708008], [69.65930176, 22.75708389], [69.65930176, 22.75652695], [69.65875244, 22.75653076], [69.65875244, 22.75681114], [69.65791321, 22.75680542], [69.65791321, 22.75708389], [69.65735626, 22.75708008], [69.65735626, 22.75736046], [69.65651703, 22.75736046], [69.65651703, 22.75764084], [69.65598297, 22.75764084], [69.65598297, 22.75792122], [69.6554184, 22.75792122], [69.6554184, 22.75819969], [69.65513611, 22.75819397], [69.65513611, 22.75847244], [69.65486145, 22.75847054], [69.65486145, 22.75902748], [69.65458679, 22.75902748], [69.65458679, 22.75930977], [69.65402985, 22.75930595], [69.65402985, 22.75958252], [69.6534729, 22.75958061], [69.6534729, 22.75985909], [69.65319824, 22.75985909], [69.65319824, 22.76014137], [69.65291595, 22.76014137], [69.65291595, 22.76042175], [69.6526413, 22.76041603], [69.6526413, 22.7606945], [69.65235901, 22.7606945], [69.65235901, 22.76097107], [69.65207672, 22.76096916], [69.65207672, 22.76126289], [69.65180206, 22.76126289], [69.65180206, 22.76153183], [69.6515274, 22.76153183], [69.6515274, 22.7618103], [69.65125275, 22.76180649], [69.65125275, 22.76208115], [69.65097046, 22.76208115], [69.65097046, 22.76235962], [69.64985657, 22.76235962], [69.64985657, 22.76264191], [69.64930725, 22.76264191], [69.64930725, 22.76292038], [69.64848328, 22.76292038], [69.64848328, 22.76320076], [69.6479187, 22.76319504], [69.6479187, 22.76347351], [69.6470871, 22.7634697], [69.6470871, 22.76403046], [69.64680481, 22.76402855], [69.64680481, 22.76458359], [69.64652252, 22.76457977], [69.64652252, 22.76542091], [69.64597321, 22.7654171], [69.64597321, 22.76597214], [69.64485931, 22.76597214], [69.64485931, 22.76569366], [69.64319611, 22.76569366], [69.64319611, 22.76597214], [69.64290619, 22.76597023], [69.64290619, 22.76625061], [69.64263916, 22.76625061], [69.64263916, 22.76653099], [69.64290619, 22.76653099], [69.64290619, 22.76680946], [69.64263916, 22.76680946], [69.64263916, 22.76736069], [69.64235687, 22.76736069], [69.64235687, 22.76791954], [69.64208221, 22.76791763], [69.64208221, 22.76847267], [69.64180756, 22.76847076], [69.64180756, 22.76902962], [69.64152527, 22.76902771], [69.64152527, 22.76958275], [69.64125061, 22.76958084], [69.64125061, 22.76986122], [69.64097595, 22.76986122], [69.64097595, 22.77041817], [69.64069366, 22.77041626], [69.64069366, 22.77069473], [69.64041901, 22.77069092], [69.64041901, 22.77124977], [69.64013672, 22.77124977], [69.64013672, 22.77152824], [69.63986206, 22.77152634], [69.63986206, 22.77208328], [69.63957977, 22.77207947], [69.63957977, 22.77263832], [69.63931274, 22.77263832], [69.63931274, 22.77319908], [69.63903046, 22.77319908], [69.63903046, 22.7737484], [69.63874817, 22.7737484], [69.63874817, 22.77569389], [69.63846588, 22.77569008], [69.63846588, 22.77680969], [69.63791656, 22.77680588], [69.63791656, 22.77958488], [69.63764191, 22.77958488], [69.63764191, 22.77986145], [69.63735199, 22.77985954], [69.63735199, 22.78013992], [69.63707733, 22.78013992], [69.63707733, 22.78181076], [69.63735962, 22.78180695], [69.63735962, 22.78319359], [69.63764191, 22.78318977], [69.63764191, 22.78403091], [69.63735962, 22.7840271], [69.63735962, 22.78458405], [69.63764191, 22.78458023], [69.63764191, 22.78681183], [69.63735199, 22.78681183], [69.63735199, 22.7887516], [69.63708496, 22.7887516], [69.63708496, 22.78986359], [69.63680267, 22.78986168], [69.63680267, 22.79042053], [69.63652802, 22.79042053], [69.63652802, 22.79070282], [69.63625336, 22.79069519], [69.63625336, 22.79097366], [69.63597107, 22.79096985], [69.63597107, 22.79181099], [69.63569641, 22.79181099], [69.63569641, 22.79236031], [69.63540649, 22.79236031], [69.63540649, 22.79292107], [69.63513947, 22.79291725], [69.63513947, 22.79319572], [69.63486481, 22.79319572], [69.63486481, 22.79347229], [69.63430786, 22.79347229], [69.63430786, 22.7943058], [69.63402557, 22.7943058], [69.63402557, 22.79458427], [69.63375092, 22.79458046], [69.63375092, 22.79541969], [69.63318634, 22.79541969], [69.63318634, 22.79430008], [69.63346863, 22.7943058], [69.63346863, 22.79402733], [69.63375092, 22.79403114], [69.63375092, 22.79347038], [69.63402557, 22.79347229], [69.63402557, 22.79319572], [69.63430786, 22.79319572], [69.63430786, 22.79236031], [69.63458252, 22.79236031], [69.63458252, 22.79181099], [69.63485718, 22.79181099], [69.63485718, 22.7912426], [69.63513947, 22.79125023], [69.63513947, 22.79097366], [69.63541412, 22.79097366], [69.63541412, 22.79041672], [69.63597107, 22.79042053], [69.63597107, 22.78986168], [69.63625336, 22.78986359], [69.63625336, 22.7887516], [69.63652802, 22.7887516], [69.63652802, 22.7881794], [69.63680267, 22.78819466], [69.63680267, 22.78458405], [69.63652802, 22.78458405], [69.63652802, 22.78430557], [69.63625336, 22.78430939], [69.63625336, 22.78403091], [69.63597107, 22.78403091], [69.63597107, 22.78292084], [69.63569641, 22.78292084], [69.63569641, 22.78236008], [69.63513947, 22.78236198], [69.63513947, 22.78208351], [69.63486481, 22.78208351], [69.63486481, 22.78152847], [69.63458252, 22.78153038], [69.63458252, 22.78070068], [69.63430786, 22.78070068], [69.63430786, 22.77902985], [69.63458252, 22.77902985], [69.63458252, 22.77736282], [69.63485718, 22.77736282], [69.63485718, 22.77653122], [69.63513947, 22.77653122], [69.63513947, 22.77597046], [69.63541412, 22.77597046], [69.63541412, 22.77569389], [69.63569641, 22.77569389], [69.63569641, 22.77541733], [69.63597107, 22.77542114], [69.63597107, 22.77486229], [69.63625336, 22.77486229], [69.63625336, 22.77403069], [69.63652802, 22.77403069], [69.63652802, 22.7737484], [69.63680267, 22.7737484], [69.63680267, 22.77346992], [69.63708496, 22.77347183], [69.63708496, 22.77319527], [69.63735199, 22.77319908], [69.63735199, 22.77263832], [69.63764191, 22.77263832], [69.63764191, 22.77235985], [69.63791656, 22.77236176], [69.63791656, 22.77208328], [69.63819122, 22.77208328], [69.63819122, 22.77180481], [69.63847351, 22.77180481], [69.63847351, 22.7709713], [69.63874817, 22.7709713], [69.63874817, 22.77069473], [69.63903046, 22.77069473], [69.63903046, 22.77041626], [69.63931274, 22.77041817], [69.63931274, 22.76986122], [69.63957977, 22.76986122], [69.63957977, 22.76958084], [69.63986206, 22.76958275], [69.63986206, 22.76902771], [69.64013672, 22.76902962], [69.64013672, 22.76875114], [69.64041901, 22.76875114], [69.64041901, 22.76819038], [69.64069366, 22.7681942], [69.64069366, 22.76791573], [69.64097595, 22.76791954], [69.64097595, 22.76764107], [69.64125061, 22.76764107], [69.64125061, 22.76653099], [69.64068604, 22.76653099], [69.64068604, 22.76625061], [69.63986206, 22.76625061], [69.63986206, 22.76597023], [69.63957977, 22.76597214], [69.63957977, 22.7654171], [69.63874817, 22.7654171], [69.63874817, 22.76569366], [69.63847351, 22.76569366], [69.63847351, 22.76597214], [69.63791656, 22.76597214], [69.63791656, 22.76569366], [69.63735962, 22.76569366], [69.63735962, 22.7654171], [69.63625336, 22.76542091], [69.63625336, 22.76514053], [69.63485718, 22.76514053], [69.63485718, 22.76486015], [69.63430786, 22.76486206], [69.63430786, 22.76458359], [69.63346863, 22.76458359], [69.63346863, 22.76430511], [69.63263702, 22.76430511], [69.63263702, 22.76402855], [69.63181305, 22.76403046], [69.63181305, 22.76375008], [69.63096619, 22.76375008], [69.63096619, 22.7634697], [69.62958527, 22.76347351], [69.6295929, 22.76375008], [69.62902832, 22.76375008], [69.62902832, 22.76403046], [69.62847137, 22.76402855], [69.62847137, 22.76430511], [69.62791443, 22.76430511], [69.62791443, 22.76458359], [69.62708282, 22.76458359], [69.62708282, 22.76486206], [69.62625122, 22.76486015], [69.62625122, 22.76514053], [69.62458038, 22.76514053], [69.62458038, 22.76486015], [69.6220932, 22.76486015], [69.6220932, 22.76514053], [69.62180328, 22.76513863], [69.62180328, 22.76597214], [69.6220932, 22.76597023], [69.6220932, 22.76680946], [69.62180328, 22.76680565], [69.62180328, 22.76708412], [69.62152863, 22.76707077], [69.62152863, 22.76736069], [69.61958313, 22.76736069], [69.61958313, 22.76764107], [69.61736298, 22.76764107], [69.61736298, 22.76736069], [69.61624908, 22.76736069], [69.61624908, 22.76707077], [69.61486053, 22.76708412], [69.61486053, 22.76680565], [69.61458588, 22.76680946], [69.61458588, 22.76653099], [69.61429596, 22.76653099], [69.61429596, 22.76625061], [69.61402893, 22.76625061], [69.61402893, 22.76597023], [69.61291504, 22.76597214], [69.61292267, 22.76625061], [69.61207581, 22.76625061], [69.61207581, 22.76653099], [69.61125183, 22.76653099], [69.61125183, 22.76680946], [69.61068726, 22.76680946], [69.61068726, 22.76653099], [69.6104126, 22.76653099], [69.6104126, 22.76680946], [69.61013794, 22.76680565], [69.61013794, 22.76708412], [69.60930634, 22.76708412], [69.60930634, 22.76680565], [69.60901642, 22.76680946], [69.60901642, 22.76568985], [69.60930634, 22.76569366], [69.60930634, 22.7654171], [69.60958099, 22.76542091], [69.60958099, 22.76514053], [69.60986328, 22.76514053], [69.60986328, 22.76429939], [69.61013794, 22.76430511], [69.61013794, 22.76347351], [69.60986328, 22.76347351], [69.60986328, 22.76319504], [69.60958099, 22.76320076], [69.60958099, 22.76292038], [69.60930634, 22.76292038], [69.60930634, 22.76264191], [69.60901642, 22.76264191], [69.60901642, 22.76235962], [69.60874939, 22.76235962], [69.60874939, 22.76180649], [69.6084671, 22.7618103], [69.6084671, 22.76153183], [69.60735321, 22.76153183], [69.60735321, 22.76126289], [69.60542297, 22.76126289], [69.60542297, 22.76096916], [69.6048584, 22.76097107], [69.6048584, 22.7606945], [69.60375214, 22.7606945], [69.60375214, 22.76041603], [69.6020813, 22.76042175], [69.6020813, 22.76014137], [69.60124969, 22.76014137], [69.60124969, 22.75958061], [69.60097504, 22.75958252], [69.60097504, 22.75902748], [69.60069275, 22.75902748], [69.60069275, 22.75930977], [69.5993042, 22.75930595], [69.5993042, 22.75958252], [69.5973587, 22.75958061], [69.5973587, 22.75985909], [69.59680939, 22.75985909], [69.59680176, 22.76014137], [69.59625244, 22.76014137], [69.59625244, 22.76042175], [69.59513855, 22.76041603], [69.59513855, 22.7606945], [69.59486389, 22.7606945], [69.59486389, 22.76097107], [69.5945816, 22.76096916], [69.5945816, 22.76126289], [69.59401703, 22.76126289], [69.59401703, 22.76153183], [69.59179688, 22.76153183], [69.59179688, 22.7618103], [69.59152985, 22.76180649], [69.59152985, 22.76208115], [69.5909729, 22.76208115], [69.5909729, 22.76180649], [69.58985901, 22.76180649], [69.58985901, 22.76208115], [69.58930969, 22.76207924], [69.58930969, 22.76292038], [69.58847046, 22.76292038], [69.58847046, 22.76264191], [69.58708191, 22.76264191], [69.58708191, 22.76292038], [69.58624268, 22.76292038], [69.58624268, 22.76320076], [69.58597565, 22.76319504], [69.58597565, 22.76347351], [69.58569336, 22.7634697], [69.58569336, 22.76375008], [69.58429718, 22.76375008], [69.58429718, 22.76403046], [69.58374786, 22.76402855], [69.58374786, 22.76430511], [69.58319092, 22.76430511], [69.58319092, 22.76458359], [69.58291626, 22.76458359], [69.58291626, 22.76430511], [69.58208466, 22.76430511], [69.58208466, 22.76458359], [69.58152771, 22.76457977], [69.58152771, 22.76542091], [69.58125305, 22.7654171], [69.58125305, 22.76569366], [69.58097076, 22.76569366], [69.58097076, 22.7654171], [69.58040619, 22.76542091], [69.58040619, 22.76514053], [69.58013916, 22.76514053], [69.58013916, 22.76486015], [69.57930756, 22.76486015], [69.57930756, 22.76514053], [69.57875061, 22.76514053], [69.57875061, 22.76542091], [69.57818604, 22.76542091], [69.57818604, 22.76625061], [69.57847595, 22.76625061], [69.57847595, 22.76680946], [69.57819366, 22.76680565], [69.57819366, 22.76708412], [69.57707977, 22.76707077], [69.57707977, 22.76736069], [69.57457733, 22.76736069], [69.57457733, 22.76791954], [69.57402802, 22.76791763], [69.57402802, 22.7681942], [69.57375336, 22.7681942], [69.57375336, 22.76847267], [69.5715332, 22.76847076], [69.5715332, 22.76875114], [69.57124329, 22.76875114], [69.57124329, 22.76902962], [69.5715332, 22.76902962], [69.5715332, 22.76931], [69.57125092, 22.76930618], [69.57125092, 22.76958275], [69.57041931, 22.76958084], [69.57041931, 22.76986122], [69.56958008, 22.76986122], [69.56958008, 22.77013969], [69.56874847, 22.77013969], [69.56874847, 22.77041817], [69.56819153, 22.77041626], [69.56819153, 22.7709713], [69.56791687, 22.77096939], [69.56791687, 22.77124977], [69.56764221, 22.77124977], [69.56764221, 22.77152824], [69.56708527, 22.77152634], [69.56708527, 22.77180481], [69.56625366, 22.77180481], [69.56625366, 22.77208328], [69.56569672, 22.77208328], [69.56569672, 22.77236176], [69.56513977, 22.77235985], [69.56513977, 22.77263832], [69.56485748, 22.77263832], [69.56485748, 22.77292061], [69.56458282, 22.77292061], [69.56458282, 22.77319908], [69.56430817, 22.77319527], [69.56430817, 22.77347183], [69.56375122, 22.77346992], [69.56375122, 22.7737484], [69.56318665, 22.7737484], [69.56318665, 22.77403069], [69.56291962, 22.77403069], [69.56291962, 22.77430916], [69.56263733, 22.77430534], [69.56263733, 22.77458382], [69.56236267, 22.77457809], [69.56236267, 22.77486229], [69.56207275, 22.77486229], [69.56207275, 22.77514267], [69.56181335, 22.77514267], [69.56181335, 22.77542114], [69.56124878, 22.77541733], [69.56124878, 22.77569389], [69.56096649, 22.77569008], [69.56096649, 22.77680969], [69.56069183, 22.77680588], [69.56069183, 22.77708054], [69.56041718, 22.77708054], [69.56041718, 22.77736282], [69.56014252, 22.77736282], [69.56014252, 22.77763939], [69.55986023, 22.77763939], [69.55986023, 22.77736282], [69.55958557, 22.77736282], [69.5595932, 22.77763939], [69.55930328, 22.77763939], [69.55930328, 22.77819443], [69.55874634, 22.77819443], [69.55874634, 22.77847481], [69.55847168, 22.7784729], [69.55847168, 22.77874947], [69.55819702, 22.77874947], [69.55819702, 22.77902985], [69.55791473, 22.77902794], [69.55791473, 22.77930641], [69.55764008, 22.77930641], [69.55764008, 22.77986145], [69.55735779, 22.77985954], [69.55735779, 22.78013992], [69.55708313, 22.78013992], [69.55708313, 22.7804203], [69.55680847, 22.7804203], [69.55680847, 22.78070068], [69.55652618, 22.78070068], [69.55652618, 22.78125], [69.55625916, 22.78125], [69.55625916, 22.78153038], [69.55596924, 22.78153038], [69.55596924, 22.78181076], [69.55569458, 22.78180695], [69.55569458, 22.78208351], [69.55541992, 22.7820797], [69.55541992, 22.78264046], [69.55513763, 22.78264046], [69.55513763, 22.78292084], [69.55486298, 22.78291512], [69.55486298, 22.78347206], [69.55458069, 22.78347015], [69.55458069, 22.78375053], [69.55430603, 22.78375053], [69.55430603, 22.78403091], [69.55403137, 22.7840271], [69.55403137, 22.78458405], [69.55374908, 22.78458023], [69.55374908, 22.78486061], [69.5534668, 22.78486061], [69.5534668, 22.78513908], [69.55319977, 22.78513908], [69.55319977, 22.78543091], [69.55291748, 22.78541756], [69.55291748, 22.78569412], [69.55264282, 22.78569031], [69.55264282, 22.78652763], [69.55236053, 22.78652763], [69.55236053, 22.78708267], [69.55208588, 22.78708267], [69.55208588, 22.78819466], [69.55263519, 22.78819466], [69.55263519, 22.78847313], [69.55319214, 22.78847313], [69.55319214, 22.7887516], [69.55374908, 22.7887516], [69.55374908, 22.78903008], [69.55430603, 22.78902817], [69.55430603, 22.78930473], [69.55441284, 22.78930473], [69.55541992, 22.78930473], [69.55541992, 22.78947067], [69.55541992, 22.78986359], [69.55568695, 22.78986168], [69.55568695, 22.79014015], [69.55596924, 22.79014015], [69.55596924, 22.79042053], [69.55625916, 22.79042053], [69.55625916, 22.79153061], [69.55596924, 22.79153061], [69.55596924, 22.79181099], [69.55569458, 22.79180527], [69.55569458, 22.79208374], [69.55513763, 22.79207993], [69.55513763, 22.79236031], [69.55458069, 22.79236031], [69.55458069, 22.79207993], [69.55403137, 22.79207993], [69.55403137, 22.79236031], [69.5534668, 22.79236031], [69.5534668, 22.79207993], [69.55291748, 22.79208374], [69.55291748, 22.7915287], [69.55264282, 22.79153061], [69.55264282, 22.7912426], [69.55208588, 22.79125023], [69.55208588, 22.79097366], [69.55180359, 22.79097366], [69.55180359, 22.79041672], [69.55152893, 22.79042053], [69.55152893, 22.78957939], [69.55097198, 22.7895813], [69.55097198, 22.78902817], [69.55069733, 22.78903008], [69.55069733, 22.78866959], [69.55069733, 22.78819466], [69.55041504, 22.78819466], [69.55041504, 22.78791618], [69.55013275, 22.78792191], [69.55013275, 22.78652763], [69.54985809, 22.78652763], [69.54985809, 22.78624916], [69.54902649, 22.78624916], [69.54902649, 22.78652763], [69.54763794, 22.78652763], [69.54763794, 22.78624916], [69.54736328, 22.78624916], [69.54736328, 22.78597069], [69.54624939, 22.78597069], [69.54624939, 22.78624916], [69.54514313, 22.78624916], [69.54514313, 22.78597069], [69.54458618, 22.7859726], [69.54458618, 22.78569412], [69.54347229, 22.78569412], [69.54347229, 22.7859726], [69.54264069, 22.78597069], [69.54264069, 22.78624916], [69.54207611, 22.78624916], [69.54207611, 22.78652763], [69.54070282, 22.78652763], [69.54070282, 22.78624916], [69.54013824, 22.78624916], [69.54013824, 22.78652763], [69.53985596, 22.78652763], [69.53985596, 22.78624916], [69.5395813, 22.78624916], [69.5395813, 22.78652763], [69.53624725, 22.78652763], [69.53624725, 22.78681183], [69.53569794, 22.78681183], [69.53569794, 22.78652763], [69.53542328, 22.78652763], [69.53542328, 22.78681183], [69.53375244, 22.78680611], [69.53375244, 22.78708267], [69.53291321, 22.78708076], [69.53291321, 22.78735924], [69.53180695, 22.78735924], [69.53180695, 22.78764153], [69.53152466, 22.78764153], [69.53152466, 22.78847313], [69.53125, 22.78846931], [69.53125, 22.7887516], [69.53013611, 22.7887516], [69.53013611, 22.7881794], [69.52986145, 22.78819466], [69.52986145, 22.78791618], [69.52874756, 22.78791618], [69.52874756, 22.78819466], [69.5284729, 22.78819466], [69.5284729, 22.78847313], [69.52791595, 22.78847313], [69.52791595, 22.78930473], [69.5276413, 22.78930473], [69.5276413, 22.7895813], [69.52708435, 22.7895813], [69.52708435, 22.78930473], [69.52680206, 22.78930473], [69.52680206, 22.7895813], [69.5265274, 22.7895813], [69.5265274, 22.78986359], [69.52485657, 22.78986168], [69.52485657, 22.79014015], [69.52348328, 22.79014015], [69.52348328, 22.79042053], [69.52124786, 22.79042053], [69.52124786, 22.79070282], [69.52041626, 22.79070282], [69.52041626, 22.79014015], [69.51790619, 22.79014015], [69.51790619, 22.79042053], [69.51680756, 22.79042053], [69.51680756, 22.79070282], [69.51597595, 22.79069519], [69.51597595, 22.79097366], [69.51541901, 22.79097366], [69.51541901, 22.79069519], [69.51513672, 22.79070282], [69.51513672, 22.79014015], [69.51486206, 22.79014015], [69.51486206, 22.78986168], [69.51403046, 22.78986359], [69.51403046, 22.7895813], [69.51374817, 22.7895813], [69.51374817, 22.78930473], [69.51319122, 22.78930473], [69.51319122, 22.78902817], [69.51291656, 22.78902817], [69.51291656, 22.78930473], [69.51235962, 22.78930473], [69.51235962, 22.78902817], [69.51152802, 22.78903008], [69.51152802, 22.7881794], [69.51097107, 22.78819466], [69.51097107, 22.78791618], [69.50930786, 22.78792191], [69.50930786, 22.78764153], [69.5041275, 22.78764153], [69.50096893, 22.78764153], [69.50096893, 22.78735924], [69.49736023, 22.78735924], [69.49736023, 22.78764153], [69.4970932, 22.78764153], [69.4970932, 22.78792191], [69.49595642, 22.78792191], [69.49595642, 22.78764153], [69.49569702, 22.78764153], [69.49569702, 22.78735924], [69.49485779, 22.78735924], [69.49485779, 22.78764153], [69.49458313, 22.78764153], [69.49458313, 22.78792191], [69.49291992, 22.78792191], [69.49291992, 22.78764153], [69.49236298, 22.78764153], [69.49236298, 22.78735924], [69.49180603, 22.78735924], [69.49180603, 22.78708076], [69.49124908, 22.78708267], [69.49124908, 22.78680611], [69.4909668, 22.78681183], [69.4909668, 22.78652763], [69.49069214, 22.78652763], [69.49069214, 22.78681183], [69.49013519, 22.78680611], [69.49014282, 22.78735924], [69.48986053, 22.78735924], [69.48986053, 22.78764153], [69.48819733, 22.78764153], [69.48819733, 22.78735924], [69.48596954, 22.78735924], [69.48596954, 22.78708076], [69.48542023, 22.78708076], [69.48542023, 22.78792191], [69.48458099, 22.78792191], [69.48458099, 22.78764153], [69.48430634, 22.78764153], [69.48430634, 22.78735924], [69.48401642, 22.78735924], [69.48401642, 22.78681183], [69.4834671, 22.78681183], [69.4834671, 22.78652763], [69.48319244, 22.78652763], [69.48319244, 22.78624916], [69.48291779, 22.78624916], [69.48291779, 22.78597069], [69.4826355, 22.7859726], [69.4826355, 22.78569412], [69.48402405, 22.78569412], [69.48402405, 22.7859726], [69.48458099, 22.78597069], [69.48458099, 22.78624916], [69.48542023, 22.78624916], [69.48542023, 22.78597069], [69.48625183, 22.78597069], [69.48625183, 22.78624916], [69.48707581, 22.78624916], [69.48707581, 22.78597069], [69.48735809, 22.7859726], [69.48735809, 22.78569412], [69.48764038, 22.78569412], [69.48764038, 22.78513718], [69.48792267, 22.78513908], [69.48792267, 22.78486061], [69.48819733, 22.78486061], [69.48819733, 22.78458023], [69.48874664, 22.78458405], [69.48874664, 22.78430557], [69.48902893, 22.78430939], [69.48902893, 22.78403091], [69.48986053, 22.78403091], [69.48986053, 22.78375053], [69.49041748, 22.78375053], [69.49041748, 22.78347015], [69.49263763, 22.78347206], [69.49263763, 22.78319359], [69.49319458, 22.78319359], [69.49319458, 22.78291512], [69.49346924, 22.78292084], [69.49346924, 22.78264046], [69.49375153, 22.78264046], [69.49375153, 22.7820797], [69.49402618, 22.78208351], [69.49402618, 22.78152847], [69.49375153, 22.78153038], [69.49375153, 22.78125], [69.49346924, 22.78125], [69.49346924, 22.78153038], [69.49291992, 22.78153038], [69.49291992, 22.78181076], [69.49263763, 22.78181076], [69.49263763, 22.78153038], [69.49180603, 22.78153038], [69.49180603, 22.78125], [69.49153137, 22.78125], [69.49153137, 22.78096962], [69.49069214, 22.78097153], [69.49069214, 22.78069305], [69.49014282, 22.78070068], [69.49014282, 22.7804203], [69.48958588, 22.7804203], [69.48958588, 22.78013992], [69.48792267, 22.78013992], [69.48792267, 22.77985954], [69.48764038, 22.77986145], [69.48764038, 22.77958488], [69.48735809, 22.77958488], [69.48735809, 22.77930641], [69.48652649, 22.77930641], [69.48652649, 22.77902794], [69.48596954, 22.77902985], [69.48596954, 22.77874947], [69.48568726, 22.77874947], [69.48568726, 22.77791977], [69.48486328, 22.77791977], [69.48486328, 22.77763939], [69.48374939, 22.77763939], [69.48374939, 22.77736282], [69.48179626, 22.77736282], [69.48179626, 22.77708054], [69.48152924, 22.77708054], [69.48152924, 22.77680588], [69.48097992, 22.77680969], [69.48097992, 22.77653122], [69.48069763, 22.77653122], [69.48069763, 22.7762394], [69.48041534, 22.77625275], [69.48041534, 22.77597046], [69.48014069, 22.77597046], [69.48014069, 22.77569389], [69.47958374, 22.77569389], [69.47958374, 22.77541733], [69.47930908, 22.77542114], [69.47930908, 22.77514267], [69.47846985, 22.77514267], [69.47846985, 22.77486229], [69.47735596, 22.77486229], [69.47735596, 22.77457809], [69.47458649, 22.77458382], [69.47458649, 22.77430534], [69.47402954, 22.77430916], [69.47402954, 22.77403069], [69.47374725, 22.77403069], [69.47374725, 22.77346992], [69.4723587, 22.77346992], [69.4723587, 22.7737484], [69.4715271, 22.7737484], [69.4715271, 22.77403069], [69.46985626, 22.77403069], [69.46985626, 22.7737484], [69.4695816, 22.7737484], [69.4695816, 22.77403069], [69.46930695, 22.77403069], [69.46930695, 22.77430916], [69.46875, 22.77430534], [69.46875, 22.77458382], [69.46847534, 22.77458382], [69.46848297, 22.77486229], [69.46819305, 22.77486229], [69.46819305, 22.77542114], [69.46763611, 22.77541733], [69.46763611, 22.77569389], [69.46708679, 22.77569389], [69.46708679, 22.77597046], [69.46569824, 22.77597046], [69.46569824, 22.77625275], [69.4651413, 22.7762394], [69.4651413, 22.77653122], [69.46457672, 22.77653122], [69.46457672, 22.77680969], [69.46430206, 22.77680969], [69.46430206, 22.77736282], [69.46347046, 22.77736282], [69.46347046, 22.77763939], [69.46290588, 22.77763939], [69.46290588, 22.77791977], [69.46208191, 22.77791595], [69.46208191, 22.77819443], [69.46152496, 22.77819443], [69.46152496, 22.77847481], [69.46125031, 22.7784729], [69.46125031, 22.77874947], [69.46069336, 22.77874947], [69.46069336, 22.77902985], [69.45986176, 22.77902794], [69.45986176, 22.77930641], [69.45735931, 22.77930641], [69.45735931, 22.77958488], [69.45569611, 22.77958488], [69.45569611, 22.77930641], [69.45513916, 22.77930641], [69.45513916, 22.77902794], [69.45430756, 22.77902794], [69.45430756, 22.77930641], [69.45263672, 22.77930641], [69.45263672, 22.77958488], [69.45097351, 22.77958488], [69.45097351, 22.77986145], [69.45014191, 22.77986145], [69.44930267, 22.77985954], [69.44930267, 22.78013992], [69.4465332, 22.78013992], [69.4465332, 22.7804203], [69.44625092, 22.7804203], [69.44625092, 22.78070068], [69.44596863, 22.78070068], [69.44596863, 22.78125], [69.44568634, 22.78125], [69.44568634, 22.78181076], [69.44541931, 22.78180695], [69.44541931, 22.78208351], [69.44513702, 22.78208351], [69.44513702, 22.78236198], [69.44487, 22.78236008], [69.44487, 22.78264046], [69.44458008, 22.78264046], [69.44458008, 22.78292084], [69.44430542, 22.78291512], [69.44430542, 22.78319359], [69.44374847, 22.78319359], [69.44374847, 22.78347206], [69.44319153, 22.78347015], [69.44319153, 22.78375053], [69.44291687, 22.78375053], [69.44291687, 22.78430939], [69.44208527, 22.78430557], [69.44208527, 22.78458405], [69.44180298, 22.78458405], [69.44181061, 22.78486061], [69.44152832, 22.78486061], [69.44152832, 22.78513908], [69.4404068, 22.78513908], [69.4404068, 22.78543091], [69.44013977, 22.78541756], [69.44013977, 22.78569412], [69.43958282, 22.78569412], [69.43958282, 22.7859726], [69.43930817, 22.78597069], [69.43930817, 22.78624916], [69.43873596, 22.78624916], [69.43873596, 22.78652763], [69.43846893, 22.78652763], [69.43846893, 22.78681183], [69.43819427, 22.78680611], [69.43819427, 22.78708267], [69.43763733, 22.78708076], [69.43763733, 22.78735924], [69.43736267, 22.78735924], [69.43736267, 22.78764153], [69.43681335, 22.78764153], [69.43681335, 22.78792191], [69.43653107, 22.78791618], [69.43653107, 22.78819466], [69.43569183, 22.78819466], [69.43569183, 22.78847313], [69.43514252, 22.78846931], [69.43514252, 22.7887516], [69.43430328, 22.7887516], [69.43430328, 22.78903008], [69.43347168, 22.78902817], [69.43347168, 22.78930473], [69.43291473, 22.78930473], [69.43291473, 22.7895813], [69.43208313, 22.7895813], [69.43208313, 22.78986359], [69.43152618, 22.78986168], [69.43152618, 22.79014015], [69.43096924, 22.79014015], [69.43096924, 22.79042053], [69.43068695, 22.79042053], [69.43068695, 22.79070282], [69.43013763, 22.79069519], [69.43013763, 22.79097366], [69.42958069, 22.79097366], [69.42958069, 22.79125023], [69.42930603, 22.7912426], [69.42930603, 22.79153061], [69.42903137, 22.79153061], [69.42903137, 22.79181099], [69.42874908, 22.79180527], [69.42874908, 22.79208374], [69.4284668, 22.79207993], [69.4284668, 22.79236031], [69.42819214, 22.79236031], [69.42819214, 22.79264069], [69.42791748, 22.79264069], [69.42791748, 22.79292107], [69.42763519, 22.79291725], [69.42763519, 22.79319572], [69.42736053, 22.79319572], [69.42736053, 22.79347229], [69.42708588, 22.79347038], [69.42708588, 22.79375076], [69.42679596, 22.79375076], [69.42679596, 22.79403114], [69.42652893, 22.79402733], [69.42652893, 22.7943058], [69.42624664, 22.7943058], [69.42624664, 22.79458427], [69.42597198, 22.79458046], [69.42597198, 22.79486084], [69.42569733, 22.79486084], [69.42569733, 22.79514122], [69.42542267, 22.79514122], [69.42542267, 22.79541969], [69.42485809, 22.79541588], [69.42485809, 22.79569435], [69.42458344, 22.79569435], [69.42458344, 22.79597282], [69.42402649, 22.79597092], [69.42402649, 22.79624939], [69.42373657, 22.79624939], [69.42373657, 22.79652977], [69.42318726, 22.79652977], [69.42318726, 22.79681015], [69.42292023, 22.79680634], [69.42292023, 22.7970829], [69.42236328, 22.79708099], [69.42236328, 22.79737091], [69.42208099, 22.79737091], [69.42208099, 22.79763985], [69.42151642, 22.79763985], [69.42151642, 22.79792023], [69.42124939, 22.79791641], [69.42124939, 22.79819489], [69.42069244, 22.79819489], [69.42069244, 22.79847145], [69.42041779, 22.79846954], [69.42041779, 22.79874992], [69.41986084, 22.79874992], [69.41986084, 22.7990284], [69.41958618, 22.7990284], [69.41958618, 22.79931068], [69.41874695, 22.79930496], [69.41874695, 22.79958344], [69.41819763, 22.79958344], [69.41819763, 22.79986191], [69.41764069, 22.79985809], [69.41764069, 22.80013847], [69.41596985, 22.80013847], [69.41596985, 22.8006897], [69.41569519, 22.80069542], [69.41569519, 22.80097008], [69.4154129, 22.80096817], [69.4154129, 22.80124855], [69.41513824, 22.80124855], [69.41513824, 22.80153275], [69.41485596, 22.80153275], [69.41485596, 22.80181122], [69.41430664, 22.8018055], [69.41430664, 22.80208397], [69.41374969, 22.80208015], [69.41374969, 22.80236244], [69.41291809, 22.80236244], [69.41291809, 22.80264282], [69.41208649, 22.80264282], [69.41208649, 22.80291939], [69.41152954, 22.80291748], [69.41152954, 22.80319214], [69.4109726, 22.80319214], [69.4109726, 22.80347252], [69.41069794, 22.80347252], [69.41069794, 22.8037529], [69.41042328, 22.8037529], [69.41042328, 22.80402946], [69.4098587, 22.80402946], [69.4098587, 22.80430984], [69.40958405, 22.80430603], [69.40958405, 22.8045845], [69.40930939, 22.80458069], [69.40930176, 22.80486107], [69.40847015, 22.80486107], [69.40847015, 22.80513954], [69.40791321, 22.80513954], [69.40791321, 22.80541992], [69.40736389, 22.80541611], [69.40736389, 22.80569458], [69.40680695, 22.80569458], [69.40680695, 22.80597305], [69.40652466, 22.80597305], [69.40652466, 22.80624962], [69.40570068, 22.80624008], [69.40570068, 22.80653], [69.40458679, 22.80652809], [69.40458679, 22.80680466], [69.40402985, 22.80680466], [69.40402985, 22.80708313], [69.4034729, 22.80708313], [69.4034729, 22.8073616], [69.40291595, 22.8073597], [69.40291595, 22.80764008], [69.40235901, 22.80764008], [69.40235901, 22.80820084], [69.40208435, 22.80819511], [69.40208435, 22.80847168], [69.40180206, 22.80846977], [69.40180206, 22.80875015], [69.4015274, 22.80875015], [69.4015274, 22.80903053], [69.40040588, 22.80903053], [69.40040588, 22.80931091], [69.39930725, 22.80930519], [69.39930725, 22.80958366], [69.39875031, 22.80957985], [69.39875031, 22.80986023], [69.39819336, 22.80986023], [69.39819336, 22.81014061], [69.39763641, 22.81014061], [69.39763641, 22.81042099], [69.3970871, 22.81041718], [69.3970871, 22.81069374], [69.39653015, 22.81069374], [69.39653015, 22.81097221], [69.39597321, 22.81097031], [69.39597321, 22.81125069], [69.39541626, 22.81125069], [69.39541626, 22.81153107], [69.39457703, 22.81153107], [69.39457703, 22.81180954], [69.39402771, 22.81180573], [69.39402771, 22.8120842], [69.39347076, 22.81208038], [69.39347076, 22.81236839], [69.39290619, 22.81236839], [69.39290619, 22.81263924], [69.39235687, 22.81263924], [69.39235687, 22.81291962], [69.39180756, 22.8129158], [69.39180756, 22.81319427], [69.39125061, 22.81319427], [69.39125061, 22.81347275], [69.39070129, 22.81347084], [69.39070129, 22.81374931], [69.38986206, 22.81374931], [69.38986206, 22.8140316], [69.38903046, 22.8140316], [69.38903046, 22.81431007], [69.38486481, 22.81430626], [69.38486481, 22.81458282], [69.38402557, 22.81458282], [69.38402557, 22.81485939], [69.38346863, 22.81485939], [69.38346863, 22.81514168], [69.38263702, 22.81514168], [69.38263702, 22.81541634], [69.38208008, 22.81541634], [69.38208008, 22.81569481], [69.38153076, 22.81569481], [69.38153076, 22.81596947], [69.38041687, 22.81596947], [69.38041687, 22.81625175], [69.3795929, 22.81625175], [69.3795929, 22.81653023], [69.37847137, 22.81652832], [69.37847137, 22.81680489], [69.37763977, 22.81680489], [69.37763977, 22.81708336], [69.37652588, 22.81708336], [69.37652588, 22.81736374], [69.37568665, 22.81736183], [69.37568665, 22.8176403], [69.37513733, 22.8176403], [69.37513733, 22.81792068], [69.37403107, 22.81792068], [69.37403107, 22.81820107], [69.37347412, 22.81819534], [69.37347412, 22.81847382], [69.37152863, 22.81847], [69.37152863, 22.81875038], [69.37097168, 22.81875038], [69.37097168, 22.81903076], [69.37069702, 22.81903076], [69.37069702, 22.81931114], [69.36875153, 22.81930542], [69.36875153, 22.8195858], [69.36736298, 22.81958008], [69.36736298, 22.81986046], [69.36653137, 22.81986046], [69.36653137, 22.82014084], [69.3659668, 22.82014084], [69.3659668, 22.82042122], [69.36514282, 22.82042122], [69.36514282, 22.82014084], [69.36486053, 22.82014084], [69.36486053, 22.82042122], [69.36430359, 22.8204174], [69.36430359, 22.82069588], [69.36374664, 22.82069588], [69.36374664, 22.82097244], [69.36264038, 22.82097054], [69.36264038, 22.82125092], [69.36208344, 22.82125092], [69.36208344, 22.82208252], [69.36180878, 22.82208061], [69.36180878, 22.82236099], [69.36125183, 22.82236099], [69.36125183, 22.82263947], [69.36068726, 22.82263947], [69.36068726, 22.82236099], [69.36013794, 22.82236099], [69.36013794, 22.82263947], [69.35819244, 22.82263947], [69.35819244, 22.82236099], [69.35791779, 22.82236099], [69.35791779, 22.82208061], [69.35652924, 22.82208252], [69.35652924, 22.82180405], [69.35597229, 22.82180977], [69.35597229, 22.82154083], [69.35542297, 22.82154083], [69.35542297, 22.82125092], [69.35514069, 22.82125092], [69.35514069, 22.81986046], [69.35458374, 22.81986046], [69.35458374, 22.8195858], [69.35430908, 22.8195858], [69.35430908, 22.81902695], [69.35402679, 22.81903076], [69.35402679, 22.81875038], [69.35375214, 22.81875038], [69.35375214, 22.81847], [69.35319519, 22.81847382], [69.35319519, 22.81819534], [69.3529129, 22.81820107], [69.3529129, 22.81792068], [69.35235596, 22.81792068], [69.35235596, 22.8176403], [69.3520813, 22.8176403], [69.3520813, 22.81820107], [69.35180664, 22.81820107], [69.35180664, 22.81903076], [69.35152435, 22.81902695], [69.35152435, 22.8195858], [69.35180664, 22.81958008], [69.35180664, 22.81986046], [69.3520813, 22.81986046], [69.3520813, 22.82014084], [69.35235596, 22.82014084], [69.35235596, 22.82042122], [69.35263824, 22.8204174], [69.35263824, 22.82069588], [69.3529129, 22.82069016], [69.3529129, 22.82125092], [69.35320282, 22.82125092], [69.35320282, 22.82154083], [69.35346985, 22.82154083], [69.35346985, 22.82180977], [69.35375214, 22.82180977], [69.35375214, 22.82291985], [69.35402679, 22.82291985], [69.35402679, 22.82374954], [69.35430908, 22.82374954], [69.35430908, 22.82486153], [69.35459137, 22.82485962], [69.35459137, 22.82570076], [69.3548584, 22.82570076], [69.3548584, 22.82624817], [69.35514069, 22.82624817], [69.35514069, 22.82653046], [69.35542297, 22.82653046], [69.35542297, 22.82681084], [69.35569763, 22.82680511], [69.35569763, 22.82735825], [69.35597229, 22.82736015], [69.35597229, 22.82847023], [69.35569763, 22.82847023], [69.35569763, 22.82875252], [69.35514069, 22.82875252], [69.35514069, 22.82847023], [69.3548584, 22.82847023], [69.3548584, 22.8279171], [69.35459137, 22.82792091], [69.35459137, 22.82763863], [69.35430908, 22.82763863], [69.35430908, 22.82735062], [69.35319519, 22.82736015], [69.35319519, 22.82680511], [69.3529129, 22.82681084], [69.3529129, 22.82653046], [69.35263824, 22.82653046], [69.35263824, 22.8259697], [69.35236359, 22.8259716], [69.35236359, 22.82374954], [69.3520813, 22.82374954], [69.3520813, 22.82347107], [69.35152435, 22.82347298], [69.35152435, 22.8231945], [69.35124969, 22.8231945], [69.35124969, 22.82236099], [69.35097504, 22.82236099], [69.35097504, 22.82180405], [69.35069275, 22.82180977], [69.35069275, 22.82069016], [69.3484726, 22.82069588], [69.3484726, 22.8204174], [69.34680939, 22.8204174], [69.34680176, 22.82069588], [69.34597015, 22.82069588], [69.34597015, 22.82097244], [69.3456955, 22.82097244], [69.34571075, 22.82125092], [69.34513855, 22.82125092], [69.34513855, 22.82154083], [69.3445816, 22.82154083], [69.3445816, 22.82180977], [69.34430695, 22.82180405], [69.34430695, 22.82208252], [69.34402466, 22.82208252], [69.34402466, 22.82180405], [69.34347534, 22.82180405], [69.34347534, 22.82208252], [69.3429184, 22.82208061], [69.3429184, 22.82236099], [69.34263611, 22.82236099], [69.34265137, 22.82263947], [69.34208679, 22.82263947], [69.34208679, 22.82291985], [69.3418045, 22.82291794], [69.3418045, 22.8231945], [69.34152985, 22.8231945], [69.34152985, 22.82347298], [69.34124756, 22.82347107], [69.34124756, 22.82374954], [69.34069824, 22.82374954], [69.34069824, 22.82402992], [69.3401413, 22.82402992], [69.3401413, 22.8243103], [69.33985901, 22.82430649], [69.33985901, 22.82458305], [69.33930206, 22.82458305], [69.33930206, 22.82486153], [69.33875275, 22.82485962], [69.33875275, 22.82513809], [69.3381958, 22.82513809], [69.3381958, 22.82542038], [69.33763885, 22.82542038], [69.33763885, 22.82570076], [69.33708191, 22.82569504], [69.33708191, 22.8259716], [69.33680725, 22.8259697], [69.33680725, 22.82624817], [69.33625031, 22.82624817], [69.33625031, 22.82653046], [69.33598328, 22.82653046], [69.33598328, 22.82681084], [69.3354187, 22.82680511], [69.3354187, 22.82708359], [69.33486176, 22.82708359], [69.33486176, 22.82736015], [69.33403015, 22.82735062], [69.33403015, 22.82763863], [69.33235931, 22.82763863], [69.33235931, 22.82792091], [69.33180237, 22.8279171], [69.33180237, 22.82819366], [69.33152771, 22.82819366], [69.33152771, 22.82847023], [69.33125305, 22.82847023], [69.33125305, 22.82875252], [69.32958221, 22.82875252], [69.32958221, 22.8290329], [69.32930756, 22.8290329], [69.32930756, 22.82930946], [69.32847595, 22.82930565], [69.32847595, 22.82958412], [69.32707977, 22.82958031], [69.32707977, 22.82986259], [69.32624817, 22.82986259], [69.32624817, 22.83014107], [69.32597351, 22.83013916], [69.32597351, 22.83041573], [69.32514191, 22.83041763], [69.32514191, 22.8306942], [69.32375336, 22.8306942], [69.32375336, 22.83097267], [69.32263947, 22.83097267], [69.32263947, 22.83125114], [69.32125092, 22.83125114], [69.32125092, 22.83152962], [69.32068634, 22.83152962], [69.32068634, 22.83125114], [69.32013702, 22.83125114], [69.32013702, 22.83152962], [69.31958008, 22.83152962], [69.31958008, 22.83181], [69.31930542, 22.83180618], [69.31930542, 22.83208466], [69.31874847, 22.83208084], [69.31874847, 22.83236122], [69.31430817, 22.83236122], [69.31430817, 22.83263969], [69.31402588, 22.83263969], [69.31402588, 22.83236122], [69.31263733, 22.83236122], [69.31263733, 22.83263969], [69.31153107, 22.83263969], [69.31153107, 22.83236122], [69.30374908, 22.83236122], [69.30374908, 22.83208084], [69.30319214, 22.83208084], [69.30319214, 22.83236122], [69.30263519, 22.83236122], [69.30263519, 22.83208466], [69.30236053, 22.83208084], [69.30236053, 22.83236122], [69.30069733, 22.83236122], [69.30069733, 22.83208084], [69.30041504, 22.83208466], [69.30041504, 22.83180618], [69.30014038, 22.83181], [69.30014038, 22.83152962], [69.29957581, 22.83152962], [69.29957581, 22.83125114], [69.29930878, 22.83125114], [69.29930878, 22.83097267], [69.29846954, 22.83097267], [69.29846954, 22.8306942], [69.29763794, 22.8306942], [69.29763794, 22.83041763], [69.29652405, 22.83041573], [69.29652405, 22.83013916], [69.2959671, 22.83014107], [69.2959671, 22.82986259], [69.29541779, 22.82986259], [69.29541779, 22.82958031], [69.29430389, 22.82958412], [69.29430389, 22.82930565], [69.29319763, 22.82930946], [69.29319763, 22.8290329], [69.29180908, 22.8290329], [69.29180908, 22.82875252], [69.29096985, 22.82875252], [69.29096985, 22.82847023], [69.2895813, 22.82847023], [69.2895813, 22.82819366], [69.28902435, 22.82819366], [69.28902435, 22.8279171], [69.28817749, 22.82792091], [69.28817749, 22.82763863], [69.28736115, 22.82763863], [69.28736115, 22.82735062], [69.28652954, 22.82736015], [69.28652954, 22.82708359], [69.28569794, 22.82708359], [69.28569794, 22.82680511], [69.28430176, 22.82681084], [69.28430176, 22.82653046], [69.28237152, 22.82653046], [69.28237152, 22.82624817], [69.28013611, 22.82624817], [69.28013611, 22.8259697], [69.2765274, 22.8259716], [69.2765274, 22.82569504], [69.27402496, 22.82569504], [69.27402496, 22.8259716], [69.27347565, 22.8259716], [69.27347565, 22.82569504], [69.2731781, 22.82570076], [69.2731781, 22.82542038], [69.27179718, 22.82542038], [69.27179718, 22.82513809], [69.27043152, 22.82513809], [69.27043152, 22.82485962], [69.26875305, 22.82486153], [69.26875305, 22.82458305], [69.26847076, 22.82458305], [69.26847076, 22.82430649], [69.26737213, 22.8243103], [69.26737213, 22.82402992], [69.26680756, 22.82402992], [69.26680756, 22.8243103], [69.26625061, 22.82430649], [69.26625061, 22.82458305], [69.26597595, 22.82458305], [69.26597595, 22.82486153], [69.26569366, 22.82486153], [69.26569366, 22.82458305], [69.26541901, 22.82458305], [69.26541901, 22.82486153], [69.26513672, 22.82485962], [69.26513672, 22.82513809], [69.26486206, 22.82513809], [69.26486206, 22.82542038], [69.26429749, 22.82542038], [69.26429749, 22.82570076], [69.26347351, 22.82569504], [69.26347351, 22.8259716], [69.26291656, 22.8259697], [69.26291656, 22.82624817], [69.26207733, 22.82624817], [69.26207733, 22.82653046], [69.26152802, 22.82653046], [69.26152802, 22.82681084], [69.26097107, 22.82680511], [69.26097107, 22.82708359], [69.26041412, 22.82708359], [69.26041412, 22.82736015], [69.26013947, 22.82736015], [69.26013947, 22.82748032], [69.26013947, 22.82763863], [69.25961304, 22.82763863], [69.25902557, 22.82763863], [69.2590332, 22.82781982], [69.2590332, 22.82792091], [69.25869751, 22.82792091], [69.25736237, 22.8279171], [69.25736237, 22.82819366], [69.25597382, 22.82819366], [69.25597382, 22.82847023], [69.25514221, 22.82847023], [69.25514221, 22.82875252], [69.25402832, 22.82875252], [69.25402832, 22.8290329], [69.2529068, 22.8290329], [69.2529068, 22.82930946], [69.25180817, 22.82930565], [69.25180817, 22.82958412], [69.25013733, 22.82958031], [69.25013733, 22.82986259], [69.24861908, 22.82986259], [69.2470932, 22.82986259], [69.2470932, 22.83014107], [69.24652863, 22.83013916], [69.24652863, 22.83041573], [69.24597168, 22.83041763], [69.24597168, 22.8306942], [69.24541473, 22.8306942], [69.24541473, 22.83097267], [69.24485779, 22.83097267], [69.24485779, 22.83125114], [69.24430847, 22.83125114], [69.24430847, 22.83152962], [69.24402618, 22.83152962], [69.24402618, 22.83125114], [69.24346924, 22.83125114], [69.24346924, 22.83152962], [69.24263763, 22.83152962], [69.24263763, 22.83181], [69.24153137, 22.83180618], [69.24153137, 22.83208466], [69.24069214, 22.83208084], [69.24069214, 22.83236122], [69.23986053, 22.83236122], [69.23986053, 22.83263969], [69.23929596, 22.83263969], [69.23929596, 22.83292007], [69.23819733, 22.83291626], [69.23819733, 22.83319473], [69.23764038, 22.83319092], [69.23764038, 22.83348083], [69.23652649, 22.83348083], [69.23652649, 22.83319092], [69.23625183, 22.83319092], [69.23625183, 22.83348083], [69.23542023, 22.83348083], [69.23542023, 22.83319092], [69.23513794, 22.83319092], [69.23513794, 22.83348083], [69.23458099, 22.83348083], [69.23458099, 22.83374977], [69.23432159, 22.83374977], [69.23432159, 22.83403015], [69.2326355, 22.83402824], [69.2326355, 22.83430672], [69.23208618, 22.83430672], [69.23208618, 22.83458328], [69.23069763, 22.83457947], [69.23069763, 22.83514023], [69.23041534, 22.83513832], [69.23041534, 22.83597183], [69.23014069, 22.83596992], [69.23014069, 22.83764076], [69.2298584, 22.83764076], [69.2298584, 22.83792114], [69.23014069, 22.83792114], [69.23014069, 22.83903122], [69.2298584, 22.83903122], [69.2298584, 22.83930969], [69.23014069, 22.83930969], [69.23014069, 22.84042168], [69.2298584, 22.84041595], [69.2298584, 22.84069443], [69.22958374, 22.84069443], [69.22958374, 22.8409729], [69.22930908, 22.84096909], [69.22930908, 22.84124947], [69.22902679, 22.84124947], [69.22902679, 22.84153175], [69.22875214, 22.84152985], [69.22875214, 22.84208107], [69.22846985, 22.84208107], [69.22846985, 22.84235954], [69.22819519, 22.84235954], [69.22819519, 22.84208107], [69.2279129, 22.84208107], [69.2279129, 22.84152985], [69.22763824, 22.84153175], [69.22763824, 22.84042168], [69.22735596, 22.84042168], [69.22735596, 22.83986092], [69.22763824, 22.83986092], [69.22763824, 22.83958054], [69.22736359, 22.83958244], [69.22736359, 22.83930588], [69.2270813, 22.83930969], [69.2270813, 22.83875084], [69.22651672, 22.83875084], [69.22651672, 22.83847046], [69.22597504, 22.83847237], [69.22597504, 22.83819389], [69.22541809, 22.83819389], [69.22541809, 22.83791733], [69.22486115, 22.83792114], [69.22486115, 22.83764076], [69.22458649, 22.83764076], [69.22458649, 22.83736038], [69.22402954, 22.83736038], [69.22402954, 22.83708], [69.22374725, 22.83708382], [69.22374725, 22.83652687], [69.2234726, 22.83653831], [69.2234726, 22.83625031], [69.22319794, 22.83625031], [69.22319794, 22.83596992], [69.22208405, 22.83597183], [69.22209167, 22.83625031], [69.22125244, 22.83625031], [69.22125244, 22.83653831], [69.21985626, 22.83653831], [69.21985626, 22.83681107], [69.21875, 22.83680534], [69.21875, 22.83708382], [69.21347046, 22.83708382], [69.21347046, 22.83680534], [69.21047211, 22.83680534], [69.20819092, 22.83680534], [69.20819092, 22.83708382], [69.20791626, 22.83708], [69.20791626, 22.83736038], [69.20735931, 22.83736038], [69.20735931, 22.83764076], [69.20708466, 22.83763885], [69.20708466, 22.83847237], [69.20735931, 22.83847046], [69.20735931, 22.83875084], [69.2076416, 22.83875084], [69.2076416, 22.83903122], [69.20780182, 22.83903122], [69.20791626, 22.83903122], [69.20791626, 22.83986092], [69.2076416, 22.83986092], [69.2076416, 22.8401413], [69.20646667, 22.8401413], [69.20597076, 22.8401413], [69.20597076, 22.83986092], [69.20458221, 22.83986092], [69.20458221, 22.83958054], [69.20347595, 22.83958244], [69.20347595, 22.83930588], [69.20263672, 22.83930588], [69.20263672, 22.83958244], [69.20236206, 22.83958054], [69.20236206, 22.83986092], [69.20180511, 22.83986092], [69.20181274, 22.8401413], [69.20153046, 22.8401413], [69.20153046, 22.83986092], [69.20041656, 22.83986092], [69.20041656, 22.8401413], [69.20014191, 22.8401413], [69.20014191, 22.83986092], [69.19985962, 22.83986092], [69.19985962, 22.83958054], [69.19958496, 22.83958244], [69.19958496, 22.83930588], [69.19930267, 22.83930969], [69.19930267, 22.83903122], [69.19902802, 22.83903122], [69.19902802, 22.83875084], [69.19847107, 22.83875084], [69.19847107, 22.83847046], [69.19735718, 22.83847046], [69.19735718, 22.83903122], [69.19708252, 22.83903122], [69.19708252, 22.83930969], [69.19652557, 22.83930588], [69.19652557, 22.83958244], [69.19625092, 22.83958054], [69.19625092, 22.83986092], [69.19596863, 22.83986092], [69.19596863, 22.8401413], [69.19568634, 22.8401413], [69.19568634, 22.84042168], [69.19513702, 22.84041595], [69.19513702, 22.84069443], [69.19486237, 22.84069443], [69.19486237, 22.8409729], [69.19374847, 22.8409729], [69.19374847, 22.84069443], [69.19208527, 22.84069443], [69.19208527, 22.8409729], [69.19152832, 22.84096909], [69.19152832, 22.84124947], [69.19069672, 22.84124947], [69.19069672, 22.84153175], [69.19013977, 22.84153175], [69.19013977, 22.84181023], [69.18985748, 22.84180641], [69.18985748, 22.84208107], [69.18930817, 22.84208107], [69.18930817, 22.84235954], [69.18901825, 22.8423481], [69.18901825, 22.84264183], [69.18818665, 22.84264183], [69.18818665, 22.8429203], [69.18763733, 22.8429203], [69.18763733, 22.84320068], [69.18736267, 22.84319496], [69.18736267, 22.84347343], [69.18653107, 22.84346962], [69.18653107, 22.84375191], [69.18624878, 22.84375191], [69.18624878, 22.84403038], [69.18595886, 22.84403038], [69.18595886, 22.84431076], [69.18569183, 22.84430504], [69.18569183, 22.84458351], [69.18541718, 22.84458351], [69.18541718, 22.84486389], [69.18514252, 22.84486008], [69.18514252, 22.84514046], [69.18402863, 22.84514046], [69.18402863, 22.84542084], [69.18374634, 22.84541702], [69.18374634, 22.84569168], [69.18319702, 22.84569168], [69.18319702, 22.84597206], [69.18235779, 22.84597015], [69.18235779, 22.84625053], [69.18152618, 22.84625053], [69.18152618, 22.84653091], [69.18096924, 22.84653091], [69.18096924, 22.84680939], [69.18041992, 22.84680557], [69.18041992, 22.84708595], [69.18013763, 22.84708023], [69.18013763, 22.84736061], [69.17986298, 22.84736061], [69.17986298, 22.84764099], [69.17958069, 22.84764099], [69.17958069, 22.84791946], [69.17930603, 22.84791756], [69.17930603, 22.84819412], [69.17903137, 22.84819031], [69.17903137, 22.84848022], [69.17874908, 22.84848022], [69.17874908, 22.84875107], [69.1784668, 22.84875107], [69.1784668, 22.84902954], [69.17819214, 22.84902954], [69.17819214, 22.84930992], [69.17791748, 22.84930611], [69.17791748, 22.84958267], [69.17763519, 22.84958267], [69.17764282, 22.84986115], [69.17736053, 22.84986115], [69.17736053, 22.85013962], [69.17708588, 22.85013962], [69.17707825, 22.85030174], [69.17707825, 22.85041809], [69.17685699, 22.85041618], [69.17652893, 22.85041618], [69.17652893, 22.85058022], [69.17652893, 22.85069466], [69.17624664, 22.85069466], [69.17624664, 22.85097313], [69.17597198, 22.85097122], [69.17597198, 22.85124969], [69.17541504, 22.85124969], [69.17541504, 22.85152626], [69.17514038, 22.85152626], [69.17514038, 22.85124969], [69.17485809, 22.85124969], [69.17485809, 22.85152626], [69.17469788, 22.85152626], [69.17375183, 22.85152626], [69.17375183, 22.85180473], [69.17346954, 22.85180473], [69.17346954, 22.85208321], [69.17319489, 22.85208321], [69.17319489, 22.85236168], [69.17308044, 22.85236168], [69.17292023, 22.85235977], [69.17292023, 22.85263824], [69.17263794, 22.85263824], [69.17263794, 22.85292053], [69.17236328, 22.85292053], [69.17236328, 22.85320091], [69.17180634, 22.85319519], [69.17180634, 22.85347176], [69.17124939, 22.85346985], [69.17124939, 22.85374832], [69.17098236, 22.85374832], [69.17098236, 22.85403061], [69.17069244, 22.85403061], [69.17069244, 22.85430908], [69.17041779, 22.85430527], [69.17041779, 22.85458374], [69.16986084, 22.85457993], [69.16986084, 22.8548584], [69.16958618, 22.8548584], [69.16958618, 22.85514259], [69.16902924, 22.85514259], [69.16902924, 22.85542107], [69.16874695, 22.85541725], [69.16874695, 22.85569382], [69.16819763, 22.85569191], [69.16819763, 22.85653114], [69.16707611, 22.85653114], [69.16707611, 22.85680962], [69.16625214, 22.8568058], [69.16625214, 22.85708427], [69.16569519, 22.85708427], [69.16570282, 22.85736275], [69.1654129, 22.85736275], [69.1654129, 22.85765076], [69.16486359, 22.85763931], [69.16486359, 22.85819435], [69.16430664, 22.85819435], [69.16430664, 22.85847473], [69.16401672, 22.85847282], [69.16401672, 22.85874939], [69.16374969, 22.85874939], [69.16374969, 22.85902977], [69.1626358, 22.85902977], [69.1626358, 22.85931015], [69.1618042, 22.85930634], [69.1618042, 22.85958481], [69.16152954, 22.8595829], [69.16152954, 22.86013985], [69.16124725, 22.86013985], [69.16124725, 22.86042023], [69.1598587, 22.86041641], [69.1598587, 22.86069489], [69.15958405, 22.86069489], [69.15958405, 22.86097145], [69.1590271, 22.86097145], [69.1590271, 22.86124992], [69.15820313, 22.86124992], [69.15820313, 22.8615303], [69.15791321, 22.8615303], [69.15791321, 22.86181068], [69.15736389, 22.86180687], [69.15736389, 22.86208344], [69.15680695, 22.86208344], [69.15680695, 22.86236191], [69.15598297, 22.86236], [69.15598297, 22.86264038], [69.1554184, 22.86264038], [69.1554184, 22.86292076], [69.15513611, 22.86291695], [69.15513611, 22.8631897], [69.15486145, 22.86319542], [69.15486145, 22.86347198], [69.15458679, 22.86346054], [69.15458679, 22.86375046], [69.1534729, 22.86375046], [69.1534729, 22.86403084], [69.15319824, 22.86403084], [69.15319824, 22.86431122], [69.15235901, 22.8643055], [69.15235901, 22.86458397], [69.15207672, 22.86458015], [69.15207672, 22.86486053], [69.1515274, 22.86486053], [69.1515274, 22.86514091], [69.15097046, 22.86514091], [69.15097046, 22.86541748], [69.15013885, 22.86541748], [69.15013885, 22.86569405], [69.14930725, 22.86569405], [69.14930725, 22.86597252], [69.14903259, 22.86597061], [69.14903259, 22.86624908], [69.1470871, 22.86624718], [69.1470871, 22.86652756], [69.14653015, 22.86652756], [69.14653015, 22.8670826], [69.14624786, 22.86708069], [69.14624786, 22.86735916], [69.14608002, 22.86735916], [69.14569092, 22.86735916], [69.14569092, 22.86709023], [69.14541626, 22.86708069], [69.14541626, 22.86735916], [69.14485931, 22.86735916], [69.14485931, 22.86764145], [69.14430237, 22.86764145], [69.14430237, 22.86792183], [69.14375305, 22.86791611], [69.14375305, 22.86819458], [69.14347076, 22.86819458], [69.14347076, 22.86847115], [69.14180756, 22.86846924], [69.14180756, 22.86875153], [69.14125061, 22.86875153], [69.14125061, 22.86903191], [69.14041901, 22.86902809], [69.14041901, 22.86930466], [69.13957977, 22.86930084], [69.13957977, 22.86959267], [69.13903046, 22.86958122], [69.13903046, 22.86986351], [69.13819122, 22.8698597], [69.13819122, 22.87014008], [69.13790894, 22.87014008], [69.13790894, 22.87042046], [69.13735962, 22.87042046], [69.13735962, 22.87070084], [69.13625336, 22.87069511], [69.13625336, 22.87097359], [69.13597107, 22.87096977], [69.13597107, 22.87125015], [69.13540649, 22.87125015], [69.13540649, 22.87153053], [69.13487244, 22.87153053], [69.13487244, 22.87181091], [69.13402557, 22.87180519], [69.13402557, 22.87208366], [69.13318634, 22.87207985], [69.13318634, 22.87236023], [69.13208008, 22.87236023], [69.13208008, 22.87265015], [69.13153076, 22.8726387], [69.13153076, 22.87319565], [69.13097382, 22.87319565], [69.13097382, 22.87347221], [69.13041687, 22.87347031], [69.13041687, 22.87375069], [69.1295929, 22.87375069], [69.1295929, 22.87403107], [69.12902832, 22.87403107], [69.12902832, 22.87430954], [69.12875366, 22.87430573], [69.12875366, 22.8745842], [69.12819672, 22.87458038], [69.12819672, 22.87486076], [69.1279068, 22.87486076], [69.1279068, 22.87514114], [69.12763977, 22.87514114], [69.12763977, 22.87541962], [69.12680817, 22.8754158], [69.12680817, 22.87569427], [69.12652588, 22.87569427], [69.12652588, 22.87597275], [69.12625122, 22.87597084], [69.12625122, 22.87625122], [69.12567902, 22.87625122], [69.12567902, 22.87652969], [69.12541962, 22.87652969], [69.12541962, 22.87681007], [69.12513733, 22.87680626], [69.12513733, 22.87708282], [69.12486267, 22.87708282], [69.12486267, 22.8773613], [69.12430573, 22.8773613], [69.12431335, 22.87763977], [69.12403107, 22.87763977], [69.12403107, 22.87791824], [69.12347412, 22.87791634], [69.12347412, 22.87819481], [69.12319183, 22.87819481], [69.12319183, 22.87847137], [69.12291718, 22.87847137], [69.12293243, 22.87874985], [69.12264252, 22.87874985], [69.12264252, 22.87902832], [69.12208557, 22.87902832], [69.12208557, 22.87930489], [69.12180328, 22.87930489], [69.12180328, 22.87958336], [69.12152863, 22.87958336], [69.12152863, 22.87986183], [69.12124634, 22.87985992], [69.12124634, 22.8801384], [69.12097168, 22.8801384], [69.12097168, 22.88042068], [69.12069702, 22.88042068], [69.12069702, 22.88069916], [69.1204071, 22.88069916], [69.1204071, 22.88124847], [69.12014008, 22.88124847], [69.12014008, 22.88181114], [69.11930847, 22.88180542], [69.11930847, 22.88208389], [69.11875153, 22.88208008], [69.11875153, 22.88236237], [69.11846924, 22.88236237], [69.11846924, 22.88264275], [69.11791992, 22.88264275], [69.11791992, 22.88292122], [69.11763763, 22.8829174], [69.11763763, 22.88319206], [69.11736298, 22.88319206], [69.11736298, 22.88347054], [69.11708069, 22.88347054], [69.11708069, 22.88375282], [69.1167984, 22.88375282], [69.1167984, 22.88402939], [69.11653137, 22.88402939], [69.11653137, 22.88430977], [69.11569214, 22.88430977], [69.11569214, 22.88459015], [69.11514282, 22.88459015], [69.11514282, 22.88541985], [69.11486053, 22.88541603], [69.11486053, 22.8856945], [69.11458588, 22.8856945], [69.11458588, 22.88597488], [69.11429596, 22.88597107], [69.11429596, 22.88624954], [69.11402893, 22.88624954], [69.11402893, 22.88652992], [69.11373901, 22.88652992], [69.11373901, 22.8868103], [69.11319733, 22.88680649], [69.11319733, 22.88708305], [69.11264038, 22.88708305], [69.11264038, 22.88736153], [69.11180878, 22.88735962], [69.11180878, 22.88764954], [69.11152649, 22.88764954], [69.11152649, 22.88792038], [69.11125183, 22.88792038], [69.11125183, 22.88820076], [69.11069489, 22.88819695], [69.11069489, 22.8884716], [69.11042023, 22.8884697], [69.11042023, 22.88903046], [69.10986328, 22.88903046], [69.10986328, 22.88931084], [69.10958099, 22.88930511], [69.10958099, 22.88958359], [69.10930634, 22.88958359], [69.10930634, 22.88986206], [69.10901642, 22.88986015], [69.10901642, 22.89014053], [69.10819244, 22.89014053], [69.10819244, 22.89042091], [69.1076355, 22.89041519], [69.1076355, 22.89069366], [69.10708618, 22.89069366], [69.10708618, 22.89097214], [69.10652924, 22.89097023], [69.10652924, 22.89125061], [69.10624695, 22.89125061], [69.10624695, 22.89146805], [69.10569763, 22.89152908], [69.10569763, 22.89180946], [69.10541534, 22.89180565], [69.10541534, 22.89208412], [69.10514069, 22.89208031], [69.10514069, 22.89236069], [69.1048584, 22.89236069], [69.1048584, 22.89263916], [69.10430908, 22.89263916], [69.10430908, 22.89291763], [69.10402679, 22.89291763], [69.10402679, 22.8931942], [69.10375214, 22.8931942], [69.10375214, 22.89347267], [69.10362244, 22.89347267], [69.10346985, 22.89347076], [69.10346985, 22.89374924], [69.10320282, 22.89374924], [69.10320282, 22.89403152], [69.1029129, 22.89403152], [69.1029129, 22.8943119], [69.10236359, 22.89430618], [69.10236359, 22.89458275], [69.1020813, 22.89458084], [69.1020813, 22.89485931], [69.10179901, 22.89485931], [69.10179901, 22.8951416], [69.10124969, 22.8951416], [69.10124969, 22.89542007], [69.10097504, 22.89541626], [69.10097504, 22.89569473], [69.10041809, 22.89569473], [69.10041809, 22.89596939], [69.09986115, 22.89596939], [69.09986115, 22.89625168], [69.09958649, 22.89625168], [69.09958649, 22.89653015], [69.0993042, 22.89652824], [69.0993042, 22.89680481], [69.09874725, 22.89680481], [69.09874725, 22.89708138], [69.0984726, 22.89708138], [69.0984726, 22.89736366], [69.0973587, 22.89735985], [69.0973587, 22.89764023], [69.09707642, 22.89764023], [69.09707642, 22.89792061], [69.09680939, 22.89792061], [69.09680176, 22.8982029], [69.09597015, 22.89819527], [69.09597015, 22.89847374], [69.0956955, 22.89847374], [69.09570313, 22.89875031], [69.09541321, 22.89875031], [69.09541321, 22.89903069], [69.09401703, 22.89903069], [69.09401703, 22.89931107], [69.09347534, 22.89930534], [69.09347534, 22.89958572], [69.09319305, 22.89957047], [69.09319305, 22.89986038], [69.09263611, 22.89986038], [69.09263611, 22.90014076], [69.09236145, 22.90014076], [69.09236145, 22.90042114], [69.0918045, 22.90041733], [69.0918045, 22.9006958], [69.09124756, 22.9006958], [69.09124756, 22.90097237], [69.0909729, 22.90097046], [69.0909729, 22.90125084], [69.09069824, 22.90125084], [69.09069824, 22.90153122], [69.09041595, 22.9015274], [69.09041595, 22.90167809], [69.09041595, 22.90180969], [69.08985901, 22.90180588], [69.08985901, 22.90208244], [69.08930206, 22.90208054], [69.08930206, 22.90236092], [69.0890274, 22.90236092], [69.0890274, 22.90263939], [69.08875275, 22.90262985], [69.08875275, 22.90291977], [69.08847046, 22.90291786], [69.08847046, 22.90319443], [69.0881958, 22.90319443], [69.0881958, 22.9034729], [69.08735657, 22.90347099], [69.08735657, 22.90374947], [69.08625031, 22.90374947], [69.08625031, 22.90402985], [69.08569336, 22.90402985], [69.08569336, 22.90431023], [69.0854187, 22.90430641], [69.0854187, 22.90486145], [69.08486176, 22.90485954], [69.08486176, 22.90513992], [69.08429718, 22.90513992], [69.08429718, 22.9054203], [69.08374786, 22.90541649], [69.08374786, 22.90569496], [69.08291626, 22.90569496], [69.08291626, 22.90597153], [69.0826416, 22.90596962], [69.0826416, 22.90624809], [69.08207703, 22.90624809], [69.08207703, 22.90652847], [69.08152771, 22.90652847], [69.08152771, 22.90681076], [69.08125305, 22.90680504], [69.08125305, 22.90708351], [69.08069611, 22.90708351], [69.08069611, 22.90736008], [69.08040619, 22.90735817], [69.08040619, 22.90763855], [69.08013916, 22.90763855], [69.08013916, 22.90792084], [69.07958221, 22.90791702], [69.07958221, 22.90819359], [69.07930756, 22.90819359], [69.07930756, 22.90847015], [69.07847595, 22.90847015], [69.07847595, 22.90876007], [69.07791901, 22.90876007], [69.07791901, 22.90903282], [69.07762909, 22.90903282], [69.07762909, 22.90930939], [69.07736206, 22.90930557], [69.07736206, 22.90958405], [69.07680511, 22.90958405], [69.07681274, 22.90986252], [69.07624817, 22.90986252], [69.07624817, 22.9101429], [69.07596588, 22.9101429], [69.07596588, 22.91041946], [69.07569122, 22.91041756], [69.07569122, 22.91069221], [69.07541656, 22.91069221], [69.07541656, 22.91097069], [69.07485962, 22.91097069], [69.07485962, 22.91125107], [69.07430267, 22.91125107], [69.07430267, 22.91152954], [69.07402802, 22.91152763], [69.07402802, 22.91208458], [69.07375336, 22.91208076], [69.07375336, 22.91236115], [69.07235718, 22.91236115], [69.07235718, 22.91263962], [69.07208252, 22.91263962], [69.07208252, 22.91292], [69.07152557, 22.91291618], [69.07152557, 22.91319466], [69.07096863, 22.91319466], [69.07096863, 22.91347313], [69.07041931, 22.91347122], [69.07041931, 22.91374969], [69.06958008, 22.91374969], [69.06958008, 22.91403008], [69.06930542, 22.91402817], [69.06930542, 22.91458321], [69.06903076, 22.91458321], [69.06903076, 22.91486168], [69.0687561, 22.91485977], [69.0687561, 22.91514015], [69.06846619, 22.91514015], [69.06846619, 22.91542053], [69.06819153, 22.91542053], [69.06819153, 22.91570091], [69.06791687, 22.91569519], [69.06791687, 22.91597176], [69.06735992, 22.91596985], [69.06735992, 22.91625023], [69.06680298, 22.91625023], [69.06680298, 22.91653061], [69.06652832, 22.91653061], [69.06652832, 22.91681099], [69.06569672, 22.91680527], [69.06569672, 22.91708374], [69.06485748, 22.91707993], [69.06485748, 22.91736031], [69.06319427, 22.91736031], [69.06319427, 22.91763878], [69.06291962, 22.91763115], [69.06291962, 22.91792107], [69.06263733, 22.91791725], [69.06263733, 22.91819382], [69.06208038, 22.91819382], [69.06208038, 22.91847229], [69.06153107, 22.91847038], [69.06153107, 22.91875076], [69.06041718, 22.91875076], [69.06041718, 22.91903114], [69.06014252, 22.91903114], [69.06014252, 22.91930962], [69.05986023, 22.9193058], [69.05986023, 22.91958427], [69.05930328, 22.91958046], [69.05930328, 22.91986084], [69.05874634, 22.91986084], [69.05874634, 22.92013931], [69.05847168, 22.92013931], [69.05847168, 22.9204216], [69.05819702, 22.9204216], [69.05819702, 22.92070007], [69.05791473, 22.92069435], [69.05791473, 22.92097282], [69.05764008, 22.92097092], [69.05764008, 22.92124939], [69.05708313, 22.92124939], [69.05708313, 22.92153168], [69.05652618, 22.92153168], [69.05652618, 22.92181015], [69.05625153, 22.92180634], [69.05625153, 22.9220829], [69.05569458, 22.9220829], [69.05569458, 22.92235947], [69.05513763, 22.92235947], [69.05513763, 22.92264175], [69.05458069, 22.92264175], [69.05458069, 22.92292023], [69.05403137, 22.92291641], [69.05403137, 22.92319489], [69.05319214, 22.92319489], [69.05319214, 22.92347336], [69.05236053, 22.92346954], [69.05236053, 22.9240303], [69.05208588, 22.9240284], [69.05208588, 22.92416191], [69.05208588, 22.92431068], [69.05152893, 22.92430305], [69.05152893, 22.92458153], [69.05124664, 22.92458153], [69.05124664, 22.92486382], [69.0506897, 22.92486191], [69.0506897, 22.92514038], [69.05042267, 22.92514038], [69.05042267, 22.92542076], [69.04985809, 22.92541695], [69.04985809, 22.9256897], [69.04930878, 22.92569542], [69.04930878, 22.92597389], [69.04875183, 22.92597008], [69.04875183, 22.92625046], [69.04846954, 22.92625046], [69.04846954, 22.92653084], [69.04819489, 22.92652702], [69.04819489, 22.9268055], [69.04792023, 22.9268055], [69.04792023, 22.92708588], [69.04708099, 22.92708015], [69.04708099, 22.92736053], [69.04651642, 22.92736053], [69.04651642, 22.92764091], [69.04624939, 22.92764091], [69.04624939, 22.92791939], [69.04597473, 22.92791748], [69.04597473, 22.92819595], [69.04569244, 22.92819595], [69.04569244, 22.92847252], [69.04541779, 22.92847061], [69.04541779, 22.92875099], [69.04514313, 22.92875099], [69.04514313, 22.92902946], [69.04486084, 22.92902946], [69.04486084, 22.92930984], [69.04458618, 22.92930794], [69.04458618, 22.9295826], [69.04402924, 22.92957115], [69.04402924, 22.92986107], [69.04264069, 22.92986107], [69.04264069, 22.93013954], [69.04151917, 22.93013954], [69.04151917, 22.93041992], [69.04125214, 22.93041611], [69.04125214, 22.93069458], [69.04069519, 22.93069458], [69.04069519, 22.93097305], [69.03930664, 22.93097115], [69.03930664, 22.93152809], [69.03902435, 22.93152618], [69.03902435, 22.93180466], [69.03847504, 22.93180466], [69.03847504, 22.93208313], [69.03819275, 22.93208313], [69.03819275, 22.9323616], [69.0376358, 22.9323597], [69.0376358, 22.93263817], [69.03679657, 22.93263817], [69.03679657, 22.9329319], [69.03624725, 22.9329319], [69.03624725, 22.93320084], [69.0348587, 22.93319511], [69.0348587, 22.93347168], [69.03375244, 22.93346977], [69.03375244, 22.93374825], [69.03264618, 22.93374825], [69.03264618, 22.93403053], [69.03235626, 22.93403053], [69.03235626, 22.93431091], [69.0320816, 22.93430519], [69.0320816, 22.93458366], [69.03180695, 22.93457985], [69.03180695, 22.93485832], [69.03098297, 22.93485832], [69.03098297, 22.93514252], [69.03069305, 22.93514252], [69.03069305, 22.9354229], [69.0304184, 22.9354229], [69.0304184, 22.93569946], [69.02902985, 22.93569374], [69.02902985, 22.93597031], [69.02874756, 22.93597031], [69.02874756, 22.93625259], [69.0284729, 22.93625259], [69.0284729, 22.93653107], [69.0276413, 22.93653107], [69.0276413, 22.93680954], [69.02708435, 22.93680573], [69.02708435, 22.9370842], [69.02625275, 22.93708038], [69.02625275, 22.93736267], [69.02597046, 22.93736267], [69.02597046, 22.93764114], [69.02540588, 22.93764114], [69.02540588, 22.93791962], [69.02513885, 22.9379158], [69.02513885, 22.93819237], [69.0248642, 22.93819237], [69.0248642, 22.93847466], [69.02430725, 22.93847466], [69.02430725, 22.93874931], [69.02375031, 22.93873978], [69.02375031, 22.93902969], [69.02348328, 22.93902969], [69.02348328, 22.93931007], [69.02319336, 22.93930626], [69.02319336, 22.93958473], [69.0229187, 22.93958473], [69.0229187, 22.9398613], [69.02263641, 22.93985939], [69.02263641, 22.94013977], [69.02236176, 22.94013977], [69.02236176, 22.94042015], [69.02180481, 22.94041634], [69.02180481, 22.94069481], [69.02124786, 22.94069481], [69.02124786, 22.94097137], [69.02097321, 22.94096947], [69.02097321, 22.94124985], [69.02041626, 22.94124985], [69.02041626, 22.94153023], [69.01958466, 22.94152832], [69.01958466, 22.94180679], [69.01875305, 22.94180679], [69.01875305, 22.94208336], [69.01791382, 22.94208336], [69.01791382, 22.94236183], [69.01734924, 22.94235992], [69.01734924, 22.9426403], [69.01708221, 22.9426403], [69.01708221, 22.94292068], [69.01680756, 22.94292068], [69.01680756, 22.94320107], [69.01541901, 22.94319534], [69.01541901, 22.94347191], [69.01513672, 22.94347], [69.01513672, 22.94375038], [69.01486206, 22.94375038], [69.01486206, 22.94403076], [69.01346588, 22.94403076], [69.01346588, 22.94431114], [69.01291656, 22.94430542], [69.01291656, 22.94458389], [69.01264191, 22.94458008], [69.01264191, 22.94486809], [69.01154327, 22.94486809], [69.01154327, 22.94514084], [69.01125336, 22.94513893], [69.01125336, 22.94569397], [69.01097107, 22.94569397], [69.01097107, 22.94597244], [69.01040649, 22.94597054], [69.01040649, 22.94625092], [69.00985718, 22.94625092], [69.00985718, 22.94652748], [69.00930786, 22.94652748], [69.00930786, 22.94681168], [69.00902557, 22.94680595], [69.00902557, 22.94708252], [69.00818634, 22.94708061], [69.00818634, 22.94735909], [69.00763702, 22.94735909], [69.00763702, 22.94764137], [69.00736237, 22.94764137], [69.00736237, 22.94792938], [69.00680542, 22.94791603], [69.00680542, 22.9481945], [69.00624847, 22.9481945], [69.00624847, 22.94847107], [69.00596619, 22.94846916], [69.00596619, 22.94874954], [69.00514221, 22.94874954], [69.00514221, 22.94903183], [69.0045929, 22.94903183], [69.0045929, 22.9493103], [69.00375366, 22.94930649], [69.00375366, 22.94958115], [69.00319672, 22.94958115], [69.00319672, 22.94985962], [69.00234985, 22.94985962], [69.00234985, 22.95014191], [69.00096893, 22.95014191], [69.00096893, 22.95042038], [69.00069427, 22.95041656], [69.00069427, 22.95097351], [69.00013733, 22.95097351], [68.99958038, 22.9509697], [68.99958038, 22.95125008], [68.99903107, 22.95125008], [68.99903107, 22.95153046], [68.99819183, 22.95153046], [68.99819183, 22.95181084], [68.99764252, 22.95180321], [68.99764252, 22.95208359], [68.99708557, 22.95208359], [68.99708557, 22.95236206], [68.99653625, 22.95236015], [68.99653625, 22.95264053], [68.99569702, 22.95264053], [68.99569702, 22.95292091], [68.99514008, 22.9529171], [68.99514008, 22.95319557], [68.99458313, 22.95319557], [68.99458313, 22.95347214], [68.99402618, 22.95347214], [68.99402618, 22.95375061], [68.99318695, 22.95374107], [68.99318695, 22.95403099], [68.99263763, 22.95403099], [68.99263763, 22.95430946], [68.99208069, 22.95430565], [68.99208069, 22.95458412], [68.99124908, 22.95458031], [68.99124908, 22.95486069], [68.99040985, 22.95486069], [68.99040985, 22.95514107], [68.98986053, 22.95514107], [68.98986053, 22.95541954], [68.98902893, 22.95541763], [68.98902893, 22.9556942], [68.98847198, 22.9556942], [68.98847198, 22.95597267], [68.98764038, 22.95597076], [68.98764038, 22.95625114], [68.98707581, 22.95625114], [68.98707581, 22.95652962], [68.98680878, 22.95652962], [68.98680878, 22.95680809], [68.98625183, 22.95680618], [68.98625183, 22.95708275], [68.98596954, 22.95708084], [68.98596954, 22.95736122], [68.98542023, 22.95736122], [68.98542023, 22.95763969], [68.98513794, 22.95763969], [68.98513794, 22.95791817], [68.98458099, 22.95791626], [68.98458099, 22.95819473], [68.98402405, 22.95819473], [68.98402405, 22.9584713], [68.98374939, 22.95846939], [68.98374939, 22.95874977], [68.98319244, 22.95874977], [68.98319244, 22.95902824], [68.9826355, 22.95902824], [68.9826355, 22.95930481], [68.98208618, 22.95930481], [68.98208618, 22.95958328], [68.98179626, 22.95957947], [68.98179626, 22.95986938], [68.98124695, 22.95986938], [68.98124695, 22.96013832], [68.98069763, 22.96013832], [68.98069763, 22.96042061], [68.98042297, 22.96042061], [68.98042297, 22.96069908], [68.9798584, 22.96069527], [68.9798584, 22.96097183], [68.97902679, 22.96096992], [68.97902679, 22.9612484], [68.97820282, 22.9612484], [68.97820282, 22.96153069], [68.97763824, 22.96153069], [68.97763824, 22.96181107], [68.97736359, 22.96180534], [68.97736359, 22.96208382], [68.97569275, 22.96208382], [68.97569275, 22.96180534], [68.97541809, 22.96180534], [68.97541809, 22.96208382], [68.9751358, 22.96208191], [68.9751358, 22.96236038], [68.97486115, 22.96236038], [68.97486115, 22.96264267], [68.97402954, 22.96264076], [68.97402954, 22.96291733], [68.97291565, 22.96291733], [68.97291565, 22.96319389], [68.97208405, 22.96319389], [68.97208405, 22.96347046], [68.97097015, 22.96347046], [68.97097015, 22.96375275], [68.97041321, 22.96375275], [68.97041321, 22.96430969], [68.9695816, 22.96430969], [68.9695816, 22.96541977], [68.96902466, 22.96541405], [68.96902466, 22.96597481], [68.96875, 22.9659729], [68.96875, 22.96652985], [68.96819305, 22.96652985], [68.96819305, 22.96681023], [68.9679184, 22.96680641], [68.9679184, 22.96708488], [68.96736145, 22.96708488], [68.96736145, 22.96736145], [68.96708679, 22.96735954], [68.96708679, 22.96763992], [68.96679688, 22.96763992], [68.96679688, 22.96820068], [68.96541595, 22.96819687], [68.96541595, 22.96847153], [68.96485901, 22.96846962], [68.96485901, 22.97014046], [68.96458435, 22.97013855], [68.96458435, 22.97069359], [68.96430206, 22.97069359], [68.96430206, 22.97097206], [68.96263885, 22.97097206], [68.96263885, 22.97069359], [68.96069336, 22.97069359], [68.96069336, 22.97097206], [68.96013641, 22.97097015], [68.96013641, 22.97125053], [68.9595871, 22.97125053], [68.9595871, 22.97180748], [68.95903015, 22.97180557], [68.95903015, 22.97208405], [68.95847321, 22.97208023], [68.95847321, 22.97236061], [68.95791626, 22.97236061], [68.95791626, 22.97291756], [68.9576416, 22.97291756], [68.9576416, 22.97319412], [68.95625305, 22.97319412], [68.95625305, 22.9734726], [68.95597076, 22.97347069], [68.95597076, 22.97374916], [68.95540619, 22.97374916], [68.95540619, 22.97403145], [68.95485687, 22.97403145], [68.95485687, 22.97431183], [68.95458221, 22.97430611], [68.95458221, 22.97458267], [68.95402527, 22.97458267], [68.95402527, 22.97485924], [68.95375061, 22.9748497], [68.95375061, 22.97514153], [68.95318604, 22.97514153], [68.95318604, 22.97542191], [68.95291901, 22.97541618], [68.95291901, 22.97569466], [68.95236206, 22.97569466], [68.95236206, 22.97597122], [68.95180511, 22.97597122], [68.95181274, 22.9762516], [68.95153046, 22.9762516], [68.95153046, 22.97653008], [68.95097351, 22.97652817], [68.95097351, 22.97680473], [68.95041656, 22.97680473], [68.95041656, 22.9770813], [68.95014191, 22.9770813], [68.95014191, 22.97736359], [68.94959259, 22.97735977], [68.94959259, 22.97764015], [68.94930267, 22.97763824], [68.94930267, 22.97791672], [68.94875336, 22.9779129], [68.94875336, 22.97820091], [68.94819641, 22.97819519], [68.94819641, 22.97847366], [68.94790649, 22.97846985], [68.94790649, 22.97875023], [68.94735718, 22.97875023], [68.94735718, 22.97903061], [68.94680786, 22.97903061], [68.94680786, 22.97931099], [68.94625092, 22.97930527], [68.94625092, 22.97958565], [68.94596863, 22.97957993], [68.94596863, 22.97986031], [68.94542694, 22.97986031], [68.94542694, 22.98014069], [68.94486237, 22.98014069], [68.94486237, 22.98042107], [68.94374847, 22.98041725], [68.94374847, 22.98069572], [68.94291687, 22.98069], [68.94291687, 22.98097992], [68.94127655, 22.98097229], [68.94069672, 22.98097229], [68.94069672, 22.98134995], [68.94069672, 22.98153114], [68.9404068, 22.98153114], [68.9404068, 22.98180962], [68.93997955, 22.9818058], [68.93958282, 22.9818058], [68.93958282, 22.98208427], [68.93902588, 22.98208046], [68.93902588, 22.98236084], [68.93875122, 22.98236084], [68.93875122, 22.98262024], [68.93846893, 22.98263931], [68.93846893, 22.98278046], [68.93846893, 22.98291969], [68.93826294, 22.98291779], [68.93791962, 22.98291779], [68.93791962, 22.98319435], [68.93763733, 22.98319435], [68.93763733, 22.9833107], [68.93763733, 22.98347282], [68.93739319, 22.98347282], [68.93708038, 22.98347282], [68.93708038, 22.98374939], [68.93695831, 22.98374939], [68.93680573, 22.98374939], [68.93680573, 22.98385048], [68.93681335, 22.98404121], [68.93653107, 22.98404121], [68.93653107, 22.98431015], [68.93624878, 22.98430634], [68.93624878, 22.9845829], [68.93597412, 22.9845829], [68.93597412, 22.98486137], [68.93569183, 22.98485947], [68.93569183, 22.98513985], [68.93514252, 22.98513985], [68.93514252, 22.98541832], [68.93486023, 22.98541641], [68.93486023, 22.98569489], [68.93458557, 22.98569489], [68.93458557, 22.98597145], [68.93430328, 22.98596954], [68.93430328, 22.98624992], [68.93402863, 22.98624992], [68.93402863, 22.9865284], [68.93374634, 22.9865284], [68.93374634, 22.98681068], [68.93319702, 22.98680496], [68.93319702, 22.98708344], [68.93291473, 22.98708344], [68.93291473, 22.98736191], [68.93235779, 22.98735809], [68.93235779, 22.98763847], [68.93208313, 22.98763847], [68.93208313, 22.98792076], [68.93152618, 22.98791695], [68.93152618, 22.9881897], [68.93125153, 22.98819542], [68.93125153, 22.98847008], [68.93096924, 22.98846817], [68.93096924, 22.98875237], [68.93068695, 22.98875237], [68.93068695, 22.98903275], [68.93041992, 22.98903275], [68.93041992, 22.98931122], [68.93013763, 22.9893055], [68.93013763, 22.98958206], [68.92986298, 22.98958206], [68.92986298, 22.98986053], [68.92958069, 22.98984909], [68.92958069, 22.99014282], [68.92930603, 22.99014091], [68.92930603, 22.99069214], [68.92903137, 22.99069214], [68.92903137, 22.99097061], [68.92874908, 22.99097061], [68.92874908, 22.9912529], [68.9284668, 22.9912529], [68.9284668, 22.99152946], [68.92819214, 22.99152946], [68.92819214, 22.99180984], [68.92791748, 22.99180603], [68.92791748, 22.9920845], [68.92763519, 22.9920845], [68.92764282, 22.99236107], [68.92652893, 22.99236107], [68.92652893, 22.99263954], [68.92569733, 22.99263954], [68.92569733, 22.99291992], [68.92541504, 22.99291611], [68.92541504, 22.99319458], [68.92485809, 22.99319458], [68.92485809, 22.99347305], [68.92457581, 22.99347115], [68.92458344, 22.99374962], [68.92431641, 22.99374962], [68.92431641, 22.99403], [68.92402649, 22.99402809], [68.92402649, 22.99430466], [68.92346954, 22.99430466], [68.92346954, 22.99458313], [68.92180634, 22.99458313], [68.92180634, 22.9948616], [68.92151642, 22.9948597], [68.92151642, 22.99514008], [68.92014313, 22.99514008], [68.92014313, 22.99542046], [68.91958618, 22.99542046], [68.91958618, 22.99570084], [68.91902924, 22.99570084], [68.91902924, 22.99598122], [68.91847229, 22.99598122], [68.91847229, 22.99625015], [68.91792297, 22.99625015], [68.91792297, 22.99653053], [68.9173584, 22.99653053], [68.9173584, 22.99681091], [68.91680908, 22.99680519], [68.91680908, 22.99708366], [68.91652679, 22.99707985], [68.91652679, 22.99736023], [68.91596985, 22.99736023], [68.91596985, 22.99764061], [68.91570282, 22.99764061], [68.91570282, 22.99792099], [68.9145813, 22.99791718], [68.9145813, 22.99819374], [68.91402435, 22.99819374], [68.91402435, 22.99847221], [68.91374969, 22.99847031], [68.91374969, 22.99875069], [68.91319275, 22.99875069], [68.91319275, 22.9990406], [68.91291809, 22.9990406], [68.91291809, 22.99930954], [68.9118042, 22.99930573], [68.9118042, 22.9995842], [68.91152954, 22.99958038], [68.91152954, 22.99986076], [68.91124725, 22.99986076], [68.91124725, 23.00013924], [68.9109726, 23.00013924], [68.9109726, 23.00042152], [68.91069794, 23.0004158], [68.91069794, 23.00069427], [68.91042328, 23.00069046], [68.91042328, 23.00124931], [68.91014099, 23.00124931], [68.91014099, 23.0015316], [68.9098587, 23.0015316], [68.9098587, 23.00181007], [68.90930939, 23.00180626], [68.90930176, 23.00208282], [68.9090271, 23.00208282], [68.9090271, 23.00235939], [68.90875244, 23.00235939], [68.90875244, 23.00292015], [68.90847015, 23.00291634], [68.90847015, 23.00347137], [68.9081955, 23.00347137], [68.90820313, 23.00375175], [68.90791321, 23.00375175], [68.90791321, 23.00403023], [68.90763855, 23.00402832], [68.90763855, 23.00430489], [68.90736389, 23.00430489], [68.90736389, 23.00458145], [68.9070816, 23.00458145], [68.9070816, 23.00486374], [68.90680695, 23.00485992], [68.90680695, 23.00542068], [68.90651703, 23.00542068], [68.90651703, 23.00570107], [68.90625, 23.00569534], [68.90625, 23.00597382], [68.90597534, 23.00597382], [68.90598297, 23.00625038], [68.90569305, 23.00625038], [68.90569305, 23.00653076], [68.90486145, 23.00653076], [68.90486145, 23.00681114], [68.9043045, 23.00680542], [68.9043045, 23.0070858], [68.90374756, 23.00708008], [68.90374756, 23.00736046], [68.9034729, 23.00736046], [68.9034729, 23.00764084], [68.90291595, 23.00764084], [68.90291595, 23.00792122], [68.9026413, 23.0079174], [68.9026413, 23.00819588], [68.90208435, 23.00819588], [68.90208435, 23.00847244], [68.90180206, 23.00847054], [68.90180206, 23.00875092], [68.90125275, 23.00875092], [68.90125275, 23.00902939], [68.90097046, 23.00902939], [68.90097046, 23.01098061], [68.89985657, 23.01098061], [68.89985657, 23.01013947], [68.90014648, 23.01013947], [68.90013885, 23.00930786], [68.90040588, 23.00930977], [68.90040588, 23.00875092], [68.90013885, 23.00875092], [68.90013885, 23.00847244], [68.90041351, 23.00847244], [68.90041351, 23.00819588], [68.90097046, 23.00819588], [68.90097046, 23.0079174], [68.90125275, 23.00792122], [68.90125275, 23.00764084], [68.90180206, 23.00764084], [68.90180206, 23.00736046], [68.90207672, 23.00736046], [68.90207672, 23.00708008], [68.90235901, 23.0070858], [68.90235901, 23.00680542], [68.9026413, 23.00681114], [68.9026413, 23.00653076], [68.90291595, 23.00653076], [68.90291595, 23.00625038], [68.90319061, 23.00625038], [68.90319061, 23.00597], [68.9034729, 23.00597382], [68.9034729, 23.00569534], [68.90374756, 23.00570107], [68.90374756, 23.00542068], [68.90235901, 23.00542068], [68.90235901, 23.00570107], [68.90208435, 23.00569534], [68.90208435, 23.00597382], [68.9015274, 23.00597], [68.9015274, 23.00625038], [68.90097046, 23.00625038], [68.90097046, 23.00653076], [68.90014648, 23.00653076], [68.90014648, 23.00681114], [68.89958191, 23.00680542], [68.89958191, 23.0070858], [68.89902496, 23.0070858], [68.89903259, 23.00736046], [68.89875031, 23.00736046], [68.89875031, 23.00764084], [68.89819336, 23.00764084], [68.89819336, 23.00792122], [68.8979187, 23.0079174], [68.8979187, 23.00819588], [68.89736176, 23.00819588], [68.89736176, 23.00847244], [68.8970871, 23.00847054], [68.8970871, 23.00875092], [68.89653015, 23.00875092], [68.89653015, 23.00902939], [68.89624786, 23.00902939], [68.89624786, 23.00930977], [68.89569092, 23.00930786], [68.89569092, 23.00958252], [68.89541626, 23.00958061], [68.89541626, 23.00986099], [68.89485931, 23.00986099], [68.89485931, 23.01013947], [68.89430237, 23.01013947], [68.89430237, 23.01041985], [68.89375305, 23.01041794], [68.89375305, 23.0106945], [68.89319611, 23.01069069], [68.89319611, 23.01098061], [68.89263916, 23.01098061], [68.89263916, 23.01124954], [68.89208221, 23.01124954], [68.89208221, 23.01152992], [68.89180756, 23.01152992], [68.89180756, 23.0118103], [68.89125061, 23.01180649], [68.89125061, 23.01208305], [68.89097595, 23.01208305], [68.89097595, 23.01236153], [68.89068604, 23.01235962], [68.89068604, 23.01263809], [68.89013672, 23.01263809], [68.89013672, 23.01292038], [68.88986206, 23.01292038], [68.88986206, 23.01320076], [68.88903046, 23.01319504], [68.88903046, 23.0134716], [68.88819122, 23.0134697], [68.88819122, 23.01374817], [68.88764191, 23.01374817], [68.88764191, 23.01402855], [68.88709259, 23.01402092], [68.88709259, 23.01431084], [68.88652802, 23.01430511], [68.88652802, 23.01458359], [68.88597107, 23.01458359], [68.88597107, 23.01486015], [68.88569641, 23.01485825], [68.88569641, 23.01514244], [68.88514709, 23.01514244], [68.88514709, 23.01542282], [68.88458252, 23.0154171], [68.88458252, 23.01569366], [68.88430786, 23.01569366], [68.88430786, 23.01597023], [68.88375092, 23.01597023], [68.88375092, 23.01625252], [68.88346863, 23.01625252], [68.88346863, 23.0165329], [68.88291931, 23.0165329], [68.88291931, 23.01680946], [68.88236237, 23.01680565], [68.88236237, 23.01708221], [68.88208008, 23.01708031], [68.88208008, 23.01736259], [68.88153076, 23.01736259], [68.88153076, 23.01764107], [68.88096619, 23.01764107], [68.88096619, 23.01791954], [68.88069153, 23.01791763], [68.88069153, 23.01819229], [68.88014221, 23.01819229], [68.88014221, 23.01847458], [68.8795929, 23.01847076], [68.8795929, 23.01875114], [68.87902069, 23.01875114], [68.87902069, 23.01902962], [68.87874603, 23.01902962], [68.87874603, 23.01931], [68.87819672, 23.01930618], [68.87819672, 23.01958466], [68.87763977, 23.01958084], [68.87763977, 23.01986122], [68.87708282, 23.01986122], [68.87708282, 23.02015114], [68.87652588, 23.02015114], [68.87652588, 23.02042007], [68.87596893, 23.02041626], [68.87596893, 23.02069473], [68.87569427, 23.02069473], [68.87569427, 23.0209713], [68.87513733, 23.02096939], [68.87513733, 23.02124977], [68.87458038, 23.02124977], [68.87458038, 23.02153015], [68.87403107, 23.02152824], [68.87403107, 23.02180672], [68.87347412, 23.02180672], [68.87347412, 23.02208328], [68.87319183, 23.02207947], [68.87319183, 23.02264023], [68.87291718, 23.02264023], [68.87291718, 23.02292061], [68.87264252, 23.02291679], [68.87264252, 23.02347183], [68.87236023, 23.02346992], [68.87236023, 23.02375031], [68.87180328, 23.02375031], [68.87180328, 23.02403069], [68.87152863, 23.02403069], [68.87152863, 23.02431107], [68.87097168, 23.02430534], [68.87097168, 23.02458382], [68.87069702, 23.02458], [68.87069702, 23.02486038], [68.87014008, 23.02486038], [68.87014008, 23.02514076], [68.86985779, 23.02514076], [68.86985779, 23.02542114], [68.86930847, 23.02541733], [68.86930847, 23.02569389], [68.86902618, 23.02569389], [68.86902618, 23.02597237], [68.86846924, 23.02596092], [68.86846924, 23.02625084], [68.86763763, 23.02625084], [68.86763763, 23.02653122], [68.86708069, 23.02653122], [68.86708069, 23.02680969], [68.86624908, 23.02680588], [68.86624908, 23.02708244], [68.86569214, 23.02708054], [68.86569214, 23.02736092], [68.86541748, 23.02736092], [68.86541748, 23.02763939], [68.86486053, 23.02763939], [68.86486053, 23.02792168], [68.86458588, 23.02791595], [68.86458588, 23.02819443], [68.86402893, 23.02819443], [68.86402893, 23.0284729], [68.86374664, 23.02846909], [68.86374664, 23.02874947], [68.86319733, 23.02874947], [68.86319733, 23.02902794], [68.86292267, 23.0290184], [68.86292267, 23.02931023], [68.86235809, 23.02930641], [68.86235809, 23.02958107], [68.86208344, 23.02958107], [68.86208344, 23.02985954], [68.86152649, 23.02985954], [68.86152649, 23.03014183], [68.86068726, 23.03014183], [68.86068726, 23.0304203], [68.86013794, 23.0304203], [68.86013794, 23.03070068], [68.85958099, 23.03069305], [68.85958099, 23.03097343], [68.85901642, 23.03096962], [68.85901642, 23.03125191], [68.85819244, 23.03125191], [68.85819244, 23.03153038], [68.85764313, 23.03153038], [68.85764313, 23.03181076], [68.85708618, 23.03181076], [68.85708618, 23.03209114], [68.85680389, 23.0320816], [68.85680389, 23.03236389], [68.85624695, 23.03236008], [68.85624695, 23.03264046], [68.85597229, 23.03264046], [68.85597229, 23.03292084], [68.85541534, 23.03291702], [68.85541534, 23.0331955], [68.85514069, 23.0331955], [68.85514069, 23.03347206], [68.85457611, 23.03347015], [68.85457611, 23.03375053], [68.85430908, 23.03375053], [68.85430908, 23.03403091], [68.85375214, 23.03403091], [68.85375214, 23.03430939], [68.85319519, 23.03430557], [68.85319519, 23.03458595], [68.85263824, 23.03458023], [68.85263824, 23.03486061], [68.8520813, 23.03486061], [68.8520813, 23.03515053], [68.85151672, 23.03515053], [68.85151672, 23.03541946], [68.85097504, 23.03541756], [68.85097504, 23.03569412], [68.85069275, 23.03569412], [68.85069275, 23.0359726], [68.8501358, 23.03597069], [68.8501358, 23.03625107], [68.84958649, 23.03625107], [68.84958649, 23.03652954], [68.84929657, 23.03652954], [68.84929657, 23.03680992], [68.84874725, 23.03680611], [68.84874725, 23.03708267], [68.8484726, 23.03708076], [68.8484726, 23.03736115], [68.84791565, 23.03736115], [68.84792328, 23.03763962], [68.8473587, 23.03763962], [68.8473587, 23.03791809], [68.84708405, 23.03791618], [68.84708405, 23.03819466], [68.8465271, 23.03819466], [68.8465271, 23.03847313], [68.84625244, 23.03847122], [68.84625244, 23.03874969], [68.84570313, 23.03874969], [68.84570313, 23.03902817], [68.84513855, 23.03902817], [68.84513855, 23.03930473], [68.84486389, 23.03930473], [68.84486389, 23.03958321], [68.84430695, 23.03958321], [68.84430695, 23.03986168], [68.84401703, 23.03985977], [68.84401703, 23.04013824], [68.84348297, 23.04013824], [68.84348297, 23.04042053], [68.84291077, 23.04042053], [68.84291077, 23.04070091], [68.84208679, 23.04069519], [68.84208679, 23.04097176], [68.84152985, 23.04096031], [68.84152985, 23.04124832], [68.84124756, 23.04124832], [68.84124756, 23.04153061], [68.8409729, 23.04153061], [68.8409729, 23.0418129], [68.83930206, 23.04180527], [68.83930206, 23.04208374], [68.83875275, 23.04208183], [68.83875275, 23.04236031], [68.83790588, 23.04236031], [68.83790588, 23.04264259], [68.8373642, 23.04263878], [68.8373642, 23.04347038], [68.83597565, 23.04347038], [68.83598328, 23.04375267], [68.83569336, 23.04375267], [68.83569336, 23.04403114], [68.83513641, 23.04403114], [68.83513641, 23.04432106], [68.83486176, 23.0443058], [68.83486176, 23.04458427], [68.83429718, 23.04458046], [68.83430481, 23.04486275], [68.83403778, 23.04486275], [68.83403778, 23.04514122], [68.83347321, 23.04514122], [68.83347321, 23.04541969], [68.83319092, 23.04541588], [68.83319092, 23.04569244], [68.83291626, 23.04569244], [68.83291626, 23.04597473], [68.83235931, 23.04597282], [68.83235931, 23.04624939], [68.83207703, 23.04624939], [68.83207703, 23.04652977], [68.83180237, 23.04652977], [68.83180237, 23.04681015], [68.83125305, 23.04681015], [68.83125305, 23.04709053], [68.83097076, 23.04708481], [68.83097076, 23.04736137], [68.83069611, 23.04735947], [68.83069611, 23.04763985], [68.83013916, 23.04763985], [68.83013916, 23.04792023], [68.8298645, 23.04791641], [68.8298645, 23.04819679], [68.82958221, 23.04819679], [68.82958221, 23.04847145], [68.82902527, 23.04847145], [68.8290329, 23.04874992], [68.82875061, 23.04874992], [68.82875061, 23.0490303], [68.82818604, 23.0490303], [68.82818604, 23.04931068], [68.82791901, 23.04930687], [68.82791901, 23.04958344], [68.82736206, 23.04958344], [68.82736206, 23.04986191], [68.82680511, 23.04986191], [68.82680511, 23.05013847], [68.82653046, 23.05013084], [68.82653046, 23.05042076], [68.82597351, 23.05041695], [68.82596588, 23.0506897], [68.82541656, 23.05069542], [68.82541656, 23.05097198], [68.82514191, 23.05097008], [68.82514191, 23.05125046], [68.82459259, 23.05125046], [68.82459259, 23.05153084], [68.82430267, 23.05153084], [68.82430267, 23.05181122], [68.82375336, 23.0518055], [68.82375336, 23.05208397], [68.82347107, 23.05208015], [68.82347107, 23.05236053], [68.82290649, 23.05236053], [68.82290649, 23.05264091], [68.82263947, 23.05264091], [68.82263947, 23.05291748], [68.82208252, 23.05291748], [68.82208252, 23.05319405], [68.82152557, 23.05319405], [68.82152557, 23.05347252], [68.82125092, 23.05347061], [68.82125092, 23.05374908], [68.82068634, 23.05374908], [68.82068634, 23.05403137], [68.82013702, 23.05403137], [68.82013702, 23.05431175], [68.81986237, 23.05430603], [68.81986237, 23.0545826], [68.81930542, 23.0545826], [68.81931305, 23.05514145], [68.81874084, 23.05514145], [68.81874084, 23.05542183], [68.81847382, 23.05541611], [68.81847382, 23.05569458], [68.81791687, 23.05569458], [68.81791687, 23.05597115], [68.81764221, 23.05596924], [68.81764221, 23.05626106], [68.8170929, 23.05626106], [68.8170929, 23.05653191], [68.81680298, 23.05652809], [68.81680298, 23.05680466], [68.81652832, 23.05680466], [68.81652832, 23.05708122], [68.81847382, 23.05708122], [68.81847382, 23.05680466], [68.81903076, 23.05680466], [68.81903076, 23.05652809], [68.81958008, 23.05653191], [68.81958008, 23.05626106], [68.81986237, 23.05626106], [68.81986237, 23.05596924], [68.82013702, 23.05597115], [68.82013702, 23.05569458], [68.82069397, 23.05569458], [68.82069397, 23.05514145], [68.82096863, 23.05514145], [68.82096863, 23.05485916], [68.8215332, 23.05485916], [68.82152557, 23.0545826], [68.82180786, 23.0545826], [68.82180786, 23.05430603], [68.82319641, 23.05430603], [68.82319641, 23.0545826], [68.82347107, 23.05458069], [68.82347107, 23.05485916], [68.82319641, 23.05485916], [68.82319641, 23.05514145], [68.82208252, 23.05514145], [68.82208252, 23.05542183], [68.82152557, 23.05541611], [68.82152557, 23.05569458], [68.82125092, 23.05569458], [68.82125092, 23.05597115], [68.82096863, 23.05596924], [68.82096863, 23.05626106], [68.82068634, 23.05626106], [68.82068634, 23.05653191], [68.82041931, 23.05652809], [68.82041931, 23.05680466], [68.82013702, 23.05680466], [68.82013702, 23.05708122], [68.81986237, 23.05708122], [68.81986237, 23.05736351], [68.81958008, 23.0573597], [68.81958008, 23.05764008], [68.81931305, 23.05764008], [68.81931305, 23.05792046], [68.81735992, 23.05792046], [68.81735992, 23.05820084], [68.81652832, 23.05820084], [68.81652832, 23.05792046], [68.81624603, 23.05792046], [68.81624603, 23.05820084], [68.81569672, 23.05819511], [68.81569672, 23.05847359], [68.8154068, 23.05846977], [68.8154068, 23.05875015], [68.81513977, 23.05875015], [68.81513977, 23.05903053], [68.81458282, 23.05903053], [68.81458282, 23.05932045], [68.81430817, 23.05932045], [68.81430817, 23.05986023], [68.81458282, 23.05986023], [68.81458282, 23.06069565], [68.81485748, 23.06068993], [68.81485748, 23.06125069], [68.81513977, 23.06125069], [68.81513977, 23.06153107], [68.8154068, 23.06153107], [68.8154068, 23.06180954], [68.81569672, 23.06180954], [68.81569672, 23.06291962], [68.81597137, 23.06291771], [68.81597137, 23.06347275], [68.81569672, 23.06347084], [68.81569672, 23.06375122], [68.81597137, 23.06375122], [68.81597137, 23.06430817], [68.81569672, 23.06430626], [68.81569672, 23.0648613], [68.8154068, 23.06485939], [68.8154068, 23.06541824], [68.81513977, 23.06541824], [68.81513977, 23.06624985], [68.81485748, 23.06624985], [68.81485748, 23.06680489], [68.81458282, 23.06680489], [68.81458282, 23.06736183], [68.81430817, 23.06736183], [68.81430817, 23.06708336], [68.81402588, 23.06708336], [68.81402588, 23.06652832], [68.81430817, 23.06652832], [68.81430817, 23.06624985], [68.81402588, 23.06624985], [68.81402588, 23.06541824], [68.81430817, 23.06541824], [68.81430817, 23.06485939], [68.81458282, 23.0648613], [68.81458282, 23.06458282], [68.81485748, 23.06458282], [68.81485748, 23.06319427], [68.81458282, 23.06319427], [68.81458282, 23.06291771], [68.81430817, 23.06291962], [68.81430817, 23.06264114], [68.81402588, 23.06264114], [68.81402588, 23.06236076], [68.81375122, 23.06236076], [68.81375122, 23.06207085], [68.81346893, 23.0620842], [68.81346893, 23.06180573], [68.81318665, 23.06180954], [68.81318665, 23.06153107], [68.81263733, 23.06153107], [68.81263733, 23.06125069], [68.81236267, 23.06125069], [68.81236267, 23.06097031], [68.81208038, 23.06097221], [68.81208038, 23.06069565], [68.80819702, 23.06069565], [68.80819702, 23.06097221], [68.80735779, 23.06097031], [68.80735779, 23.06125069], [68.80652618, 23.06125069], [68.80652618, 23.06153107], [68.80596924, 23.06153107], [68.80596924, 23.06180954], [68.80513763, 23.06180954], [68.80513763, 23.06236076], [68.80458069, 23.06236076], [68.80458069, 23.06264114], [68.80430603, 23.06264114], [68.80430603, 23.06291962], [68.80374908, 23.06291771], [68.80374908, 23.06319427], [68.80291748, 23.06319427], [68.80291748, 23.06347275], [68.80264282, 23.06347084], [68.80264282, 23.06375122], [68.80208588, 23.06375122], [68.80208588, 23.06402969], [68.80179596, 23.06402969], [68.80179596, 23.06430817], [68.80152893, 23.06430626], [68.80152893, 23.06458282], [68.80069733, 23.06458282], [68.80069733, 23.0648613], [68.80041504, 23.0648613], [68.80041504, 23.06513977], [68.79985809, 23.06513023], [68.79985809, 23.06541824], [68.79958344, 23.06541634], [68.79958344, 23.06569481], [68.79902649, 23.06569481], [68.79902649, 23.06597137], [68.79875183, 23.06596947], [68.79875183, 23.06624985], [68.79818726, 23.06624985], [68.79818726, 23.06652832], [68.79763794, 23.06652832], [68.79763794, 23.06680489], [68.79708099, 23.06680489], [68.79708099, 23.06708336], [68.79624939, 23.06708336], [68.79624939, 23.06736183], [68.79569244, 23.06735992], [68.79569244, 23.0676384], [68.79514313, 23.0676384], [68.79514313, 23.06792068], [68.79458618, 23.06792068], [68.79458618, 23.06819916], [68.79402924, 23.06819534], [68.79402924, 23.06847191], [68.79374695, 23.06846809], [68.79374695, 23.06875229], [68.79319763, 23.06875229], [68.79319763, 23.06903267], [68.79264069, 23.06903267], [68.79264069, 23.06931114], [68.79208374, 23.06930542], [68.79208374, 23.06958389], [68.79180145, 23.06958008], [68.79180145, 23.06986046], [68.79125214, 23.06986046], [68.79125214, 23.07014275], [68.79070282, 23.07014275], [68.79070282, 23.07042122], [68.79013824, 23.0704174], [68.79013824, 23.07069206], [68.7895813, 23.07069206], [68.7895813, 23.07097054], [68.78901672, 23.07097054], [68.78901672, 23.07126045], [68.78875732, 23.07126045], [68.78875732, 23.07152939], [68.78819275, 23.07152939], [68.78819275, 23.07180977], [68.7876358, 23.07180595], [68.7876358, 23.07208443], [68.78708649, 23.07208061], [68.78708649, 23.0723629], [68.78624725, 23.0723629], [68.78624725, 23.07263947], [68.78542328, 23.07263947], [68.78542328, 23.07291985], [68.7848587, 23.07291412], [68.7848587, 23.0731945], [68.7840271, 23.0731945], [68.7840271, 23.07347488], [68.7831955, 23.07347488], [68.78320313, 23.07374954], [68.78235626, 23.07374954], [68.78235626, 23.07402992], [68.78125, 23.07402802], [68.78125, 23.07430649], [68.7804184, 23.07430649], [68.7804184, 23.07458305], [68.77958679, 23.07458305], [68.77958679, 23.07486153], [68.77874756, 23.07485962], [68.77874756, 23.07514], [68.7776413, 23.07514], [68.7776413, 23.07542038], [68.77680206, 23.07542038], [68.77680206, 23.07570076], [68.7756958, 23.07569695], [68.7756958, 23.0759716], [68.77485657, 23.0759697], [68.7748642, 23.07625008], [68.77375793, 23.07625008], [68.77375793, 23.07653046], [68.77263641, 23.07653046], [68.77263641, 23.07681084], [68.77153015, 23.07680511], [68.77153015, 23.07708359], [68.77041626, 23.07708359], [68.77041626, 23.07736206], [68.76902771, 23.07736015], [68.76902771, 23.07764053], [68.76790619, 23.07764053], [68.76790619, 23.07792091], [68.76680756, 23.0779171], [68.76680756, 23.07819366], [68.76579285, 23.07819366], [68.76541901, 23.07819366], [68.76541901, 23.07847214], [68.76430511, 23.07847214], [68.76431274, 23.07875061], [68.76235962, 23.07875061], [68.76235962, 23.07902908], [68.76180267, 23.07902908], [68.76180267, 23.07930756], [68.76125336, 23.07930565], [68.76125336, 23.07958412], [68.76097107, 23.07958031], [68.76097107, 23.07986069], [68.76040649, 23.07986069], [68.76040649, 23.08013916], [68.75985718, 23.08013916], [68.75985718, 23.08042145], [68.75930786, 23.08041763], [68.75930786, 23.0806942], [68.75902557, 23.0806942], [68.75902557, 23.08097267], [68.75846863, 23.08097076], [68.75846863, 23.08124924], [68.75818634, 23.08124924], [68.75818634, 23.08153152], [68.75791931, 23.08153152], [68.75791931, 23.0818119], [68.75736237, 23.0818119], [68.75736237, 23.08235931], [68.75708008, 23.08235931], [68.75708008, 23.08292007], [68.75680542, 23.08291626], [68.75680542, 23.08346939], [68.75653076, 23.08346939], [68.75653076, 23.08403015], [68.75624847, 23.08402824], [68.75624847, 23.08430481], [68.75541687, 23.08430481], [68.75541687, 23.08458138], [68.75485992, 23.08458138], [68.75485992, 23.08486366], [68.75402832, 23.08485985], [68.75402832, 23.08514023], [68.75374603, 23.08514023], [68.75374603, 23.08542061], [68.75347137, 23.08541679], [68.75347137, 23.08597374], [68.75319672, 23.08597374], [68.75319672, 23.08625031], [68.7529068, 23.08624268], [68.7529068, 23.08653069], [68.75263214, 23.08653069], [68.75263214, 23.08681107], [68.75208282, 23.08680534], [68.75208282, 23.08708572], [68.75180817, 23.08708], [68.75180817, 23.08736038], [68.75152588, 23.08736038], [68.75152588, 23.08764076], [68.75125122, 23.08764076], [68.75125122, 23.08792114], [68.75069427, 23.08791733], [68.75069427, 23.0881958], [68.75041962, 23.0881958], [68.75041962, 23.08847237], [68.75013733, 23.08847046], [68.75013733, 23.08875084], [68.74986267, 23.08875084], [68.74986267, 23.08903122], [68.74958038, 23.0890274], [68.74958038, 23.08930588], [68.74930573, 23.08930588], [68.74931335, 23.08986092], [68.74903107, 23.08986092], [68.74903107, 23.09013939], [68.74874878, 23.09013939], [68.74874878, 23.09041977], [68.74847412, 23.09041786], [68.74847412, 23.09069443], [68.74819183, 23.09069443], [68.74819183, 23.0909729], [68.74791718, 23.09097099], [68.74791718, 23.09124947], [68.74736023, 23.09124947], [68.74736023, 23.09152985], [68.7470932, 23.09152985], [68.7470932, 23.09181023], [68.74652863, 23.09180641], [68.74652863, 23.09208298], [68.74624634, 23.09208298], [68.74624634, 23.09236145], [68.74597168, 23.09235954], [68.74597168, 23.09263992], [68.74569702, 23.09263992], [68.74569702, 23.0929184], [68.7454071, 23.0929184], [68.7454071, 23.09320068], [68.74514008, 23.09319496], [68.74514008, 23.09347153], [68.74485779, 23.09346962], [68.74485779, 23.09374809], [68.74458313, 23.09374809], [68.74458313, 23.09402847], [68.74430847, 23.09402847], [68.74430847, 23.09431076], [68.74402618, 23.09430504], [68.74402618, 23.09458351], [68.74375153, 23.09458351], [68.74375153, 23.09486008], [68.74402618, 23.09486008], [68.74402618, 23.09517097], [68.74402618, 23.09543037], [68.74375153, 23.09541702], [68.74375153, 23.09597015], [68.74346161, 23.09597015], [68.74346161, 23.09625244], [68.74291992, 23.09625244], [68.74291992, 23.09653282], [68.74236298, 23.09653282], [68.74236298, 23.09680939], [68.74180603, 23.09680557], [68.74180603, 23.09708214], [68.74153137, 23.09708023], [68.74153137, 23.09736061], [68.7409668, 23.09736061], [68.7409668, 23.0976429], [68.74041748, 23.0976429], [68.74041748, 23.09791946], [68.74013519, 23.09791756], [68.74013519, 23.09819221], [68.73986053, 23.09819221], [68.73986053, 23.0984745], [68.73958588, 23.09847069], [68.73958588, 23.09875107], [68.73929596, 23.09875107], [68.73929596, 23.09902954], [68.73874664, 23.09902954], [68.73874664, 23.09930992], [68.73847198, 23.09930611], [68.73847198, 23.09958458], [68.73819733, 23.09958076], [68.73819733, 23.09986115], [68.73791504, 23.09986115], [68.73791504, 23.10013962], [68.73764801, 23.10013962], [68.73764801, 23.10042], [68.73735809, 23.10041618], [68.73735809, 23.10069466], [68.73708344, 23.10069466], [68.73708344, 23.10097313], [68.73652649, 23.10097313], [68.73652649, 23.10124969], [68.73625183, 23.10124016], [68.73625183, 23.10153008], [68.73596954, 23.10152817], [68.73596954, 23.10180664], [68.73569489, 23.10180664], [68.73569489, 23.10208321], [68.73542023, 23.10208321], [68.73542023, 23.10236168], [68.73486328, 23.10235977], [68.73486328, 23.10264015], [68.73458862, 23.10264015], [68.73458862, 23.10292053], [68.73430634, 23.10292053], [68.73430634, 23.10320091], [68.73374939, 23.10319519], [68.73374939, 23.10347176], [68.7334671, 23.10346985], [68.7334671, 23.10375023], [68.73319244, 23.10375023], [68.73319244, 23.10403061], [68.7326355, 23.1040287], [68.7326355, 23.10430527], [68.73236084, 23.10430527], [68.73236084, 23.10458374], [68.73208618, 23.10457993], [68.73208618, 23.10486031], [68.73179626, 23.10486031], [68.73179626, 23.10514069], [68.73124695, 23.10514069], [68.73124695, 23.10542107], [68.73097229, 23.10541725], [68.73097229, 23.10569382], [68.73069763, 23.10569382], [68.73069763, 23.10597229], [68.73041534, 23.10597229], [68.73042297, 23.10625076], [68.7298584, 23.10625076], [68.7298584, 23.10652924], [68.72957611, 23.10652924], [68.72957611, 23.10680962], [68.72930908, 23.1068058], [68.72930908, 23.10708427], [68.72902679, 23.10708046], [68.72902679, 23.10737038], [68.72846222, 23.10737038], [68.72846222, 23.10763931], [68.72820282, 23.10763931], [68.72820282, 23.1079216], [68.72763824, 23.10791588], [68.72763824, 23.10819435], [68.72736359, 23.10819435], [68.72736359, 23.10847282], [68.72680664, 23.10847092], [68.72680664, 23.10874939], [68.72651672, 23.10874939], [68.72651672, 23.10903168], [68.72598267, 23.10903168], [68.72598267, 23.10931015], [68.72569275, 23.10930634], [68.72569275, 23.1095829], [68.7251358, 23.1095829], [68.7251358, 23.10985947], [68.72458649, 23.10985947], [68.72458649, 23.11014175], [68.72402954, 23.11014175], [68.72402954, 23.11042976], [68.72374725, 23.11041641], [68.72374725, 23.11069489], [68.72319794, 23.11069489], [68.72319794, 23.11097145], [68.72264099, 23.11097145], [68.72264862, 23.11125183], [68.72180939, 23.11125183], [68.72180176, 23.1115303], [68.72125244, 23.1115303], [68.72125244, 23.11181068], [68.72097015, 23.11180305], [68.72097015, 23.11236382], [68.72070312, 23.11236], [68.72070312, 23.11292076], [68.72041321, 23.11291695], [68.72041321, 23.11318016], [68.72013855, 23.11319542], [68.72013855, 23.11347389], [68.71985626, 23.11347008], [68.71985626, 23.11375046], [68.7195816, 23.11375046], [68.7195816, 23.11403084], [68.71901703, 23.11403084], [68.71901703, 23.11431122], [68.71847534, 23.1143055], [68.71847534, 23.11458588], [68.71819305, 23.11458015], [68.71819305, 23.11486053], [68.7179184, 23.11486053], [68.7179184, 23.11514091], [68.71736145, 23.11514091], [68.71736145, 23.11541939], [68.71708679, 23.11541748], [68.71708679, 23.11569595], [68.7168045, 23.11569595], [68.7168045, 23.11597252], [68.71652985, 23.11597252], [68.71652985, 23.11624908], [68.71624756, 23.11623955], [68.71624756, 23.11652946], [68.71569824, 23.11652946], [68.71569824, 23.11680984], [68.71541595, 23.11680794], [68.71541595, 23.1170826], [68.71485901, 23.11708069], [68.71485901, 23.11736107], [68.71457672, 23.11736107], [68.71457672, 23.11763954], [68.7140274, 23.11763954], [68.7140274, 23.11791992], [68.71375275, 23.11791611], [68.71375275, 23.11819458], [68.71347046, 23.11819458], [68.71347046, 23.11847305], [68.71290588, 23.11847115], [68.71290588, 23.11874962], [68.71263885, 23.11874962], [68.71263885, 23.11902809], [68.71208191, 23.11902809], [68.71208191, 23.11931038], [68.71180725, 23.11930466], [68.71180725, 23.11958313], [68.71125031, 23.11958313], [68.71125031, 23.1198616], [68.71098328, 23.1198597], [68.71098328, 23.12013817], [68.7104187, 23.12013817], [68.7104187, 23.12042046], [68.71013641, 23.12042046], [68.71013641, 23.12070084], [68.7095871, 23.12069511], [68.7095871, 23.12097168], [68.70929718, 23.12096977], [68.70929718, 23.12124825], [68.70819092, 23.12124825], [68.70819092, 23.12152863], [68.70791626, 23.12152863], [68.70791626, 23.12181091], [68.70735931, 23.12180519], [68.70735931, 23.12208366], [68.70707703, 23.12207985], [68.70707703, 23.12236977], [68.70680237, 23.12236977], [68.70680237, 23.12264252], [68.70625305, 23.12264252], [68.70625305, 23.1229229], [68.70597076, 23.12291718], [68.70597076, 23.12319374], [68.70569611, 23.12319374], [68.70569611, 23.12347031], [68.70513916, 23.12347031], [68.70513916, 23.12375259], [68.70485687, 23.12375259], [68.70485687, 23.12403107], [68.70430756, 23.12403107], [68.70430756, 23.12430954], [68.70402527, 23.12430573], [68.70402527, 23.12458229], [68.70347595, 23.12458038], [68.70347595, 23.12486267], [68.70318604, 23.12486267], [68.70318604, 23.12514114], [68.70291901, 23.12513924], [68.70291901, 23.1254158], [68.70236206, 23.1254158], [68.70236206, 23.12569237], [68.70207977, 23.12569237], [68.70207977, 23.12597466], [68.70181274, 23.12597084], [68.70181274, 23.12625122], [68.70153809, 23.12625122], [68.70153809, 23.12652969], [68.70096588, 23.12652969], [68.70096588, 23.12681007], [68.70069122, 23.12680626], [68.70069122, 23.12708473], [68.70014191, 23.12708473], [68.70014191, 23.1273613], [68.69985962, 23.12735939], [68.69985962, 23.12763977], [68.69930267, 23.12763977], [68.69930267, 23.12792015], [68.69902802, 23.12791634], [68.69902802, 23.12819672], [68.69847107, 23.12819672], [68.69847107, 23.12847137], [68.69763947, 23.12846947], [68.69763947, 23.12874985], [68.69680786, 23.12874985], [68.69680786, 23.12903023], [68.69652557, 23.12902832], [68.69652557, 23.12930679], [68.69596863, 23.12930679], [68.69596863, 23.12958336], [68.69541931, 23.12958336], [68.69541931, 23.12986183], [68.69513702, 23.12985992], [68.69513702, 23.1301403], [68.69458008, 23.1301403], [68.69458008, 23.13042068], [68.69403076, 23.13042068], [68.69403076, 23.13070107], [68.69374847, 23.13069534], [68.69374847, 23.13097191], [68.69319153, 23.13097], [68.69319153, 23.13125038], [68.69264221, 23.13125038], [68.69264221, 23.13153839], [68.69235229, 23.13153839], [68.69235229, 23.13181114], [68.69180298, 23.13180542], [68.69180298, 23.13208389], [68.69152832, 23.13208008], [68.69152832, 23.13236046], [68.69097137, 23.13236046], [68.69097137, 23.13264084], [68.6904068, 23.13264084], [68.6904068, 23.13292122], [68.69013977, 23.1329174], [68.69013977, 23.13319397], [68.68958282, 23.13319397], [68.68958282, 23.13347244], [68.68930817, 23.13347054], [68.68930817, 23.13375092], [68.68875122, 23.13375092], [68.68875122, 23.1340313], [68.68818665, 23.1340313], [68.68818665, 23.13431168], [68.68791962, 23.13430595], [68.68791962, 23.13458252], [68.68736267, 23.13458061], [68.68736267, 23.13485909], [68.68708038, 23.13485909], [68.68708038, 23.13513947], [68.6865387, 23.13513947], [68.6865387, 23.13542175], [68.68624878, 23.13541603], [68.68624878, 23.1356945], [68.68569183, 23.1356945], [68.68569183, 23.13597107], [68.68541718, 23.13596916], [68.68541718, 23.13624954], [68.68486023, 23.13624954], [68.68486023, 23.13653183], [68.6845932, 23.13653183], [68.6845932, 23.1368103], [68.68402863, 23.13680649], [68.68402863, 23.13708115], [68.68374634, 23.13708115], [68.68374634, 23.13736343], [68.68319702, 23.13735008], [68.68319702, 23.13764191], [68.6829071, 23.13764191], [68.6829071, 23.13792038], [68.68235779, 23.13792038], [68.68235779, 23.13820076], [68.68208313, 23.13819313], [68.68208313, 23.13847351], [68.68152618, 23.1384697], [68.68152618, 23.13875008], [68.68125153, 23.13875008], [68.68125153, 23.13903046], [68.68068695, 23.13903046], [68.68068695, 23.13931084], [68.68041992, 23.13930321], [68.68041992, 23.13958168], [68.67903137, 23.13958168], [68.67903137, 23.13986206], [68.67874908, 23.13986015], [68.67874908, 23.14014053], [68.67778015, 23.14013863], [68.67763519, 23.14013863], [68.67763519, 23.1402626], [68.67763519, 23.1404171], [68.6774292, 23.1404171], [68.67708588, 23.1404171], [68.67708588, 23.14069557], [68.67652893, 23.14069557], [68.67652893, 23.14097214], [68.67597198, 23.14097023], [68.67597198, 23.14125061], [68.67542267, 23.14125061], [68.67542267, 23.14153099], [68.67457581, 23.14153099], [68.67457581, 23.14180946], [68.67430878, 23.14180565], [68.67430878, 23.14208412], [68.67318726, 23.14208031], [68.67318726, 23.14236069], [68.67263794, 23.14236069], [68.67263794, 23.14264107], [68.67236328, 23.14264107], [68.67236328, 23.14291954], [68.67180634, 23.14291763], [68.67180634, 23.1431942], [68.67124939, 23.14319038], [68.67124939, 23.1434803], [68.67069244, 23.1434803], [68.67069244, 23.14375114], [68.67014313, 23.14375114], [68.67014313, 23.14402962], [68.66958618, 23.14402962], [68.66958618, 23.14430809], [68.66902924, 23.14430618], [68.66902924, 23.14458275], [68.66847229, 23.14458084], [68.66847229, 23.14486122], [68.66819763, 23.14486122], [68.66819763, 23.14513969], [68.66764069, 23.14513969], [68.66764069, 23.14541817], [68.66708374, 23.14541626], [68.66708374, 23.14569473], [68.66680908, 23.14569473], [68.66680908, 23.1459713], [68.66625214, 23.14596939], [68.66625214, 23.14624977], [68.66596985, 23.14624977], [68.66596985, 23.1465416], [68.6654129, 23.14652824], [68.6654129, 23.14680481], [68.66486359, 23.14680481], [68.66486359, 23.14708328], [68.66430664, 23.14708328], [68.66430664, 23.14736176], [68.66374969, 23.14735985], [68.66374969, 23.14763832], [68.66348267, 23.14763832], [68.66348267, 23.14792061], [68.66291809, 23.14792061], [68.66291809, 23.14819908], [68.66236115, 23.14819527], [68.66236115, 23.14847183], [68.66208649, 23.14846992], [68.66208649, 23.14875031], [68.66152954, 23.14875031], [68.66152954, 23.14903259], [68.6609726, 23.14903259], [68.6609726, 23.14931107], [68.66034698, 23.14930534], [68.66014099, 23.14930534], [68.66014099, 23.14948082], [68.66014099, 23.14958382], [68.65957642, 23.14958191], [68.65957642, 23.14986038], [68.6590271, 23.14986038], [68.6590271, 23.15014267], [68.65875244, 23.15014267], [68.65875244, 23.15042114], [68.65847015, 23.15041733], [68.65847015, 23.15069389], [68.6581955, 23.15069389], [68.6581955, 23.15097046], [68.65791321, 23.15097046], [68.65791321, 23.15125275], [68.65763855, 23.15125275], [68.65763855, 23.15153122], [68.65736389, 23.1515274], [68.65736389, 23.15208435], [68.6570816, 23.15208435], [68.6570816, 23.15236282], [68.65624237, 23.15234947], [68.65624237, 23.15263939], [68.65569305, 23.15263939], [68.65569305, 23.15291977], [68.6554184, 23.15291405], [68.6554184, 23.15319252], [68.65486145, 23.15319252], [68.65486145, 23.15347481], [68.65458679, 23.1534729], [68.65458679, 23.15374947], [68.65429688, 23.15374947], [68.65429688, 23.15402985], [68.65374756, 23.15402985], [68.65374756, 23.15431023], [68.6534729, 23.15430641], [68.6534729, 23.15458488], [68.65291595, 23.15458488], [68.65291595, 23.15486145], [68.6526413, 23.15485954], [68.6526413, 23.15513992], [68.65235901, 23.15513992], [68.65235901, 23.15571022], [68.65208435, 23.15569687], [68.65208435, 23.15597153], [68.65180206, 23.15596962], [68.65180206, 23.15625], [68.6515274, 23.15625], [68.6515274, 23.15681076], [68.65125275, 23.15680695], [68.65125275, 23.15708351], [68.65097046, 23.1570797], [68.65097046, 23.15764046], [68.6506958, 23.15764046], [68.6506958, 23.15792084], [68.65041351, 23.15791893], [68.65041351, 23.15819359], [68.65013885, 23.15818977], [68.65013885, 23.15847969], [68.64958191, 23.15847969], [68.64958191, 23.15875053], [68.64930725, 23.15875053], [68.64930725, 23.15903091], [68.64903259, 23.15903091], [68.64903259, 23.15930748], [68.64875031, 23.15930748], [68.64875031, 23.16013908], [68.6479187, 23.16013908], [68.6479187, 23.16041756], [68.64763641, 23.16041756], [68.64763641, 23.1609726], [68.64736176, 23.1609726], [68.64736176, 23.16152763], [68.6470871, 23.1615181], [68.6470871, 23.16181183], [68.64680481, 23.16180611], [68.64680481, 23.16208267], [68.64653015, 23.16208076], [68.64653015, 23.16235924], [68.64624786, 23.16235924], [68.64624786, 23.16263962], [68.64597321, 23.16263962], [68.64597321, 23.16292191], [68.64569092, 23.16291618], [68.64569092, 23.16319466], [68.64541626, 23.16319466], [68.64541626, 23.16347122], [68.6451416, 23.16346931], [68.6451416, 23.16403008], [68.64485931, 23.16402817], [68.64485931, 23.16430473], [68.64375305, 23.16430473], [68.64375305, 23.16486359], [68.64347076, 23.16485977], [68.64347076, 23.16514015], [68.64180756, 23.16514015], [68.64180756, 23.16542053], [68.64152527, 23.16541672], [68.64152527, 23.16597366], [68.64124298, 23.16596985], [68.64124298, 23.16653061], [68.64097595, 23.16653061], [68.64097595, 23.16681099], [68.64069366, 23.16680336], [68.64069366, 23.16708565], [68.64041901, 23.16707993], [68.64041901, 23.16736031], [68.63986206, 23.16736031], [68.63986206, 23.16765022], [68.63957977, 23.16765022], [68.63957977, 23.16792107], [68.63903046, 23.16791725], [68.63903046, 23.16819572], [68.63847351, 23.16819572], [68.63847351, 23.16847229], [68.63791656, 23.16847038], [68.63791656, 23.16875076], [68.63764191, 23.16875076], [68.63764191, 23.16903114], [68.63709259, 23.16903114], [68.63709259, 23.16930962], [68.63680267, 23.1693058], [68.63680267, 23.16958427], [68.63597107, 23.16958046], [68.63597107, 23.16986084], [68.63569641, 23.16986084], [68.63569641, 23.17014122], [68.63513947, 23.17014122], [68.63513947, 23.17041969], [68.63458252, 23.17041779], [68.63458252, 23.17069435], [68.63430786, 23.17069435], [68.63430786, 23.17097282], [68.63375092, 23.17097092], [68.63375092, 23.17124939], [68.63346863, 23.17124939], [68.63346863, 23.17152977], [68.63291931, 23.17152977], [68.63291931, 23.17180824], [68.63263702, 23.17180634], [68.63263702, 23.1720829], [68.63236237, 23.1720829], [68.63236237, 23.17236137], [68.63207245, 23.17235947], [68.63208008, 23.17263985], [68.63181305, 23.17263985], [68.63181305, 23.17291832], [68.63153076, 23.17291641], [68.63153076, 23.17319489], [68.63124847, 23.17319489], [68.63124847, 23.17347145], [68.63096619, 23.17346001], [68.63096619, 23.17374992], [68.63069153, 23.17374992], [68.63069153, 23.17431068], [68.63041687, 23.17430496], [68.63041687, 23.17597008], [68.63069153, 23.17597008], [68.63069153, 23.17652702], [68.63097382, 23.17652702], [68.63097382, 23.17708206], [68.63124847, 23.17708015], [68.63124847, 23.17736053], [68.63236237, 23.17736053], [68.63236237, 23.17764282], [68.63346863, 23.17764282], [68.63346863, 23.17736053], [68.6340332, 23.17736053], [68.63402557, 23.17708206], [68.63458252, 23.17708206], [68.63458252, 23.1768055], [68.63485718, 23.17681122], [68.63485718, 23.17625046], [68.63513947, 23.17625046], [68.63513947, 23.17597008], [68.63541412, 23.17597008], [68.63541412, 23.17569351], [68.63569641, 23.17569351], [68.63569641, 23.17541695], [68.63540649, 23.17542267], [68.63540649, 23.17513847], [68.63513947, 23.17513847], [68.63513947, 23.17485809], [68.63486481, 23.17486191], [68.63486481, 23.17458344], [68.63430786, 23.17458344], [68.63430786, 23.17430496], [68.63513947, 23.17431068], [68.63513947, 23.17291832], [68.63485718, 23.17291832], [68.63485718, 23.17263985], [68.63458252, 23.17263985], [68.63458252, 23.17208099], [68.63541412, 23.1720829], [68.63541412, 23.17236137], [68.63597107, 23.17235947], [68.63597107, 23.17263985], [68.63652802, 23.17263985], [68.63652802, 23.17235947], [68.63680267, 23.17236137], [68.63680267, 23.1720829], [68.63708496, 23.1720829], [68.63708496, 23.17180634], [68.63764191, 23.17180824], [68.63764191, 23.17152977], [68.63791656, 23.17152977], [68.63791656, 23.17124939], [68.63819885, 23.17124939], [68.63819122, 23.17097282], [68.63847351, 23.17097282], [68.63847351, 23.17069435], [68.63903046, 23.17069435], [68.63903046, 23.17041779], [68.63931274, 23.17041969], [68.63931274, 23.17014122], [68.63986206, 23.17014122], [68.63986206, 23.16986084], [68.64013672, 23.16986084], [68.64013672, 23.16958046], [68.64069366, 23.16958237], [68.64069366, 23.1693058], [68.64124298, 23.16930962], [68.64124298, 23.16903114], [68.64180756, 23.16903114], [68.64180756, 23.16875076], [68.64235687, 23.16875076], [68.64235687, 23.16847038], [68.64291382, 23.16847229], [68.64291382, 23.16819572], [68.64402771, 23.16819572], [68.64402771, 23.16791725], [68.64485931, 23.16792107], [68.64485931, 23.16765022], [68.64541626, 23.16765022], [68.64541626, 23.16736031], [68.64597321, 23.16736031], [68.64597321, 23.16707993], [68.64485931, 23.16708565], [68.64485931, 23.16680336], [68.64402771, 23.16681099], [68.64402771, 23.16653061], [68.64597321, 23.16653061], [68.64597321, 23.16625023], [68.64624786, 23.16625023], [68.64624786, 23.16596985], [68.64653015, 23.16597366], [68.64653015, 23.16569519], [68.64679718, 23.16570091], [68.64679718, 23.16542053], [68.64736938, 23.16542053], [68.64736938, 23.16485977], [68.64763641, 23.16486359], [68.64763641, 23.16430473], [68.6479187, 23.16430473], [68.6479187, 23.16374969], [68.64819336, 23.16374969], [68.64819336, 23.16346931], [68.64847565, 23.16347122], [68.64847565, 23.16291618], [68.64875031, 23.16292191], [68.64875031, 23.16263962], [68.64903259, 23.16263962], [68.64902496, 23.16208267], [68.64930725, 23.16208267], [68.64930725, 23.16180611], [68.64958191, 23.16181183], [68.64958191, 23.1615181], [68.6498642, 23.16152763], [68.6498642, 23.16124916], [68.65013885, 23.16124916], [68.65013885, 23.16097069], [68.65041351, 23.1609726], [68.65041351, 23.16069412], [68.6506958, 23.16069412], [68.6506958, 23.16041756], [68.65097046, 23.16041756], [68.65097046, 23.15930748], [68.65125275, 23.15930748], [68.65125275, 23.15903091], [68.6515274, 23.15903091], [68.6515274, 23.15847969], [68.65180206, 23.15847969], [68.65180206, 23.15818977], [68.65208435, 23.15819359], [68.65208435, 23.15791893], [68.65235901, 23.15792084], [68.65235901, 23.15764046], [68.6526413, 23.15764046], [68.6526413, 23.1570797], [68.65291595, 23.15708351], [68.65291595, 23.15680695], [68.65318298, 23.15681076], [68.65319824, 23.15653038], [68.6534729, 23.15653038], [68.6534729, 23.15596962], [68.65374756, 23.15597153], [68.65374756, 23.15569687], [68.65402985, 23.15571022], [68.65402985, 23.1554203], [68.65429688, 23.1554203], [68.65429688, 23.15513992], [68.65486145, 23.15513992], [68.65486145, 23.15485954], [68.65513611, 23.15486145], [68.65513611, 23.15430641], [68.6554184, 23.15431023], [68.6554184, 23.15374947], [68.65569305, 23.15374947], [68.65569305, 23.1534729], [68.65625, 23.15347481], [68.65625, 23.15319252], [68.65680695, 23.15319252], [68.65680695, 23.15291405], [68.65735626, 23.15291977], [68.65735626, 23.15263939], [68.65791321, 23.15263939], [68.65791321, 23.15234947], [68.65847015, 23.15236282], [68.65847015, 23.15208435], [68.65875244, 23.15208435], [68.65875244, 23.15180588], [68.65930939, 23.15180969], [68.65930939, 23.15153122], [68.65957642, 23.15153122], [68.65957642, 23.15125275], [68.66069794, 23.15125275], [68.66069794, 23.15153122], [68.66124725, 23.15153122], [68.66124725, 23.15180969], [68.66152954, 23.15180969], [68.66152954, 23.15153122], [68.66208649, 23.15153122], [68.66208649, 23.15125275], [68.66319275, 23.15125275], [68.66319275, 23.15097046], [68.66374969, 23.15097046], [68.66374969, 23.15069389], [68.66402435, 23.15069389], [68.66402435, 23.15041733], [68.6645813, 23.15042114], [68.6645813, 23.15014267], [68.66485596, 23.15014267], [68.66485596, 23.14986038], [68.66513824, 23.14986038], [68.66513824, 23.14958191], [68.6654129, 23.14958382], [68.6654129, 23.14930534], [68.66596985, 23.14931107], [68.66596985, 23.14903259], [68.66625214, 23.14903259], [68.66625214, 23.14875031], [68.66652679, 23.14875031], [68.66652679, 23.14846992], [68.66680908, 23.14847183], [68.66680908, 23.14819527], [68.66707611, 23.14819908], [68.66707611, 23.14792061], [68.6673584, 23.14792061], [68.6673584, 23.14763832], [68.66764069, 23.14763832], [68.66764069, 23.14735985], [68.66819763, 23.14736176], [68.66819763, 23.14708328], [68.66847229, 23.14708328], [68.66847229, 23.14680481], [68.66874695, 23.14680481], [68.66874695, 23.1459713], [68.67124939, 23.1459713], [68.67124939, 23.14569473], [68.67152405, 23.14569473], [68.67152405, 23.14541626], [68.67180634, 23.14541817], [68.67180634, 23.14486122], [68.67208099, 23.14486122], [68.67208099, 23.14430809], [68.67236328, 23.14430809], [68.67236328, 23.14402962], [68.67263794, 23.14402962], [68.67263794, 23.14375114], [68.67318726, 23.14375114], [68.67318726, 23.1434803], [68.67410278, 23.14347458], [68.67430878, 23.1434803], [68.67430878, 23.1431942], [68.67541504, 23.1431942], [68.67541504, 23.14291763], [68.67597198, 23.14291954], [68.67597198, 23.14264107], [68.67679596, 23.14264107], [68.67679596, 23.14236069], [68.67764282, 23.14236069], [68.67763519, 23.14208412], [68.67847443, 23.14208412], [68.67847443, 23.14180565], [68.67903137, 23.14180946], [68.67903137, 23.14153099], [68.67986298, 23.14153099], [68.67986298, 23.14180946], [68.68049622, 23.14180756], [68.68152618, 23.14180565], [68.68152618, 23.14208412], [68.68096924, 23.14208031], [68.68096924, 23.14236069], [68.68068695, 23.14236069], [68.68068695, 23.14264107], [68.68013763, 23.14264107], [68.68013763, 23.14291954], [68.67980194, 23.14291763], [68.67930603, 23.14291763], [68.67930603, 23.1431942], [68.67791748, 23.14319038], [68.67791748, 23.1434803], [68.67764282, 23.1434803], [68.67764282, 23.14402962], [68.67735291, 23.14402962], [68.67735291, 23.14486122], [68.67679596, 23.14486122], [68.67679596, 23.14513969], [68.67652893, 23.14513969], [68.67652893, 23.14541817], [68.67597198, 23.14541626], [68.67597198, 23.14569473], [68.67569733, 23.14569473], [68.67569733, 23.1459713], [68.67514038, 23.14596939], [68.67514038, 23.14624977], [68.67485809, 23.14624977], [68.67485809, 23.1465416], [68.67180634, 23.14652824], [68.67180634, 23.14680481], [68.67124939, 23.14680481], [68.67124939, 23.14708328], [68.6709671, 23.14707947], [68.6709671, 23.14763832], [68.67069244, 23.14763832], [68.67069244, 23.14819908], [68.67041779, 23.14819908], [68.67041779, 23.14875031], [68.67014313, 23.14875031], [68.67014313, 23.14931107], [68.66986084, 23.14930534], [68.66986084, 23.14958382], [68.66958618, 23.14958191], [68.66958618, 23.14986038], [68.66902924, 23.14986038], [68.66902924, 23.15014267], [68.66874695, 23.15014267], [68.66874695, 23.15042114], [68.66847229, 23.15041733], [68.66847229, 23.15069389], [68.66819763, 23.15069389], [68.66819763, 23.15097046], [68.66792297, 23.15097046], [68.66792297, 23.15153122], [68.66764069, 23.15153122], [68.66764069, 23.15180969], [68.6673584, 23.15180588], [68.6673584, 23.15208435], [68.66707611, 23.15208054], [68.66707611, 23.15263939], [68.66680908, 23.15263939], [68.66680908, 23.15291977], [68.66596985, 23.15291405], [68.66596985, 23.15319252], [68.66486359, 23.15319252], [68.66486359, 23.15347481], [68.66401672, 23.1534729], [68.66402435, 23.15374947], [68.66330719, 23.15374947], [68.66319275, 23.15374947], [68.66319275, 23.15385056], [68.66319275, 23.15402985], [68.66300964, 23.15402985], [68.65834808, 23.15402985], [68.65820313, 23.15402985], [68.65820313, 23.15431023], [68.65736389, 23.15430641], [68.65736389, 23.15458488], [68.6570816, 23.15458488], [68.6570816, 23.15486145], [68.65651703, 23.15485954], [68.65651703, 23.15513992], [68.65598297, 23.15513992], [68.65598297, 23.1554203], [68.65569305, 23.15541649], [68.65569305, 23.15597153], [68.65513611, 23.15596962], [68.65513611, 23.15625], [68.65486145, 23.15625], [68.65486145, 23.15736198], [68.65458679, 23.15736198], [68.65458679, 23.15958405], [68.65429688, 23.15958023], [68.65429688, 23.16013908], [68.65402985, 23.16013718], [68.65402985, 23.16069412], [68.65374756, 23.16069031], [68.65374756, 23.16124916], [68.6534729, 23.16124916], [68.6534729, 23.16181183], [68.65319824, 23.16181183], [68.65319824, 23.16235924], [68.65291595, 23.16235924], [68.65291595, 23.16263962], [68.6526413, 23.16263962], [68.6526413, 23.16292191], [68.65235901, 23.16291618], [68.65235901, 23.16347122], [68.65207672, 23.16346931], [68.65207672, 23.16374969], [68.65180206, 23.16374969], [68.65180206, 23.16403008], [68.6515274, 23.16402817], [68.6515274, 23.16430473], [68.65125275, 23.16430473], [68.65125275, 23.1645813], [68.65097046, 23.16457939], [68.65097046, 23.16514015], [68.6506958, 23.16514015], [68.6506958, 23.16542053], [68.65041351, 23.16541672], [68.65041351, 23.16597366], [68.6506958, 23.16597366], [68.6506958, 23.16708565], [68.65097046, 23.16707993], [68.65097046, 23.16736031], [68.6506958, 23.16736031], [68.6506958, 23.16765022], [68.65041351, 23.16763878], [68.65041351, 23.16819572], [68.65013885, 23.16819572], [68.65013885, 23.16847229], [68.64985657, 23.16847038], [68.64985657, 23.16903114], [68.64958191, 23.16902733], [68.64958191, 23.16922569], [68.64958191, 23.1693058], [68.64930725, 23.1693058], [68.64930725, 23.16942024], [68.64930725, 23.16986084], [68.64903259, 23.16986084], [68.64903259, 23.17014122], [68.64875031, 23.17013931], [68.64875031, 23.17069435], [68.64847565, 23.17069435], [68.64847565, 23.17097282], [68.64819336, 23.17097092], [68.64819336, 23.17124939], [68.6479187, 23.17124939], [68.6479187, 23.17097092], [68.64669037, 23.17097092], [68.64653015, 23.17097092], [68.64653015, 23.17124939], [68.6462326, 23.17124939], [68.64597321, 23.17124939], [68.64592743, 23.17147255], [68.64585876, 23.17152786], [68.6451416, 23.17152977], [68.6451416, 23.17180824], [68.64458466, 23.17180634], [68.64458466, 23.1720829], [68.64430237, 23.1720829], [68.64430237, 23.17236137], [68.64402771, 23.17235947], [68.64402771, 23.17263985], [68.64375305, 23.17263985], [68.64375305, 23.17319489], [68.64363098, 23.17319489], [68.64319611, 23.17319489], [68.64319611, 23.17347145], [68.64290619, 23.17346001], [68.64290619, 23.17374992], [68.64319611, 23.17374992], [68.64319611, 23.1740284], [68.64291382, 23.1740284], [68.64291382, 23.17486191], [68.64263916, 23.17486191], [68.64263916, 23.1756916], [68.6423645, 23.17569542], [68.6423645, 23.17652702], [68.64208221, 23.17651939], [68.64208221, 23.17736053], [68.64180756, 23.17736053], [68.64180756, 23.17819214], [68.6415329, 23.17819023], [68.6415329, 23.1787529], [68.64124298, 23.1787529], [68.64124298, 23.17930984], [68.64097595, 23.17930984], [68.64097595, 23.17959023], [68.64068604, 23.17959023], [68.64068604, 23.17986107], [68.64041901, 23.17986107], [68.64041901, 23.18041992], [68.64013672, 23.1804142], [68.64013672, 23.18069458], [68.63986206, 23.18069458], [68.63986206, 23.18097305], [68.63957977, 23.18097115], [68.63957977, 23.18153], [68.63930511, 23.18152809], [68.63930511, 23.18180656], [68.63903046, 23.18180656], [68.63903046, 23.18208313], [68.63847351, 23.18208313], [68.63847351, 23.1823616], [68.63819885, 23.1823597], [68.63819885, 23.18264961], [68.63764191, 23.18264961], [68.63764191, 23.18292046], [68.63735962, 23.18292046], [68.63735962, 23.18320084], [68.63708496, 23.18319511], [68.63708496, 23.18347168], [68.63652802, 23.18346977], [68.63652802, 23.18375015], [68.63625336, 23.18375015], [68.63625336, 23.18403053], [68.63540649, 23.18403053], [68.63540649, 23.18431091], [68.63486481, 23.18430519], [68.63486481, 23.18458366], [68.63402557, 23.18458366], [68.6340332, 23.18486023], [68.63263702, 23.18486023], [68.63263702, 23.18514061], [68.63096619, 23.18514061], [68.63096619, 23.18541908], [68.63070679, 23.18541718], [68.62958527, 23.18541718], [68.62958527, 23.18569374], [68.62652588, 23.18569374], [68.62652588, 23.18597221], [68.62680817, 23.18597031], [68.62680817, 23.18625069], [68.62652588, 23.18625069], [68.62652588, 23.18680763], [68.62625122, 23.18680573], [68.62625122, 23.1870842], [68.62513733, 23.18708038], [68.62513733, 23.18736076], [68.62486267, 23.18736076], [68.62486267, 23.18763924], [68.62458038, 23.18763924], [68.62458038, 23.18792152], [68.62430573, 23.1879158], [68.62430573, 23.18819427], [68.62374878, 23.18819427], [68.62374878, 23.18847275], [68.62346649, 23.1884594], [68.62346649, 23.1890316], [68.62319946, 23.1890316], [68.62319946, 23.18931007], [68.62208557, 23.18930626], [68.62208557, 23.18958282], [68.62180328, 23.18958092], [68.62180328, 23.19014168], [68.62152863, 23.19014168], [68.62152863, 23.19042015], [68.62124634, 23.19041634], [68.62124634, 23.19097137], [68.62097168, 23.19096947], [68.62097168, 23.19124985], [68.62069702, 23.19124985], [68.62069702, 23.19153023], [68.62041473, 23.19152832], [68.62041473, 23.19208145], [68.62014008, 23.19208145], [68.62014008, 23.19236374], [68.61985779, 23.19235992], [68.61985779, 23.1926403], [68.61958313, 23.1926403], [68.61958313, 23.19292068], [68.61930847, 23.19292068], [68.61930847, 23.19320107], [68.61902618, 23.19319534], [68.61902618, 23.19347382], [68.61875153, 23.19347], [68.61875153, 23.19375038], [68.61846924, 23.19375038], [68.61846924, 23.19403076], [68.61818695, 23.19403076], [68.61818695, 23.19458961], [68.61791992, 23.19458961], [68.61791992, 23.19514084], [68.61680603, 23.19514084], [68.61680603, 23.19542122], [68.61624908, 23.1954174], [68.61624908, 23.19569588], [68.61597443, 23.19569588], [68.61597443, 23.19597244], [68.61541748, 23.19597054], [68.61541748, 23.19625092], [68.61514282, 23.19625092], [68.61514282, 23.19652939], [68.61458588, 23.19652939], [68.61458588, 23.19680977], [68.61430359, 23.19680786], [68.61430359, 23.19708252], [68.61374664, 23.19708061], [68.61374664, 23.19736099], [68.61347198, 23.19736099], [68.61347198, 23.19765091], [68.61292267, 23.19765091], [68.61292267, 23.19791985], [68.61264038, 23.19791794], [68.61264038, 23.1981945], [68.61235809, 23.1981945], [68.61235809, 23.19847298], [68.61180878, 23.19847107], [68.61180878, 23.19902992], [68.61152649, 23.19902992], [68.61152649, 23.1993103], [68.61125183, 23.19930649], [68.61125183, 23.19958305], [68.61068726, 23.19958115], [68.61068726, 23.20013809], [68.61042023, 23.20013809], [68.61042023, 23.20041847], [68.61013794, 23.20041656], [68.61013794, 23.2009716], [68.60986328, 23.2009697], [68.60986328, 23.20124817], [68.60958099, 23.20124817], [68.60958099, 23.20152855], [68.60930634, 23.20152855], [68.60930634, 23.20181084], [68.60902405, 23.20180511], [68.60902405, 23.20208359], [68.60874939, 23.20208359], [68.60874939, 23.20236015], [68.6084671, 23.20236015], [68.6084671, 23.20264244], [68.60819244, 23.20264244], [68.60819244, 23.20292282], [68.60791779, 23.2029171], [68.60791779, 23.20319366], [68.6076355, 23.20319366], [68.6076355, 23.20347023], [68.60708618, 23.20347023], [68.60708618, 23.20375252], [68.60679626, 23.20375252], [68.60679626, 23.2040329], [68.60624695, 23.2040329], [68.60624695, 23.20430946], [68.60597229, 23.20430565], [68.60597229, 23.20458221], [68.60541534, 23.20458221], [68.60542297, 23.20486069], [68.60513306, 23.20486069], [68.60513306, 23.20514107], [68.60457611, 23.20514107], [68.60457611, 23.20541954], [68.60375214, 23.20541763], [68.60375214, 23.20569229], [68.60319519, 23.20569229], [68.60319519, 23.20597458], [68.6029129, 23.20597076], [68.6029129, 23.20625114], [68.60235596, 23.20625114], [68.60235596, 23.20652962], [68.60208893, 23.20652962], [68.60208893, 23.20681953], [68.60152435, 23.20680618], [68.60152435, 23.20708466], [68.60097504, 23.20708466], [68.60098267, 23.20736122], [68.60069275, 23.20736122], [68.60069275, 23.20763969], [68.60041809, 23.20763969], [68.60041809, 23.20819664], [68.59986115, 23.20819664], [68.59986115, 23.2084713], [68.59958649, 23.20846939], [68.59958649, 23.20874977], [68.59929657, 23.20874977], [68.59929657, 23.20903015], [68.59874725, 23.20902824], [68.59874725, 23.20930672], [68.5984726, 23.20930672], [68.5984726, 23.20958328], [68.59819794, 23.20958328], [68.59819794, 23.20986176], [68.59764099, 23.20985985], [68.59764099, 23.21014023], [68.5973587, 23.21014023], [68.5973587, 23.21042061], [68.59707642, 23.21042061], [68.59707642, 23.21070099], [68.5965271, 23.21069527], [68.5965271, 23.21097183], [68.59625244, 23.21096992], [68.59625244, 23.21125031], [68.59570313, 23.21125031], [68.59570313, 23.21153069], [68.59513855, 23.21153069], [68.59513855, 23.21181107], [68.5945816, 23.21180534], [68.5945816, 23.21208382], [68.59401703, 23.21208], [68.59401703, 23.21236038], [68.59375, 23.21236038], [68.59375, 23.21263885], [68.59348297, 23.21263123], [68.59348297, 23.21292114], [68.59319305, 23.21291733], [68.59319305, 23.21319389], [68.5929184, 23.21319389], [68.5929184, 23.21347237], [68.59263611, 23.21347046], [68.59263611, 23.21375084], [68.59208679, 23.21375084], [68.59208679, 23.21402931], [68.59152985, 23.21402931], [68.59152985, 23.2143116], [68.59124756, 23.2143116], [68.59124756, 23.21513939], [68.5909729, 23.21513939], [68.5909729, 23.21569443], [68.59069824, 23.21569443], [68.59069824, 23.2159729], [68.59041595, 23.21596909], [68.59041595, 23.21624947], [68.59014893, 23.21624947], [68.59014893, 23.21653175], [68.58985901, 23.21653175], [68.58985901, 23.21681023], [68.58958435, 23.21680641], [68.58958435, 23.21708107], [68.58930206, 23.21708107], [68.58930206, 23.21736336], [68.5890274, 23.21735954], [68.5890274, 23.21764183], [68.58875275, 23.21764183], [68.58875275, 23.2179203], [68.58847046, 23.21791649], [68.58847046, 23.21847153], [68.5881958, 23.21846962], [68.5881958, 23.21875954], [68.58790588, 23.21875954], [68.58790588, 23.21903038], [68.58763885, 23.21903038], [68.58763885, 23.21931076], [68.5873642, 23.21930313], [68.5873642, 23.2195816], [68.58708191, 23.2195816], [68.58708191, 23.21986389], [68.58680725, 23.21986008], [68.58680725, 23.22014046], [68.58653259, 23.22014046], [68.58653259, 23.22042084], [68.58625031, 23.22041702], [68.58625031, 23.22097206], [68.58597565, 23.22097206], [68.58598328, 23.22125053], [68.58569336, 23.22125053], [68.58569336, 23.22153091], [68.5854187, 23.22153091], [68.5854187, 23.22182083], [68.58513641, 23.22182083], [68.58513641, 23.22236061], [68.58486176, 23.22236061], [68.58486176, 23.22319412], [68.5845871, 23.22319031], [68.5845871, 23.22402954], [68.58429718, 23.22402954], [68.58429718, 23.22486115], [68.58403015, 23.22486115], [68.58403015, 23.22513962], [68.58430481, 23.22513962], [68.58430481, 23.22847176], [68.5845871, 23.22846985], [68.5845871, 23.22874832], [68.58486176, 23.22874832], [68.58486176, 23.2293129], [68.58513641, 23.22930527], [68.58513641, 23.22958374], [68.5854187, 23.22958183], [68.5854187, 23.23014259], [68.58513641, 23.23014259], [68.58513641, 23.23042107], [68.5845871, 23.23042107], [68.5845871, 23.23291969], [68.58486176, 23.23291588], [68.58486176, 23.23347473], [68.58513641, 23.23347092], [68.58513641, 23.23402977], [68.5854187, 23.23402786], [68.5854187, 23.23458481], [68.58569336, 23.23458481], [68.58569336, 23.23486137], [68.58598328, 23.23485947], [68.58598328, 23.23513985], [68.58625031, 23.23513985], [68.58625031, 23.23542023], [68.58680725, 23.23541641], [68.58680725, 23.23569679], [68.58708191, 23.23569679], [68.58708191, 23.23597145], [68.58735657, 23.23596954], [68.58735657, 23.23624992], [68.58763885, 23.23624992], [68.58763885, 23.2365303], [68.58791351, 23.2365284], [68.58791351, 23.23680687], [68.5881958, 23.23680687], [68.5881958, 23.23708344], [68.58847046, 23.23708344], [68.58847046, 23.23736191], [68.5890274, 23.23736], [68.5890274, 23.23764038], [68.58930206, 23.23764038], [68.58930206, 23.23792076], [68.58958435, 23.23791885], [68.58958435, 23.23819351], [68.58985901, 23.23819351], [68.58985901, 23.23847198], [68.59069824, 23.23847008], [68.59069824, 23.23875046], [68.59152985, 23.23875046], [68.59152985, 23.23903084], [68.59236145, 23.23903084], [68.59236145, 23.23931122], [68.59319305, 23.2393055], [68.59319305, 23.23958397], [68.59401703, 23.23957062], [68.59401703, 23.23986053], [68.59485626, 23.23986053], [68.59485626, 23.24014091], [68.59570313, 23.24014091], [68.59570313, 23.24041748], [68.59902954, 23.24041748], [68.59902954, 23.23931122], [68.59874725, 23.23931122], [68.59874725, 23.23764038], [68.5984726, 23.23764038], [68.5984726, 23.23624992], [68.59874725, 23.23624992], [68.59874725, 23.23569107], [68.59902954, 23.23569679], [68.59902954, 23.23458481], [68.5993042, 23.23458481], [68.5993042, 23.23430634], [68.6001358, 23.23431015], [68.6001358, 23.23291969], [68.60041809, 23.23291969], [68.60041809, 23.23264122], [68.60098267, 23.23264122], [68.60098267, 23.23208046], [68.60124969, 23.23208237], [68.60124969, 23.2318058], [68.60151672, 23.23180962], [68.60151672, 23.23153114], [68.60098267, 23.23153114], [68.60098267, 23.23125267], [68.6001358, 23.23125267], [68.6001358, 23.23097038], [68.59986115, 23.23097038], [68.59986115, 23.23041725], [68.59958649, 23.23042107], [68.59958649, 23.23014259], [68.59902954, 23.23014259], [68.59902954, 23.22903252], [68.59874725, 23.22903252], [68.59874725, 23.22874832], [68.60041809, 23.22874832], [68.60041809, 23.22846985], [68.60097504, 23.22847176], [68.60097504, 23.22791672], [68.60124969, 23.22791862], [68.60124969, 23.22707748], [68.60069275, 23.22708321], [68.60069275, 23.22680473], [68.6001358, 23.22680473], [68.6001358, 23.22652817], [68.59986115, 23.22652817], [68.59986115, 23.22375107], [68.59958649, 23.22375107], [68.59958649, 23.22291946], [68.59986115, 23.22291946], [68.59986115, 23.22236061], [68.6001358, 23.22236061], [68.6001358, 23.22182083], [68.60041809, 23.22182083], [68.60041809, 23.22125053], [68.60069275, 23.22125053], [68.60069275, 23.22068977], [68.60097504, 23.2206955], [68.60097504, 23.21875191], [68.60124969, 23.21875954], [68.60124969, 23.21846962], [68.60151672, 23.21846962], [68.60151672, 23.21875954], [68.60180664, 23.21875954], [68.60180664, 23.21903038], [68.60208893, 23.21903038], [68.60208893, 23.21931076], [68.60236359, 23.21930313], [68.60236359, 23.2195816], [68.60263824, 23.2195816], [68.60263824, 23.21986389], [68.60375214, 23.21986389], [68.60375214, 23.2195816], [68.60430908, 23.2195816], [68.60430908, 23.21930313], [68.60457611, 23.21931076], [68.60457611, 23.21903038], [68.60513306, 23.21903038], [68.60513306, 23.21875954], [68.60541534, 23.21875191], [68.60541534, 23.22043037], [68.60541534, 23.2206955], [68.60555267, 23.2206955], [68.60791779, 23.2206955], [68.60791779, 23.22097206], [68.60902405, 23.22097206], [68.60902405, 23.2206955], [68.60958099, 23.2206955], [68.60958099, 23.21847153], [68.60930634, 23.21847153], [68.60930634, 23.21791649], [68.60986328, 23.2179203], [68.60986328, 23.21764183], [68.61125946, 23.21764183], [68.61125946, 23.2179203], [68.61152649, 23.2179203], [68.61152649, 23.21820068], [68.61180878, 23.21819305], [68.61180878, 23.21847153], [68.61235809, 23.21846962], [68.61235809, 23.21875954], [68.61319733, 23.21875954], [68.61319733, 23.21820068], [68.61347198, 23.21820068], [68.61347198, 23.21708107], [68.61430359, 23.21708107], [68.61430359, 23.21736336], [68.61458588, 23.21735954], [68.61458588, 23.21764183], [68.61486053, 23.21764183], [68.61486053, 23.2179203], [68.61514282, 23.2179203], [68.61514282, 23.21820068], [68.61541748, 23.21819305], [68.61541748, 23.21847153], [68.61569214, 23.21846962], [68.61569214, 23.21875954], [68.61680603, 23.21875954], [68.61680603, 23.21903038], [68.61818695, 23.21903038], [68.61818695, 23.21653175], [68.62013245, 23.21653175], [68.62013245, 23.21624947], [68.6204071, 23.21624947], [68.6204071, 23.21596909], [68.62097168, 23.21596909], [68.62097168, 23.21681023], [68.62291718, 23.21681023], [68.62291718, 23.21653175], [68.62374878, 23.21653175], [68.62374878, 23.21569061], [68.62430573, 23.21569443], [68.62430573, 23.2159729], [68.62596893, 23.21596909], [68.62596893, 23.21624947], [68.62652588, 23.21624947], [68.62652588, 23.21596909], [68.62680817, 23.2159729], [68.62680817, 23.21569443], [68.62708282, 23.21569443], [68.62708282, 23.21513939], [68.62735748, 23.21513939], [68.62735748, 23.21486092], [68.62763977, 23.21486092], [68.62763977, 23.21458054], [68.62902832, 23.21458244], [68.62902832, 23.21430588], [68.62930298, 23.2143116], [68.62930298, 23.21402931], [68.6295929, 23.21402931], [68.6295929, 23.21375084], [68.62985992, 23.21375084], [68.62985992, 23.21347046], [68.63014221, 23.21347237], [68.63014221, 23.21319389], [68.63069153, 23.21319389], [68.63069153, 23.21347237], [68.63096619, 23.21347046], [68.63096619, 23.21402931], [68.63124847, 23.21402931], [68.63124847, 23.2143116], [68.63153076, 23.2143116], [68.63153076, 23.21542168], [68.63124847, 23.21541595], [68.63124847, 23.2159729], [68.62930298, 23.21596909], [68.62930298, 23.21624947], [68.62902832, 23.21624947], [68.62902832, 23.21653175], [68.62874603, 23.21653175], [68.62874603, 23.21681023], [68.62847137, 23.21680641], [68.62847137, 23.21736336], [68.62874603, 23.21735954], [68.62874603, 23.21764183], [68.62930298, 23.21764183], [68.62930298, 23.2179203], [68.6295929, 23.2179203], [68.6295929, 23.21820068], [68.63014221, 23.21819305], [68.63014221, 23.21847153], [68.63096619, 23.21846962], [68.63096619, 23.21875954], [68.63153076, 23.21875954], [68.63153076, 23.21903038], [68.6340332, 23.21903038], [68.6340332, 23.21931076], [68.63486481, 23.21930313], [68.63486481, 23.2195816], [68.63513947, 23.2195797], [68.63513947, 23.22014046], [68.63485718, 23.22014046], [68.63485718, 23.22042084], [68.63458252, 23.22041702], [68.63458252, 23.22097206], [68.63430786, 23.22097015], [68.63430786, 23.22125053], [68.6340332, 23.22125053], [68.6340332, 23.22153091], [68.63430786, 23.22153091], [68.63430786, 23.22182083], [68.63458252, 23.22182083], [68.63458252, 23.22153091], [68.63485718, 23.22153091], [68.63485718, 23.22125053], [68.63513947, 23.22125053], [68.63513947, 23.22097015], [68.63541412, 23.22097206], [68.63541412, 23.2206955], [68.63625336, 23.2206955], [68.63625336, 23.22041702], [68.63680267, 23.22042084], [68.63680267, 23.22153091], [68.63764191, 23.22153091], [68.63764191, 23.22182083], [68.63791656, 23.22180557], [68.63791656, 23.22208595], [68.63986206, 23.22208023], [68.63986206, 23.22236061], [68.63957977, 23.22236061], [68.63957977, 23.22264099], [68.63931274, 23.22264099], [68.63931274, 23.22291946], [68.63903046, 23.22291756], [68.63903046, 23.22319412], [68.63652802, 23.22319412], [68.63652802, 23.2234726], [68.63625336, 23.22347069], [68.63625336, 23.22375107], [68.63375092, 23.22375107], [68.63375092, 23.22402954], [68.63346863, 23.22402954], [68.63346863, 23.22430992], [68.63315582, 23.22430992], [68.63153076, 23.22430611], [68.63153076, 23.22458267], [68.63096619, 23.22457123], [68.63096619, 23.22486115], [68.62902832, 23.22486115], [68.62902832, 23.22457123], [68.62875366, 23.22458267], [68.62875366, 23.22430611], [68.62847137, 23.22430992], [68.62847137, 23.22402954], [68.62819672, 23.22402954], [68.62819672, 23.22375107], [68.6279068, 23.22375107], [68.6279068, 23.22319031], [68.62763977, 23.22319412], [68.62763977, 23.22291756], [68.62735748, 23.22291946], [68.62735748, 23.22264099], [68.62708282, 23.22264099], [68.62708282, 23.22236061], [68.62680817, 23.22236061], [68.62680817, 23.22182083], [68.62652588, 23.22182083], [68.62652588, 23.22153091], [68.62625885, 23.22153091], [68.62625885, 23.22125053], [68.62568665, 23.22125053], [68.62568665, 23.22097015], [68.62486267, 23.22097206], [68.62486267, 23.2206955], [68.62403107, 23.2206955], [68.62403107, 23.22097206], [68.62346649, 23.22097015], [68.62347412, 23.22125053], [68.62319183, 23.22125053], [68.62319183, 23.22171021], [68.62319183, 23.2234726], [68.62346649, 23.22347069], [68.62346649, 23.22402954], [68.62374878, 23.22402954], [68.62374878, 23.22430992], [68.62347412, 23.22430611], [68.62347412, 23.22458267], [68.62319183, 23.22458267], [68.62319183, 23.22486115], [68.62346649, 23.22486115], [68.62346649, 23.22513962], [68.62374878, 23.22513962], [68.62374878, 23.22541809], [68.62430573, 23.22541618], [68.62430573, 23.22569466], [68.62458038, 23.22569466], [68.62458038, 23.22597313], [68.62486267, 23.22597122], [68.62486267, 23.22624969], [68.62374878, 23.22624969], [68.62374878, 23.22597122], [68.62347412, 23.22597313], [68.62347412, 23.22569466], [68.62264252, 23.22569466], [68.62264252, 23.22458267], [68.62236023, 23.22458267], [68.62236023, 23.22374916], [68.6220932, 23.22375107], [68.6220932, 23.22319031], [68.62180328, 23.22319412], [68.62180328, 23.22291756], [68.62124634, 23.22291946], [68.62124634, 23.22265816], [68.62097168, 23.22264099], [68.62097168, 23.22236061], [68.62069702, 23.22236061], [68.62069702, 23.22264099], [68.62041473, 23.22263908], [68.62041473, 23.22313118], [68.6204071, 23.22402954], [68.62069702, 23.22402954], [68.62069702, 23.22430992], [68.62097168, 23.22430611], [68.62097168, 23.22458267], [68.62124634, 23.22457123], [68.62124634, 23.22486115], [68.61930847, 23.22486115], [68.61930847, 23.22513962], [68.61875153, 23.22513962], [68.61875153, 23.22486115], [68.61902618, 23.22486115], [68.61902618, 23.22384071], [68.61902618, 23.22208595], [68.61930847, 23.22208595], [68.61930847, 23.21986389], [68.61902618, 23.21986008], [68.61902618, 23.22014046], [68.61875153, 23.22013855], [68.61875153, 23.2206955], [68.61846924, 23.2206955], [68.61846924, 23.22097206], [68.61818695, 23.22097015], [68.61818695, 23.22125053], [68.61791992, 23.22125053], [68.61791992, 23.22182083], [68.61763763, 23.22182083], [68.61763763, 23.22236061], [68.61736298, 23.22236061], [68.61736298, 23.22319412], [68.61707306, 23.22319031], [68.61707306, 23.22375107], [68.61680603, 23.22375107], [68.61680603, 23.22402954], [68.61653137, 23.22402763], [68.61653137, 23.22458267], [68.61624908, 23.22458267], [68.61624908, 23.22528076], [68.61624908, 23.22569466], [68.61597443, 23.22569466], [68.61597443, 23.22597313], [68.61569214, 23.22597122], [68.61569214, 23.22624969], [68.61541748, 23.22624969], [68.61541748, 23.22652817], [68.61486053, 23.22652817], [68.61486053, 23.22680473], [68.61430359, 23.22680473], [68.61430359, 23.22708321], [68.61374664, 23.22708321], [68.61374664, 23.22763824], [68.61347198, 23.22763062], [68.61347198, 23.22791862], [68.61319733, 23.22791672], [68.61319733, 23.22847176], [68.61292267, 23.22846985], [68.61292267, 23.22903252], [68.61264038, 23.22903252], [68.61264038, 23.2293129], [68.61235809, 23.2293129], [68.61235809, 23.22986031], [68.61207581, 23.22986031], [68.61207581, 23.23014259], [68.61180878, 23.23014259], [68.61180878, 23.23069954], [68.61152649, 23.23069954], [68.61152649, 23.23125267], [68.61125946, 23.23125267], [68.61125946, 23.23180962], [68.61096954, 23.2318058], [68.61096954, 23.23208237], [68.61068726, 23.23208046], [68.61068726, 23.23264122], [68.61042023, 23.23263931], [68.61042023, 23.23319244], [68.61013794, 23.23319054], [68.61013794, 23.23376083], [68.60986328, 23.23376083], [68.60986328, 23.23402977], [68.60958099, 23.23402786], [68.60958099, 23.23458481], [68.60930634, 23.23458481], [68.60930634, 23.23486137], [68.60819244, 23.23485947], [68.60819244, 23.23513985], [68.60791779, 23.23513985], [68.60791779, 23.23542023], [68.60736084, 23.23541641], [68.60736084, 23.23569679], [68.60708618, 23.23569679], [68.60708618, 23.23597145], [68.60679626, 23.23596954], [68.60679626, 23.23624992], [68.60652924, 23.23624992], [68.60652924, 23.23680687], [68.60624695, 23.23680687], [68.60624695, 23.23708344], [68.60597229, 23.23708344], [68.60597229, 23.23736191], [68.60569763, 23.23736], [68.60569763, 23.23792076], [68.60541534, 23.23791885], [68.60542297, 23.2381897], [68.60513306, 23.23820114], [68.60513306, 23.23875046], [68.6048584, 23.23875046], [68.6048584, 23.23903084], [68.60458374, 23.23902893], [68.60458374, 23.23958397], [68.60430908, 23.23957062], [68.60430908, 23.23986053], [68.60457611, 23.23986053], [68.60457611, 23.24041748], [68.60513306, 23.24041748], [68.60513306, 23.24014091], [68.60569763, 23.2401371], [68.60569763, 23.24081993], [68.60569763, 23.24097252], [68.60542297, 23.24097061], [68.60542297, 23.24124908], [68.60513306, 23.24124908], [68.60513306, 23.24181175], [68.6048584, 23.24180603], [68.6048584, 23.2420826], [68.60430908, 23.24208069], [68.60430908, 23.24235916], [68.60375214, 23.24235916], [68.60375214, 23.24292946], [68.6048584, 23.24291611], [68.6048584, 23.24319458], [68.60541534, 23.24319458], [68.60541534, 23.24347115], [68.60624695, 23.24346924], [68.60624695, 23.24374962], [68.60708618, 23.24374962], [68.60708618, 23.24346924], [68.60736084, 23.24347115], [68.60736084, 23.24319458], [68.60930634, 23.24319458], [68.60930634, 23.24291611], [68.61096954, 23.24292946], [68.61096954, 23.24263954], [68.61292267, 23.24263954], [68.61291504, 23.24235916], [68.61513519, 23.24235916], [68.61513519, 23.24263954], [68.61791992, 23.24263954], [68.61791992, 23.24292946], [68.62264252, 23.24291611], [68.62264252, 23.24319458], [68.62458038, 23.24319458], [68.62458038, 23.24291611], [68.62486267, 23.24291611], [68.62486267, 23.24319458], [68.62541962, 23.24319458], [68.62541962, 23.24347115], [68.62596893, 23.24346924], [68.62596893, 23.24374962], [68.62680817, 23.24374962], [68.62680817, 23.24403191], [68.62735748, 23.24402809], [68.62735748, 23.24430466], [68.62791443, 23.24430466], [68.62791443, 23.24458122], [68.62930298, 23.24458122], [68.62930298, 23.24430466], [68.62958527, 23.24430466], [68.62958527, 23.24402809], [68.62985992, 23.24403191], [68.62985992, 23.24348068], [68.63014221, 23.24346924], [68.63014221, 23.24319458], [68.63069153, 23.24319458], [68.63069153, 23.24430466], [68.63054657, 23.24430275], [68.63041687, 23.24430275], [68.63041687, 23.24514008], [68.6279068, 23.24514008], [68.6279068, 23.24681091], [68.62819672, 23.24680328], [68.62819672, 23.24708557], [68.62985992, 23.24708557], [68.62985992, 23.24680328], [68.63014221, 23.24681091], [68.63014221, 23.24653053], [68.63041687, 23.24653053], [68.63041687, 23.24596977], [68.63124847, 23.24597359], [68.63124847, 23.24569321], [68.63153076, 23.24570084], [68.63153076, 23.24550056], [68.63153076, 23.24541664], [68.63236237, 23.24542046], [68.63236237, 23.24570084], [68.63263702, 23.24570084], [68.63263702, 23.24625015], [68.63430786, 23.24625015], [68.63430786, 23.24653053], [68.63513947, 23.24653053], [68.63513947, 23.24625015], [68.63597107, 23.24625015], [68.63597107, 23.24653053], [68.63709259, 23.24653053], [68.63709259, 23.24596977], [68.63735962, 23.24597359], [68.63735962, 23.24541664], [68.63791656, 23.24542046], [68.63791656, 23.24570084], [68.63847351, 23.24569321], [68.63847351, 23.24597359], [68.63874817, 23.24597359], [68.63874817, 23.24569321], [68.63931274, 23.24570084], [68.63931274, 23.2448597], [68.63957977, 23.24486351], [68.63957977, 23.24458122], [68.64041901, 23.24458122], [68.64041901, 23.24486351], [68.64068604, 23.2448597], [68.64068604, 23.24514008], [68.64097595, 23.24514008], [68.64097595, 23.24542046], [68.64124298, 23.24542046], [68.64124298, 23.24570084], [68.64263916, 23.24569321], [68.64263916, 23.24597359], [68.64290619, 23.24596977], [68.64290619, 23.24625015], [68.64319611, 23.24625015], [68.64319611, 23.24736023], [68.64290619, 23.24736023], [68.64290619, 23.24764061], [68.64263916, 23.24764061], [68.64263916, 23.24792099], [68.6423645, 23.24791718], [68.6423645, 23.24819565], [68.64125061, 23.24819565], [68.64125061, 23.24791718], [68.64097595, 23.24792099], [68.64097595, 23.24764061], [68.64041901, 23.24764061], [68.64041901, 23.24792099], [68.64013672, 23.24792099], [68.64013672, 23.24903107], [68.63903046, 23.24903107], [68.63903046, 23.24930954], [68.63930511, 23.24930573], [68.63930511, 23.24986076], [68.63957977, 23.24986076], [68.63957977, 23.24958038], [68.64180756, 23.24958038], [68.64180756, 23.24986076], [68.64263916, 23.24986076], [68.64263916, 23.25014114], [68.6423645, 23.25013924], [68.6423645, 23.25069427], [68.64263916, 23.25069046], [68.64263916, 23.25125122], [68.64375305, 23.25124931], [68.64375305, 23.25180626], [68.64430237, 23.25180626], [68.64430237, 23.25152779], [68.64457703, 23.25152969], [68.64457703, 23.25125122], [68.64485931, 23.25125122], [68.64485931, 23.25097084], [68.64569092, 23.25097084], [68.64569092, 23.25152969], [68.64597321, 23.25152779], [68.64597321, 23.25180626], [68.64624786, 23.25180626], [68.64624786, 23.25208282], [68.64653015, 23.25208282], [68.64653015, 23.2523613], [68.64679718, 23.25235939], [68.64679718, 23.25291824], [68.64653015, 23.25291634], [68.64653015, 23.25304031], [68.64653015, 23.25319481], [68.64597321, 23.25319481], [68.64597321, 23.25347137], [68.64626312, 23.25347137], [68.6470871, 23.25346947], [68.6470871, 23.25374985], [68.64848328, 23.25374985], [68.64848328, 23.25402832], [68.64819336, 23.25402832], [68.64819336, 23.25458336], [68.6479187, 23.25457954], [68.6479187, 23.25486946], [68.64763641, 23.25486946], [68.64763641, 23.2551384], [68.64679718, 23.2551384], [68.64679718, 23.25625038], [68.6470871, 23.25625038], [68.6470871, 23.25653267], [68.64736176, 23.25652695], [68.64736176, 23.25708389], [68.64763641, 23.25708008], [68.64763641, 23.25736046], [68.6479187, 23.25736046], [68.6479187, 23.25764275], [68.64848328, 23.25764275], [68.64848328, 23.25793076], [68.64875031, 23.2579174], [68.64875031, 23.25819206], [68.64958191, 23.25819206], [68.64958191, 23.25847054], [68.65040588, 23.25847054], [68.65040588, 23.25875282], [68.65180206, 23.25875282], [68.65180206, 23.25902939], [68.65319824, 23.25902939], [68.65319824, 23.25930977], [68.65402985, 23.25930405], [68.65402985, 23.25958443], [68.65513611, 23.25958061], [68.65513611, 23.2598629], [68.65597534, 23.2598629], [68.65597534, 23.26013947], [68.65624237, 23.26013947], [68.65624237, 23.26041985], [68.65652466, 23.26041412], [68.65652466, 23.2606926], [68.65763855, 23.2606926], [68.65763855, 23.26097488], [68.65847015, 23.26097107], [68.65847015, 23.26124954], [68.6590271, 23.26124954], [68.6590271, 23.26152992], [68.65930176, 23.26152802], [68.65930939, 23.26180077], [68.65958405, 23.26180649], [68.65958405, 23.26208305], [68.6598587, 23.26208115], [68.6598587, 23.26264], [68.66014099, 23.26264], [68.66014099, 23.26680756], [68.66041565, 23.26680565], [68.66041565, 23.26708412], [68.66069794, 23.26708031], [68.66069794, 23.26736069], [68.66124725, 23.26736069], [68.66124725, 23.26763916], [68.66152954, 23.26763916], [68.66152954, 23.26792145], [68.66236115, 23.26791573], [68.66236115, 23.2681942], [68.66291809, 23.2681942], [68.66291809, 23.26847267], [68.66374969, 23.26847076], [68.66374969, 23.26874924], [68.66430664, 23.26874924], [68.66430664, 23.26903152], [68.66513824, 23.26903152], [68.66513824, 23.2693119], [68.66569519, 23.26930618], [68.66569519, 23.26958275], [68.66707611, 23.26958084], [68.66707611, 23.26987267], [68.66874695, 23.26987267], [68.66874695, 23.26958084], [68.67041779, 23.26958084], [68.67041779, 23.26987267], [68.67180634, 23.26987267], [68.67180634, 23.27013969], [68.67151642, 23.27013969], [68.67151642, 23.27124977], [68.67124939, 23.27124977], [68.67124939, 23.27236366], [68.6709671, 23.27235985], [68.6709671, 23.27264023], [68.67014313, 23.27264023], [68.67014313, 23.27235985], [68.66930389, 23.27236366], [68.66930389, 23.27208138], [68.66874695, 23.27208138], [68.66874695, 23.27180481], [68.66791534, 23.27180481], [68.66791534, 23.27152824], [68.66707611, 23.27153015], [68.66707611, 23.27124977], [68.66347504, 23.27124977], [68.66347504, 23.27208138], [68.66124725, 23.27208138], [68.66124725, 23.27180481], [68.6581955, 23.27180481], [68.6581955, 23.27208138], [68.65625, 23.27208138], [68.65625, 23.27180481], [68.6554184, 23.27180481], [68.6554184, 23.27152824], [68.65235901, 23.27153015], [68.65235901, 23.27124977], [68.65207672, 23.27124977], [68.65207672, 23.27096939], [68.65180206, 23.2709713], [68.65180206, 23.27069473], [68.65125275, 23.27069473], [68.65125275, 23.27041626], [68.65097046, 23.27042007], [68.65097046, 23.27013969], [68.6506958, 23.27013969], [68.6506958, 23.26987267], [68.65013885, 23.26987267], [68.65013885, 23.26958084], [68.6498642, 23.26958275], [68.6498642, 23.26930618], [68.64930725, 23.2693119], [68.64930725, 23.26903152], [68.64736938, 23.26903152], [68.64736938, 23.26874924], [68.64597321, 23.26874924], [68.64597321, 23.26847076], [68.64458466, 23.26847267], [68.64458466, 23.2681942], [68.64402771, 23.2681942], [68.64402771, 23.26791763], [68.64375305, 23.26792145], [68.64375305, 23.26763916], [68.64319611, 23.26763916], [68.64319611, 23.26736069], [68.64290619, 23.26736069], [68.64290619, 23.26708031], [68.64263916, 23.26708412], [68.64263916, 23.26652718], [68.64232635, 23.26652718], [68.64068604, 23.26652908], [68.64068604, 23.26680756], [68.64041901, 23.26680565], [68.64041901, 23.26708412], [68.64013672, 23.26708031], [68.64013672, 23.26736069], [68.63986206, 23.26736069], [68.63986206, 23.26763916], [68.63957977, 23.26763916], [68.63957977, 23.26847267], [68.63791656, 23.26847076], [68.63791656, 23.26874924], [68.63764191, 23.26874924], [68.63764191, 23.2693119], [68.63735962, 23.2693119], [68.63735962, 23.27013969], [68.63708496, 23.27013969], [68.63708496, 23.27069473], [68.63680267, 23.27069283], [68.63680267, 23.27124977], [68.63652802, 23.27124977], [68.63652802, 23.27208138], [68.63625336, 23.27207947], [68.63625336, 23.27264023], [68.63597107, 23.27263832], [68.63597107, 23.27347374], [68.63625336, 23.27346992], [68.63625336, 23.27431107], [68.63597107, 23.27431107], [68.63597107, 23.27486038], [68.63569641, 23.27486038], [68.63569641, 23.2756958], [68.63540649, 23.27568054], [68.63540649, 23.27625084], [68.63513947, 23.27625084], [68.63513947, 23.27653122], [68.63485718, 23.27653122], [68.63485718, 23.27736092], [68.63458252, 23.27736092], [68.63458252, 23.27819443], [68.63430786, 23.27819061], [68.63430786, 23.27902985], [68.6340332, 23.27902985], [68.6340332, 23.28013992], [68.63375092, 23.28013992], [68.63375092, 23.28097153], [68.63346863, 23.28096962], [68.63346863, 23.28181076], [68.63318634, 23.28181076], [68.63318634, 23.28264236], [68.63291931, 23.28263855], [68.63291931, 23.28347015], [68.63263702, 23.28347015], [68.63263702, 23.28430939], [68.63236237, 23.28430557], [68.63236237, 23.28486061], [68.63207245, 23.28484917], [68.63207245, 23.28541946], [68.63180542, 23.28541756], [68.63180542, 23.28569221], [68.63153076, 23.28569031], [68.63153076, 23.28625107], [68.63124847, 23.28625107], [68.63124847, 23.28680992], [68.63096619, 23.28680992], [68.63096619, 23.28736115], [68.63069153, 23.28736115], [68.63069153, 23.28819466], [68.63041687, 23.28819084], [68.63041687, 23.28903008], [68.63014221, 23.28902817], [68.63014221, 23.28986168], [68.62985992, 23.28985977], [68.62985992, 23.29042053], [68.6295929, 23.29042053], [68.6295929, 23.29097939], [68.62930298, 23.29097939], [68.62930298, 23.29236031], [68.6295929, 23.29236031], [68.6295929, 23.29513931], [68.62985992, 23.29513931], [68.62985992, 23.2954216], [68.63014221, 23.29541588], [68.63014221, 23.29569435], [68.63153076, 23.29569435], [68.63153076, 23.29597282], [68.63291931, 23.29597092], [68.63291931, 23.29624939], [68.63318634, 23.29624939], [68.63318634, 23.29597092], [68.63458252, 23.29597282], [68.63458252, 23.29569435], [68.63680267, 23.29569435], [68.63680267, 23.29541588], [68.63791656, 23.29541588], [68.63791656, 23.29569435], [68.63847351, 23.29569435], [68.63847351, 23.29541588], [68.63903046, 23.29541588], [68.63903046, 23.29569435], [68.63957977, 23.29569435], [68.63957977, 23.29597282], [68.63986206, 23.29597092], [68.63986206, 23.29624939], [68.64041901, 23.29624939], [68.64041901, 23.29653168], [68.64903259, 23.29653168], [68.64903259, 23.29624939], [68.64958191, 23.29624939], [68.64958191, 23.29597092], [68.65041351, 23.29597282], [68.65041351, 23.29569435], [68.6506958, 23.29569435], [68.6506958, 23.29513931], [68.65097046, 23.29513931], [68.65097046, 23.29486084], [68.6515274, 23.29486084], [68.6515274, 23.29458046], [68.6526413, 23.29458046], [68.6526413, 23.29486084], [68.65319824, 23.29486084], [68.65319824, 23.29513931], [68.6534729, 23.29513931], [68.6534729, 23.2954216], [68.65458679, 23.2954216], [68.65458679, 23.29513931], [68.65513611, 23.29513931], [68.65513611, 23.29486084], [68.65569305, 23.29486084], [68.65569305, 23.29513931], [68.65624237, 23.29513931], [68.65624237, 23.29486084], [68.65680695, 23.29486084], [68.65680695, 23.29513931], [68.65791321, 23.29513931], [68.65791321, 23.2954216], [68.65930176, 23.29541588], [68.65930939, 23.29569435], [68.66069794, 23.29569435], [68.66069794, 23.29597282], [68.66152954, 23.29597092], [68.66152954, 23.29624939], [68.66208649, 23.29624939], [68.66208649, 23.29653168], [68.66291809, 23.29653168], [68.66291809, 23.29681015], [68.66347504, 23.29680634], [68.66347504, 23.2970829], [68.66430664, 23.2970829], [68.66430664, 23.29736137], [68.66485596, 23.29735947], [68.66485596, 23.29764175], [68.6654129, 23.29764175], [68.6654129, 23.29792023], [68.66569519, 23.29791641], [68.66569519, 23.29819489], [68.66625214, 23.29819489], [68.66625214, 23.29847145], [68.66680908, 23.29846954], [68.66680908, 23.29874992], [68.6673584, 23.29874992], [68.6673584, 23.2990303], [68.66902924, 23.2990303], [68.66902924, 23.29931068], [68.67041779, 23.29930305], [68.67041779, 23.29958153], [68.67208099, 23.29958153], [68.67208099, 23.29986382], [68.67402649, 23.29985046], [68.67402649, 23.30014038], [68.67457581, 23.30014038], [68.67457581, 23.29985046], [68.67819214, 23.29986382], [68.67819214, 23.29958153], [68.67903137, 23.29957962], [68.67903137, 23.30014038], [68.67930603, 23.30013847], [68.67930603, 23.30069542], [68.67958069, 23.30069542], [68.67958069, 23.30097389], [68.68264008, 23.30097389], [68.68264008, 23.30069542], [68.68319702, 23.30069542], [68.68319702, 23.30041695], [68.68430328, 23.30041695], [68.68430328, 23.30069542], [68.68458557, 23.30069542], [68.68458557, 23.30097389], [68.68486023, 23.30097008], [68.68486023, 23.30125046], [68.68514252, 23.30125046], [68.68514252, 23.30153084], [68.68569183, 23.30153084], [68.68569183, 23.30181122], [68.68597412, 23.3018055], [68.68597412, 23.30208588], [68.68624878, 23.30208015], [68.68624878, 23.30236053], [68.6865387, 23.30236053], [68.6865387, 23.30291939], [68.68791962, 23.30291748], [68.68791962, 23.30347252], [68.68818665, 23.30347061], [68.68818665, 23.30375099], [68.68875122, 23.30375099], [68.68875122, 23.30402946], [68.69097137, 23.30402756], [68.69097137, 23.3045826], [68.69124603, 23.30458069], [68.69124603, 23.30486107], [68.69180298, 23.30486107], [68.69180298, 23.30513954], [68.69264221, 23.30513954], [68.69264221, 23.30541992], [68.69319153, 23.30541611], [68.69319153, 23.30569458], [68.69374847, 23.30569077], [68.69374847, 23.30598068], [68.69403076, 23.30598068], [68.69403076, 23.30624962], [68.69458008, 23.30624962], [68.69458008, 23.30652809], [68.69541931, 23.30652809], [68.69541931, 23.30680466], [68.69569397, 23.30680466], [68.69569397, 23.3073616], [68.69596863, 23.3073616], [68.69596863, 23.30652809], [68.69819641, 23.30652809], [68.69819641, 23.30624962], [68.69875336, 23.30624962], [68.69875336, 23.30598068], [68.69930267, 23.30598068], [68.69930267, 23.30569077], [68.70207977, 23.30569458], [68.70207977, 23.30541611], [68.70458221, 23.30541992], [68.70458221, 23.30486107], [68.70430756, 23.30486107], [68.70430756, 23.30458069], [68.70513916, 23.3045826], [68.70513916, 23.30430794], [68.70540619, 23.30430984], [68.70540619, 23.30402946], [68.70569611, 23.30402946], [68.70569611, 23.30375099], [68.70707703, 23.30375099], [68.70707703, 23.30347061], [68.70735931, 23.30347252], [68.70735931, 23.30319595], [68.7076416, 23.30319595], [68.7076416, 23.30291748], [68.70791626, 23.30291939], [68.70791626, 23.30236053], [68.70819092, 23.30236053], [68.70819092, 23.30181122], [68.70847321, 23.30181122], [68.70847321, 23.30125046], [68.70874786, 23.30125046], [68.70874786, 23.30042076], [68.70903015, 23.30042076], [68.70903015, 23.29985046], [68.70791626, 23.29986382], [68.70791626, 23.29930305], [68.70819092, 23.29931068], [68.70819092, 23.2990303], [68.70903015, 23.2990303], [68.70903015, 23.29874992], [68.7104187, 23.29874992], [68.7104187, 23.29819107], [68.71069336, 23.29819489], [68.71069336, 23.29791641], [68.71180725, 23.29792023], [68.71180725, 23.29764175], [68.71208191, 23.29764175], [68.71208191, 23.29735947], [68.71263885, 23.29736137], [68.71263885, 23.2970829], [68.7140274, 23.2970829], [68.7140274, 23.29680634], [68.71679688, 23.29681015], [68.71679688, 23.29653168], [68.71763611, 23.29653168], [68.71763611, 23.29624939], [68.71985626, 23.29624939], [68.71985626, 23.29597092], [68.72097015, 23.29597282], [68.72097015, 23.29569435], [68.72208405, 23.29569435], [68.72208405, 23.29541588], [68.72402954, 23.29541588], [68.72402954, 23.29569435], [68.7251358, 23.29569435], [68.7251358, 23.29597282], [68.72597504, 23.29597282], [68.72597504, 23.29624939], [68.72651672, 23.29624939], [68.72651672, 23.29653168], [68.7270813, 23.29653168], [68.7270813, 23.29681015], [68.72763824, 23.29680634], [68.72763824, 23.2970829], [68.7279129, 23.2970829], [68.7279129, 23.29736137], [68.72846222, 23.29735947], [68.72846222, 23.29764175], [68.72875214, 23.29764175], [68.72875214, 23.29792023], [68.72930908, 23.29791641], [68.72930908, 23.29819489], [68.72958374, 23.29819489], [68.72958374, 23.29847145], [68.7298584, 23.29846954], [68.7298584, 23.29874992], [68.73014069, 23.29874992], [68.73014069, 23.2990303], [68.73041534, 23.2990284], [68.73041534, 23.29958153], [68.73069763, 23.29958153], [68.73069763, 23.29986382], [68.73097229, 23.29985046], [68.73097229, 23.30014038], [68.73124695, 23.30013847], [68.73124695, 23.30069542], [68.73152161, 23.3006897], [68.73152161, 23.30125046], [68.73179626, 23.30125046], [68.73179626, 23.30236053], [68.73208618, 23.30236053], [68.73208618, 23.30541992], [68.73236084, 23.30541992], [68.73236084, 23.30598068], [68.7326355, 23.30597305], [68.7326355, 23.30624962], [68.73291779, 23.30624962], [68.73291779, 23.30680466], [68.73319244, 23.30680466], [68.73319244, 23.30708313], [68.73347473, 23.30708313], [68.73347473, 23.3073616], [68.73401642, 23.3073597], [68.73401642, 23.30763817], [68.73430634, 23.30763817], [68.73430634, 23.30791855], [68.73486328, 23.30791855], [68.73486328, 23.30820084], [68.73513794, 23.30819511], [68.73513794, 23.30847168], [68.73568726, 23.30846977], [68.73568726, 23.30874825], [68.73735809, 23.30874825], [68.73735809, 23.30846977], [68.73847198, 23.30847168], [68.73847198, 23.30819511], [68.73929596, 23.30820084], [68.73929596, 23.30791855], [68.74014282, 23.30791855], [68.74014282, 23.30763817], [68.74069214, 23.30763817], [68.74069214, 23.3073597], [68.74097443, 23.3073616], [68.74097443, 23.30708313], [68.74153137, 23.30708313], [68.74153137, 23.30680466], [68.74208069, 23.30680466], [68.74208069, 23.30652809], [68.74263763, 23.30652809], [68.74263763, 23.30624962], [68.74346161, 23.30624962], [68.74346161, 23.30598068], [68.74375153, 23.30598068], [68.74375153, 23.30569077], [68.74402618, 23.30569458], [68.74402618, 23.30541611], [68.74430847, 23.30541992], [68.74430847, 23.30513954], [68.74458313, 23.30513954], [68.74458313, 23.30486107], [68.74514008, 23.30486107], [68.74514008, 23.30402946], [68.74819183, 23.30402946], [68.74819183, 23.30513954], [68.74846649, 23.30513954], [68.74846649, 23.30541992], [68.74874878, 23.30541611], [68.74874878, 23.30569458], [68.74930573, 23.30569458], [68.74930573, 23.30624962], [68.74958038, 23.30624962], [68.74958038, 23.30680466], [68.74986267, 23.30680466], [68.74986267, 23.3073616], [68.75013733, 23.3073597], [68.75013733, 23.30791855], [68.75041962, 23.30791664], [68.75041962, 23.30847168], [68.75068665, 23.30846977], [68.75068665, 23.30904007], [68.75096893, 23.30902863], [68.75096893, 23.30958366], [68.75125122, 23.30958176], [68.75125122, 23.31014252], [68.75152588, 23.3101387], [68.75152588, 23.31347466], [68.75180817, 23.31347466], [68.75180817, 23.31458473], [68.75208282, 23.31458473], [68.75208282, 23.31569672], [68.75235748, 23.31569672], [68.75235748, 23.31680679], [68.75263214, 23.31680107], [68.75263214, 23.3176403], [68.75291443, 23.3176384], [68.75291443, 23.31847191], [68.75319672, 23.31847], [68.75319672, 23.31931114], [68.75347137, 23.31931114], [68.75347137, 23.32014084], [68.75374603, 23.32014084], [68.75374603, 23.32098007], [68.75402832, 23.32098007], [68.75402832, 23.32181168], [68.75430298, 23.32181168], [68.75430298, 23.32263947], [68.75458527, 23.32263947], [68.75458527, 23.3231945], [68.75485992, 23.32319069], [68.75485992, 23.32374954], [68.75514221, 23.32374954], [68.75514221, 23.32430267], [68.75541687, 23.32430649], [68.75541687, 23.32486343], [68.75569153, 23.32485962], [68.75569153, 23.32542038], [68.75597382, 23.32541656], [68.75597382, 23.3259716], [68.75624847, 23.3259697], [68.75624847, 23.32653046], [68.75653076, 23.32652855], [68.75653076, 23.32708549], [68.75680542, 23.32708549], [68.75680542, 23.32736015], [68.75708008, 23.32736015], [68.75708008, 23.32764053], [68.75736237, 23.32763863], [68.75736237, 23.32819557], [68.75763702, 23.32818985], [68.75763702, 23.32875061], [68.75791931, 23.32875061], [68.75791931, 23.32986069], [68.75818634, 23.32986069], [68.75818634, 23.33041954], [68.75763702, 23.33041954], [68.75763702, 23.3301506], [68.75736237, 23.3301506], [68.75736237, 23.32958031], [68.75708008, 23.32958412], [68.75708008, 23.32902718], [68.75681305, 23.32903099], [68.75681305, 23.32875061], [68.75653076, 23.32875061], [68.75653076, 23.32818985], [68.75624847, 23.32819557], [68.75624847, 23.32763863], [68.75596619, 23.32764053], [68.75596619, 23.32736015], [68.75569153, 23.32736206], [68.75569153, 23.32680321], [68.75541687, 23.32681084], [68.75541687, 23.32625008], [68.75514221, 23.32625008], [68.75514221, 23.32570076], [68.75485992, 23.32570076], [68.75485992, 23.32514191], [68.7545929, 23.32514191], [68.7545929, 23.32458115], [68.75430298, 23.32458115], [68.75430298, 23.32402802], [68.75402832, 23.32402802], [68.75402832, 23.32347107], [68.75375366, 23.32347107], [68.75375366, 23.32291603], [68.75347137, 23.32292175], [68.75347137, 23.32235909], [68.75319672, 23.32235909], [68.75319672, 23.32181168], [68.7529068, 23.32181168], [68.7529068, 23.32125092], [68.75263214, 23.32125092], [68.75263214, 23.32041931], [68.75235748, 23.32041931], [68.75235748, 23.31957817], [68.75208282, 23.31958389], [68.75208282, 23.31875038], [68.75180817, 23.31875038], [68.75180817, 23.31792068], [68.75152588, 23.31792068], [68.75152588, 23.31707954], [68.75125122, 23.31708336], [68.75125122, 23.31652832], [68.75096893, 23.31653023], [68.75096893, 23.31569099], [68.75069427, 23.31569672], [68.75069427, 23.3148613], [68.75041962, 23.3148613], [68.75041962, 23.31374931], [68.75013733, 23.31375122], [68.75013733, 23.31291962], [68.74986267, 23.31291962], [68.74986267, 23.31208038], [68.74958038, 23.31208229], [68.74958038, 23.31152725], [68.74931335, 23.31153107], [68.74931335, 23.31097031], [68.74903107, 23.31097031], [68.74903107, 23.3101387], [68.74874878, 23.31014252], [68.74874878, 23.30958176], [68.74847412, 23.30958366], [68.74847412, 23.30874825], [68.74819183, 23.30874825], [68.74819183, 23.30791855], [68.74791718, 23.30791855], [68.74791718, 23.30680084], [68.74764252, 23.30680466], [68.74764252, 23.30652809], [68.74736023, 23.30652809], [68.74736023, 23.30624962], [68.74708557, 23.30624962], [68.74708557, 23.30597305], [68.74680328, 23.30598068], [68.74680328, 23.30569077], [68.7454071, 23.30569077], [68.7454071, 23.30598068], [68.74485779, 23.30598068], [68.74485779, 23.30624962], [68.74458313, 23.30624962], [68.74458313, 23.30652809], [68.74402618, 23.30652809], [68.74402618, 23.30680466], [68.74375153, 23.30680466], [68.74375153, 23.30708313], [68.74319458, 23.30708313], [68.74319458, 23.3073616], [68.74263763, 23.3073597], [68.74263763, 23.30763817], [68.74180603, 23.30763817], [68.74180603, 23.30791855], [68.74124908, 23.30791855], [68.74124908, 23.30820084], [68.74069214, 23.30819511], [68.74069214, 23.30847168], [68.74013519, 23.30847168], [68.74014282, 23.30874825], [68.73929596, 23.30874825], [68.73929596, 23.30904007], [68.73874664, 23.30904007], [68.73874664, 23.30931282], [68.73513794, 23.30931282], [68.73513794, 23.30904007], [68.73430634, 23.30904007], [68.73430634, 23.30874825], [68.73374939, 23.30874825], [68.73374939, 23.30846977], [68.73347473, 23.30847168], [68.73347473, 23.30819511], [68.73291779, 23.30820084], [68.73291779, 23.30791855], [68.73236084, 23.30791855], [68.73236084, 23.30763817], [68.73208618, 23.30763817], [68.73208618, 23.3073597], [68.73180389, 23.3073616], [68.73180389, 23.30708313], [68.73152924, 23.30708313], [68.73152924, 23.30652809], [68.73124695, 23.30652809], [68.73124695, 23.30569077], [68.73097229, 23.30569458], [68.73097229, 23.30402756], [68.73069763, 23.30402946], [68.73069763, 23.30264091], [68.73042297, 23.30264091], [68.73042297, 23.30208015], [68.73014069, 23.30208588], [68.73014069, 23.30152512], [68.7298584, 23.30153084], [68.7298584, 23.30125046], [68.72957611, 23.30125046], [68.72957611, 23.30097008], [68.72930908, 23.30097389], [68.72930908, 23.30041695], [68.72902679, 23.30042076], [68.72902679, 23.30014038], [68.72875214, 23.30014038], [68.72875214, 23.29985046], [68.72846985, 23.29986382], [68.72846985, 23.29958153], [68.72819519, 23.29958153], [68.72819519, 23.29930305], [68.72763824, 23.29931068], [68.72763824, 23.2990303], [68.72735596, 23.2990303], [68.72735596, 23.29874992], [68.72680664, 23.29874992], [68.72680664, 23.29846954], [68.72652435, 23.29847145], [68.72652435, 23.29819489], [68.72597504, 23.29819489], [68.72597504, 23.29791641], [68.7251358, 23.29792023], [68.7251358, 23.29764175], [68.72458649, 23.29764175], [68.72458649, 23.29735947], [68.72402954, 23.29736137], [68.72402954, 23.2970829], [68.7206955, 23.2970829], [68.7206955, 23.29736137], [68.71985626, 23.29735947], [68.71985626, 23.29764175], [68.71930695, 23.29764175], [68.71930695, 23.29792023], [68.7179184, 23.29791641], [68.7179184, 23.29819489], [68.71652985, 23.29819489], [68.71652985, 23.29847145], [68.7159729, 23.29846954], [68.7159729, 23.29874992], [68.71569824, 23.29874992], [68.71569824, 23.2990303], [68.7151413, 23.2990303], [68.7151413, 23.29931068], [68.71485901, 23.29930305], [68.71485901, 23.29958153], [68.71430206, 23.29958153], [68.71430206, 23.29986382], [68.7140274, 23.29985046], [68.7140274, 23.30042076], [68.71375275, 23.30041695], [68.71375275, 23.30097389], [68.71347046, 23.30097389], [68.71347809, 23.30125046], [68.7131958, 23.30125046], [68.7131958, 23.30347252], [68.71347809, 23.30347061], [68.71347809, 23.30430984], [68.71736145, 23.30430984], [68.71736145, 23.30402946], [68.71847534, 23.30402756], [68.71847534, 23.3045826], [68.71708679, 23.30458069], [68.71708679, 23.30486107], [68.7159729, 23.30486107], [68.7159729, 23.30513954], [68.71375275, 23.30513954], [68.71375275, 23.30541992], [68.71347809, 23.30541992], [68.71347809, 23.30598068], [68.7131958, 23.30597305], [68.7131958, 23.30680466], [68.71291351, 23.30680466], [68.71291351, 23.3073616], [68.71263885, 23.3073597], [68.71263885, 23.30791855], [68.7123642, 23.30791664], [68.7123642, 23.30847168], [68.71208191, 23.30846977], [68.71208191, 23.30904007], [68.71180725, 23.30902863], [68.71180725, 23.30958366], [68.71153259, 23.30958176], [68.71153259, 23.31014252], [68.71125031, 23.3101387], [68.71125031, 23.31069374], [68.7104187, 23.31069183], [68.7104187, 23.31264114], [68.70929718, 23.31264114], [68.70929718, 23.31291962], [68.70735931, 23.3129158], [68.70735931, 23.31319237], [68.7076416, 23.31319046], [68.7076416, 23.31375122], [68.70791626, 23.31375122], [68.70791626, 23.31402969], [68.70847321, 23.31402969], [68.70847321, 23.31431007], [68.70874786, 23.31430626], [68.70874786, 23.31458473], [68.70847321, 23.31458473], [68.70847321, 23.3148613], [68.7076416, 23.3148613], [68.7076416, 23.31458473], [68.70652771, 23.31458473], [68.70652771, 23.31430626], [68.70540619, 23.31431007], [68.70540619, 23.31402969], [68.70430756, 23.31402969], [68.70430756, 23.31375122], [68.70291901, 23.31375122], [68.70291901, 23.31347084], [68.70181274, 23.31347084], [68.70181274, 23.31375122], [68.69875336, 23.31375122], [68.69875336, 23.31347084], [68.69847107, 23.31347466], [68.69847107, 23.31319237], [68.69819641, 23.31319237], [68.69819641, 23.3129158], [68.69763947, 23.31291962], [68.69763947, 23.31264114], [68.69680786, 23.31264114], [68.69680786, 23.31069183], [68.69625092, 23.31069374], [68.69625092, 23.31041718], [68.69568634, 23.3104229], [68.69568634, 23.31014252], [68.69513702, 23.31014252], [68.69513702, 23.30986023], [68.69430542, 23.30986023], [68.69430542, 23.30958366], [68.69374847, 23.30958366], [68.69374847, 23.30930519], [68.69319153, 23.30931282], [68.69319153, 23.30904007], [68.69291687, 23.30904007], [68.69291687, 23.30874825], [68.69235229, 23.30874825], [68.69235229, 23.30846977], [68.69180298, 23.30846977], [68.69180298, 23.30874825], [68.69097137, 23.30874825], [68.69097137, 23.30904007], [68.68930817, 23.30904007], [68.68930817, 23.30874825], [68.68818665, 23.30874825], [68.68818665, 23.30846977], [68.68763733, 23.30847168], [68.68763733, 23.30819511], [68.68681335, 23.30820084], [68.68681335, 23.30791855], [68.68624878, 23.30791855], [68.68624878, 23.30763817], [68.68541718, 23.30763817], [68.68541718, 23.3073597], [68.68402863, 23.3073616], [68.68402863, 23.30708313], [68.68264008, 23.30708313], [68.68264008, 23.30680466], [68.68041992, 23.30680466], [68.68041992, 23.30708313], [68.68013763, 23.30708122], [68.68013763, 23.30791855], [68.67986298, 23.30791855], [68.67986298, 23.30820084], [68.67680359, 23.30819511], [68.67680359, 23.30847168], [68.67652893, 23.30847168], [68.67652893, 23.3073616], [68.67680359, 23.3073616], [68.67680359, 23.30708313], [68.67874908, 23.30708313], [68.67874908, 23.30652809], [68.6784668, 23.30652809], [68.6784668, 23.30569077], [68.67819214, 23.30569458], [68.67819214, 23.30541611], [68.67735291, 23.30541992], [68.67735291, 23.30513954], [68.67624664, 23.30513954], [68.67624664, 23.30541992], [68.67569733, 23.30541611], [68.67569733, 23.30569458], [68.67542267, 23.30569077], [68.67542267, 23.30652809], [68.67569733, 23.30652809], [68.67569733, 23.3073616], [68.67542267, 23.3073597], [68.67542267, 23.30820084], [68.67514038, 23.30820084], [68.67514038, 23.30763817], [68.67485809, 23.30763817], [68.67485809, 23.3073597], [68.67458344, 23.3073616], [68.67458344, 23.30708313], [68.67485809, 23.30708313], [68.67485809, 23.30680466], [68.67458344, 23.30680466], [68.67458344, 23.30624962], [68.67430878, 23.30624962], [68.67430878, 23.30458069], [68.67402649, 23.3045826], [68.67402649, 23.30402756], [68.67375183, 23.30402946], [68.67375183, 23.30375099], [68.67318726, 23.30375099], [68.67318726, 23.30402946], [68.67263794, 23.30402946], [68.67263794, 23.30430984], [68.67236328, 23.30430794], [68.67236328, 23.3045826], [68.67208099, 23.30458069], [68.67208099, 23.30486107], [68.67180634, 23.30486107], [68.67180634, 23.30541992], [68.67152405, 23.30541611], [68.67152405, 23.30569458], [68.67124939, 23.30569077], [68.67124939, 23.30624962], [68.6709671, 23.30624962], [68.6709671, 23.30652809], [68.67014313, 23.30652809], [68.67014313, 23.30624962], [68.66958618, 23.30624962], [68.66958618, 23.30598068], [68.66874695, 23.30598068], [68.66874695, 23.30513954], [68.66902924, 23.30513954], [68.66902924, 23.30375099], [68.66874695, 23.30375099], [68.66874695, 23.30347061], [68.66847229, 23.30347252], [68.66847229, 23.30319595], [68.66819763, 23.30319595], [68.66819763, 23.30291748], [68.66764069, 23.30291748], [68.66764069, 23.30319595], [68.6673584, 23.30319023], [68.6673584, 23.30430984], [68.66680908, 23.30430984], [68.66680908, 23.30402946], [68.66596985, 23.30402946], [68.66596985, 23.30375099], [68.6654129, 23.30375099], [68.6654129, 23.30347061], [68.66513824, 23.30347252], [68.66513824, 23.30319595], [68.6645813, 23.30319595], [68.6645813, 23.30291748], [68.66430664, 23.30291748], [68.66430664, 23.30319595], [68.66374969, 23.30319595], [68.66374969, 23.30347252], [68.66348267, 23.30347061], [68.66348267, 23.30375099], [68.66319275, 23.30375099], [68.66319275, 23.30402946], [68.66291809, 23.30402946], [68.66291809, 23.30430984], [68.6626358, 23.30430794], [68.6626358, 23.3045826], [68.66236115, 23.3045826], [68.66236877, 23.30513954], [68.66208649, 23.30513954], [68.66208649, 23.30569458], [68.66152954, 23.30569458], [68.66152954, 23.30541611], [68.66069794, 23.30541992], [68.66069794, 23.30513954], [68.66041565, 23.30513954], [68.66041565, 23.30486107], [68.66014099, 23.30486107], [68.66014099, 23.30458069], [68.6598587, 23.3045826], [68.6598587, 23.30430794], [68.65957642, 23.30430984], [68.65957642, 23.30375099], [68.65930939, 23.30375099], [68.65930939, 23.30347061], [68.65875244, 23.30347061], [68.65875244, 23.30375099], [68.65847015, 23.30375099], [68.65847015, 23.30402946], [68.6581955, 23.30402756], [68.6581955, 23.3045826], [68.65847015, 23.30458069], [68.65847015, 23.30513954], [68.65875244, 23.30513954], [68.65875244, 23.30598068], [68.6590271, 23.30598068], [68.6590271, 23.30652809], [68.65930176, 23.30652809], [68.65930939, 23.3073616], [68.65957642, 23.3073597], [68.65957642, 23.30820084], [68.6598587, 23.30820084], [68.6598587, 23.30904007], [68.66014099, 23.30904007], [68.66014099, 23.3104229], [68.66042328, 23.3104229], [68.66042328, 23.31903076], [68.66069794, 23.31903076], [68.66069794, 23.31986046], [68.6609726, 23.31986046], [68.6609726, 23.32014084], [68.66152954, 23.32014084], [68.66152954, 23.32041931], [68.6618042, 23.3204174], [68.6618042, 23.32069397], [68.66208649, 23.32068825], [68.66208649, 23.32098007], [68.6626358, 23.32098007], [68.6626358, 23.32125092], [68.66291809, 23.32125092], [68.66291809, 23.32152939], [68.66348267, 23.32152939], [68.66348267, 23.32181168], [68.66374969, 23.32180595], [68.66374969, 23.32208252], [68.66430664, 23.32208061], [68.66430664, 23.32235909], [68.66625214, 23.32235909], [68.66625214, 23.32263947], [68.6673584, 23.32263947], [68.6673584, 23.32292175], [68.66819763, 23.32291603], [68.66819763, 23.32347107], [68.66847229, 23.32347107], [68.66847229, 23.32402802], [68.66930389, 23.32402802], [68.66930389, 23.32486343], [68.66902924, 23.32485962], [68.66902924, 23.32514191], [68.66874695, 23.32514191], [68.66874695, 23.32542038], [68.66792297, 23.32542038], [68.66792297, 23.32514191], [68.66764069, 23.32514191], [68.66764069, 23.32485962], [68.66708374, 23.32486343], [68.66708374, 23.32458115], [68.66680908, 23.32458115], [68.66680908, 23.32430649], [68.66652679, 23.3243103], [68.66652679, 23.32401848], [68.66625214, 23.32402802], [68.66625214, 23.32374954], [68.66596985, 23.32374954], [68.66596985, 23.32346916], [68.66486359, 23.32347107], [68.66486359, 23.3231945], [68.66374969, 23.3231945], [68.66374969, 23.32291603], [68.6626358, 23.32291603], [68.6626358, 23.32347107], [68.66291809, 23.32347107], [68.66291809, 23.32402802], [68.66069794, 23.32402802], [68.66069794, 23.32347107], [68.66041565, 23.32347107], [68.66041565, 23.32291603], [68.65958405, 23.32291603], [68.65958405, 23.3231945], [68.6590271, 23.3231945], [68.6590271, 23.32291603], [68.65875244, 23.32292175], [68.65875244, 23.32235909], [68.6590271, 23.32235909], [68.6590271, 23.32181168], [68.65930939, 23.32181168], [68.65930939, 23.32152939], [68.65875244, 23.32152939], [68.65875244, 23.32125092], [68.6581955, 23.32125092], [68.6581955, 23.32097244], [68.65791321, 23.32098007], [68.65791321, 23.32041931], [68.65763855, 23.32041931], [68.65763855, 23.31986046], [68.65735626, 23.31986046], [68.65735626, 23.31957817], [68.65763855, 23.31958389], [68.65763855, 23.31930542], [68.65791321, 23.31931114], [68.65791321, 23.31875038], [68.65820313, 23.31875038], [68.6581955, 23.31791878], [68.65847015, 23.31792068], [68.65847015, 23.31680107], [68.65875244, 23.31680679], [68.65875244, 23.31541634], [68.6590271, 23.31542015], [68.6590271, 23.31431007], [68.65930939, 23.31431007], [68.65930939, 23.31319046], [68.6590271, 23.31319237], [68.6590271, 23.3129158], [68.65875244, 23.31291962], [68.65875244, 23.31264114], [68.6590271, 23.31264114], [68.6590271, 23.30986023], [68.65875244, 23.30986023], [68.65875244, 23.30874825], [68.65847015, 23.30874825], [68.65847015, 23.30820084], [68.65820313, 23.30820084], [68.65820313, 23.30763817], [68.65791321, 23.30763817], [68.65791321, 23.30708122], [68.65763855, 23.30708313], [68.65763855, 23.30652809], [68.65735626, 23.30652809], [68.65735626, 23.30541992], [68.6570816, 23.30541992], [68.6570816, 23.30458069], [68.65680695, 23.3045826], [68.65680695, 23.30319595], [68.65652466, 23.30319595], [68.65652466, 23.30291748], [68.65569305, 23.30291939], [68.65569305, 23.30264091], [68.6534729, 23.30264091], [68.6534729, 23.30291939], [68.65235901, 23.30291748], [68.65235901, 23.30319595], [68.6526413, 23.30319023], [68.6526413, 23.30430984], [68.65208435, 23.30430794], [68.65208435, 23.3045826], [68.65180206, 23.30458069], [68.65180206, 23.30513954], [68.65097046, 23.30513954], [68.65097046, 23.30486107], [68.6506958, 23.30486107], [68.6506958, 23.30430984], [68.65013885, 23.30430794], [68.65013885, 23.3045826], [68.64985657, 23.30458069], [68.64985657, 23.30486107], [68.64958191, 23.30486107], [68.64958191, 23.30541992], [68.64930725, 23.30541611], [68.64930725, 23.30569458], [68.64903259, 23.30569077], [68.64903259, 23.30652809], [68.64930725, 23.30652809], [68.64930725, 23.30763817], [68.64903259, 23.30763817], [68.64903259, 23.30791855], [68.64848328, 23.30791855], [68.64848328, 23.30820084], [68.64819336, 23.30819511], [68.64819336, 23.30847168], [68.6479187, 23.30846977], [68.6479187, 23.31014252], [68.64763641, 23.31014252], [68.64763641, 23.31153107], [68.64736176, 23.31152725], [68.64736176, 23.31319237], [68.6470871, 23.31319046], [68.6470871, 23.31431007], [68.64680481, 23.31430626], [68.64680481, 23.31458473], [68.6470871, 23.31458473], [68.6470871, 23.3148613], [68.64680481, 23.3148613], [68.64680481, 23.31569672], [68.64653015, 23.31569099], [68.64653015, 23.31624985], [68.64624786, 23.31624985], [68.64624786, 23.31736183], [68.64597321, 23.31736183], [68.64597321, 23.31847191], [68.64569092, 23.31847], [68.64569092, 23.31931114], [68.64541626, 23.31931114], [68.64541626, 23.31986046], [68.6451416, 23.31986046], [68.6451416, 23.32098007], [68.64485931, 23.32098007], [68.64485931, 23.32181168], [68.64457703, 23.32181168], [68.64457703, 23.32263947], [68.64430237, 23.32263947], [68.64430237, 23.32292175], [68.64402771, 23.32291603], [68.64402771, 23.3231945], [68.64375305, 23.3231945], [68.64375305, 23.32291603], [68.64347076, 23.32292175], [68.64347076, 23.32263947], [68.64290619, 23.32263947], [68.64290619, 23.32235909], [68.64263916, 23.32235909], [68.64263916, 23.32208061], [68.6423645, 23.32208252], [68.6423645, 23.32180595], [68.64208221, 23.32181168], [68.64208221, 23.32152939], [68.64180756, 23.32152939], [68.64180756, 23.32125092], [68.64152527, 23.32125092], [68.64152527, 23.32097244], [68.64124298, 23.32098007], [68.64124298, 23.32041931], [68.64097595, 23.32041931], [68.64097595, 23.32014084], [68.64068604, 23.32014084], [68.64068604, 23.31986046], [68.64041901, 23.31986046], [68.64041901, 23.31957817], [68.63986206, 23.31958389], [68.63986206, 23.31930542], [68.63903046, 23.31931114], [68.63903046, 23.31903076], [68.63819885, 23.31903076], [68.63819885, 23.31875038], [68.63791656, 23.31875038], [68.63791656, 23.31847], [68.63764191, 23.31847191], [68.63764191, 23.31819534], [68.63735962, 23.3182106], [68.63735962, 23.31792068], [68.63709259, 23.31792068], [68.63709259, 23.31735992], [68.63680267, 23.31736183], [68.63680267, 23.31680679], [68.63652802, 23.31680679], [68.63652802, 23.31652832], [68.63569641, 23.31652832], [68.63569641, 23.31680679], [68.63541412, 23.31680679], [68.63541412, 23.31708336], [68.63513947, 23.31708336], [68.63513947, 23.31736183], [68.63485718, 23.31735992], [68.63485718, 23.3176403], [68.63458252, 23.3176403], [68.63458252, 23.31792068], [68.6340332, 23.31792068], [68.6340332, 23.3182106], [68.63375092, 23.31819534], [68.63375092, 23.31847191], [68.63346863, 23.31847], [68.63346863, 23.31875038], [68.63318634, 23.31875038], [68.63318634, 23.31903076], [68.63291931, 23.31903076], [68.63291931, 23.31931114], [68.63318634, 23.31931114], [68.63318634, 23.32292175], [68.63291931, 23.32291603], [68.63291931, 23.32347107], [68.63263702, 23.32347107], [68.63263702, 23.32402802], [68.63291931, 23.32402802], [68.63291931, 23.32430267], [68.63319397, 23.32430649], [68.63319397, 23.32486343], [68.63346863, 23.32485962], [68.63346863, 23.32542038], [68.63375092, 23.32542038], [68.63375092, 23.32625008], [68.6340332, 23.32625008], [68.6340332, 23.32681084], [68.63430786, 23.32680321], [68.63430786, 23.32708549], [68.63458252, 23.32707977], [68.63458252, 23.32736015], [68.63485718, 23.32736015], [68.63485718, 23.32764053], [68.63513947, 23.32764053], [68.63513947, 23.32792091], [68.63541412, 23.3279171], [68.63541412, 23.32819557], [68.63569641, 23.32818985], [68.63569641, 23.32875061], [68.63597107, 23.32875061], [68.63597107, 23.32903099], [68.63625336, 23.32903099], [68.63625336, 23.32930946], [68.63652802, 23.32930946], [68.63652802, 23.32986069], [68.63680267, 23.32986069], [68.63680267, 23.3301506], [68.63709259, 23.3301506], [68.63709259, 23.33041954], [68.63735962, 23.33041763], [68.63735962, 23.33097267], [68.63764191, 23.33097076], [68.63764191, 23.33125114], [68.63735962, 23.33125114], [68.63735962, 23.33152962], [68.63652802, 23.33152962], [68.63652802, 23.33125114], [68.63625336, 23.33125114], [68.63625336, 23.33097076], [68.63597107, 23.33097267], [68.63597107, 23.3306942], [68.63569641, 23.3306942], [68.63569641, 23.33041763], [68.63540649, 23.33041954], [68.63540649, 23.3301506], [68.63513947, 23.3301506], [68.63513947, 23.32986069], [68.63485718, 23.32986069], [68.63485718, 23.32958031], [68.63430786, 23.32958412], [68.63430786, 23.32930565], [68.63346863, 23.32930565], [68.63346863, 23.32958412], [68.63318634, 23.32958031], [68.63318634, 23.3301506], [68.63291931, 23.33013916], [68.63291931, 23.33097267], [68.63263702, 23.33097076], [68.63263702, 23.33152962], [68.63375092, 23.33152962], [68.63375092, 23.33125114], [68.63486481, 23.33124924], [68.63486481, 23.33208275], [68.63458252, 23.33208084], [68.63458252, 23.33263969], [68.63430786, 23.33263969], [68.63430786, 23.33291817], [68.63402557, 23.33291626], [68.63402557, 23.3334713], [68.63430786, 23.33346939], [68.63430786, 23.33402824], [68.63402557, 23.33402824], [68.63402557, 23.33430481], [68.63375092, 23.33430481], [68.63375092, 23.33458328], [68.63346863, 23.33458328], [68.63346863, 23.33486176], [68.63207245, 23.33485985], [68.63207245, 23.33513832], [68.63096619, 23.33513832], [68.63096619, 23.3354187], [68.6279068, 23.3354187], [68.6279068, 23.3357029], [68.62652588, 23.33569527], [68.62652588, 23.33597183], [68.62596893, 23.33596039], [68.62596893, 23.33625031], [68.62568665, 23.33625031], [68.62568665, 23.33681107], [68.62541962, 23.33681107], [68.62541962, 23.33764267], [68.62513733, 23.33763885], [68.62513733, 23.33847046], [68.62486267, 23.33847046], [68.62486267, 23.3390274], [68.62458038, 23.3390274], [68.62458038, 23.33958244], [68.62486267, 23.33958054], [68.62486267, 23.33986282], [68.62513733, 23.33986282], [68.62513733, 23.34041977], [68.62541962, 23.34041977], [68.62541962, 23.34124947], [68.62568665, 23.34124947], [68.62568665, 23.34209061], [68.62541962, 23.34209061], [68.62541962, 23.34263992], [68.62568665, 23.34263992], [68.62568665, 23.34320068], [68.62596893, 23.34319687], [68.62596893, 23.34347153], [68.62652588, 23.34346962], [68.62652588, 23.34375], [68.62680817, 23.34375], [68.62680817, 23.34458351], [68.62568665, 23.3445797], [68.62568665, 23.34625053], [68.62680817, 23.34625053], [68.62680817, 23.34653091], [68.62708282, 23.34653091], [68.62708282, 23.34680748], [68.62735748, 23.34680748], [68.62735748, 23.34653091], [68.62763977, 23.34653091], [68.62763977, 23.34597015], [68.62735748, 23.34597206], [68.62735748, 23.34486198], [68.62763977, 23.34486198], [68.62763977, 23.34430695], [68.62930298, 23.34431076], [68.62930298, 23.34375], [68.6295929, 23.34375], [68.62958527, 23.34347153], [68.62875366, 23.34347153], [68.62875366, 23.34291649], [68.62902832, 23.3429203], [68.62902832, 23.34263992], [68.63014221, 23.34263992], [68.63014221, 23.34235954], [68.63180542, 23.34236145], [68.63180542, 23.34180641], [68.63153076, 23.34181023], [68.63153076, 23.34152985], [68.63124847, 23.34152985], [68.63124847, 23.34124947], [68.63096619, 23.34124947], [68.63096619, 23.34097099], [68.63319397, 23.34097481], [68.63319397, 23.34041405], [68.63346863, 23.34041977], [68.63346863, 23.33958054], [68.63375092, 23.33958244], [68.63375092, 23.33930588], [68.63485718, 23.33930969], [68.63485718, 23.33986282], [68.63458252, 23.33986282], [68.63458252, 23.34013939], [68.63430786, 23.34013939], [68.63430786, 23.34069252], [68.63402557, 23.34069252], [68.63402557, 23.34097481], [68.63485718, 23.34097099], [68.63485718, 23.34124947], [68.63540649, 23.34124947], [68.63540649, 23.34209061], [68.63569641, 23.34209061], [68.63569641, 23.3429203], [68.63652802, 23.3429203], [68.63652802, 23.34320068], [68.63680267, 23.34320068], [68.63680267, 23.34375], [68.63708496, 23.34375], [68.63708496, 23.34486198], [68.63680267, 23.34486008], [68.63680267, 23.34542084], [68.63708496, 23.34541893], [68.63709259, 23.34625053], [68.63680267, 23.34625053], [68.63680267, 23.34680748], [68.63458252, 23.34680557], [68.63458252, 23.34708405], [68.63430786, 23.34708023], [68.63430786, 23.34736061], [68.6340332, 23.34736061], [68.6340332, 23.34792137], [68.63375092, 23.34791756], [68.63375092, 23.34958267], [68.63346863, 23.34958076], [68.63346863, 23.35013962], [68.63319397, 23.35013962], [68.63319397, 23.3520813], [68.63236237, 23.3520813], [68.63236237, 23.35236359], [68.62958527, 23.35236359], [68.62958527, 23.3520813], [68.62930298, 23.3520813], [68.62930298, 23.35180473], [68.62847137, 23.35180473], [68.62847137, 23.35124969], [68.6279068, 23.35124969], [68.6279068, 23.35153008], [68.62735748, 23.35152817], [68.62735748, 23.35180473], [68.62680817, 23.35180283], [68.62680817, 23.35292053], [68.62652588, 23.35292053], [68.62652588, 23.35375023], [68.62625885, 23.35375023], [68.62625885, 23.35403061], [68.62541962, 23.35403061], [68.62541962, 23.35346985], [68.62513733, 23.35346985], [68.62513733, 23.35375023], [68.62458038, 23.35375023], [68.62458038, 23.35320091], [68.62431335, 23.35320091], [68.62431335, 23.35264015], [68.62346649, 23.35264015], [68.62346649, 23.35124969], [68.62374878, 23.35124969], [68.62374878, 23.35096169], [68.62403107, 23.35097122], [68.62403107, 23.35069466], [68.62374878, 23.35069466], [68.62374878, 23.35013962], [68.62346649, 23.35013962], [68.62346649, 23.35042191], [68.62291718, 23.35041618], [68.62291718, 23.35069466], [68.62264252, 23.35069275], [68.62264252, 23.35124969], [68.62236023, 23.35124969], [68.62236023, 23.35292053], [68.62264252, 23.35292053], [68.62264252, 23.35375023], [68.62291718, 23.35375023], [68.62291718, 23.35403061], [68.6220932, 23.35403061], [68.6220932, 23.35375023], [68.62152863, 23.35375023], [68.62152863, 23.35542107], [68.62208557, 23.35541725], [68.62208557, 23.35569572], [68.62236023, 23.35569], [68.62236023, 23.35709], [68.62208557, 23.35708427], [68.6220932, 23.35736084], [68.62180328, 23.35736084], [68.62180328, 23.35764122], [68.62152863, 23.35764122], [68.62152863, 23.35791969], [68.62124634, 23.35791779], [68.62124634, 23.35819435], [68.62069702, 23.35819435], [68.62069702, 23.35791779], [68.6204071, 23.35791969], [68.6204071, 23.35764122], [68.61985779, 23.35764122], [68.61985779, 23.35736084], [68.61707306, 23.35736084], [68.61707306, 23.35764122], [68.61653137, 23.35764122], [68.61653137, 23.35791969], [68.61597443, 23.35791779], [68.61597443, 23.35819435], [68.61569214, 23.35819435], [68.61569214, 23.35847282], [68.61513519, 23.35847282], [68.61514282, 23.35874939], [68.61486053, 23.35874939], [68.61486053, 23.35902977], [68.61458588, 23.35902786], [68.61458588, 23.3595829], [68.61429596, 23.35958099], [68.61429596, 23.36041832], [68.61458588, 23.36041641], [68.61458588, 23.36069489], [68.61486053, 23.36069489], [68.61486053, 23.36097145], [68.61513519, 23.36097145], [68.61514282, 23.36124992], [68.61486053, 23.36124992], [68.61486053, 23.36208344], [68.61458588, 23.36208344], [68.61458588, 23.36236191], [68.61430359, 23.36236191], [68.61430359, 23.36180496], [68.61402893, 23.36181068], [68.61402893, 23.3615284], [68.61319733, 23.3615284], [68.61319733, 23.36181068], [68.61291504, 23.36180496], [68.61291504, 23.36458206], [68.61319733, 23.36458015], [68.61319733, 23.36514282], [68.61429596, 23.36514282], [68.61429596, 23.36541939], [68.61513519, 23.36541748], [68.61513519, 23.36569214], [68.61624908, 23.36569214], [68.61624908, 23.36541748], [68.61653137, 23.36541939], [68.61653137, 23.36514282], [68.61680603, 23.36514282], [68.61680603, 23.36486053], [68.61736298, 23.36486053], [68.61736298, 23.36458015], [68.61819458, 23.36458206], [68.61819458, 23.3643055], [68.61930847, 23.3643055], [68.61930847, 23.36458206], [68.61958313, 23.36458015], [68.61958313, 23.36541939], [68.61902618, 23.36541748], [68.61902618, 23.36569214], [68.61875153, 23.36569214], [68.61875153, 23.36597443], [68.61818695, 23.36597061], [68.61818695, 23.36626053], [68.61707306, 23.36626053], [68.61707306, 23.36652946], [68.61653137, 23.36652946], [68.61653137, 23.36680984], [68.61569214, 23.36680412], [68.61569214, 23.3670845], [68.61291504, 23.3670845], [68.61292267, 23.36736107], [68.61264038, 23.36736107], [68.61264038, 23.36763954], [68.61207581, 23.36763954], [68.61207581, 23.36791992], [68.61180878, 23.3679142], [68.61180878, 23.36819267], [68.61152649, 23.36819077], [68.61152649, 23.36874962], [68.61125183, 23.36874962], [68.61125183, 23.36930656], [68.61096954, 23.36930656], [68.61096954, 23.3698616], [68.61068726, 23.3698597], [68.61068726, 23.37042046], [68.60901642, 23.37042046], [68.60901642, 23.37070084], [68.60874939, 23.37070084], [68.60874939, 23.37375069], [68.60819244, 23.37375069], [68.60819244, 23.37402916], [68.60791779, 23.37402916], [68.60791779, 23.37431145], [68.6076355, 23.37430573], [68.6076355, 23.3745842], [68.60708618, 23.37458038], [68.60708618, 23.37486076], [68.60569763, 23.37486076], [68.60569763, 23.37513924], [68.60542297, 23.3751297], [68.60542297, 23.37542152], [68.60514069, 23.3754158], [68.60514069, 23.37569427], [68.60542297, 23.37569046], [68.60542297, 23.37624931], [68.60624695, 23.37624931], [68.60624695, 23.3765316], [68.60652924, 23.3765316], [68.60652924, 23.37681007], [68.60430908, 23.37680626], [68.60430908, 23.37708282], [68.60320282, 23.37708092], [68.60320282, 23.37820053], [68.60375214, 23.37819481], [68.60375214, 23.37847137], [68.60430908, 23.37846947], [68.60430908, 23.37874985], [68.60458374, 23.37874985], [68.60458374, 23.37930489], [68.6048584, 23.37930489], [68.6048584, 23.37986374], [68.60569763, 23.37985992], [68.60569763, 23.38042068], [68.60597229, 23.38041687], [68.60597229, 23.38097382], [68.60513306, 23.38097], [68.60513306, 23.38125992], [68.60457611, 23.38125992], [68.60457611, 23.38153076], [68.60402679, 23.38153076], [68.60402679, 23.38181114], [68.60346985, 23.38180351], [68.60346985, 23.3820858], [68.60319519, 23.3820858], [68.60320282, 23.38236046], [68.60263824, 23.38236046], [68.60263824, 23.38264084], [68.60236359, 23.38263893], [68.60236359, 23.38319588], [68.6020813, 23.38319588], [68.6020813, 23.38347244], [68.60151672, 23.38347054], [68.60151672, 23.38375092], [68.60069275, 23.38375092], [68.60069275, 23.38402939], [68.60041809, 23.38402748], [68.60041809, 23.38430786], [68.6001358, 23.38430786], [68.6001358, 23.38458252], [68.5993042, 23.38458252], [68.5993042, 23.38430786], [68.59902954, 23.38430786], [68.59902954, 23.38402748], [68.59874725, 23.38402939], [68.59874725, 23.38375092], [68.5984726, 23.38375092], [68.5984726, 23.38347054], [68.59791565, 23.38347244], [68.59791565, 23.38319588], [68.5973587, 23.38319588], [68.5973587, 23.3829174], [68.59707642, 23.38292122], [68.59707642, 23.38264084], [68.59680176, 23.38264084], [68.59680176, 23.38236046], [68.59625244, 23.38236046], [68.59625244, 23.38208008], [68.59597015, 23.3820858], [68.59597015, 23.38152695], [68.59625244, 23.38153076], [68.59625244, 23.37903023], [68.5965271, 23.37903023], [68.5965271, 23.37846947], [68.59680176, 23.37847137], [68.59680176, 23.37819481], [68.59902954, 23.37820053], [68.59902954, 23.37763977], [68.59958649, 23.37763977], [68.59958649, 23.37735939], [68.6001358, 23.3773613], [68.6001358, 23.37680626], [68.59986115, 23.37681007], [68.59986115, 23.37624931], [68.59958649, 23.37624931], [68.59958649, 23.37347031], [68.59986115, 23.37347221], [68.59986115, 23.37291718], [68.6001358, 23.37291908], [68.6001358, 23.37264061], [68.60041809, 23.37264061], [68.60041809, 23.37236023], [68.60098267, 23.37236023], [68.60097504, 23.37208366], [68.60124969, 23.37208366], [68.60124969, 23.37180519], [68.60151672, 23.37181091], [68.60151672, 23.37125015], [68.60180664, 23.37125015], [68.60180664, 23.37096977], [68.6020813, 23.37097168], [68.6020813, 23.37069511], [68.60235596, 23.37070084], [68.60235596, 23.37042046], [68.6029129, 23.37042046], [68.6029129, 23.3698597], [68.60319519, 23.3698616], [68.60319519, 23.36902809], [68.6029129, 23.36903], [68.6029129, 23.36791992], [68.60263824, 23.36791992], [68.60263824, 23.36708069], [68.6029129, 23.3670845], [68.6029129, 23.36680412], [68.60320282, 23.36680984], [68.60320282, 23.36626053], [68.60346985, 23.36626053], [68.60346985, 23.36569023], [68.60375214, 23.36569214], [68.60375214, 23.36541748], [68.60402679, 23.36541939], [68.60402679, 23.36514282], [68.60457611, 23.36514282], [68.60457611, 23.36486053], [68.6048584, 23.36486053], [68.6048584, 23.36431122], [68.60513306, 23.36431122], [68.60513306, 23.36403275], [68.60542297, 23.36403275], [68.60542297, 23.36347008], [68.60569763, 23.36347008], [68.60569763, 23.36291695], [68.60542297, 23.36292267], [68.60542297, 23.36235809], [68.60402679, 23.36236191], [68.60402679, 23.36208344], [68.60346985, 23.36208344], [68.60346985, 23.36180496], [68.60235596, 23.36181068], [68.60235596, 23.3615284], [68.60263824, 23.3615284], [68.60263824, 23.36124992], [68.6029129, 23.36124992], [68.6029129, 23.36096954], [68.60319519, 23.36097145], [68.60319519, 23.36041641], [68.60346985, 23.36041832], [68.60346985, 23.35985947], [68.60319519, 23.35986137], [68.60319519, 23.35930634], [68.60236359, 23.35930634], [68.60236359, 23.3595829], [68.6020813, 23.3595829], [68.6020813, 23.36013985], [68.60098267, 23.36013031], [68.60098267, 23.36041832], [68.60069275, 23.36041641], [68.60069275, 23.36069489], [68.60041809, 23.36069489], [68.60041809, 23.36097145], [68.6001358, 23.36096954], [68.6001358, 23.3615284], [68.59986115, 23.3615284], [68.59986115, 23.36236191], [68.60041809, 23.36235809], [68.60041809, 23.36264038], [68.60069275, 23.36263847], [68.60069275, 23.36319351], [68.60097504, 23.36319351], [68.60097504, 23.36347008], [68.60069275, 23.36347008], [68.60069275, 23.36375046], [68.60041809, 23.36375046], [68.60041809, 23.36403275], [68.6001358, 23.36402702], [68.6001358, 23.36597443], [68.59986115, 23.36597061], [68.59986115, 23.36652946], [68.59958649, 23.36652756], [68.59958649, 23.3670845], [68.59929657, 23.36708069], [68.59929657, 23.36763954], [68.59902954, 23.36763954], [68.59902954, 23.36819267], [68.59874725, 23.36819077], [68.59874725, 23.36874962], [68.5984726, 23.36874962], [68.5984726, 23.36903], [68.59819794, 23.36902809], [68.59819794, 23.36958313], [68.59791565, 23.36958313], [68.59791565, 23.3698616], [68.59764099, 23.3698597], [68.59764099, 23.37014008], [68.5965271, 23.37014008], [68.5965271, 23.37042046], [68.59597015, 23.37042046], [68.59597015, 23.37070084], [68.5956955, 23.37069511], [68.5956955, 23.37097168], [68.59541321, 23.37096977], [68.59541321, 23.37125015], [68.59513855, 23.37125015], [68.59513855, 23.37153053], [68.59485626, 23.37153053], [68.59485626, 23.37181091], [68.5945816, 23.37181091], [68.5945816, 23.37236023], [68.59430695, 23.37236023], [68.59430695, 23.37319374], [68.59401703, 23.37318993], [68.59401703, 23.37375069], [68.59375, 23.37375069], [68.59375, 23.37431145], [68.59347534, 23.37430573], [68.59347534, 23.3745842], [68.5929184, 23.3745842], [68.5929184, 23.37430573], [68.59152985, 23.37430573], [68.59152985, 23.3745842], [68.59124756, 23.37458038], [68.59124756, 23.37486076], [68.59069824, 23.37486076], [68.59069824, 23.37513924], [68.59041595, 23.3751297], [68.59041595, 23.37542152], [68.5901413, 23.3754158], [68.5901413, 23.37569427], [68.58985901, 23.37569046], [68.58985901, 23.3765316], [68.58958435, 23.37652779], [68.58958435, 23.3773613], [68.58930206, 23.37735939], [68.58930206, 23.37763977], [68.5890274, 23.37763977], [68.5890274, 23.37792015], [68.58875275, 23.37792015], [68.58875275, 23.37820053], [68.58847046, 23.37819481], [68.58847046, 23.37986374], [68.58763885, 23.37985992], [68.58763885, 23.38042068], [68.58790588, 23.38042068], [68.58790588, 23.38070107], [68.58763885, 23.38069534], [68.58763885, 23.38097382], [68.58708954, 23.38097], [68.58708954, 23.38125992], [68.58653259, 23.38125992], [68.58653259, 23.38153076], [68.58597565, 23.38152695], [68.58597565, 23.38236046], [68.58625031, 23.38236046], [68.58625031, 23.38264084], [68.58569336, 23.38264084], [68.58569336, 23.38292122], [68.58430481, 23.3829174], [68.58430481, 23.38319588], [68.58374786, 23.38319016], [68.58374786, 23.38375092], [68.58403015, 23.38375092], [68.58403015, 23.38486099], [68.58374786, 23.38486099], [68.58374786, 23.3856945], [68.58347321, 23.38569069], [68.58347321, 23.38624954], [68.5845871, 23.38624954], [68.5845871, 23.3868084], [68.58403015, 23.38680649], [68.58403015, 23.38708305], [68.58291626, 23.38708305], [68.58291626, 23.38736153], [68.58235931, 23.38735962], [68.58235931, 23.38763809], [68.58180237, 23.38763809], [68.58180237, 23.38820076], [68.58152771, 23.38820076], [68.58152771, 23.38902855], [68.58125305, 23.38902855], [68.58125305, 23.38958359], [68.58097076, 23.38958359], [68.58097076, 23.38986015], [68.58013916, 23.38986015], [68.58013916, 23.38958359], [68.5798645, 23.38958359], [68.5798645, 23.38930511], [68.57958221, 23.38931274], [68.57958221, 23.38902855], [68.57930756, 23.38902855], [68.57930756, 23.38874817], [68.57875061, 23.38874817], [68.57875061, 23.3884697], [68.57847595, 23.3884716], [68.57847595, 23.38708305], [68.57875061, 23.38708305], [68.57875061, 23.38652992], [68.57847595, 23.38652992], [68.57847595, 23.38597107], [68.57791901, 23.38597107], [68.57791901, 23.38624954], [68.57763672, 23.38624954], [68.57763672, 23.38652992], [68.57707977, 23.38652992], [68.57707977, 23.3868084], [68.57680511, 23.38680649], [68.57680511, 23.38708305], [68.57624817, 23.38708305], [68.57624817, 23.38736153], [68.57596588, 23.38735962], [68.57596588, 23.38763809], [68.57514954, 23.38763809], [68.57514954, 23.38791847], [68.57402802, 23.38791847], [68.57402802, 23.38820076], [68.57375336, 23.38820076], [68.57375336, 23.38931274], [68.57402802, 23.38930511], [68.57402802, 23.38958359], [68.57430267, 23.38958168], [68.57430267, 23.39014244], [68.57290649, 23.39014244], [68.57290649, 23.39042282], [68.57263947, 23.39042282], [68.57263947, 23.39125061], [68.57290649, 23.39125061], [68.57290649, 23.39180946], [68.57180786, 23.39180946], [68.57180786, 23.3915329], [68.5715332, 23.3915329], [68.5715332, 23.39125061], [68.57096863, 23.39125061], [68.57096863, 23.39097023], [68.57041931, 23.39097023], [68.57041931, 23.39069366], [68.57013702, 23.39069366], [68.57013702, 23.39013863], [68.56986237, 23.39014244], [68.56986237, 23.38958168], [68.56958008, 23.38958359], [68.56958008, 23.38819504], [68.56930542, 23.38819504], [68.56930542, 23.3884716], [68.56903076, 23.3884716], [68.56903076, 23.38819504], [68.56819153, 23.38820076], [68.56819153, 23.38791847], [68.56874847, 23.38791847], [68.56874847, 23.38735962], [68.56930542, 23.38736153], [68.56930542, 23.38708305], [68.56958008, 23.38708305], [68.56958008, 23.38680649], [68.56986237, 23.38680077], [68.56986237, 23.38652992], [68.57013702, 23.38652992], [68.57013702, 23.38624954], [68.57041931, 23.38624954], [68.57041931, 23.38597107], [68.57069397, 23.38597298], [68.57069397, 23.3856945], [68.57096863, 23.3856945], [68.57096863, 23.38541794], [68.57125092, 23.38541985], [68.57125092, 23.38458061], [68.57152557, 23.38458252], [68.57152557, 23.38430786], [68.57180786, 23.38430786], [68.57180786, 23.38375092], [68.57208252, 23.38375092], [68.57208252, 23.38347054], [68.57236481, 23.38347244], [68.57236481, 23.3829174], [68.57319641, 23.38292122], [68.57319641, 23.38402939], [68.57291412, 23.38402748], [68.57291412, 23.38458252], [68.57263947, 23.38458061], [68.57263947, 23.38486099], [68.57208252, 23.38486099], [68.57208252, 23.38541985], [68.57180786, 23.38541985], [68.57180786, 23.38624954], [68.5715332, 23.38624954], [68.5715332, 23.38652992], [68.57125092, 23.38652992], [68.57125092, 23.38680458], [68.57208252, 23.38680458], [68.57208252, 23.38652992], [68.57235718, 23.38652992], [68.57235718, 23.38624954], [68.57319641, 23.38624954], [68.57319641, 23.38652992], [68.57375336, 23.38652992], [68.57375336, 23.38569069], [68.57402802, 23.3856945], [68.57402802, 23.38513947], [68.57430267, 23.38513947], [68.57430267, 23.38486099], [68.57459259, 23.38486099], [68.57458496, 23.38458252], [68.57485962, 23.38458252], [68.57485962, 23.38430786], [68.57541656, 23.38430786], [68.57541656, 23.38402748], [68.57569122, 23.38402939], [68.57569122, 23.38375092], [68.57596588, 23.38375092], [68.57596588, 23.38347054], [68.57680511, 23.38347244], [68.57680511, 23.38319588], [68.57736206, 23.38319588], [68.57736206, 23.38263893], [68.57763672, 23.38264084], [68.57763672, 23.38236046], [68.57791901, 23.38236046], [68.57791901, 23.38208008], [68.57819366, 23.3820858], [68.57819366, 23.38180351], [68.57847595, 23.38181114], [68.57847595, 23.38153076], [68.57875061, 23.38153076], [68.57875061, 23.38097], [68.57902527, 23.38097382], [68.57902527, 23.37986374], [68.57930756, 23.37986374], [68.57930756, 23.37958145], [68.57958221, 23.37958145], [68.57958221, 23.37902832], [68.58013916, 23.37903023], [68.58013916, 23.37792015], [68.57985687, 23.37792015], [68.57985687, 23.37735939], [68.57958221, 23.3773613], [68.57958221, 23.37708282], [68.5798645, 23.37708282], [68.5798645, 23.37652779], [68.58040619, 23.3765316], [68.58040619, 23.37624931], [68.57958221, 23.37624931], [68.57958221, 23.37597084], [68.57875061, 23.37597084], [68.57875061, 23.37624931], [68.57235718, 23.37624931], [68.57235718, 23.37597084], [68.57208252, 23.37597275], [68.57208252, 23.37569427], [68.57180786, 23.37569427], [68.57180786, 23.3754158], [68.57096863, 23.37542152], [68.57096863, 23.3751297], [68.57068634, 23.3751297], [68.57068634, 23.37542152], [68.57041931, 23.3754158], [68.57041931, 23.37569427], [68.57013702, 23.37569046], [68.57013702, 23.3765316], [68.57041931, 23.3765316], [68.57041931, 23.37681007], [68.57013702, 23.37680626], [68.57013702, 23.37708282], [68.56986237, 23.37708282], [68.56986237, 23.3773613], [68.56958008, 23.37735939], [68.56958008, 23.37763977], [68.56874847, 23.37763977], [68.56874847, 23.37792015], [68.56819153, 23.37792015], [68.56819153, 23.37820053], [68.56764221, 23.37819481], [68.56764221, 23.37847137], [68.56735992, 23.37847137], [68.56735992, 23.37930489], [68.56708527, 23.37930489], [68.56708527, 23.37986374], [68.56680298, 23.37985992], [68.56680298, 23.3801403], [68.56735992, 23.3801403], [68.56735992, 23.38042068], [68.56819153, 23.38042068], [68.56819153, 23.38125992], [68.56764221, 23.38125992], [68.56764221, 23.38153076], [68.5654068, 23.38153076], [68.5654068, 23.38181114], [68.56375122, 23.38180351], [68.56375122, 23.3820858], [68.56346893, 23.38208008], [68.56346893, 23.38236046], [68.56318665, 23.38236046], [68.56318665, 23.38264084], [68.56291962, 23.38264084], [68.56291962, 23.38292122], [68.56263733, 23.3829174], [68.56263733, 23.38319588], [68.56236267, 23.38319016], [68.56236267, 23.38375092], [68.56208038, 23.38375092], [68.56208038, 23.38458252], [68.56180573, 23.38458252], [68.56180573, 23.3856945], [68.56153107, 23.38569069], [68.56153107, 23.38624954], [68.5595932, 23.38624954], [68.5595932, 23.38652992], [68.55902863, 23.38652992], [68.55902863, 23.3868084], [68.55874634, 23.38680649], [68.55874634, 23.38708305], [68.55847168, 23.3870697], [68.55847168, 23.38763809], [68.55819702, 23.38763809], [68.55819702, 23.38820076], [68.5579071, 23.38820076], [68.5579071, 23.38874817], [68.55764008, 23.38874817], [68.55764008, 23.38902855], [68.55735779, 23.38902855], [68.55735779, 23.38958359], [68.55708313, 23.38958168], [68.55708313, 23.39264107], [68.55735779, 23.39264107], [68.55735779, 23.39375114], [68.55764008, 23.39375114], [68.55764008, 23.39431], [68.5579071, 23.39431], [68.5579071, 23.39513969], [68.55819702, 23.39513969], [68.55819702, 23.39569664], [68.55958557, 23.39569664], [68.55958557, 23.39486122], [68.55986023, 23.39486122], [68.55986023, 23.39431], [68.56014252, 23.39431], [68.56014252, 23.39375114], [68.56041718, 23.39375114], [68.56041718, 23.39319992], [68.56069183, 23.39319992], [68.56069183, 23.39291954], [68.56096649, 23.39291954], [68.56096649, 23.39236069], [68.56124878, 23.39236069], [68.56124878, 23.39180946], [68.56153107, 23.39180946], [68.56153107, 23.39125061], [68.56181335, 23.39125061], [68.56180573, 23.39097023], [68.56291962, 23.39097023], [68.56291962, 23.3915329], [68.56263733, 23.39152718], [68.56263733, 23.39208221], [68.56236267, 23.39208031], [68.56236267, 23.39264107], [68.56208038, 23.39264107], [68.56208038, 23.39319992], [68.56181335, 23.39319992], [68.56181335, 23.39375114], [68.56153107, 23.39375114], [68.56153107, 23.39431], [68.56124878, 23.39431], [68.56124878, 23.39486122], [68.56181335, 23.39486122], [68.56180573, 23.39458466], [68.56263733, 23.39458466], [68.56263733, 23.39430618], [68.56318665, 23.39431], [68.56318665, 23.39375114], [68.56375122, 23.39374924], [68.56375122, 23.39680672], [68.56402588, 23.39680672], [68.56402588, 23.39847183], [68.56430817, 23.39846992], [68.56430817, 23.40014076], [68.56458282, 23.40014076], [68.56458282, 23.40152931], [68.56430817, 23.40152931], [68.56430817, 23.4018116], [68.56402588, 23.4018116], [68.56402588, 23.40236092], [68.56375122, 23.40236092], [68.56375122, 23.40292168], [68.56346893, 23.40291595], [68.56346893, 23.4034729], [68.56318665, 23.40346909], [68.56318665, 23.40403175], [68.56291962, 23.40402794], [68.56291962, 23.40458107], [68.56263733, 23.40458107], [68.56263733, 23.40681076], [68.56236267, 23.40680313], [68.56236267, 23.41124916], [68.56208038, 23.41123962], [68.56208038, 23.41374969], [68.56180573, 23.41374969], [68.56180573, 23.41458321], [68.56153107, 23.41457748], [68.56153107, 23.41570282], [68.56124878, 23.41570282], [68.56124878, 23.41653252], [68.56096649, 23.41653252], [68.56096649, 23.41764259], [68.56069183, 23.41764259], [68.56069183, 23.41875267], [68.56041718, 23.41875267], [68.56041718, 23.41930962], [68.56014252, 23.4193058], [68.56014252, 23.41958237], [68.55958557, 23.41958237], [68.5595932, 23.41986084], [68.55930328, 23.41986084], [68.55930328, 23.42014122], [68.55874634, 23.42014122], [68.55874634, 23.42043114], [68.55652618, 23.42043114], [68.55652618, 23.42014122], [68.55513763, 23.42014122], [68.55513763, 23.41958046], [68.55541992, 23.41958237], [68.55541992, 23.41902733], [68.55568695, 23.41903114], [68.55568695, 23.41819191], [68.55541992, 23.41819382], [68.55541992, 23.41763878], [68.55513763, 23.41764259], [68.55513763, 23.41708183], [68.55486298, 23.41708374], [68.55486298, 23.41680527], [68.55458069, 23.4168129], [68.55458069, 23.41653252], [68.55401611, 23.41653252], [68.55401611, 23.41625023], [68.55319214, 23.41625023], [68.55319214, 23.41541862], [68.55264282, 23.41541862], [68.55264282, 23.41513824], [68.55208588, 23.41513824], [68.55208588, 23.41541862], [68.5510025, 23.41541862], [68.55097961, 23.41570282], [68.55041504, 23.41569519], [68.55041504, 23.41597176], [68.54846954, 23.41597176], [68.54846954, 23.41625023], [68.54792023, 23.41625023], [68.54792023, 23.41653252], [68.54736328, 23.41653252], [68.54736328, 23.4168129], [68.54708099, 23.4168129], [68.54708099, 23.41736984], [68.54651642, 23.41736984], [68.54651642, 23.41764259], [68.5459671, 23.41764259], [68.5459671, 23.41792107], [68.54569244, 23.41792107], [68.54569244, 23.41930962], [68.54541779, 23.4193058], [68.54541779, 23.41958237], [68.54485321, 23.41958046], [68.54485321, 23.42014122], [68.54402924, 23.42014122], [68.54402924, 23.42043114], [68.54374695, 23.42041588], [68.54374695, 23.42069244], [68.54430389, 23.42069244], [68.54430389, 23.42041588], [68.54486084, 23.42041588], [68.54486084, 23.42097473], [68.5451355, 23.42097473], [68.5451355, 23.42124939], [68.54541779, 23.42124939], [68.54541779, 23.42097092], [68.54569244, 23.42097473], [68.54569244, 23.42069244], [68.54597473, 23.42069244], [68.54597473, 23.42041588], [68.54651642, 23.42043114], [68.54651642, 23.42014122], [68.54708099, 23.42014122], [68.54708099, 23.41986084], [68.54792023, 23.41986084], [68.54792023, 23.42014122], [68.54819489, 23.42013931], [68.54819489, 23.42069244], [68.54846954, 23.42069054], [68.54846954, 23.42152977], [68.54875183, 23.42152977], [68.54875183, 23.42124939], [68.54958344, 23.42124939], [68.54958344, 23.42236137], [68.55042267, 23.42235947], [68.55042267, 23.42292023], [68.55014038, 23.42291641], [68.55014038, 23.42319679], [68.54875183, 23.42319679], [68.54875183, 23.42347145], [68.54846954, 23.42346954], [68.54846954, 23.42374992], [68.54763794, 23.42374992], [68.54763794, 23.42346954], [68.54708099, 23.42347145], [68.54708099, 23.42208481], [68.54680634, 23.42208481], [68.54680634, 23.42180634], [68.54624939, 23.42180634], [68.54624939, 23.42208481], [68.54569244, 23.42208481], [68.54569244, 23.42236137], [68.54374695, 23.42235947], [68.54374695, 23.42292023], [68.54347229, 23.42291641], [68.54347229, 23.42347145], [68.54264069, 23.42347145], [68.54264069, 23.42319679], [68.54208374, 23.42319679], [68.54208374, 23.42291641], [68.54180908, 23.42292023], [68.54180908, 23.42263985], [68.54096985, 23.42263985], [68.54096985, 23.42235947], [68.5404129, 23.42236137], [68.5404129, 23.42208481], [68.5395813, 23.42208481], [68.5395813, 23.42180634], [68.5376358, 23.42181015], [68.5376358, 23.42152977], [68.53679657, 23.42152977], [68.53679657, 23.42124939], [68.53569794, 23.42124939], [68.53569794, 23.42152977], [68.5359726, 23.42152786], [68.5359726, 23.42208481], [68.53624725, 23.42208481], [68.53624725, 23.42347145], [68.53430939, 23.42346954], [68.53430176, 23.42374992], [68.5340271, 23.42374992], [68.5340271, 23.42514038], [68.53457642, 23.42514038], [68.53457642, 23.42542076], [68.5348587, 23.42541885], [68.5348587, 23.42847252], [68.53457642, 23.42847061], [68.53457642, 23.42874908], [68.53430939, 23.42874908], [68.53430176, 23.43042183], [68.5340271, 23.43041611], [68.5340271, 23.43069458], [68.53375244, 23.43069458], [68.53375244, 23.43097115], [68.53347015, 23.43097115], [68.53347015, 23.43124962], [68.5331955, 23.43124962], [68.5331955, 23.43180466], [68.53291321, 23.43180275], [68.53291321, 23.43237114], [68.53263855, 23.43236351], [68.53263855, 23.43347168], [68.5331955, 23.43347168], [68.5331955, 23.43291664], [68.53347015, 23.43292046], [68.53347015, 23.43208122], [68.53375244, 23.43208122], [68.53375244, 23.43152809], [68.5340271, 23.43153191], [68.5340271, 23.43097115], [68.53430176, 23.43097115], [68.53430176, 23.43069458], [68.53458405, 23.43069458], [68.53458405, 23.43041611], [68.5348587, 23.43042183], [68.5348587, 23.43013954], [68.53514099, 23.43013954], [68.53514099, 23.42985916], [68.53542328, 23.42985916], [68.53541565, 23.4295826], [68.53569794, 23.4295826], [68.53569794, 23.42930603], [68.53598022, 23.42931175], [68.53598022, 23.42902946], [68.53624725, 23.42902946], [68.53624725, 23.42764091], [68.53736115, 23.42764091], [68.53736115, 23.42736053], [68.53708649, 23.42736053], [68.53708649, 23.42681122], [68.53679657, 23.42681122], [68.53679657, 23.42653084], [68.53708649, 23.42653084], [68.53708649, 23.42542076], [68.53736115, 23.42542076], [68.53736115, 23.42486], [68.5376358, 23.42486191], [68.5376358, 23.42458344], [68.53791809, 23.42458344], [68.53791809, 23.42430687], [68.53930664, 23.42430687], [68.53930664, 23.42458344], [68.54070282, 23.42457962], [68.54070282, 23.42514038], [68.54096985, 23.42513847], [68.54096985, 23.4256897], [68.54069519, 23.42569542], [68.54069519, 23.42597198], [68.5404129, 23.42597198], [68.5404129, 23.42625046], [68.54013824, 23.42624092], [68.54013824, 23.42681122], [68.53986359, 23.4268055], [68.53986359, 23.42708397], [68.5395813, 23.42707825], [68.5395813, 23.42736053], [68.53930664, 23.42736053], [68.53930664, 23.42764091], [68.53901672, 23.42764091], [68.53901672, 23.42791939], [68.53874969, 23.42791748], [68.53874969, 23.42819405], [68.53848267, 23.42818832], [68.53848267, 23.42874908], [68.53819275, 23.42874908], [68.53819275, 23.42902946], [68.53791809, 23.42902946], [68.53791809, 23.42931175], [68.5376358, 23.42930603], [68.5376358, 23.4295826], [68.53736115, 23.42958069], [68.53736115, 23.42985916], [68.53708649, 23.42985916], [68.53708649, 23.43013954], [68.53679657, 23.43013954], [68.53679657, 23.43042183], [68.53652954, 23.43041611], [68.53652954, 23.43069458], [68.53624725, 23.43069458], [68.53624725, 23.43097115], [68.53569794, 23.43097115], [68.53569794, 23.43124962], [68.53541565, 23.43124962], [68.53541565, 23.43180466], [68.53514099, 23.43180275], [68.53514099, 23.43264008], [68.5348587, 23.43264008], [68.5348587, 23.43320084], [68.53457642, 23.43320084], [68.53457642, 23.43375015], [68.53514099, 23.43375015], [68.53514099, 23.43486023], [68.5348587, 23.43486023], [68.5348587, 23.43541718], [68.53458405, 23.43541718], [68.53458405, 23.43569565], [68.53430939, 23.43568993], [68.53430176, 23.43625069], [68.5340271, 23.43625069], [68.5340271, 23.43653107], [68.53375244, 23.43652725], [68.53375244, 23.4370842], [68.53347015, 23.43708038], [68.53347015, 23.43764114], [68.5331955, 23.43763924], [68.5331955, 23.43819427], [68.53291321, 23.43819427], [68.53291321, 23.43847275], [68.53263855, 23.43847084], [68.53263855, 23.43902969], [68.53236389, 23.43902779], [68.53236389, 23.43958282], [68.5320816, 23.43958282], [68.5320816, 23.44097137], [68.53180695, 23.44097137], [68.53180695, 23.44236183], [68.53151703, 23.44235992], [68.53151703, 23.44292259], [68.53125, 23.44292259], [68.53125, 23.44320107], [68.53097534, 23.44319534], [68.53097534, 23.44347191], [68.53069305, 23.44347191], [68.53069305, 23.44403267], [68.5304184, 23.44403267], [68.5304184, 23.44486046], [68.53013611, 23.44486046], [68.53013611, 23.44597435], [68.52984619, 23.44597054], [68.52984619, 23.44680977], [68.53069305, 23.44680405], [68.53069305, 23.44708252], [68.53097534, 23.44708252], [68.53097534, 23.4473629], [68.53125, 23.44734955], [68.53125, 23.44791985], [68.53097534, 23.44791412], [68.53097534, 23.4481926], [68.5304184, 23.4481926], [68.5304184, 23.44847488], [68.52958679, 23.44847107], [68.52958679, 23.44874954], [68.52929688, 23.44874954], [68.52929688, 23.4493103], [68.52902985, 23.44930649], [68.52902985, 23.44986153], [68.52874756, 23.44985962], [68.52874756, 23.45014], [68.5284729, 23.45013809], [68.5284729, 23.45041656], [68.52819824, 23.45041084], [68.52819824, 23.45070076], [68.52791595, 23.45069695], [68.52791595, 23.4509716], [68.5276413, 23.4509697], [68.5276413, 23.45125008], [68.52735901, 23.45125008], [68.52735901, 23.45153046], [68.52707672, 23.45153046], [68.52707672, 23.45181084], [68.52680206, 23.45180511], [68.52680206, 23.45208359], [68.5265274, 23.45208359], [68.5265274, 23.45236206], [68.52625275, 23.45236015], [68.52625275, 23.45292091], [68.52597046, 23.45292091], [68.52597046, 23.45431137], [68.5256958, 23.45431137], [68.5256958, 23.45542145], [68.52541351, 23.45541763], [68.52541351, 23.4556942], [68.52513885, 23.4556942], [68.52513885, 23.45597267], [68.52485657, 23.45597076], [68.52485657, 23.45624924], [68.52458191, 23.45624924], [68.52458191, 23.45654106], [68.52430725, 23.45654106], [68.52430725, 23.4568119], [68.52402496, 23.45680618], [68.52402496, 23.45708275], [68.52375031, 23.45708084], [68.52375031, 23.45735931], [68.52347565, 23.45735931], [68.52348328, 23.45763969], [68.52319336, 23.45763969], [68.52319336, 23.45819473], [68.5229187, 23.45819473], [68.5229187, 23.4584713], [68.52263641, 23.45846939], [68.52263641, 23.45874977], [68.52236176, 23.45874977], [68.52236176, 23.45958138], [68.5220871, 23.45957947], [68.5220871, 23.46014023], [68.52179718, 23.46014023], [68.52179718, 23.46070099], [68.52153015, 23.46070099], [68.52153015, 23.46125031], [68.52124786, 23.46125031], [68.52124786, 23.46181107], [68.52097321, 23.46181107], [68.52097321, 23.46264076], [68.52179718, 23.46264076], [68.52179718, 23.46375084], [68.52153015, 23.46375084], [68.52153015, 23.46403122], [68.52124786, 23.4640274], [68.52124786, 23.46458244], [68.52097321, 23.46458054], [68.52097321, 23.46541977], [68.52124786, 23.46541977], [68.52124786, 23.46624947], [68.52153015, 23.46624947], [68.52153015, 23.46680832], [68.52180481, 23.46680641], [68.52180481, 23.46736145], [68.52068329, 23.46735954], [68.52068329, 23.46763992], [68.51957703, 23.46763992], [68.51957703, 23.46820068], [68.51930237, 23.46820068], [68.51930237, 23.46902847], [68.51902771, 23.46902847], [68.51902771, 23.47042274], [68.51930237, 23.47041702], [68.51930237, 23.47097015], [68.51902771, 23.47097015], [68.51902771, 23.47125053], [68.51791382, 23.47125053], [68.51791382, 23.4715271], [68.51763916, 23.47151947], [68.51763916, 23.47236061], [68.51735687, 23.47236061], [68.51735687, 23.47291946], [68.51708221, 23.47291756], [68.51708221, 23.4734745], [68.51680756, 23.47347069], [68.51680756, 23.47402954], [68.51652527, 23.47402763], [68.51652527, 23.47458458], [68.51625061, 23.47458076], [68.51625061, 23.47513962], [68.51597595, 23.47513962], [68.51597595, 23.47542], [68.51486969, 23.47542], [68.51486969, 23.47513962], [68.51457977, 23.47513962], [68.51457977, 23.47486115], [68.51430511, 23.47486115], [68.51430511, 23.47458458], [68.51403046, 23.47458458], [68.51403046, 23.47374916], [68.51457977, 23.47375107], [68.51457977, 23.47402954], [68.51568604, 23.47402954], [68.51568604, 23.47347069], [68.51597595, 23.4734745], [68.51597595, 23.47291756], [68.51625061, 23.47291946], [68.51625061, 23.47236061], [68.51597595, 23.47236061], [68.51597595, 23.47125053], [68.51568604, 23.47125053], [68.51568604, 23.47014046], [68.51541901, 23.47014046], [68.51541901, 23.46847916], [68.51457977, 23.46847916], [68.51457977, 23.46874809], [68.51431274, 23.46874809], [68.51431274, 23.46931267], [68.51403046, 23.46930504], [68.51403046, 23.46986008], [68.51374817, 23.46986008], [68.51374817, 23.47042274], [68.51347351, 23.47041702], [68.51347351, 23.47097015], [68.51319122, 23.47097015], [68.51319122, 23.47125053], [68.51291656, 23.47125053], [68.51291656, 23.47180939], [68.51235962, 23.47180939], [68.51235962, 23.47125053], [68.51208496, 23.47125053], [68.51208496, 23.47013855], [68.51235962, 23.47014046], [68.51235962, 23.4679184], [68.51264191, 23.4679184], [68.51264191, 23.46735954], [68.51319122, 23.46736145], [68.51319122, 23.46708298], [68.51403046, 23.46708298], [68.51403046, 23.46680641], [68.51568604, 23.46680832], [68.51568604, 23.46763992], [68.51597595, 23.46763992], [68.51597595, 23.46820068], [68.51735687, 23.46820068], [68.51735687, 23.46652985], [68.51708221, 23.46652985], [68.51708221, 23.46624947], [68.51735687, 23.46624947], [68.51735687, 23.46486092], [68.51763916, 23.46486092], [68.51763916, 23.46347046], [68.51791382, 23.46347237], [68.51791382, 23.46291733], [68.51819611, 23.46292114], [68.51819611, 23.46235085], [68.51847076, 23.46236038], [68.51847076, 23.46208572], [68.51875305, 23.46208572], [68.51875305, 23.46152687], [68.51902771, 23.46153069], [68.51902771, 23.46125031], [68.51930237, 23.46125031], [68.51930237, 23.46070099], [68.51957703, 23.46070099], [68.51957703, 23.45929146], [68.51902771, 23.45930481], [68.51902771, 23.45958138], [68.51875305, 23.45957947], [68.51875305, 23.46014023], [68.51847076, 23.46014023], [68.51847076, 23.46070099], [68.51819611, 23.46070099], [68.51819611, 23.46125031], [68.51790619, 23.46125031], [68.51790619, 23.46181107], [68.51763916, 23.46180344], [68.51763916, 23.46208572], [68.51735687, 23.46208], [68.51735687, 23.46292114], [68.51708221, 23.46292114], [68.51708221, 23.46375084], [68.51652527, 23.46375084], [68.51652527, 23.46347237], [68.51625061, 23.46347237], [68.51625061, 23.46236038], [68.51597595, 23.46236038], [68.51597595, 23.46180344], [68.51625061, 23.46181107], [68.51625061, 23.46125031], [68.5165329, 23.46125031], [68.51652527, 23.46013832], [68.51680756, 23.46014023], [68.51680756, 23.45846939], [68.51708221, 23.4584713], [68.51708221, 23.45763969], [68.51735687, 23.45763969], [68.5173645, 23.45726967], [68.5173645, 23.45708275], [68.51763916, 23.45708275], [68.51763916, 23.45680618], [68.51790619, 23.4568119], [68.51790619, 23.45624924], [68.51819611, 23.45624924], [68.51819611, 23.45597076], [68.51847076, 23.45597267], [68.51847076, 23.45541573], [68.51875305, 23.45542145], [68.51875305, 23.45513916], [68.51930237, 23.45513916], [68.51930237, 23.45486069], [68.51957703, 23.45486069], [68.51957703, 23.45458031], [68.5201416, 23.45458412], [68.5201416, 23.45430565], [68.52124786, 23.45431137], [68.52124786, 23.45486069], [68.52153015, 23.45486069], [68.52153015, 23.45542145], [68.52180481, 23.45541573], [68.52180481, 23.45597267], [68.52153015, 23.45597076], [68.52153015, 23.45654106], [68.52124786, 23.45652771], [68.52124786, 23.45708275], [68.52097321, 23.45708275], [68.52097321, 23.45930481], [68.52153015, 23.45930481], [68.52153015, 23.4584713], [68.52180481, 23.4584713], [68.52180481, 23.45819473], [68.5220871, 23.45819473], [68.5220871, 23.45791626], [68.52236176, 23.45792007], [68.52236176, 23.45735931], [68.52263641, 23.45735931], [68.52263641, 23.45708084], [68.5229187, 23.45708275], [68.5229187, 23.45680618], [68.52348328, 23.4568119], [68.52348328, 23.45624924], [68.52375031, 23.45624924], [68.52375031, 23.45597076], [68.52402496, 23.45597267], [68.52402496, 23.4556942], [68.52430725, 23.4556942], [68.52430725, 23.45541573], [68.52485657, 23.45542145], [68.52485657, 23.45486069], [68.52458191, 23.45486069], [68.52458191, 23.45431137], [68.52430725, 23.45431137], [68.52430725, 23.45375061], [68.52402496, 23.45375061], [68.52402496, 23.45125008], [68.52430725, 23.45125008], [68.52430725, 23.45041084], [68.52458191, 23.45041656], [68.52458191, 23.44958305], [68.5248642, 23.44958305], [68.5248642, 23.44847488], [68.52458191, 23.44847488], [68.52458191, 23.44791412], [68.52430725, 23.44791985], [68.52430725, 23.44763947], [68.52402496, 23.44763947], [68.52402496, 23.4473629], [68.52375031, 23.4473629], [68.52375031, 23.44708252], [68.52347565, 23.44708252], [68.52347565, 23.44680405], [68.52319336, 23.44680977], [68.52319336, 23.44652939], [68.5220871, 23.44652939], [68.5220871, 23.44680977], [68.52180481, 23.44680405], [68.52180481, 23.44708252], [68.52153015, 23.44708252], [68.52153015, 23.4473629], [68.52124786, 23.44734955], [68.52124786, 23.44763947], [68.52097321, 23.44763947], [68.52097321, 23.4481926], [68.52069092, 23.4481926], [68.52069092, 23.44847488], [68.52097321, 23.44847107], [68.52097321, 23.44874954], [68.52124786, 23.44874954], [68.52124786, 23.44902992], [68.52153015, 23.44902802], [68.52153015, 23.44930077], [68.52180481, 23.44930649], [68.52180481, 23.44958305], [68.51958466, 23.44958305], [68.51958466, 23.44986153], [68.51930237, 23.44985962], [68.51930237, 23.45014], [68.51875305, 23.45013809], [68.51875305, 23.45041656], [68.51847076, 23.45041084], [68.51847076, 23.45070076], [68.51875305, 23.45069695], [68.51875305, 23.4509716], [68.51902771, 23.4509716], [68.51902771, 23.45069695], [68.51930237, 23.45070076], [68.51930237, 23.45041084], [68.51985931, 23.45041656], [68.51985931, 23.45013809], [68.52041626, 23.45014], [68.52041626, 23.44985962], [68.52068329, 23.44985962], [68.52068329, 23.45014], [68.52097321, 23.45014], [68.52097321, 23.45070076], [68.52069092, 23.45069695], [68.52069092, 23.4509716], [68.5201416, 23.4509716], [68.5201416, 23.45208359], [68.51985931, 23.45208359], [68.51985931, 23.45236206], [68.51958466, 23.45236206], [68.51958466, 23.45208359], [68.51930237, 23.45208359], [68.51930237, 23.45180511], [68.51847076, 23.45181084], [68.51847076, 23.45236015], [68.51902771, 23.45236015], [68.51902771, 23.45264053], [68.51930237, 23.45263863], [68.51930237, 23.45319366], [68.51902771, 23.45318985], [68.51902771, 23.45347977], [68.51875305, 23.45347977], [68.51875305, 23.45375061], [68.51819611, 23.45375061], [68.51819611, 23.45402908], [68.51790619, 23.45402908], [68.51790619, 23.45431137], [68.5173645, 23.45430565], [68.5173645, 23.45458412], [68.51708221, 23.45458031], [68.51706696, 23.45486069], [68.51680756, 23.45486069], [68.51680756, 23.45513916], [68.51652527, 23.45513916], [68.51652527, 23.4556942], [68.51625061, 23.45568848], [68.51625061, 23.45624924], [68.51597595, 23.45624924], [68.51597595, 23.45682716], [68.51568604, 23.4568119], [68.51568604, 23.45735931], [68.51541901, 23.45735931], [68.51541901, 23.45792007], [68.51457977, 23.45792007], [68.51457977, 23.45735931], [68.51430511, 23.45735931], [68.51430511, 23.45652771], [68.51403046, 23.45654106], [68.51403046, 23.45640182], [68.51403046, 23.45541763], [68.51374817, 23.45542145], [68.51374817, 23.45431137], [68.51346588, 23.45431137], [68.51346588, 23.45347977], [68.51319122, 23.45347977], [68.51319122, 23.45292091], [68.51291656, 23.4529171], [68.51291656, 23.45319366], [68.51264191, 23.45318985], [68.51264191, 23.45347977], [68.51235962, 23.45347977], [68.51235962, 23.45375061], [68.51207733, 23.45375061], [68.51207733, 23.45402908], [68.5118103, 23.45402908], [68.5118103, 23.45431137], [68.51152802, 23.45430565], [68.51152802, 23.45458412], [68.51180267, 23.45458412], [68.51180267, 23.45486069], [68.51207733, 23.45486069], [68.51207733, 23.45513916], [68.51235962, 23.45513916], [68.51235962, 23.45597267], [68.51264191, 23.45597267], [68.51264191, 23.45635986], [68.51264191, 23.4568119], [68.51291656, 23.45680618], [68.51291656, 23.45708275], [68.51319122, 23.45708084], [68.51319122, 23.45735931], [68.51291656, 23.45735931], [68.51291656, 23.45763969], [68.51264191, 23.45763969], [68.51264191, 23.45735931], [68.51235962, 23.45735931], [68.51235962, 23.45708084], [68.51208496, 23.45708275], [68.51208496, 23.45680618], [68.5118103, 23.4568119], [68.5118103, 23.45667267], [68.51180267, 23.45597267], [68.51152802, 23.45597267], [68.51152802, 23.45541763], [68.51069641, 23.45542145], [68.51069641, 23.45513916], [68.51041412, 23.45513916], [68.51041412, 23.4556942], [68.51013947, 23.45568848], [68.51013947, 23.4568119], [68.51041412, 23.45680618], [68.51041412, 23.45717049], [68.51040649, 23.45735931], [68.51069641, 23.45735931], [68.51069641, 23.45819473], [68.51040649, 23.45819283], [68.51040649, 23.45874977], [68.50846863, 23.45874977], [68.50846863, 23.45930481], [68.50819397, 23.45930481], [68.50819397, 23.45986366], [68.50791931, 23.45985985], [68.50791931, 23.46042061], [68.50763702, 23.46041679], [68.50763702, 23.46097374], [68.50708008, 23.46096992], [68.50708008, 23.46153069], [68.50680542, 23.46152687], [68.50680542, 23.46208572], [68.50653076, 23.46208], [68.50653076, 23.46264076], [68.50624847, 23.46263885], [68.50624847, 23.4631958], [68.50596619, 23.46319008], [68.50596619, 23.46375084], [68.50541687, 23.46375084], [68.50541687, 23.46403122], [68.50485992, 23.46403122], [68.50485992, 23.46430969], [68.50430298, 23.46430779], [68.50430298, 23.46458244], [68.50374603, 23.46458054], [68.50374603, 23.46486092], [68.50319672, 23.46486092], [68.50319672, 23.46513939], [68.50263977, 23.46513939], [68.50263977, 23.46541977], [68.50235748, 23.46541977], [68.50235748, 23.46624947], [68.50263977, 23.46624947], [68.50263977, 23.46652985], [68.5029068, 23.46652985], [68.5029068, 23.46680832], [68.50319672, 23.46680641], [68.50319672, 23.46708298], [68.50347137, 23.46708298], [68.50347137, 23.46736145], [68.50402832, 23.46735954], [68.50402832, 23.46763992], [68.50485992, 23.46763992], [68.50485992, 23.46735954], [68.50514221, 23.46736145], [68.50514221, 23.46708298], [68.50541687, 23.46708298], [68.50541687, 23.46652985], [68.50567627, 23.46652985], [68.50567627, 23.46624947], [68.50596619, 23.46624947], [68.50596619, 23.46458054], [68.50624847, 23.46458244], [68.50624847, 23.46430779], [68.50653076, 23.46430969], [68.50653076, 23.46375084], [68.50681305, 23.46375084], [68.50680542, 23.46347237], [68.50708008, 23.46347237], [68.50708008, 23.46291733], [68.50736237, 23.46292114], [68.50736237, 23.46264076], [68.50846863, 23.46264076], [68.50846863, 23.46292114], [68.50902557, 23.46291733], [68.50902557, 23.4631958], [68.51041412, 23.4631958], [68.51041412, 23.46347237], [68.51152802, 23.46347046], [68.51152802, 23.46430969], [68.51180267, 23.46430779], [68.51180267, 23.4659729], [68.51208496, 23.4659729], [68.51208496, 23.46708298], [68.51152802, 23.46708298], [68.51152802, 23.46736145], [68.51125336, 23.46735954], [68.51125336, 23.46763992], [68.51097107, 23.46763992], [68.51097107, 23.4679184], [68.51040649, 23.4679184], [68.51040649, 23.46820068], [68.51013947, 23.46820068], [68.51013947, 23.46847916], [68.50985718, 23.46847916], [68.50985718, 23.46874809], [68.50958252, 23.46874809], [68.50958252, 23.46902847], [68.50930786, 23.46902847], [68.50930786, 23.46958351], [68.50902557, 23.46958351], [68.50902557, 23.46986008], [68.50985718, 23.46986008], [68.50985718, 23.47014046], [68.51013947, 23.47014046], [68.51013947, 23.47042274], [68.51041412, 23.47041702], [68.51041412, 23.47069359], [68.51069641, 23.47069359], [68.51069641, 23.4715271], [68.51040649, 23.47151947], [68.51040649, 23.47236061], [68.50985718, 23.47236061], [68.50985718, 23.4726429], [68.50958252, 23.4726429], [68.50958252, 23.47291946], [68.51152802, 23.47291946], [68.51152802, 23.47375107], [68.51097107, 23.47375107], [68.51097107, 23.47402954], [68.51040649, 23.47402954], [68.51040649, 23.47430992], [68.50958252, 23.4743042], [68.50958252, 23.47458458], [68.50846863, 23.47458458], [68.50846863, 23.4743042], [68.50791931, 23.47430992], [68.50791931, 23.47402954], [68.50763702, 23.47402954], [68.50763702, 23.47347069], [68.50791931, 23.4734745], [68.50791931, 23.47291756], [68.50763702, 23.47291946], [68.50763702, 23.47236061], [68.50736237, 23.47236061], [68.50736237, 23.47180939], [68.50708008, 23.47180939], [68.50708008, 23.47151947], [68.5045929, 23.47151947], [68.5045929, 23.47180939], [68.50402832, 23.47180557], [68.50402832, 23.47208214], [68.50374603, 23.47208023], [68.50374603, 23.47236061], [68.50347137, 23.47236061], [68.50347137, 23.47291946], [68.50291443, 23.47291756], [68.50291443, 23.47319221], [68.50263977, 23.47319221], [68.50263977, 23.4734745], [68.50208282, 23.47347069], [68.50208282, 23.47375107], [68.50180817, 23.47375107], [68.50180817, 23.47430992], [68.50152588, 23.4743042], [68.50152588, 23.47458458], [68.50125122, 23.47458076], [68.50125122, 23.47513962], [68.50096893, 23.47513962], [68.50096893, 23.47542], [68.50069427, 23.47541428], [68.50069427, 23.47597313], [68.50041962, 23.47597122], [68.50041962, 23.47653008], [68.50068665, 23.47653008], [68.50068665, 23.47903061], [68.50013733, 23.4790287], [68.50013733, 23.47958374], [68.50041962, 23.47957993], [68.50041962, 23.48014069], [68.50069427, 23.48013878], [68.50069427, 23.48069382], [68.50096893, 23.4806881], [68.50096893, 23.48181152], [68.50068665, 23.48181152], [68.50068665, 23.4829216], [68.50041962, 23.48291588], [68.50041962, 23.48347282], [68.50013733, 23.48345757], [68.50013733, 23.48431015], [68.4998703, 23.48431015], [68.4998703, 23.48542023], [68.50013733, 23.48541641], [68.50013733, 23.48597145], [68.50041962, 23.48596954], [68.50041962, 23.48624992], [68.50068665, 23.48624992], [68.50068665, 23.48681068], [68.50096893, 23.48680305], [68.50096893, 23.48708534], [68.50069427, 23.48708534], [68.50069427, 23.48819542], [68.50096893, 23.48819542], [68.50096893, 23.48847389], [68.50125122, 23.48847008], [68.50125122, 23.48903084], [68.50152588, 23.48903084], [68.50152588, 23.49014091], [68.50180817, 23.49013901], [68.50180817, 23.49069595], [68.50208282, 23.49069023], [68.50208282, 23.49125099], [68.50235748, 23.49125099], [68.50235748, 23.49180984], [68.50319672, 23.49180984], [68.50319672, 23.49152946], [68.50347137, 23.49152946], [68.50347137, 23.49125099], [68.50374603, 23.49125099], [68.50374603, 23.49069023], [68.50402832, 23.49069595], [68.50402832, 23.49041748], [68.50430298, 23.49041939], [68.50430298, 23.49014091], [68.5045929, 23.49014091], [68.5045929, 23.48986053], [68.50485992, 23.48986053], [68.50485992, 23.48958969], [68.50681305, 23.48958969], [68.50681305, 23.48931122], [68.50818634, 23.48931122], [68.50818634, 23.48903084], [68.50985718, 23.48903084], [68.50985718, 23.48847008], [68.51013947, 23.48847389], [68.51013947, 23.48791695], [68.51040649, 23.48792076], [68.51040649, 23.48736], [68.51069641, 23.48736382], [68.51069641, 23.48708534], [68.51097107, 23.48708534], [68.51097107, 23.48680305], [68.51125336, 23.48681068], [68.51125336, 23.48624992], [68.51152802, 23.48624992], [68.51152802, 23.48596954], [68.51180267, 23.48597145], [68.51180267, 23.48569489], [68.51208496, 23.48569489], [68.51208496, 23.48541641], [68.51264191, 23.48542023], [68.51264191, 23.48513985], [68.51291656, 23.48513985], [68.51291656, 23.48485947], [68.51457977, 23.48485947], [68.51457977, 23.48513985], [68.51541901, 23.48513985], [68.51541901, 23.48542023], [68.51597595, 23.48541641], [68.51597595, 23.48569489], [68.51652527, 23.48569489], [68.51652527, 23.48597145], [68.51708221, 23.48596954], [68.51708221, 23.48624992], [68.51735687, 23.48624992], [68.51735687, 23.48681068], [68.51763916, 23.48680305], [68.51763916, 23.48736382], [68.51790619, 23.48736], [68.51790619, 23.48792076], [68.51819611, 23.48791695], [68.51819611, 23.48819542], [68.51875305, 23.48819542], [68.51875305, 23.48847389], [68.51902771, 23.48847008], [68.51902771, 23.48903084], [68.51875305, 23.48903084], [68.51875305, 23.48958969], [68.51680756, 23.48958969], [68.51680756, 23.48931122], [68.51625061, 23.48931122], [68.51625061, 23.48903084], [68.51568604, 23.48903084], [68.51568604, 23.48875046], [68.51541901, 23.48875046], [68.51541901, 23.48847008], [68.51486206, 23.48847389], [68.51486206, 23.48819542], [68.51431274, 23.4881897], [68.51430511, 23.48791695], [68.51374817, 23.48792076], [68.51374817, 23.48764038], [68.51291656, 23.48764038], [68.51291656, 23.48792076], [68.51264191, 23.48791695], [68.51264191, 23.48847389], [68.51235962, 23.48847008], [68.51235962, 23.48903084], [68.51264191, 23.48903084], [68.51264191, 23.48875046], [68.51291656, 23.48875046], [68.51291656, 23.48847008], [68.51374817, 23.48847008], [68.51374817, 23.48903084], [68.51346588, 23.48903084], [68.51346588, 23.48931122], [68.51319122, 23.48931122], [68.51319122, 23.48958969], [68.51291656, 23.48958969], [68.51291656, 23.49125099], [68.51319122, 23.49125099], [68.51319122, 23.49180984], [68.51403046, 23.49180984], [68.51403046, 23.49152946], [68.51431274, 23.49152946], [68.51431274, 23.49125099], [68.51486969, 23.49125099], [68.51486969, 23.49180984], [68.51541901, 23.49180984], [68.51541901, 23.49236107], [68.51513672, 23.49236107], [68.51513672, 23.49264908], [68.51457977, 23.49264908], [68.51457977, 23.49291992], [68.51208496, 23.49291611], [68.51208496, 23.49319458], [68.51152802, 23.49319458], [68.51152802, 23.49347305], [68.51069641, 23.49347115], [68.51069641, 23.49374962], [68.50818634, 23.49374962], [68.50818634, 23.49402809], [68.50485992, 23.49402809], [68.50485992, 23.49374962], [68.50263977, 23.49374962], [68.50263977, 23.49402809], [68.50208282, 23.49402809], [68.50208282, 23.49419975], [68.50208282, 23.49430466], [68.50180817, 23.49430466], [68.50180817, 23.49458313], [68.50125122, 23.49458313], [68.50125122, 23.49430466], [68.49986267, 23.49430466], [68.49986267, 23.49402809], [68.49903107, 23.49402809], [68.49903107, 23.49430466], [68.49930573, 23.49430466], [68.49930573, 23.4948616], [68.49958038, 23.4948597], [68.49958038, 23.49541855], [68.49986267, 23.49541664], [68.49986267, 23.49625015], [68.50013733, 23.49625015], [68.50013733, 23.49653244], [68.50041962, 23.49653244], [68.50041962, 23.49681282], [68.50068665, 23.49681282], [68.50068665, 23.49736023], [68.50041962, 23.49736023], [68.50041962, 23.4979229], [68.50125122, 23.49791718], [68.50125122, 23.49819374], [68.50208282, 23.49819374], [68.50208282, 23.49847031], [68.50235748, 23.49846077], [68.50235748, 23.49875069], [68.5029068, 23.49875069], [68.5029068, 23.49903107], [68.50347137, 23.49903107], [68.50347137, 23.49930954], [68.50375366, 23.49930573], [68.50375366, 23.49958229], [68.50402832, 23.49958229], [68.50402832, 23.50006294], [68.50402832, 23.50041962], [68.50375366, 23.5004158], [68.50375366, 23.50069237], [68.50347137, 23.50069237], [68.50347137, 23.50097466], [68.50319672, 23.50097084], [68.50319672, 23.50125122], [68.5029068, 23.50125122], [68.5029068, 23.50181007], [68.50263977, 23.50180626], [68.50263977, 23.50208473], [68.50152588, 23.50208092], [68.50152588, 23.50292015], [68.50180817, 23.50291443], [68.50180817, 23.50347137], [68.50208282, 23.50346947], [68.50208282, 23.50374985], [68.50319672, 23.50374985], [68.50319672, 23.50346947], [68.50514221, 23.50346947], [68.50514221, 23.50374985], [68.50485992, 23.50374985], [68.50485992, 23.50430679], [68.50458527, 23.50430679], [68.50458527, 23.50486183], [68.50430298, 23.50485992], [68.50430298, 23.50542068], [68.50402832, 23.50542068], [68.50402832, 23.50570107], [68.50375366, 23.50569534], [68.50375366, 23.50597191], [68.50152588, 23.50597191], [68.50152588, 23.50486183], [68.50096893, 23.50486183], [68.50096893, 23.50458336], [68.50041962, 23.50459099], [68.50041962, 23.50430107], [68.50013733, 23.50430679], [68.50013733, 23.50402832], [68.4998703, 23.50403023], [68.4998703, 23.50319099], [68.50013733, 23.50319672], [68.50013733, 23.50263977], [68.50068665, 23.50263977], [68.50068665, 23.50125122], [68.50096893, 23.50125122], [68.50096893, 23.50097084], [68.50125122, 23.50097466], [68.50125122, 23.50069237], [68.50208282, 23.50069237], [68.50208282, 23.50097466], [68.50235748, 23.50097466], [68.50235748, 23.5004158], [68.50263977, 23.50041962], [68.50263977, 23.50014114], [68.50235748, 23.50011063], [68.50235748, 23.49986076], [68.50208282, 23.49986076], [68.50208282, 23.49958038], [68.50152588, 23.49958229], [68.50152588, 23.49930573], [68.50096893, 23.49930954], [68.50096893, 23.49903107], [68.50068665, 23.49903107], [68.50068665, 23.49875069], [68.50013733, 23.49875069], [68.50013733, 23.49846077], [68.49874878, 23.49847031], [68.49874878, 23.49819374], [68.49708557, 23.49819374], [68.49708557, 23.49847031], [68.49680328, 23.49846077], [68.49680328, 23.49875069], [68.496521, 23.49875069], [68.49569702, 23.49875069], [68.49569702, 23.49903107], [68.4954071, 23.49903107], [68.4954071, 23.49930954], [68.49514008, 23.49930573], [68.49514008, 23.49958229], [68.49485779, 23.49958038], [68.49485779, 23.50014114], [68.49458313, 23.50014114], [68.49458313, 23.50041962], [68.49208069, 23.5004158], [68.49208069, 23.50097466], [68.49180603, 23.50097084], [68.49180603, 23.50263977], [68.49208069, 23.50263977], [68.49208069, 23.50319672], [68.49236298, 23.50319099], [68.49236298, 23.50374985], [68.49263763, 23.50374985], [68.49263763, 23.50403023], [68.49291992, 23.50403023], [68.49291992, 23.50374985], [68.49318695, 23.50374985], [68.49318695, 23.50319099], [68.49346924, 23.50319672], [68.49346924, 23.50291443], [68.49430847, 23.50291443], [68.49430847, 23.50319672], [68.49458313, 23.50319672], [68.49458313, 23.50430679], [68.49430847, 23.50430107], [68.49430847, 23.50653076], [68.49458313, 23.50653076], [68.49458313, 23.50736046], [68.4954071, 23.50736046], [68.4954071, 23.50707817], [68.49597168, 23.50708389], [68.49597168, 23.50680542], [68.49652863, 23.50680542], [68.49652863, 23.50708389], [68.49680328, 23.50707817], [68.49680328, 23.50791931], [68.49652863, 23.50791931], [68.49652863, 23.51042175], [68.49680328, 23.51041603], [68.49680328, 23.51097107], [68.4970932, 23.51097107], [68.4970932, 23.51153183], [68.49736023, 23.51152802], [68.49736023, 23.51208115], [68.49764252, 23.51208115], [68.49764252, 23.51264191], [68.49791718, 23.51264191], [68.49791718, 23.51320076], [68.49819183, 23.51320076], [68.49819183, 23.51375008], [68.49846649, 23.51375008], [68.49846649, 23.51431084], [68.49874878, 23.51431084], [68.49874878, 23.51486015], [68.49903107, 23.51486015], [68.49903107, 23.51514053], [68.49846649, 23.51514053], [68.49846649, 23.51486015], [68.49819183, 23.51486206], [68.49819183, 23.51458549], [68.49791718, 23.51458549], [68.49791718, 23.51486206], [68.49764252, 23.51486015], [68.49764252, 23.51514053], [68.49736023, 23.51514053], [68.49736023, 23.51542091], [68.49680328, 23.5154171], [68.49680328, 23.51569557], [68.49624634, 23.51569557], [68.49624634, 23.51597214], [68.49569702, 23.51597023], [68.49569702, 23.51625061], [68.49514008, 23.51625061], [68.49514008, 23.51653099], [68.49458313, 23.51653099], [68.49458313, 23.51764107], [68.49485779, 23.51764107], [68.49485779, 23.51930809], [68.49514008, 23.51930809], [68.49514008, 23.52152824], [68.4954071, 23.52152824], [68.4954071, 23.52375031], [68.49569702, 23.52375031], [68.49569702, 23.52486038], [68.4954071, 23.52486038], [68.4954071, 23.52514267], [68.49514008, 23.52514267], [68.49514008, 23.52542114], [68.49485779, 23.52541733], [68.49485779, 23.52597237], [68.49458313, 23.52597046], [68.49458313, 23.52625275], [68.49430847, 23.52625275], [68.49430847, 23.52680969], [68.49402618, 23.52680588], [68.49402618, 23.52708244], [68.49373627, 23.52708054], [68.49373627, 23.52736092], [68.49346924, 23.52736092], [68.49346924, 23.52763939], [68.49318695, 23.52763939], [68.49318695, 23.52791977], [68.49291992, 23.52791405], [68.49291992, 23.52819252], [68.49263763, 23.52819252], [68.49263763, 23.52847481], [68.49236298, 23.52847099], [68.49236298, 23.52902985], [68.49208069, 23.52902794], [68.49208069, 23.52958488], [68.49180603, 23.52958107], [68.49180603, 23.53013992], [68.49153137, 23.53013611], [68.49153137, 23.53097153], [68.49124908, 23.53096962], [68.49124908, 23.53153038], [68.49097443, 23.53152847], [68.49097443, 23.53208351], [68.49069977, 23.5320797], [68.49069977, 23.53264046], [68.49041748, 23.53264046], [68.49041748, 23.53375053], [68.49014282, 23.53375053], [68.49014282, 23.53513908], [68.48986053, 23.53513908], [68.48986053, 23.5359726], [68.49014282, 23.53597069], [68.49014282, 23.53624916], [68.49041748, 23.53624916], [68.49041748, 23.53652954], [68.49069977, 23.53652954], [68.49069977, 23.53681183], [68.49097443, 23.53680611], [68.49097443, 23.53708267], [68.49124908, 23.53708076], [68.49124908, 23.53735924], [68.49097443, 23.53735924], [68.49097443, 23.53763962], [68.49041748, 23.53762817], [68.49041748, 23.53792191], [68.48986053, 23.53791618], [68.48986053, 23.5395813], [68.48958588, 23.53957939], [68.48958588, 23.54042053], [68.48930359, 23.54041672], [68.48930359, 23.54097176], [68.48902893, 23.54096985], [68.48902893, 23.54125023], [68.48874664, 23.54125023], [68.48874664, 23.54153061], [68.48847198, 23.5415287], [68.48847198, 23.54208565], [68.48819733, 23.54207993], [68.48819733, 23.54264069], [68.48791504, 23.54263878], [68.48791504, 23.54319572], [68.48764038, 23.54319], [68.48764038, 23.5437603], [68.48735809, 23.5437603], [68.48735809, 23.54403114], [68.48708344, 23.54402542], [68.48708344, 23.54458427], [68.48680878, 23.54458046], [68.48680878, 23.54514122], [68.48652649, 23.54514122], [68.48652649, 23.54541969], [68.48625183, 23.54541779], [68.48625183, 23.54597282], [68.48596954, 23.54597092], [68.48596954, 23.54652977], [68.48569489, 23.54652977], [68.48569489, 23.54680634], [68.48542023, 23.54680634], [68.48542023, 23.54736137], [68.48513794, 23.54735947], [68.48513794, 23.54791832], [68.48458099, 23.54791641], [68.48458099, 23.54819489], [68.48401642, 23.54818916], [68.48401642, 23.54931259], [68.48625183, 23.54931259], [68.48625183, 23.5490284], [68.48707581, 23.5490284], [68.48707581, 23.54874992], [68.48764038, 23.54874992], [68.48764038, 23.54846954], [68.48874664, 23.54846954], [68.48874664, 23.5490284], [68.49014282, 23.5490284], [68.49014282, 23.54874992], [68.49124908, 23.54874992], [68.49124908, 23.54846954], [68.49208069, 23.54846954], [68.49208069, 23.5490284], [68.49180603, 23.5490284], [68.49180603, 23.54931259], [68.49153137, 23.54930496], [68.49153137, 23.54958344], [68.49208069, 23.54958344], [68.49208069, 23.54930496], [68.49263763, 23.54931259], [68.49263763, 23.54818916], [68.49291992, 23.54819489], [68.49291992, 23.54763985], [68.49318695, 23.54763985], [68.49318695, 23.54735947], [68.49375153, 23.54736137], [68.49375153, 23.5470829], [68.49402618, 23.5470829], [68.49402618, 23.54680634], [68.49430847, 23.54680634], [68.49430847, 23.54652977], [68.49458313, 23.54652977], [68.49458313, 23.54624939], [68.49514008, 23.54624939], [68.49514008, 23.54652977], [68.49541473, 23.54652977], [68.49541473, 23.5470829], [68.49597168, 23.5470829], [68.49597168, 23.54736137], [68.49736023, 23.54735947], [68.49736023, 23.54791832], [68.49708557, 23.54791641], [68.49708557, 23.54847145], [68.49680328, 23.54847145], [68.49680328, 23.54958344], [68.49624634, 23.54956818], [68.49624634, 23.55014038], [68.49597168, 23.55013847], [68.49597168, 23.55069351], [68.49514008, 23.55069351], [68.49514008, 23.54958344], [68.49485779, 23.54958344], [68.49485779, 23.54874992], [68.49402618, 23.54874992], [68.49402618, 23.54931259], [68.49375153, 23.54930496], [68.49375153, 23.54986191], [68.49402618, 23.54986191], [68.49402618, 23.55097008], [68.49430847, 23.55097008], [68.49430847, 23.55264282], [68.49402618, 23.55264282], [68.49402618, 23.55293083], [68.49373627, 23.55293083], [68.49373627, 23.5537529], [68.49402618, 23.5537529], [68.49402618, 23.55430984], [68.49430847, 23.55430412], [68.49430847, 23.5545826], [68.49458313, 23.55458069], [68.49458313, 23.55513954], [68.49485779, 23.55513954], [68.49485779, 23.55624962], [68.49514008, 23.55624962], [68.49514008, 23.5573616], [68.49485779, 23.5573616], [68.49485779, 23.55875015], [68.49514008, 23.55875015], [68.49514008, 23.55958366], [68.49485779, 23.55957985], [68.49485779, 23.55986023], [68.49318695, 23.55986023], [68.49318695, 23.56041908], [68.49346924, 23.56041718], [68.49346924, 23.5620842], [68.49373627, 23.56208038], [68.49373627, 23.56402969], [68.49346924, 23.56402969], [68.49346924, 23.56653023], [68.49318695, 23.56653023], [68.49318695, 23.56903076], [68.49291992, 23.56903076], [68.49291992, 23.57152939], [68.49263763, 23.57152748], [68.49263763, 23.5731945], [68.49236298, 23.57319069], [68.49236298, 23.5743084], [68.49208069, 23.57430649], [68.49208069, 23.57458305], [68.49153137, 23.57458305], [68.49153137, 23.57486153], [68.49124908, 23.57486153], [68.49124908, 23.5759716], [68.4909668, 23.5759697], [68.49097443, 23.57625008], [68.49069977, 23.57625008], [68.49069977, 23.57653236], [68.49041748, 23.57652855], [68.49041748, 23.57736015], [68.48958588, 23.57736015], [68.48958588, 23.57764053], [68.48764038, 23.57764053], [68.48764038, 23.57792282], [68.48735809, 23.5779171], [68.48735809, 23.57847023], [68.48764038, 23.57847023], [68.48764038, 23.5790329], [68.4879303, 23.5790329], [68.4879303, 23.57987022], [68.48764038, 23.57987022], [68.48764038, 23.58125114], [68.48735809, 23.58125114], [68.48735809, 23.58736038], [68.48708344, 23.58736038], [68.48708344, 23.58847237], [68.48735809, 23.58847237], [68.48735809, 23.59069443], [68.48707581, 23.59069061], [68.48707581, 23.59181023], [68.48680878, 23.59181023], [68.48680878, 23.5929203], [68.48652649, 23.59291649], [68.48652649, 23.59597206], [68.48680878, 23.59597015], [68.48680878, 23.59653091], [68.48707581, 23.59653091], [68.48707581, 23.59680939], [68.48764038, 23.59680939], [68.48764038, 23.59736061], [68.4879303, 23.59736061], [68.4879303, 23.59764099], [68.48819733, 23.59763908], [68.48819733, 23.59791756], [68.48847198, 23.59791756], [68.48847198, 23.59819412], [68.48874664, 23.59819412], [68.48874664, 23.5984726], [68.48986053, 23.59847069], [68.48986053, 23.59902954], [68.49013519, 23.59902763], [68.49013519, 23.59958267], [68.49041748, 23.59958076], [68.49041748, 23.59986115], [68.49069214, 23.59986115], [68.49069214, 23.60013962], [68.49097443, 23.60013962], [68.49097443, 23.60069466], [68.49124908, 23.60069466], [68.49124908, 23.6020298], [68.49124908, 23.60263824], [68.49153137, 23.60263824], [68.49153137, 23.60292244], [68.49180603, 23.60292244], [68.49180603, 23.60320282], [68.49208069, 23.60320282], [68.49208069, 23.60404015], [68.49236298, 23.60404015], [68.49236298, 23.60486031], [68.49263763, 23.60486031], [68.49263763, 23.60597229], [68.49291992, 23.60597038], [68.49291992, 23.60653114], [68.49318695, 23.60653114], [68.49318695, 23.60680962], [68.49375153, 23.6068058], [68.49375153, 23.60708237], [68.49430847, 23.60708046], [68.49430847, 23.60736084], [68.49458313, 23.60736084], [68.49458313, 23.60764122], [68.49485779, 23.60763931], [68.49485779, 23.60819244], [68.49458313, 23.60819054], [68.49458313, 23.60874939], [68.49346924, 23.60874939], [68.49346924, 23.60902977], [68.49236298, 23.60902786], [68.49236298, 23.60958481], [68.49208069, 23.60958481], [68.49208069, 23.61136055], [68.49208069, 23.61181068], [68.49180603, 23.61181068], [68.49180603, 23.61375046], [68.49153137, 23.61375046], [68.49153137, 23.61486053], [68.49124908, 23.61486053], [68.49124908, 23.61598015], [68.4909668, 23.61598015], [68.4909668, 23.61763954], [68.49124908, 23.61763954], [68.49124908, 23.61903954], [68.49153137, 23.61902809], [68.49153137, 23.61930466], [68.49180603, 23.61930275], [68.49180603, 23.62014008], [68.49208069, 23.62014008], [68.49208069, 23.62181091], [68.49236298, 23.62180328], [68.49236298, 23.62347221], [68.49208069, 23.62347031], [68.49208069, 23.62375069], [68.49153137, 23.62375069], [68.49153137, 23.6245842], [68.49124908, 23.62458038], [68.49124908, 23.62541962], [68.49097443, 23.62541771], [68.49097443, 23.62597275], [68.49014282, 23.62597084], [68.49014282, 23.62625122], [68.48986053, 23.62625122], [68.48986053, 23.62652969], [68.48902893, 23.62652969], [68.48902893, 23.62791824], [68.48930359, 23.62791634], [68.48930359, 23.62819481], [68.48986053, 23.62819481], [68.48986053, 23.62847137], [68.49014282, 23.62846756], [68.49014282, 23.62902832], [68.48958588, 23.62902832], [68.48958588, 23.62930489], [68.48902893, 23.62930489], [68.48902893, 23.62958336], [68.48874664, 23.62957764], [68.48874664, 23.63070107], [68.48902893, 23.63070107], [68.48902893, 23.63153267], [68.48874664, 23.63153267], [68.48874664, 23.63236046], [68.48902893, 23.63236046], [68.48902893, 23.63292122], [68.48930359, 23.6329174], [68.48930359, 23.63319206], [68.48958588, 23.63319016], [68.48958588, 23.63375282], [68.48929596, 23.63375282], [68.48929596, 23.63513947], [68.48902893, 23.63513947], [68.48902893, 23.63541985], [68.48986053, 23.63541412], [68.48986053, 23.63569641], [68.49013519, 23.63569641], [68.49013519, 23.63597488], [68.49041748, 23.63597107], [68.49041748, 23.63624954], [68.49069977, 23.63624954], [68.49069977, 23.63652992], [68.49097443, 23.63652611], [68.49097443, 23.63708305], [68.49124908, 23.63708305], [68.49124908, 23.63736153], [68.49180603, 23.63735962], [68.49180603, 23.63764], [68.49208069, 23.63764], [68.49208069, 23.63735962], [68.49236298, 23.63736153], [68.49236298, 23.63708305], [68.49291992, 23.63708115], [68.49291992, 23.63764], [68.49318695, 23.63764], [68.49318695, 23.63792038], [68.49346924, 23.63792038], [68.49346924, 23.63820076], [68.49319458, 23.63819695], [68.49319458, 23.6384716], [68.49291992, 23.6384697], [68.49291992, 23.63931084], [68.49319458, 23.63930511], [68.49319458, 23.63958359], [68.49346924, 23.63957977], [68.49346924, 23.63986015], [68.49373627, 23.63986015], [68.49373627, 23.64014816], [68.49402618, 23.64014816], [68.49402618, 23.64042091], [68.49430847, 23.6404171], [68.49430847, 23.64097214], [68.49458313, 23.64097023], [68.49458313, 23.64152908], [68.49485779, 23.64152718], [68.49485779, 23.64208412], [68.49514008, 23.6420784], [68.49514008, 23.64236069], [68.4954071, 23.64236069], [68.4954071, 23.64291954], [68.49569702, 23.64291573], [68.49569702, 23.6431942], [68.49624634, 23.6431942], [68.49624634, 23.64347267], [68.49652863, 23.64347076], [68.49652863, 23.64374924], [68.4970932, 23.64374924], [68.4970932, 23.64402962], [68.49736023, 23.64402771], [68.49736023, 23.64418983], [68.49736023, 23.6443119], [68.49781036, 23.64430809], [68.49903107, 23.64430618], [68.49903107, 23.64458275], [68.49886322, 23.64458275], [68.49874878, 23.64458275], [68.49874878, 23.64486122], [68.49847412, 23.64486122], [68.49847412, 23.64569473], [68.49874878, 23.64569283], [68.49874878, 23.64764023], [68.49903107, 23.64763832], [68.49903107, 23.64847183], [68.49874878, 23.64846992], [68.49874878, 23.64931107], [68.49846649, 23.64931107], [68.49846649, 23.64986038], [68.49736023, 23.64986038], [68.49736023, 23.65014076], [68.4970932, 23.65014076], [68.4970932, 23.65042114], [68.49680328, 23.65042114], [68.49680328, 23.65291977], [68.49736023, 23.65291786], [68.49736023, 23.65319443], [68.49764252, 23.65319443], [68.49764252, 23.6534729], [68.49819183, 23.65347099], [68.49819183, 23.65374947], [68.49874878, 23.65374947], [68.49874878, 23.65402985], [68.49903107, 23.65402985], [68.49903107, 23.65430832], [68.49930573, 23.65430641], [68.49930573, 23.65486145], [68.49958038, 23.65485954], [68.49958038, 23.65514946], [68.4998703, 23.65514946], [68.4998703, 23.65570068], [68.50013733, 23.65570068], [68.50013733, 23.65625191], [68.50041962, 23.65625191], [68.50041962, 23.65681267], [68.50069427, 23.65680504], [68.50069427, 23.65708351], [68.50263977, 23.65708351], [68.50263977, 23.65680504], [68.50430298, 23.65680504], [68.50430298, 23.65736008], [68.50458527, 23.65736008], [68.50458527, 23.65819359], [68.50541687, 23.65819359], [68.50541687, 23.65847015], [68.50567627, 23.65847015], [68.50567627, 23.65903282], [68.50681305, 23.65903282], [68.50681305, 23.65875053], [68.50763702, 23.65875053], [68.50763702, 23.65847015], [68.50791931, 23.65847015], [68.50791931, 23.65819359], [68.50846863, 23.65819359], [68.50846863, 23.65791702], [68.5090332, 23.65792274], [68.5090332, 23.65764046], [68.51013947, 23.65763855], [68.51013947, 23.65847015], [68.51040649, 23.65847015], [68.51040649, 23.65930939], [68.51069641, 23.65930939], [68.51069641, 23.65986061], [68.51097107, 23.65986061], [68.51097107, 23.66041946], [68.51180267, 23.66041756], [68.51180267, 23.66069221], [68.51264191, 23.66069221], [68.51264191, 23.66041756], [68.51597595, 23.66041756], [68.51597595, 23.66069221], [68.5173645, 23.66069221], [68.5173645, 23.66041756], [68.51763916, 23.66041946], [68.51763916, 23.6601429], [68.51875305, 23.6601429], [68.51875305, 23.65819168], [68.51902771, 23.65819359], [68.51902771, 23.65736008], [68.51930237, 23.65736008], [68.51930237, 23.65319443], [68.51958466, 23.65319443], [68.51958466, 23.65263939], [68.51985931, 23.65263939], [68.51985931, 23.65236092], [68.5201416, 23.65236092], [68.5201416, 23.65180969], [68.52041626, 23.65180969], [68.52041626, 23.65153122], [68.52179718, 23.65153122], [68.52179718, 23.65125084], [68.52319336, 23.65125084], [68.52319336, 23.65153122], [68.52404022, 23.65153122], [68.52404022, 23.65180969], [68.52513885, 23.65180969], [68.52513885, 23.65208817], [68.52540588, 23.65208817], [68.52540588, 23.65263939], [68.5256958, 23.65263939], [68.5256958, 23.65319443], [68.52597046, 23.65319061], [68.52597046, 23.65374947], [68.52625275, 23.65374947], [68.52625275, 23.6554184], [68.5265274, 23.65541649], [68.5265274, 23.65597153], [68.52680206, 23.65597153], [68.52680206, 23.65736008], [68.52707672, 23.65736008], [68.52707672, 23.65764046], [68.52735901, 23.65763855], [68.52735901, 23.65819359], [68.5276413, 23.65819359], [68.5276413, 23.65847015], [68.52791595, 23.65847015], [68.52791595, 23.65875053], [68.52819824, 23.65875053], [68.52819824, 23.65903282], [68.5284729, 23.65903282], [68.5284729, 23.65930939], [68.52874756, 23.65930557], [68.52874756, 23.65958214], [68.52902985, 23.65958214], [68.52902985, 23.65930557], [68.53152466, 23.65930557], [68.53152466, 23.65958214], [68.5320816, 23.65958023], [68.5320816, 23.65986061], [68.53347015, 23.65986061], [68.53347015, 23.65958023], [68.5359726, 23.65958214], [68.5359726, 23.65986061], [68.53624725, 23.65986061], [68.53624725, 23.66041946], [68.53652954, 23.66041756], [68.53652954, 23.66069221], [68.53736115, 23.66069221], [68.53736115, 23.6609745], [68.53791809, 23.66096115], [68.53791809, 23.66125107], [68.53819275, 23.66125107], [68.53819275, 23.66152954], [68.53847504, 23.66152763], [68.53847504, 23.66208267], [68.53874969, 23.66208076], [68.53874969, 23.66236115], [68.53901672, 23.66236115], [68.53902435, 23.66263962], [68.53848267, 23.66263962], [68.53848267, 23.66292], [68.53652954, 23.66292], [68.53652954, 23.66263962], [68.53624725, 23.66263962], [68.53624725, 23.66236115], [68.5359726, 23.66236115], [68.5359726, 23.66208267], [68.53569794, 23.66208267], [68.53569794, 23.6618042], [68.5348587, 23.66180992], [68.5348587, 23.66152954], [68.5340271, 23.66152954], [68.5340271, 23.66125107], [68.53263855, 23.66125107], [68.53263855, 23.66152954], [68.53235626, 23.66152954], [68.53235626, 23.66180992], [68.53125, 23.6618042], [68.53125, 23.66208267], [68.52986145, 23.66208267], [68.52986145, 23.6618042], [68.52929688, 23.66180992], [68.52929688, 23.66152954], [68.52874756, 23.66152954], [68.52874756, 23.66125107], [68.52819824, 23.66125107], [68.52819061, 23.66096115], [68.52791595, 23.6609745], [68.52791595, 23.66069221], [68.5276413, 23.66069221], [68.5276413, 23.66041756], [68.52735901, 23.66041946], [68.52735901, 23.65986061], [68.52707672, 23.65986061], [68.52707672, 23.65958023], [68.52680206, 23.65958214], [68.52680206, 23.65930557], [68.5265274, 23.65930939], [68.5265274, 23.65875053], [68.52625275, 23.65875053], [68.52625275, 23.65819168], [68.52597046, 23.65819359], [68.52597046, 23.65708351], [68.5256958, 23.65708351], [68.5256958, 23.65541649], [68.52540588, 23.6554184], [68.52540588, 23.65430832], [68.52458191, 23.65430832], [68.52458191, 23.65402985], [68.52430725, 23.65402985], [68.52430725, 23.65347099], [68.52402496, 23.6534729], [68.52402496, 23.65319443], [68.52347565, 23.65319443], [68.52347565, 23.6534729], [68.5220871, 23.65347099], [68.5220871, 23.65402985], [68.52179718, 23.65402985], [68.52179718, 23.65430832], [68.52041626, 23.65430641], [68.52041626, 23.65458298], [68.5201416, 23.65458298], [68.5201416, 23.65486145], [68.52041626, 23.65485954], [68.52041626, 23.65570068], [68.52068329, 23.65570068], [68.52068329, 23.65653038], [68.52041626, 23.65652847], [68.52041626, 23.65708351], [68.5201416, 23.6570816], [68.5201416, 23.65764046], [68.51985931, 23.65763855], [68.51985931, 23.65847015], [68.51957703, 23.65847015], [68.51957703, 23.6601429], [68.51930237, 23.6601429], [68.51930237, 23.66125107], [68.51875305, 23.66125107], [68.51875305, 23.66152954], [68.51847076, 23.66152954], [68.51847076, 23.66180992], [68.51791382, 23.6618042], [68.51791382, 23.66208267], [68.5173645, 23.66208267], [68.5173645, 23.66347313], [68.51763916, 23.66347122], [68.51763916, 23.66374969], [68.51790619, 23.66374969], [68.51790619, 23.66403008], [68.51819611, 23.66402817], [68.51819611, 23.66458321], [68.51847076, 23.66458321], [68.51847076, 23.66486168], [68.51875305, 23.66485977], [68.51875305, 23.66542053], [68.51847076, 23.66542053], [68.51847076, 23.66680908], [68.51875305, 23.66680908], [68.51875305, 23.66791916], [68.51902771, 23.66791725], [68.51902771, 23.66847229], [68.51930237, 23.66847038], [68.51930237, 23.66875076], [68.51957703, 23.66875076], [68.51957703, 23.66931152], [68.51985931, 23.6693058], [68.51985931, 23.66958237], [68.5201416, 23.66958046], [68.5201416, 23.66986084], [68.52069092, 23.66986084], [68.52069092, 23.67013931], [68.52097321, 23.67012978], [68.52097321, 23.6704216], [68.52153015, 23.67041588], [68.52153015, 23.67069435], [68.52180481, 23.67069435], [68.52180481, 23.67097282], [68.5220871, 23.67097092], [68.5220871, 23.67124939], [68.52236176, 23.67124939], [68.52236176, 23.6720829], [68.52263641, 23.6720829], [68.52263641, 23.67292023], [68.5229187, 23.67291641], [68.5229187, 23.67347145], [68.52319336, 23.67346954], [68.52319336, 23.6740303], [68.52348328, 23.6740303], [68.52348328, 23.67431068], [68.52375031, 23.67430305], [68.52375031, 23.67486382], [68.52404022, 23.67486], [68.52404022, 23.67514038], [68.52458191, 23.67514038], [68.52458191, 23.67542076], [68.5248642, 23.67541695], [68.5248642, 23.67569351], [68.52541351, 23.67569351], [68.52541351, 23.67597198], [68.5256958, 23.67597008], [68.5256958, 23.67625999], [68.52625275, 23.67625046], [68.52625275, 23.67708588], [68.5265274, 23.67708015], [68.5265274, 23.67875099], [68.52680969, 23.67875099], [68.52680969, 23.68152809], [68.52708435, 23.68152809], [68.52708435, 23.68347168], [68.52735901, 23.68347168], [68.52735901, 23.68680954], [68.52707672, 23.68680954], [68.52708435, 23.68736076], [68.52680969, 23.68736076], [68.52680969, 23.68791962], [68.5265274, 23.68791962], [68.5265274, 23.6882], [68.52625275, 23.68819237], [68.52625275, 23.68847466], [68.52597046, 23.68847084], [68.52597046, 23.68875122], [68.5256958, 23.68875122], [68.5256958, 23.68902969], [68.52513885, 23.68902969], [68.52513885, 23.68931007], [68.5248642, 23.68930435], [68.5248642, 23.68958282], [68.52458191, 23.68958092], [68.52458191, 23.69042015], [68.5248642, 23.69041443], [68.5248642, 23.69069672], [68.52541351, 23.69069672], [68.52541351, 23.69041443], [68.52597046, 23.69042015], [68.52597046, 23.69013977], [68.52625275, 23.69013977], [68.52625275, 23.68985939], [68.5265274, 23.6898613], [68.5265274, 23.68958282], [68.52680206, 23.68958282], [68.52680206, 23.68930435], [68.52735901, 23.68931007], [68.52735901, 23.68902969], [68.5276413, 23.68902969], [68.5276413, 23.68875122], [68.52791595, 23.68875122], [68.52791595, 23.68847084], [68.52958679, 23.68847084], [68.52958679, 23.68875122], [68.52984619, 23.68875122], [68.52984619, 23.68902969], [68.53013611, 23.68902969], [68.53013611, 23.68931007], [68.53069305, 23.68931007], [68.53069305, 23.68902969], [68.5320816, 23.68902969], [68.5320816, 23.68931007], [68.53236389, 23.68930435], [68.53236389, 23.68958282], [68.53263855, 23.68958282], [68.53263855, 23.6898613], [68.53291321, 23.68985939], [68.53291321, 23.69013977], [68.53320312, 23.69013977], [68.5331955, 23.68958282], [68.53347015, 23.68958282], [68.53347015, 23.68930435], [68.53569794, 23.68930435], [68.53569794, 23.68958282], [68.5359726, 23.68958282], [68.5359726, 23.69013977], [68.53679657, 23.69013977], [68.53679657, 23.69042015], [68.53736115, 23.69041443], [68.53736115, 23.69069672], [68.53819275, 23.69069672], [68.53819275, 23.69097137], [68.53874969, 23.69096947], [68.53874969, 23.69153023], [68.53902435, 23.69152832], [68.53902435, 23.69208336], [68.53930664, 23.69207954], [68.53930664, 23.69292068], [68.5395813, 23.69291878], [68.5395813, 23.69347191], [68.53985596, 23.69346809], [68.53985596, 23.69403076], [68.54152679, 23.69402885], [68.54152679, 23.69430542], [68.54180908, 23.6942997], [68.54180908, 23.69486046], [68.54207611, 23.69486046], [68.54207611, 23.69514084], [68.5423584, 23.69514084], [68.5423584, 23.69541931], [68.54291534, 23.6954174], [68.54291534, 23.69569397], [68.54319763, 23.69569397], [68.54319763, 23.69597244], [68.54347229, 23.69597054], [68.54347229, 23.69625092], [68.54429626, 23.69625092], [68.54429626, 23.69652939], [68.54541779, 23.69652939], [68.54541779, 23.69681168], [68.54624939, 23.69681168], [68.54624939, 23.69735909], [68.54652405, 23.69735909], [68.54652405, 23.6981945], [68.54680634, 23.6981926], [68.54680634, 23.69874954], [68.54708099, 23.69874954], [68.54708099, 23.69930267], [68.54736328, 23.69930649], [68.54736328, 23.69986153], [68.54763794, 23.69985962], [68.54763794, 23.70070076], [68.54792023, 23.70070076], [68.54792023, 23.70125008], [68.54818726, 23.70125008], [68.54818726, 23.70181084], [68.54846954, 23.70181084], [68.54846954, 23.70236015], [68.54875183, 23.70236015], [68.54875183, 23.70292091], [68.54902649, 23.70292091], [68.54902649, 23.70375061], [68.54930878, 23.70375061], [68.54930878, 23.70430946], [68.54957581, 23.70430946], [68.54957581, 23.70486069], [68.54985809, 23.70486069], [68.54985809, 23.70541954], [68.55014038, 23.70541763], [68.55014038, 23.70624924], [68.55042267, 23.7062397], [68.55042267, 23.70680809], [68.55069733, 23.70680809], [68.55069733, 23.70736122], [68.55097961, 23.70736122], [68.55097961, 23.70791817], [68.55124664, 23.70791817], [68.55124664, 23.70874977], [68.55152893, 23.70874977], [68.55152893, 23.70930481], [68.55180359, 23.70930481], [68.55180359, 23.70986176], [68.55208588, 23.70986176], [68.55208588, 23.71042252], [68.55236053, 23.71041679], [68.55236053, 23.71097183], [68.55264282, 23.71097183], [68.55264282, 23.71153259], [68.55291748, 23.71152687], [68.55291748, 23.71208382], [68.55319214, 23.71208191], [68.55319214, 23.71236038], [68.5534668, 23.71236038], [68.5534668, 23.71292114], [68.55374908, 23.71291733], [68.55374908, 23.71347237], [68.55401611, 23.71347046], [68.55401611, 23.71375084], [68.55430603, 23.71375084], [68.55430603, 23.71403122], [68.55458069, 23.7140274], [68.55458069, 23.71458244], [68.55486298, 23.71458054], [68.55486298, 23.71486092], [68.55513763, 23.71486092], [68.55513763, 23.71513939], [68.55541992, 23.71513939], [68.55541992, 23.71569633], [68.55569458, 23.71569633], [68.55569458, 23.71597481], [68.55596924, 23.71597099], [68.55596924, 23.71624947], [68.55625153, 23.71624947], [68.55625153, 23.71652985], [68.55652618, 23.71652794], [68.55652618, 23.71708488], [68.55680847, 23.71708488], [68.55680847, 23.71736145], [68.55708313, 23.71735954], [68.55708313, 23.71763992], [68.55735779, 23.71763992], [68.55735779, 23.7179203], [68.55764008, 23.7179203], [68.55764008, 23.71820068], [68.5579071, 23.71820068], [68.5579071, 23.71875], [68.55819702, 23.71875], [68.55819702, 23.71903038], [68.55847168, 23.71903038], [68.55847168, 23.71931076], [68.55902863, 23.71930695], [68.55902863, 23.71958351], [68.55986023, 23.71958351], [68.55986023, 23.71986198], [68.56041718, 23.71986008], [68.56041718, 23.72014046], [68.56096649, 23.72014046], [68.56096649, 23.72042084], [68.56153107, 23.72041893], [68.56153107, 23.72069359], [68.56208038, 23.72069359], [68.56208038, 23.72097206], [68.56263733, 23.72097206], [68.56263733, 23.72125053], [68.56318665, 23.721241], [68.56318665, 23.72153091], [68.56375122, 23.72153091], [68.56375122, 23.72180939], [68.56430817, 23.72180557], [68.56430817, 23.72208405], [68.56569672, 23.72207832], [68.56569672, 23.72236061], [68.56680298, 23.72236061], [68.56680298, 23.72263908], [68.56735992, 23.72263908], [68.56735992, 23.72291946], [68.56791687, 23.72291756], [68.56791687, 23.72319412], [68.56847382, 23.72319412], [68.56847382, 23.7234726], [68.56902313, 23.72347069], [68.56902313, 23.72374916], [68.56958008, 23.72374916], [68.56958008, 23.72402954], [68.57013702, 23.72402763], [68.57013702, 23.72430611], [68.57069397, 23.72430611], [68.57069397, 23.72458267], [68.57125092, 23.72458267], [68.57125092, 23.72486115], [68.57263947, 23.72486115], [68.57263947, 23.72458267], [68.57319641, 23.72458267], [68.57319641, 23.72430611], [68.57375336, 23.72430611], [68.57375336, 23.72402763], [68.57402802, 23.72402954], [68.57402802, 23.72374916], [68.57430267, 23.72374916], [68.57430267, 23.7231884], [68.57458496, 23.72319412], [68.57458496, 23.72291756], [68.57485962, 23.72291946], [68.57485962, 23.72263908], [68.57514954, 23.72263908], [68.57514954, 23.72207832], [68.57541656, 23.72208405], [68.57541656, 23.72180557], [68.57569122, 23.72180939], [68.57569122, 23.721241], [68.57597351, 23.72125053], [68.57597351, 23.72097206], [68.57624817, 23.72097206], [68.57624817, 23.72069359], [68.57653046, 23.72069359], [68.57653046, 23.72041893], [68.57707977, 23.72042084], [68.57707977, 23.72014046], [68.57763672, 23.72014046], [68.57763672, 23.72042084], [68.57736206, 23.72041893], [68.57736206, 23.72125053], [68.57707977, 23.721241], [68.57707977, 23.72180939], [68.57681274, 23.72180939], [68.57681274, 23.72263908], [68.57653046, 23.72263908], [68.57653046, 23.72374916], [68.57624817, 23.72374916], [68.57624817, 23.72458267], [68.57680511, 23.72458267], [68.57680511, 23.72486115], [68.57736206, 23.72486115], [68.57736206, 23.72513962], [68.57763672, 23.72513962], [68.57763672, 23.72542191], [68.57819366, 23.72541618], [68.57819366, 23.72569466], [68.57847595, 23.72569466], [68.57847595, 23.72597122], [68.57875061, 23.72597122], [68.57875061, 23.72653008], [68.57902527, 23.72652817], [68.57902527, 23.7270813], [68.57930756, 23.72707939], [68.57930756, 23.72764015], [68.57958221, 23.72764015], [68.57958221, 23.72820091], [68.5798645, 23.72819328], [68.5798645, 23.72847176], [68.58040619, 23.72846985], [68.58040619, 23.72875023], [68.58096313, 23.72875023], [68.58096313, 23.72903061], [68.58207703, 23.72903061], [68.58207703, 23.72931099], [68.58319092, 23.72930336], [68.58319092, 23.72958565], [68.58486176, 23.72957993], [68.58486176, 23.72986031], [68.58653259, 23.72986031], [68.58653259, 23.73014069], [68.58763885, 23.73014069], [68.58763885, 23.7304306], [68.58875275, 23.73041534], [68.58875275, 23.73069572], [68.58958435, 23.73069572], [68.58958435, 23.73097229], [68.59041595, 23.73097038], [68.59041595, 23.73125076], [68.59124756, 23.73125076], [68.59124756, 23.73153114], [68.59208679, 23.73153114], [68.59208679, 23.73125076], [68.59236145, 23.73125076], [68.59236145, 23.73097038], [68.59263611, 23.73097229], [68.59263611, 23.73069572], [68.59347534, 23.73069572], [68.59347534, 23.73041534], [68.59430695, 23.7304306], [68.59430695, 23.73014069], [68.59541321, 23.73013878], [68.59541321, 23.73097229], [68.59513855, 23.73097038], [68.59513855, 23.73180962], [68.59541321, 23.73180962], [68.59541321, 23.73236084], [68.59570313, 23.73236084], [68.59570313, 23.73264122], [68.59597015, 23.73264122], [68.59597015, 23.73291969], [68.59625244, 23.73291779], [68.59625244, 23.73319435], [68.5965271, 23.73319435], [68.5965271, 23.73347282], [68.59680176, 23.73347092], [68.59680939, 23.73374939], [68.59707642, 23.73374939], [68.59707642, 23.73402977], [68.59764099, 23.73402977], [68.59764099, 23.73430824], [68.59791565, 23.73430634], [68.59791565, 23.7345829], [68.59819794, 23.7345829], [68.59819794, 23.73569489], [68.5984726, 23.73568916], [68.5984726, 23.7365303], [68.59874725, 23.7365303], [68.59874725, 23.73681259], [68.59902954, 23.73680496], [68.59902954, 23.73736191], [68.59929657, 23.73736191], [68.59929657, 23.73764038], [68.59902954, 23.73763847], [68.59902954, 23.7381916], [68.59874725, 23.73820114], [68.59874725, 23.73875046], [68.5984726, 23.73875046], [68.5984726, 23.73903275], [68.59792328, 23.73903275], [68.59792328, 23.73931122], [68.59764099, 23.7393055], [68.59764099, 23.73958206], [68.59792328, 23.73958015], [68.59792328, 23.74014282], [68.59819794, 23.74014282], [68.59819794, 23.74041939], [68.60124969, 23.74041939], [68.60124969, 23.74570084], [68.60151672, 23.74570084], [68.60151672, 23.74625015], [68.60180664, 23.74625015], [68.60180664, 23.74681091], [68.6020813, 23.74680519], [68.6020813, 23.74708366], [68.60235596, 23.74707985], [68.60235596, 23.74736023], [68.60263824, 23.74736023], [68.60263824, 23.74764061], [68.6029129, 23.7476387], [68.6029129, 23.74819374], [68.60319519, 23.74819374], [68.60319519, 23.74847221], [68.60346985, 23.74847031], [68.60346985, 23.74875069], [68.60402679, 23.74875069], [68.60402679, 23.74847031], [68.60736084, 23.74847031], [68.60736084, 23.74875069], [68.6076355, 23.74875069], [68.6076355, 23.74986076], [68.61152649, 23.74986076], [68.61152649, 23.75013924], [68.61207581, 23.75013924], [68.61207581, 23.75041962], [68.61235809, 23.7504158], [68.61235809, 23.75069427], [68.61264038, 23.75069427], [68.61264038, 23.75097275], [68.61319733, 23.75097084], [68.61319733, 23.75125122], [68.61347198, 23.75125122], [68.61347198, 23.75154114], [68.61374664, 23.75154114], [68.61374664, 23.75181007], [68.61486053, 23.75180626], [68.61486053, 23.75208282], [68.61597443, 23.75208282], [68.61597443, 23.7523613], [68.61707306, 23.75235939], [68.61707306, 23.75263977], [68.61902618, 23.75263977], [68.61902618, 23.75292015], [68.62097168, 23.75291634], [68.62097168, 23.75319481], [68.62124634, 23.75319481], [68.62124634, 23.75347137], [68.62152863, 23.75346947], [68.62152863, 23.75403023], [68.62180328, 23.75403023], [68.62180328, 23.75431061], [68.62403107, 23.75430489], [68.62403107, 23.75458336], [68.62431335, 23.75457954], [68.62431335, 23.75542068], [68.62458038, 23.75542068], [68.62458038, 23.75570107], [68.62486267, 23.75569344], [68.62486267, 23.75597191], [68.62541962, 23.75597], [68.62541962, 23.75625038], [68.62568665, 23.75625038], [68.62568665, 23.75653076], [68.62596893, 23.75653076], [68.62596893, 23.75681114], [68.62652588, 23.75680351], [68.62652588, 23.7570858], [68.62708282, 23.7570858], [68.62708282, 23.75736046], [68.62763977, 23.75735092], [68.62763977, 23.75764084], [68.62819672, 23.75764084], [68.62819672, 23.75792122], [68.62847137, 23.7579174], [68.62847137, 23.75819588], [68.62902832, 23.75819588], [68.62902832, 23.75847244], [68.62930298, 23.75847054], [68.62930298, 23.75875092], [68.6295929, 23.75875092], [68.6295929, 23.75902939], [68.63069153, 23.75902939], [68.63069153, 23.75875092], [68.63096619, 23.75875092], [68.63096619, 23.75847054], [68.63124847, 23.75847244], [68.63124847, 23.75819588], [68.63153076, 23.75819588], [68.63153076, 23.7579174], [68.63263702, 23.7579174], [68.63263702, 23.75847244], [68.63291931, 23.75847054], [68.63291931, 23.75902939], [68.63263702, 23.75902939], [68.63263702, 23.75986099], [68.63236237, 23.75986099], [68.63236237, 23.76097298], [68.63208008, 23.76097298], [68.63207245, 23.76180077], [68.63236237, 23.76180649], [68.63236237, 23.76236153], [68.63263702, 23.76235962], [68.63263702, 23.76291847], [68.63291931, 23.76291847], [68.63291931, 23.76348114], [68.63318634, 23.76348114], [68.63318634, 23.76403046], [68.63346863, 23.76403046], [68.63346863, 23.76431274], [68.63375092, 23.76431274], [68.63375092, 23.76486015], [68.6340332, 23.76486015], [68.6340332, 23.76542282], [68.63430786, 23.7654171], [68.63430786, 23.76597023], [68.63458252, 23.76597023], [68.63458252, 23.76654053], [68.63486481, 23.76652718], [68.63486481, 23.76708221], [68.63513947, 23.76708031], [68.63513947, 23.76764107], [68.63541412, 23.76763916], [68.63541412, 23.76819229], [68.63569641, 23.76819038], [68.63569641, 23.76875114], [68.63597107, 23.76875114], [68.63597107, 23.76931], [68.63625336, 23.76930428], [68.63625336, 23.76958275], [68.63652802, 23.76958084], [68.63652802, 23.77013969], [68.63680267, 23.77013969], [68.63680267, 23.77069664], [68.63708496, 23.77069664], [68.63708496, 23.77124977], [68.63735962, 23.77124977], [68.63735962, 23.77153015], [68.63764191, 23.77152824], [68.63764191, 23.77208328], [68.63791656, 23.77208328], [68.63791656, 23.77236176], [68.63819885, 23.77235031], [68.63819885, 23.77292061], [68.63846588, 23.77292061], [68.63846588, 23.77319908], [68.63874817, 23.77319908], [68.63874817, 23.77375031], [68.63903046, 23.77375031], [68.63903046, 23.77430916], [68.63930511, 23.77430534], [68.63930511, 23.77458382], [68.63957977, 23.77457809], [68.63957977, 23.77514076], [68.63986206, 23.77514076], [68.63986206, 23.77541924], [68.64013672, 23.77541733], [68.64013672, 23.77597237], [68.64041901, 23.77597046], [68.64041901, 23.77625084], [68.64068604, 23.77625084], [68.64068604, 23.7768116], [68.64097595, 23.77680588], [68.64097595, 23.77708244], [68.64124298, 23.77708054], [68.64124298, 23.77763939], [68.6415329, 23.77763939], [68.6415329, 23.77792168], [68.64180756, 23.77792168], [68.64180756, 23.77848053], [68.64208221, 23.77848053], [68.64208221, 23.77874947], [68.64235687, 23.77874947], [68.64235687, 23.77902985], [68.64263916, 23.77902794], [68.64263916, 23.77958107], [68.64291382, 23.77958107], [68.64291382, 23.77986145], [68.64319611, 23.77985954], [68.64319611, 23.78013992], [68.64347076, 23.78013992], [68.64347076, 23.78070068], [68.64375305, 23.78069305], [68.64375305, 23.78097153], [68.64402771, 23.78096962], [68.64402771, 23.78125], [68.64430237, 23.78125], [68.64430237, 23.78181076], [68.64458466, 23.78180313], [68.64458466, 23.78208351], [68.64485931, 23.78208351], [68.64485931, 23.78236389], [68.6451416, 23.78236008], [68.6451416, 23.78292084], [68.64541626, 23.78291512], [68.64541626, 23.78347206], [68.64569092, 23.78347015], [68.64569092, 23.78375053], [68.64597321, 23.78375053], [68.64597321, 23.78430939], [68.64624786, 23.78430939], [68.64624786, 23.78486061], [68.64653015, 23.78486061], [68.64653015, 23.78541946], [68.64680481, 23.78541756], [68.64680481, 23.78569412], [68.6470871, 23.78569031], [68.6470871, 23.78625107], [68.64736938, 23.78625107], [68.64736938, 23.78680992], [68.64763641, 23.78680611], [68.64763641, 23.78708267], [68.6479187, 23.78708076], [68.6479187, 23.78764915], [68.64819336, 23.78764915], [68.64819336, 23.78791809], [68.64847565, 23.78791618], [68.64847565, 23.78847313], [68.64875031, 23.78847122], [68.64875031, 23.78874969], [68.64902496, 23.78874969], [68.64902496, 23.78930473], [68.64930725, 23.78930473], [68.64930725, 23.78958321], [68.64958191, 23.78957748], [68.64958191, 23.79014015], [68.64985657, 23.79014015], [68.64985657, 23.79071045], [68.65013885, 23.79071045], [68.65013885, 23.79153252], [68.65041351, 23.7915287], [68.65041351, 23.79208374], [68.6506958, 23.79208183], [68.6506958, 23.79292107], [68.65097046, 23.79291725], [68.65097046, 23.79347229], [68.6506958, 23.79346275], [68.6506958, 23.79375076], [68.65097046, 23.79375076], [68.65097046, 23.79403114], [68.65125275, 23.79403114], [68.65125275, 23.79430962], [68.65180206, 23.7943058], [68.65180206, 23.79458237], [68.65207672, 23.79458046], [68.65207672, 23.79514122], [68.65235901, 23.79514122], [68.65235901, 23.79541969], [68.6526413, 23.79541588], [68.6526413, 23.79569244], [68.65291595, 23.79569244], [68.65291595, 23.79597473], [68.65319824, 23.79597473], [68.65319824, 23.79652786], [68.6534729, 23.79652023], [68.6534729, 23.79681015], [68.65374756, 23.79680443], [68.65374756, 23.7970829], [68.65402985, 23.7970829], [68.65402985, 23.79736137], [68.65429688, 23.79735947], [68.65429688, 23.79763985], [68.65458679, 23.79763985], [68.65458679, 23.79792023], [68.65486145, 23.79791451], [68.65486145, 23.79819679], [68.65513611, 23.79819107], [68.65513611, 23.79874992], [68.6554184, 23.79874992], [68.6554184, 23.7990303], [68.65569305, 23.7990303], [68.65569305, 23.79931068], [68.65598297, 23.79931068], [68.65598297, 23.79959106], [68.65625, 23.79958344], [68.65625, 23.79986191], [68.65651703, 23.79985809], [68.65651703, 23.80014038], [68.65680695, 23.80014038], [68.65680695, 23.80042076], [68.6570816, 23.80041885], [68.6570816, 23.80069351], [68.65736389, 23.80069351], [68.65736389, 23.80097198], [68.65763855, 23.80096817], [68.65763855, 23.80125046], [68.65791321, 23.80125046], [68.65791321, 23.80153084], [68.65820313, 23.80153084], [68.65820313, 23.80180931], [68.65847015, 23.8018055], [68.65847015, 23.80208397], [68.65875244, 23.80207825], [68.65875244, 23.80265045], [68.6590271, 23.80265045], [68.6590271, 23.80291939], [68.65930176, 23.80291748], [68.65930939, 23.80319405], [68.6598587, 23.80319405], [68.6598587, 23.80347252], [68.66042328, 23.80347061], [68.66042328, 23.80374908], [68.6609726, 23.80374908], [68.6609726, 23.80402946], [68.66152954, 23.80402946], [68.66152954, 23.80431175], [68.66208649, 23.80430603], [68.66208649, 23.8045826], [68.66236115, 23.8045826], [68.66236115, 23.80486107], [68.6626358, 23.80486107], [68.6626358, 23.80542183], [68.66291809, 23.80541611], [68.66291809, 23.80569458], [68.66319275, 23.80569458], [68.66319275, 23.80597115], [68.66374969, 23.80597115], [68.66374969, 23.80624962], [68.66401672, 23.80624962], [68.66401672, 23.80653191], [68.66430664, 23.80652809], [68.66430664, 23.80680466], [68.6645813, 23.80680466], [68.6645813, 23.80708122], [68.66486359, 23.80708122], [68.66486359, 23.8073616], [68.6654129, 23.8073597], [68.6654129, 23.80764008], [68.66570282, 23.80764008], [68.66570282, 23.80792046], [68.66596985, 23.80792046], [68.66596985, 23.80820084], [68.66625214, 23.80819321], [68.66625214, 23.80847168], [68.66680908, 23.80846024], [68.66680908, 23.80875015], [68.66764069, 23.80875015], [68.66764069, 23.80903053], [68.66819763, 23.80903053], [68.66819763, 23.80931091], [68.66902924, 23.80930328], [68.66902924, 23.80958557], [68.66958618, 23.80957985], [68.66958618, 23.80986023], [68.66986084, 23.80986023], [68.66986084, 23.81042099], [68.6701355, 23.81041527], [68.6701355, 23.81069374], [68.67124939, 23.81069374], [68.67124939, 23.81097221], [68.67236328, 23.81097221], [68.67236328, 23.81069374], [68.67430878, 23.81069374], [68.67430878, 23.81097221], [68.67541504, 23.81097221], [68.67541504, 23.81069374], [68.67569733, 23.81069374], [68.67569733, 23.8101387], [68.67597198, 23.81014061], [68.67597198, 23.80931091], [68.67624664, 23.80931091], [68.67624664, 23.80875015], [68.67652893, 23.80875015], [68.67652893, 23.80820084], [68.67679596, 23.80820084], [68.67679596, 23.80764008], [68.67791748, 23.80764008], [68.67791748, 23.80875015], [68.67763519, 23.80875015], [68.67763519, 23.80958557], [68.67735291, 23.80957985], [68.67735291, 23.81014061], [68.67708588, 23.81014061], [68.67708588, 23.81125069], [68.67680359, 23.81125069], [68.67680359, 23.8120842], [68.67708588, 23.8120842], [68.67708588, 23.81319427], [68.67735291, 23.81319046], [68.67735291, 23.81430817], [68.67791748, 23.81430817], [68.67791748, 23.81459045], [68.67819214, 23.81458282], [68.67819214, 23.8148613], [68.67874908, 23.81485748], [68.67874908, 23.81513977], [68.67930603, 23.81513977], [68.67930603, 23.81541824], [68.67958069, 23.81541634], [68.67958069, 23.81569481], [68.68013763, 23.81569481], [68.68013763, 23.81597137], [68.68041229, 23.81596756], [68.68041229, 23.81624985], [68.68096924, 23.81624985], [68.68096924, 23.81653023], [68.68152618, 23.81652832], [68.68152618, 23.81680489], [68.68180847, 23.81680489], [68.68180847, 23.81708336], [68.68235779, 23.81708336], [68.68235779, 23.81736183], [68.68264008, 23.81736183], [68.68264008, 23.81792259], [68.6829071, 23.81792259], [68.6829071, 23.81875038], [68.68264008, 23.81875038], [68.68264008, 23.81931114], [68.68347168, 23.81930542], [68.68347168, 23.81958389], [68.68402863, 23.81958008], [68.68402863, 23.81986046], [68.6845932, 23.81986046], [68.6845932, 23.82014275], [68.68486023, 23.82014275], [68.68486023, 23.82042122], [68.68541718, 23.8204174], [68.68541718, 23.82069206], [68.68597412, 23.82069206], [68.68597412, 23.82097244], [68.68653107, 23.82097244], [68.68653107, 23.82125092], [68.68681335, 23.82125092], [68.68681335, 23.82152939], [68.68736267, 23.82152939], [68.68736267, 23.82180977], [68.68846893, 23.82180405], [68.68846893, 23.82208252], [68.68930817, 23.82208061], [68.68930817, 23.82236099], [68.6904068, 23.82236099], [68.6904068, 23.82263947], [68.69458008, 23.82263947], [68.69458008, 23.82291985], [68.69680786, 23.82291412], [68.69680786, 23.82319641], [68.69847107, 23.82319641], [68.69847107, 23.82347488], [68.69985962, 23.82347107], [68.69985962, 23.82374954], [68.70153809, 23.82374954], [68.70153809, 23.82402992], [68.70319366, 23.82402611], [68.70318604, 23.82430077], [68.7048645, 23.82430458], [68.7048645, 23.82458305], [68.70625305, 23.82458305], [68.70625305, 23.82486153], [68.7076416, 23.82485962], [68.7076416, 23.82514], [68.70903015, 23.82514], [68.70903015, 23.82542038], [68.71098328, 23.82542038], [68.71098328, 23.82570076], [68.71736145, 23.82569695], [68.71736145, 23.8259716], [68.71847534, 23.8259716], [68.71847534, 23.82625008], [68.71930695, 23.82625008], [68.71930695, 23.82653046], [68.72013855, 23.82653046], [68.72013855, 23.82681847], [68.72097015, 23.82680511], [68.72097015, 23.82708359], [68.72180176, 23.82707977], [68.72180939, 23.82736015], [68.72264862, 23.82736015], [68.72264862, 23.82764053], [68.7234726, 23.82764053], [68.7234726, 23.82792091], [68.7243042, 23.8279171], [68.7243042, 23.82819366], [68.72486115, 23.82819366], [68.72486115, 23.82847214], [68.72569275, 23.82846832], [68.72569275, 23.82875061], [68.72624969, 23.82875061], [68.72624969, 23.82902908], [68.72651672, 23.82902908], [68.72651672, 23.82930946], [68.7270813, 23.82930565], [68.7270813, 23.82958412], [68.72735596, 23.82957077], [68.72735596, 23.82986069], [68.7279129, 23.82986069], [68.7279129, 23.83013916], [68.72820282, 23.83013916], [68.72820282, 23.83041954], [68.72875214, 23.83041573], [68.72875214, 23.8306942], [68.7298584, 23.8306942], [68.7298584, 23.83097267], [68.73069763, 23.83097076], [68.73069763, 23.83124924], [68.73124695, 23.83124924], [68.73124695, 23.83152962], [68.73179626, 23.83152962], [68.73179626, 23.8318119], [68.73236084, 23.83180618], [68.73236084, 23.83208275], [68.7326355, 23.83208275], [68.7326355, 23.83236122], [68.73319244, 23.83236122], [68.73319244, 23.83263969], [68.73374939, 23.83263016], [68.73374939, 23.83292007], [68.73430634, 23.83291626], [68.73430634, 23.83319473], [68.73486328, 23.83319473], [68.73486328, 23.8334713], [68.73542023, 23.83346939], [68.73542023, 23.83374977], [68.73596954, 23.83374977], [68.73596954, 23.83403015], [68.73652649, 23.83402824], [68.73652649, 23.83430481], [68.73708344, 23.83430481], [68.73708344, 23.83458328], [68.73735809, 23.83458328], [68.73735809, 23.83486176], [68.73764801, 23.83485985], [68.73764801, 23.83542061], [68.73791504, 23.83541679], [68.73791504, 23.83569336], [68.73819733, 23.83569336], [68.73819733, 23.83597183], [68.73902893, 23.83596992], [68.73902893, 23.83625031], [68.73986053, 23.83625031], [68.73986053, 23.83653069], [68.7409668, 23.83653069], [68.7409668, 23.83681107], [68.74180603, 23.83680344], [68.74180603, 23.83708572], [68.74263763, 23.83708], [68.74263763, 23.83903122], [68.74318695, 23.83903122], [68.74318695, 23.83930969], [68.74375153, 23.83930969], [68.74375153, 23.83986092], [68.74402618, 23.83986092], [68.74402618, 23.84182167], [68.74375153, 23.84180641], [68.74375153, 23.84236145], [68.74318695, 23.84235954], [68.74318695, 23.84263992], [68.74291992, 23.84263992], [68.74291992, 23.84347153], [68.74318695, 23.84347153], [68.74318695, 23.84375191], [68.74263763, 23.84375191], [68.74263763, 23.84347153], [68.74236298, 23.84347153], [68.74236298, 23.84319496], [68.74208069, 23.84320259], [68.74208069, 23.8429184], [68.74153137, 23.8429184], [68.74153137, 23.84263992], [68.74124908, 23.84263992], [68.74124908, 23.84235954], [68.74097443, 23.84236145], [68.74097443, 23.84208298], [68.74069214, 23.84208298], [68.74069214, 23.84180641], [68.74014282, 23.84182167], [68.74014282, 23.84152985], [68.73986053, 23.84152985], [68.73986053, 23.84124947], [68.73958588, 23.84124947], [68.73958588, 23.84097099], [68.73930359, 23.8409729], [68.73930359, 23.84069443], [68.73902893, 23.84069443], [68.73902893, 23.84041786], [68.73847198, 23.84041977], [68.73847198, 23.84013939], [68.73819733, 23.84013939], [68.73819733, 23.83986092], [68.73791504, 23.83986092], [68.73791504, 23.83958244], [68.73764038, 23.83958244], [68.73764038, 23.83930779], [68.73707581, 23.83930969], [68.73707581, 23.83903122], [68.73680878, 23.83903122], [68.73680878, 23.83876038], [68.73652649, 23.83876038], [68.73652649, 23.83847046], [68.73625183, 23.83847237], [68.73625183, 23.8381958], [68.73596954, 23.8381958], [68.73596954, 23.83791542], [68.73542023, 23.83792114], [68.73542023, 23.83764076], [68.73513794, 23.83764076], [68.73513794, 23.83736038], [68.73486328, 23.83736038], [68.73486328, 23.83708], [68.73458099, 23.83708572], [68.73458099, 23.83680344], [68.73401642, 23.83681107], [68.73401642, 23.83653069], [68.73374939, 23.83653069], [68.73374939, 23.83625031], [68.7334671, 23.83625031], [68.7334671, 23.83596992], [68.73319244, 23.83597183], [68.73319244, 23.83569336], [68.7326355, 23.83569336], [68.7326355, 23.83541679], [68.73236084, 23.83542061], [68.73236084, 23.83514023], [68.73208618, 23.83514023], [68.73208618, 23.83485985], [68.73152924, 23.83486176], [68.73152924, 23.83458328], [68.73124695, 23.83458328], [68.73124695, 23.83430481], [68.73097229, 23.83430481], [68.73097229, 23.83402824], [68.73042297, 23.83403015], [68.73042297, 23.83374977], [68.73014069, 23.83374977], [68.73014069, 23.83346939], [68.7298584, 23.8334713], [68.7298584, 23.83319473], [68.72958374, 23.83319473], [68.72958374, 23.83291626], [68.72930908, 23.83292007], [68.72930908, 23.83263016], [68.72902679, 23.83263969], [68.72902679, 23.83236122], [68.72875214, 23.83236122], [68.72875214, 23.83208275], [68.72846985, 23.83208275], [68.72846985, 23.83180618], [68.72820282, 23.8318119], [68.72820282, 23.83152962], [68.7279129, 23.83152962], [68.7279129, 23.83124924], [68.72763824, 23.83124924], [68.72763824, 23.83097076], [68.72319794, 23.83097076], [68.72319794, 23.83124924], [68.72292328, 23.83124924], [68.72292328, 23.83152962], [68.7223587, 23.83152962], [68.7223587, 23.8318119], [68.72208405, 23.83180618], [68.72208405, 23.83208275], [68.7223587, 23.83208275], [68.7223587, 23.83236122], [68.72319794, 23.83236122], [68.72319794, 23.83263969], [68.72402954, 23.83263016], [68.72402954, 23.83292007], [68.72486115, 23.83291626], [68.72486115, 23.83319473], [68.72541809, 23.83319473], [68.72541809, 23.8334713], [68.72624969, 23.83346939], [68.72624969, 23.83374977], [68.7270813, 23.83374977], [68.7270813, 23.83403015], [68.72763824, 23.83402824], [68.72763824, 23.83430481], [68.72819519, 23.83430481], [68.72819519, 23.83458328], [68.72846985, 23.83458328], [68.72846985, 23.83486176], [68.72902679, 23.83485985], [68.72902679, 23.83514023], [68.72957611, 23.83514023], [68.72957611, 23.83542061], [68.73014069, 23.83541679], [68.73014069, 23.83569336], [68.73041534, 23.83569336], [68.73041534, 23.83597183], [68.73097229, 23.83596992], [68.73097229, 23.83625031], [68.73152161, 23.83625031], [68.73152161, 23.83653069], [68.73208618, 23.83653069], [68.73208618, 23.83681107], [68.73236084, 23.83680344], [68.73236084, 23.83708572], [68.73291779, 23.83708], [68.73291779, 23.83736038], [68.73264313, 23.83736038], [68.73264313, 23.83764076], [68.73208618, 23.83764076], [68.73208618, 23.83792114], [68.73180389, 23.83791542], [68.73180389, 23.8381958], [68.73124695, 23.8381958], [68.73124695, 23.83847237], [68.73097229, 23.83847046], [68.73097229, 23.83876038], [68.73069763, 23.83876038], [68.73069763, 23.83903122], [68.73014069, 23.83903122], [68.73014069, 23.83930969], [68.7298584, 23.83930779], [68.7298584, 23.83958244], [68.73014069, 23.83958054], [68.73014069, 23.83986092], [68.73097229, 23.83986092], [68.73097229, 23.83958054], [68.73152924, 23.83958244], [68.73152924, 23.83930779], [68.73208618, 23.83930969], [68.73208618, 23.83903122], [68.73236084, 23.83903122], [68.73236084, 23.83876038], [68.73291779, 23.83876038], [68.73291779, 23.83847046], [68.73347473, 23.83847237], [68.73347473, 23.8381958], [68.73402405, 23.8381958], [68.73402405, 23.83791542], [68.73486328, 23.83791542], [68.73486328, 23.8381958], [68.73513794, 23.83819008], [68.73513794, 23.83876038], [68.73542023, 23.83876038], [68.73542023, 23.83930969], [68.73568726, 23.83930969], [68.73568726, 23.84124947], [68.73596954, 23.84124947], [68.73596954, 23.84182167], [68.73625183, 23.84180641], [68.73625183, 23.84236145], [68.73652649, 23.84235954], [68.73652649, 23.84263992], [68.73680878, 23.84263992], [68.73680878, 23.84320259], [68.73707581, 23.84320259], [68.73707581, 23.84375191], [68.73596954, 23.84375191], [68.73596954, 23.84347153], [68.73513794, 23.84347153], [68.73513794, 23.84319496], [68.73374939, 23.84319496], [68.73374939, 23.84347153], [68.7334671, 23.84347153], [68.7334671, 23.84375191], [68.73319244, 23.84375191], [68.73319244, 23.84403038], [68.73291779, 23.84403038], [68.73291779, 23.84431267], [68.7326355, 23.84430504], [68.7326355, 23.84458351], [68.73236084, 23.84456825], [68.73236084, 23.84514046], [68.73208618, 23.84514046], [68.73208618, 23.84542274], [68.73124695, 23.84541702], [68.73124695, 23.84569359], [68.73097229, 23.84569359], [68.73097229, 23.84597015], [68.73041534, 23.84597015], [68.73042297, 23.84625053], [68.72569275, 23.84625053], [68.72569275, 23.84680939], [68.72541809, 23.84680939], [68.72541809, 23.84736061], [68.7251358, 23.84736061], [68.7251358, 23.84791946], [68.72541809, 23.84791756], [68.72541809, 23.84819221], [68.72569275, 23.84819221], [68.72569275, 23.8484726], [68.72598267, 23.84847069], [68.72598267, 23.84875107], [68.72624969, 23.84875107], [68.72624969, 23.84930992], [68.72652435, 23.8493042], [68.72652435, 23.84958267], [68.72680664, 23.84958076], [68.72680664, 23.84986115], [68.7270813, 23.84986115], [68.7270813, 23.85013962], [68.72735596, 23.85013962], [68.72735596, 23.85070038], [68.72763824, 23.85070038], [68.72763824, 23.85124969], [68.7279129, 23.85124969], [68.7279129, 23.85208321], [68.72820282, 23.85207939], [68.72820282, 23.85292053], [68.72846985, 23.85291862], [68.72846985, 23.85347176], [68.72875214, 23.85346985], [68.72875214, 23.85430908], [68.72902679, 23.85430908], [68.72902679, 23.85486031], [68.72957611, 23.85486031], [68.72957611, 23.85514069], [68.7298584, 23.85514069], [68.7298584, 23.85541916], [68.73041534, 23.85541725], [68.73041534, 23.85569382], [68.73097229, 23.85569382], [68.73097229, 23.85597229], [68.73152161, 23.85597038], [68.73152161, 23.85625076], [68.73179626, 23.85625076], [68.73179626, 23.85652924], [68.73236084, 23.85652733], [68.73236084, 23.8568058], [68.73291779, 23.8568058], [68.73291779, 23.85708237], [68.7334671, 23.85707855], [68.7334671, 23.85736084], [68.73374939, 23.85736084], [68.73374939, 23.85763931], [68.73430634, 23.85763931], [68.73430634, 23.85791969], [68.73486328, 23.85791588], [68.73486328, 23.85819435], [68.73542023, 23.85819435], [68.73542023, 23.85847282], [68.73568726, 23.85847282], [68.73568726, 23.85874939], [68.73625183, 23.85874939], [68.73625183, 23.85902977], [68.73680878, 23.85902977], [68.73680878, 23.85931015], [68.73708344, 23.85930634], [68.73708344, 23.8595829], [68.73735809, 23.8595829], [68.73735809, 23.85986137], [68.73792267, 23.85985947], [68.73792267, 23.86013985], [68.73847198, 23.86013985], [68.73847198, 23.86042023], [68.73930359, 23.86041641], [68.73930359, 23.86069489], [68.73986053, 23.86069489], [68.73986053, 23.86097145], [68.74013519, 23.86097145], [68.74013519, 23.86069489], [68.74041748, 23.86069489], [68.74041748, 23.86097145], [68.74236298, 23.86097145], [68.74236298, 23.86069489], [68.74346924, 23.86069489], [68.74346924, 23.86041641], [68.74402618, 23.86042023], [68.74402618, 23.86013985], [68.74569702, 23.86013985], [68.74569702, 23.85985947], [68.74680328, 23.85985947], [68.74680328, 23.86013985], [68.74708557, 23.86013794], [68.74708557, 23.86069489], [68.74736023, 23.86069107], [68.74736023, 23.86181068], [68.74764252, 23.86180305], [68.74764252, 23.86208344], [68.74791718, 23.86208344], [68.74791718, 23.86236191], [68.74819183, 23.86236], [68.74819183, 23.86264038], [68.74847412, 23.86263847], [68.74847412, 23.86319351], [68.74874878, 23.86319351], [68.74874878, 23.86347198], [68.74903107, 23.86347008], [68.74903107, 23.86375046], [68.74846649, 23.86375046], [68.74846649, 23.86347008], [68.74791718, 23.86347198], [68.74791718, 23.86319351], [68.7470932, 23.8631897], [68.74708557, 23.86291695], [68.74652863, 23.86291695], [68.74652863, 23.8631897], [68.74624634, 23.86319351], [68.74624634, 23.86347198], [68.74597168, 23.86347008], [68.74597168, 23.86375046], [68.74569702, 23.86375046], [68.74569702, 23.86541939], [68.74597168, 23.86541748], [68.74597168, 23.86597252], [68.74624634, 23.86597061], [68.74624634, 23.86625099], [68.74680328, 23.86625099], [68.74680328, 23.86652946], [68.7470932, 23.86652946], [68.7470932, 23.86680984], [68.74764252, 23.86680794], [68.74764252, 23.8670826], [68.74791718, 23.86708069], [68.74791718, 23.86736107], [68.74819183, 23.86736107], [68.74819183, 23.86763954], [68.74874878, 23.86763954], [68.74874878, 23.86791992], [68.74903107, 23.86791611], [68.74903107, 23.86819458], [68.74930573, 23.86819458], [68.74930573, 23.86847305], [68.74958038, 23.86847305], [68.74958038, 23.86874962], [68.75013733, 23.86874008], [68.75013733, 23.86902809], [68.75041962, 23.86902809], [68.75041962, 23.86930466], [68.75096893, 23.86930466], [68.75096893, 23.86958313], [68.75125122, 23.86958313], [68.75125122, 23.8698616], [68.75180817, 23.8698597], [68.75180817, 23.87014008], [68.75208282, 23.87014008], [68.75208282, 23.87042236], [68.75263214, 23.87042236], [68.75263214, 23.87070274], [68.75291443, 23.87069511], [68.75291443, 23.87097168], [68.75319672, 23.87097168], [68.75319672, 23.87125015], [68.75374603, 23.87125015], [68.75374603, 23.87153053], [68.75402832, 23.87152863], [68.75402832, 23.87180519], [68.75430298, 23.87180519], [68.75430298, 23.87208366], [68.75458527, 23.87208366], [68.75458527, 23.87236023], [68.75514221, 23.87236023], [68.75514221, 23.87264061], [68.75541687, 23.87264061], [68.75541687, 23.8729229], [68.75569153, 23.87291718], [68.75569153, 23.87319374], [68.75624847, 23.87319374], [68.75624847, 23.87347221], [68.75680542, 23.87347221], [68.75680542, 23.87375069], [68.75708008, 23.87375069], [68.75708008, 23.87403107], [68.75763702, 23.87403107], [68.75763702, 23.87430954], [68.75846863, 23.87430573], [68.75846863, 23.87458229], [68.7590332, 23.87458038], [68.7590332, 23.8748703], [68.76125336, 23.8748703], [68.76125336, 23.87541962], [68.75902557, 23.8754158], [68.75902557, 23.87569237], [68.75653076, 23.87569237], [68.75653076, 23.8754158], [68.75541687, 23.87541962], [68.75541687, 23.87514114], [68.75430298, 23.87514114], [68.75430298, 23.8748703], [68.75402832, 23.8748703], [68.75402832, 23.87430954], [68.75374603, 23.87430954], [68.75374603, 23.87403107], [68.75347137, 23.87403107], [68.75347137, 23.87347031], [68.75319672, 23.87347221], [68.75319672, 23.87319374], [68.75291443, 23.87319374], [68.75291443, 23.87291718], [68.75263214, 23.8729229], [68.75263214, 23.87264061], [68.75208282, 23.87264061], [68.75208282, 23.87236023], [68.75180817, 23.87236023], [68.75180817, 23.87208176], [68.75152588, 23.87208366], [68.75152588, 23.87180519], [68.75125122, 23.87180519], [68.75125122, 23.87152863], [68.75096893, 23.87153053], [68.75096893, 23.87125015], [68.75041962, 23.87125015], [68.75041962, 23.87097168], [68.74986267, 23.87097168], [68.74986267, 23.87069511], [68.74903107, 23.87070274], [68.74903107, 23.87042236], [68.74846649, 23.87042236], [68.74846649, 23.87014008], [68.74819183, 23.87014008], [68.74819183, 23.8698597], [68.74764252, 23.8698616], [68.74764252, 23.86958313], [68.74736023, 23.86958313], [68.74736023, 23.86930466], [68.74680328, 23.86930466], [68.74680328, 23.86902809], [68.74652863, 23.86902809], [68.74652863, 23.86874008], [68.74624634, 23.86874962], [68.74624634, 23.86847305], [68.74569702, 23.86847305], [68.74569702, 23.86819458], [68.74541473, 23.86819458], [68.74541473, 23.86791611], [68.74514008, 23.86791992], [68.74514008, 23.86763954], [68.74485779, 23.86763954], [68.74485779, 23.86736107], [68.74430847, 23.86736107], [68.74430847, 23.86708069], [68.74319458, 23.8670826], [68.74319458, 23.86680794], [68.74208069, 23.86680984], [68.74208069, 23.86625099], [68.74180603, 23.86625099], [68.74180603, 23.86597061], [68.74153137, 23.86597252], [68.74153137, 23.86569595], [68.74124908, 23.86569977], [68.74124908, 23.86541939], [68.7409668, 23.86541939], [68.7409668, 23.86514091], [68.74041748, 23.86514091], [68.74041748, 23.86486053], [68.74013519, 23.86486053], [68.74013519, 23.86458588], [68.73986053, 23.86458588], [68.73986053, 23.8643074], [68.73929596, 23.86431122], [68.73929596, 23.86403084], [68.73874664, 23.86403084], [68.73874664, 23.86375046], [68.73819733, 23.86375046], [68.73819733, 23.86347008], [68.73764038, 23.86347198], [68.73764038, 23.86319351], [68.73707581, 23.8631897], [68.73708344, 23.86291695], [68.73652649, 23.8629303], [68.73652649, 23.86264038], [68.73568726, 23.86264038], [68.73568726, 23.86236], [68.73486328, 23.86236191], [68.73486328, 23.86208344], [68.73014069, 23.86208344], [68.73014069, 23.86180305], [68.7298584, 23.86181068], [68.7298584, 23.86124992], [68.72957611, 23.86124992], [68.72957611, 23.86096954], [68.72930908, 23.86097145], [68.72930908, 23.86069489], [68.72902679, 23.86069489], [68.72902679, 23.86041641], [68.72875214, 23.86042023], [68.72875214, 23.86013985], [68.72846222, 23.86013985], [68.72846222, 23.85985947], [68.7279129, 23.85986137], [68.7279129, 23.8595829], [68.7270813, 23.8595829], [68.7270813, 23.85930634], [68.71848297, 23.85931015], [68.71848297, 23.85902977], [68.71819305, 23.85902977], [68.71819305, 23.85874939], [68.7179184, 23.85874939], [68.7179184, 23.85847282], [68.71763611, 23.85847282], [68.71763611, 23.85819435], [68.71708679, 23.85819435], [68.71708679, 23.85791588], [68.71679688, 23.85791969], [68.71679688, 23.85763931], [68.71624756, 23.85763931], [68.71624756, 23.85736084], [68.71208191, 23.85736084], [68.71208191, 23.85763931], [68.70903015, 23.85763931], [68.70903015, 23.85791969], [68.70708466, 23.85791588], [68.70708466, 23.85819435], [68.7048645, 23.85819435], [68.7048645, 23.85791588], [68.70347595, 23.85791969], [68.70347595, 23.85763931], [68.70318604, 23.85763931], [68.70318604, 23.85736084], [68.70291901, 23.85736084], [68.70291901, 23.85679817], [68.70180511, 23.8568058], [68.70180511, 23.85708427], [68.70096588, 23.85707855], [68.70096588, 23.85736084], [68.70041656, 23.85736084], [68.70041656, 23.85763931], [68.69985962, 23.85763931], [68.69985962, 23.85791969], [68.69930267, 23.85791588], [68.69930267, 23.85819435], [68.69875336, 23.85819435], [68.69875336, 23.85847282], [68.69819641, 23.85847282], [68.69819641, 23.85874939], [68.6965332, 23.85874939], [68.6965332, 23.85902977], [68.69596863, 23.85902977], [68.69596863, 23.85931015], [68.69541931, 23.85930634], [68.69541931, 23.8595829], [68.69486237, 23.8595829], [68.69486237, 23.85986137], [68.69431305, 23.85985947], [68.69431305, 23.86013985], [68.69374847, 23.86013985], [68.69374847, 23.86042023], [68.69347382, 23.86041641], [68.69347382, 23.86069489], [68.69291687, 23.86069489], [68.69291687, 23.86097145], [68.68902588, 23.86096954], [68.68902588, 23.86124992], [68.68736267, 23.86124992], [68.68736267, 23.8615303], [68.68374634, 23.8615303], [68.68374634, 23.86181068], [68.67791748, 23.86181068], [68.67791748, 23.8615303], [68.67679596, 23.8615303], [68.67679596, 23.86124992], [68.67485809, 23.86124992], [68.67485809, 23.8615303], [68.67180634, 23.8615303], [68.67180634, 23.86124992], [68.6709671, 23.86124992], [68.6709671, 23.86096954], [68.67041779, 23.86097145], [68.67041779, 23.86069489], [68.66958618, 23.86069489], [68.66958618, 23.86041641], [68.66902924, 23.86042023], [68.66902924, 23.86013985], [68.66874695, 23.86013985], [68.66874695, 23.85985947], [68.66819763, 23.85986137], [68.66819763, 23.8595829], [68.66791534, 23.8595829], [68.66791534, 23.85930634], [68.6673584, 23.85931015], [68.6673584, 23.85902977], [68.66707611, 23.85902977], [68.66707611, 23.85874939], [68.66680908, 23.85874939], [68.66680908, 23.85847282], [68.66625214, 23.85847282], [68.66625214, 23.85819435], [68.66569519, 23.85819435], [68.66569519, 23.85791588], [68.66513824, 23.85791969], [68.66513824, 23.85763931], [68.66430664, 23.85763931], [68.66430664, 23.85791969], [68.66236115, 23.85791588], [68.66236115, 23.85819435], [68.66152954, 23.85819435], [68.66152954, 23.85847282], [68.66014099, 23.85847282], [68.66014099, 23.85791588], [68.66042328, 23.85791969], [68.66042328, 23.85763931], [68.66069794, 23.85763931], [68.66069794, 23.85736084], [68.6609726, 23.85736084], [68.6609726, 23.85707855], [68.66124725, 23.85708237], [68.66124725, 23.8568058], [68.66152954, 23.8568058], [68.66152954, 23.85652733], [68.66236115, 23.85652733], [68.66236115, 23.8568058], [68.6626358, 23.8568058], [68.6626358, 23.85708237], [68.66374969, 23.85708237], [68.66374969, 23.8568058], [68.66402435, 23.8568058], [68.66402435, 23.85652733], [68.66430664, 23.85652733], [68.66430664, 23.8568058], [68.6654129, 23.8568058], [68.6654129, 23.85597229], [68.66513824, 23.85597229], [68.66513824, 23.85541725], [68.66485596, 23.85541916], [68.66485596, 23.85486031], [68.66513824, 23.85486031], [68.66513824, 23.85457993], [68.6654129, 23.85458374], [68.6654129, 23.85430527], [68.66570282, 23.85430908], [68.66570282, 23.85403061], [68.66596985, 23.85403061], [68.66596985, 23.85346985], [68.66625214, 23.85347176], [68.66625214, 23.85263634], [68.66596985, 23.85264015], [68.66596985, 23.85207939], [68.66569519, 23.85208321], [68.66569519, 23.85180664], [68.66486359, 23.85180664], [68.66486359, 23.85152626], [68.66430664, 23.85153008], [68.66430664, 23.85124969], [68.66401672, 23.85124969], [68.66401672, 23.85097122], [68.66347504, 23.85097313], [68.66347504, 23.85069656], [68.66291809, 23.85070038], [68.66291809, 23.85042], [68.66236877, 23.85042], [68.66236877, 23.85013962], [68.66208649, 23.85013962], [68.66208649, 23.84986115], [68.66152954, 23.84986115], [68.66152954, 23.84958076], [68.6609726, 23.84958267], [68.6609726, 23.8493042], [68.66069794, 23.84930992], [68.66069794, 23.84902954], [68.66014099, 23.84902954], [68.66014099, 23.84875107], [68.6598587, 23.84875107], [68.6598587, 23.84847069], [68.65930176, 23.8484726], [68.65930176, 23.84819221], [68.6590271, 23.84819221], [68.6590271, 23.84791756], [68.65847015, 23.84791946], [68.65847015, 23.84762955], [68.6581955, 23.84763908], [68.6581955, 23.84736061], [68.65763855, 23.84736061], [68.65763855, 23.84708023], [68.65736389, 23.84708214], [68.65736389, 23.84680557], [68.65680695, 23.84680939], [68.65680695, 23.84653282], [68.65624237, 23.84653282], [68.65624237, 23.84625053], [68.6554184, 23.84625053], [68.6554184, 23.84597015], [68.65374756, 23.84597015], [68.65374756, 23.84625053], [68.6526413, 23.84625053], [68.6526413, 23.84653282], [68.65180206, 23.84653282], [68.65180206, 23.84680939], [68.65041351, 23.84680557], [68.65041351, 23.84708214], [68.64985657, 23.84708023], [68.64985657, 23.84736061], [68.64958191, 23.84736061], [68.64958191, 23.84791946], [68.64819336, 23.84791946], [68.64819336, 23.84762955], [68.6479187, 23.84763908], [68.6479187, 23.84708214], [68.64819336, 23.84708214], [68.64819336, 23.8465271], [68.64848328, 23.84653282], [68.64848328, 23.84597015], [68.64875031, 23.84597015], [68.64875031, 23.84569359], [68.64902496, 23.84569359], [68.64902496, 23.84541702], [68.64930725, 23.84542274], [68.64930725, 23.84514046], [68.64958191, 23.84514046], [68.64958191, 23.84486008], [68.6498642, 23.84486008], [68.6498642, 23.84458351], [68.65013885, 23.84458351], [68.65013885, 23.84430504], [68.64985657, 23.84431267], [68.64985657, 23.84403038], [68.64958191, 23.84403038], [68.64958191, 23.84431267], [68.64902496, 23.84430504], [68.64902496, 23.84458351], [68.64847565, 23.84458351], [68.64847565, 23.84486008], [68.64819336, 23.84486008], [68.64819336, 23.84514046], [68.6479187, 23.84514046], [68.6479187, 23.84542274], [68.6470871, 23.84541702], [68.6470871, 23.84569359], [68.64653015, 23.84569359], [68.64653015, 23.84597015], [68.64624786, 23.84597015], [68.64624786, 23.84625053], [68.64485931, 23.84625053], [68.64485931, 23.84597015], [68.64458466, 23.84597015], [68.64458466, 23.84569359], [68.64485931, 23.84569359], [68.64485931, 23.84513855], [68.6451416, 23.84514046], [68.6451416, 23.84486008], [68.64624786, 23.84486008], [68.64624786, 23.84458351], [68.64653015, 23.84458351], [68.64653015, 23.84430504], [68.64736938, 23.84431267], [68.64736938, 23.84375191], [68.64763641, 23.84375191], [68.64763641, 23.84347153], [68.6479187, 23.84347153], [68.6479187, 23.84319496], [68.64848328, 23.84320259], [68.64848328, 23.8429184], [68.6479187, 23.8429184], [68.6479187, 23.84263992], [68.64736938, 23.84263992], [68.64736938, 23.84235954], [68.6470871, 23.84236145], [68.6470871, 23.84180641], [68.64679718, 23.84182167], [68.64679718, 23.83958054], [68.64653015, 23.83958244], [68.64653015, 23.83930779], [68.64624786, 23.83930969], [68.64624786, 23.83903122], [68.64597321, 23.83903122], [68.64597321, 23.83876038], [68.64569092, 23.83876038], [68.64569092, 23.83847046], [68.64541626, 23.83847237], [68.64541626, 23.8381958], [68.6451416, 23.8381958], [68.6451416, 23.83791542], [68.64430237, 23.83792114], [68.64430237, 23.83764076], [68.64347076, 23.83764076], [68.64347076, 23.83736038], [68.64263916, 23.83736038], [68.64263916, 23.83708], [68.64125061, 23.83708572], [68.64125061, 23.83680344], [68.64013672, 23.83681107], [68.64013672, 23.83653069], [68.63874817, 23.83653069], [68.63874817, 23.83625031], [68.63735962, 23.83625031], [68.63735962, 23.83596992], [68.63458252, 23.83597183], [68.63458252, 23.83569336], [68.63180542, 23.83569336], [68.63180542, 23.83541679], [68.62708282, 23.83541679], [68.62708282, 23.83569336], [68.62541962, 23.83569336], [68.62541962, 23.83597183], [68.62403107, 23.83596992], [68.62403107, 23.83625031], [68.62236023, 23.83625031], [68.62236023, 23.83653069], [68.62069702, 23.83653069], [68.62069702, 23.83681107], [68.61930847, 23.83680344], [68.61930847, 23.83708572], [68.61818695, 23.83708], [68.61818695, 23.83736038], [68.61680603, 23.83736038], [68.61680603, 23.83764076], [68.61514282, 23.83764076], [68.61514282, 23.83792114], [68.61486053, 23.83792114], [68.61486053, 23.83876038], [68.61458588, 23.83876038], [68.61458588, 23.83903122], [68.61429596, 23.83903122], [68.61429596, 23.83876038], [68.61402893, 23.83876038], [68.61402893, 23.83819008], [68.61374664, 23.8381958], [68.61374664, 23.83791542], [68.61347198, 23.83792114], [68.61347198, 23.83764076], [68.61235809, 23.83764076], [68.61235809, 23.83792114], [68.61208344, 23.83791542], [68.61208344, 23.8381958], [68.61180878, 23.8381958], [68.61180878, 23.83847237], [68.61096954, 23.83847237], [68.61096954, 23.8381958], [68.6048584, 23.8381958], [68.6048584, 23.83847237], [68.60430908, 23.83847046], [68.60430908, 23.83876038], [68.60375214, 23.83876038], [68.60375214, 23.83903122], [68.60320282, 23.83903122], [68.60320282, 23.83930969], [68.60263824, 23.83930779], [68.60263824, 23.83958244], [68.6020813, 23.83958244], [68.6020813, 23.83986092], [68.60235596, 23.83986092], [68.60235596, 23.84041977], [68.6020813, 23.84041786], [68.6020813, 23.8409729], [68.60180664, 23.84097099], [68.60180664, 23.84182167], [68.6020813, 23.84180641], [68.60208893, 23.84375191], [68.60180664, 23.84375191], [68.60180664, 23.84403038], [68.60152435, 23.84402847], [68.60152435, 23.84458351], [68.60124969, 23.84458351], [68.60124969, 23.84486008], [68.60098267, 23.84486008], [68.60098267, 23.84514046], [68.60069275, 23.84514046], [68.60069275, 23.84542274], [68.6001358, 23.84542274], [68.6001358, 23.84653282], [68.60041809, 23.8465271], [68.60041809, 23.84708214], [68.60180664, 23.84708023], [68.60180664, 23.84736061], [68.60236359, 23.84736061], [68.60236359, 23.84763908], [68.60263824, 23.84762955], [68.60263824, 23.84791946], [68.6029129, 23.84791756], [68.6029129, 23.84819221], [68.60319519, 23.84819221], [68.60319519, 23.8484726], [68.60346985, 23.84847069], [68.60346985, 23.84875107], [68.60375214, 23.84875107], [68.60375214, 23.84902954], [68.60402679, 23.84902954], [68.60402679, 23.84930992], [68.60430908, 23.8493042], [68.60430908, 23.84958267], [68.60457611, 23.84958076], [68.60457611, 23.84986115], [68.60430908, 23.84986115], [68.60430908, 23.85013962], [68.60375214, 23.85013962], [68.60375214, 23.84986115], [68.60346985, 23.84986115], [68.60346985, 23.84958076], [68.60319519, 23.84958267], [68.60319519, 23.84902763], [68.60263824, 23.84902954], [68.60263824, 23.84875107], [68.60235596, 23.84875107], [68.60235596, 23.84847069], [68.6020813, 23.8484726], [68.6020813, 23.84819221], [68.60180664, 23.84819221], [68.60180664, 23.84791756], [68.59986115, 23.84791946], [68.59986115, 23.84762955], [68.59902954, 23.84763908], [68.59902954, 23.84736061], [68.59874725, 23.84736061], [68.59874725, 23.84569168], [68.59902954, 23.84569359], [68.59902954, 23.84513855], [68.59929657, 23.84514046], [68.59929657, 23.84486008], [68.59958649, 23.84486008], [68.59958649, 23.84458351], [68.60041809, 23.84458351], [68.60041809, 23.84430504], [68.60069275, 23.84431267], [68.60069275, 23.84403038], [68.60098267, 23.84403038], [68.60098267, 23.84263992], [68.60069275, 23.84263992], [68.60069275, 23.84124947], [68.60041809, 23.84124947], [68.60041809, 23.84041977], [68.6001358, 23.84041977], [68.6001358, 23.83958054], [68.59708405, 23.83958244], [68.59708405, 23.83930779], [68.59597015, 23.83930969], [68.59597015, 23.83903122], [68.59485626, 23.83903122], [68.59485626, 23.83876038], [68.59375, 23.83876038], [68.59375, 23.83847046], [68.59263611, 23.83847237], [68.59263611, 23.8381958], [68.5918045, 23.8381958], [68.5918045, 23.83791542], [68.59041595, 23.83792114], [68.59041595, 23.83764076], [68.59014893, 23.83764076], [68.59014893, 23.83736038], [68.58985901, 23.83736038], [68.58985901, 23.83708], [68.58930206, 23.83708572], [68.58930206, 23.83680344], [68.58875275, 23.83681107], [68.58875275, 23.83653069], [68.5881958, 23.83653069], [68.5881958, 23.83625031], [68.58790588, 23.83625031], [68.58790588, 23.83596992], [68.58763885, 23.83597183], [68.58763885, 23.83541679], [68.58735657, 23.83542061], [68.58735657, 23.83514023], [68.58680725, 23.83514023], [68.58680725, 23.83457947], [68.58652496, 23.83458328], [68.58652496, 23.83430481], [68.58625031, 23.83430481], [68.58625031, 23.83402824], [68.58598328, 23.83403015], [68.58598328, 23.83374977], [68.5854187, 23.83374977], [68.5854187, 23.83346939], [68.58513641, 23.8334713], [68.58513641, 23.83319473], [68.58486176, 23.83319473], [68.58486176, 23.83263969], [68.5845871, 23.83263969], [68.5845871, 23.83236122], [68.58429718, 23.83236122], [68.58429718, 23.83208275], [68.58403015, 23.83208275], [68.58403015, 23.83180618], [68.58374786, 23.8318119], [68.58374786, 23.83152962], [68.58347321, 23.83152962], [68.58347321, 23.83097076], [68.58319092, 23.83097267], [68.58319092, 23.8306942], [68.58291626, 23.8306942], [68.58291626, 23.83041763], [68.5826416, 23.83041954], [68.5826416, 23.83013916], [68.58235931, 23.83013916], [68.58235931, 23.82986069], [68.58207703, 23.82986069], [68.58207703, 23.82957077], [68.58180237, 23.82958412], [68.58180237, 23.82930565], [68.58152771, 23.82930946], [68.58152771, 23.82902908], [68.58125305, 23.82902908], [68.58125305, 23.82875061], [68.58096313, 23.82875061], [68.58096313, 23.82846832], [68.58069611, 23.82847214], [68.58069611, 23.82819366], [68.58041382, 23.82819366], [68.58041382, 23.82763863], [68.58013916, 23.82764053], [68.58013916, 23.82707977], [68.5798645, 23.82708359], [68.5798645, 23.82652855], [68.57958221, 23.82653046], [68.57958221, 23.8259697], [68.57875061, 23.8259716], [68.57875061, 23.82569695], [68.57847595, 23.82570076], [68.57847595, 23.82542038], [68.57791901, 23.82542038], [68.57791901, 23.82514], [68.57763672, 23.82514], [68.57763672, 23.82485962], [68.57736206, 23.82486153], [68.57736206, 23.82430458], [68.57707977, 23.8243103], [68.57707977, 23.82402992], [68.57681274, 23.82402992], [68.57681274, 23.82374954], [68.57653046, 23.82374954], [68.57653046, 23.82347107], [68.57624817, 23.82347488], [68.57624817, 23.82291412], [68.57596588, 23.82291985], [68.57596588, 23.82263947], [68.57569122, 23.82263947], [68.57569122, 23.82236099], [68.57541656, 23.82236099], [68.57541656, 23.82180977], [68.57514954, 23.82180977], [68.57514954, 23.82152939], [68.57485962, 23.82152939], [68.57485962, 23.82125092], [68.57458496, 23.82125092], [68.57458496, 23.82069206], [68.57430267, 23.82069206], [68.57430267, 23.82013893], [68.57402802, 23.82014275], [68.57402802, 23.81958008], [68.57375336, 23.81958389], [68.57375336, 23.81902695], [68.57347107, 23.81903267], [68.57347107, 23.81847191], [68.57319641, 23.81847191], [68.57319641, 23.81791687], [68.57290649, 23.81792259], [68.57290649, 23.81736183], [68.57263947, 23.81736183], [68.57263947, 23.81680489], [68.57236481, 23.81680489], [68.57236481, 23.81624985], [68.57208252, 23.81624985], [68.57208252, 23.81568909], [68.57180786, 23.81569481], [68.57180786, 23.81541634], [68.5715332, 23.81541824], [68.5715332, 23.81485748], [68.57125092, 23.8148613], [68.57125092, 23.81458282], [68.57096863, 23.81459045], [68.57096863, 23.81402969], [68.57068634, 23.81402969], [68.57068634, 23.81319046], [68.57041931, 23.81319427], [68.57041931, 23.8120842], [68.57013702, 23.8120842], [68.57013702, 23.81097221], [68.56986237, 23.81097221], [68.56986237, 23.81041527], [68.56958008, 23.81042099], [68.56958008, 23.80957985], [68.56930542, 23.80958557], [68.56930542, 23.80902863], [68.56902313, 23.80903053], [68.56902313, 23.80820084], [68.56874847, 23.80820084], [68.56874847, 23.80764008], [68.56846619, 23.80764008], [68.56846619, 23.80708122], [68.56819153, 23.80708122], [68.56819153, 23.80652809], [68.56791687, 23.80653191], [68.56791687, 23.80569267], [68.56764221, 23.80569458], [68.56764221, 23.80486107], [68.56735992, 23.80486107], [68.56735992, 23.80431175], [68.5670929, 23.80431175], [68.5670929, 23.80347061], [68.56680298, 23.80347252], [68.56680298, 23.80291748], [68.56652832, 23.80291939], [68.56652832, 23.80236053], [68.56624603, 23.80236053], [68.56624603, 23.80153084], [68.56595612, 23.80153084], [68.56595612, 23.80096817], [68.56569672, 23.80097198], [68.56569672, 23.80013847], [68.5654068, 23.80014038], [68.5654068, 23.79959106], [68.56513977, 23.79959106], [68.56513977, 23.7990303], [68.56485748, 23.7990303], [68.56485748, 23.79846954], [68.56458282, 23.79847145], [68.56458282, 23.79791451], [68.56430817, 23.79792023], [68.56430817, 23.79763985], [68.56402588, 23.79763985], [68.56402588, 23.79735947], [68.56375122, 23.79736137], [68.56375122, 23.79680443], [68.56346893, 23.79681015], [68.56346893, 23.79652023], [68.56319427, 23.79652786], [68.56319427, 23.79624939], [68.56291962, 23.79624939], [68.56291962, 23.79569054], [68.56263733, 23.79569244], [68.56263733, 23.79541588], [68.56236267, 23.79541969], [68.56236267, 23.79514122], [68.56208038, 23.79514122], [68.56208038, 23.79458046], [68.56180573, 23.79458237], [68.56180573, 23.7943058], [68.56153107, 23.79430962], [68.56153107, 23.79403114], [68.56124878, 23.79403114], [68.56124878, 23.79375076], [68.56096649, 23.79375076], [68.56096649, 23.79319191], [68.56069183, 23.79319382], [68.56069183, 23.79291725], [68.56041718, 23.79292107], [68.56041718, 23.79264069], [68.56014252, 23.79264069], [68.56014252, 23.79236031], [68.55986023, 23.79236031], [68.55986023, 23.79208183], [68.55930328, 23.79208374], [68.55930328, 23.79180527], [68.55902863, 23.7918129], [68.55902863, 23.79153252], [68.55874634, 23.79153252], [68.55874634, 23.79125023], [68.55847168, 23.79125023], [68.55847168, 23.79071045], [68.55819702, 23.79071045], [68.55819702, 23.79042244], [68.5579071, 23.79042244], [68.5579071, 23.79014015], [68.55764008, 23.79014015], [68.55764008, 23.78957748], [68.55735779, 23.78958321], [68.55735779, 23.78930473], [68.55708313, 23.78930473], [68.55708313, 23.78902817], [68.55680847, 23.78902817], [68.55680847, 23.78847122], [68.55652618, 23.78847313], [68.55652618, 23.78819466], [68.55625153, 23.78819466], [68.55625153, 23.78791618], [68.55596924, 23.78791809], [68.55596924, 23.78736115], [68.55568695, 23.78736115], [68.55568695, 23.78680992], [68.55541992, 23.78680992], [68.55541992, 23.78625107], [68.55513763, 23.78625107], [68.55513763, 23.78569031], [68.55486298, 23.78569412], [68.55486298, 23.78513908], [68.55458069, 23.78514099], [68.55458069, 23.78486061], [68.55430603, 23.78486061], [68.55430603, 23.78430939], [68.55401611, 23.78430939], [68.55401611, 23.78403091], [68.55374908, 23.78403091], [68.55374908, 23.78375053], [68.55319214, 23.78375053], [68.55319214, 23.78347015], [68.55291748, 23.78347206], [68.55291748, 23.78291512], [68.55264282, 23.78292084], [68.55264282, 23.78264046], [68.55291748, 23.78264046], [68.55291748, 23.78236008], [68.55263519, 23.78236389], [68.55263519, 23.78180313], [68.55236053, 23.78181076], [68.55236053, 23.78125], [68.55208588, 23.78125], [68.55208588, 23.78070068], [68.55179596, 23.78070068], [68.55179596, 23.7804203], [68.55152893, 23.7804203], [68.55152893, 23.78013992], [68.55124664, 23.78013992], [68.55124664, 23.77985954], [68.55097198, 23.77986145], [68.55097198, 23.77958107], [68.55069733, 23.77958107], [68.55069733, 23.77930641], [68.55042267, 23.77931023], [68.55042267, 23.77902985], [68.55014038, 23.77902985], [68.55014038, 23.77874947], [68.54985809, 23.77874947], [68.54985809, 23.77848053], [68.54957581, 23.77848053], [68.54957581, 23.77819252], [68.54930878, 23.77819443], [68.54930878, 23.77791595], [68.54902649, 23.77792168], [68.54902649, 23.77763939], [68.54875183, 23.77763939], [68.54875183, 23.77736092], [68.54846954, 23.77736092], [68.54846954, 23.77708054], [68.54819489, 23.77708244], [68.54819489, 23.77680588], [68.54792023, 23.7768116], [68.54792023, 23.77625084], [68.54763794, 23.77625084], [68.54763794, 23.77597046], [68.54736328, 23.77597237], [68.54736328, 23.77541733], [68.54708099, 23.77541924], [68.54708099, 23.77486038], [68.54680634, 23.77486038], [68.54680634, 23.77457809], [68.54652405, 23.77458382], [68.54652405, 23.77402878], [68.54624939, 23.77403069], [68.54624939, 23.77375031], [68.5459671, 23.77375031], [68.5459671, 23.77319908], [68.54569244, 23.77319908], [68.54569244, 23.77264023], [68.54541779, 23.77264023], [68.54541779, 23.77207947], [68.5451355, 23.77208328], [68.5451355, 23.77152824], [68.54485321, 23.77153015], [68.54485321, 23.77096939], [68.54458618, 23.7709713], [68.54458618, 23.77069664], [68.54430389, 23.77069664], [68.54430389, 23.77041435], [68.54402924, 23.77042007], [68.54402924, 23.77013969], [68.54374695, 23.77013969], [68.54374695, 23.76986122], [68.54319763, 23.76986122], [68.54319763, 23.76902962], [68.54292297, 23.76902962], [68.54292297, 23.76847076], [68.54264069, 23.76847267], [68.54264069, 23.76819229], [68.5423584, 23.76819229], [68.5423584, 23.76763916], [68.54207611, 23.76764107], [68.54207611, 23.76736069], [68.54180908, 23.76736069], [68.54180908, 23.76708031], [68.54152679, 23.76708221], [68.54152679, 23.76652718], [68.54125214, 23.76654053], [68.54125214, 23.76625061], [68.54096985, 23.76625061], [68.54096985, 23.76597023], [68.54069519, 23.76597023], [68.54069519, 23.7654171], [68.5404129, 23.76542282], [68.5404129, 23.76486015], [68.54013824, 23.76486015], [68.54013824, 23.76430511], [68.53985596, 23.76431274], [68.53985596, 23.76403046], [68.5395813, 23.76403046], [68.5395813, 23.76348114], [68.53930664, 23.76348114], [68.53930664, 23.76291847], [68.53901672, 23.76291847], [68.53901672, 23.76263809], [68.53874969, 23.76263809], [68.53874969, 23.76208115], [68.53847504, 23.76208305], [68.53847504, 23.76180649], [68.53819275, 23.7618084], [68.53819275, 23.76152992], [68.53791809, 23.76152992], [68.53791809, 23.76097107], [68.5376358, 23.76097298], [68.5376358, 23.76041794], [68.53736115, 23.76041794], [68.53736115, 23.76013947], [68.53708649, 23.76013947], [68.53708649, 23.75986099], [68.53679657, 23.75986099], [68.53679657, 23.75958061], [68.53652954, 23.75958252], [68.53652954, 23.75902557], [68.53624725, 23.75902939], [68.53624725, 23.75875092], [68.5359726, 23.75875092], [68.5359726, 23.75847244], [68.53569794, 23.75847244], [68.53569794, 23.7579174], [68.53542328, 23.75792122], [68.53542328, 23.75764084], [68.53514099, 23.75764084], [68.53514099, 23.75708008], [68.5348587, 23.7570858], [68.5348587, 23.75680351], [68.53457642, 23.75681114], [68.53457642, 23.75653076], [68.5340271, 23.75653076], [68.5340271, 23.75625038], [68.53347015, 23.75625038], [68.53347015, 23.75597], [68.5320816, 23.75597], [68.5320816, 23.75625038], [68.53069305, 23.75625038], [68.53069305, 23.75597], [68.5304184, 23.75597191], [68.5304184, 23.75569344], [68.52984619, 23.75570107], [68.52984619, 23.75542068], [68.52902985, 23.75542068], [68.52902985, 23.75570107], [68.52874756, 23.75569344], [68.52874756, 23.75597191], [68.5284729, 23.75597], [68.5284729, 23.75625038], [68.52791595, 23.75625038], [68.52791595, 23.75653076], [68.5276413, 23.75653076], [68.5276413, 23.75681114], [68.52708435, 23.75680351], [68.52708435, 23.7570858], [68.52680206, 23.7570858], [68.52680206, 23.75736046], [68.52625275, 23.75735092], [68.52625275, 23.75792122], [68.52597046, 23.7579174], [68.52597046, 23.75819588], [68.5256958, 23.75819016], [68.5256958, 23.75875092], [68.52540588, 23.75875092], [68.52540588, 23.75902939], [68.52513885, 23.75902557], [68.52513885, 23.7606945], [68.52540588, 23.76069069], [68.52540588, 23.76124954], [68.5256958, 23.76124954], [68.5256958, 23.76263809], [68.52597046, 23.76263809], [68.52597046, 23.76375008], [68.52625275, 23.76375008], [68.52625275, 23.76625061], [68.5265274, 23.76625061], [68.5265274, 23.76680946], [68.52680969, 23.76680946], [68.52680969, 23.76875114], [68.5265274, 23.76874924], [68.5265274, 23.76958275], [68.52680206, 23.76958275], [68.52680969, 23.77124977], [68.5265274, 23.77124977], [68.5265274, 23.77264023], [68.52625275, 23.77263641], [68.52625275, 23.77347183], [68.52597046, 23.77346992], [68.52597046, 23.77375031], [68.5256958, 23.77375031], [68.5256958, 23.77430916], [68.52540588, 23.77430916], [68.52540588, 23.77514076], [68.52513885, 23.77514076], [68.52513885, 23.77569389], [68.5248642, 23.77569389], [68.5248642, 23.77597237], [68.52458191, 23.77597046], [68.52458191, 23.77625084], [68.52430725, 23.77625084], [68.52430725, 23.7768116], [68.52402496, 23.77680588], [68.52402496, 23.77708244], [68.52347565, 23.77708244], [68.52348328, 23.77736092], [68.5229187, 23.77736092], [68.5229187, 23.77763939], [68.52236176, 23.77763939], [68.52236176, 23.77819443], [68.5220871, 23.77819252], [68.5220871, 23.77848053], [68.52153015, 23.77848053], [68.52153015, 23.77874947], [68.52097321, 23.77874947], [68.52097321, 23.77902985], [68.5201416, 23.77902985], [68.5201416, 23.77931023], [68.51902771, 23.77930641], [68.51902771, 23.77958107], [68.51875305, 23.77958107], [68.51875305, 23.77986145], [68.51847076, 23.77985954], [68.51847076, 23.78013992], [68.51819611, 23.78013992], [68.51819611, 23.7804203], [68.51790619, 23.7804203], [68.51790619, 23.78070068], [68.51735687, 23.78070068], [68.51735687, 23.78181076], [68.51708221, 23.78180313], [68.51708221, 23.78208351], [68.51680756, 23.7820797], [68.51680756, 23.78264046], [68.51652527, 23.78263855], [68.51652527, 23.78319359], [68.51625061, 23.78318977], [68.51625061, 23.78403091], [68.51652527, 23.78402519], [68.51652527, 23.78458595], [68.51625061, 23.78458023], [68.51625061, 23.78486061], [68.51541901, 23.78486061], [68.51541901, 23.78541946], [68.51569366, 23.78541756], [68.51569366, 23.7859726], [68.51597595, 23.78597069], [68.51597595, 23.78652954], [68.51625061, 23.78652763], [68.51625061, 23.78847313], [68.5165329, 23.78847122], [68.5165329, 23.79042244], [68.51680756, 23.79042244], [68.51680756, 23.79071045], [68.51708221, 23.79069519], [68.51708221, 23.79097176], [68.51790619, 23.79097176], [68.51790619, 23.79125023], [68.51763916, 23.79125023], [68.51763916, 23.79236031], [68.51735687, 23.79236031], [68.51735687, 23.79375076], [68.51763916, 23.79375076], [68.51763916, 23.79486084], [68.51790619, 23.79486084], [68.51790619, 23.79541969], [68.51819611, 23.79541588], [68.51819611, 23.79569244], [68.51875305, 23.79569244], [68.51875305, 23.79597473], [68.51902771, 23.79597092], [68.51902771, 23.79624939], [68.51930237, 23.79624939], [68.51930237, 23.79652786], [68.51985931, 23.79652023], [68.51985931, 23.79681015], [68.5201416, 23.79680443], [68.5201416, 23.79736137], [68.52068329, 23.79735947], [68.52068329, 23.79763985], [68.52153015, 23.79763985], [68.52153015, 23.79792023], [68.5220871, 23.79791451], [68.5220871, 23.79819679], [68.52263641, 23.79819679], [68.52263641, 23.79847145], [68.5229187, 23.79846954], [68.5229187, 23.79874992], [68.52348328, 23.79874992], [68.52348328, 23.7990303], [68.52404022, 23.7990303], [68.52404022, 23.79931068], [68.52430725, 23.79931068], [68.52430725, 23.79959106], [68.5248642, 23.79958344], [68.5248642, 23.79986191], [68.52513885, 23.79985809], [68.52513885, 23.80014038], [68.52540588, 23.80014038], [68.52540588, 23.80042076], [68.52791595, 23.80042076], [68.52791595, 23.80014038], [68.53098297, 23.80014038], [68.53098297, 23.80042076], [68.53125, 23.80041885], [68.53125, 23.80097198], [68.53151703, 23.80096817], [68.53151703, 23.80153084], [68.53180695, 23.80153084], [68.53180695, 23.80180931], [68.5320816, 23.80180931], [68.5320816, 23.80236053], [68.53235626, 23.80236053], [68.53235626, 23.80291939], [68.53263855, 23.80291748], [68.53263855, 23.80319405], [68.53291321, 23.80318832], [68.53291321, 23.80374908], [68.53320312, 23.80374908], [68.53320312, 23.80402946], [68.53347015, 23.80402946], [68.53347015, 23.80431175], [68.53375244, 23.80431175], [68.53375244, 23.80486107], [68.5340271, 23.80486107], [68.5340271, 23.80569458], [68.53430176, 23.80569458], [68.53430939, 23.80597115], [68.5348587, 23.80597115], [68.5348587, 23.80624962], [68.53514099, 23.80624962], [68.53514099, 23.80792046], [68.5348587, 23.80792046], [68.5348587, 23.80903053], [68.53458405, 23.80902863], [68.53458405, 23.80958557], [68.53430939, 23.80957985], [68.53430939, 23.81125069], [68.53457642, 23.81125069], [68.53457642, 23.81153107], [68.5348587, 23.81153107], [68.5348587, 23.81180954], [68.53514099, 23.81180954], [68.53514099, 23.81236076], [68.53542328, 23.81236076], [68.53542328, 23.81264114], [68.53569794, 23.81263924], [68.53569794, 23.81319427], [68.53624725, 23.81319427], [68.53624725, 23.81347275], [68.53652954, 23.81347084], [68.53652954, 23.81402969], [68.53679657, 23.81402969], [68.53679657, 23.81459045], [68.53708649, 23.81458282], [68.53708649, 23.8148613], [68.53736115, 23.81485748], [68.53736115, 23.81513977], [68.53708649, 23.81513977], [68.53708649, 23.81541824], [68.53652954, 23.81541824], [68.53652954, 23.81513977], [68.53624725, 23.81513977], [68.53624725, 23.81459045], [68.53598022, 23.81459045], [68.53598022, 23.81402969], [68.53542328, 23.81402969], [68.53542328, 23.81375122], [68.53514099, 23.81375122], [68.53514099, 23.81319046], [68.5348587, 23.81319427], [68.5348587, 23.81263924], [68.53457642, 23.81264114], [68.53457642, 23.81236076], [68.53430176, 23.81236076], [68.53430176, 23.81180954], [68.53375244, 23.81180954], [68.53375244, 23.81153107], [68.53347015, 23.81153107], [68.53347015, 23.80957985], [68.53375244, 23.80958557], [68.53375244, 23.80902863], [68.5340271, 23.80903053], [68.5340271, 23.80792046], [68.53430176, 23.80792046], [68.53430176, 23.8073597], [68.5340271, 23.8073616], [68.5340271, 23.80708122], [68.53375244, 23.80708122], [68.53375244, 23.80652809], [68.53347015, 23.80653191], [68.53347015, 23.80624962], [68.5331955, 23.80624962], [68.5331955, 23.80597115], [68.53291321, 23.80597115], [68.53291321, 23.80513954], [68.53263855, 23.80513954], [68.53263855, 23.80458069], [68.53236389, 23.8045826], [68.53236389, 23.80430603], [68.5320816, 23.80431175], [68.5320816, 23.80374908], [68.53180695, 23.80374908], [68.53180695, 23.80347061], [68.53152466, 23.80347252], [68.53152466, 23.80291748], [68.53125, 23.80291939], [68.53125, 23.80265045], [68.53098297, 23.80265045], [68.53098297, 23.80207825], [68.53069305, 23.80208397], [68.53069305, 23.8018055], [68.5304184, 23.80180931], [68.5304184, 23.80153084], [68.53013611, 23.80153084], [68.53013611, 23.80125046], [68.52902985, 23.80125046], [68.52902985, 23.80153084], [68.52819824, 23.80153084], [68.52819824, 23.80180931], [68.52708435, 23.8018055], [68.52708435, 23.80208397], [68.52597046, 23.80207825], [68.52597046, 23.80236053], [68.5256958, 23.80236053], [68.5256958, 23.80265045], [68.52540588, 23.80265045], [68.52540588, 23.80374908], [68.52513885, 23.80374908], [68.52513885, 23.80513954], [68.5248642, 23.80513954], [68.5248642, 23.80569458], [68.52458191, 23.80569458], [68.52458191, 23.80597115], [68.52430725, 23.80597115], [68.52430725, 23.80624962], [68.52402496, 23.80624962], [68.52402496, 23.80680466], [68.52375031, 23.80680466], [68.52375031, 23.8073616], [68.52348328, 23.8073597], [68.52348328, 23.80764008], [68.52319336, 23.80764008], [68.52319336, 23.80792046], [68.5229187, 23.80791664], [68.5229187, 23.80847168], [68.52263641, 23.80846024], [68.52263641, 23.80875015], [68.52236176, 23.80875015], [68.52236176, 23.80931091], [68.5220871, 23.80931091], [68.5220871, 23.81014061], [68.52180481, 23.8101387], [68.52180481, 23.81097221], [68.52153015, 23.81097031], [68.52153015, 23.81153107], [68.52179718, 23.81153107], [68.52179718, 23.81236076], [68.5220871, 23.81236076], [68.5220871, 23.81291962], [68.52236176, 23.81291962], [68.52236176, 23.81375122], [68.52263641, 23.81375122], [68.52263641, 23.81459045], [68.5229187, 23.81458282], [68.5229187, 23.81597137], [68.52319336, 23.81596756], [68.52319336, 23.81624985], [68.5229187, 23.81624985], [68.5229187, 23.81708336], [68.52263641, 23.81708145], [68.52263641, 23.81764984], [68.52236176, 23.81764984], [68.52236176, 23.81792259], [68.52179718, 23.81792259], [68.52179718, 23.81820107], [68.52153015, 23.81819534], [68.52153015, 23.81847191], [68.52124786, 23.81847191], [68.52124786, 23.81875038], [68.52097321, 23.81875038], [68.52097321, 23.81903267], [68.52068329, 23.81903267], [68.52068329, 23.81931114], [68.5201416, 23.81930542], [68.5201416, 23.81958389], [68.51957703, 23.81958008], [68.51957703, 23.81986046], [68.51902771, 23.81986046], [68.51902771, 23.82014275], [68.51875305, 23.82014275], [68.51875305, 23.82042122], [68.51819611, 23.8204174], [68.51819611, 23.82069206], [68.51790619, 23.82069016], [68.51790619, 23.82125092], [68.51708221, 23.82125092], [68.51708221, 23.82152939], [68.51625061, 23.82152939], [68.51625061, 23.82180977], [68.51569366, 23.82180405], [68.51569366, 23.82208252], [68.51541901, 23.82208061], [68.51541901, 23.82236099], [68.51486206, 23.82236099], [68.51486206, 23.82263947], [68.51541901, 23.82263947], [68.51541901, 23.82291985], [68.51513672, 23.82291412], [68.51513672, 23.82347488], [68.51486969, 23.82347107], [68.51486969, 23.82402992], [68.51513672, 23.82402611], [68.51513672, 23.82486153], [68.51597595, 23.82485962], [68.51597595, 23.82514], [68.5165329, 23.82514], [68.5165329, 23.82542038], [68.51735687, 23.82542038], [68.51735687, 23.82570076], [68.51791382, 23.82569695], [68.51791382, 23.8259716], [68.51847076, 23.8259697], [68.51847076, 23.82625008], [68.51930237, 23.82625008], [68.51930237, 23.82653046], [68.52236176, 23.82653046], [68.52236176, 23.82681847], [68.52319336, 23.82680511], [68.52319336, 23.82708359], [68.52402496, 23.82708359], [68.52402496, 23.82736015], [68.52680969, 23.82736015], [68.52680969, 23.82764053], [68.53125, 23.82764053], [68.53125, 23.82792091], [68.53430176, 23.8279171], [68.53430939, 23.82819366], [68.5348587, 23.82819366], [68.5348587, 23.82847214], [68.53569794, 23.82846832], [68.53569794, 23.82875061], [68.53624725, 23.82875061], [68.53624725, 23.82902908], [68.53679657, 23.82902908], [68.53679657, 23.82930946], [68.53736115, 23.82930565], [68.53736115, 23.82958412], [68.5376358, 23.82957077], [68.5376358, 23.82986069], [68.53791809, 23.82986069], [68.53791809, 23.83041954], [68.53819275, 23.83041573], [68.53819275, 23.83097267], [68.53848267, 23.83097076], [68.53848267, 23.83124924], [68.53930664, 23.83124924], [68.53930664, 23.83152962], [68.53985596, 23.83152962], [68.53985596, 23.8318119], [68.54013824, 23.83180618], [68.54013824, 23.83208275], [68.54069519, 23.83208275], [68.54069519, 23.83236122], [68.54096985, 23.83236122], [68.54096985, 23.83263969], [68.54152679, 23.83263016], [68.54152679, 23.83292007], [68.54208374, 23.83291626], [68.54208374, 23.83319473], [68.54264069, 23.83319473], [68.54264069, 23.8334713], [68.54291534, 23.8334713], [68.54291534, 23.83374977], [68.54319763, 23.83374977], [68.54319763, 23.83403015], [68.54458618, 23.83402824], [68.54458618, 23.83430481], [68.54486084, 23.83430481], [68.54486084, 23.83458328], [68.5451355, 23.83458328], [68.5451355, 23.83486176], [68.54541779, 23.83485985], [68.54541779, 23.83514023], [68.54569244, 23.83514023], [68.54569244, 23.83542061], [68.54597473, 23.83541679], [68.54597473, 23.83569336], [68.54652405, 23.83569336], [68.54652405, 23.83597183], [68.54680634, 23.83596992], [68.54680634, 23.83625031], [68.54708099, 23.83625031], [68.54708099, 23.83653069], [68.54736328, 23.83653069], [68.54736328, 23.83681107], [68.54763794, 23.83680344], [68.54763794, 23.83708572], [68.54792023, 23.83708], [68.54792023, 23.83736038], [68.54818726, 23.83736038], [68.54818726, 23.83764076], [68.54846954, 23.83764076], [68.54846954, 23.83792114], [68.54875183, 23.83791542], [68.54875183, 23.8381958], [68.54902649, 23.8381958], [68.54902649, 23.83847237], [68.54930878, 23.83847046], [68.54930878, 23.83876038], [68.54957581, 23.83876038], [68.54957581, 23.83903122], [68.54985809, 23.83903122], [68.54985809, 23.83930969], [68.55014038, 23.83930969], [68.55014038, 23.83986092], [68.55041504, 23.83986092], [68.55041504, 23.84013939], [68.55069733, 23.84013939], [68.55069733, 23.84069443], [68.55097198, 23.84069443], [68.55097198, 23.84124947], [68.55124664, 23.84124947], [68.55124664, 23.84236145], [68.55152893, 23.84235954], [68.55152893, 23.84320259], [68.55179596, 23.84320259], [68.55179596, 23.84403038], [68.55208588, 23.84402847], [68.55208588, 23.84458351], [68.55236053, 23.84456825], [68.55236053, 23.84514046], [68.55263519, 23.84513855], [68.55263519, 23.84569359], [68.55291748, 23.84569168], [68.55291748, 23.84625053], [68.55319214, 23.84625053], [68.55319214, 23.84680939], [68.5534668, 23.84680939], [68.5534668, 23.84736061], [68.55374908, 23.84736061], [68.55374908, 23.8484726], [68.55401611, 23.84847069], [68.55401611, 23.84930992], [68.55430603, 23.84930992], [68.55430603, 23.85013962], [68.55458069, 23.85013962], [68.55458069, 23.85070038], [68.55486298, 23.85070038], [68.55486298, 23.85124969], [68.55513763, 23.85124969], [68.55513763, 23.85180664], [68.55541992, 23.85180092], [68.55541992, 23.85264015], [68.55568695, 23.85264015], [68.55568695, 23.85320091], [68.55596924, 23.85320091], [68.55596924, 23.85403061], [68.55625153, 23.8540287], [68.55625153, 23.85458374], [68.55652618, 23.85457993], [68.55652618, 23.85486031], [68.55680847, 23.85486031], [68.55680847, 23.85541916], [68.55708313, 23.85541725], [68.55708313, 23.85569382], [68.55735779, 23.8556881], [68.55735779, 23.85625076], [68.55764008, 23.85625076], [68.55764008, 23.85652924], [68.55791473, 23.85652733], [68.55791473, 23.8568058], [68.55819702, 23.8568058], [68.55819702, 23.85708237], [68.55847168, 23.85707855], [68.55847168, 23.85736084], [68.55902863, 23.85736084], [68.55902863, 23.85763931], [68.55930328, 23.85763931], [68.55930328, 23.85791969], [68.55958557, 23.85791588], [68.55958557, 23.85819435], [68.56041718, 23.85819435], [68.56041718, 23.85847282], [68.56096649, 23.85847282], [68.56096649, 23.85874939], [68.56124878, 23.85874939], [68.56124878, 23.85902977], [68.56181335, 23.85902977], [68.56181335, 23.85931015], [68.56208038, 23.85930634], [68.56208038, 23.8595829], [68.56236267, 23.8595829], [68.56236267, 23.85986137], [68.56263733, 23.85985947], [68.56263733, 23.86013985], [68.56291962, 23.86013985], [68.56291962, 23.86042023], [68.56319427, 23.86041641], [68.56319427, 23.86069489], [68.56346893, 23.86069489], [68.56346893, 23.86097145], [68.56375122, 23.86096954], [68.56375122, 23.86124992], [68.56402588, 23.86124992], [68.56402588, 23.8615303], [68.56430817, 23.8615303], [68.56430817, 23.86181068], [68.56458282, 23.86180305], [68.56458282, 23.86208344], [68.56485748, 23.86208344], [68.56485748, 23.86236191], [68.56513977, 23.86236], [68.56513977, 23.86264038], [68.5654068, 23.86264038], [68.5654068, 23.8629303], [68.56569672, 23.86291695], [68.56569672, 23.86319351], [68.56595612, 23.8631897], [68.56595612, 23.86375046], [68.56625366, 23.86375046], [68.56625366, 23.86458588], [68.56652832, 23.86458015], [68.56652832, 23.86514091], [68.56680298, 23.86514091], [68.56680298, 23.86625099], [68.56708527, 23.86624718], [68.56708527, 23.86763954], [68.56735992, 23.86763954], [68.56735992, 23.86819458], [68.56764221, 23.86819458], [68.56764221, 23.86958313], [68.56791687, 23.86958313], [68.56791687, 23.87097168], [68.56819153, 23.87097168], [68.56819153, 23.87208366], [68.56847382, 23.87208366], [68.56847382, 23.87319374], [68.56874847, 23.87319183], [68.56874847, 23.87403107], [68.56903076, 23.87402725], [68.56903076, 23.87458229], [68.56931305, 23.87458038], [68.56931305, 23.87514114], [68.56958008, 23.87513924], [68.56958008, 23.87597275], [68.56986237, 23.87597084], [68.56986237, 23.87652969], [68.57013702, 23.87652779], [68.57013702, 23.87708282], [68.57041931, 23.87708092], [68.57041931, 23.87763977], [68.57069397, 23.87763977], [68.57069397, 23.87819672], [68.57096863, 23.87819099], [68.57096863, 23.87874985], [68.57125092, 23.87874985], [68.57125092, 23.87930679], [68.57152557, 23.87930679], [68.57152557, 23.87986183], [68.57180786, 23.87985992], [68.57180786, 23.8801403], [68.57235718, 23.8801403], [68.57235718, 23.88042068], [68.57263947, 23.88042068], [68.57263947, 23.88069916], [68.57291412, 23.88069534], [68.57291412, 23.88097191], [68.57347107, 23.88096809], [68.57347107, 23.88125038], [68.57430267, 23.88125038], [68.57430267, 23.88153076], [68.57459259, 23.88153076], [68.57459259, 23.88180923], [68.57514191, 23.88180542], [68.57514191, 23.88208389], [68.57569122, 23.88207817], [68.57569122, 23.88236046], [68.57681274, 23.88236046], [68.57681274, 23.88264084], [68.57736206, 23.88264084], [68.57736206, 23.88319397], [68.57791901, 23.88319397], [68.57791901, 23.88347244], [68.57875061, 23.88347244], [68.57875061, 23.88375092], [68.58013916, 23.88373947], [68.58013916, 23.88402939], [68.58152771, 23.88402939], [68.58152771, 23.88431168], [68.58235931, 23.88430595], [68.58235931, 23.88458252], [68.58347321, 23.88458061], [68.58347321, 23.8848629], [68.58429718, 23.8848629], [68.58429718, 23.88513947], [68.58513641, 23.88513947], [68.58513641, 23.88542175], [68.5854187, 23.88541603], [68.5854187, 23.8856945], [68.58597565, 23.8856945], [68.58597565, 23.88597107], [68.58625031, 23.88597107], [68.58625031, 23.88624954], [68.58653259, 23.88624954], [68.58653259, 23.88652992], [68.58708954, 23.88652992], [68.58708954, 23.8868103], [68.5873642, 23.88680649], [68.5873642, 23.88708115], [68.58763885, 23.88708115], [68.58763885, 23.88736153], [68.5881958, 23.88735962], [68.5881958, 23.88764], [68.58847046, 23.88764], [68.58847046, 23.88792038], [68.5890274, 23.88792038], [68.5890274, 23.88820076], [68.58958435, 23.88819313], [68.58958435, 23.8884716], [68.5901413, 23.8884716], [68.5901413, 23.88875008], [68.59041595, 23.88875008], [68.59041595, 23.88903046], [68.5909729, 23.88903046], [68.5909729, 23.88931084], [68.59152985, 23.88930321], [68.59152985, 23.88958359], [68.59208679, 23.88957977], [68.59208679, 23.88986969], [68.59263611, 23.88986969], [68.59263611, 23.89014053], [68.59319305, 23.89014053], [68.59319305, 23.89042091], [68.59375, 23.89041519], [68.59375, 23.89069366], [68.59430695, 23.89069366], [68.59430695, 23.89097214], [68.59485626, 23.89097023], [68.59485626, 23.89125061], [68.59570313, 23.89125061], [68.59570313, 23.89153099], [68.59625244, 23.89153099], [68.59625244, 23.89180946], [68.59680176, 23.89180756], [68.59680176, 23.89194679], [68.59680939, 23.89208412], [68.59791565, 23.89208412], [68.59791565, 23.89236069], [68.5984726, 23.89236069], [68.5984726, 23.89291763], [68.59874725, 23.89291763], [68.59874725, 23.89347267], [68.59902954, 23.89347076], [68.59902954, 23.89375114], [68.59929657, 23.89375114], [68.59929657, 23.89402962], [68.59958649, 23.89402962], [68.59958649, 23.89430809], [68.59986115, 23.89430618], [68.59986115, 23.89458275], [68.6001358, 23.89458084], [68.6001358, 23.89486122], [68.60041809, 23.89486122], [68.60041809, 23.89513969], [68.60069275, 23.89513969], [68.60069275, 23.89541817], [68.60097504, 23.89541626], [68.60097504, 23.89569473], [68.60124969, 23.89569473], [68.60124969, 23.8959713], [68.60151672, 23.89596748], [68.60151672, 23.89624977], [68.60180664, 23.89624977], [68.60180664, 23.89652824], [68.60236359, 23.89652824], [68.60236359, 23.89680481], [68.60263824, 23.89680481], [68.60263824, 23.89708328], [68.6029129, 23.89708328], [68.6029129, 23.89736176], [68.60320282, 23.89736176], [68.60320282, 23.89764023], [68.60346985, 23.89764023], [68.60346985, 23.89792252], [68.60375214, 23.89792252], [68.60375214, 23.8982029], [68.60402679, 23.89819527], [68.60402679, 23.89847183], [68.60430908, 23.89847183], [68.60430908, 23.89875031], [68.60457611, 23.89875031], [68.60457611, 23.89903259], [68.60513306, 23.89903259], [68.60513306, 23.89931107], [68.60569763, 23.89930534], [68.60569763, 23.89958382], [68.60624695, 23.89958191], [68.60624695, 23.89986038], [68.60652924, 23.89986038], [68.60652924, 23.90014076], [68.60708618, 23.90014076], [68.60708618, 23.90042114], [68.6076355, 23.90041733], [68.6076355, 23.90069389], [68.60819244, 23.90069389], [68.60819244, 23.90097237], [68.60901642, 23.90097046], [68.60901642, 23.90125084], [68.60958099, 23.90125084], [68.60958099, 23.90153122], [68.61042023, 23.90153122], [68.61042023, 23.90180969], [68.61096954, 23.90180588], [68.61096954, 23.90208244], [68.61180878, 23.90208054], [68.61180878, 23.90236092], [68.61235809, 23.90236092], [68.61235809, 23.90263939], [68.61292267, 23.90263939], [68.61292267, 23.90291977], [68.61347198, 23.90291405], [68.61347198, 23.90319443], [68.61597443, 23.90319443], [68.61597443, 23.90291405], [68.61624908, 23.90291977], [68.61624908, 23.90263939], [68.61680603, 23.90263939], [68.61680603, 23.90236092], [68.61736298, 23.90236092], [68.61736298, 23.90208054], [68.61819458, 23.90208244], [68.61819458, 23.90180588], [68.61875153, 23.90180969], [68.61875153, 23.90153122], [68.61985779, 23.90153122], [68.61985779, 23.90125084], [68.62264252, 23.90125084], [68.62264252, 23.90097046], [68.62486267, 23.90097237], [68.62486267, 23.90069389], [68.62596893, 23.90069389], [68.62596893, 23.90041733], [68.62652588, 23.90042114], [68.62652588, 23.90014076], [68.62708282, 23.90014076], [68.62708282, 23.89986038], [68.62763977, 23.89986038], [68.62763977, 23.89958191], [68.62791443, 23.89958382], [68.62791443, 23.89930534], [68.62847137, 23.89931107], [68.62847137, 23.89903259], [68.6295929, 23.89903259], [68.6295929, 23.89875031], [68.63014221, 23.89875031], [68.63014221, 23.89847183], [68.63069153, 23.89847183], [68.63069153, 23.89819527], [68.63153076, 23.8982029], [68.63153076, 23.89792252], [68.63207245, 23.89792252], [68.63207245, 23.89764023], [68.6340332, 23.89764023], [68.6340332, 23.89736176], [68.63458252, 23.89736176], [68.63458252, 23.89708328], [68.63486481, 23.89708328], [68.63486481, 23.89680481], [68.63513947, 23.89680481], [68.63513947, 23.89652824], [68.63540649, 23.89652824], [68.63540649, 23.89624977], [68.63597107, 23.89624977], [68.63597107, 23.89596748], [68.63625336, 23.8959713], [68.63625336, 23.89569473], [68.63680267, 23.89569473], [68.63680267, 23.89541626], [68.63764191, 23.89541817], [68.63764191, 23.89513969], [68.63819885, 23.89513969], [68.63819122, 23.89486122], [68.63846588, 23.89486122], [68.63846588, 23.89513969], [68.63874817, 23.89513969], [68.63874817, 23.89541817], [68.63847351, 23.89541626], [68.63847351, 23.89569473], [68.63819122, 23.89569473], [68.63819122, 23.8959713], [68.63764191, 23.89596748], [68.63764191, 23.89624977], [68.63709259, 23.89624977], [68.63709259, 23.89652824], [68.63680267, 23.89652824], [68.63680267, 23.89680481], [68.63625336, 23.89680481], [68.63625336, 23.89708328], [68.63597107, 23.89708328], [68.63597107, 23.89736176], [68.63625336, 23.89736176], [68.63625336, 23.89764023], [68.63791656, 23.89764023], [68.63791656, 23.89792252], [68.63874817, 23.89791679], [68.63874817, 23.89847183], [68.63903046, 23.89847183], [68.63903046, 23.89903259], [68.63931274, 23.89903259], [68.63931274, 23.89931107], [68.63986206, 23.89930534], [68.63986206, 23.89958382], [68.64013672, 23.89958191], [68.64013672, 23.89986038], [68.64068604, 23.89986038], [68.64068604, 23.90014076], [68.64097595, 23.90014076], [68.64097595, 23.90042114], [68.64125061, 23.90041733], [68.64125061, 23.90069389], [68.64152527, 23.90069389], [68.64152527, 23.90097237], [68.64208221, 23.90097046], [68.64208221, 23.90125084], [68.64235687, 23.90125084], [68.64235687, 23.90153122], [68.64263916, 23.90153122], [68.64263916, 23.90180969], [68.64291382, 23.90180588], [68.64291382, 23.90208244], [68.64319611, 23.90208054], [68.64319611, 23.90236092], [68.64347076, 23.90236092], [68.64347076, 23.90263939], [68.64402771, 23.90263939], [68.64402771, 23.90291977], [68.64430237, 23.90291405], [68.64430237, 23.90319443], [68.64458466, 23.90319443], [68.64458466, 23.90347481], [68.64485931, 23.90347099], [68.64485931, 23.90374947], [68.6451416, 23.90374947], [68.6451416, 23.90402985], [68.64541626, 23.90402985], [68.64541626, 23.90431023], [68.64597321, 23.9043045], [68.64597321, 23.90458298], [68.64653015, 23.90458298], [68.64653015, 23.90486145], [68.64679718, 23.90485001], [68.64679718, 23.90513992], [68.6470871, 23.90513992], [68.6470871, 23.9054203], [68.64736938, 23.9054203], [68.64736938, 23.90570068], [68.6479187, 23.90569687], [68.6479187, 23.90597153], [68.64819336, 23.90596962], [68.64819336, 23.90625], [68.64875031, 23.90625], [68.64875031, 23.90653038], [68.64903259, 23.90653038], [68.64903259, 23.90681076], [68.64930725, 23.90680695], [68.64930725, 23.90708351], [68.6498642, 23.90708351], [68.6498642, 23.90736198], [68.65013885, 23.90735817], [68.65013885, 23.90764046], [68.65041351, 23.90763855], [68.65041351, 23.90819359], [68.6506958, 23.90818977], [68.6506958, 23.90875053], [68.65097046, 23.90875053], [68.65097046, 23.90903091], [68.65125275, 23.9090271], [68.65125275, 23.90958405], [68.6515274, 23.90957832], [68.6515274, 23.91013908], [68.65180206, 23.91013908], [68.65180206, 23.91041946], [68.65208435, 23.91041756], [68.65208435, 23.91069412], [68.65235901, 23.9106884], [68.65235901, 23.91098022], [68.6526413, 23.91098022], [68.6526413, 23.91124916], [68.65291595, 23.91124916], [68.65291595, 23.91152954], [68.65319824, 23.91152954], [68.65319824, 23.91181183], [68.6534729, 23.91180611], [68.6534729, 23.91208267], [68.65374756, 23.91208267], [68.65374756, 23.91236115], [68.65402985, 23.91236115], [68.65402985, 23.91263962], [68.65429688, 23.91263962], [68.65429688, 23.91292191], [68.65458679, 23.91291618], [68.65458679, 23.91319466], [68.65486145, 23.91319466], [68.65486145, 23.91347122], [68.65513611, 23.91347122], [68.65513611, 23.91374969], [68.65569305, 23.91374969], [68.65569305, 23.91403961], [68.65625, 23.91402817], [68.65625, 23.91430473], [68.65652466, 23.91430473], [68.65652466, 23.91458321], [68.6570816, 23.91458321], [68.6570816, 23.91486168], [68.6590271, 23.91485977], [68.6590271, 23.91514015], [68.65930939, 23.91514015], [68.65930939, 23.91570091], [68.65958405, 23.91569328], [68.65958405, 23.91597176], [68.6598587, 23.91596985], [68.6598587, 23.91625023], [68.66014099, 23.91625023], [68.66014099, 23.91681099], [68.66041565, 23.91680336], [68.66041565, 23.91708565], [68.6609726, 23.91707993], [68.6609726, 23.91736031], [68.66152954, 23.91736031], [68.66152954, 23.91707993], [68.66291809, 23.91707993], [68.66291809, 23.91736031], [68.66319275, 23.91736031], [68.66319275, 23.91792107], [68.6626358, 23.91792107], [68.6626358, 23.92041969], [68.66236877, 23.92041969], [68.66236877, 23.92263985], [68.66179657, 23.92263985], [68.66179657, 23.92235756], [68.6609726, 23.92236137], [68.6609726, 23.9220829], [68.66014099, 23.9220829], [68.66014099, 23.92180634], [68.65957642, 23.92180824], [68.65957642, 23.92152977], [68.6598587, 23.92152977], [68.6598587, 23.91958046], [68.65958405, 23.91958427], [68.65958405, 23.91930771], [68.65930939, 23.91930962], [68.65930939, 23.91875076], [68.6590271, 23.91875076], [68.6590271, 23.91847038], [68.65875244, 23.91847229], [68.65875244, 23.91819382], [68.65847015, 23.91819382], [68.65847015, 23.91791534], [68.65820313, 23.91792107], [68.65820313, 23.91764069], [68.65763855, 23.91764069], [68.65763855, 23.91736031], [68.65735626, 23.91736031], [68.65735626, 23.91707993], [68.6554184, 23.91708565], [68.6554184, 23.91680336], [68.65402985, 23.91681099], [68.65402985, 23.91653061], [68.65374756, 23.91653061], [68.65374756, 23.91625023], [68.6534729, 23.91625023], [68.6534729, 23.91596985], [68.65291595, 23.91597176], [68.65291595, 23.91569328], [68.65207672, 23.91570091], [68.65207672, 23.91542053], [68.65180206, 23.91542053], [68.65180206, 23.91485977], [68.6515274, 23.91486168], [68.6515274, 23.91458321], [68.65125275, 23.91458321], [68.65125275, 23.91430473], [68.6506958, 23.91430473], [68.6506958, 23.91402817], [68.65040588, 23.91403961], [68.65040588, 23.91374969], [68.65013885, 23.91374969], [68.65013885, 23.91347122], [68.64958191, 23.91347122], [68.64958191, 23.91319466], [68.64930725, 23.91319466], [68.64930725, 23.91263962], [68.64902496, 23.91263962], [68.64902496, 23.91208267], [68.64875031, 23.91208267], [68.64875031, 23.91180611], [68.64848328, 23.91181183], [68.64848328, 23.91152954], [68.6479187, 23.91152954], [68.6479187, 23.91124916], [68.64763641, 23.91124916], [68.64763641, 23.91098022], [68.6470871, 23.91098022], [68.6470871, 23.9106884], [68.64680481, 23.91069412], [68.64680481, 23.91041756], [68.64653015, 23.91041946], [68.64653015, 23.91013908], [68.64597321, 23.91013908], [68.64597321, 23.90986061], [68.64569092, 23.90986061], [68.64569092, 23.90957832], [68.64541626, 23.90958405], [68.64541626, 23.90930557], [68.64485931, 23.90930939], [68.64485931, 23.90903091], [68.64457703, 23.90903091], [68.64457703, 23.90875053], [68.64430237, 23.90875053], [68.64430237, 23.90818977], [68.64402771, 23.90819359], [68.64402771, 23.90763855], [68.64375305, 23.90764046], [68.64375305, 23.90735817], [68.64347076, 23.90736198], [68.64347076, 23.90708351], [68.64319611, 23.90708351], [68.64319611, 23.90680695], [68.64290619, 23.90681076], [68.64290619, 23.90653038], [68.64263916, 23.90653038], [68.64263916, 23.90625], [68.64235687, 23.90625], [68.64235687, 23.90570068], [68.64208221, 23.90570068], [68.64208221, 23.9054203], [68.64180756, 23.9054203], [68.64180756, 23.90513992], [68.6415329, 23.90513992], [68.6415329, 23.90485001], [68.64125061, 23.90486145], [68.64125061, 23.90458298], [68.64097595, 23.90458298], [68.64097595, 23.9043045], [68.64041901, 23.90431023], [68.64041901, 23.90402985], [68.63986206, 23.90402985], [68.63986206, 23.90374947], [68.63903046, 23.90374947], [68.63903046, 23.90347099], [68.63819122, 23.90347481], [68.63819122, 23.90319443], [68.63402557, 23.90319443], [68.63402557, 23.90347481], [68.63318634, 23.90347099], [68.63318634, 23.90374947], [68.63207245, 23.90374947], [68.63207245, 23.90402985], [68.63124847, 23.90402985], [68.63124847, 23.90431023], [68.63041687, 23.9043045], [68.63041687, 23.90458298], [68.62985992, 23.90458298], [68.62985992, 23.90486145], [68.62902832, 23.90485001], [68.62902832, 23.90513992], [68.62847137, 23.90513992], [68.62847137, 23.9054203], [68.62763977, 23.9054203], [68.62763977, 23.90570068], [68.62708282, 23.90569687], [68.62708282, 23.90597153], [68.62513733, 23.90596962], [68.62513733, 23.90625], [68.62097168, 23.90625], [68.62097168, 23.90653038], [68.61985779, 23.90653038], [68.61985779, 23.90681076], [68.61958313, 23.90680695], [68.61958313, 23.90708351], [68.61930847, 23.9070797], [68.61930847, 23.90764046], [68.61902618, 23.90763855], [68.61902618, 23.90791893], [68.61875153, 23.90791893], [68.61875153, 23.90819359], [68.61763763, 23.90818977], [68.61763763, 23.90930939], [68.61736298, 23.90930939], [68.61736298, 23.91041946], [68.61763763, 23.91041946], [68.61763763, 23.91292191], [68.61791992, 23.91291618], [68.61791992, 23.91347122], [68.61818695, 23.91347122], [68.61818695, 23.91374969], [68.61846924, 23.91374969], [68.61846924, 23.91430473], [68.61875153, 23.91430473], [68.61875153, 23.91486168], [68.61902618, 23.91485977], [68.61902618, 23.91542053], [68.61930847, 23.91542053], [68.61930847, 23.91625023], [68.61958313, 23.91625023], [68.61958313, 23.91819382], [68.61985779, 23.91819382], [68.61985779, 23.92069435], [68.61958313, 23.92069435], [68.61958313, 23.92236137], [68.61985779, 23.92236137], [68.61985779, 23.92319489], [68.62013245, 23.92318916], [68.62013245, 23.9240303], [68.62041473, 23.9240284], [68.62041473, 23.92458344], [68.62069702, 23.92458344], [68.62069702, 23.92486191], [68.62097168, 23.92486191], [68.62097168, 23.92514038], [68.62124634, 23.92514038], [68.62124634, 23.92542267], [68.62180328, 23.92541695], [68.62180328, 23.92569351], [68.6220932, 23.9256916], [68.6220932, 23.92597961], [68.62236023, 23.92597961], [68.62236023, 23.9256916], [68.62264252, 23.9256916], [68.62264252, 23.92597961], [68.62291718, 23.92597961], [68.62291718, 23.92625046], [68.62264252, 23.92625046], [68.62264252, 23.92681122], [68.62236023, 23.92681122], [68.62236023, 23.92736053], [68.62097168, 23.92736053], [68.62097168, 23.92708015], [68.61958313, 23.92708206], [68.61958313, 23.9268055], [68.61930847, 23.92681122], [68.61930847, 23.92653275], [68.61902618, 23.92653275], [68.61902618, 23.92625046], [68.61846924, 23.92625046], [68.61846924, 23.92597961], [68.61818695, 23.92597961], [68.61818695, 23.92458153], [68.61791992, 23.92458344], [68.61791992, 23.9240284], [68.61763763, 23.9240303], [68.61763763, 23.92375183], [68.61736298, 23.92375183], [68.61736298, 23.92347145], [68.61708069, 23.92347145], [68.61708069, 23.92319489], [68.61680603, 23.92319489], [68.61680603, 23.92291641], [68.61653137, 23.92291832], [68.61653137, 23.92263985], [68.61624908, 23.92263985], [68.61624908, 23.92235756], [68.61597443, 23.92236137], [68.61597443, 23.9220829], [68.61541748, 23.9220829], [68.61541748, 23.92236137], [68.61514282, 23.92235756], [68.61514282, 23.92263985], [68.61429596, 23.92263985], [68.61429596, 23.92291832], [68.61402893, 23.92291641], [68.61402893, 23.92319489], [68.61374664, 23.92318916], [68.61374664, 23.92375183], [68.61347198, 23.92375183], [68.61347198, 23.92486191], [68.61319733, 23.92486191], [68.61319733, 23.92653275], [68.61292267, 23.92653275], [68.61292267, 23.92791939], [68.61264038, 23.92791939], [68.61264038, 23.92875099], [68.61235809, 23.92875099], [68.61235809, 23.92930984], [68.61207581, 23.92930984], [68.61207581, 23.92986107], [68.61180878, 23.92986107], [68.61180878, 23.93013954], [68.61152649, 23.93013954], [68.61152649, 23.93069649], [68.61125183, 23.93069649], [68.61125183, 23.93097305], [68.61096954, 23.93097115], [68.61096954, 23.93153], [68.61069489, 23.93152618], [68.61069489, 23.93180466], [68.61042023, 23.93180466], [68.61042023, 23.9323616], [68.61013794, 23.9323597], [68.61013794, 23.93264008], [68.60986328, 23.93264008], [68.60986328, 23.93292046], [68.60958099, 23.93292046], [68.60958099, 23.93320084], [68.60930634, 23.93320084], [68.60930634, 23.93375015], [68.60901642, 23.93375015], [68.60901642, 23.93403053], [68.60874939, 23.93403053], [68.60874939, 23.93431091], [68.60847473, 23.93430519], [68.60847473, 23.93458366], [68.60819244, 23.93457985], [68.60819244, 23.93486023], [68.60791779, 23.93486023], [68.60791779, 23.93514061], [68.60764313, 23.93514061], [68.60764313, 23.93541908], [68.60708618, 23.93541718], [68.60708618, 23.93569374], [68.60680389, 23.93569374], [68.60680389, 23.93597221], [68.60652924, 23.9359684], [68.60652924, 23.93625069], [68.60624695, 23.93625069], [68.60624695, 23.93652916], [68.60597229, 23.93652916], [68.60597229, 23.93680954], [68.60514069, 23.93680573], [68.60514069, 23.9370842], [68.60430908, 23.93707848], [68.60430908, 23.93736076], [68.60320282, 23.93736076], [68.60320282, 23.93763924], [68.60208893, 23.93763924], [68.60208893, 23.93791962], [68.59986115, 23.9379158], [68.59986115, 23.93819427], [68.5993042, 23.93819427], [68.5993042, 23.93847275], [68.59874725, 23.93847275], [68.59874725, 23.93875122], [68.59819794, 23.93875122], [68.59819794, 23.93902969], [68.59764099, 23.93902969], [68.59764099, 23.93931007], [68.59708405, 23.93930626], [68.59708405, 23.93958282], [68.59680939, 23.93958282], [68.59680176, 23.94013977], [68.5965271, 23.94013977], [68.5965271, 23.94069481], [68.59625244, 23.9406929], [68.59625244, 23.94124985], [68.59597015, 23.94124985], [68.59597015, 23.94180489], [68.59402466, 23.94180489], [68.59402466, 23.94152832], [68.59208679, 23.94153023], [68.59208679, 23.94124985], [68.59041595, 23.94124985], [68.59041595, 23.94098091], [68.58847046, 23.94098091], [68.58847046, 23.9406929], [68.5873642, 23.94069481], [68.5873642, 23.93930626], [68.58763885, 23.93931007], [68.58763885, 23.93875122], [68.58790588, 23.93875122], [68.58790588, 23.93707848], [68.58763885, 23.9370842], [68.58763885, 23.93430519], [68.58735657, 23.93431091], [68.58735657, 23.93346977], [68.58763885, 23.93347168], [68.58763885, 23.93291855], [68.58790588, 23.93292046], [68.58790588, 23.93153], [68.58763885, 23.93153], [68.58763885, 23.93124962], [68.58735657, 23.93124962], [68.58735657, 23.93097115], [68.58708191, 23.93097305], [68.58708191, 23.93069649], [68.5873642, 23.93069649], [68.5873642, 23.9304142], [68.58763885, 23.93041992], [68.58763885, 23.93013954], [68.58790588, 23.93013954], [68.58790588, 23.92904091], [68.5881958, 23.92904091], [68.5881958, 23.92875099], [68.58790588, 23.92875099], [68.58790588, 23.92653275], [68.5881958, 23.92653275], [68.5881958, 23.92625046], [68.58847046, 23.92625046], [68.58847046, 23.92514038], [68.58875275, 23.92514038], [68.58875275, 23.92375183], [68.58847046, 23.92375183], [68.58847046, 23.92235756], [68.58598328, 23.92235756], [68.58598328, 23.92263985], [68.5854187, 23.92263985], [68.5854187, 23.92291832], [68.58486176, 23.92291641], [68.58486176, 23.92319489], [68.58403015, 23.92319489], [68.58403015, 23.92347145], [68.5826416, 23.92347145], [68.5826416, 23.92375183], [68.58096313, 23.92375183], [68.58096313, 23.9240303], [68.57958221, 23.9240303], [68.57958221, 23.92431259], [68.57235718, 23.92431259], [68.57235718, 23.9240303], [68.57125092, 23.9240303], [68.57125092, 23.92375183], [68.56458282, 23.92375183], [68.56458282, 23.92347145], [68.56153107, 23.92347145], [68.56153107, 23.92375183], [68.5595932, 23.92375183], [68.5595932, 23.9240303], [68.55874634, 23.9240284], [68.55874634, 23.92458344], [68.55902863, 23.92458153], [68.55902863, 23.92625046], [68.55930328, 23.92625046], [68.55930328, 23.92736053], [68.5595932, 23.92736053], [68.5595932, 23.92904091], [68.55986023, 23.92904091], [68.55986023, 23.93041992], [68.55958557, 23.9304142], [68.5595932, 23.93124962], [68.55930328, 23.93124962], [68.55930328, 23.93180466], [68.55902863, 23.93180466], [68.55902863, 23.93208313], [68.55847168, 23.93208313], [68.55847168, 23.9323616], [68.55819702, 23.9323597], [68.55819702, 23.93264008], [68.55764008, 23.93264008], [68.55764008, 23.93292046], [68.55568695, 23.93292046], [68.55568695, 23.93320084], [68.55541992, 23.93319511], [68.55541992, 23.93347168], [68.55458069, 23.93347168], [68.55458069, 23.93319511], [68.55291748, 23.93319511], [68.55291748, 23.93347168], [68.55263519, 23.93347168], [68.55263519, 23.93375015], [68.55291748, 23.93375015], [68.55291748, 23.93403053], [68.55179596, 23.93403053], [68.55179596, 23.93375015], [68.55152893, 23.93375015], [68.55152893, 23.93346977], [68.55097198, 23.93347168], [68.55097198, 23.93319511], [68.54819489, 23.93319511], [68.54819489, 23.93347168], [68.54763794, 23.93346977], [68.54763794, 23.93375015], [68.54708099, 23.93375015], [68.54708099, 23.93403053], [68.54624939, 23.93403053], [68.54624939, 23.93431091], [68.54569244, 23.93430519], [68.54569244, 23.93458366], [68.5451355, 23.93458366], [68.54514313, 23.93486023], [68.54458618, 23.93486023], [68.54458618, 23.93514061], [68.54374695, 23.93514061], [68.54374695, 23.93541908], [68.54347229, 23.93541718], [68.54347229, 23.93597221], [68.54402924, 23.9359684], [68.54402924, 23.93625069], [68.54429626, 23.93625069], [68.54429626, 23.93652916], [68.54402924, 23.93652725], [68.54402924, 23.9370842], [68.54264069, 23.93707848], [68.54264069, 23.93763924], [68.5423584, 23.93763924], [68.5423584, 23.93791962], [68.54208374, 23.9379158], [68.54208374, 23.93847275], [68.54180908, 23.93847275], [68.54180908, 23.93875122], [68.54152679, 23.93875122], [68.54152679, 23.93931007], [68.54125214, 23.93930626], [68.54125214, 23.9398613], [68.54096985, 23.93985939], [68.54096985, 23.94042015], [68.54070282, 23.94042015], [68.54070282, 23.94098091], [68.5404129, 23.94097137], [68.5404129, 23.94208336], [68.54013824, 23.94207954], [68.54013824, 23.94320107], [68.5395813, 23.94319344], [68.5395813, 23.94347191], [68.53930664, 23.94347191], [68.53930664, 23.94402695], [68.53901672, 23.94402122], [68.53901672, 23.94431114], [68.53874969, 23.94431114], [68.53874969, 23.94486046], [68.53848267, 23.94486046], [68.53848267, 23.94514084], [68.53819275, 23.94514084], [68.53819275, 23.94542122], [68.53791809, 23.94542122], [68.53791809, 23.94625092], [68.5376358, 23.94625092], [68.5376358, 23.94680977], [68.53736115, 23.94680977], [68.53736115, 23.94736099], [68.53791809, 23.94736099], [68.53791809, 23.94763947], [68.53848267, 23.94763947], [68.53848267, 23.94791985], [68.53902435, 23.94791794], [68.53902435, 23.94847298], [68.53930664, 23.94847298], [68.53930664, 23.94930077], [68.53986359, 23.94930649], [68.53986359, 23.94955063], [68.53986359, 23.95041656], [68.54013824, 23.95041656], [68.54013824, 23.95236015], [68.5404129, 23.95236015], [68.5404129, 23.9529171], [68.54069519, 23.9529171], [68.54069519, 23.95347214], [68.54096985, 23.95347214], [68.54096985, 23.95402718], [68.54125214, 23.95402718], [68.54125214, 23.95486069], [68.54152679, 23.95486069], [68.54152679, 23.95513916], [68.54180908, 23.95513916], [68.54180908, 23.95569229], [68.54208374, 23.95569229], [68.54208374, 23.95624924], [68.5423584, 23.95624924], [68.5423584, 23.95680428], [68.54264069, 23.95680428], [68.54264069, 23.95736122], [68.54291534, 23.95736122], [68.54291534, 23.95819664], [68.54319763, 23.95819664], [68.54319763, 23.95874977], [68.54347229, 23.95874977], [68.54347229, 23.95930672], [68.54374695, 23.95930672], [68.54374695, 23.95986176], [68.54402924, 23.95986176], [68.54402924, 23.96013641], [68.54430389, 23.96013641], [68.54430389, 23.9604187], [68.54458618, 23.9604187], [68.54458618, 23.96069527], [68.54486084, 23.96069527], [68.54486084, 23.96097183], [68.5451355, 23.96097183], [68.5451355, 23.96125031], [68.54541779, 23.96125031], [68.54541779, 23.96152878], [68.54569244, 23.96152878], [68.54569244, 23.96180534], [68.54597473, 23.96180534], [68.54597473, 23.96236038], [68.54624939, 23.96236038], [68.54624939, 23.96264076], [68.54652405, 23.96264076], [68.54652405, 23.96291733], [68.54680634, 23.96291733], [68.54680634, 23.96319389], [68.54708099, 23.96318626], [68.68630981, 23.96240044], [68.72147369, 23.96220207], [68.74924469, 23.96204567], [68.75092316, 23.99999809], [68.75955963, 24.03582191], [68.76139832, 24.10002327], [68.7614212, 24.10292435], [68.7618103, 24.16122246], [68.76216125, 24.19102859], [68.76306915, 24.2066288], [68.76417542, 24.23598862], [68.76412201, 24.28412247], [68.76750183, 24.2896862], [68.771492, 24.29313469], [68.77265167, 24.29413605], [68.7922821, 24.29999352], [68.80521393, 24.3032074], [68.80619049, 24.30344772], [68.82635498, 24.30839539], [68.83205414, 24.29932785], [68.83172607, 24.29557037], [68.83104706, 24.28784943], [68.83585358, 24.24988365], [68.84030914, 24.22818756], [68.84772491, 24.20837975], [68.85253143, 24.20571136], [68.86403656, 24.20522308], [68.86750793, 24.20620346], [68.86820984, 24.20713806], [68.86962891, 24.20903587], [68.87068939, 24.20487022], [68.87124634, 24.20351982], [68.87242126, 24.20066071], [68.87409973, 24.19979095], [68.87458038, 24.19955254], [68.87529755, 24.19919205], [68.87841034, 24.19763947], [68.87844849, 24.19693947], [68.88595581, 24.19605064], [68.88754272, 24.19585037], [68.89099121, 24.19593811], [68.89317322, 24.19655991], [68.89507294, 24.19720268], [68.89794922, 24.19886017], [68.90405273, 24.20916939], [68.91278839, 24.24113083], [68.91335297, 24.24266052], [68.91409302, 24.24526978], [68.91822815, 24.25312042], [68.92196655, 24.25864983], [68.93360138, 24.26857185], [68.94724274, 24.27662659], [68.94780731, 24.27565575], [68.95734406, 24.26137543], [68.95999908, 24.25362968], [68.9705658, 24.23752975], [68.98149109, 24.22854424], [68.98628235, 24.22633171], [68.99700928, 24.2259903], [68.99835205, 24.22594833], [69.00053406, 24.22587967], [69.00415039, 24.22675705], [69.01371765, 24.22907448], [69.0394516, 24.24210167], [69.07009125, 24.26024055], [69.07927704, 24.26527405], [69.08544159, 24.26827812], [69.09292603, 24.26908302], [69.10547638, 24.26607323], [69.11463928, 24.26342964], [69.11829376, 24.26237679], [69.12142181, 24.26085091], [69.13696289, 24.25326538], [69.14826965, 24.25000572], [69.14828491, 24.24908638], [69.15553284, 24.24897003], [69.15808868, 24.24625778], [69.17288971, 24.2413826], [69.1900177, 24.23574066], [69.19976807, 24.23519897], [69.22229004, 24.24745178], [69.22897339, 24.2512207], [69.23642731, 24.25183868], [69.24340057, 24.25532722], [69.26774597, 24.26370239], [69.27073669, 24.26420403], [69.27144623, 24.26673508], [69.27490997, 24.26884842], [69.29256439, 24.27391434], [69.31027222, 24.27668762], [69.33081055, 24.27399635], [69.36193848, 24.26617432], [69.38218689, 24.26599503], [69.39188385, 24.26910591], [69.3951416, 24.26869011], [69.40036774, 24.27092552], [69.41162872, 24.27385139], [69.43157959, 24.27365303], [69.43832397, 24.27270508], [69.44284821, 24.27093124], [69.44874573, 24.26940727], [69.45854187, 24.26687622], [69.46820068, 24.26438522], [69.47042847, 24.2641468], [69.48419189, 24.25741005], [69.49796295, 24.2554512], [69.5011673, 24.25502014], [69.52818298, 24.25904083], [69.55194092, 24.26459122], [69.55635071, 24.26492119], [69.57974243, 24.27038956], [69.60067749, 24.27784729], [69.61287689, 24.26755524], [69.61747742, 24.26027489], [69.66956329, 24.21664619], [69.67511749, 24.21235657], [69.68121338, 24.20509148], [69.6930542, 24.19789124], [69.70240021, 24.1904335], [69.70866394, 24.1889019], [69.71652985, 24.17959213], [69.72457886, 24.17509651], [69.72839355, 24.17487717], [69.73886871, 24.17427635], [69.74132538, 24.17413521], [69.75081635, 24.17400932], [69.7665863, 24.17165756], [69.82532501, 24.1674614], [69.83480835, 24.16755867], [69.85804749, 24.16641617], [69.86580658, 24.16535187], [69.87030792, 24.16470718], [69.87378693, 24.16611671], [69.89876556, 24.16521645], [69.90599823, 24.16620255], [69.91226196, 24.16419983], [69.97868347, 24.16505051], [70.0, 24.16635513], [70.00064087, 24.16639519], [70.01186371, 24.16764069], [70.01858521, 24.16976357], [70.024086, 24.16935349], [70.03203583, 24.17309189], [70.04890442, 24.18354607], [70.05930328, 24.19280243], [70.07730865, 24.21564293], [70.08834839, 24.23521233], [70.10400391, 24.26972198], [70.11009979, 24.28489685], [70.11904144, 24.29069901], [70.1439743, 24.29800224], [70.15045166, 24.30057335], [70.19087982, 24.308218], [70.23081207, 24.31653595], [70.23706055, 24.31726646], [70.24752808, 24.32123756], [70.27071381, 24.32987976], [70.29689026, 24.33991432], [70.30712128, 24.34204483], [70.32559204, 24.34743881], [70.35756683, 24.35199547], [70.37031555, 24.35345078], [70.45963287, 24.38697624], [70.46614075, 24.38678169], [70.48313141, 24.39077187], [70.53155518, 24.41004372], [70.56012726, 24.41859436], [70.57486725, 24.42031479], [70.59319305, 24.41173172], [70.5936203, 24.4099369], [70.59993744, 24.40730286], [70.60653687, 24.40358925], [70.60681915, 24.40343285], [70.61149597, 24.40151978], [70.61186981, 24.4005394], [70.610672, 24.3960495], [70.60840607, 24.39157104], [70.60616302, 24.38610077], [70.60394287, 24.38059807], [70.60269165, 24.37811089], [70.59939575, 24.37210846], [70.59658051, 24.36762047], [70.59378815, 24.36211967], [70.59204865, 24.35863113], [70.59082794, 24.35710907], [70.58641052, 24.35309982], [70.58516693, 24.35209274], [70.57684326, 24.34843063], [70.57446289, 24.34648132], [70.57206726, 24.34454918], [70.57280731, 24.34073067], [70.57681274, 24.32741928], [70.5796814, 24.31983185], [70.58115387, 24.31597328], [70.5874176, 24.31014633], [70.58560944, 24.30858994], [70.57348633, 24.29816437], [70.572258, 24.29357719], [70.57403564, 24.28968811], [70.5878067, 24.28539658], [70.5828476, 24.27872849], [70.57736969, 24.27388954], [70.57242584, 24.26492882], [70.57220459, 24.25919914], [70.57424927, 24.25233269], [70.58428955, 24.24412918], [70.59355164, 24.24027443], [70.59710693, 24.24012947], [70.60850525, 24.23966408], [70.61380005, 24.23944855], [70.63357544, 24.23265648], [70.65530396, 24.22508812], [70.68983459, 24.22325516], [70.72582245, 24.22086525], [70.76379395, 24.22076035], [70.79102325, 24.22199249], [70.80576324, 24.22272682], [70.81624603, 24.22504616], [70.83370972, 24.23288536], [70.83718872, 24.23450089], [70.84169006, 24.23794746], [70.84616852, 24.24300194], [70.85365295, 24.24737549], [70.86563873, 24.25084305], [70.88287354, 24.2536335], [70.894104, 24.25709724], [70.90106201, 24.26270676], [70.89482117, 24.26497269], [70.88907623, 24.26885986], [70.88713837, 24.27238083], [70.88576508, 24.27517319], [70.88537598, 24.27597046], [70.88426208, 24.28094292], [70.8842392, 24.28391075], [70.88471222, 24.28673172], [70.88513947, 24.2907505], [70.88777161, 24.29355812], [70.89041901, 24.29636955], [70.89308929, 24.29824829], [70.89972687, 24.30110168], [70.90540314, 24.30302048], [70.90670776, 24.30425072], [70.90983582, 24.30577087], [70.91034698, 24.30677986], [70.91171265, 24.30734062], [70.91539764, 24.30952072], [70.91755676, 24.31213951], [70.9212265, 24.31483841], [70.9212265, 24.31574059], [70.92488098, 24.31715965], [70.92547607, 24.31843948], [70.92687225, 24.31944084], [70.929039, 24.32324982], [70.93289185, 24.3261795], [70.93786621, 24.32932091], [70.94451141, 24.33403015], [70.94815063, 24.33685112], [70.95281219, 24.33969116], [70.95645142, 24.34342003], [70.95974731, 24.346241], [70.96746063, 24.34725189], [70.97413635, 24.34826088], [70.98179626, 24.35205078], [70.98744202, 24.3558197], [70.99209595, 24.35864067], [70.99475861, 24.35959816], [70.99633789, 24.36001968], [70.99842834, 24.36057091], [71.00112915, 24.35876083], [71.00153351, 24.35809135], [71.00233459, 24.35678291], [71.00282288, 24.35598946], [71.00453949, 24.35323906], [71.00926971, 24.34958839], [71.01299286, 24.34686089], [71.01667786, 24.34597969], [71.02539825, 24.34514046], [71.02906036, 24.34519005], [71.03369141, 24.34539986], [71.04718781, 24.34733963], [71.06093597, 24.35385323], [71.06269836, 24.35469055], [71.06642914, 24.35567093], [71.06732178, 24.35682106], [71.06784058, 24.35709], [71.07540894, 24.36843109], [71.07710266, 24.37228012], [71.08687592, 24.38040924], [71.08828735, 24.38145256], [71.09339905, 24.38355064], [71.0995636, 24.38512421], [71.12146759, 24.39071274], [71.1220932, 24.39087105], [71.12502289, 24.39293289], [71.13176727, 24.40180016], [71.13282776, 24.40572929], [71.13368988, 24.40893936], [71.13410187, 24.41381073], [71.13237, 24.41493988], [71.12415314, 24.42770958], [71.11894989, 24.43104935], [71.11009216, 24.43165207], [71.10736847, 24.43319321], [71.09309387, 24.43593407], [71.07557678, 24.43362808], [71.02857971, 24.43337822], [71.02320099, 24.43509102], [71.01738739, 24.43717957], [71.0134964, 24.43861008], [71.00998688, 24.44134712], [71.00783539, 24.44200134], [71.00756836, 24.44224167], [71.00701141, 24.44687271], [71.00752258, 24.46664047], [71.01165771, 24.49151039], [71.01420593, 24.50196075], [71.01534271, 24.52276993], [71.009758, 24.52884102], [70.99826813, 24.54133987], [71.00340271, 24.56645966], [71.00345612, 24.57009125], [71.00257111, 24.57218933], [71.00118256, 24.57503128], [70.99862671, 24.58473015], [71.00055695, 24.59921265], [71.01019287, 24.61557961], [71.01526642, 24.62035179], [71.01663208, 24.62162018], [71.01719666, 24.62244034], [71.02047729, 24.63051033], [71.02470398, 24.63188934], [71.03446198, 24.63507271], [71.0460968, 24.63881111], [71.06077576, 24.64644814], [71.07299805, 24.65402985], [71.08496094, 24.66142082], [71.09224701, 24.6677494], [71.09941864, 24.67396355], [71.10713959, 24.68065071], [71.11334229, 24.67362976], [71.11927795, 24.66864967], [71.14673615, 24.65801048], [71.17164612, 24.64886093], [71.19709778, 24.64292908], [71.2073288, 24.63954926], [71.23789215, 24.62850952], [71.24154663, 24.6266098], [71.25298309, 24.62363052], [71.26095581, 24.62053108], [71.28714752, 24.61271095], [71.29773712, 24.60764122], [71.30745697, 24.61987114], [71.31006622, 24.62108994], [71.31777191, 24.63591957], [71.32164001, 24.64031982], [71.32649231, 24.64292908], [71.34276581, 24.6482296], [71.35103607, 24.65321922], [71.35671234, 24.65405083], [71.36196899, 24.64160919], [71.36702728, 24.63190079], [71.36765289, 24.62726021], [71.37269592, 24.62576103], [71.37518311, 24.62305069], [71.3807373, 24.62138176], [71.38305664, 24.62168121], [71.38835144, 24.62393951], [71.38977051, 24.6282196], [71.39451599, 24.62701035], [71.39962769, 24.62696075], [71.40280151, 24.63153076], [71.40703583, 24.63467026], [71.41295624, 24.63531113], [71.42230988, 24.63810158], [71.42897034, 24.64256096], [71.43241882, 24.64616013], [71.4453125, 24.65397072], [71.45146942, 24.65884018], [71.45889282, 24.66127968], [71.4668808, 24.66076279], [71.47424316, 24.66320038], [71.4883194, 24.67385101], [71.50353241, 24.67380905], [71.51618958, 24.67634964], [71.52092743, 24.67548943], [71.52275085, 24.67526054], [71.52731323, 24.67716026], [71.53697205, 24.67892075], [71.54364014, 24.67358017], [71.55142212, 24.67063141], [71.5684433, 24.67352104], [71.57717896, 24.67740059], [71.58309937, 24.67653084], [71.58965302, 24.67016983], [71.592453, 24.66558838], [71.59783173, 24.66385078], [71.60486603, 24.66553116], [71.61003876, 24.66854095], [71.61659241, 24.670681], [71.61833191, 24.66836166], [71.62081909, 24.66698265], [71.62338257, 24.66424942], [71.62711334, 24.66193008], [71.6307373, 24.66255951], [71.6341629, 24.65805054], [71.64057159, 24.65608025], [71.64494324, 24.65254021], [71.64836121, 24.64640999], [71.65122223, 24.64315987], [71.65027618, 24.63993073], [71.66156006, 24.63326073], [71.66977692, 24.6365509], [71.68599701, 24.63984108], [71.71631622, 24.6543293], [71.73734283, 24.65344048], [71.74577332, 24.65427971], [71.75830841, 24.66027069], [71.78450775, 24.66885948], [71.79094696, 24.67012024], [71.79898834, 24.67052078], [71.80459595, 24.66905975], [71.80912781, 24.66592026], [71.81292725, 24.66087914], [71.81508636, 24.65468025], [71.81738281, 24.64587975], [71.81259155, 24.63252068], [71.81153107, 24.62593079], [71.81176758, 24.62182045], [71.8155365, 24.61832809], [71.82141113, 24.61658096], [71.83860779, 24.61638069], [71.84657288, 24.61486053], [71.85553741, 24.60609055], [71.85839081, 24.60416985], [71.8609314, 24.61405945], [71.86470032, 24.6195507], [71.86868286, 24.62347984], [71.867836, 24.63002014], [71.86255646, 24.64948082], [71.86276245, 24.65475273], [71.86495972, 24.66291046], [71.87110138, 24.67221832], [71.87647247, 24.67515945], [71.8813324, 24.67567062], [71.89095306, 24.67008972], [71.89379883, 24.6657505], [71.90416718, 24.66904068], [71.91210175, 24.66959953], [71.92008209, 24.66735077], [71.92592621, 24.66208267], [71.92597961, 24.65871048], [71.92405701, 24.65448189], [71.92137909, 24.65223122], [71.91723633, 24.65089035], [71.91879272, 24.64620018], [71.92800903, 24.63381195], [71.93450928, 24.62685013], [71.93952179, 24.62760162], [71.94419098, 24.62677956], [71.94744873, 24.62758064], [71.95079041, 24.6325798], [71.96218109, 24.63845062], [71.96740723, 24.63793945], [71.97914886, 24.64696121], [71.98282623, 24.65085983], [71.99077606, 24.65139961], [71.99324799, 24.65312958], [71.99339294, 24.65670967], [71.98987579, 24.66704941], [71.99407959, 24.67755127], [72.001091, 24.68297005], [72.00730896, 24.68598175], [72.03161621, 24.69181061], [72.04087067, 24.69547081], [72.05249023, 24.70578957], [72.07958221, 24.70033836], [72.08525085, 24.69700813], [72.0923233, 24.67476082], [72.08239746, 24.66847038], [72.08547974, 24.65872002], [72.0848999, 24.65275192], [72.09091187, 24.64869118], [72.10186005, 24.64333916], [72.11654663, 24.63336945], [72.12100983, 24.63196182], [72.12529755, 24.63163948], [72.13475037, 24.63380051], [72.14595032, 24.63487053], [72.15072632, 24.63410187], [72.15357971, 24.63110924], [72.16101074, 24.61944962], [72.16166687, 24.61581039], [72.16539764, 24.61450005], [72.17559052, 24.61271095], [72.18589783, 24.60943031], [72.20144653, 24.6161499], [72.20697021, 24.61207008], [72.21063995, 24.61256981], [72.20828247, 24.61725044], [72.21096802, 24.61901093], [72.21637726, 24.62021255], [72.2299881, 24.63288116], [72.23362732, 24.63080978], [72.24202728, 24.62334061], [72.24893188, 24.62078094], [72.25421906, 24.62138939], [72.26059723, 24.62074089], [72.27414703, 24.62214279], [72.27474976, 24.62223053], [72.29366302, 24.61320114], [72.29969788, 24.61619949], [72.30619812, 24.61497116], [72.30932617, 24.6119709], [72.31505585, 24.60887146], [72.3237381, 24.60894012], [72.33100891, 24.61188126], [72.34020233, 24.62298965], [72.34797668, 24.62132263], [72.35378265, 24.61810112], [72.35309601, 24.61624908], [72.35011292, 24.6146698], [72.34896851, 24.61199188], [72.34915161, 24.60231018], [72.34546661, 24.59945107], [72.34221649, 24.59352112], [72.3259964, 24.58686066], [72.31784821, 24.58496094], [72.31402588, 24.58539009], [72.30890656, 24.5908699], [72.30458069, 24.59727287], [72.30033112, 24.60015106], [72.29305267, 24.59708977], [72.27925873, 24.60000038], [72.27671051, 24.59918022], [72.25099945, 24.58016014], [72.27168274, 24.55015945], [72.28508759, 24.55743027], [72.29003906, 24.55828094], [72.29170227, 24.55528069], [72.29191589, 24.55046082], [72.29393005, 24.54491043], [72.29338837, 24.53999138], [72.29512024, 24.5384407], [72.30182648, 24.54055977], [72.33241272, 24.54244041], [72.33701324, 24.5441494], [72.33362579, 24.55583954], [72.3348999, 24.55867958], [72.34057617, 24.55751038], [72.34327698, 24.55496979], [72.34860992, 24.55348969], [72.35793304, 24.55251122], [72.3615799, 24.54331017], [72.36546326, 24.53934097], [72.36860657, 24.5365181], [72.373909, 24.53735924], [72.37419891, 24.53354073], [72.37523651, 24.53164291], [72.37486267, 24.5299511], [72.37088013, 24.52876091], [72.38632202, 24.50051117], [72.39052582, 24.49884987], [72.39772034, 24.50028038], [72.42111206, 24.50806808], [72.4260025, 24.50832939], [72.4360199, 24.50536919], [72.44248962, 24.50424957], [72.44561005, 24.49962044], [72.44815063, 24.49332047], [72.44558716, 24.4877491], [72.43863678, 24.47907257], [72.43667603, 24.46051025], [72.44616699, 24.44826126], [72.45623779, 24.43812943], [72.45761871, 24.43285179], [72.46127319, 24.42685127], [72.46375275, 24.42094994], [72.4646759, 24.40711975], [72.48744202, 24.4054203], [72.50099945, 24.4073391], [72.50771332, 24.40993118], [72.51000214, 24.41834259], [72.50441742, 24.43089104], [72.50055695, 24.45029068], [72.51174164, 24.4473896], [72.51387787, 24.46455956], [72.51877594, 24.47299194], [72.54213715, 24.50486946], [72.54457855, 24.5068512], [72.54772186, 24.50559235], [72.55181122, 24.50032806], [72.55914307, 24.49464035], [72.57422638, 24.48814011], [72.5823822, 24.47746086], [72.58850098, 24.47250175], [72.60412598, 24.46910858], [72.63932037, 24.46146011], [72.658638, 24.45643044], [72.67443085, 24.45696259], [72.68460846, 24.45919991], [72.69301605, 24.46016121], [72.69725037, 24.45721054], [72.69753265, 24.452631], [72.69264221, 24.4414196], [72.69346619, 24.41928101], [72.70664215, 24.39133263], [72.71747589, 24.37555122], [72.73253632, 24.3612709], [72.73928833, 24.35884094], [72.74871826, 24.35752106], [72.77282715, 24.36074066], [72.79325104, 24.36016083], [72.81534576, 24.35819054], [72.82924652, 24.36498833], [72.83905029, 24.36478043], [72.85367584, 24.36601067], [72.86811829, 24.36581039], [72.8842926, 24.36084938], [72.90055847, 24.35144806], [72.91002655, 24.34049988], [72.91557312, 24.33280945], [72.9210968, 24.32723999], [72.92391205, 24.32632256], [72.92903137, 24.33265114], [72.9337616, 24.33618927], [72.94602203, 24.33928108], [72.96177673, 24.34877014], [72.96537018, 24.35110855], [72.97749329, 24.35884094], [72.99146271, 24.36397171], [72.99201202, 24.3682003], [72.98748016, 24.37511063], [72.98127747, 24.38005066], [72.974617, 24.38343048], [72.9661026, 24.38303185], [72.96327972, 24.38373947], [72.96418762, 24.39222145], [72.97245026, 24.40192986], [72.97939301, 24.40563965], [72.99061584, 24.42089081], [72.98931122, 24.43272972], [72.98324585, 24.44029808], [72.98100281, 24.4510498], [72.98912048, 24.45700073], [72.9980011, 24.46804047], [73.00034332, 24.47063065], [73.00676727, 24.47628021], [73.01278687, 24.48240089], [73.02185059, 24.46511269], [73.02719879, 24.46511269], [73.03320313, 24.46371078], [73.05104065, 24.46525955], [73.0533905, 24.4664917], [73.05728149, 24.4726181], [73.06713867, 24.47458267], [73.07006073, 24.48088074], [73.07485962, 24.48269081], [73.08381653, 24.49020958], [73.09438324, 24.49472809], [73.09892273, 24.49149132], [73.098526, 24.47261047], [73.10719299, 24.45681953], [73.10762787, 24.45181084], [73.1065979, 24.44536972], [73.10883331, 24.43241119], [73.10832977, 24.42632103], [73.10624695, 24.42032051], [73.09673309, 24.41720963], [73.0930481, 24.41312981], [73.09072113, 24.40878105], [73.08862305, 24.40008926], [73.08442688, 24.39764977], [73.08496094, 24.39447021], [73.09825897, 24.38552094], [73.10865021, 24.38746262], [73.11119843, 24.38680077], [73.11863708, 24.37574005], [73.127388, 24.36882973], [73.13730621, 24.36444092], [73.14531708, 24.36305046], [73.15455627, 24.35642815], [73.16200256, 24.35268021], [73.16996765, 24.35066986], [73.18017578, 24.35066986], [73.19039154, 24.35577011], [73.20072937, 24.36679077], [73.21098328, 24.37541962], [73.23147583, 24.36466026], [73.22561646, 24.35647964], [73.21644592, 24.35046959], [73.21105957, 24.33423042], [73.20140076, 24.33409119], [73.19792938, 24.33977127], [73.19294739, 24.34357071], [73.18701172, 24.33494949], [73.18612671, 24.32697105], [73.18643951, 24.3201828], [73.18479919, 24.30911064], [73.18062592, 24.30149078], [73.1733017, 24.30105019], [73.15123749, 24.31079292], [73.1449585, 24.30785751], [73.14385223, 24.29948044], [73.13894653, 24.28005028], [73.11606598, 24.26259041], [73.10987854, 24.25399017], [73.10690308, 24.24895287], [73.10575867, 24.24431038], [73.10090637, 24.23771095], [73.10193634, 24.23485184], [73.10617065, 24.23238945], [73.11120605, 24.23111153], [73.10600281, 24.22615051], [73.10119629, 24.22327042], [73.09172821, 24.22088051], [73.08722687, 24.20079994], [73.08196259, 24.19664955], [73.08130646, 24.19185829], [73.08268738, 24.18498039], [73.09095001, 24.17527962], [73.10243988, 24.16519928], [73.11303711, 24.15779114], [73.11650848, 24.15286064], [73.11416626, 24.13858986], [73.12339783, 24.14030075], [73.13846588, 24.12807083], [73.14715576, 24.12255096], [73.1554718, 24.12186813], [73.16114807, 24.12005997], [73.16755676, 24.11628914], [73.17173004, 24.1113224], [73.18686676, 24.10770035], [73.19190216, 24.10654831], [73.19386292, 24.10518265], [73.19760132, 24.11079025], [73.19999695, 24.10839081], [73.21227264, 24.10414124], [73.21578979, 24.10169983], [73.22381592, 24.09822083], [73.22264862, 24.09350967], [73.22041321, 24.08930016], [73.21672058, 24.08526039], [73.21438599, 24.08019066], [73.21366882, 24.07578087], [73.20910645, 24.06664085], [73.20108795, 24.05739021], [73.19893646, 24.05146027], [73.20063782, 24.0452404], [73.20812225, 24.03948021], [73.2232666, 24.03239059], [73.22933197, 24.02811813], [73.22940063, 24.02403069], [73.23513794, 24.02011108], [73.24032593, 24.01831818], [73.2425766, 24.01279831], [73.24582672, 24.01070976], [73.25254059, 24.01111984], [73.25637817, 24.01317978], [73.26390839, 24.02009964], [73.2753067, 24.02802086], [73.28275299, 24.02881813], [73.29103088, 24.02740288], [73.2979126, 24.03676987], [73.3068161, 24.05145073], [73.31140137, 24.05461121], [73.31845856, 24.0567894], [73.32656097, 24.0625], [73.33249664, 24.07368279], [73.33451843, 24.08256912], [73.33188629, 24.10400963], [73.33518219, 24.1151104], [73.34276581, 24.11582947], [73.36081696, 24.11409187], [73.37346649, 24.1281395], [73.36962128, 24.11249161], [73.36962891, 24.08798027], [73.37475586, 24.08708191], [73.37979126, 24.08415031], [73.38526917, 24.07958031], [73.39659119, 24.07253075], [73.40419006, 24.06520081], [73.41375732, 24.05106926], [73.41140747, 24.03484154], [73.41146851, 24.02518272], [73.40925598, 24.01585007], [73.41081238, 24.00255013], [73.41060638, 23.99833107], [73.40505981, 23.99054909], [73.41396332, 23.98843193], [73.41957855, 23.98266029], [73.42146301, 23.97467041], [73.41912842, 23.95379829], [73.42038727, 23.93644905], [73.42468262, 23.93106079], [73.42346954, 23.92760086], [73.42012024, 23.92340088], [73.40775299, 23.91612053], [73.40225983, 23.91822052], [73.39611053, 23.91679192], [73.3864975, 23.90577126], [73.38237762, 23.89500046], [73.37695313, 23.88879967], [73.37124634, 23.87585068], [73.36606598, 23.86907005], [73.36207581, 23.86186981], [73.35984802, 23.85462952], [73.36952209, 23.83855057], [73.3719101, 23.83208275], [73.37267303, 23.8219223], [73.37042236, 23.81438065], [73.36283112, 23.79775047], [73.36112976, 23.79165077], [73.36264801, 23.78742981], [73.36769867, 23.78364944], [73.37133789, 23.77787018], [73.37590027, 23.76667023], [73.3898468, 23.76926041], [73.39391327, 23.77846146], [73.40000916, 23.78397751], [73.408638, 23.78359032], [73.41349792, 23.78110123], [73.42048645, 23.77933121], [73.42765808, 23.7664299], [73.43218994, 23.76208115], [73.45082092, 23.75259018], [73.45128632, 23.74884033], [73.45493317, 23.73971939], [73.46276855, 23.73430824], [73.47289276, 23.72578049], [73.47661591, 23.72103119], [73.47927094, 23.70897293], [73.48561096, 23.70500946], [73.50192261, 23.70664978], [73.50853729, 23.70333099], [73.51035309, 23.69697952], [73.51122284, 23.68008041], [73.51094055, 23.67338943], [73.50779724, 23.66263008], [73.50720978, 23.6577301], [73.50052643, 23.65073013], [73.5116272, 23.64508057], [73.50845337, 23.63939095], [73.50137329, 23.63544083], [73.50109863, 23.63383102], [73.50569153, 23.62885094], [73.51024628, 23.62068939], [73.51348877, 23.61681175], [73.52672577, 23.6106205], [73.53224182, 23.61354065], [73.54141998, 23.62265015], [73.55297852, 23.63134956], [73.57074738, 23.65351105], [73.57727051, 23.65536118], [73.60853577, 23.65430832], [73.61901855, 23.6514225], [73.63295746, 23.63853073], [73.64225769, 23.63126945], [73.65039825, 23.62688065], [73.66073608, 23.62290192], [73.64998627, 23.60769272], [73.64804077, 23.59864044], [73.64872742, 23.59067917], [73.65120697, 23.58086967], [73.6497879, 23.57534027], [73.64286804, 23.56962013], [73.63825989, 23.56254959], [73.63713074, 23.54801941], [73.63700104, 23.53112984], [73.65219879, 23.52140236], [73.65733337, 23.51618004], [73.65844727, 23.51415253], [73.65841675, 23.50411987], [73.65258789, 23.50093079], [73.64491272, 23.49873924], [73.64382172, 23.4967804], [73.64064789, 23.47304153], [73.63275146, 23.45239258], [73.63806915, 23.45034027], [73.65320587, 23.44049072], [73.66081238, 23.44725037], [73.6687088, 23.451931], [73.68190765, 23.45708084], [73.69394684, 23.45890045], [73.704216, 23.45578194], [73.70960236, 23.44449043], [73.71356201, 23.43367958], [73.71721649, 23.41884041], [73.7203064, 23.4148407], [73.72614288, 23.41266251], [73.72881317, 23.41829109], [73.7339859, 23.42489243], [73.7513504, 23.44246101], [73.7565918, 23.4495697], [73.76065063, 23.4568119], [73.7647171, 23.45857811], [73.77099609, 23.45257759], [73.7739563, 23.44586945], [73.77784729, 23.44231987], [73.7830658, 23.43461037], [73.79416656, 23.43556976], [73.82688904, 23.44684029], [73.83213043, 23.44675064], [73.83679962, 23.44013977], [73.8364563, 23.43069077], [73.85743713, 23.40479279], [73.86676025, 23.39577103], [73.87708282, 23.37833023], [73.87944031, 23.36811066], [73.89118195, 23.35860062], [73.89492798, 23.35258102], [73.89427185, 23.33713913], [73.90122986, 23.3359127], [73.91398621, 23.33597946], [73.92784119, 23.33788109], [73.93889618, 23.34141922], [73.94262695, 23.34593964], [73.9438324, 23.35359955], [73.94371033, 23.36634064], [73.94729614, 23.3735199], [73.95691681, 23.37763977], [73.96247101, 23.38138962], [73.97103119, 23.37713814], [73.97889709, 23.36783981], [73.98348999, 23.35984039], [73.98446655, 23.34945107], [73.98696899, 23.34123993], [73.99077606, 23.33762932], [74.00380707, 23.33620071], [74.02361298, 23.33288193], [74.03266144, 23.33234978], [74.03006744, 23.31994057], [74.03592682, 23.31261063], [74.03759766, 23.30574036], [74.04138184, 23.30700111], [74.04769897, 23.31093979], [74.04968262, 23.30709076], [74.04447174, 23.29609108], [74.04873657, 23.29506111], [74.07652283, 23.29819107], [74.08973694, 23.29799271], [74.10166168, 23.29574966], [74.10658264, 23.2941227], [74.11106873, 23.28572083], [74.11387634, 23.27734947], [74.11856079, 23.27536964], [74.12989044, 23.27272034], [74.13378143, 23.26945114], [74.1361084, 23.26472092], [74.13652039, 23.24480057], [74.1388092, 23.23637962], [74.13865662, 23.23092079], [74.13948059, 23.2268219], [74.13510132, 23.22006989], [74.13391113, 23.21517944], [74.12470245, 23.20656967], [74.12349701, 23.20170021], [74.12252045, 23.19157028], [74.12452698, 23.19044113], [74.1244812, 23.18799973], [74.12702179, 23.17885017], [74.13051605, 23.17764282], [74.13617706, 23.17770958], [74.14569092, 23.17523003], [74.14845276, 23.17205048], [74.15516663, 23.15775108], [74.16069031, 23.15554047], [74.16493988, 23.15648079], [74.18299103, 23.15221977], [74.18660736, 23.15252113], [74.18914795, 23.15790939], [74.18953705, 23.17184067], [74.19412231, 23.17856026], [74.20008087, 23.18374062], [74.2041626, 23.18909073], [74.20754242, 23.19205093], [74.2293396, 23.184021], [74.2370224, 23.18270111], [74.24603271, 23.18825912], [74.24977875, 23.17843056], [74.25242615, 23.17616844], [74.25701904, 23.17472076], [74.26185608, 23.17160034], [74.26706696, 23.16596985], [74.2718277, 23.15600967], [74.27661896, 23.13977242], [74.27762604, 23.13397026], [74.27954102, 23.12997055], [74.28491211, 23.12458038], [74.28814697, 23.11873055], [74.2820282, 23.10643005], [74.28077698, 23.10098076], [74.28253937, 23.09501266], [74.28678131, 23.0916996], [74.30391693, 23.08389282], [74.31017303, 23.07954025], [74.31552124, 23.07212067], [74.31829071, 23.06725121], [74.32277679, 23.06269073], [74.32531738, 23.04817009], [74.32772064, 23.04269028], [74.33191681, 23.03919029], [74.33886719, 23.03582954], [74.3467865, 23.03394127], [74.34919739, 23.03024101], [74.35066223, 23.01552963], [74.35536194, 23.00307083], [74.35771179, 23.00037193], [74.36546326, 22.98981094], [74.3687973, 22.98355103], [74.3707962, 22.98005295], [74.3707962, 22.97723007], [74.36805725, 22.97653008], [74.36297607, 22.97793007], [74.35713959, 22.97722054], [74.35481262, 22.97511101], [74.34971619, 22.96876907], [74.34163666, 22.96469116], [74.34438324, 22.95836258], [74.34792328, 22.95344925], [74.35417938, 22.9471302], [74.36003876, 22.94222069], [74.3620224, 22.93309021], [74.36553955, 22.92957115], [74.37140656, 22.92605972], [74.37454987, 22.9225502], [74.37769318, 22.91553116], [74.38160706, 22.90990829], [74.38826752, 22.90710258], [74.39293671, 22.90219116], [74.400383, 22.89937973], [74.40817261, 22.90431023], [74.41243744, 22.91274834], [74.41870117, 22.9183712], [74.42375946, 22.91978073], [74.42843628, 22.91978073], [74.4319458, 22.92258072], [74.43585968, 22.92048073], [74.43859863, 22.9176712], [74.44406128, 22.92259979], [74.45147705, 22.92399979], [74.45500946, 22.91838074], [74.45812988, 22.91628265], [74.46282196, 22.91345978], [74.46360016, 22.90714073], [74.466362, 22.90081024], [74.46636963, 22.8944912], [74.46871185, 22.88746071], [74.47146606, 22.88043976], [74.47380066, 22.87479973], [74.47421265, 22.86778069], [74.47540283, 22.86497116], [74.47891998, 22.85864067], [74.4719162, 22.83265114], [74.46881866, 22.82351112], [74.46494293, 22.81508064], [74.45947266, 22.81225967], [74.45168304, 22.81085968], [74.4438858, 22.81014061], [74.4391861, 22.80944061], [74.43881989, 22.80521965], [74.44078064, 22.79961014], [74.44039917, 22.79327965], [74.43923187, 22.78555107], [74.43534851, 22.77922249], [74.43107605, 22.77008057], [74.42523956, 22.76024055], [74.42057037, 22.75743103], [74.41707611, 22.75111008], [74.41438293, 22.74477959], [74.40851593, 22.73705101], [74.40307617, 22.73070908], [74.40078735, 22.72017097], [74.40117645, 22.71244049], [74.40080261, 22.70681953], [74.39691162, 22.70050049], [74.39692688, 22.69207001], [74.39424133, 22.68573952], [74.38994598, 22.67801285], [74.38490295, 22.66957092], [74.38414001, 22.66043091], [74.38456726, 22.65057945], [74.38418579, 22.64356995], [74.38108826, 22.63863945], [74.37288666, 22.63652992], [74.36395264, 22.63652039], [74.35224915, 22.63932037], [74.34406281, 22.6421299], [74.33705139, 22.64071274], [74.33434296, 22.64141083], [74.33081055, 22.64351082], [74.32807922, 22.64421082], [74.32653046, 22.64211082], [74.32537079, 22.63858986], [74.32227325, 22.63647842], [74.31720734, 22.63646126], [74.31328583, 22.63858032], [74.3094101, 22.63928032], [74.30433655, 22.63997078], [74.29888153, 22.64067078], [74.29458618, 22.64136124], [74.28991699, 22.64344978], [74.27822113, 22.64766121], [74.27472687, 22.64274025], [74.27355194, 22.64063263], [74.27160645, 22.64133263], [74.26925659, 22.64344025], [74.26535797, 22.6448307], [74.26342773, 22.64272118], [74.26226807, 22.63850975], [74.25914764, 22.63639069], [74.25641632, 22.63568115], [74.25644684, 22.63076019], [74.25840759, 22.62655067], [74.25763702, 22.62444115], [74.25374603, 22.62302971], [74.24986267, 22.62302017], [74.24754333, 22.61740112], [74.24365997, 22.61387062], [74.23665619, 22.61387062], [74.23432922, 22.6068306], [74.23008728, 22.59699059], [74.22737122, 22.59065819], [74.22622681, 22.5850296], [74.22274017, 22.58152008], [74.2184906, 22.58151054], [74.21652222, 22.57798958], [74.21383667, 22.56744003], [74.20955658, 22.5667305], [74.20332336, 22.56812096], [74.19941711, 22.57022095], [74.19007874, 22.56740189], [74.19519043, 22.56248856], [74.19557953, 22.56038094], [74.19519806, 22.55686951], [74.19171143, 22.55335045], [74.18431854, 22.54981041], [74.17887115, 22.54840088], [74.1726532, 22.54486847], [74.16802216, 22.54134941], [74.16295624, 22.53712082], [74.15869141, 22.53429985], [74.15753937, 22.53219032], [74.15795135, 22.52656937], [74.15680695, 22.52094078], [74.15332031, 22.51741982], [74.14788818, 22.51811028], [74.14321136, 22.51880074], [74.13852692, 22.52019119], [74.13347626, 22.51877975], [74.12995911, 22.52158928], [74.12760925, 22.52437973], [74.12484741, 22.53000069], [74.12211609, 22.53560829], [74.11859894, 22.53981018], [74.11351776, 22.54120064], [74.10964966, 22.53839111], [74.10575104, 22.53767014], [74.10069275, 22.54117012], [74.09327698, 22.54465103], [74.08428955, 22.54955101], [74.07805634, 22.55162811], [74.06674957, 22.55089951], [74.05628204, 22.5477829], [74.0500412, 22.54565048], [74.04463959, 22.54212189], [74.04231262, 22.53718948], [74.04078674, 22.5301609], [74.04315948, 22.52384949], [74.04358673, 22.51682091], [74.0389328, 22.51400185], [74.03466797, 22.50836945], [74.03511047, 22.50274277], [74.03591919, 22.49641991], [74.03708649, 22.49151039], [74.04293823, 22.49082947], [74.04566956, 22.49294281], [74.04640961, 22.49715996], [74.0499115, 22.49998283], [74.0545578, 22.50139809], [74.05609894, 22.50562859], [74.05879974, 22.51054955], [74.06188965, 22.51126099], [74.0650177, 22.51057053], [74.06968689, 22.50988007], [74.07396698, 22.51059914], [74.07865143, 22.50921059], [74.08136749, 22.50851822], [74.08526611, 22.50851822], [74.08644867, 22.50502014], [74.08570099, 22.4987011], [74.08727264, 22.49378014], [74.08963776, 22.48887062], [74.09043884, 22.48254967], [74.08889771, 22.47973251], [74.08538818, 22.48182106], [74.08344269, 22.48463058], [74.08030701, 22.48603058], [74.07878876, 22.48111153], [74.07843018, 22.47339058], [74.07808685, 22.46564293], [74.08583832, 22.46707916], [74.09050751, 22.46920013], [74.0951767, 22.46920967], [74.10024261, 22.46923256], [74.10334778, 22.46783066], [74.10610962, 22.4622097], [74.10573578, 22.45589066], [74.10225677, 22.4509697], [74.10073853, 22.44534111], [74.10270691, 22.4397316], [74.10507202, 22.43341064], [74.11051941, 22.42921066], [74.11637115, 22.42642021], [74.1230011, 22.4208107], [74.12689972, 22.42012978], [74.13037872, 22.42154121], [74.13037872, 22.42505074], [74.1307373, 22.42996979], [74.13111115, 22.43629074], [74.13417816, 22.44262123], [74.13728333, 22.44824982], [74.14074707, 22.4538784], [74.14424896, 22.45671082], [74.15122986, 22.45671844], [74.15628815, 22.4567318], [74.15672302, 22.45041084], [74.15596008, 22.44548988], [74.15598297, 22.43987274], [74.15873718, 22.43494987], [74.16107178, 22.43215942], [74.1672821, 22.43217087], [74.17077637, 22.4335804], [74.17153931, 22.43779182], [74.17267609, 22.44201279], [74.18280029, 22.44275093], [74.18667603, 22.44415092], [74.18743134, 22.44767189], [74.18624878, 22.45259285], [74.18430328, 22.45609093], [74.18234253, 22.46030045], [74.18270874, 22.46453094], [74.18541718, 22.46944046], [74.19082642, 22.47788048], [74.19785309, 22.47509956], [74.20252991, 22.47229958], [74.20449066, 22.46668053], [74.20450592, 22.46105003], [74.20493317, 22.45474052], [74.2045517, 22.44701004], [74.20459747, 22.44067955], [74.20461273, 22.43717194], [74.21160126, 22.43437004], [74.21626282, 22.43439102], [74.21663666, 22.43931961], [74.21856689, 22.4428196], [74.22054291, 22.4421196], [74.22364044, 22.44001007], [74.22831726, 22.44003105], [74.23725891, 22.43934059], [74.24659729, 22.4365406], [74.25402069, 22.43305969], [74.25945282, 22.42885017], [74.26412201, 22.42464066], [74.26648712, 22.4183197], [74.26999664, 22.41481018], [74.2700119, 22.41059113], [74.27120972, 22.40498161], [74.27471161, 22.40357971], [74.27820587, 22.40287971], [74.28172302, 22.40007973], [74.28830719, 22.39797974], [74.29418182, 22.39446831], [74.29106903, 22.39166069], [74.2871933, 22.39306068], [74.28135681, 22.39375114], [74.27394867, 22.3930397], [74.26850891, 22.39443016], [74.26345062, 22.39653969], [74.25798798, 22.40003014], [74.25723267, 22.39511108], [74.25685883, 22.39019966], [74.25611115, 22.38599014], [74.25300598, 22.38387108], [74.24951935, 22.38315964], [74.24600983, 22.38315964], [74.24563599, 22.37753105], [74.24019623, 22.37681961], [74.2351532, 22.37821007], [74.23085022, 22.37962151], [74.22543335, 22.37820053], [74.22582245, 22.37540054], [74.22737885, 22.37259293], [74.22738647, 22.36907005], [74.22663116, 22.36485291], [74.22704315, 22.35853958], [74.22355652, 22.35783005], [74.21656036, 22.35781288], [74.21344757, 22.35921097], [74.21111298, 22.36273003], [74.20993042, 22.36621094], [74.20680237, 22.36762047], [74.20603943, 22.36341095], [74.20565796, 22.35989952], [74.20609283, 22.35357094], [74.20533752, 22.34794998], [74.2022171, 22.34303093], [74.198349, 22.34301949], [74.1979599, 22.34793282], [74.19754028, 22.35073853], [74.19483185, 22.34934044], [74.19484711, 22.34371948], [74.19644165, 22.33390045], [74.19568634, 22.32543945], [74.19106293, 22.32192993], [74.18406677, 22.32261086], [74.17588806, 22.32471275], [74.16384125, 22.32678986], [74.15409851, 22.32887077], [74.14362335, 22.33026123], [74.1342926, 22.3323307], [74.13153076, 22.33794975], [74.13034821, 22.34355927], [74.12914276, 22.35268974], [74.12445831, 22.35830116], [74.11709595, 22.35757065], [74.1162796, 22.36108971], [74.11508942, 22.36740112], [74.11196136, 22.37161255], [74.10534668, 22.37299156], [74.09989929, 22.37297821], [74.09836578, 22.36876106], [74.09527588, 22.36244011], [74.08985901, 22.36241913], [74.08364105, 22.36239052], [74.07702637, 22.36238098], [74.07198334, 22.36024094], [74.07084656, 22.35462952], [74.07164764, 22.34901047], [74.0743866, 22.34621048], [74.07596588, 22.34130287], [74.07405853, 22.33638191], [74.06826782, 22.33073044], [74.06828308, 22.32582283], [74.06674194, 22.31739044], [74.06680298, 22.31105995], [74.06643677, 22.30544281], [74.06254578, 22.3068409], [74.05905151, 22.30541039], [74.0579071, 22.29980087], [74.05832672, 22.29348183], [74.05989075, 22.29067039], [74.0591507, 22.28574944], [74.06149292, 22.28084183], [74.06463623, 22.2759304], [74.06891632, 22.27243042], [74.07242584, 22.26893044], [74.07826996, 22.2682476], [74.07943726, 22.26333809], [74.07987213, 22.25842094], [74.07872772, 22.25278091], [74.08067322, 22.24999046], [74.08535004, 22.24790001], [74.08922577, 22.24720955], [74.09158325, 22.24370003], [74.0892868, 22.24019051], [74.08460999, 22.23805809], [74.07842255, 22.23735809], [74.07454681, 22.2345295], [74.07338715, 22.22960091], [74.07578278, 22.22187805], [74.08159637, 22.22050095], [74.08744049, 22.22051048], [74.09440613, 22.221241], [74.10177612, 22.22056007], [74.10761261, 22.22056961], [74.11383057, 22.21918106], [74.11927032, 22.21638107], [74.12277985, 22.21290016], [74.12240601, 22.20866013], [74.12124634, 22.2051506], [74.12245941, 22.19812965], [74.12364197, 22.19252014], [74.12211609, 22.18760109], [74.12291718, 22.18198013], [74.12409973, 22.17776108], [74.12490845, 22.17215919], [74.1264801, 22.16654015], [74.13189697, 22.16444016], [74.13504028, 22.1616497], [74.13349152, 22.15813065], [74.13314056, 22.15321922], [74.13355255, 22.14619255], [74.12967682, 22.14266014], [74.12738037, 22.13774109], [74.12663269, 22.13212013], [74.12782288, 22.12721062], [74.13130951, 22.12441063], [74.13134766, 22.1201992], [74.13020325, 22.11387062], [74.12905884, 22.10825157], [74.12906647, 22.10333824], [74.13027191, 22.09770966], [74.13259125, 22.09632111], [74.13800049, 22.09845161], [74.14382172, 22.10126114], [74.15000916, 22.10408974], [74.15466309, 22.10550117], [74.15621185, 22.10409927], [74.15856171, 22.10200119], [74.16204834, 22.10271072], [74.1655426, 22.10271835], [74.17021179, 22.1013298], [74.17214203, 22.09852982], [74.17411041, 22.09641075], [74.17215729, 22.09360123], [74.17527008, 22.09151077], [74.17875671, 22.09011078], [74.18070984, 22.08660126], [74.17646027, 22.08449173], [74.17064667, 22.08447075], [74.16755676, 22.08236122], [74.16602325, 22.07814026], [74.16487885, 22.07393265], [74.16179657, 22.07110977], [74.16336823, 22.06409073], [74.16298676, 22.06056976], [74.15447998, 22.0577507], [74.14906311, 22.05632019], [74.13783264, 22.05350113], [74.13939667, 22.0506897], [74.14404297, 22.04788971], [74.14523315, 22.04368019], [74.14100647, 22.04086113], [74.13208008, 22.03873062], [74.1251297, 22.03589058], [74.12088776, 22.03026962], [74.11664581, 22.02464104], [74.10890198, 22.02181053], [74.10118866, 22.01828003], [74.09770203, 22.01545906], [74.10045624, 22.01055908], [74.1003418, 22.00159264], [74.10500336, 21.99893951], [74.1082077, 21.99835968], [74.11688995, 21.99863052], [74.12773132, 21.99376106], [74.14198303, 21.99123192], [74.14959717, 21.98880959], [74.15384674, 21.98641968], [74.1518631, 21.98089027], [74.15320587, 21.97557068], [74.14560699, 21.97400093], [74.14366913, 21.97222137], [74.14335632, 21.96988106], [74.1453476, 21.96461105], [74.14890289, 21.96071053], [74.14467621, 21.95656967], [74.14601898, 21.9540596], [74.13816071, 21.95337105], [74.11364746, 21.94470024], [74.09867096, 21.9376297], [74.07151031, 21.92960167], [74.06162262, 21.92805099], [74.056427, 21.92641068], [74.04666901, 21.9228096], [74.03560638, 21.9160099], [74.02304077, 21.90597153], [74.01168823, 21.9005394], [74.00489044, 21.89936066], [73.97973633, 21.88750076], [73.9608078, 21.87599182], [73.9491806, 21.87034035], [73.93636322, 21.86314964], [73.92192841, 21.85658264], [73.90666962, 21.85363007], [73.89951324, 21.85449028], [73.87960052, 21.83864021], [73.86374664, 21.83665085], [73.84152222, 21.83850098], [73.82792664, 21.83485985], [73.8162384, 21.82856941], [73.81051636, 21.82333755], [73.81356812, 21.81011963], [73.81759644, 21.80850029], [73.82759857, 21.81193924], [73.83210754, 21.81085014], [73.83351898, 21.80516052], [73.83893585, 21.8001709], [73.83421326, 21.79661179], [73.83567047, 21.79347992], [73.84496307, 21.79068184], [73.8441391, 21.78711128], [73.83837891, 21.7841301], [73.84294891, 21.77213097], [73.84129333, 21.76865005], [73.83120728, 21.76288986], [73.84635925, 21.74200058], [73.85633087, 21.73464012], [73.86029816, 21.73301125], [73.86511993, 21.72937965], [73.87123108, 21.72191811], [73.8783493, 21.71693039], [73.88504791, 21.71442986], [73.8902359, 21.71064949], [73.89396667, 21.70314026], [73.8963623, 21.70028114], [73.89810181, 21.66727066], [73.89444733, 21.6570797], [73.89126587, 21.65151024], [73.88562775, 21.64505959], [73.87026978, 21.63879013], [73.86025238, 21.64184761], [73.8530426, 21.63586998], [73.84523773, 21.63315964], [73.83854675, 21.63537979], [73.8290329, 21.63978958], [73.80882263, 21.63571167], [73.80013275, 21.63463974], [73.79086304, 21.6287899], [73.78761292, 21.62504959], [73.78952789, 21.62091064], [73.79057312, 21.61850929], [73.80683899, 21.60237122], [73.81845093, 21.60233116], [73.82315063, 21.6006794], [73.82450104, 21.59828949], [73.82905579, 21.57295036], [73.83376312, 21.55348015], [73.84015656, 21.5369091], [73.84503174, 21.5215683], [73.84989166, 21.51098061], [73.85401154, 21.50726128], [73.86078644, 21.49582291], [73.87030029, 21.49725914], [73.87684631, 21.50118828], [73.88020325, 21.5078907], [73.88256836, 21.50978279], [73.8866272, 21.50468063], [73.89707184, 21.50604248], [73.9036026, 21.50875282], [73.91004944, 21.51330185], [73.91047668, 21.52017021], [73.9260788, 21.51959991], [73.92839813, 21.52062988], [73.93099213, 21.52299118], [73.93377686, 21.52359009], [73.93614197, 21.52244949], [73.93762207, 21.5206604], [73.93940735, 21.51011086], [73.95358276, 21.51580048], [73.95728302, 21.51647186], [73.96111298, 21.51929855], [73.96276093, 21.53787994], [73.96631622, 21.53907013], [73.96985626, 21.5385685], [73.97335815, 21.53141022], [73.97445679, 21.52408028], [73.98219299, 21.5218029], [73.98568726, 21.5213604], [73.9875412, 21.52240944], [73.98252106, 21.53573036], [73.98178864, 21.53977013], [73.98352051, 21.54204178], [74.00534058, 21.54076958], [74.0190506, 21.55051041], [74.02555847, 21.55261993], [74.04168701, 21.55134964], [74.04714966, 21.54968071], [74.0542984, 21.5521698], [74.05905914, 21.55568123], [74.05993652, 21.5560894], [74.06082916, 21.55652046], [74.0617218, 21.55695152], [74.06260681, 21.55738068], [74.06349945, 21.55779266], [74.06440735, 21.55817986], [74.06534576, 21.55852127], [74.06626892, 21.55886078], [74.06723022, 21.55914116], [74.06822205, 21.55937195], [74.06920624, 21.55950928], [74.06978607, 21.55953026], [74.07019043, 21.55953979], [74.07118988, 21.55953979], [74.07218933, 21.55953979], [74.07285309, 21.55953026], [74.07318115, 21.55953026], [74.07367706, 21.55952263], [74.07418823, 21.55949974], [74.07483673, 21.55948067], [74.07518768, 21.55945969], [74.07621002, 21.55941963], [74.07727051, 21.55933952], [74.07818604, 21.55927086], [74.07920837, 21.55919075], [74.08019257, 21.55907822], [74.08117676, 21.5589695], [74.08216095, 21.5588398], [74.08315277, 21.55869293], [74.08407593, 21.55842972], [74.08502197, 21.55804062], [74.08522797, 21.5579319], [74.08592987, 21.55758286], [74.08683014, 21.55714035], [74.08776855, 21.55677032], [74.08872223, 21.55657005], [74.08914185, 21.55657005], [74.08970642, 21.55656052], [74.09068298, 21.55655289], [74.09168243, 21.55657959], [74.09266663, 21.55661964], [74.09321594, 21.55665016], [74.09365082, 21.55668259], [74.09416199, 21.5567112], [74.0946579, 21.55673981], [74.09564972, 21.55682182], [74.0966568, 21.55690956], [74.09764862, 21.55700111], [74.09866333, 21.5571003], [74.09966278, 21.55721092], [74.10064697, 21.55731964], [74.10166931, 21.55742836], [74.10264587, 21.55754089], [74.10367584, 21.55763817], [74.10463715, 21.55774117], [74.10566711, 21.55784035], [74.10665894, 21.55792236], [74.10765839, 21.55798912], [74.10813904, 21.55801964], [74.10864258, 21.55804825], [74.10913849, 21.55808067], [74.10964203, 21.55811119], [74.11062622, 21.55813026], [74.11160278, 21.55815125], [74.11260986, 21.55815125], [74.11358643, 21.55809975], [74.11453247, 21.55783081], [74.11546326, 21.55744171], [74.11637115, 21.5569706], [74.11728668, 21.55652809], [74.11821747, 21.55615044], [74.11917114, 21.55590057], [74.12016296, 21.55586052], [74.12114716, 21.55584908], [74.12216949, 21.55590057], [74.12319183, 21.55598068], [74.1242218, 21.55607986], [74.12526703, 21.55622101], [74.12631989, 21.55636024], [74.12734985, 21.55649948], [74.12840271, 21.55665016], [74.12940979, 21.5567894], [74.13041687, 21.55689049], [74.13143921, 21.5569706], [74.13240051, 21.55701828], [74.13288116, 21.55701828], [74.13334656, 21.55702972], [74.13430786, 21.55698013], [74.1352005, 21.55688095], [74.13609314, 21.55669975], [74.13677216, 21.55623055], [74.13729858, 21.55548096], [74.1377182, 21.55450058], [74.13809967, 21.55348015], [74.1385498, 21.55251122], [74.13910675, 21.55173111], [74.13983917, 21.5512104], [74.14071655, 21.55085945], [74.14170074, 21.55060959], [74.14274597, 21.55046082], [74.14380646, 21.55038071], [74.14444733, 21.55035973], [74.14483643, 21.55034065], [74.14582825, 21.55034065], [74.14681244, 21.55038071], [74.14782715, 21.55045128], [74.14879608, 21.55056953], [74.14980316, 21.55070114], [74.15078735, 21.5508709], [74.15180206, 21.55105019], [74.15276337, 21.55122948], [74.1537323, 21.55143166], [74.15473938, 21.55171967], [74.15563965, 21.55212975], [74.15632629, 21.55273056], [74.15686035, 21.5535202], [74.15735626, 21.55438042], [74.15789795, 21.55517006], [74.15854645, 21.55587959], [74.15921021, 21.55665016], [74.15988922, 21.55741119], [74.16057587, 21.55813026], [74.16133118, 21.55875969], [74.16213989, 21.55927086], [74.16301727, 21.55960083], [74.16394806, 21.55986023], [74.16488647, 21.56010056], [74.16584778, 21.5603199], [74.16681671, 21.56052971], [74.1678009, 21.56072044], [74.16879272, 21.56088066], [74.16945648, 21.56098938], [74.1697998, 21.56104279], [74.17034149, 21.56112099], [74.17079926, 21.56118011], [74.17182159, 21.56132126], [74.17282104, 21.56142807], [74.17383575, 21.56153107], [74.17485809, 21.56161118], [74.1758728, 21.56167984], [74.17687988, 21.56175041], [74.1778717, 21.56178093], [74.17888641, 21.56182098], [74.17984772, 21.56183052], [74.18081665, 21.56183815], [74.18183136, 21.56176949], [74.18286896, 21.56155968], [74.18387604, 21.56121063], [74.18483734, 21.5607605], [74.18569183, 21.56021118], [74.18634033, 21.55960083], [74.1867981, 21.55887032], [74.18704987, 21.5580101], [74.18718719, 21.55706024], [74.18725586, 21.5560627], [74.18736267, 21.55505943], [74.18750763, 21.55409813], [74.18782806, 21.55321121], [74.18821716, 21.552351], [74.18863678, 21.55150032], [74.18910217, 21.55065918], [74.18933105, 21.55027962], [74.18961334, 21.54982758], [74.19011688, 21.54902267], [74.19068146, 21.54823112], [74.19122314, 21.54746819], [74.19184875, 21.54673958], [74.19251251, 21.54603958], [74.1932373, 21.5453701], [74.19391632, 21.54470825], [74.19464111, 21.54402924], [74.19532013, 21.54334068], [74.19595337, 21.54261971], [74.19654083, 21.54186058], [74.19711304, 21.54107285], [74.19758606, 21.5402298], [74.19801331, 21.53938103], [74.19831848, 21.53849983], [74.19850159, 21.53759956], [74.19860077, 21.5366497], [74.19866943, 21.53570938], [74.19869995, 21.5352211], [74.19873047, 21.53475952], [74.1987915, 21.53420067], [74.19882965, 21.53383064], [74.19890594, 21.53342056], [74.19901276, 21.53290939], [74.19930267, 21.53193855], [74.19969177, 21.53100014], [74.20030975, 21.53033829], [74.20115662, 21.5299511], [74.20211792, 21.52963066], [74.20314789, 21.52939034], [74.204216, 21.52924919], [74.20523834, 21.52921104], [74.20617676, 21.52930069], [74.2069397, 21.52975082], [74.20726013, 21.53009987], [74.20762634, 21.53050995], [74.20797729, 21.5309124], [74.20831299, 21.53128052], [74.20897675, 21.53168106], [74.20915222, 21.53178024], [74.21009064, 21.53211021], [74.21054077, 21.53222084], [74.21108246, 21.53236008], [74.21208954, 21.53261948], [74.21304321, 21.53293037], [74.21386719, 21.53334999], [74.21444702, 21.53405952], [74.21478271, 21.53508949], [74.21514893, 21.53600121], [74.21586609, 21.53647041], [74.21673584, 21.5367012], [74.21769714, 21.53685188], [74.21820831, 21.53689957], [74.21869659, 21.53693962], [74.21974182, 21.53698921], [74.22077942, 21.53703117], [74.2218399, 21.53707123], [74.22283173, 21.53716087], [74.22383118, 21.53730965], [74.2248764, 21.53745079], [74.22595215, 21.53762054], [74.2269516, 21.53787994], [74.2277832, 21.53827095], [74.22834015, 21.53890038], [74.22856903, 21.53982162], [74.22866058, 21.5408802], [74.22875977, 21.54187965], [74.22910309, 21.54269981], [74.22994995, 21.54304123], [74.23111725, 21.54305077], [74.23213196, 21.54322052], [74.23233032, 21.54356194], [74.2325058, 21.54387093], [74.2325058, 21.54482079], [74.2323761, 21.54588127], [74.23232269, 21.54691124], [74.23246765, 21.54737091], [74.23258972, 21.54771996], [74.23323822, 21.54833031], [74.23406982, 21.54883957], [74.23506927, 21.54924011], [74.23607635, 21.54959106], [74.23668671, 21.54976082], [74.23705292, 21.54985046], [74.23810577, 21.5501194], [74.23919678, 21.55029106], [74.24017334, 21.5502491], [74.24093628, 21.54989815], [74.24125671, 21.54951286], [74.24147797, 21.54919815], [74.24194336, 21.54829979], [74.24237061, 21.54730988], [74.24279022, 21.54640961], [74.2434082, 21.54574013], [74.24429321, 21.54549026], [74.24539185, 21.54556274], [74.24646759, 21.54561043], [74.24732208, 21.5452404], [74.24796295, 21.54462051], [74.2485733, 21.54391289], [74.24916077, 21.54314041], [74.24936676, 21.54282951], [74.24970245, 21.54232979], [74.25025177, 21.54150963], [74.25078583, 21.54068947], [74.25138092, 21.53989983], [74.25197601, 21.53915024], [74.25267029, 21.53844261], [74.25335693, 21.53770065], [74.25414276, 21.53701019], [74.25496674, 21.53646088], [74.25583649, 21.53611946], [74.25679779, 21.53595161], [74.2578125, 21.53580093], [74.2588501, 21.53564072], [74.25992584, 21.5354805], [74.26098633, 21.53534126], [74.26209259, 21.53520012], [74.26319122, 21.53510094], [74.26368713, 21.53507042], [74.26426697, 21.53502083], [74.26535034, 21.53499031], [74.26638031, 21.53499985], [74.26737213, 21.53507042], [74.26834106, 21.53517914], [74.26924133, 21.53536987], [74.27011108, 21.53563118], [74.27086639, 21.53597069], [74.27155304, 21.53642082], [74.27211761, 21.53701973], [74.27258301, 21.53775024], [74.27297974, 21.5385685], [74.27332306, 21.53950119], [74.27361298, 21.5404911], [74.27387238, 21.54150009], [74.27413177, 21.5425396], [74.27440643, 21.54356956], [74.27469635, 21.54455948], [74.27501678, 21.54552078], [74.2754364, 21.54639053], [74.27590942, 21.54718018], [74.27651215, 21.54780006], [74.27735138, 21.54816818], [74.27839661, 21.54833031], [74.27951813, 21.54841995], [74.28063202, 21.54850006], [74.28163147, 21.54868126], [74.2824173, 21.54906845], [74.28282166, 21.54981041], [74.28292084, 21.5508194], [74.28305817, 21.55185127], [74.28327179, 21.552351], [74.28343201, 21.55270958], [74.28396606, 21.5535202], [74.28460693, 21.55428123], [74.28534698, 21.5549202], [74.28617096, 21.55540085], [74.28656006, 21.55549049], [74.28713226, 21.55562973], [74.28819275, 21.55574989], [74.28916931, 21.5559597], [74.2899704, 21.55641174], [74.29052734, 21.55725288], [74.29103088, 21.55817032], [74.2917099, 21.55878067], [74.2926178, 21.55898094], [74.29360962, 21.55909157], [74.29464722, 21.55914116], [74.29516602, 21.55912971], [74.2957077, 21.55912971], [74.29633331, 21.55912018], [74.29677582, 21.55909157], [74.29785156, 21.55904007], [74.29892731, 21.55901909], [74.29995728, 21.55903244], [74.30052185, 21.55906105], [74.30095673, 21.55909157], [74.30190277, 21.55922127], [74.30275726, 21.55945969], [74.30354309, 21.55982018], [74.30409241, 21.56043053], [74.30451202, 21.56126976], [74.30478668, 21.5622406], [74.30504608, 21.56328011], [74.30523682, 21.56398964], [74.30532837, 21.56429291], [74.30568695, 21.56520081], [74.30623627, 21.56595993], [74.30706024, 21.56656265], [74.30805969, 21.56705284], [74.30909729, 21.56732178], [74.30996704, 21.56732178], [74.31066895, 21.56688118], [74.31127167, 21.56604958], [74.31175995, 21.56507111], [74.31212616, 21.56417084], [74.31246185, 21.56328964], [74.3127594, 21.56240082], [74.3130188, 21.56149101], [74.3132782, 21.56056023], [74.31346893, 21.55965042], [74.31363678, 21.55871964], [74.31369781, 21.55828285], [74.31378174, 21.55779266], [74.3138504, 21.55685043], [74.31387329, 21.55655289], [74.31391144, 21.55589104], [74.3139801, 21.5549202], [74.31401062, 21.55395126], [74.31401062, 21.55298042], [74.31401825, 21.55200958], [74.31402588, 21.55103111], [74.31404877, 21.55055046], [74.3140564, 21.55006981], [74.31410217, 21.54911995], [74.3141861, 21.54818153], [74.31430054, 21.54726982], [74.31443024, 21.54636955], [74.31461334, 21.54551125], [74.31484985, 21.54466248], [74.31520081, 21.54385948], [74.31581879, 21.54317093], [74.31665802, 21.54259109], [74.31764984, 21.54211998], [74.31867218, 21.54175949], [74.31968689, 21.54152107], [74.32064819, 21.54137039], [74.32161713, 21.54125023], [74.32260895, 21.54117966], [74.32357788, 21.54113007], [74.32406616, 21.54112053], [74.32457733, 21.54111099], [74.32559204, 21.54109955], [74.32659149, 21.54111099], [74.32727051, 21.54112053], [74.32762146, 21.54112053], [74.32861328, 21.54115105], [74.32962036, 21.54116058], [74.33065033, 21.54117966], [74.33164978, 21.54117966], [74.33274078, 21.54116058], [74.33551788, 21.5402298], [74.33335876, 21.51980972], [74.3320694, 21.51402092], [74.33165741, 21.51222992], [74.33125305, 21.51037979], [74.33082581, 21.50855064], [74.33039093, 21.50672913], [74.32995605, 21.50488281], [74.32950592, 21.50306129], [74.32907104, 21.50123024], [74.32859802, 21.49939919], [74.32821655, 21.4975605], [74.32772064, 21.49575043], [74.32624054, 21.49454117], [74.32443237, 21.4937706], [74.32253265, 21.49319267], [74.32061005, 21.4926796], [74.3187027, 21.49217033], [74.31678009, 21.49156952], [74.31497955, 21.49078178], [74.3134079, 21.48962021], [74.31236267, 21.48805809], [74.31173706, 21.48625946], [74.31125641, 21.48443985], [74.31057739, 21.48266029], [74.30943298, 21.48118019], [74.30776215, 21.48011971], [74.30591583, 21.4793911], [74.30400848, 21.47887039], [74.30204773, 21.47850037], [74.30005646, 21.47824097], [74.29807281, 21.4780407], [74.2960968, 21.47788048], [74.2940979, 21.47774124], [74.29210663, 21.4776001], [74.29013062, 21.47747993], [74.28811646, 21.4773407], [74.28613281, 21.47717285], [74.28414154, 21.47696114], [74.28217316, 21.47672081], [74.28018188, 21.47649956], [74.27819824, 21.47631073], [74.27620697, 21.4761219], [74.27423096, 21.47590065], [74.27224731, 21.47562027], [74.27028656, 21.47525024], [74.26837921, 21.47473907], [74.26654053, 21.47402], [74.26502991, 21.47284126], [74.26454926, 21.47101021], [74.26439667, 21.46915245], [74.26415253, 21.46729279], [74.26319122, 21.46570015], [74.26138306, 21.46491051], [74.2594986, 21.46426964], [74.25759125, 21.46375084], [74.25563812, 21.46333122], [74.25367737, 21.4630394], [74.2516861, 21.46286964], [74.24967194, 21.46286964], [74.24769592, 21.46310043], [74.24581909, 21.46370125], [74.24430084, 21.46491051], [74.24333191, 21.46653938], [74.24269104, 21.46831131], [74.24215698, 21.47013283], [74.24169922, 21.47195053], [74.24121094, 21.47376823], [74.24059296, 21.47555923], [74.23873138, 21.47841263], [74.23696136, 21.4792881], [74.23501587, 21.47970772], [74.23303223, 21.47986984], [74.23103333, 21.47982025], [74.22904968, 21.47960091], [74.22709656, 21.4791584], [74.22525024, 21.47846031], [74.22374725, 21.47726059], [74.22303009, 21.47552109], [74.22290039, 21.47365952], [74.22302246, 21.47178268], [74.22323608, 21.46990967], [74.22350311, 21.46805954], [74.22373199, 21.46618271], [74.22383118, 21.4643116], [74.22376251, 21.46241951], [74.22358704, 21.46056747], [74.22263336, 21.4589901], [74.22065735, 21.45877838], [74.21868896, 21.45895004], [74.21671295, 21.45927048], [74.21475983, 21.4596405], [74.21279144, 21.45998001], [74.21082306, 21.46018982], [74.2088089, 21.46014023], [74.20684052, 21.45988083], [74.20485687, 21.45959091], [74.20287323, 21.45944023], [74.20091248, 21.45969963], [74.19940186, 21.46090126], [74.19815063, 21.46236038], [74.19661713, 21.46355247], [74.19497681, 21.4646492], [74.19328308, 21.46562195], [74.19145203, 21.46636963], [74.1894989, 21.46681023], [74.18752289, 21.46702957], [74.18553925, 21.46702194], [74.18395996, 21.46590042], [74.18274689, 21.46442032], [74.18154907, 21.46291924], [74.18017578, 21.4615612], [74.1783371, 21.46087074], [74.17650604, 21.46145058], [74.17507172, 21.46273994], [74.17325592, 21.46352005], [74.17128754, 21.46371078], [74.16931915, 21.4634304], [74.16786957, 21.46222115], [74.16723633, 21.46044159], [74.16664124, 21.4586525], [74.1652298, 21.4574604], [74.16322327, 21.45759964], [74.16159821, 21.45683098], [74.16127777, 21.4549675], [74.16046906, 21.45335007], [74.15847015, 21.45308113], [74.15648651, 21.45313072], [74.15450287, 21.45334053], [74.15252686, 21.45360947], [74.1505661, 21.45388985], [74.14858246, 21.45409012], [74.14659119, 21.45428085], [74.14465332, 21.45471954], [74.14318085, 21.45593071], [74.14258575, 21.4577198], [74.14187622, 21.46099091], [74.14076996, 21.46249008], [74.13887024, 21.4630394], [74.1368866, 21.46339035], [74.13491058, 21.46360016], [74.13292694, 21.46370125], [74.1309433, 21.46367073], [74.12892151, 21.46352005], [74.12697601, 21.46320152], [74.12506104, 21.46267128], [74.12332916, 21.46170998], [74.122612, 21.46000099], [74.12255859, 21.45812988], [74.12269592, 21.45625114], [74.1228714, 21.45438004], [74.12290192, 21.45251274], [74.12245941, 21.45070076], [74.12081909, 21.4496994], [74.11885834, 21.4493084], [74.11688995, 21.44896126], [74.1149292, 21.44861031], [74.11297607, 21.44831085], [74.11097717, 21.44810104], [74.1089859, 21.44802284], [74.106987, 21.44812012], [74.10560608, 21.44922066], [74.10558319, 21.45108986], [74.10536194, 21.45293999], [74.10372925, 21.45388985], [74.10175323, 21.45420074], [74.09976959, 21.45449066], [74.09778595, 21.45474052], [74.09581757, 21.45500946], [74.09382629, 21.45524025], [74.09185791, 21.45548058], [74.0898819, 21.4557209], [74.08789825, 21.45597076], [74.08592224, 21.45625114], [74.08394623, 21.45652962], [74.08197784, 21.45684052], [74.08001709, 21.45720291], [74.07814789, 21.45781136], [74.07704926, 21.45934105], [74.0770874, 21.46121025], [74.07740784, 21.46305847], [74.07758331, 21.46494293], [74.07752228, 21.46681023], [74.07740021, 21.46867943], [74.07701111, 21.47051811], [74.07624054, 21.47224808], [74.07527161, 21.4738903], [74.07418823, 21.47546959], [74.07301331, 21.47698021], [74.07176971, 21.47845078], [74.07042694, 21.47986031], [74.06891632, 21.48106956], [74.06716156, 21.48193169], [74.06598663, 21.4811306], [74.06642914, 21.47930145], [74.06665802, 21.47744179], [74.06648254, 21.47557068], [74.06616974, 21.47372055], [74.06569672, 21.47190094], [74.06497192, 21.47014999], [74.06413269, 21.46842957], [74.0632782, 21.4667511], [74.0623703, 21.46508026], [74.06082916, 21.46236992], [74.05988312, 21.4607296], [74.05893707, 21.45907021], [74.0580368, 21.45738983], [74.05716705, 21.45570946], [74.05634308, 21.45399094], [74.05565643, 21.45223999], [74.05513, 21.45041847], [74.05471802, 21.44860077], [74.05444336, 21.44672966], [74.05432129, 21.44485092], [74.05426025, 21.44297028], [74.05417633, 21.44110107], [74.05396271, 21.43923187], [74.05371094, 21.4373703], [74.05343628, 21.43551064], [74.05316925, 21.43366051], [74.05285645, 21.4317894], [74.05251312, 21.42995071], [74.05208588, 21.42811012], [74.05162811, 21.42628098], [74.05110168, 21.42448997], [74.05046082, 21.42270088], [74.0496521, 21.42098045], [74.04854584, 21.41942978], [74.04679108, 21.41852188], [74.04479218, 21.41852951], [74.04280853, 21.41876984], [74.04081726, 21.41896057], [74.03885651, 21.41930008], [74.03690338, 21.41966057], [74.03491211, 21.41981125], [74.03292084, 21.41958046], [74.03098297, 21.41916084], [74.02908325, 21.41862106], [74.0271759, 21.41804123], [74.0252533, 21.41751099], [74.02332306, 21.41710091], [74.02133942, 21.4170208], [74.01959991, 21.41798019], [74.0177002, 21.41855812], [74.01579285, 21.41798019], [74.0140686, 21.41703033], [74.01251984, 21.41584015], [74.01107788, 21.4145298], [74.00949097, 21.41337013], [74.00765991, 21.41257286], [74.00547791, 21.4118309], [73.98883057, 21.40448952], [73.98529053, 21.40191078], [73.98155975, 21.39733124], [73.97741699, 21.39496994], [73.97193909, 21.39479828], [73.96869659, 21.39206123], [73.96193695, 21.39311028], [73.95545959, 21.4025383], [73.95284271, 21.40237045], [73.95562744, 21.39001083], [73.95530701, 21.37425995], [73.95658875, 21.36161041], [73.95700836, 21.3444519], [73.9519577, 21.33060074], [73.95127869, 21.31500816], [73.95015717, 21.30805016], [73.94992065, 21.30658913], [73.94848633, 21.2975502], [73.93358612, 21.28532982], [73.92354584, 21.28101921], [73.89199066, 21.26241112], [73.88432312, 21.26263046], [73.87174225, 21.26737976], [73.85840607, 21.26995087], [73.83213806, 21.26745033], [73.83223724, 21.25830269], [73.83650208, 21.245821], [73.83634949, 21.24234009], [73.8274765, 21.23314095], [73.82316589, 21.22756958], [73.82013702, 21.22186089], [73.81841278, 21.21372032], [73.81859589, 21.20857048], [73.81877899, 21.20385933], [73.81951141, 21.19960976], [73.82134247, 21.19532013], [73.83405304, 21.19719124], [73.83590698, 21.19518089], [73.83232117, 21.1853981], [73.83048248, 21.18439293], [73.82917786, 21.18234062], [73.82254791, 21.17192078], [73.81793976, 21.17143822], [73.81212616, 21.17206764], [73.80753326, 21.1746006], [73.80253601, 21.1785717], [73.79631042, 21.18173027], [73.7911377, 21.17622948], [73.78975677, 21.16867828], [73.78720093, 21.1663208], [73.78366089, 21.16506004], [73.77966309, 21.16455269], [73.75306702, 21.16818047], [73.74162292, 21.16711044], [73.7407608, 21.16039848], [73.74619293, 21.15483093], [73.74797058, 21.15153122], [73.74603271, 21.14760971], [73.74318695, 21.1468029], [73.73983765, 21.14016151], [73.73668671, 21.13828087], [73.72235107, 21.13924026], [73.71707153, 21.1417408], [73.71517944, 21.14310074], [73.7131958, 21.1504612], [73.69824219, 21.15011024], [73.68943024, 21.15116119], [73.68131256, 21.15212059], [73.67460632, 21.15102005], [73.67150879, 21.14513969], [73.63639832, 21.13265991], [73.63897705, 21.14734077], [73.63745117, 21.15313911], [73.61969757, 21.15794945], [73.61470032, 21.16348076], [73.61384583, 21.16797066], [73.61418915, 21.17245102], [73.61316681, 21.17605972], [73.60991669, 21.17667961], [73.60691833, 21.17846107], [73.59819794, 21.17472076], [73.58830261, 21.16790009], [73.58875275, 21.16086006], [73.58751678, 21.15674019], [73.58879852, 21.15419006], [73.59229279, 21.15294075], [73.59667969, 21.15273094], [73.60027313, 21.15433121], [73.60491943, 21.15505981], [73.61147308, 21.15446091], [73.61258698, 21.15219116], [73.61345673, 21.15043068], [73.61422729, 21.14698029], [73.61885071, 21.14417267], [73.62908173, 21.14166069], [73.62634277, 21.1398201], [73.62359619, 21.13799095], [73.62872314, 21.12014961], [73.63802338, 21.12170982], [73.64546204, 21.12295914], [73.64924622, 21.12274933], [73.6530304, 21.12254143], [73.65537262, 21.12179947], [73.6577301, 21.12104988], [73.65994263, 21.10837936], [73.67890167, 21.10925102], [73.68937683, 21.10598946], [73.69338989, 21.1009903], [73.70323944, 21.10896111], [73.71058655, 21.11902237], [73.70897675, 21.11234093], [73.71478271, 21.10719109], [73.7358017, 21.10322952], [73.7388916, 21.1013298], [73.74337006, 21.10824966], [73.75260925, 21.11408997], [73.74946594, 21.1077404], [73.73906708, 21.0948391], [73.74046326, 21.08486938], [73.74224091, 21.08156967], [73.744133, 21.08167076], [73.74079895, 21.07287025], [73.74373627, 21.0641613], [73.7421875, 21.05550003], [73.747612, 21.03997993], [73.7569809, 21.03917122], [73.76300049, 21.03864098], [73.7660675, 21.04005051], [73.7756424, 21.02760124], [73.77392578, 21.0216198], [73.76944733, 21.01452065], [73.77485657, 21.01045036], [73.78470612, 21.0195694], [73.79382324, 21.01976967], [73.80770111, 21.02255821], [73.81208038, 21.01066017], [73.81404877, 21.00080109], [73.81640625, 20.99605179], [73.82050323, 20.99504089], [73.82752991, 20.99607086], [73.83769226, 20.99483109], [73.84078217, 20.99313927], [73.84683228, 20.99398994], [73.85012817, 21.00141907], [73.8537674, 20.99911118], [73.85721588, 20.99770927], [73.87268829, 20.99073029], [73.87918854, 20.98647118], [73.89863586, 20.98222923], [73.90644836, 20.98315048], [73.91116333, 20.97542953], [73.91396332, 20.96996117], [73.91538239, 20.96482086], [73.91123199, 20.96235275], [73.9017868, 20.96170044], [73.89694214, 20.95255089], [73.89509583, 20.94652176], [73.89501953, 20.94013977], [73.89633942, 20.93300056], [73.90396118, 20.92536926], [73.90956116, 20.92140007], [73.91221619, 20.91794014], [73.91681671, 20.91505051], [73.92032623, 20.91123009], [73.92273712, 20.90774918], [73.92443848, 20.90283966], [73.92732239, 20.89911079], [73.9310379, 20.88591766], [73.93123627, 20.8766098], [73.92967987, 20.86887169], [73.9316864, 20.86473274], [73.93013, 20.86011124], [73.9315567, 20.85250282], [73.93106079, 20.84839058], [73.93373108, 20.8449707], [73.93589783, 20.8434391], [73.94509888, 20.84013176], [73.94760895, 20.82939911], [73.94763947, 20.82509041], [73.94626617, 20.81867027], [73.94019318, 20.80886078], [73.94114685, 20.80378151], [73.93811798, 20.78967094], [73.94056702, 20.76885986], [73.93834686, 20.76078987], [73.9471817, 20.76078033], [73.94750214, 20.75247002], [73.94523621, 20.74929047], [73.94845581, 20.74670029], [73.94953156, 20.74230957], [73.93596649, 20.73150063], [73.93506622, 20.73461914], [73.92756653, 20.73044014], [73.92090607, 20.72352982], [73.90875244, 20.72522926], [73.90379333, 20.73064041], [73.88886261, 20.73108101], [73.88556671, 20.72961044], [73.88194275, 20.72687912], [73.87728119, 20.72133064], [73.87362671, 20.7077198], [73.86360168, 20.6942997], [73.84275818, 20.70211983], [73.83917999, 20.70190048], [73.83362579, 20.69960976], [73.82874298, 20.69646072], [73.82264709, 20.69382095], [73.82543182, 20.67361832], [73.83425903, 20.67353821], [73.84150696, 20.67513847], [73.84535217, 20.66707039], [73.84707642, 20.65636253], [73.8434906, 20.65032959], [73.84310913, 20.64441109], [73.84641266, 20.6235199], [73.83828735, 20.6157608], [73.83390808, 20.61412048], [73.83068848, 20.61491966], [73.82538605, 20.61401939], [73.81656647, 20.60936928], [73.80596161, 20.60152054], [73.80237579, 20.60579109], [73.79273224, 20.60431099], [73.78705597, 20.60225868], [73.78135681, 20.59507942], [73.77997589, 20.59185982], [73.7756958, 20.58876038], [73.76906586, 20.58716965], [73.76394653, 20.58333015], [73.74820709, 20.56735992], [73.74154663, 20.57261848], [73.73766327, 20.57398987], [73.72902679, 20.5741291], [73.72428131, 20.57580185], [73.71985626, 20.57632065], [73.70964813, 20.57450294], [73.70101929, 20.57838058], [73.69243622, 20.57534981], [73.68550873, 20.57168961], [73.68136597, 20.56767082], [73.67617798, 20.56415939], [73.6707077, 20.56233978], [73.66584015, 20.5628109], [73.6618576, 20.56574059], [73.65705109, 20.57219124], [73.65093994, 20.57641029], [73.64710236, 20.57749939], [73.64328766, 20.57715988], [73.63949585, 20.57790947], [73.63677216, 20.57929039], [73.63448334, 20.58229065], [73.63506317, 20.59165955], [73.63217163, 20.60223961], [73.63038635, 20.60602951], [73.62948608, 20.61230087], [73.62594604, 20.62111092], [73.62219238, 20.62529945], [73.60730743, 20.63630104], [73.60275269, 20.63786125], [73.59120941, 20.64511108], [73.58418274, 20.64789963], [73.57419586, 20.65105057], [73.56732941, 20.64791107], [73.5629425, 20.64739037], [73.55365753, 20.65533066], [73.54476166, 20.6692009], [73.53837585, 20.67386055], [73.53040314, 20.6731205], [73.52697754, 20.67012978], [73.52516174, 20.66714287], [73.51998901, 20.66633987], [73.51780701, 20.67014122], [73.5123291, 20.66302109], [73.50788116, 20.65864944], [73.50087738, 20.65274048], [73.49843597, 20.65341949], [73.49547577, 20.66269112], [73.49336243, 20.66555977], [73.49250793, 20.66843033], [73.4895401, 20.66963959], [73.48777771, 20.67212105], [73.4874115, 20.67555046], [73.48918915, 20.67850113], [73.49205017, 20.68033028], [73.4972229, 20.6809597], [73.49729156, 20.6860199], [73.49375916, 20.68952942], [73.49336243, 20.6942997], [73.48873901, 20.70660019], [73.48416901, 20.70907021], [73.48261261, 20.71722984], [73.48049927, 20.71965027], [73.47518921, 20.72167015], [73.45868683, 20.71431923], [73.4536972, 20.7104702], [73.44729614, 20.70111084], [73.45654297, 20.69339943], [73.45452881, 20.68605042], [73.45288086, 20.68300056], [73.4500885, 20.68075943], [73.443573, 20.6779995], [73.44325256, 20.67437935], [73.43991852, 20.6648407], [73.43551636, 20.66237259], [73.43035889, 20.66088104], [73.41916656, 20.66047096], [73.41752625, 20.65789032], [73.41496277, 20.65604019], [73.40983582, 20.65501022], [73.40364838, 20.65237045], [73.40158081, 20.64920998], [73.40273285, 20.64259911], [73.41134644, 20.63858032], [73.414711, 20.63570023], [73.41797638, 20.63047028], [73.41512299, 20.62805939], [73.41596222, 20.62616158], [73.42764282, 20.62449074], [73.43078613, 20.62053108], [73.43382263, 20.61471939], [73.43908691, 20.60126114], [73.4375, 20.59747124], [73.44036102, 20.59511948], [73.45482635, 20.59458923], [73.46855927, 20.58876991], [73.47670746, 20.58630943], [73.4808197, 20.58359909], [73.4837265, 20.57843018], [73.48584747, 20.56405067], [73.48179626, 20.54335976], [73.49327087, 20.54220009], [73.50074005, 20.54024124], [73.49729919, 20.53622246], [73.48474121, 20.52570915], [73.47690582, 20.52203751], [73.47380829, 20.51531982], [73.47226715, 20.51404953], [73.47413635, 20.50106049], [73.47593689, 20.49501991], [73.46983337, 20.49233055], [73.46669769, 20.48830032], [73.46523285, 20.48415947], [73.46109009, 20.47813034], [73.45594025, 20.47537041], [73.45204163, 20.47140121], [73.44901276, 20.4666996], [73.43792725, 20.44572258], [73.43585968, 20.43606949], [73.43080902, 20.42881966], [73.42928314, 20.41996956], [73.42974091, 20.41439056], [73.42288971, 20.41432953], [73.41633606, 20.41065979], [73.41583252, 20.40619087], [73.41461182, 20.40566063], [73.41306305, 20.40784836], [73.40879059, 20.40422058], [73.40952301, 20.40134811], [73.40762329, 20.39628983], [73.39772797, 20.39923286], [73.39550781, 20.39801979], [73.39134979, 20.39019966], [73.39025116, 20.3801899], [73.39157867, 20.37289047], [73.39454651, 20.3729496], [73.39807892, 20.3747406], [73.40310669, 20.3817997], [73.4076767, 20.38392067], [73.41200256, 20.38352966], [73.41478729, 20.38157082], [73.42173767, 20.35560036], [73.4234314, 20.35209084], [73.42373657, 20.34181023], [73.42539978, 20.33767128], [73.42531586, 20.32072067], [73.42611694, 20.31592941], [73.42854309, 20.31191063], [73.43076324, 20.29804993], [73.43694305, 20.28212166], [73.436203, 20.27902031], [73.42462158, 20.27683067], [73.42314148, 20.27368927], [73.42442322, 20.26914024], [73.42180634, 20.26356125], [73.42041016, 20.25699997], [73.42160797, 20.25371933], [73.42227936, 20.24809074], [73.42032623, 20.24228096], [73.42280579, 20.23676109], [73.42237854, 20.23176193], [73.42607117, 20.22359848], [73.42788696, 20.21543121], [73.43031311, 20.21232033], [73.42991638, 20.20623016], [73.42682648, 20.20157051], [73.41681671, 20.20030975], [73.40920258, 20.20049095], [73.4054718, 20.19796944], [73.40281677, 20.19502068], [73.39807892, 20.19600105], [73.39626312, 20.20163155], [73.39736176, 20.20594025], [73.39528656, 20.20916939], [73.38851929, 20.20630074], [73.38366699, 20.20239067], [73.37632751, 20.20532036], [73.37528992, 20.20290947], [73.37594604, 20.19497108], [73.37431335, 20.19265938], [73.36691284, 20.19634056], [73.3647995, 20.20099831], [73.36760712, 20.20940018], [73.36923981, 20.21170807], [73.36759949, 20.21337128], [73.36178589, 20.21198845], [73.35930634, 20.20911026], [73.35721588, 20.20249939], [73.35481262, 20.1996212], [73.35285187, 20.19847107], [73.34806061, 20.1990509], [73.33642578, 20.20409966], [73.32787323, 20.20249939], [73.32047272, 20.20433235], [73.31416321, 20.20767021], [73.3111496, 20.20721054], [73.29821777, 20.19616127], [73.2948761, 20.19621086], [73.29405975, 20.19386101], [73.29374695, 20.18597984], [73.29073334, 20.177351], [73.29065704, 20.17440987], [73.29321289, 20.16216087], [73.29363251, 20.15388107], [73.28907776, 20.14956284], [73.28347015, 20.14575958], [73.26846313, 20.13928986], [73.2649765, 20.13376045], [73.26280975, 20.12795067], [73.2612915, 20.12559128], [73.25946808, 20.12463951], [73.25614929, 20.12788963], [73.25361633, 20.12852097], [73.24391937, 20.12903976], [73.23812103, 20.12811089], [73.23667908, 20.1297226], [73.23690796, 20.13692284], [73.23548889, 20.14099121], [73.23264313, 20.1406002], [73.23046875, 20.13771057], [73.22952271, 20.13315964], [73.23033142, 20.12816048], [73.22672272, 20.12257957], [73.22148895, 20.12079811], [73.21631622, 20.12199974], [73.21095276, 20.12360001], [73.20069122, 20.12969971], [73.19597626, 20.13994026], [73.19532776, 20.15093994], [73.19609833, 20.15611267], [73.19924164, 20.16164017], [73.21775055, 20.16813278], [73.2220993, 20.17142105], [73.22673035, 20.17636108], [73.22833252, 20.18009949], [73.22915649, 20.18429947], [73.2277832, 20.18704987], [73.21936798, 20.19043922], [73.21615601, 20.19278908], [73.20993042, 20.19735146], [73.20440674, 20.19832039], [73.19586945, 20.19752121], [73.19132996, 20.19860268], [73.1885376, 20.20062065], [73.18113708, 20.20240021], [73.18017578, 20.20860863], [73.17298126, 20.20132065], [73.16895294, 20.19968987], [73.16351318, 20.20146942], [73.15364075, 20.20222092], [73.15284729, 20.2027607], [73.15223694, 20.20318985], [73.14981842, 20.20560074], [73.14575195, 20.20697975], [73.1421814, 20.20438957], [73.14157104, 20.20186996], [73.14602661, 20.18739128], [73.14839935, 20.18548012], [73.15213013, 20.17974281], [73.1523819, 20.17605972], [73.15007019, 20.17284012], [73.14702606, 20.17105293], [73.13947296, 20.1731205], [73.13582611, 20.17231941], [73.13260651, 20.16777039], [73.12606049, 20.16362762], [73.12555695, 20.16109276], [73.12802887, 20.15711975], [73.12494659, 20.15666008], [73.12259674, 20.15775108], [73.11974335, 20.15906906], [73.1167984, 20.15879059], [73.11302948, 20.1584301], [73.10910034, 20.15920067], [73.10514069, 20.15996933], [73.10334015, 20.16134834], [73.10182953, 20.16410828], [73.0994873, 20.17257118], [73.09790802, 20.17334938], [73.09616089, 20.17424011], [73.09348297, 20.17389107], [73.08991241, 20.17043114], [73.08790588, 20.16575813], [73.08648682, 20.1570015], [73.08244324, 20.15658951], [73.07553101, 20.16007996], [73.07244873, 20.16345024], [73.07422638, 20.17728043], [73.07435608, 20.19252014], [73.07303619, 20.19613075], [73.07048035, 20.19737053], [73.0703125, 20.19745064], [73.0666275, 20.19787979], [73.0642395, 20.20316124], [73.07036591, 20.22145081], [73.07685852, 20.22980118], [73.08187866, 20.23281288], [73.0875473, 20.23397255], [73.10192871, 20.22894287], [73.110466, 20.23213005], [73.10852051, 20.23855019], [73.11331177, 20.24418068], [73.12458038, 20.25671959], [73.1280365, 20.25850105], [73.13684845, 20.26046944], [73.14095306, 20.26523018], [73.14260101, 20.26863098], [73.14270782, 20.27528954], [73.14628601, 20.28053093], [73.1469574, 20.28104973], [73.14987183, 20.28012276], [73.15254211, 20.27667999], [73.15355682, 20.2770195], [73.1542511, 20.27934837], [73.15513611, 20.28236008], [73.15519714, 20.28541946], [73.15625763, 20.28742981], [73.15820313, 20.29048157], [73.16129303, 20.29179192], [73.1654129, 20.28703117], [73.16680145, 20.28341103], [73.1690979, 20.28231812], [73.17195129, 20.28250122], [73.17578888, 20.28417015], [73.17887878, 20.28646088], [73.17954254, 20.28986168], [73.17698669, 20.30088043], [73.17710876, 20.30759811], [73.17753601, 20.30907059], [73.17801666, 20.31071091], [73.17710114, 20.31232262], [73.17073822, 20.31052971], [73.16838074, 20.31380081], [73.16551971, 20.31592941], [73.16139984, 20.31719017], [73.15242004, 20.31747055], [73.14731598, 20.31682968], [73.1417923, 20.31746101], [73.14015198, 20.31468964], [73.13931274, 20.30957985], [73.1342926, 20.30532837], [73.1291275, 20.30578041], [73.11566162, 20.30404091], [73.11286926, 20.30494118], [73.11440277, 20.3106308], [73.11650848, 20.31270981], [73.11888123, 20.32620049], [73.12195587, 20.33287811], [73.12145996, 20.3364296], [73.11801147, 20.34287071], [73.11638641, 20.34716034], [73.11425018, 20.35279083], [73.11138153, 20.35609818], [73.1073761, 20.36071014], [73.10542297, 20.36054039], [73.10338593, 20.3603611], [73.10253143, 20.35967064], [73.10212708, 20.35845947], [73.10132599, 20.35603905], [73.09916687, 20.33993912], [73.09741211, 20.33509827], [73.09089661, 20.32683945], [73.08863068, 20.32648277], [73.08628845, 20.32611084], [73.08273315, 20.32912064], [73.07525635, 20.3296299], [73.07151031, 20.32716942], [73.06668091, 20.32608032], [73.06204224, 20.32574081], [73.05512238, 20.32524109], [73.05047607, 20.32299805], [73.04767609, 20.31661034], [73.0475769, 20.3044529], [73.04586029, 20.29243279], [73.04416656, 20.2911129], [73.04197693, 20.2902298], [73.03726959, 20.29059982], [73.02979279, 20.29226112], [73.02651978, 20.29412079], [73.02696228, 20.30380058], [73.02469635, 20.31279945], [73.02226257, 20.31585121], [73.01983643, 20.31739807], [73.01760101, 20.31549263], [73.02053833, 20.30751991], [73.02056885, 20.30207825], [73.02217102, 20.29706955], [73.02179718, 20.2927475], [73.02049255, 20.29090118], [73.01728821, 20.29053116], [73.01048279, 20.29236984], [73.00357056, 20.29314041], [72.99046326, 20.29208946], [72.98947144, 20.27753067], [72.98779297, 20.27466965], [72.98409271, 20.27168083], [72.98005676, 20.27075005], [72.9744873, 20.27178001], [72.96977997, 20.27474022], [72.95749664, 20.28770065], [72.95078278, 20.2920208], [72.94597626, 20.29343033], [72.94142151, 20.29212761], [72.93811035, 20.28800964], [72.930336, 20.28397942], [72.92459106, 20.27865982], [72.92230988, 20.27440071], [72.92375183, 20.26819992], [72.9408493, 20.24682045], [72.94367218, 20.24488068], [72.95146942, 20.24357033], [72.95778656, 20.24115181], [72.96534729, 20.23718071], [72.96962738, 20.23394012], [72.9744873, 20.22583961], [72.97543335, 20.21920013], [72.97437286, 20.21497154], [72.97042847, 20.21232986], [72.96924591, 20.2109108], [72.96082306, 20.21404076], [72.95101929, 20.21598053], [72.94181061, 20.21780968], [72.92842865, 20.2233696], [72.92218781, 20.22359848], [72.91680908, 20.22476959], [72.91086578, 20.22606087], [72.90538025, 20.22623253], [72.89984131, 20.22167015], [72.88873291, 20.22582054], [72.88432312, 20.22657967], [72.87454224, 20.2258091], [72.87188721, 20.22256088], [72.87287903, 20.21251106], [72.87200165, 20.20824051], [72.86438751, 20.20862961], [72.85508728, 20.20911026], [72.85028839, 20.20794106], [72.846138, 20.20356941], [72.8441391, 20.19779015], [72.84571838, 20.19413948], [72.84905243, 20.19094276], [72.84967041, 20.18925095], [72.84352112, 20.19004059], [72.84220123, 20.18886948], [72.83725739, 20.18868065], [72.83553314, 20.18766022], [72.8346405, 20.18577003], [72.83361816, 20.18357086], [72.82884216, 20.15657043], [72.83416748, 20.14973068], [72.83534241, 20.14464188], [72.83229828, 20.14402008], [72.82604218, 20.14628029], [72.81585693, 20.15328026], [72.81195068, 20.15242004], [72.80912781, 20.15180016], [72.80536652, 20.15003014], [72.80206299, 20.14846992], [72.80148315, 20.14711761], [72.80066681, 20.14526939], [72.8012619, 20.13780975], [72.80519867, 20.12701035], [72.80352783, 20.12601089], [72.80184937, 20.12501907], [72.79447174, 20.12817955], [72.78761292, 20.13008118], [72.7745285, 20.13080025], [72.7618103, 20.13149834], [72.7546463, 20.13303947], [72.74830627, 20.13441086], [72.74106598, 20.13595963], [72.73764038, 20.13653946], [72.73764038, 20.13736153], [72.73792267, 20.13735962], [72.73792267, 20.13820076], [72.73819733, 20.13819695], [72.73819733, 20.13958359], [72.73847198, 20.13958359], [72.73847198, 20.14069366], [72.73874664, 20.14068985], [72.73874664, 20.14236259], [72.73902893, 20.14236259], [72.73902893, 20.14375114], [72.73929596, 20.14375114], [72.73929596, 20.14542007], [72.73958588, 20.14541626], [72.73958588, 20.14708328], [72.73986053, 20.14708328], [72.73986053, 20.14875031], [72.74014282, 20.14874077], [72.74014282, 20.15014076], [72.74041748, 20.15013885], [72.74041748, 20.15319443], [72.74069214, 20.15319443], [72.74069214, 20.15847206], [72.74041748, 20.15847015], [72.74041748, 20.15903091], [72.74069214, 20.15903091], [72.74069214, 20.15930939], [72.7409668, 20.15930939], [72.7409668, 20.16014099], [72.74124908, 20.16013908], [72.74124908, 20.16374969], [72.74153137, 20.16374969], [72.74153137, 20.16430473], [72.74180603, 20.16430473], [72.74180603, 20.16486168], [72.74208069, 20.16486168], [72.74208069, 20.16847229], [72.74236298, 20.16846848], [72.74236298, 20.16930962], [72.74263763, 20.16930962], [72.74263763, 20.17124939], [72.74291992, 20.17124939], [72.74291992, 20.17236137], [72.74319458, 20.17236137], [72.74319458, 20.17819405], [72.74291992, 20.17819023], [72.74291992, 20.17985916], [72.74263763, 20.17985916], [72.74263763, 20.18292046], [72.74291992, 20.18291664], [72.74291992, 20.18347168], [72.74318695, 20.18347168], [72.74318695, 20.18403053], [72.74346924, 20.18402863], [72.74346924, 20.18458366], [72.74375153, 20.18458176], [72.74375153, 20.1854229], [72.74402618, 20.1854229], [72.74402618, 20.18625069], [72.74430847, 20.18625069], [72.74430847, 20.18680954], [72.74458313, 20.18680573], [72.74458313, 20.1879158], [72.74485779, 20.18791008], [72.74485779, 20.18902969], [72.74514008, 20.18902779], [72.74514008, 20.1898613], [72.7454071, 20.18985939], [72.7454071, 20.19153023], [72.74569702, 20.19153023], [72.74569702, 20.19292068], [72.74597168, 20.19291878], [72.74597168, 20.19708252], [72.74624634, 20.19708252], [72.74624634, 20.19847107], [72.74652863, 20.19847107], [72.74652863, 20.19958305], [72.74680328, 20.19958305], [72.74680328, 20.19986153], [72.7470932, 20.19985008], [72.7470932, 20.20070076], [72.74736023, 20.20069313], [72.74736023, 20.2009716], [72.74764252, 20.2009697], [72.74764252, 20.20125008], [72.74791718, 20.20125008], [72.74791718, 20.20153046], [72.74819183, 20.20153046], [72.74819183, 20.20430946], [72.74791718, 20.20430946], [72.74791718, 20.20486069], [72.74764252, 20.20486069], [72.74764252, 20.20597839], [72.74791718, 20.20597267], [72.74791718, 20.20846939], [72.74764252, 20.20846939], [72.74764252, 20.20930481], [72.74736023, 20.20930481], [72.74736023, 20.20958328], [72.7470932, 20.20957947], [72.7470932, 20.21042061], [72.74680328, 20.21041679], [72.74680328, 20.21319389], [72.74652863, 20.21319389], [72.74652863, 20.2159729], [72.74624634, 20.21597099], [72.74624634, 20.21681023], [72.74597168, 20.21681023], [72.74597168, 20.22180939], [72.74569702, 20.22180939], [72.74569702, 20.2226429], [72.7454071, 20.2226429], [72.7454071, 20.22764015], [72.74569702, 20.22764015], [72.74569702, 20.22986031], [72.7454071, 20.22986031], [72.7454071, 20.23125076], [72.74514008, 20.23125076], [72.74514008, 20.23153114], [72.74458313, 20.23153114], [72.74458313, 20.23180962], [72.74430847, 20.23180962], [72.74430847, 20.23236084], [72.74402618, 20.23236084], [72.74402618, 20.23291969], [72.74375153, 20.23291969], [72.74375153, 20.23402977], [72.74347687, 20.23402977], [72.74347687, 20.23431015], [72.74319458, 20.23430634], [72.74319458, 20.2345829], [72.74291992, 20.2345829], [72.74291992, 20.23569489], [72.74263763, 20.23569489], [72.74263763, 20.23596954], [72.74236298, 20.2359581], [72.74236298, 20.2365303], [72.74208069, 20.2365303], [72.74208069, 20.23681068], [72.74180603, 20.23681068], [72.74180603, 20.23792076], [72.74153137, 20.23791695], [72.74153137, 20.2381897], [72.74124908, 20.23820114], [72.74124908, 20.23875046], [72.7409668, 20.23875046], [72.7409668, 20.23931122], [72.74069214, 20.2393055], [72.74069214, 20.24097252], [72.74041748, 20.24097061], [72.74041748, 20.24291992], [72.74069214, 20.24291992], [72.74069214, 20.24403], [72.74097443, 20.24402618], [72.74097443, 20.24458313], [72.74180603, 20.24458313], [72.74180603, 20.2448616], [72.74208069, 20.2448616], [72.74208069, 20.24597168], [72.74236298, 20.24596977], [72.74236298, 20.24653053], [72.74263763, 20.24653053], [72.74263763, 20.24735832], [72.74291992, 20.24735832], [72.74291992, 20.24764061], [72.74319458, 20.24764061], [72.74319458, 20.24819374], [72.74346924, 20.24819374], [72.74346924, 20.24875069], [72.74375153, 20.24875069], [72.74375153, 20.24902916], [72.74402618, 20.24902916], [72.74402618, 20.24930954], [72.74430847, 20.24930573], [72.74430847, 20.2495842], [72.74458313, 20.24958038], [72.74458313, 20.24986267], [72.74485779, 20.24986267], [72.74485779, 20.25014114], [72.74514008, 20.25014114], [72.74514008, 20.25041962], [72.74541473, 20.2504158], [72.74541473, 20.25069427], [72.74569702, 20.25069427], [72.74569702, 20.25097275], [72.74597168, 20.2509594], [72.74597168, 20.25125122], [72.74624634, 20.25125122], [72.74624634, 20.25152969], [72.746521, 20.25152969], [72.746521, 20.25181007], [72.74680328, 20.25180626], [72.74680328, 20.2523613], [72.74708557, 20.2523613], [72.74708557, 20.25263977], [72.74736023, 20.25263977], [72.74736023, 20.25292015], [72.74764252, 20.25291634], [72.74764252, 20.25319481], [72.74791718, 20.25319481], [72.74791718, 20.25347137], [72.74819183, 20.25346947], [72.74819183, 20.25403023], [72.74847412, 20.25402832], [72.74847412, 20.25430489], [72.74874878, 20.25430489], [72.74874878, 20.25458336], [72.74903107, 20.25458336], [72.74903107, 20.25486183], [72.74931335, 20.25485992], [72.74931335, 20.2551403], [72.74958038, 20.2551403], [72.74958038, 20.25542068], [72.74986267, 20.25541687], [72.74986267, 20.25597191], [72.75013733, 20.25597], [72.75013733, 20.25653076], [72.75041962, 20.25653076], [72.75041962, 20.25708961], [72.75069427, 20.25708389], [72.75069427, 20.25819397], [72.75096893, 20.25819016], [72.75096893, 20.25875092], [72.75125122, 20.25875092], [72.75125122, 20.25958252], [72.75152588, 20.25958252], [72.75152588, 20.2606945], [72.75180817, 20.2606945], [72.75180817, 20.26208305], [72.75208282, 20.26208305], [72.75208282, 20.26319504], [72.75235748, 20.26318932], [72.75235748, 20.26431274], [72.75263977, 20.26430511], [72.75263977, 20.26458359], [72.7529068, 20.26457977], [72.75291443, 20.26486015], [72.75319672, 20.26486015], [72.75319672, 20.26736069], [72.75347137, 20.26736069], [72.75347137, 20.26931953], [72.75375366, 20.26930428], [72.75375366, 20.2709713], [72.75402832, 20.27096939], [72.75402832, 20.27403069], [72.75430298, 20.27402687], [72.75430298, 20.2784729], [72.75458527, 20.2784729], [72.75458527, 20.28236198], [72.75485992, 20.28236008], [72.75485992, 20.28541946], [72.75514221, 20.28541946], [72.75514221, 20.28903008], [72.75541687, 20.28903008], [72.75541687, 20.29042053], [72.75569153, 20.29041672], [72.75569153, 20.29208374], [72.75596619, 20.29208183], [72.75596619, 20.29236031], [72.75624847, 20.29236031], [72.75624847, 20.29292107], [72.75653076, 20.29291725], [72.75653076, 20.29347229], [72.75708008, 20.29347038], [72.75708008, 20.29403114], [72.75736237, 20.29403114], [72.75736237, 20.29430962], [72.75763702, 20.2943058], [72.75763702, 20.29458237], [72.75791931, 20.29458046], [72.75791931, 20.29486084], [72.75818634, 20.29486084], [72.75818634, 20.29514122], [72.75875092, 20.29514122], [72.75875092, 20.29541969], [72.75958252, 20.29541588], [72.75958252, 20.29569435], [72.75986481, 20.29569435], [72.75986481, 20.29624939], [72.76013947, 20.29624939], [72.76013947, 20.2970829], [72.76040649, 20.29708099], [72.76040649, 20.29763985], [72.76069641, 20.29763985], [72.76069641, 20.29792023], [72.76097107, 20.29791641], [72.76097107, 20.29819489], [72.76152802, 20.29819489], [72.76152802, 20.29847145], [72.76180267, 20.29847145], [72.76180267, 20.29930496], [72.76207733, 20.29930115], [72.76207733, 20.30014038], [72.76264191, 20.30014038], [72.76264191, 20.29985809], [72.76374817, 20.29985809], [72.76374817, 20.30014038], [72.76431274, 20.30014038], [72.76431274, 20.29985809], [72.76486206, 20.29986191], [72.76486206, 20.29958344], [72.76513672, 20.29958344], [72.76513672, 20.29930496], [72.76541901, 20.29930496], [72.76541901, 20.29902649], [72.76568604, 20.2990303], [72.76568604, 20.29874992], [72.76634216, 20.29874992], [72.76708221, 20.29874992], [72.76708221, 20.2990303], [72.7673645, 20.29902649], [72.7673645, 20.29930496], [72.76819611, 20.29930496], [72.76819611, 20.29958344], [72.76930237, 20.29958344], [72.76930237, 20.29986191], [72.76985931, 20.29985809], [72.76985931, 20.30014038], [72.7701416, 20.30014038], [72.7701416, 20.30042076], [72.77041626, 20.30041885], [72.77041626, 20.30097008], [72.77069092, 20.30096817], [72.77069092, 20.30124855], [72.77124786, 20.30124855], [72.77124786, 20.30153084], [72.77153015, 20.30153084], [72.77153015, 20.30180931], [72.77180481, 20.3018055], [72.77180481, 20.30208397], [72.7720871, 20.30207825], [72.7720871, 20.30235863], [72.77236176, 20.30235863], [72.77236176, 20.30264282], [72.77263641, 20.30264282], [72.77263641, 20.30291939], [72.77319336, 20.30291748], [72.77319336, 20.30319405], [72.77402496, 20.30319405], [72.77402496, 20.30347252], [72.77430725, 20.30347252], [72.77430725, 20.3037529], [72.77458191, 20.3037529], [72.77458191, 20.30486107], [72.77485657, 20.30486107], [72.77485657, 20.30653], [72.77513885, 20.30653], [72.77513885, 20.30764008], [72.7748642, 20.30763817], [72.7748642, 20.30847168], [72.77430725, 20.30846977], [72.77430725, 20.31180954], [72.77458191, 20.31180954], [72.77458191, 20.31514168], [72.77485657, 20.31514168], [72.77485657, 20.31986046], [72.77458191, 20.31986046], [72.77458191, 20.32513809], [72.7748642, 20.32513618], [72.7748642, 20.32847023], [72.77513885, 20.32846832], [72.77513885, 20.33014107], [72.77541351, 20.33013916], [72.77541351, 20.33208275], [72.7756958, 20.33208275], [72.7756958, 20.3334713], [72.7765274, 20.33346939], [72.7765274, 20.33374977], [72.7776413, 20.33374977], [72.7776413, 20.33403015], [72.77791595, 20.33402824], [72.77791595, 20.33486176], [72.77819824, 20.33486176], [72.77819824, 20.33597183], [72.77874756, 20.33596992], [72.77874756, 20.33681107], [72.77902985, 20.33681107], [72.77902985, 20.33764076], [72.7793045, 20.33763885], [72.7793045, 20.33819389], [72.77958679, 20.33819389], [72.77958679, 20.33847237], [72.77986145, 20.33847046], [72.77986145, 20.33875084], [72.78013611, 20.33875084], [72.78013611, 20.33903122], [72.7804184, 20.33903122], [72.7804184, 20.33930969], [72.78069305, 20.33930588], [72.78069305, 20.33958244], [72.7820816, 20.33958054], [72.7820816, 20.33986092], [72.78235626, 20.33986092], [72.78235626, 20.34013748], [72.78263092, 20.34013748], [72.78263092, 20.34041977], [72.78291321, 20.34041595], [72.78291321, 20.34069443], [72.7831955, 20.34069443], [72.7831955, 20.34125137], [72.78375244, 20.34125137], [72.78375244, 20.34153938], [72.7840271, 20.34153938], [72.7840271, 20.34181023], [72.78430176, 20.34181023], [72.78430939, 20.34264183], [72.78457642, 20.34264183], [72.78457642, 20.34320259], [72.7848587, 20.34319496], [72.7848587, 20.34346962], [72.78457642, 20.34346962], [72.78457642, 20.34375191], [72.7848587, 20.34375191], [72.7848587, 20.34431076], [72.78514099, 20.34430504], [72.78514099, 20.34458351], [72.78542328, 20.3445797], [72.78542328, 20.34514046], [72.78569794, 20.34513855], [72.78569794, 20.34569359], [72.7859726, 20.34569359], [72.7859726, 20.34597206], [72.78624725, 20.34597015], [72.78624725, 20.34625053], [72.78652954, 20.34625053], [72.78652954, 20.34680939], [72.7868042, 20.34680557], [72.7868042, 20.34736061], [72.78708649, 20.34735107], [72.78708649, 20.34764099], [72.7876358, 20.34763908], [72.7876358, 20.34819412], [72.78791809, 20.34819412], [72.78791809, 20.3484726], [72.78848267, 20.34847069], [72.78848267, 20.34902954], [72.78875732, 20.34902954], [72.78875732, 20.34930992], [72.78901672, 20.34930992], [72.78901672, 20.34986115], [72.7895813, 20.34986115], [72.7895813, 20.35013962], [72.79069519, 20.35013962], [72.79069519, 20.35041618], [72.79096985, 20.35041618], [72.79096985, 20.35069466], [72.79125214, 20.35069466], [72.79125214, 20.35097313], [72.79180908, 20.35097313], [72.79180908, 20.35124969], [72.7923584, 20.35124969], [72.7923584, 20.35153008], [72.79264069, 20.35152626], [72.79264069, 20.35180473], [72.79458618, 20.35180473], [72.79458618, 20.35152626], [72.79486084, 20.35153008], [72.79486084, 20.35124969], [72.7959671, 20.35124969], [72.7959671, 20.35097122], [72.79680634, 20.35097313], [72.79680634, 20.35069466], [72.80097198, 20.35069466], [72.80097198, 20.35097313], [72.8034668, 20.35097122], [72.8034668, 20.35124969], [72.80430603, 20.35124969], [72.80430603, 20.35153008], [72.80513763, 20.35152626], [72.80513763, 20.35180473], [72.80569458, 20.35180473], [72.80569458, 20.35208321], [72.80652618, 20.35208321], [72.80652618, 20.35236168], [72.80735779, 20.35235977], [72.80735779, 20.35263824], [72.80764008, 20.35263824], [72.80764008, 20.35292053], [72.80819702, 20.35292053], [72.80819702, 20.35320091], [72.80847168, 20.35320091], [72.80847168, 20.35347939], [72.80874634, 20.35347939], [72.80874634, 20.35374832], [72.80930328, 20.35374832], [72.80930328, 20.35403061], [72.8095932, 20.35403061], [72.8095932, 20.35430908], [72.80986023, 20.35430527], [72.80986023, 20.35458374], [72.81041718, 20.35457993], [72.81041718, 20.3548584], [72.81069183, 20.3548584], [72.81069183, 20.35514069], [72.81096649, 20.35514069], [72.81096649, 20.35541916], [72.81124878, 20.35541725], [72.81124878, 20.35569382], [72.81180573, 20.35569382], [72.81180573, 20.35597229], [72.81208038, 20.35596848], [72.81208038, 20.35625267], [72.81236267, 20.35625267], [72.81236267, 20.35654068], [72.81291962, 20.35654068], [72.81291962, 20.35680962], [72.81319427, 20.3568058], [72.81319427, 20.35708046], [72.81346893, 20.35708046], [72.81346893, 20.35736275], [72.81375122, 20.35736275], [72.81375122, 20.35764122], [72.81402588, 20.35764122], [72.81402588, 20.35791969], [72.81430817, 20.35791588], [72.81430817, 20.35819435], [72.81458282, 20.35819435], [72.81458282, 20.35847282], [72.81485748, 20.35847282], [72.81485748, 20.35874939], [72.81513977, 20.35874939], [72.81513977, 20.35931015], [72.81541443, 20.35930634], [72.81541443, 20.35958481], [72.81597137, 20.3595829], [72.81597137, 20.36013985], [72.81624603, 20.36013985], [72.81624603, 20.36042023], [72.81652832, 20.36041641], [72.81652832, 20.36069489], [72.81680298, 20.36069489], [72.81680298, 20.36097145], [72.81708527, 20.36097145], [72.81708527, 20.36124992], [72.81735992, 20.36124992], [72.81735992, 20.3615303], [72.81764221, 20.3615284], [72.81764221, 20.36208344], [72.81791687, 20.36207962], [72.81791687, 20.36264038], [72.81819153, 20.36263847], [72.81819153, 20.36319351], [72.81846619, 20.3631897], [72.81846619, 20.36375046], [72.81874084, 20.36375046], [72.81874084, 20.36431122], [72.81903076, 20.3643055], [72.81903076, 20.36458397], [72.81931305, 20.36458015], [72.81931305, 20.36514091], [72.81958008, 20.3651371], [72.81958008, 20.36569405], [72.81986237, 20.36569023], [72.81986237, 20.36624908], [72.82013702, 20.36624908], [72.82013702, 20.36680984], [72.82041931, 20.36680984], [72.82041931, 20.36735916], [72.82235718, 20.36735916], [72.82235718, 20.36763763], [72.82263947, 20.36763763], [72.82263947, 20.36819458], [72.82235718, 20.36819077], [72.82235718, 20.36848259], [72.82208252, 20.36848259], [72.82208252, 20.36903191], [72.82180786, 20.36902809], [72.82180786, 20.3698616], [72.82152557, 20.3698616], [72.8215332, 20.3710804], [72.82649231, 20.36676025], [72.83132935, 20.36873817], [72.8353653, 20.37371254], [72.85894775, 20.37434006], [72.86501312, 20.37241173], [72.87520599, 20.3728199], [72.87988281, 20.3707695], [72.88378143, 20.370224], [72.89354706, 20.37214661], [72.89637756, 20.37669563], [72.89564514, 20.38036346], [72.88873291, 20.38420105], [72.88685608, 20.38718224], [72.88632202, 20.39336777], [72.88951111, 20.3982811], [72.90042114, 20.40526772], [72.90330505, 20.41033745], [72.90261078, 20.41524124], [72.89962769, 20.41921425], [72.89583588, 20.42136002], [72.88889313, 20.41911316], [72.87956238, 20.41846848], [72.8688736, 20.41582489], [72.86510468, 20.41617584], [72.86031342, 20.41961479], [72.85932159, 20.42437363], [72.86154938, 20.42836952], [72.86811066, 20.434412], [72.87340546, 20.44420815], [72.87704468, 20.44462204], [72.88488007, 20.44006157], [72.88877869, 20.43915558], [72.89280701, 20.44166946], [72.89334869, 20.44538689], [72.89000702, 20.44886017], [72.88744354, 20.45333099], [72.88564301, 20.45907021], [72.88248444, 20.46276665], [72.87428284, 20.46296692], [72.8664093, 20.46469688], [72.86589813, 20.46751022], [72.86340332, 20.46883965], [72.86013794, 20.47096062], [72.86013794, 20.47153091], [72.86042023, 20.47153091], [72.86042023, 20.47180939], [72.86013794, 20.47180557], [72.86013794, 20.47208405], [72.86042023, 20.47208023], [72.86042023, 20.47236061], [72.86067963, 20.47236061], [72.86067963, 20.47291946], [72.86096954, 20.47291946], [72.86096954, 20.4734726], [72.86125183, 20.4734726], [72.86125183, 20.47569466], [72.86152649, 20.47569084], [72.86152649, 20.47681046], [72.86180878, 20.47680473], [72.86180878, 20.47708321], [72.86207581, 20.47707939], [72.86207581, 20.47764015], [72.86180878, 20.47763824], [72.86180878, 20.47847366], [72.86207581, 20.47847176], [72.86207581, 20.47903061], [72.86235809, 20.4790287], [72.86235809, 20.47958374], [72.86264038, 20.47957993], [72.86264038, 20.48014069], [72.86291504, 20.48013878], [72.86291504, 20.48069382], [72.86319733, 20.48069382], [72.86319733, 20.48097229], [72.86347198, 20.48097038], [72.86347198, 20.48153114], [72.86374664, 20.48153114], [72.86374664, 20.48180962], [72.86402893, 20.4818058], [72.86402893, 20.48236084], [72.86430359, 20.48236084], [72.86430359, 20.48291588], [72.86458588, 20.48291588], [72.86458588, 20.48319435], [72.86486053, 20.48319054], [72.86486053, 20.48374939], [72.86514282, 20.48374939], [72.86514282, 20.48431015], [72.86541748, 20.48430634], [72.86541748, 20.48486137], [72.86569214, 20.48485947], [72.86569214, 20.48513985], [72.8659668, 20.48513985], [72.8659668, 20.48542023], [72.86624908, 20.48541641], [72.86624908, 20.48597145], [72.86653137, 20.48597145], [72.86653137, 20.48639107], [72.86653137, 20.4865303], [72.8666687, 20.48652649], [72.86680603, 20.48652649], [72.86680603, 20.4866581], [72.86680603, 20.48681068], [72.86694336, 20.48681068], [72.86708069, 20.48680496], [72.86708069, 20.48694992], [72.86708069, 20.48763847], [72.86736298, 20.48763847], [72.86736298, 20.48792076], [72.86763763, 20.48791885], [72.86763763, 20.48847008], [72.86791992, 20.48846817], [72.86791992, 20.48874855], [72.86818695, 20.48874855], [72.86818695, 20.48903084], [72.86850739, 20.48902702], [72.86875153, 20.48902702], [72.86875153, 20.48938179], [72.86875153, 20.48957825], [72.8690033, 20.48958969], [72.86902618, 20.48986244], [72.86930084, 20.48987961], [72.86930847, 20.49014282], [72.86956024, 20.49014282], [72.86958313, 20.49041939], [72.86985779, 20.49041748], [72.86985779, 20.49069405], [72.87014008, 20.49069405], [72.87014008, 20.49097252], [72.8704071, 20.49097252], [72.8704071, 20.49152946], [72.87069702, 20.49152946], [72.87069702, 20.49180984], [72.87097168, 20.49180603], [72.87097168, 20.4920826], [72.87124634, 20.4920826], [72.87124634, 20.49236107], [72.87152863, 20.49236107], [72.87152863, 20.49263954], [72.87180328, 20.49263954], [72.87180328, 20.49291992], [72.87208557, 20.49291611], [72.87208557, 20.49347305], [72.87236023, 20.49347115], [72.87236023, 20.49403], [72.87319183, 20.49402809], [72.87319183, 20.49430466], [72.87403107, 20.49430466], [72.87403107, 20.49458313], [72.87432098, 20.49458313], [72.87458038, 20.49458313], [72.87458038, 20.49430466], [72.87486267, 20.49430466], [72.87486267, 20.49458313], [72.87625122, 20.49458313], [72.87625122, 20.4948616], [72.87652588, 20.49485016], [72.87652588, 20.49514008], [72.87847137, 20.49514008], [72.87847137, 20.49542046], [72.87903595, 20.49542046], [72.87903595, 20.49570084], [72.87958527, 20.49569511], [72.87958527, 20.49597168], [72.87985992, 20.49596977], [72.87985992, 20.49625015], [72.88041687, 20.49625015], [72.88041687, 20.49653053], [72.88096619, 20.49653053], [72.88096619, 20.49681091], [72.88124847, 20.49680519], [72.88124847, 20.49708366], [72.88153076, 20.49707985], [72.88153076, 20.49736023], [72.88181305, 20.49736023], [72.88181305, 20.49764061], [72.88263702, 20.4976387], [72.88263702, 20.49791527], [72.88319397, 20.49791527], [72.88319397, 20.49819374], [72.88375092, 20.49819374], [72.88375092, 20.49847221], [72.8840332, 20.49847031], [72.8840332, 20.49903107], [72.88430786, 20.49902725], [72.88430786, 20.4995842], [72.88458252, 20.49958038], [72.88458252, 20.49986076], [72.88484955, 20.49986076], [72.88484955, 20.50041962], [72.88458252, 20.5004158], [72.88458252, 20.50069427], [72.88430786, 20.50069046], [72.88430786, 20.50124931], [72.88458252, 20.50124931], [72.88458252, 20.5015316], [72.88486481, 20.50152969], [72.88486481, 20.50208282], [72.88513947, 20.50208092], [72.88513947, 20.50292015], [72.88540649, 20.50292015], [72.88540649, 20.5051403], [72.88569641, 20.5051384], [72.88569641, 20.50597382], [72.88597107, 20.50597191], [72.88597107, 20.50625038], [72.88625336, 20.50625038], [72.88625336, 20.50736046], [72.88652802, 20.50736046], [72.88652802, 20.50847244], [72.88680267, 20.50847244], [72.88680267, 20.51291656], [72.88707733, 20.51291084], [72.88707733, 20.51374817], [72.88735962, 20.51374817], [72.88735962, 20.51458359], [72.88764191, 20.51457977], [72.88764191, 20.51904106], [72.88791656, 20.51902771], [72.88791656, 20.51958466], [72.88764191, 20.51958275], [72.88764191, 20.51986122], [72.88735962, 20.51986122], [72.88735962, 20.52013969], [72.88708496, 20.52013969], [72.88708496, 20.52069473], [72.88735962, 20.52069283], [72.88735962, 20.52124977], [72.88764191, 20.52124977], [72.88764191, 20.52264023], [72.88735962, 20.52264023], [72.88735962, 20.52292061], [72.88707733, 20.52292061], [72.88707733, 20.52320099], [72.88680267, 20.52320099], [72.88680267, 20.52514076], [72.88652802, 20.52513885], [72.88652802, 20.5284729], [72.88625336, 20.52846909], [72.88625336, 20.52875137], [72.88597107, 20.52875137], [72.88597107, 20.52958107], [72.88625336, 20.52957916], [72.88625336, 20.53014183], [72.88652802, 20.53014183], [72.88652802, 20.5304203], [72.88680267, 20.5304203], [72.88680267, 20.53070068], [72.88791656, 20.53070068], [72.88791656, 20.53098106], [72.88819122, 20.53098106], [72.88819122, 20.53125191], [72.88931274, 20.53125191], [72.88930511, 20.53096962], [72.89013672, 20.53098106], [72.89013672, 20.53070068], [72.89125061, 20.53070068], [72.89125061, 20.53098106], [72.89152527, 20.53096962], [72.89152527, 20.53125191], [72.89180756, 20.53125191], [72.89180756, 20.53236389], [72.8915329, 20.53236008], [72.89154053, 20.53267288], [72.89125061, 20.53263855], [72.89125061, 20.53273392], [72.89125061, 20.53319359], [72.89152527, 20.53319359], [72.89152527, 20.53347206], [72.89125061, 20.53347015], [72.89125061, 20.53375053], [72.89097595, 20.53375053], [72.89097595, 20.5340271], [72.89068604, 20.53401947], [72.89068604, 20.53430939], [72.89013672, 20.53430939], [72.89013672, 20.53401947], [72.88931274, 20.53401947], [72.88931274, 20.53430939], [72.88903046, 20.53430939], [72.88903046, 20.53514099], [72.88874817, 20.53513908], [72.88874817, 20.5359726], [72.88846588, 20.53597069], [72.88846588, 20.53625107], [72.88819122, 20.53625107], [72.88820648, 20.53654099], [72.88764191, 20.53652954], [72.88768768, 20.53688431], [72.88735962, 20.53680992], [72.88736725, 20.53709984], [72.88708496, 20.53708267], [72.88708496, 20.53736115], [72.88697815, 20.53736115], [72.88680267, 20.53736115], [72.88680267, 20.53746033], [72.88680267, 20.53763962], [72.88652802, 20.53763962], [72.88625336, 20.53763962], [72.88625336, 20.53782082], [72.88625336, 20.53958321], [72.88597107, 20.53958321], [72.88597107, 20.53986168], [72.88569641, 20.53985977], [72.88569641, 20.5401516], [72.88540649, 20.5401516], [72.88540649, 20.54070091], [72.88513947, 20.54070091], [72.88513947, 20.54624939], [72.88540649, 20.54624939], [72.88540649, 20.54792023], [72.88569641, 20.54791641], [72.88569641, 20.54847145], [72.88597107, 20.54846954], [72.88597107, 20.54931068], [72.88625336, 20.54930687], [72.88625336, 20.54986191], [72.88597107, 20.54986], [72.88597107, 20.55042076], [72.88625336, 20.55041695], [72.88625336, 20.55097198], [72.88652802, 20.55097008], [72.88652802, 20.55125046], [72.88680267, 20.55125046], [72.88680267, 20.55319405], [72.88735962, 20.55319023], [72.88735962, 20.55374908], [72.88764191, 20.55374908], [72.88764191, 20.55430984], [72.88791656, 20.55430984], [72.88791656, 20.55485916], [72.88819122, 20.55485916], [72.88819122, 20.55542183], [72.88846588, 20.55542183], [72.88846588, 20.55625153], [72.88874817, 20.55625153], [72.88874817, 20.55653191], [72.88903046, 20.55652809], [72.88903046, 20.55680466], [72.88930511, 20.55680466], [72.88930511, 20.5573616], [72.88957977, 20.5573616], [72.88957977, 20.55847359], [72.88986206, 20.55846977], [72.88986206, 20.55903053], [72.89013672, 20.55903053], [72.89013672, 20.55986023], [72.89041901, 20.55986023], [72.89041901, 20.56042099], [72.89097595, 20.56042099], [72.89097595, 20.56125069], [72.89125061, 20.56125069], [72.89125061, 20.56153107], [72.8915329, 20.56153107], [72.8915329, 20.56180954], [72.89180756, 20.56180954], [72.89180756, 20.56236076], [72.89208221, 20.56236076], [72.89208221, 20.56291962], [72.8923645, 20.5629158], [72.8923645, 20.56347275], [72.89319611, 20.56347084], [72.89319611, 20.56402969], [72.89347076, 20.56402969], [72.89347076, 20.56431961], [72.89375305, 20.56430626], [72.89375305, 20.56458282], [72.89457703, 20.56458092], [72.89457703, 20.56513977], [72.89485931, 20.56513977], [72.89485931, 20.56569481], [72.8951416, 20.56569099], [72.8951416, 20.56624985], [72.89541626, 20.56624985], [72.89541626, 20.56680489], [72.89569092, 20.56680489], [72.89569092, 20.56736183], [72.89597321, 20.56735992], [72.89597321, 20.56819916], [72.89624786, 20.56819916], [72.89624786, 20.56930923], [72.89653015, 20.56930542], [72.89653015, 20.57069206], [72.89678955, 20.57069016], [72.89678955, 20.57180977], [72.8970871, 20.57180595], [72.8970871, 20.5731945], [72.89736176, 20.5731945], [72.89736176, 20.57430077], [72.89763641, 20.5743103], [72.89763641, 20.57653046], [72.89736176, 20.57653046], [72.89736176, 20.57681084], [72.89763641, 20.57681084], [72.89763641, 20.57903099], [72.89736176, 20.57902718], [72.89736176, 20.57958412], [72.89763641, 20.57958412], [72.89763641, 20.58708382], [72.89736176, 20.58708382], [72.89736176, 20.58847237], [72.89707947, 20.58847046], [72.89707947, 20.58930969], [72.89678955, 20.58930969], [72.89678955, 20.59126091], [72.89653015, 20.59126091], [72.89653015, 20.59181023], [72.89624786, 20.59180641], [72.89624786, 20.59208298], [72.89597321, 20.59208298], [72.89597321, 20.59347153], [72.89569092, 20.59347153], [72.89569092, 20.59458351], [72.89541626, 20.5945797], [72.89541626, 20.59542084], [72.8951416, 20.59541893], [72.8951416, 20.5984726], [72.89485931, 20.5984726], [72.89485931, 20.59902954], [72.89457703, 20.59902954], [72.89457703, 20.59930992], [72.89430237, 20.59930992], [72.89430237, 20.60042], [72.89402771, 20.60041618], [72.89402771, 20.60180473], [72.89375305, 20.60180473], [72.89375305, 20.60208321], [72.89402008, 20.60207939], [72.89402008, 20.60292053], [72.89375305, 20.60292053], [72.89375305, 20.60375023], [72.89347076, 20.60375023], [72.89347076, 20.60458374], [72.89319611, 20.60457993], [72.89319611, 20.60653114], [72.89290619, 20.60653114], [72.89290619, 20.60680962], [72.89263916, 20.6068058], [72.89263916, 20.60708427], [72.89235687, 20.60708046], [72.89235687, 20.60903168], [72.89208221, 20.60902977], [72.89208221, 20.6095829], [72.89180756, 20.60957909], [72.89180756, 20.61042023], [72.89152527, 20.61041641], [72.8915329, 20.61125183], [72.89125061, 20.61125183], [72.89125061, 20.6115303], [72.8915329, 20.6115303], [72.8915329, 20.61181068], [72.89125061, 20.61180496], [72.89125061, 20.61236382], [72.89097595, 20.61236382], [72.89097595, 20.61458588], [72.89068604, 20.61458015], [72.89068604, 20.61486053], [72.89041901, 20.61486053], [72.89041901, 20.61514091], [72.89069366, 20.61513901], [72.89069366, 20.61569595], [72.89041901, 20.61569023], [72.89041901, 20.61652946], [72.89013672, 20.61652946], [72.89013672, 20.61763954], [72.88986206, 20.61763954], [72.88986206, 20.61819458], [72.88957977, 20.61818123], [72.88957977, 20.61874962], [72.88931274, 20.61874962], [72.88931274, 20.61902809], [72.88957977, 20.61902618], [72.88957977, 20.61930466], [72.88931274, 20.61930084], [72.88931274, 20.62013817], [72.88903046, 20.62013626], [72.88903046, 20.62124825], [72.88874817, 20.62124825], [72.88874817, 20.62208366], [72.88846588, 20.62207985], [72.88846588, 20.62291908], [72.88874817, 20.62291718], [72.88874817, 20.62319374], [72.88819122, 20.62318993], [72.88819122, 20.62403107], [72.88791656, 20.62402725], [72.88791656, 20.62430573], [72.88819122, 20.62430191], [72.88819122, 20.62486267], [72.88791656, 20.62486267], [72.88791656, 20.62514114], [72.88764191, 20.62514114], [72.88764191, 20.62541962], [72.88735962, 20.62541962], [72.88735962, 20.62681007], [72.88707733, 20.62681007], [72.88707733, 20.62737083], [72.88680267, 20.62737083], [72.88680267, 20.62874985], [72.88652802, 20.62874985], [72.88652802, 20.63097191], [72.88625336, 20.63097191], [72.88625336, 20.63208389], [72.88735962, 20.63208389], [72.88735962, 20.63180542], [72.89125061, 20.63180542], [72.89125061, 20.63208389], [72.8923645, 20.63208389], [72.8923645, 20.63319397], [72.89152527, 20.63319397], [72.89152527, 20.63347244], [72.89097595, 20.63347054], [72.89097595, 20.63375092], [72.88957977, 20.63375092], [72.88957977, 20.63402748], [72.88931274, 20.63402748], [72.88931274, 20.63430977], [72.88903046, 20.63430595], [72.88903046, 20.63458252], [72.88846588, 20.63458061], [72.88846588, 20.63485909], [72.88819122, 20.63485909], [72.88819122, 20.63514137], [72.88764191, 20.63514137], [72.88764191, 20.63542175], [72.88735962, 20.63541603], [72.88735962, 20.6356945], [72.88708496, 20.6356945], [72.88708496, 20.63597107], [72.88680267, 20.63597107], [72.88680267, 20.63625145], [72.88652802, 20.6362381], [72.88652802, 20.63792038], [72.88680267, 20.63792038], [72.88680267, 20.64153099], [72.88597107, 20.64153099], [72.88597107, 20.64237022], [72.88569641, 20.64237022], [72.88569641, 20.64264107], [72.88541412, 20.64263916], [72.88541412, 20.64347267], [72.88569641, 20.64347076], [72.88569641, 20.64431], [72.88597107, 20.64431], [72.88597107, 20.64486122], [72.88569641, 20.64486122], [72.88569641, 20.64513969], [72.88540649, 20.64513969], [72.88540649, 20.64486122], [72.88513947, 20.64486122], [72.88513947, 20.64431], [72.88484955, 20.64431], [72.88484955, 20.64375114], [72.88458252, 20.64375114], [72.88458252, 20.64347076], [72.88430786, 20.64347267], [72.88430786, 20.64291763], [72.88375092, 20.64291954], [72.88375092, 20.64237022], [72.88346863, 20.64237022], [72.88346863, 20.64208031], [72.88319397, 20.64208412], [72.88319397, 20.64180565], [72.88291931, 20.64180565], [72.88291931, 20.64208412], [72.88208008, 20.64208031], [72.88208008, 20.64264107], [72.88181305, 20.64264107], [72.88181305, 20.64291954], [72.88153076, 20.64291763], [72.88153076, 20.64347267], [72.88124847, 20.64347076], [72.88124847, 20.64375114], [72.88096619, 20.64375114], [72.88096619, 20.64402962], [72.88069153, 20.64402771], [72.88069153, 20.64458275], [72.88041687, 20.64458084], [72.88041687, 20.64513969], [72.87985992, 20.64513969], [72.87985992, 20.64541626], [72.87930298, 20.64541626], [72.87930298, 20.64569473], [72.87902832, 20.64569473], [72.87902832, 20.6459713], [72.87874603, 20.64596939], [72.87874603, 20.64624977], [72.87847137, 20.64624977], [72.87847137, 20.64652824], [72.87819672, 20.64652634], [72.87819672, 20.64680481], [72.8779068, 20.64680099], [72.8779068, 20.64763832], [72.87763977, 20.64763832], [72.87763977, 20.64792061], [72.87735748, 20.64792061], [72.87735748, 20.64819908], [72.87708282, 20.64819527], [72.87708282, 20.64847183], [72.87680817, 20.64846992], [72.87680817, 20.6487484], [72.87652588, 20.6487484], [72.87652588, 20.64930916], [72.87625122, 20.64930916], [72.87625122, 20.64985847], [72.87596893, 20.64985847], [72.87596893, 20.65069389], [72.87568665, 20.65069008], [72.87568665, 20.65125275], [72.87541962, 20.65125275], [72.87541962, 20.65208054], [72.87513733, 20.65208054], [72.87513733, 20.65291977], [72.87486267, 20.65291595], [72.87486267, 20.65347481], [72.87458038, 20.65347481], [72.87458038, 20.65486145], [72.87431335, 20.65485954], [72.87431335, 20.6554203], [72.87403107, 20.6554203], [72.87403107, 20.65653038], [72.87374878, 20.65652847], [72.87374878, 20.65736198], [72.87346649, 20.65735054], [72.87346649, 20.65764046], [72.87319183, 20.65763855], [72.87319183, 20.65847206], [72.87290955, 20.65847015], [72.87290955, 20.65930939], [72.87264252, 20.65930557], [72.87264252, 20.6609726], [72.87236023, 20.66097069], [72.87236023, 20.66235924], [72.8720932, 20.66235924], [72.8720932, 20.66348267], [72.87180328, 20.66347313], [72.87180328, 20.66430473], [72.87152863, 20.66430092], [72.87152863, 20.66514015], [72.87124634, 20.66513824], [72.87124634, 20.66597366], [72.87097168, 20.66596985], [72.87097168, 20.66930962], [72.87069702, 20.6693058], [72.87069702, 20.66958427], [72.8704071, 20.66958046], [72.8704071, 20.67041969], [72.87014008, 20.67041969], [72.87014008, 20.67181015], [72.86985779, 20.67180634], [72.86985779, 20.6720829], [72.86958313, 20.67208099], [72.86958313, 20.67374992], [72.86930847, 20.67374992], [72.86930847, 20.67431068], [72.86902618, 20.67430496], [72.86902618, 20.6756897], [72.86875153, 20.67569923], [72.86875153, 20.67624855], [72.86846924, 20.67624855], [72.86846924, 20.67708397], [72.86818695, 20.67708015], [72.86818695, 20.67791939], [72.86791992, 20.67791939], [72.86791992, 20.67986107], [72.86763763, 20.67986107], [72.86763763, 20.68124962], [72.86736298, 20.68124962], [72.86736298, 20.68264008], [72.86708069, 20.68264008], [72.86708069, 20.68375015], [72.86680603, 20.68375015], [72.86680603, 20.68431091], [72.86653137, 20.68430519], [72.86653137, 20.68458366], [72.86624908, 20.68457985], [72.86624908, 20.68514061], [72.86597443, 20.6851387], [72.86597443, 20.68569374], [72.86569214, 20.68568993], [72.86569214, 20.68680954], [72.86541748, 20.68680954], [72.86541748, 20.68791962], [72.86514282, 20.68791962], [72.86514282, 20.6890316], [72.86486053, 20.6890316], [72.86486053, 20.69014168], [72.86458588, 20.69014168], [72.86458588, 20.69096947], [72.86430359, 20.69096947], [72.86430359, 20.69180489], [72.86402893, 20.69180489], [72.86402893, 20.69236374], [72.86374664, 20.69236183], [72.86374664, 20.69320107], [72.86347198, 20.69320107], [72.86347198, 20.69403076], [72.86319733, 20.69402695], [72.86319733, 20.6945858], [72.86292267, 20.69458008], [72.86292267, 20.69542122], [72.86264038, 20.69542122], [72.86264038, 20.69625092], [72.86235809, 20.69625092], [72.86235809, 20.69680977], [72.86207581, 20.69680977], [72.86207581, 20.69763947], [72.86180878, 20.69763947], [72.86180878, 20.69847298], [72.86152649, 20.69847107], [72.86152649, 20.69959068], [72.86125183, 20.69959068], [72.86125183, 20.70042038], [72.86096954, 20.70042038], [72.86096954, 20.70153046], [72.86067963, 20.70153046], [72.86067963, 20.70265007], [72.86042023, 20.70263863], [72.86042023, 20.70347023], [72.86013794, 20.70347023], [72.86013794, 20.70458412], [72.85986328, 20.70458031], [72.85986328, 20.70514107], [72.85958099, 20.70514107], [72.85958099, 20.70625114], [72.85930634, 20.70625114], [72.85930634, 20.70736122], [72.85902405, 20.70736122], [72.85902405, 20.7084713], [72.85874939, 20.7084713], [72.85874939, 20.70958328], [72.8584671, 20.70957947], [72.8584671, 20.71042061], [72.85819244, 20.71042061], [72.85819244, 20.71125031], [72.85791779, 20.71125031], [72.85791779, 20.71208382], [72.85764313, 20.71208], [72.85764313, 20.71264076], [72.85736084, 20.71263885], [72.85736084, 20.71319389], [72.85708618, 20.71319008], [72.85708618, 20.71430969], [72.85679626, 20.71430969], [72.85679626, 20.71542168], [72.85652924, 20.71542168], [72.85652924, 20.71653175], [72.85624695, 20.71652985], [72.85624695, 20.71735954], [72.85597229, 20.71735954], [72.85597229, 20.71820068], [72.85569763, 20.71820068], [72.85569763, 20.71903038], [72.85541534, 20.71902847], [72.85541534, 20.71986389], [72.85514069, 20.71986389], [72.85514069, 20.72097206], [72.85486603, 20.72097015], [72.85486603, 20.72264099], [72.85457611, 20.72264099], [72.85457611, 20.72430992], [72.85430908, 20.72430992], [72.85430908, 20.72652817], [72.85402679, 20.72652817], [72.85402679, 20.72874832], [72.85375214, 20.72874832], [72.85375214, 20.72958946], [72.85346985, 20.72958946], [72.85346985, 20.73042107], [72.85319519, 20.73041725], [72.85319519, 20.73097038], [72.8529129, 20.73097038], [72.8529129, 20.73263931], [72.85263824, 20.73263931], [72.85263824, 20.73347473], [72.85235596, 20.73347282], [72.85235596, 20.73402977], [72.8520813, 20.73402977], [72.8520813, 20.73792076], [72.85235596, 20.73792076], [72.85235596, 20.74041748], [72.85180664, 20.74041748], [72.85180664, 20.74097252], [72.85151672, 20.74097061], [72.85151672, 20.74152756], [72.85098267, 20.74152756], [72.85098267, 20.74292183], [72.85124969, 20.74291611], [72.85124969, 20.74458122], [72.85152435, 20.74458122], [72.85152435, 20.74486351], [72.85263824, 20.74486351], [72.85263824, 20.74458122], [72.85319519, 20.74458122], [72.85319519, 20.74430466], [72.85346985, 20.74430466], [72.85346985, 20.74402809], [72.85375214, 20.74403191], [72.85375214, 20.74375153], [72.85402679, 20.74375153], [72.85402679, 20.74346924], [72.85430908, 20.74347115], [72.85430908, 20.74291611], [72.85457611, 20.74292183], [72.85457611, 20.74264145], [72.85486603, 20.74264145], [72.8548584, 20.74180603], [72.85514069, 20.74181938], [72.85514069, 20.74152756], [72.85542297, 20.74152756], [72.85542297, 20.74124908], [72.85569763, 20.74124908], [72.85569763, 20.74097061], [72.85597229, 20.74097252], [72.85597229, 20.74069405], [72.85624695, 20.74069405], [72.85624695, 20.74041748], [72.85652924, 20.74041748], [72.85652924, 20.74014091], [72.85679626, 20.74014091], [72.85679626, 20.73986053], [72.85708618, 20.73986053], [72.85708618, 20.73931122], [72.85736084, 20.73931122], [72.85736084, 20.73875809], [72.85764313, 20.73875809], [72.85764313, 20.73847008], [72.85819244, 20.73847198], [72.85819244, 20.73819351], [72.85847473, 20.73819351], [72.85847473, 20.73791695], [72.85874939, 20.73791695], [72.85874939, 20.73819351], [72.85902405, 20.73819351], [72.85902405, 20.73736191], [72.85930634, 20.73736191], [72.85930634, 20.7365284], [72.85958099, 20.7365303], [72.85958099, 20.73624992], [72.85986328, 20.73624992], [72.85986328, 20.73542023], [72.86013794, 20.73542023], [72.86013794, 20.73513985], [72.86096954, 20.73513985], [72.86096954, 20.73542023], [72.86125183, 20.73541641], [72.86125183, 20.73597145], [72.86152649, 20.73596954], [72.86152649, 20.73624992], [72.86207581, 20.73624992], [72.86207581, 20.73596954], [72.86235809, 20.73597145], [72.86235809, 20.73569489], [72.86264038, 20.73569489], [72.86264038, 20.73597145], [72.86291504, 20.73597145], [72.86291504, 20.73569489], [72.86319733, 20.73569489], [72.86319733, 20.73541641], [72.86347198, 20.73542023], [72.86347198, 20.73513985], [72.86708069, 20.73513985], [72.86708069, 20.73542023], [72.86791992, 20.73541641], [72.86791992, 20.73569489], [72.86902618, 20.73569489], [72.86902618, 20.73541641], [72.86930847, 20.73542023], [72.86930847, 20.73485947], [72.86958313, 20.73486137], [72.86958313, 20.73319435], [72.86930847, 20.73319435], [72.86930847, 20.73291588], [72.86902618, 20.73291969], [72.86902618, 20.73263168], [72.87014008, 20.73263168], [72.87014008, 20.73291969], [72.87041473, 20.73291588], [72.87041473, 20.73319435], [72.87152863, 20.73319435], [72.87152863, 20.73347473], [72.87180328, 20.73347282], [72.87180328, 20.73374939], [72.8720932, 20.73374939], [72.8720932, 20.73402977], [72.87236023, 20.73402977], [72.87236023, 20.73431015], [72.87403107, 20.73430634], [72.87403107, 20.73458481], [72.87458038, 20.73458481], [72.87458038, 20.73486137], [72.87486267, 20.73485947], [72.87486267, 20.73513985], [72.87513733, 20.73513794], [72.87513733, 20.73569489], [72.87569427, 20.73569489], [72.87569427, 20.73597145], [72.87735748, 20.73596954], [72.87735748, 20.73624992], [72.87763977, 20.73624992], [72.87763977, 20.7365303], [72.87847137, 20.7365303], [72.87847137, 20.73681068], [72.87875366, 20.73680687], [72.87875366, 20.73736191], [72.8795929, 20.73736], [72.8795929, 20.73764038], [72.88014221, 20.73764038], [72.88014221, 20.73792076], [72.88124847, 20.73791695], [72.88124847, 20.73819351], [72.88458252, 20.73819351], [72.88458252, 20.73847198], [72.88597107, 20.73847008], [72.88597107, 20.73875809], [72.88874817, 20.73875809], [72.88874817, 20.73903084], [72.88986206, 20.73903084], [72.88986206, 20.74041748], [72.88957977, 20.74041748], [72.88957977, 20.74069405], [72.88903046, 20.74069405], [72.88903046, 20.74097252], [72.88874817, 20.74097061], [72.88874817, 20.74124908], [72.88819122, 20.74124908], [72.88819122, 20.74152756], [72.88791656, 20.74152756], [72.88791656, 20.74181938], [72.88764191, 20.74180603], [72.88764191, 20.7420826], [72.88819122, 20.74208069], [72.88819122, 20.74235916], [72.88846588, 20.74235916], [72.88846588, 20.74264145], [72.88874817, 20.74264145], [72.88874817, 20.74292183], [72.88903046, 20.74291611], [72.88903046, 20.74347115], [72.88874817, 20.74346924], [72.88874817, 20.74375153], [72.88846588, 20.74375153], [72.88846588, 20.74403191], [72.88819122, 20.74402809], [72.88819122, 20.74597359], [72.88846588, 20.74596977], [72.88846588, 20.74653053], [72.88874817, 20.74653053], [72.88874817, 20.74681091], [72.88903046, 20.74680519], [72.88903046, 20.74708366], [72.88930511, 20.74708366], [72.88930511, 20.74736023], [72.88957977, 20.74736023], [72.88957977, 20.74819565], [72.88930511, 20.74819565], [72.88930511, 20.74847221], [72.88903046, 20.74847221], [72.88903046, 20.74819565], [72.88874817, 20.74819565], [72.88874817, 20.74791718], [72.88846588, 20.74792099], [72.88846588, 20.74763107], [72.88819122, 20.7476387], [72.88819122, 20.74736023], [72.88791656, 20.74736023], [72.88791656, 20.74653053], [72.88764191, 20.74653053], [72.88764191, 20.74625015], [72.88735962, 20.74625015], [72.88735962, 20.74596977], [72.88708496, 20.74597359], [72.88708496, 20.74541664], [72.88680267, 20.74542046], [72.88680267, 20.7448597], [72.88652802, 20.74486351], [72.88652802, 20.74430466], [72.88625336, 20.74430466], [72.88625336, 20.74402809], [72.88597107, 20.74403191], [72.88597107, 20.74319077], [72.88569641, 20.74319458], [72.88569641, 20.74291611], [72.88513947, 20.74292183], [72.88513947, 20.74264145], [72.88484955, 20.74264145], [72.88484955, 20.74235916], [72.88430786, 20.74235916], [72.88430786, 20.74208069], [72.88096619, 20.74208069], [72.88097382, 20.74235916], [72.87958527, 20.74235916], [72.87958527, 20.74347115], [72.88041687, 20.74347115], [72.88041687, 20.74430466], [72.87735748, 20.74430466], [72.87735748, 20.74402809], [72.87708282, 20.74402809], [72.87708282, 20.74430466], [72.87680817, 20.74430466], [72.87680817, 20.74458122], [72.87569427, 20.74458122], [72.87569427, 20.74486351], [72.87403107, 20.7448597], [72.87403107, 20.74514008], [72.87319183, 20.74514008], [72.87319183, 20.74542046], [72.87264252, 20.74542046], [72.87264252, 20.74570084], [72.87208557, 20.74569511], [72.87208557, 20.74597359], [72.87097168, 20.74596977], [72.87097168, 20.74625015], [72.87014008, 20.74625015], [72.87014008, 20.74653053], [72.86958313, 20.74653053], [72.86958313, 20.74681091], [72.86930847, 20.74680519], [72.86930847, 20.74708366], [72.86902618, 20.74707985], [72.86902618, 20.74736023], [72.86846924, 20.74736023], [72.86846924, 20.7476387], [72.86818695, 20.74763107], [72.86818695, 20.74792099], [72.86736298, 20.74791718], [72.86736298, 20.74819565], [72.86680603, 20.74818993], [72.86680603, 20.74930954], [72.86653137, 20.74930573], [72.86653137, 20.7495842], [72.86624908, 20.74958038], [72.86624908, 20.75041962], [72.86597443, 20.7504158], [72.86597443, 20.75097275], [72.86569214, 20.75097084], [72.86569214, 20.75152969], [72.86541748, 20.75152969], [72.86541748, 20.75181007], [72.86513519, 20.75180626], [72.86514282, 20.75263977], [72.86486053, 20.75263977], [72.86486053, 20.75291824], [72.86458588, 20.75291634], [72.86458588, 20.75319481], [72.86430359, 20.75319481], [72.86430359, 20.75347137], [72.86403656, 20.75346947], [72.86403656, 20.75375938], [72.86374664, 20.75375938], [72.86374664, 20.75402832], [72.86347198, 20.75402832], [72.86347198, 20.75430489], [72.86319733, 20.75430489], [72.86319733, 20.75458336], [72.86292267, 20.75457954], [72.86292267, 20.7551384], [72.86264038, 20.7551384], [72.86264038, 20.75542068], [72.86235809, 20.75542068], [72.86235809, 20.75764275], [72.86207581, 20.75764275], [72.86207581, 20.75875282], [72.86180878, 20.75875282], [72.86180878, 20.76041985], [72.86208344, 20.76041603], [72.86208344, 20.76097488], [72.86180878, 20.76097107], [72.86180878, 20.76124954], [72.86152649, 20.76124954], [72.86152649, 20.76152992], [72.86125183, 20.76152992], [72.86125183, 20.7618103], [72.86096954, 20.76180649], [72.86096954, 20.76208305], [72.86067963, 20.76208115], [72.86067963, 20.76264], [72.86042023, 20.76264], [72.86042023, 20.76292992], [72.86013794, 20.76292992], [72.86013794, 20.76320076], [72.85986328, 20.76319695], [72.85986328, 20.7634716], [72.85958099, 20.7634697], [72.85958099, 20.76375008], [72.85930634, 20.76375008], [72.85930634, 20.76431084], [72.85902405, 20.76430511], [72.85902405, 20.76458359], [72.85874939, 20.76458359], [72.85874939, 20.76486206], [72.85791016, 20.76486015], [72.85791016, 20.76514053], [72.85736084, 20.76514053], [72.85736084, 20.76542091], [72.85708618, 20.76542091], [72.85708618, 20.76569939], [72.85680389, 20.76569366], [72.85680389, 20.76597214], [72.85624695, 20.76597023], [72.85624695, 20.76625061], [72.85486603, 20.76625061], [72.85486603, 20.76652908], [72.85346985, 20.76652908], [72.85346985, 20.76680946], [72.8520813, 20.76680565], [72.8520813, 20.76708412], [72.85180664, 20.76708031], [72.85180664, 20.76736069], [72.85098267, 20.76736069], [72.85098267, 20.76763916], [72.84986115, 20.76763916], [72.84986115, 20.76791763], [72.84902954, 20.76791763], [72.84902954, 20.7681942], [72.84819794, 20.7681942], [72.84819794, 20.76847267], [72.84708405, 20.76847267], [72.84708405, 20.76874924], [72.8465271, 20.7687397], [72.8465271, 20.76903152], [72.84625244, 20.76903152], [72.84625244, 20.7693119], [72.84597015, 20.76930618], [72.84597015, 20.76958275], [72.84541321, 20.76958084], [72.84541321, 20.76985931], [72.84513855, 20.76985931], [72.84513855, 20.77042007], [72.84485626, 20.77042007], [72.84485626, 20.77125168], [72.8445816, 20.77125168], [72.8445816, 20.77236366], [72.84430695, 20.77236176], [72.84430695, 20.77264023], [72.84348297, 20.77264023], [72.84348297, 20.77292061], [72.84319305, 20.77292061], [72.84319305, 20.7732029], [72.8429184, 20.77319527], [72.8429184, 20.77347374], [72.84263611, 20.77346992], [72.84263611, 20.77431107], [72.84236145, 20.77431107], [72.84236145, 20.77486992], [72.84208679, 20.77486992], [72.84208679, 20.77514076], [72.8418045, 20.77513885], [72.8418045, 20.7756958], [72.84152985, 20.7756958], [72.84152985, 20.77597237], [72.84124756, 20.77597046], [72.84124756, 20.77625084], [72.84069824, 20.77625084], [72.84069824, 20.77653122], [72.84041595, 20.77653122], [72.84041595, 20.77680969], [72.83985901, 20.77680588], [72.83985901, 20.77708244], [72.83930206, 20.77708054], [72.83930206, 20.77736092], [72.8390274, 20.77736092], [72.8390274, 20.77763939], [72.83875275, 20.77763939], [72.83875275, 20.77793121], [72.83847046, 20.77791786], [72.83847046, 20.7784729], [72.8381958, 20.77847099], [72.8381958, 20.77902985], [72.83791351, 20.77902794], [72.83791351, 20.77958298], [72.83763885, 20.77958298], [72.83763885, 20.77986145], [72.83735657, 20.77985954], [72.83735657, 20.7804203], [72.83679962, 20.7804203], [72.83679962, 20.78070068], [72.83651733, 20.78070068], [72.83652496, 20.7805481], [72.83652496, 20.78041649], [72.83598328, 20.7804203], [72.83598328, 20.78070068], [72.8354187, 20.78069496], [72.8354187, 20.78097153], [72.83513641, 20.78096962], [72.83513641, 20.78152847], [72.83486176, 20.78152847], [72.83486176, 20.78181076], [72.8345871, 20.78180504], [72.8345871, 20.78347015], [72.83486176, 20.78347015], [72.83486176, 20.78430939], [72.83513641, 20.78430557], [72.83513641, 20.78458405], [72.83569336, 20.78458023], [72.83569336, 20.78486252], [72.83589935, 20.78486252], [72.83597565, 20.78486252], [72.83598328, 20.78541946], [72.83625031, 20.78541946], [72.83625031, 20.78680992], [72.83597565, 20.78680611], [72.83597565, 20.78819466], [72.83569336, 20.78819466], [72.83569336, 20.78958321], [72.8354187, 20.78957939], [72.8354187, 20.79070091], [72.83569336, 20.79070091], [72.83569336, 20.79125023], [72.83651733, 20.79125023], [72.83651733, 20.79153061], [72.83679962, 20.79153061], [72.83679962, 20.79181099], [72.8373642, 20.79180527], [72.8373642, 20.79208374], [72.83763885, 20.79207993], [72.83763885, 20.79264069], [72.83790588, 20.79264069], [72.83790588, 20.79430962], [72.83763885, 20.7943058], [72.83763885, 20.79597282], [72.83790588, 20.79597092], [72.83790588, 20.79681015], [72.8381958, 20.79680634], [72.8381958, 20.79735947], [72.83847046, 20.79735947], [72.83847046, 20.79792023], [72.83875275, 20.79792023], [72.83875275, 20.79875183], [72.83986664, 20.79875183], [72.83986664, 20.7990303], [72.84069061, 20.7990303], [72.84069824, 20.79875183], [72.8409729, 20.79875183], [72.8409729, 20.79818916], [72.84124756, 20.79819489], [72.84124756, 20.79791641], [72.84152985, 20.79792023], [72.84152985, 20.79764175], [72.84208679, 20.79764175], [72.84208679, 20.79735947], [72.84263611, 20.79735947], [72.84263611, 20.7970829], [72.84347534, 20.7970829], [72.84347534, 20.79735947], [72.84390259, 20.79735947], [72.84401703, 20.79735947], [72.84401703, 20.79764175], [72.84430695, 20.79764175], [72.84430695, 20.79792023], [72.84513855, 20.79791641], [72.84513855, 20.79847336], [72.8473587, 20.79847336], [72.8473587, 20.79819489], [72.84819794, 20.79819489], [72.84819794, 20.79791641], [72.84958649, 20.79791641], [72.84958649, 20.79819489], [72.85041809, 20.79819489], [72.85041809, 20.79847336], [72.85069275, 20.79846954], [72.85069275, 20.7990303], [72.85041809, 20.7990303], [72.85041809, 20.79931068], [72.84986115, 20.79930305], [72.84986115, 20.79958344], [72.84958649, 20.79958344], [72.84958649, 20.79986382], [72.84902954, 20.79986191], [72.84902954, 20.80014038], [72.84873962, 20.80014038], [72.84873962, 20.80042076], [72.8484726, 20.80041695], [72.8484726, 20.8006897], [72.84819794, 20.80070114], [72.84819794, 20.80125046], [72.84764099, 20.80125046], [72.84764099, 20.80153084], [72.8473587, 20.80153084], [72.8473587, 20.80264091], [72.84708405, 20.80263901], [72.84708405, 20.80335045], [72.84708405, 20.80347252], [72.84680939, 20.80347061], [72.84680176, 20.80375099], [72.8456955, 20.80374908], [72.8456955, 20.80347252], [72.84348297, 20.80347061], [72.84348297, 20.80375099], [72.84319305, 20.80375099], [72.84319305, 20.80402946], [72.84263611, 20.80402946], [72.84263611, 20.80430984], [72.84208679, 20.80430794], [72.84208679, 20.8045826], [72.84152985, 20.8045826], [72.84152985, 20.80471992], [72.84152985, 20.80486107], [72.84111786, 20.80485535], [72.84069824, 20.80484962], [72.84069824, 20.80513954], [72.8390274, 20.80513954], [72.8390274, 20.80484962], [72.83763885, 20.80486107], [72.83763885, 20.8045826], [72.8373642, 20.8045826], [72.8373642, 20.80430794], [72.83597565, 20.80430794], [72.83597565, 20.8045826], [72.8354187, 20.8045826], [72.8354187, 20.80486107], [72.8345871, 20.80486107], [72.8345871, 20.80569458], [72.83429718, 20.80569077], [72.83429718, 20.80624962], [72.83403015, 20.80624962], [72.83403015, 20.80597115], [72.83347321, 20.80597115], [72.83347321, 20.80652809], [72.83291626, 20.80652618], [72.83291626, 20.80680466], [72.83235931, 20.80680466], [72.83235931, 20.80708313], [72.83208466, 20.80708313], [72.83208466, 20.8073616], [72.83152771, 20.8073597], [72.83152771, 20.80763817], [72.83125305, 20.80763817], [72.83125305, 20.80791664], [72.83097076, 20.80791092], [72.83097076, 20.80820084], [72.83069611, 20.80819511], [72.83069611, 20.80847168], [72.83040619, 20.80846977], [72.83040619, 20.80874825], [72.83013916, 20.80874825], [72.83013916, 20.80903053], [72.82985687, 20.80903053], [72.82985687, 20.80931091], [72.82958221, 20.80930519], [72.82958221, 20.80958366], [72.82875061, 20.80957985], [72.82875061, 20.80985832], [72.82847595, 20.80985832], [72.82847595, 20.8104229], [72.82819366, 20.81041718], [72.82819366, 20.81097031], [72.82792664, 20.81097031], [72.82792664, 20.81180954], [72.82763672, 20.81180954], [72.82763672, 20.81236267], [72.82736206, 20.81236267], [72.82736206, 20.81264114], [72.82707977, 20.81264114], [72.82707977, 20.81291962], [72.82680511, 20.8129158], [72.82680511, 20.81319427], [72.82653046, 20.81319427], [72.82653046, 20.81347466], [72.82624817, 20.81347275], [72.82624817, 20.81404114], [72.82596588, 20.81404114], [72.82596588, 20.81431007], [72.82569122, 20.81431007], [72.82569122, 20.81624985], [72.82597351, 20.81624985], [72.82597351, 20.81708336], [72.82569122, 20.81707954], [72.82569122, 20.81792068], [72.82541656, 20.81792068], [72.82541656, 20.81903076], [72.82514191, 20.81903076], [72.82514191, 20.82014084], [72.82485962, 20.82013893], [72.82485962, 20.82069397], [72.82458496, 20.82069397], [72.82458496, 20.82097244], [72.82430267, 20.82097054], [72.82430267, 20.82180977], [72.82402802, 20.82180977], [72.82402802, 20.82235909], [72.82375336, 20.82235909], [72.82375336, 20.8231945], [72.82347107, 20.82319069], [72.82347107, 20.82403183], [72.82319641, 20.82402992], [72.82319641, 20.82458115], [72.82290649, 20.82457924], [72.82290649, 20.82542038], [72.82263947, 20.82542038], [72.82263947, 20.82625008], [72.82235718, 20.82625008], [72.82235718, 20.82681084], [72.82208252, 20.82681084], [72.82208252, 20.82764053], [72.82180023, 20.82764053], [72.82180023, 20.82792091], [72.82208252, 20.8279171], [72.82208252, 20.82847214], [72.82180023, 20.82847023], [72.82180023, 20.82930946], [72.82152557, 20.82930565], [72.8215332, 20.82986069], [72.82125092, 20.82986069], [72.82125092, 20.83097267], [72.82096863, 20.83097076], [72.82096863, 20.83180809], [72.82068634, 20.83180809], [72.82068634, 20.83263969], [72.82041931, 20.83263969], [72.82041931, 20.83291817], [72.82013702, 20.83291626], [72.82013702, 20.8334713], [72.81986237, 20.83346939], [72.81986237, 20.83542061], [72.81958008, 20.83542061], [72.81958008, 20.83569908], [72.81931305, 20.83569908], [72.81931305, 20.83681107], [72.81903076, 20.83681107], [72.81903076, 20.83792114], [72.81874847, 20.83791733], [72.81874847, 20.83847046], [72.81846619, 20.83847046], [72.81846619, 20.83875275], [72.81819153, 20.83875275], [72.81819153, 20.83958054], [72.81791687, 20.83958054], [72.81791687, 20.84013939], [72.81764221, 20.84013939], [72.81764221, 20.84124947], [72.81735992, 20.84124947], [72.81735992, 20.84181023], [72.8170929, 20.84181023], [72.8170929, 20.84263992], [72.81680298, 20.84263992], [72.81680298, 20.84320068], [72.81652832, 20.84320068], [72.81652832, 20.84375], [72.81624603, 20.84375], [72.81624603, 20.84431076], [72.81597137, 20.84430695], [72.81597137, 20.84458351], [72.81569672, 20.8445797], [72.81569672, 20.84514046], [72.81541443, 20.84513855], [72.81541443, 20.84569359], [72.81513977, 20.84568977], [72.81513977, 20.84653091], [72.81485748, 20.8465271], [72.81485748, 20.84708405], [72.81458282, 20.84708023], [72.81458282, 20.84791756], [72.81430817, 20.84791756], [72.81430817, 20.8484726], [72.81402588, 20.84847069], [72.81402588, 20.84931183], [72.81375122, 20.84931183], [72.81375122, 20.84985924], [72.81346893, 20.84985924], [72.81346893, 20.85069466], [72.81318665, 20.85069084], [72.81318665, 20.8512516], [72.81291962, 20.8512516], [72.81291962, 20.8520813], [72.81263733, 20.85207939], [72.81263733, 20.85264015], [72.81236267, 20.85263824], [72.81236267, 20.85347366], [72.81208038, 20.85346985], [72.81208038, 20.85403061], [72.81180573, 20.8540287], [72.81181335, 20.85486031], [72.81153107, 20.85486031], [72.81153107, 20.85569572], [72.81124878, 20.85569], [72.81124878, 20.85625076], [72.81097412, 20.85625076], [72.81097412, 20.85708427], [72.81069183, 20.85708046], [72.81069183, 20.85764122], [72.81041718, 20.85764122], [72.81041718, 20.85791969], [72.81014252, 20.85791779], [72.81014252, 20.85819435], [72.80986023, 20.85819435], [72.80986023, 20.85847282], [72.8095932, 20.85847092], [72.8095932, 20.86013985], [72.80930328, 20.86013985], [72.80930328, 20.86069489], [72.80902863, 20.86069107], [72.80902863, 20.86124992], [72.80874634, 20.86124992], [72.80874634, 20.86181068], [72.80847168, 20.86180496], [72.80847168, 20.86236191], [72.80819702, 20.86235809], [72.80819702, 20.86292076], [72.80791473, 20.86291695], [72.80791473, 20.86347008], [72.80764008, 20.86346817], [72.80764008, 20.86403275], [72.80735779, 20.86402702], [72.80735779, 20.86458206], [72.80708313, 20.86458015], [72.80708313, 20.86515045], [72.80680847, 20.86514091], [72.80680847, 20.86569214], [72.80652618, 20.86569023], [72.80652618, 20.86652946], [72.80625153, 20.86652756], [72.80625153, 20.8670845], [72.80596924, 20.86708069], [72.80596924, 20.86763954], [72.80569458, 20.86763954], [72.80569458, 20.86819458], [72.80541992, 20.86819077], [72.80541992, 20.86874962], [72.80513763, 20.86874962], [72.80513763, 20.86958313], [72.80486298, 20.86958122], [72.80486298, 20.87014008], [72.80458069, 20.87014008], [72.80458069, 20.87070084], [72.80430603, 20.87070084], [72.80430603, 20.87125015], [72.80403137, 20.87125015], [72.80403137, 20.87181091], [72.80375671, 20.87181091], [72.80375671, 20.87264061], [72.80347443, 20.8726387], [72.80347443, 20.87319374], [72.80319214, 20.87318993], [72.80319214, 20.87402916], [72.80291748, 20.87402725], [72.80291748, 20.8745842], [72.80264282, 20.87458038], [72.80264282, 20.87542152], [72.80236053, 20.8754158], [72.80236053, 20.87597275], [72.80208588, 20.87597084], [72.80208588, 20.8765316], [72.80179596, 20.8765316], [72.80179596, 20.87681007], [72.80152893, 20.87681007], [72.80152893, 20.87709045], [72.80124664, 20.87708282], [72.80124664, 20.87847328], [72.80097198, 20.87846947], [72.80097198, 20.87903023], [72.80069733, 20.87902832], [72.80069733, 20.87986374], [72.80042267, 20.87985992], [72.80042267, 20.88042068], [72.80014038, 20.88041687], [72.80014038, 20.88097382], [72.79985809, 20.88097], [72.79985809, 20.88153076], [72.79958344, 20.88152695], [72.79958344, 20.8820858], [72.79930878, 20.88208008], [72.79930878, 20.88264084], [72.79902649, 20.88263893], [72.79902649, 20.88319588], [72.79875183, 20.88319016], [72.79875183, 20.88375092], [72.79846954, 20.88375092], [72.79846954, 20.88430977], [72.79818726, 20.88430977], [72.79818726, 20.88486099], [72.79792023, 20.88486099], [72.79792023, 20.88513947], [72.79763794, 20.88513947], [72.79763794, 20.88597298], [72.79736328, 20.88597107], [72.79736328, 20.88652992], [72.79708099, 20.88652992], [72.79708099, 20.8868103], [72.79680634, 20.88680649], [72.79680634, 20.88736153], [72.79651642, 20.88735962], [72.79651642, 20.88792038], [72.79624939, 20.88791656], [72.79624939, 20.8884716], [72.7959671, 20.8884697], [72.7959671, 20.88902855], [72.79569244, 20.88902855], [72.79569244, 20.88958359], [72.79541779, 20.88957977], [72.79541779, 20.89013863], [72.7951355, 20.89013863], [72.7951355, 20.89097023], [72.79486084, 20.89097023], [72.79486084, 20.89125252], [72.79458618, 20.89125252], [72.79458618, 20.89180946], [72.79429626, 20.89180946], [72.79429626, 20.89236259], [72.79402924, 20.89236259], [72.79402924, 20.89291954], [72.79374695, 20.89291763], [72.79374695, 20.89347458], [72.79347229, 20.89347076], [72.79347229, 20.89402962], [72.79319763, 20.89402771], [72.79319763, 20.89458466], [72.79291534, 20.89458466], [72.79291534, 20.89513969], [72.79264069, 20.89513016], [72.79264069, 20.89542007], [72.7923584, 20.89541626], [72.7923584, 20.8959713], [72.79207611, 20.89596939], [72.79207611, 20.89653015], [72.79181671, 20.89653015], [72.79181671, 20.89792061], [72.79152679, 20.89792061], [72.79152679, 20.89875031], [72.79181671, 20.89875031], [72.79181671, 20.89903069], [72.79152679, 20.89902687], [72.79152679, 20.89958382], [72.79125214, 20.89958], [72.79125214, 20.90125847], [72.79096985, 20.90125847], [72.79096985, 20.90263939], [72.79070282, 20.90263939], [72.79070282, 20.90431976], [72.7904129, 20.90431976], [72.7904129, 20.91320038], [72.79013824, 20.91320038], [72.79013824, 20.91402817], [72.78986359, 20.91402817], [72.78986359, 20.91458321], [72.7895813, 20.91458321], [72.7895813, 20.91597176], [72.78930664, 20.91596985], [72.78930664, 20.91653061], [72.78901672, 20.91653061], [72.78901672, 20.9168129], [72.78874969, 20.91680527], [72.78874969, 20.91708374], [72.78848267, 20.91708183], [72.78848267, 20.91764259], [72.78819275, 20.91763878], [72.78819275, 20.91819382], [72.78791809, 20.91819191], [72.78791809, 20.91903114], [72.78736115, 20.91902733], [72.78736115, 20.9193058], [72.78708649, 20.9193058], [72.78708649, 20.91958427], [72.7868042, 20.91958427], [72.7868042, 20.92069244], [72.78652954, 20.92069244], [72.78652954, 20.92097473], [72.78624725, 20.92097282], [72.78624725, 20.92152977], [72.7859726, 20.92152977], [72.7859726, 20.92181015], [72.78569794, 20.92180634], [72.78569794, 20.92208481], [72.78541565, 20.92208481], [72.78541565, 20.92319679], [72.78569794, 20.92319679], [72.78569794, 20.92291641], [72.78679657, 20.92292023], [72.78679657, 20.92263985], [72.78847504, 20.92263794], [72.78847504, 20.92319679], [72.78791809, 20.92319679], [72.78791809, 20.92347145], [72.78736115, 20.92346954], [72.78736115, 20.92374992], [72.78708649, 20.92374992], [72.78708649, 20.9240303], [72.7868042, 20.9240284], [72.7868042, 20.92486191], [72.78624725, 20.92486], [72.78624725, 20.92514038], [72.7859726, 20.92514038], [72.7859726, 20.9254303], [72.78569031, 20.9254303], [72.78569031, 20.92791748], [72.7859726, 20.92791748], [72.7859726, 20.92819405], [72.78624725, 20.92818069], [72.78624725, 20.92903137], [72.78652954, 20.92903137], [72.78652954, 20.92985916], [72.7868042, 20.92985916], [72.7868042, 20.93069458], [72.78708649, 20.93069458], [72.78708649, 20.93124962], [72.78736115, 20.93123817], [72.78736115, 20.93153191], [72.7876358, 20.93152809], [72.7876358, 20.93180466], [72.78847504, 20.93180466], [72.78847504, 20.93208122], [72.7895813, 20.93208122], [72.7895813, 20.93180466], [72.79125214, 20.93180466], [72.79125214, 20.93152809], [72.79402924, 20.93153191], [72.79402924, 20.93320084], [72.79430389, 20.93319511], [72.79430389, 20.93569565], [72.79402924, 20.93569565], [72.79402924, 20.93597221], [72.79374695, 20.93597221], [72.79374695, 20.9370842], [72.79347229, 20.93708038], [72.79347229, 20.9373703], [72.79319763, 20.9373703], [72.79319763, 20.93791962], [72.79291534, 20.93791771], [72.79291534, 20.93819427], [72.79013824, 20.93819427], [72.79013824, 20.93847275], [72.78901672, 20.93847084], [72.78901672, 20.93875122], [72.78848267, 20.93875122], [72.78848267, 20.93902969], [72.78875732, 20.93902969], [72.78875732, 20.93930817], [72.78902435, 20.93930626], [72.78902435, 20.93958282], [72.78930664, 20.93958282], [72.78930664, 20.94069481], [72.78902435, 20.94069481], [72.78902435, 20.94097137], [72.78875732, 20.94096947], [72.78875732, 20.94152832], [72.78902435, 20.94152832], [72.78902435, 20.94180489], [72.7895813, 20.94180489], [72.7895813, 20.94208336], [72.78986359, 20.94208336], [72.78986359, 20.94236183], [72.7904129, 20.94235992], [72.7904129, 20.9426384], [72.79070282, 20.9426384], [72.79070282, 20.94319916], [72.79125214, 20.94319534], [72.79125214, 20.94347191], [72.79152679, 20.94346809], [72.79152679, 20.94375229], [72.79181671, 20.94375229], [72.79181671, 20.94403267], [72.79264069, 20.94403267], [72.79264069, 20.94431114], [72.79374695, 20.94431114], [72.79374695, 20.94514275], [72.79181671, 20.94514275], [72.79181671, 20.94486046], [72.79125214, 20.94486046], [72.79125214, 20.94458008], [72.79096985, 20.94458389], [72.79096985, 20.94430542], [72.7904129, 20.94431114], [72.7904129, 20.94403267], [72.7895813, 20.94403267], [72.7895813, 20.94375229], [72.78874969, 20.94375229], [72.78874969, 20.94347191], [72.78819275, 20.94347191], [72.78819275, 20.94319534], [72.7876358, 20.94319916], [72.7876358, 20.94292068], [72.78736115, 20.94292068], [72.78736115, 20.9426384], [72.78708649, 20.9426384], [72.78708649, 20.94235992], [72.78624725, 20.94236183], [72.78624725, 20.94208336], [72.78458405, 20.94208336], [72.78458405, 20.94180489], [72.78375244, 20.94180489], [72.78375244, 20.94152832], [72.78320313, 20.94152832], [72.78320313, 20.94124985], [72.78235626, 20.94124985], [72.78235626, 20.94152832], [72.7820816, 20.94152832], [72.7820816, 20.94124985], [72.78097534, 20.94124985], [72.78097534, 20.94097137], [72.78013611, 20.94097137], [72.78013611, 20.94069481], [72.7793045, 20.94069481], [72.7793045, 20.94041634], [72.7784729, 20.94043159], [72.7784729, 20.94013977], [72.77819824, 20.94013977], [72.77819061, 20.93985939], [72.7776413, 20.9398613], [72.7776413, 20.93958282], [72.77708435, 20.93958282], [72.77708435, 20.93930626], [72.7765274, 20.93930817], [72.7765274, 20.93902969], [72.77597046, 20.93902969], [72.77597046, 20.93875122], [72.7756958, 20.93875122], [72.7756958, 20.93847084], [72.7748642, 20.93847275], [72.7748642, 20.93819427], [72.77430725, 20.93819427], [72.77430725, 20.93791771], [72.77403259, 20.93791962], [72.77403259, 20.93764114], [72.77348328, 20.93764114], [72.77348328, 20.9373703], [72.77319336, 20.9373703], [72.77319336, 20.93708038], [72.7729187, 20.9370842], [72.7729187, 20.93680573], [72.77263641, 20.93680954], [72.77263641, 20.93653107], [72.77236176, 20.93653107], [72.77236176, 20.93625069], [72.7720871, 20.93625069], [72.7720871, 20.93542099], [72.77179718, 20.93542099], [72.77179718, 20.93486023], [72.77153015, 20.93486023], [72.77153015, 20.93429947], [72.77124786, 20.93430328], [72.77124786, 20.93375015], [72.77153015, 20.93375015], [72.77153015, 20.93346977], [72.77124786, 20.93347359], [72.77124786, 20.93208122], [72.77153015, 20.93208122], [72.77153015, 20.92569542], [72.77124786, 20.9256897], [72.77124786, 20.92541695], [72.77097321, 20.9254303], [72.77097321, 20.92441177], [72.77097321, 20.92152786], [72.77124786, 20.92152977], [72.77124786, 20.92041969], [72.77153015, 20.92041969], [72.77153015, 20.91986275], [72.77179718, 20.91986275], [72.77179718, 20.91958046], [72.7720871, 20.91958046], [72.7720871, 20.91902733], [72.77236176, 20.91903114], [72.77236176, 20.91819191], [72.77263641, 20.91819382], [72.77263641, 20.91791725], [72.77319336, 20.91792107], [72.77319336, 20.91764259], [72.77348328, 20.91764259], [72.77348328, 20.91736031], [72.77430725, 20.91736031], [72.77430725, 20.91708183], [72.77735901, 20.91708374], [72.77735901, 20.91680527], [72.7776413, 20.9168129], [72.7776413, 20.91653061], [72.77791595, 20.91653061], [72.77791595, 20.91624069], [72.77819061, 20.91624832], [72.77819061, 20.91486168], [72.77680206, 20.91485977], [72.77680206, 20.91513824], [72.77597046, 20.91513824], [72.77597046, 20.91542053], [72.77319336, 20.91542053], [72.77319336, 20.91570091], [72.77236176, 20.91569519], [72.77236176, 20.91597176], [72.77180481, 20.91597176], [72.77180481, 20.91624832], [72.77124786, 20.91624069], [72.77124786, 20.91653061], [72.77097321, 20.91653061], [72.77097321, 20.91708374], [72.77069092, 20.91708183], [72.77069092, 20.91736031], [72.77041626, 20.91736031], [72.77041626, 20.91792107], [72.7701416, 20.91791725], [72.7701416, 20.91819382], [72.76985931, 20.91819382], [72.76985931, 20.91847038], [72.76957703, 20.91847038], [72.76957703, 20.91875267], [72.76930237, 20.91875267], [72.76930237, 20.91903114], [72.76902771, 20.91902733], [72.76902771, 20.9193058], [72.76847076, 20.91930008], [72.76847076, 20.91986275], [72.76819611, 20.91986275], [72.76819611, 20.92014122], [72.76791382, 20.92013931], [72.76791382, 20.92069244], [72.76763916, 20.92069244], [72.76764679, 20.92124939], [72.76735687, 20.92124939], [72.76735687, 20.92152977], [72.76708221, 20.92152977], [72.76708221, 20.92181015], [72.76680756, 20.92180634], [72.76680756, 20.92236137], [72.7665329, 20.92235947], [72.7665329, 20.92292023], [72.76625061, 20.92291641], [72.76625061, 20.92347145], [72.76597595, 20.92346954], [72.76597595, 20.92374992], [72.76568604, 20.92374992], [72.76568604, 20.9240303], [72.76541901, 20.9240303], [72.76541901, 20.92514038], [72.76513672, 20.92513847], [72.76513672, 20.9256897], [72.76486206, 20.92570114], [72.76486206, 20.92625046], [72.7645874, 20.92625046], [72.7645874, 20.92681122], [72.76430511, 20.9268055], [72.76430511, 20.92708397], [72.76403046, 20.92708015], [72.76403046, 20.92736053], [72.76374817, 20.92736053], [72.76374817, 20.92791748], [72.76347351, 20.92791748], [72.76347351, 20.92847252], [72.76319122, 20.92847061], [72.76319122, 20.92903137], [72.76291656, 20.92903137], [72.76291656, 20.92931175], [72.76264191, 20.92930603], [72.76264191, 20.9295826], [72.76235962, 20.92958069], [72.76235962, 20.92985916], [72.76209259, 20.92985916], [72.76209259, 20.93042183], [72.76180267, 20.93041611], [72.76180267, 20.93097115], [72.76097107, 20.93097115], [72.76097107, 20.93124962], [72.76069641, 20.93124962], [72.76069641, 20.93180466], [72.76041412, 20.93180466], [72.76041412, 20.93236351], [72.76013947, 20.9323597], [72.76013947, 20.93292046], [72.75986481, 20.93291664], [72.75986481, 20.93347359], [72.75958252, 20.93346977], [72.75958252, 20.93403053], [72.75930786, 20.93402863], [72.75930786, 20.93458366], [72.7590332, 20.93457985], [72.7590332, 20.93514061], [72.75875092, 20.9351387], [72.75875092, 20.93569565], [72.75846863, 20.93569565], [72.75846863, 20.93597221], [72.75818634, 20.93597031], [72.75818634, 20.93653107], [72.75791931, 20.93652725], [72.75791931, 20.9370842], [72.75763702, 20.93708038], [72.75763702, 20.93764114], [72.75736237, 20.93763924], [72.75736237, 20.93819427], [72.75708008, 20.93819427], [72.75708008, 20.93847275], [72.75681305, 20.93847084], [72.75681305, 20.93902969], [72.75653076, 20.93902969], [72.75653076, 20.93930817], [72.75624847, 20.93930626], [72.75624847, 20.9398613], [72.75596619, 20.93985939], [72.75596619, 20.94043159], [72.75569153, 20.94041634], [72.75569153, 20.94069481], [72.75541687, 20.94069099], [72.75541687, 20.94124985], [72.75514221, 20.94124985], [72.75514221, 20.94152832], [72.75485992, 20.94152832], [72.75485992, 20.94208336], [72.7545929, 20.94207954], [72.7545929, 20.9426384], [72.75430298, 20.9426384], [72.75430298, 20.94292068], [72.75402832, 20.94291687], [72.75402832, 20.94347191], [72.75374603, 20.94346809], [72.75374603, 20.94403267], [72.75347137, 20.94402695], [72.75347137, 20.94458389], [72.75319672, 20.94458008], [72.75319672, 20.94514275], [72.7529068, 20.94514275], [72.7529068, 20.94542122], [72.75263977, 20.9454174], [72.75263977, 20.94597054], [72.75235748, 20.94597054], [72.75235748, 20.94652939], [72.75208282, 20.94652939], [72.75208282, 20.9473629], [72.75180817, 20.9473629], [72.75180817, 20.94847488], [72.75152588, 20.94847107], [72.75152588, 20.9493103], [72.75125122, 20.94930649], [72.75125122, 20.94958305], [72.75096893, 20.94958115], [72.75096893, 20.95042038], [72.75069427, 20.95041656], [72.75069427, 20.9509716], [72.75041962, 20.9509716], [72.75041962, 20.95208359], [72.75013733, 20.95207977], [72.75013733, 20.95236969], [72.74986267, 20.95236969], [72.74986267, 20.95264053], [72.74958038, 20.95264053], [72.74958038, 20.95375061], [72.74930573, 20.95375061], [72.74931335, 20.95486069], [72.74903107, 20.95486069], [72.74903107, 20.95541573], [72.74874878, 20.95541763], [72.74874878, 20.95597267], [72.74846649, 20.95597076], [72.74846649, 20.95653152], [72.74819183, 20.95652771], [72.74819183, 20.95708275], [72.74791718, 20.95708084], [72.74791718, 20.9576416], [72.74764252, 20.9576416], [72.74764252, 20.95819473], [72.74736023, 20.95817757], [72.74736023, 20.95903015], [72.74708557, 20.95902824], [72.74708557, 20.95986366], [72.74680328, 20.95985985], [72.74680328, 20.96042061], [72.746521, 20.96042061], [72.746521, 20.96125031], [72.74624634, 20.96125031], [72.74624634, 20.96208572], [72.74597168, 20.96208], [72.74597168, 20.96292114], [72.74569702, 20.96292114], [72.74569702, 20.96375084], [72.7454071, 20.96375084], [72.7454071, 20.96486092], [72.74514008, 20.96486092], [72.74514008, 20.96569443], [72.74485779, 20.96569061], [72.74485779, 20.96652985], [72.74458313, 20.96652794], [72.74458313, 20.96708298], [72.74430847, 20.96708107], [72.74430847, 20.9679184], [72.74402618, 20.9679184], [72.74402618, 20.96874809], [72.74375153, 20.96874809], [72.74375153, 20.96986008], [72.74346924, 20.96986008], [72.74346924, 20.97097015], [72.74318695, 20.97097015], [72.74318695, 20.97125244], [72.74291992, 20.97125244], [72.74291992, 20.97153282], [72.74263763, 20.97153282], [72.74263763, 20.97236061], [72.74236298, 20.97236061], [72.74236298, 20.97319221], [72.74208069, 20.97319031], [72.74208069, 20.97402954], [72.74180603, 20.97402954], [72.74180603, 20.97486115], [72.74153137, 20.97486115], [72.74153137, 20.97653961], [72.74124908, 20.97653961], [72.74124908, 20.97764015], [72.7409668, 20.97764015], [72.7409668, 20.97792053], [72.74069214, 20.97792053], [72.74069214, 20.97820091], [72.74041748, 20.97820091], [72.74041748, 20.97875023], [72.74014282, 20.97875023], [72.74014282, 20.97931099], [72.73986053, 20.97931099], [72.73986053, 20.97986031], [72.73958588, 20.97986031], [72.73958588, 20.98069382], [72.73929596, 20.9806881], [72.73929596, 20.98152924], [72.73958588, 20.98152924], [72.73958588, 20.98180962], [72.73930359, 20.9818058], [72.73930359, 20.98208427], [72.73902893, 20.98208427], [72.73902893, 20.98236084], [72.73874664, 20.98236084], [72.73874664, 20.98319435], [72.73847198, 20.98319054], [72.73847198, 20.98374939], [72.73819733, 20.98374939], [72.73819733, 20.98431015], [72.73792267, 20.98431015], [72.73792267, 20.98542023], [72.73764038, 20.98542023], [72.73764038, 20.9865303], [72.73735809, 20.9865303], [72.73735809, 20.98764038], [72.73707581, 20.98764038], [72.73707581, 20.98875046], [72.73680878, 20.98875046], [72.73680878, 20.98986053], [72.73652649, 20.98986053], [72.73652649, 20.99069595], [72.73625183, 20.99069023], [72.73625183, 20.99180984], [72.73596954, 20.99180984], [72.73596954, 20.99263954], [72.73569489, 20.99263954], [72.73569489, 20.99347305], [72.73542023, 20.99347305], [72.73542023, 20.99430466], [72.73513794, 20.9942894], [72.73513794, 20.99570084], [72.73486328, 20.99569511], [72.73486328, 20.99708366], [72.73458099, 20.99708366], [72.73458099, 20.99819374], [72.73430634, 20.99819183], [72.73430634, 20.99930954], [72.73402405, 20.99930573], [72.73401642, 20.99992943], [72.73401642, 21.00014114], [72.73458099, 21.00014114], [72.73458099, 21.00041962], [72.73430634, 21.00041962], [72.73430634, 21.00125122], [72.73401642, 21.00125122], [72.73401642, 21.00152969], [72.73374939, 21.00152779], [72.73374939, 21.0023613], [72.73401642, 21.00235939], [72.73401642, 21.0051403], [72.73374939, 21.0051384], [72.73374939, 21.00597191], [72.73347473, 21.00597191], [72.73347473, 21.00652885], [72.73319244, 21.00652122], [72.73319244, 21.00681114], [72.73291779, 21.00680542], [72.73291779, 21.00819397], [72.73264313, 21.00819016], [72.73264313, 21.0090313], [72.73236084, 21.0090313], [72.73236084, 21.01042175], [72.73208618, 21.01041603], [72.73208618, 21.01097107], [72.73179626, 21.01096916], [72.73179626, 21.0118103], [72.73153687, 21.0118103], [72.73153687, 21.01320076], [72.73124695, 21.01320076], [72.73124695, 21.01375008], [72.73097229, 21.01375008], [72.73097229, 21.01597214], [72.73069763, 21.01597023], [72.73069763, 21.01653099], [72.73041534, 21.01652718], [72.73042297, 21.01736069], [72.7298584, 21.01736069], [72.7298584, 21.01875114], [72.72957611, 21.01875114], [72.72957611, 21.01930809], [72.72930908, 21.01930809], [72.72930908, 21.01986122], [72.72902679, 21.01986122], [72.72902679, 21.02041817], [72.72875214, 21.02041626], [72.72875214, 21.0209713], [72.72847748, 21.02096939], [72.72847748, 21.02152824], [72.72820282, 21.02152824], [72.72820282, 21.02263832], [72.7279129, 21.02263832], [72.7279129, 21.02292061], [72.72763824, 21.02292061], [72.72763824, 21.02542114], [72.72735596, 21.02542114], [72.72735596, 21.02625275], [72.7270813, 21.02625275], [72.7270813, 21.02680969], [72.72680664, 21.02680969], [72.72680664, 21.02736282], [72.72651672, 21.02736282], [72.72651672, 21.02931023], [72.72624969, 21.02930641], [72.72624969, 21.02986145], [72.72597504, 21.02986145], [72.72597504, 21.03069687], [72.72569275, 21.03069115], [72.72569275, 21.03153038], [72.72541809, 21.03152847], [72.72541809, 21.03208351], [72.7251358, 21.03208351], [72.7251358, 21.03319359], [72.72486115, 21.03319359], [72.72486115, 21.03347206], [72.72458649, 21.03347015], [72.72458649, 21.03403091], [72.7243042, 21.0340271], [72.7243042, 21.0359726], [72.72402954, 21.03597069], [72.72402954, 21.03624916], [72.72374725, 21.03624916], [72.72374725, 21.04042053], [72.72402954, 21.04042053], [72.72402954, 21.04125023], [72.72429657, 21.04125023], [72.72429657, 21.04181099], [72.72458649, 21.04181099], [72.72458649, 21.04403114], [72.7243042, 21.04402733], [72.7243042, 21.04458427], [72.72402954, 21.04458046], [72.72402954, 21.04624939], [72.72374725, 21.04624939], [72.72374725, 21.04736137], [72.7234726, 21.04735947], [72.7234726, 21.04791832], [72.72319794, 21.04791832], [72.72319794, 21.0490284], [72.7234726, 21.0490284], [72.7234726, 21.04958344], [72.72374725, 21.04957962], [72.72374725, 21.05013847], [72.72402954, 21.05013847], [72.72402954, 21.05042267], [72.7243042, 21.05041695], [72.7243042, 21.05069351], [72.72458649, 21.05069351], [72.72458649, 21.05097008], [72.72486115, 21.05097008], [72.72486115, 21.05125046], [72.7251358, 21.05125046], [72.7251358, 21.05153275], [72.72541809, 21.05152702], [72.72541809, 21.05208206], [72.72569275, 21.05208015], [72.72569275, 21.05264282], [72.72598267, 21.05264282], [72.72598267, 21.05291939], [72.72624969, 21.05291748], [72.72624969, 21.05319214], [72.72652435, 21.05319214], [72.72652435, 21.05347443], [72.7270813, 21.05347443], [72.7270813, 21.05319214], [72.72763824, 21.05319214], [72.72763824, 21.05263901], [72.72820282, 21.05264282], [72.72820282, 21.05236053], [72.72875214, 21.05236053], [72.72875214, 21.05208015], [72.72902679, 21.05208206], [72.72902679, 21.05152702], [72.72930908, 21.05153275], [72.72930908, 21.05125046], [72.7298584, 21.05125046], [72.7298584, 21.0506916], [72.73014069, 21.05069351], [72.73014069, 21.05041695], [72.73097229, 21.05042267], [72.73097229, 21.05013847], [72.73124695, 21.05013847], [72.73124695, 21.04985809], [72.73152924, 21.04986191], [72.73152924, 21.04958344], [72.73180389, 21.04958344], [72.73180389, 21.04930496], [72.73208618, 21.04931068], [72.73208618, 21.0490284], [72.73236084, 21.0490284], [72.73236084, 21.04875946], [72.73319244, 21.04875946], [72.73319244, 21.04846954], [72.73347473, 21.04847145], [72.73347473, 21.04829979], [72.73347473, 21.04819489], [72.73374939, 21.04819489], [72.73374939, 21.04791641], [72.73401642, 21.04791832], [72.73401642, 21.04763985], [72.73568726, 21.04763985], [72.73568726, 21.04735947], [72.73792267, 21.04735947], [72.73792267, 21.04763985], [72.73819733, 21.04763985], [72.73819733, 21.04735947], [72.73874664, 21.04735947], [72.73874664, 21.04763985], [72.73958588, 21.04763985], [72.73958588, 21.04791832], [72.73986053, 21.04791641], [72.73986053, 21.04819489], [72.74041748, 21.04819489], [72.74041748, 21.04847145], [72.7409668, 21.04846954], [72.7409668, 21.04875946], [72.74124908, 21.04875946], [72.74124908, 21.0490284], [72.74208069, 21.0490284], [72.74208069, 21.04931068], [72.74263763, 21.04930496], [72.74263763, 21.04986191], [72.74318695, 21.04985809], [72.74318695, 21.05013847], [72.74402618, 21.05013847], [72.74402618, 21.05042267], [72.74485779, 21.05041695], [72.74485779, 21.05069351], [72.74764252, 21.05069351], [72.74764252, 21.05097008], [72.74930573, 21.05097008], [72.74930573, 21.05125046], [72.74958038, 21.05125046], [72.74958038, 21.05097008], [72.75013733, 21.05097008], [72.75013733, 21.05125046], [72.75152588, 21.05125046], [72.75152588, 21.05153275], [72.75319672, 21.05153275], [72.75319672, 21.05182076], [72.76069641, 21.0518055], [72.76069641, 21.05208206], [72.76125336, 21.05208015], [72.76125336, 21.05236053], [72.76152802, 21.05236053], [72.76152802, 21.05319214], [72.76125336, 21.05319023], [72.76125336, 21.05402946], [72.76097107, 21.05402946], [72.76097107, 21.05430984], [72.76040649, 21.05430984], [72.76040649, 21.05486107], [72.76069641, 21.05486107], [72.76069641, 21.05513954], [72.76097107, 21.05513954], [72.76097107, 21.05541992], [72.76125336, 21.0554142], [72.76125336, 21.05569458], [72.76152802, 21.05569458], [72.76152802, 21.05597305], [72.76180267, 21.05597115], [72.76180267, 21.05653], [72.76208496, 21.05652809], [72.76208496, 21.05680656], [72.76235962, 21.05680656], [72.76235962, 21.05708313], [72.76291656, 21.05708313], [72.76291656, 21.05763817], [72.76319122, 21.05763054], [72.76319122, 21.05792046], [72.76346588, 21.05792046], [72.76346588, 21.05820084], [72.76430511, 21.05819511], [72.76430511, 21.05847168], [72.76457977, 21.05847168], [72.76457977, 21.05819511], [72.76486206, 21.05820084], [72.76486206, 21.05792046], [72.76568604, 21.05792046], [72.76568604, 21.05820084], [72.76625061, 21.05819511], [72.76625061, 21.05847168], [72.76680756, 21.05846977], [72.76680756, 21.05875015], [72.76847076, 21.05875015], [72.76847076, 21.06097221], [72.76819611, 21.06097031], [72.76819611, 21.06263924], [72.76847076, 21.06263924], [72.76847076, 21.06319427], [72.76875305, 21.06319427], [72.76875305, 21.06347275], [72.76930237, 21.06347084], [72.76930237, 21.06431007], [72.76958466, 21.06430626], [72.76958466, 21.06485939], [72.76985931, 21.06485939], [72.76985931, 21.06569481], [72.7701416, 21.0656929], [72.7701416, 21.06624985], [72.77041626, 21.06624985], [72.77041626, 21.06680489], [72.7701416, 21.06680489], [72.7701416, 21.06708145], [72.76985931, 21.06708145], [72.76985931, 21.06736374], [72.76957703, 21.06735992], [72.76957703, 21.0676403], [72.76930237, 21.0676403], [72.76930237, 21.06792068], [72.76902771, 21.06792068], [72.76902771, 21.06820107], [72.76875305, 21.06819534], [72.76875305, 21.06847382], [72.76763916, 21.06847382], [72.76763916, 21.06819534], [72.76735687, 21.06820107], [72.76735687, 21.06792068], [72.76680756, 21.06792068], [72.76680756, 21.0676403], [72.76541901, 21.0676403], [72.76541901, 21.06735992], [72.76513672, 21.06736374], [72.76513672, 21.06708145], [72.76457977, 21.06708145], [72.76457977, 21.06680489], [72.76430511, 21.06680489], [72.76430511, 21.06652832], [72.76374817, 21.06653023], [72.76374817, 21.06624985], [72.76291656, 21.06624985], [72.76291656, 21.06596947], [72.76208496, 21.06597137], [72.76208496, 21.06569481], [72.76180267, 21.06569481], [72.76180267, 21.06541634], [72.76125336, 21.06542015], [72.76125336, 21.06514168], [72.76069641, 21.06514168], [72.76069641, 21.06485939], [72.76041412, 21.06485939], [72.76041412, 21.06458282], [72.76013947, 21.06458282], [72.76013947, 21.06430626], [72.75985718, 21.06431007], [72.75985718, 21.06376266], [72.75958252, 21.06376266], [72.75958252, 21.06347084], [72.75846863, 21.06347275], [72.75846863, 21.06319427], [72.75763702, 21.06319427], [72.75763702, 21.0629158], [72.75736237, 21.06292152], [72.75736237, 21.06263924], [72.75653076, 21.06263924], [72.75653076, 21.06236076], [72.75624847, 21.06236076], [72.75624847, 21.06208038], [72.75208282, 21.06208038], [72.75208282, 21.06236076], [72.75125122, 21.06236076], [72.75125122, 21.06208038], [72.75096893, 21.06208038], [72.75096893, 21.06236076], [72.75068665, 21.06236076], [72.75068665, 21.06263924], [72.74931335, 21.06263924], [72.74931335, 21.06292152], [72.74819183, 21.0629158], [72.74819183, 21.06319427], [72.74764252, 21.06319427], [72.74764252, 21.06347275], [72.74680328, 21.06347084], [72.74680328, 21.06376266], [72.746521, 21.06376266], [72.746521, 21.0640316], [72.74597168, 21.0640316], [72.74597168, 21.06431007], [72.74514008, 21.06430626], [72.74514008, 21.06458282], [72.74458313, 21.06458092], [72.74458313, 21.06514168], [72.74430847, 21.06514168], [72.74430847, 21.06542015], [72.74402618, 21.06541634], [72.74402618, 21.06569481], [72.74319458, 21.06569481], [72.74319458, 21.06597137], [72.74291992, 21.06596947], [72.74291992, 21.06624985], [72.74236298, 21.06624985], [72.74236298, 21.06653023], [72.74208069, 21.06652832], [72.74208069, 21.06680489], [72.74180603, 21.06680489], [72.74180603, 21.06652832], [72.74153137, 21.06652832], [72.74153137, 21.06708145], [72.73902893, 21.06708145], [72.73902893, 21.06736374], [72.73792267, 21.06735992], [72.73792267, 21.0676403], [72.73652649, 21.0676403], [72.73652649, 21.06820107], [72.73569489, 21.06819534], [72.73569489, 21.06847382], [72.73486328, 21.06847], [72.73486328, 21.06875038], [72.73458099, 21.06875038], [72.73458099, 21.06903076], [72.7334671, 21.06903076], [72.7334671, 21.06931114], [72.7326355, 21.06930542], [72.7326355, 21.0695858], [72.73179626, 21.06957054], [72.73180389, 21.06986046], [72.73153687, 21.06986046], [72.73153687, 21.07014084], [72.72930908, 21.07014084], [72.72930908, 21.07042122], [72.72846985, 21.0704174], [72.72846985, 21.07069588], [72.72651672, 21.07069016], [72.72651672, 21.07125092], [72.72541809, 21.07125092], [72.72541809, 21.07152939], [72.72429657, 21.07152939], [72.72429657, 21.07180977], [72.72291565, 21.07180786], [72.72291565, 21.07208252], [72.72041321, 21.07208061], [72.72041321, 21.07236099], [72.72013855, 21.07236099], [72.72013855, 21.07263947], [72.71875, 21.07263947], [72.71875, 21.07292747], [72.71708679, 21.07291794], [72.71708679, 21.0731945], [72.71125031, 21.0731945], [72.71125031, 21.07291794], [72.71097565, 21.07291794], [72.71097565, 21.0731945], [72.7104187, 21.0731945], [72.7104187, 21.07291794], [72.70874786, 21.07291794], [72.70874786, 21.0731945], [72.7076416, 21.0731945], [72.7076416, 21.07347298], [72.70597076, 21.07347107], [72.70597076, 21.07374954], [72.70569611, 21.07374954], [72.70569611, 21.07402992], [72.70513916, 21.07402992], [72.70513916, 21.0743103], [72.7048645, 21.07430649], [72.7048645, 21.07458305], [72.70458221, 21.07458305], [72.70458221, 21.07486153], [72.70430756, 21.07485962], [72.70430756, 21.07624817], [72.7040329, 21.07624817], [72.7040329, 21.07652855], [72.70375061, 21.07652855], [72.70375061, 21.08014107], [72.7040329, 21.08014107], [72.7040329, 21.08542061], [72.70375061, 21.08542061], [72.70375061, 21.08793068], [72.70347595, 21.08793068], [72.70347595, 21.08875084], [72.70318604, 21.08875084], [72.70318604, 21.09042168], [72.70291901, 21.09041595], [72.70291901, 21.0909729], [72.70263672, 21.09096909], [72.70263672, 21.09124947], [72.70236206, 21.09124947], [72.70236206, 21.09236336], [72.70207977, 21.09235954], [72.70207977, 21.09320068], [72.70181274, 21.09320068], [72.70181274, 21.09403038], [72.70153046, 21.09402847], [72.70153046, 21.0956955], [72.70124817, 21.09568977], [72.70124817, 21.09736061], [72.70096588, 21.09736061], [72.70096588, 21.09791946], [72.70069122, 21.09791946], [72.70069122, 21.09987068], [72.70041656, 21.09987068], [72.70041656, 21.10041809], [72.70014191, 21.10041618], [72.70014191, 21.10097313], [72.70041656, 21.10097122], [72.70041656, 21.10152817], [72.70069122, 21.10152817], [72.70069122, 21.10263824], [72.70097351, 21.10263824], [72.70097351, 21.10291672], [72.70124817, 21.10290909], [72.70124817, 21.10320091], [72.70153046, 21.10319519], [72.70153046, 21.10347176], [72.70181274, 21.10346985], [72.70181274, 21.10403252], [72.70207977, 21.1040287], [72.70207977, 21.10458374], [72.70236206, 21.10458183], [72.70236206, 21.10514259], [72.70291901, 21.10514259], [72.70291901, 21.10542107], [72.70319366, 21.10541725], [72.70319366, 21.10569382], [72.70347595, 21.10568047], [72.70347595, 21.10625267], [72.70458221, 21.10625267], [72.70458221, 21.10680962], [72.70485687, 21.10680962], [72.70485687, 21.10736275], [72.70541382, 21.10736275], [72.70541382, 21.10958481], [72.70569611, 21.10958099], [72.70569611, 21.11181068], [72.70597076, 21.11181068], [72.70597076, 21.11264038], [72.70625305, 21.11263847], [72.70625305, 21.11458397], [72.70652771, 21.11458015], [72.70652771, 21.11514091], [72.70625305, 21.11514091], [72.70625305, 21.11541748], [72.70652771, 21.11541748], [72.70652771, 21.11597252], [72.70625305, 21.11597252], [72.70625305, 21.1170826], [72.70597076, 21.1170826], [72.70597076, 21.11819458], [72.70569611, 21.11819077], [72.70569611, 21.12181091], [72.70597076, 21.12181091], [72.70597076, 21.12292099], [72.70625305, 21.12292099], [72.70625305, 21.12486076], [72.70652771, 21.12486076], [72.70652771, 21.1273613], [72.70680237, 21.12735939], [72.70680237, 21.12791824], [72.70707703, 21.12791824], [72.70707703, 21.12874985], [72.70735931, 21.12874985], [72.70735931, 21.12958336], [72.7076416, 21.12957954], [72.7076416, 21.13042068], [72.70791626, 21.13041687], [72.70791626, 21.13097191], [72.70819092, 21.13097191], [72.70819092, 21.13125038], [72.70847321, 21.13125038], [72.70847321, 21.13181114], [72.70874786, 21.13181114], [72.70874786, 21.13236046], [72.70903015, 21.13236046], [72.70903015, 21.13292122], [72.7095871, 21.1329174], [72.7095871, 21.13319206], [72.71013641, 21.13319206], [72.71013641, 21.13347054], [72.70986176, 21.13347054], [72.70986176, 21.13375282], [72.71013641, 21.13375282], [72.71013641, 21.13402939], [72.71069336, 21.13402939], [72.71069336, 21.13430977], [72.71097565, 21.13430405], [72.71097565, 21.1348629], [72.71125031, 21.1348629], [72.71125031, 21.13513947], [72.71151733, 21.13513947], [72.71151733, 21.13541985], [72.71180725, 21.13541412], [72.71180725, 21.1356926], [72.71235657, 21.13569069], [72.71235657, 21.13598061], [72.71263885, 21.13598061], [72.71263885, 21.13624954], [72.71290588, 21.13624954], [72.71290588, 21.13652992], [72.7131958, 21.13652802], [72.7131958, 21.13708305], [72.71347046, 21.13708305], [72.71347046, 21.13736153], [72.71375275, 21.13735962], [72.71375275, 21.13764], [72.7140274, 21.13764], [72.7140274, 21.13820076], [72.71430206, 21.13820076], [72.71430206, 21.13931084], [72.71457672, 21.13931084], [72.71458435, 21.13986015], [72.7151413, 21.13986015], [72.7151413, 21.14014053], [72.71569824, 21.14014053], [72.71569824, 21.14042091], [72.7159729, 21.1404171], [72.7159729, 21.14069366], [72.7168045, 21.14069366], [72.7168045, 21.14097214], [72.71708679, 21.14097214], [72.71708679, 21.14069366], [72.7195816, 21.14069366], [72.7195816, 21.1404171], [72.72041321, 21.1404171], [72.72041321, 21.14069366], [72.7206955, 21.14069366], [72.7206955, 21.1431942], [72.72013855, 21.1431942], [72.72013855, 21.14347267], [72.71930695, 21.14347076], [72.71930695, 21.14374924], [72.71875, 21.14374924], [72.71875, 21.14403152], [72.7159729, 21.14403152], [72.7159729, 21.1443119], [72.71485901, 21.14430618], [72.71485901, 21.14458275], [72.7140274, 21.14458084], [72.7140274, 21.14485931], [72.71347046, 21.14485931], [72.71347046, 21.14513969], [72.71235657, 21.14513969], [72.71235657, 21.14542007], [72.71013641, 21.14541626], [72.71013641, 21.14569473], [72.70986176, 21.14569473], [72.70986176, 21.1459713], [72.70874786, 21.14596939], [72.70874786, 21.14653015], [72.70791626, 21.14652824], [72.70791626, 21.14680481], [72.70652771, 21.14680481], [72.70652771, 21.14708138], [72.70597076, 21.14708138], [72.70597076, 21.14736366], [72.70540619, 21.14735985], [72.70540619, 21.14792061], [72.70430756, 21.14792061], [72.70430756, 21.14821053], [72.70375061, 21.14819527], [72.70375061, 21.14847374], [72.70347595, 21.14846992], [72.70347595, 21.14875031], [72.70318604, 21.14875031], [72.70318604, 21.14903069], [72.70263672, 21.14903069], [72.70263672, 21.14931107], [72.70180511, 21.14930344], [72.70180511, 21.14958572], [72.70124817, 21.14958], [72.70124817, 21.14986038], [72.70096588, 21.14986038], [72.70096588, 21.15014076], [72.70069122, 21.15014076], [72.70069122, 21.15042114], [72.69985962, 21.15041733], [72.69985962, 21.1506958], [72.69957733, 21.15069008], [72.69957733, 21.15098], [72.69875336, 21.15098], [72.69875336, 21.15125084], [72.69847107, 21.15125084], [72.69847107, 21.15153122], [72.69790649, 21.15153122], [72.69790649, 21.15180969], [72.69736481, 21.15180779], [72.69736481, 21.15208244], [72.69680786, 21.15208054], [72.69680786, 21.15236092], [72.69625092, 21.15236092], [72.69625092, 21.15291977], [72.69596863, 21.15291786], [72.69596863, 21.15319443], [72.69569397, 21.15319443], [72.69569397, 21.1534729], [72.69513702, 21.15347099], [72.69513702, 21.15374947], [72.69458008, 21.15374947], [72.69458008, 21.15402794], [72.69403076, 21.15402794], [72.69403076, 21.15458298], [72.69347382, 21.15458298], [72.69347382, 21.15486145], [72.69264221, 21.15485954], [72.69264221, 21.15513992], [72.6920929, 21.15513992], [72.6920929, 21.1554184], [72.6904068, 21.1554184], [72.6904068, 21.15570068], [72.68985748, 21.15569496], [72.68985748, 21.15597153], [72.68930817, 21.15596962], [72.68930817, 21.15624809], [72.68846893, 21.15624809], [72.68846893, 21.15652847], [72.68680573, 21.15652847], [72.68680573, 21.15708351], [72.68569183, 21.15708351], [72.68569183, 21.15736008], [72.68486023, 21.15735817], [72.68486023, 21.15764236], [72.68347168, 21.15764236], [72.68347168, 21.15792274], [72.68264008, 21.15791702], [72.68264008, 21.15819359], [72.68125153, 21.15819359], [72.68125153, 21.15847015], [72.67874908, 21.15847015], [72.67874908, 21.15819359], [72.67819214, 21.15819359], [72.67819214, 21.15763855], [72.67736816, 21.15764236], [72.67736816, 21.15735817], [72.67680359, 21.15736008], [72.67680359, 21.15708351], [72.67652893, 21.15708351], [72.67652893, 21.15736008], [72.67318726, 21.15735817], [72.67318726, 21.15764236], [72.67124176, 21.15764236], [72.67124176, 21.15735817], [72.67069244, 21.15736008], [72.67069244, 21.15708351], [72.67041779, 21.15708351], [72.67041779, 21.15652847], [72.67014313, 21.15652847], [72.67014313, 21.15624809], [72.66986084, 21.15624809], [72.66986084, 21.15596962], [72.66930389, 21.15597153], [72.66930389, 21.15569496], [72.66874695, 21.15570068], [72.66874695, 21.1554184], [72.66707611, 21.1554184], [72.66707611, 21.15485954], [72.66680908, 21.15486145], [72.66680908, 21.15458298], [72.66625214, 21.15458298], [72.66625214, 21.15430641], [72.66596985, 21.15430832], [72.66596985, 21.15402031], [72.66569519, 21.15402794], [72.66569519, 21.15374947], [72.6654129, 21.15374947], [72.6654129, 21.15347099], [72.66513824, 21.1534729], [72.66513824, 21.15291786], [72.66485596, 21.15291977], [72.66485596, 21.15236092], [72.6645813, 21.15236092], [72.6645813, 21.15180969], [72.66430664, 21.15180969], [72.66430664, 21.15069008], [72.66402435, 21.1506958], [72.66402435, 21.15041733], [72.66374969, 21.15042114], [72.66374969, 21.14958], [72.66319275, 21.14958572], [72.66319275, 21.14930344], [72.66291809, 21.14931107], [72.66291809, 21.14903069], [72.6626358, 21.14903069], [72.6626358, 21.14846992], [72.66236115, 21.14847374], [72.66236115, 21.14819527], [72.66208649, 21.14821053], [72.66208649, 21.14764023], [72.66179657, 21.14764023], [72.66179657, 21.1468029], [72.66152954, 21.14680481], [72.66152954, 21.14541626], [72.66124725, 21.14542007], [72.66124725, 21.1443119], [72.6609726, 21.1443119], [72.6609726, 21.14347076], [72.66069794, 21.14347267], [72.66069794, 21.14263916], [72.66042328, 21.14263916], [72.66042328, 21.13986015], [72.66014099, 21.13986206], [72.66014099, 21.13875008], [72.6598587, 21.13875008], [72.6598587, 21.13125038], [72.66014099, 21.13125038], [72.66014099, 21.12985039], [72.66041565, 21.12986183], [72.66041565, 21.12791634], [72.66069794, 21.12791824], [72.66069794, 21.12735939], [72.6609726, 21.1273613], [72.6609726, 21.12680626], [72.66124725, 21.12680817], [72.66124725, 21.12541962], [72.65930176, 21.12541962], [72.65930176, 21.12514114], [72.6590271, 21.12514114], [72.6590271, 21.12486076], [72.65875244, 21.12486076], [72.65875244, 21.12458038], [72.65847015, 21.1245842], [72.65847015, 21.12347221], [72.6581955, 21.12347221], [72.6581955, 21.12013817], [72.65791321, 21.12014008], [72.65791321, 21.11930275], [72.6581955, 21.11930466], [72.6581955, 21.11652756], [72.65847015, 21.11653137], [72.65847015, 21.11514091], [72.65875244, 21.11514091], [72.65875244, 21.11375046], [72.6590271, 21.11375046], [72.6590271, 21.1131897], [72.65930176, 21.11319351], [72.65930176, 21.11263847], [72.65957642, 21.11264038], [72.65957642, 21.11207962], [72.6598587, 21.11208344], [72.6598587, 21.11180687], [72.66014099, 21.11181068], [72.66014099, 21.1115303], [72.66042328, 21.1115303], [72.66042328, 21.11069107], [72.66014099, 21.11069679], [72.66014099, 21.11013794], [72.66042328, 21.11013985], [72.66042328, 21.10985947], [72.66069794, 21.10986137], [72.66069794, 21.10791588], [72.66042328, 21.10791969], [72.66042328, 21.10680962], [72.66014099, 21.10680962], [72.66014099, 21.10625267], [72.6598587, 21.10625267], [72.6598587, 21.10597038], [72.65958405, 21.10597038], [72.65958405, 21.1040287], [72.65930176, 21.10403252], [72.65930176, 21.10207939], [72.6590271, 21.10208321], [72.6590271, 21.10180473], [72.65875244, 21.10180473], [72.65875244, 21.10097313], [72.65847015, 21.10097313], [72.65847015, 21.10041618], [72.65791321, 21.10041809], [72.65791321, 21.10013962], [72.65763855, 21.10013962], [72.65763855, 21.09987068], [72.6570816, 21.09987068], [72.6570816, 21.09958076], [72.65680695, 21.09958267], [72.65680695, 21.09930611], [72.65651703, 21.09930992], [72.65651703, 21.09736061], [72.65680695, 21.09736061], [72.65680695, 21.09708023], [72.6570816, 21.09708595], [72.6570816, 21.09680557], [72.65735626, 21.09680939], [72.65735626, 21.09431076], [72.6570816, 21.09431076], [72.6570816, 21.09264183], [72.65763855, 21.09264183], [72.65763855, 21.09207916], [72.65791321, 21.09208107], [72.65791321, 21.09180641], [72.65820313, 21.09181023], [72.65820313, 21.09124947], [72.65791321, 21.09124947], [72.65791321, 21.09068108], [72.65763855, 21.09069443], [72.65763855, 21.09013939], [72.65791321, 21.09013939], [72.65791321, 21.08958054], [72.65847015, 21.08958244], [72.65847015, 21.08930588], [72.6590271, 21.0893116], [72.6590271, 21.08793068], [72.65875244, 21.08793068], [72.65875244, 21.08764076], [72.65847015, 21.08764076], [72.65847015, 21.08736038], [72.65791321, 21.08736038], [72.65791321, 21.08708], [72.65736389, 21.08708382], [72.65736389, 21.08680534], [72.6570816, 21.08681107], [72.6570816, 21.08653069], [72.65680695, 21.08653069], [72.65680695, 21.08570099], [72.65625763, 21.08570099], [72.65625763, 21.08542061], [72.65598297, 21.08542061], [72.65598297, 21.08514023], [72.6554184, 21.08514023], [72.6554184, 21.08542061], [72.65458679, 21.08542061], [72.65458679, 21.08457947], [72.6543045, 21.08458328], [72.6543045, 21.08180618], [72.65402985, 21.08180618], [72.65402985, 21.08124924], [72.65374756, 21.08125114], [72.65374756, 21.08069038], [72.6534729, 21.08069229], [72.6534729, 21.08041763], [72.65319824, 21.08041954], [72.65319824, 21.07958031], [72.65291595, 21.07958221], [72.65291595, 21.07902718], [72.6526413, 21.0790329], [72.6526413, 21.07819176], [72.65208435, 21.07819366], [72.65208435, 21.07786942], [72.65208435, 21.07763863], [72.65180206, 21.07764244], [72.65180206, 21.07707977], [72.6515274, 21.07708359], [72.6515274, 21.07680511], [72.65041351, 21.07680511], [72.65041351, 21.07708359], [72.64985657, 21.07707977], [72.64985657, 21.07764244], [72.64958191, 21.07764244], [72.64958191, 21.07792282], [72.64930725, 21.0779171], [72.64930725, 21.07847023], [72.64875031, 21.07847023], [72.64875031, 21.07875252], [72.6479187, 21.07873917], [72.6479187, 21.0790329], [72.64736176, 21.07902718], [72.64736176, 21.07930183], [72.6470871, 21.07930565], [72.6470871, 21.07958221], [72.64653015, 21.07958031], [72.64653015, 21.07986069], [72.64624786, 21.07986069], [72.64624786, 21.08041954], [72.6451416, 21.08041763], [72.6451416, 21.08069229], [72.64458466, 21.08069229], [72.64458466, 21.08097458], [72.64247894, 21.08097458], [72.64013672, 21.08097458], [72.64013672, 21.08069229], [72.63708496, 21.08069229], [72.63708496, 21.08041763], [72.63597107, 21.08041954], [72.63597107, 21.08014107], [72.63540649, 21.08014107], [72.63540649, 21.07986069], [72.63485718, 21.07986069], [72.63485718, 21.07958031], [72.63430786, 21.07958221], [72.63430786, 21.07930565], [72.63346863, 21.07930946], [72.63346863, 21.0790329], [72.63291931, 21.0790329], [72.63291931, 21.07873917], [72.63263702, 21.07875252], [72.63263702, 21.07847023], [72.63180542, 21.07847023], [72.63180542, 21.07819366], [72.63153076, 21.07819366], [72.63153076, 21.0779171], [72.63124847, 21.07792282], [72.63124847, 21.07764244], [72.63069153, 21.07764244], [72.63069153, 21.07736015], [72.63014221, 21.07736015], [72.63014221, 21.07708359], [72.62985992, 21.07708359], [72.62985992, 21.07680511], [72.6295929, 21.07681084], [72.6295929, 21.07652855], [72.62930298, 21.07652855], [72.62930298, 21.07624817], [72.62902832, 21.07624817], [72.62902832, 21.0759697], [72.62875366, 21.0759716], [72.62875366, 21.07569504], [72.62735748, 21.07569504], [72.62735748, 21.0759716], [72.62708282, 21.0759697], [72.62708282, 21.07652855], [72.62680817, 21.07652855], [72.62680817, 21.07708359], [72.62708282, 21.07707977], [72.62708282, 21.07736015], [72.62735748, 21.07736015], [72.62735748, 21.07764244], [72.62847137, 21.07764244], [72.62847137, 21.07792282], [72.62902832, 21.0779171], [72.62902832, 21.07819366], [72.62930298, 21.07819366], [72.62930298, 21.07847023], [72.63014221, 21.07847023], [72.63014221, 21.07875252], [72.63041687, 21.07873917], [72.63041687, 21.0790329], [72.63153076, 21.07902718], [72.63153076, 21.07958221], [72.63208008, 21.07958221], [72.63208008, 21.07986069], [72.63236237, 21.07986069], [72.63236237, 21.08014107], [72.63263702, 21.08014107], [72.63263702, 21.08152962], [72.63236237, 21.08152771], [72.63236237, 21.08208466], [72.63263702, 21.08208084], [72.63263702, 21.08236122], [72.63318634, 21.08236122], [72.63318634, 21.08208084], [72.63346863, 21.08208466], [72.63346863, 21.08180618], [72.63430786, 21.08180618], [72.63430786, 21.08208466], [72.63402557, 21.08208466], [72.6340332, 21.08263969], [72.63375092, 21.08263969], [72.63375092, 21.08292007], [72.63319397, 21.08291626], [72.63319397, 21.08319664], [72.63291931, 21.08319664], [72.63291931, 21.0834713], [72.63263702, 21.08346939], [72.63263702, 21.08374977], [72.63236237, 21.08374977], [72.63236237, 21.08430672], [72.63208008, 21.08430672], [72.63208008, 21.08458328], [72.63181305, 21.08457947], [72.63181305, 21.08514023], [72.63153076, 21.08514023], [72.63153076, 21.08542061], [72.63124847, 21.08542061], [72.63124847, 21.08570099], [72.63097382, 21.08569527], [72.63097382, 21.08597183], [72.63069153, 21.08596992], [72.63069153, 21.08625031], [72.63014221, 21.08625031], [72.63014221, 21.08708382], [72.62985992, 21.08708], [72.62985992, 21.08736038], [72.62930298, 21.08736038], [72.62930298, 21.08764076], [72.62902832, 21.08764076], [72.62902832, 21.08793068], [72.62847137, 21.08791733], [72.62847137, 21.08847237], [72.62819672, 21.08847046], [72.62819672, 21.08875084], [72.6279068, 21.08875084], [72.6279068, 21.08902931], [72.62763977, 21.0890274], [72.62763977, 21.08958244], [72.62708282, 21.08958054], [72.62708282, 21.08986092], [72.62625122, 21.08986092], [72.62625122, 21.09124947], [72.62541962, 21.09124947], [72.62541962, 21.09153175], [72.62486267, 21.09153175], [72.62486267, 21.09181023], [72.62458038, 21.09181023], [72.62458038, 21.09264183], [72.62486267, 21.09264183], [72.62486267, 21.0929203], [72.62541962, 21.0929203], [72.62541962, 21.09320068], [72.62596893, 21.09320068], [72.62596893, 21.09431076], [72.62625122, 21.09430313], [72.62625122, 21.0945816], [72.62652588, 21.0945797], [72.62652588, 21.09625053], [72.62568665, 21.09625053], [72.62568665, 21.09653091], [72.62541962, 21.09653091], [72.62541962, 21.09680939], [72.62513733, 21.09680939], [72.62513733, 21.09764099], [72.62569427, 21.09763908], [72.62569427, 21.09819412], [72.62596893, 21.09819412], [72.62596893, 21.09958267], [72.62625122, 21.09958076], [72.62625122, 21.09987068], [72.62652588, 21.09986115], [72.62652588, 21.10180473], [72.62680817, 21.10180473], [72.62680817, 21.10236168], [72.62652588, 21.10236168], [72.62652588, 21.10347176], [72.62625122, 21.10346985], [72.62625122, 21.10374832], [72.62596893, 21.10374832], [72.62596893, 21.10458374], [72.62625122, 21.10458183], [72.62625122, 21.10514259], [72.62596893, 21.10514259], [72.62596893, 21.10625267], [72.62568665, 21.10625267], [72.62568665, 21.10653114], [72.62513733, 21.10653114], [72.62513733, 21.10625267], [72.62486267, 21.10625267], [72.62486267, 21.10653114], [72.62374878, 21.10653114], [72.62374878, 21.10680962], [72.62346649, 21.10680962], [72.62346649, 21.10736275], [72.62319183, 21.10736275], [72.62319183, 21.10986137], [72.62291718, 21.10985947], [72.62291718, 21.11181068], [72.62319183, 21.11181068], [72.62319183, 21.11292076], [72.62291718, 21.11291885], [72.62291718, 21.11319351], [72.62346649, 21.1131897], [72.62346649, 21.11375046], [72.62319183, 21.11375046], [72.62319183, 21.11431122], [72.62347412, 21.1143055], [72.62347412, 21.11458397], [72.62541962, 21.11458015], [72.62541962, 21.11514091], [72.62568665, 21.11514091], [72.62568665, 21.11541748], [72.62596893, 21.11541748], [72.62596893, 21.11569405], [72.62625122, 21.11569023], [72.62625122, 21.11624908], [72.62652588, 21.11624908], [72.62652588, 21.11653137], [72.62680817, 21.11652756], [72.62680817, 21.11791611], [72.62708282, 21.11790848], [72.62708282, 21.11874962], [72.62735748, 21.11874962], [72.62735748, 21.11986351], [72.62625122, 21.11986351], [72.62625122, 21.11958122], [72.62541962, 21.11958122], [72.62541962, 21.11930466], [72.62458038, 21.11930466], [72.62458038, 21.11958122], [72.62403107, 21.11958122], [72.62403107, 21.11986351], [72.62346649, 21.1198597], [72.62346649, 21.12042046], [72.62374878, 21.12042046], [72.62374878, 21.12125015], [72.62403107, 21.12125015], [72.62403107, 21.12153053], [72.62458038, 21.12153053], [72.62458038, 21.12292099], [72.62430573, 21.12291718], [72.62430573, 21.12319565], [72.62403107, 21.12319565], [72.62403107, 21.12347221], [72.62346649, 21.12347031], [72.62346649, 21.1240406], [72.62319183, 21.12402725], [72.62319183, 21.1245842], [72.62346649, 21.12458038], [72.62346649, 21.12486076], [72.62374878, 21.12486076], [72.62374878, 21.12541962], [72.62403107, 21.12541771], [72.62403107, 21.12597275], [72.62431335, 21.12597084], [72.62431335, 21.12625122], [72.62458038, 21.12625122], [72.62458038, 21.12652969], [72.62568665, 21.12652969], [72.62568665, 21.12680817], [72.62596893, 21.12680817], [72.62596893, 21.12791824], [72.62568665, 21.12791824], [72.62568665, 21.12874985], [72.62541962, 21.12874985], [72.62541962, 21.12902832], [72.62430573, 21.12902832], [72.62430573, 21.12986183], [72.62403107, 21.12985039], [72.62403107, 21.13181114], [72.62374878, 21.13180542], [72.62374878, 21.13208389], [72.62346649, 21.13208008], [72.62346649, 21.13236046], [72.62374878, 21.13236046], [72.62374878, 21.13319206], [72.62347412, 21.13319206], [72.62347412, 21.13347054], [72.62291718, 21.13347054], [72.62291718, 21.13375282], [72.62264252, 21.13375282], [72.62264252, 21.13458443], [72.62291718, 21.13458061], [72.62291718, 21.13513947], [72.62319183, 21.13513947], [72.62319183, 21.13541985], [72.62347412, 21.13541412], [72.62347412, 21.1356926], [72.62374878, 21.13569069], [72.62374878, 21.13598061], [72.62403107, 21.13597488], [72.62403107, 21.13736153], [72.62431335, 21.13735962], [72.62431335, 21.13764], [72.62486267, 21.13764], [72.62486267, 21.13820076], [72.62513733, 21.13819695], [72.62513733, 21.13958359], [72.62486267, 21.13958359], [72.62486267, 21.13986206], [72.62403107, 21.13986015], [72.62403107, 21.14014053], [72.62236023, 21.14014053], [72.62236023, 21.14042091], [72.62208557, 21.1404171], [72.62208557, 21.14097214], [72.62180328, 21.14097023], [72.62180328, 21.14125061], [72.62152863, 21.14125061], [72.62152863, 21.14180756], [72.62124634, 21.14180756], [72.62124634, 21.14292145], [72.62097168, 21.14292145], [72.62097168, 21.14513969], [72.62069702, 21.14513969], [72.62069702, 21.14624977], [72.62041473, 21.14624977], [72.62041473, 21.14736366], [72.62014771, 21.14735985], [72.62014771, 21.14764023], [72.61985779, 21.14764023], [72.61985779, 21.14792061], [72.61958313, 21.14792061], [72.61958313, 21.14875031], [72.61985779, 21.14875031], [72.61985779, 21.14846992], [72.62014008, 21.14847374], [72.62014008, 21.14819527], [72.62069702, 21.14821053], [72.62069702, 21.14792061], [72.62152863, 21.14792061], [72.62152863, 21.14821053], [72.62180328, 21.14819527], [72.62180328, 21.14847374], [72.62152863, 21.14846992], [72.62152863, 21.14903069], [72.62124634, 21.14903069], [72.62124634, 21.14931107], [72.62097168, 21.14930344], [72.62097168, 21.14958572], [72.62069702, 21.14958], [72.62069702, 21.14986038], [72.62041473, 21.14986038], [72.62041473, 21.1506958], [72.62014008, 21.1506958], [72.62014771, 21.15236092], [72.61985779, 21.15236092], [72.61985779, 21.15402794], [72.62014771, 21.15402031], [72.62014771, 21.15430832], [72.62069702, 21.15430832], [72.62069702, 21.15402031], [72.62124634, 21.15402031], [72.62124634, 21.15513992], [72.62097168, 21.15513992], [72.62097168, 21.15708351], [72.62069702, 21.1570797], [72.62069702, 21.15764236], [72.6204071, 21.15764236], [72.6204071, 21.15792274], [72.62014771, 21.15792274], [72.62014771, 21.15903282], [72.6204071, 21.15903282], [72.6204071, 21.15930939], [72.62014008, 21.15930557], [72.62014008, 21.15986061], [72.6204071, 21.15986061], [72.6204071, 21.16041946], [72.62069702, 21.16041756], [72.62069702, 21.16208458], [72.62014008, 21.16208458], [72.62014771, 21.16236115], [72.61985779, 21.16236115], [72.61985779, 21.16292], [72.61958313, 21.16291428], [72.61958313, 21.16319466], [72.61930847, 21.16319466], [72.61930847, 21.16347313], [72.61846924, 21.16347313], [72.61846924, 21.16319466], [72.61791992, 21.16319466], [72.61791992, 21.16347313], [72.61763763, 21.16347122], [72.61763763, 21.16403008], [72.61791992, 21.16402817], [72.61791992, 21.16430664], [72.61819458, 21.16430664], [72.61819458, 21.16458321], [72.61875153, 21.16457939], [72.61875153, 21.16514015], [72.61902618, 21.16514015], [72.61902618, 21.16542053], [72.61930847, 21.16542053], [72.61930847, 21.16570091], [72.61958313, 21.16569519], [72.61958313, 21.16597176], [72.61985779, 21.16596031], [72.61985779, 21.17013931], [72.61958313, 21.17013931], [72.61958313, 21.17347145], [72.61985779, 21.17346954], [72.61985779, 21.17431068], [72.61958313, 21.17431068], [72.61958313, 21.17542076], [72.61985779, 21.17541695], [72.61985779, 21.17597389], [72.61958313, 21.17597008], [72.61958313, 21.17875099], [72.61930847, 21.17875099], [72.61930847, 21.17930984], [72.61958313, 21.17930984], [72.61958313, 21.17986107], [72.61985779, 21.17986107], [72.61985779, 21.18097305], [72.61958313, 21.1809597], [72.61958313, 21.18124962], [72.61985779, 21.18124962], [72.61985779, 21.1823616], [72.62014771, 21.1823597], [72.62014771, 21.18291855], [72.61985779, 21.18291664], [72.61985779, 21.18347168], [72.61958313, 21.18346977], [72.61958313, 21.18432045], [72.61930847, 21.18432045], [72.61930847, 21.18486023], [72.61902618, 21.18486023], [72.61902618, 21.18625259], [72.61875153, 21.18625259], [72.61875153, 21.18653107], [72.61846924, 21.18653107], [72.61846924, 21.18736076], [72.61818695, 21.18736076], [72.61818695, 21.18791962], [72.61791992, 21.18791962], [72.61791992, 21.18902969], [72.61818695, 21.18902969], [72.61818695, 21.18931007], [72.61846924, 21.18930626], [72.61846924, 21.18958473], [72.61819458, 21.18958473], [72.61819458, 21.19097137], [72.61846924, 21.19097137], [72.61846924, 21.19236183], [72.61875153, 21.19235992], [72.61875153, 21.1926403], [72.61846924, 21.1926403], [72.61846924, 21.19431114], [72.61819458, 21.19430542], [72.61819458, 21.19708252], [72.61846924, 21.19708252], [72.61846924, 21.19958115], [72.61875153, 21.19958115], [72.61875153, 21.20014191], [72.61902618, 21.20013809], [72.61902618, 21.2009716], [72.61930847, 21.2009697], [72.61930847, 21.20264053], [72.61958313, 21.20263863], [72.61958313, 21.20347214], [72.61930847, 21.20347214], [72.61930847, 21.20513916], [72.61902618, 21.20512962], [72.61902618, 21.20541954], [72.61846924, 21.20541763], [72.61846924, 21.20597267], [72.61875153, 21.20597076], [72.61875153, 21.20625114], [72.61985779, 21.20625114], [72.61985779, 21.20652962], [72.62014008, 21.20652771], [72.62014008, 21.20708275], [72.62069702, 21.20708084], [72.62069702, 21.20736122], [72.62097168, 21.20736122], [72.62097168, 21.2084713], [72.62069702, 21.20846939], [72.62069702, 21.20902824], [72.62097168, 21.20902824], [72.62097168, 21.20930481], [72.62124634, 21.20930481], [72.62124634, 21.20966148], [72.62124634, 21.2104187], [72.62152863, 21.2104187], [72.62152863, 21.2107029], [72.62180328, 21.2107029], [72.62180328, 21.2104187], [72.62236023, 21.2104187], [72.62236023, 21.21013832], [72.62346649, 21.21013832], [72.62346649, 21.2104187], [72.62374878, 21.2104187], [72.62374878, 21.2107029], [72.62403107, 21.21069527], [72.62403107, 21.21208382], [72.62374878, 21.21208191], [72.62374878, 21.21236038], [72.62236023, 21.21236038], [72.62236023, 21.21208191], [72.62152863, 21.21208191], [72.62152863, 21.21236038], [72.62097168, 21.21236038], [72.62097168, 21.21264267], [72.6204071, 21.21264267], [72.6204071, 21.21292114], [72.62014008, 21.21291733], [72.62014771, 21.21513939], [72.61985779, 21.21513939], [72.61985779, 21.21736145], [72.62014771, 21.21735954], [72.62014771, 21.21763992], [72.62041473, 21.21763802], [72.62041473, 21.21847153], [72.62014771, 21.21846962], [72.62014771, 21.21903038], [72.62069702, 21.21902847], [72.62069702, 21.21958351], [72.62041473, 21.21958351], [72.62041473, 21.21986198], [72.62014771, 21.21986008], [72.62014771, 21.22014046], [72.61985779, 21.22014046], [72.61985779, 21.22042084], [72.61958313, 21.22041893], [72.61958313, 21.22068977], [72.61875153, 21.22069359], [72.61875153, 21.22097206], [72.61846924, 21.22097015], [72.61846924, 21.22263908], [72.61875153, 21.22263908], [72.61875153, 21.22292137], [72.61968231, 21.22291756], [72.62180328, 21.22292137], [72.62180328, 21.22320175], [72.62236023, 21.22319412], [72.62236023, 21.2234726], [72.62264252, 21.22347069], [72.62264252, 21.22374916], [72.62374878, 21.22374916], [72.62374878, 21.22402954], [72.62486267, 21.22402954], [72.62486267, 21.22431183], [72.63041687, 21.22431183], [72.63041687, 21.22402954], [72.63124847, 21.22402954], [72.63124847, 21.22374916], [72.63181305, 21.22374916], [72.63181305, 21.22347069], [72.63236237, 21.2234726], [72.63236237, 21.22291756], [72.63263702, 21.22292137], [72.63263702, 21.22263908], [72.63291931, 21.22263908], [72.63291931, 21.22208023], [72.63319397, 21.22208405], [72.63319397, 21.2215271], [72.63346863, 21.22153091], [72.63346863, 21.22125053], [72.63375092, 21.22125053], [72.63375092, 21.22068977], [72.63458252, 21.22069359], [72.63458252, 21.22041893], [72.63485718, 21.22042084], [72.63485718, 21.22014046], [72.63540649, 21.22014046], [72.63540649, 21.21986008], [72.63569641, 21.21986198], [72.63569641, 21.21958351], [72.63652802, 21.21958351], [72.63652802, 21.21930695], [72.63735962, 21.21931076], [72.63735962, 21.21903038], [72.63764191, 21.21903038], [72.63764191, 21.21875], [72.63791656, 21.21875], [72.63791656, 21.21846962], [72.63819122, 21.21847153], [72.63819122, 21.21791649], [72.63874817, 21.2179203], [72.63874817, 21.21735954], [72.63930511, 21.21736145], [72.63930511, 21.21708488], [72.64125061, 21.21708488], [72.64125824, 21.21735954], [72.64680481, 21.21736145], [72.64680481, 21.21743965], [72.64679718, 21.21763992], [72.6479187, 21.21763992], [72.6479187, 21.2179203], [72.64875031, 21.2179203], [72.64875031, 21.21820068], [72.64930725, 21.21819687], [72.64930725, 21.21847153], [72.64985657, 21.21846962], [72.64985657, 21.21875], [72.65040588, 21.21875], [72.65040588, 21.21903038], [72.65097046, 21.21902847], [72.65097046, 21.21958351], [72.6515274, 21.21958351], [72.6515274, 21.21986198], [72.65180206, 21.21986008], [72.65180206, 21.22014046], [72.65235901, 21.22013855], [72.65235901, 21.22069359], [72.6526413, 21.22068977], [72.6526413, 21.22320175], [72.65235901, 21.22319412], [72.65235901, 21.2234726], [72.65207672, 21.22347069], [72.65207672, 21.22485924], [72.65235901, 21.22485924], [72.65235901, 21.22542191], [72.6526413, 21.22541618], [72.6526413, 21.22597122], [72.65291595, 21.22597122], [72.65291595, 21.22624969], [72.65319824, 21.22624969], [72.65319824, 21.22680473], [72.65235901, 21.22680473], [72.65235901, 21.22624969], [72.65208435, 21.22624969], [72.65208435, 21.22597122], [72.65180206, 21.22597122], [72.65180206, 21.22541618], [72.6515274, 21.22542191], [72.6515274, 21.22485924], [72.65125275, 21.22485924], [72.65125275, 21.22458076], [72.65097046, 21.22458267], [72.65097046, 21.22430611], [72.6506958, 21.22431183], [72.6506958, 21.22374916], [72.65040588, 21.22374916], [72.65040588, 21.22320175], [72.65013123, 21.22320175], [72.65013123, 21.22263908], [72.64985657, 21.22263908], [72.64985657, 21.22097015], [72.64958191, 21.22097206], [72.64958191, 21.22041893], [72.64901733, 21.22042084], [72.64901733, 21.22014046], [72.64875031, 21.22014046], [72.64875031, 21.21986008], [72.64819336, 21.21986198], [72.64819336, 21.21958351], [72.64653015, 21.21958351], [72.64653015, 21.21986198], [72.64597321, 21.21986008], [72.64597321, 21.22014046], [72.64541626, 21.22014046], [72.64541626, 21.22042084], [72.64458466, 21.22041893], [72.64458466, 21.22069359], [72.64375305, 21.22069359], [72.64375305, 21.22097206], [72.64347076, 21.22097015], [72.64347076, 21.22125053], [72.64290619, 21.22125053], [72.64290619, 21.22153091], [72.6423645, 21.2215271], [72.6423645, 21.22208405], [72.64208221, 21.22208023], [72.64208221, 21.22236061], [72.6415329, 21.22236061], [72.6415329, 21.22263908], [72.64125824, 21.22263908], [72.64125824, 21.22292137], [72.64097595, 21.22292137], [72.64097595, 21.22374916], [72.64041901, 21.22374916], [72.64041901, 21.22431183], [72.63957977, 21.22430611], [72.63957977, 21.22458267], [72.63903046, 21.22458076], [72.63903046, 21.22513962], [72.63846588, 21.22513962], [72.63846588, 21.22542191], [72.63791656, 21.22541618], [72.63791656, 21.22569466], [72.63708496, 21.22569466], [72.63708496, 21.22597122], [72.63680267, 21.22597122], [72.63680267, 21.22624969], [72.63569641, 21.22624016], [72.63569641, 21.22653008], [72.63458252, 21.22652817], [72.63458252, 21.22680473], [72.63402557, 21.22680473], [72.63402557, 21.2270813], [72.63319397, 21.2270813], [72.63319397, 21.22736359], [72.63236237, 21.22735977], [72.63236237, 21.22792053], [72.63181305, 21.22792053], [72.63181305, 21.22820091], [72.63124847, 21.22819328], [72.63124847, 21.22847366], [72.63069153, 21.22846985], [72.63069153, 21.22875023], [72.62930298, 21.22875023], [72.62930298, 21.22903061], [72.62735748, 21.2290287], [72.62735748, 21.22912407], [72.62735748, 21.22930336], [72.62625122, 21.22930336], [72.62625122, 21.2290287], [72.62596893, 21.2290287], [72.62596893, 21.22930336], [72.62569427, 21.22930336], [72.62569427, 21.22958565], [72.62513733, 21.22957993], [72.62513733, 21.22986031], [72.62486267, 21.22986031], [72.62486267, 21.23014069], [72.62430573, 21.23013878], [72.62430573, 21.23097229], [72.62374878, 21.23097038], [72.62374878, 21.23125076], [72.62346649, 21.23125076], [72.62346649, 21.23153114], [72.62319183, 21.23153114], [72.62319183, 21.23180962], [72.62291718, 21.23180771], [72.62291718, 21.23208427], [72.62264252, 21.23208046], [72.62264252, 21.23264122], [72.62236023, 21.23264122], [72.62236023, 21.23291969], [72.62208557, 21.23291779], [72.62208557, 21.23347282], [72.62124634, 21.23347282], [72.62124634, 21.23208427], [72.62097168, 21.23208427], [72.62097168, 21.23180771], [72.6204071, 21.23180962], [72.6204071, 21.23153114], [72.62014771, 21.23153114], [72.62014771, 21.23125076], [72.61902618, 21.23125076], [72.61902618, 21.23097038], [72.61846924, 21.23097229], [72.61846924, 21.23069572], [72.61736298, 21.23069572], [72.61736298, 21.23097229], [72.61653137, 21.23097229], [72.61653137, 21.23069572], [72.61624908, 21.23069572], [72.61624908, 21.23041725], [72.61541748, 21.23042107], [72.61541748, 21.23014069], [72.61514282, 21.23014069], [72.61514282, 21.22986031], [72.61486053, 21.22986031], [72.61486053, 21.22957993], [72.61458588, 21.22958565], [72.61458588, 21.22930336], [72.61374664, 21.22930336], [72.61374664, 21.2290287], [72.61347198, 21.22903061], [72.61347198, 21.22875023], [72.61235809, 21.22875023], [72.61235809, 21.22846985], [72.61180878, 21.22846985], [72.61180878, 21.22903061], [72.61096954, 21.2290287], [72.61096954, 21.22930336], [72.61069489, 21.22930336], [72.61069489, 21.22958565], [72.61013794, 21.22957993], [72.61013794, 21.22986031], [72.60958099, 21.22986031], [72.60958099, 21.23069572], [72.60930634, 21.23069572], [72.60930634, 21.23097229], [72.60901642, 21.23097038], [72.60901642, 21.23125076], [72.60874939, 21.23125076], [72.60874939, 21.23208237], [72.60930634, 21.23208046], [72.60930634, 21.23236084], [72.60958099, 21.23236084], [72.60958099, 21.23291969], [72.60930634, 21.23291969], [72.60930634, 21.23374939], [72.60901642, 21.23374939], [72.60901642, 21.23430824], [72.60819244, 21.23430824], [72.60819244, 21.23402977], [72.60764313, 21.23402977], [72.60764313, 21.23430824], [72.60708618, 21.23430634], [72.60708618, 21.2345829], [72.60680389, 21.2345829], [72.60680389, 21.23486137], [72.60652924, 21.23485947], [72.60652924, 21.23513985], [72.60597229, 21.23513985], [72.60597229, 21.23543167], [72.60569763, 21.23541641], [72.60569763, 21.23569489], [72.60541534, 21.23569489], [72.60541534, 21.23597145], [72.60514069, 21.23597145], [72.60514832, 21.23624992], [72.6048584, 21.23624992], [72.6048584, 21.2365284], [72.60457611, 21.2365284], [72.60457611, 21.23681068], [72.60430908, 21.23680496], [72.60430908, 21.23708344], [72.60402679, 21.23707962], [72.60402679, 21.23764038], [72.60375214, 21.23764038], [72.60375214, 21.23792267], [72.60346985, 21.23791695], [72.60346985, 21.23847008], [72.60319519, 21.23847008], [72.60320282, 21.23875046], [72.6029129, 21.23875046], [72.6029129, 21.23903275], [72.60263824, 21.23902702], [72.60263824, 21.23958206], [72.6029129, 21.23958015], [72.6029129, 21.24041939], [72.60319519, 21.24041748], [72.60319519, 21.24097443], [72.60236359, 21.24097443], [72.60236359, 21.24124908], [72.60208893, 21.24123955], [72.60208893, 21.24152946], [72.60180664, 21.24152946], [72.60180664, 21.24180984], [72.60124969, 21.24180412], [72.60124969, 21.2420845], [72.60097504, 21.2420845], [72.60098267, 21.24263954], [72.60069275, 21.24263954], [72.60069275, 21.24347305], [72.60041809, 21.24347115], [72.60041809, 21.24403], [72.6001358, 21.24403], [72.6001358, 21.24514008], [72.60041809, 21.24514008], [72.60041809, 21.24653053], [72.6001358, 21.24653053], [72.6001358, 21.24681091], [72.59986115, 21.24680519], [72.59986115, 21.24819374], [72.59958649, 21.24818993], [72.59958649, 21.24875069], [72.59929657, 21.24875069], [72.59929657, 21.24931145], [72.59902954, 21.24930573], [72.59902954, 21.2495842], [72.59764099, 21.24958038], [72.59764099, 21.24986076], [72.5973587, 21.24986076], [72.5973587, 21.25013924], [72.59708405, 21.25013924], [72.59708405, 21.25319481], [72.5973587, 21.25319481], [72.5973587, 21.25430489], [72.59708405, 21.25430489], [72.59708405, 21.25458145], [72.5973587, 21.25457954], [72.5973587, 21.25542068], [72.59707642, 21.25542068], [72.59707642, 21.25681114], [72.5973587, 21.25681114], [72.5973587, 21.25764084], [72.59764099, 21.25764084], [72.59764099, 21.25792122], [72.59791565, 21.2579174], [72.59792328, 21.26013947], [72.59764099, 21.26013947], [72.59764099, 21.26097298], [72.5973587, 21.26097107], [72.5973587, 21.2618084], [72.59707642, 21.2618084], [72.59707642, 21.26291847], [72.5973587, 21.26291847], [72.5973587, 21.26374817], [72.59764099, 21.26374817], [72.59764099, 21.26458359], [72.59791565, 21.26458359], [72.59791565, 21.26597023], [72.59819794, 21.26597023], [72.59819794, 21.26625061], [72.5984726, 21.26625061], [72.5984726, 21.26680946], [72.59791565, 21.26680565], [72.59791565, 21.26736069], [72.59819794, 21.26736069], [72.59819794, 21.26764107], [72.5984726, 21.26764107], [72.5984726, 21.26791954], [72.59874725, 21.26791954], [72.59874725, 21.26902962], [72.5984726, 21.26902771], [72.5984726, 21.26958466], [72.59819794, 21.26958084], [72.59819794, 21.26986122], [72.59791565, 21.26986122], [72.59792328, 21.27013969], [72.59764099, 21.27013969], [72.59764099, 21.27069664], [72.5973587, 21.27069092], [72.5973587, 21.27124977], [72.59680939, 21.27124977], [72.59680176, 21.27153969], [72.5965271, 21.27152824], [72.5965271, 21.27180672], [72.59680176, 21.27180672], [72.59680939, 21.27208328], [72.59791565, 21.27208328], [72.59791565, 21.27236176], [72.5984726, 21.27235985], [72.5984726, 21.27264023], [72.59929657, 21.27264023], [72.59929657, 21.27292061], [72.59958649, 21.27292061], [72.59958649, 21.27320099], [72.59986115, 21.27320099], [72.59986115, 21.27375031], [72.60041809, 21.27375031], [72.60041809, 21.27403069], [72.60069275, 21.27403069], [72.60069275, 21.27431107], [72.60180664, 21.27430534], [72.60180664, 21.27458382], [72.60235596, 21.27457809], [72.60235596, 21.27486038], [72.60263824, 21.27486038], [72.60263824, 21.27514076], [72.6029129, 21.27514076], [72.6029129, 21.27541924], [72.60319519, 21.27541733], [72.60319519, 21.27625084], [72.60457611, 21.27625084], [72.60457611, 21.2768116], [72.6048584, 21.27680588], [72.6048584, 21.27736092], [72.6029129, 21.27736092], [72.6029129, 21.27708244], [72.60236359, 21.27708244], [72.60236359, 21.27680588], [72.60152435, 21.27680588], [72.60152435, 21.27708244], [72.60041809, 21.27708244], [72.60041809, 21.27736092], [72.59986115, 21.27734947], [72.59986115, 21.27763939], [72.59929657, 21.27763939], [72.59929657, 21.27792168], [72.59874725, 21.27791595], [72.59874725, 21.27819443], [72.5973587, 21.27819443], [72.5973587, 21.27791595], [72.59513855, 21.27792168], [72.59513855, 21.27763939], [72.59401703, 21.27763939], [72.59401703, 21.27792168], [72.59348297, 21.27792168], [72.59348297, 21.27763939], [72.59041595, 21.27763939], [72.59041595, 21.27792168], [72.58985901, 21.27792168], [72.58985901, 21.27763939], [72.58930206, 21.27763939], [72.58930206, 21.27708054], [72.5890274, 21.27708244], [72.5890274, 21.27625084], [72.58875275, 21.27625084], [72.58875275, 21.27597046], [72.58847046, 21.27597237], [72.58847046, 21.27569389], [72.58735657, 21.27568817], [72.58735657, 21.27652931], [72.58763885, 21.27652931], [72.58763885, 21.2768116], [72.58790588, 21.2768116], [72.58790588, 21.27763939], [72.5881958, 21.27763939], [72.5881958, 21.27819443], [72.58847046, 21.27819061], [72.58847046, 21.27874947], [72.58875275, 21.27874947], [72.58875275, 21.28097153], [72.5890274, 21.28096962], [72.5890274, 21.28153038], [72.58930206, 21.28152847], [72.58930206, 21.28236389], [72.5909729, 21.28236389], [72.5909729, 21.28180313], [72.59124756, 21.28181076], [72.59124756, 21.28153038], [72.59179688, 21.28153038], [72.59179688, 21.28125], [72.59348297, 21.28125], [72.59347534, 21.28097153], [72.59513855, 21.28096962], [72.59513855, 21.28125], [72.59596252, 21.28125], [72.59596252, 21.28153038], [72.59625244, 21.28153038], [72.59625244, 21.28125], [72.5965271, 21.28125], [72.5965271, 21.28070068], [72.59680176, 21.28070068], [72.59680176, 21.28041267], [72.59708405, 21.28041649], [72.59708405, 21.28013802], [72.5973587, 21.28014183], [72.5973587, 21.27985954], [72.5984726, 21.27985954], [72.5984726, 21.28070068], [72.59819794, 21.28069305], [72.59819794, 21.28097153], [72.59764099, 21.28096962], [72.59764099, 21.28125], [72.5973587, 21.28125], [72.5973587, 21.28153038], [72.5965271, 21.28152847], [72.5965271, 21.28208542], [72.59597015, 21.28208542], [72.59597015, 21.28236389], [72.59570313, 21.28236008], [72.59570313, 21.28264046], [72.59541321, 21.28264046], [72.59541321, 21.28292084], [72.59486389, 21.28291702], [72.59486389, 21.2831955], [72.5945816, 21.2831955], [72.5945816, 21.28291702], [72.59319305, 21.28291702], [72.59319305, 21.2831955], [72.5929184, 21.2831955], [72.5929184, 21.28291702], [72.59124756, 21.28291702], [72.59124756, 21.2831955], [72.59069824, 21.28318977], [72.59069824, 21.28347969], [72.59041595, 21.28347969], [72.59041595, 21.28375053], [72.59014893, 21.28375053], [72.59014893, 21.28403091], [72.58930206, 21.28403091], [72.58930206, 21.28430939], [72.5890274, 21.28430557], [72.5890274, 21.28458595], [72.58875275, 21.28458595], [72.58875275, 21.28569412], [72.58847046, 21.28569031], [72.58847046, 21.28736115], [72.58875275, 21.28736115], [72.58875275, 21.28819466], [72.58847046, 21.28819084], [72.58847046, 21.28874969], [72.5881958, 21.28874969], [72.5881958, 21.28930473], [72.58847046, 21.28928947], [72.58847046, 21.29041862], [72.5881958, 21.29041862], [72.5881958, 21.29070282], [72.58790588, 21.29070282], [72.58790588, 21.29125023], [72.5881958, 21.29125023], [72.5881958, 21.29153252], [72.58847046, 21.2915287], [72.58847046, 21.29319382], [72.58875275, 21.29319191], [72.58875275, 21.29375267], [72.58930206, 21.29375267], [72.58930206, 21.29403114], [72.58957672, 21.29403114], [72.58957672, 21.29486084], [72.58930206, 21.29486084], [72.58930206, 21.29569244], [72.58957672, 21.29569054], [72.58957672, 21.29652977], [72.58985901, 21.29652786], [72.58985901, 21.29736137], [72.58957672, 21.29735947], [72.58957672, 21.29763985], [72.58930206, 21.29763985], [72.58930206, 21.29792023], [72.5890274, 21.29792023], [72.5890274, 21.29848099], [72.58930206, 21.29848099], [72.58930206, 21.29874992], [72.58957672, 21.29874992], [72.58957672, 21.2990303], [72.58985901, 21.2990303], [72.58985901, 21.30014038], [72.59014893, 21.30014038], [72.59014893, 21.30042076], [72.59041595, 21.30041885], [72.59041595, 21.30069351], [72.5909729, 21.30069351], [72.5909729, 21.30097198], [72.59124756, 21.30097198], [72.59124756, 21.30208397], [72.59152985, 21.30208397], [72.59152985, 21.30347252], [72.59179688, 21.30347061], [72.59179688, 21.30402946], [72.59208679, 21.30402946], [72.59208679, 21.30431175], [72.59236145, 21.30431175], [72.59236145, 21.30485916], [72.59263611, 21.30485916], [72.59263611, 21.30542183], [72.5929184, 21.30541611], [72.5929184, 21.30569458], [72.59347534, 21.30569458], [72.59347534, 21.30624962], [72.59375, 21.30624962], [72.59375, 21.30653191], [72.59319305, 21.30652809], [72.59319305, 21.30680466], [72.5929184, 21.30680275], [72.5929184, 21.30792046], [72.59319305, 21.30792046], [72.59319305, 21.30820084], [72.59347534, 21.30819321], [72.59347534, 21.30847168], [72.59375, 21.30846977], [72.59375, 21.30875015], [72.59319305, 21.30875015], [72.59319305, 21.30903053], [72.5929184, 21.30903053], [72.5929184, 21.31014061], [72.59319305, 21.3101387], [72.59319305, 21.3120842], [72.59347534, 21.3120842], [72.59347534, 21.31236076], [72.59375, 21.31236076], [72.59375, 21.31264114], [72.59402466, 21.31263924], [72.59402466, 21.31347275], [72.59430695, 21.3134594], [72.59430695, 21.31375122], [72.5945816, 21.31375122], [72.5945816, 21.31430817], [72.59486389, 21.31430626], [72.59486389, 21.31458282], [72.59541321, 21.31458092], [72.59541321, 21.31513977], [72.5956955, 21.31513977], [72.5956955, 21.31597137], [72.59625244, 21.31596947], [72.59625244, 21.31624985], [72.59680176, 21.31624985], [72.59680939, 21.31680489], [72.59708405, 21.31680489], [72.59708405, 21.31708336], [72.5973587, 21.31707764], [72.5973587, 21.3176403], [72.59764099, 21.3176403], [72.59764099, 21.31820107], [72.59791565, 21.31819534], [72.59791565, 21.31847191], [72.59819794, 21.31847191], [72.59819794, 21.31903267], [72.5984726, 21.31903267], [72.5984726, 21.31931114], [72.59929657, 21.31931114], [72.59929657, 21.31958961], [72.59958649, 21.31958961], [72.59958649, 21.31986046], [72.59986115, 21.31986046], [72.59986115, 21.32042122], [72.6001358, 21.3204174], [72.6001358, 21.32069206], [72.60041809, 21.32069206], [72.60041809, 21.32097435], [72.60098267, 21.32097054], [72.60098267, 21.32152939], [72.60124969, 21.32152939], [72.60124969, 21.32180977], [72.60151672, 21.32180977], [72.60151672, 21.3223629], [72.60180664, 21.3223629], [72.60180664, 21.32265091], [72.60263824, 21.32265091], [72.60263824, 21.32291985], [72.6029129, 21.32291412], [72.6029129, 21.3231926], [72.60319519, 21.3231926], [72.60319519, 21.32347488], [72.60346985, 21.32347107], [72.60346985, 21.32374954], [72.60375214, 21.32374954], [72.60375214, 21.32430077], [72.60430908, 21.32430649], [72.60430908, 21.32458305], [72.60458374, 21.32458305], [72.60458374, 21.32486153], [72.60624695, 21.32485962], [72.60624695, 21.32514], [72.60679626, 21.32514], [72.60679626, 21.32542038], [72.6076355, 21.32541656], [72.6076355, 21.32625008], [72.60874939, 21.32625008], [72.60874939, 21.32902908], [72.60901642, 21.32902908], [72.60901642, 21.32930756], [72.60874939, 21.32930565], [72.60874939, 21.3306942], [72.60902405, 21.3306942], [72.60902405, 21.33097267], [72.60930634, 21.33097076], [72.60930634, 21.33124924], [72.60958099, 21.33124924], [72.60958099, 21.33208275], [72.60986328, 21.33208084], [72.60986328, 21.33235931], [72.61042023, 21.33235931], [72.61042023, 21.33263969], [72.61068726, 21.33263969], [72.61068726, 21.33292007], [72.61096954, 21.33291626], [72.61096954, 21.33319473], [72.61125183, 21.33319283], [72.61125183, 21.33374977], [72.61152649, 21.33374977], [72.61152649, 21.33403015], [72.61180878, 21.33402824], [72.61180878, 21.33430481], [72.61207581, 21.3343029], [72.61207581, 21.33459091], [72.61235809, 21.33459091], [72.61235809, 21.33514023], [72.61264038, 21.33514023], [72.61264038, 21.33542061], [72.61292267, 21.33542061], [72.61292267, 21.33570099], [72.61319733, 21.33569336], [72.61319733, 21.33597374], [72.61347198, 21.33596992], [72.61347198, 21.33653069], [72.61374664, 21.33653069], [72.61374664, 21.33681107], [72.61402893, 21.33680344], [72.61402893, 21.33708572], [72.61458588, 21.33708], [72.61458588, 21.33736038], [72.61541748, 21.33736038], [72.61541748, 21.3376503], [72.61597443, 21.33763885], [72.61597443, 21.33847237], [72.61624908, 21.33847046], [72.61624908, 21.33875084], [72.61653137, 21.33875084], [72.61653137, 21.33903122], [72.61708069, 21.3390274], [72.61708069, 21.33958244], [72.61736298, 21.33958054], [72.61736298, 21.33986092], [72.61763763, 21.33986092], [72.61763763, 21.34013939], [72.61736298, 21.34013939], [72.61736298, 21.34041977], [72.61763763, 21.34041786], [72.61763763, 21.34069443], [72.61791992, 21.34069443], [72.61791992, 21.3409729], [72.61818695, 21.34097099], [72.61818695, 21.34124947], [72.61875153, 21.34124947], [72.61875153, 21.34180832], [72.61902618, 21.34180641], [72.61902618, 21.34208298], [72.61875153, 21.34208298], [72.61875153, 21.34236145], [72.61930847, 21.34235954], [72.61930847, 21.34263992], [72.61958313, 21.34263992], [72.61958313, 21.3429184], [72.6204071, 21.3429184], [72.6204071, 21.34374809], [72.62069702, 21.34374809], [72.62069702, 21.34431267], [72.62097168, 21.34430504], [72.62097168, 21.34458351], [72.62124634, 21.3445816], [72.62124634, 21.34514046], [72.62152863, 21.34514046], [72.62152863, 21.34542274], [72.62208557, 21.34541702], [72.62208557, 21.34569359], [72.62236023, 21.34569359], [72.62236023, 21.34597015], [72.62264252, 21.34597015], [72.62264252, 21.34625053], [72.62180328, 21.34625053], [72.62180328, 21.34682083], [72.62236023, 21.34680557], [72.62236023, 21.34708214], [72.62264252, 21.34708023], [72.62264252, 21.34791946], [72.62291718, 21.34791756], [72.62291718, 21.3484745], [72.62319183, 21.34847069], [72.62319183, 21.34875107], [72.62346649, 21.34875107], [72.62346649, 21.34930992], [72.62403107, 21.34930992], [72.62403107, 21.35013962], [72.62430573, 21.35013962], [72.62430573, 21.35069656], [72.62458038, 21.35069084], [72.62458038, 21.35292053], [72.62431335, 21.35292053], [72.62431335, 21.35320091], [72.62403107, 21.35320091], [72.62403107, 21.35375023], [72.62374878, 21.35375023], [72.62374878, 21.35403061], [72.62346649, 21.35403061], [72.62346649, 21.35486031], [72.62374878, 21.35486031], [72.62374878, 21.35514069], [72.62403107, 21.35514069], [72.62403107, 21.35541916], [72.62458038, 21.35541725], [72.62458038, 21.35597229], [72.62513733, 21.35597038], [72.62513733, 21.35625076], [72.62541962, 21.35625076], [72.62541962, 21.35652924], [72.62596893, 21.35652924], [72.62596893, 21.35681152], [72.62652588, 21.3568058], [72.62652588, 21.35708237], [72.62708282, 21.35708046], [72.62708282, 21.35736084], [72.62763977, 21.35736084], [72.62763977, 21.3579216], [72.62791443, 21.35791588], [72.62791443, 21.35819435], [72.62819672, 21.35819435], [72.62819672, 21.35847282], [72.62874603, 21.35847092], [72.62874603, 21.35876274], [72.62902832, 21.35876274], [72.62902832, 21.35903168], [72.62930298, 21.35903168], [72.62930298, 21.35931015], [72.62985992, 21.35930634], [72.62985992, 21.3595829], [72.63041687, 21.3595829], [72.63041687, 21.35986137], [72.63153076, 21.35985947], [72.63153076, 21.36013985], [72.63181305, 21.36013985], [72.63181305, 21.36042023], [72.63236237, 21.36041641], [72.63236237, 21.36069489], [72.63263702, 21.36069489], [72.63263702, 21.36097145], [72.63346863, 21.36096954], [72.63346863, 21.36124992], [72.6340332, 21.36124992], [72.6340332, 21.3615303], [72.63430786, 21.3615303], [72.63430786, 21.36182022], [72.63458252, 21.36180305], [72.63458252, 21.36208153], [72.63486481, 21.36208153], [72.63486481, 21.36236382], [72.63540649, 21.36236], [72.63540649, 21.36292076], [72.63569641, 21.36292076], [72.63569641, 21.36375046], [72.63597107, 21.36375046], [72.63597107, 21.36514091], [72.63569641, 21.36514091], [72.63569641, 21.36625099], [72.63541412, 21.36624908], [72.63541412, 21.3670826], [72.63513947, 21.3670826], [72.63513947, 21.36763954], [72.63486481, 21.36763954], [72.63486481, 21.36819458], [72.63458252, 21.36819077], [72.63458252, 21.36874962], [72.63430786, 21.36874962], [72.63430786, 21.36902809], [72.63458252, 21.36902809], [72.63458252, 21.3698616], [72.63485718, 21.3698597], [72.63485718, 21.37013817], [72.63513184, 21.37013817], [72.63513184, 21.37041855], [72.63540649, 21.37041855], [72.63540649, 21.37070084], [72.63569641, 21.37069511], [72.63569641, 21.37097168], [72.63597107, 21.37096977], [72.63597107, 21.37153244], [72.63625336, 21.37153244], [72.63625336, 21.37181282], [72.63652802, 21.37180519], [72.63652802, 21.37208366], [72.63680267, 21.37208176], [72.63680267, 21.37236023], [72.63707733, 21.37236023], [72.63707733, 21.37264252], [72.63735962, 21.37264252], [72.63735962, 21.3729229], [72.63764191, 21.37291718], [72.63764191, 21.37319374], [72.63791656, 21.37319374], [72.63791656, 21.37347031], [72.63874817, 21.37347031], [72.63874817, 21.37403107], [72.63903046, 21.37403107], [72.63903046, 21.37430954], [72.63931274, 21.37430954], [72.63931274, 21.37403107], [72.64180756, 21.37403107], [72.64180756, 21.37376022], [72.64319611, 21.37376022], [72.64319611, 21.37347031], [72.64402771, 21.37347031], [72.64402771, 21.37319374], [72.64624786, 21.37319374], [72.64624786, 21.37291718], [72.6470871, 21.3729229], [72.6470871, 21.37264252], [72.64763641, 21.37264252], [72.64763641, 21.37236023], [72.6479187, 21.37236023], [72.6479187, 21.37125015], [72.64819336, 21.37125015], [72.64819336, 21.36958122], [72.6479187, 21.36958313], [72.6479187, 21.36902809], [72.64763641, 21.36902809], [72.64763641, 21.36847115], [72.64736176, 21.36847305], [72.64736176, 21.36791611], [72.6470871, 21.36791992], [72.6470871, 21.36763], [72.64680481, 21.36763954], [72.64680481, 21.36680794], [72.64653015, 21.36680984], [72.64653015, 21.36569023], [72.64624786, 21.36569595], [72.64624786, 21.36486053], [72.64597321, 21.36486053], [72.64597321, 21.36403084], [72.64569092, 21.36403084], [72.64569092, 21.36320114], [72.64541626, 21.3631897], [72.64541626, 21.36208153], [72.6451416, 21.36208153], [72.6451416, 21.36180305], [72.64485931, 21.36182022], [72.64485931, 21.36124992], [72.64430237, 21.36124992], [72.64430237, 21.36042023], [72.64402771, 21.36042023], [72.64402771, 21.35985947], [72.64375305, 21.35986137], [72.64375305, 21.35930634], [72.64347076, 21.35931015], [72.64347076, 21.35847092], [72.64430237, 21.35847092], [72.64430237, 21.35903168], [72.64458466, 21.35902786], [72.64458466, 21.3595829], [72.64485931, 21.3595829], [72.64485931, 21.35986137], [72.6451416, 21.35985947], [72.6451416, 21.36042023], [72.64541626, 21.36041641], [72.64541626, 21.36097145], [72.64569092, 21.36096954], [72.64569092, 21.36124992], [72.64597321, 21.36124992], [72.64597321, 21.36208153], [72.64624786, 21.36208153], [72.64624786, 21.36236382], [72.64653015, 21.36236], [72.64653015, 21.36264038], [72.6470871, 21.36263847], [72.6470871, 21.36319542], [72.64736176, 21.3631897], [72.64736176, 21.36375046], [72.64763641, 21.36375046], [72.64763641, 21.36458588], [72.6479187, 21.36457062], [72.6479187, 21.36514091], [72.64819336, 21.36514091], [72.64819336, 21.36541939], [72.64848328, 21.36541939], [72.64848328, 21.36625099], [72.64875031, 21.36624908], [72.64875031, 21.3670826], [72.64901733, 21.36708069], [72.64901733, 21.36736107], [72.64930725, 21.36736107], [72.64930725, 21.36819458], [72.64958191, 21.36819458], [72.64958191, 21.3698616], [72.64930725, 21.3698597], [72.64930725, 21.37070084], [72.64958191, 21.37069511], [72.64958191, 21.37097168], [72.64930725, 21.37096977], [72.64930725, 21.37181282], [72.64901733, 21.37181282], [72.64901733, 21.37376022], [72.64875031, 21.37376022], [72.64875031, 21.37430954], [72.64847565, 21.37430573], [72.64847565, 21.37458229], [72.64819336, 21.37458038], [72.64819336, 21.37486076], [72.6479187, 21.37486076], [72.6479187, 21.37514114], [72.64763641, 21.37514114], [72.64763641, 21.37541962], [72.64736176, 21.3754158], [72.64736176, 21.37569237], [72.64541626, 21.37569237], [72.64541626, 21.3754158], [72.64485931, 21.37541962], [72.64485931, 21.37514114], [72.64457703, 21.37514114], [72.64457703, 21.37486076], [72.64347076, 21.37486076], [72.64347076, 21.37458038], [72.64235687, 21.37458038], [72.64235687, 21.37486076], [72.64208221, 21.37486076], [72.64208221, 21.37514114], [72.64125824, 21.37514114], [72.64125824, 21.37541962], [72.64069366, 21.3754158], [72.64069366, 21.37569237], [72.64013672, 21.37569237], [72.64013672, 21.37597466], [72.63957977, 21.37597466], [72.63957977, 21.37569237], [72.63735962, 21.37569237], [72.63735962, 21.3754158], [72.63652802, 21.37541962], [72.63652802, 21.37514114], [72.63625336, 21.37514114], [72.63625336, 21.37486076], [72.63597107, 21.37486076], [72.63597107, 21.37458038], [72.63569641, 21.37458229], [72.63569641, 21.37430573], [72.63540649, 21.37430954], [72.63540649, 21.37376022], [72.63513184, 21.37376022], [72.63513184, 21.3729229], [72.63485718, 21.3729229], [72.63485718, 21.37264252], [72.63458252, 21.37264252], [72.63458252, 21.37208176], [72.63430786, 21.37208366], [72.63430786, 21.37180519], [72.6340332, 21.37181282], [72.6340332, 21.37153244], [72.63375092, 21.37153244], [72.63375092, 21.37096977], [72.63346863, 21.37097168], [72.63346863, 21.37069511], [72.63318634, 21.37070084], [72.63318634, 21.37013817], [72.63291931, 21.37013817], [72.63291931, 21.36958122], [72.63263702, 21.36958313], [72.63263702, 21.36930466], [72.63236237, 21.36930466], [72.63236237, 21.36874962], [72.63208008, 21.36874962], [72.63208008, 21.36847305], [72.63153076, 21.36847305], [72.63153076, 21.36652756], [72.63124847, 21.36652946], [72.63124847, 21.36625099], [72.63096619, 21.36625099], [72.63096619, 21.36597061], [72.63124847, 21.36597252], [72.63124847, 21.36513901], [72.63069153, 21.36514091], [72.63069153, 21.36486053], [72.62985992, 21.36486053], [72.62985992, 21.36514091], [72.62930298, 21.36514091], [72.62930298, 21.36541939], [72.62847137, 21.36541748], [72.62847137, 21.36569595], [72.62791443, 21.36569595], [72.62791443, 21.36541748], [72.62763977, 21.36541939], [72.62763977, 21.36514091], [72.62319183, 21.36513901], [72.62319183, 21.36597252], [72.62346649, 21.36597061], [72.62346649, 21.36625099], [72.62374878, 21.36625099], [72.62374878, 21.36680984], [72.62403107, 21.36680794], [72.62403107, 21.3670826], [72.62430573, 21.3670826], [72.62431335, 21.36736107], [72.62374878, 21.36736107], [72.62374878, 21.36791992], [72.62403107, 21.36791611], [72.62403107, 21.36819458], [72.62430573, 21.36819458], [72.62430573, 21.36930466], [72.62403107, 21.36930466], [72.62403107, 21.36958313], [72.62347412, 21.36958313], [72.62347412, 21.3698616], [72.62319183, 21.3698597], [72.62319183, 21.37236023], [72.62291718, 21.37236023], [72.62291718, 21.37376022], [72.62264252, 21.37376022], [72.62264252, 21.37403107], [72.62291718, 21.37403107], [72.62291718, 21.37514114], [72.62319183, 21.37513924], [72.62319183, 21.37569237], [72.62346649, 21.37569046], [72.62346649, 21.37652969], [72.62374878, 21.37652779], [72.62374878, 21.37708473], [72.62347412, 21.37708473], [72.62347412, 21.3773613], [72.62403107, 21.3773613], [72.62403107, 21.37819672], [72.62430573, 21.37819672], [72.62430573, 21.37847137], [72.62458038, 21.37846947], [72.62458038, 21.37903023], [72.62486267, 21.37903023], [72.62486267, 21.3801403], [72.62513733, 21.3801384], [72.62513733, 21.38097191], [72.62541962, 21.38096809], [72.62541962, 21.38153076], [72.62568665, 21.38153076], [72.62568665, 21.38180923], [72.62596893, 21.38180542], [72.62596893, 21.38208389], [72.62625122, 21.38207817], [72.62625122, 21.38236046], [72.62652588, 21.38236046], [72.62652588, 21.38293266], [72.62680817, 21.3829174], [72.62680817, 21.38347244], [72.62708282, 21.38347054], [72.62708282, 21.38375092], [72.62735748, 21.38375092], [72.62735748, 21.38402939], [72.62763977, 21.38402939], [72.62763977, 21.38431168], [72.62847137, 21.38431168], [72.62847137, 21.38485909], [72.62874603, 21.38485909], [72.62874603, 21.38513947], [72.62902832, 21.38513947], [72.62902832, 21.38542175], [72.6295929, 21.38542175], [72.6295929, 21.38570023], [72.62985992, 21.38570023], [72.62985992, 21.38624954], [72.63014221, 21.38624954], [72.63014221, 21.38680267], [72.63041687, 21.38680649], [72.63041687, 21.38736153], [72.63069153, 21.38735962], [72.63069153, 21.38764191], [72.63181305, 21.38764191], [72.63181305, 21.38820076], [72.63208008, 21.38819313], [72.63208008, 21.3884716], [72.63236237, 21.3884697], [72.63236237, 21.38903046], [72.63291931, 21.38902855], [72.63291931, 21.38958549], [72.63346863, 21.38957977], [72.63346863, 21.38986015], [72.63375092, 21.38986015], [72.63375092, 21.39014053], [72.63430786, 21.39014053], [72.63430786, 21.39042091], [72.63458252, 21.3904171], [72.63458252, 21.39069557], [72.63513947, 21.39069557], [72.63513947, 21.39097214], [72.63540649, 21.39097023], [72.63540649, 21.39153099], [72.63569641, 21.39152527], [72.63569641, 21.39180756], [72.63597107, 21.39180756], [72.63597107, 21.39208412], [72.63625336, 21.39208031], [72.63625336, 21.39236069], [72.63652802, 21.39236069], [72.63652802, 21.39264107], [72.63680267, 21.39264107], [72.63680267, 21.39291954], [72.63708496, 21.39291763], [72.63708496, 21.3931942], [72.63735962, 21.39319038], [72.63735962, 21.39375114], [72.63764191, 21.39375114], [72.63764191, 21.39402962], [72.63791656, 21.39402962], [72.63791656, 21.39430809], [72.63819122, 21.39430618], [72.63819122, 21.39458275], [72.63847351, 21.39458275], [72.63847351, 21.39569473], [72.63874817, 21.39569092], [72.63874817, 21.39624977], [72.63903046, 21.39624977], [72.63903046, 21.39652824], [72.63930511, 21.39652824], [72.63930511, 21.39680481], [72.63957977, 21.39680481], [72.63957977, 21.39708328], [72.63986206, 21.39708328], [72.63986206, 21.39736176], [72.64041901, 21.39735985], [72.64041901, 21.39763832], [72.64068604, 21.39763832], [72.64068604, 21.39793015], [72.64125824, 21.39793015], [72.64125824, 21.3982029], [72.64152527, 21.39819527], [72.64152527, 21.39847183], [72.64208221, 21.39847183], [72.64208221, 21.39875031], [72.64235687, 21.39875031], [72.64235687, 21.39903259], [72.64290619, 21.39903259], [72.64290619, 21.39931107], [72.64319611, 21.39930534], [72.64319611, 21.39958382], [72.64375305, 21.39958191], [72.64375305, 21.39986038], [72.64402771, 21.39986038], [72.64402771, 21.40097237], [72.64430237, 21.40097046], [72.64430237, 21.40180969], [72.64458466, 21.40180588], [72.64458466, 21.40208244], [72.6451416, 21.40208244], [72.6451416, 21.40180588], [72.64624786, 21.40180588], [72.64624786, 21.40208244], [72.64653015, 21.40208054], [72.64653015, 21.40236092], [72.64679718, 21.40236092], [72.64679718, 21.40291977], [72.6470871, 21.40291405], [72.6470871, 21.40319252], [72.64736176, 21.40319061], [72.64736176, 21.40402985], [72.6470871, 21.40402794], [72.6470871, 21.40458488], [72.64736176, 21.40458488], [72.64736176, 21.40486145], [72.64763641, 21.40486145], [72.64763641, 21.40458488], [72.6479187, 21.40458488], [72.6479187, 21.40430641], [72.64875031, 21.40430641], [72.64875031, 21.40486145], [72.64901733, 21.40485954], [72.64901733, 21.4054203], [72.64930725, 21.40541649], [72.64930725, 21.40597153], [72.64958191, 21.40596962], [72.64958191, 21.40625], [72.64985657, 21.40625], [72.64985657, 21.40596962], [72.6506958, 21.40596962], [72.6506958, 21.40625], [72.65097046, 21.40625], [72.65097046, 21.40653038], [72.6506958, 21.40653038], [72.6506958, 21.40681076], [72.65097046, 21.40680695], [72.65097046, 21.40819359], [72.65125275, 21.40819359], [72.65125275, 21.40958405], [72.6515274, 21.40957832], [72.6515274, 21.40987015], [72.65180206, 21.40987015], [72.65180206, 21.41013908], [72.65207672, 21.41013908], [72.65207672, 21.41124916], [72.65235901, 21.41124916], [72.65235901, 21.41181183], [72.6526413, 21.41180611], [72.6526413, 21.41208267], [72.65291595, 21.41208076], [72.65291595, 21.41235924], [72.65319824, 21.41235924], [72.65319824, 21.41291618], [72.6534729, 21.41291618], [72.6534729, 21.41319466], [72.65374756, 21.41319466], [72.65374756, 21.41347122], [72.65458679, 21.41347122], [72.65458679, 21.41374969], [72.65486145, 21.41374969], [72.65486145, 21.41403008], [72.65513611, 21.41402817], [72.65513611, 21.4145813], [72.6554184, 21.4145813], [72.6554184, 21.41486359], [72.65569305, 21.41485977], [72.65569305, 21.41514015], [72.65598297, 21.41514015], [72.65598297, 21.41542053], [72.65625763, 21.41542053], [72.65625763, 21.41570091], [72.65652466, 21.41569328], [72.65652466, 21.41597176], [72.65680695, 21.41596985], [72.65680695, 21.41625023], [72.6570816, 21.41625023], [72.6570816, 21.41653061], [72.65735626, 21.41653061], [72.65735626, 21.41681099], [72.65763855, 21.41680336], [72.65763855, 21.41708565], [72.6581955, 21.41708565], [72.6581955, 21.41736031], [72.65847015, 21.41736031], [72.65847015, 21.41764069], [72.65875244, 21.41764069], [72.65875244, 21.41792107], [72.6590271, 21.41791725], [72.6590271, 21.41847229], [72.65957642, 21.41847038], [72.65957642, 21.41903114], [72.6598587, 21.41903114], [72.6598587, 21.41930962], [72.66014099, 21.41930962], [72.66014099, 21.41986084], [72.66042328, 21.41986084], [72.66042328, 21.42041969], [72.66069794, 21.42041779], [72.66069794, 21.42097282], [72.6609726, 21.42097092], [72.6609726, 21.42152977], [72.66124725, 21.42152977], [72.66124725, 21.4220829], [72.66152954, 21.42208099], [72.66152954, 21.42263985], [72.66124725, 21.42263985], [72.66124725, 21.42291832], [72.66152954, 21.42291641], [72.66152954, 21.42319489], [72.6618042, 21.42319489], [72.6618042, 21.42347145], [72.66208649, 21.42346954], [72.66208649, 21.4240284], [72.66236115, 21.4240284], [72.66236115, 21.42431259], [72.6626358, 21.42430496], [72.6626358, 21.42486191], [72.66291809, 21.42485046], [72.66291809, 21.42542267], [72.66319275, 21.42541695], [72.66319275, 21.42569351], [72.66347504, 21.42569351], [72.66347504, 21.42597008], [72.66374969, 21.42597008], [72.66374969, 21.42625046], [72.66401672, 21.42625046], [72.66401672, 21.42653275], [72.66430664, 21.42653275], [72.66430664, 21.42681122], [72.6645813, 21.4268055], [72.6645813, 21.42708206], [72.66485596, 21.42708015], [72.66485596, 21.42736053], [72.66596985, 21.42736053], [72.66596985, 21.42764282], [72.66625214, 21.42763901], [72.66625214, 21.42791748], [72.66680908, 21.42791748], [72.66680908, 21.42819214], [72.66764069, 21.42819214], [72.66764069, 21.42847443], [72.66847229, 21.42847061], [72.66847229, 21.4287529], [72.67041779, 21.4287529], [72.67041779, 21.42902946], [72.67124176, 21.42902946], [72.67124176, 21.42930984], [72.67236328, 21.42930412], [72.67236328, 21.4295826], [72.67318726, 21.42958069], [72.67318726, 21.42986107], [72.67402649, 21.42986107], [72.67402649, 21.43013954], [72.67457581, 21.43013954], [72.67457581, 21.43041992], [72.67514038, 21.4304142], [72.67514038, 21.43069649], [72.67541504, 21.43069649], [72.67541504, 21.43097305], [72.67624664, 21.43097115], [72.67624664, 21.43153], [72.67680359, 21.43152809], [72.67680359, 21.43180656], [72.67708588, 21.43180656], [72.67708588, 21.43208313], [72.67791748, 21.43208313], [72.67791748, 21.4323616], [72.6784668, 21.4323597], [72.6784668, 21.43264008], [72.67874908, 21.43264008], [72.67874908, 21.43292046], [72.67930603, 21.43292046], [72.67930603, 21.43320084], [72.67958069, 21.43320084], [72.67958069, 21.43375015], [72.68013763, 21.43375015], [72.68013763, 21.43431091], [72.68041992, 21.43430519], [72.68041992, 21.43458366], [72.68068695, 21.43457985], [72.68068695, 21.43541908], [72.68096924, 21.43541718], [72.68096924, 21.43597221], [72.68125153, 21.43597031], [72.68125153, 21.43652916], [72.68152618, 21.43652916], [72.68152618, 21.43736076], [72.68180847, 21.43736076], [72.68180847, 21.43792152], [72.68208313, 21.43792152], [72.68208313, 21.43931007], [72.68235779, 21.43930626], [72.68235779, 21.43958282], [72.68264008, 21.43958282], [72.68264008, 21.4398613], [72.6829071, 21.43985176], [72.6829071, 21.44013977], [72.68319702, 21.44013977], [72.68319702, 21.44042015], [72.68347168, 21.44041634], [72.68347168, 21.44097137], [72.68374634, 21.44096947], [72.68374634, 21.44124985], [72.68402863, 21.44124985], [72.68402863, 21.44153023], [72.68430328, 21.44152832], [72.68430328, 21.44208145], [72.6845932, 21.44207954], [72.6845932, 21.44292068], [72.68486023, 21.44292068], [72.68486023, 21.44403076], [72.68514252, 21.44403076], [72.68514252, 21.44431114], [72.68541718, 21.44430351], [72.68541718, 21.4445858], [72.68569183, 21.4445858], [72.68569183, 21.44486046], [72.68596649, 21.44486046], [72.68596649, 21.44514084], [72.68624115, 21.44514084], [72.68624115, 21.44542122], [72.68653107, 21.44542122], [72.68653107, 21.44598007], [72.68681335, 21.44598007], [72.68681335, 21.44680977], [72.68624115, 21.44680977], [72.68624115, 21.44736099], [72.68653107, 21.44736099], [72.68653107, 21.44763947], [72.68680573, 21.44763947], [72.68680573, 21.44847298], [72.68708038, 21.44847298], [72.68708038, 21.44958305], [72.68736267, 21.44958115], [72.68736267, 21.45125008], [72.68763733, 21.45125008], [72.68763733, 21.45236015], [72.68791962, 21.45236015], [72.68791962, 21.45319366], [72.68818665, 21.45319176], [72.68818665, 21.45375061], [72.68875122, 21.45375061], [72.68875122, 21.45486069], [72.68902588, 21.45486069], [72.68902588, 21.45541954], [72.68930817, 21.45541573], [72.68930817, 21.45597458], [72.68958282, 21.45597076], [72.68958282, 21.45625114], [72.68985748, 21.45625114], [72.68985748, 21.45681], [72.69013977, 21.45681], [72.69013977, 21.45763969], [72.6904068, 21.45763969], [72.6904068, 21.45792007], [72.69069672, 21.45791435], [72.69069672, 21.4584713], [72.69097137, 21.45846939], [72.69097137, 21.45903015], [72.69125366, 21.45902824], [72.69125366, 21.45930672], [72.69152832, 21.45930672], [72.69152832, 21.45958328], [72.69180298, 21.45958328], [72.69180298, 21.45986176], [72.6920929, 21.45985985], [72.6920929, 21.46042061], [72.69236755, 21.46042061], [72.69236755, 21.46069908], [72.69264221, 21.46069908], [72.69264221, 21.46097946], [72.69291687, 21.46097946], [72.69291687, 21.46180916], [72.69346619, 21.46180916], [72.69346619, 21.46236038], [72.69374847, 21.46236038], [72.69374847, 21.46291924], [72.69403076, 21.46291733], [72.69403076, 21.46319389], [72.69430542, 21.46319389], [72.69430542, 21.46375084], [72.69486237, 21.46375084], [72.69486237, 21.4640274], [72.69541168, 21.46401978], [72.69541168, 21.4643116], [72.69625092, 21.46430588], [72.69625092, 21.46458244], [72.69680786, 21.46458054], [72.69680786, 21.46513939], [72.69625092, 21.46513939], [72.69625092, 21.46542168], [72.69596863, 21.46541595], [72.69596863, 21.46569443], [72.69569397, 21.46569443], [72.69569397, 21.4659729], [72.69541168, 21.46596909], [72.69541931, 21.46624947], [72.69430542, 21.46624947], [72.69430542, 21.4659729], [72.69403076, 21.4659729], [72.69403076, 21.46569443], [72.69347382, 21.46569443], [72.69347382, 21.46541595], [72.69319153, 21.46542168], [72.69319153, 21.46513939], [72.69291687, 21.46513939], [72.69291687, 21.46486092], [72.69264221, 21.46486092], [72.69264221, 21.46458054], [72.69180298, 21.46458244], [72.69180298, 21.46430588], [72.69152832, 21.4643116], [72.69152832, 21.46401978], [72.69125366, 21.4640274], [72.69125366, 21.46375084], [72.69097137, 21.46375084], [72.69097137, 21.46347046], [72.69069672, 21.46347237], [72.69069672, 21.46319389], [72.69013977, 21.46319389], [72.69013977, 21.46263885], [72.68985748, 21.46264076], [72.68985748, 21.46236038], [72.68958282, 21.46236038], [72.68958282, 21.46207809], [72.68930817, 21.46208382], [72.68930817, 21.46180534], [72.68902588, 21.46180916], [72.68902588, 21.46153069], [72.68875122, 21.46153069], [72.68875122, 21.46069908], [72.68846893, 21.46069908], [72.68846893, 21.46014023], [72.68818665, 21.46014023], [72.68818665, 21.45985985], [72.68791962, 21.45986176], [72.68791962, 21.45958328], [72.68736267, 21.45958328], [72.68736267, 21.45902824], [72.68708038, 21.45903015], [72.68708038, 21.45874977], [72.68680573, 21.45874977], [72.68680573, 21.45819664], [72.68653107, 21.45819664], [72.68653107, 21.45791435], [72.68624115, 21.45792007], [72.68624115, 21.45736122], [72.68596649, 21.45736122], [72.68596649, 21.45708084], [72.68541718, 21.45708466], [72.68541718, 21.45680428], [72.68514252, 21.45681], [72.68514252, 21.45652962], [72.68486023, 21.45652962], [72.68486023, 21.45569038], [72.68458557, 21.45569229], [72.68458557, 21.45541763], [72.68430328, 21.45541954], [72.68430328, 21.45458031], [72.68402863, 21.45458221], [72.68402863, 21.45430565], [72.68374634, 21.45430946], [72.68374634, 21.45375061], [72.68347168, 21.45375061], [72.68347168, 21.45347023], [72.68319702, 21.45347023], [72.68319702, 21.4529171], [72.6829071, 21.45292282], [72.6829071, 21.45264053], [72.68264008, 21.45264053], [72.68264008, 21.45181274], [72.68235779, 21.45181274], [72.68235779, 21.45153236], [72.68208313, 21.45153236], [72.68208313, 21.45070076], [72.68235779, 21.45070076], [72.68235779, 21.4493084], [72.68208313, 21.4493084], [72.68208313, 21.44903946], [72.68180847, 21.44903946], [72.68180847, 21.44874954], [72.68125153, 21.44874954], [72.68125153, 21.44847107], [72.68041992, 21.44847298], [72.68041992, 21.4481945], [72.68013763, 21.4481945], [72.68013763, 21.44791794], [72.67986298, 21.44791985], [72.67986298, 21.44763947], [72.67930603, 21.44763947], [72.67930603, 21.44736099], [72.67903137, 21.44736099], [72.67903137, 21.44763947], [72.6784668, 21.44763947], [72.6784668, 21.44736099], [72.67819214, 21.44736099], [72.67819214, 21.44708061], [72.67763519, 21.44708252], [72.67764282, 21.44736099], [72.67652893, 21.44736099], [72.67652893, 21.44763947], [72.67624664, 21.44763947], [72.67624664, 21.44791985], [72.67263794, 21.44791985], [72.67263794, 21.44763947], [72.67180634, 21.44763947], [72.67180634, 21.44736099], [72.6709671, 21.44736099], [72.6709671, 21.44708061], [72.66930389, 21.44708252], [72.66930389, 21.44680786], [72.66902924, 21.44680977], [72.66902924, 21.44652939], [72.66874695, 21.44652939], [72.66874695, 21.44625092], [72.66847229, 21.44625092], [72.66847229, 21.44569016], [72.66764069, 21.44569588], [72.66764069, 21.4454174], [72.66707611, 21.44542122], [72.66707611, 21.44514084], [72.66625214, 21.44514084], [72.66625214, 21.44486046], [72.66596985, 21.44486046], [72.66596985, 21.44458008], [72.66569519, 21.4445858], [72.66569519, 21.44430351], [72.66513824, 21.44431114], [72.66513824, 21.44403076], [72.6645813, 21.44403076], [72.6645813, 21.44375038], [72.66430664, 21.44375038], [72.66430664, 21.44347], [72.66374969, 21.44347382], [72.66374969, 21.44319344], [72.66319275, 21.44320107], [72.66319275, 21.44292068], [72.6626358, 21.44292068], [72.6626358, 21.4426403], [72.66236115, 21.4426403], [72.66236115, 21.44235992], [72.66208649, 21.44236374], [72.66208649, 21.44208145], [72.6618042, 21.44208145], [72.6618042, 21.44180489], [72.66152954, 21.44180489], [72.66152954, 21.44152832], [72.66069794, 21.44153023], [72.66069794, 21.44124985], [72.66041565, 21.44124985], [72.66041565, 21.44097137], [72.65930176, 21.44097137], [72.65930176, 21.44069481], [72.6590271, 21.44069481], [72.6590271, 21.44041634], [72.65847015, 21.44042015], [72.65847015, 21.44013977], [72.65791321, 21.44013977], [72.65791321, 21.43985176], [72.65736389, 21.4398613], [72.65736389, 21.43958282], [72.65652466, 21.43958282], [72.65652466, 21.43930626], [72.65625763, 21.43931007], [72.65625763, 21.43902969], [72.65569305, 21.43902969], [72.65569305, 21.43874931], [72.65513611, 21.43874931], [72.65513611, 21.43847084], [72.65486145, 21.43847275], [72.65486145, 21.43819427], [72.6543045, 21.43819427], [72.6543045, 21.4379158], [72.6534729, 21.43792152], [72.6534729, 21.43763924], [72.65291595, 21.43763924], [72.65291595, 21.43736076], [72.6526413, 21.43736076], [72.6526413, 21.4371624], [72.6526413, 21.43680573], [72.65235901, 21.43681145], [72.65235901, 21.43625069], [72.65180206, 21.43625069], [72.65180206, 21.43597031], [72.6506958, 21.43597031], [72.6506958, 21.43625069], [72.64985657, 21.43625069], [72.64985657, 21.43652916], [72.6479187, 21.43652916], [72.6479187, 21.43597031], [72.64680481, 21.43597221], [72.64680481, 21.43541718], [72.64653015, 21.43541908], [72.64653015, 21.43514061], [72.64624786, 21.43514061], [72.64624786, 21.43486023], [72.64597321, 21.43486023], [72.64597321, 21.43457985], [72.64569092, 21.43458366], [72.64569092, 21.43375015], [72.6451416, 21.43375015], [72.6451416, 21.43541908], [72.64485931, 21.43541718], [72.64485931, 21.43597221], [72.64457703, 21.43597031], [72.64457703, 21.43625069], [72.64430237, 21.43625069], [72.64430237, 21.43792152], [72.64402771, 21.4379158], [72.64402771, 21.43847275], [72.64375305, 21.43847084], [72.64375305, 21.43874931], [72.64402771, 21.43874931], [72.64402771, 21.43931007], [72.64375305, 21.43930626], [72.64375305, 21.43958282], [72.64319611, 21.43958282], [72.64319611, 21.44124985], [72.64347076, 21.44124985], [72.64347076, 21.44153023], [72.64375305, 21.44152832], [72.64375305, 21.44180489], [72.64402771, 21.44180489], [72.64402771, 21.44208145], [72.64430237, 21.44207954], [72.64430237, 21.4426403], [72.64457703, 21.4426403], [72.64457703, 21.44320107], [72.64485931, 21.44319344], [72.64485931, 21.44347382], [72.6451416, 21.44347], [72.6451416, 21.44375038], [72.64569092, 21.44375038], [72.64569092, 21.44431114], [72.64597321, 21.44430351], [72.64597321, 21.4445858], [72.64624786, 21.44458008], [72.64624786, 21.44486046], [72.64736176, 21.44486046], [72.64737701, 21.44514084], [72.6479187, 21.44513893], [72.6479187, 21.44569588], [72.64819336, 21.44569016], [72.64819336, 21.44598007], [72.64848328, 21.44598007], [72.64848328, 21.44652939], [72.64875031, 21.44652748], [72.64875031, 21.44708252], [72.64901733, 21.44708061], [72.64901733, 21.44763947], [72.64958191, 21.44763947], [72.64958191, 21.4481945], [72.6498642, 21.4481945], [72.64985657, 21.44930077], [72.65013123, 21.4493084], [72.65013123, 21.45070076], [72.65041351, 21.45069504], [72.65041351, 21.4509716], [72.6506958, 21.4509697], [72.6506958, 21.45153236], [72.65097046, 21.45152855], [72.65097046, 21.45319366], [72.65125275, 21.45319176], [72.65125275, 21.45763969], [72.6515274, 21.45763969], [72.6515274, 21.45986176], [72.65180206, 21.45985985], [72.65180206, 21.46014023], [72.65207672, 21.46014023], [72.65207672, 21.46042061], [72.65235901, 21.46042061], [72.65235901, 21.46097946], [72.6526413, 21.46097946], [72.6526413, 21.46125031], [72.65235901, 21.46125031], [72.65235901, 21.46208382], [72.6526413, 21.46207809], [72.6526413, 21.46236038], [72.6534729, 21.46236038], [72.6534729, 21.46264076], [72.65402985, 21.46263885], [72.65402985, 21.46319389], [72.65429688, 21.46318817], [72.65429688, 21.46375084], [72.65458679, 21.46375084], [72.65458679, 21.4640274], [72.65486145, 21.46401978], [72.65486145, 21.4643116], [72.65513611, 21.4643116], [72.65513611, 21.46375084], [72.65569305, 21.46375084], [72.65569305, 21.4643116], [72.65597534, 21.46430588], [72.65597534, 21.46486092], [72.65625763, 21.46486092], [72.65625763, 21.46542168], [72.65597534, 21.46541595], [72.65597534, 21.46569443], [72.6543045, 21.46569443], [72.6543045, 21.46541595], [72.65374756, 21.46542168], [72.65374756, 21.46513939], [72.6534729, 21.46513939], [72.6534729, 21.46486092], [72.65235901, 21.46486092], [72.65235901, 21.46513939], [72.65207672, 21.46513939], [72.65207672, 21.46542168], [72.65235901, 21.46541595], [72.65235901, 21.46569443], [72.65291595, 21.46569443], [72.65291595, 21.4659729], [72.6534729, 21.46596909], [72.6534729, 21.46624947], [72.65402985, 21.46624947], [72.65402985, 21.46653175], [72.6543045, 21.46652794], [72.6543045, 21.46708107], [72.65458679, 21.46708107], [72.65458679, 21.46736145], [72.65486145, 21.46735954], [72.65486145, 21.4679203], [72.65513611, 21.4679203], [72.65513611, 21.46820068], [72.6554184, 21.46819305], [72.6554184, 21.46847153], [72.65597534, 21.46847153], [72.65597534, 21.46875], [72.65625763, 21.46875], [72.65625763, 21.46903038], [72.6570816, 21.46903038], [72.6570816, 21.46931076], [72.65736389, 21.46930313], [72.65736389, 21.46958542], [72.65763855, 21.4695797], [72.65763855, 21.47014999], [72.65791321, 21.47013855], [72.65791321, 21.47097206], [72.65820313, 21.47097015], [72.65820313, 21.47180939], [72.65847015, 21.47180367], [72.65847015, 21.47208595], [72.6590271, 21.47208023], [72.6590271, 21.47236061], [72.65930176, 21.47236061], [72.65930176, 21.47264099], [72.65957642, 21.47264099], [72.65957642, 21.47291946], [72.6598587, 21.47291756], [72.6598587, 21.47319412], [72.66014099, 21.47319412], [72.66014099, 21.4734726], [72.66041565, 21.4734726], [72.66041565, 21.47513962], [72.66179657, 21.47513962], [72.66179657, 21.47541809], [72.66208649, 21.47541618], [72.66208649, 21.47569466], [72.66236115, 21.47569084], [72.66236115, 21.47624969], [72.6626358, 21.47624969], [72.6626358, 21.47652817], [72.66291809, 21.47652817], [72.66291809, 21.47708321], [72.66319275, 21.47707748], [72.66319275, 21.47763824], [72.66348267, 21.47763824], [72.66348267, 21.47792244], [72.66401672, 21.47792244], [72.66401672, 21.47763824], [72.6645813, 21.47763824], [72.6645813, 21.47792244], [72.66485596, 21.47792244], [72.66485596, 21.47875023], [72.66513824, 21.47875023], [72.66513824, 21.47986031], [72.6654129, 21.47986031], [72.6654129, 21.48069382], [72.66570282, 21.48069191], [72.66570282, 21.48180962], [72.66596985, 21.48180962], [72.66596985, 21.48236084], [72.66625214, 21.48236084], [72.66625214, 21.48374939], [72.66652679, 21.48374939], [72.66652679, 21.48458481], [72.66680908, 21.48458481], [72.66680908, 21.48642159], [72.66680908, 21.48847198], [72.66707611, 21.48846817], [72.66707611, 21.48903084], [72.6673584, 21.48902893], [72.6673584, 21.4920826], [72.66707611, 21.49208069], [72.66707611, 21.49235916], [72.6673584, 21.49235916], [72.6673584, 21.49292183], [72.66764069, 21.49291611], [72.66764069, 21.49347115], [72.66791534, 21.49347115], [72.66791534, 21.49374962], [72.66819763, 21.49374962], [72.66819763, 21.49681091], [72.66847229, 21.49680328], [72.66847229, 21.49819565], [72.66874695, 21.49818993], [72.66874695, 21.49875069], [72.66902924, 21.49875069], [72.66902924, 21.50097275], [72.66874695, 21.50097275], [72.66874695, 21.50208282], [72.66902924, 21.50208282], [72.66902924, 21.5023613], [72.66929626, 21.50235939], [72.66929626, 21.50263977], [72.66986084, 21.50263977], [72.66986084, 21.50291824], [72.67041779, 21.50291634], [72.67041779, 21.50319481], [72.67069244, 21.50319481], [72.67069244, 21.50486183], [72.6709671, 21.50486183], [72.6709671, 21.50542259], [72.67124176, 21.50542259], [72.67124176, 21.50681114], [72.6709671, 21.50681114], [72.6709671, 21.50792122], [72.67069244, 21.50792122], [72.67069244, 21.50902939], [72.67041779, 21.50902939], [72.67041779, 21.50932121], [72.67069244, 21.50932121], [72.67069244, 21.51013947], [72.6709671, 21.51013947], [72.6709671, 21.51124954], [72.67124939, 21.51124954], [72.67124176, 21.51180077], [72.67152405, 21.51180649], [72.67152405, 21.51236153], [72.67180634, 21.51235962], [72.67180634, 21.51292038], [72.67346954, 21.51292038], [72.67346954, 21.51320076], [72.67541504, 21.51319695], [72.67541504, 21.5134716], [72.67736053, 21.5134716], [72.67736053, 21.51375008], [72.67764282, 21.51375008], [72.67764282, 21.51403046], [72.6784668, 21.51403046], [72.6784668, 21.51375008], [72.67930603, 21.51375008], [72.67930603, 21.51403046], [72.67986298, 21.51403046], [72.67986298, 21.51431084], [72.68041992, 21.51430511], [72.68041992, 21.51458359], [72.68068695, 21.51457977], [72.68069458, 21.51486015], [72.68096924, 21.51486206], [72.68096924, 21.51513863], [72.68125153, 21.515131], [72.68125153, 21.51542091], [72.68152618, 21.5154171], [72.68152618, 21.51569366], [72.68180847, 21.51569366], [72.68180847, 21.51597214], [72.68208313, 21.51597023], [72.68208313, 21.51763916], [72.68152618, 21.51763916], [72.68152618, 21.51736069], [72.68125153, 21.51736069], [72.68125153, 21.5170784], [72.68096924, 21.51708412], [72.68096924, 21.51652718], [72.68042755, 21.51652908], [72.68042755, 21.51625061], [72.67986298, 21.51625061], [72.67986298, 21.51597023], [72.67958069, 21.51597214], [72.67958069, 21.51569366], [72.67847443, 21.51569366], [72.67847443, 21.5154171], [72.67791748, 21.5154171], [72.67791748, 21.51569366], [72.67652893, 21.51569366], [72.67652893, 21.5154171], [72.67624664, 21.51542091], [72.67624664, 21.515131], [72.67597198, 21.51513863], [72.67597198, 21.51486206], [72.67541504, 21.51486206], [72.67541504, 21.51458359], [72.67402649, 21.51458359], [72.67402649, 21.51430511], [72.67236328, 21.51430511], [72.67236328, 21.51458359], [72.6709671, 21.51457977], [72.67097473, 21.51486015], [72.67124939, 21.51486206], [72.67124939, 21.51513863], [72.67151642, 21.515131], [72.67151642, 21.51542091], [72.67180634, 21.5154171], [72.67180634, 21.51569366], [72.67208099, 21.51568985], [72.67208099, 21.51625061], [72.67236328, 21.51625061], [72.67236328, 21.51652908], [72.67292023, 21.51652908], [72.67292023, 21.51681137], [72.67318726, 21.51681137], [72.67318726, 21.51791954], [72.67346954, 21.51791954], [72.67346954, 21.51820183], [72.67375183, 21.51820183], [72.67375183, 21.51874924], [72.67402649, 21.51874924], [72.67402649, 21.52042007], [72.67430878, 21.52041626], [72.67430878, 21.52069473], [72.67457581, 21.52069283], [72.67457581, 21.52126122], [72.67542267, 21.52126122], [72.67542267, 21.52153015], [72.67569733, 21.52152824], [72.67569733, 21.52180481], [72.67624664, 21.52180481], [72.67624664, 21.52208138], [72.67652893, 21.52208138], [72.67652893, 21.52236366], [72.67679596, 21.52235985], [72.67679596, 21.52264023], [72.67708588, 21.52264023], [72.67708588, 21.52292061], [72.67736816, 21.52292061], [72.67736816, 21.52320099], [72.67791748, 21.52319336], [72.67791748, 21.52347183], [72.67819214, 21.52346992], [72.67819214, 21.52375031], [72.6784668, 21.52375031], [72.6784668, 21.52403069], [72.67874908, 21.52402687], [72.67874908, 21.52458572], [72.67930603, 21.52458], [72.67930603, 21.52486038], [72.67986298, 21.52486038], [72.67986298, 21.52514076], [72.68042755, 21.52514076], [72.68042755, 21.52542114], [72.68096924, 21.52541733], [72.68096924, 21.5256958], [72.68125153, 21.5256958], [72.68125153, 21.52597237], [72.68152618, 21.52597046], [72.68152618, 21.52625084], [72.68208313, 21.52625084], [72.68208313, 21.52653122], [72.68264008, 21.52653122], [72.68264008, 21.52680969], [72.68458557, 21.52680779], [72.68458557, 21.52708244], [72.68486023, 21.527071], [72.68486023, 21.52736092], [72.68514252, 21.52736092], [72.68514252, 21.52763939], [72.68541718, 21.52763939], [72.68541718, 21.52791977], [72.68569183, 21.52791786], [72.68569183, 21.52819443], [72.68653107, 21.52819443], [72.68653107, 21.5284729], [72.68819427, 21.5284729], [72.68819427, 21.52819443], [72.68902588, 21.52819443], [72.68902588, 21.52791786], [72.68985748, 21.52791786], [72.68985748, 21.52819443], [72.69013977, 21.52819443], [72.69013977, 21.52791786], [72.69180298, 21.52791977], [72.69180298, 21.52763939], [72.69264221, 21.52763939], [72.69264221, 21.52736092], [72.69568634, 21.52736092], [72.69568634, 21.527071], [72.69875336, 21.527071], [72.69875336, 21.52736092], [72.69930267, 21.52736092], [72.69930267, 21.527071], [72.70041656, 21.527071], [72.70041656, 21.52736092], [72.70236206, 21.52736092], [72.70236206, 21.52763939], [72.7040329, 21.52763939], [72.7040329, 21.52791977], [72.70569611, 21.52791786], [72.70569611, 21.52819443], [72.70597076, 21.52819443], [72.70597076, 21.5284729], [72.70652771, 21.52847099], [72.70652771, 21.52874947], [72.70680237, 21.52874947], [72.70680237, 21.52902985], [72.70707703, 21.52902985], [72.70707703, 21.52930832], [72.7076416, 21.52930641], [72.7076416, 21.52958298], [72.70903015, 21.52958298], [72.70903015, 21.52986145], [72.7095871, 21.52985954], [72.7095871, 21.53013992], [72.71041107, 21.53013992], [72.71041107, 21.5304184], [72.71125031, 21.5304184], [72.71125031, 21.53070068], [72.71208191, 21.53069496], [72.71208191, 21.53097153], [72.71290588, 21.53096962], [72.71290588, 21.53124809], [72.71430206, 21.53124809], [72.71430206, 21.53153038], [72.71457672, 21.53153038], [72.71457672, 21.53181267], [72.71569824, 21.53180504], [72.71569824, 21.53208351], [72.71624756, 21.53208351], [72.71624756, 21.53236008], [72.71671295, 21.53236008], [72.71708679, 21.53236008], [72.71708679, 21.53264046], [72.71763611, 21.53264046], [72.71763611, 21.53292274], [72.71819305, 21.53292274], [72.71819305, 21.53320122], [72.71902466, 21.53319359], [72.71902466, 21.53347015], [72.71985626, 21.53347015], [72.71985626, 21.53375053], [72.72070313, 21.53375053], [72.72070313, 21.53403282], [72.7215271, 21.53403282], [72.7215271, 21.53430939], [72.72180176, 21.53430557], [72.72180939, 21.53458214], [72.72208405, 21.53458214], [72.72208405, 21.53430557], [72.7223587, 21.53430557], [72.7223587, 21.53458214], [72.72429657, 21.53458023], [72.72429657, 21.53486061], [72.72486115, 21.53486061], [72.72486115, 21.5351429], [72.72624969, 21.5351429], [72.72624969, 21.53486061], [72.72680664, 21.53486061], [72.72680664, 21.5351429], [72.72735596, 21.5351429], [72.72735596, 21.53541946], [72.7279129, 21.53541756], [72.7279129, 21.53569221], [72.72902679, 21.53569221], [72.72902679, 21.5359745], [72.7298584, 21.5359745], [72.7298584, 21.53624916], [72.73069763, 21.53623962], [72.73069763, 21.53652954], [72.73208618, 21.53652954], [72.73208618, 21.53680992], [72.73236084, 21.53680992], [72.73236084, 21.53652954], [72.73291779, 21.53652763], [72.73291779, 21.53708267], [72.73374939, 21.53708076], [72.73374939, 21.53736115], [72.73430634, 21.53736115], [72.73430634, 21.53763962], [72.73486328, 21.53763962], [72.73486328, 21.53792], [72.73569489, 21.53791428], [72.73569489, 21.53819656], [72.73680878, 21.53819656], [72.73680878, 21.53847313], [72.73707581, 21.53847122], [72.73707581, 21.53874969], [72.73735809, 21.53874969], [72.73735809, 21.53903008], [72.73764038, 21.53902817], [72.73764038, 21.53958321], [72.73791504, 21.53958321], [72.73791504, 21.53986168], [72.73819733, 21.53985977], [72.73819733, 21.54014015], [72.73874664, 21.54014015], [72.73874664, 21.54042053], [72.73902893, 21.54041862], [72.73902893, 21.54097176], [72.73929596, 21.54096985], [72.73929596, 21.54125023], [72.73958588, 21.54125023], [72.73958588, 21.54153061], [72.74014282, 21.54153061], [72.74014282, 21.54180908], [72.74069214, 21.54180908], [72.74069214, 21.54264069], [72.74097443, 21.54263878], [72.74097443, 21.54319382], [72.74153137, 21.54319382], [72.74153137, 21.54347229], [72.74180603, 21.54347229], [72.74180603, 21.54569435], [72.74263763, 21.54569435], [72.74263763, 21.5470829], [72.74236298, 21.5470829], [72.74236298, 21.54847145], [72.74208069, 21.54846954], [72.74208069, 21.54874992], [72.74236298, 21.54874992], [72.74236298, 21.55014038], [72.74208069, 21.55014038], [72.74208069, 21.55042076], [72.74180603, 21.55041695], [72.74180603, 21.5506897], [72.74153137, 21.55069351], [72.74153137, 21.55097389], [72.74124908, 21.55097389], [72.74124908, 21.55125046], [72.7409668, 21.55124092], [72.7409668, 21.55153084], [72.74069214, 21.55153084], [72.74069214, 21.55181122], [72.74041748, 21.55180359], [72.74041748, 21.55208588], [72.73986053, 21.55208015], [72.73986053, 21.55236053], [72.73958588, 21.55236053], [72.73958588, 21.55264091], [72.73874664, 21.55264091], [72.73874664, 21.55291939], [72.73819733, 21.55291748], [72.73819733, 21.55319595], [72.73735809, 21.55319595], [72.73735809, 21.55291748], [72.73680878, 21.55291748], [72.73680878, 21.55319595], [72.73596954, 21.55319595], [72.73596954, 21.55347252], [72.73568726, 21.55347061], [72.73568726, 21.55402946], [72.73542023, 21.55402946], [72.73542023, 21.55486107], [72.73568726, 21.55486107], [72.73568726, 21.55513954], [72.73625183, 21.55513954], [72.73625183, 21.55541992], [72.73652649, 21.55541611], [72.73652649, 21.55597305], [72.73680878, 21.55597305], [72.73680878, 21.55680466], [72.73625183, 21.55680466], [72.73625183, 21.55652809], [72.73568726, 21.55652809], [72.73568726, 21.55624962], [72.73486328, 21.55624962], [72.73486328, 21.55597115], [72.73458099, 21.55597305], [72.73458099, 21.55569458], [72.73374939, 21.55569458], [72.73374939, 21.55541611], [72.7334671, 21.55541992], [72.7334671, 21.55486107], [72.73319244, 21.55486107], [72.73319244, 21.55402946], [72.73291779, 21.55402946], [72.73291779, 21.55264091], [72.73319244, 21.55264091], [72.73319244, 21.55208015], [72.73374939, 21.55208588], [72.73374939, 21.55180359], [72.73401642, 21.55181122], [72.73401642, 21.55153084], [72.73430634, 21.55153084], [72.73430634, 21.55124092], [72.73458099, 21.55125046], [72.73458099, 21.55097389], [72.73483276, 21.55097389], [72.73596954, 21.55097389], [72.73596954, 21.55069351], [72.73652649, 21.55069351], [72.73652649, 21.55097389], [72.73680878, 21.55097389], [72.73680878, 21.55069351], [72.73764038, 21.55069351], [72.73764038, 21.55041695], [72.73874664, 21.55042076], [72.73874664, 21.55014038], [72.73986053, 21.55014038], [72.73986053, 21.54986], [72.74013519, 21.54986382], [72.74013519, 21.54652786], [72.73986053, 21.54652977], [72.73986053, 21.54624939], [72.73958588, 21.54624939], [72.73958588, 21.54568863], [72.73986053, 21.54569435], [72.73986053, 21.54486084], [72.73958588, 21.54486084], [72.73958588, 21.54375076], [72.73929596, 21.54375076], [72.73929596, 21.54347038], [72.73902893, 21.54347229], [72.73902893, 21.54263878], [72.73874664, 21.54264069], [72.73874664, 21.54236031], [72.73847198, 21.54236031], [72.73847198, 21.54207993], [72.73819733, 21.54208374], [72.73819733, 21.54180527], [72.73792267, 21.54180908], [72.73792267, 21.54125023], [72.73764038, 21.54125023], [72.73764038, 21.54096985], [72.73735809, 21.54097176], [72.73735809, 21.54069519], [72.73707581, 21.54070091], [72.73707581, 21.54042053], [72.73568726, 21.54042053], [72.73568726, 21.54014015], [72.73513794, 21.54014015], [72.73513794, 21.53985977], [72.73430634, 21.53986168], [72.73430634, 21.53958321], [72.7326355, 21.53958321], [72.7326355, 21.53902817], [72.73208618, 21.53903008], [72.73208618, 21.53874969], [72.73041534, 21.53874969], [72.73041534, 21.53847313], [72.72875214, 21.53847313], [72.72875214, 21.53819656], [72.72680664, 21.53819656], [72.72680664, 21.53791428], [72.72598267, 21.53792], [72.72598267, 21.53763962], [72.72486115, 21.53763962], [72.72486115, 21.53736115], [72.72458649, 21.53736115], [72.72458649, 21.53763962], [72.72319794, 21.53763962], [72.72319794, 21.53736115], [72.72157288, 21.53736115], [72.72125244, 21.53736115], [72.72125244, 21.53708076], [72.71930695, 21.53708267], [72.71930695, 21.5368042], [72.71875, 21.53680992], [72.71875, 21.53652954], [72.71819305, 21.53652954], [72.71819305, 21.53623962], [72.7168045, 21.53624916], [72.7168045, 21.5359745], [72.7159729, 21.5359745], [72.7159729, 21.53569221], [72.71458435, 21.53569221], [72.71458435, 21.53541756], [72.71290588, 21.53541946], [72.71290588, 21.5351429], [72.71208191, 21.5351429], [72.71208191, 21.53486061], [72.71125031, 21.53486061], [72.71125031, 21.53458023], [72.71097565, 21.53458214], [72.71097565, 21.5340271], [72.71013641, 21.53403282], [72.71013641, 21.53375053], [72.7095871, 21.53375053], [72.7095871, 21.53347015], [72.70930481, 21.53347015], [72.70930481, 21.53319359], [72.70874786, 21.53319359], [72.70874786, 21.53347015], [72.70847321, 21.53347015], [72.70847321, 21.53319359], [72.70791626, 21.53320122], [72.70791626, 21.53292274], [72.70707703, 21.53292274], [72.70707703, 21.53264046], [72.70652771, 21.53264046], [72.70652771, 21.53236008], [72.70597076, 21.53236008], [72.70597076, 21.53208351], [72.7048645, 21.53208351], [72.7048645, 21.53236008], [72.70402527, 21.53236008], [72.70402527, 21.53208351], [72.70347595, 21.53208351], [72.70347595, 21.53236008], [72.70236206, 21.53236008], [72.70236206, 21.53264046], [72.70181274, 21.53264046], [72.70181274, 21.53292274], [72.70096588, 21.53292274], [72.70096588, 21.53320122], [72.69875336, 21.53319359], [72.69875336, 21.53347015], [72.69847107, 21.53347015], [72.69847107, 21.53375053], [72.69790649, 21.53375053], [72.69790649, 21.53403282], [72.69708252, 21.53403282], [72.69708252, 21.53430939], [72.69596863, 21.53430557], [72.69596863, 21.53458214], [72.69486237, 21.53458214], [72.69486237, 21.53430557], [72.69430542, 21.53430557], [72.69430542, 21.53458214], [72.69319153, 21.53458023], [72.69319153, 21.53486061], [72.69264221, 21.53486061], [72.69264221, 21.53458023], [72.69235992, 21.53458214], [72.69236755, 21.53486061], [72.69124603, 21.53486061], [72.69124603, 21.53541946], [72.69069672, 21.53541756], [72.69069672, 21.53569221], [72.69013977, 21.53569221], [72.69013977, 21.5359745], [72.68958282, 21.5359745], [72.68958282, 21.53624916], [72.68902588, 21.53623962], [72.68902588, 21.53652954], [72.68846893, 21.53652763], [72.68846893, 21.53708267], [72.68818665, 21.53708076], [72.68818665, 21.53736115], [72.68763733, 21.53736115], [72.68763733, 21.53763962], [72.68736267, 21.53763962], [72.68736267, 21.53819656], [72.68708038, 21.53819656], [72.68708038, 21.53847313], [72.68680573, 21.53847313], [72.68681335, 21.53874969], [72.68653107, 21.53874969], [72.68653107, 21.53930664], [72.68624878, 21.53930664], [72.68624878, 21.53958321], [72.68569183, 21.53957939], [72.68569183, 21.54014015], [72.68541718, 21.54014015], [72.68541718, 21.54070091], [72.68514252, 21.54069519], [72.68514252, 21.54097176], [72.68458557, 21.54097176], [72.6845932, 21.54125023], [72.68430328, 21.54125023], [72.68430328, 21.54153061], [72.68402863, 21.54153061], [72.68402863, 21.54291916], [72.68319702, 21.54291916], [72.68319702, 21.54264069], [72.6829071, 21.54264069], [72.6829071, 21.54236031], [72.68264008, 21.54236031], [72.68264008, 21.54207993], [72.68235779, 21.54208374], [72.68235779, 21.54125023], [72.68208313, 21.54125023], [72.68208313, 21.54070091], [72.68180847, 21.54070091], [72.68180847, 21.54042053], [72.68152618, 21.54042053], [72.68152618, 21.54014015], [72.68096924, 21.54014015], [72.68096924, 21.53985977], [72.67847443, 21.53986168], [72.67847443, 21.53958321], [72.67791748, 21.53958321], [72.67791748, 21.53930664], [72.67736053, 21.53930664], [72.67736053, 21.53874969], [72.67624664, 21.53874969], [72.67624664, 21.53847122], [72.67597198, 21.53847313], [72.67597198, 21.53819656], [72.67569733, 21.53819656], [72.67569733, 21.53791428], [72.67542267, 21.53792], [72.67542267, 21.53763962], [72.67375183, 21.53763962], [72.67375183, 21.53736115], [72.67292023, 21.53736115], [72.67292023, 21.53708076], [72.67180634, 21.53708267], [72.67180634, 21.5368042], [72.67124176, 21.53680992], [72.67124176, 21.53652954], [72.67069244, 21.53652954], [72.67069244, 21.53597069], [72.67041779, 21.5359745], [72.67041779, 21.53569221], [72.66930389, 21.53569221], [72.66930389, 21.53513908], [72.66902924, 21.5351429], [72.66902924, 21.53486061], [72.66819763, 21.53486061], [72.66819763, 21.53458023], [72.66791534, 21.53458214], [72.66791534, 21.53430557], [72.6673584, 21.53430939], [72.6673584, 21.53375053], [72.66680908, 21.53375053], [72.66680908, 21.53347015], [72.66652679, 21.53347015], [72.66652679, 21.53319359], [72.66570282, 21.53320122], [72.66570282, 21.53264046], [72.6654129, 21.53264046], [72.6654129, 21.53236008], [72.66513824, 21.53236008], [72.66513824, 21.53208351], [72.66486359, 21.53208351], [72.66486359, 21.53180504], [72.6645813, 21.53181267], [72.6645813, 21.53153038], [72.66430664, 21.53153038], [72.66430664, 21.53070068], [72.66401672, 21.53070068], [72.66401672, 21.5304184], [72.66374969, 21.5304184], [72.66374969, 21.52985954], [72.66347504, 21.52986145], [72.66347504, 21.52958298], [72.66319275, 21.52958298], [72.66319275, 21.52902985], [72.6626358, 21.52902985], [72.6626358, 21.52874947], [72.66236115, 21.52874947], [72.66236115, 21.52847099], [72.66208649, 21.5284729], [72.66208649, 21.52819443], [72.6618042, 21.52819443], [72.6618042, 21.52791786], [72.66124725, 21.52791977], [72.66124725, 21.52763939], [72.6609726, 21.52763939], [72.6609726, 21.52736092], [72.66041565, 21.52736092], [72.66041565, 21.52708244], [72.65930176, 21.52708244], [72.65930176, 21.52680779], [72.6590271, 21.52680969], [72.6590271, 21.52653122], [72.65875244, 21.52653122], [72.65875244, 21.52625084], [72.65847015, 21.52625084], [72.65847015, 21.52597046], [72.6581955, 21.52597237], [72.6581955, 21.5256958], [72.65791321, 21.5256958], [72.65791321, 21.52541733], [72.65763855, 21.52542114], [72.65763855, 21.52514076], [72.65735626, 21.52514076], [72.65735626, 21.52486038], [72.6570816, 21.52486038], [72.6570816, 21.52458], [72.65680695, 21.52458572], [72.65680695, 21.52430344], [72.65652466, 21.52430344], [72.65652466, 21.52458572], [72.65486145, 21.52458572], [72.65486145, 21.52430344], [72.65458679, 21.52430344], [72.65458679, 21.52402687], [72.65429688, 21.52403069], [72.65429688, 21.52375031], [72.65402985, 21.52375031], [72.65402985, 21.52346992], [72.65374756, 21.52347183], [72.65374756, 21.52319336], [72.6534729, 21.52320099], [72.6534729, 21.52292061], [72.65319824, 21.52292061], [72.65319824, 21.51986122], [72.65207672, 21.51986122], [72.65207672, 21.51958275], [72.6515274, 21.51958275], [72.6515274, 21.51930618], [72.65125275, 21.5193119], [72.65125275, 21.51874924], [72.65097046, 21.51874924], [72.65097046, 21.51820183], [72.6506958, 21.51820183], [72.6506958, 21.51736069], [72.65040588, 21.51736069], [72.65040588, 21.51681137], [72.64985657, 21.51681137], [72.64985657, 21.51652908], [72.64958191, 21.51652908], [72.64958191, 21.51625061], [72.64930725, 21.51625061], [72.64930725, 21.51597023], [72.64902496, 21.51597214], [72.64902496, 21.51569366], [72.64875031, 21.51569366], [72.64875031, 21.5154171], [72.64848328, 21.51542091], [72.64848328, 21.515131], [72.64819336, 21.51513863], [72.64819336, 21.51486206], [72.6479187, 21.51486206], [72.6479187, 21.51458359], [72.64763641, 21.51458359], [72.64763641, 21.51430511], [72.64736176, 21.51431084], [72.64736176, 21.51403046], [72.6470871, 21.51403046], [72.6470871, 21.5134697], [72.64680481, 21.5134716], [72.64680481, 21.51291466], [72.64653015, 21.51292038], [72.64653015, 21.51264], [72.64624786, 21.51264], [72.64624786, 21.51235962], [72.64597321, 21.51236153], [72.64597321, 21.51180649], [72.64569092, 21.5118103], [72.64569092, 21.51152992], [72.64541626, 21.51152992], [72.64541626, 21.51097107], [72.6451416, 21.51097488], [72.6451416, 21.51041412], [72.64485931, 21.51041985], [72.64485931, 21.51013947], [72.64457703, 21.51013947], [72.64457703, 21.50932121], [72.64430237, 21.50932121], [72.64430237, 21.50902939], [72.64402771, 21.50902939], [72.64402771, 21.50847054], [72.64375305, 21.50847244], [72.64375305, 21.50819206], [72.64347076, 21.50819206], [72.64347076, 21.5079174], [72.64319611, 21.50792122], [72.64319611, 21.50764275], [72.64290619, 21.50764275], [72.64290619, 21.50708008], [72.64263916, 21.50708389], [72.64263916, 21.50680542], [72.64235687, 21.50681114], [72.64235687, 21.50625992], [72.64208221, 21.50625992], [72.64208221, 21.50570107], [72.64180756, 21.50570107], [72.64180756, 21.50486183], [72.64152527, 21.50486183], [72.64152527, 21.50430489], [72.64125061, 21.50430489], [72.64125061, 21.50347137], [72.64097595, 21.50347137], [72.64097595, 21.50291634], [72.64068604, 21.50291824], [72.64068604, 21.50208092], [72.64041901, 21.50208282], [72.64041901, 21.50152779], [72.64013672, 21.50152969], [72.64013672, 21.50069046], [72.63986206, 21.50069427], [72.63986206, 21.50013924], [72.63957977, 21.50013924], [72.63957977, 21.4995842], [72.63930511, 21.4995842], [72.63930511, 21.49875069], [72.63903046, 21.49875069], [72.63903046, 21.49818993], [72.63791656, 21.49819565], [72.63791656, 21.49791718], [72.63764191, 21.49792099], [72.63764191, 21.49736023], [72.63735962, 21.49736023], [72.63735962, 21.49653053], [72.63707733, 21.49653053], [72.63707733, 21.49596977], [72.63680267, 21.49597168], [72.63680267, 21.49569321], [72.63652802, 21.49570084], [72.63652802, 21.49542046], [72.63597107, 21.49542046], [72.63597107, 21.49514008], [72.63540649, 21.49514008], [72.63540649, 21.4948597], [72.63513947, 21.4948616], [72.63513947, 21.49458122], [72.63458252, 21.49458122], [72.63458252, 21.49430466], [72.63402557, 21.49430466], [72.63402557, 21.49402809], [72.63291931, 21.49403191], [72.63291931, 21.49374962], [72.63208008, 21.49374962], [72.63208008, 21.49347115], [72.63124847, 21.49347115], [72.63124847, 21.49319458], [72.63014221, 21.49319458], [72.63014221, 21.49291611], [72.62930298, 21.49292183], [72.62930298, 21.49263954], [72.62819672, 21.49263954], [72.62819672, 21.49235916], [72.62568665, 21.49235916], [72.62568665, 21.49263954], [72.62541962, 21.49263954], [72.62541962, 21.49319458], [72.62513733, 21.49319267], [72.62513733, 21.49374962], [72.62486267, 21.49374962], [72.62486267, 21.49430466], [72.62458038, 21.49430466], [72.62458038, 21.4948616], [72.62431335, 21.4948597], [72.62431335, 21.49542046], [72.62403107, 21.49541664], [72.62403107, 21.49597168], [72.62374878, 21.49596977], [72.62374878, 21.49625015], [72.62403107, 21.49625015], [72.62403107, 21.49653053], [72.62431335, 21.49653053], [72.62431335, 21.49681091], [72.62458038, 21.49681091], [72.62458038, 21.49708939], [72.62486267, 21.49708939], [72.62486267, 21.49736023], [72.62513733, 21.49736023], [72.62513733, 21.49764061], [72.62541962, 21.49764061], [72.62541962, 21.49792099], [72.62569427, 21.49791718], [72.62569427, 21.4995842], [72.62596893, 21.49958038], [72.62596893, 21.50041962], [72.62625122, 21.50041962], [72.62625122, 21.50152969], [72.62652588, 21.50152779], [72.62652588, 21.50208282], [72.62680817, 21.50208282], [72.62680817, 21.50458336], [72.62652588, 21.50457764], [72.62652588, 21.50542259], [72.62625122, 21.50541687], [72.62625122, 21.50597191], [72.62596893, 21.50597191], [72.62596893, 21.50625992], [72.62180328, 21.50625992], [72.62180328, 21.50653267], [72.62124634, 21.50652695], [72.62124634, 21.50819206], [72.62097168, 21.50819206], [72.62097168, 21.50847244], [72.62069702, 21.50847054], [72.62069702, 21.50875282], [72.6204071, 21.50875282], [72.62041473, 21.50986099], [72.62014008, 21.50986099], [72.62014771, 21.51013947], [72.61985779, 21.51013947], [72.61985779, 21.51041985], [72.61958313, 21.51041412], [72.61958313, 21.51097488], [72.61930847, 21.51097107], [72.61930847, 21.51124954], [72.61902618, 21.51124954], [72.61902618, 21.51180077], [72.61930847, 21.51180649], [72.61930847, 21.51236153], [72.61958313, 21.51235962], [72.61958313, 21.51292038], [72.62014771, 21.51292038], [72.62014771, 21.51320076], [72.62069702, 21.51319695], [72.62069702, 21.5134716], [72.6204071, 21.5134697], [72.6204071, 21.51403046], [72.62014008, 21.51402855], [72.62014008, 21.51458359], [72.61985779, 21.51458359], [72.61985779, 21.51513863], [72.61958313, 21.515131], [72.61958313, 21.51542091], [72.61846924, 21.51542091], [72.61846924, 21.51625061], [72.61818695, 21.51625061], [72.61818695, 21.51652908], [72.61791992, 21.51652908], [72.61791992, 21.51681137], [72.61763763, 21.51680565], [72.61763763, 21.51708412], [72.61736298, 21.5170784], [72.61736298, 21.51736069], [72.61708832, 21.51736069], [72.61708832, 21.51763916], [72.61680603, 21.51763916], [72.61680603, 21.51791954], [72.61653137, 21.51791954], [72.61653137, 21.51820183], [72.61624908, 21.51820183], [72.61624908, 21.51902962], [72.6159668, 21.51902962], [72.6159668, 21.5193119], [72.61569214, 21.51930618], [72.61569214, 21.51958275], [72.61458588, 21.51958275], [72.61458588, 21.51930618], [72.61429596, 21.5193119], [72.61429596, 21.52042007], [72.61402893, 21.52041626], [72.61402893, 21.52180481], [72.61374664, 21.52180481], [72.61374664, 21.52208138], [72.61347198, 21.52207947], [72.61347198, 21.52264023], [72.61319733, 21.52264023], [72.61319733, 21.52292061], [72.61291504, 21.52291679], [72.61291504, 21.52347183], [72.61264038, 21.52346992], [72.61264038, 21.52375031], [72.61235809, 21.52375031], [72.61235809, 21.52403069], [72.61208344, 21.52402687], [72.61208344, 21.52430344], [72.61235809, 21.52429962], [72.61235809, 21.52542114], [72.61264038, 21.52541733], [72.61264038, 21.5256958], [72.61291504, 21.5256958], [72.61291504, 21.52597237], [72.61347198, 21.52597046], [72.61347198, 21.52625084], [72.61374664, 21.52625084], [72.61374664, 21.52597046], [72.61458588, 21.52597237], [72.61458588, 21.5256958], [72.61597443, 21.5256958], [72.61597443, 21.52541733], [72.61708069, 21.52541733], [72.61708069, 21.5256958], [72.61763763, 21.5256958], [72.61763763, 21.52597237], [72.61791992, 21.52597237], [72.61791992, 21.52708244], [72.61818695, 21.527071], [72.61818695, 21.52736092], [72.61846924, 21.52736092], [72.61846924, 21.52791977], [72.61875153, 21.52791977], [72.61875153, 21.53013992], [72.62069702, 21.53013992], [72.62069702, 21.5304184], [72.61985779, 21.5304184], [72.61985779, 21.53070068], [72.61902618, 21.53069496], [72.61902618, 21.53097153], [72.61653137, 21.53096962], [72.61653137, 21.53124809], [72.61347198, 21.53124809], [72.61347198, 21.53096962], [72.61319733, 21.53097153], [72.61319733, 21.53013992], [72.61207581, 21.53013992], [72.61207581, 21.52985954], [72.61125183, 21.52986145], [72.61125183, 21.52958298], [72.61013794, 21.52958298], [72.61013794, 21.52902985], [72.60986328, 21.52902985], [72.60986328, 21.52874947], [72.60930634, 21.52874947], [72.60930634, 21.52902985], [72.60901642, 21.52902985], [72.60901642, 21.52930832], [72.60847473, 21.52930641], [72.60847473, 21.52958298], [72.60819244, 21.52958298], [72.60819244, 21.52986145], [72.60791779, 21.52985954], [72.60791779, 21.53181267], [72.60819244, 21.53180504], [72.60819244, 21.53236008], [72.6084671, 21.53236008], [72.6084671, 21.53320122], [72.60874939, 21.53320122], [72.60874939, 21.53375053], [72.60901642, 21.53375053], [72.60901642, 21.53430939], [72.60930634, 21.53430939], [72.60930634, 21.5351429], [72.60958099, 21.53513908], [72.60958099, 21.53569221], [72.60986328, 21.53569031], [72.60986328, 21.53680992], [72.61013794, 21.5368042], [72.61013794, 21.53819656], [72.61042023, 21.53819656], [72.61042023, 21.53986168], [72.61068726, 21.53985977], [72.61068726, 21.54125023], [72.61042023, 21.54125023], [72.61042023, 21.54208374], [72.60958099, 21.54207993], [72.60958099, 21.54236031], [72.60901642, 21.54236031], [72.60901642, 21.54264069], [72.60764313, 21.54264069], [72.60764313, 21.54153061], [72.60736084, 21.54153061], [72.60736084, 21.53957939], [72.60708618, 21.53958321], [72.60708618, 21.53791428], [72.60679626, 21.53792], [72.60679626, 21.53680992], [72.60514069, 21.5368042], [72.60514069, 21.53708267], [72.6048584, 21.53708076], [72.6048584, 21.53736115], [72.60457611, 21.53736115], [72.60457611, 21.53763962], [72.60430908, 21.53763962], [72.60430908, 21.53792], [72.60402679, 21.53791428], [72.60402679, 21.53819656], [72.60375214, 21.53819656], [72.60375214, 21.53847313], [72.60346985, 21.53847122], [72.60346985, 21.53874969], [72.60320282, 21.53874969], [72.60320282, 21.53903008], [72.6029129, 21.53903008], [72.6029129, 21.54014015], [72.60319519, 21.54013634], [72.60319519, 21.54125023], [72.60346985, 21.54125023], [72.60346985, 21.54874992], [72.60319519, 21.54874992], [72.60319519, 21.54986382], [72.6029129, 21.54986382], [72.6029129, 21.54958534], [72.60263824, 21.54958534], [72.60263824, 21.54930305], [72.60235596, 21.54931068], [72.60235596, 21.54846954], [72.6020813, 21.54847145], [72.6020813, 21.54736137], [72.60180664, 21.54736137], [72.60180664, 21.54597282], [72.60152435, 21.54597282], [72.60152435, 21.54486084], [72.60124969, 21.54486084], [72.60124969, 21.5431881], [72.60097504, 21.54319382], [72.60097504, 21.54236031], [72.60041809, 21.54236031], [72.60041809, 21.54264069], [72.6001358, 21.54264069], [72.6001358, 21.54291916], [72.59958649, 21.54291725], [72.59958649, 21.54319382], [72.5993042, 21.54319382], [72.5993042, 21.54347229], [72.59874725, 21.54347038], [72.59874725, 21.54375076], [72.5984726, 21.54375076], [72.5984726, 21.54431152], [72.59819794, 21.5443058], [72.59819794, 21.54597282], [72.5984726, 21.54597092], [72.5984726, 21.54763985], [72.59874725, 21.54763794], [72.59874725, 21.54847145], [72.59902191, 21.54846954], [72.59902191, 21.5490303], [72.5993042, 21.5490284], [72.5993042, 21.54958534], [72.59958649, 21.54957962], [72.59958649, 21.55014038], [72.59986115, 21.55013847], [72.59986115, 21.55069351], [72.6001358, 21.55069351], [72.6001358, 21.55125046], [72.60041809, 21.55124092], [72.60041809, 21.55181122], [72.60069275, 21.55181122], [72.60069275, 21.55236053], [72.60098267, 21.55236053], [72.60098267, 21.55291939], [72.60124969, 21.55291748], [72.60124969, 21.55430794], [72.60041809, 21.55430794], [72.60041809, 21.55402756], [72.6001358, 21.55402946], [72.6001358, 21.55347061], [72.59986115, 21.55347252], [72.59986115, 21.55263901], [72.59958649, 21.55264091], [72.59958649, 21.55208015], [72.5993042, 21.55208588], [72.5993042, 21.55152512], [72.59874725, 21.55153084], [72.59874725, 21.55124092], [72.59764099, 21.55124092], [72.59764099, 21.55181122], [72.5973587, 21.55181122], [72.5973587, 21.55236053], [72.59764099, 21.55236053], [72.59764099, 21.55319595], [72.59792328, 21.55319023], [72.59792328, 21.55375099], [72.59819794, 21.55375099], [72.59819794, 21.55402946], [72.5984726, 21.55402756], [72.5984726, 21.55430794], [72.59874725, 21.55430794], [72.59874725, 21.5545826], [72.59902191, 21.55458069], [72.59902191, 21.55486107], [72.59929657, 21.55486107], [72.59929657, 21.55541992], [72.59958649, 21.55541611], [72.59958649, 21.55569458], [72.59986115, 21.55569458], [72.59986115, 21.55597305], [72.6001358, 21.55597115], [72.6001358, 21.55624962], [72.60041809, 21.55624962], [72.60041809, 21.55652809], [72.60069275, 21.55652809], [72.60069275, 21.55736923], [72.60097504, 21.5573616], [72.60097504, 21.55847168], [72.60124969, 21.55847168], [72.60124969, 21.55875015], [72.60151672, 21.55875015], [72.60151672, 21.55903244], [72.60208893, 21.55903244], [72.60208893, 21.55931282], [72.60236359, 21.55930519], [72.60236359, 21.55958366], [72.60319519, 21.55958366], [72.60319519, 21.55902863], [72.60346985, 21.55903244], [72.60346985, 21.55875015], [72.60375214, 21.55875015], [72.60375214, 21.55820274], [72.60402679, 21.55820274], [72.60402679, 21.55792236], [72.60430908, 21.55792236], [72.60430908, 21.55763817], [72.60457611, 21.55763817], [72.60457611, 21.55708122], [72.6048584, 21.55708313], [72.6048584, 21.55680466], [72.60514069, 21.55680466], [72.60514069, 21.55624962], [72.60541534, 21.55624962], [72.60541534, 21.55597305], [72.60569763, 21.55597305], [72.60569763, 21.55541611], [72.60597229, 21.55541992], [72.60597229, 21.55513954], [72.60624695, 21.55513954], [72.60624695, 21.55486107], [72.60652924, 21.55486107], [72.60652924, 21.55430031], [72.60680389, 21.55430794], [72.60680389, 21.55402756], [72.60708618, 21.55402946], [72.60708618, 21.55347061], [72.60736084, 21.55347252], [72.60736084, 21.55319595], [72.6076355, 21.55319595], [72.6076355, 21.55291748], [72.60791779, 21.55291939], [72.60791779, 21.55264091], [72.6084671, 21.55264091], [72.6084671, 21.55236053], [72.60874939, 21.55236053], [72.60874939, 21.55208015], [72.60930634, 21.55208015], [72.60930634, 21.55291939], [72.60901642, 21.55291939], [72.60901642, 21.55820274], [72.60930634, 21.55820274], [72.60930634, 21.55875015], [72.60958099, 21.55875015], [72.60958099, 21.55958366], [72.60986328, 21.55958176], [72.60986328, 21.56014061], [72.61013794, 21.5601387], [72.61013794, 21.56097221], [72.61042023, 21.56097031], [72.61042023, 21.56153107], [72.61069489, 21.56152725], [72.61069489, 21.56208229], [72.61042023, 21.56208038], [72.61042023, 21.56264114], [72.61013794, 21.56264114], [72.61013794, 21.56291962], [72.60986328, 21.5629158], [72.60986328, 21.56347466], [72.60958099, 21.56347084], [72.60958099, 21.56402969], [72.60930634, 21.56402969], [72.60930634, 21.56431007], [72.60902405, 21.56430435], [72.60902405, 21.5648613], [72.60874939, 21.56485939], [72.60874939, 21.56513977], [72.60847473, 21.56513977], [72.60847473, 21.56569672], [72.60819244, 21.56569672], [72.60819244, 21.56597137], [72.60791779, 21.56596947], [72.60791779, 21.56653023], [72.6076355, 21.56652832], [72.6076355, 21.56708336], [72.60736084, 21.56708336], [72.60736084, 21.56736183], [72.60708618, 21.56735992], [72.60708618, 21.56792068], [72.60679626, 21.56792068], [72.60679626, 21.56819916], [72.60624695, 21.56819534], [72.60624695, 21.56847191], [72.60597229, 21.56846809], [72.60597229, 21.56875038], [72.60569763, 21.56875038], [72.60569763, 21.56903076], [72.60514832, 21.56903076], [72.60514832, 21.56930923], [72.6048584, 21.56930542], [72.6048584, 21.56958389], [72.60457611, 21.56957817], [72.60457611, 21.56986046], [72.60430908, 21.56986046], [72.60430908, 21.57181168], [72.60458374, 21.57180595], [72.60458374, 21.5731945], [72.6048584, 21.5731945], [72.6048584, 21.57458115], [72.60514069, 21.57458115], [72.60514069, 21.5759716], [72.60541534, 21.5759716], [72.60541534, 21.57736015], [72.60569763, 21.57736015], [72.60569763, 21.57875061], [72.60597229, 21.57875061], [72.60597229, 21.57958412], [72.60680389, 21.57958412], [72.60680389, 21.57930756], [72.60708618, 21.57930946], [72.60708618, 21.57903099], [72.60791779, 21.57903099], [72.60791779, 21.58180809], [72.6076355, 21.58180618], [72.6076355, 21.58263969], [72.60791779, 21.58263969], [72.60791779, 21.58319473], [72.60819244, 21.58319092], [72.60819244, 21.58374977], [72.6084671, 21.58374977], [72.6084671, 21.58402824], [72.60874939, 21.58402824], [72.60874939, 21.58458328], [72.60902405, 21.58458328], [72.60902405, 21.58486176], [72.60930634, 21.58486176], [72.60930634, 21.58542252], [72.60958099, 21.58541679], [72.60958099, 21.58597183], [72.60986328, 21.58597183], [72.60986328, 21.58625031], [72.61013794, 21.58625031], [72.61013794, 21.58653259], [72.61042023, 21.58653259], [72.61042023, 21.58681107], [72.61069489, 21.58680534], [72.61069489, 21.58708382], [72.61096954, 21.58708382], [72.61096954, 21.58736038], [72.61125183, 21.58735085], [72.61125183, 21.58764267], [72.61152649, 21.58764267], [72.61152649, 21.58792114], [72.61180878, 21.58791733], [72.61180878, 21.58819389], [72.61207581, 21.58819008], [72.61207581, 21.58875084], [72.61235809, 21.58875084], [72.61235809, 21.58930969], [72.61264038, 21.58930588], [72.61264038, 21.58958244], [72.61291504, 21.58958244], [72.61291504, 21.58986092], [72.61347198, 21.58986092], [72.61347198, 21.59013939], [72.61374664, 21.59013939], [72.61374664, 21.59041405], [72.61402893, 21.59041405], [72.61402893, 21.59097481], [72.61429596, 21.59097099], [72.61429596, 21.59152985], [72.61458588, 21.59152985], [72.61458588, 21.59181023], [72.61486053, 21.5918045], [72.61486053, 21.59208488], [72.61514282, 21.59208107], [72.61514282, 21.59263992], [72.6159668, 21.59263992], [72.6159668, 21.5929203], [72.61680603, 21.5929203], [72.61680603, 21.59348106], [72.61708069, 21.59347153], [72.61708069, 21.59458351], [72.61736298, 21.5945797], [72.61736298, 21.59514046], [72.61763763, 21.59514046], [72.61763763, 21.59542084], [72.61819458, 21.59541893], [72.61819458, 21.59569359], [72.61875153, 21.59569359], [72.61875153, 21.59597206], [72.61958313, 21.59596825], [72.61958313, 21.59625053], [72.62069702, 21.59625053], [72.62069702, 21.59680939], [72.62097168, 21.59680939], [72.62097168, 21.59736061], [72.62124634, 21.59736061], [72.62124634, 21.59931183], [72.62152863, 21.59931183], [72.62152863, 21.60042191], [72.62180328, 21.60041618], [72.62180328, 21.6020813], [72.6220932, 21.60207939], [72.6220932, 21.60320091], [72.62236023, 21.60320091], [72.62236023, 21.60375023], [72.62264252, 21.60375023], [72.62264252, 21.60403061], [72.62291718, 21.60403061], [72.62291718, 21.60431099], [72.62319183, 21.60430336], [72.62319183, 21.60458565], [72.62346649, 21.60457993], [72.62346649, 21.60486031], [72.62374878, 21.60486031], [72.62374878, 21.60542107], [72.62403107, 21.60541534], [72.62403107, 21.60569572], [72.62431335, 21.60569], [72.62431335, 21.60653114], [72.62486267, 21.60652542], [72.62486267, 21.60708237], [72.62513733, 21.60708046], [72.62513733, 21.60764122], [72.62541962, 21.60764122], [72.62541962, 21.60848045], [72.62596893, 21.60848045], [72.62596893, 21.60874939], [72.62625122, 21.60874939], [72.62625122, 21.6095829], [72.62652588, 21.60957909], [72.62652588, 21.61041832], [72.62680817, 21.61041832], [72.62680817, 21.61124992], [72.62708282, 21.61124992], [72.62708282, 21.61181259], [72.62735748, 21.61180496], [72.62735748, 21.61236191], [72.62708282, 21.61236191], [72.62708282, 21.61347008], [72.62735748, 21.61347008], [72.62735748, 21.61431122], [72.62763977, 21.6143055], [72.62763977, 21.61458206], [72.6279068, 21.61458015], [72.6279068, 21.61541939], [72.62819672, 21.61541939], [72.62819672, 21.61680984], [72.62875366, 21.61680412], [72.62875366, 21.6170826], [72.62930298, 21.61708069], [72.62930298, 21.61765099], [72.63014221, 21.61765099], [72.63014221, 21.61791992], [72.63097382, 21.6179142], [72.63097382, 21.61819649], [72.63208008, 21.61819649], [72.63208008, 21.61847305], [72.63263702, 21.61847115], [72.63263702, 21.61874962], [72.63346863, 21.61874962], [72.63346863, 21.61903], [72.63402557, 21.61902618], [72.63402557, 21.61930656], [72.63458252, 21.61930656], [72.63458252, 21.6198616], [72.63485718, 21.6198597], [72.63485718, 21.62014008], [72.63513184, 21.62014008], [72.63513184, 21.62042046], [72.63846588, 21.62042046], [72.63846588, 21.62014008], [72.63931274, 21.62014008], [72.63931274, 21.6198597], [72.63957977, 21.6198616], [72.63957977, 21.61958313], [72.64069366, 21.61958313], [72.64069366, 21.61930656], [72.64125061, 21.61930656], [72.64125061, 21.61902618], [72.6415329, 21.61903], [72.6415329, 21.61874962], [72.64208221, 21.61874962], [72.64208221, 21.61847115], [72.6423645, 21.61847305], [72.6423645, 21.61819649], [72.64319611, 21.61819649], [72.64319611, 21.6179142], [72.64347076, 21.61791992], [72.64347076, 21.61765099], [72.64402771, 21.61765099], [72.64402771, 21.61736107], [72.64541626, 21.61736107], [72.64541626, 21.61708069], [72.6479187, 21.61708069], [72.6479187, 21.61736107], [72.64848328, 21.61736107], [72.64848328, 21.61765099], [72.64875031, 21.61765099], [72.64875031, 21.61791992], [72.64902496, 21.6179142], [72.64902496, 21.61819649], [72.64930725, 21.61819649], [72.64930725, 21.61847305], [72.64958191, 21.61847115], [72.64958191, 21.61903], [72.64985657, 21.61903], [72.64985657, 21.62014008], [72.65013123, 21.62014008], [72.65013123, 21.62042046], [72.65041351, 21.62041855], [72.65041351, 21.62097168], [72.6506958, 21.62096977], [72.6506958, 21.62125015], [72.65097046, 21.62125015], [72.65097046, 21.62181091], [72.65125275, 21.62180519], [72.65125275, 21.62208366], [72.65180206, 21.62208366], [72.65180206, 21.62319374], [72.65208435, 21.62319374], [72.65208435, 21.62347221], [72.65235901, 21.62346077], [72.65235901, 21.62375069], [72.6526413, 21.62375069], [72.6526413, 21.62346077], [72.65291595, 21.62347221], [72.65291595, 21.62319374], [72.65319824, 21.62319374], [72.65319824, 21.62347221], [72.65374756, 21.62346077], [72.65374756, 21.62375069], [72.6554184, 21.62375069], [72.6554184, 21.62402916], [72.65569305, 21.62402916], [72.65569305, 21.62431145], [72.65597534, 21.62430573], [72.65597534, 21.6245842], [72.65680695, 21.62457848], [72.65680695, 21.62486076], [72.65763855, 21.62486076], [72.65763855, 21.62513924], [72.65791321, 21.62513924], [72.65791321, 21.62541962], [72.6581955, 21.6254158], [72.6581955, 21.62597275], [72.65735626, 21.62597084], [72.65735626, 21.62625122], [72.6570816, 21.62625122], [72.6570816, 21.62681007], [72.65736389, 21.62680626], [72.65736389, 21.62708282], [72.65763855, 21.62708282], [72.65763855, 21.6273613], [72.65791321, 21.62735939], [72.65791321, 21.62763977], [72.65957642, 21.62763977], [72.65957642, 21.62792015], [72.66041565, 21.62791634], [72.66041565, 21.62819481], [72.66319275, 21.62819481], [72.66319275, 21.62791634], [72.66485596, 21.62792015], [72.66485596, 21.62763977], [72.6654129, 21.62763977], [72.6654129, 21.62735939], [72.66570282, 21.62735939], [72.66570282, 21.62792015], [72.66596985, 21.62791634], [72.66596985, 21.62819481], [72.66708374, 21.62819481], [72.66708374, 21.62791634], [72.67263794, 21.62791634], [72.67263794, 21.62819481], [72.67319489, 21.62819481], [72.67319489, 21.62847137], [72.67346954, 21.62846947], [72.67346954, 21.62874985], [72.67430115, 21.62874985], [72.67430115, 21.62903023], [72.67514038, 21.62902832], [72.67514038, 21.62986374], [72.67569733, 21.62985992], [72.67569733, 21.6301403], [72.67652893, 21.6301403], [72.67652893, 21.63042068], [72.67679596, 21.63042068], [72.67679596, 21.63070107], [72.67708588, 21.63069344], [72.67708588, 21.63097191], [72.67764282, 21.63097], [72.67764282, 21.63153076], [72.67791748, 21.63152695], [72.67791748, 21.6320858], [72.6784668, 21.63208008], [72.6784668, 21.63265038], [72.67903137, 21.63265038], [72.67903137, 21.63292122], [72.68041992, 21.6329174], [72.68041992, 21.63319588], [72.68069458, 21.63319588], [72.68069458, 21.63347244], [72.68125153, 21.63347054], [72.68125153, 21.63402939], [72.68152618, 21.63402939], [72.68152618, 21.63430977], [72.68235779, 21.63430786], [72.68235779, 21.63458252], [72.68264008, 21.63458061], [72.68264008, 21.63486099], [72.68319702, 21.63486099], [72.68319702, 21.63513947], [72.68402863, 21.63513947], [72.68402863, 21.63541985], [72.68458557, 21.63541794], [72.68458557, 21.6356945], [72.68486023, 21.6356945], [72.68486023, 21.63597298], [72.68541718, 21.63597107], [72.68541718, 21.63624954], [72.68569183, 21.63624954], [72.68569183, 21.63652992], [72.68597412, 21.63652992], [72.68596649, 21.63680077], [72.68653107, 21.63680649], [72.68653107, 21.63708305], [72.68708038, 21.63708305], [72.68708038, 21.63736153], [72.68736267, 21.63735962], [72.68736267, 21.63763809], [72.68791962, 21.63763809], [72.68791962, 21.63791847], [72.68819427, 21.63791656], [72.68819427, 21.6384716], [72.68846893, 21.63845825], [72.68846893, 21.63875008], [72.68875122, 21.63875008], [72.68875122, 21.63903046], [72.68930817, 21.63903046], [72.68930817, 21.63931274], [72.68958282, 21.63931274], [72.68958282, 21.63986015], [72.6904068, 21.63986015], [72.6904068, 21.64014053], [72.69124603, 21.64014053], [72.69124603, 21.64042282], [72.69180298, 21.6404171], [72.69180298, 21.64069366], [72.69236755, 21.64069176], [72.69236755, 21.6415329], [72.69264221, 21.6415329], [72.69264221, 21.64180946], [72.69291687, 21.64180565], [72.69291687, 21.64208221], [72.69319153, 21.64208031], [72.69319153, 21.64264107], [72.69347382, 21.64263916], [72.69347382, 21.64319229], [72.69319153, 21.64319229], [72.69319153, 21.64347458], [72.69346619, 21.64347076], [72.69346619, 21.64402962], [72.69374847, 21.64402962], [72.69374847, 21.64431], [72.69403076, 21.64431], [72.69403076, 21.64486122], [72.69430542, 21.64486122], [72.69430542, 21.64513969], [72.69458008, 21.64513969], [72.69458008, 21.64569664], [72.69486237, 21.64569092], [72.69486237, 21.64624977], [72.69513702, 21.64624977], [72.69513702, 21.64653015], [72.69541931, 21.64652824], [72.69541931, 21.64680672], [72.69569397, 21.64680672], [72.69569397, 21.64736176], [72.69596863, 21.64735985], [72.69596863, 21.64764977], [72.69625092, 21.64764977], [72.69625092, 21.64819908], [72.69652557, 21.64819527], [72.69652557, 21.64847183], [72.69680786, 21.64846992], [72.69680786, 21.64875031], [72.6965332, 21.64875031], [72.6965332, 21.64903069], [72.69708252, 21.64903069], [72.69708252, 21.64930916], [72.69736481, 21.64930534], [72.69736481, 21.64958382], [72.69763947, 21.64957809], [72.69763947, 21.64986038], [72.69819641, 21.64986038], [72.69819641, 21.65014076], [72.69847107, 21.65014076], [72.69847107, 21.65041924], [72.69875336, 21.65041733], [72.69875336, 21.65069389], [72.69902802, 21.65069389], [72.69902802, 21.65097237], [72.69957733, 21.65097046], [72.69957733, 21.65125084], [72.70041656, 21.65125084], [72.70041656, 21.65152931], [72.70096588, 21.65152931], [72.70096588, 21.6518116], [72.70236206, 21.65180588], [72.70236206, 21.65208244], [72.7048645, 21.65208244], [72.7048645, 21.65180588], [72.70540619, 21.6518116], [72.70540619, 21.65152931], [72.70569611, 21.65152931], [72.70569611, 21.65125084], [72.70597076, 21.65125084], [72.70597076, 21.65097046], [72.70625305, 21.65097237], [72.70625305, 21.65041733], [72.70680237, 21.65041733], [72.70680237, 21.65069389], [72.70708466, 21.65069389], [72.70708466, 21.65041733], [72.70735168, 21.65041924], [72.70735168, 21.65014076], [72.7076416, 21.65014076], [72.7076416, 21.64957809], [72.70847321, 21.64958382], [72.70847321, 21.64902878], [72.70903015, 21.64903069], [72.70903015, 21.64875031], [72.70929718, 21.64875031], [72.70929718, 21.64846992], [72.70986176, 21.64847183], [72.70986176, 21.64819527], [72.71041107, 21.64819908], [72.71041107, 21.64764977], [72.71069336, 21.64764977], [72.71069336, 21.64707947], [72.71097565, 21.64708328], [72.71097565, 21.64652824], [72.71125031, 21.64653015], [72.71125031, 21.64624977], [72.71151733, 21.64624977], [72.71151733, 21.64596939], [72.71180725, 21.6459713], [72.71180725, 21.64513969], [72.71235657, 21.64513969], [72.71235657, 21.64459038], [72.71263885, 21.64459038], [72.71263885, 21.64431], [72.71290588, 21.64431], [72.71290588, 21.64375114], [72.71375275, 21.64375114], [72.71375275, 21.64319038], [72.7140274, 21.64319229], [72.7140274, 21.64263916], [72.71430206, 21.64264107], [72.71430206, 21.64236069], [72.71485901, 21.64236069], [72.71485901, 21.64180946], [72.7151413, 21.64180946], [72.7151413, 21.6415329], [72.71541595, 21.6415329], [72.71541595, 21.64097023], [72.71624756, 21.64097023], [72.71624756, 21.64069366], [72.7168045, 21.64069366], [72.7168045, 21.6404171], [72.71736145, 21.64042282], [72.71736145, 21.64014053], [72.71763611, 21.64014053], [72.71763611, 21.63986015], [72.71819305, 21.63986015], [72.71819305, 21.63958168], [72.71930695, 21.63958359], [72.71930695, 21.63930511], [72.72041321, 21.63931274], [72.72041321, 21.63903046], [72.72319794, 21.63903046], [72.72319794, 21.63875008], [72.72624969, 21.63875008], [72.72624969, 21.63903046], [72.72820282, 21.63903046], [72.72820282, 21.63931274], [72.72875214, 21.63930511], [72.72875214, 21.63958359], [72.72930908, 21.63958168], [72.72930908, 21.63986015], [72.73124695, 21.63986015], [72.73124695, 21.64014053], [72.73264313, 21.64014053], [72.73264313, 21.63986015], [72.73291779, 21.63986015], [72.73291779, 21.63958168], [72.73347473, 21.63958359], [72.73347473, 21.63930511], [72.73486328, 21.63930511], [72.73486328, 21.63958359], [72.73568726, 21.63958168], [72.73568726, 21.64014053], [72.73596954, 21.64013863], [72.73596954, 21.64069366], [72.73930359, 21.64069366], [72.73930359, 21.64097023], [72.73986053, 21.64097023], [72.73986053, 21.64125061], [72.74014282, 21.64125061], [72.74014282, 21.64180946], [72.74041748, 21.64180565], [72.74041748, 21.64208221], [72.74236298, 21.64208031], [72.74236298, 21.64236069], [72.74291992, 21.64236069], [72.74291992, 21.64208031], [72.74402618, 21.64208221], [72.74402618, 21.64180565], [72.74458313, 21.64180565], [72.74458313, 21.64208221], [72.7454071, 21.64208031], [72.7454071, 21.64236069], [72.74736023, 21.64236069], [72.74736023, 21.64264107], [72.74791718, 21.64264107], [72.74791718, 21.64291954], [72.74819183, 21.64291573], [72.74819183, 21.64319229], [72.74847412, 21.64319229], [72.74847412, 21.64347458], [72.74874878, 21.64347076], [72.74874878, 21.64402962], [72.74903107, 21.64402962], [72.74903107, 21.64459038], [72.74930573, 21.64458275], [72.74930573, 21.6459713], [72.74958038, 21.64596939], [72.74958038, 21.64653015], [72.74986267, 21.64652824], [72.74986267, 21.64708328], [72.74958038, 21.64707947], [72.74958038, 21.64764977], [72.74986267, 21.64764977], [72.74986267, 21.64792061], [72.75013733, 21.64792061], [72.75013733, 21.64819908], [72.75041962, 21.64819527], [72.75041962, 21.64847183], [72.75068665, 21.64846992], [72.75068665, 21.64875031], [72.75096893, 21.64875031], [72.75096893, 21.64903069], [72.75125122, 21.64903069], [72.75125122, 21.64930916], [72.75096893, 21.64930534], [72.75096893, 21.64958382], [72.75152588, 21.64957809], [72.75152588, 21.64986038], [72.75208282, 21.64986038], [72.75208282, 21.65014076], [72.75235748, 21.65014076], [72.75235748, 21.64986038], [72.75374603, 21.64986038], [72.75374603, 21.65014076], [72.75681305, 21.65014076], [72.75681305, 21.64986038], [72.75736237, 21.64986038], [72.75736237, 21.64957809], [72.75819397, 21.64958382], [72.75819397, 21.64930534], [72.7590332, 21.64930916], [72.7590332, 21.64903069], [72.75958252, 21.64903069], [72.75958252, 21.64875031], [72.76040649, 21.64875031], [72.76040649, 21.64792061], [72.76346588, 21.64792061], [72.76346588, 21.64764977], [72.76403046, 21.64764977], [72.76403046, 21.64735985], [72.76625061, 21.64736176], [72.76625061, 21.64708328], [72.76791382, 21.64708328], [72.76791382, 21.64680672], [72.76958466, 21.64680672], [72.76958466, 21.64652824], [72.7701416, 21.64653015], [72.7701416, 21.64624977], [72.77097321, 21.64624977], [72.77097321, 21.64596939], [72.77375031, 21.6459713], [72.77375031, 21.64569664], [72.77625275, 21.64569664], [72.77625275, 21.64541435], [72.7804184, 21.64542007], [72.7804184, 21.64513969], [72.78430176, 21.64513969], [72.78430176, 21.64486122], [72.78457642, 21.64486122], [72.78457642, 21.64513969], [72.78736115, 21.64513969], [72.78736115, 21.64542007], [72.78874969, 21.64541435], [72.78874969, 21.64569664], [72.78986359, 21.64569664], [72.78986359, 21.6459713], [72.79096985, 21.64596939], [72.79096985, 21.64624977], [72.79264069, 21.64624977], [72.79264069, 21.64653015], [72.79319763, 21.64652824], [72.79319763, 21.64680672], [72.79402924, 21.64680672], [72.79402924, 21.64708328], [72.7951355, 21.64708328], [72.7951355, 21.64736176], [72.7959671, 21.64735985], [72.7959671, 21.64764977], [72.79680634, 21.64764977], [72.79680634, 21.64792061], [72.79708099, 21.64792061], [72.79708099, 21.64764977], [72.79763031, 21.64764977], [72.79763031, 21.64792061], [72.79846954, 21.64792061], [72.79846954, 21.64819908], [72.79875183, 21.64819527], [72.79875183, 21.64847183], [72.80042267, 21.64846992], [72.80042267, 21.64903069], [72.80152893, 21.64903069], [72.80152893, 21.64930916], [72.80208588, 21.64930534], [72.80208588, 21.64958382], [72.80319214, 21.64957809], [72.80319214, 21.64986038], [72.80403137, 21.64986038], [72.80403137, 21.65014076], [72.80486298, 21.65014076], [72.80486298, 21.65041924], [72.80541992, 21.65041733], [72.80541992, 21.65069389], [72.80625153, 21.65069389], [72.80625153, 21.65097237], [72.80680084, 21.65097046], [72.80680084, 21.65125084], [72.80735779, 21.65125084], [72.80735779, 21.65152931], [72.8079071, 21.65152931], [72.8079071, 21.6518116], [72.80902863, 21.65180588], [72.80902863, 21.65208244], [72.80958557, 21.65208244], [72.80958557, 21.65236092], [72.80986023, 21.65236092], [72.80986023, 21.65263939], [72.81041718, 21.65263939], [72.81041718, 21.65292168], [72.81097412, 21.65291595], [72.81097412, 21.65319443], [72.81128693, 21.65319443], [72.81153107, 21.65319443], [72.81153107, 21.6534729], [72.81208038, 21.6534729], [72.81208038, 21.65374947], [72.81236267, 21.65374947], [72.81236267, 21.65402985], [72.81291962, 21.65402985], [72.81291962, 21.65431023], [72.81375122, 21.65430641], [72.81375122, 21.65458107], [72.81430817, 21.65458107], [72.81430817, 21.65486145], [72.81458282, 21.65485954], [72.81458282, 21.65513992], [72.81485748, 21.65513992], [72.81485748, 21.6554203], [72.81513977, 21.6554203], [72.81513977, 21.65570068], [72.81569672, 21.65569305], [72.81569672, 21.65597153], [72.81597137, 21.65596962], [72.81597137, 21.65625], [72.81624603, 21.65625], [72.81624603, 21.65653038], [72.81652832, 21.65653038], [72.81652832, 21.6568203], [72.81735992, 21.65680313], [72.81735992, 21.65708542], [72.81791687, 21.65708542], [72.81791687, 21.65736389], [72.81819153, 21.65736008], [72.81819153, 21.65764046], [72.81846619, 21.65764046], [72.81846619, 21.65792084], [72.81903076, 21.65791512], [72.81903076, 21.65819359], [72.81945801, 21.65819359], [72.81954956, 21.65814018], [72.81958008, 21.65847206], [72.81986237, 21.65847015], [72.81986237, 21.65875053], [72.82068634, 21.65875053], [72.82068634, 21.65903091], [72.82096863, 21.65903091], [72.82096863, 21.65930939], [72.82125092, 21.65930939], [72.82125092, 21.65958977], [72.82180023, 21.65958977], [72.82180023, 21.65986061], [72.82235718, 21.65986061], [72.82235718, 21.66041946], [72.82291412, 21.66041756], [72.82291412, 21.66069412], [72.82319641, 21.66069412], [72.82319641, 21.6609726], [72.82347107, 21.66097069], [72.82347107, 21.66125107], [72.82402802, 21.66125107], [72.82402802, 21.66152954], [72.82485962, 21.66152763], [72.82485962, 21.66208267], [72.82541656, 21.66208076], [72.82541656, 21.66236115], [72.82624817, 21.66236115], [72.82624817, 21.66263962], [72.82653046, 21.66263008], [72.82653046, 21.66291809], [72.82707977, 21.66291618], [72.82707977, 21.66319466], [72.82736206, 21.66319466], [72.82736206, 21.66347313], [72.82763672, 21.66347122], [72.82763672, 21.66374969], [72.82818604, 21.66374969], [72.82818604, 21.66402817], [72.82847595, 21.66402817], [72.82847595, 21.66430473], [72.82902527, 21.66430473], [72.82902527, 21.66458321], [72.82930756, 21.66458321], [72.82930756, 21.66486168], [72.82958221, 21.66485977], [72.82958221, 21.66514015], [72.83040619, 21.66514015], [72.83040619, 21.66542244], [72.83069611, 21.66541672], [72.83069611, 21.66569519], [72.83125305, 21.66569519], [72.83125305, 21.66597176], [72.83180237, 21.66597176], [72.83180237, 21.66625023], [72.83235931, 21.66625023], [72.83235931, 21.66653252], [72.83319092, 21.66653252], [72.83319092, 21.6668129], [72.83347321, 21.66680527], [72.83347321, 21.66708374], [72.83403015, 21.66708183], [72.83403015, 21.66736031], [72.83513641, 21.66736031], [72.83513641, 21.66792107], [72.83486176, 21.66792107], [72.83486176, 21.6687603], [72.8345871, 21.6687603], [72.8345871, 21.66930962], [72.83429718, 21.66930962], [72.83429718, 21.67014122], [72.83403015, 21.67013931], [72.83403015, 21.67069244], [72.83374023, 21.67069054], [72.83374023, 21.67152977], [72.83347321, 21.67152786], [72.83347321, 21.67236137], [72.83319092, 21.67236137], [72.83319092, 21.67251968], [72.83319092, 21.67292023], [72.83291626, 21.67291451], [72.83291626, 21.67319679], [72.83235931, 21.67319679], [72.83235931, 21.67291451], [72.83180237, 21.67292023], [72.83180237, 21.67263985], [72.83125305, 21.67263985], [72.83125305, 21.67235947], [72.83069611, 21.67236137], [72.83069611, 21.6720829], [72.83013916, 21.6720829], [72.83013916, 21.67180443], [72.82930756, 21.67181969], [72.82930756, 21.67152977], [72.82818604, 21.67152977], [72.82818604, 21.67124939], [72.82736206, 21.67124939], [72.82736206, 21.67097092], [72.82653046, 21.67097473], [72.82653046, 21.67069244], [72.82569122, 21.67069244], [72.82569122, 21.67041588], [72.82430267, 21.67041969], [72.82430267, 21.67014122], [72.82319641, 21.67014122], [72.82319641, 21.66958046], [72.82263947, 21.66958237], [72.82263947, 21.6693058], [72.8215332, 21.66930962], [72.8215332, 21.66903114], [72.82125092, 21.66903114], [72.82125092, 21.6687603], [72.82041931, 21.6687603], [72.82041931, 21.66847038], [72.81958008, 21.66847229], [72.81958008, 21.66819382], [72.81874847, 21.66819382], [72.81874847, 21.66791725], [72.81764221, 21.66792107], [72.81764221, 21.66764069], [72.8170929, 21.66764069], [72.8170929, 21.66736031], [72.81569672, 21.66736031], [72.81569672, 21.66708183], [72.81513977, 21.66708374], [72.81513977, 21.66680527], [72.81430817, 21.6668129], [72.81430817, 21.66656113], [72.81430817, 21.66625023], [72.81318665, 21.66625023], [72.81318665, 21.66597176], [72.81236267, 21.66597176], [72.81236267, 21.66569519], [72.81180573, 21.66569519], [72.81180573, 21.66541672], [72.81069183, 21.66542244], [72.81069183, 21.66514015], [72.8095932, 21.66514015], [72.8095932, 21.66485977], [72.80874634, 21.66486168], [72.80874634, 21.66458321], [72.80764008, 21.66458321], [72.80764008, 21.66430473], [72.80708313, 21.66430473], [72.80708313, 21.66402817], [72.80596924, 21.66402817], [72.80596924, 21.66374969], [72.80486298, 21.66374969], [72.80486298, 21.66347122], [72.80403137, 21.66347313], [72.80403137, 21.66319466], [72.80319214, 21.66319466], [72.80319214, 21.66291618], [72.80208588, 21.66291809], [72.80208588, 21.66263008], [72.80124664, 21.66263962], [72.80124664, 21.66236115], [72.79985809, 21.66236115], [72.79985809, 21.66208076], [72.79930878, 21.66208267], [72.79930878, 21.66180611], [72.79818726, 21.66180992], [72.79818726, 21.66152954], [72.79680634, 21.66152954], [72.79680634, 21.66180992], [72.79486084, 21.66180992], [72.79486084, 21.66152954], [72.79402924, 21.66152954], [72.79402924, 21.66180992], [72.79374695, 21.66180611], [72.79374695, 21.66208267], [72.78708649, 21.66208076], [72.78708649, 21.66236115], [72.7859726, 21.66236115], [72.7859726, 21.66263962], [72.78375244, 21.66263008], [72.78375244, 21.66291809], [72.78236389, 21.66291618], [72.78236389, 21.66319466], [72.77986145, 21.66319466], [72.77986145, 21.66347313], [72.77902985, 21.66347122], [72.77902985, 21.66374969], [72.77819824, 21.66374969], [72.77819824, 21.66402817], [72.77735901, 21.66402817], [72.77735901, 21.66430473], [72.7765274, 21.66430473], [72.7765274, 21.66458321], [72.7756958, 21.66458321], [72.7756958, 21.66486168], [72.77401733, 21.66485977], [72.77401733, 21.66514015], [72.77348328, 21.66514015], [72.77348328, 21.66542244], [72.77263641, 21.66541672], [72.77263641, 21.66569519], [72.77180481, 21.66569519], [72.77180481, 21.66597176], [72.77124786, 21.66597176], [72.77124786, 21.66625023], [72.77076721, 21.66625023], [72.76930237, 21.66625023], [72.76930237, 21.66653252], [72.76902771, 21.66653252], [72.76902771, 21.6668129], [72.76847076, 21.66680527], [72.76847076, 21.66708374], [72.76763916, 21.66708374], [72.76764679, 21.66736031], [72.76680756, 21.66736031], [72.76680756, 21.66764069], [72.76597595, 21.66764069], [72.76597595, 21.66792107], [72.76513672, 21.66791725], [72.76513672, 21.66819382], [72.76403046, 21.66819382], [72.76403046, 21.66847229], [72.76374817, 21.66847038], [72.76374817, 21.6687603], [72.76346588, 21.6687603], [72.76346588, 21.66903114], [72.76264191, 21.66903114], [72.76264191, 21.66930962], [72.76251984, 21.66930962], [72.76180267, 21.6693058], [72.76180267, 21.66958237], [72.76152039, 21.66958046], [72.76152039, 21.66986084], [72.76125336, 21.66986084], [72.76125336, 21.67014122], [72.76069641, 21.67014122], [72.76069641, 21.67041969], [72.76041412, 21.67041588], [72.76041412, 21.67069244], [72.76013947, 21.67069244], [72.76013947, 21.67097473], [72.75985718, 21.67097092], [72.75985718, 21.67124939], [72.75930786, 21.67124939], [72.75930786, 21.67152977], [72.75875092, 21.67152977], [72.75875092, 21.67181969], [72.75791931, 21.67180443], [72.75791931, 21.6720829], [72.75763702, 21.6720829], [72.75763702, 21.67236137], [72.75681305, 21.67235947], [72.75681305, 21.67292023], [72.75653076, 21.67291451], [72.75653076, 21.67319679], [72.75597382, 21.67319679], [72.75597382, 21.67347145], [72.75569153, 21.67346954], [72.75569153, 21.67374992], [72.75514221, 21.67374992], [72.75514221, 21.6740303], [72.7545929, 21.6740303], [72.7545929, 21.67431068], [72.75402832, 21.67430687], [72.75402832, 21.67458344], [72.75375366, 21.67458344], [72.75375366, 21.67486191], [72.75347137, 21.67485809], [72.75347137, 21.67514038], [72.75319672, 21.67514038], [72.75319672, 21.67542076], [72.75291443, 21.67541885], [72.7529068, 21.6756897], [72.75235748, 21.67569923], [72.75235748, 21.67653084], [72.75180817, 21.67653084], [72.75180817, 21.67680931], [72.75152588, 21.6768055], [72.75152588, 21.67708397], [72.75125122, 21.67708397], [72.75125122, 21.67764091], [72.75096893, 21.67762947], [72.75096893, 21.67791939], [72.75069427, 21.67791748], [72.75069427, 21.67847252], [72.75041962, 21.67847061], [72.75041962, 21.67874908], [72.74986267, 21.67874908], [72.74986267, 21.67986107], [72.74958038, 21.67986107], [72.74958038, 21.6807003], [72.74930573, 21.68069458], [72.74931335, 21.68124962], [72.74903107, 21.68124962], [72.74903107, 21.68180466], [72.74874878, 21.68180466], [72.74874878, 21.6823616], [72.74846649, 21.6823597], [72.74846649, 21.68320084], [72.74819183, 21.68320084], [72.74819183, 21.68375969], [72.74791718, 21.68375969], [72.74791718, 21.68403053], [72.74764252, 21.68403053], [72.74764252, 21.68431091], [72.74736023, 21.68430328], [72.74736023, 21.68458557], [72.74764252, 21.68457985], [72.74764252, 21.68486023], [72.74736023, 21.68486023], [72.74736023, 21.68514061], [72.74680328, 21.68514061], [72.74680328, 21.68542099], [72.74652863, 21.68541527], [72.74652863, 21.68597221], [72.74597168, 21.68597031], [72.74597168, 21.68625069], [72.74569702, 21.68625069], [72.74569702, 21.68653107], [72.74541473, 21.68652534], [72.74541473, 21.68680763], [72.74514008, 21.68680763], [72.74514008, 21.6870842], [72.74458313, 21.68708038], [72.74458313, 21.68736076], [72.74430847, 21.68736076], [72.74430847, 21.68764114], [72.74375153, 21.68764114], [72.74375153, 21.68791962], [72.74346924, 21.68791771], [72.74346924, 21.68819427], [72.74319458, 21.68819427], [72.74319458, 21.68847275], [72.74236298, 21.68847084], [72.74236298, 21.68875122], [72.74208069, 21.68875122], [72.74208069, 21.68902969], [72.7409668, 21.68902969], [72.7409668, 21.68930817], [72.73986053, 21.68930626], [72.73986053, 21.68958282], [72.73625183, 21.68958282], [72.73625183, 21.68930626], [72.73542023, 21.68930817], [72.73542023, 21.68902969], [72.73486328, 21.68902969], [72.73486328, 21.68875122], [72.73401642, 21.68875122], [72.73401642, 21.68847084], [72.73374939, 21.68847275], [72.73374939, 21.68819427], [72.73291779, 21.68819427], [72.73291779, 21.68791771], [72.73264313, 21.68791962], [72.73264313, 21.68764114], [72.73208618, 21.68764114], [72.73208618, 21.68736076], [72.73152924, 21.68736076], [72.73152924, 21.6870842], [72.73097229, 21.6870842], [72.73097229, 21.68680763], [72.73069763, 21.68680763], [72.73069763, 21.68652534], [72.7298584, 21.68653107], [72.7298584, 21.68625069], [72.72930908, 21.68625069], [72.72930908, 21.68597031], [72.72875214, 21.68597221], [72.72875214, 21.68569374], [72.72819519, 21.68569374], [72.72819519, 21.68541527], [72.72763824, 21.68542099], [72.72763824, 21.68514061], [72.72680664, 21.68514061], [72.72680664, 21.68486023], [72.72486115, 21.68486023], [72.72486115, 21.68457985], [72.72374725, 21.68458557], [72.72374725, 21.68430328], [72.72292328, 21.68431091], [72.72292328, 21.68403053], [72.72235107, 21.68403053], [72.72235107, 21.68375969], [72.72180176, 21.68375969], [72.72180176, 21.68349075], [72.72097015, 21.68346977], [72.72097015, 21.68319321], [72.72070313, 21.68320084], [72.72070313, 21.68292046], [72.72013855, 21.68292046], [72.72013855, 21.68264008], [72.71930695, 21.68264008], [72.71930695, 21.6823597], [72.71902466, 21.6823616], [72.71902466, 21.68180466], [72.71847534, 21.68180466], [72.71847534, 21.68152809], [72.71819305, 21.68153191], [72.71819305, 21.68124962], [72.71763611, 21.68124962], [72.71763611, 21.68097115], [72.7168045, 21.68097115], [72.7168045, 21.68069458], [72.7159729, 21.6807003], [72.7159729, 21.68042183], [72.71541595, 21.68042183], [72.71541595, 21.68013954], [72.71485901, 21.68013954], [72.71485901, 21.67986107], [72.71457672, 21.67986107], [72.71457672, 21.67958069], [72.71347046, 21.6795826], [72.71347046, 21.67930603], [72.71235657, 21.67931175], [72.71235657, 21.67902946], [72.71180725, 21.67902946], [72.71180725, 21.67874908], [72.71125031, 21.67874908], [72.71125031, 21.67847061], [72.70819092, 21.67847061], [72.70819092, 21.67874908], [72.70707703, 21.67874908], [72.70707703, 21.67902946], [72.70513916, 21.67902756], [72.70513916, 21.6795826], [72.70485687, 21.67958069], [72.70485687, 21.67986107], [72.70458221, 21.67986107], [72.70458221, 21.68013954], [72.70318604, 21.68013954], [72.70318604, 21.68042183], [72.70263672, 21.68042183], [72.70263672, 21.68013954], [72.70207977, 21.68013954], [72.70207977, 21.67986107], [72.70181274, 21.67986107], [72.70181274, 21.68042183], [72.70041656, 21.68042183], [72.70041656, 21.68013954], [72.69985962, 21.68013954], [72.69985962, 21.68042183], [72.69930267, 21.68041611], [72.69930267, 21.68097115], [72.69902802, 21.68097115], [72.69902802, 21.68124962], [72.69847107, 21.68124962], [72.69847107, 21.68153191], [72.69790649, 21.68153191], [72.69790649, 21.68124962], [72.69708252, 21.68124962], [72.69708252, 21.68153191], [72.69625092, 21.68153191], [72.69625092, 21.68124962], [72.69568634, 21.68124962], [72.69568634, 21.68097115], [72.69458008, 21.68097115], [72.69458008, 21.68069458], [72.69403076, 21.6807003], [72.69403076, 21.68042183], [72.6920929, 21.68042183], [72.6920929, 21.68013954], [72.69124603, 21.68013954], [72.69124603, 21.67986107], [72.68902588, 21.67986107], [72.68902588, 21.67958069], [72.68763733, 21.67958069], [72.68763733, 21.67986107], [72.68653107, 21.67986107], [72.68653107, 21.67958069], [72.68624878, 21.6795826], [72.68624878, 21.67930603], [72.68402863, 21.67930603], [72.68402863, 21.6795826], [72.68125153, 21.67958069], [72.68125153, 21.67986107], [72.68068695, 21.67986107], [72.68068695, 21.68013954], [72.67930603, 21.68013954], [72.67930603, 21.68042183], [72.67874908, 21.68042183], [72.67874908, 21.6807003], [72.67736053, 21.68069458], [72.67736053, 21.68097115], [72.67708588, 21.68097115], [72.67708588, 21.68124962], [72.67679596, 21.68124962], [72.67679596, 21.68153191], [72.67597198, 21.68152809], [72.67597198, 21.68180466], [72.67430878, 21.68180466], [72.67430878, 21.68208122], [72.67375183, 21.68208122], [72.67375183, 21.6823616], [72.67292023, 21.6823597], [72.67292023, 21.68264008], [72.67180634, 21.68264008], [72.67180634, 21.68292046], [72.66958618, 21.68292046], [72.66958618, 21.68320084], [72.66707611, 21.68320084], [72.66707611, 21.68292046], [72.66625214, 21.68292046], [72.66625214, 21.68264008], [72.66555786, 21.68264008], [72.6654129, 21.68264008], [72.6654129, 21.6823597], [72.66430664, 21.6823616], [72.66430664, 21.68208122], [72.66402435, 21.68208122], [72.66402435, 21.68180466], [72.66374969, 21.68180466], [72.66374969, 21.68152809], [72.66348267, 21.68153191], [72.66348267, 21.68124962], [72.66319275, 21.68124962], [72.66319275, 21.68097115], [72.66208649, 21.68097115], [72.66208649, 21.68069458], [72.66179657, 21.6807003], [72.66179657, 21.68042946], [72.66152954, 21.68042183], [72.66152954, 21.68013954], [72.66124725, 21.68013954], [72.66124725, 21.67986107], [72.6609726, 21.67986107], [72.6609726, 21.67958069], [72.66069794, 21.6795826], [72.66069794, 21.67930603], [72.66014099, 21.67931175], [72.66014099, 21.67902946], [72.65957642, 21.67902946], [72.65957642, 21.67847061], [72.6590271, 21.67847252], [72.6590271, 21.67819405], [72.65736389, 21.67819405], [72.65736389, 21.67791748], [72.65651703, 21.67791939], [72.65651703, 21.67762947], [72.65625, 21.67764091], [72.65625, 21.67736053], [72.65597534, 21.67736053], [72.65597534, 21.67708397], [72.6554184, 21.67707825], [72.6554184, 21.67736053], [72.65291595, 21.67736053], [72.65291595, 21.67764091], [72.65235901, 21.67764091], [72.65235901, 21.67736053], [72.65208435, 21.67736053], [72.65208435, 21.67764091], [72.65180206, 21.67762947], [72.65180206, 21.67791939], [72.65097046, 21.67791748], [72.65097046, 21.67819405], [72.65013885, 21.67819405], [72.65013885, 21.67847252], [72.64624786, 21.67847061], [72.64624786, 21.67874908], [72.64597321, 21.67874908], [72.64597321, 21.67847061], [72.64485931, 21.67847061], [72.64485931, 21.67874908], [72.64125824, 21.67874908], [72.64125824, 21.67902946], [72.63791656, 21.67902946], [72.63791656, 21.67931175], [72.63680267, 21.67931175], [72.63680267, 21.67902946], [72.63540649, 21.67902946], [72.63540649, 21.67931175], [72.6340332, 21.67931175], [72.6340332, 21.67902946], [72.63236237, 21.67902946], [72.63236237, 21.67931175], [72.63097382, 21.67930603], [72.63097382, 21.6795826], [72.62930298, 21.67958069], [72.62930298, 21.67986107], [72.62486267, 21.67986107], [72.62486267, 21.68013954], [72.62458038, 21.68013954], [72.62458038, 21.67986107], [72.62430573, 21.67986107], [72.62431335, 21.68013954], [72.62180328, 21.68013954], [72.62180328, 21.68042183], [72.61624908, 21.68042183], [72.61624908, 21.68013954], [72.6159668, 21.68013954], [72.6159668, 21.68042183], [72.61541748, 21.68042183], [72.61541748, 21.6807003], [72.61486053, 21.68069458], [72.61486053, 21.68097115], [72.61374664, 21.68097115], [72.61374664, 21.68124962], [72.61292267, 21.68124962], [72.61292267, 21.68153191], [72.61235809, 21.68152809], [72.61235809, 21.68180466], [72.61180878, 21.68180466], [72.61180878, 21.68208122], [72.60945892, 21.68208122], [72.60847473, 21.68208122], [72.60847473, 21.68180466], [72.60819244, 21.68180466], [72.60819244, 21.68152809], [72.60597229, 21.68153191], [72.60597229, 21.68124962], [72.60375214, 21.68124962], [72.60375214, 21.68097115], [72.60319519, 21.68097115], [72.60320282, 21.68124962], [72.6029129, 21.68124962], [72.6029129, 21.68097115], [72.60236359, 21.68097115], [72.60236359, 21.68069458], [72.60124969, 21.68069458], [72.60124969, 21.68097115], [72.60097504, 21.68097115], [72.60098267, 21.68124962], [72.60069275, 21.68124962], [72.60069275, 21.68153191], [72.60041809, 21.68153191], [72.60041809, 21.68124962], [72.6001358, 21.68124962], [72.6001358, 21.68097115], [72.59958649, 21.68097115], [72.59958649, 21.68069458], [72.5984726, 21.6807003], [72.5984726, 21.68042183], [72.59792328, 21.68042183], [72.59792328, 21.6807003], [72.5973587, 21.6807003], [72.5973587, 21.68042183], [72.59680176, 21.68042183], [72.59680176, 21.68013954], [72.5965271, 21.68013954], [72.5965271, 21.67986107], [72.59596252, 21.67986107], [72.59596252, 21.67958069], [72.59486389, 21.6795826], [72.59486389, 21.67930603], [72.5945816, 21.67931175], [72.5945816, 21.67902946], [72.59430695, 21.67902946], [72.59430695, 21.67874908], [72.59401703, 21.67874908], [72.59401703, 21.67847061], [72.59375, 21.67847252], [72.59375, 21.67819405], [72.59319305, 21.67819405], [72.59319305, 21.67791748], [72.5929184, 21.67791939], [72.5929184, 21.67762947], [72.59263611, 21.67764091], [72.59263611, 21.67708397], [72.59236145, 21.67708397], [72.59236145, 21.6768055], [72.59179688, 21.67680931], [72.59179688, 21.67653084], [72.59152985, 21.67653084], [72.59152985, 21.67625046], [72.59069824, 21.67625046], [72.59069061, 21.67596817], [72.59041595, 21.67597198], [72.59041595, 21.67541885], [72.59014893, 21.67542076], [72.59014893, 21.67514038], [72.5890274, 21.67514038], [72.5890274, 21.67485809], [72.58875275, 21.67486191], [72.58875275, 21.67430687], [72.58763885, 21.67430687], [72.58763885, 21.67458344], [72.58680725, 21.67458344], [72.58680725, 21.6740284], [72.58651733, 21.6740303], [72.58651733, 21.67374992], [72.58625031, 21.67374992], [72.58625031, 21.67346954], [72.5854187, 21.67347145], [72.5854187, 21.67319679], [72.58513641, 21.67319679], [72.58513641, 21.67291451], [72.58402252, 21.67292023], [72.58402252, 21.67263985], [72.58374786, 21.67263985], [72.58374786, 21.67235947], [72.58347321, 21.67236137], [72.58347321, 21.6720829], [72.5826416, 21.6720829], [72.5826416, 21.67236137], [72.58235931, 21.67235947], [72.58235931, 21.67292023], [72.58207703, 21.67292023], [72.58207703, 21.67263985], [72.58152771, 21.67263985], [72.58152771, 21.67235947], [72.58125305, 21.67236137], [72.58125305, 21.67180443], [72.58097839, 21.67181969], [72.58097839, 21.67124939], [72.58069611, 21.67124939], [72.58069611, 21.67097092], [72.58013916, 21.67097473], [72.58013916, 21.67069244], [72.57930756, 21.67069244], [72.57930756, 21.67041588], [72.57736206, 21.67041969], [72.57736206, 21.67014122], [72.57681274, 21.67014122], [72.57681274, 21.66986084], [72.57624817, 21.66986084], [72.57624817, 21.66958046], [72.57597351, 21.66958237], [72.57597351, 21.6693058], [72.57569122, 21.66930962], [72.57569122, 21.66903114], [72.57541656, 21.66903114], [72.57541656, 21.6687603], [72.57485199, 21.6687603], [72.57485199, 21.66847038], [72.57430267, 21.66847229], [72.57430267, 21.66819382], [72.57347107, 21.66819382], [72.57347107, 21.66791725], [72.57263947, 21.66792107], [72.57263947, 21.66764069], [72.57235718, 21.66764069], [72.57235718, 21.66736031], [72.57208252, 21.66736031], [72.57208252, 21.66708183], [72.57180786, 21.66708374], [72.57180786, 21.66680527], [72.57096863, 21.6668129], [72.57096863, 21.66653252], [72.57041931, 21.66653252], [72.57041931, 21.66625023], [72.56958008, 21.66625023], [72.56958008, 21.66653252], [72.56903839, 21.66653252], [72.56903839, 21.66625023], [72.56846619, 21.66625023], [72.56846619, 21.66597176], [72.56791687, 21.66597176], [72.56791687, 21.66569519], [72.56735992, 21.66569519], [72.56735992, 21.66513824], [72.5670929, 21.66514015], [72.5670929, 21.66485977], [72.56597137, 21.66486168], [72.56597137, 21.66458321], [72.56541443, 21.66458321], [72.56541443, 21.66430473], [72.56513977, 21.66430473], [72.56513977, 21.66374969], [72.56485748, 21.66374969], [72.56485748, 21.66263008], [72.56458282, 21.66263962], [72.56458282, 21.66208267], [72.56485748, 21.66208267], [72.56485748, 21.66180611], [72.56402588, 21.66180992], [72.56402588, 21.66152954], [72.56375122, 21.66152954], [72.56375122, 21.66180992], [72.56291199, 21.66180992], [72.56291199, 21.66152954], [72.56263733, 21.66152954], [72.56263733, 21.65930939], [72.56291199, 21.65930939], [72.56291199, 21.65903091], [72.56263733, 21.65903091], [72.56263733, 21.65875053], [72.56180573, 21.65875053], [72.56180573, 21.65847206], [72.56153107, 21.65847015], [72.56153107, 21.65875053], [72.56069183, 21.65875053], [72.56069183, 21.66069412], [72.55986023, 21.66069412], [72.55986023, 21.66041756], [72.5595932, 21.66041946], [72.5595932, 21.66014099], [72.55930328, 21.66014099], [72.55930328, 21.65986061], [72.55902863, 21.65986061], [72.55902863, 21.65958977], [72.55874634, 21.65958977], [72.55874634, 21.65930939], [72.55652618, 21.65930939], [72.55652618, 21.65903091], [72.55374908, 21.65903091], [72.55374908, 21.65875053], [72.55152893, 21.65875053], [72.55152893, 21.65903091], [72.55042267, 21.65903091], [72.55042267, 21.65875053], [72.54985809, 21.65875053], [72.54985809, 21.65847015], [72.54736328, 21.65847015], [72.54736328, 21.65875053], [72.54680634, 21.65875053], [72.54680634, 21.65903091], [72.54651642, 21.65903091], [72.54651642, 21.65958977], [72.5459671, 21.65958977], [72.5459671, 21.65986061], [72.54429626, 21.65986061], [72.54429626, 21.66014099], [72.54319763, 21.66014099], [72.54319763, 21.66041946], [72.54264069, 21.66041756], [72.54264069, 21.6609726], [72.54207611, 21.66097069], [72.54207611, 21.66125107], [72.54180908, 21.66125107], [72.54180908, 21.66152954], [72.54152679, 21.66152954], [72.54152679, 21.66180992], [72.54125214, 21.66180992], [72.54125214, 21.66236115], [72.54069519, 21.66236115], [72.54069519, 21.66263962], [72.53985596, 21.66263008], [72.53985596, 21.66291809], [72.53930664, 21.66291618], [72.53930664, 21.66319466], [72.53902435, 21.66319466], [72.53902435, 21.66347313], [72.53874207, 21.66347122], [72.53874207, 21.66402817], [72.53819275, 21.66402817], [72.53819275, 21.66430473], [72.5376358, 21.66430473], [72.5376358, 21.66486168], [72.53736115, 21.66485977], [72.53736115, 21.66514015], [72.53679657, 21.66514015], [72.53679657, 21.66542244], [72.53652954, 21.66541672], [72.53652954, 21.66569519], [72.53624725, 21.66569138], [72.53624725, 21.6668129], [72.5359726, 21.6668129], [72.5359726, 21.66736031], [72.53569794, 21.66736031], [72.53569794, 21.66764069], [72.53541565, 21.66763878], [72.53541565, 21.66819382], [72.53514099, 21.66819382], [72.53514099, 21.66847229], [72.5348587, 21.66847038], [72.5348587, 21.6687603], [72.53457642, 21.6687603], [72.53457642, 21.66903114], [72.53430939, 21.66902733], [72.53430176, 21.66958237], [72.5340271, 21.66958046], [72.5340271, 21.67014122], [72.53375244, 21.67014122], [72.53375244, 21.67041969], [72.53347015, 21.67041588], [72.53347015, 21.67069244], [72.53291321, 21.67069054], [72.53291321, 21.67124939], [72.53235626, 21.67124939], [72.53235626, 21.67152977], [72.5320816, 21.67152786], [72.5320816, 21.67236137], [72.53235626, 21.67235947], [72.53235626, 21.67263985], [72.53263855, 21.67263794], [72.53263855, 21.67319679], [72.53291321, 21.67319679], [72.53291321, 21.67347145], [72.53263855, 21.67346954], [72.53263855, 21.67431068], [72.53235626, 21.67431068], [72.53235626, 21.67514038], [72.5320816, 21.67514038], [72.5320816, 21.67485809], [72.53152466, 21.67486191], [72.53152466, 21.67458344], [72.53125, 21.67458344], [72.53125, 21.67430687], [72.53097534, 21.67430687], [72.53097534, 21.67486191], [72.53069305, 21.67485809], [72.5306778, 21.67514038], [72.5304184, 21.67514038], [72.5304184, 21.67457008], [72.53013611, 21.67458344], [72.53013611, 21.67486191], [72.52958679, 21.67485809], [72.52958679, 21.67514038], [72.52929687, 21.67514038], [72.52929687, 21.67542076], [72.52902985, 21.67541885], [72.52902985, 21.6756897], [72.52874756, 21.67569542], [72.52874756, 21.67597198], [72.5284729, 21.67596817], [72.5284729, 21.67625046], [72.52819824, 21.67625046], [72.52819824, 21.67680931], [72.5276413, 21.6768055], [72.5276413, 21.67708397], [72.52707672, 21.67707825], [72.52707672, 21.67736053], [72.52680206, 21.67736053], [72.52680206, 21.67764091], [72.52625275, 21.67762947], [72.52625275, 21.67791939], [72.5256958, 21.67791748], [72.5256958, 21.67819405], [72.52540588, 21.67818832], [72.52540588, 21.67902946], [72.52513885, 21.67902946], [72.52513885, 21.67931175], [72.5248642, 21.67930603], [72.5248642, 21.6795826], [72.52458191, 21.67958069], [72.52458191, 21.67986107], [72.52430725, 21.67986107], [72.52430725, 21.68013954], [72.52402496, 21.68013954], [72.52402496, 21.68180466], [72.52374268, 21.68180275], [72.52375031, 21.68486023], [72.52348328, 21.68486023], [72.52348328, 21.68514061], [72.52375031, 21.6851387], [72.52375031, 21.6870842], [72.52401733, 21.68708038], [72.52401733, 21.68736076], [72.52319336, 21.68736076], [72.52319336, 21.68764114], [72.5229187, 21.68763924], [72.5229187, 21.68819427], [72.52263641, 21.68819046], [72.52263641, 21.68875122], [72.52236176, 21.68875122], [72.52236176, 21.68902969], [72.5220871, 21.68902969], [72.5220871, 21.68958282], [72.52180481, 21.68958282], [72.52180481, 21.6898613], [72.52124786, 21.68985748], [72.52124786, 21.69013977], [72.52097321, 21.69013977], [72.52097321, 21.69041824], [72.52041626, 21.69041634], [72.52041626, 21.69069481], [72.51958466, 21.69069481], [72.51958466, 21.69041634], [72.51403046, 21.69041824], [72.51403046, 21.69013977], [72.51040649, 21.69013977], [72.51040649, 21.68985748], [72.51013947, 21.6898613], [72.51013947, 21.68958282], [72.50875092, 21.68958282], [72.50875092, 21.6898613], [72.50818634, 21.68985748], [72.50818634, 21.69041824], [72.50791931, 21.69041634], [72.50791931, 21.69180489], [72.50819397, 21.69180489], [72.50819397, 21.69236183], [72.50874329, 21.69236183], [72.50874329, 21.6926403], [72.50985718, 21.6926403], [72.50985718, 21.69236183], [72.51013947, 21.69236183], [72.51013947, 21.69208336], [72.51041412, 21.69208336], [72.51041412, 21.69180489], [72.51069641, 21.69180489], [72.51069641, 21.69152832], [72.52180481, 21.69152832], [72.52180481, 21.69180489], [72.5220871, 21.69180489], [72.5220871, 21.69236183], [72.52236176, 21.69236183], [72.52236176, 21.69320107], [72.52263641, 21.69320107], [72.52263641, 21.69403267], [72.52236176, 21.69403267], [72.52236176, 21.69431114], [72.52263641, 21.69431114], [72.52263641, 21.69486046], [72.5229187, 21.69486046], [72.5229187, 21.69569969], [72.52319336, 21.69569206], [72.52319336, 21.69597244], [72.52263641, 21.69597054], [72.52263641, 21.69625092], [72.52236176, 21.69625092], [72.52236176, 21.69652939], [72.5220871, 21.69652939], [72.5220871, 21.69680977], [72.52180481, 21.69680405], [72.52180481, 21.69708252], [72.52124786, 21.69708252], [72.52124786, 21.69680405], [72.52097321, 21.69680405], [72.52097321, 21.69819641], [72.52124786, 21.69819641], [72.52124786, 21.69847488], [72.52097321, 21.69847488], [72.52097321, 21.69874954], [72.52068329, 21.69874001], [72.52068329, 21.69902992], [72.52041626, 21.69902992], [72.52041626, 21.70014], [72.51902771, 21.70014], [72.51902771, 21.70042038], [72.51875305, 21.70042038], [72.51875305, 21.70070076], [72.50958252, 21.70070076], [72.50958252, 21.70042038], [72.50930786, 21.70042038], [72.50930786, 21.70014], [72.50958252, 21.70014], [72.50958252, 21.6993103], [72.50930786, 21.6993103], [72.50930786, 21.69902992], [72.5090332, 21.69902992], [72.5090332, 21.69874001], [72.50791931, 21.69874001], [72.50791931, 21.69902992], [72.50736237, 21.69902992], [72.50736237, 21.70125008], [72.50763702, 21.70125008], [72.50763702, 21.70153046], [72.50791931, 21.70152855], [72.50791931, 21.70180511], [72.51847076, 21.70180511], [72.51847076, 21.70208359], [72.51875305, 21.70207977], [72.51875305, 21.70292091], [72.51902771, 21.7029171], [72.51902771, 21.70319366], [72.51930237, 21.70318985], [72.51930237, 21.70375061], [72.51957703, 21.70375061], [72.51957703, 21.70402908], [72.51985931, 21.70402718], [72.51985931, 21.70458412], [72.51957703, 21.7045784], [72.51957703, 21.70513916], [72.51875305, 21.70513916], [72.51875305, 21.70541954], [72.51847076, 21.70541763], [72.51847076, 21.7056942], [72.51819611, 21.7056942], [72.51819611, 21.70597267], [72.51790619, 21.70597076], [72.51790619, 21.7068119], [72.51763916, 21.7068119], [72.51763916, 21.70763969], [72.51790619, 21.70763969], [72.51790619, 21.71042061], [72.51763916, 21.71042061], [72.51763916, 21.71264076], [72.51790619, 21.71264076], [72.51790619, 21.71292114], [72.51763916, 21.71291542], [72.51763916, 21.71347237], [72.51791382, 21.71347237], [72.51791382, 21.71458244], [72.51875305, 21.71458244], [72.51875305, 21.7140255], [72.51902771, 21.71403122], [72.51902771, 21.71347046], [72.51930237, 21.71347237], [72.51930237, 21.7131958], [72.51958466, 21.7131958], [72.51958466, 21.71125031], [72.51930237, 21.71125031], [72.51930237, 21.71096992], [72.51958466, 21.71097183], [72.51958466, 21.71069336], [72.51930237, 21.71070099], [72.51930237, 21.70957947], [72.51902771, 21.70958328], [72.51902771, 21.70874977], [72.51930237, 21.70874977], [72.51930237, 21.70792961], [72.51957703, 21.70792961], [72.51957703, 21.70763969], [72.51985931, 21.70763969], [72.51985931, 21.70736122], [72.5201416, 21.70736122], [72.5201416, 21.70708275], [72.52069092, 21.70708275], [72.52069092, 21.70652771], [72.52153015, 21.70652771], [72.52153015, 21.7084713], [72.52179718, 21.70846939], [72.52179718, 21.70903015], [72.52153015, 21.70902824], [72.52153015, 21.70930481], [72.52124786, 21.70930481], [72.52124786, 21.70958328], [72.52097321, 21.70957947], [72.52097321, 21.71014023], [72.52068329, 21.71014023], [72.52068329, 21.71070099], [72.52041626, 21.71070099], [72.52041626, 21.71125031], [72.5201416, 21.71125031], [72.5201416, 21.71153069], [72.51985931, 21.71153069], [72.51985931, 21.71181107], [72.5201416, 21.71180344], [72.5201416, 21.71208572], [72.52041626, 21.71208], [72.52041626, 21.71236038], [72.52069092, 21.71236038], [72.52069092, 21.71347237], [72.52041626, 21.71347237], [72.52041626, 21.71375084], [72.52068329, 21.7137394], [72.52068329, 21.71403122], [72.52097321, 21.7140255], [72.52097321, 21.71458244], [72.52153015, 21.71458054], [72.52153015, 21.71486092], [72.52179718, 21.71486092], [72.52179718, 21.71624947], [72.52236176, 21.71624947], [72.52236176, 21.71652985], [72.52263641, 21.71652985], [72.52263641, 21.71680832], [72.5229187, 21.71680641], [72.5229187, 21.71708298], [72.52319336, 21.71708298], [72.52319336, 21.71736145], [72.52348328, 21.71735954], [72.52348328, 21.71763992], [72.52401733, 21.71763992], [72.52401733, 21.7179184], [72.52430725, 21.7179184], [72.52430725, 21.71820259], [72.52458191, 21.71819496], [72.52458191, 21.71847153], [72.52485657, 21.71847153], [72.52485657, 21.71875191], [72.52513885, 21.71875191], [72.52513885, 21.71903038], [72.52541351, 21.71902847], [72.52541351, 21.71958351], [72.5256958, 21.7195816], [72.5256958, 21.72014046], [72.52597046, 21.72014046], [72.52597046, 21.72042274], [72.52625275, 21.72041702], [72.52625275, 21.72097015], [72.5265274, 21.72097015], [72.5265274, 21.72125053], [72.52680206, 21.72125053], [72.52680206, 21.72153282], [72.52708435, 21.7215271], [72.52708435, 21.72208214], [72.52735901, 21.72208214], [72.52735901, 21.7234726], [72.5276413, 21.72347069], [72.5276413, 21.72430992], [72.52791595, 21.72430992], [72.52791595, 21.72486115], [72.52819824, 21.72486115], [72.52819824, 21.72513962], [72.5284729, 21.72513962], [72.5284729, 21.72569656], [72.52874756, 21.7256794], [72.52874756, 21.72624969], [72.5293045, 21.72624969], [72.5293045, 21.72736168], [72.52958679, 21.72735977], [72.52958679, 21.72792053], [72.52986145, 21.72791862], [72.52986145, 21.72847176], [72.53013611, 21.72846985], [72.53013611, 21.72875023], [72.53069305, 21.72875023], [72.53069305, 21.72903061], [72.53098297, 21.72903061], [72.53098297, 21.72930908], [72.53125, 21.72930908], [72.53125, 21.73014069], [72.53151703, 21.73014069], [72.53151703, 21.73041916], [72.53180695, 21.73041725], [72.53180695, 21.73069382], [72.5320816, 21.7306881], [72.5320816, 21.73125076], [72.53235626, 21.73125076], [72.53235626, 21.73152924], [72.53263855, 21.73152924], [72.53263855, 21.73181152], [72.53291321, 21.7318058], [72.53291321, 21.73208237], [72.53347015, 21.73207855], [72.53347015, 21.73236084], [72.53375244, 21.73236084], [72.53375244, 21.73263931], [72.53430176, 21.73263931], [72.53430939, 21.73291969], [72.5348587, 21.73291588], [72.5348587, 21.73319435], [72.53514099, 21.73318863], [72.53514099, 21.73374939], [72.53542328, 21.73374939], [72.53542328, 21.73402977], [72.53569794, 21.73402786], [72.53569794, 21.7345829], [72.5359726, 21.7345829], [72.5359726, 21.73486137], [72.53736115, 21.73485184], [72.53736115, 21.73513985], [72.53901672, 21.73513985], [72.53901672, 21.73542023], [72.53930664, 21.73541641], [72.53930664, 21.73569489], [72.5404129, 21.73569107], [72.5404129, 21.73931122], [72.54069519, 21.7393074], [72.54069519, 21.73958588], [72.54096985, 21.73958015], [72.54096985, 21.73986053], [72.54125214, 21.73986053], [72.54125214, 21.74014091], [72.54152679, 21.74014091], [72.54152679, 21.74041939], [72.54180908, 21.74041748], [72.54180908, 21.74069595], [72.54207611, 21.74069023], [72.54207611, 21.74125099], [72.54264069, 21.74125099], [72.54264069, 21.74180984], [72.54291534, 21.74180794], [72.54291534, 21.74236107], [72.54319763, 21.74236107], [72.54319763, 21.74291992], [72.54347229, 21.74291992], [72.54347229, 21.74403954], [72.54319763, 21.74402809], [72.54319763, 21.7448616], [72.54264069, 21.7448597], [72.54264069, 21.74570274], [72.54291534, 21.74569511], [72.54291534, 21.74708366], [72.54319763, 21.74708176], [72.54319763, 21.74736023], [72.54347229, 21.74736023], [72.54347229, 21.7479229], [72.54374695, 21.74791718], [72.54374695, 21.74847221], [72.54402924, 21.74847031], [72.54402924, 21.74930954], [72.54374695, 21.74930573], [72.54374695, 21.74958229], [72.54347229, 21.74958038], [72.54347229, 21.75014114], [72.54319763, 21.75013924], [72.54319763, 21.75069237], [72.54291534, 21.75069237], [72.54291534, 21.75458336], [72.54319763, 21.75457954], [72.54319763, 21.7551403], [72.54347229, 21.7551403], [72.54347229, 21.75597763], [72.54402924, 21.75597763], [72.54402924, 21.75736046], [72.54430389, 21.75736046], [72.54430389, 21.75847244], [72.54402924, 21.75847054], [72.54402924, 21.75875092], [72.54347229, 21.75875092], [72.54347229, 21.75931168], [72.54319763, 21.75931168], [72.54319763, 21.76042175], [72.54292297, 21.76042175], [72.54292297, 21.76152992], [72.54347229, 21.76152802], [72.54347229, 21.76178932], [72.5451355, 21.76180649], [72.5451355, 21.76208115], [72.54541779, 21.76208115], [72.54541779, 21.76236153], [72.54569244, 21.76235962], [72.54569244, 21.76264], [72.5459671, 21.76264], [72.5459671, 21.76375008], [72.54624939, 21.76375008], [72.54624939, 21.76625061], [72.54651642, 21.76625061], [72.54651642, 21.76653099], [72.54708099, 21.76653099], [72.54708099, 21.76680946], [72.54736328, 21.76680946], [72.54736328, 21.76736069], [72.54763794, 21.76736069], [72.54763794, 21.76791954], [72.54736328, 21.76791763], [72.54736328, 21.76847267], [72.54708099, 21.76847076], [72.54708099, 21.76875114], [72.54736328, 21.76875114], [72.54736328, 21.76930809], [72.54763794, 21.76930809], [72.54763794, 21.76986122], [72.5479126, 21.76986122], [72.5479126, 21.77041817], [72.54819489, 21.77041626], [72.54819489, 21.77236176], [72.54846954, 21.77236176], [72.54846954, 21.77264023], [72.54875183, 21.77264023], [72.54875183, 21.7732029], [72.54902649, 21.77319527], [72.54902649, 21.77347183], [72.54930878, 21.77347183], [72.54930878, 21.77514076], [72.54957581, 21.77514076], [72.54957581, 21.77791977], [72.54985809, 21.77791977], [72.54985809, 21.77874947], [72.55014038, 21.77874947], [72.55014038, 21.77931023], [72.55042267, 21.77931023], [72.55042267, 21.78181076], [72.55069733, 21.78180695], [72.55069733, 21.78319359], [72.55097198, 21.78318977], [72.55097198, 21.78624916], [72.55124664, 21.78624916], [72.55124664, 21.78736115], [72.55152893, 21.78736115], [72.55152893, 21.78792191], [72.55179596, 21.78792191], [72.55179596, 21.79014015], [72.55208588, 21.79014015], [72.55208588, 21.79236031], [72.55236053, 21.79236031], [72.55236053, 21.79292107], [72.55263519, 21.79291534], [72.55263519, 21.79347229], [72.55291748, 21.79347038], [72.55291748, 21.79430962], [72.55319214, 21.79430771], [72.55319214, 21.79458237], [72.5534668, 21.79458046], [72.5534668, 21.79515076], [72.55374908, 21.79513931], [72.55374908, 21.79597282], [72.554039, 21.79597092], [72.554039, 21.79652977], [72.55430603, 21.79652977], [72.55430603, 21.7970829], [72.55458069, 21.79707909], [72.55458069, 21.79763985], [72.55486298, 21.79763985], [72.55486298, 21.79847145], [72.55513763, 21.79846764], [72.55513763, 21.7990303], [72.55541992, 21.7990284], [72.55541992, 21.79958344], [72.55568695, 21.79958153], [72.55568695, 21.80014038], [72.55596924, 21.80013847], [72.55596924, 21.80069351], [72.55625153, 21.8006916], [72.55625153, 21.80153275], [72.55652618, 21.80152702], [72.55652618, 21.80208206], [72.55680847, 21.80208015], [72.55680847, 21.80236053], [72.55708313, 21.80236053], [72.55708313, 21.80264282], [72.55735779, 21.80263901], [72.55735779, 21.80319214], [72.55764008, 21.80319214], [72.55764008, 21.80347252], [72.5579071, 21.80347061], [72.5579071, 21.80375099], [72.55819702, 21.80375099], [72.55819702, 21.80402946], [72.55847168, 21.80402946], [72.55847168, 21.80431938], [72.55874634, 21.80430412], [72.55874634, 21.8045826], [72.55902863, 21.80458069], [72.55902863, 21.80513954], [72.55930328, 21.80513954], [72.55930328, 21.80541992], [72.55958557, 21.8054142], [72.55958557, 21.80569649], [72.55986023, 21.80569649], [72.55986023, 21.80597305], [72.56014252, 21.80597115], [72.56014252, 21.80653], [72.56041718, 21.80653], [72.56041718, 21.80709076], [72.56069183, 21.80709076], [72.56069183, 21.80764008], [72.56096649, 21.80764008], [72.56096649, 21.80820084], [72.56124878, 21.80820084], [72.56124878, 21.80875015], [72.56153107, 21.80875015], [72.56153107, 21.80931091], [72.56180573, 21.80930519], [72.56180573, 21.80958366], [72.56208038, 21.80958366], [72.56208038, 21.8101387], [72.56236267, 21.81013107], [72.56236267, 21.81041908], [72.56263733, 21.81041718], [72.56263733, 21.81097221], [72.56291199, 21.8109684], [72.56291199, 21.81152916], [72.56318665, 21.81152916], [72.56318665, 21.81180954], [72.56346893, 21.81180573], [72.56346893, 21.8120842], [72.56375122, 21.81207848], [72.56375122, 21.81236076], [72.56402588, 21.81236076], [72.56402588, 21.81291962], [72.56430817, 21.8129158], [72.56430817, 21.81347275], [72.56458282, 21.81347275], [72.56458282, 21.81375122], [72.56485748, 21.81375122], [72.56485748, 21.81402969], [72.56513977, 21.81402779], [72.56513977, 21.81458282], [72.5654068, 21.81458282], [72.5654068, 21.81513977], [72.56569672, 21.81513977], [72.56569672, 21.81542015], [72.56597137, 21.81541634], [72.56597137, 21.81597137], [72.56624603, 21.81596947], [72.56624603, 21.81625938], [72.56652832, 21.81624985], [72.56652832, 21.81680489], [72.56680298, 21.81680489], [72.56680298, 21.81708336], [72.5670929, 21.81707954], [72.5670929, 21.8176403], [72.56735992, 21.8176403], [72.56735992, 21.81820107], [72.56708527, 21.81819344], [72.56708527, 21.81847191], [72.56652832, 21.81847], [72.56652832, 21.81875038], [72.56624603, 21.81875038], [72.56624603, 21.81903076], [72.565979, 21.81903076], [72.565979, 21.82014084], [72.56569672, 21.82014084], [72.56569672, 21.82152939], [72.565979, 21.82152939], [72.565979, 21.82180977], [72.56625366, 21.82180786], [72.56625366, 21.82208252], [72.56652832, 21.82207108], [72.56652832, 21.82263947], [72.5670929, 21.82263947], [72.5670929, 21.82291985], [72.56764221, 21.82291794], [72.56764221, 21.8231945], [72.56791687, 21.8231945], [72.56791687, 21.82347298], [72.56819153, 21.82347107], [72.56819153, 21.82374954], [72.56846619, 21.82374954], [72.56846619, 21.82402992], [72.56986237, 21.82402992], [72.56986237, 21.8243084], [72.56930542, 21.82430649], [72.56930542, 21.82458305], [72.56874847, 21.82458305], [72.56874847, 21.82486153], [72.56819153, 21.82485962], [72.56819153, 21.82513809], [72.56791687, 21.82513809], [72.56791687, 21.82522011], [72.56791687, 21.82542038], [72.56735992, 21.82542038], [72.56735992, 21.82570267], [72.56680298, 21.82569504], [72.56680298, 21.8259716], [72.56624603, 21.8259716], [72.56624603, 21.82625008], [72.56569672, 21.82625008], [72.56569672, 21.82653046], [72.5654068, 21.82653046], [72.5654068, 21.82681274], [72.56485748, 21.82680511], [72.56485748, 21.82708359], [72.56430817, 21.82708359], [72.56430817, 21.82736015], [72.56375122, 21.82736015], [72.56375122, 21.82764053], [72.56346893, 21.82764053], [72.56346893, 21.82792282], [72.56291199, 21.82792282], [72.56291199, 21.82819939], [72.56319427, 21.82819366], [72.56319427, 21.82847214], [72.56291199, 21.82847023], [72.56291199, 21.82875061], [72.56263733, 21.82875061], [72.56263733, 21.8290329], [72.56208038, 21.8290329], [72.56208038, 21.82930946], [72.56180573, 21.82930565], [72.56180573, 21.82958221], [72.56124878, 21.82958031], [72.56124878, 21.82986069], [72.56096649, 21.82986069], [72.56096649, 21.83014107], [72.56041718, 21.83014107], [72.56041718, 21.83041954], [72.56014252, 21.83041763], [72.56014252, 21.83069229], [72.55958557, 21.83069229], [72.55958557, 21.83097267], [72.55930328, 21.83097076], [72.55930328, 21.83126068], [72.55874634, 21.83126068], [72.55874634, 21.83152962], [72.55847168, 21.83152962], [72.55847168, 21.83181], [72.55791473, 21.83180428], [72.55791473, 21.83208275], [72.55764008, 21.83208084], [72.55764008, 21.83236122], [72.55708313, 21.83236122], [72.55708313, 21.83263969], [72.55652618, 21.83263969], [72.55652618, 21.83292007], [72.55625153, 21.83291435], [72.55625153, 21.83319664], [72.55569458, 21.83319664], [72.55569458, 21.8334713], [72.55541992, 21.83346939], [72.55541992, 21.83374977], [72.55486298, 21.83374977], [72.55486298, 21.83403015], [72.55458069, 21.83402634], [72.55458069, 21.83430672], [72.55403137, 21.83430672], [72.55403137, 21.83458328], [72.55374908, 21.83458328], [72.55374908, 21.83486176], [72.55319214, 21.83485985], [72.55319214, 21.83514023], [72.55291748, 21.83514023], [72.55291748, 21.83542061], [72.55236053, 21.83542061], [72.55236053, 21.83569908], [72.55208588, 21.83569527], [72.55208588, 21.83597183], [72.55152893, 21.83596992], [72.55152893, 21.83625031], [72.55097198, 21.83625031], [72.55097198, 21.83653069], [72.55069733, 21.83653069], [72.55069733, 21.83680916], [72.55014038, 21.83680534], [72.55014038, 21.83708382], [72.54985809, 21.83707047], [72.54985809, 21.83736038], [72.54930878, 21.83736038], [72.54930878, 21.83764076], [72.54902649, 21.83764076], [72.54902649, 21.83791924], [72.54846954, 21.83791733], [72.54846954, 21.83819389], [72.54819489, 21.83819389], [72.54819489, 21.83847237], [72.54763794, 21.83847046], [72.54763794, 21.83875084], [72.54736328, 21.83875084], [72.54736328, 21.83902931], [72.54680634, 21.83902931], [72.54680634, 21.8393116], [72.54652405, 21.83930588], [72.54652405, 21.83958244], [72.5459671, 21.83957863], [72.5459671, 21.83986092], [72.54569244, 21.83986092], [72.54569244, 21.84013939], [72.54514313, 21.84013939], [72.54514313, 21.84041977], [72.54458618, 21.84041595], [72.54458618, 21.84069443], [72.54430389, 21.84069443], [72.54430389, 21.8409729], [72.54374695, 21.8409729], [72.54374695, 21.84124947], [72.54347229, 21.84124947], [72.54347229, 21.84152985], [72.54292297, 21.84152985], [72.54292297, 21.84181023], [72.54264069, 21.84180641], [72.54264069, 21.84208107], [72.54208374, 21.84208107], [72.54208374, 21.84236145], [72.54180908, 21.84235954], [72.54180908, 21.84263992], [72.54125214, 21.84263992], [72.54125214, 21.8429203], [72.54096985, 21.8429203], [72.54096985, 21.84320068], [72.5404129, 21.84319305], [72.5404129, 21.84347153], [72.54013824, 21.84346962], [72.54013824, 21.84375], [72.5395813, 21.84375], [72.5395813, 21.84403038], [72.53930664, 21.84403038], [72.53930664, 21.84431076], [72.53874969, 21.84430313], [72.53874969, 21.84458351], [72.53819275, 21.84458351], [72.53819275, 21.84486198], [72.53791809, 21.84486008], [72.53791809, 21.84514046], [72.53736115, 21.84514046], [72.53736115, 21.84542084], [72.53708649, 21.84541512], [72.53708649, 21.84569359], [72.53652954, 21.84569359], [72.53652954, 21.84597206], [72.53624725, 21.84597206], [72.53624725, 21.84625053], [72.53569794, 21.846241], [72.53569794, 21.84653091], [72.53542328, 21.84653091], [72.53542328, 21.84680939], [72.5348587, 21.84680748], [72.5348587, 21.84708595], [72.53457642, 21.84708023], [72.53457642, 21.84736061], [72.5340271, 21.84736061], [72.5340271, 21.84764099], [72.5276413, 21.84764099], [72.5276413, 21.84791946], [72.52708435, 21.84791756], [72.52708435, 21.84819412], [72.52625275, 21.84819412], [72.52625275, 21.8484726], [72.5256958, 21.84847069], [72.5256958, 21.84875107], [72.52513885, 21.84875107], [72.52513885, 21.84902954], [72.52458191, 21.84902954], [72.52458191, 21.84930611], [72.52375031, 21.84930611], [72.52375031, 21.84958267], [72.52319336, 21.84958076], [72.52319336, 21.84986115], [72.52374268, 21.84986115], [72.52375031, 21.85013962], [72.52348328, 21.85013962], [72.52348328, 21.85041809], [72.5229187, 21.85041618], [72.5229187, 21.85069466], [72.52263641, 21.85069466], [72.52263641, 21.85097313], [72.5229187, 21.85097122], [72.5229187, 21.85152817], [72.52319336, 21.85152817], [72.52319336, 21.85208321], [72.52347565, 21.85208321], [72.52347565, 21.85236168], [72.52374268, 21.85236168], [72.52374268, 21.85264015], [72.52403259, 21.85264015], [72.52403259, 21.85292244], [72.52430725, 21.85291672], [72.52430725, 21.85347176], [72.52374268, 21.85347176], [72.52375031, 21.85375023], [72.52348328, 21.85375023], [72.52348328, 21.8543129], [72.52374268, 21.8543129], [72.52374268, 21.85486031], [72.52403259, 21.85486031], [72.52403259, 21.8554306], [72.52430725, 21.85541725], [72.52430725, 21.85597229], [72.52458191, 21.85597038], [72.52458191, 21.85653114], [72.5248642, 21.85652733], [72.5248642, 21.85708237], [72.52513885, 21.85708046], [72.52513885, 21.85764122], [72.52540588, 21.85764122], [72.52540588, 21.85791969], [72.52430725, 21.85791969], [72.52430725, 21.85764122], [72.52374268, 21.85764122], [72.52374268, 21.85736084], [72.52347565, 21.85736084], [72.52347565, 21.85708237], [72.5229187, 21.85708237], [72.5229187, 21.8568058], [72.52236176, 21.85680962], [72.52236176, 21.85653114], [72.5220871, 21.85653114], [72.5220871, 21.85680962], [72.52180481, 21.8568058], [72.52180481, 21.85708237], [72.52153015, 21.85708046], [72.52153015, 21.85764122], [72.52124786, 21.85764122], [72.52124786, 21.85791969], [72.52097321, 21.85791588], [72.52097321, 21.85819435], [72.51902771, 21.85819435], [72.51902771, 21.85763931], [72.51875305, 21.85764122], [72.51875305, 21.85708046], [72.51847076, 21.85708237], [72.51847076, 21.8568058], [72.51819611, 21.8568058], [72.51819611, 21.85708237], [72.51790619, 21.85708046], [72.51790619, 21.85736084], [72.51763916, 21.85736084], [72.51763916, 21.85791969], [72.5173645, 21.85791588], [72.5173645, 21.85847282], [72.51708221, 21.85847282], [72.51708221, 21.8595829], [72.51680756, 21.8595829], [72.51680756, 21.86124992], [72.5165329, 21.86124039], [72.5165329, 21.86264038], [72.51902771, 21.86264038], [72.51902771, 21.86292076], [72.51875305, 21.86291885], [72.51875305, 21.86847115], [72.51847076, 21.86847115], [72.51847076, 21.87403107], [72.51819611, 21.87403107], [72.51819611, 21.87486076], [72.51680756, 21.87486076], [72.51680756, 21.87458038], [72.51625061, 21.87458038], [72.51625061, 21.87486076], [72.51597595, 21.87486076], [72.51597595, 21.87680817], [72.51625061, 21.87680817], [72.51625061, 21.87791824], [72.5165329, 21.87791824], [72.5165329, 21.87903023], [72.51625061, 21.87902832], [72.51625061, 21.87958336], [72.51597595, 21.87958336], [72.51597595, 21.88097191], [72.51568604, 21.88097191], [72.51568604, 21.88237], [72.51541901, 21.88237], [72.51541901, 21.88375092], [72.51513672, 21.88375092], [72.51513672, 21.88541412], [72.51486206, 21.88541412], [72.51486206, 21.88597488], [72.51457977, 21.88597107], [72.51457977, 21.88820076], [72.51513672, 21.88819695], [72.51513672, 21.8884716], [72.51680756, 21.8884697], [72.51680756, 21.88931084], [72.51625061, 21.88930511], [72.51625061, 21.88958359], [72.51597595, 21.88958359], [72.51597595, 21.88986206], [72.51568604, 21.88985825], [72.51568604, 21.89014053], [72.51541901, 21.89014053], [72.51541901, 21.89042091], [72.51513672, 21.8904171], [72.51513672, 21.89069366], [72.51486206, 21.89069366], [72.51486206, 21.89097214], [72.51457977, 21.89096832], [72.51457977, 21.89125061], [72.51431274, 21.89125061], [72.51431274, 21.89154053], [72.51374817, 21.89154053], [72.51374817, 21.89180946], [72.51347351, 21.89180565], [72.51347351, 21.89208412], [72.51319122, 21.8920784], [72.51319122, 21.89236069], [72.51291656, 21.89236069], [72.51291656, 21.89263916], [72.51264191, 21.89263916], [72.51264191, 21.89291954], [72.51208496, 21.89291763], [72.51208496, 21.89347267], [72.51180267, 21.89347267], [72.51180267, 21.89402962], [72.51152802, 21.89402962], [72.51152802, 21.8943119], [72.51097107, 21.89430618], [72.51097107, 21.89458275], [72.51069641, 21.89458275], [72.51069641, 21.89486122], [72.51040649, 21.89486122], [72.51040649, 21.89542007], [72.51013947, 21.89541626], [72.51013947, 21.89569473], [72.50958252, 21.89569473], [72.50958252, 21.8959713], [72.50930786, 21.89596939], [72.50930786, 21.89624977], [72.50902557, 21.89624977], [72.50902557, 21.89680481], [72.50875092, 21.89680481], [72.50875092, 21.89708328], [72.50846863, 21.89708328], [72.50846863, 21.89736176], [72.50818634, 21.89735031], [72.50818634, 21.89764023], [72.50791931, 21.89764023], [72.50791931, 21.89792061], [72.50763702, 21.89791679], [72.50763702, 21.90041542], [72.50736237, 21.90041542], [72.50736237, 21.90069389], [72.50708008, 21.90069008], [72.50708008, 21.90125084], [72.50680542, 21.90125084], [72.50680542, 21.90263939], [72.50708008, 21.90263939], [72.50708008, 21.90319443], [72.50736237, 21.90319443], [72.50736237, 21.90458298], [72.50708008, 21.90458298], [72.50708008, 21.90486145], [72.50681305, 21.90485764], [72.50681305, 21.90513992], [72.50653076, 21.90513992], [72.50653076, 21.90570259], [72.50624847, 21.90570259], [72.50624847, 21.90681267], [72.50597382, 21.90680504], [72.50597382, 21.90736008], [72.50569153, 21.90736008], [72.50569153, 21.90819359], [72.50541687, 21.90819168], [72.50541687, 21.90903282], [72.50514221, 21.9090271], [72.50514221, 21.90958214], [72.50485992, 21.90958214], [72.50485992, 21.91236115], [72.50514221, 21.9123497], [72.50514221, 21.91263962], [72.50541687, 21.91263962], [72.50541687, 21.91319656], [72.50569153, 21.91319656], [72.50569153, 21.91374969], [72.50596619, 21.91374969], [72.50596619, 21.91625023], [72.50624847, 21.91625023], [72.50624847, 21.92152786], [72.50596619, 21.92152023], [72.50596619, 21.92514038], [72.50569916, 21.92514038], [72.50569916, 21.92542076], [72.50485992, 21.92541695], [72.50485992, 21.9256897], [72.50458527, 21.92569351], [72.50458527, 21.92847252], [72.50430298, 21.92847061], [72.50430298, 21.92930984], [72.50402832, 21.92930984], [72.50402832, 21.93124962], [72.50375366, 21.93124962], [72.50375366, 21.93180466], [72.50347137, 21.93180084], [72.50347137, 21.93264008], [72.50319672, 21.93263817], [72.50319672, 21.93347168], [72.50291443, 21.93347168], [72.50291443, 21.93458366], [72.50263977, 21.93458176], [72.50263977, 21.93514061], [72.50235748, 21.93514061], [72.50235748, 21.93680954], [72.50291443, 21.93680573], [72.50291443, 21.93708229], [72.50319672, 21.93708038], [72.50319672, 21.93736076], [72.5029068, 21.93736076], [72.5029068, 21.93764114], [72.50319672, 21.93764114], [72.50319672, 21.93875122], [72.5029068, 21.93875122], [72.5029068, 21.93902969], [72.50319672, 21.93902969], [72.50319672, 21.94042015], [72.50291443, 21.94041443], [72.50291443, 21.94069672], [72.50263977, 21.94069672], [72.50263977, 21.94097137], [72.50235748, 21.94096947], [72.50235748, 21.94153023], [72.50208282, 21.94152641], [72.50208282, 21.94180679], [72.50235748, 21.94180679], [72.50235748, 21.94847107], [72.50263977, 21.94846153], [72.50263977, 21.95070076], [72.50291443, 21.95069313], [72.50291443, 21.95208359], [72.50263977, 21.95208359], [72.50263977, 21.95347214], [72.50235748, 21.95347023], [72.50235748, 21.95514107], [72.50263977, 21.95513725], [72.50263977, 21.95597267], [72.5029068, 21.95597076], [72.5029068, 21.95903015], [72.50319672, 21.95903015], [72.50319672, 21.96042252], [72.50347137, 21.96041679], [72.50347137, 21.96208382], [72.50319672, 21.96208191], [72.50319672, 21.96264076], [72.50347137, 21.96264076], [72.50347137, 21.96375084], [72.50374603, 21.96375084], [72.50374603, 21.96403122], [72.50402832, 21.9640274], [72.50402832, 21.96569443], [72.50430298, 21.96569061], [72.50430298, 21.96624947], [72.50402832, 21.96624947], [72.50402832, 21.96681976], [72.50430298, 21.9668045], [72.50430298, 21.96736145], [72.5045929, 21.96735954], [72.5045929, 21.9679203], [72.50485992, 21.9679184], [72.50485992, 21.96847153], [72.5045929, 21.96846962], [72.5045929, 21.97291946], [72.50485992, 21.97291756], [72.50485992, 21.9734726], [72.50458527, 21.9734726], [72.50458527, 21.97458267], [72.50485992, 21.97458267], [72.50485992, 21.97486115], [72.5045929, 21.97486115], [72.5045929, 21.97653008], [72.50485992, 21.97652817], [72.50485992, 21.97708321], [72.50514221, 21.97708321], [72.50514221, 21.97736168], [72.50485992, 21.97735977], [72.50485992, 21.97931099], [72.50514221, 21.97931099], [72.50514221, 21.97986031], [72.50541687, 21.97986031], [72.50541687, 21.98042107], [72.50514221, 21.98041534], [72.50514221, 21.98069382], [72.50485992, 21.98069382], [72.50485992, 21.98097229], [72.50514221, 21.98097038], [72.50514221, 21.98125076], [72.50541687, 21.98125076], [72.50541687, 21.98181915], [72.50569916, 21.98181915], [72.50569916, 21.98264122], [72.50541687, 21.98264122], [72.50541687, 21.98291969], [72.50569153, 21.98291779], [72.50569153, 21.98347282], [72.50596619, 21.98347092], [72.50596619, 21.98430824], [72.50624847, 21.98430634], [72.50624847, 21.98569489], [72.50596619, 21.98568916], [72.50596619, 21.98625183], [72.50624847, 21.98625183], [72.50624847, 21.98681259], [72.50653076, 21.98681259], [72.50653076, 21.98792267], [72.50680542, 21.98791695], [72.50680542, 21.98875046], [72.50708008, 21.98875046], [72.50708008, 21.99097252], [72.50736237, 21.99097061], [72.50736237, 21.99180984], [72.50708008, 21.99180984], [72.50708008, 21.99263954], [72.50736237, 21.99263954], [72.50736237, 21.99430466], [72.50763702, 21.99430084], [72.50763702, 21.99514008], [72.50791931, 21.99514008], [72.50791931, 21.99735832], [72.50818634, 21.99735832], [72.50818634, 21.99764061], [72.50846863, 21.99764061], [72.50846863, 21.99819374], [72.50875092, 21.99819374], [72.50875092, 21.9995842], [72.50902557, 21.9995842], [72.5090332, 21.99986076], [72.5090332, 22.00041962], [72.50930786, 22.00041962], [72.50930786, 22.00152969], [72.50958252, 22.00152969], [72.50958252, 22.00263977], [72.50986481, 22.00263977], [72.50986481, 22.00347137], [72.51013947, 22.00347137], [72.51013947, 22.00458336], [72.51040649, 22.00457954], [72.51040649, 22.00542068], [72.51069641, 22.00542068], [72.51069641, 22.00653076], [72.51097107, 22.00653076], [72.51097107, 22.00764084], [72.51125336, 22.00763893], [72.51125336, 22.00847244], [72.51152802, 22.00847244], [72.51152802, 22.00958252], [72.51180267, 22.00958061], [72.51180267, 22.01041985], [72.51209259, 22.01041985], [72.51209259, 22.01152992], [72.51235962, 22.01152992], [72.51235962, 22.01264191], [72.51264191, 22.01263809], [72.51264191, 22.0134716], [72.51291656, 22.0134716], [72.51291656, 22.01458359], [72.51319122, 22.01458168], [72.51319122, 22.01542282], [72.51346588, 22.01542282], [72.51346588, 22.0165329], [72.51374817, 22.0165329], [72.51374817, 22.01764107], [72.51403046, 22.01763916], [72.51403046, 22.01847267], [72.51431274, 22.01847076], [72.51431274, 22.01931], [72.51457977, 22.01931], [72.51457977, 22.02013969], [72.51486206, 22.02013969], [72.51486206, 22.0209713], [72.51513672, 22.02096939], [72.51513672, 22.02153015], [72.51541901, 22.02152634], [72.51541901, 22.02236176], [72.51568604, 22.02235985], [72.51568604, 22.02319908], [72.51597595, 22.02319908], [72.51597595, 22.02403069], [72.51625061, 22.02403069], [72.51625061, 22.02486038], [72.51652527, 22.02486038], [72.51652527, 22.02569389], [72.51680756, 22.02568817], [72.51680756, 22.02652931], [72.51708221, 22.0265274], [72.51708221, 22.02708244], [72.51735687, 22.02708244], [72.51735687, 22.02791977], [72.51763916, 22.02791977], [72.51763916, 22.02874947], [72.51791382, 22.02874947], [72.51791382, 22.02958107], [72.51819611, 22.02958107], [72.51819611, 22.03097153], [72.51847076, 22.03096962], [72.51847076, 22.03264046], [72.51875305, 22.03264046], [72.51875305, 22.03430939], [72.51902771, 22.03430939], [72.51902771, 22.03541946], [72.51930237, 22.03541946], [72.51930237, 22.03652954], [72.51957703, 22.03652954], [72.51957703, 22.03763962], [72.51985931, 22.03763962], [72.51985931, 22.03874969], [72.5201416, 22.03874969], [72.5201416, 22.04042053], [72.52041626, 22.04041672], [72.52041626, 22.04208374], [72.52068329, 22.04208183], [72.52068329, 22.04403114], [72.52097321, 22.04402733], [72.52097321, 22.04569435], [72.52124786, 22.04569435], [72.52124786, 22.04736137], [72.52153015, 22.04735947], [72.52153015, 22.0490303], [72.52180481, 22.04902649], [72.52180481, 22.05069351], [72.5220871, 22.0506897], [72.5220871, 22.05236053], [72.52236176, 22.05236053], [72.52236176, 22.05404282], [72.52263641, 22.05402756], [72.52263641, 22.05597115], [72.5229187, 22.05597115], [72.5229187, 22.05820084], [72.52319336, 22.05819321], [72.52319336, 22.05986023], [72.52347565, 22.05986023], [72.52347565, 22.06125069], [72.52374268, 22.06125069], [72.52374268, 22.06264114], [72.52403259, 22.06264114], [72.52403259, 22.06402969], [72.52430725, 22.06402969], [72.52430725, 22.06542015], [72.52458191, 22.06541634], [72.52458191, 22.06680489], [72.52485657, 22.06679916], [72.52485657, 22.06820107], [72.52513885, 22.06819534], [72.52513885, 22.06958389], [72.52541351, 22.06958389], [72.52541351, 22.07097244], [72.5256958, 22.07097054], [72.5256958, 22.07263947], [72.52597046, 22.07263947], [72.52597046, 22.07402992], [72.52625275, 22.07402992], [72.52625275, 22.07542038], [72.5265274, 22.07542038], [72.5265274, 22.07624817], [72.52625275, 22.07624817], [72.52625275, 22.07681084], [72.5265274, 22.07681084], [72.5265274, 22.07764053], [72.52680206, 22.07764053], [72.52680206, 22.07847214], [72.52707672, 22.07846832], [72.52707672, 22.07930946], [72.52735901, 22.07930946], [72.52735901, 22.08013916], [72.5276413, 22.08013916], [72.5276413, 22.08125114], [72.52791595, 22.08124924], [72.52791595, 22.08208275], [72.52819824, 22.08208275], [72.52819824, 22.08292007], [72.5284729, 22.08291626], [72.5284729, 22.08402824], [72.52874756, 22.08402061], [72.52874756, 22.08514023], [72.52902985, 22.08514023], [72.52902985, 22.08625031], [72.52929687, 22.08625031], [72.52929687, 22.08736038], [72.52958679, 22.08736038], [72.52958679, 22.08819389], [72.52986908, 22.08819008], [72.52986908, 22.08930969], [72.53013611, 22.08930969], [72.53013611, 22.09015083], [72.5304184, 22.09013939], [72.5304184, 22.0909729], [72.53069305, 22.0909729], [72.53069305, 22.09236145], [72.53097534, 22.09236145], [72.53097534, 22.09347153], [72.53125, 22.09347153], [72.53125, 22.09431267], [72.53151703, 22.09431267], [72.53151703, 22.09542274], [72.53180695, 22.09542274], [72.53180695, 22.09625053], [72.5320816, 22.09625053], [72.5320816, 22.09680939], [72.53236389, 22.09680557], [72.53236389, 22.09819412], [72.53263855, 22.09819412], [72.53263855, 22.09902763], [72.53291321, 22.09902], [72.53291321, 22.10013962], [72.5331955, 22.10013962], [72.5331955, 22.10097313], [72.53347015, 22.10097122], [72.53347015, 22.10209084], [72.53375244, 22.10209084], [72.53375244, 22.10320091], [72.5340271, 22.10320091], [72.5340271, 22.10430908], [72.53430176, 22.10430908], [72.53430939, 22.10541916], [72.53457642, 22.10541916], [72.53457642, 22.10652924], [72.5348587, 22.10652924], [72.5348587, 22.10764122], [72.53514099, 22.10764122], [72.53514099, 22.10874939], [72.53541565, 22.10874939], [72.53541565, 22.1095829], [72.53569794, 22.1095829], [72.53569794, 22.11013985], [72.5359726, 22.11013794], [72.5359726, 22.11097145], [72.53624725, 22.11096191], [72.53624725, 22.11181068], [72.53652954, 22.11180305], [72.53652954, 22.11236191], [72.5368042, 22.11236191], [72.5368042, 22.11319351], [72.53708649, 22.1131897], [72.53708649, 22.11403084], [72.53736115, 22.11402512], [72.53736115, 22.11458588], [72.5376358, 22.11458588], [72.5376358, 22.11597252], [72.53791809, 22.11597061], [72.53791809, 22.11791992], [72.53819275, 22.11791611], [72.53819275, 22.11958313], [72.53847504, 22.11958313], [72.53847504, 22.12013817], [72.53874969, 22.12013817], [72.53874969, 22.12097168], [72.53901672, 22.12097168], [72.53901672, 22.12181282], [72.53930664, 22.12181282], [72.53930664, 22.12236023], [72.5395813, 22.12236023], [72.5395813, 22.12319374], [72.53985596, 22.12319183], [72.53985596, 22.12403107], [72.54013824, 22.12403107], [72.54013824, 22.12514114], [72.5404129, 22.12513924], [72.5404129, 22.12597275], [72.54069519, 22.12597275], [72.54069519, 22.12708282], [72.54096985, 22.12708092], [72.54096985, 22.12792015], [72.54125214, 22.12792015], [72.54125214, 22.12903023], [72.54152679, 22.12903023], [72.54152679, 22.1301403], [72.54180908, 22.1301403], [72.54180908, 22.13125038], [72.54207611, 22.13125038], [72.54207611, 22.13235855], [72.5423584, 22.13235855], [72.5423584, 22.13347244], [72.54264069, 22.13347244], [72.54264069, 22.13458252], [72.54291534, 22.13458252], [72.54291534, 22.1356945], [72.54319763, 22.1356926], [72.54319763, 22.13652992], [72.54347229, 22.13652802], [72.54347229, 22.13736153], [72.54374695, 22.13735962], [72.54374695, 22.13820076], [72.54402924, 22.13820076], [72.54402924, 22.13903046], [72.54429626, 22.13903046], [72.54430389, 22.13986015], [72.54458618, 22.13986015], [72.54458618, 22.14042091], [72.54486084, 22.14041519], [72.54486084, 22.14097214], [72.54514313, 22.14097023], [72.54514313, 22.14180946], [72.54541779, 22.14180946], [72.54541779, 22.14236069], [72.54569244, 22.14236069], [72.54569244, 22.1431942], [72.54597473, 22.1431942], [72.54597473, 22.14430618], [72.54624939, 22.14430046], [72.54624939, 22.14541817], [72.54651642, 22.14541817], [72.54651642, 22.14653015], [72.54680634, 22.14653015], [72.54680634, 22.14764023], [72.54708099, 22.14764023], [72.54708099, 22.14875031], [72.54736328, 22.14875031], [72.54736328, 22.14986038], [72.54763794, 22.14986038], [72.54763794, 22.15069389], [72.5479126, 22.15069008], [72.5479126, 22.15125084], [72.54818726, 22.15125084], [72.54818726, 22.15180969], [72.54846954, 22.15180969], [72.54846954, 22.15236092], [72.54875183, 22.15236092], [72.54875183, 22.15320015], [72.54902649, 22.15320015], [72.54902649, 22.15374947], [72.54930878, 22.15374947], [72.54930878, 22.15431023], [72.54958344, 22.1543045], [72.54958344, 22.15486145], [72.54985809, 22.15485954], [72.54985809, 22.15570068], [72.55014038, 22.15569687], [72.55014038, 22.15624809], [72.55042267, 22.15624046], [72.55042267, 22.15681076], [72.55069733, 22.15680695], [72.55069733, 22.15736198], [72.55097198, 22.15736198], [72.55097198, 22.15819359], [72.55124664, 22.15818977], [72.55124664, 22.15875053], [72.55152893, 22.15875053], [72.55152893, 22.15930557], [72.55179596, 22.15929985], [72.55179596, 22.15986061], [72.55208588, 22.15986061], [72.55208588, 22.16041946], [72.55236053, 22.16041756], [72.55236053, 22.1609726], [72.55264282, 22.1609726], [72.55264282, 22.16152954], [72.55291748, 22.16152763], [72.55291748, 22.16208267], [72.55319214, 22.16208267], [72.55319214, 22.16263962], [72.55347443, 22.16263962], [72.55347443, 22.16347313], [72.55374908, 22.16347122], [72.55374908, 22.16403008], [72.55403137, 22.16402817], [72.55403137, 22.16458321], [72.55430603, 22.16457939], [72.55430603, 22.16514015], [72.55458069, 22.16514015], [72.55458069, 22.16570091], [72.55486298, 22.16570091], [72.55486298, 22.16625023], [72.55513763, 22.16625023], [72.55513763, 22.16681099], [72.55541992, 22.16681099], [72.55541992, 22.16736031], [72.55568695, 22.16736031], [72.55568695, 22.16792107], [72.55596924, 22.16791534], [72.55596924, 22.16847229], [72.55625153, 22.16847038], [72.55625153, 22.16875076], [72.55652618, 22.16875076], [72.55652618, 22.16930962], [72.55680847, 22.16930771], [72.55680847, 22.16958237], [72.55708313, 22.16958046], [72.55708313, 22.17014122], [72.55735779, 22.17014122], [72.55735779, 22.17041969], [72.55764008, 22.17041779], [72.55764008, 22.17097282], [72.55791473, 22.17097282], [72.55791473, 22.17124748], [72.55819702, 22.17123985], [72.55819702, 22.17180824], [72.55847168, 22.17180634], [72.55847168, 22.1720829], [72.55874634, 22.17207909], [72.55874634, 22.17264175], [72.55902863, 22.17264175], [72.55902863, 22.17292023], [72.55930328, 22.17291641], [72.55930328, 22.17347145], [72.55958557, 22.17347145], [72.55958557, 22.17375183], [72.55986023, 22.17375183], [72.55986023, 22.17430496], [72.56014252, 22.17430496], [72.56014252, 22.17458344], [72.56041718, 22.17457962], [72.56041718, 22.17514038], [72.56069183, 22.17514038], [72.56069183, 22.17542076], [72.56097412, 22.17541695], [72.56097412, 22.17597389], [72.56124878, 22.17597008], [72.56124878, 22.17625046], [72.56153107, 22.17625046], [72.56153107, 22.17681122], [72.56180573, 22.1768055], [72.56180573, 22.17708206], [72.56208038, 22.17708015], [72.56208038, 22.17764091], [72.56236267, 22.17764091], [72.56236267, 22.17791939], [72.56263733, 22.17791748], [72.56263733, 22.17847252], [72.56291199, 22.17847061], [72.56291199, 22.17875099], [72.56318665, 22.17875099], [72.56318665, 22.17930984], [72.56346893, 22.17930412], [72.56346893, 22.1795826], [72.56375122, 22.17958069], [72.56375122, 22.18013954], [72.56402588, 22.18013954], [72.56402588, 22.18042946], [72.56430817, 22.1804142], [72.56430817, 22.18097305], [72.56458282, 22.18097115], [72.56458282, 22.18124962], [72.56485748, 22.18124962], [72.56485748, 22.18180466], [72.56513977, 22.18180466], [72.56513977, 22.18208313], [72.5654068, 22.18208122], [72.5654068, 22.18264008], [72.56569672, 22.18264008], [72.56569672, 22.18292046], [72.56597137, 22.18291855], [72.56597137, 22.18347168], [72.56624603, 22.18346977], [72.56624603, 22.18374825], [72.56652832, 22.18374825], [72.56652832, 22.18431091], [72.56680298, 22.18430519], [72.56680298, 22.18458366], [72.5670929, 22.18457985], [72.5670929, 22.18514061], [72.56735992, 22.18514061], [72.56735992, 22.18541908], [72.56764221, 22.18541718], [72.56764221, 22.18597221], [72.56791687, 22.18597221], [72.56791687, 22.18625069], [72.56819153, 22.18624115], [72.56819153, 22.18680954], [72.56847382, 22.18680573], [72.56847382, 22.1870842], [72.56874847, 22.18707848], [72.56874847, 22.18764114], [72.56903839, 22.18764114], [72.56903839, 22.18791962], [72.56930542, 22.1879158], [72.56930542, 22.18819427], [72.56958008, 22.18819427], [72.56958008, 22.18847275], [72.56986237, 22.18847275], [72.56986237, 22.18875122], [72.57013702, 22.18875122], [72.57013702, 22.18902969], [72.57041931, 22.18902969], [72.57041931, 22.18931007], [72.57069397, 22.18930626], [72.57069397, 22.18958282], [72.57096863, 22.18958282], [72.57096863, 22.1898613], [72.57125092, 22.18985939], [72.57125092, 22.19042015], [72.57152557, 22.19041634], [72.57152557, 22.19069481], [72.57180786, 22.19069481], [72.57180786, 22.19097137], [72.57208252, 22.19096947], [72.57208252, 22.19124985], [72.57235718, 22.19124985], [72.57235718, 22.19153023], [72.57263947, 22.19152832], [72.57263947, 22.19180489], [72.57291412, 22.19180489], [72.57291412, 22.19208336], [72.57319641, 22.19207954], [72.57319641, 22.19236946], [72.57347107, 22.19236946], [72.57347107, 22.1926403], [72.57375336, 22.1926403], [72.57375336, 22.19292068], [72.57402802, 22.19292068], [72.57402802, 22.19320107], [72.57430267, 22.19319534], [72.57430267, 22.19347191], [72.57458496, 22.19347191], [72.57458496, 22.19375038], [72.57514191, 22.19375038], [72.57514191, 22.19403076], [72.57541656, 22.19403076], [72.57541656, 22.19431114], [72.57569122, 22.19430542], [72.57569122, 22.19458389], [72.57596588, 22.19458008], [72.57596588, 22.19486046], [72.57624817, 22.19486046], [72.57624817, 22.19514084], [72.57653046, 22.19513893], [72.57653046, 22.1954155], [72.57680511, 22.1954155], [72.57680511, 22.19569397], [72.57707977, 22.19569397], [72.57707977, 22.19597244], [72.57736206, 22.19597054], [72.57736206, 22.19625092], [72.57763672, 22.19625092], [72.57763672, 22.19652939], [72.57791901, 22.19652939], [72.57791901, 22.19680977], [72.57819366, 22.19680786], [72.57819366, 22.19708252], [72.57847595, 22.19708061], [72.57847595, 22.19735909], [72.57875061, 22.19735909], [72.57875061, 22.19763947], [72.5790329, 22.19763947], [72.5790329, 22.19791985], [72.57930756, 22.19791794], [72.57930756, 22.1981945], [72.57958221, 22.1981945], [72.57958221, 22.19847298], [72.57985687, 22.19846916], [72.57985687, 22.19874763], [72.58013916, 22.19874763], [72.58013916, 22.19903183], [72.58041382, 22.19902992], [72.58040619, 22.19930077], [72.58069611, 22.19930649], [72.58069611, 22.19958305], [72.58097076, 22.19958305], [72.58097076, 22.19986153], [72.58125305, 22.19986153], [72.58125305, 22.20014191], [72.58152771, 22.20014191], [72.58152771, 22.20042038], [72.58180237, 22.20042038], [72.58180237, 22.20070267], [72.58208466, 22.20069504], [72.58208466, 22.2009716], [72.5826416, 22.2009716], [72.5826416, 22.20125008], [72.58291626, 22.20125008], [72.58291626, 22.20153999], [72.58319092, 22.20153999], [72.58319092, 22.20181274], [72.58374786, 22.20180511], [72.58374786, 22.20208359], [72.58402252, 22.20208168], [72.58403015, 22.20236015], [72.5845871, 22.20236015], [72.5845871, 22.20264053], [72.58486176, 22.20264053], [72.58486176, 22.20292282], [72.58513641, 22.2029171], [72.58513641, 22.20319366], [72.58569336, 22.20319366], [72.58569336, 22.20347214], [72.58597565, 22.20347214], [72.58597565, 22.20375061], [72.58625031, 22.20375061], [72.58625031, 22.20403099], [72.58680725, 22.20403099], [72.58680725, 22.20430946], [72.58708191, 22.20430565], [72.58708191, 22.20458221], [72.58735657, 22.20458031], [72.58735657, 22.20486069], [72.58790588, 22.20486069], [72.58790588, 22.20514107], [72.5881958, 22.20514107], [72.5881958, 22.20541954], [72.58847046, 22.20541573], [72.58847046, 22.2056942], [72.5890274, 22.2056942], [72.5890274, 22.20597267], [72.58930206, 22.20597076], [72.58930206, 22.20625114], [72.58985901, 22.20625114], [72.58985901, 22.20652962], [72.59014893, 22.20652962], [72.59014893, 22.20681], [72.59041595, 22.20680428], [72.59041595, 22.20708275], [72.5909729, 22.20708275], [72.5909729, 22.20736122], [72.59124756, 22.20734978], [72.59124756, 22.20763969], [72.59152985, 22.20763969], [72.59152985, 22.20792007], [72.59208679, 22.20791435], [72.59208679, 22.20819473], [72.59236145, 22.20819473], [72.59236145, 22.2084713], [72.5929184, 22.20846939], [72.5929184, 22.20874977], [72.59348297, 22.20874977], [72.59348297, 22.20903015], [72.59375, 22.20902634], [72.59375, 22.20930481], [72.59430695, 22.20930481], [72.59430695, 22.20958328], [72.59486389, 22.20958328], [72.59486389, 22.20986176], [72.59541321, 22.20985985], [72.59541321, 22.21014023], [72.5956955, 22.21013641], [72.5956955, 22.2104187], [72.59625244, 22.21041107], [72.59625244, 22.21069908], [72.59680176, 22.21069908], [72.59680939, 22.21097183], [72.5973587, 22.21096992], [72.5973587, 22.21125031], [72.59792328, 22.21125031], [72.59792328, 22.21153069], [72.59819794, 22.21153069], [72.59819794, 22.21180916], [72.59874725, 22.21180534], [72.59874725, 22.21208382], [72.59929657, 22.21207809], [72.59929657, 22.21235847], [72.59986115, 22.21235847], [72.59986115, 22.21264076], [72.6001358, 22.21264076], [72.6001358, 22.21291924], [72.60069275, 22.21291733], [72.60069275, 22.21319389], [72.60124969, 22.21318817], [72.60124969, 22.2134819], [72.60235596, 22.2134819], [72.60235596, 22.21375084], [72.60346985, 22.21375084], [72.60346985, 22.21403122], [72.60430908, 22.21403122], [72.60430908, 22.21430969], [72.60541534, 22.21430588], [72.60541534, 22.21458244], [72.60652924, 22.21458244], [72.60652924, 22.21486282], [72.6076355, 22.21486282], [72.6076355, 22.21513939], [72.6084671, 22.21513939], [72.6084671, 22.21541977], [72.60958099, 22.21541595], [72.60958099, 22.21569443], [72.61069489, 22.21569443], [72.61069489, 22.2159729], [72.61125183, 22.2159729], [72.61125183, 22.21624947], [72.61180878, 22.21624947], [72.61180878, 22.21653938], [72.61264038, 22.21653938], [72.61264038, 22.21681023], [72.61319733, 22.21680641], [72.61319733, 22.21708488], [72.61374664, 22.21708488], [72.61374664, 22.21736145], [72.61486053, 22.21735954], [72.61486053, 22.21763992], [72.61569214, 22.21763992], [72.61569214, 22.21735954], [72.62097168, 22.21735954], [72.62097168, 22.21763992], [72.62541962, 22.21763992], [72.62541962, 22.2179203], [72.63957977, 22.2179203], [72.63957977, 22.21763992], [72.63986206, 22.21763992], [72.63986206, 22.21735954], [72.64208221, 22.21736145], [72.64208221, 22.21708488], [72.6423645, 22.21708488], [72.6423645, 22.21680641], [72.64291382, 22.21680641], [72.64291382, 22.21736145], [72.64485931, 22.21736145], [72.64485931, 22.21708488], [72.64736176, 22.21708488], [72.64736176, 22.21680641], [72.64848328, 22.21681023], [72.64848328, 22.21653938], [72.64875031, 22.21653938], [72.64875031, 22.21624947], [72.64930725, 22.21624947], [72.64930725, 22.2159729], [72.65041351, 22.2159729], [72.65041351, 22.21569443], [72.6506958, 22.21569443], [72.6506958, 22.21541595], [72.65207672, 22.21541977], [72.65207672, 22.21513939], [72.6526413, 22.21513939], [72.6526413, 22.21486282], [72.6534729, 22.21486282], [72.6534729, 22.21458244], [72.65402985, 22.21458244], [72.65402985, 22.21430588], [72.65458679, 22.21430969], [72.65458679, 22.21403122], [72.65513611, 22.21403122], [72.65513611, 22.21375084], [72.65598297, 22.21375084], [72.65597534, 22.21347237], [72.65651703, 22.2134819], [72.65651703, 22.21318817], [72.6570816, 22.21319389], [72.6570816, 22.21291733], [72.65763855, 22.21291924], [72.65763855, 22.21265984], [72.6579361, 22.2126503], [72.65847015, 22.21264076], [72.65847015, 22.21253967], [72.65847015, 22.21235847], [72.6590271, 22.21235847], [72.6590271, 22.21207809], [72.65930176, 22.21208382], [72.65930176, 22.21180534], [72.65957642, 22.21180916], [72.65957642, 22.21153069], [72.66014099, 22.21153069], [72.66014099, 22.21125031], [72.66042328, 22.21125031], [72.66041565, 22.21097183], [72.6609726, 22.21097183], [72.6609726, 22.21069527], [72.66124725, 22.21069908], [72.66124725, 22.21041107], [72.6618042, 22.2104187], [72.6618042, 22.21013641], [72.66208649, 22.21014023], [72.66208649, 22.20985985], [72.66236115, 22.20986176], [72.66236115, 22.20958328], [72.6626358, 22.20958328], [72.6626358, 22.20902634], [72.66291809, 22.20903015], [72.66291809, 22.20874977], [72.66319275, 22.20874977], [72.66319275, 22.20846939], [72.66347504, 22.2084713], [72.66347504, 22.20819473], [72.66374969, 22.20819473], [72.66374969, 22.20791435], [72.66430664, 22.20792007], [72.66430664, 22.20763969], [72.66485596, 22.20763969], [72.66485596, 22.20734978], [72.6654129, 22.20736122], [72.6654129, 22.20708275], [72.66569519, 22.20708275], [72.66569519, 22.20680428], [72.66596985, 22.20681], [72.66596985, 22.20652962], [72.66625214, 22.20652962], [72.66625214, 22.20625114], [72.66652679, 22.20625114], [72.66652679, 22.20597076], [72.66680908, 22.20597267], [72.66680908, 22.2056942], [72.6673584, 22.2056942], [72.6673584, 22.20541573], [72.66847229, 22.20541954], [72.66847229, 22.20514107], [72.66874695, 22.20514107], [72.66874695, 22.20486069], [72.66902924, 22.20486069], [72.66902924, 22.20458031], [72.66930389, 22.20458221], [72.66930389, 22.20430565], [72.67014313, 22.20430946], [72.67014313, 22.20375061], [72.67041779, 22.20375061], [72.67041779, 22.20347023], [72.67097473, 22.20347214], [72.67097473, 22.2029171], [72.67124176, 22.20292282], [72.67124176, 22.20264053], [72.67151642, 22.20264053], [72.67151642, 22.20236015], [72.67263794, 22.20236015], [72.67263794, 22.20208168], [72.67346954, 22.20208359], [72.67346954, 22.20152855], [72.67375183, 22.20153999], [72.67375183, 22.20125008], [72.67402649, 22.20125008], [72.67402649, 22.2009716], [72.67430878, 22.2009716], [72.67430878, 22.20069504], [72.67485809, 22.20070267], [72.67485809, 22.20042038], [72.67542267, 22.20042038], [72.67542267, 22.20014191], [72.67597198, 22.20014191], [72.67597198, 22.19986153], [72.67652893, 22.19986153], [72.67652893, 22.19958305], [72.67791748, 22.19958305], [72.67791748, 22.19930649], [72.67930603, 22.19930077], [72.67930603, 22.19902992], [72.67986298, 22.19903183], [72.67986298, 22.19874763], [72.68068695, 22.19874763], [72.68068695, 22.19846916], [72.68125153, 22.19847298], [72.68125153, 22.1981945], [72.68180847, 22.1981945], [72.68180847, 22.19791794], [72.68208313, 22.19791985], [72.68208313, 22.19763947], [72.68264008, 22.19763947], [72.68264008, 22.19735909], [72.68319702, 22.19735909], [72.68319702, 22.19708061], [72.68374634, 22.19708252], [72.68374634, 22.19680786], [72.68402863, 22.19680977], [72.68402863, 22.19652939], [72.6845932, 22.19652939], [72.6845932, 22.19625092], [72.68514252, 22.19625092], [72.68514252, 22.19597054], [72.68569183, 22.19597244], [72.68569183, 22.19569397], [72.68597412, 22.19569397], [72.68597412, 22.1954155], [72.68653107, 22.1954155], [72.68653107, 22.19513893], [72.68708038, 22.19514084], [72.68708038, 22.19486046], [72.68763733, 22.19486046], [72.68763733, 22.19458008], [72.68791962, 22.19458389], [72.68791962, 22.19430542], [72.68846893, 22.19431114], [72.68846893, 22.19403076], [72.68875122, 22.19403076], [72.68875122, 22.19375038], [72.68930817, 22.19375038], [72.68930817, 22.19320107], [72.68958282, 22.19320107], [72.68958282, 22.19292068], [72.69013977, 22.19292068], [72.69013977, 22.19236946], [72.6904068, 22.19236946], [72.6904068, 22.19207954], [72.69069672, 22.19208336], [72.69069672, 22.19180489], [72.69097137, 22.19180489], [72.69097137, 22.19124985], [72.69124603, 22.19124985], [72.69124603, 22.19096947], [72.69180298, 22.19097137], [72.69180298, 22.19041634], [72.6920929, 22.19042015], [72.6920929, 22.19013977], [72.69235992, 22.19013977], [72.69235992, 22.1898613], [72.69264221, 22.1898613], [72.69264221, 22.18958282], [72.69319153, 22.18958282], [72.69319153, 22.18930626], [72.69346619, 22.18931007], [72.69346619, 22.18875122], [72.69403076, 22.18875122], [72.69403076, 22.18847275], [72.69486237, 22.18847275], [72.69486237, 22.18819427], [72.69541931, 22.18819427], [72.69541931, 22.18763924], [72.69596863, 22.18764114], [72.69596863, 22.18736267], [72.69625092, 22.18736267], [72.69625092, 22.18707848], [72.69708252, 22.1870842], [72.69708252, 22.18680573], [72.69790649, 22.18680954], [72.69790649, 22.18652916], [72.69819641, 22.18652916], [72.69819641, 22.18624115], [72.69875336, 22.18625069], [72.69875336, 22.18597221], [72.69902802, 22.18597221], [72.69902802, 22.18569374], [72.69930267, 22.18569374], [72.69930267, 22.18514061], [72.69959259, 22.18514061], [72.69959259, 22.18457985], [72.70014191, 22.18458366], [72.70014191, 22.18430519], [72.70124817, 22.18431091], [72.70124817, 22.18403053], [72.70347595, 22.18403053], [72.70347595, 22.18374825], [72.70540619, 22.18374825], [72.70540619, 22.18403053], [72.70625305, 22.18403053], [72.70625305, 22.18431091], [72.70652771, 22.18431091], [72.70652771, 22.18485832], [72.70707703, 22.18485832], [72.70707703, 22.18514061], [72.70735931, 22.18514061], [72.70735931, 22.18569374], [72.7076416, 22.18569374], [72.7076416, 22.18597221], [72.7095871, 22.18597221], [72.7095871, 22.18569374], [72.71152496, 22.18569374], [72.71152496, 22.18541718], [72.7131958, 22.18541908], [72.7131958, 22.18514061], [72.71485901, 22.18514061], [72.71485901, 22.18485832], [72.71569061, 22.18485832], [72.71569824, 22.18457985], [72.7159729, 22.18458366], [72.7159729, 22.18430519], [72.71653748, 22.18431091], [72.71653748, 22.18403053], [72.71736145, 22.18403053], [72.71736145, 22.18374825], [72.72013855, 22.18374825], [72.72013855, 22.18346977], [72.72125244, 22.18347168], [72.72125244, 22.18319511], [72.72292328, 22.18320084], [72.72292328, 22.18292046], [72.7234726, 22.18292046], [72.7234726, 22.18264008], [72.72458649, 22.18264008], [72.72458649, 22.1823597], [72.72569275, 22.1823616], [72.72569275, 22.18208313], [72.72597504, 22.18208313], [72.72597504, 22.18180466], [72.72736359, 22.18180466], [72.72736359, 22.18152618], [72.72763824, 22.18153], [72.72763824, 22.18124962], [72.7279129, 22.18124962], [72.7279129, 22.18097115], [72.72902679, 22.18097305], [72.72902679, 22.18069458], [72.72930908, 22.18069458], [72.72930908, 22.1804142], [72.73014069, 22.18042946], [72.73014069, 22.18013954], [72.73042297, 22.18013954], [72.73041534, 22.1795826], [72.73097229, 22.1795826], [72.73097229, 22.17930412], [72.73124695, 22.17930984], [72.73124695, 22.17902946], [72.73153687, 22.17902946], [72.73153687, 22.17875099], [72.73208618, 22.17875099], [72.73208618, 22.17847061], [72.73291779, 22.17847252], [72.73291779, 22.17791748], [72.7334671, 22.17791939], [72.7334671, 22.17764091], [72.73430634, 22.17764091], [72.73430634, 22.17737007], [72.73513794, 22.17737007], [72.73513794, 22.17708015], [72.73625183, 22.17708206], [72.73625183, 22.1768055], [72.73652649, 22.17681122], [72.73652649, 22.17653084], [72.73680878, 22.17653084], [72.73680878, 22.17625046], [72.73792267, 22.17625046], [72.73792267, 22.17653084], [72.73847198, 22.17653084], [72.73847198, 22.17625046], [72.73929596, 22.17625046], [72.73929596, 22.17597008], [72.73986053, 22.17597389], [72.73986053, 22.17569351], [72.74041748, 22.17569351], [72.74041748, 22.17541695], [72.7409668, 22.17542076], [72.7409668, 22.17514038], [72.74180603, 22.17514038], [72.74180603, 22.17486191], [72.74236298, 22.17486191], [72.74236298, 22.17458344], [72.74346924, 22.17458344], [72.74346924, 22.17430496], [72.74458313, 22.17430496], [72.74458313, 22.1740284], [72.74597168, 22.1740303], [72.74597168, 22.17375183], [72.7470932, 22.17375183], [72.74708557, 22.17347145], [72.74819183, 22.17347145], [72.74819183, 22.17319489], [72.75208282, 22.17319489], [72.75402832, 22.17319489], [72.75402832, 22.17347145], [72.75514221, 22.17347145], [72.75514221, 22.17375183], [72.75624847, 22.17375183], [72.75624847, 22.1740303], [72.75763702, 22.1740284], [72.75763702, 22.17430496], [72.75819397, 22.17430496], [72.75819397, 22.17458344], [72.75875092, 22.17458344], [72.75875092, 22.17486191], [72.75930786, 22.17486191], [72.75930786, 22.17514038], [72.75985718, 22.17514038], [72.75985718, 22.17542076], [72.76013947, 22.17541695], [72.76013947, 22.17597389], [72.76040649, 22.17597008], [72.76040649, 22.17625046], [72.76069641, 22.17625046], [72.76069641, 22.17653084], [72.76097107, 22.17653084], [72.76097107, 22.17681122], [72.76125336, 22.1768055], [72.76125336, 22.17708206], [72.76152039, 22.17708015], [72.76152039, 22.17737007], [72.76180267, 22.17737007], [72.76180267, 22.17764091], [72.76209259, 22.17764091], [72.76209259, 22.17791939], [72.76235962, 22.17791748], [72.76235962, 22.17819214], [72.76209259, 22.17819023], [72.76209259, 22.17902946], [72.76180267, 22.17902946], [72.76180267, 22.17930984], [72.76208496, 22.17930412], [72.76208496, 22.1795826], [72.76235962, 22.17958069], [72.76235962, 22.17986107], [72.76264191, 22.17986107], [72.76264191, 22.18042946], [72.76291656, 22.1804142], [72.76291656, 22.18069458], [72.76319122, 22.18069458], [72.76319122, 22.18097305], [72.76346588, 22.18097115], [72.76346588, 22.18124962], [72.76374817, 22.18124962], [72.76374817, 22.18153], [72.76403046, 22.18152618], [72.76403046, 22.18180466], [72.76430511, 22.18180466], [72.76430511, 22.18208313], [72.7645874, 22.18208122], [72.7645874, 22.18264008], [72.76513672, 22.18264008], [72.76513672, 22.18292046], [72.76541901, 22.18291855], [72.76541901, 22.18347168], [72.76568604, 22.18346977], [72.76568604, 22.18403053], [72.76597595, 22.18403053], [72.76597595, 22.18431091], [72.76625061, 22.18430519], [72.76625061, 22.18458366], [72.76680756, 22.18457985], [72.76680756, 22.18485832], [72.76708221, 22.18485832], [72.76708221, 22.18514061], [72.76735687, 22.18514061], [72.76735687, 22.18541908], [72.76763916, 22.18541718], [72.76763916, 22.18597221], [72.76790619, 22.1859684], [72.76790619, 22.18680954], [72.76819611, 22.18680573], [72.76819611, 22.1870842], [72.76847076, 22.18707848], [72.76847076, 22.18736267], [72.76875305, 22.18736267], [72.76875305, 22.18764114], [72.76902771, 22.18763924], [72.76902771, 22.18819427], [72.76930237, 22.18819427], [72.76930237, 22.18847275], [72.76957703, 22.18847275], [72.76957703, 22.18875122], [72.7701416, 22.18875122], [72.7701416, 22.18902969], [72.77041626, 22.18902779], [72.77041626, 22.1898613], [72.77069092, 22.18985939], [72.77069092, 22.19042015], [72.77097321, 22.19041634], [72.77097321, 22.19069481], [72.77124786, 22.19069481], [72.77124786, 22.19097137], [72.77153015, 22.19096947], [72.77153015, 22.19124985], [72.77180481, 22.19124985], [72.77180481, 22.19180489], [72.7720871, 22.19180489], [72.7720871, 22.19208336], [72.77236176, 22.19207954], [72.77236176, 22.19236946], [72.77263641, 22.19236946], [72.77263641, 22.19292068], [72.7729187, 22.19292068], [72.7729187, 22.19320107], [72.77319336, 22.19319534], [72.77319336, 22.19347191], [72.77347565, 22.19347191], [72.77347565, 22.19375038], [72.77375031, 22.19375038], [72.77375031, 22.19403076], [72.77403259, 22.19403076], [72.77403259, 22.19431114], [72.77430725, 22.19431114], [72.77430725, 22.19486046], [72.77458191, 22.19486046], [72.77458191, 22.1954155], [72.7748642, 22.1954155], [72.7748642, 22.19569397], [72.77513885, 22.19569016], [72.77513885, 22.19625092], [72.77540588, 22.19625092], [72.77540588, 22.19680977], [72.7756958, 22.19680786], [72.7756958, 22.19708252], [72.77597046, 22.19708061], [72.77597046, 22.19763947], [72.77625275, 22.19763947], [72.77625275, 22.1981945], [72.7765274, 22.19818115], [72.7765274, 22.19874763], [72.77680206, 22.19874763], [72.77680206, 22.19903183], [72.77735901, 22.19902992], [72.77735901, 22.19986153], [72.7776413, 22.19986153], [72.7776413, 22.20014191], [72.77791595, 22.20013809], [72.77791595, 22.2009716], [72.77819824, 22.2009716], [72.77819824, 22.20125008], [72.7784729, 22.20125008], [72.7784729, 22.20236015], [72.77874756, 22.20236015], [72.77874756, 22.20292282], [72.77902985, 22.2029171], [72.77902985, 22.20319366], [72.77929688, 22.20318985], [72.77929688, 22.20375061], [72.77958679, 22.20375061], [72.77958679, 22.2056942], [72.77986145, 22.20569038], [72.77986145, 22.20625114], [72.78013611, 22.20625114], [72.78013611, 22.20652962], [72.7804184, 22.20652771], [72.7804184, 22.20736122], [72.78069305, 22.20736122], [72.78069305, 22.20819473], [72.78097534, 22.20819473], [72.78097534, 22.2084713], [72.78125, 22.20846939], [72.78125, 22.20874977], [72.78152466, 22.20874977], [72.78152466, 22.20958328], [72.78180695, 22.20957947], [72.78180695, 22.21014023], [72.7820816, 22.21013641], [72.7820816, 22.2104187], [72.78235626, 22.21041107], [72.78235626, 22.21264076], [72.78263092, 22.21264076], [72.78263092, 22.21291924], [72.78291321, 22.21291924], [72.78291321, 22.2134819], [72.7831955, 22.21347237], [72.7831955, 22.21375084], [72.78347015, 22.21375084], [72.78347015, 22.21430969], [72.78375244, 22.21430588], [72.78375244, 22.21458244], [72.7840271, 22.21458244], [72.7840271, 22.21513939], [72.78430176, 22.21513939], [72.78430939, 22.21541977], [72.78458405, 22.21541595], [72.78458405, 22.2159729], [72.7848587, 22.2159729], [72.7848587, 22.21653938], [72.78514099, 22.21653938], [72.78514099, 22.21681023], [72.78541565, 22.21680641], [72.78541565, 22.21736145], [72.78569031, 22.21735954], [72.78569031, 22.21763992], [72.7859726, 22.21763992], [72.7859726, 22.21820068], [72.78624725, 22.21819305], [72.78624725, 22.21847153], [72.78652954, 22.21846962], [72.78652954, 22.21903038], [72.78679657, 22.21903038], [72.78679657, 22.21931076], [72.78708649, 22.21930313], [72.78708649, 22.21986198], [72.78736115, 22.21986008], [72.78736115, 22.22042084], [72.7876358, 22.22041512], [72.7876358, 22.22069359], [72.78791809, 22.22068977], [72.78791809, 22.22125053], [72.78848267, 22.22125053], [72.78848267, 22.22153091], [72.78875732, 22.22153091], [72.78875732, 22.22180939], [72.78902435, 22.22180557], [72.78902435, 22.22208595], [72.78930664, 22.22208595], [72.78930664, 22.22236061], [72.7895813, 22.22235107], [72.7895813, 22.22264099], [72.78986359, 22.22263718], [72.78986359, 22.2234726], [72.79013824, 22.22347069], [72.79013824, 22.22375107], [72.7904129, 22.22375107], [72.7904129, 22.22430992], [72.79069519, 22.22430611], [72.79069519, 22.22513962], [72.79096985, 22.22513962], [72.79096985, 22.22541809], [72.79125214, 22.22541618], [72.79125214, 22.22569466], [72.79152679, 22.22569084], [72.79152679, 22.2262516], [72.79180908, 22.2262516], [72.79180908, 22.22708321], [72.79208374, 22.22708321], [72.79208374, 22.22736168], [72.79264069, 22.22736168], [72.79264069, 22.22764015], [72.79292297, 22.22764015], [72.79292297, 22.2293129], [72.79319763, 22.22930527], [72.79319763, 22.22958374], [72.79347229, 22.22958183], [72.79347229, 22.22986031], [72.79374695, 22.22986031], [72.79374695, 22.23042107], [72.79402924, 22.23041725], [72.79402924, 22.23069382], [72.79430389, 22.23069382], [72.79430389, 22.23097229], [72.79458618, 22.23097229], [72.79458618, 22.23152733], [72.79486084, 22.2315197], [72.79486084, 22.23180962], [72.7951355, 22.2318058], [72.7951355, 22.23236084], [72.79541779, 22.23236084], [72.79541779, 22.23264122], [72.79569244, 22.23264122], [72.79569244, 22.23291969], [72.79597473, 22.23291588], [72.79597473, 22.23347282], [72.79624939, 22.23347092], [72.79624939, 22.23374939], [72.79651642, 22.23374939], [72.79651642, 22.23402977], [72.79680634, 22.23402786], [72.79680634, 22.2345829], [72.79708099, 22.2345829], [72.79708099, 22.23486137], [72.79736328, 22.23485947], [72.79736328, 22.23542023], [72.79763794, 22.23541641], [72.79763794, 22.23569679], [72.79792023, 22.23569679], [72.79792023, 22.23597145], [72.79818726, 22.23596954], [72.79818726, 22.2365303], [72.79846954, 22.2365303], [72.79846954, 22.23681068], [72.79875183, 22.23680496], [72.79875183, 22.23736191], [72.79902649, 22.23735809], [72.79902649, 22.23765182], [72.79930878, 22.23765182], [72.79930878, 22.23792076], [72.79958344, 22.23791885], [72.79958344, 22.23847008], [72.79985809, 22.23846817], [72.79985809, 22.23875046], [72.80042267, 22.23875046], [72.80042267, 22.23903084], [72.80069733, 22.23902893], [72.80069733, 22.23958397], [72.80097198, 22.23957825], [72.80097198, 22.23985863], [72.80152893, 22.23985863], [72.80152893, 22.24014091], [72.80179596, 22.24014091], [72.80179596, 22.24041939], [72.80208588, 22.24041748], [72.80208588, 22.24069405], [72.80263519, 22.24069405], [72.80263519, 22.24097252], [72.80291748, 22.24097252], [72.80291748, 22.24152946], [72.80319214, 22.24152946], [72.80319214, 22.24180984], [72.80374908, 22.24180603], [72.80374908, 22.2420826], [72.80430603, 22.2420826], [72.80430603, 22.24236107], [72.80513763, 22.24236107], [72.80513763, 22.24263954], [72.80568695, 22.24263954], [72.80568695, 22.24291992], [72.80596924, 22.24291611], [72.80596924, 22.24347115], [72.80625153, 22.24346161], [72.80625153, 22.24374962], [72.80652618, 22.24374962], [72.80652618, 22.24430466], [72.80680847, 22.24430466], [72.80680847, 22.24458313], [72.80735779, 22.24458313], [72.80735779, 22.2448616], [72.80764008, 22.2448597], [72.80764008, 22.24514008], [72.8079071, 22.24514008], [72.8079071, 22.24542046], [72.80847168, 22.24542046], [72.80847168, 22.24570084], [72.80874634, 22.24569321], [72.80874634, 22.24597168], [72.80930328, 22.24596977], [72.80930328, 22.24625015], [72.81014252, 22.24625015], [72.81014252, 22.24652863], [72.81069183, 22.246521], [72.81069183, 22.24681091], [72.81124878, 22.24680519], [72.81124878, 22.24708366], [72.81208038, 22.24707985], [72.81208038, 22.24736023], [72.81263733, 22.24736023], [72.81263733, 22.24764061], [72.81375122, 22.24764061], [72.81375122, 22.24792099], [72.81597137, 22.24792099], [72.81597137, 22.24764061], [72.8170929, 22.24764061], [72.8170929, 22.24792099], [72.81735992, 22.24792099], [72.81735992, 22.24764061], [72.81819153, 22.24764061], [72.81819153, 22.24707985], [72.81847382, 22.24708366], [72.81847382, 22.24680519], [72.81903076, 22.24681091], [72.81903076, 22.246521], [72.81986237, 22.24652863], [72.81986237, 22.24597168], [72.82041931, 22.24597168], [72.82041931, 22.24569321], [72.82096863, 22.24570084], [72.82096863, 22.24542046], [72.82125092, 22.24542046], [72.82125092, 22.24514008], [72.82180023, 22.24514008], [72.82180023, 22.24458122], [72.82208252, 22.24458313], [72.82208252, 22.24430466], [72.82236481, 22.24430466], [72.82236481, 22.24374962], [72.82290649, 22.24374962], [72.82290649, 22.24346161], [72.82347107, 22.24347115], [72.82347107, 22.24263954], [72.82430267, 22.24263954], [72.82430267, 22.2420826], [72.82485962, 22.2420826], [72.82485962, 22.24180603], [72.82541656, 22.24180984], [72.82541656, 22.24152946], [72.82569122, 22.24152946], [72.82569122, 22.2412529], [72.82624817, 22.2412529], [72.82624817, 22.24068832], [72.82707977, 22.24069405], [72.82707977, 22.24041748], [72.82792664, 22.24041939], [72.82792664, 22.24014091], [72.83013916, 22.24014091], [72.83013916, 22.23985863], [72.83040619, 22.23985863], [72.83040619, 22.23957825], [72.83097076, 22.23958397], [72.83097076, 22.2393055], [72.83152771, 22.23930931], [72.83152771, 22.23903084], [72.83347321, 22.23903084], [72.83347321, 22.23875046], [72.83429718, 22.23875046], [72.83429718, 22.23846817], [72.83486176, 22.23847008], [72.83486176, 22.23819351], [72.83625031, 22.23819351], [72.83625031, 22.23847008], [72.83652496, 22.23847008], [72.83652496, 22.23819351], [72.8381958, 22.23819351], [72.8381958, 22.23791885], [72.8390274, 22.23792076], [72.8390274, 22.23765182], [72.83986664, 22.23765182], [72.83986664, 22.23735809], [72.8418045, 22.23736191], [72.8418045, 22.23708344], [72.84402466, 22.23708344], [72.84402466, 22.23680496], [72.84625244, 22.23681068], [72.84625244, 22.2365303], [72.84792328, 22.2365303], [72.84792328, 22.23624992], [72.8484726, 22.23624992], [72.8484726, 22.23596954], [72.8493042, 22.23597145], [72.8493042, 22.23569679], [72.84986115, 22.23569679], [72.84986115, 22.23513794], [72.85041809, 22.23513985], [72.85041809, 22.23485947], [72.85124969, 22.23486137], [72.85124969, 22.2345829], [72.85152435, 22.2345829], [72.85152435, 22.23430443], [72.8520813, 22.23431015], [72.8520813, 22.23402977], [72.85235596, 22.23402977], [72.85235596, 22.23374939], [72.85263824, 22.23374939], [72.85263824, 22.23347092], [72.85319519, 22.23347282], [72.85319519, 22.23319435], [72.85346985, 22.23319435], [72.85346985, 22.23291588], [72.85402679, 22.23291969], [72.85402679, 22.23264122], [72.85457611, 22.23264122], [72.85457611, 22.23236084], [72.85514069, 22.23236084], [72.85514069, 22.23208046], [72.85541534, 22.23208237], [72.85541534, 22.2318058], [72.85569763, 22.23180962], [72.85569763, 22.2315197], [72.85597229, 22.23152733], [72.85597229, 22.23125076], [72.85652924, 22.23125076], [72.85652924, 22.23097038], [72.85708618, 22.23097229], [72.85708618, 22.23069382], [72.85736084, 22.23069382], [72.85736084, 22.23041725], [72.85791016, 22.23042107], [72.85791016, 22.23014069], [72.8584671, 22.23014069], [72.8584671, 22.22986031], [72.85874939, 22.22986031], [72.85874939, 22.22958183], [72.85902405, 22.22958374], [72.85902405, 22.22930527], [72.85930634, 22.2293129], [72.85930634, 22.22903061], [72.85986328, 22.22903061], [72.85986328, 22.22875023], [72.86042023, 22.22875023], [72.86042023, 22.22820282], [72.86067963, 22.22820282], [72.86067963, 22.22792053], [72.86125183, 22.22792053], [72.86125183, 22.22764015], [72.86152649, 22.22764015], [72.86152649, 22.22736168], [72.86180878, 22.22736168], [72.86180878, 22.22708321], [72.86208344, 22.22708321], [72.86208344, 22.22680473], [72.86235809, 22.22680473], [72.86235809, 22.22652817], [72.86264038, 22.22653008], [72.86264038, 22.2262516], [72.86292267, 22.2262516], [72.86291504, 22.22597313], [72.86402893, 22.22597313], [72.86402893, 22.22569466], [72.86513519, 22.22569466], [72.86513519, 22.22541618], [72.86569214, 22.22541809], [72.86569214, 22.22513962], [72.86653137, 22.22513962], [72.86653137, 22.22485924], [72.86708069, 22.22485924], [72.86708069, 22.22458076], [72.86846924, 22.22458267], [72.86846924, 22.22430611], [72.86875153, 22.22430992], [72.86875153, 22.22375107], [72.86958313, 22.22375107], [72.86958313, 22.22347069], [72.8720932, 22.22347069], [72.8720932, 22.22375107], [72.87391663, 22.22374725], [72.8779068, 22.22375107], [72.8779068, 22.22430992], [72.87847137, 22.22430611], [72.87847137, 22.22458267], [72.87930298, 22.22458076], [72.87930298, 22.22485924], [72.87985992, 22.22485924], [72.87985992, 22.22513962], [72.88054657, 22.22513962], [72.88069153, 22.22513962], [72.88069153, 22.22525978], [72.88069153, 22.22541809], [72.88083649, 22.22541809], [72.88097382, 22.22541618], [72.88097382, 22.22554016], [72.88097382, 22.22569466], [72.88124847, 22.22569466], [72.88124847, 22.22597313], [72.88153076, 22.22596931], [72.88153076, 22.2262516], [72.88208008, 22.2262516], [72.88208008, 22.22653008], [72.88236237, 22.22652817], [72.88236237, 22.22680473], [72.88263702, 22.22680473], [72.88263702, 22.22708321], [72.88291931, 22.22708321], [72.88291931, 22.22736168], [72.88375092, 22.22736168], [72.88375092, 22.22792053], [72.8840332, 22.22792053], [72.8840332, 22.22820282], [72.88430786, 22.22820282], [72.88430786, 22.22847939], [72.88458252, 22.22847939], [72.88458252, 22.22875023], [72.88513947, 22.22875023], [72.88513947, 22.22903061], [72.88540649, 22.22903061], [72.88540649, 22.2293129], [72.88569641, 22.22930527], [72.88569641, 22.22958374], [72.88597107, 22.22958183], [72.88597107, 22.23014069], [72.88625336, 22.23013878], [72.88625336, 22.23069382], [72.88791656, 22.23069382], [72.88791656, 22.23097229], [72.89041901, 22.23097229], [72.89041901, 22.23069382], [72.89069366, 22.23069382], [72.89069366, 22.23097229], [72.89208221, 22.23097038], [72.89208221, 22.23125076], [72.89347076, 22.23125076], [72.89347076, 22.23152733], [72.8941803, 22.2315464], [72.89430237, 22.23155022], [72.89430237, 22.23180962], [72.89569092, 22.2318058], [72.89569092, 22.23208237], [72.89821625, 22.23208427], [72.89930725, 22.23208427], [72.89930725, 22.23221016], [72.89930725, 22.23236084], [72.89985657, 22.23236084], [72.89985657, 22.23264122], [72.90014648, 22.23264122], [72.90014648, 22.23291969], [72.90097046, 22.23291588], [72.90097046, 22.23347282], [72.9015274, 22.23347092], [72.9015274, 22.23402977], [72.90180206, 22.23402977], [72.90180206, 22.23431015], [72.90235901, 22.23430443], [72.90235901, 22.2345829], [72.9026413, 22.23458099], [72.9026413, 22.23513985], [72.90291595, 22.23513985], [72.90291595, 22.23542023], [72.90319824, 22.23541641], [72.90319824, 22.23624992], [72.9034729, 22.23624992], [72.9034729, 22.2365303], [72.90374756, 22.23652649], [72.90374756, 22.23708344], [72.90402985, 22.23707962], [72.90402985, 22.23765182], [72.90429688, 22.23765182], [72.90429688, 22.23792076], [72.90486145, 22.23791885], [72.90486145, 22.23819351], [72.90513611, 22.2381897], [72.90513611, 22.23875046], [72.9054184, 22.23875046], [72.9054184, 22.23903084], [72.90569305, 22.23903084], [72.90569305, 22.23930931], [72.90597534, 22.2393055], [72.90597534, 22.23985863], [72.90651703, 22.23985863], [72.90651703, 22.24014091], [72.9070816, 22.24014091], [72.9070816, 22.24069405], [72.90763855, 22.24069405], [72.90763855, 22.24097252], [72.90791321, 22.24097252], [72.90791321, 22.2412529], [72.90820313, 22.2412529], [72.90820313, 22.24180984], [72.90847015, 22.24180603], [72.90847015, 22.2420826], [72.90901947, 22.2420826], [72.90901947, 22.24263954], [72.90957642, 22.24263954], [72.90957642, 22.24291992], [72.91014099, 22.24291611], [72.91014099, 22.24319458], [72.91042328, 22.24319267], [72.91042328, 22.24403], [72.91069794, 22.24402809], [72.91069794, 22.24458313], [72.91124725, 22.24458122], [72.91124725, 22.24514008], [72.91152954, 22.24514008], [72.91152954, 22.24542046], [72.9118042, 22.24541664], [72.9118042, 22.24597168], [72.91208649, 22.24597168], [72.91208649, 22.24652863], [72.91236115, 22.246521], [72.91236115, 22.24681091], [72.9126358, 22.24681091], [72.9126358, 22.24736023], [72.91291809, 22.24736023], [72.91291809, 22.24764061], [72.91319275, 22.2476387], [72.91319275, 22.24819374], [72.91347504, 22.24819374], [72.91347504, 22.24847221], [72.91374969, 22.24847031], [72.91374969, 22.24875069], [72.91401672, 22.24875069], [72.91401672, 22.24930954], [72.91430664, 22.24930954], [72.91430664, 22.24986076], [72.9145813, 22.24986076], [72.9145813, 22.25041962], [72.91486359, 22.2504158], [72.91486359, 22.25097275], [72.91514587, 22.25097084], [72.91514587, 22.25152969], [72.9154129, 22.25152969], [72.9154129, 22.25265121], [72.91569519, 22.25264168], [72.91569519, 22.25319481], [72.91596985, 22.25319481], [72.91596985, 22.25346947], [72.91625214, 22.25346947], [72.91625214, 22.25375175], [72.91652679, 22.25375175], [72.91652679, 22.25430489], [72.91680908, 22.25430489], [72.91680908, 22.25458336], [72.91707611, 22.25457954], [72.91707611, 22.25542068], [72.9173584, 22.25542068], [72.9173584, 22.2557106], [72.91764069, 22.2557106], [72.91764069, 22.25625038], [72.91791534, 22.25625038], [72.91791534, 22.25708389], [72.91821289, 22.25708008], [72.91821289, 22.25792122], [72.91847229, 22.2579174], [72.91847229, 22.25847244], [72.91874695, 22.25846291], [72.91874695, 22.25930977], [72.91902924, 22.25930977], [72.91902924, 22.25986099], [72.91930389, 22.25986099], [72.91930389, 22.2606945], [72.91958618, 22.26069069], [72.91958618, 22.26263809], [72.91930389, 22.26263618], [72.91930389, 22.2666111], [72.91930389, 22.2681942], [72.91958618, 22.2681942], [72.91958618, 22.26958275], [72.91929626, 22.26958275], [72.91929626, 22.27042007], [72.91902924, 22.27042007], [72.91902924, 22.27124977], [72.91874695, 22.27124977], [72.91874695, 22.27264023], [72.91847229, 22.27263832], [72.91847229, 22.27347183], [72.91821289, 22.27346992], [72.91821289, 22.27403069], [72.91791534, 22.27402687], [72.91791534, 22.27458382], [72.91764069, 22.27458], [72.91764069, 22.27486038], [72.9173584, 22.27486038], [72.9173584, 22.27542114], [72.91708374, 22.27541542], [72.91708374, 22.27597237], [72.91680908, 22.27597046], [72.91680908, 22.27653122], [72.91652679, 22.27652931], [72.91652679, 22.27708244], [72.91625214, 22.27708054], [72.91625214, 22.27763748], [72.91596985, 22.27763748], [72.91596985, 22.27819443], [72.91513824, 22.27819443], [72.91513824, 22.27791595], [72.9145813, 22.27791977], [72.9145813, 22.27763748], [72.91430664, 22.27763748], [72.91430664, 22.27736092], [72.91401672, 22.27736092], [72.91401672, 22.27708054], [72.91374969, 22.27708244], [72.91374969, 22.27680779], [72.91348267, 22.27681923], [72.91348267, 22.27653122], [72.91319275, 22.27653122], [72.91319275, 22.27597046], [72.91291809, 22.27597237], [72.91291809, 22.27569389], [72.9126358, 22.27569389], [72.9126358, 22.27541542], [72.91236115, 22.27542114], [72.91236115, 22.27514076], [72.91208649, 22.27514076], [72.91208649, 22.27292061], [72.91236115, 22.27292061], [72.91236115, 22.26931], [72.91208649, 22.26931], [72.91208649, 22.2670784], [72.9118042, 22.26708412], [72.9118042, 22.26625061], [72.91152954, 22.26625061], [72.91152954, 22.26614952], [72.91152954, 22.2654171], [72.91124725, 22.26542091], [72.91124725, 22.26458931], [72.9109726, 22.26458931], [72.9109726, 22.26374817], [72.91069794, 22.26374817], [72.91069794, 22.26263809], [72.91042328, 22.26263809], [72.91042328, 22.2618103], [72.91014099, 22.2618103], [72.91014099, 22.26097107], [72.9098587, 22.26097298], [72.9098587, 22.26013947], [72.90957642, 22.26013947], [72.90957642, 22.25930977], [72.90930176, 22.25930977], [72.90930176, 22.25875092], [72.90901947, 22.25875092], [72.90901947, 22.25846291], [72.90875244, 22.25847244], [72.90875244, 22.25819206], [72.90847015, 22.25819206], [72.90847015, 22.2579174], [72.90820313, 22.25792122], [72.90820313, 22.25736046], [72.90791321, 22.25736046], [72.90791321, 22.25708008], [72.90763855, 22.25708389], [72.90763855, 22.25680542], [72.90735626, 22.25681114], [72.90735626, 22.25653076], [72.9070816, 22.25653076], [72.9070816, 22.25625038], [72.90680695, 22.25625038], [72.90680695, 22.2557106], [72.90651703, 22.2557106], [72.90651703, 22.25542068], [72.90625, 22.25542068], [72.90625, 22.2551403], [72.90598297, 22.2551403], [72.90598297, 22.25457954], [72.90569305, 22.25458336], [72.90569305, 22.25430489], [72.9054184, 22.25430489], [72.9054184, 22.25402832], [72.90513611, 22.25403023], [72.90513611, 22.25346947], [72.90486145, 22.25346947], [72.90486145, 22.25319481], [72.90458679, 22.25319481], [72.90458679, 22.25291634], [72.90429688, 22.25292015], [72.90429688, 22.25235748], [72.90402985, 22.2523613], [72.90402985, 22.25208282], [72.90374756, 22.25208282], [72.90374756, 22.25180626], [72.9034729, 22.25180817], [72.9034729, 22.25152969], [72.90320587, 22.25152969], [72.90319061, 22.25125122], [72.90291595, 22.25125122], [72.90291595, 22.25097084], [72.9026413, 22.25097275], [72.9026413, 22.25069427], [72.90208435, 22.25069427], [72.90208435, 22.2504158], [72.90180206, 22.25041962], [72.90180206, 22.25014114], [72.9015274, 22.25014114], [72.9015274, 22.24986076], [72.90125275, 22.24986076], [72.90125275, 22.24958992], [72.90097046, 22.24958992], [72.90097046, 22.24930954], [72.9006958, 22.24930954], [72.9006958, 22.24903107], [72.90014648, 22.24903107], [72.90014648, 22.24875069], [72.89958191, 22.24875069], [72.89958191, 22.24847031], [72.89930725, 22.24847221], [72.89930725, 22.24819374], [72.89875031, 22.24819374], [72.89875031, 22.24791527], [72.89819336, 22.24792099], [72.89819336, 22.24764061], [72.89763641, 22.24764061], [72.89763641, 22.24736023], [72.89707947, 22.24736023], [72.89707947, 22.24707985], [72.89653015, 22.24708366], [72.89653015, 22.24680519], [72.89624786, 22.24681091], [72.89624786, 22.246521], [72.89569092, 22.24652863], [72.89569092, 22.24625015], [72.8951416, 22.24625015], [72.8951416, 22.24596977], [72.89458466, 22.24597168], [72.89458466, 22.24569321], [72.89375305, 22.24570084], [72.89375305, 22.24542046], [72.89290619, 22.24542046], [72.89290619, 22.24514008], [72.89180756, 22.24514008], [72.89180756, 22.2448597], [72.89097595, 22.2448616], [72.89097595, 22.24458313], [72.89013672, 22.24458313], [72.89013672, 22.24430466], [72.88930511, 22.24430466], [72.88930511, 22.24402809], [72.88819122, 22.24403], [72.88819122, 22.24374962], [72.88625336, 22.24374962], [72.88625336, 22.24346161], [72.88541412, 22.24347115], [72.88541412, 22.24319458], [72.88486481, 22.24319458], [72.88486481, 22.24291611], [72.8840332, 22.24291992], [72.8840332, 22.24263954], [72.88346863, 22.24263954], [72.88346863, 22.24236107], [72.87264252, 22.24236107], [72.87264252, 22.24263954], [72.86680603, 22.24263954], [72.86680603, 22.24291992], [72.86597443, 22.24291611], [72.86597443, 22.24319458], [72.86569214, 22.24319458], [72.86569214, 22.24347115], [72.86514282, 22.24346161], [72.86514282, 22.24403], [72.86458588, 22.24402809], [72.86458588, 22.24430466], [72.86430359, 22.24430466], [72.86430359, 22.2448616], [72.86403656, 22.2448597], [72.86403656, 22.24542046], [72.86374664, 22.24542046], [72.86374664, 22.24625015], [72.86347198, 22.24625015], [72.86347198, 22.24652863], [72.86319733, 22.246521], [72.86319733, 22.24764061], [72.86291504, 22.2476387], [72.86291504, 22.24819374], [72.86264038, 22.24818993], [72.86264038, 22.24903107], [72.86235809, 22.24903107], [72.86235809, 22.24930954], [72.86207581, 22.24930954], [72.86207581, 22.25014114], [72.86152649, 22.25014114], [72.86152649, 22.25041962], [72.86125183, 22.2504158], [72.86125183, 22.25069427], [72.86096954, 22.25069427], [72.86096954, 22.25097275], [72.86067963, 22.25097084], [72.86067963, 22.25152969], [72.86042023, 22.25152969], [72.86042023, 22.25208282], [72.86013794, 22.25208282], [72.86013794, 22.2523613], [72.85958099, 22.25235748], [72.85958099, 22.25403023], [72.85930634, 22.25402832], [72.85930634, 22.25458336], [72.85901642, 22.25457954], [72.85901642, 22.25542068], [72.85874939, 22.25542068], [72.85874939, 22.25625038], [72.8584671, 22.25625038], [72.8584671, 22.25681114], [72.85819244, 22.25681114], [72.85819244, 22.25764084], [72.85791779, 22.25763893], [72.85791779, 22.25819206], [72.8576355, 22.25819206], [72.8576355, 22.25958252], [72.85736084, 22.25958061], [72.85736084, 22.26041985], [72.85708618, 22.26041985], [72.85708618, 22.26152992], [72.85679626, 22.26152992], [72.85679626, 22.2618103], [72.85652924, 22.2618103], [72.85652924, 22.26292038], [72.85624695, 22.26291847], [72.85624695, 22.2634716], [72.85597229, 22.2634697], [72.85597229, 22.26431084], [72.85569763, 22.26431084], [72.85569763, 22.26680946], [72.85542297, 22.26680946], [72.85542297, 22.26875114], [72.85514069, 22.26874924], [72.85514069, 22.27069473], [72.8548584, 22.27069473], [72.8548584, 22.27180481], [72.85514069, 22.2718029], [72.85514069, 22.27264023], [72.8548584, 22.27263832], [72.8548584, 22.27297974], [72.85486603, 22.27431107], [72.85458374, 22.27430534], [72.85458374, 22.27569389], [72.85430908, 22.27569008], [72.85430908, 22.27736092], [72.85402679, 22.27736092], [72.85402679, 22.27819443], [72.85375214, 22.27819061], [72.85375214, 22.27902985], [72.85346985, 22.27902985], [72.85346985, 22.27939987], [72.85346985, 22.27959251], [72.85320282, 22.27959251], [72.85320282, 22.2804203], [72.8529129, 22.2804203], [72.8529129, 22.28125191], [72.85263824, 22.28125191], [72.85263824, 22.28181267], [72.85041809, 22.28180504], [72.85041809, 22.28208351], [72.8484726, 22.28208351], [72.8484726, 22.28236389], [72.84375, 22.28236389], [72.84375, 22.28208351], [72.84319305, 22.28208351], [72.84319305, 22.28180504], [72.84263611, 22.28181267], [72.84263611, 22.28153038], [72.84179688, 22.28153038], [72.84179688, 22.28125191], [72.84124756, 22.28125191], [72.84124756, 22.28097153], [72.84069824, 22.28097153], [72.84069061, 22.28069496], [72.8401413, 22.28070259], [72.8401413, 22.2804203], [72.83957672, 22.2804203], [72.83957672, 22.28014183], [72.83875275, 22.28014183], [72.83875275, 22.27986145], [72.8381958, 22.27986145], [72.8381958, 22.27958298], [72.83763885, 22.27959251], [72.83763885, 22.27931023], [72.83735657, 22.27931023], [72.83735657, 22.27902985], [72.83679962, 22.27902985], [72.83679962, 22.27874756], [72.83651733, 22.27874756], [72.83651733, 22.27846909], [72.83597565, 22.2784729], [72.83597565, 22.27819443], [72.83513641, 22.27819443], [72.83513641, 22.27791595], [72.83486176, 22.27791977], [72.83486176, 22.27763748], [72.8345871, 22.27763748], [72.8345871, 22.27736092], [72.83403015, 22.27736092], [72.83403015, 22.27708054], [72.83347321, 22.27708244], [72.83347321, 22.27680779], [72.83319092, 22.27681923], [72.83319092, 22.27653122], [72.8326416, 22.27653122], [72.8326416, 22.27625084], [72.83235931, 22.27625084], [72.83235931, 22.27597046], [72.83208466, 22.27597237], [72.83208466, 22.27569389], [72.83180237, 22.27569389], [72.83180237, 22.27541542], [72.83125305, 22.27542114], [72.83125305, 22.27514076], [72.83097076, 22.27514076], [72.83097076, 22.27486038], [72.83069611, 22.27486038], [72.83069611, 22.27458], [72.83013916, 22.27458382], [72.83013916, 22.27430534], [72.82985687, 22.27431107], [72.82985687, 22.27403069], [72.82930756, 22.27403069], [72.82930756, 22.27375031], [72.82875061, 22.27375031], [72.82875061, 22.27346992], [72.82819366, 22.27347183], [72.82819366, 22.27319336], [72.82763672, 22.27320099], [72.82763672, 22.27292061], [72.82736206, 22.27292061], [72.82736206, 22.27264023], [72.82681274, 22.27264023], [72.82681274, 22.27235985], [72.82624817, 22.27236176], [72.82624817, 22.27208328], [72.82569122, 22.27208328], [72.82569122, 22.27180481], [72.82514191, 22.27180481], [72.82514191, 22.27152824], [72.82457733, 22.27153015], [72.82457733, 22.27124977], [72.82402802, 22.27124977], [72.82402802, 22.27096939], [72.82319641, 22.2709713], [72.82319641, 22.27069473], [72.82263947, 22.27069473], [72.82263947, 22.27041626], [72.82180023, 22.27042007], [72.82180023, 22.27013969], [72.82125092, 22.27013969], [72.82125092, 22.26986122], [72.82041931, 22.26986122], [72.82041931, 22.26958275], [72.81986237, 22.26958275], [72.81986237, 22.26930618], [72.81903076, 22.26931], [72.81903076, 22.26902962], [72.81819153, 22.26902962], [72.81819153, 22.26875114], [72.81735992, 22.26875114], [72.81735992, 22.26847267], [72.81708527, 22.26847267], [72.81708527, 22.2681942], [72.81625366, 22.2681942], [72.81625366, 22.26791763], [72.81569672, 22.26791954], [72.81569672, 22.2676506], [72.81513977, 22.2676506], [72.81513977, 22.26736259], [72.81485748, 22.26736259], [72.81485748, 22.2670784], [72.81458282, 22.26708412], [72.81458282, 22.26680565], [72.81430817, 22.26680946], [72.81430817, 22.26652908], [72.81346893, 22.26652908], [72.81346893, 22.26625061], [72.81263733, 22.26625061], [72.81263733, 22.26596832], [72.81208038, 22.26597214], [72.81208038, 22.26569366], [72.81180573, 22.26569366], [72.81180573, 22.2654171], [72.81124878, 22.26542091], [72.81124878, 22.26514053], [72.81041718, 22.26514053], [72.81041718, 22.26485825], [72.81014252, 22.26486206], [72.81014252, 22.26458359], [72.80986023, 22.26458931], [72.80986023, 22.26431084], [72.8095932, 22.26431084], [72.8095932, 22.26403046], [72.80902863, 22.26403046], [72.80902863, 22.26374817], [72.80874634, 22.26374817], [72.80874634, 22.26320076], [72.80847168, 22.26320076], [72.80847168, 22.26292038], [72.8079071, 22.26292038], [72.8079071, 22.26263809], [72.80764008, 22.26263809], [72.80764008, 22.26208115], [72.80708313, 22.26208305], [72.80708313, 22.26152611], [72.80680084, 22.26152992], [72.80680084, 22.26124954], [72.80652618, 22.26124954], [72.80652618, 22.26097107], [72.80596924, 22.26097298], [72.80596924, 22.2606945], [72.80569458, 22.2606945], [72.80569458, 22.26041412], [72.80430603, 22.26041985], [72.80430603, 22.26013947], [72.8034668, 22.26013947], [72.8034668, 22.25986099], [72.80291748, 22.25986099], [72.80291748, 22.25958061], [72.80236053, 22.25958252], [72.80236053, 22.25930405], [72.80208588, 22.25930977], [72.80208588, 22.25902939], [72.80179596, 22.25902939], [72.80179596, 22.25875092], [72.80152893, 22.25875092], [72.80152893, 22.25846291], [72.80097198, 22.25847244], [72.80097198, 22.25819206], [72.80069733, 22.25819206], [72.80069733, 22.2579174], [72.79930878, 22.25792122], [72.79930878, 22.25764084], [72.79902649, 22.25764084], [72.79902649, 22.25736046], [72.79875183, 22.25736046], [72.79875183, 22.25681114], [72.79736328, 22.25681114], [72.79736328, 22.25653076], [72.79708099, 22.25653076], [72.79708099, 22.25625038], [72.79680634, 22.25625038], [72.79680634, 22.25597191], [72.79624939, 22.25597382], [72.79624939, 22.25569534], [72.79541779, 22.2557106], [72.79541779, 22.25541687], [72.79532623, 22.25541878], [72.79514313, 22.25542068], [72.79514313, 22.2551403], [72.79486084, 22.2551403], [72.79486084, 22.25457954], [72.79458618, 22.25458336], [72.79458618, 22.25430489], [72.79402924, 22.25430489], [72.79402924, 22.25402832], [72.79292297, 22.25403023], [72.79292297, 22.25375175], [72.79264069, 22.25375175], [72.79264069, 22.25346947], [72.7923584, 22.25346947], [72.7923584, 22.25319481], [72.79208374, 22.25319481], [72.79208374, 22.25291634], [72.79181671, 22.25292015], [72.79181671, 22.25265121], [72.79152679, 22.25265121], [72.79152679, 22.25235748], [72.79125214, 22.2523613], [72.79125214, 22.25208282], [72.79069519, 22.25208282], [72.79069519, 22.25180626], [72.7904129, 22.25180817], [72.7904129, 22.25152969], [72.7895813, 22.25152969], [72.7895813, 22.25125122], [72.78930664, 22.25125122], [72.78930664, 22.25097084], [72.78902435, 22.25097275], [72.78902435, 22.25069427], [72.78847504, 22.25069427], [72.78847504, 22.2504158], [72.78819275, 22.25041962], [72.78819275, 22.24986076], [72.78791809, 22.24986076], [72.78791809, 22.24958992], [72.7876358, 22.24958992], [72.7876358, 22.24930954], [72.78708649, 22.24930954], [72.78708649, 22.24875069], [72.78679657, 22.24875069], [72.78679657, 22.24847031], [72.78624725, 22.24847221], [72.78624725, 22.24819374], [72.7859726, 22.24819374], [72.7859726, 22.24791527], [72.78569031, 22.24792099], [72.78569031, 22.24764061], [72.7848587, 22.24764061], [72.7848587, 22.24736023], [72.78457642, 22.24736023], [72.78457642, 22.24707985], [72.78430176, 22.24708366], [72.78430176, 22.24680519], [72.7840271, 22.24681091], [72.7840271, 22.246521], [72.78347015, 22.24652863], [72.78347015, 22.24625015], [72.7831955, 22.24625015], [72.7831955, 22.24597168], [72.78291321, 22.24597168], [72.78291321, 22.24569321], [72.78263092, 22.24570084], [72.78263092, 22.24542046], [72.78235626, 22.24542046], [72.78235626, 22.2448597], [72.7820816, 22.2448616], [72.7820816, 22.24458313], [72.78152466, 22.24458313], [72.78152466, 22.24430466], [72.78125, 22.24430466], [72.78125, 22.24402809], [72.78069305, 22.24403], [72.78069305, 22.24374962], [72.7804184, 22.24374962], [72.7804184, 22.24346161], [72.77902985, 22.24347115], [72.77902985, 22.24291611], [72.77874756, 22.24291992], [72.77874756, 22.24263954], [72.77791595, 22.24263954], [72.77791595, 22.24236107], [72.7776413, 22.24236107], [72.7776413, 22.2420826], [72.77708435, 22.2420826], [72.77708435, 22.24180603], [72.77680206, 22.24180984], [72.77680206, 22.24152946], [72.77625275, 22.24152946], [72.77625275, 22.2412529], [72.77597046, 22.2412529], [72.77597046, 22.24097252], [72.77513885, 22.24097252], [72.77513885, 22.24069405], [72.77458191, 22.24069405], [72.77458191, 22.24041748], [72.77403259, 22.24041939], [72.77403259, 22.24014091], [72.77375031, 22.24014091], [72.77375031, 22.23985863], [72.77319336, 22.23985863], [72.77319336, 22.23957825], [72.7729187, 22.23958397], [72.7729187, 22.2393055], [72.77236176, 22.23930931], [72.77236176, 22.23903084], [72.7720871, 22.23903084], [72.7720871, 22.23875046], [72.77179718, 22.23875046], [72.77179718, 22.23846817], [72.77153015, 22.23847008], [72.77153015, 22.23819542], [72.77069092, 22.2381897], [72.77069092, 22.23791885], [72.76985931, 22.23792076], [72.76985931, 22.23765182], [72.76957703, 22.23765182], [72.76957703, 22.23735809], [72.76930237, 22.23736191], [72.76930237, 22.23708344], [72.76847076, 22.23708344], [72.76847076, 22.23680496], [72.76790619, 22.23681068], [72.76790619, 22.2365303], [72.76764679, 22.2365303], [72.76764679, 22.23624992], [72.76735687, 22.23624992], [72.76735687, 22.23596954], [72.76708221, 22.23597145], [72.76708221, 22.23569679], [72.76652527, 22.23569679], [72.76652527, 22.23541641], [72.76625061, 22.23542023], [72.76625061, 22.23513985], [72.76597595, 22.23513985], [72.76597595, 22.23485947], [72.76541901, 22.23486137], [72.76541901, 22.2345829], [72.76513672, 22.2345829], [72.76513672, 22.23430443], [72.7645874, 22.23431015], [72.7645874, 22.23402977], [72.76403046, 22.23402977], [72.76403046, 22.23374939], [72.76346588, 22.23374939], [72.76346588, 22.23347092], [72.76319122, 22.23347282], [72.76319122, 22.23319435], [72.76264191, 22.23319435], [72.76264191, 22.23291588], [72.76209259, 22.23291969], [72.76209259, 22.23264122], [72.76152039, 22.23264122], [72.76152039, 22.23236084], [72.76069641, 22.23236084], [72.76069641, 22.23208046], [72.76013947, 22.23208427], [72.76013947, 22.2318058], [72.75930786, 22.23180962], [72.75930786, 22.2315197], [72.75736237, 22.23152733], [72.75736237, 22.23125076], [72.75596619, 22.23125076], [72.75596619, 22.23097038], [72.75208282, 22.23097038], [72.75208282, 22.23125076], [72.75096893, 22.23125076], [72.75096893, 22.23152733], [72.74958038, 22.2315197], [72.74958038, 22.23180962], [72.74930573, 22.2318058], [72.74930573, 22.23208427], [72.74736023, 22.23208046], [72.74736023, 22.23236084], [72.74402618, 22.23236084], [72.74402618, 22.23208046], [72.74375153, 22.23208046], [72.74375153, 22.23236084], [72.74291992, 22.23236084], [72.74291992, 22.23264122], [72.74153137, 22.23264122], [72.74153137, 22.23291969], [72.74124908, 22.23291969], [72.74124908, 22.23264122], [72.74069214, 22.23264122], [72.74069214, 22.23291969], [72.73986053, 22.23291588], [72.73986053, 22.23319435], [72.73902893, 22.23319435], [72.73902893, 22.23347282], [72.73735809, 22.23347092], [72.73735809, 22.23374939], [72.73625183, 22.23374939], [72.73625183, 22.23402977], [72.73513794, 22.23402977], [72.73513794, 22.23431015], [72.7326355, 22.23430443], [72.7326355, 22.2345829], [72.7298584, 22.2345829], [72.7298584, 22.23486137], [72.72902679, 22.23486137], [72.72902679, 22.2345829], [72.72875214, 22.2345829], [72.72875214, 22.23486137], [72.72735596, 22.23485947], [72.72735596, 22.23513985], [72.72680664, 22.23513985], [72.72680664, 22.23485947], [72.72624969, 22.23485947], [72.72624969, 22.23513985], [72.72458649, 22.23513985], [72.72458649, 22.23542023], [72.72208405, 22.23541641], [72.72208405, 22.23569679], [72.72041321, 22.23569679], [72.72041321, 22.23597145], [72.71847534, 22.23597145], [72.71848297, 22.23624992], [72.71457672, 22.23624992], [72.71457672, 22.2365303], [72.71180725, 22.2365303], [72.71180725, 22.23681068], [72.71153259, 22.23681068], [72.71153259, 22.2365303], [72.70903015, 22.2365303], [72.70903015, 22.23681068], [72.69625092, 22.23680496], [72.69625092, 22.23708344], [72.69152832, 22.23708344], [72.69152832, 22.23736191], [72.69097137, 22.23735809], [72.69097137, 22.23765182], [72.69013977, 22.23765182], [72.69013977, 22.23792076], [72.68930817, 22.23791885], [72.68930817, 22.2381897], [72.68875122, 22.23819542], [72.68875122, 22.23847008], [72.68791962, 22.23846817], [72.68791962, 22.23875046], [72.68763733, 22.23875046], [72.68763733, 22.23903084], [72.68736267, 22.23903084], [72.68736267, 22.23930931], [72.68708038, 22.2393055], [72.68708038, 22.23958397], [72.68680573, 22.23958397], [72.68681335, 22.23985863], [72.68653107, 22.23985863], [72.68653107, 22.24014091], [72.68624878, 22.24014091], [72.68624878, 22.24069405], [72.68597412, 22.24069405], [72.68597412, 22.24097252], [72.68569183, 22.24097252], [72.68569183, 22.2412529], [72.68541718, 22.2412529], [72.68541718, 22.24152946], [72.68514252, 22.24152946], [72.68514252, 22.24180984], [72.68486023, 22.24180603], [72.68486023, 22.2420826], [72.68458557, 22.2420826], [72.6845932, 22.24236107], [72.68430328, 22.24236107], [72.68430328, 22.24291992], [72.68402863, 22.24291611], [72.68402863, 22.24319458], [72.68374634, 22.24319267], [72.68374634, 22.24374962], [72.68347168, 22.24374962], [72.68347168, 22.24430466], [72.68319702, 22.24430466], [72.68319702, 22.2448616], [72.68235779, 22.2448597], [72.68235779, 22.24514008], [72.68208313, 22.24514008], [72.68208313, 22.24542046], [72.68180847, 22.24542046], [72.68180847, 22.24570084], [72.68152618, 22.24570084], [72.68152618, 22.24625015], [72.68125153, 22.24625015], [72.68125153, 22.24652863], [72.68096924, 22.246521], [72.68096924, 22.24681091], [72.68069458, 22.24680519], [72.68069458, 22.24708366], [72.68013763, 22.24707985], [72.68013763, 22.24736023], [72.67986298, 22.24736023], [72.67986298, 22.24764061], [72.67958069, 22.24764061], [72.67958069, 22.24792099], [72.67903137, 22.24791527], [72.67903137, 22.24819374], [72.67874908, 22.24819374], [72.67874908, 22.24847221], [72.6784668, 22.24847031], [72.6784668, 22.24875069], [72.67819214, 22.24875069], [72.67819214, 22.24903107], [72.67764282, 22.24903107], [72.67764282, 22.24930954], [72.67736816, 22.24930954], [72.67736816, 22.24958992], [72.67708588, 22.24958992], [72.67708588, 22.24986076], [72.67679596, 22.24986076], [72.67679596, 22.25014114], [72.67652893, 22.25014114], [72.67652893, 22.25041962], [72.67514038, 22.2504158], [72.67514038, 22.25069427], [72.67485809, 22.25069046], [72.67485809, 22.25125122], [72.67457581, 22.25125122], [72.67457581, 22.25152969], [72.67430115, 22.25152969], [72.67430115, 22.25180817], [72.67346954, 22.25180626], [72.67346954, 22.25208282], [72.67318726, 22.25208092], [72.67318726, 22.25265121], [72.67292023, 22.25265121], [72.67292023, 22.25292015], [72.67263794, 22.25291634], [72.67263794, 22.25319481], [72.67236328, 22.25319481], [72.67236328, 22.25346947], [72.67208099, 22.25346947], [72.67208099, 22.25403023], [72.67180634, 22.25402832], [72.67180634, 22.25430489], [72.67152405, 22.25430489], [72.67152405, 22.25458336], [72.67124939, 22.25458336], [72.67124939, 22.25486183], [72.67069244, 22.25486183], [72.67069244, 22.25542068], [72.67041779, 22.25541687], [72.67041779, 22.25597382], [72.67014313, 22.25597191], [72.67014313, 22.25653076], [72.66986084, 22.25653076], [72.66986084, 22.25681114], [72.66958618, 22.25680542], [72.66958618, 22.25708389], [72.66902924, 22.25708008], [72.66902924, 22.25764084], [72.66874695, 22.25764084], [72.66874695, 22.25792122], [72.66847229, 22.2579174], [72.66847229, 22.25819206], [72.66819763, 22.25819206], [72.66819763, 22.25847244], [72.66791534, 22.25847244], [72.66792297, 22.25875092], [72.66764069, 22.25875092], [72.66764069, 22.25902939], [72.6673584, 22.25902939], [72.6673584, 22.25930977], [72.66708374, 22.25930405], [72.66708374, 22.25958252], [72.66680908, 22.25958061], [72.66680908, 22.26013947], [72.66652679, 22.26013947], [72.66652679, 22.26041985], [72.66625214, 22.26041412], [72.66625214, 22.2606945], [72.66569519, 22.2606945], [72.66569519, 22.26097298], [72.6654129, 22.26097107], [72.6654129, 22.26124954], [72.66513824, 22.26124954], [72.66513824, 22.2618103], [72.66486359, 22.2618084], [72.66486359, 22.26236153], [72.6645813, 22.26235962], [72.6645813, 22.26292038], [72.66430664, 22.26292038], [72.66430664, 22.26320076], [72.66401672, 22.26320076], [72.66401672, 22.26374817], [72.66374969, 22.26374817], [72.66374969, 22.26403046], [72.66348267, 22.26403046], [72.66348267, 22.26431084], [72.66291809, 22.26431084], [72.66291809, 22.26458931], [72.6626358, 22.26458359], [72.6626358, 22.26486206], [72.66236115, 22.26485825], [72.66236115, 22.26514053], [72.66208649, 22.26514053], [72.66208649, 22.26542091], [72.6618042, 22.2654171], [72.6618042, 22.26597214], [72.66152954, 22.26596832], [72.66152954, 22.26625061], [72.6609726, 22.26625061], [72.6609726, 22.26680946], [72.66041565, 22.26680565], [72.66042328, 22.26736259], [72.66014099, 22.26736259], [72.66014099, 22.2676506], [72.6598587, 22.26763916], [72.6598587, 22.2681942], [72.65930939, 22.2681942], [72.65930176, 22.26847267], [72.6590271, 22.26847267], [72.6590271, 22.26875114], [72.65875244, 22.26875114], [72.65875244, 22.26931], [72.65847015, 22.26931], [72.65847015, 22.26986122], [72.65820313, 22.26986122], [72.65820313, 22.27403069], [72.65847015, 22.27403069], [72.65847015, 22.27431107], [72.65820313, 22.27431107], [72.65820313, 22.27542114], [72.65791321, 22.27541542], [72.65791321, 22.27569389], [72.6581955, 22.27569389], [72.6581955, 22.27597237], [72.65791321, 22.27597046], [72.65791321, 22.27653122], [72.65763855, 22.27653122], [72.65763855, 22.27681923], [72.65735626, 22.27681923], [72.65735626, 22.27736092], [72.6570816, 22.27736092], [72.6570816, 22.27791977], [72.65680695, 22.27791595], [72.65680695, 22.27819443], [72.65651703, 22.27819061], [72.65652466, 22.27874756], [72.65625763, 22.27874756], [72.65625763, 22.27902985], [72.65569305, 22.27902985], [72.65569305, 22.27931023], [72.65513611, 22.27931023], [72.65513611, 22.27959251], [72.65458679, 22.27958298], [72.65458679, 22.27986145], [72.65402985, 22.27986145], [72.65402985, 22.28014183], [72.65291595, 22.28014183], [72.65291595, 22.2804203], [72.65180206, 22.2804203], [72.65180206, 22.28070259], [72.65097046, 22.28069496], [72.65097046, 22.28097153], [72.64985657, 22.28097153], [72.6498642, 22.28125191], [72.64903259, 22.28125191], [72.64903259, 22.28153038], [72.6479187, 22.28153038], [72.6479187, 22.28181267], [72.64736176, 22.28180504], [72.64736176, 22.28208351], [72.64541626, 22.28208351], [72.64541626, 22.28236389], [72.64375305, 22.28236389], [72.64375305, 22.28263855], [72.64263916, 22.28263283], [72.64263916, 22.28292084], [72.6423645, 22.28291702], [72.6423645, 22.28319359], [72.64214325, 22.28319359], [72.64152527, 22.28319359], [72.64152527, 22.28347206], [72.64097595, 22.28347206], [72.64097595, 22.28335953], [72.64097595, 22.28319359], [72.64041901, 22.28319359], [72.64041901, 22.28347206], [72.64025879, 22.28347206], [72.63930511, 22.28347206], [72.63930511, 22.28360939], [72.63931274, 22.28375053], [72.63874817, 22.28375053], [72.63874817, 22.28403091], [72.63709259, 22.28403091], [72.63709259, 22.28430939], [72.63541412, 22.28430557], [72.63541412, 22.28458214], [72.63430786, 22.28458214], [72.63430786, 22.28430557], [72.63291931, 22.28430557], [72.63291931, 22.28458214], [72.63153076, 22.28458214], [72.63153076, 22.28430557], [72.62985992, 22.28430939], [72.62985992, 22.28403091], [72.62763977, 22.28403091], [72.62763977, 22.28375053], [72.62708282, 22.28375053], [72.62708282, 22.28347015], [72.62652588, 22.28347206], [72.62652588, 22.28319359], [72.62513733, 22.28319359], [72.62513733, 22.28291702], [72.62374878, 22.28292084], [72.62374878, 22.28263283], [72.62319183, 22.28263855], [72.62319183, 22.28236389], [72.62236023, 22.28236389], [72.62236023, 22.28208351], [72.62152863, 22.28208351], [72.62152863, 22.28180504], [72.62069702, 22.28181267], [72.62069702, 22.28153038], [72.61985779, 22.28153038], [72.61985779, 22.28125191], [72.61902618, 22.28125191], [72.61902618, 22.28097153], [72.61736298, 22.28097153], [72.61736298, 22.28069496], [72.61569214, 22.28070259], [72.61569214, 22.2804203], [72.61402893, 22.2804203], [72.61402893, 22.28014183], [72.61292267, 22.28014183], [72.61292267, 22.2804203], [72.61264038, 22.2804203], [72.61264038, 22.28014183], [72.61207581, 22.28014183], [72.61207581, 22.27986145], [72.61042023, 22.27986145], [72.61042023, 22.27958298], [72.60986328, 22.27959251], [72.60986328, 22.27931023], [72.6084671, 22.27931023], [72.6084671, 22.27902985], [72.60764313, 22.27902985], [72.60764313, 22.27874756], [72.60736084, 22.27874756], [72.60736084, 22.27846909], [72.60680389, 22.2784729], [72.60680389, 22.27819443], [72.60624695, 22.27819443], [72.60624695, 22.27791595], [72.60597229, 22.27791977], [72.60597229, 22.27763748], [72.60541534, 22.27763748], [72.60541534, 22.27736092], [72.6048584, 22.27736092], [72.6048584, 22.27708054], [72.60430908, 22.27708244], [72.60430908, 22.27680779], [72.60375214, 22.27681923], [72.60375214, 22.27653122], [72.60346985, 22.27653122], [72.60346985, 22.27625084], [72.60319519, 22.27625084], [72.60319519, 22.27597237], [72.6029129, 22.27597237], [72.6029129, 22.27569389], [72.60236359, 22.27569389], [72.60236359, 22.27513885], [72.60151672, 22.27514076], [72.60151672, 22.27486038], [72.6001358, 22.27486038], [72.6001358, 22.27458], [72.5993042, 22.27458382], [72.5993042, 22.27430534], [72.5984726, 22.27431107], [72.5984726, 22.27403069], [72.5973587, 22.27403069], [72.5973587, 22.27375031], [72.5965271, 22.27375031], [72.5965271, 22.27346992], [72.59597015, 22.27347183], [72.59597015, 22.27319336], [72.59570313, 22.27320099], [72.59570313, 22.27292061], [72.59541321, 22.27292061], [72.59541321, 22.27264023], [72.59485626, 22.27264023], [72.59485626, 22.27235985], [72.5945816, 22.27236176], [72.5945816, 22.27208328], [72.59402466, 22.27208328], [72.59402466, 22.27180481], [72.59347534, 22.27180481], [72.59347534, 22.27152824], [72.59319305, 22.27153015], [72.59319305, 22.27124977], [72.5929184, 22.27124977], [72.5929184, 22.27096939], [72.59263611, 22.2709713], [72.59263611, 22.27069473], [72.59236145, 22.27069473], [72.59236145, 22.27041626], [72.59208679, 22.27042007], [72.59208679, 22.27013969], [72.59152985, 22.27013969], [72.59152985, 22.26986122], [72.59124756, 22.26986122], [72.59124756, 22.26958275], [72.5909729, 22.26958275], [72.5909729, 22.26902771], [72.59069824, 22.26902962], [72.59069061, 22.26847267], [72.59041595, 22.26847267], [72.59041595, 22.2681942], [72.5901413, 22.2681942], [72.5901413, 22.26791763], [72.58957672, 22.26791954], [72.58957672, 22.2676506], [72.58930206, 22.2676506], [72.58930206, 22.26736259], [72.5890274, 22.26736259], [72.5890274, 22.26680946], [72.58875275, 22.26680946], [72.58875275, 22.26652908], [72.58790588, 22.26652908], [72.58790588, 22.26625061], [72.58735657, 22.26625061], [72.58735657, 22.26596832], [72.58708191, 22.26597214], [72.58708191, 22.26569366], [72.58625031, 22.26569366], [72.58625031, 22.2654171], [72.58598328, 22.26542091], [72.58598328, 22.26514053], [72.5854187, 22.26514053], [72.5854187, 22.26485825], [72.58513641, 22.26486206], [72.58513641, 22.26458359], [72.58486176, 22.26458931], [72.58486176, 22.26403046], [72.5845871, 22.26403046], [72.5845871, 22.26374817], [72.58429718, 22.26374817], [72.58429718, 22.26320076], [72.58402252, 22.26320076], [72.58402252, 22.26292038], [72.58374786, 22.26292038], [72.58374786, 22.26263809], [72.58319092, 22.26263809], [72.58319092, 22.26235962], [72.58291626, 22.26236153], [72.58291626, 22.26208305], [72.5826416, 22.26208305], [72.5826416, 22.2618084], [72.58235931, 22.2618103], [72.58235931, 22.26152992], [72.58180237, 22.26152992], [72.58180237, 22.26124954], [72.58152771, 22.26124954], [72.58152771, 22.26097107], [72.58125305, 22.26097298], [72.58125305, 22.2606945], [72.58097076, 22.2606945], [72.58097076, 22.26041412], [72.58040619, 22.26041985], [72.58040619, 22.26013947], [72.58013916, 22.26013947], [72.58013916, 22.25986099], [72.57958221, 22.25986099], [72.57958221, 22.25958061], [72.57930756, 22.25958252], [72.57930756, 22.25930405], [72.5790329, 22.25930977], [72.5790329, 22.25902939], [72.57847595, 22.25902939], [72.57847595, 22.25846291], [72.57819366, 22.25847244], [72.57819366, 22.25819206], [72.57763672, 22.25819206], [72.57763672, 22.2579174], [72.57736206, 22.25792122], [72.57736206, 22.25764084], [72.57681274, 22.25764084], [72.57681274, 22.25736046], [72.57653046, 22.25736046], [72.57653046, 22.25708008], [72.57624817, 22.25708389], [72.57624817, 22.25680542], [72.57596588, 22.25681114], [72.57596588, 22.25653076], [72.57541656, 22.25653076], [72.57541656, 22.25625038], [72.57514191, 22.25625038], [72.57514191, 22.25597191], [72.57485962, 22.25597382], [72.57485962, 22.25569534], [72.57459259, 22.2557106], [72.57459259, 22.25542068], [72.57402802, 22.25542068], [72.57402802, 22.2551403], [72.57347107, 22.2551403], [72.57347107, 22.25486183], [72.57319641, 22.25486183], [72.57319641, 22.25458336], [72.57125092, 22.25458336], [72.57125092, 22.25486183], [72.57096863, 22.25486183], [72.57096863, 22.25681114], [72.57125092, 22.25681114], [72.57125092, 22.25764084], [72.57096863, 22.25764084], [72.57096863, 22.25792122], [72.57068634, 22.25792122], [72.57068634, 22.25764084], [72.57041931, 22.25764084], [72.57041931, 22.25597191], [72.57013702, 22.25597382], [72.57013702, 22.25541687], [72.56958008, 22.25542068], [72.56958008, 22.2551403], [72.56846619, 22.2551403], [72.56846619, 22.25486183], [72.56819153, 22.25486183], [72.56819153, 22.25458336], [72.56764221, 22.25458336], [72.56764221, 22.25430489], [72.56735992, 22.25430489], [72.56735992, 22.25402832], [72.56680298, 22.25403023], [72.56680298, 22.25375175], [72.56652832, 22.25375175], [72.56652832, 22.25346947], [72.56625366, 22.25346947], [72.56625366, 22.25319481], [72.56597137, 22.25319481], [72.56597137, 22.25291634], [72.56569672, 22.25292015], [72.56569672, 22.25180817], [72.5654068, 22.25180817], [72.5654068, 22.25152969], [72.56458282, 22.25152969], [72.56458282, 22.25125122], [72.56430817, 22.25125122], [72.56430817, 22.25069046], [72.56402588, 22.25069427], [72.56402588, 22.25013733], [72.56375122, 22.25014114], [72.56375122, 22.24986076], [72.56346893, 22.24986076], [72.56346893, 22.24958992], [72.56318665, 22.24958992], [72.56318665, 22.24930954], [72.56236267, 22.24930954], [72.56236267, 22.24903107], [72.56208038, 22.24903107], [72.56208038, 22.24875069], [72.56180573, 22.24875069], [72.56180573, 22.24847221], [72.56153107, 22.24847221], [72.56153107, 22.24819374], [72.56124878, 22.24819374], [72.56124878, 22.2476387], [72.56096649, 22.24764061], [72.56096649, 22.24681091], [72.56041718, 22.24681091], [72.56041718, 22.246521], [72.56014252, 22.24652863], [72.56014252, 22.24625015], [72.5598526, 22.24625015], [72.5598526, 22.24596977], [72.55958557, 22.24597168], [72.55958557, 22.24875069], [72.5598526, 22.24875069], [72.5598526, 22.24930954], [72.56014252, 22.24930954], [72.56014252, 22.24958992], [72.56096649, 22.24958992], [72.56096649, 22.25152969], [72.56069183, 22.25152969], [72.56069183, 22.25346947], [72.56096649, 22.25346947], [72.56096649, 22.25625038], [72.56124878, 22.25625038], [72.56124878, 22.25653076], [72.56153107, 22.25653076], [72.56153107, 22.25764084], [72.56124878, 22.25763893], [72.56124878, 22.25847244], [72.56096649, 22.25846291], [72.56096649, 22.25902939], [72.56014252, 22.25902939], [72.56014252, 22.25930977], [72.55980682, 22.25930405], [72.55735779, 22.25930977], [72.55735779, 22.25877953], [72.55708313, 22.25875092], [72.55708313, 22.25846291], [72.55735779, 22.25847244], [72.55735779, 22.25819206], [72.55708313, 22.25819206], [72.55708313, 22.25708389], [72.55680847, 22.25708389], [72.55680847, 22.25625038], [72.55652618, 22.25625038], [72.55652618, 22.25597191], [72.55625153, 22.25597382], [72.55625153, 22.25541687], [72.55486298, 22.25542068], [72.55486298, 22.2551403], [72.554039, 22.2551403], [72.554039, 22.25542068], [72.55319214, 22.25542068], [72.55319214, 22.2551403], [72.55264282, 22.2551403], [72.55264282, 22.25486183], [72.55236053, 22.25486183], [72.55236053, 22.25402832], [72.55179596, 22.25403023], [72.55179596, 22.25292015], [72.55152893, 22.25292015], [72.55152893, 22.25265121], [72.55097198, 22.25265121], [72.55097198, 22.25235748], [72.55014038, 22.2523613], [72.55014038, 22.25208282], [72.54985809, 22.25208282], [72.54985809, 22.2504158], [72.54957581, 22.25041962], [72.54957581, 22.25014114], [72.54930878, 22.25014114], [72.54930878, 22.24986076], [72.54902649, 22.24986076], [72.54902649, 22.24958992], [72.54875183, 22.24958992], [72.54875183, 22.24930954], [72.54846954, 22.24930954], [72.54846954, 22.24903107], [72.5479126, 22.24903107], [72.5479126, 22.24875069], [72.54763794, 22.24875069], [72.54763794, 22.24847031], [72.54736328, 22.24847221], [72.54736328, 22.24819374], [72.54680634, 22.24819374], [72.54680634, 22.24791527], [72.54651642, 22.24792099], [72.54651642, 22.24764061], [72.54624939, 22.24764061], [72.54624939, 22.24707985], [72.54597473, 22.24708366], [72.54597473, 22.24569321], [72.54541779, 22.24570084], [72.54541779, 22.24514008], [72.54514313, 22.24514008], [72.54514313, 22.24458122], [72.54486084, 22.24458313], [72.54486084, 22.24402809], [72.54458618, 22.24403], [72.54458618, 22.24374962], [72.54347229, 22.24374962], [72.54347229, 22.24346161], [72.54264069, 22.24347115], [72.54264069, 22.24319458], [72.54125214, 22.24319458], [72.54125214, 22.24347115], [72.54096985, 22.24346161], [72.54096985, 22.24374962], [72.54069519, 22.24374962], [72.54069519, 22.2448616], [72.54096985, 22.2448597], [72.54096985, 22.24542046], [72.54125214, 22.24541664], [72.54125214, 22.24597168], [72.54152679, 22.24597168], [72.54152679, 22.24652863], [72.54180908, 22.246521], [72.54180908, 22.24875069], [72.54125214, 22.24875069], [72.54125214, 22.24847031], [72.54069519, 22.24847221], [72.54069519, 22.24819374], [72.5404129, 22.24819374], [72.5404129, 22.24791527], [72.53985596, 22.24792099], [72.53985596, 22.24764061], [72.5395813, 22.24764061], [72.5395813, 22.24736023], [72.53874207, 22.24736023], [72.53874207, 22.24707985], [72.53847504, 22.24708366], [72.53847504, 22.24680519], [72.53819275, 22.24681091], [72.53819275, 22.246521], [72.53791809, 22.24652863], [72.53791809, 22.24625015], [72.5376358, 22.24625015], [72.5376358, 22.24596977], [72.53736115, 22.24597168], [72.53736115, 22.24569321], [72.5348587, 22.24569321], [72.5348587, 22.24597168], [72.53430939, 22.24596977], [72.53430176, 22.24625015], [72.53320313, 22.24625015], [72.53320313, 22.24681091], [72.53347015, 22.24681091], [72.53347015, 22.24736023], [72.53375244, 22.24736023], [72.53375244, 22.24792099], [72.5340271, 22.24791527], [72.5340271, 22.24847221], [72.53457642, 22.24847031], [72.53457642, 22.24875069], [72.53514099, 22.24875069], [72.53514099, 22.24903107], [72.53569794, 22.24903107], [72.53569794, 22.24958992], [72.5359726, 22.24958992], [72.5359726, 22.24986076], [72.53624725, 22.24986076], [72.53624725, 22.25014114], [72.53708649, 22.25014114], [72.53708649, 22.25041962], [72.5376358, 22.25041962], [72.5376358, 22.25125122], [72.53708649, 22.25125122], [72.53708649, 22.25152969], [72.53652954, 22.25152969], [72.53652954, 22.25125122], [72.53624725, 22.25125122], [72.53624725, 22.25097084], [72.5359726, 22.25097275], [72.5359726, 22.25069427], [72.53541565, 22.25069427], [72.53541565, 22.2504158], [72.5348587, 22.25041962], [72.5348587, 22.25014114], [72.53375244, 22.25014114], [72.53375244, 22.25041962], [72.53347015, 22.2504158], [72.53347015, 22.25069427], [72.5331955, 22.25069427], [72.5331955, 22.25097275], [72.53291321, 22.25097084], [72.53291321, 22.25180817], [72.5331955, 22.25180626], [72.5331955, 22.25208282], [72.53347015, 22.25208092], [72.53347015, 22.25265121], [72.53375244, 22.25265121], [72.53375244, 22.25292015], [72.5340271, 22.25291634], [72.5340271, 22.25319481], [72.53430176, 22.25319481], [72.53430939, 22.25346947], [72.53457642, 22.25346947], [72.53457642, 22.25375175], [72.5348587, 22.25375175], [72.5348587, 22.25403023], [72.53514099, 22.25402832], [72.53514099, 22.25458336], [72.53542328, 22.25457954], [72.53542328, 22.2551403], [72.5359726, 22.2551403], [72.5359726, 22.25542068], [72.53708649, 22.25542068], [72.53708649, 22.2557106], [72.5376358, 22.2557106], [72.5376358, 22.25542068], [72.53819275, 22.25542068], [72.53819275, 22.25429916], [72.53902435, 22.25430489], [72.53902435, 22.25486183], [72.53930664, 22.25486183], [72.53930664, 22.25542068], [72.5395813, 22.25541687], [72.5395813, 22.25597382], [72.53985596, 22.25597191], [72.53985596, 22.25625038], [72.54013824, 22.25625038], [72.54013824, 22.25681114], [72.5404129, 22.25680542], [72.5404129, 22.25708389], [72.54096985, 22.25708008], [72.54096985, 22.25764084], [72.54070282, 22.25764084], [72.54070282, 22.25792122], [72.5404129, 22.2579174], [72.5404129, 22.25819206], [72.54013824, 22.25819206], [72.54013824, 22.25847244], [72.5395813, 22.25847244], [72.5395813, 22.25819206], [72.53902435, 22.25819206], [72.53902435, 22.2579174], [72.53791809, 22.2579174], [72.53791809, 22.25819206], [72.5376358, 22.25819206], [72.5376358, 22.25847244], [72.53736115, 22.25846291], [72.53736115, 22.25875092], [72.53679657, 22.25875092], [72.53679657, 22.25930977], [72.53652954, 22.25930405], [72.53652954, 22.25958252], [72.5359726, 22.25958061], [72.5359726, 22.26041985], [72.5348587, 22.26041412], [72.5348587, 22.26236153], [72.53514099, 22.26235962], [72.53514099, 22.26292038], [72.5348587, 22.26292038], [72.5348587, 22.26320076], [72.53514099, 22.26320076], [72.53514099, 22.26374817], [72.53542328, 22.26374817], [72.53542328, 22.26431084], [72.53569794, 22.26431084], [72.53569794, 22.26458931], [72.5359726, 22.26458931], [72.5359726, 22.26514053], [72.53624725, 22.26514053], [72.53624725, 22.26847267], [72.53652954, 22.26847267], [72.53652954, 22.26931], [72.5368042, 22.26930618], [72.5368042, 22.27037811], [72.5368042, 22.27069473], [72.5376358, 22.27069283], [72.5376358, 22.27124977], [72.53736115, 22.27124977], [72.53736115, 22.27180481], [72.53708649, 22.2718029], [72.53708649, 22.27264023], [72.53736115, 22.27264023], [72.53736115, 22.27375031], [72.5376358, 22.27375031], [72.5376358, 22.27431107], [72.53791809, 22.27430534], [72.53791809, 22.27458382], [72.53847504, 22.27458382], [72.53847504, 22.27486038], [72.53874207, 22.27486038], [72.53874207, 22.27514076], [72.54096985, 22.27514076], [72.54096985, 22.27542114], [72.54125214, 22.27542114], [72.54125214, 22.27514076], [72.54374695, 22.27514076], [72.54374695, 22.27542114], [72.54652405, 22.27541542], [72.54652405, 22.27569389], [72.54680634, 22.27569389], [72.54680634, 22.27597237], [72.54846954, 22.27597046], [72.54846954, 22.27625084], [72.54930878, 22.27625084], [72.54930878, 22.27653122], [72.54985809, 22.27653122], [72.54985809, 22.27681923], [72.55041504, 22.27680779], [72.55041504, 22.27708244], [72.55124664, 22.27708054], [72.55124664, 22.27736092], [72.55179596, 22.27736092], [72.55179596, 22.27763748], [72.55236053, 22.27763748], [72.55236053, 22.27791977], [72.55319214, 22.27791595], [72.55319214, 22.27819443], [72.55374908, 22.27819061], [72.55374908, 22.27959251], [72.55347443, 22.27958298], [72.55347443, 22.28097153], [72.55263519, 22.28097153], [72.55263519, 22.28069496], [72.55236053, 22.28070259], [72.55236053, 22.2804203], [72.55042267, 22.2804203], [72.55042267, 22.28070259], [72.54902649, 22.28069496], [72.54902649, 22.28097153], [72.54264069, 22.28097153], [72.54264069, 22.28069496], [72.54125214, 22.28070259], [72.54125214, 22.2804203], [72.53985596, 22.2804203], [72.53985596, 22.28014183], [72.5395813, 22.28014183], [72.5395813, 22.27986145], [72.53930664, 22.27986145], [72.53930664, 22.27958298], [72.53848267, 22.27959251], [72.53848267, 22.27931023], [72.5376358, 22.27931023], [72.5376358, 22.27902985], [72.53708649, 22.27902985], [72.53708649, 22.27874756], [72.53679657, 22.27874756], [72.53679657, 22.27819061], [72.53624725, 22.27819443], [72.53624725, 22.27791595], [72.53569794, 22.27791977], [72.53569794, 22.27763748], [72.53514099, 22.27763748], [72.53514099, 22.27736092], [72.5348587, 22.27736092], [72.5348587, 22.27708054], [72.53457642, 22.27708054], [72.53457642, 22.27736092], [72.53430939, 22.27736092], [72.53430176, 22.27763748], [72.5340271, 22.27763748], [72.5340271, 22.27736092], [72.5331955, 22.27736092], [72.5331955, 22.27708244], [72.53263855, 22.27708244], [72.53263855, 22.27652931], [72.53291321, 22.27653122], [72.53291321, 22.27597046], [72.5331955, 22.27597237], [72.5331955, 22.27541542], [72.53291321, 22.27542114], [72.53291321, 22.27486038], [72.53263855, 22.27486038], [72.53263855, 22.27458], [72.53236389, 22.27458382], [72.53236389, 22.27430534], [72.5320816, 22.27431107], [72.5320816, 22.27403069], [72.53180695, 22.27403069], [72.53180695, 22.27375031], [72.53151703, 22.27375031], [72.53151703, 22.27346992], [72.53097534, 22.27347183], [72.53097534, 22.27319336], [72.53070068, 22.27320099], [72.53069305, 22.27292061], [72.5304184, 22.27292061], [72.5304184, 22.27264023], [72.53013611, 22.27264023], [72.53013611, 22.27235985], [72.52986145, 22.27236176], [72.52986145, 22.27208328], [72.52958679, 22.27208328], [72.52958679, 22.27180481], [72.52902985, 22.27180481], [72.52902985, 22.27152824], [72.52874756, 22.27153015], [72.52874756, 22.27124977], [72.5284729, 22.27124977], [72.5284729, 22.27096939], [72.52791595, 22.2709713], [72.52791595, 22.27069473], [72.5276413, 22.27069473], [72.5276413, 22.27041626], [72.52735901, 22.27042007], [72.52735901, 22.26986122], [72.52680206, 22.26986122], [72.52680206, 22.26958275], [72.5265274, 22.26958275], [72.5265274, 22.26930618], [72.52597046, 22.26931], [72.52597046, 22.26847267], [72.52541351, 22.26847267], [72.52541351, 22.26791763], [72.52513885, 22.26791954], [72.52513885, 22.26736259], [72.52485657, 22.26736259], [72.52485657, 22.26680946], [72.52458191, 22.26680946], [72.52458191, 22.26652908], [72.52430725, 22.26652908], [72.52430725, 22.26431084], [72.52403259, 22.26431084], [72.52403259, 22.2634697], [72.52375031, 22.2634716], [72.52375031, 22.26236153], [72.52347565, 22.26236153], [72.52347565, 22.26097298], [72.52375031, 22.26097298], [72.52375031, 22.25958252], [72.52347565, 22.25958252], [72.52347565, 22.25930405], [72.52374268, 22.25930977], [72.52374268, 22.2557106], [72.52403259, 22.2557106], [72.52403259, 22.2551403], [72.52430725, 22.2551403], [72.52430725, 22.25014114], [72.52458191, 22.25014114], [72.52458191, 22.24792099], [72.52430725, 22.24792099], [72.52430725, 22.24542046], [72.52403259, 22.24542046], [72.52403259, 22.2448597], [72.52375031, 22.2448616], [72.52375031, 22.24458313], [72.52347565, 22.24458313], [72.52347565, 22.24430466], [72.52319336, 22.24430466], [72.52319336, 22.24374962], [72.5229187, 22.24374962], [72.5229187, 22.24346161], [72.52263641, 22.24347115], [72.52263641, 22.24319458], [72.52236176, 22.24319458], [72.52236176, 22.24263954], [72.5220871, 22.24263954], [72.5220871, 22.24236107], [72.52179718, 22.24236107], [72.52179718, 22.2420826], [72.52153015, 22.2420826], [72.52153015, 22.24180603], [72.52124786, 22.24180984], [72.52124786, 22.24152946], [72.52097321, 22.24152946], [72.52097321, 22.2412529], [72.52068329, 22.2412529], [72.52068329, 22.24097252], [72.52041626, 22.24097252], [72.52041626, 22.24069405], [72.5201416, 22.24069405], [72.5201416, 22.24041748], [72.51957703, 22.24041939], [72.51957703, 22.24014091], [72.51930237, 22.24014091], [72.51930237, 22.23985863], [72.51902771, 22.23985863], [72.51902771, 22.23957825], [72.51875305, 22.23958397], [72.51875305, 22.2393055], [72.51847076, 22.23930931], [72.51847076, 22.23903084], [72.51819611, 22.23903084], [72.51819611, 22.23875046], [72.51790619, 22.23875046], [72.51790619, 22.23846817], [72.5173645, 22.23847008], [72.5173645, 22.23791885], [72.51708221, 22.23792076], [72.51708221, 22.23735809], [72.51680756, 22.23736191], [72.51680756, 22.23708344], [72.51625061, 22.23708344], [72.51625061, 22.23680496], [72.51597595, 22.23681068], [72.51597595, 22.2365303], [72.51541901, 22.2365303], [72.51541901, 22.23624992], [72.51513672, 22.23624992], [72.51513672, 22.23596954], [72.51457977, 22.23597145], [72.51457977, 22.23569679], [72.51430511, 22.23569679], [72.51430511, 22.23541641], [72.51374817, 22.23542023], [72.51374817, 22.23513985], [72.51291656, 22.23513985], [72.51291656, 22.23458099], [72.51264191, 22.2345829], [72.51264191, 22.23430443], [72.51235962, 22.23431015], [72.51235962, 22.23402977], [72.51180267, 22.23402977], [72.51180267, 22.23374939], [72.51152802, 22.23374939], [72.51152802, 22.23347092], [72.51097107, 22.23347282], [72.51097107, 22.23319435], [72.51069641, 22.23319435], [72.51069641, 22.23291588], [72.51013947, 22.23291969], [72.51013947, 22.23264122], [72.50985718, 22.23264122], [72.50985718, 22.23236084], [72.50958252, 22.23236084], [72.50958252, 22.23208046], [72.50875092, 22.23208427], [72.50875092, 22.2318058], [72.50846863, 22.23180962], [72.50846863, 22.2315197], [72.50791931, 22.23152733], [72.50791931, 22.23125076], [72.50763702, 22.23125076], [72.50763702, 22.23097038], [72.50736237, 22.23097229], [72.50736237, 22.23041725], [72.50708008, 22.23042107], [72.50708008, 22.23014069], [72.50681305, 22.23014069], [72.50681305, 22.22986031], [72.50653076, 22.22986031], [72.50653076, 22.22958183], [72.50624847, 22.22958374], [72.50624847, 22.22930527], [72.50596619, 22.2293129], [72.50596619, 22.22903061], [72.50569916, 22.22903061], [72.50569916, 22.22847939], [72.50541687, 22.22847939], [72.50541687, 22.22820282], [72.50514221, 22.22820282], [72.50514221, 22.22764015], [72.50485992, 22.22764015], [72.50485992, 22.22680092], [72.50458527, 22.22680473], [72.50458527, 22.22513962], [72.50430298, 22.22513962], [72.50430298, 22.22430992], [72.50402832, 22.22430992], [72.50402832, 22.22347069], [72.50430298, 22.2234726], [72.50430298, 22.22180557], [72.50402832, 22.22180939], [72.50402832, 22.22042084], [72.50263977, 22.22042084], [72.50263977, 22.22014046], [72.50235748, 22.22014046], [72.50235748, 22.21986008], [72.50208282, 22.21986198], [72.50208282, 22.21958351], [72.50180817, 22.21958351], [72.50180817, 22.21930313], [72.50096893, 22.21931076], [72.50096893, 22.21903038], [72.50068665, 22.21903038], [72.50068665, 22.21846962], [72.50041962, 22.21847153], [72.50041962, 22.21819305], [72.50013733, 22.21820068], [72.50013733, 22.2179203], [72.49986267, 22.2179203], [72.49986267, 22.21763992], [72.49957275, 22.21763992], [72.49957275, 22.21735954], [72.49903107, 22.21736145], [72.49903107, 22.21680641], [72.4985733, 22.21681023], [72.49846649, 22.21681023], [72.49846649, 22.21653938], [72.49819183, 22.21653938], [72.49819183, 22.21569252], [72.49791718, 22.21569443], [72.49791718, 22.21486282], [72.49764252, 22.21486282], [72.49764252, 22.21458244], [72.49736023, 22.21458244], [72.49736023, 22.2140274], [72.4970932, 22.21403122], [72.4970932, 22.21375084], [72.49680328, 22.21375084], [72.49680328, 22.2134819], [72.49652863, 22.2134819], [72.49652863, 22.21318817], [72.49624634, 22.21319389], [72.49624634, 22.21291733], [72.49597168, 22.21291924], [72.49597168, 22.21235847], [72.49569702, 22.21235847], [72.49569702, 22.21207809], [72.49541473, 22.21208382], [72.49541473, 22.21180534], [72.49514008, 22.21180916], [72.49514008, 22.21153069], [72.49485779, 22.21153069], [72.49485779, 22.21125031], [72.49458313, 22.21125031], [72.49458313, 22.21069908], [72.49430847, 22.21069908], [72.49430847, 22.21041107], [72.49402618, 22.2104187], [72.49402618, 22.21013641], [72.49375916, 22.21014023], [72.49375916, 22.20985985], [72.49346924, 22.20986176], [72.49346924, 22.20958328], [72.49319458, 22.20958328], [72.49319458, 22.20902634], [72.49291992, 22.20903015], [72.49291992, 22.20874977], [72.49263763, 22.20874977], [72.49263763, 22.20846939], [72.49236298, 22.2084713], [72.49236298, 22.20791435], [72.49208069, 22.20792007], [72.49208069, 22.20763969], [72.49180603, 22.20763969], [72.49180603, 22.20734978], [72.49153137, 22.20736122], [72.49153137, 22.20680428], [72.49124908, 22.20681], [72.49124908, 22.20652962], [72.4909668, 22.20652962], [72.4909668, 22.20625114], [72.49124908, 22.20625114], [72.49124908, 22.20597076], [72.49153137, 22.20597267], [72.49153137, 22.2056942], [72.49180603, 22.2056942], [72.49180603, 22.20541573], [72.49208069, 22.20541954], [72.49208069, 22.20499039], [72.49208069, 22.20458221], [72.49180603, 22.20458221], [72.49180603, 22.20319366], [72.49153137, 22.20319366], [72.49153137, 22.20263863], [72.49124908, 22.20264053], [72.49124908, 22.20236015], [72.48986053, 22.20236206], [72.48986053, 22.20208359], [72.48930359, 22.20208359], [72.48930359, 22.20152855], [72.48902893, 22.20153999], [72.48902893, 22.20125008], [72.48874664, 22.20125008], [72.48874664, 22.20042038], [72.48902893, 22.20042038], [72.48902893, 22.20014191], [72.48874664, 22.20014191], [72.48874664, 22.19986153], [72.48847198, 22.19986153], [72.48847198, 22.19930649], [72.48819733, 22.1993103], [72.48819733, 22.19903183], [72.48792267, 22.19903183], [72.48792267, 22.19874763], [72.48763275, 22.19874763], [72.48763275, 22.19735909], [72.48596954, 22.19735909], [72.48596954, 22.19763947], [72.48542023, 22.19763947], [72.48542023, 22.19791985], [72.48513794, 22.19791794], [72.48513794, 22.1981945], [72.48486328, 22.1981945], [72.48486328, 22.19847298], [72.48430634, 22.19846916], [72.48430634, 22.19874763], [72.48236084, 22.19874763], [72.48236084, 22.19903183], [72.48179626, 22.19903183], [72.48179626, 22.1993103], [72.48124695, 22.19930649], [72.48124695, 22.19958305], [72.48069763, 22.19958305], [72.48069763, 22.19986153], [72.4798584, 22.19986153], [72.4798584, 22.20014191], [72.47902679, 22.20014191], [72.47902679, 22.20042038], [72.47891235, 22.20041656], [72.47569275, 22.20042038], [72.47569275, 22.20070267], [72.4743042, 22.20069504], [72.4743042, 22.2009716], [72.47374725, 22.2009716], [72.47374725, 22.20125008], [72.47402954, 22.20125008], [72.47402954, 22.20208359], [72.47429657, 22.20208168], [72.47429657, 22.20264053], [72.47458649, 22.20263863], [72.47458649, 22.20319366], [72.47486115, 22.20318985], [72.47486115, 22.20375061], [72.4751358, 22.20375061], [72.4751358, 22.20486069], [72.47541809, 22.20486069], [72.47541809, 22.2056942], [72.47624969, 22.2056942], [72.47624969, 22.20541573], [72.47652435, 22.20541573], [72.47652435, 22.2056942], [72.47680664, 22.2056942], [72.47680664, 22.20597267], [72.4770813, 22.20597076], [72.4770813, 22.20625114], [72.47735596, 22.20625114], [72.47735596, 22.20652962], [72.47763824, 22.20652962], [72.47763824, 22.20681], [72.4779129, 22.20680428], [72.4779129, 22.20736122], [72.47819519, 22.20736122], [72.47819519, 22.20763969], [72.47846985, 22.20763969], [72.47846985, 22.20792007], [72.47875214, 22.20791435], [72.47875214, 22.20819473], [72.47902679, 22.20819473], [72.47902679, 22.2084713], [72.47930908, 22.20846939], [72.47930908, 22.20874977], [72.47958374, 22.20874977], [72.47958374, 22.20930481], [72.4798584, 22.20930481], [72.4798584, 22.20986176], [72.48014069, 22.20986176], [72.48014069, 22.2104187], [72.48041534, 22.2104187], [72.48041534, 22.21097183], [72.48069763, 22.21096992], [72.48069763, 22.21153069], [72.48097229, 22.21152878], [72.48097229, 22.21208382], [72.48124695, 22.21208382], [72.48124695, 22.21319389], [72.48097229, 22.21318817], [72.48097229, 22.21430969], [72.48014069, 22.21430588], [72.48014069, 22.21458244], [72.4798584, 22.21458244], [72.4798584, 22.21513939], [72.48014069, 22.21513939], [72.48014069, 22.21541977], [72.48097229, 22.21541595], [72.48097229, 22.21569443], [72.4813385, 22.21569252], [72.48152924, 22.21569252], [72.48152924, 22.21624947], [72.48179626, 22.21624947], [72.48179626, 22.21681023], [72.48208618, 22.21680641], [72.48208618, 22.21736145], [72.48236084, 22.21735954], [72.48236084, 22.2179203], [72.4826355, 22.21791649], [72.4826355, 22.21847153], [72.48291779, 22.21846962], [72.48291779, 22.21875], [72.48319244, 22.21875], [72.48319244, 22.21931076], [72.48347473, 22.21930313], [72.48347473, 22.21986198], [72.48374939, 22.21986008], [72.48374939, 22.22042084], [72.48402405, 22.22041512], [72.48402405, 22.22097206], [72.48430634, 22.22097015], [72.48430634, 22.22153091], [72.48458099, 22.22152519], [72.48458099, 22.22208595], [72.48486328, 22.22208023], [72.48486328, 22.22264099], [72.48513794, 22.22263718], [72.48513794, 22.22319412], [72.48458099, 22.22319412], [72.48458099, 22.2234726], [72.48401642, 22.22347069], [72.48401642, 22.22375107], [72.48374939, 22.22375107], [72.48374939, 22.22402954], [72.48319244, 22.22402954], [72.48319244, 22.22430992], [72.48291779, 22.22430611], [72.48291779, 22.22458267], [72.48236084, 22.22458076], [72.48236084, 22.22485924], [72.48208618, 22.22485924], [72.48208618, 22.22513962], [72.48152924, 22.22513962], [72.48152924, 22.22541809], [72.48097229, 22.22541618], [72.48097229, 22.22569466], [72.48069763, 22.22569466], [72.48069763, 22.22597313], [72.48014069, 22.22596931], [72.48014069, 22.2262516], [72.47957611, 22.2262516], [72.47957611, 22.22653008], [72.47902679, 22.22652817], [72.47902679, 22.22680473], [72.47846985, 22.22680092], [72.47846985, 22.22764015], [72.47875977, 22.22764015], [72.47875977, 22.22847939], [72.4798584, 22.22847939], [72.4798584, 22.22820282], [72.48152924, 22.22820282], [72.48152924, 22.22792053], [72.48208618, 22.22792053], [72.48208618, 22.22820282], [72.48542023, 22.22820282], [72.48542023, 22.22847939], [72.48568726, 22.22847939], [72.48568726, 22.22875023], [72.48625183, 22.22875023], [72.48625183, 22.22903061], [72.48902893, 22.22903061], [72.48902893, 22.2293129], [72.48958588, 22.22930527], [72.48958588, 22.22958374], [72.49013519, 22.22958374], [72.49013519, 22.22986031], [72.49069977, 22.22986031], [72.49069977, 22.23014069], [72.49124908, 22.23013878], [72.49124908, 22.23097229], [72.49153137, 22.23097038], [72.49153137, 22.23236084], [72.49180603, 22.23236084], [72.49180603, 22.23347282], [72.49208069, 22.23347282], [72.49208069, 22.23486137], [72.49236298, 22.23485947], [72.49236298, 22.23624992], [72.49263763, 22.23624992], [72.49263763, 22.23708344], [72.49208069, 22.23708344], [72.49208069, 22.23736191], [72.49097443, 22.23736191], [72.49097443, 22.23708344], [72.49069214, 22.23708344], [72.49069214, 22.23680496], [72.49041748, 22.23681068], [72.49041748, 22.2365303], [72.49014282, 22.2365303], [72.49014282, 22.23624992], [72.48958588, 22.23624992], [72.48958588, 22.23596954], [72.48930359, 22.23597145], [72.48930359, 22.23569679], [72.48902893, 22.23569679], [72.48902893, 22.23541641], [72.48291779, 22.23542023], [72.48291779, 22.23513985], [72.48236084, 22.23513985], [72.48236084, 22.23485947], [72.48124695, 22.23486137], [72.48124695, 22.2345829], [72.4798584, 22.2345829], [72.4798584, 22.23430443], [72.47846985, 22.23430443], [72.47846985, 22.2345829], [72.4779129, 22.2345829], [72.4779129, 22.23486137], [72.47763824, 22.23485947], [72.47763824, 22.23513985], [72.47875977, 22.23513985], [72.47875977, 22.23542023], [72.47958374, 22.23541641], [72.47958374, 22.23569679], [72.48069763, 22.23569679], [72.48069763, 22.23597145], [72.48152924, 22.23596954], [72.48152924, 22.23624992], [72.48319244, 22.23624992], [72.48319244, 22.23596954], [72.48568726, 22.23596954], [72.48568726, 22.23624992], [72.48652649, 22.23624992], [72.48652649, 22.2365303], [72.48735809, 22.2365303], [72.48735809, 22.23681068], [72.48819733, 22.23680496], [72.48819733, 22.23708344], [72.48902893, 22.23708344], [72.48902893, 22.23736191], [72.48986053, 22.23735809], [72.48986053, 22.23765182], [72.49041748, 22.23765182], [72.49041748, 22.23792076], [72.49097443, 22.23791885], [72.49097443, 22.23819351], [72.49124908, 22.23819351], [72.49124908, 22.23847008], [72.49180603, 22.23846817], [72.49180603, 22.23875046], [72.49236298, 22.23875046], [72.49236298, 22.23903084], [72.49263763, 22.23902893], [72.49263763, 22.23958397], [72.49291992, 22.23957825], [72.49291992, 22.24014091], [72.49319458, 22.24014091], [72.49319458, 22.24069405], [72.49346924, 22.24068832], [72.49346924, 22.2412529], [72.49375916, 22.2412529], [72.49375916, 22.24180984], [72.49402618, 22.24180984], [72.49402618, 22.24236107], [72.49430847, 22.24236107], [72.49430847, 22.24319458], [72.49402618, 22.24319458], [72.49402618, 22.24458313], [72.49375916, 22.24458122], [72.49375916, 22.24542046], [72.49346924, 22.24541664], [72.49346924, 22.24652863], [72.49318695, 22.246521], [72.49318695, 22.24764061], [72.49291992, 22.2476387], [72.49291992, 22.24819374], [72.49236298, 22.24819374], [72.49236298, 22.2476387], [72.49208069, 22.24764061], [72.49208069, 22.24736023], [72.49180603, 22.24736023], [72.49180603, 22.24681091], [72.49153137, 22.24681091], [72.49153137, 22.246521], [72.49124908, 22.24652863], [72.49124908, 22.24597168], [72.49097443, 22.24597168], [72.49097443, 22.24569321], [72.49069977, 22.24570084], [72.49069977, 22.24542046], [72.49014282, 22.24542046], [72.49014282, 22.24514008], [72.48986053, 22.24514008], [72.48986053, 22.2448597], [72.48930359, 22.2448616], [72.48930359, 22.24458313], [72.48902893, 22.24458313], [72.48902893, 22.24430466], [72.48847198, 22.24430466], [72.48847198, 22.24402809], [72.48819733, 22.24403], [72.48819733, 22.24374962], [72.48763275, 22.24374962], [72.48763275, 22.24346161], [72.48735809, 22.24347115], [72.48735809, 22.24319458], [72.48680878, 22.24319458], [72.48680878, 22.24291611], [72.48430634, 22.24291992], [72.48430634, 22.24263954], [72.48401642, 22.24263954], [72.48401642, 22.24236107], [72.48374939, 22.24236107], [72.48374939, 22.2420826], [72.48347473, 22.2420826], [72.48347473, 22.24180603], [72.48319244, 22.24180984], [72.48319244, 22.24152946], [72.48291779, 22.24152946], [72.48291779, 22.2412529], [72.48264313, 22.2412529], [72.48264313, 22.24097252], [72.48236084, 22.24097252], [72.48236084, 22.24069405], [72.48097229, 22.24069405], [72.48097229, 22.24041748], [72.47957611, 22.24041939], [72.47957611, 22.24014091], [72.47820282, 22.24014091], [72.47820282, 22.23985863], [72.4770813, 22.23985863], [72.4770813, 22.23957825], [72.47652435, 22.23958397], [72.47652435, 22.2393055], [72.47458649, 22.23930931], [72.47458649, 22.23903084], [72.4734726, 22.23903084], [72.4734726, 22.23875046], [72.4706955, 22.23875046], [72.4706955, 22.23958397], [72.47041321, 22.23958397], [72.47041321, 22.24069405], [72.47013855, 22.24068832], [72.47013855, 22.2412529], [72.47041321, 22.2412529], [72.47041321, 22.24152946], [72.4706955, 22.24152756], [72.47070313, 22.24263954], [72.47041321, 22.24263954], [72.47041321, 22.24347115], [72.4695816, 22.24347115], [72.46958923, 22.24374962], [72.46930695, 22.24374962], [72.46930695, 22.24430466], [72.46902466, 22.24430466], [72.46902466, 22.2448616], [72.46875, 22.2448597], [72.46875, 22.24570084], [72.46847534, 22.24569321], [72.46848297, 22.24625015], [72.46819305, 22.24625015], [72.46819305, 22.24681091], [72.4679184, 22.24681091], [72.4679184, 22.24736023], [72.46763611, 22.24736023], [72.46763611, 22.24792099], [72.46736145, 22.24791527], [72.46736145, 22.24819374], [72.46708679, 22.24819374], [72.46708679, 22.24847221], [72.46679688, 22.24847031], [72.46679688, 22.24903107], [72.46652985, 22.24903107], [72.46652985, 22.24930954], [72.46624756, 22.24930954], [72.46624756, 22.24986076], [72.4659729, 22.24986076], [72.4659729, 22.25014114], [72.46569824, 22.25014114], [72.46569824, 22.25041962], [72.46541595, 22.2504158], [72.46541595, 22.25097275], [72.4651413, 22.25097084], [72.4651413, 22.25125122], [72.46485901, 22.25125122], [72.46485901, 22.25180817], [72.46458435, 22.25180626], [72.46458435, 22.25208282], [72.46430206, 22.25208092], [72.46430206, 22.25265121], [72.4640274, 22.25265121], [72.4640274, 22.25292015], [72.46375275, 22.25291634], [72.46375275, 22.25319481], [72.46346283, 22.25318909], [72.46346283, 22.25375175], [72.4631958, 22.25375175], [72.4631958, 22.25403023], [72.46291351, 22.25402832], [72.46291351, 22.25458336], [72.46263885, 22.25458336], [72.46263885, 22.25486183], [72.46235657, 22.25486183], [72.46235657, 22.25542068], [72.46208191, 22.25542068], [72.46208191, 22.2557106], [72.46180725, 22.25569534], [72.46180725, 22.25597382], [72.46153259, 22.25597191], [72.46153259, 22.25653076], [72.46098328, 22.25653076], [72.46098328, 22.25681114], [72.46069336, 22.25680542], [72.46069336, 22.25708389], [72.4604187, 22.25708008], [72.4604187, 22.25764084], [72.46013641, 22.25763893], [72.46013641, 22.25819206], [72.45986176, 22.25819206], [72.45986176, 22.25847244], [72.4595871, 22.25846291], [72.4595871, 22.25902939], [72.45930481, 22.25902748], [72.45930481, 22.25958252], [72.45903015, 22.25958061], [72.45903015, 22.26013947], [72.45874786, 22.26013947], [72.45874786, 22.26041985], [72.45847321, 22.26041412], [72.45847321, 22.26097298], [72.45819092, 22.26097107], [72.45819092, 22.26152992], [72.45791626, 22.26152992], [72.45791626, 22.2618103], [72.4576416, 22.2618084], [72.4576416, 22.26236153], [72.45735931, 22.26235962], [72.45735931, 22.26292038], [72.45708466, 22.26291847], [72.45708466, 22.2634716], [72.45680237, 22.2634697], [72.45680237, 22.26403046], [72.45652771, 22.26403046], [72.45652771, 22.26458931], [72.45625305, 22.26458931], [72.45625305, 22.26514053], [72.45597076, 22.26514053], [72.45597076, 22.26569366], [72.45569611, 22.26568985], [72.45569611, 22.26625061], [72.45540619, 22.26625061], [72.45540619, 22.26680946], [72.45513916, 22.26680946], [72.45513916, 22.26736259], [72.45485687, 22.26736259], [72.45485687, 22.26791954], [72.45458221, 22.26791763], [72.45458221, 22.26847267], [72.45430756, 22.26847267], [72.45430756, 22.26902962], [72.45402527, 22.26902771], [72.45402527, 22.26958275], [72.45375061, 22.26958275], [72.45375061, 22.27013969], [72.45347595, 22.27013969], [72.45347595, 22.27042007], [72.45319366, 22.27041626], [72.45319366, 22.2709713], [72.45291901, 22.27096939], [72.45291901, 22.27124977], [72.45263672, 22.27124977], [72.45263672, 22.27153015], [72.45236206, 22.27152824], [72.45236206, 22.27208328], [72.45207977, 22.27208328], [72.45207977, 22.27236176], [72.45181274, 22.27235985], [72.45181274, 22.27292061], [72.45152283, 22.27292061], [72.45152283, 22.27320099], [72.45124817, 22.27320099], [72.45124817, 22.27375031], [72.45096588, 22.27375031], [72.45096588, 22.27403069], [72.45069122, 22.27403069], [72.45069122, 22.27431107], [72.45041656, 22.27431107], [72.45041656, 22.27486038], [72.45014191, 22.27486038], [72.45014191, 22.27514076], [72.44985962, 22.27513885], [72.44985962, 22.27569389], [72.44958496, 22.27569389], [72.44958496, 22.27597237], [72.44930267, 22.27597046], [72.44930267, 22.27653122], [72.44902802, 22.27652931], [72.44902802, 22.27708244], [72.44875336, 22.27708054], [72.44875336, 22.27763748], [72.44847107, 22.27763748], [72.44847107, 22.27819443], [72.44819641, 22.27819061], [72.44819641, 22.27874756], [72.44790649, 22.27874756], [72.44790649, 22.27931023], [72.44763947, 22.27930641], [72.44763947, 22.27986145], [72.44735718, 22.27986145], [72.44735718, 22.2804203], [72.44708252, 22.28041649], [72.44708252, 22.28097153], [72.44625092, 22.28097153], [72.44625092, 22.28347206], [72.44568634, 22.28347015], [72.44568634, 22.28375053], [72.44541931, 22.28375053], [72.44541931, 22.28403091], [72.44486237, 22.28403091], [72.44486237, 22.28430939], [72.44458008, 22.28430939], [72.44458008, 22.28486061], [72.44486237, 22.28486061], [72.44486237, 22.28541946], [72.44513702, 22.28541946], [72.44513702, 22.28625107], [72.44541931, 22.28625107], [72.44541931, 22.28652954], [72.44513702, 22.28652763], [72.44513702, 22.28708267], [72.44486237, 22.28708076], [72.44486237, 22.28763962], [72.44458008, 22.28763962], [72.44458008, 22.28819466], [72.44431305, 22.28819084], [72.44431305, 22.28876114], [72.44403076, 22.28876114], [72.44403076, 22.28903008], [72.44374847, 22.28902626], [72.44374847, 22.28930473], [72.44347382, 22.28930473], [72.44347382, 22.28958321], [72.44319153, 22.28958321], [72.44319153, 22.28986168], [72.44291687, 22.28985977], [72.44291687, 22.29014015], [72.44264984, 22.29014015], [72.44264984, 22.29042053], [72.44235992, 22.29042053], [72.44235992, 22.29182243], [72.44208527, 22.29180527], [72.44208527, 22.29208374], [72.44180298, 22.29207993], [72.44180298, 22.29264069], [72.44152832, 22.29264069], [72.44152832, 22.29291916], [72.44125366, 22.29291725], [72.44125366, 22.29319382], [72.44097137, 22.2931881], [72.44097137, 22.29375076], [72.44069672, 22.29375076], [72.44069672, 22.29403114], [72.4404068, 22.29403114], [72.4404068, 22.29430962], [72.44013977, 22.2943058], [72.44013977, 22.29458427], [72.43985748, 22.29457092], [72.43985748, 22.29514122], [72.43958282, 22.29514122], [72.43958282, 22.29541969], [72.43930817, 22.29541588], [72.43930817, 22.29569435], [72.43902588, 22.29569054], [72.43902588, 22.29624939], [72.43875122, 22.29624939], [72.43875122, 22.29652977], [72.43846893, 22.29652977], [72.43846893, 22.29681015], [72.43819427, 22.29680634], [72.43819427, 22.29708481], [72.43791962, 22.29708481], [72.43791962, 22.29763794], [72.43763733, 22.29763031], [72.43763733, 22.29792023], [72.43736267, 22.29791641], [72.43736267, 22.29819489], [72.43708038, 22.29819489], [72.43708038, 22.29847145], [72.43681335, 22.29846954], [72.43681335, 22.2990303], [72.43651581, 22.2990303], [72.43651581, 22.29931068], [72.43624878, 22.29930305], [72.43624878, 22.29958344], [72.43597412, 22.29958344], [72.43597412, 22.29986191], [72.43569183, 22.29986], [72.43569183, 22.30042076], [72.43541718, 22.30042076], [72.43541718, 22.30070114], [72.43514252, 22.30070114], [72.43514252, 22.30125046], [72.4345932, 22.30125046], [72.4345932, 22.30153084], [72.43402863, 22.30153084], [72.43402863, 22.30181122], [72.43319702, 22.3018055], [72.43319702, 22.30208397], [72.43235779, 22.30208015], [72.43235779, 22.30236053], [72.43180847, 22.30236053], [72.43180847, 22.30264091], [72.43096924, 22.30264091], [72.43096924, 22.30291939], [72.42958069, 22.30291939], [72.42958069, 22.30319405], [72.42874908, 22.30319405], [72.42874908, 22.30347252], [72.42764282, 22.30347061], [72.42764282, 22.30376053], [72.42652893, 22.30376053], [72.42652893, 22.30402946], [72.42542267, 22.30402946], [72.42542267, 22.30430984], [72.42430878, 22.30430794], [72.42430878, 22.3045826], [72.42346954, 22.30458069], [72.42346954, 22.30485916], [72.42236328, 22.30485916], [72.42236328, 22.30513763], [72.42124939, 22.30513763], [72.42124939, 22.30485916], [72.4209671, 22.30485916], [72.4209671, 22.30513763], [72.41958618, 22.30513763], [72.41958618, 22.30569458], [72.41764069, 22.30569458], [72.41764069, 22.30597305], [72.41708374, 22.30597305], [72.41708374, 22.30569458], [72.41680908, 22.30569458], [72.41680908, 22.30597305], [72.41625214, 22.30596924], [72.41625214, 22.30625153], [72.41596985, 22.30625153], [72.41596985, 22.30653191], [72.4154129, 22.30652809], [72.4154129, 22.30680466], [72.41486359, 22.30680466], [72.41486359, 22.30708313], [72.4145813, 22.30708313], [72.4145813, 22.3073616], [72.41319275, 22.3073616], [72.41319275, 22.30764008], [72.4126358, 22.30764008], [72.4126358, 22.30792046], [72.41179657, 22.30792046], [72.41179657, 22.30820274], [72.4109726, 22.30819511], [72.4109726, 22.30847168], [72.41041565, 22.30847168], [72.41042328, 22.30875015], [72.4098587, 22.30875015], [72.4098587, 22.30903053], [72.40930939, 22.30903053], [72.4092865, 22.30931282], [72.40847015, 22.30930519], [72.40847015, 22.30958366], [72.40651703, 22.30957031], [72.40652466, 22.30986023], [72.40598297, 22.30986023], [72.40598297, 22.31014061], [72.40513611, 22.31014061], [72.40513611, 22.30957031], [72.4043045, 22.30958366], [72.4043045, 22.30930519], [72.40374756, 22.30931282], [72.40374756, 22.30903053], [72.40319824, 22.30903053], [72.40319061, 22.30875015], [72.40235901, 22.30875015], [72.40235901, 22.30847168], [72.40180206, 22.30847168], [72.40180206, 22.30819511], [72.4015274, 22.30820274], [72.4015274, 22.30792046], [72.40097046, 22.30792046], [72.40097046, 22.30764008], [72.4006958, 22.30764008], [72.4006958, 22.3073616], [72.40013885, 22.3073616], [72.40013885, 22.30764008], [72.39875031, 22.30764008], [72.39875031, 22.3073616], [72.39819336, 22.3073616], [72.39819336, 22.30708313], [72.39736176, 22.30708313], [72.39736176, 22.3073616], [72.39679718, 22.3073616], [72.39679718, 22.30764008], [72.39541626, 22.30764008], [72.39541626, 22.3073616], [72.39402771, 22.3073616], [72.39402771, 22.30764008], [72.39347076, 22.30764008], [72.39347076, 22.30792046], [72.39319611, 22.30792046], [72.39319611, 22.30820274], [72.39263916, 22.30819511], [72.39263916, 22.30847168], [72.39208221, 22.30847168], [72.39208221, 22.30875015], [72.3915329, 22.30875015], [72.3915329, 22.30903053], [72.39125061, 22.30903053], [72.39125061, 22.30931282], [72.39069366, 22.30930519], [72.39069366, 22.30958366], [72.39013672, 22.30957031], [72.39013672, 22.30986023], [72.38957977, 22.30986023], [72.38957977, 22.31014061], [72.38931274, 22.31014061], [72.38928986, 22.3104229], [72.38874817, 22.31041718], [72.38874817, 22.31097221], [72.38846588, 22.31097031], [72.38846588, 22.31153107], [72.38819122, 22.31152725], [72.38819122, 22.3120842], [72.38791656, 22.31208038], [72.38791656, 22.31264114], [72.38764191, 22.31263924], [72.38764191, 22.31319427], [72.38791656, 22.31319427], [72.38791656, 22.31347275], [72.38817596, 22.31347084], [72.38817596, 22.31402969], [72.38847351, 22.31402779], [72.38847351, 22.31458282], [72.38874817, 22.31458282], [72.38874817, 22.3148613], [72.38903046, 22.31485939], [72.38903046, 22.31542015], [72.38931274, 22.31542015], [72.38931274, 22.31570053], [72.38957977, 22.31569481], [72.38957977, 22.31597137], [72.38986206, 22.31596947], [72.38986206, 22.31653023], [72.39013672, 22.31652641], [72.39013672, 22.31680489], [72.39041901, 22.31680489], [72.39041901, 22.31708336], [72.39069366, 22.31708336], [72.39069366, 22.31736183], [72.39097595, 22.31735992], [72.39097595, 22.3176403], [72.39125061, 22.3176403], [72.39125061, 22.31792068], [72.3915329, 22.31792068], [72.3915329, 22.31819916], [72.39180756, 22.31819534], [72.39180756, 22.31847191], [72.39208221, 22.31847191], [72.39208221, 22.31874847], [72.39235687, 22.31874084], [72.39235687, 22.31903076], [72.39263916, 22.31903076], [72.39263916, 22.31930923], [72.39291382, 22.31930542], [72.39291382, 22.31958389], [72.39319611, 22.31957817], [72.39319611, 22.31985855], [72.39347076, 22.31985855], [72.39347076, 22.32014084], [72.39402771, 22.32014084], [72.39402771, 22.32041931], [72.39430237, 22.3204174], [72.39430237, 22.32069397], [72.39458466, 22.32069397], [72.39458466, 22.32097244], [72.39485931, 22.32097244], [72.39485931, 22.32125282], [72.3951416, 22.32125282], [72.3951416, 22.32152939], [72.39541626, 22.32152748], [72.39541626, 22.32180595], [72.39569092, 22.32180595], [72.39569092, 22.32208252], [72.39597321, 22.32208252], [72.39597321, 22.3223629], [72.39653015, 22.3223629], [72.39653015, 22.32263947], [72.39679718, 22.32263947], [72.39679718, 22.32291985], [72.3970871, 22.32291603], [72.3970871, 22.3231945], [72.39736176, 22.3231945], [72.39736176, 22.32347107], [72.39763641, 22.32347107], [72.39763641, 22.32374954], [72.3979187, 22.32374954], [72.3979187, 22.32402992], [72.39847565, 22.32402802], [72.39848328, 22.32430077], [72.39875031, 22.32430649], [72.39875031, 22.32458305], [72.39903259, 22.32458115], [72.39903259, 22.32487106], [72.39930725, 22.32487106], [72.39930725, 22.32514], [72.39958191, 22.32514], [72.39958191, 22.32542038], [72.39985657, 22.32542038], [72.39985657, 22.32570076], [72.40013885, 22.32569313], [72.40013885, 22.3259716], [72.40027618, 22.3259716], [72.40041351, 22.3259716], [72.40041351, 22.32625008], [72.4006958, 22.32625008], [72.4006958, 22.32653046], [72.40097046, 22.32653046], [72.40097046, 22.32681084], [72.40125275, 22.32680511], [72.40125275, 22.32708359], [72.4015274, 22.32707977], [72.4015274, 22.32736015], [72.40180206, 22.32736015], [72.40180206, 22.32764053], [72.40208435, 22.32763863], [72.40208435, 22.32819366], [72.40235901, 22.32819366], [72.40235901, 22.32847214], [72.4026413, 22.32847023], [72.4026413, 22.32903099], [72.40291595, 22.32902527], [72.40291595, 22.32958412], [72.40319824, 22.32958031], [72.40319824, 22.32986069], [72.4034729, 22.32986069], [72.4034729, 22.33041954], [72.40374756, 22.33041573], [72.40374756, 22.3306942], [72.40402985, 22.33068085], [72.40402985, 22.33125114], [72.40429688, 22.33125114], [72.40429688, 22.33180809], [72.40458679, 22.33180618], [72.40458679, 22.33226013], [72.40458679, 22.33235931], [72.40486145, 22.33235931], [72.40486145, 22.33266068], [72.40486145, 22.33292007], [72.40513611, 22.33291626], [72.40513611, 22.33305931], [72.40513611, 22.33346939], [72.4054184, 22.33346939], [72.4054184, 22.33403015], [72.40569305, 22.33402824], [72.40569305, 22.33486176], [72.40598297, 22.33486176], [72.40598297, 22.33542061], [72.40625, 22.33541679], [72.40625, 22.33597374], [72.40651703, 22.33597183], [72.40651703, 22.33653069], [72.40680695, 22.33653069], [72.40680695, 22.33736038], [72.4070816, 22.33736038], [72.4070816, 22.33792114], [72.40735626, 22.33792114], [72.40735626, 22.33875084], [72.40763855, 22.33875084], [72.40763855, 22.33958244], [72.40791321, 22.33958054], [72.40791321, 22.34013939], [72.4081955, 22.34013939], [72.4081955, 22.3409729], [72.40847015, 22.34097099], [72.40847015, 22.34152985], [72.40875244, 22.34152794], [72.40875244, 22.34236145], [72.4090271, 22.34236145], [72.4090271, 22.34291649], [72.40930176, 22.34291649], [72.40930939, 22.34347153], [72.40957642, 22.34346962], [72.40957642, 22.34431076], [72.4098587, 22.34430504], [72.4098587, 22.34486198], [72.41014099, 22.34486198], [72.41014099, 22.34569359], [72.41041565, 22.34569359], [72.41041565, 22.34625053], [72.41069794, 22.34625053], [72.41069794, 22.34708405], [72.4109726, 22.34707832], [72.4109726, 22.3476429], [72.41124725, 22.34763908], [72.41124725, 22.3484726], [72.41152954, 22.3484726], [72.41152954, 22.34930992], [72.41179657, 22.34930992], [72.41179657, 22.34986115], [72.41208649, 22.34986115], [72.41208649, 22.35124969], [72.41236115, 22.35124969], [72.41236115, 22.35347176], [72.4126358, 22.35346985], [72.4126358, 22.35625076], [72.41236115, 22.35625076], [72.41236115, 22.35736084], [72.41236115, 22.35847282], [72.41208649, 22.35847092], [72.41208649, 22.35874748], [72.41179657, 22.35874748], [72.41179657, 22.35902977], [72.41152954, 22.35904121], [72.41152954, 22.35931015], [72.41124725, 22.35930634], [72.41124725, 22.3595829], [72.4109726, 22.3595829], [72.4109726, 22.35986137], [72.41069794, 22.35986137], [72.41069794, 22.36013985], [72.41042328, 22.36014175], [72.41042328, 22.36042023], [72.41014099, 22.36041641], [72.41014099, 22.36069489], [72.4098587, 22.36069489], [72.4098587, 22.36096954], [72.40957642, 22.36096954], [72.40957642, 22.36125183], [72.40930939, 22.36125183], [72.4092865, 22.3615303], [72.40898132, 22.3615303], [72.40875244, 22.3615303], [72.40875244, 22.36181068], [72.40847015, 22.36180496], [72.40847015, 22.36208344], [72.40791321, 22.36208344], [72.40791321, 22.36236382], [72.40763855, 22.36236191], [72.40763855, 22.36264038], [72.40735626, 22.36264038], [72.40735626, 22.36292076], [72.40680695, 22.36291695], [72.40680695, 22.3631897], [72.40652466, 22.36319542], [72.40652466, 22.36347389], [72.40625, 22.36347008], [72.40625, 22.36375046], [72.40569305, 22.36375046], [72.40569305, 22.36404037], [72.4054184, 22.36404037], [72.4054184, 22.36431122], [72.40486145, 22.3643055], [72.40486145, 22.36458206], [72.40458679, 22.36458015], [72.40458679, 22.36486053], [72.40429688, 22.36486053], [72.40429688, 22.36514091], [72.40402985, 22.36514091], [72.40402985, 22.36541939], [72.40374756, 22.36541748], [72.40374756, 22.36569595], [72.4034729, 22.36569595], [72.4034729, 22.36597252], [72.40319824, 22.36597061], [72.40319824, 22.36625099], [72.40291595, 22.36625099], [72.40291595, 22.36652946], [72.4026413, 22.36652946], [72.4026413, 22.36680984], [72.40235901, 22.36680412], [72.40235901, 22.3670826], [72.40180206, 22.36708069], [72.40180206, 22.36736107], [72.40125275, 22.36736107], [72.40125275, 22.36763954], [72.4006958, 22.36763954], [72.4006958, 22.36791992], [72.40041351, 22.3679142], [72.40041351, 22.36819458], [72.3998642, 22.36819458], [72.3998642, 22.36847305], [72.39930725, 22.36847115], [72.39930725, 22.36874962], [72.39902496, 22.36874962], [72.39902496, 22.36930466], [72.39875031, 22.36930466], [72.39875031, 22.36958313], [72.39848328, 22.36958122], [72.39848328, 22.37013817], [72.39819336, 22.37013817], [72.39819336, 22.37070084], [72.3979187, 22.37070084], [72.3979187, 22.37124825], [72.39763641, 22.37124825], [72.39763641, 22.37181091], [72.3973465, 22.37181091], [72.3973465, 22.37235832], [72.3970871, 22.37235832], [72.3970871, 22.37291908], [72.39679718, 22.37291908], [72.39679718, 22.37375069], [72.39653015, 22.37375069], [72.39653015, 22.3745842], [72.39624786, 22.3745842], [72.39624786, 22.37569427], [72.39597321, 22.37569046], [72.39597321, 22.37652969], [72.39569092, 22.37652779], [72.39569092, 22.3773613], [72.39541626, 22.3773613], [72.39541626, 22.37819481], [72.39530945, 22.37819481], [72.3951416, 22.37819481], [72.3951416, 22.3783226], [72.3951416, 22.37903976], [72.39485931, 22.37902832], [72.39485931, 22.37986183], [72.39457703, 22.37985992], [72.39457703, 22.38070107], [72.39430237, 22.38069534], [72.39431, 22.38150024], [72.39414978, 22.3815403], [72.39402771, 22.38154984], [72.39402771, 22.38236046], [72.39375305, 22.38236046], [72.39375305, 22.38264084], [72.39319611, 22.38264084], [72.39319611, 22.38236046], [72.39263916, 22.38236046], [72.39263916, 22.38220024], [72.39263916, 22.38208389], [72.3923645, 22.38208389], [72.3923645, 22.38180542], [72.39180756, 22.38181114], [72.39180756, 22.38153076], [72.3915329, 22.38153076], [72.3915329, 22.38181114], [72.39069366, 22.38180542], [72.39069366, 22.38208389], [72.38986206, 22.38208008], [72.38986206, 22.38236046], [72.38903046, 22.38236046], [72.38903046, 22.38264084], [72.38846588, 22.38264084], [72.38846588, 22.38292122], [72.38764191, 22.3829155], [72.38764191, 22.38319397], [72.38708496, 22.38319397], [72.38708496, 22.38347244], [72.38652802, 22.38347054], [72.38652802, 22.38375092], [72.38597107, 22.38375092], [72.38597107, 22.38402748], [72.38513947, 22.38402748], [72.38513947, 22.38430977], [72.38458252, 22.38430786], [72.38458252, 22.38458252], [72.38346863, 22.38458061], [72.38346863, 22.38485909], [72.38263702, 22.38485909], [72.38263702, 22.38513756], [72.38153076, 22.38513756], [72.38153076, 22.38541985], [72.37931061, 22.38541985], [72.37931061, 22.38513756], [72.37623596, 22.38513756], [72.37623596, 22.38485909], [72.37568665, 22.38485909], [72.37568665, 22.38458061], [72.37541962, 22.38458252], [72.37541962, 22.38430786], [72.37486267, 22.38430977], [72.37486267, 22.38402748], [72.37431335, 22.38402748], [72.37431335, 22.38375092], [72.37403107, 22.38375092], [72.37403107, 22.38347054], [72.37347412, 22.38347244], [72.37347412, 22.38319397], [72.37291718, 22.38319397], [72.37291718, 22.3829155], [72.37264252, 22.38292122], [72.37264252, 22.38264084], [72.3720932, 22.38264084], [72.3720932, 22.38236046], [72.37180328, 22.38236046], [72.37180328, 22.38208008], [72.37124634, 22.38208389], [72.37124634, 22.38180542], [72.37069702, 22.38180542], [72.37069702, 22.38152695], [72.3704071, 22.38153076], [72.3704071, 22.38125038], [72.36985779, 22.38125038], [72.36985779, 22.38097], [72.36930847, 22.38097191], [72.36930847, 22.38069534], [72.36902618, 22.38070107], [72.36902618, 22.38042068], [72.36846924, 22.38042068], [72.36846924, 22.3801403], [72.36818695, 22.3801403], [72.36818695, 22.37985992], [72.36763763, 22.37986183], [72.36763763, 22.37958336], [72.36736298, 22.37958336], [72.36736298, 22.37930489], [72.36680603, 22.37930489], [72.36680603, 22.37902832], [72.36653137, 22.37903976], [72.36653137, 22.37874985], [72.3659668, 22.37874985], [72.3659668, 22.37846947], [72.36569214, 22.37847137], [72.36569214, 22.37819481], [72.36513519, 22.37819481], [72.36513519, 22.37791634], [72.36486053, 22.37792015], [72.36486053, 22.37763977], [72.36429596, 22.37763977], [72.36429596, 22.37735939], [72.36402893, 22.3773613], [72.36402893, 22.37708282], [72.36374664, 22.37708282], [72.36374664, 22.37680626], [72.36319733, 22.37681007], [72.36319733, 22.37652969], [72.36292267, 22.37652969], [72.36292267, 22.37625122], [72.36235809, 22.37625122], [72.36235809, 22.37598038], [72.36207581, 22.37598038], [72.36207581, 22.37569046], [72.36180878, 22.37566948], [72.36180878, 22.37513924], [72.36152649, 22.37514114], [72.36152649, 22.37486267], [72.36123657, 22.37486267], [72.36123657, 22.37402916], [72.36096954, 22.37402916], [72.36096954, 22.37291908], [72.36068726, 22.37291908], [72.36068726, 22.37207985], [72.36096954, 22.37208366], [72.36096954, 22.37153053], [72.36207581, 22.37153053], [72.36207581, 22.37181091], [72.36374664, 22.37180519], [72.36374664, 22.37194061], [72.36374664, 22.37208366], [72.36402893, 22.37207985], [72.36402893, 22.37235832], [72.36429596, 22.37235832], [72.36429596, 22.37264061], [72.36458588, 22.37264061], [72.36458588, 22.37291908], [72.36513519, 22.37291718], [72.36513519, 22.37319374], [72.36541748, 22.37319374], [72.36541748, 22.37347221], [72.36569214, 22.37347221], [72.36569214, 22.37319374], [72.36958313, 22.37319374], [72.36958313, 22.37347221], [72.37152863, 22.3734684], [72.37152863, 22.37375069], [72.37291718, 22.37375069], [72.37291718, 22.3734684], [72.37458038, 22.37347221], [72.37458038, 22.37319374], [72.37569427, 22.37319374], [72.37569427, 22.37347221], [72.37650299, 22.3734684], [72.37708282, 22.3734684], [72.37708282, 22.37375069], [72.37763977, 22.37375069], [72.37763977, 22.37402916], [72.3779068, 22.37402916], [72.3779068, 22.37430954], [72.37847137, 22.37430573], [72.37847137, 22.3745842], [72.37874603, 22.37458038], [72.37874603, 22.37486267], [72.37931061, 22.37486267], [72.37931061, 22.37514114], [72.3795929, 22.37514114], [72.3795929, 22.37541962], [72.38014221, 22.3754158], [72.38014221, 22.37569427], [72.38153076, 22.37569427], [72.38153076, 22.3754158], [72.38237, 22.37541962], [72.38237, 22.37514114], [72.38208008, 22.37514114], [72.38208008, 22.37486267], [72.38237, 22.37486267], [72.38236237, 22.3745842], [72.38263702, 22.3745842], [72.38263702, 22.37430573], [72.38291931, 22.37430954], [72.38291931, 22.37402916], [72.38318634, 22.37402916], [72.38318634, 22.37375069], [72.38346863, 22.37375069], [72.38346863, 22.37318993], [72.38375092, 22.37319374], [72.38375092, 22.37291718], [72.3840332, 22.37291908], [72.3840332, 22.37264061], [72.38430786, 22.37264061], [72.38430786, 22.37231064], [72.38430786, 22.37208366], [72.38458252, 22.37208366], [72.38458252, 22.37180519], [72.38485718, 22.37181091], [72.38485718, 22.37153053], [72.38513947, 22.37153053], [72.38513947, 22.37124825], [72.38540649, 22.37124825], [72.38540649, 22.37096977], [72.38569641, 22.37097168], [72.38569641, 22.37069511], [72.38597107, 22.37070084], [72.38597107, 22.37042046], [72.38625336, 22.37042046], [72.38625336, 22.37013817], [72.38652802, 22.37013817], [72.38652802, 22.36985016], [72.38680267, 22.3698616], [72.38680267, 22.36958313], [72.38708496, 22.36958313], [72.38708496, 22.36930466], [72.38735962, 22.36930466], [72.38735962, 22.36902618], [72.38764191, 22.36903], [72.38764191, 22.36847115], [72.38791656, 22.36847305], [72.38791656, 22.3679142], [72.38817596, 22.36791992], [72.38817596, 22.36708069], [72.38847351, 22.3670826], [72.38847351, 22.36624908], [72.38903046, 22.36625099], [72.38903046, 22.36597061], [72.38957977, 22.36597252], [72.38957977, 22.36569595], [72.39041901, 22.36569595], [72.39041901, 22.36541748], [72.39097595, 22.36541939], [72.39097595, 22.36514091], [72.39125061, 22.36514091], [72.39125061, 22.36486053], [72.39180756, 22.36486053], [72.39180756, 22.36458015], [72.39208221, 22.36458206], [72.39208221, 22.3643055], [72.39263916, 22.36431122], [72.39263916, 22.36404037], [72.39290619, 22.36404037], [72.39290619, 22.36375046], [72.39347076, 22.36375046], [72.39347076, 22.36347008], [72.39375305, 22.36347389], [72.39375305, 22.36319351], [72.39430237, 22.36319351], [72.39430237, 22.36263847], [72.39457703, 22.36264038], [72.39457703, 22.36207962], [72.39485931, 22.36208344], [72.39485931, 22.3615284], [72.3951416, 22.3615303], [72.3951416, 22.36096954], [72.39541626, 22.36096954], [72.39541626, 22.36041641], [72.39569092, 22.36042023], [72.39569092, 22.35986137], [72.39597321, 22.35986137], [72.39597321, 22.35930634], [72.39624786, 22.35931015], [72.39624786, 22.35902977], [72.3970871, 22.35902977], [72.3970871, 22.35847092], [72.39736176, 22.35847282], [72.39736176, 22.35819435], [72.39763641, 22.35819435], [72.39763641, 22.35791588], [72.3979187, 22.35791588], [72.3979187, 22.35736084], [72.39819336, 22.35736084], [72.39819336, 22.35680962], [72.39848328, 22.35680962], [72.39848328, 22.35625076], [72.39875031, 22.35625076], [72.39875031, 22.35597038], [72.39902496, 22.35597229], [72.39902496, 22.35541534], [72.4005661, 22.35541534], [72.40125275, 22.35541534], [72.40125275, 22.35569382], [72.40180206, 22.35569382], [72.40180206, 22.35541534], [72.40207672, 22.35542107], [72.40207672, 22.35485077], [72.40235901, 22.35486031], [72.40235901, 22.35458374], [72.4026413, 22.35458374], [72.4026413, 22.3540287], [72.40319061, 22.35403061], [72.40319824, 22.35375023], [72.40374756, 22.35375023], [72.40374756, 22.35320091], [72.40402985, 22.35320091], [72.40402985, 22.35235977], [72.4043045, 22.35236168], [72.4043045, 22.35152817], [72.40402985, 22.35153008], [72.40402985, 22.35124969], [72.40374756, 22.35124969], [72.40374756, 22.35069275], [72.4034729, 22.35069466], [72.4034729, 22.34986115], [72.40319824, 22.34986115], [72.40319061, 22.34902954], [72.40291595, 22.34902954], [72.40291595, 22.34875107], [72.40235901, 22.34875107], [72.40235901, 22.3484726], [72.40208435, 22.3484726], [72.40208435, 22.34819412], [72.4015274, 22.34819412], [72.4015274, 22.34791756], [72.40125275, 22.34791946], [72.40125275, 22.3476429], [72.40097046, 22.3476429], [72.40097046, 22.3473587], [72.40040588, 22.3473587], [72.40040588, 22.34707832], [72.40013885, 22.34708405], [72.40013885, 22.34680557], [72.39958191, 22.34680939], [72.39958191, 22.34653091], [72.39930725, 22.34653091], [72.39930725, 22.34625053], [72.39875031, 22.34625053], [72.39875031, 22.34597015], [72.39847565, 22.34597015], [72.39847565, 22.34569359], [72.3970871, 22.34569359], [72.3970871, 22.34541893], [72.39597321, 22.34542084], [72.39597321, 22.34514046], [72.39541626, 22.34514046], [72.39541626, 22.34485817], [72.39485931, 22.34486198], [72.39485931, 22.34458351], [72.39430237, 22.34458351], [72.39430237, 22.34430504], [72.39375305, 22.34430504], [72.39375305, 22.34458351], [72.3923645, 22.34458351], [72.3923645, 22.34430504], [72.39125061, 22.34431076], [72.39125061, 22.34403038], [72.38931274, 22.34403038], [72.38931274, 22.34374809], [72.38903046, 22.34374809], [72.38903046, 22.34346962], [72.38847351, 22.34347153], [72.38847351, 22.34319687], [72.38791656, 22.34320068], [72.38791656, 22.34291077], [72.38764191, 22.34291649], [72.38764191, 22.34263611], [72.38707733, 22.34263992], [72.38707733, 22.34235954], [72.38652802, 22.34236145], [72.38652802, 22.34208298], [72.38597107, 22.34208298], [72.38597107, 22.34180832], [72.38569641, 22.34181023], [72.38569641, 22.34152985], [72.38513947, 22.34152985], [72.38513947, 22.34124947], [72.38458252, 22.34124947], [72.38458252, 22.34097099], [72.38430786, 22.3409729], [72.38430786, 22.34069443], [72.38375092, 22.34069443], [72.38375092, 22.33986092], [72.38346863, 22.33987045], [72.38346863, 22.33930969], [72.38237, 22.33930969], [72.38237, 22.33903122], [72.38208008, 22.33903122], [72.38208008, 22.33875084], [72.38180542, 22.33875084], [72.38180542, 22.33847237], [72.38153076, 22.33847237], [72.38153076, 22.33819389], [72.38124847, 22.33819389], [72.38124847, 22.33791733], [72.38096619, 22.33792114], [72.38096619, 22.33764076], [72.38069153, 22.33764076], [72.38069153, 22.33736038], [72.38041687, 22.33736038], [72.38041687, 22.33708191], [72.38014221, 22.33708382], [72.38014221, 22.33680534], [72.37985992, 22.33681107], [72.37985992, 22.33653069], [72.3795929, 22.33653069], [72.3795929, 22.33625031], [72.37930298, 22.33625031], [72.37930298, 22.33597374], [72.37902832, 22.33597374], [72.37902832, 22.33541679], [72.37874603, 22.33542061], [72.37874603, 22.33514023], [72.37847137, 22.33514023], [72.37847137, 22.33457947], [72.37819672, 22.33458328], [72.37819672, 22.33402824], [72.3779068, 22.33403015], [72.3779068, 22.33373833], [72.37763977, 22.33375168], [72.37763977, 22.33319473], [72.37735748, 22.33319473], [72.37735748, 22.3326416], [72.37708282, 22.3326416], [72.37708282, 22.33208084], [72.37680817, 22.33208275], [72.37680817, 22.33180618], [72.37652588, 22.33180809], [72.37652588, 22.33125114], [72.37623596, 22.33125114], [72.37623596, 22.33068085], [72.37596893, 22.3306942], [72.37596893, 22.33041954], [72.37568665, 22.33041954], [72.37568665, 22.32986069], [72.37541962, 22.32986069], [72.37541962, 22.32930946], [72.37513733, 22.32930946], [72.37513733, 22.32875061], [72.37486267, 22.32875061], [72.37486267, 22.32793045], [72.37458038, 22.32793045], [72.37458038, 22.32707977], [72.37430573, 22.32708359], [72.37430573, 22.32625008], [72.37403107, 22.32625008], [72.37403107, 22.32570076], [72.37374878, 22.32570076], [72.37374878, 22.32487106], [72.3735733, 22.32487106], [72.37346649, 22.32487106], [72.37347412, 22.32434845], [72.37347412, 22.32402802], [72.37317657, 22.32402992], [72.37317657, 22.3231926], [72.37291718, 22.3231945], [72.37288666, 22.32125282], [72.37264252, 22.32125282], [72.37264252, 22.32018089], [72.37264252, 22.31847191], [72.37236023, 22.31847191], [72.37236023, 22.31652641], [72.37264252, 22.31653023], [72.37264252, 22.31513977], [72.37291718, 22.31513977], [72.37291718, 22.31375122], [72.37317657, 22.31375122], [72.37317657, 22.31264114], [72.37346649, 22.31264114], [72.37346649, 22.31208038], [72.37374878, 22.3120842], [72.37374878, 22.31125069], [72.37403107, 22.31125069], [72.37403107, 22.3104229], [72.37431335, 22.3104229], [72.37431335, 22.30986023], [72.37458038, 22.30986023], [72.37458038, 22.30903053], [72.37486267, 22.30903053], [72.3748703, 22.30847168], [72.37513733, 22.30847168], [72.37513733, 22.30791664], [72.37541962, 22.30792046], [72.37541962, 22.30707932], [72.37569427, 22.30708313], [72.37569427, 22.30652809], [72.37596893, 22.30653191], [72.37596893, 22.30596924], [72.37625122, 22.30597305], [72.37625122, 22.30541611], [72.37652588, 22.30541992], [72.37652588, 22.30513763], [72.37680817, 22.30513763], [72.37680817, 22.30485916], [72.37708282, 22.30485916], [72.37708282, 22.30458069], [72.37763977, 22.3045826], [72.37763977, 22.30430794], [72.3779068, 22.30430984], [72.3779068, 22.30402946], [72.37819672, 22.30402946], [72.37819672, 22.30376053], [72.37847137, 22.30376053], [72.37847137, 22.30347061], [72.37875366, 22.30347252], [72.37875366, 22.30319405], [72.37902832, 22.30319405], [72.37902832, 22.30291939], [72.3795929, 22.30291939], [72.3795929, 22.30264091], [72.37985992, 22.30264091], [72.37985992, 22.30236053], [72.38014221, 22.30236053], [72.38014221, 22.30208015], [72.38041687, 22.30208397], [72.38041687, 22.3018055], [72.38096619, 22.30181122], [72.38096619, 22.30153084], [72.38124847, 22.30153084], [72.38124847, 22.30125046], [72.38153076, 22.30125046], [72.38153076, 22.30097008], [72.38208008, 22.30097198], [72.38208008, 22.30069351], [72.38237, 22.30070114], [72.38237, 22.30042076], [72.38291931, 22.30042076], [72.38291931, 22.30014038], [72.38318634, 22.30014038], [72.38318634, 22.29986], [72.38430786, 22.29986191], [72.38430786, 22.29958344], [72.38541412, 22.29958344], [72.38541412, 22.29930305], [72.38652802, 22.29931068], [72.38652802, 22.2990303], [72.38671112, 22.2990303], [72.38764191, 22.2990303], [72.38764191, 22.29874992], [72.39290619, 22.29874992], [72.39290619, 22.2990303], [72.39639282, 22.2990303], [72.39848328, 22.2990303], [72.39848328, 22.29931068], [72.4109726, 22.29931068], [72.4109726, 22.2990303], [72.41124725, 22.2990303], [72.41124725, 22.29874992], [72.41179657, 22.29874992], [72.41179657, 22.29846954], [72.41236115, 22.29847145], [72.41236115, 22.29819489], [72.41291809, 22.29819489], [72.41291809, 22.29791641], [72.41319275, 22.29792023], [72.41319275, 22.29763031], [72.41374969, 22.29763794], [72.41374969, 22.29708481], [72.41402435, 22.29708481], [72.41402435, 22.29597282], [72.41430664, 22.29597282], [72.41430664, 22.29513931], [72.4145813, 22.29514122], [72.4145813, 22.29430962], [72.41485596, 22.29430962], [72.41485596, 22.2931881], [72.41513824, 22.29319382], [72.41513824, 22.29180527], [72.41542053, 22.29182243], [72.41542053, 22.28957939], [72.41569519, 22.28958321], [72.41569519, 22.28736115], [72.41596985, 22.28736115], [72.41596985, 22.28458023], [72.41625214, 22.28458214], [72.41625214, 22.28180504], [72.41652679, 22.28181267], [72.41652679, 22.27959251], [72.41625214, 22.27959251], [72.41625214, 22.27514076], [72.41596985, 22.27514076], [72.41596985, 22.27096939], [72.41569519, 22.2709713], [72.41569519, 22.26847267], [72.4154129, 22.26847267], [72.4154129, 22.26736259], [72.41513824, 22.26736259], [72.41513824, 22.26652908], [72.41485596, 22.26652908], [72.41485596, 22.26542091], [72.4145813, 22.26542091], [72.4145813, 22.26431084], [72.41430664, 22.26431084], [72.41430664, 22.2634697], [72.41402435, 22.2634716], [72.41402435, 22.26236153], [72.41374969, 22.26236153], [72.41374969, 22.2618084], [72.41348267, 22.2618103], [72.41348267, 22.25958061], [72.41319275, 22.25958252], [72.41319275, 22.25708389], [72.41291809, 22.25708389], [72.41291809, 22.25430489], [72.4126358, 22.25430489], [72.4126358, 22.25402832], [72.41291809, 22.25403023], [72.41291809, 22.25375175], [72.41319275, 22.25375175], [72.41319275, 22.25041962], [72.41348267, 22.25041962], [72.41348267, 22.24986076], [72.41319275, 22.24986076], [72.41319275, 22.24930954], [72.41348267, 22.24930954], [72.41348267, 22.24792099], [72.41374969, 22.24792099], [72.41374969, 22.24625015], [72.41401672, 22.24625015], [72.41401672, 22.2448597], [72.41430664, 22.2448616], [72.41430664, 22.24347115], [72.4145813, 22.24347115], [72.4145813, 22.24180603], [72.41485596, 22.24180984], [72.41485596, 22.23707962], [72.41513824, 22.23708344], [72.41513824, 22.23513794], [72.41542053, 22.23513985], [72.41542053, 22.23319054], [72.41569519, 22.23319435], [72.41569519, 22.23152733], [72.41596985, 22.23152733], [72.41596985, 22.22986031], [72.41625214, 22.22986031], [72.41625214, 22.22820282], [72.41652679, 22.22820282], [72.41652679, 22.22736168], [72.41402435, 22.22736168], [72.41402435, 22.22708321], [72.41152954, 22.22708321], [72.41152954, 22.2262516], [72.41179657, 22.2262516], [72.41179657, 22.22513962], [72.41208649, 22.22513962], [72.41208649, 22.22375107], [72.41234589, 22.22375107], [72.41234589, 22.22264099], [72.4126358, 22.22264099], [72.4126358, 22.22125053], [72.41234589, 22.22125053], [72.41234589, 22.22020721], [72.41208649, 22.22014046], [72.41208649, 22.21903038], [72.41179657, 22.21903038], [72.41179657, 22.2179203], [72.41152954, 22.2179203], [72.41152954, 22.21681023], [72.41124725, 22.21681023], [72.41124725, 22.21569252], [72.4109726, 22.21569443], [72.4109726, 22.21513939], [72.41014099, 22.21513939], [72.41014099, 22.21486282], [72.4092865, 22.21486282], [72.4092865, 22.21458244], [72.40847015, 22.21458244], [72.40847015, 22.21430588], [72.40820313, 22.21430969], [72.40820313, 22.21403122], [72.40791321, 22.21403122], [72.40791321, 22.21375084], [72.40763855, 22.21375084], [72.40763855, 22.2134819], [72.40735626, 22.2134819], [72.40735626, 22.21318817], [72.40680695, 22.21318817], [72.40680695, 22.21375084], [72.4054184, 22.21375084], [72.4054184, 22.21180916], [72.40513611, 22.21180916], [72.40513611, 22.20957947], [72.40458679, 22.20958328], [72.40458679, 22.20930481], [72.4034729, 22.20930481], [72.4034729, 22.20958328], [72.4026413, 22.20958328], [72.4026413, 22.20902634], [72.40235901, 22.20903015], [72.40235901, 22.20846939], [72.40208435, 22.2084713], [72.40208435, 22.20763969], [72.40180206, 22.20763969], [72.40180206, 22.20597076], [72.4015274, 22.20597267], [72.4015274, 22.20458221], [72.40125275, 22.20458221], [72.40125275, 22.20347214], [72.40097046, 22.20347214], [72.40097046, 22.20236206], [72.4006958, 22.20236206], [72.4006958, 22.20152855], [72.40040588, 22.20153999], [72.40040588, 22.20070267], [72.40013885, 22.20070267], [72.40013885, 22.19957924], [72.3998642, 22.19958305], [72.3998642, 22.19930649], [72.39958191, 22.19930649], [72.39958191, 22.19958305], [72.39930725, 22.19957924], [72.39930725, 22.20042038], [72.39901733, 22.20042038], [72.39901733, 22.20125008], [72.39875031, 22.20125008], [72.39875031, 22.20181274], [72.39848328, 22.20181274], [72.39848328, 22.20264053], [72.39819336, 22.20264053], [72.39819336, 22.20375061], [72.3979187, 22.20375061], [72.3979187, 22.20430946], [72.39763641, 22.20430946], [72.39763641, 22.20486069], [72.39736176, 22.20486069], [72.39736176, 22.2056942], [72.3970871, 22.20569038], [72.3970871, 22.20625114], [72.39679718, 22.20625114], [72.39679718, 22.20681], [72.39653015, 22.20680428], [72.39653015, 22.20708275], [72.39624786, 22.20708275], [72.39624786, 22.20736122], [72.39597321, 22.20734978], [72.39597321, 22.20763969], [72.39569092, 22.20763969], [72.39569092, 22.20792007], [72.39541626, 22.20791435], [72.39541626, 22.20819473], [72.3951416, 22.20819473], [72.3951416, 22.2084713], [72.39485931, 22.20846939], [72.39485931, 22.20874977], [72.39458466, 22.20874977], [72.39458466, 22.20930481], [72.39430237, 22.20930481], [72.39430237, 22.20986176], [72.39402771, 22.20986176], [72.39402771, 22.2104187], [72.39375305, 22.2104187], [72.39375305, 22.21097183], [72.39347076, 22.21096992], [72.39347076, 22.21153069], [72.39319611, 22.21152878], [72.39319611, 22.21208382], [72.39290619, 22.21207809], [72.39290619, 22.21264076], [72.39263916, 22.21264076], [72.39263916, 22.21319389], [72.39235687, 22.21318817], [72.39235687, 22.2134819], [72.39208221, 22.2134819], [72.39208221, 22.21375084], [72.3915329, 22.21375084], [72.3915329, 22.21403122], [72.39125061, 22.21403122], [72.39125061, 22.21430969], [72.39097595, 22.21430588], [72.39097595, 22.21458244], [72.39068604, 22.21458244], [72.39068604, 22.21486282], [72.39041901, 22.21486282], [72.39041901, 22.21513939], [72.38957977, 22.21513939], [72.38957977, 22.21541977], [72.38930511, 22.21541595], [72.38930511, 22.21569443], [72.38847351, 22.21569443], [72.38847351, 22.2159729], [72.38791656, 22.2159729], [72.38791656, 22.21624947], [72.38707733, 22.21624947], [72.38707733, 22.21653938], [72.38652802, 22.21653938], [72.38652802, 22.21681023], [72.38569641, 22.21680641], [72.38569641, 22.21708488], [72.38513947, 22.21708488], [72.38513947, 22.21736145], [72.38430786, 22.21735954], [72.38430786, 22.21763992], [72.38375092, 22.21763992], [72.38375092, 22.2179203], [72.38291931, 22.2179203], [72.38291931, 22.21820068], [72.38236237, 22.21819305], [72.38236237, 22.21847153], [72.38208008, 22.21846962], [72.38208008, 22.21903038], [72.38181305, 22.21903038], [72.38181305, 22.21931076], [72.38153076, 22.21930313], [72.38153076, 22.21986198], [72.38124847, 22.21986008], [72.38124847, 22.22042084], [72.38097382, 22.22041512], [72.38097382, 22.22069359], [72.38069153, 22.22068977], [72.38069153, 22.22125053], [72.38041687, 22.22125053], [72.38041687, 22.22153091], [72.38014221, 22.22152519], [72.38014221, 22.22208595], [72.37985992, 22.22208023], [72.37985992, 22.22264099], [72.3795929, 22.22264099], [72.3795929, 22.22291946], [72.37930298, 22.22291946], [72.37930298, 22.2234726], [72.37902832, 22.22347069], [72.37902832, 22.22375107], [72.37874603, 22.22375107], [72.37874603, 22.22430992], [72.37847137, 22.22430992], [72.37847137, 22.22485924], [72.37819672, 22.22485924], [72.37819672, 22.22513962], [72.37791443, 22.22513962], [72.37791443, 22.22569466], [72.37763977, 22.22569084], [72.37763977, 22.2262516], [72.37735748, 22.2262516], [72.37735748, 22.22736168], [72.37708282, 22.22736168], [72.37708282, 22.22820282], [72.37680817, 22.22819519], [72.37680817, 22.22850037], [72.37680817, 22.22863007], [72.37680817, 22.22903061], [72.37652588, 22.22903061], [72.37652588, 22.23014069], [72.37625122, 22.23013878], [72.37625122, 22.23097229], [72.37596893, 22.23097229], [72.37596893, 22.23208427], [72.37569427, 22.23208427], [72.37569427, 22.23597145], [72.37596893, 22.23596954], [72.37596893, 22.2365303], [72.37625122, 22.23652649], [72.37625122, 22.23736191], [72.37652588, 22.23735809], [72.37652588, 22.23792076], [72.37680817, 22.23792076], [72.37680817, 22.23875046], [72.37708282, 22.23875046], [72.37708282, 22.23930931], [72.37735748, 22.23930931], [72.37735748, 22.24014091], [72.37763977, 22.24014091], [72.37763977, 22.24041939], [72.37819672, 22.24041748], [72.37819672, 22.24069405], [72.37875366, 22.24069405], [72.37875366, 22.24097252], [72.37902832, 22.24097252], [72.37902832, 22.2412529], [72.37931061, 22.2412529], [72.37931061, 22.24152946], [72.3795929, 22.24152946], [72.3795929, 22.24180984], [72.37985992, 22.24180603], [72.37985992, 22.2420826], [72.38014221, 22.2420826], [72.38014221, 22.24263954], [72.38069153, 22.24263954], [72.38069153, 22.24319458], [72.38097382, 22.24319458], [72.38097382, 22.24347115], [72.38124847, 22.24346161], [72.38124847, 22.24403], [72.38153076, 22.24402809], [72.38153076, 22.24430466], [72.38208008, 22.24430466], [72.38208008, 22.24458313], [72.38236237, 22.24458313], [72.38236237, 22.2448616], [72.38263702, 22.2448597], [72.38263702, 22.24514008], [72.38291931, 22.24514008], [72.38291931, 22.24542046], [72.38318634, 22.24542046], [72.38318634, 22.24570084], [72.38346863, 22.24570084], [72.38346863, 22.24681091], [72.38208008, 22.24681091], [72.38208008, 22.24736023], [72.38180542, 22.24736023], [72.38180542, 22.24819374], [72.38153076, 22.24818993], [72.38153076, 22.24875069], [72.38124847, 22.24875069], [72.38124847, 22.24986076], [72.38153076, 22.24986076], [72.38153076, 22.25069427], [72.38181305, 22.25069046], [72.38181305, 22.25265121], [72.38208008, 22.25264168], [72.38208008, 22.25346947], [72.38153076, 22.25346947], [72.38153076, 22.25403023], [72.38124847, 22.25402832], [72.38124847, 22.25458336], [72.38096619, 22.25457954], [72.38096619, 22.2551403], [72.38069153, 22.2551403], [72.38069153, 22.2557106], [72.38041687, 22.2557106], [72.38041687, 22.25625038], [72.38014221, 22.25625038], [72.38014221, 22.25681114], [72.37985992, 22.25681114], [72.37985992, 22.25736046], [72.3795929, 22.25736046], [72.3795929, 22.25764084], [72.37930298, 22.25763893], [72.37930298, 22.25819206], [72.37902832, 22.25819206], [72.37902832, 22.25847244], [72.37874603, 22.25846291], [72.37874603, 22.25902939], [72.37847137, 22.25902939], [72.37847137, 22.25930977], [72.37819672, 22.25930977], [72.37819672, 22.25986099], [72.3779068, 22.25986099], [72.3779068, 22.26013947], [72.37763977, 22.26013947], [72.37763977, 22.2606945], [72.37735748, 22.2606945], [72.37735748, 22.26097298], [72.37680817, 22.26097107], [72.37680817, 22.26124954], [72.37623596, 22.26124954], [72.37623596, 22.26152992], [72.37568665, 22.26152992], [72.37568665, 22.2618103], [72.37513733, 22.2618084], [72.37513733, 22.26208305], [72.37430573, 22.26208305], [72.37430573, 22.26236153], [72.37374878, 22.26235962], [72.37374878, 22.26263809], [72.37291718, 22.26263809], [72.37291718, 22.26292038], [72.37236023, 22.26292038], [72.37236023, 22.26320076], [72.37152863, 22.26319695], [72.37152863, 22.2634716], [72.37097168, 22.2634697], [72.37097168, 22.26374817], [72.37014008, 22.26374817], [72.37014008, 22.26403046], [72.36958313, 22.26403046], [72.36958313, 22.26431084], [72.36818695, 22.26431084], [72.36818695, 22.26458931], [72.36680603, 22.26458931], [72.36680603, 22.26652908], [72.36541748, 22.26652908], [72.36541748, 22.26680946], [72.36374664, 22.26680565], [72.36374664, 22.26708412], [72.36235809, 22.2670784], [72.36235809, 22.26736259], [72.36180878, 22.26736259], [72.36180878, 22.2676506], [72.36152649, 22.2676506], [72.36152649, 22.26791954], [72.36096954, 22.26791763], [72.36096954, 22.2681942], [72.36013794, 22.2681942], [72.36013794, 22.26791763], [72.36003113, 22.26791763], [72.35986328, 22.26791954], [72.35986328, 22.2676506], [72.35930634, 22.2676506], [72.35930634, 22.26736259], [72.35901642, 22.26736259], [72.35901642, 22.2676506], [72.35874939, 22.26763916], [72.35874939, 22.2681942], [72.3584671, 22.26819038], [72.3584671, 22.27042007], [72.35819244, 22.27041626], [72.35819244, 22.2709713], [72.3576355, 22.2709713], [72.35764313, 22.27124977], [72.35624695, 22.27124977], [72.35624695, 22.27013969], [72.35597229, 22.27013969], [72.35597229, 22.26847267], [72.35624695, 22.26847267], [72.35624695, 22.26625061], [72.35652924, 22.26625061], [72.35652924, 22.26431084], [72.35679626, 22.26431084], [72.35679626, 22.26320076], [72.35708618, 22.26320076], [72.35708618, 22.26292038], [72.35736084, 22.26292038], [72.35736084, 22.26263809], [72.35764313, 22.26263809], [72.35764313, 22.26235962], [72.35791779, 22.26236153], [72.35791779, 22.26208305], [72.35819244, 22.26208305], [72.35819244, 22.2618084], [72.35874939, 22.26180077], [72.35874939, 22.26152611], [72.35901642, 22.26152992], [72.35901642, 22.26124954], [72.35913849, 22.26124954], [72.35930634, 22.26124954], [72.35930634, 22.26097107], [72.35958099, 22.26097298], [72.35958099, 22.2606945], [72.35986328, 22.2606945], [72.35986328, 22.26041412], [72.36069489, 22.26041412], [72.36069489, 22.2606945], [72.36096954, 22.2606945], [72.36096954, 22.26097298], [72.36180878, 22.26097298], [72.36180878, 22.2606945], [72.36235809, 22.2606945], [72.36235809, 22.26041412], [72.36319733, 22.26041985], [72.36319733, 22.25986099], [72.36347198, 22.25986099], [72.36347198, 22.25930977], [72.36374664, 22.25930977], [72.36374664, 22.25875092], [72.36402893, 22.25875092], [72.36402893, 22.25819016], [72.36430359, 22.25819206], [72.36430359, 22.25680542], [72.36402893, 22.25681114], [72.36402893, 22.2557106], [72.36429596, 22.2557106], [72.36429596, 22.2551403], [72.36458588, 22.2551403], [72.36458588, 22.25457954], [72.36486053, 22.25458336], [72.36486053, 22.25430489], [72.36513519, 22.25430489], [72.36513519, 22.25375175], [72.36541748, 22.25375175], [72.36541748, 22.25318909], [72.36569214, 22.25319481], [72.36569214, 22.2523613], [72.36597443, 22.2523613], [72.36597443, 22.25152969], [72.36624908, 22.25152969], [72.36624908, 22.25097084], [72.36653137, 22.25097275], [72.36653137, 22.25013733], [72.36680603, 22.25014114], [72.36680603, 22.24958992], [72.36708069, 22.24958992], [72.36708069, 22.24903107], [72.36737061, 22.24903107], [72.36737061, 22.24875069], [72.36763763, 22.24875069], [72.36763763, 22.24847031], [72.36791992, 22.24847221], [72.36791992, 22.24791527], [72.36818695, 22.24792099], [72.36818695, 22.24764061], [72.36846924, 22.24764061], [72.36846924, 22.24736023], [72.36875153, 22.24736023], [72.36875153, 22.24681091], [72.36902618, 22.24681091], [72.36902618, 22.246521], [72.36930847, 22.24652863], [72.36930847, 22.24625015], [72.36985779, 22.24625015], [72.36985779, 22.24596977], [72.37014008, 22.24597168], [72.37014008, 22.24569321], [72.3704071, 22.24570084], [72.3704071, 22.24542046], [72.37069702, 22.24542046], [72.37069702, 22.24514008], [72.37097168, 22.24514008], [72.37097168, 22.24403], [72.37069702, 22.24403], [72.37069702, 22.24263954], [72.3704071, 22.24263954], [72.3704071, 22.2420826], [72.37014008, 22.2420826], [72.37014008, 22.24152756], [72.36985779, 22.24152946], [72.36985779, 22.24097252], [72.36958313, 22.24097252], [72.36958313, 22.24041748], [72.36930847, 22.24041939], [72.36930847, 22.23985863], [72.36902618, 22.23985863], [72.36902618, 22.23957825], [72.36875153, 22.23958397], [72.36875153, 22.2393055], [72.36846924, 22.23930931], [72.36846924, 22.23875046], [72.36818695, 22.23875046], [72.36818695, 22.23846817], [72.36791992, 22.23847008], [72.36791992, 22.23819542], [72.36763763, 22.2381897], [72.36763763, 22.23791885], [72.36737061, 22.23792076], [72.36737061, 22.23765182], [72.36708069, 22.23765182], [72.36708069, 22.23707962], [72.36680603, 22.23708344], [72.36680603, 22.23652649], [72.36653137, 22.2365303], [72.36653137, 22.23624992], [72.36624908, 22.23624992], [72.36624908, 22.23569107], [72.36597443, 22.23569679], [72.36597443, 22.23541641], [72.36569214, 22.23542023], [72.36569214, 22.23485947], [72.36541748, 22.23486137], [72.36541748, 22.23430443], [72.36514282, 22.23431015], [72.36514282, 22.23402977], [72.36486053, 22.23402977], [72.36486053, 22.23347092], [72.36458588, 22.23347282], [72.36458588, 22.23319435], [72.36430359, 22.23319435], [72.36430359, 22.23291588], [72.36402893, 22.23291969], [72.36402893, 22.23236084], [72.36374664, 22.23236084], [72.36374664, 22.23208046], [72.36347198, 22.23208427], [72.36347198, 22.2318058], [72.36319733, 22.23180962], [72.36319733, 22.23125076], [72.36291504, 22.23125076], [72.36291504, 22.23097229], [72.36264038, 22.23097229], [72.36264038, 22.23041725], [72.36235809, 22.23042107], [72.36235809, 22.23014069], [72.36207581, 22.23014069], [72.36207581, 22.22958183], [72.36180878, 22.22958374], [72.36180878, 22.2290287], [72.36152649, 22.22903061], [72.36152649, 22.22875023], [72.36123657, 22.22875023], [72.36123657, 22.22820282], [72.36096954, 22.22820282], [72.36096954, 22.22736168], [72.36069489, 22.22736168], [72.36069489, 22.2262516], [72.36042023, 22.2262516], [72.36042023, 22.22513962], [72.36013794, 22.22513962], [72.36013794, 22.22235107], [72.36042023, 22.22236061], [72.36042023, 22.22069359], [72.36013794, 22.22069359], [72.36013794, 22.22041512], [72.36042023, 22.22042084], [72.36042023, 22.2179203], [72.36068726, 22.2179203], [72.36068726, 22.21513939], [72.36096954, 22.21513939], [72.36096954, 22.21235847], [72.36123657, 22.21235847], [72.36123657, 22.21014023], [72.36096954, 22.21014023], [72.36096954, 22.20930099], [72.36125183, 22.20930481], [72.36125183, 22.20819473], [72.36152649, 22.20819473], [72.36152649, 22.20708275], [72.36180878, 22.20708275], [72.36180878, 22.20624924], [72.36207581, 22.20625114], [72.36207581, 22.20514107], [72.36235809, 22.20514107], [72.36235809, 22.20458031], [72.36264038, 22.20458221], [72.36264038, 22.20375061], [72.36292267, 22.20375061], [72.36291504, 22.20319366], [72.36319733, 22.20319366], [72.36319733, 22.2029171], [72.36347198, 22.20292282], [72.36347198, 22.20264053], [72.36374664, 22.20264053], [72.36374664, 22.20208168], [72.36402893, 22.20208359], [72.36402893, 22.20180511], [72.36429596, 22.20181274], [72.36429596, 22.20153999], [72.36486053, 22.20153999], [72.36486053, 22.2009716], [72.36541748, 22.2009716], [72.36541748, 22.20069504], [72.3659668, 22.20070267], [72.3659668, 22.20042038], [72.36653137, 22.20042038], [72.36653137, 22.20014191], [72.36737061, 22.20014191], [72.36737061, 22.19986153], [72.36763763, 22.19986153], [72.36763763, 22.19958305], [72.36846924, 22.19958305], [72.36846924, 22.19930649], [72.36930847, 22.19930077], [72.36930847, 22.19902992], [72.36985779, 22.19903183], [72.36985779, 22.19874763], [72.37069702, 22.19874763], [72.37069702, 22.19846916], [72.37124634, 22.19847298], [72.37124634, 22.1981945], [72.37208557, 22.1981945], [72.37208557, 22.19763947], [72.37403107, 22.19763947], [72.37403107, 22.19735909], [72.37513733, 22.19735909], [72.37513733, 22.19708061], [72.37652588, 22.19708252], [72.37652588, 22.19680786], [72.37735748, 22.19680977], [72.37735748, 22.19652939], [72.3779068, 22.19652939], [72.3779068, 22.19625092], [72.37847137, 22.19625092], [72.37847137, 22.19597054], [72.37902832, 22.19597244], [72.37902832, 22.19569397], [72.37958527, 22.19569397], [72.37958527, 22.1954155], [72.37985992, 22.1954155], [72.37985992, 22.19513893], [72.38041687, 22.19514084], [72.38041687, 22.19486046], [72.38069153, 22.19486046], [72.38069153, 22.19458008], [72.38097382, 22.19458389], [72.38097382, 22.19430542], [72.38124847, 22.19431114], [72.38124847, 22.19403076], [72.38153076, 22.19403076], [72.38153076, 22.19375038], [72.38181305, 22.19375038], [72.38180542, 22.19347191], [72.38236237, 22.19347191], [72.38236237, 22.19319534], [72.38263702, 22.19320107], [72.38263702, 22.19292068], [72.38291931, 22.19292068], [72.38291931, 22.1926403], [72.38318634, 22.1926403], [72.38318634, 22.19236946], [72.38346863, 22.19236946], [72.38346863, 22.19207954], [72.38375092, 22.19208336], [72.38375092, 22.19180489], [72.38402557, 22.19180489], [72.38402557, 22.19152832], [72.38430786, 22.19153023], [72.38430786, 22.19124985], [72.38458252, 22.19124985], [72.38458252, 22.19096947], [72.38486481, 22.19097137], [72.38486481, 22.19041634], [72.38513947, 22.19042015], [72.38513947, 22.19013977], [72.38540649, 22.19013977], [72.38540649, 22.18985939], [72.38569641, 22.1898613], [72.38569641, 22.18958282], [72.38597107, 22.18958282], [72.38597107, 22.18930626], [72.38625336, 22.18931007], [72.38625336, 22.18902969], [72.38652802, 22.18902969], [72.38652802, 22.18847275], [72.38680267, 22.18847275], [72.38680267, 22.18819427], [72.38708496, 22.18819427], [72.38708496, 22.18763924], [72.38735962, 22.18764114], [72.38735962, 22.18736267], [72.38764191, 22.18736267], [72.38764191, 22.18680954], [72.38791656, 22.18680954], [72.38791656, 22.18652916], [72.38817596, 22.18652916], [72.38817596, 22.18624115], [72.38847351, 22.18625069], [72.38847351, 22.18569374], [72.38874817, 22.18569374], [72.38874817, 22.18541718], [72.38903046, 22.18541908], [72.38903046, 22.18488121], [72.38931274, 22.18485832], [72.38930511, 22.18430519], [72.38957977, 22.18431091], [72.38957977, 22.18403053], [72.38986206, 22.18403053], [72.38986206, 22.18346977], [72.39013672, 22.18347168], [72.39013672, 22.18263626], [72.38986206, 22.18264008], [72.38986206, 22.1823597], [72.39013672, 22.1823616], [72.39013672, 22.18180466], [72.39041901, 22.18180466], [72.39041901, 22.18152618], [72.39068604, 22.18153], [72.39068604, 22.18097115], [72.39097595, 22.18097305], [72.39097595, 22.18069458], [72.39125061, 22.18069458], [72.39125061, 22.18013954], [72.3915329, 22.18013954], [72.39152527, 22.1795826], [72.39125061, 22.1795826], [72.39125061, 22.17930412], [72.39013672, 22.17930984], [72.39013672, 22.17875099], [72.38986206, 22.17875099], [72.38986206, 22.17764091], [72.38957977, 22.17764091], [72.38957977, 22.17653084], [72.38931274, 22.17653084], [72.38931274, 22.17542076], [72.38903046, 22.17542076], [72.38903046, 22.17429924], [72.38930511, 22.17430496], [72.38930511, 22.17319489], [72.38957977, 22.17319489], [72.38957977, 22.1720829], [72.38986206, 22.1720829], [72.38986206, 22.17097282], [72.39013672, 22.17097282], [72.39013672, 22.17041779], [72.39041901, 22.17041969], [72.39041901, 22.16986084], [72.39068604, 22.16986084], [72.39068604, 22.16930962], [72.39097595, 22.16930962], [72.39097595, 22.16875076], [72.39125061, 22.16875076], [72.39125061, 22.16818047], [72.39152527, 22.16819382], [72.39152527, 22.16791534], [72.39097595, 22.16792107], [72.39097595, 22.16764069], [72.39068604, 22.16764069], [72.39068604, 22.16736031], [72.39013672, 22.16736031], [72.39013672, 22.16707993], [72.38986206, 22.16708374], [72.38986206, 22.16680527], [72.38957977, 22.16681099], [72.38957977, 22.16764069], [72.38930511, 22.16763878], [72.38931274, 22.16986084], [72.38903046, 22.16986084], [72.38903046, 22.17097282], [72.38874817, 22.17097282], [72.38874817, 22.17124748], [72.38846588, 22.17123985], [72.38846588, 22.17152977], [72.38791656, 22.17152977], [72.38791656, 22.17180824], [72.38764191, 22.17180634], [72.38764191, 22.1720829], [72.38735962, 22.1720829], [72.38735962, 22.17236137], [72.38652802, 22.17236137], [72.38652802, 22.17180634], [72.38625336, 22.17180824], [72.38625336, 22.17123985], [72.38597107, 22.17124748], [72.38597107, 22.17097282], [72.38569641, 22.17097282], [72.38569641, 22.17041779], [72.38540649, 22.17041969], [72.38540649, 22.17014122], [72.38569641, 22.17014122], [72.38569641, 22.16958046], [72.38597107, 22.16958237], [72.38597107, 22.16930771], [72.38625336, 22.16930962], [72.38625336, 22.16875076], [72.38652802, 22.16875076], [72.38652802, 22.16764069], [72.38625336, 22.16764069], [72.38625336, 22.16543007], [72.38597107, 22.16543007], [72.38597107, 22.16319275], [72.38625336, 22.16319466], [72.38625336, 22.16180611], [72.38652802, 22.16180992], [72.38652802, 22.1609726], [72.38680267, 22.1609726], [72.38680267, 22.16041756], [72.38707733, 22.16041946], [72.38707733, 22.15986061], [72.38680267, 22.15986061], [72.38680267, 22.15957832], [72.38652802, 22.15958405], [72.38652802, 22.1590271], [72.38625336, 22.15903091], [72.38625336, 22.15875053], [72.38597107, 22.15875053], [72.38597107, 22.15846825], [72.38569641, 22.15847206], [72.38569641, 22.15819359], [72.38541412, 22.15819359], [72.38541412, 22.15764046], [72.38513947, 22.15764046], [72.38513947, 22.15735817], [72.38486481, 22.15736198], [72.38486481, 22.15708351], [72.38458252, 22.15708351], [72.38458252, 22.15680695], [72.38430786, 22.15681076], [72.38430786, 22.15624046], [72.38402557, 22.15624809], [72.38402557, 22.15597153], [72.38346863, 22.15597153], [72.38346863, 22.15624809], [72.38291931, 22.15624046], [72.38291931, 22.15653038], [72.38237, 22.15653038], [72.38237, 22.15681076], [72.38180542, 22.15680695], [72.38180542, 22.15708351], [72.38124847, 22.15708351], [72.38124847, 22.15736198], [72.38069153, 22.15735817], [72.38069153, 22.15764046], [72.38014221, 22.15764046], [72.38014221, 22.15792084], [72.37958527, 22.15791893], [72.37958527, 22.15819359], [72.37902832, 22.15819359], [72.37902832, 22.15847206], [72.37735748, 22.15847206], [72.37735748, 22.15819359], [72.37708282, 22.15819359], [72.37708282, 22.15680695], [72.37735748, 22.15681076], [72.37735748, 22.15653038], [72.37763977, 22.15653038], [72.37763977, 22.15570068], [72.3779068, 22.15570068], [72.3779068, 22.15402985], [72.37819672, 22.15402985], [72.37819672, 22.15347099], [72.37847137, 22.1534729], [72.37847137, 22.15208244], [72.37875366, 22.15208244], [72.37875366, 22.1515274], [72.37847137, 22.15153122], [72.37847137, 22.15097046], [72.37819672, 22.15097237], [72.37819672, 22.15069389], [72.37791443, 22.15069389], [72.37791443, 22.15041733], [72.37680817, 22.15042114], [72.37680817, 22.14986038], [72.37596893, 22.14986038], [72.37596893, 22.15042114], [72.37541962, 22.15041733], [72.37541962, 22.15069389], [72.37513733, 22.15069389], [72.37513733, 22.15097237], [72.37486267, 22.15097046], [72.37486267, 22.15153122], [72.37458038, 22.15153122], [72.37458038, 22.15180969], [72.37430573, 22.15180588], [72.37430573, 22.15708351], [72.37403107, 22.1570797], [72.37403107, 22.15792084], [72.37431335, 22.15792084], [72.37431335, 22.16013908], [72.37403107, 22.16013908], [72.37403107, 22.16180992], [72.37430573, 22.16180611], [72.37430573, 22.16347313], [72.37458038, 22.16347122], [72.37458038, 22.16514015], [72.37486267, 22.16514015], [72.37486267, 22.16653061], [72.37458038, 22.1665287], [72.37458038, 22.16708374], [72.37431335, 22.16707993], [72.37431335, 22.16764069], [72.37403107, 22.16763878], [72.37403107, 22.16819382], [72.37374878, 22.16818047], [72.37374878, 22.16875076], [72.37346649, 22.16875076], [72.37346649, 22.16930962], [72.37317657, 22.16930962], [72.37317657, 22.16986084], [72.37291718, 22.16986084], [72.37291718, 22.17041969], [72.37264252, 22.17041779], [72.37264252, 22.17097282], [72.37236023, 22.17097282], [72.37236023, 22.17124748], [72.3720932, 22.17123985], [72.3720932, 22.17180824], [72.37180328, 22.17180634], [72.37180328, 22.1720829], [72.37124634, 22.1720829], [72.37124634, 22.17236137], [72.37069702, 22.17235756], [72.37069702, 22.17264175], [72.36958313, 22.17264175], [72.36958313, 22.17235756], [72.36818695, 22.17235756], [72.36818695, 22.17264175], [72.36708069, 22.17264175], [72.36708069, 22.17292023], [72.36597443, 22.17291641], [72.36597443, 22.17319489], [72.36486053, 22.17319489], [72.36486053, 22.17347145], [72.36235809, 22.17347145], [72.36235809, 22.17319489], [72.36125183, 22.17319489], [72.36125183, 22.17291641], [72.35986328, 22.17292023], [72.35986328, 22.17264175], [72.35901642, 22.17264175], [72.35901642, 22.1740303], [72.35930634, 22.1740284], [72.35930634, 22.17486191], [72.35902405, 22.17486191], [72.35902405, 22.17597389], [72.35930634, 22.17597389], [72.35930634, 22.17708206], [72.35958099, 22.17708206], [72.35958099, 22.17819214], [72.35986328, 22.17819023], [72.35986328, 22.17902946], [72.36013794, 22.17902756], [72.36013794, 22.1795826], [72.36042023, 22.17958069], [72.36042023, 22.18013954], [72.36068726, 22.18013954], [72.36068726, 22.18042946], [72.36096954, 22.1804142], [72.36096954, 22.18097305], [72.36123657, 22.18097115], [72.36123657, 22.18124962], [72.36152649, 22.18124962], [72.36152649, 22.18153], [72.36180878, 22.18152618], [72.36180878, 22.18208313], [72.36208344, 22.18208313], [72.36208344, 22.1823616], [72.36235809, 22.1823597], [72.36235809, 22.18292046], [72.36264038, 22.18291855], [72.36264038, 22.18347168], [72.36291504, 22.18347168], [72.36291504, 22.18458366], [72.36319733, 22.18458366], [72.36319733, 22.18625069], [72.36347198, 22.18624115], [72.36347198, 22.18791962], [72.36374664, 22.18791962], [72.36374664, 22.18902969], [72.36319733, 22.18902969], [72.36319733, 22.18931007], [72.36264038, 22.18930626], [72.36264038, 22.18958282], [72.36208344, 22.18958282], [72.36208344, 22.1898613], [72.36152649, 22.18985939], [72.36152649, 22.19013977], [72.36123657, 22.19013977], [72.36123657, 22.19042015], [72.36096954, 22.19041634], [72.36096954, 22.19069481], [72.36068726, 22.1906929], [72.36068726, 22.19124985], [72.36042023, 22.19124985], [72.36042023, 22.19153023], [72.36013794, 22.19152832], [72.36013794, 22.19180489], [72.35986328, 22.19180489], [72.35986328, 22.19208336], [72.35958099, 22.19207954], [72.35958099, 22.19236946], [72.35930634, 22.19236946], [72.35930634, 22.19292068], [72.35901642, 22.19292068], [72.35901642, 22.19320107], [72.35820007, 22.19320107], [72.35820007, 22.19292068], [72.35764313, 22.19292068], [72.35764313, 22.1926403], [72.35791779, 22.1926403], [72.35791779, 22.19207954], [72.35819244, 22.19208336], [72.35819244, 22.19180489], [72.35847473, 22.19180489], [72.35847473, 22.19124985], [72.35874939, 22.19124985], [72.35874939, 22.19096947], [72.35902405, 22.19097137], [72.35902405, 22.19069481], [72.35930634, 22.19069481], [72.35930634, 22.19013977], [72.35958099, 22.19013977], [72.35958099, 22.18985939], [72.35986328, 22.1898613], [72.35986328, 22.18930626], [72.36013794, 22.18931007], [72.36013794, 22.18791962], [72.35986328, 22.18791962], [72.35986328, 22.18652916], [72.35958099, 22.18652916], [72.35958099, 22.1859684], [72.35930634, 22.18597221], [72.35930634, 22.18569374], [72.35902405, 22.18569374], [72.35902405, 22.18541718], [72.35874939, 22.18541908], [72.35874939, 22.18485832], [72.3584671, 22.18485832], [72.3584671, 22.18457985], [72.35819244, 22.18458366], [72.35819244, 22.18430519], [72.35791779, 22.18431091], [72.35791779, 22.18403053], [72.35764313, 22.18403053], [72.35764313, 22.18374825], [72.35736084, 22.18374825], [72.35736084, 22.18346977], [72.35708618, 22.18347168], [72.35708618, 22.18319511], [72.35679626, 22.18320084], [72.35679626, 22.18292046], [72.35652924, 22.18292046], [72.35652924, 22.1823597], [72.35624695, 22.1823616], [72.35624695, 22.18208313], [72.35597229, 22.18208313], [72.35597229, 22.18180466], [72.35541534, 22.18180466], [72.35541534, 22.18208313], [72.35514069, 22.18208313], [72.35514069, 22.1823616], [72.35375214, 22.1823597], [72.35375214, 22.18264008], [72.35206604, 22.18264008], [72.35206604, 22.18208122], [72.35180664, 22.18208313], [72.35180664, 22.18152618], [72.35206604, 22.18153], [72.35206604, 22.18124962], [72.35263824, 22.18124962], [72.35263824, 22.18097115], [72.3529129, 22.18097305], [72.3529129, 22.18069458], [72.35346985, 22.18069458], [72.35346985, 22.1804142], [72.35375214, 22.18042946], [72.35375214, 22.17764091], [72.35402679, 22.17764091], [72.35402679, 22.17457962], [72.35430908, 22.17458344], [72.35430908, 22.17236137], [72.35458374, 22.17236137], [72.35458374, 22.17013741], [72.35402679, 22.17014122], [72.35402679, 22.16764069], [72.35375214, 22.16764069], [72.35375214, 22.16720009], [72.35375214, 22.16625023], [72.35346985, 22.16625023], [72.35346985, 22.16514015], [72.35320282, 22.16514015], [72.35320282, 22.16457939], [72.35152435, 22.16458321], [72.35152435, 22.16486168], [72.35098267, 22.16485977], [72.35098267, 22.16514015], [72.35069275, 22.16514015], [72.35069275, 22.16543007], [72.3501358, 22.16543007], [72.3501358, 22.16570091], [72.34986115, 22.16569328], [72.34986115, 22.16597176], [72.34929657, 22.16596985], [72.34929657, 22.16625023], [72.34902954, 22.16625023], [72.34902954, 22.16653061], [72.3484726, 22.16653061], [72.3484726, 22.16681099], [72.34819794, 22.16680527], [72.34819794, 22.16708374], [72.34791565, 22.16708374], [72.34792328, 22.16736031], [72.34764099, 22.16736031], [72.34764099, 22.16764069], [72.34707642, 22.16764069], [72.34707642, 22.16792107], [72.34680939, 22.16791534], [72.34680176, 22.16819382], [72.3465271, 22.16819382], [72.3465271, 22.16847229], [72.34402466, 22.16847229], [72.34402466, 22.16819382], [72.34430695, 22.16819382], [72.34430695, 22.16763878], [72.3445816, 22.16764069], [72.3445816, 22.16707993], [72.34486389, 22.16708374], [72.34486389, 22.16680527], [72.34513855, 22.16681099], [72.34513855, 22.16625023], [72.34541321, 22.16625023], [72.34541321, 22.16570091], [72.34570313, 22.16570091], [72.34570313, 22.16543007], [72.34597015, 22.16543007], [72.34597015, 22.16485977], [72.34625244, 22.16486168], [72.34625244, 22.16458321], [72.3465271, 22.16458321], [72.3465271, 22.16402817], [72.34680176, 22.16403008], [72.34680176, 22.16347122], [72.34708405, 22.16347313], [72.34708405, 22.16319466], [72.34791565, 22.16319466], [72.34791565, 22.16291618], [72.34819794, 22.16292], [72.34819794, 22.16263962], [72.34902954, 22.16263962], [72.34902954, 22.16236115], [72.35069275, 22.16236115], [72.35069275, 22.16208267], [72.35152435, 22.16208267], [72.35152435, 22.16180611], [72.35206604, 22.16180992], [72.35206604, 22.16152954], [72.3529129, 22.16152954], [72.3529129, 22.16125107], [72.35375214, 22.16125107], [72.35375214, 22.16069031], [72.35402679, 22.16069412], [72.35402679, 22.15958405], [72.35430908, 22.15958405], [72.35430908, 22.15847206], [72.35458374, 22.15847206], [72.35458374, 22.15764046], [72.3548584, 22.15764046], [72.3548584, 22.15653038], [72.35514069, 22.15653038], [72.35514069, 22.15570068], [72.3554306, 22.15570068], [72.3554306, 22.15458107], [72.35569763, 22.15458298], [72.35569763, 22.1534729], [72.35597229, 22.1534729], [72.35597229, 22.15263939], [72.35624695, 22.15263939], [72.35624695, 22.15153122], [72.35652924, 22.15153122], [72.35652924, 22.15042114], [72.35679626, 22.15042114], [72.35679626, 22.15014076], [72.35652924, 22.15014076], [72.35652924, 22.1482029], [72.35624695, 22.1482029], [72.35624695, 22.14736176], [72.35597229, 22.14736176], [72.35597229, 22.14680481], [72.35569763, 22.14680481], [72.35569763, 22.14652824], [72.3529129, 22.14652824], [72.3529129, 22.14708328], [72.35263824, 22.14706993], [72.35263824, 22.14792061], [72.35151672, 22.14792061], [72.35151672, 22.14764023], [72.35124969, 22.14764023], [72.35124969, 22.14736176], [72.35069275, 22.14736176], [72.35069275, 22.14652824], [72.35041809, 22.14653015], [72.35041809, 22.14513969], [72.3501358, 22.14513969], [72.3501358, 22.14486122], [72.35041809, 22.14486122], [72.35041809, 22.14458084], [72.35069275, 22.14458275], [72.35069275, 22.14430618], [72.35097504, 22.14430618], [72.35097504, 22.14402962], [72.35124969, 22.14402962], [72.35124969, 22.14347076], [72.35152435, 22.14347267], [72.35152435, 22.14291573], [72.35180664, 22.14291954], [72.35180664, 22.14236069], [72.35206604, 22.14236069], [72.35206604, 22.14153099], [72.35235596, 22.14153099], [72.35235596, 22.13652992], [72.35206604, 22.13652992], [72.35206604, 22.13597107], [72.35180664, 22.13597107], [72.35180664, 22.1356945], [72.35152435, 22.1356945], [72.35152435, 22.13541603], [72.35098267, 22.13541985], [72.35098267, 22.1348629], [72.35069275, 22.1348629], [72.35069275, 22.13402939], [72.35041809, 22.13402939], [72.35041809, 22.13291931], [72.3501358, 22.13291931], [72.3501358, 22.13235855], [72.34986115, 22.13235855], [72.34986115, 22.13125038], [72.34958649, 22.13125038], [72.34958649, 22.12985992], [72.34986115, 22.12986183], [72.34986115, 22.12847137], [72.3501358, 22.12847137], [72.3501358, 22.12680435], [72.34986115, 22.12681007], [72.34986115, 22.12652969], [72.34874725, 22.12652969], [72.34874725, 22.12626076], [72.34764099, 22.12626076], [72.34764099, 22.12597084], [72.3465271, 22.12597275], [72.3465271, 22.12569427], [72.34513855, 22.12569427], [72.34513855, 22.1254158], [72.34375, 22.12541962], [72.34375, 22.12514114], [72.3434906, 22.12514114], [72.3434906, 22.12486076], [72.34179687, 22.12486076], [72.34179687, 22.12458038], [72.34124756, 22.12458038], [72.34124756, 22.12486076], [72.3409729, 22.12486076], [72.3409729, 22.12597275], [72.34124756, 22.12597084], [72.34124756, 22.12652969], [72.34152985, 22.12652779], [72.34152985, 22.12708282], [72.34179687, 22.12708092], [72.34179687, 22.12763977], [72.34208679, 22.12763977], [72.34208679, 22.12847137], [72.34236145, 22.12847137], [72.34236145, 22.12958336], [72.34263611, 22.12958336], [72.34263611, 22.13319397], [72.34236145, 22.13319397], [72.34236145, 22.13513947], [72.34208679, 22.13513947], [72.34208679, 22.1356945], [72.3418045, 22.1356945], [72.3418045, 22.13597107], [72.34152985, 22.13597107], [72.34152985, 22.13624954], [72.34124756, 22.13624954], [72.34124756, 22.1368103], [72.3409729, 22.13680649], [72.3409729, 22.13708305], [72.34069824, 22.13708115], [72.34069824, 22.13764], [72.34041595, 22.13764], [72.34041595, 22.13792038], [72.34012604, 22.13792038], [72.34012604, 22.13820076], [72.33985901, 22.13819313], [72.33985901, 22.1384716], [72.33957672, 22.1384697], [72.33957672, 22.13875008], [72.33875275, 22.13875008], [72.33875275, 22.13903046], [72.33651733, 22.13903046], [72.33651733, 22.13875008], [72.33486176, 22.13875008], [72.33486176, 22.13903046], [72.3345871, 22.13902855], [72.3345871, 22.13958359], [72.33430481, 22.13958359], [72.33430481, 22.14069366], [72.33403015, 22.14069366], [72.33403015, 22.14097214], [72.33291626, 22.14097023], [72.33291626, 22.14126015], [72.3326416, 22.14126015], [72.3326416, 22.14153099], [72.33235931, 22.14153099], [72.33235931, 22.14180946], [72.33152771, 22.14180756], [72.33152771, 22.14208412], [72.33069611, 22.14208031], [72.33069611, 22.14236069], [72.33040619, 22.14238167], [72.33040619, 22.14291954], [72.33022308, 22.14291573], [72.3298645, 22.14291954], [72.3298645, 22.1431942], [72.32958221, 22.1431942], [72.32958221, 22.14347267], [72.3290329, 22.14347076], [72.3290329, 22.14375114], [72.32875061, 22.14375114], [72.32875061, 22.14402962], [72.32847595, 22.14402962], [72.32847595, 22.14458275], [72.32818604, 22.14458084], [72.32818604, 22.14486122], [72.32791901, 22.14486122], [72.32791901, 22.14513969], [72.32707977, 22.14513969], [72.32707977, 22.14541817], [72.32653046, 22.14541626], [72.32653046, 22.14569473], [72.32597351, 22.14569473], [72.32597351, 22.14596939], [72.32541656, 22.14596939], [72.32541656, 22.14625168], [72.32485962, 22.14625168], [72.32485962, 22.14653015], [72.32458496, 22.14652824], [72.32458496, 22.14680481], [72.32375336, 22.14680481], [72.32375336, 22.14708328], [72.32236481, 22.14708328], [72.32236481, 22.14680481], [72.32180786, 22.14680481], [72.32180786, 22.14652824], [72.32096863, 22.14653015], [72.32096863, 22.14625168], [72.31986237, 22.14625168], [72.31986237, 22.14653015], [72.31958008, 22.14652824], [72.31958008, 22.14680481], [72.31930542, 22.14680481], [72.31930542, 22.14736176], [72.31903076, 22.14736176], [72.31903076, 22.14792061], [72.31819153, 22.14792061], [72.31819153, 22.14764023], [72.31764221, 22.14764023], [72.31764221, 22.14736176], [72.31735992, 22.14736176], [72.31735992, 22.14708328], [72.31680298, 22.14708328], [72.31680298, 22.14680481], [72.31652832, 22.14680481], [72.31652832, 22.14652824], [72.31624603, 22.14653015], [72.31624603, 22.15125084], [72.31597137, 22.15125084], [72.31597137, 22.15153122], [72.31624603, 22.15153122], [72.31624603, 22.15263939], [72.31597137, 22.15263939], [72.31597137, 22.1554203], [72.31624603, 22.1554203], [72.31624603, 22.15653038], [72.31652832, 22.15652657], [72.31652832, 22.15736198], [72.31625366, 22.15736198], [72.31625366, 22.15930557], [72.31597137, 22.15930557], [72.31597137, 22.15958405], [72.31624603, 22.15957832], [72.31624603, 22.16013908], [72.31652832, 22.16013908], [72.31652832, 22.1609726], [72.31680298, 22.1609726], [72.31680298, 22.16236115], [72.31708527, 22.16236115], [72.31708527, 22.16347313], [72.31735992, 22.16347313], [72.31735992, 22.16486168], [72.31764221, 22.16486168], [72.31764221, 22.16708374], [72.31791687, 22.16707993], [72.31791687, 22.16792107], [72.31819153, 22.16792107], [72.31819153, 22.16875076], [72.31846619, 22.16875076], [72.31846619, 22.16930962], [72.31874847, 22.16930962], [72.31874847, 22.17014122], [72.31887054, 22.17014122], [72.31903076, 22.17013741], [72.31903076, 22.17097282], [72.31932068, 22.17097092], [72.31932068, 22.17180824], [72.31958008, 22.17180824], [72.31958008, 22.17292023], [72.31932068, 22.17292023], [72.31932068, 22.1740303], [72.31909943, 22.1740303], [72.31903076, 22.17514038], [72.31874847, 22.17514038], [72.31874847, 22.17625046], [72.31846619, 22.17625046], [72.31846619, 22.17737007], [72.31819153, 22.17736053], [72.31819153, 22.17847252], [72.31791687, 22.17847252], [72.31791687, 22.1795826], [72.31764221, 22.1795826], [72.31764221, 22.18069458], [72.31735992, 22.18069077], [72.31735992, 22.18124962], [72.31708527, 22.18124962], [72.31708527, 22.18208313], [72.31680298, 22.18208122], [72.31680298, 22.18264008], [72.31652832, 22.18264008], [72.31652832, 22.18320084], [72.31624603, 22.18320084], [72.31624603, 22.18403053], [72.31597137, 22.18402863], [72.31597137, 22.18458366], [72.31569672, 22.18457985], [72.31569672, 22.18514061], [72.31513977, 22.18514061], [72.31513977, 22.18541908], [72.31485748, 22.18541718], [72.31485748, 22.18569374], [72.31430817, 22.18569374], [72.31430817, 22.18597221], [72.31375122, 22.18597221], [72.31375122, 22.18625069], [72.31346893, 22.18624115], [72.31346893, 22.18652916], [72.31291962, 22.18652916], [72.31291962, 22.18680954], [72.31263733, 22.18680573], [72.31263733, 22.1870842], [72.31208038, 22.18707848], [72.31208038, 22.18736267], [72.31124878, 22.18736267], [72.31124878, 22.18764114], [72.31069183, 22.18764114], [72.31069183, 22.18791962], [72.30986023, 22.1879158], [72.30986023, 22.18819427], [72.30930328, 22.18819427], [72.30930328, 22.18847275], [72.30874634, 22.18847275], [72.30874634, 22.18875122], [72.30819702, 22.18875122], [72.30819702, 22.18902969], [72.3079071, 22.18902969], [72.3079071, 22.18931007], [72.30735779, 22.18930626], [72.30735779, 22.18958282], [72.30708313, 22.18958282], [72.30708313, 22.1898613], [72.30680847, 22.18985939], [72.30680847, 22.19013977], [72.30652618, 22.19013977], [72.30652618, 22.19042015], [72.30625153, 22.19041634], [72.30625153, 22.19069481], [72.30596924, 22.19069481], [72.30596924, 22.19097137], [72.30568695, 22.19096947], [72.30568695, 22.19124985], [72.30513763, 22.19124985], [72.30513763, 22.19153023], [72.30486298, 22.19152832], [72.30486298, 22.19180489], [72.30458069, 22.19180489], [72.30458069, 22.19208336], [72.30430603, 22.19207954], [72.30430603, 22.19236946], [72.30403137, 22.19236946], [72.30403137, 22.1926403], [72.30374908, 22.1926403], [72.30374908, 22.19292068], [72.3034668, 22.19292068], [72.3034668, 22.19320107], [72.30208588, 22.19320107], [72.30208588, 22.19292068], [72.30095673, 22.19292068], [72.30095673, 22.1926403], [72.29985809, 22.1926403], [72.29985809, 22.19292068], [72.29957581, 22.19292068], [72.29957581, 22.19320107], [72.29985809, 22.19320107], [72.29985809, 22.19375038], [72.30014038, 22.19375038], [72.30014038, 22.19458389], [72.29985809, 22.19458389], [72.29985809, 22.1954155], [72.29958344, 22.1954155], [72.29958344, 22.19597244], [72.29930878, 22.19597054], [72.29930878, 22.19680977], [72.29902649, 22.19680977], [72.29902649, 22.19763947], [72.29875183, 22.19763947], [72.29875183, 22.19847298], [72.29846954, 22.19846916], [72.29846954, 22.1993103], [72.29819489, 22.19930649], [72.29819489, 22.19986153], [72.29792023, 22.19986153], [72.29792023, 22.20070267], [72.29763794, 22.20070267], [72.29763794, 22.20125008], [72.29708099, 22.20125008], [72.29708099, 22.20153999], [72.29651642, 22.20153999], [72.29651642, 22.20181274], [72.29624939, 22.20180511], [72.29624939, 22.20208359], [72.29569244, 22.20208359], [72.29569244, 22.20236206], [72.29430389, 22.20236206], [72.29430389, 22.20152855], [72.29458618, 22.20153999], [72.29458618, 22.20125008], [72.29486084, 22.20125008], [72.29486084, 22.20070267], [72.29515076, 22.20070267], [72.29515076, 22.20042038], [72.29541779, 22.20042038], [72.29541779, 22.20014191], [72.29569244, 22.20014191], [72.29569244, 22.19986153], [72.29597473, 22.19986153], [72.29597473, 22.19958305], [72.29624939, 22.19958305], [72.29624939, 22.19930649], [72.29651642, 22.19930077], [72.29652405, 22.19902992], [72.29680634, 22.19903183], [72.29680634, 22.19874763], [72.29708099, 22.19874763], [72.29708099, 22.19292068], [72.29680634, 22.19292068], [72.29680634, 22.19124985], [72.29708099, 22.19124985], [72.29708099, 22.1906929], [72.29736328, 22.19069481], [72.29736328, 22.19013977], [72.29763794, 22.19013977], [72.29763794, 22.18958282], [72.29792023, 22.18958282], [72.29792023, 22.18930626], [72.29818726, 22.18931007], [72.29818726, 22.18875122], [72.29846954, 22.18875122], [72.29846954, 22.18819046], [72.29875183, 22.18819427], [72.29875183, 22.18763924], [72.29902649, 22.18764114], [72.29902649, 22.18736267], [72.29930878, 22.18736267], [72.29930878, 22.18707848], [72.29958344, 22.1870842], [72.29958344, 22.18680573], [72.29985809, 22.18680954], [72.29985809, 22.18652916], [72.30014038, 22.18652916], [72.30014038, 22.1859684], [72.30041504, 22.18597221], [72.30041504, 22.18569374], [72.30069733, 22.18569374], [72.30069733, 22.18541718], [72.30095673, 22.18541908], [72.30095673, 22.18514061], [72.30124664, 22.18514061], [72.30124664, 22.18485832], [72.30152893, 22.18485832], [72.30152893, 22.18457985], [72.30180359, 22.18458366], [72.30180359, 22.18430519], [72.30208588, 22.18431091], [72.30208588, 22.18374825], [72.30236053, 22.18374825], [72.30236053, 22.18346977], [72.30263519, 22.18347168], [72.30263519, 22.18319511], [72.30291748, 22.18320084], [72.30291748, 22.18292046], [72.30430603, 22.18292046], [72.30430603, 22.18320084], [72.30486298, 22.18319511], [72.30486298, 22.18347168], [72.30568695, 22.18346977], [72.30568695, 22.18374825], [72.30652618, 22.18374825], [72.30652618, 22.18403053], [72.30709076, 22.18403053], [72.30709076, 22.18431091], [72.30819702, 22.18431091], [72.30819702, 22.18403053], [72.30847168, 22.18403053], [72.30847168, 22.18374825], [72.30902863, 22.18374825], [72.30902863, 22.18346977], [72.30930328, 22.18347168], [72.30930328, 22.18319511], [72.30986023, 22.18320084], [72.30986023, 22.18292046], [72.31041718, 22.18292046], [72.31041718, 22.18264008], [72.31069183, 22.18264008], [72.31069183, 22.1823597], [72.31124878, 22.1823616], [72.31124878, 22.18208313], [72.31153107, 22.18208313], [72.31153107, 22.18180466], [72.31180573, 22.18180466], [72.31180573, 22.18124962], [72.31208038, 22.18124962], [72.31208038, 22.18097115], [72.31236267, 22.18097305], [72.31236267, 22.18069458], [72.31263733, 22.18069458], [72.31263733, 22.1795826], [72.31291962, 22.1795826], [72.31291962, 22.17791748], [72.31318665, 22.17791939], [72.31318665, 22.17625046], [72.31346893, 22.17625046], [72.31346893, 22.17152977], [72.31318665, 22.17152977], [72.31318665, 22.17123985], [72.31291962, 22.17124748], [72.31291962, 22.17097282], [72.31263733, 22.17097282], [72.31263733, 22.17069435], [72.31208038, 22.17069435], [72.31208038, 22.17041779], [72.31181335, 22.17041969], [72.31181335, 22.17014122], [72.31153107, 22.17014122], [72.31153107, 22.16958046], [72.31180573, 22.16958237], [72.31180573, 22.16875076], [72.31208038, 22.16875076], [72.31208038, 22.16792107], [72.31236267, 22.16792107], [72.31236267, 22.16707993], [72.31208038, 22.16708374], [72.31208038, 22.16625023], [72.31180573, 22.16625023], [72.31180573, 22.16569328], [72.31153107, 22.16570091], [72.31153107, 22.16485977], [72.31124878, 22.16486168], [72.31124878, 22.16402817], [72.31096649, 22.16403008], [72.31096649, 22.16347122], [72.31069183, 22.16347313], [72.31069183, 22.16124916], [72.31041718, 22.16125107], [72.31041718, 22.15735817], [72.31014252, 22.15736198], [72.31014252, 22.15624809], [72.30986023, 22.15624809], [72.30986023, 22.15180588], [72.3095932, 22.15180969], [72.3095932, 22.14875031], [72.30986023, 22.14875031], [72.30986023, 22.1482029], [72.31015015, 22.1482029], [72.31015015, 22.14625168], [72.31041718, 22.14625168], [72.31041718, 22.14458084], [72.31069183, 22.14458275], [72.31069183, 22.14430618], [72.31097412, 22.14430618], [72.31097412, 22.14347267], [72.31124878, 22.14347267], [72.31124878, 22.1431942], [72.31153107, 22.1431942], [72.31153107, 22.14208412], [72.31180573, 22.14208412], [72.31180573, 22.14152527], [72.31208038, 22.14153099], [72.31208038, 22.14068985], [72.31236267, 22.14069366], [72.31236267, 22.13986206], [72.31263733, 22.13986015], [72.31263733, 22.13957977], [72.31291962, 22.13958359], [72.31291962, 22.13902855], [72.31318665, 22.13903046], [72.31318665, 22.1384697], [72.31346893, 22.1384716], [72.31346893, 22.13708305], [72.31402588, 22.13708305], [72.31402588, 22.13736153], [72.31430817, 22.13736153], [72.31430817, 22.13708305], [72.31458282, 22.13708305], [72.31458282, 22.13652802], [72.31485748, 22.13652992], [72.31485748, 22.13624954], [72.31513977, 22.13624954], [72.31513977, 22.13597107], [72.31541443, 22.13597107], [72.31541443, 22.1356945], [72.31569672, 22.1356945], [72.31569672, 22.13541603], [72.31597137, 22.13541985], [72.31597137, 22.13513184], [72.31652832, 22.13513947], [72.31652832, 22.1348629], [72.31680298, 22.1348629], [72.31680298, 22.13458252], [72.31735992, 22.13458252], [72.31735992, 22.13430595], [72.31846619, 22.13430977], [72.31846619, 22.13402939], [72.31958008, 22.13402939], [72.31958008, 22.13375282], [72.32041931, 22.13375282], [72.32041931, 22.13346863], [72.32069397, 22.13347244], [72.32069397, 22.13319397], [72.32125092, 22.13319397], [72.32125092, 22.1329174], [72.32180786, 22.13291931], [72.32180786, 22.13264084], [72.32235718, 22.13264084], [72.32235718, 22.13235855], [72.32263947, 22.13235855], [72.32263947, 22.13207054], [72.32291412, 22.13208389], [72.32291412, 22.13180542], [72.32319641, 22.13180923], [72.32319641, 22.13153076], [72.32347107, 22.13153076], [72.32347107, 22.13096809], [72.32375336, 22.13097191], [72.32375336, 22.13013649], [72.32347107, 22.1301403], [72.32347107, 22.12985992], [72.32291412, 22.12986183], [72.32291412, 22.12958336], [72.32263947, 22.12958336], [72.32263947, 22.12930489], [72.32208252, 22.12930489], [72.32208252, 22.12902641], [72.32180786, 22.12902641], [72.32180786, 22.12930489], [72.32096863, 22.12930489], [72.32096863, 22.12902641], [72.32041931, 22.12903023], [72.32041931, 22.12874985], [72.32013702, 22.12874985], [72.32013702, 22.12792015], [72.32041931, 22.12792015], [72.32041931, 22.12763977], [72.3215332, 22.12763977], [72.32152557, 22.1273613], [72.32180786, 22.1273613], [72.32180786, 22.12708282], [72.32152557, 22.12708282], [72.32152557, 22.12624931], [72.32125092, 22.12626076], [72.32125092, 22.12597084], [72.32069397, 22.12597275], [72.32069397, 22.1254158], [72.32096863, 22.12541962], [72.32096863, 22.12514114], [72.32125092, 22.12514114], [72.32125092, 22.12430954], [72.3215332, 22.12430954], [72.3215332, 22.12347031], [72.32208252, 22.12347221], [72.32208252, 22.12319374], [72.32263947, 22.12319374], [72.32263947, 22.12291718], [72.32319641, 22.1229229], [72.32319641, 22.12264061], [72.32290649, 22.12264061], [72.32290649, 22.12236023], [72.32263947, 22.12236023], [72.32263947, 22.12208176], [72.32236481, 22.12208366], [72.32236481, 22.12152863], [72.32209015, 22.12153053], [72.32209015, 22.12125015], [72.32180786, 22.12125015], [72.32180786, 22.12097168], [72.32152557, 22.12097168], [72.32152557, 22.12069511], [72.32125092, 22.12070274], [72.32125092, 22.12042046], [72.32096863, 22.12042046], [72.32096863, 22.1198616], [72.32069397, 22.1198616], [72.32069397, 22.11958313], [72.32041931, 22.11958313], [72.32041931, 22.11930466], [72.32013702, 22.11930466], [72.32013702, 22.11902809], [72.31986237, 22.11903191], [72.31986237, 22.11874962], [72.31958008, 22.11874962], [72.31958008, 22.11819077], [72.31930542, 22.11819458], [72.31930542, 22.11791611], [72.31903076, 22.11791992], [72.31903076, 22.11763954], [72.31874847, 22.11763954], [72.31874847, 22.11708832], [72.31846619, 22.11708832], [72.31846619, 22.11680984], [72.31819153, 22.11680984], [72.31819153, 22.11652946], [72.31791687, 22.11652946], [72.31791687, 22.11597061], [72.31764221, 22.11597252], [72.31764221, 22.11569405], [72.31485748, 22.11569405], [72.31485748, 22.11597252], [72.31430817, 22.11597252], [72.31430817, 22.1151371], [72.31402588, 22.11514091], [72.31402588, 22.11458015], [72.31375122, 22.11458588], [72.31375122, 22.1143055], [72.31346893, 22.11432076], [72.31346893, 22.11403084], [72.31318665, 22.11403084], [72.31318665, 22.11375046], [72.31291962, 22.11375046], [72.31291962, 22.11347008], [72.31263733, 22.11347198], [72.31263733, 22.11319733], [72.31236267, 22.1131897], [72.31236267, 22.11263847], [72.31208038, 22.11264038], [72.31208038, 22.11236], [72.31180573, 22.11236191], [72.31180573, 22.11208344], [72.31153107, 22.11208344], [72.31153107, 22.1115284], [72.31124878, 22.1115303], [72.31124878, 22.11042023], [72.31153107, 22.11042023], [72.31153107, 22.1095829], [72.31124878, 22.1095829], [72.31124878, 22.10847282], [72.31153107, 22.10847282], [72.31153107, 22.10708427], [72.31180573, 22.10708237], [72.31180573, 22.10514069], [72.31208038, 22.10515022], [72.31208038, 22.1048584], [72.31236267, 22.1048584], [72.31236267, 22.10457993], [72.31263733, 22.10458374], [72.31263733, 22.1040287], [72.31291962, 22.10403061], [72.31291962, 22.10375023], [72.31346893, 22.10375023], [72.31346893, 22.10346985], [72.31375122, 22.10347176], [72.31375122, 22.10291862], [72.31402588, 22.10292053], [72.31402588, 22.10264015], [72.31485748, 22.10264015], [72.31485748, 22.10235977], [72.31513977, 22.10236168], [72.31513977, 22.10069466], [72.31541443, 22.10069466], [72.31541443, 22.09958267], [72.31513977, 22.09958267], [72.31513977, 22.09902763], [72.31485748, 22.09902763], [72.31485748, 22.0984726], [72.31458282, 22.0984726], [72.31458282, 22.09819412], [72.31430817, 22.09819412], [72.31430817, 22.09791756], [72.31402588, 22.09791946], [72.31402588, 22.09764099], [72.31375122, 22.09764099], [72.31375122, 22.09736061], [72.31346893, 22.09736061], [72.31346893, 22.09680939], [72.31318665, 22.09680939], [72.31318665, 22.09653091], [72.31291962, 22.09653091], [72.31291962, 22.09596252], [72.31319427, 22.09597206], [72.31319427, 22.09513855], [72.31291962, 22.09514046], [72.31291962, 22.0945816], [72.31263733, 22.09458351], [72.31263733, 22.09430504], [72.31236267, 22.09431267], [72.31236267, 22.09403038], [72.31208038, 22.09403038], [72.31208038, 22.09321022], [72.31181335, 22.09321022], [72.31181335, 22.09207916], [72.31153107, 22.09208298], [72.31153107, 22.0909729], [72.31124878, 22.0909729], [72.31124878, 22.09069443], [72.31097412, 22.09069443], [72.31097412, 22.08930779], [72.31069183, 22.08930969], [72.31069183, 22.08875084], [72.31041718, 22.08875084], [72.31041718, 22.08764076], [72.31015015, 22.08764076], [72.31015015, 22.08708], [72.30958557, 22.08708382], [72.30958557, 22.08680534], [72.30930328, 22.08681107], [72.30930328, 22.08542061], [72.30902863, 22.08542061], [72.30902863, 22.08374977], [72.30874634, 22.08374977], [72.30874634, 22.08263969], [72.30847168, 22.08263969], [72.30847168, 22.0809803], [72.30819702, 22.0809803], [72.30819702, 22.08041954], [72.3079071, 22.08041954], [72.3079071, 22.07930946], [72.30764008, 22.07930946], [72.30764008, 22.07846832], [72.30735779, 22.07847214], [72.30735779, 22.0779171], [72.30709076, 22.07792091], [72.30709076, 22.07764053], [72.30680847, 22.07764053], [72.30680847, 22.07735825], [72.30652618, 22.07736206], [72.30652618, 22.07680511], [72.30680847, 22.07681084], [72.30680847, 22.07180977], [72.30652618, 22.07180977], [72.30652618, 22.07042122], [72.30625153, 22.07042122], [72.30625153, 22.06847191], [72.30596924, 22.06847382], [72.30596924, 22.0676384], [72.30568695, 22.0676403], [72.30568695, 22.06513977], [72.30541992, 22.06513977], [72.30541992, 22.06485748], [72.30513763, 22.0648613], [72.30513763, 22.06430626], [72.30486298, 22.06430817], [72.30486298, 22.06375122], [72.30458069, 22.06375122], [72.30458069, 22.06208038], [72.30430603, 22.0620842], [72.30430603, 22.06152534], [72.30403137, 22.06153107], [72.30403137, 22.05931091], [72.30374908, 22.05931091], [72.30374908, 22.05875015], [72.3034668, 22.05875015], [72.3034668, 22.05764008], [72.30319214, 22.05764008], [72.30319214, 22.05653], [72.3034668, 22.05653], [72.3034668, 22.05624962], [72.30319214, 22.05624962], [72.30319214, 22.05569267], [72.30291748, 22.05569458], [72.30291748, 22.0545826], [72.30263519, 22.0545826], [72.30263519, 22.05374908], [72.30236053, 22.0537529], [72.30236053, 22.0534687], [72.30208588, 22.05347252], [72.30208588, 22.05208397], [72.30180359, 22.05208397], [72.30180359, 22.05125046], [72.30152893, 22.05125046], [72.30152893, 22.05042076], [72.30124664, 22.05042076], [72.30124664, 22.04931068], [72.30095673, 22.04931068], [72.30095673, 22.0490303], [72.30069733, 22.0490303], [72.30069733, 22.04819107], [72.30041504, 22.04819679], [72.30041504, 22.04791832], [72.30014038, 22.04791832], [72.30014038, 22.04763985], [72.29985809, 22.04763985], [72.29985809, 22.04597092], [72.29958344, 22.04597282], [72.29958344, 22.04458237], [72.29930878, 22.04458237], [72.29930878, 22.04402733], [72.29902649, 22.04403114], [72.29902649, 22.04319191], [72.29875183, 22.04319382], [72.29875183, 22.04263878], [72.29902649, 22.04264069], [72.29902649, 22.04208183], [72.29875183, 22.04208374], [72.29875183, 22.04125023], [72.29846954, 22.04125023], [72.29846954, 22.04070282], [72.29875183, 22.04070282], [72.29875183, 22.03986168], [72.29846954, 22.03986168], [72.29846954, 22.03958321], [72.29819489, 22.03958321], [72.29819489, 22.03902817], [72.29792023, 22.03903008], [72.29792023, 22.03791809], [72.29818726, 22.03791809], [72.29818726, 22.03763962], [72.29792023, 22.03763962], [72.29792023, 22.03680992], [72.29763794, 22.03680992], [72.29763794, 22.03597069], [72.29736328, 22.0359726], [72.29736328, 22.03569412], [72.29708099, 22.03569412], [72.29708099, 22.03541565], [72.29680634, 22.03541946], [72.29680634, 22.03375053], [72.29708099, 22.03375053], [72.29708099, 22.03347015], [72.29680634, 22.03347206], [72.29680634, 22.03263855], [72.29651642, 22.03264046], [72.29651642, 22.0320797], [72.29624939, 22.03208351], [72.29624939, 22.03097153], [72.29597473, 22.03097153], [72.29597473, 22.02930641], [72.29569244, 22.02931023], [72.29569244, 22.02736282], [72.29541779, 22.02736282], [72.29541779, 22.02596855], [72.2951355, 22.02597237], [72.2951355, 22.02514076], [72.29486084, 22.02514076], [72.29486084, 22.02430916], [72.29458618, 22.02430916], [72.29458618, 22.02264023], [72.29429626, 22.02264023], [72.29429626, 22.02153015], [72.29402924, 22.02153015], [72.29402924, 22.02067947], [72.29374695, 22.02069664], [72.29374695, 22.02013969], [72.29347229, 22.02013969], [72.29347229, 22.01847076], [72.29319763, 22.01847267], [72.29319763, 22.01736069], [72.29291534, 22.01736069], [72.29291534, 22.01625061], [72.29264069, 22.01625061], [72.29264069, 22.01542282], [72.2923584, 22.01542282], [72.2923584, 22.0134716], [72.29208374, 22.0134716], [72.29208374, 22.01319504], [72.29180908, 22.01320267], [72.29180908, 22.01264191], [72.29152679, 22.01264191], [72.29152679, 22.01180077], [72.29125214, 22.01180649], [72.29125214, 22.01041794], [72.29096985, 22.01041985], [72.29096985, 22.01013947], [72.29069519, 22.01013947], [72.29069519, 22.00930786], [72.2904129, 22.00930977], [72.2904129, 22.00792122], [72.29013824, 22.00792122], [72.29013824, 22.00708008], [72.28986359, 22.0070858], [72.28986359, 22.00597191], [72.2895813, 22.00597191], [72.2895813, 22.00569344], [72.28930664, 22.00570107], [72.28930664, 22.00485992], [72.28902435, 22.00486183], [72.28902435, 22.00402832], [72.28874969, 22.00403023], [72.28874969, 22.00292969], [72.28848267, 22.00292969], [72.28848267, 22.00263977], [72.28819275, 22.00263977], [72.28819275, 22.00235939], [72.28791809, 22.0023613], [72.28791809, 22.00180626], [72.2876358, 22.00181007], [72.2876358, 22.00014114], [72.2876358, 21.99957085], [72.28708649, 21.9995842], [72.28708649, 21.99791718], [72.28679657, 21.99791908], [72.28679657, 21.99653053], [72.28652954, 21.99653053], [72.28652954, 21.99514008], [72.28624725, 21.99514008], [72.28624725, 21.99014091], [72.28595734, 21.99014091], [72.28595734, 21.98847008], [72.28569794, 21.98847389], [72.28569794, 21.98680496], [72.28542328, 21.98681259], [72.28542328, 21.98542023], [72.28514099, 21.98542023], [72.28514099, 21.98402977], [72.2848587, 21.98402977], [72.2848587, 21.98208046], [72.28458405, 21.98208427], [72.28458405, 21.98097229], [72.28430176, 21.98097229], [72.28430176, 21.97986031], [72.2840271, 21.97986031], [72.2840271, 21.97903061], [72.28375244, 21.97903061], [72.28375244, 21.97820091], [72.28347015, 21.97820091], [72.28347015, 21.97707939], [72.2831955, 21.97708321], [72.2831955, 21.97624969], [72.28291321, 21.97624969], [72.28291321, 21.97569466], [72.28263855, 21.97569466], [72.28263855, 21.97486115], [72.28235626, 21.97486115], [72.28235626, 21.9731884], [72.2820816, 21.97319412], [72.2820816, 21.97291756], [72.28180695, 21.97291946], [72.28180695, 21.97236061], [72.28151703, 21.97236061], [72.28151703, 21.97180939], [72.28125, 21.97180939], [72.28125, 21.97125053], [72.28097534, 21.97125053], [72.28097534, 21.97041893], [72.28069305, 21.97042084], [72.28069305, 21.96931076], [72.2804184, 21.96931076], [72.2804184, 21.96846962], [72.28013611, 21.96847153], [72.28013611, 21.96736145], [72.27986145, 21.96736145], [72.27986145, 21.96430588], [72.2793045, 21.96430588], [72.2793045, 21.96458244], [72.27874756, 21.96458054], [72.27874756, 21.96486092], [72.27791595, 21.96486092], [72.27791595, 21.96513939], [72.2767868, 21.96513939], [72.2767868, 21.96541977], [72.27597046, 21.96541405], [72.27597046, 21.96569443], [72.2748642, 21.96569443], [72.2748642, 21.9659729], [72.27401733, 21.96597099], [72.27402496, 21.96624947], [72.27348328, 21.96624947], [72.27348328, 21.96652985], [72.2729187, 21.96652985], [72.2729187, 21.96681976], [72.27236176, 21.9668045], [72.27236176, 21.96708298], [72.27180481, 21.96708298], [72.27180481, 21.96736145], [72.27124786, 21.96735954], [72.27124786, 21.96763992], [72.27098083, 21.96763992], [72.27098083, 21.96541977], [72.27124786, 21.96541977], [72.27124786, 21.96513939], [72.27179718, 21.96513939], [72.27179718, 21.96486092], [72.2720871, 21.96486092], [72.2720871, 21.96458054], [72.27236176, 21.96458244], [72.27236176, 21.96430588], [72.27263641, 21.96430969], [72.27263641, 21.96375084], [72.2729187, 21.96375084], [72.2729187, 21.96319008], [72.27319336, 21.96319389], [72.27319336, 21.96236038], [72.27348328, 21.96236038], [72.27347565, 21.96125031], [72.27375031, 21.96125031], [72.27375031, 21.96097183], [72.27402496, 21.96097183], [72.27402496, 21.96069527], [72.27430725, 21.96069527], [72.27430725, 21.96013832], [72.27458191, 21.96014023], [72.27458191, 21.95986176], [72.2748642, 21.95986176], [72.2748642, 21.95958328], [72.27541351, 21.95958328], [72.27541351, 21.95930481], [72.2756958, 21.95930481], [72.2756958, 21.95902824], [72.27625275, 21.95903015], [72.27625275, 21.95875168], [72.2765274, 21.95875168], [72.2765274, 21.95846748], [72.27708435, 21.9584713], [72.27708435, 21.95819473], [72.27735901, 21.95819473], [72.27735901, 21.95791626], [72.2776413, 21.95791817], [72.2776413, 21.95764923], [72.27791595, 21.95764923], [72.27791595, 21.95708084], [72.27819061, 21.95708275], [72.27819824, 21.95680618], [72.2784729, 21.95680809], [72.2784729, 21.95597076], [72.27874756, 21.95597267], [72.27874756, 21.95486069], [72.27902985, 21.95486069], [72.27902985, 21.94708252], [72.27874756, 21.94708252], [72.27874756, 21.94569397], [72.2784729, 21.94569397], [72.2784729, 21.94458389], [72.27819824, 21.94458389], [72.27819061, 21.94375038], [72.27791595, 21.94375038], [72.27791595, 21.94124985], [72.27819061, 21.94124985], [72.27819061, 21.93959045], [72.27791595, 21.93959045], [72.27791595, 21.93931007], [72.2776413, 21.93931007], [72.2776413, 21.93875122], [72.27735901, 21.93875122], [72.27735901, 21.93847084], [72.27708435, 21.93847275], [72.27708435, 21.93625069], [72.27735901, 21.93625069], [72.27735901, 21.93569183], [72.2776413, 21.93569374], [72.2776413, 21.93458366], [72.27791595, 21.93458366], [72.27791595, 21.93375015], [72.27819061, 21.93375015], [72.27819824, 21.93292046], [72.2784729, 21.93292046], [72.2784729, 21.93207932], [72.27819824, 21.93208313], [72.27819061, 21.93180466], [72.2776413, 21.93180466], [72.2776413, 21.93152809], [72.27735901, 21.93152809], [72.27735901, 21.93124962], [72.27707672, 21.93124962], [72.27707672, 21.93097115], [72.2765274, 21.93097305], [72.2765274, 21.93069458], [72.27625275, 21.93069458], [72.27625275, 21.93013954], [72.27597046, 21.93013954], [72.27597046, 21.92986107], [72.27513885, 21.92986107], [72.27513885, 21.93013954], [72.27485657, 21.93013954], [72.27485657, 21.93041992], [72.27458191, 21.93041611], [72.27458191, 21.93069458], [72.27430725, 21.93069458], [72.27430725, 21.93097305], [72.27401733, 21.93097115], [72.27401733, 21.93124962], [72.27375031, 21.93124962], [72.27375031, 21.93152809], [72.27347565, 21.93152809], [72.27347565, 21.93180466], [72.27319336, 21.93180466], [72.27319336, 21.93208313], [72.27263641, 21.93208313], [72.27263641, 21.9323616], [72.2720871, 21.9323616], [72.2720871, 21.93264008], [72.27179718, 21.93264008], [72.27179718, 21.93292046], [72.27153015, 21.93291664], [72.27153015, 21.93347168], [72.27124786, 21.93345833], [72.27124786, 21.93375015], [72.27098083, 21.93375015], [72.27098083, 21.93403053], [72.27041626, 21.93403053], [72.27041626, 21.93431282], [72.26985931, 21.93430519], [72.26985931, 21.93458366], [72.26930237, 21.93458176], [72.26930237, 21.93486023], [72.26902771, 21.93486023], [72.26902771, 21.93514061], [72.26875305, 21.93514061], [72.26875305, 21.9354229], [72.26847076, 21.93541718], [72.26847076, 21.93569374], [72.26819611, 21.93569183], [72.26819611, 21.93625069], [72.26791382, 21.93625069], [72.26791382, 21.93652725], [72.26763916, 21.93651962], [72.26763916, 21.93680954], [72.2673645, 21.93680573], [72.2673645, 21.93708229], [72.26708221, 21.93708038], [72.26708221, 21.93736076], [72.26680756, 21.93736076], [72.26680756, 21.93791962], [72.26652527, 21.9379158], [72.26652527, 21.93847275], [72.26625061, 21.93847084], [72.26625061, 21.93902969], [72.26597595, 21.93902779], [72.26597595, 21.94069672], [72.26569366, 21.94069672], [72.26569366, 21.94097137], [72.26541901, 21.94096947], [72.26541901, 21.94124985], [72.26513672, 21.94124985], [72.26513672, 21.94208336], [72.2648468, 21.94207954], [72.2648468, 21.94264984], [72.26457977, 21.94263649], [72.26457977, 21.94347191], [72.26431274, 21.94346809], [72.26431274, 21.94430923], [72.26403046, 21.94430923], [72.26403046, 21.94541931], [72.26374817, 21.9454174], [72.26374817, 21.94597244], [72.26346588, 21.94597054], [72.26346588, 21.94652939], [72.26319122, 21.94652939], [72.26319122, 21.95264053], [72.26291656, 21.95263863], [72.26291656, 21.95319366], [72.26264191, 21.95318985], [72.26264191, 21.95375061], [72.26235962, 21.95375061], [72.26235962, 21.95430946], [72.26207733, 21.95430946], [72.26207733, 21.95486069], [72.26180267, 21.95486069], [72.26180267, 21.9556942], [72.26152802, 21.95569038], [72.26152802, 21.95625114], [72.26125336, 21.95624733], [72.26125336, 21.95708275], [72.26097107, 21.95708275], [72.26097107, 21.9584713], [72.26069641, 21.9584713], [72.26069641, 21.95958328], [72.26040649, 21.95958138], [72.26040649, 21.96820068], [72.26069641, 21.96820068], [72.26069641, 21.97153091], [72.26041412, 21.9715271], [72.26041412, 21.97263908], [72.26013947, 21.97262955], [72.26013947, 21.97431183], [72.26040649, 21.97431183], [72.26040649, 21.97513962], [72.26069641, 21.97513962], [72.26069641, 21.97624969], [72.26097107, 21.97624969], [72.26097107, 21.97764015], [72.26125336, 21.97764015], [72.26125336, 21.97875977], [72.26152802, 21.97875023], [72.26152802, 21.98097229], [72.26125336, 21.98097038], [72.26125336, 21.98153114], [72.26097107, 21.98152542], [72.26097107, 21.98208427], [72.25985718, 21.98208046], [72.25986481, 21.98236084], [72.25556183, 21.98236084], [72.25514221, 21.98236084], [72.25514221, 21.98264122], [72.25485992, 21.98264122], [72.25485992, 21.98291969], [72.25458527, 21.98291779], [72.25458527, 21.98347282], [72.25430298, 21.98347092], [72.25430298, 21.98374748], [72.25402832, 21.98374748], [72.25402832, 21.98402977], [72.25374603, 21.98402977], [72.25374603, 21.98430824], [72.25347137, 21.98430634], [72.25347137, 21.98486137], [72.25319672, 21.98485756], [72.25319672, 21.98513985], [72.2529068, 21.98513985], [72.2529068, 21.98542023], [72.25263977, 21.98541641], [72.25263977, 21.98597145], [72.25235748, 21.98597145], [72.25235748, 21.9865303], [72.25208282, 21.9865284], [72.25208282, 21.98736191], [72.25180817, 21.98736191], [72.25180817, 21.98958206], [72.25208282, 21.98958015], [72.25208282, 21.99152946], [72.25180817, 21.99152946], [72.25180817, 21.99291992], [72.25208282, 21.9929142], [72.25208282, 21.99430466], [72.25235748, 21.99430466], [72.25235748, 21.9948616], [72.25263977, 21.9948597], [72.25263977, 21.99542046], [72.25291443, 21.99541855], [72.25291443, 21.99597168], [72.25319672, 21.99597168], [72.25319672, 21.99847221], [72.25291443, 21.99847221], [72.25291443, 21.99913025], [72.25291443, 21.9995842], [72.25347137, 21.99957085], [72.25347137, 21.99986076], [72.25347137, 22.00014114], [72.25319672, 22.00014114], [72.25319672, 22.00125122], [72.25347137, 22.00124931], [72.25347137, 22.00208282], [72.25374603, 22.00208282], [72.25374603, 22.00292969], [72.25402832, 22.00292969], [72.25402832, 22.00374985], [72.25430298, 22.00374985], [72.25430298, 22.00458336], [72.2545929, 22.00457954], [72.2545929, 22.00542068], [72.25485992, 22.00542068], [72.25485992, 22.00625038], [72.25514221, 22.00625038], [72.25514221, 22.0070858], [72.25541687, 22.00708008], [72.25541687, 22.00764084], [72.25569153, 22.00763893], [72.25569153, 22.00819397], [72.25597382, 22.00819397], [72.25597382, 22.00875092], [72.25624847, 22.00873947], [72.25624847, 22.00902939], [72.25653076, 22.00902557], [72.25653076, 22.00958252], [72.25680542, 22.00958252], [72.25680542, 22.00986099], [72.25708008, 22.00986099], [72.25708008, 22.01041985], [72.25736237, 22.01041794], [72.25736237, 22.01097298], [72.25763702, 22.01096916], [72.25763702, 22.01124954], [72.25791931, 22.01124954], [72.25791931, 22.01152992], [72.25819397, 22.01152992], [72.25819397, 22.01180458], [72.25846863, 22.01180649], [72.25846863, 22.01208305], [72.25875092, 22.01208305], [72.25875092, 22.01236153], [72.25904083, 22.01236153], [72.25904083, 22.01264191], [72.25930786, 22.01264191], [72.25930786, 22.01292038], [72.25958252, 22.01292038], [72.25958252, 22.01320267], [72.25985718, 22.01320267], [72.25985718, 22.01375008], [72.26013947, 22.01375008], [72.26013947, 22.01458359], [72.26040649, 22.01458168], [72.26040649, 22.01514053], [72.26069641, 22.01513863], [72.26069641, 22.01597214], [72.26097107, 22.01597023], [72.26097107, 22.01764107], [72.26069641, 22.01764107], [72.26069641, 22.01931], [72.26040649, 22.01931], [72.26040649, 22.01986122], [72.26013947, 22.01986122], [72.26013947, 22.02013969], [72.25986481, 22.02013969], [72.25986481, 22.02069664], [72.25958252, 22.02069664], [72.25958252, 22.02100182], [72.25958252, 22.02124977], [72.25930786, 22.02124977], [72.25930786, 22.02153015], [72.25902557, 22.02152634], [72.25902557, 22.02208328], [72.25875092, 22.02207947], [72.25875092, 22.02264023], [72.25846863, 22.02264023], [72.25846863, 22.02292061], [72.25819397, 22.0229187], [72.25819397, 22.02347183], [72.25791931, 22.02346992], [72.25791931, 22.02403069], [72.25763702, 22.02402878], [72.25763702, 22.02458382], [72.25736237, 22.02457809], [72.25736237, 22.02541924], [72.25708008, 22.02541733], [72.25708008, 22.02597237], [72.25653076, 22.02596855], [72.25653076, 22.02625084], [72.25598145, 22.02625084], [72.25598145, 22.02680969], [72.25569153, 22.02680588], [72.25569153, 22.02708244], [72.25541687, 22.02708244], [72.25541687, 22.02736282], [72.25514221, 22.02736282], [72.25514221, 22.02791977], [72.25430298, 22.02791595], [72.25430298, 22.02819443], [72.25402832, 22.02819443], [72.25402832, 22.0284729], [72.25347137, 22.0284729], [72.25347137, 22.02874947], [72.25319672, 22.02874947], [72.25319672, 22.02902985], [72.2529068, 22.02902985], [72.2529068, 22.02931023], [72.24986267, 22.02930641], [72.24986267, 22.02958107], [72.24846649, 22.02958107], [72.24846649, 22.02987099], [72.24819183, 22.02987099], [72.24819183, 22.03013992], [72.24791718, 22.03013992], [72.24791718, 22.0304203], [72.24764252, 22.0304203], [72.24764252, 22.03070068], [72.24736023, 22.03069305], [72.24736023, 22.03097153], [72.24708557, 22.03097153], [72.24708557, 22.03125], [72.24681091, 22.03125], [72.24681091, 22.03153038], [72.24652863, 22.03153038], [72.24652863, 22.03181076], [72.24624634, 22.03180313], [72.24624634, 22.03208351], [72.24597168, 22.03208351], [72.24597168, 22.03236198], [72.24569702, 22.03236008], [72.24569702, 22.03264046], [72.24541473, 22.03263855], [72.24541473, 22.03291512], [72.24514008, 22.03291512], [72.24514008, 22.03347206], [72.24485779, 22.03347015], [72.24485779, 22.03430939], [72.24458313, 22.03430939], [72.24458313, 22.03514099], [72.24430847, 22.03514099], [72.24430847, 22.03763962], [72.24402618, 22.03763962], [72.24402618, 22.03958321], [72.24375153, 22.03957939], [72.24375153, 22.04070282], [72.24318695, 22.04070282], [72.24318695, 22.04125023], [72.24291992, 22.04125023], [72.24291992, 22.04153061], [72.24263763, 22.04153061], [72.24263763, 22.04403114], [72.24291992, 22.04403114], [72.24291992, 22.04430962], [72.24263763, 22.04430962], [72.24263763, 22.04514122], [72.24236298, 22.04514122], [72.24236298, 22.04541969], [72.24208069, 22.04541588], [72.24208069, 22.04569435], [72.24180603, 22.04569435], [72.24180603, 22.0470829], [72.24153137, 22.0470829], [72.24153137, 22.04958344], [72.24180603, 22.04958344], [72.24180603, 22.05069351], [72.24236298, 22.05069351], [72.24236298, 22.05097198], [72.24263763, 22.05096817], [72.24263763, 22.05125046], [72.24318695, 22.05125046], [72.24318695, 22.05153084], [72.24346924, 22.05153084], [72.24346924, 22.05180931], [72.24375153, 22.0518055], [72.24375153, 22.05208397], [72.24402618, 22.05208397], [72.24402618, 22.05236053], [72.24430847, 22.05236053], [72.24430847, 22.05264091], [72.24458313, 22.05264091], [72.24458313, 22.05291939], [72.24514008, 22.05291748], [72.24514008, 22.05319405], [72.24541473, 22.05319405], [72.24541473, 22.05347252], [72.24569702, 22.0534687], [72.24569702, 22.0537529], [72.24624634, 22.0537529], [72.24624634, 22.05404282], [72.24681091, 22.05404282], [72.24681091, 22.05430984], [72.24708557, 22.05430603], [72.24708557, 22.0545826], [72.24764252, 22.0545826], [72.24764252, 22.05486107], [72.24819183, 22.05486107], [72.24819183, 22.05513954], [72.24874878, 22.05513954], [72.24874878, 22.05541992], [72.24903107, 22.05541611], [72.24903107, 22.05569458], [72.24958038, 22.05569458], [72.24958038, 22.05597115], [72.25013733, 22.05597115], [72.25013733, 22.05624962], [72.25068665, 22.05624962], [72.25068665, 22.05653], [72.25152588, 22.05652809], [72.25152588, 22.05680466], [72.25208282, 22.05680466], [72.25208282, 22.05708313], [72.25263977, 22.05708313], [72.25263977, 22.0573616], [72.25319672, 22.0573597], [72.25319672, 22.05764008], [72.25402832, 22.05764008], [72.25402832, 22.05792046], [72.2545929, 22.05792046], [72.2545929, 22.05820084], [72.25514221, 22.05819321], [72.25514221, 22.05847168], [72.25569153, 22.05846977], [72.25569153, 22.05875015], [72.25653076, 22.05875015], [72.25653076, 22.05903053], [72.25708008, 22.05903053], [72.25708008, 22.05931091], [72.25763702, 22.05930328], [72.25763702, 22.05958366], [72.25846863, 22.05958366], [72.25846863, 22.05986023], [72.25930786, 22.05985069], [72.25930786, 22.06014061], [72.25985718, 22.06014061], [72.25985718, 22.06042099], [72.26069641, 22.06041527], [72.26069641, 22.06069374], [72.26152802, 22.06069374], [72.26152802, 22.06097221], [72.26235962, 22.06097031], [72.26235962, 22.06125069], [72.26291656, 22.06125069], [72.26291656, 22.06153107], [72.26374817, 22.06153107], [72.26374817, 22.06180954], [72.26430511, 22.06180763], [72.26430511, 22.0620842], [72.26513672, 22.06208038], [72.26513672, 22.06236076], [72.26568604, 22.06236076], [72.26568604, 22.06264114], [72.26625061, 22.06264114], [72.26625061, 22.06291962], [72.26680756, 22.06291771], [72.26680756, 22.06319427], [72.26763916, 22.06319427], [72.26763916, 22.06347275], [72.26819611, 22.06347084], [72.26819611, 22.06375122], [72.26875305, 22.06375122], [72.26875305, 22.06402969], [72.26930237, 22.06402969], [72.26930237, 22.06430817], [72.26985931, 22.06430626], [72.26985931, 22.06458282], [72.27041626, 22.06458282], [72.27041626, 22.0648613], [72.27097321, 22.0648613], [72.27097321, 22.06513977], [72.27153015, 22.06513977], [72.27153015, 22.06542015], [72.2720871, 22.06541634], [72.2720871, 22.06569481], [72.27236176, 22.06568909], [72.27236176, 22.06598282], [72.2729187, 22.06598282], [72.2729187, 22.06625175], [72.27348328, 22.06625175], [72.27348328, 22.06653023], [72.27402496, 22.06652832], [72.27402496, 22.06680489], [72.27430725, 22.06680489], [72.27430725, 22.06708336], [72.2748642, 22.06708336], [72.2748642, 22.06736183], [72.27540588, 22.06736183], [72.27540588, 22.0676403], [72.2756958, 22.0676403], [72.2756958, 22.06792068], [72.27625275, 22.06792068], [72.27625275, 22.06820107], [72.27680206, 22.06819534], [72.27680206, 22.06847382], [72.27735901, 22.06847191], [72.27735901, 22.06875038], [72.2776413, 22.06875038], [72.2776413, 22.0690403], [72.27819824, 22.0690403], [72.27819824, 22.06931114], [72.27874756, 22.06930542], [72.27874756, 22.06958389], [72.27902985, 22.06958008], [72.27902985, 22.06986046], [72.27958679, 22.06986046], [72.27958679, 22.07014084], [72.27986145, 22.07014084], [72.27986145, 22.07042122], [72.2804184, 22.0704174], [72.2804184, 22.07069206], [72.28069305, 22.07069206], [72.28069305, 22.07097244], [72.28125, 22.07097054], [72.28125, 22.07125092], [72.28151703, 22.07125092], [72.28151703, 22.07152939], [72.2820816, 22.07152939], [72.2820816, 22.07180977], [72.28236389, 22.07180405], [72.28236389, 22.07208252], [72.28291321, 22.07208252], [72.28291321, 22.07236099], [72.2831955, 22.07236099], [72.2831955, 22.07263947], [72.28430176, 22.07263947], [72.28430939, 22.07291985], [72.28514099, 22.07291412], [72.28514099, 22.07347298], [72.28595734, 22.07347107], [72.28595734, 22.07374954], [72.28624725, 22.07374954], [72.28624725, 22.07402992], [72.28652954, 22.07402611], [72.28652954, 22.07430458], [72.2868042, 22.07430458], [72.2868042, 22.07374954], [72.28708649, 22.07374954], [72.28708649, 22.07347107], [72.28736115, 22.07347298], [72.28736115, 22.0731945], [72.2876358, 22.0731945], [72.2876358, 22.07291412], [72.28791809, 22.07291985], [72.28791809, 22.07263947], [72.28819275, 22.07263947], [72.28819275, 22.07236099], [72.28848267, 22.07236099], [72.28847504, 22.07208252], [72.28874969, 22.07208252], [72.28874969, 22.07097244], [72.28902435, 22.07097244], [72.28902435, 22.07013893], [72.28930664, 22.07014084], [72.28930664, 22.06986046], [72.28985596, 22.06986046], [72.28985596, 22.06958008], [72.29013824, 22.06958389], [72.29013824, 22.06930542], [72.2904129, 22.06931114], [72.2904129, 22.0690403], [72.29096985, 22.0690403], [72.29096985, 22.06875038], [72.29125214, 22.06875038], [72.29125214, 22.06847191], [72.29180908, 22.06847382], [72.29180908, 22.06819534], [72.29209137, 22.06820107], [72.29209137, 22.06736183], [72.2923584, 22.06736183], [72.2923584, 22.06625175], [72.29264069, 22.06625175], [72.29264069, 22.06568909], [72.29291534, 22.06569481], [72.29291534, 22.06513977], [72.29319763, 22.06513977], [72.29319763, 22.06458092], [72.29347229, 22.06458282], [72.29347229, 22.06402969], [72.29374695, 22.06402969], [72.29374695, 22.06347084], [72.29402924, 22.06347275], [72.29402924, 22.06319427], [72.29445648, 22.06319427], [72.29763794, 22.06319427], [72.29763794, 22.06347275], [72.29792023, 22.06347084], [72.29792023, 22.06375122], [72.29818726, 22.06375122], [72.29818726, 22.06430817], [72.29846954, 22.06430626], [72.29846954, 22.06458282], [72.29875183, 22.06458282], [72.29875183, 22.0648613], [72.29902649, 22.06485748], [72.29902649, 22.06513977], [72.29930878, 22.06513977], [72.29930878, 22.06569481], [72.29957581, 22.06568909], [72.29957581, 22.06598282], [72.29985809, 22.06598282], [72.29985809, 22.06625175], [72.30014038, 22.06625175], [72.30014038, 22.06653023], [72.30041504, 22.06652832], [72.30041504, 22.06680489], [72.30069733, 22.06680489], [72.30069733, 22.06736183], [72.30095673, 22.06736183], [72.30095673, 22.0676403], [72.30124664, 22.0676403], [72.30124664, 22.06792068], [72.30152893, 22.06792068], [72.30152893, 22.06820107], [72.30179596, 22.06820107], [72.30179596, 22.06875038], [72.30208588, 22.06875038], [72.30208588, 22.0690403], [72.30236053, 22.0690403], [72.30236053, 22.06931114], [72.30263519, 22.06930542], [72.30263519, 22.06986046], [72.30291748, 22.06986046], [72.30291748, 22.07042122], [72.30319214, 22.0704174], [72.30319214, 22.07097244], [72.3034668, 22.07097054], [72.3034668, 22.07152939], [72.30374908, 22.07152748], [72.30374908, 22.07208252], [72.30403137, 22.07208061], [72.30403137, 22.07291985], [72.30374908, 22.07291985], [72.30374908, 22.07514], [72.30403137, 22.07514], [72.30403137, 22.07681084], [72.30347443, 22.07680511], [72.30347443, 22.07708359], [72.30291748, 22.07708359], [72.30291748, 22.07736206], [72.30264282, 22.07735825], [72.30264282, 22.07764053], [72.30208588, 22.07764053], [72.30208588, 22.07792091], [72.30152893, 22.0779171], [72.30152893, 22.07819366], [72.30097198, 22.07819366], [72.30097198, 22.07847214], [72.30069733, 22.07846832], [72.30069733, 22.07875061], [72.30014038, 22.07875061], [72.30014038, 22.07930946], [72.29930878, 22.07930565], [72.29930878, 22.07958412], [72.29875183, 22.0795784], [72.29875183, 22.07986069], [72.29818726, 22.07986069], [72.29818726, 22.08013916], [72.29736328, 22.08013916], [72.29736328, 22.08041954], [72.29652405, 22.08041763], [72.29652405, 22.0806942], [72.29515076, 22.08069038], [72.29515076, 22.08125114], [72.29541779, 22.08125114], [72.29541779, 22.0818119], [72.2959671, 22.0818119], [72.2959671, 22.08152962], [72.29680634, 22.08152962], [72.29680634, 22.08125114], [72.29792023, 22.08125114], [72.29792023, 22.08152962], [72.29819489, 22.08152771], [72.29819489, 22.08208275], [72.29846954, 22.08208275], [72.29846954, 22.08292007], [72.29875183, 22.08291626], [72.29875183, 22.08458328], [72.29957581, 22.08457947], [72.29957581, 22.08570099], [72.29985809, 22.08570099], [72.29985809, 22.08625031], [72.30014038, 22.08625031], [72.30014038, 22.08653069], [72.30042267, 22.08653069], [72.30042267, 22.08681107], [72.30069733, 22.08680534], [72.30069733, 22.08708382], [72.30095673, 22.08708], [72.30095673, 22.08736038], [72.30124664, 22.08736038], [72.30124664, 22.08764076], [72.30152893, 22.08763885], [72.30152893, 22.08819389], [72.30180359, 22.08819389], [72.30180359, 22.08847237], [72.30208588, 22.08847046], [72.30208588, 22.08875084], [72.30236053, 22.08875084], [72.30236053, 22.08903122], [72.30263519, 22.0890255], [72.30264282, 22.08986092], [72.30236053, 22.08986092], [72.30236053, 22.0909729], [72.30208588, 22.0909729], [72.30208588, 22.09208298], [72.30236053, 22.09207916], [72.30236053, 22.0929203], [72.30263519, 22.09291649], [72.30263519, 22.09375191], [72.30291748, 22.09375191], [72.30291748, 22.09458351], [72.30319214, 22.0945816], [72.30319214, 22.09542274], [72.30291748, 22.09541702], [72.30291748, 22.09597206], [72.30264282, 22.09596252], [72.30264282, 22.09653091], [72.30236053, 22.09653091], [72.30236053, 22.09736061], [72.30208588, 22.09736061], [72.30208588, 22.09791946], [72.30180359, 22.09791756], [72.30180359, 22.0984726], [72.30069733, 22.0984726], [72.30069733, 22.09902763], [72.30097198, 22.09902763], [72.30097198, 22.09958267], [72.30124664, 22.09958267], [72.30124664, 22.10069466], [72.30152893, 22.10069084], [72.30152893, 22.10209084], [72.30179596, 22.10209084], [72.30179596, 22.10375023], [72.30152893, 22.10375023], [72.30152893, 22.10569382], [72.30179596, 22.1056881], [72.30179596, 22.10680962], [72.30152893, 22.1068058], [72.30152893, 22.10708427], [72.30124664, 22.10707855], [72.30124664, 22.10736275], [72.30095673, 22.10736275], [72.30095673, 22.10764122], [72.30069733, 22.10763931], [72.30069733, 22.10819435], [72.30041504, 22.10819435], [72.30041504, 22.10847282], [72.30014038, 22.10847282], [72.30014038, 22.10874939], [72.29930878, 22.10874939], [72.29930878, 22.10847282], [72.29902649, 22.10847282], [72.29902649, 22.10819435], [72.29875183, 22.10819435], [72.29875183, 22.10791588], [72.29846954, 22.10791969], [72.29846954, 22.10764122], [72.29818726, 22.10764122], [72.29818726, 22.10736275], [72.29792023, 22.10736275], [72.29792023, 22.10707855], [72.29763794, 22.10708427], [72.29763794, 22.1068058], [72.29736328, 22.10680962], [72.29736328, 22.10652924], [72.29708099, 22.10652924], [72.29708099, 22.10625076], [72.29680634, 22.10625076], [72.29680634, 22.10596848], [72.29652405, 22.10597229], [72.29652405, 22.10569382], [72.29624939, 22.10569382], [72.29624939, 22.10541725], [72.2959671, 22.10541916], [72.2959671, 22.10515022], [72.29569244, 22.10515022], [72.29569244, 22.1048584], [72.29541779, 22.1048584], [72.29541779, 22.10430908], [72.29515076, 22.10430908], [72.29515076, 22.10346985], [72.29486084, 22.10347176], [72.29486084, 22.10291862], [72.29429626, 22.10292053], [72.29429626, 22.10264015], [72.29347229, 22.10264015], [72.29347229, 22.10235977], [72.29291534, 22.10236168], [72.29291534, 22.10208321], [72.29209137, 22.10209084], [72.29209137, 22.10180092], [72.29152679, 22.10180473], [72.29152679, 22.10152626], [72.2904129, 22.10153008], [72.2904129, 22.10124969], [72.28930664, 22.10124969], [72.28930664, 22.10097122], [72.28874969, 22.10097313], [72.28874969, 22.10069466], [72.28791809, 22.10069466], [72.28791809, 22.10041428], [72.2876358, 22.10042], [72.2876358, 22.10013962], [72.28736115, 22.10013962], [72.28736115, 22.09986115], [72.28679657, 22.09986115], [72.28679657, 22.09958076], [72.28652954, 22.09958267], [72.28652954, 22.0984726], [72.28624725, 22.0984726], [72.28624725, 22.09680557], [72.28595734, 22.09680939], [72.28595734, 22.09596252], [72.28708649, 22.09597206], [72.28708649, 22.09541702], [72.28679657, 22.09542274], [72.28679657, 22.09486008], [72.28652954, 22.09486008], [72.28652954, 22.09430504], [72.28624725, 22.09431267], [72.28624725, 22.09403038], [72.28595734, 22.09403038], [72.28595734, 22.09375191], [72.28569794, 22.09375191], [72.28569794, 22.09347153], [72.28541565, 22.09347153], [72.28541565, 22.09319496], [72.28514099, 22.09321022], [72.28514099, 22.0929203], [72.2848587, 22.0929203], [72.2848587, 22.09264183], [72.28430939, 22.09264183], [72.28430176, 22.09321022], [72.2840271, 22.09319496], [72.2840271, 22.09347153], [72.28375244, 22.09347153], [72.28375244, 22.09375191], [72.28291321, 22.09375191], [72.28291321, 22.09347153], [72.28263855, 22.09347153], [72.28263855, 22.09291649], [72.28235626, 22.0929203], [72.28235626, 22.09264183], [72.2820816, 22.09264183], [72.2820816, 22.09236145], [72.28180695, 22.09236145], [72.28180695, 22.09208298], [72.28125, 22.09208298], [72.28125, 22.09180641], [72.28098297, 22.09180832], [72.28098297, 22.09152985], [72.27791595, 22.09152985], [72.27791595, 22.09124756], [72.2776413, 22.09124756], [72.2776413, 22.09096909], [72.27735901, 22.0909729], [72.27735901, 22.09069443], [72.27707672, 22.09069061], [72.27707672, 22.09124756], [72.2767868, 22.09124756], [72.2767868, 22.09180832], [72.2765274, 22.09180832], [72.2765274, 22.09653091], [72.27680206, 22.0965271], [72.27680206, 22.09819412], [72.27625275, 22.09819412], [72.27625275, 22.0984726], [72.27597046, 22.09847069], [72.27597046, 22.09875107], [72.27541351, 22.09874916], [72.27541351, 22.09902763], [72.27513885, 22.09902], [72.27513885, 22.09930992], [72.27485657, 22.09930992], [72.27485657, 22.09986115], [72.27458191, 22.09986115], [72.27458191, 22.10013962], [72.27430725, 22.10013962], [72.27430725, 22.10042], [72.27348328, 22.10042], [72.27348328, 22.10013962], [72.2729187, 22.10013962], [72.2729187, 22.09986115], [72.27097321, 22.09986115], [72.27098083, 22.10013962], [72.2701416, 22.10013962], [72.2701416, 22.10042], [72.26985931, 22.10041428], [72.26985931, 22.10069466], [72.26930237, 22.10069084], [72.26930237, 22.10124969], [72.26902771, 22.10124969], [72.26902771, 22.10153008], [72.26875305, 22.10153008], [72.26875305, 22.10209084], [72.26847076, 22.10209084], [72.26847076, 22.10320091], [72.26819611, 22.10320091], [72.26819611, 22.10625076], [72.26792145, 22.10625076], [72.26792145, 22.10652924], [72.26763916, 22.10652924], [72.26763916, 22.10680962], [72.26708221, 22.10680962], [72.26708221, 22.10652924], [72.26680756, 22.10652924], [72.26680756, 22.10625076], [72.26625061, 22.10625076], [72.26625061, 22.10596848], [72.26597595, 22.10597229], [72.26597595, 22.10569382], [72.26569366, 22.10569382], [72.26569366, 22.10541725], [72.26541901, 22.10541916], [72.26541901, 22.10403061], [72.26597595, 22.10403061], [72.26597595, 22.10346985], [72.26625061, 22.10347176], [72.26625061, 22.10263634], [72.26597595, 22.10264015], [72.26597595, 22.10235977], [72.26569366, 22.10236168], [72.26569366, 22.10180473], [72.26597595, 22.10180473], [72.26597595, 22.10152626], [72.2665329, 22.10153008], [72.2665329, 22.10124969], [72.26680756, 22.10124969], [72.26680756, 22.10097122], [72.2673645, 22.10097313], [72.2673645, 22.10069466], [72.26763916, 22.10069466], [72.26763916, 22.10041428], [72.26847076, 22.10042], [72.26847076, 22.10013962], [72.26875305, 22.10013962], [72.26875305, 22.09986115], [72.26930237, 22.09986115], [72.26930237, 22.09958076], [72.2701416, 22.09958267], [72.2701416, 22.0993042], [72.27069092, 22.09930992], [72.27069092, 22.09902], [72.27097321, 22.09902763], [72.27097321, 22.09874916], [72.27153015, 22.09875107], [72.27153015, 22.09847069], [72.27180481, 22.0984726], [72.27180481, 22.09819412], [72.2720871, 22.09819412], [72.2720871, 22.09791756], [72.2729187, 22.09791946], [72.2729187, 22.09764099], [72.27401733, 22.09764099], [72.27401733, 22.09736061], [72.27485657, 22.09736061], [72.27485657, 22.09568977], [72.27513885, 22.09569359], [72.27513885, 22.09402847], [72.27485657, 22.09403038], [72.27485657, 22.09321022], [72.27458191, 22.09321022], [72.27458191, 22.09264183], [72.27430725, 22.09264183], [72.27430725, 22.09180832], [72.27458191, 22.09180832], [72.27458191, 22.09069061], [72.2748642, 22.09069443], [72.2748642, 22.08958244], [72.27513885, 22.08958244], [72.27513885, 22.08875084], [72.27540588, 22.08875084], [72.27540588, 22.08764076], [72.2756958, 22.08764076], [72.2756958, 22.08708], [72.27597046, 22.08708382], [72.27597046, 22.08680534], [72.27625275, 22.08681107], [72.27625275, 22.08653069], [72.2765274, 22.08653069], [72.2765274, 22.08570099], [72.27625275, 22.08570099], [72.27625275, 22.08457947], [72.2765274, 22.08458328], [72.2765274, 22.08402824], [72.27680206, 22.08402824], [72.27680206, 22.0834713], [72.27819061, 22.0834713], [72.27819824, 22.08263969], [72.2784729, 22.08263969], [72.2784729, 22.08152962], [72.27819824, 22.08152962], [72.27819061, 22.08041954], [72.27791595, 22.08041954], [72.27791595, 22.07986069], [72.27735901, 22.07986069], [72.27735901, 22.0795784], [72.27708435, 22.07958412], [72.27708435, 22.07930565], [72.2765274, 22.07930946], [72.2765274, 22.07902908], [72.2756958, 22.07902908], [72.2756958, 22.07875061], [72.27485657, 22.07875061], [72.27485657, 22.07846832], [72.27375031, 22.07847214], [72.27375031, 22.07819366], [72.2729187, 22.07819366], [72.2729187, 22.0779171], [72.27263641, 22.07792091], [72.27263641, 22.07764053], [72.27179718, 22.07764053], [72.27179718, 22.07735825], [72.27124786, 22.07736206], [72.27124786, 22.07708359], [72.27041626, 22.07708359], [72.27041626, 22.07680511], [72.26957703, 22.07681084], [72.26957703, 22.07653046], [72.26902771, 22.07653046], [72.26902771, 22.07624817], [72.26819611, 22.07624817], [72.26819611, 22.0759697], [72.26763916, 22.0759716], [72.26763916, 22.07569695], [72.26708221, 22.07570076], [72.26708221, 22.07542038], [72.26680756, 22.07542038], [72.26680756, 22.07514], [72.26625061, 22.07514], [72.26625061, 22.07485962], [72.26569366, 22.07486153], [72.26569366, 22.07458305], [72.26513672, 22.07458305], [72.26513672, 22.07430458], [72.2648468, 22.0743103], [72.2648468, 22.07402992], [72.26457977, 22.07402992], [72.26457977, 22.07374954], [72.26430511, 22.07374954], [72.26430511, 22.07347298], [72.26403046, 22.07347298], [72.26403046, 22.0731945], [72.26374817, 22.0731945], [72.26374817, 22.07291412], [72.26346588, 22.07291985], [72.26346588, 22.07263947], [72.26319122, 22.07263947], [72.26319122, 22.07236099], [72.26291656, 22.07236099], [72.26291656, 22.07208061], [72.26235962, 22.07208252], [72.26235962, 22.07180405], [72.26207733, 22.07180977], [72.26207733, 22.07152939], [72.26178741, 22.07152939], [72.26178741, 22.07125092], [72.26152802, 22.07125092], [72.26152802, 22.07097054], [72.26125336, 22.07097244], [72.26125336, 22.07069206], [72.26097107, 22.07069206], [72.26097107, 22.0704174], [72.26069641, 22.07042122], [72.26069641, 22.07014084], [72.26040649, 22.07014084], [72.26040649, 22.06986046], [72.25985718, 22.06986046], [72.25985718, 22.06958008], [72.25958252, 22.06958389], [72.25958252, 22.06930542], [72.25930786, 22.06931114], [72.25930786, 22.0690403], [72.25904083, 22.0690403], [72.25904083, 22.06875038], [72.25875092, 22.06875038], [72.25875092, 22.06847191], [72.25819397, 22.06847382], [72.25819397, 22.06819534], [72.25791931, 22.06820107], [72.25791931, 22.06792068], [72.25763702, 22.06792068], [72.25763702, 22.0676403], [72.25736237, 22.0676403], [72.25736237, 22.06736183], [72.25680542, 22.06736183], [72.25680542, 22.06708336], [72.25653076, 22.06708336], [72.25653076, 22.06680489], [72.25624847, 22.06680489], [72.25624847, 22.06652832], [72.25569153, 22.06653023], [72.25569153, 22.06625175], [72.25541687, 22.06625175], [72.25541687, 22.06598282], [72.25485992, 22.06598282], [72.25485992, 22.06568909], [72.25430298, 22.06569481], [72.25430298, 22.06541634], [72.25347137, 22.06542015], [72.25347137, 22.06513977], [72.2529068, 22.06513977], [72.2529068, 22.06485748], [72.25235748, 22.0648613], [72.25235748, 22.06458282], [72.25180817, 22.06458282], [72.25180817, 22.06430626], [72.25096893, 22.06430817], [72.25096893, 22.06402969], [72.25041962, 22.06402969], [72.25041962, 22.06375122], [72.24874878, 22.06375122], [72.24874878, 22.06347084], [72.24764252, 22.06347275], [72.24764252, 22.06319427], [72.24708557, 22.06319427], [72.24708557, 22.06263733], [72.24652863, 22.06264114], [72.24652863, 22.06236076], [72.24597168, 22.06236076], [72.24597168, 22.06208038], [72.24514008, 22.0620842], [72.24514008, 22.06180763], [72.24430847, 22.06180954], [72.24430847, 22.06153107], [72.24375153, 22.06153107], [72.24375153, 22.06125069], [72.24291992, 22.06125069], [72.24291992, 22.06097031], [72.24180603, 22.06097221], [72.24180603, 22.06069374], [72.24124908, 22.06069374], [72.24124908, 22.06041527], [72.24067688, 22.06042099], [72.24067688, 22.06014061], [72.24014282, 22.06014061], [72.24014282, 22.05985069], [72.23930359, 22.05986023], [72.23930359, 22.05958366], [72.23874664, 22.05958366], [72.23874664, 22.05930328], [72.23790741, 22.05931091], [72.23790741, 22.05875015], [72.23764038, 22.05875015], [72.23764038, 22.05846977], [72.23735809, 22.05847168], [72.23735809, 22.05819321], [72.23707581, 22.05820084], [72.23707581, 22.05792046], [72.23652649, 22.05792046], [72.23652649, 22.05764008], [72.23625183, 22.05764008], [72.23625183, 22.05708122], [72.23596954, 22.05708313], [72.23596954, 22.05680466], [72.23569489, 22.05680466], [72.23569489, 22.05597115], [72.23542023, 22.05597115], [72.23542023, 22.05569458], [72.23513794, 22.05569458], [72.23513794, 22.05541611], [72.23458099, 22.05541992], [72.23458099, 22.05513954], [72.23430634, 22.05513954], [72.23430634, 22.05486107], [72.23401642, 22.05486107], [72.23401642, 22.05430984], [72.23374939, 22.05430984], [72.23374939, 22.05404282], [72.2334671, 22.05404282], [72.2334671, 22.0537529], [72.23319244, 22.0537529], [72.23319244, 22.05318832], [72.23291779, 22.05319405], [72.23291779, 22.05291748], [72.23264313, 22.05291939], [72.23264313, 22.05207825], [72.23236084, 22.05208397], [72.23236084, 22.05152893], [72.23210144, 22.05153084], [72.23210144, 22.05096817], [72.23180389, 22.05097198], [72.23180389, 22.05069542], [72.23152924, 22.0506897], [72.23152924, 22.05013657], [72.23124695, 22.05014038], [72.23124695, 22.04931068], [72.23097229, 22.04931068], [72.23097229, 22.04874992], [72.23069763, 22.04874992], [72.23069763, 22.04681015], [72.23042297, 22.04681015], [72.23042297, 22.0448494], [72.23014069, 22.04486084], [72.23014069, 22.04236031], [72.2298584, 22.04236031], [72.2298584, 22.04208183], [72.23014069, 22.04208374], [72.23014069, 22.03902817], [72.23042297, 22.03903008], [72.23042297, 22.03680992], [72.23069763, 22.03680992], [72.23069763, 22.03568077], [72.23097229, 22.03569412], [72.23097229, 22.03375053], [72.23124695, 22.03375053], [72.23124695, 22.03264046], [72.23152924, 22.03264046], [72.23152924, 22.0320797], [72.23180389, 22.03208351], [72.23180389, 22.03013802], [72.23210144, 22.03013992], [72.23210144, 22.02987099], [72.23236084, 22.02987099], [72.23236084, 22.02902985], [72.23264313, 22.02902985], [72.23264313, 22.02763939], [72.23291779, 22.02763939], [72.23291779, 22.02680969], [72.23319244, 22.02680969], [72.23319244, 22.02514076], [72.2334671, 22.02514076], [72.2334671, 22.02374077], [72.23374939, 22.02375031], [72.23374939, 22.02236176], [72.23347473, 22.02236176], [72.23347473, 22.0209713], [72.23319244, 22.0209713], [72.23319244, 22.01958275], [72.23291779, 22.01958275], [72.23291779, 22.0181942], [72.2326355, 22.0181942], [72.2326355, 22.01763916], [72.23181152, 22.01764107], [72.23181152, 22.01793098], [72.23097229, 22.01791763], [72.23097229, 22.0181942], [72.23041534, 22.0181942], [72.23041534, 22.01847267], [72.22957611, 22.01847076], [72.22957611, 22.01875114], [72.22873688, 22.01875114], [72.22873688, 22.01902962], [72.2270813, 22.01902962], [72.2270813, 22.01931], [72.22541809, 22.01930428], [72.22541809, 22.01958275], [72.2251358, 22.01958084], [72.2251358, 22.01986122], [72.22486115, 22.01986122], [72.22486115, 22.02013969], [72.22458649, 22.02013969], [72.22458649, 22.02042007], [72.2243042, 22.02041435], [72.2243042, 22.02069664], [72.2234726, 22.02069664], [72.2234726, 22.0209713], [72.22319794, 22.0209713], [72.22319794, 22.02069664], [72.22291565, 22.02069664], [72.22291565, 22.01986122], [72.22264099, 22.01986122], [72.22264099, 22.01931], [72.22207642, 22.01931], [72.22207642, 22.01902962], [72.22180176, 22.01902962], [72.22180176, 22.01875114], [72.22125244, 22.01875114], [72.22125244, 22.01819038], [72.22097015, 22.0181942], [72.22097015, 22.01763916], [72.22070313, 22.01764107], [72.22070313, 22.01736069], [72.22041321, 22.01736069], [72.22041321, 22.01680946], [72.22013855, 22.01680946], [72.22013855, 22.0165329], [72.21996307, 22.01652908], [72.21986389, 22.01652718], [72.21987152, 22.01625061], [72.21930695, 22.01625061], [72.21930695, 22.01597023], [72.21902466, 22.01597214], [72.21902466, 22.01569366], [72.21875, 22.01569366], [72.21875, 22.0154171], [72.21848297, 22.01542282], [72.21848297, 22.01514053], [72.21819305, 22.01514053], [72.21819305, 22.01458168], [72.2179184, 22.01458359], [72.2179184, 22.01402855], [72.21736145, 22.01403046], [72.21736145, 22.01375008], [72.21708679, 22.01375008], [72.21708679, 22.01292038], [72.21679688, 22.01292038], [72.21679688, 22.01207924], [72.2166748, 22.01210213], [72.2165451, 22.01212883], [72.21652985, 22.01180077], [72.21569824, 22.01180649], [72.21569061, 22.01152992], [72.21485901, 22.01152992], [72.21485901, 22.01124954], [72.21457672, 22.01124954], [72.21457672, 22.01096916], [72.21430206, 22.01097298], [72.21430206, 22.0106945], [72.2123642, 22.0106945], [72.2123642, 22.01041794], [72.2095871, 22.01041794], [72.2095871, 22.0106945], [72.20903015, 22.0106945], [72.20903015, 22.01097298], [72.20793152, 22.01096916], [72.20793152, 22.01152992], [72.2076416, 22.01152992], [72.2076416, 22.01180649], [72.20735931, 22.01180649], [72.20735931, 22.01208305], [72.20708466, 22.01208305], [72.20708466, 22.01236153], [72.20680237, 22.01236153], [72.20680237, 22.01292038], [72.20652771, 22.01292038], [72.20652771, 22.01320267], [72.20625305, 22.01319504], [72.20625305, 22.0134716], [72.20597076, 22.0134716], [72.20597076, 22.01375008], [72.20540619, 22.01375008], [72.20540619, 22.01403046], [72.20513916, 22.01402855], [72.20513916, 22.01458359], [72.20458221, 22.01458168], [72.20458221, 22.01514053], [72.20430756, 22.01514053], [72.20430756, 22.01542282], [72.20402527, 22.0154171], [72.20402527, 22.01569366], [72.20375061, 22.01569366], [72.20375061, 22.01597214], [72.20347595, 22.01597023], [72.20347595, 22.01625061], [72.20318604, 22.01625061], [72.20318604, 22.0165329], [72.20291901, 22.0165329], [72.20291901, 22.01680946], [72.20263672, 22.01680565], [72.20263672, 22.01708221], [72.20236206, 22.01708031], [72.20236206, 22.01736069], [72.20207977, 22.01736069], [72.20207977, 22.01764107], [72.20179749, 22.01764107], [72.20179749, 22.01793098], [72.20153046, 22.01791763], [72.20153046, 22.0181942], [72.20096588, 22.01819038], [72.20096588, 22.01875114], [72.20069122, 22.01875114], [72.20069122, 22.01902962], [72.20014191, 22.01902771], [72.20014191, 22.01958275], [72.19985962, 22.01958084], [72.19985962, 22.01986122], [72.19930267, 22.01986122], [72.19930267, 22.02069664], [72.19902802, 22.02069664], [72.19902802, 22.0209713], [72.19847107, 22.02096939], [72.19847107, 22.02124977], [72.19819641, 22.02124977], [72.19819641, 22.02153015], [72.19763947, 22.02152634], [72.19763947, 22.02180481], [72.19680786, 22.02180481], [72.19680786, 22.02208328], [72.19652557, 22.02208328], [72.19652557, 22.02236176], [72.19596863, 22.02235985], [72.19596863, 22.02264023], [72.19486237, 22.02264023], [72.19486237, 22.02235985], [72.19374847, 22.02236176], [72.19374847, 22.02208328], [72.19235992, 22.02208328], [72.19235992, 22.02180481], [72.19180298, 22.02180481], [72.19180298, 22.02152634], [72.1904068, 22.02153015], [72.1904068, 22.02124977], [72.19013977, 22.02124977], [72.19013977, 22.02096939], [72.18958282, 22.0209713], [72.18958282, 22.02069664], [72.18902588, 22.02069664], [72.18902588, 22.02041435], [72.18875122, 22.02042007], [72.18875122, 22.01986122], [72.18846893, 22.01986122], [72.18846893, 22.01958084], [72.18791962, 22.01958275], [72.18791962, 22.01930428], [72.18763733, 22.01930428], [72.18763733, 22.01958275], [72.18596649, 22.01958084], [72.18596649, 22.01986122], [72.18569183, 22.01986122], [72.18569183, 22.02013969], [72.18541718, 22.02013969], [72.18541718, 22.02042007], [72.18514252, 22.02041435], [72.18514252, 22.02069664], [72.18486023, 22.02067947], [72.18486023, 22.02264023], [72.1845932, 22.02264023], [72.1845932, 22.02430916], [72.18486023, 22.02430916], [72.18486023, 22.02514076], [72.18514252, 22.02514076], [72.18514252, 22.02569389], [72.18541718, 22.02569389], [72.18541718, 22.02708244], [72.18430328, 22.02708244], [72.18430328, 22.02736282], [72.1845932, 22.02736282], [72.1845932, 22.02791977], [72.18486023, 22.02791595], [72.18486023, 22.0284729], [72.1845932, 22.0284729], [72.1845932, 22.02902985], [72.18430328, 22.02902985], [72.18430328, 22.02987099], [72.18402863, 22.02987099], [72.18402863, 22.03070068], [72.18374634, 22.03069305], [72.1837616, 22.03125], [72.18347168, 22.03125], [72.18347168, 22.03208351], [72.18319702, 22.03208351], [72.18319702, 22.03291512], [72.18291473, 22.03291512], [72.18291473, 22.03347206], [72.18264008, 22.03347015], [72.18264008, 22.03403091], [72.18235779, 22.03402519], [72.18235779, 22.03458595], [72.18208313, 22.03458023], [72.18208313, 22.03514099], [72.18096924, 22.03514099], [72.18096924, 22.03541946], [72.17986298, 22.03541565], [72.17986298, 22.03569412], [72.17958069, 22.03569412], [72.17958069, 22.0359726], [72.17903137, 22.03597069], [72.17903137, 22.03625107], [72.17819214, 22.03625107], [72.17819214, 22.03652954], [72.17791748, 22.03652954], [72.17791748, 22.03680992], [72.17762756, 22.03680992], [72.17762756, 22.03791809], [72.17736053, 22.03791809], [72.17736053, 22.03903008], [72.17708588, 22.03902817], [72.17708588, 22.03930473], [72.17652893, 22.03930473], [72.17652893, 22.03958321], [72.17624664, 22.03958321], [72.17624664, 22.03986168], [72.17597198, 22.03986168], [72.17597198, 22.04014015], [72.17569733, 22.04014015], [72.17569733, 22.04042053], [72.17514038, 22.04042053], [72.17514038, 22.04070282], [72.17485809, 22.04069519], [72.17485809, 22.04097176], [72.17456818, 22.04097176], [72.17456818, 22.04125023], [72.17430878, 22.04125023], [72.17430878, 22.04153061], [72.17236328, 22.04153061], [72.17236328, 22.04070282], [72.17263794, 22.04070282], [72.17263794, 22.03986168], [72.17346954, 22.03986168], [72.17346954, 22.03958321], [72.17402649, 22.03958321], [72.17402649, 22.03930473], [72.17485809, 22.03930473], [72.17485809, 22.03902817], [72.17514038, 22.03903008], [72.17514038, 22.03847122], [72.17541504, 22.03847313], [72.17541504, 22.03819466], [72.17569733, 22.03819466], [72.17569733, 22.03763962], [72.17597198, 22.03763962], [72.17597198, 22.03708076], [72.17624664, 22.03708267], [72.17624664, 22.03680611], [72.17652893, 22.03680992], [72.17652893, 22.03625107], [72.17679596, 22.03625107], [72.17679596, 22.03597069], [72.17708588, 22.0359726], [72.17708588, 22.03541565], [72.17819214, 22.03541946], [72.17819214, 22.03514099], [72.17874908, 22.03514099], [72.17874908, 22.03486061], [72.17958069, 22.03486061], [72.17958069, 22.03458023], [72.17986298, 22.03458595], [72.17986298, 22.03430748], [72.18013763, 22.03430939], [72.18013763, 22.03375053], [72.18041992, 22.03375053], [72.18041992, 22.03347015], [72.18069458, 22.03347206], [72.18069458, 22.03319359], [72.18096924, 22.03319359], [72.18096924, 22.03180313], [72.18070221, 22.03181076], [72.18070221, 22.03070068], [72.18096924, 22.03070068], [72.18096924, 22.03013992], [72.18152618, 22.03013992], [72.18152618, 22.02987099], [72.18125153, 22.02987099], [72.18125153, 22.02958107], [72.18069458, 22.02958107], [72.18069458, 22.02930641], [72.18096924, 22.02931023], [72.18096924, 22.02874947], [72.18125153, 22.02874947], [72.18125153, 22.02819252], [72.18152618, 22.02819443], [72.18152618, 22.02763939], [72.18180847, 22.02763939], [72.18180847, 22.02403069], [72.18152618, 22.02403069], [72.18152618, 22.02292061], [72.18125153, 22.02292061], [72.18125153, 22.02207947], [72.18096924, 22.02208328], [72.18096924, 22.02152634], [72.18070221, 22.02153015], [72.18070221, 22.02096939], [72.18041992, 22.0209713], [72.18041992, 22.02013969], [72.18013763, 22.02013969], [72.18013763, 22.01958084], [72.17986298, 22.01958275], [72.17986298, 22.01902771], [72.18013763, 22.01902962], [72.18013763, 22.01875114], [72.18041992, 22.01875114], [72.18041992, 22.01847076], [72.18069458, 22.01847267], [72.18069458, 22.0181942], [72.18235779, 22.0181942], [72.18235779, 22.01736069], [72.18264008, 22.01736069], [72.18264008, 22.01680946], [72.18319702, 22.01680946], [72.18319702, 22.0165329], [72.1837616, 22.0165329], [72.1837616, 22.01625061], [72.18541718, 22.01625061], [72.18541718, 22.01597023], [72.18569183, 22.01597214], [72.18569183, 22.0154171], [72.19041443, 22.0154171], [72.19041443, 22.01569366], [72.19125366, 22.01569366], [72.19125366, 22.01597214], [72.19264221, 22.01597214], [72.19264221, 22.01569366], [72.19291687, 22.01569366], [72.19291687, 22.01597214], [72.19346619, 22.01597023], [72.19346619, 22.01625061], [72.19513702, 22.01625061], [72.19513702, 22.0165329], [72.1957016, 22.0165329], [72.1957016, 22.01680946], [72.19708252, 22.01680946], [72.19708252, 22.0165329], [72.19735718, 22.0165329], [72.19735718, 22.01625061], [72.19763947, 22.01625061], [72.19763947, 22.01597023], [72.19791412, 22.01597214], [72.19791412, 22.0154171], [72.19819641, 22.01542282], [72.19819641, 22.01458168], [72.19847107, 22.01458359], [72.19847107, 22.01430511], [72.19819641, 22.01431274], [72.19819641, 22.01292038], [72.19790649, 22.01292038], [72.19790649, 22.01236153], [72.19763947, 22.01236153], [72.19763947, 22.01124954], [72.19790649, 22.01124954], [72.19790649, 22.01069069], [72.19763947, 22.0106945], [72.19763947, 22.00958252], [72.19736481, 22.00958252], [72.19736481, 22.00819397], [72.19763947, 22.00819397], [72.19763947, 22.00763893], [72.19790649, 22.00764084], [72.19790649, 22.00681114], [72.19819641, 22.00681114], [72.19819641, 22.00625038], [72.19847107, 22.00625038], [72.19847107, 22.00597], [72.19902802, 22.00597191], [72.19902802, 22.00569344], [72.19930267, 22.00570107], [72.19930267, 22.00542068], [72.19985962, 22.00542068], [72.19985962, 22.0051403], [72.20014191, 22.0051403], [72.20014191, 22.00457954], [72.20041656, 22.00458336], [72.20041656, 22.00430489], [72.20124817, 22.00430489], [72.20124817, 22.00402832], [72.20179749, 22.00403023], [72.20179749, 22.00374985], [72.20236206, 22.00374985], [72.20236206, 22.00346947], [72.20375061, 22.00346947], [72.20375061, 22.00374985], [72.20485687, 22.00374985], [72.20485687, 22.00346947], [72.20569611, 22.00347137], [72.20569611, 22.00319481], [72.20652771, 22.00319481], [72.20652771, 22.00291634], [72.20735931, 22.00292969], [72.20735931, 22.00263977], [72.2076416, 22.00263977], [72.2076416, 22.00235939], [72.20791626, 22.0023613], [72.20791626, 22.00208282], [72.20819092, 22.00208282], [72.20819092, 22.00180626], [72.20847321, 22.00181007], [72.20847321, 22.00125122], [72.20874786, 22.00125122], [72.20874786, 22.00097275], [72.20903015, 22.00097275], [72.20903015, 22.00069427], [72.20930481, 22.00069427], [72.20930481, 22.0004158], [72.2095871, 22.00041962], [72.2095871, 22.00014114], [72.20986176, 22.00014114], [72.20986176, 21.99986076], [72.20986176, 21.99957085], [72.21097565, 21.9995842], [72.21097565, 21.99930573], [72.21125031, 21.99930954], [72.21125031, 21.99902916], [72.21152496, 21.99902725], [72.21152496, 21.9995842], [72.2123642, 21.9995842], [72.2123642, 21.99930573], [72.21290588, 21.99930954], [72.21290588, 21.99902916], [72.21373749, 21.99902916], [72.21373749, 21.99930954], [72.21430206, 21.99930573], [72.21430206, 21.9995842], [72.21485901, 21.9995842], [72.21485901, 21.99930573], [72.2151413, 21.99930573], [72.2151413, 21.9995842], [72.21624756, 21.99957085], [72.21624756, 21.99986076], [72.21624756, 22.00014114], [72.21652985, 22.00014114], [72.21652985, 22.00041962], [72.2168045, 22.0004158], [72.2168045, 22.00069427], [72.21708679, 22.00069427], [72.21708679, 22.00097275], [72.21736145, 22.00097275], [72.21736145, 22.00125122], [72.21763611, 22.00125122], [72.21763611, 22.00152969], [72.21848297, 22.00152969], [72.21848297, 22.00181007], [72.21902466, 22.00180626], [72.21902466, 22.00208282], [72.21930695, 22.00208282], [72.21930695, 22.0023613], [72.2195816, 22.00235939], [72.2195816, 22.00263977], [72.21987152, 22.00263977], [72.21987152, 22.00292969], [72.22013855, 22.00291634], [72.22013855, 22.00319481], [72.22041321, 22.00319481], [72.22041321, 22.00347137], [72.22097015, 22.00346947], [72.22097015, 22.00374985], [72.22125244, 22.00374985], [72.22125244, 22.00403023], [72.2215271, 22.00402832], [72.2215271, 22.00430489], [72.22180176, 22.00430489], [72.22180939, 22.00458336], [72.22208405, 22.00458336], [72.22208405, 22.00486183], [72.2223587, 22.00485992], [72.2223587, 22.0051403], [72.22264099, 22.0051403], [72.22264099, 22.00542068], [72.22293091, 22.00542068], [72.22293091, 22.00570107], [72.2234726, 22.00569344], [72.2234726, 22.00597191], [72.22374725, 22.00597], [72.22374725, 22.00625038], [72.22402954, 22.00625038], [72.22402954, 22.00653076], [72.22429657, 22.00653076], [72.22429657, 22.00681114], [72.22624969, 22.00680542], [72.22624969, 22.0070858], [72.2270813, 22.00708008], [72.2270813, 22.00736046], [72.22735596, 22.00736046], [72.22735596, 22.00792122], [72.22763824, 22.0079155], [72.22763824, 22.00819397], [72.22819519, 22.00819397], [72.22819519, 22.00847244], [72.23014069, 22.00847244], [72.23014069, 22.00819397], [72.23041534, 22.00819397], [72.23041534, 22.0079155], [72.23069763, 22.00792122], [72.23069763, 22.00764084], [72.23097229, 22.00764084], [72.23097229, 22.00653076], [72.23124695, 22.00653076], [72.23124695, 22.00570107], [72.23152924, 22.00570107], [72.23152924, 22.00346947], [72.23124695, 22.00347137], [72.23124695, 22.00319481], [72.23097229, 22.00319481], [72.23097229, 22.00291634], [72.23014069, 22.00292969], [72.23014069, 22.00263977], [72.2298584, 22.00263977], [72.2298584, 22.00235939], [72.23014069, 22.0023613], [72.23014069, 22.00180626], [72.2298584, 22.00181007], [72.2298584, 22.00152969], [72.22957611, 22.00152969], [72.22957611, 22.00125122], [72.22930908, 22.00125122], [72.22930908, 22.00097275], [72.22902679, 22.00097275], [72.22902679, 22.00069427], [72.22875214, 22.00069427], [72.22875214, 22.00013924], [72.22846985, 22.00014114], [72.22846985, 21.99986076], [72.22846985, 21.99957085], [72.22930908, 21.9995842], [72.22930908, 21.99930573], [72.23014069, 21.99930954], [72.23014069, 21.99875069], [72.23042297, 21.99875069], [72.23041534, 21.99625015], [72.23014069, 21.99625015], [72.23014069, 21.99458122], [72.2298584, 21.99458313], [72.2298584, 21.99402618], [72.22957611, 21.99403], [72.22957611, 21.99376106], [72.22902679, 21.99376106], [72.22902679, 21.99319077], [72.22875214, 21.99319458], [72.22875214, 21.9929142], [72.22846985, 21.99291992], [72.22846985, 21.99208069], [72.22819519, 21.9920826], [72.22819519, 21.99152756], [72.2279129, 21.99152946], [72.2279129, 21.99041939], [72.22763824, 21.99041939], [72.22763824, 21.98931122], [72.22735596, 21.98931122], [72.22735596, 21.98763084], [72.2270813, 21.98763847], [72.2270813, 21.98541641], [72.22680664, 21.98542023], [72.22680664, 21.98402977], [72.22651672, 21.98402977], [72.22651672, 21.98319054], [72.22624969, 21.98319435], [72.22624969, 21.98263931], [72.22596741, 21.98264122], [72.22596741, 21.98097038], [72.22569275, 21.98097229], [72.22569275, 21.98013878], [72.22541809, 21.98014069], [72.22541809, 21.97875977], [72.2251358, 21.97875977], [72.2251358, 21.97792053], [72.22486115, 21.97792053], [72.22486115, 21.97707939], [72.22458649, 21.97708321], [72.22458649, 21.97597122], [72.2243042, 21.97597122], [72.2243042, 21.97541618], [72.22402954, 21.97542], [72.22402954, 21.97458267], [72.22374725, 21.97458267], [72.22374725, 21.97430611], [72.2234726, 21.97431183], [72.2234726, 21.97375107], [72.22319794, 21.97375107], [72.22319794, 21.9731884], [72.22291565, 21.97319412], [72.22291565, 21.97263908], [72.22264099, 21.97263908], [72.22264099, 21.97236061], [72.2223587, 21.97236061], [72.2223587, 21.97153091], [72.22207642, 21.97153091], [72.22207642, 21.97042084], [72.22180176, 21.97042084], [72.22180176, 21.96931076], [72.2215271, 21.96931076], [72.2215271, 21.96820068], [72.22125244, 21.96820068], [72.22125244, 21.96763992], [72.22097015, 21.96763992], [72.22097015, 21.96430969], [72.22125244, 21.96430969], [72.22125244, 21.96292114], [72.22097015, 21.96292114], [72.22097015, 21.96236038], [72.22125244, 21.96236038], [72.22125244, 21.96153069], [72.2215271, 21.96153069], [72.2215271, 21.95708084], [72.22125244, 21.95708275], [72.22125244, 21.95652962], [72.22097015, 21.95652962], [72.22097015, 21.95625114], [72.2151413, 21.95625114], [72.2151413, 21.95597076], [72.21375275, 21.95597267], [72.21375275, 21.9556942], [72.21263885, 21.9556942], [72.21263885, 21.95541763], [72.21208191, 21.95541954], [72.21208191, 21.95514107], [72.21153259, 21.95514107], [72.21153259, 21.95486069], [72.2106781, 21.95486069], [72.2106781, 21.95458984], [72.2095871, 21.95458984], [72.2095871, 21.95430946], [72.20874786, 21.95430946], [72.20874786, 21.95403099], [72.20819092, 21.95403099], [72.20819092, 21.95375061], [72.20791626, 21.95375061], [72.20791626, 21.95347214], [72.20735931, 21.95347214], [72.20735931, 21.95319366], [72.20680237, 21.95319366], [72.20680237, 21.95291519], [72.20625305, 21.95292091], [72.20625305, 21.95264053], [72.20569611, 21.95264053], [72.20569611, 21.95236015], [72.20541382, 21.95236206], [72.20541382, 21.95208359], [72.2048645, 21.95208359], [72.2048645, 21.95180321], [72.20430756, 21.95181084], [72.20430756, 21.95153046], [72.20375061, 21.95153046], [72.20375061, 21.95125008], [72.20318604, 21.95125008], [72.20318604, 21.9509697], [72.20291901, 21.9509716], [72.20291901, 21.95069313], [72.20263672, 21.95070076], [72.20263672, 21.95042038], [72.20207977, 21.95042038], [72.20207977, 21.95014], [72.20153046, 21.95014], [72.20153046, 21.94985962], [72.20097351, 21.94986153], [72.20097351, 21.94958115], [72.20069122, 21.94958115], [72.20069122, 21.94930649], [72.19985962, 21.9493103], [72.19985962, 21.94902992], [72.19959259, 21.94902992], [72.19959259, 21.94874954], [72.19930267, 21.94874954], [72.19930267, 21.9481926], [72.19875336, 21.9481945], [72.19875336, 21.94791603], [72.19847107, 21.94791985], [72.19847107, 21.94763947], [72.19819641, 21.94763947], [72.19819641, 21.9473629], [72.19790649, 21.9473629], [72.19790649, 21.94708252], [72.19736481, 21.94708252], [72.19736481, 21.94680595], [72.19708252, 21.94681168], [72.19708252, 21.94652939], [72.19680786, 21.94652939], [72.19680786, 21.94625092], [72.19652557, 21.94625092], [72.19652557, 21.94597244], [72.19596863, 21.94597244], [72.19596863, 21.94569397], [72.19541931, 21.94569397], [72.19541931, 21.9454174], [72.19513702, 21.94541931], [72.19513702, 21.94514084], [72.19486237, 21.94514084], [72.19486237, 21.94486046], [72.19430542, 21.94486046], [72.19430542, 21.94458389], [72.19374847, 21.94458389], [72.19374847, 21.94430542], [72.19319153, 21.94430923], [72.19319153, 21.94375038], [72.19291687, 21.94375038], [72.19291687, 21.94346809], [72.19264221, 21.94347191], [72.19264221, 21.94319534], [72.19235992, 21.94319916], [72.19235992, 21.94292068], [72.1920929, 21.94292068], [72.1920929, 21.94264984], [72.19180298, 21.94264984], [72.19180298, 21.94235992], [72.19069672, 21.94235992], [72.19069672, 21.94264984], [72.1904068, 21.94264984], [72.1904068, 21.94292068], [72.19013977, 21.94292068], [72.19013977, 21.94319916], [72.18985748, 21.94319534], [72.18985748, 21.94347191], [72.18875122, 21.94346809], [72.18875122, 21.94375038], [72.18818665, 21.94375038], [72.18818665, 21.94403076], [72.18736267, 21.94403076], [72.18736267, 21.94430923], [72.18708038, 21.94430542], [72.18708038, 21.94458389], [72.18680573, 21.94458389], [72.18682098, 21.94486046], [72.18624878, 21.94486046], [72.18624878, 21.94541931], [72.18597412, 21.9454174], [72.18597412, 21.94569397], [72.18569183, 21.94569397], [72.18569183, 21.94597244], [72.18541718, 21.94597054], [72.18541718, 21.94625092], [72.1845932, 21.94625092], [72.1845932, 21.94652939], [72.18430328, 21.94652939], [72.18430328, 21.94763947], [72.18402863, 21.94763947], [72.18402863, 21.94791985], [72.18374634, 21.94791603], [72.18374634, 21.9481945], [72.18347168, 21.9481945], [72.18347168, 21.94847107], [72.1829071, 21.94846153], [72.1829071, 21.94902992], [72.18264008, 21.94902992], [72.18264008, 21.9493103], [72.18235779, 21.94930649], [72.18235779, 21.94986153], [72.18208313, 21.94985962], [72.18208313, 21.95042038], [72.18152618, 21.95042038], [72.18152618, 21.95070076], [72.18125153, 21.95069313], [72.18125153, 21.9509716], [72.18096924, 21.9509697], [72.18096924, 21.95125008], [72.18069458, 21.95125008], [72.18069458, 21.95208359], [72.18041992, 21.95208359], [72.18041992, 21.95236206], [72.18013763, 21.95236015], [72.18013763, 21.95264053], [72.17930603, 21.95264053], [72.17930603, 21.95292091], [72.17874908, 21.95291519], [72.17874908, 21.95319366], [72.17847443, 21.95319366], [72.17847443, 21.95347214], [72.17819214, 21.95347023], [72.17819214, 21.95403099], [72.17791748, 21.95403099], [72.17791748, 21.95430946], [72.17762756, 21.95430946], [72.17762756, 21.95458984], [72.17736053, 21.95458984], [72.17736053, 21.95486069], [72.17708588, 21.95486069], [72.17708588, 21.95514107], [72.17680359, 21.95513725], [72.17680359, 21.9556942], [72.17652893, 21.95569038], [72.17652893, 21.95625114], [72.17624664, 21.95625114], [72.17624664, 21.95652962], [72.17597198, 21.95652962], [72.17597198, 21.95680809], [72.17569733, 21.95680618], [72.17569733, 21.95708275], [72.17541504, 21.95708275], [72.17542267, 21.95736122], [72.17514038, 21.95736122], [72.17514038, 21.95764923], [72.17485809, 21.95764923], [72.17485809, 21.95791817], [72.17458344, 21.95791626], [72.17458344, 21.95819473], [72.17430878, 21.95819473], [72.17430878, 21.9584713], [72.17402649, 21.95846748], [72.17402649, 21.95875168], [72.17346954, 21.95875168], [72.17346954, 21.95903015], [72.1709671, 21.95903015], [72.1709671, 21.95875168], [72.17041779, 21.95875168], [72.17041779, 21.95903015], [72.16986084, 21.95903015], [72.16986084, 21.95875168], [72.16958618, 21.95875168], [72.16958618, 21.95846748], [72.16902924, 21.9584713], [72.16902924, 21.95819473], [72.16680908, 21.95819473], [72.16680908, 21.9584713], [72.16625214, 21.95846748], [72.16625214, 21.95875168], [72.16596985, 21.95875168], [72.16596985, 21.95903015], [72.16569519, 21.95902824], [72.16569519, 21.95930481], [72.1654129, 21.95930481], [72.1654129, 21.95958328], [72.16486359, 21.95958328], [72.16486359, 21.95986176], [72.16401672, 21.95986176], [72.16401672, 21.96014023], [72.16374969, 21.96014023], [72.16374969, 21.96125031], [72.16348267, 21.96125031], [72.16348267, 21.96181107], [72.16291809, 21.96180534], [72.16291809, 21.96208382], [72.16236115, 21.96208191], [72.16236115, 21.96236038], [72.16208649, 21.96236038], [72.16208649, 21.96264076], [72.1618042, 21.96263885], [72.1618042, 21.96319389], [72.16152954, 21.96319389], [72.16152954, 21.96347237], [72.16124725, 21.96347046], [72.16124725, 21.96375084], [72.1609726, 21.96375084], [72.1609726, 21.96403122], [72.16069794, 21.96403122], [72.16069794, 21.96541977], [72.16041565, 21.96541405], [72.16041565, 21.96569443], [72.16014099, 21.96569443], [72.16014099, 21.9659729], [72.1598587, 21.96597099], [72.1598587, 21.96624947], [72.15959167, 21.96624947], [72.15959167, 21.96652985], [72.1590271, 21.96652794], [72.1590271, 21.96708298], [72.15875244, 21.96708298], [72.15875244, 21.96736145], [72.15847015, 21.96736145], [72.15847015, 21.96847153], [72.1581955, 21.96847153], [72.15820313, 21.96874809], [72.15791321, 21.96874809], [72.15791321, 21.96903038], [72.15763855, 21.96902847], [72.15763855, 21.97097206], [72.15735626, 21.97096825], [72.15735626, 21.97153091], [72.1570816, 21.97153091], [72.1570816, 21.97431183], [72.15680695, 21.97430611], [72.15680695, 21.97486115], [72.15652466, 21.97486115], [72.15653229, 21.97513962], [72.15625, 21.97513962], [72.15625, 21.97569466], [72.15597534, 21.97569466], [72.15597534, 21.97597122], [72.15569305, 21.97597122], [72.15569305, 21.97624969], [72.1554184, 21.97624969], [72.1554184, 21.97653008], [72.15458679, 21.97652817], [72.15458679, 21.97680473], [72.15374756, 21.97680473], [72.15374756, 21.97708321], [72.15291595, 21.97708321], [72.15291595, 21.97736168], [72.1526413, 21.97735977], [72.1526413, 21.97764015], [72.15235901, 21.97764015], [72.15235901, 21.97792053], [72.15207672, 21.97792053], [72.15207672, 21.97820091], [72.15180206, 21.97819328], [72.15180206, 21.97847176], [72.1515274, 21.97846985], [72.1515274, 21.97875977], [72.15125275, 21.97875977], [72.15125275, 21.97903061], [72.15097046, 21.97903061], [72.15097046, 21.97931099], [72.1506958, 21.97930336], [72.1506958, 21.97958374], [72.15039825, 21.97957993], [72.15039825, 21.98014069], [72.15013885, 21.98013878], [72.15013885, 21.98069382], [72.14958191, 21.98069382], [72.14958191, 21.98097229], [72.14930725, 21.98097038], [72.14930725, 21.98125076], [72.14903259, 21.98125076], [72.14903259, 21.98153114], [72.14875031, 21.98153114], [72.14875031, 21.98181915], [72.14847565, 21.98180771], [72.14847565, 21.98208427], [72.14819336, 21.98208046], [72.14819336, 21.98236084], [72.1479187, 21.98236084], [72.1479187, 21.98264122], [72.14765167, 21.98264122], [72.14765167, 21.98291969], [72.1470871, 21.98291779], [72.1470871, 21.98319435], [72.14680481, 21.98319435], [72.14680481, 21.98347282], [72.14653015, 21.98347282], [72.14653015, 21.98291779], [72.14679718, 21.98291969], [72.14679718, 21.98236084], [72.14736176, 21.98236084], [72.14736176, 21.98208046], [72.14763641, 21.98208237], [72.14763641, 21.98152542], [72.14819336, 21.98153114], [72.14819336, 21.98125076], [72.14848328, 21.98125076], [72.14847565, 21.98069382], [72.14902496, 21.98069382], [72.14902496, 21.98041534], [72.14930725, 21.98042107], [72.14930725, 21.98014069], [72.14958191, 21.98014069], [72.14958191, 21.97986031], [72.14985657, 21.97986031], [72.14985657, 21.97957993], [72.15013885, 21.97958374], [72.15013885, 21.9790287], [72.15068817, 21.97903061], [72.15068817, 21.97846985], [72.15097046, 21.97847176], [72.15097046, 21.97763824], [72.15125275, 21.97764015], [72.15125275, 21.97735977], [72.15180206, 21.97736168], [72.15180206, 21.97708321], [72.15208435, 21.97708321], [72.15208435, 21.97680473], [72.15291595, 21.97680473], [72.15291595, 21.97652817], [72.15319061, 21.97653008], [72.15319824, 21.97624969], [72.15345764, 21.97624969], [72.15345764, 21.97597122], [72.15402985, 21.97597122], [72.15402985, 21.97569466], [72.1543045, 21.97569466], [72.1543045, 21.97541618], [72.15458679, 21.97542], [72.15458679, 21.97513962], [72.15486145, 21.97513962], [72.15486145, 21.97486115], [72.15513611, 21.97486115], [72.15513611, 21.97458267], [72.1554184, 21.97458267], [72.1554184, 21.97430611], [72.15569305, 21.97431183], [72.15569305, 21.97402954], [72.15598297, 21.97402954], [72.15598297, 21.9731884], [72.15625, 21.97319412], [72.15625, 21.97263908], [72.15652466, 21.97263908], [72.15652466, 21.97180557], [72.1568222, 21.97180939], [72.1568222, 21.97014046], [72.1570816, 21.97014046], [72.1570816, 21.96874809], [72.15735626, 21.96874809], [72.15735626, 21.96763992], [72.15763855, 21.96763992], [72.15763855, 21.96735954], [72.15791321, 21.96736145], [72.15791321, 21.96652794], [72.15820313, 21.96652985], [72.15820313, 21.96597099], [72.15847015, 21.9659729], [72.15847015, 21.96541405], [72.15875244, 21.96541977], [72.15875244, 21.96513939], [72.15930176, 21.96513939], [72.15930176, 21.96458054], [72.15958405, 21.96458244], [72.15958405, 21.9640274], [72.1598587, 21.96403122], [72.1598587, 21.96347046], [72.16014099, 21.96347237], [72.16014099, 21.96319389], [72.16041565, 21.96319389], [72.16041565, 21.96263885], [72.16069794, 21.96264076], [72.16069794, 21.96181107], [72.1609726, 21.96181107], [72.1609726, 21.96068954], [72.16069794, 21.96069527], [72.16069794, 21.95986176], [72.16041565, 21.95986176], [72.16041565, 21.95930481], [72.15930176, 21.95930481], [72.15930176, 21.95902824], [72.1590271, 21.95902824], [72.1590271, 21.95930481], [72.15875244, 21.95930481], [72.15875244, 21.95902824], [72.15598297, 21.95903015], [72.15598297, 21.95875168], [72.15374756, 21.95875168], [72.15374756, 21.95846748], [72.1526413, 21.9584713], [72.1526413, 21.95819473], [72.15180206, 21.95819473], [72.15180206, 21.95791626], [72.1515274, 21.95791817], [72.1515274, 21.95764923], [72.15097046, 21.95764923], [72.15097046, 21.95736122], [72.15039825, 21.95736122], [72.15039825, 21.95708084], [72.1498642, 21.95708275], [72.1498642, 21.95680618], [72.14903259, 21.95680809], [72.14903259, 21.95652962], [72.14848328, 21.95652962], [72.14848328, 21.95625114], [72.14819336, 21.95625114], [72.14819336, 21.95597076], [72.1479187, 21.95597267], [72.1479187, 21.9556942], [72.14736176, 21.9556942], [72.14736176, 21.95541763], [72.1470871, 21.95541954], [72.1470871, 21.95486069], [72.14765167, 21.95486069], [72.14765167, 21.95514107], [72.14875031, 21.95514107], [72.14875031, 21.95541954], [72.14958191, 21.95541763], [72.14958191, 21.9556942], [72.1498642, 21.9556942], [72.1498642, 21.95597267], [72.15125275, 21.95597076], [72.15125275, 21.95625114], [72.15180206, 21.95625114], [72.15180206, 21.95652962], [72.15235901, 21.95652962], [72.15235901, 21.95680809], [72.15319824, 21.95680618], [72.15319824, 21.95708275], [72.15374756, 21.95708084], [72.15374756, 21.95736122], [72.1554184, 21.95736122], [72.1554184, 21.95708084], [72.15597534, 21.95708275], [72.15597534, 21.95736122], [72.1598587, 21.95736122], [72.1598587, 21.95708084], [72.16124725, 21.95708275], [72.16124725, 21.95680618], [72.16179657, 21.95680809], [72.16179657, 21.95652962], [72.16208649, 21.95652962], [72.16208649, 21.95625114], [72.16319275, 21.95625114], [72.16319275, 21.95597076], [72.16374969, 21.95597267], [72.16374969, 21.9556942], [72.16486359, 21.9556942], [72.16486359, 21.95541763], [72.16568756, 21.95541954], [72.16568756, 21.95514107], [72.16625214, 21.95514107], [72.16625214, 21.95486069], [72.16707611, 21.95486069], [72.16707611, 21.95458984], [72.16764069, 21.95458984], [72.16764069, 21.95430946], [72.16819763, 21.95430946], [72.16819763, 21.95403099], [72.16847229, 21.95403099], [72.16847229, 21.95375061], [72.16902924, 21.95375061], [72.16902924, 21.95347023], [72.16958618, 21.95347214], [72.16958618, 21.95319366], [72.1701355, 21.95319366], [72.1701355, 21.95291519], [72.17069244, 21.95292091], [72.17069244, 21.95264053], [72.17153168, 21.95264053], [72.17153168, 21.95236015], [72.17180634, 21.95236015], [72.17180634, 21.95208359], [72.17208099, 21.95208359], [72.17208099, 21.95180321], [72.17236328, 21.95181084], [72.17236328, 21.95153046], [72.17263794, 21.95153046], [72.17263794, 21.95125008], [72.17292023, 21.95125008], [72.17292023, 21.9509697], [72.17346954, 21.9509716], [72.17346954, 21.95069313], [72.17375183, 21.95070076], [72.17375183, 21.95042038], [72.17402649, 21.95042038], [72.17402649, 21.94985962], [72.17430878, 21.94986153], [72.17430878, 21.94958115], [72.17458344, 21.94958115], [72.17458344, 21.94930649], [72.17485809, 21.94930267], [72.17485809, 21.94902802], [72.17514038, 21.94902992], [72.17514038, 21.94874954], [72.17542267, 21.94874954], [72.17541504, 21.94847107], [72.17569733, 21.94847107], [72.17569733, 21.9481945], [72.17597198, 21.9481945], [72.17597198, 21.94791603], [72.17652893, 21.94791985], [72.17652893, 21.94763947], [72.17708588, 21.94763947], [72.17708588, 21.9473629], [72.17736053, 21.9473629], [72.17736053, 21.94708252], [72.17763519, 21.94708252], [72.17763519, 21.94680595], [72.17791748, 21.94681168], [72.17791748, 21.94625092], [72.17874908, 21.94625092], [72.17874908, 21.94568825], [72.17903137, 21.94569397], [72.17903137, 21.9454174], [72.17930603, 21.94541931], [72.17930603, 21.94486046], [72.17986298, 21.94486046], [72.17986298, 21.94457817], [72.18013763, 21.94458389], [72.18013763, 21.94430542], [72.18041992, 21.94430923], [72.18041992, 21.94403076], [72.18096924, 21.94403076], [72.18096924, 21.94375038], [72.18125153, 21.94375038], [72.18125153, 21.94346809], [72.18152618, 21.94347191], [72.18152618, 21.94319534], [72.18180847, 21.94319916], [72.18180847, 21.94292068], [72.18208313, 21.94292068], [72.18208313, 21.94180107], [72.18235779, 21.94180679], [72.18235779, 21.94124985], [72.18264008, 21.94124985], [72.18264008, 21.94069099], [72.18291473, 21.94069672], [72.18291473, 21.94041443], [72.18319702, 21.94042015], [72.18319702, 21.94013977], [72.18347168, 21.94013977], [72.18347168, 21.93985939], [72.18402863, 21.9398613], [72.18402863, 21.93958282], [72.18486023, 21.93959045], [72.18486023, 21.93902969], [72.18514252, 21.93902969], [72.18514252, 21.93875122], [72.18541718, 21.93875122], [72.18541718, 21.93847084], [72.18624878, 21.93847275], [72.18624878, 21.93819427], [72.18736267, 21.93819427], [72.18736267, 21.9379158], [72.18818665, 21.93791962], [72.18818665, 21.93764114], [72.18930817, 21.93764114], [72.18930817, 21.93736076], [72.19013977, 21.93736076], [72.19013977, 21.93708038], [72.19319153, 21.93708038], [72.19319153, 21.93736076], [72.19374847, 21.93736076], [72.19374847, 21.93764114], [72.19430542, 21.93763924], [72.19430542, 21.93847275], [72.19458008, 21.93847275], [72.19458008, 21.93819427], [72.19708252, 21.93819427], [72.19708252, 21.93847275], [72.19735718, 21.93847084], [72.19735718, 21.93875122], [72.19790649, 21.93875122], [72.19790649, 21.93902969], [72.19847107, 21.93902969], [72.19847107, 21.93931007], [72.1987381, 21.93931007], [72.1987381, 21.93959045], [72.19985962, 21.93958282], [72.19985962, 21.9398613], [72.20124817, 21.9398613], [72.20124817, 21.93958282], [72.20180511, 21.93958282], [72.20180511, 21.9398613], [72.20236206, 21.93985939], [72.20236206, 21.94042015], [72.20263672, 21.94041443], [72.20263672, 21.94069672], [72.20402527, 21.94069672], [72.20402527, 21.94097137], [72.20430756, 21.94096947], [72.20430756, 21.94124985], [72.20485687, 21.94124985], [72.20485687, 21.94153023], [72.20541382, 21.94152641], [72.20541382, 21.94180679], [72.20569611, 21.94180679], [72.20569611, 21.94208336], [72.20597076, 21.94208336], [72.20597076, 21.94236183], [72.20625305, 21.94235992], [72.20625305, 21.94264984], [72.20652771, 21.94264984], [72.20652771, 21.94292068], [72.20680237, 21.94292068], [72.20680237, 21.94319916], [72.20735931, 21.94319534], [72.20735931, 21.94347191], [72.20791626, 21.94347191], [72.20791626, 21.94375038], [72.20874786, 21.94375038], [72.20874786, 21.94430923], [72.20930481, 21.94430542], [72.20930481, 21.94458389], [72.2095871, 21.94457817], [72.2095871, 21.94486046], [72.21013641, 21.94486046], [72.21013641, 21.94514084], [72.2104187, 21.94514084], [72.2104187, 21.94541931], [72.21013641, 21.9454174], [72.21013641, 21.94569397], [72.2104187, 21.94569397], [72.2104187, 21.94597244], [72.2106781, 21.94597054], [72.2106781, 21.94652939], [72.21125031, 21.94652748], [72.21125031, 21.94708252], [72.21152496, 21.94708252], [72.21152496, 21.9473629], [72.21208191, 21.9473629], [72.21208191, 21.94763947], [72.21235657, 21.94763947], [72.21235657, 21.94791985], [72.21291351, 21.94791603], [72.21291351, 21.9481945], [72.2131958, 21.9481945], [72.2131958, 21.94847107], [72.21373749, 21.94846153], [72.21373749, 21.94874954], [72.2140274, 21.94874954], [72.2140274, 21.94846153], [72.2179184, 21.94847107], [72.2179184, 21.94791603], [72.21902466, 21.94791603], [72.21902466, 21.9481945], [72.2195816, 21.9481945], [72.2195816, 21.94791603], [72.22013855, 21.94791985], [72.22013855, 21.94763947], [72.22041321, 21.94763947], [72.22041321, 21.9473629], [72.22097015, 21.9473629], [72.22097015, 21.94652939], [72.22125244, 21.94652939], [72.22125244, 21.94625092], [72.2215271, 21.94625092], [72.2215271, 21.94597054], [72.22180176, 21.94597244], [72.22180176, 21.94569397], [72.22208405, 21.94569397], [72.22208405, 21.9454174], [72.2223587, 21.94541931], [72.2223587, 21.94486046], [72.22264099, 21.94486046], [72.22264099, 21.94430923], [72.22293091, 21.94430923], [72.22293091, 21.94403076], [72.22319794, 21.94403076], [72.22319794, 21.94346809], [72.2234726, 21.94347191], [72.2234726, 21.94319534], [72.22374725, 21.94319916], [72.22374725, 21.94292068], [72.22402954, 21.94292068], [72.22402954, 21.94264984], [72.22429657, 21.94264984], [72.22429657, 21.94207954], [72.22458649, 21.94208336], [72.22458649, 21.94180679], [72.22486115, 21.94180679], [72.22486115, 21.94152641], [72.2251358, 21.94153023], [72.2251358, 21.94124985], [72.22541809, 21.94124985], [72.22541809, 21.94096947], [72.22569275, 21.94097137], [72.22569275, 21.9398613], [72.22597504, 21.9398613], [72.22597504, 21.93930435], [72.22624969, 21.93931007], [72.22624969, 21.93847084], [72.22652435, 21.93847275], [72.22652435, 21.93763924], [72.22680664, 21.93764114], [72.22680664, 21.93736076], [72.2270813, 21.93736076], [72.2270813, 21.93625069], [72.22735596, 21.93625069], [72.22735596, 21.93569183], [72.22763824, 21.93569374], [72.22763824, 21.9351387], [72.2279129, 21.93514061], [72.2279129, 21.93486023], [72.22820282, 21.93486023], [72.22819519, 21.93347168], [72.2279129, 21.93347168], [72.2279129, 21.93319511], [72.22820282, 21.93320274], [72.22820282, 21.93292046], [72.22846985, 21.93292046], [72.22846985, 21.9323616], [72.22875214, 21.9323616], [72.22875214, 21.93152809], [72.22902679, 21.93152809], [72.22902679, 21.93097115], [72.22930908, 21.93097305], [72.22930908, 21.93069458], [72.22958374, 21.93069458], [72.22958374, 21.93041611], [72.2298584, 21.93041992], [72.2298584, 21.92930984], [72.23014069, 21.92930984], [72.23014069, 21.92902946], [72.23042297, 21.92902946], [72.23042297, 21.92847061], [72.23069763, 21.92847252], [72.23069763, 21.9268074], [72.23097229, 21.92681122], [72.23097229, 21.92653084], [72.23181152, 21.92653084], [72.23181152, 21.92625046], [72.23208618, 21.92625046], [72.23208618, 21.92597198], [72.23236084, 21.92597198], [72.23236084, 21.92569351], [72.2326355, 21.92569351], [72.2326355, 21.92541695], [72.23291779, 21.92542076], [72.23291779, 21.92514038], [72.23319244, 21.92514038], [72.23319244, 21.92457962], [72.23347473, 21.92458344], [72.23347473, 21.92374992], [72.23374939, 21.92374992], [72.23374939, 21.92346954], [72.23402405, 21.92347145], [72.23402405, 21.92319489], [72.23430634, 21.92319489], [72.23430634, 21.92291641], [72.23458099, 21.92292023], [72.23458099, 21.92263985], [72.23487091, 21.92263985], [72.23487091, 21.92235947], [72.23513794, 21.92236137], [72.23513794, 21.9220829], [72.23542023, 21.9220829], [72.23542023, 21.92152786], [72.23569489, 21.92152786], [72.23569489, 21.92124939], [72.23625183, 21.92124939], [72.23625183, 21.92097282], [72.23652649, 21.92097282], [72.23652649, 21.92069435], [72.23680878, 21.92069435], [72.23680878, 21.92041588], [72.23764038, 21.92041969], [72.23764038, 21.91986084], [72.23819733, 21.91986084], [72.23819733, 21.91957855], [72.23847198, 21.91958237], [72.23847198, 21.9193058], [72.23874664, 21.91930962], [72.23874664, 21.91902924], [72.23902893, 21.91902924], [72.23902893, 21.91875076], [72.23958588, 21.91875076], [72.23958588, 21.91848183], [72.24041748, 21.91848183], [72.24041748, 21.91791916], [72.2409668, 21.91791916], [72.2409668, 21.91764069], [72.24124908, 21.91764069], [72.24124908, 21.91736031], [72.24153137, 21.91736031], [72.24153137, 21.91707993], [72.24180603, 21.91708374], [72.24180603, 21.91680527], [72.24208069, 21.91680908], [72.24208069, 21.91653061], [72.24236298, 21.91653061], [72.24236298, 21.91596985], [72.24263763, 21.91597176], [72.24263763, 21.91541862], [72.24291992, 21.91542053], [72.24291992, 21.91485977], [72.24319458, 21.91486168], [72.24319458, 21.91430473], [72.24346924, 21.91430473], [72.24346924, 21.91402626], [72.24375153, 21.91403008], [72.24375153, 21.91374969], [72.24404144, 21.91374969], [72.24402618, 21.91319656], [72.24430847, 21.91319656], [72.24430847, 21.91291428], [72.24458313, 21.91292], [72.24458313, 21.91263962], [72.24485779, 21.91263962], [72.24485779, 21.9123497], [72.24514008, 21.91236115], [72.24514008, 21.91152763], [72.2454071, 21.91152954], [72.2454071, 21.91097069], [72.24569702, 21.9109726], [72.24569702, 21.91069221], [72.24597168, 21.91069221], [72.24597168, 21.91041756], [72.24624634, 21.91041946], [72.24624634, 21.91014099], [72.24652863, 21.91014099], [72.24652863, 21.90986061], [72.24681091, 21.90986061], [72.24680328, 21.90930557], [72.24710083, 21.90930939], [72.24710083, 21.90847015], [72.24736023, 21.90847206], [72.24736023, 21.90791702], [72.24764252, 21.90792274], [72.24764252, 21.90764046], [72.24791718, 21.90764046], [72.24791718, 21.90681267], [72.24819183, 21.90681267], [72.24819183, 21.90597153], [72.24847412, 21.90597153], [72.24847412, 21.90513992], [72.24874878, 21.90513992], [72.24874878, 21.90457916], [72.24903107, 21.90458298], [72.24903107, 21.90319443], [72.24930573, 21.90319443], [72.24930573, 21.90263939], [72.24958038, 21.90263939], [72.24958038, 21.90236092], [72.24984741, 21.90236092], [72.24984741, 21.90180969], [72.25013733, 21.90180969], [72.25013733, 21.90153122], [72.25041962, 21.90153122], [72.25041962, 21.90125084], [72.25068665, 21.90125084], [72.25068665, 21.90097046], [72.25096893, 21.90097237], [72.25096893, 21.90069389], [72.25125122, 21.90069389], [72.25125122, 21.90013885], [72.25152588, 21.90014076], [72.25152588, 21.89958], [72.25208282, 21.89958572], [72.25208282, 21.89902687], [72.25235748, 21.89903069], [72.25235748, 21.89846992], [72.25263977, 21.89847183], [72.25263977, 21.89791679], [72.2529068, 21.89792061], [72.2529068, 21.89735031], [72.25319672, 21.89736176], [72.25319672, 21.89652824], [72.25347137, 21.89653015], [72.25347137, 21.89569283], [72.25375366, 21.89569473], [72.25375366, 21.89458275], [72.25402832, 21.89458275], [72.25402832, 21.89402771], [72.25430298, 21.89402962], [72.25430298, 21.89347267], [72.25458527, 21.89347267], [72.25458527, 21.8931942], [72.25485992, 21.8931942], [72.25485992, 21.89263916], [72.25514221, 21.89263916], [72.25514221, 21.8920784], [72.25541687, 21.89208412], [72.25541687, 21.89125061], [72.25569153, 21.89125061], [72.25569153, 21.89068985], [72.25597382, 21.89069366], [72.25597382, 21.89013863], [72.25624847, 21.89014053], [72.25624847, 21.88875008], [72.25653076, 21.88875008], [72.25653076, 21.88735962], [72.25680542, 21.88736153], [72.25680542, 21.88624954], [72.25708008, 21.88624954], [72.25708008, 21.88513947], [72.25736237, 21.88513947], [72.25736237, 21.88486099], [72.25708008, 21.88486099], [72.25708008, 21.88402939], [72.25736237, 21.88402939], [72.25736237, 21.88347054], [72.25763702, 21.88347244], [72.25763702, 21.88319206], [72.25791931, 21.88319206], [72.25791931, 21.88236046], [72.25818634, 21.88237], [72.25818634, 21.88097191], [72.25791931, 21.88097191], [72.25791931, 21.88069534], [72.25818634, 21.88070107], [72.25818634, 21.87735748], [72.25791931, 21.8773613], [72.25791931, 21.87624741], [72.25763702, 21.87624741], [72.25763702, 21.87541771], [72.25736237, 21.87541962], [72.25736237, 21.87430954], [72.25763702, 21.87430954], [72.25763702, 21.87375069], [72.25736237, 21.87375069], [72.25736237, 21.87318039], [72.25708008, 21.87319374], [72.25708008, 21.87208366], [72.25680542, 21.87208366], [72.25680542, 21.87152863], [72.25653076, 21.87153053], [72.25653076, 21.87096977], [72.25624847, 21.87097168], [72.25624847, 21.87013817], [72.25598145, 21.87014008], [72.25598145, 21.8698597], [72.25569153, 21.8698616], [72.25569153, 21.86930466], [72.25597382, 21.86930466], [72.25597382, 21.8670826], [72.25569153, 21.8670826], [72.25569153, 21.86486053], [72.25541687, 21.86486053], [72.25541687, 21.86403084], [72.25514221, 21.86403084], [72.25514221, 21.86292076], [72.25485992, 21.86292076], [72.25485992, 21.86264038], [72.25514221, 21.86264038], [72.25514221, 21.85931015], [72.25485992, 21.85931015], [72.25485992, 21.85902977], [72.25514221, 21.85902977], [72.25514221, 21.85764122], [72.25485992, 21.85764122], [72.25485992, 21.85680962], [72.25514221, 21.85680962], [72.25514221, 21.85625076], [72.25541687, 21.85625076], [72.25541687, 21.85486031], [72.25569153, 21.85486031], [72.25569153, 21.85264015], [72.25598145, 21.85264015], [72.25598145, 21.85236168], [72.25624847, 21.85236168], [72.25624847, 21.85208321], [72.25597382, 21.85208321], [72.25597382, 21.85180473], [72.25624847, 21.85180473], [72.25624847, 21.85097313], [72.25597382, 21.85097313], [72.25597382, 21.85069466], [72.25624847, 21.85069466], [72.25624847, 21.84930611], [72.25597382, 21.84930611], [72.25597382, 21.84902954], [72.25624847, 21.84902954], [72.25624847, 21.84791946], [72.25653076, 21.84791946], [72.25653076, 21.84680939], [72.25681305, 21.84680939], [72.25681305, 21.84542084], [72.25708008, 21.84542084], [72.25708008, 21.84403038], [72.25736237, 21.84403038], [72.25736237, 21.84346962], [72.25708008, 21.84347153], [72.25708008, 21.84291649], [72.25736237, 21.8429203], [72.25736237, 21.84208107], [72.25763702, 21.84208107], [72.25763702, 21.84041595], [72.25791931, 21.84041977], [72.25791931, 21.8393116], [72.25818634, 21.8393116], [72.25818634, 21.83818817], [72.25846863, 21.83819389], [72.25846863, 21.83708382], [72.25875092, 21.83708382], [72.25875092, 21.83263969], [72.25904083, 21.83263969], [72.25902557, 21.83236122], [72.25875092, 21.83236122], [72.25875092, 21.83126068], [72.25904083, 21.83126068], [72.25904083, 21.82986069], [72.25875092, 21.82986069], [72.25875092, 21.82930946], [72.25904083, 21.82930946], [72.25904083, 21.8290329], [72.25930786, 21.8290329], [72.25930786, 21.82457924], [72.25902557, 21.82458305], [72.25902557, 21.82236099], [72.25930786, 21.82236099], [72.25930786, 21.81625938], [72.25904083, 21.81625938], [72.25904083, 21.81431007], [72.25930786, 21.81431007], [72.25930786, 21.81347275], [72.25902557, 21.81347275], [72.25902557, 21.8129158], [72.25875092, 21.81291962], [72.25875092, 21.81236076], [72.25846863, 21.81236076], [72.25846863, 21.81180954], [72.25904083, 21.81180954], [72.25904083, 21.80957985], [72.25875092, 21.80958366], [72.25875092, 21.80708313], [72.25904083, 21.80709076], [72.25904083, 21.80680084], [72.25875092, 21.80680466], [72.25875092, 21.8054142], [72.25846863, 21.80541992], [72.25846863, 21.80513954], [72.25875092, 21.80513954], [72.25875092, 21.80402946], [72.25846863, 21.80402946], [72.25846863, 21.8006916], [72.25875092, 21.80069351], [72.25875092, 21.79652977], [72.25904083, 21.79652977], [72.25904083, 21.79430962], [72.25930786, 21.79430962], [72.25930786, 21.79403114], [72.25904083, 21.79403114], [72.25904083, 21.79375076], [72.25930786, 21.79375076], [72.25930786, 21.79236031], [72.25958252, 21.79236031], [72.25958252, 21.79014015], [72.25985718, 21.79014015], [72.25985718, 21.78736115], [72.26013947, 21.78736115], [72.26013947, 21.78430939], [72.26040649, 21.78430939], [72.26040649, 21.78346825], [72.26069641, 21.78347206], [72.26069641, 21.78236198], [72.26097107, 21.78236198], [72.26097107, 21.78152847], [72.26125336, 21.78153038], [72.26125336, 21.78014946], [72.26152802, 21.78014946], [72.26152802, 21.77874947], [72.26178741, 21.77874947], [72.26178741, 21.77819061], [72.26208496, 21.77819443], [72.26208496, 21.77736092], [72.26235962, 21.77736092], [72.26235962, 21.77653122], [72.26264191, 21.77653122], [72.26264191, 21.77569008], [72.26291656, 21.77569389], [72.26291656, 21.77458382], [72.26319122, 21.77458382], [72.26319122, 21.77375031], [72.26346588, 21.77375031], [72.26346588, 21.77292252], [72.26374817, 21.77292252], [72.26374817, 21.77208138], [72.26403046, 21.77208328], [72.26403046, 21.7709713], [72.26431274, 21.77098083], [72.26431274, 21.77069092], [72.26457977, 21.77069473], [72.26457977, 21.76986122], [72.2648468, 21.76986122], [72.2648468, 21.76902962], [72.26513672, 21.76902962], [72.26513672, 21.76791954], [72.26541901, 21.76791954], [72.26541901, 21.76653099], [72.26568604, 21.76653099], [72.26568604, 21.76597023], [72.26597595, 21.76597214], [72.26597595, 21.76569366], [72.26625061, 21.76569366], [72.26625061, 21.76513863], [72.2665329, 21.76514053], [72.2665329, 21.76457977], [72.26680756, 21.76458359], [72.26680756, 21.76402855], [72.26708221, 21.76403046], [72.26708221, 21.76355934], [72.26708221, 21.7634716], [72.2673645, 21.7634716], [72.2673645, 21.76263809], [72.26763916, 21.76264], [72.26763916, 21.76208115], [72.26791382, 21.76208115], [72.26791382, 21.76180649], [72.26819611, 21.76178932], [72.26819611, 21.76124954], [72.26847076, 21.76124954], [72.26847076, 21.76042175], [72.26875305, 21.76042175], [72.26875305, 21.75958061], [72.26902771, 21.75958252], [72.26902771, 21.75902748], [72.26930237, 21.75904274], [72.26930237, 21.75818825], [72.26958466, 21.75819397], [72.26958466, 21.75764084], [72.26985931, 21.75764084], [72.26985931, 21.75707817], [72.2701416, 21.75708389], [72.2701416, 21.75541878], [72.27041626, 21.75542068], [72.27041626, 21.75346947], [72.2701416, 21.75347137], [72.2701416, 21.75319672], [72.27041626, 21.75319672], [72.27041626, 21.75291443], [72.2701416, 21.75292015], [72.2701416, 21.75235939], [72.27041626, 21.7523613], [72.27041626, 21.75180435], [72.27069092, 21.75181007], [72.27069092, 21.75152969], [72.27098083, 21.75152969], [72.27098083, 21.75041962], [72.27069092, 21.75041962], [72.27069092, 21.74985123], [72.27041626, 21.74986076], [72.27041626, 21.74819374], [72.2701416, 21.74819374], [72.2701416, 21.7476387], [72.26985931, 21.74764061], [72.26985931, 21.74708176], [72.26958466, 21.74708366], [72.26958466, 21.74652863], [72.26930237, 21.74653053], [72.26930237, 21.74625015], [72.26902771, 21.74625015], [72.26902771, 21.74597168], [72.26875305, 21.74597168], [72.26875305, 21.74569511], [72.26847076, 21.74570274], [72.26847076, 21.74514008], [72.26819611, 21.74514008], [72.26819611, 21.7448597], [72.26791382, 21.7448616], [72.26791382, 21.74430466], [72.26763916, 21.74430466], [72.26763916, 21.74402809], [72.26735687, 21.74403954], [72.26735687, 21.74374962], [72.26708221, 21.74374962], [72.26708221, 21.74347115], [72.26680756, 21.74347305], [72.26680756, 21.74319458], [72.26625061, 21.74319458], [72.26625061, 21.74291611], [72.26597595, 21.74291992], [72.26597595, 21.74180984], [72.26568604, 21.74180984], [72.26568604, 21.74152946], [72.26541901, 21.74152946], [72.26541901, 21.74125099], [72.26513672, 21.74125099], [72.26513672, 21.74097061], [72.26486206, 21.74097252], [72.26486206, 21.74069595], [72.26457977, 21.74069595], [72.26457977, 21.74041748], [72.26347351, 21.74041748], [72.26347351, 21.74069595], [72.26319122, 21.74069023], [72.26319122, 21.74125099], [72.26291656, 21.74125099], [72.26291656, 21.74180984], [72.26264191, 21.74180984], [72.26264191, 21.74236107], [72.26235962, 21.74236107], [72.26235962, 21.74263954], [72.26208496, 21.74263954], [72.26208496, 21.74319458], [72.26180267, 21.74319458], [72.26180267, 21.74347305], [72.26152802, 21.74347115], [72.26152802, 21.74403954], [72.26125336, 21.74402809], [72.26125336, 21.74430466], [72.26113892, 21.74430466], [72.26097107, 21.74430466], [72.26097107, 21.7448616], [72.26069641, 21.7448597], [72.26069641, 21.74514008], [72.26041412, 21.74513817], [72.26041412, 21.74708366], [72.26013947, 21.74708366], [72.26013947, 21.74819374], [72.25985718, 21.74819183], [72.25985718, 21.74930954], [72.25958252, 21.74930573], [72.25958252, 21.74986076], [72.25930786, 21.74985123], [72.25930786, 21.75041962], [72.25902557, 21.7504158], [72.25902557, 21.75069237], [72.25846863, 21.75069046], [72.25846863, 21.75125122], [72.25819397, 21.75124931], [72.25819397, 21.75208282], [72.25791931, 21.75208282], [72.25791931, 21.7523613], [72.25763702, 21.7523613], [72.25763702, 21.75319672], [72.25736237, 21.75319099], [72.25736237, 21.75374985], [72.25708008, 21.75374985], [72.25708008, 21.75403023], [72.25653076, 21.75402832], [72.25653076, 21.75430679], [72.25624847, 21.75430679], [72.25624847, 21.75458336], [72.25653076, 21.75457954], [72.25653076, 21.7551403], [72.25624847, 21.7551403], [72.25624847, 21.75542068], [72.25598145, 21.75542068], [72.25598145, 21.75569916], [72.25569153, 21.75569916], [72.25569153, 21.75597763], [72.25598145, 21.75597763], [72.25598145, 21.75680923], [72.25569153, 21.75680542], [72.25569153, 21.75708389], [72.25541687, 21.75708389], [72.25541687, 21.75819397], [72.25514221, 21.75818825], [72.25514221, 21.75875092], [72.25485992, 21.75875092], [72.25485992, 21.75904274], [72.2545929, 21.75904274], [72.2545929, 21.75931168], [72.25430298, 21.75931168], [72.25430298, 21.76013947], [72.25402832, 21.76013947], [72.25402832, 21.76042175], [72.25319672, 21.76041603], [72.25319672, 21.7606945], [72.25291443, 21.7606945], [72.25291443, 21.76097107], [72.25263977, 21.76097107], [72.25263977, 21.76292038], [72.25235748, 21.76291656], [72.25235748, 21.7634716], [72.25208282, 21.7634697], [72.25208282, 21.76403046], [72.25180817, 21.76403046], [72.25180817, 21.76680946], [72.25152588, 21.76680756], [72.25152588, 21.76708412], [72.25125122, 21.76708031], [72.25125122, 21.76764107], [72.25096893, 21.76763916], [72.25096893, 21.7681942], [72.25068665, 21.76819038], [72.25068665, 21.76902962], [72.25041962, 21.76902962], [72.25041962, 21.77069473], [72.25013733, 21.77069473], [72.25013733, 21.77180481], [72.24986267, 21.77180481], [72.24986267, 21.77347183], [72.24958038, 21.77347183], [72.24958038, 21.77402687], [72.24930573, 21.77402687], [72.24931335, 21.77486038], [72.24903107, 21.77486038], [72.24903107, 21.77569389], [72.24930573, 21.77569389], [72.24931335, 21.77763939], [72.24903107, 21.77763939], [72.24903107, 21.77958298], [72.24874878, 21.77958107], [72.24874878, 21.78375053], [72.24847412, 21.78375053], [72.24847412, 21.78458405], [72.24874878, 21.78458405], [72.24874878, 21.7859726], [72.24846649, 21.78596115], [72.24846649, 21.78763962], [72.24819183, 21.78763962], [72.24819183, 21.78930473], [72.24764252, 21.78930283], [72.24764252, 21.79014015], [72.24736023, 21.79014015], [72.24736023, 21.79042053], [72.24708557, 21.79041672], [72.24708557, 21.79097176], [72.24652863, 21.79096985], [72.24652863, 21.79153061], [72.24624634, 21.79153061], [72.24624634, 21.79181099], [72.24569702, 21.79181099], [72.24569702, 21.79236031], [72.24514008, 21.79236031], [72.24514008, 21.79264069], [72.24458313, 21.79264069], [72.24458313, 21.79292107], [72.24402618, 21.79291534], [72.24402618, 21.79319382], [72.24346924, 21.79319382], [72.24346924, 21.79347229], [72.24263763, 21.79347038], [72.24263763, 21.79375076], [72.24180603, 21.79375076], [72.24180603, 21.79403114], [72.24067688, 21.79403114], [72.24067688, 21.79430962], [72.23986053, 21.79430771], [72.23986053, 21.79458427], [72.23929596, 21.79458046], [72.23929596, 21.79486084], [72.23874664, 21.79486084], [72.23874664, 21.79515076], [72.23790741, 21.79515076], [72.23790741, 21.79541969], [72.23735809, 21.79541779], [72.23735809, 21.79569435], [72.23708344, 21.79569435], [72.23708344, 21.79597282], [72.23680878, 21.79597092], [72.23680878, 21.79624939], [72.23652649, 21.79624939], [72.23652649, 21.79652977], [72.23596954, 21.79652977], [72.23596954, 21.79597092], [72.23625183, 21.79597282], [72.23625183, 21.79541779], [72.23596954, 21.79541969], [72.23596954, 21.79458046], [72.23430634, 21.79458427], [72.23430634, 21.79430771], [72.23402405, 21.79430771], [72.23402405, 21.79458427], [72.23291779, 21.79458046], [72.23291779, 21.79486084], [72.23236084, 21.79486084], [72.23236084, 21.79515076], [72.23210144, 21.79515076], [72.23210144, 21.79541969], [72.23180389, 21.79541779], [72.23180389, 21.79569435], [72.23041534, 21.79569435], [72.23041534, 21.79597282], [72.22957611, 21.79597092], [72.22957611, 21.79624939], [72.22902679, 21.79624939], [72.22902679, 21.79652977], [72.22846985, 21.79652977], [72.22846985, 21.79680824], [72.2279129, 21.79680634], [72.2279129, 21.7970829], [72.22736359, 21.7970829], [72.22736359, 21.79736137], [72.2270813, 21.79735756], [72.2270813, 21.79763985], [72.22624969, 21.79763985], [72.22624969, 21.79791832], [72.22597504, 21.79791641], [72.22597504, 21.79819489], [72.22541809, 21.79819489], [72.22541809, 21.79847145], [72.22486115, 21.79846764], [72.22486115, 21.79875183], [72.22458649, 21.79875183], [72.22458649, 21.7990303], [72.22402954, 21.7990303], [72.22402954, 21.79931259], [72.22374725, 21.79930496], [72.22374725, 21.79958344], [72.22319794, 21.79958344], [72.22319794, 21.79986191], [72.22293091, 21.79986191], [72.22293091, 21.80014038], [72.22264099, 21.80014038], [72.22264099, 21.80042267], [72.22208405, 21.80041695], [72.22207642, 21.8006916], [72.2215271, 21.80069542], [72.2215271, 21.80097008], [72.2206955, 21.80097008], [72.22070313, 21.80125046], [72.22041321, 21.80125046], [72.22041321, 21.80153275], [72.22013855, 21.80153275], [72.22013855, 21.80181122], [72.21875, 21.8018055], [72.21875, 21.80208206], [72.21847534, 21.80208206], [72.21848297, 21.80236053], [72.21819305, 21.80236053], [72.21819305, 21.80264282], [72.2179184, 21.80264282], [72.2179184, 21.80291939], [72.21763611, 21.80291748], [72.21763611, 21.80347252], [72.21708679, 21.80347061], [72.21708679, 21.80375099], [72.21652985, 21.80375099], [72.21652985, 21.80402946], [72.21624756, 21.80402946], [72.21624756, 21.80431938], [72.2159729, 21.80430412], [72.2159729, 21.8045826], [72.21569824, 21.80458069], [72.21569824, 21.80486107], [72.21541595, 21.80486107], [72.21541595, 21.80513954], [72.2151413, 21.80513954], [72.2151413, 21.80541992], [72.21485901, 21.8054142], [72.21485901, 21.80569649], [72.21457672, 21.80569077], [72.21457672, 21.80624962], [72.21430206, 21.80624962], [72.21430206, 21.80653], [72.2140274, 21.80653], [72.2140274, 21.80709076], [72.21375275, 21.80708313], [72.21375275, 21.8073616], [72.21347046, 21.8073597], [72.21347046, 21.80764008], [72.2131958, 21.80764008], [72.2131958, 21.80792046], [72.21290588, 21.80792046], [72.21290588, 21.80903053], [72.21263885, 21.80903053], [72.21263885, 21.80986023], [72.2123642, 21.80986023], [72.2123642, 21.81097221], [72.21208191, 21.8109684], [72.21208191, 21.81431007], [72.21180725, 21.81430626], [72.21180725, 21.8148613], [72.21152496, 21.8148613], [72.21152496, 21.81569481], [72.21125031, 21.8156929], [72.21125031, 21.81653023], [72.21097565, 21.81652832], [72.21097565, 21.81736183], [72.2106781, 21.81735992], [72.2106781, 21.8176403], [72.2104187, 21.8176403], [72.2104187, 21.81820107], [72.21013641, 21.81819344], [72.21013641, 21.81847191], [72.20986176, 21.81847], [72.20986176, 21.81903076], [72.2095871, 21.81903076], [72.2095871, 21.81932068], [72.20929718, 21.81932068], [72.20929718, 21.81986046], [72.20903015, 21.81986046], [72.20903015, 21.82069588], [72.20874786, 21.82069588], [72.20874786, 21.82097244], [72.20735931, 21.82097054], [72.20735931, 21.82125092], [72.20707703, 21.82125092], [72.20707703, 21.82152939], [72.20680237, 21.82152557], [72.20680237, 21.82208252], [72.20652771, 21.82207108], [72.20652771, 21.82236099], [72.20597076, 21.82236099], [72.20597076, 21.82263947], [72.20540619, 21.82263947], [72.20540619, 21.82291985], [72.2048645, 21.82291794], [72.2048645, 21.8231945], [72.20458221, 21.8231945], [72.20458221, 21.82347298], [72.20430756, 21.82347107], [72.20430756, 21.82374954], [72.2040329, 21.82374954], [72.2040329, 21.82402992], [72.20347595, 21.82402992], [72.20347595, 21.8243084], [72.20319366, 21.82430649], [72.20319366, 21.82486153], [72.20263672, 21.82486153], [72.20263672, 21.82513809], [72.20153046, 21.82513046], [72.20153046, 21.82542038], [72.20096588, 21.82542038], [72.20096588, 21.82570267], [72.20041656, 21.82569504], [72.20041656, 21.8259716], [72.20014191, 21.8259716], [72.20014191, 21.82625008], [72.19985962, 21.82625008], [72.19985962, 21.82653046], [72.1987381, 21.82653046], [72.1987381, 21.82681274], [72.19819641, 21.82680511], [72.19819641, 21.82708359], [72.19708252, 21.82708359], [72.19708252, 21.82736015], [72.1957016, 21.82736015], [72.1957016, 21.82764053], [72.19431305, 21.82764053], [72.19431305, 21.82792282], [72.1920929, 21.82792282], [72.1920929, 21.82819939], [72.18930817, 21.82819939], [72.18930817, 21.82792282], [72.18708038, 21.82792282], [72.18708038, 21.82764053], [72.18653107, 21.82764053], [72.18653107, 21.82736015], [72.18541718, 21.82736015], [72.18541718, 21.82680511], [72.18514252, 21.82681274], [72.18514252, 21.82653046], [72.1845932, 21.82653046], [72.1845932, 21.82625008], [72.18402863, 21.82625008], [72.18402863, 21.8259716], [72.18374634, 21.8259716], [72.18374634, 21.82569504], [72.18347168, 21.82570267], [72.18347168, 21.82513046], [72.18319702, 21.82513809], [72.18319702, 21.82486153], [72.18291473, 21.82486153], [72.18291473, 21.82374954], [72.1837616, 21.82374954], [72.1837616, 21.82402992], [72.18430328, 21.82402992], [72.18430328, 21.82458305], [72.18458557, 21.82458305], [72.18458557, 21.82513809], [72.18486023, 21.82513046], [72.18486023, 21.82570267], [72.18514252, 21.82569504], [72.18514252, 21.8259716], [72.18541718, 21.8259716], [72.18541718, 21.82625008], [72.18624878, 21.82625008], [72.18624878, 21.82653046], [72.18763733, 21.82653046], [72.18763733, 21.82681274], [72.18930817, 21.82680511], [72.18930817, 21.82708359], [72.19486237, 21.82708359], [72.19486237, 21.82680511], [72.19596863, 21.82681274], [72.19596863, 21.82653046], [72.19680786, 21.82653046], [72.19680786, 21.82625008], [72.19735718, 21.82625008], [72.19735718, 21.8259716], [72.19791412, 21.8259716], [72.19791412, 21.82569504], [72.19902802, 21.82570267], [72.19902802, 21.82542038], [72.19959259, 21.82542038], [72.19959259, 21.82513046], [72.20014191, 21.82513809], [72.20014191, 21.82486153], [72.20069122, 21.82486153], [72.20069122, 21.82458305], [72.20097351, 21.82458305], [72.20097351, 21.82430649], [72.20153046, 21.82430077], [72.20153046, 21.82402992], [72.20179749, 21.82402992], [72.20179749, 21.82374954], [72.20236206, 21.82374954], [72.20236206, 21.82347107], [72.20291901, 21.82347298], [72.20291901, 21.8231945], [72.20319366, 21.8231945], [72.20319366, 21.82291794], [72.2040329, 21.82291985], [72.2040329, 21.82263947], [72.20458221, 21.82263947], [72.20458221, 21.82236099], [72.20513916, 21.82236099], [72.20513916, 21.82207108], [72.20541382, 21.82208252], [72.20541382, 21.82180786], [72.20569611, 21.82180977], [72.20569611, 21.82152939], [72.20597076, 21.82152939], [72.20597076, 21.82125092], [72.20625305, 21.82125092], [72.20625305, 21.82097054], [72.20680237, 21.82097244], [72.20680237, 21.8204155], [72.20707703, 21.82042122], [72.20707703, 21.82014084], [72.20735931, 21.82014084], [72.20735931, 21.81986046], [72.2076416, 21.81986046], [72.2076416, 21.81958008], [72.20791626, 21.8195858], [72.20791626, 21.81930733], [72.20819092, 21.81932068], [72.20819092, 21.81820107], [72.20847321, 21.81820107], [72.20847321, 21.8176403], [72.20874786, 21.8176403], [72.20874786, 21.81707954], [72.20903015, 21.81708336], [72.20903015, 21.81652832], [72.20929718, 21.81653023], [72.20929718, 21.81458282], [72.2095871, 21.81458282], [72.2095871, 21.81263924], [72.20986176, 21.81263924], [72.20986176, 21.8109684], [72.21013641, 21.81097221], [72.21013641, 21.8101387], [72.2104187, 21.8101387], [72.2104187, 21.80958366], [72.21069336, 21.80958366], [72.21069336, 21.80791855], [72.21099091, 21.80792046], [72.21099091, 21.8073597], [72.21125031, 21.8073616], [72.21125031, 21.80652618], [72.21153259, 21.80653], [72.21153259, 21.80597115], [72.21208191, 21.80597305], [72.21208191, 21.80569649], [72.2123642, 21.80569649], [72.2123642, 21.80513954], [72.21263885, 21.80513954], [72.21263885, 21.80486107], [72.21290588, 21.80486107], [72.21290588, 21.80458069], [72.2131958, 21.8045826], [72.2131958, 21.80430412], [72.21347046, 21.80431938], [72.21347046, 21.80402946], [72.21373749, 21.80402946], [72.21373749, 21.80375099], [72.2140274, 21.80375099], [72.2140274, 21.80347061], [72.21430206, 21.80347252], [72.21430206, 21.80319214], [72.21458435, 21.80319214], [72.21458435, 21.80291748], [72.21485901, 21.80291939], [72.21485901, 21.80264282], [72.2151413, 21.80264282], [72.2151413, 21.80236053], [72.21541595, 21.80236053], [72.21541595, 21.80208015], [72.21624756, 21.80208206], [72.21624756, 21.8018055], [72.21652985, 21.80181122], [72.21652985, 21.80125046], [72.21708679, 21.80125046], [72.21708679, 21.80095863], [72.21736145, 21.80097008], [72.21736145, 21.80069351], [72.21819305, 21.80069351], [72.21819305, 21.80041695], [72.21875, 21.80042267], [72.21875, 21.80014038], [72.21930695, 21.80014038], [72.21930695, 21.79986191], [72.21986389, 21.79986191], [72.21986389, 21.79958344], [72.22013855, 21.79958344], [72.22013855, 21.79930496], [72.22041321, 21.79931259], [72.22041321, 21.7990303], [72.22070313, 21.7990303], [72.22070313, 21.79875183], [72.22097015, 21.79875183], [72.22097015, 21.79818916], [72.2215271, 21.79819489], [72.2215271, 21.79791641], [72.22180176, 21.79791832], [72.22180176, 21.79763985], [72.22207642, 21.79763985], [72.22207642, 21.79735756], [72.22291565, 21.79736137], [72.22291565, 21.7970829], [72.22319794, 21.7970829], [72.22319794, 21.79680634], [72.2234726, 21.79680824], [72.2234726, 21.79652977], [72.22402954, 21.79652977], [72.22402954, 21.79624939], [72.22458649, 21.79624939], [72.22458649, 21.79569054], [72.2251358, 21.79569435], [72.2251358, 21.79541779], [72.22541809, 21.79541969], [72.22541809, 21.79515076], [72.22596741, 21.79515076], [72.22596741, 21.79486084], [72.22624969, 21.79486084], [72.22624969, 21.79458046], [72.22680664, 21.79458237], [72.22680664, 21.79430771], [72.2270813, 21.79430962], [72.2270813, 21.79403114], [72.22763824, 21.79403114], [72.22763824, 21.79375076], [72.22820282, 21.79375076], [72.22819519, 21.79347229], [72.22902679, 21.79347229], [72.22902679, 21.79319382], [72.22958374, 21.79319382], [72.22958374, 21.79291534], [72.23042297, 21.79292107], [72.23042297, 21.79264069], [72.23097229, 21.79264069], [72.23097229, 21.79236031], [72.23319244, 21.79236031], [72.23319244, 21.79208946], [72.2334671, 21.79208946], [72.2334671, 21.79181099], [72.23542023, 21.79181099], [72.23542023, 21.79153061], [72.23568726, 21.79153061], [72.23568726, 21.79125023], [72.23625183, 21.79125023], [72.23625183, 21.79096985], [72.23652649, 21.79097176], [72.23652649, 21.79069328], [72.23707581, 21.79070091], [72.23707581, 21.79042053], [72.23764038, 21.79042053], [72.23764038, 21.79014015], [72.23819733, 21.79014015], [72.23819733, 21.78985977], [72.23847198, 21.78986168], [72.23847198, 21.78958321], [72.23874664, 21.78958321], [72.23874664, 21.78930473], [72.23930359, 21.78930473], [72.23930359, 21.78902817], [72.23958588, 21.78902817], [72.23958588, 21.78874969], [72.23986053, 21.78874969], [72.23986053, 21.78847122], [72.24013519, 21.78847122], [72.24013519, 21.78819466], [72.24041748, 21.78819466], [72.24041748, 21.78791618], [72.24067688, 21.78792191], [72.24067688, 21.78763962], [72.2409668, 21.78763962], [72.2409668, 21.78736115], [72.24124908, 21.78736115], [72.24124908, 21.78681183], [72.24153137, 21.78681183], [72.24153137, 21.7856884], [72.24180603, 21.78569412], [72.24180603, 21.78486061], [72.24208069, 21.78486061], [72.24208069, 21.78430939], [72.24236298, 21.78430939], [72.24236298, 21.78096962], [72.24263763, 21.78097153], [72.24263763, 21.77847481], [72.24291992, 21.77847481], [72.24291992, 21.77791405], [72.24263763, 21.77791977], [72.24263763, 21.77708054], [72.24291992, 21.77708244], [72.24291992, 21.77680588], [72.24263763, 21.77680969], [72.24263763, 21.77597046], [72.24291992, 21.77597237], [72.24291992, 21.77458382], [72.24319458, 21.77458382], [72.24319458, 21.77319527], [72.24346924, 21.7732029], [72.24346924, 21.77179909], [72.24375153, 21.77180481], [72.24375153, 21.77041626], [72.24430847, 21.77041817], [72.24430847, 21.77013969], [72.24402618, 21.77013969], [72.24402618, 21.76986122], [72.24430847, 21.76986122], [72.24430847, 21.76708031], [72.24458313, 21.76708412], [72.24458313, 21.76513863], [72.24430847, 21.76514053], [72.24430847, 21.76486015], [72.24402618, 21.76486206], [72.24402618, 21.76458359], [72.24375153, 21.76458359], [72.24375153, 21.76430321], [72.24346924, 21.76431084], [72.24346924, 21.76375008], [72.24430847, 21.76375008], [72.24430847, 21.7634697], [72.24485779, 21.7634716], [72.24485779, 21.76319313], [72.24514008, 21.76320076], [72.24514008, 21.76235962], [72.24541473, 21.76236153], [72.24541473, 21.76152802], [72.24569702, 21.76152992], [72.24569702, 21.76124954], [72.24597168, 21.76124954], [72.24597168, 21.76042175], [72.24569702, 21.76042175], [72.24569702, 21.75958061], [72.24597168, 21.75958252], [72.24597168, 21.75902748], [72.24624634, 21.75904274], [72.24624634, 21.75875092], [72.24652863, 21.75875092], [72.24652863, 21.75818825], [72.24624634, 21.75819397], [72.24624634, 21.75764084], [72.24652863, 21.75764084], [72.24652863, 21.75707817], [72.24680328, 21.75708389], [72.24680328, 21.75680542], [72.24710083, 21.75680923], [72.24710083, 21.75542068], [72.24736023, 21.75542068], [72.24736023, 21.75457954], [72.24764252, 21.75458336], [72.24764252, 21.75347137], [72.24736023, 21.75347137], [72.24736023, 21.7523613], [72.24708557, 21.7523613], [72.24708557, 21.75124931], [72.24736023, 21.75125122], [72.24736023, 21.75097084], [72.24791718, 21.75097275], [72.24791718, 21.7504158], [72.24819183, 21.75041962], [72.24819183, 21.75014114], [72.24846649, 21.75014114], [72.24846649, 21.74985123], [72.24874878, 21.74986076], [72.24874878, 21.74902725], [72.24903107, 21.74903107], [72.24903107, 21.74847031], [72.24930573, 21.74847221], [72.24930573, 21.74819374], [72.24958038, 21.74819374], [72.24958038, 21.7476387], [72.24984741, 21.74764061], [72.24984741, 21.74625015], [72.25013733, 21.74625015], [72.25013733, 21.74570274], [72.25041962, 21.74570274], [72.25041962, 21.74542236], [72.25068665, 21.74542236], [72.25068665, 21.74514008], [72.25096893, 21.74514008], [72.25096893, 21.74430084], [72.25125122, 21.74430466], [72.25125122, 21.74291611], [72.25152588, 21.74291992], [72.25152588, 21.74236107], [72.25180817, 21.74236107], [72.25180817, 21.74180984], [72.25208282, 21.74180984], [72.25208282, 21.74069023], [72.25235748, 21.74069595], [72.25235748, 21.7393074], [72.25263977, 21.73931122], [72.25263977, 21.73903084], [72.2529068, 21.73903084], [72.2529068, 21.73847008], [72.25319672, 21.73847198], [72.25319672, 21.73791695], [72.25347137, 21.73791695], [72.25347137, 21.73763847], [72.25374603, 21.73764038], [72.25374603, 21.73707962], [72.25402832, 21.73708344], [72.25402832, 21.7365284], [72.25430298, 21.7365303], [72.25430298, 21.73513985], [72.2545929, 21.73513985], [72.2545929, 21.73485184], [72.25485992, 21.73486137], [72.25485992, 21.73430634], [72.25514221, 21.73431015], [72.25514221, 21.73402977], [72.25541687, 21.73402977], [72.25541687, 21.73347282], [72.25569153, 21.73347282], [72.25569153, 21.73236084], [72.25598145, 21.73236084], [72.25597382, 21.7318058], [72.25624847, 21.73181152], [72.25624847, 21.73125076], [72.25653076, 21.73125076], [72.25653076, 21.72986031], [72.25681305, 21.72986031], [72.25680542, 21.72930527], [72.25708008, 21.72930908], [72.25708008, 21.72903061], [72.25736237, 21.72903061], [72.25736237, 21.72846985], [72.25763702, 21.72847176], [72.25763702, 21.72819519], [72.25791931, 21.72820091], [72.25791931, 21.72764015], [72.25818634, 21.72764015], [72.25818634, 21.72707939], [72.25846863, 21.72708321], [72.25846863, 21.72652626], [72.25875092, 21.72653008], [72.25875092, 21.7256794], [72.25902557, 21.72569656], [72.25902557, 21.72513962], [72.25930786, 21.72513962], [72.25930786, 21.72430992], [72.25958252, 21.72430992], [72.25958252, 21.72347069], [72.25986481, 21.7234726], [72.25986481, 21.72319221], [72.26013947, 21.72319221], [72.26013947, 21.72263908], [72.26040649, 21.7226429], [72.26040649, 21.72236061], [72.26069641, 21.72236061], [72.26069641, 21.72180939], [72.26097107, 21.72180939], [72.26097107, 21.72153282], [72.26125336, 21.72153282], [72.26125336, 21.72097015], [72.26152802, 21.72097015], [72.26152802, 21.72041702], [72.26178741, 21.72042274], [72.26178741, 21.72014046], [72.26207733, 21.72014046], [72.26207733, 21.7195816], [72.26235962, 21.71958351], [72.26235962, 21.71930504], [72.26264191, 21.71931267], [72.26264191, 21.71875191], [72.26291656, 21.71875191], [72.26291656, 21.71820259], [72.26319122, 21.71820259], [72.26319122, 21.7179184], [72.26346588, 21.7179184], [72.26346588, 21.71763992], [72.26374817, 21.71763992], [72.26374817, 21.71707916], [72.26403046, 21.71708298], [72.26403046, 21.71680641], [72.26431274, 21.71680832], [72.26431274, 21.71624947], [72.26457977, 21.71624947], [72.26457977, 21.71569061], [72.26486206, 21.71569443], [72.26486206, 21.71541786], [72.26541901, 21.71541977], [72.26541901, 21.71458054], [72.26597595, 21.71458244], [72.26597595, 21.71347237], [72.26625061, 21.71347237], [72.26625061, 21.71291542], [72.2665329, 21.71292114], [72.2665329, 21.71264076], [72.26680756, 21.71264076], [72.26680756, 21.71236038], [72.26708221, 21.71236038], [72.26708221, 21.71181107], [72.26735687, 21.71181107], [72.26735687, 21.71153069], [72.26763916, 21.71153069], [72.26763916, 21.71096992], [72.26791382, 21.71097183], [72.26791382, 21.71041679], [72.26819611, 21.71042061], [72.26819611, 21.70957947], [72.26847076, 21.70958328], [72.26847076, 21.70902824], [72.26875305, 21.70903015], [72.26875305, 21.70874977], [72.26902771, 21.70874977], [72.26902771, 21.70819283], [72.26930237, 21.70819473], [72.26930237, 21.70708275], [72.26902771, 21.70708275], [72.26902771, 21.70680618], [72.26819611, 21.7068119], [72.26819611, 21.70624924], [72.26902771, 21.70624924], [72.26902771, 21.70597076], [72.26930237, 21.70597267], [72.26930237, 21.7056942], [72.26958466, 21.7056942], [72.26958466, 21.70541573], [72.26985931, 21.70541954], [72.26985931, 21.70513916], [72.2701416, 21.70513916], [72.2701416, 21.7045784], [72.27041626, 21.70458412], [72.27041626, 21.70430565], [72.27069092, 21.70430946], [72.27069092, 21.70402908], [72.27098083, 21.70402908], [72.27098083, 21.70346832], [72.27124786, 21.70347214], [72.27124786, 21.70208359], [72.27153015, 21.70208359], [72.27153015, 21.70152855], [72.27179718, 21.70153046], [72.27179718, 21.7009697], [72.2720871, 21.7009716], [72.2720871, 21.70069695], [72.27263641, 21.70070076], [72.27263641, 21.70042038], [72.2729187, 21.70042038], [72.2729187, 21.70014], [72.27319336, 21.70014], [72.27319336, 21.69985962], [72.27347565, 21.69986153], [72.27347565, 21.69930458], [72.27375031, 21.69930077], [72.27375031, 21.69874954], [72.27402496, 21.69874954], [72.27402496, 21.69847488], [72.27430725, 21.69847488], [72.27430725, 21.69791412], [72.27485657, 21.69791985], [72.27485657, 21.69736099], [72.27513885, 21.69736099], [72.27513885, 21.69708061], [72.27541351, 21.69708252], [72.27541351, 21.69652748], [72.2756958, 21.69652939], [72.2756958, 21.69597054], [72.27625275, 21.69597244], [72.27625275, 21.69569206], [72.2765274, 21.69569969], [72.2765274, 21.69514275], [72.2767868, 21.69514275], [72.2767868, 21.69486046], [72.27707672, 21.69486046], [72.27707672, 21.69458008], [72.27735901, 21.69458389], [72.27735901, 21.69430542], [72.2776413, 21.69431114], [72.2776413, 21.69347191], [72.27791595, 21.69347191], [72.27791595, 21.6926384], [72.27819061, 21.6926403], [72.27819824, 21.69236946], [72.2784729, 21.69236183], [72.2784729, 21.69208336], [72.27874756, 21.69208336], [72.27874756, 21.69152832], [72.27902985, 21.69153023], [72.27902985, 21.69124985], [72.27929688, 21.69124985], [72.27929688, 21.69096756], [72.27958679, 21.69097137], [72.27958679, 21.69013977], [72.27986145, 21.69013977], [72.27986145, 21.68985748], [72.28013611, 21.6898613], [72.28013611, 21.68763924], [72.2804184, 21.68764114], [72.2804184, 21.68708038], [72.28097534, 21.6870842], [72.28097534, 21.68680763], [72.28125, 21.68680763], [72.28125, 21.68625069], [72.28151703, 21.68625069], [72.28151703, 21.68568993], [72.28180695, 21.68569374], [72.28180695, 21.68541527], [72.2820816, 21.68542099], [72.2820816, 21.68486023], [72.28235626, 21.68486023], [72.28235626, 21.68403053], [72.28292084, 21.68403053], [72.28292084, 21.68292046], [72.28321075, 21.68292046], [72.28321075, 21.68264008], [72.28347015, 21.68264008], [72.28347015, 21.68097115], [72.28375244, 21.68097115], [72.28375244, 21.67986107], [72.2840271, 21.67986107], [72.2840271, 21.67931175], [72.28430176, 21.67931175], [72.28430176, 21.67902946], [72.2848587, 21.67902946], [72.2848587, 21.67874908], [72.28514099, 21.67874908], [72.28514099, 21.67653084], [72.28542328, 21.67653084], [72.28542328, 21.67514038], [72.2848587, 21.67514038], [72.2848587, 21.67431068], [72.28514099, 21.67431068], [72.28514099, 21.67319107], [72.2848587, 21.67319679], [72.2848587, 21.66708374], [72.28514099, 21.66708374], [72.28514099, 21.66625023], [72.28542328, 21.66625023], [72.28541565, 21.66486168], [72.28569794, 21.66486168], [72.28569794, 21.66458321], [72.28624725, 21.66458321], [72.28624725, 21.66374969], [72.28679657, 21.66374969], [72.28679657, 21.66319084], [72.28708649, 21.66319466], [72.28708649, 21.66263962], [72.28736115, 21.66263962], [72.28736115, 21.66236115], [72.2876358, 21.66236115], [72.2876358, 21.66208076], [72.28791809, 21.66208267], [72.28791809, 21.66152763], [72.28819275, 21.66152954], [72.28819275, 21.66125107], [72.28848267, 21.66125107], [72.28848267, 21.66097069], [72.28874969, 21.6609726], [72.28874969, 21.66069412], [72.28902435, 21.66069412], [72.28902435, 21.66041756], [72.28930664, 21.66041946], [72.28930664, 21.66014099], [72.28952026, 21.66014099], [72.28956604, 21.65986061], [72.28985596, 21.65986061], [72.28985596, 21.65958977], [72.29013824, 21.65958977], [72.29013824, 21.65903091], [72.2904129, 21.65903091], [72.2904129, 21.65875053], [72.29070282, 21.65875053], [72.29069519, 21.65819359], [72.29096985, 21.65819359], [72.29096985, 21.65763855], [72.29125214, 21.65761185], [72.29125214, 21.65708542], [72.29152679, 21.65708542], [72.29152679, 21.65680313], [72.29180908, 21.6568203], [72.29180908, 21.65653038], [72.29209137, 21.65653038], [72.29209137, 21.65625], [72.2923584, 21.65625], [72.2923584, 21.65596962], [72.29264069, 21.65597153], [72.29264069, 21.65569305], [72.29292297, 21.65570068], [72.29292297, 21.6554203], [72.29347229, 21.6554203], [72.29347229, 21.65513992], [72.29402924, 21.65513992], [72.29402924, 21.65485954], [72.29458618, 21.65486145], [72.29458618, 21.65458107], [72.29486084, 21.65458107], [72.29486084, 21.65430641], [72.29541779, 21.65431023], [72.29541779, 21.65374947], [72.29569244, 21.65374947], [72.29569244, 21.6534729], [72.29597473, 21.6534729], [72.29597473, 21.65319443], [72.29624939, 21.65319443], [72.29624939, 21.65291595], [72.29651642, 21.65292168], [72.29651642, 21.65236092], [72.29680634, 21.65236092], [72.29680634, 21.65208054], [72.29708099, 21.65208244], [72.29708099, 21.65180588], [72.29736328, 21.6518116], [72.29736328, 21.65125084], [72.29792023, 21.65125084], [72.29792023, 21.65068817], [72.29819489, 21.65069389], [72.29819489, 21.65014076], [72.29846954, 21.65014076], [72.29846954, 21.64986038], [72.29875183, 21.64986038], [72.29875183, 21.64957809], [72.29902649, 21.64958382], [72.29902649, 21.64902878], [72.29930878, 21.64903069], [72.29930878, 21.64792061], [72.29957581, 21.64792061], [72.29957581, 21.64764977], [72.30014038, 21.64764977], [72.30014038, 21.64735985], [72.30041504, 21.64736176], [72.30041504, 21.64652824], [72.30069733, 21.64653015], [72.30069733, 21.64596939], [72.30097198, 21.6459713], [72.30097198, 21.64569664], [72.30124664, 21.64569664], [72.30124664, 21.64541435], [72.30152893, 21.64542007], [72.30152893, 21.64513969], [72.30179596, 21.64513969], [72.30179596, 21.64486122], [72.30208588, 21.64486122], [72.30208588, 21.64431], [72.30236053, 21.64431], [72.30236053, 21.64402962], [72.30264282, 21.64402962], [72.30264282, 21.64319038], [72.30291748, 21.64319229], [72.30291748, 21.64097023], [72.30319214, 21.64097023], [72.30319214, 21.63958359], [72.30347443, 21.63958359], [72.30347443, 21.63652992], [72.30374908, 21.63652992], [72.30374908, 21.63624954], [72.30403137, 21.63624954], [72.30403137, 21.63597107], [72.30486298, 21.63597298], [72.30486298, 21.63513947], [72.30513763, 21.63513947], [72.30513763, 21.63458061], [72.30541992, 21.63458252], [72.30541992, 21.63375092], [72.30568695, 21.63375092], [72.30568695, 21.63181114], [72.30596924, 21.63181114], [72.30596924, 21.62846947], [72.30569458, 21.62847137], [72.30569458, 21.6273613], [72.30541992, 21.6273613], [72.30541992, 21.62680626], [72.30513763, 21.62681007], [72.30513763, 21.62625122], [72.30486298, 21.62625122], [72.30486298, 21.62568855], [72.30458069, 21.62569427], [72.30458069, 21.62513924], [72.30430603, 21.62513924], [72.30430603, 21.62431145], [72.30403137, 21.62431145], [72.30403137, 21.62402916], [72.30374908, 21.62402916], [72.30374908, 21.62291908], [72.3034668, 21.62291908], [72.3034668, 21.62207985], [72.30319214, 21.62208366], [72.30319214, 21.62152863], [72.30291748, 21.62153053], [72.30291748, 21.62096977], [72.30263519, 21.62097168], [72.30263519, 21.62041855], [72.30236053, 21.62042046], [72.30236053, 21.6198597], [72.30208588, 21.6198616], [72.30208588, 21.61930656], [72.30152893, 21.61930656], [72.30152893, 21.61902618], [72.30124664, 21.61903], [72.30124664, 21.61847115], [72.30097198, 21.61847305], [72.30097198, 21.61763954], [72.30069733, 21.61765099], [72.30069733, 21.61736107], [72.30041504, 21.61736107], [72.30041504, 21.6170826], [72.30014038, 21.6170826], [72.30014038, 21.61680412], [72.29985809, 21.61680984], [72.29985809, 21.61652946], [72.29957581, 21.61652946], [72.29957581, 21.61597061], [72.29930878, 21.61597252], [72.29930878, 21.61569214], [72.29902649, 21.61569214], [72.29902649, 21.61541748], [72.29846954, 21.61541939], [72.29846954, 21.61514282], [72.29818726, 21.61514282], [72.29818726, 21.61486053], [72.29792023, 21.61486053], [72.29792023, 21.61458015], [72.29763794, 21.61458206], [72.29763794, 21.61402702], [72.29736328, 21.61403275], [72.29736328, 21.61375046], [72.29708099, 21.61375046], [72.29708099, 21.61347008], [72.29680634, 21.61347008], [72.29680634, 21.61319542], [72.29651642, 21.6131916], [72.29652405, 21.61291695], [72.29624939, 21.61292267], [72.29624939, 21.61264038], [72.29569244, 21.61264038], [72.29569244, 21.61236191], [72.29541779, 21.61236191], [72.29541779, 21.61208344], [72.2951355, 21.61208344], [72.2951355, 21.6115284], [72.29486084, 21.6115284], [72.29486084, 21.61124992], [72.29458618, 21.61124992], [72.29458618, 21.61096764], [72.29430389, 21.61097145], [72.29430389, 21.61069489], [72.29402924, 21.61069489], [72.29402924, 21.61041641], [72.29374695, 21.61041832], [72.29374695, 21.61013985], [72.29347229, 21.61013985], [72.29347229, 21.60957909], [72.29319763, 21.6095829], [72.29319763, 21.60930634], [72.29292297, 21.60930824], [72.29292297, 21.60874939], [72.29264069, 21.60874939], [72.29264069, 21.60848045], [72.2923584, 21.60848045], [72.2923584, 21.60819054], [72.29208374, 21.60819435], [72.29208374, 21.60791779], [72.29180908, 21.60791969], [72.29180908, 21.60764122], [72.29152679, 21.60764122], [72.29152679, 21.60736084], [72.29125214, 21.60736084], [72.29125214, 21.60708046], [72.29096985, 21.60708427], [72.29096985, 21.60652542], [72.29070282, 21.60653114], [72.29070282, 21.60569], [72.2904129, 21.60569572], [72.2904129, 21.60513878], [72.29013824, 21.60514069], [72.29013824, 21.60486031], [72.28985596, 21.60486031], [72.28985596, 21.60431099], [72.2895813, 21.60431099], [72.2895813, 21.60403061], [72.28930664, 21.60403061], [72.28930664, 21.60375023], [72.28874969, 21.60375023], [72.28874969, 21.60320091], [72.28848267, 21.60320091], [72.28848267, 21.60264015], [72.28819275, 21.60264015], [72.28819275, 21.60235023], [72.28791809, 21.60236168], [72.28791809, 21.6020813], [72.2876358, 21.6020813], [72.2876358, 21.60152817], [72.28708649, 21.60153008], [72.28708649, 21.60124969], [72.28679657, 21.60124969], [72.28679657, 21.60069275], [72.28652954, 21.60069466], [72.28652954, 21.60041618], [72.28624725, 21.60042191], [72.28624725, 21.60013962], [72.28595734, 21.60013962], [72.28595734, 21.59986115], [72.28569794, 21.59986115], [72.28569794, 21.59931183], [72.28542328, 21.59931183], [72.28542328, 21.59874916], [72.28514099, 21.59874916], [72.28514099, 21.5981884], [72.2848587, 21.59819412], [72.2848587, 21.59791756], [72.28457642, 21.59791946], [72.28457642, 21.59763908], [72.28430176, 21.59763908], [72.28430176, 21.59707832], [72.2840271, 21.59708405], [72.2840271, 21.5965271], [72.28375244, 21.59654236], [72.28375244, 21.59596825], [72.28347015, 21.59597206], [72.28347015, 21.59513855], [72.28321075, 21.59514046], [72.28321075, 21.59486008], [72.28291321, 21.59486198], [72.28291321, 21.59458351], [72.28263855, 21.59458351], [72.28263855, 21.59402847], [72.28235626, 21.59403038], [72.28235626, 21.59348106], [72.2820816, 21.59348106], [72.2820816, 21.59320068], [72.28180695, 21.59320068], [72.28180695, 21.5929203], [72.28151703, 21.5929203], [72.28151703, 21.59235954], [72.28125, 21.59236145], [72.28125, 21.5918045], [72.28098297, 21.59181023], [72.28098297, 21.59152985], [72.28069305, 21.59152985], [72.28069305, 21.59097099], [72.2804184, 21.59097481], [72.2804184, 21.59041405], [72.27986145, 21.59041405], [72.27986145, 21.59013939], [72.27958679, 21.59013939], [72.27958679, 21.58958054], [72.2793045, 21.58958244], [72.2793045, 21.58875084], [72.27902985, 21.58875084], [72.27902985, 21.58847046], [72.27874756, 21.58847237], [72.27874756, 21.58819389], [72.2784729, 21.58819389], [72.2784729, 21.58791733], [72.27819824, 21.58792114], [72.27819061, 21.58735085], [72.27791595, 21.58736038], [72.27791595, 21.58680534], [72.2776413, 21.58681107], [72.2776413, 21.58653259], [72.27735901, 21.58653259], [72.27735901, 21.58625031], [72.27707672, 21.58625031], [72.27707672, 21.58597183], [72.27680206, 21.58597183], [72.27680206, 21.58541679], [72.2765274, 21.58542252], [72.2765274, 21.58514023], [72.27625275, 21.58514023], [72.27625275, 21.58486176], [72.27597046, 21.58486176], [72.27597046, 21.58458328], [72.2756958, 21.58458328], [72.2756958, 21.58430481], [72.27540588, 21.58430862], [72.27540588, 21.58374977], [72.27513885, 21.58374977], [72.27513885, 21.58319092], [72.27458191, 21.58319473], [72.27458191, 21.58291626], [72.27430725, 21.58291817], [72.27430725, 21.58263969], [72.27401733, 21.58263969], [72.27401733, 21.58208084], [72.27375031, 21.58208275], [72.27375031, 21.58180618], [72.27348328, 21.58180809], [72.27348328, 21.58125114], [72.27319336, 21.58125114], [72.27319336, 21.58097076], [72.2729187, 21.58097267], [72.2729187, 21.5806942], [72.27263641, 21.5806942], [72.27263641, 21.58013916], [72.27236176, 21.58014107], [72.27236176, 21.57958031], [72.2720871, 21.57958412], [72.2720871, 21.57875061], [72.27179718, 21.57875061], [72.27179718, 21.57818031], [72.27153015, 21.57819557], [72.27153015, 21.57791519], [72.27124786, 21.57792091], [72.27124786, 21.57736015], [72.27097321, 21.57736206], [72.27097321, 21.57680321], [72.27069092, 21.57681084], [72.27069092, 21.57625008], [72.27041626, 21.57625008], [72.27041626, 21.57570076], [72.2701416, 21.57570076], [72.2701416, 21.57514], [72.26985931, 21.57514], [72.26985931, 21.57458115], [72.26958466, 21.57458115], [72.26958466, 21.57402802], [72.26930237, 21.57403183], [72.26930237, 21.57374954], [72.26902771, 21.57374954], [72.26902771, 21.57292175], [72.26875305, 21.57292175], [72.26875305, 21.57208061], [72.26847076, 21.57208252], [72.26847076, 21.56986046], [72.26819611, 21.56986046], [72.26819611, 21.56875038], [72.26791382, 21.56875038], [72.26791382, 21.56597137], [72.26763916, 21.56597137], [72.26763916, 21.56458473], [72.2673645, 21.56458473], [72.2673645, 21.56319237], [72.26708221, 21.56319237], [72.26708221, 21.56236076], [72.26680756, 21.56236076], [72.26680756, 21.56208038], [72.26652527, 21.56208229], [72.26652527, 21.56152725], [72.26625061, 21.56153107], [72.26625061, 21.56069183], [72.26597595, 21.56069374], [72.26597595, 21.55930519], [72.26568604, 21.55931282], [72.26568604, 21.55903244], [72.26541901, 21.55903244], [72.26541901, 21.55847168], [72.26513672, 21.55847168], [72.26513672, 21.55819511], [72.2648468, 21.55820274], [72.2648468, 21.55763817], [72.26457977, 21.55763817], [72.26457977, 21.55708122], [72.26430511, 21.55708313], [72.26430511, 21.55652809], [72.26403046, 21.55652809], [72.26403046, 21.55430031], [72.26430511, 21.55430794], [72.26430511, 21.54791641], [72.26457977, 21.54792023], [72.26457977, 21.54735947], [72.26486206, 21.54736137], [72.26486206, 21.54680634], [72.26513672, 21.54681015], [72.26513672, 21.54153061], [72.2648468, 21.54153061], [72.2648468, 21.54014015], [72.26457977, 21.54014015], [72.26457977, 21.53957939], [72.26430511, 21.53958321], [72.26430511, 21.53847313], [72.26403046, 21.53847313], [72.26403046, 21.53736115], [72.26374817, 21.53736115], [72.26374817, 21.53652954], [72.26346588, 21.53652954], [72.26346588, 21.53569031], [72.26319122, 21.53569221], [72.26319122, 21.53541756], [72.26291656, 21.53541946], [72.26291656, 21.53292274], [72.26264191, 21.53292274], [72.26264191, 21.53181267], [72.26235962, 21.53181267], [72.26235962, 21.53070068], [72.26207733, 21.53070068], [72.26207733, 21.53013992], [72.26178741, 21.53013992], [72.26178741, 21.52958107], [72.26152802, 21.52958298], [72.26152802, 21.52930641], [72.26125336, 21.52930832], [72.26125336, 21.52874947], [72.26097107, 21.52874947], [72.26097107, 21.52847099], [72.26069641, 21.5284729], [72.26069641, 21.52819443], [72.26041412, 21.52819443], [72.26041412, 21.52708244], [72.26013947, 21.52708244], [72.26013947, 21.5265255], [72.25985718, 21.52653122], [72.25985718, 21.52542114], [72.25958252, 21.52542114], [72.25958252, 21.52458], [72.25930786, 21.52458572], [72.25930786, 21.52375031], [72.25902557, 21.52375031], [72.25902557, 21.52291679], [72.25875092, 21.52292061], [72.25875092, 21.52126122], [72.25846863, 21.52126122], [72.25846863, 21.52069283], [72.25819397, 21.52069473], [72.25819397, 21.51930618], [72.25846863, 21.5193119], [72.25846863, 21.51791954], [72.25818634, 21.51791954], [72.25818634, 21.51736069], [72.25791931, 21.51736069], [72.25791931, 21.5170784], [72.25763702, 21.51708412], [72.25763702, 21.51680565], [72.25736237, 21.51681137], [72.25736237, 21.51652908], [72.25708008, 21.51652908], [72.25708008, 21.51431084], [72.25681305, 21.51431084], [72.25681305, 21.51403046], [72.25653076, 21.51403046], [72.25653076, 21.51375008], [72.25624847, 21.51375008], [72.25624847, 21.51320076], [72.25598145, 21.51320076], [72.25598145, 21.51292038], [72.25569153, 21.51292038], [72.25569153, 21.5118103], [72.25541687, 21.5118103], [72.25541687, 21.51013947], [72.25514221, 21.51013947], [72.25514221, 21.50932121], [72.25485992, 21.50932121], [72.25485992, 21.50792122], [72.2545929, 21.50792122], [72.2545929, 21.50570107], [72.25430298, 21.50570107], [72.25430298, 21.50291824], [72.25402832, 21.50291824], [72.25402832, 21.50180817], [72.25374603, 21.50180817], [72.25375366, 21.50140953], [72.25375366, 21.50124931], [72.25347137, 21.50125122], [72.25347137, 21.50041962], [72.25319672, 21.50041962], [72.25319672, 21.49986076], [72.2529068, 21.49986076], [72.2529068, 21.49958038], [72.25263977, 21.4995842], [72.25263977, 21.49902534], [72.25235748, 21.49903107], [72.25235748, 21.49818993], [72.25208282, 21.49819565], [72.25208282, 21.49736023], [72.25180817, 21.49736023], [72.25180817, 21.49708939], [72.25152588, 21.49708939], [72.25152588, 21.49570084], [72.25125122, 21.49570084], [72.25125122, 21.4948597], [72.25152588, 21.4948616], [72.25152588, 21.49458122], [72.25125122, 21.49458122], [72.25125122, 21.49402809], [72.25096893, 21.49403191], [72.25096893, 21.49374962], [72.25068665, 21.49374962], [72.25068665, 21.49319267], [72.25041962, 21.49319458], [72.25041962, 21.49235916], [72.25013733, 21.49235916], [72.25013733, 21.49181175], [72.24984741, 21.49181175], [72.24984741, 21.49096107], [72.24958038, 21.49097252], [72.24958038, 21.49069405], [72.24930573, 21.49069405], [72.24930573, 21.49041748], [72.24903107, 21.49041939], [72.24903107, 21.48986053], [72.24874878, 21.48986053], [72.24874878, 21.48957825], [72.24847412, 21.48958397], [72.24847412, 21.48875046], [72.24819183, 21.48875046], [72.24819183, 21.48764038], [72.24791718, 21.48764038], [72.24791718, 21.48707962], [72.24764252, 21.48708344], [72.24764252, 21.4865284], [72.24736023, 21.4865303], [72.24736023, 21.48624992], [72.24708557, 21.48624992], [72.24708557, 21.48569679], [72.24680328, 21.48569679], [72.24680328, 21.48347473], [72.24652863, 21.48347473], [72.24652863, 21.48319244], [72.24624634, 21.48319244], [72.24624634, 21.48263931], [72.24597168, 21.48264122], [72.24597168, 21.48236084], [72.24569702, 21.48236084], [72.24569702, 21.48209], [72.2454071, 21.48209], [72.2454071, 21.48125076], [72.24514008, 21.48125076], [72.24514008, 21.48069191], [72.24485779, 21.48069382], [72.24485779, 21.47958374], [72.24458313, 21.47958374], [72.24458313, 21.4790287], [72.24430847, 21.4790287], [72.24430847, 21.47847176], [72.24402618, 21.47847176], [72.24402618, 21.47791672], [72.24375153, 21.47792244], [72.24375153, 21.47735977], [72.24346924, 21.47736168], [72.24346924, 21.47708321], [72.24319458, 21.47708321], [72.24319458, 21.47680473], [72.24291992, 21.47680473], [72.24291992, 21.47597313], [72.24263763, 21.47597313], [72.24263763, 21.47374916], [72.24236298, 21.47375107], [72.24236298, 21.47319031], [72.24208069, 21.47319412], [72.24208069, 21.47263908], [72.24180603, 21.47264099], [72.24180603, 21.47208023], [72.24153137, 21.47208595], [72.24153137, 21.47152519], [72.24124908, 21.47153091], [72.24124908, 21.47125053], [72.2409668, 21.47125053], [72.2409668, 21.47068977], [72.24069214, 21.4706955], [72.24069214, 21.47041512], [72.24041748, 21.47042084], [72.24041748, 21.47014999], [72.24014282, 21.47014999], [72.24014282, 21.46986008], [72.23986053, 21.46986389], [72.23986053, 21.46958542], [72.23958588, 21.46958542], [72.23958588, 21.46902847], [72.23929596, 21.46903038], [72.23929596, 21.46875], [72.23902893, 21.46875], [72.23902893, 21.46846962], [72.23847198, 21.46847153], [72.23847198, 21.46791649], [72.23819733, 21.4679203], [72.23819733, 21.46763992], [72.23790741, 21.46763992], [72.23790741, 21.46708107], [72.23764038, 21.46708107], [72.23764038, 21.46680641], [72.23707581, 21.46681023], [72.23707581, 21.46653175], [72.23680878, 21.46653175], [72.23680878, 21.46542168], [72.23652649, 21.46542168], [72.23652649, 21.46458054], [72.23625183, 21.46458244], [72.23625183, 21.46430588], [72.23568726, 21.4643116], [72.23568726, 21.46347046], [72.23542023, 21.46347237], [72.23542023, 21.46236038], [72.23513794, 21.46236038], [72.23513794, 21.46153069], [72.23487091, 21.46153069], [72.23487091, 21.46014023], [72.23513794, 21.46014023], [72.23513794, 21.45930099], [72.23542023, 21.45930672], [72.23542023, 21.45708466], [72.23513794, 21.45708466], [72.23513794, 21.45652771], [72.23487091, 21.45652962], [72.23487091, 21.45625114], [72.23458099, 21.45625114], [72.23458099, 21.45597076], [72.23430634, 21.45597458], [72.23430634, 21.45569229], [72.23402405, 21.45569229], [72.23402405, 21.45513916], [72.23374939, 21.45514107], [72.23374939, 21.45458031], [72.23347473, 21.45458221], [72.23347473, 21.45430565], [72.23319244, 21.45430946], [72.23319244, 21.45375061], [72.2326355, 21.45375061], [72.2326355, 21.45319366], [72.23208618, 21.45319366], [72.23208618, 21.45263863], [72.23124695, 21.45264053], [72.23124695, 21.45236015], [72.23097229, 21.45236015], [72.23097229, 21.45208359], [72.23069763, 21.45208359], [72.23069763, 21.45180511], [72.23042297, 21.45181274], [72.23042297, 21.45153236], [72.23014069, 21.45153236], [72.23014069, 21.45125008], [72.2298584, 21.45125008], [72.2298584, 21.4509697], [72.22958374, 21.4509716], [72.22958374, 21.45069504], [72.22930908, 21.45070076], [72.22930908, 21.45013809], [72.22902679, 21.45013809], [72.22902679, 21.44958115], [72.22875214, 21.44958305], [72.22875214, 21.44930649], [72.22846985, 21.4493084], [72.22846985, 21.44903946], [72.22820282, 21.44903946], [72.22820282, 21.44874954], [72.2279129, 21.44874954], [72.2279129, 21.44847107], [72.22763824, 21.44847298], [72.22763824, 21.4481945], [72.22736359, 21.4481945], [72.22736359, 21.44763947], [72.2270813, 21.44763947], [72.2270813, 21.44736099], [72.22680664, 21.44736099], [72.22680664, 21.44708061], [72.22652435, 21.44708252], [72.22652435, 21.44680786], [72.22624969, 21.44680977], [72.22624969, 21.44652939], [72.22596741, 21.44652939], [72.22596741, 21.44598007], [72.22567749, 21.44598007], [72.22567749, 21.44569016], [72.22541809, 21.44569588], [72.22541809, 21.44513893], [72.2251358, 21.44514084], [72.2251358, 21.44458008], [72.22486115, 21.4445858], [72.22486115, 21.44430351], [72.22458649, 21.44431114], [72.22458649, 21.44403076], [72.22429657, 21.44403076], [72.22429657, 21.44375038], [72.22402954, 21.44375038], [72.22402954, 21.44180107], [72.2243042, 21.44180489], [72.2243042, 21.44041634], [72.22402954, 21.44042015], [72.22402954, 21.44013977], [72.22374725, 21.44013977], [72.22374725, 21.43958282], [72.2234726, 21.43958282], [72.2234726, 21.43930626], [72.22319794, 21.43931007], [72.22319794, 21.43874931], [72.22264099, 21.43874931], [72.22264099, 21.43847084], [72.2223587, 21.43847275], [72.2223587, 21.43819427], [72.22180176, 21.43819427], [72.22180176, 21.4379158], [72.2215271, 21.43792152], [72.2215271, 21.43736076], [72.22125244, 21.43736076], [72.22125244, 21.43681145], [72.22097015, 21.43681145], [72.22097015, 21.43652916], [72.22041321, 21.43652916], [72.22041321, 21.43625069], [72.22013855, 21.43625069], [72.22013855, 21.43597031], [72.21986389, 21.43597221], [72.21986389, 21.43569374], [72.21930695, 21.43569374], [72.21930695, 21.43486023], [72.21901703, 21.43486023], [72.21901703, 21.43457985], [72.21875, 21.43458366], [72.21875, 21.43430519], [72.21848297, 21.43431091], [72.21848297, 21.43403816], [72.21819305, 21.43403816], [72.21819305, 21.43375015], [72.21763611, 21.43375015], [72.21763611, 21.43346977], [72.21736145, 21.43347168], [72.21736145, 21.43291664], [72.21708679, 21.43292046], [72.21708679, 21.43264008], [72.21679688, 21.43264008], [72.21679688, 21.4323597], [72.21624756, 21.4323616], [72.21624756, 21.43208313], [72.2159729, 21.43208313], [72.2159729, 21.43097305], [72.21569824, 21.43097305], [72.21569061, 21.4304142], [72.21541595, 21.43041992], [72.21541595, 21.42986107], [72.21485901, 21.42986107], [72.21485901, 21.42958069], [72.21430206, 21.4295826], [72.21430206, 21.42930412], [72.2140274, 21.42930984], [72.2140274, 21.42791176], [72.21430206, 21.42791748], [72.21430206, 21.42763901], [72.2140274, 21.42764282], [72.2140274, 21.42708015], [72.21347046, 21.42708206], [72.21347046, 21.4268055], [72.21290588, 21.42681122], [72.21290588, 21.42653275], [72.21263885, 21.42653275], [72.21263885, 21.42625046], [72.21235657, 21.42625046], [72.21235657, 21.42597008], [72.21152496, 21.42597008], [72.21152496, 21.42569542], [72.21125031, 21.4256916], [72.21125031, 21.42513847], [72.2104187, 21.42514038], [72.2104187, 21.42374992], [72.21013641, 21.42374992], [72.21013641, 21.42318916], [72.20986176, 21.42319489], [72.20986176, 21.42291641], [72.2095871, 21.42291832], [72.2095871, 21.42263985], [72.20903015, 21.42263985], [72.20903015, 21.42235947], [72.20874786, 21.42236137], [72.20874786, 21.4220829], [72.20819092, 21.4220829], [72.20819092, 21.42180634], [72.2076416, 21.42180824], [72.2076416, 21.42152977], [72.20707703, 21.42152977], [72.20707703, 21.42124939], [72.20680237, 21.42124939], [72.20680237, 21.42097092], [72.20652771, 21.42097282], [72.20652771, 21.42041779], [72.20540619, 21.42041969], [72.20540619, 21.41986084], [72.20485687, 21.41986084], [72.20485687, 21.41930962], [72.20458221, 21.41930962], [72.20458221, 21.41875076], [72.20430756, 21.41875076], [72.20430756, 21.41847038], [72.20375061, 21.41847229], [72.20375061, 21.41819572], [72.20347595, 21.41819572], [72.20347595, 21.41791725], [72.20263672, 21.41792107], [72.20263672, 21.41764069], [72.20236206, 21.41764069], [72.20236206, 21.41736031], [72.20207977, 21.41736031], [72.20207977, 21.41681099], [72.20179749, 21.41681099], [72.20179749, 21.41653061], [72.20153046, 21.41653061], [72.20153046, 21.41485977], [72.20124817, 21.41486359], [72.20124817, 21.41430473], [72.20069122, 21.41430473], [72.20069122, 21.41347122], [72.20097351, 21.41347122], [72.20097351, 21.41319466], [72.20124817, 21.41319466], [72.20124817, 21.41291618], [72.20097351, 21.41291618], [72.20097351, 21.41263962], [72.20041656, 21.41263962], [72.20041656, 21.41235924], [72.19902802, 21.41235924], [72.19902802, 21.41208076], [72.19847107, 21.41208267], [72.19847107, 21.41180611], [72.19763947, 21.41181183], [72.19763947, 21.41152954], [72.19708252, 21.41152954], [72.19708252, 21.41124916], [72.1965332, 21.41124916], [72.1965332, 21.41097069], [72.19625092, 21.4109726], [72.19625092, 21.41069412], [72.19569397, 21.41069412], [72.19569397, 21.41041756], [72.19541931, 21.41041946], [72.19541931, 21.40987015], [72.19513702, 21.40987015], [72.19513702, 21.40957832], [72.19458008, 21.40958405], [72.19458008, 21.40930557], [72.19431305, 21.40930748], [72.19431305, 21.40903091], [72.19403076, 21.40903091], [72.19403076, 21.40875053], [72.19374847, 21.40875053], [72.19374847, 21.40847015], [72.19347382, 21.40847206], [72.19347382, 21.40819359], [72.19319153, 21.40819359], [72.19319153, 21.40791893], [72.19291687, 21.40792084], [72.19291687, 21.40764046], [72.19235992, 21.40764046], [72.19235992, 21.40736008], [72.19208527, 21.40736198], [72.19208527, 21.40708351], [72.19180298, 21.40708351], [72.19180298, 21.40680695], [72.19152832, 21.40681076], [72.19152832, 21.40653038], [72.19097137, 21.40653038], [72.19097137, 21.40625], [72.18985748, 21.40625], [72.18985748, 21.40596962], [72.18902588, 21.40597153], [72.18902588, 21.40569687], [72.18875122, 21.40570068], [72.18875122, 21.4054203], [72.18846893, 21.4054203], [72.18846893, 21.40513992], [72.18818665, 21.40513992], [72.18818665, 21.40485954], [72.18791962, 21.40486145], [72.18791962, 21.40458488], [72.18736267, 21.40458488], [72.18736267, 21.40430641], [72.18682098, 21.40431023], [72.18682098, 21.40402985], [72.18653107, 21.40402985], [72.18653107, 21.40347099], [72.18624878, 21.40347481], [72.18624878, 21.40319252], [72.18597412, 21.40319252], [72.18597412, 21.40263939], [72.18541718, 21.40263939], [72.18541718, 21.40236092], [72.18514252, 21.40236092], [72.18514252, 21.40208054], [72.18486023, 21.40208244], [72.18486023, 21.40180588], [72.1845932, 21.40180969], [72.1845932, 21.40153122], [72.18430328, 21.40153122], [72.18430328, 21.40125275], [72.18402863, 21.40125275], [72.18402863, 21.40097046], [72.18374634, 21.40097237], [72.18374634, 21.40041733], [72.1829071, 21.40042114], [72.1829071, 21.40014267], [72.18235779, 21.40014267], [72.18235779, 21.39986038], [72.18208313, 21.39986038], [72.18208313, 21.39958191], [72.18152618, 21.39958382], [72.18152618, 21.39930534], [72.18096924, 21.39931107], [72.18096924, 21.39903259], [72.18070221, 21.39903259], [72.18070221, 21.39875031], [72.18041992, 21.39875031], [72.18041992, 21.39847183], [72.18013763, 21.39847183], [72.18013763, 21.39819527], [72.17986298, 21.3982029], [72.17986298, 21.39793015], [72.17958069, 21.39793015], [72.17958069, 21.39763832], [72.17930603, 21.39763832], [72.17930603, 21.39735985], [72.17819214, 21.39736176], [72.17819214, 21.39708328], [72.17736053, 21.39708328], [72.17736053, 21.39680481], [72.17680359, 21.39680481], [72.17680359, 21.39652824], [72.17652893, 21.39652824], [72.17652893, 21.39596748], [72.17624664, 21.3959713], [72.17624664, 21.39569473], [72.17597198, 21.39569473], [72.17597198, 21.39541626], [72.17569733, 21.39541817], [72.17569733, 21.39487076], [72.17542267, 21.39487076], [72.17542267, 21.39458084], [72.17514038, 21.39458275], [72.17514038, 21.39430618], [72.17485809, 21.39430809], [72.17485809, 21.39375114], [72.17456818, 21.39375114], [72.17456818, 21.39319038], [72.17430878, 21.3931942], [72.17430878, 21.39236069], [72.17402649, 21.39236069], [72.17402649, 21.39208031], [72.17375183, 21.39208412], [72.17375183, 21.39180756], [72.17346954, 21.39180756], [72.17346954, 21.39152527], [72.17318726, 21.39153099], [72.17318726, 21.39125061], [72.17263794, 21.39125061], [72.17263794, 21.39097023], [72.17236328, 21.39097214], [72.17236328, 21.39069557], [72.17208099, 21.39069557], [72.17208099, 21.39013863], [72.17153168, 21.39014053], [72.17153168, 21.38986015], [72.17097473, 21.38986206], [72.17097473, 21.38875008], [72.17069244, 21.38875008], [72.17069244, 21.38763809], [72.17041779, 21.38764191], [72.17041779, 21.38708115], [72.1701355, 21.38708115], [72.1701355, 21.38597107], [72.16986084, 21.38597107], [72.16986084, 21.3856945], [72.16958618, 21.38570023], [72.16958618, 21.38542175], [72.16929626, 21.38542175], [72.16929626, 21.38485909], [72.16902924, 21.38485909], [72.16902924, 21.38431168], [72.16876221, 21.38431168], [72.16876221, 21.38402939], [72.16819763, 21.38402939], [72.16819763, 21.38318825], [72.16764069, 21.38319397], [72.16764069, 21.3829174], [72.16707611, 21.38293266], [72.16707611, 21.38236046], [72.16680908, 21.38236046], [72.16680908, 21.38096809], [72.16708374, 21.38097191], [72.16708374, 21.38041878], [72.1673584, 21.38042068], [72.1673584, 21.3801403], [72.16764069, 21.3801403], [72.16764069, 21.37985992], [72.1673584, 21.37986183], [72.1673584, 21.37930679], [72.16708374, 21.37930679], [72.16708374, 21.37847137], [72.16680908, 21.37847137], [72.16680908, 21.37652779], [72.16652679, 21.37652969], [72.16652679, 21.37625122], [72.16625214, 21.37625122], [72.16625214, 21.37597084], [72.16596985, 21.37597466], [72.16596985, 21.37569237], [72.16569519, 21.37569237], [72.16569519, 21.3754158], [72.16539764, 21.37541962], [72.16539764, 21.37486076], [72.16513824, 21.37486076], [72.16513824, 21.37458038], [72.1645813, 21.37458229], [72.1645813, 21.37430573], [72.16430664, 21.37430954], [72.16430664, 21.37403107], [72.16401672, 21.37403107], [72.16401672, 21.37347031], [72.16374969, 21.37347031], [72.16374969, 21.37291718], [72.16319275, 21.3729229], [72.16319275, 21.37264252], [72.16291809, 21.37264252], [72.16291809, 21.37236023], [72.16262817, 21.37236023], [72.16262817, 21.37208176], [72.16236115, 21.37208366], [72.16236115, 21.37180519], [72.16208649, 21.37181282], [72.16208649, 21.37153244], [72.16152954, 21.37153244], [72.16152954, 21.37125015], [72.16124725, 21.37125015], [72.16124725, 21.37096977], [72.16069794, 21.37097168], [72.16069794, 21.37069511], [72.16042328, 21.37070084], [72.16042328, 21.37041855], [72.16014099, 21.37041855], [72.16014099, 21.37013817], [72.1598587, 21.37013817], [72.1598587, 21.36930084], [72.15958405, 21.36930466], [72.15958405, 21.36902809], [72.1590271, 21.36902809], [72.1590271, 21.36874962], [72.15875244, 21.36874962], [72.15875244, 21.36819077], [72.15847015, 21.36819458], [72.15847015, 21.36791611], [72.15820313, 21.36791992], [72.15820313, 21.36763], [72.15791321, 21.36763954], [72.15791321, 21.36736107], [72.15763855, 21.36736107], [72.15763855, 21.36680984], [72.15735626, 21.36680984], [72.15735626, 21.36652946], [72.1570816, 21.36652946], [72.1570816, 21.36625099], [72.1568222, 21.36625099], [72.1568222, 21.36569023], [72.15652466, 21.36569595], [72.15652466, 21.36541748], [72.15625, 21.36541939], [72.15625, 21.36514091], [72.15598297, 21.36514091], [72.15598297, 21.36457062], [72.15569305, 21.36458588], [72.15569305, 21.36402512], [72.1554184, 21.36403084], [72.1554184, 21.36347008], [72.15513611, 21.36347389], [72.15513611, 21.36319542], [72.15486145, 21.3631897], [72.15486145, 21.36291695], [72.15458679, 21.36292076], [72.15458679, 21.36264038], [72.15429688, 21.36264038], [72.15429688, 21.36182022], [72.15402985, 21.36182022], [72.15402985, 21.3615303], [72.15374756, 21.3615303], [72.15374756, 21.36124992], [72.15345764, 21.36124992], [72.15345764, 21.36096954], [72.15319824, 21.36097145], [72.15319061, 21.36069489], [72.15291595, 21.36069489], [72.15291595, 21.36041641], [72.1526413, 21.36042023], [72.1526413, 21.36013985], [72.15235901, 21.36013985], [72.15235901, 21.3595829], [72.15180206, 21.3595829], [72.15180206, 21.35930634], [72.1515274, 21.35931015], [72.1515274, 21.35903168], [72.15125275, 21.35903168], [72.15125275, 21.35876274], [72.15068817, 21.35876274], [72.15068817, 21.35819054], [72.15041351, 21.35819435], [72.15041351, 21.35736084], [72.15013885, 21.35736084], [72.15013885, 21.35681152], [72.14985657, 21.35681152], [72.14985657, 21.35625076], [72.14958191, 21.35625076], [72.14958191, 21.35597038], [72.14930725, 21.35597229], [72.14930725, 21.35569382], [72.14902496, 21.35569382], [72.14902496, 21.35541725], [72.14848328, 21.35541916], [72.14848328, 21.35514069], [72.14819336, 21.35514069], [72.14819336, 21.35486031], [72.1479187, 21.35486031], [72.1479187, 21.35457993], [72.14736176, 21.35458374], [72.14736176, 21.3540287], [72.1470871, 21.35403061], [72.1470871, 21.35375023], [72.14679718, 21.35375023], [72.14679718, 21.35320091], [72.14653015, 21.35320091], [72.14653015, 21.35292053], [72.14624786, 21.35292053], [72.14624786, 21.35263062], [72.14597321, 21.35263824], [72.14597321, 21.35236168], [72.14569092, 21.35236168], [72.14569092, 21.35208321], [72.14541626, 21.35208321], [72.14541626, 21.35180664], [72.14485931, 21.35180664], [72.14485931, 21.35124969], [72.14458466, 21.35124969], [72.14458466, 21.35097313], [72.14430237, 21.35097313], [72.14430237, 21.35069656], [72.14402771, 21.35069656], [72.14402771, 21.35041428], [72.14347076, 21.35042], [72.14347076, 21.34986115], [72.14319611, 21.34986115], [72.14319611, 21.3495903], [72.14290619, 21.3495903], [72.14290619, 21.34930992], [72.14263916, 21.34930992], [72.14263916, 21.34902954], [72.14235687, 21.34902954], [72.14235687, 21.34875107], [72.14208221, 21.34875107], [72.14208221, 21.34847069], [72.14180756, 21.3484745], [72.14180756, 21.34819221], [72.14152527, 21.34819221], [72.14152527, 21.34791756], [72.14125061, 21.34791946], [72.14125061, 21.3476429], [72.14097595, 21.3476429], [72.14097595, 21.34736061], [72.14041901, 21.34736061], [72.14041901, 21.34708023], [72.14013672, 21.34708214], [72.14013672, 21.3465271], [72.13986206, 21.34653282], [72.13986206, 21.34625053], [72.13957977, 21.34625053], [72.13957977, 21.34597015], [72.13930511, 21.34597015], [72.13930511, 21.34569359], [72.13903046, 21.34569359], [72.13903046, 21.34541702], [72.13874817, 21.34542274], [72.13874817, 21.34514046], [72.13845825, 21.34514046], [72.13845825, 21.34486008], [72.13819122, 21.34486008], [72.13819122, 21.34458351], [72.13791656, 21.34458351], [72.13791656, 21.34430504], [72.13764191, 21.34431267], [72.13764191, 21.34402847], [72.13709259, 21.34402847], [72.13709259, 21.34374809], [72.13680267, 21.34374809], [72.13680267, 21.34346962], [72.13652802, 21.34347153], [72.13652802, 21.34291649], [72.13625336, 21.3429184], [72.13625336, 21.34263992], [72.13597107, 21.34263992], [72.13597107, 21.34235954], [72.13569641, 21.34236145], [72.13569641, 21.34208298], [72.13541412, 21.34208298], [72.13541412, 21.34180641], [72.13485718, 21.34180832], [72.13485718, 21.34152985], [72.13458252, 21.34152985], [72.13458252, 21.34124947], [72.13430786, 21.34124947], [72.13430786, 21.34097099], [72.13402557, 21.3409729], [72.13402557, 21.34069443], [72.13375092, 21.34069443], [72.13375092, 21.34013939], [72.13346863, 21.34013939], [72.13346863, 21.33986092], [72.13318634, 21.33986092], [72.13318634, 21.33958054], [72.13291931, 21.33958244], [72.13291931, 21.33930779], [72.13265228, 21.33930969], [72.13265228, 21.33875084], [72.13236237, 21.33875084], [72.13236237, 21.33847046], [72.13208008, 21.33847237], [72.13208008, 21.3381958], [72.13180542, 21.3381958], [72.13180542, 21.33791733], [72.13153076, 21.33792114], [72.13153076, 21.3376503], [72.13124847, 21.3376503], [72.13124847, 21.33708], [72.13097382, 21.33708572], [72.13097382, 21.33680344], [72.13069153, 21.33681107], [72.13069153, 21.33653069], [72.13041687, 21.33653069], [72.13041687, 21.33625031], [72.13014221, 21.33625031], [72.13014221, 21.33596992], [72.12985992, 21.33597374], [72.12985992, 21.33569336], [72.12957764, 21.33570099], [72.12957764, 21.33542061], [72.12930298, 21.33542061], [72.12930298, 21.33514023], [72.12902832, 21.33514023], [72.12902832, 21.33459091], [72.12874603, 21.33459091], [72.12874603, 21.33403015], [72.12847137, 21.33403015], [72.12847137, 21.33374977], [72.12819672, 21.33374977], [72.12819672, 21.33346939], [72.12791443, 21.3334713], [72.12791443, 21.33319473], [72.12763977, 21.33319473], [72.12763977, 21.33263969], [72.12735748, 21.33263969], [72.12735748, 21.33235931], [72.12708282, 21.33235931], [72.12708282, 21.33208084], [72.12680817, 21.33208275], [72.12680817, 21.33152771], [72.12651825, 21.33152962], [72.12651825, 21.33124924], [72.12596893, 21.33124924], [72.12596893, 21.33068848], [72.12569427, 21.3306942], [72.12569427, 21.33041763], [72.12541962, 21.33042145], [72.12541962, 21.33013916], [72.12513733, 21.33013916], [72.12513733, 21.32930756], [72.12458038, 21.32930756], [72.12458038, 21.32875061], [72.12430573, 21.32875061], [72.12430573, 21.32847214], [72.12403107, 21.32847214], [72.12403107, 21.3279171], [72.12374878, 21.32792091], [72.12374878, 21.32736015], [72.12319183, 21.32736206], [72.12319183, 21.32680511], [72.12291718, 21.32681084], [72.12291718, 21.32653046], [72.12264252, 21.32653046], [72.12264252, 21.32625008], [72.12236023, 21.32625008], [72.12236023, 21.3259697], [72.12208557, 21.3259716], [72.12208557, 21.32569695], [72.12180328, 21.3257103], [72.12180328, 21.32542038], [72.12152863, 21.32542038], [72.12152863, 21.32485962], [72.12124634, 21.32486153], [72.12124634, 21.32374954], [72.12097168, 21.32374954], [72.12097168, 21.32319069], [72.12069702, 21.3231926], [72.12069702, 21.32291412], [72.12042236, 21.32291985], [72.12042236, 21.32265091], [72.12014008, 21.32265091], [72.12014008, 21.32208061], [72.11985779, 21.32208252], [72.11985779, 21.32152748], [72.11958313, 21.32152939], [72.11958313, 21.32097054], [72.11930847, 21.32097435], [72.11930847, 21.32069206], [72.11902618, 21.32069206], [72.11902618, 21.32013893], [72.11875153, 21.32014275], [72.11875153, 21.31986046], [72.11846924, 21.31986046], [72.11846924, 21.31931114], [72.11818695, 21.31931114], [72.11818695, 21.31875038], [72.11791992, 21.31875038], [72.11791992, 21.31847191], [72.11763763, 21.31847191], [72.11763763, 21.3176384], [72.11736298, 21.3176403], [72.11736298, 21.31707764], [72.11680603, 21.31708336], [72.11680603, 21.31680489], [72.11653137, 21.31680489], [72.11653137, 21.31624985], [72.11624908, 21.31624985], [72.11624908, 21.31568909], [72.11597443, 21.31569481], [72.11597443, 21.3148613], [72.11569214, 21.3148613], [72.11569214, 21.31458282], [72.11541748, 21.31458282], [72.11541748, 21.31402779], [72.11514282, 21.31402969], [72.11514282, 21.3134594], [72.11486053, 21.31347275], [72.11486053, 21.31319427], [72.11458588, 21.31319427], [72.11458588, 21.31263924], [72.11428833, 21.31264114], [72.11428833, 21.31236076], [72.11402893, 21.31236076], [72.11402893, 21.31153107], [72.11374664, 21.31153107], [72.11374664, 21.31097031], [72.11347198, 21.31097221], [72.11347198, 21.31041718], [72.11319733, 21.31042099], [72.11319733, 21.31014061], [72.11292267, 21.31014061], [72.11292267, 21.30957985], [72.11264038, 21.30958557], [72.11264038, 21.30902863], [72.11235809, 21.30903053], [72.11235809, 21.30764961], [72.11207581, 21.30764961], [72.11207581, 21.3073597], [72.11180878, 21.30736351], [72.11180878, 21.30597115], [72.11152649, 21.30597115], [72.11152649, 21.30513954], [72.11125183, 21.30513954], [72.11125183, 21.30458069], [72.11096954, 21.3045826], [72.11096954, 21.30402756], [72.11068726, 21.30402946], [72.11068726, 21.30374908], [72.11042023, 21.30374908], [72.11042023, 21.30318832], [72.11013794, 21.30319405], [72.11013794, 21.30291748], [72.10986328, 21.30291939], [72.10986328, 21.30264091], [72.10958099, 21.30264091], [72.10958099, 21.30236053], [72.10930634, 21.30236053], [72.10930634, 21.30151939], [72.10902405, 21.30152893], [72.10902405, 21.30069351], [72.10930634, 21.30069351], [72.10930634, 21.30041885], [72.10958099, 21.30042076], [72.10958099, 21.30014038], [72.10986328, 21.30014038], [72.10986328, 21.29957962], [72.11013794, 21.29958344], [72.11013794, 21.29930687], [72.11042023, 21.29931068], [72.11042023, 21.29874992], [72.11068726, 21.29874992], [72.11068726, 21.29681015], [72.11096954, 21.29681015], [72.11096954, 21.29624939], [72.11125183, 21.29624939], [72.11125183, 21.29597092], [72.11180878, 21.29597473], [72.11180878, 21.29347038], [72.11152649, 21.29347038], [72.11152649, 21.29319382], [72.11125183, 21.29319382], [72.11125183, 21.29263878], [72.11096954, 21.29264259], [72.11096954, 21.29070282], [72.11068726, 21.29070282], [72.11068726, 21.28957748], [72.11096954, 21.28958321], [72.11096954, 21.28874969], [72.11068726, 21.28874969], [72.11068726, 21.28819084], [72.11042023, 21.28819466], [72.11042023, 21.28763962], [72.11068726, 21.28763962], [72.11068726, 21.28708076], [72.11096954, 21.28708267], [72.11096954, 21.28680611], [72.11068726, 21.28680992], [72.11068726, 21.28653908], [72.11013794, 21.28653908], [72.11013794, 21.28597069], [72.10986328, 21.2859726], [72.10986328, 21.28569412], [72.10958099, 21.28569412], [72.10958099, 21.28541756], [72.10920715, 21.28541946], [72.10901642, 21.28541946], [72.10901642, 21.28458023], [72.10847473, 21.28458595], [72.10847473, 21.28375053], [72.10874939, 21.28375053], [72.10874939, 21.28347969], [72.10901642, 21.28347969], [72.10901642, 21.28292084], [72.10874939, 21.28291702], [72.10874939, 21.2831955], [72.10791779, 21.2831955], [72.10791779, 21.28291702], [72.10679626, 21.28292084], [72.10679626, 21.28264046], [72.10652924, 21.28264046], [72.10652924, 21.2820797], [72.10624695, 21.28208542], [72.10624695, 21.28180313], [72.10569763, 21.28181076], [72.10569763, 21.28153038], [72.10540771, 21.28153038], [72.10540771, 21.28125], [72.10514069, 21.28125], [72.10514069, 21.28070068], [72.1048584, 21.28070068], [72.1048584, 21.27985954], [72.10458374, 21.27986145], [72.10458374, 21.27930641], [72.10430908, 21.27931023], [72.10430908, 21.27903175], [72.10402679, 21.27903175], [72.10402679, 21.27874947], [72.10375214, 21.27874947], [72.10375214, 21.27846909], [72.10263824, 21.2784729], [72.10263824, 21.27819443], [72.1020813, 21.27819443], [72.1020813, 21.27791595], [72.10180664, 21.27791595], [72.10180664, 21.2784729], [72.10151672, 21.27846909], [72.10151672, 21.27874947], [72.10124969, 21.27874947], [72.10124969, 21.27931023], [72.10097504, 21.27930641], [72.10097504, 21.27986145], [72.10041809, 21.27985954], [72.10041809, 21.28014183], [72.09989166, 21.28014183], [72.09986115, 21.28070068], [72.09958649, 21.28069305], [72.09958649, 21.28097153], [72.09928894, 21.28096962], [72.09928894, 21.28153038], [72.09902954, 21.28152847], [72.09902954, 21.28208542], [72.09874725, 21.2820797], [72.09874725, 21.28264046], [72.0984726, 21.28263855], [72.0984726, 21.2831955], [72.09758759, 21.28319168], [72.09654236, 21.28318977], [72.09654236, 21.28347969], [72.09625244, 21.28347969], [72.09625244, 21.28403091], [72.09597015, 21.28402519], [72.09597015, 21.28458595], [72.0956955, 21.28458595], [72.09570313, 21.28486061], [72.09541321, 21.28486061], [72.09541321, 21.28514099], [72.09513855, 21.28514099], [72.09513855, 21.28541946], [72.09486389, 21.28541756], [72.09486389, 21.28569412], [72.0945816, 21.28569031], [72.0945816, 21.28625107], [72.09485626, 21.28625107], [72.09485626, 21.28736115], [72.0945816, 21.28736115], [72.0945816, 21.28763962], [72.09430695, 21.28763962], [72.09430695, 21.28791809], [72.09375, 21.28791809], [72.09375, 21.28763962], [72.09319305, 21.28763962], [72.09319305, 21.28736115], [72.09263611, 21.28736115], [72.09263611, 21.28708076], [72.09208679, 21.28708076], [72.09208679, 21.28736115], [72.09179688, 21.28736115], [72.09179688, 21.28763962], [72.09152985, 21.28763962], [72.09152985, 21.28791809], [72.09124756, 21.28791618], [72.09124756, 21.28847313], [72.0909729, 21.28847122], [72.0909729, 21.28874969], [72.09069824, 21.28874969], [72.09069824, 21.28902817], [72.09041595, 21.28902817], [72.09041595, 21.28958321], [72.0901413, 21.28957748], [72.0901413, 21.29041862], [72.08985901, 21.29041672], [72.08985901, 21.29097176], [72.08957672, 21.29097176], [72.08957672, 21.2918129], [72.08930206, 21.29180527], [72.08930206, 21.29208374], [72.0890274, 21.29208183], [72.0890274, 21.29264259], [72.08875275, 21.29263878], [72.08875275, 21.29319382], [72.08847046, 21.29319191], [72.08847046, 21.29403114], [72.0881958, 21.29402733], [72.0881958, 21.29458237], [72.08790588, 21.29458046], [72.08790588, 21.29514122], [72.08763885, 21.29513931], [72.08763885, 21.29597473], [72.08791351, 21.29597473], [72.08791351, 21.29708481], [72.08847046, 21.29708481], [72.08847046, 21.29736137], [72.08875275, 21.29735947], [72.08875275, 21.29763985], [72.0890274, 21.29763985], [72.0890274, 21.29848099], [72.08875275, 21.29848099], [72.08875275, 21.2990303], [72.08847046, 21.2990303], [72.08847046, 21.30014038], [72.08708191, 21.30014038], [72.08708191, 21.30042076], [72.08680725, 21.30041885], [72.08680725, 21.30319405], [72.08652496, 21.30319405], [72.08652496, 21.30347252], [72.08625031, 21.30347061], [72.08625031, 21.30431175], [72.08569336, 21.30430603], [72.08569336, 21.3045826], [72.08513641, 21.3045826], [72.08513641, 21.30430603], [72.08460236, 21.30431175], [72.08460236, 21.30374908], [72.08431244, 21.30374908], [72.08431244, 21.30347061], [72.08403015, 21.30347252], [72.08403015, 21.30291748], [72.08374786, 21.30291939], [72.08374786, 21.30236053], [72.08403015, 21.30236053], [72.08403015, 21.30151939], [72.08430481, 21.30152893], [72.08430481, 21.30125046], [72.08486176, 21.30125046], [72.08486176, 21.3006897], [72.08513641, 21.30069351], [72.08513641, 21.29930687], [72.0854187, 21.29931068], [72.0854187, 21.29848099], [72.08569336, 21.29848099], [72.08569336, 21.29819107], [72.08597565, 21.29819679], [72.08597565, 21.29736137], [72.08347321, 21.29736137], [72.08347321, 21.29624939], [72.08319092, 21.29624939], [72.08319092, 21.29597092], [72.08291626, 21.29597473], [72.08291626, 21.29569244], [72.0826416, 21.29569244], [72.0826416, 21.29541588], [72.08180237, 21.29541588], [72.08180237, 21.29569244], [72.08152771, 21.29569244], [72.08152771, 21.29597473], [72.08125305, 21.29597092], [72.08125305, 21.29652977], [72.08097076, 21.29652786], [72.08097076, 21.29708481], [72.08069611, 21.29708481], [72.08069611, 21.29736137], [72.08097076, 21.29735947], [72.08097076, 21.29874992], [72.08040619, 21.29874992], [72.08040619, 21.2990303], [72.08013916, 21.2990303], [72.08013916, 21.29931068], [72.0798645, 21.29930687], [72.07985687, 21.3006897], [72.07958221, 21.30069542], [72.07958221, 21.30097198], [72.07930756, 21.30097198], [72.07930756, 21.30152893], [72.07846832, 21.30151939], [72.07846832, 21.30181122], [72.07819366, 21.3018055], [72.07819366, 21.30208397], [72.07791901, 21.30207825], [72.07791901, 21.30236053], [72.07763672, 21.30236053], [72.07763672, 21.30264091], [72.07624817, 21.30264091], [72.07624817, 21.30207825], [72.07597351, 21.30208397], [72.07597351, 21.30069542], [72.07569122, 21.3006897], [72.07569122, 21.29930687], [72.07596588, 21.29931068], [72.07596588, 21.2990303], [72.07707977, 21.2990303], [72.07707977, 21.29931068], [72.07791901, 21.29931068], [72.07791901, 21.2990303], [72.0790329, 21.2990303], [72.0790329, 21.29848099], [72.07930756, 21.29848099], [72.07930756, 21.29763985], [72.07958221, 21.29763985], [72.07958221, 21.29652977], [72.07985687, 21.29652977], [72.07985687, 21.29569054], [72.08013916, 21.29569244], [72.08013916, 21.29486084], [72.07985687, 21.29486084], [72.07985687, 21.29403114], [72.08097076, 21.29403114], [72.08097076, 21.29375267], [72.08125305, 21.29375267], [72.08125305, 21.29347038], [72.08097076, 21.29347038], [72.08097076, 21.29319382], [72.08069611, 21.29319382], [72.08069611, 21.29263878], [72.08040619, 21.29264259], [72.08040619, 21.29235077], [72.08013916, 21.29236031], [72.08013916, 21.29208374], [72.0798645, 21.29208374], [72.0798645, 21.29180527], [72.07930756, 21.2918129], [72.07930756, 21.29153252], [72.0790329, 21.29153252], [72.0790329, 21.29125023], [72.07846832, 21.29125023], [72.07846832, 21.29153252], [72.07819366, 21.2915287], [72.07819366, 21.29208374], [72.07763672, 21.29208374], [72.07763672, 21.29236031], [72.07736206, 21.29236031], [72.07736206, 21.29180527], [72.07707977, 21.2918129], [72.07707977, 21.29153252], [72.07681274, 21.29153252], [72.07681274, 21.29097176], [72.07653046, 21.29097176], [72.07653046, 21.29069519], [72.07624817, 21.29070282], [72.07624817, 21.29041862], [72.07485962, 21.29041862], [72.07485962, 21.28957748], [72.07514191, 21.28958321], [72.07514191, 21.28874969], [72.07540894, 21.28874969], [72.07540894, 21.28847122], [72.07597351, 21.28847313], [72.07597351, 21.28819466], [72.07707977, 21.28819466], [72.07707977, 21.28847313], [72.07817841, 21.28847122], [72.07817841, 21.28874969], [72.07875061, 21.28874969], [72.07875061, 21.28902817], [72.07902527, 21.28902817], [72.07902527, 21.28930473], [72.07930756, 21.28930473], [72.07930756, 21.28958321], [72.0798645, 21.28958321], [72.0798645, 21.28986168], [72.08013916, 21.28985977], [72.08013916, 21.29013824], [72.08040619, 21.29013824], [72.08040619, 21.29041862], [72.08069611, 21.29041862], [72.08069611, 21.29070282], [72.08180237, 21.29069519], [72.08180237, 21.29097176], [72.08235931, 21.29097176], [72.08235931, 21.29125023], [72.0826416, 21.29125023], [72.0826416, 21.29153252], [72.08291626, 21.29153252], [72.08291626, 21.29125023], [72.08319092, 21.29125023], [72.08319092, 21.29070282], [72.08347321, 21.29070282], [72.08347321, 21.29041862], [72.08374786, 21.29041862], [72.08374786, 21.29013824], [72.08431244, 21.29013824], [72.08431244, 21.29041862], [72.08486176, 21.29041862], [72.08486176, 21.29013824], [72.08513641, 21.29013824], [72.08513641, 21.28874969], [72.08486176, 21.28874969], [72.08486176, 21.28680992], [72.08513641, 21.28680992], [72.08513641, 21.28597069], [72.0854187, 21.2859726], [72.0854187, 21.28430557], [72.08569336, 21.28430939], [72.08569336, 21.28403091], [72.08598328, 21.28403091], [72.08598328, 21.28236008], [72.08625031, 21.28236389], [72.08625031, 21.28152847], [72.08653259, 21.28153038], [72.08653259, 21.28070068], [72.08680725, 21.28070068], [72.08680725, 21.28014183], [72.08708191, 21.28014183], [72.08708191, 21.27931023], [72.08734894, 21.27931023], [72.08734894, 21.27903175], [72.08763885, 21.27903175], [72.08763885, 21.27874947], [72.08790588, 21.27874947], [72.08790588, 21.27819061], [72.08847046, 21.27819443], [72.08847046, 21.27763939], [72.08875275, 21.27763939], [72.08875275, 21.27734947], [72.08930206, 21.27736092], [72.08930206, 21.27708244], [72.08958435, 21.27708244], [72.08958435, 21.27680588], [72.09152985, 21.2768116], [72.09152985, 21.27625084], [72.09179688, 21.27625084], [72.09179688, 21.27597046], [72.09236145, 21.27597237], [72.09236145, 21.27541733], [72.0929184, 21.27541924], [72.0929184, 21.27486038], [72.09319305, 21.27486038], [72.09319305, 21.27457809], [72.09347534, 21.27458382], [72.09347534, 21.27430534], [72.0945816, 21.27431107], [72.0945816, 21.27514076], [72.09486389, 21.27513885], [72.09486389, 21.27569389], [72.09513855, 21.27568817], [72.09513855, 21.27652931], [72.09541321, 21.2765274], [72.09541321, 21.27736092], [72.0956955, 21.27736092], [72.0956955, 21.27763939], [72.09597015, 21.27763939], [72.09597015, 21.27792168], [72.09654236, 21.27792168], [72.09654236, 21.27734947], [72.09708405, 21.27736092], [72.09708405, 21.27708244], [72.0973587, 21.27708244], [72.0973587, 21.27597237], [72.09708405, 21.27597237], [72.09708405, 21.27541733], [72.09680176, 21.27541924], [72.09680176, 21.27457809], [72.09708405, 21.27458382], [72.09708405, 21.27347183], [72.0973587, 21.27347183], [72.0973587, 21.27319527], [72.09707642, 21.27320099], [72.09707642, 21.27207947], [72.0973587, 21.27208328], [72.0973587, 21.27152824], [72.09764099, 21.27153969], [72.09764099, 21.27124977], [72.09792328, 21.27124977], [72.09791565, 21.26958466], [72.09764099, 21.26958466], [72.09764099, 21.26625061], [72.0973587, 21.26625061], [72.0973587, 21.26458168], [72.09791565, 21.26458359], [72.09791565, 21.26430511], [72.09819794, 21.26431274], [72.09819794, 21.26402855], [72.09792328, 21.26402855], [72.09792328, 21.26374817], [72.09764099, 21.26374817], [72.09764099, 21.2634697], [72.0973587, 21.2634716], [72.0973587, 21.26319504], [72.09707642, 21.26320076], [72.09707642, 21.26263809], [72.09680176, 21.26263809], [72.09680176, 21.26236916], [72.09597015, 21.26236916], [72.09597015, 21.26208115], [72.0956955, 21.26208305], [72.0956955, 21.26180649], [72.09541321, 21.2618084], [72.09541321, 21.26152992], [72.0945816, 21.26152992], [72.0945816, 21.26124954], [72.09430695, 21.26124954], [72.09430695, 21.26152992], [72.09375, 21.26152992], [72.09375, 21.2618084], [72.09263611, 21.2618084], [72.09263611, 21.26152992], [72.09236145, 21.26152992], [72.09236145, 21.26013947], [72.09208679, 21.26013947], [72.09208679, 21.25958061], [72.0918045, 21.25958252], [72.0918045, 21.25902748], [72.09152985, 21.25902939], [72.09152985, 21.25847054], [72.09124756, 21.25847244], [72.09124756, 21.25819588], [72.0909729, 21.25819588], [72.0909729, 21.25763893], [72.09069824, 21.25764084], [72.09069061, 21.25708008], [72.09041595, 21.2570858], [72.09041595, 21.25652695], [72.0901413, 21.25653076], [72.0901413, 21.25624275], [72.08985901, 21.25625038], [72.08985901, 21.25569534], [72.08957672, 21.25570107], [72.08957672, 21.25542068], [72.08930206, 21.25542068], [72.08930206, 21.2551403], [72.0890274, 21.2551403], [72.0890274, 21.25457954], [72.08875275, 21.25458145], [72.08875275, 21.25430489], [72.08847046, 21.25430489], [72.08847046, 21.25374985], [72.0881958, 21.25374985], [72.0881958, 21.25346947], [72.08791351, 21.25347137], [72.08791351, 21.25319481], [72.08763885, 21.25319481], [72.08763885, 21.25263977], [72.08734894, 21.25263977], [72.08734894, 21.25235939], [72.08708191, 21.2523613], [72.08708191, 21.25208282], [72.08680725, 21.25208282], [72.08680725, 21.25152779], [72.08653259, 21.2515316], [72.08653259, 21.25124931], [72.08625031, 21.25124931], [72.08625031, 21.25069046], [72.08597565, 21.25069427], [72.08597565, 21.2504158], [72.0854187, 21.25043106], [72.0854187, 21.24986076], [72.08513641, 21.24986076], [72.08513641, 21.24931145], [72.08486176, 21.24930573], [72.08486176, 21.2495842], [72.0845871, 21.2495842], [72.0845871, 21.25069427], [72.08431244, 21.25069046], [72.08431244, 21.25124931], [72.08403015, 21.25124931], [72.08403015, 21.2515316], [72.08374786, 21.2515316], [72.08374786, 21.25181007], [72.08347321, 21.25180626], [72.08347321, 21.25208282], [72.08208466, 21.25208282], [72.08208466, 21.25180626], [72.08152771, 21.25181007], [72.08152771, 21.25097084], [72.08125305, 21.25097275], [72.08125305, 21.24847221], [72.08152771, 21.24847221], [72.08152771, 21.2476387], [72.08180237, 21.24764061], [72.08180237, 21.24653053], [72.08207703, 21.24653053], [72.08207703, 21.24570084], [72.0826416, 21.24570084], [72.0826416, 21.24542046], [72.08291626, 21.24542046], [72.08291626, 21.24514008], [72.08347321, 21.24514008], [72.08347321, 21.2448597], [72.08374786, 21.2448616], [72.08374786, 21.24430656], [72.08430481, 21.24430656], [72.08430481, 21.24402809], [72.08460236, 21.24403], [72.08460236, 21.24374962], [72.08513641, 21.24374962], [72.08513641, 21.24291992], [72.0854187, 21.24291992], [72.0854187, 21.24263954], [72.08569336, 21.24263954], [72.08569336, 21.24180984], [72.08598328, 21.24180984], [72.08598328, 21.23847008], [72.08625031, 21.23847008], [72.08625031, 21.23624992], [72.08653259, 21.23624992], [72.08652496, 21.23541641], [72.08680725, 21.23543167], [72.08680725, 21.23458099], [72.08708191, 21.2345829], [72.08708191, 21.23347282], [72.0873642, 21.23347282], [72.0873642, 21.23291779], [72.08763885, 21.23291969], [72.08763885, 21.23180962], [72.08790588, 21.23180962], [72.08790588, 21.23097038], [72.0881958, 21.23097229], [72.0881958, 21.23041725], [72.08847046, 21.23042107], [72.08847046, 21.22986031], [72.08875275, 21.22986031], [72.08875275, 21.22903061], [72.0890274, 21.22903061], [72.0890274, 21.22875023], [72.08930206, 21.22875023], [72.08930206, 21.22846985], [72.08958435, 21.22847366], [72.08958435, 21.22791672], [72.0901413, 21.22792053], [72.0901413, 21.22764015], [72.09040833, 21.22764015], [72.09040833, 21.22735977], [72.09069061, 21.22736359], [72.09069824, 21.2270813], [72.0909729, 21.2270813], [72.0909729, 21.22652817], [72.09179688, 21.22653008], [72.09179688, 21.22624016], [72.0929184, 21.22624969], [72.0929184, 21.22597122], [72.09319305, 21.22597122], [72.09319305, 21.22569466], [72.09347534, 21.22569466], [72.09347534, 21.22541618], [72.09401703, 21.22542191], [72.09401703, 21.22513962], [72.09485626, 21.22513962], [72.09485626, 21.22485924], [72.09513855, 21.22485924], [72.09513855, 21.22458076], [72.09541321, 21.22458267], [72.09541321, 21.22402763], [72.09570313, 21.22402954], [72.09570313, 21.22374916], [72.09597015, 21.22374916], [72.09597015, 21.22347069], [72.09625244, 21.2234726], [72.09625244, 21.22291756], [72.10124969, 21.22292137], [72.10124969, 21.22320175], [72.10180664, 21.22319412], [72.10180664, 21.2234726], [72.1020813, 21.22347069], [72.1020813, 21.22374916], [72.10234833, 21.22374916], [72.10234833, 21.22402954], [72.1029129, 21.22402954], [72.1029129, 21.22431183], [72.10346985, 21.22430611], [72.10346985, 21.22458267], [72.10402679, 21.22458076], [72.10402679, 21.22485924], [72.10430908, 21.22485924], [72.10430908, 21.22431183], [72.10457611, 21.22431183], [72.10457611, 21.22374916], [72.1048584, 21.22374916], [72.1048584, 21.22320175], [72.10514069, 21.22320175], [72.10514069, 21.22236061], [72.10540771, 21.22236061], [72.10540771, 21.22180748], [72.10597229, 21.22180748], [72.10597229, 21.22153091], [72.10624695, 21.22153091], [72.10624695, 21.22125053], [72.10679626, 21.22125053], [72.10679626, 21.22097015], [72.10847473, 21.22097206], [72.10847473, 21.22069359], [72.10902405, 21.22069359], [72.10902405, 21.22097206], [72.10930634, 21.22097206], [72.10930634, 21.22113037], [72.10930634, 21.2234726], [72.10902405, 21.2234726], [72.10902405, 21.22458267], [72.10874939, 21.22458076], [72.10874939, 21.22485924], [72.10901642, 21.22485924], [72.10901642, 21.22513962], [72.10986328, 21.22513962], [72.10986328, 21.22485924], [72.11042023, 21.22485924], [72.11042023, 21.22431183], [72.11096954, 21.22431183], [72.11096954, 21.22402954], [72.11125183, 21.22402954], [72.11125183, 21.22374916], [72.11154175, 21.22374916], [72.11154175, 21.22263908], [72.11235809, 21.22263908], [72.11235809, 21.22153091], [72.11180878, 21.22153091], [72.11180878, 21.22125053], [72.11152649, 21.22125053], [72.11152649, 21.22041893], [72.11125183, 21.22042084], [72.11125183, 21.21986008], [72.11096954, 21.21986198], [72.11096954, 21.21957016], [72.11096954, 21.21930695], [72.11042023, 21.21931076], [72.11042023, 21.21903038], [72.10930634, 21.21903038], [72.10930634, 21.21820068], [72.10848236, 21.21820068], [72.10848236, 21.2179203], [72.10679626, 21.2179203], [72.10679626, 21.21763992], [72.10624695, 21.21763992], [72.10624695, 21.21735954], [72.10597229, 21.21736145], [72.10597229, 21.21708488], [72.10541534, 21.21708488], [72.10541534, 21.21624947], [72.10514069, 21.21624947], [72.10514069, 21.21541977], [72.10540771, 21.21541977], [72.10540771, 21.21513939], [72.10569763, 21.21513939], [72.10569763, 21.21486282], [72.10624695, 21.21486282], [72.10624695, 21.21458054], [72.10791779, 21.21458054], [72.10791779, 21.21486282], [72.10930634, 21.21486282], [72.10930634, 21.21458054], [72.11042023, 21.21458244], [72.11042023, 21.21430588], [72.11096954, 21.21432114], [72.11096954, 21.21403122], [72.11125183, 21.21403122], [72.11125183, 21.21375275], [72.11154175, 21.21375275], [72.11152649, 21.21347046], [72.11208344, 21.21347046], [72.11208344, 21.21263885], [72.11235809, 21.21264267], [72.11235809, 21.21181107], [72.11319733, 21.21180534], [72.11319733, 21.21208382], [72.11374664, 21.21208382], [72.11374664, 21.21180534], [72.11428833, 21.21181107], [72.11428833, 21.21125984], [72.11374664, 21.21125984], [72.11374664, 21.21097183], [72.11347198, 21.21097183], [72.11347198, 21.21069527], [72.11292267, 21.2107029], [72.11292267, 21.2104187], [72.11264038, 21.2104187], [72.11264038, 21.20929909], [72.11291504, 21.20930481], [72.11291504, 21.20708275], [72.11264038, 21.20708275], [72.11264038, 21.20680618], [72.11235809, 21.20680809], [72.11235809, 21.20652962], [72.11207581, 21.20652962], [72.11207581, 21.20625114], [72.11180878, 21.20625114], [72.11180878, 21.20597076], [72.11096954, 21.20597267], [72.11096954, 21.2056942], [72.11069489, 21.2056942], [72.11069489, 21.20541763], [72.11042023, 21.20541954], [72.11042023, 21.20458031], [72.11096954, 21.20458412], [72.11096954, 21.20430565], [72.11180878, 21.20430946], [72.11180878, 21.20347023], [72.11264038, 21.20347023], [72.11264038, 21.20375061], [72.11292267, 21.20375061], [72.11292267, 21.20403099], [72.11319733, 21.20403099], [72.11319733, 21.20292091], [72.11486053, 21.20292091], [72.11486053, 21.20264053], [72.11514282, 21.20264053], [72.11514282, 21.20207024], [72.11541748, 21.20208549], [72.11541748, 21.2009716], [72.11513519, 21.2009716], [72.11513519, 21.20013809], [72.11486053, 21.20014191], [72.11486053, 21.19985962], [72.11458588, 21.19986343], [72.11458588, 21.1981945], [72.11430359, 21.1981945], [72.11430359, 21.19763947], [72.11402893, 21.19763947], [72.11402893, 21.19708061], [72.11374664, 21.19708252], [72.11374664, 21.19652748], [72.11319733, 21.19652939], [72.11319733, 21.19626236], [72.11235809, 21.19626236], [72.11235809, 21.19652939], [72.11125183, 21.19652939], [72.11125183, 21.19681168], [72.11042023, 21.19681168], [72.11042023, 21.19652939], [72.11013794, 21.19652939], [72.11013794, 21.19626236], [72.10930634, 21.19626236], [72.10930634, 21.19597054], [72.10847473, 21.19597244], [72.10847473, 21.19569397], [72.10791779, 21.19569397], [72.10791779, 21.1954174], [72.10764313, 21.19542122], [72.10764313, 21.19514084], [72.10680389, 21.19513893], [72.10680389, 21.19569397], [72.10708618, 21.19569397], [72.10708618, 21.19597244], [72.10764313, 21.19597054], [72.10764313, 21.19626236], [72.10819244, 21.19626236], [72.10819244, 21.19652939], [72.10847473, 21.19652748], [72.10847473, 21.19708252], [72.1076355, 21.19708252], [72.1076355, 21.19680595], [72.10569763, 21.19681168], [72.10569763, 21.19626236], [72.10514069, 21.19626236], [72.10514069, 21.19597054], [72.1048584, 21.19597244], [72.1048584, 21.19569397], [72.10319519, 21.19569397], [72.10319519, 21.1954174], [72.1029129, 21.19542122], [72.1029129, 21.19514084], [72.10234833, 21.19514084], [72.10234833, 21.19486046], [72.10180664, 21.19486046], [72.10180664, 21.19458008], [72.10124969, 21.19458389], [72.10124969, 21.19430542], [72.10098267, 21.19431114], [72.10098267, 21.19403076], [72.10069275, 21.19403076], [72.10069275, 21.19347], [72.10041809, 21.19347191], [72.10041809, 21.19319534], [72.09986115, 21.19319534], [72.09986115, 21.19347191], [72.0984726, 21.19347191], [72.0984726, 21.19319534], [72.09791565, 21.19319534], [72.09791565, 21.19291687], [72.09764099, 21.19292068], [72.09764099, 21.1926403], [72.09707642, 21.1926403], [72.09707642, 21.19235992], [72.09654236, 21.19235992], [72.09654236, 21.1926403], [72.09625244, 21.1926403], [72.09625244, 21.19292068], [72.09541321, 21.19292068], [72.09541321, 21.19235992], [72.09513855, 21.19236183], [72.09513855, 21.19208336], [72.0945816, 21.19208336], [72.0945816, 21.19180679], [72.09263611, 21.19180679], [72.09263611, 21.19152832], [72.09208679, 21.19153023], [72.09208679, 21.19124985], [72.09179688, 21.19124985], [72.09179688, 21.19096947], [72.0901413, 21.19097137], [72.0901413, 21.19069672], [72.08958435, 21.19069672], [72.08958435, 21.19013977], [72.08930206, 21.19013023], [72.08930206, 21.19042015], [72.08708191, 21.19042015], [72.08708191, 21.18875122], [72.08734894, 21.18875122], [72.08734894, 21.18736076], [72.08708191, 21.18736076], [72.08708191, 21.18708992], [72.08625031, 21.18708992], [72.08625031, 21.18680954], [72.08431244, 21.18680954], [72.08431244, 21.18653107], [72.08403015, 21.18653107], [72.08403015, 21.18625259], [72.08235931, 21.18625259], [72.08235931, 21.18653107], [72.08207703, 21.18653107], [72.08207703, 21.18625259], [72.08180237, 21.18625259], [72.08180237, 21.18597031], [72.08152771, 21.18597031], [72.08152771, 21.18569374], [72.08097076, 21.18569374], [72.08097076, 21.18541718], [72.08040619, 21.1854229], [72.08040619, 21.18514252], [72.08013916, 21.18514252], [72.08013916, 21.18486023], [72.07958221, 21.18486023], [72.07958221, 21.18432045], [72.07930756, 21.18432045], [72.07930756, 21.18374825], [72.07902527, 21.18374825], [72.07902527, 21.18319511], [72.07875061, 21.18320084], [72.07875061, 21.18291855], [72.07846832, 21.18291855], [72.07846832, 21.1823597], [72.07736206, 21.1823616], [72.07736206, 21.18180466], [72.07624817, 21.18180466], [72.07624817, 21.18124962], [72.07596588, 21.18124962], [72.07596588, 21.18069077], [72.07569122, 21.18069458], [72.07569122, 21.18041611], [72.07540894, 21.18041992], [72.07540894, 21.18013954], [72.07514191, 21.18013954], [72.07514191, 21.17958069], [72.07485962, 21.1795826], [72.07485962, 21.17930794], [72.07430267, 21.17930984], [72.07430267, 21.17902946], [72.07319641, 21.17902946], [72.07319641, 21.17875099], [72.07237244, 21.17875099], [72.07237244, 21.17902946], [72.07180786, 21.17902946], [72.07180786, 21.17930984], [72.07096863, 21.17930794], [72.07096863, 21.1795826], [72.07041931, 21.17958069], [72.07041931, 21.17986107], [72.07013702, 21.17986107], [72.07013702, 21.17958069], [72.06903076, 21.1795826], [72.06903076, 21.17930794], [72.06874847, 21.17930984], [72.06874847, 21.17902946], [72.06846619, 21.17902946], [72.06846619, 21.17764091], [72.06791687, 21.17764091], [72.06791687, 21.17736053], [72.06764221, 21.17736053], [72.06764221, 21.17708015], [72.06735992, 21.17708015], [72.06735992, 21.17736053], [72.06680298, 21.17736053], [72.06680298, 21.17764091], [72.06652832, 21.17764091], [72.06652832, 21.17791939], [72.06597137, 21.17791748], [72.06597137, 21.17819595], [72.06541443, 21.17819595], [72.06541443, 21.17763901], [72.06458282, 21.17764091], [72.06458282, 21.17736053], [72.06402588, 21.17736053], [72.06402588, 21.17681122], [72.06375122, 21.17681122], [72.06375122, 21.17431068], [72.06346893, 21.17431068], [72.06346893, 21.17374992], [72.06317902, 21.17374992], [72.06317902, 21.17319107], [72.06291962, 21.17319489], [72.06291962, 21.17264175], [72.06208038, 21.17264175], [72.06208038, 21.17235947], [72.06181335, 21.17235947], [72.06181335, 21.17264175], [72.06153107, 21.17264175], [72.06153107, 21.17292023], [72.06069183, 21.17291641], [72.06069183, 21.17319489], [72.05986023, 21.17319489], [72.05986023, 21.17291641], [72.05958557, 21.17291641], [72.05958557, 21.17319489], [72.05902863, 21.17319107], [72.05902863, 21.17431068], [72.05930328, 21.17430305], [72.05930328, 21.17486382], [72.05847168, 21.17486382], [72.05847168, 21.17458153], [72.05680847, 21.17458153], [72.05680847, 21.17430305], [72.05625153, 21.17431068], [72.05625153, 21.1740303], [72.05568695, 21.1740303], [72.05568695, 21.17374992], [72.05541992, 21.17374992], [72.05541992, 21.17346954], [72.05513763, 21.17347145], [72.05513763, 21.17263794], [72.05541992, 21.17264175], [72.05541992, 21.17235947], [72.05625153, 21.17236137], [72.05625153, 21.17124939], [72.05568695, 21.17124939], [72.05568695, 21.17097092], [72.05513763, 21.17097282], [72.05513763, 21.17069435], [72.05486298, 21.17069435], [72.05486298, 21.17041588], [72.05458069, 21.1704216], [72.05458069, 21.17013931], [72.0542984, 21.17013931], [72.0542984, 21.16931152], [72.05374908, 21.16931152], [72.05374908, 21.1690197], [72.05347443, 21.16902733], [72.05347443, 21.16847229], [72.05319214, 21.16847229], [72.05319214, 21.16791725], [72.05291748, 21.16791916], [72.05291748, 21.16736031], [72.05263519, 21.16736031], [72.05263519, 21.16708374], [72.05208588, 21.16708374], [72.05208588, 21.16680527], [72.05179596, 21.16681099], [72.05179596, 21.16596031], [72.05152893, 21.16597176], [72.05152893, 21.16569519], [72.05123901, 21.16570091], [72.05123901, 21.16542053], [72.05097198, 21.16542053], [72.05097198, 21.16485977], [72.05069733, 21.16486168], [72.05069733, 21.16458321], [72.05041504, 21.16458321], [72.05041504, 21.16430664], [72.05014038, 21.16430664], [72.05014038, 21.16402817], [72.04875183, 21.16403008], [72.04875183, 21.16292], [72.04846954, 21.16292], [72.04846954, 21.16208076], [72.04819489, 21.16208458], [72.04819489, 21.16180611], [72.04792023, 21.16180992], [72.04792023, 21.16069031], [72.04763794, 21.16069221], [72.04763794, 21.16041756], [72.04680634, 21.16041946], [72.04680634, 21.15930939], [72.04651642, 21.15930939], [72.04651642, 21.15903282], [72.04541779, 21.1590271], [72.04543304, 21.15986061], [72.04458618, 21.15986061], [72.04458618, 21.15958023], [72.04429626, 21.15958023], [72.04429626, 21.15986061], [72.04347229, 21.15986061], [72.04347229, 21.15958023], [72.04264069, 21.15958023], [72.04264069, 21.15986061], [72.0423584, 21.15986061], [72.0423584, 21.16069221], [72.04208374, 21.16069221], [72.04208374, 21.1609745], [72.0423584, 21.16097069], [72.0423584, 21.16180992], [72.04264069, 21.16180611], [72.04264069, 21.16208458], [72.0423584, 21.16208076], [72.0423584, 21.16236115], [72.04206848, 21.16236115], [72.04206848, 21.16263962], [72.04152679, 21.16263962], [72.04152679, 21.16236115], [72.04180908, 21.16236115], [72.04180908, 21.16208076], [72.04152679, 21.16208458], [72.04152679, 21.16180611], [72.04125214, 21.16180992], [72.04125214, 21.16152954], [72.04070282, 21.16152954], [72.04070282, 21.16180992], [72.03874969, 21.16180992], [72.03874969, 21.16152954], [72.03848267, 21.16152954], [72.03848267, 21.16041946], [72.03819275, 21.16041946], [72.03819275, 21.15986061], [72.03791809, 21.15986061], [72.03791809, 21.15958023], [72.0376358, 21.15958214], [72.0376358, 21.15930557], [72.03736115, 21.15930939], [72.03736115, 21.15903282], [72.03708649, 21.15903282], [72.03708649, 21.15875053], [72.03679657, 21.15875053], [72.03679657, 21.15847015], [72.03569794, 21.15847015], [72.03569794, 21.15819359], [72.03541565, 21.15819359], [72.03541565, 21.15791702], [72.03457642, 21.15792274], [72.03457642, 21.15764236], [72.0340271, 21.15764236], [72.0340271, 21.15735817], [72.03375244, 21.15736008], [72.03375244, 21.15708351], [72.03347015, 21.15708351], [72.03347015, 21.15680504], [72.03291321, 21.15680504], [72.03291321, 21.15708351], [72.0320816, 21.15708351], [72.0320816, 21.15680504], [72.03125, 21.15681076], [72.03125, 21.15652847], [72.0304184, 21.15652847], [72.0304184, 21.15624809], [72.03012848, 21.15624809], [72.03012848, 21.15596962], [72.02986145, 21.15597153], [72.02986145, 21.15569496], [72.02902985, 21.15570068], [72.02902985, 21.1554184], [72.02874756, 21.1554184], [72.02874756, 21.15513992], [72.02791595, 21.15513992], [72.02791595, 21.15485954], [72.02735901, 21.15486145], [72.02735901, 21.15458298], [72.02680206, 21.15458298], [72.02680206, 21.15430641], [72.02625275, 21.15430832], [72.02625275, 21.15402031], [72.02346039, 21.15402794], [72.02319336, 21.15402794], [72.02319336, 21.15374947], [72.02153015, 21.15374947], [72.02153015, 21.15458298], [72.0220871, 21.15458298], [72.0220871, 21.15486145], [72.02236176, 21.15485954], [72.02236176, 21.15513992], [72.02263641, 21.15513992], [72.02263641, 21.15570068], [72.02179718, 21.15570068], [72.02179718, 21.1554184], [72.02069092, 21.1554184], [72.02069092, 21.15513992], [72.0201416, 21.15513992], [72.0201416, 21.15485954], [72.01930237, 21.15486145], [72.01930237, 21.15458298], [72.01902771, 21.15458298], [72.01902771, 21.15430641], [72.01818848, 21.15430832], [72.01818848, 21.15402031], [72.01791382, 21.15402794], [72.01791382, 21.1534729], [72.01763916, 21.1534729], [72.01763916, 21.15319443], [72.0173645, 21.15319443], [72.0173645, 21.15263939], [72.01763916, 21.15263939], [72.01763916, 21.15153122], [72.01790619, 21.15153122], [72.01790619, 21.15125084], [72.01763916, 21.15125084], [72.01763916, 21.15042114], [72.01735687, 21.15042114], [72.01735687, 21.14986038], [72.01680756, 21.14986038], [72.01680756, 21.14958], [72.01652527, 21.14958572], [72.01652527, 21.14902687], [72.01597595, 21.14903069], [72.01597595, 21.14875031], [72.01541901, 21.14875031], [72.01541901, 21.14846992], [72.01486206, 21.14847374], [72.01486206, 21.14819527], [72.01264191, 21.14821053], [72.01264191, 21.14792061], [72.01209259, 21.14792061], [72.01209259, 21.14764023], [72.01180267, 21.14764023], [72.01180267, 21.14735985], [72.01125336, 21.14736366], [72.01125336, 21.14708138], [72.01097107, 21.14708138], [72.01097107, 21.14652824], [72.01069641, 21.14653015], [72.01069641, 21.14624977], [72.01040649, 21.14624977], [72.01040649, 21.14596939], [72.01013947, 21.1459713], [72.01013947, 21.14569473], [72.00986481, 21.14569473], [72.00986481, 21.14458275], [72.01013947, 21.14458275], [72.01013947, 21.14291763], [72.00985718, 21.14292145], [72.00985718, 21.14208031], [72.00958252, 21.14208412], [72.00958252, 21.14152718], [72.00932312, 21.14152908], [72.00932312, 21.14097023], [72.00958252, 21.14097214], [72.00958252, 21.14069366], [72.00986481, 21.14069366], [72.00986481, 21.13958359], [72.01013947, 21.13958359], [72.01013947, 21.13930511], [72.01097107, 21.13931084], [72.01097107, 21.13903809], [72.01125336, 21.13903809], [72.01125336, 21.1384697], [72.01097107, 21.1384716], [72.01097107, 21.13652802], [72.01125336, 21.13652992], [72.01125336, 21.13513947], [72.01097107, 21.13513947], [72.01097107, 21.1348629], [72.01069641, 21.1348629], [72.01069641, 21.13458061], [72.01041412, 21.13458443], [72.01041412, 21.13430405], [72.01013947, 21.13430977], [72.01013947, 21.13375282], [72.00958252, 21.13375282], [72.00958252, 21.13347054], [72.00875092, 21.13347054], [72.00875092, 21.1329174], [72.00818634, 21.13292122], [72.00818634, 21.13264275], [72.00763702, 21.13264275], [72.00763702, 21.13292122], [72.00736237, 21.1329174], [72.00736237, 21.13319206], [72.00708008, 21.13319016], [72.00708008, 21.13402939], [72.00624847, 21.13402748], [72.00624847, 21.13458443], [72.00596619, 21.13458061], [72.00596619, 21.1348629], [72.00624847, 21.1348629], [72.00624847, 21.13598061], [72.00680542, 21.13597488], [72.00680542, 21.13624954], [72.00708008, 21.13624954], [72.00708008, 21.13680077], [72.00736237, 21.13680649], [72.00736237, 21.13736153], [72.00708008, 21.13735962], [72.00708008, 21.13764], [72.00596619, 21.13764], [72.00596619, 21.13735962], [72.00541687, 21.13736153], [72.00541687, 21.13680649], [72.00485992, 21.1368103], [72.00485992, 21.13652992], [72.0032196, 21.13652992], [72.00318909, 21.1368103], [72.00263977, 21.13680649], [72.00263977, 21.13708305], [72.00235748, 21.13708305], [72.00235748, 21.1384716], [72.00263977, 21.1384697], [72.00263977, 21.13931084], [72.00289917, 21.13931084], [72.00291443, 21.13986015], [72.00357056, 21.13986015], [72.00430298, 21.13986206], [72.00430298, 21.14097214], [72.00374603, 21.14097023], [72.00373077, 21.14152908], [72.00208282, 21.14152908], [72.00208282, 21.14180756], [72.00041962, 21.14180756], [72.00041962, 21.14152908], [71.99986267, 21.14152908], [71.99986267, 21.14125061], [71.99846649, 21.14125061], [71.99846649, 21.14152908], [71.99791718, 21.14152908], [71.99791718, 21.14180756], [71.99736023, 21.14180565], [71.99736023, 21.14208412], [71.99708557, 21.14208412], [71.99708557, 21.14680481], [71.99680328, 21.14680481], [71.99680328, 21.14736366], [71.9970932, 21.14735985], [71.9970932, 21.14792061], [71.99736023, 21.14792061], [71.99736023, 21.14821053], [71.99764252, 21.14821053], [71.99764252, 21.14792061], [71.99874878, 21.14792061], [71.99874878, 21.14821053], [71.99903107, 21.14819527], [71.99903107, 21.14882088], [71.99903107, 21.1506958], [71.99930573, 21.1506958], [71.99930573, 21.15236092], [71.99958038, 21.15236092], [71.99958038, 21.1534729], [72.0, 21.1534729], [72.00041962, 21.1534729], [72.00041962, 21.15319443], [72.00069427, 21.15319443], [72.00069427, 21.15291786], [72.00125122, 21.15291786], [72.00125122, 21.1534729], [72.00180817, 21.15347099], [72.00180817, 21.15374947], [72.00235748, 21.15374947], [72.00235748, 21.15291977], [72.00289917, 21.15291977], [72.00289917, 21.15263939], [72.00347137, 21.15263939], [72.00347137, 21.15236092], [72.00430298, 21.15236092], [72.00430298, 21.15263939], [72.0045929, 21.15263939], [72.0045929, 21.15291977], [72.00485992, 21.15291786], [72.00485992, 21.15319443], [72.00514221, 21.15319061], [72.00514221, 21.15374947], [72.00541687, 21.15374947], [72.00541687, 21.15458298], [72.00569153, 21.15458298], [72.00569153, 21.15486145], [72.00624847, 21.15485954], [72.00624847, 21.15513992], [72.00653076, 21.15513992], [72.00653076, 21.1554184], [72.00708008, 21.1554184], [72.00708008, 21.15570068], [72.00736237, 21.15569496], [72.00736237, 21.15597153], [72.00791931, 21.15596962], [72.00791931, 21.15624809], [72.00846863, 21.15624809], [72.00846863, 21.15681076], [72.00875092, 21.15680504], [72.00875092, 21.15736008], [72.0090332, 21.15735817], [72.0090332, 21.15792274], [72.00875092, 21.15791702], [72.00875092, 21.15819359], [72.00846863, 21.15819359], [72.00846863, 21.15847015], [72.00818634, 21.15847015], [72.00818634, 21.15875053], [72.00791931, 21.15875053], [72.00791931, 21.15903282], [72.00736237, 21.1590271], [72.00736237, 21.15958214], [72.00653076, 21.15958023], [72.00653076, 21.15986061], [72.00624847, 21.15986061], [72.00624847, 21.16060066], [72.00624847, 21.16125107], [72.00653076, 21.16124916], [72.00653076, 21.1614418], [72.00653076, 21.16152763], [72.00680542, 21.16152763], [72.00680542, 21.16208458], [72.00736237, 21.16208076], [72.00736237, 21.16236115], [72.00846863, 21.16236115], [72.00846863, 21.16263962], [72.0090332, 21.16263962], [72.0090332, 21.16292], [72.00930786, 21.16291428], [72.00930786, 21.16319466], [72.00986481, 21.16319466], [72.00986481, 21.16347313], [72.01069641, 21.16347122], [72.01069641, 21.16374969], [72.01097107, 21.16374969], [72.01097107, 21.16403008], [72.01208496, 21.16402817], [72.01208496, 21.16430664], [72.01235962, 21.16430664], [72.01235962, 21.16458321], [72.01374817, 21.16458321], [72.01374817, 21.16486168], [72.01430511, 21.16486168], [72.01430511, 21.16597176], [72.01457977, 21.16596031], [72.01457977, 21.16764069], [72.01430511, 21.16763878], [72.01430511, 21.16819382], [72.01208496, 21.16819382], [72.01208496, 21.16847229], [72.01180267, 21.16847038], [72.01180267, 21.17013931], [72.01208496, 21.17013931], [72.01208496, 21.17069435], [72.01235962, 21.17069435], [72.01235962, 21.17080116], [72.01235962, 21.17097282], [72.01264954, 21.17095947], [72.01264191, 21.17124939], [72.01319885, 21.17123985], [72.01319122, 21.17153168], [72.0137558, 21.17152786], [72.01403046, 21.17153168], [72.01403046, 21.17124939], [72.01486206, 21.17124939], [72.01486206, 21.17097092], [72.01513672, 21.17097282], [72.01513672, 21.17069435], [72.01541901, 21.17069435], [72.01541901, 21.17041588], [72.01597595, 21.17041588], [72.01597595, 21.17069435], [72.01680756, 21.17069054], [72.01680756, 21.17124939], [72.01708221, 21.17124939], [72.01708221, 21.17181015], [72.0173645, 21.17180634], [72.0173645, 21.17236137], [72.01763916, 21.17235947], [72.01763916, 21.17292023], [72.01791382, 21.17291641], [72.01791382, 21.17319489], [72.01818848, 21.17319107], [72.01818848, 21.17374992], [72.01847076, 21.17374992], [72.01847076, 21.17430305], [72.01856995, 21.17431068], [72.01875305, 21.17430305], [72.01875305, 21.17443275], [72.01875305, 21.17542076], [72.01902771, 21.17541695], [72.01902771, 21.17569542], [72.01930237, 21.1756897], [72.01930237, 21.17625046], [72.01985931, 21.17625046], [72.01985931, 21.17653084], [72.0201416, 21.17653084], [72.0201416, 21.17681122], [72.02041626, 21.1768055], [72.02041626, 21.17708588], [72.02097321, 21.17708015], [72.02097321, 21.17791939], [72.02153015, 21.17791748], [72.02153015, 21.17847252], [72.02179718, 21.17847061], [72.02179718, 21.17875099], [72.0220871, 21.17875099], [72.0220871, 21.17902946], [72.02319336, 21.17902756], [72.02319336, 21.1795826], [72.02347565, 21.1795826], [72.02347565, 21.17986107], [72.02375031, 21.17986107], [72.02375031, 21.18097305], [72.02348328, 21.1809597], [72.02348328, 21.18152809], [72.0229187, 21.18152809], [72.0229187, 21.18180466], [72.02180481, 21.18180466], [72.02180481, 21.18208313], [72.02153015, 21.18208122], [72.02153015, 21.18263817], [72.0220871, 21.18263817], [72.0220871, 21.18374825], [72.02124786, 21.18374825], [72.02124786, 21.18347168], [72.02069092, 21.18346977], [72.02069092, 21.18432045], [72.02124786, 21.18430519], [72.02126312, 21.18486023], [72.02097321, 21.18486023], [72.02097321, 21.1854229], [72.02069092, 21.1854229], [72.02069092, 21.18653107], [72.02041626, 21.18653107], [72.02041626, 21.18680954], [72.01847076, 21.18680954], [72.01847076, 21.18736076], [72.01819611, 21.18736076], [72.01819611, 21.18819237], [72.01763916, 21.18819237], [72.01763916, 21.1879158], [72.01735687, 21.18791962], [72.01735687, 21.18764114], [72.01708221, 21.18764114], [72.01708221, 21.18708992], [72.01680756, 21.18708992], [72.01680756, 21.18625259], [72.01652527, 21.18625259], [72.01652527, 21.18597031], [72.01512909, 21.18597031], [72.01512909, 21.18708992], [72.01457977, 21.18708992], [72.01457977, 21.18680954], [72.01431274, 21.18680954], [72.01431274, 21.18653107], [72.01374817, 21.18653107], [72.01374817, 21.18625259], [72.01346588, 21.18625259], [72.01346588, 21.18597031], [72.01319122, 21.18597031], [72.01319122, 21.18569374], [72.01235962, 21.18569374], [72.01235962, 21.18541718], [72.01208496, 21.18541718], [72.01208496, 21.18569374], [72.01152802, 21.18569374], [72.01152802, 21.18597031], [72.01069641, 21.18597031], [72.01069641, 21.18541718], [72.01040649, 21.1854229], [72.01040649, 21.18486023], [72.01013947, 21.18486023], [72.01013947, 21.18320084], [72.01040649, 21.18320084], [72.01040649, 21.18291855], [72.01013947, 21.18291855], [72.01013947, 21.18208122], [72.00902557, 21.18208313], [72.00902557, 21.1823616], [72.00875092, 21.1823597], [72.00875092, 21.18263817], [72.00818634, 21.18263817], [72.00818634, 21.1823597], [72.00791931, 21.1823616], [72.00791931, 21.18208313], [72.00763702, 21.18208313], [72.00763702, 21.18180466], [72.00736237, 21.18180466], [72.00736237, 21.18152809], [72.00708008, 21.18152809], [72.00708008, 21.18124962], [72.00680542, 21.18124962], [72.00680542, 21.18097305], [72.00624847, 21.18097305], [72.00624847, 21.18069458], [72.00541687, 21.18069458], [72.00541687, 21.18097305], [72.00402832, 21.18097305], [72.00402832, 21.18013954], [72.00374603, 21.18013954], [72.00374603, 21.17930984], [72.00402832, 21.17930984], [72.00402832, 21.17875099], [72.00430298, 21.17875099], [72.00430298, 21.17791939], [72.00402832, 21.17791939], [72.00402832, 21.17764091], [72.00374603, 21.17764091], [72.00374603, 21.17542076], [72.00402832, 21.17542076], [72.00402832, 21.17486], [72.00430298, 21.17486382], [72.00430298, 21.17458153], [72.00485992, 21.17458153], [72.00485992, 21.17374992], [72.00514221, 21.17374992], [72.00514221, 21.17319107], [72.00485992, 21.17319489], [72.00485992, 21.17236137], [72.00458527, 21.17236137], [72.00458527, 21.1720829], [72.00430298, 21.17209053], [72.00430298, 21.17181015], [72.00402832, 21.17181015], [72.00402832, 21.17153168], [72.00374603, 21.17153168], [72.00374603, 21.1690197], [72.00347137, 21.16902733], [72.00347137, 21.16875076], [72.00318909, 21.16875076], [72.00318909, 21.16847038], [72.00291443, 21.16847229], [72.00291443, 21.16819382], [72.00235748, 21.16819382], [72.00235748, 21.16791725], [72.00208282, 21.16791916], [72.00208282, 21.16764069], [72.00180817, 21.16764069], [72.00180817, 21.16707993], [72.00096893, 21.16708374], [72.00096893, 21.16680527], [72.00041962, 21.16681099], [72.00041962, 21.16653061], [71.99986267, 21.16653061], [71.99986267, 21.16625023], [71.99874878, 21.16625023], [71.99874878, 21.16596031], [71.99847412, 21.16597176], [71.99847412, 21.16486168], [71.99736023, 21.16485977], [71.99736023, 21.16542053], [71.99708557, 21.16541672], [71.99708557, 21.16597176], [71.99680328, 21.16596031], [71.99680328, 21.16736031], [71.99652863, 21.16736031], [71.99652863, 21.16764069], [71.99680328, 21.16763878], [71.99680328, 21.16958427], [71.99652863, 21.16958046], [71.99652863, 21.16986084], [71.99597168, 21.16986084], [71.99597168, 21.16958046], [71.99569702, 21.16958427], [71.99569702, 21.16902733], [71.99541473, 21.16902733], [71.99541473, 21.16875076], [71.99514008, 21.16875076], [71.99514008, 21.16931152], [71.99485779, 21.1693058], [71.99485779, 21.16958427], [71.99458313, 21.16958046], [71.99458313, 21.16986084], [71.99402618, 21.16986084], [71.99402618, 21.16958046], [71.99319458, 21.16958427], [71.99319458, 21.1693058], [71.99291992, 21.16931152], [71.99291992, 21.16875076], [71.99318695, 21.16875076], [71.99318695, 21.16847038], [71.99346924, 21.16847229], [71.99346924, 21.16819382], [71.99375153, 21.16819382], [71.99375153, 21.16791725], [71.99430847, 21.16791916], [71.99430847, 21.16736031], [71.99402618, 21.16736031], [71.99402618, 21.16653061], [71.99430847, 21.16653061], [71.99430847, 21.16625023], [71.99569702, 21.16625023], [71.99569702, 21.16570091], [71.99597168, 21.16570091], [71.99597168, 21.16514015], [71.99514008, 21.16514015], [71.99514008, 21.16485977], [71.99485779, 21.16486168], [71.99485779, 21.16458321], [71.99458313, 21.16458321], [71.99458313, 21.16430664], [71.99430847, 21.16430664], [71.99430847, 21.16347313], [71.99458313, 21.16347313], [71.99458313, 21.16263962], [71.99485779, 21.16263962], [71.99485779, 21.16152954], [71.99514008, 21.16152954], [71.99514008, 21.16097069], [71.99458313, 21.1609745], [71.99458313, 21.16069221], [71.99430847, 21.16069221], [71.99430847, 21.16041756], [71.99402618, 21.16041946], [71.99402618, 21.16015053], [71.99375153, 21.16015053], [71.99375153, 21.15986061], [71.99346924, 21.15986061], [71.99346924, 21.15958023], [71.99236298, 21.15958214], [71.99236298, 21.15930557], [71.99097443, 21.15930557], [71.99097443, 21.15958214], [71.99013519, 21.15958214], [71.99013519, 21.15930557], [71.98902893, 21.15930939], [71.98902893, 21.15903282], [71.98847198, 21.15903282], [71.98847198, 21.15875053], [71.98819733, 21.15875053], [71.98819733, 21.15819359], [71.98791504, 21.15819359], [71.98791504, 21.15791702], [71.98764038, 21.15792274], [71.98764038, 21.15764236], [71.98735809, 21.15764236], [71.98735809, 21.15735817], [71.98708344, 21.15736008], [71.98708344, 21.15708351], [71.98671722, 21.15708351], [71.98596954, 21.15708351], [71.98596954, 21.15680504], [71.98568726, 21.15681076], [71.98568726, 21.15624809], [71.98596954, 21.15624809], [71.98596954, 21.15485954], [71.98569489, 21.15486145], [71.98569489, 21.15319443], [71.98596954, 21.15319443], [71.98596954, 21.15291786], [71.98680878, 21.15291786], [71.98680878, 21.15319443], [71.98708344, 21.15319443], [71.98708344, 21.15402794], [71.98680878, 21.15402031], [71.98680878, 21.15430832], [71.98750305, 21.15430832], [71.98958588, 21.15430832], [71.98958588, 21.15402031], [71.98986053, 21.15402794], [71.98986053, 21.15374947], [71.99014282, 21.15374947], [71.99013519, 21.1534729], [71.99041748, 21.1534729], [71.99041748, 21.15319443], [71.99069214, 21.15319443], [71.99069214, 21.15263939], [71.99095917, 21.15263939], [71.99095917, 21.14875031], [71.99124908, 21.14875031], [71.99124908, 21.14792061], [71.99153137, 21.14792061], [71.99153137, 21.14729118], [71.99153137, 21.14708138], [71.99180603, 21.14708138], [71.99180603, 21.14513969], [71.99153137, 21.14513969], [71.99153137, 21.14263916], [71.99124908, 21.14263916], [71.99124908, 21.14236069], [71.99069214, 21.14236069], [71.99069214, 21.14208031], [71.99041748, 21.14208412], [71.99041748, 21.14180565], [71.99014282, 21.14180756], [71.99014282, 21.14152908], [71.98986053, 21.14152908], [71.98986053, 21.14125061], [71.98929596, 21.14125061], [71.98929596, 21.14097023], [71.98874664, 21.14097214], [71.98874664, 21.14069366], [71.98819733, 21.14069366], [71.98819733, 21.1404171], [71.98792267, 21.14042091], [71.98792267, 21.14014053], [71.98764038, 21.14014053], [71.98764038, 21.13986015], [71.98652649, 21.13986015], [71.98652649, 21.14014053], [71.98596954, 21.14014053], [71.98596954, 21.13986015], [71.98569489, 21.13986206], [71.98569489, 21.13930511], [71.98542023, 21.13931084], [71.98542023, 21.13903809], [71.9851532, 21.13903809], [71.9851532, 21.13875008], [71.98486328, 21.13875008], [71.98486328, 21.1384697], [71.98430634, 21.1384716], [71.98430634, 21.13819695], [71.98401642, 21.13820076], [71.98401642, 21.13792038], [71.98319244, 21.13792038], [71.98319244, 21.13764], [71.98179626, 21.13764], [71.98179626, 21.13735962], [71.98124695, 21.13736153], [71.98124695, 21.13708305], [71.98097229, 21.13708305], [71.98097229, 21.13680649], [71.98042297, 21.1368103], [71.98042297, 21.13652992], [71.98014069, 21.13652992], [71.98014069, 21.13624954], [71.97930908, 21.13624954], [71.97930908, 21.13598061], [71.97901917, 21.13598061], [71.97901917, 21.13569069], [71.97875214, 21.1356926], [71.97875214, 21.13541412], [71.97846985, 21.13541985], [71.97846985, 21.13513947], [71.97875214, 21.13513947], [71.97875214, 21.1348629], [71.98041534, 21.1348629], [71.98041534, 21.13513947], [71.98152924, 21.13513947], [71.98152924, 21.13541985], [71.98208618, 21.13541985], [71.98208618, 21.13513947], [71.98236084, 21.13513947], [71.98236084, 21.13541985], [71.98319244, 21.13541985], [71.98319244, 21.13513947], [71.98401642, 21.13513947], [71.98401642, 21.1348629], [71.98486328, 21.1348629], [71.98486328, 21.13458061], [71.98513794, 21.13458443], [71.98513794, 21.13430405], [71.98568726, 21.13430977], [71.98568726, 21.13402939], [71.98596954, 21.13402939], [71.98596954, 21.13347054], [71.98569489, 21.13347054], [71.98569489, 21.13319206], [71.98513794, 21.13319206], [71.98513794, 21.1329174], [71.98486328, 21.13292122], [71.98486328, 21.13264275], [71.98430634, 21.13264275], [71.98430634, 21.13236046], [71.9834671, 21.13236046], [71.9834671, 21.13208008], [71.98291779, 21.13208389], [71.98291779, 21.13180542], [71.98208618, 21.13181114], [71.98208618, 21.13153267], [71.98179626, 21.13153267], [71.98179626, 21.13125038], [71.98097229, 21.13125038], [71.98097229, 21.13097191], [71.98041534, 21.13097191], [71.98042297, 21.13125038], [71.98014069, 21.13125038], [71.98014069, 21.13097191], [71.97901917, 21.13097191], [71.97901917, 21.13125038], [71.9779129, 21.13125038], [71.9779129, 21.13097191], [71.9770813, 21.13097191], [71.9770813, 21.1301384], [71.97680664, 21.1301384], [71.97680664, 21.12985039], [71.97652435, 21.12986183], [71.97652435, 21.12958336], [71.97624969, 21.12958336], [71.97624969, 21.12930489], [71.9751358, 21.12930489], [71.9751358, 21.12902832], [71.97402954, 21.12902832], [71.97402954, 21.12846947], [71.9743042, 21.12847137], [71.9743042, 21.12819481], [71.97486115, 21.12819481], [71.97486115, 21.12847137], [71.97624969, 21.12846947], [71.97624969, 21.12874985], [71.97680664, 21.12874985], [71.97680664, 21.12846947], [71.9770813, 21.12847137], [71.9770813, 21.12791634], [71.97680664, 21.12791824], [71.97680664, 21.12763977], [71.97651672, 21.12763977], [71.97651672, 21.12735939], [71.97597504, 21.1273613], [71.97597504, 21.12708282], [71.97569275, 21.12708282], [71.97569275, 21.12652779], [71.97541809, 21.12652969], [71.97541809, 21.12597084], [71.9751358, 21.12597275], [71.9751358, 21.12541771], [71.97458649, 21.12541962], [71.97458649, 21.12514114], [71.9751358, 21.12514114], [71.9751358, 21.12486076], [71.97680664, 21.12486076], [71.97680664, 21.12458038], [71.9770813, 21.1245842], [71.9770813, 21.12402725], [71.97735596, 21.1240406], [71.97735596, 21.12430954], [71.97763824, 21.12430954], [71.97763824, 21.1240406], [71.9779129, 21.1240406], [71.9779129, 21.12375069], [71.97820282, 21.12375069], [71.97819519, 21.12291718], [71.9779129, 21.12292099], [71.9779129, 21.12236023], [71.97763824, 21.12236023], [71.97763824, 21.12207985], [71.97736359, 21.12208557], [71.97736359, 21.12180328], [71.9770813, 21.12181091], [71.9770813, 21.12153053], [71.97680664, 21.12153053], [71.97680664, 21.12096977], [71.9743042, 21.12097359], [71.9743042, 21.12069321], [71.97374725, 21.12070084], [71.97374725, 21.12042046], [71.9715271, 21.12042046], [71.9715271, 21.12070084], [71.97125244, 21.12069321], [71.97125244, 21.12097359], [71.97041321, 21.12097359], [71.97041321, 21.12069321], [71.97013855, 21.12069321], [71.97013855, 21.12097359], [71.96985626, 21.12096977], [71.96985626, 21.12125015], [71.9695816, 21.12125015], [71.9695816, 21.12153053], [71.96985626, 21.12153053], [71.96985626, 21.12181091], [71.97013855, 21.12180328], [71.97013855, 21.12236023], [71.97041321, 21.12236023], [71.97041321, 21.12264061], [71.97097015, 21.12264061], [71.97097015, 21.12292099], [71.97125244, 21.12291718], [71.97125244, 21.12319565], [71.9706955, 21.12319565], [71.9706955, 21.12291718], [71.97014618, 21.12292099], [71.97014618, 21.12264061], [71.96985626, 21.12264061], [71.96985626, 21.12236023], [71.96930695, 21.12236023], [71.96930695, 21.12207985], [71.96902466, 21.12208557], [71.96902466, 21.12180328], [71.96848297, 21.12181091], [71.96848297, 21.12153053], [71.96736145, 21.12153053], [71.96736145, 21.12181091], [71.9668045, 21.12180328], [71.9668045, 21.12208557], [71.96652985, 21.12207985], [71.96652985, 21.12236023], [71.96569824, 21.12236023], [71.96569824, 21.12207985], [71.9659729, 21.12208557], [71.9659729, 21.12097359], [71.96541595, 21.12097359], [71.96541595, 21.12069321], [71.96485901, 21.12070084], [71.96485901, 21.12042046], [71.96430206, 21.12041664], [71.96430206, 21.12097359], [71.96457672, 21.12096977], [71.96457672, 21.12181091], [71.96485901, 21.12181091], [71.96485901, 21.12236023], [71.9651413, 21.12236023], [71.9651413, 21.12264061], [71.9659729, 21.12264061], [71.9659729, 21.12292099], [71.96652985, 21.12291718], [71.96652985, 21.12319565], [71.9651413, 21.12319565], [71.9651413, 21.12347221], [71.96347046, 21.12347031], [71.96347046, 21.12430954], [71.96097565, 21.12430573], [71.96097565, 21.1245842], [71.96013641, 21.1245842], [71.96013641, 21.12430573], [71.95986176, 21.12430954], [71.95986176, 21.12375069], [71.95929718, 21.12375069], [71.95929718, 21.12347031], [71.95847321, 21.12347221], [71.95847321, 21.12319565], [71.95819092, 21.12319565], [71.95819092, 21.12291718], [71.95791626, 21.12292099], [71.95791626, 21.12264061], [71.9576416, 21.12264061], [71.9576416, 21.12236023], [71.95735931, 21.12236023], [71.95735931, 21.12207985], [71.95708466, 21.12208557], [71.95708466, 21.12180328], [71.95680237, 21.12181091], [71.95680237, 21.12153053], [71.95652771, 21.12153053], [71.95652771, 21.12181091], [71.95597076, 21.12180328], [71.95597076, 21.12208557], [71.95569611, 21.12207985], [71.95569611, 21.12236023], [71.95597076, 21.12236023], [71.95597076, 21.12264061], [71.95625305, 21.1226387], [71.95625305, 21.12319565], [71.95513916, 21.12319565], [71.95513916, 21.12291718], [71.9540329, 21.12292099], [71.9540329, 21.12153053], [71.95375061, 21.12153053], [71.95375061, 21.12014008], [71.95347595, 21.12014008], [71.95347595, 21.11958122], [71.95319366, 21.11958122], [71.95319366, 21.11902809], [71.95263672, 21.11903191], [71.95263672, 21.11874962], [71.95207977, 21.11874962], [71.95207977, 21.11846924], [71.95124817, 21.11847115], [71.95124817, 21.11819458], [71.95069122, 21.11819458], [71.95069122, 21.11847115], [71.95041656, 21.11846924], [71.95041656, 21.11874962], [71.94819641, 21.11874962], [71.94819641, 21.11846924], [71.94763947, 21.11847115], [71.94763947, 21.11819458], [71.94708252, 21.11819458], [71.94708252, 21.11791611], [71.94652557, 21.11791611], [71.94652557, 21.11763954], [71.94541931, 21.11763954], [71.94541931, 21.11791611], [71.94458008, 21.11791611], [71.94458008, 21.11819458], [71.94403076, 21.11819077], [71.94403076, 21.12042046], [71.94346619, 21.12042046], [71.94346619, 21.12014008], [71.94319153, 21.12014008], [71.94319153, 21.1198597], [71.94291687, 21.11986351], [71.94291687, 21.11958122], [71.94264221, 21.11958122], [71.94264221, 21.11930466], [71.94235992, 21.11930466], [71.94235992, 21.11902809], [71.9420929, 21.11903191], [71.9420929, 21.11874962], [71.94180298, 21.11874962], [71.94180298, 21.11846924], [71.94152832, 21.11847115], [71.94152832, 21.11791611], [71.94180298, 21.11791611], [71.94180298, 21.11735916], [71.9420929, 21.11735916], [71.94208527, 21.1170826], [71.94180298, 21.1170826], [71.94180298, 21.11680603], [71.94152832, 21.11681175], [71.94152832, 21.11653137], [71.94124603, 21.11653137], [71.94124603, 21.11624908], [71.94069672, 21.11624908], [71.94069672, 21.11597061], [71.94041443, 21.11597252], [71.94041443, 21.11569405], [71.94013977, 21.11569405], [71.94013977, 21.1151371], [71.93846893, 21.11514091], [71.93846893, 21.11541748], [71.93569183, 21.11541748], [71.93569183, 21.11514091], [71.93486023, 21.11514091], [71.93486023, 21.11541748], [71.93319702, 21.11541748], [71.93319702, 21.11514091], [71.93264008, 21.11514091], [71.93264008, 21.11541748], [71.93235779, 21.11541748], [71.93235779, 21.11597252], [71.93180847, 21.11597252], [71.93180847, 21.11458397], [71.93041992, 21.11458397], [71.93041992, 21.1143055], [71.93013763, 21.11431122], [71.93013763, 21.11403084], [71.92986298, 21.11403084], [71.92986298, 21.11431122], [71.92930603, 21.1143055], [71.92930603, 21.11458397], [71.92847443, 21.11458397], [71.92847443, 21.11319542], [71.92819214, 21.1131897], [71.92819214, 21.11263847], [71.92708588, 21.11264038], [71.92708588, 21.11207962], [71.92680359, 21.11208344], [71.92680359, 21.11180687], [71.92652893, 21.11181068], [71.92652893, 21.11124992], [71.92624664, 21.11124992], [71.92624664, 21.11096954], [71.92569733, 21.11096954], [71.92569733, 21.11124992], [71.92542267, 21.11124992], [71.92542267, 21.1115303], [71.92457581, 21.1115303], [71.92457581, 21.11124992], [71.92430878, 21.11124992], [71.92430878, 21.11096954], [71.92402649, 21.11096954], [71.92402649, 21.11124992], [71.92375183, 21.11124992], [71.92375183, 21.1115303], [71.92208099, 21.1115303], [71.92208099, 21.11181068], [71.9201355, 21.11180687], [71.9201355, 21.11208344], [71.91986084, 21.11207962], [71.91986084, 21.11264038], [71.91958618, 21.11264038], [71.91958618, 21.11292076], [71.91902924, 21.11292076], [71.91902924, 21.11264038], [71.91873932, 21.11264038], [71.91873932, 21.11236], [71.91847229, 21.11236191], [71.91847229, 21.11208344], [71.91596985, 21.11208344], [71.91596985, 21.11180687], [71.91570282, 21.11181068], [71.91570282, 21.1115303], [71.91513824, 21.1115303], [71.91513824, 21.11124992], [71.91485596, 21.11124992], [71.91485596, 21.11096954], [71.91430664, 21.11097145], [71.91430664, 21.11069679], [71.91402435, 21.11069679], [71.91402435, 21.11041641], [71.91319275, 21.11041641], [71.91319275, 21.11069679], [71.90958405, 21.11069679], [71.90958405, 21.11041641], [71.9090271, 21.11042023], [71.9090271, 21.11013985], [71.90847015, 21.11013985], [71.90847015, 21.10985947], [71.90763855, 21.10986137], [71.90763855, 21.10958481], [71.90680695, 21.10958481], [71.90680695, 21.10930634], [71.90402985, 21.10931015], [71.90402985, 21.10902977], [71.9034729, 21.10902977], [71.9034729, 21.10874939], [71.90319824, 21.10874939], [71.90319061, 21.10847092], [71.90097046, 21.10847092], [71.90097046, 21.10902977], [71.9006958, 21.10902977], [71.9006958, 21.10931015], [71.89930725, 21.10931015], [71.89930725, 21.10902977], [71.89903259, 21.10902977], [71.89903259, 21.10847092], [71.89875031, 21.10847473], [71.89875031, 21.10819244], [71.89847565, 21.10819244], [71.89847565, 21.10736275], [71.89819336, 21.10736275], [71.89819336, 21.10680962], [71.89792633, 21.10680962], [71.89792633, 21.10653114], [71.89763641, 21.10653114], [71.89763641, 21.10625267], [71.89736176, 21.10625267], [71.89736176, 21.10597038], [71.89680481, 21.10597038], [71.89680481, 21.10569382], [71.89569092, 21.10569382], [71.89569092, 21.10541725], [71.89541626, 21.10542107], [71.89541626, 21.10514259], [71.8951416, 21.10514259], [71.8951416, 21.10486031], [71.89430237, 21.10486031], [71.89430237, 21.10458183], [71.89402771, 21.10458374], [71.89402771, 21.10430527], [71.89375305, 21.1043129], [71.89375305, 21.10403252], [71.89263916, 21.10403252], [71.89263916, 21.10374832], [71.89125061, 21.10374832], [71.89125061, 21.10346985], [71.89097595, 21.10347176], [71.89097595, 21.10291672], [71.89069366, 21.10291672], [71.89069366, 21.10263824], [71.89041901, 21.10263824], [71.89041901, 21.10235977], [71.88986206, 21.10236168], [71.88986206, 21.10208321], [71.88903046, 21.10208321], [71.88903046, 21.10180473], [71.88874817, 21.10180473], [71.88874817, 21.10152817], [71.88846588, 21.10152817], [71.88846588, 21.10069084], [71.88819122, 21.10069466], [71.88819122, 21.10013962], [71.88791656, 21.10013962], [71.88791656, 21.09847069], [71.88764191, 21.0984726], [71.88764191, 21.09819412], [71.88735962, 21.09819412], [71.88735962, 21.09791756], [71.88709259, 21.09791946], [71.88709259, 21.09764099], [71.88680267, 21.09764099], [71.88680267, 21.09736061], [71.88652802, 21.09736061], [71.88652802, 21.09708023], [71.88625336, 21.09708595], [71.88625336, 21.09680557], [71.88597107, 21.09680939], [71.88597107, 21.09653091], [71.88569641, 21.09653091], [71.88569641, 21.09597015], [71.88541412, 21.09597206], [71.88541412, 21.09513855], [71.88513947, 21.09514046], [71.88513947, 21.0945797], [71.88486481, 21.0945816], [71.88486481, 21.09430313], [71.88430786, 21.09431076], [71.88430786, 21.09403038], [71.88375092, 21.09403038], [71.88375092, 21.09374046], [71.88346863, 21.09375191], [71.88346863, 21.09347153], [71.88291931, 21.09347153], [71.88291931, 21.09319305], [71.88236237, 21.09320068], [71.88236237, 21.0929203], [71.88208008, 21.0929203], [71.88208008, 21.09235954], [71.88153076, 21.09236336], [71.88153076, 21.09208107], [71.88124847, 21.09208107], [71.88124847, 21.09180641], [71.88069153, 21.09181023], [71.88069153, 21.09153175], [71.88041687, 21.09153175], [71.88041687, 21.09096909], [71.88014221, 21.0909729], [71.88014221, 21.09041595], [71.87985992, 21.09042168], [71.87985992, 21.09013939], [71.87958527, 21.09013939], [71.87958527, 21.08986092], [71.87902832, 21.08986092], [71.87902832, 21.08958054], [71.87819672, 21.08958244], [71.87819672, 21.08930588], [71.87652588, 21.0893116], [71.87652588, 21.08902931], [71.87625122, 21.08902931], [71.87625122, 21.08875084], [71.87596893, 21.08875084], [71.87596893, 21.08847046], [71.87458038, 21.08847046], [71.87458038, 21.08902931], [71.87430573, 21.0890274], [71.87431335, 21.08986092], [71.87403107, 21.08986092], [71.87403107, 21.09013939], [71.86958313, 21.09013939], [71.86958313, 21.08958054], [71.86985779, 21.08958244], [71.86985779, 21.08930588], [71.87014008, 21.0893116], [71.87014008, 21.08902931], [71.8704071, 21.08902931], [71.8704071, 21.08875084], [71.87014008, 21.08875084], [71.87014008, 21.08847046], [71.86958313, 21.08847237], [71.86958313, 21.08819389], [71.86902618, 21.08819389], [71.86902618, 21.08791733], [71.86875153, 21.08793068], [71.86875153, 21.08764076], [71.86846924, 21.08764076], [71.86846924, 21.08708], [71.86819458, 21.08708382], [71.86819458, 21.08597183], [71.86791992, 21.08596992], [71.86791992, 21.08625031], [71.86763, 21.08625031], [71.86763, 21.08653069], [71.86680603, 21.08653069], [71.86680603, 21.08681107], [71.86374664, 21.08681107], [71.86374664, 21.08653069], [71.86319733, 21.08653069], [71.86319733, 21.08625031], [71.86291504, 21.08625031], [71.86291504, 21.08597183], [71.86264038, 21.08597183], [71.86264038, 21.08569527], [71.86152649, 21.08570099], [71.86152649, 21.08542061], [71.86068726, 21.08542061], [71.86068726, 21.08514023], [71.86042023, 21.08514023], [71.86042023, 21.08486938], [71.85986328, 21.08486938], [71.85986328, 21.08457947], [71.85930634, 21.08458328], [71.85930634, 21.08430672], [71.85902405, 21.08430672], [71.85902405, 21.08402824], [71.85875702, 21.08403015], [71.85875702, 21.08374977], [71.8584671, 21.08374977], [71.8584671, 21.08346939], [71.85819244, 21.0834713], [71.85819244, 21.08319664], [71.85791779, 21.08319664], [71.85791779, 21.08291626], [71.85764313, 21.08292007], [71.85764313, 21.08263969], [71.85736084, 21.08263969], [71.85736084, 21.08236122], [71.85708618, 21.08236122], [71.85708618, 21.08125114], [71.85652924, 21.08125114], [71.85652924, 21.08097076], [71.85588837, 21.08097076], [71.85569, 21.08097076], [71.85569, 21.08125114], [71.8548584, 21.08125114], [71.8548584, 21.08097076], [71.85458374, 21.08097458], [71.85458374, 21.08069229], [71.85402679, 21.08069229], [71.85402679, 21.08041763], [71.85320282, 21.08041954], [71.85320282, 21.08014107], [71.85263062, 21.08014107], [71.85263062, 21.07986069], [71.85235596, 21.07986069], [71.85235596, 21.07958031], [71.8520813, 21.07958221], [71.8520813, 21.07930565], [71.85180664, 21.07930946], [71.85180664, 21.0790329], [71.85151672, 21.0790329], [71.85151672, 21.07873917], [71.85124969, 21.07875252], [71.85124969, 21.07847023], [71.85097504, 21.07847023], [71.85097504, 21.07819366], [71.85069275, 21.07819366], [71.85069275, 21.07763863], [71.85041809, 21.07764244], [71.85041809, 21.07736015], [71.84986115, 21.07736015], [71.84986115, 21.07708359], [71.84958649, 21.07708359], [71.84958649, 21.07680511], [71.84929657, 21.07681084], [71.84929657, 21.07652855], [71.84812164, 21.07652855], [71.84680939, 21.07652855], [71.84680939, 21.07708359], [71.84708405, 21.07708359], [71.84707642, 21.07767105], [71.84707642, 21.07792282], [71.8473587, 21.0779171], [71.8473587, 21.07847023], [71.84486389, 21.07847023], [71.84486389, 21.07811928], [71.84486389, 21.0779171], [71.84263611, 21.07792282], [71.84263611, 21.07764244], [71.84236145, 21.07764244], [71.84236145, 21.07736015], [71.84208679, 21.07736015], [71.84208679, 21.07708359], [71.8409729, 21.07708359], [71.8409729, 21.07652855], [71.84124756, 21.07652855], [71.84124756, 21.07624817], [71.84208679, 21.07624817], [71.84208679, 21.07485962], [71.84179688, 21.07485962], [71.84179688, 21.07513809], [71.83930206, 21.07513809], [71.83930206, 21.07485962], [71.83875275, 21.07486153], [71.83875275, 21.07458305], [71.83847046, 21.07458305], [71.83847046, 21.07430649], [71.8381958, 21.0743103], [71.8381958, 21.07374954], [71.83790588, 21.07374954], [71.83790588, 21.07347107], [71.83735657, 21.07347107], [71.8373642, 21.07374954], [71.83652496, 21.07374954], [71.83652496, 21.07347298], [71.83625031, 21.07347298], [71.83625031, 21.0731945], [71.83597565, 21.0731945], [71.83597565, 21.07291794], [71.83569336, 21.07292747], [71.83569336, 21.07263947], [71.83235931, 21.07263947], [71.83235931, 21.07236099], [71.83207703, 21.07236099], [71.83207703, 21.07208061], [71.83180237, 21.07208252], [71.83180237, 21.07180786], [71.83125305, 21.07180977], [71.83125305, 21.07152939], [71.83069611, 21.07152939], [71.83069611, 21.07125092], [71.83040619, 21.07125092], [71.83040619, 21.07097054], [71.83013916, 21.07097244], [71.83013916, 21.07069588], [71.82958221, 21.07069588], [71.82958221, 21.0704174], [71.82930756, 21.07042122], [71.82930756, 21.07014084], [71.82875061, 21.07014084], [71.82875061, 21.06986046], [71.82847595, 21.06986046], [71.82847595, 21.06957054], [71.82819366, 21.0695858], [71.82819366, 21.06930542], [71.82736206, 21.06931114], [71.82736206, 21.06903076], [71.82569122, 21.06903076], [71.82569122, 21.06875038], [71.82458496, 21.06875038], [71.82458496, 21.06847382], [71.82375336, 21.06847382], [71.82375336, 21.06819534], [71.82319641, 21.06820107], [71.82319641, 21.06875038], [71.82347107, 21.06875038], [71.82347107, 21.07014084], [71.82319641, 21.07014084], [71.82319641, 21.07042122], [71.82291412, 21.0704174], [71.82291412, 21.07069588], [71.82236481, 21.07069588], [71.82236481, 21.07097244], [71.82208252, 21.07097054], [71.82208252, 21.07152939], [71.82180786, 21.07152939], [71.82180786, 21.07180977], [71.82152557, 21.07180786], [71.82152557, 21.07208252], [71.82096863, 21.07208252], [71.82096863, 21.07180786], [71.82069397, 21.07180786], [71.82069397, 21.07208252], [71.81986237, 21.07208252], [71.81986237, 21.07180786], [71.81958008, 21.07180977], [71.81958008, 21.07152939], [71.81903076, 21.07152939], [71.81903076, 21.07125092], [71.81874847, 21.07125092], [71.81874847, 21.07097054], [71.81819153, 21.07097244], [71.81819153, 21.07069588], [71.81791687, 21.07069588], [71.81791687, 21.0704174], [71.81764221, 21.07042122], [71.81764221, 21.07014084], [71.81735992, 21.07014084], [71.81735992, 21.06986046], [71.81708527, 21.06986046], [71.81708527, 21.0695858], [71.81652832, 21.0695858], [71.81652832, 21.06930542], [71.81513977, 21.06931114], [71.81513977, 21.06903076], [71.81430817, 21.06903076], [71.81430817, 21.06875038], [71.81375122, 21.06875038], [71.81375122, 21.06847], [71.81343842, 21.06847382], [71.81319427, 21.06847382], [71.81319427, 21.06819534], [71.81263733, 21.06820107], [71.81263733, 21.06792068], [71.81208038, 21.06792068], [71.81208038, 21.0676403], [71.81153107, 21.0676403], [71.81153107, 21.06735992], [71.81124878, 21.06736374], [71.81124878, 21.06708145], [71.81097412, 21.06708145], [71.81097412, 21.06680489], [71.81041718, 21.06680489], [71.81041718, 21.06652832], [71.80986023, 21.06653023], [71.80986023, 21.06624985], [71.80902863, 21.06624985], [71.80902863, 21.0656929], [71.80874634, 21.06569481], [71.80874634, 21.06541634], [71.80819702, 21.06542015], [71.80819702, 21.06514168], [71.80764008, 21.06514168], [71.80764008, 21.06485939], [71.80735779, 21.06485939], [71.80735779, 21.06458282], [71.80708313, 21.06458282], [71.80708313, 21.06430626], [71.80680847, 21.06431007], [71.80680847, 21.0640316], [71.80652618, 21.0640316], [71.80652618, 21.06376266], [71.80568695, 21.06376266], [71.80568695, 21.0640316], [71.80486298, 21.0640316], [71.80486298, 21.06376266], [71.80403137, 21.06376266], [71.80403137, 21.06347084], [71.80347443, 21.06347275], [71.80347443, 21.06319427], [71.80263519, 21.06319427], [71.80263519, 21.0629158], [71.80208588, 21.06292152], [71.80208588, 21.06263924], [71.80179596, 21.06263924], [71.80179596, 21.06236076], [71.80152893, 21.06236076], [71.80152893, 21.0620842], [71.80124664, 21.0620842], [71.80124664, 21.06180573], [71.80069733, 21.06180763], [71.80069733, 21.06152916], [71.80042267, 21.06152916], [71.80042267, 21.06125069], [71.80014038, 21.06125069], [71.80014038, 21.06069946], [71.79985809, 21.06069946], [71.79985809, 21.06041908], [71.79957581, 21.06041908], [71.79957581, 21.06014061], [71.79930878, 21.06014061], [71.79930878, 21.05986023], [71.79902649, 21.05986023], [71.79902649, 21.05957985], [71.79875183, 21.05958366], [71.79875183, 21.05930519], [71.79847717, 21.05931091], [71.79847717, 21.05903053], [71.79818726, 21.05903053], [71.79818726, 21.05875015], [71.79763794, 21.05875015], [71.79763794, 21.05846977], [71.79736328, 21.05847168], [71.79736328, 21.05819511], [71.79708099, 21.05820084], [71.79708099, 21.05792046], [71.79680634, 21.05792046], [71.79680634, 21.05708122], [71.79708099, 21.05708313], [71.79708099, 21.05652809], [71.79736328, 21.05653], [71.79736328, 21.05597115], [71.79708099, 21.05597305], [71.79708099, 21.05513954], [71.79680634, 21.05513954], [71.79680634, 21.05486107], [71.79651642, 21.05486107], [71.79651642, 21.05430984], [71.79624939, 21.05430984], [71.79624939, 21.05319023], [71.79652405, 21.05319214], [71.79652405, 21.05291748], [71.79708099, 21.05291748], [71.79708099, 21.05319214], [71.79736328, 21.05319214], [71.79736328, 21.05291748], [71.79763794, 21.05291939], [71.79763794, 21.05264282], [71.79792023, 21.05264282], [71.79792023, 21.05208015], [71.79819489, 21.05208206], [71.79819489, 21.0518055], [71.79902649, 21.05182076], [71.79902649, 21.05153275], [71.79930878, 21.05153275], [71.79930878, 21.05097008], [71.79958344, 21.05097008], [71.79958344, 21.05069351], [71.79985809, 21.05069351], [71.79985809, 21.05041695], [71.80014038, 21.05042267], [71.80014038, 21.04875946], [71.80042267, 21.04875946], [71.80042267, 21.04819107], [71.80069733, 21.04819489], [71.80069733, 21.04801369], [71.80069733, 21.04791641], [71.80108643, 21.04791641], [71.80152893, 21.04791641], [71.80152893, 21.04819489], [71.80236053, 21.04819489], [71.80236053, 21.04757118], [71.80236053, 21.04736137], [71.80263519, 21.04736137], [71.80263519, 21.0470829], [71.80291748, 21.0470829], [71.80291748, 21.04652786], [71.80319214, 21.04652977], [71.80319214, 21.04624939], [71.80263519, 21.04624939], [71.80263519, 21.04597282], [71.80236053, 21.04597282], [71.80236053, 21.04541779], [71.80264282, 21.04541969], [71.80264282, 21.04514122], [71.80291748, 21.04514122], [71.80291748, 21.04486084], [71.8034668, 21.04486084], [71.8034668, 21.04514122], [71.80374908, 21.04514122], [71.80374908, 21.04541969], [71.80403137, 21.04541779], [71.80403137, 21.04569435], [71.80430603, 21.04569435], [71.80430603, 21.0443058], [71.80403137, 21.04430962], [71.80403137, 21.04403114], [71.80374908, 21.04403114], [71.80374908, 21.04319], [71.80403137, 21.04319572], [71.80403137, 21.04291725], [71.80513763, 21.04292107], [71.80513763, 21.04263115], [71.80541992, 21.04263878], [71.80541992, 21.04208565], [71.80569458, 21.04208565], [71.80569458, 21.0415287], [71.80541992, 21.04153061], [71.80541992, 21.04096985], [71.80569458, 21.04097366], [71.80569458, 21.04069519], [71.80625153, 21.04070091], [71.80625153, 21.04014015], [71.80652618, 21.04014015], [71.80652618, 21.03985977], [71.80680847, 21.03986359], [71.80680847, 21.03930473], [71.80652618, 21.03930473], [71.80652618, 21.03902817], [71.80680847, 21.03903008], [71.80680847, 21.03886986], [71.80680847, 21.03791618], [71.80625153, 21.03791618], [71.80625153, 21.03819466], [71.80541992, 21.03819466], [71.80541992, 21.03847122], [71.80486298, 21.03846931], [71.80486298, 21.03874969], [71.80291748, 21.03874969], [71.80291748, 21.03846931], [71.80263519, 21.03847122], [71.80263519, 21.03791618], [71.80236053, 21.03792191], [71.80236053, 21.03764153], [71.80069733, 21.03764153], [71.80069733, 21.03792191], [71.80041504, 21.03791618], [71.80041504, 21.03819466], [71.80014038, 21.03819084], [71.80014038, 21.03874969], [71.79985809, 21.03874969], [71.79985809, 21.03903008], [71.79958344, 21.03902817], [71.79958344, 21.03930473], [71.79875183, 21.03930473], [71.79875183, 21.03902817], [71.79847717, 21.03903008], [71.79847717, 21.03846931], [71.79819489, 21.03847122], [71.79819489, 21.03791618], [71.79651642, 21.03792191], [71.79651642, 21.03764153], [71.79624939, 21.03764153], [71.79624939, 21.03819466], [71.79597473, 21.03819466], [71.79597473, 21.03847122], [71.7951355, 21.03847122], [71.7951355, 21.03819466], [71.79486084, 21.03819466], [71.79486084, 21.03791618], [71.79458618, 21.03792191], [71.79458618, 21.03764153], [71.79429626, 21.03764153], [71.79429626, 21.03735924], [71.79402924, 21.03735924], [71.79402924, 21.03708076], [71.79347229, 21.03708267], [71.79347229, 21.03680611], [71.79264069, 21.03681946], [71.79264069, 21.03653145], [71.79235077, 21.03653145], [71.79235077, 21.03597069], [71.79208374, 21.0359726], [71.79208374, 21.03569412], [71.79180908, 21.03569412], [71.79180908, 21.0359726], [71.79152679, 21.03597069], [71.79152679, 21.03624916], [71.79125214, 21.03624916], [71.79125214, 21.03653145], [71.79069519, 21.03652763], [71.79069519, 21.03764153], [71.79096985, 21.03764153], [71.79096985, 21.03847122], [71.79125214, 21.03846931], [71.79125214, 21.03874969], [71.79152679, 21.03874969], [71.79152679, 21.03930473], [71.79125214, 21.03930283], [71.79125214, 21.03959084], [71.79070282, 21.03959084], [71.79070282, 21.03930283], [71.78985596, 21.03930283], [71.78985596, 21.03959084], [71.7895813, 21.0395813], [71.7895813, 21.03986359], [71.78901672, 21.03985977], [71.78901672, 21.04014015], [71.78874969, 21.04014015], [71.78874969, 21.03985977], [71.78819275, 21.03986359], [71.78819275, 21.0395813], [71.78791809, 21.03959084], [71.78791809, 21.03846931], [71.7876358, 21.03847122], [71.7876358, 21.03819466], [71.78736115, 21.03819466], [71.78736115, 21.03791618], [71.78708649, 21.03792191], [71.78708649, 21.03764153], [71.7859726, 21.03764153], [71.7859726, 21.03847122], [71.78624725, 21.03846931], [71.78624725, 21.03903008], [71.78652954, 21.03902817], [71.78652954, 21.03930473], [71.78679657, 21.03930283], [71.78679657, 21.03959084], [71.78736115, 21.03959084], [71.78736115, 21.04014015], [71.78708649, 21.04014015], [71.78708649, 21.04042053], [71.78624725, 21.04042053], [71.78624725, 21.04014015], [71.7859726, 21.04014015], [71.7859726, 21.03985977], [71.78569794, 21.03986359], [71.78569794, 21.0395813], [71.78542328, 21.03959084], [71.78542328, 21.03930283], [71.78514099, 21.03930473], [71.78514099, 21.03902817], [71.7848587, 21.03903008], [71.7848587, 21.03874969], [71.78430939, 21.03874969], [71.78430176, 21.03903008], [71.78375244, 21.03902817], [71.78375244, 21.03930473], [71.78347015, 21.03930283], [71.78347015, 21.03959084], [71.78291321, 21.03959084], [71.78291321, 21.03930283], [71.78236389, 21.03930473], [71.78236389, 21.03902817], [71.78041077, 21.03903008], [71.78041077, 21.03874969], [71.77986145, 21.03874969], [71.77986145, 21.03846931], [71.77902985, 21.03847122], [71.77902985, 21.03930473], [71.77874756, 21.03930473], [71.77874756, 21.03986359], [71.77819824, 21.03986359], [71.77819061, 21.0395813], [71.77791595, 21.03959084], [71.77791595, 21.03930283], [71.7776413, 21.03930473], [71.7776413, 21.03902817], [71.77735138, 21.03903008], [71.77735138, 21.03819084], [71.7776413, 21.03819466], [71.7776413, 21.03764153], [71.77791595, 21.03764153], [71.77791595, 21.03735924], [71.77819061, 21.03735924], [71.77819824, 21.03681946], [71.7784729, 21.03681946], [71.7784729, 21.03653145], [71.77958679, 21.03653145], [71.77958679, 21.03624916], [71.78041077, 21.03624916], [71.78041077, 21.03597069], [71.78069305, 21.0359726], [71.78069305, 21.03569412], [71.78097534, 21.03569412], [71.78097534, 21.03541756], [71.78125, 21.03541756], [71.78125, 21.03458023], [71.78152466, 21.03458405], [71.78152466, 21.03430557], [71.7820816, 21.03430557], [71.7820816, 21.03458405], [71.78236389, 21.03458405], [71.78236389, 21.0340271], [71.78263855, 21.03403091], [71.78263855, 21.03375053], [71.78291321, 21.03375053], [71.78291321, 21.03264046], [71.78320313, 21.03264046], [71.78320313, 21.03236008], [71.7840271, 21.03236008], [71.7840271, 21.03264046], [71.78542328, 21.03264046], [71.78542328, 21.03292084], [71.78569794, 21.03292084], [71.78569794, 21.03181076], [71.78542328, 21.03181076], [71.78542328, 21.03153038], [71.7848587, 21.03153038], [71.7848587, 21.03125], [71.78430176, 21.03125], [71.78430176, 21.03096962], [71.7840271, 21.03096962], [71.7840271, 21.03125], [71.78347015, 21.03125], [71.78347015, 21.03153038], [71.78263855, 21.03153038], [71.78263855, 21.03125], [71.78235626, 21.03125], [71.78235626, 21.03096962], [71.7820816, 21.03097153], [71.7820816, 21.03069687], [71.78180695, 21.03069687], [71.78180695, 21.03041649], [71.78151703, 21.0304203], [71.78151703, 21.02985954], [71.7804184, 21.02986145], [71.7804184, 21.02958488], [71.77902985, 21.02958488], [71.77902985, 21.02986145], [71.77625275, 21.02986145], [71.77625275, 21.02958488], [71.77597046, 21.02958488], [71.77597046, 21.02930641], [71.7756958, 21.02931023], [71.7756958, 21.02902985], [71.77513885, 21.02902985], [71.77513885, 21.02874947], [71.77153015, 21.02874947], [71.77153015, 21.0284729], [71.77124786, 21.02847481], [71.77124786, 21.02791405], [71.77153015, 21.02791977], [71.77153015, 21.02708054], [71.77124786, 21.02708435], [71.77124786, 21.02680588], [71.76957703, 21.02680969], [71.76957703, 21.02653122], [71.76875305, 21.02653122], [71.76875305, 21.02625275], [71.76847076, 21.02625275], [71.76847076, 21.02597046], [71.76819611, 21.02597046], [71.76819611, 21.02625275], [71.76513672, 21.02625275], [71.76513672, 21.02597046], [71.76457977, 21.02597046], [71.76457977, 21.02569389], [71.76430511, 21.02569389], [71.76430511, 21.02541733], [71.76403046, 21.02542114], [71.76403046, 21.02514267], [71.76374817, 21.02514267], [71.76374817, 21.02319908], [71.76403046, 21.02319908], [71.76403046, 21.02263832], [71.76431274, 21.02263832], [71.76431274, 21.02235985], [71.76457977, 21.02236176], [71.76457977, 21.02180481], [71.76430511, 21.02180481], [71.76430511, 21.02152824], [71.76403046, 21.02152824], [71.76403046, 21.02124977], [71.76319122, 21.02124977], [71.76319122, 21.02096939], [71.76208496, 21.0209713], [71.76208496, 21.02069473], [71.76152802, 21.02069473], [71.76152802, 21.02041626], [71.76069641, 21.02041817], [71.76069641, 21.02013969], [71.75958252, 21.02013969], [71.75958252, 21.02041817], [71.75930786, 21.02041626], [71.75930786, 21.02069473], [71.75644684, 21.02069473], [71.75569153, 21.02069473], [71.75569153, 21.02083969], [71.75569153, 21.0209713], [71.75541687, 21.0209713], [71.75541687, 21.02180481], [71.75514221, 21.02180481], [71.75514221, 21.02208328], [71.75430298, 21.02208328], [71.75430298, 21.02236176], [71.75347137, 21.02235985], [71.75347137, 21.02263832], [71.75319672, 21.02263832], [71.75319672, 21.02292061], [71.75263977, 21.02292061], [71.75263977, 21.02263832], [71.75235748, 21.02263832], [71.75235748, 21.02207947], [71.75208282, 21.02208328], [71.75208282, 21.02180481], [71.75180817, 21.02180481], [71.75180817, 21.02152824], [71.75152588, 21.02152824], [71.75152588, 21.02124977], [71.75125122, 21.02124977], [71.75125122, 21.02069092], [71.75096893, 21.02069473], [71.75096893, 21.02041626], [71.75042725, 21.02041817], [71.75042725, 21.02013969], [71.75013733, 21.02013969], [71.75013733, 21.01986122], [71.74903107, 21.01986122], [71.74903107, 21.02013969], [71.74846649, 21.02013969], [71.74846649, 21.02041817], [71.74791718, 21.02041626], [71.74791718, 21.02069473], [71.74708557, 21.02069473], [71.74708557, 21.02041626], [71.74680328, 21.02041817], [71.74680328, 21.02013969], [71.74652863, 21.02013969], [71.74652863, 21.01986122], [71.74624634, 21.01986122], [71.74624634, 21.01958084], [71.74569702, 21.01958275], [71.74569702, 21.01930618], [71.7454071, 21.01930809], [71.7454071, 21.01902962], [71.74430084, 21.01902962], [71.74430084, 21.01930809], [71.74375153, 21.01930618], [71.74375153, 21.01958275], [71.74346924, 21.01958084], [71.74346924, 21.01986122], [71.74318695, 21.01986122], [71.74318695, 21.02013969], [71.74263763, 21.02013969], [71.74263763, 21.01986122], [71.74236298, 21.01986122], [71.74236298, 21.01958084], [71.74208069, 21.01958275], [71.74208069, 21.01930618], [71.74180603, 21.01930809], [71.74180603, 21.01902962], [71.74153137, 21.01902962], [71.74153137, 21.01819038], [71.74097443, 21.0181942], [71.74097443, 21.01791763], [71.73986053, 21.01791954], [71.73986053, 21.01764107], [71.73929596, 21.01764107], [71.73929596, 21.01736069], [71.73874664, 21.01736069], [71.73874664, 21.01791954], [71.73847198, 21.01791763], [71.73847198, 21.0181942], [71.73819733, 21.0181942], [71.73819733, 21.01847267], [71.73792267, 21.01846123], [71.73792267, 21.01875114], [71.73764038, 21.01875114], [71.73764038, 21.01902962], [71.73735809, 21.01902962], [71.73735809, 21.01930809], [71.73707581, 21.01930809], [71.73707581, 21.01986122], [71.73680878, 21.01986122], [71.73680878, 21.02013969], [71.73667145, 21.02013969], [71.73652649, 21.02013969], [71.73652649, 21.02041817], [71.73625183, 21.02041626], [71.73625183, 21.02069473], [71.73569489, 21.02069473], [71.73569489, 21.02041626], [71.73542786, 21.02041817], [71.73542786, 21.02013969], [71.73430634, 21.02013969], [71.73430634, 21.01986122], [71.73401642, 21.01986122], [71.73401642, 21.01958084], [71.73347473, 21.01958275], [71.73347473, 21.01930618], [71.73319244, 21.01930809], [71.73319244, 21.01902962], [71.73291779, 21.01902962], [71.73291779, 21.01884079], [71.73291779, 21.01874924], [71.73264313, 21.01875114], [71.73264313, 21.01846123], [71.73236084, 21.01847267], [71.73236084, 21.01736069], [71.73041534, 21.01736069], [71.73041534, 21.01708412], [71.73014069, 21.01708412], [71.73014069, 21.01652718], [71.73042297, 21.01653099], [71.73042297, 21.01597023], [71.73014069, 21.01597214], [71.73014069, 21.0154171], [71.7298584, 21.01542091], [71.7298584, 21.01431084], [71.73014069, 21.01431084], [71.73014069, 21.01403046], [71.7298584, 21.01403046], [71.7298584, 21.01375008], [71.72930145, 21.01375008], [71.72930145, 21.0134697], [71.72875214, 21.0134697], [71.72875214, 21.01375008], [71.72846985, 21.01375008], [71.72846985, 21.01431084], [71.72875214, 21.01430321], [71.72875214, 21.01458168], [71.72902679, 21.01457977], [71.72902679, 21.01514053], [71.72875214, 21.01514053], [71.72875214, 21.01542091], [71.7279129, 21.01542091], [71.7279129, 21.01514053], [71.72763824, 21.01514053], [71.72763824, 21.01457977], [71.7270813, 21.01458168], [71.7270813, 21.01486206], [71.72680664, 21.01486015], [71.72680664, 21.01542091], [71.7270813, 21.01542091], [71.7270813, 21.01680946], [71.72736359, 21.01680565], [71.72736359, 21.01692963], [71.72736359, 21.01708412], [71.72763824, 21.01708031], [71.72763824, 21.01791954], [71.7279129, 21.01791954], [71.7279129, 21.01902962], [71.72819519, 21.01902771], [71.72819519, 21.01958275], [71.7279129, 21.01958275], [71.7279129, 21.02069473], [71.72763824, 21.02069473], [71.72763824, 21.0209713], [71.72735596, 21.02096939], [71.72736359, 21.02124977], [71.72625732, 21.02124977], [71.72625732, 21.02152824], [71.72541809, 21.02152824], [71.72541809, 21.02180481], [71.72402954, 21.02180481], [71.72402954, 21.02152824], [71.7223587, 21.02152824], [71.7223587, 21.02180481], [71.7206955, 21.02180481], [71.7206955, 21.02152824], [71.71930695, 21.02152824], [71.71930695, 21.02124977], [71.71875, 21.02124977], [71.71875, 21.02096939], [71.71708679, 21.0209713], [71.71708679, 21.02069473], [71.71624756, 21.02069473], [71.71624756, 21.02041626], [71.7151413, 21.02041817], [71.7151413, 21.02013969], [71.71485901, 21.02013969], [71.71485901, 21.01986122], [71.7140274, 21.01986122], [71.7140274, 21.01958084], [71.71347046, 21.01958275], [71.71347046, 21.01930618], [71.71235657, 21.01930809], [71.71235657, 21.01902962], [71.71180725, 21.01902962], [71.71180725, 21.01875114], [71.71125793, 21.01875114], [71.71125793, 21.01846123], [71.71069336, 21.01847267], [71.71069336, 21.0181942], [71.7104187, 21.0181942], [71.7104187, 21.01791763], [71.70986176, 21.01791954], [71.70986176, 21.01764107], [71.70929718, 21.01764107], [71.70929718, 21.01736069], [71.70874786, 21.01736069], [71.70874786, 21.01708031], [71.70847321, 21.01708412], [71.70847321, 21.01680565], [71.70791626, 21.01680946], [71.70791626, 21.01653099], [71.7076416, 21.01653099], [71.7076416, 21.01625061], [71.70735931, 21.01625061], [71.70735931, 21.01597023], [71.70680237, 21.01597214], [71.70680237, 21.01569557], [71.70652771, 21.01569557], [71.70652771, 21.0154171], [71.70625305, 21.01542091], [71.70625305, 21.01514053], [71.70569611, 21.01514053], [71.70569611, 21.01486015], [71.70541382, 21.01486206], [71.70541382, 21.01458168], [71.70513916, 21.01458168], [71.70513916, 21.01430321], [71.70485687, 21.01431084], [71.70485687, 21.01403046], [71.70430756, 21.01403046], [71.70430756, 21.01375008], [71.70375061, 21.01375008], [71.70375061, 21.0134697], [71.70347595, 21.01347351], [71.70347595, 21.01319313], [71.70318604, 21.01320076], [71.70318604, 21.01292038], [71.70263672, 21.01292038], [71.70263672, 21.01264954], [71.70236206, 21.01264954], [71.70236206, 21.01235962], [71.70180511, 21.01236343], [71.70180511, 21.01208115], [71.70153046, 21.01208115], [71.70153046, 21.01180649], [71.70096588, 21.0118103], [71.70096588, 21.01153183], [71.70069122, 21.01153183], [71.70069122, 21.01124954], [71.70014191, 21.01124954], [71.70014191, 21.01096916], [71.69930267, 21.01097107], [71.69930267, 21.0106945], [71.69875336, 21.0106945], [71.69875336, 21.01013947], [71.69819641, 21.01013947], [71.69819641, 21.00985909], [71.69735718, 21.00985909], [71.69735718, 21.00959015], [71.69680786, 21.00959015], [71.69680786, 21.00931168], [71.6965332, 21.00931168], [71.6965332, 21.0090313], [71.69374847, 21.0090313], [71.69374847, 21.00875092], [71.69235992, 21.00875092], [71.69235992, 21.00847054], [71.69041443, 21.00847244], [71.69041443, 21.00819397], [71.68902588, 21.00819397], [71.68902588, 21.00792122], [71.68846893, 21.00792122], [71.68846893, 21.00764084], [71.68818665, 21.00764084], [71.68818665, 21.00736046], [71.68763733, 21.00736046], [71.68763733, 21.00708008], [71.68736267, 21.00708389], [71.68736267, 21.00680542], [71.68653107, 21.00681114], [71.68653107, 21.00652122], [71.68624878, 21.00652885], [71.68624878, 21.00625038], [71.68596649, 21.00625038], [71.68596649, 21.00597], [71.68514252, 21.00597191], [71.68514252, 21.00569534], [71.6845932, 21.00570107], [71.6845932, 21.00542068], [71.68430328, 21.00542068], [71.68430328, 21.00485992], [71.68374634, 21.00486183], [71.68374634, 21.00458336], [71.68291473, 21.00458336], [71.68291473, 21.00430679], [71.68208313, 21.00430679], [71.68208313, 21.00374985], [71.68180847, 21.00374985], [71.68180847, 21.00319099], [71.68096924, 21.00319672], [71.68096924, 21.00291634], [71.68041992, 21.00292015], [71.68041992, 21.00263977], [71.68013763, 21.00263977], [71.68013763, 21.00235939], [71.67986298, 21.0023613], [71.67986298, 21.00180626], [71.67958069, 21.00181007], [71.67958069, 21.00125122], [71.67930603, 21.00125122], [71.67930603, 21.00069046], [71.67958069, 21.00069237], [71.67958069, 20.99986267], [71.67958069, 20.99930954], [71.67986298, 20.99930954], [71.67986298, 20.99872017], [71.67986298, 20.99791718], [71.67958069, 20.9979229], [71.67958069, 20.99736023], [71.67736053, 20.99736023], [71.67736053, 20.99707985], [71.67680359, 20.99708366], [71.67680359, 20.99680519], [71.67514038, 20.99680519], [71.67514038, 20.99708366], [71.67457581, 20.99707985], [71.67458344, 20.99736023], [71.67436981, 20.99736023], [71.67402649, 20.99736023], [71.67402649, 20.99765015], [71.67346954, 20.99765015], [71.67346954, 20.9979229], [71.67292023, 20.99791718], [71.67292023, 20.99819374], [71.67236328, 20.99819374], [71.67236328, 20.99847031], [71.67180634, 20.99847031], [71.67180634, 20.99875259], [71.67124939, 20.99875259], [71.67124939, 20.99903107], [71.66874695, 20.99903107], [71.66874695, 20.99930954], [71.66499329, 20.99930573], [71.66374969, 20.99930954], [71.66374969, 20.99903107], [71.6609726, 20.99903107], [71.6609726, 20.99875259], [71.65930176, 20.99875259], [71.65930176, 20.99847031], [71.65763855, 20.99847031], [71.65763855, 20.99819374], [71.65569305, 20.99819374], [71.65569305, 20.99791718], [71.65486145, 20.9979229], [71.65486145, 20.99765015], [71.65374756, 20.99765015], [71.65374756, 20.99736023], [71.65291595, 20.99736023], [71.65291595, 20.99707985], [71.65180206, 20.99708366], [71.65180206, 20.99680519], [71.65125275, 20.99681091], [71.65125275, 20.99652863], [71.65040588, 20.99652863], [71.65040588, 20.99624825], [71.64985657, 20.99624825], [71.64985657, 20.99596977], [71.64902496, 20.99597168], [71.64902496, 20.99569511], [71.64848328, 20.99570084], [71.64848328, 20.99542046], [71.64763641, 20.99542046], [71.64763641, 20.99513817], [71.6470871, 20.99513817], [71.6470871, 20.9948597], [71.64653015, 20.9948616], [71.64653015, 20.99458313], [71.64624786, 20.99458313], [71.64624786, 20.99430466], [71.64569092, 20.99430466], [71.64569092, 20.99402618], [71.64541626, 20.99402809], [71.64541626, 20.99374962], [71.64485168, 20.99374962], [71.64485168, 20.99347115], [71.64458466, 20.99347305], [71.64458466, 20.99319458], [71.64402771, 20.99319458], [71.64402771, 20.99291611], [71.64347076, 20.99291992], [71.64347076, 20.99263954], [71.64319611, 20.99263954], [71.64319611, 20.99236107], [71.64263916, 20.99236107], [71.64263916, 20.99208069], [71.6423645, 20.9920826], [71.6423645, 20.99180794], [71.64180756, 20.99180984], [71.64180756, 20.99151993], [71.64152527, 20.99152756], [71.64152527, 20.99124908], [71.64097595, 20.99125099], [71.64097595, 20.99097061], [71.64041901, 20.99097252], [71.64041901, 20.99069595], [71.63986206, 20.99069595], [71.63986206, 20.99041748], [71.63957977, 20.99041939], [71.63957977, 20.99014091], [71.63903809, 20.99014091], [71.63903809, 20.98986053], [71.63846588, 20.98986053], [71.63846588, 20.98903084], [71.63819122, 20.98903084], [71.63819122, 20.98792076], [71.63791656, 20.98792076], [71.63791656, 20.98681068], [71.63764191, 20.98681068], [71.63764191, 20.98569107], [71.63735962, 20.98569489], [71.63735962, 20.9845829], [71.63708496, 20.9845829], [71.63708496, 20.98347282], [71.63680267, 20.98347282], [71.63680267, 20.98291588], [71.63625336, 20.9829216], [71.63625336, 20.98097038], [71.63597107, 20.98097229], [71.63597107, 20.97847176], [71.63625336, 20.97847176], [71.63625336, 20.97791672], [71.63680267, 20.97792053], [71.63680267, 20.97764015], [71.63791656, 20.97764015], [71.63791656, 20.97707939], [71.63819122, 20.97708321], [71.63819122, 20.97680664], [71.63847351, 20.97680664], [71.63847351, 20.97624969], [71.63874817, 20.97624969], [71.63874817, 20.97597122], [71.63847351, 20.97597313], [71.63847351, 20.97569466], [71.63819122, 20.97569466], [71.63819122, 20.97513962], [71.63791656, 20.97513962], [71.63791656, 20.97486115], [71.63764191, 20.97486115], [71.63764191, 20.97458076], [71.63735962, 20.97458458], [71.63735962, 20.97430611], [71.63707733, 20.97430992], [71.63707733, 20.97402954], [71.63680267, 20.97402954], [71.63680267, 20.97375107], [71.63652802, 20.97375107], [71.63652802, 20.97348022], [71.6359787, 20.97348022], [71.6359787, 20.97319031], [71.63513947, 20.97319221], [71.63513947, 20.97291756], [71.63458252, 20.97291946], [71.63458252, 20.9726429], [71.63375092, 20.9726429], [71.63375092, 20.97236061], [71.63318634, 20.97236061], [71.63318634, 20.97208023], [71.63236237, 20.97208214], [71.63236237, 20.97180557], [71.63181305, 20.97180939], [71.63181305, 20.97153282], [71.63096619, 20.97153282], [71.63096619, 20.97125244], [71.63014221, 20.97125244], [71.63014221, 20.97097015], [71.62930298, 20.97097015], [71.62930298, 20.97069359], [71.62847137, 20.97069359], [71.62847137, 20.97013855], [71.62819672, 20.97013855], [71.62819672, 20.9695797], [71.62791443, 20.96958351], [71.62791443, 20.96930504], [71.62652588, 20.96931076], [71.62652588, 20.96902847], [71.62523651, 20.96902847], [71.62513733, 20.96902847], [71.62513733, 20.96874809], [71.62430573, 20.96874809], [71.62430573, 20.96847153], [71.62347412, 20.96847153], [71.62347412, 20.96819496], [71.62291718, 20.96820068], [71.62291718, 20.9679184], [71.6220932, 20.9679184], [71.6220932, 20.96763992], [71.62097168, 20.96763992], [71.62097168, 20.96902847], [71.62069702, 20.96902847], [71.62069702, 20.96958351], [71.62041473, 20.96958351], [71.62041473, 20.96986008], [71.61902618, 20.96986008], [71.61902618, 20.96930504], [71.61875153, 20.96931076], [71.61875153, 20.96902847], [71.61680603, 20.96902847], [71.61680603, 20.96931076], [71.61708069, 20.96931076], [71.61708069, 20.97013855], [71.61736298, 20.97013855], [71.61736298, 20.97069359], [71.61763763, 20.97069359], [71.61763763, 20.97102928], [71.61763763, 20.97125244], [71.61791229, 20.97125244], [71.61791229, 20.97153282], [71.61818695, 20.97153282], [71.61818695, 20.97180939], [71.61846924, 20.97180939], [71.61846924, 20.97236061], [71.61875153, 20.97236061], [71.61875153, 20.97291946], [71.61846924, 20.97291946], [71.61846924, 20.97402954], [71.61819458, 20.97402763], [71.61819458, 20.97458458], [71.61763763, 20.97458076], [71.61763763, 20.97486115], [71.61708069, 20.97486115], [71.61708069, 20.97513962], [71.61653137, 20.97513962], [71.61653137, 20.97542], [71.61597443, 20.97541618], [71.61597443, 20.97569466], [71.61264038, 20.97569466], [71.61264038, 20.97541618], [71.61235809, 20.97542], [71.61235809, 20.97513962], [71.61207581, 20.97513962], [71.61207581, 20.97486115], [71.61180878, 20.97486115], [71.61180878, 20.97458076], [71.61152649, 20.97458458], [71.61152649, 20.97402763], [71.61125183, 20.97402954], [71.61125183, 20.97348022], [71.61096954, 20.97348022], [71.61096954, 20.97291946], [71.61068726, 20.97291946], [71.61068726, 20.97236061], [71.61042023, 20.97236061], [71.61042023, 20.97180939], [71.61013794, 20.97180939], [71.61013794, 20.97153282], [71.61042023, 20.97153282], [71.61042023, 20.97097015], [71.61069489, 20.97097015], [71.61069489, 20.97041702], [71.61096954, 20.97041702], [71.61096954, 20.97013855], [71.61125183, 20.97013855], [71.61125183, 20.9695797], [71.61152649, 20.96958351], [71.61152649, 20.96941948], [71.61152649, 20.96847153], [71.61180878, 20.96847153], [71.61180878, 20.96736145], [71.61125183, 20.96736145], [71.61125183, 20.96708298], [71.61042023, 20.96708298], [71.61042023, 20.96680641], [71.60958099, 20.96681023], [71.60958099, 20.96652985], [71.6084671, 20.96652985], [71.6084671, 20.96624947], [71.60819244, 20.96624947], [71.60819244, 20.96597099], [71.60791779, 20.9659729], [71.60791779, 20.96569443], [71.60736084, 20.96569443], [71.60736084, 20.96541786], [71.60708618, 20.96541977], [71.60708618, 20.96513939], [71.60679626, 20.96513939], [71.60679626, 20.96486092], [71.60457611, 20.96486092], [71.60457611, 20.96458054], [71.60346985, 20.96458244], [71.60346985, 20.96430588], [71.60097504, 20.96430588], [71.60097504, 20.96458244], [71.59999847, 20.96458244], [71.59986115, 20.96458244], [71.59986877, 20.96486092], [71.59902954, 20.96486092], [71.59902954, 20.96708298], [71.59819794, 20.96708298], [71.59819794, 20.96736145], [71.5973587, 20.96736145], [71.5973587, 20.96680641], [71.59707642, 20.96681023], [71.59707642, 20.96652985], [71.59680176, 20.96652985], [71.59680176, 20.96597099], [71.5965271, 20.9659729], [71.5965271, 20.96569443], [71.59625244, 20.96569443], [71.59625244, 20.96513939], [71.59597015, 20.96513939], [71.59597015, 20.96486092], [71.5956955, 20.96486092], [71.5956955, 20.96430588], [71.59541321, 20.96430969], [71.59541321, 20.96403122], [71.59513855, 20.96403122], [71.59513855, 20.96347046], [71.59486389, 20.96347237], [71.59486389, 20.9631958], [71.5945816, 20.9631958], [71.5945816, 20.96263885], [71.59430695, 20.96264076], [71.59430695, 20.96236038], [71.59401703, 20.96236038], [71.59402466, 20.96208], [71.59402466, 20.96180534], [71.59374237, 20.96181107], [71.59374237, 20.96154022], [71.59348297, 20.96154022], [71.59348297, 20.96125031], [71.5929184, 20.96125031], [71.5929184, 20.96096992], [71.59263611, 20.96097374], [71.59263611, 20.96069527], [71.59208679, 20.96070099], [71.59208679, 20.96042061], [71.58911896, 20.96042061], [71.58735657, 20.96042061], [71.58735657, 20.96070099], [71.58680725, 20.96070099], [71.58680725, 20.96042061], [71.58651733, 20.96042061], [71.58651733, 20.96014023], [71.58598328, 20.96014023], [71.58598328, 20.95985985], [71.5854187, 20.95986366], [71.5854187, 20.95969009], [71.5854187, 20.95958138], [71.58513641, 20.95958138], [71.58513641, 20.95930481], [71.58486176, 20.95930481], [71.58486176, 20.95902824], [71.58204651, 20.95903015], [71.58097076, 20.95903015], [71.58097076, 20.95878029], [71.58069611, 20.95874977], [71.58069611, 20.95846939], [71.58041382, 20.95846939], [71.58041382, 20.95819473], [71.58013916, 20.95819473], [71.58013916, 20.95791626], [71.57958221, 20.95792007], [71.57958221, 20.9576416], [71.57930756, 20.9576416], [71.57930756, 20.95735931], [71.57902527, 20.95735931], [71.57902527, 20.95708275], [71.57875061, 20.95708275], [71.57875061, 20.95680618], [71.5790329, 20.9568119], [71.5790329, 20.95624924], [71.57930756, 20.95624924], [71.57930756, 20.95597076], [71.57958221, 20.95597267], [71.57958221, 20.9556942], [71.5798645, 20.9556942], [71.5798645, 20.95513725], [71.58013916, 20.95513916], [71.58013916, 20.95486069], [71.57985687, 20.95486069], [71.57985687, 20.95430756], [71.57958221, 20.95430756], [71.57958221, 20.95402908], [71.57624817, 20.95402908], [71.57624817, 20.95430756], [71.57457733, 20.95430756], [71.57457733, 20.95402908], [71.57319641, 20.95402908], [71.57319641, 20.95375061], [71.57263947, 20.95375061], [71.57263947, 20.95347023], [71.57236481, 20.95347214], [71.57236481, 20.95319366], [71.57096863, 20.95319366], [71.57096863, 20.95347214], [71.57068634, 20.95347023], [71.57068634, 20.95375061], [71.57013702, 20.95375061], [71.57013702, 20.95402908], [71.56846619, 20.95402908], [71.56846619, 20.95375061], [71.56819153, 20.95375061], [71.56819153, 20.95318985], [71.56791687, 20.95319366], [71.56791687, 20.95263863], [71.56764221, 20.95264053], [71.56764221, 20.95207977], [71.56735992, 20.95208359], [71.56735992, 20.95152855], [71.5670929, 20.95153046], [71.5670929, 20.9509697], [71.56680298, 20.9509716], [71.56680298, 20.95069695], [71.56652832, 20.95070076], [71.56652832, 20.95042038], [71.56597137, 20.95042038], [71.56597137, 20.95014], [71.56569672, 20.95014], [71.56569672, 20.94985962], [71.56513977, 20.94986153], [71.56513977, 20.94958305], [71.56319427, 20.94958305], [71.56319427, 20.94986153], [71.56124878, 20.94985962], [71.56124878, 20.95014], [71.55652618, 20.95014], [71.55652618, 20.95042038], [71.55430603, 20.95042038], [71.55430603, 20.95014], [71.55403137, 20.95014], [71.55403137, 20.94985962], [71.55347443, 20.94986153], [71.55347443, 20.94958305], [71.54792023, 20.94958305], [71.54792023, 20.94986153], [71.54763794, 20.94985962], [71.54763794, 20.95014], [71.54736328, 20.95013809], [71.54736328, 20.95039177], [71.54708099, 20.95042038], [71.54708099, 20.95070076], [71.54569244, 20.95070076], [71.54569244, 20.95042038], [71.54541779, 20.95042038], [71.54541779, 20.94985962], [71.5451355, 20.94986153], [71.5451355, 20.94958305], [71.54486084, 20.94958305], [71.54486084, 20.94930649], [71.54374695, 20.9493103], [71.54374695, 20.94902992], [71.54347229, 20.94902992], [71.54347229, 20.94874954], [71.54291534, 20.94874954], [71.54291534, 20.94847488], [71.54264069, 20.94847488], [71.54264069, 20.9481945], [71.5423584, 20.9481945], [71.5423584, 20.94791412], [71.54180908, 20.94791985], [71.54180908, 20.94763947], [71.54152679, 20.94763947], [71.54152679, 20.9473629], [71.54125214, 20.9473629], [71.54125214, 20.94680977], [71.54096985, 20.94680977], [71.54096985, 20.94652939], [71.54013824, 20.94652939], [71.54013824, 20.94623947], [71.53902435, 20.94625282], [71.53902435, 20.94597054], [71.53819275, 20.94597054], [71.53819275, 20.94569206], [71.5376358, 20.94569206], [71.5376358, 20.9454174], [71.53679657, 20.94542122], [71.53679657, 20.94514275], [71.5359726, 20.94514275], [71.5359726, 20.94486046], [71.53569794, 20.94486046], [71.53569794, 20.94458008], [71.53541565, 20.94458389], [71.53541565, 20.94430542], [71.53514099, 20.94431114], [71.53514099, 20.94403267], [71.53457642, 20.94403267], [71.53457642, 20.94375229], [71.53430176, 20.94375229], [71.53430176, 20.94346809], [71.5340271, 20.94347191], [71.5340271, 20.94319534], [71.53013611, 20.94319534], [71.53013611, 20.94347191], [71.52986145, 20.94347191], [71.52986145, 20.94390106], [71.52986145, 20.94403267], [71.52929688, 20.94403267], [71.52929688, 20.94431114], [71.52874756, 20.94430542], [71.52874756, 20.94458389], [71.52819824, 20.94458008], [71.52819824, 20.94486046], [71.52764893, 20.94486046], [71.52764893, 20.94514275], [71.52707672, 20.94514275], [71.52707672, 20.94542122], [71.52680206, 20.9454174], [71.52680206, 20.94569206], [71.52625275, 20.94569206], [71.52625275, 20.94597054], [71.5256958, 20.94597054], [71.5256958, 20.94625282], [71.52513885, 20.94623947], [71.52513885, 20.94652939], [71.52458954, 20.94652939], [71.52458954, 20.94680977], [71.52401733, 20.94680977], [71.52401733, 20.94652939], [71.52348328, 20.94652939], [71.52348328, 20.94680977], [71.52319336, 20.94680977], [71.52319336, 20.94763947], [71.5229187, 20.94763947], [71.5229187, 20.94847488], [71.52263641, 20.94847107], [71.52263641, 20.94902992], [71.52069092, 20.94902992], [71.52069092, 20.9493103], [71.51790619, 20.9493103], [71.51790619, 20.94902992], [71.51708221, 20.94902992], [71.51708221, 20.94874954], [71.51652527, 20.94874954], [71.51652527, 20.94847488], [71.51569366, 20.94847488], [71.51569366, 20.9481945], [71.51486206, 20.9481945], [71.51486206, 20.94791412], [71.51457977, 20.94791985], [71.51457977, 20.94763947], [71.51403046, 20.94763947], [71.51403046, 20.9473629], [71.51374817, 20.9473629], [71.51374817, 20.94708061], [71.51319122, 20.94708443], [71.51319122, 20.94680595], [71.51291656, 20.94680977], [71.51291656, 20.94652939], [71.51264954, 20.94652939], [71.51264954, 20.94597054], [71.51235962, 20.94597054], [71.51235962, 20.9454174], [71.51207733, 20.94542122], [71.51207733, 20.94514275], [71.51152802, 20.94514275], [71.51152802, 20.94486046], [71.51097107, 20.94486046], [71.51097107, 20.94458008], [71.51041412, 20.94458389], [71.51041412, 20.94430542], [71.50985718, 20.94431114], [71.50985718, 20.94403267], [71.50958252, 20.94403267], [71.50958252, 20.94346809], [71.50930786, 20.94347191], [71.50930786, 20.94319534], [71.5090332, 20.94319916], [71.5090332, 20.9426384], [71.50875092, 20.9426384], [71.50875092, 20.94207954], [71.50846863, 20.94208336], [71.50846863, 20.94152832], [71.50875092, 20.94152832], [71.50875092, 20.94124985], [71.5090332, 20.94124985], [71.50902557, 20.94097137], [71.50930786, 20.94097137], [71.50930786, 20.94041634], [71.50958252, 20.94043159], [71.50958252, 20.94013977], [71.50985718, 20.94013977], [71.50985718, 20.93985939], [71.51013947, 20.9398613], [71.51013947, 20.93958282], [71.51041412, 20.93958282], [71.51041412, 20.93930626], [71.51097107, 20.93930817], [71.51097107, 20.93902969], [71.51125336, 20.93902969], [71.51125336, 20.93847084], [71.51097107, 20.93847275], [71.51097107, 20.93736076], [71.51069641, 20.9373703], [71.51069641, 20.93625069], [71.51040649, 20.93625069], [71.51040649, 20.93568993], [71.51013947, 20.93569565], [71.51013947, 20.93541718], [71.50985718, 20.93542099], [71.50985718, 20.93514061], [71.50958252, 20.93514061], [71.50958252, 20.93486023], [71.50930786, 20.93486023], [71.50930786, 20.93457985], [71.50902557, 20.93458366], [71.50902557, 20.93430328], [71.50875092, 20.93430328], [71.50875092, 20.93402863], [71.50846863, 20.93403053], [71.50846863, 20.93375015], [71.50818634, 20.93375015], [71.50818634, 20.93346977], [71.50791931, 20.93347359], [71.50791931, 20.93319511], [71.50763702, 20.93320084], [71.50763702, 20.93292046], [71.50736237, 20.93292046], [71.50736237, 20.93264008], [71.50708008, 20.93264008], [71.50708008, 20.9323597], [71.50680542, 20.93236351], [71.50680542, 20.93208122], [71.50653076, 20.93208122], [71.50653076, 20.93180466], [71.50680542, 20.93180466], [71.50680542, 20.93152809], [71.50708008, 20.93153191], [71.50708008, 20.93123817], [71.50736237, 20.93124962], [71.50736237, 20.93097115], [71.50763702, 20.93097115], [71.50763702, 20.93041611], [71.50791931, 20.93042183], [71.50791931, 20.93014145], [71.50818634, 20.93014145], [71.50818634, 20.92985916], [71.50846863, 20.92985916], [71.50846863, 20.92958069], [71.50875092, 20.9295826], [71.50875092, 20.92930603], [71.5090332, 20.92931175], [71.5090332, 20.92903137], [71.50930786, 20.92903137], [71.50930786, 20.92874908], [71.50958252, 20.92874908], [71.50958252, 20.92847061], [71.50986481, 20.92847252], [71.50986481, 20.92819405], [71.51013947, 20.92819405], [71.51013947, 20.9276371], [71.51040649, 20.92764091], [71.51040649, 20.92736053], [71.51069641, 20.92736053], [71.51069641, 20.92708015], [71.51097107, 20.92708397], [71.51097107, 20.9268055], [71.51125336, 20.92681122], [71.51125336, 20.92625046], [71.51097107, 20.92625046], [71.51097107, 20.92514038], [71.51069641, 20.92514038], [71.51069641, 20.92431068], [71.51097107, 20.92431068], [71.51097107, 20.92374992], [71.51235962, 20.92374992], [71.51235962, 20.9240303], [71.51319122, 20.9240303], [71.51319122, 20.92431068], [71.51403046, 20.92430687], [71.51403046, 20.92441177], [71.51403046, 20.92458344], [71.51486206, 20.92458344], [71.51486206, 20.92486191], [71.51541901, 20.92486191], [71.51541901, 20.92458344], [71.51569366, 20.92458344], [71.51569366, 20.9240284], [71.51597595, 20.9240303], [71.51597595, 20.92346954], [71.51652527, 20.92347145], [71.51652527, 20.92319679], [71.51625061, 20.92319679], [71.51625061, 20.92291641], [71.51597595, 20.92292023], [71.51597595, 20.92235947], [71.51569366, 20.92236137], [71.51569366, 20.92208481], [71.51541901, 20.92208481], [71.51541901, 20.92180634], [71.51513672, 20.92181015], [71.51513672, 20.92152977], [71.51486206, 20.92152977], [71.51486206, 20.92124939], [71.51430511, 20.92124939], [71.51430511, 20.92097473], [71.51374817, 20.92097473], [71.51374817, 20.92069244], [71.51319122, 20.92069244], [71.51319122, 20.92041588], [71.51291656, 20.92041969], [71.51291656, 20.92014122], [71.51235962, 20.92014122], [71.51235962, 20.91958046], [71.51180267, 20.91958427], [71.51180267, 20.9193058], [71.51125336, 20.9193058], [71.51125336, 20.91875267], [71.51069641, 20.91875267], [71.51069641, 20.91847038], [71.51013947, 20.91847038], [71.51013947, 20.91819382], [71.50986481, 20.91819382], [71.50986481, 20.91791725], [71.50930786, 20.91792107], [71.50930786, 20.91764259], [71.5090332, 20.91764259], [71.5090332, 20.91736031], [71.50875092, 20.91736031], [71.50875092, 20.9168129], [71.50846863, 20.9168129], [71.50846863, 20.91653061], [71.50818634, 20.91653061], [71.50818634, 20.91624069], [71.50763702, 20.91624451], [71.50708008, 20.91624832], [71.50708008, 20.91597176], [71.50541687, 20.91597176], [71.50541687, 20.91624832], [71.5045929, 20.91624069], [71.5045929, 20.91653061], [71.50235748, 20.91653061], [71.50235748, 20.91736031], [71.50208282, 20.91736031], [71.50208282, 20.91764259], [71.50068665, 20.91764259], [71.50068665, 20.91792107], [71.49931335, 20.91792107], [71.49931335, 20.91764259], [71.49903107, 20.91764259], [71.49903107, 20.91708183], [71.49874878, 20.91708374], [71.49874878, 20.91680527], [71.49819183, 20.91680527], [71.49819183, 20.91708374], [71.49764252, 20.91708183], [71.49764252, 20.91736031], [71.4970932, 20.91736031], [71.4970932, 20.91764259], [71.49680328, 20.91764259], [71.49680328, 20.91792107], [71.49318695, 20.91792107], [71.49318695, 20.91764259], [71.49291992, 20.91764259], [71.49291992, 20.91736031], [71.49263763, 20.91736031], [71.49263763, 20.91708183], [71.49208069, 20.91708374], [71.49208069, 20.91680527], [71.49180603, 20.9168129], [71.49180603, 20.91653061], [71.491539, 20.91653061], [71.491539, 20.91624069], [71.49124908, 20.91624832], [71.49124908, 20.91597176], [71.49069214, 20.91597176], [71.49069214, 20.91569519], [71.49041748, 20.91570091], [71.49041748, 20.91542053], [71.48958588, 20.91542053], [71.48958588, 20.91513824], [71.48902893, 20.91513824], [71.48902893, 20.91485977], [71.48819733, 20.91486168], [71.48819733, 20.91458321], [71.48791504, 20.91458321], [71.48791504, 20.91402817], [71.48764038, 20.91402817], [71.48764038, 20.91347122], [71.48791504, 20.91347313], [71.48791504, 20.91291618], [71.48819733, 20.91291809], [71.48819733, 20.91236115], [71.48847961, 20.91236115], [71.48847198, 20.91208267], [71.48652649, 20.91208267], [71.48652649, 20.91180611], [71.48625183, 20.91180992], [71.48625183, 20.91152954], [71.48596954, 20.91152954], [71.48596954, 20.91125107], [71.4854126, 20.91125107], [71.4854126, 20.91097069], [71.48513794, 20.9109726], [71.48513794, 20.91069412], [71.48596954, 20.91069412], [71.48596954, 20.91041756], [71.48707581, 20.91041946], [71.48707581, 20.91014099], [71.48792267, 20.91014099], [71.48792267, 20.90986061], [71.48819733, 20.90986061], [71.48819733, 20.90930939], [71.48847961, 20.90930939], [71.48847961, 20.90903091], [71.49041748, 20.90903091], [71.49041748, 20.90875053], [71.49236298, 20.90875053], [71.49236298, 20.90847015], [71.49430847, 20.90847206], [71.49430847, 20.9081955], [71.49458313, 20.9081955], [71.49458313, 20.90791702], [71.49514008, 20.90792084], [71.49514008, 20.90764046], [71.48430634, 20.90764046], [71.48430634, 20.90736008], [71.48402405, 20.90736389], [71.48402405, 20.9070816], [71.48347473, 20.9070816], [71.48347473, 20.90680313], [71.48319244, 20.90681076], [71.48319244, 20.90653038], [71.48264313, 20.90653038], [71.48264313, 20.90625191], [71.48235321, 20.90625191], [71.48235321, 20.90570068], [71.48208618, 20.90570068], [71.48208618, 20.90514183], [71.48179626, 20.90514183], [71.48179626, 20.90457916], [71.48152924, 20.90458107], [71.48152924, 20.90374947], [71.48179626, 20.90374947], [71.48179626, 20.90236092], [71.48208618, 20.90236092], [71.48208618, 20.90097046], [71.48236084, 20.90097237], [71.48236084, 20.90013885], [71.48179626, 20.90014076], [71.48179626, 20.89986038], [71.48097229, 20.89986038], [71.48097229, 20.89958], [71.48069763, 20.89958382], [71.48069763, 20.89902687], [71.48042297, 20.89903069], [71.48042297, 20.89846992], [71.48014069, 20.89847183], [71.48014069, 20.89819527], [71.4798584, 20.89820099], [71.4798584, 20.89764023], [71.47957611, 20.89764023], [71.47957611, 20.89707947], [71.47930908, 20.89708328], [71.47930908, 20.89680672], [71.47902679, 20.89680672], [71.47902679, 20.89652824], [71.47875214, 20.89653015], [71.47875214, 20.89624977], [71.47846985, 20.89624977], [71.47846985, 20.89596939], [71.47819519, 20.8959713], [71.47819519, 20.89374924], [71.47846985, 20.89375114], [71.47846985, 20.89285278], [71.47846985, 20.89263916], [71.47820282, 20.89264107], [71.47820282, 20.8915329], [71.4779129, 20.8915329], [71.4779129, 20.89069176], [71.47763824, 20.89069366], [71.47763824, 20.8904171], [71.47735596, 20.89042282], [71.47735596, 20.89013863], [71.4770813, 20.89013863], [71.4770813, 20.88985825], [71.47458649, 20.88986015], [71.47458649, 20.88958359], [71.47402954, 20.88958359], [71.47402954, 20.88930511], [71.4734726, 20.88932037], [71.4734726, 20.88902855], [71.47264099, 20.88902855], [71.47264099, 20.88874817], [71.47207642, 20.88874817], [71.47207642, 20.8884697], [71.47180176, 20.8884716], [71.47180176, 20.88819504], [71.4715271, 20.88820076], [71.4715271, 20.88763809], [71.47125244, 20.88763809], [71.47125244, 20.88735962], [71.47097015, 20.88736153], [71.47097015, 20.88708305], [71.46986389, 20.88708305], [71.46986389, 20.88680649], [71.4695816, 20.8868103], [71.4695816, 20.88652992], [71.46930695, 20.88652992], [71.46930695, 20.88597107], [71.46902466, 20.88597298], [71.46902466, 20.8856945], [71.46875, 20.8856945], [71.46875, 20.88541794], [71.46848297, 20.88541985], [71.46848297, 20.88513947], [71.4679184, 20.88513947], [71.4679184, 20.88486099], [71.4651413, 20.88486099], [71.4651413, 20.88458061], [71.46485901, 20.88458252], [71.46485901, 20.88402748], [71.46457672, 20.88402939], [71.46457672, 20.88375092], [71.46430206, 20.88375092], [71.46430206, 20.88319588], [71.4640274, 20.88319588], [71.4640274, 20.88263893], [71.46375275, 20.88264084], [71.46375275, 20.88236046], [71.46347046, 20.88236046], [71.46347046, 20.88181114], [71.4631958, 20.88181114], [71.4631958, 20.88153076], [71.46290588, 20.88153076], [71.46290588, 20.88125038], [71.46263885, 20.88125038], [71.46263885, 20.88097], [71.45986176, 20.88097], [71.45986176, 20.88125038], [71.45874786, 20.88125038], [71.45874786, 20.88097], [71.4576416, 20.88097382], [71.4576416, 20.88069534], [71.45569611, 20.88069534], [71.45569611, 20.88097382], [71.45513916, 20.88097], [71.45513916, 20.88125038], [71.45236969, 20.88125038], [71.45236969, 20.88153076], [71.44847107, 20.88153076], [71.44847107, 20.88097], [71.44819641, 20.88097382], [71.44819641, 20.88041687], [71.44790649, 20.88042068], [71.44790649, 20.87709045], [71.44652557, 20.87708282], [71.44652557, 20.87735939], [71.44596863, 20.87735939], [71.44596863, 20.87708282], [71.44568634, 20.87709045], [71.44568634, 20.87681007], [71.44541931, 20.87681007], [71.44541931, 20.8765316], [71.44513702, 20.8765316], [71.44513702, 20.87624931], [71.44431305, 20.87624931], [71.44431305, 20.87597084], [71.44403076, 20.87597275], [71.44403076, 20.8754158], [71.44374847, 20.87542152], [71.44374847, 20.87513924], [71.44346619, 20.87513924], [71.44346619, 20.87486076], [71.44317627, 20.87486076], [71.44317627, 20.87431908], [71.44291687, 20.87431908], [71.44291687, 20.87402916], [71.44264221, 20.87402916], [71.44264221, 20.87375069], [71.44235992, 20.87375069], [71.44235992, 20.87318993], [71.44208527, 20.87319374], [71.44208527, 20.87291718], [71.44180298, 20.87292099], [71.44180298, 20.87207985], [71.44152832, 20.87208366], [71.44152832, 20.87125015], [71.44124603, 20.87125015], [71.44124603, 20.87096024], [71.44097137, 20.87097168], [71.44097137, 20.87069511], [71.44069672, 20.87070084], [71.44069672, 20.87014008], [71.4404068, 20.87014008], [71.4404068, 20.8698597], [71.44013977, 20.8698616], [71.44013977, 20.86958313], [71.43958282, 20.86958313], [71.43958282, 20.86930466], [71.43875122, 20.86930466], [71.43875122, 20.86902809], [71.43818665, 20.86903], [71.43818665, 20.86874962], [71.43736267, 20.86874962], [71.43736267, 20.86847305], [71.43569183, 20.86847115], [71.43569183, 20.86903], [71.43486023, 20.86903], [71.43486023, 20.86874962], [71.43374634, 20.86874962], [71.43374634, 20.86847115], [71.43235779, 20.86847305], [71.43235779, 20.86819458], [71.43180847, 20.86819458], [71.43180847, 20.86791611], [71.43123627, 20.86791992], [71.43123627, 20.86763954], [71.43068695, 20.86763954], [71.43068695, 20.86736107], [71.42819214, 20.86736107], [71.42819214, 20.86763954], [71.42764282, 20.86763954], [71.42764282, 20.86791992], [71.42652893, 20.86791992], [71.42652893, 20.86763954], [71.42624664, 20.86763954], [71.42624664, 20.86736107], [71.42485809, 20.86736107], [71.42485809, 20.86763954], [71.42430878, 20.86763954], [71.42430878, 20.86791992], [71.42346954, 20.86791992], [71.42346954, 20.86763954], [71.42292023, 20.86763954], [71.42292023, 20.86736107], [71.42263794, 20.86736107], [71.42263794, 20.86708069], [71.42236328, 20.8670845], [71.42236328, 20.86680603], [71.42151642, 20.86680984], [71.42151642, 20.86652946], [71.4209671, 20.86652946], [71.42097473, 20.86636925], [71.42097473, 20.86624908], [71.42069244, 20.8662529], [71.42069244, 20.86597061], [71.4201355, 20.86597061], [71.42014313, 20.86652184], [71.42041779, 20.86652946], [71.42041779, 20.86680984], [71.42069244, 20.86680603], [71.42069244, 20.8670845], [71.42151642, 20.86708069], [71.42151642, 20.86736107], [71.42180634, 20.86736107], [71.42180634, 20.86847305], [71.42097473, 20.86847305], [71.42097473, 20.86819458], [71.42069244, 20.86819458], [71.42069244, 20.86791611], [71.41986084, 20.86791992], [71.41986084, 20.86874962], [71.41958618, 20.86874962], [71.41958618, 20.86903], [71.41929626, 20.86903], [71.41929626, 20.86874962], [71.41847229, 20.86874962], [71.41847229, 20.86847115], [71.41791534, 20.86847305], [71.41791534, 20.86819458], [71.41708374, 20.86819458], [71.41708374, 20.86791611], [71.41569519, 20.86791611], [71.41569519, 20.86763954], [71.41401672, 20.86763954], [71.41401672, 20.86736107], [71.41347504, 20.86736107], [71.41347504, 20.8670845], [71.41291809, 20.8670845], [71.41291809, 20.86680603], [71.4118042, 20.86680603], [71.4118042, 20.8670845], [71.41152954, 20.86708069], [71.41152954, 20.86736107], [71.4109726, 20.86736107], [71.4109726, 20.86763954], [71.41069794, 20.86763954], [71.41069794, 20.86791992], [71.41041565, 20.86791611], [71.41041565, 20.86819458], [71.4081955, 20.86819458], [71.4081955, 20.86791611], [71.40625, 20.86791611], [71.40625, 20.86819458], [71.40569305, 20.86819458], [71.40569305, 20.86847305], [71.40458679, 20.86847305], [71.40458679, 20.86819458], [71.4043045, 20.86819458], [71.4043045, 20.86791611], [71.40374756, 20.86791992], [71.40374756, 20.86763954], [71.40319824, 20.86763954], [71.40319061, 20.86736107], [71.4026413, 20.86736107], [71.4026413, 20.86708069], [71.40235901, 20.8670845], [71.40235901, 20.86680603], [71.40180206, 20.86680984], [71.40180206, 20.86652946], [71.40126038, 20.86652946], [71.40126038, 20.8662529], [71.40097046, 20.8662529], [71.40097046, 20.86597061], [71.40041351, 20.86597061], [71.40041351, 20.86569214], [71.40013885, 20.86569214], [71.40013885, 20.86541748], [71.3970871, 20.86541939], [71.3970871, 20.86515045], [71.39597321, 20.86514091], [71.39597321, 20.86569214], [71.39569092, 20.86569023], [71.39569092, 20.8662529], [71.39541626, 20.8662529], [71.39541626, 20.86680984], [71.3951416, 20.86680603], [71.3951416, 20.8670845], [71.39263916, 20.8670845], [71.39263916, 20.86680603], [71.39180756, 20.86680984], [71.39180756, 20.86652946], [71.39068604, 20.86652946], [71.39068604, 20.8662529], [71.38874817, 20.8662529], [71.38874817, 20.86736107], [71.38957977, 20.86736107], [71.38957977, 20.86763954], [71.39013672, 20.86763954], [71.39013672, 20.86819458], [71.39041901, 20.86819077], [71.39041901, 20.86874962], [71.39069366, 20.86874962], [71.39069366, 20.86930466], [71.39097595, 20.86930084], [71.39097595, 20.87014008], [71.39069366, 20.87013817], [71.39069366, 20.87097168], [71.39041901, 20.87096024], [71.39041901, 20.87181091], [71.39013672, 20.87181091], [71.39013672, 20.87236023], [71.38986206, 20.87236023], [71.38986206, 20.87292099], [71.38957977, 20.87291718], [71.38957977, 20.87319374], [71.38930511, 20.87319374], [71.38930511, 20.87347221], [71.38903046, 20.87347031], [71.38903046, 20.87402916], [71.38874817, 20.87402916], [71.38874817, 20.87431908], [71.38819122, 20.87430573], [71.38819122, 20.8745842], [71.38791656, 20.87458038], [71.38791656, 20.87486076], [71.38735962, 20.87486076], [71.38735962, 20.87513924], [71.38707733, 20.87513924], [71.38707733, 20.87542152], [71.38652802, 20.8754158], [71.38652802, 20.87569427], [71.38625336, 20.87569427], [71.38625336, 20.87597275], [71.38513947, 20.87597275], [71.38513947, 20.87569427], [71.38430786, 20.87569427], [71.38430786, 20.8754158], [71.38318634, 20.87542152], [71.38318634, 20.87513924], [71.38208008, 20.87513924], [71.38208008, 20.87486076], [71.38096619, 20.87486076], [71.38096619, 20.87458038], [71.38014221, 20.8745842], [71.38014221, 20.87430573], [71.37902832, 20.87431908], [71.37902832, 20.87402916], [71.3779068, 20.87402916], [71.3779068, 20.87375069], [71.37763977, 20.87375069], [71.37763977, 20.87347031], [71.37735748, 20.87347221], [71.37735748, 20.87291718], [71.37709045, 20.87292099], [71.37709045, 20.87264061], [71.37680817, 20.87264061], [71.37680817, 20.87236023], [71.37652588, 20.87236023], [71.37652588, 20.87207985], [71.37625122, 20.87208366], [71.37625122, 20.87152863], [71.37596893, 20.87153053], [71.37594604, 20.87125015], [71.37568665, 20.87125015], [71.37568665, 20.87070084], [71.37596893, 20.87070084], [71.37596893, 20.87014008], [71.37625122, 20.87014008], [71.37625122, 20.86958122], [71.37652588, 20.86958313], [71.37652588, 20.86902809], [71.37680817, 20.86903], [71.37680817, 20.86847115], [71.37708282, 20.86847305], [71.37708282, 20.86791611], [71.37735748, 20.86791992], [71.37735748, 20.86736107], [71.37763977, 20.86736107], [71.37763977, 20.86708069], [71.37791443, 20.8670845], [71.37791443, 20.86680603], [71.37847137, 20.86680984], [71.37847137, 20.86652946], [71.37902832, 20.86652946], [71.37902832, 20.8662529], [71.37930298, 20.8662529], [71.37930298, 20.86597061], [71.37985992, 20.86597061], [71.37985992, 20.86569214], [71.38014221, 20.86569214], [71.38014221, 20.86541748], [71.38069153, 20.86541939], [71.38069153, 20.86515045], [71.38124847, 20.86515045], [71.38124847, 20.86486244], [71.38153076, 20.86486244], [71.38153076, 20.86431122], [71.38181305, 20.86431122], [71.38181305, 20.86375237], [71.38208008, 20.86375237], [71.38208008, 20.8631897], [71.38236237, 20.86319351], [71.38236237, 20.86291695], [71.38208008, 20.86292076], [71.38208008, 20.86263847], [71.38181305, 20.86263847], [71.38181305, 20.86235809], [71.38153076, 20.86236191], [71.38153076, 20.86097145], [71.38180542, 20.86097145], [71.38180542, 20.85986137], [71.38263702, 20.85986137], [71.38263702, 20.8595829], [71.38375092, 20.8595829], [71.38375092, 20.85986137], [71.38458252, 20.85985947], [71.38458252, 20.86013985], [71.38513947, 20.86013985], [71.38513947, 20.86041832], [71.38597107, 20.86041641], [71.38597107, 20.86069489], [71.38735962, 20.86069489], [71.38735962, 20.86041641], [71.38791656, 20.86041832], [71.38791656, 20.86013985], [71.38735962, 20.86013985], [71.38735962, 20.85985947], [71.38652802, 20.85986137], [71.38652802, 20.8595829], [71.38569641, 20.8595829], [71.38569641, 20.85930634], [71.38513947, 20.85931015], [71.38513947, 20.85902023], [71.38458252, 20.85902786], [71.38458252, 20.85708427], [71.38346863, 20.85708427], [71.38346863, 20.8568058], [71.38236237, 20.85680962], [71.38236237, 20.85653114], [71.38124847, 20.85653114], [71.38124847, 20.85625076], [71.38014221, 20.85625076], [71.38014221, 20.85597229], [71.37902832, 20.85597229], [71.37902832, 20.85569572], [71.37875366, 20.85569572], [71.37875366, 20.85597229], [71.3779068, 20.85596085], [71.3779068, 20.85625076], [71.37625122, 20.85625076], [71.37625122, 20.85596085], [71.37569427, 20.85597229], [71.37569427, 20.85569572], [71.37513733, 20.85569572], [71.37513733, 20.85541725], [71.37486267, 20.85542107], [71.37486267, 20.85514069], [71.37431335, 20.85514069], [71.37431335, 20.85486031], [71.37374878, 20.85486031], [71.37374878, 20.85457993], [71.37347412, 20.85458374], [71.37347412, 20.85430527], [71.37291718, 20.85431099], [71.37291718, 20.85403061], [71.37236023, 20.85403061], [71.37236023, 20.85375023], [71.37208557, 20.85375023], [71.37208557, 20.85347366], [71.36958313, 20.85346985], [71.36958313, 20.85375023], [71.36902618, 20.85375023], [71.36902618, 20.85346985], [71.36846924, 20.85347366], [71.36846924, 20.85319519], [71.36763763, 20.85321045], [71.36763763, 20.85292053], [71.36708069, 20.85292053], [71.36708069, 20.85264015], [71.36680603, 20.85264015], [71.36680603, 20.85235977], [71.36653137, 20.85236359], [71.36653137, 20.8520813], [71.36486053, 20.8520813], [71.36486053, 20.85236359], [71.36235809, 20.85236359], [71.36235809, 20.8520813], [71.36152649, 20.8520813], [71.36152649, 20.85180473], [71.36042023, 20.85180473], [71.36042023, 20.8520813], [71.35986328, 20.8520813], [71.35986328, 20.85180473], [71.35902405, 20.85180473], [71.35902405, 20.85152817], [71.3584671, 20.85153008], [71.3584671, 20.8512516], [71.35791779, 20.8512516], [71.35791779, 20.85096931], [71.35597229, 20.85097122], [71.35597229, 20.85069466], [71.35346985, 20.85069466], [71.35346985, 20.85097122], [71.35319519, 20.85097122], [71.35321045, 20.8512516], [71.35180664, 20.8512516], [71.35180664, 20.85096931], [71.35152435, 20.85097122], [71.35152435, 20.85069466], [71.35124969, 20.85069466], [71.35124969, 20.85041618], [71.35069275, 20.85042191], [71.35069275, 20.85015106], [71.34874725, 20.85015106], [71.34874725, 20.84985924], [71.34792328, 20.84985924], [71.34792328, 20.85015106], [71.3473587, 20.85015106], [71.3473587, 20.85042191], [71.34708405, 20.85041618], [71.34708405, 20.85097122], [71.3465271, 20.85096931], [71.3465271, 20.8512516], [71.34485626, 20.8512516], [71.34485626, 20.85096931], [71.34402466, 20.85097122], [71.34402466, 20.85069466], [71.34347534, 20.85069466], [71.34347534, 20.85041618], [71.34263611, 20.85042191], [71.34263611, 20.85015106], [71.34236145, 20.85015106], [71.34236145, 20.85042191], [71.34179688, 20.85042191], [71.34179688, 20.84985924], [71.34152985, 20.84985924], [71.34152985, 20.84958076], [71.34124756, 20.84958267], [71.34124756, 20.84902763], [71.34098053, 20.84903145], [71.34098053, 20.84874916], [71.34069824, 20.84874916], [71.34069061, 20.84847069], [71.3390274, 20.8484726], [71.3390274, 20.84819412], [71.33875275, 20.84819412], [71.33875275, 20.8484726], [71.33597565, 20.8484726], [71.33597565, 20.84819412], [71.3345871, 20.84819412], [71.3345871, 20.84791756], [71.33374786, 20.84791756], [71.33374786, 20.84763908], [71.33319092, 20.84763908], [71.33319092, 20.84708023], [71.3326416, 20.84708405], [71.3326416, 20.84680557], [71.33207703, 20.84680748], [71.33207703, 20.84653091], [71.33040619, 20.84653091], [71.33040619, 20.84625053], [71.33013916, 20.84625053], [71.33013916, 20.84653091], [71.32736206, 20.84653091], [71.32736206, 20.84625053], [71.32707977, 20.84625053], [71.32707977, 20.84653091], [71.32653046, 20.84653091], [71.32653046, 20.84625053], [71.32597351, 20.84625053], [71.32597351, 20.84597206], [71.32430267, 20.84597015], [71.32430267, 20.84625053], [71.32263947, 20.84625053], [71.32263947, 20.84597015], [71.32208252, 20.84597206], [71.32208252, 20.84569359], [71.32180786, 20.84569359], [71.32180786, 20.84541512], [71.32068634, 20.84542084], [71.32068634, 20.84514046], [71.31958008, 20.84514046], [71.31958008, 20.84486008], [71.31930542, 20.84486198], [71.31930542, 20.84458351], [71.31903076, 20.84458351], [71.31903076, 20.84430695], [71.31874847, 20.84431076], [71.31874847, 20.84402084], [71.31819153, 20.84402847], [71.31819153, 20.84375], [71.31764221, 20.84375], [71.31764221, 20.84346962], [71.31708527, 20.84347153], [71.31708527, 20.84319687], [71.31652832, 20.84320068], [71.31652832, 20.8429203], [71.31597137, 20.8429203], [71.31597137, 20.84263992], [71.3154068, 20.84263992], [71.3154068, 20.84235954], [71.31485748, 20.84236145], [71.31485748, 20.84208488], [71.31402588, 20.84208488], [71.31402588, 20.84180641], [71.31346893, 20.84181023], [71.31346893, 20.84152985], [71.31291962, 20.84152985], [71.31291962, 20.84124947], [71.31208038, 20.84124947], [71.31208038, 20.84098053], [71.31153107, 20.84098053], [71.31153107, 20.84069061], [71.31069183, 20.84069443], [71.31069183, 20.84041405], [71.3095932, 20.84041977], [71.3095932, 20.84013939], [71.30930328, 20.84013939], [71.30930328, 20.83986282], [71.30874634, 20.83986282], [71.30874634, 20.83958054], [71.30847168, 20.83958054], [71.30847168, 20.83930588], [71.3079071, 20.83930969], [71.3079071, 20.83903122], [71.30764008, 20.83903122], [71.30764008, 20.83875275], [71.30708313, 20.83875275], [71.30708313, 20.83847046], [71.30486298, 20.83847046], [71.30486298, 20.83819389], [71.30458069, 20.83819389], [71.30458069, 20.83791733], [71.30403137, 20.83792114], [71.30403137, 20.83764267], [71.3034668, 20.83764267], [71.3034668, 20.83736038], [71.30291748, 20.83736038], [71.30291748, 20.83708191], [71.30263519, 20.83708382], [71.30263519, 20.83680534], [71.30210114, 20.83681107], [71.30210114, 20.83653069], [71.30152893, 20.83653069], [71.30152893, 20.83596992], [71.30124664, 20.83597183], [71.30124664, 20.83541679], [71.30097198, 20.83542061], [71.30097198, 20.83513832], [71.30042267, 20.83513832], [71.30042267, 20.83542061], [71.29624939, 20.83542061], [71.29624939, 20.83513832], [71.2959671, 20.83513832], [71.2959671, 20.83485985], [71.29541779, 20.83486176], [71.29541779, 20.83458328], [71.2951355, 20.83458328], [71.2951355, 20.83430481], [71.29486084, 20.83430481], [71.29486084, 20.83402824], [71.29458618, 20.83402824], [71.29458618, 20.83374977], [71.29402924, 20.83374977], [71.29402924, 20.83346939], [71.29374695, 20.8334713], [71.29374695, 20.83236122], [71.29347229, 20.83236122], [71.29347229, 20.83125114], [71.2929306, 20.83125114], [71.2929306, 20.83097076], [71.29264069, 20.83097267], [71.29264069, 20.8306942], [71.29208374, 20.8306942], [71.29208374, 20.83041763], [71.29180908, 20.83041954], [71.29180908, 20.82875061], [71.29125214, 20.82875061], [71.29125214, 20.82904053], [71.29013824, 20.82904053], [71.29013824, 20.82930946], [71.28874969, 20.82930946], [71.28874969, 20.82904053], [71.28819275, 20.82904053], [71.28819275, 20.82875061], [71.28736115, 20.82875061], [71.28736115, 20.82847023], [71.2868042, 20.82847214], [71.2868042, 20.82819557], [71.28624725, 20.82819557], [71.28624725, 20.8279171], [71.28569794, 20.82792091], [71.28569794, 20.82764053], [71.28457642, 20.82764053], [71.28457642, 20.82736015], [71.2840271, 20.82736206], [71.2840271, 20.82708359], [71.28347015, 20.82708359], [71.28347015, 20.82680321], [71.28263855, 20.82681084], [71.28263855, 20.82653046], [71.2809906, 20.82653046], [71.2809906, 20.82681084], [71.2806778, 20.82681084], [71.2806778, 20.82792091], [71.2804184, 20.8279171], [71.2804184, 20.82819557], [71.28013611, 20.82819557], [71.28013611, 20.8279171], [71.27986145, 20.82792091], [71.27986145, 20.82764053], [71.27958679, 20.82764053], [71.27958679, 20.82736015], [71.2793045, 20.82736206], [71.2793045, 20.82708359], [71.27874756, 20.82708359], [71.27874756, 20.82680321], [71.2784729, 20.82681084], [71.2784729, 20.82653046], [71.27819824, 20.82653046], [71.27819061, 20.82625008], [71.27791595, 20.82625008], [71.27791595, 20.82597351], [71.2776413, 20.82598114], [71.2776413, 20.82570076], [71.27735901, 20.82570076], [71.27735901, 20.82542038], [71.27680206, 20.82542038], [71.27680206, 20.82514191], [71.2765274, 20.82514191], [71.2765274, 20.82485962], [71.27625275, 20.82485962], [71.27625275, 20.82542038], [71.2756958, 20.82542038], [71.2756958, 20.82485962], [71.27541351, 20.82485962], [71.27541351, 20.82458115], [71.2748642, 20.82458115], [71.2748642, 20.82430649], [71.27401733, 20.8243103], [71.27401733, 20.82403183], [71.27375031, 20.82403183], [71.27375031, 20.82374954], [71.27347565, 20.82374954], [71.27347565, 20.82347107], [71.27319336, 20.82347107], [71.27319336, 20.8231945], [71.2729187, 20.8231945], [71.2729187, 20.82291603], [71.27263641, 20.82291603], [71.27263641, 20.82264137], [71.27179718, 20.82264137], [71.27179718, 20.82235909], [71.26819611, 20.82235909], [71.26819611, 20.82208061], [71.26763916, 20.82208252], [71.26763916, 20.82180595], [71.26735687, 20.82180977], [71.26735687, 20.82152748], [71.26680756, 20.82152748], [71.26680756, 20.82125092], [71.26597595, 20.82125092], [71.26597595, 20.82097244], [71.26513672, 20.82097244], [71.26513672, 20.8204174], [71.26431274, 20.82042122], [71.26431274, 20.82014084], [71.26403046, 20.82014084], [71.26403046, 20.81958008], [71.26374817, 20.81958389], [71.26374817, 20.81930542], [71.26346588, 20.81931114], [71.26346588, 20.81903076], [71.26319122, 20.81903076], [71.26319122, 20.81875038], [71.26264191, 20.81875038], [71.26264191, 20.81847], [71.26235962, 20.81847191], [71.26235962, 20.81819534], [71.26207733, 20.81820107], [71.26207733, 20.81792068], [71.26125336, 20.81792068], [71.26125336, 20.8176403], [71.26069641, 20.8176403], [71.26069641, 20.81735992], [71.26013947, 20.81736183], [71.26013947, 20.81708336], [71.25986481, 20.81708336], [71.25986481, 20.81680679], [71.25958252, 20.81680679], [71.25958252, 20.81652832], [71.25875092, 20.81653023], [71.25875092, 20.81624985], [71.25846863, 20.81624985], [71.25846863, 20.81596947], [71.25791931, 20.81597137], [71.25791931, 20.81569481], [71.25708008, 20.81569481], [71.25708008, 20.81541634], [71.25624847, 20.81542015], [71.25624847, 20.81513977], [71.25347137, 20.81513977], [71.25347137, 20.81485939], [71.25291443, 20.8148613], [71.25291443, 20.81458473], [71.25235748, 20.81458473], [71.25235748, 20.81430626], [71.25180817, 20.81431007], [71.25180817, 20.81404114], [71.25108337, 20.81402969], [71.25096893, 20.81404114], [71.25096893, 20.81392097], [71.25096893, 20.81374931], [71.2507782, 20.81374931], [71.25041962, 20.81375122], [71.25041962, 20.81347275], [71.24903107, 20.81347466], [71.24903107, 20.81319427], [71.24819183, 20.81319427], [71.24819183, 20.8129158], [71.2470932, 20.81291962], [71.2470932, 20.81264114], [71.24680328, 20.81264114], [71.24680328, 20.81180954], [71.24597168, 20.81180954], [71.24597168, 20.81153107], [71.24485779, 20.81153107], [71.24485779, 20.81180954], [71.24430847, 20.81180954], [71.24430847, 20.81236267], [71.24263763, 20.81236267], [71.24263763, 20.81208038], [71.24124908, 20.8120842], [71.24124908, 20.81180573], [71.24014282, 20.81180954], [71.24014282, 20.81153107], [71.2387619, 20.81153107], [71.2387619, 20.81069183], [71.23847198, 20.81069374], [71.23847198, 20.81041718], [71.23819733, 20.8104229], [71.23819733, 20.81014252], [71.23792267, 20.81014252], [71.23792267, 20.80957985], [71.23764038, 20.80958366], [71.23764038, 20.80930519], [71.23735809, 20.80931091], [71.23735809, 20.80903053], [71.23707581, 20.80903053], [71.23707581, 20.80846977], [71.23680878, 20.80847168], [71.23680878, 20.80819511], [71.23652649, 20.80820084], [71.23652649, 20.80791092], [71.23625183, 20.80791664], [71.23625183, 20.8073616], [71.23596954, 20.8073616], [71.23596954, 20.80708313], [71.23569489, 20.80708313], [71.23569489, 20.80680466], [71.23542023, 20.80680466], [71.23542023, 20.80652618], [71.23513794, 20.80652809], [71.23513794, 20.80624962], [71.23486328, 20.80624962], [71.23486328, 20.80597115], [71.23458099, 20.80597305], [71.23458099, 20.80569458], [71.23430634, 20.80569458], [71.23430634, 20.80541611], [71.23374939, 20.80541992], [71.23374939, 20.80513954], [71.2334671, 20.80513954], [71.2334671, 20.80484962], [71.2326355, 20.80486107], [71.2326355, 20.80402756], [71.23236084, 20.80402946], [71.23236084, 20.80430984], [71.23152924, 20.80430794], [71.23152924, 20.8045826], [71.23041534, 20.8045826], [71.23041534, 20.80430794], [71.22959137, 20.80430984], [71.22959137, 20.80402946], [71.22875214, 20.80402946], [71.22875214, 20.80375099], [71.22846985, 20.80375099], [71.22846985, 20.80347061], [71.22569275, 20.80347061], [71.22569275, 20.80375099], [71.21985626, 20.80375099], [71.21985626, 20.80347061], [71.21847534, 20.80347252], [71.21847534, 20.80319595], [71.21708679, 20.80319595], [71.21708679, 20.80291748], [71.21569824, 20.80291939], [71.21569061, 20.80264091], [71.21069336, 20.80264091], [71.21069336, 20.80236053], [71.20986176, 20.80236053], [71.20986176, 20.80208015], [71.20903015, 20.80208588], [71.20903015, 20.80125046], [71.20874786, 20.80125046], [71.20874786, 20.80070114], [71.20845795, 20.8006897], [71.20847321, 20.80041695], [71.20791626, 20.80042076], [71.20791626, 20.80014038], [71.2076416, 20.80014038], [71.2076416, 20.79986191], [71.20708466, 20.79986382], [71.20708466, 20.7990284], [71.20680237, 20.7990303], [71.20680237, 20.79875183], [71.20625305, 20.79875183], [71.20625305, 20.79818916], [71.20541382, 20.79819489], [71.20541382, 20.79791641], [71.20513916, 20.79792023], [71.20513916, 20.79735947], [71.2048645, 20.79735947], [71.2048645, 20.7970829], [71.20513916, 20.7970829], [71.20513916, 20.79624939], [71.20542145, 20.79624939], [71.20541382, 20.79569435], [71.20513916, 20.79569435], [71.20513916, 20.79486084], [71.20485687, 20.79486084], [71.20485687, 20.79430962], [71.2076416, 20.79430962], [71.2076416, 20.79403114], [71.20735931, 20.79403114], [71.20735931, 20.79374123], [71.20735931, 20.79347229], [71.20680237, 20.79347229], [71.20680237, 20.79319382], [71.20625305, 20.79319382], [71.20625305, 20.79291725], [71.20569611, 20.79291725], [71.20569611, 20.79263878], [71.20542145, 20.79264069], [71.20542145, 20.79236031], [71.20485687, 20.79236031], [71.20485687, 20.79207993], [71.20458221, 20.79208374], [71.20458221, 20.79180527], [71.20430756, 20.79181099], [71.20430756, 20.79153061], [71.20375061, 20.79153061], [71.20375061, 20.79125023], [71.20347595, 20.79125023], [71.20347595, 20.79096985], [71.20319366, 20.79097176], [71.20319366, 20.79041672], [71.20291901, 20.79042053], [71.20291901, 20.79014015], [71.20375061, 20.79014015], [71.20375061, 20.78930092], [71.20319366, 20.78930473], [71.20319366, 20.78902817], [71.20265198, 20.78903008], [71.20265198, 20.78874969], [71.20207977, 20.78874969], [71.20207977, 20.78847122], [71.19958496, 20.78847313], [71.19958496, 20.78819466], [71.19791412, 20.78819466], [71.19791412, 20.78791618], [71.19763947, 20.78792], [71.19763947, 20.78763962], [71.19735718, 20.78763962], [71.19735718, 20.78736115], [71.19680786, 20.78736115], [71.19680786, 20.78708076], [71.19652557, 20.78708458], [71.19652557, 20.78680611], [71.19541931, 20.78680992], [71.19541931, 20.78652954], [71.19431305, 20.78652954], [71.19431305, 20.78625107], [71.19319153, 20.78625107], [71.19319153, 20.7859726], [71.18958282, 20.7859726], [71.18958282, 20.78569221], [71.18930817, 20.78569221], [71.18930817, 20.78541756], [71.18681335, 20.78541946], [71.18681335, 20.7851429], [71.18428802, 20.7851429], [71.18428802, 20.78486252], [71.18319702, 20.78486252], [71.18319702, 20.78458023], [71.18180847, 20.78458405], [71.18180847, 20.78430557], [71.18068695, 20.78430939], [71.18068695, 20.78403282], [71.17930603, 20.78403282], [71.17930603, 20.78373909], [71.17736053, 20.78375244], [71.17736053, 20.78347015], [71.17569733, 20.78347015], [71.17569733, 20.78319359], [71.17375183, 20.78319359], [71.17375183, 20.78291702], [71.17180634, 20.78292084], [71.17180634, 20.78263855], [71.17041779, 20.78263855], [71.17041779, 20.78235817], [71.16928864, 20.78235817], [71.16928864, 20.78263855], [71.16764069, 20.78263855], [71.16764069, 20.78235817], [71.16596985, 20.78236008], [71.16596985, 20.78208351], [71.16430664, 20.78208351], [71.16430664, 20.78180504], [71.16346741, 20.78181076], [71.16346741, 20.78152847], [71.16319275, 20.78152847], [71.16319275, 20.78124809], [71.16236115, 20.78124809], [71.16236115, 20.78096962], [71.1609726, 20.78097153], [71.1609726, 20.78069496], [71.16040802, 20.78070068], [71.16040802, 20.7804203], [71.16014099, 20.78038025], [71.16014099, 20.78013611], [71.1598587, 20.78013992], [71.1598587, 20.77985954], [71.15847015, 20.77986145], [71.15847015, 20.77958298], [71.15791321, 20.77958298], [71.15791321, 20.77930641], [71.15734863, 20.77931023], [71.15734863, 20.77902985], [71.15680695, 20.77902985], [71.15680695, 20.77874947], [71.15625, 20.77874947], [71.15625, 20.77847099], [71.15569305, 20.7784729], [71.15569305, 20.77791786], [71.1554184, 20.77793121], [71.1554184, 20.77763939], [71.15513611, 20.77763939], [71.15513611, 20.77708054], [71.15486145, 20.77708244], [71.15486145, 20.77680588], [71.15431213, 20.77680969], [71.15431213, 20.77653122], [71.15402985, 20.77653122], [71.15402985, 20.77625084], [71.1534729, 20.77625084], [71.1534729, 20.77597046], [71.15291595, 20.77597237], [71.15291595, 20.7756958], [71.1526413, 20.7756958], [71.1526413, 20.77513885], [71.15235901, 20.77514076], [71.15235901, 20.77458], [71.15208435, 20.77458572], [71.15208435, 20.77430534], [71.15180206, 20.77431107], [71.15180206, 20.77375031], [71.1515274, 20.77375031], [71.1515274, 20.7732029], [71.15125275, 20.7732029], [71.15125275, 20.77292061], [71.15097046, 20.77292061], [71.15097046, 20.77236176], [71.1506958, 20.77236366], [71.1506958, 20.77222061], [71.1506958, 20.77180481], [71.15041351, 20.77180481], [71.15041351, 20.77096939], [71.15013885, 20.77096939], [71.15013885, 20.76847267], [71.1498642, 20.76847267], [71.1498642, 20.76736069], [71.14958191, 20.76736069], [71.14958191, 20.76708031], [71.14930725, 20.76708412], [71.14930725, 20.76680565], [71.14903259, 20.76680946], [71.14903259, 20.76652908], [71.14875031, 20.76652908], [71.14875031, 20.76625061], [71.14846802, 20.76625061], [71.14846802, 20.76569939], [71.1481781, 20.76569939], [71.1481781, 20.76514053], [71.14846802, 20.76514053], [71.14846802, 20.76457977], [71.14875031, 20.76458359], [71.14875031, 20.76402855], [71.14903259, 20.76403046], [71.14903259, 20.7634697], [71.14930725, 20.7634716], [71.14930725, 20.76319695], [71.14985657, 20.76320076], [71.14985657, 20.76292992], [71.15039063, 20.76292992], [71.15040588, 20.76264], [71.15097046, 20.76264], [71.15097046, 20.76235962], [71.1515274, 20.76236153], [71.1515274, 20.76208305], [71.15208435, 20.76208305], [71.15208435, 20.76180649], [71.15402985, 20.76180649], [71.15402985, 20.76208305], [71.1554184, 20.76208305], [71.1554184, 20.76236153], [71.15680695, 20.76236153], [71.15680695, 20.76124954], [71.15651703, 20.76124954], [71.15651703, 20.76041985], [71.15625, 20.76041985], [71.15625, 20.76013947], [71.15569305, 20.76013947], [71.15569305, 20.7598629], [71.1554184, 20.7598629], [71.1554184, 20.75956917], [71.15486145, 20.75958061], [71.15486145, 20.75930595], [71.15291595, 20.75930977], [71.15291595, 20.75902939], [71.15207672, 20.75902939], [71.15207672, 20.75875282], [71.15125275, 20.75875282], [71.15125275, 20.75854111], [71.15074158, 20.75849915], [71.15041351, 20.75847054], [71.15041351, 20.75819206], [71.1498642, 20.75819206], [71.1498642, 20.7579174], [71.14958191, 20.75792122], [71.14958191, 20.75764275], [71.14903259, 20.75764275], [71.14903259, 20.75736237], [71.14763641, 20.75736237], [71.14763641, 20.75764275], [71.14679718, 20.75764275], [71.14679718, 20.75736237], [71.14597321, 20.75736237], [71.14597321, 20.75708008], [71.14457703, 20.75708008], [71.14457703, 20.75736237], [71.14263916, 20.75736237], [71.14263916, 20.75708008], [71.14069366, 20.75708389], [71.14069366, 20.75680542], [71.13791656, 20.75680542], [71.13791656, 20.75652695], [71.13291931, 20.75652695], [71.13291931, 20.75680542], [71.13124847, 20.75680542], [71.13124847, 20.75708389], [71.13041687, 20.75708389], [71.13043213, 20.75736237], [71.1279068, 20.75736237], [71.1279068, 20.75708008], [71.12763977, 20.75708389], [71.12763977, 20.75680542], [71.12735748, 20.75680542], [71.12735748, 20.75652695], [71.12708282, 20.75653076], [71.12708282, 20.75624847], [71.12680817, 20.75624847], [71.12680817, 20.75596809], [71.12652588, 20.75597191], [71.12652588, 20.75569534], [71.12596893, 20.75569916], [71.12596893, 20.75542068], [71.12568665, 20.75542068], [71.12568665, 20.7551384], [71.12541962, 20.7551384], [71.12541962, 20.75485992], [71.12513733, 20.75486183], [71.12513733, 20.75458336], [71.12486267, 20.75458336], [71.12486267, 20.75430489], [71.12347412, 20.75430489], [71.12347412, 20.75402832], [71.12014008, 20.75402832], [71.12014008, 20.75430489], [71.11958313, 20.75430489], [71.11958313, 20.75458336], [71.11930847, 20.75458336], [71.11930847, 20.75486183], [71.11875153, 20.75485992], [71.11875153, 20.75542068], [71.11846924, 20.75541687], [71.11846924, 20.75597191], [71.11820221, 20.75596809], [71.11820221, 20.75653076], [71.11846924, 20.75652695], [71.11846924, 20.75680542], [71.11875153, 20.75680542], [71.11875153, 20.75708389], [71.11902618, 20.75708008], [71.11902618, 20.75736237], [71.11930847, 20.75736237], [71.11930847, 20.75764275], [71.11680603, 20.75764275], [71.11680603, 20.75792122], [71.11667633, 20.7579174], [71.1159668, 20.75792122], [71.1159668, 20.75875282], [71.11624908, 20.75875282], [71.11624908, 20.75930977], [71.11680603, 20.75930595], [71.11680603, 20.75958061], [71.11708069, 20.75956917], [71.11708069, 20.7598629], [71.11653137, 20.7598629], [71.11653137, 20.76013947], [71.1159668, 20.76013947], [71.1159668, 20.76041985], [71.11541748, 20.76041603], [71.11541748, 20.7606945], [71.11180878, 20.7606945], [71.11180878, 20.76041603], [71.11125183, 20.76041985], [71.11125183, 20.76013947], [71.11068726, 20.76013947], [71.11068726, 20.7598629], [71.11013794, 20.7598629], [71.11013794, 20.75956917], [71.10958099, 20.75958061], [71.10958099, 20.75930595], [71.10900879, 20.75930977], [71.10900879, 20.75902939], [71.10819244, 20.75902939], [71.10819244, 20.75875282], [71.10541534, 20.75875282], [71.10541534, 20.75847054], [71.1048584, 20.75847054], [71.1048584, 20.75819206], [71.10458374, 20.75819206], [71.10458374, 20.7579174], [71.10402679, 20.75792122], [71.10402679, 20.75764275], [71.10346985, 20.75764275], [71.10346985, 20.75736237], [71.09874725, 20.75736237], [71.09874725, 20.75764275], [71.09902954, 20.75764084], [71.09902954, 20.75819206], [71.09430695, 20.75819206], [71.09430695, 20.7579174], [71.0929184, 20.75792122], [71.0929184, 20.75764275], [71.09126282, 20.75764275], [71.09126282, 20.75736237], [71.08985901, 20.75736237], [71.08985901, 20.75708008], [71.0890274, 20.75708389], [71.0890274, 20.75680542], [71.08791351, 20.75680542], [71.08791351, 20.75652695], [71.08708191, 20.75653076], [71.08708191, 20.75624847], [71.08597565, 20.75624847], [71.08597565, 20.75597191], [71.08569336, 20.75597191], [71.08569336, 20.75569534], [71.08512878, 20.75569916], [71.08512878, 20.75542068], [71.08486176, 20.75542068], [71.08486176, 20.7551384], [71.08429718, 20.7551384], [71.08429718, 20.75485992], [71.08403015, 20.75486183], [71.08403015, 20.75458336], [71.08347321, 20.75458336], [71.08347321, 20.75430489], [71.08319092, 20.75430489], [71.08319092, 20.75402832], [71.0826416, 20.75402832], [71.0826416, 20.75375938], [71.08235931, 20.75375938], [71.08235931, 20.75346947], [71.08180237, 20.75347137], [71.08180237, 20.75319481], [71.08152771, 20.75319481], [71.08152771, 20.75291634], [71.08125305, 20.75291824], [71.08125305, 20.75263977], [71.08069611, 20.75263977], [71.08069611, 20.75235939], [71.08041382, 20.7523613], [71.08041382, 20.75208282], [71.08013916, 20.75208282], [71.08013916, 20.75180626], [71.07985687, 20.75181007], [71.07985687, 20.75152969], [71.07932281, 20.75152969], [71.07932281, 20.75125122], [71.0790329, 20.75125122], [71.0790329, 20.75097084], [71.07875061, 20.75097275], [71.07875061, 20.75069427], [71.07847595, 20.7507], [71.07847595, 20.75041962], [71.07791901, 20.75041962], [71.07791901, 20.75014114], [71.07763672, 20.75014114], [71.07763672, 20.74903107], [71.07736206, 20.74903107], [71.07736206, 20.74818993], [71.07707977, 20.74819565], [71.07707977, 20.7476387], [71.07680511, 20.7476387], [71.07680511, 20.74736023], [71.07653046, 20.74736023], [71.07653046, 20.74707985], [71.07624817, 20.74708366], [71.07624817, 20.74652863], [71.07596588, 20.74653053], [71.07596588, 20.74625015], [71.07569122, 20.74625015], [71.07569122, 20.74596977], [71.07541656, 20.74597359], [71.07541656, 20.74541664], [71.07514191, 20.74542046], [71.07514191, 20.74514008], [71.07569122, 20.74514008], [71.07569122, 20.7448597], [71.07597351, 20.74486351], [71.07597351, 20.74458122], [71.07653046, 20.74458122], [71.07653046, 20.74430466], [71.07680511, 20.74430466], [71.07680511, 20.74402809], [71.07736206, 20.74403191], [71.07736206, 20.74375153], [71.07818604, 20.74375153], [71.07818604, 20.74292183], [71.07847595, 20.74292183], [71.07847595, 20.74235916], [71.07875061, 20.74235916], [71.07875061, 20.74208069], [71.07902527, 20.7420826], [71.07902527, 20.74152756], [71.07932281, 20.74152756], [71.07932281, 20.74124908], [71.07958221, 20.74124908], [71.07958221, 20.74069023], [71.0798645, 20.74069405], [71.0798645, 20.74041748], [71.08013916, 20.74041748], [71.08013916, 20.74014091], [71.08040619, 20.74014091], [71.08040619, 20.73958015], [71.08069611, 20.73958397], [71.08069611, 20.7393055], [71.08097076, 20.73931122], [71.08097076, 20.73875809], [71.08152771, 20.73875809], [71.08152771, 20.73847008], [71.08097076, 20.73847198], [71.08097076, 20.73819542], [71.08040619, 20.7381897], [71.08041382, 20.73791695], [71.07985687, 20.73792076], [71.07985687, 20.73764038], [71.07932281, 20.73764038], [71.07932281, 20.73736], [71.07875061, 20.73736191], [71.07875061, 20.73708344], [71.07819366, 20.73708344], [71.07819366, 20.73680687], [71.07763672, 20.73681068], [71.07763672, 20.7365303], [71.07569122, 20.7365303], [71.07569122, 20.73624992], [71.07514191, 20.73624992], [71.07514191, 20.73596954], [71.07430267, 20.73597145], [71.07430267, 20.73569489], [71.07375336, 20.73569489], [71.07375336, 20.73541641], [71.07068634, 20.73542023], [71.07068634, 20.73513985], [71.06958008, 20.73513985], [71.06958008, 20.73485947], [71.0670929, 20.73485947], [71.0670929, 20.73513985], [71.06652832, 20.73513985], [71.06652832, 20.73485947], [71.06625366, 20.73486137], [71.06625366, 20.73458481], [71.06597137, 20.73458481], [71.06597137, 20.73430634], [71.06569672, 20.73431015], [71.06569672, 20.73402977], [71.0654068, 20.73402977], [71.0654068, 20.73374939], [71.06291962, 20.73374939], [71.06291962, 20.73569489], [71.06236267, 20.73569489], [71.06236267, 20.73597145], [71.06208038, 20.73596954], [71.06208038, 20.73624992], [71.06069183, 20.73624992], [71.06069183, 20.73596954], [71.06041718, 20.73597145], [71.06041718, 20.73569489], [71.06014252, 20.73569489], [71.06014252, 20.73541641], [71.05902863, 20.73542023], [71.05902863, 20.73513985], [71.05789948, 20.73513985], [71.05789948, 20.73485947], [71.05735779, 20.73486137], [71.05735779, 20.73458481], [71.05652618, 20.73458481], [71.05652618, 20.73430634], [71.05596924, 20.73431015], [71.05596924, 20.73402977], [71.05541992, 20.73402977], [71.05541992, 20.73374939], [71.05513763, 20.73374939], [71.05513763, 20.73347473], [71.05486298, 20.73347473], [71.05486298, 20.73319435], [71.05430603, 20.73319435], [71.05430603, 20.73291588], [71.0534668, 20.73291969], [71.0534668, 20.73263168], [71.05291748, 20.73263931], [71.05291748, 20.73236275], [71.05236053, 20.73236275], [71.05236053, 20.73208046], [71.05180359, 20.73208427], [71.05180359, 20.7318058], [71.05124664, 20.73180962], [71.05124664, 20.73153114], [71.05097198, 20.73153114], [71.05097198, 20.73125267], [71.05041504, 20.73125267], [71.05041504, 20.73097038], [71.04569244, 20.73097038], [71.04569244, 20.73153114], [71.04541779, 20.73152733], [71.04541779, 20.73208427], [71.0451355, 20.73208427], [71.04514313, 20.73236275], [71.04486084, 20.73236275], [71.04486084, 20.73263931], [71.04514313, 20.73263168], [71.04514313, 20.73291969], [71.04486084, 20.73291588], [71.04486084, 20.73347473], [71.04458618, 20.73347282], [71.04458618, 20.73374939], [71.04429626, 20.73374939], [71.04429626, 20.73402977], [71.04402924, 20.73402977], [71.04402924, 20.73431015], [71.04374695, 20.73430634], [71.04374695, 20.73486137], [71.04347229, 20.73485947], [71.04347229, 20.73513794], [71.04292297, 20.73513985], [71.04292297, 20.73542023], [71.0423584, 20.73541641], [71.0423584, 20.73569489], [71.04125214, 20.73569489], [71.04125214, 20.73597145], [71.04096985, 20.73596954], [71.04096985, 20.73624992], [71.0404129, 20.73624992], [71.0404129, 20.7365303], [71.04013824, 20.7365303], [71.04013824, 20.73681068], [71.0395813, 20.73680687], [71.0395813, 20.73708344], [71.03930664, 20.73708344], [71.03930664, 20.73736191], [71.03874969, 20.73736], [71.03874969, 20.73764038], [71.03848267, 20.73764038], [71.03848267, 20.73792076], [71.03791809, 20.73791695], [71.03791809, 20.7381897], [71.0376358, 20.73819542], [71.0376358, 20.73847198], [71.03624725, 20.73847008], [71.03624725, 20.73875809], [71.03542328, 20.73875809], [71.03542328, 20.73903084], [71.0348587, 20.73903084], [71.0348587, 20.73931122], [71.03236389, 20.7393055], [71.03236389, 20.73958397], [71.03152466, 20.73958397], [71.03152466, 20.7393055], [71.03013611, 20.73931122], [71.03013611, 20.73903084], [71.02902985, 20.73903084], [71.02902985, 20.73875809], [71.02884674, 20.73875809], [71.0276413, 20.73875809], [71.0276413, 20.73903084], [71.02484894, 20.73903084], [71.02484894, 20.73875809], [71.02353668, 20.73875427], [71.02263641, 20.73875809], [71.02263641, 20.73847008], [71.02153015, 20.73847198], [71.02153015, 20.73819542], [71.02041626, 20.73819542], [71.02041626, 20.73847198], [71.01957703, 20.73847008], [71.01957703, 20.73875809], [71.01904297, 20.73875809], [71.01904297, 20.73903084], [71.01819611, 20.73903084], [71.01819611, 20.73931122], [71.01763916, 20.7393055], [71.01763916, 20.73958397], [71.01680756, 20.73958015], [71.01680756, 20.73986053], [71.0151062, 20.73986053], [71.01457977, 20.73986053], [71.01457977, 20.73958015], [71.01319122, 20.73958015], [71.01319122, 20.73986053], [71.01097107, 20.73986053], [71.01097107, 20.73958015], [71.01069641, 20.73958397], [71.01069641, 20.7393055], [71.0090332, 20.73931122], [71.0090332, 20.73875809], [71.00791931, 20.73875809], [71.00791931, 20.73847008], [71.00680542, 20.73847198], [71.00680542, 20.73791695], [71.00653076, 20.73792076], [71.00653076, 20.73764038], [71.00569153, 20.73764038], [71.00569153, 20.73736], [71.00485992, 20.73736191], [71.00485992, 20.73708344], [71.00402832, 20.73708344], [71.00402832, 20.73680687], [71.00319672, 20.73681068], [71.00319672, 20.7365303], [71.00263977, 20.7365303], [71.00263977, 20.73624992], [71.00235748, 20.73624992], [71.00235748, 20.73596954], [71.00180817, 20.73597145], [71.00180817, 20.73569489], [71.00152588, 20.73569489], [71.00152588, 20.73541641], [71.00096893, 20.73542023], [71.00096893, 20.73513985], [70.99986267, 20.73513985], [70.99931335, 20.73513985], [70.99931335, 20.73485947], [70.99874878, 20.73486137], [70.99874878, 20.73458481], [70.99847412, 20.73458481], [70.99847412, 20.73430634], [70.99819183, 20.73431015], [70.99819183, 20.73402977], [70.99764252, 20.73402977], [70.99764252, 20.73374939], [70.99736023, 20.73374939], [70.99736023, 20.73347282], [70.99708557, 20.73347473], [70.99708557, 20.73319435], [70.99652863, 20.73319435], [70.99652863, 20.73291588], [70.99597168, 20.73291969], [70.99597168, 20.73263168], [70.99514008, 20.73263931], [70.99514008, 20.73236275], [70.99402618, 20.73236275], [70.99402618, 20.73180962], [70.99375153, 20.73180962], [70.99375153, 20.73125267], [70.99346924, 20.73125267], [70.99346924, 20.73097038], [70.99291992, 20.73097038], [70.99291992, 20.73069382], [70.99263763, 20.73069382], [70.99263763, 20.73014069], [70.99236298, 20.73014259], [70.99236298, 20.72958946], [70.99208069, 20.72958946], [70.99208069, 20.72930908], [70.99153137, 20.72930908], [70.99153137, 20.72874832], [70.99124908, 20.72874832], [70.99124908, 20.72820091], [70.9909668, 20.72820091], [70.9909668, 20.72735977], [70.99069214, 20.72736168], [70.99069214, 20.72597313], [70.99041748, 20.72597313], [70.99041748, 20.72569466], [70.99013519, 20.72569466], [70.99013519, 20.72513962], [70.98986053, 20.72513962], [70.98986053, 20.72458076], [70.98958588, 20.72458267], [70.98958588, 20.72402763], [70.98929596, 20.72402954], [70.98929596, 20.72347069], [70.98902893, 20.7234726], [70.98902893, 20.72319412], [70.98847198, 20.72319412], [70.98847198, 20.72291756], [70.98819733, 20.72291946], [70.98819733, 20.72264099], [70.98792267, 20.72264099], [70.98792267, 20.72236061], [70.98764038, 20.72236061], [70.98764038, 20.72208023], [70.98680878, 20.72208023], [70.98680878, 20.72236061], [70.98652649, 20.72236061], [70.98652649, 20.72264099], [70.98625183, 20.72264099], [70.98625183, 20.72402954], [70.98596954, 20.72402954], [70.98596954, 20.72430992], [70.98569489, 20.72430611], [70.98569489, 20.72458267], [70.98542023, 20.72458076], [70.98542023, 20.72486115], [70.98486328, 20.72486115], [70.98486328, 20.72513962], [70.98458099, 20.72513962], [70.98458099, 20.72541809], [70.98402405, 20.72541618], [70.98402405, 20.72569466], [70.98374939, 20.72569084], [70.98374939, 20.72624969], [70.98430634, 20.72624969], [70.98430634, 20.72652817], [70.98486328, 20.72652626], [70.98486328, 20.72680473], [70.98513794, 20.72680473], [70.98513794, 20.72708321], [70.98569489, 20.72708321], [70.98569489, 20.72736168], [70.98596954, 20.72735977], [70.98596954, 20.72763824], [70.98625183, 20.72763824], [70.98625183, 20.72792053], [70.98652649, 20.72792053], [70.98652649, 20.72820091], [70.98680878, 20.72820091], [70.98680878, 20.72874832], [70.98707581, 20.72874832], [70.98707581, 20.72958946], [70.98735809, 20.72958374], [70.98735809, 20.73097038], [70.98791504, 20.73097038], [70.98791504, 20.73069382], [70.98819733, 20.73069382], [70.98819733, 20.73041725], [70.98847198, 20.73042107], [70.98847198, 20.73014259], [70.98986053, 20.73014259], [70.98986053, 20.73042107], [70.99013519, 20.73041725], [70.99013519, 20.73069382], [70.99041748, 20.73069191], [70.99041748, 20.73125267], [70.99097443, 20.73125267], [70.99097443, 20.73137856], [70.9909668, 20.73153114], [70.99124908, 20.73153114], [70.99124908, 20.73180962], [70.99153137, 20.73180962], [70.99153137, 20.73236275], [70.99180603, 20.73236275], [70.99180603, 20.73402977], [70.99208069, 20.73402977], [70.99208069, 20.73431015], [70.99236298, 20.73430634], [70.99236298, 20.73458481], [70.99263763, 20.73458481], [70.99263763, 20.73486137], [70.99318695, 20.73485947], [70.99318695, 20.73513985], [70.99346924, 20.73513794], [70.99346924, 20.73569489], [70.99402618, 20.73569489], [70.99402618, 20.73597145], [70.99430847, 20.73596954], [70.99430847, 20.73624992], [70.99458313, 20.73624992], [70.99458313, 20.73681068], [70.99485779, 20.73680687], [70.99485779, 20.73708344], [70.99514008, 20.73707962], [70.99514008, 20.73764038], [70.9954071, 20.73764038], [70.9954071, 20.73792076], [70.99597168, 20.73791695], [70.99597168, 20.73819351], [70.99624634, 20.7381897], [70.99624634, 20.73875809], [70.99680328, 20.73875809], [70.99680328, 20.73903084], [70.9970932, 20.73903084], [70.9970932, 20.73931122], [70.99736023, 20.73931122], [70.99736023, 20.73986053], [70.99764252, 20.73986053], [70.99764252, 20.74041748], [70.99819183, 20.74041748], [70.99819183, 20.74064255], [70.99819183, 20.74152756], [70.99847412, 20.74152756], [70.99847412, 20.7420826], [70.99874878, 20.74208069], [70.99874878, 20.74235916], [70.99903107, 20.74235916], [70.99903107, 20.74264145], [70.99874878, 20.74264145], [70.99874878, 20.74292183], [70.99819183, 20.74292183], [70.99819183, 20.74264145], [70.99569702, 20.74264145], [70.99569702, 20.74235916], [70.99430847, 20.74235916], [70.99430847, 20.74264145], [70.99402618, 20.74264145], [70.99402618, 20.74292183], [70.99375153, 20.74292183], [70.99375153, 20.74375153], [70.99346924, 20.74375153], [70.99346924, 20.74430466], [70.99319458, 20.74430466], [70.99319458, 20.74458122], [70.99291992, 20.74458122], [70.99291992, 20.74486351], [70.99263763, 20.7448597], [70.99263763, 20.74514008], [70.99236298, 20.74514008], [70.99236298, 20.74542046], [70.99180603, 20.74542046], [70.99180603, 20.74570084], [70.99124908, 20.74569511], [70.99124908, 20.74597359], [70.99013519, 20.74597359], [70.99013519, 20.74569511], [70.98958588, 20.74570084], [70.98958588, 20.74542046], [70.98847198, 20.74542046], [70.98847198, 20.74570084], [70.98735809, 20.74570084], [70.98735809, 20.74542046], [70.98680878, 20.74542046], [70.98680878, 20.74514008], [70.98625183, 20.74514008], [70.98625183, 20.7448597], [70.98596954, 20.74486351], [70.98596954, 20.74458122], [70.98542023, 20.74458122], [70.98542023, 20.74430466], [70.98486328, 20.74430466], [70.98486328, 20.74402809], [70.98402405, 20.74402809], [70.98402405, 20.74430466], [70.98374939, 20.74430466], [70.98374939, 20.74486351], [70.9826355, 20.74486351], [70.9826355, 20.74458122], [70.98236084, 20.74458122], [70.98236084, 20.74430466], [70.98208618, 20.74430466], [70.98208618, 20.74402809], [70.98179626, 20.74403191], [70.98179626, 20.74375153], [70.98069763, 20.74375153], [70.98069763, 20.74346924], [70.98014069, 20.74347115], [70.98014069, 20.74319458], [70.9798584, 20.74319458], [70.9798584, 20.74291611], [70.97930908, 20.74292183], [70.97930908, 20.74264145], [70.97902679, 20.74264145], [70.97902679, 20.74235916], [70.97846985, 20.74235916], [70.97846985, 20.74208069], [70.9779129, 20.7420826], [70.9779129, 20.74180603], [70.97763824, 20.74181938], [70.97763824, 20.74152756], [70.97735596, 20.74152756], [70.97735596, 20.74124908], [70.97624969, 20.74124908], [70.97624969, 20.74097061], [70.97569275, 20.74097252], [70.97569275, 20.74069405], [70.97541809, 20.74069405], [70.97541809, 20.74041748], [70.9751358, 20.74041748], [70.9751358, 20.74014091], [70.97486115, 20.74014091], [70.97486115, 20.73986053], [70.97429657, 20.73986053], [70.97429657, 20.74014091], [70.97373962, 20.74014091], [70.97373962, 20.73986053], [70.97319794, 20.73986053], [70.97319794, 20.73958015], [70.9723587, 20.73958397], [70.9723587, 20.7393055], [70.97207642, 20.73931122], [70.97207642, 20.73903084], [70.97180176, 20.73903084], [70.97180176, 20.73875809], [70.9715271, 20.73875809], [70.9715271, 20.73847008], [70.9695816, 20.73847008], [70.9695816, 20.73875809], [70.96930695, 20.73875809], [70.96930695, 20.73931122], [70.96902466, 20.7393055], [70.96902466, 20.73958397], [70.96875, 20.73958015], [70.96875, 20.73986053], [70.96848297, 20.73986053], [70.96848297, 20.74014091], [70.96652985, 20.7401371], [70.96652985, 20.74069405], [70.96624756, 20.74069023], [70.96624756, 20.74124908], [70.9659729, 20.74124908], [70.9659729, 20.74152756], [70.96569824, 20.74152756], [70.96569824, 20.74181938], [70.96523285, 20.74181175], [70.96457672, 20.74181938], [70.96457672, 20.74152756], [70.9640274, 20.74152756], [70.9640274, 20.74181938], [70.9631958, 20.74181938], [70.9631958, 20.74152756], [70.96235657, 20.74152756], [70.96235657, 20.74124908], [70.96153259, 20.74124908], [70.96153259, 20.74097061], [70.96097565, 20.74097252], [70.96097565, 20.74069405], [70.96069336, 20.74069405], [70.96069336, 20.74041748], [70.9604187, 20.74041748], [70.9604187, 20.74014091], [70.96013641, 20.74014091], [70.96013641, 20.73986053], [70.9595871, 20.73986053], [70.9595871, 20.73958015], [70.95930481, 20.73958397], [70.95930481, 20.7393055], [70.95903015, 20.73931122], [70.95903015, 20.73903084], [70.95847321, 20.73903084], [70.95847321, 20.73875809], [70.95819092, 20.73875809], [70.95819092, 20.73792076], [70.95791626, 20.73792076], [70.95791626, 20.73764038], [70.9576416, 20.73764038], [70.9576416, 20.73736], [70.95708466, 20.73736191], [70.95708466, 20.73708344], [70.95652771, 20.73708344], [70.95652771, 20.73680687], [70.95625305, 20.73681068], [70.95625305, 20.7365303], [70.95597076, 20.7365303], [70.95597076, 20.73624992], [70.95569611, 20.73624992], [70.95569611, 20.73596954], [70.95541382, 20.73597145], [70.95541382, 20.73569489], [70.9548645, 20.73569489], [70.9548645, 20.73541641], [70.95458221, 20.73542023], [70.95458221, 20.73485947], [70.9548645, 20.73486137], [70.9548645, 20.73458481], [70.95625305, 20.73458481], [70.95625305, 20.73486137], [70.95680237, 20.73485947], [70.95680237, 20.73513985], [70.95707703, 20.73513985], [70.95707703, 20.73542023], [70.9576416, 20.73541641], [70.9576416, 20.73569489], [70.95819092, 20.73569489], [70.95819092, 20.73597145], [70.9595871, 20.73596954], [70.9595871, 20.73624992], [70.96013641, 20.73624992], [70.96013641, 20.73596954], [70.9604187, 20.73597145], [70.9604187, 20.73569489], [70.96069336, 20.73569489], [70.96069336, 20.73541641], [70.96125031, 20.73542023], [70.96125031, 20.73513985], [70.96208191, 20.73513985], [70.96208191, 20.7345829], [70.96263885, 20.73458481], [70.96263885, 20.73374939], [70.96290588, 20.73374939], [70.96290588, 20.73347282], [70.9631958, 20.73347473], [70.9631958, 20.73319435], [70.96291351, 20.73319435], [70.96291351, 20.73291588], [70.96375275, 20.73291969], [70.96375275, 20.73208046], [70.96347046, 20.73208427], [70.96347046, 20.73152733], [70.9631958, 20.73153114], [70.9631958, 20.73069191], [70.96291351, 20.73069382], [70.96291351, 20.7298584], [70.96263885, 20.7298584], [70.96263885, 20.72938156], [70.96203613, 20.7292099], [70.94854736, 20.73374176], [70.93889618, 20.73648834], [70.93403625, 20.73595047], [70.92965698, 20.73192024], [70.92093658, 20.72891045], [70.90487671, 20.72652817], [70.89965057, 20.7238903], [70.89689636, 20.72000122], [70.89295959, 20.71302032], [70.89208221, 20.70819092], [70.89069366, 20.70819473], [70.89069366, 20.7084713], [70.88986206, 20.70845985], [70.88986206, 20.70874977], [70.88854218, 20.70874977], [70.88853455, 20.70903206], [70.88764191, 20.70902824], [70.88764191, 20.70930672], [70.88569641, 20.70930672], [70.88569641, 20.70958328], [70.88541412, 20.70958328], [70.88541412, 20.70930672], [70.88430786, 20.70930672], [70.88430786, 20.70958328], [70.88069153, 20.70958328], [70.88069153, 20.70930672], [70.87680817, 20.70930672], [70.87680817, 20.70902824], [70.87458038, 20.70902824], [70.87458038, 20.70930672], [70.87403107, 20.70930672], [70.87403107, 20.70958328], [70.87374878, 20.70958328], [70.87374878, 20.70982933], [70.87347412, 20.70986176], [70.87347412, 20.71208382], [70.87319183, 20.71208], [70.87319183, 20.71264076], [70.87346649, 20.71264076], [70.87346649, 20.71292114], [70.87374878, 20.71292114], [70.87374878, 20.71486092], [70.87346649, 20.71486092], [70.87346649, 20.7151413], [70.87374878, 20.7151413], [70.87374878, 20.71569443], [70.87346649, 20.71569061], [70.87346649, 20.7179203], [70.87374878, 20.7179203], [70.87374878, 20.71875191], [70.87431335, 20.71875191], [70.87431335, 20.71903038], [70.87458038, 20.71903038], [70.87458038, 20.71931076], [70.87513733, 20.71930504], [70.87513733, 20.71958351], [70.87541962, 20.71958351], [70.87541962, 20.71986389], [70.87596893, 20.71986008], [70.87596893, 20.72014046], [70.87625122, 20.72014046], [70.87625122, 20.72042084], [70.87652588, 20.72041702], [70.87652588, 20.72069359], [70.87680817, 20.72068977], [70.87680817, 20.72125053], [70.87708282, 20.72125053], [70.87708282, 20.72153091], [70.87763977, 20.72153091], [70.87763977, 20.72180939], [70.8779068, 20.72180939], [70.8779068, 20.72236061], [70.87819672, 20.72236061], [70.87819672, 20.72264099], [70.87847137, 20.72264099], [70.87847137, 20.72291946], [70.87902832, 20.72291756], [70.87902832, 20.72319412], [70.87930298, 20.72319412], [70.87930298, 20.7234726], [70.8795929, 20.72347069], [70.8795929, 20.72375107], [70.87985992, 20.72375107], [70.87985992, 20.72402954], [70.88014221, 20.72402954], [70.88014221, 20.72513962], [70.88041687, 20.72513962], [70.88041687, 20.72541809], [70.88097382, 20.72541618], [70.88097382, 20.72569466], [70.88069153, 20.72569084], [70.88069153, 20.72624969], [70.88097382, 20.72624969], [70.88097382, 20.72680473], [70.88124847, 20.72680473], [70.88124847, 20.72708321], [70.88180542, 20.72708321], [70.88180542, 20.72736168], [70.88208008, 20.72735977], [70.88208008, 20.72792053], [70.88236237, 20.72792053], [70.88236237, 20.72874832], [70.88291931, 20.72874832], [70.88291931, 20.72903061], [70.88347626, 20.72903061], [70.88347626, 20.72930908], [70.8840332, 20.72930908], [70.8840332, 20.72958946], [70.88485718, 20.72958946], [70.88485718, 20.7298584], [70.88791656, 20.7298584], [70.88791656, 20.73014259], [70.88874817, 20.73014259], [70.88874817, 20.73042107], [70.89041901, 20.73041725], [70.89041901, 20.73069382], [70.89152527, 20.73069382], [70.89152527, 20.73097038], [70.89208221, 20.73097038], [70.89208221, 20.73125267], [70.89290619, 20.73125267], [70.89290619, 20.73153114], [70.89347076, 20.73153114], [70.89347076, 20.73180962], [70.89624786, 20.7318058], [70.89624786, 20.73208046], [70.89763641, 20.73208046], [70.89763641, 20.73236275], [70.89902496, 20.73236275], [70.89902496, 20.73263931], [70.89930725, 20.73263931], [70.89930725, 20.73236275], [70.89958191, 20.73236275], [70.89958191, 20.73263931], [70.9006958, 20.73263931], [70.9006958, 20.73236275], [70.90125275, 20.73236275], [70.90125275, 20.73263931], [70.90151978, 20.73263168], [70.90151978, 20.73291969], [70.90208435, 20.73291588], [70.90208435, 20.73319435], [70.90291595, 20.73319054], [70.90291595, 20.73374939], [70.90319824, 20.73374939], [70.90319824, 20.73402977], [70.90429688, 20.73402977], [70.90429688, 20.73431015], [70.90513611, 20.73430634], [70.90513611, 20.73458481], [70.90569305, 20.73458481], [70.90569305, 20.73486137], [70.90652466, 20.73486137], [70.90652466, 20.73458481], [70.90791321, 20.73458481], [70.90791321, 20.73486137], [70.90820313, 20.73485947], [70.90820313, 20.73513985], [70.9090271, 20.73513985], [70.9090271, 20.73542023], [70.91014099, 20.73541641], [70.91014099, 20.73569489], [70.91060638, 20.73569489], [70.9118042, 20.73569489], [70.9118042, 20.73541641], [70.91152954, 20.73542023], [70.91152954, 20.73513985], [70.91236115, 20.73513794], [70.91236115, 20.73569489], [70.91402435, 20.73569489], [70.91402435, 20.73541641], [70.91683197, 20.73541641], [70.91764069, 20.73541641], [70.91764069, 20.73569489], [70.91819763, 20.73569489], [70.91819763, 20.73597145], [70.91902924, 20.73596954], [70.91902924, 20.73624992], [70.91958618, 20.73624992], [70.91958618, 20.7365303], [70.92014313, 20.7365303], [70.92014313, 20.73681068], [70.92041779, 20.73680687], [70.92041779, 20.73708344], [70.9201355, 20.73708344], [70.9201355, 20.73736191], [70.91986084, 20.73736], [70.91986084, 20.73792076], [70.91958618, 20.73792076], [70.91958618, 20.73736], [70.91930389, 20.73736191], [70.91930389, 20.73680687], [70.91902924, 20.73681068], [70.91902924, 20.7365303], [70.91765594, 20.7365303], [70.91513824, 20.7365303], [70.91513824, 20.73681068], [70.91486359, 20.73680687], [70.91486359, 20.73708344], [70.9145813, 20.73708344], [70.9145813, 20.73736191], [70.91401672, 20.73736], [70.91401672, 20.73764038], [70.91374969, 20.73763847], [70.91374969, 20.73819351], [70.91402435, 20.73819351], [70.91402435, 20.73847198], [70.91430664, 20.73847008], [70.91430664, 20.73903084], [70.9145813, 20.73903084], [70.9145813, 20.73931122], [70.91486359, 20.7393055], [70.91486359, 20.73958397], [70.91513824, 20.73958015], [70.91513824, 20.73986053], [70.9154129, 20.73986053], [70.9154129, 20.74041748], [70.91569519, 20.74041748], [70.91569519, 20.74069405], [70.91596985, 20.74069405], [70.91596985, 20.74097252], [70.91652679, 20.74097061], [70.91652679, 20.74124908], [70.91681671, 20.74124908], [70.91681671, 20.74152756], [70.9173584, 20.74152756], [70.9173584, 20.74181938], [70.91764069, 20.74180603], [70.91764069, 20.7420826], [70.91819763, 20.74208069], [70.91819763, 20.74235916], [70.91902924, 20.74235916], [70.91902924, 20.74264145], [70.91958618, 20.74264145], [70.91958618, 20.74292183], [70.91986084, 20.74291611], [70.91986084, 20.74347115], [70.91902924, 20.74346924], [70.91902924, 20.74375153], [70.91791534, 20.74375153], [70.91791534, 20.74347115], [70.91680908, 20.74347115], [70.91680908, 20.74319458], [70.91652679, 20.74319458], [70.91652679, 20.74291611], [70.91570282, 20.74292183], [70.91570282, 20.74264145], [70.9154129, 20.74264145], [70.9154129, 20.74235916], [70.91513824, 20.74235916], [70.91513824, 20.74208069], [70.9145813, 20.7420826], [70.9145813, 20.74180603], [70.91430664, 20.74181938], [70.91430664, 20.74152756], [70.91374969, 20.74152756], [70.91374969, 20.74097061], [70.91347504, 20.74097252], [70.91347504, 20.74041748], [70.91319275, 20.74041748], [70.91319275, 20.73986053], [70.91291809, 20.73986053], [70.91291809, 20.73958015], [70.9126358, 20.73958397], [70.9126358, 20.73902893], [70.91236115, 20.73903084], [70.91236115, 20.73875809], [70.91208649, 20.73875809], [70.91208649, 20.73847008], [70.9118042, 20.73847198], [70.9118042, 20.73791695], [70.91152954, 20.73792076], [70.91152954, 20.73764038], [70.91124725, 20.73764038], [70.91124725, 20.73736], [70.91041565, 20.73736191], [70.91041565, 20.73708344], [70.90846252, 20.73708344], [70.90763855, 20.73708344], [70.90763855, 20.73680687], [70.90458679, 20.73681068], [70.90458679, 20.7365303], [70.90374756, 20.7365303], [70.90374756, 20.73624992], [70.90319824, 20.73624992], [70.90319061, 20.73596954], [70.90291595, 20.73597145], [70.90291595, 20.73541641], [70.9026413, 20.73542023], [70.9026413, 20.73513985], [70.90207672, 20.73513985], [70.90207672, 20.73542023], [70.90180206, 20.73542023], [70.90180206, 20.73513985], [70.9006958, 20.73513985], [70.9006958, 20.73485947], [70.89958191, 20.73486137], [70.89958191, 20.73458481], [70.89875031, 20.73458481], [70.89875031, 20.73430634], [70.89653015, 20.73431015], [70.89653015, 20.73402977], [70.89597321, 20.73402977], [70.89597321, 20.73374939], [70.89569092, 20.73374939], [70.89569092, 20.73347282], [70.89180756, 20.73347282], [70.89180756, 20.73374939], [70.88819122, 20.73374939], [70.88819122, 20.73347282], [70.88597107, 20.73347473], [70.88597107, 20.73319435], [70.88541412, 20.73319435], [70.88541412, 20.73291588], [70.88485718, 20.73291969], [70.88485718, 20.73263168], [70.88430786, 20.73263931], [70.88430786, 20.73236275], [70.88375092, 20.73236275], [70.88375092, 20.73208046], [70.88208008, 20.73208427], [70.88208008, 20.7318058], [70.88181305, 20.73180962], [70.88181305, 20.73153114], [70.88153076, 20.73153114], [70.88153076, 20.73125267], [70.88041687, 20.73125267], [70.88041687, 20.73153114], [70.88014221, 20.73153114], [70.88014221, 20.73125267], [70.87930298, 20.73125267], [70.87930298, 20.73097038], [70.87875366, 20.73097038], [70.87875366, 20.73069382], [70.87819672, 20.73069382], [70.87819672, 20.73041725], [70.8779068, 20.73042107], [70.8779068, 20.73014259], [70.87763977, 20.73014259], [70.87763977, 20.7298584], [70.87735748, 20.7298584], [70.87735748, 20.72930908], [70.87708282, 20.72930908], [70.87708282, 20.72846985], [70.87680817, 20.72847176], [70.87680817, 20.72819519], [70.87652588, 20.72820091], [70.87652588, 20.72792053], [70.87625122, 20.72792053], [70.87625122, 20.72763824], [70.87596893, 20.72763824], [70.87596893, 20.72735977], [70.87569427, 20.72736168], [70.87569427, 20.72708321], [70.87513733, 20.72708321], [70.87513733, 20.72680473], [70.87486267, 20.72680473], [70.87486267, 20.72708321], [70.87374878, 20.72708321], [70.87374878, 20.72736168], [70.87346649, 20.72735977], [70.87346649, 20.72792053], [70.87291718, 20.72792053], [70.87291718, 20.72820091], [70.87264252, 20.72819519], [70.87264252, 20.72847176], [70.87208557, 20.72847176], [70.8720932, 20.72874832], [70.87180328, 20.72874832], [70.87180328, 20.72903061], [70.87153625, 20.72903061], [70.87153625, 20.72930908], [70.87124634, 20.72930908], [70.87124634, 20.72958946], [70.87097168, 20.72958946], [70.87097168, 20.73014259], [70.8704071, 20.73014259], [70.8704071, 20.73042107], [70.87014008, 20.73041725], [70.87014008, 20.73069382], [70.86985779, 20.73069191], [70.86985779, 20.73125267], [70.86958313, 20.73125267], [70.86958313, 20.73153114], [70.86930847, 20.73153114], [70.86930847, 20.73236275], [70.86902618, 20.73236275], [70.86902618, 20.73291969], [70.86846924, 20.73291588], [70.86846924, 20.73347473], [70.86818695, 20.73347282], [70.86818695, 20.73374939], [70.86791992, 20.73374939], [70.86791992, 20.73431015], [70.86763763, 20.73430634], [70.86763763, 20.73458481], [70.86736298, 20.7345829], [70.86736298, 20.73513985], [70.86708069, 20.73513985], [70.86708069, 20.73597145], [70.86653137, 20.73596954], [70.86653137, 20.73624992], [70.86624908, 20.73624992], [70.86624908, 20.73681068], [70.86597443, 20.73680687], [70.86597443, 20.73708344], [70.86541748, 20.73708344], [70.86541748, 20.73736191], [70.86514282, 20.73736], [70.86514282, 20.73764038], [70.86458588, 20.73763847], [70.86458588, 20.7381897], [70.86429596, 20.73820114], [70.86429596, 20.73903084], [70.86402893, 20.73902893], [70.86402893, 20.73958397], [70.86374664, 20.73958015], [70.86374664, 20.73986053], [70.86347198, 20.73986053], [70.86347198, 20.74014091], [70.86374664, 20.7401371], [70.86374664, 20.74069405], [70.86347198, 20.74069405], [70.86347198, 20.7420826], [70.86291504, 20.7420826], [70.86291504, 20.74319458], [70.86264038, 20.74319458], [70.86264038, 20.74486351], [70.86292267, 20.7448597], [70.86292267, 20.74542046], [70.86319733, 20.74542046], [70.86319733, 20.74570084], [70.86347198, 20.74570084], [70.86347198, 20.74625015], [70.86374664, 20.74625015], [70.86374664, 20.74681091], [70.86402893, 20.74680519], [70.86402893, 20.74708366], [70.86429596, 20.74707985], [70.86429596, 20.74736023], [70.86458588, 20.74736023], [70.86458588, 20.74930954], [70.86429596, 20.74930954], [70.86429596, 20.74986076], [70.86402893, 20.74986076], [70.86402893, 20.75041962], [70.86374664, 20.75041962], [70.86374664, 20.7507], [70.86347198, 20.7507], [70.86347198, 20.75125122], [70.86319733, 20.75124931], [70.86319733, 20.75208282], [70.86291504, 20.75208282], [70.86291504, 20.75263977], [70.86319733, 20.75263977], [70.86319733, 20.75319481], [70.86347198, 20.75319099], [70.86347198, 20.75402832], [70.86319733, 20.75402832], [70.86319733, 20.75486183], [70.86292267, 20.75485992], [70.86292267, 20.7551384], [70.86180878, 20.7551384], [70.86180878, 20.75485992], [70.85930634, 20.75486183], [70.85930634, 20.75458336], [70.85847473, 20.75458336], [70.85847473, 20.75430489], [70.85819244, 20.75430489], [70.85819244, 20.75374985], [70.85764313, 20.75375938], [70.85764313, 20.75346947], [70.85736084, 20.75347137], [70.85736084, 20.75319481], [70.85458374, 20.75319481], [70.85458374, 20.75347137], [70.85441589, 20.75347137], [70.85375214, 20.75346947], [70.85375214, 20.75375938], [70.85346985, 20.75375938], [70.85346985, 20.75402832], [70.8529129, 20.75402832], [70.8529129, 20.75319099], [70.85319519, 20.75319481], [70.85319519, 20.75291634], [70.85346985, 20.75291824], [70.85346985, 20.75263977], [70.85375214, 20.75263977], [70.85375214, 20.75235939], [70.85430908, 20.7523613], [70.85430908, 20.75208282], [70.85456085, 20.75208282]]], [[[69.64263916, 22.76486206], [69.64263916, 22.76458359], [69.64402771, 22.76458359], [69.64402771, 22.76430511], [69.64430237, 22.76430511], [69.64430237, 22.76402855], [69.64485931, 22.76403046], [69.64485931, 22.76375008], [69.6451416, 22.76375008], [69.6451416, 22.7634697], [69.64541626, 22.76347351], [69.64541626, 22.76319504], [69.64597321, 22.76320076], [69.64597321, 22.76292038], [69.64624786, 22.76292038], [69.64624786, 22.76264191], [69.64652252, 22.76264191], [69.64652252, 22.76235962], [69.64680481, 22.76235962], [69.64680481, 22.76208115], [69.6470871, 22.76208115], [69.6470871, 22.76180649], [69.64736176, 22.7618103], [69.64736176, 22.76153183], [69.64763641, 22.76153183], [69.64763641, 22.76126289], [69.6479187, 22.76126289], [69.6479187, 22.76096916], [69.64819336, 22.76097107], [69.64819336, 22.7606945], [69.64847565, 22.7606945], [69.64847565, 22.76041603], [69.64875031, 22.76042175], [69.64875031, 22.76014137], [69.64930725, 22.76014137], [69.64930725, 22.75985909], [69.64958191, 22.75985909], [69.64958191, 22.75958061], [69.65013885, 22.75958252], [69.65013885, 22.75930595], [69.65040588, 22.75930977], [69.65040588, 22.75902748], [69.65097046, 22.75902748], [69.65097046, 22.75875092], [69.65125275, 22.75875092], [69.65125275, 22.75847054], [69.6515274, 22.75847244], [69.6515274, 22.75819397], [69.65207672, 22.75819969], [69.65207672, 22.75792122], [69.65235901, 22.75792122], [69.65235901, 22.75764084], [69.65264893, 22.75764084], [69.65264893, 22.75736046], [69.65319824, 22.75736046], [69.65319824, 22.75708008], [69.6534729, 22.75708389], [69.6534729, 22.75680542], [69.65402985, 22.75681114], [69.65402985, 22.75653076], [69.65429688, 22.75653076], [69.65429688, 22.75625038], [69.65486145, 22.75625038], [69.65486145, 22.75597], [69.65569305, 22.75597191], [69.65569305, 22.75569534], [69.65625, 22.75570107], [69.65625, 22.75542068], [69.6570816, 22.75542068], [69.6570816, 22.75513077], [69.65958405, 22.7551384], [69.65958405, 22.75486183], [69.66069794, 22.75486183], [69.66069794, 22.7551384], [69.6626358, 22.7551384], [69.6626358, 22.75486183], [69.66291809, 22.75486183], [69.66291809, 22.75458336], [69.66319275, 22.75458336], [69.66319275, 22.75430679], [69.66347504, 22.75430679], [69.66347504, 22.75402832], [69.66374969, 22.75403023], [69.66374969, 22.75374985], [69.66485596, 22.75374985], [69.66485596, 22.75346947], [69.66569519, 22.75347137], [69.66569519, 22.75319481], [69.66652679, 22.75319481], [69.66652679, 22.75291634], [69.66680908, 22.75292015], [69.66680908, 22.75235939], [69.66708374, 22.7523613], [69.66708374, 22.75180626], [69.66680908, 22.75181007], [69.66680908, 22.75152969], [69.66652679, 22.75152969], [69.66652679, 22.75069046], [69.66569519, 22.75069427], [69.66569519, 22.7504158], [69.6645813, 22.7504158], [69.6645813, 22.75069427], [69.66430664, 22.75069427], [69.66430664, 22.7504158], [69.66374969, 22.7504158], [69.66374969, 22.75069427], [69.66208649, 22.75069427], [69.66208649, 22.75097275], [69.66152191, 22.75097275], [69.66152191, 22.75125122], [69.66124725, 22.75125122], [69.66124725, 22.75152969], [69.66069794, 22.75152969], [69.66069794, 22.75181007], [69.65930176, 22.75180626], [69.65930176, 22.75208473], [69.65847015, 22.75208473], [69.65847015, 22.7523613], [69.65763855, 22.75235939], [69.65763855, 22.75263977], [69.65680695, 22.75263977], [69.65680695, 22.75292015], [69.65625, 22.75291634], [69.65625, 22.75319481], [69.65513611, 22.75319481], [69.65513611, 22.75347137], [69.65374756, 22.75346947], [69.65374756, 22.75374985], [69.65291595, 22.75374985], [69.65291595, 22.75403023], [69.65235901, 22.75402832], [69.65235901, 22.75430679], [69.6515274, 22.75430679], [69.6515274, 22.75458336], [69.6506958, 22.75457954], [69.6506958, 22.75542068], [69.65040588, 22.75542068], [69.65040588, 22.75570107], [69.6498642, 22.75569534], [69.6498642, 22.75597191], [69.64930725, 22.75597], [69.64930725, 22.75625038], [69.64819336, 22.75625038], [69.64819336, 22.75597], [69.64763641, 22.75597191], [69.64763641, 22.75569534], [69.64736176, 22.75570107], [69.64736176, 22.75513077], [69.6470871, 22.75513077], [69.6470871, 22.75542068], [69.64679718, 22.75542068], [69.64679718, 22.75570107], [69.64652252, 22.75570107], [69.64652252, 22.75653076], [69.64624786, 22.75653076], [69.64624786, 22.75792122], [69.64652252, 22.75792122], [69.64652252, 22.75819969], [69.64624786, 22.75819397], [69.64624786, 22.75847244], [69.64541626, 22.75847054], [69.64541626, 22.75875092], [69.6451416, 22.75875092], [69.6451416, 22.75902748], [69.64485931, 22.75902748], [69.64485931, 22.75875092], [69.64430237, 22.75875092], [69.64430237, 22.75847054], [69.64263916, 22.75847054], [69.64263916, 22.75875092], [69.64235687, 22.75875092], [69.64235687, 22.75902748], [69.64068604, 22.75902748], [69.64068604, 22.75930977], [69.64013672, 22.75930977], [69.64013672, 22.76014137], [69.63986206, 22.76014137], [69.63986206, 22.76097107], [69.63957977, 22.76096916], [69.63957977, 22.76126289], [69.63846588, 22.76126289], [69.63846588, 22.76096916], [69.63735199, 22.76096916], [69.63735199, 22.76126289], [69.63707733, 22.76126289], [69.63707733, 22.76096916], [69.63680267, 22.76097107], [69.63680267, 22.76041603], [69.63430786, 22.76041603], [69.63430786, 22.7606945], [69.63346863, 22.7606945], [69.63346863, 22.76097107], [69.63263702, 22.76097107], [69.63263702, 22.7606945], [69.63236237, 22.7606945], [69.63236237, 22.76041603], [69.63180542, 22.76041603], [69.63180542, 22.7606945], [69.63153076, 22.7606945], [69.63153076, 22.76097107], [69.63124847, 22.76096916], [69.63124847, 22.76126289], [69.63097382, 22.76125145], [69.63097382, 22.76235962], [69.63124847, 22.76235962], [69.63124847, 22.76264191], [69.63181305, 22.76264191], [69.63181305, 22.76292038], [69.63208008, 22.76292038], [69.63208008, 22.76320076], [69.63319397, 22.76319504], [69.63319397, 22.76347351], [69.63402557, 22.76347351], [69.63402557, 22.76375008], [69.63513947, 22.76375008], [69.63513947, 22.76403046], [69.63597107, 22.76402855], [69.63597107, 22.76430511], [69.63680267, 22.76430511], [69.63680267, 22.76458359], [69.63764191, 22.76458359], [69.63764191, 22.76486206], [69.63847351, 22.76486206], [69.63847351, 22.76458359], [69.64152527, 22.76458359], [69.64152527, 22.76486206], [69.64263916, 22.76486206]]], [[[69.63652802, 22.77986145], [69.63652802, 22.77958488], [69.63680267, 22.77958488], [69.63680267, 22.77930641], [69.63708496, 22.77930641], [69.63708496, 22.77874947], [69.63735199, 22.77874947], [69.63735199, 22.77653122], [69.63764191, 22.77653122], [69.63764191, 22.77569008], [69.63625336, 22.77569389], [69.63625336, 22.77597046], [69.63597107, 22.77597046], [69.63597107, 22.77653122], [69.63569641, 22.7765274], [69.63569641, 22.77708054], [69.63540649, 22.77708054], [69.63540649, 22.77791977], [69.63513947, 22.77791595], [69.63513947, 22.77930641], [69.63541412, 22.77930641], [69.63541412, 22.77958488], [69.63625336, 22.77958488], [69.63625336, 22.77986145], [69.63652802, 22.77986145]]], [[[70.23569489, 22.68458366], [70.23569489, 22.68430519], [70.23596954, 22.68431091], [70.23596954, 22.68403053], [70.23568726, 22.68403053], [70.23568726, 22.68375015], [70.23654175, 22.68375015], [70.23652649, 22.68347359], [70.23708344, 22.68347359], [70.23708344, 22.68319511], [70.23847198, 22.68320274], [70.23847198, 22.6823616], [70.23819733, 22.6823616], [70.23819733, 22.68208122], [70.23764038, 22.68208122], [70.23764038, 22.6823616], [70.23735809, 22.6823616], [70.23735809, 22.68264008], [70.23542023, 22.68264008], [70.23542023, 22.6823616], [70.23513794, 22.6823616], [70.23513794, 22.68320274], [70.23486328, 22.68320274], [70.23486328, 22.68403053], [70.23458099, 22.68403053], [70.23458099, 22.68431091], [70.23486328, 22.68430519], [70.23486328, 22.68458366], [70.23569489, 22.68458366]]], [[[70.24263763, 22.68458366], [70.24263763, 22.68430519], [70.24375153, 22.68431091], [70.24375153, 22.68320274], [70.24346924, 22.68320274], [70.24346924, 22.6823616], [70.24291992, 22.6823616], [70.24291992, 22.68292046], [70.24319458, 22.68291664], [70.24319458, 22.68347359], [70.24291992, 22.68346977], [70.24291992, 22.68375015], [70.24234772, 22.68375015], [70.24234772, 22.68292046], [70.24180603, 22.68292046], [70.24180603, 22.68207932], [70.24124908, 22.68208122], [70.24124908, 22.6823616], [70.24013519, 22.6823616], [70.24013519, 22.68208122], [70.23986053, 22.68208122], [70.23986053, 22.68180466], [70.23930359, 22.68180466], [70.23930359, 22.68208122], [70.23902893, 22.68207932], [70.23902893, 22.68320274], [70.23874664, 22.68319511], [70.23874664, 22.68347359], [70.23902893, 22.68346977], [70.23902893, 22.68375015], [70.23960114, 22.68375015], [70.23960114, 22.68403053], [70.24014282, 22.68403053], [70.24014282, 22.68375015], [70.24041748, 22.68375015], [70.24041748, 22.68346977], [70.24069214, 22.68346977], [70.24069214, 22.68403053], [70.2409668, 22.68403053], [70.2409668, 22.68431091], [70.24208069, 22.68430519], [70.24208069, 22.68458366], [70.24263763, 22.68458366]]], [[[70.24680328, 22.69180489], [70.24680328, 22.69152641], [70.24736023, 22.69152832], [70.24736023, 22.69124985], [70.24764252, 22.69124985], [70.24764252, 22.68985939], [70.24791718, 22.6898613], [70.24791718, 22.68930626], [70.24736023, 22.68931007], [70.24736023, 22.68904114], [70.24680328, 22.68904114], [70.24680328, 22.68875122], [70.24736023, 22.68875122], [70.24736023, 22.68819046], [70.24680328, 22.68819427], [70.24680328, 22.6879158], [70.24597168, 22.68791962], [70.24597168, 22.68764114], [70.24569702, 22.68764114], [70.24569702, 22.68791962], [70.2454071, 22.68791962], [70.2454071, 22.68708038], [70.24485779, 22.6870842], [70.24485779, 22.68680573], [70.24430847, 22.68680954], [70.24430847, 22.68736076], [70.24402618, 22.68736076], [70.24402618, 22.68680954], [70.24346924, 22.68680573], [70.24346924, 22.6870842], [70.24319458, 22.6870842], [70.24319458, 22.68680573], [70.24263763, 22.68680954], [70.24263763, 22.68764114], [70.24375153, 22.68764114], [70.24375153, 22.68791962], [70.24402618, 22.6879158], [70.24402618, 22.68819427], [70.24430847, 22.68819427], [70.24430847, 22.68847275], [70.24291992, 22.68847275], [70.24291992, 22.68819427], [70.24208069, 22.68819046], [70.24208069, 22.68931007], [70.24180603, 22.68930626], [70.24180603, 22.68958282], [70.24236298, 22.68958282], [70.24236298, 22.68930626], [70.24263763, 22.68930626], [70.24263763, 22.6898613], [70.24319458, 22.6898613], [70.24319458, 22.68958282], [70.24346924, 22.68958282], [70.24346924, 22.69069481], [70.24375153, 22.69069099], [70.24375153, 22.69124985], [70.24430847, 22.69124985], [70.24430847, 22.69152832], [70.24514008, 22.69152832], [70.24514008, 22.69124985], [70.24569702, 22.69124985], [70.24569702, 22.69069099], [70.24597168, 22.69069481], [70.24597168, 22.69041634], [70.24624634, 22.69041634], [70.24624634, 22.69097137], [70.24652863, 22.69096947], [70.24652863, 22.69124985], [70.24624634, 22.69124985], [70.24624634, 22.69180489], [70.24680328, 22.69180489]]], [[[70.24402618, 22.72013855], [70.24402618, 22.71902084], [70.24430847, 22.71903038], [70.24430847, 22.71763611], [70.24458313, 22.71763992], [70.24458313, 22.71708107], [70.24485779, 22.71708298], [70.24485779, 22.71652794], [70.24514008, 22.71652985], [70.24514008, 22.71569061], [70.24569702, 22.71569443], [70.24569702, 22.71513939], [70.24597168, 22.71513939], [70.24597168, 22.71486092], [70.24624634, 22.71486092], [70.24624634, 22.71458054], [70.24652863, 22.71458244], [70.24652863, 22.7131958], [70.24624634, 22.7131958], [70.24624634, 22.71291733], [70.24597168, 22.71292114], [70.24597168, 22.71264076], [70.24569702, 22.71264076], [70.24569702, 22.71208], [70.24541473, 22.71208382], [70.24541473, 22.71180534], [70.24514008, 22.71181107], [70.24514008, 22.71236038], [70.24346924, 22.71236038], [70.24346924, 22.7131958], [70.24375153, 22.71319008], [70.24375153, 22.71681023], [70.24346924, 22.71681023], [70.24346924, 22.71931076], [70.24318695, 22.71931076], [70.24318695, 22.72013855], [70.24402618, 22.72013855]]]]}}, {\\\"id\\\": \\\"10\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.12_1\\\", \\\"HASC_1\\\": \\\"IN.HR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Haryana\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -20.2, \\\"dalys_apm25_rate_6cod_mean_total\\\": 632.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1178.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -546.0, \\\"geo-id\\\": 10, \\\"hpm25_child_popweighted\\\": -170.3, \\\"hpm25_female_popweighted\\\": -195.7, \\\"hpm25_male_popweighted\\\": -140.9, \\\"location\\\": \\\"Haryana\\\", \\\"mort_apm25_6cod_mean_total\\\": 5612.0, \\\"mort_hpm25_6cod_mean_total\\\": -10805.0, \\\"mort_tpm25_6cod_mean_total\\\": -5193.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[76.08009338, 27.8510704], [76.06002808, 27.85717964], [76.05478668, 27.8518219], [76.04962921, 27.84786034], [76.04368591, 27.84885025], [76.03839874, 27.85250092], [76.03383636, 27.85418129], [76.02961731, 27.85388947], [76.0207901, 27.85752106], [76.00930786, 27.86260986], [76.00524902, 27.85744095], [75.99662018, 27.86016846], [75.99447632, 27.86091995], [75.98427582, 27.86286926], [75.97544861, 27.86462975], [75.96308136, 27.86473083], [75.96425629, 27.87150955], [75.97345734, 27.87745285], [75.97280121, 27.88537979], [75.97518921, 27.8930912], [75.96724701, 27.89931107], [75.97738647, 27.9092598], [75.96753693, 27.91537094], [75.95588684, 27.91954994], [75.94174957, 27.91908073], [75.92883301, 27.91680908], [75.9287796, 27.92648125], [75.92362213, 27.93309021], [75.92858887, 27.94174957], [75.93850708, 27.95109177], [75.94169617, 27.94634056], [75.9446106, 27.94008827], [75.95394897, 27.93943977], [75.96317291, 27.93695068], [75.97319794, 27.95800018], [75.96833038, 27.96231079], [75.97384644, 27.96993828], [75.98182678, 27.97831154], [75.98647308, 27.98110962], [75.98690796, 27.98463058], [75.98207855, 27.98698044], [75.97316742, 27.98396111], [75.9656601, 27.98657036], [75.95546722, 27.98863983], [75.95527649, 27.99418068], [75.95639801, 28.00102043], [75.96051788, 28.00209999], [75.96452332, 28.00266075], [75.96687317, 28.00222969], [75.97226715, 28.00134087], [75.97988892, 28.00145149], [75.98911285, 28.00432968], [75.99053955, 28.01017189], [75.98581696, 28.01474953], [75.97915649, 28.01545906], [75.97267914, 28.01814079], [75.97083282, 28.02375031], [75.96998596, 28.03094864], [75.9743576, 28.03693962], [75.9805069, 28.03870964], [75.99105072, 28.03991127], [76.01007843, 28.03671074], [76.01088715, 28.04704094], [76.00995636, 28.04990959], [76.00535583, 28.0545311], [76.01667023, 28.05611038], [76.01924133, 28.0589447], [76.02229309, 28.06230927], [76.0331192, 28.0686512], [76.03562927, 28.07398033], [76.03420258, 28.07995033], [76.03121185, 28.08389282], [76.01564789, 28.08885193], [76.01486206, 28.08107948], [76.01242828, 28.07635117], [76.00192261, 28.06073189], [75.99957275, 28.0589447], [75.99762726, 28.05746841], [75.99106598, 28.0564518], [75.98455048, 28.0507412], [75.97740936, 28.05220032], [75.97458649, 28.0570507], [75.97640991, 28.0589447], [75.98763275, 28.07058907], [75.98206329, 28.08022118], [75.97706604, 28.08418083], [75.95896912, 28.08406067], [75.93608856, 28.09353065], [75.94249725, 28.10563087], [75.94740295, 28.10968971], [75.95749664, 28.11555099], [75.96761322, 28.11939049], [75.97706604, 28.12720108], [75.99111176, 28.12817955], [75.99429321, 28.13111115], [75.99571991, 28.13532066], [75.99466705, 28.15060043], [75.99975586, 28.15644073], [76.00602722, 28.15656281], [76.01119995, 28.15767288], [76.0161972, 28.16107941], [76.02774811, 28.17272186], [76.06072998, 28.169981], [76.06635284, 28.16777039], [76.0654068, 28.15564919], [76.0636673, 28.1498909], [76.06505585, 28.14447021], [76.07491302, 28.14195061], [76.08319855, 28.14225006], [76.0879364, 28.14353943], [76.09179688, 28.14641953], [76.09287262, 28.15162086], [76.09288788, 28.15521812], [76.08042908, 28.16810989], [76.07480621, 28.17242813], [76.07157135, 28.17922974], [76.06929779, 28.19425011], [76.06561279, 28.19894981], [76.05665588, 28.201231], [76.04506683, 28.20293045], [76.04382324, 28.20549011], [76.04975128, 28.20983124], [76.05227661, 28.21443939], [76.05300903, 28.22422981], [76.03634644, 28.22710991], [76.02577972, 28.23591995], [76.01119232, 28.24175072], [76.00740051, 28.25315285], [76.01872253, 28.28095818], [75.99124146, 28.29519081], [75.98657227, 28.29589081], [75.97933197, 28.30633163], [75.97470856, 28.31586075], [75.96762848, 28.32409286], [75.95466614, 28.31853104], [75.95449066, 28.32870865], [75.95143127, 28.33349991], [75.95659637, 28.33558083], [75.95630646, 28.33837128], [75.92740631, 28.3451004], [75.92840576, 28.35601997], [75.92498016, 28.36469841], [75.92237854, 28.36890984], [75.90467072, 28.37606049], [75.89713287, 28.38008118], [75.89686584, 28.38999939], [75.88922882, 28.39365959], [75.88353729, 28.39199066], [75.88315582, 28.38669968], [75.87213135, 28.39085007], [75.84120178, 28.39727974], [75.83508301, 28.39770126], [75.82823944, 28.40907288], [75.81813812, 28.40588951], [75.81671143, 28.41150093], [75.80258942, 28.41422844], [75.79405212, 28.40987968], [75.78759003, 28.40444183], [75.78256226, 28.40723038], [75.77031708, 28.40761948], [75.76544952, 28.42078018], [75.77683258, 28.43047142], [75.78513336, 28.43921089], [75.78515625, 28.45074081], [75.77822876, 28.45761108], [75.74713898, 28.46937943], [75.73500061, 28.47264099], [75.73654938, 28.48720169], [75.72395325, 28.49129295], [75.70069122, 28.49533081], [75.69007874, 28.49909973], [75.6710968, 28.51692963], [75.6639328, 28.52086067], [75.6654892, 28.53327942], [75.66333008, 28.53611183], [75.65355682, 28.54057121], [75.64351654, 28.54290962], [75.63665009, 28.54751015], [75.62909698, 28.54597092], [75.6252594, 28.55850983], [75.61904907, 28.58872986], [75.62001801, 28.59922981], [75.61804962, 28.60220909], [75.60933685, 28.60588074], [75.58495331, 28.60638046], [75.57699585, 28.61667061], [75.55570984, 28.6145916], [75.54901123, 28.64312172], [75.53956604, 28.64887047], [75.54071808, 28.65527916], [75.53793335, 28.66128922], [75.53980255, 28.67601967], [75.53663635, 28.68217087], [75.53547668, 28.68839073], [75.53148651, 28.71729088], [75.53093719, 28.73282051], [75.52603149, 28.74291992], [75.52892303, 28.75028038], [75.5219574, 28.7561512], [75.51608276, 28.77222824], [75.50502777, 28.78279114], [75.49854279, 28.7876606], [75.50392151, 28.79673958], [75.50312042, 28.80928993], [75.50878906, 28.81529045], [75.5133667, 28.83658981], [75.51049805, 28.84342003], [75.50267792, 28.84597969], [75.49915314, 28.85036087], [75.49771881, 28.85618973], [75.48799133, 28.85964966], [75.48842621, 28.89831924], [75.48462677, 28.90166092], [75.46707916, 28.92625046], [75.46888733, 28.93799019], [75.49756622, 28.94148827], [75.50354767, 28.95182037], [75.50293732, 28.96148109], [75.50891876, 28.9657383], [75.51651764, 28.97538948], [75.51525116, 28.99105072], [75.51113892, 29.00332069], [75.51107025, 29.00414085], [75.51110077, 29.01082993], [75.50511932, 29.01515007], [75.48362732, 29.01885033], [75.47342682, 29.02020073], [75.4586792, 29.02015114], [75.43473816, 29.01654053], [75.43264008, 29.02206993], [75.44055939, 29.04152107], [75.4375, 29.05047989], [75.42975616, 29.05617905], [75.4302597, 29.06472015], [75.39025116, 29.06822968], [75.38065338, 29.07032013], [75.38218689, 29.08359909], [75.3813858, 29.08967018], [75.38315582, 29.09537125], [75.38130188, 29.10256958], [75.38069916, 29.11071968], [75.39134216, 29.11931992], [75.39620972, 29.12844086], [75.38508606, 29.134161], [75.37380981, 29.13706017], [75.36115265, 29.14262009], [75.36763, 29.15042114], [75.36895752, 29.16995811], [75.37845612, 29.17152023], [75.38857269, 29.17070007], [75.39438629, 29.17427063], [75.40065002, 29.18890953], [75.39985657, 29.20148277], [75.39646149, 29.21342087], [75.39229584, 29.21807098], [75.38611603, 29.2212429], [75.38729858, 29.22904015], [75.3936615, 29.23423958], [75.39936829, 29.24027061], [75.39968109, 29.24677849], [75.39868927, 29.25498962], [75.39570618, 29.26194], [75.3879776, 29.2643528], [75.37954712, 29.26393127], [75.37246704, 29.26003075], [75.35797882, 29.25461006], [75.35016632, 29.24738121], [75.34719849, 29.23011971], [75.3453064, 29.22616005], [75.33454132, 29.22883034], [75.31492615, 29.23596001], [75.32318115, 29.25175095], [75.32537079, 29.27831078], [75.32424927, 29.29018974], [75.31926727, 29.29343987], [75.30857849, 29.28891754], [75.29969025, 29.28198051], [75.28968811, 29.27770042], [75.27937317, 29.27682114], [75.27671814, 29.27345085], [75.27172852, 29.25436974], [75.24946594, 29.25646019], [75.23522949, 29.25193977], [75.22345734, 29.23495102], [75.21195984, 29.2345295], [75.1953125, 29.24422073], [75.18850708, 29.25863075], [75.17999268, 29.26861954], [75.16401672, 29.2643795], [75.16082001, 29.25374985], [75.1474762, 29.24584961], [75.12467194, 29.24496078], [75.11374664, 29.24290085], [75.10817719, 29.2267704], [75.09250641, 29.22911263], [75.07807922, 29.23245049], [75.06270599, 29.23892021], [75.06532288, 29.24661064], [75.06062317, 29.25331116], [75.05094147, 29.26371193], [75.05066681, 29.26888084], [75.05047607, 29.2723999], [75.03991699, 29.28714943], [75.02385712, 29.29153061], [75.005867, 29.28380966], [74.99104309, 29.2717495], [74.98291779, 29.27826118], [74.97690582, 29.28111839], [74.96806335, 29.28244019], [74.95996094, 29.28015137], [74.95310974, 29.28194046], [74.94753265, 29.28815842], [74.94256592, 29.29518127], [74.94010925, 29.30481911], [74.94584656, 29.31102753], [74.95056915, 29.31851006], [74.95096588, 29.32607079], [74.94608307, 29.33280945], [74.93592072, 29.33794975], [74.92714691, 29.36463928], [74.92196655, 29.36603165], [74.91021729, 29.37115288], [74.89907074, 29.3782196], [74.89530945, 29.3841095], [74.88848114, 29.38667107], [74.87058258, 29.38511276], [74.86656952, 29.38846016], [74.86393738, 29.39635086], [74.85719299, 29.39937019], [74.84951782, 29.40279007], [74.84113312, 29.4040699], [74.8351059, 29.40147972], [74.80954742, 29.39847946], [74.79878235, 29.38465118], [74.78578186, 29.37054062], [74.77591705, 29.36015129], [74.75663757, 29.35596085], [74.73169708, 29.35378838], [74.72255707, 29.36084938], [74.71688843, 29.36635971], [74.71124268, 29.36890984], [74.68868256, 29.36515999], [74.67601776, 29.36817169], [74.65851593, 29.36997986], [74.650177, 29.37236977], [74.64370728, 29.35440063], [74.64412689, 29.33534813], [74.64182281, 29.33119965], [74.60603333, 29.3275795], [74.59577942, 29.32831192], [74.60003662, 29.35433006], [74.59671783, 29.36219025], [74.59053802, 29.37067032], [74.57978058, 29.37873077], [74.57289886, 29.38644981], [74.56909943, 29.39730072], [74.57003021, 29.40615845], [74.56439972, 29.41077995], [74.55780792, 29.4186306], [74.5521698, 29.42240143], [74.5411377, 29.42314911], [74.53129578, 29.42498016], [74.52955627, 29.43499947], [74.52910614, 29.44953918], [74.53074646, 29.45754814], [74.53462982, 29.46503258], [74.54280853, 29.4665699], [74.55037689, 29.46447945], [74.55947113, 29.46437073], [74.57170868, 29.46230125], [74.57891083, 29.45862007], [74.58042145, 29.46349907], [74.58553314, 29.4689827], [74.59156036, 29.47985077], [74.59030914, 29.48612976], [74.592659, 29.49212265], [74.60074615, 29.50354958], [74.60452271, 29.51044083], [74.61168671, 29.52000809], [74.61440277, 29.52711105], [74.61142731, 29.53149986], [74.5994873, 29.53686905], [74.59117889, 29.54342079], [74.58178711, 29.54768944], [74.57174683, 29.55558014], [74.56653595, 29.56349945], [74.57060242, 29.56854057], [74.57028198, 29.58591843], [74.57467651, 29.6144104], [74.57699585, 29.62082291], [74.57536316, 29.62732124], [74.58127594, 29.63054085], [74.58603668, 29.63525963], [74.58203888, 29.64406967], [74.57852173, 29.65475273], [74.58513641, 29.67502975], [74.59085083, 29.68272018], [74.59387207, 29.69143295], [74.59287262, 29.70071983], [74.59902954, 29.70621109], [74.60037994, 29.71310806], [74.60347748, 29.72142982], [74.60161591, 29.74066925], [74.60598755, 29.7466507], [74.60540009, 29.7528801], [74.59751129, 29.75797081], [74.59253693, 29.76671982], [74.5866394, 29.76851082], [74.57816315, 29.76696014], [74.57139587, 29.75324821], [74.56402588, 29.75461006], [74.54933167, 29.7548008], [74.53778839, 29.75386047], [74.53185272, 29.74934959], [74.52583313, 29.74136925], [74.51155853, 29.7406826], [74.49680328, 29.74182129], [74.48319244, 29.74403], [74.47200012, 29.74403], [74.46911621, 29.75823975], [74.46526337, 29.78754997], [74.4705658, 29.80200005], [74.48060608, 29.8152504], [74.4916687, 29.82650948], [74.50588989, 29.83258057], [74.53253174, 29.83928108], [74.54747009, 29.85692024], [74.55356598, 29.86564064], [74.55179596, 29.8735199], [74.54521942, 29.88072968], [74.54345703, 29.88871956], [74.53369141, 29.90262032], [74.5255127, 29.90256119], [74.51091003, 29.90429115], [74.50502777, 29.90776062], [74.51278687, 29.93003845], [74.51906586, 29.94334984], [74.52464294, 29.95156097], [74.53024292, 29.94497108], [74.54901886, 29.93316269], [74.55200195, 29.92922974], [74.56183624, 29.92930984], [74.57295227, 29.92588806], [74.58084869, 29.91830254], [74.58580017, 29.91476059], [74.62201691, 29.90777969], [74.62638855, 29.90600967], [74.63263702, 29.90566254], [74.63963318, 29.90394974], [74.64697266, 29.90467072], [74.63886261, 29.91444969], [74.63986206, 29.92249107], [74.64892578, 29.93092918], [74.66570282, 29.94169044], [74.68096161, 29.94919014], [74.68319702, 29.96107292], [74.69078827, 29.96927071], [74.69550323, 29.97153091], [74.69737244, 29.97114944], [74.70613861, 29.96887016], [74.72400665, 29.96186066], [74.73723602, 29.96904945], [74.75071716, 29.97122955], [74.75868225, 29.97363091], [74.76737213, 29.9727211], [74.77599335, 29.97439957], [74.78421783, 29.98042107], [74.79440308, 29.98961067], [74.80117798, 29.99257278], [74.80902863, 29.99047089], [74.81668091, 29.98451996], [74.81968689, 29.97945976], [74.82138824, 29.97305107], [74.82898712, 29.96947098], [74.83660889, 29.96416092], [74.84963226, 29.95912933], [74.85935974, 29.9611702], [74.86566162, 29.95889091], [74.87195587, 29.95912933], [74.87741089, 29.96256828], [74.88149261, 29.96834946], [74.88543701, 29.9623394], [74.88976288, 29.95903015], [74.89435577, 29.95293999], [74.89309692, 29.9472599], [74.88960266, 29.94501114], [74.88523865, 29.9391098], [74.89437866, 29.93944168], [74.91573334, 29.94915962], [74.92408752, 29.94153023], [74.9285965, 29.92916107], [74.93192291, 29.92277908], [74.93566895, 29.9154129], [74.94317627, 29.9025383], [74.95786285, 29.89773941], [74.96988678, 29.88992119], [74.96946716, 29.88067055], [74.9899292, 29.85646057], [74.99411011, 29.86320114], [75.00566101, 29.86757088], [75.01412964, 29.86462975], [75.02348328, 29.87286949], [75.03749847, 29.88178062], [75.05175781, 29.87486076], [75.06040192, 29.87611961], [75.06548309, 29.87903976], [75.07000732, 29.8933506], [75.0777359, 29.91230965], [75.08480072, 29.91514015], [75.08978271, 29.91171074], [75.09475708, 29.90507126], [75.10267639, 29.89702034], [75.10309601, 29.87677956], [75.1042099, 29.87319183], [75.10058594, 29.8678894], [75.08468628, 29.85859108], [75.08098602, 29.85414124], [75.08125305, 29.84937286], [75.08574677, 29.84481049], [75.09895325, 29.84142113], [75.10408783, 29.83801079], [75.1071167, 29.82653046], [75.09333801, 29.81931114], [75.08905029, 29.81282997], [75.09017944, 29.80666161], [75.09552765, 29.8043499], [75.10228729, 29.80255127], [75.12491608, 29.80562019], [75.13141632, 29.78486061], [75.1354599, 29.78038025], [75.141716, 29.77700806], [75.15405273, 29.78101921], [75.15918732, 29.78421974], [75.15486145, 29.78910065], [75.14951324, 29.79164124], [75.14894867, 29.79611969], [75.15130615, 29.80183983], [75.15542603, 29.81981087], [75.15995789, 29.82364082], [75.16699982, 29.82495117], [75.1751709, 29.82951927], [75.17603302, 29.83506966], [75.17855835, 29.83690834], [75.18234253, 29.83870125], [75.18860626, 29.83457947], [75.20091248, 29.82999992], [75.20250702, 29.8213501], [75.19777679, 29.81344032], [75.19645691, 29.80511093], [75.1979599, 29.79622078], [75.20536041, 29.79000092], [75.21238708, 29.78652], [75.21617889, 29.7798996], [75.21673584, 29.77149963], [75.22328186, 29.76353836], [75.22733307, 29.75612068], [75.23097992, 29.75206757], [75.22136688, 29.73307037], [75.21660614, 29.72999001], [75.21067047, 29.73089027], [75.2061615, 29.73525047], [75.19809723, 29.73080063], [75.19368744, 29.72520065], [75.18724823, 29.71191978], [75.1884079, 29.70374107], [75.19243622, 29.69952965], [75.19766998, 29.69647026], [75.19528198, 29.6877594], [75.18888855, 29.68082809], [75.17986298, 29.67830276], [75.17531586, 29.67805099], [75.16783905, 29.67327118], [75.15892029, 29.66936111], [75.15783691, 29.66271019], [75.16275787, 29.65802956], [75.16854858, 29.65423012], [75.1733017, 29.64948082], [75.1724472, 29.63862991], [75.17333984, 29.63008118], [75.18473053, 29.62254143], [75.19937134, 29.6226902], [75.22123718, 29.60655022], [75.2232132, 29.5988903], [75.21936798, 29.59250259], [75.21118927, 29.58239937], [75.21788788, 29.57846069], [75.2217865, 29.57028008], [75.2281723, 29.55855751], [75.22432709, 29.55002975], [75.22348022, 29.54617119], [75.23806763, 29.55154037], [75.25453949, 29.55418015], [75.26748657, 29.55928993], [75.27503204, 29.56110954], [75.29064941, 29.56176186], [75.29606628, 29.5680809], [75.30304718, 29.57905006], [75.30486298, 29.58361053], [75.30451202, 29.58847809], [75.30203247, 29.59198952], [75.29361725, 29.59767151], [75.28034973, 29.6032505], [75.28056335, 29.61010933], [75.28785706, 29.61976814], [75.30105591, 29.62709045], [75.30753326, 29.63256073], [75.31169891, 29.64875984], [75.31623077, 29.66082191], [75.31772614, 29.67070007], [75.32260895, 29.67240906], [75.33014679, 29.67227936], [75.3414917, 29.66213036], [75.34680939, 29.65888977], [75.34850311, 29.65907097], [75.35044861, 29.65928078], [75.34932709, 29.66563988], [75.34603882, 29.67142105], [75.33384705, 29.68805122], [75.33535004, 29.69384956], [75.34121704, 29.69524002], [75.35269165, 29.70449066], [75.35855865, 29.70576096], [75.36194611, 29.71289063], [75.37003326, 29.71306038], [75.37877655, 29.7112999], [75.3835907, 29.72030258], [75.38218689, 29.72705841], [75.3837204, 29.7340107], [75.39087677, 29.73859978], [75.39679718, 29.74867058], [75.39723206, 29.76102066], [75.40999603, 29.77532005], [75.41976929, 29.77437973], [75.42720795, 29.77794075], [75.43463898, 29.78028107], [75.44378662, 29.7861805], [75.44315338, 29.79417038], [75.43547058, 29.79884911], [75.44426727, 29.80784988], [75.4983902, 29.77775002], [75.5063324, 29.77407074], [75.51171112, 29.76004982], [75.52397919, 29.76724052], [75.53019714, 29.7727108], [75.54418182, 29.77176094], [75.55639648, 29.7658329], [75.56308746, 29.74423981], [75.56878662, 29.74262047], [75.59274292, 29.74915123], [75.60048676, 29.74740028], [75.61322784, 29.74645805], [75.62261963, 29.75362015], [75.6235199, 29.76688957], [75.62535858, 29.7732296], [75.64087677, 29.77111053], [75.6496582, 29.77456093], [75.65638733, 29.7760601], [75.66616821, 29.77270126], [75.67830658, 29.75706291], [75.68743134, 29.75177956], [75.69744873, 29.75521088], [75.70593262, 29.80862045], [75.70987701, 29.81225967], [75.7259903, 29.81151962], [75.73272705, 29.81126022], [75.74839783, 29.81212044], [75.76059723, 29.81866074], [75.76342773, 29.82196045], [75.76698303, 29.82345009], [75.7716217, 29.82538986], [75.77243805, 29.82467079], [75.78320313, 29.81532097], [75.79605103, 29.80712128], [75.81997681, 29.8153801], [75.82901764, 29.81232071], [75.82927704, 29.80070114], [75.83338928, 29.79066086], [75.84124756, 29.78083992], [75.84362793, 29.77596092], [75.85459137, 29.76966095], [75.86377716, 29.75233078], [75.87201691, 29.75012016], [75.87928009, 29.74707031], [75.89068604, 29.75321007], [75.89723206, 29.7555294], [75.90313721, 29.74628258], [75.91394806, 29.73876953], [75.92314911, 29.73491096], [75.9289093, 29.73365021], [75.93401337, 29.7325325], [75.93662262, 29.73308182], [75.9386673, 29.73351288], [75.94235229, 29.73427963], [75.9500885, 29.73391151], [75.95748901, 29.73212051], [75.96485901, 29.73138046], [75.97045898, 29.73210907], [75.97254944, 29.73237038], [75.98000336, 29.73616982], [75.98927307, 29.74230957], [76.00382996, 29.75093079], [76.01127625, 29.75282097], [76.01759338, 29.75607109], [76.02424622, 29.75560188], [76.03170776, 29.7508812], [76.03292084, 29.74959946], [76.03565216, 29.74668121], [76.04148102, 29.7487812], [76.0584259, 29.77314949], [76.0632019, 29.7774601], [76.06990051, 29.77602005], [76.07434082, 29.78124046], [76.07543945, 29.78790092], [76.07557678, 29.79704857], [76.07766724, 29.80577278], [76.08605957, 29.80989838], [76.09056091, 29.81083107], [76.09438324, 29.81156158], [76.10321045, 29.80841064], [76.11026764, 29.80331993], [76.11638641, 29.79640007], [76.12140656, 29.7994709], [76.12718201, 29.80542946], [76.13210297, 29.81205177], [76.13926697, 29.81676292], [76.15312958, 29.81627274], [76.16665649, 29.81832123], [76.18582153, 29.83123016], [76.18936157, 29.84047127], [76.19418335, 29.8449707], [76.2022171, 29.84530067], [76.20964813, 29.84274292], [76.21111298, 29.8432312], [76.20965576, 29.8501606], [76.21176147, 29.85314941], [76.21582794, 29.85470963], [76.22290039, 29.85559082], [76.22852325, 29.85452843], [76.2318573, 29.85637093], [76.23522949, 29.85980988], [76.23795319, 29.86545944], [76.24201202, 29.86902809], [76.23869324, 29.87590027], [76.23245239, 29.88132095], [76.22529602, 29.88506126], [76.21694946, 29.88385963], [76.20812988, 29.88651085], [76.19740295, 29.88401985], [76.18463898, 29.88858032], [76.18270874, 29.89388084], [76.18358612, 29.91571808], [76.18199158, 29.92324066], [76.1714859, 29.92323112], [76.16629028, 29.92865944], [76.1696167, 29.93655968], [76.1789093, 29.94626808], [76.18480682, 29.94627953], [76.19087219, 29.94445992], [76.20387268, 29.94412041], [76.2050705, 29.94750023], [76.20345306, 29.95206833], [76.19473267, 29.96567917], [76.19901276, 29.97317123], [76.19748688, 29.97981071], [76.19713593, 29.98511124], [76.19577789, 29.9904995], [76.19303131, 29.99662018], [76.18937683, 30.00419044], [76.1896286, 30.00632286], [76.18981171, 30.00838089], [76.18998718, 30.01044846], [76.19020844, 30.01249123], [76.19050598, 30.01449013], [76.19091797, 30.01641273], [76.19156647, 30.01823044], [76.19346619, 30.01938057], [76.19581604, 30.02006149], [76.19803619, 30.02052116], [76.2003479, 30.02085114], [76.20263672, 30.02120018], [76.20490265, 30.02166939], [76.20720673, 30.02211952], [76.20947266, 30.02272987], [76.21140289, 30.02373123], [76.21354675, 30.02530861], [76.21543884, 30.02713013], [76.21613312, 30.0286808], [76.21514893, 30.0296402], [76.21333313, 30.03035164], [76.21098328, 30.03092957], [76.20838928, 30.03144836], [76.20580292, 30.03203011], [76.20345306, 30.03273964], [76.20111847, 30.03367233], [76.19890594, 30.03482819], [76.19793701, 30.03625107], [76.19838715, 30.03792953], [76.19962311, 30.03977966], [76.20111084, 30.04164124], [76.20252991, 30.04331017], [76.20404053, 30.04483986], [76.2056427, 30.04628944], [76.20723724, 30.04779053], [76.20864105, 30.04939079], [76.20987701, 30.05106926], [76.21102905, 30.05282021], [76.2121582, 30.05458832], [76.21330261, 30.05633163], [76.2144928, 30.05808067], [76.21566772, 30.05981064], [76.21681976, 30.06155014], [76.21798706, 30.06329918], [76.21916199, 30.06502914], [76.22035217, 30.06674957], [76.2215271, 30.06848907], [76.22273254, 30.0702076], [76.22395325, 30.07194138], [76.22509766, 30.07366943], [76.22632599, 30.0753994], [76.22749329, 30.07713127], [76.22869873, 30.07886124], [76.22991943, 30.08056831], [76.23116302, 30.08226013], [76.23246002, 30.08394051], [76.23381042, 30.08558083], [76.2351532, 30.08719826], [76.23660278, 30.08884811], [76.23808289, 30.09046173], [76.23963165, 30.09203911], [76.24120331, 30.09353065], [76.242836, 30.09490967], [76.24455261, 30.09614944], [76.24672699, 30.09638977], [76.2492218, 30.09603119], [76.25093079, 30.09706116], [76.25237274, 30.0986824], [76.25358582, 30.10053062], [76.2545929, 30.10239983], [76.25499725, 30.10457993], [76.25377655, 30.10602951], [76.2517395, 30.1067028], [76.2494812, 30.1072197], [76.2470932, 30.10762024], [76.24469757, 30.10792923], [76.24238586, 30.10819054], [76.24006653, 30.10827827], [76.23771667, 30.10823059], [76.23539734, 30.108181], [76.233078, 30.10822105], [76.23082733, 30.10852051], [76.2286911, 30.10933113], [76.22667694, 30.11040115], [76.2248764, 30.11165047], [76.22316742, 30.11301994], [76.22123718, 30.11412048], [76.21920013, 30.11512184], [76.2171402, 30.11610985], [76.21518707, 30.11717987], [76.21343994, 30.11845016], [76.21193695, 30.11996269], [76.21058655, 30.12161064], [76.20928955, 30.12330055], [76.20791626, 30.12495995], [76.20639801, 30.12648964], [76.20471191, 30.12786102], [76.20262909, 30.12865829], [76.20038605, 30.12930107], [76.19837189, 30.13025093], [76.19632721, 30.13126945], [76.1943512, 30.13235092], [76.19249725, 30.13351059], [76.19061279, 30.13496017], [76.18962097, 30.13669014], [76.19055176, 30.13862991], [76.19230652, 30.14045906], [76.19410706, 30.1407795], [76.19590759, 30.13999176], [76.19777679, 30.13870049], [76.19969177, 30.13721085], [76.20162964, 30.13582993], [76.20365143, 30.13473129], [76.20580292, 30.13376045], [76.20794678, 30.13314819], [76.21008301, 30.13360977], [76.21192932, 30.13506126], [76.21266174, 30.13683128], [76.21156311, 30.1384716], [76.2100296, 30.1400795], [76.20851898, 30.14172173], [76.20744324, 30.14348984], [76.20706177, 30.14550018], [76.20632172, 30.14740944], [76.20511627, 30.14924049], [76.20375824, 30.15103912], [76.20259857, 30.15281105], [76.20195007, 30.15457153], [76.20236206, 30.15671158], [76.20387268, 30.15890121], [76.20558929, 30.15934944], [76.20720673, 30.15851021], [76.20884705, 30.15739059], [76.21053314, 30.15607834], [76.21224976, 30.15460968], [76.21395111, 30.1530304], [76.21565247, 30.15139008], [76.2173233, 30.1497612], [76.21897888, 30.14817047], [76.2205658, 30.14668083], [76.22202301, 30.14509964], [76.22336578, 30.14343834], [76.2247467, 30.14180946], [76.22628784, 30.14031029], [76.2280426, 30.1390419], [76.22997284, 30.1378994], [76.23191833, 30.13677979], [76.23375702, 30.13556862], [76.23539734, 30.13414955], [76.23680115, 30.13255119], [76.23816681, 30.13091087], [76.24095917, 30.12865829], [76.24299622, 30.12746811], [76.24458313, 30.1218605], [76.25115967, 30.11899948], [76.26551056, 30.11769295], [76.27202606, 30.11433983], [76.27984619, 30.11365128], [76.28636169, 30.11682129], [76.29308319, 30.11862946], [76.31275177, 30.10851288], [76.32289886, 30.10822105], [76.32837677, 30.10951042], [76.33790588, 30.11585045], [76.34892273, 30.12766075], [76.34829712, 30.13166046], [76.33570862, 30.13926125], [76.3286972, 30.14476967], [76.32588196, 30.14924049], [76.34306335, 30.1534481], [76.3483429, 30.15052032], [76.35816193, 30.13330269], [76.36374664, 30.12754059], [76.37471771, 30.12372971], [76.3843689, 30.1238327], [76.39000702, 30.12754059], [76.38845062, 30.13396835], [76.38832855, 30.13832855], [76.38456726, 30.14581108], [76.3861618, 30.14824104], [76.39251709, 30.15026093], [76.39951324, 30.15517044], [76.40164185, 30.1577282], [76.38861847, 30.17410088], [76.38304138, 30.17902946], [76.3809967, 30.18324089], [76.38674164, 30.18699074], [76.39100647, 30.19225121], [76.39884186, 30.1989994], [76.41020203, 30.20228958], [76.4200058, 30.19787979], [76.42858124, 30.1797924], [76.42900848, 30.1729908], [76.42642975, 30.16757965], [76.42243195, 30.16357994], [76.42227173, 30.15870094], [76.42488861, 30.15462112], [76.42604065, 30.14756012], [76.43135071, 30.14071083], [76.43631744, 30.13702965], [76.44104004, 30.13595963], [76.44645691, 30.1371212], [76.44618988, 30.12895966], [76.4444809, 30.12288094], [76.44664001, 30.11123085], [76.44909668, 30.10480118], [76.4520874, 30.10070992], [76.46157074, 30.09900093], [76.48348999, 30.09955978], [76.49082947, 30.0971508], [76.49517059, 30.09238815], [76.49501038, 30.08708191], [76.49713898, 30.08156967], [76.50112152, 30.07662964], [76.50894165, 30.07953072], [76.52554321, 30.0808506], [76.533638, 30.08278084], [76.55487061, 30.0987606], [76.55916595, 30.09804916], [76.56143951, 30.09763908], [76.56363678, 30.09711075], [76.56575012, 30.09626007], [76.56767273, 30.09511948], [76.5694809, 30.0938797], [76.57124329, 30.09255981], [76.57301331, 30.09123993], [76.57478333, 30.08995819], [76.57663727, 30.08876038], [76.57879639, 30.08784294], [76.58080292, 30.08685112], [76.5819397, 30.08521271], [76.58194733, 30.08312988], [76.58104706, 30.08127975], [76.57977295, 30.07953072], [76.57787323, 30.07771111], [76.57637787, 30.07611084], [76.57676697, 30.07509995], [76.57917023, 30.07459068], [76.58194733, 30.07467079], [76.58399963, 30.07543945], [76.58583069, 30.07674026], [76.58763885, 30.07814026], [76.58953094, 30.07929993], [76.59168243, 30.07974052], [76.59406281, 30.0795517], [76.59642029, 30.07947159], [76.59877777, 30.07970047], [76.60105133, 30.08023071], [76.60286713, 30.08131981], [76.6044693, 30.08272171], [76.60595703, 30.08428955], [76.60742188, 30.08589935], [76.60896301, 30.08745956], [76.61061096, 30.08886909], [76.61235046, 30.09020996], [76.61411285, 30.09150124], [76.6158905, 30.09278107], [76.61769867, 30.09406281], [76.61947632, 30.09536171], [76.62515259, 30.10184097], [76.62667084, 30.10564995], [76.62755585, 30.11048126], [76.62663269, 30.11396027], [76.62474823, 30.11688995], [76.62520599, 30.12103081], [76.62872314, 30.13019943], [76.62940216, 30.13476944], [76.62309265, 30.14466095], [76.62326813, 30.14940262], [76.62763977, 30.1551075], [76.6227417, 30.17029953], [76.63925171, 30.18521118], [76.641716, 30.18925095], [76.64198303, 30.19366837], [76.63716888, 30.19695091], [76.63891602, 30.20594025], [76.63282013, 30.21001053], [76.61675262, 30.21105957], [76.60941315, 30.21277046], [76.60427856, 30.21517181], [76.60627747, 30.22001076], [76.61186981, 30.22562981], [76.61199951, 30.23096848], [76.60930634, 30.23488045], [76.59942627, 30.24032974], [76.59590912, 30.24394035], [76.59031677, 30.25412178], [76.58399963, 30.25653076], [76.57588959, 30.25586128], [76.56904602, 30.2513504], [76.54766846, 30.23444176], [76.54438019, 30.23085976], [76.53253174, 30.22713089], [76.53292084, 30.23207855], [76.54219818, 30.23637962], [76.5459671, 30.24353981], [76.54692841, 30.24953079], [76.54582214, 30.25863075], [76.54763794, 30.26492119], [76.55792999, 30.26426125], [76.58094025, 30.26987076], [76.60449982, 30.27226067], [76.6098175, 30.27061081], [76.61437988, 30.27527046], [76.61969757, 30.28784943], [76.62283325, 30.29138947], [76.626297, 30.28392982], [76.65128326, 30.2993412], [76.66242981, 30.29955101], [76.67307281, 30.31277084], [76.67088318, 30.31917], [76.67462921, 30.32595062], [76.67949677, 30.32137108], [76.68846893, 30.32598114], [76.69767761, 30.32485771], [76.70025635, 30.32985115], [76.70475006, 30.33168983], [76.71096039, 30.32987022], [76.71515656, 30.33291054], [76.71515656, 30.33990097], [76.72392273, 30.34436989], [76.72901154, 30.34843254], [76.73462677, 30.35393906], [76.73853302, 30.35964966], [76.73501587, 30.36491013], [76.73039246, 30.36744118], [76.71135712, 30.36512947], [76.7089386, 30.36816978], [76.71808624, 30.37710953], [76.71572113, 30.38026047], [76.70487976, 30.38083267], [76.70168304, 30.38482857], [76.70014954, 30.39361191], [76.71289063, 30.39824295], [76.72654724, 30.40500069], [76.72516632, 30.42041969], [76.73786163, 30.42486954], [76.74887085, 30.42663193], [76.7543869, 30.43280983], [76.75786591, 30.43889046], [76.76332855, 30.43972969], [76.76674652, 30.43600082], [76.764328, 30.42501068], [76.77082062, 30.41830063], [76.78069305, 30.4150219], [76.79728699, 30.41512108], [76.80845642, 30.41185951], [76.82314301, 30.42254829], [76.82789612, 30.43033028], [76.8324585, 30.43388176], [76.83972931, 30.42074966], [76.84726715, 30.41489983], [76.86473083, 30.40879059], [76.86756134, 30.40151978], [76.86624146, 30.3948307], [76.87441254, 30.39128113], [76.88022614, 30.38622284], [76.88043213, 30.38298988], [76.87571716, 30.36954117], [76.87644196, 30.36333847], [76.88022614, 30.35970116], [76.88722229, 30.35838127], [76.89227295, 30.35967827], [76.89776611, 30.36260033], [76.90348816, 30.36750984], [76.91699219, 30.38275909], [76.92077637, 30.38478279], [76.9272995, 30.38863945], [76.93026733, 30.39258957], [76.93139648, 30.39707184], [76.92904663, 30.3998909], [76.92579651, 30.40159035], [76.91947174, 30.4030304], [76.90925598, 30.40327072], [76.90518188, 30.40468979], [76.90384674, 30.40670967], [76.90392303, 30.40995026], [76.90524292, 30.41319084], [76.90370178, 30.41823006], [76.90370941, 30.42488098], [76.90167999, 30.42832947], [76.88993073, 30.43669128], [76.88884735, 30.44111061], [76.89071655, 30.45106125], [76.89518738, 30.45556831], [76.8980484, 30.46778107], [76.89663696, 30.47537994], [76.8898468, 30.47932816], [76.88891602, 30.48458862], [76.89385986, 30.48964119], [76.90114594, 30.48884964], [76.9078064, 30.49078941], [76.91236877, 30.49365997], [76.91590881, 30.49942017], [76.91828918, 30.50723076], [76.92032623, 30.51802063], [76.92006683, 30.52469063], [76.91429901, 30.52655029], [76.90724945, 30.5298996], [76.89821625, 30.53470039], [76.88775635, 30.53815079], [76.88504028, 30.54042053], [76.89218903, 30.54444122], [76.90223694, 30.55104065], [76.90592957, 30.55838966], [76.90384674, 30.56171989], [76.89888763, 30.56402969], [76.89888763, 30.56671906], [76.90390778, 30.57518005], [76.90453339, 30.58057022], [76.89855957, 30.5884304], [76.9072113, 30.59140968], [76.91342926, 30.59970284], [76.91060638, 30.60582924], [76.90154266, 30.60840988], [76.89959717, 30.62002945], [76.89453888, 30.62333107], [76.88360596, 30.62709045], [76.88063049, 30.6330719], [76.87709045, 30.63702011], [76.87267303, 30.64002037], [76.86795807, 30.64163971], [76.86194611, 30.64027023], [76.85858154, 30.64063072], [76.85897064, 30.65155983], [76.86186218, 30.65971947], [76.86310577, 30.6715107], [76.86222839, 30.6792717], [76.85540771, 30.67320251], [76.84983826, 30.66485977], [76.83985901, 30.65678024], [76.83479309, 30.65582085], [76.83499908, 30.66411018], [76.83006287, 30.66493034], [76.82694244, 30.66333008], [76.82409668, 30.66007042], [76.81881714, 30.66059113], [76.818367, 30.67296028], [76.81980896, 30.68582916], [76.81770325, 30.69062996], [76.82110596, 30.69678116], [76.82829285, 30.70594978], [76.83629608, 30.71426964], [76.8343811, 30.72439957], [76.82480621, 30.7308197], [76.82274628, 30.74008179], [76.82818604, 30.76379013], [76.83081818, 30.76793289], [76.8467865, 30.79252052], [76.84134674, 30.79908943], [76.83351135, 30.80457115], [76.83335876, 30.81589127], [76.83209991, 30.82542038], [76.82775116, 30.83256912], [76.81894684, 30.83710098], [76.8065567, 30.84025192], [76.80121613, 30.84252167], [76.78494263, 30.8612709], [76.77333832, 30.87115097], [76.76904297, 30.87652969], [76.76254272, 30.89340973], [76.76985931, 30.90639114], [76.79876709, 30.92464066], [76.81018829, 30.93037987], [76.81339264, 30.92732048], [76.8143692, 30.92134094], [76.80979919, 30.90680122], [76.81575775, 30.89600945], [76.82266235, 30.88809967], [76.83715057, 30.87887192], [76.85243225, 30.87068939], [76.86178589, 30.87355042], [76.86962891, 30.87816048], [76.87858582, 30.88598251], [76.8865509, 30.88829994], [76.90216064, 30.89722824], [76.90706635, 30.89099121], [76.91584015, 30.86932945], [76.92661285, 30.85444069], [76.92780304, 30.84814072], [76.92751312, 30.83735275], [76.93370056, 30.83196259], [76.94283295, 30.8291893], [76.94764709, 30.82316971], [76.95375061, 30.81121063], [76.96180725, 30.80899048], [76.96864319, 30.80796051], [76.97910309, 30.79881287], [76.98264313, 30.80430031], [76.98477173, 30.81047249], [76.98652649, 30.81324959], [76.98845673, 30.81500053], [76.99266052, 30.81830025], [76.99584198, 30.81670952], [76.99796295, 30.814291], [76.9985199, 30.80973053], [76.9997406, 30.80490112], [77.00035095, 30.79762268], [76.99973297, 30.79397964], [77.00003052, 30.78902054], [76.99487305, 30.78507042], [76.99095917, 30.78065109], [76.98860168, 30.777071], [76.99121094, 30.77345276], [76.99524689, 30.77103996], [76.9988327, 30.76915169], [77.002388, 30.76795006], [77.0044632, 30.76634979], [77.00582123, 30.76175117], [77.00466156, 30.75735283], [77.00470734, 30.75248909], [77.00644684, 30.74950981], [77.00939178, 30.74571037], [77.01309967, 30.74220848], [77.01805115, 30.74044991], [77.02401733, 30.74162102], [77.02828979, 30.74344063], [77.03037262, 30.7463398], [77.03032684, 30.75176048], [77.03370667, 30.75542068], [77.03801727, 30.7531395], [77.04705811, 30.74867058], [77.05497742, 30.74674034], [77.06170654, 30.74612808], [77.06971741, 30.74698257], [77.07684326, 30.74476051], [77.08627319, 30.73994255], [77.09111786, 30.73621178], [77.09613037, 30.73462105], [77.10056305, 30.73238754], [77.10234833, 30.73077965], [77.1002121, 30.72639084], [77.09990692, 30.7222805], [77.1031723, 30.72044945], [77.10957336, 30.72268295], [77.1174469, 30.71791077], [77.12223816, 30.71216011], [77.12512207, 30.70709991], [77.13381958, 30.70215988], [77.14037323, 30.6975708], [77.14743805, 30.69347954], [77.15177155, 30.6905098], [77.15352631, 30.6887207], [77.15020752, 30.68455124], [77.15068817, 30.68119812], [77.153862, 30.67694283], [77.15519714, 30.6680603], [77.1526413, 30.65876007], [77.15273285, 30.6541996], [77.15619659, 30.64792061], [77.16044617, 30.64240074], [77.16236115, 30.63865089], [77.15986633, 30.63148117], [77.15863037, 30.61380959], [77.15847778, 30.60746002], [77.158638, 30.60314178], [77.15748596, 30.59955025], [77.15409851, 30.59632111], [77.15122223, 30.59283066], [77.14692688, 30.58896065], [77.1398468, 30.58320045], [77.1326828, 30.57845116], [77.12587738, 30.57369041], [77.12378693, 30.57269287], [77.12059021, 30.57118034], [77.11514282, 30.56984138], [77.11289215, 30.56824112], [77.11149597, 30.56728935], [77.11370087, 30.56244087], [77.11650848, 30.5574398], [77.12233734, 30.54823112], [77.13105774, 30.54150963], [77.13758087, 30.53857994], [77.14553833, 30.53779984], [77.15203857, 30.53691292], [77.16368866, 30.53412056], [77.16953278, 30.53288078], [77.17455292, 30.53051949], [77.18534851, 30.52588081], [77.19082642, 30.51932907], [77.19589233, 30.51177025], [77.19966125, 30.50659943], [77.19957733, 30.49913979], [77.20030975, 30.48904991], [77.19904327, 30.48454285], [77.2026062, 30.48034096], [77.21190643, 30.48187065], [77.21885681, 30.48598289], [77.22676849, 30.48861122], [77.23345947, 30.48747063], [77.24186707, 30.4853611], [77.25177765, 30.48441124], [77.2565918, 30.48142052], [77.26084137, 30.47612], [77.26193237, 30.47104073], [77.26358032, 30.46667099], [77.27455902, 30.46404076], [77.28244019, 30.46191978], [77.29373932, 30.45913124], [77.30069733, 30.45659828], [77.31069946, 30.45362091], [77.31677246, 30.45762062], [77.3223877, 30.46211815], [77.3262558, 30.46318245], [77.33267975, 30.46422958], [77.33937836, 30.46360016], [77.34607697, 30.46190071], [77.34970093, 30.45728111], [77.35349274, 30.44856071], [77.35679626, 30.44206047], [77.36965179, 30.44584274], [77.37621307, 30.44625092], [77.38038635, 30.44614029], [77.38186646, 30.43927193], [77.39409637, 30.43427086], [77.39679718, 30.43046951], [77.39546204, 30.4209404], [77.40061188, 30.41875076], [77.40763855, 30.42788124], [77.41723633, 30.4338398], [77.42620087, 30.44111824], [77.43559265, 30.45100975], [77.44568634, 30.46566963], [77.45053864, 30.46523094], [77.4562912, 30.45819092], [77.45677185, 30.45155907], [77.45429993, 30.44606018], [77.45334625, 30.44036102], [77.44204712, 30.42988968], [77.43972015, 30.42440033], [77.42569733, 30.42000008], [77.42092896, 30.41682243], [77.41590118, 30.41283035], [77.41644287, 30.40839195], [77.43041229, 30.40747833], [77.43495178, 30.40367126], [77.44301605, 30.40460014], [77.45311737, 30.40480042], [77.46098328, 30.40538025], [77.4679718, 30.4117794], [77.47751617, 30.41334915], [77.4825592, 30.41521835], [77.48683167, 30.41261292], [77.49134827, 30.41735077], [77.49118805, 30.42498016], [77.49294281, 30.43304825], [77.50115204, 30.44367981], [77.50534058, 30.44836044], [77.50984955, 30.44882965], [77.51436615, 30.43942261], [77.51803589, 30.43087006], [77.52577209, 30.41714096], [77.52925873, 30.41350174], [77.5356369, 30.40905952], [77.53874207, 30.40191269], [77.54289246, 30.39723015], [77.5524826, 30.39336014], [77.55792236, 30.39036942], [77.56534576, 30.3848896], [77.57489014, 30.38451958], [77.58444214, 30.38136101], [77.59012604, 30.37726021], [77.59201813, 30.37086105], [77.58278656, 30.35843849], [77.57463074, 30.34695053], [77.56989288, 30.33711052], [77.57009888, 30.3315506], [77.57501221, 30.32607079], [77.5738678, 30.3189106], [77.57035065, 30.31122971], [77.56355286, 30.30608177], [77.55577087, 30.30257034], [77.5453186, 30.29413986], [77.54042053, 30.29096985], [77.53218079, 30.2868576], [77.52677917, 30.28231239], [77.52468109, 30.2779808], [77.52250671, 30.26619911], [77.51983643, 30.26013184], [77.50550842, 30.24224091], [77.49598694, 30.23363113], [77.49372101, 30.2274704], [77.48853302, 30.21874046], [77.48390198, 30.2100811], [77.47997284, 30.20215988], [77.47677612, 30.19501114], [77.4732666, 30.188591], [77.46021271, 30.1837883], [77.45598602, 30.18096161], [77.45153809, 30.17362976], [77.44684601, 30.16860962], [77.44033813, 30.16920853], [77.43517303, 30.16995811], [77.43061066, 30.16642952], [77.42354584, 30.16847992], [77.41532135, 30.1566906], [77.41142273, 30.14969063], [77.41082764, 30.14587975], [77.41490173, 30.1434803], [77.41783905, 30.14118195], [77.41552734, 30.13349915], [77.41261292, 30.12771034], [77.40865326, 30.12320137], [77.40326691, 30.12105942], [77.39800262, 30.11872292], [77.40061188, 30.11326027], [77.40603638, 30.11130905], [77.41008759, 30.11108971], [77.4141922, 30.11111069], [77.41442871, 30.10713005], [77.40857697, 30.10255241], [77.39673615, 30.09576035], [77.39245605, 30.09441185], [77.38034058, 30.09304047], [77.37342834, 30.09301949], [77.36849976, 30.09155846], [77.35697937, 30.08415031], [77.34842682, 30.0766983], [77.33716583, 30.06824112], [77.33174133, 30.06445122], [77.32480621, 30.06180191], [77.31291199, 30.06053925], [77.30290985, 30.06058121], [77.29759216, 30.0603199], [77.29184723, 30.05849075], [77.28610992, 30.0574894], [77.2804184, 30.05251122], [77.27625275, 30.05047035], [77.27040863, 30.04833984], [77.2698822, 30.04422951], [77.27176666, 30.03991127], [77.27313995, 30.03404045], [77.26969147, 30.02746964], [77.26759338, 30.02210999], [77.26544189, 30.01803017], [77.26434326, 30.01305962], [77.26191711, 30.0073204], [77.26154327, 30.00561905], [77.26316071, 30.00214958], [77.25512695, 29.99596977], [77.25476074, 29.99316025], [77.25047302, 29.988451], [77.23548126, 29.98117256], [77.23310852, 29.97363091], [77.23194885, 29.96632195], [77.22957611, 29.96190262], [77.22489929, 29.95858955], [77.22373962, 29.95475006], [77.21112823, 29.94071007], [77.20256805, 29.9310894], [77.1955719, 29.92727089], [77.18913269, 29.92204285], [77.18689728, 29.91748047], [77.18591309, 29.91305161], [77.18016815, 29.90621185], [77.1795578, 29.90226936], [77.1848526, 29.89490128], [77.18496704, 29.89030838], [77.18229675, 29.88158989], [77.18245697, 29.87327957], [77.18006134, 29.86914063], [77.17810822, 29.86215973], [77.16758728, 29.84638977], [77.16703796, 29.84370995], [77.16903687, 29.82958031], [77.16526794, 29.82448959], [77.15564728, 29.81678963], [77.15396881, 29.81378174], [77.15209961, 29.80766106], [77.15171814, 29.80347061], [77.15400696, 29.79768944], [77.1523819, 29.79327965], [77.14222717, 29.78757095], [77.13743591, 29.78220177], [77.13199615, 29.77898026], [77.12349701, 29.7778492], [77.11828613, 29.77555084], [77.11704254, 29.77090073], [77.11889648, 29.76422119], [77.11785889, 29.76043129], [77.11421967, 29.75429153], [77.11295319, 29.74860001], [77.11515808, 29.74496078], [77.12256622, 29.74282074], [77.12255859, 29.73603821], [77.14021301, 29.7172718], [77.14332581, 29.70597076], [77.14260101, 29.70163918], [77.13987732, 29.70022964], [77.13218689, 29.69948006], [77.12552643, 29.69691086], [77.12110138, 29.69156075], [77.11917114, 29.68584061], [77.11997986, 29.6802597], [77.13114166, 29.66634941], [77.13130188, 29.66299057], [77.12941742, 29.65859032], [77.12180328, 29.65353966], [77.10970306, 29.64723969], [77.10782623, 29.63996124], [77.10489655, 29.63557816], [77.10106659, 29.63307953], [77.10160065, 29.62491989], [77.10047913, 29.62227249], [77.0945282, 29.61776924], [77.09388733, 29.61297035], [77.09218597, 29.60867119], [77.08561707, 29.60079956], [77.08680725, 29.59646988], [77.08989716, 29.59043121], [77.09378052, 29.5872097], [77.10198212, 29.57699966], [77.10675812, 29.56636047], [77.10971832, 29.55298996], [77.10443115, 29.54891014], [77.09529877, 29.54764938], [77.0894165, 29.54469109], [77.08622742, 29.53949928], [77.08490753, 29.53359032], [77.08648682, 29.52826118], [77.09761047, 29.51201248], [77.10340881, 29.50954056], [77.11451721, 29.50315857], [77.11989594, 29.49732971], [77.12332153, 29.4860611], [77.12039185, 29.48006058], [77.115448, 29.47540283], [77.1140213, 29.47029114], [77.11429596, 29.46186066], [77.117836, 29.45646095], [77.12413788, 29.45294189], [77.1319809, 29.45049095], [77.13774872, 29.44659042], [77.13938904, 29.44210052], [77.13845062, 29.43686295], [77.13577271, 29.43222046], [77.12487793, 29.42217064], [77.12586975, 29.41064072], [77.12908936, 29.40249062], [77.133461, 29.39843941], [77.14006805, 29.39472008], [77.14597321, 29.39248085], [77.14679718, 29.38977051], [77.13864899, 29.38390923], [77.13105011, 29.38070107], [77.12046814, 29.37877083], [77.11694336, 29.37668037], [77.11669922, 29.37257957], [77.11884308, 29.36195946], [77.11752319, 29.35715103], [77.12003326, 29.34979057], [77.12368774, 29.34498978], [77.12757874, 29.34433937], [77.14644623, 29.34506035], [77.1518631, 29.33929062], [77.15394592, 29.33547974], [77.15001678, 29.33169174], [77.15104675, 29.32551956], [77.1536026, 29.3222599], [77.15421295, 29.31692123], [77.1423111, 29.30151176], [77.14437103, 29.2961998], [77.13761902, 29.28746986], [77.12948608, 29.27279091], [77.13498688, 29.26649284], [77.14247894, 29.25160027], [77.14402008, 29.24333191], [77.14279938, 29.23779106], [77.12722015, 29.22814178], [77.12522125, 29.22487068], [77.12770081, 29.21842003], [77.13262939, 29.21311951], [77.1361618, 29.20745087], [77.13813782, 29.20106125], [77.13999176, 29.18208122], [77.13240814, 29.17181015], [77.12734222, 29.16291046], [77.12661743, 29.15402031], [77.13858032, 29.13476944], [77.13620758, 29.12784004], [77.12441254, 29.11346054], [77.12204742, 29.1057682], [77.12438202, 29.10148811], [77.13176727, 29.09464836], [77.14160156, 29.08681107], [77.14929962, 29.08324051], [77.15718842, 29.07753181], [77.162323, 29.06537247], [77.16163635, 29.05244064], [77.1626358, 29.04857063], [77.1765213, 29.03647041], [77.19159698, 29.02129173], [77.20379639, 29.01671982], [77.21113586, 29.01138115], [77.21404266, 29.00669098], [77.21418762, 29.00596046], [77.20790863, 28.99106026], [77.20375061, 28.9822998], [77.19095612, 28.96165085], [77.19013977, 28.95566177], [77.19078827, 28.94686127], [77.204422, 28.93997955], [77.20536804, 28.93646049], [77.19676971, 28.92093086], [77.20204926, 28.91555977], [77.21602631, 28.91143036], [77.22149658, 28.90813065], [77.22119141, 28.90413284], [77.21687317, 28.90034294], [77.20530701, 28.89460945], [77.19909668, 28.89268112], [77.18177032, 28.88980103], [77.17803955, 28.8855629], [77.17829132, 28.88004112], [77.18318939, 28.87177086], [77.18686676, 28.86681938], [77.18363953, 28.86230087], [77.16458893, 28.86063004], [77.1595993, 28.85744286], [77.15065002, 28.84844971], [77.14237976, 28.84247017], [77.1391983, 28.84166908], [77.13381195, 28.84472275], [77.1355896, 28.85268974], [77.13508606, 28.85848999], [77.12854004, 28.86539078], [77.10970306, 28.86613274], [77.10713196, 28.86845016], [77.09945679, 28.87244034], [77.08335114, 28.87461853], [77.07585144, 28.88451195], [77.07013702, 28.8800106], [77.06565857, 28.8730011], [77.04975891, 28.87318993], [77.03766632, 28.85277748], [77.03153992, 28.83679008], [77.02466583, 28.83628082], [77.01880646, 28.83706284], [77.00662994, 28.83526039], [76.98972321, 28.83916092], [76.98349762, 28.83908081], [76.97955322, 28.83670044], [76.97368622, 28.82583046], [76.9705658, 28.82510185], [76.96083069, 28.83167076], [76.95800781, 28.8303299], [76.95578003, 28.82002068], [76.94822693, 28.81766129], [76.94230652, 28.82068062], [76.93736267, 28.8091507], [76.93746948, 28.80350113], [76.94309235, 28.79512024], [76.94233704, 28.78775978], [76.94396973, 28.77853012], [76.94657135, 28.77403069], [76.93820953, 28.75962067], [76.9474411, 28.75113106], [76.95031738, 28.7466507], [76.94919586, 28.74150276], [76.95066071, 28.73645973], [76.94126129, 28.71702957], [76.95095825, 28.70976067], [76.95459747, 28.70537186], [76.954216, 28.7005291], [76.94999695, 28.69412994], [76.94838715, 28.68799019], [76.94595337, 28.68348122], [76.94725037, 28.67716026], [76.94255066, 28.67511177], [76.92973328, 28.6744194], [76.92310333, 28.66921043], [76.9174881, 28.65727043], [76.91821289, 28.65327072], [76.93390656, 28.63764954], [76.92597961, 28.62924957], [76.92366028, 28.62865067], [76.91034698, 28.63783073], [76.90400696, 28.63793945], [76.8972702, 28.63280106], [76.89367676, 28.63275146], [76.87793732, 28.63763046], [76.86090088, 28.60251045], [76.85481262, 28.59235191], [76.85022736, 28.59011841], [76.8350296, 28.59140015], [76.83291626, 28.58250809], [76.83761597, 28.55698967], [76.85674286, 28.54782104], [76.85920715, 28.54191971], [76.87631226, 28.52840042], [76.8794632, 28.52399826], [76.87380981, 28.51439095], [76.87937164, 28.50905037], [76.8868103, 28.51122856], [76.89372253, 28.51614189], [76.89745331, 28.51777077], [76.90847778, 28.51490974], [76.9226532, 28.51926994], [76.93321991, 28.5160408], [76.94462585, 28.51362991], [76.96846771, 28.52758026], [76.97653198, 28.52380943], [76.99027252, 28.51978111], [77.00554657, 28.51444054], [77.01093292, 28.51803017], [77.01139832, 28.52411079], [77.00499725, 28.52873993], [76.99820709, 28.53215027], [76.99594879, 28.53689957], [77.00020599, 28.54199982], [77.00609589, 28.54277992], [77.01566315, 28.53331947], [77.01963806, 28.53327179], [77.03314209, 28.52833939], [77.04165649, 28.51896095], [77.04876709, 28.51524162], [77.05696106, 28.5138607], [77.06746674, 28.52065086], [77.07247925, 28.52028084], [77.08598328, 28.51086044], [77.09031677, 28.5054512], [77.10352325, 28.49745941], [77.10766602, 28.49386978], [77.10334015, 28.48310852], [77.10154724, 28.47647858], [77.10273743, 28.47044945], [77.10604858, 28.46590042], [77.10874939, 28.45735168], [77.11251068, 28.45023155], [77.11830139, 28.4424305], [77.12407684, 28.43923759], [77.1313858, 28.43870163], [77.14243317, 28.43571091], [77.1518631, 28.42831993], [77.15434265, 28.4213028], [77.16577148, 28.40846062], [77.17948914, 28.41237068], [77.19522095, 28.4125309], [77.20590973, 28.41340065], [77.21530914, 28.41574097], [77.2227478, 28.41897011], [77.24061584, 28.42885971], [77.24318695, 28.43367958], [77.24430084, 28.44166946], [77.2432785, 28.44749069], [77.23986816, 28.45360756], [77.23311615, 28.45944977], [77.2264328, 28.46026039], [77.22574615, 28.46401024], [77.22763062, 28.46974945], [77.23239899, 28.47579956], [77.23673248, 28.47969055], [77.24265289, 28.48460007], [77.25396729, 28.48554039], [77.26010132, 28.48842812], [77.27111053, 28.49703026], [77.27805328, 28.49814987], [77.28578949, 28.49627113], [77.29627228, 28.4911499], [77.3009491, 28.49011993], [77.30686951, 28.49068069], [77.31488037, 28.49456978], [77.32170105, 28.49938965], [77.32668304, 28.50345039], [77.32898712, 28.50831985], [77.33447266, 28.51108932], [77.33773804, 28.50897026], [77.34319305, 28.50361061], [77.36048126, 28.49785995], [77.36396027, 28.49290085], [77.36412048, 28.48565102], [77.36936188, 28.4806881], [77.37600708, 28.47616005], [77.38816833, 28.47281837], [77.39789581, 28.47117043], [77.40003204, 28.4666996], [77.39483643, 28.46279907], [77.39779663, 28.45864105], [77.40828705, 28.45560074], [77.4181366, 28.45578957], [77.42578125, 28.45454025], [77.42829895, 28.44406128], [77.43599701, 28.43161011], [77.44399261, 28.42897034], [77.45147705, 28.42485809], [77.45610046, 28.42098808], [77.46869659, 28.41753006], [77.47455597, 28.41351128], [77.47386169, 28.40381241], [77.46684265, 28.39968109], [77.46953583, 28.39430046], [77.48589325, 28.37970161], [77.4920578, 28.36952019], [77.49423981, 28.35826111], [77.48517609, 28.35021019], [77.46640778, 28.34120941], [77.46375275, 28.33801079], [77.46592712, 28.33394051], [77.47355652, 28.32788086], [77.4818573, 28.32361984], [77.49578857, 28.30704117], [77.49417114, 28.30026054], [77.49476624, 28.29261017], [77.49273682, 28.28063011], [77.48808289, 28.27911949], [77.47225189, 28.28120995], [77.46481323, 28.27742958], [77.46730042, 28.26972008], [77.48707581, 28.26176071], [77.50206757, 28.25784111], [77.51062012, 28.25489044], [77.51159668, 28.25455093], [77.51225281, 28.25432968], [77.52501678, 28.25342941], [77.53878021, 28.25440979], [77.54120636, 28.2477417], [77.53562164, 28.24052048], [77.51557922, 28.22976112], [77.51703644, 28.22138977], [77.52157593, 28.21739006], [77.52327728, 28.20717049], [77.51911926, 28.20178032], [77.51281738, 28.20168114], [77.51056671, 28.20633125], [77.49759674, 28.21302032], [77.48912048, 28.21199036], [77.49061584, 28.19305992], [77.49211884, 28.18510056], [77.50151825, 28.18719101], [77.50566101, 28.19547081], [77.52082062, 28.19174004], [77.53018951, 28.1929493], [77.53794861, 28.19089127], [77.54236603, 28.1816597], [77.5317688, 28.17025948], [77.51159668, 28.16489029], [77.498909, 28.16300964], [77.49636841, 28.15987015], [77.49529266, 28.14581108], [77.48986816, 28.14438057], [77.48725128, 28.14143181], [77.48796082, 28.13878059], [77.49846649, 28.1356926], [77.49964142, 28.12735939], [77.49939728, 28.12259102], [77.49137115, 28.11271095], [77.49324036, 28.10817909], [77.49373627, 28.10227013], [77.49230957, 28.09801102], [77.49014282, 28.09529114], [77.48602295, 28.09739113], [77.48278046, 28.10785294], [77.47823334, 28.10797119], [77.47479248, 28.10428047], [77.47306824, 28.10371971], [77.46887207, 28.08601189], [77.47001648, 28.0837307], [77.47173309, 28.07875061], [77.47683716, 28.07331276], [77.48290253, 28.06071091], [77.48287201, 28.0589447], [77.48284912, 28.05764961], [77.47763824, 28.04910088], [77.47911072, 28.04416275], [77.48970795, 28.0393219], [77.49517059, 28.03429985], [77.49743652, 28.03063965], [77.50177002, 28.02737999], [77.50652313, 28.02234077], [77.50937653, 28.01772118], [77.5118866, 28.01025009], [77.52011108, 28.00654984], [77.53521729, 27.99333], [77.53215027, 27.98884964], [77.52667999, 27.98402023], [77.51344299, 27.97743988], [77.50958252, 27.97333145], [77.51059723, 27.96820831], [77.51502991, 27.9654808], [77.52900696, 27.96624947], [77.53591919, 27.96554947], [77.53733826, 27.95776939], [77.53613281, 27.94930267], [77.53137207, 27.94181824], [77.51921082, 27.93188095], [77.5137558, 27.93634033], [77.51116943, 27.9374218], [77.50585938, 27.93614006], [77.49777985, 27.93141174], [77.49537659, 27.93077087], [77.49225616, 27.93180847], [77.49060059, 27.93394852], [77.48796082, 27.94145012], [77.48474884, 27.94391251], [77.47766113, 27.94021034], [77.46872711, 27.93291092], [77.46845245, 27.93188095], [77.47059631, 27.92789268], [77.47086334, 27.92061043], [77.47245026, 27.9192009], [77.474617, 27.91206169], [77.4724884, 27.90120125], [77.46981812, 27.89472961], [77.45848846, 27.88529968], [77.44584656, 27.87840843], [77.44219971, 27.87848091], [77.430336, 27.88884163], [77.42220306, 27.89447975], [77.41423035, 27.89652061], [77.41229248, 27.89615822], [77.41104126, 27.89501953], [77.40709686, 27.88912964], [77.40409088, 27.88661003], [77.40155029, 27.88190079], [77.40453339, 27.8758297], [77.40512848, 27.87174988], [77.40629578, 27.86967087], [77.41369629, 27.86260033], [77.41442108, 27.86069107], [77.41239166, 27.85907173], [77.40377808, 27.85824013], [77.39282227, 27.85894966], [77.38208008, 27.86309052], [77.37388611, 27.86370277], [77.37001038, 27.86313057], [77.36483002, 27.86059189], [77.35264587, 27.8564415], [77.34406281, 27.85898972], [77.33933258, 27.85959053], [77.33265686, 27.85489082], [77.33120728, 27.85268021], [77.32924652, 27.85198975], [77.32406616, 27.8408699], [77.32733154, 27.83772087], [77.32211304, 27.83472061], [77.31719208, 27.83324051], [77.31292725, 27.83005142], [77.30632019, 27.83200073], [77.3048172, 27.83123016], [77.29915619, 27.83138275], [77.28888702, 27.82913971], [77.29062653, 27.81970978], [77.28970337, 27.81783295], [77.28347778, 27.81591988], [77.27934265, 27.8119812], [77.27707672, 27.80673981], [77.27577972, 27.80654907], [77.26748657, 27.81196022], [77.26249695, 27.81611061], [77.25805664, 27.80929947], [77.25699615, 27.80525017], [77.25284576, 27.79763985], [77.24794769, 27.79375076], [77.24088287, 27.7903595], [77.23455811, 27.78581047], [77.23174286, 27.78580093], [77.22724915, 27.78865814], [77.22870636, 27.79310036], [77.22685242, 27.79610062], [77.22215271, 27.79764938], [77.21684265, 27.7954998], [77.20677185, 27.80105972], [77.20571136, 27.80548096], [77.20210266, 27.81257057], [77.19676208, 27.81944084], [77.19384766, 27.82193947], [77.18747711, 27.81504822], [77.18659973, 27.81048012], [77.18894196, 27.79842949], [77.17556, 27.78722191], [77.16870117, 27.78490067], [77.16400909, 27.78691101], [77.16216278, 27.79059029], [77.16660309, 27.79591942], [77.16924286, 27.80056953], [77.17814636, 27.80252075], [77.18044281, 27.80443192], [77.18065643, 27.80865288], [77.1758728, 27.81445122], [77.17237854, 27.81632042], [77.16108704, 27.81318855], [77.15666199, 27.81360054], [77.15209961, 27.8157711], [77.15061951, 27.81555939], [77.14972687, 27.81243134], [77.15354156, 27.80243111], [77.15329742, 27.79785919], [77.15142822, 27.79181099], [77.14727783, 27.78665924], [77.14142609, 27.78623009], [77.13535309, 27.78395081], [77.12652588, 27.77646065], [77.12520599, 27.77693176], [77.12467194, 27.78483963], [77.12210846, 27.7883091], [77.11997223, 27.78947067], [77.11741638, 27.79019165], [77.11476898, 27.78988075], [77.10748291, 27.78665924], [77.10263062, 27.78518105], [77.10116577, 27.78549194], [77.09362793, 27.78970146], [77.08023071, 27.80039024], [77.07663727, 27.8014698], [77.07427216, 27.80435181], [77.07241058, 27.80952072], [77.06848145, 27.81157112], [77.06529236, 27.81258011], [77.05625153, 27.81146049], [77.05182648, 27.81516075], [77.04682159, 27.81809044], [77.04514313, 27.81698036], [77.03827667, 27.82004166], [77.03504944, 27.81666183], [77.03539276, 27.81410027], [77.03457642, 27.81252289], [77.03038025, 27.81142998], [77.02398682, 27.79817009], [77.0230484, 27.78718948], [77.0197525, 27.78032112], [77.02066803, 27.77812004], [77.02276611, 27.77794838], [77.024086, 27.77700996], [77.02672577, 27.77791023], [77.02841187, 27.78029823], [77.03943634, 27.77490044], [77.04692841, 27.76798058], [77.05010223, 27.76104164], [77.05422974, 27.76189995], [77.05603027, 27.7643795], [77.06181335, 27.76568985], [77.06733704, 27.76375961], [77.0707016, 27.75884056], [77.07118988, 27.75192261], [77.07253265, 27.74909973], [77.07840729, 27.74287987], [77.07943726, 27.74019051], [77.079216, 27.73841095], [77.07797241, 27.73734093], [77.07113647, 27.73574066], [77.06572723, 27.73241043], [77.05944824, 27.73135948], [77.0532074, 27.7278595], [77.05065918, 27.72811127], [77.04427338, 27.73224068], [77.04271698, 27.73590279], [77.0402832, 27.73835945], [77.0393219, 27.7415905], [77.03649902, 27.74462128], [77.03196716, 27.74841118], [77.02894592, 27.74937057], [77.02485657, 27.74712944], [77.01680756, 27.74776077], [77.01140594, 27.74651909], [77.00502014, 27.73913956], [77.00337219, 27.73855019], [77.00099182, 27.73851967], [76.99437714, 27.74204254], [76.9935379, 27.74170113], [76.9913559, 27.73642921], [76.98912811, 27.73377991], [76.98744965, 27.72928047], [76.98277283, 27.71850014], [76.97910309, 27.70615959], [76.97608185, 27.69285011], [76.97312927, 27.68042183], [76.97229767, 27.67287064], [76.97033691, 27.66545105], [76.97049713, 27.65714264], [76.96022797, 27.66242027], [76.95153809, 27.66625023], [76.94478607, 27.67057037], [76.93844604, 27.67366982], [76.93419647, 27.67510033], [76.93028259, 27.67170906], [76.92684174, 27.66543007], [76.92385101, 27.66073036], [76.91899109, 27.66148186], [76.91382599, 27.65960121], [76.90947723, 27.65680122], [76.90540314, 27.65596962], [76.90262604, 27.65851974], [76.90052795, 27.6634407], [76.90009308, 27.66803932], [76.89715576, 27.67243004], [76.89322662, 27.67687988], [76.89164734, 27.67988968], [76.89401245, 27.68333054], [76.89673615, 27.68596077], [76.89473724, 27.68965912], [76.8886261, 27.69284058], [76.88311768, 27.69549942], [76.88092041, 27.69936943], [76.88284302, 27.70337105], [76.88802338, 27.70167923], [76.89350891, 27.69826126], [76.9003067, 27.69462967], [76.90600586, 27.69584084], [76.91036224, 27.69664955], [76.91456604, 27.70082092], [76.91220093, 27.70610046], [76.90830994, 27.71208954], [76.90278625, 27.7164402], [76.89539337, 27.71850967], [76.88854218, 27.71955109], [76.88334656, 27.72442245], [76.88407898, 27.73090935], [76.88786316, 27.73721123], [76.89060974, 27.74201965], [76.8914032, 27.76119041], [76.89232635, 27.77203178], [76.89363861, 27.7792511], [76.89560699, 27.78614044], [76.89865112, 27.79108047], [76.90392303, 27.79488945], [76.90280151, 27.80128098], [76.90660095, 27.80765915], [76.90524292, 27.81255913], [76.900383, 27.82114983], [76.90106964, 27.82541847], [76.90377808, 27.83266068], [76.90788269, 27.83591843], [76.91499329, 27.83461952], [76.92193604, 27.83183098], [76.92664337, 27.83422089], [76.92809296, 27.84398079], [76.92990875, 27.85523033], [76.92829895, 27.86713028], [76.9247818, 27.876791], [76.92610931, 27.88837051], [76.92608643, 27.89442062], [76.93817902, 27.89599037], [76.93673706, 27.90754128], [76.93881989, 27.91902924], [76.92993927, 27.92136002], [76.92127991, 27.92105293], [76.9190979, 27.92486], [76.91909027, 27.94082069], [76.91954041, 27.95283127], [76.92276764, 27.96577072], [76.92492676, 27.97836113], [76.9223175, 27.9858284], [76.91864777, 27.99761009], [76.92163086, 28.00568962], [76.92658234, 28.01250076], [76.93074036, 28.03050041], [76.93186188, 28.04202271], [76.93364716, 28.04813004], [76.93777466, 28.0589447], [76.93802643, 28.05961037], [76.94252777, 28.06682014], [76.94655609, 28.07134056], [76.94806671, 28.0786705], [76.95107269, 28.09608841], [76.955513, 28.11174965], [76.95582581, 28.12371826], [76.96176147, 28.14401054], [76.95654297, 28.14600945], [76.94174194, 28.14870071], [76.94052887, 28.15092087], [76.94156647, 28.15517044], [76.93781281, 28.15534973], [76.92753601, 28.15891266], [76.92105103, 28.16225052], [76.91204834, 28.17185974], [76.8991394, 28.17932129], [76.89009094, 28.18782806], [76.88404846, 28.19165993], [76.88387299, 28.19473076], [76.88574219, 28.1967411], [76.89984894, 28.20476913], [76.89668274, 28.20763016], [76.88668823, 28.21049118], [76.8792572, 28.21038055], [76.86618042, 28.21152115], [76.86580658, 28.21795845], [76.8636322, 28.22463989], [76.85772705, 28.22317123], [76.8543396, 28.22524071], [76.85048676, 28.22666931], [76.83342743, 28.2248497], [76.82724762, 28.21749115], [76.82382965, 28.2147007], [76.8189621, 28.21469116], [76.81323242, 28.21631241], [76.80580902, 28.21589088], [76.80136871, 28.21160126], [76.80246735, 28.20463181], [76.80560303, 28.20038033], [76.8026123, 28.19607162], [76.79788971, 28.19437981], [76.79384613, 28.19955063], [76.79309845, 28.19832993], [76.79025269, 28.19375992], [76.79225922, 28.18292046], [76.79228973, 28.17566109], [76.79614258, 28.17048073], [76.79148865, 28.15724182], [76.7830658, 28.1556797], [76.77294159, 28.15142059], [76.76216888, 28.1500206], [76.75508118, 28.14661026], [76.73912811, 28.12903976], [76.73295593, 28.12857246], [76.7315979, 28.12845039], [76.720047, 28.13153076], [76.70996094, 28.13236046], [76.708992, 28.13138008], [76.70543671, 28.12772751], [76.69876099, 28.11571121], [76.69494629, 28.11529922], [76.69024658, 28.11478996], [76.6894989, 28.1135006], [76.68564606, 28.10688019], [76.68218231, 28.09777069], [76.67790985, 28.09781075], [76.6639328, 28.0978508], [76.6579895, 28.0990715], [76.65122986, 28.0967598], [76.64785004, 28.09221077], [76.64697266, 28.08510971], [76.64804077, 28.07908058], [76.64792633, 28.06767082], [76.64892578, 28.06171036], [76.6501236, 28.0589447], [76.65162659, 28.05548286], [76.65099335, 28.0444603], [76.65341949, 28.03992081], [76.65962219, 28.03367043], [76.66146088, 28.0293026], [76.66240692, 28.02294159], [76.66007233, 28.0190506], [76.65455627, 28.01556969], [76.64671326, 28.01262093], [76.63687897, 28.01066017], [76.62534332, 28.01046944], [76.6159668, 28.0112896], [76.60389709, 28.01079178], [76.59896851, 28.00984001], [76.59523773, 28.00614929], [76.59175873, 28.00365829], [76.58381653, 28.0003109], [76.57727051, 27.99487114], [76.57382965, 27.98901939], [76.56749725, 27.98357964], [76.55979156, 27.98178291], [76.55343628, 27.9750309], [76.54659271, 27.9713707], [76.53819275, 27.970541], [76.53350067, 27.97372818], [76.53103638, 27.97932816], [76.53193665, 27.98570061], [76.53553772, 27.99306107], [76.53640747, 28.00473022], [76.53845215, 28.00537109], [76.53774261, 28.00751114], [76.53862, 28.01206017], [76.53855133, 28.01670074], [76.53553009, 28.02571106], [76.53852081, 28.03911972], [76.53124237, 28.0431118], [76.52585602, 28.0454483], [76.51859283, 28.03896141], [76.51140594, 28.03536034], [76.50522614, 28.03503036], [76.49949646, 28.03635979], [76.49848938, 28.04018021], [76.49604797, 28.04364014], [76.49221802, 28.04709816], [76.48307037, 28.0463295], [76.47570801, 28.04405975], [76.46170044, 28.04457283], [76.45574188, 28.04648018], [76.45372772, 28.04966927], [76.4540329, 28.05507278], [76.45624542, 28.0589447], [76.45797729, 28.06197166], [76.47129822, 28.06110954], [76.48087311, 28.0589447], [76.48381805, 28.05828094], [76.48780823, 28.0589447], [76.48957825, 28.05924034], [76.49453735, 28.0610714], [76.49765778, 28.0647316], [76.49537659, 28.0676403], [76.48590088, 28.07512093], [76.46988678, 28.08632088], [76.46360779, 28.0840683], [76.45881653, 28.08500099], [76.45343018, 28.08778954], [76.44857025, 28.09317017], [76.45121765, 28.09766006], [76.4539032, 28.10589027], [76.45688629, 28.11038971], [76.46092987, 28.11190033], [76.4662323, 28.11297035], [76.47254181, 28.11271095], [76.47728729, 28.10598946], [76.48874664, 28.10473061], [76.49780273, 28.10662079], [76.49729156, 28.11597824], [76.49809265, 28.12253952], [76.4868927, 28.12281036], [76.48574066, 28.12812042], [76.48972321, 28.13367844], [76.48509216, 28.13490105], [76.48329163, 28.13484764], [76.47722626, 28.13467026], [76.47319031, 28.13573074], [76.46996307, 28.13850021], [76.47233582, 28.14960098], [76.47099304, 28.15474129], [76.46517944, 28.15561104], [76.46109009, 28.15237045], [76.45604706, 28.15142822], [76.43712616, 28.15215111], [76.43135834, 28.14757156], [76.42729187, 28.14594078], [76.4122467, 28.1474781], [76.39704132, 28.14779282], [76.39302826, 28.14105034], [76.38851166, 28.13952065], [76.3840332, 28.13986015], [76.37677002, 28.13807106], [76.35983276, 28.14338112], [76.35740662, 28.14785194], [76.35597229, 28.1597805], [76.3532486, 28.1661911], [76.34259796, 28.17393112], [76.33590698, 28.17734146], [76.32595825, 28.17743111], [76.30871582, 28.18336105], [76.30496216, 28.18386078], [76.29802704, 28.18287086], [76.28885651, 28.1826725], [76.27906799, 28.17872047], [76.2767868, 28.17276001], [76.27818298, 28.16857147], [76.2930069, 28.16527939], [76.29852295, 28.16254807], [76.29846954, 28.15944862], [76.29506683, 28.15705109], [76.29590607, 28.15467072], [76.30155945, 28.15100098], [76.30821228, 28.15088081], [76.31111908, 28.15467072], [76.31732941, 28.15306091], [76.32274628, 28.14921761], [76.33100891, 28.13896942], [76.33759308, 28.13484764], [76.34321594, 28.13277054], [76.34934235, 28.13215065], [76.35560608, 28.12845039], [76.34350586, 28.11321831], [76.3395462, 28.10969925], [76.33188629, 28.10671806], [76.31417847, 28.11212921], [76.30802917, 28.11128044], [76.30132294, 28.10620117], [76.29740143, 28.10104942], [76.30716705, 28.09645271], [76.31344604, 28.09467125], [76.32054901, 28.09431267], [76.32488251, 28.09215927], [76.32879639, 28.08776093], [76.33126831, 28.08164978], [76.33213806, 28.07678986], [76.33734894, 28.07306099], [76.34436798, 28.07386971], [76.35048676, 28.07578087], [76.354599, 28.07420158], [76.35328674, 28.06557274], [76.35081482, 28.0589447], [76.34591675, 28.04578972], [76.34126282, 28.0360508], [76.33679962, 28.02966118], [76.32995605, 28.02487946], [76.32367706, 28.02384186], [76.31659698, 28.02099037], [76.29715729, 28.02596092], [76.29012299, 28.0298996], [76.28811646, 28.04204941], [76.29007721, 28.04911041], [76.28200531, 28.0589447], [76.27178955, 28.06638908], [76.2649231, 28.06874084], [76.25109863, 28.07092094], [76.24356842, 28.06893921], [76.23542786, 28.0589447], [76.23336792, 28.05642128], [76.22593689, 28.05518913], [76.20833588, 28.05556107], [76.20431519, 28.0589447], [76.20363617, 28.05952072], [76.19991302, 28.06075096], [76.19284821, 28.05981064], [76.17733765, 28.05925941], [76.17722321, 28.0589447], [76.17545319, 28.05425072], [76.17688751, 28.04895973], [76.18318176, 28.04302025], [76.19342804, 28.03523064], [76.19818115, 28.03494835], [76.2041626, 28.04224968], [76.21356201, 28.04018021], [76.21382904, 28.03168106], [76.20346069, 28.03036118], [76.20038605, 28.02567101], [76.19587708, 28.02173805], [76.19068146, 28.02141953], [76.1838913, 28.0235405], [76.1795578, 28.02329254], [76.174263, 28.02190971], [76.16938782, 28.01685905], [76.15872192, 28.00455093], [76.15493774, 27.99899101], [76.15386963, 27.99253082], [76.16246796, 27.98830986], [76.16098022, 27.98010063], [76.16703796, 27.97915268], [76.17421722, 27.97521019], [76.17946625, 27.97284126], [76.17817688, 27.96747017], [76.17629242, 27.96105957], [76.17693329, 27.95506096], [76.17636871, 27.94831085], [76.17476654, 27.94124985], [76.17037201, 27.93329048], [76.16765594, 27.92835045], [76.16607666, 27.92098999], [76.16645813, 27.91506958], [76.1697464, 27.90974998], [76.17516327, 27.90710068], [76.18261719, 27.90507126], [76.19095612, 27.90269089], [76.19863892, 27.89899063], [76.20012665, 27.8923111], [76.19975281, 27.88809967], [76.19444275, 27.88394165], [76.19032288, 27.88157845], [76.18901062, 27.87636948], [76.19135284, 27.86942863], [76.1931076, 27.86391258], [76.19895172, 27.85967064], [76.2050705, 27.85552025], [76.20594788, 27.84799004], [76.21063232, 27.84481812], [76.22328186, 27.84093094], [76.21380615, 27.8325882], [76.20773315, 27.82849121], [76.20054626, 27.82891083], [76.19412994, 27.83121109], [76.1904068, 27.82676125], [76.18624115, 27.81904984], [76.18041992, 27.81241035], [76.17292023, 27.80746078], [76.16734314, 27.80914116], [76.1628418, 27.81484032], [76.15319061, 27.82129288], [76.14267731, 27.82783127], [76.12776947, 27.83320045], [76.12822723, 27.83784103], [76.12845612, 27.84692192], [76.12213898, 27.85440063], [76.11258698, 27.85858154], [76.10334778, 27.86237907], [76.09577179, 27.8647995], [76.0880661, 27.86844826], [76.08563995, 27.86522293], [76.08476257, 27.85639], [76.08009338, 27.8510704]]]}}, {\\\"id\\\": \\\"11\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.13_1\\\", \\\"HASC_1\\\": \\\"IN.HP\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Himachal Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -5.0, \\\"dalys_apm25_rate_6cod_mean_total\\\": 569.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1423.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -854.0, \\\"geo-id\\\": 11, \\\"hpm25_child_popweighted\\\": -143.3, \\\"hpm25_female_popweighted\\\": -164.7, \\\"hpm25_male_popweighted\\\": -118.6, \\\"location\\\": \\\"Himachal Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 1300.0, \\\"mort_hpm25_6cod_mean_total\\\": -2862.0, \\\"mort_tpm25_6cod_mean_total\\\": -1562.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[77.80056, 30.51316071], [77.79917908, 30.51139069], [77.79389954, 30.50860023], [77.78819275, 30.5060997], [77.76761627, 30.5043602], [77.76344299, 30.50024986], [77.75504303, 30.49832916], [77.74752808, 30.49404907], [77.73658752, 30.48725128], [77.72927856, 30.48233986], [77.72144318, 30.47776985], [77.71122742, 30.47727013], [77.70466614, 30.47340012], [77.69918823, 30.4686985], [77.69008636, 30.46294022], [77.68219757, 30.45769119], [77.67906952, 30.45173073], [77.66160583, 30.44878006], [77.65320587, 30.44954109], [77.64665222, 30.45245934], [77.6402359, 30.45235062], [77.63783264, 30.44948769], [77.63568115, 30.44433975], [77.63333893, 30.43976974], [77.63054657, 30.43615913], [77.61672211, 30.43623161], [77.61200714, 30.43840027], [77.60375214, 30.43744087], [77.59041595, 30.43378067], [77.58106995, 30.43029976], [77.57463074, 30.42651939], [77.56790161, 30.4217186], [77.56288147, 30.41707993], [77.5622406, 30.41006279], [77.56305695, 30.40448952], [77.56785583, 30.39875984], [77.57292175, 30.3930912], [77.57615662, 30.38989067], [77.57489014, 30.38451958], [77.56534576, 30.3848896], [77.55792236, 30.39036942], [77.5524826, 30.39336014], [77.54289246, 30.39723015], [77.53874207, 30.40191269], [77.5356369, 30.40905952], [77.52925873, 30.41350174], [77.52577209, 30.41714096], [77.51803589, 30.43087006], [77.51436615, 30.43942261], [77.50984955, 30.44882965], [77.50534058, 30.44836044], [77.50115204, 30.44367981], [77.49294281, 30.43304825], [77.49118805, 30.42498016], [77.49134827, 30.41735077], [77.48683167, 30.41261292], [77.4825592, 30.41521835], [77.47751617, 30.41334915], [77.4679718, 30.4117794], [77.46098328, 30.40538025], [77.45311737, 30.40480042], [77.44301605, 30.40460014], [77.43495178, 30.40367126], [77.43041229, 30.40747833], [77.41644287, 30.40839195], [77.41590118, 30.41283035], [77.42092896, 30.41682243], [77.42569733, 30.42000008], [77.43972015, 30.42440033], [77.44204712, 30.42988968], [77.45334625, 30.44036102], [77.45429993, 30.44606018], [77.45677185, 30.45155907], [77.4562912, 30.45819092], [77.45053864, 30.46523094], [77.44568634, 30.46566963], [77.43559265, 30.45100975], [77.42620087, 30.44111824], [77.41723633, 30.4338398], [77.40763855, 30.42788124], [77.40061188, 30.41875076], [77.39546204, 30.4209404], [77.39679718, 30.43046951], [77.39409637, 30.43427086], [77.38186646, 30.43927193], [77.38038635, 30.44614029], [77.37621307, 30.44625092], [77.36965179, 30.44584274], [77.35679626, 30.44206047], [77.35349274, 30.44856071], [77.34970093, 30.45728111], [77.34607697, 30.46190071], [77.33937836, 30.46360016], [77.33267975, 30.46422958], [77.3262558, 30.46318245], [77.3223877, 30.46211815], [77.31677246, 30.45762062], [77.31069946, 30.45362091], [77.30069733, 30.45659828], [77.29373932, 30.45913124], [77.28244019, 30.46191978], [77.27455902, 30.46404076], [77.26358032, 30.46667099], [77.26193237, 30.47104073], [77.26084137, 30.47612], [77.2565918, 30.48142052], [77.25177765, 30.48441124], [77.24186707, 30.4853611], [77.23345947, 30.48747063], [77.22676849, 30.48861122], [77.21885681, 30.48598289], [77.21190643, 30.48187065], [77.2026062, 30.48034096], [77.19904327, 30.48454285], [77.20030975, 30.48904991], [77.19957733, 30.49913979], [77.19966125, 30.50659943], [77.19589233, 30.51177025], [77.19082642, 30.51932907], [77.18534851, 30.52588081], [77.17455292, 30.53051949], [77.16953278, 30.53288078], [77.16368866, 30.53412056], [77.15203857, 30.53691292], [77.14553833, 30.53779984], [77.13758087, 30.53857994], [77.13105774, 30.54150963], [77.12233734, 30.54823112], [77.11650848, 30.5574398], [77.11370087, 30.56244087], [77.11149597, 30.56728935], [77.11289215, 30.56824112], [77.11514282, 30.56984138], [77.12059021, 30.57118034], [77.12378693, 30.57269287], [77.12587738, 30.57369041], [77.1326828, 30.57845116], [77.1398468, 30.58320045], [77.14692688, 30.58896065], [77.15122223, 30.59283066], [77.15409851, 30.59632111], [77.15748596, 30.59955025], [77.158638, 30.60314178], [77.15847778, 30.60746002], [77.15863037, 30.61380959], [77.15986633, 30.63148117], [77.16236115, 30.63865089], [77.16044617, 30.64240074], [77.15619659, 30.64792061], [77.15273285, 30.6541996], [77.1526413, 30.65876007], [77.15519714, 30.6680603], [77.153862, 30.67694283], [77.15068817, 30.68119812], [77.15020752, 30.68455124], [77.15352631, 30.6887207], [77.15177155, 30.6905098], [77.14743805, 30.69347954], [77.14037323, 30.6975708], [77.13381958, 30.70215988], [77.12512207, 30.70709991], [77.12223816, 30.71216011], [77.1174469, 30.71791077], [77.10957336, 30.72268295], [77.1031723, 30.72044945], [77.09990692, 30.7222805], [77.1002121, 30.72639084], [77.10234833, 30.73077965], [77.10056305, 30.73238754], [77.09613037, 30.73462105], [77.09111786, 30.73621178], [77.08627319, 30.73994255], [77.07684326, 30.74476051], [77.06971741, 30.74698257], [77.06170654, 30.74612808], [77.05497742, 30.74674034], [77.04705811, 30.74867058], [77.03801727, 30.7531395], [77.03370667, 30.75542068], [77.03032684, 30.75176048], [77.03037262, 30.7463398], [77.02828979, 30.74344063], [77.02401733, 30.74162102], [77.01805115, 30.74044991], [77.01309967, 30.74220848], [77.00939178, 30.74571037], [77.00644684, 30.74950981], [77.00470734, 30.75248909], [77.00466156, 30.75735283], [77.00582123, 30.76175117], [77.0044632, 30.76634979], [77.002388, 30.76795006], [76.9988327, 30.76915169], [76.99524689, 30.77103996], [76.99121094, 30.77345276], [76.98860168, 30.777071], [76.99095917, 30.78065109], [76.99487305, 30.78507042], [77.00003052, 30.78902054], [76.99973297, 30.79397964], [77.00035095, 30.79762268], [76.9997406, 30.80490112], [76.9985199, 30.80973053], [76.99796295, 30.814291], [76.99584198, 30.81670952], [76.99266052, 30.81830025], [76.98845673, 30.81500053], [76.98652649, 30.81324959], [76.98477173, 30.81047249], [76.98264313, 30.80430031], [76.97910309, 30.79881287], [76.96864319, 30.80796051], [76.96180725, 30.80899048], [76.95375061, 30.81121063], [76.94764709, 30.82316971], [76.94283295, 30.8291893], [76.93370056, 30.83196259], [76.92751312, 30.83735275], [76.92780304, 30.84814072], [76.92661285, 30.85444069], [76.91584015, 30.86932945], [76.90706635, 30.89099121], [76.90216064, 30.89722824], [76.8865509, 30.88829994], [76.87858582, 30.88598251], [76.86962891, 30.87816048], [76.86178589, 30.87355042], [76.85243225, 30.87068939], [76.83715057, 30.87887192], [76.82266235, 30.88809967], [76.81575775, 30.89600945], [76.80979919, 30.90680122], [76.8143692, 30.92134094], [76.81339264, 30.92732048], [76.81018829, 30.93037987], [76.79876709, 30.92464066], [76.76985931, 30.90639114], [76.75383759, 30.91781807], [76.75411987, 30.92295265], [76.74868774, 30.92379951], [76.74862671, 30.92916107], [76.74382019, 30.92904091], [76.7383728, 30.93005943], [76.72602081, 30.93933105], [76.72547913, 30.9425106], [76.72413635, 30.9505825], [76.71260071, 30.96342087], [76.70507813, 30.9633007], [76.69837952, 30.96889114], [76.69615936, 30.97179031], [76.69423676, 30.97249031], [76.66819, 30.96988106], [76.6626358, 30.97113037], [76.65306091, 30.98180962], [76.63334656, 30.99072266], [76.62592316, 30.9924984], [76.62094879, 30.99830055], [76.61241913, 31.0020504], [76.61006927, 31.0042305], [76.61360168, 31.02198982], [76.60518646, 31.03351974], [76.60151672, 31.04356194], [76.59896851, 31.05355072], [76.60952759, 31.06067085], [76.60489655, 31.07837868], [76.60782623, 31.08350182], [76.61184692, 31.09638977], [76.62573242, 31.11024284], [76.62371063, 31.11800957], [76.61559296, 31.12158012], [76.60727692, 31.11964035], [76.59744263, 31.12619972], [76.58931732, 31.12770081], [76.59395599, 31.1364994], [76.59874725, 31.15117073], [76.59467316, 31.15134048], [76.59007263, 31.15726852], [76.5914917, 31.16032028], [76.58943939, 31.16476059], [76.59246826, 31.1722908], [76.59039307, 31.18285942], [76.59831238, 31.18647957], [76.60066223, 31.1910305], [76.6057663, 31.19712067], [76.61221313, 31.20264053], [76.61869812, 31.20390129], [76.62011719, 31.20666122], [76.63542175, 31.21298027], [76.63414764, 31.21533966], [76.62452698, 31.22104073], [76.62594604, 31.22709084], [76.61625671, 31.22944069], [76.5867691, 31.21606064], [76.58061218, 31.21635246], [76.57935333, 31.2204895], [76.57596588, 31.22578812], [76.58252716, 31.2309494], [76.58470917, 31.23964119], [76.59268188, 31.24615097], [76.60161591, 31.25090981], [76.57050323, 31.28014946], [76.55224609, 31.26485252], [76.54592133, 31.25588036], [76.53495026, 31.25535011], [76.53264618, 31.26651192], [76.53481293, 31.27233124], [76.53717041, 31.28395081], [76.53122711, 31.28354073], [76.52789307, 31.2699604], [76.51811218, 31.26231003], [76.51428223, 31.26450157], [76.5165863, 31.27738953], [76.51426697, 31.28307915], [76.51091003, 31.28261948], [76.50340271, 31.27788925], [76.49823761, 31.27329063], [76.48858643, 31.27340126], [76.4832077, 31.28427124], [76.4797287, 31.28910255], [76.47564697, 31.29220009], [76.47505951, 31.29899979], [76.47245026, 31.30669975], [76.46671295, 31.31021118], [76.46208954, 31.30681038], [76.45101166, 31.29620934], [76.44577789, 31.28970909], [76.43113708, 31.28284073], [76.42849731, 31.28923035], [76.43580627, 31.29463959], [76.44558716, 31.30041122], [76.44827271, 31.30599022], [76.43744659, 31.31742287], [76.42801666, 31.32518005], [76.41816711, 31.33731079], [76.41284943, 31.34765816], [76.40883636, 31.35374832], [76.39924622, 31.36547089], [76.39105225, 31.37863159], [76.37924957, 31.3911705], [76.39039612, 31.39733124], [76.38162994, 31.41061974], [76.37303162, 31.41364861], [76.37526703, 31.4221611], [76.36917114, 31.42814064], [76.36313629, 31.44135094], [76.35677338, 31.4296093], [76.35914612, 31.41563034], [76.35312653, 31.41246033], [76.34689331, 31.40571022], [76.33460236, 31.40373993], [76.32952118, 31.40113831], [76.31584167, 31.40237808], [76.31877136, 31.38817978], [76.3182373, 31.3810997], [76.32958221, 31.37951851], [76.33001709, 31.36771011], [76.33129883, 31.35909271], [76.33666229, 31.35301971], [76.33007813, 31.34527969], [76.32446289, 31.34711075], [76.31783295, 31.35222054], [76.3157959, 31.34749985], [76.29991913, 31.34383011], [76.2959671, 31.34222984], [76.30226898, 31.3263607], [76.2960968, 31.31920052], [76.29039001, 31.31563187], [76.28439331, 31.31356049], [76.27735901, 31.3099308], [76.26840973, 31.30660057], [76.26116943, 31.30583], [76.25562286, 31.31495094], [76.24414063, 31.31371117], [76.22319031, 31.31306076], [76.21495819, 31.30764008], [76.20639801, 31.30526161], [76.18569946, 31.3046608], [76.17282867, 31.30673981], [76.16845703, 31.31412125], [76.16607666, 31.3261795], [76.1663208, 31.34145927], [76.1580658, 31.34694099], [76.14774323, 31.34814835], [76.13961029, 31.3531208], [76.13503265, 31.36175919], [76.13408661, 31.38264275], [76.1386261, 31.38685989], [76.14713287, 31.39190292], [76.15303802, 31.39725113], [76.15674591, 31.4045105], [76.15349579, 31.41401291], [76.14707184, 31.41884041], [76.14713287, 31.42560959], [76.14346313, 31.43229103], [76.13507843, 31.43750954], [76.12824249, 31.44375992], [76.122612, 31.45372963], [76.12127686, 31.46097946], [76.11551666, 31.46544075], [76.11472321, 31.47354126], [76.10795593, 31.48221016], [76.10816193, 31.49510956], [76.10410309, 31.5023098], [76.09455109, 31.51420975], [76.09062195, 31.51898956], [76.08895874, 31.52763939], [76.08399963, 31.53718185], [76.07681274, 31.54595947], [76.07158661, 31.55414963], [76.06601715, 31.56051826], [76.06490326, 31.56179047], [76.05150604, 31.58179092], [76.04315948, 31.59197044], [76.04268646, 31.59588051], [76.04402924, 31.60303116], [76.03997803, 31.60845947], [76.03671265, 31.60679817], [76.03140259, 31.60946083], [76.02319336, 31.61547089], [76.01760101, 31.62167168], [76.00274658, 31.64657021], [76.00624847, 31.65142822], [76.00392151, 31.65689087], [76.00473022, 31.66303062], [75.99736023, 31.66888046], [75.99742126, 31.6760006], [75.99469757, 31.68154907], [75.99214935, 31.68452072], [75.99098969, 31.68575096], [75.99066162, 31.6847496], [75.98562622, 31.68539047], [75.97579193, 31.69532967], [75.97737122, 31.70499992], [75.97257996, 31.71515274], [75.96936798, 31.71967125], [75.96602631, 31.73345947], [75.96100616, 31.73677254], [75.95755005, 31.7404995], [75.95974731, 31.74430275], [75.9595108, 31.74953842], [75.95189667, 31.76301956], [75.94506073, 31.78128052], [75.93644714, 31.78434944], [75.93582153, 31.78974915], [75.93300629, 31.7971096], [75.92722321, 31.80514908], [75.92182922, 31.81718063], [75.92675018, 31.81644058], [75.92932892, 31.81524086], [75.93325043, 31.81501961], [75.9360733, 31.81826019], [75.94877625, 31.8231411], [75.95289612, 31.82396126], [75.96031189, 31.81847954], [75.96697998, 31.81488991], [75.97146606, 31.81454849], [75.97091675, 31.81921005], [75.96762848, 31.82351112], [75.95575714, 31.83237076], [75.95358276, 31.83995056], [75.94972992, 31.84810066], [75.94425201, 31.85751915], [75.93840027, 31.8678894], [75.93144226, 31.88383102], [75.92617035, 31.88979149], [75.91268921, 31.91657829], [75.90276337, 31.92791939], [75.89595795, 31.94025993], [75.89454651, 31.94980049], [75.87771606, 31.96198082], [75.86972046, 31.96597099], [75.8685379, 31.96690941], [75.86617279, 31.96882057], [75.85679626, 31.96945953], [75.8513031, 31.97253036], [75.84162903, 31.97361946], [75.83637238, 31.9816494], [75.81404877, 31.98340034], [75.80560303, 31.98501968], [75.79512024, 31.9885807], [75.7842865, 31.99432945], [75.77429962, 32.00078964], [75.76644897, 32.00764084], [75.76154327, 32.01390076], [75.75380707, 32.0198822], [75.74836731, 32.02716064], [75.74003601, 32.03448105], [75.73800659, 32.03580093], [75.73397827, 32.03733063], [75.72322845, 32.03617096], [75.71048737, 32.03602219], [75.70040894, 32.04359055], [75.692276, 32.05945206], [75.68981934, 32.06153107], [75.67310333, 32.06692123], [75.64936066, 32.07717133], [75.6400528, 32.07674026], [75.62532043, 32.07266998], [75.60955811, 32.06946945], [75.598526, 32.06600952], [75.57875824, 32.0816803], [75.61055756, 32.09960937], [75.6312027, 32.11949921], [75.64787292, 32.13766098], [75.65547943, 32.14606094], [75.66182709, 32.16466904], [75.65615845, 32.17662048], [75.64958954, 32.17969131], [75.62021637, 32.18516922], [75.6194458, 32.18984985], [75.61833191, 32.19702148], [75.62011719, 32.22021103], [75.62177277, 32.23003006], [75.62254333, 32.23468018], [75.63407898, 32.24473953], [75.64092255, 32.2473793], [75.65244293, 32.25543976], [75.65487671, 32.25585175], [75.67584229, 32.26401901], [75.68489075, 32.26501846], [75.70487976, 32.26723862], [75.73639679, 32.27376175], [75.75183868, 32.28417206], [75.75467682, 32.28607941], [75.76185608, 32.29611206], [75.7633667, 32.30215073], [75.78314209, 32.32220078], [75.78549194, 32.3237915], [75.79371643, 32.3323822], [75.79927826, 32.33737183], [75.81391907, 32.35055923], [75.81887054, 32.35503006], [75.83740234, 32.37302017], [75.8438797, 32.37931061], [75.86631012, 32.39456177], [75.87193298, 32.39844894], [75.91110992, 32.40919113], [75.91542053, 32.41025925], [75.92592621, 32.41178131], [75.93216705, 32.41682053], [75.93463135, 32.42475891], [75.93141174, 32.43078995], [75.92443848, 32.4389801], [75.91549683, 32.44869995], [75.89541626, 32.46186066], [75.88712311, 32.47203064], [75.86876678, 32.48868179], [75.85527802, 32.49958038], [75.85096741, 32.50786972], [75.85138702, 32.5213089], [75.85636902, 32.53768921], [75.87030029, 32.55876923], [75.87545013, 32.57086182], [75.87254333, 32.57619095], [75.8862915, 32.59191895], [75.90458679, 32.61521912], [75.90776062, 32.61914063], [75.92362213, 32.64369965], [75.92543793, 32.65427017], [75.92405701, 32.6582222], [75.91475677, 32.6659317], [75.90540314, 32.67224884], [75.89885712, 32.6806221], [75.89657593, 32.69105911], [75.89906311, 32.70024872], [75.90486145, 32.70936203], [75.90983582, 32.72093964], [75.91404724, 32.74201965], [75.91248322, 32.75712204], [75.90006256, 32.76985931], [75.88568115, 32.79547882], [75.87378693, 32.81369019], [75.85523987, 32.82614136], [75.83738708, 32.8367691], [75.82752991, 32.84037018], [75.82106018, 32.84276199], [75.81581116, 32.84706116], [75.80831146, 32.85319901], [75.80551147, 32.85614014], [75.79537201, 32.86925888], [75.79464722, 32.87018967], [75.78983307, 32.88140106], [75.78917694, 32.88462067], [75.78742218, 32.89332199], [75.78987885, 32.89398193], [75.79380798, 32.89731216], [75.7983551, 32.90216446], [75.80000305, 32.90391922], [75.80175781, 32.91027069], [75.79830933, 32.91942215], [75.80332184, 32.92354965], [75.80795288, 32.9297905], [75.82142639, 32.93347168], [75.82811737, 32.93408203], [75.83389282, 32.93460083], [75.85006714, 32.93115997], [75.86711884, 32.93021011], [75.88089752, 32.92477036], [75.90011597, 32.91569901], [75.91356659, 32.90621185], [75.92323303, 32.89809036], [75.93377686, 32.88431168], [75.93955231, 32.88422012], [75.94577026, 32.88513947], [75.98320007, 32.90040207], [75.98741913, 32.90058136], [75.99752808, 32.90937042], [76.00463104, 32.91400909], [76.01351166, 32.91593933], [76.01718903, 32.91764069], [76.02117157, 32.92443085], [76.02365112, 32.93157959], [76.02807617, 32.93743896], [76.04260254, 32.94023895], [76.05039978, 32.94427109], [76.05446625, 32.9509697], [76.06587982, 32.95798111], [76.06999969, 32.96221924], [76.07834625, 32.96607208], [76.08220673, 32.96879959], [76.08567047, 32.97500992], [76.09123993, 32.99275208], [76.09455872, 33.00032043], [76.09368896, 33.00482941], [76.10732269, 33.00788879], [76.1159668, 33.0085907], [76.12049103, 33.01042175], [76.12819672, 33.01008224], [76.14389038, 33.01647949], [76.15223694, 33.02289963], [76.18830109, 33.02758026], [76.21615601, 33.02857208], [76.2294693, 33.03026199], [76.22978973, 33.03083038], [76.23728943, 33.03258896], [76.25524139, 33.05228043], [76.26751709, 33.08610916], [76.2712326, 33.09635925], [76.27584076, 33.09803009], [76.27687073, 33.10063171], [76.27500153, 33.10398865], [76.28800201, 33.11315918], [76.29194641, 33.12020874], [76.30692291, 33.12722015], [76.3155365, 33.13019943], [76.33558655, 33.14627075], [76.35212708, 33.15483856], [76.35578918, 33.15460205], [76.3588562, 33.15750122], [76.36080933, 33.16275024], [76.36615753, 33.16804123], [76.37351227, 33.17346191], [76.37985229, 33.17646027], [76.38455963, 33.18289185], [76.39167786, 33.18669128], [76.40067291, 33.18656158], [76.40769196, 33.18841934], [76.42177582, 33.18180847], [76.42977142, 33.18281174], [76.44181061, 33.18046951], [76.45020294, 33.18291855], [76.45555115, 33.18331909], [76.46614075, 33.17988205], [76.46906281, 33.17990875], [76.48877716, 33.19015884], [76.49597168, 33.19602966], [76.4988327, 33.19668961], [76.50576019, 33.19578171], [76.52023315, 33.20040894], [76.53417969, 33.19934845], [76.54196167, 33.20677185], [76.54747772, 33.20952988], [76.55589294, 33.20685196], [76.56295013, 33.20618057], [76.56761932, 33.20705032], [76.57673645, 33.2057991], [76.58190155, 33.20687103], [76.58618927, 33.20421982], [76.58470154, 33.19956207], [76.58403778, 33.19306946], [76.58799744, 33.18999863], [76.59253693, 33.19063187], [76.59732819, 33.18803024], [76.59886169, 33.18391037], [76.5984726, 33.17650986], [76.59958649, 33.17375946], [76.61255646, 33.16596985], [76.62700653, 33.1624794], [76.64074707, 33.16468048], [76.65110779, 33.17182922], [76.65873718, 33.17116928], [76.65944672, 33.17111206], [76.66055298, 33.17134857], [76.66947937, 33.17332077], [76.68527222, 33.17404175], [76.69365692, 33.17760086], [76.69671631, 33.18148041], [76.70847321, 33.18130112], [76.71418762, 33.17744064], [76.72986603, 33.17943192], [76.73060608, 33.18527985], [76.73435211, 33.19311905], [76.74212646, 33.19749069], [76.74558258, 33.20434952], [76.75055695, 33.21012878], [76.75605011, 33.21982193], [76.75988007, 33.22467041], [76.76235962, 33.2395401], [76.75756836, 33.2431221], [76.75520325, 33.24740982], [76.75534058, 33.24948883], [76.75688171, 33.25054169], [76.75997162, 33.25297928], [76.76355743, 33.25432968], [76.77826691, 33.2557106], [76.78543854, 33.25358963], [76.79693604, 33.24121094], [76.80275726, 33.23666], [76.8062973, 33.23622894], [76.80845642, 33.24232101], [76.80916595, 33.24430084], [76.81394196, 33.24744034], [76.817276, 33.24850082], [76.8219223, 33.24835205], [76.82354736, 33.24785995], [76.82717133, 33.24674988], [76.82834625, 33.24639893], [76.82887268, 33.2425499], [76.82319641, 33.23738098], [76.81785583, 33.23114014], [76.81304932, 33.2227211], [76.81108093, 33.21546173], [76.81716156, 33.21223068], [76.81858826, 33.20557022], [76.80330658, 33.19385147], [76.80661011, 33.18473053], [76.80517578, 33.18225861], [76.80042267, 33.17779922], [76.79812622, 33.1733017], [76.799263, 33.1694603], [76.80201721, 33.16603088], [76.80143738, 33.16154099], [76.80345917, 33.15568924], [76.80948639, 33.14855194], [76.81495667, 33.14617157], [76.81725311, 33.14200211], [76.82296753, 33.14128876], [76.82917023, 33.13772202], [76.82808685, 33.13167953], [76.83740234, 33.12638855], [76.83410645, 33.12055969], [76.8391571, 33.11529922], [76.84443665, 33.11230087], [76.85256958, 33.11154938], [76.86044312, 33.11637878], [76.86869049, 33.12022018], [76.87719727, 33.11423874], [76.87741852, 33.1072197], [76.88477325, 33.09743881], [76.89431, 33.09513855], [76.89498901, 33.09141922], [76.89093018, 33.08459854], [76.89074707, 33.08076096], [76.89639282, 33.07580948], [76.89694214, 33.07099152], [76.90011597, 33.06414032], [76.9102478, 33.05020905], [76.91332245, 33.04420853], [76.91461182, 33.03882217], [76.91751099, 33.03367996], [76.92414856, 33.02896881], [76.93266296, 33.02845001], [76.94832611, 33.01848984], [76.95677948, 33.01673889], [76.96212769, 33.01393127], [76.96370697, 33.01004028], [76.96652222, 33.00720978], [76.98082733, 33.00146103], [76.98693848, 32.99592209], [76.99147034, 32.99285889], [76.99401855, 32.9922905], [76.99846649, 32.98957062], [77.0112381, 32.99324036], [77.01992035, 32.99174881], [77.02442169, 32.99695969], [77.03531647, 32.99967957], [77.05237579, 32.9908905], [77.05847168, 32.98608017], [77.06593323, 32.98553085], [77.07167053, 32.97623062], [77.07489777, 32.97335052], [77.08418274, 32.97367096], [77.09712219, 32.97758102], [77.10315704, 32.98720169], [77.11238098, 32.98413086], [77.12007141, 32.98271179], [77.12750244, 32.98384094], [77.13639069, 32.98046112], [77.13585663, 32.97444916], [77.13430786, 32.96949005], [77.13553619, 32.96467972], [77.13527679, 32.96094131], [77.13638306, 32.9577713], [77.14612579, 32.95639038], [77.14611053, 32.94277191], [77.14878082, 32.94137955], [77.14855194, 32.93791199], [77.14694977, 32.93437958], [77.15072632, 32.92023087], [77.14618683, 32.91402054], [77.15743256, 32.91323853], [77.16043091, 32.91608047], [77.16156769, 32.92111969], [77.16372681, 32.92510986], [77.1665802, 32.92805099], [77.17385864, 32.93112946], [77.18180084, 32.91545105], [77.18895721, 32.91006088], [77.20453644, 32.90637207], [77.21798706, 32.89731216], [77.22825623, 32.89556885], [77.22930145, 32.88679886], [77.22746277, 32.88393021], [77.22408295, 32.88270187], [77.224823, 32.88002014], [77.22782898, 32.8769722], [77.23626709, 32.87229919], [77.23802948, 32.86901093], [77.23887634, 32.8651619], [77.24758148, 32.8649292], [77.25831604, 32.87636185], [77.27009583, 32.86640167], [77.27433777, 32.85976028], [77.28128052, 32.85565186], [77.28874207, 32.85261917], [77.29795837, 32.85401154], [77.30516052, 32.85404968], [77.3125, 32.84630966], [77.31086731, 32.83766937], [77.31651306, 32.82975006], [77.32065582, 32.82810211], [77.32161713, 32.82239151], [77.32789612, 32.81988144], [77.33596039, 32.81890869], [77.34046173, 32.82054138], [77.3483963, 32.82120132], [77.35647583, 32.82527161], [77.35955048, 32.83816147], [77.36184692, 32.84260941], [77.3626709, 32.84659958], [77.35980988, 32.85161972], [77.35871887, 32.85639954], [77.35968018, 32.85958099], [77.36306763, 32.86352921], [77.37124634, 32.8674202], [77.3793869, 32.88082886], [77.38746643, 32.88552094], [77.39541626, 32.8873291], [77.39733124, 32.88698959], [77.39917755, 32.88393021], [77.40312195, 32.88145065], [77.41013336, 32.8782196], [77.4177475, 32.87921143], [77.42572021, 32.88367081], [77.43122101, 32.87582016], [77.43224335, 32.87044907], [77.43617249, 32.8658905], [77.448349, 32.86167908], [77.45522308, 32.86174011], [77.47318268, 32.87879181], [77.48455048, 32.88653946], [77.49434662, 32.88151169], [77.50623322, 32.8830719], [77.5112915, 32.88542938], [77.51956177, 32.88737869], [77.52320099, 32.88978195], [77.52700043, 32.89228058], [77.53531647, 32.90229034], [77.54471588, 32.91173172], [77.54949188, 32.9133606], [77.55384827, 32.91310883], [77.56964874, 32.92166138], [77.57966614, 32.93167877], [77.58096313, 32.93450165], [77.58152771, 32.93923187], [77.58392334, 32.94380188], [77.58637238, 32.93989944], [77.59343719, 32.94153976], [77.60614777, 32.94240952], [77.61071014, 32.94231033], [77.61296082, 32.94141006], [77.61725616, 32.94400024], [77.62336731, 32.94454193], [77.6384964, 32.95613861], [77.64334869, 32.95785141], [77.64987946, 32.9582901], [77.65331268, 32.95940018], [77.65637207, 32.96596146], [77.6599884, 32.96895981], [77.66307831, 32.97592926], [77.66520691, 32.98603058], [77.67086029, 32.9862709], [77.6780014, 32.98072052], [77.67948914, 32.97777939], [77.69087219, 32.97941971], [77.69500732, 32.97782135], [77.69670868, 32.97335052], [77.69988251, 32.96903992], [77.70368958, 32.9661293], [77.70832825, 32.96731949], [77.71248627, 32.97180176], [77.7231369, 32.96435928], [77.7273407, 32.95755005], [77.73412323, 32.9503212], [77.73641968, 32.94787216], [77.73895264, 32.94726944], [77.74478912, 32.94586945], [77.74717712, 32.94221115], [77.74745941, 32.9405098], [77.74762726, 32.93941879], [77.75099182, 32.93603134], [77.75956726, 32.92741013], [77.7780304, 32.91577911], [77.78174591, 32.91003036], [77.79016876, 32.90542984], [77.79250336, 32.89807892], [77.7869873, 32.8916893], [77.77274323, 32.8909111], [77.76597595, 32.88029099], [77.76142883, 32.86483002], [77.76772308, 32.85847092], [77.77578735, 32.854702], [77.78087616, 32.85409927], [77.78774261, 32.84976196], [77.79187775, 32.84926987], [77.79899597, 32.84584045], [77.80821228, 32.8360405], [77.8143158, 32.8361702], [77.81881714, 32.83853149], [77.8250885, 32.83987045], [77.83138275, 32.83504105], [77.84760284, 32.8284111], [77.85254669, 32.82518005], [77.85497284, 32.82118988], [77.86126709, 32.81616211], [77.86383057, 32.81145096], [77.86454773, 32.80651855], [77.8690033, 32.80036926], [77.86696625, 32.79029083], [77.87224579, 32.78625107], [77.876297, 32.78001022], [77.88089752, 32.7754097], [77.88748169, 32.77526093], [77.89087677, 32.77450943], [77.89949799, 32.77532196], [77.90349579, 32.77289963], [77.90892792, 32.77212143], [77.91227722, 32.76716995], [77.91513062, 32.76605988], [77.91689301, 32.76272964], [77.9179306, 32.75691986], [77.91716003, 32.75188065], [77.91440582, 32.74454117], [77.9143219, 32.74177933], [77.91182709, 32.73651123], [77.91562653, 32.73369217], [77.91847229, 32.73078918], [77.91203308, 32.72576904], [77.90943909, 32.72138977], [77.90847778, 32.7163887], [77.90625763, 32.71234894], [77.90566254, 32.70359039], [77.90239716, 32.69841003], [77.90325165, 32.69309998], [77.9109726, 32.68817902], [77.92021179, 32.67951202], [77.9262085, 32.66680908], [77.92716217, 32.66262054], [77.93229675, 32.65620041], [77.93891144, 32.6480217], [77.9464798, 32.64273071], [77.95265961, 32.64039993], [77.95510101, 32.63481903], [77.95424652, 32.6259613], [77.95947266, 32.62073898], [77.96222687, 32.61380005], [77.96784973, 32.60797882], [77.9749527, 32.5963707], [77.97669983, 32.59194183], [77.9825592, 32.58652878], [77.98705292, 32.58819962], [78.01743317, 32.5870285], [78.02744293, 32.58864975], [78.03579712, 32.59194946], [78.04161072, 32.59923935], [78.04146576, 32.6053009], [78.03675842, 32.61085892], [78.03443146, 32.61565018], [78.03244019, 32.62839127], [78.03273773, 32.63375092], [78.0338974, 32.63560867], [78.0440979, 32.6288414], [78.05901337, 32.62458038], [78.06533051, 32.62427902], [78.06745911, 32.6256218], [78.07293701, 32.64440155], [78.07900238, 32.65279007], [78.08851624, 32.659832], [78.09337616, 32.66215134], [78.09926605, 32.65996933], [78.106987, 32.64974213], [78.11615753, 32.64241028], [78.12149811, 32.64234924], [78.12666321, 32.64910126], [78.13066101, 32.66006088], [78.13600159, 32.6703186], [78.14444733, 32.67660141], [78.15254211, 32.67901993], [78.15841675, 32.67913055], [78.17047882, 32.67721176], [78.17951202, 32.67041016], [78.18395233, 32.66387177], [78.19499207, 32.6673317], [78.20163727, 32.66519928], [78.2129364, 32.66918945], [78.22496796, 32.67556], [78.23326111, 32.68370056], [78.23658752, 32.69467163], [78.25911713, 32.70291901], [78.27274323, 32.70293045], [78.28486633, 32.70677948], [78.29572296, 32.71281052], [78.2985611, 32.71974182], [78.29811096, 32.72483063], [78.2946167, 32.73160934], [78.28765869, 32.73783112], [78.31394958, 32.74898148], [78.34474182, 32.76343155], [78.3642807, 32.76298141], [78.37135315, 32.76182938], [78.37277222, 32.76015091], [78.3707428, 32.74584961], [78.37121582, 32.7336998], [78.37494659, 32.72264862], [78.37782288, 32.71931076], [78.36756897, 32.69952011], [78.36367798, 32.68553162], [78.36315155, 32.67198944], [78.3709259, 32.63816071], [78.3759079, 32.62961197], [78.38881683, 32.62322998], [78.37706757, 32.61487961], [78.34062195, 32.59305954], [78.33175659, 32.58486938], [78.31799316, 32.58021164], [78.30236816, 32.57870102], [78.29662323, 32.57751083], [78.29917145, 32.52927017], [78.29503632, 32.52246094], [78.27851868, 32.50793076], [78.30623627, 32.47774887], [78.31040955, 32.47592926], [78.35636139, 32.51266098], [78.3766861, 32.52605057], [78.38243103, 32.52965164], [78.39438629, 32.52853012], [78.3979187, 32.52706909], [78.39906311, 32.526371], [78.4002533, 32.52368164], [78.40141296, 32.51818085], [78.40525818, 32.51512146], [78.40522766, 32.51422882], [78.40892029, 32.51271057], [78.40917206, 32.51202011], [78.41075897, 32.51174164], [78.41497803, 32.51100159], [78.41651917, 32.51115036], [78.42565918, 32.51203156], [78.4316864, 32.51028061], [78.43557739, 32.50774002], [78.43637085, 32.507061], [78.43839264, 32.50535202], [78.43998718, 32.50320053], [78.44064331, 32.50054169], [78.44352722, 32.49930191], [78.44503784, 32.49790955], [78.44763947, 32.49240875], [78.44872284, 32.49013901], [78.44867706, 32.48921967], [78.448349, 32.48719025], [78.44795227, 32.48635864], [78.44577026, 32.48207855], [78.44327545, 32.47946167], [78.44159698, 32.47769928], [78.44100952, 32.47677994], [78.43733215, 32.47106171], [78.43579865, 32.46606064], [78.43543243, 32.46257019], [78.43662262, 32.45936966], [78.43714142, 32.4591217], [78.43710327, 32.45800018], [78.4381485, 32.45705032], [78.43811035, 32.45639038], [78.4414978, 32.45471191], [78.44315338, 32.45431137], [78.44599915, 32.45351028], [78.45474243, 32.45055008], [78.46199036, 32.44797897], [78.46611786, 32.44515991], [78.46681976, 32.44311142], [78.46761322, 32.44285202], [78.46817017, 32.44282913], [78.46813965, 32.442379], [78.46868134, 32.44213104], [78.47087097, 32.43733978], [78.47102356, 32.43727112], [78.47135925, 32.43711853], [78.47190857, 32.43687057], [78.47299957, 32.43291855], [78.47360229, 32.43252945], [78.47486877, 32.4311409], [78.47509766, 32.43022919], [78.47663879, 32.42905045], [78.47659302, 32.42747879], [78.4779129, 32.42673874], [78.47814178, 32.42586136], [78.4836731, 32.42501068], [78.48732758, 32.42525864], [78.50258636, 32.42621994], [78.51151276, 32.42370224], [78.51445007, 32.42193985], [78.51876068, 32.41849899], [78.51721954, 32.41313934], [78.5166626, 32.41249847], [78.50498962, 32.40293121], [78.5038681, 32.40182114], [78.50211334, 32.40050888], [78.50171661, 32.40005875], [78.49762726, 32.39524078], [78.49588013, 32.39076996], [78.49397278, 32.37731171], [78.49172211, 32.37329865], [78.48503876, 32.36769104], [78.48403168, 32.36685944], [78.48291779, 32.36587906], [78.47731018, 32.36291504], [78.46798706, 32.35799026], [78.46460724, 32.35316086], [78.46407318, 32.35223007], [78.462883, 32.34957123], [78.46129608, 32.34296036], [78.46069336, 32.33721924], [78.46124268, 32.3370018], [78.46465302, 32.32064056], [78.46533203, 32.31230927], [78.46697998, 32.29190063], [78.46615601, 32.28401947], [78.46431732, 32.27777863], [78.46273041, 32.27613068], [78.45915222, 32.27070999], [78.45844269, 32.26914978], [78.45649719, 32.26784897], [78.45397186, 32.26409149], [78.45291138, 32.26364136], [78.45083618, 32.26189041], [78.45053101, 32.26142883], [78.44835663, 32.25823975], [78.4471817, 32.25712204], [78.4454422, 32.25576019], [78.44503021, 32.25535965], [78.44168091, 32.25183105], [78.44090271, 32.25162125], [78.43942261, 32.24827194], [78.43920898, 32.24645996], [78.4467392, 32.24580002], [78.44790649, 32.24568939], [78.4590683, 32.24544144], [78.46013641, 32.24518204], [78.46411896, 32.24596024], [78.4776001, 32.24392319], [78.48284912, 32.24312973], [78.50154114, 32.24571991], [78.50588226, 32.24784088], [78.51389313, 32.24943161], [78.52024078, 32.2501297], [78.52075958, 32.25017929], [78.52374268, 32.25045013], [78.53569794, 32.24982071], [78.53942108, 32.24998093], [78.54308319, 32.24874115], [78.56223297, 32.23731995], [78.57392883, 32.23133087], [78.59291077, 32.21866989], [78.59339905, 32.21775055], [78.59430695, 32.21712875], [78.59509277, 32.21667862], [78.59516144, 32.21575928], [78.59513092, 32.21147919], [78.59111786, 32.20394135], [78.59049988, 32.19763184], [78.59126282, 32.19738007], [78.59420013, 32.18848038], [78.59369659, 32.18241882], [78.5922699, 32.17996216], [78.58950806, 32.17396164], [78.58876038, 32.17150116], [78.58531952, 32.16894913], [78.58409882, 32.16847992], [78.57802582, 32.16553116], [78.57784271, 32.16508102], [78.57728577, 32.16508102], [78.57457733, 32.16154099], [78.5743103, 32.15861893], [78.57467651, 32.1577301], [78.57572174, 32.15768051], [78.57623291, 32.15655136], [78.57968903, 32.15446854], [78.58830261, 32.14736938], [78.58878326, 32.14598846], [78.58953094, 32.14554977], [78.58994293, 32.14234924], [78.59121704, 32.1411705], [78.59249878, 32.14001083], [78.59420776, 32.13566971], [78.59448242, 32.13188934], [78.59632874, 32.12340927], [78.59713745, 32.12295151], [78.59733582, 32.12203217], [78.59928894, 32.12091064], [78.59947205, 32.12034988], [78.6062088, 32.11748886], [78.6101532, 32.11779022], [78.61593628, 32.11581039], [78.61646271, 32.1160202], [78.61709595, 32.11621857], [78.62861633, 32.11495209], [78.63961029, 32.11212158], [78.64787292, 32.10713196], [78.64839935, 32.10643005], [78.64900208, 32.1053009], [78.64965057, 32.09870911], [78.65106201, 32.09334946], [78.65241241, 32.08826065], [78.65672302, 32.08383179], [78.65740967, 32.08132172], [78.65796661, 32.08087921], [78.65976715, 32.07947159], [78.65985107, 32.07901001], [78.66079712, 32.0782814], [78.67437744, 32.06927872], [78.68080139, 32.0638504], [78.68132019, 32.06343079], [78.68205261, 32.0622406], [78.68255615, 32.0608902], [78.68482971, 32.05857086], [78.68611145, 32.05762863], [78.68760681, 32.05335999], [78.68814087, 32.0531311], [78.68882751, 32.05257034], [78.68940735, 32.05097198], [78.69011688, 32.04573059], [78.69076538, 32.04523087], [78.6934433, 32.04315948], [78.69394684, 32.04270935], [78.69391632, 32.04179001], [78.69548798, 32.04130936], [78.69593048, 32.03990936], [78.69696808, 32.0392189], [78.69747162, 32.03874207], [78.70517731, 32.03369904], [78.70540619, 32.03306961], [78.71192932, 32.02927017], [78.71691132, 32.02524948], [78.7171402, 32.02460098], [78.72258759, 32.02040863], [78.72283936, 32.01976013], [78.72547913, 32.0175209], [78.72593689, 32.01626968], [78.72688293, 32.0132103], [78.72766113, 32.01295853], [78.72808838, 32.01264572], [78.72894287, 32.01202011], [78.72915649, 32.01110077], [78.72969818, 32.01087952], [78.73017883, 32.00951004], [78.73014069, 32.00881958], [78.73117828, 32.0083313], [78.73140717, 32.00764847], [78.73706818, 32.00408173], [78.73948669, 32.00447083], [78.75055695, 32.00363922], [78.75314331, 32.00302887], [78.76055908, 32.00123215], [78.76837921, 31.99989128], [78.76995087, 31.99938965], [78.77102661, 31.99981117], [78.77099609, 31.99641991], [78.77057648, 31.99494171], [78.77039337, 31.99451065], [78.76918793, 31.99131966], [78.76106262, 31.96377945], [78.75750732, 31.95465851], [78.75608063, 31.95028877], [78.75258636, 31.93956947], [78.75026703, 31.93465042], [78.7454071, 31.9250412], [78.74027252, 31.9199791], [78.73953247, 31.9197998], [78.73751068, 31.91740036], [78.73596954, 31.91605186], [78.7352066, 31.91584969], [78.73490143, 31.91513062], [78.73454285, 31.91476059], [78.73275757, 31.91303062], [78.73235321, 31.90962982], [78.73127747, 31.90888977], [78.73015594, 31.90814972], [78.72944641, 31.90658951], [78.72927094, 31.90571022], [78.73104858, 31.9043026], [78.73137665, 31.90293121], [78.7315979, 31.89818001], [78.7283783, 31.89001274], [78.72764587, 31.88948059], [78.72720337, 31.88865089], [78.72476196, 31.88500023], [78.72450256, 31.88433266], [78.7243576, 31.88396072], [78.72409821, 31.8832798], [78.72377014, 31.88150024], [78.72402954, 31.87516975], [78.7233963, 31.84698105], [78.72193909, 31.83798981], [78.7217865, 31.83732986], [78.72052765, 31.83533096], [78.71969604, 31.83492088], [78.71835327, 31.83426285], [78.70378876, 31.82682991], [78.70205688, 31.82576942], [78.70149994, 31.82579041], [78.70134735, 31.82533073], [78.70095825, 31.82447052], [78.70041656, 31.82449913], [78.69468689, 31.81719017], [78.69297028, 31.81431961], [78.69242859, 31.81264114], [78.69081116, 31.80672073], [78.69120789, 31.79692841], [78.69135284, 31.79335022], [78.69322205, 31.78652954], [78.69386292, 31.78593826], [78.69429779, 31.78375053], [78.69626617, 31.77878189], [78.69703674, 31.77806664], [78.70083618, 31.77453995], [78.70184326, 31.77362061], [78.70332336, 31.77040863], [78.71383667, 31.76739311], [78.71555328, 31.76690292], [78.72183228, 31.76506805], [78.72466278, 31.7638607], [78.72402191, 31.76005173], [78.71985626, 31.75636482], [78.71688843, 31.75374031], [78.71627808, 31.75254059], [78.71514893, 31.75032997], [78.7141571, 31.74924088], [78.7117691, 31.7448597], [78.71134186, 31.74126244], [78.71187592, 31.74103928], [78.71237946, 31.74078941], [78.71259308, 31.73896027], [78.71334076, 31.73851013], [78.71409607, 31.73802948], [78.71430969, 31.73665047], [78.71845245, 31.73450279], [78.72007751, 31.7319603], [78.7206192, 31.73195076], [78.72146606, 31.73032951], [78.72310638, 31.72544289], [78.72367859, 31.72373962], [78.72567749, 31.71780014], [78.72860718, 31.70236015], [78.73195648, 31.69771004], [78.73324585, 31.69597054], [78.73439789, 31.69198036], [78.7351532, 31.69153023], [78.7352829, 31.69094086], [78.7360611, 31.69046021], [78.73995972, 31.68803978], [78.74752808, 31.68510056], [78.74843597, 31.68514061], [78.74990082, 31.68472099], [78.75211334, 31.68491745], [78.7536087, 31.68505096], [78.75463867, 31.68478966], [78.76481628, 31.68617058], [78.77139282, 31.68787193], [78.77316284, 31.68841171], [78.77964783, 31.68984032], [78.78022003, 31.68756104], [78.78065491, 31.67563248], [78.7807312, 31.67350769], [78.78076172, 31.67266273], [78.78423309, 31.66126251], [78.786026, 31.65983009], [78.78650665, 31.65846062], [78.78674316, 31.65755081], [78.78749847, 31.65707016], [78.78927612, 31.65476036], [78.79235077, 31.65221024], [78.79305267, 31.65113068], [78.79458618, 31.65031815], [78.79457855, 31.64986992], [78.79534912, 31.64915848], [78.80890656, 31.63991165], [78.80967712, 31.63957024], [78.81669617, 31.63648033], [78.81987, 31.63379097], [78.82364655, 31.6307106], [78.8240509, 31.63038254], [78.82483673, 31.62935066], [78.82688904, 31.62799072], [78.82724762, 31.6273098], [78.82762146, 31.62658119], [78.82759857, 31.62569046], [78.82832336, 31.62507057], [78.82852173, 31.62467957], [78.8306427, 31.62045097], [78.83117676, 31.61988258], [78.83109283, 31.61526108], [78.82756042, 31.60722923], [78.82447052, 31.60281181], [78.8237915, 31.60238838], [78.82280731, 31.60062027], [78.81893158, 31.59753036], [78.81794739, 31.59621048], [78.81501007, 31.59365082], [78.81394958, 31.59325981], [78.81297302, 31.59215927], [78.81224823, 31.59082985], [78.81099701, 31.58904839], [78.81027222, 31.58839035], [78.80948639, 31.58819008], [78.80918121, 31.5874691], [78.80513, 31.58324051], [78.79728699, 31.5761528], [78.79136658, 31.57364845], [78.78475189, 31.57139015], [78.76811981, 31.56574059], [78.76808929, 31.56505966], [78.76374054, 31.56213951], [78.76119232, 31.55750275], [78.75759888, 31.55356026], [78.75000763, 31.54883003], [78.74658203, 31.54771996], [78.73008728, 31.54426956], [78.72126007, 31.54095078], [78.71916199, 31.53675079], [78.71716309, 31.53046989], [78.71644592, 31.52992058], [78.71562958, 31.52975082], [78.71533966, 31.52907944], [78.70868683, 31.52396965], [78.70677185, 31.52110291], [78.70664215, 31.51839256], [78.70807648, 31.5149498], [78.71514893, 31.50773048], [78.71605682, 31.5038681], [78.71604919, 31.48717117], [78.71658325, 31.48488235], [78.71917725, 31.48411942], [78.72357941, 31.48595428], [78.72376251, 31.48603058], [78.72901154, 31.48713684], [78.7441864, 31.49032974], [78.74680328, 31.49045944], [78.74814606, 31.49087906], [78.74893188, 31.49061966], [78.75150299, 31.48894119], [78.7545929, 31.48072052], [78.76048279, 31.47648048], [78.76122284, 31.47577286], [78.76120758, 31.47521973], [78.76119232, 31.47487259], [78.76229858, 31.47425461], [78.76557159, 31.47243118], [78.76611328, 31.47212982], [78.76635742, 31.47144127], [78.76818085, 31.47093964], [78.77147675, 31.46914291], [78.7730484, 31.46751022], [78.77419281, 31.46620941], [78.77909851, 31.46301079], [78.78018188, 31.46197128], [78.79245758, 31.45535088], [78.79547882, 31.4527626], [78.79693604, 31.44908905], [78.79727173, 31.44458961], [78.79601288, 31.43964195], [78.79579926, 31.43447113], [78.79563904, 31.43063927], [78.79248047, 31.41785812], [78.78972626, 31.41547012], [78.78357697, 31.41296005], [78.78242493, 31.41224861], [78.78185272, 31.41189003], [78.78166962, 31.41098976], [78.78112793, 31.41054153], [78.77648163, 31.40665817], [78.77603912, 31.40237808], [78.77632904, 31.40154648], [78.77643585, 31.40122986], [78.77783966, 31.40143013], [78.78202057, 31.40037918], [78.79450226, 31.39653969], [78.80172729, 31.39384079], [78.80796051, 31.39229965], [78.81128693, 31.39081955], [78.81671906, 31.38841057], [78.82103729, 31.38418961], [78.82102203, 31.38329124], [78.82668304, 31.38107109], [78.8272171, 31.3812809], [78.83013153, 31.37553024], [78.83422852, 31.37247086], [78.8347702, 31.37114906], [78.83474731, 31.37046814], [78.83577728, 31.36939049], [78.83757019, 31.36444092], [78.83805847, 31.36423111], [78.84028625, 31.35444069], [78.84014893, 31.3506012], [78.8377533, 31.34502983], [78.83174133, 31.33892059], [78.82871246, 31.3324604], [78.82901001, 31.3302002], [78.83347321, 31.3291111], [78.83506012, 31.32930183], [78.837883, 31.32876015], [78.83867645, 31.32840157], [78.84008026, 31.32769966], [78.84555817, 31.32417107], [78.84838104, 31.32234001], [78.84937286, 31.32096291], [78.85063934, 31.32002068], [78.8506012, 31.31909943], [78.85161591, 31.31839943], [78.85211945, 31.31793022], [78.85340118, 31.31698036], [78.85336304, 31.31607056], [78.85389709, 31.31606102], [78.85824585, 31.31298065], [78.86035156, 31.30913162], [78.86081696, 31.30828094], [78.86135864, 31.30825996], [78.86142731, 31.30766106], [78.86419678, 31.30533028], [78.86463928, 31.30432129], [78.86469269, 31.30372047], [78.86746979, 31.30137825], [78.87005615, 31.29136848], [78.87058258, 31.29112053], [78.87101746, 31.28951263], [78.87152863, 31.2892704], [78.87834167, 31.27287292], [78.87886047, 31.27263069], [78.87953949, 31.27071953], [78.88495636, 31.26679993], [78.88542175, 31.26646042], [78.88955688, 31.26517105], [78.9008255, 31.26128006], [78.90688324, 31.25918961], [78.90585327, 31.2501812], [78.90991211, 31.23388863], [78.91564941, 31.2251606], [78.9196167, 31.22309113], [78.93512726, 31.22236252], [78.93506622, 31.2191906], [78.9332428, 31.21455193], [78.93585205, 31.20568085], [78.94168091, 31.20080185], [78.94486237, 31.19693947], [78.94621277, 31.19355965], [78.95284271, 31.1898098], [78.96092224, 31.18643188], [78.96615601, 31.18599129], [78.96845245, 31.18346977], [78.97187042, 31.18237114], [78.97466278, 31.17810059], [78.97747803, 31.17016029], [78.97767639, 31.15483093], [78.97579956, 31.15070915], [78.97808838, 31.1456604], [78.98480988, 31.14093971], [78.98706055, 31.14060974], [78.98919678, 31.13735962], [78.99077606, 31.13087845], [78.99669647, 31.11758995], [78.99669647, 31.11618042], [78.99658203, 31.11533928], [78.99079895, 31.11709023], [78.98486328, 31.11647034], [78.96565247, 31.1153698], [78.95582581, 31.1108799], [78.95243073, 31.10840988], [78.94211578, 31.10502815], [78.93752289, 31.10534286], [78.93257141, 31.10697937], [78.92047119, 31.10758972], [78.91265869, 31.11618042], [78.90779114, 31.11631966], [78.90379333, 31.11547089], [78.90058136, 31.11206055], [78.89942932, 31.10759926], [78.89679718, 31.10563087], [78.89074707, 31.1060791], [78.88417816, 31.10423279], [78.88004303, 31.10383987], [78.87139893, 31.10732079], [78.86225128, 31.11240959], [78.85202026, 31.12621117], [78.84432983, 31.12804031], [78.83777618, 31.13068962], [78.82897949, 31.13633919], [78.82472229, 31.14355087], [78.81873322, 31.14721107], [78.81587219, 31.15393066], [78.81021881, 31.16386032], [78.81170654, 31.16941071], [78.80050659, 31.1782608], [78.7975769, 31.18250275], [78.7980423, 31.18894958], [78.80111694, 31.1939106], [78.80316925, 31.19923019], [78.8001709, 31.20237923], [78.79503632, 31.20503998], [78.78881073, 31.20445061], [78.77088928, 31.19729996], [78.76460266, 31.1959095], [78.75759125, 31.1946907], [78.74945068, 31.1943512], [78.72038269, 31.19701958], [78.71302795, 31.1966629], [78.70746613, 31.19497108], [78.70069885, 31.19639015], [78.6955719, 31.19629097], [78.67608643, 31.20318985], [78.66575623, 31.20247269], [78.65983582, 31.20325089], [78.65067291, 31.19785118], [78.64769745, 31.19466972], [78.64549255, 31.20251846], [78.63800812, 31.20838928], [78.63600159, 31.2195797], [78.63445282, 31.2218895], [78.62831879, 31.22191811], [78.61711121, 31.22524834], [78.61329651, 31.22743988], [78.61004639, 31.23105049], [78.6006012, 31.23585129], [78.59536743, 31.23639107], [78.58392334, 31.23430061], [78.57939911, 31.23500252], [78.56658173, 31.23373985], [78.56189728, 31.22960091], [78.55632782, 31.22738075], [78.55024719, 31.21849251], [78.537117, 31.20671082], [78.51413727, 31.20392036], [78.48657227, 31.20417023], [78.47698212, 31.20510292], [78.47010803, 31.20375061], [78.46721649, 31.21184921], [78.46656799, 31.22093964], [78.45722198, 31.22781181], [78.44413757, 31.24419975], [78.4316864, 31.24959946], [78.42706299, 31.25597954], [78.41945648, 31.25988007], [78.41438293, 31.25090981], [78.4050827, 31.24867058], [78.3975296, 31.24779129], [78.39134979, 31.25299072], [78.39308167, 31.2622776], [78.38619232, 31.26963043], [78.38327026, 31.2743206], [78.38136292, 31.28147125], [78.37346649, 31.27920914], [78.3692627, 31.28790092], [78.36335754, 31.2901001], [78.35632324, 31.29087067], [78.3474884, 31.29011917], [78.34247589, 31.28897285], [78.33609009, 31.2874794], [78.32663727, 31.28824043], [78.31693268, 31.28507805], [78.30632782, 31.28623962], [78.29836273, 31.28820992], [78.29680634, 31.2844696], [78.29551697, 31.27285957], [78.29341888, 31.2660408], [78.28845978, 31.26420021], [78.27815247, 31.26666069], [78.26902008, 31.2713604], [78.25814056, 31.26036263], [78.25495911, 31.25659943], [78.25324249, 31.25287056], [78.2497406, 31.25055122], [78.24820709, 31.24665833], [78.24263, 31.24336243], [78.23751068, 31.24394035], [78.23764801, 31.2397995], [78.23258972, 31.23501968], [78.21843719, 31.23871994], [78.21209717, 31.23855019], [78.20681763, 31.2372303], [78.20398712, 31.23409081], [78.20027161, 31.22571945], [78.19284058, 31.22291183], [78.18756104, 31.22221947], [78.18492126, 31.22332954], [78.17648315, 31.23003006], [78.17141724, 31.23180962], [78.16581726, 31.23106194], [78.16308594, 31.23150063], [78.16044617, 31.23192024], [78.15542603, 31.23028755], [78.15313721, 31.23068047], [78.14782715, 31.2315712], [78.14583588, 31.22688103], [78.14360809, 31.22407913], [78.137146, 31.22242165], [78.13490295, 31.21611977], [78.11915588, 31.21404076], [78.11380005, 31.20623016], [78.10984802, 31.2056694], [78.10688019, 31.20248985], [78.10079193, 31.19979095], [78.09237671, 31.19283104], [78.08773804, 31.19079971], [78.08007813, 31.19070816], [78.07549286, 31.19291115], [78.07110596, 31.19276047], [78.05915833, 31.19236946], [78.05383301, 31.19293022], [78.03967285, 31.18750954], [78.03874969, 31.18715096], [78.029953, 31.18531036], [78.02688599, 31.18019104], [78.01622009, 31.1715126], [78.01528168, 31.16615105], [78.01654816, 31.15850067], [78.01423645, 31.15493965], [78.00772095, 31.1570797], [77.9925766, 31.16703033], [77.98522949, 31.16802025], [77.97896576, 31.16644096], [77.96938324, 31.1651516], [77.95475769, 31.1787796], [77.94602203, 31.17617035], [77.9412384, 31.17116165], [77.93921661, 31.16730118], [77.93443298, 31.16729164], [77.91468811, 31.15657806], [77.9094162, 31.15550041], [77.9021759, 31.15882111], [77.89279175, 31.15726852], [77.88748932, 31.15470123], [77.88970947, 31.14896965], [77.88575745, 31.14307022], [77.88040161, 31.13743019], [77.87905884, 31.13158989], [77.87872314, 31.12467194], [77.87275696, 31.12321091], [77.85787201, 31.11623955], [77.85153198, 31.11096954], [77.8501358, 31.10420036], [77.85037994, 31.09516907], [77.84282684, 31.0812912], [77.83746338, 31.07751083], [77.8310318, 31.07703972], [77.82472992, 31.07443047], [77.81954956, 31.06491089], [77.81469727, 31.06090164], [77.80947876, 31.05973244], [77.80960846, 31.06137085], [77.8068924, 31.06233025], [77.80060577, 31.06208038], [77.80491638, 31.05877113], [77.80502319, 31.05406952], [77.81067657, 31.04359055], [77.81511688, 31.03392982], [77.81880951, 31.03230095], [77.82160187, 31.02992058], [77.82106018, 31.02108002], [77.81884766, 31.01579094], [77.82270813, 31.01180077], [77.82533264, 31.00813293], [77.82470703, 31.0051899], [77.81005096, 31.00521088], [77.81028748, 31.00213051], [77.81360626, 30.99892044], [77.81091309, 30.9953804], [77.80754089, 30.99384117], [77.80621338, 30.98806], [77.80648041, 30.98503113], [77.80621338, 30.98348045], [77.80523682, 30.98163986], [77.80319214, 30.97970963], [77.79872131, 30.97611809], [77.79728699, 30.97295952], [77.79641724, 30.96982002], [77.79740143, 30.96775818], [77.80158234, 30.96356964], [77.80462646, 30.96099091], [77.81324768, 30.96244812], [77.81639099, 30.96198273], [77.81891632, 30.96009064], [77.81932068, 30.95684052], [77.8171463, 30.95356941], [77.81260681, 30.95279121], [77.80754089, 30.95371056], [77.80227661, 30.95510101], [77.79659271, 30.95843124], [77.78761292, 30.96572113], [77.77838135, 30.97232056], [77.77094269, 30.97566032], [77.76387787, 30.97698975], [77.75392151, 30.97684288], [77.74196625, 30.96764183], [77.73634338, 30.96359062], [77.73457336, 30.95956993], [77.73327637, 30.94950104], [77.73487854, 30.94401169], [77.73568726, 30.94202042], [77.73665619, 30.9396019], [77.73924255, 30.93667984], [77.74357605, 30.93522835], [77.74649811, 30.9339695], [77.74736786, 30.92872047], [77.74559784, 30.92230988], [77.75219727, 30.92095947], [77.75824738, 30.92038155], [77.76317596, 30.92015076], [77.76725769, 30.92048073], [77.7716217, 30.92419052], [77.77449036, 30.92533112], [77.78185272, 30.92621994], [77.78874207, 30.92628098], [77.79102325, 30.92613029], [77.79337311, 30.92598152], [77.79561615, 30.92379951], [77.79498291, 30.92043114], [77.79741669, 30.91674995], [77.80084991, 30.91274071], [77.7989502, 30.90879059], [77.79463196, 30.90348053], [77.79088593, 30.90067101], [77.78639984, 30.8960495], [77.78543854, 30.89335823], [77.78443909, 30.88837051], [77.78412628, 30.88215065], [77.78362274, 30.87865067], [77.78350067, 30.87206078], [77.78705597, 30.86812019], [77.7889328, 30.86495972], [77.78936768, 30.85854912], [77.77852631, 30.86000061], [77.77359772, 30.86103058], [77.76899719, 30.86295128], [77.76516724, 30.86517906], [77.76278687, 30.86816025], [77.76177979, 30.87508965], [77.76026917, 30.87784195], [77.75820923, 30.88047981], [77.75454712, 30.88244057], [77.75105286, 30.88272095], [77.74774933, 30.88227081], [77.74452209, 30.88119125], [77.74178314, 30.87828064], [77.74085236, 30.87433052], [77.74101257, 30.86992073], [77.74167633, 30.86420059], [77.73958588, 30.86018944], [77.73573303, 30.85704994], [77.73336792, 30.85420036], [77.73146057, 30.85077095], [77.73338318, 30.8474884], [77.74089813, 30.84015083], [77.74407196, 30.83624268], [77.74440765, 30.82985115], [77.74038696, 30.82766914], [77.73744965, 30.82629967], [77.73403168, 30.82406807], [77.73088837, 30.81939125], [77.7265625, 30.8144207], [77.72408295, 30.81104088], [77.71942139, 30.80830956], [77.71806335, 30.80509949], [77.71710205, 30.79949951], [77.71539307, 30.79421806], [77.70864868, 30.78450966], [77.70452881, 30.77902031], [77.69843292, 30.77342033], [77.69265747, 30.77141953], [77.68828583, 30.76866913], [77.69148254, 30.76025963], [77.69300842, 30.75785065], [77.6917572, 30.75505066], [77.6904068, 30.75132942], [77.69158936, 30.74831009], [77.69394684, 30.74617004], [77.69770813, 30.74496841], [77.700737, 30.74496841], [77.70435333, 30.74570084], [77.70723724, 30.74552917], [77.70928192, 30.74415016], [77.71163177, 30.7420826], [77.71289062, 30.73945236], [77.71533966, 30.73826027], [77.71765137, 30.73886108], [77.72033691, 30.7382412], [77.72171021, 30.73635292], [77.72249603, 30.73335838], [77.72219086, 30.73061943], [77.7252121, 30.72734833], [77.73068237, 30.72447968], [77.73227692, 30.72070122], [77.73432922, 30.71669006], [77.7372818, 30.71346855], [77.7410965, 30.71066093], [77.74038696, 30.7071228], [77.73690033, 30.70500946], [77.73574066, 30.70157814], [77.73358154, 30.69745255], [77.73339844, 30.69350052], [77.73340607, 30.68582916], [77.7365799, 30.68284988], [77.74275208, 30.68056107], [77.74788666, 30.67814064], [77.75419617, 30.67605972], [77.75881195, 30.67238998], [77.76294708, 30.66843033], [77.76590729, 30.66527939], [77.76950073, 30.66419029], [77.77220917, 30.66539192], [77.77423096, 30.66566086], [77.77706146, 30.66558838], [77.77905273, 30.66377068], [77.7749176, 30.65845108], [77.77025604, 30.65514946], [77.76830292, 30.65147972], [77.77217102, 30.64496994], [77.77497864, 30.64112091], [77.77545166, 30.63746834], [77.77231598, 30.63237953], [77.77127838, 30.62848091], [77.77645874, 30.62613106], [77.77960968, 30.62268066], [77.78199005, 30.61935806], [77.77864838, 30.61787987], [77.7722168, 30.61783028], [77.76711273, 30.61818123], [77.76132965, 30.61944962], [77.75660706, 30.62032127], [77.75563049, 30.61619949], [77.7572403, 30.60479927], [77.75444031, 30.60074997], [77.74971008, 30.60136986], [77.74246979, 30.6071701], [77.73832703, 30.60808945], [77.73478699, 30.60816002], [77.73210907, 30.60712814], [77.73159027, 30.6047802], [77.73126984, 30.60152054], [77.72952271, 30.59838295], [77.73192596, 30.5961895], [77.73863983, 30.59287071], [77.74362946, 30.58975983], [77.74619293, 30.5844326], [77.74948883, 30.57996941], [77.75187683, 30.57458115], [77.75353241, 30.57023048], [77.75727081, 30.56558037], [77.76184845, 30.56298828], [77.7665329, 30.56349945], [77.77091217, 30.56240082], [77.77459717, 30.55890083], [77.77826691, 30.5573597], [77.78637695, 30.56139946], [77.79058838, 30.56025124], [77.7951889, 30.5611496], [77.79827118, 30.56413078], [77.80323792, 30.56377983], [77.80586243, 30.56073952], [77.80687714, 30.55426025], [77.80680847, 30.5493412], [77.80995941, 30.5440197], [77.81220245, 30.5380497], [77.81064606, 30.53318024], [77.80502319, 30.52478027], [77.80412292, 30.52037048], [77.80197144, 30.51538086], [77.80056, 30.51316071]]]}}, {\\\"id\\\": \\\"12\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.14_1\\\", \\\"HASC_1\\\": \\\"IN.JK\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Jammu and Kashmir\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -1.9, \\\"dalys_apm25_rate_6cod_mean_total\\\": 808.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -2178.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1371.0, \\\"geo-id\\\": 12, \\\"hpm25_child_popweighted\\\": -260.0, \\\"hpm25_female_popweighted\\\": -299.0, \\\"hpm25_male_popweighted\\\": -215.0, \\\"location\\\": \\\"Jammu and Kashmir\\\", \\\"mort_apm25_6cod_mean_total\\\": 3830.0, \\\"mort_hpm25_6cod_mean_total\\\": -8708.0, \\\"mort_tpm25_6cod_mean_total\\\": -4878.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[75.78742218, 32.89332199], [75.78917694, 32.88462067], [75.78983307, 32.88140106], [75.79464722, 32.87018967], [75.79537201, 32.86925888], [75.80551147, 32.85614014], [75.80831146, 32.85319901], [75.81581116, 32.84706116], [75.82106018, 32.84276199], [75.82752991, 32.84037018], [75.83738708, 32.8367691], [75.85523987, 32.82614136], [75.87378693, 32.81369019], [75.88568115, 32.79547882], [75.90006256, 32.76985931], [75.91248322, 32.75712204], [75.91404724, 32.74201965], [75.90983582, 32.72093964], [75.90486145, 32.70936203], [75.89906311, 32.70024872], [75.89657593, 32.69105911], [75.89885712, 32.6806221], [75.90540314, 32.67224884], [75.91475677, 32.6659317], [75.92405701, 32.6582222], [75.92543793, 32.65427017], [75.92362213, 32.64369965], [75.90776062, 32.61914063], [75.90458679, 32.61521912], [75.8862915, 32.59191895], [75.87254333, 32.57619095], [75.87177277, 32.57529068], [75.85653687, 32.55842209], [75.83783722, 32.5376091], [75.83055115, 32.52450943], [75.82892609, 32.51996994], [75.82504272, 32.50922012], [75.82357788, 32.50764084], [75.81569672, 32.4992218], [75.80433655, 32.48706055], [75.79014587, 32.47879028], [75.77886963, 32.47504044], [75.77246857, 32.47510147], [75.75296021, 32.4752388], [75.7459259, 32.47634888], [75.74505615, 32.47426224], [75.74373627, 32.46910858], [75.73532104, 32.45468903], [75.72970581, 32.44506073], [75.72515106, 32.43832016], [75.71974945, 32.43032074], [75.71534729, 32.42383194], [75.71153259, 32.41815948], [75.69822693, 32.40953064], [75.68495941, 32.40061951], [75.66274261, 32.39350891], [75.64807129, 32.3888092], [75.63697815, 32.38737869], [75.59263611, 32.38169861], [75.56700134, 32.37184143], [75.55731964, 32.36695862], [75.54515076, 32.36082077], [75.52921295, 32.34888077], [75.5242691, 32.34004974], [75.51582336, 32.29798889], [75.50559998, 32.28134155], [75.50450134, 32.27952957], [75.50123596, 32.27605057], [75.49894714, 32.27532959], [75.49472046, 32.27690887], [75.49002075, 32.28797913], [75.49212646, 32.30279922], [75.49111938, 32.30672073], [75.49022675, 32.31021118], [75.48475647, 32.31029129], [75.47992706, 32.31034851], [75.47142029, 32.31465149], [75.46775818, 32.3175621], [75.473526, 32.33919907], [75.47223663, 32.34004974], [75.46660614, 32.33885193], [75.45635223, 32.33351898], [75.45178986, 32.33176041], [75.44859314, 32.33132172], [75.43257904, 32.32669067], [75.43107605, 32.32648849], [75.41499329, 32.32427216], [75.39745331, 32.32625198], [75.38595581, 32.32769012], [75.37853241, 32.3288002], [75.37346649, 32.33057022], [75.35919189, 32.33491898], [75.34526825, 32.33916092], [75.3440094, 32.34020996], [75.33177948, 32.34469986], [75.32530212, 32.3428421], [75.32440186, 32.34165955], [75.32232666, 32.33732605], [75.31148529, 32.344841], [75.2890625, 32.35757446], [75.28033447, 32.36726379], [75.27822876, 32.36825562], [75.26676178, 32.37366486], [75.25331116, 32.3800087], [75.2371521, 32.39577866], [75.23152924, 32.399189], [75.2305069, 32.39929199], [75.22384644, 32.39995956], [75.20024872, 32.40232086], [75.19740295, 32.40409088], [75.19547272, 32.40531158], [75.19272614, 32.41807175], [75.19234467, 32.41984177], [75.18852997, 32.42448044], [75.17954254, 32.42544174], [75.17195892, 32.42190552], [75.16040039, 32.41651154], [75.14763641, 32.41337967], [75.13945007, 32.41460419], [75.12792969, 32.42116928], [75.12090302, 32.44149017], [75.11888123, 32.44377136], [75.11444092, 32.44878387], [75.10978699, 32.45404053], [75.10675049, 32.45503998], [75.09818268, 32.4658699], [75.08262634, 32.48004532], [75.0716095, 32.48296356], [75.06268311, 32.48212814], [75.06140137, 32.48200989], [75.03663635, 32.49206924], [75.03016663, 32.49176025], [75.02140808, 32.48537064], [75.01174927, 32.47618103], [75.00608826, 32.46904373], [75.00154114, 32.46330261], [75.0, 32.4591217], [74.98786926, 32.44956207], [74.97934723, 32.44776917], [74.97310638, 32.44792938], [74.96386719, 32.45252991], [74.94889832, 32.4540863], [74.943573, 32.46070862], [74.9336319, 32.46757126], [74.92411804, 32.46825027], [74.8996582, 32.4661293], [74.89681244, 32.46741867], [74.89099884, 32.47005844], [74.88523102, 32.47840881], [74.88291931, 32.4817543], [74.88287354, 32.48181915], [74.88274384, 32.48189926], [74.87919617, 32.48408127], [74.87666321, 32.48564148], [74.86151123, 32.48947906], [74.85642242, 32.49267197], [74.84618378, 32.49438858], [74.83532715, 32.49621201], [74.818573, 32.49605942], [74.79885864, 32.48405838], [74.76138306, 32.4821701], [74.75802612, 32.47993851], [74.74822998, 32.47924042], [74.74698639, 32.47915268], [74.74357605, 32.48149872], [74.72109985, 32.48173904], [74.69841766, 32.48493958], [74.68673706, 32.4930687], [74.68225861, 32.50204849], [74.68138123, 32.50381088], [74.67917633, 32.51541138], [74.68302917, 32.52960205], [74.68051147, 32.53818893], [74.66195679, 32.55147171], [74.65999603, 32.55324936], [74.65239716, 32.56016159], [74.64802551, 32.5718689], [74.64330292, 32.59595108], [74.64221191, 32.61104965], [74.64924622, 32.62586975], [74.65844727, 32.63735962], [74.66921234, 32.64593887], [74.6762085, 32.65800095], [74.67563629, 32.66577911], [74.67499542, 32.66672516], [74.66928101, 32.67509079], [74.66210938, 32.68046951], [74.65419006, 32.69245148], [74.65013885, 32.71841049], [74.66188049, 32.75482178], [74.66805267, 32.76340103], [74.66752625, 32.76659012], [74.67776489, 32.78157043], [74.68768311, 32.79608154], [74.69458008, 32.80952072], [74.70038605, 32.82703018], [74.69702148, 32.83971405], [74.68083191, 32.83819962], [74.66146088, 32.82802963], [74.64199829, 32.82289886], [74.63800049, 32.81809998], [74.63722992, 32.81081009], [74.64154053, 32.79188919], [74.63279724, 32.77766037], [74.61423492, 32.75773239], [74.60831451, 32.75747299], [74.5941391, 32.75684357], [74.57919312, 32.75331497], [74.57360077, 32.75555038], [74.56710815, 32.75521088], [74.54310608, 32.74544144], [74.54120636, 32.74467087], [74.53153229, 32.74073029], [74.50269318, 32.75986862], [74.47973633, 32.77267075], [74.47792053, 32.77532959], [74.47195435, 32.77836227], [74.46605682, 32.78136063], [74.46202087, 32.79088974], [74.46166992, 32.7917099], [74.45748901, 32.80157089], [74.45423126, 32.80506897], [74.45063782, 32.81682205], [74.44522858, 32.82556915], [74.44321442, 32.82882309], [74.43006134, 32.84465408], [74.42635345, 32.85777283], [74.42933655, 32.87950897], [74.42848969, 32.88360214], [74.42505646, 32.89305878], [74.41389465, 32.90394974], [74.40605164, 32.90697479], [74.3886795, 32.90841293], [74.38579559, 32.90864944], [74.36832428, 32.90845108], [74.36471558, 32.90840912], [74.3477478, 32.90821075], [74.3272171, 32.913311], [74.31803131, 32.91970062], [74.31613922, 32.93016052], [74.32071686, 32.94142914], [74.33489227, 32.95476151], [74.34635925, 32.96554947], [74.35317993, 32.98313141], [74.35282898, 32.9902916], [74.35169983, 33.01313019], [74.34983063, 33.01625061], [74.33792114, 33.02593994], [74.32647705, 33.02946091], [74.30787659, 33.03052139], [74.2831955, 33.04319], [74.25496674, 33.04877472], [74.24203491, 33.04729462], [74.22039795, 33.04481506], [74.21644592, 33.04299164], [74.20524597, 33.04330063], [74.19927216, 33.04687881], [74.19064331, 33.07670975], [74.17624664, 33.10715103], [74.1570282, 33.12586212], [74.14878082, 33.13388443], [74.14485168, 33.13526917], [74.11170197, 33.16444016], [74.09986877, 33.17250824], [74.08283997, 33.18074036], [74.05643463, 33.18661499], [74.03366852, 33.18809891], [74.02625275, 33.188591], [74.01822662, 33.19319153], [74.0142746, 33.19824982], [74.01125336, 33.21875], [74.01101685, 33.23849869], [74.0131073, 33.2498703], [74.01397705, 33.25094223], [74.02030182, 33.25878143], [74.02438354, 33.26245499], [74.03649902, 33.2647438], [74.04799652, 33.26447296], [74.06503296, 33.2599144], [74.06829071, 33.25999069], [74.07894135, 33.26023102], [74.08810425, 33.26289749], [74.09069061, 33.26364899], [74.10298157, 33.27054214], [74.11579895, 33.28113174], [74.11763, 33.28559875], [74.16685486, 33.3441391], [74.16944122, 33.34580994], [74.17074585, 33.34664917], [74.18508148, 33.38351059], [74.18421173, 33.3910408], [74.18006134, 33.40206909], [74.17929077, 33.42568588], [74.18165588, 33.43040085], [74.18292999, 33.44197083], [74.18707275, 33.45552063], [74.18564606, 33.46646881], [74.18502808, 33.46773911], [74.17813873, 33.48168182], [74.16460419, 33.49564743], [74.15810394, 33.50235367], [74.14263916, 33.51831818], [74.1233902, 33.54320908], [74.09696198, 33.56917953], [74.09571075, 33.57039642], [74.08835602, 33.57320404], [74.07447052, 33.56852341], [74.0743866, 33.56943893], [74.05390167, 33.56507874], [74.04535675, 33.56575012], [74.02844238, 33.57468033], [74.01468658, 33.59836578], [74.01066589, 33.60528946], [74.0, 33.62366867], [73.9996109, 33.62478256], [73.97570038, 33.69363403], [73.95625305, 33.72029114], [73.96646118, 33.74032211], [74.0, 33.75257874], [74.02397919, 33.77204132], [74.0283432, 33.77595901], [74.03833008, 33.79513931], [74.04134369, 33.79899216], [74.04904938, 33.80883026], [74.05276489, 33.81134033], [74.06572723, 33.82009888], [74.0900116, 33.82627869], [74.12979889, 33.82756042], [74.14334106, 33.83013916], [74.17008972, 33.83988953], [74.192276, 33.85142136], [74.20762634, 33.8594017], [74.21967316, 33.86717606], [74.24555969, 33.89500046], [74.26112366, 33.92479706], [74.26358032, 33.94261932], [74.26325226, 33.95523071], [74.26274109, 33.97428894], [74.25457764, 33.99725723], [74.24868774, 34.01382065], [74.24652863, 34.01602936], [74.23722076, 34.02553177], [74.22556305, 34.03340149], [74.2146759, 34.03855515], [74.1963501, 34.04008484], [74.18143463, 34.03956604], [74.16142273, 34.03887177], [74.14922333, 34.04302597], [74.13244629, 34.05267334], [74.12688446, 34.05426407], [74.12369537, 34.0551796], [74.1149826, 34.05378342], [74.10046387, 34.04562759], [74.09591675, 34.04032135], [74.0870285, 34.03776169], [74.0610733, 34.03470993], [74.05665588, 34.03124619], [74.04405975, 34.02972031], [74.03890228, 34.02910995], [74.006073, 34.02244186], [74.0, 34.03018951], [73.90898895, 34.03253937], [73.89817047, 34.03282166], [73.88980865, 34.04240417], [73.88321686, 34.04994965], [73.88432312, 34.06135941], [73.88565063, 34.07511902], [73.9043808, 34.09689331], [73.90408325, 34.1222496], [73.91707611, 34.14210892], [73.94477081, 34.1701889], [73.97657776, 34.21180344], [73.98203278, 34.23907852], [73.97622681, 34.26480865], [73.94097137, 34.30173874], [73.9199295, 34.34231186], [73.91334534, 34.34792709], [73.89940643, 34.35981369], [73.8894043, 34.35702515], [73.87940979, 34.3542366], [73.8417511, 34.33832169], [73.80739594, 34.35671997], [73.77339172, 34.34975052], [73.76322174, 34.35963058], [73.76432037, 34.37107086], [73.77698517, 34.41630173], [73.78965759, 34.42703629], [73.80725861, 34.44194794], [73.85481262, 34.47335052], [73.89874268, 34.4957695], [73.88668823, 34.51499939], [73.89533997, 34.54666901], [73.94806671, 34.5730896], [73.94155884, 34.59195709], [73.92733002, 34.64588928], [73.94155884, 34.67720032], [73.96022034, 34.69668198], [73.98607635, 34.70415878], [74.0, 34.70821762], [74.01289368, 34.70985413], [74.03363037, 34.69364166], [74.04171753, 34.68731689], [74.0491333, 34.68495941], [74.05970001, 34.68508911], [74.08130646, 34.69202042], [74.08653259, 34.69371033], [74.09313965, 34.69451904], [74.09716034, 34.69290161], [74.11676788, 34.6912117], [74.13269806, 34.69023895], [74.1417923, 34.69120026], [74.14897156, 34.69527054], [74.17473602, 34.71735001], [74.20295715, 34.7365799], [74.21050262, 34.74018097], [74.22574615, 34.74745941], [74.22749329, 34.75008011], [74.2390213, 34.75207901], [74.26989746, 34.7626915], [74.27974701, 34.76826859], [74.28679657, 34.77416992], [74.30278015, 34.79753876], [74.30729675, 34.80030441], [74.31509399, 34.80025864], [74.33094788, 34.79248047], [74.33159637, 34.79216766], [74.34126282, 34.78969193], [74.34621429, 34.79040909], [74.36753845, 34.80256271], [74.37554169, 34.80344391], [74.47396851, 34.79063416], [74.4771347, 34.78964996], [74.48536682, 34.7870903], [74.50657654, 34.77553177], [74.51470184, 34.77480316], [74.5381012, 34.77618408], [74.54406738, 34.77653885], [74.56149292, 34.77444077], [74.56529236, 34.77186966], [74.57715607, 34.76948929], [74.58017731, 34.77009964], [74.61242676, 34.74637222], [74.61815643, 34.74214935], [74.63154602, 34.73799896], [74.63883209, 34.73353958], [74.64798737, 34.7226181], [74.65805817, 34.71060181], [74.6713028, 34.70069885], [74.70300293, 34.6930809], [74.72807312, 34.68858337], [74.73931885, 34.68722153], [74.76312256, 34.68433762], [74.7664032, 34.68519211], [74.7721405, 34.68270874], [74.78659058, 34.68273163], [74.83560181, 34.67755127], [74.85389709, 34.67819977], [74.88981628, 34.68387222], [74.89375305, 34.6844902], [74.9105072, 34.68320847], [74.92781067, 34.67831039], [74.94671631, 34.66635132], [74.99780273, 34.65108109], [75.0, 34.64945602], [75.00364685, 34.64675903], [75.01874542, 34.64149857], [75.02990723, 34.64147186], [75.04180145, 34.64141846], [75.05079651, 34.6439209], [75.05449677, 34.6466217], [75.08472443, 34.65538025], [75.10555267, 34.65565872], [75.11119843, 34.6579895], [75.14229584, 34.66241074], [75.16467285, 34.66044998], [75.17727661, 34.65745926], [75.17849731, 34.65717697], [75.20671844, 34.64628983], [75.23575592, 34.64829254], [75.24971008, 34.64731216], [75.25963593, 34.64408112], [75.26605988, 34.63954926], [75.26693726, 34.63454056], [75.25807953, 34.61759949], [75.26185608, 34.61088181], [75.27915192, 34.60174942], [75.33519745, 34.57213211], [75.35054779, 34.5622406], [75.37782288, 34.55242157], [75.39497375, 34.54880905], [75.41396332, 34.54734039], [75.46463776, 34.54338837], [75.478508, 34.5393486], [75.50609589, 34.53733063], [75.51687622, 34.53779221], [75.52120209, 34.53958893], [75.55179596, 34.53813934], [75.56463623, 34.53874969], [75.57888794, 34.53944016], [75.59188843, 34.54006958], [75.61556244, 34.53853989], [75.64414978, 34.53353882], [75.69230652, 34.52153015], [75.71383667, 34.5184021], [75.72923279, 34.51615906], [75.74920654, 34.51583099], [75.76877594, 34.5221405], [75.79302979, 34.53392029], [75.81047821, 34.548172], [75.82064819, 34.55891037], [75.84107971, 34.57310104], [75.84327698, 34.57463074], [75.8814621, 34.5907402], [75.91192627, 34.60113144], [75.91864777, 34.60483932], [75.93221283, 34.62443161], [75.94625092, 34.63117981], [75.96720886, 34.63360214], [75.96821594, 34.63333893], [75.98327637, 34.62940979], [75.99185181, 34.62997055], [76.0003891, 34.63581085], [76.01436615, 34.65357208], [76.02542877, 34.66410065], [76.03646088, 34.67026901], [76.05502319, 34.67602921], [76.07444, 34.67631149], [76.08582306, 34.6714592], [76.09295654, 34.66656113], [76.12193298, 34.64665222], [76.13075256, 34.64352036], [76.13909149, 34.64247894], [76.15791321, 34.64340973], [76.19278717, 34.65526962], [76.19785309, 34.6591301], [76.22737885, 34.67214203], [76.23429871, 34.67309952], [76.26004791, 34.68437195], [76.27511597, 34.69364166], [76.28330231, 34.70151901], [76.28994751, 34.71232224], [76.30150604, 34.72444153], [76.31613922, 34.73163223], [76.32872009, 34.73305511], [76.33988953, 34.73431778], [76.35073853, 34.73470306], [76.38593292, 34.73595047], [76.40953827, 34.75216675], [76.42761993, 34.76243973], [76.43695831, 34.76438141], [76.46920013, 34.79166794], [76.47177124, 34.79302216], [76.47434235, 34.79437256], [76.47732544, 34.79398727], [76.48973846, 34.79238129], [76.51409149, 34.78380203], [76.5453186, 34.76559067], [76.56181335, 34.75833893], [76.57097626, 34.75842285], [76.58001709, 34.75551605], [76.61804199, 34.75606918], [76.65249634, 34.75656128], [76.67163849, 34.75741959], [76.6818161, 34.75959015], [76.68719482, 34.7632103], [76.69670105, 34.77912903], [76.70619202, 34.80125046], [76.72728729, 34.82089996], [76.73784637, 34.83074188], [76.74324036, 34.84009933], [76.74468994, 34.84473038], [76.74343872, 34.86489105], [76.73886108, 34.90192795], [76.74337006, 34.91814041], [76.74936676, 34.92660141], [76.76242828, 34.93299103], [76.76419067, 34.93312073], [76.79933929, 34.93577194], [76.80442047, 34.93432999], [76.81105042, 34.93545532], [76.82552338, 34.94165421], [76.84815216, 34.95796967], [76.85315704, 34.963871], [76.86315155, 34.97084045], [76.87004089, 34.97243118], [76.88350677, 34.97032928], [76.89846802, 34.9642601], [76.90140533, 34.96307373], [76.90843201, 34.96168518], [76.95034027, 34.94094086], [76.9703598, 34.93558121], [76.98874664, 34.93521881], [76.99748993, 34.93915176], [77.01013947, 34.95628738], [77.01145172, 34.96670914], [77.01130676, 34.9727211], [77.01065826, 35.0], [77.01029968, 35.01618195], [77.01094818, 35.02759171], [77.01378632, 35.03512192], [77.01809692, 35.03846359], [77.0269165, 35.04079437], [77.03677368, 35.03236389], [77.068367, 35.02412033], [77.08137512, 35.02633667], [77.10980225, 35.03932953], [77.1568222, 35.05469894], [77.17558289, 35.06679153], [77.19481659, 35.0791893], [77.28079224, 35.13828659], [77.2951889, 35.14562988], [77.30075073, 35.14847946], [77.37944031, 35.19789124], [77.38440704, 35.19916916], [77.41883087, 35.22006989], [77.44252014, 35.23443985], [77.48542023, 35.26654053], [77.53961182, 35.29777908], [77.58502197, 35.3239212], [77.6505661, 35.36708069], [77.66091919, 35.37522888], [77.73551178, 35.43384171], [77.76036835, 35.45117569], [77.77467346, 35.4601593], [77.81465149, 35.48524857], [77.81929016, 35.49328995], [77.82392883, 35.50133133], [77.84082031, 35.50111008], [77.84307861, 35.50098419], [77.84677887, 35.50078201], [77.85018921, 35.49172974], [77.85131836, 35.48873901], [77.8626709, 35.45859146], [77.86872101, 35.45051956], [77.87941742, 35.43624878], [77.88477325, 35.43195724], [77.8886261, 35.42887115], [77.89956665, 35.42789459], [77.90296936, 35.42758942], [77.91018677, 35.42935944], [77.9198761, 35.43433762], [77.92092896, 35.4348793], [77.92801666, 35.44054031], [77.94377899, 35.46295547], [77.94458771, 35.46411133], [77.95128632, 35.47364044], [77.96172333, 35.48006058], [77.9668808, 35.48131561], [77.99064636, 35.48711014], [78.00999451, 35.48918915], [78.01998138, 35.49026108], [78.04535675, 35.49108887], [78.06375122, 35.49169159], [78.06481934, 35.49172592], [78.07935333, 35.49219894], [78.08194733, 35.49169922], [78.08769989, 35.49058914], [78.09429932, 35.48929977], [78.10398865, 35.48445892], [78.10704803, 35.4804306], [78.10983276, 35.47676849], [78.1108017, 35.47266006], [78.10769653, 35.46456909], [78.10449982, 35.4618187], [78.09732819, 35.45563889], [78.07964325, 35.44815063], [78.07183075, 35.44684982], [78.07019043, 35.44464111], [78.06887817, 35.44287872], [78.0316925, 35.42306137], [78.03009796, 35.42046738], [78.02983093, 35.42002869], [78.02845764, 35.41928101], [78.02459717, 35.41717148], [78.02120209, 35.41688156], [78.02076721, 35.41646957], [78.0194931, 35.41526031], [77.99707031, 35.39408875], [77.99028778, 35.37903214], [77.98995972, 35.36363983], [77.99185181, 35.34854889], [77.99434662, 35.34492874], [78.00151062, 35.29796982], [78.00202179, 35.29462051], [78.00636292, 35.29035187], [78.01370239, 35.26418686], [78.01774597, 35.24975204], [78.03183746, 35.2202301], [78.04276276, 35.20233154], [78.04360962, 35.20132828], [78.05221558, 35.19109726], [78.05755615, 35.1847496], [78.0597229, 35.18310928], [78.06902313, 35.17604065], [78.07740021, 35.1727066], [78.07834625, 35.17232895], [78.11605072, 35.14535141], [78.11843872, 35.14243698], [78.12417603, 35.13542175], [78.12605286, 35.12903976], [78.12531281, 35.12599182], [78.12431335, 35.12189102], [78.11709595, 35.11164093], [78.11102295, 35.10734177], [78.09771729, 35.09793091], [78.08894348, 35.09582901], [78.08831787, 35.09568024], [78.08428192, 35.09077072], [78.08287048, 35.08248901], [78.09494781, 35.05690002], [78.11483002, 35.01475906], [78.1182785, 35.00664902], [78.12110901, 35.0], [78.13031006, 34.97834015], [78.13347626, 34.97087097], [78.16731262, 34.91213989], [78.17359924, 34.90629959], [78.17515564, 34.90280533], [78.18464661, 34.88151932], [78.18833923, 34.86278152], [78.20732117, 34.76610947], [78.21039581, 34.75893402], [78.21868896, 34.73955917], [78.22104645, 34.73403168], [78.23156738, 34.71680069], [78.23176575, 34.71653748], [78.24803162, 34.69509888], [78.26570129, 34.67938995], [78.27259827, 34.67494583], [78.27404785, 34.67401123], [78.28436279, 34.66736221], [78.30033875, 34.66193008], [78.30680084, 34.660923], [78.31733704, 34.65927887], [78.32353973, 34.65658188], [78.32492065, 34.65597916], [78.38717651, 34.6516304], [78.39552307, 34.64939117], [78.39836121, 34.64863205], [78.39872742, 34.64835358], [78.40458679, 34.6439209], [78.40701294, 34.63663101], [78.40689087, 34.6210289], [78.40931702, 34.61349869], [78.41812897, 34.60540009], [78.42511749, 34.60346222], [78.43546295, 34.6028595], [78.44315338, 34.60240173], [78.45915222, 34.60278702], [78.48223114, 34.60334015], [78.51154327, 34.60911179], [78.537117, 34.614151], [78.5581665, 34.61474991], [78.56933594, 34.61194992], [78.58207703, 34.60314941], [78.61109161, 34.58306122], [78.62100983, 34.57427979], [78.63762665, 34.5522995], [78.64382935, 34.5478096], [78.65248871, 34.5381546], [78.66005707, 34.52972031], [78.68061829, 34.51560211], [78.68618774, 34.51276016], [78.69631958, 34.50759125], [78.71663666, 34.50100708], [78.73007965, 34.4966507], [78.7361145, 34.4916687], [78.73826599, 34.48989105], [78.74935913, 34.47698975], [78.75035095, 34.47505188], [78.75283813, 34.47016907], [78.75405121, 34.46901321], [78.76302338, 34.46046066], [78.78847504, 34.44142151], [78.79937744, 34.4332695], [78.82495117, 34.41413116], [78.83725739, 34.40701675], [78.83809662, 34.40652847], [78.87568665, 34.39465332], [78.89155579, 34.38964081], [78.91503906, 34.3788414], [78.92254639, 34.3753891], [78.92743683, 34.37163544], [78.92917633, 34.37030029], [78.93989563, 34.36207962], [78.96073914, 34.34609985], [78.96884918, 34.34162903], [78.97673798, 34.33393097], [78.98146057, 34.33285141], [78.98922729, 34.31926727], [78.99005127, 34.31782913], [78.99421692, 34.30252075], [78.99340057, 34.28874207], [78.98499298, 34.26779175], [78.9750061, 34.24285889], [78.95619965, 34.21783066], [78.94211578, 34.20479202], [78.93534088, 34.19961166], [78.91036224, 34.18050003], [78.89435577, 34.17002106], [78.88887787, 34.16643143], [78.87904358, 34.16132736], [78.87114716, 34.15723038], [78.85883331, 34.15180206], [78.81531525, 34.13261032], [78.77426147, 34.11450958], [78.77094269, 34.11373901], [78.76389313, 34.11210632], [78.76066589, 34.11135864], [78.75946045, 34.11108017], [78.72923279, 34.09569931], [78.7244339, 34.09140396], [78.71331787, 34.08145905], [78.70638275, 34.0721817], [78.70614624, 34.05863953], [78.71212006, 34.05047989], [78.73184967, 34.04253006], [78.75953674, 34.03633881], [78.75987244, 34.03626633], [78.76064301, 34.03609848], [78.76595306, 34.03250885], [78.76828766, 34.02574921], [78.77036285, 34.01972961], [78.76841736, 34.01446915], [78.7636261, 34.00151062], [78.74289703, 33.9872818], [78.72841644, 33.9773407], [78.71578979, 33.96453094], [78.71425629, 33.95946884], [78.71615601, 33.94894028], [78.71724701, 33.94895935], [78.71665955, 33.93909073], [78.71492767, 33.93344879], [78.71156311, 33.92250061], [78.71724701, 33.89048004], [78.72566986, 33.87112045], [78.74178314, 33.84017944], [78.76132202, 33.81734085], [78.76203156, 33.81650925], [78.77506256, 33.80125046], [78.7805481, 33.7891922], [78.78398895, 33.77043152], [78.77529144, 33.74640274], [78.77522278, 33.74621964], [78.76239777, 33.73065948], [78.75756073, 33.7264595], [78.73731995, 33.70888138], [78.73724365, 33.70881653], [78.73175049, 33.70404053], [78.70929718, 33.67961121], [78.70842743, 33.67610931], [78.70678711, 33.66947937], [78.70935059, 33.66054916], [78.71098328, 33.65486908], [78.72727966, 33.62277603], [78.72992706, 33.61756897], [78.74223328, 33.59741211], [78.74347687, 33.59537506], [78.75811005, 33.57139206], [78.76319885, 33.56304932], [78.77068329, 33.55204391], [78.78386688, 33.53264999], [78.79115295, 33.52518845], [78.80387115, 33.50680923], [78.81859589, 33.48907852], [78.82073212, 33.48651505], [78.82325745, 33.48348999], [78.87039948, 33.43970108], [78.87152863, 33.43907928], [78.87565613, 33.43680191], [78.89539337, 33.42031097], [78.92125702, 33.39870071], [78.94110107, 33.3900795], [78.9548111, 33.37417984], [78.97268677, 33.36732101], [78.97953033, 33.35877609], [78.98866272, 33.34737015], [78.998703, 33.34022522], [79.00415039, 33.33634949], [79.01954651, 33.3307991], [79.03379822, 33.31357956], [79.03656769, 33.31208801], [79.0476532, 33.30611038], [79.06659698, 33.29589081], [79.07079315, 33.29092026], [79.07311249, 33.28359985], [79.06926727, 33.27310944], [79.0661087, 33.26448059], [79.06684875, 33.25462341], [79.06720734, 33.24983215], [79.07147217, 33.23816299], [79.07496643, 33.22861099], [79.09298706, 33.22045898], [79.11328125, 33.21128082], [79.12773132, 33.20473862], [79.14144135, 33.20009995], [79.15701294, 33.19791031], [79.1647644, 33.19681931], [79.18049622, 33.1946106], [79.1829834, 33.19292068], [79.18546295, 33.19123077], [79.20622253, 33.19395065], [79.21237183, 33.19475937], [79.31517029, 33.18880081], [79.35584259, 33.18952942], [79.3772583, 33.18991089], [79.39362335, 33.18893051], [79.399086, 33.18714905], [79.40197754, 33.18489456], [79.40983582, 33.17877197], [79.41683197, 33.16669083], [79.4175415, 33.15523911], [79.41546631, 33.1476593], [79.41320038, 33.14191437], [79.41075134, 33.13570023], [79.39853668, 33.11471176], [79.39726257, 33.10943222], [79.39502716, 33.10720062], [79.39328003, 33.10544586], [79.39055634, 33.10271072], [79.37358856, 33.07342911], [79.37328339, 33.0719986], [79.37230682, 33.06745911], [79.36760712, 33.06161118], [79.36618042, 33.05984116], [79.35492706, 33.03060913], [79.35301971, 33.02259064], [79.35186768, 33.01774216], [79.35002899, 32.99618149], [79.3507309, 32.99126053], [79.3509903, 32.98942184], [79.35121918, 32.98781586], [79.3524704, 32.97903061], [79.36211395, 32.96205902], [79.36503601, 32.95692062], [79.38111115, 32.93956757], [79.38313293, 32.93738937], [79.38712311, 32.93307877], [79.39096069, 32.930439], [79.39906311, 32.92486954], [79.41867065, 32.91139984], [79.43206024, 32.90510941], [79.4348526, 32.90032959], [79.44185638, 32.89466095], [79.44621277, 32.89113998], [79.44857788, 32.88922882], [79.45439911, 32.88035202], [79.45506287, 32.87805939], [79.45697021, 32.87142944], [79.46452332, 32.81674194], [79.47122955, 32.80282211], [79.47782135, 32.79624176], [79.48442078, 32.78966141], [79.49630737, 32.78411102], [79.5152359, 32.77528], [79.52672577, 32.76758957], [79.52893066, 32.76501465], [79.53334045, 32.75986099], [79.54052734, 32.74869156], [79.54402924, 32.73950195], [79.54541016, 32.73586655], [79.5473938, 32.73065186], [79.55539703, 32.7096405], [79.56124878, 32.68402863], [79.56259155, 32.67816925], [79.56429291, 32.67076111], [79.55776978, 32.63061905], [79.55355835, 32.62026978], [79.54982758, 32.61439133], [79.54535675, 32.60736084], [79.52404785, 32.59589005], [79.52200317, 32.59479141], [79.51436615, 32.59286499], [79.50878906, 32.59146118], [79.48854065, 32.59283066], [79.48497009, 32.59307098], [79.47812653, 32.59293365], [79.46414948, 32.59265137], [79.44801331, 32.58607864], [79.43630981, 32.57990265], [79.43031311, 32.57674026], [79.40381622, 32.55768967], [79.36222076, 32.53755951], [79.36148834, 32.5370369], [79.35997009, 32.53594971], [79.35324097, 32.53112793], [79.34697723, 32.52664185], [79.32025146, 32.49129868], [79.31373596, 32.48788834], [79.31221771, 32.48709106], [79.30493164, 32.48654938], [79.29734039, 32.48852921], [79.27011871, 32.5177803], [79.2607193, 32.52227783], [79.25840759, 32.52338028], [79.2579422, 32.5233345], [79.2532196, 32.52285767], [79.24816132, 32.52235031], [79.23497772, 32.51898956], [79.23309326, 32.51850891], [79.22310638, 32.51596069], [79.22088623, 32.51539612], [79.21382904, 32.5135994], [79.20693207, 32.51184082], [79.20295715, 32.51082993], [79.18330383, 32.50102234], [79.16506958, 32.49192047], [79.14885712, 32.4838295], [79.1289444, 32.46642685], [79.12652588, 32.46430969], [79.12172699, 32.45611191], [79.12024689, 32.45357895], [79.12007904, 32.45328903], [79.1181488, 32.45000076], [79.11978149, 32.43832016], [79.12187958, 32.42324066], [79.12133789, 32.41762161], [79.12119293, 32.41613007], [79.11180115, 32.39929199], [79.10912323, 32.38322067], [79.1044693, 32.37171173], [79.09564209, 32.367939], [79.09185028, 32.36903], [79.07662964, 32.37901688], [79.06754303, 32.38497925], [79.0642395, 32.3852272], [79.05970001, 32.38557053], [79.04921722, 32.38336945], [79.04904938, 32.383255], [79.04654694, 32.38156891], [79.02498627, 32.36701202], [78.99375916, 32.36429977], [78.98252869, 32.34582138], [78.97720337, 32.34276962], [78.97373199, 32.34360886], [78.97096252, 32.34428024], [78.92399597, 32.3633194], [78.91886139, 32.36539841], [78.91467285, 32.36709213], [78.91413879, 32.36771011], [78.90232849, 32.38139343], [78.90001678, 32.38407135], [78.88800049, 32.39237213], [78.88582611, 32.39597702], [78.87457275, 32.41461945], [78.8674469, 32.41909027], [78.85692596, 32.4189415], [78.83602142, 32.42528152], [78.8212204, 32.43627167], [78.81980896, 32.43732071], [78.81790161, 32.43873978], [78.81636047, 32.44062042], [78.79792786, 32.46318054], [78.79641724, 32.46427536], [78.78118134, 32.47529984], [78.77667236, 32.48392868], [78.77542877, 32.49055099], [78.77558136, 32.51635361], [78.77559662, 32.51966095], [78.7726059, 32.54434967], [78.76792145, 32.55327225], [78.76675415, 32.5554924], [78.76555634, 32.55776215], [78.76425171, 32.56484222], [78.76371002, 32.56781006], [78.76516724, 32.57493973], [78.77649689, 32.58818054], [78.78032684, 32.59832001], [78.77929687, 32.60224533], [78.77578735, 32.61562729], [78.77056885, 32.63552094], [78.76805878, 32.66297913], [78.76521301, 32.6736908], [78.76456451, 32.67609406], [78.76391602, 32.67848969], [78.76027679, 32.68416977], [78.7459259, 32.69607925], [78.74214172, 32.69601822], [78.7364502, 32.69593048], [78.71703339, 32.68072891], [78.66426849, 32.65649033], [78.65442657, 32.64923096], [78.65162659, 32.64442062], [78.63233948, 32.6110611], [78.62567139, 32.60705185], [78.60328674, 32.60438156], [78.59976959, 32.60525894], [78.5947113, 32.60652161], [78.58695221, 32.60845947], [78.55927277, 32.61233902], [78.54985046, 32.61231995], [78.54950714, 32.61231995], [78.54519653, 32.6123085], [78.5449295, 32.6123085], [78.53894043, 32.61042786], [78.53704834, 32.60983276], [78.53675079, 32.60974121], [78.53108215, 32.60795975], [78.52641296, 32.60649109], [78.50885773, 32.59471893], [78.50328064, 32.58956146], [78.49591064, 32.58274841], [78.48561096, 32.5732193], [78.47966003, 32.57312012], [78.47274017, 32.57786179], [78.47249603, 32.57802963], [78.47151947, 32.57823944], [78.47027588, 32.57850266], [78.46161652, 32.58034897], [78.45272064, 32.57950211], [78.44332886, 32.57207489], [78.4378891, 32.56777191], [78.41223907, 32.55606079], [78.41145325, 32.55430984], [78.40432739, 32.53873062], [78.40522766, 32.52523041], [78.41125488, 32.51982498], [78.41204834, 32.51911545], [78.41652679, 32.51509857], [78.41333771, 32.51324081], [78.41075897, 32.51174164], [78.40917206, 32.51202011], [78.40892029, 32.51271057], [78.40522766, 32.51422882], [78.40525818, 32.51512146], [78.40141296, 32.51818085], [78.4002533, 32.52368164], [78.39906311, 32.526371], [78.3979187, 32.52706909], [78.39438629, 32.52853012], [78.38243103, 32.52965164], [78.3766861, 32.52605057], [78.35636139, 32.51266098], [78.31040955, 32.47592926], [78.30623627, 32.47774887], [78.27851868, 32.50793076], [78.29503632, 32.52246094], [78.29917145, 32.52927017], [78.29662323, 32.57751083], [78.30236816, 32.57870102], [78.31799316, 32.58021164], [78.33175659, 32.58486938], [78.34062195, 32.59305954], [78.37706757, 32.61487961], [78.38881683, 32.62322998], [78.3759079, 32.62961197], [78.3709259, 32.63816071], [78.36315155, 32.67198944], [78.36367798, 32.68553162], [78.36756897, 32.69952011], [78.37782288, 32.71931076], [78.37494659, 32.72264862], [78.37121582, 32.7336998], [78.3707428, 32.74584961], [78.37277222, 32.76015091], [78.37135315, 32.76182938], [78.3642807, 32.76298141], [78.34474182, 32.76343155], [78.31394958, 32.74898148], [78.28765869, 32.73783112], [78.2946167, 32.73160934], [78.29811096, 32.72483063], [78.2985611, 32.71974182], [78.29572296, 32.71281052], [78.28486633, 32.70677948], [78.27274323, 32.70293045], [78.25911713, 32.70291901], [78.23658752, 32.69467163], [78.23326111, 32.68370056], [78.22496796, 32.67556], [78.2129364, 32.66918945], [78.20163727, 32.66519928], [78.19499207, 32.6673317], [78.18395233, 32.66387177], [78.17951202, 32.67041016], [78.17047882, 32.67721176], [78.15841675, 32.67913055], [78.15254211, 32.67901993], [78.14444733, 32.67660141], [78.13600159, 32.6703186], [78.13066101, 32.66006088], [78.12666321, 32.64910126], [78.12149811, 32.64234924], [78.11615753, 32.64241028], [78.106987, 32.64974213], [78.09926605, 32.65996933], [78.09337616, 32.66215134], [78.08851624, 32.659832], [78.07900238, 32.65279007], [78.07293701, 32.64440155], [78.06745911, 32.6256218], [78.06533051, 32.62427902], [78.05901337, 32.62458038], [78.0440979, 32.6288414], [78.0338974, 32.63560867], [78.03273773, 32.63375092], [78.03244019, 32.62839127], [78.03443146, 32.61565018], [78.03675842, 32.61085892], [78.04146576, 32.6053009], [78.04161072, 32.59923935], [78.03579712, 32.59194946], [78.02744293, 32.58864975], [78.01743317, 32.5870285], [77.98705292, 32.58819962], [77.9825592, 32.58652878], [77.97669983, 32.59194183], [77.9749527, 32.5963707], [77.96784973, 32.60797882], [77.96222687, 32.61380005], [77.95947266, 32.62073898], [77.95424652, 32.6259613], [77.95510101, 32.63481903], [77.95265961, 32.64039993], [77.9464798, 32.64273071], [77.93891144, 32.6480217], [77.93229675, 32.65620041], [77.92716217, 32.66262054], [77.9262085, 32.66680908], [77.92021179, 32.67951202], [77.9109726, 32.68817902], [77.90325165, 32.69309998], [77.90239716, 32.69841003], [77.90566254, 32.70359039], [77.90625763, 32.71234894], [77.90847778, 32.7163887], [77.90943909, 32.72138977], [77.91203308, 32.72576904], [77.91847229, 32.73078918], [77.91562653, 32.73369217], [77.91182709, 32.73651123], [77.9143219, 32.74177933], [77.91440582, 32.74454117], [77.91716003, 32.75188065], [77.9179306, 32.75691986], [77.91689301, 32.76272964], [77.91513062, 32.76605988], [77.91227722, 32.76716995], [77.90892792, 32.77212143], [77.90349579, 32.77289963], [77.89949799, 32.77532196], [77.89087677, 32.77450943], [77.88748169, 32.77526093], [77.88089752, 32.7754097], [77.876297, 32.78001022], [77.87224579, 32.78625107], [77.86696625, 32.79029083], [77.8690033, 32.80036926], [77.86454773, 32.80651855], [77.86383057, 32.81145096], [77.86126709, 32.81616211], [77.85497284, 32.82118988], [77.85254669, 32.82518005], [77.84760284, 32.8284111], [77.83138275, 32.83504105], [77.8250885, 32.83987045], [77.81881714, 32.83853149], [77.8143158, 32.8361702], [77.80821228, 32.8360405], [77.79899597, 32.84584045], [77.79187775, 32.84926987], [77.78774261, 32.84976196], [77.78087616, 32.85409927], [77.77578735, 32.854702], [77.76772308, 32.85847092], [77.76142883, 32.86483002], [77.76597595, 32.88029099], [77.77274323, 32.8909111], [77.7869873, 32.8916893], [77.79250336, 32.89807892], [77.79016876, 32.90542984], [77.78174591, 32.91003036], [77.7780304, 32.91577911], [77.75956726, 32.92741013], [77.75099182, 32.93603134], [77.74762726, 32.93941879], [77.74745941, 32.9405098], [77.74717712, 32.94221115], [77.74478912, 32.94586945], [77.73895264, 32.94726944], [77.73641968, 32.94787216], [77.73412323, 32.9503212], [77.7273407, 32.95755005], [77.7231369, 32.96435928], [77.71248627, 32.97180176], [77.70832825, 32.96731949], [77.70368958, 32.9661293], [77.69988251, 32.96903992], [77.69670868, 32.97335052], [77.69500732, 32.97782135], [77.69087219, 32.97941971], [77.67948914, 32.97777939], [77.6780014, 32.98072052], [77.67086029, 32.9862709], [77.66520691, 32.98603058], [77.66307831, 32.97592926], [77.6599884, 32.96895981], [77.65637207, 32.96596146], [77.65331268, 32.95940018], [77.64987946, 32.9582901], [77.64334869, 32.95785141], [77.6384964, 32.95613861], [77.62336731, 32.94454193], [77.61725616, 32.94400024], [77.61296082, 32.94141006], [77.61071014, 32.94231033], [77.60614777, 32.94240952], [77.59343719, 32.94153976], [77.58637238, 32.93989944], [77.58392334, 32.94380188], [77.58152771, 32.93923187], [77.58096313, 32.93450165], [77.57966614, 32.93167877], [77.56964874, 32.92166138], [77.55384827, 32.91310883], [77.54949188, 32.9133606], [77.54471588, 32.91173172], [77.53531647, 32.90229034], [77.52700043, 32.89228058], [77.52320099, 32.88978195], [77.51956177, 32.88737869], [77.5112915, 32.88542938], [77.50623322, 32.8830719], [77.49434662, 32.88151169], [77.48455048, 32.88653946], [77.47318268, 32.87879181], [77.45522308, 32.86174011], [77.448349, 32.86167908], [77.43617249, 32.8658905], [77.43224335, 32.87044907], [77.43122101, 32.87582016], [77.42572021, 32.88367081], [77.4177475, 32.87921143], [77.41013336, 32.8782196], [77.40312195, 32.88145065], [77.39917755, 32.88393021], [77.39733124, 32.88698959], [77.39541626, 32.8873291], [77.38746643, 32.88552094], [77.3793869, 32.88082886], [77.37124634, 32.8674202], [77.36306763, 32.86352921], [77.35968018, 32.85958099], [77.35871887, 32.85639954], [77.35980988, 32.85161972], [77.3626709, 32.84659958], [77.36184692, 32.84260941], [77.35955048, 32.83816147], [77.35647583, 32.82527161], [77.3483963, 32.82120132], [77.34046173, 32.82054138], [77.33596039, 32.81890869], [77.32789612, 32.81988144], [77.32161713, 32.82239151], [77.32065582, 32.82810211], [77.31651306, 32.82975006], [77.31086731, 32.83766937], [77.3125, 32.84630966], [77.30516052, 32.85404968], [77.29795837, 32.85401154], [77.28874207, 32.85261917], [77.28128052, 32.85565186], [77.27433777, 32.85976028], [77.27009583, 32.86640167], [77.25831604, 32.87636185], [77.24758148, 32.8649292], [77.23887634, 32.8651619], [77.23802948, 32.86901093], [77.23626709, 32.87229919], [77.22782898, 32.8769722], [77.224823, 32.88002014], [77.22408295, 32.88270187], [77.22746277, 32.88393021], [77.22930145, 32.88679886], [77.22825623, 32.89556885], [77.21798706, 32.89731216], [77.20453644, 32.90637207], [77.18895721, 32.91006088], [77.18180084, 32.91545105], [77.17385864, 32.93112946], [77.1665802, 32.92805099], [77.16372681, 32.92510986], [77.16156769, 32.92111969], [77.16043091, 32.91608047], [77.15743256, 32.91323853], [77.14618683, 32.91402054], [77.15072632, 32.92023087], [77.14694977, 32.93437958], [77.14855194, 32.93791199], [77.14878082, 32.94137955], [77.14611053, 32.94277191], [77.14612579, 32.95639038], [77.13638306, 32.9577713], [77.13527679, 32.96094131], [77.13553619, 32.96467972], [77.13430786, 32.96949005], [77.13585663, 32.97444916], [77.13639069, 32.98046112], [77.12750244, 32.98384094], [77.12007141, 32.98271179], [77.11238098, 32.98413086], [77.10315704, 32.98720169], [77.09712219, 32.97758102], [77.08418274, 32.97367096], [77.07489777, 32.97335052], [77.07167053, 32.97623062], [77.06593323, 32.98553085], [77.05847168, 32.98608017], [77.05237579, 32.9908905], [77.03531647, 32.99967957], [77.02442169, 32.99695969], [77.01992035, 32.99174881], [77.0112381, 32.99324036], [76.99846649, 32.98957062], [76.99401855, 32.9922905], [76.99147034, 32.99285889], [76.98693848, 32.99592209], [76.98082733, 33.00146103], [76.96652222, 33.00720978], [76.96370697, 33.01004028], [76.96212769, 33.01393127], [76.95677948, 33.01673889], [76.94832611, 33.01848984], [76.93266296, 33.02845001], [76.92414856, 33.02896881], [76.91751099, 33.03367996], [76.91461182, 33.03882217], [76.91332245, 33.04420853], [76.9102478, 33.05020905], [76.90011597, 33.06414032], [76.89694214, 33.07099152], [76.89639282, 33.07580948], [76.89074707, 33.08076096], [76.89093018, 33.08459854], [76.89498901, 33.09141922], [76.89431, 33.09513855], [76.88477325, 33.09743881], [76.87741852, 33.1072197], [76.87719727, 33.11423874], [76.86869049, 33.12022018], [76.86044312, 33.11637878], [76.85256958, 33.11154938], [76.84443665, 33.11230087], [76.8391571, 33.11529922], [76.83410645, 33.12055969], [76.83740234, 33.12638855], [76.82808685, 33.13167953], [76.82917023, 33.13772202], [76.82296753, 33.14128876], [76.81725311, 33.14200211], [76.81495667, 33.14617157], [76.80948639, 33.14855194], [76.80345917, 33.15568924], [76.80143738, 33.16154099], [76.80201721, 33.16603088], [76.799263, 33.1694603], [76.79812622, 33.1733017], [76.80042267, 33.17779922], [76.80517578, 33.18225861], [76.80661011, 33.18473053], [76.80330658, 33.19385147], [76.81858826, 33.20557022], [76.81716156, 33.21223068], [76.81108093, 33.21546173], [76.81304932, 33.2227211], [76.81785583, 33.23114014], [76.82319641, 33.23738098], [76.82887268, 33.2425499], [76.82834625, 33.24639893], [76.82717133, 33.24674988], [76.82354736, 33.24785995], [76.8219223, 33.24835205], [76.817276, 33.24850082], [76.81394196, 33.24744034], [76.80916595, 33.24430084], [76.80845642, 33.24232101], [76.8062973, 33.23622894], [76.80275726, 33.23666], [76.79693604, 33.24121094], [76.78543854, 33.25358963], [76.77826691, 33.2557106], [76.76355743, 33.25432968], [76.75997162, 33.25297928], [76.75688171, 33.25054169], [76.75534058, 33.24948883], [76.75520325, 33.24740982], [76.75756836, 33.2431221], [76.76235962, 33.2395401], [76.75988007, 33.22467041], [76.75605011, 33.21982193], [76.75055695, 33.21012878], [76.74558258, 33.20434952], [76.74212646, 33.19749069], [76.73435211, 33.19311905], [76.73060608, 33.18527985], [76.72986603, 33.17943192], [76.71418762, 33.17744064], [76.70847321, 33.18130112], [76.69671631, 33.18148041], [76.69365692, 33.17760086], [76.68527222, 33.17404175], [76.66947937, 33.17332077], [76.66055298, 33.17134857], [76.65944672, 33.17111206], [76.65873718, 33.17116928], [76.65110779, 33.17182922], [76.64074707, 33.16468048], [76.62700653, 33.1624794], [76.61255646, 33.16596985], [76.59958649, 33.17375946], [76.5984726, 33.17650986], [76.59886169, 33.18391037], [76.59732819, 33.18803024], [76.59253693, 33.19063187], [76.58799744, 33.18999863], [76.58403778, 33.19306946], [76.58470154, 33.19956207], [76.58618927, 33.20421982], [76.58190155, 33.20687103], [76.57673645, 33.2057991], [76.56761932, 33.20705032], [76.56295013, 33.20618057], [76.55589294, 33.20685196], [76.54747772, 33.20952988], [76.54196167, 33.20677185], [76.53417969, 33.19934845], [76.52023315, 33.20040894], [76.50576019, 33.19578171], [76.4988327, 33.19668961], [76.49597168, 33.19602966], [76.48877716, 33.19015884], [76.46906281, 33.17990875], [76.46614075, 33.17988205], [76.45555115, 33.18331909], [76.45020294, 33.18291855], [76.44181061, 33.18046951], [76.42977142, 33.18281174], [76.42177582, 33.18180847], [76.40769196, 33.18841934], [76.40067291, 33.18656158], [76.39167786, 33.18669128], [76.38455963, 33.18289185], [76.37985229, 33.17646027], [76.37351227, 33.17346191], [76.36615753, 33.16804123], [76.36080933, 33.16275024], [76.3588562, 33.15750122], [76.35578918, 33.15460205], [76.35212708, 33.15483856], [76.33558655, 33.14627075], [76.3155365, 33.13019943], [76.30692291, 33.12722015], [76.29194641, 33.12020874], [76.28800201, 33.11315918], [76.27500153, 33.10398865], [76.27687073, 33.10063171], [76.27584076, 33.09803009], [76.2712326, 33.09635925], [76.26751709, 33.08610916], [76.25524139, 33.05228043], [76.23728943, 33.03258896], [76.22978973, 33.03083038], [76.2294693, 33.03026199], [76.21615601, 33.02857208], [76.18830109, 33.02758026], [76.15223694, 33.02289963], [76.14389038, 33.01647949], [76.12819672, 33.01008224], [76.12049103, 33.01042175], [76.1159668, 33.0085907], [76.10732269, 33.00788879], [76.09368896, 33.00482941], [76.09455872, 33.00032043], [76.09123993, 32.99275208], [76.08567047, 32.97500992], [76.08220673, 32.96879959], [76.07834625, 32.96607208], [76.06999969, 32.96221924], [76.06587982, 32.95798111], [76.05446625, 32.9509697], [76.05039978, 32.94427109], [76.04260254, 32.94023895], [76.02807617, 32.93743896], [76.02365112, 32.93157959], [76.02117157, 32.92443085], [76.01718903, 32.91764069], [76.01351166, 32.91593933], [76.00463104, 32.91400909], [75.99752808, 32.90937042], [75.98741913, 32.90058136], [75.98320007, 32.90040207], [75.94577026, 32.88513947], [75.93955231, 32.88422012], [75.93377686, 32.88431168], [75.92323303, 32.89809036], [75.91356659, 32.90621185], [75.90011597, 32.91569901], [75.88089752, 32.92477036], [75.86711884, 32.93021011], [75.85006714, 32.93115997], [75.83389282, 32.93460083], [75.82811737, 32.93408203], [75.82142639, 32.93347168], [75.80795288, 32.9297905], [75.80332184, 32.92354965], [75.79830933, 32.91942215], [75.80175781, 32.91027069], [75.80000305, 32.90391922], [75.7983551, 32.90216446], [75.79380798, 32.89731216], [75.78987885, 32.89398193], [75.78742218, 32.89332199]]]}}, {\\\"id\\\": \\\"13\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.15_1\\\", \\\"HASC_1\\\": \\\"IN.JH\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Jharkhand\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Vananchal\\\", \\\"apm25_popweighted\\\": -45.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 796.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1833.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1037.0, \\\"geo-id\\\": 13, \\\"hpm25_child_popweighted\\\": -224.8, \\\"hpm25_female_popweighted\\\": -258.4, \\\"hpm25_male_popweighted\\\": -186.0, \\\"location\\\": \\\"Jharkhand\\\", \\\"mort_apm25_6cod_mean_total\\\": 8873.0, \\\"mort_hpm25_6cod_mean_total\\\": -21325.0, \\\"mort_tpm25_6cod_mean_total\\\": -12452.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[86.72278595, 22.21524811], [86.72097015, 22.21684074], [86.71147156, 22.21772003], [86.69178772, 22.2173996], [86.68216705, 22.21951103], [86.67399597, 22.22496986], [86.66995239, 22.23010063], [86.66989136, 22.2368412], [86.66514587, 22.23855972], [86.66269684, 22.23748016], [86.66034698, 22.2342205], [86.65114594, 22.23320007], [86.6481781, 22.23569107], [86.64729309, 22.24969292], [86.64833832, 22.25323105], [86.64589691, 22.25728035], [86.64557648, 22.26136971], [86.64227295, 22.26184273], [86.64137268, 22.26419258], [86.63761902, 22.26309013], [86.63729095, 22.26620293], [86.63465881, 22.26914978], [86.63025665, 22.26902962], [86.62715149, 22.26683044], [86.61605835, 22.27600288], [86.60851288, 22.27876091], [86.60263062, 22.27843285], [86.59845734, 22.27437973], [86.59092712, 22.27483177], [86.58992767, 22.28214073], [86.58561707, 22.28663063], [86.58560181, 22.29088974], [86.58217621, 22.29101944], [86.58130646, 22.29491806], [86.57846069, 22.29781914], [86.5752182, 22.2963295], [86.57433319, 22.29393959], [86.57068634, 22.29294968], [86.56771088, 22.29700279], [86.561203, 22.29701042], [86.55206299, 22.29528999], [86.54573822, 22.29892921], [86.53988647, 22.30373001], [86.53237915, 22.29819107], [86.52455139, 22.30285072], [86.52320099, 22.30783844], [86.52083588, 22.31148911], [86.52509308, 22.3123703], [86.52365112, 22.31857109], [86.51957703, 22.32057953], [86.50798798, 22.32402039], [86.50125885, 22.33146095], [86.49994659, 22.34095192], [86.48371887, 22.34441948], [86.48171234, 22.34201813], [86.47853088, 22.33446121], [86.47457886, 22.33422089], [86.46842194, 22.33228111], [86.4670105, 22.32891083], [86.46395874, 22.32699966], [86.46026611, 22.32641983], [86.45823669, 22.32211113], [86.44954681, 22.3230629], [86.44181824, 22.32534027], [86.43839264, 22.32336807], [86.43881226, 22.31645966], [86.44019318, 22.3114109], [86.4393158, 22.30578041], [86.43335724, 22.30154037], [86.42437744, 22.3062706], [86.42469788, 22.30920982], [86.42169189, 22.31389046], [86.41137695, 22.31555939], [86.40130615, 22.31941032], [86.39060974, 22.32528114], [86.37552643, 22.33711815], [86.36303711, 22.33960915], [86.35273743, 22.34542084], [86.35266113, 22.35153008], [86.34736633, 22.35900116], [86.33931732, 22.36605072], [86.32534027, 22.37308121], [86.31986237, 22.38035965], [86.31770325, 22.39059067], [86.30979919, 22.39726067], [86.30223846, 22.40520287], [86.30065155, 22.41531944], [86.29292297, 22.42014122], [86.28795624, 22.42536163], [86.2798233, 22.4455204], [86.27137756, 22.44282913], [86.2651825, 22.43954086], [86.25956726, 22.44127083], [86.2425766, 22.44453049], [86.22849274, 22.44958115], [86.22103119, 22.45059967], [86.22038269, 22.44909096], [86.21150208, 22.45971107], [86.21694946, 22.46403122], [86.21820831, 22.46821022], [86.2175827, 22.46824837], [86.21653748, 22.46504974], [86.20913696, 22.46284103], [86.20239258, 22.47027969], [86.19668579, 22.46774101], [86.17370605, 22.47643089], [86.16602325, 22.47674751], [86.1555481, 22.4790802], [86.14514923, 22.47513962], [86.1462326, 22.47914124], [86.11992645, 22.48555946], [86.11192322, 22.48293114], [86.10733032, 22.48489761], [86.10137939, 22.49015045], [86.0981369, 22.49563026], [86.09350586, 22.50822067], [86.09155273, 22.50915909], [86.07834625, 22.53041077], [86.06920624, 22.54306984], [86.06182861, 22.5485096], [86.05813599, 22.55342102], [86.0533905, 22.55465126], [86.04664612, 22.55788994], [86.0384903, 22.5635891], [86.01834106, 22.5436306], [86.02826691, 22.53433037], [86.02202606, 22.52054977], [86.01544952, 22.52448082], [86.00868225, 22.51855087], [86.00179291, 22.51486015], [85.9998703, 22.51497269], [85.99591827, 22.50896263], [85.99297333, 22.50892067], [85.98413849, 22.51062012], [85.98071289, 22.50974083], [85.96924591, 22.49978065], [85.96637726, 22.49381065], [85.96560669, 22.4901619], [85.9670105, 22.48601151], [85.9667511, 22.48216057], [85.96079254, 22.47861862], [85.95813751, 22.47618103], [85.9593277, 22.47038078], [85.95826721, 22.46590042], [85.95350647, 22.45597267], [85.96140289, 22.45269966], [85.96311188, 22.44512177], [85.96697998, 22.44122124], [85.98213196, 22.42898941], [85.99297333, 22.42214012], [85.99685669, 22.4216404], [86.00002289, 22.42264748], [86.00283813, 22.42506027], [86.0059967, 22.42536163], [86.00874329, 22.42432022], [86.00974274, 22.42165947], [86.00961304, 22.41889], [86.01204681, 22.41473007], [86.01365662, 22.40388107], [86.01226807, 22.39899063], [86.01477814, 22.39705086], [86.01574707, 22.39334106], [86.01802063, 22.39324188], [86.01906586, 22.39066124], [86.0175705, 22.38612175], [86.02050781, 22.38420105], [86.02149963, 22.38176155], [86.0196228, 22.37815094], [86.02124786, 22.37504005], [86.01891327, 22.37475967], [86.01841736, 22.37153053], [86.01596832, 22.37297058], [86.01526642, 22.36600113], [86.01686096, 22.3622303], [86.0061264, 22.34875107], [85.99288177, 22.33815956], [85.99582672, 22.33311844], [85.99842834, 22.33107948], [86.00476074, 22.33564949], [86.01399994, 22.33450127], [86.02043152, 22.32939911], [86.01918793, 22.32713127], [86.01328278, 22.32396126], [86.00589752, 22.31591034], [86.008461, 22.31324005], [86.00842285, 22.30995941], [86.01117706, 22.31056976], [86.01139832, 22.30939102], [86.01777649, 22.30455017], [86.02040863, 22.30554008], [86.02471924, 22.30417061], [86.02816772, 22.30768967], [86.03230286, 22.30523109], [86.03407288, 22.30793953], [86.03930664, 22.30865097], [86.04225922, 22.30824089], [86.04328918, 22.30619049], [86.03996277, 22.30355072], [86.03031921, 22.30298805], [86.0293808, 22.30076027], [86.02732086, 22.29949951], [86.02339172, 22.29767036], [86.0197525, 22.29781914], [86.01605988, 22.29652977], [86.00849915, 22.2926712], [86.00023651, 22.28437042], [86.00222015, 22.28146172], [86.00074005, 22.27933121], [85.99752808, 22.27534103], [85.99304199, 22.2732811], [85.98519135, 22.2672081], [85.98544312, 22.25745964], [85.98181152, 22.2520504], [85.9697876, 22.24340057], [85.97135925, 22.23838043], [85.97779083, 22.23554993], [85.98513031, 22.22384262], [85.992836, 22.21548271], [86.01738739, 22.19876289], [86.0255661, 22.18921089], [86.02671814, 22.18522263], [86.01477814, 22.17264175], [86.01257324, 22.16785812], [86.01312256, 22.16361046], [86.01140594, 22.15765953], [86.00385284, 22.15105057], [85.99923706, 22.14492989], [85.99968719, 22.14240074], [85.99909973, 22.13710976], [85.99462891, 22.13178062], [85.99508667, 22.12356949], [85.99608612, 22.12065125], [86.00258636, 22.11302185], [86.00047302, 22.10897064], [85.99259949, 22.10025024], [85.98919678, 22.09345055], [85.97899628, 22.08336067], [85.97731781, 22.08003998], [85.97738647, 22.07673836], [85.97528839, 22.0717907], [85.97122955, 22.06682014], [85.96737671, 22.05978012], [85.96331024, 22.0544281], [85.95797729, 22.04251099], [85.95358276, 22.03610039], [85.95153809, 22.0316391], [85.94470978, 22.02326965], [85.94258118, 22.01913071], [85.93856049, 22.01662064], [85.93309021, 22.0174408], [85.92877197, 22.01935959], [85.92488861, 22.01735115], [85.92340088, 22.01407814], [85.91954041, 22.00979042], [85.91223907, 22.0048008], [85.91306305, 21.9966507], [85.90924835, 21.99012947], [85.90725708, 21.98130989], [85.90966797, 21.97758102], [85.90921021, 21.97554016], [85.90445709, 21.9726696], [85.90599823, 21.96809006], [85.90542603, 21.96663094], [85.90284729, 21.96659088], [85.89417267, 21.97829056], [85.89115143, 21.97851944], [85.88613129, 21.97542], [85.88175201, 21.97483063], [85.87132263, 21.97475052], [85.8469696, 21.97707939], [85.84041595, 21.97648048], [85.82859802, 21.97294044], [85.82227325, 21.97013092], [85.81832886, 21.97001076], [85.81558228, 21.97130013], [85.81606293, 21.9753418], [85.81539154, 21.98013115], [85.81265259, 21.98096085], [85.80515289, 21.98022079], [85.80097961, 21.98166084], [85.78427887, 21.97859955], [85.78218842, 21.9793911], [85.78050232, 21.98104095], [85.77140045, 21.98371124], [85.76074982, 21.98971939], [85.76052094, 21.99694061], [85.7561264, 22.00839043], [85.75869751, 22.01480293], [85.76184845, 22.01794052], [85.77217102, 22.02470016], [85.77559662, 22.02827072], [85.77893829, 22.0362606], [85.77330017, 22.04330826], [85.7712326, 22.04714966], [85.77033234, 22.05128288], [85.78511047, 22.07191086], [85.78794098, 22.0771904], [85.79676056, 22.07450104], [85.80272675, 22.07176018], [85.8143692, 22.07007027], [85.83075714, 22.07697105], [85.82808685, 22.08266068], [85.82491302, 22.08712959], [85.8189621, 22.08963013], [85.81542206, 22.09282112], [85.80870819, 22.09184074], [85.81521606, 22.09902], [85.81474304, 22.10211182], [85.80204773, 22.11083031], [85.79718018, 22.10630035], [85.79397583, 22.10536957], [85.79091644, 22.10038948], [85.78425598, 22.09898758], [85.77903748, 22.09342003], [85.77339172, 22.09024048], [85.76502228, 22.08820915], [85.75782013, 22.08498192], [85.75213623, 22.0792408], [85.7504425, 22.07439041], [85.74606323, 22.06987953], [85.73381805, 22.06452942], [85.72235107, 22.05813026], [85.71755981, 22.05772972], [85.71277618, 22.0564003], [85.70780182, 22.05628967], [85.70465088, 22.05433083], [85.69600677, 22.0568409], [85.68788147, 22.05607986], [85.6815033, 22.04878044], [85.67195129, 22.05147171], [85.67236328, 22.05972099], [85.66757202, 22.06102943], [85.66472626, 22.06657028], [85.65750885, 22.07427979], [85.65532684, 22.07781029], [85.65033722, 22.08130074], [85.64805603, 22.08681107], [85.64460754, 22.09028053], [85.6400528, 22.09023285], [85.63639069, 22.08576965], [85.63124847, 22.08154106], [85.62623596, 22.0796299], [85.61958313, 22.07784081], [85.61110687, 22.07679939], [85.6085968, 22.07895088], [85.60732269, 22.08179092], [85.60359955, 22.0792408], [85.60176086, 22.07634163], [85.59664917, 22.07472038], [85.59108734, 22.07444], [85.5867691, 22.07681847], [85.58223724, 22.08098984], [85.57110596, 22.08605957], [85.56623077, 22.08703995], [85.56022644, 22.08490944], [85.55433655, 22.09082031], [85.54862213, 22.08855057], [85.53954315, 22.08658981], [85.53734589, 22.09029961], [85.53604889, 22.09440994], [85.53350067, 22.09679985], [85.52873993, 22.0987606], [85.52416992, 22.10305023], [85.5148468, 22.10820961], [85.50567627, 22.11145973], [85.4858017, 22.11648941], [85.47940063, 22.12177086], [85.47173309, 22.12413979], [85.46517944, 22.1312027], [85.45700836, 22.1357708], [85.43578339, 22.14417076], [85.41781616, 22.15335846], [85.41028595, 22.15608025], [85.40236664, 22.15653038], [85.3944397, 22.15859985], [85.39035034, 22.15513039], [85.38536835, 22.15234184], [85.37931824, 22.15168953], [85.37217712, 22.15244102], [85.36937714, 22.15521049], [85.36319733, 22.15456963], [85.36242676, 22.15004921], [85.36292267, 22.14657974], [85.35807037, 22.1379509], [85.35865784, 22.13280106], [85.36171722, 22.12475967], [85.36138153, 22.12144089], [85.35813141, 22.1196003], [85.35356903, 22.12057114], [85.34536743, 22.12699127], [85.33850098, 22.12471962], [85.32301331, 22.12499046], [85.31536865, 22.11584091], [85.30970001, 22.11338997], [85.30007935, 22.10705948], [85.28742218, 22.0931797], [85.28089905, 22.08764076], [85.27416229, 22.08008957], [85.26995087, 22.06896019], [85.26545715, 22.06025124], [85.25998688, 22.05285263], [85.25609589, 22.04245949], [85.24652863, 22.0254097], [85.24105835, 22.01251984], [85.23094177, 22.00027084], [85.22212982, 22.00344849], [85.21835327, 22.00667], [85.21488953, 22.01071167], [85.21383667, 22.01628113], [85.21389771, 22.02716064], [85.21460724, 22.03728104], [85.21074677, 22.04318047], [85.19232178, 22.05115128], [85.18699646, 22.05273056], [85.18345642, 22.05492973], [85.17913055, 22.06479073], [85.17675018, 22.06671906], [85.17246246, 22.06818962], [85.16960907, 22.06609917], [85.16436768, 22.06522942], [85.16983032, 22.05310059], [85.17080688, 22.04819107], [85.16720581, 22.0486908], [85.16374969, 22.0529995], [85.15896606, 22.06192017], [85.1578064, 22.06698036], [85.1555481, 22.07045937], [85.14891052, 22.07263947], [85.14083862, 22.07355118], [85.13506317, 22.07114029], [85.12539673, 22.06912041], [85.11888123, 22.0664711], [85.11329651, 22.07107925], [85.1102829, 22.07586288], [85.10897064, 22.0800209], [85.10447693, 22.08278084], [85.09970856, 22.08453941], [85.09900665, 22.09612083], [85.0954361, 22.09945107], [85.08409882, 22.10043907], [85.07623291, 22.10297012], [85.06945038, 22.10712814], [85.04389954, 22.11070061], [85.03513336, 22.1081295], [85.03118134, 22.10247993], [85.0271225, 22.10113907], [85.01995087, 22.10337067], [85.0140686, 22.09370995], [85.00901794, 22.09065056], [85.00720215, 22.08312988], [85.00231934, 22.0799427], [84.99359894, 22.07720947], [84.98742676, 22.07673836], [84.98104095, 22.08242035], [84.97982025, 22.08468056], [84.98049927, 22.09126091], [84.9834671, 22.09148979], [84.98586273, 22.09256935], [84.99362946, 22.09794807], [85.0194931, 22.10839081], [85.02374268, 22.11199188], [85.02429199, 22.11794281], [85.02735138, 22.1225605], [85.03115082, 22.13735962], [85.03031158, 22.14246178], [85.02619934, 22.14845085], [85.02539825, 22.15400124], [85.02802277, 22.15735817], [85.03322601, 22.1608429], [85.0414505, 22.17066002], [85.04779053, 22.17429924], [85.04960632, 22.17930984], [85.04692078, 22.18579292], [85.05879974, 22.20595169], [85.06253815, 22.21615982], [85.0694809, 22.23064995], [85.0681076, 22.24344063], [85.07206726, 22.24571991], [85.07431793, 22.25094032], [85.06990051, 22.26029015], [85.06941986, 22.26758194], [85.07051086, 22.27215958], [85.08235168, 22.27770805], [85.09857178, 22.28792], [85.10529327, 22.2911396], [85.10836029, 22.28947258], [85.11445618, 22.2904892], [85.11483765, 22.30038071], [85.11218262, 22.30507088], [85.11403656, 22.3142128], [85.10772705, 22.31523132], [85.10122681, 22.31432915], [85.09512329, 22.31239128], [85.08795929, 22.31408119], [85.08590698, 22.31698036], [85.09046173, 22.32487106], [85.09295654, 22.34109116], [85.08216095, 22.34132957], [85.07990265, 22.34439087], [85.07405853, 22.34859085], [85.07549286, 22.35577965], [85.07504272, 22.36096954], [85.07788086, 22.3691597], [85.08307648, 22.37844086], [85.08068085, 22.39546013], [85.07720184, 22.4030304], [85.07726288, 22.40830994], [85.07459259, 22.41345978], [85.06809235, 22.41806984], [85.06369019, 22.42322159], [85.06289673, 22.43608284], [85.05815125, 22.4397316], [85.05703735, 22.44470978], [85.06048584, 22.44951057], [85.07110596, 22.45590019], [85.07093811, 22.46116066], [85.07363892, 22.46668053], [85.07319641, 22.47286987], [85.06249237, 22.47841072], [85.05139923, 22.47941971], [85.04672241, 22.47739029], [85.04223633, 22.47694016], [85.03733063, 22.47508049], [85.03544617, 22.47729111], [85.03330994, 22.47692108], [85.03156281, 22.46978188], [85.02810669, 22.46820259], [85.02157593, 22.46710968], [85.00049591, 22.45836067], [84.994133, 22.45827103], [84.97779083, 22.45092964], [84.96024323, 22.44371986], [84.95728302, 22.44185829], [84.95458221, 22.4389019], [84.95243835, 22.43944931], [84.95336151, 22.4455204], [84.95244598, 22.45277023], [84.94728088, 22.45108032], [84.94077301, 22.44742966], [84.93136597, 22.43964958], [84.92533875, 22.43660927], [84.91739655, 22.43437958], [84.91815186, 22.42856979], [84.91986847, 22.42599106], [84.91639709, 22.4233799], [84.90770721, 22.41963959], [84.89379883, 22.41801071], [84.88024902, 22.41759109], [84.88198853, 22.42624855], [84.88150024, 22.42943954], [84.87947083, 22.43219948], [84.87779999, 22.4425106], [84.87652588, 22.44325066], [84.87525177, 22.44117928], [84.87124634, 22.43822289], [84.86371613, 22.43453026], [84.85534668, 22.43197823], [84.84780121, 22.43441963], [84.84136963, 22.43486977], [84.83946991, 22.43403053], [84.83574677, 22.42755127], [84.83254242, 22.42637825], [84.83162689, 22.4299202], [84.82842255, 22.42917061], [84.81269073, 22.43161011], [84.81047821, 22.43522835], [84.81047058, 22.44125175], [84.80779266, 22.44686127], [84.80124664, 22.44371033], [84.79128265, 22.4428196], [84.77805328, 22.44354057], [84.75269318, 22.44201279], [84.74385071, 22.41475105], [84.72614288, 22.41664124], [84.7113266, 22.41390038], [84.69149017, 22.41251183], [84.6815033, 22.41492081], [84.67282104, 22.41493034], [84.66934967, 22.41629982], [84.66160583, 22.41391945], [84.63210297, 22.4286499], [84.6255188, 22.42758942], [84.61364746, 22.42757988], [84.5953064, 22.4249382], [84.59395599, 22.42884064], [84.58907318, 22.42537117], [84.57215881, 22.42301178], [84.54329681, 22.41719818], [84.54065704, 22.42058945], [84.52662659, 22.42002106], [84.52101135, 22.41489029], [84.50582886, 22.41620064], [84.50179291, 22.41531944], [84.48126984, 22.40569115], [84.47666931, 22.40598106], [84.47447968, 22.40173149], [84.47595978, 22.39353943], [84.47572327, 22.39018822], [84.48020935, 22.38723946], [84.47759247, 22.38368034], [84.47280884, 22.38269043], [84.45565033, 22.37522125], [84.44785309, 22.37907982], [84.44207764, 22.37302017], [84.42694092, 22.36465073], [84.42719269, 22.36198044], [84.43144226, 22.36001015], [84.42584229, 22.3520298], [84.42608643, 22.3488102], [84.41911316, 22.35077095], [84.3944931, 22.34385109], [84.38786316, 22.34642029], [84.37758636, 22.34590912], [84.37200165, 22.34905052], [84.36741638, 22.34956932], [84.36171722, 22.34852982], [84.35909271, 22.34504128], [84.35328674, 22.34510994], [84.34496307, 22.34404945], [84.33838654, 22.34209824], [84.333992, 22.34291077], [84.32396698, 22.33892059], [84.31874847, 22.34049988], [84.31461334, 22.33892059], [84.28922272, 22.33732033], [84.28501892, 22.34211159], [84.27324677, 22.34509277], [84.26616669, 22.34782982], [84.26088715, 22.35370064], [84.25141144, 22.37041092], [84.24655914, 22.3737011], [84.24046326, 22.3744812], [84.22612762, 22.37412071], [84.19410706, 22.37181091], [84.18344116, 22.38368034], [84.17516327, 22.38894081], [84.15248871, 22.4009304], [84.14229584, 22.41539955], [84.13587952, 22.42068291], [84.13310242, 22.44531059], [84.13522339, 22.4490509], [84.13751984, 22.45718956], [84.13743591, 22.46710014], [84.13492584, 22.47094917], [84.13069153, 22.47001076], [84.12914276, 22.47348976], [84.12557983, 22.47359276], [84.117836, 22.47142029], [84.10611725, 22.47384834], [84.10211945, 22.47731018], [84.10347748, 22.47933006], [84.1029129, 22.48129082], [84.0998764, 22.48033905], [84.0877533, 22.48493004], [84.07920837, 22.48885155], [84.07164001, 22.49419022], [84.0670929, 22.49812126], [84.06900024, 22.49954987], [84.06668854, 22.50223923], [84.06047821, 22.50502014], [84.05758667, 22.51015091], [84.05065918, 22.51235962], [84.0330658, 22.5120697], [84.02472687, 22.51621246], [84.01914978, 22.52107048], [84.01554108, 22.52168083], [84.00963593, 22.52029037], [84.00250244, 22.52086067], [84.00518036, 22.52473068], [84.00489807, 22.53013039], [84.00157928, 22.53399086], [83.99944305, 22.53950119], [84.00212097, 22.54659843], [84.00417328, 22.55486107], [84.00392914, 22.56192017], [84.00505066, 22.56956291], [84.01103973, 22.57500267], [84.01777649, 22.5789299], [84.02002716, 22.58279037], [84.02134705, 22.58723259], [84.03359222, 22.59127045], [84.04193115, 22.59218025], [84.04812622, 22.59414291], [84.05287933, 22.60260963], [84.05930328, 22.6074028], [84.08039093, 22.6365509], [84.09395599, 22.63264084], [84.09764099, 22.63301086], [84.1072464, 22.63667107], [84.11531067, 22.63525963], [84.13210297, 22.63578033], [84.14993286, 22.63442039], [84.15743256, 22.64093971], [84.16483307, 22.64532089], [84.18035126, 22.6498394], [84.19161987, 22.66025162], [84.1969986, 22.66378021], [84.20160675, 22.66518974], [84.20717621, 22.66506004], [84.20967102, 22.6629982], [84.21479034, 22.66456032], [84.22061157, 22.66891098], [84.22775269, 22.67699051], [84.23223877, 22.68857956], [84.22769165, 22.6979599], [84.22944641, 22.70523262], [84.22763062, 22.72315025], [84.22471619, 22.72735023], [84.22535706, 22.73516083], [84.2297287, 22.74015045], [84.2416687, 22.74835014], [84.25158691, 22.75807953], [84.25370789, 22.76072121], [84.25422668, 22.76297951], [84.26010132, 22.76494026], [84.27403259, 22.76559067], [84.27877808, 22.76136017], [84.28144836, 22.76011086], [84.28528595, 22.76337051], [84.28768921, 22.77090073], [84.28710938, 22.77671051], [84.29030609, 22.78716278], [84.29627991, 22.79363823], [84.30181885, 22.79507065], [84.3034668, 22.79846954], [84.30996704, 22.79898262], [84.31169128, 22.80330086], [84.31252289, 22.81035042], [84.31770325, 22.81718063], [84.32038116, 22.83603096], [84.31858826, 22.83513069], [84.31839752, 22.84375191], [84.3203125, 22.84942055], [84.32946014, 22.85955048], [84.33500671, 22.86024094], [84.33835602, 22.85904121], [84.34217834, 22.85917091], [84.34789276, 22.86316109], [84.35793304, 22.86059952], [84.36988831, 22.86450005], [84.36995697, 22.86890984], [84.37145996, 22.87212944], [84.3759613, 22.87363815], [84.37692261, 22.87589073], [84.37587738, 22.88140106], [84.37818909, 22.88786125], [84.37825775, 22.8931427], [84.37670898, 22.89772987], [84.37278748, 22.8984108], [84.37085724, 22.90160942], [84.37619019, 22.90920067], [84.38629913, 22.9168396], [84.38964844, 22.92374039], [84.38905334, 22.93873978], [84.38645935, 22.94238091], [84.38195038, 22.94573021], [84.37922668, 22.94890022], [84.37779236, 22.95191765], [84.37773132, 22.96171951], [84.37638092, 22.96630287], [84.3733902, 22.97214127], [84.3705368, 22.97507095], [84.36149597, 22.97455025], [84.34823608, 22.97587013], [84.34361267, 22.97372055], [84.33181, 22.97913933], [84.32515717, 22.97933006], [84.3182373, 22.97657967], [84.31449127, 22.97223091], [84.3067627, 22.96751022], [84.28933716, 22.9616394], [84.27857208, 22.9612484], [84.27192688, 22.97093964], [84.26888275, 22.97903061], [84.27111053, 22.98415947], [84.27140045, 22.98884964], [84.26789093, 22.98791122], [84.2620697, 22.9800415], [84.25461578, 22.97369957], [84.2509079, 22.97142982], [84.24150848, 22.97287941], [84.2374115, 22.98040009], [84.22680664, 22.98007011], [84.21705627, 22.97647285], [84.21494293, 22.97743034], [84.21202087, 22.98638916], [84.20107269, 22.99882126], [84.1967926, 23.00410271], [84.19993591, 23.01511955], [84.19824982, 23.01898956], [84.18992615, 23.02371979], [84.17904663, 23.02256012], [84.17668152, 23.02051926], [84.17537689, 23.01190186], [84.17259979, 23.00720024], [84.17397308, 23.00035095], [84.17314911, 22.99875069], [84.16860199, 22.99500084], [84.17059326, 22.98518944], [84.1713562, 22.97707939], [84.16786194, 22.97096062], [84.15458679, 22.96437263], [84.14800262, 22.96386909], [84.14356995, 22.97511101], [84.14511108, 22.98257065], [84.14421082, 22.9881897], [84.13835907, 22.99848938], [84.13733673, 23.00626945], [84.13169861, 23.01826286], [84.12664795, 23.02601051], [84.1246109, 23.03074837], [84.12367249, 23.03661919], [84.12335968, 23.04499245], [84.12483215, 23.05347824], [84.12587738, 23.05688286], [84.13076782, 23.06336021], [84.13170624, 23.0674305], [84.13092041, 23.07748985], [84.12937927, 23.08154106], [84.12647247, 23.08514977], [84.11618805, 23.08613968], [84.11244965, 23.08718109], [84.11026001, 23.09208107], [84.10492706, 23.09922028], [84.09736633, 23.10482025], [84.08786774, 23.10948944], [84.07646179, 23.10984993], [84.06671143, 23.10711288], [84.0614624, 23.10989952], [84.05893707, 23.11259079], [84.05560303, 23.12070084], [84.0528717, 23.12446976], [84.04527283, 23.13052177], [84.03997803, 23.1321106], [84.03595734, 23.13495064], [84.03367615, 23.13844109], [84.03336334, 23.14273071], [84.03026581, 23.14936829], [84.02909088, 23.15388107], [84.03112793, 23.16113281], [84.03380585, 23.16784096], [84.03932953, 23.1785183], [84.04399109, 23.18460083], [84.05090332, 23.18958092], [84.05612183, 23.19640923], [84.05834961, 23.20359993], [84.05802917, 23.20800018], [84.0535965, 23.21317101], [84.05236816, 23.21643066], [84.05223846, 23.2212429], [84.05400848, 23.23418045], [84.05045319, 23.24094963], [84.05126953, 23.2466011], [84.05906677, 23.27412033], [84.05906677, 23.28232002], [84.06005859, 23.28628922], [84.06304169, 23.28964043], [84.06381989, 23.29224014], [84.05938721, 23.30430031], [84.05995178, 23.30820084], [84.07025146, 23.32999039], [84.06797028, 23.33409119], [84.06051636, 23.3431797], [84.04995728, 23.35186005], [84.04860687, 23.35416031], [84.04734039, 23.36365128], [84.04444885, 23.36712074], [84.04345703, 23.36972046], [84.04722595, 23.37121964], [84.04338837, 23.37401009], [84.03803253, 23.3761692], [84.02648163, 23.37692833], [84.02073669, 23.37545967], [84.01715088, 23.37158966], [84.01145172, 23.36339951], [84.00653076, 23.35280037], [83.99276733, 23.35588264], [83.98301697, 23.35955048], [83.97486115, 23.36479187], [83.97025299, 23.36939812], [83.96688843, 23.37422943], [83.96582794, 23.38121033], [83.96778107, 23.39299011], [83.97616577, 23.40752029], [83.97805786, 23.4141407], [83.97815704, 23.42093086], [83.97944641, 23.42669106], [83.97775269, 23.4314518], [83.96972656, 23.44766808], [83.9695282, 23.4554081], [83.97914886, 23.46058083], [83.98462677, 23.47559166], [83.98889923, 23.48178101], [83.99272156, 23.4851799], [83.99724579, 23.49311066], [84.00563812, 23.49646187], [84.00875854, 23.49958038], [84.01228333, 23.5081501], [84.01274872, 23.52081108], [84.01539612, 23.52563286], [84.02266693, 23.54424095], [84.02128601, 23.54992867], [84.02511597, 23.56579018], [84.02291107, 23.57459068], [84.02411652, 23.58788109], [84.02194214, 23.59221077], [84.02233887, 23.59736061], [84.02030182, 23.60017967], [84.01257324, 23.60548019], [84.0018692, 23.62043953], [84.00177765, 23.62290955], [84.0036087, 23.62631989], [84.00771332, 23.62852097], [84.00702667, 23.63231087], [83.99267578, 23.63305283], [83.97545624, 23.63083076], [83.962677, 23.62618828], [83.94861603, 23.62431908], [83.9378891, 23.6224308], [83.93152618, 23.6114006], [83.92958832, 23.59367943], [83.93525696, 23.56303978], [83.92249298, 23.56504822], [83.91467285, 23.56874084], [83.9052887, 23.56950951], [83.89849091, 23.57116127], [83.89009094, 23.5759201], [83.88292694, 23.57277107], [83.85959625, 23.5783329], [83.84616089, 23.58092117], [83.83763123, 23.58135986], [83.8212204, 23.58485031], [83.81088257, 23.58885956], [83.80634308, 23.58230972], [83.80047607, 23.58317947], [83.79772186, 23.5900898], [83.78614807, 23.59818077], [83.77488708, 23.59950066], [83.76776886, 23.60908127], [83.76573944, 23.61754036], [83.76493835, 23.62148094], [83.74778748, 23.62664986], [83.74302673, 23.64046097], [83.74462128, 23.64565086], [83.75208282, 23.64898109], [83.75094604, 23.65332985], [83.74404144, 23.65913963], [83.72891235, 23.66740036], [83.72132874, 23.67374039], [83.71472931, 23.68254089], [83.71507263, 23.69024086], [83.72257996, 23.69413948], [83.72431183, 23.69678116], [83.73213959, 23.70466995], [83.73471832, 23.71355057], [83.73246002, 23.72398949], [83.72934723, 23.7318306], [83.73000336, 23.74368095], [83.72940063, 23.75473022], [83.72709656, 23.75990105], [83.71235657, 23.77233124], [83.71250153, 23.78083992], [83.71080017, 23.7895298], [83.70775604, 23.79495049], [83.69989777, 23.80163002], [83.69558716, 23.80759811], [83.69859314, 23.81646156], [83.69538879, 23.82066917], [83.68849182, 23.82393265], [83.68200684, 23.82580185], [83.67772675, 23.82266808], [83.67220306, 23.8200798], [83.66649628, 23.8259182], [83.65833282, 23.82781982], [83.65528107, 23.83201027], [83.65759277, 23.83697128], [83.65624237, 23.84364128], [83.64955139, 23.84806061], [83.63790131, 23.84703064], [83.62998962, 23.84736061], [83.61148834, 23.85336113], [83.60057068, 23.85347748], [83.59044647, 23.85649109], [83.58116913, 23.8619194], [83.57177734, 23.86306], [83.56121063, 23.86295128], [83.55760956, 23.86952972], [83.56369781, 23.87306023], [83.57302856, 23.87706947], [83.57615662, 23.88438034], [83.57015228, 23.89035988], [83.56050873, 23.89265823], [83.54936981, 23.89283943], [83.54284668, 23.89824104], [83.537323, 23.91463089], [83.53894043, 23.93350029], [83.53373718, 23.94174004], [83.5226059, 23.95216942], [83.51243591, 23.96699905], [83.50772095, 23.97945976], [83.50654602, 23.99134064], [83.50750732, 24.00139046], [83.51655579, 24.01062012], [83.51483154, 24.01576042], [83.5096283, 24.02540016], [83.50670624, 24.0282402], [83.50122833, 24.03068924], [83.4789505, 24.03854942], [83.46840668, 24.04067039], [83.45813751, 24.04191971], [83.45307922, 24.04142189], [83.44758606, 24.04248047], [83.4332428, 24.05470085], [83.43132019, 24.0579319], [83.42920685, 24.06202126], [83.43061066, 24.06904984], [83.43013, 24.07401085], [83.42858887, 24.07977295], [83.42536926, 24.08376122], [83.42137909, 24.08378029], [83.41467285, 24.08121109], [83.40895081, 24.08047104], [83.40309143, 24.08077812], [83.4006958, 24.08177948], [83.39240265, 24.09495163], [83.38326263, 24.09987068], [83.36197662, 24.10196114], [83.35723114, 24.10169029], [83.3457489, 24.09707069], [83.32759857, 24.09964943], [83.32356262, 24.1013298], [83.33904266, 24.11045074], [83.34279633, 24.11425018], [83.34355164, 24.11878967], [83.34900665, 24.12643814], [83.34992218, 24.13709259], [83.35250092, 24.14030075], [83.35607147, 24.14773941], [83.35735321, 24.15683937], [83.36560059, 24.17196083], [83.36936188, 24.18058968], [83.37049866, 24.18675041], [83.37834167, 24.20079041], [83.37822723, 24.2052803], [83.37621307, 24.21013069], [83.37602997, 24.213871], [83.37840271, 24.21685982], [83.37930298, 24.22019958], [83.37689972, 24.23093033], [83.37734222, 24.23566055], [83.38085938, 24.24002075], [83.39111328, 24.24464989], [83.39343262, 24.2471199], [83.39338684, 24.25266075], [83.40188599, 24.26600075], [83.40291595, 24.27613068], [83.4005127, 24.28524017], [83.39615631, 24.29339027], [83.39050293, 24.29652023], [83.38656616, 24.29756927], [83.38182831, 24.29988098], [83.38063812, 24.30046844], [83.38027191, 24.3047905], [83.37561035, 24.31344986], [83.37593842, 24.31454086], [83.37861633, 24.31552124], [83.38530731, 24.32034111], [83.3914032, 24.32677078], [83.40332794, 24.3373909], [83.40689087, 24.33899117], [83.41118622, 24.33955002], [83.42352295, 24.33870125], [83.42661285, 24.3399601], [83.43004608, 24.34495926], [83.43431091, 24.34747124], [83.44104767, 24.3608799], [83.44567108, 24.36327171], [83.45139313, 24.36474991], [83.45144653, 24.36700058], [83.44763947, 24.36844826], [83.44320679, 24.37278938], [83.44278717, 24.37764168], [83.4397583, 24.38013077], [83.43995667, 24.38698006], [83.43884277, 24.38899994], [83.43470764, 24.39063072], [83.43292999, 24.39404106], [83.43048859, 24.39600754], [83.42988586, 24.40378952], [83.4262085, 24.40604973], [83.41652679, 24.40947914], [83.41197205, 24.41025162], [83.40013885, 24.40867996], [83.3989563, 24.41208076], [83.40067291, 24.43713951], [83.39248657, 24.43642044], [83.38978577, 24.43758965], [83.38140869, 24.45565033], [83.3842392, 24.46140099], [83.38713074, 24.46457291], [83.38820648, 24.4681282], [83.38816833, 24.47326279], [83.39256287, 24.48027992], [83.39346313, 24.48476982], [83.39360809, 24.48891068], [83.39160156, 24.49283981], [83.39212799, 24.49711037], [83.393013, 24.50119019], [83.39546967, 24.50377083], [83.39997864, 24.50605965], [83.42636108, 24.51278114], [83.43563843, 24.5135994], [83.45308685, 24.51711082], [83.46186829, 24.51787758], [83.48139191, 24.52391052], [83.48671722, 24.52435112], [83.49816895, 24.52705956], [83.50950623, 24.52754021], [83.52384186, 24.52592087], [83.53504181, 24.52557945], [83.54244232, 24.52618027], [83.54725647, 24.52403069], [83.57121277, 24.51700974], [83.59240723, 24.51489067], [83.60015869, 24.51324081], [83.64483643, 24.51618004], [83.66252899, 24.51568031], [83.67080688, 24.51477051], [83.68245697, 24.51558113], [83.69567871, 24.51061058], [83.70236969, 24.50733948], [83.71669006, 24.50494957], [83.73073578, 24.50879097], [83.74865723, 24.51053047], [83.78174591, 24.52358055], [83.78803253, 24.52717018], [83.794487, 24.52944946], [83.79901123, 24.52988052], [83.80895233, 24.52894974], [83.81623077, 24.53125954], [83.82740021, 24.53314972], [83.8414917, 24.53450012], [83.84807587, 24.5363102], [83.8576889, 24.53755951], [83.86804199, 24.53288078], [83.87885284, 24.53650093], [83.90274811, 24.54244041], [83.9179306, 24.54578972], [83.92407227, 24.54620934], [83.92845917, 24.54791069], [83.93300629, 24.55174255], [83.93649292, 24.55591965], [83.94818115, 24.56651115], [83.95758057, 24.57632828], [83.9648819, 24.58764076], [83.97235107, 24.59662819], [83.97924042, 24.61512947], [83.99221039, 24.63803291], [84.00196838, 24.63540077], [84.01452637, 24.63163948], [84.01566315, 24.62760162], [84.01963806, 24.62681961], [84.02416992, 24.62906075], [84.0267868, 24.62774277], [84.0289917, 24.62264061], [84.03205109, 24.62157822], [84.0332489, 24.61895943], [84.03823853, 24.61940956], [84.04673767, 24.61228943], [84.0448761, 24.6069603], [84.04785919, 24.60650826], [84.05311584, 24.59469986], [84.05142212, 24.59152031], [84.05293274, 24.5879612], [84.05808258, 24.58836174], [84.06136322, 24.58937073], [84.06265259, 24.58371925], [84.05974579, 24.57698059], [84.06526184, 24.57505989], [84.06774139, 24.57102966], [84.07247925, 24.56960106], [84.07467651, 24.56475067], [84.07367706, 24.55758095], [84.07723999, 24.5524807], [84.07833862, 24.54500961], [84.08429718, 24.5387001], [84.08870697, 24.53607941], [84.08969116, 24.53392982], [84.086586, 24.51463127], [84.08909607, 24.5041275], [84.0969696, 24.49572182], [84.10092163, 24.48790169], [84.10977936, 24.48139954], [84.12258148, 24.48666954], [84.12490845, 24.49831963], [84.12901306, 24.50068092], [84.13654327, 24.50254059], [84.13996124, 24.5048008], [84.1370163, 24.51818085], [84.1362915, 24.52936172], [84.14605713, 24.54030037], [84.14955902, 24.54030037], [84.16065979, 24.53824043], [84.16440582, 24.53371239], [84.15571594, 24.52433968], [84.15589142, 24.51948166], [84.15364075, 24.51764107], [84.16114044, 24.51258278], [84.17137146, 24.50979042], [84.17926025, 24.51041985], [84.18226624, 24.51563072], [84.18225861, 24.51834106], [84.18641663, 24.52249908], [84.18239594, 24.52360916], [84.17282104, 24.54198074], [84.17288208, 24.54713058], [84.18158722, 24.54706001], [84.18695831, 24.54930115], [84.18830109, 24.55532074], [84.19991302, 24.55702019], [84.20050049, 24.54944038], [84.20620728, 24.54533005], [84.20892334, 24.53716087], [84.21749115, 24.5351696], [84.22068024, 24.55033112], [84.23500824, 24.55318069], [84.23426056, 24.5435791], [84.24108887, 24.54322052], [84.24829865, 24.53876114], [84.24994659, 24.5357399], [84.24852753, 24.53158951], [84.25714111, 24.53075027], [84.25846863, 24.53769112], [84.26274109, 24.53711128], [84.26474762, 24.54057121], [84.26944733, 24.54136848], [84.26859283, 24.54685974], [84.27828217, 24.54747009], [84.28009033, 24.55191994], [84.27189636, 24.55402184], [84.26922607, 24.56425285], [84.27997589, 24.56336021], [84.29297638, 24.56599045], [84.29743195, 24.56314278], [84.30200958, 24.54725266], [84.30944824, 24.53954124], [84.3119278, 24.53375816], [84.31284332, 24.52676964], [84.31910706, 24.52231026], [84.32168579, 24.51317978], [84.32634735, 24.50271988], [84.32565308, 24.49670982], [84.32170868, 24.48975754], [84.3082428, 24.48690033], [84.29418945, 24.48076057], [84.28526306, 24.46591949], [84.29022217, 24.45808029], [84.29321289, 24.45082283], [84.31498718, 24.44750977], [84.33039856, 24.43119049], [84.33065796, 24.42843056], [84.32749176, 24.42772865], [84.31939697, 24.42925072], [84.31505585, 24.42345238], [84.3182373, 24.42021942], [84.32486725, 24.42366982], [84.32778931, 24.4221611], [84.32779694, 24.41657066], [84.3258667, 24.41093063], [84.33162689, 24.40464973], [84.33798218, 24.40129089], [84.33586121, 24.39583015], [84.34696198, 24.39207077], [84.3553009, 24.39096069], [84.36136627, 24.38663292], [84.36725616, 24.38695908], [84.37377167, 24.39099121], [84.38221741, 24.38969994], [84.3850174, 24.37934113], [84.39202881, 24.37574959], [84.39766693, 24.37741089], [84.3997879, 24.37463951], [84.39494324, 24.36779022], [84.42253876, 24.35914993], [84.41816711, 24.34235954], [84.41742706, 24.33136177], [84.44491577, 24.33418083], [84.4466629, 24.3397007], [84.45453644, 24.33864975], [84.46196747, 24.31755066], [84.46511078, 24.30838966], [84.46839905, 24.30529022], [84.47534943, 24.30256271], [84.47856903, 24.30289078], [84.48706055, 24.30483246], [84.48874664, 24.3021698], [84.48751068, 24.29883957], [84.48420715, 24.29692078], [84.4935379, 24.28704071], [84.49688721, 24.29272079], [84.50229645, 24.29454994], [84.50123596, 24.29880905], [84.50454712, 24.30590057], [84.50319672, 24.31541061], [84.51069641, 24.3171711], [84.51419067, 24.3236084], [84.51741028, 24.33366966], [84.52548981, 24.33947945], [84.51937866, 24.34584045], [84.51882172, 24.35316086], [84.52671051, 24.36102104], [84.52796173, 24.36483002], [84.52406311, 24.36876106], [84.52152252, 24.37626076], [84.54167938, 24.37671089], [84.54585266, 24.37369919], [84.5560379, 24.3797226], [84.56578064, 24.38393974], [84.56430817, 24.38989067], [84.55912018, 24.39710808], [84.56121826, 24.40184021], [84.56539154, 24.4074707], [84.57247925, 24.41234016], [84.58006287, 24.41041946], [84.58184814, 24.40146065], [84.58992004, 24.4043808], [84.59420013, 24.40401077], [84.60096741, 24.40097809], [84.61251068, 24.40121269], [84.61521149, 24.4038105], [84.61929321, 24.40205956], [84.62288666, 24.40394974], [84.62885284, 24.40017128], [84.64305115, 24.39861107], [84.65825653, 24.39374161], [84.6601181, 24.39598083], [84.66294861, 24.4106102], [84.66779327, 24.41296005], [84.66838837, 24.42629051], [84.66584778, 24.42843056], [84.66622925, 24.43119049], [84.67401123, 24.44114113], [84.67891693, 24.4563427], [84.68405914, 24.45919991], [84.69407654, 24.46179962], [84.70652771, 24.4723587], [84.71292877, 24.46863174], [84.71750641, 24.4688282], [84.72490692, 24.47294998], [84.74006653, 24.48826981], [84.74201965, 24.49645805], [84.7629776, 24.50176811], [84.7798996, 24.50485039], [84.78367615, 24.51770973], [84.78970337, 24.52154922], [84.79532623, 24.52949142], [84.80164337, 24.52111816], [84.81949615, 24.52482033], [84.83262634, 24.51148033], [84.82792664, 24.48600006], [84.82718658, 24.47011948], [84.83345795, 24.46958923], [84.83273315, 24.46116066], [84.83062744, 24.45920944], [84.83439636, 24.45252037], [84.84198761, 24.45547104], [84.84748077, 24.46593094], [84.85733795, 24.46076965], [84.85703278, 24.45758247], [84.85974884, 24.45664024], [84.8629303, 24.4576416], [84.8674469, 24.46692085], [84.87271881, 24.46582031], [84.87625122, 24.46278954], [84.88017273, 24.46280098], [84.87805176, 24.44379044], [84.88004303, 24.43204117], [84.87789917, 24.42263031], [84.88234711, 24.41710281], [84.89190674, 24.39853096], [84.8981781, 24.39381981], [84.9005127, 24.38208008], [84.89441681, 24.37504005], [84.89803314, 24.37212944], [84.90331268, 24.37231064], [84.91297913, 24.37565041], [84.92533875, 24.37804031], [84.93495178, 24.37645912], [84.94793701, 24.37177086], [84.96856689, 24.37594986], [84.99040222, 24.41222954], [85.01069641, 24.41608047], [85.01460266, 24.41912079], [85.02066803, 24.42201996], [85.03209686, 24.42535019], [85.03573608, 24.42311287], [85.03954315, 24.42412758], [85.04223633, 24.41827965], [85.05329132, 24.41513062], [85.05748749, 24.41648293], [85.06040955, 24.42460823], [85.06461334, 24.43058968], [85.06906891, 24.43565941], [85.07615662, 24.43987083], [85.07567596, 24.42175102], [85.07375336, 24.4129982], [85.07454681, 24.40846252], [85.07302094, 24.40653992], [85.07038879, 24.40517998], [85.06919861, 24.40119934], [85.07100677, 24.39969254], [85.06548309, 24.38676071], [85.08068085, 24.38075066], [85.0894165, 24.37919998], [85.092453, 24.38152122], [85.09594727, 24.39077187], [85.09867096, 24.3939209], [85.10932922, 24.39882088], [85.1150589, 24.40901947], [85.11898804, 24.40913963], [85.1206665, 24.40843964], [85.12693024, 24.41151047], [85.14795685, 24.4181881], [85.15529633, 24.41801071], [85.1578598, 24.42416], [85.16439056, 24.42769051], [85.16938019, 24.42947006], [85.1688385, 24.4317894], [85.16625977, 24.43349075], [85.1648407, 24.43580055], [85.16372681, 24.4414196], [85.16133118, 24.44329071], [85.15872955, 24.45125008], [85.15260315, 24.45375061], [85.14990997, 24.45585251], [85.14927673, 24.45928001], [85.15067291, 24.46286964], [85.15289307, 24.46414948], [85.16323853, 24.46718979], [85.16750336, 24.46735954], [85.1698761, 24.46609116], [85.17632294, 24.46797943], [85.18260193, 24.46866035], [85.19052124, 24.46858025], [85.19924927, 24.46739006], [85.20326233, 24.47294998], [85.21578217, 24.47254944], [85.22392273, 24.4711895], [85.22853851, 24.47941017], [85.23532867, 24.47985077], [85.23941803, 24.48882294], [85.24649811, 24.49529076], [85.25444031, 24.49793053], [85.26956177, 24.49837112], [85.28196716, 24.49720001], [85.28103638, 24.49975014], [85.28237152, 24.50375938], [85.28192902, 24.509161], [85.27980804, 24.51388168], [85.27935791, 24.51910019], [85.28251648, 24.52668953], [85.28804779, 24.52840042], [85.29734802, 24.52864075], [85.31253052, 24.52658081], [85.31855774, 24.52462959], [85.32250214, 24.52557945], [85.3315506, 24.5262413], [85.33790588, 24.52799034], [85.34581757, 24.52799988], [85.36116028, 24.52971268], [85.37026978, 24.52958107], [85.38278198, 24.53253174], [85.38336945, 24.53519058], [85.38860321, 24.53708076], [85.39517212, 24.54128075], [85.40305328, 24.54494095], [85.40661621, 24.54566193], [85.411026, 24.54511261], [85.42753601, 24.53729057], [85.43327332, 24.53607941], [85.44213104, 24.53938484], [85.44230652, 24.53944969], [85.44655609, 24.53997993], [85.45658875, 24.53921127], [85.47215271, 24.54779053], [85.4809494, 24.5481205], [85.48648071, 24.55075073], [85.48944092, 24.54915047], [85.49446106, 24.55061913], [85.49752045, 24.54850006], [85.49746704, 24.54688072], [85.49997711, 24.54389], [85.50254822, 24.5428791], [85.50319672, 24.53572273], [85.50241852, 24.53142929], [85.50435638, 24.52972984], [85.51481628, 24.52782822], [85.51830292, 24.52454948], [85.53418732, 24.53219032], [85.53646088, 24.53601074], [85.54035187, 24.55034828], [85.53987122, 24.5561409], [85.53820038, 24.56145096], [85.53646088, 24.56380081], [85.53679657, 24.56524086], [85.53901672, 24.56587029], [85.54380798, 24.56447983], [85.55233002, 24.5594101], [85.55461121, 24.55612946], [85.55625916, 24.55681992], [85.55658722, 24.56064034], [85.56445313, 24.56184959], [85.56829071, 24.56520081], [85.56575775, 24.571661], [85.56711578, 24.57822037], [85.56221771, 24.58098984], [85.56138611, 24.58366966], [85.56285095, 24.59127045], [85.56520081, 24.59666061], [85.56989288, 24.60021973], [85.57657623, 24.60301018], [85.58196259, 24.60009956], [85.59114075, 24.59705925], [85.59825134, 24.59757042], [85.60787964, 24.59078979], [85.60852051, 24.58503914], [85.615448, 24.58292961], [85.62198639, 24.58385849], [85.63279724, 24.58056068], [85.64427948, 24.57829094], [85.66470337, 24.58193016], [85.67031097, 24.5880928], [85.67324829, 24.59294128], [85.67352295, 24.59563065], [85.67238617, 24.59818077], [85.670578, 24.59943008], [85.67212677, 24.61940002], [85.66895294, 24.6305294], [85.66570282, 24.63626099], [85.66432953, 24.6410408], [85.66364288, 24.64447021], [85.66118622, 24.64664078], [85.66069794, 24.65060234], [85.66371918, 24.66098022], [85.66333008, 24.66471291], [85.66079712, 24.66757965], [85.65975952, 24.67031288], [85.65997314, 24.6747303], [85.65046692, 24.67924118], [85.64826202, 24.68188095], [85.6495285, 24.68704033], [85.67965698, 24.69376755], [85.6870575, 24.70089149], [85.6966629, 24.71347237], [85.69639587, 24.71725082], [85.69875336, 24.72106934], [85.70343781, 24.72537041], [85.70477295, 24.72872925], [85.70533752, 24.74005127], [85.70812988, 24.7476902], [85.70553589, 24.75162125], [85.70355988, 24.7574501], [85.70346832, 24.76349258], [85.70478058, 24.76883125], [85.709198, 24.77563858], [85.70980072, 24.7809906], [85.71231079, 24.78333282], [85.72099304, 24.7869606], [85.72296906, 24.79890823], [85.72830963, 24.80066109], [85.72978973, 24.80849075], [85.73252106, 24.81648254], [85.73500824, 24.82138252], [85.73674011, 24.82265091], [85.74727631, 24.81991959], [85.75827789, 24.81508827], [85.76074982, 24.81507111], [85.76544952, 24.81250954], [85.76879883, 24.80881119], [85.76859283, 24.80404091], [85.76940155, 24.8028717], [85.77723694, 24.7989502], [85.77923584, 24.80048943], [85.78572845, 24.79868126], [85.81066132, 24.79449844], [85.81260681, 24.79936028], [85.81803131, 24.80696106], [85.82257843, 24.80895042], [85.8272171, 24.80964279], [85.84194183, 24.80805969], [85.85381317, 24.80764008], [85.86402893, 24.80542946], [85.8777771, 24.80029106], [85.88967896, 24.79165077], [85.88717651, 24.78558922], [85.90168762, 24.76986122], [85.90457153, 24.76128006], [85.9105072, 24.75366974], [85.9209671, 24.74456024], [85.92767334, 24.7404995], [85.94270325, 24.73442078], [85.95030212, 24.73211861], [85.96064758, 24.7317009], [85.96613312, 24.73229027], [85.97016907, 24.73357964], [85.97271729, 24.73628998], [85.97589111, 24.74596977], [85.97725677, 24.74763107], [85.99997711, 24.75138092], [86.00611115, 24.76568031], [86.00956726, 24.76799965], [86.01397705, 24.7689991], [86.01967621, 24.76776123], [86.02275848, 24.76938057], [86.02778625, 24.77029037], [86.03179169, 24.77275276], [86.03443909, 24.77617073], [86.03897858, 24.77667046], [86.04305267, 24.77740097], [86.04788208, 24.77828979], [86.05058289, 24.77954102], [86.05264282, 24.77318954], [86.05288696, 24.76770973], [86.0530014, 24.76174927], [86.04984283, 24.75578117], [86.04535675, 24.75191116], [86.04154968, 24.74790001], [86.03601074, 24.74734116], [86.03681946, 24.74382973], [86.03907013, 24.74131966], [86.04270935, 24.74387169], [86.05503845, 24.74634933], [86.06041718, 24.74768066], [86.06318665, 24.75167084], [86.08657837, 24.74632072], [86.10553741, 24.73596954], [86.10929871, 24.73224068], [86.11094666, 24.72402763], [86.1159668, 24.7188797], [86.11863708, 24.71165085], [86.12444305, 24.70516014], [86.12909698, 24.69003105], [86.13201141, 24.6803894], [86.13359833, 24.67551041], [86.13002777, 24.6714592], [86.12594604, 24.67080116], [86.12848663, 24.66597939], [86.12631989, 24.65422058], [86.1231308, 24.64793015], [86.11824799, 24.64189148], [86.12185669, 24.63005066], [86.12200928, 24.62393188], [86.12322998, 24.61968994], [86.12558746, 24.61182022], [86.13076019, 24.60893059], [86.13329315, 24.60354042], [86.14463043, 24.60305977], [86.15226746, 24.59971046], [86.15696716, 24.58923912], [86.16565704, 24.58368111], [86.19493866, 24.58516121], [86.21570587, 24.59117126], [86.21656036, 24.60280037], [86.21737671, 24.61177063], [86.23026276, 24.60227013], [86.23874664, 24.59679985], [86.24288177, 24.59213829], [86.24855042, 24.58513069], [86.25747681, 24.58312988], [86.26152802, 24.57690048], [86.26413727, 24.57583809], [86.26625824, 24.58195114], [86.26970673, 24.57780075], [86.27348328, 24.57562065], [86.27688599, 24.57419968], [86.27612305, 24.57908058], [86.27378845, 24.58274841], [86.28040314, 24.58418083], [86.28835297, 24.58433914], [86.29263306, 24.58609009], [86.30166626, 24.58315086], [86.31005096, 24.58156013], [86.31223297, 24.58588028], [86.32286072, 24.58409119], [86.32269287, 24.58056068], [86.318573, 24.57892036], [86.31936646, 24.57445908], [86.31098938, 24.56818008], [86.30809784, 24.5657196], [86.30982208, 24.56310081], [86.30404663, 24.55829048], [86.30983734, 24.54734039], [86.3081665, 24.54083252], [86.3013382, 24.53197861], [86.30330658, 24.52773094], [86.30751801, 24.52635956], [86.31056213, 24.51382256], [86.31241608, 24.50847054], [86.30973053, 24.50636292], [86.30349731, 24.49827194], [86.30162811, 24.49353981], [86.29824066, 24.48899841], [86.29773712, 24.48252106], [86.29387665, 24.47643089], [86.28557587, 24.47680283], [86.28183746, 24.47047806], [86.27913666, 24.4620018], [86.30090332, 24.45680046], [86.2988205, 24.45426178], [86.29957581, 24.44898987], [86.30375671, 24.44483948], [86.31555939, 24.4439106], [86.31949615, 24.44016075], [86.33273315, 24.44019127], [86.34781647, 24.44049835], [86.35072327, 24.44371033], [86.35350037, 24.44206047], [86.36271667, 24.42679024], [86.36789703, 24.42424965], [86.37326813, 24.41585159], [86.38123322, 24.4123497], [86.3986969, 24.40028954], [86.40101624, 24.39627075], [86.41558838, 24.37920952], [86.42514801, 24.37811852], [86.43070221, 24.37613106], [86.4341507, 24.37685966], [86.44632721, 24.36844063], [86.45220947, 24.36862946], [86.45504761, 24.37396812], [86.46179962, 24.37672043], [86.46568298, 24.38500023], [86.46711731, 24.39516068], [86.46366882, 24.40775108], [86.46568298, 24.41378975], [86.46367645, 24.4185009], [86.46582794, 24.42188072], [86.4733963, 24.42276192], [86.48207855, 24.42498016], [86.48858643, 24.42500114], [86.48819733, 24.43386078], [86.49194336, 24.43930054], [86.49098969, 24.44695282], [86.49112701, 24.45405006], [86.48448944, 24.45882034], [86.48974609, 24.46760178], [86.48877716, 24.47426987], [86.49080658, 24.47875023], [86.49028015, 24.48437119], [86.49532318, 24.48527908], [86.49812317, 24.48727036], [86.49752808, 24.49797821], [86.50572205, 24.5177002], [86.52352905, 24.53574944], [86.53044891, 24.53293037], [86.53614807, 24.5364399], [86.54057312, 24.53662109], [86.54669189, 24.5350399], [86.5513382, 24.54342079], [86.55792999, 24.54847908], [86.55464172, 24.55927086], [86.55831909, 24.55928993], [86.56170654, 24.56311035], [86.56804657, 24.56279945], [86.57823944, 24.56787109], [86.58315277, 24.57278061], [86.58389282, 24.58531952], [86.58976746, 24.59268951], [86.59485626, 24.59707069], [86.59998322, 24.59949112], [86.60292053, 24.60506821], [86.60929871, 24.60741043], [86.60968018, 24.60252953], [86.60936737, 24.60192108], [86.60791779, 24.59931946], [86.60691833, 24.59435081], [86.61885834, 24.59469986], [86.61828613, 24.58449173], [86.62716675, 24.57962036], [86.63420105, 24.57667923], [86.64126587, 24.57611847], [86.64575958, 24.5672226], [86.65593719, 24.56319809], [86.668396, 24.56064034], [86.67767334, 24.56611252], [86.68151855, 24.5650692], [86.68663788, 24.57044029], [86.69536591, 24.5689106], [86.70990753, 24.57353973], [86.7186203, 24.57821274], [86.73158264, 24.57579994], [86.7350769, 24.58084106], [86.73950958, 24.58649254], [86.74565125, 24.58950043], [86.74459839, 24.60288048], [86.75086212, 24.61797905], [86.75405121, 24.61475945], [86.76912689, 24.61648178], [86.7755127, 24.61557961], [86.77519226, 24.61951065], [86.7771225, 24.61976051], [86.78085327, 24.61483955], [86.78407288, 24.61028099], [86.78647614, 24.60457993], [86.78690338, 24.59937096], [86.79437256, 24.59683037], [86.79429626, 24.60070038], [86.79251099, 24.60518074], [86.79032135, 24.60844994], [86.78736115, 24.61092949], [86.78585052, 24.61309242], [86.78560638, 24.61720085], [86.79184723, 24.61531067], [86.7943573, 24.61209106], [86.79660797, 24.60852051], [86.79749298, 24.60573959], [86.79808807, 24.60346985], [86.79866791, 24.60114288], [86.80018616, 24.59857941], [86.8017807, 24.59745979], [86.8057785, 24.5945015], [86.80446625, 24.59065056], [86.80488586, 24.58538055], [86.80625916, 24.58114052], [86.80761719, 24.57685089], [86.80322266, 24.57435989], [86.80120087, 24.57196808], [86.80033875, 24.56870079], [86.80018616, 24.56592941], [86.80029297, 24.5646019], [86.80499268, 24.56412125], [86.80871582, 24.56377029], [86.81358337, 24.56820107], [86.81825256, 24.56933975], [86.82147217, 24.56831932], [86.82559204, 24.56599998], [86.83152771, 24.56805038], [86.83705139, 24.56828117], [86.83857727, 24.56278038], [86.83869171, 24.55862045], [86.83880615, 24.55406952], [86.84710693, 24.55297089], [86.85463715, 24.55046082], [86.85745239, 24.55661011], [86.86161041, 24.56027031], [86.86949158, 24.56138039], [86.87320709, 24.56497955], [86.87639618, 24.56731987], [86.87909698, 24.56305122], [86.88398743, 24.56035805], [86.88414001, 24.5544796], [86.88672638, 24.55402946], [86.89308929, 24.55483818], [86.89842224, 24.54975128], [86.90117645, 24.54449272], [86.90583038, 24.54097176], [86.91117859, 24.53867912], [86.9071579, 24.54338074], [86.90629578, 24.54926109], [86.90650177, 24.55529976], [86.90644073, 24.55989075], [86.90635681, 24.56336975], [86.90122223, 24.56679916], [86.90322113, 24.57152939], [86.90065765, 24.57615089], [86.89795685, 24.58053017], [86.89807892, 24.58654022], [86.90123749, 24.5915699], [86.90467834, 24.59514046], [86.90895081, 24.59698868], [86.91001892, 24.60114288], [86.91786194, 24.61079025], [86.9189682, 24.61347961], [86.91893768, 24.61940956], [86.92386627, 24.62433052], [86.92926788, 24.62644005], [86.93414307, 24.62652016], [86.93605804, 24.63037109], [86.93344116, 24.63572121], [86.93009186, 24.64282036], [86.93884277, 24.64307022], [86.94861603, 24.64276123], [86.94754791, 24.63586807], [86.94474792, 24.63117027], [86.94550323, 24.62656021], [86.95347595, 24.62765121], [86.95842743, 24.62943077], [86.96556091, 24.63186836], [86.97119141, 24.63030052], [86.9801178, 24.62467003], [86.98549652, 24.62162971], [86.98815155, 24.6201992], [86.99008942, 24.62002945], [86.99014282, 24.62071037], [86.99260712, 24.61918068], [87.0102005, 24.6062603], [87.01291656, 24.60909271], [87.01558685, 24.61330032], [87.01670074, 24.61779976], [87.02144623, 24.61962128], [87.02435303, 24.62109947], [87.02635193, 24.62008286], [87.02646637, 24.61605072], [87.02643585, 24.61123276], [87.02751923, 24.60931969], [87.03011322, 24.60951996], [87.0326004, 24.60989761], [87.03497314, 24.61010933], [87.03592682, 24.61177063], [87.03671265, 24.61325073], [87.03872681, 24.6125412], [87.04086304, 24.61104965], [87.0430069, 24.60893059], [87.04463196, 24.60539818], [87.05046844, 24.60676956], [87.04834747, 24.61014938], [87.04673004, 24.61421013], [87.04670715, 24.61740112], [87.04592133, 24.62017059], [87.04440308, 24.62403107], [87.04580688, 24.63089752], [87.04881287, 24.63701057], [87.05039978, 24.64344025], [87.05101013, 24.64927101], [87.05237579, 24.65551186], [87.05475616, 24.66069031], [87.05532074, 24.66509056], [87.05473328, 24.67060089], [87.05892181, 24.67225075], [87.06017303, 24.67721939], [87.06131744, 24.68152046], [87.06381226, 24.68503952], [87.0670166, 24.68847275], [87.06932831, 24.69124985], [87.07063293, 24.69449997], [87.07087708, 24.69885063], [87.07138062, 24.70313072], [87.07125092, 24.70734978], [87.07264709, 24.7109108], [87.07367706, 24.7125206], [87.07660675, 24.71459961], [87.07772064, 24.71879959], [87.08029175, 24.7219696], [87.08185577, 24.72454071], [87.08235168, 24.72699928], [87.08138275, 24.72925949], [87.08119202, 24.73265076], [87.08132172, 24.73594284], [87.08040619, 24.73698044], [87.07847595, 24.73615074], [87.07704926, 24.73566055], [87.0756073, 24.73641968], [87.07576752, 24.73814964], [87.07636261, 24.7399292], [87.07398987, 24.74054909], [87.07359314, 24.7430706], [87.07454681, 24.74472046], [87.07646179, 24.74549103], [87.07982635, 24.74658966], [87.08161163, 24.74834061], [87.08120728, 24.75075912], [87.08097076, 24.75168991], [87.08309174, 24.7536602], [87.08508301, 24.75580978], [87.08631134, 24.75831985], [87.08486938, 24.7614994], [87.08339691, 24.76452065], [87.08254242, 24.76798248], [87.08254242, 24.7729702], [87.0828476, 24.77922821], [87.08560181, 24.7824707], [87.08804321, 24.78523827], [87.0912323, 24.78811073], [87.09288025, 24.79229164], [87.09568024, 24.79759979], [87.09667206, 24.80149269], [87.09660339, 24.80402756], [87.09395599, 24.80441093], [87.09072876, 24.80266953], [87.08886719, 24.8040905], [87.0863266, 24.80591011], [87.08345032, 24.80658913], [87.08138275, 24.80738068], [87.08078003, 24.80951118], [87.07730103, 24.80834961], [87.07713318, 24.81182098], [87.0776062, 24.81422043], [87.07730103, 24.81814194], [87.0785675, 24.82225037], [87.08036041, 24.8243618], [87.08423615, 24.82322121], [87.0877533, 24.82304192], [87.09121704, 24.82356071], [87.0949707, 24.82620049], [87.09754944, 24.82985115], [87.0996933, 24.83476067], [87.10240936, 24.83925819], [87.10462189, 24.84445953], [87.10604858, 24.84733009], [87.10949707, 24.85078812], [87.11447144, 24.85552979], [87.11915588, 24.85396957], [87.12333679, 24.8529911], [87.12731934, 24.85448265], [87.12980652, 24.85749054], [87.13273621, 24.85957909], [87.13881683, 24.85926056], [87.14451599, 24.8592205], [87.15097809, 24.85843086], [87.15168762, 24.86308098], [87.14733887, 24.86240768], [87.14792633, 24.86786842], [87.14964294, 24.87240028], [87.15453339, 24.87647057], [87.15653992, 24.88070107], [87.1581192, 24.88563156], [87.15822601, 24.88955116], [87.15695953, 24.89608955], [87.15432739, 24.90011024], [87.15023041, 24.90316963], [87.14877319, 24.90509033], [87.14774323, 24.9081707], [87.14650726, 24.91286278], [87.14762878, 24.9178009], [87.14971161, 24.92122269], [87.15268707, 24.9239502], [87.15461731, 24.92651749], [87.15531158, 24.93168068], [87.15213013, 24.93653107], [87.14859009, 24.9421196], [87.14877319, 24.94938087], [87.15075684, 24.95574951], [87.15258026, 24.96299934], [87.1519165, 24.96861267], [87.15203094, 24.97443962], [87.15299225, 24.9831295], [87.15368652, 24.99097061], [87.14647675, 24.9998703], [87.14597321, 25.00355911], [87.1444931, 25.00642967], [87.14388275, 25.01078987], [87.14420319, 25.01797104], [87.14676666, 25.02431107], [87.14904785, 25.0262394], [87.15232086, 25.02651978], [87.15834045, 25.03100014], [87.1649704, 25.04281998], [87.16503906, 25.04586983], [87.16847992, 25.0489502], [87.17325592, 25.05647087], [87.17384338, 25.05800247], [87.17664337, 25.06402016], [87.18431854, 25.06701088], [87.18776703, 25.06699944], [87.19747162, 25.07365036], [87.19986725, 25.07944107], [87.20832062, 25.08332062], [87.21071625, 25.08525085], [87.21135712, 25.08959961], [87.21563721, 25.09019089], [87.21795654, 25.08854294], [87.22708893, 25.08757019], [87.23387909, 25.08582115], [87.23986053, 25.0994606], [87.24106598, 25.10079956], [87.24533081, 25.09908104], [87.24923706, 25.1053791], [87.25055695, 25.10585022], [87.25875092, 25.10461044], [87.26307678, 25.10082054], [87.26444244, 25.09777832], [87.27024841, 25.09363937], [87.27488708, 25.09218979], [87.28560638, 25.09091949], [87.29110718, 25.08926964], [87.29535675, 25.09970093], [87.29280853, 25.10469055], [87.29486847, 25.1119194], [87.2948761, 25.11381912], [87.2932663, 25.11435127], [87.2979126, 25.13466072], [87.29988098, 25.13459015], [87.30342865, 25.13814163], [87.30239105, 25.14059067], [87.30343628, 25.14320946], [87.30171967, 25.14389992], [87.30229187, 25.14532089], [87.30797577, 25.15029144], [87.30963898, 25.1535511], [87.31041718, 25.16032982], [87.3143692, 25.16275978], [87.31503296, 25.16504097], [87.31437683, 25.16736984], [87.31301117, 25.16926003], [87.31064606, 25.16982079], [87.31601715, 25.18630028], [87.31711578, 25.18868065], [87.31574249, 25.19298935], [87.315979, 25.19695091], [87.31833649, 25.20124054], [87.32345581, 25.22309113], [87.33053589, 25.22219086], [87.33045197, 25.21706963], [87.34777832, 25.21317291], [87.35507965, 25.21340942], [87.35801697, 25.21121979], [87.36846161, 25.20689964], [87.36988831, 25.20504951], [87.37394714, 25.21853065], [87.37713623, 25.2226181], [87.38330078, 25.22347069], [87.38648224, 25.22570992], [87.39177704, 25.22751808], [87.3966217, 25.22571945], [87.40215302, 25.22141075], [87.40764618, 25.2190094], [87.40949249, 25.21513939], [87.41660309, 25.21491051], [87.45511627, 25.19750023], [87.45783234, 25.19779968], [87.46192932, 25.19515038], [87.46685791, 25.1956501], [87.46763611, 25.19314194], [87.47216034, 25.19466972], [87.47181702, 25.22237968], [87.47305298, 25.23143005], [87.47264099, 25.24088287], [87.48755646, 25.26199913], [87.49484253, 25.25969124], [87.49571991, 25.26247978], [87.49559021, 25.26530075], [87.49195862, 25.27143097], [87.49447632, 25.27543068], [87.48757935, 25.27761078], [87.48150635, 25.29517174], [87.48638153, 25.2960701], [87.49006653, 25.30520058], [87.49887085, 25.29228973], [87.51287079, 25.29214287], [87.52552032, 25.28098106], [87.52942657, 25.27961922], [87.53562927, 25.28010941], [87.53974915, 25.28161812], [87.53849792, 25.29623032], [87.54112244, 25.30425072], [87.54412079, 25.32290077], [87.54680634, 25.32365036], [87.5474472, 25.33094025], [87.56710815, 25.33389091], [87.57144165, 25.34050941], [87.57948303, 25.3439312], [87.57891846, 25.34678268], [87.5800705, 25.34839058], [87.58766174, 25.34054756], [87.58046722, 25.33232117], [87.5811615, 25.32803917], [87.5892868, 25.3237896], [87.58925629, 25.32188988], [87.59989166, 25.31466293], [87.60688019, 25.31138039], [87.61361694, 25.31553841], [87.62267303, 25.31080055], [87.6262207, 25.3157196], [87.62597656, 25.31861115], [87.63179016, 25.31186104], [87.6340332, 25.31235123], [87.6517868, 25.30724907], [87.65878296, 25.30973053], [87.6841507, 25.31013107], [87.68409729, 25.30805016], [87.68087006, 25.30767059], [87.6806488, 25.30427933], [87.68824005, 25.30476952], [87.6934967, 25.3030529], [87.69140625, 25.29860115], [87.69478607, 25.29541016], [87.69030762, 25.29121971], [87.68907166, 25.28494072], [87.69130707, 25.28139114], [87.69641113, 25.27886963], [87.70096588, 25.2777729], [87.70591736, 25.27457047], [87.70796967, 25.2713604], [87.70687103, 25.25978088], [87.70778656, 25.25640869], [87.72106171, 25.25344086], [87.73087311, 25.25315094], [87.76283264, 25.24928856], [87.76911926, 25.24665833], [87.78330994, 25.24617767], [87.78367615, 25.24299049], [87.78520203, 25.24045944], [87.78544617, 25.23631287], [87.78753662, 25.22862053], [87.7875824, 25.2204895], [87.78518677, 25.20907974], [87.78466797, 25.19960022], [87.7804718, 25.18527031], [87.77900696, 25.17692947], [87.77275085, 25.15961838], [87.77104187, 25.15227127], [87.77120972, 25.138731], [87.76928711, 25.12700081], [87.76983643, 25.11470985], [87.77266693, 25.09909821], [87.7765274, 25.09127045], [87.77986145, 25.08735085], [87.7928772, 25.07573128], [87.79989624, 25.07123947], [87.8201828, 25.06150055], [87.83493805, 25.05701828], [87.84262085, 25.05220032], [87.8550415, 25.04623985], [87.86434174, 25.03985023], [87.87697601, 25.02803993], [87.88117981, 25.02150917], [87.88082123, 25.02053833], [87.89292145, 25.00894928], [87.90242004, 24.99945068], [87.90336609, 24.99839973], [87.90648651, 24.98581123], [87.91352844, 24.97890282], [87.91851044, 24.9728508], [87.92444611, 24.96718025], [87.930336, 24.96179962], [87.93904877, 24.95573044], [87.94621277, 24.94889069], [87.9502182, 24.94534111], [87.95627594, 24.94141006], [87.96169281, 24.93593025], [87.9664917, 24.92959976], [87.9699707, 24.92358017], [87.97041321, 24.91607094], [87.97123718, 24.91003036], [87.97228241, 24.9033699], [87.9733429, 24.89648247], [87.97220612, 24.89142036], [87.96936798, 24.88512039], [87.96650696, 24.88129997], [87.96124268, 24.87905121], [87.9523468, 24.87685966], [87.94464111, 24.87267113], [87.93644714, 24.86961174], [87.92874146, 24.86588287], [87.92154694, 24.86024094], [87.91124725, 24.85593987], [87.89701843, 24.85435295], [87.88897705, 24.85293961], [87.89135742, 24.84815979], [87.89466858, 24.84775925], [87.89776611, 24.84278107], [87.89724731, 24.84174919], [87.89569092, 24.83959007], [87.8949585, 24.83389282], [87.89391327, 24.82917023], [87.89591217, 24.82756996], [87.89842224, 24.82452965], [87.8961792, 24.82259941], [87.89070892, 24.82287979], [87.88655853, 24.81966019], [87.88170624, 24.8203907], [87.87471771, 24.82271957], [87.86924744, 24.8234005], [87.86766815, 24.82298279], [87.86631012, 24.82074928], [87.8681488, 24.81811905], [87.87029266, 24.81524277], [87.87210846, 24.81186295], [87.87271881, 24.8075695], [87.87284851, 24.8052597], [87.87583923, 24.80311012], [87.87760925, 24.80101013], [87.87751007, 24.79800034], [87.87666321, 24.79368973], [87.87475586, 24.78980064], [87.87291718, 24.78977013], [87.87233734, 24.79193115], [87.87005615, 24.79087067], [87.86810303, 24.7870903], [87.86654663, 24.78244972], [87.86486053, 24.7785511], [87.86650848, 24.77614975], [87.86538696, 24.7743206], [87.85999298, 24.77200127], [87.8584671, 24.76781082], [87.85453796, 24.76431084], [87.85022736, 24.76127052], [87.84677887, 24.7610302], [87.84246826, 24.76285934], [87.83885956, 24.76536179], [87.83524323, 24.76323128], [87.83376312, 24.7658596], [87.83378601, 24.76968002], [87.833992, 24.77464104], [87.83687592, 24.77734947], [87.83899689, 24.78014183], [87.83847046, 24.78470993], [87.83753204, 24.78780174], [87.83368683, 24.78786087], [87.83001709, 24.78297043], [87.82836914, 24.77670288], [87.82785034, 24.77192116], [87.82565308, 24.76931], [87.82209015, 24.76671982], [87.81806183, 24.76598167], [87.81603241, 24.75960922], [87.81389618, 24.75336075], [87.81607819, 24.75204086], [87.82050323, 24.75206947], [87.82533264, 24.75221062], [87.83970642, 24.7381897], [87.85234833, 24.73493958], [87.86103821, 24.73125076], [87.86738586, 24.72940063], [87.87088013, 24.73002815], [87.87493896, 24.73508835], [87.8777771, 24.73908043], [87.88244629, 24.73627281], [87.88423157, 24.73347092], [87.88545227, 24.72929955], [87.8871994, 24.72544289], [87.89077759, 24.72258949], [87.89565277, 24.72302055], [87.90083313, 24.72159958], [87.90215302, 24.71849823], [87.9033432, 24.71455956], [87.90313721, 24.71190071], [87.90291595, 24.70993805], [87.90091705, 24.71050262], [87.89884949, 24.7098999], [87.89750671, 24.70647049], [87.8961792, 24.7024498], [87.8990097, 24.69968033], [87.897789, 24.69497108], [87.89656067, 24.69066048], [87.89274597, 24.68574905], [87.88941193, 24.68177986], [87.88625336, 24.67808914], [87.88661957, 24.67410278], [87.89038086, 24.67033005], [87.89507294, 24.66850281], [87.89990997, 24.6693306], [87.90319824, 24.66695976], [87.90647888, 24.66436005], [87.91159821, 24.66229057], [87.91340637, 24.6585598], [87.91013336, 24.65493011], [87.90886688, 24.65130997], [87.90785217, 24.64682961], [87.90796661, 24.64208984], [87.9076767, 24.63678169], [87.90629578, 24.63264275], [87.90428925, 24.63042068], [87.90200806, 24.62943077], [87.90000153, 24.62942123], [87.8968811, 24.6303997], [87.89227295, 24.63204956], [87.88886261, 24.63142014], [87.8868103, 24.62949944], [87.88461304, 24.62664986], [87.887146, 24.62446976], [87.89177704, 24.62368011], [87.89539337, 24.62449265], [87.89885712, 24.62574005], [87.90225983, 24.62592125], [87.90180206, 24.62257004], [87.90139008, 24.62002945], [87.90213013, 24.61650085], [87.90161133, 24.61258125], [87.89948273, 24.6114006], [87.89631653, 24.61186981], [87.89383698, 24.61296272], [87.89118195, 24.61219978], [87.88828278, 24.61133003], [87.88552094, 24.61178017], [87.88215637, 24.61359024], [87.87911224, 24.61475182], [87.87700653, 24.61629105], [87.87483215, 24.61552048], [87.87346649, 24.61347008], [87.8727417, 24.61071968], [87.87354279, 24.60931969], [87.87528992, 24.60990906], [87.87596893, 24.60885811], [87.87799835, 24.60944939], [87.88118744, 24.60696983], [87.88613129, 24.60514069], [87.88802338, 24.60532951], [87.88871002, 24.60820961], [87.89348602, 24.60834122], [87.8986969, 24.60807037], [87.90290833, 24.60804176], [87.9081192, 24.60817909], [87.90773773, 24.60436821], [87.90762329, 24.59939766], [87.90912628, 24.5963726], [87.90997314, 24.59386826], [87.90873718, 24.5911808], [87.90683746, 24.58735085], [87.90544891, 24.58380127], [87.90326691, 24.58238983], [87.89940643, 24.58357048], [87.89737701, 24.58245087], [87.89608765, 24.58062172], [87.89148712, 24.57962036], [87.89025879, 24.57472992], [87.88989258, 24.57191086], [87.88732147, 24.56270981], [87.8807373, 24.56295967], [87.87661743, 24.56108284], [87.86863708, 24.5612812], [87.86585999, 24.56083107], [87.86443329, 24.55870819], [87.86389923, 24.55657959], [87.860466, 24.55526161], [87.85632324, 24.55459023], [87.85378265, 24.55603027], [87.85047913, 24.55783272], [87.84921265, 24.5569191], [87.84996033, 24.5537281], [87.8482132, 24.55105019], [87.84497833, 24.55278015], [87.84111023, 24.55441093], [87.83480072, 24.55632973], [87.82698822, 24.55816078], [87.82450867, 24.55948257], [87.82388306, 24.56335258], [87.82327271, 24.56655121], [87.82015228, 24.5683918], [87.81685638, 24.57007027], [87.81420898, 24.57261276], [87.81166077, 24.57444], [87.80899811, 24.576231], [87.80500793, 24.57752037], [87.80224609, 24.57802963], [87.79889679, 24.57781029], [87.79505157, 24.57966995], [87.79067993, 24.58107948], [87.78536224, 24.5823307], [87.77966309, 24.58209038], [87.76940918, 24.58176041], [87.76792145, 24.57602119], [87.76757813, 24.57156944], [87.77317047, 24.57188034], [87.77774811, 24.57138062], [87.78572845, 24.56858063], [87.79158783, 24.56568909], [87.7961731, 24.56238174], [87.79936981, 24.55890083], [87.80261993, 24.55428123], [87.8048172, 24.54922104], [87.80634308, 24.54520035], [87.8057785, 24.54244041], [87.8035965, 24.54010963], [87.79985046, 24.54116058], [87.79749298, 24.53866959], [87.79798126, 24.53535843], [87.79712677, 24.53001022], [87.79756927, 24.52462959], [87.79901886, 24.52091026], [87.80121613, 24.51769066], [87.80116272, 24.51463127], [87.79972076, 24.51172066], [87.79850006, 24.50942993], [87.79850769, 24.50699997], [87.79994202, 24.50424957], [87.79823303, 24.50242996], [87.7939682, 24.50032043], [87.79260254, 24.49722862], [87.79380035, 24.49426079], [87.79515076, 24.49105072], [87.79853058, 24.49185944], [87.80101776, 24.49481964], [87.80298615, 24.49864006], [87.80342865, 24.50164032], [87.80374146, 24.50476074], [87.80391693, 24.50723076], [87.80526733, 24.50963974], [87.80667114, 24.51060104], [87.80758667, 24.5093708], [87.80734253, 24.50619125], [87.80831146, 24.50456047], [87.81021881, 24.50204086], [87.81178284, 24.49900055], [87.81111145, 24.49641991], [87.81001282, 24.49452972], [87.81021118, 24.49209023], [87.81225586, 24.4915905], [87.81555939, 24.4928093], [87.81867981, 24.49205971], [87.82022095, 24.49347115], [87.8197403, 24.49591064], [87.82190704, 24.49644089], [87.82287598, 24.49440956], [87.82244873, 24.49234009], [87.82145691, 24.49008942], [87.82099152, 24.48843002], [87.82025909, 24.48584938], [87.81685638, 24.48608017], [87.8130188, 24.48512077], [87.81035614, 24.48037148], [87.80909729, 24.47659111], [87.81138611, 24.47480965], [87.8137207, 24.47274017], [87.81478882, 24.47006035], [87.81784821, 24.46845055], [87.81659698, 24.46547127], [87.81772614, 24.46232033], [87.81735992, 24.4589901], [87.81614685, 24.45531273], [87.81524658, 24.45359993], [87.81494904, 24.45134926], [87.81125641, 24.4518795], [87.80687714, 24.45259857], [87.80251312, 24.45014], [87.80094147, 24.4473896], [87.79972076, 24.44544983], [87.79988098, 24.44371986], [87.79688263, 24.44186974], [87.79595184, 24.43939972], [87.79290009, 24.43980026], [87.79103851, 24.4377594], [87.78978729, 24.43465996], [87.7881012, 24.43209267], [87.79038239, 24.42939949], [87.79226685, 24.42687035], [87.79220581, 24.4238205], [87.79003143, 24.42167091], [87.78620911, 24.41862106], [87.78475189, 24.41454124], [87.78790283, 24.41152954], [87.79297638, 24.41063118], [87.79862976, 24.41122246], [87.80134583, 24.41341972], [87.80522156, 24.41814041], [87.80639648, 24.41472054], [87.80847931, 24.41213036], [87.80899048, 24.40923119], [87.81002045, 24.40662003], [87.80745697, 24.40435982], [87.80425262, 24.40354919], [87.8015213, 24.40192032], [87.79821014, 24.39973068], [87.79476929, 24.40007973], [87.79257965, 24.39644051], [87.79263306, 24.3930912], [87.79469299, 24.39217949], [87.7973175, 24.39229965], [87.79811096, 24.3907795], [87.7975769, 24.38606071], [87.79750824, 24.38218117], [87.79376984, 24.38076019], [87.78994751, 24.37701035], [87.78765106, 24.37166977], [87.78494263, 24.36763191], [87.78235626, 24.3602314], [87.77922821, 24.35705948], [87.77658844, 24.35341072], [87.77262878, 24.34938049], [87.76941681, 24.34539986], [87.7678833, 24.34045982], [87.76451874, 24.3385601], [87.7612381, 24.33331108], [87.76055908, 24.32817078], [87.76420593, 24.32522011], [87.76448059, 24.32279015], [87.76248169, 24.32068062], [87.76007843, 24.31952095], [87.75946045, 24.31688118], [87.76035309, 24.31303978], [87.75849915, 24.30783081], [87.75627899, 24.30359268], [87.75209808, 24.30465126], [87.74819946, 24.30148125], [87.7457428, 24.29980278], [87.74312592, 24.29772186], [87.74046326, 24.29272842], [87.73620605, 24.29199982], [87.73638153, 24.28894043], [87.73304749, 24.28791046], [87.73015594, 24.2876091], [87.72718811, 24.28622055], [87.72395325, 24.28749275], [87.71977234, 24.28803062], [87.71573639, 24.29001045], [87.71031952, 24.29207039], [87.71008301, 24.28657913], [87.7094574, 24.28290939], [87.70833588, 24.28038979], [87.70617676, 24.2781105], [87.70461273, 24.2745018], [87.70543671, 24.27170944], [87.70598602, 24.2678299], [87.70452881, 24.26375961], [87.70263672, 24.25992012], [87.69740295, 24.25972939], [87.69301605, 24.25739098], [87.6886673, 24.25560951], [87.68496704, 24.25284958], [87.68309784, 24.24855042], [87.68135834, 24.24644089], [87.67791748, 24.24645233], [87.67384338, 24.24670029], [87.67067719, 24.24427986], [87.66876984, 24.24274063], [87.6654129, 24.24349022], [87.66190338, 24.24495125], [87.66028595, 24.2419796], [87.6590271, 24.23835754], [87.65703583, 24.23539925], [87.65429688, 24.23658943], [87.6519165, 24.24015045], [87.64985657, 24.24365997], [87.64929962, 24.24662018], [87.64714813, 24.24855995], [87.64173126, 24.24986076], [87.64002991, 24.24603081], [87.63571167, 24.24253082], [87.63658142, 24.23818016], [87.63951874, 24.23472023], [87.643013, 24.23010063], [87.64315796, 24.22459984], [87.64151001, 24.21960068], [87.63844299, 24.21614075], [87.63772583, 24.21158028], [87.64509583, 24.20799065], [87.65278625, 24.20618248], [87.65901947, 24.20740128], [87.6661377, 24.20611191], [87.67095184, 24.20573807], [87.67378998, 24.20049095], [87.67460632, 24.1952095], [87.67830658, 24.19111061], [87.68353271, 24.18905258], [87.68891144, 24.18514061], [87.69255829, 24.18618011], [87.69399261, 24.18197823], [87.69378662, 24.1784687], [87.69667816, 24.17534828], [87.69641113, 24.17131042], [87.69645691, 24.16721153], [87.6932373, 24.16434097], [87.69364166, 24.15917015], [87.69248199, 24.15447044], [87.68956757, 24.1498394], [87.68435669, 24.14916992], [87.68016815, 24.14797974], [87.67353058, 24.15134048], [87.66777802, 24.15143967], [87.66361237, 24.15427971], [87.6569519, 24.15591049], [87.65054321, 24.15452957], [87.6457901, 24.15379906], [87.64067078, 24.15493011], [87.63632965, 24.15738106], [87.63162994, 24.16028976], [87.62754059, 24.16313171], [87.62166595, 24.16386986], [87.61605835, 24.1646595], [87.6104126, 24.16488075], [87.60415649, 24.16399956], [87.59957886, 24.16050911], [87.5955658, 24.15980911], [87.59037781, 24.1600914], [87.58407593, 24.16146088], [87.57975006, 24.16153908], [87.5766983, 24.15888023], [87.56938171, 24.15565109], [87.57142639, 24.15440941], [87.57646942, 24.15275955], [87.58087158, 24.15044022], [87.58602142, 24.14752007], [87.59004211, 24.14410019], [87.59391785, 24.14147949], [87.59794617, 24.1379509], [87.60119629, 24.13517952], [87.6049118, 24.1321106], [87.60761261, 24.12894249], [87.60481262, 24.12656975], [87.60041046, 24.12537003], [87.59541321, 24.12487984], [87.59262085, 24.12424088], [87.58172607, 24.12339973], [87.57952118, 24.11951065], [87.57965088, 24.11501122], [87.57779694, 24.11042023], [87.5748291, 24.1089592], [87.57211304, 24.10971069], [87.5692215, 24.10675049], [87.56949615, 24.10098076], [87.57064819, 24.09547043], [87.5743103, 24.09015083], [87.57644653, 24.08710098], [87.57615662, 24.08526039], [87.57316589, 24.0862999], [87.57021332, 24.08762169], [87.56672668, 24.08641052], [87.56344604, 24.08450127], [87.5597229, 24.08288956], [87.55628204, 24.08230972], [87.55261993, 24.0845108], [87.54825592, 24.08546066], [87.54419708, 24.0865612], [87.53916931, 24.08780098], [87.53449249, 24.09140968], [87.53096771, 24.09486961], [87.53069305, 24.09921074], [87.52986145, 24.10240936], [87.52693939, 24.10378075], [87.52406311, 24.10370827], [87.52130127, 24.10423088], [87.51991272, 24.1058712], [87.51889038, 24.10872078], [87.516922, 24.11100006], [87.51367188, 24.11082077], [87.51052856, 24.1103611], [87.50717926, 24.11128044], [87.50293732, 24.1128006], [87.49951172, 24.11458015], [87.49659729, 24.11580086], [87.49359894, 24.11520958], [87.49310303, 24.11193085], [87.49384308, 24.10815048], [87.49536896, 24.10547066], [87.49656677, 24.1026783], [87.49694824, 24.0993309], [87.49584961, 24.0971508], [87.49365234, 24.09724045], [87.49281311, 24.09547043], [87.49353027, 24.09309006], [87.48964691, 24.09004021], [87.48892212, 24.08819962], [87.49001312, 24.08546829], [87.49324036, 24.08460045], [87.4980011, 24.08435059], [87.50216675, 24.0832901], [87.50578308, 24.08208084], [87.50535583, 24.07942963], [87.50357056, 24.07766914], [87.50260162, 24.07526016], [87.50123596, 24.07331848], [87.49978638, 24.07254028], [87.49685669, 24.07369041], [87.49318695, 24.07473946], [87.48973083, 24.07323074], [87.48890686, 24.06966019], [87.49075317, 24.06657028], [87.49252319, 24.06470108], [87.49423218, 24.06265068], [87.49331665, 24.05924988], [87.49185181, 24.05553055], [87.4912262, 24.05202103], [87.49539185, 24.04997063], [87.50137329, 24.04751015], [87.5042572, 24.04618263], [87.50784302, 24.04566956], [87.50845337, 24.0425396], [87.51055145, 24.03983116], [87.5090332, 24.03467941], [87.50670624, 24.03199959], [87.50393677, 24.03009033], [87.50196075, 24.02815056], [87.50131226, 24.02609062], [87.5013504, 24.02232933], [87.49649048, 24.02316093], [87.49476624, 24.02435112], [87.4912262, 24.02337074], [87.48847961, 24.01933098], [87.48642731, 24.01595116], [87.48275757, 24.0136528], [87.47915649, 24.0141201], [87.47619629, 24.01301193], [87.47345734, 24.01143265], [87.4713974, 24.01089096], [87.46924591, 24.01156235], [87.46733856, 24.01217842], [87.46393585, 24.01262093], [87.46209717, 24.01311111], [87.45926666, 24.01297951], [87.45691681, 24.01406288], [87.45490265, 24.01496124], [87.45226288, 24.01506042], [87.44851685, 24.01634026], [87.44625092, 24.01428986], [87.44316101, 24.01375961], [87.43872833, 24.01251984], [87.43650055, 24.01094246], [87.43383026, 24.00832176], [87.43464661, 24.00686073], [87.43678284, 24.00781059], [87.43844604, 24.00904083], [87.44087219, 24.00946045], [87.44423676, 24.00909996], [87.44676971, 24.00835037], [87.44610596, 24.00696945], [87.44487762, 24.00576019], [87.44246674, 24.00530052], [87.44139862, 24.00323105], [87.44330597, 24.00094032], [87.44676971, 24.00062943], [87.45018768, 23.99999046], [87.45067596, 23.99924088], [87.45487976, 23.99689102], [87.45835876, 23.99349976], [87.45980072, 23.98483276], [87.45796967, 23.98142052], [87.45359802, 23.98339081], [87.44898224, 23.98429108], [87.44547272, 23.98146057], [87.43910217, 23.97813034], [87.43656158, 23.97915077], [87.43398285, 23.98168945], [87.4292984, 23.98186111], [87.42758942, 23.98397064], [87.42735291, 23.98792839], [87.42637634, 23.99032021], [87.42212677, 23.99080086], [87.4185791, 23.98935127], [87.41452789, 23.99084282], [87.4003067, 23.99392128], [87.39427185, 23.99653053], [87.39389038, 23.99924088], [87.38976288, 24.00196266], [87.38234711, 24.00270081], [87.37687683, 24.00317001], [87.37400818, 24.00657845], [87.36479187, 24.00677109], [87.36038971, 24.00734138], [87.35663605, 24.00918961], [87.35484314, 24.00559807], [87.35334778, 24.00225067], [87.35098267, 23.99920273], [87.3502121, 23.99697113], [87.34810638, 23.99579048], [87.3372879, 23.99495125], [87.32787323, 23.99599075], [87.32395935, 23.99706268], [87.31989288, 23.99917984], [87.31788635, 24.00152016], [87.31539154, 24.00442123], [87.31581116, 24.00708961], [87.31828308, 24.00687027], [87.32054138, 24.00927925], [87.32225037, 24.01316261], [87.32417297, 24.01748085], [87.32743073, 24.01662064], [87.3323288, 24.01753998], [87.33319092, 24.0222702], [87.33550262, 24.02386284], [87.33235931, 24.03100967], [87.32628632, 24.03013039], [87.31997681, 24.03144073], [87.31373596, 24.03239059], [87.30877686, 24.0319519], [87.30368042, 24.02937126], [87.29654694, 24.03016281], [87.28956604, 24.03030968], [87.28621674, 24.02717972], [87.28264618, 24.02692986], [87.27915955, 24.02935982], [87.27427673, 24.03184128], [87.26918793, 24.03301048], [87.26387024, 24.03469086], [87.2578125, 24.0354805], [87.25345612, 24.03734016], [87.2490387, 24.04012108], [87.24359894, 24.04211998], [87.23797607, 24.04121971], [87.23480225, 24.03731918], [87.23348236, 24.03268814], [87.23265076, 24.02459908], [87.23536682, 24.01754951], [87.23922729, 24.01478004], [87.24034882, 24.01066017], [87.24059296, 24.00572014], [87.24356842, 24.00101089], [87.24539948, 23.99855042], [87.24581146, 23.99802017], [87.24616241, 23.99765015], [87.24687195, 23.99702072], [87.24727631, 23.99677086], [87.24769592, 23.99653053], [87.24816132, 23.99632072], [87.24862671, 23.99612999], [87.24909973, 23.99599075], [87.24960327, 23.99587059], [87.25009918, 23.99578094], [87.25060272, 23.99572754], [87.251091, 23.99571037], [87.25157928, 23.99572754], [87.25208282, 23.99578094], [87.25260162, 23.99587059], [87.25311279, 23.99599075], [87.25363159, 23.99614906], [87.25408936, 23.99636078], [87.2545166, 23.99661064], [87.25493622, 23.99689102], [87.25531006, 23.99716949], [87.25565338, 23.99751091], [87.25595856, 23.99788094], [87.25621033, 23.99827003], [87.25640869, 23.99909019], [87.25718689, 23.99978065], [87.26081848, 24.00290108], [87.26271057, 23.99912071], [87.26206207, 23.99509048], [87.26692963, 23.98777962], [87.26802826, 23.98463058], [87.26602173, 23.9818306], [87.26072693, 23.97809029], [87.25953674, 23.96992111], [87.26154327, 23.96616936], [87.26452637, 23.9634819], [87.26925659, 23.96532059], [87.27805328, 23.95755959], [87.28666687, 23.95749092], [87.29181671, 23.95569992], [87.2904892, 23.94745255], [87.29193115, 23.93875122], [87.28513336, 23.93388939], [87.28782654, 23.9259491], [87.28768921, 23.92023087], [87.29454803, 23.89857101], [87.2906723, 23.89870071], [87.29258728, 23.89014053], [87.28552246, 23.88361168], [87.28129578, 23.88420105], [87.27832031, 23.88194847], [87.27041626, 23.87294006], [87.26493073, 23.87482834], [87.26174927, 23.87817192], [87.26412964, 23.87997055], [87.26088715, 23.89217949], [87.25630951, 23.89814949], [87.25987244, 23.90211105], [87.25920105, 23.90420151], [87.25666046, 23.90759277], [87.25242615, 23.91011047], [87.24822235, 23.90701103], [87.2443161, 23.90039063], [87.24608612, 23.89493942], [87.24311066, 23.8848629], [87.24530029, 23.88060951], [87.24442291, 23.87807846], [87.24487305, 23.86840057], [87.24904633, 23.86582947], [87.24608612, 23.85658073], [87.24742889, 23.85131073], [87.25152588, 23.84766006], [87.25270081, 23.84286118], [87.25521851, 23.83930016], [87.24572754, 23.82807159], [87.24272919, 23.82616043], [87.23880005, 23.82485008], [87.23375702, 23.82534981], [87.22912598, 23.82300949], [87.21975708, 23.82720947], [87.21855927, 23.83080101], [87.22235107, 23.83483124], [87.22410583, 23.84268951], [87.22796631, 23.84290123], [87.23174286, 23.84456062], [87.23513794, 23.84824181], [87.23623657, 23.85306931], [87.22782898, 23.85530281], [87.22248077, 23.85763931], [87.21675873, 23.85094261], [87.21282196, 23.85027122], [87.2073288, 23.85301018], [87.20302582, 23.84617233], [87.19944763, 23.84749985], [87.19433594, 23.84212112], [87.19164276, 23.84044266], [87.18856812, 23.84083748], [87.18869781, 23.84631157], [87.19541931, 23.8508606], [87.19565582, 23.85425949], [87.18736267, 23.85717964], [87.18427277, 23.852911], [87.18060303, 23.85153008], [87.17662048, 23.85246277], [87.17295074, 23.85622025], [87.16911316, 23.8577919], [87.16668701, 23.8604908], [87.1566925, 23.86488914], [87.1529007, 23.86559105], [87.14750671, 23.86268234], [87.14076996, 23.86510086], [87.13860321, 23.86740112], [87.13581848, 23.86813927], [87.13092804, 23.86696053], [87.12786102, 23.86244011], [87.12963104, 23.8581295], [87.12944031, 23.85490036], [87.13033295, 23.85091019], [87.13772583, 23.84580994], [87.14581299, 23.83661079], [87.15399933, 23.82574081], [87.15912628, 23.82830048], [87.16220856, 23.82761955], [87.16644287, 23.81958961], [87.15592957, 23.80372047], [87.15364838, 23.79845047], [87.14874268, 23.79437065], [87.14354706, 23.79636192], [87.13920593, 23.80006027], [87.13362885, 23.79634094], [87.12416077, 23.79503822], [87.11299896, 23.79681015], [87.11025238, 23.79906273], [87.1146698, 23.80008125], [87.11633301, 23.80196953], [87.1160965, 23.80480194], [87.11258698, 23.80553818], [87.10771179, 23.80187035], [87.10592651, 23.79952049], [87.09572601, 23.80948067], [87.09130096, 23.80961037], [87.08840179, 23.80780983], [87.0845108, 23.80526924], [87.07660675, 23.80911064], [87.07276917, 23.81233978], [87.06423187, 23.81349945], [87.0569458, 23.81625938], [87.03440857, 23.83682823], [87.02243042, 23.84052277], [87.01345825, 23.8469429], [87.00205994, 23.85248947], [86.99455261, 23.85353088], [86.98013306, 23.85638046], [86.97187805, 23.86283112], [86.96691132, 23.86529922], [86.96304321, 23.8647728], [86.95957184, 23.86231041], [86.95771027, 23.85913086], [86.95575714, 23.84961128], [86.95123291, 23.84587097], [86.94319916, 23.84286118], [86.93637848, 23.84486008], [86.92813873, 23.84995842], [86.92540741, 23.85384178], [86.92415619, 23.86588097], [86.90688324, 23.87951088], [86.90365601, 23.8789711], [86.8950119, 23.87995148], [86.89138031, 23.87639046], [86.88461304, 23.87335014], [86.88008881, 23.86650085], [86.87526703, 23.86238098], [86.8753891, 23.85745049], [86.88226318, 23.85661125], [86.88017273, 23.84220123], [86.88478851, 23.83436966], [86.88474274, 23.83049011], [86.88690948, 23.82732964], [86.88768768, 23.82216072], [86.88437653, 23.81920052], [86.88226318, 23.81447983], [86.87693024, 23.81344986], [86.87693024, 23.82133102], [86.87329102, 23.82723045], [86.87309265, 23.83448029], [86.87121582, 23.84418106], [86.86084747, 23.84217262], [86.85704803, 23.83950043], [86.8544693, 23.83247757], [86.84442902, 23.82185173], [86.83500671, 23.81925964], [86.82591248, 23.81319809], [86.82077026, 23.81130981], [86.813797, 23.81216049], [86.80930328, 23.81413078], [86.80702209, 23.81814957], [86.80786896, 23.82455254], [86.80647278, 23.8281002], [86.80367279, 23.83068085], [86.80018616, 23.83263016], [86.79738617, 23.83186913], [86.79283905, 23.83138084], [86.79220581, 23.82726288], [86.79747009, 23.82403946], [86.80097198, 23.8133297], [86.79769135, 23.79771805], [86.80841064, 23.78827095], [86.81671906, 23.77614975], [86.81977081, 23.76107025], [86.81933594, 23.75226974], [86.81610107, 23.74483109], [86.81163025, 23.74480057], [86.80800629, 23.74381065], [86.80451202, 23.73985291], [86.79837036, 23.71634102], [86.79351044, 23.70601273], [86.79093933, 23.69849968], [86.79305267, 23.69502258], [86.79567719, 23.69347954], [86.79203796, 23.6873703], [86.77269745, 23.68188095], [86.75850677, 23.67848015], [86.73812866, 23.6776104], [86.73591614, 23.6790905], [86.73654938, 23.68876076], [86.73169708, 23.69379044], [86.71100616, 23.69722939], [86.69384766, 23.69452095], [86.68334961, 23.68974113], [86.66873169, 23.68605042], [86.64884949, 23.68287086], [86.63334656, 23.6757412], [86.62444305, 23.67276955], [86.61580658, 23.6716404], [86.59160614, 23.67115021], [86.58796692, 23.66908073], [86.58850861, 23.66544151], [86.59062195, 23.66224098], [86.58310699, 23.65884018], [86.56524658, 23.64627075], [86.55201721, 23.64009285], [86.53743744, 23.63462067], [86.52865601, 23.62898064], [86.5236969, 23.62836075], [86.51187897, 23.62906075], [86.50171661, 23.63157845], [86.48129272, 23.63503838], [86.47162628, 23.6312809], [86.46642303, 23.6296196], [86.44490814, 23.63153267], [86.43988037, 23.62961006], [86.43847656, 23.62779236], [86.43791962, 23.62417984], [86.43959808, 23.61667252], [86.43963623, 23.60910034], [86.43456268, 23.60845184], [86.43045807, 23.61111069], [86.42727661, 23.61033058], [86.42466736, 23.60491943], [86.41821289, 23.60341263], [86.41356659, 23.60133171], [86.41036987, 23.59802246], [86.40622711, 23.58798027], [86.40019226, 23.58945274], [86.38941956, 23.58877945], [86.38697052, 23.58535957], [86.38092804, 23.58436012], [86.38220215, 23.5789299], [86.38176727, 23.57550049], [86.38288116, 23.57201958], [86.37812042, 23.56883812], [86.37486267, 23.56851959], [86.37304688, 23.5613308], [86.36789703, 23.55920982], [86.36480713, 23.55705261], [86.36422729, 23.55134964], [86.36160278, 23.54966164], [86.36048126, 23.54612923], [86.35797119, 23.5430603], [86.36048126, 23.53848076], [86.3587265, 23.53363991], [86.35965729, 23.53067017], [86.36383057, 23.52807045], [86.36495209, 23.52548981], [86.36765289, 23.52255821], [86.36701202, 23.51885986], [86.36503601, 23.51543808], [86.35690308, 23.51288986], [86.35706329, 23.51025009], [86.35370636, 23.49641991], [86.3585968, 23.48958969], [86.36205292, 23.49188995], [86.37059784, 23.49026108], [86.37214661, 23.48607826], [86.37194824, 23.48266029], [86.37052155, 23.48163986], [86.36850739, 23.48396111], [86.36440277, 23.48214912], [86.35549927, 23.48155975], [86.34897614, 23.47249985], [86.35222626, 23.46819115], [86.35183716, 23.46363068], [86.34703827, 23.46116257], [86.33789825, 23.46109009], [86.33834076, 23.45697975], [86.34041595, 23.45239258], [86.33135986, 23.44724083], [86.32926941, 23.44824028], [86.32863617, 23.45498085], [86.32621002, 23.45756149], [86.3212204, 23.45448112], [86.31511688, 23.45267105], [86.31208801, 23.44860077], [86.30647278, 23.44820976], [86.30014801, 23.44371033], [86.30034637, 23.4406395], [86.30578613, 23.43618011], [86.30998993, 23.43761063], [86.31227875, 23.43732071], [86.31286621, 23.43143082], [86.3142395, 23.42828941], [86.3133316, 23.42606163], [86.30000305, 23.42006111], [86.28967285, 23.42287064], [86.28237152, 23.42745972], [86.28115082, 23.43544769], [86.2806778, 23.43960953], [86.2784729, 23.44112015], [86.27348328, 23.43894958], [86.26719666, 23.44000053], [86.26629639, 23.43795967], [86.26374817, 23.43657112], [86.25784302, 23.43821907], [86.25244141, 23.43749046], [86.25006104, 23.43559074], [86.2466507, 23.4341526], [86.24794769, 23.43083954], [86.25305176, 23.42485046], [86.25083923, 23.42221069], [86.24646759, 23.41918945], [86.24317932, 23.41958046], [86.23989105, 23.42258072], [86.2390976, 23.42571068], [86.23954773, 23.43168068], [86.23110962, 23.42951965], [86.22466278, 23.43568039], [86.22502136, 23.4428196], [86.22735596, 23.44960976], [86.23517609, 23.45598984], [86.23874664, 23.46969032], [86.23226929, 23.47072029], [86.22532654, 23.46988106], [86.22319794, 23.46480751], [86.22406006, 23.4572506], [86.22097778, 23.4559803], [86.20970917, 23.45923042], [86.20326233, 23.45868111], [86.19956207, 23.46404839], [86.19536591, 23.46347046], [86.19180298, 23.46442032], [86.18676758, 23.46837044], [86.18102264, 23.46692085], [86.1787796, 23.46772957], [86.17914581, 23.47512054], [86.17233276, 23.47854042], [86.16792297, 23.47608948], [86.15296173, 23.47698975], [86.1455307, 23.47307014], [86.14267731, 23.47733116], [86.14331055, 23.4812603], [86.14585876, 23.48612976], [86.14517975, 23.49398994], [86.15511322, 23.5042305], [86.15328979, 23.50975037], [86.15455627, 23.51914978], [86.14292908, 23.52734184], [86.14427948, 23.53524017], [86.14969635, 23.54117966], [86.15273285, 23.5482502], [86.15326691, 23.55159187], [86.14846802, 23.55550957], [86.14628601, 23.55866051], [86.14842987, 23.56393051], [86.14819336, 23.56542015], [86.14476776, 23.56777191], [86.13861084, 23.57002068], [86.13607025, 23.56926918], [86.13172913, 23.56623077], [86.1266861, 23.56674957], [86.11943817, 23.57391167], [86.1102066, 23.57073021], [86.10485077, 23.57196045], [86.10154724, 23.57389832], [86.09835815, 23.570961], [86.09358215, 23.57001114], [86.08795929, 23.5676403], [86.08268738, 23.56857109], [86.07276917, 23.56822014], [86.07144165, 23.57847977], [86.06530762, 23.58073044], [86.05133057, 23.57889938], [86.04686737, 23.58386993], [86.0373764, 23.58345985], [86.03533936, 23.57509041], [86.03009796, 23.57476044], [86.02511597, 23.57229805], [86.01760864, 23.56361008], [86.01100922, 23.56124115], [86.01077271, 23.55164909], [86.02110291, 23.54549026], [86.01854706, 23.54243088], [86.02506256, 23.53174973], [86.02703857, 23.52425003], [86.03156281, 23.52096748], [86.03269196, 23.51802254], [86.03276825, 23.50484085], [86.04860687, 23.5026207], [86.0508728, 23.50155067], [86.05150604, 23.49900055], [86.04722595, 23.49364281], [86.04136658, 23.49024963], [86.03575134, 23.49032021], [86.02906799, 23.48715973], [86.02559662, 23.48808098], [86.02037048, 23.48791122], [86.01545715, 23.48516083], [86.01023102, 23.48315048], [86.00557709, 23.48269081], [86.00137329, 23.47879982], [85.99475098, 23.47553253], [85.99037933, 23.47637939], [85.97566223, 23.47072983], [85.96781921, 23.46537018], [85.95717621, 23.46193123], [85.95289612, 23.45962906], [85.94979858, 23.45545006], [85.94390869, 23.45462036], [85.9379425, 23.45513916], [85.91752625, 23.46235085], [85.91269684, 23.46729851], [85.90637207, 23.47175026], [85.89125061, 23.47598076], [85.87757874, 23.4758606], [85.87412262, 23.47623062], [85.87007904, 23.47480011], [85.86602783, 23.4702301], [85.86354828, 23.45948982], [85.86206055, 23.45496941], [85.85954285, 23.45095062], [85.85975647, 23.44161987], [85.86089325, 23.42818069], [85.86287689, 23.40997124], [85.8722229, 23.40853119], [85.87419891, 23.41050911], [85.87845612, 23.40802956], [85.8817215, 23.40372086], [85.8782959, 23.4021492], [85.87731171, 23.40043068], [85.88478088, 23.38734055], [85.88212585, 23.38371086], [85.88247681, 23.3810997], [85.89057922, 23.38103294], [85.89434814, 23.37968063], [85.89585876, 23.37697983], [85.89569092, 23.37059021], [85.89337921, 23.36953926], [85.88527679, 23.37375832], [85.87503052, 23.36828041], [85.86625671, 23.36484909], [85.8666687, 23.36148071], [85.87301636, 23.35689926], [85.87277985, 23.35527992], [85.8708725, 23.35251999], [85.87159729, 23.33015823], [85.87535095, 23.32874107], [85.87751007, 23.32625961], [85.87798309, 23.32370949], [85.87523651, 23.32067108], [85.86830139, 23.31587982], [85.86077118, 23.31497955], [85.86149597, 23.30332947], [85.85785675, 23.3010807], [85.85240936, 23.2944603], [85.84446716, 23.28956985], [85.84173584, 23.28432083], [85.83912659, 23.2820797], [85.83365631, 23.2806797], [85.82636261, 23.26312065], [85.83067322, 23.24323082], [85.83184052, 23.21783066], [85.83068848, 23.21397018], [85.83072662, 23.21063995], [85.83281708, 23.20614052], [85.83371735, 23.20190048], [85.83155823, 23.19511986], [85.83241272, 23.1926403], [85.83500671, 23.19210052], [85.84391022, 23.19412994], [85.85192108, 23.19255066], [85.85752106, 23.19436264], [85.85984802, 23.19239044], [85.87721252, 23.17296028], [85.87780762, 23.17101288], [85.87657928, 23.16127968], [85.87731171, 23.15866089], [85.88640594, 23.15335083], [85.88916016, 23.1517601], [85.900383, 23.1480999], [85.90673828, 23.14207077], [85.91160583, 23.13358116], [85.91499329, 23.12952995], [85.91781616, 23.1311512], [85.91957092, 23.12695122], [85.92147064, 23.12593079], [85.92202759, 23.12939835], [85.92581177, 23.13065147], [85.93628693, 23.1296711], [85.94380951, 23.12947083], [85.9467392, 23.13088036], [85.94790649, 23.13396072], [85.95155334, 23.13816071], [85.95629883, 23.13947105], [85.9593277, 23.13977242], [85.97048187, 23.14002991], [85.98194122, 23.14590073], [85.99006653, 23.14628029], [85.99555969, 23.14442062], [86.00258636, 23.14616966], [86.00609589, 23.14490128], [86.00971985, 23.14497948], [86.01389313, 23.14164162], [86.01799774, 23.14048958], [86.0247879, 23.14319992], [86.02835846, 23.1457119], [86.03227234, 23.1450901], [86.03692627, 23.14361], [86.04199219, 23.13596916], [86.04839325, 23.12916946], [86.04897308, 23.12484932], [86.04653931, 23.12068748], [86.04424286, 23.11186028], [86.047966, 23.10868073], [86.05928802, 23.1055603], [86.07000732, 23.1014328], [86.08096313, 23.10429955], [86.08322144, 23.10093117], [86.08358765, 23.09859085], [86.09179688, 23.09077072], [86.09710693, 23.09166908], [86.10476685, 23.08889961], [86.10640717, 23.09028816], [86.11418152, 23.09196091], [86.11569214, 23.09363174], [86.12735748, 23.08908081], [86.12864685, 23.0857296], [86.13656616, 23.08310127], [86.13803864, 23.08048058], [86.13363647, 23.06990051], [86.13456726, 23.0629406], [86.1381073, 23.05932999], [86.14604187, 23.05572128], [86.14833069, 23.05266953], [86.15001678, 23.04089928], [86.15365601, 23.03722954], [86.16015625, 23.03906059], [86.162323, 23.03380966], [86.1667099, 23.02695084], [86.17249298, 23.02305031], [86.17562866, 23.01299095], [86.17838287, 23.01172066], [86.18118286, 23.01296043], [86.2008667, 23.01514244], [86.20436096, 23.0132103], [86.20024109, 23.00974846], [86.20381165, 22.99785805], [86.20642853, 22.99407005], [86.21247864, 22.9918499], [86.21697235, 22.99160957], [86.22706604, 22.99287033], [86.23095703, 22.99214172], [86.23448181, 22.99336815], [86.2386322, 22.99488831], [86.24508667, 22.99546051], [86.25086212, 22.99497986], [86.2612915, 22.99553108], [86.26378632, 22.99802971], [86.26328278, 22.99936104], [86.26500702, 23.00040054], [86.26972198, 23.00443077], [86.27350616, 23.00653076], [86.27552032, 23.00860023], [86.27937317, 23.0107193], [86.28475952, 23.01086044], [86.29199219, 23.0100708], [86.29191589, 23.00905037], [86.29400635, 23.00811005], [86.29482269, 23.00914192], [86.29638672, 23.0102005], [86.29751587, 23.01325989], [86.29825592, 23.01328278], [86.30030823, 23.01234055], [86.30069733, 23.01035118], [86.30042267, 23.00831985], [86.30020142, 23.00630188], [86.30211639, 23.00335121], [86.3059082, 23.00248909], [86.30992889, 23.00065041], [86.30989075, 22.9981308], [86.31217957, 22.99521065], [86.31529236, 22.99555969], [86.32585907, 22.9924202], [86.33215332, 22.98890114], [86.3347168, 22.98935127], [86.34133148, 22.99328041], [86.34648895, 22.9930191], [86.35048676, 22.98917961], [86.35160828, 22.99491119], [86.35997772, 22.99668121], [86.3632431, 22.99274826], [86.36949921, 22.99431038], [86.38044739, 22.99074936], [86.38096619, 22.98441124], [86.38360596, 22.98013115], [86.38730621, 22.97673035], [86.39303589, 22.97423935], [86.3968811, 22.97781944], [86.4003067, 22.98314095], [86.41052246, 22.98701859], [86.41628265, 22.99479103], [86.43170166, 22.99032974], [86.44056702, 22.99007988], [86.44168854, 22.98732948], [86.44522858, 22.98509026], [86.44779205, 22.9871006], [86.45108795, 22.98760986], [86.46308899, 22.98521805], [86.46618652, 22.98863029], [86.4749527, 22.98566055], [86.47936249, 22.98884964], [86.4973526, 22.98990822], [86.49730682, 22.98314857], [86.50401306, 22.97801971], [86.50762177, 22.97277069], [86.49991608, 22.96854019], [86.51223755, 22.96626091], [86.51876068, 22.96811295], [86.52271271, 22.97215843], [86.52076721, 22.97282982], [86.5341568, 22.98135948], [86.5402832, 22.9872303], [86.54203033, 22.97434044], [86.53774261, 22.96583939], [86.53851318, 22.96186829], [86.53244781, 22.96223259], [86.52662659, 22.96087074], [86.52757263, 22.95792961], [86.52339172, 22.94868088], [86.51835632, 22.94433022], [86.51272583, 22.94619179], [86.50757599, 22.94535828], [86.49868774, 22.94774055], [86.49662018, 22.94754028], [86.49772644, 22.94512939], [86.49577332, 22.94129181], [86.49401093, 22.94148827], [86.49246979, 22.94423103], [86.48943329, 22.94406128], [86.48680115, 22.93554115], [86.48452759, 22.9342804], [86.4838028, 22.93824959], [86.47872162, 22.9405899], [86.47344971, 22.94408035], [86.4743576, 22.94882965], [86.47042084, 22.94944954], [86.47012329, 22.94662285], [86.46206665, 22.94423103], [86.4580307, 22.93879128], [86.45820618, 22.93296051], [86.45104218, 22.93046951], [86.43708801, 22.92728996], [86.43282318, 22.92340279], [86.43113708, 22.92013931], [86.43241882, 22.91576958], [86.44845581, 22.90192032], [86.46234894, 22.89898109], [86.46304321, 22.89663124], [86.45101929, 22.88297081], [86.44696045, 22.8834095], [86.44928741, 22.87705994], [86.44667053, 22.86944962], [86.44769287, 22.86173058], [86.44687653, 22.85877991], [86.43283844, 22.8604908], [86.43126678, 22.84638023], [86.43321991, 22.84058952], [86.43300629, 22.83533287], [86.43390656, 22.82859039], [86.42159271, 22.80882072], [86.41796875, 22.78981972], [86.4126358, 22.78643036], [86.41615295, 22.77650833], [86.42198944, 22.7741909], [86.42887115, 22.76843071], [86.43982697, 22.76268005], [86.4438858, 22.7585907], [86.45401001, 22.75963974], [86.46604156, 22.74645042], [86.46666718, 22.74023056], [86.47001648, 22.73740768], [86.47898102, 22.72239113], [86.48162079, 22.72474098], [86.48774719, 22.72328949], [86.48993683, 22.71981049], [86.49653625, 22.7154808], [86.50035858, 22.7110405], [86.5065918, 22.70152092], [86.50955963, 22.70226288], [86.50805664, 22.70816994], [86.50995636, 22.71606064], [86.51644897, 22.71478081], [86.52017975, 22.71790123], [86.53369904, 22.71657944], [86.53925323, 22.72064972], [86.54634857, 22.71528816], [86.5495224, 22.7109108], [86.55510712, 22.70788002], [86.57401276, 22.69463921], [86.58078003, 22.68899155], [86.59121704, 22.68864059], [86.59670258, 22.68544006], [86.6029129, 22.67983055], [86.61016083, 22.67741966], [86.61786652, 22.67338943], [86.62236786, 22.66631126], [86.63037872, 22.66250992], [86.63668823, 22.65512085], [86.63548279, 22.64719963], [86.6367569, 22.63081932], [86.63510132, 22.62265968], [86.63239288, 22.60997963], [86.63400269, 22.60401154], [86.63432312, 22.59725952], [86.63897705, 22.59375], [86.64827728, 22.59160995], [86.65109253, 22.58426285], [86.64932251, 22.58204079], [86.65170288, 22.57579041], [86.65727997, 22.57270813], [86.66139984, 22.57443047], [86.67279816, 22.57238007], [86.67388916, 22.57349014], [86.68340302, 22.57676125], [86.70601654, 22.58036041], [86.72767639, 22.57463837], [86.75598907, 22.57427025], [86.7599411, 22.57242966], [86.76344299, 22.5646286], [86.76741791, 22.56088829], [86.76696014, 22.55603027], [86.76348114, 22.55252075], [86.76451874, 22.55063057], [86.77126312, 22.54831123], [86.77137756, 22.54583931], [86.77630615, 22.54700851], [86.77789307, 22.54541016], [86.78407288, 22.54424095], [86.78617096, 22.53741074], [86.78279114, 22.5357399], [86.78531647, 22.53244019], [86.78520966, 22.52931023], [86.7828064, 22.52437019], [86.789711, 22.52038002], [86.79139709, 22.51666069], [86.79177856, 22.51343918], [86.78930664, 22.50965118], [86.78962708, 22.50757027], [86.79860687, 22.49882126], [86.79096222, 22.49362946], [86.79296112, 22.49060059], [86.79701233, 22.48875809], [86.797966, 22.48699188], [86.79801178, 22.48398972], [86.79556274, 22.47968292], [86.78922272, 22.47451019], [86.7855072, 22.47665024], [86.78251648, 22.47735023], [86.77571106, 22.47730064], [86.76953125, 22.4759407], [86.76066589, 22.47891045], [86.75332642, 22.48011971], [86.74826813, 22.47866058], [86.7454071, 22.4756794], [86.74513245, 22.47053909], [86.74900055, 22.46033287], [86.7514801, 22.45067978], [86.75744629, 22.44638062], [86.75707245, 22.44244957], [86.75794983, 22.43565941], [86.76226044, 22.42523193], [86.76389313, 22.42288971], [86.76925659, 22.42158127], [86.77867889, 22.42149162], [86.78897858, 22.41825294], [86.8052597, 22.41649055], [86.81841278, 22.41230011], [86.83090973, 22.40637016], [86.83875275, 22.40135956], [86.84393311, 22.39606094], [86.8449173, 22.39232826], [86.84359741, 22.38764191], [86.84047699, 22.3842392], [86.83822632, 22.37861061], [86.84094238, 22.36902046], [86.83634186, 22.36087036], [86.82894135, 22.34150124], [86.83006287, 22.33839989], [86.82853699, 22.32949066], [86.82919312, 22.32459068], [86.8368988, 22.31675148], [86.84066772, 22.31381035], [86.84719086, 22.31315041], [86.86295319, 22.30381966], [86.86808014, 22.30458069], [86.87121582, 22.30266953], [86.87258911, 22.2987709], [86.88080597, 22.29640961], [86.88511658, 22.29670906], [86.88623047, 22.29412079], [86.88684845, 22.28668976], [86.88845062, 22.28141022], [86.88860321, 22.27569962], [86.88796234, 22.26958275], [86.88562775, 22.26890945], [86.88555908, 22.26342964], [86.88667297, 22.25900078], [86.88568115, 22.25212097], [86.87313843, 22.25447083], [86.86904907, 22.25464058], [86.86460876, 22.25348282], [86.85835266, 22.25443077], [86.85423279, 22.25678062], [86.85069275, 22.26049042], [86.85015106, 22.25926971], [86.84127045, 22.2571106], [86.83605194, 22.26078987], [86.83371735, 22.25959969], [86.82842255, 22.25922966], [86.82280731, 22.26132965], [86.82034302, 22.26061058], [86.81912231, 22.25354958], [86.81633759, 22.2493], [86.81382751, 22.2580204], [86.81256104, 22.25928116], [86.81186676, 22.26393127], [86.8113327, 22.25948143], [86.80919647, 22.25379944], [86.80996704, 22.24954987], [86.80895233, 22.2464695], [86.80744171, 22.24582291], [86.80660248, 22.24378014], [86.80394745, 22.24397087], [86.80242157, 22.24180984], [86.79960632, 22.24097252], [86.79691315, 22.24306107], [86.79650879, 22.24508095], [86.79846191, 22.24544907], [86.79641724, 22.24991035], [86.80062866, 22.26192284], [86.79026794, 22.26280022], [86.79068756, 22.25323105], [86.79316711, 22.24398994], [86.79283142, 22.23872948], [86.79756165, 22.23394966], [86.7995224, 22.23518944], [86.80137634, 22.23863029], [86.80986786, 22.23800278], [86.8091507, 22.2331028], [86.80011749, 22.21363068], [86.79136658, 22.21754074], [86.78594208, 22.21405029], [86.78356934, 22.21165085], [86.77906036, 22.21152115], [86.77601624, 22.21377945], [86.77892303, 22.22171974], [86.78250122, 22.22536278], [86.79115295, 22.22030067], [86.79220581, 22.22384262], [86.78681946, 22.2293396], [86.77996826, 22.23172188], [86.77588654, 22.23154068], [86.77275085, 22.23034286], [86.77207184, 22.22768021], [86.77455902, 22.2233696], [86.77522278, 22.21462822], [86.76992035, 22.21455002], [86.76703644, 22.21134186], [86.75509644, 22.20798111], [86.74780273, 22.20798111], [86.74106598, 22.21080971], [86.73375702, 22.21121979], [86.72534943, 22.21350098], [86.72278595, 22.21524811]]]}}, {\\\"id\\\": \\\"14\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.16_1\\\", \\\"HASC_1\\\": \\\"IN.KA\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Karnataka\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Maisur|Mysore\\\", \\\"apm25_popweighted\\\": -6.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 650.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1244.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -594.0, \\\"geo-id\\\": 14, \\\"hpm25_child_popweighted\\\": -127.2, \\\"hpm25_female_popweighted\\\": -146.2, \\\"hpm25_male_popweighted\\\": -105.3, \\\"location\\\": \\\"Karnataka\\\", \\\"mort_apm25_6cod_mean_total\\\": 12963.0, \\\"mort_hpm25_6cod_mean_total\\\": -25021.0, \\\"mort_tpm25_6cod_mean_total\\\": -12058.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[74.67069244, 13.3829174], [74.67069244, 13.38319302], [74.67152405, 13.38319302], [74.67152405, 13.3829174], [74.67180634, 13.3829174], [74.67180634, 13.38263893], [74.67208099, 13.38264084], [74.67208099, 13.38236141], [74.67236328, 13.38236141], [74.67236328, 13.38208294], [74.67272186, 13.38208294], [74.67346954, 13.38208294], [74.67346954, 13.38180542], [74.67363739, 13.38180542], [74.67375183, 13.38180542], [74.67375183, 13.38152695], [74.67391205, 13.38152885], [74.67402649, 13.38153172], [74.67402649, 13.38126945], [74.67430878, 13.38125134], [74.67430878, 13.38097095], [74.67458344, 13.38097095], [74.67458344, 13.38069534], [74.67485809, 13.38069534], [74.67485809, 13.37959194], [74.67485809, 13.37791729], [74.67457581, 13.3779192], [74.67457581, 13.3773613], [74.67485809, 13.3773613], [74.67485809, 13.37652874], [74.67514038, 13.37653065], [74.67514038, 13.37569046], [74.67346954, 13.37569046], [74.67346954, 13.37597275], [74.67318726, 13.37597275], [74.67318726, 13.37653065], [74.67292023, 13.37653065], [74.67292023, 13.37681103], [74.67263794, 13.37680531], [74.67263794, 13.37708282], [74.67236328, 13.37708282], [74.67236328, 13.3773613], [74.67208099, 13.3773613], [74.67208099, 13.3779192], [74.67180634, 13.37791729], [74.67180634, 13.37847328], [74.67151642, 13.37847137], [74.67151642, 13.37903118], [74.67124939, 13.37903118], [74.67124939, 13.37931156], [74.67097473, 13.37930489], [74.67097473, 13.37958336], [74.67041779, 13.37958336], [74.67041779, 13.37986088], [74.67014313, 13.37985039], [74.67014313, 13.38014126], [74.67041779, 13.38013935], [74.67041779, 13.38069534], [74.6701355, 13.38069534], [74.6701355, 13.38097095], [74.6709671, 13.38097095], [74.6709671, 13.38153172], [74.67069244, 13.38152695], [74.67069244, 13.38171196], [74.67069244, 13.38208294], [74.67041779, 13.38208294], [74.67041779, 13.3829174], [74.67069244, 13.3829174]]], [[[74.68958282, 13.33375168], [74.68958282, 13.33403015], [74.69069672, 13.33403015], [74.69069672, 13.33375168], [74.69097137, 13.33375168], [74.69097137, 13.33319092], [74.69125366, 13.33319569], [74.69125366, 13.33291531], [74.69152832, 13.33292198], [74.69152832, 13.33235931], [74.69180298, 13.33236122], [74.69180298, 13.33208275], [74.69208527, 13.33208275], [74.69208527, 13.3316412], [74.69208527, 13.33152676], [74.69235992, 13.33152962], [74.69235992, 13.33069134], [74.68985748, 13.33069324], [74.68985748, 13.33250046], [74.68985748, 13.33375168], [74.68958282, 13.33375168]]], [[[74.68763733, 13.34069443], [74.68763733, 13.34097195], [74.68902588, 13.34097195], [74.68902588, 13.33930588], [74.68930817, 13.33931065], [74.68930817, 13.33875179], [74.68958282, 13.33875179], [74.68958282, 13.33819103], [74.68985748, 13.33819389], [74.68985748, 13.33720016], [74.68985748, 13.33541775], [74.68902588, 13.33541965], [74.68902588, 13.33514023], [74.6886673, 13.33514023], [74.68763733, 13.33514023], [74.68763733, 13.33569431], [74.68819427, 13.33569431], [74.68819427, 13.33597183], [74.68846893, 13.33597183], [74.68846893, 13.33681011], [74.68791962, 13.3368063], [74.68791962, 13.33708382], [74.68736267, 13.33708382], [74.68736267, 13.3368063], [74.68569183, 13.3368063], [74.68569183, 13.33708382], [74.68597412, 13.33708382], [74.68597412, 13.33736229], [74.68653107, 13.33736038], [74.68653107, 13.33763981], [74.68681335, 13.33763981], [74.68681335, 13.33903027], [74.68708038, 13.33903027], [74.68708038, 13.34042263], [74.68736267, 13.34041595], [74.68736267, 13.34069443], [74.68763733, 13.34069443]]], [[[74.68152618, 13.34735966], [74.68152618, 13.3484726], [74.68264008, 13.3484726], [74.68264008, 13.34819508], [74.68291473, 13.34819508], [74.68291473, 13.34763908], [74.68319702, 13.34764099], [74.68319702, 13.34708023], [74.68347168, 13.34708214], [74.68347168, 13.34652901], [74.68374634, 13.34653091], [74.68374634, 13.34589005], [74.68374634, 13.34569359], [74.68402863, 13.34569359], [74.68402863, 13.3451376], [74.68486023, 13.34514141], [74.68486023, 13.34486008], [74.68514252, 13.34486008], [74.68514252, 13.3445797], [74.68541718, 13.34458447], [74.68541718, 13.34402847], [74.68569183, 13.34403133], [74.68569183, 13.34374142], [74.68597412, 13.34375], [74.68597412, 13.34347153], [74.68624878, 13.34347153], [74.68624878, 13.34319401], [74.68653107, 13.34319401], [74.68653107, 13.34291553], [74.68681335, 13.34292126], [74.68681335, 13.34235954], [74.68708038, 13.3423624], [74.68708038, 13.34208202], [74.68736267, 13.34208202], [74.68736267, 13.34152794], [74.68708038, 13.34153271], [74.68708038, 13.34125042], [74.68653107, 13.34125042], [74.68653107, 13.34097195], [74.68569183, 13.34097195], [74.68569183, 13.34069443], [74.68486023, 13.34068012], [74.68486023, 13.34153271], [74.68514252, 13.34152794], [74.68514252, 13.3423624], [74.68374634, 13.34235954], [74.68374634, 13.34263992], [74.68347168, 13.34263992], [74.68347168, 13.34292126], [74.68282318, 13.34291553], [74.68152618, 13.34291553], [74.68152618, 13.34319401], [74.68180084, 13.34319019], [74.68180084, 13.34403133], [74.68152618, 13.34403133], [74.68152618, 13.34431076], [74.68125153, 13.34430599], [74.68125153, 13.34458447], [74.68096924, 13.3445797], [74.68096924, 13.34486008], [74.68235779, 13.34486008], [74.68235779, 13.34514141], [74.68208313, 13.3451376], [74.68208313, 13.34569359], [74.68180084, 13.34568977], [74.68180847, 13.34735966], [74.68152618, 13.34735966]]], [[[74.32624817, 14.02069473], [74.32624817, 14.02041721], [74.32682037, 14.02042103], [74.32682037, 14.01986027], [74.32707977, 14.01986027], [74.32707977, 14.01958466], [74.32736206, 14.01958466], [74.32736206, 14.01930428], [74.32763672, 14.01931095], [74.32763672, 14.01903057], [74.32791901, 14.01903057], [74.32791901, 14.01875114], [74.32958984, 14.01875114], [74.32958221, 14.01847172], [74.3298645, 14.01847172], [74.3298645, 14.0181942], [74.33041382, 14.0181942], [74.33041382, 14.01680565], [74.33013916, 14.01681137], [74.33013916, 14.01653099], [74.32985687, 14.01653099], [74.32985687, 14.01542091], [74.32958984, 14.01542091], [74.32958984, 14.01513958], [74.32930756, 14.01513958], [74.32930756, 14.01485062], [74.32902527, 14.01486015], [74.32902527, 14.01458359], [74.32847595, 14.01458359], [74.32847595, 14.01375008], [74.32875061, 14.01375008], [74.32875061, 14.01292038], [74.32847595, 14.01292038], [74.32847595, 14.01264], [74.32875061, 14.01264], [74.32875061, 14.01235962], [74.32847595, 14.01236153], [74.32847595, 14.01180553], [74.32791901, 14.01181126], [74.32791901, 14.01152992], [74.32763672, 14.01152992], [74.32763672, 14.01124954], [74.32653046, 14.01124954], [74.32653046, 14.01152992], [74.32596588, 14.01152992], [74.32596588, 14.01181126], [74.32569122, 14.01180553], [74.32569122, 14.01236153], [74.32541656, 14.01235962], [74.32541656, 14.01292038], [74.32569122, 14.01291561], [74.32569122, 14.01319408], [74.32541656, 14.01318932], [74.32541656, 14.01375008], [74.32514191, 14.01375008], [74.32514191, 14.01431084], [74.32458496, 14.01430607], [74.32458496, 14.01458359], [74.32430267, 14.01458168], [74.32430267, 14.01513958], [74.32375336, 14.01513958], [74.32375336, 14.01542091], [74.32345581, 14.01542091], [74.32345581, 14.01735973], [74.32319641, 14.01735973], [74.32319641, 14.01764107], [74.32347107, 14.01763821], [74.32347107, 14.01847172], [74.32375336, 14.01847172], [74.32375336, 14.01958466], [74.32402802, 14.01958179], [74.32402802, 14.02042103], [74.32458496, 14.02041721], [74.32458496, 14.02069473], [74.32624817, 14.02069473]]], [[[74.48291779, 14.01124954], [74.48291779, 14.01097202], [74.48319244, 14.01097202], [74.48319244, 14.01041794], [74.4834671, 14.01041985], [74.4834671, 14.00930977], [74.48319244, 14.00930977], [74.48319244, 14.00792027], [74.48264313, 14.00792027], [74.4826355, 14.00771046], [74.48290253, 14.00764179], [74.48291779, 14.00652981], [74.48264313, 14.00652981], [74.48264313, 14.00624943], [74.48208618, 14.00624943], [74.48208618, 14.00541973], [74.48152924, 14.00541973], [74.48152924, 14.00486088], [74.48042297, 14.00486088], [74.48042297, 14.0051403], [74.4798584, 14.0051403], [74.4798584, 14.00541973], [74.47958374, 14.00541782], [74.47958374, 14.00569344], [74.47930908, 14.00569057], [74.47930908, 14.00624943], [74.47902679, 14.00624943], [74.47902679, 14.00736237], [74.47875214, 14.00735855], [74.47875214, 14.00792027], [74.47846985, 14.00792027], [74.47846985, 14.00930977], [74.47875214, 14.00930977], [74.47875214, 14.00986195], [74.47902679, 14.00986195], [74.47902679, 14.01069355], [74.4798584, 14.01069355], [74.4798584, 14.01097202], [74.48042297, 14.01097202], [74.48041534, 14.01124954], [74.48052216, 14.01124954], [74.48291779, 14.01124954]]], [[[74.6701355, 13.19958401], [74.6701355, 13.19986153], [74.67097473, 13.19986153], [74.67097473, 13.19958401], [74.67152405, 13.19958401], [74.67152405, 13.19930553], [74.67208099, 13.1993103], [74.67208099, 13.19902992], [74.67263794, 13.19902992], [74.67263794, 13.19874859], [74.67292023, 13.19874859], [74.67292023, 13.19792175], [74.67263794, 13.19792175], [74.67263794, 13.19680977], [74.67318726, 13.19680977], [74.67318726, 13.19736099], [74.67375183, 13.19736099], [74.67375183, 13.19792175], [74.67402649, 13.19792175], [74.67402649, 13.19763947], [74.67430878, 13.19763947], [74.67430878, 13.19708061], [74.67458344, 13.19708347], [74.67458344, 13.19652653], [74.67485809, 13.19653034], [74.67485809, 13.19597054], [74.67514038, 13.1959734], [74.67514038, 13.19569492], [74.67542267, 13.19569111], [74.67541504, 13.1954174], [74.67569733, 13.19542027], [74.67569733, 13.19514179], [74.67597198, 13.19514179], [74.67597198, 13.19486141], [74.67624664, 13.19486141], [74.67624664, 13.19375134], [74.67652893, 13.19375134], [74.67652893, 13.19292164], [74.67624664, 13.19292164], [74.67624664, 13.19208145], [74.67597198, 13.19208336], [74.67597198, 13.19152737], [74.67569733, 13.19152737], [74.67569733, 13.19208336], [74.67542267, 13.19208145], [74.67542267, 13.19264126], [74.67514038, 13.19264126], [74.67514038, 13.19292164], [74.67485809, 13.19291687], [74.67485809, 13.19347095], [74.67457581, 13.19347095], [74.67457581, 13.19403172], [74.67430878, 13.19403172], [74.67430878, 13.19431019], [74.67402649, 13.19430542], [74.67402649, 13.19486141], [74.67375183, 13.19486141], [74.67375183, 13.19542027], [74.67346954, 13.1954174], [74.67346954, 13.19569302], [74.67208099, 13.19569302], [74.67208099, 13.19624901], [74.67180634, 13.19624043], [74.67180634, 13.19653034], [74.67152405, 13.19652653], [74.67152405, 13.19708347], [74.67124939, 13.19708061], [74.67124939, 13.19736099], [74.6709671, 13.19736099], [74.6709671, 13.19763947], [74.67069244, 13.19763947], [74.67069244, 13.19819641], [74.67041779, 13.19819641], [74.67041779, 13.19847107], [74.67014313, 13.19847107], [74.67014313, 13.19902992], [74.66986084, 13.19902706], [74.66986084, 13.19958401], [74.6701355, 13.19958401]]], [[[74.69986725, 13.28402996], [74.69986725, 13.28431034], [74.70041656, 13.28431034], [74.70041656, 13.28345966], [74.70069122, 13.28347206], [74.70069122, 13.28291798], [74.70097351, 13.28291798], [74.70097351, 13.28319359], [74.70124817, 13.28319359], [74.70124817, 13.27930546], [74.70096588, 13.27931023], [74.70096588, 13.27874947], [74.69930267, 13.27874947], [74.69930267, 13.27903175], [74.69902802, 13.27902699], [74.69902802, 13.27958393], [74.69875336, 13.27958107], [74.69875336, 13.28153038], [74.69958496, 13.28152847], [74.69958496, 13.28208447], [74.69930267, 13.28208447], [74.69930267, 13.28319359], [74.69957733, 13.28319073], [74.69957733, 13.28402996], [74.69986725, 13.28402996]]], [[[74.7279129, 13.28264046], [74.7279129, 13.28292179], [74.72846985, 13.28292179], [74.72846985, 13.28264046], [74.72875214, 13.28264046], [74.72875214, 13.28208065], [74.72846985, 13.28208447], [74.72846985, 13.28180599], [74.72820282, 13.28180981], [74.72820282, 13.28153038], [74.72763824, 13.28153038], [74.72763824, 13.28125191], [74.72735596, 13.28125191], [74.72735596, 13.28069115], [74.72763824, 13.28069305], [74.72763824, 13.28013992], [74.7279129, 13.28014183], [74.7279129, 13.27958107], [74.72819519, 13.27958393], [74.72819519, 13.27902699], [74.7279129, 13.27903175], [74.7279129, 13.27847099], [74.72735596, 13.27847099], [74.72735596, 13.27874947], [74.72680664, 13.27874947], [74.72680664, 13.27903175], [74.72651672, 13.27903175], [74.72651672, 13.27931023], [74.72597504, 13.27930546], [74.72597504, 13.27958393], [74.72569275, 13.27958393], [74.72569275, 13.2798624], [74.7251358, 13.2798624], [74.7251358, 13.28014183], [74.72541809, 13.28014183], [74.72541809, 13.2804203], [74.72569275, 13.28041458], [74.72569275, 13.28069305], [74.72597504, 13.28069305], [74.72597504, 13.28097153], [74.72624969, 13.28097153], [74.72624969, 13.28125191], [74.72651672, 13.28125191], [74.72651672, 13.28153038], [74.72680664, 13.28152847], [74.72680664, 13.28197193], [74.72680664, 13.28208447], [74.7270813, 13.28208065], [74.7270813, 13.28236198], [74.72735596, 13.28236198], [74.72738647, 13.28264046], [74.7279129, 13.28264046]]], [[[74.72319794, 13.28931141], [74.72319794, 13.28959084], [74.72374725, 13.28959084], [74.72374725, 13.28931141], [74.72429657, 13.28931141], [74.72429657, 13.28903103], [74.72486115, 13.28903103], [74.72486115, 13.28874969], [74.72541809, 13.28874969], [74.72541809, 13.28847027], [74.72569275, 13.28847218], [74.72569275, 13.2881937], [74.72624969, 13.2881937], [74.72624969, 13.28791618], [74.72680664, 13.28792095], [74.72680664, 13.28763962], [74.72735596, 13.28763962], [74.72735596, 13.28736019], [74.72763824, 13.2873621], [74.72763824, 13.28708363], [74.7280426, 13.28708363], [74.72846985, 13.28708363], [74.72846985, 13.28652763], [74.72820282, 13.28652954], [74.72820282, 13.28596973], [74.72793579, 13.28597164], [74.72763824, 13.28597164], [74.72763824, 13.28569412], [74.72652435, 13.28569412], [74.72652435, 13.28541565], [74.72624969, 13.28542042], [74.72624969, 13.28514004], [74.72541809, 13.28514004], [74.72541809, 13.28542042], [74.72486115, 13.28542042], [74.72486115, 13.28514004], [74.72458649, 13.28514004], [74.72458649, 13.28542042], [74.7243042, 13.28541565], [74.7243042, 13.28597164], [74.72403717, 13.28596973], [74.72403717, 13.28625011], [74.72374725, 13.28625011], [74.72374725, 13.28652954], [74.7234726, 13.28652954], [74.7234726, 13.28682041], [74.72319794, 13.28680611], [74.72319794, 13.28708363], [74.72291565, 13.28708363], [74.72291565, 13.2873621], [74.72270203, 13.28736019], [74.72264099, 13.28763962], [74.7223587, 13.28763962], [74.7223587, 13.28931141], [74.72265625, 13.28931141], [74.72319794, 13.28931141]]], [[[74.05652618, 14.81708431], [74.05652618, 14.81680584], [74.05680847, 14.81680965], [74.05680847, 14.81653023], [74.05652618, 14.81653023], [74.05652618, 14.81624985], [74.05625153, 14.81624985], [74.05625153, 14.81596947], [74.05596924, 14.81596947], [74.05596924, 14.81624985], [74.05569458, 14.81624985], [74.05569458, 14.81597233], [74.05458069, 14.81596947], [74.05458069, 14.81624985], [74.05430603, 14.81624985], [74.05430603, 14.81653023], [74.05458069, 14.81653023], [74.05458069, 14.81680965], [74.05486298, 14.81680584], [74.05486298, 14.81708431], [74.05652618, 14.81708431]]], [[[74.06402588, 14.82124996], [74.06402588, 14.82096958], [74.06458282, 14.82097244], [74.06458282, 14.82069397], [74.06513977, 14.8206892], [74.06513977, 14.82041645], [74.0654068, 14.82042122], [74.0654068, 14.82014179], [74.06569672, 14.82014179], [74.06569672, 14.81986046], [74.06541443, 14.81986237], [74.06541443, 14.81958199], [74.06485748, 14.81958199], [74.06485748, 14.81930637], [74.06291962, 14.81930637], [74.06291962, 14.81958199], [74.06263733, 14.81958199], [74.06263733, 14.8206892], [74.06291962, 14.82069397], [74.06291962, 14.82097244], [74.06318665, 14.82096958], [74.06318665, 14.82124996], [74.06402588, 14.82124996]]], [[[74.05930328, 14.82152843], [74.05930328, 14.82124996], [74.0617981, 14.82124996], [74.0617981, 14.82070065], [74.06208038, 14.8206892], [74.06208038, 14.82041645], [74.0617981, 14.82042122], [74.0617981, 14.82014179], [74.06153107, 14.82014179], [74.06153107, 14.81986046], [74.06097412, 14.81986237], [74.06097412, 14.81958199], [74.05958557, 14.81958199], [74.05958557, 14.81930637], [74.05819702, 14.81931114], [74.05819702, 14.81902981], [74.05735779, 14.8190279], [74.05735779, 14.81958199], [74.05708313, 14.81958199], [74.05708313, 14.82014179], [74.05735779, 14.82014179], [74.05735779, 14.82042122], [74.05791473, 14.82041645], [74.0579071, 14.8206892], [74.05819702, 14.82070065], [74.05819702, 14.82124996], [74.05847168, 14.82124996], [74.05847168, 14.82152843], [74.05930328, 14.82152843]]], [[[74.08791351, 14.79597187], [74.08791351, 14.79569435], [74.08875275, 14.79569435], [74.08875275, 14.79541588], [74.0890274, 14.79542065], [74.0890274, 14.79375172], [74.08735657, 14.79375172], [74.08735657, 14.79431057], [74.08708191, 14.7943058], [74.08708191, 14.79458427], [74.08680725, 14.79458046], [74.08680725, 14.79486179], [74.08625031, 14.79485989], [74.08625031, 14.79569435], [74.08652496, 14.79569435], [74.08652496, 14.79597187], [74.08791351, 14.79597187]]], [[[74.11125183, 14.76154137], [74.11125183, 14.76124954], [74.11152649, 14.76124954], [74.11152649, 14.75958061], [74.11180878, 14.75958443], [74.11180878, 14.75902653], [74.11207581, 14.75903034], [74.11207581, 14.75875187], [74.11235809, 14.75875187], [74.11235809, 14.75847054], [74.11264038, 14.75847054], [74.11264038, 14.75819588], [74.11290741, 14.75817966], [74.11291504, 14.75791836], [74.11347198, 14.75792027], [74.11347198, 14.75764179], [74.11374664, 14.75764179], [74.11374664, 14.75736141], [74.11402893, 14.75736141], [74.11402893, 14.75708294], [74.11430359, 14.75708294], [74.11430359, 14.75680542], [74.11486053, 14.75681019], [74.11486053, 14.75653172], [74.11541748, 14.75653172], [74.11541748, 14.75625134], [74.11569214, 14.75625134], [74.11569214, 14.75569057], [74.11597443, 14.75569534], [74.11597443, 14.75541687], [74.11653137, 14.75541687], [74.11653137, 14.75513935], [74.11875153, 14.75513935], [74.11875153, 14.75486088], [74.11975098, 14.75486088], [74.11985779, 14.75486088], [74.11985779, 14.75470161], [74.11985779, 14.75430489], [74.12014008, 14.75430965], [74.12014008, 14.75347137], [74.11985779, 14.75347328], [74.11985779, 14.75319481], [74.11902618, 14.75319481], [74.11902618, 14.75347328], [74.11875153, 14.75347137], [74.11875153, 14.75374889], [74.11650848, 14.75374889], [74.11458588, 14.75374889], [74.11458588, 14.75402927], [74.11402893, 14.75402927], [74.11402893, 14.75430965], [74.11347198, 14.75430489], [74.11347198, 14.75458336], [74.11290741, 14.75458145], [74.11290741, 14.75486088], [74.11264038, 14.75486088], [74.11264038, 14.75513935], [74.11152649, 14.75513935], [74.11152649, 14.75458145], [74.11096954, 14.75458336], [74.11096954, 14.75430489], [74.11068726, 14.75430965], [74.11068726, 14.75402927], [74.10984802, 14.75402927], [74.10984802, 14.75486088], [74.11013794, 14.75486088], [74.11013794, 14.75513935], [74.11042023, 14.75513935], [74.11042023, 14.75653172], [74.11013794, 14.75653172], [74.11013794, 14.75681019], [74.10986328, 14.75680542], [74.10986328, 14.75708294], [74.10958099, 14.75708294], [74.10958099, 14.75736141], [74.10901642, 14.75736141], [74.10901642, 14.75764179], [74.10874939, 14.75764179], [74.10874939, 14.75875187], [74.10791779, 14.75874901], [74.10791779, 14.75958443], [74.10819244, 14.75958061], [74.10819244, 14.75986195], [74.1084671, 14.75986195], [74.1084671, 14.76014042], [74.10874939, 14.76014042], [74.10874939, 14.76042175], [74.10902405, 14.76041794], [74.10902405, 14.7606926], [74.10930634, 14.7606926], [74.10930634, 14.76097202], [74.10958099, 14.76097202], [74.10958099, 14.76124954], [74.11013794, 14.76124954], [74.11013794, 14.76154137], [74.11125183, 14.76154137]]], [[[74.09708405, 14.87847233], [74.09708405, 14.87791634], [74.0973587, 14.8779211], [74.0973587, 14.87707996], [74.09680939, 14.87708378], [74.09680176, 14.87680626], [74.09625244, 14.87681103], [74.09625244, 14.87653065], [74.09570313, 14.87653065], [74.09570313, 14.87625027], [74.09513855, 14.87625027], [74.09513855, 14.87597179], [74.09430695, 14.87597179], [74.09430695, 14.87653065], [74.09402466, 14.87652779], [74.09402466, 14.87708378], [74.09430695, 14.87707996], [74.09430695, 14.87764072], [74.0945816, 14.87764072], [74.0945816, 14.8779211], [74.09513855, 14.87791634], [74.09513855, 14.87819386], [74.0956955, 14.87819386], [74.0956955, 14.87847233], [74.09708405, 14.87847233]]], [[[74.09402466, 14.83847141], [74.09402466, 14.8381958], [74.09430695, 14.8381958], [74.09430695, 14.83763885], [74.0945816, 14.83764172], [74.0945816, 14.83708096], [74.09486389, 14.83708286], [74.09486389, 14.83680534], [74.09401703, 14.8368206], [74.09401703, 14.83625126], [74.09375, 14.83625126], [74.09375, 14.83597088], [74.0929184, 14.83597088], [74.0929184, 14.83708286], [74.09319305, 14.83708286], [74.09319305, 14.8381958], [74.09347534, 14.8381958], [74.09347534, 14.83847141], [74.09402466, 14.83847141]]], [[[74.0984726, 14.84597206], [74.0984726, 14.84569359], [74.09874725, 14.84569359], [74.09874725, 14.84541798], [74.09929657, 14.84542274], [74.09929657, 14.84514046], [74.09986115, 14.84514046], [74.09986115, 14.84486198], [74.10041809, 14.84486198], [74.10041809, 14.8445816], [74.1020813, 14.84458447], [74.1020813, 14.84319401], [74.10190582, 14.84319401], [74.10180664, 14.84319401], [74.10180664, 14.84291553], [74.10151672, 14.8429203], [74.10151672, 14.84263134], [74.10097504, 14.84263992], [74.10097504, 14.84208393], [74.10041809, 14.84208393], [74.10041809, 14.84180641], [74.09874725, 14.84180641], [74.09874725, 14.84208393], [74.09791565, 14.84208393], [74.09791565, 14.8423624], [74.09764099, 14.8423624], [74.09764099, 14.84263992], [74.0973587, 14.84263134], [74.0973587, 14.8429203], [74.09708405, 14.84291553], [74.09708405, 14.84347153], [74.09680176, 14.84347153], [74.09680176, 14.84486198], [74.0965271, 14.84486198], [74.0965271, 14.84597206], [74.0984726, 14.84597206]]], [[[74.1554184, 14.7418108], [74.1554184, 14.74153137], [74.15598297, 14.74153137], [74.15598297, 14.74125004], [74.15651703, 14.74125004], [74.15651703, 14.74096966], [74.15680695, 14.74097157], [74.15680695, 14.74041557], [74.1570816, 14.74043179], [74.1570816, 14.74013996], [74.15735626, 14.74013996], [74.15735626, 14.73985958], [74.15763855, 14.73986244], [74.15763855, 14.73958397], [74.15791321, 14.73958397], [74.15791321, 14.73930645], [74.15821075, 14.73931122], [74.15821075, 14.73875046], [74.15789795, 14.73875046], [74.15789795, 14.7381916], [74.15763855, 14.73819447], [74.15763855, 14.73791599], [74.15735626, 14.73791981], [74.15735626, 14.73764038], [74.15651703, 14.73764038], [74.15651703, 14.73791981], [74.15625, 14.73791599], [74.15625, 14.73819447], [74.15598297, 14.7381916], [74.15598297, 14.73875046], [74.15569305, 14.73875046], [74.15569305, 14.73903275], [74.1554184, 14.73903275], [74.1554184, 14.73931122], [74.15486145, 14.73930645], [74.15486145, 14.73958397], [74.1543045, 14.73958397], [74.1543045, 14.73986244], [74.15402985, 14.73985958], [74.15402985, 14.74013996], [74.15319824, 14.74013996], [74.15319824, 14.74125004], [74.1534729, 14.74125004], [74.1534729, 14.74153137], [74.15374756, 14.74153137], [74.15374756, 14.7418108], [74.1554184, 14.7418108]]], [[[74.24069214, 14.71125031], [74.24069214, 14.71097183], [74.24097443, 14.71097183], [74.24097443, 14.70986176], [74.24041748, 14.70986176], [74.24041748, 14.70930576], [74.24014282, 14.70930958], [74.24014282, 14.70903015], [74.23958588, 14.70903015], [74.23958588, 14.70874977], [74.23847198, 14.70874977], [74.23847198, 14.70903015], [74.23792267, 14.70903015], [74.23792267, 14.71041965], [74.23819733, 14.71041584], [74.23819733, 14.71069431], [74.23874664, 14.71069431], [74.23874664, 14.71097183], [74.23958588, 14.71097183], [74.23958588, 14.71125031], [74.24069214, 14.71125031]]], [[[74.25375366, 14.70597363], [74.25375366, 14.70569324], [74.25430298, 14.70569324], [74.25430298, 14.70541763], [74.25541687, 14.70541954], [74.25541687, 14.70514202], [74.25514221, 14.70514202], [74.25514221, 14.70486164], [74.25485992, 14.70486164], [74.25485992, 14.70432091], [74.25514221, 14.70432091], [74.25514221, 14.70375156], [74.25374603, 14.70375156], [74.25374603, 14.70432091], [74.25347137, 14.70432091], [74.25347137, 14.70403194], [74.25319672, 14.70403194], [74.25319672, 14.70375156], [74.25235748, 14.70375156], [74.25235748, 14.70403194], [74.25180817, 14.70403194], [74.25180817, 14.70432091], [74.25152588, 14.70432091], [74.25152588, 14.70486164], [74.25180817, 14.70486164], [74.25180817, 14.70514202], [74.25208282, 14.70514202], [74.25208282, 14.70541954], [74.25235748, 14.70541763], [74.25235748, 14.70569324], [74.25263977, 14.70569324], [74.25263977, 14.70597363], [74.25375366, 14.70597363]]], [[[74.40319824, 14.31540108], [74.40319824, 14.31513786], [74.40402985, 14.31514072], [74.40402985, 14.31486034], [74.4043045, 14.31486034], [74.4043045, 14.31458473], [74.40458679, 14.31458473], [74.40458679, 14.31430435], [74.40486908, 14.31431103], [74.40486908, 14.31403065], [74.40513611, 14.31403065], [74.40513611, 14.31319046], [74.40486145, 14.31319427], [74.40486145, 14.3129158], [74.40458679, 14.3129158], [74.40458679, 14.31263828], [74.40402985, 14.31263828], [74.40402985, 14.3129158], [74.40374756, 14.3129158], [74.40374756, 14.31263828], [74.40291595, 14.31264019], [74.40291595, 14.31236172], [74.40235901, 14.31236172], [74.40235901, 14.31208038], [74.40013885, 14.31208038], [74.40013885, 14.31236172], [74.39971924, 14.31236172], [74.39930725, 14.31236172], [74.39930725, 14.31264019], [74.39901733, 14.31264019], [74.39901733, 14.31347179], [74.39958191, 14.31347179], [74.39958191, 14.31375027], [74.40010071, 14.31375027], [74.40040588, 14.31375027], [74.40040588, 14.31403065], [74.4006958, 14.31403065], [74.4006958, 14.31431103], [74.40097046, 14.31430435], [74.40097046, 14.31486034], [74.4015274, 14.31486034], [74.4015274, 14.31513786], [74.40164948, 14.31514835], [74.40180969, 14.31516075], [74.40180969, 14.3154211], [74.40245056, 14.3154211], [74.40299225, 14.3154211], [74.40319824, 14.31540108]]], [[[76.60787201, 11.60044193], [76.60144043, 11.60122108], [76.59671021, 11.6033802], [76.58827972, 11.60435963], [76.58615875, 11.60799026], [76.58096313, 11.60940075], [76.5748291, 11.60571957], [76.56006622, 11.61012077], [76.55362701, 11.61291981], [76.55322266, 11.61953163], [76.54968262, 11.62697124], [76.54705811, 11.6357708], [76.54521942, 11.64825058], [76.54308319, 11.65648079], [76.5430069, 11.66296959], [76.54042053, 11.67050934], [76.53531647, 11.67704105], [76.52468872, 11.68601036], [76.51307678, 11.69419193], [76.50421143, 11.69804096], [76.48781586, 11.68545055], [76.48532104, 11.68234921], [76.47934723, 11.68240166], [76.47377777, 11.68422031], [76.47367859, 11.67813969], [76.46660614, 11.67232132], [76.45136261, 11.6551199], [76.4312973, 11.65657043], [76.42346191, 11.65932083], [76.41757965, 11.66342068], [76.41020966, 11.66456985], [76.40740204, 11.66953087], [76.40219879, 11.68311977], [76.40293884, 11.69948196], [76.39640808, 11.70107937], [76.40310669, 11.70677853], [76.40628815, 11.70359993], [76.40867615, 11.70414925], [76.41108704, 11.70995045], [76.41793823, 11.71358013], [76.41889191, 11.71708107], [76.41899109, 11.7215004], [76.41726685, 11.72593117], [76.41197968, 11.73429108], [76.40558624, 11.73336124], [76.40661621, 11.74063969], [76.4108429, 11.7464819], [76.4076767, 11.75333118], [76.40441895, 11.74985027], [76.39071655, 11.74286938], [76.38376617, 11.74504089], [76.37233734, 11.73620129], [76.35604858, 11.73991108], [76.35114288, 11.73443031], [76.34625244, 11.73050117], [76.34091949, 11.73110008], [76.3349762, 11.73062992], [76.32434845, 11.73873138], [76.31758118, 11.7403717], [76.3105011, 11.7438612], [76.30311584, 11.76957035], [76.29995728, 11.77615166], [76.29469299, 11.7780714], [76.28365326, 11.78486919], [76.27509308, 11.80076027], [76.2720108, 11.80354023], [76.26544952, 11.80041122], [76.25312805, 11.79979992], [76.2443924, 11.79531002], [76.23210907, 11.79646969], [76.21852875, 11.80003929], [76.21431732, 11.80420971], [76.21199036, 11.81427002], [76.205513, 11.81958103], [76.20720673, 11.83176041], [76.20510864, 11.83865929], [76.20342255, 11.84906101], [76.20088959, 11.85412979], [76.19608307, 11.85554123], [76.18403625, 11.8637619], [76.1736908, 11.86244202], [76.16259003, 11.86003113], [76.14942169, 11.86101055], [76.13902283, 11.85711098], [76.1256485, 11.84477043], [76.12043762, 11.84429073], [76.11653137, 11.84304047], [76.10806274, 11.85118103], [76.10932159, 11.85859013], [76.10874939, 11.87059021], [76.10743713, 11.87633991], [76.10865021, 11.9280901], [76.10791016, 11.97063923], [76.09127045, 11.96158886], [76.08100128, 11.96067047], [76.07280731, 11.96128082], [76.06674957, 11.95827103], [76.04775238, 11.94447041], [76.04194641, 11.9433012], [76.03851318, 11.93900013], [76.02958679, 11.93278122], [76.02301788, 11.93465042], [76.01843262, 11.9350214], [76.01390076, 11.93326187], [76.00396729, 11.93192101], [75.99819183, 11.92362118], [75.9944458, 11.9233017], [75.98336792, 11.92544174], [75.9798584, 11.92466927], [75.97627258, 11.92496967], [75.97264862, 11.92755032], [75.9679184, 11.92697144], [75.95887756, 11.92860985], [75.95490265, 11.93151093], [75.94838715, 11.93391132], [75.93718719, 11.93283081], [75.93112183, 11.93111038], [75.92518616, 11.93287182], [75.91963196, 11.93562126], [75.91543579, 11.93402958], [75.90379333, 11.93476963], [75.89444733, 11.9365406], [75.88968658, 11.93814087], [75.88330078, 11.93891239], [75.87674713, 11.94071198], [75.86589813, 11.94563007], [75.85108948, 11.95704174], [75.84657288, 11.96465015], [75.84443665, 11.97027016], [75.83969116, 11.97281075], [75.83058929, 11.97463036], [75.82697296, 11.97797108], [75.8243866, 11.98427963], [75.82359314, 11.99456978], [75.82375336, 11.99456978], [75.82752228, 12.00284958], [75.82662964, 12.00579071], [75.8235321, 12.00933933], [75.81191254, 12.01611042], [75.81199646, 12.02196121], [75.81019592, 12.02406025], [75.79995728, 12.0302906], [75.79815674, 12.03267097], [75.79857635, 12.03966999], [75.79785919, 12.04164124], [75.79325867, 12.04751015], [75.79618073, 12.04949093], [75.80169678, 12.06797886], [75.79968262, 12.0711813], [75.79534912, 12.07423115], [75.7895813, 12.07461071], [75.78370667, 12.07643032], [75.7678833, 12.07752037], [75.76296234, 12.07858181], [75.75813293, 12.07721043], [75.75190735, 12.07740974], [75.74758911, 12.0734396], [75.74294281, 12.07178116], [75.73890686, 12.0721817], [75.73435974, 12.06770134], [75.72805023, 12.06410027], [75.71705627, 12.06208992], [75.71465302, 12.06534195], [75.71420288, 12.06921196], [75.71753693, 12.07745075], [75.71714783, 12.07843113], [75.70652771, 12.08280945], [75.70066071, 12.08353043], [75.70033264, 12.08803082], [75.70159912, 12.10033131], [75.6919632, 12.10258961], [75.68419647, 12.10224056], [75.681633, 12.09657955], [75.67830658, 12.09306145], [75.67273712, 12.09066963], [75.66760254, 12.09000015], [75.66242981, 12.0911808], [75.65822601, 12.09430122], [75.65278625, 12.10130024], [75.65155029, 12.10396194], [75.64807892, 12.10558033], [75.64745331, 12.11475086], [75.64298248, 12.11993027], [75.64433289, 12.12371063], [75.64385223, 12.12707043], [75.64250946, 12.13077164], [75.64068604, 12.13315105], [75.63761902, 12.13377953], [75.63678741, 12.14042091], [75.63508606, 12.1423912], [75.62937164, 12.14161968], [75.6268692, 12.14505005], [75.61708832, 12.14893246], [75.61131287, 12.14586163], [75.60814667, 12.1486702], [75.6020813, 12.1467514], [75.59760284, 12.1465292], [75.59471893, 12.14535999], [75.5931778, 12.14295959], [75.59144592, 12.14304924], [75.58715057, 12.14829063], [75.58271027, 12.15043068], [75.57684326, 12.15075016], [75.57038879, 12.16545963], [75.56384277, 12.16683197], [75.55961609, 12.16867065], [75.55525208, 12.17633057], [75.55240631, 12.17614174], [75.5511322, 12.18444061], [75.54875183, 12.18838978], [75.54386139, 12.19197083], [75.54036713, 12.19237041], [75.53791809, 12.19539165], [75.53373718, 12.19609165], [75.5329895, 12.19909096], [75.53688049, 12.20352173], [75.53804779, 12.20678139], [75.53793335, 12.21105194], [75.52532959, 12.21963024], [75.52482605, 12.22503185], [75.52336121, 12.22887039], [75.51850128, 12.23060036], [75.51994324, 12.23317146], [75.51928711, 12.23593998], [75.51667023, 12.24375057], [75.51307678, 12.24932098], [75.51140594, 12.25043964], [75.5111084, 12.25332069], [75.5038681, 12.25970173], [75.50392914, 12.26315975], [75.50200653, 12.2640419], [75.4940033, 12.265131], [75.49252319, 12.26681995], [75.48670197, 12.28146076], [75.48272705, 12.28618145], [75.46720886, 12.29537964], [75.45836639, 12.28855228], [75.44140625, 12.29001045], [75.43608093, 12.29181099], [75.43073273, 12.29200172], [75.42737579, 12.29067135], [75.42366791, 12.28703976], [75.41912842, 12.28639984], [75.42164612, 12.29096127], [75.43039703, 12.29952145], [75.42990875, 12.30223083], [75.42308044, 12.30814075], [75.41996002, 12.31446075], [75.41985321, 12.31946087], [75.41633606, 12.32147121], [75.41436768, 12.33375072], [75.41117859, 12.33782196], [75.41005707, 12.34134102], [75.41427612, 12.34393024], [75.4177475, 12.34843063], [75.4193573, 12.35254955], [75.4214325, 12.36190128], [75.42138672, 12.36672974], [75.41886902, 12.36952019], [75.41146088, 12.37457085], [75.40336609, 12.37255955], [75.40113831, 12.37570095], [75.39711761, 12.37524128], [75.39433289, 12.37983131], [75.39071655, 12.38344097], [75.38578796, 12.3855896], [75.38117218, 12.38479042], [75.37858582, 12.38667107], [75.3761673, 12.39246178], [75.37219238, 12.39573002], [75.36972046, 12.4017992], [75.36560059, 12.4070406], [75.3705368, 12.42894173], [75.36943817, 12.44563198], [75.3658905, 12.44908047], [75.36662292, 12.45166016], [75.38582611, 12.45070076], [75.39192963, 12.44508934], [75.40349579, 12.44756889], [75.40908051, 12.44985008], [75.41467285, 12.45409203], [75.41677094, 12.45888042], [75.42250824, 12.46006107], [75.42428589, 12.46625137], [75.42053986, 12.4715414], [75.42018127, 12.47966194], [75.41448975, 12.49671173], [75.40892029, 12.49419117], [75.40423584, 12.48960114], [75.40099335, 12.49057198], [75.39731598, 12.49781036], [75.39492798, 12.49755955], [75.39187622, 12.49254131], [75.38656616, 12.49192142], [75.3830719, 12.49265957], [75.381073, 12.49149036], [75.37950897, 12.48787975], [75.37721252, 12.48643112], [75.37223816, 12.48550987], [75.37000275, 12.48346996], [75.37055206, 12.48099041], [75.3730011, 12.47716141], [75.37206268, 12.46878147], [75.36273956, 12.46489143], [75.35941315, 12.45998096], [75.3556366, 12.45802116], [75.34086609, 12.45604992], [75.33676147, 12.45778179], [75.3405304, 12.46463108], [75.33833313, 12.47334194], [75.3393631, 12.47964954], [75.33898926, 12.48294067], [75.33557892, 12.48504925], [75.3348465, 12.49024105], [75.32805634, 12.49177074], [75.32064056, 12.49125099], [75.3141861, 12.49202061], [75.31009674, 12.495821], [75.30735016, 12.49741173], [75.3049469, 12.49675274], [75.30430603, 12.49751186], [75.30465698, 12.51729012], [75.30004883, 12.51689053], [75.29611969, 12.51966], [75.29177094, 12.52069092], [75.28581238, 12.51986122], [75.28114319, 12.51813984], [75.27961731, 12.52338028], [75.27240753, 12.53988075], [75.2709198, 12.55354023], [75.27258301, 12.55886173], [75.27683258, 12.56408978], [75.28349304, 12.56417179], [75.28676605, 12.56499004], [75.29139709, 12.57488155], [75.29496765, 12.57492924], [75.30314636, 12.57349968], [75.30977631, 12.57163239], [75.31619263, 12.56866169], [75.31936646, 12.57374191], [75.3263092, 12.57444191], [75.32846069, 12.57711124], [75.32785797, 12.58518124], [75.31852722, 12.58514023], [75.30825043, 12.58786964], [75.30561829, 12.59492016], [75.30149078, 12.59906101], [75.29833984, 12.59841061], [75.29390717, 12.59554195], [75.2911377, 12.59661961], [75.28885651, 12.60458088], [75.28103638, 12.60802937], [75.27672577, 12.61166], [75.27031708, 12.60898018], [75.26785278, 12.60568047], [75.262146, 12.59300137], [75.25881958, 12.59097004], [75.25617981, 12.58572102], [75.25019836, 12.5791893], [75.24948883, 12.57488155], [75.24003601, 12.57396984], [75.23867798, 12.57250023], [75.2381897, 12.56411266], [75.23629761, 12.56184006], [75.23129272, 12.56082153], [75.22290039, 12.56264019], [75.21691132, 12.57107067], [75.21404266, 12.57341194], [75.21084595, 12.58397961], [75.20752716, 12.58299065], [75.20340729, 12.58057022], [75.2045517, 12.58665085], [75.20749664, 12.58850193], [75.20897675, 12.59154034], [75.20954132, 12.59727192], [75.20729828, 12.59994984], [75.20244598, 12.60272121], [75.19870758, 12.60616016], [75.19946289, 12.61312103], [75.20279694, 12.62307167], [75.20143127, 12.62511063], [75.19438171, 12.62543106], [75.18985748, 12.62705135], [75.18257904, 12.62744141], [75.1774826, 12.62220955], [75.1700058, 12.61655998], [75.16279602, 12.61763954], [75.15917206, 12.61705017], [75.15487671, 12.61958027], [75.14766693, 12.62865067], [75.14296722, 12.63331032], [75.14122009, 12.63782024], [75.15032959, 12.64188957], [75.15123749, 12.64344025], [75.15164948, 12.64936066], [75.1550827, 12.65367985], [75.16129303, 12.66407108], [75.16113281, 12.66567993], [75.15571594, 12.66603088], [75.1506958, 12.66885853], [75.1506424, 12.67634201], [75.14450836, 12.6729002], [75.1391983, 12.67275047], [75.13667297, 12.67117119], [75.13188934, 12.67084026], [75.12689972, 12.67331123], [75.12078857, 12.67356968], [75.1126709, 12.67591095], [75.10865784, 12.68494129], [75.10441589, 12.69155121], [75.09925842, 12.69335079], [75.09163666, 12.69471169], [75.08609772, 12.69778156], [75.08242798, 12.69322968], [75.0849762, 12.68968201], [75.08743286, 12.67596054], [75.08670044, 12.67085075], [75.08490753, 12.67047977], [75.08309174, 12.66640854], [75.079422, 12.6665802], [75.07520294, 12.66543198], [75.07026672, 12.65802002], [75.06600952, 12.65795231], [75.0608902, 12.66148186], [75.05827332, 12.65863132], [75.05531311, 12.66006184], [75.04780579, 12.66008854], [75.04476166, 12.66330147], [75.04309082, 12.67057133], [75.04467773, 12.68744087], [75.04859924, 12.68832111], [75.05213165, 12.6870079], [75.05455017, 12.6835804], [75.05679321, 12.68672085], [75.0521698, 12.69817066], [75.05574799, 12.7034111], [75.05285645, 12.7098217], [75.04966736, 12.71469975], [75.04624176, 12.7163496], [75.04308319, 12.71552944], [75.03811646, 12.71858978], [75.0313797, 12.71695232], [75.0256958, 12.71431923], [75.02295685, 12.71562099], [75.01905823, 12.71475029], [75.01429749, 12.70780087], [75.00708008, 12.70920944], [75.00402832, 12.71172142], [75.00306702, 12.71369171], [75.01085663, 12.71928978], [75.01216888, 12.72284126], [75.00023651, 12.72740078], [74.99304962, 12.73313999], [74.99015045, 12.73110008], [74.98838043, 12.73192978], [74.98693848, 12.72879791], [74.98477936, 12.72988129], [74.98442841, 12.73594093], [74.9860611, 12.73847961], [74.98986053, 12.73728085], [74.99175262, 12.73816967], [74.99529266, 12.74484062], [75.0002594, 12.75155067], [75.00427246, 12.75399017], [75.0071106, 12.75706196], [75.00860596, 12.76043129], [75.00779724, 12.76509094], [75.00522614, 12.76933098], [75.0041275, 12.77355194], [75.00527954, 12.78549194], [75.00393677, 12.78561974], [75.00029755, 12.7834816], [74.9960022, 12.78798103], [74.99228668, 12.79045963], [74.98945618, 12.79081059], [74.98883057, 12.78923035], [74.9925766, 12.78362083], [74.98729706, 12.77792072], [74.98192596, 12.77523994], [74.97067261, 12.77256012], [74.96900177, 12.77292919], [74.96862793, 12.77626133], [74.96726227, 12.77685165], [74.96536255, 12.77480125], [74.96337128, 12.77482986], [74.96025848, 12.77904034], [74.95420074, 12.77928066], [74.93733215, 12.77219105], [74.92935181, 12.77133179], [74.90911102, 12.76303101], [74.90804291, 12.76257133], [74.90509796, 12.75993061], [74.90141296, 12.75953007], [74.89776611, 12.75540066], [74.89453125, 12.7560997], [74.89176178, 12.75452995], [74.8886795, 12.75237179], [74.88559723, 12.74877071], [74.87991333, 12.74927044], [74.87802887, 12.75024128], [74.87766266, 12.7523489], [74.87589264, 12.75529099], [74.86708069, 12.75445175], [74.86708069, 12.75458241], [74.86736298, 12.75457954], [74.86736298, 12.75625134], [74.86708069, 12.75625134], [74.86708069, 12.75764084], [74.86680603, 12.75763893], [74.86680603, 12.75819016], [74.86653137, 12.7582016], [74.86653137, 12.75875092], [74.86624908, 12.75875092], [74.86624908, 12.75931168], [74.86597443, 12.75930691], [74.86597443, 12.75986099], [74.86569214, 12.75984859], [74.86569214, 12.76041889], [74.86541748, 12.76041698], [74.86541748, 12.76069546], [74.86486053, 12.76069546], [74.86486053, 12.76013947], [74.86458588, 12.76014137], [74.86458588, 12.75984859], [74.86429596, 12.75984859], [74.86429596, 12.76041889], [74.86374664, 12.76041698], [74.86374664, 12.76097298], [74.86347198, 12.76097107], [74.86347198, 12.76180935], [74.86319733, 12.76180935], [74.86319733, 12.76264095], [74.86291504, 12.76263905], [74.86291504, 12.76319504], [74.86264038, 12.76319122], [74.86264038, 12.76402855], [74.86235809, 12.76402664], [74.86235809, 12.76458263], [74.86207581, 12.76458073], [74.86207581, 12.76542187], [74.86180878, 12.76542187], [74.86180878, 12.76597977], [74.86152649, 12.76597118], [74.86152649, 12.76615143], [74.86152649, 12.76681042], [74.86125183, 12.7668047], [74.86125183, 12.76705074], [74.86125183, 12.76764202], [74.86096954, 12.76764011], [74.86096954, 12.76796055], [74.86096954, 12.76819324], [74.86069489, 12.76819324], [74.86066437, 12.76885891], [74.86065674, 12.76904106], [74.86042023, 12.76902676], [74.86042023, 12.76935959], [74.86042023, 12.76958084], [74.8601532, 12.76959038], [74.86013794, 12.77042007], [74.85986328, 12.77041531], [74.85986328, 12.77097225], [74.85958099, 12.77096939], [74.85958099, 12.77180958], [74.85930634, 12.77180576], [74.85930634, 12.77236176], [74.85902405, 12.77236176], [74.85902405, 12.77319431], [74.85874939, 12.77319145], [74.85874939, 12.77402973], [74.85847473, 12.77402782], [74.85847473, 12.77458191], [74.85819244, 12.77458191], [74.85819244, 12.77542019], [74.85791779, 12.77542019], [74.85791779, 12.77625179], [74.85764313, 12.77625179], [74.85764313, 12.77681065], [74.85736084, 12.77681065], [74.85736084, 12.77764034], [74.85708618, 12.77764034], [74.85708618, 12.77819443], [74.85679626, 12.77818966], [74.85679626, 12.77875042], [74.85652924, 12.77875042], [74.85652924, 12.77958202], [74.85623932, 12.77958202], [74.85623932, 12.78014088], [74.85597229, 12.78014088], [74.85597229, 12.78098202], [74.85569763, 12.78098202], [74.85569763, 12.78153133], [74.85541534, 12.78152943], [74.85541534, 12.7820816], [74.85514069, 12.7820797], [74.85514069, 12.78264141], [74.8548584, 12.7826376], [74.8548584, 12.78319454], [74.85457611, 12.78318977], [74.85457611, 12.78375053], [74.85430908, 12.78375053], [74.85430908, 12.78431129], [74.85402679, 12.78430462], [74.85402679, 12.78486061], [74.85375214, 12.78486061], [74.85375214, 12.78542137], [74.85346985, 12.7854166], [74.85346985, 12.7859726], [74.85320282, 12.78597069], [74.85320282, 12.78653145], [74.8529129, 12.78652668], [74.8529129, 12.78708267], [74.85263824, 12.7870779], [74.85263824, 12.78764057], [74.85235596, 12.78764057], [74.85235596, 12.78792191], [74.8520813, 12.78791714], [74.8520813, 12.78819466], [74.85180664, 12.78819275], [74.85180664, 12.78875065], [74.85151672, 12.78875065], [74.85151672, 12.78903103], [74.85098267, 12.78903103], [74.85098267, 12.78931046], [74.85069275, 12.78930473], [74.85069275, 12.78958321], [74.85043335, 12.7895813], [74.85043335, 12.79015064], [74.8501358, 12.79015064], [74.8501358, 12.79041862], [74.84958649, 12.79041672], [74.84958649, 12.7909708], [74.8493042, 12.79097271], [74.8493042, 12.79208279], [74.84902954, 12.79208279], [74.84902954, 12.79236126], [74.84874725, 12.79236126], [74.84874725, 12.79264164], [74.8484726, 12.79263878], [74.8484726, 12.79319477], [74.84792328, 12.79319096], [74.84792328, 12.79375172], [74.84764099, 12.79375172], [74.84764099, 12.79403019], [74.84736633, 12.79403019], [74.84736633, 12.79430962], [74.84708405, 12.79430485], [74.84708405, 12.79458332], [74.8465271, 12.79458141], [74.8465271, 12.79514027], [74.84625244, 12.79514027], [74.84625244, 12.79597092], [74.84597015, 12.79596043], [74.84597015, 12.79652977], [74.84570313, 12.79652977], [74.84570313, 12.79681015], [74.84541321, 12.79680634], [74.84541321, 12.79708385], [74.8456955, 12.79708385], [74.8456955, 12.79736233], [74.84541321, 12.79735947], [74.84541321, 12.79763985], [74.84513855, 12.79763985], [74.84513855, 12.79819584], [74.84486389, 12.79819584], [74.84486389, 12.7990284], [74.8445816, 12.79901886], [74.8445816, 12.80014038], [74.84429932, 12.80014038], [74.84429932, 12.80041981], [74.84402466, 12.8004179], [74.84402466, 12.80097198], [74.84375, 12.80097198], [74.84375, 12.80209064], [74.84348297, 12.80209064], [74.84348297, 12.80375004], [74.84319305, 12.80375004], [74.84319305, 12.80458355], [74.8429184, 12.80457973], [74.8429184, 12.80542088], [74.84263611, 12.80541611], [74.84263611, 12.8059721], [74.84236145, 12.80597019], [74.84236145, 12.80681133], [74.84208679, 12.80681133], [74.84208679, 12.80764103], [74.8418045, 12.80763817], [74.8418045, 12.80847168], [74.84152985, 12.80846977], [74.84152985, 12.80903053], [74.84124756, 12.80902863], [74.84124756, 12.80958462], [74.8409729, 12.80957985], [74.8409729, 12.81014061], [74.84069824, 12.8101387], [74.84069824, 12.81097317], [74.84041595, 12.81096077], [74.84041595, 12.81153107], [74.8401413, 12.81152916], [74.8401413, 12.81208324], [74.83985901, 12.81208324], [74.83985901, 12.81236076], [74.8401413, 12.8123579], [74.8401413, 12.81292057], [74.83985901, 12.81292057], [74.83985901, 12.81347275], [74.83957672, 12.81347275], [74.83957672, 12.81375122], [74.83930206, 12.81375122], [74.83930206, 12.8148613], [74.8390274, 12.8148613], [74.8390274, 12.81652927], [74.83875275, 12.81652927], [74.83875275, 12.81763935], [74.8381958, 12.81763935], [74.8381958, 12.81792164], [74.83790588, 12.81792164], [74.83790588, 12.81903172], [74.83763885, 12.81902695], [74.83763885, 12.81986141], [74.83735657, 12.81986141], [74.83735657, 12.82042027], [74.83708191, 12.82042027], [74.83708191, 12.82125187], [74.83680725, 12.82125187], [74.83680725, 12.82153034], [74.83653259, 12.82153034], [74.83653259, 12.82292175], [74.83625031, 12.82292175], [74.83625031, 12.82402992], [74.83597565, 12.82402802], [74.83597565, 12.82458401], [74.83569336, 12.82457924], [74.83569336, 12.82542038], [74.8354187, 12.82541561], [74.8354187, 12.8259716], [74.83513641, 12.8259716], [74.83513641, 12.82625198], [74.83542633, 12.82625198], [74.83542633, 12.82653046], [74.83513641, 12.8265276], [74.83513641, 12.82736206], [74.83486176, 12.82736206], [74.83486176, 12.82847214], [74.8345871, 12.82847023], [74.8345871, 12.82932186], [74.83429718, 12.82932186], [74.83429718, 12.82985973], [74.83403015, 12.82985973], [74.83403015, 12.8306942], [74.83374786, 12.8306942], [74.83374786, 12.8312912], [74.83374786, 12.83181095], [74.83347321, 12.83180618], [74.83347321, 12.8320837], [74.83325195, 12.83211231], [74.83319092, 12.83226204], [74.83319092, 12.83319378], [74.83291626, 12.83319187], [74.83291626, 12.83403111], [74.8326416, 12.83402824], [74.8326416, 12.83458233], [74.8320694, 12.83458042], [74.8320694, 12.83542061], [74.83152771, 12.83541584], [74.83152771, 12.83597279], [74.83125305, 12.83597279], [74.83125305, 12.83736134], [74.83097076, 12.83736134], [74.83097076, 12.83764076], [74.83069611, 12.83763885], [74.83069611, 12.83819485], [74.83040619, 12.83819008], [74.83040619, 12.83931065], [74.83013916, 12.83931065], [74.83013916, 12.8401413], [74.82958221, 12.84013939], [74.82958221, 12.84069538], [74.82929993, 12.84068966], [74.82929993, 12.84125996], [74.8290329, 12.84125996], [74.8290329, 12.84180927], [74.82875061, 12.84180546], [74.82875061, 12.84319496], [74.82847595, 12.84319496], [74.82847595, 12.84347343], [74.82902527, 12.84347343], [74.82902527, 12.84319496], [74.82930756, 12.84319496], [74.82930756, 12.84263897], [74.82985687, 12.84264088], [74.82985687, 12.84291935], [74.82958221, 12.84291935], [74.82958221, 12.84402943], [74.82929993, 12.84402943], [74.82930756, 12.84486103], [74.82902527, 12.84486103], [74.82902527, 12.84569454], [74.82875061, 12.84569073], [74.82875061, 12.84653187], [74.8290329, 12.84653187], [74.8290329, 12.84681034], [74.82763672, 12.84680462], [74.82763672, 12.84708309], [74.82653046, 12.84708309], [74.82653046, 12.84736061], [74.82563782, 12.84736061], [74.82541656, 12.84736061], [74.82541656, 12.84708309], [74.82485962, 12.84708309], [74.82485962, 12.84680462], [74.82430267, 12.84681034], [74.82430267, 12.84653187], [74.82375336, 12.8465271], [74.82375336, 12.84708309], [74.82347107, 12.84708309], [74.82347107, 12.84819317], [74.82319641, 12.84819126], [74.82319641, 12.84930992], [74.82291412, 12.84930515], [74.82291412, 12.84958363], [74.82263947, 12.84957886], [74.82263947, 12.85042], [74.82236481, 12.85041809], [74.82236481, 12.85097218], [74.82180786, 12.85096931], [74.82180786, 12.85124969], [74.82152557, 12.85124969], [74.82152557, 12.85208416], [74.82125092, 12.8520813], [74.82125092, 12.85236168], [74.82096863, 12.85236168], [74.82096863, 12.85291958], [74.82125092, 12.85291958], [74.82125092, 12.85681057], [74.82096863, 12.8568058], [74.82096863, 12.85847187], [74.82069397, 12.85847187], [74.82069397, 12.85930634], [74.82041931, 12.85929871], [74.82041931, 12.86042118], [74.82013702, 12.86041641], [74.82013702, 12.8609724], [74.81986237, 12.86096954], [74.81986237, 12.86264133], [74.81958008, 12.86264133], [74.81958008, 12.86292076], [74.81986237, 12.86291599], [74.81986237, 12.86319542], [74.81958008, 12.8631897], [74.81958008, 12.86375141], [74.81930542, 12.86375141], [74.81930542, 12.86458302], [74.81903076, 12.86458015], [74.81903076, 12.86680889], [74.81874847, 12.86680698], [74.81874847, 12.8670826], [74.81846619, 12.86707973], [74.81846619, 12.86764145], [74.81819153, 12.86764145], [74.81819153, 12.86875057], [74.81838226, 12.86874866], [74.81847382, 12.86874866], [74.81846619, 12.87014103], [74.81819153, 12.87014103], [74.81819153, 12.87041855], [74.81791687, 12.87041664], [74.81791687, 12.87069511], [74.81819153, 12.87069511], [74.81819153, 12.87208271], [74.81791687, 12.87208271], [74.81791687, 12.87236118], [74.81764221, 12.87236118], [74.81764221, 12.87292194], [74.81735992, 12.87292194], [74.81735992, 12.87375069], [74.81764221, 12.87374878], [74.81764221, 12.87569332], [74.81735992, 12.87569332], [74.81735992, 12.87662983], [74.81735992, 12.87681007], [74.81708527, 12.87680626], [74.8170929, 12.87721062], [74.8170929, 12.87737083], [74.81680298, 12.87737083], [74.81680298, 12.87763977], [74.81652832, 12.87763977], [74.81652832, 12.87837124], [74.81652832, 12.87903023], [74.81624603, 12.87903023], [74.81624603, 12.8801403], [74.81597137, 12.8801403], [74.81597137, 12.88208389], [74.81569672, 12.88208199], [74.81569672, 12.88431072], [74.8154068, 12.88431072], [74.8154068, 12.8854208], [74.81513977, 12.88541603], [74.81513977, 12.88569355], [74.81541443, 12.88569355], [74.81541443, 12.88597202], [74.81513977, 12.88597202], [74.81513977, 12.88624954], [74.81485748, 12.88624096], [74.81485748, 12.88681126], [74.81458282, 12.88680553], [74.81458282, 12.88736153], [74.8143158, 12.88735962], [74.8143158, 12.88764095], [74.81402588, 12.88763809], [74.81402588, 12.88958454], [74.81375122, 12.88957977], [74.81375122, 12.89042091], [74.81402588, 12.8904171], [74.81402588, 12.89097309], [74.81375122, 12.89097309], [74.81375122, 12.89208317], [74.81346893, 12.89208317], [74.81346893, 12.89347267], [74.81318665, 12.8934679], [74.81318665, 12.89403057], [74.81291962, 12.89403057], [74.81291962, 12.8965292], [74.81263733, 12.8965292], [74.81263733, 12.89763927], [74.81236267, 12.89763927], [74.81236267, 12.89819527], [74.81208038, 12.89818192], [74.81208038, 12.89903164], [74.81180573, 12.89902687], [74.81180573, 12.90069485], [74.81153107, 12.90069103], [74.81153107, 12.90180969], [74.81124878, 12.90180492], [74.81124878, 12.9020834], [74.81096649, 12.90208054], [74.81096649, 12.90264034], [74.81069183, 12.90264034], [74.81069183, 12.90347099], [74.81096649, 12.90347099], [74.81096649, 12.90374947], [74.81069183, 12.90374947], [74.81069183, 12.90513992], [74.81097412, 12.90513992], [74.81097412, 12.90597153], [74.81041718, 12.90597153], [74.81041718, 12.90736198], [74.80986023, 12.90736198], [74.80986023, 12.91097164], [74.8095932, 12.91096973], [74.8095932, 12.91125011], [74.80930328, 12.91125011], [74.80930328, 12.91181087], [74.80902863, 12.91181087], [74.80902863, 12.91348076], [74.80874634, 12.91348076], [74.80874634, 12.91374969], [74.80847168, 12.91374969], [74.80847168, 12.91485977], [74.80818939, 12.91485977], [74.80818939, 12.91625118], [74.80791473, 12.91625118], [74.80791473, 12.91708469], [74.80764008, 12.91708469], [74.80764008, 12.91736031], [74.80791473, 12.91736031], [74.80791473, 12.91819477], [74.80764008, 12.91819], [74.80764008, 12.91875076], [74.80735779, 12.91875076], [74.80735779, 12.91903114], [74.80708313, 12.91903114], [74.80708313, 12.91931057], [74.80680847, 12.91930676], [74.80680847, 12.92097282], [74.80708313, 12.92097092], [74.80708313, 12.9212513], [74.80735779, 12.9212513], [74.80735779, 12.92153072], [74.80764008, 12.92152691], [74.80764008, 12.9220829], [74.80791473, 12.9220829], [74.80791473, 12.92236137], [74.80764008, 12.92236137], [74.80764008, 12.92458344], [74.80902863, 12.92458344], [74.80902863, 12.92430496], [74.8095932, 12.92430973], [74.8095932, 12.92402935], [74.80986023, 12.92402935], [74.80986023, 12.92347145], [74.81041718, 12.92347336], [74.81041718, 12.92263889], [74.81069183, 12.92263889], [74.81069183, 12.92208099], [74.81097412, 12.9220829], [74.81097412, 12.92152691], [74.81125641, 12.92153072], [74.81125641, 12.92068958], [74.81153107, 12.9206953], [74.81153107, 12.92013931], [74.81181335, 12.92014122], [74.81181335, 12.91958046], [74.81208038, 12.91958332], [74.81208038, 12.91902733], [74.81236267, 12.91903114], [74.81236267, 12.91875076], [74.81291962, 12.91875076], [74.81291962, 12.91847038], [74.81375122, 12.91847038], [74.81375122, 12.91903114], [74.81402588, 12.91902733], [74.81402588, 12.9206953], [74.81430817, 12.9206953], [74.8143158, 12.9212513], [74.81402588, 12.9212513], [74.81402588, 12.92153072], [74.81375122, 12.92152691], [74.81375122, 12.92236137], [74.8143158, 12.92235184], [74.8143158, 12.92291927], [74.81541443, 12.92291737], [74.81541443, 12.92319489], [74.81569672, 12.92319489], [74.81569672, 12.92347336], [74.81597137, 12.92347145], [74.81597137, 12.92375088], [74.81624603, 12.92375088], [74.81624603, 12.92402935], [74.81652832, 12.92402935], [74.81652832, 12.92430973], [74.81680298, 12.92430496], [74.81680298, 12.92458344], [74.81735992, 12.92458057], [74.81735992, 12.92486095], [74.81764221, 12.92486095], [74.81764221, 12.92514133], [74.81791687, 12.92514133], [74.81791687, 12.92542171], [74.81819153, 12.92541695], [74.81819153, 12.92569542], [74.81847382, 12.92569542], [74.81847382, 12.92597103], [74.81874847, 12.92597103], [74.81874847, 12.92625141], [74.81931305, 12.92625141], [74.81931305, 12.92653179], [74.81958008, 12.92653179], [74.81958008, 12.92681026], [74.81986237, 12.92680454], [74.81986237, 12.92708302], [74.82013702, 12.92708302], [74.82013702, 12.92736053], [74.82041931, 12.92736053], [74.82041931, 12.92764187], [74.82068634, 12.92764187], [74.82068634, 12.92792034], [74.82096863, 12.92792034], [74.82096863, 12.92931175], [74.82068634, 12.92931175], [74.82068634, 12.92986202], [74.82041931, 12.92986202], [74.82041931, 12.93041992], [74.82013702, 12.93041801], [74.82013702, 12.93069553], [74.81930542, 12.93069553], [74.81930542, 12.93041801], [74.81819153, 12.93041801], [74.81819153, 12.93097115], [74.81791687, 12.93096924], [74.81791687, 12.93124962], [74.81735992, 12.93124962], [74.81735992, 12.93096924], [74.81708527, 12.93097115], [74.81708527, 12.93069553], [74.81680298, 12.93069553], [74.81680298, 12.93041801], [74.8170929, 12.93041992], [74.8170929, 12.92986202], [74.81680298, 12.92986202], [74.81680298, 12.92958069], [74.81624603, 12.92958069], [74.81624603, 12.92986202], [74.8154068, 12.92986202], [74.8154068, 12.93013954], [74.81485748, 12.93013954], [74.81485748, 12.93041992], [74.81458282, 12.93041801], [74.81458282, 12.93069553], [74.81375122, 12.93069553], [74.81375122, 12.93097115], [74.81319427, 12.93097115], [74.81319427, 12.93069553], [74.81236267, 12.93069553], [74.81236267, 12.93041801], [74.81153107, 12.93041992], [74.81153107, 12.93013954], [74.81096649, 12.93013954], [74.81096649, 12.92986202], [74.81069183, 12.92986202], [74.81069183, 12.92958069], [74.80902863, 12.9295826], [74.80902863, 12.92930508], [74.80847168, 12.92931175], [74.80847168, 12.92903042], [74.80764008, 12.92903042], [74.80764008, 12.92875195], [74.80708313, 12.92875195], [74.80708313, 12.92819118], [74.80680847, 12.92819118], [74.80680847, 12.92848015], [74.80652618, 12.92848015], [74.80652618, 12.92903042], [74.80625153, 12.92903042], [74.80625153, 12.92986202], [74.80596924, 12.92986202], [74.80596924, 12.93069553], [74.80569458, 12.93069553], [74.80569458, 12.93097115], [74.80513, 12.93096924], [74.80513, 12.93124962], [74.80430603, 12.93124962], [74.80430603, 12.93096924], [74.80347443, 12.93097115], [74.80347443, 12.93069553], [74.80291748, 12.93068886], [74.80291748, 12.93124962], [74.80236053, 12.93124962], [74.80236053, 12.93181038], [74.80291748, 12.93180561], [74.80291748, 12.93208408], [74.80319214, 12.93207932], [74.80319214, 12.9323616], [74.80347443, 12.9323616], [74.80347443, 12.93319416], [74.80374908, 12.93319416], [74.80374908, 12.93347168], [74.80403137, 12.93347168], [74.80403137, 12.93375015], [74.80430603, 12.93375015], [74.80430603, 12.93513966], [74.80403137, 12.93513775], [74.80403137, 12.9370842], [74.80374908, 12.93708038], [74.80374908, 12.93875027], [74.8034668, 12.93875027], [74.8034668, 12.94013977], [74.80319214, 12.94013977], [74.80319214, 12.94153118], [74.80291748, 12.94152832], [74.80291748, 12.94319439], [74.80263519, 12.94319439], [74.80263519, 12.94458199], [74.80236053, 12.94458199], [74.80236053, 12.9459734], [74.80208588, 12.94596958], [74.80208588, 12.94764137], [74.80179596, 12.94764137], [74.80179596, 12.94903088], [74.80152893, 12.94902897], [74.80152893, 12.95069504], [74.80124664, 12.95069504], [74.80124664, 12.95208263], [74.80097198, 12.95208263], [74.80097198, 12.95347118], [74.80069733, 12.95347118], [74.80069733, 12.95397854], [74.80069733, 12.95514202], [74.80041504, 12.95513916], [74.80041504, 12.95555019], [74.80042267, 12.95652962], [74.80014038, 12.95652676], [74.80014038, 12.95678043], [74.80014038, 12.95792007], [74.79985809, 12.95791531], [74.79985809, 12.95804977], [74.79985809, 12.95958424], [74.79958344, 12.95958424], [74.79958344, 12.96097183], [74.79931641, 12.96097183], [74.79931641, 12.96263981], [74.79902649, 12.96263981], [74.79902649, 12.96403027], [74.79875183, 12.96402836], [74.79875183, 12.96569443], [74.79846954, 12.96569443], [74.79846954, 12.96708202], [74.79819489, 12.96708202], [74.79819489, 12.96847153], [74.79792023, 12.96846962], [74.79792023, 12.97014141], [74.79763794, 12.97014141], [74.79763794, 12.97153091], [74.79736328, 12.97152901], [74.79736328, 12.97319508], [74.79708099, 12.97319031], [74.79708099, 12.97431183], [74.79680634, 12.97431183], [74.79680634, 12.97514057], [74.79652405, 12.97513866], [74.79652405, 12.97597313], [74.79624939, 12.97597313], [74.79624939, 12.97708321], [74.79597473, 12.97708321], [74.79597473, 12.9784708], [74.79569244, 12.9784708], [74.79569244, 12.97931194], [74.79541779, 12.97930527], [74.79541779, 12.98097134], [74.7951355, 12.98097134], [74.7951355, 12.98263931], [74.79486084, 12.98262978], [74.79486084, 12.98431015], [74.79458618, 12.98430634], [74.79458618, 12.9859724], [74.79430389, 12.9859724], [74.79430389, 12.98819447], [74.79402924, 12.98819065], [74.79402924, 12.98903179], [74.79374695, 12.98903179], [74.79374695, 12.99013996], [74.79347229, 12.99013996], [74.79347229, 12.99125004], [74.79319, 12.99125004], [74.79319763, 12.99236012], [74.79291534, 12.99236012], [74.79291534, 12.99319363], [74.79264069, 12.99319172], [74.79264069, 12.99431133], [74.79250336, 12.99430561], [74.7923584, 12.99431133], [74.7923584, 12.99542141], [74.79207611, 12.99542141], [74.79207611, 12.99625015], [74.79180908, 12.99625015], [74.79180908, 12.99736023], [74.79152679, 12.99736023], [74.79152679, 12.99847317], [74.79125214, 12.99847317], [74.79125214, 12.99958324], [74.79096985, 12.99958038], [74.79096985, 13.00014114], [74.79070282, 13.00014114], [74.79070282, 13.00042057], [74.7904129, 13.00042057], [74.7904129, 13.0007019], [74.79014587, 13.0007019], [74.79014587, 13.00153065], [74.7904129, 13.00152683], [74.7904129, 13.0023613], [74.79013824, 13.0023613], [74.79013824, 13.00347328], [74.7895813, 13.00347137], [74.7895813, 13.00376034], [74.78930664, 13.00374889], [74.78930664, 13.00569534], [74.78901672, 13.00569057], [74.78901672, 13.00764179], [74.78874969, 13.00764179], [74.78874969, 13.00875187], [74.78847504, 13.00874901], [74.78847504, 13.0106926], [74.78791809, 13.0106926], [74.78791809, 13.0134716], [74.7876358, 13.0134716], [74.7876358, 13.01403046], [74.78775787, 13.01403046], [74.78791809, 13.0140276], [74.78791809, 13.01458359], [74.7876358, 13.01458168], [74.7876358, 13.01570129], [74.78736115, 13.01569366], [74.78736115, 13.01708412], [74.78708649, 13.01708031], [74.78708649, 13.01764011], [74.78679657, 13.01764011], [74.78679657, 13.01931095], [74.78652954, 13.01930618], [74.78652954, 13.01986217], [74.78624725, 13.01986217], [74.78624725, 13.02208233], [74.7859726, 13.02208042], [74.7859726, 13.02292061], [74.78569794, 13.02291584], [74.78569794, 13.02458191], [74.78542328, 13.02458], [74.78542328, 13.02625084], [74.78514099, 13.02625084], [74.78514099, 13.02736092], [74.7848587, 13.02736092], [74.7848587, 13.02875137], [74.78458405, 13.02875137], [74.78458405, 13.03069496], [74.78430939, 13.03068066], [74.78430176, 13.03181171], [74.7840271, 13.03181171], [74.7840271, 13.03292179], [74.78375244, 13.03292179], [74.78375244, 13.03403187], [74.78347015, 13.0340271], [74.78347015, 13.03486061], [74.78320312, 13.03486061], [74.78320312, 13.03652954], [74.78291321, 13.03652668], [74.78291321, 13.03847122], [74.78263855, 13.03847122], [74.78263855, 13.03958416], [74.78235626, 13.0395813], [74.78235626, 13.04041958], [74.7820816, 13.04041767], [74.7820816, 13.04097176], [74.78180695, 13.04096889], [74.78180695, 13.04125023], [74.7820816, 13.04125023], [74.7820816, 13.04152966], [74.78180695, 13.04152966], [74.78180695, 13.04181004], [74.7820816, 13.04180622], [74.7820816, 13.04208374], [74.78180695, 13.04208374], [74.78180695, 13.04347229], [74.78152466, 13.04347229], [74.78152466, 13.04458427], [74.78125, 13.04458046], [74.78125, 13.04514027], [74.78098297, 13.04514027], [74.78098297, 13.04542065], [74.78125, 13.04541588], [74.78125, 13.04569435], [74.78097534, 13.04569435], [74.78097534, 13.04708195], [74.78069305, 13.04708195], [74.78069305, 13.04819393], [74.7804184, 13.04819202], [74.7804184, 13.04986], [74.78013611, 13.04986], [74.78013611, 13.05069447], [74.77986145, 13.05069447], [74.77986145, 13.05097294], [74.78013611, 13.05097294], [74.78013611, 13.05236053], [74.77958679, 13.05236053], [74.77958679, 13.05264091], [74.77929688, 13.05264091], [74.77929688, 13.0529213], [74.77986145, 13.05291653], [74.77986145, 13.05347347], [74.77958679, 13.05346966], [74.77958679, 13.05403137], [74.77929688, 13.05403137], [74.77929688, 13.05430889], [74.77902985, 13.05430698], [74.77902985, 13.0570507], [74.77902985, 13.05791664], [74.77874756, 13.05791664], [74.77874756, 13.05847263], [74.7784729, 13.05847073], [74.7784729, 13.06042194], [74.77819824, 13.06041718], [74.77819824, 13.06208324], [74.77791595, 13.06208134], [74.77791595, 13.06263924], [74.77820587, 13.06263924], [74.77820587, 13.06431007], [74.77791595, 13.06430531], [74.77791595, 13.06486225], [74.7776413, 13.06485939], [74.7776413, 13.06542015], [74.77735901, 13.06541538], [74.77735901, 13.06597233], [74.77707672, 13.06597233], [74.77707672, 13.06653023], [74.77680206, 13.06653023], [74.77680206, 13.0676403], [74.7765274, 13.0676403], [74.7765274, 13.06931019], [74.77625275, 13.06930637], [74.77625275, 13.0707798], [74.77625275, 13.07097244], [74.77597046, 13.07097244], [74.77597046, 13.07116127], [74.77597046, 13.07319355], [74.7756958, 13.07319164], [74.7756958, 13.07374954], [74.77541351, 13.07374954], [74.77541351, 13.07569408], [74.77513885, 13.07569408], [74.77513885, 13.07708454], [74.77485657, 13.07707977], [74.77485657, 13.07764053], [74.77458191, 13.07763767], [74.77458191, 13.07819462], [74.7765274, 13.07819462], [74.7765274, 13.07736015], [74.77680206, 13.07736015], [74.77680206, 13.07708454], [74.7765274, 13.07708454], [74.7765274, 13.0765276], [74.77680206, 13.07653141], [74.77680206, 13.07625008], [74.77707672, 13.07625008], [74.77707672, 13.07514], [74.77735901, 13.07514], [74.77735901, 13.07403088], [74.7776413, 13.07403088], [74.7776413, 13.07319164], [74.77791595, 13.07319355], [74.77791595, 13.07263756], [74.77819061, 13.07264042], [74.77820587, 13.07236004], [74.7784729, 13.07236004], [74.7784729, 13.07207966], [74.77874756, 13.07208443], [74.77874756, 13.07152843], [74.77902985, 13.07153034], [74.77902985, 13.07124996], [74.77929688, 13.07124996], [74.77929688, 13.0706892], [74.77958679, 13.07069397], [74.77958679, 13.06492138], [74.77958679, 13.06458378], [74.77971649, 13.06458378], [74.77986145, 13.06458378], [74.77986145, 13.06419182], [74.77986145, 13.06263924], [74.78013611, 13.06263924], [74.78013611, 13.06208134], [74.7804184, 13.06208324], [74.7804184, 13.06152725], [74.78069305, 13.06153202], [74.78069305, 13.06125069], [74.78096008, 13.06122017], [74.78097534, 13.06097126], [74.78125, 13.06097126], [74.78125, 13.06041718], [74.78180695, 13.06042194], [74.78180695, 13.06014061], [74.7820816, 13.06014061], [74.7820816, 13.05986118], [74.78236389, 13.05986118], [74.78236389, 13.05958271], [74.78263855, 13.05958271], [74.78263855, 13.05930519], [74.78320312, 13.05931187], [74.78320312, 13.05903244], [74.78424072, 13.05903244], [74.78430939, 13.05931187], [74.78457642, 13.05931187], [74.78457642, 13.06042194], [74.78443146, 13.06041718], [74.78430939, 13.06041718], [74.78430176, 13.06097126], [74.7840271, 13.06097126], [74.7840271, 13.06125069], [74.78375244, 13.06125069], [74.78375244, 13.06153202], [74.78320312, 13.06153202], [74.78320312, 13.06180954], [74.78291321, 13.06180954], [74.78291321, 13.06236076], [74.78263855, 13.06236076], [74.78263855, 13.06263924], [74.78236389, 13.06263924], [74.78236389, 13.06319332], [74.7820816, 13.06319141], [74.7820816, 13.06374931], [74.78151703, 13.06374931], [74.78151703, 13.06404114], [74.78098297, 13.06404114], [74.78098297, 13.06431007], [74.78069305, 13.06431007], [74.78069305, 13.06513977], [74.78125, 13.06513977], [74.78125, 13.06597233], [74.78152466, 13.06597233], [74.78152466, 13.06708431], [74.78125, 13.06708145], [74.78125, 13.0676403], [74.78097534, 13.0676403], [74.78097534, 13.06847191], [74.78069305, 13.06847191], [74.78069305, 13.06986237], [74.7804184, 13.06986237], [74.7804184, 13.07097244], [74.78013611, 13.07096958], [74.78013611, 13.07153034], [74.77986145, 13.07152843], [74.77986145, 13.07208443], [74.77958679, 13.07207966], [74.77958679, 13.07264042], [74.7793045, 13.07263756], [74.7793045, 13.07319355], [74.77958679, 13.07319355], [74.77958679, 13.07347202], [74.77929688, 13.07347202], [74.77929688, 13.07431126], [74.77902985, 13.07430553], [74.77902985, 13.07569408], [74.77874756, 13.07569027], [74.77874756, 13.07597923], [74.7784729, 13.0759716], [74.7784729, 13.07819462], [74.77874756, 13.07819462], [74.77874756, 13.07847309], [74.77902985, 13.07847309], [74.77902985, 13.07958317], [74.77929688, 13.07958031], [74.77929688, 13.07986069], [74.77902985, 13.07986069], [74.77902985, 13.08125114], [74.7793045, 13.08125114], [74.7793045, 13.08208275], [74.77902985, 13.08208275], [74.77902985, 13.08236122], [74.7793045, 13.08236122], [74.7793045, 13.08319473], [74.77958679, 13.08319473], [74.77958679, 13.08347321], [74.77986145, 13.0834713], [74.77986145, 13.08375072], [74.78013611, 13.08374882], [74.78013611, 13.08458328], [74.7804184, 13.08458328], [74.7804184, 13.0848608], [74.78069305, 13.0848608], [74.78069305, 13.08597088], [74.78098297, 13.08597088], [74.78098297, 13.08653164], [74.7811203, 13.08652878], [74.78125, 13.08652687], [74.78125, 13.08708286], [74.78152466, 13.08708286], [74.78152466, 13.08736134], [74.78180695, 13.08736134], [74.78180695, 13.08792019], [74.7820816, 13.08791733], [74.7820816, 13.08819485], [74.78236389, 13.08819485], [74.78235626, 13.0890913], [74.78235626, 13.08986092], [74.7820816, 13.08986092], [74.7820816, 13.09097958], [74.78180695, 13.09097958], [74.78180695, 13.09124947], [74.78151703, 13.09124947], [74.78151703, 13.09181023], [74.78125, 13.09180641], [74.78125, 13.0923624], [74.78098297, 13.0923624], [74.78098297, 13.09264183], [74.7804184, 13.09263992], [74.7804184, 13.09319401], [74.78013611, 13.09319401], [74.78013611, 13.09347153], [74.77986145, 13.09347153], [74.77986145, 13.09458447], [74.77958679, 13.0945816], [74.77958679, 13.09681129], [74.77986145, 13.09681129], [74.77986145, 13.09792042], [74.78013611, 13.09791565], [74.78013611, 13.09819412], [74.7804184, 13.09818935], [74.7804184, 13.09875011], [74.78069305, 13.09875011], [74.78069305, 13.09908962], [74.78069305, 13.09931087], [74.78125, 13.09930611], [74.78125, 13.09958363], [74.78272247, 13.09958363], [74.78391266, 13.09958363], [74.78430176, 13.09958363], [74.78430176, 13.09930611], [74.7848587, 13.09931087], [74.7848587, 13.09902954], [74.78542328, 13.09902954], [74.78542328, 13.09875011], [74.78624725, 13.09875011], [74.78624725, 13.09846973], [74.7868042, 13.09847164], [74.7868042, 13.09819412], [74.78736115, 13.09819412], [74.78736115, 13.09791565], [74.7895813, 13.09792042], [74.7895813, 13.09875011], [74.78736115, 13.09875011], [74.78736115, 13.09902954], [74.78679657, 13.09902954], [74.78679657, 13.09931087], [74.78624725, 13.09930611], [74.78624725, 13.09957123], [74.78541565, 13.09958363], [74.78541565, 13.0998621], [74.7848587, 13.09986019], [74.7848587, 13.10015202], [74.78430939, 13.10015202], [74.78430176, 13.10042095], [74.78125, 13.10042095], [74.78125, 13.10015202], [74.78069305, 13.10015202], [74.78069305, 13.09986019], [74.78013611, 13.0998621], [74.78013611, 13.09958363], [74.77986145, 13.09958363], [74.77986145, 13.09930611], [74.7784729, 13.09931087], [74.7784729, 13.09875011], [74.77820587, 13.09875011], [74.77819061, 13.09818935], [74.77791595, 13.09819412], [74.77791595, 13.09736156], [74.77803802, 13.09736156], [74.77819061, 13.09735966], [74.77819061, 13.09624958], [74.77791595, 13.09624958], [74.77791595, 13.09514046], [74.77819061, 13.09514046], [74.77819061, 13.09486198], [74.77791595, 13.09486198], [74.77791595, 13.09319115], [74.77819061, 13.09319401], [74.77819824, 13.09263992], [74.7784729, 13.09264183], [74.7784729, 13.09208107], [74.77902985, 13.09208393], [74.77902985, 13.09180641], [74.77929688, 13.09181023], [74.77929688, 13.09097958], [74.77958679, 13.09097958], [74.77958679, 13.09069061], [74.77986145, 13.09069347], [74.77986145, 13.08986092], [74.78013611, 13.08986092], [74.78013611, 13.08958054], [74.77986145, 13.0895834], [74.77986145, 13.08930492], [74.77958679, 13.08930969], [74.77958679, 13.08819103], [74.7793045, 13.08819485], [74.7793045, 13.08625126], [74.77902985, 13.08625126], [74.77902985, 13.08569145], [74.7784729, 13.08569527], [74.7784729, 13.08541679], [74.77819824, 13.08541679], [74.77819824, 13.08569527], [74.77791595, 13.08569527], [74.77791595, 13.08597088], [74.77708435, 13.08597088], [74.77708435, 13.08541679], [74.7765274, 13.08542156], [74.7765274, 13.08458138], [74.77625275, 13.08458328], [74.77625275, 13.08152676], [74.77597046, 13.08153057], [74.77597046, 13.0818119], [74.7756958, 13.08180523], [74.7756958, 13.08208275], [74.77514648, 13.08208275], [74.77514648, 13.08264065], [74.77430725, 13.08263874], [74.77430725, 13.08283043], [74.77430725, 13.08291721], [74.77402496, 13.08291721], [74.77402496, 13.08319473], [74.77348328, 13.08318996], [74.77348328, 13.08375072], [74.77319336, 13.08374882], [74.77319336, 13.08458328], [74.7729187, 13.08458138], [74.7729187, 13.08542156], [74.77263641, 13.08542156], [74.77263641, 13.08625126], [74.77236176, 13.08625126], [74.77236176, 13.08736134], [74.7720871, 13.08736134], [74.7720871, 13.0895834], [74.77179718, 13.08958054], [74.77179718, 13.09013939], [74.77153015, 13.09013939], [74.77153015, 13.09069347], [74.77124786, 13.09069061], [74.77124786, 13.09181023], [74.77097321, 13.09180641], [74.77097321, 13.0923624], [74.77069092, 13.0923624], [74.77069092, 13.09375191], [74.77041626, 13.09375191], [74.77041626, 13.09430981], [74.7701416, 13.09430981], [74.7701416, 13.09486198], [74.76985931, 13.09486198], [74.76985931, 13.09542274], [74.76958466, 13.09541798], [74.76958466, 13.09708405], [74.76930237, 13.09707928], [74.76930237, 13.09931087], [74.76902008, 13.09931087], [74.76902008, 13.10042095], [74.76875305, 13.10042095], [74.76875305, 13.10124969], [74.76847076, 13.10124969], [74.76847076, 13.10153103], [74.76819611, 13.10152817], [74.76819611, 13.10208225], [74.76847076, 13.10208225], [74.76847076, 13.10319424], [74.76819611, 13.10319042], [74.76819611, 13.10375023], [74.76790619, 13.10375023], [74.76790619, 13.10514069], [74.76763916, 13.10513783], [74.76763916, 13.10708332], [74.7673645, 13.10708332], [74.7673645, 13.1081953], [74.76708221, 13.10818958], [74.76708221, 13.1093092], [74.76680756, 13.10930538], [74.76680756, 13.11069489], [74.7665329, 13.11069012], [74.7665329, 13.11181164], [74.76625061, 13.11180496], [74.76625061, 13.11319542], [74.76597595, 13.11319065], [74.76597595, 13.11431026], [74.76568604, 13.11431026], [74.76568604, 13.11542034], [74.76541901, 13.11541653], [74.76541901, 13.11597347], [74.76513672, 13.11597061], [74.76513672, 13.11681175], [74.76486206, 13.11681175], [74.76486206, 13.11736107], [74.76457977, 13.11736107], [74.76457977, 13.11958408], [74.76431274, 13.11958122], [74.76431274, 13.12180996], [74.76403046, 13.12180996], [74.76403046, 13.12263966], [74.76374817, 13.12263966], [74.76374817, 13.12374973], [74.76347351, 13.12374973], [74.76347351, 13.1245842], [74.76319122, 13.12457943], [74.76319122, 13.12541962], [74.76291656, 13.12541962], [74.76291656, 13.12652969], [74.76264191, 13.12652779], [74.76264191, 13.12736225], [74.76235962, 13.12736225], [74.76235962, 13.13069439], [74.76208496, 13.13069439], [74.76208496, 13.13097191], [74.76180267, 13.13097], [74.76180267, 13.13125134], [74.76152802, 13.13125134], [74.76152802, 13.1334734], [74.76125336, 13.13346958], [74.76125336, 13.13431072], [74.76097107, 13.13431072], [74.76097107, 13.13486099], [74.76069641, 13.13486099], [74.76069641, 13.13625145], [74.76040649, 13.13625145], [74.76040649, 13.13875103], [74.76014709, 13.13875103], [74.76014709, 13.13932133], [74.75986481, 13.13930511], [74.75986481, 13.14097118], [74.75958252, 13.14097118], [74.75958252, 13.14208317], [74.75930786, 13.14208317], [74.75930786, 13.14319324], [74.7590332, 13.14319134], [74.7590332, 13.14402962], [74.75875092, 13.14402676], [74.75875092, 13.14458275], [74.75846863, 13.14458275], [74.75846863, 13.14708424], [74.75791931, 13.14708424], [74.75791931, 13.15069389], [74.75763702, 13.15069199], [74.75763702, 13.15153027], [74.75736237, 13.15153027], [74.75736237, 13.15235996], [74.75708008, 13.15235996], [74.75708008, 13.15254021], [74.75708008, 13.15347195], [74.75695801, 13.15347195], [74.75680542, 13.15347195], [74.75680542, 13.15468025], [74.75680542, 13.1548624], [74.75653076, 13.1548624], [74.75653076, 13.15569401], [74.75624847, 13.15569019], [74.75624847, 13.15653133], [74.75596619, 13.15653133], [74.75596619, 13.15792084], [74.75569153, 13.15792084], [74.75569153, 13.15875053], [74.75541687, 13.15875053], [74.75541687, 13.15986061], [74.75514221, 13.15986061], [74.75514221, 13.16069508], [74.75485992, 13.16069031], [74.75485992, 13.16292095], [74.7545929, 13.16292095], [74.7545929, 13.16375065], [74.75430298, 13.16374874], [74.75430298, 13.16458321], [74.75402069, 13.1645813], [74.75402069, 13.16542244], [74.75374603, 13.16542244], [74.75374603, 13.16625977], [74.75347137, 13.16625118], [74.75347137, 13.16736126], [74.75319672, 13.16736126], [74.75319672, 13.16819477], [74.75291443, 13.16819477], [74.75291443, 13.16930485], [74.75263977, 13.16930103], [74.75263977, 13.16986084], [74.75235748, 13.16986084], [74.75235748, 13.17013931], [74.75208282, 13.17013931], [74.75208282, 13.17236233], [74.75180817, 13.17236233], [74.75180817, 13.17319584], [74.75152588, 13.17319107], [74.75152588, 13.17430973], [74.75125122, 13.17430973], [74.75125122, 13.17514038], [74.75097656, 13.17514038], [74.75097656, 13.17653179], [74.75041962, 13.17653179], [74.75041962, 13.17681026], [74.75013733, 13.17681026], [74.75013733, 13.17903042], [74.74986267, 13.17902756], [74.74986267, 13.17958355], [74.74958038, 13.17957973], [74.74958038, 13.17986012], [74.74931335, 13.17986012], [74.74931335, 13.18153095], [74.74903107, 13.18152809], [74.74903107, 13.18208218], [74.74874878, 13.18208027], [74.74874878, 13.18264008], [74.74847412, 13.18263817], [74.74846649, 13.18346119], [74.74846649, 13.18375015], [74.74819183, 13.18375015], [74.74819183, 13.18430424], [74.74791718, 13.18430042], [74.74791718, 13.18514061], [74.74764252, 13.18513775], [74.74764252, 13.18597317], [74.74736023, 13.18597031], [74.74736023, 13.18653107], [74.7470932, 13.18653107], [74.7470932, 13.18681145], [74.74680328, 13.18681145], [74.74680328, 13.1873703], [74.74652863, 13.18738079], [74.74652863, 13.18792057], [74.74635315, 13.18791676], [74.74624634, 13.18791676], [74.74624634, 13.18819523], [74.74597168, 13.18819046], [74.74597168, 13.18875122], [74.74569702, 13.18875122], [74.74569702, 13.18958282], [74.74541473, 13.18958282], [74.74541473, 13.18976974], [74.7454071, 13.19014072], [74.74514008, 13.19013882], [74.74514008, 13.19024086], [74.74514008, 13.19069481], [74.74497986, 13.19069481], [74.74485779, 13.19069481], [74.74485779, 13.19097328], [74.74458313, 13.19097137], [74.74458313, 13.19124889], [74.74430847, 13.19124889], [74.74430847, 13.19181156], [74.74402618, 13.19181156], [74.74402618, 13.19292164], [74.74375153, 13.19292164], [74.74375153, 13.19375134], [74.74346924, 13.19375134], [74.74346924, 13.194911], [74.74346924, 13.19819641], [74.74318695, 13.19819069], [74.74318695, 13.20014191], [74.74291992, 13.20014191], [74.74291992, 13.20153046], [74.74263763, 13.20153046], [74.74263763, 13.20263958], [74.74236298, 13.20263958], [74.74236298, 13.20374966], [74.74208069, 13.20374966], [74.74208069, 13.20458412], [74.74180603, 13.20458412], [74.74180603, 13.2056942], [74.74153137, 13.20568943], [74.74153137, 13.20681095], [74.74124908, 13.20681095], [74.74124908, 13.20763969], [74.74097443, 13.20763779], [74.74097443, 13.20847225], [74.74069214, 13.20847034], [74.74069214, 13.20903111], [74.74041748, 13.20903111], [74.74041748, 13.20931053], [74.74013519, 13.20930576], [74.74013519, 13.21208191], [74.73986053, 13.21208], [74.73986053, 13.21375084], [74.73958588, 13.21375084], [74.73958588, 13.21486092], [74.73930359, 13.21486092], [74.73930359, 13.21569538], [74.73902893, 13.21569538], [74.73902893, 13.21708298], [74.73874664, 13.21708012], [74.73874664, 13.21875095], [74.73847198, 13.21875095], [74.73847198, 13.22014141], [74.73819733, 13.22013855], [74.73819733, 13.22069454], [74.73792267, 13.22069073], [74.73792267, 13.22153187], [74.73764038, 13.2215271], [74.73764038, 13.22236061], [74.73735809, 13.22236061], [74.73735809, 13.22264194], [74.73707581, 13.22264194], [74.73707581, 13.22292042], [74.73680878, 13.2229166], [74.73680878, 13.22319317], [74.73652649, 13.22319126], [74.73652649, 13.22348022], [74.73625183, 13.22348022], [74.73625183, 13.22375202], [74.73597717, 13.22375202], [74.73597717, 13.22402954], [74.73569489, 13.22402668], [74.73569489, 13.22847176], [74.73542023, 13.22846889], [74.73542023, 13.22931004], [74.73513794, 13.22931004], [74.73513794, 13.23042011], [74.73486328, 13.23042011], [74.73486328, 13.23153019], [74.73458099, 13.23153019], [74.73458099, 13.23264027], [74.73430634, 13.23264027], [74.73430634, 13.23375034], [74.73401642, 13.23375034], [74.73401642, 13.23513985], [74.73374939, 13.23513794], [74.73374939, 13.23569393], [74.73401642, 13.23569202], [74.73401642, 13.23624992], [74.73374939, 13.23624992], [74.73374939, 13.23708439], [74.7334671, 13.23707962], [74.7334671, 13.23875141], [74.73319244, 13.23875141], [74.73319244, 13.2404213], [74.73291016, 13.2404213], [74.73291016, 13.24180889], [74.7326355, 13.24180698], [74.7326355, 13.24347305], [74.73236084, 13.24347115], [74.73236084, 13.24514103], [74.73208618, 13.24513912], [74.73208618, 13.24736118], [74.73179626, 13.24736118], [74.73179626, 13.24930954], [74.73152924, 13.24930954], [74.73152924, 13.25041962], [74.73124695, 13.25041962], [74.73124695, 13.25152969], [74.73097229, 13.25152969], [74.73097229, 13.25264168], [74.73069763, 13.25264168], [74.73069763, 13.25374985], [74.73041534, 13.25374985], [74.73042297, 13.25486183], [74.73014069, 13.25486183], [74.73014069, 13.25625038], [74.72985077, 13.25625038], [74.72985077, 13.25764179], [74.72957611, 13.25764179], [74.72957611, 13.25874996], [74.72930908, 13.25874996], [74.72930908, 13.26014042], [74.72902679, 13.26014042], [74.72902679, 13.26124954], [74.72875214, 13.26124954], [74.72875214, 13.26236153], [74.72846985, 13.26236153], [74.72846985, 13.2634716], [74.72819519, 13.2634716], [74.72819519, 13.26458454], [74.7279129, 13.26458454], [74.7279129, 13.26569366], [74.72763824, 13.26568985], [74.72763824, 13.26681137], [74.72735596, 13.26681137], [74.72735596, 13.26792145], [74.7270813, 13.26792145], [74.7270813, 13.26903057], [74.72680664, 13.26903057], [74.72680664, 13.27014065], [74.72652435, 13.27013874], [74.72652435, 13.27069473], [74.72624969, 13.27068996], [74.72624969, 13.27125072], [74.72598267, 13.27125072], [74.72598267, 13.27181244], [74.72569275, 13.27180481], [74.72569275, 13.2723608], [74.72541809, 13.2723608], [74.72541809, 13.27292156], [74.7251358, 13.27291679], [74.7251358, 13.27347088], [74.72486115, 13.27347088], [74.72486115, 13.27403164], [74.72458649, 13.27403164], [74.72458649, 13.27458954], [74.72429657, 13.27458954], [74.72429657, 13.27542019], [74.72403717, 13.27542019], [74.72403717, 13.27652931], [74.72374725, 13.27652931], [74.72374725, 13.27736092], [74.7234726, 13.27736092], [74.7234726, 13.27819633], [74.72319794, 13.27819061], [74.72319794, 13.27874947], [74.72292328, 13.27874947], [74.72292328, 13.27931023], [74.72264099, 13.27931023], [74.72264099, 13.28014183], [74.7223587, 13.28013992], [74.7223587, 13.28069305], [74.72207642, 13.28069115], [74.72207642, 13.28125191], [74.72180939, 13.28125191], [74.72180176, 13.28180981], [74.7215271, 13.28180981], [74.7215271, 13.28264046], [74.72125244, 13.2826376], [74.72125244, 13.28319359], [74.72097015, 13.28319073], [74.72097015, 13.28402996], [74.7206955, 13.28402805], [74.7206955, 13.28708363], [74.72041321, 13.28707981], [74.72041321, 13.28763962], [74.72013855, 13.28763771], [74.72013855, 13.2881937], [74.71986389, 13.2881937], [74.71986389, 13.29069424], [74.7195816, 13.29069042], [74.7195816, 13.29431057], [74.71985626, 13.29431057], [74.71985626, 13.2962513], [74.7195816, 13.2962513], [74.7195816, 13.2968092], [74.71930695, 13.29680538], [74.71930695, 13.29736137], [74.71902466, 13.29736137], [74.71902466, 13.29958344], [74.71875, 13.29958344], [74.71875, 13.30236053], [74.71848297, 13.30236053], [74.71848297, 13.30375099], [74.71819305, 13.30375099], [74.71819305, 13.30513859], [74.71791077, 13.30513859], [74.71791077, 13.30681038], [74.71763611, 13.30680561], [74.71763611, 13.30819416], [74.71736145, 13.3081913], [74.71736145, 13.30930996], [74.71763611, 13.30930614], [74.71763611, 13.30986214], [74.71736145, 13.30986023], [74.71736145, 13.31042004], [74.71708679, 13.31041622], [74.71708679, 13.31097221], [74.71679688, 13.31096935], [74.71679688, 13.31180954], [74.71652985, 13.31180954], [74.71652985, 13.31264019], [74.71624756, 13.31264019], [74.71624756, 13.31376076], [74.7159729, 13.31375027], [74.7159729, 13.31458378], [74.71569824, 13.31458378], [74.71569824, 13.31569386], [74.71541595, 13.31569386], [74.71541595, 13.31680584], [74.7151413, 13.31680202], [74.7151413, 13.31735992], [74.71486664, 13.31735992], [74.71486664, 13.31792068], [74.71458435, 13.31791592], [74.71458435, 13.31847191], [74.71430206, 13.31847], [74.71430206, 13.31903076], [74.7140274, 13.31903076], [74.7140274, 13.3215313], [74.71375275, 13.32152557], [74.71375275, 13.32208347], [74.71347046, 13.32207966], [74.71347046, 13.32264137], [74.7131958, 13.32263947], [74.7131958, 13.32319546], [74.71290588, 13.32318974], [74.71290588, 13.32375145], [74.71263885, 13.32375145], [74.71263885, 13.32430935], [74.71235657, 13.32430935], [74.71235657, 13.32542133], [74.71208191, 13.32541656], [74.71208191, 13.32708263], [74.71180725, 13.32708263], [74.71180725, 13.32819462], [74.71151733, 13.3281908], [74.71151733, 13.32903194], [74.71125031, 13.32902718], [74.71125031, 13.32958317], [74.71098328, 13.32958126], [74.71098328, 13.33014202], [74.71069336, 13.33013916], [74.71069336, 13.33069324], [74.7104187, 13.33069134], [74.7104187, 13.33124924], [74.71013641, 13.33124924], [74.71013641, 13.33180523], [74.70986176, 13.33180523], [74.70986176, 13.33236122], [74.7095871, 13.33235931], [74.7095871, 13.33292198], [74.70930481, 13.33291531], [74.70930481, 13.33319569], [74.70903015, 13.33319092], [74.70903015, 13.33375168], [74.70874023, 13.33375168], [74.70874023, 13.33403015], [74.70847321, 13.33403015], [74.70847321, 13.33430958], [74.70819092, 13.33430958], [74.70819092, 13.33487129], [74.70791626, 13.33487129], [74.70791626, 13.33514023], [74.7076416, 13.33514023], [74.7076416, 13.33569431], [74.70735931, 13.33569145], [74.70735931, 13.33625031], [74.70707703, 13.33625031], [74.70707703, 13.33652973], [74.70680237, 13.33652782], [74.70680237, 13.33708382], [74.70652771, 13.33708382], [74.70652771, 13.33736229], [74.70625305, 13.33736038], [74.70625305, 13.33763981], [74.70597076, 13.33763981], [74.70597076, 13.33793163], [74.70569611, 13.33791637], [74.70569611, 13.33819389], [74.70541382, 13.33819389], [74.70541382, 13.33847237], [74.70513916, 13.33847046], [74.70513916, 13.33875179], [74.70485687, 13.33875179], [74.70485687, 13.33903027], [74.70469666, 13.33903027], [74.70458221, 13.33903027], [74.70458221, 13.33931065], [74.70402527, 13.33930588], [74.70402527, 13.33958435], [74.70375061, 13.33957863], [74.70375061, 13.33985996], [74.70318604, 13.33985996], [74.70318604, 13.34014034], [74.70292664, 13.34014034], [74.70292664, 13.34042263], [74.70236206, 13.34041595], [74.70236206, 13.34069443], [74.70180511, 13.34069443], [74.70180511, 13.34097195], [74.70153046, 13.34097195], [74.70153046, 13.34125042], [74.70096588, 13.34125042], [74.70096588, 13.34153271], [74.70069122, 13.34153271], [74.70069122, 13.34181118], [74.70014191, 13.34180641], [74.70014191, 13.34208202], [74.69958496, 13.34208202], [74.69958496, 13.3423624], [74.69930267, 13.34235954], [74.69930267, 13.34263992], [74.69875336, 13.34263992], [74.69875336, 13.34292126], [74.69847107, 13.34291553], [74.69847107, 13.34319401], [74.69791412, 13.34319401], [74.69791412, 13.34347153], [74.69736481, 13.34347153], [74.69736481, 13.34375], [74.69708252, 13.34374142], [74.69708252, 13.34403133], [74.6965332, 13.34403133], [74.6965332, 13.34431076], [74.69596863, 13.34430599], [74.69596863, 13.34458447], [74.69568634, 13.3445797], [74.69568634, 13.34486008], [74.69513702, 13.34486008], [74.69513702, 13.34514141], [74.69486237, 13.34514141], [74.69486237, 13.34542084], [74.69458008, 13.34541607], [74.69458008, 13.34569359], [74.69430542, 13.34569359], [74.69430542, 13.34597206], [74.69403076, 13.34597015], [74.69403076, 13.34625053], [74.69374084, 13.34625053], [74.69374084, 13.34653091], [74.69346619, 13.34653091], [74.69346619, 13.34681129], [74.69291687, 13.34680653], [74.69291687, 13.34708214], [74.69264221, 13.34708214], [74.69264221, 13.34735966], [74.69235992, 13.34735966], [74.69235992, 13.34764099], [74.69180298, 13.34764099], [74.69180298, 13.34792137], [74.69125366, 13.3479166], [74.69125366, 13.34819508], [74.69097137, 13.34819508], [74.69097137, 13.3484726], [74.6904068, 13.34846973], [74.6904068, 13.34903145], [74.69124603, 13.34903145], [74.69124603, 13.34875107], [74.69180298, 13.34875107], [74.69180298, 13.34846973], [74.69235992, 13.3484726], [74.69235992, 13.34819508], [74.69291687, 13.34819508], [74.69291687, 13.3479166], [74.69319153, 13.34792137], [74.69319153, 13.34764099], [74.69374084, 13.34764099], [74.69374084, 13.34735966], [74.69430542, 13.34735966], [74.69430542, 13.34708214], [74.69486237, 13.34708214], [74.69486237, 13.34680653], [74.69541931, 13.34681129], [74.69541931, 13.34653091], [74.69596863, 13.34653091], [74.69596863, 13.34625053], [74.6965332, 13.34625053], [74.6965332, 13.34597015], [74.69680786, 13.34597206], [74.69680786, 13.34569359], [74.69736481, 13.34569359], [74.69736481, 13.34541607], [74.69763947, 13.34542084], [74.69763947, 13.34514141], [74.69819641, 13.34514141], [74.69819641, 13.34486008], [74.69847107, 13.34486008], [74.69847107, 13.3445797], [74.69902802, 13.34458447], [74.69902802, 13.34430599], [74.69930267, 13.34431076], [74.69930267, 13.34403133], [74.69986725, 13.34403133], [74.69986725, 13.34374142], [74.70014191, 13.34375], [74.70014191, 13.34347153], [74.70069122, 13.34347153], [74.70069122, 13.34319401], [74.70124817, 13.34319401], [74.70124817, 13.34291553], [74.70181274, 13.34292126], [74.70181274, 13.34263992], [74.70236206, 13.34263992], [74.70236206, 13.34235954], [74.70263672, 13.3423624], [74.70263672, 13.34208202], [74.70319366, 13.34208202], [74.70319366, 13.34180641], [74.70375061, 13.34181118], [74.70375061, 13.34153271], [74.70430756, 13.34153271], [74.70430756, 13.34125042], [74.70513916, 13.34125042], [74.70513916, 13.34014034], [74.70526123, 13.34014034], [74.70540619, 13.34014034], [74.70540619, 13.33957863], [74.70597076, 13.33958435], [74.70597076, 13.33930588], [74.70614624, 13.33930779], [74.70625305, 13.33931065], [74.70625305, 13.33912086], [74.70625305, 13.33902836], [74.70652771, 13.33903027], [74.70652771, 13.33875179], [74.70707703, 13.33875179], [74.70707703, 13.33847046], [74.70652771, 13.33847237], [74.70652771, 13.33819389], [74.70680237, 13.33819389], [74.70680237, 13.33791637], [74.70691681, 13.33792019], [74.70735931, 13.33793163], [74.70735931, 13.33763981], [74.7076416, 13.33763981], [74.7076416, 13.33736038], [74.70819092, 13.33736229], [74.70819092, 13.33708382], [74.70847321, 13.33708382], [74.70847321, 13.3368063], [74.70903015, 13.33681011], [74.70903015, 13.33652973], [74.70929718, 13.33652973], [74.70929718, 13.33514023], [74.7095871, 13.33514023], [74.7095871, 13.33487129], [74.70986176, 13.33487129], [74.70986176, 13.33430958], [74.71013641, 13.33430958], [74.71013641, 13.33403015], [74.7104187, 13.33403015], [74.7104187, 13.33375168], [74.71069336, 13.33375168], [74.71069336, 13.3334713], [74.71097565, 13.3334713], [74.71097565, 13.33319569], [74.71125031, 13.33319569], [74.71125031, 13.33263969], [74.71151733, 13.33263969], [74.71151733, 13.33235931], [74.71180725, 13.33236122], [74.71180725, 13.33208275], [74.71208191, 13.33208275], [74.71208191, 13.33180523], [74.7123642, 13.33180523], [74.7123642, 13.33152676], [74.71263885, 13.33152962], [74.71263885, 13.33097076], [74.71291351, 13.33097076], [74.71290588, 13.33069134], [74.7131958, 13.33069324], [74.7131958, 13.32958317], [74.71347046, 13.32958317], [74.71347046, 13.32847309], [74.71375275, 13.32847309], [74.71375275, 13.32763863], [74.7140274, 13.32764053], [74.7140274, 13.32653141], [74.71430206, 13.32653141], [74.71430206, 13.32625103], [74.71457672, 13.32625103], [74.71457672, 13.32570171], [74.71486664, 13.32570171], [74.71486664, 13.32542133], [74.7151413, 13.32542133], [74.7151413, 13.32486057], [74.71541595, 13.32486057], [74.71541595, 13.32374859], [74.71569061, 13.32375145], [74.71569824, 13.32293034], [74.7159729, 13.32293034], [74.7159729, 13.32238102], [74.71624756, 13.32236099], [74.71624756, 13.32184982], [74.71624756, 13.32125092], [74.71649933, 13.32125092], [74.71649933, 13.32113934], [74.71652985, 13.31958199], [74.7168045, 13.31958199], [74.7168045, 13.31791592], [74.71708679, 13.31792068], [74.71708679, 13.31458187], [74.71736145, 13.31458378], [74.71736145, 13.31347179], [74.71763611, 13.31347179], [74.71763611, 13.31180954], [74.71791077, 13.31180954], [74.71791077, 13.31096935], [74.71819305, 13.31097221], [74.71819305, 13.31069374], [74.71791077, 13.31070137], [74.71791077, 13.30986023], [74.71819305, 13.30986214], [74.71819305, 13.30902767], [74.71848297, 13.30902958], [74.71848297, 13.3081913], [74.71875, 13.30819416], [74.71875, 13.30708408], [74.71902466, 13.30708408], [74.71902466, 13.30597115], [74.71930695, 13.30597115], [74.71930695, 13.30513859], [74.7195816, 13.30513859], [74.7195816, 13.3045702], [74.71986389, 13.3045826], [74.71986389, 13.30125141], [74.7195816, 13.30125141], [74.7195816, 13.30014133], [74.71985626, 13.30014133], [74.71985626, 13.29847145], [74.72013855, 13.29847336], [74.72013855, 13.29652882], [74.72041321, 13.29653072], [74.72041321, 13.29125023], [74.72070313, 13.29125023], [74.7206955, 13.28902817], [74.72097015, 13.28903103], [74.72097015, 13.28736019], [74.72125244, 13.2873621], [74.72125244, 13.28625011], [74.7215271, 13.28625011], [74.7215271, 13.28514004], [74.72180176, 13.28514004], [74.72180176, 13.28402996], [74.72207642, 13.28402996], [74.72207642, 13.28345966], [74.7223587, 13.28347206], [74.7223587, 13.28319359], [74.72264099, 13.28319359], [74.72264099, 13.2826376], [74.72292328, 13.28264046], [74.72292328, 13.28208065], [74.72319794, 13.28208447], [74.72319794, 13.28152847], [74.7234726, 13.28153038], [74.7234726, 13.28069115], [74.72374725, 13.28069305], [74.72374725, 13.2798624], [74.72402954, 13.2798624], [74.72402954, 13.27958393], [74.7243042, 13.27958393], [74.7243042, 13.27902699], [74.72458649, 13.27903175], [74.72458649, 13.27874947], [74.72486115, 13.27874947], [74.72486115, 13.27847099], [74.7251358, 13.27847099], [74.7251358, 13.27819633], [74.72569275, 13.27819633], [74.72569275, 13.27791691], [74.72598267, 13.27791977], [74.72598267, 13.27765083], [74.72651672, 13.27765083], [74.72651672, 13.27736092], [74.72680664, 13.27736092], [74.72680664, 13.27708054], [74.7270813, 13.2770834], [74.7270813, 13.27680492], [74.72846985, 13.27680492], [74.72846985, 13.2770834], [74.72902679, 13.27708054], [74.72902679, 13.27791977], [74.72875214, 13.27791977], [74.72875214, 13.27903175], [74.72902679, 13.27903175], [74.72902679, 13.2804203], [74.72930908, 13.2804203], [74.72930908, 13.28153038], [74.72957611, 13.28153038], [74.72957611, 13.28236198], [74.73014069, 13.28236198], [74.73014069, 13.28319359], [74.73041534, 13.28319359], [74.73041534, 13.28347206], [74.73014069, 13.28345966], [74.73014069, 13.28431034], [74.7298584, 13.28430557], [74.7298584, 13.28458405], [74.72930908, 13.28458405], [74.72930908, 13.28486156], [74.72902679, 13.28485966], [74.72902679, 13.28542042], [74.72930908, 13.28541565], [74.72930908, 13.28569412], [74.73014069, 13.28569412], [74.73014069, 13.28597164], [74.73152924, 13.28596973], [74.73152924, 13.28625011], [74.73208618, 13.28625011], [74.73208618, 13.28652954], [74.73236084, 13.28652954], [74.73236084, 13.28682041], [74.73291779, 13.28680611], [74.73291779, 13.28708363], [74.73347473, 13.28708363], [74.73347473, 13.2873621], [74.73374939, 13.28736019], [74.73374939, 13.28763962], [74.73401642, 13.28763962], [74.73401642, 13.28792095], [74.73430634, 13.28791618], [74.73430634, 13.2881937], [74.73486328, 13.2881937], [74.73486328, 13.28847218], [74.73542023, 13.28847027], [74.73542023, 13.28874969], [74.73568726, 13.28874969], [74.73568726, 13.28931141], [74.73597717, 13.28931141], [74.73597717, 13.28959084], [74.73568726, 13.28959084], [74.73568726, 13.29014015], [74.73513794, 13.29014015], [74.73513794, 13.29042053], [74.73374939, 13.29042053], [74.73374939, 13.29014015], [74.73291016, 13.29014015], [74.73291016, 13.28985977], [74.7326355, 13.28985977], [74.7326355, 13.28958225], [74.73236084, 13.28959084], [74.73236084, 13.28931141], [74.73208618, 13.28931141], [74.73208618, 13.28874969], [74.73179626, 13.28874969], [74.73179626, 13.2881918], [74.73152924, 13.2881937], [74.73152924, 13.28763771], [74.73124695, 13.28763962], [74.73124695, 13.28736019], [74.72930908, 13.28736019], [74.72930908, 13.28763962], [74.72957611, 13.28763962], [74.72957611, 13.28792095], [74.72875214, 13.28791618], [74.72875214, 13.2881937], [74.7279129, 13.2881937], [74.7279129, 13.28847218], [74.72759247, 13.28847218], [74.72735596, 13.28847027], [74.72735596, 13.28874969], [74.72651672, 13.28874969], [74.72651672, 13.28903103], [74.72598267, 13.28903103], [74.72598267, 13.28931141], [74.7251358, 13.28931141], [74.7251358, 13.28959084], [74.72458649, 13.28959084], [74.72458649, 13.28985977], [74.72429657, 13.28985977], [74.72429657, 13.29014015], [74.72374725, 13.29013824], [74.72374725, 13.29097176], [74.7234726, 13.29096985], [74.7234726, 13.29181099], [74.72319794, 13.29180431], [74.72319794, 13.29263783], [74.72291565, 13.29263783], [74.72291565, 13.29347324], [74.72264099, 13.29347038], [74.72264099, 13.29403114], [74.7223587, 13.29403114], [74.7223587, 13.29514122], [74.72251892, 13.29514122], [74.72264099, 13.29514122], [74.72264099, 13.29653072], [74.72292328, 13.29653072], [74.72292328, 13.29763889], [74.72319794, 13.29763889], [74.72319794, 13.29876041], [74.7234726, 13.29876041], [74.7234726, 13.29903126], [74.72319794, 13.29902744], [74.72319794, 13.29958344], [74.72291565, 13.29958344], [74.72292328, 13.29986095], [74.72264099, 13.29986095], [74.72264099, 13.30042171], [74.72291565, 13.30041695], [74.72291565, 13.30097103], [74.72319794, 13.30097103], [74.72319794, 13.30182076], [74.7234726, 13.30180454], [74.7234726, 13.30208302], [74.72319794, 13.30208111], [74.72319794, 13.30292034], [74.72291565, 13.30291653], [74.72291565, 13.30347347], [74.72264099, 13.30347347], [74.72264099, 13.3045826], [74.7223587, 13.3045702], [74.7223587, 13.30486107], [74.72180939, 13.30486107], [74.72180939, 13.30500031], [74.72180176, 13.30513859], [74.7215271, 13.30513859], [74.7215271, 13.30569553], [74.72175598, 13.30569553], [74.72208405, 13.30569553], [74.72208405, 13.30597115], [74.7223587, 13.30596924], [74.7223587, 13.30625153], [74.72207642, 13.30625153], [74.72207642, 13.30653191], [74.7223587, 13.30653191], [74.7223587, 13.3073616], [74.72208405, 13.3073616], [74.72208405, 13.30819416], [74.72180939, 13.3081913], [74.72180176, 13.30875015], [74.7215271, 13.30875015], [74.7215271, 13.30930996], [74.72125244, 13.30930996], [74.72125244, 13.31013966], [74.72097015, 13.31013775], [74.72097015, 13.31235981], [74.7206955, 13.31235981], [74.72070313, 13.31347179], [74.72041321, 13.31347179], [74.72041321, 13.31458378], [74.72013855, 13.31458187], [74.72013855, 13.3154211], [74.71986389, 13.31541634], [74.71986389, 13.31569386], [74.72013855, 13.31569386], [74.72013855, 13.31597233], [74.71986389, 13.31597233], [74.71986389, 13.31680584], [74.7195816, 13.31680202], [74.7195816, 13.31903076], [74.71930695, 13.31903076], [74.71930695, 13.32014084], [74.71901703, 13.32014084], [74.71901703, 13.32042122], [74.71875, 13.32042122], [74.71875, 13.3215313], [74.71847534, 13.32152557], [74.71847534, 13.32208347], [74.71875, 13.32208347], [74.71875, 13.32319546], [74.71848297, 13.32318974], [74.71848297, 13.32375145], [74.71875, 13.32375145], [74.71875, 13.32430935], [74.71847534, 13.32430458], [74.71847534, 13.32458305], [74.71875, 13.32458305], [74.71875, 13.32486057], [74.71848297, 13.32486057], [74.71848297, 13.32542133], [74.71819305, 13.32541656], [74.71819305, 13.32597256], [74.71763611, 13.32597256], [74.71763611, 13.32736111], [74.71736145, 13.32736111], [74.71736145, 13.32764053], [74.71708679, 13.32763863], [74.71708679, 13.32819462], [74.71679688, 13.3281908], [74.71679688, 13.32903194], [74.71652985, 13.32902718], [74.71652985, 13.32958317], [74.7159729, 13.32958126], [74.7159729, 13.32986069], [74.71569824, 13.32986069], [74.71569824, 13.33014202], [74.7151413, 13.33013916], [74.7151413, 13.33069324], [74.71485901, 13.33069324], [74.71486664, 13.33124924], [74.71458435, 13.33124924], [74.71458435, 13.33208275], [74.71430206, 13.33208084], [74.71430206, 13.33263969], [74.7140274, 13.33263969], [74.7140274, 13.33319569], [74.71430206, 13.33319569], [74.71430206, 13.33458424], [74.7140274, 13.33458138], [74.7140274, 13.33487129], [74.71375275, 13.33487129], [74.71375275, 13.33541965], [74.71347046, 13.33541775], [74.71347046, 13.33569431], [74.71290588, 13.33569145], [74.71290588, 13.33625031], [74.71263885, 13.33625031], [74.71263885, 13.33652973], [74.71208191, 13.33652782], [74.71208191, 13.33708382], [74.71180725, 13.33708191], [74.71180725, 13.33763981], [74.71152496, 13.33763981], [74.71152496, 13.33819389], [74.71125031, 13.33819103], [74.71125031, 13.34042263], [74.71151733, 13.34042263], [74.71151733, 13.34125042], [74.71125031, 13.34125042], [74.71125031, 13.34181118], [74.7104187, 13.34181118], [74.7104187, 13.34153271], [74.70986176, 13.34153271], [74.70986176, 13.34097195], [74.7095871, 13.34097195], [74.7095871, 13.34041595], [74.70929718, 13.34042263], [74.70929718, 13.34014034], [74.70903015, 13.34014034], [74.70903015, 13.34042263], [74.70874786, 13.34041595], [74.70874786, 13.34069443], [74.70819092, 13.34069443], [74.70819092, 13.34097195], [74.70791626, 13.34097195], [74.70791626, 13.34125042], [74.70735931, 13.34125042], [74.70735931, 13.34153271], [74.70680237, 13.34153271], [74.70680237, 13.34181118], [74.70625305, 13.34180641], [74.70625305, 13.34208202], [74.70597076, 13.34208202], [74.70597076, 13.34263992], [74.70540619, 13.34263992], [74.70540619, 13.34292126], [74.70513916, 13.34291553], [74.70513916, 13.34319401], [74.7048645, 13.34319401], [74.7048645, 13.34347153], [74.70458221, 13.34347153], [74.70458221, 13.34375], [74.70430756, 13.34374142], [74.70430756, 13.34431076], [74.70319366, 13.34430599], [74.70319366, 13.34458447], [74.70180511, 13.34458447], [74.70181274, 13.34486008], [74.70069122, 13.34486008], [74.70069122, 13.34514141], [74.69957733, 13.34514141], [74.69957733, 13.34542084], [74.69902802, 13.34541607], [74.69902802, 13.34569359], [74.69847107, 13.34569359], [74.69847107, 13.34597206], [74.69819641, 13.34597015], [74.69819641, 13.34625053], [74.69763947, 13.34625053], [74.69763947, 13.34653091], [74.69708252, 13.34653091], [74.69708252, 13.34681129], [74.69652557, 13.34680653], [74.69652557, 13.34708214], [74.69625092, 13.34708214], [74.69625092, 13.34735966], [74.69568634, 13.34735966], [74.69568634, 13.34764099], [74.69513702, 13.34764099], [74.69513702, 13.34792137], [74.69541931, 13.3479166], [74.69541931, 13.34819508], [74.69596863, 13.34819508], [74.69596863, 13.3484726], [74.69625092, 13.34846973], [74.69625092, 13.34875107], [74.6965332, 13.34875107], [74.6965332, 13.34931087], [74.69680786, 13.34930515], [74.69680786, 13.34958267], [74.69735718, 13.3495779], [74.69735718, 13.34986973], [74.69763947, 13.34986115], [74.69763947, 13.35097313], [74.69785309, 13.35097122], [74.69790649, 13.35264111], [74.69819641, 13.3526392], [74.69819641, 13.35458279], [74.69790649, 13.35458088], [74.69790649, 13.35652924], [74.69763947, 13.35652924], [74.69763947, 13.35902977], [74.69791412, 13.35902691], [74.69791412, 13.3595829], [74.69819641, 13.3595829], [74.69819641, 13.35986233], [74.69847107, 13.35986233], [74.69847107, 13.36013985], [74.69875336, 13.36013985], [74.69875336, 13.36097145], [74.69847107, 13.36097145], [74.69847107, 13.36208439], [74.69819641, 13.36208057], [74.69819641, 13.36236191], [74.69790649, 13.36236191], [74.69790649, 13.36403179], [74.69763947, 13.36403179], [74.69763947, 13.36736202], [74.69736481, 13.36736202], [74.69736481, 13.37069416], [74.69708252, 13.37069035], [74.69708252, 13.37403965], [74.69680786, 13.37402916], [74.69680786, 13.37458229], [74.69652557, 13.37458229], [74.69652557, 13.37569523], [74.69625092, 13.37569046], [74.69625092, 13.37681103], [74.69596863, 13.37681103], [74.69596863, 13.37903118], [74.69569397, 13.37902737], [74.69569397, 13.3829174], [74.69596863, 13.3829174], [74.69596863, 13.38708401], [74.69625092, 13.38708115], [74.69625092, 13.39041996], [74.6965332, 13.39041996], [74.6965332, 13.39291954], [74.69680786, 13.39291573], [74.69680786, 13.39305019], [74.69680023, 13.39513969], [74.69708252, 13.39513969], [74.69708252, 13.39764023], [74.69735718, 13.39764023], [74.69735718, 13.40236092], [74.69708252, 13.40236092], [74.69708252, 13.40653133], [74.69680023, 13.40653133], [74.69680023, 13.40931034], [74.69652557, 13.40930462], [74.69652557, 13.41208267], [74.69625092, 13.41208267], [74.69625092, 13.41708374], [74.69596863, 13.41708374], [74.69596863, 13.41847229], [74.69569397, 13.41847229], [74.69569397, 13.41958427], [74.69541931, 13.41958427], [74.69541931, 13.42097187], [74.69513702, 13.42097187], [74.69513702, 13.42319393], [74.69486237, 13.42319202], [74.69486237, 13.42625046], [74.69458008, 13.42625046], [74.69458008, 13.4295826], [74.69430542, 13.4295826], [74.69431305, 13.43847084], [74.69403076, 13.43847084], [74.69403076, 13.44612026], [74.69403076, 13.44653034], [74.69384766, 13.44652843], [74.69374847, 13.44652843], [74.69374847, 13.44675064], [74.69374084, 13.44764042], [74.69403076, 13.44763756], [74.69403076, 13.44847202], [74.69431305, 13.44847202], [74.69431305, 13.44932175], [74.69458008, 13.44930553], [74.69458008, 13.44986153], [74.69431305, 13.44985962], [74.69431305, 13.45403099], [74.69403076, 13.45402908], [74.69403076, 13.45458221], [74.69374084, 13.45458031], [74.69374084, 13.45485973], [74.69346619, 13.45485973], [74.69346619, 13.45542145], [74.69319153, 13.45541668], [74.69319153, 13.45597267], [74.69291687, 13.4559679], [74.69291687, 13.45653057], [74.69264221, 13.45652866], [74.69264221, 13.45708275], [74.69235992, 13.45708275], [74.69235992, 13.45736122], [74.6920929, 13.45736122], [74.6920929, 13.45792103], [74.69180298, 13.45792103], [74.69180298, 13.45819855], [74.69152832, 13.45819855], [74.69152832, 13.45875072], [74.69124603, 13.45875072], [74.69124603, 13.45903111], [74.69097137, 13.4590292], [74.69097137, 13.45958328], [74.69069672, 13.45958328], [74.69069672, 13.46069527], [74.69041443, 13.46069527], [74.6904068, 13.46286011], [74.69013977, 13.46291733], [74.69013977, 13.4636097], [74.69013977, 13.46486092], [74.68985748, 13.46486092], [74.68985748, 13.46708298], [74.68958282, 13.46706963], [74.68958282, 13.46903038], [74.68930817, 13.46903038], [74.68930817, 13.47124958], [74.68902588, 13.47124958], [74.68902588, 13.47431087], [74.68875122, 13.47431087], [74.68875122, 13.47875023], [74.68846893, 13.47875023], [74.68846893, 13.48292065], [74.68818665, 13.48292065], [74.68818665, 13.48625088], [74.68791962, 13.48625088], [74.68791962, 13.48986053], [74.68763733, 13.48986053], [74.68763733, 13.49263859], [74.68736267, 13.49263859], [74.68736267, 13.49458313], [74.68708038, 13.49458122], [74.68708038, 13.49680996], [74.68681335, 13.49680996], [74.68681335, 13.49874973], [74.68653107, 13.49874973], [74.68653107, 13.50069427], [74.68624878, 13.50069237], [74.68624878, 13.5029211], [74.68597412, 13.50291634], [74.68597412, 13.50569439], [74.68569183, 13.50568962], [74.68569183, 13.50931072], [74.68541718, 13.50930691], [74.68541718, 13.51347256], [74.68514252, 13.51347256], [74.68514252, 13.51708317], [74.68486023, 13.51708126], [74.68486023, 13.51874924], [74.6845932, 13.51874924], [74.6845932, 13.52042198], [74.68430328, 13.52042198], [74.68430328, 13.52291965], [74.68402863, 13.52291775], [74.68402863, 13.5256958], [74.68374634, 13.5256958], [74.68374634, 13.52847195], [74.68347168, 13.52847195], [74.68347168, 13.53069401], [74.68319702, 13.53069019], [74.68319702, 13.53181076], [74.6829071, 13.53181076], [74.6829071, 13.53374958], [74.68264008, 13.53374958], [74.68264008, 13.53654003], [74.68235779, 13.53652859], [74.68235779, 13.53822041], [74.68235779, 13.53931236], [74.68208313, 13.53930473], [74.68208313, 13.54208279], [74.68180084, 13.54208088], [74.68180084, 13.54486084], [74.68152618, 13.54486084], [74.68152618, 13.54736137], [74.68125153, 13.54736137], [74.68125153, 13.5490303], [74.68096924, 13.54902744], [74.68096924, 13.55069447], [74.68068695, 13.55069065], [74.68068695, 13.55263996], [74.68041992, 13.55263996], [74.68041992, 13.5543108], [74.68013763, 13.55430603], [74.68013763, 13.5559721], [74.67986298, 13.55597019], [74.67986298, 13.55792141], [74.67958069, 13.55791569], [74.67958069, 13.55958366], [74.67930603, 13.55957985], [74.67930603, 13.56124973], [74.67903137, 13.56124973], [74.67903137, 13.56319523], [74.67874146, 13.56319046], [74.67874146, 13.56514072], [74.67847443, 13.56513882], [74.67847443, 13.56708336], [74.67819214, 13.56708145], [74.67819214, 13.56903076], [74.67791748, 13.56902695], [74.67791748, 13.5709734], [74.67764282, 13.57097054], [74.67764282, 13.57292175], [74.67736053, 13.57291698], [74.67736053, 13.57486057], [74.67708588, 13.57486057], [74.67708588, 13.57653046], [74.67680359, 13.5765276], [74.67680359, 13.57847214], [74.67652893, 13.57845974], [74.67652893, 13.58041954], [74.67624664, 13.58041573], [74.67624664, 13.58086014], [74.67624664, 13.58236217], [74.67610931, 13.58236217], [74.67597198, 13.58236217], [74.67595673, 13.58393002], [74.6759491, 13.58431053], [74.67569733, 13.58431053], [74.67569733, 13.58625031], [74.67541504, 13.58625031], [74.67541504, 13.58819389], [74.67514038, 13.58819199], [74.67514038, 13.58985996], [74.67485809, 13.58985996], [74.67485809, 13.59152889], [74.67457581, 13.59152889], [74.67457581, 13.59292126], [74.67430878, 13.59291744], [74.67430878, 13.59458256], [74.67402649, 13.59458256], [74.67402649, 13.59597301], [74.67375183, 13.59597301], [74.67375183, 13.59736061], [74.67346954, 13.59736061], [74.67346954, 13.59902859], [74.67318726, 13.59902859], [74.67318726, 13.60042191], [74.67292023, 13.60041714], [74.67292023, 13.60208321], [74.67263794, 13.60208321], [74.67263794, 13.6034708], [74.67236328, 13.60346889], [74.67236328, 13.60513973], [74.67208099, 13.60513973], [74.67208099, 13.60624123], [74.67208099, 13.60653019], [74.67180634, 13.60652828], [74.67180634, 13.60720921], [74.67180634, 13.60819435], [74.67152405, 13.60819435], [74.67152405, 13.60859966], [74.67152405, 13.60958195], [74.67124939, 13.60958195], [74.67124939, 13.61000061], [74.67124939, 13.61124992], [74.67106628, 13.61124992], [74.67097473, 13.61124992], [74.6709671, 13.61264038], [74.67069244, 13.61264038], [74.67069244, 13.61403084], [74.67041779, 13.61402798], [74.67041779, 13.61569405], [74.6701355, 13.61569405], [74.6701355, 13.61708164], [74.67002106, 13.61708164], [74.66986084, 13.61708164], [74.66986084, 13.61757946], [74.66986084, 13.61875057], [74.66958618, 13.61875057], [74.66958618, 13.62014103], [74.66929626, 13.62014103], [74.66929626, 13.62181187], [74.66902924, 13.62180519], [74.66902924, 13.62319469], [74.66874695, 13.62319088], [74.66874695, 13.62486076], [74.66847229, 13.62486076], [74.66847229, 13.6265316], [74.66819763, 13.62652683], [74.66819763, 13.62801075], [74.66819763, 13.62819576], [74.66792297, 13.62819099], [74.66792297, 13.62930965], [74.66819763, 13.62930965], [74.66819763, 13.62986183], [74.66847229, 13.62986183], [74.66847229, 13.63041973], [74.66874695, 13.63041782], [74.66874695, 13.63097191], [74.66902924, 13.63097191], [74.66902924, 13.63152981], [74.66930389, 13.6315279], [74.66930389, 13.63208389], [74.66958618, 13.63208389], [74.66958618, 13.63236237], [74.66986084, 13.63236046], [74.66986084, 13.63264179], [74.67041779, 13.63264179], [74.67041779, 13.63293171], [74.67069244, 13.63293171], [74.67069244, 13.63374996], [74.67041779, 13.63374996], [74.67041779, 13.63486195], [74.6701355, 13.63486195], [74.6701355, 13.63597202], [74.66986084, 13.63597202], [74.66986084, 13.63708401], [74.66958618, 13.63708401], [74.66958618, 13.63819408], [74.66930389, 13.63819408], [74.66930389, 13.6384716], [74.66819763, 13.6384716], [74.66819763, 13.63875008], [74.66792297, 13.63874054], [74.66792297, 13.63931084], [74.66764069, 13.63930416], [74.66764069, 13.63958359], [74.6673584, 13.63958359], [74.6673584, 13.63986015], [74.66708374, 13.63986015], [74.66708374, 13.64069366], [74.66680145, 13.64068985], [74.66680145, 13.64124966], [74.66652679, 13.64124966], [74.66652679, 13.64153099], [74.66625214, 13.64152813], [74.66625214, 13.6418066], [74.66569519, 13.6418066], [74.66569519, 13.64208221], [74.6654129, 13.64208031], [74.6654129, 13.64235973], [74.66513824, 13.64235973], [74.66513824, 13.64292145], [74.66485596, 13.64292145], [74.66485596, 13.64403057], [74.6645813, 13.64402866], [74.6645813, 13.64819527], [74.66430664, 13.64818954], [74.66430664, 13.64903069], [74.66402435, 13.64902687], [74.66402435, 13.64958286], [74.66375732, 13.64958096], [74.66375732, 13.65041924], [74.66348267, 13.65041924], [74.66348267, 13.65125084], [74.66319275, 13.65124893], [74.66319275, 13.6520834], [74.66291809, 13.65208054], [74.66291809, 13.65291977], [74.6626358, 13.65291691], [74.6626358, 13.65347099], [74.66236115, 13.65347099], [74.66236115, 13.65431023], [74.66208649, 13.65430546], [74.66208649, 13.65486145], [74.66179657, 13.65486145], [74.66179657, 13.6554203], [74.66152954, 13.6554184], [74.66152954, 13.65569305], [74.66124725, 13.65569305], [74.66124725, 13.65597057], [74.6609726, 13.65597057], [74.6609726, 13.65653038], [74.66069794, 13.65653038], [74.66069794, 13.65680981], [74.6598587, 13.65680599], [74.6598587, 13.65708447], [74.65957642, 13.65708065], [74.65957642, 13.65736198], [74.65930939, 13.65736198], [74.65930176, 13.65764046], [74.6590271, 13.65764046], [74.6590271, 13.65792179], [74.65875244, 13.65791798], [74.65875244, 13.65819359], [74.65847015, 13.65819359], [74.65847015, 13.65847206], [74.65820313, 13.6584692], [74.65820313, 13.65874958], [74.65791321, 13.65874958], [74.65791321, 13.65902996], [74.65763855, 13.65902805], [74.65763855, 13.65958405], [74.65735626, 13.65957928], [74.65735626, 13.6598711], [74.6570816, 13.6598711], [74.6570816, 13.66014004], [74.65680695, 13.66014004], [74.65680695, 13.66042042], [74.65652466, 13.66041565], [74.65652466, 13.66069412], [74.65625, 13.66068935], [74.65625, 13.66125202], [74.65598297, 13.66125202], [74.65598297, 13.66152954], [74.65569305, 13.66152954], [74.65569305, 13.66181087], [74.6554184, 13.66180611], [74.6554184, 13.66208363], [74.65513611, 13.66208363], [74.65513611, 13.6623621], [74.65486145, 13.66236019], [74.65486145, 13.66292953], [74.65458679, 13.66291809], [74.65458679, 13.6631937], [74.6543045, 13.6631937], [74.6543045, 13.66347218], [74.65402985, 13.66347027], [74.65402985, 13.66374969], [74.65374756, 13.66374969], [74.65374756, 13.66403008], [74.6534729, 13.66402817], [74.6534729, 13.66458416], [74.65319824, 13.66458035], [74.65319824, 13.66486168], [74.65291595, 13.66486168], [74.65291595, 13.66514015], [74.65208435, 13.66514015], [74.65208435, 13.66569424], [74.65180206, 13.66569424], [74.65180206, 13.66597176], [74.6515274, 13.66596985], [74.6515274, 13.66625023], [74.65125275, 13.66625023], [74.65125275, 13.66681099], [74.65097046, 13.66681099], [74.65097046, 13.66764069], [74.6506958, 13.66764069], [74.6506958, 13.66931057], [74.65041351, 13.66930676], [74.65041351, 13.67097282], [74.65013885, 13.67097282], [74.65013885, 13.6720829], [74.64985657, 13.67208004], [74.64985657, 13.6726408], [74.64958191, 13.67263889], [74.64958191, 13.67319489], [74.64930725, 13.67319012], [74.64930725, 13.67375088], [74.64901733, 13.67375088], [74.64901733, 13.67431164], [74.64875793, 13.67431164], [74.64875793, 13.67486954], [74.64848328, 13.67486954], [74.64848328, 13.67542171], [74.64819336, 13.67541695], [74.64819336, 13.67597294], [74.6479187, 13.67597103], [74.6479187, 13.67653084], [74.64763641, 13.67652702], [74.64763641, 13.67708302], [74.64736176, 13.67708111], [74.64736176, 13.67764091], [74.6470871, 13.67763901], [74.6470871, 13.67819309], [74.64679718, 13.67819118], [74.64679718, 13.67875099], [74.64653015, 13.67875099], [74.64653015, 13.67931175], [74.64624786, 13.67931175], [74.64624786, 13.6801424], [74.64597321, 13.6801424], [74.64597321, 13.68125153], [74.64569092, 13.68124866], [74.64569092, 13.68208313], [74.64541626, 13.68208122], [74.64541626, 13.68292046], [74.6451416, 13.68292046], [74.6451416, 13.68404102], [74.64485931, 13.68402767], [74.64485931, 13.68486214], [74.64458466, 13.68486214], [74.64458466, 13.68597221], [74.64430237, 13.68597221], [74.64430237, 13.68958378], [74.64402771, 13.68958378], [74.64402771, 13.6915102], [74.64402771, 13.69375038], [74.64375305, 13.69375038], [74.64375305, 13.69542122], [74.64347076, 13.69541645], [74.64347076, 13.69708157], [74.64319611, 13.69708157], [74.64318848, 13.69757938], [74.64317322, 13.69875145], [74.64290619, 13.69875145], [74.64290619, 13.70042133], [74.64263916, 13.70041656], [74.64263916, 13.70208263], [74.64235687, 13.70208073], [74.64235687, 13.70375061], [74.64208221, 13.7037487], [74.64208221, 13.70569515], [74.64180756, 13.70569515], [74.64180756, 13.70736122], [74.6415329, 13.70736122], [74.6415329, 13.70930958], [74.64125061, 13.70930958], [74.64125061, 13.71098137], [74.64097595, 13.71098137], [74.64097595, 13.71292019], [74.64069366, 13.71291637], [74.64069366, 13.71458435], [74.64041901, 13.71458244], [74.64041901, 13.71625042], [74.64013672, 13.71625042], [74.64013672, 13.71708202], [74.64013672, 13.71792126], [74.63986206, 13.71791553], [74.63986206, 13.71958447], [74.6395874, 13.7195797], [74.6395874, 13.72124958], [74.63931274, 13.72124958], [74.63931274, 13.72292137], [74.63903046, 13.72291565], [74.63903046, 13.72458458], [74.63874817, 13.7245779], [74.63874817, 13.72625065], [74.63846588, 13.72625065], [74.63846588, 13.72792053], [74.63819122, 13.72791672], [74.63819122, 13.72958279], [74.63791656, 13.72958088], [74.63791656, 13.73125076], [74.63764191, 13.73125076], [74.63764191, 13.73291969], [74.63735962, 13.73291683], [74.63735962, 13.7345829], [74.63707733, 13.73458099], [74.63707733, 13.73625183], [74.63680267, 13.73624897], [74.63680267, 13.73819256], [74.63652802, 13.73819256], [74.63652802, 13.73986244], [74.63625336, 13.73985958], [74.63625336, 13.74153042], [74.63597107, 13.74152756], [74.63597107, 13.7434721], [74.63569641, 13.74347019], [74.63569641, 13.74514008], [74.63540649, 13.74514008], [74.63540649, 13.74681091], [74.63513947, 13.74681091], [74.63513947, 13.74792099], [74.63485718, 13.74792099], [74.63485718, 13.74931145], [74.63458252, 13.74930668], [74.63458252, 13.75069523], [74.63430786, 13.75069046], [74.63430786, 13.75181103], [74.63402557, 13.75180435], [74.63402557, 13.75319481], [74.63375092, 13.75319481], [74.63375092, 13.75458336], [74.63346863, 13.75458336], [74.633461, 13.75568962], [74.63319397, 13.75569534], [74.63319397, 13.75708294], [74.63291931, 13.75708294], [74.63291931, 13.75753021], [74.63291931, 13.7584734], [74.63276672, 13.7584734], [74.63263702, 13.7584734], [74.63263702, 13.75938034], [74.63263702, 13.75958347], [74.63236237, 13.75958347], [74.63236237, 13.76119041], [74.63236237, 13.76292038], [74.63208008, 13.76291847], [74.63206482, 13.76378059], [74.63205719, 13.76403046], [74.63180542, 13.76402664], [74.63180542, 13.76458359], [74.63153076, 13.76458359], [74.63153076, 13.76513958], [74.63124847, 13.76513958], [74.63124847, 13.76569366], [74.63096619, 13.7656889], [74.63096619, 13.76681042], [74.63069153, 13.76680565], [74.63069153, 13.76847172], [74.63041687, 13.76846981], [74.63041687, 13.77013969], [74.63014221, 13.77013969], [74.63014221, 13.77181053], [74.62985992, 13.77180576], [74.62985992, 13.77347183], [74.6295929, 13.77346992], [74.6295929, 13.77514267], [74.62930298, 13.77514267], [74.62930298, 13.77681065], [74.62902832, 13.77681065], [74.62902832, 13.78042126], [74.62875366, 13.78041744], [74.62875366, 13.78069496], [74.62847137, 13.78069019], [74.62847137, 13.78153133], [74.62819672, 13.78153133], [74.62819672, 13.78320026], [74.62791443, 13.78319454], [74.62791443, 13.78486061], [74.62763977, 13.78486061], [74.62763977, 13.7859726], [74.62735748, 13.78597069], [74.62735748, 13.78681183], [74.62708282, 13.78681183], [74.62708282, 13.78792191], [74.62680817, 13.78792191], [74.62680817, 13.7887516], [74.62652588, 13.78874874], [74.62652588, 13.78958321], [74.62625122, 13.7895813], [74.62625122, 13.79041958], [74.62596893, 13.79041958], [74.62596893, 13.79152966], [74.62569427, 13.79152775], [74.62569427, 13.79236221], [74.62541962, 13.79236221], [74.62541962, 13.79319572], [74.62568665, 13.79319096], [74.62568665, 13.79430962], [74.62596893, 13.7943058], [74.62596893, 13.79526138], [74.62596893, 13.79542923], [74.62625122, 13.79542923], [74.62625122, 13.79625034], [74.62596893, 13.79625034], [74.62596893, 13.79708195], [74.62569427, 13.79708195], [74.62569427, 13.79652786], [74.62538147, 13.79652977], [74.62513733, 13.79653263], [74.62513733, 13.7968111], [74.62458038, 13.79680634], [74.62458038, 13.79708195], [74.62431335, 13.79708195], [74.62431335, 13.79820061], [74.62403107, 13.79820061], [74.62403107, 13.79874992], [74.62374878, 13.79874992], [74.62374878, 13.7990303], [74.62346649, 13.7990303], [74.62346649, 13.80014038], [74.62319183, 13.80013847], [74.62319183, 13.80125046], [74.62291718, 13.80124092], [74.62291718, 13.80264091], [74.62264252, 13.80264091], [74.62264252, 13.80403137], [74.62236023, 13.80403137], [74.62236023, 13.80542088], [74.6220932, 13.80542088], [74.6220932, 13.80681133], [74.62180328, 13.80680466], [74.62180328, 13.80819511], [74.62152863, 13.80819511], [74.62152863, 13.80958271], [74.62124634, 13.80958271], [74.62124634, 13.81097317], [74.62097168, 13.81097126], [74.62097168, 13.81236076], [74.62069702, 13.81236076], [74.62069702, 13.81375122], [74.6204071, 13.81375122], [74.6204071, 13.81514168], [74.62014008, 13.81514168], [74.62014008, 13.81653023], [74.61985779, 13.81653023], [74.61985779, 13.81791973], [74.61958313, 13.81791973], [74.61958313, 13.81931019], [74.61930847, 13.81930637], [74.61930847, 13.8206892], [74.61902618, 13.82069588], [74.61902618, 13.82208443], [74.61875153, 13.82208443], [74.61875153, 13.82347202], [74.61846924, 13.82347202], [74.61846924, 13.82486153], [74.61818695, 13.82485962], [74.61818695, 13.82625008], [74.61791992, 13.82625008], [74.61791992, 13.82681084], [74.61708069, 13.82681084], [74.61708069, 13.82792091], [74.61680603, 13.82792091], [74.61680603, 13.83014107], [74.61653137, 13.83014107], [74.61653137, 13.83181095], [74.61624908, 13.83181095], [74.61624908, 13.83292103], [74.6159668, 13.83292103], [74.6159668, 13.83403111], [74.61569214, 13.83403111], [74.61569214, 13.83514118], [74.61541748, 13.83513927], [74.61541748, 13.83597279], [74.61513519, 13.83597279], [74.61513519, 13.83708286], [74.61486053, 13.83708286], [74.61486053, 13.83819485], [74.61458588, 13.83819103], [74.61458588, 13.83902931], [74.61429596, 13.83902931], [74.61429596, 13.84013939], [74.61402893, 13.84013939], [74.61402893, 13.84125137], [74.61374664, 13.84125137], [74.61374664, 13.84224129], [74.61374664, 13.84236145], [74.61347198, 13.84236145], [74.61347198, 13.84319305], [74.61319733, 13.84319305], [74.61318207, 13.84418011], [74.61318207, 13.84430981], [74.61291504, 13.84430504], [74.61292267, 13.84517193], [74.61292267, 13.84542179], [74.61264038, 13.84541798], [74.61264801, 13.84613991], [74.61264801, 13.8465414], [74.61252594, 13.84652805], [74.61235809, 13.84652805], [74.61235809, 13.84713173], [74.61235809, 13.84764194], [74.61219788, 13.84764004], [74.61208344, 13.84764004], [74.61208344, 13.84809971], [74.61207581, 13.84875202], [74.61180878, 13.84875011], [74.61180878, 13.84907055], [74.61180878, 13.8498621], [74.61152649, 13.8498621], [74.61152649, 13.85006046], [74.61152649, 13.85097218], [74.61125183, 13.85097218], [74.61125183, 13.85208416], [74.61096954, 13.85208416], [74.61096954, 13.85319424], [74.61068726, 13.85319042], [74.61068726, 13.85403061], [74.61042023, 13.85402775], [74.61042023, 13.85486031], [74.61013794, 13.85486031], [74.61013794, 13.85509014], [74.61013794, 13.85597229], [74.60986328, 13.85597038], [74.60986328, 13.85681057], [74.60958099, 13.85681057], [74.60958099, 13.85764122], [74.60930634, 13.85764122], [74.60930634, 13.8587513], [74.60902405, 13.8587513], [74.60902405, 13.8595829], [74.60874939, 13.85958004], [74.60874939, 13.86042118], [74.6084671, 13.86042118], [74.6084671, 13.86125088], [74.60819244, 13.86125088], [74.60819244, 13.86236095], [74.60791779, 13.86236095], [74.60791779, 13.86319542], [74.60764313, 13.8631897], [74.60764313, 13.86403084], [74.60736084, 13.86403084], [74.60736084, 13.86514091], [74.60708618, 13.86513901], [74.60708618, 13.86597347], [74.60679626, 13.86597061], [74.60679626, 13.86652946], [74.60791779, 13.86652946], [74.60791779, 13.86597061], [74.60819244, 13.86597347], [74.60819244, 13.86513901], [74.6084671, 13.86514091], [74.6084671, 13.86430931], [74.60874939, 13.86430931], [74.60874939, 13.86347103], [74.60902405, 13.86347294], [74.60902405, 13.86263943], [74.60930634, 13.86264133], [74.60930634, 13.86207962], [74.60958099, 13.86208344], [74.60958099, 13.86180687], [74.60986328, 13.86181164], [74.60986328, 13.86125088], [74.61013794, 13.86125088], [74.61013794, 13.86097145], [74.61042023, 13.86097336], [74.61042023, 13.86069489], [74.61096954, 13.86069489], [74.61096954, 13.86041737], [74.61125183, 13.86042118], [74.61125183, 13.8601408], [74.61180878, 13.8601408], [74.61180878, 13.85847855], [74.61207581, 13.85847855], [74.61207581, 13.85513973], [74.61235809, 13.85513973], [74.61235809, 13.85486031], [74.61264038, 13.85486031], [74.61264038, 13.85458374], [74.61291504, 13.85458374], [74.61291504, 13.85402775], [74.61319733, 13.85403061], [74.61319733, 13.85346985], [74.61347198, 13.85347176], [74.61347198, 13.8531599], [74.61347198, 13.85291576], [74.61374664, 13.85292053], [74.61374664, 13.85235119], [74.61402893, 13.85235977], [74.61402893, 13.85208416], [74.61430359, 13.85208416], [74.61430359, 13.85152817], [74.61458588, 13.85153008], [74.61458588, 13.85124969], [74.61541748, 13.85124969], [74.61541748, 13.85097027], [74.61624908, 13.85097218], [74.61624908, 13.8506937], [74.61714935, 13.8506937], [74.61736298, 13.8506937], [74.61736298, 13.85052967], [74.61736298, 13.85041809], [74.61749268, 13.85041809], [74.61846161, 13.85042], [74.61846161, 13.85013962], [74.61902618, 13.85013962], [74.61902618, 13.84986019], [74.61985779, 13.8498621], [74.61985779, 13.84958363], [74.62097168, 13.84958363], [74.62097168, 13.84930611], [74.62180328, 13.84930992], [74.62180328, 13.84902954], [74.62291718, 13.84902954], [74.62291718, 13.84875202], [74.62403107, 13.84875202], [74.62403107, 13.84847164], [74.62541962, 13.84847164], [74.62541962, 13.84819412], [74.62652588, 13.84819412], [74.62652588, 13.84791565], [74.62770081, 13.84791565], [74.63041687, 13.84791565], [74.63041687, 13.84819412], [74.63124847, 13.84819412], [74.63124847, 13.84847164], [74.63208008, 13.84847164], [74.63208008, 13.84875202], [74.63318634, 13.84875202], [74.63318634, 13.84902954], [74.63291931, 13.84902763], [74.63291931, 13.8498621], [74.63069153, 13.8498621], [74.63069153, 13.84958363], [74.63014221, 13.84958363], [74.63014221, 13.84930611], [74.62930298, 13.84930992], [74.62930298, 13.84902954], [74.62874603, 13.84902954], [74.62874603, 13.84875202], [74.62819672, 13.84875202], [74.62819672, 13.84902954], [74.6279068, 13.84902954], [74.6279068, 13.84930992], [74.62741089, 13.84930611], [74.62486267, 13.84930611], [74.62486267, 13.84958363], [74.62458038, 13.84958363], [74.62458038, 13.8498621], [74.62403107, 13.84986019], [74.62403107, 13.85013962], [74.62374878, 13.85013962], [74.62374878, 13.85042], [74.62319183, 13.85041809], [74.62319183, 13.8506937], [74.62291718, 13.8506937], [74.62291718, 13.85097218], [74.62124634, 13.85097218], [74.62124634, 13.8506937], [74.62097168, 13.8506937], [74.62097168, 13.85041809], [74.61985779, 13.85041809], [74.61985779, 13.8506937], [74.61930847, 13.8506937], [74.61930847, 13.85097218], [74.61846161, 13.85097027], [74.61846161, 13.85153008], [74.61708069, 13.85153008], [74.61708069, 13.85181141], [74.61579895, 13.85180569], [74.61569214, 13.85180569], [74.61569214, 13.85208416], [74.61541748, 13.85208035], [74.61541748, 13.85264015], [74.61513519, 13.85264015], [74.61513519, 13.85319424], [74.61486053, 13.85319424], [74.61486053, 13.85347176], [74.61458588, 13.85346985], [74.61458588, 13.85403061], [74.61429596, 13.85403061], [74.61429596, 13.85431099], [74.61402893, 13.85430622], [74.61402893, 13.85486031], [74.61429596, 13.85486031], [74.61429596, 13.85542107], [74.61402893, 13.8554163], [74.61402893, 13.85569382], [74.61374664, 13.85569382], [74.61374664, 13.85597229], [74.61347198, 13.85597038], [74.61347198, 13.85625267], [74.61319733, 13.85625267], [74.61319733, 13.85764122], [74.61292267, 13.85764122], [74.61292267, 13.85903072], [74.61347198, 13.85903072], [74.61347198, 13.8593092], [74.61763763, 13.85930443], [74.61763763, 13.8595829], [74.61736298, 13.8595829], [74.61736298, 13.85971928], [74.61736298, 13.85986137], [74.61605072, 13.85986137], [74.61264801, 13.85986137], [74.61264801, 13.86042118], [74.61235809, 13.86041737], [74.61235809, 13.86097336], [74.61180878, 13.86097145], [74.61180878, 13.86181164], [74.61208344, 13.86180687], [74.61207581, 13.86265945], [74.61207581, 13.86292076], [74.61180878, 13.86291695], [74.61180878, 13.86347294], [74.61152649, 13.86347103], [74.61152649, 13.86375141], [74.61125183, 13.86375141], [74.61125183, 13.86427116], [74.61096954, 13.86430454], [74.61096954, 13.86447144], [74.61096954, 13.86486053], [74.61069489, 13.86486053], [74.61069489, 13.86597347], [74.61042023, 13.86597061], [74.61042023, 13.86736107], [74.61013794, 13.86736107], [74.61013794, 13.8676424], [74.60986328, 13.8676424], [74.60986328, 13.86792183], [74.60902405, 13.86791706], [74.60902405, 13.86819458], [74.60847473, 13.86819458], [74.60847473, 13.86847115], [74.60764313, 13.86847115], [74.60764313, 13.86875057], [74.60708618, 13.86875057], [74.60708618, 13.86903191], [74.60668182, 13.86903191], [74.60597229, 13.86903191], [74.60597229, 13.86931038], [74.60569763, 13.86930466], [74.60569763, 13.86958313], [74.60541534, 13.86958313], [74.60541534, 13.86986065], [74.60514069, 13.86986065], [74.60514069, 13.87014198], [74.6048584, 13.87013912], [74.6048584, 13.87069321], [74.60458374, 13.87069321], [74.60458374, 13.87097359], [74.60430908, 13.87097073], [74.60430908, 13.8712492], [74.60402679, 13.8712492], [74.60402679, 13.87208366], [74.60319519, 13.87208366], [74.60319519, 13.87236214], [74.60263824, 13.87235928], [74.60263824, 13.87263966], [74.60180664, 13.87263966], [74.60180664, 13.87403011], [74.60151672, 13.87403011], [74.60151672, 13.87486172], [74.60124969, 13.87486172], [74.60124969, 13.87569427], [74.60097504, 13.87569427], [74.60097504, 13.87652779], [74.60069275, 13.87652779], [74.60069275, 13.87736225], [74.60041809, 13.87736034], [74.60041809, 13.87792015], [74.6001358, 13.87791634], [74.6001358, 13.87847233], [74.59986115, 13.87847042], [74.59986115, 13.87903023], [74.59958649, 13.87902832], [74.59958649, 13.87958431], [74.59929657, 13.87957954], [74.59929657, 13.87985992], [74.59902954, 13.87985992], [74.59902954, 13.88042068], [74.59874725, 13.88041592], [74.59874725, 13.88097191], [74.5984726, 13.88097], [74.5984726, 13.88153076], [74.59819794, 13.8815279], [74.59819794, 13.88208199], [74.59791565, 13.88208199], [74.59791565, 13.88236237], [74.59764099, 13.88236046], [74.59764099, 13.88292122], [74.5973587, 13.88291645], [74.5973587, 13.88347244], [74.59707642, 13.88346958], [74.59707642, 13.8840313], [74.59680939, 13.88402939], [74.59680176, 13.88458157], [74.5965271, 13.88457966], [74.5965271, 13.88514137], [74.59625244, 13.88513756], [74.59625244, 13.88569546], [74.59597015, 13.88568974], [74.59597015, 13.88625145], [74.59570313, 13.88625145], [74.59570313, 13.88681126], [74.59541321, 13.88680458], [74.59541321, 13.88736057], [74.59513855, 13.88736057], [74.59513855, 13.88792133], [74.59486389, 13.88791656], [74.59486389, 13.88847256], [74.5945816, 13.88845921], [74.5945816, 13.89014053], [74.59430695, 13.89013863], [74.59430695, 13.89208317], [74.59402466, 13.89208317], [74.59402466, 13.89319515], [74.59375, 13.89319134], [74.59375, 13.89403152], [74.59348297, 13.89403152], [74.59348297, 13.8951416], [74.59319305, 13.8951416], [74.59319305, 13.89625168], [74.5929184, 13.89625168], [74.5929184, 13.89765072], [74.59263611, 13.89765072], [74.59263611, 13.89931011], [74.59236145, 13.8993063], [74.59236145, 13.90097237], [74.59208679, 13.90096855], [74.59208679, 13.90264034], [74.59179688, 13.90264034], [74.59179688, 13.90431118], [74.59152985, 13.90430641], [74.59152985, 13.90597153], [74.59124756, 13.90597153], [74.59124756, 13.90708447], [74.5909729, 13.9070797], [74.5909729, 13.90764046], [74.59069824, 13.9076376], [74.59069824, 13.90847206], [74.59041595, 13.90847015], [74.59041595, 13.90931129], [74.5901413, 13.90930557], [74.5901413, 13.90986347], [74.58985901, 13.90986347], [74.58985901, 13.91069412], [74.58957672, 13.91069031], [74.58957672, 13.91125107], [74.58930206, 13.91125107], [74.58930206, 13.91208458], [74.5890274, 13.91208458], [74.5890274, 13.91263866], [74.58875275, 13.91263199], [74.58875275, 13.91375065], [74.58847809, 13.91375065], [74.58847809, 13.91431141], [74.5881958, 13.91431141], [74.5881958, 13.91486073], [74.58791351, 13.91486073], [74.58791351, 13.91569519], [74.58763885, 13.91569042], [74.58763885, 13.91653061], [74.5873642, 13.91652679], [74.5873642, 13.91736126], [74.58708191, 13.91736126], [74.58708191, 13.91819477], [74.58680725, 13.91819], [74.58680725, 13.9187603], [74.58651733, 13.9187603], [74.58651733, 13.91930962], [74.58625031, 13.91930962], [74.58625031, 13.91986084], [74.58598328, 13.91986084], [74.58598328, 13.9204216], [74.58569336, 13.92041683], [74.58569336, 13.92097092], [74.5854187, 13.92097092], [74.5854187, 13.92153168], [74.58513641, 13.92152691], [74.58513641, 13.9220829], [74.58486176, 13.92208099], [74.58486176, 13.92264175], [74.5845871, 13.92263889], [74.5845871, 13.92319489], [74.58430481, 13.92319489], [74.58430481, 13.92347431], [74.58403015, 13.92347431], [74.58403015, 13.92360115], [74.58403015, 13.9240303], [74.58374786, 13.9240303], [74.58374786, 13.92430973], [74.58347321, 13.92430496], [74.58347321, 13.92458344], [74.58319092, 13.92457199], [74.58319092, 13.92486191], [74.58300781, 13.92486191], [74.58291626, 13.92486191], [74.58291626, 13.92514038], [74.58235168, 13.92514038], [74.58235168, 13.92541981], [74.57930756, 13.9254179], [74.57930756, 13.92569256], [74.57902527, 13.92569256], [74.5790329, 13.92625046], [74.57875061, 13.92625046], [74.57875061, 13.92708397], [74.57847595, 13.92708397], [74.57847595, 13.92763996], [74.57819366, 13.92763996], [74.57819366, 13.92847157], [74.57791901, 13.92847157], [74.57791901, 13.92903042], [74.57763672, 13.92903042], [74.57763672, 13.92986202], [74.57736206, 13.92986202], [74.57736206, 13.93041992], [74.57707977, 13.93041992], [74.57707977, 13.93124962], [74.57681274, 13.93124962], [74.57681274, 13.93181133], [74.57653809, 13.93181133], [74.57653809, 13.93264008], [74.57624817, 13.93264008], [74.57624817, 13.93319416], [74.57596588, 13.93318939], [74.57596588, 13.9337616], [74.57569122, 13.9337616], [74.57569122, 13.93431091], [74.57541656, 13.93430614], [74.57541656, 13.93486023], [74.57514191, 13.93486023], [74.57514191, 13.93542099], [74.57485962, 13.93541622], [74.57485962, 13.93597221], [74.57459259, 13.93597031], [74.57459259, 13.93653107], [74.57430267, 13.93652821], [74.57430267, 13.93708229], [74.57402802, 13.93708038], [74.57402802, 13.93764114], [74.57375336, 13.93763828], [74.57375336, 13.93819427], [74.57347107, 13.93819427], [74.5734787, 13.93875122], [74.57319641, 13.93875122], [74.57319641, 13.93931103], [74.57291412, 13.93930435], [74.57291412, 13.9398613], [74.57263947, 13.9398613], [74.57263947, 13.9404211], [74.57236481, 13.94041729], [74.57236481, 13.94097328], [74.57208252, 13.94097042], [74.57208252, 13.94153118], [74.57180786, 13.94152737], [74.57180786, 13.94208336], [74.5715332, 13.94207954], [74.5715332, 13.94293118], [74.57125092, 13.94293118], [74.57125092, 13.94375134], [74.57096863, 13.94375134], [74.57096863, 13.94430923], [74.57068634, 13.94430923], [74.57068634, 13.94514084], [74.57041931, 13.94513893], [74.57041931, 13.94526196], [74.57041931, 13.9459734], [74.57013702, 13.94597054], [74.57013702, 13.94652939], [74.56986237, 13.94652939], [74.56986237, 13.94680977], [74.56958008, 13.946805], [74.56958008, 13.94708347], [74.56903076, 13.94708061], [74.56903076, 13.94764137], [74.56846619, 13.94764137], [74.56846619, 13.94792175], [74.56819153, 13.94791698], [74.56819153, 13.94819546], [74.56791687, 13.94819546], [74.56791687, 13.94847107], [74.56735992, 13.94847107], [74.56735992, 13.94874859], [74.56680298, 13.94874001], [74.56680298, 13.94903183], [74.56597137, 13.94903183], [74.56597137, 13.94874001], [74.56569672, 13.94874859], [74.56569672, 13.94847107], [74.56513977, 13.94847107], [74.56513977, 13.94819546], [74.56485748, 13.94819546], [74.56485748, 13.94791698], [74.56430817, 13.94792175], [74.56430817, 13.94764137], [74.56402588, 13.94764137], [74.56402588, 13.94716072], [74.56402588, 13.94708347], [74.56375122, 13.94708347], [74.56375122, 13.94624901], [74.56346893, 13.94625092], [74.56346893, 13.94569969], [74.56318665, 13.94569969], [74.56318665, 13.94541931], [74.56153107, 13.94541931], [74.56153107, 13.94569969], [74.56041718, 13.94569492], [74.56041718, 13.9459734], [74.56014252, 13.94597054], [74.56014252, 13.94625092], [74.56041718, 13.94625092], [74.56041718, 13.94652939], [74.56014252, 13.94652939], [74.56014252, 13.94736099], [74.55986023, 13.94736099], [74.55986023, 13.9482317], [74.55986023, 13.94903183], [74.5595932, 13.94903183], [74.5595932, 13.9493103], [74.55930328, 13.94930458], [74.55930328, 13.94958305], [74.55902863, 13.94958305], [74.55902863, 13.94986057], [74.55874634, 13.94986057], [74.55874634, 13.95014191], [74.55847168, 13.95014191], [74.55847168, 13.95042038], [74.55819702, 13.95041656], [74.55819702, 13.95069313], [74.55791473, 13.95069313], [74.55791473, 13.95097446], [74.55764008, 13.95097065], [74.55764008, 13.95125198], [74.55541229, 13.95125198], [74.55541229, 13.95097065], [74.55430603, 13.95097446], [74.55430603, 13.95069313], [74.55319214, 13.95069313], [74.55319214, 13.95041656], [74.55291748, 13.95042038], [74.55291748, 13.95014191], [74.55264282, 13.95014191], [74.55263519, 13.95004845], [74.55261993, 13.94986057], [74.55208588, 13.94986057], [74.55208588, 13.94958305], [74.55180359, 13.94958305], [74.55180359, 13.94930458], [74.55152893, 13.9493103], [74.55152893, 13.94903183], [74.55124664, 13.94903183], [74.55124664, 13.94874001], [74.55069733, 13.94874859], [74.55069733, 13.94847107], [74.55041504, 13.94847107], [74.55041504, 13.94819546], [74.54985809, 13.94819546], [74.54985809, 13.94847107], [74.54875183, 13.94847107], [74.54875183, 13.94874859], [74.54846954, 13.94875145], [74.54846954, 13.95097446], [74.54819489, 13.95097446], [74.54819489, 13.95180511], [74.54792023, 13.95180511], [74.54792023, 13.95282173], [74.54792023, 13.95291805], [74.5477829, 13.95291996], [74.54763794, 13.95291996], [74.54763794, 13.95374966], [74.54736328, 13.95374966], [74.54736328, 13.95431042], [74.54708099, 13.95431042], [74.54708099, 13.95487118], [74.54680634, 13.95487118], [74.54680634, 13.95541954], [74.54652405, 13.95541573], [74.54652405, 13.95597172], [74.54624176, 13.95596886], [74.54624176, 13.95652962], [74.54486084, 13.95652962], [74.54486084, 13.95681], [74.54347229, 13.95680618], [74.54347229, 13.9570837], [74.54208374, 13.9570837], [74.54208374, 13.95736217], [74.54180908, 13.95736027], [74.54180908, 13.95763969], [74.54152679, 13.95763969], [74.54152679, 13.95792866], [74.54141998, 13.95792866], [74.54125214, 13.95792866], [74.54125214, 13.95875168], [74.54096985, 13.95874977], [74.54096985, 13.95958424], [74.54069519, 13.95958424], [74.54069519, 13.96177197], [74.54069519, 13.96236229], [74.54058075, 13.96236229], [74.5404129, 13.96236038], [74.5404129, 13.96292114], [74.53986359, 13.96291637], [74.53986359, 13.96347237], [74.5395813, 13.96347046], [74.5395813, 13.96431065], [74.53901672, 13.96431065], [74.53901672, 13.96485996], [74.53874969, 13.96485996], [74.53874969, 13.9651413], [74.53848267, 13.9651413], [74.53848267, 13.96542072], [74.53791809, 13.96541595], [74.53791809, 13.96569538], [74.5376358, 13.96569538], [74.5376358, 13.9659729], [74.53708649, 13.96597004], [74.53708649, 13.96625137], [74.53679657, 13.96625137], [74.53679657, 13.9665308], [74.5359726, 13.9665308], [74.5359726, 13.96681118], [74.53542328, 13.96681118], [74.53542328, 13.9665308], [74.5348587, 13.9665308], [74.5348587, 13.96625137], [74.53457642, 13.96625137], [74.53457642, 13.96568966], [74.53430176, 13.96569538], [74.53430176, 13.96513844], [74.5340271, 13.9651413], [74.5340271, 13.96457958], [74.53180695, 13.96457958], [74.53180695, 13.96485996], [74.53151703, 13.96485996], [74.53151703, 13.96903133], [74.53124237, 13.96903133], [74.53124237, 13.96986961], [74.53098297, 13.96986961], [74.53098297, 13.97014141], [74.53069305, 13.97014141], [74.53069305, 13.97042084], [74.5304184, 13.97041702], [74.5304184, 13.97097301], [74.53013611, 13.97097111], [74.53013611, 13.97125053], [74.52986145, 13.97125053], [74.52986145, 13.97180939], [74.52958679, 13.97180462], [74.52958679, 13.97208309], [74.5293045, 13.97208309], [74.5293045, 13.97236061], [74.52902985, 13.97236061], [74.52902985, 13.97264099], [74.52874756, 13.97264099], [74.52874756, 13.97293091], [74.52819824, 13.9729166], [74.52819824, 13.97319508], [74.52735901, 13.97319508], [74.52735901, 13.9734726], [74.5265274, 13.97347069], [74.5265274, 13.97375107], [74.52540588, 13.97375107], [74.52540588, 13.97431183], [74.52513885, 13.97430515], [74.52513885, 13.97458267], [74.52485657, 13.97458076], [74.52485657, 13.97514153], [74.52458191, 13.97514153], [74.52458191, 13.97542191], [74.52430725, 13.97541714], [74.52430725, 13.97569466], [74.52403259, 13.9756794], [74.52403259, 13.97625065], [74.52375031, 13.97625065], [74.52375031, 13.97653198], [74.52348328, 13.97653198], [74.52348328, 13.9776392], [74.5229187, 13.9776392], [74.5229187, 13.97791958], [74.52263641, 13.97791767], [74.52263641, 13.9784708], [74.5220871, 13.97846889], [74.5220871, 13.97902966], [74.52180481, 13.97902679], [74.52180481, 13.97958374], [74.52153015, 13.97958374], [74.52153015, 13.97986221], [74.52124786, 13.97985935], [74.52124786, 13.98042011], [74.52097321, 13.98041534], [74.52097321, 13.98097229], [74.52069092, 13.98096943], [74.52069092, 13.98125172], [74.52041626, 13.98125172], [74.52041626, 13.98180962], [74.5201416, 13.98180962], [74.5201416, 13.98236179], [74.51985931, 13.98236179], [74.51985931, 13.98264027], [74.51902771, 13.98264027], [74.51902771, 13.98291969], [74.51819611, 13.98291779], [74.51819611, 13.98319435], [74.51791382, 13.98319435], [74.51791382, 13.98347187], [74.51763916, 13.98347187], [74.51763916, 13.98402977], [74.51735687, 13.98402977], [74.51735687, 13.98431015], [74.51708221, 13.98430634], [74.51708221, 13.98458385], [74.5165329, 13.98458195], [74.5165329, 13.98487091], [74.51625824, 13.98487091], [74.51625824, 13.98513985], [74.51597595, 13.98513985], [74.51597595, 13.98542023], [74.51569366, 13.98541641], [74.51569366, 13.98569393], [74.51513672, 13.98569393], [74.51513672, 13.9859724], [74.51486206, 13.98596954], [74.51486206, 13.98624992], [74.51457977, 13.98624992], [74.51457977, 13.98764038], [74.51431274, 13.98764038], [74.51431274, 13.99014091], [74.51403046, 13.99014091], [74.51403046, 13.9918108], [74.51374817, 13.9918108], [74.51374817, 13.99236012], [74.51346588, 13.99236012], [74.51346588, 13.99292088], [74.51319122, 13.99291706], [74.51319122, 13.99569511], [74.51291656, 13.99569035], [74.51291656, 13.99625111], [74.51264191, 13.99625111], [74.51264191, 13.99681187], [74.51235962, 13.99680519], [74.51235962, 13.99708271], [74.51208496, 13.99708271], [74.51208496, 13.99736118], [74.51180267, 13.99736118], [74.51180267, 13.99792099], [74.51152802, 13.99792099], [74.51152802, 13.99875069], [74.51125336, 13.99875069], [74.51125336, 13.99903107], [74.51097107, 13.99903107], [74.51097107, 13.99930859], [74.50985718, 13.99930859], [74.50985718, 13.99992943], [74.50985718, 14.00013924], [74.51013184, 14.00013924], [74.51013184, 14.00097084], [74.50985718, 14.00097084], [74.50985718, 14.00125122], [74.50958252, 14.00125122], [74.50958252, 14.00181198], [74.50930786, 14.00180531], [74.50930786, 14.00208282], [74.5090332, 14.00208092], [74.5090332, 14.00264168], [74.50875092, 14.00263882], [74.50875092, 14.00458336], [74.50902557, 14.00458336], [74.50902557, 14.00708389], [74.50875092, 14.00708103], [74.50875092, 14.00764179], [74.50846863, 14.00763988], [74.50846863, 14.00819111], [74.50818634, 14.00819969], [74.50818634, 14.00904083], [74.50791931, 14.00902843], [74.50791931, 14.00958443], [74.50763702, 14.00958157], [74.50763702, 14.01014042], [74.50736237, 14.01013756], [74.50736237, 14.01097202], [74.50707245, 14.01097202], [74.50707245, 14.01152992], [74.50680542, 14.01152802], [74.50680542, 14.01236153], [74.50653076, 14.01235962], [74.50653076, 14.01292038], [74.50624847, 14.01291561], [74.50624847, 14.0134716], [74.50596619, 14.0134697], [74.50596619, 14.01431084], [74.50569153, 14.01430607], [74.50569153, 14.01486015], [74.50541687, 14.01485062], [74.50541687, 14.01542091], [74.50514221, 14.01541615], [74.50514221, 14.01597214], [74.50485992, 14.01597023], [74.50485992, 14.01653099], [74.50458527, 14.01652813], [74.50458527, 14.01708221], [74.50430298, 14.01708031], [74.50430298, 14.01764107], [74.50402832, 14.01763821], [74.50402832, 14.0181942], [74.50374603, 14.01819038], [74.50374603, 14.01875114], [74.50347137, 14.01875114], [74.50347137, 14.01931095], [74.50319672, 14.01930428], [74.50319672, 14.01986027], [74.5029068, 14.01986027], [74.5029068, 14.02042103], [74.50263977, 14.02042103], [74.50263977, 14.02098179], [74.50235748, 14.02098179], [74.50235748, 14.02153111], [74.50208282, 14.0215292], [74.50208282, 14.02208328], [74.50180817, 14.02208042], [74.50180817, 14.02264118], [74.50152588, 14.02264118], [74.50152588, 14.02375126], [74.50125122, 14.02375126], [74.50125122, 14.02486134], [74.50152588, 14.02486134], [74.50152588, 14.02514076], [74.50208282, 14.02514076], [74.50208282, 14.02541924], [74.50235748, 14.02541924], [74.50235748, 14.02625084], [74.5029068, 14.02625084], [74.5029068, 14.02652931], [74.50485992, 14.02652931], [74.50485992, 14.02625084], [74.50569153, 14.02625084], [74.50569153, 14.02652931], [74.50596619, 14.02652931], [74.50596619, 14.02680969], [74.50624847, 14.02680492], [74.50624847, 14.0270834], [74.50653076, 14.02708054], [74.50653076, 14.02736092], [74.50681305, 14.02736092], [74.50681305, 14.0276413], [74.50763702, 14.0276413], [74.50763702, 14.02792168], [74.51097107, 14.02792168], [74.51097107, 14.0276413], [74.51125336, 14.0276413], [74.51125336, 14.02792168], [74.5118866, 14.02791691], [74.51209259, 14.02792168], [74.51210022, 14.0276413], [74.51346588, 14.0276413], [74.51346588, 14.02736092], [74.51403046, 14.02736092], [74.51403046, 14.02708054], [74.51457977, 14.0270834], [74.51457977, 14.02680492], [74.51513672, 14.02680969], [74.51513672, 14.02652931], [74.51568604, 14.02652931], [74.51568604, 14.02625084], [74.51763916, 14.02625084], [74.51763916, 14.02680969], [74.51791382, 14.02680492], [74.51791382, 14.0270834], [74.51763916, 14.02708054], [74.51763916, 14.02736092], [74.51735687, 14.02736092], [74.51735687, 14.0276413], [74.51680756, 14.0276413], [74.51680756, 14.02792168], [74.51652527, 14.02791691], [74.51652527, 14.02819538], [74.51597595, 14.02819538], [74.51597595, 14.02847099], [74.51568604, 14.02847099], [74.51568604, 14.02875137], [74.51541901, 14.02875137], [74.51541901, 14.02903175], [74.51513672, 14.02903175], [74.51513672, 14.02931023], [74.51457977, 14.02930546], [74.51457977, 14.02958298], [74.51374817, 14.02958298], [74.51374817, 14.02986145], [74.51345825, 14.02986145], [74.51291656, 14.02986145], [74.51291656, 14.03015137], [74.51235962, 14.03015137], [74.51235962, 14.0304203], [74.51180267, 14.03041744], [74.51180267, 14.03069305], [74.51152802, 14.03069305], [74.51152802, 14.03097439], [74.51097107, 14.03097057], [74.51097107, 14.03125191], [74.51040649, 14.03125191], [74.51040649, 14.03153038], [74.5090332, 14.03153038], [74.5090332, 14.03180981], [74.50846863, 14.03180504], [74.50846863, 14.03208256], [74.50814819, 14.03208065], [74.50791931, 14.03208065], [74.50791931, 14.03236198], [74.50736237, 14.03236198], [74.50736237, 14.03292179], [74.50708008, 14.03291798], [74.50708008, 14.03319645], [74.50681305, 14.03319073], [74.50681305, 14.03374958], [74.50653076, 14.03374958], [74.50653076, 14.03431034], [74.50708008, 14.03430557], [74.50708008, 14.03458405], [74.50736237, 14.03457928], [74.50736237, 14.03542042], [74.50763702, 14.03542042], [74.50763702, 14.03625202], [74.50791931, 14.03625011], [74.50791931, 14.03708363], [74.50818634, 14.03707886], [74.50818634, 14.03792], [74.50846863, 14.03791809], [74.50846863, 14.0381937], [74.50875092, 14.0381918], [74.50875092, 14.03874969], [74.50902557, 14.03874969], [74.50902557, 14.03902817], [74.50708008, 14.03902817], [74.50708008, 14.0381937], [74.50680542, 14.0381937], [74.50680542, 14.03763771], [74.50624847, 14.03763962], [74.50624847, 14.03736019], [74.50596619, 14.03736019], [74.50596619, 14.03763962], [74.50569153, 14.03763771], [74.50569153, 14.0381937], [74.50541687, 14.0381918], [74.50541687, 14.03874969], [74.50514221, 14.03874969], [74.50514221, 14.03931141], [74.50485992, 14.03930569], [74.50485992, 14.03959084], [74.50485992, 14.03986168], [74.50458527, 14.03985977], [74.50458527, 14.04064178], [74.5045929, 14.04181099], [74.50428009, 14.04180622], [74.50402832, 14.04181099], [74.50402832, 14.04125023], [74.50374603, 14.04125023], [74.50374603, 14.04068947], [74.50347137, 14.04069424], [74.50347137, 14.03902817], [74.50375366, 14.03902817], [74.50375366, 14.03763771], [74.50402832, 14.03763962], [74.50402832, 14.03736019], [74.50430298, 14.0373621], [74.50430298, 14.03680611], [74.5045929, 14.03680992], [74.5045929, 14.03652954], [74.50485992, 14.03652954], [74.50485992, 14.0359602], [74.50458527, 14.03597164], [74.50458527, 14.03541565], [74.50430298, 14.03542042], [74.50430298, 14.03402996], [74.50485992, 14.03402996], [74.50485992, 14.0334692], [74.50569153, 14.03347111], [74.50569153, 14.03291798], [74.50596619, 14.03292179], [74.50596619, 14.03264046], [74.50514221, 14.03264046], [74.50514221, 14.03208065], [74.50541687, 14.03208256], [74.50541687, 14.03152657], [74.50569153, 14.03153038], [74.50569153, 14.03125191], [74.50596619, 14.03125191], [74.50596619, 14.0304203], [74.50624847, 14.0304203], [74.50624847, 14.02986145], [74.50569153, 14.02986145], [74.50569153, 14.02958298], [74.50541687, 14.02958298], [74.50541687, 14.02930546], [74.50485992, 14.02931023], [74.50485992, 14.02903175], [74.50430298, 14.02903175], [74.50430298, 14.02875137], [74.50402832, 14.02875137], [74.50402832, 14.02847099], [74.50347137, 14.02847099], [74.50347137, 14.02819538], [74.50319672, 14.02819538], [74.50319672, 14.02791691], [74.50263977, 14.02792168], [74.50263977, 14.0276413], [74.50235748, 14.0276413], [74.50235748, 14.02736092], [74.50208282, 14.02736092], [74.50208282, 14.02708054], [74.50180817, 14.02708054], [74.50180817, 14.02736092], [74.50125122, 14.02736092], [74.50125122, 14.0270834], [74.50096893, 14.02708054], [74.50096893, 14.02903175], [74.50068665, 14.02903175], [74.50068665, 14.03180981], [74.50096893, 14.03180981], [74.50096893, 14.03652954], [74.50069427, 14.03652763], [74.50069427, 14.04069424], [74.50041962, 14.04069424], [74.50041962, 14.04319382], [74.50013733, 14.04319191], [74.50013733, 14.04486275], [74.49986267, 14.04486275], [74.49986267, 14.04653072], [74.49958038, 14.04652882], [74.49958038, 14.04819489], [74.49930573, 14.04819489], [74.49931335, 14.04986095], [74.49903107, 14.04986095], [74.49903107, 14.05125141], [74.49874878, 14.05125141], [74.49874878, 14.05236053], [74.49847412, 14.05236053], [74.49847412, 14.05347347], [74.49819183, 14.05347347], [74.49819183, 14.0545826], [74.49791718, 14.0545826], [74.49791718, 14.05569458], [74.49764252, 14.05569077], [74.49764252, 14.05681038], [74.49736023, 14.05681038], [74.49736023, 14.05792046], [74.4970932, 14.05792046], [74.4970932, 14.05902958], [74.49680328, 14.05902672], [74.49680328, 14.06013966], [74.49652863, 14.06013012], [74.49652863, 14.06124973], [74.49624634, 14.06124973], [74.49624634, 14.06236172], [74.49597168, 14.06236172], [74.49597168, 14.06347179], [74.49569702, 14.06347179], [74.49569702, 14.06431007], [74.4954071, 14.06431007], [74.4954071, 14.06542015], [74.49513245, 14.06542015], [74.49513245, 14.06653023], [74.49485779, 14.06653023], [74.49485779, 14.0676403], [74.49458313, 14.0676403], [74.49458313, 14.06903267], [74.49430847, 14.06903267], [74.49430847, 14.07042122], [74.49402618, 14.07042122], [74.49402618, 14.07181072], [74.49375153, 14.07180691], [74.49375153, 14.07319546], [74.49346924, 14.07318974], [74.49346924, 14.07431126], [74.49319458, 14.07430363], [74.49319458, 14.07569504], [74.49291992, 14.07569504], [74.49291992, 14.07708263], [74.49263763, 14.07708263], [74.49263763, 14.07847309], [74.49236298, 14.07847118], [74.49236298, 14.07930946], [74.49207306, 14.07930946], [74.49207306, 14.07986069], [74.49180603, 14.07986069], [74.49180603, 14.08041859], [74.49153137, 14.08041668], [74.49153137, 14.08097267], [74.49124908, 14.08096886], [74.49124908, 14.08153152], [74.49097443, 14.08152676], [74.49097443, 14.08208275], [74.49069214, 14.08208084], [74.49069214, 14.0826416], [74.49041748, 14.0826416], [74.49041748, 14.08292198], [74.49013519, 14.08291721], [74.49013519, 14.0834713], [74.48986053, 14.0834713], [74.48986053, 14.08403015], [74.48958588, 14.08402729], [74.48958588, 14.08458328], [74.48929596, 14.08458138], [74.48929596, 14.08513927], [74.48902893, 14.08513927], [74.48902893, 14.08569336], [74.48874664, 14.08569145], [74.48874664, 14.08624935], [74.48847198, 14.08624935], [74.48847198, 14.08681011], [74.48819733, 14.08680534], [74.48819733, 14.08847237], [74.48847198, 14.08847237], [74.48847198, 14.09069443], [74.48819733, 14.09069061], [74.48819733, 14.09181023], [74.48792267, 14.09181023], [74.48792267, 14.09263992], [74.48735809, 14.09263992], [74.48735809, 14.0929203], [74.48707581, 14.0929203], [74.48707581, 14.09320068], [74.48652649, 14.09319401], [74.48652649, 14.09347153], [74.48458099, 14.09347153], [74.48458099, 14.09291553], [74.48430634, 14.0929203], [74.48430634, 14.09208202], [74.48374939, 14.09208393], [74.48374939, 14.0923624], [74.4834671, 14.09235954], [74.4834671, 14.09263992], [74.48291779, 14.09263992], [74.48291779, 14.0929203], [74.48264313, 14.0929203], [74.48264313, 14.09320068], [74.48152924, 14.09320068], [74.48152924, 14.0929203], [74.48069763, 14.0929203], [74.48069763, 14.09320068], [74.48042297, 14.09320068], [74.48042297, 14.09375], [74.48069763, 14.09375], [74.48069763, 14.09431076], [74.48097229, 14.09431076], [74.48097229, 14.09486008], [74.48264313, 14.09486008], [74.48264313, 14.09514046], [74.48291779, 14.09514046], [74.48291779, 14.09542274], [74.48319244, 14.09542274], [74.48319244, 14.09514046], [74.48374939, 14.09514046], [74.48374939, 14.09486008], [74.48513794, 14.09486008], [74.48513794, 14.0945797], [74.48596954, 14.0945797], [74.48596954, 14.09514046], [74.48625183, 14.0951376], [74.48625183, 14.09597206], [74.48652649, 14.09597015], [74.48652649, 14.09653091], [74.48680878, 14.09653091], [74.48680878, 14.09735966], [74.48708344, 14.09736156], [74.48708344, 14.09958458], [74.48735809, 14.09958172], [74.48735809, 14.10264111], [74.48764038, 14.10264111], [74.48764038, 14.1054306], [74.48792267, 14.1054306], [74.48792267, 14.11042023], [74.48764038, 14.11042023], [74.48764038, 14.11180973], [74.48680878, 14.11180973], [74.48680878, 14.11069107], [74.48652649, 14.11069489], [74.48652649, 14.10986137], [74.48625183, 14.10986137], [74.48625183, 14.11042023], [74.48596954, 14.11041737], [74.48596954, 14.11097336], [74.48568726, 14.11097145], [74.48568726, 14.11180973], [74.48542023, 14.11180973], [74.48542023, 14.11236095], [74.48513794, 14.11236095], [74.48513794, 14.11347103], [74.48486328, 14.11347103], [74.48486328, 14.11514187], [74.48458099, 14.11514187], [74.48458099, 14.11653042], [74.48430634, 14.11652756], [74.48430634, 14.11819363], [74.48401642, 14.11818886], [74.48402405, 14.1198597], [74.48374939, 14.1198597], [74.48374939, 14.12125015], [74.4834671, 14.12125015], [74.4834671, 14.12292099], [74.48319244, 14.12292099], [74.48319244, 14.12431145], [74.48291779, 14.12431145], [74.48291779, 14.12597179], [74.48264313, 14.12597179], [74.48264313, 14.12764072], [74.48236084, 14.12764072], [74.48236084, 14.12903118], [74.48208618, 14.12902641], [74.48208618, 14.13069534], [74.48179626, 14.13068962], [74.48179626, 14.13180923], [74.48152924, 14.13180923], [74.48152924, 14.13264084], [74.48124695, 14.13263893], [74.48124695, 14.1334734], [74.48097229, 14.13347054], [74.48097229, 14.13431168], [74.48069763, 14.13431168], [74.48069763, 14.13514137], [74.48042297, 14.13514137], [74.48041534, 14.13624859], [74.48014069, 14.13625145], [74.48014069, 14.13695145], [74.48014069, 14.13708305], [74.4798584, 14.13708115], [74.4798584, 14.13792038], [74.47957611, 14.13792038], [74.47957611, 14.13875198], [74.47930908, 14.13875198], [74.47930908, 14.13931179], [74.47902679, 14.13930511], [74.47902679, 14.13986111], [74.47820282, 14.1398592], [74.47820282, 14.14013958], [74.47735596, 14.14013958], [74.47735596, 14.14041996], [74.47652435, 14.14041805], [74.47652435, 14.14069557], [74.47680664, 14.14069557], [74.47680664, 14.14097118], [74.47708893, 14.14096928], [74.47708893, 14.14154053], [74.47736359, 14.14152813], [74.47736359, 14.14208412], [74.47763824, 14.14208126], [74.47763824, 14.14264202], [74.4779129, 14.14264011], [74.4779129, 14.1431942], [74.47819519, 14.1431942], [74.47819519, 14.14375019], [74.47846985, 14.14375019], [74.47846985, 14.14735985], [74.47820282, 14.14735126], [74.47820282, 14.14902973], [74.4779129, 14.14902782], [74.4779129, 14.14986229], [74.47846985, 14.14986229], [74.47846985, 14.14958191], [74.47902679, 14.14958191], [74.47902679, 14.15014267], [74.47875214, 14.1501379], [74.47875214, 14.15069389], [74.47846985, 14.15069199], [74.47846985, 14.15125275], [74.47820282, 14.15125275], [74.47820282, 14.15181065], [74.4779129, 14.15181065], [74.4779129, 14.15235996], [74.47763824, 14.15235996], [74.47763824, 14.15292072], [74.47735596, 14.15292072], [74.47735596, 14.15348244], [74.47708893, 14.15348244], [74.47708893, 14.1540308], [74.47680664, 14.1540308], [74.47680664, 14.15514088], [74.47651672, 14.15514088], [74.47651672, 14.15653992], [74.47624969, 14.15653992], [74.47624969, 14.15792084], [74.47598267, 14.15792084], [74.47598267, 14.15930939], [74.47569275, 14.15930939], [74.47569275, 14.16041946], [74.47541809, 14.16041946], [74.47541809, 14.16181183], [74.4751358, 14.16180515], [74.4751358, 14.16319466], [74.47486115, 14.16319466], [74.47486115, 14.16458321], [74.47458649, 14.1645813], [74.47458649, 14.16541958], [74.4743042, 14.16541672], [74.4743042, 14.1659708], [74.47402954, 14.16597366], [74.47402954, 14.16708279], [74.47429657, 14.16708088], [74.47429657, 14.16875172], [74.47402954, 14.16875172], [74.47402954, 14.16930962], [74.47374725, 14.16930962], [74.47374725, 14.16986179], [74.4734726, 14.16986179], [74.4734726, 14.17097187], [74.47319794, 14.17097187], [74.47319794, 14.17208385], [74.47291565, 14.17208385], [74.47291565, 14.17319393], [74.47264099, 14.17319202], [74.47264099, 14.17431068], [74.4723587, 14.17431068], [74.4723587, 14.17542267], [74.47207642, 14.17542267], [74.47207642, 14.17653275], [74.47180939, 14.17652798], [74.47180176, 14.17736244], [74.4715271, 14.17735958], [74.4715271, 14.1779213], [74.47125244, 14.17791557], [74.47125244, 14.17847157], [74.47097015, 14.17847157], [74.47097015, 14.18069363], [74.4706955, 14.18069363], [74.4706955, 14.18319511], [74.47097015, 14.18319511], [74.47097015, 14.18347263], [74.4706955, 14.18347263], [74.47070313, 14.18375111], [74.47041321, 14.18375111], [74.47041321, 14.18431091], [74.47013855, 14.18431091], [74.47013855, 14.18542099], [74.46985626, 14.18542099], [74.46985626, 14.18625069], [74.4695816, 14.18624878], [74.4695816, 14.18708324], [74.46930695, 14.18708324], [74.46930695, 14.18819523], [74.46901703, 14.18819141], [74.46901703, 14.18875122], [74.46875, 14.18875122], [74.46875, 14.1890316], [74.46847534, 14.18902683], [74.46847534, 14.18958282], [74.46819305, 14.18958092], [74.46819305, 14.19014168], [74.4679184, 14.19013882], [74.4679184, 14.19097328], [74.46763611, 14.19097137], [74.46763611, 14.19153023], [74.46736145, 14.19152737], [74.46736145, 14.19208336], [74.46708679, 14.19208145], [74.46708679, 14.19291973], [74.4668045, 14.19291687], [74.4668045, 14.19347095], [74.46652985, 14.19347095], [74.46652985, 14.19625187], [74.46679688, 14.19625187], [74.46679688, 14.19680977], [74.46652985, 14.19680977], [74.46652985, 14.19736195], [74.46624756, 14.19736195], [74.46624756, 14.19764042], [74.4659729, 14.19763756], [74.4659729, 14.19819355], [74.46569824, 14.19819355], [74.46569824, 14.19847202], [74.46541595, 14.19845963], [74.4654007, 14.19902992], [74.46514893, 14.19902992], [74.46514893, 14.1993103], [74.46485901, 14.19930553], [74.46485901, 14.19958401], [74.46458435, 14.19958401], [74.46458435, 14.19986153], [74.4640274, 14.19985962], [74.4640274, 14.20014], [74.46375275, 14.20014], [74.46375275, 14.20042038], [74.46347046, 14.20041561], [74.46347046, 14.20069408], [74.4631958, 14.20069408], [74.4631958, 14.2009716], [74.46013641, 14.2009716], [74.46013641, 14.20083141], [74.46013641, 14.20069408], [74.45986176, 14.20069408], [74.45986176, 14.20014], [74.4595871, 14.20014], [74.4595871, 14.19985962], [74.45930481, 14.19986153], [74.45930481, 14.19958401], [74.45903015, 14.19958401], [74.45903015, 14.19930553], [74.45874786, 14.1993103], [74.45874786, 14.19902992], [74.45847321, 14.19902992], [74.45847321, 14.19874954], [74.45819092, 14.19874954], [74.45819092, 14.19845963], [74.45791626, 14.19845963], [74.45791626, 14.19874954], [74.4576416, 14.19874954], [74.4576416, 14.19902992], [74.45707703, 14.19902992], [74.45707703, 14.1993103], [74.45680237, 14.19930553], [74.45680237, 14.19958401], [74.45625305, 14.19958401], [74.45625305, 14.19986153], [74.45596313, 14.19985962], [74.45596313, 14.20014], [74.45485687, 14.20014], [74.45485687, 14.19985962], [74.45458221, 14.19986153], [74.45458221, 14.19958401], [74.45430756, 14.19958401], [74.45430756, 14.19930553], [74.45402527, 14.19930553], [74.45402527, 14.19986153], [74.45375061, 14.19985962], [74.45375061, 14.20042038], [74.45347595, 14.20041561], [74.45347595, 14.2009716], [74.45319366, 14.2009716], [74.45319366, 14.2015276], [74.45347595, 14.20152092], [74.45347595, 14.20181084], [74.45375061, 14.20180607], [74.45375061, 14.20236206], [74.4540329, 14.20236015], [74.4540329, 14.20263958], [74.45430756, 14.20263958], [74.45430756, 14.20292091], [74.45402527, 14.20291615], [74.45402527, 14.20319366], [74.45375061, 14.20319366], [74.45375061, 14.20347214], [74.45347595, 14.20347023], [74.45347595, 14.20374966], [74.45318604, 14.20374966], [74.45318604, 14.20403099], [74.45291901, 14.20403099], [74.45291901, 14.20431137], [74.45263672, 14.20431137], [74.45263672, 14.20485973], [74.45236206, 14.20485973], [74.45236206, 14.20542145], [74.45263672, 14.20542145], [74.45263672, 14.20653057], [74.45291901, 14.20652771], [74.45291901, 14.20736027], [74.45236206, 14.20736027], [74.45236206, 14.20765018], [74.45153046, 14.20765018], [74.45153046, 14.20792103], [74.45097351, 14.20791626], [74.45097351, 14.20819473], [74.45069122, 14.20818996], [74.45069122, 14.20875072], [74.45041656, 14.20875072], [74.45041656, 14.2098608], [74.45069122, 14.2098608], [74.45069122, 14.21014118], [74.45097351, 14.21013927], [74.45097351, 14.21069527], [74.45069122, 14.21069527], [74.45069122, 14.21097279], [74.45041656, 14.21097088], [74.45041656, 14.21153069], [74.45014954, 14.21153069], [74.45014954, 14.21181202], [74.44902802, 14.21181202], [74.44902802, 14.21291924], [74.44930267, 14.21291733], [74.44930267, 14.21347332], [74.44958496, 14.21347332], [74.44958496, 14.21569538], [74.44930267, 14.21569061], [74.44930267, 14.21653175], [74.44847107, 14.21652699], [74.44847107, 14.21736145], [74.44875336, 14.21736145], [74.44875336, 14.21819305], [74.44819641, 14.21819305], [74.44819641, 14.21847343], [74.44790649, 14.21847057], [74.44790649, 14.21875191], [74.44763947, 14.21875191], [74.44763947, 14.21903038], [74.44735718, 14.21903038], [74.44735718, 14.21930981], [74.44708252, 14.21930981], [74.44708252, 14.21959019], [74.44596863, 14.21959019], [74.44596863, 14.21986103], [74.44541931, 14.21986103], [74.44541931, 14.22013855], [74.44458008, 14.22013855], [74.44458008, 14.22042179], [74.44403076, 14.22041798], [74.44403076, 14.22236156], [74.44374847, 14.22236156], [74.44374847, 14.22264004], [74.44346619, 14.22263145], [74.44346619, 14.22292042], [74.44319153, 14.2229147], [74.44319153, 14.22319412], [74.44291687, 14.22319412], [74.44291687, 14.22347164], [74.44264221, 14.22347164], [74.44264221, 14.22375202], [74.44180298, 14.22375011], [74.44180298, 14.2248621], [74.44152832, 14.22486019], [74.44152832, 14.22624969], [74.4420929, 14.22624969], [74.4420929, 14.22653008], [74.44235992, 14.22653008], [74.44235992, 14.22681141], [74.44264221, 14.22680569], [74.44264221, 14.22708416], [74.44291687, 14.22707939], [74.44291687, 14.22791958], [74.44264221, 14.22791958], [74.44264221, 14.22902966], [74.44235992, 14.22902775], [74.44235992, 14.22986221], [74.44208527, 14.22986221], [74.44208527, 14.23069382], [74.44180298, 14.23069191], [74.44180298, 14.23153114], [74.44152832, 14.23153114], [74.44152832, 14.23236179], [74.44125366, 14.23235989], [74.44125366, 14.23319435], [74.440979, 14.23318958], [74.440979, 14.23403072], [74.44069672, 14.23402882], [74.44069672, 14.23486042], [74.44041443, 14.23486042], [74.44041443, 14.23569489], [74.44013977, 14.23569012], [74.44013977, 14.23653126], [74.43985748, 14.23653126], [74.43985748, 14.23736095], [74.43958282, 14.23736095], [74.43958282, 14.23819542], [74.43930817, 14.2381897], [74.43930817, 14.23903084], [74.43902588, 14.23902893], [74.43902588, 14.23986053], [74.43875122, 14.23986053], [74.43875122, 14.24070168], [74.43846893, 14.24070168], [74.43846893, 14.24125099], [74.43819427, 14.24125099], [74.43819427, 14.2420826], [74.43791962, 14.24208069], [74.43791962, 14.24292183], [74.43763733, 14.24291706], [74.43763733, 14.24347115], [74.43736267, 14.24347115], [74.43736267, 14.24431038], [74.43708038, 14.24431038], [74.43708038, 14.24514198], [74.43680573, 14.24513912], [74.43680573, 14.24569321], [74.43653107, 14.2456913], [74.43653107, 14.24652958], [74.43624878, 14.24652958], [74.43624878, 14.24763966], [74.43596649, 14.24763966], [74.43596649, 14.24875164], [74.43569183, 14.24874878], [74.43569183, 14.2495842], [74.43541718, 14.2495842], [74.43541718, 14.25069427], [74.43514252, 14.25069141], [74.43514252, 14.25152969], [74.4348526, 14.25152969], [74.4348526, 14.25263977], [74.43458557, 14.25263786], [74.4345932, 14.25374985], [74.43430328, 14.25374985], [74.43430328, 14.25458431], [74.43402863, 14.25457954], [74.43402863, 14.25542068], [74.43374634, 14.25541592], [74.43374634, 14.25597191], [74.43347168, 14.25597191], [74.43347168, 14.25681114], [74.43319702, 14.25681114], [74.43319702, 14.25764275], [74.43291473, 14.25763798], [74.4329071, 14.25819016], [74.43264008, 14.25820065], [74.43264008, 14.2590313], [74.43235779, 14.2590313], [74.43235779, 14.26014137], [74.43208313, 14.26014137], [74.43208313, 14.26153088], [74.43180847, 14.26152897], [74.43180847, 14.2620821], [74.43152618, 14.26208019], [74.43152618, 14.26264095], [74.43125153, 14.26263905], [74.43125153, 14.26319504], [74.43096924, 14.26319027], [74.43096924, 14.26375103], [74.43069458, 14.26375103], [74.43069458, 14.26458263], [74.43041992, 14.26457977], [74.43041992, 14.26514053], [74.43013763, 14.26513863], [74.43013763, 14.26569462], [74.42986298, 14.26568985], [74.42986298, 14.26625061], [74.42958069, 14.2662487], [74.42958069, 14.26708317], [74.42930603, 14.26708317], [74.42930603, 14.26819515], [74.429039, 14.26819134], [74.429039, 14.26903152], [74.42874908, 14.26902676], [74.42874908, 14.26986122], [74.42847443, 14.26986122], [74.42847443, 14.27097321], [74.42819214, 14.2709713], [74.42819214, 14.27180958], [74.42791748, 14.27180958], [74.42791748, 14.27263927], [74.42763519, 14.27263927], [74.42763519, 14.27374935], [74.42736053, 14.27374935], [74.42736053, 14.27458286], [74.42708588, 14.27458286], [74.42708588, 14.2756958], [74.42679596, 14.27569103], [74.42679596, 14.27653027], [74.42652893, 14.27653027], [74.42652893, 14.27736187], [74.42624664, 14.27736187], [74.42624664, 14.27847195], [74.42597961, 14.27847195], [74.42597961, 14.27931023], [74.42624664, 14.27931023], [74.42624664, 14.28013992], [74.42652893, 14.28013992], [74.42652893, 14.28125], [74.42624664, 14.28125], [74.42624664, 14.28236008], [74.42597961, 14.28236008], [74.42597961, 14.28264046], [74.42569733, 14.28264046], [74.42569733, 14.28293037], [74.42541504, 14.28291607], [74.42541504, 14.28347206], [74.42514038, 14.28347015], [74.42514038, 14.28374958], [74.42485809, 14.28374958], [74.42485809, 14.28486156], [74.42457581, 14.28485966], [74.42457581, 14.28625011], [74.42430878, 14.28625011], [74.42430878, 14.28736019], [74.42402649, 14.28736019], [74.42402649, 14.28847313], [74.42375183, 14.28847313], [74.42375183, 14.28958225], [74.42346954, 14.28958225], [74.42346954, 14.29069519], [74.42375183, 14.29069042], [74.42375183, 14.29181099], [74.42402649, 14.29181099], [74.42402649, 14.29264069], [74.42430878, 14.29263878], [74.42430878, 14.29347324], [74.42458344, 14.29347324], [74.42458344, 14.29458332], [74.42485809, 14.29458141], [74.42485809, 14.2954216], [74.42457581, 14.2954216], [74.42457581, 14.29653168], [74.42430878, 14.29652691], [74.42430878, 14.2970829], [74.42402649, 14.29708099], [74.42402649, 14.29764175], [74.42375183, 14.29763889], [74.42375183, 14.29783058], [74.42375183, 14.29819489], [74.42362976, 14.29819489], [74.42346954, 14.29819489], [74.42346954, 14.29868126], [74.4229126, 14.29875088], [74.4229126, 14.29902935], [74.42208099, 14.29902935], [74.42208099, 14.29930973], [74.42124939, 14.29930496], [74.42124939, 14.29958344], [74.4209671, 14.29958057], [74.4209671, 14.30013943], [74.42069244, 14.30013943], [74.42069244, 14.30069637], [74.42041779, 14.30069065], [74.42041779, 14.30124855], [74.42014313, 14.30124855], [74.42014313, 14.30153179], [74.41986084, 14.30152702], [74.41986084, 14.30208397], [74.41958618, 14.30208111], [74.41958618, 14.30264187], [74.41930389, 14.30263996], [74.41930389, 14.30319309], [74.41902924, 14.30319118], [74.41902924, 14.30375195], [74.41874695, 14.30375195], [74.41874695, 14.30430984], [74.41847229, 14.30430603], [74.41847229, 14.30458355], [74.41819763, 14.30458069], [74.41819763, 14.30513954], [74.41791534, 14.30513763], [74.41791534, 14.30569363], [74.41764069, 14.30568886], [74.41764069, 14.30624962], [74.4173584, 14.30624962], [74.4173584, 14.30681038], [74.41707611, 14.30681038], [74.41708374, 14.3073597], [74.41680908, 14.3073597], [74.41680908, 14.30792046], [74.41652679, 14.30791569], [74.41652679, 14.30847168], [74.41625214, 14.30846977], [74.41625214, 14.30931091], [74.41652679, 14.30930614], [74.41652679, 14.30958366], [74.41625214, 14.30958366], [74.41625214, 14.31069374], [74.41596985, 14.31069183], [74.41596985, 14.31124973], [74.41570282, 14.31124973], [74.41570282, 14.31181145], [74.4154129, 14.31181145], [74.4154129, 14.31236172], [74.41513824, 14.31236172], [74.41513824, 14.31264019], [74.41486359, 14.31263828], [74.41486359, 14.31319427], [74.4145813, 14.31319046], [74.4145813, 14.31375027], [74.41430664, 14.31375027], [74.41430664, 14.31431103], [74.41402435, 14.31430435], [74.41402435, 14.31486034], [74.41374969, 14.31486034], [74.41374969, 14.31569481], [74.41347504, 14.31569481], [74.41348267, 14.31736088], [74.41319275, 14.31736088], [74.41319275, 14.32208347], [74.41348267, 14.32208061], [74.41348267, 14.32514191], [74.41319275, 14.32513905], [74.41319275, 14.32736111], [74.41291809, 14.32736111], [74.41291809, 14.32958412], [74.4126358, 14.32958126], [74.4126358, 14.33098125], [74.41236115, 14.33098125], [74.41236115, 14.33181], [74.41208649, 14.33180618], [74.41208649, 14.33236217], [74.4118042, 14.33236217], [74.4118042, 14.33319378], [74.41152954, 14.33319378], [74.41152954, 14.33402824], [74.41124725, 14.33402824], [74.41124725, 14.33485985], [74.4109726, 14.33485985], [74.4109726, 14.33541965], [74.41069794, 14.33541965], [74.41069794, 14.33625031], [74.41041565, 14.33625031], [74.41041565, 14.33708191], [74.41014099, 14.33708382], [74.41014099, 14.33819389], [74.4098587, 14.33819199], [74.4098587, 14.33931065], [74.40957642, 14.33931065], [74.40957642, 14.34015179], [74.40930939, 14.34013844], [74.40930176, 14.34107018], [74.40930176, 14.34125042], [74.4090271, 14.34125042], [74.4090271, 14.34235954], [74.40875244, 14.34235954], [74.40875244, 14.34347343], [74.40847015, 14.34346962], [74.40847015, 14.34486103], [74.40820313, 14.34486103], [74.40820313, 14.34680939], [74.40791321, 14.34680939], [74.40791321, 14.34875107], [74.40763855, 14.34875107], [74.40763855, 14.3526392], [74.40735626, 14.3526392], [74.40735626, 14.35374928], [74.4070816, 14.35374928], [74.4070816, 14.35486126], [74.40680695, 14.35485935], [74.40680695, 14.35542202], [74.40652466, 14.35541534], [74.40652466, 14.35569572], [74.40625, 14.35569572], [74.40625, 14.35597134], [74.40598297, 14.35597134], [74.40598297, 14.35625172], [74.4054184, 14.35625172], [74.4054184, 14.35653019], [74.40513611, 14.35653019], [74.40513611, 14.35680962], [74.40486145, 14.3568058], [74.40486145, 14.35708427], [74.40458679, 14.35708427], [74.40458679, 14.35819435], [74.40513611, 14.35819435], [74.40513611, 14.35847187], [74.4054184, 14.35847187], [74.4054184, 14.35875034], [74.40569305, 14.35875034], [74.40569305, 14.35902977], [74.40598297, 14.35902977], [74.40598297, 14.35931015], [74.40625, 14.35930634], [74.40625, 14.36069393], [74.40598297, 14.36069202], [74.40598297, 14.36124992], [74.4054184, 14.36124992], [74.4054184, 14.3615303], [74.40513611, 14.3615284], [74.40513611, 14.36208439], [74.40486908, 14.36207962], [74.40486908, 14.36264038], [74.40458679, 14.36264038], [74.40458679, 14.36375046], [74.40486908, 14.36375046], [74.40486908, 14.3654213], [74.40569305, 14.3654213], [74.40569305, 14.36513996], [74.40625, 14.36513996], [74.40625, 14.36709118], [74.40569305, 14.36709118], [74.40569305, 14.3668108], [74.4054184, 14.3668108], [74.4054184, 14.36653137], [74.40513611, 14.36653137], [74.40513611, 14.36625004], [74.40486908, 14.36625004], [74.40486908, 14.36596966], [74.40458679, 14.36596966], [74.40458679, 14.36625004], [74.40429688, 14.36625004], [74.40429688, 14.36653137], [74.40402985, 14.36653137], [74.40402985, 14.3668108], [74.4034729, 14.3668108], [74.4034729, 14.36709118], [74.40319824, 14.36709118], [74.40319824, 14.36736012], [74.40291595, 14.36736012], [74.40291595, 14.36792088], [74.4026413, 14.36791611], [74.4026413, 14.3684721], [74.40235901, 14.36847019], [74.40235901, 14.36931133], [74.4026413, 14.36930656], [74.4026413, 14.37013912], [74.40291595, 14.37013912], [74.40291595, 14.37097263], [74.40319824, 14.37096977], [74.40319824, 14.37153053], [74.40513611, 14.37152863], [74.40513611, 14.37208271], [74.4054184, 14.37207985], [74.4054184, 14.37292099], [74.40513611, 14.37292099], [74.40513611, 14.37403107], [74.40486145, 14.37402916], [74.40486908, 14.37486076], [74.40458679, 14.37486076], [74.40458679, 14.37597084], [74.40429688, 14.37597084], [74.40429688, 14.37681198], [74.40402985, 14.37681198], [74.40402985, 14.37764072], [74.40374756, 14.37763882], [74.40374756, 14.37847328], [74.4034729, 14.37847328], [74.4034729, 14.37958336], [74.40319824, 14.37958145], [74.40319824, 14.38041973], [74.40291595, 14.38041973], [74.40291595, 14.38124943], [74.4026413, 14.38124943], [74.4026413, 14.38236237], [74.40235901, 14.38236237], [74.40235901, 14.38347054], [74.40208435, 14.38347054], [74.40208435, 14.38458443], [74.40180206, 14.38458443], [74.40180206, 14.38597202], [74.4015274, 14.38597202], [74.4015274, 14.38708401], [74.40125275, 14.38708401], [74.40125275, 14.3884716], [74.40097046, 14.3884716], [74.40097046, 14.38958359], [74.4006958, 14.38958359], [74.4006958, 14.39069366], [74.40040588, 14.3906889], [74.40040588, 14.39181137], [74.40013885, 14.39181137], [74.40013885, 14.39292145], [74.39985657, 14.39292145], [74.39985657, 14.39403057], [74.39958191, 14.39402771], [74.39958191, 14.39486027], [74.39930725, 14.39486027], [74.39930725, 14.39597321], [74.39901733, 14.39597034], [74.39901733, 14.39681053], [74.39874268, 14.39681053], [74.39874268, 14.39792061], [74.39848328, 14.39792061], [74.39848328, 14.39903069], [74.39819336, 14.39902878], [74.39819336, 14.39986134], [74.3979187, 14.39986134], [74.3979187, 14.40069485], [74.39763641, 14.40069008], [74.39763641, 14.4018116], [74.39736176, 14.4018116], [74.39736176, 14.4026413], [74.3970871, 14.40263939], [74.3970871, 14.40347099], [74.39680481, 14.40347099], [74.39680481, 14.40458298], [74.39653015, 14.40458107], [74.39653015, 14.4054203], [74.39624786, 14.4054203], [74.39624786, 14.40626144], [74.39597321, 14.40626144], [74.39597321, 14.40681171], [74.39568329, 14.40681171], [74.39568329, 14.40763855], [74.39597321, 14.40763855], [74.39597321, 14.40875244], [74.39624786, 14.40874863], [74.39624786, 14.40958405], [74.39597321, 14.40958118], [74.39597321, 14.41014194], [74.39569092, 14.41014004], [74.39569092, 14.41069317], [74.39541626, 14.41069126], [74.39541626, 14.41125202], [74.3951416, 14.41125202], [74.3951416, 14.41180992], [74.39485931, 14.41180992], [74.39485931, 14.41263962], [74.39458466, 14.41263771], [74.39458466, 14.4131937], [74.39430237, 14.41319084], [74.39430237, 14.41374969], [74.39402771, 14.41374969], [74.39402771, 14.41485977], [74.39375305, 14.41485977], [74.39375305, 14.41625023], [74.39347076, 14.41625023], [74.39347076, 14.41681099], [74.39319611, 14.41681099], [74.39319611, 14.41763973], [74.39291382, 14.41763783], [74.39289093, 14.41812611], [74.39263916, 14.41820145], [74.39263916, 14.41875172], [74.39212036, 14.41874981], [74.38819122, 14.41875172], [74.38819122, 14.41847038], [74.38708496, 14.41847229], [74.38708496, 14.41819382], [74.38735962, 14.41820145], [74.38735962, 14.41792107], [74.38764191, 14.41792107], [74.38764191, 14.41763973], [74.38791656, 14.41763973], [74.38791656, 14.41736031], [74.38819122, 14.41736221], [74.38819122, 14.41708374], [74.38680267, 14.41708374], [74.38680267, 14.41736221], [74.38652802, 14.41736031], [74.38652802, 14.41763973], [74.38597107, 14.41763973], [74.38597107, 14.41792107], [74.38569641, 14.41792107], [74.38569641, 14.41820145], [74.38541412, 14.41819382], [74.38541412, 14.41847229], [74.3840332, 14.41847038], [74.3840332, 14.41875172], [74.38346863, 14.41874981], [74.38346863, 14.41958427], [74.38318634, 14.41958046], [74.38318634, 14.42042065], [74.38236237, 14.42041588], [74.38236237, 14.42069435], [74.38208008, 14.42069435], [74.38208008, 14.42125034], [74.38180542, 14.42125034], [74.38180542, 14.42236042], [74.38153076, 14.42236042], [74.38153076, 14.42292118], [74.38124847, 14.42291641], [74.38124847, 14.42347336], [74.38096619, 14.42346954], [74.38096619, 14.42403126], [74.38124847, 14.42402554], [74.38124847, 14.42458344], [74.38180542, 14.42458344], [74.38180542, 14.42486095], [74.38236237, 14.42486095], [74.38236237, 14.42457962], [74.38291931, 14.42458344], [74.38291931, 14.42430687], [74.38402557, 14.42430687], [74.38402557, 14.42486095], [74.38430786, 14.42486095], [74.38430786, 14.42625141], [74.38458252, 14.42625141], [74.38458252, 14.4279213], [74.38430786, 14.42791653], [74.38430786, 14.428195], [74.38375092, 14.428195], [74.38375092, 14.42847347], [74.38346863, 14.42847061], [74.38346863, 14.42875099], [74.38318634, 14.42875099], [74.38318634, 14.42903137], [74.38263702, 14.42903137], [74.38263702, 14.42930889], [74.38236237, 14.42930698], [74.38236237, 14.4295826], [74.3795929, 14.42958069], [74.3795929, 14.43153191], [74.38014221, 14.43153191], [74.38014221, 14.43181038], [74.38041687, 14.43180466], [74.38041687, 14.43208313], [74.38096619, 14.43208122], [74.38096619, 14.43236065], [74.38124847, 14.43236065], [74.38124847, 14.43208122], [74.38153076, 14.43208313], [74.38153076, 14.43180466], [74.38181305, 14.43181038], [74.38181305, 14.43153191], [74.38263702, 14.43152714], [74.38263702, 14.43208313], [74.38291931, 14.43208313], [74.38291931, 14.43319321], [74.38318634, 14.4331789], [74.38318634, 14.43402958], [74.38291931, 14.43402958], [74.38291931, 14.43430996], [74.38263702, 14.43430519], [74.38263702, 14.43486118], [74.38236237, 14.43486118], [74.38236237, 14.43597126], [74.38208008, 14.43597126], [74.38208008, 14.43680954], [74.38180542, 14.43680573], [74.38180542, 14.4370842], [74.38208008, 14.43708134], [74.38208008, 14.43764019], [74.38236237, 14.43764019], [74.38236237, 14.43986225], [74.38208008, 14.43986034], [74.38208008, 14.44181061], [74.38181305, 14.44181061], [74.38181305, 14.44237137], [74.38153076, 14.44237137], [74.38153076, 14.44291973], [74.38124847, 14.44291592], [74.38124847, 14.44347191], [74.38096619, 14.44347191], [74.38096619, 14.44403267], [74.38069153, 14.4440279], [74.38069153, 14.44458199], [74.38041687, 14.44458199], [74.38041687, 14.44569397], [74.38069153, 14.44569397], [74.38069153, 14.44708443], [74.38041687, 14.44707966], [74.38041687, 14.4479208], [74.38014221, 14.4479208], [74.38014221, 14.44874954], [74.37985992, 14.44874954], [74.37985992, 14.4495821], [74.3795929, 14.44958019], [74.3795929, 14.45014095], [74.37930298, 14.45013809], [74.37930298, 14.45097256], [74.37902832, 14.4509697], [74.37902832, 14.45181084], [74.37875366, 14.45180511], [74.37875366, 14.45236111], [74.37847137, 14.45236111], [74.37847137, 14.45319462], [74.37819672, 14.45318985], [74.37819672, 14.45403099], [74.37791443, 14.45402908], [74.37791443, 14.45458317], [74.37763977, 14.45458126], [74.37763977, 14.45514107], [74.37735748, 14.45513916], [74.37735748, 14.45569515], [74.37708282, 14.45569038], [74.37708282, 14.45625114], [74.37680817, 14.45625114], [74.37680817, 14.4568119], [74.37652588, 14.45680523], [74.37652588, 14.45736122], [74.37625122, 14.45734978], [74.37625122, 14.45875072], [74.37596893, 14.45874882], [74.37596893, 14.46069527], [74.37568665, 14.46069145], [74.37568665, 14.46152973], [74.37541962, 14.46152687], [74.37541962, 14.46208286], [74.37513733, 14.46208096], [74.37513733, 14.46292019], [74.37486267, 14.46292019], [74.37486267, 14.46375179], [74.37458038, 14.46374893], [74.37458038, 14.46458435], [74.37431335, 14.46458054], [74.37431335, 14.46541977], [74.37403107, 14.46541977], [74.37403107, 14.46654129], [74.37374878, 14.46652794], [74.37374878, 14.4673624], [74.37347412, 14.4673624], [74.37347412, 14.46819401], [74.37319183, 14.46818924], [74.37319183, 14.46903038], [74.37291718, 14.46903038], [74.37291718, 14.46986198], [74.37264252, 14.46986198], [74.37264252, 14.47042274], [74.37236023, 14.47041607], [74.37236023, 14.47097206], [74.3720932, 14.47097015], [74.3720932, 14.47152996], [74.37180328, 14.47152805], [74.37180328, 14.47236156], [74.37152863, 14.47235107], [74.37152863, 14.47292137], [74.37124634, 14.47291565], [74.37124634, 14.47347164], [74.37097168, 14.47346973], [74.37097168, 14.47403145], [74.37069702, 14.47402763], [74.37069702, 14.47486019], [74.3704071, 14.47486019], [74.3704071, 14.47542095], [74.37014008, 14.47541618], [74.37014008, 14.47597218], [74.36985779, 14.47597027], [74.36985779, 14.47681141], [74.36958313, 14.47681141], [74.36958313, 14.47735977], [74.36930847, 14.47735977], [74.36930847, 14.47792053], [74.36902618, 14.47792053], [74.36902618, 14.47848034], [74.36873627, 14.47848034], [74.36873627, 14.47931099], [74.36846924, 14.47930527], [74.36846924, 14.47986126], [74.36818695, 14.47986126], [74.36818695, 14.48042107], [74.36791992, 14.48041725], [74.36791992, 14.48097324], [74.36763763, 14.48097134], [74.36763763, 14.48181152], [74.36736298, 14.48181152], [74.36736298, 14.48236084], [74.36708069, 14.48236084], [74.36708069, 14.4829216], [74.36680603, 14.4829216], [74.36680603, 14.4837513], [74.36653137, 14.4837513], [74.36653137, 14.48431015], [74.36624908, 14.48431015], [74.36624908, 14.4851408], [74.36597443, 14.48513889], [74.36597443, 14.48569489], [74.36569977, 14.48569107], [74.36569977, 14.48625088], [74.36541748, 14.48624897], [74.36541748, 14.48708344], [74.36514282, 14.48708057], [74.36514282, 14.48763943], [74.36486053, 14.48763943], [74.36486053, 14.48847103], [74.36458588, 14.48847103], [74.36458588, 14.48903179], [74.36430359, 14.48902702], [74.36430359, 14.48958302], [74.36402893, 14.48958111], [74.36402893, 14.49042034], [74.36374664, 14.49041843], [74.36374664, 14.49097061], [74.36347198, 14.49097061], [74.36347198, 14.49180984], [74.36319733, 14.49180984], [74.36319733, 14.49236202], [74.36292267, 14.49236202], [74.36292267, 14.49291992], [74.36264038, 14.49291992], [74.36264038, 14.49374962], [74.36235809, 14.49374962], [74.36235809, 14.49431038], [74.36207581, 14.49431038], [74.36207581, 14.49514008], [74.36180878, 14.49514008], [74.36180878, 14.49597168], [74.36152649, 14.49597168], [74.36152649, 14.49652767], [74.36125183, 14.49652767], [74.36125183, 14.49736214], [74.36096954, 14.49736214], [74.36096954, 14.49819374], [74.36068726, 14.49819183], [74.36068726, 14.49903011], [74.36042023, 14.49903011], [74.36042023, 14.49986172], [74.36013794, 14.49986172], [74.36013794, 14.50042057], [74.35986328, 14.50042057], [74.35986328, 14.50125027], [74.35957336, 14.50125027], [74.35957336, 14.50181103], [74.35847473, 14.50180435], [74.35847473, 14.50208473], [74.3576355, 14.50208473], [74.3576355, 14.50180435], [74.35736084, 14.50181103], [74.35736084, 14.50125027], [74.35708618, 14.50125027], [74.35708618, 14.50097179], [74.35541534, 14.50097179], [74.35542297, 14.50125027], [74.35514069, 14.50125027], [74.35514069, 14.50153065], [74.3548584, 14.50153065], [74.3548584, 14.50181103], [74.35458374, 14.50180435], [74.35458374, 14.50208473], [74.35430908, 14.50208473], [74.35430908, 14.50236034], [74.35402679, 14.50236034], [74.35402679, 14.5029211], [74.35375977, 14.5029211], [74.35375977, 14.50375271], [74.35402679, 14.5037508], [74.35402679, 14.50458241], [74.35430908, 14.50457954], [74.35430908, 14.50486088], [74.35402679, 14.50486088], [74.35402679, 14.50708294], [74.35430908, 14.50708294], [74.35430908, 14.50736141], [74.3548584, 14.50736141], [74.3548584, 14.50819016], [74.35457611, 14.5082016], [74.35457611, 14.50875092], [74.35514069, 14.50875092], [74.35514069, 14.5090313], [74.35597229, 14.5090313], [74.35597229, 14.50931168], [74.35652924, 14.509305], [74.35652924, 14.50958347], [74.35708618, 14.50958061], [74.35708618, 14.50986099], [74.35764313, 14.50986099], [74.35764313, 14.51014137], [74.35819244, 14.51014137], [74.35819244, 14.51041889], [74.35930634, 14.51041698], [74.35930634, 14.51097298], [74.35902405, 14.51097298], [74.35902405, 14.51208305], [74.35874939, 14.51208305], [74.35874939, 14.51319313], [74.3584671, 14.51319122], [74.3584671, 14.51542187], [74.35874939, 14.5154171], [74.35874939, 14.51597118], [74.35901642, 14.51597118], [74.35901642, 14.51653194], [74.35930634, 14.51653194], [74.35930634, 14.51681042], [74.35957336, 14.51681042], [74.35957336, 14.51736164], [74.35986328, 14.51736164], [74.35986328, 14.5176506], [74.36013794, 14.51764011], [74.36013794, 14.51819324], [74.36042023, 14.51819134], [74.36042023, 14.51875019], [74.36068726, 14.51875019], [74.36068726, 14.51902962], [74.36125183, 14.51902962], [74.36125183, 14.51931], [74.36069489, 14.51930618], [74.36069489, 14.51986217], [74.36096954, 14.51986027], [74.36096954, 14.52013969], [74.36152649, 14.52013969], [74.36152649, 14.52042007], [74.36208344, 14.52041626], [74.36208344, 14.52069378], [74.36264038, 14.52069378], [74.36264038, 14.52097225], [74.36319733, 14.52096939], [74.36319733, 14.52124977], [74.36429596, 14.52124977], [74.36429596, 14.52153015], [74.36458588, 14.52152824], [74.36458588, 14.52208424], [74.36486053, 14.52208424], [74.36486053, 14.52235985], [74.36514282, 14.52235985], [74.36514282, 14.52264023], [74.36541748, 14.52264023], [74.36541748, 14.52291965], [74.36597443, 14.52291584], [74.36597443, 14.52319431], [74.36624908, 14.52319431], [74.36624908, 14.52347183], [74.36736298, 14.52346134], [74.36736298, 14.52402973], [74.36763763, 14.52402973], [74.36763763, 14.52431107], [74.36791992, 14.52431107], [74.36791992, 14.52514267], [74.36819458, 14.5251379], [74.36819458, 14.52569389], [74.36846924, 14.52569199], [74.36846924, 14.52625179], [74.36873627, 14.52625179], [74.36873627, 14.52682018], [74.36902618, 14.52682018], [74.36902618, 14.52735996], [74.36930847, 14.52735996], [74.36930847, 14.52764034], [74.37069702, 14.52764034], [74.37069702, 14.52792072], [74.37236023, 14.52792072], [74.37236023, 14.52764034], [74.37264252, 14.52764034], [74.37264252, 14.52735996], [74.37291718, 14.52735996], [74.37291718, 14.52707958], [74.37319183, 14.52708435], [74.37319183, 14.52680588], [74.37346649, 14.52682018], [74.37346649, 14.52653122], [74.37374878, 14.52653122], [74.37374878, 14.52597046], [74.37403107, 14.52597237], [74.37403107, 14.52569389], [74.37430573, 14.52569389], [74.37430573, 14.52541637], [74.37458038, 14.52542114], [74.37458038, 14.52486038], [74.37486267, 14.52486229], [74.37486267, 14.52458191], [74.37513733, 14.52458191], [74.37513733, 14.5243063], [74.37541962, 14.52431107], [74.37541962, 14.52375031], [74.37568665, 14.52375031], [74.37568665, 14.52346134], [74.37596893, 14.52347183], [74.37596893, 14.52291584], [74.37625122, 14.52291965], [74.37625122, 14.52235985], [74.37652588, 14.52235985], [74.37652588, 14.52264023], [74.37680817, 14.52264023], [74.37680817, 14.52291965], [74.37735748, 14.52291584], [74.37735748, 14.52319431], [74.37763977, 14.52319431], [74.37763977, 14.52347183], [74.3779068, 14.52346134], [74.3779068, 14.52375031], [74.37847137, 14.52375031], [74.37847137, 14.52402973], [74.37874603, 14.52402973], [74.37874603, 14.52431107], [74.37930298, 14.5243063], [74.37930298, 14.52458191], [74.3795929, 14.52458191], [74.3795929, 14.52542114], [74.37930298, 14.52541637], [74.37930298, 14.52597237], [74.37902832, 14.52597046], [74.37902832, 14.52625179], [74.37874603, 14.52625179], [74.37874603, 14.52682018], [74.37847137, 14.52680588], [74.37847137, 14.52708435], [74.37819672, 14.52707958], [74.37819672, 14.52764034], [74.37791443, 14.52764034], [74.37791443, 14.52819443], [74.37763977, 14.52818966], [74.37763977, 14.52875042], [74.37735748, 14.52875042], [74.37735748, 14.52985954], [74.37708282, 14.52985954], [74.37708282, 14.53097343], [74.37680817, 14.53096962], [74.37680817, 14.53153133], [74.37652588, 14.53152561], [74.37652588, 14.53208256], [74.37625122, 14.53208256], [74.37625122, 14.53263855], [74.37596893, 14.53263855], [74.37596893, 14.53319454], [74.37568665, 14.53318977], [74.37568665, 14.53375053], [74.37541962, 14.53375053], [74.37541962, 14.53430939], [74.37486267, 14.53430462], [74.37486267, 14.53458309], [74.37458038, 14.53458309], [74.37458038, 14.53486061], [74.37431335, 14.53486061], [74.37431335, 14.53542137], [74.37374878, 14.5354166], [74.37374878, 14.53569508], [74.37346649, 14.53569031], [74.37346649, 14.53625107], [74.37319183, 14.53625107], [74.37319183, 14.53708267], [74.37374878, 14.53708267], [74.37374878, 14.53736115], [74.37458038, 14.53736115], [74.37458038, 14.53680515], [74.37486267, 14.53681183], [74.37486267, 14.53625107], [74.37513733, 14.53625107], [74.37513733, 14.53569031], [74.37541962, 14.53569508], [74.37541962, 14.53513908], [74.37568665, 14.53514099], [74.37568665, 14.53458023], [74.37596893, 14.53458309], [74.37596893, 14.53402901], [74.37625122, 14.53403091], [74.37625122, 14.53375053], [74.37652588, 14.53375053], [74.37652588, 14.53347111], [74.37680817, 14.53347301], [74.37680817, 14.53319454], [74.37708282, 14.53319454], [74.37708282, 14.53291702], [74.37735748, 14.53292084], [74.37735748, 14.53263187], [74.37930298, 14.53263855], [74.37930298, 14.53236103], [74.3795929, 14.53236103], [74.37958527, 14.53180695], [74.37985992, 14.53181076], [74.37985992, 14.53153133], [74.38014221, 14.53153133], [74.38014221, 14.53125095], [74.38041687, 14.53125095], [74.38041687, 14.53069019], [74.38069153, 14.53069496], [74.38069153, 14.53041553], [74.38096619, 14.53042126], [74.38096619, 14.53014088], [74.38124847, 14.53014088], [74.38124847, 14.52959061], [74.38153076, 14.52959061], [74.38153076, 14.52931118], [74.38181305, 14.52931118], [74.38181305, 14.5290308], [74.38208008, 14.5290308], [74.38208008, 14.52847004], [74.38236237, 14.52847195], [74.38236237, 14.52819443], [74.38263702, 14.52819443], [74.38263702, 14.52763844], [74.38291931, 14.52764034], [74.38291931, 14.52707958], [74.38319397, 14.52708435], [74.38319397, 14.52624989], [74.38346863, 14.52625179], [74.38346863, 14.52569199], [74.38375092, 14.52569389], [74.38375092, 14.52486229], [74.38402557, 14.52486229], [74.38402557, 14.5243063], [74.38430786, 14.52431107], [74.38430786, 14.52375031], [74.38652802, 14.52375031], [74.38652802, 14.52479172], [74.38652802, 14.52875042], [74.38707733, 14.52875042], [74.38707733, 14.5290308], [74.38735962, 14.5290308], [74.38735962, 14.52931118], [74.38791656, 14.52931118], [74.38791656, 14.52959061], [74.38931274, 14.52959061], [74.38931274, 14.52931118], [74.39068604, 14.52931118], [74.39068604, 14.5290308], [74.39290619, 14.5290308], [74.39290619, 14.52931118], [74.39347076, 14.52931118], [74.39347076, 14.53042126], [74.39319611, 14.53042126], [74.39319611, 14.53125095], [74.39068604, 14.53125095], [74.39068604, 14.53153133], [74.39041901, 14.53152561], [74.39041901, 14.53208256], [74.39013672, 14.53208256], [74.39013672, 14.53263855], [74.38986206, 14.53263855], [74.38986206, 14.53319454], [74.38957977, 14.53318977], [74.38957977, 14.53375053], [74.38931274, 14.53375053], [74.38931274, 14.53403091], [74.38735962, 14.53403091], [74.38735962, 14.53375053], [74.38707733, 14.53375053], [74.38707733, 14.53318977], [74.38680267, 14.53319454], [74.38680267, 14.53291702], [74.38652802, 14.53292084], [74.38652802, 14.53236103], [74.38625336, 14.53236103], [74.38625336, 14.53181076], [74.38597107, 14.53181076], [74.38597107, 14.53153133], [74.38569641, 14.53153133], [74.38569641, 14.53096962], [74.38541412, 14.53097343], [74.38541412, 14.53069496], [74.3840332, 14.53069019], [74.3840332, 14.53125095], [74.38430786, 14.53125095], [74.38430786, 14.53181076], [74.38458252, 14.53181076], [74.38458252, 14.53236103], [74.38485718, 14.53236103], [74.38485718, 14.53292084], [74.38513947, 14.53291702], [74.38513947, 14.53347301], [74.38540649, 14.53347111], [74.38540649, 14.53430939], [74.38513947, 14.53430939], [74.38513947, 14.53514099], [74.38458252, 14.53514099], [74.38458252, 14.53542137], [74.38430786, 14.5354166], [74.38430786, 14.53569508], [74.38375092, 14.53569508], [74.38375092, 14.5359726], [74.38346863, 14.53597069], [74.38346863, 14.53625107], [74.38321686, 14.53625107], [74.38291931, 14.53625107], [74.38291931, 14.53708267], [74.38304901, 14.53708076], [74.38318634, 14.5370779], [74.38318634, 14.53876019], [74.38346863, 14.53876019], [74.38346863, 14.54041958], [74.38375092, 14.54041672], [74.38375092, 14.54347134], [74.38513947, 14.54347134], [74.38513947, 14.54375172], [74.38540649, 14.54375172], [74.38540649, 14.54403019], [74.38597107, 14.54403019], [74.38597107, 14.54430962], [74.38625336, 14.5443058], [74.38625336, 14.54458427], [74.38652802, 14.54456997], [74.38652802, 14.54486179], [74.38680267, 14.54486179], [74.38680267, 14.54514027], [74.38708496, 14.54514027], [74.38708496, 14.54569435], [74.38735962, 14.54569054], [74.38735962, 14.54681015], [74.38708496, 14.54680634], [74.38708496, 14.54708385], [74.38680267, 14.54708385], [74.38680267, 14.54736233], [74.38652802, 14.54736233], [74.38652802, 14.54763985], [74.38625336, 14.54763126], [74.38625336, 14.54792023], [74.38597107, 14.54791641], [74.38597107, 14.5484724], [74.38569641, 14.54846859], [74.38569641, 14.54874992], [74.38540649, 14.54874992], [74.38540649, 14.5490303], [74.38513947, 14.5490303], [74.38513947, 14.54930973], [74.38485718, 14.54930973], [74.38485718, 14.54986191], [74.38458252, 14.54986191], [74.38458252, 14.55014038], [74.38430786, 14.55014038], [74.38430786, 14.55041981], [74.3840332, 14.55041981], [74.3840332, 14.55070114], [74.38375092, 14.55069447], [74.38375092, 14.55097198], [74.38346863, 14.55097198], [74.38346863, 14.55153275], [74.38318634, 14.55153275], [74.38318634, 14.55181122], [74.38236237, 14.55181122], [74.38236237, 14.55125046], [74.38208008, 14.55125046], [74.38208008, 14.55097198], [74.38180542, 14.55097198], [74.38180542, 14.55041599], [74.38153076, 14.55041981], [74.38153076, 14.55014038], [74.38124847, 14.55014038], [74.38124847, 14.54986191], [74.38096619, 14.54986191], [74.38096619, 14.54930973], [74.3795929, 14.54930973], [74.3795929, 14.5490303], [74.37902832, 14.5490303], [74.37902832, 14.54874992], [74.37847137, 14.54874992], [74.37847137, 14.54846859], [74.3779068, 14.54846859], [74.3779068, 14.5490303], [74.37763977, 14.5490303], [74.37763977, 14.54930973], [74.37735748, 14.54930592], [74.37735748, 14.54958439], [74.37708282, 14.54957867], [74.37708282, 14.55014038], [74.37680817, 14.55014038], [74.37680817, 14.55041981], [74.37652588, 14.55041981], [74.37652588, 14.55070114], [74.37625122, 14.55070114], [74.37625122, 14.55125046], [74.37596893, 14.55125046], [74.37596893, 14.55153275], [74.37541962, 14.55153275], [74.37541962, 14.55181122], [74.37513733, 14.55180645], [74.37513733, 14.55208206], [74.37458038, 14.55208206], [74.37458038, 14.55236244], [74.37403107, 14.55235958], [74.37403107, 14.55263996], [74.37374878, 14.55263996], [74.37374878, 14.5529213], [74.37319183, 14.55291557], [74.37319183, 14.55319405], [74.37291718, 14.55319405], [74.37291718, 14.55347157], [74.37264252, 14.55346966], [74.37264252, 14.55376244], [74.37152863, 14.55376244], [74.37152863, 14.55346966], [74.37124634, 14.55347157], [74.37124634, 14.55319405], [74.37069702, 14.55319405], [74.37069702, 14.55291557], [74.37014008, 14.5529213], [74.37014008, 14.55263996], [74.36791992, 14.55263996], [74.36653137, 14.55263996], [74.36653137, 14.5529213], [74.36597443, 14.55291557], [74.36597443, 14.55319405], [74.36541748, 14.55319405], [74.36541748, 14.55347157], [74.36486053, 14.55346966], [74.36486053, 14.55376244], [74.36458588, 14.55376244], [74.36458588, 14.55403137], [74.36486053, 14.55402756], [74.36486053, 14.55458355], [74.36514282, 14.55457973], [74.36514282, 14.55514145], [74.36541748, 14.55514145], [74.36541748, 14.55542088], [74.36569214, 14.55541611], [74.36569214, 14.55569363], [74.36624908, 14.55569363], [74.36624908, 14.5559721], [74.36653137, 14.55597019], [74.36653137, 14.55624962], [74.36680603, 14.55624962], [74.36680603, 14.55653095], [74.36708069, 14.55652905], [74.36708069, 14.55680656], [74.36736298, 14.55680656], [74.36736298, 14.55708218], [74.36763763, 14.55708027], [74.36763763, 14.5573597], [74.36818695, 14.5573597], [74.36818695, 14.55764103], [74.36846924, 14.55764103], [74.36846924, 14.55792141], [74.36875153, 14.55791664], [74.36875153, 14.55847263], [74.36902618, 14.55846977], [74.36902618, 14.55931091], [74.36930847, 14.55931091], [74.36930847, 14.56014061], [74.36958313, 14.5601387], [74.36958313, 14.56097317], [74.36985779, 14.56097126], [74.36985779, 14.5618124], [74.37014008, 14.5618124], [74.37014008, 14.56236076], [74.3704071, 14.56236076], [74.3704071, 14.56264114], [74.37097168, 14.56264114], [74.37097168, 14.56293106], [74.37124634, 14.56291676], [74.37124634, 14.56319523], [74.37152863, 14.56319046], [74.37152863, 14.56347084], [74.37180328, 14.56347084], [74.37180328, 14.56375122], [74.37236023, 14.56375122], [74.37236023, 14.56403065], [74.37264252, 14.56403065], [74.37264252, 14.56431198], [74.37346649, 14.56431198], [74.37346649, 14.56403065], [74.37403107, 14.56403065], [74.37403107, 14.56375122], [74.37486267, 14.56375122], [74.37486267, 14.56347084], [74.37596893, 14.56347084], [74.37596893, 14.56375122], [74.37625122, 14.56375122], [74.37625122, 14.56431198], [74.37569427, 14.56430531], [74.37569427, 14.56458282], [74.37513733, 14.56458282], [74.37513733, 14.5648613], [74.37458038, 14.5648613], [74.37458038, 14.56514072], [74.37486267, 14.56514072], [74.37486267, 14.56569958], [74.37513733, 14.56569958], [74.37513733, 14.56652927], [74.37541962, 14.56652927], [74.37541962, 14.56763935], [74.37569427, 14.56763935], [74.37569427, 14.56819534], [74.37596893, 14.56819534], [74.37596893, 14.56874943], [74.37625122, 14.56874943], [74.37625122, 14.57097054], [74.37763977, 14.57097054], [74.37763977, 14.57236195], [74.37735748, 14.57236195], [74.37735748, 14.57264042], [74.37708282, 14.57264042], [74.37708282, 14.57291985], [74.37652588, 14.57291794], [74.37652588, 14.57319355], [74.37625122, 14.57319355], [74.37625122, 14.57347202], [74.37596893, 14.57347202], [74.37596893, 14.57374954], [74.37374878, 14.57374954], [74.37374878, 14.57347202], [74.37152863, 14.57347202], [74.37152863, 14.57319355], [74.37124634, 14.57319355], [74.37124634, 14.57291794], [74.37097168, 14.57291985], [74.37097168, 14.57236195], [74.37069702, 14.57236195], [74.37069702, 14.57208061], [74.37041473, 14.57208443], [74.37041473, 14.57180595], [74.37014008, 14.57180595], [74.37014008, 14.57152843], [74.36985779, 14.57153034], [74.36985779, 14.57097054], [74.36958313, 14.57097054], [74.36958313, 14.57069588], [74.36930847, 14.57069111], [74.36930847, 14.57041836], [74.36902618, 14.57042027], [74.36902618, 14.57014179], [74.36873627, 14.57014179], [74.36873627, 14.56958103], [74.36846924, 14.56958294], [74.36846924, 14.56930542], [74.36818695, 14.56931019], [74.36818695, 14.56903172], [74.36736298, 14.56903172], [74.36736298, 14.5687418], [74.36653137, 14.56874943], [74.36653137, 14.56847095], [74.36569214, 14.56847095], [74.36569214, 14.56791687], [74.3659668, 14.56791973], [74.3659668, 14.56763935], [74.36569977, 14.56763935], [74.36569977, 14.56736088], [74.36541748, 14.56736088], [74.36541748, 14.56680965], [74.36514282, 14.56680965], [74.36514282, 14.56652927], [74.36486053, 14.56652927], [74.36486053, 14.5662508], [74.36068726, 14.5662508], [74.36068726, 14.56597137], [74.36042023, 14.56597328], [74.36042023, 14.56569481], [74.36013794, 14.56569958], [74.36013794, 14.5654192], [74.35986328, 14.5654192], [74.35986328, 14.56514072], [74.35957336, 14.56514072], [74.35957336, 14.5648613], [74.35930634, 14.5648613], [74.35930634, 14.56430531], [74.35901642, 14.56431198], [74.35901642, 14.56403065], [74.35874939, 14.56403065], [74.35874939, 14.56375122], [74.3584671, 14.56375122], [74.3584671, 14.56347084], [74.35819244, 14.56347084], [74.35819244, 14.56319046], [74.35791779, 14.56319523], [74.35791779, 14.56291676], [74.35736084, 14.56293106], [74.35736084, 14.56264114], [74.35652924, 14.56264114], [74.35652924, 14.56208038], [74.35680389, 14.56208324], [74.35680389, 14.56152916], [74.35708618, 14.56153107], [74.35708618, 14.56097126], [74.35736084, 14.56097317], [74.35736084, 14.56041718], [74.35764313, 14.56042099], [74.35764313, 14.55986118], [74.35791779, 14.55986118], [74.35791779, 14.55930519], [74.35819244, 14.55931091], [74.35819244, 14.55875111], [74.3584671, 14.55875111], [74.3584671, 14.55819035], [74.35874939, 14.55819511], [74.35874939, 14.55763817], [74.35901642, 14.55764103], [74.35901642, 14.55708027], [74.35930634, 14.55708218], [74.35930634, 14.55652905], [74.35957336, 14.55653095], [74.35957336, 14.55597019], [74.35986328, 14.5559721], [74.35986328, 14.55319405], [74.35958099, 14.55319405], [74.35958099, 14.55180645], [74.35986328, 14.55181122], [74.35986328, 14.55070114], [74.36013794, 14.55070114], [74.36013794, 14.55041981], [74.36042023, 14.55041981], [74.36042023, 14.55014038], [74.36013794, 14.55014038], [74.36013794, 14.54957867], [74.35986328, 14.54958439], [74.35986328, 14.5490284], [74.35957336, 14.5490303], [74.35957336, 14.54846859], [74.35930634, 14.5484724], [74.35930634, 14.54791641], [74.35901642, 14.54792023], [74.35901642, 14.54736042], [74.35874939, 14.54736233], [74.35874939, 14.54680634], [74.3584671, 14.54681015], [74.3584671, 14.54625034], [74.35819244, 14.54625034], [74.35819244, 14.54597187], [74.3576355, 14.54597187], [74.3576355, 14.54569435], [74.35708618, 14.54569435], [74.35708618, 14.54541779], [74.35652924, 14.54541969], [74.35652924, 14.54514027], [74.35597229, 14.54514027], [74.35597229, 14.54486179], [74.35542297, 14.54486179], [74.35542297, 14.54456997], [74.35514069, 14.54458427], [74.35514069, 14.5443058], [74.3548584, 14.54430962], [74.3548584, 14.54375172], [74.35457611, 14.54375172], [74.35457611, 14.54347134], [74.35430908, 14.54347134], [74.35430908, 14.54291534], [74.35402679, 14.54291534], [74.35402679, 14.54319572], [74.35346985, 14.54319572], [74.35346985, 14.54347134], [74.3529129, 14.54347134], [74.3529129, 14.54375172], [74.35235596, 14.54375172], [74.35235596, 14.54403019], [74.35180664, 14.54403019], [74.35180664, 14.54430962], [74.35124969, 14.5443058], [74.35124969, 14.54458427], [74.35070038, 14.54456997], [74.35070038, 14.54486179], [74.3501358, 14.54486179], [74.3501358, 14.54514027], [74.34958649, 14.54514027], [74.34958649, 14.54625034], [74.34929657, 14.54625034], [74.34929657, 14.54681015], [74.34902954, 14.54680634], [74.34902954, 14.54736233], [74.34874725, 14.54736042], [74.34874725, 14.54792023], [74.3484726, 14.54791641], [74.3484726, 14.5484724], [74.34819794, 14.54846859], [74.34819794, 14.5490303], [74.34791565, 14.5490284], [74.34791565, 14.54958439], [74.34763336, 14.54957867], [74.34763336, 14.54986191], [74.3473587, 14.54986191], [74.3473587, 14.55041981], [74.34708405, 14.55041599], [74.34708405, 14.55097198], [74.34680939, 14.55097198], [74.34680176, 14.55153275], [74.3465271, 14.55152798], [74.3465271, 14.55208206], [74.34625244, 14.55208015], [74.34625244, 14.55263996], [74.34597015, 14.55263805], [74.34597015, 14.55319405], [74.34570313, 14.55319023], [74.34570313, 14.5543108], [74.34541321, 14.5543108], [74.34541321, 14.55653095], [74.34513855, 14.55653095], [74.34513855, 14.55792141], [74.34541321, 14.55791664], [74.34541321, 14.55819511], [74.3456955, 14.55819511], [74.3456955, 14.55875111], [74.34597015, 14.55875111], [74.34597015, 14.55903053], [74.34625244, 14.55903053], [74.34625244, 14.55931091], [74.3465271, 14.55930519], [74.3465271, 14.55986118], [74.34680176, 14.55986118], [74.34680176, 14.56069469], [74.3465271, 14.56069469], [74.3465271, 14.56097317], [74.34597015, 14.56097126], [74.34597015, 14.56125069], [74.34570313, 14.56125069], [74.34570313, 14.56153107], [74.34513855, 14.56153107], [74.34513855, 14.5618124], [74.34486389, 14.56180477], [74.34486389, 14.56208324], [74.34430695, 14.56208038], [74.34430695, 14.56236076], [74.34401703, 14.56236076], [74.34401703, 14.56264114], [74.34375, 14.56264114], [74.34375, 14.56293106], [74.34319305, 14.56291676], [74.34319305, 14.56319523], [74.3429184, 14.56319046], [74.3429184, 14.56347084], [74.34236145, 14.56347084], [74.34236145, 14.56375122], [74.34208679, 14.56375122], [74.34208679, 14.56431198], [74.34179688, 14.56431198], [74.34179688, 14.56514072], [74.34152985, 14.56513882], [74.34152985, 14.56597328], [74.34124756, 14.56597137], [74.34124756, 14.56652927], [74.3409729, 14.56652927], [74.3409729, 14.56736088], [74.34069824, 14.56736088], [74.34069824, 14.56819534], [74.34041595, 14.56819534], [74.34041595, 14.56874943], [74.3373642, 14.56874943], [74.3373642, 14.56819534], [74.33708191, 14.56819534], [74.33708191, 14.56763935], [74.33680725, 14.56763935], [74.33680725, 14.56708145], [74.33652496, 14.56708336], [74.33652496, 14.56652737], [74.33625031, 14.56652927], [74.33625031, 14.56597137], [74.33597565, 14.56597328], [74.33597565, 14.56541729], [74.33569336, 14.5654192], [74.33569336, 14.5648613], [74.3354187, 14.5648613], [74.3354187, 14.56375122], [74.33513641, 14.56375122], [74.33513641, 14.56264114], [74.3354187, 14.56264114], [74.3354187, 14.56208038], [74.33569336, 14.56208324], [74.33569336, 14.56180477], [74.33598328, 14.5618124], [74.33598328, 14.56125069], [74.33625031, 14.56125069], [74.33625031, 14.56068993], [74.33652496, 14.56069469], [74.33652496, 14.56041718], [74.33680725, 14.56042099], [74.33680725, 14.55986118], [74.33708191, 14.55986118], [74.33708191, 14.55958271], [74.3373642, 14.55958271], [74.3373642, 14.55902863], [74.33763885, 14.55903053], [74.33763885, 14.55846977], [74.33791351, 14.55847263], [74.33791351, 14.55819511], [74.3381958, 14.55819511], [74.3381958, 14.55763817], [74.33847046, 14.55764103], [74.33847046, 14.5568018], [74.33875275, 14.55680656], [74.33875275, 14.55541611], [74.3390274, 14.55542088], [74.3390274, 14.55457973], [74.33875275, 14.55458355], [74.33875275, 14.55402756], [74.33847046, 14.55403137], [74.33847046, 14.55376244], [74.3381958, 14.55376244], [74.3381958, 14.55346966], [74.33847046, 14.55347157], [74.33847046, 14.55319405], [74.33875275, 14.55319405], [74.33875275, 14.55291557], [74.33930206, 14.5529213], [74.33930206, 14.55263996], [74.33957672, 14.55263996], [74.33957672, 14.55235958], [74.3401413, 14.55236244], [74.3401413, 14.55208206], [74.34041595, 14.55208206], [74.34041595, 14.55180645], [74.3409729, 14.55181122], [74.3409729, 14.55153275], [74.34124756, 14.55153275], [74.34124756, 14.55125046], [74.34152985, 14.55125046], [74.34152985, 14.55097198], [74.3418045, 14.55097198], [74.3418045, 14.55041599], [74.34208679, 14.55041981], [74.34208679, 14.55014038], [74.34236145, 14.55014038], [74.34236145, 14.54986191], [74.34263611, 14.54986191], [74.34263611, 14.54957867], [74.3429184, 14.54958439], [74.3429184, 14.54930592], [74.34319305, 14.54930973], [74.34319305, 14.54874992], [74.34348297, 14.54874992], [74.34348297, 14.54846859], [74.34375, 14.5484724], [74.34375, 14.54819584], [74.34402466, 14.54819584], [74.34402466, 14.54763985], [74.34430695, 14.54763985], [74.34430695, 14.54736233], [74.3445816, 14.54736233], [74.3445816, 14.54708385], [74.34486389, 14.54708385], [74.34486389, 14.54652786], [74.34513855, 14.54652977], [74.34513855, 14.54625034], [74.34541321, 14.54625034], [74.34541321, 14.54597187], [74.3456955, 14.54597187], [74.3456955, 14.54541779], [74.34625244, 14.54541969], [74.34625244, 14.54681015], [74.3465271, 14.54680634], [74.3465271, 14.54708385], [74.34680176, 14.54708385], [74.34680939, 14.54736233], [74.3473587, 14.54736233], [74.3473587, 14.54763985], [74.34791565, 14.54763985], [74.34791565, 14.54652786], [74.34819794, 14.54652977], [74.34819794, 14.54625034], [74.34707642, 14.54625034], [74.34707642, 14.54486179], [74.3473587, 14.54486179], [74.3473587, 14.54403019], [74.34986115, 14.54403019], [74.34986115, 14.54347134], [74.3501358, 14.54347134], [74.3501358, 14.54236126], [74.35041809, 14.54236126], [74.35041809, 14.54180527], [74.35098267, 14.54182053], [74.35098267, 14.54152966], [74.35151672, 14.54152966], [74.35151672, 14.54124928], [74.3520813, 14.54124928], [74.3520813, 14.54096889], [74.35263824, 14.5409708], [74.35263824, 14.54069519], [74.35236359, 14.54069519], [74.35236359, 14.5401392], [74.3520813, 14.5401392], [74.3520813, 14.53986073], [74.35180664, 14.53986073], [74.35180664, 14.53931046], [74.35151672, 14.53931046], [74.35151672, 14.53876019], [74.35180664, 14.53876019], [74.35180664, 14.53792191], [74.3520813, 14.53792191], [74.3520813, 14.53764057], [74.35180664, 14.53764057], [74.35180664, 14.53736115], [74.35152435, 14.53736115], [74.35152435, 14.53625107], [74.35124969, 14.53625107], [74.35124969, 14.53347111], [74.35152435, 14.53347301], [74.35152435, 14.53291702], [74.35180664, 14.53292084], [74.35180664, 14.5320797], [74.35236359, 14.53208256], [74.35236359, 14.53152561], [74.3529129, 14.53153133], [74.3529129, 14.53125095], [74.35320282, 14.53125095], [74.35320282, 14.53069019], [74.35346985, 14.53069496], [74.35346985, 14.53013802], [74.35375977, 14.53014088], [74.35375977, 14.52959061], [74.35402679, 14.52959061], [74.35402679, 14.5290308], [74.35430908, 14.5290308], [74.35430908, 14.52847004], [74.35458374, 14.52847195], [74.35458374, 14.52819443], [74.3548584, 14.52819443], [74.3548584, 14.52763844], [74.35514069, 14.52764034], [74.35514069, 14.52682018], [74.35542297, 14.52682018], [74.35542297, 14.52625179], [74.35569763, 14.52625179], [74.35569763, 14.52514267], [74.35597229, 14.52514267], [74.35597229, 14.52402973], [74.35624695, 14.52402973], [74.35624695, 14.52291965], [74.35597229, 14.52291965], [74.35597229, 14.52207947], [74.35541534, 14.52208424], [74.35541534, 14.52180576], [74.35457611, 14.52180958], [74.35457611, 14.52153015], [74.35402679, 14.52153015], [74.35402679, 14.52124977], [74.34986115, 14.52124977], [74.34986115, 14.52153015], [74.34958649, 14.52153015], [74.34958649, 14.52124977], [74.34929657, 14.52124977], [74.34929657, 14.52069092], [74.34902954, 14.52069378], [74.34902954, 14.52041626], [74.34513855, 14.52042007], [74.34513855, 14.52013969], [74.34485626, 14.52013969], [74.34485626, 14.51986027], [74.3445816, 14.51986217], [74.3445816, 14.5195837], [74.34430695, 14.5195837], [74.34430695, 14.51875019], [74.34401703, 14.51875019], [74.34401703, 14.5176506], [74.34375, 14.5176506], [74.34375, 14.51736164], [74.34347534, 14.51736164], [74.34347534, 14.51708412], [74.34319305, 14.51708412], [74.34319305, 14.51652718], [74.3429184, 14.51653194], [74.3429184, 14.51597118], [74.34263611, 14.51597118], [74.34263611, 14.5154171], [74.34236145, 14.51542187], [74.34236145, 14.5148592], [74.34208679, 14.51486111], [74.34208679, 14.51430511], [74.34179688, 14.51431179], [74.34179688, 14.51402855], [74.34124756, 14.51402855], [74.34124756, 14.51375103], [74.33985901, 14.51375103], [74.33985901, 14.51402855], [74.33957672, 14.51402855], [74.33957672, 14.51431179], [74.33930206, 14.51431179], [74.33930206, 14.51459026], [74.3390274, 14.51458263], [74.3390274, 14.51486111], [74.33876038, 14.5148592], [74.33876038, 14.51513863], [74.33847046, 14.51513863], [74.33847046, 14.51542187], [74.3381958, 14.5154171], [74.3381958, 14.51569557], [74.33791351, 14.51569557], [74.33791351, 14.51708412], [74.3381958, 14.51708126], [74.3381958, 14.51736164], [74.33763885, 14.51736164], [74.33763885, 14.5176506], [74.33735657, 14.5176506], [74.33735657, 14.51791954], [74.33319092, 14.51791954], [74.33319092, 14.51736164], [74.33291626, 14.51736164], [74.33291626, 14.51708126], [74.33235931, 14.51708126], [74.33235931, 14.51736164], [74.33180237, 14.51736164], [74.33180237, 14.5176506], [74.33013916, 14.5176506], [74.33013916, 14.51625156], [74.32785034, 14.5162487], [74.32763672, 14.51625156], [74.32763672, 14.51597118], [74.32736206, 14.51597118], [74.32736206, 14.51569557], [74.32707977, 14.51569557], [74.32707977, 14.5154171], [74.32682037, 14.51542187], [74.32682037, 14.51513863], [74.32653046, 14.51513863], [74.32653046, 14.5148592], [74.32624817, 14.51486111], [74.32624817, 14.51458263], [74.32597351, 14.51458263], [74.32597351, 14.51486111], [74.32569122, 14.51486111], [74.32569122, 14.51693058], [74.32569122, 14.5176506], [74.32541656, 14.5176506], [74.32541656, 14.51875019], [74.32514191, 14.51875019], [74.32514191, 14.5195837], [74.32291412, 14.5195837], [74.32291412, 14.51736164], [74.32180786, 14.51736164], [74.32180786, 14.51791954], [74.32208252, 14.51791954], [74.32208252, 14.51875019], [74.32180786, 14.51875019], [74.32180786, 14.51931], [74.32152557, 14.51930618], [74.32152557, 14.5195837], [74.31874847, 14.5195837], [74.31874847, 14.51902771], [74.31846619, 14.51902962], [74.31846619, 14.51847172], [74.31874847, 14.51847172], [74.31874847, 14.51819324], [74.31903076, 14.51819324], [74.31903076, 14.51791763], [74.31931305, 14.51791954], [74.31931305, 14.51708126], [74.31903076, 14.51708412], [74.31903076, 14.5162487], [74.31874847, 14.51625156], [74.31874847, 14.51681042], [74.31846619, 14.51681042], [74.31846619, 14.5176506], [74.31819153, 14.51764011], [74.31819153, 14.51847363], [74.31791687, 14.51847172], [74.31791687, 14.51902962], [74.31624603, 14.51902962], [74.31624603, 14.51931], [74.31597137, 14.51930618], [74.31597137, 14.5195837], [74.31569672, 14.5195837], [74.31569672, 14.51986217], [74.3154068, 14.51986027], [74.3154068, 14.52013969], [74.31513977, 14.52013969], [74.31513977, 14.52042007], [74.31485748, 14.52041626], [74.31485748, 14.52069092], [74.31430817, 14.52069378], [74.31430817, 14.52097225], [74.31402588, 14.52096939], [74.31402588, 14.52124977], [74.31208038, 14.52124977], [74.31208038, 14.52096939], [74.31041718, 14.52097225], [74.31041718, 14.52069378], [74.3095932, 14.52069092], [74.3095932, 14.52124977], [74.30986023, 14.52124977], [74.30986023, 14.52208424], [74.31014252, 14.52207947], [74.31014252, 14.52264023], [74.31041718, 14.52264023], [74.31041718, 14.52319431], [74.31014252, 14.52319241], [74.31014252, 14.52375031], [74.31041718, 14.52375031], [74.31041718, 14.52402973], [74.31069183, 14.52402782], [74.31069183, 14.52458191], [74.31097412, 14.52458191], [74.31097412, 14.52486229], [74.31151581, 14.52486038], [74.31151581, 14.52514267], [74.31236267, 14.52514267], [74.31236267, 14.52542114], [74.31291962, 14.52541637], [74.31291962, 14.52569389], [74.31458282, 14.52569389], [74.31458282, 14.52597237], [74.31485748, 14.52597046], [74.31485748, 14.52625179], [74.31513977, 14.52625179], [74.31513977, 14.52682018], [74.3154068, 14.52682018], [74.3154068, 14.52735996], [74.31569672, 14.52735996], [74.31569672, 14.52875042], [74.31541443, 14.52875042], [74.31539917, 14.53040123], [74.31485748, 14.53041553], [74.31485748, 14.53069496], [74.31430817, 14.53069496], [74.31430817, 14.53097343], [74.31318665, 14.53096962], [74.31318665, 14.53125095], [74.31236267, 14.53125095], [74.31236267, 14.53153133], [74.31181335, 14.53153133], [74.31181335, 14.53181076], [74.31153107, 14.53180695], [74.31153107, 14.53208256], [74.31097412, 14.53208256], [74.31097412, 14.53347301], [74.31069183, 14.53347111], [74.31069183, 14.53625107], [74.31041718, 14.53625107], [74.31041718, 14.53764057], [74.31014252, 14.53763866], [74.31014252, 14.53819466], [74.30986023, 14.53819275], [74.30986023, 14.53876019], [74.31014252, 14.53876019], [74.31014252, 14.53903198], [74.31041718, 14.53903198], [74.31041718, 14.53931046], [74.31069183, 14.53930473], [74.31069183, 14.53958321], [74.31124878, 14.5395813], [74.31124878, 14.53986073], [74.31181335, 14.53986073], [74.31181335, 14.5401392], [74.31375122, 14.5401392], [74.31375122, 14.54041958], [74.31402588, 14.54041672], [74.31402588, 14.54236126], [74.31375122, 14.54236126], [74.31375122, 14.54458427], [74.31346893, 14.54456997], [74.31346893, 14.54541969], [74.31318665, 14.54541969], [74.31318665, 14.54625034], [74.31291962, 14.54625034], [74.31291962, 14.54708385], [74.31263733, 14.54708385], [74.31263733, 14.54763985], [74.31236267, 14.54763985], [74.31236267, 14.5484724], [74.31208038, 14.54846859], [74.31208038, 14.54930973], [74.31181335, 14.54930973], [74.31181335, 14.55014038], [74.31153107, 14.55013847], [74.31153107, 14.55097198], [74.31124878, 14.55097198], [74.31124878, 14.55181122], [74.31097412, 14.55180645], [74.31097412, 14.55236244], [74.31069183, 14.55235958], [74.31069183, 14.5529213], [74.31041718, 14.55291557], [74.31041718, 14.55347157], [74.31014252, 14.55346966], [74.31014252, 14.55403137], [74.30986023, 14.55402756], [74.30986023, 14.55458355], [74.3095932, 14.55457973], [74.3095932, 14.55514145], [74.30930328, 14.55513763], [74.30930328, 14.5559721], [74.30902863, 14.55597019], [74.30902863, 14.55653095], [74.30874634, 14.55652905], [74.30874634, 14.55708218], [74.30845642, 14.55708027], [74.30845642, 14.55764103], [74.30819702, 14.55763817], [74.30819702, 14.55819511], [74.3079071, 14.55819035], [74.3079071, 14.55875111], [74.30764008, 14.55875111], [74.30764008, 14.55931091], [74.30735779, 14.55931091], [74.30735779, 14.56014061], [74.30708313, 14.5601387], [74.30708313, 14.56069469], [74.30680847, 14.56068993], [74.30680847, 14.56125069], [74.30652618, 14.56125069], [74.30652618, 14.5618124], [74.30625153, 14.5618124], [74.30625153, 14.56264114], [74.30596924, 14.56263924], [74.30596924, 14.56319523], [74.30568695, 14.56319046], [74.30568695, 14.56375122], [74.30541992, 14.56375122], [74.30541992, 14.56431198], [74.30513763, 14.56431198], [74.30513763, 14.56514072], [74.30486298, 14.56514072], [74.30486298, 14.56569958], [74.30458069, 14.56569958], [74.30458069, 14.5662508], [74.30430603, 14.5662508], [74.30430603, 14.56680965], [74.30403137, 14.56680965], [74.30403137, 14.56736088], [74.30374908, 14.56736088], [74.30374908, 14.56819534], [74.30347443, 14.56819534], [74.30347443, 14.56874943], [74.30319214, 14.5687418], [74.30319214, 14.56931019], [74.30291748, 14.56930542], [74.30291748, 14.56986141], [74.30263519, 14.56986141], [74.30265045, 14.57069111], [74.30236053, 14.57069969], [74.30236053, 14.57125187], [74.30208588, 14.57124901], [74.30208588, 14.57208443], [74.30179596, 14.57208061], [74.30179596, 14.57236195], [74.30152893, 14.57236195], [74.30152893, 14.57347202], [74.30124664, 14.57347202], [74.30124664, 14.57374954], [74.30097198, 14.57374954], [74.30097198, 14.5743103], [74.30069733, 14.5743103], [74.30069733, 14.57487106], [74.30041504, 14.57486153], [74.30041504, 14.57708359], [74.30014038, 14.57708168], [74.30014038, 14.57763958], [74.29985809, 14.57763767], [74.29985809, 14.57819366], [74.29957581, 14.5781889], [74.29957581, 14.57874966], [74.29930878, 14.57874966], [74.29930878, 14.57958412], [74.29902649, 14.57958031], [74.29902649, 14.58014011], [74.29875183, 14.58013821], [74.29875183, 14.5806942], [74.29846954, 14.58068085], [74.29846954, 14.58125019], [74.29818726, 14.58125019], [74.29818726, 14.58181095], [74.29792023, 14.58180428], [74.29792023, 14.58236027], [74.29763794, 14.58236027], [74.29763794, 14.58292103], [74.29736328, 14.58291626], [74.29736328, 14.58347225], [74.29708099, 14.58347034], [74.29708099, 14.58403111], [74.29680634, 14.5840292], [74.29680634, 14.58458233], [74.29651642, 14.58458042], [74.29651642, 14.58514118], [74.29624939, 14.58513927], [74.29624939, 14.58569527], [74.2959671, 14.58568954], [74.2959671, 14.58625126], [74.29569244, 14.58625126], [74.29569244, 14.58681107], [74.29541779, 14.58680534], [74.29541779, 14.58736134], [74.29514313, 14.58736134], [74.29514313, 14.58791924], [74.29486084, 14.58791733], [74.29486084, 14.58847332], [74.29458618, 14.58847141], [74.29458618, 14.58903122], [74.29429626, 14.58903122], [74.29429626, 14.58987045], [74.29402924, 14.58987045], [74.29402924, 14.59042168], [74.29374695, 14.59042168], [74.29374695, 14.59125137], [74.29347992, 14.59125137], [74.29347992, 14.59181023], [74.29319763, 14.59180546], [74.29319763, 14.59236145], [74.29292297, 14.59236145], [74.29292297, 14.59293079], [74.2923584, 14.59291744], [74.2923584, 14.59347343], [74.29207611, 14.59347057], [74.29207611, 14.59402943], [74.29180908, 14.59402657], [74.29180908, 14.59458256], [74.29152679, 14.59458065], [74.29152679, 14.59486103], [74.29125214, 14.59486103], [74.29125214, 14.59542179], [74.29096985, 14.59541702], [74.29096985, 14.59597111], [74.29069519, 14.59597111], [74.29069519, 14.59708309], [74.29096985, 14.59708118], [74.29096985, 14.59792042], [74.29292297, 14.59792042], [74.29292297, 14.59764194], [74.29347992, 14.59764194], [74.29347992, 14.59736156], [74.29402924, 14.59736156], [74.29402924, 14.59708118], [74.29486084, 14.59708309], [74.29486084, 14.59736156], [74.29458618, 14.59736156], [74.29458618, 14.60060024], [74.29458618, 14.60153008], [74.29319763, 14.60153008], [74.29319763, 14.60181046], [74.29180908, 14.60180569], [74.29180908, 14.60208416], [74.29125214, 14.60207939], [74.29125214, 14.60235977], [74.29096985, 14.60235977], [74.29096985, 14.60264015], [74.29042053, 14.60264015], [74.29042053, 14.60291958], [74.28986359, 14.60291576], [74.28986359, 14.60319424], [74.2895813, 14.60319424], [74.2895813, 14.60347176], [74.28901672, 14.60346985], [74.28902435, 14.60375023], [74.28848267, 14.60375023], [74.28848267, 14.60402966], [74.28819275, 14.60402966], [74.28819275, 14.60431099], [74.2876358, 14.60430622], [74.2876358, 14.60458374], [74.28736115, 14.60458183], [74.28736115, 14.6048708], [74.28679657, 14.6048708], [74.28679657, 14.60513973], [74.28652954, 14.60513973], [74.28652954, 14.60542107], [74.28624725, 14.6054163], [74.28624725, 14.60569382], [74.28569794, 14.60569382], [74.28569794, 14.60597229], [74.28542328, 14.60597038], [74.28542328, 14.60625172], [74.2848587, 14.60625172], [74.2848587, 14.60653019], [74.28457642, 14.60653019], [74.28457642, 14.60681057], [74.28430939, 14.6068058], [74.28430176, 14.60708427], [74.28375244, 14.60708046], [74.28375244, 14.60736179], [74.28347015, 14.60736179], [74.28347015, 14.60764027], [74.2831955, 14.60764027], [74.2831955, 14.60791588], [74.28263855, 14.60791588], [74.28263855, 14.60819435], [74.28236389, 14.60819435], [74.28236389, 14.60847187], [74.2820816, 14.60846996], [74.2820816, 14.60875034], [74.28180695, 14.60875034], [74.28180695, 14.60903072], [74.28151703, 14.60903072], [74.28151703, 14.6093111], [74.28097534, 14.60930634], [74.28097534, 14.60958195], [74.28069305, 14.60958195], [74.28069305, 14.60986042], [74.2804184, 14.60986042], [74.2804184, 14.6101408], [74.28013611, 14.6101408], [74.28013611, 14.61042118], [74.27986145, 14.61041641], [74.27986145, 14.61097336], [74.27958679, 14.61096954], [74.27958679, 14.61181068], [74.27929688, 14.61181068], [74.27929688, 14.61292076], [74.27902985, 14.61292076], [74.27902985, 14.61375141], [74.27874756, 14.61375141], [74.27874756, 14.61681175], [74.2784729, 14.61680698], [74.27848053, 14.61736107], [74.27819824, 14.61736107], [74.27819824, 14.61792183], [74.27791595, 14.61792183], [74.27791595, 14.61875057], [74.2776413, 14.61875057], [74.2776413, 14.61931038], [74.27735901, 14.61931038], [74.27735901, 14.62014103], [74.27708435, 14.62013912], [74.27708435, 14.62069321], [74.27680206, 14.6206913], [74.27680206, 14.6212492], [74.27625275, 14.6212492], [74.27625275, 14.62152863], [74.27597046, 14.62152672], [74.27597046, 14.62236118], [74.2756958, 14.62236118], [74.2756958, 14.62291527], [74.27542114, 14.62291145], [74.27542114, 14.62375164], [74.27513885, 14.62375164], [74.27513885, 14.62403202], [74.27485657, 14.62403202], [74.27485657, 14.62430954], [74.27458191, 14.62430477], [74.27458191, 14.6245842], [74.27401733, 14.62458134], [74.27401733, 14.62486172], [74.27375031, 14.62486172], [74.27375031, 14.62652969], [74.27347565, 14.62652779], [74.27347565, 14.62708378], [74.27263641, 14.62708378], [74.27263641, 14.62680626], [74.27179718, 14.62681007], [74.27179718, 14.62652969], [74.27153015, 14.62652969], [74.27153015, 14.62625027], [74.27041626, 14.62625027], [74.27041626, 14.62652969], [74.26985931, 14.62652969], [74.26985931, 14.62681007], [74.26957703, 14.62681007], [74.26957703, 14.62874985], [74.26985931, 14.62874985], [74.26985931, 14.62904167], [74.2701416, 14.62902832], [74.2701416, 14.62958431], [74.27069092, 14.62957859], [74.27069092, 14.6301403], [74.27041626, 14.6301403], [74.27041626, 14.63069439], [74.27069092, 14.63069439], [74.27069092, 14.63097191], [74.2720871, 14.63097191], [74.2720871, 14.63041592], [74.2723465, 14.63041973], [74.2723465, 14.6301403], [74.2729187, 14.6301403], [74.2729187, 14.62986183], [74.27319336, 14.62986183], [74.27319336, 14.62957859], [74.27347565, 14.62958431], [74.27347565, 14.62930584], [74.27375031, 14.62930965], [74.27375031, 14.62904167], [74.27430725, 14.62904167], [74.27430725, 14.62874985], [74.27542114, 14.62874985], [74.27541351, 14.62847233], [74.27625275, 14.62847233], [74.27625275, 14.62819576], [74.2765274, 14.62819576], [74.2765274, 14.62791634], [74.27707672, 14.62792015], [74.27707672, 14.62763977], [74.27791595, 14.62763977], [74.27791595, 14.62735939], [74.2784729, 14.62736225], [74.2784729, 14.62708378], [74.27902985, 14.62708378], [74.27902985, 14.62680626], [74.28013611, 14.62680626], [74.28013611, 14.62708378], [74.28125, 14.62708378], [74.28125, 14.62736225], [74.28151703, 14.62735939], [74.28151703, 14.62792015], [74.28180695, 14.62791634], [74.28180695, 14.62847233], [74.2820816, 14.62846947], [74.2820816, 14.62904167], [74.28236389, 14.62902832], [74.28236389, 14.62958431], [74.28263855, 14.62957859], [74.28263855, 14.6301403], [74.28291321, 14.6301403], [74.28291321, 14.63041973], [74.2831955, 14.63041592], [74.2831955, 14.63069439], [74.28375244, 14.63069439], [74.28375244, 14.63097191], [74.2840271, 14.63097191], [74.2840271, 14.6340313], [74.28430176, 14.63402843], [74.28430939, 14.63597202], [74.28458405, 14.63597202], [74.28458405, 14.63819504], [74.2848587, 14.63819027], [74.2848587, 14.64014053], [74.28457642, 14.64014053], [74.28457642, 14.64236069], [74.28430939, 14.64236069], [74.2842865, 14.6443119], [74.2840271, 14.6443119], [74.2840271, 14.64542198], [74.28375244, 14.64541721], [74.28375244, 14.64597321], [74.28347015, 14.6459713], [74.28347015, 14.6465292], [74.28320313, 14.6465292], [74.28320313, 14.64680958], [74.28263855, 14.64680481], [74.28263855, 14.6473608], [74.28236389, 14.6473608], [74.28236389, 14.64847088], [74.2820816, 14.64847088], [74.2820816, 14.64903164], [74.27902985, 14.64902687], [74.27902985, 14.64958286], [74.2793045, 14.64958286], [74.2793045, 14.64986134], [74.27986145, 14.64986134], [74.27986145, 14.65015125], [74.28013611, 14.65015125], [74.28013611, 14.65042019], [74.28069305, 14.65041542], [74.28069305, 14.6506958], [74.28097534, 14.6506958], [74.28097534, 14.65097141], [74.28125, 14.65097141], [74.28125, 14.65125179], [74.28151703, 14.65125179], [74.28151703, 14.65153027], [74.28180695, 14.6515274], [74.28180695, 14.65208435], [74.2820816, 14.65208054], [74.2820816, 14.65236187], [74.28235626, 14.65236187], [74.28235626, 14.65264034], [74.2820816, 14.65264034], [74.2820816, 14.65319443], [74.28180695, 14.65319443], [74.28180695, 14.65347195], [74.28151703, 14.65347195], [74.28151703, 14.65402985], [74.28125, 14.65402794], [74.28125, 14.65458393], [74.28097534, 14.65458393], [74.28097534, 14.6548624], [74.28069305, 14.65485954], [74.28069305, 14.6554203], [74.2804184, 14.65541553], [74.2804184, 14.65569401], [74.28013611, 14.65569401], [74.28013611, 14.65597153], [74.27986145, 14.65596008], [74.27986145, 14.65625], [74.27958679, 14.65625], [74.27958679, 14.65653038], [74.27902985, 14.65653038], [74.27902985, 14.65625], [74.27874756, 14.65625], [74.27874756, 14.65680981], [74.27848053, 14.65680981], [74.27848053, 14.65764046], [74.27819824, 14.65764046], [74.27819824, 14.65792274], [74.27791595, 14.65791798], [74.27791595, 14.65819359], [74.27819824, 14.65819168], [74.27819824, 14.65874958], [74.27848053, 14.65874958], [74.27848053, 14.65931129], [74.27874756, 14.65931129], [74.27874756, 14.65985966], [74.27902985, 14.65985966], [74.27902985, 14.66042137], [74.27958679, 14.66041565], [74.27958679, 14.66069412], [74.28013611, 14.66069412], [74.28013611, 14.66097164], [74.28125, 14.66096973], [74.28125, 14.66125011], [74.28151703, 14.66125011], [74.28151703, 14.66181087], [74.28180695, 14.6618309], [74.28180695, 14.66209126], [74.2820816, 14.66209126], [74.2820816, 14.66264057], [74.28235626, 14.66264057], [74.28235626, 14.66292095], [74.28291321, 14.66291618], [74.28291321, 14.66347218], [74.28263855, 14.66347027], [74.28263855, 14.66374969], [74.28098297, 14.66374969], [74.28098297, 14.6631918], [74.2808609, 14.6631918], [74.28069305, 14.6631937], [74.28069305, 14.66291618], [74.2804184, 14.66292095], [74.2804184, 14.66264057], [74.28013611, 14.66264057], [74.28013611, 14.66209126], [74.27986145, 14.66209126], [74.27986145, 14.66181087], [74.27958679, 14.66181087], [74.27958679, 14.66153145], [74.27902985, 14.66153145], [74.27902985, 14.66125011], [74.27848053, 14.66125011], [74.27848053, 14.66096973], [74.27791595, 14.66097164], [74.27791595, 14.66069412], [74.27735901, 14.66069412], [74.27735901, 14.66041565], [74.27707672, 14.66042137], [74.27707672, 14.66014004], [74.2765274, 14.66014004], [74.2765274, 14.65985966], [74.27625275, 14.65985966], [74.27625275, 14.66014004], [74.2756958, 14.66014004], [74.2756958, 14.66042137], [74.27541351, 14.66041565], [74.27541351, 14.66069412], [74.2756958, 14.66069412], [74.2756958, 14.66097164], [74.27625275, 14.66096973], [74.27625275, 14.66125011], [74.2765274, 14.66125011], [74.2765274, 14.66153145], [74.27680206, 14.66153145], [74.27680206, 14.66181087], [74.27848053, 14.66181087], [74.27848053, 14.66209126], [74.27902985, 14.66209126], [74.27902985, 14.66264057], [74.27874756, 14.66264057], [74.27874756, 14.66374969], [74.27848053, 14.66374969], [74.27848053, 14.66431141], [74.27819824, 14.66431141], [74.27819824, 14.66485977], [74.27791595, 14.66485977], [74.27791595, 14.66542053], [74.2776413, 14.66541672], [74.2776413, 14.66569519], [74.27708435, 14.66569519], [74.27708435, 14.66597271], [74.27541351, 14.66597271], [74.27541351, 14.66625118], [74.2756958, 14.66625118], [74.2756958, 14.66681099], [74.27597046, 14.66680527], [74.27597046, 14.66708469], [74.27625275, 14.66708469], [74.27625275, 14.66736126], [74.2765274, 14.66736126], [74.2765274, 14.66764069], [74.27680206, 14.66764069], [74.27680206, 14.66792107], [74.27708435, 14.66791725], [74.27708435, 14.66847324], [74.27735901, 14.66847134], [74.27735901, 14.66875076], [74.2776413, 14.66875076], [74.2776413, 14.66903114], [74.27735901, 14.66902924], [74.27735901, 14.66958332], [74.2765274, 14.66958046], [74.2765274, 14.66986084], [74.27597046, 14.66986084], [74.27597046, 14.67014122], [74.27625275, 14.67013931], [74.27625275, 14.6706953], [74.2765274, 14.67068958], [74.2765274, 14.6712513], [74.27680206, 14.6712513], [74.27680206, 14.6718092], [74.27708435, 14.67180538], [74.27708435, 14.67236137], [74.27735901, 14.67236137], [74.27735901, 14.67263889], [74.2776413, 14.67263889], [74.2776413, 14.67236137], [74.27791595, 14.67236137], [74.27791595, 14.6720829], [74.27819061, 14.6720829], [74.27819824, 14.67180538], [74.27874756, 14.6718092], [74.27874756, 14.67153072], [74.27902985, 14.67153072], [74.27902985, 14.6712513], [74.27929688, 14.6712513], [74.27929688, 14.67095947], [74.2804184, 14.67095947], [74.2804184, 14.6712513], [74.28069305, 14.6712513], [74.28069305, 14.6718092], [74.28097534, 14.67180538], [74.28097534, 14.6720829], [74.28125, 14.67208099], [74.28125, 14.67263889], [74.28152466, 14.67263889], [74.28152466, 14.67319489], [74.28180695, 14.67319107], [74.28180695, 14.67792034], [74.28152466, 14.67791843], [74.28152466, 14.67847061], [74.28125, 14.67847061], [74.28125, 14.67903042], [74.28097534, 14.67902756], [74.28097534, 14.67958355], [74.28069305, 14.67958355], [74.28069305, 14.68013954], [74.2804184, 14.68013954], [74.2804184, 14.68069363], [74.28013611, 14.68068886], [74.28013611, 14.68124962], [74.27986145, 14.68124962], [74.27986145, 14.68208408], [74.27958679, 14.68207932], [74.27958679, 14.68264008], [74.2793045, 14.68264008], [74.2793045, 14.68319416], [74.27902985, 14.68318939], [74.27902985, 14.68375015], [74.27874756, 14.68375015], [74.27874756, 14.68431091], [74.2784729, 14.68430614], [74.2784729, 14.68486214], [74.27819824, 14.68486023], [74.27819824, 14.68542004], [74.27791595, 14.68541622], [74.27791595, 14.68597221], [74.2776413, 14.68597031], [74.2776413, 14.68653011], [74.27735901, 14.68653011], [74.27735901, 14.68681145], [74.27707672, 14.68681145], [74.27707672, 14.68736172], [74.27680206, 14.68736172], [74.27680206, 14.68792057], [74.2765274, 14.6879158], [74.2765274, 14.68819427], [74.27625275, 14.68819046], [74.27625275, 14.68875027], [74.27597046, 14.68875027], [74.27597046, 14.68931961], [74.2756958, 14.68930626], [74.2756958, 14.68986034], [74.27542114, 14.68986034], [74.27542114, 14.6904211], [74.27513885, 14.69041634], [74.27513885, 14.69097233], [74.27485657, 14.69097042], [74.27485657, 14.69153118], [74.27458191, 14.69153118], [74.27458191, 14.69235992], [74.27430725, 14.69235992], [74.27430725, 14.69292068], [74.27402496, 14.69291687], [74.27402496, 14.69347286], [74.27375031, 14.69347], [74.27375031, 14.69403076], [74.27347565, 14.69402885], [74.27347565, 14.69458294], [74.27319336, 14.69458294], [74.27319336, 14.69486141], [74.2729187, 14.69486141], [74.2729187, 14.69513893], [74.27263641, 14.69513035], [74.27263641, 14.69542122], [74.27236176, 14.6954174], [74.27236176, 14.6959734], [74.2720871, 14.6959734], [74.2720871, 14.69640064], [74.2720871, 14.6965313], [74.27180481, 14.69652653], [74.27180481, 14.69708347], [74.27153015, 14.69708061], [74.27153015, 14.69764137], [74.27124786, 14.69764137], [74.27124786, 14.69820023], [74.27097321, 14.69820023], [74.27097321, 14.69875145], [74.27069092, 14.69875145], [74.27069092, 14.69958305], [74.27041626, 14.69958115], [74.27041626, 14.70014095], [74.2701416, 14.70013905], [74.2701416, 14.70069313], [74.26985931, 14.70069122], [74.26985931, 14.70125961], [74.26957703, 14.70125961], [74.26957703, 14.70181179], [74.26930237, 14.70180511], [74.26930237, 14.70236111], [74.26902771, 14.7023592], [74.26902771, 14.70264244], [74.26875305, 14.70264244], [74.26875305, 14.70292187], [74.26847076, 14.7029171], [74.26847076, 14.70319462], [74.26819611, 14.70319462], [74.26819611, 14.70347118], [74.26790619, 14.70347118], [74.26790619, 14.70375156], [74.26763916, 14.70375156], [74.26763916, 14.70403194], [74.26735687, 14.70403194], [74.26735687, 14.70432091], [74.26708221, 14.7043047], [74.26708221, 14.70458317], [74.26680756, 14.70458126], [74.26680756, 14.70486164], [74.26654053, 14.70486164], [74.26654053, 14.70514202], [74.26374817, 14.70514202], [74.26374817, 14.70486164], [74.26291656, 14.70486164], [74.26291656, 14.70541954], [74.26264191, 14.70541763], [74.26264191, 14.70569324], [74.26208496, 14.70569324], [74.26208496, 14.70597363], [74.26180267, 14.70597076], [74.26180267, 14.70625019], [74.26125336, 14.70625019], [74.26125336, 14.70652962], [74.26097107, 14.70652771], [74.26097107, 14.7070837], [74.25958252, 14.7070837], [74.25958252, 14.70680618], [74.25875092, 14.70681], [74.25875092, 14.70652962], [74.25846863, 14.70652962], [74.25846863, 14.70681], [74.25763702, 14.70681], [74.25763702, 14.70652962], [74.25734711, 14.70652962], [74.25734711, 14.70625019], [74.25708008, 14.70625019], [74.25708008, 14.70597076], [74.25681305, 14.70597076], [74.25681305, 14.70652962], [74.25653076, 14.70652962], [74.25653076, 14.70792007], [74.25846863, 14.70792007], [74.25846863, 14.70874977], [74.25985718, 14.70874977], [74.25985718, 14.70903015], [74.26040649, 14.70903015], [74.26040649, 14.70930958], [74.26069641, 14.70930576], [74.26069641, 14.70958424], [74.26097107, 14.70958424], [74.26097107, 14.70986176], [74.26152802, 14.70985985], [74.26152802, 14.71014023], [74.26180267, 14.71014023], [74.26180267, 14.71041965], [74.26235962, 14.71041584], [74.26235962, 14.71069431], [74.26264191, 14.71069431], [74.26264191, 14.71097183], [74.26319122, 14.71097183], [74.26319122, 14.71125031], [74.26348114, 14.71125031], [74.26348114, 14.71152973], [74.26403046, 14.71152973], [74.26403046, 14.71181107], [74.26457977, 14.7118063], [74.26457977, 14.71208191], [74.26597595, 14.71208191], [74.26597595, 14.71236229], [74.26708221, 14.71236038], [74.26708221, 14.71263981], [74.26735687, 14.71263981], [74.26735687, 14.71320057], [74.26708221, 14.71320057], [74.26708221, 14.71375179], [74.26680756, 14.71375179], [74.26680756, 14.71431065], [74.26652527, 14.71430588], [74.26654053, 14.71485996], [74.26625061, 14.71485996], [74.26625061, 14.71514034], [74.26597595, 14.71514034], [74.26597595, 14.71542072], [74.26569366, 14.71541595], [74.26569366, 14.71569443], [74.26486206, 14.71569443], [74.26486206, 14.71430588], [74.26457977, 14.71431065], [74.26457977, 14.71403027], [74.26374817, 14.71402836], [74.26374817, 14.71708202], [74.26348114, 14.71708012], [74.26348114, 14.71764088], [74.26319122, 14.71764088], [74.26319122, 14.71792126], [74.26291656, 14.71791553], [74.26291656, 14.71847343], [74.26264191, 14.71846962], [74.26264191, 14.71875095], [74.26235962, 14.71875095], [74.26235962, 14.71930695], [74.26208496, 14.71930695], [74.26208496, 14.7195816], [74.26180267, 14.7195797], [74.26180267, 14.72014141], [74.26152802, 14.72014141], [74.26152802, 14.72042084], [74.26125336, 14.72041702], [74.26125336, 14.72097301], [74.26097107, 14.72097015], [74.26097107, 14.72153091], [74.26069641, 14.72152901], [74.26069641, 14.72208309], [74.26041412, 14.72208309], [74.26041412, 14.72236061], [74.26013947, 14.72236061], [74.26013947, 14.72292137], [74.25986481, 14.7229166], [74.25986481, 14.7234726], [74.25958252, 14.72347069], [74.25958252, 14.72403145], [74.25930786, 14.72403145], [74.25930786, 14.72431183], [74.25902557, 14.72430515], [74.25902557, 14.72486115], [74.25875092, 14.72486115], [74.25875092, 14.72543144], [74.25846863, 14.72541714], [74.25846863, 14.72597313], [74.25818634, 14.72597122], [74.25818634, 14.72625065], [74.25791931, 14.72625065], [74.25791931, 14.72681046], [74.25763702, 14.72680473], [74.25763702, 14.72708321], [74.25734711, 14.7270813], [74.25734711, 14.72736073], [74.25708008, 14.72736073], [74.25708008, 14.72791958], [74.25681305, 14.72791958], [74.25681305, 14.72819996], [74.25653076, 14.72819996], [74.25653076, 14.72874928], [74.25624847, 14.72874928], [74.25624847, 14.72903156], [74.25597382, 14.72902679], [74.25597382, 14.72958279], [74.25569153, 14.72958279], [74.25569153, 14.72986126], [74.25541687, 14.72986126], [74.25541687, 14.73014164], [74.25514221, 14.73013878], [74.25514221, 14.73069572], [74.25485992, 14.73069572], [74.25485992, 14.73097134], [74.25458527, 14.73097134], [74.25460052, 14.73152065], [74.25431061, 14.73153019], [74.25431061, 14.73180962], [74.25402832, 14.73180485], [74.25402832, 14.73208427], [74.25374603, 14.73208141], [74.25374603, 14.73236179], [74.25319672, 14.73236179], [74.25319672, 14.73264027], [74.2529068, 14.73264027], [74.2529068, 14.73291969], [74.25263977, 14.73291779], [74.25263977, 14.7331934], [74.25235748, 14.7331934], [74.25235748, 14.73347092], [74.25180817, 14.73347092], [74.25180817, 14.73375034], [74.25152588, 14.73375034], [74.25152588, 14.73402977], [74.25125122, 14.73402786], [74.25125122, 14.73430634], [74.25096893, 14.73430634], [74.25096893, 14.73458385], [74.25069427, 14.73458385], [74.25069427, 14.73486233], [74.25013733, 14.73485947], [74.25013733, 14.73513985], [74.24986267, 14.73513985], [74.24986267, 14.73542023], [74.24958038, 14.73541641], [74.24958038, 14.73922157], [74.24958038, 14.73958397], [74.24913788, 14.73958397], [74.24903107, 14.73958397], [74.24903107, 14.73985958], [74.24874878, 14.73987961], [74.24874878, 14.74013996], [74.24845123, 14.74013805], [74.24819183, 14.74013805], [74.24819183, 14.74033928], [74.24819183, 14.74041557], [74.24791718, 14.74041557], [74.24791718, 14.74069405], [74.24736023, 14.74069405], [74.24736023, 14.74097157], [74.2470932, 14.74096966], [74.2470932, 14.74125004], [74.24652863, 14.74125004], [74.24652863, 14.74153137], [74.24624634, 14.74153137], [74.24624634, 14.7418108], [74.24569702, 14.74180603], [74.24569702, 14.74208355], [74.2454071, 14.74207973], [74.2454071, 14.74236012], [74.24485779, 14.74236012], [74.24485779, 14.74263954], [74.24458313, 14.74263954], [74.24458313, 14.74292088], [74.24430847, 14.74291611], [74.24430847, 14.74319363], [74.24375153, 14.74319363], [74.24375153, 14.7434721], [74.24318695, 14.74347019], [74.24318695, 14.74374962], [74.24291992, 14.74374962], [74.24291992, 14.74403095], [74.24237061, 14.74403095], [74.24237061, 14.74431133], [74.24208069, 14.74430656], [74.24208069, 14.74458218], [74.24153137, 14.74458218], [74.24153137, 14.7448597], [74.24124908, 14.7448597], [74.24124908, 14.74514103], [74.24069214, 14.74514103], [74.24069214, 14.74542141], [74.24013519, 14.74541569], [74.24013519, 14.74569511], [74.23958588, 14.74569511], [74.23958588, 14.74597263], [74.23930359, 14.74597263], [74.23930359, 14.74625111], [74.23874664, 14.74624062], [74.23874664, 14.74653053], [74.23819733, 14.74653053], [74.23819733, 14.74681091], [74.23791504, 14.74680424], [74.23791504, 14.74708462], [74.23735809, 14.74708462], [74.23735809, 14.74736118], [74.23596954, 14.74736118], [74.23596954, 14.74764061], [74.23458099, 14.74764061], [74.23458099, 14.74792099], [74.23264313, 14.74792099], [74.23264313, 14.74764061], [74.23208618, 14.74764061], [74.23208618, 14.74736118], [74.23124695, 14.74736118], [74.23124695, 14.74708462], [74.23069763, 14.74708462], [74.23069763, 14.74680424], [74.2298584, 14.74681091], [74.2298584, 14.74653053], [74.22930908, 14.74653053], [74.22930908, 14.74624062], [74.22875214, 14.74625111], [74.22875214, 14.74597263], [74.22819519, 14.74597263], [74.22819519, 14.74569511], [74.22763824, 14.74569511], [74.22763824, 14.74513817], [74.22737122, 14.74514103], [74.22737122, 14.74458027], [74.22763824, 14.74458218], [74.22763824, 14.74430656], [74.22737122, 14.74431133], [74.22737122, 14.74403095], [74.22763824, 14.74403095], [74.22763824, 14.74318123], [74.2279129, 14.74319363], [74.2279129, 14.74263763], [74.22820282, 14.74263954], [74.22820282, 14.74236012], [74.22846985, 14.74236012], [74.22846985, 14.74125004], [74.22902679, 14.74125004], [74.22902679, 14.74096966], [74.22875214, 14.74097157], [74.22875214, 14.74069405], [74.22902679, 14.74069405], [74.22902679, 14.74041557], [74.22875214, 14.74043179], [74.22875214, 14.73931122], [74.22846985, 14.73931122], [74.22846985, 14.7381916], [74.22875214, 14.73819447], [74.22875214, 14.73763847], [74.22820282, 14.73764038], [74.22820282, 14.73708153], [74.22624969, 14.73708439], [74.22624969, 14.73680592], [74.22319794, 14.73680973], [74.22319794, 14.7365303], [74.22292328, 14.7365303], [74.22292328, 14.73596859], [74.22264099, 14.7359724], [74.22264099, 14.73541641], [74.2215271, 14.73541641], [74.2215271, 14.73569584], [74.22125244, 14.73569584], [74.22125244, 14.7359724], [74.22070313, 14.73596859], [74.22070313, 14.73624992], [74.22013855, 14.73624992], [74.22013855, 14.7365303], [74.2195816, 14.7365303], [74.2195816, 14.73680973], [74.21820068, 14.73680973], [74.21820068, 14.7365303], [74.21763611, 14.7365303], [74.21763611, 14.73624992], [74.21652985, 14.73624992], [74.21652985, 14.73596859], [74.21624756, 14.7359724], [74.21624756, 14.73541641], [74.21569824, 14.73542023], [74.21569061, 14.73513985], [74.2151413, 14.73513985], [74.2151413, 14.73485947], [74.21485901, 14.73486233], [74.21485901, 14.73458385], [74.21291351, 14.73458385], [74.21291351, 14.73430634], [74.21263885, 14.73430634], [74.21263885, 14.73402786], [74.21235657, 14.73402977], [74.21235657, 14.73375034], [74.21206665, 14.73375034], [74.21206665, 14.73347092], [74.21180725, 14.73347092], [74.21180725, 14.7331934], [74.21125031, 14.7331934], [74.21125031, 14.73291779], [74.21097565, 14.73291779], [74.21097565, 14.7331934], [74.2104187, 14.7331934], [74.2104187, 14.73347092], [74.20986176, 14.73347092], [74.20986176, 14.73375034], [74.2095871, 14.73375034], [74.2095871, 14.73402977], [74.20930481, 14.73402786], [74.20930481, 14.73486233], [74.20903015, 14.73485947], [74.20903015, 14.73680973], [74.20874786, 14.73680592], [74.20874786, 14.73708439], [74.20847321, 14.73708153], [74.20847321, 14.73737144], [74.20735931, 14.73737144], [74.20735931, 14.73764038], [74.20707703, 14.73764038], [74.20707703, 14.73737144], [74.20652771, 14.73737144], [74.20652771, 14.73708153], [74.20597076, 14.73708439], [74.20597076, 14.73680592], [74.20569611, 14.73680973], [74.20569611, 14.7365303], [74.20513916, 14.7365303], [74.20513916, 14.73596859], [74.2048645, 14.7359724], [74.2048645, 14.73541641], [74.20430756, 14.73542023], [74.20430756, 14.73513985], [74.2040329, 14.73513985], [74.2040329, 14.73485947], [74.20375061, 14.73486233], [74.20375061, 14.73458385], [74.20347595, 14.73458385], [74.20347595, 14.73291779], [74.20320129, 14.73291969], [74.20320129, 14.73264027], [74.20349121, 14.73264027], [74.20349121, 14.73236179], [74.20375061, 14.73236179], [74.20375061, 14.73124027], [74.20402527, 14.73124886], [74.20402527, 14.73097134], [74.20458221, 14.73097134], [74.20458221, 14.73069572], [74.20513916, 14.73069572], [74.20513916, 14.73013878], [74.20569611, 14.73014164], [74.20569611, 14.72986126], [74.20597076, 14.72986126], [74.20597076, 14.72930527], [74.20626068, 14.72931194], [74.20626068, 14.72736073], [74.20652771, 14.72736073], [74.20652771, 14.72625065], [74.20680237, 14.72625065], [74.20680237, 14.72514057], [74.20707703, 14.72514057], [74.20707703, 14.72431183], [74.20735931, 14.72431183], [74.20735931, 14.72375107], [74.2076416, 14.72375107], [74.2076416, 14.72347069], [74.20735931, 14.7234726], [74.20735931, 14.72319508], [74.20791626, 14.72319508], [74.20791626, 14.72208309], [74.20819092, 14.72208309], [74.20819092, 14.72152901], [74.20791626, 14.72153091], [74.20791626, 14.72125053], [74.20819092, 14.72125053], [74.20819092, 14.72097015], [74.20847321, 14.72097301], [74.20847321, 14.71986008], [74.20874786, 14.71986008], [74.20874786, 14.71764088], [74.20847321, 14.71764088], [74.20847321, 14.71735954], [74.20819092, 14.71735954], [74.20819092, 14.71764088], [74.20791626, 14.71764088], [74.20791626, 14.71735954], [74.2076416, 14.71735954], [74.2076416, 14.71764088], [74.20652771, 14.71764088], [74.20652771, 14.71792126], [74.2059021, 14.71791935], [74.2048645, 14.71791553], [74.2048645, 14.71819401], [74.20458221, 14.71819401], [74.20458221, 14.71847343], [74.2040329, 14.71846962], [74.2040329, 14.71875095], [74.20347595, 14.71875095], [74.20347595, 14.71930695], [74.20319366, 14.71930695], [74.20319366, 14.7195816], [74.20263672, 14.7195797], [74.20263672, 14.71986008], [74.20207977, 14.71986008], [74.20207977, 14.72014141], [74.20153046, 14.72014141], [74.20153046, 14.72042084], [74.20124817, 14.72041702], [74.20124817, 14.72069454], [74.20069122, 14.72068977], [74.20069122, 14.72125053], [74.20012665, 14.72125053], [74.20012665, 14.72181129], [74.19985962, 14.72180462], [74.19985962, 14.72208309], [74.19958496, 14.72208309], [74.19958496, 14.72236061], [74.19930267, 14.72236061], [74.19930267, 14.72264099], [74.19902802, 14.72263908], [74.19902802, 14.72319508], [74.19847107, 14.72319508], [74.19847107, 14.7234726], [74.19819641, 14.72347069], [74.19819641, 14.72403145], [74.19763947, 14.72403145], [74.19763947, 14.72431183], [74.19735718, 14.72431183], [74.19735718, 14.72403145], [74.19706726, 14.72403145], [74.19706726, 14.72431183], [74.19652557, 14.72430515], [74.19652557, 14.72458267], [74.19541931, 14.72458267], [74.19541931, 14.72486115], [74.19403076, 14.72486115], [74.19403076, 14.72514057], [74.19374847, 14.72514057], [74.19374847, 14.72543144], [74.19319153, 14.72541714], [74.19319153, 14.72569466], [74.19235992, 14.72569275], [74.19235992, 14.72736073], [74.19264221, 14.72736073], [74.19264221, 14.72791958], [74.19291687, 14.72791958], [74.19291687, 14.72819996], [74.19319153, 14.72819519], [74.19319153, 14.7284708], [74.19346619, 14.72846889], [74.19346619, 14.72874928], [74.19374847, 14.72874928], [74.19374847, 14.72903156], [74.19403076, 14.72902679], [74.19403076, 14.72958279], [74.19430542, 14.72958279], [74.19430542, 14.72986126], [74.19458008, 14.72986126], [74.19458008, 14.73014164], [74.19430542, 14.73013878], [74.19430542, 14.73069572], [74.19403076, 14.73069572], [74.19403076, 14.73124886], [74.19374847, 14.73124027], [74.19374847, 14.73153019], [74.19347382, 14.73152733], [74.19347382, 14.73188972], [74.19346619, 14.73513985], [74.19291687, 14.73513985], [74.19291687, 14.73569584], [74.19264221, 14.73569107], [74.19264221, 14.73624992], [74.19235992, 14.73624992], [74.19235992, 14.7365303], [74.1920929, 14.7365303], [74.1920929, 14.73680973], [74.19180298, 14.73680592], [74.19180298, 14.73708439], [74.19152832, 14.73708153], [74.19152832, 14.73764038], [74.19126129, 14.73764038], [74.19126129, 14.73791981], [74.19097137, 14.73791599], [74.19097137, 14.73819447], [74.19069672, 14.73819447], [74.19069672, 14.73847198], [74.1904068, 14.73847198], [74.1904068, 14.73875046], [74.19013977, 14.73875046], [74.19013977, 14.73903275], [74.18985748, 14.73902798], [74.18985748, 14.73958397], [74.18958282, 14.73958397], [74.18958282, 14.73986244], [74.18930817, 14.73985958], [74.18930817, 14.74013996], [74.18902588, 14.74013996], [74.18902588, 14.74043179], [74.18875122, 14.74041557], [74.18875122, 14.74097157], [74.18846893, 14.74096966], [74.18846893, 14.74125004], [74.18818665, 14.74125004], [74.18818665, 14.74153137], [74.18791962, 14.74152756], [74.18791962, 14.74208355], [74.18763733, 14.74207973], [74.18763733, 14.74236012], [74.18708038, 14.74236012], [74.18708038, 14.74263954], [74.18653107, 14.74263954], [74.18653107, 14.74292088], [74.18605804, 14.74291897], [74.18597412, 14.74291611], [74.18597412, 14.74319363], [74.18575287, 14.74319363], [74.18541718, 14.74319363], [74.18541718, 14.74349976], [74.18541718, 14.74374962], [74.18514252, 14.74374962], [74.18514252, 14.74458218], [74.18486023, 14.74458027], [74.18486023, 14.7448597], [74.1845932, 14.7448597], [74.1845932, 14.74514103], [74.18430328, 14.74514103], [74.18430328, 14.74542141], [74.18402863, 14.74541569], [74.18402863, 14.74569511], [74.18374634, 14.74569511], [74.18374634, 14.74597263], [74.18347168, 14.74597263], [74.18347168, 14.74625111], [74.18319702, 14.74624062], [74.18319702, 14.74653053], [74.1829071, 14.74653053], [74.1829071, 14.74681091], [74.18264008, 14.74680424], [74.18264008, 14.74708462], [74.18235779, 14.74708462], [74.18235779, 14.74736118], [74.18206787, 14.74736118], [74.18206787, 14.74764061], [74.18180847, 14.74764061], [74.18180847, 14.74792099], [74.18152618, 14.74791718], [74.18152618, 14.74819469], [74.18125153, 14.74819469], [74.18125153, 14.74847317], [74.18068695, 14.74847031], [74.18068695, 14.74875069], [74.18041992, 14.74875069], [74.18041992, 14.74903107], [74.18013763, 14.74903107], [74.18013763, 14.74931145], [74.17958069, 14.74930477], [74.17958069, 14.74958324], [74.17930603, 14.74958324], [74.17932129, 14.74986076], [74.17624664, 14.74986076], [74.17624664, 14.74958038], [74.17569733, 14.74958038], [74.17569733, 14.75014114], [74.17542267, 14.75014114], [74.17542267, 14.75042057], [74.17514038, 14.75041676], [74.17514038, 14.75069523], [74.17485809, 14.75069046], [74.17485809, 14.75097084], [74.17457581, 14.75097084], [74.17458344, 14.75125122], [74.17318726, 14.75125122], [74.17263794, 14.75125122], [74.17263794, 14.75097084], [74.17180634, 14.75097084], [74.17180634, 14.75125122], [74.17151642, 14.75125122], [74.17151642, 14.75153065], [74.1709671, 14.75153065], [74.1709671, 14.75181198], [74.17069244, 14.75180531], [74.17069244, 14.75208282], [74.17041779, 14.75208092], [74.17041779, 14.75237179], [74.16819763, 14.75237179], [74.16819763, 14.75264072], [74.1673584, 14.75264072], [74.1673584, 14.7529192], [74.16668701, 14.7529192], [74.16374969, 14.75291729], [74.16374969, 14.75319481], [74.16347504, 14.75319481], [74.16347504, 14.75374889], [74.16374969, 14.75374889], [74.16374969, 14.75402927], [74.16403198, 14.75402927], [74.16403198, 14.75430965], [74.16430664, 14.75430489], [74.16430664, 14.75458336], [74.1645813, 14.75458145], [74.1645813, 14.75486088], [74.16486359, 14.75486088], [74.16486359, 14.75569534], [74.16513824, 14.75569534], [74.16513824, 14.75597095], [74.1654129, 14.75597095], [74.1654129, 14.75681019], [74.16513824, 14.75680542], [74.16513824, 14.75708294], [74.1654129, 14.75708103], [74.1654129, 14.75930977], [74.16513824, 14.75930977], [74.16513824, 14.76014042], [74.16486359, 14.7601366], [74.16486359, 14.76097202], [74.16513824, 14.76097202], [74.16513824, 14.76154137], [74.1654129, 14.76152802], [74.1654129, 14.76208401], [74.16570282, 14.76207924], [74.16570282, 14.76264], [74.16596985, 14.76264], [74.16596985, 14.76292038], [74.16625214, 14.76291561], [74.16625214, 14.76319408], [74.16708374, 14.76319408], [74.16708374, 14.7634716], [74.1673584, 14.7634716], [74.1673584, 14.76291561], [74.16791534, 14.76291561], [74.16791534, 14.76319408], [74.16819763, 14.76319408], [74.16819763, 14.7634716], [74.16847229, 14.7634716], [74.16847229, 14.76403046], [74.16874695, 14.76403046], [74.16874695, 14.76431274], [74.16847229, 14.76430607], [74.16847229, 14.76458359], [74.16819763, 14.76458359], [74.16819763, 14.76486206], [74.16792297, 14.76486015], [74.16792297, 14.76513958], [74.16764069, 14.76513958], [74.16764069, 14.76541996], [74.1673584, 14.76541805], [74.1673584, 14.76569366], [74.16709137, 14.7656889], [74.16709137, 14.76624966], [74.16680908, 14.76624966], [74.16680908, 14.76653004], [74.16625214, 14.76653004], [74.16625214, 14.76624966], [74.16570282, 14.76624966], [74.16570282, 14.76597023], [74.1654129, 14.76597214], [74.1654129, 14.76569366], [74.16513824, 14.76569366], [74.16513824, 14.76458359], [74.16486359, 14.76458359], [74.16486359, 14.76319408], [74.1645813, 14.76319408], [74.1645813, 14.76291561], [74.16430664, 14.76292038], [74.16430664, 14.76235962], [74.16402435, 14.76236153], [74.16402435, 14.76180553], [74.16374969, 14.7618103], [74.16374969, 14.76014042], [74.16403198, 14.76014042], [74.16403198, 14.75958061], [74.16374969, 14.75958443], [74.16374969, 14.75736141], [74.16402435, 14.75736141], [74.16402435, 14.75597095], [74.16374969, 14.75597095], [74.16374969, 14.75541687], [74.16347504, 14.75541687], [74.16347504, 14.75486088], [74.16319275, 14.75486088], [74.16319275, 14.75458145], [74.1626358, 14.75458145], [74.1626358, 14.75486088], [74.1598587, 14.75486088], [74.1598587, 14.75458145], [74.15958405, 14.75458336], [74.15958405, 14.75430489], [74.1590271, 14.75430965], [74.1590271, 14.75402927], [74.15875244, 14.75402927], [74.15875244, 14.7529192], [74.15847015, 14.7529192], [74.15847015, 14.75208092], [74.16013336, 14.75208282], [74.16041565, 14.75208282], [74.16041565, 14.75180531], [74.16014862, 14.75181198], [74.16014099, 14.75153065], [74.1598587, 14.75153065], [74.1598587, 14.75125122], [74.15957642, 14.75125122], [74.15957642, 14.75097084], [74.15930176, 14.75097084], [74.15930176, 14.75069046], [74.1590271, 14.75069523], [74.1590271, 14.75041676], [74.15875244, 14.75042057], [74.15875244, 14.74903107], [74.1590271, 14.74903107], [74.1590271, 14.74624062], [74.15875244, 14.74625111], [74.15875244, 14.74569511], [74.15791321, 14.74569511], [74.15791321, 14.74541569], [74.15735626, 14.74542141], [74.15735626, 14.74514103], [74.15680695, 14.74514103], [74.15680695, 14.74542141], [74.15597534, 14.74541569], [74.15597534, 14.74569511], [74.1554184, 14.74569511], [74.1554184, 14.74597263], [74.15319824, 14.74596977], [74.15319824, 14.74653053], [74.15291595, 14.74652863], [74.15291595, 14.74708462], [74.15208435, 14.74708462], [74.15208435, 14.74736118], [74.15180206, 14.74736118], [74.15180206, 14.74764061], [74.1515274, 14.74764061], [74.1515274, 14.74792099], [74.15097046, 14.74791718], [74.15097046, 14.74819469], [74.1506958, 14.74818993], [74.1506958, 14.74875069], [74.15097046, 14.74875069], [74.15097046, 14.74986076], [74.1506958, 14.74986076], [74.1506958, 14.75153065], [74.15097046, 14.75153065], [74.15097046, 14.75181198], [74.15125275, 14.75180531], [74.15125275, 14.75208282], [74.15097046, 14.75208092], [74.15097046, 14.75237179], [74.15125275, 14.75237179], [74.15125275, 14.7529192], [74.1515274, 14.75291729], [74.1515274, 14.75347328], [74.15180206, 14.75347137], [74.15180206, 14.75374889], [74.15209198, 14.75374889], [74.15209198, 14.75430965], [74.15235901, 14.75430965], [74.15235901, 14.75486088], [74.15291595, 14.75486088], [74.15291595, 14.75569534], [74.15319824, 14.75569534], [74.15319824, 14.75597095], [74.1534729, 14.75597095], [74.1534729, 14.75653172], [74.15402985, 14.75653172], [74.15402985, 14.75681019], [74.1543045, 14.75680542], [74.1543045, 14.75736141], [74.15458679, 14.75736141], [74.15458679, 14.75792027], [74.15486145, 14.75791836], [74.15486145, 14.75847054], [74.15597534, 14.75847054], [74.15597534, 14.75819302], [74.15652466, 14.75819302], [74.15652466, 14.75847054], [74.1570816, 14.75847054], [74.1570816, 14.75875187], [74.15736389, 14.75874901], [74.15736389, 14.7606926], [74.1570816, 14.76069069], [74.1570816, 14.76124954], [74.15680695, 14.76124954], [74.15680695, 14.7618103], [74.15652466, 14.76180553], [74.15652466, 14.76236153], [74.15625, 14.76235962], [74.15625, 14.76292038], [74.15597534, 14.76291561], [74.15597534, 14.76319408], [74.15569305, 14.76319408], [74.15569305, 14.7634716], [74.1554184, 14.7634716], [74.1554184, 14.76375198], [74.15515137, 14.76375198], [74.15515137, 14.76403046], [74.15486145, 14.76403046], [74.15486145, 14.76431274], [74.15458679, 14.76430607], [74.15458679, 14.76458359], [74.1543045, 14.76458359], [74.1543045, 14.76486206], [74.15402985, 14.76486015], [74.15402985, 14.76513958], [74.15374756, 14.76513958], [74.15374756, 14.76541996], [74.1534729, 14.76541805], [74.1534729, 14.76569366], [74.15319824, 14.76569366], [74.15319824, 14.76597214], [74.15291595, 14.76597023], [74.15291595, 14.76624966], [74.1526413, 14.76624966], [74.1526413, 14.76653004], [74.15235901, 14.76653004], [74.15235901, 14.76681137], [74.15208435, 14.76680565], [74.15208435, 14.76708412], [74.15180206, 14.76708412], [74.15180206, 14.76735973], [74.1515274, 14.76735115], [74.1515274, 14.76764011], [74.15125275, 14.76764011], [74.15125275, 14.76792145], [74.15097046, 14.76791573], [74.15097046, 14.7681942], [74.1506958, 14.7681942], [74.1506958, 14.76847172], [74.15040588, 14.76847172], [74.15040588, 14.76903057], [74.15013885, 14.76903057], [74.15013885, 14.76931095], [74.1498642, 14.76930618], [74.1498642, 14.7695837], [74.14958191, 14.7695837], [74.14958191, 14.76986027], [74.14930725, 14.76986027], [74.14930725, 14.77014065], [74.14902496, 14.77013779], [74.14902496, 14.77041626], [74.14875031, 14.77041626], [74.14875031, 14.77069378], [74.14847565, 14.77069378], [74.14847565, 14.77097225], [74.14819336, 14.77097034], [74.14819336, 14.77124977], [74.1479187, 14.77124977], [74.1479187, 14.77153111], [74.14763641, 14.77153111], [74.14763641, 14.77181053], [74.14736176, 14.77180672], [74.14736176, 14.77208233], [74.1470871, 14.77208233], [74.1470871, 14.77235985], [74.14679718, 14.77235985], [74.14679718, 14.77292061], [74.14653015, 14.77291584], [74.14653015, 14.77319527], [74.14624786, 14.77318954], [74.14624786, 14.77347946], [74.14569092, 14.77347279], [74.14569092, 14.77378941], [74.14569092, 14.77431107], [74.14541626, 14.77430439], [74.14541626, 14.77486134], [74.1451416, 14.77486134], [74.1451416, 14.77514076], [74.14485931, 14.77514076], [74.14485931, 14.77542114], [74.14458466, 14.77541733], [74.14458466, 14.77597332], [74.14402771, 14.77597141], [74.14402771, 14.7768116], [74.14375305, 14.77680683], [74.14375305, 14.7770834], [74.14319611, 14.7770834], [74.14319611, 14.77736092], [74.14292145, 14.77736092], [74.14292145, 14.77792072], [74.1423645, 14.77791691], [74.1423645, 14.77819538], [74.14180756, 14.77819538], [74.14180756, 14.7784729], [74.1415329, 14.77847099], [74.1415329, 14.77902889], [74.14097595, 14.77902889], [74.14097595, 14.77930927], [74.14041901, 14.77930546], [74.14041901, 14.77958298], [74.14015198, 14.77958107], [74.14015198, 14.78014088], [74.13957977, 14.78014088], [74.13957977, 14.78041935], [74.13874817, 14.78041744], [74.13874817, 14.78069305], [74.13847351, 14.78069305], [74.13847351, 14.78041744], [74.13791656, 14.78041935], [74.13791656, 14.78014088], [74.13764191, 14.78014088], [74.13764191, 14.77986145], [74.13735962, 14.77986145], [74.13735962, 14.77958298], [74.13708496, 14.77958298], [74.13708496, 14.77930546], [74.13678741, 14.77930927], [74.13678741, 14.77875137], [74.13652802, 14.77875137], [74.13652802, 14.77847099], [74.13597107, 14.7784729], [74.13597107, 14.77819538], [74.13569641, 14.77819538], [74.13569641, 14.77791691], [74.13540649, 14.77792072], [74.13540649, 14.7776413], [74.13458252, 14.7776413], [74.13458252, 14.77792072], [74.13402557, 14.77791691], [74.13402557, 14.7784729], [74.13375092, 14.77847099], [74.13375092, 14.77902889], [74.13346863, 14.77902699], [74.13346863, 14.77958298], [74.13319397, 14.77958298], [74.13319397, 14.77986145], [74.13263702, 14.77986145], [74.13263702, 14.78014088], [74.13236237, 14.78014088], [74.13236237, 14.78041935], [74.12821198, 14.78041935], [74.12821198, 14.78014088], [74.12763977, 14.78014088], [74.12763977, 14.77958107], [74.12735748, 14.77958298], [74.12735748, 14.77930546], [74.12708282, 14.77930927], [74.12708282, 14.77902889], [74.1268692, 14.77902889], [74.12652588, 14.77902889], [74.12652588, 14.77847099], [74.12625122, 14.7784729], [74.12625122, 14.77791691], [74.12596893, 14.77792072], [74.12596893, 14.7776413], [74.12568665, 14.7776413], [74.12568665, 14.7768116], [74.12541962, 14.7768116], [74.12541962, 14.77654266], [74.12568665, 14.77654266], [74.12568665, 14.77625084], [74.12541962, 14.77625084], [74.12541962, 14.77597141], [74.12569427, 14.77597332], [74.12569427, 14.77486134], [74.12541962, 14.77486134], [74.12541962, 14.77458477], [74.12180328, 14.77458286], [74.12180328, 14.77430439], [74.12152863, 14.77430439], [74.12152863, 14.77458286], [74.12014008, 14.77458477], [74.12014008, 14.77486134], [74.11904144, 14.77486134], [74.11904144, 14.77542114], [74.11875153, 14.77541733], [74.11875153, 14.77569485], [74.11902618, 14.77569485], [74.11902618, 14.77597332], [74.11875153, 14.77597141], [74.11875153, 14.77625084], [74.11904144, 14.77625084], [74.11904144, 14.77654266], [74.11875153, 14.77654266], [74.11875153, 14.77792072], [74.11902618, 14.77791691], [74.11902618, 14.77819538], [74.11958313, 14.77819538], [74.11958313, 14.7784729], [74.12014008, 14.77847099], [74.12014008, 14.77902889], [74.12041473, 14.77902699], [74.12041473, 14.77958298], [74.12097168, 14.77958107], [74.12097168, 14.78014088], [74.12124634, 14.78013897], [74.12124634, 14.78069305], [74.12152863, 14.78069115], [74.12152863, 14.78152943], [74.12124634, 14.78155041], [74.12124634, 14.78181171], [74.12097168, 14.78180504], [74.12097168, 14.78236103], [74.12069702, 14.78234959], [74.12069702, 14.78292179], [74.12041473, 14.78291702], [74.12041473, 14.78347111], [74.12014008, 14.78347111], [74.12014008, 14.78375244], [74.11985779, 14.78375244], [74.11985779, 14.78431034], [74.11958313, 14.78430462], [74.11958313, 14.78486061], [74.11930847, 14.78486061], [74.11930847, 14.78542042], [74.11902618, 14.78541756], [74.11902618, 14.78597355], [74.11875153, 14.78597069], [74.11875153, 14.78625202], [74.11846924, 14.78625202], [74.11846924, 14.78652954], [74.11818695, 14.78652954], [74.11818695, 14.78680992], [74.11763763, 14.78680611], [74.11763763, 14.78708363], [74.11736298, 14.78708363], [74.11736298, 14.7873621], [74.11708069, 14.78735924], [74.11708069, 14.78763962], [74.11680603, 14.78763962], [74.11680603, 14.78792], [74.11653137, 14.78791809], [74.11653137, 14.7881937], [74.11597443, 14.7881937], [74.11597443, 14.78791809], [74.1149826, 14.78792], [74.11458588, 14.78792], [74.11458588, 14.78763962], [74.11402893, 14.78763962], [74.11402893, 14.78707886], [74.11374664, 14.78708363], [74.11374664, 14.78652668], [74.11319733, 14.78652954], [74.11319733, 14.78625202], [74.11290741, 14.78625202], [74.11290741, 14.78597069], [74.11235809, 14.78597355], [74.11235809, 14.78569317], [74.11208344, 14.78569317], [74.11208344, 14.78486061], [74.11096954, 14.78486061], [74.11096954, 14.78458309], [74.11013794, 14.78458309], [74.11013794, 14.78486061], [74.10984802, 14.78486061], [74.10984802, 14.78514194], [74.10958099, 14.78514004], [74.10958099, 14.78708363], [74.10986328, 14.78708363], [74.10986328, 14.7881937], [74.11013794, 14.78819084], [74.11013794, 14.78903008], [74.11042023, 14.78903008], [74.11042023, 14.78985977], [74.11013794, 14.78985977], [74.11013794, 14.79041958], [74.10986328, 14.79041576], [74.10986328, 14.79069424], [74.10958099, 14.79069424], [74.10958099, 14.79097176], [74.10930634, 14.79097176], [74.10930634, 14.79143047], [74.10930634, 14.79181099], [74.10902405, 14.79180622], [74.10902405, 14.79319382], [74.10847473, 14.79319382], [74.10847473, 14.79347229], [74.10736084, 14.79347229], [74.10736084, 14.79319382], [74.10652924, 14.79319382], [74.10652924, 14.7929163], [74.10597229, 14.79292011], [74.10597229, 14.79263973], [74.10549927, 14.79263973], [74.1048584, 14.79263973], [74.1048584, 14.79236031], [74.10346985, 14.79236031], [74.10346985, 14.79263973], [74.10320282, 14.79263973], [74.10320282, 14.79236031], [74.1029129, 14.79236031], [74.1029129, 14.79263973], [74.1020813, 14.79263973], [74.1020813, 14.79292011], [74.10180664, 14.7929163], [74.10180664, 14.79347229], [74.1020813, 14.79347038], [74.1020813, 14.79375172], [74.1029129, 14.79375172], [74.1029129, 14.79403019], [74.10263824, 14.79402828], [74.10263824, 14.79419041], [74.10263824, 14.79458427], [74.10235596, 14.79458046], [74.10235596, 14.79514027], [74.1020813, 14.79514027], [74.1020813, 14.79542065], [74.10180664, 14.79541588], [74.10180664, 14.79569435], [74.10152435, 14.79569435], [74.10152435, 14.79597187], [74.10124969, 14.79596996], [74.10124969, 14.79625034], [74.10096741, 14.79625034], [74.10096741, 14.79653072], [74.10069275, 14.79652786], [74.10069275, 14.79736328], [74.10041809, 14.79736042], [74.10041809, 14.79764271], [74.1001358, 14.79763794], [74.1001358, 14.79819393], [74.09986115, 14.79819393], [74.09986115, 14.7984724], [74.09958649, 14.7984724], [74.09958649, 14.79819393], [74.0993042, 14.79819393], [74.0993042, 14.7984724], [74.09874725, 14.79846954], [74.09874725, 14.79875088], [74.09707642, 14.79875088], [74.09707642, 14.79846954], [74.0965271, 14.79846954], [74.0965271, 14.79875088], [74.09541321, 14.79875088], [74.09541321, 14.79931068], [74.09513855, 14.79931068], [74.09513855, 14.79986], [74.09487152, 14.79986], [74.09487152, 14.80014133], [74.0945816, 14.80014133], [74.0945816, 14.80042076], [74.09430695, 14.80041695], [74.09430695, 14.80097294], [74.09401703, 14.80097008], [74.09401703, 14.80125141], [74.09375, 14.80125141], [74.09375, 14.80153084], [74.09347534, 14.80152893], [74.09347534, 14.80236053], [74.09319305, 14.80236053], [74.09319305, 14.80264091], [74.0929184, 14.80263901], [74.0929184, 14.803195], [74.09263611, 14.80319023], [74.09263611, 14.80403137], [74.0929184, 14.80403137], [74.0929184, 14.80514145], [74.09319305, 14.80514145], [74.09319305, 14.80542183], [74.09347534, 14.80541706], [74.09347534, 14.80597305], [74.09401703, 14.80597115], [74.09401703, 14.80625057], [74.0945816, 14.80624866], [74.0945816, 14.80652905], [74.09625244, 14.80652046], [74.09625244, 14.80681038], [74.09680176, 14.80681038], [74.09680176, 14.80652046], [74.09764099, 14.80652046], [74.09764099, 14.80681038], [74.09986115, 14.80680466], [74.09986115, 14.80708313], [74.1001358, 14.80708313], [74.1001358, 14.80680466], [74.10041809, 14.80680466], [74.10041809, 14.80708313], [74.10151672, 14.80708122], [74.10151672, 14.80736065], [74.1020813, 14.80736065], [74.1020813, 14.80708122], [74.10236359, 14.80708313], [74.10236359, 14.80680466], [74.10263824, 14.80681038], [74.10263824, 14.80652046], [74.1029129, 14.80652905], [74.1029129, 14.80597305], [74.10346985, 14.80597305], [74.10346985, 14.80569458], [74.10430908, 14.80569458], [74.10430908, 14.80541706], [74.10458374, 14.80541706], [74.10458374, 14.80569458], [74.10514069, 14.80569458], [74.10514069, 14.80597305], [74.10542297, 14.80597115], [74.10542297, 14.80625057], [74.10624695, 14.80625057], [74.10624695, 14.80681038], [74.10791779, 14.80680466], [74.10791779, 14.80708313], [74.10847473, 14.80708313], [74.10847473, 14.80652905], [74.10930634, 14.80652905], [74.10930634, 14.80624866], [74.10984802, 14.80625057], [74.10984802, 14.80597115], [74.11042023, 14.80597305], [74.11042023, 14.80569458], [74.11069489, 14.80569458], [74.11069489, 14.80541706], [74.11208344, 14.80541706], [74.11208344, 14.80597305], [74.11235809, 14.80597115], [74.11235809, 14.80736065], [74.11264038, 14.80736065], [74.11264038, 14.80764103], [74.11319733, 14.80764103], [74.11319733, 14.80652046], [74.11347198, 14.80652905], [74.11347198, 14.80513859], [74.11402893, 14.80514145], [74.11402893, 14.80458069], [74.11430359, 14.8045826], [74.11430359, 14.80430698], [74.11458588, 14.80431175], [74.11458588, 14.80208015], [74.11402893, 14.80208302], [74.11402893, 14.80125141], [74.11374664, 14.80125141], [74.11374664, 14.80097008], [74.11347198, 14.80097294], [74.11347198, 14.80069542], [74.11319733, 14.80069542], [74.11319733, 14.80041695], [74.11290741, 14.80042076], [74.11290741, 14.80014133], [74.11264038, 14.80014133], [74.11264038, 14.79993057], [74.11264038, 14.79958153], [74.11235809, 14.79958153], [74.11235809, 14.79930687], [74.11207581, 14.79931068], [74.11207581, 14.79903126], [74.11152649, 14.79903126], [74.11152649, 14.79875088], [74.11125183, 14.79875088], [74.11125183, 14.79846954], [74.11096954, 14.7984724], [74.11096954, 14.79819393], [74.11125183, 14.79819393], [74.11125183, 14.79763794], [74.11152649, 14.79764271], [74.11152649, 14.79708004], [74.11180878, 14.79708195], [74.11180878, 14.79680634], [74.11347198, 14.7968111], [74.11347198, 14.79792118], [74.11291504, 14.79791641], [74.11291504, 14.7984724], [74.11319733, 14.79846954], [74.11319733, 14.79903126], [74.11347198, 14.79903126], [74.11347198, 14.79931068], [74.11374664, 14.79930687], [74.11374664, 14.79958153], [74.11402893, 14.79957962], [74.11402893, 14.79986], [74.11429596, 14.79986], [74.11429596, 14.80014133], [74.11458588, 14.80014133], [74.11458588, 14.80042076], [74.11486053, 14.80041695], [74.11486053, 14.80069542], [74.11513519, 14.80069542], [74.11513519, 14.80097294], [74.11541748, 14.80097008], [74.11541748, 14.80125141], [74.11569214, 14.80125141], [74.11569214, 14.80153084], [74.11597443, 14.80152893], [74.11597443, 14.80208302], [74.11624908, 14.80208302], [74.11624908, 14.80236053], [74.11736298, 14.80236053], [74.11736298, 14.80208302], [74.11763763, 14.80208302], [74.11763763, 14.80180454], [74.11846924, 14.80181122], [74.11846924, 14.80153084], [74.12014008, 14.80153084], [74.12014008, 14.80181122], [74.12041473, 14.80180454], [74.12041473, 14.80208302], [74.12097168, 14.80208302], [74.12097168, 14.80236053], [74.12124634, 14.80236053], [74.12124634, 14.80264091], [74.12152863, 14.80263901], [74.12152863, 14.803195], [74.12178802, 14.80319023], [74.12178802, 14.80375099], [74.12207794, 14.80375099], [74.12207794, 14.80431175], [74.12236023, 14.80430698], [74.12236023, 14.8045826], [74.12264252, 14.80458069], [74.12264252, 14.80486107], [74.12346649, 14.80486107], [74.12346649, 14.80542183], [74.12374878, 14.80541706], [74.12374878, 14.80569458], [74.12403107, 14.8056879], [74.12403107, 14.80625057], [74.12430573, 14.80624866], [74.12430573, 14.80652905], [74.12458038, 14.80652046], [74.12458038, 14.80764103], [74.12431335, 14.80764103], [74.12431335, 14.80791855], [74.12458038, 14.80791664], [74.12458038, 14.80819511], [74.12431335, 14.8081913], [74.12431335, 14.80931187], [74.12458038, 14.80930519], [74.12458038, 14.80986118], [74.12486267, 14.80986118], [74.12486267, 14.81097126], [74.12541962, 14.81097126], [74.12541962, 14.81180954], [74.12568665, 14.81180954], [74.12568665, 14.81374931], [74.12596893, 14.81374931], [74.12596893, 14.81597233], [74.12625122, 14.81597233], [74.12625122, 14.81986237], [74.12596893, 14.81986046], [74.12596893, 14.82459068], [74.12568665, 14.82459068], [74.12568665, 14.82514095], [74.12541962, 14.82513809], [74.12541962, 14.82569408], [74.12513733, 14.82569027], [74.12513733, 14.82625103], [74.12541962, 14.82625103], [74.12541962, 14.82681084], [74.12569427, 14.82680416], [74.12569427, 14.82736015], [74.12541962, 14.82736015], [74.12541962, 14.82819462], [74.12513733, 14.82818985], [74.12513733, 14.82931137], [74.12484741, 14.82931137], [74.12484741, 14.8318119], [74.12458038, 14.83180523], [74.12458038, 14.83736134], [74.12541962, 14.83736134], [74.12541962, 14.83749104], [74.12541962, 14.83764172], [74.12568665, 14.83764172], [74.12568665, 14.83792019], [74.12596893, 14.83791733], [74.12596893, 14.8381958], [74.12625122, 14.8381958], [74.12625122, 14.83847141], [74.12652588, 14.83847141], [74.12652588, 14.83903027], [74.12680817, 14.83903027], [74.12680817, 14.83930969], [74.12708282, 14.83930969], [74.12708282, 14.83959007], [74.12735748, 14.83959007], [74.12735748, 14.83986187], [74.12792206, 14.83986187], [74.12792206, 14.84014034], [74.1295929, 14.84014034], [74.1295929, 14.83986187], [74.13041687, 14.83986187], [74.13041687, 14.84015083], [74.13041687, 14.8423624], [74.13069153, 14.8423624], [74.13069153, 14.8444109], [74.13069153, 14.84458447], [74.13091278, 14.8445816], [74.13098145, 14.84624958], [74.12821198, 14.84624958], [74.12821198, 14.84652996], [74.12792206, 14.84652996], [74.12792206, 14.84681129], [74.12763977, 14.84680557], [74.12763977, 14.84708405], [74.12569427, 14.84708405], [74.12569427, 14.84736156], [74.12458038, 14.84735966], [74.12458038, 14.84764004], [74.12431335, 14.84764004], [74.12431335, 14.84792137], [74.12374878, 14.84791565], [74.12374878, 14.84819412], [74.12347412, 14.84819412], [74.12347412, 14.84847164], [74.12291718, 14.84846973], [74.12291718, 14.84876156], [74.12264252, 14.84876156], [74.12264252, 14.84903145], [74.12236023, 14.84903145], [74.12236023, 14.84931087], [74.12180328, 14.84930611], [74.12180328, 14.84958363], [74.12124634, 14.84958363], [74.12124634, 14.84986019], [74.12097168, 14.84986019], [74.12097168, 14.85013962], [74.11985779, 14.85013962], [74.11985779, 14.85042095], [74.11930847, 14.85041618], [74.11930847, 14.8506937], [74.11875153, 14.8506937], [74.11875153, 14.85097218], [74.11818695, 14.85097027], [74.11818695, 14.85124969], [74.11763763, 14.85124969], [74.11763763, 14.85153103], [74.11715698, 14.85152817], [74.11708069, 14.85152817], [74.11708069, 14.85181999], [74.11653137, 14.85180664], [74.11653137, 14.85208225], [74.11597443, 14.85208225], [74.11598206, 14.85235977], [74.11541748, 14.85235977], [74.11541748, 14.85264111], [74.11486053, 14.85264111], [74.11486053, 14.85292053], [74.11458588, 14.85291576], [74.11458588, 14.85319424], [74.11402893, 14.85319424], [74.11402893, 14.85291576], [74.11429596, 14.85292053], [74.11429596, 14.85264111], [74.11402893, 14.85264111], [74.11402893, 14.85235977], [74.11429596, 14.85235977], [74.11429596, 14.85208035], [74.11458588, 14.85208225], [74.11458588, 14.85180664], [74.11486053, 14.85181999], [74.11486053, 14.85153103], [74.11541748, 14.85153103], [74.11541748, 14.85124969], [74.11569214, 14.85124969], [74.11569214, 14.85097027], [74.11597443, 14.85097218], [74.11597443, 14.8506937], [74.11624908, 14.8506937], [74.11624908, 14.85041618], [74.11680603, 14.85042095], [74.11680603, 14.85013962], [74.11708069, 14.85013962], [74.11708069, 14.84986019], [74.11763763, 14.84986019], [74.11763763, 14.84976196], [74.11763763, 14.84958363], [74.11791992, 14.84958363], [74.11791992, 14.84930611], [74.11846924, 14.84931087], [74.11846924, 14.84903145], [74.11875153, 14.84903145], [74.11875153, 14.84876156], [74.11904144, 14.84876156], [74.11904144, 14.84846973], [74.11958313, 14.84847164], [74.11958313, 14.84819412], [74.12014008, 14.84819412], [74.12014008, 14.84791565], [74.12069702, 14.84792137], [74.12069702, 14.84764004], [74.12178802, 14.84764004], [74.12178802, 14.84735966], [74.12236023, 14.84735966], [74.12236023, 14.84708023], [74.12319183, 14.84708405], [74.12319183, 14.84680557], [74.12374878, 14.84681129], [74.12374878, 14.84652996], [74.12431335, 14.84652996], [74.12431335, 14.84624958], [74.12484741, 14.84624958], [74.12484741, 14.84597015], [74.12458038, 14.84597206], [74.12458038, 14.8451376], [74.12403107, 14.84514046], [74.12403107, 14.84486198], [74.12291718, 14.84486198], [74.12291718, 14.8445816], [74.12264252, 14.84458447], [74.12264252, 14.84430599], [74.12207794, 14.84430981], [74.12207794, 14.84403038], [74.1204071, 14.84403038], [74.1204071, 14.84375191], [74.11923981, 14.84375191], [74.11680603, 14.84375191], [74.11680603, 14.84403038], [74.11624908, 14.84403038], [74.11624908, 14.84430981], [74.11541748, 14.84430599], [74.11541748, 14.84458447], [74.11486053, 14.8445816], [74.11486053, 14.84486198], [74.11402893, 14.84486198], [74.11402893, 14.84514046], [74.11347198, 14.84514046], [74.11347198, 14.84542274], [74.11319733, 14.84541798], [74.11319733, 14.84569359], [74.11291504, 14.84569359], [74.11291504, 14.84597206], [74.11264038, 14.84597015], [74.11264038, 14.84652996], [74.11235809, 14.84652996], [74.11235809, 14.84681129], [74.11207581, 14.84681129], [74.11207581, 14.84764004], [74.11180878, 14.84764004], [74.11180878, 14.84876156], [74.11152649, 14.84876156], [74.11152649, 14.85181999], [74.11180878, 14.85180664], [74.11180878, 14.85597324], [74.11152649, 14.85597038], [74.11152649, 14.8587513], [74.11125183, 14.8587513], [74.11125183, 14.8595829], [74.11096954, 14.85958099], [74.11096954, 14.86041927], [74.11068726, 14.86041927], [74.11068726, 14.86125088], [74.11042023, 14.86125088], [74.11042023, 14.86180973], [74.11013794, 14.86180973], [74.11013794, 14.86264229], [74.10986328, 14.86263943], [74.10986328, 14.86347103], [74.10958099, 14.86347103], [74.10958099, 14.86403179], [74.10930634, 14.86402702], [74.10930634, 14.86458302], [74.10901642, 14.86458111], [74.10901642, 14.86514187], [74.10874939, 14.86513901], [74.10874939, 14.86569309], [74.1084671, 14.86569118], [74.1084671, 14.86653042], [74.10819244, 14.86653042], [74.10819244, 14.86736202], [74.10791779, 14.86736202], [74.10791779, 14.86819267], [74.10764313, 14.86818886], [74.10764313, 14.86903], [74.10736084, 14.86903], [74.10736084, 14.8698597], [74.10708618, 14.8698616], [74.10708618, 14.87069416], [74.10680389, 14.87069416], [74.10681152, 14.87125015], [74.10652924, 14.87125015], [74.10652924, 14.87152958], [74.10624695, 14.87152958], [74.10624695, 14.87180996], [74.10597229, 14.87180614], [74.10597229, 14.87236214], [74.10569763, 14.87236023], [74.10569763, 14.87263966], [74.10542297, 14.87263966], [74.10542297, 14.87292957], [74.10514069, 14.87291622], [74.10514069, 14.87319374], [74.1048584, 14.87319374], [74.1048584, 14.87347221], [74.10457611, 14.87347031], [74.10457611, 14.87403011], [74.10430908, 14.87403011], [74.10430908, 14.87431145], [74.10404205, 14.87431145], [74.10404205, 14.87542057], [74.10375214, 14.87542057], [74.10375214, 14.87681103], [74.10346985, 14.87680626], [74.10346985, 14.87708378], [74.10319519, 14.87708378], [74.10319519, 14.87736034], [74.1029129, 14.87736034], [74.1029129, 14.87764072], [74.10263824, 14.87764072], [74.10263824, 14.8779211], [74.10236359, 14.87791634], [74.10236359, 14.87819386], [74.1020813, 14.87819386], [74.1020813, 14.87847233], [74.10180664, 14.87847233], [74.10180664, 14.87874985], [74.10151672, 14.87874126], [74.10151672, 14.87903118], [74.10124969, 14.87903118], [74.10124969, 14.87931061], [74.10069275, 14.87930679], [74.10069275, 14.87958241], [74.10041809, 14.87957954], [74.10041809, 14.87985992], [74.1001358, 14.87985992], [74.1001358, 14.88014126], [74.09958649, 14.88014126], [74.09958649, 14.88042068], [74.09929657, 14.88042068], [74.09929657, 14.88125134], [74.09958649, 14.88125134], [74.09958649, 14.88236141], [74.09986115, 14.88236141], [74.09986115, 14.88319492], [74.1001358, 14.88319492], [74.1001358, 14.88708305], [74.10041809, 14.88708305], [74.10041809, 14.89097118], [74.1001358, 14.89097118], [74.1001358, 14.89153194], [74.09986115, 14.89152718], [74.09986115, 14.89186001], [74.09986115, 14.89208317], [74.09958649, 14.89208126], [74.09958649, 14.89264202], [74.0993042, 14.89263916], [74.0993042, 14.89319324], [74.09902954, 14.89319324], [74.09902954, 14.89374924], [74.09874725, 14.8937397], [74.09874725, 14.89431], [74.0984726, 14.89430618], [74.0984726, 14.89486217], [74.09790802, 14.89485931], [74.09790802, 14.89513969], [74.09764099, 14.89513969], [74.09764099, 14.89542007], [74.0973587, 14.89541531], [74.0973587, 14.89565945], [74.10331726, 14.90147972], [74.10417175, 14.90375042], [74.11308289, 14.91116047], [74.11733246, 14.9096117], [74.1227417, 14.91264057], [74.12652588, 14.91321087], [74.13204193, 14.91265011], [74.13342285, 14.91594791], [74.13622284, 14.91966057], [74.13939667, 14.9204607], [74.14570618, 14.91743183], [74.14922333, 14.91852093], [74.15389252, 14.91726971], [74.16339111, 14.91325188], [74.16982269, 14.90927029], [74.17539215, 14.90891933], [74.17735291, 14.91320038], [74.17516327, 14.91615105], [74.17383575, 14.91794014], [74.16596222, 14.9367609], [74.16609955, 14.93944168], [74.16966248, 14.94218063], [74.16989899, 14.94729996], [74.17215729, 14.95100975], [74.18036652, 14.95304966], [74.18656158, 14.95338058], [74.1902771, 14.95171928], [74.19248199, 14.94500923], [74.19741821, 14.94326973], [74.2041626, 14.93785095], [74.20405579, 14.9321003], [74.20308685, 14.92742062], [74.21183777, 14.9214201], [74.2192688, 14.93138027], [74.22471619, 14.94134045], [74.24167633, 14.94645023], [74.24386597, 14.95748997], [74.24639893, 14.95866108], [74.25100708, 14.9608202], [74.25659943, 14.95842171], [74.2620697, 14.95755196], [74.26434326, 14.96324921], [74.2665863, 14.96682072], [74.27011871, 14.96664143], [74.27095032, 14.97153187], [74.27391052, 14.97522163], [74.27095795, 14.98042965], [74.26171112, 14.9907608], [74.26644135, 14.99295139], [74.27065277, 14.99489117], [74.27159119, 14.9977417], [74.27126312, 14.9977417], [74.27102661, 14.99880791], [74.27291107, 15.00146103], [74.27184296, 15.00249195], [74.27641296, 15.00964069], [74.28186035, 15.01557159], [74.28978729, 15.02161121], [74.28936768, 15.02656174], [74.2890625, 15.0301218], [74.29310608, 15.03374958], [74.30233765, 15.03985977], [74.30120087, 15.04407024], [74.29499054, 15.05429173], [74.29525757, 15.06269264], [74.28900909, 15.0658493], [74.28721619, 15.06936073], [74.28379059, 15.09401035], [74.2783432, 15.09589958], [74.28106689, 15.10182953], [74.28572845, 15.10373116], [74.28824615, 15.10558128], [74.2906189, 15.11663055], [74.29309082, 15.11996269], [74.29144287, 15.12329865], [74.289711, 15.1299696], [74.29122925, 15.13538074], [74.28956604, 15.1431303], [74.29258728, 15.14767933], [74.29782867, 15.14630985], [74.30142975, 15.14988136], [74.31086731, 15.16203117], [74.31813049, 15.17533016], [74.32190704, 15.18406963], [74.31697083, 15.1910696], [74.31577301, 15.19631195], [74.31555939, 15.20321274], [74.31445313, 15.20561028], [74.31163025, 15.20705128], [74.31066132, 15.20895195], [74.31005859, 15.2134304], [74.30670929, 15.21899986], [74.3066864, 15.2232008], [74.30213165, 15.22814178], [74.29427338, 15.23198032], [74.27867126, 15.23719025], [74.27075195, 15.2385006], [74.26351929, 15.24188137], [74.26174927, 15.24372196], [74.25926208, 15.24999046], [74.25752258, 15.25762939], [74.26793671, 15.25839138], [74.27024078, 15.26093197], [74.27275085, 15.26777172], [74.27661896, 15.27444935], [74.28295898, 15.28129959], [74.28914642, 15.27907181], [74.29554749, 15.28310966], [74.30002594, 15.28230095], [74.30230713, 15.28586102], [74.30980682, 15.28323078], [74.31841278, 15.28192043], [74.33412933, 15.28286171], [74.34165192, 15.2929306], [74.34044647, 15.29680061], [74.32797241, 15.31326962], [74.32334137, 15.3295908], [74.32840729, 15.3434], [74.32595062, 15.34724045], [74.32261658, 15.35725021], [74.32364655, 15.36203194], [74.32859802, 15.36547089], [74.32836914, 15.3672514], [74.31282806, 15.37488174], [74.30568695, 15.38050175], [74.28996277, 15.38121986], [74.28624725, 15.38260078], [74.28263855, 15.38862038], [74.2845459, 15.40151119], [74.28144836, 15.4090414], [74.27735901, 15.41486931], [74.27561951, 15.4239006], [74.2826767, 15.43329144], [74.27999878, 15.43593121], [74.28295898, 15.43748093], [74.28251648, 15.44312096], [74.2798996, 15.45076084], [74.27255249, 15.46523952], [74.2563324, 15.48952007], [74.25724792, 15.49676132], [74.26082611, 15.50084114], [74.2681427, 15.50592136], [74.2818985, 15.51295185], [74.28375244, 15.51945019], [74.28279877, 15.52054119], [74.28727722, 15.52600002], [74.28559875, 15.5341711], [74.28292847, 15.54157066], [74.27894592, 15.54870033], [74.27258301, 15.55426121], [74.26988983, 15.56115055], [74.26763916, 15.56343937], [74.26457977, 15.56079102], [74.25431061, 15.56583023], [74.25441742, 15.57250118], [74.25741577, 15.57549953], [74.25637054, 15.58256054], [74.26515961, 15.59016037], [74.26545715, 15.60160065], [74.26854706, 15.60958862], [74.26747131, 15.61704922], [74.26249695, 15.62291145], [74.25942993, 15.62446117], [74.25435638, 15.62313175], [74.25253296, 15.6238203], [74.2545166, 15.62961197], [74.25723267, 15.63393974], [74.25647736, 15.64680099], [74.25525665, 15.65421009], [74.24504089, 15.66563129], [74.24191284, 15.66585922], [74.23683929, 15.66189098], [74.23158264, 15.66652012], [74.22405243, 15.6588707], [74.2284317, 15.65445042], [74.22879791, 15.65296078], [74.22409058, 15.65031147], [74.21324921, 15.64902973], [74.20986176, 15.65413094], [74.21196747, 15.65849972], [74.21154022, 15.66097927], [74.19632721, 15.66491127], [74.19447327, 15.67214012], [74.19811249, 15.67365074], [74.19769287, 15.67893028], [74.19013214, 15.68098068], [74.18302917, 15.67735004], [74.17867279, 15.6714201], [74.17543793, 15.67016029], [74.1734314, 15.65205193], [74.16593933, 15.65237999], [74.1632309, 15.64859009], [74.15497589, 15.64977074], [74.14685059, 15.64866066], [74.14277649, 15.64711094], [74.12896729, 15.65023994], [74.12602997, 15.65028954], [74.12136841, 15.65367031], [74.11205292, 15.6550312], [74.10453033, 15.65920162], [74.09802246, 15.6659708], [74.0965271, 15.6708498], [74.10056305, 15.67234993], [74.10624695, 15.67064095], [74.11752319, 15.67078018], [74.12700653, 15.67374039], [74.13359833, 15.67840099], [74.13887787, 15.68622971], [74.14042664, 15.69456005], [74.13889313, 15.69903183], [74.1415329, 15.70036125], [74.13891602, 15.70634079], [74.13553619, 15.70925236], [74.13475037, 15.71603203], [74.13062286, 15.71792126], [74.13485718, 15.72218132], [74.14045715, 15.7216711], [74.14186859, 15.72317886], [74.14296722, 15.72719097], [74.14737701, 15.73007107], [74.1505127, 15.7317009], [74.1553421, 15.73228168], [74.16013336, 15.73434925], [74.16226959, 15.74207115], [74.1676712, 15.74925041], [74.17115021, 15.74995041], [74.19706726, 15.75022125], [74.20439911, 15.7534008], [74.2113266, 15.75858974], [74.2146225, 15.76599121], [74.21570587, 15.77387047], [74.21740723, 15.77876091], [74.22247314, 15.78170109], [74.22734833, 15.78567123], [74.23549652, 15.7868309], [74.23892975, 15.78454018], [74.24034119, 15.78075027], [74.23516846, 15.75961113], [74.23523712, 15.75397015], [74.23898315, 15.75214005], [74.24386597, 15.74440002], [74.25006866, 15.74118042], [74.25892639, 15.74339104], [74.2660675, 15.74702072], [74.27086639, 15.75191021], [74.2740097, 15.75312042], [74.28494263, 15.74331093], [74.29216766, 15.73931122], [74.31299591, 15.7482996], [74.31465149, 15.75214863], [74.31864929, 15.75341034], [74.32408142, 15.75652981], [74.32495117, 15.76130009], [74.32756805, 15.76820087], [74.32975006, 15.77038002], [74.33454132, 15.76767921], [74.34227753, 15.76552105], [74.34677124, 15.76311016], [74.35093689, 15.76336002], [74.36485291, 15.77365112], [74.36789703, 15.7816], [74.37084198, 15.78218174], [74.37551117, 15.79671955], [74.37580109, 15.80120087], [74.37454987, 15.80452156], [74.37400818, 15.81044102], [74.36915588, 15.81216145], [74.36637115, 15.81549072], [74.3707428, 15.81722069], [74.37336731, 15.82583237], [74.37454987, 15.82750034], [74.38626862, 15.83326244], [74.38944244, 15.83631134], [74.38931274, 15.84414005], [74.38741302, 15.8471117], [74.3537674, 15.84810066], [74.3463974, 15.84934998], [74.34453583, 15.85205078], [74.35340118, 15.85573196], [74.35295868, 15.85924053], [74.3640976, 15.87016106], [74.36702728, 15.87109089], [74.36743164, 15.87321854], [74.36997986, 15.87568092], [74.3706131, 15.88000202], [74.37052155, 15.8903904], [74.37412262, 15.89161015], [74.3744812, 15.88994122], [74.37277985, 15.88768959], [74.3765564, 15.8849411], [74.38313293, 15.87776184], [74.38556671, 15.87323093], [74.38794708, 15.86394119], [74.3884964, 15.8572197], [74.39228821, 15.85744953], [74.39343262, 15.8517704], [74.40312195, 15.84895992], [74.4065094, 15.8519001], [74.41158295, 15.85259056], [74.41221619, 15.85763931], [74.39919281, 15.87434959], [74.40254974, 15.87826061], [74.40164185, 15.88726997], [74.39930725, 15.89577103], [74.39836121, 15.8977108], [74.39234924, 15.89926147], [74.39186859, 15.90115929], [74.40203857, 15.9110508], [74.41226959, 15.92520046], [74.43522644, 15.95116997], [74.44229126, 15.9654789], [74.44394684, 15.9743309], [74.4499588, 15.98323059], [74.44847107, 15.9864006], [74.44843292, 15.98829079], [74.45017242, 15.99260139], [74.44966888, 15.99853134], [74.45336914, 16.00580978], [74.45643616, 16.00890923], [74.46391296, 16.02256012], [74.46710205, 16.03026962], [74.467659, 16.03364944], [74.47027588, 16.0405407], [74.46795654, 16.04669952], [74.46383667, 16.0477314], [74.45587158, 16.05216026], [74.44803619, 16.05240059], [74.44048309, 16.05702019], [74.4363327, 16.05673027], [74.43213654, 16.05513191], [74.4229126, 16.05319023], [74.4155426, 16.05105972], [74.41121674, 16.04901123], [74.40960693, 16.04709816], [74.40931702, 16.04533005], [74.39607239, 16.03960037], [74.3900528, 16.03512955], [74.37858582, 16.03662109], [74.37822723, 16.03926086], [74.37888336, 16.04339981], [74.38173676, 16.05356979], [74.38014221, 16.05476761], [74.37075043, 16.05101967], [74.36815643, 16.05295944], [74.37098694, 16.05957031], [74.37510681, 16.06336975], [74.38008118, 16.06958008], [74.3806076, 16.07302094], [74.3795929, 16.07682037], [74.3809967, 16.07826042], [74.38680267, 16.07809067], [74.39045715, 16.07992935], [74.39724731, 16.07838821], [74.39830017, 16.08011818], [74.39731598, 16.08712959], [74.40406036, 16.09097862], [74.40760803, 16.09069824], [74.41520691, 16.09181976], [74.41607666, 16.09600067], [74.41845703, 16.10089111], [74.42276001, 16.10256958], [74.4345932, 16.1106205], [74.43795013, 16.10816002], [74.44452667, 16.10518074], [74.45491028, 16.10267067], [74.46000671, 16.102911], [74.4645462, 16.10211182], [74.47796631, 16.09189987], [74.47891235, 16.08789063], [74.4818573, 16.08696938], [74.48908997, 16.08732033], [74.490448, 16.09037018], [74.49279785, 16.09283829], [74.49263, 16.09553909], [74.49349976, 16.09859276], [74.49640656, 16.10157967], [74.49710846, 16.11236954], [74.49095154, 16.1420002], [74.48710632, 16.1430912], [74.48580933, 16.14698982], [74.48996735, 16.14722252], [74.49466705, 16.15504074], [74.49532318, 16.16900063], [74.49781799, 16.18133926], [74.50177002, 16.18543053], [74.50908661, 16.18783951], [74.51287842, 16.18826294], [74.51288605, 16.18939972], [74.51252747, 16.19584084], [74.51081085, 16.19881821], [74.51322937, 16.19922066], [74.51329803, 16.2012291], [74.5031662, 16.2115612], [74.50211334, 16.21413994], [74.50296021, 16.21622086], [74.50772095, 16.22128105], [74.5083313, 16.22294044], [74.50311279, 16.23104095], [74.49507141, 16.23596954], [74.49482727, 16.23801994], [74.48412323, 16.2467308], [74.48079681, 16.24432945], [74.47606659, 16.23903084], [74.47318268, 16.23851967], [74.46343231, 16.24183083], [74.4614563, 16.24377823], [74.46122742, 16.24843025], [74.44277954, 16.2495594], [74.44184113, 16.25415039], [74.44094086, 16.25266075], [74.4363327, 16.25476837], [74.42253113, 16.2574501], [74.42082214, 16.26387978], [74.42159271, 16.27145958], [74.4212265, 16.28059006], [74.41802216, 16.28092957], [74.40075684, 16.27625084], [74.39126587, 16.27560043], [74.39038086, 16.29024124], [74.38742065, 16.29034805], [74.38006592, 16.2935009], [74.37377167, 16.29031944], [74.36960602, 16.29072189], [74.36257172, 16.28713989], [74.35853577, 16.28880119], [74.35611725, 16.29092026], [74.35459137, 16.28976059], [74.35328674, 16.2918396], [74.35169983, 16.28820992], [74.3603363, 16.28190994], [74.35986328, 16.27960968], [74.35514069, 16.27449036], [74.35212708, 16.27448273], [74.35074615, 16.27625847], [74.3493576, 16.27506065], [74.34945679, 16.27326965], [74.34390259, 16.27212143], [74.34041595, 16.2675705], [74.33705139, 16.26572037], [74.33383942, 16.26807022], [74.33065796, 16.27293968], [74.32868958, 16.27943039], [74.32932281, 16.28106117], [74.33215332, 16.28409958], [74.33178711, 16.2861805], [74.33637238, 16.29017067], [74.34268188, 16.28877068], [74.34871674, 16.29146957], [74.34484863, 16.30326843], [74.34115601, 16.30282021], [74.34012604, 16.30398941], [74.34233093, 16.30509186], [74.34059143, 16.31162071], [74.33210754, 16.3107605], [74.33101654, 16.31502151], [74.33152008, 16.31641006], [74.33569336, 16.31500053], [74.3400116, 16.31693077], [74.33727264, 16.32339287], [74.33335876, 16.32374191], [74.32993317, 16.3223629], [74.32302094, 16.32512283], [74.32401276, 16.32742119], [74.32727814, 16.32920074], [74.32911682, 16.3325901], [74.32480621, 16.33666992], [74.32345581, 16.33989143], [74.32823181, 16.34110069], [74.33439636, 16.34052277], [74.33156586, 16.34649086], [74.32370758, 16.35361099], [74.33152008, 16.35556984], [74.33223724, 16.35695076], [74.32762909, 16.36811066], [74.32776642, 16.37034035], [74.32546234, 16.37924957], [74.33255005, 16.3755703], [74.33474731, 16.38285828], [74.33500671, 16.38871956], [74.33596039, 16.38964272], [74.34033203, 16.3909626], [74.34306335, 16.39067078], [74.34577179, 16.38952065], [74.34771729, 16.38601112], [74.34858704, 16.38038254], [74.35108185, 16.37676048], [74.35189819, 16.36630058], [74.36165619, 16.36474991], [74.35961151, 16.37882042], [74.36868286, 16.3911705], [74.36911011, 16.39432907], [74.36782074, 16.39846992], [74.36457062, 16.4032383], [74.35954285, 16.40398979], [74.34916687, 16.4039402], [74.34928131, 16.39940071], [74.34265137, 16.40049171], [74.34194183, 16.40521049], [74.33818054, 16.41337013], [74.33728027, 16.42020988], [74.34375, 16.42554092], [74.34052277, 16.43297958], [74.34062195, 16.43617058], [74.34223175, 16.43956947], [74.34246063, 16.44232941], [74.33904266, 16.44486046], [74.33876038, 16.44664192], [74.33998871, 16.44812965], [74.33886719, 16.45216179], [74.33555603, 16.45308113], [74.33052826, 16.45279121], [74.32193756, 16.45004082], [74.31482697, 16.45319939], [74.30709076, 16.45959091], [74.30464935, 16.46079063], [74.30239868, 16.46108055], [74.30139923, 16.45906067], [74.29631805, 16.45901108], [74.2964325, 16.46671104], [74.29483795, 16.47435188], [74.2975769, 16.48161125], [74.30055237, 16.49963188], [74.29989624, 16.50263023], [74.28894806, 16.50378036], [74.28330994, 16.49603271], [74.28051758, 16.48936081], [74.28099823, 16.48579025], [74.28253937, 16.48257065], [74.27842712, 16.47963905], [74.26877594, 16.47603035], [74.26516724, 16.48240089], [74.26452637, 16.48545074], [74.262146, 16.48867035], [74.26008606, 16.49090767], [74.25315857, 16.49488068], [74.25570679, 16.49677086], [74.26313019, 16.49895287], [74.27864075, 16.50102043], [74.28575897, 16.50337029], [74.28668976, 16.50677109], [74.28440094, 16.51647949], [74.28190613, 16.52055168], [74.27662659, 16.52061081], [74.2755127, 16.52515984], [74.27197266, 16.5334301], [74.27155304, 16.53866005], [74.27636719, 16.54453278], [74.28431702, 16.54309273], [74.28822327, 16.53947067], [74.28672791, 16.52940941], [74.28713226, 16.52732086], [74.28955841, 16.52526283], [74.28961945, 16.52256966], [74.29483795, 16.52929115], [74.29447937, 16.53154182], [74.29762268, 16.53193092], [74.30692291, 16.52917099], [74.30892181, 16.52399826], [74.30845642, 16.52187157], [74.31157684, 16.50692749], [74.31346893, 16.50325966], [74.31411743, 16.50209808], [74.32145691, 16.50267029], [74.32390594, 16.50629807], [74.32267761, 16.51900101], [74.3232193, 16.5322094], [74.32216644, 16.53905106], [74.32222748, 16.54450035], [74.32377625, 16.55146027], [74.32940674, 16.55347061], [74.33215332, 16.55369949], [74.34020233, 16.55013275], [74.34612274, 16.54644966], [74.35507202, 16.55311012], [74.35974884, 16.55368996], [74.36308289, 16.55620193], [74.36561584, 16.55706978], [74.36923218, 16.55327034], [74.36287689, 16.5485611], [74.36464691, 16.54368019], [74.36258698, 16.53874016], [74.36611938, 16.53763962], [74.37110138, 16.53765106], [74.38543701, 16.52740288], [74.3899231, 16.5279007], [74.39289856, 16.53107071], [74.39565277, 16.53567123], [74.39550018, 16.55952263], [74.40113068, 16.56088829], [74.40077209, 16.56347275], [74.39839935, 16.56542969], [74.40120697, 16.57094002], [74.40216064, 16.57472992], [74.40348053, 16.5786705], [74.41371918, 16.58023834], [74.42228699, 16.58350182], [74.42883301, 16.58272934], [74.43354034, 16.59436035], [74.44081879, 16.59869194], [74.44698334, 16.60033989], [74.47245789, 16.60481071], [74.47080231, 16.61495018], [74.47136688, 16.6217804], [74.46981049, 16.62347984], [74.46446991, 16.63398933], [74.46283722, 16.64448929], [74.46518707, 16.64689827], [74.46479797, 16.65295029], [74.47013855, 16.65518951], [74.47738647, 16.66077995], [74.4813385, 16.6540699], [74.48587036, 16.6391201], [74.48983765, 16.63607025], [74.49178314, 16.63233948], [74.49550629, 16.62767029], [74.49800873, 16.62664032], [74.50167084, 16.62713814], [74.51029205, 16.63145065], [74.53009033, 16.63060951], [74.55143738, 16.63321114], [74.54937744, 16.61552048], [74.55024719, 16.60902023], [74.54985046, 16.59218025], [74.55459595, 16.59242058], [74.56555939, 16.59037971], [74.56981659, 16.58122063], [74.56510162, 16.57463074], [74.55970001, 16.57137108], [74.55908966, 16.56710815], [74.55966949, 16.5597496], [74.56220245, 16.55803108], [74.56552887, 16.55779076], [74.56907654, 16.55639839], [74.5740509, 16.55196953], [74.58152008, 16.55183983], [74.58152008, 16.55500031], [74.59195709, 16.55554962], [74.59253693, 16.55727005], [74.5916214, 16.55883026], [74.59179688, 16.56072044], [74.59335327, 16.56382942], [74.59588623, 16.56439018], [74.60484314, 16.56214142], [74.61699677, 16.56797028], [74.62264252, 16.57364082], [74.62438965, 16.57755089], [74.62393951, 16.58192062], [74.62695313, 16.58093071], [74.63066101, 16.57765007], [74.6363678, 16.57574081], [74.64051819, 16.5819397], [74.63938141, 16.59435272], [74.63974762, 16.59953117], [74.64113617, 16.60469055], [74.64280701, 16.60677147], [74.64771271, 16.60807037], [74.65174866, 16.60697937], [74.66387177, 16.60107994], [74.66882324, 16.60268021], [74.67529297, 16.60598946], [74.67855072, 16.60655975], [74.69037628, 16.60445976], [74.69338226, 16.60727119], [74.69462585, 16.61082077], [74.69431305, 16.61519051], [74.69122314, 16.61814117], [74.68531036, 16.61988068], [74.67386627, 16.62845993], [74.66600037, 16.62872124], [74.66304779, 16.63216972], [74.6605072, 16.63758087], [74.66880035, 16.65555191], [74.67173767, 16.66353035], [74.69610596, 16.67498016], [74.69458008, 16.67864037], [74.68727875, 16.67901039], [74.68752289, 16.68166161], [74.68895721, 16.68412018], [74.69561005, 16.68583107], [74.69503784, 16.69244194], [74.69593811, 16.71054077], [74.69819641, 16.71520042], [74.70783234, 16.7130909], [74.72244263, 16.71329117], [74.73661804, 16.71583939], [74.74820709, 16.72212029], [74.75409698, 16.72619057], [74.75614166, 16.72962952], [74.76381683, 16.73680115], [74.76940918, 16.73946953], [74.7750473, 16.74077988], [74.77555847, 16.74399948], [74.77900696, 16.74859047], [74.79110718, 16.74814987], [74.80040741, 16.74565125], [74.80410767, 16.75076294], [74.8503418, 16.76032066], [74.85497284, 16.77076912], [74.86836243, 16.77108002], [74.89263916, 16.76869011], [74.90701294, 16.76979065], [74.9238205, 16.76995087], [74.91586304, 16.78568077], [74.91581726, 16.81022072], [74.91306305, 16.83074951], [74.91330719, 16.84144974], [74.91195679, 16.85593987], [74.92778778, 16.86334991], [74.9315033, 16.86954117], [74.93708038, 16.86916161], [74.93984985, 16.87232018], [74.93966675, 16.87652016], [74.94513702, 16.87712288], [74.94861603, 16.88009071], [74.95606995, 16.87729073], [74.96409607, 16.8778801], [74.96726227, 16.90538025], [74.95284271, 16.90648079], [74.94803619, 16.90917015], [74.94407654, 16.91327095], [74.9382019, 16.91646957], [74.93694305, 16.92073059], [74.92703247, 16.92562294], [74.9285202, 16.93520164], [74.93839264, 16.94099045], [74.94834137, 16.93581963], [74.95243073, 16.93622017], [74.95453644, 16.93000031], [74.95802307, 16.92914009], [74.95999908, 16.9329319], [74.96671295, 16.93564987], [74.96949768, 16.93591118], [74.97528839, 16.93460083], [74.98142242, 16.93061066], [74.98581696, 16.92901993], [74.99449158, 16.93503952], [74.99954224, 16.94189835], [75.00370026, 16.94582748], [75.01140594, 16.94258118], [75.03029633, 16.94153023], [75.03011322, 16.93114281], [75.03190613, 16.92567062], [75.03449249, 16.92873955], [75.04535675, 16.93425941], [75.04814911, 16.93871117], [75.05078888, 16.93966103], [75.05523682, 16.93885994], [75.0654068, 16.93926048], [75.08294678, 16.94659805], [75.09041595, 16.94865036], [75.09414673, 16.94722939], [75.0947113, 16.92115021], [75.09796906, 16.91386986], [75.10692596, 16.9095211], [75.11875916, 16.90997124], [75.12200165, 16.90723038], [75.1235733, 16.90043831], [75.12763214, 16.89718056], [75.13839722, 16.89292145], [75.13710785, 16.88459969], [75.13838959, 16.8782692], [75.14112854, 16.87354088], [75.15052795, 16.86940956], [75.16438293, 16.86557961], [75.17175293, 16.86479759], [75.18084717, 16.86751175], [75.18965912, 16.87350082], [75.19252014, 16.86955833], [75.18900299, 16.86189842], [75.18319702, 16.84204102], [75.18828583, 16.84089088], [75.21585846, 16.84033966], [75.23001099, 16.84091949], [75.23291016, 16.84554291], [75.23565674, 16.85419083], [75.24099731, 16.86296082], [75.24344635, 16.86449051], [75.24867249, 16.86452866], [75.25797272, 16.86213112], [75.26830292, 16.86086082], [75.28277588, 16.87424088], [75.28565216, 16.87879944], [75.28749847, 16.88321114], [75.29177856, 16.90113831], [75.28557587, 16.90943146], [75.28359985, 16.94294167], [75.28462219, 16.95355034], [75.28843689, 16.95477295], [75.2947464, 16.95412827], [75.30612946, 16.95466995], [75.33796692, 16.9535408], [75.34532928, 16.95252037], [75.35957336, 16.9568882], [75.36435699, 16.9636097], [75.37168884, 16.96869087], [75.39476013, 16.97639275], [75.41683197, 16.96949959], [75.43102264, 16.96346092], [75.4388504, 16.97088051], [75.44380188, 16.97949028], [75.45353699, 16.98265076], [75.46791077, 16.98533058], [75.46858978, 16.97957039], [75.48249817, 16.97595024], [75.48969269, 16.96538925], [75.49178314, 16.95783043], [75.49263, 16.95150948], [75.49301147, 16.94518089], [75.49249268, 16.9428997], [75.50187683, 16.94540977], [75.5092926, 16.94859123], [75.51065063, 16.94730949], [75.51700592, 16.95193291], [75.52406311, 16.95874023], [75.53000641, 16.96582985], [75.53286743, 16.96665192], [75.54281616, 16.96314049], [75.55847168, 16.96434975], [75.57034302, 16.96362114], [75.56929779, 16.99885941], [75.56991577, 17.00617027], [75.57579803, 17.00779915], [75.59944153, 17.00522041], [75.60951996, 17.00311089], [75.60965729, 16.99893951], [75.61065674, 16.96961975], [75.62101746, 16.96775055], [75.6309433, 16.96714973], [75.63633728, 16.96581078], [75.63938904, 16.95915985], [75.64502716, 16.95103264], [75.64962769, 16.95199966], [75.65561676, 16.95611], [75.66374969, 16.95788193], [75.67137909, 16.95853806], [75.67460632, 16.96026993], [75.67842102, 16.96394157], [75.67459106, 16.96935081], [75.67263031, 16.97408104], [75.66938019, 16.97562981], [75.66883087, 16.97776031], [75.66867828, 16.98321915], [75.67053986, 16.9988308], [75.67310333, 17.02617073], [75.67224121, 17.03573036], [75.66216278, 17.03244972], [75.65399933, 17.03063965], [75.64819336, 17.03269005], [75.64375305, 17.03639984], [75.64787292, 17.04657173], [75.65439606, 17.05508995], [75.66268921, 17.06178284], [75.6709671, 17.06157112], [75.67840576, 17.06286049], [75.68107605, 17.07114029], [75.68013763, 17.07826805], [75.67739105, 17.08774948], [75.67848969, 17.09417152], [75.67550659, 17.10112953], [75.67410278, 17.11355019], [75.65363312, 17.11313057], [75.65273285, 17.13273048], [75.64968872, 17.13318062], [75.64871216, 17.13880157], [75.64273071, 17.14763832], [75.6313858, 17.16007042], [75.62802124, 17.17012024], [75.62851715, 17.18074989], [75.63018799, 17.18144989], [75.63069916, 17.18616104], [75.64264679, 17.18815994], [75.64359283, 17.19408035], [75.65743256, 17.20378113], [75.662117, 17.20833015], [75.66387939, 17.21375084], [75.66281891, 17.22793961], [75.66091919, 17.23999977], [75.65988922, 17.26144028], [75.65747833, 17.27057076], [75.63231659, 17.27222061], [75.63336945, 17.27738953], [75.63109589, 17.2798481], [75.62786865, 17.28812027], [75.62468719, 17.29380035], [75.60595703, 17.3032608], [75.61374664, 17.31944084], [75.61604309, 17.32876015], [75.61310577, 17.34229088], [75.59810638, 17.34511948], [75.58994293, 17.34968948], [75.58483124, 17.34977913], [75.58405304, 17.35134125], [75.57853699, 17.38293076], [75.58371735, 17.38220024], [75.58817291, 17.3830204], [75.59815979, 17.38610077], [75.60331726, 17.38986015], [75.61057281, 17.39200974], [75.61580658, 17.39185905], [75.61672211, 17.39863968], [75.61495209, 17.40956116], [75.61055756, 17.41711998], [75.61013794, 17.41954041], [75.61543274, 17.4220295], [75.61873627, 17.43911171], [75.62532806, 17.45811081], [75.63127136, 17.46117973], [75.63288879, 17.46964073], [75.6355896, 17.47751045], [75.64955902, 17.47340965], [75.65618134, 17.46751022], [75.66230011, 17.45968056], [75.6704483, 17.45932007], [75.6775589, 17.45797157], [75.68081665, 17.45397186], [75.68080902, 17.43616295], [75.68711853, 17.41730118], [75.69119263, 17.41261101], [75.69721222, 17.41056824], [75.70806122, 17.40831947], [75.71517944, 17.40893173], [75.72236633, 17.4117794], [75.72901154, 17.41950989], [75.7339859, 17.42165947], [75.73703766, 17.4218998], [75.75052643, 17.41290092], [75.75875854, 17.40841103], [75.76412201, 17.40842056], [75.76976776, 17.40684128], [75.77661896, 17.38820267], [75.78231812, 17.37881279], [75.79102325, 17.37298012], [75.80233765, 17.37010193], [75.8113327, 17.3699398], [75.81505585, 17.37384987], [75.81759644, 17.38072968], [75.81768799, 17.38804054], [75.81627655, 17.39781189], [75.81729126, 17.40121078], [75.82025146, 17.4065609], [75.82199097, 17.41967964], [75.82472229, 17.42284966], [75.82779694, 17.42371941], [75.83889008, 17.42054176], [75.8478775, 17.41534042], [75.85600281, 17.40768242], [75.85910797, 17.38896942], [75.86196899, 17.38585091], [75.86487579, 17.38644028], [75.87666321, 17.39697075], [75.87890625, 17.40032959], [75.87909698, 17.40493965], [75.8771286, 17.41135025], [75.87844849, 17.41654015], [75.88243103, 17.41900063], [75.88723755, 17.41732979], [75.89025879, 17.41360092], [75.89435577, 17.40590286], [75.89643097, 17.39497948], [75.89697266, 17.37700081], [75.89639282, 17.3699894], [75.89198303, 17.36079979], [75.8936615, 17.35362053], [75.89808655, 17.35075951], [75.9107132, 17.34581947], [75.91622162, 17.33897018], [75.93115234, 17.32411003], [75.94174957, 17.32485962], [75.95981598, 17.33383179], [75.9715271, 17.33646011], [75.98071289, 17.33620071], [76.00026703, 17.33774948], [76.00417328, 17.3427906], [76.00914001, 17.34752274], [76.01545715, 17.35061073], [76.02127838, 17.34931183], [76.03666687, 17.34896278], [76.05452728, 17.35429955], [76.06046295, 17.35393143], [76.0632019, 17.3519001], [76.0734787, 17.33232117], [76.07874298, 17.3300705], [76.08499146, 17.3321209], [76.08685303, 17.3337307], [76.08696747, 17.33844757], [76.09252167, 17.34367943], [76.09407806, 17.34709167], [76.09046936, 17.35056114], [76.09276581, 17.35444069], [76.09596252, 17.35781288], [76.10199738, 17.36226082], [76.11667633, 17.36622047], [76.12120819, 17.36634064], [76.1375885, 17.35256958], [76.14566803, 17.34793282], [76.16314697, 17.34090996], [76.16422272, 17.31925964], [76.1638031, 17.30033112], [76.17188263, 17.29758072], [76.17575836, 17.29721069], [76.18383026, 17.31104279], [76.18260193, 17.31430054], [76.17891693, 17.31391907], [76.1763382, 17.32146072], [76.17350769, 17.33223915], [76.17233276, 17.34873009], [76.17603302, 17.35238075], [76.1829071, 17.35650063], [76.19320679, 17.35859108], [76.20352173, 17.35878944], [76.22899628, 17.36322975], [76.2303772, 17.37026024], [76.24436188, 17.37467957], [76.24671173, 17.3678894], [76.2504425, 17.36667061], [76.248909, 17.36213112], [76.25, 17.35790062], [76.25627899, 17.35738945], [76.26494598, 17.35816193], [76.27017975, 17.35653114], [76.27263641, 17.34794998], [76.27587891, 17.33053017], [76.2857666, 17.33035088], [76.29589844, 17.32863808], [76.30502319, 17.32845116], [76.31720734, 17.32944107], [76.318367, 17.33184052], [76.31301117, 17.34327126], [76.31704712, 17.34540939], [76.33473969, 17.3498497], [76.34361267, 17.34993172], [76.3506012, 17.32772064], [76.35227203, 17.31059074], [76.35936737, 17.31028938], [76.38170624, 17.31180954], [76.38389587, 17.31954193], [76.39299011, 17.33628082], [76.4020462, 17.34399033], [76.4106369, 17.34769058], [76.4105072, 17.35413933], [76.4080658, 17.3692894], [76.36199951, 17.37508011], [76.37004852, 17.40789986], [76.36988068, 17.42304039], [76.37317657, 17.43441963], [76.3638916, 17.43555069], [76.34195709, 17.43383026], [76.33365631, 17.43229294], [76.33084106, 17.46162033], [76.33080292, 17.46881866], [76.33776855, 17.47040939], [76.3427887, 17.47037125], [76.3500061, 17.47212982], [76.37229919, 17.48578072], [76.37503815, 17.49352074], [76.36659241, 17.49529266], [76.35518646, 17.49416924], [76.34594727, 17.49159813], [76.34348297, 17.49435043], [76.34372711, 17.50811958], [76.34633636, 17.51148033], [76.35601807, 17.51337051], [76.3664093, 17.51671028], [76.36612701, 17.52217293], [76.36460876, 17.52852058], [76.36090088, 17.5362606], [76.35481262, 17.53873062], [76.34583282, 17.54021072], [76.34002686, 17.54257011], [76.33724213, 17.5551796], [76.33423615, 17.56348991], [76.33290863, 17.57383156], [76.33167267, 17.59486961], [76.33641052, 17.59604073], [76.34870148, 17.59539986], [76.35948181, 17.5962925], [76.37301636, 17.59793854], [76.38207245, 17.60078049], [76.4156723, 17.60420036], [76.41818237, 17.60583115], [76.42074585, 17.61424065], [76.42410278, 17.62154007], [76.42579651, 17.62832069], [76.42723083, 17.63978004], [76.4287262, 17.64441109], [76.43477631, 17.64453125], [76.44275665, 17.6418705], [76.4408493, 17.64937019], [76.45153809, 17.65151024], [76.45230103, 17.6555481], [76.48929596, 17.66066933], [76.48464966, 17.66963005], [76.48442841, 17.68442917], [76.48562622, 17.69269943], [76.48636627, 17.71352005], [76.49225616, 17.71494102], [76.51095581, 17.71591949], [76.52363586, 17.71523094], [76.52482605, 17.72290993], [76.52503967, 17.73467255], [76.5236969, 17.75889015], [76.52632141, 17.75936127], [76.53159332, 17.75852966], [76.53820801, 17.75893974], [76.55977631, 17.76313972], [76.56754303, 17.76288986], [76.57330322, 17.76000023], [76.56936646, 17.75638008], [76.56459045, 17.7536602], [76.5681076, 17.7397995], [76.56942749, 17.70374107], [76.57322693, 17.70216942], [76.57720947, 17.70314026], [76.5870285, 17.70788956], [76.59324646, 17.71755981], [76.59880066, 17.72797012], [76.60405731, 17.75583076], [76.60690308, 17.75958061], [76.60951233, 17.76597977], [76.61444855, 17.76831245], [76.62336731, 17.7578907], [76.62695313, 17.75596046], [76.62979889, 17.74187088], [76.63065338, 17.72900009], [76.63743591, 17.72410965], [76.65083313, 17.72083092], [76.6552124, 17.71640015], [76.65812683, 17.70853043], [76.65983582, 17.69919014], [76.66313934, 17.68786049], [76.67164612, 17.68914032], [76.67814636, 17.68734169], [76.68826294, 17.67851067], [76.69055176, 17.67995262], [76.69313049, 17.69376183], [76.69122314, 17.6981411], [76.69087219, 17.70194054], [76.69235992, 17.70526123], [76.70079803, 17.70726967], [76.70345306, 17.7186203], [76.70210266, 17.72371101], [76.69815063, 17.72603989], [76.70347595, 17.72912025], [76.72760773, 17.73699951], [76.72650146, 17.7403698], [76.72193146, 17.74802971], [76.7179718, 17.74786949], [76.71909332, 17.76133156], [76.72096252, 17.76758957], [76.71720123, 17.76984978], [76.7128067, 17.7713604], [76.71244812, 17.77509117], [76.71570587, 17.78191948], [76.71938324, 17.7852993], [76.72463226, 17.78507805], [76.73943329, 17.77913094], [76.74355316, 17.78079033], [76.74401093, 17.78346062], [76.74777222, 17.78360939], [76.74887848, 17.78635025], [76.76275635, 17.78710938], [76.7663269, 17.79664993], [76.77002716, 17.79701996], [76.77628326, 17.79938126], [76.77979279, 17.80591965], [76.77947998, 17.81028938], [76.78141785, 17.8151207], [76.78481293, 17.81963921], [76.78816986, 17.82647133], [76.78546906, 17.83146286], [76.77974701, 17.83633041], [76.76573944, 17.85079956], [76.76434326, 17.84950066], [76.75972748, 17.85206032], [76.75456238, 17.85658836], [76.74578857, 17.8583107], [76.73745728, 17.85705948], [76.73964691, 17.88362122], [76.73958588, 17.89204979], [76.74067688, 17.89801025], [76.74297333, 17.89902115], [76.76595306, 17.89842987], [76.7701416, 17.89236069], [76.77310944, 17.88515091], [76.77379608, 17.8822403], [76.77326202, 17.8786602], [76.77456665, 17.87696075], [76.7974472, 17.8693409], [76.80280304, 17.86832047], [76.80625153, 17.87049294], [76.80535126, 17.87420845], [76.80822754, 17.88309097], [76.81108093, 17.88408852], [76.81713104, 17.88309097], [76.82036591, 17.88445282], [76.83307648, 17.88274956], [76.83175659, 17.89067268], [76.8469162, 17.89640045], [76.85383606, 17.89783859], [76.87185669, 17.89474106], [76.87526703, 17.89273071], [76.88117981, 17.89305115], [76.88320923, 17.89707947], [76.88938141, 17.89718056], [76.89240265, 17.9028511], [76.89366913, 17.90737152], [76.89659882, 17.90802002], [76.90020752, 17.91468811], [76.91320038, 17.91379929], [76.91644287, 17.91509056], [76.91834259, 17.92310905], [76.91918945, 17.93666077], [76.91322327, 17.93720818], [76.91726685, 17.96047974], [76.91823578, 17.9728508], [76.91958618, 17.98538017], [76.9196701, 17.99064064], [76.91763306, 17.99625969], [76.91848755, 17.99868965], [76.91816711, 18.00187111], [76.9176712, 18.01234055], [76.92024994, 18.01375961], [76.91940308, 18.0220108], [76.91771698, 18.03322983], [76.93863678, 18.03722954], [76.95205688, 18.03771019], [76.95464325, 18.03968048], [76.95430756, 18.04273033], [76.94863129, 18.04572105], [76.94844818, 18.04866028], [76.9506073, 18.0582695], [76.95266724, 18.06340981], [76.94948578, 18.06826973], [76.94702911, 18.07376099], [76.94973755, 18.0823307], [76.95482635, 18.08535957], [76.96431732, 18.08821106], [76.96734619, 18.09263992], [76.96827698, 18.09711075], [76.95857239, 18.10643005], [76.95339203, 18.11011124], [76.94252777, 18.11141014], [76.93215179, 18.11098289], [76.92256165, 18.11610985], [76.92228699, 18.12018967], [76.92417908, 18.12446022], [76.92999268, 18.13225174], [76.9317627, 18.13657951], [76.92765808, 18.13986015], [76.92536926, 18.14481926], [76.93335724, 18.15790939], [76.9437561, 18.15473938], [76.95095825, 18.17247963], [76.95410919, 18.18489075], [76.95881653, 18.18614006], [76.97090149, 18.18686104], [76.97985077, 18.18740082], [76.98055267, 18.18939972], [76.98789215, 18.18847847], [76.99146271, 18.18665123], [76.99295044, 18.1820507], [76.99547577, 18.1783905], [76.99529266, 18.17333031], [76.99775696, 18.16684914], [77.02398682, 18.16267967], [77.02274323, 18.17124939], [77.02171326, 18.17822075], [77.03032684, 18.17934036], [77.03238678, 18.18300056], [77.03283691, 18.18378067], [77.0381012, 18.18131065], [77.04944611, 18.17320824], [77.05031586, 18.16127968], [77.05767059, 18.15592957], [77.05767059, 18.15236282], [77.06910706, 18.14944077], [77.08618164, 18.15027046], [77.08925629, 18.15596008], [77.09268188, 18.15697861], [77.09661865, 18.15813065], [77.10888672, 18.15269089], [77.11633301, 18.16760826], [77.10292816, 18.18630981], [77.09886169, 18.19114113], [77.09554291, 18.19510078], [77.10659027, 18.20181084], [77.11662292, 18.20240974], [77.12098694, 18.20670128], [77.13114929, 18.20618057], [77.13949585, 18.20724106], [77.14221954, 18.21604919], [77.14998627, 18.21656036], [77.1506424, 18.22153091], [77.14879608, 18.22145271], [77.14768982, 18.22140121], [77.14776611, 18.23764992], [77.15141296, 18.23793983], [77.15719604, 18.25309181], [77.16567993, 18.25592041], [77.16738129, 18.27345085], [77.17053223, 18.28087044], [77.17784119, 18.28185081], [77.19165039, 18.27429008], [77.19882965, 18.27923012], [77.20617676, 18.27795982], [77.20446014, 18.29047966], [77.19764709, 18.29552078], [77.19541168, 18.31270981], [77.20014954, 18.31917], [77.2099762, 18.31374168], [77.21691132, 18.32489014], [77.22297668, 18.33780098], [77.22727203, 18.34490013], [77.22136688, 18.34720993], [77.23081207, 18.36557961], [77.24163055, 18.3663826], [77.24503326, 18.3705883], [77.23287201, 18.38612747], [77.23639679, 18.39981079], [77.24022675, 18.40864754], [77.24912262, 18.40825272], [77.25836182, 18.41041946], [77.26455688, 18.41838074], [77.29476929, 18.43268013], [77.30226135, 18.43847084], [77.31327057, 18.43938065], [77.31741333, 18.45379066], [77.32557678, 18.45512009], [77.32601929, 18.44885063], [77.33271027, 18.44845963], [77.33338165, 18.44189072], [77.33731079, 18.43544006], [77.34207916, 18.43029022], [77.34529114, 18.43437195], [77.35407257, 18.44874191], [77.36962891, 18.44765091], [77.36535645, 18.43808937], [77.3644104, 18.42984962], [77.36975098, 18.40070915], [77.39263916, 18.39702988], [77.40049744, 18.39780045], [77.41011047, 18.38853073], [77.40788269, 18.37849045], [77.40067291, 18.37017059], [77.39182281, 18.36593056], [77.39824677, 18.35353088], [77.39833069, 18.34749985], [77.39594269, 18.34464073], [77.39277649, 18.3456707], [77.3928299, 18.34054947], [77.38922882, 18.34078979], [77.38617706, 18.33819008], [77.37930298, 18.33910179], [77.38089752, 18.33193016], [77.37800598, 18.32868958], [77.37394714, 18.32950974], [77.36701965, 18.32232285], [77.35542297, 18.31851959], [77.35881042, 18.31064987], [77.36252594, 18.30829048], [77.38128662, 18.30595016], [77.3925705, 18.30093002], [77.39628601, 18.30298042], [77.4078064, 18.29956055], [77.42500305, 18.30467033], [77.42780304, 18.30917931], [77.43637085, 18.30649185], [77.43461609, 18.29298019], [77.4369278, 18.28203964], [77.44489288, 18.27724075], [77.44522095, 18.27012062], [77.45079041, 18.26596069], [77.46539307, 18.25996017], [77.46923065, 18.26316071], [77.47480774, 18.26229095], [77.48034668, 18.26865959], [77.49223328, 18.26588058], [77.4977417, 18.27334976], [77.51020813, 18.27844048], [77.51264191, 18.28198051], [77.50843048, 18.3021698], [77.50950623, 18.30673027], [77.51978302, 18.30736923], [77.52388763, 18.30303192], [77.5395813, 18.29383087], [77.54995728, 18.29134941], [77.56098175, 18.28310966], [77.57065582, 18.29047012], [77.57463837, 18.28931046], [77.57433319, 18.28684807], [77.58381653, 18.28308105], [77.59784698, 18.28121948], [77.60301971, 18.27799988], [77.59902954, 18.27291107], [77.59194183, 18.26177025], [77.58149719, 18.25632095], [77.57253265, 18.24056053], [77.57676697, 18.23310089], [77.58106995, 18.22273827], [77.58496094, 18.21674156], [77.5743866, 18.19992065], [77.56430817, 18.20055008], [77.5643158, 18.18997955], [77.57002258, 18.18915939], [77.57247162, 18.17894936], [77.57753754, 18.16827011], [77.57936096, 18.16212082], [77.5891571, 18.15345955], [77.59777069, 18.15184021], [77.59350586, 18.12786102], [77.59661102, 18.12103081], [77.60056305, 18.09939957], [77.59745789, 18.08428955], [77.58979797, 18.08028984], [77.57744598, 18.07686996], [77.56733704, 18.07629013], [77.56048584, 18.07113075], [77.55670929, 18.06217003], [77.54743195, 18.06363106], [77.54574585, 18.05376053], [77.54807281, 18.0479908], [77.55206299, 18.04693985], [77.55311584, 18.03466988], [77.55782318, 18.03520012], [77.57448578, 18.03074074], [77.58496857, 18.02478981], [77.58724976, 18.01333046], [77.59224701, 18.01016808], [77.5994873, 18.01573944], [77.60666656, 18.01801109], [77.61006165, 18.01048088], [77.61585236, 18.00608826], [77.62229156, 18.00465965], [77.62390137, 18.00115967], [77.62145233, 17.99834061], [77.62879944, 17.99251938], [77.63272858, 17.99514008], [77.63822174, 17.99654007], [77.64228821, 17.99590111], [77.6461792, 17.9932003], [77.64775085, 17.98732185], [77.64978027, 17.98586273], [77.64888763, 17.97841072], [77.64360809, 17.97344971], [77.64742279, 17.97043991], [77.65339661, 17.96935272], [77.6520462, 17.96430016], [77.64425659, 17.96269035], [77.6428299, 17.95729065], [77.64742279, 17.95318985], [77.64398956, 17.94637108], [77.64061737, 17.9496212], [77.63561249, 17.95051956], [77.63182068, 17.95353127], [77.6297226, 17.96297073], [77.62374115, 17.95775032], [77.62899017, 17.95384026], [77.62886047, 17.94851112], [77.62428284, 17.94369125], [77.62001038, 17.94445992], [77.6167984, 17.93810081], [77.61952972, 17.93007088], [77.6186676, 17.92180824], [77.61894989, 17.91348076], [77.61657715, 17.90286827], [77.60444641, 17.90549088], [77.59979248, 17.90367126], [77.58516693, 17.90822983], [77.58307648, 17.89838028], [77.58521271, 17.8925209], [77.59249115, 17.87949944], [77.59777832, 17.87706947], [77.59668732, 17.87045097], [77.59275818, 17.86977959], [77.58127594, 17.87574959], [77.57772827, 17.87122917], [77.57274628, 17.87281036], [77.56743622, 17.86614037], [77.56604004, 17.84955978], [77.56215668, 17.84913063], [77.56346893, 17.84200096], [77.55918884, 17.83864021], [77.55432129, 17.83049011], [77.54973602, 17.8180294], [77.54479218, 17.81701088], [77.54371643, 17.82626915], [77.52600098, 17.82681847], [77.52607727, 17.81168938], [77.51805115, 17.80772018], [77.51087952, 17.80144119], [77.50701904, 17.79295921], [77.50448608, 17.78259087], [77.50934601, 17.7800808], [77.52304077, 17.77962112], [77.52760315, 17.77666092], [77.53449249, 17.77469063], [77.53697205, 17.7704525], [77.55445099, 17.76125908], [77.56595612, 17.76411057], [77.56202698, 17.74711037], [77.55464172, 17.74113083], [77.55187988, 17.73438072], [77.54412079, 17.73339081], [77.53936005, 17.72542191], [77.53398895, 17.72520256], [77.52755737, 17.72711754], [77.52258301, 17.72402954], [77.50946808, 17.71996117], [77.50544739, 17.7145195], [77.49427795, 17.71603966], [77.49173737, 17.71286011], [77.48932648, 17.70680046], [77.48446655, 17.70364952], [77.48108673, 17.70685005], [77.47867584, 17.70302963], [77.47415161, 17.70139122], [77.47155762, 17.70401001], [77.45786285, 17.69896126], [77.45462036, 17.69409752], [77.4503479, 17.69129944], [77.45140839, 17.68774033], [77.4509964, 17.68086052], [77.44909668, 17.66611099], [77.44564819, 17.65746117], [77.44500732, 17.64842033], [77.44753265, 17.64711952], [77.45081329, 17.63236046], [77.45321655, 17.63076973], [77.44882202, 17.62278938], [77.44580078, 17.61230087], [77.44650269, 17.60724068], [77.44130707, 17.60663033], [77.44050598, 17.60409164], [77.44207001, 17.59581184], [77.43992615, 17.58147049], [77.46121979, 17.57703018], [77.46515656, 17.57465935], [77.46911621, 17.56818008], [77.47207642, 17.56913185], [77.47408295, 17.56511116], [77.48999786, 17.56627083], [77.49563599, 17.55002975], [77.49555206, 17.54652977], [77.49681854, 17.5433712], [77.50161743, 17.5408802], [77.50965881, 17.54916954], [77.51390076, 17.55724907], [77.52742004, 17.57322121], [77.5320816, 17.5730896], [77.53669739, 17.57132912], [77.54395294, 17.55459976], [77.54839325, 17.54945946], [77.55281067, 17.55000114], [77.55612946, 17.55215073], [77.56083679, 17.5535202], [77.58538818, 17.55836105], [77.5854187, 17.56204033], [77.58982849, 17.5627594], [77.59185791, 17.55505943], [77.592453, 17.5490799], [77.59172821, 17.53268051], [77.59925079, 17.5340004], [77.60325623, 17.53069115], [77.60797119, 17.53107262], [77.61657715, 17.52935028], [77.62121582, 17.52225113], [77.63315582, 17.52308083], [77.64531708, 17.5187912], [77.64987946, 17.52107048], [77.65661621, 17.52133942], [77.66120911, 17.51481056], [77.66606903, 17.50995064], [77.67893982, 17.50510025], [77.68202972, 17.50666809], [77.68325043, 17.50402069], [77.68562317, 17.50564957], [77.68799591, 17.49854279], [77.68696594, 17.49156952], [77.68467712, 17.48522949], [77.68401337, 17.4728508], [77.66488647, 17.47628975], [77.64808655, 17.48117828], [77.64897156, 17.49155235], [77.65276337, 17.50325012], [77.64794922, 17.49936295], [77.64422607, 17.49489975], [77.64259338, 17.48344994], [77.64042664, 17.47601128], [77.6340332, 17.47223091], [77.62657166, 17.47120094], [77.61564636, 17.47140121], [77.61094666, 17.46994019], [77.61010742, 17.46463966], [77.61144257, 17.45290947], [77.61061096, 17.44423294], [77.60447693, 17.44309044], [77.59590149, 17.44268036], [77.59041595, 17.44810295], [77.57319641, 17.45420074], [77.57195282, 17.43855095], [77.57256317, 17.42951965], [77.5577774, 17.43527031], [77.54884338, 17.43492126], [77.53347015, 17.44095039], [77.52337646, 17.43668938], [77.51014709, 17.42725945], [77.51068878, 17.41254044], [77.52671814, 17.4059906], [77.53357697, 17.40610123], [77.5355072, 17.40410042], [77.53357697, 17.39884949], [77.52133179, 17.38633156], [77.52658844, 17.37882996], [77.53018188, 17.3778801], [77.52802277, 17.37211037], [77.52081299, 17.36205101], [77.509758, 17.3592701], [77.49912262, 17.35407066], [77.49237823, 17.35551071], [77.48261261, 17.35445976], [77.47447205, 17.35917091], [77.47241211, 17.36317825], [77.4753418, 17.36815071], [77.47931671, 17.36961174], [77.45159912, 17.37049103], [77.44988251, 17.3630619], [77.44976807, 17.35004807], [77.45298004, 17.34880829], [77.45635223, 17.34498978], [77.45510101, 17.3379097], [77.45250702, 17.32793045], [77.45137024, 17.32723045], [77.44963837, 17.31489944], [77.44798279, 17.31345177], [77.44043732, 17.2978096], [77.43776703, 17.29668999], [77.434021, 17.28825951], [77.4469986, 17.2888298], [77.45279694, 17.28663063], [77.45450592, 17.27589035], [77.44967651, 17.26986122], [77.44248199, 17.26859093], [77.43736267, 17.26136971], [77.4225769, 17.25325012], [77.42047882, 17.24933052], [77.42002106, 17.24160957], [77.41776276, 17.23278999], [77.41493988, 17.22987938], [77.40545654, 17.23740959], [77.3988266, 17.23188972], [77.39585114, 17.23285103], [77.39225006, 17.22855949], [77.38401794, 17.22331047], [77.38035583, 17.21977043], [77.38128662, 17.21632195], [77.38458252, 17.2129612], [77.39318848, 17.21147919], [77.39901733, 17.21153069], [77.39881134, 17.20877838], [77.39344788, 17.2069397], [77.39148712, 17.19236946], [77.38173676, 17.1937294], [77.37671661, 17.19300079], [77.37075043, 17.19007111], [77.36753082, 17.18320084], [77.36837006, 17.17648125], [77.36354828, 17.16948128], [77.36490631, 17.16494942], [77.35999298, 17.16162109], [77.36686707, 17.15133095], [77.37541962, 17.14870071], [77.37632751, 17.13788986], [77.39890289, 17.13191986], [77.4037323, 17.12321091], [77.41178894, 17.12051964], [77.42352295, 17.11405754], [77.43376923, 17.11115074], [77.43862915, 17.11458015], [77.44841766, 17.11149979], [77.45237732, 17.1076107], [77.46263885, 17.10407066], [77.46031189, 17.09284019], [77.46386719, 17.08671188], [77.46842957, 17.08111191], [77.47692108, 17.07623291], [77.47783661, 17.07226944], [77.47543335, 17.06989098], [77.47805786, 17.06098938], [77.48306274, 17.05344009], [77.486763, 17.04467964], [77.49186707, 17.03884125], [77.49323273, 17.0329895], [77.49199677, 17.02165031], [77.49819946, 17.01519966], [77.49938965, 17.0073204], [77.49357605, 17.0058403], [77.48323059, 16.99867821], [77.481987, 16.99719048], [77.47837067, 16.99024963], [77.47998047, 16.97517014], [77.47918701, 16.96803284], [77.47374725, 16.95947075], [77.46917725, 16.95384026], [77.46407318, 16.95269012], [77.46465302, 16.94637108], [77.46430206, 16.93980026], [77.4659729, 16.93457031], [77.46354675, 16.92904091], [77.46459961, 16.92489815], [77.46787262, 16.92419815], [77.46774292, 16.91711044], [77.46537018, 16.91407967], [77.4601059, 16.91292953], [77.45339966, 16.90903282], [77.45391846, 16.90627289], [77.45581818, 16.90465927], [77.45426178, 16.88612938], [77.45223999, 16.88159943], [77.45759583, 16.87928009], [77.46031189, 16.85453033], [77.46039581, 16.84411049], [77.45662689, 16.82374954], [77.45941162, 16.81776237], [77.46272278, 16.80451965], [77.46575928, 16.80083084], [77.47175598, 16.79628944], [77.47162628, 16.78518105], [77.471138, 16.77913094], [77.46733856, 16.77659988], [77.44454193, 16.78004265], [77.43753815, 16.78321075], [77.43527985, 16.77762032], [77.43721008, 16.76313019], [77.43534088, 16.74954987], [77.43128967, 16.73644066], [77.42784119, 16.72948265], [77.42569733, 16.72706032], [77.42633057, 16.72274971], [77.42755127, 16.72113991], [77.42672729, 16.71837997], [77.4241333, 16.71780014], [77.42341614, 16.71453094], [77.4254303, 16.71175957], [77.43000793, 16.71170044], [77.43325806, 16.70911026], [77.4373703, 16.70754814], [77.44541168, 16.71380043], [77.44845581, 16.71357918], [77.45627594, 16.71068954], [77.46103668, 16.71316147], [77.46679688, 16.71194077], [77.46877289, 16.70870972], [77.46746063, 16.70237923], [77.46750641, 16.69680023], [77.46504211, 16.67828178], [77.46170044, 16.67235947], [77.44642639, 16.67416], [77.43715668, 16.6665802], [77.41657257, 16.66281128], [77.41684723, 16.65475082], [77.42119598, 16.65199089], [77.42809296, 16.65007973], [77.43026733, 16.64472961], [77.43247223, 16.64306068], [77.43622589, 16.64253044], [77.43293762, 16.63763809], [77.43836975, 16.63620186], [77.44406128, 16.63579178], [77.44851685, 16.63883018], [77.45478058, 16.64487076], [77.46141815, 16.64883041], [77.46939087, 16.64691162], [77.47133636, 16.6435318], [77.46586609, 16.63594055], [77.46247101, 16.62920952], [77.4613266, 16.62478065], [77.45556641, 16.62001038], [77.4538269, 16.61379814], [77.45388031, 16.60741997], [77.46363068, 16.60481071], [77.4646759, 16.59744072], [77.46420288, 16.59514046], [77.46034241, 16.59555054], [77.45877838, 16.59205055], [77.46134186, 16.59065819], [77.46418762, 16.58719063], [77.46417236, 16.58420944], [77.46038055, 16.58346939], [77.45639038, 16.58099937], [77.44326019, 16.58205986], [77.43672943, 16.58120918], [77.42095947, 16.56517029], [77.41728973, 16.56390953], [77.40213013, 16.56629181], [77.39753723, 16.56335068], [77.39144135, 16.56520081], [77.39029694, 16.5597496], [77.39261627, 16.55945015], [77.39480591, 16.55824089], [77.39653778, 16.55554008], [77.39705658, 16.55289268], [77.4004364, 16.55023003], [77.40157318, 16.54677963], [77.41565704, 16.54400063], [77.41532135, 16.5178299], [77.41197968, 16.51381111], [77.40061188, 16.51595116], [77.39351654, 16.51486015], [77.38871002, 16.51210976], [77.38115692, 16.51153946], [77.37908173, 16.51072121], [77.37290192, 16.50601959], [77.36908722, 16.50210953], [77.36730957, 16.4937706], [77.36717224, 16.48693085], [77.36628723, 16.48410988], [77.35816956, 16.48315048], [77.35163116, 16.48332024], [77.34790039, 16.4855175], [77.3436203, 16.48488045], [77.34365845, 16.48205948], [77.32995605, 16.48069191], [77.32440948, 16.48093033], [77.31362152, 16.48755074], [77.30909729, 16.48933983], [77.29664612, 16.49147034], [77.29688263, 16.48588943], [77.29580688, 16.48134041], [77.29199982, 16.47363853], [77.28536224, 16.47151184], [77.25151062, 16.46790123], [77.24452209, 16.47221947], [77.23886108, 16.47290993], [77.23517609, 16.46808052], [77.25245667, 16.45329094], [77.25820923, 16.44730949], [77.26438904, 16.4300518], [77.26925659, 16.42308044], [77.27475739, 16.41773987], [77.27820587, 16.41070938], [77.28466034, 16.40299988], [77.29457855, 16.39960289], [77.30696869, 16.39402008], [77.33273315, 16.38829994], [77.34294891, 16.37972069], [77.35253906, 16.3766098], [77.37319946, 16.37992096], [77.38813782, 16.37179947], [77.40112305, 16.36602974], [77.41174316, 16.36268044], [77.42220306, 16.36284256], [77.42778015, 16.36507988], [77.43519592, 16.37267113], [77.43811035, 16.3744297], [77.44896698, 16.37580109], [77.46131134, 16.3754406], [77.48137665, 16.37776947], [77.49449158, 16.37578964], [77.51014709, 16.37018013], [77.51885986, 16.37010956], [77.52863312, 16.35836029], [77.53515625, 16.35293961], [77.54432678, 16.34975815], [77.54949188, 16.34468079], [77.55452728, 16.34156036], [77.57184601, 16.33595085], [77.58644104, 16.33793068], [77.59160614, 16.33751106], [77.58438873, 16.32804108], [77.5866394, 16.32044983], [77.5908432, 16.31197929], [77.59099579, 16.30461121], [77.58835602, 16.29565048], [77.59227753, 16.29010963], [77.59030151, 16.28685188], [77.58068085, 16.28606033], [77.57434082, 16.28894043], [77.56925964, 16.29477119], [77.56498718, 16.29771042], [77.54950714, 16.29067039], [77.54321289, 16.28705978], [77.53975677, 16.28263283], [77.53378296, 16.26263046], [77.52581787, 16.26702118], [77.52442169, 16.26978111], [77.51933289, 16.27088165], [77.51309204, 16.27071953], [77.50122833, 16.26781082], [77.50020599, 16.26068115], [77.49897003, 16.25786018], [77.48755646, 16.24982071], [77.48890686, 16.24183083], [77.4887619, 16.22434998], [77.49362183, 16.22302055], [77.50222778, 16.22478104], [77.51075745, 16.22333908], [77.51116943, 16.21718979], [77.50878143, 16.21494293], [77.50232697, 16.21570015], [77.49532318, 16.21300125], [77.49369812, 16.20617104], [77.49494171, 16.19535065], [77.49491882, 16.18712044], [77.4883728, 16.17868042], [77.48362732, 16.15855026], [77.48680878, 16.15307808], [77.48809814, 16.14739037], [77.48858643, 16.12646103], [77.48667145, 16.1157608], [77.49022675, 16.11615944], [77.49543762, 16.11465073], [77.50271606, 16.10947037], [77.50939941, 16.10353088], [77.50347137, 16.10152054], [77.49788666, 16.09721947], [77.4928894, 16.08377075], [77.4930191, 16.0796299], [77.50293732, 16.07323265], [77.49952698, 16.05426025], [77.49621582, 16.05477905], [77.49447632, 16.04977989], [77.4956665, 16.04771042], [77.49072266, 16.03063011], [77.49207306, 16.02556992], [77.49881744, 16.01716042], [77.4985733, 16.01389122], [77.50028229, 16.01135063], [77.5016861, 16.00554085], [77.51010895, 16.00225067], [77.50839996, 15.99582958], [77.50549316, 15.97876167], [77.50551605, 15.97266865], [77.50901031, 15.96744061], [77.51487732, 15.96315193], [77.51589966, 15.95746136], [77.51457977, 15.94342995], [77.50945282, 15.92086029], [77.49732208, 15.92630005], [77.48332214, 15.92805958], [77.46697998, 15.92758083], [77.45250702, 15.93152046], [77.43647766, 15.9390316], [77.42642212, 15.94227886], [77.42193604, 15.94129944], [77.41644287, 15.93796062], [77.40763092, 15.93565178], [77.40003204, 15.93546009], [77.3927002, 15.93676186], [77.38559723, 15.9344511], [77.3762207, 15.93325043], [77.36814117, 15.93604088], [77.35987091, 15.94155025], [77.35360718, 15.94370174], [77.33516693, 15.94327068], [77.31478882, 15.94519043], [77.30021667, 15.95049953], [77.29178619, 15.94996929], [77.28244781, 15.94736195], [77.26317596, 15.95138931], [77.25813293, 15.95397091], [77.24891663, 15.95774078], [77.2440567, 15.95676136], [77.23609161, 15.95271111], [77.22711945, 15.95160961], [77.21866608, 15.95164204], [77.20295715, 15.94987965], [77.18782806, 15.9507103], [77.18062592, 15.95006275], [77.17070007, 15.94554996], [77.15712738, 15.9444809], [77.14343262, 15.9406004], [77.13677216, 15.93621922], [77.12993622, 15.93039131], [77.12065887, 15.92882061], [77.10460663, 15.92453194], [77.09005737, 15.91786957], [77.07679749, 15.90974045], [77.06595612, 15.89931107], [77.05821228, 15.88716125], [77.05245209, 15.87628269], [77.04104614, 15.86395931], [77.03318787, 15.85308075], [77.02902985, 15.84490108], [77.0222702, 15.83178043], [77.02442169, 15.82948971], [77.02815247, 15.82559013], [77.03388214, 15.82439995], [77.03836823, 15.82551003], [77.04154205, 15.821661], [77.04991913, 15.82014275], [77.05226135, 15.82433891], [77.06388855, 15.82316971], [77.06151581, 15.79792118], [77.06723785, 15.79605007], [77.06247711, 15.77839088], [77.05976868, 15.77884007], [77.05660248, 15.77228069], [77.0537262, 15.76364994], [77.04972076, 15.76410103], [77.04850769, 15.76076031], [77.05316925, 15.75887966], [77.05171967, 15.7501297], [77.04669189, 15.75133133], [77.04322815, 15.73448181], [77.04724884, 15.73317146], [77.04708862, 15.72501183], [77.06299591, 15.72367191], [77.07627106, 15.72141075], [77.0762558, 15.71037102], [77.08436584, 15.70895958], [77.08164978, 15.69533062], [77.07792664, 15.69336128], [77.07592773, 15.69087887], [77.10083771, 15.67887974], [77.110466, 15.67126274], [77.1190567, 15.66208935], [77.12497711, 15.65905094], [77.1209259, 15.63720131], [77.11620331, 15.62510967], [77.10389709, 15.63393116], [77.10056305, 15.63916111], [77.09593201, 15.64414978], [77.08889771, 15.64752102], [77.08143616, 15.65284061], [77.06887054, 15.64090919], [77.03601074, 15.6323719], [77.03266144, 15.63200855], [77.02928162, 15.63383865], [77.02710724, 15.62934971], [77.02839661, 15.60684967], [77.02889252, 15.59825993], [77.02443695, 15.58436203], [77.02371216, 15.57638168], [77.028862, 15.52512169], [77.02874756, 15.50856018], [77.02659607, 15.49999046], [77.00543213, 15.50277138], [76.99603271, 15.49973106], [76.99085236, 15.50107098], [76.98165131, 15.50477028], [76.97189331, 15.50633144], [76.97013855, 15.49495125], [76.97039032, 15.49092197], [76.97608185, 15.48201275], [76.98898315, 15.47315121], [76.9960022, 15.46745968], [77.00074005, 15.46170139], [77.00203705, 15.45538139], [77.00609589, 15.44823074], [77.01528168, 15.4410696], [77.02384186, 15.43856144], [77.02739716, 15.43518066], [77.03048706, 15.42633057], [77.03100586, 15.41833973], [77.0268631, 15.40775204], [77.02854156, 15.40130234], [77.03325653, 15.39626026], [77.041008, 15.39151001], [77.04382324, 15.38374138], [77.04228973, 15.37479973], [77.03803253, 15.35878181], [77.04260254, 15.35224056], [77.05784607, 15.34319019], [77.06289673, 15.3379097], [77.0631485, 15.32808018], [77.06157684, 15.32186031], [77.0690918, 15.31947136], [77.09929657, 15.32662106], [77.10968781, 15.32728195], [77.11023712, 15.32073021], [77.11342621, 15.31912041], [77.11541748, 15.28985023], [77.12374878, 15.28757], [77.13883972, 15.28547955], [77.14791107, 15.28567028], [77.14872742, 15.27785015], [77.14803314, 15.27095127], [77.14491272, 15.26928043], [77.14517212, 15.26605129], [77.14985657, 15.26693058], [77.15766907, 15.26037979], [77.16414642, 15.2590704], [77.16525269, 15.25097179], [77.1579361, 15.2513504], [77.14668274, 15.25029087], [77.14025116, 15.25155067], [77.13265991, 15.2346096], [77.12345886, 15.23332024], [77.12090302, 15.221241], [77.14138031, 15.21813202], [77.14707947, 15.20880985], [77.14996338, 15.207901], [77.15577698, 15.19433975], [77.15815735, 15.19382], [77.16153717, 15.18221092], [77.16448212, 15.16847038], [77.16320038, 15.16133118], [77.15879059, 15.15786934], [77.1592865, 15.15212059], [77.15770721, 15.14895058], [77.15305328, 15.14882088], [77.14549255, 15.15070057], [77.13697052, 15.14925194], [77.13208008, 15.14268112], [77.13536072, 15.13601017], [77.15276337, 15.13162136], [77.15403748, 15.12052059], [77.14771271, 15.10733032], [77.13938904, 15.09988117], [77.12760925, 15.09364128], [77.12552643, 15.06820965], [77.12091064, 15.05507088], [77.11839294, 15.05063057], [77.11606598, 15.04010201], [77.11161041, 15.03812981], [77.10957336, 15.02856922], [77.10167694, 15.02734089], [77.09078217, 15.02772236], [77.08825684, 15.02303791], [77.0820694, 15.02229023], [77.08049774, 15.00791073], [77.07881927, 15.00000954], [77.06858826, 15.00111008], [77.06147003, 15.00154972], [77.05092621, 15.00428963], [77.041008, 15.00548172], [77.04638672, 15.01601791], [77.04878998, 15.02386093], [77.04688263, 15.029212], [77.0374527, 15.02757072], [77.02295685, 15.02765083], [77.0092926, 15.02958107], [77.00067902, 15.02958965], [76.99862671, 15.02706146], [76.99565125, 15.02368069], [76.98351288, 15.02042198], [76.98178101, 15.01036072], [76.96679688, 15.01316929], [76.95066833, 15.02443123], [76.94274902, 15.02703094], [76.93167114, 15.02631092], [76.9193573, 15.02852154], [76.91352081, 15.03095055], [76.90544128, 15.0292902], [76.89620972, 15.03188133], [76.88868713, 15.03175068], [76.87670135, 15.02867889], [76.86975098, 15.0440197], [76.86406708, 15.05000019], [76.86057281, 15.05671024], [76.84320831, 15.06615925], [76.83740997, 15.07246971], [76.82943726, 15.07429123], [76.82126617, 15.07485199], [76.81188202, 15.08023071], [76.79693604, 15.09076023], [76.78756714, 15.08043957], [76.78423309, 15.08078003], [76.78224945, 15.07882023], [76.78391266, 15.07567024], [76.7786026, 15.0715704], [76.77636719, 15.07329273], [76.77422333, 15.07138062], [76.77574158, 15.06916142], [76.77256012, 15.06511974], [76.77082062, 15.05828857], [76.77112579, 15.05409145], [76.77501678, 15.04395962], [76.78079224, 15.03423977], [76.78179169, 15.02332973], [76.78457642, 15.01667023], [76.77974701, 15.00588989], [76.76953125, 15.00058174], [76.76805878, 14.9956398], [76.76622009, 14.99081135], [76.7651825, 14.98906136], [76.76235962, 14.9894619], [76.7592392, 14.98507023], [76.75698853, 14.98297119], [76.75863647, 14.97946072], [76.76185608, 14.97528076], [76.76377106, 14.96986961], [76.7720871, 14.96864033], [76.79688263, 14.96292114], [76.81545258, 14.96380997], [76.82028198, 14.95917034], [76.82364655, 14.95361137], [76.82789612, 14.95100975], [76.83255005, 14.95348072], [76.83587646, 14.9590807], [76.84115601, 14.96117115], [76.86445618, 14.96401978], [76.86367035, 14.95521069], [76.86547852, 14.93760014], [76.86348724, 14.91564274], [76.86389923, 14.91174126], [76.86271667, 14.90176964], [76.86030579, 14.89118958], [76.846138, 14.89033127], [76.84377289, 14.88642025], [76.84326172, 14.88147163], [76.84905243, 14.87993145], [76.85087585, 14.87285042], [76.85167694, 14.86252117], [76.85411835, 14.86137199], [76.84938812, 14.83869934], [76.84436035, 14.83325195], [76.84008789, 14.83004093], [76.84026337, 14.82807159], [76.84298706, 14.82430172], [76.8444519, 14.81559086], [76.84854126, 14.81425095], [76.84960175, 14.81180954], [76.84873962, 14.80403137], [76.8469162, 14.80231094], [76.83721161, 14.80414104], [76.83496857, 14.8001318], [76.83377075, 14.78490925], [76.83136749, 14.78411198], [76.82641602, 14.78698063], [76.82073212, 14.78660965], [76.81735229, 14.78544044], [76.81671143, 14.78249073], [76.81096649, 14.7814312], [76.78034973, 14.77926159], [76.78128815, 14.77433014], [76.78642273, 14.76191139], [76.78813934, 14.75184059], [76.79502869, 14.74113178], [76.79807281, 14.73459053], [76.78553772, 14.70709133], [76.78108215, 14.6904707], [76.77127838, 14.67383957], [76.76950836, 14.65631104], [76.7629776, 14.61192131], [76.76017761, 14.60201073], [76.76091003, 14.59628105], [76.77275085, 14.58720112], [76.77435303, 14.59057045], [76.77628326, 14.59033012], [76.77815247, 14.5793314], [76.78405762, 14.56198025], [76.78617096, 14.55305958], [76.79469299, 14.54073048], [76.79972839, 14.5277319], [76.80509186, 14.52487087], [76.81089783, 14.5237999], [76.81973267, 14.52033997], [76.82758331, 14.52305889], [76.82842255, 14.52224064], [76.83207703, 14.51507092], [76.84393311, 14.50914955], [76.85421753, 14.49888039], [76.86044312, 14.48713112], [76.86380768, 14.47467136], [76.87020111, 14.46844006], [76.88030243, 14.47052956], [76.88549042, 14.4759407], [76.89427185, 14.48075199], [76.90651703, 14.48416138], [76.94541168, 14.48215103], [76.95580292, 14.47958946], [76.96909332, 14.47908974], [76.9733963, 14.47828102], [76.97419739, 14.47036076], [76.96437073, 14.45174122], [76.95858765, 14.4453907], [76.94378662, 14.44510174], [76.94271088, 14.43984127], [76.94432068, 14.42523193], [76.94467926, 14.40892029], [76.94359589, 14.40326118], [76.94156647, 14.39954185], [76.93678284, 14.40130997], [76.9189682, 14.41145039], [76.9131012, 14.41355228], [76.90116119, 14.3983202], [76.89663696, 14.39447975], [76.89232635, 14.3928709], [76.88677979, 14.39245129], [76.88314056, 14.39029121], [76.87861633, 14.35139275], [76.87909698, 14.34638977], [76.88536072, 14.33959103], [76.89897156, 14.31924057], [76.90615845, 14.315341], [76.91680908, 14.31225967], [76.92314911, 14.30965042], [76.93656158, 14.30840969], [76.94293976, 14.30537891], [76.94670105, 14.30044937], [76.95011139, 14.29402924], [76.9487381, 14.28676128], [76.9437561, 14.28168106], [76.93548584, 14.27664185], [76.92485809, 14.27218056], [76.92582703, 14.26439953], [76.9336319, 14.25350094], [76.93598938, 14.24877167], [76.93784332, 14.24012089], [76.94346619, 14.23631001], [76.95139313, 14.23415184], [76.96157074, 14.23590183], [76.96971893, 14.23521137], [76.97560883, 14.23742008], [76.98248291, 14.23815155], [76.98937988, 14.2364006], [76.99279022, 14.23298931], [76.99456024, 14.23556042], [77.00411987, 14.23156929], [77.01251221, 14.23509121], [77.02458954, 14.23668098], [77.03304291, 14.24048996], [77.04064941, 14.2407589], [77.04962921, 14.23954201], [77.05532074, 14.23230076], [77.06022644, 14.22416019], [77.06761932, 14.21786022], [77.07534027, 14.20934963], [77.08486938, 14.20845032], [77.09522247, 14.20948029], [77.10507965, 14.21328163], [77.1099472, 14.22148037], [77.110466, 14.23198032], [77.11299896, 14.23991966], [77.1115799, 14.24846172], [77.11551666, 14.25681973], [77.10692596, 14.26176071], [77.1105423, 14.27493], [77.11192322, 14.2875309], [77.11730957, 14.29141045], [77.12577057, 14.30153179], [77.13092804, 14.31381035], [77.13262939, 14.32404995], [77.13191986, 14.3305912], [77.13553619, 14.33401203], [77.14054108, 14.33611107], [77.14644623, 14.33219147], [77.15215302, 14.3377409], [77.15975952, 14.33623886], [77.16422272, 14.33046055], [77.17188263, 14.33023071], [77.17674255, 14.32629013], [77.17951202, 14.32637024], [77.19635773, 14.31429958], [77.20979309, 14.31301022], [77.22292328, 14.31498146], [77.23195648, 14.31107044], [77.24508667, 14.31453037], [77.251297, 14.32060242], [77.25785065, 14.32570171], [77.26732635, 14.32701015], [77.2733078, 14.33175087], [77.28114319, 14.33111095], [77.2826767, 14.30228043], [77.28189087, 14.29045963], [77.27958679, 14.27608967], [77.28549957, 14.27474976], [77.29545593, 14.27647114], [77.30748749, 14.27383995], [77.32058716, 14.27345085], [77.34336853, 14.27052021], [77.35340881, 14.27067947], [77.35926056, 14.26933002], [77.35826874, 14.26032066], [77.35923767, 14.24360085], [77.35540771, 14.2300396], [77.36431122, 14.22331047], [77.37661743, 14.216712], [77.38162231, 14.21018028], [77.38011169, 14.20255089], [77.38378906, 14.1918211], [77.39122009, 14.19088173], [77.41487885, 14.20322132], [77.41570282, 14.21196175], [77.41470337, 14.21706009], [77.40905762, 14.22358131], [77.40618134, 14.23671055], [77.40479279, 14.24860096], [77.40101624, 14.26041031], [77.38986969, 14.26138973], [77.38433838, 14.26561069], [77.38504791, 14.27245045], [77.3812027, 14.28299141], [77.37500763, 14.2951889], [77.37386322, 14.30510998], [77.37882233, 14.31707954], [77.38565826, 14.32487011], [77.39488983, 14.32915974], [77.4092865, 14.32710171], [77.42072296, 14.32199192], [77.4258728, 14.32081127], [77.42752838, 14.30484962], [77.44233704, 14.30975056], [77.44243622, 14.29091072], [77.4436264, 14.2775507], [77.45469666, 14.27219009], [77.46842957, 14.27943993], [77.47912598, 14.283741], [77.47934723, 14.28477097], [77.48439026, 14.27525997], [77.49214172, 14.27128124], [77.4962616, 14.2717514], [77.49936676, 14.26051044], [77.49878693, 14.24954033], [77.49627686, 14.24040985], [77.49008179, 14.22763062], [77.49285126, 14.22006035], [77.49308777, 14.21397018], [77.49971008, 14.20446968], [77.50108337, 14.19322109], [77.50414276, 14.18066025], [77.5094223, 14.17695045], [77.51035309, 14.17201996], [77.50679016, 14.16424084], [77.50267029, 14.1571207], [77.5004425, 14.15096092], [77.48854065, 14.15307999], [77.46333313, 14.16423035], [77.45392609, 14.16298103], [77.42347717, 14.16508007], [77.41631317, 14.16930103], [77.40972137, 14.1697197], [77.39745331, 14.16650009], [77.3897171, 14.16526031], [77.38955688, 14.15354061], [77.38262177, 14.14772034], [77.37873077, 14.13827991], [77.3766861, 14.12960052], [77.36501312, 14.12710953], [77.3548584, 14.12374973], [77.34773254, 14.12434101], [77.34651184, 14.1178503], [77.34651184, 14.11044025], [77.34453583, 14.09601116], [77.34851074, 14.09926128], [77.35246277, 14.10535145], [77.3589325, 14.10872173], [77.37325287, 14.1125803], [77.38035583, 14.1166296], [77.38973999, 14.11857033], [77.39444733, 14.11464119], [77.39643097, 14.11056995], [77.39544678, 14.10344124], [77.38568115, 14.09346104], [77.37966156, 14.09039116], [77.37238312, 14.07185173], [77.36136627, 14.06595135], [77.35855865, 14.05892944], [77.35012054, 14.05338192], [77.33796692, 14.0538311], [77.33454895, 14.04779053], [77.33126068, 14.03984165], [77.32618713, 14.02293968], [77.34406281, 14.01906013], [77.35009766, 14.01645088], [77.36232758, 14.01599026], [77.37507629, 14.01210022], [77.38336182, 14.00735855], [77.37988281, 13.99328136], [77.37320709, 13.98171043], [77.37269592, 13.9755106], [77.37565613, 13.96911144], [77.38651276, 13.97400188], [77.41018677, 13.97692204], [77.42050171, 13.97687054], [77.42661285, 13.97328186], [77.43064117, 13.96877956], [77.43090057, 13.96199131], [77.42904663, 13.9563818], [77.42870331, 13.94334126], [77.4225769, 13.93900108], [77.40770721, 13.93610001], [77.40843964, 13.92161083], [77.41015625, 13.91460133], [77.42250061, 13.91195011], [77.42740631, 13.90921974], [77.42562866, 13.90205193], [77.4189682, 13.89490891], [77.4085083, 13.88881016], [77.39705658, 13.88054085], [77.39626312, 13.88044071], [77.39186096, 13.87989044], [77.39041901, 13.89768982], [77.35884857, 13.89556122], [77.3483429, 13.89654064], [77.34590149, 13.9033308], [77.34350586, 13.90598106], [77.34261322, 13.91224194], [77.35263824, 13.92845058], [77.36260986, 13.9423008], [77.36200714, 13.9454689], [77.34374237, 13.95089245], [77.34720612, 13.95535183], [77.34693909, 13.96058941], [77.35338593, 13.97628975], [77.35378265, 13.98232079], [77.34567261, 13.98558044], [77.33347321, 13.98805141], [77.3303299, 13.99035931], [77.32977295, 13.99335194], [77.32966614, 13.99335194], [77.33011627, 13.99488068], [77.32409668, 14.00531006], [77.32022095, 14.00925064], [77.31700897, 14.01532269], [77.31648254, 14.02145958], [77.31349182, 14.02482033], [77.30355835, 14.02672958], [77.29802704, 14.02303123], [77.2922821, 14.01449966], [77.28518677, 14.01152992], [77.27851105, 14.00690079], [77.2726059, 14.0080204], [77.27420807, 14.01618195], [77.27150726, 14.02810192], [77.26451874, 14.02652931], [77.25575256, 14.0209589], [77.24256897, 14.00631142], [77.22727203, 14.00795174], [77.21884918, 14.00791073], [77.20767975, 14.00487137], [77.19455719, 14.00286007], [77.17138672, 14.00859928], [77.16168976, 14.00624943], [77.16278076, 13.99775982], [77.15815735, 13.99351978], [77.15836334, 13.99351978], [77.15444183, 13.99061012], [77.14733887, 13.99162197], [77.14459991, 13.99351978], [77.14437103, 13.99351978], [77.13949585, 13.99719048], [77.13434601, 13.9981308], [77.13288116, 14.00421047], [77.1340332, 14.00967026], [77.12783051, 14.01865005], [77.12468719, 14.0347414], [77.12110138, 14.04218006], [77.1101532, 14.04204082], [77.10396576, 14.04057121], [77.0966568, 14.04070091], [77.09075928, 14.03826046], [77.07649231, 14.0380497], [77.06952667, 14.03944111], [77.06903076, 14.04718971], [77.05120087, 14.04959202], [77.04322052, 14.05167007], [77.0348587, 14.05144024], [77.02848053, 14.05198002], [77.0236969, 14.0532589], [77.02024078, 14.06144142], [77.02453613, 14.07716942], [77.02398682, 14.08337116], [77.01470947, 14.08869934], [77.01043701, 14.0920496], [77.00831604, 14.09813118], [77.0165863, 14.10609245], [77.01703644, 14.11195087], [77.01635742, 14.11752129], [77.0202713, 14.12232113], [77.01920319, 14.12529087], [77.01380157, 14.12740135], [77.01493835, 14.13218117], [77.01600647, 14.15269089], [77.02105713, 14.16432953], [77.02133942, 14.16839886], [77.0198288, 14.17270184], [77.01403809, 14.17304134], [77.00605011, 14.17485142], [76.9943924, 14.17374992], [76.98626709, 14.17253113], [76.97818756, 14.17292023], [76.97276306, 14.1742897], [76.96568298, 14.17432022], [76.95849609, 14.17550945], [76.95378113, 14.18103027], [76.94908142, 14.18381023], [76.94404602, 14.18832016], [76.94164276, 14.18931198], [76.9392395, 14.18680859], [76.94153595, 14.17803001], [76.93924713, 14.1677103], [76.9369812, 14.16589165], [76.922966, 14.1633997], [76.91718292, 14.15767097], [76.89675903, 14.16190147], [76.89142609, 14.15899944], [76.88919067, 14.15087891], [76.88691711, 14.13624001], [76.88368225, 14.13103199], [76.89090729, 14.127841], [76.89846802, 14.12687969], [76.9125061, 14.12210941], [76.91712952, 14.12448025], [76.92241669, 14.12903976], [76.92697906, 14.12720966], [76.93739319, 14.11515141], [76.94291687, 14.11190128], [76.94658661, 14.10297108], [76.94822693, 14.09658146], [76.94854736, 14.09141159], [76.94629669, 14.08526039], [76.95143127, 14.08537197], [76.96012115, 14.08296967], [76.96808624, 14.07973957], [76.97184753, 14.07571125], [76.97225189, 14.06840134], [76.9750061, 14.06527042], [76.97421265, 14.05770969], [76.9715271, 14.05239105], [76.94972992, 14.04784107], [76.94328308, 14.04721928], [76.93797302, 14.04759979], [76.93371582, 14.04067135], [76.93109894, 14.02273178], [76.94078064, 14.02060127], [76.94232941, 14.01548004], [76.9447403, 14.0106802], [76.94857025, 14.00677967], [76.96420288, 14.00224018], [76.97518158, 13.99658966], [76.97764587, 13.99386024], [76.97734833, 13.99387074], [76.98501587, 13.98752022], [76.99437714, 13.98149109], [76.99133301, 13.97581196], [76.99019623, 13.97027969], [76.98899841, 13.95669174], [76.99433136, 13.95337963], [76.99505615, 13.9527216], [76.99942017, 13.95044041], [77.00810242, 13.94736958], [77.01397705, 13.93948174], [77.01860046, 13.93479156], [77.0358429, 13.92559147], [77.04128265, 13.8973999], [77.02780914, 13.89717007], [77.01728058, 13.89337063], [77.01661682, 13.88772964], [77.01169586, 13.87144089], [77.01259613, 13.86723995], [77.01230621, 13.86409092], [77.00802612, 13.86290073], [77.00711823, 13.85417175], [77.00598907, 13.85009003], [76.994133, 13.83897018], [76.9899292, 13.83950996], [76.98625946, 13.83922958], [76.9839859, 13.82774067], [76.97653961, 13.82136059], [76.97155762, 13.81886101], [76.96839142, 13.81439018], [76.96882629, 13.8102417], [76.98002625, 13.80719185], [76.98371887, 13.80418968], [76.98577881, 13.79300022], [76.98484802, 13.78870106], [76.98123169, 13.78579998], [76.98435974, 13.77657032], [76.98634338, 13.76652145], [76.98898315, 13.76018047], [76.99012756, 13.7530899], [76.99212646, 13.74950886], [76.99167633, 13.7453413], [76.99259186, 13.74255085], [76.993927, 13.74151039], [77.00193787, 13.73666191], [77.0114212, 13.73272133], [77.01384735, 13.74747181], [77.01844025, 13.76169968], [77.01986694, 13.76986027], [77.02636719, 13.77144146], [77.03518677, 13.76928139], [77.04734802, 13.75607967], [77.05474854, 13.74450016], [77.06004333, 13.73886108], [77.07148743, 13.73875046], [77.08058929, 13.73739147], [77.07927704, 13.74602032], [77.08036041, 13.75342274], [77.08521271, 13.75455093], [77.08577728, 13.758111], [77.09526825, 13.76088047], [77.11094666, 13.75462055], [77.1235199, 13.75089073], [77.1341095, 13.75303078], [77.13751984, 13.75565243], [77.14673615, 13.75475121], [77.15815735, 13.75493145], [77.1665802, 13.75466919], [77.16964722, 13.76136971], [77.17134094, 13.7720499], [77.16918945, 13.77556038], [77.16407013, 13.78035069], [77.15849304, 13.78710079], [77.15599823, 13.79331017], [77.15573883, 13.79814243], [77.15409851, 13.8005619], [77.15632629, 13.80375957], [77.15537262, 13.80739021], [77.15619659, 13.81134033], [77.16194153, 13.81546116], [77.1622467, 13.8207407], [77.15791321, 13.82547092], [77.14789581, 13.82885075], [77.14576721, 13.83493996], [77.14045715, 13.83788967], [77.12526703, 13.8430109], [77.12388611, 13.84939003], [77.13015747, 13.84993935], [77.13938904, 13.85904026], [77.14821625, 13.85980129], [77.16249084, 13.85698032], [77.16491699, 13.86621857], [77.1623764, 13.87629128], [77.16171265, 13.88243103], [77.15702057, 13.89130116], [77.15593719, 13.89981174], [77.15956116, 13.90846062], [77.17006683, 13.91634178], [77.17703247, 13.91740036], [77.18161774, 13.91077042], [77.18221283, 13.90130043], [77.18134308, 13.89118958], [77.17920685, 13.88328075], [77.17959595, 13.87833118], [77.17822266, 13.8713913], [77.17513275, 13.8614006], [77.17880249, 13.85984039], [77.19271088, 13.8562212], [77.19689178, 13.85953045], [77.20095825, 13.86651993], [77.20256805, 13.87484074], [77.2049408, 13.88116074], [77.20884705, 13.87843132], [77.20812225, 13.86040115], [77.2115097, 13.86141872], [77.21700287, 13.86926174], [77.22093201, 13.8817606], [77.22189331, 13.88883114], [77.22547913, 13.89546967], [77.23384094, 13.89493179], [77.24009705, 13.89408016], [77.24156189, 13.88885117], [77.23882294, 13.88150978], [77.23925018, 13.87359047], [77.24073792, 13.86588192], [77.24373627, 13.86029053], [77.2530365, 13.85612106], [77.2504425, 13.83947086], [77.25595093, 13.83945084], [77.27514648, 13.84280109], [77.28292847, 13.84097958], [77.28552246, 13.84603119], [77.28970337, 13.85002232], [77.29602814, 13.8535614], [77.30693054, 13.85723972], [77.31088257, 13.85113144], [77.31616211, 13.83973122], [77.32000732, 13.8257513], [77.32724762, 13.82479191], [77.33468628, 13.82942009], [77.3398819, 13.83484936], [77.34697723, 13.83958054], [77.35220337, 13.84438133], [77.35946655, 13.8456707], [77.36753845, 13.84320927], [77.3731308, 13.83819103], [77.37285614, 13.83128929], [77.38111115, 13.83125114], [77.38983917, 13.83292961], [77.39920044, 13.83242035], [77.40393066, 13.83142185], [77.41873932, 13.83353043], [77.42453003, 13.83512974], [77.42624664, 13.82973003], [77.42472076, 13.82668972], [77.41506195, 13.81536007], [77.41275787, 13.81175041], [77.41368103, 13.80738068], [77.40820313, 13.80247021], [77.40866089, 13.79925156], [77.41158295, 13.79889107], [77.41470337, 13.80019093], [77.41925812, 13.79971027], [77.41954041, 13.79580116], [77.41689301, 13.79094028], [77.4200592, 13.78896141], [77.42865753, 13.78798962], [77.43546295, 13.79923058], [77.44056702, 13.80229187], [77.44676971, 13.80202961], [77.45559692, 13.79981041], [77.45745087, 13.79705048], [77.4527359, 13.79131985], [77.45079041, 13.78553104], [77.45240021, 13.78040123], [77.4539566, 13.77804184], [77.4587326, 13.74981022], [77.46212006, 13.74905109], [77.46261597, 13.74357891], [77.46006012, 13.73388958], [77.45809937, 13.73033047], [77.45806885, 13.72303867], [77.45684814, 13.71263981], [77.45340729, 13.70409966], [77.44600677, 13.70063972], [77.44481659, 13.69576073], [77.44975281, 13.67579079], [77.47648621, 13.67759991], [77.48294067, 13.67970181], [77.48513794, 13.68669033], [77.48352051, 13.69170094], [77.48239899, 13.6988306], [77.47972107, 13.70321083], [77.48734283, 13.70679188], [77.50276947, 13.7044096], [77.50679016, 13.70047092], [77.50691986, 13.69266129], [77.50797272, 13.68879986], [77.5123291, 13.68568039], [77.52152252, 13.68787003], [77.5255661, 13.69721031], [77.52783966, 13.70703125], [77.52754211, 13.71903038], [77.52659607, 13.72525024], [77.52268982, 13.73107147], [77.51512146, 13.73703957], [77.51966858, 13.74384975], [77.52950287, 13.74585056], [77.53951263, 13.74372005], [77.54155731, 13.73493195], [77.54514313, 13.72818089], [77.54814148, 13.72040939], [77.55607605, 13.71646023], [77.56661987, 13.72938919], [77.57363129, 13.72665024], [77.58154297, 13.73057175], [77.5868988, 13.7367897], [77.59559631, 13.74357891], [77.60427094, 13.74255085], [77.61564636, 13.72836113], [77.62124634, 13.72740173], [77.62851715, 13.72994137], [77.63356018, 13.73283958], [77.63674927, 13.73524189], [77.63375092, 13.74129105], [77.61264801, 13.74687004], [77.610466, 13.75543976], [77.61434937, 13.76031017], [77.649086, 13.77583981], [77.65659332, 13.77666092], [77.66401672, 13.77587032], [77.67022705, 13.7774992], [77.67176819, 13.77013111], [77.66979218, 13.76255989], [77.66371155, 13.75226021], [77.66850281, 13.75228119], [77.67881775, 13.75568104], [77.68467712, 13.75862122], [77.69552612, 13.76143169], [77.70218658, 13.73099136], [77.70736694, 13.73418045], [77.70874786, 13.73273945], [77.71100616, 13.73771], [77.71346283, 13.74615002], [77.7131424, 13.75074005], [77.71420288, 13.76079082], [77.7127533, 13.7747097], [77.71512604, 13.78327179], [77.71286011, 13.79051971], [77.71849823, 13.79272175], [77.72841644, 13.80173969], [77.7335968, 13.80344105], [77.74102783, 13.803792], [77.74817657, 13.80620956], [77.75533295, 13.80754089], [77.76921082, 13.8085413], [77.77848816, 13.81289196], [77.78044128, 13.8166914], [77.78026581, 13.82002068], [77.77742767, 13.82406044], [77.77410126, 13.83173084], [77.77603912, 13.8359108], [77.78637695, 13.83992004], [77.79453278, 13.84095955], [77.80278015, 13.84066963], [77.80784607, 13.8466711], [77.81080627, 13.85211182], [77.82772064, 13.86061954], [77.81920624, 13.86602116], [77.82724762, 13.87160015], [77.82504272, 13.87990093], [77.82099152, 13.88923168], [77.81468964, 13.89111042], [77.81108093, 13.89470196], [77.80737305, 13.90322971], [77.80635834, 13.90864086], [77.80635071, 13.91755009], [77.80848694, 13.9225893], [77.81423187, 13.93100166], [77.81829071, 13.93488121], [77.82158661, 13.93054104], [77.83011627, 13.92715168], [77.84600067, 13.92832088], [77.85407257, 13.9270792], [77.86242676, 13.92680073], [77.88698578, 13.93118191], [77.88786316, 13.92772198], [77.88732147, 13.91774082], [77.88968658, 13.9113512], [77.89570618, 13.90771961], [77.90045166, 13.90234089], [77.90593719, 13.89945126], [77.91160583, 13.89724064], [77.91980743, 13.89870167], [77.92973328, 13.90880966], [77.93564606, 13.91790962], [77.93885803, 13.92461967], [77.94602203, 13.92843056], [77.9490509, 13.92673969], [77.95075989, 13.92792034], [77.95426941, 13.93704987], [77.95532227, 13.94190025], [77.96127319, 13.9499712], [77.96643066, 13.95055199], [77.97857666, 13.94765091], [77.97795105, 13.93762016], [77.97351074, 13.92422962], [77.97336578, 13.91988182], [77.97460175, 13.91225147], [77.97466278, 13.90533161], [77.97802734, 13.89334965], [77.97161865, 13.88858891], [77.9495163, 13.88447094], [77.94246674, 13.8802309], [77.94184113, 13.87105083], [77.94571686, 13.83980179], [77.94805145, 13.82936096], [77.94814301, 13.82480145], [77.94458008, 13.81997108], [77.96578217, 13.82015991], [77.97038269, 13.82664204], [77.98123932, 13.84879971], [77.98226929, 13.85680199], [77.98516083, 13.86166954], [77.99149323, 13.86241055], [78.004776, 13.86171055], [78.01033783, 13.85649014], [78.01558685, 13.85438156], [78.03782654, 13.85284996], [78.04133606, 13.8580513], [78.04292297, 13.86378098], [78.04270172, 13.87337971], [78.04115295, 13.88672924], [78.04831696, 13.88453007], [78.05471039, 13.87935162], [78.06034851, 13.87678146], [78.06796265, 13.8745203], [78.07092285, 13.87195969], [78.07491302, 13.85491943], [78.08837891, 13.85491943], [78.09736633, 13.85276127], [78.10604095, 13.85354137], [78.11353302, 13.84089088], [78.11725616, 13.82177162], [78.10765839, 13.80360031], [78.10900116, 13.79836273], [78.11517334, 13.78767967], [78.11823273, 13.77690029], [78.11100769, 13.76175117], [78.10649872, 13.75679111], [78.10119629, 13.75298977], [78.09532166, 13.75028038], [78.08927155, 13.74304962], [78.08492279, 13.7334919], [78.09327698, 13.72762108], [78.09738922, 13.72315121], [78.10044098, 13.71801186], [78.1055069, 13.71463203], [78.10938263, 13.71023083], [78.10988617, 13.70395184], [78.10721588, 13.69835186], [78.1053772, 13.68440056], [78.09986877, 13.68256187], [78.08515167, 13.68063164], [78.0640564, 13.68817997], [78.06260681, 13.68560028], [78.06537628, 13.68006039], [78.06408691, 13.67455959], [78.06092072, 13.6717701], [78.05834198, 13.66697025], [78.06585693, 13.6644907], [78.07280731, 13.65517139], [78.07998657, 13.65038967], [78.07965851, 13.64454174], [78.08072662, 13.63534069], [78.08634949, 13.63350105], [78.09060669, 13.63300037], [78.09390259, 13.6402607], [78.10736084, 13.64709187], [78.1158905, 13.64563084], [78.12322998, 13.64890099], [78.12908936, 13.64826965], [78.14617157, 13.64966011], [78.15576172, 13.64871025], [78.15899658, 13.64517117], [78.16053772, 13.62343025], [78.16555786, 13.62097073], [78.18583679, 13.62117958], [78.19393921, 13.61615944], [78.19536591, 13.6015501], [78.19374084, 13.59490204], [78.18856812, 13.58840179], [78.17946625, 13.57894135], [78.18105316, 13.5737009], [78.18012238, 13.56417179], [78.18161011, 13.5591507], [78.18327332, 13.55638027], [78.18900299, 13.55638027], [78.19583893, 13.56068134], [78.20240021, 13.56796932], [78.20849609, 13.58188057], [78.21479034, 13.58010101], [78.21840668, 13.57800198], [78.22261047, 13.57709026], [78.22769165, 13.58722115], [78.23655701, 13.58449078], [78.24967957, 13.57430077], [78.25827026, 13.57530975], [78.26539612, 13.57822132], [78.28058624, 13.577672], [78.2918396, 13.57882023], [78.31247711, 13.58350182], [78.3228302, 13.58299065], [78.34366608, 13.57778072], [78.36139679, 13.57887268], [78.36709595, 13.58030033], [78.38031769, 13.58130932], [78.39076233, 13.5781002], [78.39389801, 13.57065201], [78.39775848, 13.56619167], [78.38600922, 13.54395199], [78.38546753, 13.53166962], [78.37309265, 13.5122509], [78.37419128, 13.50551033], [78.36958313, 13.49993038], [78.36728668, 13.49517155], [78.36828613, 13.48976994], [78.3674469, 13.48197079], [78.36728668, 13.46685123], [78.3635788, 13.45924091], [78.36255646, 13.45207119], [78.36419678, 13.44561195], [78.36416626, 13.43791103], [78.36463165, 13.43685055], [78.36702728, 13.4312706], [78.36531067, 13.42439079], [78.3673172, 13.41500092], [78.36946106, 13.40894985], [78.37127686, 13.3971796], [78.37127686, 13.39100075], [78.36871338, 13.37981129], [78.36444855, 13.37049103], [78.3598175, 13.36432171], [78.35515594, 13.35507107], [78.35640717, 13.34671974], [78.35839844, 13.34684086], [78.36051178, 13.34696198], [78.3640213, 13.34830189], [78.36818695, 13.34831142], [78.37477112, 13.3464098], [78.38366699, 13.34235096], [78.38491058, 13.33820057], [78.39253235, 13.33554077], [78.39737701, 13.33233166], [78.39523315, 13.32256985], [78.39125061, 13.32371044], [78.38838959, 13.31845188], [78.38456726, 13.32354069], [78.37899017, 13.32452106], [78.3753891, 13.32640171], [78.37754059, 13.33131981], [78.37129211, 13.33240891], [78.36791229, 13.3284893], [78.36699677, 13.32003975], [78.37512207, 13.31859112], [78.37914276, 13.31687927], [78.38291168, 13.3140707], [78.39125061, 13.30370998], [78.40206146, 13.30737972], [78.40706635, 13.31009197], [78.41526031, 13.31713009], [78.42077637, 13.3190918], [78.42446899, 13.31910133], [78.42682648, 13.31807995], [78.42906952, 13.31711197], [78.43031311, 13.3078289], [78.43598175, 13.29835033], [78.43785858, 13.29876041], [78.44130707, 13.29950142], [78.44507599, 13.30139923], [78.44790649, 13.30281925], [78.45417786, 13.30414963], [78.46053314, 13.30792046], [78.46640015, 13.31012154], [78.47174835, 13.30792046], [78.4701767, 13.29390144], [78.47255707, 13.29113197], [78.48352814, 13.28808022], [78.49521637, 13.279212], [78.50115967, 13.27721119], [78.50392914, 13.27245045], [78.5083313, 13.26947117], [78.51197052, 13.25995064], [78.51550293, 13.2571497], [78.52079773, 13.25559139], [78.52229309, 13.25811195], [78.52377319, 13.26062107], [78.52561951, 13.26929092], [78.52876282, 13.27586174], [78.53327179, 13.27600098], [78.53557587, 13.27608013], [78.54361725, 13.27323246], [78.54717255, 13.27267075], [78.55060577, 13.27602959], [78.55323029, 13.28462029], [78.55413818, 13.2983017], [78.55565643, 13.29942989], [78.56009674, 13.29334927], [78.56156158, 13.28803921], [78.56443787, 13.28341007], [78.56716919, 13.27177143], [78.57611084, 13.2671299], [78.57746887, 13.26204967], [78.57215118, 13.24860096], [78.56854248, 13.24353027], [78.56321716, 13.23841095], [78.55989075, 13.23337173], [78.5594101, 13.23038197], [78.55887604, 13.22713089], [78.55719757, 13.21202087], [78.56433105, 13.20805073], [78.56867981, 13.20426273], [78.56588745, 13.20088959], [78.56012726, 13.19820023], [78.5583725, 13.19218063], [78.5532608, 13.18924141], [78.54094696, 13.18725109], [78.54247284, 13.18017006], [78.54688263, 13.17862034], [78.55349731, 13.17987061], [78.55647278, 13.179842], [78.55940247, 13.17980099], [78.56333923, 13.17740059], [78.56472778, 13.17404079], [78.56568146, 13.17175102], [78.56907654, 13.1564827], [78.56536865, 13.15681076], [78.56125641, 13.15570068], [78.55805969, 13.15234184], [78.54685974, 13.15343094], [78.53878021, 13.15157127], [78.53369904, 13.14610958], [78.53269958, 13.14209175], [78.53669739, 13.13693047], [78.53544617, 13.13074017], [78.52143097, 13.12905121], [78.51291656, 13.12023067], [78.50875092, 13.11958981], [78.50869751, 13.11326981], [78.51113892, 13.10632992], [78.5161972, 13.10081959], [78.52237701, 13.09966183], [78.52796173, 13.09735966], [78.51480865, 13.09111023], [78.5138092, 13.08468056], [78.50681305, 13.08419132], [78.50192261, 13.08166122], [78.49958038, 13.07582188], [78.4985733, 13.06979084], [78.50479889, 13.05937958], [78.50457764, 13.05276203], [78.48792267, 13.04972076], [78.48750305, 13.04939079], [78.48108673, 13.04438972], [78.47738647, 13.04322147], [78.47107697, 13.04385853], [78.46704865, 13.04137135], [78.46472168, 13.03489971], [78.46105194, 13.03201008], [78.45500946, 13.03259087], [78.45157623, 13.03153229], [78.4506073, 13.0282402], [78.44991302, 13.0258112], [78.45036316, 13.01487064], [78.45263672, 13.00858116], [78.45231628, 13.00376034], [78.45542145, 12.99009037], [78.46142578, 12.97912025], [78.45939636, 12.97575188], [78.45759583, 12.97066021], [78.457901, 12.96324158], [78.43358612, 12.96877956], [78.42565155, 12.96977139], [78.4226532, 12.96860027], [78.42191315, 12.96274853], [78.42282104, 12.95773125], [78.42384338, 12.95440102], [78.42735291, 12.95053101], [78.420578, 12.94764996], [78.41977692, 12.94668198], [78.42459106, 12.93820953], [78.42328644, 12.93379974], [78.42035675, 12.92895889], [78.4213562, 12.92352962], [78.4259491, 12.91713047], [78.43447113, 12.90827084], [78.4412384, 12.90563202], [78.44290161, 12.90411186], [78.4490509, 12.8966589], [78.45613098, 12.89275265], [78.45833588, 12.87972069], [78.45694733, 12.8660593], [78.45423889, 12.85316181], [78.45211792, 12.85572147], [78.45266724, 12.86549187], [78.44644165, 12.87473202], [78.43849182, 12.87974072], [78.43830109, 12.88624096], [78.43570709, 12.88885975], [78.43582916, 12.90067005], [78.42640686, 12.90206146], [78.42489624, 12.89817047], [78.42465973, 12.89341068], [78.41734314, 12.88903141], [78.41152954, 12.89089966], [78.40291595, 12.89132118], [78.39953613, 12.89620113], [78.38839722, 12.90552044], [78.38508606, 12.89625072], [78.38337708, 12.89540958], [78.37834167, 12.89519119], [78.36868286, 12.90178013], [78.36097717, 12.91161919], [78.34542847, 12.92806053], [78.34076691, 12.92492008], [78.34041595, 12.92198944], [78.34398651, 12.91809177], [78.33827209, 12.91575146], [78.33773041, 12.91312122], [78.33833313, 12.90649986], [78.32718658, 12.88923073], [78.32216644, 12.88960075], [78.31645966, 12.89261055], [78.31347656, 12.88862133], [78.31240845, 12.88330078], [78.31328583, 12.87977123], [78.30996704, 12.87648201], [78.31093597, 12.8738308], [78.31617737, 12.87220192], [78.32141876, 12.87165928], [78.32271576, 12.87619019], [78.32749176, 12.8740406], [78.32271576, 12.86785126], [78.32158661, 12.86285019], [78.31105042, 12.86537075], [78.30409241, 12.8657608], [78.30622101, 12.85647106], [78.30310059, 12.84720039], [78.27568817, 12.84916019], [78.27056885, 12.8505497], [78.26262665, 12.85659027], [78.25814819, 12.85562992], [78.25382233, 12.8495903], [78.24874878, 12.8498497], [78.24465942, 12.85110092], [78.2410965, 12.84742069], [78.24186707, 12.8123312], [78.24021912, 12.80314159], [78.23542786, 12.78757954], [78.22949982, 12.76200962], [78.22512054, 12.75493145], [78.22064972, 12.75259018], [78.21248627, 12.75506973], [78.20233917, 12.75507927], [78.1989212, 12.75509071], [78.19538116, 12.7575407], [78.19024658, 12.76107979], [78.18395996, 12.76260853], [78.17871857, 12.75992012], [78.17530823, 12.76331139], [78.16615295, 12.76500034], [78.16156006, 12.76226139], [78.15814209, 12.76022053], [78.14771271, 12.76329994], [78.14302826, 12.76664066], [78.1364975, 12.76916027], [78.13163757, 12.76966953], [78.12711334, 12.77015972], [78.1206665, 12.7700119], [78.117836, 12.77989197], [78.11448669, 12.78707123], [78.10946655, 12.79140186], [78.10205078, 12.7933979], [78.09765625, 12.79592991], [78.09514618, 12.80023098], [78.08647919, 12.80333996], [78.08246613, 12.80915165], [78.0761261, 12.82051086], [78.07367706, 12.821311], [78.06594849, 12.81893063], [78.06639862, 12.82668114], [78.06456757, 12.83016968], [78.05139923, 12.83230972], [78.05060577, 12.83858204], [78.04673004, 12.84237003], [78.04202271, 12.8421011], [78.04000854, 12.83821106], [78.02215576, 12.84122086], [78.01957703, 12.84620953], [78.0149231, 12.84592056], [78.01435852, 12.84298992], [78.01685333, 12.83836079], [78.01677704, 12.83352947], [78.00907898, 12.83370018], [78.00711823, 12.82820129], [78.00804901, 12.82296085], [78.00712585, 12.8200407], [78.00382233, 12.8179493], [77.9998703, 12.81904125], [77.99330139, 12.81367111], [78.0032959, 12.80583096], [78.00559998, 12.80326939], [78.0014801, 12.79543972], [77.98972321, 12.79719067], [77.98602295, 12.79530144], [77.98139954, 12.79564095], [77.98134613, 12.81042099], [77.97457886, 12.81444168], [77.97360229, 12.81816959], [77.97129822, 12.82264042], [77.95746613, 12.82153034], [77.95501709, 12.82516003], [77.95800018, 12.83634186], [77.95522308, 12.83870983], [77.95134735, 12.83786201], [77.94684601, 12.83808136], [77.94856262, 12.84811974], [77.94555664, 12.8493309], [77.93860626, 12.84969139], [77.93345642, 12.84478092], [77.93255615, 12.83963108], [77.93612671, 12.83380985], [77.93990326, 12.82934856], [77.93297577, 12.81292057], [77.92479706, 12.8137207], [77.92076111, 12.81621933], [77.91825104, 12.81921196], [77.91047668, 12.81971073], [77.90923309, 12.82201958], [77.91182709, 12.83243084], [77.91487885, 12.83899021], [77.91533661, 12.84427071], [77.91844177, 12.84736061], [77.92780304, 12.85046959], [77.92878723, 12.85425091], [77.93105316, 12.85621071], [77.93444824, 12.85604], [77.93356323, 12.86168957], [77.91967773, 12.86349964], [77.91838074, 12.86887169], [77.92871857, 12.87143135], [77.92900848, 12.87477016], [77.92428589, 12.87784004], [77.9177475, 12.87837124], [77.91436768, 12.87354183], [77.90933228, 12.87295246], [77.90219879, 12.87337112], [77.90052032, 12.86788273], [77.89427948, 12.86822891], [77.8874588, 12.86692142], [77.88226318, 12.85839939], [77.87800598, 12.85928059], [77.86689758, 12.85861969], [77.86219025, 12.85692024], [77.85884857, 12.85762024], [77.85449982, 12.85673141], [77.84944153, 12.85786057], [77.84407043, 12.85589027], [77.83963013, 12.85585117], [77.83644867, 12.85763073], [77.83094025, 12.85786057], [77.82559967, 12.85898972], [77.82224274, 12.85461998], [77.82209015, 12.8498497], [77.81704712, 12.84898186], [77.81362915, 12.84401131], [77.80902863, 12.84272957], [77.80493927, 12.84275055], [77.79981995, 12.83784103], [77.79196167, 12.83983135], [77.78948975, 12.83877087], [77.78859711, 12.83535004], [77.78488159, 12.83380985], [77.78356171, 12.82825089], [77.78803253, 12.82364178], [77.79232025, 12.82137012], [77.80101776, 12.82080936], [77.79868317, 12.8117609], [77.80066681, 12.80562973], [77.79876709, 12.80491924], [77.79441071, 12.80580997], [77.79136658, 12.79631996], [77.79650116, 12.78961945], [77.79949188, 12.78685856], [77.7979126, 12.78292084], [77.79353333, 12.78387165], [77.78793335, 12.78132057], [77.78304291, 12.77612019], [77.7815094, 12.77103138], [77.77162933, 12.75983143], [77.77163696, 12.75477791], [77.77384949, 12.75113201], [77.77829742, 12.74787045], [77.78497314, 12.74505138], [77.78292084, 12.73882198], [77.77807617, 12.73367119], [77.76695251, 12.72963047], [77.75836945, 12.72931957], [77.75306702, 12.72509861], [77.75166321, 12.71840096], [77.75557709, 12.71557045], [77.76303864, 12.71446037], [77.76152802, 12.70771027], [77.75733948, 12.70398998], [77.75598145, 12.69705009], [77.75023651, 12.68716145], [77.7470932, 12.68664074], [77.74001312, 12.68855095], [77.73355865, 12.69147968], [77.72725677, 12.68287182], [77.730896, 12.67797089], [77.73320007, 12.67189121], [77.73140717, 12.66397953], [77.7232132, 12.66321182], [77.71839905, 12.66198063], [77.71531677, 12.6630106], [77.71412659, 12.66539097], [77.71411133, 12.67027855], [77.70381927, 12.67374134], [77.70178986, 12.65824986], [77.69547272, 12.6512394], [77.68753052, 12.65190029], [77.67835999, 12.6490202], [77.6733017, 12.65042973], [77.66780853, 12.65063953], [77.66738129, 12.65283012], [77.66929626, 12.66193962], [77.66590881, 12.66436005], [77.67030334, 12.6712389], [77.65428925, 12.67416954], [77.63878632, 12.67014027], [77.6329422, 12.67013073], [77.60943604, 12.66335106], [77.59783936, 12.65902042], [77.59033966, 12.65754128], [77.58927917, 12.64825153], [77.58796692, 12.6426897], [77.58937073, 12.63664246], [77.59169006, 12.63275146], [77.59552002, 12.63043118], [77.594841, 12.62710953], [77.59781647, 12.62102032], [77.59352875, 12.6165514], [77.58539581, 12.61193085], [77.5821228, 12.60508919], [77.58145905, 12.58423138], [77.57422638, 12.56723118], [77.57119751, 12.56354141], [77.5700531, 12.5579319], [77.57235718, 12.54042053], [77.57644653, 12.5368309], [77.57763672, 12.52347088], [77.57982635, 12.51148129], [77.57850647, 12.50701141], [77.59516144, 12.50366974], [77.60520172, 12.50333023], [77.60636902, 12.49979115], [77.60473633, 12.49488163], [77.60177612, 12.49166107], [77.58249664, 12.47631073], [77.57536316, 12.46837997], [77.59664917, 12.4646101], [77.6108017, 12.4780407], [77.61728668, 12.48550987], [77.62520599, 12.47726154], [77.62169647, 12.45444965], [77.61815643, 12.4431324], [77.62010193, 12.43809032], [77.61694336, 12.42464066], [77.61712646, 12.41866112], [77.62065125, 12.41376019], [77.62008667, 12.40847969], [77.61582947, 12.40488052], [77.61329651, 12.39780045], [77.61094666, 12.38564968], [77.60987854, 12.3736496], [77.60753632, 12.36765957], [77.6063385, 12.36026001], [77.60382843, 12.35375118], [77.60024261, 12.35122108], [77.59120178, 12.3491993], [77.58616638, 12.3363018], [77.57530975, 12.32625103], [77.56859589, 12.32419014], [77.56603241, 12.31670094], [77.55609894, 12.29716015], [77.54515076, 12.29269028], [77.54270935, 12.28371143], [77.53954315, 12.28239059], [77.52352142, 12.28100109], [77.51834106, 12.2695303], [77.50208282, 12.2663002], [77.49796295, 12.2683897], [77.49318695, 12.27279091], [77.4906311, 12.27305984], [77.48423004, 12.2697897], [77.47844696, 12.26965141], [77.4752121, 12.26597023], [77.4701767, 12.26187038], [77.46723175, 12.25318241], [77.46666718, 12.24847126], [77.46350098, 12.24403954], [77.46295166, 12.23577118], [77.46676636, 12.23398018], [77.47366333, 12.22494125], [77.47229004, 12.21726036], [77.4683609, 12.21019936], [77.46566772, 12.20226097], [77.46923828, 12.19651127], [77.47493744, 12.19582939], [77.47875214, 12.19398117], [77.48248291, 12.19011974], [77.49246216, 12.18719196], [77.51130676, 12.18397141], [77.51979828, 12.18866158], [77.52445221, 12.18824005], [77.52805328, 12.19001102], [77.53102112, 12.19014072], [77.53341675, 12.19383144], [77.53852081, 12.19448853], [77.54667664, 12.19037056], [77.55583191, 12.18711185], [77.56533813, 12.19045067], [77.56955719, 12.18807125], [77.58421326, 12.18884182], [77.59113312, 12.19056034], [77.59659576, 12.19530106], [77.60411835, 12.19516182], [77.61051941, 12.19159031], [77.61582184, 12.18978119], [77.62136841, 12.19170189], [77.62561035, 12.1897192], [77.62890625, 12.18632126], [77.63301086, 12.18642139], [77.64466858, 12.18857002], [77.65544891, 12.18774986], [77.6681366, 12.18371964], [77.67282104, 12.18138885], [77.7012558, 12.17259979], [77.71077728, 12.1733408], [77.71951294, 12.17152023], [77.72635651, 12.16732025], [77.7290802, 12.15995979], [77.73195648, 12.15461063], [77.73906708, 12.14785957], [77.74046326, 12.14258194], [77.74024963, 12.12928963], [77.74421692, 12.12669182], [77.74729156, 12.12232018], [77.75282288, 12.11797047], [77.76700592, 12.1091404], [77.76844788, 12.10559177], [77.76638794, 12.1009903], [77.76280975, 12.09748173], [77.75826263, 12.09440136], [77.75634003, 12.09195995], [77.75052643, 12.08051014], [77.74610138, 12.06932068], [77.73396301, 12.06022072], [77.72036743, 12.05335236], [77.71562195, 12.04850197], [77.71264648, 12.04138184], [77.70722961, 12.03328133], [77.70155334, 12.02714062], [77.69410706, 12.01519203], [77.68945313, 12.00994968], [77.68115234, 11.99123096], [77.6810379, 11.99123096], [77.67719269, 11.98427105], [77.66705322, 11.95893192], [77.66371155, 11.95296001], [77.664711, 11.93970013], [77.66044617, 11.93814087], [77.6548233, 11.93735886], [77.64675903, 11.93871117], [77.64341736, 11.94417191], [77.63949585, 11.94283199], [77.63672638, 11.94026089], [77.63021851, 11.93797016], [77.61517334, 11.93414974], [77.60372162, 11.93026924], [77.59596252, 11.92928028], [77.591362, 11.92633057], [77.58573151, 11.92945957], [77.5789566, 11.9282999], [77.57328796, 11.92401123], [77.54799652, 11.93074989], [77.53132629, 11.92649937], [77.52365112, 11.92148113], [77.51402283, 11.92568111], [77.51095581, 11.92534161], [77.50063324, 11.92723083], [77.49043274, 11.92973995], [77.48439789, 11.93239975], [77.48282623, 11.92869186], [77.48394012, 11.9214716], [77.48219299, 11.91214085], [77.47949982, 11.9003706], [77.47733307, 11.8952713], [77.47596741, 11.88955021], [77.47721863, 11.88177967], [77.47690582, 11.87601185], [77.47367096, 11.87780094], [77.4704361, 11.88361073], [77.46743011, 11.88321018], [77.46333313, 11.88727093], [77.45392609, 11.89055061], [77.45279694, 11.88853073], [77.45385742, 11.8819418], [77.45302582, 11.87589073], [77.45329285, 11.87089062], [77.45516205, 11.8672514], [77.45387268, 11.85733891], [77.45210266, 11.85323048], [77.45252991, 11.84910011], [77.45096588, 11.84431171], [77.45536041, 11.84268188], [77.45629883, 11.83912182], [77.45159149, 11.82341194], [77.44658661, 11.81626034], [77.44650269, 11.81149197], [77.44246674, 11.80647087], [77.44087219, 11.79134178], [77.43622589, 11.78176975], [77.43209076, 11.77894115], [77.43028259, 11.77667141], [77.43105316, 11.77168179], [77.42384338, 11.76608944], [77.4207077, 11.7602911], [77.41925049, 11.75067139], [77.4134903, 11.75115204], [77.4125061, 11.75612926], [77.41246796, 11.76228142], [77.40654755, 11.76233959], [77.40145111, 11.76403141], [77.38189697, 11.77616119], [77.36223602, 11.7758007], [77.35948944, 11.77879143], [77.35515594, 11.77837181], [77.35092926, 11.76858044], [77.34565735, 11.76406956], [77.32611847, 11.75893974], [77.31356049, 11.76998043], [77.30623627, 11.77870178], [77.29045105, 11.79416084], [77.28481293, 11.79836178], [77.28235626, 11.79286003], [77.27829742, 11.78973961], [77.27227783, 11.79117966], [77.24848175, 11.8008604], [77.24173737, 11.80245972], [77.24125671, 11.79399967], [77.23707581, 11.7881918], [77.22705078, 11.78374958], [77.21642303, 11.78476048], [77.20392609, 11.78447056], [77.18966675, 11.78281975], [77.17842102, 11.77952003], [77.17230225, 11.77573013], [77.16591644, 11.77423], [77.15541077, 11.77427101], [77.14379883, 11.77129936], [77.13723755, 11.7719717], [77.13459015, 11.76641083], [77.13102722, 11.7623806], [77.12738037, 11.76093197], [77.11972046, 11.76338196], [77.1138916, 11.76183033], [77.11096954, 11.76314926], [77.10282898, 11.7631197], [77.1053009, 11.75948048], [77.10610962, 11.75622082], [77.10573578, 11.75064087], [77.10323334, 11.74588013], [77.10540009, 11.73158073], [77.10830688, 11.72243023], [77.10929871, 11.71280098], [77.10367584, 11.71554947], [77.0962677, 11.72312069], [77.07588959, 11.72389126], [77.07163239, 11.72500992], [77.07385254, 11.72954082], [77.05010986, 11.75774956], [77.05438995, 11.76496124], [77.0618515, 11.77206135], [77.05654144, 11.77711964], [77.05253601, 11.77923107], [77.04569244, 11.77915955], [77.04125977, 11.7775898], [77.02757263, 11.76169968], [77.02233887, 11.76470089], [77.03026581, 11.77830124], [77.03167725, 11.78395081], [77.02767944, 11.78668976], [77.02855682, 11.78911972], [77.02275848, 11.79498196], [77.01857758, 11.79732037], [77.01344299, 11.79917145], [77.00884247, 11.79696178], [77.00443268, 11.80301952], [76.99035645, 11.79931927], [76.9821167, 11.79953957], [76.97277069, 11.80106926], [76.97341156, 11.79511166], [76.97483826, 11.79102135], [76.96539307, 11.77647972], [76.96330261, 11.77079964], [76.95960236, 11.76519966], [76.95316315, 11.7712698], [76.95025635, 11.77543068], [76.94444275, 11.7813406], [76.94032288, 11.78102016], [76.93580627, 11.77674198], [76.93239594, 11.77737141], [76.92666626, 11.78089046], [76.91348267, 11.78036976], [76.90679169, 11.78123188], [76.89968872, 11.78327179], [76.89335632, 11.77730274], [76.89150238, 11.77011204], [76.88796997, 11.76589966], [76.88934326, 11.76060104], [76.88851166, 11.75043201], [76.88600922, 11.74448109], [76.88172913, 11.73009014], [76.880867, 11.72459126], [76.87558746, 11.71789932], [76.86457062, 11.71053123], [76.8535614, 11.69878197], [76.85572815, 11.69433975], [76.84910583, 11.68721962], [76.84617615, 11.6824789], [76.84472656, 11.67737198], [76.84137726, 11.66977119], [76.83838654, 11.66466999], [76.83566284, 11.65607071], [76.83230591, 11.65266132], [76.83003235, 11.64904022], [76.82847595, 11.64410973], [76.82775116, 11.63842964], [76.829216, 11.63497066], [76.82969666, 11.62934113], [76.83309174, 11.62529087], [76.83882141, 11.62341976], [76.83798218, 11.6187706], [76.83825684, 11.61584187], [76.84155273, 11.61322117], [76.84581757, 11.61164093], [76.84588623, 11.60605145], [76.85090637, 11.60182953], [76.84733582, 11.58864021], [76.84375763, 11.58603096], [76.83728027, 11.57448006], [76.83596802, 11.58403015], [76.83349609, 11.58703136], [76.82993317, 11.58982086], [76.8236084, 11.59130001], [76.81651306, 11.59720993], [76.80832672, 11.59618187], [76.79075623, 11.59970093], [76.78082275, 11.60357094], [76.77377319, 11.60342979], [76.75139618, 11.60670853], [76.74626923, 11.61054134], [76.74104309, 11.60580921], [76.73542786, 11.60523033], [76.72020721, 11.60505009], [76.70749664, 11.60593891], [76.69309998, 11.6044302], [76.67904663, 11.60414124], [76.66443634, 11.60509968], [76.63372803, 11.60352993], [76.62565613, 11.60381889], [76.60787201, 11.60044193]]], [[[74.36514282, 14.55263996], [74.36514282, 14.55235958], [74.36597443, 14.55236244], [74.36597443, 14.55208206], [74.3677063, 14.55208206], [74.37208557, 14.55208206], [74.37208557, 14.55236244], [74.37291718, 14.55236244], [74.37291718, 14.55208206], [74.37319183, 14.55208206], [74.37319183, 14.55180645], [74.37346649, 14.55181122], [74.37346649, 14.55153275], [74.37374878, 14.55153275], [74.37374878, 14.55125046], [74.37403107, 14.55125046], [74.37403107, 14.55097198], [74.37430573, 14.55097198], [74.37430573, 14.55041599], [74.37458038, 14.55041981], [74.37458038, 14.55014038], [74.37486267, 14.55014038], [74.37486267, 14.54986191], [74.37513733, 14.54986191], [74.37513733, 14.54957867], [74.37541962, 14.54958439], [74.37541962, 14.54930592], [74.37568665, 14.54930973], [74.37568665, 14.5490303], [74.37596893, 14.5490303], [74.37596893, 14.54874992], [74.37625122, 14.54874992], [74.37625122, 14.54681015], [74.3779068, 14.54681015], [74.3779068, 14.54597187], [74.37819672, 14.54597187], [74.37819672, 14.54541779], [74.37708282, 14.54541969], [74.37708282, 14.54514027], [74.37596893, 14.54514027], [74.37596893, 14.54486179], [74.37568665, 14.54486179], [74.37568665, 14.54456997], [74.37513733, 14.54458427], [74.37513733, 14.5443058], [74.37486267, 14.54430962], [74.37486267, 14.54403019], [74.37431335, 14.54403019], [74.37431335, 14.54347134], [74.37403107, 14.54347134], [74.37403107, 14.54291534], [74.37431335, 14.54292202], [74.37431335, 14.54264164], [74.37458038, 14.54264164], [74.37458038, 14.54236126], [74.37486267, 14.54236126], [74.37486267, 14.54208279], [74.37513733, 14.54208279], [74.37513733, 14.54180527], [74.37404633, 14.54181385], [74.37346649, 14.54182053], [74.37346649, 14.54152966], [74.37124634, 14.54152966], [74.37124634, 14.54182053], [74.37041473, 14.54180527], [74.37041473, 14.54208279], [74.36791992, 14.54208279], [74.36791992, 14.54180527], [74.36763763, 14.54182053], [74.36763763, 14.54152966], [74.36736298, 14.54152966], [74.36736298, 14.54124928], [74.36680603, 14.54124928], [74.36680603, 14.54152966], [74.36653137, 14.54152966], [74.36653137, 14.54182053], [74.36597443, 14.54180527], [74.36597443, 14.54208279], [74.36541748, 14.54208279], [74.36541748, 14.54236126], [74.36514282, 14.54236126], [74.36514282, 14.54264164], [74.36458588, 14.54264164], [74.36458588, 14.54292202], [74.36430359, 14.54291534], [74.36430359, 14.54319572], [74.36398315, 14.54319286], [74.36374664, 14.54319096], [74.36374664, 14.54375172], [74.36347198, 14.54374886], [74.36347198, 14.54458427], [74.36319733, 14.54456997], [74.36319733, 14.54486179], [74.36347198, 14.54486179], [74.36347198, 14.54569435], [74.36374664, 14.54569054], [74.36374664, 14.54652977], [74.36402893, 14.54652977], [74.36402893, 14.54930973], [74.36374664, 14.54930592], [74.36374664, 14.55208206], [74.36402893, 14.55208015], [74.36402893, 14.55263996], [74.36514282, 14.55263996]]]]}}, {\\\"id\\\": \\\"15\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.17_1\\\", \\\"HASC_1\\\": \\\"IN.KL\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Kerala\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -6.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 551.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1149.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -598.0, \\\"geo-id\\\": 15, \\\"hpm25_child_popweighted\\\": -110.2, \\\"hpm25_female_popweighted\\\": -126.7, \\\"hpm25_male_popweighted\\\": -91.2, \\\"location\\\": \\\"Kerala\\\", \\\"mort_apm25_6cod_mean_total\\\": 5462.0, \\\"mort_hpm25_6cod_mean_total\\\": -11123.0, \\\"mort_tpm25_6cod_mean_total\\\": -5661.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[76.40429688, 9.54152966], [76.40429688, 9.53986073], [76.40458679, 9.53986073], [76.40458679, 9.53708267], [76.40486145, 9.53708267], [76.40486145, 9.52763844], [76.40207672, 9.5276413], [76.40207672, 9.52735996], [76.38318634, 9.52735996], [76.38318634, 9.5276413], [76.38291931, 9.52763844], [76.38291931, 9.52875137], [76.38263702, 9.52875137], [76.38263702, 9.52902889], [76.38291931, 9.52902889], [76.38291931, 9.53042126], [76.38263702, 9.53041744], [76.38263702, 9.53069496], [76.38291931, 9.53069496], [76.38291931, 9.53208256], [76.38263702, 9.53208065], [76.38263702, 9.53292179], [76.38207245, 9.53292179], [76.38207245, 9.53375053], [76.38236237, 9.53375053], [76.38236237, 9.53403091], [76.38291931, 9.53403091], [76.38291931, 9.53431034], [76.38375092, 9.53430462], [76.38375092, 9.53458309], [76.38458252, 9.53458309], [76.38458252, 9.53486061], [76.38513947, 9.53486061], [76.38513947, 9.53514099], [76.38597107, 9.53514099], [76.38597107, 9.53541946], [76.38680267, 9.5354166], [76.38680267, 9.53569508], [76.38764191, 9.53569508], [76.38764191, 9.5359726], [76.38846588, 9.53597069], [76.38846588, 9.53625107], [76.38903046, 9.53624916], [76.38903046, 9.53652668], [76.38986206, 9.53652], [76.38986206, 9.53681183], [76.39069366, 9.53680515], [76.39069366, 9.53708267], [76.39152527, 9.53708267], [76.39152527, 9.53736115], [76.39235687, 9.53736115], [76.39235687, 9.53764153], [76.39319611, 9.53764153], [76.39319611, 9.53792191], [76.39375305, 9.53791714], [76.39375305, 9.53819466], [76.39458466, 9.53819466], [76.39458466, 9.53847122], [76.39541626, 9.53847122], [76.39541626, 9.5387516], [76.39624786, 9.5387516], [76.39624786, 9.53903198], [76.3970871, 9.53903198], [76.3970871, 9.53931046], [76.39763641, 9.53930473], [76.39763641, 9.53958321], [76.39847565, 9.53958321], [76.39847565, 9.53986073], [76.39930725, 9.53986073], [76.39930725, 9.54014015], [76.40013885, 9.54014015], [76.40013885, 9.54041958], [76.40097046, 9.54041767], [76.40097046, 9.54069328], [76.4015274, 9.54069328], [76.4015274, 9.5409708], [76.40235901, 9.54097366], [76.40235901, 9.54124928], [76.40318298, 9.54124928], [76.40319824, 9.54152966], [76.40429688, 9.54152966]]], [[[76.46736145, 9.5409708], [76.46736145, 9.54069328], [76.46847534, 9.54069328], [76.46847534, 9.54041767], [76.46901703, 9.54041958], [76.46901703, 9.54014015], [76.4695816, 9.54014015], [76.4695816, 9.53986073], [76.4706955, 9.53986073], [76.4706955, 9.53958321], [76.4715271, 9.53958321], [76.4715271, 9.53930473], [76.4723587, 9.53931046], [76.4723587, 9.53903198], [76.4734726, 9.53903198], [76.4734726, 9.5387516], [76.47429657, 9.5387516], [76.47429657, 9.53847122], [76.47458649, 9.53847122], [76.47458649, 9.53819466], [76.47624969, 9.53819466], [76.47624969, 9.53791714], [76.47680664, 9.53792191], [76.47680664, 9.53764153], [76.47763824, 9.53764153], [76.47763824, 9.53736115], [76.47846985, 9.53736115], [76.47846985, 9.53708267], [76.47902679, 9.53708267], [76.47902679, 9.53652668], [76.47930908, 9.53652668], [76.47930908, 9.53013897], [76.47902679, 9.53014088], [76.47902679, 9.52986145], [76.47125244, 9.52986145], [76.47125244, 9.52958298], [76.46763611, 9.52958298], [76.46763611, 9.52930546], [76.46736145, 9.52930546], [76.46736145, 9.52958298], [76.46652985, 9.52958298], [76.46652985, 9.52986145], [76.4659729, 9.52986145], [76.4659729, 9.53514099], [76.46624756, 9.53514099], [76.46624756, 9.53625107], [76.4659729, 9.53625107], [76.4659729, 9.53931046], [76.46624756, 9.53930473], [76.46624756, 9.5409708], [76.46736145, 9.5409708]]], [[[76.45207977, 9.54569435], [76.45291901, 9.54569435], [76.45291901, 9.54541588], [76.4540329, 9.54541969], [76.4540329, 9.54514027], [76.45513916, 9.54514027], [76.45513916, 9.54486179], [76.45569611, 9.54486179], [76.45569611, 9.54458237], [76.45652771, 9.54458427], [76.45652771, 9.5443058], [76.45735931, 9.54430962], [76.45735931, 9.54403019], [76.45819092, 9.54403019], [76.45819092, 9.54374981], [76.45847321, 9.54374981], [76.45847321, 9.54347229], [76.45930481, 9.54347229], [76.45930481, 9.54319572], [76.46013641, 9.54319572], [76.46013641, 9.5429163], [76.46098328, 9.54292011], [76.46098328, 9.54265118], [76.46180725, 9.54265118], [76.46180725, 9.54235935], [76.46263885, 9.54236221], [76.46263885, 9.54208374], [76.4631958, 9.54208374], [76.4631958, 9.54180622], [76.4640274, 9.54181004], [76.4640274, 9.54152966], [76.46457672, 9.54152966], [76.46457672, 9.54041958], [76.46485901, 9.54041958], [76.46485901, 9.53764153], [76.46457672, 9.53764153], [76.46457672, 9.53681183], [76.46430206, 9.53681183], [76.46430206, 9.53625107], [76.46457672, 9.53625107], [76.46457672, 9.53458118], [76.46430206, 9.53458309], [76.46430206, 9.53430462], [76.46457672, 9.53431034], [76.46457672, 9.53042126], [76.46430206, 9.53042126], [76.46430206, 9.52986145], [76.46263885, 9.52986145], [76.46263885, 9.52958298], [76.46180725, 9.52958298], [76.46180725, 9.52986145], [76.4604187, 9.52986145], [76.4604187, 9.52958298], [76.45791626, 9.52958298], [76.45791626, 9.52930546], [76.45375061, 9.52930546], [76.45375061, 9.52958298], [76.45319366, 9.52958298], [76.45319366, 9.52930546], [76.4465332, 9.52930927], [76.4465332, 9.52902889], [76.44513702, 9.52902889], [76.44513702, 9.52930927], [76.44431305, 9.52930927], [76.44431305, 9.52902889], [76.44235229, 9.52902889], [76.44235229, 9.52875137], [76.44013977, 9.52875137], [76.44013977, 9.5284729], [76.43958282, 9.5284729], [76.43958282, 9.52819538], [76.43930817, 9.52819538], [76.43930817, 9.52791691], [76.43846893, 9.52791691], [76.43846893, 9.52819538], [76.43708038, 9.52819538], [76.43708038, 9.5284729], [76.43680573, 9.5284729], [76.43680573, 9.52819538], [76.43597412, 9.52819538], [76.43597412, 9.5284729], [76.43541718, 9.5284729], [76.43541718, 9.53819466], [76.43569183, 9.53819466], [76.43569183, 9.54597187], [76.43597412, 9.54597187], [76.43597412, 9.54758072], [76.43597412, 9.55152798], [76.43680573, 9.55152798], [76.43680573, 9.55125046], [76.43736267, 9.55125046], [76.43736267, 9.55097198], [76.43763733, 9.55097198], [76.43763733, 9.55069447], [76.43846893, 9.55069447], [76.43846893, 9.55041599], [76.43875122, 9.55042076], [76.43875122, 9.55014038], [76.43985748, 9.55014038], [76.43985748, 9.54986], [76.44069672, 9.54986], [76.44069672, 9.54958439], [76.44125366, 9.54958439], [76.44125366, 9.54930592], [76.4420929, 9.54931068], [76.44208527, 9.54912186], [76.44208527, 9.5490284], [76.44291687, 9.5490303], [76.44291687, 9.54874992], [76.44374847, 9.54874992], [76.44374847, 9.54846096], [76.44458008, 9.5484724], [76.44458008, 9.54819393], [76.44486237, 9.54819393], [76.44486237, 9.54791641], [76.44541931, 9.54792118], [76.44541931, 9.54763985], [76.44735718, 9.54763985], [76.44735718, 9.54736042], [76.44819641, 9.54736233], [76.44819641, 9.54708195], [76.44902802, 9.54708195], [76.44902802, 9.54680634], [76.44957733, 9.5468111], [76.44957733, 9.54653263], [76.44985962, 9.54653263], [76.44985962, 9.54625034], [76.45069122, 9.54625034], [76.45069122, 9.54597187], [76.45207977, 9.54597187], [76.45207977, 9.54569435]]], [[[76.43458557, 9.55152798], [76.43458557, 9.55125046], [76.43486023, 9.55125046], [76.43486023, 9.54819393], [76.43458557, 9.54819393], [76.43458557, 9.54722977], [76.43458557, 9.54014015], [76.43430328, 9.54014015], [76.43430328, 9.53236103], [76.43402863, 9.53236103], [76.43402863, 9.5284729], [76.42791748, 9.5284729], [76.42791748, 9.52819538], [76.42124939, 9.52819538], [76.42124939, 9.52791691], [76.4145813, 9.52792072], [76.4145813, 9.5276413], [76.40625, 9.52763844], [76.40625, 9.52986145], [76.40598297, 9.52986145], [76.40598297, 9.53541946], [76.40569305, 9.53541946], [76.40569305, 9.54014015], [76.4054184, 9.54014015], [76.4054184, 9.54208374], [76.40569305, 9.54208374], [76.40569305, 9.54236221], [76.40651703, 9.54235935], [76.40651703, 9.54265118], [76.40735626, 9.54265118], [76.40735626, 9.54292011], [76.4081955, 9.5429163], [76.4081955, 9.54319572], [76.4090271, 9.54319572], [76.4090271, 9.54347229], [76.41014099, 9.54347229], [76.41014099, 9.54374981], [76.4109726, 9.54374981], [76.4109726, 9.54403019], [76.41159058, 9.54403019], [76.41179657, 9.54403019], [76.41179657, 9.54430962], [76.4126358, 9.5443058], [76.4126358, 9.54458427], [76.41348267, 9.54458237], [76.41348267, 9.54486179], [76.41430664, 9.54486179], [76.41430664, 9.54514027], [76.41513824, 9.54514027], [76.41513824, 9.54541969], [76.41596985, 9.54541588], [76.41596985, 9.54569435], [76.41680908, 9.54569435], [76.41680908, 9.54597187], [76.41764069, 9.54597187], [76.41764069, 9.54625034], [76.41847229, 9.54625034], [76.41847229, 9.54653263], [76.41902924, 9.54653263], [76.41902924, 9.5468111], [76.41986084, 9.54680634], [76.41986084, 9.54708195], [76.42069244, 9.54708195], [76.42069244, 9.54736233], [76.42151642, 9.54736042], [76.42151642, 9.54763985], [76.42236328, 9.54763985], [76.42236328, 9.54792118], [76.42319489, 9.54791641], [76.42319489, 9.54819393], [76.42402649, 9.54819393], [76.42402649, 9.5484724], [76.42485809, 9.54846096], [76.42485809, 9.54874992], [76.42542267, 9.54874992], [76.42542267, 9.5490303], [76.42624664, 9.5490303], [76.42624664, 9.54931068], [76.42708588, 9.54930592], [76.42708588, 9.54958439], [76.42819214, 9.54958439], [76.42819214, 9.54986], [76.42874908, 9.54986], [76.42874908, 9.55014038], [76.43013763, 9.55014038], [76.43013763, 9.55042076], [76.43125153, 9.55041599], [76.43125153, 9.55069447], [76.43208313, 9.55069447], [76.43208313, 9.55097198], [76.43347168, 9.55097198], [76.43347168, 9.55125046], [76.43430328, 9.55125046], [76.43430328, 9.55152798], [76.43458557, 9.55152798]]], [[[76.41430664, 9.56319523], [76.41430664, 9.56291676], [76.4145813, 9.56291962], [76.4145813, 9.56236076], [76.41485596, 9.56236076], [76.41485596, 9.56069088], [76.41513824, 9.56069469], [76.41513824, 9.5601387], [76.4154129, 9.56014061], [76.4154129, 9.55986118], [76.41513824, 9.55986118], [76.41513824, 9.55958271], [76.4154129, 9.55958271], [76.4154129, 9.55902672], [76.41570282, 9.55903053], [76.41570282, 9.55819035], [76.41625214, 9.55819511], [76.41625214, 9.55763912], [76.41707611, 9.55764961], [76.41707611, 9.55736065], [76.41819763, 9.55736065], [76.41819763, 9.55708313], [76.41902924, 9.55708313], [76.41902924, 9.55680466], [76.41958618, 9.55680466], [76.41958618, 9.55708313], [76.4201355, 9.55708313], [76.4201355, 9.55680466], [76.42124939, 9.55681133], [76.42124939, 9.55653095], [76.42151642, 9.55653095], [76.42151642, 9.55625057], [76.42208099, 9.55625057], [76.42208099, 9.55597019], [76.42292023, 9.55597305], [76.42292023, 9.55569458], [76.42319489, 9.55569458], [76.42319489, 9.55486012], [76.42375183, 9.55486012], [76.42375183, 9.55402946], [76.42402649, 9.55403137], [76.42402649, 9.55346966], [76.42430878, 9.55347157], [76.42430878, 9.55263805], [76.42457581, 9.55264091], [76.42457581, 9.55208015], [76.42485809, 9.55208206], [76.42485809, 9.55152798], [76.42514038, 9.55152798], [76.42514038, 9.55097198], [76.42569733, 9.55097198], [76.42569733, 9.54986], [76.42485809, 9.54986], [76.42485809, 9.54958439], [76.42402649, 9.54958439], [76.42402649, 9.54930592], [76.42318726, 9.54931068], [76.42318726, 9.5490303], [76.42236328, 9.5490303], [76.42236328, 9.54874992], [76.42151642, 9.54874992], [76.42151642, 9.54846096], [76.42069244, 9.5484724], [76.42069244, 9.54819393], [76.41986084, 9.54819393], [76.41986084, 9.54791641], [76.41902924, 9.54792118], [76.41902924, 9.54763985], [76.41819763, 9.54763985], [76.41819763, 9.54736042], [76.4173584, 9.54736233], [76.4173584, 9.54708195], [76.41652679, 9.54708195], [76.41652679, 9.54680634], [76.41570282, 9.5468111], [76.41570282, 9.54653263], [76.41513824, 9.54653263], [76.41513824, 9.54625034], [76.41430664, 9.54625034], [76.41430664, 9.54597187], [76.41347504, 9.54597187], [76.41347504, 9.54569435], [76.41291809, 9.54569435], [76.41291809, 9.54541588], [76.41208649, 9.54541969], [76.41208649, 9.54514027], [76.41152954, 9.54514027], [76.41152954, 9.54486179], [76.41088104, 9.54486179], [76.41069794, 9.54486179], [76.41069794, 9.54458237], [76.4098587, 9.54458427], [76.4098587, 9.5443058], [76.40930939, 9.54430962], [76.40930939, 9.54403019], [76.40847015, 9.54403019], [76.40847015, 9.54374981], [76.40763855, 9.54374981], [76.40763855, 9.54347229], [76.40680695, 9.54347229], [76.40680695, 9.54319572], [76.40569305, 9.54319572], [76.40569305, 9.5429163], [76.40486145, 9.54292011], [76.40486145, 9.54265118], [76.40374756, 9.54265118], [76.40374756, 9.54235935], [76.40319824, 9.54236221], [76.40319824, 9.54208374], [76.40208435, 9.54208374], [76.40208435, 9.54180622], [76.40125275, 9.54181004], [76.40125275, 9.54152966], [76.40040588, 9.54152966], [76.40040588, 9.54124928], [76.39958191, 9.54124928], [76.39958191, 9.5409708], [76.39902496, 9.5409708], [76.39902496, 9.54069328], [76.39819336, 9.54069328], [76.39819336, 9.54041767], [76.39763641, 9.54041958], [76.39763641, 9.54014015], [76.39679718, 9.54014015], [76.39679718, 9.53986073], [76.39597321, 9.53986073], [76.39597321, 9.53958321], [76.39541626, 9.53958321], [76.39541626, 9.53930473], [76.39457703, 9.53931046], [76.39457703, 9.53903198], [76.39402771, 9.53903198], [76.39402771, 9.5387516], [76.39319611, 9.5387516], [76.39319611, 9.53847122], [76.3923645, 9.53847122], [76.3923645, 9.53819466], [76.39180756, 9.53819466], [76.39180756, 9.53791714], [76.39097595, 9.53792191], [76.39097595, 9.53764153], [76.39041901, 9.53764153], [76.39041901, 9.53736115], [76.38957977, 9.53736115], [76.38957977, 9.53708267], [76.38874817, 9.53708267], [76.38874817, 9.53680515], [76.38819885, 9.53681183], [76.38819885, 9.53652], [76.38735962, 9.53652668], [76.38735962, 9.53624916], [76.38680267, 9.53625107], [76.38680267, 9.53597069], [76.38597107, 9.5359726], [76.38597107, 9.53569508], [76.38541412, 9.53569508], [76.38541412, 9.5354166], [76.38458252, 9.53541946], [76.38458252, 9.53514099], [76.3840332, 9.53514099], [76.3840332, 9.53486061], [76.38291931, 9.53486061], [76.38291931, 9.53703976], [76.38291931, 9.53736115], [76.38263702, 9.53736115], [76.38263702, 9.54069328], [76.38236237, 9.54069138], [76.38236237, 9.54181004], [76.38208008, 9.54180622], [76.38208008, 9.54319572], [76.38263702, 9.54319572], [76.38263702, 9.54347229], [76.38346863, 9.54347229], [76.38346863, 9.54374981], [76.3840332, 9.54374981], [76.3840332, 9.54403019], [76.38458252, 9.54403019], [76.38458252, 9.54430962], [76.38513947, 9.5443058], [76.38513947, 9.54458427], [76.38597107, 9.54458237], [76.38597107, 9.54486179], [76.38652802, 9.54486179], [76.38652802, 9.54514027], [76.38707733, 9.54514027], [76.38707733, 9.54541969], [76.38764191, 9.54541588], [76.38764191, 9.54569435], [76.38847351, 9.54569435], [76.38847351, 9.54597187], [76.38903046, 9.54597187], [76.38903046, 9.54625034], [76.38957977, 9.54625034], [76.38957977, 9.54653263], [76.39013672, 9.54653263], [76.39013672, 9.5468111], [76.39069366, 9.54680634], [76.39069366, 9.54708195], [76.39125061, 9.54708195], [76.39125061, 9.54736233], [76.39180756, 9.54736042], [76.39180756, 9.54763985], [76.39235687, 9.54763985], [76.39235687, 9.54792118], [76.39291382, 9.54791641], [76.39291382, 9.54819393], [76.39347076, 9.54819393], [76.39347076, 9.5484724], [76.39402771, 9.54846096], [76.39402771, 9.54874992], [76.39457703, 9.54874992], [76.39457703, 9.5490303], [76.3951416, 9.5490303], [76.3951416, 9.54931068], [76.39569092, 9.54930592], [76.39569092, 9.54958439], [76.39624786, 9.54958439], [76.39624786, 9.54986], [76.39679718, 9.54986], [76.39679718, 9.55014038], [76.39736938, 9.55014038], [76.39736938, 9.55042076], [76.3979187, 9.55041599], [76.3979187, 9.55069447], [76.39847565, 9.55069447], [76.39847565, 9.55097198], [76.39901733, 9.55097008], [76.39901733, 9.55125046], [76.39958191, 9.55125046], [76.39958191, 9.55152798], [76.40013885, 9.55151939], [76.40013885, 9.55181122], [76.40041351, 9.55180645], [76.40041351, 9.55208206], [76.40097046, 9.55208206], [76.40097046, 9.5523634], [76.4015274, 9.55235958], [76.4015274, 9.55264091], [76.4019928, 9.55263805], [76.40208435, 9.55263805], [76.40207672, 9.5529213], [76.4026413, 9.55291557], [76.4026413, 9.55319405], [76.4034729, 9.55319405], [76.4034729, 9.55347157], [76.40429688, 9.55346966], [76.40429688, 9.55375099], [76.40458679, 9.55375099], [76.40458679, 9.55653095], [76.4043045, 9.55652905], [76.4043045, 9.55847263], [76.40458679, 9.55847073], [76.40458679, 9.55903053], [76.40374756, 9.55903053], [76.40374756, 9.55931187], [76.4043045, 9.55930519], [76.4043045, 9.55958271], [76.40458679, 9.55958271], [76.40458679, 9.55986118], [76.40486145, 9.55986118], [76.40486145, 9.56014061], [76.4054184, 9.56014061], [76.4054184, 9.56042194], [76.40625, 9.56041718], [76.40625, 9.56069469], [76.40680695, 9.56069469], [76.40680695, 9.56097317], [76.40735626, 9.56097126], [76.40735626, 9.56125069], [76.40770721, 9.56125069], [76.40791321, 9.56125069], [76.40791321, 9.56153202], [76.4090271, 9.56153202], [76.4090271, 9.56180954], [76.4098587, 9.56180477], [76.4098587, 9.56208324], [76.4109726, 9.56208134], [76.4109726, 9.56236076], [76.41179657, 9.56236076], [76.41179657, 9.56263924], [76.4126358, 9.56263924], [76.4126358, 9.56291962], [76.41319275, 9.56291676], [76.41319275, 9.56319523], [76.41430664, 9.56319523]]], [[[76.37152863, 9.75847244], [76.37152863, 9.75791645], [76.37180328, 9.75792027], [76.37180328, 9.75626087], [76.3720932, 9.75626087], [76.3720932, 9.7551403], [76.37236023, 9.7551403], [76.37236023, 9.75486088], [76.37208557, 9.75486088], [76.37208557, 9.7546196], [76.37208557, 9.75430489], [76.37236023, 9.75430965], [76.37236023, 9.75403023], [76.37264252, 9.75403023], [76.37264252, 9.75319958], [76.37291718, 9.75319958], [76.37291718, 9.7523613], [76.37319183, 9.7523613], [76.37319183, 9.75180531], [76.37291718, 9.75181198], [76.37291718, 9.75125122], [76.3720932, 9.75125122], [76.3720932, 9.7515316], [76.37180328, 9.75152683], [76.37180328, 9.75208282], [76.37152863, 9.75208092], [76.37152863, 9.75264168], [76.37124634, 9.75263882], [76.37124634, 9.75347137], [76.37097168, 9.75347137], [76.37097168, 9.75458336], [76.37069702, 9.75458145], [76.37069702, 9.75541973], [76.37041473, 9.75541782], [76.3704071, 9.75598145], [76.3704071, 9.75652981], [76.37013245, 9.75652981], [76.37013245, 9.75792027], [76.37041473, 9.75791645], [76.37041473, 9.75819397], [76.37124634, 9.75819588], [76.37124634, 9.75847244], [76.37152863, 9.75847244]]], [[[76.32402802, 9.82569504], [76.32402802, 9.82541656], [76.32457733, 9.82542133], [76.32457733, 9.82486057], [76.32485962, 9.82486057], [76.32485962, 9.82430363], [76.32514954, 9.82431126], [76.32514954, 9.82375145], [76.32541656, 9.82375145], [76.32541656, 9.82319546], [76.32569122, 9.82319546], [76.32569122, 9.82291603], [76.32596588, 9.82291889], [76.32596588, 9.82235146], [76.32653046, 9.82235146], [76.32653046, 9.82264137], [76.32681274, 9.82264137], [76.32681274, 9.82291889], [76.32707977, 9.82291603], [76.32707977, 9.82347298], [76.32763672, 9.82347298], [76.32763672, 9.82319546], [76.32847595, 9.82319546], [76.32847595, 9.82180691], [76.32763672, 9.82181072], [76.32763672, 9.82096958], [76.32736206, 9.82097244], [76.32736206, 9.81958199], [76.32763672, 9.81958199], [76.32763672, 9.81847191], [76.32791901, 9.81847191], [76.32791901, 9.81791592], [76.32847595, 9.81792068], [76.32847595, 9.8176403], [76.3290329, 9.8176403], [76.3290329, 9.81735992], [76.32875061, 9.81735992], [76.32875061, 9.81680584], [76.32847595, 9.81681061], [76.32847595, 9.81624985], [76.32875061, 9.81624985], [76.32875061, 9.81597233], [76.32847595, 9.81597233], [76.32847595, 9.81569386], [76.32819366, 9.81569386], [76.32819366, 9.81541634], [76.32791901, 9.81542015], [76.32791901, 9.81431007], [76.32763672, 9.81431007], [76.32763672, 9.81208134], [76.32736206, 9.8120842], [76.32736206, 9.81041527], [76.32707977, 9.81041527], [76.32707977, 9.80958366], [76.32680511, 9.80958366], [76.32680511, 9.8087492], [76.32653046, 9.8087492], [76.32653046, 9.80819321], [76.32680511, 9.80819321], [76.32680511, 9.80791664], [76.32653046, 9.80792046], [76.32653046, 9.80764198], [76.32541656, 9.80764198], [76.32541656, 9.80735016], [76.32430267, 9.80735016], [76.32430267, 9.80764198], [76.32375336, 9.80764198], [76.32375336, 9.80792046], [76.32319641, 9.80792046], [76.32319641, 9.80902958], [76.32291412, 9.80902672], [76.32291412, 9.81097221], [76.32319641, 9.81097221], [76.32319641, 9.81236172], [76.32347107, 9.81235981], [76.32347107, 9.81348133], [76.32319641, 9.81347179], [76.32319641, 9.81486225], [76.32291412, 9.81486225], [76.32291412, 9.81708431], [76.32319641, 9.81707954], [76.32319641, 9.8215313], [76.32290649, 9.8215313], [76.32290649, 9.82264137], [76.32263947, 9.82264137], [76.32263947, 9.82375145], [76.32291412, 9.82375145], [76.32291412, 9.82486057], [76.32319641, 9.82486057], [76.32319641, 9.82542133], [76.32347107, 9.82541656], [76.32347107, 9.82569504], [76.32402802, 9.82569504]]], [[[76.37236023, 9.82569504], [76.37236023, 9.82541656], [76.37291718, 9.82542133], [76.37291718, 9.82514095], [76.37319946, 9.82514095], [76.37319946, 9.82486057], [76.37347412, 9.82486057], [76.37347412, 9.82458305], [76.37319183, 9.82458305], [76.37319183, 9.82152843], [76.37236023, 9.82152843], [76.37236023, 9.82208538], [76.37208557, 9.82208538], [76.37208557, 9.82319546], [76.37180328, 9.82318974], [76.37180328, 9.82542133], [76.37152863, 9.82541656], [76.37152863, 9.82569504], [76.37236023, 9.82569504]]], [[[76.36846924, 9.82681179], [76.36846924, 9.82653141], [76.36958313, 9.82653141], [76.36958313, 9.82625103], [76.36985779, 9.82625103], [76.36985779, 9.82569027], [76.37014008, 9.82569504], [76.37014008, 9.82513905], [76.3704071, 9.82514095], [76.3704071, 9.82431126], [76.37013245, 9.82431126], [76.37013245, 9.82403088], [76.36985779, 9.82403088], [76.36985779, 9.82431126], [76.36958313, 9.82430363], [76.36958313, 9.82458305], [76.36930847, 9.82458305], [76.36930847, 9.82486057], [76.36846924, 9.82486057], [76.36846924, 9.82514095], [76.36736298, 9.82514095], [76.36736298, 9.82542133], [76.36708069, 9.82541656], [76.36708069, 9.82569504], [76.36680603, 9.82569027], [76.36680603, 9.82681179], [76.36846924, 9.82681179]]], [[[76.28930664, 9.84736156], [76.28930664, 9.84708214], [76.28986359, 9.84708214], [76.28986359, 9.84680557], [76.2904129, 9.84681129], [76.2904129, 9.84624958], [76.29013824, 9.84624958], [76.29013824, 9.84569168], [76.28986359, 9.84569359], [76.28986359, 9.8451376], [76.2895813, 9.84514046], [76.2895813, 9.8445797], [76.28930664, 9.84458447], [76.28930664, 9.84430599], [76.28874969, 9.84431076], [76.28874969, 9.84403038], [76.28819275, 9.84403038], [76.28819275, 9.84431076], [76.28791809, 9.84430599], [76.28791809, 9.84458447], [76.2876358, 9.84458447], [76.2876358, 9.84569359], [76.28791809, 9.84569168], [76.28791809, 9.84681129], [76.28819275, 9.84680557], [76.28819275, 9.84708214], [76.28847504, 9.84708214], [76.28847504, 9.84736156], [76.28930664, 9.84736156]]], [[[76.37791443, 9.83930588], [76.37791443, 9.83958435], [76.37847137, 9.83958435], [76.37847137, 9.83902836], [76.37874603, 9.83903027], [76.37874603, 9.83847237], [76.37902832, 9.83847237], [76.37902832, 9.83791542], [76.37930298, 9.83792019], [76.37930298, 9.83708096], [76.37875366, 9.83708382], [76.37875366, 9.8368063], [76.37819672, 9.83681011], [76.37819672, 9.83652973], [76.37708282, 9.83652973], [76.37708282, 9.83681011], [76.37625122, 9.8368063], [76.37625122, 9.83736229], [76.37652588, 9.83735943], [76.37652588, 9.83792019], [76.37680817, 9.83791542], [76.37680817, 9.83847237], [76.37708282, 9.83847237], [76.37708282, 9.83903027], [76.37735748, 9.83903027], [76.37735748, 9.83930969], [76.37791443, 9.83930588]]], [[[76.37625885, 9.84125042], [76.37625885, 9.84152985], [76.37763977, 9.84152985], [76.37763977, 9.84069061], [76.37735748, 9.84069443], [76.37735748, 9.84041786], [76.37708282, 9.84041977], [76.37708282, 9.84014034], [76.37680817, 9.84014034], [76.37680817, 9.83986187], [76.37652588, 9.83986187], [76.37652588, 9.83930588], [76.37625885, 9.83930969], [76.37625885, 9.83903027], [76.37596893, 9.83903027], [76.37596893, 9.83875179], [76.37568665, 9.83875179], [76.37568665, 9.83819103], [76.37541962, 9.8381958], [76.37541962, 9.83791542], [76.37513733, 9.83792019], [76.37513733, 9.83763981], [76.37486267, 9.83763981], [76.37486267, 9.83792019], [76.37403107, 9.83791542], [76.37403107, 9.83847237], [76.37374878, 9.83847237], [76.37374878, 9.83903027], [76.37346649, 9.83903027], [76.37346649, 9.83930969], [76.37319183, 9.83930588], [76.37319183, 9.83986187], [76.37291718, 9.83986187], [76.37291718, 9.84041977], [76.37264252, 9.84041786], [76.37264252, 9.84069443], [76.37319183, 9.84069443], [76.37319183, 9.84097195], [76.37346649, 9.84097195], [76.37346649, 9.84125042], [76.37625885, 9.84125042]]], [[[76.34958649, 9.87458229], [76.34958649, 9.87402821], [76.34986115, 9.87403107], [76.34986115, 9.87319183], [76.3501358, 9.87319374], [76.3501358, 9.87208366], [76.34986115, 9.87208366], [76.34986115, 9.87097168], [76.3501358, 9.87097168], [76.3501358, 9.87041569], [76.35041809, 9.87042046], [76.35041809, 9.8698597], [76.35069275, 9.8698597], [76.35069275, 9.86930561], [76.35098267, 9.86931133], [76.35098267, 9.86847019], [76.35124969, 9.8684721], [76.35124969, 9.86763763], [76.35151672, 9.86765099], [76.35151672, 9.86708164], [76.35180664, 9.86708355], [76.35180664, 9.86625004], [76.35206604, 9.86625195], [76.35206604, 9.86569118], [76.35236359, 9.86569405], [76.35236359, 9.86513996], [76.35263824, 9.86514187], [76.35263824, 9.86486244], [76.3529129, 9.86486244], [76.3529129, 9.86458397], [76.35346985, 9.86458969], [76.35346985, 9.86431026], [76.35375214, 9.86431026], [76.35375214, 9.86403179], [76.35430908, 9.86403179], [76.35430908, 9.86374855], [76.3548584, 9.86374855], [76.3548584, 9.86347103], [76.35541534, 9.86347103], [76.35541534, 9.8629179], [76.35569763, 9.86291981], [76.35569763, 9.86236095], [76.35597229, 9.86236095], [76.35597229, 9.86180496], [76.35624695, 9.86180973], [76.35624695, 9.86069107], [76.35652924, 9.86069489], [76.35652924, 9.85986137], [76.35736084, 9.85986137], [76.35736084, 9.8595829], [76.35847473, 9.8595829], [76.35847473, 9.85930538], [76.35930634, 9.85931015], [76.35930634, 9.85903168], [76.36042023, 9.85903168], [76.36042023, 9.8587513], [76.36069489, 9.8587513], [76.36068726, 9.85819054], [76.36096954, 9.8581953], [76.36096954, 9.85791683], [76.36125946, 9.8579216], [76.36125946, 9.85764122], [76.36152649, 9.85764122], [76.36152649, 9.85736084], [76.36180878, 9.85736084], [76.36180878, 9.85708141], [76.36208344, 9.85708332], [76.36208344, 9.85680485], [76.36235809, 9.85680866], [76.36235809, 9.85652924], [76.36264038, 9.85652924], [76.36264038, 9.85624886], [76.36291504, 9.85624886], [76.36291504, 9.85597324], [76.36430359, 9.85597324], [76.36430359, 9.85569477], [76.3655014, 9.85569477], [76.36597443, 9.85569477], [76.36597443, 9.85541725], [76.36624908, 9.85542107], [76.36624908, 9.85457993], [76.36597443, 9.85458279], [76.36597443, 9.85319519], [76.36624908, 9.85319519], [76.36624908, 9.8526392], [76.36653137, 9.85264969], [76.36653137, 9.85208035], [76.36680603, 9.85208321], [76.36680603, 9.85180664], [76.36705017, 9.85181141], [76.3670578, 9.85168839], [76.36708069, 9.85125065], [76.36725616, 9.85125065], [76.36736298, 9.85125065], [76.36736298, 9.85098171], [76.36763763, 9.85097027], [76.36763763, 9.85069466], [76.36791992, 9.85069466], [76.36791992, 9.8493042], [76.36763763, 9.84931087], [76.36763763, 9.84764099], [76.36736298, 9.84764099], [76.36736298, 9.84735966], [76.36763763, 9.84736156], [76.36763763, 9.84624958], [76.36791992, 9.84624958], [76.36791992, 9.84431076], [76.36763763, 9.84431076], [76.36763763, 9.84403038], [76.36791992, 9.84403038], [76.36791992, 9.84375], [76.36818695, 9.84375], [76.36818695, 9.8429203], [76.36846924, 9.8429203], [76.36846924, 9.84235954], [76.36875153, 9.8423624], [76.36875153, 9.84180641], [76.36902618, 9.84181023], [76.36902618, 9.84125042], [76.36930847, 9.84125042], [76.36930847, 9.84097195], [76.36958313, 9.84097195], [76.36958313, 9.83986187], [76.36985779, 9.83986187], [76.36985779, 9.83958435], [76.36958313, 9.83958435], [76.36958313, 9.83902836], [76.36985779, 9.83903027], [76.36985779, 9.83819103], [76.37014008, 9.8381958], [76.37014008, 9.83736229], [76.37041473, 9.83736229], [76.37041473, 9.83652687], [76.37097168, 9.83652973], [76.37097168, 9.83541965], [76.37124634, 9.83541965], [76.37124634, 9.83485889], [76.37152863, 9.8348608], [76.37152863, 9.83430481], [76.37180328, 9.83430958], [76.37180328, 9.83292198], [76.3720932, 9.83292198], [76.3720932, 9.83125114], [76.37180328, 9.83125114], [76.37180328, 9.83097267], [76.37097168, 9.83097076], [76.37097168, 9.83069515], [76.37014008, 9.83069515], [76.37014008, 9.83041668], [76.36930847, 9.83041859], [76.36930847, 9.83014107], [76.36292267, 9.83014107], [76.36292267, 9.83041859], [76.36152649, 9.83041668], [76.36152649, 9.83069515], [76.36042023, 9.83069515], [76.36042023, 9.83097076], [76.35986328, 9.83097267], [76.35986328, 9.83125114], [76.35941315, 9.83125114], [76.35930634, 9.83125114], [76.35930634, 9.83148098], [76.35930634, 9.8318119], [76.35916138, 9.83180714], [76.35902405, 9.83180523], [76.35902405, 9.83208275], [76.35791779, 9.83208275], [76.35791779, 9.83236122], [76.35736084, 9.83236122], [76.35736084, 9.8326416], [76.35708618, 9.8326416], [76.35708618, 9.83292198], [76.35680389, 9.83291721], [76.35680389, 9.83319473], [76.35652924, 9.83319473], [76.35652924, 9.8334713], [76.35597229, 9.8334713], [76.35597229, 9.83375072], [76.35569763, 9.83375072], [76.35569763, 9.83403015], [76.35542297, 9.83403015], [76.35542297, 9.83375072], [76.35513306, 9.83375072], [76.35513306, 9.83403015], [76.35457611, 9.83403015], [76.35457611, 9.83430958], [76.35402679, 9.83430481], [76.35402679, 9.83458328], [76.35375214, 9.83458138], [76.35375214, 9.83513927], [76.35320282, 9.83513927], [76.35320282, 9.83541965], [76.3529129, 9.83541775], [76.3529129, 9.83569336], [76.35263824, 9.83569336], [76.35263824, 9.83597088], [76.35235596, 9.83597088], [76.35236359, 9.83624935], [76.35180664, 9.83624935], [76.35180664, 9.83652973], [76.35151672, 9.83652973], [76.35151672, 9.83681011], [76.35097504, 9.8368063], [76.35097504, 9.83736229], [76.35041809, 9.83736229], [76.35041809, 9.83763981], [76.34986115, 9.83763981], [76.34986115, 9.83792019], [76.34958649, 9.83791542], [76.34958649, 9.83847237], [76.34902954, 9.83847237], [76.34902954, 9.83930969], [76.34874725, 9.83930969], [76.34874725, 9.84014034], [76.34902954, 9.84014034], [76.34902954, 9.84041977], [76.34986115, 9.84041786], [76.34986115, 9.84097195], [76.3501358, 9.84097195], [76.3501358, 9.84125042], [76.35069275, 9.84125042], [76.35069275, 9.84152985], [76.35098267, 9.84152985], [76.35098267, 9.84181023], [76.35124969, 9.84180641], [76.35124969, 9.84208393], [76.35151672, 9.84208202], [76.35151672, 9.84263992], [76.35180664, 9.84263992], [76.35180664, 9.84403038], [76.35151672, 9.84403038], [76.35152435, 9.84486008], [76.35124969, 9.84486008], [76.35124969, 9.84597206], [76.35140991, 9.84597206], [76.35152435, 9.84597206], [76.35152435, 9.84652805], [76.35180664, 9.84652138], [76.35180664, 9.84764099], [76.35152435, 9.84763813], [76.35152435, 9.84819412], [76.35180664, 9.84819412], [76.35180664, 9.84958458], [76.3520813, 9.84958458], [76.3520813, 9.84986019], [76.35180664, 9.84986019], [76.35180664, 9.85014057], [76.35206604, 9.85014057], [76.35206604, 9.85236073], [76.35235596, 9.85236073], [76.35235596, 9.85292053], [76.35263824, 9.85291672], [76.35263824, 9.85375118], [76.3529129, 9.85375118], [76.3529129, 9.85458279], [76.35263824, 9.85458279], [76.35263824, 9.85569477], [76.35235596, 9.85569], [76.35235596, 9.85764122], [76.3520813, 9.85763931], [76.3520813, 9.8581953], [76.35180664, 9.8581953], [76.35180664, 9.8587513], [76.35151672, 9.8587513], [76.35151672, 9.85931015], [76.35124969, 9.85930538], [76.35124969, 9.8595829], [76.35069275, 9.8595829], [76.35069275, 9.85986137], [76.35041809, 9.85986137], [76.35041809, 9.86013889], [76.3501358, 9.86013889], [76.3501358, 9.86042023], [76.34986115, 9.86041737], [76.34986115, 9.86069489], [76.34874725, 9.86069489], [76.34874725, 9.86097336], [76.34819794, 9.86097145], [76.34819794, 9.86180973], [76.3484726, 9.86180496], [76.3484726, 9.86208344], [76.34874725, 9.86208057], [76.34874725, 9.86264038], [76.34902954, 9.86264038], [76.34902954, 9.86319256], [76.34929657, 9.86319065], [76.34929657, 9.86403179], [76.34902954, 9.86402798], [76.34902954, 9.86569405], [76.34929657, 9.86569118], [76.34929657, 9.86680984], [76.34902954, 9.86680603], [76.34902954, 9.86708355], [76.3484726, 9.86708355], [76.3484726, 9.86736202], [76.34792328, 9.86736202], [76.34792328, 9.86791992], [76.34764099, 9.86791801], [76.34764099, 9.86819363], [76.3473587, 9.86818886], [76.3473587, 9.86931133], [76.34708405, 9.86930561], [76.34708405, 9.86958408], [76.3473587, 9.86957932], [76.3473587, 9.87014008], [76.34764099, 9.87014008], [76.34764099, 9.87069416], [76.34792328, 9.87068939], [76.34792328, 9.87152958], [76.34819794, 9.87152958], [76.34819794, 9.87263966], [76.3484726, 9.87263775], [76.3484726, 9.87347221], [76.34874725, 9.87345886], [76.34874725, 9.87431145], [76.3493042, 9.87430573], [76.3493042, 9.87458229], [76.34958649, 9.87458229]]], [[[76.38541412, 9.62069321], [76.38541412, 9.62041759], [76.38597107, 9.62042046], [76.38597107, 9.62014198], [76.38625336, 9.62014198], [76.38625336, 9.62042046], [76.38652802, 9.62042046], [76.38652802, 9.61986065], [76.38680267, 9.61986065], [76.38680267, 9.62014198], [76.38707733, 9.62014198], [76.38707733, 9.61986065], [76.38764191, 9.61986065], [76.38764191, 9.61930466], [76.38791656, 9.61931038], [76.38791656, 9.61903191], [76.38764191, 9.61903191], [76.38764191, 9.6176424], [76.38735962, 9.6176424], [76.38735962, 9.61736107], [76.38707733, 9.61736107], [76.38707733, 9.61680984], [76.38680267, 9.61680984], [76.38680267, 9.61569118], [76.38652802, 9.615695], [76.38652802, 9.61541653], [76.38625336, 9.61541653], [76.38625336, 9.615695], [76.38597107, 9.615695], [76.38597107, 9.61458302], [76.38541412, 9.61458302], [76.38541412, 9.61430454], [76.38513947, 9.61430931], [76.38513947, 9.61375141], [76.38485718, 9.61375141], [76.38485718, 9.61347103], [76.38458252, 9.61347294], [76.38458252, 9.61374855], [76.38402557, 9.61375141], [76.38402557, 9.61458302], [76.38430786, 9.61458302], [76.38430786, 9.61486053], [76.38318634, 9.61486053], [76.38318634, 9.61541939], [76.38291931, 9.61541653], [76.38291931, 9.615695], [76.38236237, 9.615695], [76.38236237, 9.61597347], [76.38207245, 9.61597061], [76.38207245, 9.61625099], [76.38181305, 9.61625099], [76.38181305, 9.61793137], [76.38208008, 9.61791706], [76.38208008, 9.61847115], [76.38236237, 9.61847115], [76.38236237, 9.61903191], [76.38263702, 9.61903191], [76.38263702, 9.61931038], [76.38402557, 9.61930466], [76.38402557, 9.61986065], [76.38430786, 9.61986065], [76.38430786, 9.62014198], [76.38458252, 9.62014198], [76.38458252, 9.62042046], [76.38513947, 9.62041759], [76.38513947, 9.62069321], [76.38541412, 9.62069321]]], [[[76.38124847, 9.71458244], [76.38069153, 9.71457958], [76.38069153, 9.7151413], [76.38096619, 9.7151413], [76.38096619, 9.71681118], [76.38124847, 9.71681118], [76.38124847, 9.71709156], [76.38181305, 9.71709156], [76.38181305, 9.7165308], [76.38153076, 9.7165308], [76.38153076, 9.71485996], [76.38124847, 9.71485996], [76.38124847, 9.71458244]]], [[[76.23986053, 10.10237026], [76.23986053, 10.1020813], [76.24013519, 10.10208321], [76.24013519, 10.10180473], [76.24067688, 10.10181046], [76.24067688, 10.10153198], [76.24124908, 10.10153198], [76.24124908, 10.10125065], [76.24153137, 10.10125065], [76.24153137, 10.10097122], [76.24208069, 10.10097313], [76.24208069, 10.10069466], [76.24263763, 10.10069466], [76.24263763, 10.09958267], [76.24291992, 10.09958267], [76.24291992, 10.09930515], [76.24318695, 10.09931183], [76.24318695, 10.09903145], [76.24346924, 10.09903145], [76.24346924, 10.09875107], [76.24373627, 10.09875107], [76.24373627, 10.09847069], [76.24458313, 10.0984726], [76.24458313, 10.09819508], [76.24485779, 10.09819508], [76.24485779, 10.0979166], [76.24514008, 10.09792233], [76.24514008, 10.09764099], [76.2454071, 10.09764099], [76.2454071, 10.09736061], [76.24597168, 10.09736061], [76.24597168, 10.09708309], [76.24624634, 10.09708309], [76.24624634, 10.09680462], [76.24652863, 10.09680939], [76.24652863, 10.09597111], [76.24680328, 10.09597301], [76.24680328, 10.09513855], [76.2470932, 10.09514141], [76.2470932, 10.0945797], [76.24736023, 10.09458256], [76.24736023, 10.09402561], [76.24764252, 10.09403133], [76.24764252, 10.09346962], [76.24791718, 10.09347343], [76.24791718, 10.09291744], [76.24819183, 10.09292126], [76.24819183, 10.09068966], [76.24764252, 10.09069443], [76.24764252, 10.09125042], [76.24736023, 10.09125042], [76.24736023, 10.09181118], [76.24708557, 10.09180355], [76.24708557, 10.09235954], [76.24680328, 10.09235954], [76.24680328, 10.09292126], [76.24652863, 10.09291744], [76.24652863, 10.09319496], [76.24624634, 10.09318066], [76.24624634, 10.09375095], [76.24597168, 10.09375095], [76.24597168, 10.09486103], [76.24541473, 10.09486103], [76.24541473, 10.09569454], [76.24514008, 10.09568977], [76.24514008, 10.09653091], [76.24373627, 10.09653091], [76.24373627, 10.09680939], [76.24346924, 10.09680462], [76.24346924, 10.09736061], [76.24263763, 10.09736061], [76.24263763, 10.09708309], [76.24236298, 10.09708309], [76.24236298, 10.09680462], [76.24180603, 10.09680939], [76.24180603, 10.09181118], [76.24041748, 10.09181118], [76.24041748, 10.09292126], [76.24067688, 10.09292126], [76.24069214, 10.09486103], [76.24041748, 10.09486103], [76.24041748, 10.09569454], [76.24013519, 10.09569454], [76.24013519, 10.09624863], [76.24041748, 10.09624195], [76.24041748, 10.09680939], [76.24069214, 10.09680462], [76.24069214, 10.09736061], [76.24208069, 10.09736061], [76.24208069, 10.09764099], [76.24318695, 10.09764099], [76.24318695, 10.09792233], [76.24263763, 10.0979166], [76.24263763, 10.09819508], [76.24208069, 10.09819508], [76.24208069, 10.0984726], [76.23929596, 10.09847069], [76.23929596, 10.09875107], [76.23902893, 10.09875107], [76.23902893, 10.09931183], [76.23874664, 10.09930515], [76.23874664, 10.09958267], [76.23902893, 10.09958267], [76.23902893, 10.09986115], [76.23874664, 10.09986115], [76.23874664, 10.10042191], [76.23847198, 10.10041714], [76.23847198, 10.10097313], [76.23819733, 10.10097122], [76.23819733, 10.10125065], [76.2379303, 10.10125065], [76.2379303, 10.10181046], [76.23847198, 10.10180473], [76.23847198, 10.10208321], [76.23902893, 10.1020813], [76.23902893, 10.10237026], [76.23986053, 10.10237026]]], [[[75.81124878, 11.16180611], [75.81124878, 11.16152763], [75.81153107, 11.16152954], [75.81153107, 11.16068935], [75.81124878, 11.16069412], [75.81124878, 11.15958405], [75.81097412, 11.15958405], [75.81097412, 11.15930557], [75.81014252, 11.15931034], [75.81014252, 11.16042042], [75.81040955, 11.16042042], [75.81040955, 11.16152954], [75.81097412, 11.16152763], [75.81097412, 11.16180611], [75.81124878, 11.16180611]]], [[[75.8381958, 11.13431072], [75.8381958, 11.13403034], [75.83847046, 11.13403034], [75.83847046, 11.13374996], [75.8381958, 11.13374996], [75.8381958, 11.13309956], [75.8381958, 11.13263988], [75.83790588, 11.13264179], [75.83790588, 11.13182163], [75.83763885, 11.13182163], [75.83763885, 11.13125038], [75.83735657, 11.13125038], [75.83735657, 11.13069057], [75.83708191, 11.13069439], [75.83708191, 11.12986183], [75.83680725, 11.12986183], [75.83680725, 11.12930584], [75.83651733, 11.12930965], [75.83651733, 11.12876129], [75.83625031, 11.12876129], [75.83625031, 11.12819099], [75.83597565, 11.12819576], [75.83597565, 11.12791538], [75.8354187, 11.12792015], [75.8354187, 11.12764168], [75.83457947, 11.12764168], [75.83457947, 11.12735939], [75.83403015, 11.12736225], [75.83403015, 11.12708282], [75.83319092, 11.12708282], [75.83319092, 11.12680531], [75.83235931, 11.12681007], [75.83235931, 11.12652969], [75.83152771, 11.12652683], [75.83152771, 11.12708282], [75.83125305, 11.12708282], [75.83125305, 11.12763023], [75.83097076, 11.12764168], [75.83097076, 11.12903023], [75.83040619, 11.12903023], [75.83040619, 11.12930965], [75.83013916, 11.12930584], [75.83013916, 11.12986183], [75.83154297, 11.12986183], [75.83154297, 11.13041973], [75.83235931, 11.13041782], [75.83235931, 11.13069439], [75.8326416, 11.13069439], [75.8326416, 11.13125038], [75.83291626, 11.13125038], [75.83291626, 11.1315279], [75.83319092, 11.1315279], [75.83319092, 11.13182163], [75.83347321, 11.13180637], [75.83347321, 11.13208389], [75.83374786, 11.13208389], [75.83374786, 11.13236237], [75.83428955, 11.13236046], [75.83428955, 11.13292027], [75.83486176, 11.13291645], [75.83486176, 11.13319397], [75.83513641, 11.13319397], [75.83513641, 11.13347244], [75.83569336, 11.13346958], [75.83569336, 11.13374996], [75.83625031, 11.13374996], [75.83625031, 11.13403034], [75.83735657, 11.13403034], [75.83735657, 11.13431072], [75.8381958, 11.13431072]]], [[[75.15763855, 12.1093111], [75.15763855, 12.10902882], [75.15791321, 12.10903072], [75.15791321, 12.10875034], [75.15820313, 12.10875034], [75.15820313, 12.10848236], [75.1581955, 12.10819435], [75.15847015, 12.10819435], [75.15847015, 12.10763836], [75.15875244, 12.10764122], [75.15875244, 12.10736275], [75.15892029, 12.10735989], [75.1590271, 12.10736275], [75.1590271, 12.10696125], [75.1590271, 12.1068058], [75.15957642, 12.10681057], [75.15957642, 12.10625267], [75.1598587, 12.10625267], [75.1598587, 12.10597038], [75.16041565, 12.10597229], [75.16041565, 12.10569382], [75.16069794, 12.10569382], [75.16069794, 12.1054163], [75.1609726, 12.10542107], [75.1609726, 12.10486031], [75.16124725, 12.10486221], [75.16124725, 12.10458374], [75.16152954, 12.10458374], [75.16152954, 12.10402775], [75.16179657, 12.10402966], [75.16179657, 12.10374069], [75.16208649, 12.10375023], [75.16208649, 12.10319424], [75.16236115, 12.10319424], [75.16236115, 12.10264015], [75.16291809, 12.10264015], [75.16291809, 12.10236168], [75.16346741, 12.10236168], [75.16346741, 12.10207939], [75.16402435, 12.10208416], [75.16402435, 12.10180569], [75.16430664, 12.10181141], [75.16430664, 12.10153008], [75.16485596, 12.10153008], [75.16485596, 12.10068035], [75.16513824, 12.1006937], [75.16513824, 12.10013771], [75.1654129, 12.10013962], [75.1654129, 12.09902954], [75.16570282, 12.09902954], [75.16570282, 12.09875202], [75.1654129, 12.09875202], [75.1654129, 12.09793091], [75.16513824, 12.09793091], [75.16513824, 12.09764194], [75.1654129, 12.09764194], [75.1654129, 12.09681034], [75.16570282, 12.09681034], [75.16570282, 12.09487057], [75.16596985, 12.09487057], [75.16596985, 12.09264183], [75.16623688, 12.09264183], [75.16624451, 12.09175968], [75.16625214, 12.09125137], [75.16641998, 12.09125137], [75.16652679, 12.09125137], [75.16652679, 12.09087086], [75.16652679, 12.09041691], [75.16623688, 12.09042168], [75.16623688, 12.0893116], [75.16652679, 12.0893116], [75.16652679, 12.08819008], [75.16680908, 12.08819485], [75.16680908, 12.08791733], [75.16707611, 12.08791924], [75.16707611, 12.08763885], [75.16764069, 12.08763885], [75.16764069, 12.08681202], [75.1673584, 12.08681202], [75.1673584, 12.08653069], [75.16764069, 12.08653069], [75.16764069, 12.08570194], [75.16792297, 12.08570194], [75.16792297, 12.08514118], [75.16819763, 12.08514118], [75.16819763, 12.0848608], [75.16847229, 12.0848608], [75.16847229, 12.08458328], [75.16874695, 12.08458328], [75.16874695, 12.0840292], [75.16902924, 12.08403111], [75.16902924, 12.08375072], [75.16931152, 12.08375072], [75.16931152, 12.08318996], [75.16958618, 12.08319473], [75.16958618, 12.08291626], [75.16986084, 12.08292103], [75.16986084, 12.08208179], [75.17041779, 12.08208466], [75.17041779, 12.08152866], [75.17095947, 12.08150959], [75.17097473, 12.08097172], [75.17124939, 12.08097172], [75.17124939, 12.0806942], [75.17180634, 12.0806942], [75.17180634, 12.07985973], [75.17208099, 12.07985973], [75.17208099, 12.07956791], [75.17236328, 12.07958221], [75.17236328, 12.07874966], [75.17263794, 12.07874966], [75.17263794, 12.07847023], [75.17292023, 12.07847214], [75.17292023, 12.07791615], [75.17318726, 12.07792091], [75.17318726, 12.07736015], [75.17375183, 12.07736206], [75.17375183, 12.07680607], [75.17402649, 12.07680607], [75.17402649, 12.0765276], [75.17430878, 12.07653046], [75.17430878, 12.07625008], [75.17456818, 12.07621956], [75.17458344, 12.07458401], [75.17485809, 12.07458401], [75.17485809, 12.07374954], [75.17457581, 12.07376099], [75.17458344, 12.07332134], [75.17458344, 12.07291794], [75.17430878, 12.07291985], [75.17430878, 12.07264042], [75.17457581, 12.07264042], [75.17457581, 12.07236195], [75.17430878, 12.07236195], [75.17430878, 12.07208061], [75.17458344, 12.07208443], [75.17458344, 12.07180595], [75.17430878, 12.07180977], [75.17430878, 12.07042027], [75.17457581, 12.07042027], [75.17457581, 12.06985855], [75.17485809, 12.06986237], [75.17485809, 12.06958389], [75.17458344, 12.06958389], [75.17458344, 12.06930542], [75.17485809, 12.06931019], [75.17485809, 12.06847095], [75.17514038, 12.06847095], [75.17514038, 12.06680489], [75.17569733, 12.06680965], [75.17569733, 12.06597137], [75.17597198, 12.06597328], [75.17597198, 12.06569481], [75.17652893, 12.06569481], [75.17652893, 12.06513882], [75.17679596, 12.06514168], [75.17679596, 12.06456947], [75.17708588, 12.06458282], [75.17708588, 12.06402683], [75.17736053, 12.0640316], [75.17736053, 12.06319141], [75.17763519, 12.06319523], [75.17763519, 12.06263924], [75.17791748, 12.06264114], [75.17791748, 12.06208134], [75.17819214, 12.06208324], [75.17819214, 12.06180477], [75.1784668, 12.06182098], [75.1784668, 12.06125069], [75.17874908, 12.06125069], [75.17874908, 12.06068993], [75.17930603, 12.06069469], [75.17930603, 12.05986118], [75.17958069, 12.05986118], [75.17958069, 12.05902672], [75.17986298, 12.05903053], [75.17986298, 12.05846977], [75.18013763, 12.05847263], [75.18013763, 12.05708218], [75.18041992, 12.05708218], [75.18041992, 12.05597305], [75.18069458, 12.05597305], [75.18069458, 12.05513763], [75.18096924, 12.05514145], [75.18096924, 12.05457973], [75.18125153, 12.05458546], [75.18125153, 12.05375004], [75.18152618, 12.05375004], [75.18152618, 12.05153275], [75.18180847, 12.05153275], [75.18180847, 12.04986], [75.18125153, 12.04986], [75.18125153, 12.05042076], [75.18096924, 12.05042076], [75.18096924, 12.05125046], [75.18068695, 12.05125046], [75.18068695, 12.05153275], [75.18041992, 12.05152798], [75.18041992, 12.05208206], [75.18013763, 12.05208206], [75.18013763, 12.05263805], [75.17986298, 12.05263805], [75.17986298, 12.05319405], [75.17958069, 12.05319405], [75.17958069, 12.05347157], [75.17930603, 12.05346966], [75.17930603, 12.05403137], [75.17903137, 12.05403137], [75.17903137, 12.05542088], [75.17874908, 12.05541611], [75.17874908, 12.05569363], [75.1784668, 12.05569172], [75.1784668, 12.05625057], [75.17817688, 12.05625057], [75.17817688, 12.05681133], [75.17791748, 12.05681133], [75.17791748, 12.05736065], [75.17763519, 12.05736065], [75.17763519, 12.05847263], [75.17736053, 12.05846977], [75.17736053, 12.05903053], [75.17708588, 12.05902672], [75.17708588, 12.05958271], [75.17679596, 12.05957985], [75.17679596, 12.06042099], [75.17652893, 12.06042099], [75.17652893, 12.06125069], [75.17624664, 12.06125069], [75.17624664, 12.06182098], [75.17597198, 12.06180477], [75.17597198, 12.06208324], [75.17569733, 12.06208134], [75.17569733, 12.06264114], [75.17540741, 12.06264114], [75.17540741, 12.06347084], [75.17514038, 12.06347084], [75.17514038, 12.06458282], [75.17485809, 12.06456947], [75.17485809, 12.06514168], [75.17458344, 12.06513882], [75.17458344, 12.06569481], [75.17430878, 12.06569099], [75.17430878, 12.06653023], [75.17402649, 12.06652737], [75.17402649, 12.06708336], [75.17375183, 12.06708336], [75.17375183, 12.06763935], [75.17346954, 12.06763935], [75.17346954, 12.06819344], [75.17319489, 12.06819344], [75.17319489, 12.06847095], [75.17292023, 12.06847095], [75.17292023, 12.06902981], [75.17263794, 12.06902981], [75.17263794, 12.07042027], [75.17237091, 12.07042027], [75.17237091, 12.07069969], [75.17208099, 12.07069969], [75.17208099, 12.07180977], [75.17180634, 12.07180977], [75.17180634, 12.07291985], [75.17152405, 12.07291794], [75.17152405, 12.07319355], [75.17124939, 12.07319069], [75.17124939, 12.07376099], [75.1709671, 12.07376099], [75.1709671, 12.0743103], [75.17069244, 12.0743103], [75.17069244, 12.07514], [75.17041779, 12.07514], [75.17041779, 12.0759716], [75.17014313, 12.0759697], [75.17014313, 12.07653046], [75.16986084, 12.0765276], [75.16986084, 12.07708359], [75.16958618, 12.07708359], [75.16958618, 12.07819366], [75.16931152, 12.07818985], [75.16931152, 12.07903099], [75.16902924, 12.07902813], [75.16902924, 12.07958221], [75.16874695, 12.07956791], [75.16874695, 12.08014107], [75.16847229, 12.08013821], [75.16847229, 12.0806942], [75.16819763, 12.0806942], [75.16819763, 12.08208466], [75.16792297, 12.08208179], [75.16792297, 12.08264065], [75.16764069, 12.08263779], [75.16764069, 12.08319473], [75.1673584, 12.08318996], [75.1673584, 12.08375072], [75.16707611, 12.08375072], [75.16707611, 12.08431053], [75.16680908, 12.08430672], [75.16680908, 12.0848608], [75.16652679, 12.0848608], [75.16652679, 12.08514118], [75.16625214, 12.08513927], [75.16625214, 12.08597279], [75.16596985, 12.08597088], [75.16596985, 12.08653069], [75.16569519, 12.08652878], [75.16569519, 12.08736134], [75.1654129, 12.08736134], [75.1654129, 12.08791924], [75.16513824, 12.08791733], [75.16513824, 12.08847332], [75.16486359, 12.08847332], [75.16486359, 12.08874893], [75.1645813, 12.08874035], [75.1645813, 12.0893116], [75.16430664, 12.0893116], [75.16430664, 12.0901413], [75.16401672, 12.0901413], [75.16401672, 12.09152889], [75.16374969, 12.09152699], [75.16374969, 12.09180546], [75.16346741, 12.09180069], [75.16346741, 12.09264183], [75.16319275, 12.09263897], [75.16319275, 12.09347343], [75.16291809, 12.09347343], [75.16291809, 12.09458256], [75.1626358, 12.09458065], [75.1626358, 12.09542179], [75.16236115, 12.09541798], [75.16236115, 12.09597111], [75.16208649, 12.0959692], [75.16208649, 12.09624863], [75.16179657, 12.09624863], [75.16179657, 12.09653187], [75.16152954, 12.09653187], [75.16152954, 12.09793091], [75.16124725, 12.0979147], [75.16124725, 12.09847164], [75.1609726, 12.09847164], [75.1609726, 12.09902954], [75.16069794, 12.09902763], [75.16069794, 12.09958363], [75.16043091, 12.09957886], [75.16043091, 12.10042], [75.16014099, 12.10041809], [75.16014099, 12.10097218], [75.1598587, 12.10097027], [75.1598587, 12.10264015], [75.15957642, 12.10264015], [75.15957642, 12.10291958], [75.15930176, 12.10291958], [75.15930176, 12.10402966], [75.1590271, 12.10402966], [75.1590271, 12.10431099], [75.15875244, 12.10430622], [75.15875244, 12.10458374], [75.15847015, 12.10458183], [75.15847015, 12.10542107], [75.1581955, 12.1054163], [75.1581955, 12.10597229], [75.15791321, 12.10597038], [75.15791321, 12.10653114], [75.15763855, 12.10652828], [75.15763855, 12.10819435], [75.15737152, 12.10818958], [75.15737152, 12.10903072], [75.1570816, 12.10902882], [75.1570816, 12.10958195], [75.15763855, 12.10958195], [75.15763855, 12.1093111]]], [[[75.19403076, 12.11625099], [75.19403076, 12.11597061], [75.19430542, 12.11597347], [75.19430542, 12.11541653], [75.19458008, 12.11541939], [75.19458008, 12.11403084], [75.19431305, 12.11403084], [75.19431305, 12.11375141], [75.19403076, 12.11375141], [75.19403076, 12.11347103], [75.19291687, 12.11347103], [75.19291687, 12.11375141], [75.19180298, 12.11375141], [75.19180298, 12.11403084], [75.1920929, 12.11403084], [75.1920929, 12.11541939], [75.19235992, 12.11541653], [75.19235992, 12.115695], [75.19264221, 12.115695], [75.19264221, 12.11597347], [75.19319153, 12.11597061], [75.19319153, 12.11625099], [75.19403076, 12.11625099]]], [[[75.13541412, 12.18597221], [75.13541412, 12.18569374], [75.13597107, 12.18569374], [75.13597107, 12.18513775], [75.13626099, 12.18514919], [75.13626099, 12.18457985], [75.13652802, 12.18458366], [75.13652802, 12.18375015], [75.13680267, 12.18375015], [75.13680267, 12.18318939], [75.13708496, 12.18319416], [75.13708496, 12.18264008], [75.13764191, 12.18264008], [75.13764191, 12.1823597], [75.13791656, 12.1823597], [75.13791656, 12.18209076], [75.13846588, 12.18209076], [75.13846588, 12.18181038], [75.13874817, 12.18181038], [75.13874817, 12.18153], [75.13903046, 12.18153], [75.13903046, 12.18124962], [75.13957977, 12.18124962], [75.13957977, 12.18096924], [75.13986206, 12.1809721], [75.13986206, 12.18069363], [75.14041901, 12.18069363], [75.14041901, 12.18041801], [75.14068604, 12.18041992], [75.14068604, 12.17930984], [75.14097595, 12.17930984], [75.14097595, 12.17819118], [75.14069366, 12.17819309], [75.14069366, 12.17541695], [75.14125061, 12.17541981], [75.14125061, 12.17458057], [75.14097595, 12.17458344], [75.14097595, 12.17402744], [75.14125061, 12.1740303], [75.14125061, 12.17319107], [75.14152527, 12.17319489], [75.14152527, 12.17263889], [75.14180756, 12.17263889], [75.14180756, 12.17181015], [75.14206696, 12.17181015], [75.14206696, 12.1712513], [75.14235687, 12.1712513], [75.14235687, 12.17069054], [75.14263916, 12.1706953], [75.14263916, 12.17041683], [75.14290619, 12.1704216], [75.14290619, 12.17015266], [75.14319611, 12.17015266], [75.14319611, 12.16986084], [75.14347076, 12.16986084], [75.14347076, 12.16958141], [75.14375305, 12.16958332], [75.14375305, 12.16902924], [75.14402771, 12.16902924], [75.14402771, 12.16874886], [75.14430237, 12.16874886], [75.14430237, 12.16847324], [75.14458466, 12.16847324], [75.14458466, 12.16819477], [75.14485931, 12.16819477], [75.14485931, 12.16791725], [75.1451416, 12.16792107], [75.1451416, 12.16764069], [75.14543152, 12.16764069], [75.14543152, 12.16736126], [75.14569092, 12.16736126], [75.14569092, 12.16708279], [75.14597321, 12.16708279], [75.14597321, 12.16680527], [75.14624786, 12.16681099], [75.14624786, 12.16653061], [75.14653015, 12.16653061], [75.14653015, 12.16625118], [75.14679718, 12.16625118], [75.14679718, 12.16596985], [75.1470871, 12.16597271], [75.1470871, 12.16569519], [75.14736176, 12.16569519], [75.14736176, 12.16541672], [75.14763641, 12.16542053], [75.14763641, 12.16514111], [75.1479187, 12.16514111], [75.1479187, 12.16486073], [75.14820099, 12.16486073], [75.14819336, 12.16430664], [75.14849091, 12.16431141], [75.14849091, 12.16401958], [75.14875031, 12.16402912], [75.14875031, 12.16375065], [75.14901733, 12.16375065], [75.14901733, 12.1631918], [75.14930725, 12.1631937], [75.14930725, 12.16236019], [75.14958191, 12.16236019], [75.14958191, 12.16152763], [75.14985657, 12.16153145], [75.14985657, 12.16125011], [75.15013885, 12.16125011], [75.15013885, 12.16097927], [75.15040588, 12.16097927], [75.15040588, 12.16069031], [75.1506958, 12.16069412], [75.1506958, 12.16041565], [75.15097046, 12.16042137], [75.15097046, 12.16014004], [75.15123749, 12.16014004], [75.15123749, 12.15985966], [75.1515274, 12.15986156], [75.1515274, 12.15958214], [75.15180206, 12.15958214], [75.15180206, 12.15874958], [75.15207672, 12.15874958], [75.15207672, 12.15819168], [75.15180206, 12.15819359], [75.15180206, 12.15597153], [75.1515274, 12.15597153], [75.1515274, 12.15569401], [75.15180206, 12.15569401], [75.15180206, 12.15430641], [75.1515274, 12.15431023], [75.1515274, 12.15402985], [75.15123749, 12.15402985], [75.15123749, 12.15375042], [75.1506958, 12.15375042], [75.1506958, 12.15319061], [75.15041351, 12.15319443], [75.15041351, 12.15291786], [75.15013885, 12.15291977], [75.15013885, 12.15208054], [75.15041351, 12.15208435], [75.15041351, 12.15180588], [75.15013885, 12.15180969], [75.15013885, 12.15042019], [75.15040588, 12.15042019], [75.15040588, 12.14931011], [75.1506958, 12.14931011], [75.1506958, 12.14763927], [75.15040588, 12.14763927], [75.15040588, 12.14735889], [75.1506958, 12.1473608], [75.1506958, 12.14708328], [75.15013885, 12.14708328], [75.15013885, 12.14680481], [75.1498642, 12.14680481], [75.1498642, 12.1473608], [75.14958191, 12.14735889], [75.14958191, 12.14791965], [75.14930725, 12.14791965], [75.14930725, 12.14874935], [75.14901733, 12.14874935], [75.14901733, 12.14931011], [75.14875031, 12.14931011], [75.14875031, 12.15042019], [75.14849091, 12.15042019], [75.14849091, 12.15125179], [75.14820099, 12.15125179], [75.14820099, 12.15153027], [75.1479187, 12.15153027], [75.1479187, 12.15180969], [75.14763641, 12.15180969], [75.14763641, 12.15236187], [75.14736176, 12.15236187], [75.14736176, 12.15264034], [75.1470871, 12.15263844], [75.1470871, 12.15347195], [75.14680481, 12.15347195], [75.14680481, 12.15458393], [75.14653015, 12.15458393], [75.14653015, 12.15597153], [75.14624786, 12.15597153], [75.14624786, 12.15708447], [75.14597321, 12.1570797], [75.14597321, 12.15764046], [75.14569092, 12.1576376], [75.14569092, 12.15819359], [75.14543152, 12.15819168], [75.14543152, 12.15874958], [75.1451416, 12.15874958], [75.1451416, 12.16014004], [75.14485931, 12.16013813], [75.14485931, 12.16236019], [75.14458466, 12.16236019], [75.14458466, 12.16402912], [75.14430237, 12.16401958], [75.14430237, 12.16514111], [75.14402771, 12.16514111], [75.14402771, 12.16625118], [75.14375305, 12.16625118], [75.14375305, 12.16736126], [75.14347076, 12.16736126], [75.14347076, 12.16792107], [75.14319611, 12.16791725], [75.14319611, 12.16847324], [75.14290619, 12.16847134], [75.14290619, 12.16902924], [75.14263916, 12.16902733], [75.14263916, 12.16958332], [75.14235687, 12.16958141], [75.14235687, 12.17015266], [75.14206696, 12.17015266], [75.14206696, 12.1704216], [75.14180756, 12.17041683], [75.14180756, 12.17097092], [75.14152527, 12.17097092], [75.1415329, 12.1712513], [75.14125061, 12.1712513], [75.14125061, 12.17153168], [75.14097595, 12.17152691], [75.14097595, 12.1720829], [75.14069366, 12.1720829], [75.14069366, 12.17236137], [75.14041901, 12.17236137], [75.14041901, 12.17292023], [75.14013672, 12.17291737], [75.14013672, 12.17319489], [75.13986206, 12.17319107], [75.13986206, 12.17375088], [75.13957977, 12.17375088], [75.13957977, 12.1740303], [75.13929749, 12.1740303], [75.13929749, 12.17430973], [75.13957977, 12.17430973], [75.13957977, 12.17486095], [75.13929749, 12.17486095], [75.13929749, 12.17513943], [75.13903046, 12.17513943], [75.13903046, 12.17569637], [75.13874817, 12.17569637], [75.13874817, 12.17708397], [75.13846588, 12.17708111], [75.13846588, 12.17792034], [75.13819122, 12.17791462], [75.13819122, 12.17847157], [75.13764191, 12.17847157], [75.13764191, 12.17930984], [75.13735962, 12.17930984], [75.13735962, 12.18041992], [75.13707733, 12.18041992], [75.13707733, 12.1823597], [75.13680267, 12.1823597], [75.13680267, 12.18292046], [75.13652802, 12.18291569], [75.13652802, 12.18347168], [75.13625336, 12.18347168], [75.13626099, 12.18375015], [75.13569641, 12.18375015], [75.13569641, 12.18264008], [75.13540649, 12.18264008], [75.13540649, 12.18181038], [75.13513947, 12.18181038], [75.13513947, 12.18153], [75.13485718, 12.18153], [75.13485718, 12.18181038], [75.13458252, 12.18181038], [75.13458252, 12.1823597], [75.13430786, 12.1823597], [75.13430786, 12.18375015], [75.1340332, 12.18375015], [75.1340332, 12.18431091], [75.13430786, 12.18430614], [75.13430786, 12.18458366], [75.13458252, 12.18457985], [75.13458252, 12.18514919], [75.13486481, 12.18513775], [75.13486481, 12.18569374], [75.13513947, 12.18569374], [75.13513947, 12.18597221], [75.13541412, 12.18597221]]], [[[75.13181305, 12.19153118], [75.13181305, 12.1912508], [75.13208008, 12.1912508], [75.13208008, 12.19096088], [75.13263702, 12.19097328], [75.13263702, 12.19069481], [75.13319397, 12.19069481], [75.13319397, 12.19013786], [75.13346863, 12.19014072], [75.13346863, 12.18986034], [75.13375092, 12.18986034], [75.13375092, 12.18958473], [75.13402557, 12.18958473], [75.13402557, 12.18930435], [75.13430786, 12.18931103], [75.13430786, 12.18819046], [75.13402557, 12.18819427], [75.13402557, 12.18735981], [75.1332016, 12.18736172], [75.1332016, 12.18792057], [75.13291931, 12.1879158], [75.13291931, 12.18819427], [75.13263702, 12.18819046], [75.13263702, 12.18847179], [75.13236237, 12.18847179], [75.13236237, 12.18875027], [75.13208008, 12.18875027], [75.13208008, 12.18931103], [75.13181305, 12.18931103], [75.13181305, 12.1904211], [75.13153076, 12.1904211], [75.13153076, 12.1912508], [75.13124847, 12.1912508], [75.13124847, 12.19153118], [75.13181305, 12.19153118]]], [[[75.16346741, 12.11541939], [75.16346741, 12.11514091], [75.16374969, 12.11514091], [75.16374969, 12.11486053], [75.16430664, 12.11486053], [75.16430664, 12.11458302], [75.1645813, 12.11458302], [75.1645813, 12.11430454], [75.1654129, 12.11430931], [75.1654129, 12.11375141], [75.16570282, 12.11375141], [75.16569519, 12.11347294], [75.16652679, 12.11347294], [75.16652679, 12.11319542], [75.16708374, 12.11319542], [75.16708374, 12.11263943], [75.16819763, 12.11264133], [75.16819763, 12.11236095], [75.16874695, 12.11236095], [75.16874695, 12.11207962], [75.16902924, 12.11208344], [75.16902924, 12.11180687], [75.16931152, 12.11181068], [75.16931152, 12.11153126], [75.16986084, 12.11153126], [75.16986084, 12.11096954], [75.1701355, 12.11097336], [75.1701355, 12.11069489], [75.17041779, 12.11069489], [75.17041779, 12.11013794], [75.17069244, 12.1101408], [75.17069244, 12.10903072], [75.1709671, 12.10903072], [75.1709671, 12.10875034], [75.17069244, 12.10875034], [75.17069244, 12.10764122], [75.17041779, 12.10764122], [75.17041779, 12.10736275], [75.17014313, 12.10736275], [75.17014313, 12.10653114], [75.16986084, 12.10653114], [75.16986084, 12.10625267], [75.16958618, 12.10625267], [75.16958618, 12.10569191], [75.16930389, 12.10569382], [75.16930389, 12.10458374], [75.16902924, 12.10458374], [75.16902924, 12.10430622], [75.16931152, 12.10431099], [75.16931152, 12.10402966], [75.16902924, 12.10402966], [75.16902924, 12.10374069], [75.16930389, 12.10375023], [75.16930389, 12.10319424], [75.16958618, 12.10319424], [75.16958618, 12.10291576], [75.16986084, 12.10291958], [75.16986084, 12.10181141], [75.17014313, 12.10181141], [75.17014313, 12.10124969], [75.17041779, 12.10124969], [75.17041779, 12.10097027], [75.17097473, 12.10097218], [75.17097473, 12.1006937], [75.17152405, 12.1006937], [75.17152405, 12.09930611], [75.17124939, 12.09930992], [75.17124939, 12.09847164], [75.17097473, 12.09847164], [75.17097473, 12.09819412], [75.17069244, 12.09819412], [75.17069244, 12.0979147], [75.17041779, 12.09793091], [75.17041779, 12.09764194], [75.17014313, 12.09764194], [75.17014313, 12.09708118], [75.16986084, 12.09708405], [75.16986084, 12.0965271], [75.16958618, 12.09653187], [75.16958618, 12.09624863], [75.16874695, 12.09624863], [75.16874695, 12.0959692], [75.16847229, 12.0959692], [75.16847229, 12.09653187], [75.16819763, 12.0965271], [75.16819763, 12.09708405], [75.16791534, 12.09708405], [75.16791534, 12.09736156], [75.16764069, 12.09736156], [75.16764069, 12.09793091], [75.1673584, 12.0979147], [75.1673584, 12.09847164], [75.16708374, 12.09847164], [75.16708374, 12.09958363], [75.16652679, 12.09958363], [75.16652679, 12.10208416], [75.16623688, 12.10207939], [75.16623688, 12.10236168], [75.16596985, 12.10236168], [75.16596985, 12.10291958], [75.16569519, 12.10291576], [75.16569519, 12.10319424], [75.16596985, 12.10319424], [75.16596985, 12.10347176], [75.1654129, 12.10346985], [75.1654129, 12.10402966], [75.16486359, 12.10402775], [75.16486359, 12.10458374], [75.1645813, 12.10458374], [75.1645813, 12.10486221], [75.16401672, 12.10486031], [75.16401672, 12.10513973], [75.16374969, 12.10513973], [75.16374969, 12.10542107], [75.16291809, 12.1054163], [75.16291809, 12.10597229], [75.1626358, 12.10597038], [75.1626358, 12.10681057], [75.16291809, 12.10681057], [75.16291809, 12.10764122], [75.1626358, 12.10763836], [75.1626358, 12.10819435], [75.16236115, 12.10819435], [75.16236115, 12.10847187], [75.16208649, 12.10846996], [75.16208649, 12.10903072], [75.1618042, 12.10902882], [75.1618042, 12.10958195], [75.16152954, 12.10958004], [75.16152954, 12.10987186], [75.16179657, 12.10987186], [75.16179657, 12.11042118], [75.16152954, 12.11041737], [75.16152954, 12.11069489], [75.16179657, 12.11069012], [75.16179657, 12.11125088], [75.1609726, 12.11125088], [75.1609726, 12.11096954], [75.16069794, 12.11096954], [75.16069794, 12.11181068], [75.16043091, 12.11181068], [75.16043091, 12.11430931], [75.16069794, 12.11430454], [75.16069794, 12.11458302], [75.16124725, 12.11458302], [75.16124725, 12.11486053], [75.16152954, 12.11486053], [75.16152954, 12.11514091], [75.1626358, 12.11514091], [75.1626358, 12.11541939], [75.16346741, 12.11541939]]], [[[75.15402985, 12.14264107], [75.15402985, 12.14208126], [75.1543045, 12.14208317], [75.1543045, 12.14152908], [75.15458679, 12.14153099], [75.15458679, 12.14097118], [75.15486145, 12.14097309], [75.15486145, 12.14069462], [75.15513611, 12.14069462], [75.15513611, 12.1404171], [75.1554184, 12.14042091], [75.1554184, 12.14014053], [75.15569305, 12.14014053], [75.15569305, 12.14042091], [75.15598297, 12.14042091], [75.15598297, 12.14014053], [75.15651703, 12.14014053], [75.15651703, 12.13985157], [75.1570816, 12.13986111], [75.1570816, 12.13958263], [75.15763855, 12.13958263], [75.15763855, 12.13902664], [75.15791321, 12.13903141], [75.15791321, 12.13875103], [75.15875244, 12.13875103], [75.15875244, 12.1384697], [75.1590271, 12.13847256], [75.1590271, 12.13819504], [75.15930176, 12.13819504], [75.15930939, 12.13735962], [75.1598587, 12.13735962], [75.1598587, 12.13680744], [75.16043091, 12.13681126], [75.16043091, 12.13625145], [75.16069794, 12.13625145], [75.16069794, 12.13597012], [75.1609726, 12.13597202], [75.1609726, 12.13569355], [75.16124725, 12.13569355], [75.16124725, 12.13541603], [75.16152954, 12.1354208], [75.16152954, 12.13486004], [75.16179657, 12.13486004], [75.16179657, 12.13404179], [75.16208649, 12.13404179], [75.16208649, 12.13319016], [75.1618042, 12.13319397], [75.1618042, 12.13263798], [75.16152954, 12.13264275], [75.16152954, 12.13153267], [75.16124725, 12.13153267], [75.16124725, 12.13125038], [75.1609726, 12.13125038], [75.1609726, 12.13097191], [75.16014099, 12.13097191], [75.16014099, 12.13069439], [75.1598587, 12.13069439], [75.1598587, 12.1301403], [75.15957642, 12.1301403], [75.15957642, 12.12763977], [75.1598587, 12.12763977], [75.1598587, 12.12708187], [75.15958405, 12.12708378], [75.15958405, 12.12625027], [75.15930939, 12.12625027], [75.15930939, 12.12541962], [75.15957642, 12.12541962], [75.15957642, 12.12514019], [75.15930939, 12.12514019], [75.15930939, 12.1245842], [75.15930176, 12.12347126], [75.1590271, 12.12347126], [75.1590271, 12.12263966], [75.15875244, 12.12263966], [75.15875244, 12.12235928], [75.1590271, 12.12236118], [75.1590271, 12.12152672], [75.15875244, 12.12152958], [75.15875244, 12.1212492], [75.15847015, 12.1212492], [75.15847015, 12.12097073], [75.1581955, 12.12097359], [75.15820313, 12.1212492], [75.15791321, 12.1212492], [75.15791321, 12.12292004], [75.15763855, 12.12292004], [75.15763855, 12.12430954], [75.1570816, 12.12430954], [75.1570816, 12.12487125], [75.15680695, 12.12487125], [75.15680695, 12.12514019], [75.15651703, 12.12514019], [75.15651703, 12.12541962], [75.15625, 12.12541962], [75.15625, 12.12597179], [75.15597534, 12.12597179], [75.15598297, 12.12625027], [75.15569305, 12.12625027], [75.15569305, 12.12708378], [75.1554184, 12.12708378], [75.1554184, 12.12736225], [75.15486145, 12.12736225], [75.15486145, 12.12819386], [75.15458679, 12.12819195], [75.15458679, 12.12874985], [75.15429688, 12.12874985], [75.15429688, 12.12985992], [75.15374756, 12.12985992], [75.15374756, 12.13097191], [75.1534729, 12.13097191], [75.1534729, 12.13153267], [75.15319824, 12.1315279], [75.15319061, 12.13236237], [75.15291595, 12.13236237], [75.15291595, 12.13319397], [75.15235901, 12.13319397], [75.15235901, 12.13347244], [75.15207672, 12.13346958], [75.15207672, 12.13374996], [75.15180206, 12.13374996], [75.15180206, 12.13404179], [75.1515274, 12.13404179], [75.1515274, 12.13486004], [75.15125275, 12.13486004], [75.15125275, 12.13597202], [75.15097046, 12.13597012], [75.15097046, 12.13625145], [75.15123749, 12.13625145], [75.15123749, 12.13653088], [75.15097046, 12.13653088], [75.15097046, 12.13764095], [75.1506958, 12.13763905], [75.1506958, 12.13847256], [75.15013885, 12.1384697], [75.15013885, 12.13903141], [75.1498642, 12.13902664], [75.1498642, 12.13958263], [75.14958191, 12.13958263], [75.14958191, 12.14097309], [75.15013885, 12.14097118], [75.15013885, 12.14153099], [75.15097046, 12.14153099], [75.15097046, 12.14180946], [75.15125275, 12.1418047], [75.15125275, 12.14208317], [75.15180206, 12.14208126], [75.15180206, 12.14236069], [75.15207672, 12.14236069], [75.15207672, 12.14264107], [75.1526413, 12.14264107], [75.1526413, 12.14236069], [75.15291595, 12.14236069], [75.15291595, 12.14264107], [75.15402985, 12.14264107]]], [[[75.12652588, 12.20514202], [75.12652588, 12.20486164], [75.12680817, 12.20486164], [75.12680817, 12.20403194], [75.12652588, 12.20403194], [75.12652588, 12.20263863], [75.12680817, 12.20263863], [75.12680817, 12.20097065], [75.12708282, 12.20097256], [75.12708282, 12.19986057], [75.12735748, 12.19986057], [75.12735748, 12.19763947], [75.12706757, 12.19764137], [75.12706757, 12.19597054], [75.12735748, 12.1959734], [75.12735748, 12.19486141], [75.12763977, 12.19486141], [75.12763977, 12.19430542], [75.1279068, 12.19430923], [75.1279068, 12.19403076], [75.12819672, 12.19403076], [75.12819672, 12.19375134], [75.12847137, 12.19375134], [75.12847137, 12.19292068], [75.12874603, 12.19292068], [75.12874603, 12.19236088], [75.12930298, 12.19236088], [75.12930298, 12.19207954], [75.12958527, 12.19208336], [75.12958527, 12.19152641], [75.12985992, 12.19153118], [75.12985992, 12.19096088], [75.13014221, 12.19097328], [75.13014221, 12.19041634], [75.13041687, 12.1904211], [75.13041687, 12.19014072], [75.13069153, 12.19014072], [75.13069153, 12.18903065], [75.13096619, 12.18903065], [75.13096619, 12.18847179], [75.13069153, 12.18847179], [75.13069153, 12.18819046], [75.13097382, 12.18819427], [75.13097382, 12.18652821], [75.13124847, 12.18653107], [75.13124847, 12.18569183], [75.13097382, 12.18569374], [75.13097382, 12.18541622], [75.13124847, 12.18542099], [75.13124847, 12.18457985], [75.13153076, 12.18458366], [75.13153076, 12.18375015], [75.13181305, 12.18375015], [75.13180542, 12.18319416], [75.13208008, 12.18319416], [75.13208008, 12.18264008], [75.13236237, 12.18264008], [75.13236237, 12.18209076], [75.13263702, 12.18209076], [75.13263702, 12.18153], [75.13291931, 12.18153], [75.13291931, 12.18096924], [75.13319397, 12.1809721], [75.13319397, 12.18041801], [75.13346863, 12.18041992], [75.13346863, 12.17986202], [75.13375092, 12.17986202], [75.13375092, 12.17930984], [75.1340332, 12.17930984], [75.1340332, 12.17875195], [75.13430786, 12.17875195], [75.13430786, 12.17819118], [75.13458252, 12.17819309], [75.13458252, 12.17763996], [75.13485718, 12.17764187], [75.13485718, 12.17708111], [75.13513947, 12.17708397], [75.13513947, 12.17652702], [75.13540649, 12.17653179], [75.13540649, 12.17595959], [75.13569641, 12.17597103], [75.13569641, 12.17541695], [75.13597107, 12.17541981], [75.13597107, 12.17486095], [75.13569641, 12.17486095], [75.13569641, 12.1740303], [75.13540649, 12.1740303], [75.13540649, 12.17208099], [75.13569641, 12.1720829], [75.13569641, 12.17152691], [75.13597107, 12.17153168], [75.13597107, 12.17097092], [75.13625336, 12.17097092], [75.13625336, 12.1706953], [75.13652802, 12.1706953], [75.13652802, 12.17041683], [75.13680267, 12.1704216], [75.13680267, 12.17015266], [75.13707733, 12.17015266], [75.13707733, 12.16986084], [75.13735962, 12.16986084], [75.13735962, 12.16958141], [75.13764191, 12.16958332], [75.13764191, 12.16930485], [75.13791656, 12.16931152], [75.13791656, 12.16902924], [75.13819122, 12.16902924], [75.13819122, 12.16874886], [75.13847351, 12.16874886], [75.13847351, 12.16847324], [75.13874817, 12.16847324], [75.13874817, 12.16819477], [75.13903046, 12.16819477], [75.13903046, 12.16791725], [75.13929749, 12.16792107], [75.13929749, 12.16764069], [75.13957977, 12.16764069], [75.13957977, 12.16736126], [75.13986206, 12.16736126], [75.13986206, 12.16708279], [75.14013672, 12.16708279], [75.14013672, 12.1665287], [75.14041901, 12.16653061], [75.14041901, 12.16625118], [75.14068604, 12.16625118], [75.14068604, 12.16569042], [75.14097595, 12.16569519], [75.14097595, 12.1651392], [75.14125061, 12.16514111], [75.14125061, 12.16486073], [75.1415329, 12.16486073], [75.14152527, 12.16430664], [75.14180756, 12.16431141], [75.14180756, 12.16264057], [75.1415329, 12.16264057], [75.1415329, 12.15903091], [75.14180756, 12.15903091], [75.14180756, 12.15596962], [75.14208221, 12.15597153], [75.14208221, 12.15513992], [75.14235687, 12.15513992], [75.14235687, 12.15402985], [75.14263916, 12.15402985], [75.14263916, 12.15319061], [75.14291382, 12.15319443], [75.14291382, 12.15236187], [75.14319611, 12.15236187], [75.14319611, 12.15180969], [75.14347076, 12.15180969], [75.14347076, 12.15125179], [75.14375305, 12.15125179], [75.14375305, 12.15069103], [75.14402771, 12.1506958], [75.14402771, 12.15041542], [75.14430237, 12.15042019], [75.14430237, 12.14985943], [75.14458466, 12.14986229], [75.14458466, 12.14930534], [75.14485931, 12.14931011], [75.14485931, 12.14874935], [75.1451416, 12.14874935], [75.1451416, 12.14847088], [75.14569092, 12.14847088], [75.14569092, 12.14819336], [75.14624786, 12.14819336], [75.14624786, 12.14763927], [75.14653015, 12.14763927], [75.14653015, 12.14708138], [75.14680481, 12.14708328], [75.14680481, 12.14652729], [75.1470871, 12.1465292], [75.1470871, 12.14598179], [75.14736176, 12.14598179], [75.14736176, 12.14542198], [75.14763641, 12.14542198], [75.14763641, 12.14486122], [75.1479187, 12.14486122], [75.1479187, 12.14319515], [75.14763641, 12.14319515], [75.14763641, 12.14152908], [75.14736176, 12.14153099], [75.14736176, 12.13985157], [75.1470871, 12.13986111], [75.1470871, 12.13735962], [75.14736176, 12.13735962], [75.14736176, 12.13647175], [75.14736176, 12.13541603], [75.14763641, 12.1354208], [75.14763641, 12.13457966], [75.1479187, 12.13458538], [75.1479187, 12.13374996], [75.14820099, 12.13374996], [75.14820099, 12.13320065], [75.14849091, 12.13319016], [75.14847565, 12.13236237], [75.14875031, 12.13236237], [75.14875031, 12.1315279], [75.14901733, 12.13153267], [75.14901733, 12.13097191], [75.14930725, 12.13097191], [75.14930725, 12.13041592], [75.14958191, 12.13042068], [75.14958191, 12.12985992], [75.14985657, 12.12985992], [75.14985657, 12.12903023], [75.15013885, 12.12903023], [75.15013885, 12.12847042], [75.15041351, 12.12847233], [75.15041351, 12.12791634], [75.1506958, 12.12791634], [75.1506958, 12.12736225], [75.15097046, 12.12736225], [75.15097046, 12.12680626], [75.15123749, 12.12681007], [75.15123749, 12.12597179], [75.1515274, 12.12597179], [75.1515274, 12.12541962], [75.15180206, 12.12541962], [75.15180206, 12.12487125], [75.15207672, 12.12487125], [75.15207672, 12.12430954], [75.15235901, 12.12430954], [75.15235901, 12.12347126], [75.1526413, 12.12347126], [75.1526413, 12.12291527], [75.15291595, 12.12292004], [75.15291595, 12.12235928], [75.15319824, 12.12236118], [75.15319824, 12.12180519], [75.1534729, 12.12180996], [75.1534729, 12.1212492], [75.15374756, 12.1212492], [75.15374756, 12.12097073], [75.15402985, 12.12097359], [75.15402985, 12.12069321], [75.1543045, 12.12069321], [75.1543045, 12.12041664], [75.15450287, 12.12042046], [75.15458679, 12.12041664], [75.15458679, 12.11998653], [75.15458679, 12.11986065], [75.15486145, 12.11986065], [75.15486145, 12.11958122], [75.15513611, 12.11958313], [75.15513611, 12.11930466], [75.1554184, 12.11931038], [75.1554184, 12.11875057], [75.15569305, 12.11875057], [75.15569305, 12.11819077], [75.15597534, 12.11819458], [75.15597534, 12.11736107], [75.15625, 12.11736107], [75.15625, 12.11681175], [75.15651703, 12.11681175], [75.15651703, 12.11625099], [75.15680695, 12.11625099], [75.15680695, 12.11191177], [75.15680695, 12.11097336], [75.1570816, 12.11097336], [75.1570816, 12.11041737], [75.15729523, 12.11039352], [75.15737152, 12.11016083], [75.15652466, 12.11013794], [75.15652466, 12.11069489], [75.15625, 12.11069489], [75.15625, 12.11097336], [75.15598297, 12.11096954], [75.15598297, 12.11153126], [75.15569305, 12.11153126], [75.15569305, 12.11236095], [75.1554184, 12.11236095], [75.1554184, 12.1129303], [75.15513611, 12.11291695], [75.15513611, 12.11347294], [75.15486145, 12.11347103], [75.15486145, 12.11430931], [75.15458679, 12.11430931], [75.15458679, 12.11541939], [75.1543045, 12.11541653], [75.1543045, 12.11597347], [75.15402985, 12.11597061], [75.15402985, 12.11625099], [75.15374756, 12.11625099], [75.15374756, 12.1170826], [75.1534729, 12.11708069], [75.1534729, 12.11736107], [75.15319824, 12.11736107], [75.15319061, 12.11792183], [75.15291595, 12.11792183], [75.15291595, 12.11931038], [75.1526413, 12.11931038], [75.1526413, 12.11986065], [75.15235901, 12.11986065], [75.15235901, 12.12042046], [75.15207672, 12.12042046], [75.15207672, 12.12152958], [75.15180206, 12.12152672], [75.15180206, 12.12208271], [75.1515274, 12.1220789], [75.1515274, 12.12292004], [75.15125275, 12.12291527], [75.15125275, 12.12347126], [75.15097046, 12.12347126], [75.15097046, 12.12403202], [75.1506958, 12.12402821], [75.1506958, 12.1245842], [75.15040588, 12.12458134], [75.15040588, 12.12597179], [75.15013885, 12.12597179], [75.15013885, 12.12625027], [75.14985657, 12.12625027], [75.14985657, 12.12681007], [75.14958191, 12.12680626], [75.14958191, 12.12736225], [75.14930725, 12.12736225], [75.14930725, 12.12847233], [75.14901733, 12.12847042], [75.14901733, 12.12931061], [75.14875031, 12.12931061], [75.14875031, 12.12985992], [75.14849091, 12.12985992], [75.14849091, 12.13042068], [75.14819336, 12.13041592], [75.14819336, 12.13069439], [75.1479187, 12.13069439], [75.1479187, 12.13097191], [75.14763641, 12.13097191], [75.14763641, 12.13153267], [75.14736176, 12.13153267], [75.14736176, 12.13264275], [75.1470871, 12.13264275], [75.1470871, 12.13292122], [75.14679718, 12.13292122], [75.14679718, 12.13431072], [75.14653015, 12.13431072], [75.14653015, 12.13514137], [75.14624786, 12.13513756], [75.14624786, 12.13597202], [75.14597321, 12.13597012], [75.14597321, 12.13681126], [75.14569092, 12.13680744], [75.14569092, 12.13735962], [75.14543152, 12.13735962], [75.14543152, 12.13764095], [75.1451416, 12.13763905], [75.1451416, 12.13819504], [75.14485931, 12.13819027], [75.14485931, 12.13931084], [75.14457703, 12.13931084], [75.14457703, 12.14014053], [75.14430237, 12.14013863], [75.14430237, 12.14069462], [75.14402771, 12.14068985], [75.14402771, 12.14125061], [75.14375305, 12.14125061], [75.14375305, 12.14180946], [75.14347076, 12.14180946], [75.14347076, 12.14236069], [75.14319611, 12.14236069], [75.14319611, 12.14291668], [75.14291382, 12.14291668], [75.14291382, 12.14347076], [75.14263916, 12.14346886], [75.14263916, 12.14375114], [75.14235687, 12.14375114], [75.14235687, 12.14403152], [75.14208221, 12.14402676], [75.14208221, 12.14486122], [75.14180756, 12.14486122], [75.14180756, 12.14542198], [75.14206696, 12.14542198], [75.14206696, 12.14598179], [75.14180756, 12.14598179], [75.14180756, 12.1465292], [75.14152527, 12.14652729], [75.14152527, 12.14708328], [75.14125061, 12.14708138], [75.14125061, 12.14763927], [75.14097595, 12.14763927], [75.14097595, 12.14847088], [75.14068604, 12.14847088], [75.14068604, 12.14904118], [75.14041901, 12.14904118], [75.14041901, 12.14931011], [75.14013672, 12.14931011], [75.14013672, 12.15042019], [75.13986206, 12.15042019], [75.13986206, 12.15125179], [75.13957977, 12.15125179], [75.13957977, 12.15180969], [75.13929749, 12.15180969], [75.13929749, 12.15264034], [75.13903046, 12.15263844], [75.13903046, 12.15319443], [75.13874817, 12.15319061], [75.13874817, 12.15375042], [75.13846588, 12.15375042], [75.13846588, 12.15431023], [75.13819122, 12.15430641], [75.13819122, 12.1548624], [75.13791656, 12.15485096], [75.13791656, 12.15625], [75.13764191, 12.15625], [75.13764191, 12.15681076], [75.13735962, 12.15680599], [75.13735962, 12.15708447], [75.13707733, 12.1570797], [75.13707733, 12.15931129], [75.13680267, 12.15930557], [75.13680267, 12.15958214], [75.13652802, 12.15958214], [75.13652802, 12.16069412], [75.13626099, 12.16069031], [75.13626099, 12.16125011], [75.13597107, 12.16125011], [75.13597107, 12.16181087], [75.13569641, 12.1618042], [75.13569641, 12.16236019], [75.13541412, 12.16236019], [75.13541412, 12.16347313], [75.13513947, 12.16347313], [75.13513947, 12.16402912], [75.13485718, 12.16401958], [75.13485718, 12.16486073], [75.13458252, 12.16486073], [75.13458252, 12.16569519], [75.13430786, 12.16569042], [75.13430786, 12.16625118], [75.1340332, 12.16625118], [75.1340332, 12.16681099], [75.13375092, 12.16680527], [75.13375092, 12.16736126], [75.13346863, 12.16736126], [75.13346863, 12.16792107], [75.13319397, 12.16791725], [75.13319397, 12.16874886], [75.13263702, 12.16874886], [75.13263702, 12.17015266], [75.13236237, 12.17015266], [75.13236237, 12.1712513], [75.13208008, 12.1712513], [75.13208008, 12.17181015], [75.13180542, 12.17180538], [75.13180542, 12.17236137], [75.13153076, 12.17236137], [75.13153076, 12.17292023], [75.13124847, 12.17292023], [75.13124847, 12.17375088], [75.13097382, 12.17374897], [75.13097382, 12.17458344], [75.13069153, 12.17458057], [75.13069153, 12.17541981], [75.13041687, 12.17541981], [75.13041687, 12.17624855], [75.13014221, 12.17624855], [75.13014221, 12.17708397], [75.12985992, 12.17708111], [75.12985992, 12.17764187], [75.12958527, 12.17763996], [75.12958527, 12.17847157], [75.12930298, 12.17847157], [75.12930298, 12.17902756], [75.12902832, 12.17902756], [75.12902832, 12.17958355], [75.12874603, 12.17958069], [75.12874603, 12.18124962], [75.12847137, 12.18124962], [75.12847137, 12.18153], [75.12819672, 12.18153], [75.12819672, 12.18209076], [75.1279068, 12.18209076], [75.1279068, 12.1823597], [75.12763977, 12.1823597], [75.12763977, 12.18292046], [75.12735748, 12.18292046], [75.12735748, 12.18375015], [75.12708282, 12.18375015], [75.12708282, 12.18458366], [75.12680817, 12.18457985], [75.12680817, 12.18542099], [75.12652588, 12.18542099], [75.12652588, 12.18624973], [75.12625122, 12.18624973], [75.12625122, 12.18681145], [75.12596893, 12.18681145], [75.12596893, 12.18736172], [75.12568665, 12.18736172], [75.12568665, 12.18764114], [75.12541962, 12.18764114], [75.12541962, 12.18847179], [75.12513733, 12.18847179], [75.12513733, 12.18958473], [75.12486267, 12.18957996], [75.12486267, 12.19014072], [75.12458038, 12.19013786], [75.12458038, 12.19069481], [75.12430573, 12.19069481], [75.12432098, 12.1912508], [75.12403107, 12.1912508], [75.12403107, 12.19153118], [75.12374878, 12.19153118], [75.12374878, 12.19181061], [75.12346649, 12.19181061], [75.12346649, 12.19236088], [75.12374878, 12.19236088], [75.12374878, 12.19264126], [75.12403107, 12.19264126], [75.12403107, 12.19292068], [75.12430573, 12.19291687], [75.12430573, 12.19334126], [75.12430573, 12.19347286], [75.12374878, 12.19347095], [75.12374878, 12.19403076], [75.12346649, 12.19403076], [75.12346649, 12.19430923], [75.12319183, 12.19430542], [75.12319183, 12.19486141], [75.12291718, 12.19486141], [75.12291718, 12.19721985], [75.12291718, 12.19736099], [75.12264252, 12.19736099], [75.12264252, 12.19798088], [75.12264252, 12.19847107], [75.12246704, 12.19847107], [75.12236023, 12.19847107], [75.12236786, 12.19875145], [75.12264252, 12.19875145], [75.12264252, 12.19958305], [75.12291718, 12.19958305], [75.12291718, 12.20013905], [75.12319183, 12.20013046], [75.12319183, 12.20125103], [75.12346649, 12.20125103], [75.12346649, 12.20153046], [75.12374878, 12.20152664], [75.12374878, 12.20208263], [75.12403107, 12.20208073], [75.12403107, 12.20291996], [75.12430573, 12.20291805], [75.12430573, 12.20319557], [75.12458038, 12.20319557], [75.12458038, 12.20347118], [75.12486267, 12.20346928], [75.12486267, 12.20431042], [75.12513733, 12.20431042], [75.12513733, 12.20486164], [75.12541962, 12.20486164], [75.12541962, 12.20514202], [75.12652588, 12.20514202]]], [[[75.13014221, 12.19819546], [75.13014221, 12.19791698], [75.13069153, 12.19792175], [75.13069153, 12.19764137], [75.13124847, 12.19764137], [75.13124847, 12.19681168], [75.13153076, 12.19681168], [75.13153076, 12.19569016], [75.13124847, 12.19569492], [75.13124847, 12.1954174], [75.13096619, 12.19541931], [75.13096619, 12.19514084], [75.13041687, 12.19514084], [75.13041687, 12.19486141], [75.13014221, 12.19486141], [75.13014221, 12.19458294], [75.12930298, 12.19458008], [75.12930298, 12.1965313], [75.1295929, 12.1965313], [75.1295929, 12.19764137], [75.12985992, 12.19763947], [75.12985992, 12.19819546], [75.13014221, 12.19819546]]], [[[75.36791992, 11.94347191], [75.36791992, 11.94235992], [75.36818695, 11.94235992], [75.36818695, 11.94181061], [75.36846924, 11.94181061], [75.36846924, 11.94124126], [75.36819458, 11.94124985], [75.36819458, 11.94041634], [75.36791992, 11.94042015], [75.36791992, 11.93958187], [75.36736298, 11.93958378], [75.36736298, 11.93902779], [75.36708069, 11.93902969], [75.36708069, 11.9382], [75.36653137, 11.9382], [75.36653137, 11.93791962], [75.36624908, 11.93791962], [75.36624908, 11.93735886], [75.36597443, 11.93736172], [75.36597443, 11.9370842], [75.36569214, 11.9370842], [75.36569214, 11.93680573], [75.36514282, 11.93680954], [75.36514282, 11.93624973], [75.36485291, 11.93624973], [75.36485291, 11.93596935], [75.36430359, 11.93597221], [75.36430359, 11.9370842], [75.36458588, 11.93708134], [75.36458588, 11.93791962], [75.36485291, 11.93791962], [75.36485291, 11.93875027], [75.36541748, 11.93875027], [75.36541748, 11.93931007], [75.36569214, 11.93930626], [75.36569214, 11.93986225], [75.3659668, 11.93986034], [75.3659668, 11.94013977], [75.36624908, 11.94013977], [75.36624908, 11.94042015], [75.36653137, 11.94042015], [75.36653137, 11.94153023], [75.36680603, 11.94153023], [75.36680603, 11.94181061], [75.36708069, 11.94181061], [75.36708069, 11.94292068], [75.36736298, 11.94291592], [75.36736298, 11.94347191], [75.36791992, 11.94347191]]], [[[75.36624908, 11.94208431], [75.36624908, 11.94180584], [75.3659668, 11.94181061], [75.3659668, 11.94069195], [75.36569214, 11.94069386], [75.36569214, 11.94041634], [75.36541748, 11.94042015], [75.36541748, 11.94013977], [75.36514282, 11.94013977], [75.36514282, 11.93986034], [75.36486053, 11.93986225], [75.36486053, 11.93930626], [75.36458588, 11.93931007], [75.36458588, 11.93902969], [75.36429596, 11.93902969], [75.36429596, 11.93847179], [75.36402893, 11.93847179], [75.36402893, 11.93791962], [75.36374664, 11.93791962], [75.36374664, 11.93902969], [75.36402893, 11.93902969], [75.36402893, 11.93931007], [75.36429596, 11.93931007], [75.36429596, 11.94013977], [75.36458588, 11.94013786], [75.36458588, 11.94069386], [75.36514282, 11.94069195], [75.36514282, 11.94181061], [75.36541748, 11.94181061], [75.36541748, 11.94235992], [75.36569214, 11.94235992], [75.36569214, 11.94207954], [75.3659668, 11.94207954], [75.3659668, 11.94235992], [75.36624908, 11.94235992], [75.36624908, 11.94319439], [75.36653137, 11.94319439], [75.36653137, 11.94347191], [75.36680603, 11.94347191], [75.36680603, 11.94208431], [75.36624908, 11.94208431]]], [[[75.30069733, 11.96347237], [75.30069733, 11.9631958], [75.30124664, 11.9631958], [75.30124664, 11.96291542], [75.30152893, 11.96292019], [75.30152893, 11.96208096], [75.30180359, 11.96208382], [75.30180359, 11.96152687], [75.30208588, 11.96152973], [75.30208588, 11.96124935], [75.30236053, 11.96124935], [75.30236053, 11.95958138], [75.30179596, 11.95958138], [75.30179596, 11.96013927], [75.30152893, 11.96013927], [75.30152893, 11.96041965], [75.30097198, 11.96041775], [75.30097198, 11.96097088], [75.30069733, 11.96097088], [75.30069733, 11.96152973], [75.30042267, 11.96152973], [75.30042267, 11.96237087], [75.30014038, 11.96237087], [75.30014038, 11.96292019], [75.29985809, 11.96291542], [75.29985809, 11.96347237], [75.30069733, 11.96347237]]], [[[75.29652405, 11.96847153], [75.29652405, 11.96819401], [75.29680634, 11.96819401], [75.29680634, 11.96791553], [75.29708099, 11.9679203], [75.29708099, 11.96763992], [75.29736328, 11.96763992], [75.29736328, 11.96735954], [75.29763794, 11.9673624], [75.29763794, 11.96708393], [75.29792023, 11.96708393], [75.29792023, 11.96680641], [75.29818726, 11.96681023], [75.29818726, 11.96625042], [75.29846954, 11.96625042], [75.29846954, 11.96569061], [75.29875183, 11.96569443], [75.29875183, 11.96541786], [75.29846954, 11.96541786], [75.29846954, 11.96513844], [75.29792023, 11.96513844], [75.29792023, 11.96541786], [75.29763794, 11.96541786], [75.29763794, 11.96569443], [75.29708099, 11.96569443], [75.29708099, 11.96597195], [75.29680634, 11.96597195], [75.29680634, 11.96625042], [75.29651642, 11.96625042], [75.29651642, 11.96652985], [75.29624939, 11.96652794], [75.29624939, 11.96708393], [75.29570007, 11.96708202], [75.29570007, 11.96763992], [75.29514313, 11.96763992], [75.29514313, 11.9679203], [75.29541779, 11.96791553], [75.29541779, 11.96819401], [75.29569244, 11.96819401], [75.29569244, 11.96847153], [75.29652405, 11.96847153]]], [[[75.28541565, 11.98708344], [75.28541565, 11.98680496], [75.2859726, 11.98680973], [75.2859726, 11.98654079], [75.28679657, 11.98654079], [75.28679657, 11.98625183], [75.28736115, 11.98625183], [75.28736115, 11.98597145], [75.2876358, 11.98597336], [75.2876358, 11.98556995], [75.2876358, 11.98541737], [75.28819275, 11.98542023], [75.28819275, 11.98348045], [75.28848267, 11.98348045], [75.28848267, 11.98264122], [75.28874969, 11.98264122], [75.28874969, 11.98236084], [75.28901672, 11.98236084], [75.28901672, 11.98208141], [75.28930664, 11.98208332], [75.28930664, 11.98180485], [75.28956604, 11.98180866], [75.28956604, 11.98152924], [75.28985596, 11.98152924], [75.28985596, 11.98097134], [75.29013824, 11.98097324], [75.29013824, 11.98069477], [75.2904129, 11.98069477], [75.2904129, 11.98013878], [75.29070282, 11.98014069], [75.29070282, 11.97931194], [75.29096985, 11.97931194], [75.29096985, 11.97875118], [75.29125214, 11.97875118], [75.29125214, 11.9784708], [75.29152679, 11.97847271], [75.29152679, 11.97819519], [75.29180908, 11.97819519], [75.29180908, 11.9776392], [75.29207611, 11.97764111], [75.29207611, 11.97734928], [75.2923584, 11.97736073], [75.2923584, 11.97708321], [75.29264069, 11.97708321], [75.29264069, 11.97680664], [75.29292297, 11.97681141], [75.29292297, 11.97625065], [75.29319763, 11.97625065], [75.29319763, 11.97597027], [75.29347229, 11.97597313], [75.29347229, 11.97486019], [75.29374695, 11.97486019], [75.29374695, 11.97458458], [75.29402924, 11.97458458], [75.29402924, 11.97402859], [75.29429626, 11.97403145], [75.29429626, 11.97375011], [75.29458618, 11.97375011], [75.29458618, 11.97319031], [75.29486084, 11.97319412], [75.29486084, 11.97236156], [75.2951355, 11.97236156], [75.2951355, 11.97152805], [75.29541779, 11.97154045], [75.29541779, 11.97097015], [75.29569244, 11.97097206], [75.29569244, 11.96986008], [75.29624939, 11.96986008], [75.29624939, 11.96931076], [75.29541779, 11.96930599], [75.29541779, 11.96958447], [75.2951355, 11.96958447], [75.29514313, 11.96986008], [75.29458618, 11.96986008], [75.29458618, 11.96931076], [75.29402924, 11.96930599], [75.29402924, 11.96958447], [75.29374695, 11.9695797], [75.29374695, 11.96986008], [75.29319763, 11.96986008], [75.29319763, 11.97014046], [75.29292297, 11.97014046], [75.29292297, 11.97042274], [75.2923584, 11.97041607], [75.2923584, 11.97069359], [75.29207611, 11.97069168], [75.29207611, 11.97124958], [75.29180908, 11.97124958], [75.29180908, 11.97154045], [75.29152679, 11.97154045], [75.29152679, 11.97181129], [75.29125214, 11.97181129], [75.29125214, 11.97235966], [75.29096985, 11.97235966], [75.29096985, 11.97264099], [75.29069519, 11.97263813], [75.29069519, 11.97347164], [75.29013824, 11.97346973], [75.29013824, 11.97403145], [75.28985596, 11.97403145], [75.28985596, 11.97431087], [75.2895813, 11.9743042], [75.2895813, 11.97458458], [75.28930664, 11.97458458], [75.28930664, 11.97486019], [75.28901672, 11.97486019], [75.28901672, 11.97681141], [75.28874969, 11.97681141], [75.28874969, 11.97764111], [75.28848267, 11.97764111], [75.28848267, 11.97792053], [75.28819275, 11.97791672], [75.28819275, 11.97847271], [75.28791809, 11.9784708], [75.28791809, 11.97931194], [75.2876358, 11.97930527], [75.2876358, 11.97958279], [75.28736115, 11.97957993], [75.28736115, 11.98014069], [75.28708649, 11.98013878], [75.28708649, 11.98069477], [75.2868042, 11.98069477], [75.2868042, 11.98124886], [75.28652954, 11.98124886], [75.28652954, 11.98208332], [75.2859726, 11.98208141], [75.2859726, 11.98264122], [75.2857132, 11.98264122], [75.28569794, 11.9837513], [75.28542328, 11.9837513], [75.28542328, 11.98513889], [75.28514099, 11.98513889], [75.28514099, 11.98569489], [75.2848587, 11.98569107], [75.2848587, 11.98680973], [75.28514099, 11.98680496], [75.28514099, 11.98708344], [75.28541565, 11.98708344]]], [[[75.29792023, 12.01736164], [75.29792023, 12.0162487], [75.29763794, 12.0162487], [75.29763794, 12.01596928], [75.29792023, 12.01597118], [75.29792023, 12.01569557], [75.29736328, 12.01569557], [75.29736328, 12.01513958], [75.29708099, 12.01513958], [75.29708099, 12.01458073], [75.29652405, 12.01458263], [75.29652405, 12.01430511], [75.29624939, 12.01431179], [75.29624939, 12.01375198], [75.2959671, 12.01375198], [75.2959671, 12.01346016], [75.29569244, 12.01347446], [75.29569244, 12.01319313], [75.2951355, 12.01319313], [75.2951355, 12.01291656], [75.29402924, 12.01292038], [75.29402924, 12.01264191], [75.29125214, 12.01264191], [75.29125214, 12.01292038], [75.29013824, 12.01291656], [75.29013824, 12.01319313], [75.2895813, 12.01319313], [75.2895813, 12.01347446], [75.28930664, 12.01346016], [75.28930664, 12.01375198], [75.28874969, 12.01375198], [75.28874969, 12.01403046], [75.28848267, 12.01403046], [75.28848267, 12.01431179], [75.28791809, 12.01431179], [75.28791809, 12.01541996], [75.28901672, 12.01541996], [75.28901672, 12.01513958], [75.28930664, 12.01513958], [75.28930664, 12.0148592], [75.28986359, 12.01486206], [75.28986359, 12.01458263], [75.29096985, 12.01458263], [75.29096985, 12.01430511], [75.29125214, 12.01431179], [75.29125214, 12.01403046], [75.29152679, 12.01403046], [75.29152679, 12.01375198], [75.2923584, 12.01375198], [75.2923584, 12.01403046], [75.29264069, 12.01402664], [75.29264069, 12.01569557], [75.29319763, 12.01569557], [75.29319763, 12.01541805], [75.29430389, 12.01541805], [75.29430389, 12.01569557], [75.29486084, 12.01569557], [75.29486084, 12.01597118], [75.29514313, 12.01596928], [75.29514313, 12.0162487], [75.29569244, 12.0162487], [75.29569244, 12.01652813], [75.29597473, 12.01652813], [75.29597473, 12.01708412], [75.29624939, 12.01708126], [75.29624939, 12.01736164], [75.29792023, 12.01736164]]], [[[75.29763794, 12.02375031], [75.29763794, 12.02346992], [75.29819489, 12.02347183], [75.29819489, 12.02319431], [75.29985809, 12.02319431], [75.29985809, 12.02235985], [75.29958344, 12.02235985], [75.29958344, 12.02208424], [75.29763794, 12.02208424], [75.29763794, 12.02152824], [75.29736328, 12.02153015], [75.29736328, 12.02125168], [75.29651642, 12.02125168], [75.29651642, 12.02153015], [75.2959671, 12.02153015], [75.2959671, 12.02181053], [75.29569244, 12.02180576], [75.29569244, 12.02208424], [75.29541779, 12.02208424], [75.29541779, 12.02347183], [75.29569244, 12.02347183], [75.29569244, 12.02375031], [75.29763794, 12.02375031]]], [[[76.05208588, 10.53542042], [76.05208588, 10.53458118], [76.05180359, 10.53458309], [76.05180359, 10.5340271], [76.05152893, 10.53403187], [76.05152893, 10.53375244], [76.05069733, 10.53375244], [76.05069733, 10.53347111], [76.05042267, 10.53347111], [76.05042267, 10.53375244], [76.04930878, 10.53375244], [76.04930878, 10.53431034], [76.04958344, 10.53430462], [76.04958344, 10.53458309], [76.04985809, 10.53458309], [76.04985809, 10.53486061], [76.05014038, 10.53486061], [76.05014038, 10.53514194], [76.05069733, 10.53514194], [76.05069733, 10.53542042], [76.05208588, 10.53542042]]], [[[76.05097198, 10.53903008], [76.05097198, 10.53874111], [76.05124664, 10.53874969], [76.05124664, 10.53791809], [76.05152893, 10.53792], [76.05152893, 10.53735924], [76.05124664, 10.5373621], [76.05124664, 10.53652763], [76.05069733, 10.53652954], [76.05069733, 10.53625202], [76.04985809, 10.53625202], [76.04985809, 10.53597069], [76.04930878, 10.53597355], [76.04930878, 10.53708363], [76.04902649, 10.53707886], [76.04902649, 10.53792], [76.04957581, 10.53792], [76.04957581, 10.53903008], [76.05097198, 10.53903008]]], [[[76.25875092, 9.97041798], [76.25875092, 9.97069645], [76.26069641, 9.97069645], [76.26069641, 9.97041798], [76.26207733, 9.97042179], [76.26207733, 9.97014046], [76.26291656, 9.97014046], [76.26291656, 9.96984959], [76.26457977, 9.96986103], [76.26457977, 9.96958256], [76.26486206, 9.96958256], [76.26486206, 9.96930504], [76.26597595, 9.96930981], [76.26597595, 9.96903038], [76.26625061, 9.96903038], [76.26625061, 9.96930981], [76.26708221, 9.96930981], [76.26708221, 9.96903038], [76.26763916, 9.96903038], [76.26763916, 9.96875191], [76.26783752, 9.96875191], [76.26875305, 9.96875191], [76.26875305, 9.96847057], [76.26930237, 9.96847343], [76.26930237, 9.96819305], [76.2701416, 9.96819305], [76.2701416, 9.96791744], [76.27153015, 9.9679203], [76.27153015, 9.96764183], [76.27179718, 9.96764183], [76.27179718, 9.96736145], [76.27236176, 9.96736145], [76.27236176, 9.96680546], [76.27263641, 9.96681023], [76.27263641, 9.96652889], [76.2729187, 9.96652889], [76.2729187, 9.96625137], [76.2748642, 9.96625137], [76.27485657, 9.96542168], [76.27513885, 9.96542168], [76.27513885, 9.96458054], [76.27541351, 9.9645834], [76.27541351, 9.96347332], [76.2756958, 9.96347332], [76.2756958, 9.96319485], [76.27625275, 9.96319485], [76.27625275, 9.96236134], [76.27680206, 9.96236134], [76.27680206, 9.96208286], [76.27708435, 9.96208286], [76.27708435, 9.96125126], [76.27735901, 9.96125126], [76.27735901, 9.96069527], [76.2776413, 9.96069527], [76.2776413, 9.96041679], [76.27791595, 9.96042061], [76.27791595, 9.9598608], [76.27819824, 9.9598608], [76.27819824, 9.95930672], [76.2784729, 9.95931053], [76.2784729, 9.95875072], [76.27874756, 9.95875072], [76.27874756, 9.95818996], [76.27902985, 9.95819473], [76.27902985, 9.95791721], [76.2793045, 9.95791721], [76.2793045, 9.95736027], [76.27958679, 9.95736027], [76.27958679, 9.95708466], [76.27986145, 9.95708466], [76.27986145, 9.95680428], [76.2804184, 9.95681095], [76.2804184, 9.95625019], [76.28069305, 9.95625019], [76.28069305, 9.95458221], [76.28013611, 9.95458221], [76.28013611, 9.95430565], [76.2804184, 9.95431137], [76.2804184, 9.95374966], [76.28151703, 9.95374966], [76.28151703, 9.95318985], [76.28180695, 9.95319366], [76.28180695, 9.95263767], [76.2820816, 9.95263958], [76.2820816, 9.95208168], [76.28236389, 9.95208359], [76.28236389, 9.95180607], [76.28263855, 9.95181084], [76.28263855, 9.95125008], [76.28291321, 9.95125008], [76.28291321, 9.95068932], [76.2831955, 9.95069408], [76.2831955, 9.95014], [76.28347015, 9.95014], [76.28347015, 9.94957924], [76.28375244, 9.94958401], [76.28375244, 9.94902802], [76.2840271, 9.94902992], [76.2840271, 9.94819069], [76.28430176, 9.94819355], [76.28430939, 9.94763756], [76.28457642, 9.94764042], [76.28457642, 9.94680977], [76.2848587, 9.94680977], [76.2848587, 9.94625187], [76.28514099, 9.94625187], [76.28514099, 9.94569969], [76.28542328, 9.94567966], [76.28541565, 9.94486237], [76.28569794, 9.94486237], [76.28569794, 9.94430637], [76.28598022, 9.94431019], [76.28598022, 9.94347095], [76.28624725, 9.94347095], [76.28624725, 9.94291782], [76.28652954, 9.94293118], [76.28652954, 9.94236088], [76.2868042, 9.94236088], [76.28679657, 9.94180965], [76.28708649, 9.94180965], [76.28708649, 9.94124889], [76.28736115, 9.94124889], [76.28736115, 9.94069481], [76.2876358, 9.94069481], [76.2876358, 9.94013882], [76.28791809, 9.94014168], [76.28791809, 9.93958092], [76.28819275, 9.93958282], [76.28819275, 9.93902683], [76.28848267, 9.9390316], [76.28848267, 9.93847084], [76.28874969, 9.93847084], [76.28874969, 9.93791676], [76.28901672, 9.93792152], [76.28901672, 9.93764114], [76.28930664, 9.93764114], [76.28930664, 9.93735886], [76.2895813, 9.93736076], [76.2895813, 9.93680477], [76.28985596, 9.93680859], [76.28985596, 9.93625069], [76.29013824, 9.93625069], [76.29013824, 9.93568993], [76.2904129, 9.93569469], [76.2904129, 9.9351387], [76.29070282, 9.93514061], [76.29070282, 9.93457985], [76.29096985, 9.93458271], [76.29096985, 9.93402672], [76.29125214, 9.93403053], [76.29125214, 9.93346977], [76.29152679, 9.93347263], [76.29152679, 9.93291664], [76.29180908, 9.93292141], [76.29180908, 9.93208027], [76.29208374, 9.93208218], [76.29208374, 9.93152905], [76.29226685, 9.93152905], [76.2923584, 9.93152905], [76.2923584, 9.93097019], [76.29264069, 9.93097305], [76.29264069, 9.93013763], [76.29292297, 9.93014145], [76.29292297, 9.92957973], [76.29319763, 9.92958546], [76.29319763, 9.92875004], [76.29347229, 9.92875004], [76.29347229, 9.92819023], [76.29374695, 9.92819405], [76.29374695, 9.92763805], [76.29402924, 9.92763996], [76.29402924, 9.9256897], [76.29319763, 9.92569447], [76.29319763, 9.92541599], [76.29291534, 9.92541599], [76.29291534, 9.92569447], [76.29208374, 9.92569447], [76.29208374, 9.92597198], [76.29174805, 9.92597198], [76.29096985, 9.92597198], [76.29096985, 9.92625046], [76.29013824, 9.92625046], [76.29013824, 9.92653275], [76.28930664, 9.92653275], [76.28930664, 9.92681122], [76.28847504, 9.92680645], [76.28847504, 9.92708206], [76.28791809, 9.92708206], [76.28791809, 9.92736244], [76.28708649, 9.92735958], [76.28708649, 9.92763996], [76.28652954, 9.92763996], [76.28652954, 9.92793179], [76.28569794, 9.92791557], [76.28569794, 9.92819405], [76.28531647, 9.92819405], [76.28514099, 9.92819405], [76.28514099, 9.92847157], [76.28430176, 9.92846966], [76.28430176, 9.92875004], [76.28375244, 9.92875004], [76.28375244, 9.92903137], [76.28291321, 9.92903137], [76.28291321, 9.92930889], [76.28236389, 9.92930698], [76.28236389, 9.92958546], [76.28152466, 9.92958546], [76.28152466, 9.92986012], [76.28098297, 9.92986012], [76.28098297, 9.93014145], [76.28013611, 9.93014145], [76.28013611, 9.93042088], [76.27958679, 9.93041611], [76.27958679, 9.93069458], [76.27874756, 9.93069458], [76.27874756, 9.93097305], [76.27819824, 9.93097019], [76.27819061, 9.93125057], [76.2776413, 9.93125057], [76.2776413, 9.93153095], [76.27707672, 9.93153095], [76.27707672, 9.93181133], [76.27680206, 9.93180656], [76.27680206, 9.93208218], [76.27625275, 9.93208218], [76.27625275, 9.93236065], [76.27597046, 9.93236065], [76.27597046, 9.93264103], [76.27513885, 9.93264103], [76.27513885, 9.93292141], [76.27498627, 9.93291664], [76.27458191, 9.93291664], [76.27458191, 9.93319511], [76.27402496, 9.93319511], [76.27402496, 9.93347263], [76.27347565, 9.93347263], [76.27347565, 9.93375111], [76.27319336, 9.93374157], [76.27319336, 9.93403053], [76.27236176, 9.93403053], [76.27236176, 9.93431091], [76.27180481, 9.93430519], [76.27180481, 9.93458271], [76.27153015, 9.93458271], [76.27153015, 9.93486118], [76.27124786, 9.93486118], [76.27124786, 9.93514061], [76.27097321, 9.93514061], [76.27097321, 9.93542099], [76.27069092, 9.93541718], [76.27069092, 9.93569469], [76.27041626, 9.93568993], [76.27041626, 9.93625069], [76.2701416, 9.93625069], [76.2701416, 9.93653107], [76.26985931, 9.93653107], [76.26985931, 9.93680859], [76.26958466, 9.93680477], [76.26958466, 9.93708324], [76.26930237, 9.93708324], [76.26930237, 9.93736076], [76.26902771, 9.93735886], [76.26902771, 9.93792152], [76.26875305, 9.93791676], [76.26875305, 9.93819523], [76.26847076, 9.93819523], [76.26847076, 9.93847084], [76.26819611, 9.93847084], [76.26819611, 9.93875122], [76.26790619, 9.93875122], [76.26790619, 9.9390316], [76.26763916, 9.9390316], [76.26763916, 9.93931198], [76.26735687, 9.93931198], [76.26735687, 9.93987274], [76.26708221, 9.9398613], [76.26708221, 9.94097328], [76.26680756, 9.94097137], [76.26680756, 9.94293118], [76.26708221, 9.94291782], [76.26708221, 9.94374943], [76.26735687, 9.94374943], [76.26735687, 9.94431019], [76.26708221, 9.94430637], [76.26708221, 9.94458389], [76.26680756, 9.94458389], [76.26680756, 9.94486237], [76.2665329, 9.94485855], [76.2665329, 9.94542027], [76.26625061, 9.94541454], [76.26625061, 9.94597244], [76.26597595, 9.94597244], [76.26597595, 9.94680977], [76.26569366, 9.94680595], [76.26569366, 9.94819355], [76.26597595, 9.94819069], [76.26597595, 9.94902992], [76.26625061, 9.94902802], [76.26625061, 9.94919014], [76.26625061, 9.95014], [76.26652527, 9.95014], [76.26652527, 9.95208359], [76.26625061, 9.95208359], [76.26625061, 9.95347214], [76.26597595, 9.95347023], [76.26597595, 9.95514107], [76.26569366, 9.95513821], [76.26569366, 9.9556942], [76.26597595, 9.9556942], [76.26597595, 9.95736027], [76.26568604, 9.95736027], [76.26568604, 9.95764065], [76.26597595, 9.95763779], [76.26597595, 9.95791721], [76.26569366, 9.95791721], [76.26569366, 9.95847321], [76.26541901, 9.95847321], [76.26541901, 9.9598608], [76.26513672, 9.9598608], [76.26513672, 9.96153069], [76.26486206, 9.96152878], [76.26486206, 9.96208286], [76.26457977, 9.96208286], [76.26457977, 9.96236134], [76.26431274, 9.96236134], [76.26431274, 9.96291924], [76.26374817, 9.96291733], [76.26374817, 9.96347332], [76.26346588, 9.96347141], [76.26346588, 9.96375084], [76.26291656, 9.96375084], [76.26291656, 9.9643116], [76.26235962, 9.96430492], [76.26235962, 9.9645834], [76.26152802, 9.9645834], [76.26152802, 9.96486092], [76.26125336, 9.96486092], [76.26125336, 9.9651413], [76.26097107, 9.9651413], [76.26097107, 9.96542168], [76.26041412, 9.96541691], [76.26041412, 9.96569538], [76.26013947, 9.96569538], [76.26013947, 9.96597099], [76.25958252, 9.96597099], [76.25958252, 9.96625137], [76.25930786, 9.96625137], [76.25930786, 9.96652889], [76.25902557, 9.96652699], [76.25902557, 9.96708298], [76.25875092, 9.96708298], [76.25875092, 9.96736145], [76.25846863, 9.96736145], [76.25846863, 9.96764183], [76.25818634, 9.96764183], [76.25818634, 9.9679203], [76.25791931, 9.96791744], [76.25791931, 9.96819305], [76.25763702, 9.96819115], [76.25763702, 9.96903038], [76.25791931, 9.96902657], [76.25791931, 9.96958256], [76.25818634, 9.96958065], [76.25818634, 9.97042179], [76.25875092, 9.97041798]]], [[[76.24430847, 9.98097229], [76.24430847, 9.97847176], [76.24402618, 9.97847176], [76.24402618, 9.97819424], [76.24319458, 9.97819424], [76.24319458, 9.97847176], [76.24291992, 9.97847176], [76.24291992, 9.97958374], [76.24318695, 9.97958183], [76.24318695, 9.98042107], [76.24346924, 9.9804163], [76.24346924, 9.98069382], [76.24375153, 9.98069382], [76.24375153, 9.98097229], [76.24430847, 9.98097229]]], [[[76.27153015, 9.97264004], [76.27153015, 9.9729147], [76.27236176, 9.9729147], [76.27236176, 9.97208405], [76.27263641, 9.97208405], [76.27263641, 9.97180557], [76.27236176, 9.97181034], [76.27236176, 9.97152996], [76.27179718, 9.97152996], [76.27179718, 9.97124863], [76.27097321, 9.97124863], [76.27097321, 9.9709692], [76.26957703, 9.9709692], [76.26957703, 9.97124863], [76.26930237, 9.97124863], [76.26930237, 9.97181034], [76.26902771, 9.97180557], [76.26902771, 9.97208405], [76.26875305, 9.97208118], [76.26875305, 9.97264194], [76.2701416, 9.97264194], [76.2701416, 9.97236156], [76.27097321, 9.97236156], [76.27097321, 9.97264194], [76.27153015, 9.97264004]]], [[[76.26735687, 10.00263977], [76.26735687, 10.00292015], [76.26819611, 10.00292015], [76.26819611, 10.00263977], [76.26847076, 10.00263977], [76.26847076, 10.00208187], [76.26875305, 10.00208378], [76.26875305, 10.00152779], [76.26902771, 10.00152969], [76.26902771, 10.00125027], [76.26930237, 10.00125027], [76.26930237, 10.00097179], [76.26958466, 10.00097179], [76.26957703, 10.00041962], [76.26985931, 10.00041962], [76.26985931, 9.99994087], [76.26985931, 9.99874878], [76.26957703, 9.99875164], [76.26957703, 9.99792004], [76.26930237, 9.99792004], [76.26930237, 9.9970789], [76.26902771, 9.99708271], [76.26902771, 9.99680519], [76.26819611, 9.99680519], [76.26819611, 9.99708271], [76.26791382, 9.99708271], [76.26791382, 9.99986172], [76.26763916, 9.99985886], [76.26763916, 10.00015068], [76.26735687, 10.00015068], [76.2673645, 10.00125027], [76.26708221, 10.00125027], [76.26708221, 10.00152969], [76.26680756, 10.00152969], [76.26680756, 10.00263977], [76.26735687, 10.00263977]]], [[[76.24124908, 10.01403141], [76.24124908, 10.01431084], [76.24180603, 10.01431084], [76.24180603, 10.01403141], [76.24208069, 10.01403141], [76.24208069, 10.01375103], [76.24263763, 10.01375103], [76.24263763, 10.0134697], [76.24319458, 10.01347256], [76.24319458, 10.01319504], [76.24375153, 10.01319504], [76.24375153, 10.01235962], [76.24402618, 10.01235962], [76.24402618, 10.0120821], [76.24430847, 10.01209164], [76.24430847, 10.01181126], [76.24458313, 10.01181126], [76.24458313, 10.01068974], [76.24485779, 10.01069355], [76.24485779, 10.01041603], [76.24514008, 10.0104208], [76.24514008, 10.01014137], [76.24569702, 10.01014137], [76.24569702, 10.00986004], [76.24624634, 10.00986004], [76.24624634, 10.00958538], [76.24680328, 10.00958538], [76.24680328, 10.00930595], [76.24791718, 10.00931072], [76.24791718, 10.0090189], [76.24819183, 10.00902843], [76.24819183, 10.00874996], [76.24874878, 10.00874996], [76.24874878, 10.00846958], [76.24903107, 10.00847244], [76.24903107, 10.00819397], [76.24986267, 10.00819397], [76.24986267, 10.00791645], [76.25068665, 10.00792122], [76.25068665, 10.00736046], [76.25096893, 10.00736237], [76.25096893, 10.00708199], [76.25152588, 10.00708199], [76.25152588, 10.00680637], [76.25180817, 10.00681114], [76.25180817, 10.00653267], [76.25235748, 10.00653267], [76.25235748, 10.00625038], [76.25263977, 10.00625038], [76.25263977, 10.00597191], [76.25319672, 10.00597191], [76.25319672, 10.00485992], [76.25347137, 10.00485992], [76.25347137, 10.00263786], [76.25374603, 10.00263977], [76.25374603, 10.00125027], [76.25402832, 10.00125027], [76.25402832, 10.00069427], [76.25430298, 10.00069427], [76.25430298, 10.00041771], [76.2545929, 10.00041962], [76.2545929, 9.99985886], [76.25458527, 9.9995842], [76.25485992, 9.9995842], [76.25485992, 9.99902821], [76.25514221, 9.99903202], [76.25514221, 9.99847126], [76.25541687, 9.99847126], [76.25541687, 9.99791527], [76.25567627, 9.99792004], [76.25567627, 9.99735928], [76.25597382, 9.99736214], [76.25597382, 9.99652672], [76.25624847, 9.99652958], [76.25624847, 9.99597073], [76.25653076, 9.99597359], [76.25653076, 9.99541664], [76.25681305, 9.99542046], [76.25681305, 9.99458122], [76.25708008, 9.99458313], [76.25708008, 9.99430466], [76.25681305, 9.99431038], [76.25681305, 9.99402046], [76.25708008, 9.99402714], [76.25708008, 9.99374866], [76.25736237, 9.99375057], [76.25736237, 9.99236107], [76.25763702, 9.99236107], [76.25763702, 9.9920826], [76.25791931, 9.9920826], [76.25791931, 9.99125099], [76.25818634, 9.99125099], [76.25818634, 9.99098015], [76.25846863, 9.99098015], [76.25846863, 9.99014091], [76.25875092, 9.99014091], [76.25875092, 9.98958111], [76.25846863, 9.98958302], [76.25846863, 9.98708344], [76.25875092, 9.98708344], [76.25875092, 9.98541737], [76.2590332, 9.98542118], [76.2590332, 9.98403072], [76.25930786, 9.98403072], [76.25930786, 9.98318958], [76.25958252, 9.98319435], [76.25958252, 9.98263836], [76.25985718, 9.98264122], [76.25985718, 9.98236275], [76.26013947, 9.98236275], [76.26013947, 9.98153114], [76.25985718, 9.98153114], [76.25985718, 9.98097038], [76.25958252, 9.98097229], [76.25958252, 9.98069382], [76.25902557, 9.98069382], [76.25902557, 9.9804163], [76.25846863, 9.98042107], [76.25846863, 9.98013973], [76.25818634, 9.98013973], [76.25818634, 9.97986031], [76.25763702, 9.97986221], [76.25763702, 9.97958374], [76.25708008, 9.97958374], [76.25708008, 9.97930622], [76.25653076, 9.97931099], [76.25653076, 9.97904015], [76.25596619, 9.97904015], [76.25596619, 9.97875023], [76.25514221, 9.97875023], [76.25514221, 9.97847176], [76.25458527, 9.97847176], [76.25458527, 9.97819424], [76.25375366, 9.97819424], [76.25375366, 9.97764015], [76.25319672, 9.97764015], [76.25319672, 9.97736168], [76.25263977, 9.97736168], [76.25263977, 9.97707939], [76.25208282, 9.97708416], [76.25208282, 9.97680569], [76.25152588, 9.97681141], [76.25152588, 9.97653008], [76.25068665, 9.97653008], [76.25068665, 9.97624969], [76.24958038, 9.97624969], [76.24958038, 9.97598076], [76.24819183, 9.97598076], [76.24819183, 9.97624969], [76.24736023, 9.97624969], [76.24736023, 9.97653008], [76.24652863, 9.97652817], [76.24652863, 9.97713184], [76.24652863, 9.9843111], [76.24624634, 9.98430443], [76.24624634, 9.98449993], [76.24624634, 9.98708344], [76.24597168, 9.98708344], [76.24597168, 9.98819542], [76.24569702, 9.9881897], [76.24569702, 9.98930931], [76.2454071, 9.98930931], [76.2454071, 9.99041939], [76.24514008, 9.99041939], [76.24514008, 9.99125099], [76.24485779, 9.99125099], [76.24485779, 9.99180984], [76.24458313, 9.99180984], [76.24458313, 9.99264145], [76.24430847, 9.99263859], [76.24430847, 9.99357128], [76.24430847, 9.99458313], [76.24402618, 9.99458313], [76.24402618, 9.99569321], [76.24373627, 9.9956913], [76.24373627, 9.99680996], [76.24346924, 9.99680996], [76.24346924, 9.99763966], [76.24319458, 9.99763966], [76.24319458, 9.99847126], [76.24346924, 9.99847126], [76.24346924, 9.99985886], [76.24346924, 10.00015068], [76.24373627, 10.00015068], [76.24373627, 10.00041962], [76.24402618, 10.00041771], [76.24402618, 10.00097179], [76.24373627, 10.00097179], [76.24373627, 10.00152969], [76.24346924, 10.00152779], [76.24346924, 10.00374985], [76.24373627, 10.00374985], [76.24373627, 10.00403023], [76.24346924, 10.00403023], [76.24346924, 10.00431061], [76.24319458, 10.00430584], [76.24319458, 10.00458431], [76.24291992, 10.00458431], [76.24291992, 10.00485992], [76.24263763, 10.00485992], [76.24263763, 10.0051403], [76.24236298, 10.0051403], [76.24236298, 10.00542068], [76.24208069, 10.00541592], [76.24208069, 10.00597191], [76.24180603, 10.00597191], [76.24180603, 10.00625038], [76.24153137, 10.00625038], [76.24153137, 10.00681114], [76.24124908, 10.00681114], [76.24124908, 10.00792122], [76.2409668, 10.00792122], [76.2409668, 10.00986004], [76.24067688, 10.00986004], [76.24069214, 10.01125145], [76.24041748, 10.01125145], [76.24041748, 10.01181126], [76.24014282, 10.01181126], [76.24014282, 10.01292133], [76.23986053, 10.01292133], [76.23986053, 10.01403141], [76.24014282, 10.01403141], [76.24014282, 10.01431084], [76.24067688, 10.01431084], [76.24067688, 10.01403141], [76.24124908, 10.01403141]]], [[[76.30764008, 9.92125034], [76.30764008, 9.92152977], [76.30847168, 9.92152977], [76.30847168, 9.92125034], [76.30874634, 9.92125034], [76.30874634, 9.92069435], [76.30902863, 9.92069435], [76.30902863, 9.92041779], [76.30930328, 9.92041969], [76.30930328, 9.91986179], [76.3095932, 9.91986179], [76.3095932, 9.91930962], [76.30986023, 9.91930962], [76.30986023, 9.91874027], [76.31014252, 9.91874981], [76.31014252, 9.91763973], [76.31041718, 9.91763973], [76.31041718, 9.91708088], [76.31069183, 9.91708374], [76.31069183, 9.91680527], [76.31096649, 9.91681004], [76.31096649, 9.91652966], [76.31124878, 9.91652966], [76.31124878, 9.91624928], [76.31153107, 9.91624928], [76.31153107, 9.91597366], [76.31180573, 9.9159708], [76.31180573, 9.91569328], [76.31236267, 9.91569996], [76.31236267, 9.91541958], [76.31263733, 9.91541958], [76.31263733, 9.91264057], [76.31236267, 9.91264057], [76.31236267, 9.91208076], [76.31208038, 9.91208267], [76.31208038, 9.91152668], [76.31181335, 9.9115324], [76.31181335, 9.91097069], [76.31153107, 9.9109726], [76.31153107, 9.9104166], [76.31124878, 9.91041946], [76.31124878, 9.90986061], [76.31097412, 9.90986061], [76.31097412, 9.90902901], [76.31124878, 9.90903091], [76.31124878, 9.90818977], [76.31153107, 9.90819454], [76.31153107, 9.90791702], [76.31181335, 9.90792084], [76.31181335, 9.90764141], [76.31208038, 9.90764141], [76.31208038, 9.90736103], [76.31236267, 9.90736103], [76.31236267, 9.90708256], [76.31263733, 9.90708256], [76.31263733, 9.90680695], [76.31291962, 9.90680695], [76.31291962, 9.90652657], [76.31318665, 9.90653133], [76.31318665, 9.90625095], [76.31375122, 9.90625095], [76.31375122, 9.90596962], [76.31402588, 9.90597343], [76.31402588, 9.90569496], [76.31430817, 9.90569496], [76.31430817, 9.90541744], [76.31458282, 9.90542126], [76.31458282, 9.90514088], [76.31513977, 9.90514088], [76.31513977, 9.90486145], [76.31541443, 9.90486145], [76.31541443, 9.90458202], [76.31569672, 9.90458202], [76.31569672, 9.90430355], [76.31595612, 9.90431118], [76.31595612, 9.9040308], [76.31624603, 9.9040308], [76.31624603, 9.90347004], [76.31652832, 9.9034729], [76.31652832, 9.90319443], [76.31680298, 9.90319443], [76.31680298, 9.90291595], [76.3170929, 9.90292072], [76.3170929, 9.90207958], [76.31680298, 9.9020853], [76.31680298, 9.90069389], [76.31652832, 9.90070057], [76.31652832, 9.90014267], [76.31624603, 9.90014267], [76.31624603, 9.89958191], [76.31597137, 9.89958191], [76.31597137, 9.89902782], [76.31569672, 9.89902973], [76.31569672, 9.89818859], [76.31541443, 9.89819431], [76.31541443, 9.89652824], [76.31569672, 9.89653015], [76.31569672, 9.89513969], [76.31595612, 9.89513969], [76.31595612, 9.89457035], [76.31625366, 9.8945837], [76.31625366, 9.89402771], [76.31652832, 9.89402962], [76.31652832, 9.89346886], [76.31680298, 9.89347172], [76.31680298, 9.89264011], [76.3170929, 9.89264202], [76.3170929, 9.89153194], [76.31735992, 9.89153194], [76.31735992, 9.89041996], [76.31764221, 9.89041996], [76.31764221, 9.8868103], [76.31735992, 9.8868103], [76.31735992, 9.88653183], [76.31595612, 9.88653183], [76.31595612, 9.8868103], [76.31458282, 9.88680458], [76.31458282, 9.88708305], [76.31346893, 9.88708305], [76.31346893, 9.88736057], [76.31227875, 9.88736057], [76.31041718, 9.88736057], [76.31041718, 9.88764191], [76.31014252, 9.88763905], [76.31014252, 9.88819313], [76.30986023, 9.88819313], [76.30986023, 9.88847446], [76.3095932, 9.88847065], [76.3095932, 9.88876057], [76.30930328, 9.88874912], [76.30930328, 9.88986206], [76.30902863, 9.88986206], [76.30902863, 9.89069557], [76.30874634, 9.8906889], [76.30874634, 9.89153194], [76.30847168, 9.89152813], [76.30847168, 9.89208412], [76.30819702, 9.89208126], [76.30819702, 9.89291954], [76.3079071, 9.89291954], [76.30791473, 9.89375019], [76.30764008, 9.89375019], [76.30764008, 9.89482117], [76.30764008, 9.89542007], [76.30735779, 9.89541626], [76.30735779, 9.89708424], [76.30708313, 9.89708424], [76.30708313, 9.89764023], [76.30680847, 9.89764023], [76.30680847, 9.89819431], [76.30652618, 9.89818859], [76.30652618, 9.89902973], [76.30625153, 9.89902782], [76.30625153, 9.89958191], [76.30596924, 9.89958191], [76.30596924, 9.90014267], [76.30569458, 9.9001379], [76.30569458, 9.90097237], [76.30541992, 9.90097046], [76.30541992, 9.90125275], [76.30513763, 9.90125275], [76.30513763, 9.90181065], [76.30486298, 9.90180588], [76.30486298, 9.90235996], [76.30458069, 9.90235996], [76.30458069, 9.90292072], [76.30430603, 9.90292072], [76.30430603, 9.9040308], [76.30458069, 9.9040308], [76.30458069, 9.90514088], [76.30486298, 9.90514088], [76.30486298, 9.90625095], [76.30458069, 9.90625095], [76.30458069, 9.90680695], [76.30430603, 9.90680027], [76.30430603, 9.90875053], [76.30458069, 9.90874863], [76.30458069, 9.90986061], [76.30486298, 9.90986061], [76.30486298, 9.9109726], [76.30513763, 9.9109726], [76.30513763, 9.91208267], [76.30541992, 9.91208267], [76.30541992, 9.91347122], [76.30569458, 9.91347122], [76.30569458, 9.91458321], [76.30541992, 9.9145813], [76.30541992, 9.9151392], [76.30513763, 9.9151392], [76.30513763, 9.9159708], [76.30486298, 9.91596889], [76.30486298, 9.91792011], [76.30458069, 9.91791534], [76.30458069, 9.91958427], [76.30486298, 9.91958141], [76.30486298, 9.91986179], [76.30513763, 9.91986179], [76.30513763, 9.92014027], [76.30541992, 9.92014027], [76.30541992, 9.92041969], [76.30569458, 9.92041779], [76.30569458, 9.92069435], [76.30596924, 9.92069435], [76.30596924, 9.92097187], [76.30680847, 9.92097187], [76.30680847, 9.92125034], [76.30764008, 9.92125034]]], [[[76.36763763, 9.58331108], [76.36763763, 9.58319473], [76.36735535, 9.58322716], [76.36736298, 9.58292103], [76.36707306, 9.58292103], [76.36707306, 9.58264065], [76.36680603, 9.58264065], [76.36680603, 9.58207989], [76.36653137, 9.58208466], [76.36653137, 9.58180428], [76.36624908, 9.58181953], [76.36624908, 9.58125114], [76.3659668, 9.58125114], [76.3659668, 9.58069038], [76.36569214, 9.5806942], [76.36569214, 9.57958221], [76.36541748, 9.57958221], [76.36541748, 9.57902813], [76.36514282, 9.57903099], [76.36514282, 9.57875919], [76.36541748, 9.57875919], [76.36541748, 9.57847023], [76.36486053, 9.57847214], [76.36486053, 9.57791615], [76.36429596, 9.57792091], [76.36429596, 9.57763958], [76.36374664, 9.57763958], [76.36374664, 9.57792091], [76.36319733, 9.57792091], [76.36319733, 9.57763958], [76.36235809, 9.57763958], [76.36235809, 9.57736015], [76.36180878, 9.57736015], [76.36180878, 9.57708359], [76.36125183, 9.57708359], [76.36125183, 9.57680416], [76.36068726, 9.57681084], [76.36068726, 9.57653046], [76.36013794, 9.57653046], [76.36013794, 9.5759697], [76.35986328, 9.5759716], [76.35986328, 9.57569408], [76.35958099, 9.57569408], [76.35958099, 9.57486153], [76.35930634, 9.57486153], [76.35930634, 9.57458401], [76.35958099, 9.57458401], [76.35958099, 9.57430553], [76.35930634, 9.57431126], [76.35930634, 9.56931019], [76.35958099, 9.56931019], [76.35958099, 9.5676403], [76.35930634, 9.5676403], [76.35930634, 9.56736183], [76.35958099, 9.56736183], [76.35958099, 9.56597137], [76.35930634, 9.56597137], [76.35930634, 9.56513882], [76.35901642, 9.56514168], [76.35901642, 9.5648613], [76.35847473, 9.5648613], [76.35847473, 9.56458282], [76.35819244, 9.56458282], [76.35819244, 9.56402683], [76.35764313, 9.5640316], [76.35764313, 9.56375122], [76.35736084, 9.56375122], [76.35736084, 9.56152916], [76.35764313, 9.56153202], [76.35764313, 9.56125069], [76.35736084, 9.56125069], [76.35736084, 9.56097126], [76.3576355, 9.56097317], [76.3576355, 9.56069469], [76.35736084, 9.56069469], [76.35736084, 9.56041718], [76.35764313, 9.56042194], [76.35764313, 9.55931187], [76.35791779, 9.55931187], [76.35791779, 9.55903053], [76.35764313, 9.55903053], [76.35764313, 9.55792141], [76.35736084, 9.55792141], [76.35736084, 9.55486012], [76.35708618, 9.55486012], [76.35708618, 9.55430698], [76.35679626, 9.55430889], [76.35679626, 9.55264091], [76.35652924, 9.55264091], [76.35652924, 9.55151939], [76.35624695, 9.55152798], [76.35624695, 9.55125046], [76.35597229, 9.55125046], [76.35597229, 9.55041599], [76.35569763, 9.55042076], [76.35569763, 9.54792118], [76.35542297, 9.54792118], [76.35542297, 9.54736042], [76.35514069, 9.54736233], [76.35514069, 9.54652786], [76.3548584, 9.54653263], [76.3548584, 9.54265118], [76.35457611, 9.54265118], [76.35457611, 9.54181004], [76.35430908, 9.54181004], [76.35430908, 9.54124928], [76.35402679, 9.54124928], [76.35402679, 9.54097366], [76.35375214, 9.5409708], [76.35375214, 9.54041767], [76.35346985, 9.54041958], [76.35346985, 9.53986073], [76.35319519, 9.53986073], [76.35319519, 9.53958321], [76.35346985, 9.53958321], [76.35346985, 9.53930473], [76.35320282, 9.53931046], [76.35320282, 9.53792191], [76.35346985, 9.53792191], [76.35346985, 9.53764153], [76.35320282, 9.53764153], [76.35320282, 9.53736115], [76.35346985, 9.53736115], [76.35346985, 9.53680515], [76.35320282, 9.53681183], [76.35320282, 9.53652], [76.35346985, 9.53652668], [76.35346985, 9.5354166], [76.35320282, 9.53541946], [76.35320282, 9.53486061], [76.35346985, 9.53486061], [76.35346985, 9.53319454], [76.35402679, 9.53319454], [76.35402679, 9.53263855], [76.35430908, 9.53264141], [76.35430908, 9.53097057], [76.35458374, 9.53097343], [76.35458374, 9.53069496], [76.3548584, 9.53069496], [76.3548584, 9.52986145], [76.35514069, 9.52986145], [76.35514069, 9.52930546], [76.35542297, 9.52930927], [76.35542297, 9.52902889], [76.35569763, 9.52902889], [76.35569763, 9.52875137], [76.35597229, 9.52875137], [76.35597229, 9.5284729], [76.35624695, 9.5284729], [76.35624695, 9.52791691], [76.35652924, 9.52792072], [76.35652924, 9.52707958], [76.35680389, 9.52708244], [76.35680389, 9.52597237], [76.35708618, 9.52597237], [76.35708618, 9.52541637], [76.35736084, 9.52542114], [76.35736084, 9.5251379], [76.3576355, 9.5251379], [76.3576355, 9.52458191], [76.35819244, 9.52458191], [76.35819244, 9.52486038], [76.35902405, 9.52486038], [76.35902405, 9.52458191], [76.36013794, 9.52458191], [76.36013794, 9.52402782], [76.36042023, 9.52403069], [76.36042023, 9.52375031], [76.36319733, 9.52375031], [76.36319733, 9.52347183], [76.36374664, 9.52347183], [76.36374664, 9.52319431], [76.36430359, 9.52319431], [76.36430359, 9.52291584], [76.36541748, 9.52292061], [76.36541748, 9.52264023], [76.36653137, 9.52264023], [76.36653137, 9.52235985], [76.36736298, 9.52235985], [76.36736298, 9.52208424], [76.36846924, 9.52208424], [76.36846924, 9.52180576], [76.37124634, 9.52180576], [76.37124634, 9.52208424], [76.37213135, 9.52208424], [76.37264252, 9.52208424], [76.37264252, 9.52235985], [76.37403107, 9.52235985], [76.37403107, 9.52264023], [76.37458038, 9.52264023], [76.37458038, 9.52235985], [76.37486267, 9.52235985], [76.37486267, 9.52208424], [76.37513733, 9.52208424], [76.37513733, 9.52180576], [76.37541962, 9.52181053], [76.37541962, 9.52153969], [76.37568665, 9.52153969], [76.37568665, 9.52124977], [76.37625885, 9.52124977], [76.37625885, 9.52097034], [76.37652588, 9.52097225], [76.37652588, 9.52069378], [76.37680817, 9.52069378], [76.37680817, 9.52041626], [76.37708282, 9.52042007], [76.37708282, 9.52013969], [76.37735748, 9.52013969], [76.37735748, 9.51986027], [76.37763977, 9.51986217], [76.37763977, 9.5195837], [76.37819672, 9.5195837], [76.37819672, 9.51930618], [76.37847137, 9.51931095], [76.37847137, 9.51902962], [76.37874603, 9.51902962], [76.37874603, 9.51791954], [76.37847137, 9.51791954], [76.37847137, 9.51707935], [76.38097382, 9.51708412], [76.38097382, 9.51680565], [76.38124847, 9.51681042], [76.38124847, 9.51653004], [76.38181305, 9.51653004], [76.38181305, 9.51624966], [76.38207245, 9.51624966], [76.38207245, 9.51596928], [76.38263702, 9.51597214], [76.38263702, 9.51430607], [76.38291931, 9.51431179], [76.38291931, 9.51153183], [76.38263702, 9.51153183], [76.38263702, 9.50847054], [76.38236237, 9.5084734], [76.38236237, 9.50652695], [76.38319397, 9.50652695], [76.38319397, 9.50708294], [76.38346863, 9.50708103], [76.38346863, 9.50764084], [76.38375092, 9.50764084], [76.38375092, 9.51041985], [76.3840332, 9.51041985], [76.3840332, 9.51431179], [76.38375092, 9.51431179], [76.38375092, 9.51653004], [76.38346863, 9.51652813], [76.38346863, 9.51986217], [76.38319397, 9.51986217], [76.38319397, 9.52097225], [76.38346863, 9.52097034], [76.38346863, 9.52124977], [76.38318634, 9.52124977], [76.38318634, 9.52153969], [76.38346863, 9.52152824], [76.38346863, 9.52347183], [76.38319397, 9.52347183], [76.38319397, 9.52597237], [76.38846588, 9.52597046], [76.38846588, 9.52625275], [76.39624786, 9.52625275], [76.39624786, 9.52653122], [76.40402985, 9.52653122], [76.40402985, 9.52681065], [76.41402435, 9.52680683], [76.41402435, 9.52708244], [76.42375183, 9.52708244], [76.42375183, 9.52735996], [76.43402863, 9.52735996], [76.43402863, 9.52680683], [76.43430328, 9.52681065], [76.43430328, 9.52653122], [76.43402863, 9.52653122], [76.43402863, 9.52625275], [76.43430328, 9.52625275], [76.43430328, 9.52486038], [76.43458557, 9.52486038], [76.43458557, 9.5243063], [76.43514252, 9.52431107], [76.43514252, 9.52403069], [76.43541718, 9.52403069], [76.43541718, 9.52375031], [76.43569183, 9.52375031], [76.43569183, 9.52403069], [76.43596649, 9.52403069], [76.43596649, 9.52346992], [76.43624878, 9.52347183], [76.43624878, 9.52319431], [76.43597412, 9.52319431], [76.43597412, 9.52291584], [76.43624878, 9.52292061], [76.43624878, 9.52264023], [76.43596649, 9.52264023], [76.43596649, 9.52235985], [76.43624878, 9.52235985], [76.43624878, 9.52097225], [76.43541718, 9.52097225], [76.43541718, 9.52069378], [76.43514252, 9.52069378], [76.43514252, 9.52041626], [76.4345932, 9.52042007], [76.4345932, 9.51931095], [76.43486023, 9.51931095], [76.43486023, 9.51902962], [76.43514252, 9.51902962], [76.43514252, 9.51848125], [76.43596649, 9.51848125], [76.43596649, 9.51902962], [76.43624878, 9.51902962], [76.43624878, 9.51931095], [76.4365387, 9.51931095], [76.4365387, 9.52013969], [76.43708038, 9.52013779], [76.43708038, 9.52069378], [76.43763733, 9.52069378], [76.43763733, 9.52041626], [76.43791962, 9.52042007], [76.43791962, 9.51986027], [76.43819427, 9.51986217], [76.43819427, 9.5195837], [76.43846893, 9.5195837], [76.43846893, 9.51875019], [76.43875122, 9.51875019], [76.43875122, 9.51791573], [76.43902588, 9.51791954], [76.43902588, 9.51653004], [76.43875122, 9.51653004], [76.43875122, 9.51624966], [76.43846893, 9.51624966], [76.43846893, 9.51541996], [76.43818665, 9.51541996], [76.43818665, 9.51431179], [76.43846893, 9.51431179], [76.43846893, 9.51403046], [76.43875122, 9.51403046], [76.43875122, 9.51375198], [76.43902588, 9.51375198], [76.43902588, 9.51347065], [76.43958282, 9.51347446], [76.43958282, 9.51319313], [76.43985748, 9.51319313], [76.43985748, 9.51291847], [76.4404068, 9.51292038], [76.4404068, 9.51235008], [76.44069672, 9.51236057], [76.44069672, 9.51208305], [76.44097137, 9.51208305], [76.44097137, 9.51152706], [76.44152832, 9.51153183], [76.44152832, 9.51125145], [76.44235229, 9.51125145], [76.44235229, 9.51153183], [76.44264221, 9.51152706], [76.44264221, 9.51236057], [76.44291687, 9.51235008], [76.44291687, 9.51375198], [76.44264221, 9.51375198], [76.44264221, 9.51403046], [76.44291687, 9.51402664], [76.44291687, 9.51735973], [76.44264221, 9.51735973], [76.44264221, 9.52403069], [76.44235229, 9.52403069], [76.44235229, 9.5251379], [76.44264221, 9.5251379], [76.44264221, 9.52542114], [76.44235229, 9.52542114], [76.44235229, 9.52625275], [76.44264221, 9.52624989], [76.44264221, 9.52708244], [76.44291687, 9.52707958], [76.44291687, 9.5276413], [76.4484787, 9.5276413], [76.4484787, 9.52792072], [76.45319366, 9.52791691], [76.45319366, 9.52819538], [76.45930481, 9.52819538], [76.45930481, 9.52791691], [76.4595871, 9.52791691], [76.4595871, 9.52819538], [76.46152496, 9.52819538], [76.46152496, 9.52791691], [76.46263885, 9.52791691], [76.46263885, 9.52819538], [76.46389771, 9.52819538], [76.46430206, 9.52819538], [76.46430206, 9.5284729], [76.46679688, 9.52847004], [76.46679688, 9.52875137], [76.46708679, 9.52875137], [76.46708679, 9.52902889], [76.46763611, 9.52902889], [76.46763611, 9.52875137], [76.46847534, 9.52875137], [76.46847534, 9.5284729], [76.47041321, 9.5284729], [76.47041321, 9.52875137], [76.4715271, 9.52875137], [76.4715271, 9.5284729], [76.47264099, 9.5284729], [76.47264099, 9.52875137], [76.47486115, 9.52875137], [76.47486115, 9.5284729], [76.47569275, 9.5284729], [76.47569275, 9.52875137], [76.47902679, 9.52875137], [76.47902679, 9.52819538], [76.47930908, 9.52819538], [76.47930908, 9.52735996], [76.47902679, 9.52735996], [76.47902679, 9.52708244], [76.47930908, 9.52708244], [76.47930908, 9.52680683], [76.47902679, 9.52681065], [76.47902679, 9.52458], [76.47930908, 9.52458191], [76.47930908, 9.52375031], [76.47958374, 9.52375031], [76.47957611, 9.52318954], [76.47930908, 9.52319431], [76.47930908, 9.51847172], [76.47957611, 9.51848125], [76.47957611, 9.51791954], [76.47930908, 9.51791954], [76.47930908, 9.51653004], [76.47957611, 9.51653004], [76.47957611, 9.51403046], [76.4798584, 9.51403046], [76.4798584, 9.5118103], [76.48014069, 9.5118103], [76.48014069, 9.51125145], [76.48042297, 9.51125145], [76.48042297, 9.5118103], [76.48069763, 9.51180458], [76.48069763, 9.51347446], [76.48097229, 9.51347446], [76.48097229, 9.51708412], [76.48069763, 9.51707935], [76.48069763, 9.51764202], [76.48097229, 9.51764202], [76.48097229, 9.51902962], [76.48069763, 9.51902962], [76.48069763, 9.52292061], [76.48042297, 9.52292061], [76.48042297, 9.52431107], [76.48069763, 9.5243063], [76.48069763, 9.52569389], [76.48041534, 9.52569389], [76.48041534, 9.52735996], [76.48069763, 9.52735996], [76.48069763, 9.52902889], [76.48264313, 9.52902889], [76.48264313, 9.52930927], [76.48319244, 9.52930927], [76.48319244, 9.52902889], [76.48486328, 9.52902889], [76.48486328, 9.52930927], [76.48542023, 9.52930927], [76.48542023, 9.52902889], [76.48596954, 9.52902889], [76.48596954, 9.52930927], [76.48902893, 9.52930546], [76.48902893, 9.52958298], [76.48930359, 9.52958298], [76.48930359, 9.52930546], [76.48958588, 9.52930546], [76.48958588, 9.52958298], [76.49153137, 9.52958298], [76.49153137, 9.52930546], [76.49291992, 9.52930546], [76.49291992, 9.52958298], [76.49319458, 9.52958298], [76.49319458, 9.52930546], [76.49375153, 9.52930546], [76.49375153, 9.52958298], [76.49458313, 9.52958298], [76.49458313, 9.52930546], [76.49597168, 9.52930927], [76.49597168, 9.52902889], [76.49652863, 9.52902889], [76.49652863, 9.52875137], [76.49846649, 9.52875137], [76.49846649, 9.52902889], [76.50013733, 9.52902889], [76.50013733, 9.52930927], [76.50096893, 9.52930546], [76.50096893, 9.52958298], [76.50125122, 9.52958298], [76.50125122, 9.52986145], [76.50152588, 9.52986145], [76.50152588, 9.53014088], [76.50180817, 9.53013897], [76.50180817, 9.53069496], [76.50208282, 9.53069496], [76.50208282, 9.53097343], [76.50180817, 9.53097057], [76.50180817, 9.53125095], [76.49958801, 9.53125095], [76.49958801, 9.53153133], [76.49931335, 9.53153133], [76.49931335, 9.53180885], [76.49874878, 9.53180695], [76.49874878, 9.53208256], [76.49791718, 9.53208256], [76.49791718, 9.53236103], [76.49764252, 9.53236103], [76.49764252, 9.53292179], [76.49736023, 9.53292179], [76.49736023, 9.53347969], [76.4970932, 9.53347969], [76.4970932, 9.53375053], [76.49680328, 9.53375053], [76.49680328, 9.53403091], [76.49597168, 9.53403091], [76.49597168, 9.53431034], [76.49569702, 9.53430462], [76.49569702, 9.53458309], [76.49458313, 9.53458309], [76.49458313, 9.53486061], [76.49430847, 9.53486061], [76.49430847, 9.53514099], [76.49318695, 9.53514099], [76.49318695, 9.53541946], [76.49236298, 9.5354166], [76.49236298, 9.53569508], [76.49208069, 9.53569508], [76.49208069, 9.5359726], [76.49153137, 9.5359726], [76.49153137, 9.53652668], [76.49124908, 9.53652668], [76.49124908, 9.53736115], [76.4909668, 9.53736115], [76.4909668, 9.53931046], [76.49069214, 9.53931046], [76.49069214, 9.54041958], [76.49041748, 9.54041767], [76.49041748, 9.54069328], [76.49013519, 9.54069328], [76.49013519, 9.5409708], [76.48958588, 9.54097366], [76.48958588, 9.54124928], [76.48902893, 9.54124928], [76.48902893, 9.54152966], [76.48792267, 9.54152966], [76.48792267, 9.54181004], [76.48764038, 9.54180622], [76.48764038, 9.54208374], [76.48708344, 9.54208374], [76.48708344, 9.54236221], [76.48569489, 9.54236221], [76.48569489, 9.54208374], [76.48513794, 9.54208374], [76.48513794, 9.54180622], [76.48458862, 9.54181004], [76.48458862, 9.54152966], [76.48430634, 9.54152966], [76.48430634, 9.54124928], [76.48401642, 9.54124928], [76.48401642, 9.54096889], [76.48374939, 9.5409708], [76.48374939, 9.54069328], [76.48319244, 9.54069328], [76.48319244, 9.54041767], [76.48291779, 9.54041958], [76.48291779, 9.54014015], [76.48236084, 9.54014015], [76.48236084, 9.5395813], [76.48180389, 9.53958321], [76.48180389, 9.53930473], [76.48124695, 9.53931046], [76.48124695, 9.53903198], [76.48097229, 9.53903198], [76.48097229, 9.5387516], [76.48042297, 9.5387516], [76.48042297, 9.53819084], [76.47846985, 9.53819466], [76.47846985, 9.53847122], [76.4779129, 9.53847122], [76.4779129, 9.5387516], [76.4770813, 9.5387516], [76.4770813, 9.53903198], [76.47624969, 9.53903198], [76.47624969, 9.53931046], [76.47569275, 9.53930473], [76.47569275, 9.53958321], [76.47402954, 9.53958321], [76.47402954, 9.53986073], [76.4734726, 9.53986073], [76.4734726, 9.54014015], [76.47292328, 9.54014015], [76.47292328, 9.54041958], [76.47264099, 9.54041767], [76.47264099, 9.54069328], [76.47097015, 9.54069328], [76.47097015, 9.5409708], [76.47013855, 9.54097366], [76.47013855, 9.54124928], [76.46930695, 9.54124928], [76.46930695, 9.54152966], [76.46848297, 9.54152966], [76.46848297, 9.54181004], [76.4679184, 9.54180622], [76.4679184, 9.54208374], [76.46708679, 9.54208374], [76.46708679, 9.54236221], [76.46652222, 9.54235935], [76.46652222, 9.54265118], [76.46624756, 9.54265118], [76.46624756, 9.54292011], [76.4659729, 9.54292011], [76.4659729, 9.54514027], [76.46624756, 9.54514027], [76.46624756, 9.54986], [76.46652222, 9.54986], [76.46652222, 9.55042076], [76.46624756, 9.55041599], [76.46624756, 9.55125046], [76.4659729, 9.55125046], [76.4659729, 9.55152798], [76.46624756, 9.55152798], [76.46624756, 9.55347157], [76.46652222, 9.55346966], [76.46652222, 9.55403137], [76.46624756, 9.55403137], [76.46624756, 9.55458927], [76.46652222, 9.55458927], [76.46652222, 9.55792141], [76.4668045, 9.55791664], [76.4668045, 9.55847263], [76.46652222, 9.55847073], [76.46652222, 9.55931187], [76.46541595, 9.55931187], [76.46541595, 9.55653095], [76.4651413, 9.55653095], [76.4651413, 9.55597019], [76.46541595, 9.55597305], [76.46541595, 9.55569458], [76.4651413, 9.55569458], [76.4651413, 9.55430698], [76.46541595, 9.55430889], [76.46541595, 9.55346966], [76.4651413, 9.55347157], [76.4651413, 9.55291557], [76.46541595, 9.5529213], [76.46541595, 9.55125046], [76.4651413, 9.55125046], [76.4651413, 9.54986], [76.46541595, 9.54986], [76.46541595, 9.5490284], [76.4651413, 9.5490303], [76.4651413, 9.54736042], [76.46485901, 9.54736233], [76.46485901, 9.54374981], [76.46458435, 9.54374981], [76.46458435, 9.54347229], [76.46347046, 9.54347229], [76.46347046, 9.54374981], [76.46263885, 9.54374981], [76.46263885, 9.54403019], [76.46208191, 9.54403019], [76.46208191, 9.54430962], [76.46125031, 9.5443058], [76.46125031, 9.54458427], [76.4604187, 9.54458237], [76.4604187, 9.54486179], [76.45874786, 9.54486179], [76.45874786, 9.54514027], [76.45819092, 9.54514027], [76.45819092, 9.54541969], [76.4576416, 9.54541588], [76.4576416, 9.54569435], [76.45625305, 9.54569435], [76.45625305, 9.54597187], [76.45597076, 9.54597187], [76.45597076, 9.54625034], [76.45513916, 9.54625034], [76.45513916, 9.54653263], [76.45430756, 9.54653263], [76.45430756, 9.5468111], [76.45236206, 9.54680634], [76.45236206, 9.54708195], [76.45218658, 9.54708195], [76.45180511, 9.54708195], [76.45180511, 9.54736233], [76.45124817, 9.54736042], [76.45124817, 9.54763985], [76.45014191, 9.54763985], [76.45014191, 9.54792118], [76.44930267, 9.54791641], [76.44930267, 9.54819393], [76.44875336, 9.54819393], [76.44875336, 9.5484724], [76.44735718, 9.54846096], [76.44735718, 9.54874992], [76.44680786, 9.54874992], [76.44680786, 9.5490303], [76.4465332, 9.5490303], [76.4465332, 9.54931068], [76.44486237, 9.54930592], [76.44486237, 9.54957962], [76.44403076, 9.54958439], [76.44403076, 9.54986], [76.44374847, 9.54986], [76.44374847, 9.55014038], [76.44291687, 9.55014038], [76.44291687, 9.55042076], [76.44180298, 9.55041599], [76.44180298, 9.55069447], [76.44125366, 9.55069447], [76.44125366, 9.55097198], [76.4404068, 9.55097008], [76.44041443, 9.55125046], [76.43985748, 9.55125046], [76.43985748, 9.55152798], [76.43930817, 9.55152798], [76.43930817, 9.55319405], [76.43902588, 9.55319023], [76.43902588, 9.55375099], [76.43846893, 9.55375099], [76.43846893, 9.55403137], [76.43569183, 9.55403137], [76.43569183, 9.55430889], [76.4345932, 9.55430889], [76.4345932, 9.55458927], [76.43430328, 9.55458164], [76.43430328, 9.55486012], [76.43347931, 9.55486012], [76.43347931, 9.55514145], [76.43180847, 9.55514145], [76.43180847, 9.55486012], [76.43125153, 9.55486012], [76.43125153, 9.55514145], [76.43096924, 9.55514145], [76.43096924, 9.55486012], [76.42819214, 9.55486012], [76.42819214, 9.55514145], [76.42652893, 9.55514145], [76.42652893, 9.55542088], [76.42597198, 9.55541706], [76.42597198, 9.55569458], [76.42541504, 9.55569458], [76.42541504, 9.55597305], [76.42485809, 9.55597019], [76.42485809, 9.55625057], [76.42457581, 9.55625057], [76.42457581, 9.55653095], [76.42430878, 9.55653095], [76.42430878, 9.55681133], [76.42402649, 9.55680466], [76.42402649, 9.55708313], [76.42375183, 9.55708313], [76.42375183, 9.55736065], [76.42318726, 9.55736065], [76.42318726, 9.55764961], [76.42263794, 9.55764961], [76.42263794, 9.55792141], [76.42208099, 9.55791664], [76.42208099, 9.55819511], [76.42097473, 9.55819511], [76.42097473, 9.55847263], [76.4201355, 9.55847263], [76.42014313, 9.55875111], [76.41929626, 9.55875111], [76.41929626, 9.55903053], [76.41874695, 9.55903053], [76.41874695, 9.55931187], [76.41819763, 9.55930519], [76.41819763, 9.55958271], [76.41792297, 9.5595808], [76.41792297, 9.56042194], [76.41764069, 9.56042194], [76.41764069, 9.56125069], [76.41792297, 9.56125069], [76.41792297, 9.56236076], [76.41819763, 9.56236076], [76.41819763, 9.56319523], [76.41847229, 9.56319523], [76.41847229, 9.56347084], [76.41819763, 9.56346035], [76.41819763, 9.56431198], [76.41791534, 9.56430531], [76.41791534, 9.56458282], [76.41764069, 9.56458282], [76.41764069, 9.5648613], [76.4173584, 9.5648613], [76.4173584, 9.56514168], [76.41680908, 9.56514168], [76.41680908, 9.56542015], [76.41625214, 9.56541729], [76.41625214, 9.56597137], [76.41596985, 9.56597137], [76.41596985, 9.56959057], [76.41625214, 9.56958389], [76.41625214, 9.56986237], [76.41652679, 9.56985855], [76.41652679, 9.57014179], [76.41680908, 9.57013988], [76.41680908, 9.5706892], [76.41652679, 9.57069969], [76.41652679, 9.57181263], [76.41680908, 9.57180595], [76.41680908, 9.57208443], [76.4173584, 9.57208443], [76.4173584, 9.57236195], [76.41791534, 9.57236195], [76.41791534, 9.57319355], [76.41819763, 9.57319164], [76.41819763, 9.57402992], [76.41847229, 9.57402802], [76.41847229, 9.57458401], [76.41874695, 9.57458401], [76.41874695, 9.57569408], [76.41930389, 9.57569408], [76.41930389, 9.5759716], [76.41958618, 9.5759716], [76.41958618, 9.57736015], [76.41986084, 9.57736015], [76.41986084, 9.57792091], [76.4201355, 9.57791615], [76.4201355, 9.57819366], [76.42041779, 9.57818985], [76.42041779, 9.57931137], [76.42069244, 9.57930565], [76.42069244, 9.58097267], [76.4209671, 9.5809679], [76.4209671, 9.58181953], [76.42124939, 9.58181953], [76.42124939, 9.58264065], [76.42152405, 9.58263874], [76.42152405, 9.58319473], [76.42124939, 9.58318996], [76.42124939, 9.58375072], [76.42152405, 9.58375072], [76.42152405, 9.58458328], [76.42180634, 9.58457088], [76.42180634, 9.58514118], [76.42208099, 9.58513927], [76.42208099, 9.58625126], [76.42236328, 9.58625126], [76.42236328, 9.58736134], [76.42263794, 9.58736134], [76.42263794, 9.58763885], [76.42292023, 9.58763027], [76.42292023, 9.58791924], [76.42263794, 9.58791733], [76.42263794, 9.58819485], [76.42292023, 9.58819103], [76.42292023, 9.58930969], [76.42318726, 9.58930969], [76.42318726, 9.59042168], [76.42292023, 9.59042168], [76.42292023, 9.59152889], [76.42319489, 9.59152699], [76.42319489, 9.59319305], [76.42346954, 9.59319115], [76.42346954, 9.59403038], [76.42375183, 9.59402657], [76.42375183, 9.59458447], [76.42402649, 9.59458065], [76.42402649, 9.59514046], [76.42430878, 9.59514046], [76.42430878, 9.59597206], [76.42457581, 9.5959692], [76.42457581, 9.59652996], [76.42485809, 9.59652805], [76.42485809, 9.59708405], [76.42514038, 9.59707928], [76.42514038, 9.59792042], [76.42542267, 9.59792042], [76.42542267, 9.59875202], [76.42569733, 9.59875011], [76.42569733, 9.59958363], [76.42597198, 9.59958363], [76.42597198, 9.6006937], [76.42624664, 9.6006937], [76.42624664, 9.60235977], [76.42652893, 9.60235977], [76.42652893, 9.60347176], [76.42679596, 9.60346985], [76.42679596, 9.60403061], [76.42764282, 9.60403061], [76.42764282, 9.60431099], [76.42791748, 9.60430622], [76.42791748, 9.60458374], [76.42819214, 9.60458374], [76.42819214, 9.60486031], [76.4284668, 9.60486031], [76.4284668, 9.60513973], [76.42874908, 9.60513973], [76.42874908, 9.60570145], [76.42903137, 9.60570145], [76.42903137, 9.60681057], [76.42930603, 9.60680676], [76.42930603, 9.6081953], [76.42958069, 9.60818958], [76.42958069, 9.6093092], [76.42986298, 9.6093092], [76.42986298, 9.61042118], [76.43013763, 9.61042118], [76.43013763, 9.61125088], [76.42986298, 9.61125088], [76.42986298, 9.61208344], [76.42958069, 9.61207962], [76.42958069, 9.61291885], [76.42930603, 9.61291695], [76.42930603, 9.61347294], [76.4284668, 9.61347103], [76.4284668, 9.61652946], [76.42819214, 9.61652946], [76.42819214, 9.61680984], [76.42791748, 9.61680508], [76.42791748, 9.61736107], [76.42735291, 9.61736107], [76.42735291, 9.61793137], [76.42680359, 9.61791706], [76.42680359, 9.61819458], [76.42652893, 9.61819077], [76.42652893, 9.61903191], [76.42624664, 9.61903191], [76.42624664, 9.61931038], [76.42597198, 9.61930466], [76.42597198, 9.61958313], [76.42569733, 9.61958122], [76.42569733, 9.62042046], [76.42542267, 9.62042046], [76.42542267, 9.62152958], [76.42514038, 9.62152958], [76.42514038, 9.62263966], [76.42485809, 9.62263966], [76.42485809, 9.62292004], [76.42458344, 9.62291527], [76.42458344, 9.62347221], [76.42430878, 9.62347221], [76.42430878, 9.62486172], [76.42402649, 9.62485981], [76.42402649, 9.62541962], [76.42375183, 9.6254158], [76.42375183, 9.62625027], [76.42346954, 9.62625027], [76.42346954, 9.62681103], [76.42319489, 9.62680626], [76.42319489, 9.62708378], [76.42346954, 9.62708378], [76.42346954, 9.62736225], [76.42318726, 9.62736034], [76.42318726, 9.62764168], [76.42292023, 9.62763786], [76.42292023, 9.62819386], [76.42263794, 9.62819386], [76.42263794, 9.62847233], [76.42236328, 9.62847233], [76.42236328, 9.62874985], [76.42208099, 9.62874985], [76.42208099, 9.62903023], [76.42180634, 9.62903023], [76.42180634, 9.62931061], [76.42124939, 9.62930584], [76.42124939, 9.62958431], [76.42069244, 9.62957954], [76.42069244, 9.62987137], [76.42041779, 9.62987137], [76.42041779, 9.6301403], [76.42014313, 9.6301403], [76.42014313, 9.63042068], [76.41930389, 9.63041592], [76.41930389, 9.63069439], [76.41874695, 9.63069439], [76.41874695, 9.63097191], [76.41847229, 9.63097], [76.41847229, 9.63153076], [76.41819763, 9.6315279], [76.41819763, 9.63208199], [76.41792297, 9.63208199], [76.41792297, 9.63264275], [76.41764069, 9.63263798], [76.41764069, 9.63319016], [76.4173584, 9.63320065], [76.4173584, 9.63514137], [76.41707611, 9.63514137], [76.41707611, 9.63625145], [76.4173584, 9.63625145], [76.4173584, 9.63681126], [76.41764069, 9.63681126], [76.41764069, 9.63792133], [76.41792297, 9.63792133], [76.41792297, 9.63903141], [76.41819763, 9.63903141], [76.41819763, 9.63931179], [76.41847229, 9.63930511], [76.41847229, 9.63958263], [76.41874695, 9.63958073], [76.41874695, 9.64014053], [76.41902924, 9.64014053], [76.41902924, 9.64042187], [76.41930389, 9.6404171], [76.41930389, 9.64069462], [76.41958618, 9.64068985], [76.41958618, 9.64125061], [76.41986084, 9.64125061], [76.41986084, 9.64153099], [76.42069244, 9.64153099], [76.42069244, 9.64125061], [76.4209671, 9.64125061], [76.4209671, 9.64097118], [76.42263794, 9.64097118], [76.42263794, 9.64125061], [76.42542267, 9.64125061], [76.42542267, 9.64181042], [76.42514038, 9.6418047], [76.42514038, 9.64208317], [76.42485809, 9.64208317], [76.42485809, 9.64236069], [76.42457581, 9.64236069], [76.42457581, 9.64291859], [76.42430878, 9.64291668], [76.42430878, 9.64319515], [76.42402649, 9.64319515], [76.42402649, 9.64347267], [76.42375183, 9.64347267], [76.42375183, 9.64375114], [76.42318726, 9.64375114], [76.42318726, 9.64403152], [76.42263794, 9.64403152], [76.42263794, 9.6443119], [76.42208099, 9.6443119], [76.42208099, 9.64375114], [76.42180634, 9.64375114], [76.42180634, 9.64347267], [76.42151642, 9.64347076], [76.42152405, 9.64375114], [76.42124939, 9.64375114], [76.42124939, 9.64439201], [76.42124939, 9.64458275], [76.4209671, 9.64458084], [76.4209671, 9.6451416], [76.42041779, 9.6451416], [76.42041779, 9.64458084], [76.4201355, 9.64458275], [76.4201355, 9.64347267], [76.41986084, 9.64347267], [76.41986084, 9.64319992], [76.41986084, 9.64236069], [76.41958618, 9.64236069], [76.41958618, 9.6418047], [76.41930389, 9.6418047], [76.41930389, 9.64272118], [76.41929626, 9.64403152], [76.41958618, 9.64402676], [76.41958618, 9.64569473], [76.41986084, 9.64569092], [76.41986084, 9.64625168], [76.42014313, 9.64625168], [76.42014313, 9.64680958], [76.42041779, 9.64680958], [76.42041779, 9.64764023], [76.42069244, 9.64764023], [76.42069244, 9.64819336], [76.4209671, 9.64819145], [76.4209671, 9.64931011], [76.42124939, 9.64931011], [76.42124939, 9.65042019], [76.42041779, 9.65042019], [76.42041779, 9.65013981], [76.4201355, 9.65013981], [76.4201355, 9.64986229], [76.41986084, 9.64986229], [76.41986084, 9.64902782], [76.41958618, 9.64902973], [76.41958618, 9.64791107], [76.41930389, 9.64791775], [76.41930389, 9.6473608], [76.41902924, 9.6473608], [76.41902924, 9.64680481], [76.41874695, 9.64680958], [76.41874695, 9.64625168], [76.41847229, 9.64625168], [76.41847229, 9.64458084], [76.41819763, 9.64458275], [76.41819763, 9.64291668], [76.41792297, 9.64291859], [76.41792297, 9.64236069], [76.4173584, 9.64236069], [76.4173584, 9.64264107], [76.41680908, 9.64264107], [76.41680908, 9.64291859], [76.41513824, 9.64291668], [76.41513824, 9.64319515], [76.41402435, 9.64319515], [76.41402435, 9.64347267], [76.41291809, 9.64347267], [76.41291809, 9.64375114], [76.41208649, 9.64375114], [76.41208649, 9.64403152], [76.41124725, 9.64403152], [76.41124725, 9.6443119], [76.41069794, 9.64430523], [76.41069794, 9.64458275], [76.40820313, 9.64458084], [76.40820313, 9.6448698], [76.40763855, 9.6448698], [76.40763855, 9.6451416], [76.40735626, 9.6451416], [76.40735626, 9.64542198], [76.4067688, 9.64541721], [76.40625, 9.64541721], [76.40625, 9.64569473], [76.40569305, 9.64569473], [76.40569305, 9.6459713], [76.40458679, 9.6459713], [76.40458679, 9.64625168], [76.40374756, 9.64625168], [76.40374756, 9.64653015], [76.4034729, 9.64653015], [76.4034729, 9.64680958], [76.40319824, 9.64680481], [76.40319824, 9.64708328], [76.40291595, 9.64708328], [76.40291595, 9.6473608], [76.4026413, 9.64735889], [76.4026413, 9.64931011], [76.40291595, 9.6493063], [76.40291595, 9.6506958], [76.40319824, 9.6506958], [76.40319824, 9.6514616], [76.40319824, 9.65236187], [76.4034729, 9.65236187], [76.4034729, 9.65458393], [76.40374756, 9.65458202], [76.40374756, 9.65513992], [76.40402985, 9.65513802], [76.40402985, 9.65597153], [76.40429688, 9.65596962], [76.40429688, 9.65625], [76.40402985, 9.65625], [76.40402985, 9.65653038], [76.40429688, 9.65653038], [76.40429688, 9.65681076], [76.40402985, 9.65680599], [76.40402985, 9.65708447], [76.4043045, 9.65708447], [76.4043045, 9.65847206], [76.40458679, 9.65847015], [76.40458679, 9.66181087], [76.40486145, 9.6618042], [76.40486145, 9.66236019], [76.40513611, 9.66236019], [76.40513611, 9.66264057], [76.40486145, 9.66264057], [76.40486145, 9.66375065], [76.40458679, 9.66375065], [76.40458679, 9.66458321], [76.4054184, 9.66458321], [76.4054184, 9.66486073], [76.40651703, 9.66486073], [76.40651703, 9.66514111], [76.40735626, 9.66514111], [76.40735626, 9.66486073], [76.40763855, 9.66486073], [76.40763855, 9.66458321], [76.4081955, 9.66458321], [76.4081955, 9.66430473], [76.40847015, 9.66431141], [76.40847015, 9.66403103], [76.40875244, 9.66403103], [76.40875244, 9.66375065], [76.40930939, 9.66375065], [76.40930939, 9.66347027], [76.40958405, 9.66347313], [76.40958405, 9.66319466], [76.41014099, 9.66319466], [76.41014099, 9.66291714], [76.41041565, 9.66291714], [76.41041565, 9.66263866], [76.4109726, 9.66264057], [76.4109726, 9.66236019], [76.41124725, 9.66236019], [76.41124725, 9.66208458], [76.4118042, 9.66208458], [76.4118042, 9.6618042], [76.41208649, 9.66181087], [76.41208649, 9.66153145], [76.4126358, 9.66153145], [76.4126358, 9.66125107], [76.41291809, 9.66125107], [76.41291809, 9.66096973], [76.41347504, 9.66097164], [76.41347504, 9.66069412], [76.41374969, 9.66069412], [76.41374969, 9.66041565], [76.41430664, 9.66042137], [76.41430664, 9.66014099], [76.4145813, 9.66014099], [76.4145813, 9.65985107], [76.41513824, 9.65985966], [76.41513824, 9.65958214], [76.4154129, 9.65958214], [76.4154129, 9.65930557], [76.41570282, 9.65931129], [76.41570282, 9.65874958], [76.41596985, 9.65874958], [76.41596985, 9.65847015], [76.41652679, 9.65847206], [76.41652679, 9.65819359], [76.41708374, 9.65819359], [76.41708374, 9.65847206], [76.41764069, 9.65847206], [76.41764069, 9.65819359], [76.41902924, 9.65819359], [76.41902924, 9.65847206], [76.41874695, 9.65847015], [76.41874695, 9.65874958], [76.41819763, 9.65874958], [76.41819763, 9.65903091], [76.41792297, 9.65903091], [76.41792297, 9.65931129], [76.4173584, 9.65930557], [76.4173584, 9.65958214], [76.41708374, 9.65958214], [76.41708374, 9.65986347], [76.41625214, 9.65985107], [76.41625214, 9.66014099], [76.41570282, 9.66014099], [76.41570282, 9.66042137], [76.41513824, 9.66041565], [76.41513824, 9.66069412], [76.41486359, 9.66069412], [76.41486359, 9.66097164], [76.4145813, 9.66096973], [76.4145813, 9.66125107], [76.41430664, 9.66125107], [76.41430664, 9.66153145], [76.41401672, 9.66153145], [76.41401672, 9.66181087], [76.41374969, 9.6618042], [76.41374969, 9.66208458], [76.41347504, 9.66208458], [76.41347504, 9.66236019], [76.41319275, 9.66236019], [76.41319275, 9.66291714], [76.41291809, 9.66291714], [76.41291809, 9.66319466], [76.41236115, 9.66319466], [76.41236115, 9.66347313], [76.41208649, 9.66347027], [76.41208649, 9.66375065], [76.41152954, 9.66375065], [76.41152954, 9.66403103], [76.4109726, 9.66403103], [76.4109726, 9.66431141], [76.41069794, 9.66430473], [76.41069794, 9.66458321], [76.41014099, 9.66458321], [76.41014099, 9.66486073], [76.4098587, 9.66486073], [76.4098587, 9.66514111], [76.40930939, 9.66514111], [76.40930939, 9.66542053], [76.4090271, 9.66541672], [76.4090271, 9.66569519], [76.40847015, 9.66569042], [76.40847015, 9.66598034], [76.4081955, 9.66597271], [76.4081955, 9.66625118], [76.40791321, 9.66625118], [76.40791321, 9.66653061], [76.40402985, 9.66653061], [76.40402985, 9.66681194], [76.4043045, 9.66680527], [76.4043045, 9.66736126], [76.40458679, 9.66736126], [76.40458679, 9.66819477], [76.40486145, 9.66819477], [76.40486145, 9.66958332], [76.40513611, 9.66958141], [76.40513611, 9.67153168], [76.40486145, 9.67153168], [76.40486145, 9.67263889], [76.40513611, 9.67263889], [76.40513611, 9.67292023], [76.40597534, 9.67291737], [76.40597534, 9.67319489], [76.40652466, 9.67319489], [76.40652466, 9.67347431], [76.40680695, 9.67347145], [76.40680695, 9.67375183], [76.4070816, 9.67375183], [76.4070816, 9.67430973], [76.40735626, 9.67430973], [76.40735626, 9.67514038], [76.40791321, 9.67514038], [76.40791321, 9.67597103], [76.40820313, 9.67597103], [76.40820313, 9.67625046], [76.40847015, 9.67625046], [76.40847015, 9.67653179], [76.40875244, 9.67652798], [76.40875244, 9.67736244], [76.4090271, 9.67735863], [76.4090271, 9.67763996], [76.40930176, 9.67763996], [76.40930939, 9.67847157], [76.40957642, 9.67847157], [76.40957642, 9.67875195], [76.4098587, 9.67875195], [76.4098587, 9.67903042], [76.41014099, 9.67903042], [76.41014099, 9.67930984], [76.41042328, 9.67930984], [76.41042328, 9.68013954], [76.41069794, 9.68013954], [76.41069794, 9.68041992], [76.4109726, 9.68041992], [76.4109726, 9.68098068], [76.41152954, 9.68098068], [76.41152954, 9.68153], [76.41179657, 9.68153], [76.41179657, 9.68181133], [76.41208649, 9.68180561], [76.41208649, 9.68208408], [76.41236115, 9.68208408], [76.41236115, 9.6823597], [76.4126358, 9.6823597], [76.4126358, 9.68292141], [76.41291809, 9.68291569], [76.41291809, 9.68375015], [76.41319275, 9.68375015], [76.41319275, 9.68486023], [76.41347504, 9.68486023], [76.41347504, 9.68569374], [76.41374969, 9.68569183], [76.41374969, 9.68681145], [76.41401672, 9.68681145], [76.41401672, 9.68792057], [76.41430664, 9.68792057], [76.41430664, 9.68903065], [76.4145813, 9.68903065], [76.4145813, 9.69015026], [76.41486359, 9.69013882], [76.41486359, 9.69208336], [76.4145813, 9.69207954], [76.4145813, 9.69430923], [76.41430664, 9.69430923], [76.41430664, 9.69541931], [76.41401672, 9.69541931], [76.41401672, 9.69625092], [76.41374969, 9.69625092], [76.41374969, 9.69680977], [76.41319275, 9.696805], [76.41319275, 9.69736099], [76.4126358, 9.69736099], [76.4126358, 9.69764137], [76.41179657, 9.69764137], [76.41179657, 9.69791985], [76.41069794, 9.69791698], [76.41069794, 9.69819546], [76.4098587, 9.69819546], [76.4098587, 9.69847107], [76.40957642, 9.69847107], [76.40958405, 9.69874859], [76.40930939, 9.69875145], [76.40930176, 9.69902706], [76.40875244, 9.69902039], [76.40875244, 9.6993103], [76.40847015, 9.69930458], [76.40847015, 9.69958305], [76.40791321, 9.69958305], [76.40791321, 9.69986057], [76.40652466, 9.69986057], [76.40652466, 9.69958305], [76.40597534, 9.69958305], [76.40597534, 9.69902706], [76.40569305, 9.69902706], [76.40569305, 9.69875145], [76.4054184, 9.69875145], [76.4054184, 9.69847107], [76.40513611, 9.69847107], [76.40513611, 9.69819546], [76.4043045, 9.69819546], [76.4043045, 9.69791698], [76.40402985, 9.69791985], [76.40402985, 9.69764137], [76.40374756, 9.69764137], [76.40374756, 9.69708061], [76.40319824, 9.69708347], [76.40319061, 9.69652653], [76.4026413, 9.69652939], [76.4026413, 9.69625092], [76.4006958, 9.69625092], [76.4006958, 9.69652939], [76.40040588, 9.69652939], [76.40040588, 9.69680977], [76.40013885, 9.696805], [76.40013885, 9.69708347], [76.39958191, 9.69708347], [76.39958191, 9.69736099], [76.39930725, 9.69736099], [76.39930725, 9.69764137], [76.39875031, 9.69763947], [76.39875031, 9.69874859], [76.39847565, 9.69875145], [76.39847565, 9.69986057], [76.39819336, 9.69986057], [76.39819336, 9.70042038], [76.3970871, 9.70041656], [76.3970871, 9.70069313], [76.39680481, 9.70069313], [76.39680481, 9.70097446], [76.39653015, 9.70097065], [76.39653015, 9.70125198], [76.39624786, 9.70125198], [76.39624786, 9.70181179], [76.39485931, 9.70181179], [76.39485931, 9.70153046], [76.39375305, 9.70153046], [76.39375305, 9.70125198], [76.39290619, 9.70125198], [76.39290619, 9.70097065], [76.3923645, 9.70097446], [76.3923645, 9.70069313], [76.38735962, 9.70069313], [76.38735962, 9.70097446], [76.38540649, 9.70097065], [76.38540649, 9.70125198], [76.38458252, 9.70125198], [76.38458252, 9.70153046], [76.3840332, 9.70153046], [76.3840332, 9.70209026], [76.38346863, 9.70208359], [76.38346863, 9.70236206], [76.38318634, 9.7023592], [76.38318634, 9.70263958], [76.38291931, 9.70263958], [76.38291931, 9.70347214], [76.38263702, 9.70346928], [76.38263702, 9.70374966], [76.38291931, 9.70374966], [76.38291931, 9.70403004], [76.38263702, 9.70402813], [76.38263702, 9.70458412], [76.38291931, 9.70458412], [76.38291931, 9.70486164], [76.38318634, 9.70486164], [76.38318634, 9.70541954], [76.38346863, 9.70541573], [76.38346863, 9.70597172], [76.38375092, 9.70596886], [76.38375092, 9.70681], [76.3840332, 9.70681], [76.3840332, 9.70792007], [76.38430786, 9.70792007], [76.38430786, 9.70903015], [76.38458252, 9.70902824], [76.38458252, 9.70985985], [76.38486481, 9.70985985], [76.38486481, 9.71097183], [76.38513947, 9.71096134], [76.38513947, 9.71181107], [76.38541412, 9.7118063], [76.38541412, 9.71236229], [76.38569641, 9.71236229], [76.38569641, 9.71319389], [76.38597107, 9.71319199], [76.38597107, 9.71375275], [76.38625336, 9.71375275], [76.38625336, 9.71431065], [76.38652802, 9.71430683], [76.38652802, 9.71458244], [76.38707733, 9.71457958], [76.38707733, 9.71485996], [76.38735962, 9.71485996], [76.38735962, 9.71569538], [76.38764191, 9.71568966], [76.38764191, 9.71681118], [76.38791656, 9.71681118], [76.38791656, 9.71792126], [76.38819885, 9.71792126], [76.38819885, 9.71903133], [76.38846588, 9.71903133], [76.38846588, 9.72042084], [76.38874817, 9.72041702], [76.38874817, 9.72236061], [76.38903046, 9.72236061], [76.38903046, 9.7240324], [76.38874817, 9.72402668], [76.38874817, 9.72569466], [76.38847351, 9.72569466], [76.38847351, 9.72708321], [76.38874817, 9.7270813], [76.38874817, 9.72791958], [76.38903046, 9.72791767], [76.38903046, 9.72874928], [76.38930511, 9.72874928], [76.38930511, 9.72986221], [76.38957977, 9.72986221], [76.38957977, 9.73486233], [76.38986206, 9.73486042], [76.38986206, 9.73624992], [76.39013672, 9.73624992], [76.39013672, 9.73764038], [76.39041901, 9.73764038], [76.39041901, 9.73931122], [76.39069366, 9.73930645], [76.39069366, 9.74097157], [76.39097595, 9.74097157], [76.39097595, 9.74208546], [76.39068604, 9.74207973], [76.39068604, 9.74264145], [76.39041901, 9.74263763], [76.39041901, 9.74319458], [76.38986206, 9.74319458], [76.38986206, 9.74569511], [76.39013672, 9.74569511], [76.39013672, 9.74597263], [76.38986206, 9.74597263], [76.38986206, 9.74625111], [76.39013672, 9.74625111], [76.39013672, 9.74681187], [76.38986206, 9.74681187], [76.38986206, 9.74764061], [76.38957977, 9.74764061], [76.38957977, 9.74792194], [76.38930511, 9.74791718], [76.38930511, 9.74819469], [76.38903046, 9.74819469], [76.38903046, 9.75097084], [76.38874817, 9.75097084], [76.38874817, 9.75181198], [76.38846588, 9.75181198], [76.38846588, 9.75292015], [76.38819885, 9.75292015], [76.38819885, 9.75319958], [76.38847351, 9.75319481], [76.38847351, 9.75374889], [76.38819885, 9.75374889], [76.38819885, 9.75541973], [76.38791656, 9.75541782], [76.38791656, 9.75597095], [76.38764191, 9.75597095], [76.38764191, 9.75652981], [76.38735962, 9.75652981], [76.38735962, 9.75681019], [76.38708496, 9.75680637], [76.38708496, 9.75736237], [76.38680267, 9.75736237], [76.38680267, 9.75847244], [76.38652802, 9.75847244], [76.38652802, 9.75875187], [76.38625336, 9.75874996], [76.38625336, 9.75930595], [76.38569641, 9.75930595], [76.38569641, 9.75986195], [76.38540649, 9.75986195], [76.38540649, 9.76014042], [76.38485718, 9.76014042], [76.38485718, 9.76041985], [76.38458252, 9.76041794], [76.38458252, 9.76069355], [76.38430786, 9.76069355], [76.38430786, 9.76097202], [76.38375092, 9.76097202], [76.38375092, 9.76124954], [76.38346863, 9.76124954], [76.38346863, 9.76152992], [76.38291931, 9.76152992], [76.38291931, 9.76181126], [76.38236237, 9.76180553], [76.38236237, 9.76208401], [76.38180542, 9.76208401], [76.38180542, 9.76236153], [76.38153076, 9.76235962], [76.38153076, 9.76264], [76.38124847, 9.76264], [76.38124847, 9.76319408], [76.38097382, 9.76319408], [76.38097382, 9.7634716], [76.38069153, 9.7634697], [76.38069153, 9.76375008], [76.38041687, 9.76375008], [76.38041687, 9.76403046], [76.38014221, 9.7640276], [76.38014221, 9.76458359], [76.37958527, 9.76458359], [76.37958527, 9.76486015], [76.37930298, 9.76486015], [76.37930298, 9.76513958], [76.37902832, 9.76513958], [76.37902832, 9.76543045], [76.37819672, 9.76541615], [76.37819672, 9.76569366], [76.3779068, 9.76568985], [76.3779068, 9.76820087], [76.37763977, 9.7681942], [76.37763977, 9.76875114], [76.37708282, 9.76875114], [76.37708282, 9.76903057], [76.37735748, 9.76903057], [76.37735748, 9.76931095], [76.37708282, 9.76930428], [76.37708282, 9.76958466], [76.37652588, 9.76958466], [76.37652588, 9.76986027], [76.37625885, 9.76986027], [76.37625885, 9.77014065], [76.37596893, 9.77014065], [76.37596893, 9.77042103], [76.37541962, 9.77041721], [76.37541962, 9.77069473], [76.37513733, 9.77069473], [76.37513733, 9.77097321], [76.37458038, 9.77097321], [76.37458038, 9.77125072], [76.37403107, 9.77123928], [76.37403107, 9.77181053], [76.37374878, 9.77180672], [76.37374878, 9.7723608], [76.37346649, 9.7723608], [76.37346649, 9.77264118], [76.37319183, 9.77263927], [76.37319183, 9.77375126], [76.37347412, 9.77375126], [76.37347412, 9.77430534], [76.37374878, 9.77430534], [76.37374878, 9.77513885], [76.37403107, 9.77513885], [76.37403107, 9.77569485], [76.37374878, 9.77569485], [76.37374878, 9.77597332], [76.37403107, 9.77597141], [76.37403107, 9.77652931], [76.37431335, 9.77652931], [76.37431335, 9.7776413], [76.37403107, 9.77763939], [76.37403107, 9.77847099], [76.37346649, 9.77847099], [76.37347412, 9.77875137], [76.37291718, 9.77875137], [76.37291718, 9.77902889], [76.3720932, 9.77902889], [76.3720932, 9.77931023], [76.37152863, 9.77930546], [76.37152863, 9.77958298], [76.37124634, 9.77958107], [76.37124634, 9.78014183], [76.37097168, 9.78013897], [76.37097168, 9.78097439], [76.37124634, 9.78097057], [76.37124634, 9.78180981], [76.37180328, 9.78180981], [76.37180328, 9.78374958], [76.37152863, 9.78374958], [76.37152863, 9.78402996], [76.37124634, 9.78402805], [76.37124634, 9.78458405], [76.37097168, 9.78458405], [76.37097168, 9.78486156], [76.37069702, 9.78486156], [76.37069702, 9.78514194], [76.36985779, 9.78514004], [76.36985779, 9.78569412], [76.36958313, 9.78569412], [76.36958313, 9.78597164], [76.36930847, 9.78597164], [76.36930847, 9.78652954], [76.36902618, 9.78652763], [76.36902618, 9.7873621], [76.36875153, 9.7873621], [76.36875153, 9.7881937], [76.36846924, 9.7881918], [76.36846924, 9.78903008], [76.36818695, 9.78903008], [76.36818695, 9.79014015], [76.36791992, 9.79014015], [76.36791992, 9.79097176], [76.36846924, 9.79097176], [76.36846924, 9.79125023], [76.36875153, 9.79125023], [76.36875153, 9.79181099], [76.36902618, 9.79181099], [76.36902618, 9.79263973], [76.36930847, 9.79263783], [76.36930847, 9.79319382], [76.36902618, 9.79319191], [76.36902618, 9.79431057], [76.36930847, 9.7943058], [76.36930847, 9.79458237], [76.36958313, 9.79458046], [76.36958313, 9.79486275], [76.37013245, 9.79486275], [76.37013245, 9.79514122], [76.37069702, 9.79513836], [76.37069702, 9.79541588], [76.37097168, 9.79541588], [76.37097168, 9.79569435], [76.37152863, 9.79569435], [76.37152863, 9.7962513], [76.37180328, 9.7962513], [76.37180328, 9.7968111], [76.37208557, 9.79680443], [76.37208557, 9.79708195], [76.37264252, 9.79708195], [76.37264252, 9.79736137], [76.37291718, 9.79736137], [76.37291718, 9.7976408], [76.37346649, 9.7976408], [76.37346649, 9.79792118], [76.37374878, 9.79791737], [76.37374878, 9.79819489], [76.37403107, 9.79819489], [76.37403107, 9.79847336], [76.37458038, 9.79847336], [76.37458038, 9.79819489], [76.37486267, 9.79819489], [76.37486267, 9.79736137], [76.37513733, 9.79736137], [76.37513733, 9.79652882], [76.37486267, 9.79653072], [76.37486267, 9.7962513], [76.37458038, 9.7962513], [76.37458038, 9.79597282], [76.37430573, 9.79597282], [76.37430573, 9.79569435], [76.37403107, 9.79569435], [76.37403107, 9.79541588], [76.37430573, 9.79541588], [76.37430573, 9.79485989], [76.37403107, 9.79486275], [76.37403107, 9.79403114], [76.37431335, 9.79403114], [76.37431335, 9.79375267], [76.37541962, 9.79375267], [76.37541962, 9.79403114], [76.37568665, 9.79403114], [76.37568665, 9.79431057], [76.37680817, 9.7943058], [76.37680817, 9.79458237], [76.37652588, 9.79458046], [76.37652588, 9.79514122], [76.37625122, 9.79513836], [76.37625122, 9.79569435], [76.37596893, 9.79569435], [76.37596893, 9.79597282], [76.37625122, 9.79597282], [76.37625122, 9.7962513], [76.37652588, 9.7962513], [76.37652588, 9.79653072], [76.37680817, 9.79653072], [76.37680817, 9.7968111], [76.37708282, 9.79680443], [76.37708282, 9.79708195], [76.37735748, 9.79708195], [76.37735748, 9.79736137], [76.37763977, 9.79736137], [76.37763977, 9.79819489], [76.3779068, 9.79818058], [76.3779068, 9.79903126], [76.37819672, 9.79903126], [76.37819672, 9.79931068], [76.37847137, 9.79930687], [76.37847137, 9.79986095], [76.37875366, 9.79986095], [76.37875366, 9.80069542], [76.37902832, 9.8006897], [76.37902832, 9.80180931], [76.37930298, 9.80180454], [76.37930298, 9.80208302], [76.3795929, 9.80208111], [76.3795929, 9.80264091], [76.37985992, 9.80263901], [76.37985992, 9.80347347], [76.38014221, 9.80347347], [76.38014221, 9.8045826], [76.38041687, 9.8045826], [76.38041687, 9.80486107], [76.38124847, 9.80486107], [76.38124847, 9.80514145], [76.38153076, 9.80514145], [76.38153076, 9.80542183], [76.38236237, 9.80541706], [76.38236237, 9.80569458], [76.38263702, 9.80569458], [76.38263702, 9.80597115], [76.38291931, 9.80597115], [76.38291931, 9.80625057], [76.38318634, 9.80625057], [76.38318634, 9.80653191], [76.38346863, 9.80652714], [76.38346863, 9.80708313], [76.38375092, 9.80708313], [76.38375092, 9.80736065], [76.3840332, 9.80735016], [76.3840332, 9.80792046], [76.38458252, 9.80791664], [76.38458252, 9.80819321], [76.38485718, 9.8081913], [76.38485718, 9.8087492], [76.38513947, 9.8087492], [76.38513947, 9.80930996], [76.38541412, 9.80930519], [76.38541412, 9.80958366], [76.38569641, 9.8095789], [76.38569641, 9.81013966], [76.38625336, 9.81013966], [76.38625336, 9.81069565], [76.38652802, 9.81069565], [76.38652802, 9.81097221], [76.38680267, 9.81096935], [76.38680267, 9.81153202], [76.38708496, 9.81152821], [76.38708496, 9.8120842], [76.38735962, 9.8120842], [76.38735962, 9.81236172], [76.38764191, 9.81235981], [76.38764191, 9.81291962], [76.38791656, 9.81291771], [76.38791656, 9.81375027], [76.38819885, 9.81375027], [76.38819885, 9.81402969], [76.38846588, 9.81402969], [76.38846588, 9.81431007], [76.38874817, 9.81430626], [76.38874817, 9.81458378], [76.38903046, 9.81458378], [76.38903046, 9.81486225], [76.38931274, 9.81486034], [76.38931274, 9.81542015], [76.38957977, 9.81541634], [76.38957977, 9.81569386], [76.38986206, 9.81569386], [76.38986206, 9.81624985], [76.39013672, 9.81624985], [76.39013672, 9.81681061], [76.39041901, 9.81680584], [76.39041901, 9.81986237], [76.39013672, 9.81986046], [76.39013672, 9.82014275], [76.38986206, 9.82014275], [76.38986206, 9.82042122], [76.38903046, 9.82042122], [76.38903046, 9.82014275], [76.38764191, 9.82014275], [76.38764191, 9.81986046], [76.38680267, 9.81986237], [76.38680267, 9.81958199], [76.38569641, 9.81958199], [76.38569641, 9.81930637], [76.38346863, 9.81930637], [76.38346863, 9.81958199], [76.38318634, 9.81958199], [76.38318634, 9.82014275], [76.38291931, 9.82013798], [76.38291931, 9.82097244], [76.38263702, 9.82097244], [76.38263702, 9.82208538], [76.38236237, 9.82207966], [76.38239288, 9.82431126], [76.38263702, 9.82430363], [76.38263702, 9.82597256], [76.38236237, 9.82597065], [76.38236237, 9.82653141], [76.38124847, 9.82653141], [76.38124847, 9.82681179], [76.38153076, 9.82680511], [76.38153076, 9.82708263], [76.38180542, 9.82708263], [76.38180542, 9.82736111], [76.38291931, 9.82736111], [76.38291931, 9.82708263], [76.38402557, 9.82708263], [76.38402557, 9.82680511], [76.38430786, 9.82681179], [76.38430786, 9.82653141], [76.38485718, 9.82653141], [76.38485718, 9.82625103], [76.38513947, 9.82625103], [76.38513947, 9.82597065], [76.38569641, 9.82597256], [76.38569641, 9.82569504], [76.38597107, 9.82569504], [76.38597107, 9.82541656], [76.38652802, 9.82542133], [76.38652802, 9.82514095], [76.38680267, 9.82514095], [76.38680267, 9.82486057], [76.38708496, 9.82486057], [76.38708496, 9.82458305], [76.38764191, 9.82458305], [76.38764191, 9.82430363], [76.38791656, 9.82431126], [76.38791656, 9.82403088], [76.38846588, 9.82403088], [76.38846588, 9.82375145], [76.38874817, 9.82375145], [76.38874817, 9.82347012], [76.38903046, 9.82347298], [76.38903046, 9.82319546], [76.38957977, 9.82319546], [76.38957977, 9.82291603], [76.38986206, 9.82291889], [76.38986206, 9.82264137], [76.39041901, 9.82264137], [76.39041901, 9.82235146], [76.39069366, 9.82236004], [76.39069366, 9.82208538], [76.39125061, 9.82208538], [76.39125061, 9.82180691], [76.3915329, 9.82181072], [76.3915329, 9.82118225], [76.39180756, 9.82124996], [76.39180756, 9.82097244], [76.39208221, 9.82097244], [76.39208221, 9.82041645], [76.39235687, 9.82042122], [76.39235687, 9.82014275], [76.39263916, 9.82014275], [76.39263916, 9.81958199], [76.39291382, 9.81958199], [76.39291382, 9.81930637], [76.39319611, 9.81931114], [76.39319611, 9.81903267], [76.39347076, 9.81903267], [76.39347076, 9.81875038], [76.39375305, 9.81875038], [76.39375305, 9.81847191], [76.39402771, 9.81847191], [76.39402771, 9.81819439], [76.39430237, 9.81819439], [76.39430237, 9.81791592], [76.3951416, 9.81791592], [76.3951416, 9.81819439], [76.39485931, 9.81819439], [76.39485931, 9.81875038], [76.39457703, 9.81875038], [76.39457703, 9.81903267], [76.39430237, 9.8190279], [76.39430237, 9.81958199], [76.39402771, 9.81958199], [76.39402771, 9.81986237], [76.39375305, 9.81986046], [76.39375305, 9.82042122], [76.39347076, 9.82041645], [76.39347076, 9.82069397], [76.39319611, 9.82069397], [76.39319611, 9.82111073], [76.39319611, 9.82124996], [76.39290619, 9.82124996], [76.39290619, 9.8215313], [76.39263916, 9.82152843], [76.39263916, 9.82208538], [76.3923645, 9.82208538], [76.3923645, 9.82236004], [76.39208221, 9.82235146], [76.39208221, 9.82291889], [76.39180756, 9.82291603], [76.39180756, 9.82319546], [76.3915329, 9.82318974], [76.3915329, 9.82375145], [76.39124298, 9.82375145], [76.39124298, 9.82403088], [76.39097595, 9.82403088], [76.39097595, 9.82431126], [76.39041901, 9.82430363], [76.39041901, 9.82458305], [76.39013672, 9.82458305], [76.39013672, 9.82486057], [76.38986206, 9.82486057], [76.38986206, 9.82514095], [76.38957977, 9.82514095], [76.38957977, 9.82542133], [76.38903046, 9.82541656], [76.38903046, 9.82569504], [76.38819122, 9.82569504], [76.38819122, 9.82597256], [76.38764191, 9.82597065], [76.38764191, 9.82625103], [76.38707733, 9.82625103], [76.38707733, 9.82653141], [76.38625336, 9.82653141], [76.38625336, 9.82681179], [76.38569641, 9.82680511], [76.38569641, 9.82708263], [76.38486481, 9.82708263], [76.38486481, 9.82736111], [76.38458252, 9.82736111], [76.38458252, 9.82764053], [76.38430786, 9.82764053], [76.38430786, 9.82792091], [76.38375092, 9.8279171], [76.38375092, 9.82819462], [76.38346863, 9.82818985], [76.38346863, 9.82847977], [76.38318634, 9.82847977], [76.38318634, 9.82903099], [76.38291931, 9.82902908], [76.38291931, 9.82958317], [76.38318634, 9.82958126], [76.38318634, 9.82986069], [76.38346863, 9.82986069], [76.38346863, 9.8318119], [76.38291931, 9.83180523], [76.38291931, 9.83236122], [76.38263702, 9.83236122], [76.38263702, 9.83375072], [76.38236237, 9.83375072], [76.38236237, 9.83403015], [76.38318634, 9.83403015], [76.38318634, 9.83375072], [76.38707733, 9.83375072], [76.38707733, 9.83513927], [76.38735962, 9.83513927], [76.38735962, 9.83597088], [76.38708496, 9.83597088], [76.38708496, 9.83708382], [76.38680267, 9.83708382], [76.38680267, 9.8381958], [76.38652802, 9.83819103], [76.38652802, 9.83875179], [76.38625336, 9.83874989], [76.38625336, 9.84069443], [76.38569641, 9.84069443], [76.38569641, 9.84097195], [76.38540649, 9.84097195], [76.38540649, 9.84125042], [76.38485718, 9.84125042], [76.38485718, 9.84152985], [76.38458252, 9.84152985], [76.38458252, 9.84181023], [76.38318634, 9.84181023], [76.38318634, 9.84152985], [76.38263702, 9.84152985], [76.38263702, 9.84125042], [76.38180542, 9.84125042], [76.38180542, 9.84097195], [76.38124847, 9.84097195], [76.38124847, 9.84069443], [76.38041687, 9.84069443], [76.38041687, 9.84041786], [76.37985992, 9.84041786], [76.37985992, 9.84125042], [76.38014221, 9.84125042], [76.38014221, 9.84181023], [76.38097382, 9.84180641], [76.38097382, 9.84208393], [76.38153076, 9.84208393], [76.38153076, 9.8423624], [76.38181305, 9.84235954], [76.38181305, 9.84263992], [76.38236237, 9.84263992], [76.38236237, 9.8429203], [76.38319397, 9.84291553], [76.38319397, 9.84319401], [76.38375092, 9.84318924], [76.38375092, 9.84348106], [76.3840332, 9.84348106], [76.3840332, 9.84375], [76.38458252, 9.84375], [76.38458252, 9.84431076], [76.38181305, 9.84431076], [76.38181305, 9.84403038], [76.38096619, 9.84403038], [76.38096619, 9.84375], [76.37985992, 9.84375], [76.37985992, 9.84403038], [76.3795929, 9.84403038], [76.3795929, 9.84431076], [76.37930298, 9.84430599], [76.37930298, 9.84458447], [76.37902832, 9.84458447], [76.37902832, 9.84486008], [76.37847137, 9.84486008], [76.37847137, 9.84514046], [76.37819672, 9.84514046], [76.37819672, 9.84542274], [76.37791443, 9.84541607], [76.37791443, 9.84569359], [76.37763977, 9.84569359], [76.37763977, 9.84597206], [76.37680817, 9.84597206], [76.37680817, 9.84569359], [76.37708282, 9.84569359], [76.37708282, 9.8451376], [76.37735748, 9.84514046], [76.37735748, 9.8445797], [76.37763977, 9.84458447], [76.37763977, 9.84402847], [76.3779068, 9.84403038], [76.3779068, 9.84348106], [76.37763977, 9.84348106], [76.37763977, 9.84318924], [76.37708282, 9.84319401], [76.37708282, 9.84291553], [76.37652588, 9.8429203], [76.37652588, 9.84263992], [76.37374878, 9.84263992], [76.37374878, 9.84235954], [76.37291718, 9.8423624], [76.37291718, 9.84208393], [76.37208557, 9.84208393], [76.37208557, 9.8423624], [76.37152863, 9.84235954], [76.37152863, 9.84431076], [76.37180328, 9.84430599], [76.37180328, 9.84486008], [76.37152863, 9.84486008], [76.37152863, 9.84764099], [76.37124634, 9.84764099], [76.37124634, 9.84792137], [76.37152863, 9.84791565], [76.37152863, 9.84819412], [76.37124634, 9.84819412], [76.37124634, 9.84847164], [76.37152863, 9.84846973], [76.37152863, 9.84903145], [76.37180328, 9.84903145], [76.37180328, 9.84931087], [76.37236023, 9.8493042], [76.37236023, 9.84958458], [76.37430573, 9.84958458], [76.37430573, 9.8493042], [76.37458038, 9.8493042], [76.37458038, 9.84958458], [76.37513733, 9.84958458], [76.37513733, 9.84986019], [76.37568665, 9.84986019], [76.37568665, 9.85014057], [76.37596893, 9.85014057], [76.37596893, 9.85042095], [76.37625122, 9.85041714], [76.37625122, 9.85069466], [76.37680817, 9.85069466], [76.37680817, 9.85097313], [76.37708282, 9.85097027], [76.37708282, 9.85125065], [76.37735748, 9.85125065], [76.37735748, 9.85153103], [76.37763977, 9.85153103], [76.37763977, 9.85181141], [76.37819672, 9.85180664], [76.37819672, 9.85208321], [76.37847137, 9.85208321], [76.37847137, 9.85236073], [76.37874603, 9.85236073], [76.37874603, 9.85264969], [76.37902832, 9.8526392], [76.37902832, 9.85319519], [76.37930298, 9.85319519], [76.37930298, 9.85347271], [76.37958527, 9.85347271], [76.37958527, 9.85486126], [76.37930298, 9.85486126], [76.37930298, 9.85652924], [76.37902832, 9.85652924], [76.37902832, 9.85931015], [76.37874603, 9.85931015], [76.37874603, 9.86042023], [76.37847137, 9.86042023], [76.37847137, 9.86125183], [76.37819672, 9.86124897], [76.37819672, 9.86236095], [76.3779068, 9.86236095], [76.3779068, 9.86291981], [76.37763977, 9.8629179], [76.37763977, 9.86374855], [76.37735748, 9.86374855], [76.37735748, 9.86486244], [76.37708282, 9.86486244], [76.37708282, 9.86514187], [76.37652588, 9.86514187], [76.37652588, 9.86542034], [76.37625122, 9.86541557], [76.37625122, 9.86569405], [76.37596893, 9.86569118], [76.37596893, 9.86625195], [76.37568665, 9.86625195], [76.37568665, 9.86653042], [76.37541962, 9.86652756], [76.37541962, 9.86708355], [76.37513733, 9.86708355], [76.37513733, 9.86736202], [76.37486267, 9.86736202], [76.37486267, 9.86765099], [76.37458038, 9.86765099], [76.37458038, 9.86791992], [76.37430573, 9.86791801], [76.37430573, 9.8684721], [76.37374878, 9.8684721], [76.37374878, 9.86958408], [76.37347412, 9.86958408], [76.37347412, 9.8698597], [76.37319946, 9.8698597], [76.37319946, 9.87014008], [76.37291718, 9.87014008], [76.37291718, 9.87069416], [76.37264252, 9.87068939], [76.37264252, 9.87181091], [76.37291718, 9.87180614], [76.37291718, 9.87208366], [76.37264252, 9.87207985], [76.37264252, 9.87263966], [76.37236023, 9.87263966], [76.37236023, 9.87514114], [76.37208557, 9.87513828], [76.37208557, 9.87625122], [76.37180328, 9.87625122], [76.37180328, 9.87681961], [76.37152863, 9.87680435], [76.37152863, 9.87736034], [76.37124634, 9.87736034], [76.37124634, 9.8779211], [76.37097168, 9.87791729], [76.37097168, 9.87819481], [76.37069702, 9.87819481], [76.37069702, 9.87847328], [76.3704071, 9.87847042], [76.3704071, 9.87903118], [76.37013245, 9.87903118], [76.37014008, 9.87986088], [76.36985779, 9.87986088], [76.36985779, 9.88014126], [76.36930847, 9.88013935], [76.36930847, 9.88069534], [76.36902618, 9.88069534], [76.36902618, 9.88097286], [76.36875153, 9.88097095], [76.36875153, 9.88152885], [76.36846924, 9.88152885], [76.36846924, 9.88236141], [76.36791992, 9.88236141], [76.36791992, 9.88291931], [76.36763763, 9.8829174], [76.36763763, 9.88319016], [76.36736298, 9.88319969], [76.36736298, 9.88375092], [76.36708069, 9.88374901], [76.36708069, 9.88458347], [76.36680603, 9.88458061], [76.36680603, 9.88541889], [76.36653137, 9.88541889], [76.36653137, 9.88624859], [76.36624908, 9.88625145], [76.36624908, 9.88708305], [76.3659668, 9.88708115], [76.3659668, 9.88792038], [76.36569214, 9.88792038], [76.36569214, 9.88876057], [76.36541748, 9.88874912], [76.36541748, 9.88986206], [76.36514282, 9.8898592], [76.36514282, 9.89153194], [76.36486053, 9.89152813], [76.36486053, 9.89208412], [76.36458588, 9.89208126], [76.36458588, 9.89264202], [76.36430359, 9.89264011], [76.36430359, 9.8931942], [76.36402893, 9.8931942], [76.36402893, 9.89347172], [76.36374664, 9.89347172], [76.36374664, 9.89375019], [76.36347198, 9.89375019], [76.36347198, 9.89402962], [76.36319733, 9.89402962], [76.36319733, 9.89431], [76.36291504, 9.89430618], [76.36291504, 9.89486217], [76.36264038, 9.89486027], [76.36264038, 9.89542007], [76.36235809, 9.89541626], [76.36235809, 9.89569378], [76.36207581, 9.89569187], [76.36207581, 9.89625168], [76.36180878, 9.89625168], [76.36180878, 9.89681053], [76.36152649, 9.89680576], [76.36152649, 9.89735985], [76.36125946, 9.89735985], [76.36125946, 9.89792061], [76.36096954, 9.89791584], [76.36096954, 9.89875031], [76.36069489, 9.89875031], [76.36069489, 9.89958191], [76.36042023, 9.89958191], [76.36042023, 9.90014267], [76.36013794, 9.9001379], [76.36013794, 9.90097237], [76.35986328, 9.90097046], [76.35986328, 9.90181065], [76.35958099, 9.90180588], [76.35958099, 9.90235996], [76.35930634, 9.90235996], [76.35930634, 9.9026413], [76.35901642, 9.9026413], [76.35901642, 9.90292072], [76.35874939, 9.90291595], [76.35874939, 9.9034729], [76.3584671, 9.90347004], [76.3584671, 9.90376186], [76.35819244, 9.90376186], [76.35819244, 9.90431118], [76.35791779, 9.90430355], [76.35791779, 9.90486145], [76.35764313, 9.90486145], [76.35764313, 9.90542126], [76.35736084, 9.90541744], [76.35736084, 9.90597343], [76.35708618, 9.90596962], [76.35708618, 9.90653133], [76.35680389, 9.90652657], [76.35680389, 9.90708256], [76.35652924, 9.90708256], [76.35652924, 9.90736103], [76.35624695, 9.90736103], [76.35624695, 9.90792084], [76.35597229, 9.90791702], [76.35597229, 9.90819454], [76.35569763, 9.90819454], [76.35569763, 9.90847301], [76.35542297, 9.90847111], [76.35542297, 9.90903091], [76.35513306, 9.90903091], [76.35513306, 9.90930939], [76.3548584, 9.90930462], [76.3548584, 9.90958309], [76.35457611, 9.90957069], [76.35457611, 9.91014099], [76.35430908, 9.91014099], [76.35430908, 9.91041946], [76.35402679, 9.9104166], [76.35402679, 9.91069508], [76.35346985, 9.91069508], [76.35346985, 9.9109726], [76.35320282, 9.91097069], [76.35320282, 9.91125107], [76.35263824, 9.91125107], [76.35263824, 9.9115324], [76.35235596, 9.9115324], [76.35235596, 9.91181183], [76.35180664, 9.91180515], [76.35180664, 9.91208267], [76.35152435, 9.91208267], [76.35152435, 9.91236115], [76.34625244, 9.91236115], [76.34625244, 9.91180515], [76.34597015, 9.91181183], [76.34597015, 9.91125107], [76.34570312, 9.91125107], [76.34570312, 9.91069126], [76.34541321, 9.91069508], [76.34541321, 9.91013908], [76.34485626, 9.91014099], [76.34485626, 9.91041946], [76.34402466, 9.9104166], [76.34402466, 9.91069508], [76.34430695, 9.91069126], [76.34430695, 9.91181183], [76.3445816, 9.91180515], [76.3445816, 9.91236115], [76.34430695, 9.91236115], [76.34430695, 9.91375065], [76.34401703, 9.91375065], [76.34401703, 9.91403198], [76.34375, 9.91402721], [76.34375, 9.91486073], [76.34401703, 9.91486073], [76.34402466, 9.91624928], [76.34375, 9.91624928], [76.34375, 9.91652966], [76.34319305, 9.91652679], [76.34319305, 9.91708374], [76.3429184, 9.91708374], [76.3429184, 9.91736221], [76.34263611, 9.91735935], [76.34263611, 9.91763973], [76.3418045, 9.91763973], [76.3418045, 9.91819572], [76.34124756, 9.91819572], [76.34124756, 9.91847229], [76.3409729, 9.91847229], [76.3409729, 9.91874981], [76.34041595, 9.91874027], [76.34041595, 9.91903019], [76.3401413, 9.91902828], [76.3401413, 9.91958427], [76.33680725, 9.91958427], [76.33680725, 9.91624928], [76.33651733, 9.91624928], [76.33651733, 9.91596889], [76.33625031, 9.9159708], [76.33625031, 9.91569328], [76.33598328, 9.91569996], [76.33598328, 9.91541958], [76.33569336, 9.91541958], [76.33569336, 9.91569996], [76.3354187, 9.91569328], [76.3354187, 9.9159708], [76.33403015, 9.91597366], [76.33403015, 9.91624928], [76.3326416, 9.91624928], [76.3326416, 9.91597366], [76.33235931, 9.9159708], [76.33235931, 9.91569328], [76.33207703, 9.91569996], [76.33207703, 9.91541958], [76.33152771, 9.91541958], [76.33152771, 9.9151392], [76.33096313, 9.9151392], [76.33096313, 9.91486073], [76.33040619, 9.91486073], [76.33040619, 9.9145813], [76.33013153, 9.9145813], [76.32930756, 9.91458321], [76.32930756, 9.91486073], [76.32875061, 9.91486073], [76.32875061, 9.9151392], [76.32818604, 9.9151392], [76.32818604, 9.91541958], [76.32763672, 9.91541958], [76.32763672, 9.91569996], [76.32457733, 9.91569996], [76.32457733, 9.91541958], [76.32402802, 9.91541958], [76.32402802, 9.91486073], [76.32375336, 9.91486073], [76.32375336, 9.91430473], [76.32402802, 9.91431046], [76.32402802, 9.91375065], [76.32430267, 9.91375065], [76.32430267, 9.91347122], [76.32485962, 9.91347122], [76.32485962, 9.91375065], [76.32514954, 9.91375065], [76.32514954, 9.91403198], [76.32541656, 9.91402721], [76.32541656, 9.91458321], [76.32569122, 9.91458321], [76.32569122, 9.91486073], [76.32681274, 9.91486073], [76.32681274, 9.9151392], [76.32707977, 9.9151392], [76.32707977, 9.91486073], [76.32736206, 9.91486073], [76.32736206, 9.91458321], [76.32791901, 9.91458321], [76.32791901, 9.91430473], [76.32818604, 9.91431046], [76.32818604, 9.91375065], [76.32847595, 9.91375065], [76.32847595, 9.91347122], [76.32902527, 9.91347122], [76.32902527, 9.91319466], [76.33069611, 9.91319466], [76.33069611, 9.91347122], [76.33125305, 9.91347122], [76.33125305, 9.91375065], [76.33180237, 9.91375065], [76.33180237, 9.91403198], [76.3326416, 9.91403198], [76.3326416, 9.91347122], [76.33291626, 9.91347122], [76.33291626, 9.91319466], [76.33319092, 9.91319466], [76.33319092, 9.91291714], [76.33347321, 9.91292191], [76.33347321, 9.91236115], [76.33374786, 9.91236115], [76.33374786, 9.91069508], [76.33403015, 9.91069508], [76.33403015, 9.90930462], [76.33429718, 9.90930939], [76.33429718, 9.90818977], [76.3345871, 9.90819454], [76.3345871, 9.90680695], [76.33486176, 9.90680695], [76.33486176, 9.90625095], [76.33513641, 9.90625095], [76.33513641, 9.90542126], [76.3354187, 9.90542126], [76.3354187, 9.9049902], [76.3354187, 9.90458202], [76.33569336, 9.90458202], [76.33569336, 9.90402889], [76.33598328, 9.9040308], [76.33598328, 9.90347004], [76.33702087, 9.90347004], [76.34069061, 9.9034729], [76.34069824, 9.90319443], [76.3409729, 9.90319443], [76.3409729, 9.90291595], [76.34124756, 9.90292072], [76.34124756, 9.90224171], [76.34124756, 9.90180588], [76.34069824, 9.90181065], [76.34069061, 9.90153122], [76.34012604, 9.90153122], [76.34012604, 9.90125275], [76.33985901, 9.90125275], [76.33985901, 9.90070057], [76.33957672, 9.90070057], [76.33957672, 9.90042114], [76.33930206, 9.90042114], [76.33930206, 9.89958191], [76.33958435, 9.89958191], [76.33958435, 9.8993063], [76.34069061, 9.89931107], [76.34069824, 9.89902973], [76.3409729, 9.89902973], [76.3409729, 9.89846992], [76.34124756, 9.89847183], [76.34124756, 9.89791584], [76.3409729, 9.89792061], [76.3409729, 9.89625168], [76.34069824, 9.89625168], [76.34069061, 9.89513969], [76.34041595, 9.89513969], [76.34041595, 9.89375019], [76.34012604, 9.89375019], [76.34012604, 9.89208126], [76.34041595, 9.89208412], [76.34041595, 9.89041805], [76.34069061, 9.89041996], [76.34069824, 9.8898592], [76.34124756, 9.88986206], [76.34124756, 9.88958263], [76.34152985, 9.88958263], [76.34152985, 9.88930511], [76.34208679, 9.88931179], [76.34208679, 9.88903046], [76.34236145, 9.88903046], [76.34236145, 9.88876057], [76.34263611, 9.88876057], [76.34263611, 9.88819122], [76.3429184, 9.88819313], [76.3429184, 9.88763905], [76.34319305, 9.88764191], [76.34319305, 9.88514137], [76.34263611, 9.88514137], [76.34263611, 9.88486099], [76.34179688, 9.88486099], [76.34179688, 9.88458061], [76.3409729, 9.88458347], [76.3409729, 9.884305], [76.33985901, 9.884305], [76.33985901, 9.88458347], [76.33930206, 9.88458347], [76.33930206, 9.88486099], [76.33875275, 9.88486099], [76.33875275, 9.88514137], [76.33847046, 9.88514137], [76.33847046, 9.88541889], [76.3381958, 9.88541698], [76.3381958, 9.88597107], [76.33790588, 9.88597107], [76.33791351, 9.88624859], [76.33763885, 9.88625145], [76.33763885, 9.88653183], [76.3373642, 9.88652706], [76.3373642, 9.88708305], [76.33708191, 9.88708305], [76.33708191, 9.88736057], [76.33680725, 9.88736057], [76.33680725, 9.88792038], [76.33652496, 9.88791656], [76.33652496, 9.88847446], [76.33569336, 9.88847065], [76.33569336, 9.88876057], [76.33513641, 9.88876057], [76.33513641, 9.88903046], [76.33486176, 9.88903046], [76.33486176, 9.88931179], [76.3345871, 9.88930511], [76.3345871, 9.88986206], [76.33486176, 9.88986206], [76.33486176, 9.89002991], [76.33486938, 9.89013958], [76.33513641, 9.89013958], [76.33513641, 9.89041996], [76.33569336, 9.89041805], [76.33569336, 9.89069557], [76.33597565, 9.89069557], [76.33597565, 9.89097118], [76.33625031, 9.89096928], [76.33625031, 9.89264202], [76.33651733, 9.89264202], [76.33652496, 9.89375019], [76.33625031, 9.89375019], [76.33625031, 9.8945837], [76.33598328, 9.89457035], [76.33598328, 9.89542007], [76.33569336, 9.89541626], [76.33569336, 9.89597225], [76.3345871, 9.89597225], [76.3345871, 9.89569378], [76.33291626, 9.89569187], [76.33291626, 9.89625168], [76.3326416, 9.89625168], [76.3326416, 9.89681053], [76.33235931, 9.89680576], [76.33235931, 9.89735985], [76.33207703, 9.89735985], [76.33207703, 9.89792061], [76.33180237, 9.89791584], [76.33180237, 9.89847183], [76.33152771, 9.89846992], [76.33152771, 9.89902973], [76.33125305, 9.89902973], [76.33125305, 9.89931107], [76.33097076, 9.8993063], [76.33097076, 9.89986229], [76.33069611, 9.89986038], [76.33069611, 9.90070057], [76.33040619, 9.90070057], [76.33040619, 9.90153122], [76.33013916, 9.90153122], [76.33013916, 9.90181065], [76.3298645, 9.90180588], [76.3298645, 9.9020853], [76.32958221, 9.90207958], [76.32958221, 9.9026413], [76.32930756, 9.9026413], [76.32930756, 9.90292072], [76.32875061, 9.90292072], [76.32875061, 9.90207958], [76.32902527, 9.9020853], [76.32902527, 9.90124989], [76.32930756, 9.90125275], [76.32930756, 9.90070057], [76.32958221, 9.90070057], [76.32958221, 9.89986038], [76.3298645, 9.89986229], [76.3298645, 9.8993063], [76.33013916, 9.89931107], [76.33013916, 9.89875031], [76.33041382, 9.89875031], [76.33040619, 9.89818859], [76.33069611, 9.89819431], [76.33069611, 9.89764023], [76.33097076, 9.89764023], [76.33097076, 9.89708424], [76.33125305, 9.89708424], [76.33125305, 9.89652824], [76.33152771, 9.89653015], [76.33152771, 9.89597034], [76.33180237, 9.89597225], [76.33180237, 9.89569378], [76.33208466, 9.89569378], [76.33208466, 9.89541626], [76.3326416, 9.89542007], [76.3326416, 9.89486027], [76.33291626, 9.89486217], [76.33291626, 9.89464092], [76.33291626, 9.89430618], [76.33319092, 9.89431], [76.33319092, 9.89375019], [76.33347321, 9.89375019], [76.33347321, 9.89347172], [76.33319092, 9.89347172], [76.33319092, 9.89291573], [76.33291626, 9.89291954], [76.33291626, 9.89236164], [76.3326416, 9.89236164], [76.3326416, 9.89069557], [76.33291626, 9.89069557], [76.33291626, 9.88902664], [76.33319092, 9.88903046], [76.33319092, 9.88847065], [76.33347321, 9.88847446], [76.33347321, 9.88830853], [76.33347321, 9.88791656], [76.33374786, 9.88792038], [76.33374786, 9.88736057], [76.33403015, 9.88736057], [76.33403015, 9.88708305], [76.33430481, 9.88708305], [76.33430481, 9.88652706], [76.3345871, 9.88653183], [76.3345871, 9.88597107], [76.3354187, 9.88597107], [76.3354187, 9.88541698], [76.33569336, 9.88541889], [76.33569336, 9.88458061], [76.3354187, 9.88458347], [76.3354187, 9.88402653], [76.33513641, 9.88402939], [76.33513641, 9.88375092], [76.33429718, 9.88375092], [76.33429718, 9.88347054], [76.33403015, 9.8834734], [76.33403015, 9.88319492], [76.33347321, 9.88319492], [76.33347321, 9.8829174], [76.33328247, 9.8829174], [76.33291626, 9.88291931], [76.33291626, 9.88263035], [76.3326416, 9.88263035], [76.3326416, 9.88291931], [76.33235931, 9.88291931], [76.33235931, 9.88263035], [76.33180237, 9.88263893], [76.33180237, 9.88236141], [76.33152771, 9.88236141], [76.33152771, 9.88208294], [76.33069611, 9.88208294], [76.33069611, 9.88236141], [76.33013916, 9.88236141], [76.33013916, 9.88263893], [76.32958221, 9.88263035], [76.32958221, 9.88291931], [76.32930756, 9.8829174], [76.32930756, 9.88319016], [76.3290329, 9.88319969], [76.3290329, 9.88375092], [76.32847595, 9.88375092], [76.32847595, 9.88402939], [76.32818604, 9.88402939], [76.32818604, 9.88431168], [76.32791901, 9.884305], [76.32791901, 9.88486099], [76.32763672, 9.88486099], [76.32763672, 9.88541889], [76.32736206, 9.88541698], [76.32736206, 9.88597107], [76.32707977, 9.88597107], [76.32707977, 9.88624859], [76.32624817, 9.88625145], [76.32624817, 9.88653183], [76.32569122, 9.88653183], [76.32569122, 9.8868103], [76.32514191, 9.88680458], [76.32514191, 9.88708305], [76.32485962, 9.88708305], [76.32485962, 9.88736057], [76.32457733, 9.88736057], [76.32457733, 9.88764191], [76.32430267, 9.88764191], [76.32430267, 9.88792038], [76.32402802, 9.88791656], [76.32402802, 9.88819313], [76.32375336, 9.88819313], [76.32375336, 9.88847446], [76.32209015, 9.88847065], [76.32209015, 9.88876057], [76.3215332, 9.88876057], [76.3215332, 9.88903046], [76.31931305, 9.88903046], [76.31931305, 9.88876057], [76.31874847, 9.88876057], [76.31874847, 9.88931179], [76.31846619, 9.88931179], [76.31846619, 9.89013958], [76.31874847, 9.89013958], [76.31874847, 9.89069557], [76.31930542, 9.89069557], [76.31930542, 9.89097118], [76.31958008, 9.89096928], [76.31958008, 9.89124966], [76.32125092, 9.89124966], [76.32125092, 9.89182186], [76.32152557, 9.89180565], [76.32152557, 9.89236164], [76.32096863, 9.89236164], [76.32096863, 9.89264202], [76.32041931, 9.89264202], [76.32041931, 9.89291954], [76.31958008, 9.89291573], [76.31958008, 9.8931942], [76.31791687, 9.8931942], [76.31791687, 9.89347172], [76.31764221, 9.89346886], [76.31764221, 9.89402962], [76.31735992, 9.89402962], [76.31735992, 9.89431], [76.31708527, 9.89430618], [76.31708527, 9.89569378], [76.31680298, 9.89569378], [76.31680298, 9.89708424], [76.31735992, 9.89708424], [76.31735992, 9.89735985], [76.31764221, 9.89735985], [76.31764221, 9.89764023], [76.31791687, 9.89764023], [76.31791687, 9.89819431], [76.31819153, 9.89819431], [76.31819153, 9.89847183], [76.31846619, 9.89846992], [76.31846619, 9.89875031], [76.31874847, 9.89875031], [76.31874847, 9.89986229], [76.31846619, 9.89986038], [76.31846619, 9.90042114], [76.31819153, 9.90041637], [76.31819153, 9.9020853], [76.31791687, 9.90207958], [76.31791687, 9.90292072], [76.31764221, 9.90291595], [76.31764221, 9.9034729], [76.31735992, 9.90347004], [76.31735992, 9.90376186], [76.3170929, 9.90376186], [76.3170929, 9.90431118], [76.31680298, 9.90430355], [76.31680298, 9.90458202], [76.31652832, 9.90458202], [76.31652832, 9.90486145], [76.31624603, 9.90486145], [76.31624603, 9.90514088], [76.31569672, 9.90514088], [76.31569672, 9.90542126], [76.31541443, 9.90541744], [76.31541443, 9.90569496], [76.31513977, 9.90569496], [76.31513977, 9.90597343], [76.31485748, 9.90596962], [76.31485748, 9.90653133], [76.31458282, 9.90652657], [76.31458282, 9.90680695], [76.31430817, 9.90680695], [76.31430817, 9.90708256], [76.31402588, 9.9070797], [76.31402588, 9.90764141], [76.31375122, 9.90763855], [76.31375122, 9.90819454], [76.31346893, 9.90818977], [76.31346893, 9.90875053], [76.31318665, 9.90875053], [76.31318665, 9.91041946], [76.31346893, 9.9104166], [76.31346893, 9.91069508], [76.31375122, 9.91069508], [76.31375122, 9.9109726], [76.31458282, 9.9109726], [76.31458282, 9.91208267], [76.31430817, 9.91208267], [76.31430817, 9.91319466], [76.31402588, 9.91319084], [76.31402588, 9.91375065], [76.31375122, 9.91374874], [76.31375122, 9.91458321], [76.31346893, 9.9145813], [76.31346893, 9.91541958], [76.31319427, 9.91541672], [76.31319427, 9.9159708], [76.31291962, 9.91596889], [76.31291962, 9.91652966], [76.31263733, 9.91652679], [76.31263733, 9.91708374], [76.31208038, 9.91708374], [76.31208038, 9.91736221], [76.31181335, 9.91735935], [76.31181335, 9.91763973], [76.31124878, 9.91763973], [76.31124878, 9.91792011], [76.31097412, 9.91791534], [76.31097412, 9.91874981], [76.31069183, 9.91874981], [76.31069183, 9.92069435], [76.31041718, 9.92069435], [76.31041718, 9.92208385], [76.31014252, 9.92208385], [76.31014252, 9.92236233], [76.30986023, 9.92236042], [76.30986023, 9.92263985], [76.3095932, 9.92263985], [76.3095932, 9.92292023], [76.30930328, 9.92291641], [76.30930328, 9.9234724], [76.30902863, 9.92346954], [76.30902863, 9.9240303], [76.30874634, 9.9240284], [76.30874634, 9.92486], [76.30847168, 9.92486], [76.30847168, 9.92542076], [76.30819702, 9.92541599], [76.30819702, 9.92625046], [76.30791473, 9.92625046], [76.30791473, 9.92708206], [76.30764008, 9.92708015], [76.30764008, 9.92763996], [76.30735779, 9.92763805], [76.30735779, 9.92819405], [76.30708313, 9.92819405], [76.30708313, 9.92847157], [76.30680847, 9.92846966], [76.30680847, 9.92903137], [76.30652618, 9.92902756], [76.30652618, 9.92958546], [76.30625153, 9.92958546], [76.30625153, 9.92986012], [76.30596924, 9.92986012], [76.30596924, 9.93042088], [76.30569458, 9.93041611], [76.30569458, 9.93069458], [76.30541992, 9.93068123], [76.30541992, 9.93125057], [76.30513763, 9.93125057], [76.30513763, 9.93181133], [76.30486298, 9.93180656], [76.30486298, 9.93236065], [76.30458069, 9.93236065], [76.30458069, 9.93319511], [76.30430603, 9.93319035], [76.30430603, 9.93431091], [76.30403137, 9.93430519], [76.30403137, 9.93486118], [76.30430603, 9.93486118], [76.30430603, 9.93514061], [76.30458069, 9.93514061], [76.30458069, 9.93542099], [76.30486298, 9.93541718], [76.30486298, 9.93569469], [76.30513763, 9.93569469], [76.30513763, 9.93597317], [76.30541992, 9.93597126], [76.30541992, 9.93653107], [76.30569458, 9.93652916], [76.30569458, 9.93736076], [76.30541992, 9.93736076], [76.30541992, 9.93762112], [76.30541992, 9.93847084], [76.30513763, 9.93847084], [76.30513763, 9.93958282], [76.30486298, 9.93958282], [76.30486298, 9.94069481], [76.30541992, 9.94069481], [76.30541992, 9.94347095], [76.30568695, 9.94347095], [76.30568695, 9.94374943], [76.30596924, 9.94374943], [76.30596924, 9.94402981], [76.30652618, 9.94402981], [76.30652618, 9.94431019], [76.30680847, 9.94430637], [76.30680847, 9.94486237], [76.30725861, 9.94485855], [76.30764008, 9.94485855], [76.30764008, 9.94514179], [76.3079071, 9.94514179], [76.3079071, 9.94485855], [76.30819702, 9.94485855], [76.30819702, 9.94514179], [76.30902863, 9.94514179], [76.30902863, 9.94542027], [76.31041718, 9.94541454], [76.31041718, 9.94569302], [76.31096649, 9.94567966], [76.31096649, 9.94625187], [76.31124878, 9.94625187], [76.31124878, 9.94764042], [76.31153107, 9.94763756], [76.31153107, 9.94847202], [76.31096649, 9.94847202], [76.31096649, 9.9493103], [76.31069183, 9.94930553], [76.31069183, 9.94958401], [76.30986023, 9.94958401], [76.30986023, 9.94930553], [76.30874634, 9.9493103], [76.30874634, 9.94902992], [76.30819702, 9.94902992], [76.30819702, 9.94847202], [76.30791473, 9.94847202], [76.30791473, 9.94791794], [76.30764008, 9.94791985], [76.30764008, 9.94708061], [76.30735779, 9.94708443], [76.30735779, 9.94624996], [76.30684662, 9.94624996], [76.30541992, 9.94625187], [76.30541992, 9.94597244], [76.30513763, 9.94597244], [76.30513763, 9.94513988], [76.30486298, 9.94514179], [76.30486298, 9.94374943], [76.30458069, 9.94374943], [76.30458069, 9.94263935], [76.30430603, 9.94263935], [76.30430603, 9.94153023], [76.30401611, 9.94153023], [76.30401611, 9.93875122], [76.30430603, 9.93875122], [76.30430603, 9.93763924], [76.30458069, 9.93764114], [76.30458069, 9.93714046], [76.30458069, 9.93680477], [76.30430603, 9.93680859], [76.30430603, 9.93625069], [76.30401611, 9.93625069], [76.30401611, 9.93597126], [76.3034668, 9.93597126], [76.3034668, 9.93625069], [76.30319214, 9.93625069], [76.30319214, 9.93653107], [76.30264282, 9.93653107], [76.30264282, 9.93680859], [76.30236053, 9.93680477], [76.30236053, 9.93708324], [76.30208588, 9.93708324], [76.30208588, 9.93736076], [76.30041504, 9.93736076], [76.30041504, 9.93680477], [76.30014038, 9.93680859], [76.30014038, 9.93597126], [76.30041504, 9.93597317], [76.30041504, 9.93541718], [76.30069733, 9.93542099], [76.30069733, 9.93494129], [76.30069733, 9.93486118], [76.30097961, 9.93486118], [76.30097198, 9.93402672], [76.30124664, 9.93403053], [76.30124664, 9.93292141], [76.30152893, 9.93292141], [76.30152893, 9.93208027], [76.30180359, 9.93208218], [76.30180359, 9.93152905], [76.30208588, 9.93153095], [76.30208588, 9.93125057], [76.30236053, 9.93125057], [76.30236053, 9.93097019], [76.30263519, 9.93097305], [76.30263519, 9.93041611], [76.30291748, 9.93042088], [76.30291748, 9.93014145], [76.30319214, 9.93014145], [76.30319214, 9.92986012], [76.30347443, 9.92986012], [76.3034668, 9.92957973], [76.30374908, 9.92958546], [76.30374908, 9.92930698], [76.30430603, 9.92930889], [76.30430603, 9.92903137], [76.30458069, 9.92903137], [76.30458069, 9.92597198], [76.30430603, 9.92597198], [76.30430603, 9.92569447], [76.30347443, 9.92569447], [76.30347443, 9.92597198], [76.30319214, 9.92597198], [76.30319214, 9.92625046], [76.30264282, 9.92625046], [76.30264282, 9.92653275], [76.30236053, 9.92653275], [76.30236053, 9.92681122], [76.30180359, 9.92680645], [76.30180359, 9.92708206], [76.30124664, 9.92708015], [76.30124664, 9.92793179], [76.30097198, 9.92791557], [76.30097198, 9.92819405], [76.30069733, 9.92819405], [76.30069733, 9.92847157], [76.30042267, 9.92846966], [76.30042267, 9.92903137], [76.30014038, 9.92903137], [76.30014038, 9.92930889], [76.29985809, 9.92930698], [76.29985809, 9.92986012], [76.29957581, 9.92986012], [76.29957581, 9.93014145], [76.29930878, 9.93013763], [76.29930878, 9.93069458], [76.29902649, 9.93068123], [76.29902649, 9.93125057], [76.29875183, 9.93125057], [76.29872131, 9.93153095], [76.29846954, 9.93152905], [76.29846954, 9.93208218], [76.29818726, 9.93208027], [76.29818726, 9.93264103], [76.29792023, 9.93263912], [76.29792023, 9.93319511], [76.29763794, 9.93319511], [76.29763794, 9.93375111], [76.29736328, 9.93374157], [76.29736328, 9.93403053], [76.29708099, 9.93402672], [76.29708099, 9.93458271], [76.29680634, 9.93458271], [76.29680634, 9.93486118], [76.29651642, 9.93486118], [76.29651642, 9.93542099], [76.29624939, 9.93541718], [76.29624939, 9.93597317], [76.2959671, 9.93597126], [76.2959671, 9.93625069], [76.29569244, 9.93625069], [76.29569244, 9.93680859], [76.29541779, 9.93680477], [76.29541779, 9.93708324], [76.29514313, 9.93708134], [76.29514313, 9.93764114], [76.29485321, 9.93764114], [76.29485321, 9.93792152], [76.29458618, 9.93791676], [76.29458618, 9.93847084], [76.29430389, 9.93847084], [76.29429626, 9.93904972], [76.29429626, 9.93931198], [76.29402924, 9.93931198], [76.29402924, 9.93987274], [76.29374695, 9.93987274], [76.29374695, 9.94042015], [76.29347229, 9.94041729], [76.29347229, 9.94097328], [76.29319763, 9.94097137], [76.29319763, 9.94153023], [76.29291534, 9.94152737], [76.29291534, 9.94208336], [76.29264069, 9.94208145], [76.29264069, 9.94293118], [76.2923584, 9.94291782], [76.2923584, 9.94374943], [76.29207611, 9.94374943], [76.29207611, 9.94431019], [76.29180908, 9.94431019], [76.29180908, 9.94514179], [76.29152679, 9.94513988], [76.29152679, 9.94567966], [76.29125214, 9.94569969], [76.29125214, 9.94625187], [76.29096985, 9.94625187], [76.29096985, 9.94680977], [76.29069519, 9.94680595], [76.29069519, 9.94736195], [76.2904129, 9.94736195], [76.2904129, 9.94791985], [76.29013824, 9.94791794], [76.29013824, 9.94847202], [76.28985596, 9.94847202], [76.28985596, 9.94902992], [76.2895813, 9.94902802], [76.2895813, 9.94958401], [76.28930664, 9.94958401], [76.28930664, 9.94986153], [76.28901672, 9.94985962], [76.28901672, 9.95042038], [76.28874969, 9.95041561], [76.28874969, 9.95069408], [76.28848267, 9.95068932], [76.28848267, 9.95125008], [76.28819275, 9.95125008], [76.28819275, 9.95181084], [76.28791809, 9.95180607], [76.28791809, 9.95208359], [76.2876358, 9.95208168], [76.2876358, 9.95263958], [76.28736115, 9.95263767], [76.28736115, 9.95319366], [76.28708649, 9.95319366], [76.28708649, 9.95347214], [76.28679657, 9.95347023], [76.28679657, 9.95403099], [76.28652954, 9.95402813], [76.28652954, 9.95458221], [76.28624725, 9.95458031], [76.28624725, 9.95514107], [76.2859726, 9.95513821], [76.2859726, 9.9556942], [76.28569794, 9.9556942], [76.28569794, 9.95625019], [76.28542328, 9.95625019], [76.28542328, 9.95681095], [76.28458405, 9.95680428], [76.28458405, 9.95708466], [76.28430939, 9.95707989], [76.28430176, 9.95764065], [76.2840271, 9.95763779], [76.2840271, 9.9598608], [76.28375244, 9.9598608], [76.28375244, 9.96069527], [76.28347015, 9.96069527], [76.28347015, 9.96125126], [76.2831955, 9.96125126], [76.2831955, 9.96208286], [76.28291321, 9.96208], [76.28291321, 9.96291924], [76.28263855, 9.96291733], [76.28263855, 9.96347332], [76.28235626, 9.96347141], [76.28235626, 9.9643116], [76.2820816, 9.96430492], [76.2820816, 9.96486092], [76.28180695, 9.96486092], [76.28180695, 9.96569538], [76.28151703, 9.96569061], [76.28152466, 9.96625137], [76.28125, 9.96625137], [76.28125, 9.96681023], [76.28097534, 9.96680546], [76.28097534, 9.96736145], [76.28069305, 9.96736145], [76.28069305, 9.9679203], [76.2804184, 9.96791744], [76.2804184, 9.96847343], [76.28013611, 9.96847057], [76.28013611, 9.96903038], [76.27986145, 9.96902657], [76.27986145, 9.96958256], [76.27958679, 9.96958065], [76.27958679, 9.97014046], [76.2793045, 9.97014046], [76.2793045, 9.97069645], [76.27902985, 9.97069073], [76.27902985, 9.97124863], [76.27874756, 9.97124863], [76.27874756, 9.97208405], [76.2784729, 9.97208118], [76.2784729, 9.97264194], [76.27819824, 9.97264004], [76.27819824, 9.97347164], [76.27791595, 9.97347164], [76.27791595, 9.97402954], [76.2776413, 9.97402763], [76.2776413, 9.97458363], [76.27735901, 9.97457886], [76.27735901, 9.97542], [76.27707672, 9.97542], [76.27707672, 9.97598076], [76.27680969, 9.97598076], [76.27680969, 9.97653008], [76.2765274, 9.97652817], [76.2765274, 9.97708416], [76.27625275, 9.97707939], [76.27625275, 9.97764015], [76.27597046, 9.97764015], [76.27597046, 9.97819424], [76.2756958, 9.97819424], [76.2756958, 9.97875023], [76.27540588, 9.97875023], [76.27540588, 9.97931099], [76.27513885, 9.97930622], [76.27513885, 9.97986221], [76.27485657, 9.97986031], [76.27485657, 9.98042107], [76.27458191, 9.9804163], [76.27458191, 9.98097229], [76.27430725, 9.98097038], [76.27430725, 9.98153114], [76.27402496, 9.98152828], [76.27402496, 9.98208427], [76.27348328, 9.98208046], [76.27348328, 9.98236275], [76.27319336, 9.98236275], [76.27319336, 9.98292065], [76.2729187, 9.98291588], [76.2729187, 9.98319435], [76.27263641, 9.98318958], [76.27263641, 9.98403072], [76.27236176, 9.98402882], [76.27236176, 9.98458195], [76.2720871, 9.98458004], [76.2720871, 9.98542118], [76.27180481, 9.98541737], [76.27180481, 9.98569489], [76.27153015, 9.98569489], [76.27153015, 9.98708344], [76.27124786, 9.98707962], [76.27124786, 9.98764133], [76.27097321, 9.98764133], [76.27097321, 9.98791885], [76.27069092, 9.98791695], [76.27069092, 9.98847294], [76.27041626, 9.98847103], [76.27041626, 9.98903084], [76.2701416, 9.98903084], [76.2701416, 9.98930931], [76.26985931, 9.98930454], [76.26985931, 9.98958302], [76.2701416, 9.98958302], [76.2701416, 9.990695], [76.27041626, 9.99069023], [76.27041626, 9.99180984], [76.27097321, 9.99180508], [76.27097321, 9.9920826], [76.27153015, 9.9920826], [76.27153015, 9.99236107], [76.2720871, 9.99236107], [76.2720871, 9.99292183], [76.27236176, 9.99291706], [76.27236176, 9.99347115], [76.27263641, 9.99347115], [76.27263641, 9.99375057], [76.27236176, 9.99374866], [76.27236176, 9.99402714], [76.27263641, 9.99402046], [76.27263641, 9.99542046], [76.2729187, 9.99541664], [76.2729187, 9.99597359], [76.27319336, 9.99597073], [76.27319336, 9.99652958], [76.27348328, 9.99652958], [76.27348328, 9.99680996], [76.27375031, 9.99680519], [76.27375031, 9.99708271], [76.27430725, 9.99708271], [76.27430725, 9.99680519], [76.2756958, 9.99680519], [76.2756958, 9.99708271], [76.27625275, 9.99708271], [76.27625275, 9.99736214], [76.2765274, 9.99735928], [76.2765274, 9.99875164], [76.27625275, 9.99875164], [76.27625275, 9.99903202], [76.27597046, 9.99903202], [76.27597046, 9.99930954], [76.2756958, 9.99930573], [76.2756958, 10.00000095], [76.2756958, 10.00069427], [76.27597046, 10.00069141], [76.27597046, 10.00181007], [76.27625275, 10.00181007], [76.27625275, 10.00292015], [76.27597046, 10.00291634], [76.27597046, 10.00319386], [76.2756958, 10.00319386], [76.2756958, 10.00347233], [76.27540588, 10.00347042], [76.27540588, 10.00431061], [76.27513885, 10.00431061], [76.27513885, 10.00542068], [76.2748642, 10.00541592], [76.2748642, 10.00569439], [76.27458191, 10.00569439], [76.27458191, 10.00625038], [76.27430725, 10.00625038], [76.27430725, 10.00681114], [76.27401733, 10.00681114], [76.27401733, 10.00792122], [76.27375031, 10.00791645], [76.27375031, 10.00902843], [76.27348328, 10.0090189], [76.27348328, 10.00931072], [76.27319336, 10.00930595], [76.27319336, 10.00986004], [76.2729187, 10.00986004], [76.2729187, 10.01014137], [76.27263641, 10.01014137], [76.27263641, 10.01125145], [76.27236176, 10.01125145], [76.27236176, 10.01235962], [76.27263641, 10.01235962], [76.27263641, 10.01542091], [76.27236176, 10.01542091], [76.27236176, 10.01625061], [76.27153015, 10.01625061], [76.27153015, 10.01680946], [76.27124786, 10.01680946], [76.27124786, 10.01764107], [76.27097321, 10.01764107], [76.27097321, 10.0179224], [76.27069092, 10.0179224], [76.27069092, 10.01903152], [76.27041626, 10.01903152], [76.27041626, 10.02014065], [76.2701416, 10.02013874], [76.2701416, 10.02069473], [76.26958466, 10.02069473], [76.26958466, 10.02097321], [76.26902771, 10.02095985], [76.26902771, 10.02125072], [76.26847076, 10.02125072], [76.26847076, 10.02180958], [76.26819611, 10.02180958], [76.26819611, 10.02263927], [76.26790619, 10.02263927], [76.26790619, 10.02402973], [76.26763916, 10.02402687], [76.26763916, 10.02486229], [76.2673645, 10.02486229], [76.2673645, 10.02597141], [76.26708221, 10.02597141], [76.26708221, 10.02709103], [76.26680756, 10.02709103], [76.26680756, 10.02764034], [76.26652527, 10.02764034], [76.26652527, 10.02958393], [76.26680756, 10.02958393], [76.26680756, 10.03069401], [76.2673645, 10.03069401], [76.2673645, 10.03097153], [76.26763916, 10.03096962], [76.26763916, 10.03153038], [76.2673645, 10.03152847], [76.2673645, 10.03208447], [76.26652527, 10.03208447], [76.26652527, 10.03180599], [76.26625061, 10.03181076], [76.26625061, 10.03153038], [76.26568604, 10.03153038], [76.26568604, 10.03125], [76.26513672, 10.03125], [76.26513672, 10.03096962], [76.26346588, 10.03096962], [76.26346588, 10.03153038], [76.26319122, 10.03152847], [76.26319122, 10.03236008], [76.26291656, 10.03236008], [76.26291656, 10.03264046], [76.26264191, 10.03264046], [76.26264191, 10.03292274], [76.26208496, 10.03291607], [76.26208496, 10.03319359], [76.26180267, 10.03319359], [76.26180267, 10.03347206], [76.26152802, 10.03347015], [76.26152802, 10.03374958], [76.26097107, 10.03374958], [76.26097107, 10.03403091], [76.26040649, 10.03403091], [76.26040649, 10.03431129], [76.26013947, 10.03431129], [76.26013947, 10.03403091], [76.25985718, 10.03403091], [76.25985718, 10.03347015], [76.25958252, 10.03347206], [76.25958252, 10.03152847], [76.25985718, 10.03153038], [76.25985718, 10.0304203], [76.25958252, 10.0304203], [76.25958252, 10.03013134], [76.25930786, 10.03013992], [76.25930786, 10.02958393], [76.25902557, 10.02958393], [76.25902557, 10.02902794], [76.25875092, 10.02902985], [76.25875092, 10.02875042], [76.25846863, 10.02875042], [76.25846863, 10.02819443], [76.25819397, 10.02819443], [76.25819397, 10.02791786], [76.25791931, 10.02791977], [76.25791931, 10.02709103], [76.25763702, 10.02709103], [76.25763702, 10.02597141], [76.25736237, 10.02597141], [76.25736237, 10.02319336], [76.25763702, 10.02319336], [76.25763702, 10.0223608], [76.25791931, 10.0223608], [76.25791931, 10.02208328], [76.25819397, 10.02208328], [76.25819397, 10.02152729], [76.25846863, 10.0215292], [76.25846863, 10.02095985], [76.25875092, 10.02097321], [76.25875092, 10.02069473], [76.25902557, 10.02069473], [76.25902557, 10.01986122], [76.25958252, 10.01986122], [76.25958252, 10.01958275], [76.26013947, 10.01958275], [76.26013947, 10.01930523], [76.26040649, 10.0193119], [76.26040649, 10.01847076], [76.26069641, 10.01847076], [76.26069641, 10.01791668], [76.26097107, 10.0179224], [76.26097107, 10.01708126], [76.26125336, 10.01708317], [76.26125336, 10.01652908], [76.26097107, 10.01653099], [76.26097107, 10.01625061], [76.26125336, 10.01625061], [76.26125336, 10.01515007], [76.26152802, 10.01515007], [76.26152802, 10.01486111], [76.26125336, 10.01486111], [76.26125336, 10.01458263], [76.26152802, 10.01458263], [76.26152802, 10.01319504], [76.26180267, 10.01319504], [76.26180267, 10.0120821], [76.26207733, 10.01209164], [76.26207733, 10.0104208], [76.26235962, 10.0104208], [76.26235962, 10.00957966], [76.26264191, 10.00958538], [76.26264191, 10.00763798], [76.26291656, 10.00764275], [76.26291656, 10.00542068], [76.26319122, 10.00542068], [76.26319122, 10.00374985], [76.26347351, 10.00374985], [76.26346588, 10.00319195], [76.26374817, 10.00319386], [76.26374817, 10.00263786], [76.26403046, 10.00263977], [76.26403046, 10.00236034], [76.26430511, 10.00236225], [76.26430511, 10.00152779], [76.26457977, 10.00152969], [76.26457977, 10.00041962], [76.26486969, 10.00041962], [76.26486969, 9.99994087], [76.26486206, 9.99874878], [76.26457977, 9.99875164], [76.26457977, 9.99847126], [76.26486206, 9.99847126], [76.26486206, 9.99708271], [76.26513672, 9.99708271], [76.26513672, 9.99652672], [76.26541901, 9.99652958], [76.26541901, 9.99542046], [76.26568604, 9.99542046], [76.26568604, 9.99514198], [76.26597595, 9.99514198], [76.26597595, 9.99459934], [76.26597595, 9.99341202], [76.26597595, 9.99291706], [76.26625061, 9.99292183], [76.26625061, 9.99180984], [76.2665329, 9.99180984], [76.2665329, 9.99153137], [76.26680756, 9.99153137], [76.26680756, 9.99069023], [76.26708221, 9.990695], [76.26708221, 9.98958302], [76.2673645, 9.98958302], [76.2673645, 9.98847294], [76.26763916, 9.98847294], [76.26763916, 9.98708344], [76.26791382, 9.98708344], [76.26791382, 9.98652554], [76.26819611, 9.98653126], [76.26819611, 9.9843111], [76.26847076, 9.9843111], [76.26847076, 9.9837513], [76.26875305, 9.9837513], [76.26875305, 9.98319435], [76.26847076, 9.98319435], [76.26847076, 9.98291588], [76.26819611, 9.98292065], [76.26819611, 9.98264122], [76.26735687, 9.98264122], [76.26735687, 9.98292065], [76.26680756, 9.98291588], [76.26680756, 9.98319435], [76.26625061, 9.98319435], [76.26625061, 9.98347187], [76.26597595, 9.98346996], [76.26597595, 9.98403072], [76.26569366, 9.98402882], [76.26569366, 9.98486042], [76.26597595, 9.98485088], [76.26597595, 9.9851408], [76.26568604, 9.9851408], [76.26568604, 9.98542118], [76.26541901, 9.98541737], [76.26541901, 9.98736095], [76.26557922, 9.98736095], [76.26568604, 9.98736095], [76.26568604, 9.98791885], [76.26541901, 9.98791695], [76.26541901, 9.98819542], [76.26569366, 9.98819542], [76.26569366, 9.98898125], [76.26569366, 9.98958302], [76.26541901, 9.98958111], [76.26541901, 9.99041939], [76.26513672, 9.99041939], [76.26513672, 9.99098015], [76.26486969, 9.99098015], [76.26486969, 9.99153137], [76.26457977, 9.9915266], [76.26457977, 9.9920826], [76.26431274, 9.99208069], [76.26431274, 9.99292183], [76.26403046, 9.99291706], [76.26403046, 9.99347115], [76.26374817, 9.99347115], [76.26374817, 9.99402714], [76.26346588, 9.99402046], [76.26346588, 9.99431038], [76.26319122, 9.99430466], [76.26319122, 9.99486065], [76.26291656, 9.99486065], [76.26291656, 9.99542046], [76.26264191, 9.99541664], [76.26264191, 9.99597359], [76.26235962, 9.99597073], [76.26235962, 9.99680996], [76.26264191, 9.99680519], [76.26264191, 9.99708271], [76.26235962, 9.99708271], [76.26235962, 9.99736214], [76.26264191, 9.99735928], [76.26264191, 9.99763966], [76.26235962, 9.99763966], [76.26235962, 9.99847126], [76.26207733, 9.99847126], [76.26207733, 9.99903202], [76.26180267, 9.99902821], [76.26180267, 9.9995842], [76.26152802, 9.9995842], [76.26152802, 9.99986172], [76.26125336, 9.99985886], [76.26125336, 10.00015068], [76.26125336, 10.00041962], [76.26097107, 10.00041962], [76.26097107, 10.00152969], [76.26069641, 10.00152969], [76.26069641, 10.00263977], [76.26040649, 10.00263977], [76.26040649, 10.00403023], [76.26013947, 10.00402832], [76.26013947, 10.00500965], [76.26013947, 10.00569439], [76.25985718, 10.00568867], [76.25985718, 10.00653267], [76.25958252, 10.00653267], [76.25958252, 10.00681114], [76.25930786, 10.00681114], [76.25930786, 10.00792122], [76.2590332, 10.00792122], [76.2590332, 10.00874996], [76.25875092, 10.00874996], [76.25875092, 10.00902843], [76.25846863, 10.0090189], [76.25846863, 10.00931072], [76.25875092, 10.00930595], [76.25875092, 10.00986004], [76.25846863, 10.00986004], [76.25846863, 10.0104208], [76.25819397, 10.01041603], [76.25819397, 10.01069355], [76.25791931, 10.01068974], [76.25791931, 10.01125145], [76.25763702, 10.01125145], [76.25763702, 10.01153088], [76.25736237, 10.01153088], [76.25736237, 10.01209164], [76.25708008, 10.01209164], [76.25708008, 10.01264095], [76.25680542, 10.01263905], [76.25680542, 10.01319504], [76.25653076, 10.01319504], [76.25653076, 10.01347256], [76.25624847, 10.0134697], [76.25624847, 10.01403141], [76.25597382, 10.01402664], [76.25597382, 10.01458263], [76.25569153, 10.01458263], [76.25569153, 10.01597309], [76.25541687, 10.01597118], [76.25541687, 10.01653099], [76.25514221, 10.01653099], [76.25514221, 10.01680946], [76.25485992, 10.0168047], [76.25485992, 10.01708317], [76.2545929, 10.01708126], [76.2545929, 10.0179224], [76.25430298, 10.01791668], [76.25430298, 10.01958275], [76.25402832, 10.01958084], [76.25402832, 10.02042198], [76.25375366, 10.02041721], [76.25375366, 10.02097321], [76.25347137, 10.02095985], [76.25347137, 10.0215292], [76.25319672, 10.0215292], [76.25319672, 10.02180958], [76.25291443, 10.02180481], [76.25291443, 10.0223608], [76.25263977, 10.02235889], [76.25263977, 10.02291965], [76.25235748, 10.02291679], [76.25235748, 10.02347088], [76.25208282, 10.02347088], [76.25208282, 10.02431011], [76.25235748, 10.02430534], [76.25235748, 10.0256958], [76.25208282, 10.02569103], [76.25208282, 10.02680969], [76.25180817, 10.02680588], [76.25180817, 10.02736187], [76.25152588, 10.02736187], [76.25152588, 10.02847195], [76.25125122, 10.02847195], [76.25125122, 10.02931023], [76.24986267, 10.02930641], [76.24986267, 10.0298624], [76.24958038, 10.0298624], [76.24958038, 10.03013992], [76.2498703, 10.03013134], [76.2498703, 10.0304203], [76.25041962, 10.03041553], [76.25041962, 10.03069401], [76.25069427, 10.03069401], [76.25069427, 10.03097153], [76.25096893, 10.03096962], [76.25096893, 10.03125], [76.25125122, 10.03125], [76.25125122, 10.03181076], [76.25152588, 10.03180599], [76.25152588, 10.03236008], [76.25208282, 10.03236008], [76.25208282, 10.03292274], [76.25235748, 10.03292274], [76.25235748, 10.03374958], [76.25263977, 10.03374958], [76.25263977, 10.03458214], [76.25291443, 10.03458214], [76.25291443, 10.03485966], [76.25319672, 10.03485966], [76.25319672, 10.03514004], [76.25374603, 10.03514004], [76.25374603, 10.03542137], [76.25402832, 10.03541565], [76.25402832, 10.03569412], [76.25430298, 10.03569412], [76.25430298, 10.03597164], [76.2545929, 10.03596973], [76.2545929, 10.03625011], [76.25485992, 10.03625011], [76.25485992, 10.03653145], [76.25514221, 10.03653145], [76.25514221, 10.03681087], [76.25541687, 10.0368042], [76.25541687, 10.03708458], [76.25569153, 10.03708458], [76.25569153, 10.03736019], [76.25596619, 10.03736019], [76.25596619, 10.03764057], [76.25624847, 10.03764057], [76.25624847, 10.03792095], [76.25653076, 10.03791618], [76.25653076, 10.0381937], [76.25680542, 10.0381937], [76.25680542, 10.03847313], [76.25708008, 10.03847027], [76.25708008, 10.03903103], [76.25818634, 10.03903103], [76.25818634, 10.03931999], [76.25902557, 10.03930664], [76.25902557, 10.03958225], [76.26013947, 10.03958225], [76.26013947, 10.03875065], [76.26125336, 10.03875065], [76.26125336, 10.03903103], [76.2618103, 10.03903103], [76.2618103, 10.03847027], [76.26208496, 10.03847313], [76.26208496, 10.0381937], [76.26235962, 10.0381937], [76.26235962, 10.03791618], [76.26264191, 10.03792095], [76.26264191, 10.03708172], [76.26180267, 10.03708458], [76.26180267, 10.0368042], [76.26152802, 10.03681087], [76.26152802, 10.03625011], [76.26125336, 10.03625011], [76.26125336, 10.03569031], [76.26152802, 10.03569412], [76.26152802, 10.03513813], [76.2618103, 10.03514004], [76.2618103, 10.03485966], [76.26264191, 10.03486156], [76.26264191, 10.03569412], [76.26347351, 10.03569412], [76.26347351, 10.03486156], [76.26374817, 10.03485966], [76.26374817, 10.03374958], [76.26403046, 10.03374958], [76.26403046, 10.03347015], [76.26431274, 10.03347015], [76.26431274, 10.03514004], [76.26457977, 10.03513813], [76.26457977, 10.03569412], [76.26486206, 10.03569412], [76.26486206, 10.03597164], [76.26513672, 10.03596973], [76.26513672, 10.03625011], [76.26541901, 10.03625011], [76.26541901, 10.03653145], [76.26568604, 10.03653145], [76.26568604, 10.03681087], [76.26597595, 10.0368042], [76.26597595, 10.03708458], [76.26625061, 10.03708458], [76.26625061, 10.03736019], [76.26597595, 10.03736019], [76.26597595, 10.03792095], [76.26569366, 10.03791618], [76.26569366, 10.0381937], [76.26541901, 10.03818989], [76.26541901, 10.03875065], [76.26513672, 10.03875065], [76.26513672, 10.03931999], [76.26486206, 10.03930664], [76.26486206, 10.03958225], [76.26430511, 10.03958225], [76.26430511, 10.03875065], [76.26403046, 10.03875065], [76.26403046, 10.03847027], [76.26374817, 10.03847313], [76.26374817, 10.0381937], [76.26347351, 10.0381937], [76.26347351, 10.03847313], [76.26319122, 10.03847027], [76.26319122, 10.03875065], [76.26291656, 10.03875065], [76.26291656, 10.03958225], [76.26264191, 10.03958225], [76.26264191, 10.03986073], [76.26291656, 10.03986073], [76.26291656, 10.04014111], [76.26319122, 10.04014111], [76.26319122, 10.04042053], [76.26347351, 10.04041672], [76.26347351, 10.04069519], [76.26291656, 10.04069519], [76.26291656, 10.04097271], [76.26125336, 10.04097271], [76.26125336, 10.04125118], [76.25985718, 10.04125118], [76.25985718, 10.04181099], [76.26013947, 10.04180527], [76.26013947, 10.04236126], [76.26041412, 10.04236126], [76.26041412, 10.04347324], [76.26013947, 10.04347324], [76.26013947, 10.04319477], [76.25986481, 10.04319477], [76.25986481, 10.04263878], [76.25930786, 10.04264069], [76.25930786, 10.04292107], [76.25902557, 10.04291725], [76.25902557, 10.04319477], [76.25875092, 10.04319477], [76.25875092, 10.04347324], [76.25819397, 10.04347324], [76.25819397, 10.04319477], [76.25736237, 10.04319477], [76.25736237, 10.04291725], [76.25681305, 10.04292107], [76.25681305, 10.04264069], [76.25569153, 10.04263878], [76.25569153, 10.04347324], [76.25541687, 10.04347134], [76.25541687, 10.04431152], [76.25514221, 10.04430485], [76.25514221, 10.04513931], [76.25485992, 10.04513931], [76.25485992, 10.0456953], [76.25514221, 10.04569054], [76.25514221, 10.04763889], [76.25430298, 10.04763889], [76.25430298, 10.04708099], [76.25458527, 10.0470829], [76.25458527, 10.04652691], [76.25347137, 10.04653168], [76.25347137, 10.0462513], [76.25375366, 10.0462513], [76.25374603, 10.04512978], [76.25402832, 10.04513931], [76.25402832, 10.04430485], [76.25430298, 10.04431152], [76.25430298, 10.04374886], [76.25458527, 10.04374886], [76.25458527, 10.04319477], [76.25485992, 10.04319477], [76.25485992, 10.04236126], [76.25514221, 10.04236126], [76.25514221, 10.03958225], [76.25541687, 10.03958225], [76.25541687, 10.03930664], [76.25485992, 10.03931999], [76.25485992, 10.03903103], [76.25430298, 10.03903103], [76.25430298, 10.03931999], [76.25402832, 10.03931999], [76.25402832, 10.04042053], [76.25374603, 10.04042053], [76.25374603, 10.04153061], [76.25347137, 10.0415287], [76.25347137, 10.04208279], [76.25319672, 10.04207134], [76.25319672, 10.04264069], [76.25291443, 10.04263878], [76.25291443, 10.04319477], [76.25263977, 10.04319477], [76.25263977, 10.04374886], [76.25235748, 10.04374886], [76.25235748, 10.04402924], [76.25208282, 10.04402924], [76.25208282, 10.04486084], [76.25180817, 10.04486084], [76.25180817, 10.04513931], [76.25152588, 10.04513931], [76.25152588, 10.0456953], [76.25125122, 10.0456953], [76.25125122, 10.0470829], [76.25041962, 10.0470829], [76.25041962, 10.04736137], [76.25096893, 10.04736137], [76.25096893, 10.04763889], [76.25235748, 10.04763889], [76.25235748, 10.04736137], [76.25263977, 10.04736137], [76.25263977, 10.04792023], [76.25291443, 10.04791737], [76.25291443, 10.04819489], [76.25263977, 10.04819489], [76.25263977, 10.04847336], [76.25208282, 10.04847145], [76.25208282, 10.04875088], [76.25180817, 10.04875088], [76.25180817, 10.04930973], [76.25125122, 10.04930496], [76.25125122, 10.04986095], [76.25096893, 10.04986095], [76.25096893, 10.05013943], [76.25041962, 10.05013943], [76.25041962, 10.05069637], [76.25013733, 10.05069065], [76.25013733, 10.05153179], [76.24986267, 10.05152702], [76.24986267, 10.05208397], [76.24958038, 10.05208111], [76.24958038, 10.05292034], [76.24903107, 10.05291462], [76.24903107, 10.05347157], [76.24874878, 10.05347157], [76.24874878, 10.05458355], [76.24846649, 10.05458069], [76.24846649, 10.05513954], [76.24791718, 10.05513954], [76.24791718, 10.05541992], [76.24764252, 10.05541992], [76.24764252, 10.05624962], [76.24791718, 10.05624962], [76.24791718, 10.05708408], [76.24764252, 10.05708408], [76.24764252, 10.0573597], [76.24624634, 10.0573616], [76.24624634, 10.05819416], [76.24652863, 10.05819416], [76.24652863, 10.05875015], [76.24624634, 10.05875015], [76.24624634, 10.05931091], [76.24569702, 10.05930614], [76.24569702, 10.05958366], [76.24541473, 10.05958366], [76.24541473, 10.06013775], [76.24514008, 10.06013775], [76.24514008, 10.06069374], [76.24485779, 10.06069183], [76.24485779, 10.06124973], [76.24514008, 10.06124973], [76.24514008, 10.06181145], [76.2454071, 10.06181145], [76.24545288, 10.06270695], [76.24514008, 10.06263828], [76.24514008, 10.06291199], [76.24514008, 10.06320095], [76.24485779, 10.06319427], [76.24485779, 10.06347179], [76.24458313, 10.06347179], [76.24458313, 10.06375027], [76.24430847, 10.06375027], [76.24430847, 10.06403065], [76.24402618, 10.06403065], [76.24402618, 10.06431103], [76.24375153, 10.06430435], [76.24375153, 10.06458473], [76.24346924, 10.06458473], [76.24346924, 10.06486034], [76.24318695, 10.06486034], [76.24318695, 10.06514072], [76.24236298, 10.06513786], [76.24236298, 10.06569481], [76.24263763, 10.06569004], [76.24263763, 10.06626034], [76.24291992, 10.06626034], [76.24291992, 10.06653118], [76.24318695, 10.06653118], [76.24318695, 10.06681061], [76.24291992, 10.06680679], [76.24291992, 10.06736088], [76.24263763, 10.06736088], [76.24263763, 10.06792068], [76.24236298, 10.06791687], [76.24236298, 10.06847286], [76.24208069, 10.06847095], [76.24208069, 10.06902885], [76.24153137, 10.06902885], [76.24153137, 10.06930542], [76.24124908, 10.06930542], [76.24124908, 10.06958294], [76.24097443, 10.06958294], [76.24097443, 10.06986141], [76.24067688, 10.06986141], [76.24067688, 10.07041931], [76.24041748, 10.0704174], [76.24041748, 10.0709734], [76.24067688, 10.07097054], [76.24067688, 10.0715313], [76.24097443, 10.07152653], [76.24097443, 10.07208347], [76.24124908, 10.07208347], [76.24124908, 10.07236099], [76.24180603, 10.07236099], [76.24180603, 10.07264137], [76.24346924, 10.07264137], [76.24346924, 10.07236099], [76.24375153, 10.07236099], [76.24373627, 10.07181168], [76.24402618, 10.07181168], [76.24402618, 10.0715313], [76.24430847, 10.0715313], [76.24430847, 10.07097054], [76.24458313, 10.0709734], [76.24458313, 10.07069492], [76.24485779, 10.07069492], [76.24485779, 10.06986141], [76.24514008, 10.06986141], [76.24514008, 10.06930542], [76.24541473, 10.06930542], [76.24541473, 10.06902885], [76.24514008, 10.06902885], [76.24514008, 10.06847095], [76.24485779, 10.06847286], [76.24485779, 10.06819534], [76.24514008, 10.06819534], [76.24514008, 10.06736088], [76.24541473, 10.06736088], [76.2454071, 10.06653118], [76.24569702, 10.06653118], [76.24569702, 10.06569004], [76.24597168, 10.06569481], [76.24597168, 10.06513786], [76.24624634, 10.06514072], [76.24624634, 10.06457996], [76.24652863, 10.06458473], [76.24652863, 10.06430435], [76.24680328, 10.06431103], [76.24680328, 10.06403065], [76.2470932, 10.06403065], [76.2470932, 10.06347179], [76.24736023, 10.06347179], [76.24736023, 10.0629158], [76.2470932, 10.06292057], [76.2470932, 10.06264114], [76.24736023, 10.06264114], [76.24736023, 10.06236172], [76.24764252, 10.06236172], [76.24764252, 10.06181145], [76.24791718, 10.06181145], [76.24791718, 10.06153107], [76.24819183, 10.06153107], [76.24819183, 10.06091118], [76.24819183, 10.06041622], [76.24791718, 10.06042099], [76.24791718, 10.06013107], [76.24819183, 10.06013775], [76.24819183, 10.05958366], [76.24847412, 10.05958366], [76.24847412, 10.05902767], [76.24874878, 10.05902958], [76.24874878, 10.05875015], [76.24903107, 10.05875015], [76.24903107, 10.05847168], [76.24930573, 10.05847168], [76.24930573, 10.05819416], [76.24903107, 10.05819416], [76.24903107, 10.05791569], [76.24874878, 10.05792046], [76.24874878, 10.05764008], [76.24903107, 10.05764008], [76.24903107, 10.05706978], [76.24930573, 10.05708408], [76.24930573, 10.05680561], [76.24958038, 10.05681038], [76.24958038, 10.05624962], [76.2498703, 10.05624962], [76.2498703, 10.05568886], [76.25013733, 10.05569363], [76.25013733, 10.05541801], [76.25041962, 10.05541992], [76.25041962, 10.05486202], [76.25069427, 10.05486202], [76.25068665, 10.05458069], [76.25096893, 10.05458355], [76.25096893, 10.05430603], [76.25125122, 10.05431938], [76.25125122, 10.05375195], [76.25096893, 10.05375195], [76.25096893, 10.05319118], [76.25069427, 10.05319309], [76.25069427, 10.05263996], [76.25096893, 10.05264187], [76.25096893, 10.05208111], [76.25125122, 10.05208397], [76.25125122, 10.05180454], [76.25152588, 10.05181026], [76.25152588, 10.05264187], [76.25180817, 10.05263996], [76.25180817, 10.05319309], [76.25208282, 10.05319118], [76.25208282, 10.05375195], [76.25235748, 10.05375195], [76.25235748, 10.05403042], [76.25208282, 10.05403042], [76.25208282, 10.05513954], [76.25235748, 10.05513763], [76.25235748, 10.05569363], [76.25263977, 10.05569363], [76.25263977, 10.0559721], [76.25514221, 10.0559721], [76.25514221, 10.05569363], [76.25569153, 10.05569363], [76.25569153, 10.05541801], [76.25624847, 10.05541992], [76.25624847, 10.05513954], [76.25708008, 10.05513954], [76.25708008, 10.05486202], [76.25736237, 10.05486202], [76.25736237, 10.05375004], [76.25763702, 10.05375195], [76.25763702, 10.05319118], [76.25791931, 10.05319309], [76.25791931, 10.05263996], [76.25818634, 10.05264187], [76.25818634, 10.05208111], [76.25846863, 10.05208397], [76.25846863, 10.05097103], [76.25763702, 10.05097103], [76.25763702, 10.05153179], [76.25736237, 10.05152702], [76.25736237, 10.05208397], [76.25708008, 10.05208111], [76.25708008, 10.05264187], [76.25680542, 10.05263996], [76.25680542, 10.05347157], [76.25653076, 10.05347157], [76.25653076, 10.05403042], [76.25624847, 10.05403042], [76.25624847, 10.05347157], [76.25597382, 10.05347157], [76.25597382, 10.05319309], [76.25569153, 10.05319309], [76.25569153, 10.05291462], [76.25541687, 10.05292034], [76.25541687, 10.05208111], [76.25514221, 10.05208397], [76.25514221, 10.05180454], [76.25485992, 10.05181026], [76.25485992, 10.05153179], [76.25347137, 10.05152702], [76.25347137, 10.05208397], [76.25319672, 10.05208397], [76.25319672, 10.05180454], [76.25208282, 10.05181026], [76.25208282, 10.05126095], [76.25180817, 10.05126095], [76.25180817, 10.05097103], [76.25208282, 10.05097103], [76.25208282, 10.04986095], [76.25347137, 10.04986095], [76.25347137, 10.04958344], [76.25458527, 10.04958344], [76.25458527, 10.04930496], [76.25514221, 10.04930973], [76.25514221, 10.0490303], [76.25596619, 10.0490303], [76.25596619, 10.04930973], [76.25681305, 10.04930973], [76.25681305, 10.04763889], [76.25653076, 10.04763889], [76.25653076, 10.04708099], [76.25597382, 10.0470829], [76.25597382, 10.04736137], [76.25569153, 10.04736137], [76.25569153, 10.04680538], [76.25596619, 10.04681015], [76.25596619, 10.04653168], [76.25624847, 10.04653168], [76.25624847, 10.04597092], [76.25708008, 10.04597092], [76.25708008, 10.0462513], [76.25763702, 10.0462513], [76.25763702, 10.04653168], [76.25818634, 10.04653168], [76.25818634, 10.04681015], [76.25902557, 10.04680538], [76.25902557, 10.0470829], [76.25958252, 10.0470829], [76.25958252, 10.04736137], [76.25985718, 10.04736137], [76.25985718, 10.04763889], [76.26041412, 10.04763889], [76.26041412, 10.04819489], [76.26013947, 10.04819107], [76.26013947, 10.04930973], [76.25985718, 10.04930973], [76.25985718, 10.05013943], [76.25930786, 10.05013943], [76.25930786, 10.05153179], [76.25986481, 10.05152702], [76.25986481, 10.05208397], [76.25958252, 10.05208111], [76.25958252, 10.05264187], [76.25930786, 10.05264187], [76.25930786, 10.05292034], [76.25902557, 10.05291462], [76.25902557, 10.05319309], [76.25846863, 10.05319118], [76.25846863, 10.05431938], [76.25875092, 10.05430603], [76.25875092, 10.05458355], [76.25818634, 10.05458069], [76.25818634, 10.05541992], [76.25902557, 10.05541801], [76.25902557, 10.05569363], [76.25958252, 10.05569363], [76.25958252, 10.0559721], [76.25985718, 10.05596924], [76.25985718, 10.05624962], [76.26013947, 10.05624962], [76.26013947, 10.05653], [76.26040649, 10.05653], [76.26040649, 10.05681038], [76.26097107, 10.05680561], [76.26097107, 10.05694008], [76.26097107, 10.05708408], [76.26125336, 10.05708408], [76.26125336, 10.0573597], [76.2618103, 10.0573597], [76.2618103, 10.05792046], [76.26152802, 10.05791569], [76.26152802, 10.05875015], [76.26125336, 10.05875015], [76.26125336, 10.05902958], [76.26097107, 10.05902958], [76.26097107, 10.05931091], [76.26041412, 10.05930614], [76.26041412, 10.05958366], [76.26013947, 10.05958366], [76.26013947, 10.06013775], [76.25986481, 10.06013775], [76.25986481, 10.06069374], [76.25930786, 10.06069183], [76.25930786, 10.06124973], [76.2590332, 10.06124973], [76.2590332, 10.06153107], [76.25875092, 10.06153107], [76.25875092, 10.06181145], [76.25846863, 10.06180573], [76.25846863, 10.06208229], [76.25763702, 10.06208229], [76.25763702, 10.06152821], [76.25736237, 10.06153107], [76.25736237, 10.06124973], [76.25681305, 10.06124973], [76.25681305, 10.06320095], [76.25708008, 10.06319427], [76.25708008, 10.06347179], [76.25763702, 10.06347179], [76.25763702, 10.06431103], [76.25791931, 10.06430435], [76.25791931, 10.06458473], [76.25763702, 10.06458473], [76.25763702, 10.06486034], [76.25736237, 10.06486034], [76.25736237, 10.06514072], [76.25708008, 10.06514072], [76.25708008, 10.0654211], [76.25736237, 10.06541634], [76.25736237, 10.06597328], [76.25763702, 10.06597042], [76.25763702, 10.06653118], [76.25736237, 10.06652641], [76.25736237, 10.06708336], [76.25708008, 10.06707954], [76.25708008, 10.06792068], [76.25736237, 10.06791687], [76.25736237, 10.06847286], [76.25875092, 10.06847286], [76.25875092, 10.06791687], [76.2590332, 10.06792068], [76.2590332, 10.06736088], [76.25930786, 10.06736088], [76.25930786, 10.06680679], [76.25958252, 10.06681061], [76.25958252, 10.06653118], [76.26013947, 10.06653118], [76.26013947, 10.06626034], [76.26040649, 10.06626034], [76.26040649, 10.06514072], [76.26013947, 10.06514072], [76.26013947, 10.06431103], [76.26069641, 10.06430435], [76.26069641, 10.06458473], [76.26125336, 10.06457996], [76.26125336, 10.06514072], [76.2618103, 10.06514072], [76.2618103, 10.0654211], [76.26207733, 10.0654211], [76.26207733, 10.06653118], [76.26291656, 10.06652641], [76.26291656, 10.06708336], [76.26403046, 10.06707954], [76.26403046, 10.06764126], [76.26431274, 10.06764126], [76.26431274, 10.06792068], [76.26541901, 10.06792068], [76.26541901, 10.06764126], [76.26568604, 10.06764126], [76.26568604, 10.06707954], [76.26597595, 10.06708336], [76.26597595, 10.06680679], [76.26680756, 10.06680679], [76.26680756, 10.06708336], [76.26708221, 10.06707954], [76.26708221, 10.06764126], [76.26680756, 10.06763935], [76.26680756, 10.06819534], [76.26652527, 10.06819534], [76.26652527, 10.06875134], [76.26625061, 10.06875134], [76.26625061, 10.06930542], [76.26652527, 10.06930542], [76.26652527, 10.06986141], [76.26680756, 10.06986141], [76.26680756, 10.07014084], [76.26708221, 10.07013893], [76.26708221, 10.0709734], [76.26680756, 10.07097054], [76.26680756, 10.07181168], [76.26457977, 10.07181168], [76.26457977, 10.0715313], [76.26403046, 10.0715313], [76.26403046, 10.07125092], [76.26374817, 10.07125092], [76.26374817, 10.07097054], [76.26347351, 10.0709734], [76.26347351, 10.07069492], [76.26319122, 10.07069492], [76.26319122, 10.0709734], [76.26291656, 10.0709734], [76.26291656, 10.07069492], [76.26180267, 10.07069492], [76.26180267, 10.0704174], [76.26152802, 10.07041931], [76.26152802, 10.07014084], [76.26097107, 10.07013893], [76.26097107, 10.0709734], [76.26125336, 10.07097054], [76.26125336, 10.0715313], [76.26235962, 10.0715313], [76.26235962, 10.07181168], [76.26207733, 10.07181168], [76.26207733, 10.07264137], [76.2618103, 10.07264137], [76.26180267, 10.07374859], [76.26152802, 10.07375145], [76.26152802, 10.0743103], [76.26125336, 10.07430458], [76.26125336, 10.07486057], [76.26097107, 10.07486057], [76.26097107, 10.07543087], [76.26069641, 10.07541656], [76.26069641, 10.07597256], [76.26040649, 10.07597065], [76.26040649, 10.07681179], [76.26013947, 10.07680511], [76.26013947, 10.07708263], [76.25985718, 10.07708073], [76.25985718, 10.07791996], [76.25958252, 10.07791996], [76.25958252, 10.07903194], [76.25930786, 10.07903194], [76.25930786, 10.07931042], [76.25902557, 10.07930565], [76.25902557, 10.07986164], [76.25875092, 10.07986164], [76.25875092, 10.0806942], [76.25846863, 10.0806942], [76.25846863, 10.08125019], [76.25818634, 10.08124065], [76.25818634, 10.08181], [76.25791931, 10.08180618], [76.25791931, 10.0820837], [76.25763702, 10.0820837], [76.25763702, 10.08319378], [76.25736237, 10.08319378], [76.25736237, 10.08458424], [76.25791931, 10.08458424], [76.25791931, 10.08485985], [76.25818634, 10.08485985], [76.25818634, 10.08514023], [76.25875092, 10.08514023], [76.25875092, 10.08485985], [76.25902557, 10.08485985], [76.25902557, 10.08458424], [76.25930786, 10.08458424], [76.25930786, 10.08430576], [76.25958252, 10.08430576], [76.25958252, 10.08402824], [76.25985718, 10.08403015], [76.25985718, 10.08319092], [76.26013947, 10.08319378], [76.26013947, 10.08236217], [76.26041412, 10.08236217], [76.26041412, 10.08152771], [76.26069641, 10.08152962], [76.26069641, 10.08124065], [76.26097107, 10.08125019], [76.26097107, 10.08097172], [76.26125336, 10.08097172], [76.26125336, 10.07902718], [76.26152802, 10.07903194], [76.26152802, 10.07875156], [76.26207733, 10.07875156], [76.26207733, 10.07846928], [76.26235962, 10.07847118], [76.26235962, 10.07819557], [76.26291656, 10.07820034], [76.26291656, 10.07791996], [76.26264191, 10.07791996], [76.26264191, 10.07653046], [76.26403046, 10.07653046], [76.26403046, 10.07597065], [76.26430511, 10.07597256], [76.26430511, 10.07541656], [76.26457977, 10.07543087], [76.26457977, 10.07486057], [76.26486206, 10.07486057], [76.26486206, 10.07430458], [76.26513672, 10.0743103], [76.26513672, 10.07347107], [76.26486206, 10.07347107], [76.26486206, 10.07263947], [76.26513672, 10.07264137], [76.26513672, 10.07291889], [76.26569366, 10.07291698], [76.26569366, 10.07319546], [76.26625061, 10.07319546], [76.26625061, 10.07458305], [76.26597595, 10.07458115], [76.26597595, 10.07514191], [76.26569366, 10.07513905], [76.26569366, 10.07569313], [76.26597595, 10.07569313], [76.26597595, 10.07597256], [76.26568604, 10.07597065], [76.26568604, 10.07625198], [76.26541901, 10.07625198], [76.26541901, 10.07681179], [76.26513672, 10.07680511], [76.26513672, 10.07708263], [76.26486206, 10.07708263], [76.26486206, 10.07736111], [76.26457977, 10.0773592], [76.26457977, 10.07931042], [76.26430511, 10.07930565], [76.26430511, 10.07986164], [76.26403046, 10.07986164], [76.26403046, 10.08014202], [76.26374817, 10.08014202], [76.26374817, 10.08041954], [76.26347351, 10.08041763], [76.26347351, 10.0806942], [76.26319122, 10.08069134], [76.26319122, 10.08152962], [76.26291656, 10.08152962], [76.26291656, 10.08181], [76.26264191, 10.08180618], [76.26264191, 10.0820837], [76.26235962, 10.0820837], [76.26235962, 10.08236217], [76.26208496, 10.08236217], [76.26208496, 10.08319378], [76.26180267, 10.08319378], [76.26180267, 10.08347225], [76.26152802, 10.08347034], [76.26152802, 10.08374977], [76.26125336, 10.08374977], [76.26125336, 10.08430576], [76.26097107, 10.08430576], [76.26097107, 10.08569431], [76.26069641, 10.08569431], [76.26069641, 10.08625031], [76.26013947, 10.08625031], [76.26013947, 10.08652973], [76.25930786, 10.08652973], [76.25930786, 10.08681107], [76.2590332, 10.08681107], [76.2590332, 10.08764267], [76.25930786, 10.08764267], [76.25930786, 10.08792114], [76.25958252, 10.08791637], [76.25958252, 10.08819389], [76.25985718, 10.08819199], [76.25985718, 10.08931065], [76.25958252, 10.08931065], [76.25958252, 10.0901413], [76.25930786, 10.09013844], [76.25930786, 10.09069443], [76.25902557, 10.09069443], [76.2590332, 10.09125042], [76.25818634, 10.09125042], [76.25818634, 10.09068966], [76.25791931, 10.09069443], [76.25791931, 10.08958435], [76.25763702, 10.08958435], [76.25763702, 10.08819389], [76.25791931, 10.08819389], [76.25791931, 10.08791637], [76.25818634, 10.08792114], [76.25818634, 10.08764267], [76.25846863, 10.08764267], [76.25846863, 10.08708191], [76.25819397, 10.08708191], [76.25819397, 10.08625031], [76.25791931, 10.08625031], [76.25791931, 10.08569431], [76.25763702, 10.08569431], [76.25763702, 10.08541584], [76.25736237, 10.08541965], [76.25736237, 10.08514023], [76.25708008, 10.08514023], [76.25708008, 10.08541965], [76.25624847, 10.08541584], [76.25624847, 10.08708191], [76.25597382, 10.08708191], [76.25597382, 10.08652782], [76.25567627, 10.08652973], [76.25567627, 10.08568859], [76.25541687, 10.08569431], [76.25541687, 10.08485985], [76.25514221, 10.08485985], [76.25514221, 10.08430576], [76.25485992, 10.08430576], [76.25485992, 10.08374977], [76.25430298, 10.08374977], [76.25430298, 10.08347034], [76.2529068, 10.08347034], [76.2529068, 10.08374977], [76.25263977, 10.08374977], [76.25263977, 10.08458424], [76.25235748, 10.08457947], [76.25235748, 10.08514023], [76.25208282, 10.08514023], [76.25208282, 10.08541965], [76.25235748, 10.08541965], [76.25235748, 10.08737087], [76.25347137, 10.08737087], [76.25347137, 10.08875275], [76.25319672, 10.08875275], [76.25319672, 10.08931065], [76.2529068, 10.08931065], [76.2529068, 10.08819199], [76.25263977, 10.08819389], [76.25263977, 10.0876379], [76.25152588, 10.08764267], [76.25152588, 10.08792114], [76.25096893, 10.08791637], [76.25096893, 10.08819389], [76.25068665, 10.08819199], [76.25068665, 10.08903122], [76.25096893, 10.08903122], [76.25096893, 10.0901413], [76.25125122, 10.09013844], [76.25125122, 10.09069443], [76.25152588, 10.09069443], [76.25152588, 10.09125042], [76.25235748, 10.09125042], [76.25235748, 10.0915308], [76.25263977, 10.09152889], [76.25263977, 10.09208202], [76.25235748, 10.09208012], [76.25235748, 10.09264088], [76.25208282, 10.09263802], [76.25208282, 10.09319496], [76.25180817, 10.09319496], [76.25180817, 10.09347343], [76.25125122, 10.09346962], [76.25125122, 10.09375095], [76.25096893, 10.09375095], [76.25096893, 10.09403133], [76.25041962, 10.09402561], [76.25041962, 10.09458256], [76.25013733, 10.0945797], [76.25013733, 10.09514141], [76.24986267, 10.09513855], [76.24986267, 10.09597301], [76.24958038, 10.09597301], [76.24958038, 10.09541702], [76.24931335, 10.09542084], [76.24931335, 10.09514141], [76.24764252, 10.09513855], [76.24764252, 10.09597301], [76.24791718, 10.09597301], [76.24791718, 10.09708309], [76.24847412, 10.09708309], [76.24847412, 10.09736061], [76.24874878, 10.09736061], [76.24874878, 10.09819508], [76.24846649, 10.09819031], [76.24846649, 10.09875107], [76.24819183, 10.09875107], [76.24819183, 10.09903145], [76.24791718, 10.09903145], [76.24791718, 10.09931183], [76.24764252, 10.09930515], [76.24764252, 10.09958267], [76.24736023, 10.09958267], [76.24736023, 10.09986115], [76.2470932, 10.09986115], [76.2470932, 10.10014057], [76.24597168, 10.10014057], [76.24597168, 10.10042191], [76.24624634, 10.10041714], [76.24624634, 10.10097313], [76.24652863, 10.10097122], [76.24652863, 10.10125065], [76.24569702, 10.10125065], [76.24569702, 10.10181046], [76.24541473, 10.10180473], [76.24541473, 10.10208321], [76.24514008, 10.1020813], [76.24514008, 10.1026392], [76.24208069, 10.1026392], [76.24208069, 10.10402966], [76.24318695, 10.10402966], [76.24318695, 10.10431004], [76.24346924, 10.10430527], [76.24346924, 10.10486126], [76.24236298, 10.10485935], [76.24236298, 10.10513973], [76.24180603, 10.10513973], [76.24180603, 10.10541534], [76.24208069, 10.10541534], [76.24208069, 10.10597134], [76.24236298, 10.10597134], [76.24236298, 10.10653019], [76.24124908, 10.10652828], [76.24124908, 10.10708427], [76.2409668, 10.10708141], [76.2409668, 10.10764027], [76.24124908, 10.10764027], [76.24124908, 10.10875034], [76.24067688, 10.10875034], [76.24067688, 10.10847187], [76.24041748, 10.10847187], [76.24041748, 10.10819435], [76.23930359, 10.10819435], [76.23930359, 10.10847187], [76.23902893, 10.10847187], [76.23902893, 10.10902977], [76.23930359, 10.10902786], [76.23930359, 10.10958385], [76.23958588, 10.10958195], [76.23958588, 10.11013985], [76.23986053, 10.11013985], [76.23986053, 10.11042023], [76.23847198, 10.11041641], [76.23847198, 10.11069393], [76.23819733, 10.11069393], [76.23819733, 10.1109724], [76.2379303, 10.11096954], [76.2379303, 10.11124992], [76.23902893, 10.11124992], [76.23902893, 10.11154175], [76.23874664, 10.1115284], [76.23874664, 10.11208439], [76.23847198, 10.11208439], [76.23847198, 10.11236], [76.23819733, 10.11236], [76.23819733, 10.11180592], [76.23680878, 10.11181068], [76.23680878, 10.11264038], [76.23707581, 10.11264038], [76.23708344, 10.11375046], [76.23680878, 10.11375046], [76.23680878, 10.11403275], [76.23486328, 10.11403275], [76.23486328, 10.11292267], [76.23374939, 10.11291599], [76.23374939, 10.11347198], [76.2334671, 10.11347198], [76.2334671, 10.11403275], [76.23179626, 10.11403275], [76.23179626, 10.11347198], [76.23124695, 10.11347198], [76.23124695, 10.11375046], [76.23097229, 10.11375046], [76.23097229, 10.11403275], [76.23041534, 10.11402798], [76.23041534, 10.11458206], [76.23014069, 10.11458015], [76.23014069, 10.1154213], [76.23041534, 10.11541557], [76.23041534, 10.11597157], [76.23014069, 10.11596966], [76.23014069, 10.11625004], [76.22902679, 10.11625004], [76.22902679, 10.11680889], [76.22875214, 10.11680603], [76.22875214, 10.11736012], [76.22846985, 10.11735058], [76.22846985, 10.11792088], [76.22875214, 10.11791611], [76.22875214, 10.1184721], [76.22846985, 10.11847019], [76.22846985, 10.11903095], [76.22820282, 10.11903095], [76.22820282, 10.11931133], [76.2279129, 10.11931133], [76.2279129, 10.12014103], [76.22819519, 10.12013912], [76.22819519, 10.12069511], [76.22875214, 10.12069511], [76.22875214, 10.12097263], [76.23124695, 10.12096977], [76.23124695, 10.12153053], [76.23097229, 10.12153053], [76.23097229, 10.12181091], [76.23069763, 10.12180519], [76.23069763, 10.12208271], [76.22819519, 10.12208271], [76.22819519, 10.12236118], [76.2279129, 10.12236118], [76.2279129, 10.12264061], [76.22735596, 10.12264061], [76.22735596, 10.12375069], [76.22846985, 10.12374878], [76.22846985, 10.12486076], [76.22820282, 10.12485886], [76.22820282, 10.12514114], [76.2279129, 10.12514114], [76.2279129, 10.12542152], [76.22763824, 10.12541676], [76.22763824, 10.12625122], [76.22735596, 10.12625122], [76.22735596, 10.12654114], [76.2270813, 10.12654114], [76.2270813, 10.12681198], [76.22680664, 10.12680531], [76.22680664, 10.12708282], [76.22569275, 10.12708282], [76.22569275, 10.12680531], [76.2259903, 10.12681198], [76.2259903, 10.12625122], [76.22624969, 10.12625122], [76.22624969, 10.12569523], [76.2270813, 10.12569523], [76.2270813, 10.12541676], [76.22735596, 10.12542152], [76.22735596, 10.12514114], [76.22763824, 10.12514114], [76.22763824, 10.12485886], [76.22736359, 10.12486076], [76.22736359, 10.12458324], [76.22680664, 10.12458324], [76.22680664, 10.12486076], [76.22651672, 10.12485886], [76.22651672, 10.12514114], [76.22570038, 10.12514114], [76.22570038, 10.12485886], [76.22541809, 10.12486076], [76.22541809, 10.12402916], [76.22570038, 10.12403107], [76.22570038, 10.12347984], [76.2259903, 10.12347984], [76.2259903, 10.12264061], [76.22624969, 10.12264061], [76.22624969, 10.12236118], [76.22652435, 10.12236118], [76.22652435, 10.12208271], [76.22680664, 10.12208271], [76.22680664, 10.12180519], [76.2270813, 10.12181091], [76.2270813, 10.12153053], [76.22763824, 10.12153053], [76.22763824, 10.12125111], [76.2279129, 10.12125111], [76.2279129, 10.12041664], [76.2270813, 10.12041664], [76.2270813, 10.12013912], [76.22735596, 10.12014103], [76.22735596, 10.11958027], [76.22763824, 10.11958218], [76.22763824, 10.11902905], [76.2279129, 10.11903095], [76.2279129, 10.11764145], [76.22820282, 10.11764145], [76.22820282, 10.11707973], [76.22846985, 10.11708355], [76.22846985, 10.11652756], [76.22873688, 10.11653137], [76.22873688, 10.11569023], [76.22902679, 10.11569405], [76.22902679, 10.11541557], [76.22930908, 10.1154213], [76.22930908, 10.11458015], [76.22902679, 10.11458206], [76.22902679, 10.11375046], [76.22930908, 10.11375046], [76.22930908, 10.11347198], [76.2298584, 10.11347198], [76.2298584, 10.11375046], [76.23014069, 10.11375046], [76.23014069, 10.11347198], [76.23069763, 10.11347198], [76.23069763, 10.11263847], [76.23124695, 10.11264038], [76.23124695, 10.11207962], [76.23152924, 10.11208439], [76.23152924, 10.1115284], [76.23458099, 10.11154175], [76.23458099, 10.11124992], [76.23486328, 10.11124992], [76.23486328, 10.11096954], [76.23513794, 10.1109724], [76.23513794, 10.10958385], [76.23542023, 10.10958385], [76.23542023, 10.10819435], [76.23430634, 10.10818005], [76.23430634, 10.10902977], [76.23402405, 10.10902786], [76.23402405, 10.10986233], [76.23374939, 10.10986233], [76.23374939, 10.10958385], [76.23264313, 10.10958195], [76.23264313, 10.11013985], [76.23236084, 10.11013985], [76.23236084, 10.1109724], [76.23124695, 10.1109724], [76.23124695, 10.11069393], [76.23097229, 10.11069393], [76.23097229, 10.10958385], [76.23124695, 10.10958385], [76.23124695, 10.10902786], [76.23152924, 10.10902977], [76.23152924, 10.10847187], [76.23180389, 10.10847187], [76.23180389, 10.10791779], [76.23208618, 10.10791969], [76.23208618, 10.10736179], [76.23236084, 10.10736179], [76.23236084, 10.10653019], [76.23264313, 10.10653019], [76.23264313, 10.10541058], [76.23291779, 10.10541534], [76.23291779, 10.10486126], [76.23319244, 10.10486126], [76.23319244, 10.10402679], [76.2334671, 10.10402966], [76.2334671, 10.1026392], [76.23374939, 10.1026392], [76.23374939, 10.1020813], [76.23402405, 10.10208321], [76.23402405, 10.10069466], [76.23430634, 10.10069466], [76.23430634, 10.09986115], [76.23458099, 10.09986115], [76.23458099, 10.09875107], [76.23486328, 10.09875107], [76.23486328, 10.09847069], [76.23513794, 10.0984726], [76.23513794, 10.09763908], [76.23542023, 10.09764099], [76.23542023, 10.09708118], [76.23569489, 10.09708309], [76.23569489, 10.09624863], [76.23596954, 10.09624863], [76.23596954, 10.09569454], [76.23625183, 10.09569454], [76.23625183, 10.09541702], [76.23652649, 10.09542084], [76.23652649, 10.09486103], [76.23680878, 10.09486103], [76.23680878, 10.09319496], [76.23708344, 10.09319496], [76.23708344, 10.09208202], [76.23680878, 10.09208202], [76.23680878, 10.09152889], [76.23652649, 10.0915308], [76.23652649, 10.09125042], [76.23680878, 10.09125042], [76.23680878, 10.09097195], [76.23735809, 10.09097195], [76.23735809, 10.09069443], [76.23764038, 10.09069443], [76.23764038, 10.09041595], [76.2379303, 10.09043026], [76.2379303, 10.08931065], [76.23819733, 10.08931065], [76.23819733, 10.08875275], [76.23847198, 10.08875275], [76.23847198, 10.08819199], [76.23874664, 10.08819389], [76.23874664, 10.08791637], [76.23902893, 10.08792114], [76.23902893, 10.08708191], [76.23930359, 10.08708191], [76.23930359, 10.08652782], [76.23958588, 10.08652973], [76.23958588, 10.08514023], [76.23986053, 10.08514023], [76.23986053, 10.08403015], [76.24014282, 10.08403015], [76.24014282, 10.08263969], [76.24041748, 10.08263969], [76.24041748, 10.08181], [76.24067688, 10.08181], [76.24067688, 10.08069134], [76.24097443, 10.0806942], [76.24097443, 10.08014011], [76.24124908, 10.08014202], [76.24124908, 10.07958126], [76.24153137, 10.07958412], [76.24153137, 10.07930565], [76.24180603, 10.07931042], [76.24180603, 10.07763863], [76.24208069, 10.07763863], [76.24208069, 10.07708073], [76.24236298, 10.07708263], [76.24236298, 10.07624912], [76.24263763, 10.07625198], [76.24263763, 10.07543087], [76.24236298, 10.07543087], [76.24236298, 10.07486057], [76.24208069, 10.07486057], [76.24208069, 10.07458305], [76.23986053, 10.07458305], [76.23986053, 10.07486057], [76.23958588, 10.07486057], [76.23958588, 10.07514191], [76.23930359, 10.07513905], [76.23930359, 10.07569313], [76.23902893, 10.07569313], [76.23902893, 10.07597256], [76.23874664, 10.07597065], [76.23874664, 10.07653046], [76.23847198, 10.07652664], [76.23847198, 10.07708263], [76.23819733, 10.07708263], [76.23819733, 10.07736111], [76.23791504, 10.07736111], [76.23791504, 10.07847118], [76.23764038, 10.07846928], [76.23764038, 10.07903194], [76.23735809, 10.07902718], [76.23735809, 10.07958412], [76.23680878, 10.07958412], [76.23680878, 10.07986164], [76.23652649, 10.07986164], [76.23652649, 10.08041954], [76.23625183, 10.08041763], [76.23625183, 10.0806942], [76.23652649, 10.0806942], [76.23652649, 10.08097172], [76.23625183, 10.08096886], [76.23625183, 10.08152962], [76.23596954, 10.08152962], [76.23596954, 10.08181], [76.23568726, 10.08181], [76.23568726, 10.08292007], [76.23542023, 10.08292007], [76.23542023, 10.08374977], [76.23486328, 10.08374977], [76.23486328, 10.08403015], [76.23458099, 10.08402824], [76.23458099, 10.08430576], [76.23430634, 10.08430576], [76.23430634, 10.08485985], [76.23402405, 10.08485985], [76.23402405, 10.08569431], [76.23374939, 10.08569431], [76.23374939, 10.08625031], [76.23401642, 10.08625031], [76.23401642, 10.08764267], [76.23374939, 10.08764267], [76.23374939, 10.08792114], [76.23319244, 10.08791637], [76.23319244, 10.08819389], [76.23291779, 10.08819199], [76.23291779, 10.08875275], [76.23264313, 10.08875275], [76.23264313, 10.08903122], [76.23236084, 10.08903122], [76.23236084, 10.08931065], [76.23208618, 10.08930588], [76.23208618, 10.08958435], [76.23152924, 10.08957958], [76.23152924, 10.0901413], [76.23124695, 10.09013844], [76.23124695, 10.09097195], [76.23097229, 10.09097004], [76.23097229, 10.0915308], [76.23069763, 10.0915308], [76.23069763, 10.09181118], [76.23041534, 10.09180355], [76.23041534, 10.09208202], [76.23014069, 10.09208012], [76.23014069, 10.09264088], [76.2298584, 10.09264088], [76.2298584, 10.09403133], [76.23014069, 10.09403133], [76.23014069, 10.09514141], [76.2298584, 10.09514141], [76.2298584, 10.09542084], [76.22958374, 10.09541702], [76.22958374, 10.09597301], [76.22930908, 10.09597301], [76.22930908, 10.09624863], [76.23041534, 10.09624863], [76.23041534, 10.09597301], [76.23069763, 10.09597301], [76.23069763, 10.09569454], [76.23097229, 10.09569454], [76.23097229, 10.09541702], [76.23124695, 10.09542084], [76.23124695, 10.09514141], [76.23152924, 10.09514141], [76.23152924, 10.0945797], [76.23180389, 10.09458256], [76.23180389, 10.09402561], [76.23097229, 10.09403133], [76.23097229, 10.09292126], [76.23180389, 10.09291744], [76.23180389, 10.09347343], [76.23208618, 10.09346962], [76.23208618, 10.09430885], [76.23347473, 10.09430695], [76.23347473, 10.09458256], [76.23319244, 10.0945797], [76.23319244, 10.09514141], [76.23264313, 10.09514141], [76.23264313, 10.09542084], [76.23236084, 10.09541702], [76.23236084, 10.09569454], [76.23180389, 10.09569454], [76.23180389, 10.09597301], [76.23152924, 10.09597301], [76.23152924, 10.09624863], [76.23124695, 10.09624195], [76.23124695, 10.09680939], [76.23097229, 10.09680462], [76.23097229, 10.09736061], [76.23069763, 10.09736061], [76.23069763, 10.09792233], [76.22846985, 10.0979166], [76.22846985, 10.0984726], [76.22820282, 10.09847069], [76.22820282, 10.09903145], [76.22846985, 10.09902668], [76.22846985, 10.10097313], [76.22820282, 10.10097122], [76.22820282, 10.10181046], [76.2279129, 10.10181046], [76.2279129, 10.10237026], [76.2270813, 10.10237026], [76.2270813, 10.10181046], [76.22680664, 10.10181046], [76.22680664, 10.10153198], [76.2259903, 10.10153198], [76.2259903, 10.10125065], [76.22541809, 10.10125065], [76.22541809, 10.10097122], [76.22569275, 10.10097313], [76.22569275, 10.10041714], [76.2259903, 10.10042191], [76.2259903, 10.09986115], [76.22624969, 10.09986115], [76.22624969, 10.09958267], [76.22652435, 10.09958267], [76.22652435, 10.09902668], [76.22680664, 10.09903145], [76.22680664, 10.09847069], [76.22736359, 10.0984726], [76.22736359, 10.09819508], [76.2270813, 10.09819508], [76.2270813, 10.0979166], [76.22735596, 10.09792233], [76.22735596, 10.09764099], [76.22763824, 10.09764099], [76.22763824, 10.09680939], [76.2279129, 10.09680939], [76.2279129, 10.09653091], [76.22873688, 10.09653091], [76.22873688, 10.09624195], [76.22846985, 10.09624863], [76.22846985, 10.09597301], [76.22875214, 10.09597301], [76.22875214, 10.09569454], [76.22902679, 10.09569454], [76.22902679, 10.09458256], [76.22819519, 10.09458256], [76.22819519, 10.09430695], [76.22763824, 10.09430695], [76.22763824, 10.09458256], [76.2270813, 10.0945797], [76.2270813, 10.09514141], [76.22680664, 10.09514141], [76.22680664, 10.09542084], [76.22652435, 10.09541702], [76.22652435, 10.09624863], [76.22624969, 10.09624195], [76.22624969, 10.09653091], [76.22597504, 10.09652901], [76.22597504, 10.09708309], [76.22569275, 10.09708309], [76.22569275, 10.09736061], [76.22541809, 10.09736061], [76.22541809, 10.09792233], [76.22486115, 10.0979166], [76.22486115, 10.0984726], [76.22429657, 10.09847069], [76.22429657, 10.09875107], [76.22402954, 10.09875107], [76.22402954, 10.09986115], [76.22374725, 10.09986115], [76.22374725, 10.10014057], [76.2234726, 10.10013866], [76.2234726, 10.10069466], [76.22319794, 10.10069084], [76.22319794, 10.10181046], [76.22291565, 10.10180473], [76.22291565, 10.10208321], [76.2223587, 10.1020813], [76.2223587, 10.10291958], [76.22208405, 10.10291672], [76.22208405, 10.1034708], [76.22180939, 10.10347366], [76.22180176, 10.10374928], [76.2215271, 10.10374928], [76.2215271, 10.10431004], [76.22125244, 10.10430527], [76.22125244, 10.10486126], [76.22097015, 10.10485935], [76.22097015, 10.10513973], [76.2206955, 10.10513973], [76.2206955, 10.10569572], [76.22041321, 10.10569572], [76.22041321, 10.10597134], [76.22013855, 10.10597134], [76.22013855, 10.10653019], [76.21985626, 10.10653019], [76.21985626, 10.10680962], [76.2195816, 10.1068058], [76.2195816, 10.10708427], [76.21930695, 10.10708141], [76.21930695, 10.10736179], [76.21901703, 10.10736179], [76.21901703, 10.10791969], [76.21875, 10.10791779], [76.21875, 10.10847187], [76.21848297, 10.10847187], [76.21848297, 10.10902977], [76.21819305, 10.10902786], [76.21819305, 10.10958385], [76.2179184, 10.10958385], [76.2179184, 10.10986233], [76.21763611, 10.10986042], [76.21763611, 10.11013985], [76.21736145, 10.11013985], [76.21736145, 10.11069393], [76.21708679, 10.11069202], [76.21708679, 10.11124992], [76.21679688, 10.11124992], [76.21679688, 10.11181068], [76.21624756, 10.11180592], [76.21624756, 10.11236], [76.2159729, 10.11236], [76.2159729, 10.11264038], [76.21569824, 10.11264038], [76.21569824, 10.11292267], [76.2159729, 10.11291599], [76.2159729, 10.11319447], [76.21624756, 10.11319447], [76.21624756, 10.11569405], [76.21847534, 10.11569405], [76.21847534, 10.11541557], [76.21875, 10.1154213], [76.21875, 10.11485958], [76.21902466, 10.11486244], [76.21902466, 10.11430645], [76.21930695, 10.11431122], [76.21930695, 10.11403275], [76.21901703, 10.11403275], [76.21901703, 10.11375046], [76.21847534, 10.11375046], [76.21847534, 10.11347198], [76.2179184, 10.11347198], [76.2179184, 10.11319447], [76.21819305, 10.11319447], [76.21819305, 10.11263847], [76.21875, 10.11264038], [76.21875, 10.11236], [76.21902466, 10.11236], [76.21901703, 10.11181068], [76.21930695, 10.11181068], [76.21930695, 10.11124992], [76.21956635, 10.11124992], [76.21956635, 10.11069202], [76.21986389, 10.11069393], [76.21986389, 10.11041641], [76.22013855, 10.11042023], [76.22013855, 10.10986042], [76.22041321, 10.10986233], [76.22041321, 10.10930634], [76.22070313, 10.10931015], [76.22070313, 10.10902977], [76.22097015, 10.10902977], [76.22097015, 10.10847187], [76.22125244, 10.10847187], [76.22125244, 10.10791779], [76.2215271, 10.10791969], [76.2215271, 10.10736179], [76.22180176, 10.10736179], [76.22180176, 10.10680962], [76.22207642, 10.10680962], [76.22207642, 10.10624886], [76.2223587, 10.10624886], [76.2223587, 10.10597134], [76.22264099, 10.10597134], [76.22264099, 10.10541534], [76.22291565, 10.10541534], [76.22291565, 10.10458279], [76.22319794, 10.10458279], [76.22319794, 10.10430527], [76.2234726, 10.10431004], [76.2234726, 10.10402966], [76.22374725, 10.10402966], [76.22374725, 10.10346889], [76.22429657, 10.10346889], [76.22429657, 10.10374928], [76.22458649, 10.10374928], [76.22458649, 10.10402966], [76.22429657, 10.10402966], [76.22429657, 10.10431004], [76.22402954, 10.10430527], [76.22402954, 10.10458279], [76.22374725, 10.10458279], [76.22374725, 10.10486126], [76.2234726, 10.10485935], [76.2234726, 10.10513973], [76.22374725, 10.10513973], [76.22374725, 10.10541534], [76.22402954, 10.10541534], [76.22402954, 10.10569572], [76.2243042, 10.10569572], [76.2243042, 10.10597134], [76.22402954, 10.10597134], [76.22402954, 10.10764027], [76.22319794, 10.10764027], [76.22319794, 10.10875034], [76.2234726, 10.10875034], [76.2234726, 10.10902977], [76.22374725, 10.10902977], [76.22374725, 10.10931015], [76.22486115, 10.10931015], [76.22486115, 10.10902977], [76.22541809, 10.10902977], [76.22541809, 10.10931015], [76.22624969, 10.10931015], [76.22624969, 10.11013985], [76.2259903, 10.11013985], [76.2259903, 10.11042023], [76.22570038, 10.11042023], [76.22570038, 10.11124992], [76.22541809, 10.11124992], [76.22541809, 10.11154175], [76.2251358, 10.11154175], [76.2251358, 10.11181068], [76.22458649, 10.11180592], [76.22458649, 10.11208439], [76.2243042, 10.11208439], [76.2243042, 10.11319447], [76.22402954, 10.11319447], [76.22402954, 10.11347198], [76.22374725, 10.11347198], [76.22374725, 10.11375046], [76.2234726, 10.11375046], [76.2234726, 10.11403275], [76.22319794, 10.11403275], [76.22319794, 10.11431122], [76.22291565, 10.11430645], [76.22291565, 10.11458206], [76.22264099, 10.11458206], [76.22264099, 10.11486244], [76.2223587, 10.11485958], [76.2223587, 10.1154213], [76.22208405, 10.11541557], [76.22208405, 10.11569405], [76.22180939, 10.11569405], [76.22180176, 10.11597157], [76.2215271, 10.11596966], [76.2215271, 10.11625004], [76.2223587, 10.11625004], [76.2223587, 10.11653137], [76.22319794, 10.11653137], [76.22319794, 10.11680889], [76.2234726, 10.11680603], [76.2234726, 10.11736012], [76.22319794, 10.11735058], [76.22319794, 10.11875057], [76.22291565, 10.11875057], [76.22291565, 10.11958218], [76.22264099, 10.11958218], [76.22264099, 10.12041664], [76.2223587, 10.12041664], [76.2223587, 10.12125111], [76.22207642, 10.12125111], [76.22207642, 10.12264061], [76.22180939, 10.1226387], [76.22180176, 10.12319469], [76.2215271, 10.12318993], [76.2215271, 10.12375069], [76.22125244, 10.12375069], [76.22125244, 10.12403107], [76.2215271, 10.12402916], [76.2215271, 10.12486076], [76.22125244, 10.12486076], [76.22125244, 10.12569523], [76.22097015, 10.12569523], [76.22097015, 10.12625122], [76.22070313, 10.12625122], [76.22070313, 10.12654114], [76.22041321, 10.12652683], [76.22041321, 10.12708282], [76.22013855, 10.12708282], [76.22013855, 10.1273613], [76.21985626, 10.1273613], [76.21985626, 10.12764072], [76.21956635, 10.12764072], [76.21956635, 10.12792015], [76.21930695, 10.12791729], [76.21930695, 10.12819481], [76.21901703, 10.12819099], [76.21902466, 10.12874889], [76.21875, 10.12874889], [76.21875, 10.12902927], [76.21848297, 10.12902927], [76.21848297, 10.12930965], [76.21819305, 10.12930965], [76.21819305, 10.13013935], [76.21763611, 10.13013935], [76.21763611, 10.13041973], [76.21736145, 10.13041687], [76.21736145, 10.13069534], [76.21708679, 10.13069534], [76.21708679, 10.13097095], [76.21652985, 10.13097095], [76.21652985, 10.13124943], [76.2159729, 10.13124943], [76.2159729, 10.13097095], [76.21347046, 10.13097095], [76.21347046, 10.13069534], [76.2131958, 10.13069534], [76.2131958, 10.13097095], [76.21290588, 10.13097095], [76.21291351, 10.13124943], [76.21263885, 10.13124943], [76.21263885, 10.13181019], [76.21235657, 10.13181019], [76.21235657, 10.13264179], [76.21208191, 10.13263988], [76.21208191, 10.13319302], [76.21180725, 10.13319588], [76.21180725, 10.13347054], [76.21151733, 10.13347054], [76.21151733, 10.13375187], [76.21125031, 10.13375187], [76.21125031, 10.13347054], [76.21098328, 10.13347054], [76.21098328, 10.13375187], [76.21069336, 10.13374996], [76.21069336, 10.13458443], [76.21125031, 10.13458443], [76.21125031, 10.13569355], [76.21069336, 10.13569355], [76.21069336, 10.13513756], [76.2104187, 10.13514042], [76.2104187, 10.13486195], [76.20762634, 10.13486195], [76.20762634, 10.13514042], [76.20735931, 10.13513756], [76.20735931, 10.13569355], [76.2076416, 10.13569355], [76.2076416, 10.13597202], [76.20791626, 10.13597202], [76.20791626, 10.13624954], [76.20874786, 10.13624954], [76.20874786, 10.13652992], [76.20929718, 10.13652992], [76.20929718, 10.1368103], [76.2095871, 10.13680553], [76.2095871, 10.13708401], [76.21069336, 10.13708401], [76.21069336, 10.13736153], [76.21098328, 10.13735962], [76.21098328, 10.13764], [76.21125031, 10.13764], [76.21125031, 10.13792038], [76.21208191, 10.13791561], [76.21208191, 10.13819408], [76.21235657, 10.13818932], [76.21235657, 10.13848114], [76.21263885, 10.13848114], [76.21263885, 10.13931274], [76.21208191, 10.13930607], [76.21208191, 10.13958359], [76.21180725, 10.13958168], [76.21180725, 10.14042091], [76.21208191, 10.14042091], [76.21208191, 10.14264011], [76.21180725, 10.14263821], [76.21180725, 10.1431942], [76.21152496, 10.1431942], [76.21152496, 10.14347172], [76.21125031, 10.14347172], [76.21125031, 10.14375019], [76.21070099, 10.14375019], [76.21070099, 10.14403057], [76.20986176, 10.14403057], [76.20986176, 10.14431095], [76.20930481, 10.14430428], [76.20930481, 10.14458466], [76.20791626, 10.14458466], [76.20791626, 10.14486027], [76.20762634, 10.14486027], [76.20762634, 10.14514065], [76.20735931, 10.14514065], [76.20735931, 10.14542103], [76.20680237, 10.14542103], [76.20680237, 10.14625072], [76.20652771, 10.14625072], [76.20652771, 10.14708233], [76.20569611, 10.14708233], [76.20569611, 10.14680672], [76.20540619, 10.14681053], [76.20540619, 10.14625072], [76.20569611, 10.14625072], [76.20569611, 10.14542103], [76.20540619, 10.14542103], [76.20540619, 10.14486027], [76.20513916, 10.14486027], [76.20513916, 10.14458466], [76.2048645, 10.14458466], [76.2048645, 10.14430428], [76.20541382, 10.14430428], [76.20541382, 10.14458466], [76.20569611, 10.14458466], [76.20569611, 10.14486027], [76.20625305, 10.14486027], [76.20625305, 10.14430428], [76.20652771, 10.14431095], [76.20652771, 10.14375019], [76.20625305, 10.14375019], [76.20625305, 10.14347172], [76.20597076, 10.14347172], [76.20597076, 10.14235973], [76.20569611, 10.14235973], [76.20569611, 10.14097214], [76.20402527, 10.14097214], [76.20402527, 10.14069366], [76.20347595, 10.14069366], [76.20347595, 10.13986206], [76.20375061, 10.13986206], [76.20375061, 10.13930607], [76.2040329, 10.13931274], [76.2040329, 10.13875008], [76.20430756, 10.13875008], [76.20430756, 10.13792038], [76.20347595, 10.13791561], [76.20347595, 10.13819408], [76.20319366, 10.13819408], [76.20319366, 10.13764], [76.20347595, 10.13764], [76.20347595, 10.13707924], [76.20375061, 10.13708401], [76.20375061, 10.13680553], [76.2040329, 10.1368103], [76.2040329, 10.13652992], [76.20430756, 10.13652992], [76.20430756, 10.13624954], [76.20456696, 10.13624954], [76.20456696, 10.13597202], [76.2048645, 10.13597202], [76.2048645, 10.13541794], [76.20513916, 10.13541985], [76.20513916, 10.13514042], [76.20540619, 10.13514042], [76.20540619, 10.13486195], [76.20569611, 10.13486195], [76.20569611, 10.13458443], [76.20597076, 10.13458443], [76.20597076, 10.13402843], [76.20625305, 10.13403034], [76.20625305, 10.13347054], [76.20652771, 10.13347054], [76.20652771, 10.13097095], [76.20708466, 10.13097095], [76.20708466, 10.13069534], [76.20680237, 10.13069534], [76.20680237, 10.13013935], [76.20569611, 10.13013935], [76.20569611, 10.13097095], [76.20541382, 10.13097095], [76.20541382, 10.13236237], [76.20513916, 10.13234997], [76.20513916, 10.13292027], [76.2048645, 10.13291454], [76.2048645, 10.13319302], [76.20458221, 10.13319588], [76.20458221, 10.13347054], [76.20375061, 10.13347054], [76.20375061, 10.13375187], [76.20347595, 10.13375187], [76.20347595, 10.13347054], [76.20291901, 10.13347054], [76.20291901, 10.13291454], [76.20263672, 10.13292027], [76.20263672, 10.13264179], [76.20236206, 10.13264179], [76.20236206, 10.13208103], [76.20263672, 10.13208294], [76.20263672, 10.13180542], [76.20318604, 10.13181019], [76.20318604, 10.13152981], [76.20456696, 10.13152981], [76.20456696, 10.13041973], [76.20485687, 10.13041973], [76.20485687, 10.12986088], [76.20625305, 10.12986088], [76.20625305, 10.12958336], [76.20652771, 10.12958336], [76.20652771, 10.12902737], [76.20680237, 10.12902927], [76.20680237, 10.12847137], [76.20708466, 10.12847328], [76.20708466, 10.12791729], [76.20735931, 10.12792015], [76.20735931, 10.12764072], [76.20707703, 10.12764072], [76.20707703, 10.1273613], [76.20735931, 10.1273613], [76.20735931, 10.12708282], [76.20708466, 10.12708282], [76.20708466, 10.12652683], [76.20735931, 10.12654114], [76.20735931, 10.12625122], [76.20707703, 10.12625122], [76.20707703, 10.12430859], [76.20735931, 10.12430859], [76.20735931, 10.12318993], [76.2076416, 10.12319469], [76.2076416, 10.12236118], [76.20791626, 10.12236118], [76.20791626, 10.12152672], [76.20819092, 10.12153053], [76.20819092, 10.12125111], [76.20847321, 10.12125111], [76.20847321, 10.12097263], [76.20791626, 10.12097263], [76.20791626, 10.12069511], [76.20819092, 10.12069511], [76.20819092, 10.12041664], [76.20847321, 10.12041664], [76.20847321, 10.1198597], [76.20874786, 10.1198597], [76.20874786, 10.11930656], [76.20903015, 10.11931133], [76.20903015, 10.11875057], [76.20929718, 10.11875057], [76.20929718, 10.11819172], [76.2095871, 10.11819363], [76.2095871, 10.11708355], [76.20986176, 10.11708355], [76.20986176, 10.11625004], [76.21013641, 10.11625004], [76.21013641, 10.11569023], [76.2104187, 10.11569405], [76.2104187, 10.11541557], [76.21013641, 10.1154213], [76.21013641, 10.11458015], [76.2104187, 10.11458206], [76.2104187, 10.11375046], [76.21069336, 10.11375046], [76.21070099, 10.1131916], [76.21097565, 10.11319447], [76.21097565, 10.11263847], [76.21125031, 10.11264038], [76.21125031, 10.11207962], [76.21152496, 10.11208439], [76.21152496, 10.1109724], [76.21180725, 10.1109724], [76.21180725, 10.11013985], [76.21208191, 10.11013985], [76.21208191, 10.10958195], [76.2123642, 10.10958385], [76.2123642, 10.10930634], [76.21290588, 10.10931015], [76.21290588, 10.10791969], [76.2131958, 10.10791969], [76.2131958, 10.10653019], [76.21347046, 10.10653019], [76.21347046, 10.10597134], [76.21375275, 10.10597134], [76.21375275, 10.10569572], [76.2140274, 10.10569572], [76.2140274, 10.10513973], [76.21376038, 10.10513973], [76.21376038, 10.10458088], [76.2131958, 10.10458279], [76.2131958, 10.10430527], [76.21290588, 10.10431004], [76.21290588, 10.10346889], [76.2131958, 10.1034708], [76.2131958, 10.10319328], [76.2140274, 10.10319328], [76.2140274, 10.10152721], [76.21376038, 10.10153198], [76.21376038, 10.10097122], [76.2140274, 10.10097313], [76.2140274, 10.10041714], [76.21430206, 10.10042191], [76.21430206, 10.09958076], [76.21458435, 10.09958267], [76.21458435, 10.09930515], [76.21430206, 10.09931183], [76.21430206, 10.09792233], [76.21457672, 10.09792233], [76.21457672, 10.09736061], [76.21485901, 10.09736061], [76.21485901, 10.09680462], [76.2151413, 10.09680939], [76.2151413, 10.09624195], [76.21541595, 10.09624863], [76.21541595, 10.09541702], [76.21569061, 10.09542084], [76.21569824, 10.09514141], [76.2159729, 10.09514141], [76.2159729, 10.09486103], [76.21624756, 10.09486103], [76.21624756, 10.09291744], [76.21652985, 10.09292126], [76.21652985, 10.09208012], [76.2168045, 10.09208202], [76.2168045, 10.09152889], [76.21708679, 10.0915308], [76.21708679, 10.09125042], [76.21736145, 10.09125042], [76.21736145, 10.09069443], [76.21763611, 10.09069443], [76.21763611, 10.08985996], [76.21736145, 10.08985996], [76.21736145, 10.08902836], [76.2168045, 10.08902836], [76.2168045, 10.08958435], [76.21652985, 10.08957958], [76.21652985, 10.0901413], [76.21624756, 10.09013844], [76.21624756, 10.09097195], [76.2159729, 10.09097004], [76.2159729, 10.0915308], [76.21569824, 10.0915308], [76.21569824, 10.09292126], [76.21541595, 10.09291744], [76.21541595, 10.09319496], [76.2151413, 10.09318066], [76.2151413, 10.09403133], [76.21485901, 10.09402561], [76.21485901, 10.09597301], [76.21457672, 10.09597111], [76.21457672, 10.09653091], [76.21430206, 10.09653091], [76.21430206, 10.09680939], [76.21375275, 10.09680462], [76.21375275, 10.09708309], [76.21347046, 10.09708118], [76.21347046, 10.09875107], [76.2131958, 10.09875107], [76.2131958, 10.09986115], [76.21290588, 10.09986115], [76.21290588, 10.10042191], [76.21263885, 10.10042191], [76.21263885, 10.10125065], [76.21235657, 10.10125065], [76.21235657, 10.10153198], [76.21180725, 10.10153198], [76.21180725, 10.10181046], [76.21153259, 10.10181046], [76.21153259, 10.10237026], [76.21125031, 10.10236073], [76.21125031, 10.1034708], [76.21180725, 10.10346889], [76.21180725, 10.10402966], [76.21153259, 10.10402966], [76.21153259, 10.10431004], [76.21098328, 10.10431004], [76.21098328, 10.10402966], [76.21070099, 10.10402966], [76.21070099, 10.10374928], [76.20929718, 10.10374928], [76.20929718, 10.10346889], [76.20903015, 10.1034708], [76.20903015, 10.10319328], [76.20847321, 10.10319328], [76.20847321, 10.10152721], [76.20874786, 10.10153198], [76.20874786, 10.10097122], [76.20903015, 10.10097313], [76.20903015, 10.10069466], [76.20930481, 10.10069466], [76.20930481, 10.10013866], [76.2095871, 10.10014057], [76.2095871, 10.09986115], [76.20930481, 10.09986115], [76.20930481, 10.09930515], [76.20903015, 10.09931183], [76.20903015, 10.09903145], [76.20874786, 10.09903145], [76.20874786, 10.09875107], [76.20929718, 10.09875107], [76.20929718, 10.09847069], [76.2095871, 10.0984726], [76.2095871, 10.09819508], [76.20986176, 10.09819508], [76.20986176, 10.0979166], [76.21013641, 10.09792233], [76.21013641, 10.09653091], [76.2104187, 10.09653091], [76.2104187, 10.09568977], [76.21069336, 10.09569454], [76.21069336, 10.09347343], [76.21097565, 10.09347343], [76.21097565, 10.09263802], [76.21125031, 10.09264088], [76.21125031, 10.09235954], [76.21097565, 10.09235954], [76.21097565, 10.09208202], [76.21069336, 10.09208202], [76.21069336, 10.09180355], [76.2104187, 10.09181118], [76.2104187, 10.09125042], [76.21069336, 10.09125042], [76.21069336, 10.09097195], [76.21125031, 10.09097195], [76.21125031, 10.09069443], [76.21180725, 10.09069443], [76.21180725, 10.09041595], [76.21235657, 10.09043026], [76.21235657, 10.0901413], [76.2131958, 10.0901413], [76.2131958, 10.09043026], [76.21375275, 10.09041595], [76.21375275, 10.09069443], [76.2140274, 10.09068966], [76.2140274, 10.0915308], [76.21376038, 10.0915308], [76.21376038, 10.09264088], [76.2140274, 10.09264088], [76.2140274, 10.09292126], [76.21457672, 10.09292126], [76.21457672, 10.09264088], [76.2151413, 10.09264088], [76.2151413, 10.0915308], [76.21541595, 10.0915308], [76.21541595, 10.09043026], [76.21569061, 10.09043026], [76.21569824, 10.08903122], [76.2159729, 10.08903122], [76.2159729, 10.08847046], [76.21624756, 10.08847237], [76.21624756, 10.08736229], [76.21569824, 10.08737087], [76.21569061, 10.08541965], [76.21541595, 10.08541965], [76.21541595, 10.08514023], [76.21430206, 10.08514023], [76.21430206, 10.08569431], [76.2140274, 10.08569431], [76.2140274, 10.08708191], [76.21430206, 10.08708191], [76.21430206, 10.08737087], [76.21457672, 10.08737087], [76.21457672, 10.08764267], [76.21485901, 10.08764267], [76.21485901, 10.08875275], [76.21457672, 10.08875275], [76.21457672, 10.08931065], [76.2140274, 10.08931065], [76.2140274, 10.08903122], [76.21376038, 10.08903122], [76.21376038, 10.08792114], [76.21347046, 10.08792114], [76.21347046, 10.08764267], [76.21263885, 10.08764267], [76.21263885, 10.08737087], [76.21235657, 10.08737087], [76.21235657, 10.08708191], [76.21263885, 10.08708191], [76.21263885, 10.08652782], [76.21290588, 10.08652973], [76.21290588, 10.08597183], [76.2131958, 10.08597183], [76.2131958, 10.08541584], [76.21290588, 10.08541965], [76.21291351, 10.08508968], [76.21291351, 10.08485985], [76.21263885, 10.08485985], [76.21263885, 10.08402824], [76.21290588, 10.08403015], [76.21290588, 10.08347034], [76.2131958, 10.08347225], [76.2131958, 10.08319378], [76.21370697, 10.08319378], [76.21541595, 10.08319378], [76.21541595, 10.08263779], [76.21569061, 10.08263969], [76.21569824, 10.08236027], [76.2159729, 10.08236217], [76.2159729, 10.0820837], [76.21624756, 10.0820837], [76.21624756, 10.0806942], [76.2159729, 10.0806942], [76.2159729, 10.08014011], [76.21624756, 10.08014202], [76.21624756, 10.07958126], [76.21652985, 10.07958412], [76.21652985, 10.07902718], [76.21679688, 10.07903194], [76.21679688, 10.0773592], [76.21708679, 10.07736111], [76.21708679, 10.07680511], [76.21736145, 10.07681179], [76.21736145, 10.07597065], [76.21763611, 10.07597065], [76.21763611, 10.07625198], [76.2179184, 10.07625198], [76.2179184, 10.07597065], [76.21819305, 10.07597256], [76.21819305, 10.07569313], [76.21847534, 10.07569313], [76.21847534, 10.07486057], [76.21875, 10.07486057], [76.21875, 10.07458305], [76.21902466, 10.07458305], [76.21902466, 10.07402706], [76.21930695, 10.07403183], [76.21930695, 10.07291889], [76.21956635, 10.07291889], [76.21956635, 10.07375145], [76.22097015, 10.07375145], [76.22097015, 10.07543087], [76.2206955, 10.07541656], [76.2206955, 10.07569313], [76.22041321, 10.07569313], [76.22041321, 10.07597256], [76.22013855, 10.07597065], [76.22013855, 10.07625198], [76.22041321, 10.07625198], [76.22041321, 10.07681179], [76.2206955, 10.07680511], [76.2206955, 10.07736111], [76.22041321, 10.0773592], [76.22041321, 10.07791996], [76.22013855, 10.07791805], [76.22013855, 10.07847118], [76.21985626, 10.07846928], [76.21985626, 10.07875156], [76.2195816, 10.0787487], [76.2195816, 10.07958412], [76.21930695, 10.07958126], [76.21930695, 10.08041954], [76.21902466, 10.08041763], [76.21902466, 10.08125019], [76.21875, 10.08124065], [76.21875, 10.08152962], [76.2179184, 10.08152771], [76.2179184, 10.0820837], [76.21819305, 10.08208179], [76.21819305, 10.08263969], [76.21847534, 10.08263779], [76.21847534, 10.08347225], [76.21819305, 10.08347225], [76.21819305, 10.08430576], [76.21847534, 10.08430576], [76.21847534, 10.08458424], [76.21930695, 10.08458424], [76.21930695, 10.08430576], [76.2195816, 10.08430576], [76.2195816, 10.08374977], [76.22013855, 10.08374977], [76.22013855, 10.08403015], [76.22041321, 10.08402824], [76.22041321, 10.08430576], [76.22125244, 10.08430576], [76.22125244, 10.08374977], [76.22097015, 10.08374977], [76.22097015, 10.08319092], [76.22125244, 10.08319378], [76.22125244, 10.08291626], [76.2215271, 10.08292007], [76.2215271, 10.08181], [76.22180176, 10.08181], [76.22180176, 10.08096886], [76.22264099, 10.08097172], [76.22264099, 10.08014011], [76.22180176, 10.08014202], [76.22180176, 10.07986164], [76.2215271, 10.07986164], [76.2215271, 10.07930565], [76.22180176, 10.07931042], [76.22180176, 10.07875156], [76.22207642, 10.07875156], [76.22207642, 10.07820034], [76.2223587, 10.07820034], [76.2223587, 10.07763863], [76.22264099, 10.07763863], [76.22264099, 10.0773592], [76.22291565, 10.07736111], [76.22291565, 10.07680511], [76.22319794, 10.07680511], [76.22319794, 10.07708263], [76.2234726, 10.07708263], [76.2234726, 10.07736111], [76.22402954, 10.07736111], [76.22402954, 10.07680511], [76.22429657, 10.07681179], [76.22429657, 10.07597065], [76.22319794, 10.07597256], [76.22319794, 10.07541656], [76.2234726, 10.07543087], [76.2234726, 10.0743103], [76.22374725, 10.0743103], [76.22374725, 10.07375145], [76.22402954, 10.07375145], [76.22402954, 10.07319069], [76.2243042, 10.07319546], [76.2243042, 10.07291698], [76.22486115, 10.07291889], [76.22486115, 10.07264137], [76.22541809, 10.07264137], [76.22541809, 10.07236099], [76.2251358, 10.07236099], [76.2251358, 10.07208347], [76.22486115, 10.07208347], [76.22486115, 10.071805], [76.22458649, 10.07181168], [76.22458649, 10.07125092], [76.22486115, 10.07125092], [76.22486115, 10.07097054], [76.22569275, 10.0709734], [76.22569275, 10.06902885], [76.22624969, 10.06902885], [76.22624969, 10.06847095], [76.22541809, 10.06847286], [76.22541809, 10.06736088], [76.22569275, 10.06736088], [76.22569275, 10.06680679], [76.2259903, 10.06681061], [76.2259903, 10.06597042], [76.22624969, 10.06597328], [76.22624969, 10.06541634], [76.22735596, 10.0654211], [76.22735596, 10.06514072], [76.22763824, 10.06514072], [76.22763824, 10.06486034], [76.2279129, 10.06486034], [76.2279129, 10.06430435], [76.22820282, 10.06431103], [76.22820282, 10.06403065], [76.22846985, 10.06400967], [76.22846985, 10.06319427], [76.22873688, 10.06320095], [76.22873688, 10.06236172], [76.22820282, 10.06236172], [76.22820282, 10.06208038], [76.22763824, 10.06208229], [76.22763824, 10.06124973], [76.2279129, 10.06124973], [76.2279129, 10.06069183], [76.22846985, 10.06069183], [76.22846985, 10.06124973], [76.22930908, 10.06124973], [76.22930908, 10.06097031], [76.22958374, 10.06097221], [76.22958374, 10.06041622], [76.2298584, 10.06042099], [76.2298584, 10.05986023], [76.23014069, 10.05986214], [76.23014069, 10.05847168], [76.2298584, 10.05847168], [76.2298584, 10.05819416], [76.22930908, 10.05819416], [76.22930908, 10.05791569], [76.22902679, 10.05792046], [76.22902679, 10.05596924], [76.22846985, 10.0559721], [76.22846985, 10.05569363], [76.2279129, 10.05569363], [76.2279129, 10.05541801], [76.22736359, 10.05541801], [76.22736359, 10.05513763], [76.22680664, 10.05513954], [76.22680664, 10.05486202], [76.22651672, 10.05486202], [76.22651672, 10.05458069], [76.22624969, 10.05458355], [76.22624969, 10.05486202], [76.22597504, 10.05486202], [76.22597504, 10.05402756], [76.22541809, 10.05403042], [76.22541809, 10.05513954], [76.2251358, 10.05513763], [76.2251358, 10.05708408], [76.22486115, 10.05708408], [76.22486115, 10.05766964], [76.22486115, 10.05958366], [76.22458649, 10.05957985], [76.22458649, 10.06236172], [76.2243042, 10.06235981], [76.2243042, 10.06263065], [76.22429657, 10.06292057], [76.22402954, 10.0629158], [76.22402954, 10.06375027], [76.22374725, 10.06375027], [76.22374725, 10.06514072], [76.2234726, 10.06513786], [76.2234726, 10.06597328], [76.22319794, 10.06597328], [76.22319794, 10.06708336], [76.22292328, 10.06707954], [76.22292328, 10.06764126], [76.22264099, 10.06764126], [76.22264099, 10.06792068], [76.22180176, 10.06792068], [76.22180176, 10.06777096], [76.22180176, 10.06763935], [76.2215271, 10.06764126], [76.2215271, 10.06754112], [76.2215271, 10.06736088], [76.22125244, 10.06736088], [76.22125244, 10.06764126], [76.22097015, 10.06763935], [76.22093964, 10.06785965], [76.22083282, 10.06791687], [76.2206955, 10.06791687], [76.2206955, 10.06819534], [76.22041321, 10.06819534], [76.22041321, 10.06847286], [76.22013855, 10.06847286], [76.22013855, 10.06875134], [76.21985626, 10.06875134], [76.21985626, 10.06847095], [76.2195816, 10.06847286], [76.2195816, 10.06819534], [76.21986389, 10.06819534], [76.21986389, 10.06763935], [76.22013855, 10.06764126], [76.22013855, 10.06736088], [76.2206955, 10.06736088], [76.2206955, 10.06708336], [76.22125244, 10.06708336], [76.22125244, 10.06680679], [76.22097015, 10.06681061], [76.22097015, 10.06569004], [76.2206955, 10.06569481], [76.2206955, 10.06430435], [76.22097015, 10.06431103], [76.22097015, 10.06375027], [76.22125244, 10.06375027], [76.22125244, 10.06319427], [76.2215271, 10.06320095], [76.2215271, 10.06208038], [76.22168732, 10.06208229], [76.22180176, 10.06208229], [76.22180176, 10.06124973], [76.22207642, 10.06124973], [76.22207642, 10.06097031], [76.2223587, 10.06097221], [76.2223587, 10.06069374], [76.22264099, 10.06069374], [76.22264099, 10.05969143], [76.22264099, 10.05958366], [76.2215271, 10.05958366], [76.2215271, 10.05986214], [76.22097015, 10.05986214], [76.22097015, 10.06013775], [76.22013855, 10.06013775], [76.22013855, 10.05986214], [76.21986389, 10.05986214], [76.21986389, 10.05624962], [76.22013855, 10.05624962], [76.22013855, 10.05596924], [76.2206955, 10.0559721], [76.2206955, 10.05569363], [76.22097015, 10.05569363], [76.22097015, 10.05430603], [76.22125244, 10.05431938], [76.22125244, 10.05347157], [76.2215271, 10.05347157], [76.2215271, 10.05319309], [76.22207642, 10.05319118], [76.22207642, 10.05375195], [76.2223587, 10.05375195], [76.2223587, 10.05403042], [76.22264099, 10.05403042], [76.22264099, 10.05431938], [76.22319794, 10.05431938], [76.22319794, 10.05403042], [76.22402954, 10.05403042], [76.22402954, 10.05375195], [76.22458649, 10.05375195], [76.22458649, 10.05264187], [76.22429657, 10.05264187], [76.22429657, 10.05236244], [76.22374725, 10.05236244], [76.22374725, 10.05208397], [76.2234726, 10.05208397], [76.2234726, 10.05124855], [76.22374725, 10.05126095], [76.22374725, 10.05097103], [76.22402954, 10.05097103], [76.22402954, 10.05069637], [76.2243042, 10.05069637], [76.2243042, 10.0504179], [76.22458649, 10.05041981], [76.22458649, 10.05013943], [76.2251358, 10.05013943], [76.2251358, 10.04986095], [76.22541809, 10.04986095], [76.22541809, 10.04958344], [76.22597504, 10.04958344], [76.22597504, 10.04930496], [76.22624969, 10.04930973], [76.22624969, 10.04875088], [76.22651672, 10.04875088], [76.22651672, 10.04847145], [76.22680664, 10.04847336], [76.22680664, 10.04819489], [76.22763824, 10.04819489], [76.22763824, 10.04847336], [76.22820282, 10.04847145], [76.22820282, 10.04875088], [76.22873688, 10.04875088], [76.22873688, 10.0490303], [76.22957611, 10.0490303], [76.22957611, 10.04875088], [76.2298584, 10.04875088], [76.2298584, 10.04792023], [76.23042297, 10.04792023], [76.23042297, 10.04763889], [76.23179626, 10.04763889], [76.23179626, 10.04736137], [76.23208618, 10.04736137], [76.23208618, 10.04430485], [76.23236084, 10.04431152], [76.23236084, 10.04347134], [76.2326355, 10.04347324], [76.2326355, 10.04259968], [76.2326355, 10.0415287], [76.23069763, 10.04153061], [76.23069763, 10.04125118], [76.23041534, 10.04125118], [76.23041534, 10.04069519], [76.23069763, 10.04069519], [76.23069763, 10.04041672], [76.23208618, 10.04041672], [76.23208618, 10.04069519], [76.23280334, 10.04069519], [76.23291779, 10.04069519], [76.23291779, 10.0401392], [76.23319244, 10.04014111], [76.23319244, 10.03958035], [76.23291779, 10.03958225], [76.23291779, 10.03930664], [76.23264313, 10.03931999], [76.23264313, 10.03903103], [76.23236084, 10.03903103], [76.23236084, 10.03764057], [76.23208618, 10.03764057], [76.23208618, 10.03681087], [76.23179626, 10.03681087], [76.23179626, 10.03625011], [76.23152924, 10.03625011], [76.23152924, 10.03514004], [76.23179626, 10.03514004], [76.23179626, 10.03485966], [76.23208618, 10.03485966], [76.23208618, 10.03458214], [76.23236084, 10.03458214], [76.23236084, 10.03430557], [76.23264313, 10.03431129], [76.23264313, 10.03347015], [76.23291779, 10.03347206], [76.23291779, 10.03319359], [76.23319244, 10.03319359], [76.23319244, 10.03291607], [76.23291779, 10.03292274], [76.23291779, 10.03264046], [76.23319244, 10.03264046], [76.23319244, 10.03125], [76.23339081, 10.03125], [76.23347473, 10.03125], [76.2334671, 10.0304203], [76.23374939, 10.03041553], [76.23374939, 10.03097153], [76.23401642, 10.03096962], [76.23401642, 10.03125], [76.23430634, 10.03125], [76.23430634, 10.03153038], [76.23486328, 10.03152847], [76.23486328, 10.03236008], [76.23458099, 10.03236008], [76.23458099, 10.03319359], [76.23486328, 10.03319359], [76.23486328, 10.03347206], [76.23458099, 10.03347015], [76.23458099, 10.03374958], [76.23430634, 10.03374958], [76.23430634, 10.03431129], [76.23402405, 10.03430557], [76.23402405, 10.03486156], [76.23374939, 10.03485966], [76.23374939, 10.03514004], [76.2334671, 10.03514004], [76.2334671, 10.03625011], [76.23401642, 10.03625011], [76.23401642, 10.03653145], [76.23486328, 10.03653145], [76.23486328, 10.03374958], [76.23513794, 10.03374958], [76.23513794, 10.03347015], [76.23542023, 10.03347206], [76.23542023, 10.03319359], [76.23569489, 10.03319359], [76.23569489, 10.03291607], [76.23680878, 10.03292274], [76.23680878, 10.03236008], [76.23708344, 10.03236008], [76.23707581, 10.0320797], [76.23735809, 10.03208447], [76.23735809, 10.03152847], [76.23764038, 10.03153038], [76.23764038, 10.03125], [76.2379303, 10.03125], [76.2379303, 10.03096962], [76.23819733, 10.03097153], [76.23819733, 10.03069401], [76.23847198, 10.03069401], [76.23847198, 10.03041553], [76.23874664, 10.0304203], [76.23874664, 10.02958202], [76.23847198, 10.02958393], [76.23847198, 10.02902794], [76.23874664, 10.02902985], [76.23874664, 10.02791977], [76.23902893, 10.02791977], [76.23902893, 10.02653027], [76.23929596, 10.02653027], [76.23929596, 10.02625179], [76.23902893, 10.02625179], [76.23902893, 10.02597141], [76.23930359, 10.02597141], [76.23930359, 10.02541542], [76.23819733, 10.02541542], [76.23819733, 10.0256958], [76.2379303, 10.02569103], [76.2379303, 10.02625179], [76.23764038, 10.02625179], [76.23764038, 10.02653027], [76.23735809, 10.02653027], [76.23735809, 10.02680969], [76.23680878, 10.02680588], [76.23680878, 10.02736187], [76.23625183, 10.02736187], [76.23625183, 10.02764034], [76.23596954, 10.02764034], [76.23596954, 10.02819443], [76.23568726, 10.02819061], [76.23569489, 10.02875042], [76.23542023, 10.02875042], [76.23542023, 10.02931023], [76.23513794, 10.02930641], [76.23513794, 10.0298624], [76.23347473, 10.0298624], [76.23347473, 10.02958393], [76.23319244, 10.02958393], [76.23319244, 10.02847195], [76.23347473, 10.02847195], [76.23347473, 10.02819443], [76.23374939, 10.02819443], [76.23374939, 10.02791786], [76.23401642, 10.02791977], [76.23401642, 10.02764034], [76.23458099, 10.02764034], [76.23458099, 10.02736187], [76.23486328, 10.02736187], [76.23486328, 10.02708435], [76.23513794, 10.02709103], [76.23513794, 10.02653027], [76.23542023, 10.02653027], [76.23542023, 10.02625179], [76.23596954, 10.02625179], [76.23596954, 10.02597141], [76.23625183, 10.02597141], [76.23625183, 10.02513981], [76.23652649, 10.02513981], [76.23652649, 10.02458286], [76.23680878, 10.02458286], [76.23680878, 10.02430534], [76.23735809, 10.02431011], [76.23735809, 10.02402973], [76.23764038, 10.02402973], [76.23764038, 10.02374935], [76.23874664, 10.02374935], [76.23874664, 10.02291679], [76.23819733, 10.02291965], [76.23819733, 10.02263927], [76.2379303, 10.02263927], [76.2379303, 10.02235889], [76.23764038, 10.0223608], [76.23764038, 10.02208328], [76.23735809, 10.02208328], [76.23735809, 10.02180481], [76.23707581, 10.02180958], [76.23707581, 10.0215292], [76.23680878, 10.0215292], [76.23680878, 10.0212698], [76.23652649, 10.02125072], [76.23652649, 10.02115059], [76.23652649, 10.02097321], [76.23625183, 10.02097321], [76.23625183, 10.02069473], [76.23596954, 10.02069473], [76.23596954, 10.02041721], [76.23542023, 10.02042198], [76.23542023, 10.02014065], [76.23486328, 10.02014065], [76.23486328, 10.01986122], [76.23458099, 10.01986122], [76.23458099, 10.01930523], [76.23430634, 10.0193119], [76.23430634, 10.01875114], [76.23401642, 10.01875114], [76.23401642, 10.01847076], [76.23347473, 10.01847267], [76.23347473, 10.01819515], [76.23208618, 10.01819515], [76.23208618, 10.01847267], [76.23124695, 10.01847267], [76.23124695, 10.01819515], [76.23041534, 10.01819515], [76.23041534, 10.0168047], [76.23152924, 10.01680946], [76.23152924, 10.01653099], [76.23204803, 10.01653099], [76.23236084, 10.01653099], [76.23236084, 10.01680946], [76.23347473, 10.0168047], [76.23347473, 10.01708317], [76.23430634, 10.01708317], [76.23430634, 10.01736069], [76.23596954, 10.01736069], [76.23596954, 10.01708317], [76.23625183, 10.01708317], [76.23625183, 10.0168047], [76.23652649, 10.01680946], [76.23652649, 10.01653099], [76.23680878, 10.01653099], [76.23680878, 10.01597118], [76.23708344, 10.01597309], [76.23708344, 10.01235962], [76.23680878, 10.01235962], [76.23680878, 10.01125145], [76.23652649, 10.01125145], [76.23652649, 10.01097012], [76.23680878, 10.01097298], [76.23680878, 10.01041603], [76.23707581, 10.0104208], [76.23707581, 10.01014137], [76.23652649, 10.01014137], [76.23652649, 10.0104208], [76.23542023, 10.0104208], [76.23542023, 10.01014137], [76.23513794, 10.01014137], [76.23513794, 10.00986004], [76.23569489, 10.00986004], [76.23568726, 10.00957966], [76.23625183, 10.00958538], [76.23625183, 10.00902843], [76.23652649, 10.00902843], [76.23652649, 10.00874996], [76.23708344, 10.00874996], [76.23708344, 10.00902843], [76.23735809, 10.00902843], [76.23735809, 10.00958538], [76.23764038, 10.00958538], [76.23764038, 10.00902843], [76.23791504, 10.00902843], [76.23791504, 10.00874996], [76.23819733, 10.00874996], [76.23819733, 10.00792122], [76.2379303, 10.00792122], [76.2379303, 10.00708199], [76.23819733, 10.00708199], [76.23819733, 10.00625038], [76.23847198, 10.00625038], [76.23847198, 10.00569439], [76.23874664, 10.00569439], [76.23874664, 10.0051403], [76.23902893, 10.0051403], [76.23902893, 10.00457954], [76.23930359, 10.00458431], [76.23930359, 10.00402832], [76.23958588, 10.00403023], [76.23958588, 10.00374985], [76.23986053, 10.00374985], [76.23986053, 10.00319386], [76.24013519, 10.00319386], [76.24013519, 10.00291634], [76.24041748, 10.00292015], [76.24041748, 10.00236034], [76.24069214, 10.00236225], [76.24069214, 10.00069427], [76.24041748, 10.00069427], [76.24041748, 10.00041771], [76.24014282, 10.00041962], [76.24014282, 10.00015068], [76.23986053, 10.00015068], [76.23986053, 9.99875164], [76.23958588, 9.99875164], [76.23958588, 9.99847126], [76.23902893, 9.99847126], [76.23902893, 9.99819565], [76.23874664, 9.99819565], [76.23874664, 9.99783993], [76.23874664, 9.99763966], [76.2379303, 9.99763966], [76.2379303, 9.99735928], [76.23735809, 9.99736214], [76.23735809, 9.99680519], [76.23764038, 9.99680996], [76.23764038, 9.9962492], [76.23847198, 9.9962492], [76.23847198, 9.99597359], [76.23874664, 9.99597359], [76.23874664, 9.99569321], [76.23930359, 9.99569321], [76.23930359, 9.99513912], [76.23958588, 9.99514198], [76.23958588, 9.99431038], [76.23929596, 9.99431038], [76.23929596, 9.99319077], [76.23902893, 9.99319458], [76.23902893, 9.99236107], [76.23930359, 9.99236107], [76.23929596, 9.99180984], [76.23958588, 9.99180984], [76.23958588, 9.99069023], [76.23986053, 9.990695], [76.23986053, 9.98902893], [76.24014282, 9.98903084], [76.24014282, 9.9881897], [76.24041748, 9.98819542], [76.24041748, 9.98763943], [76.24067688, 9.98764133], [76.24067688, 9.98736095], [76.2409668, 9.98736095], [76.2409668, 9.98681068], [76.24124908, 9.98681068], [76.24124908, 9.98653126], [76.24153137, 9.98653126], [76.24153137, 9.98596954], [76.24180603, 9.98597336], [76.24180603, 9.98569489], [76.24208069, 9.98569489], [76.24208069, 9.98513794], [76.24236298, 9.9851408], [76.24236298, 9.98485088], [76.24263763, 9.98486042], [76.24263763, 9.98430443], [76.24291992, 9.9843111], [76.24291992, 9.98318958], [76.24319458, 9.98319435], [76.24319458, 9.98302078], [76.24319458, 9.98263836], [76.24291992, 9.98264122], [76.24291992, 9.98208046], [76.24263763, 9.98208427], [76.24263763, 9.9818058], [76.24208069, 9.98181057], [76.24208069, 9.98153114], [76.24180603, 9.98153114], [76.24180603, 9.97986031], [76.24208069, 9.97986221], [76.24208069, 9.97819424], [76.24263763, 9.97819424], [76.24263763, 9.97764015], [76.24291992, 9.97764015], [76.24291992, 9.97736168], [76.24318695, 9.97736168], [76.24318695, 9.97707939], [76.24375153, 9.97708416], [76.24375153, 9.97680569], [76.24402618, 9.97681141], [76.24402618, 9.97653008], [76.24430847, 9.97653008], [76.24430847, 9.97569084], [76.24458313, 9.9756937], [76.24458313, 9.97458363], [76.24485779, 9.97458363], [76.24485779, 9.97347164], [76.24514008, 9.97347164], [76.24514008, 9.9729147], [76.24541473, 9.9729147], [76.24541473, 9.97236156], [76.24319458, 9.97236156], [76.24319458, 9.97208405], [76.24097443, 9.97208405], [76.24097443, 9.97236156], [76.24067688, 9.97236156], [76.24067688, 9.97264194], [76.24041748, 9.97264004], [76.24041748, 9.9729147], [76.24013519, 9.9729147], [76.24013519, 9.97319412], [76.23986053, 9.97319412], [76.23986053, 9.97347164], [76.23958588, 9.97347164], [76.23958588, 9.97402954], [76.23929596, 9.97402954], [76.23929596, 9.97430992], [76.23847198, 9.97430992], [76.23847198, 9.97402954], [76.2379303, 9.97402954], [76.2379303, 9.97375202], [76.23735809, 9.97375202], [76.23735809, 9.97347164], [76.23680878, 9.97347164], [76.23680878, 9.97319412], [76.23625183, 9.97319412], [76.23625183, 9.9729147], [76.23569489, 9.9729147], [76.23569489, 9.97264004], [76.23458099, 9.97264194], [76.23458099, 9.97236156], [76.23236084, 9.97236156], [76.23236084, 9.97264194], [76.23124695, 9.97264004], [76.23124695, 9.9729147], [76.23014069, 9.9729147], [76.23014069, 9.97319412], [76.22958374, 9.97319412], [76.22958374, 9.97347164], [76.22902679, 9.97347164], [76.22902679, 9.97375202], [76.22846985, 9.97375202], [76.22846985, 9.97402954], [76.2279129, 9.97402954], [76.2279129, 9.97430992], [76.22763824, 9.97430611], [76.22763824, 9.97458363], [76.2270813, 9.97457886], [76.2270813, 9.97513962], [76.22680664, 9.97513771], [76.22680664, 9.9756937], [76.22651672, 9.97569084], [76.22651672, 9.97624969], [76.2251358, 9.97624969], [76.2251358, 9.97653008], [76.22458649, 9.97653008], [76.22458649, 9.97681141], [76.2243042, 9.97680569], [76.2243042, 9.97708416], [76.22402954, 9.97707939], [76.22402954, 9.97791958], [76.22374725, 9.97791576], [76.22374725, 9.97875023], [76.2234726, 9.97875023], [76.2234726, 9.97986221], [76.22319794, 9.97986221], [76.22319794, 9.98069382], [76.22292328, 9.98069191], [76.22290039, 9.98181057], [76.22264099, 9.98181057], [76.22264099, 9.98292065], [76.2223587, 9.98292065], [76.2223587, 9.98403072], [76.22207642, 9.98403072], [76.22207642, 9.9851408], [76.22180939, 9.9851408], [76.22180176, 9.98625088], [76.2215271, 9.98625088], [76.2215271, 9.98736095], [76.22125244, 9.98736095], [76.22125244, 9.98847294], [76.22097015, 9.98847294], [76.22097015, 9.98958302], [76.2206955, 9.98958302], [76.22070313, 9.99061966], [76.22070313, 9.99098015], [76.22054291, 9.99097538], [76.22041321, 9.99097347], [76.22041321, 9.99127197], [76.22041321, 9.9920826], [76.22013855, 9.99208069], [76.22013855, 9.99264145], [76.21986389, 9.99263859], [76.21986389, 9.99324131], [76.21986389, 9.99347115], [76.2195816, 9.99347115], [76.2195816, 9.99402714], [76.21930695, 9.99402714], [76.21930695, 9.99486065], [76.21901703, 9.99486065], [76.21901703, 9.99542046], [76.21875, 9.99541664], [76.21875, 9.99847126], [76.21848297, 9.99847126], [76.21848297, 9.99903202], [76.21819305, 9.99902821], [76.21819305, 10.00014019], [76.21819305, 10.00208378], [76.2179184, 10.00208378], [76.2179184, 10.00319386], [76.21763611, 10.00319195], [76.21763611, 10.00542068], [76.2179184, 10.00541592], [76.2179184, 10.00569439], [76.21763611, 10.00569439], [76.21763611, 10.00597191], [76.21708679, 10.00597191], [76.21708679, 10.00819016], [76.21679688, 10.00820065], [76.21679688, 10.00874996], [76.21624756, 10.00874996], [76.21624756, 10.01069355], [76.2159729, 10.01068974], [76.2159729, 10.01125145], [76.21569824, 10.01125145], [76.21569824, 10.01153088], [76.2159729, 10.01152897], [76.2159729, 10.01235962], [76.21569824, 10.01235962], [76.21569824, 10.01458263], [76.2151413, 10.01457977], [76.2151413, 10.01515007], [76.21485901, 10.01515007], [76.21485901, 10.01625061], [76.21457672, 10.01625061], [76.21458435, 10.01736069], [76.21430206, 10.01736069], [76.21430206, 10.01875114], [76.2140274, 10.01875114], [76.2140274, 10.02014065], [76.21376038, 10.02014065], [76.21376038, 10.02125072], [76.21347046, 10.02124882], [76.21347046, 10.02208328], [76.2131958, 10.02208328], [76.2131958, 10.0223608], [76.21291351, 10.0223608], [76.21291351, 10.02319336], [76.21263885, 10.02319336], [76.21263885, 10.02374935], [76.21235657, 10.02374935], [76.21235657, 10.02431011], [76.21208191, 10.02430534], [76.21208191, 10.02486229], [76.2123642, 10.02486229], [76.2123642, 10.0256958], [76.21152496, 10.0256958], [76.21152496, 10.02597141], [76.21098328, 10.02597141], [76.21098328, 10.02625179], [76.21070099, 10.02625179], [76.21070099, 10.02680969], [76.2104187, 10.02680969], [76.2104187, 10.02791977], [76.21013641, 10.02791786], [76.21013641, 10.02819443], [76.20986176, 10.02819443], [76.20986176, 10.0298624], [76.2095871, 10.02985954], [76.2095871, 10.0304203], [76.20930481, 10.03041553], [76.20930481, 10.03069401], [76.20903015, 10.03068924], [76.20903015, 10.03125], [76.20929718, 10.03125], [76.20929718, 10.03153038], [76.20903015, 10.03152847], [76.20903015, 10.03236008], [76.20874786, 10.03236008], [76.20874786, 10.03292274], [76.20847321, 10.03292274], [76.20847321, 10.03403091], [76.20819092, 10.03403091], [76.20819092, 10.03431129], [76.20847321, 10.03430557], [76.20847321, 10.03486156], [76.20819092, 10.03486156], [76.20819092, 10.03597164], [76.20791626, 10.03596973], [76.20791626, 10.03681087], [76.20762634, 10.03681087], [76.20762634, 10.03764057], [76.20735931, 10.03763771], [76.20735931, 10.03847313], [76.20707703, 10.03847027], [76.20707703, 10.03903103], [76.20680237, 10.03902912], [76.20680237, 10.03986073], [76.20652771, 10.03986073], [76.20652771, 10.04208279], [76.20625305, 10.04208279], [76.20625305, 10.04347324], [76.20597076, 10.04347134], [76.20597076, 10.04431152], [76.20569611, 10.04431152], [76.20569611, 10.0454216], [76.20540619, 10.0454216], [76.20541382, 10.0462513], [76.20513916, 10.0462513], [76.20513916, 10.04736137], [76.2048645, 10.04736137], [76.2048645, 10.04819489], [76.20456696, 10.04819107], [76.20456696, 10.04875088], [76.20430756, 10.04874897], [76.20430756, 10.04986095], [76.2040329, 10.04986095], [76.2040329, 10.05041981], [76.20375061, 10.0504179], [76.20375061, 10.05097103], [76.20318604, 10.05097103], [76.20318604, 10.05126095], [76.20291901, 10.05126095], [76.20291901, 10.05153179], [76.20236206, 10.05153179], [76.20236206, 10.05181026], [76.20207977, 10.05180454], [76.20207977, 10.05208397], [76.20182037, 10.05208111], [76.20182037, 10.05264187], [76.20153046, 10.05263996], [76.20153046, 10.05458355], [76.20124817, 10.05458069], [76.20124817, 10.05513954], [76.20096588, 10.05513954], [76.20096588, 10.05624962], [76.20069122, 10.05624962], [76.20069122, 10.05708408], [76.20041656, 10.05708408], [76.20041656, 10.0573597], [76.20069122, 10.0573597], [76.20069122, 10.05792046], [76.20041656, 10.05791569], [76.20041656, 10.05875015], [76.20014191, 10.05875015], [76.20014191, 10.05902958], [76.19985962, 10.05902958], [76.19985962, 10.06042099], [76.19959259, 10.06042099], [76.19959259, 10.06124973], [76.19985962, 10.06124973], [76.19985962, 10.06153107], [76.19958496, 10.06152821], [76.19958496, 10.06208229], [76.19930267, 10.06208038], [76.19930267, 10.06292057], [76.19902802, 10.0629158], [76.19902802, 10.06486034], [76.19876099, 10.06486034], [76.19876099, 10.06514072], [76.19847107, 10.06513786], [76.19847107, 10.06597328], [76.19819641, 10.06597042], [76.19819641, 10.06681061], [76.19790649, 10.06681061], [76.19790649, 10.06792068], [76.19763947, 10.06792068], [76.19763947, 10.06902885], [76.19736481, 10.06902885], [76.19736481, 10.06958294], [76.19763947, 10.06958294], [76.19763947, 10.06986141], [76.19735718, 10.06986141], [76.19735718, 10.07181168], [76.19708252, 10.071805], [76.19708252, 10.07236099], [76.19680786, 10.07236099], [76.19680786, 10.07347107], [76.1965332, 10.07347107], [76.1965332, 10.0743103], [76.19625092, 10.07430458], [76.19625092, 10.07458305], [76.19596863, 10.07458115], [76.19596863, 10.07681179], [76.19569397, 10.07680511], [76.19569397, 10.07736111], [76.19541931, 10.0773592], [76.19541931, 10.07791996], [76.19513702, 10.07791805], [76.19513702, 10.07847118], [76.19486237, 10.07847118], [76.19486237, 10.07986164], [76.19458008, 10.07986164], [76.19458008, 10.08181], [76.19430542, 10.08180618], [76.19430542, 10.08319378], [76.19403076, 10.08319092], [76.19403076, 10.08403015], [76.19374847, 10.08403015], [76.19374847, 10.08514023], [76.19346619, 10.08514023], [76.19346619, 10.08541965], [76.19319153, 10.08541584], [76.19319153, 10.08597183], [76.19291687, 10.08597183], [76.19291687, 10.08652973], [76.19264221, 10.08652782], [76.19264221, 10.08708191], [76.19235992, 10.08708191], [76.19235992, 10.08764267], [76.1920929, 10.08764267], [76.1920929, 10.08792114], [76.19180298, 10.08791637], [76.19180298, 10.09097195], [76.19152832, 10.09097004], [76.19152832, 10.0915308], [76.19097137, 10.0915308], [76.19097137, 10.09264088], [76.19069672, 10.09263802], [76.19069672, 10.09347343], [76.1904068, 10.09346962], [76.1904068, 10.09403133], [76.19013977, 10.09402561], [76.19013977, 10.09486103], [76.18985748, 10.09486103], [76.18985748, 10.09569454], [76.18959045, 10.09568977], [76.18959045, 10.09764099], [76.18930817, 10.09763908], [76.18930817, 10.09986115], [76.18902588, 10.09986115], [76.18902588, 10.10208321], [76.18875122, 10.1020813], [76.18875122, 10.10431004], [76.18846893, 10.10430527], [76.18846893, 10.10541534], [76.18819427, 10.10541534], [76.18819427, 10.10708427], [76.18791962, 10.10708141], [76.18791962, 10.10791969], [76.18763733, 10.10791779], [76.18763733, 10.10986233], [76.18736267, 10.10986233], [76.18736267, 10.1109724], [76.18708038, 10.1109724], [76.18708038, 10.11236], [76.18680573, 10.11236], [76.18680573, 10.11319447], [76.18653107, 10.11319447], [76.18653107, 10.11375046], [76.18624878, 10.11375046], [76.18624878, 10.11597157], [76.18596649, 10.11596966], [76.18596649, 10.11653137], [76.18569183, 10.11653137], [76.18569183, 10.11792088], [76.18541718, 10.11791611], [76.18541718, 10.1184721], [76.18514252, 10.1184721], [76.18514252, 10.1198597], [76.18486023, 10.1198597], [76.18486023, 10.12069511], [76.1845932, 10.12069035], [76.1845932, 10.12153053], [76.18430328, 10.12153053], [76.18430328, 10.12292099], [76.18402863, 10.12292099], [76.18402863, 10.12403107], [76.18374634, 10.12402916], [76.18374634, 10.12458324], [76.18345642, 10.12458134], [76.18347168, 10.12597084], [76.18319702, 10.12597084], [76.18319702, 10.12681198], [76.1829071, 10.12681198], [76.1829071, 10.12792015], [76.18264008, 10.12792015], [76.18264008, 10.12902927], [76.18235779, 10.12902737], [76.18235779, 10.12958336], [76.18208313, 10.12958336], [76.18208313, 10.13069534], [76.18180847, 10.13069534], [76.18180847, 10.13124943], [76.18152618, 10.13124943], [76.18152618, 10.13181019], [76.18125153, 10.13181019], [76.18125153, 10.13264179], [76.18096924, 10.13263988], [76.18096924, 10.13319111], [76.18068695, 10.13319969], [76.18069458, 10.13486195], [76.18041992, 10.13486195], [76.18041992, 10.13541985], [76.18013763, 10.13541794], [76.18013763, 10.13569355], [76.17986298, 10.13569069], [76.17986298, 10.13652992], [76.17958069, 10.13652992], [76.17958069, 10.13764], [76.17930603, 10.13764], [76.17930603, 10.13792038], [76.17903137, 10.13792038], [76.17903137, 10.13875008], [76.17874908, 10.13875008], [76.17874908, 10.13931274], [76.1784668, 10.13931274], [76.1784668, 10.14042091], [76.17819214, 10.14042091], [76.17819214, 10.14264011], [76.17791748, 10.14263821], [76.17791748, 10.14347172], [76.17763519, 10.14347172], [76.17763519, 10.14375019], [76.17736053, 10.14375019], [76.17736053, 10.14458466], [76.17708588, 10.14457989], [76.17708588, 10.14625072], [76.17679596, 10.14625072], [76.17679596, 10.14681053], [76.17652893, 10.14680672], [76.17652893, 10.14708233], [76.17624664, 10.14708233], [76.17624664, 10.1473608], [76.17597198, 10.1473608], [76.17597198, 10.14792061], [76.17624664, 10.14792061], [76.17624664, 10.14931107], [76.17597198, 10.14930534], [76.17597198, 10.15013885], [76.17569733, 10.15013885], [76.17569733, 10.15041924], [76.17541504, 10.15041733], [76.17541504, 10.15069485], [76.17514038, 10.15069008], [76.17514038, 10.15125084], [76.17485809, 10.15125084], [76.17485809, 10.15153122], [76.17458344, 10.1515274], [76.17458344, 10.15319538], [76.17430878, 10.15319061], [76.17430878, 10.15402889], [76.17402649, 10.15402699], [76.17402649, 10.15458298], [76.17375183, 10.15458107], [76.17375183, 10.15514183], [76.17346954, 10.15513897], [76.17346954, 10.15597343], [76.17318726, 10.15597057], [76.17318726, 10.15680981], [76.17292023, 10.15680504], [76.17292023, 10.15736103], [76.17263794, 10.15736103], [76.17263794, 10.15763855], [76.17236328, 10.15763855], [76.17236328, 10.15875244], [76.17208099, 10.15875244], [76.17208099, 10.15931034], [76.17180634, 10.15930462], [76.17180634, 10.15984058], [76.17180634, 10.16014194], [76.17152405, 10.16014004], [76.17152405, 10.16069317], [76.17124939, 10.16069126], [76.17124939, 10.16125202], [76.17097473, 10.16125011], [76.17097473, 10.16208363], [76.17069244, 10.16207886], [76.17069244, 10.16292], [76.17041779, 10.16292], [76.17041779, 10.16374969], [76.1701355, 10.16374969], [76.1701355, 10.16458416], [76.16986084, 10.16457939], [76.16986084, 10.16514015], [76.16958618, 10.16514015], [76.16958618, 10.16597176], [76.16929626, 10.16596985], [76.16929626, 10.16681099], [76.16902924, 10.16680622], [76.16902924, 10.16708374], [76.16874695, 10.16708183], [76.16874695, 10.16763973], [76.16847229, 10.16763783], [76.16847229, 10.16847229], [76.16819763, 10.16846085], [76.16819763, 10.16903114], [76.16792297, 10.16903114], [76.16792297, 10.16931057], [76.16764069, 10.16931057], [76.16764069, 10.16986179], [76.1673584, 10.16986179], [76.1673584, 10.17042065], [76.16708374, 10.17041588], [76.16708374, 10.17097187], [76.16680908, 10.17097187], [76.16680908, 10.17152786], [76.16652679, 10.17152786], [76.16652679, 10.17208195], [76.16680908, 10.17208195], [76.16680908, 10.17236042], [76.16652679, 10.17236042], [76.16652679, 10.17347336], [76.16625214, 10.17346954], [76.16625214, 10.17375088], [76.16652679, 10.17375088], [76.16652679, 10.17403126], [76.16625214, 10.17402554], [76.16625214, 10.17486095], [76.16596985, 10.17486095], [76.16596985, 10.17569542], [76.16625214, 10.17569542], [76.16625214, 10.17847347], [76.16680908, 10.17847061], [76.16680908, 10.17903137], [76.16707611, 10.17903137], [76.16707611, 10.18014145], [76.1673584, 10.18013859], [76.1673584, 10.18069458], [76.16764069, 10.18069458], [76.16764069, 10.18097305], [76.16792297, 10.18097115], [76.16792297, 10.18125057], [76.16819763, 10.18125057], [76.16819763, 10.18153191], [76.16847229, 10.18152714], [76.16847229, 10.18208313], [76.16863251, 10.18208313], [76.16902924, 10.18208313], [76.16902924, 10.18236065], [76.1692276, 10.18236065], [76.16930389, 10.18236065], [76.16929626, 10.18264198], [76.16958618, 10.18264198], [76.16958618, 10.18292046], [76.16986084, 10.18291664], [76.16986084, 10.18319321], [76.17097473, 10.18319321], [76.17097473, 10.18347263], [76.17208099, 10.18347263], [76.17208099, 10.1837492], [76.17318726, 10.1837492], [76.17318726, 10.18402958], [76.17402649, 10.18402958], [76.17402649, 10.1837492], [76.17424774, 10.1837492], [76.17458344, 10.1837492], [76.17458344, 10.18347263], [76.17514038, 10.18347263], [76.17514038, 10.18319321], [76.17597198, 10.18319321], [76.17597198, 10.18236065], [76.17624664, 10.18236065], [76.17624664, 10.18069458], [76.17652893, 10.18069458], [76.17652893, 10.1795826], [76.17680359, 10.1795826], [76.17680359, 10.17930508], [76.17708588, 10.17930889], [76.17708588, 10.17847061], [76.17736053, 10.17847347], [76.17736053, 10.17525005], [76.17736053, 10.17513943], [76.17765045, 10.17514133], [76.17765045, 10.17403126], [76.17791748, 10.17403126], [76.17791748, 10.17375088], [76.17819214, 10.17375088], [76.17819214, 10.17346954], [76.17847443, 10.17347336], [76.17847443, 10.17319489], [76.17874908, 10.17319489], [76.17874908, 10.17291641], [76.17930603, 10.17292118], [76.17930603, 10.17236042], [76.17958069, 10.17236042], [76.17958069, 10.17208195], [76.17986298, 10.17208195], [76.17986298, 10.17180443], [76.18013763, 10.1718111], [76.18013763, 10.17125034], [76.18069458, 10.17125034], [76.18068695, 10.17096996], [76.18152618, 10.17097187], [76.18152618, 10.17041588], [76.18180847, 10.17042065], [76.18180847, 10.16986179], [76.18208313, 10.16986179], [76.18208313, 10.16958046], [76.18235779, 10.16958427], [76.18235779, 10.1693058], [76.18264008, 10.16931057], [76.18264008, 10.16903114], [76.1829071, 10.16903114], [76.1829071, 10.16875267], [76.18319702, 10.16875267], [76.18319702, 10.16819191], [76.18347168, 10.16819382], [76.18347168, 10.16763783], [76.18374634, 10.16763973], [76.18374634, 10.16736031], [76.18402863, 10.16736221], [76.18402863, 10.16680622], [76.18430328, 10.16681099], [76.18430328, 10.16652966], [76.18486023, 10.16652966], [76.18486023, 10.16625023], [76.18514252, 10.16625023], [76.18514252, 10.16569424], [76.18541718, 10.16569424], [76.18541718, 10.16514015], [76.18624878, 10.16514015], [76.18624878, 10.16485977], [76.18680573, 10.16485977], [76.18680573, 10.16458416], [76.18736267, 10.16458416], [76.18736267, 10.16430569], [76.18791962, 10.16431046], [76.18791962, 10.16403008], [76.18846893, 10.16403008], [76.18846893, 10.16374969], [76.1904068, 10.16374969], [76.1904068, 10.16346931], [76.19069672, 10.16347218], [76.19069672, 10.1631937], [76.19125366, 10.1631937], [76.19125366, 10.16291809], [76.19152832, 10.16292], [76.19152832, 10.16265106], [76.1920929, 10.16265106], [76.1920929, 10.16236019], [76.19319153, 10.1623621], [76.19319153, 10.16180611], [76.19346619, 10.16180992], [76.19346619, 10.16097164], [76.19319153, 10.16097164], [76.19319153, 10.15958405], [76.19347382, 10.15958405], [76.19347382, 10.15930462], [76.19319153, 10.15931034], [76.19319153, 10.15819073], [76.19347382, 10.15819645], [76.19347382, 10.15763855], [76.19374847, 10.15763855], [76.19374847, 10.15708065], [76.19403076, 10.15708256], [76.19403076, 10.15569305], [76.19430542, 10.15569305], [76.19430542, 10.15541744], [76.19458008, 10.1554203], [76.19458008, 10.15486145], [76.19486237, 10.15486145], [76.19486237, 10.15458298], [76.19513702, 10.15458298], [76.19513702, 10.15402699], [76.19541931, 10.15402889], [76.19541931, 10.15347958], [76.19568634, 10.15347958], [76.19568634, 10.1526413], [76.19625092, 10.1526413], [76.19625092, 10.15236092], [76.19652557, 10.15236092], [76.19652557, 10.15180492], [76.19680786, 10.1518116], [76.19680786, 10.15097141], [76.19708252, 10.15097332], [76.19708252, 10.15041733], [76.19763947, 10.15041924], [76.19763947, 10.15013885], [76.19791412, 10.15013885], [76.19790649, 10.14986134], [76.19819641, 10.14986134], [76.19819641, 10.14958286], [76.19791412, 10.14958286], [76.19791412, 10.14847279], [76.19819641, 10.14847279], [76.19819641, 10.14819527], [76.19875336, 10.14819527], [76.19875336, 10.14791679], [76.19902802, 10.14792061], [76.19902802, 10.14625072], [76.19876099, 10.14625072], [76.19876099, 10.14514065], [76.19902802, 10.14514065], [76.19902802, 10.14347172], [76.19930267, 10.14347172], [76.19930267, 10.1431942], [76.19958496, 10.1431942], [76.19958496, 10.14291573], [76.19985962, 10.14292145], [76.19985962, 10.14235973], [76.20014191, 10.14235973], [76.20014191, 10.14208221], [76.20041656, 10.14208221], [76.20041656, 10.14180565], [76.20069122, 10.14181137], [76.20069122, 10.14153957], [76.20096588, 10.14153957], [76.20096588, 10.14097023], [76.20124817, 10.14097214], [76.20124817, 10.14069366], [76.20153046, 10.14069366], [76.20153046, 10.14041615], [76.20182037, 10.14042091], [76.20182037, 10.13958168], [76.20207977, 10.13958359], [76.20207977, 10.1390276], [76.20263672, 10.1390276], [76.20263672, 10.13958359], [76.20236206, 10.13958168], [76.20236206, 10.14013958], [76.20207977, 10.14013767], [76.20207977, 10.14097214], [76.20182037, 10.14097023], [76.20182037, 10.14153957], [76.20153046, 10.14153957], [76.20153046, 10.14181137], [76.20124817, 10.14180565], [76.20124817, 10.14208221], [76.20153046, 10.14208221], [76.20153046, 10.14235973], [76.20124817, 10.14235973], [76.20124817, 10.14292145], [76.20097351, 10.14291573], [76.20097351, 10.14347172], [76.20069122, 10.14347172], [76.20069122, 10.14403057], [76.20041656, 10.14402771], [76.20041656, 10.14458466], [76.20014191, 10.14457989], [76.20014191, 10.14681053], [76.20041656, 10.14680672], [76.20041656, 10.1473608], [76.20069122, 10.1473608], [76.20069122, 10.14764118], [76.20041656, 10.14763927], [76.20041656, 10.14819527], [76.20069122, 10.14819527], [76.20069122, 10.14847279], [76.20096588, 10.14846992], [76.20096588, 10.14875126], [76.20124817, 10.14875126], [76.20124817, 10.14903069], [76.20153046, 10.14903069], [76.20153046, 10.14931107], [76.20180511, 10.14930534], [76.20180511, 10.14958286], [76.20263672, 10.14958286], [76.20263672, 10.14902878], [76.20291901, 10.14903069], [76.20291901, 10.14875126], [76.20263672, 10.14875126], [76.20263672, 10.14819527], [76.20236206, 10.14819527], [76.20236206, 10.14791679], [76.20207977, 10.14792061], [76.20207977, 10.14764118], [76.20291901, 10.14764118], [76.20291901, 10.14792061], [76.20375061, 10.14791679], [76.20375061, 10.14875126], [76.20347595, 10.14875126], [76.20347595, 10.14958286], [76.20291901, 10.14958286], [76.20291901, 10.14986134], [76.20263672, 10.14986134], [76.20263672, 10.15041924], [76.20319366, 10.15041733], [76.20319366, 10.15069485], [76.20375061, 10.15069008], [76.20375061, 10.15125084], [76.2040329, 10.15125084], [76.2040329, 10.1518116], [76.20375061, 10.15180492], [76.20375061, 10.1520834], [76.20153046, 10.1520834], [76.20153046, 10.15180492], [76.20182037, 10.1518116], [76.20182037, 10.15153122], [76.20153046, 10.15153122], [76.20153046, 10.15097141], [76.20124817, 10.15097332], [76.20124817, 10.15069485], [76.20097351, 10.15069485], [76.20097351, 10.14902878], [76.19957733, 10.14903069], [76.19957733, 10.15153122], [76.19902802, 10.15153122], [76.19902802, 10.1518116], [76.19875336, 10.15180492], [76.19875336, 10.1520834], [76.19819641, 10.1520834], [76.19819641, 10.15236092], [76.19790649, 10.15236092], [76.19790649, 10.1526413], [76.19763947, 10.15263939], [76.19763947, 10.15319538], [76.19735718, 10.15319061], [76.19736481, 10.15375137], [76.19708252, 10.15375137], [76.19708252, 10.15431023], [76.19680786, 10.15430546], [76.19680786, 10.15458298], [76.19652557, 10.15458298], [76.19652557, 10.15569305], [76.19596863, 10.15569305], [76.19596863, 10.15597343], [76.19569397, 10.15597343], [76.19569397, 10.15708256], [76.19541931, 10.15708256], [76.19541931, 10.15819645], [76.19513702, 10.15819073], [76.19513702, 10.15903187], [76.19486237, 10.15903187], [76.19486237, 10.16042042], [76.19458008, 10.16042042], [76.19458008, 10.16152954], [76.19430542, 10.16152763], [76.19430542, 10.16208363], [76.19403076, 10.16208363], [76.19403076, 10.1623621], [76.19374847, 10.1623621], [76.19374847, 10.1631937], [76.19346619, 10.16319084], [76.19346619, 10.16374969], [76.19319153, 10.16374969], [76.19319153, 10.16403008], [76.19291687, 10.16403008], [76.19291687, 10.16431046], [76.19125366, 10.16430569], [76.19125366, 10.16458416], [76.19069672, 10.16458416], [76.19069672, 10.16485977], [76.18985748, 10.16485977], [76.18985748, 10.16514015], [76.18818665, 10.16514015], [76.18818665, 10.16541958], [76.18763733, 10.16541576], [76.18763733, 10.16569424], [76.18708038, 10.16569424], [76.18708038, 10.16597176], [76.18680573, 10.16597176], [76.18680573, 10.16625023], [76.18653107, 10.16625023], [76.18653107, 10.16652966], [76.18624878, 10.16652775], [76.18624878, 10.16708374], [76.18596649, 10.16708183], [76.18596649, 10.16763973], [76.18569183, 10.16763783], [76.18569183, 10.16819382], [76.18541718, 10.16819191], [76.18541718, 10.16903114], [76.18514252, 10.16903114], [76.18514252, 10.16986179], [76.1845932, 10.16986179], [76.1845932, 10.17042065], [76.18430328, 10.17041588], [76.18430328, 10.17097187], [76.18402863, 10.17097187], [76.18402863, 10.17125034], [76.18347168, 10.17125034], [76.18347168, 10.17152786], [76.18319702, 10.17151928], [76.18319702, 10.1718111], [76.18291473, 10.17180443], [76.18291473, 10.17208195], [76.18180847, 10.17208195], [76.18180847, 10.17180443], [76.18125153, 10.17180443], [76.18125153, 10.17208195], [76.18096924, 10.17208195], [76.18096924, 10.17236042], [76.18068695, 10.17236042], [76.18068695, 10.1726408], [76.18041992, 10.1726408], [76.18041992, 10.17292118], [76.18013763, 10.17291641], [76.18013763, 10.17347336], [76.17986298, 10.17346954], [76.17986298, 10.17375088], [76.17958069, 10.17375088], [76.17958069, 10.17431068], [76.17930603, 10.17431068], [76.17930603, 10.17541885], [76.17903137, 10.17541695], [76.17903137, 10.17597294], [76.17874908, 10.17597294], [76.17874908, 10.17708302], [76.1784668, 10.17708015], [76.1784668, 10.17903137], [76.17819214, 10.17903137], [76.17819214, 10.18014145], [76.17791748, 10.18014145], [76.17791748, 10.18042183], [76.17819214, 10.18041706], [76.17819214, 10.18069458], [76.17791748, 10.18069458], [76.17791748, 10.18097305], [76.17763519, 10.18097305], [76.17763519, 10.18208313], [76.17736053, 10.18208122], [76.17736053, 10.18264198], [76.17708588, 10.18263912], [76.17709351, 10.18345261], [76.17736053, 10.18347263], [76.17736053, 10.18355083], [76.17736053, 10.1837492], [76.17767334, 10.18375397], [76.17765045, 10.18402958], [76.17819214, 10.18402958], [76.17819214, 10.18430996], [76.17847443, 10.18430519], [76.17847443, 10.18458271], [76.17930603, 10.18458271], [76.17930603, 10.1847496], [76.17930603, 10.18542194], [76.17958069, 10.18542194], [76.17958069, 10.18625164], [76.18068695, 10.18625164], [76.18068695, 10.18682098], [76.18041992, 10.18680573], [76.18041992, 10.18736172], [76.18096924, 10.18735886], [76.18096924, 10.18764019], [76.18180847, 10.18764019], [76.18180847, 10.18791962], [76.18235779, 10.18791771], [76.18235779, 10.18819427], [76.1829071, 10.18819141], [76.1829071, 10.18847179], [76.18319702, 10.18847179], [76.18319702, 10.18902969], [76.18345642, 10.18902969], [76.18345642, 10.18931007], [76.18430328, 10.18931007], [76.18430328, 10.18959141], [76.18597412, 10.18958378], [76.18597412, 10.18986225], [76.18653107, 10.18986034], [76.18653107, 10.19013977], [76.18708038, 10.19013977], [76.18708038, 10.19042015], [76.18902588, 10.19041634], [76.18902588, 10.19069386], [76.19041443, 10.19069386], [76.19041443, 10.19097233], [76.19152832, 10.19097233], [76.19152832, 10.19124985], [76.19208527, 10.19124985], [76.19208527, 10.19097233], [76.19235992, 10.19097042], [76.19235992, 10.19153023], [76.19208527, 10.19152832], [76.19208527, 10.19235992], [76.19180298, 10.19235992], [76.19180298, 10.19347191], [76.19152832, 10.19347191], [76.19152832, 10.19431114], [76.19125366, 10.19430637], [76.19125366, 10.19486237], [76.18875122, 10.19486237], [76.18875122, 10.19458199], [76.18708038, 10.19458199], [76.18708038, 10.19430637], [76.18653107, 10.19431114], [76.18653107, 10.19403267], [76.18596649, 10.19403267], [76.18596649, 10.19375038], [76.18514252, 10.19375038], [76.18514252, 10.19347191], [76.18458557, 10.19347191], [76.18458557, 10.19319439], [76.18430328, 10.19319439], [76.18430328, 10.19291592], [76.18374634, 10.19291973], [76.18374634, 10.19262886], [76.18319702, 10.1926403], [76.18319702, 10.19235992], [76.18264008, 10.19235992], [76.18264008, 10.19208431], [76.18208313, 10.19208431], [76.18208313, 10.19180584], [76.18125153, 10.19181061], [76.18125153, 10.19153023], [76.18068695, 10.19153023], [76.18068695, 10.19124985], [76.17986298, 10.19124985], [76.17986298, 10.19097233], [76.17874908, 10.19097233], [76.17874908, 10.19069386], [76.17847443, 10.19069386], [76.17847443, 10.19041634], [76.17819214, 10.19042015], [76.17819214, 10.19013977], [76.17765045, 10.19013977], [76.17765045, 10.18986034], [76.17597198, 10.18986225], [76.17597198, 10.18930626], [76.17569733, 10.18931007], [76.17569733, 10.18902969], [76.17459106, 10.18902969], [76.17459106, 10.18875027], [76.17318726, 10.18875027], [76.17318726, 10.18847179], [76.17208099, 10.18847179], [76.17208099, 10.18819427], [76.17069244, 10.18819427], [76.17069244, 10.18791771], [76.16845703, 10.18791962], [76.16845703, 10.18764019], [76.16819763, 10.18764019], [76.16819763, 10.18791962], [76.16792297, 10.18791962], [76.16792297, 10.18764019], [76.1673584, 10.18764019], [76.1673584, 10.18791962], [76.16513824, 10.18791962], [76.16513824, 10.18735886], [76.1645813, 10.18736172], [76.1645813, 10.18652725], [76.16485596, 10.18653202], [76.16485596, 10.18597126], [76.16513824, 10.18597126], [76.16513824, 10.18541527], [76.16542053, 10.18542194], [76.16542053, 10.1845789], [76.16596985, 10.18458271], [76.16596985, 10.18402672], [76.16625214, 10.18402958], [76.16625214, 10.1837492], [76.16569519, 10.1837492], [76.16569519, 10.18291664], [76.16542053, 10.18292046], [76.16542053, 10.18264198], [76.16513824, 10.18264198], [76.16513824, 10.18237019], [76.16513824, 10.18208313], [76.1645813, 10.18208313], [76.1645813, 10.18180466], [76.16347504, 10.18180466], [76.16347504, 10.18236065], [76.16319275, 10.18236065], [76.16319275, 10.18264198], [76.16291809, 10.18263912], [76.16291809, 10.18319321], [76.1626358, 10.18319321], [76.1626358, 10.18347263], [76.16236115, 10.18346024], [76.16236115, 10.18402958], [76.16208649, 10.18402672], [76.16208649, 10.18458271], [76.16179657, 10.1845789], [76.16179657, 10.18542194], [76.16152954, 10.18541527], [76.16152954, 10.18597126], [76.16124725, 10.18597126], [76.16124725, 10.18653202], [76.1609726, 10.18653202], [76.1609726, 10.18682098], [76.16069794, 10.18682098], [76.16069794, 10.18791962], [76.16041565, 10.18791771], [76.16041565, 10.18847179], [76.1598587, 10.18847179], [76.1598587, 10.18959141], [76.15957642, 10.18959141], [76.15958405, 10.19124985], [76.15930939, 10.19124985], [76.15930939, 10.19153023], [76.15957642, 10.19153023], [76.15957642, 10.19181061], [76.15930939, 10.19180584], [76.15930176, 10.19235992], [76.1590271, 10.19235992], [76.1590271, 10.19291973], [76.15875244, 10.19291592], [76.15875244, 10.19347191], [76.15847015, 10.19347191], [76.15847015, 10.19375038], [76.15820313, 10.19375038], [76.15820313, 10.19431114], [76.15791321, 10.19430637], [76.15791321, 10.19486237], [76.15763855, 10.19486046], [76.15763855, 10.19542122], [76.15735626, 10.19542122], [76.15735626, 10.1965313], [76.1570816, 10.19652843], [76.1570816, 10.19708443], [76.15680695, 10.19708443], [76.15680695, 10.19847202], [76.15652466, 10.19847202], [76.15652466, 10.1995821], [76.15625, 10.1995821], [76.15625, 10.20069504], [76.15598297, 10.20069027], [76.15598297, 10.20153141], [76.15569305, 10.20152569], [76.15569305, 10.20208263], [76.1554184, 10.20208263], [76.1554184, 10.20236111], [76.15513611, 10.20236111], [76.15513611, 10.20292091], [76.15486145, 10.2029171], [76.15486145, 10.20319462], [76.15458679, 10.20319462], [76.15458679, 10.20347309], [76.1543045, 10.20347309], [76.1543045, 10.20569515], [76.15402985, 10.20569038], [76.15402985, 10.2068119], [76.15374756, 10.20680523], [76.15374756, 10.20763874], [76.1534729, 10.20763874], [76.1534729, 10.20819473], [76.15319824, 10.20819092], [76.15319824, 10.20875072], [76.15291595, 10.20875072], [76.15291595, 10.2090292], [76.1526413, 10.20902729], [76.1526413, 10.20958328], [76.15235901, 10.20958138], [76.15235901, 10.21070004], [76.1526413, 10.21069527], [76.1526413, 10.21097088], [76.15235901, 10.21097088], [76.15235901, 10.21124935], [76.15208435, 10.21124935], [76.15208435, 10.21236134], [76.15180206, 10.21236134], [76.15180206, 10.2131958], [76.1515274, 10.21319103], [76.1515274, 10.21376133], [76.15125275, 10.21374893], [76.15125275, 10.21486187], [76.15097046, 10.21486187], [76.15097046, 10.21569443], [76.1506958, 10.21569443], [76.1506958, 10.21625042], [76.15041351, 10.21625042], [76.15041351, 10.2173624], [76.15013885, 10.21735954], [76.15013885, 10.21875], [76.14985657, 10.21875], [76.14985657, 10.21931267], [76.14958191, 10.21930599], [76.14958191, 10.21986198], [76.14930725, 10.21986198], [76.14930725, 10.22014046], [76.14902496, 10.2201376], [76.14902496, 10.22097206], [76.14875031, 10.22097206], [76.14875031, 10.22236156], [76.14847565, 10.22236156], [76.14847565, 10.22347164], [76.14819336, 10.22347164], [76.14819336, 10.22486019], [76.1479187, 10.22486019], [76.1479187, 10.22542095], [76.14763641, 10.22542095], [76.14763641, 10.22653103], [76.14736176, 10.22653103], [76.14736176, 10.22681141], [76.1470871, 10.22680664], [76.1470871, 10.22735977], [76.14653015, 10.22735977], [76.14653015, 10.22875118], [76.14624786, 10.22875118], [76.14624786, 10.22958279], [76.14597321, 10.22958279], [76.14597321, 10.23124886], [76.14569092, 10.23124886], [76.14569092, 10.23208332], [76.14541626, 10.23208141], [76.14541626, 10.23264122], [76.1451416, 10.23264122], [76.1451416, 10.2329216], [76.14485931, 10.23291683], [76.14485931, 10.23347092], [76.14457703, 10.23347092], [76.14457703, 10.23403168], [76.14428711, 10.23403168], [76.14428711, 10.23431015], [76.14402771, 10.23431015], [76.14402771, 10.23542023], [76.14428711, 10.23542023], [76.14428711, 10.23652935], [76.14402771, 10.23652935], [76.14402771, 10.23680973], [76.14430237, 10.23680496], [76.14430237, 10.23708344], [76.14402771, 10.23708057], [76.14402771, 10.23763943], [76.14375305, 10.23763943], [76.14375305, 10.23819542], [76.14347076, 10.23819065], [76.14347076, 10.23903179], [76.14319611, 10.23902702], [76.14319611, 10.23958302], [76.14290619, 10.23958111], [76.14290619, 10.24014187], [76.14263916, 10.24014187], [76.14263916, 10.24042034], [76.1423645, 10.24041843], [76.1423645, 10.24208355], [76.14208221, 10.24208069], [76.14208221, 10.24291992], [76.1423645, 10.24291801], [76.1423645, 10.24319363], [76.14208221, 10.24318886], [76.14208221, 10.24431038], [76.14180756, 10.24430561], [76.14180756, 10.24458408], [76.14208221, 10.24458408], [76.14208221, 10.2448597], [76.14180756, 10.2448597], [76.14180756, 10.24514008], [76.14152527, 10.24514008], [76.14152527, 10.24569416], [76.14125061, 10.24569416], [76.14125061, 10.24625015], [76.14097595, 10.24625015], [76.14097595, 10.24681091], [76.14069366, 10.24680614], [76.14069366, 10.24708366], [76.14041901, 10.24708366], [76.14041901, 10.24847221], [76.14013672, 10.24847221], [76.14013672, 10.2495842], [76.13986206, 10.24958038], [76.13986206, 10.25042057], [76.13957977, 10.2504158], [76.13957977, 10.25097179], [76.13930511, 10.25097179], [76.13930511, 10.25125027], [76.13903046, 10.25125027], [76.13903046, 10.25181103], [76.13874817, 10.25180435], [76.13874817, 10.25208473], [76.13847351, 10.25208473], [76.13847351, 10.25236034], [76.13874817, 10.25236034], [76.13874817, 10.25431061], [76.13819122, 10.25431061], [76.13819122, 10.25514126], [76.13791656, 10.25514126], [76.13791656, 10.25652885], [76.13764191, 10.25652885], [76.13764191, 10.25736141], [76.13735962, 10.25736141], [76.13735962, 10.25791931], [76.13708496, 10.2579174], [76.13708496, 10.2584734], [76.13680267, 10.25847054], [76.13680267, 10.2590313], [76.13652802, 10.25902653], [76.13652802, 10.26097107], [76.13625336, 10.26097107], [76.13625336, 10.26153183], [76.13597107, 10.26152706], [76.13597107, 10.26236057], [76.13625336, 10.26236057], [76.13625336, 10.26347256], [76.13597107, 10.26347256], [76.13597107, 10.26458263], [76.13569641, 10.26458073], [76.13569641, 10.26513863], [76.13541412, 10.26513863], [76.13541412, 10.26597118], [76.13513947, 10.26597118], [76.13513947, 10.26653194], [76.13485718, 10.26653194], [76.13485718, 10.26681042], [76.13458252, 10.2668047], [76.13458252, 10.26736164], [76.13430786, 10.26736164], [76.13430786, 10.26764202], [76.13458252, 10.26764011], [76.13458252, 10.26791763], [76.13430786, 10.26791763], [76.13430786, 10.2695837], [76.1340332, 10.26958084], [76.1340332, 10.27013969], [76.13375092, 10.27013969], [76.13375092, 10.27124977], [76.13346863, 10.27124977], [76.13346863, 10.27319431], [76.13318634, 10.27319241], [76.13318634, 10.27431107], [76.13291931, 10.2743063], [76.13291931, 10.27486229], [76.13263702, 10.27486038], [76.13263702, 10.27514267], [76.13291931, 10.27514267], [76.13291931, 10.27542114], [76.13263702, 10.27542114], [76.13263702, 10.27653122], [76.13234711, 10.27653122], [76.13236237, 10.27735996], [76.13208008, 10.27735996], [76.13208008, 10.27792072], [76.13180542, 10.27791595], [76.13180542, 10.27847195], [76.13153076, 10.27847195], [76.13153076, 10.27875042], [76.13124847, 10.27875042], [76.13124847, 10.27931118], [76.13096619, 10.27931118], [76.13096619, 10.28042126], [76.13069153, 10.28042126], [76.13069153, 10.28125095], [76.13096619, 10.28125095], [76.13096619, 10.28264141], [76.13069153, 10.28263855], [76.13069153, 10.28291702], [76.13041687, 10.28291035], [76.13041687, 10.28430939], [76.13014221, 10.28430939], [76.13014221, 10.28514099], [76.12985992, 10.28514099], [76.12985992, 10.28653145], [76.12958527, 10.28652668], [76.12958527, 10.28708267], [76.12985992, 10.2870779], [76.12985992, 10.28764057], [76.12960052, 10.28764057], [76.12960052, 10.28931046], [76.12928772, 10.28931046], [76.12928772, 10.2901392], [76.12902832, 10.2901392], [76.12902832, 10.29069328], [76.12874603, 10.29069138], [76.12874603, 10.29152966], [76.12847137, 10.29152966], [76.12847137, 10.29264164], [76.12819672, 10.29263878], [76.12819672, 10.29319572], [76.12791443, 10.29319572], [76.12791443, 10.29458427], [76.12763977, 10.29458427], [76.12763977, 10.29597187], [76.12735748, 10.29597187], [76.12735748, 10.29652977], [76.12708282, 10.29652977], [76.12708282, 10.29681015], [76.12680817, 10.29681015], [76.12680817, 10.29792023], [76.12654114, 10.29792023], [76.12654114, 10.2990303], [76.12625122, 10.2990303], [76.12625122, 10.29931068], [76.12652588, 10.29930592], [76.12652588, 10.29958439], [76.12625122, 10.29958439], [76.12625122, 10.29986191], [76.12596893, 10.29986191], [76.12596893, 10.30098057], [76.12541962, 10.30098057], [76.12541962, 10.30153275], [76.12513733, 10.30153275], [76.12513733, 10.30263996], [76.12486267, 10.30263996], [76.12486267, 10.3029213], [76.12431335, 10.3029213], [76.12431335, 10.30375004], [76.12458038, 10.30375004], [76.12458038, 10.30486012], [76.12430573, 10.30486012], [76.12430573, 10.30569363], [76.12403107, 10.30569363], [76.12403107, 10.3059721], [76.12431335, 10.30597019], [76.12431335, 10.30764103], [76.12403107, 10.30763817], [76.12403107, 10.30819511], [76.12374878, 10.30819511], [76.12374878, 10.30875111], [76.12348175, 10.30875111], [76.12348175, 10.30903053], [76.12319183, 10.30902863], [76.12319183, 10.30958271], [76.12291718, 10.30957985], [76.12291718, 10.31153107], [76.12264252, 10.31153107], [76.12264252, 10.31264114], [76.12236023, 10.31264114], [76.12236023, 10.31292152], [76.12208557, 10.31291676], [76.12208557, 10.31375122], [76.12180328, 10.31375122], [76.12180328, 10.31458282], [76.12208557, 10.31458282], [76.12208557, 10.3148613], [76.12180328, 10.3148613], [76.12180328, 10.31514072], [76.12152863, 10.31513882], [76.12152863, 10.31624889], [76.12124634, 10.31624889], [76.12124634, 10.31680965], [76.12097168, 10.31680965], [76.12097168, 10.31791973], [76.12069702, 10.31791687], [76.12069702, 10.31874943], [76.1204071, 10.31874943], [76.1204071, 10.31931019], [76.12014008, 10.31931019], [76.12014008, 10.32014179], [76.11985779, 10.32014179], [76.11985779, 10.32153034], [76.11958313, 10.32152843], [76.11958313, 10.32236195], [76.11930847, 10.32236195], [76.11930847, 10.32291985], [76.11902618, 10.32291794], [76.11902618, 10.32319355], [76.11846924, 10.32319069], [76.11846924, 10.32374954], [76.11875153, 10.32374954], [76.11875153, 10.3243103], [76.11846924, 10.3243103], [76.11846924, 10.32542038], [76.11818695, 10.32542038], [76.11818695, 10.32625008], [76.11791992, 10.32625008], [76.11791992, 10.32763958], [76.11818695, 10.32763958], [76.11818695, 10.32792091], [76.11791992, 10.32791805], [76.11791992, 10.32819366], [76.11763763, 10.3281889], [76.11763763, 10.32874966], [76.11734772, 10.32874966], [76.11736298, 10.32985973], [76.11708069, 10.32985973], [76.11708069, 10.33042145], [76.11680603, 10.33041573], [76.11680603, 10.3306942], [76.11653137, 10.33069038], [76.11653137, 10.33181095], [76.11624908, 10.33180428], [76.11624908, 10.33319378], [76.1159668, 10.33318996], [76.1159668, 10.33375072], [76.11569214, 10.33375072], [76.11569214, 10.33403111], [76.11541748, 10.33403111], [76.11541748, 10.33514118], [76.11514282, 10.33514118], [76.11514282, 10.33681107], [76.11486053, 10.33680534], [76.11486053, 10.33736134], [76.11460114, 10.33736134], [76.11460114, 10.33791924], [76.11431122, 10.33791924], [76.11431122, 10.33875084], [76.11402893, 10.33875084], [76.11402893, 10.33986092], [76.11374664, 10.33986092], [76.11374664, 10.34069538], [76.11347198, 10.34069538], [76.11347198, 10.34097099], [76.11319733, 10.34097099], [76.11319733, 10.34264088], [76.11292267, 10.34264088], [76.11292267, 10.34291935], [76.11235809, 10.34291935], [76.11235809, 10.34375095], [76.11207581, 10.34375095], [76.11207581, 10.34430981], [76.11180878, 10.34430504], [76.11180878, 10.34458256], [76.11152649, 10.34458256], [76.11152649, 10.34597111], [76.11125183, 10.34597111], [76.11120605, 10.34653187], [76.11096954, 10.34653187], [76.11096954, 10.34764194], [76.11068726, 10.34764194], [76.11068726, 10.34875202], [76.11042023, 10.34875202], [76.11042023, 10.34931946], [76.11013794, 10.34931946], [76.11013794, 10.35013962], [76.10986328, 10.35013962], [76.10986328, 10.3506937], [76.10958099, 10.3506937], [76.10958099, 10.35097218], [76.10930634, 10.35097218], [76.10930634, 10.35208416], [76.10901642, 10.35206985], [76.10901642, 10.35291958], [76.10874939, 10.35291576], [76.10874939, 10.35375023], [76.10847473, 10.35375023], [76.10847473, 10.35458374], [76.10819244, 10.35458374], [76.10819244, 10.35513783], [76.10791779, 10.35513783], [76.10791779, 10.35569382], [76.10764313, 10.35569191], [76.10764313, 10.35625172], [76.10736084, 10.35625172], [76.10736084, 10.35681057], [76.10708618, 10.35681057], [76.10708618, 10.35736179], [76.10680389, 10.35735989], [76.10680389, 10.35819435], [76.10652924, 10.35819435], [76.10652924, 10.35875034], [76.10624695, 10.35875034], [76.10624695, 10.35958195], [76.10597229, 10.35958004], [76.10597229, 10.3601408], [76.10569763, 10.3601408], [76.10569763, 10.36126041], [76.10540771, 10.36126041], [76.10540771, 10.36181068], [76.10514069, 10.36180687], [76.10514069, 10.36236095], [76.1048584, 10.36236095], [76.1048584, 10.36319542], [76.10457611, 10.3631897], [76.10458374, 10.36375141], [76.10430908, 10.36375141], [76.10430908, 10.36458302], [76.10402679, 10.36458302], [76.10402679, 10.365695], [76.10375214, 10.36569023], [76.10375214, 10.36625099], [76.10346985, 10.36625099], [76.10346985, 10.36680889], [76.10319519, 10.36680698], [76.10319519, 10.36819458], [76.1029129, 10.36819458], [76.1029129, 10.36847305], [76.10263824, 10.36847115], [76.10263824, 10.36903191], [76.10236359, 10.36902714], [76.10236359, 10.36958313], [76.1020813, 10.36958313], [76.1020813, 10.36986065], [76.10236359, 10.36986065], [76.10236359, 10.37013912], [76.1020813, 10.37013912], [76.1020813, 10.3712492], [76.10180664, 10.3712492], [76.10180664, 10.37180996], [76.10152435, 10.37180519], [76.10152435, 10.37236118], [76.10124969, 10.37236118], [76.10124969, 10.37320042], [76.10098267, 10.37320042], [76.10098267, 10.37375164], [76.10069275, 10.37374878], [76.10069275, 10.3745842], [76.10041809, 10.37458134], [76.10041809, 10.37514019], [76.1001358, 10.37514019], [76.1001358, 10.37541962], [76.09986115, 10.37541771], [76.09986115, 10.37708378], [76.09958649, 10.37708092], [76.09958649, 10.37792015], [76.0993042, 10.37791634], [76.0993042, 10.38069439], [76.09874725, 10.38069439], [76.09874725, 10.38097191], [76.0984726, 10.38097191], [76.0984726, 10.38125038], [76.09791565, 10.38125038], [76.09791565, 10.38208199], [76.09764099, 10.38208199], [76.09764099, 10.38292122], [76.0973587, 10.38291645], [76.0973587, 10.38319016], [76.09707642, 10.38320065], [76.09707642, 10.38374996], [76.09680939, 10.38374996], [76.09680176, 10.38458443], [76.0965271, 10.38458443], [76.0965271, 10.38569355], [76.09623718, 10.38568974], [76.09623718, 10.38653088], [76.09597015, 10.38653088], [76.09597015, 10.38681126], [76.09570313, 10.38681126], [76.09570313, 10.38764095], [76.09541321, 10.38764095], [76.09541321, 10.38820076], [76.09513855, 10.38820076], [76.09513855, 10.38931084], [76.09485626, 10.38931084], [76.09485626, 10.39014053], [76.0945816, 10.39014053], [76.0945816, 10.39042091], [76.09430695, 10.3904171], [76.09430695, 10.3912487], [76.09402466, 10.3912487], [76.09402466, 10.39208317], [76.09375, 10.39208031], [76.09375, 10.39292145], [76.09347534, 10.39291668], [76.09347534, 10.39347267], [76.0931778, 10.3934679], [76.0931778, 10.39403057], [76.0929184, 10.39402676], [76.0929184, 10.39486122], [76.09263611, 10.39486122], [76.09263611, 10.39597321], [76.09236145, 10.3959713], [76.09236145, 10.39680958], [76.09208679, 10.39680481], [76.09208679, 10.39708328], [76.09179688, 10.39708138], [76.09179688, 10.39763927], [76.09124756, 10.39763927], [76.09124756, 10.39903164], [76.0909729, 10.39902687], [76.0909729, 10.39958286], [76.09069824, 10.39958096], [76.09069824, 10.40043068], [76.09041595, 10.40041542], [76.09041595, 10.40097141], [76.0901413, 10.40097141], [76.0901413, 10.40180969], [76.08985901, 10.40180969], [76.08985901, 10.40264034], [76.08957672, 10.40264034], [76.08958435, 10.40375042], [76.08930206, 10.40375042], [76.08930206, 10.40402985], [76.0890274, 10.40402985], [76.0890274, 10.40431023], [76.08875275, 10.40431023], [76.08875275, 10.40513992], [76.08847046, 10.40513992], [76.08847046, 10.40625], [76.0881958, 10.40624142], [76.0881958, 10.40681267], [76.08790588, 10.40681267], [76.08790588, 10.40764046], [76.08763885, 10.4076376], [76.08763885, 10.40819359], [76.08737183, 10.40819168], [76.08737183, 10.40874958], [76.08708191, 10.40874958], [76.08708191, 10.40931129], [76.08680725, 10.40930557], [76.08680725, 10.40986156], [76.08651733, 10.40985966], [76.08651733, 10.41042137], [76.08625031, 10.41041565], [76.08625031, 10.41069412], [76.08598328, 10.41069031], [76.08598328, 10.41125011], [76.08569336, 10.41125011], [76.08569336, 10.41181087], [76.0854187, 10.41181087], [76.0854187, 10.41264057], [76.08513641, 10.41264057], [76.08513641, 10.41292095], [76.08486176, 10.41292095], [76.08486176, 10.41431141], [76.0845871, 10.41430664], [76.0845871, 10.41485977], [76.08429718, 10.41485977], [76.08429718, 10.41514111], [76.08403015, 10.41513824], [76.08403015, 10.41541672], [76.08374786, 10.41541195], [76.08374786, 10.41681099], [76.08347321, 10.41680527], [76.08347321, 10.41736126], [76.08319092, 10.41736126], [76.08319092, 10.41792107], [76.08291626, 10.41791725], [76.08291626, 10.41847324], [76.0826416, 10.41847134], [76.0826416, 10.41931152], [76.08291626, 10.41931152], [76.08291626, 10.41986084], [76.0826416, 10.41986084], [76.0826416, 10.4204216], [76.08235931, 10.42041683], [76.08235931, 10.4206953], [76.08180237, 10.4206953], [76.08180237, 10.4212513], [76.08152771, 10.4212513], [76.08152771, 10.42236137], [76.08125305, 10.42236137], [76.08125305, 10.42319489], [76.08097076, 10.42319489], [76.08097076, 10.42347336], [76.08069611, 10.42347145], [76.08069611, 10.42402935], [76.08040619, 10.42402935], [76.08040619, 10.42430973], [76.08013916, 10.42430496], [76.08013916, 10.42486095], [76.07985687, 10.42486095], [76.07985687, 10.42513943], [76.07958221, 10.42513943], [76.07958221, 10.42764187], [76.07930756, 10.42764187], [76.07930756, 10.42792034], [76.07902527, 10.42791843], [76.07902527, 10.42847061], [76.07875061, 10.42847061], [76.07875061, 10.42875195], [76.07820129, 10.42875195], [76.07820129, 10.42930984], [76.07791901, 10.42930603], [76.07791901, 10.43041801], [76.07763672, 10.43041134], [76.07763672, 10.43124962], [76.07736206, 10.43124962], [76.07736206, 10.43208408], [76.07707977, 10.43207932], [76.07707977, 10.43264008], [76.07681274, 10.43264008], [76.07681274, 10.43292046], [76.07624817, 10.43292046], [76.07624817, 10.43348122], [76.07596588, 10.43348122], [76.07596588, 10.43431091], [76.07569122, 10.43430614], [76.07569122, 10.43486214], [76.07543182, 10.43486023], [76.07543182, 10.43513966], [76.07514191, 10.43513966], [76.07514191, 10.43681145], [76.07485962, 10.43681145], [76.07485962, 10.43764019], [76.07458496, 10.43764019], [76.07458496, 10.43819427], [76.07430267, 10.43819427], [76.07430267, 10.43847179], [76.07402802, 10.43847179], [76.07402802, 10.43903065], [76.07375336, 10.43902779], [76.07375336, 10.43958378], [76.07347107, 10.43957996], [76.07347107, 10.44014072], [76.07319641, 10.44013786], [76.07319641, 10.4412508], [76.07291412, 10.4412508], [76.07291412, 10.44235992], [76.07263947, 10.44235134], [76.07263947, 10.44264126], [76.07208252, 10.44263935], [76.07208252, 10.44347286], [76.07180786, 10.44347], [76.07180786, 10.44430923], [76.07152557, 10.44430542], [76.07152557, 10.44458294], [76.07125092, 10.44458294], [76.07125092, 10.44486141], [76.07096863, 10.44486141], [76.07096863, 10.44514084], [76.07069397, 10.44513893], [76.07069397, 10.44569492], [76.07041931, 10.44569492], [76.07041931, 10.44708347], [76.07013702, 10.44708061], [76.07013702, 10.44791889], [76.06986237, 10.44791698], [76.06986237, 10.44819546], [76.06958008, 10.44818974], [76.06958008, 10.44847965], [76.06929779, 10.44847965], [76.06929779, 10.44903088], [76.06903076, 10.44903088], [76.06903076, 10.4493103], [76.06874847, 10.4493103], [76.06874847, 10.45014095], [76.06846619, 10.45014095], [76.06846619, 10.45125103], [76.06819153, 10.45125103], [76.06819153, 10.45181179], [76.06764221, 10.45180511], [76.06764221, 10.45208263], [76.06735992, 10.45208073], [76.06735992, 10.45292187], [76.0670929, 10.45292187], [76.0670929, 10.45431042], [76.06652832, 10.4543047], [76.06652832, 10.45597363], [76.06625366, 10.45597363], [76.06625366, 10.45625019], [76.06597137, 10.45625019], [76.06597137, 10.45681], [76.06541443, 10.45680618], [76.06541443, 10.4570837], [76.06513977, 10.4570837], [76.06513977, 10.45736217], [76.06485748, 10.45735931], [76.06485748, 10.45763969], [76.06513977, 10.45763969], [76.06513977, 10.45792007], [76.06485748, 10.45791626], [76.06485748, 10.45847225], [76.06458282, 10.45846939], [76.06458282, 10.45874977], [76.06430817, 10.45874977], [76.06430817, 10.45930958], [76.06402588, 10.45930576], [76.06402588, 10.45985985], [76.06375122, 10.45985985], [76.06375122, 10.46041965], [76.06346893, 10.46041584], [76.06346893, 10.46125031], [76.06319427, 10.46125031], [76.06319427, 10.46208191], [76.06291962, 10.46208382], [76.06291962, 10.46236229], [76.06263733, 10.46236038], [76.06263733, 10.46264172], [76.06236267, 10.4626379], [76.06236267, 10.46319389], [76.06208038, 10.46319199], [76.06208038, 10.46431065], [76.06180573, 10.46430588], [76.06180573, 10.46458435], [76.06153107, 10.46458435], [76.06153107, 10.46569443], [76.06124878, 10.46569443], [76.06124878, 10.46625042], [76.06097412, 10.46625042], [76.06097412, 10.46652794], [76.06041718, 10.46652794], [76.06041718, 10.46708202], [76.06014252, 10.46708202], [76.06014252, 10.46736336], [76.05986023, 10.46736336], [76.05986023, 10.46847343], [76.0595932, 10.46846962], [76.0595932, 10.46903133], [76.05930328, 10.46903133], [76.05930328, 10.46931076], [76.05902863, 10.46930695], [76.05902863, 10.4695816], [76.05874634, 10.4695816], [76.05874634, 10.46986103], [76.05902863, 10.46986103], [76.05902863, 10.47014141], [76.05874634, 10.47014141], [76.05874634, 10.47042084], [76.05847168, 10.47042084], [76.05847168, 10.47125053], [76.05819702, 10.47125053], [76.05819702, 10.47153091], [76.0579071, 10.47153091], [76.0579071, 10.47181129], [76.05764008, 10.47181129], [76.05764008, 10.47264957], [76.05735779, 10.47263908], [76.05735779, 10.4734726], [76.05706787, 10.47347069], [76.05706787, 10.47375107], [76.05680847, 10.47375107], [76.05680847, 10.47403145], [76.05652618, 10.47402668], [76.05652618, 10.47486115], [76.05625153, 10.47486115], [76.05625153, 10.47542191], [76.05596924, 10.47541714], [76.05596924, 10.47597313], [76.05568695, 10.47597122], [76.05568695, 10.47625065], [76.05541992, 10.47624874], [76.05541992, 10.47736073], [76.05513763, 10.47736073], [76.05513763, 10.47791958], [76.05486298, 10.47791672], [76.05486298, 10.47819519], [76.05458069, 10.47819519], [76.05458069, 10.47874928], [76.05432129, 10.47874928], [76.05432129, 10.47931194], [76.05403137, 10.47930527], [76.05403137, 10.47986126], [76.05374908, 10.47986126], [76.05374908, 10.48069572], [76.05347443, 10.48069572], [76.05347443, 10.48124886], [76.05319214, 10.48124886], [76.05319214, 10.48236179], [76.05264282, 10.48236179], [76.05264282, 10.48264027], [76.05236053, 10.48264027], [76.05236053, 10.4831934], [76.05208588, 10.48319054], [76.05208588, 10.48431015], [76.05180359, 10.48430634], [76.05180359, 10.48486233], [76.05152893, 10.48486042], [76.05152893, 10.48542023], [76.05124664, 10.48541641], [76.05124664, 10.4859724], [76.05097198, 10.48596859], [76.05097198, 10.48680973], [76.05041504, 10.48680592], [76.05041504, 10.48708439], [76.05014038, 10.48708153], [76.05014038, 10.48765087], [76.04985809, 10.48765087], [76.04985809, 10.48792267], [76.04958344, 10.48791599], [76.04958344, 10.48847198], [76.04930878, 10.48847198], [76.04930878, 10.48903275], [76.04902649, 10.48902798], [76.04902649, 10.48958397], [76.04875183, 10.48958397], [76.04875183, 10.48986244], [76.04846954, 10.48985958], [76.04846954, 10.4904213], [76.04818726, 10.4904213], [76.04818726, 10.49125004], [76.04792023, 10.49125004], [76.04792023, 10.49153137], [76.04763794, 10.49153137], [76.04763794, 10.4918108], [76.04736328, 10.49180603], [76.04736328, 10.49236012], [76.04708099, 10.49236012], [76.04708099, 10.4934721], [76.04680634, 10.49346066], [76.04680634, 10.49374962], [76.04651642, 10.49374962], [76.04651642, 10.49431133], [76.0459671, 10.49431133], [76.0459671, 10.49542141], [76.04569244, 10.49541569], [76.04569244, 10.49625111], [76.04541779, 10.49625111], [76.04541779, 10.49653053], [76.04512787, 10.49653053], [76.04512787, 10.49682045], [76.04486084, 10.49680424], [76.04486084, 10.49708462], [76.04458618, 10.49707985], [76.04458618, 10.49792099], [76.04430389, 10.49791718], [76.04430389, 10.49819469], [76.04402924, 10.49818993], [76.04402924, 10.49903107], [76.04374695, 10.49903107], [76.04374695, 10.4993124], [76.04347229, 10.49930477], [76.04347229, 10.49986076], [76.04319763, 10.4998579], [76.04319763, 10.50042057], [76.04292297, 10.50042057], [76.04292297, 10.50153065], [76.04264069, 10.50153065], [76.04264069, 10.50181198], [76.0423584, 10.50180531], [76.0423584, 10.50208282], [76.04208374, 10.50208282], [76.04208374, 10.5023613], [76.04180908, 10.5023613], [76.04180908, 10.5029192], [76.04125214, 10.50291729], [76.04125214, 10.50347328], [76.04096985, 10.50347137], [76.04096985, 10.50402927], [76.04070282, 10.50402927], [76.04070282, 10.50430965], [76.0404129, 10.50430489], [76.0404129, 10.50486088], [76.04013824, 10.50486088], [76.04013824, 10.50541973], [76.03986359, 10.50541687], [76.03986359, 10.50708294], [76.0404129, 10.50708294], [76.0404129, 10.50736141], [76.04069519, 10.50736141], [76.04069519, 10.50708294], [76.04208374, 10.50708294], [76.04208374, 10.50736141], [76.0423584, 10.50736141], [76.0423584, 10.50764179], [76.04264069, 10.50764179], [76.04264069, 10.50876141], [76.0423584, 10.50876141], [76.0423584, 10.50903034], [76.04208374, 10.50902653], [76.04208374, 10.51069355], [76.04180908, 10.51069069], [76.04180908, 10.51124954], [76.04152679, 10.51124954], [76.04152679, 10.51182175], [76.04125214, 10.51182175], [76.04125214, 10.51264], [76.04152679, 10.51264], [76.04152679, 10.51375198], [76.04125214, 10.51375008], [76.04125214, 10.51458359], [76.04096985, 10.51458359], [76.04096985, 10.51763821], [76.04070282, 10.51763058], [76.04070282, 10.51792145], [76.0404129, 10.51791573], [76.0404129, 10.51847172], [76.04013824, 10.51847172], [76.04013824, 10.51903057], [76.03986359, 10.51902771], [76.03986359, 10.5195837], [76.0395813, 10.5195837], [76.0395813, 10.51969242], [76.0395813, 10.51986027], [76.0393219, 10.51986027], [76.0393219, 10.52014065], [76.03903198, 10.52014065], [76.03903198, 10.52042103], [76.03874969, 10.52041626], [76.03874969, 10.52097225], [76.03848267, 10.52097034], [76.03848267, 10.52153111], [76.03819275, 10.52153111], [76.03819275, 10.52181053], [76.0376358, 10.52180672], [76.0376358, 10.52208233], [76.03708649, 10.52208042], [76.03708649, 10.52264118], [76.0368042, 10.52263832], [76.0368042, 10.52319527], [76.03624725, 10.52319527], [76.03624725, 10.52347279], [76.0359726, 10.52346992], [76.0359726, 10.52375984], [76.03569794, 10.52375984], [76.03569794, 10.52403069], [76.03514099, 10.52402878], [76.03514099, 10.52458286], [76.0348587, 10.52458477], [76.0348587, 10.52486134], [76.03458405, 10.52486134], [76.03458405, 10.52507019], [76.03457642, 10.52542114], [76.03430939, 10.52541733], [76.03430176, 10.52569485], [76.0340271, 10.52569485], [76.0340271, 10.52819538], [76.03430176, 10.52819538], [76.03430939, 10.52986145], [76.03457642, 10.52986145], [76.03457642, 10.53014088], [76.0348587, 10.53014088], [76.0348587, 10.53041935], [76.03541565, 10.53041744], [76.03541565, 10.53069305], [76.0359726, 10.53069305], [76.0359726, 10.53097343], [76.03624725, 10.53097057], [76.03624725, 10.53152943], [76.03652954, 10.53152943], [76.03652954, 10.53181171], [76.03708649, 10.53180504], [76.03708649, 10.53208256], [76.03736115, 10.53208256], [76.03736115, 10.53236103], [76.03794861, 10.53236103], [76.03874969, 10.53236103], [76.03874969, 10.53264236], [76.03985596, 10.53264236], [76.03985596, 10.53236103], [76.04096985, 10.53236103], [76.04096985, 10.53208256], [76.04319763, 10.53208256], [76.04319763, 10.53180504], [76.04374695, 10.53180504], [76.04374695, 10.53208256], [76.04541779, 10.53208256], [76.04541779, 10.53180504], [76.04569244, 10.53181171], [76.04569244, 10.53152943], [76.04792023, 10.53152943], [76.04792023, 10.53125095], [76.04846954, 10.53125095], [76.04846954, 10.53097057], [76.04985809, 10.53097057], [76.04985809, 10.53125095], [76.05042267, 10.53125095], [76.05042267, 10.53152943], [76.05097198, 10.53152943], [76.05097198, 10.53181171], [76.05208588, 10.53180504], [76.05208588, 10.53208256], [76.05263519, 10.53208256], [76.05263519, 10.53236103], [76.05291748, 10.53236103], [76.05291748, 10.53292179], [76.05319214, 10.53291702], [76.05319214, 10.53347111], [76.0534668, 10.53347111], [76.0534668, 10.53403187], [76.05374908, 10.53403187], [76.05374908, 10.53431034], [76.05430603, 10.53430462], [76.05430603, 10.53458309], [76.05403137, 10.53458309], [76.05403137, 10.53597355], [76.05374908, 10.53597069], [76.05374908, 10.53680992], [76.05319214, 10.53680611], [76.05319214, 10.53708363], [76.05374908, 10.53707886], [76.05374908, 10.53763962], [76.05347443, 10.53763962], [76.05347443, 10.53847218], [76.05319214, 10.53847218], [76.05319214, 10.53874969], [76.0534668, 10.53874111], [76.0534668, 10.53931046], [76.05319214, 10.53930569], [76.05319214, 10.54097176], [76.0534668, 10.54096985], [76.0534668, 10.54152966], [76.05319214, 10.54152775], [76.05319214, 10.54236221], [76.05291748, 10.54236031], [76.05291748, 10.54263973], [76.05236053, 10.54263783], [76.05236053, 10.54347229], [76.05347443, 10.54347229], [76.05347443, 10.54319382], [76.05374908, 10.54319382], [76.05374908, 10.54208374], [76.05403137, 10.54208374], [76.05403137, 10.54180622], [76.05458069, 10.54180622], [76.05458069, 10.54208374], [76.05486298, 10.54208374], [76.05486298, 10.54180622], [76.05541992, 10.54180622], [76.05541992, 10.54152775], [76.05568695, 10.54152966], [76.05568695, 10.54096985], [76.05596924, 10.54097176], [76.05596924, 10.54069424], [76.05625153, 10.54069424], [76.05625153, 10.54041576], [76.05680847, 10.54041958], [76.05680847, 10.54014015], [76.05706787, 10.54014015], [76.05706787, 10.53957939], [76.05735779, 10.53958416], [76.05735779, 10.53874969], [76.05764008, 10.53874969], [76.05764008, 10.5381937], [76.05847168, 10.5381937], [76.05847168, 10.53847218], [76.05874634, 10.53846931], [76.05874634, 10.53931046], [76.05986023, 10.53931046], [76.05986023, 10.53903008], [76.06012726, 10.53903008], [76.06012726, 10.53846931], [76.06069183, 10.53847218], [76.06069183, 10.5381937], [76.06097412, 10.5381937], [76.06097412, 10.53791809], [76.06124878, 10.53792], [76.06124878, 10.53763962], [76.06153107, 10.53763962], [76.06153107, 10.53735924], [76.06180573, 10.5373621], [76.06180573, 10.53708363], [76.06208038, 10.53708363], [76.06208038, 10.53652763], [76.06236267, 10.53652954], [76.06236267, 10.53625202], [76.06263733, 10.53625202], [76.06263733, 10.53597069], [76.06291962, 10.53597355], [76.06291962, 10.53569317], [76.06346893, 10.53569317], [76.06346893, 10.53597355], [76.06375122, 10.53597355], [76.06375122, 10.53708363], [76.06402588, 10.53708363], [76.06402588, 10.5373621], [76.06458282, 10.5373621], [76.06458282, 10.5381937], [76.06513977, 10.5381937], [76.06513977, 10.53847218], [76.06541443, 10.53847218], [76.06541443, 10.53874969], [76.06597137, 10.53874111], [76.06597137, 10.53931046], [76.06626129, 10.53931046], [76.06626129, 10.54041958], [76.06652832, 10.54041958], [76.06652832, 10.54263973], [76.06680298, 10.54263783], [76.06680298, 10.54319382], [76.06764221, 10.54319382], [76.06764221, 10.54458427], [76.06735992, 10.54458046], [76.06735992, 10.54514027], [76.0670929, 10.54514027], [76.0670929, 10.54542065], [76.06680298, 10.54541588], [76.06680298, 10.54625034], [76.06652832, 10.54625034], [76.06652832, 10.54653072], [76.06626129, 10.54653072], [76.06626129, 10.54625034], [76.06597137, 10.54625034], [76.06597137, 10.54597187], [76.06569672, 10.54597187], [76.06569672, 10.54569435], [76.06485748, 10.54569435], [76.06485748, 10.54597187], [76.06458282, 10.54597187], [76.06458282, 10.54625034], [76.06402588, 10.54625034], [76.06402588, 10.54653072], [76.06236267, 10.54653072], [76.06236267, 10.54596996], [76.06208038, 10.54597187], [76.06208038, 10.54541588], [76.06181335, 10.54542065], [76.06181335, 10.54487133], [76.06153107, 10.54487133], [76.06153107, 10.54431057], [76.06124878, 10.54431057], [76.06124878, 10.54403019], [76.06096649, 10.54403019], [76.06096649, 10.54375172], [76.06069183, 10.54375172], [76.06069183, 10.54319191], [76.06014252, 10.54319382], [76.06014252, 10.5429163], [76.05986023, 10.5429163], [76.05986023, 10.54347229], [76.0595932, 10.54347038], [76.0595932, 10.54375172], [76.05930328, 10.54375172], [76.05930328, 10.54487133], [76.05902863, 10.54487133], [76.05902863, 10.54514027], [76.05847168, 10.54514027], [76.05847168, 10.54569435], [76.05791473, 10.54569435], [76.05791473, 10.54597187], [76.05706787, 10.54596996], [76.05706787, 10.54625034], [76.05568695, 10.54625034], [76.05568695, 10.54653072], [76.05541992, 10.54653072], [76.05541992, 10.54625034], [76.05458069, 10.54625034], [76.05458069, 10.54597187], [76.05347443, 10.54597187], [76.05347443, 10.54569435], [76.05319214, 10.54569435], [76.05319214, 10.54541588], [76.05152893, 10.54541588], [76.05152893, 10.54569435], [76.05124664, 10.54569435], [76.05124664, 10.54597187], [76.05097198, 10.54597187], [76.05097198, 10.54625034], [76.05042267, 10.54625034], [76.05042267, 10.54653072], [76.05014038, 10.54653072], [76.05014038, 10.5468111], [76.04958344, 10.54680634], [76.04958344, 10.54708195], [76.04985809, 10.54708195], [76.04985809, 10.54736042], [76.04957581, 10.54736042], [76.04957581, 10.5476408], [76.04985809, 10.54763794], [76.04985809, 10.5484724], [76.04958344, 10.5484724], [76.04958344, 10.54958153], [76.04930878, 10.54958153], [76.04930878, 10.55125141], [76.04902649, 10.55125141], [76.04902649, 10.55153084], [76.04930878, 10.55153084], [76.04930878, 10.55181122], [76.04875183, 10.55180454], [76.04875183, 10.55236053], [76.04846954, 10.55236053], [76.04846954, 10.55264091], [76.04818726, 10.55264091], [76.04818726, 10.5529213], [76.04736328, 10.55291653], [76.04736328, 10.553195], [76.04708099, 10.553195], [76.04708099, 10.55375099], [76.04680634, 10.55373955], [76.04680634, 10.55430889], [76.04652405, 10.55430698], [76.04652405, 10.5545826], [76.04624939, 10.5545826], [76.04624939, 10.55486107], [76.04569244, 10.55486107], [76.04569244, 10.55542183], [76.04541779, 10.55541706], [76.04541779, 10.55569458], [76.04512787, 10.5556879], [76.04512787, 10.55625057], [76.04486084, 10.55625057], [76.04486084, 10.55653095], [76.04458618, 10.55652905], [76.04458618, 10.55819511], [76.04430389, 10.55819511], [76.04430389, 10.55847263], [76.04458618, 10.55847263], [76.04458618, 10.5587492], [76.04429626, 10.5587492], [76.04429626, 10.55986977], [76.04402924, 10.55986977], [76.04402924, 10.56014156], [76.04347229, 10.5601387], [76.04347229, 10.56069469], [76.04319763, 10.56069088], [76.04319763, 10.56125164], [76.04291534, 10.56124878], [76.04291534, 10.56208324], [76.04264069, 10.56208324], [76.04264069, 10.56236172], [76.0423584, 10.56235886], [76.0423584, 10.56264019], [76.04180908, 10.56264019], [76.04180908, 10.56293106], [76.04152679, 10.56291771], [76.04152679, 10.56347084], [76.04125214, 10.56347084], [76.04125214, 10.56431007], [76.04096985, 10.56430626], [76.04096985, 10.56597233], [76.04125214, 10.56597233], [76.04125214, 10.56624985], [76.04152679, 10.56624985], [76.04152679, 10.56653023], [76.04180908, 10.56653023], [76.04180908, 10.56680965], [76.04208374, 10.56680584], [76.04208374, 10.56708431], [76.04264069, 10.56708431], [76.04264069, 10.56736183], [76.04402924, 10.56736183], [76.04402924, 10.56708431], [76.04597473, 10.56708431], [76.04597473, 10.56680584], [76.04624939, 10.56680965], [76.04624939, 10.56653023], [76.04708099, 10.56652832], [76.04708099, 10.56708431], [76.04736328, 10.56708241], [76.04736328, 10.56791973], [76.04680634, 10.56791592], [76.04680634, 10.56819439], [76.04652405, 10.56819439], [76.04652405, 10.56847191], [76.04624939, 10.56847191], [76.04624939, 10.56958199], [76.04597473, 10.56958199], [76.04597473, 10.56986237], [76.04569244, 10.56986046], [76.04569244, 10.57042122], [76.04541779, 10.57042122], [76.04541779, 10.57124996], [76.04512787, 10.57124996], [76.04512787, 10.57153034], [76.04486084, 10.57153034], [76.04486084, 10.57181072], [76.04458618, 10.57180595], [76.04458618, 10.57236004], [76.04429626, 10.57236004], [76.04429626, 10.57264042], [76.04319763, 10.57263756], [76.04319763, 10.57319355], [76.04291534, 10.57319355], [76.04291534, 10.57347202], [76.04264069, 10.57347012], [76.04264069, 10.57431126], [76.04291534, 10.57430553], [76.04291534, 10.5745821], [76.04264069, 10.57458019], [76.04264069, 10.57487202], [76.0423584, 10.57487202], [76.0423584, 10.57514095], [76.04206848, 10.57514095], [76.04206848, 10.57542133], [76.04152679, 10.57542133], [76.04152679, 10.57514095], [76.04180908, 10.57514095], [76.04180908, 10.57153034], [76.04125214, 10.57153034], [76.04125214, 10.57124996], [76.04070282, 10.57124996], [76.04070282, 10.57096958], [76.0404129, 10.57096958], [76.0404129, 10.57124996], [76.03985596, 10.57124996], [76.03985596, 10.57096958], [76.03902435, 10.57097244], [76.03902435, 10.57069397], [76.03847504, 10.57069397], [76.03847504, 10.57041645], [76.0376358, 10.57042122], [76.0376358, 10.57014179], [76.03736115, 10.57014179], [76.03736115, 10.56958199], [76.03708649, 10.56958199], [76.03708649, 10.5690279], [76.03679657, 10.56903267], [76.03679657, 10.56847191], [76.03652954, 10.56847191], [76.03652954, 10.56819439], [76.03624725, 10.56819439], [76.03624725, 10.56791592], [76.03652954, 10.56791973], [76.03652954, 10.56680965], [76.03679657, 10.56680965], [76.03679657, 10.56624985], [76.03708649, 10.56624985], [76.03708649, 10.56569576], [76.03736115, 10.56569576], [76.03736115, 10.56486225], [76.0376358, 10.56486225], [76.0376358, 10.56430626], [76.03819275, 10.56431007], [76.03819275, 10.56402969], [76.03874969, 10.56402969], [76.03874969, 10.56375027], [76.03902435, 10.56375027], [76.03902435, 10.56347084], [76.03930664, 10.56347084], [76.03930664, 10.56319332], [76.0395813, 10.56319332], [76.0395813, 10.56291771], [76.03985596, 10.56293106], [76.03985596, 10.56264019], [76.04013824, 10.56264019], [76.04013824, 10.56069088], [76.0404129, 10.56069469], [76.0404129, 10.56041527], [76.04013824, 10.56042194], [76.04013824, 10.56014156], [76.0404129, 10.56014156], [76.0404129, 10.55986977], [76.04070282, 10.55986977], [76.04070282, 10.5595808], [76.0404129, 10.55958271], [76.0404129, 10.55930519], [76.04070282, 10.55931187], [76.04070282, 10.55902863], [76.04096985, 10.55902863], [76.04096985, 10.55791855], [76.04125214, 10.55791855], [76.04125214, 10.55764103], [76.04152679, 10.55764103], [76.04152679, 10.55736065], [76.04180908, 10.55736065], [76.04180908, 10.55708313], [76.04208374, 10.55708313], [76.04208374, 10.55680466], [76.0423584, 10.55681038], [76.0423584, 10.55653095], [76.04264069, 10.55653095], [76.04264069, 10.55625057], [76.04292297, 10.55625057], [76.04292297, 10.55597115], [76.04319763, 10.55597305], [76.04319763, 10.55569458], [76.04347229, 10.55569458], [76.04347229, 10.55347347], [76.04374695, 10.55347347], [76.04374695, 10.553195], [76.04402924, 10.553195], [76.04402924, 10.55152893], [76.04429626, 10.55153084], [76.04429626, 10.55097008], [76.04458618, 10.55097294], [76.04458618, 10.55041695], [76.04486084, 10.55041885], [76.04486084, 10.54986], [76.0451355, 10.54986], [76.04512787, 10.54957962], [76.04541779, 10.54958153], [76.04541779, 10.54930687], [76.04569244, 10.54931068], [76.04569244, 10.54903126], [76.0459671, 10.54903126], [76.0459671, 10.54846954], [76.04652405, 10.5484724], [76.04652405, 10.54763794], [76.04680634, 10.5476408], [76.04680634, 10.54736042], [76.04736328, 10.54736042], [76.04736328, 10.54652786], [76.04763794, 10.54653072], [76.04763794, 10.54596996], [76.04736328, 10.54597187], [76.04736328, 10.54485989], [76.04763794, 10.54487133], [76.04763794, 10.54292011], [76.04736328, 10.54292011], [76.04736328, 10.54152966], [76.04763794, 10.54152966], [76.04763794, 10.54096985], [76.04792023, 10.54097176], [76.04792023, 10.54041576], [76.04818726, 10.54041958], [76.04818726, 10.53903008], [76.04792023, 10.53903008], [76.04792023, 10.53625202], [76.04818726, 10.53625202], [76.04818726, 10.53514194], [76.04792023, 10.53514194], [76.04792023, 10.53431034], [76.04763794, 10.53431034], [76.04763794, 10.53403187], [76.04736328, 10.53403187], [76.04736328, 10.53347111], [76.04708099, 10.53347111], [76.04708099, 10.53375244], [76.04680634, 10.53375244], [76.04680634, 10.53347111], [76.04651642, 10.53347111], [76.04651642, 10.53375244], [76.0459671, 10.53375244], [76.0459671, 10.53403187], [76.04512787, 10.53403187], [76.04512787, 10.53431034], [76.04464722, 10.53430462], [76.04430389, 10.53430462], [76.04430389, 10.53458118], [76.04430389, 10.53486061], [76.04408264, 10.53486061], [76.04374695, 10.53486061], [76.04374695, 10.53514194], [76.04319763, 10.53514194], [76.04319763, 10.53542042], [76.04264069, 10.53542042], [76.04264069, 10.53569984], [76.04208374, 10.53569317], [76.04208374, 10.53597355], [76.04180908, 10.53597355], [76.04180908, 10.53569317], [76.04069519, 10.53569317], [76.04069519, 10.53597355], [76.03847504, 10.53597355], [76.03847504, 10.53569317], [76.0376358, 10.53569984], [76.0376358, 10.53542042], [76.03650665, 10.53541756], [76.0359726, 10.53542042], [76.0359726, 10.53514194], [76.03569794, 10.53514194], [76.03569794, 10.53542042], [76.03542328, 10.53542042], [76.03542328, 10.53514194], [76.0348587, 10.53514194], [76.0348587, 10.53486061], [76.03457642, 10.53486061], [76.03457642, 10.53514194], [76.03430176, 10.53514194], [76.03430176, 10.53486061], [76.03347015, 10.53486061], [76.03347015, 10.53680992], [76.0331955, 10.53680611], [76.0331955, 10.53708363], [76.03291321, 10.53708363], [76.03291321, 10.5373621], [76.0320816, 10.5373621], [76.0320816, 10.53708363], [76.03180695, 10.53708363], [76.03180695, 10.53680611], [76.0320816, 10.53680992], [76.0320816, 10.53625202], [76.03235626, 10.53625202], [76.03235626, 10.53569984], [76.03263855, 10.53569984], [76.03263855, 10.53514194], [76.03318787, 10.53514194], [76.03318787, 10.53319073], [76.03347015, 10.53319454], [76.03347015, 10.53236103], [76.03318787, 10.53236103], [76.03318787, 10.53181171], [76.03289795, 10.53181171], [76.03289795, 10.53125095], [76.03263855, 10.53125095], [76.03263855, 10.53069115], [76.03236389, 10.53069305], [76.03236389, 10.53013897], [76.03180695, 10.53014088], [76.03180695, 10.52902889], [76.03151703, 10.52902889], [76.03151703, 10.52818966], [76.03097534, 10.52819538], [76.03097534, 10.5265274], [76.03125, 10.52653122], [76.03125, 10.52569008], [76.03152466, 10.52569485], [76.03152466, 10.52513885], [76.03180695, 10.52513885], [76.03180695, 10.52486134], [76.0320816, 10.52486134], [76.0320816, 10.52447128], [76.0320816, 10.52430534], [76.03235626, 10.52431107], [76.03235626, 10.52375984], [76.03263855, 10.52375984], [76.03263855, 10.52318954], [76.03291321, 10.52319527], [76.03291321, 10.52291679], [76.03347015, 10.52292061], [76.03347015, 10.52235985], [76.03375244, 10.52235985], [76.03375244, 10.52208233], [76.0340271, 10.52208233], [76.0340271, 10.52180672], [76.03430176, 10.52181053], [76.03430176, 10.52153111], [76.03457642, 10.52153111], [76.03457642, 10.52097034], [76.03541565, 10.52097225], [76.03541565, 10.52069378], [76.03514099, 10.52070141], [76.03514099, 10.52014065], [76.03542328, 10.52014065], [76.03542328, 10.51958179], [76.03569794, 10.5195837], [76.03569794, 10.51930618], [76.0359726, 10.51931095], [76.03598785, 10.51909447], [76.03624725, 10.51903057], [76.03624725, 10.51792145], [76.03652954, 10.51792145], [76.03652954, 10.51763058], [76.0368042, 10.51763821], [76.0368042, 10.51708412], [76.03708649, 10.51708412], [76.03708649, 10.51680565], [76.03736115, 10.51681137], [76.03736115, 10.51624966], [76.0376358, 10.51624966], [76.0376358, 10.5156889], [76.03791809, 10.51569366], [76.03791809, 10.51513767], [76.03819275, 10.51513958], [76.03819275, 10.51457024], [76.03847504, 10.51458359], [76.03847504, 10.51375008], [76.03874969, 10.51375198], [76.03874969, 10.5134716], [76.03902435, 10.5134716], [76.03902435, 10.51291561], [76.0393219, 10.51292038], [76.0393219, 10.51264], [76.0395813, 10.51264], [76.0395813, 10.51207924], [76.03986359, 10.51208401], [76.03986359, 10.51124954], [76.04013824, 10.51124954], [76.04013824, 10.51069069], [76.03986359, 10.51069355], [76.03986359, 10.5101366], [76.0395813, 10.51014042], [76.0395813, 10.50986195], [76.03819275, 10.50986195], [76.03819275, 10.51014042], [76.03624725, 10.51014042], [76.03624725, 10.51041985], [76.0359726, 10.51041794], [76.0359726, 10.51097202], [76.03569794, 10.51097202], [76.03569794, 10.51124954], [76.03542328, 10.51124954], [76.03542328, 10.51182175], [76.03514099, 10.51180553], [76.03514099, 10.51236153], [76.0348587, 10.51235962], [76.0348587, 10.51292038], [76.03458405, 10.51291561], [76.03458405, 10.5134716], [76.0340271, 10.5134716], [76.0340271, 10.51403046], [76.03375244, 10.51403046], [76.03375244, 10.51431274], [76.03347015, 10.51430607], [76.03347015, 10.51486206], [76.0331955, 10.51486206], [76.0331955, 10.51569366], [76.03289795, 10.5156889], [76.03289795, 10.51624966], [76.03263855, 10.51624966], [76.03263855, 10.51735973], [76.03235626, 10.51735973], [76.03235626, 10.51792145], [76.0320816, 10.51791573], [76.0320816, 10.5181942], [76.03180695, 10.51819038], [76.03180695, 10.51903057], [76.03152466, 10.51902771], [76.03152466, 10.5195837], [76.03125, 10.5195837], [76.03125, 10.51986027], [76.03097534, 10.51986027], [76.03097534, 10.52097225], [76.03069305, 10.52097034], [76.03069305, 10.52153111], [76.0304184, 10.52153111], [76.0304184, 10.52181053], [76.03013611, 10.52180672], [76.03013611, 10.52235985], [76.02986145, 10.52235985], [76.02986145, 10.52292061], [76.02958679, 10.52291679], [76.02958679, 10.52347279], [76.02929688, 10.52346992], [76.02925873, 10.52375984], [76.02902985, 10.52375126], [76.02902985, 10.52458286], [76.02874756, 10.52458477], [76.02874756, 10.52513885], [76.0284729, 10.52513885], [76.0284729, 10.52625084], [76.02819824, 10.52625084], [76.02819824, 10.52653122], [76.02791595, 10.5265274], [76.02791595, 10.5270834], [76.0276413, 10.52707958], [76.0276413, 10.5276413], [76.02735901, 10.52763939], [76.02735901, 10.5284729], [76.02680206, 10.52847099], [76.02680206, 10.52902889], [76.0265274, 10.52902889], [76.0265274, 10.52930927], [76.02625275, 10.52930927], [76.02625275, 10.53041935], [76.02597046, 10.53041935], [76.02597046, 10.53181171], [76.0256958, 10.53180504], [76.0256958, 10.53208256], [76.02513885, 10.53208256], [76.02513885, 10.53347111], [76.02485657, 10.53347111], [76.02485657, 10.53403187], [76.02458191, 10.5340271], [76.02458191, 10.53458309], [76.02430725, 10.53458118], [76.02430725, 10.53514194], [76.02403259, 10.53514194], [76.02403259, 10.53569984], [76.02375031, 10.53569317], [76.02375031, 10.53597355], [76.02319336, 10.53597069], [76.02319336, 10.53680992], [76.0229187, 10.53680611], [76.0229187, 10.5381937], [76.02263641, 10.5381937], [76.02263641, 10.53874969], [76.02236176, 10.53874111], [76.02236176, 10.53931046], [76.02179718, 10.53931046], [76.02180481, 10.53985977], [76.02153015, 10.53985977], [76.02153015, 10.54097176], [76.02124786, 10.54096985], [76.02124786, 10.54152966], [76.02097321, 10.54152775], [76.02097321, 10.54180622], [76.02069092, 10.54180145], [76.02069092, 10.54263973], [76.02041626, 10.54263973], [76.02041626, 10.54292011], [76.0201416, 10.54292011], [76.0201416, 10.54403019], [76.01985931, 10.54403019], [76.01985931, 10.54487133], [76.01958466, 10.54485989], [76.01958466, 10.54597187], [76.01930237, 10.54596996], [76.01930237, 10.5468111], [76.01902771, 10.54680634], [76.01902771, 10.54736042], [76.01875305, 10.54736042], [76.01875305, 10.5476408], [76.01847076, 10.54763794], [76.01847076, 10.5484724], [76.01821136, 10.54846954], [76.01821136, 10.54931068], [76.01789856, 10.54931068], [76.01791382, 10.54986], [76.01763916, 10.54986], [76.01763916, 10.55014133], [76.01735687, 10.55014133], [76.01735687, 10.55153084], [76.01708221, 10.55152893], [76.01708221, 10.55208302], [76.01735687, 10.55208015], [76.01735687, 10.55264091], [76.01708221, 10.55263901], [76.01708221, 10.55347347], [76.01680756, 10.55347347], [76.01680756, 10.55375099], [76.0165329, 10.55373955], [76.0165329, 10.55403137], [76.01597595, 10.5540266], [76.01597595, 10.5545826], [76.01568604, 10.55458069], [76.01568604, 10.55542183], [76.01597595, 10.55542183], [76.01597595, 10.55625057], [76.01568604, 10.55625057], [76.01568604, 10.55681038], [76.01541901, 10.55680466], [76.01541901, 10.55736065], [76.01515198, 10.55736065], [76.01515198, 10.55764103], [76.01486206, 10.55763912], [76.01486206, 10.5587492], [76.01457977, 10.5587492], [76.01457977, 10.55958271], [76.01431274, 10.5595808], [76.01431274, 10.55986977], [76.01403046, 10.55986977], [76.01403046, 10.56042194], [76.01374817, 10.56041527], [76.01374817, 10.56097126], [76.01346588, 10.56097126], [76.01346588, 10.56153202], [76.01319122, 10.56153202], [76.01319122, 10.56180954], [76.01291656, 10.56180477], [76.01291656, 10.56208324], [76.01264191, 10.56208134], [76.01264191, 10.56264019], [76.01235962, 10.56264019], [76.01235962, 10.56375027], [76.01209259, 10.56375027], [76.01209259, 10.56431007], [76.01180267, 10.56430626], [76.01180267, 10.56458378], [76.01152802, 10.56458378], [76.01152802, 10.56486225], [76.01125336, 10.56486225], [76.01125336, 10.56569576], [76.01097107, 10.56569576], [76.01097107, 10.56624985], [76.01069641, 10.56624985], [76.01069641, 10.56653023], [76.01040649, 10.56653023], [76.01040649, 10.5676403], [76.01013947, 10.5676403], [76.01013947, 10.56791973], [76.00985718, 10.56791973], [76.00985718, 10.56903267], [76.00930786, 10.5690279], [76.00930786, 10.56958199], [76.00902557, 10.56958199], [76.00901794, 10.5706892], [76.00875092, 10.57070065], [76.00875092, 10.57153034], [76.00846863, 10.57153034], [76.00846863, 10.57181072], [76.00819397, 10.57180595], [76.00819397, 10.57208443], [76.00791931, 10.57207966], [76.00791931, 10.5729208], [76.00763702, 10.5729208], [76.00763702, 10.57403088], [76.00736237, 10.57402802], [76.00736237, 10.5745821], [76.00681305, 10.57458019], [76.00681305, 10.57514095], [76.00653076, 10.57514095], [76.00653076, 10.57542133], [76.00624847, 10.57542133], [76.00624847, 10.57681084], [76.00597382, 10.57680416], [76.00597382, 10.57736111], [76.00569153, 10.57736111], [76.00569153, 10.57819462], [76.00541687, 10.57818985], [76.00541687, 10.57875061], [76.00514221, 10.57875061], [76.00514221, 10.57903099], [76.00485992, 10.57902908], [76.00485992, 10.57958317], [76.00458527, 10.57958317], [76.00458527, 10.57986069], [76.00430298, 10.57986069], [76.00430298, 10.58069515], [76.00402832, 10.58069515], [76.00402832, 10.58208275], [76.00374603, 10.58208275], [76.00374603, 10.58264065], [76.00347137, 10.58264065], [76.00347137, 10.58292198], [76.00319672, 10.58291721], [76.00319672, 10.58347321], [76.00292206, 10.5834713], [76.00292206, 10.58375072], [76.00263977, 10.58374882], [76.00263977, 10.58569527], [76.00235748, 10.58569527], [76.00235748, 10.58625126], [76.00208282, 10.58625126], [76.00208282, 10.58681202], [76.00180817, 10.58680534], [76.00180817, 10.58708286], [76.00152588, 10.58708286], [76.00152588, 10.58763885], [76.00125122, 10.58763885], [76.00125122, 10.58847141], [76.00096893, 10.58847141], [76.00096893, 10.58875179], [76.00068665, 10.58875179], [76.00068665, 10.58903027], [76.00015259, 10.58903027], [75.99958038, 10.58903027], [75.99958038, 10.59014034], [75.99931335, 10.59014034], [75.99931335, 10.59041977], [75.99903107, 10.59041786], [75.99903107, 10.59097195], [75.99874878, 10.59097195], [75.99874878, 10.59152985], [75.99847412, 10.59152794], [75.99847412, 10.5923624], [75.99819183, 10.59235859], [75.99819183, 10.59375191], [75.99791718, 10.59375], [75.99791718, 10.59486198], [75.99764252, 10.59486198], [75.99764252, 10.59569359], [75.99736023, 10.59569168], [75.99736023, 10.59652996], [75.99708557, 10.59652805], [75.99708557, 10.59736156], [75.99680328, 10.59736156], [75.99680328, 10.59819412], [75.99652863, 10.59819031], [75.99652863, 10.59904194], [75.99624634, 10.59902763], [75.99624634, 10.59986019], [75.99597168, 10.59986019], [75.99597168, 10.60042095], [75.99569702, 10.60042095], [75.99569702, 10.60124969], [75.99541473, 10.60124969], [75.99541473, 10.60208225], [75.99514008, 10.60208035], [75.99514008, 10.60264111], [75.99485779, 10.60263824], [75.99485779, 10.60347271], [75.99458313, 10.60346985], [75.99458313, 10.60403061], [75.99430847, 10.6040287], [75.99430847, 10.60458469], [75.99401855, 10.60457993], [75.99401855, 10.60514069], [75.99375153, 10.60513878], [75.99375153, 10.60569477], [75.99346924, 10.60569477], [75.99346924, 10.60625076], [75.99319458, 10.60625076], [75.99319458, 10.60708332], [75.99291992, 10.60708046], [75.99291992, 10.60764122], [75.99263763, 10.60763931], [75.99263763, 10.6081953], [75.99236298, 10.6081953], [75.99236298, 10.6087513], [75.99208069, 10.6087513], [75.99208069, 10.6093092], [75.99180603, 10.6093092], [75.99180603, 10.61013889], [75.99153137, 10.61013889], [75.99153137, 10.61069489], [75.99124908, 10.61069107], [75.99124908, 10.61125088], [75.99097443, 10.61124897], [75.99097443, 10.61208344], [75.99069214, 10.61208057], [75.99069214, 10.61263943], [75.99041748, 10.61263943], [75.99041748, 10.61319542], [75.99013519, 10.61319542], [75.99013519, 10.61402702], [75.98986053, 10.61402702], [75.98986053, 10.61458302], [75.98958588, 10.61458111], [75.98958588, 10.61514187], [75.98930359, 10.61513901], [75.98930359, 10.61597443], [75.98902893, 10.61597061], [75.98902893, 10.61653042], [75.98874664, 10.6165266], [75.98874664, 10.61736202], [75.98847198, 10.61736202], [75.98847198, 10.61791992], [75.98819733, 10.61791801], [75.98819733, 10.6184721], [75.98792267, 10.61846924], [75.98792267, 10.61931038], [75.98764038, 10.61930561], [75.98764038, 10.6198597], [75.98735809, 10.6198597], [75.98735809, 10.62042046], [75.98708344, 10.62041569], [75.98708344, 10.62097168], [75.98680878, 10.62097168], [75.98680878, 10.62152958], [75.98652649, 10.62152767], [75.98652649, 10.62208366], [75.98625183, 10.6220789], [75.98625183, 10.62263966], [75.98596954, 10.62263775], [75.98596954, 10.62319374], [75.98568726, 10.62319183], [75.98568726, 10.62374973], [75.98542023, 10.62374973], [75.98542023, 10.62431145], [75.98513794, 10.62431145], [75.98513794, 10.62486172], [75.98484802, 10.62486172], [75.98484802, 10.62542057], [75.98458099, 10.6254158], [75.98458099, 10.62597179], [75.98430634, 10.6259613], [75.98430634, 10.62681103], [75.98402405, 10.62680626], [75.98402405, 10.62736034], [75.98374939, 10.62736034], [75.98374939, 10.6279211], [75.98347473, 10.62791634], [75.98347473, 10.62847233], [75.98319244, 10.62847233], [75.98319244, 10.62902641], [75.98291779, 10.62902641], [75.98291779, 10.62958241], [75.98264313, 10.62957954], [75.98264313, 10.63014126], [75.98236084, 10.6301384], [75.98236084, 10.63069534], [75.98207855, 10.63068962], [75.98207855, 10.63125134], [75.98178864, 10.63125134], [75.98178864, 10.63180923], [75.98152924, 10.63180447], [75.98152924, 10.63236141], [75.98124695, 10.63236141], [75.98124695, 10.63292122], [75.98097229, 10.63292122], [75.98097229, 10.6340313], [75.98069763, 10.6340313], [75.98069763, 10.63514996], [75.98041534, 10.63513947], [75.98041534, 10.63569546], [75.98014069, 10.63568974], [75.98014069, 10.63624859], [75.9798584, 10.63625145], [75.9798584, 10.63653088], [75.97957611, 10.63653088], [75.97957611, 10.63680935], [75.97930908, 10.63680458], [75.97930908, 10.63708305], [75.97902679, 10.63708305], [75.97902679, 10.63736057], [75.97875214, 10.63736057], [75.97875214, 10.63958263], [75.97846985, 10.63958073], [75.97846985, 10.64014244], [75.97820282, 10.64014244], [75.97820282, 10.64042187], [75.9779129, 10.6404171], [75.9779129, 10.64069462], [75.97763824, 10.6406908], [75.97763824, 10.64125156], [75.97735596, 10.64125156], [75.97735596, 10.64181042], [75.9770813, 10.6418047], [75.9770813, 10.64236069], [75.97680664, 10.64236069], [75.97680664, 10.64291954], [75.97652435, 10.64291763], [75.97652435, 10.64347363], [75.97624969, 10.64346886], [75.97624969, 10.64431], [75.97597504, 10.64430618], [75.97597504, 10.64486217], [75.97569275, 10.64485931], [75.97569275, 10.64542007], [75.97541809, 10.64541531], [75.97541809, 10.64597225], [75.9751358, 10.64596939], [75.9751358, 10.64653015], [75.97486115, 10.64653015], [75.97486115, 10.64709091], [75.97458649, 10.64709091], [75.97458649, 10.64764023], [75.9743042, 10.64764023], [75.9743042, 10.64819431], [75.97402954, 10.64819145], [75.97402954, 10.64902973], [75.97374725, 10.64902782], [75.97374725, 10.64958191], [75.9734726, 10.64958382], [75.9734726, 10.6501379], [75.97319794, 10.6501379], [75.97319794, 10.65069389], [75.97290802, 10.65069199], [75.97290802, 10.65125179], [75.97264099, 10.65125179], [75.97264099, 10.65181065], [75.9723587, 10.65180588], [75.9723587, 10.65235996], [75.97208405, 10.65235996], [75.97208405, 10.65319443], [75.97180939, 10.65319443], [75.97180176, 10.65375042], [75.9715271, 10.65375042], [75.9715271, 10.65458202], [75.97125244, 10.65458202], [75.97125244, 10.65542126], [75.97097015, 10.65541553], [75.97097015, 10.65597153], [75.97070313, 10.65596962], [75.97070313, 10.65681076], [75.97041321, 10.65680695], [75.97041321, 10.65736008], [75.97013855, 10.65736008], [75.97013855, 10.65819454], [75.96984863, 10.65818977], [75.96984863, 10.65903091], [75.9695816, 10.65902901], [75.9695816, 10.65958309], [75.96930695, 10.65958023], [75.96930695, 10.66014099], [75.96902466, 10.66013908], [75.96902466, 10.66069508], [75.96875, 10.66069508], [75.96875, 10.6609726], [75.96848297, 10.66097069], [75.96848297, 10.66153145], [75.96819305, 10.66153145], [75.96819305, 10.66181183], [75.9679184, 10.66180515], [75.9679184, 10.66236115], [75.96763611, 10.66236115], [75.96763611, 10.66264057], [75.96736145, 10.66263866], [75.96736145, 10.66319466], [75.96708679, 10.66319466], [75.96708679, 10.66347313], [75.96681213, 10.66347122], [75.96681213, 10.66403103], [75.96652985, 10.66403103], [75.96652985, 10.66431046], [75.96624756, 10.66431046], [75.96624756, 10.66486073], [75.9659729, 10.66486073], [75.9659729, 10.66541862], [75.96569824, 10.66541672], [75.96569824, 10.6659708], [75.96541595, 10.66596889], [75.96541595, 10.66653156], [75.9651413, 10.66652679], [75.9651413, 10.66708279], [75.96485901, 10.66708088], [75.96485901, 10.66792202], [75.96458435, 10.66791725], [75.96458435, 10.66847134], [75.96430206, 10.66847134], [75.96430206, 10.66903019], [75.9640274, 10.66902733], [75.9640274, 10.66958332], [75.96375275, 10.66958141], [75.96375275, 10.67014027], [75.96347046, 10.67014027], [75.96347046, 10.6706934], [75.9631958, 10.67069054], [75.9631958, 10.67126083], [75.96290588, 10.67126083], [75.96290588, 10.67181015], [75.96263885, 10.67180634], [75.96263885, 10.67236233], [75.96235657, 10.67235947], [75.96235657, 10.67292023], [75.96208191, 10.67291641], [75.96208191, 10.6734724], [75.96180725, 10.67346859], [75.96180725, 10.6740303], [75.96152496, 10.6740284], [75.96152496, 10.67458439], [75.96125031, 10.67458153], [75.96125031, 10.67514038], [75.96097565, 10.67513847], [75.96097565, 10.67597198], [75.96069336, 10.67597198], [75.96069336, 10.67653275], [75.9604187, 10.67652798], [75.9604187, 10.67708397], [75.96013641, 10.67706966], [75.96013641, 10.67763996], [75.95986176, 10.67763805], [75.95986176, 10.67819405], [75.9595871, 10.67818928], [75.9595871, 10.67875004], [75.95929718, 10.67875004], [75.95929718, 10.6793108], [75.95903015, 10.67930603], [75.95903015, 10.67986012], [75.95874786, 10.67986012], [75.95874786, 10.68042088], [75.95847321, 10.68041611], [75.95847321, 10.6809721], [75.95819092, 10.68097019], [75.95819092, 10.68153095], [75.95791626, 10.68152809], [75.95791626, 10.6823597], [75.9576416, 10.6823597], [75.9576416, 10.68292141], [75.95735931, 10.68291569], [75.95735931, 10.68347263], [75.95708466, 10.68347263], [75.95707703, 10.68389034], [75.95707703, 10.68403053], [75.95680237, 10.68402863], [75.95680237, 10.68458462], [75.95652771, 10.68457985], [75.95652771, 10.68514061], [75.95625305, 10.6851387], [75.95625305, 10.68597317], [75.95597076, 10.68597031], [75.95597076, 10.68653107], [75.95569611, 10.68652916], [75.95569611, 10.68708324], [75.95540619, 10.68708038], [75.95540619, 10.68764114], [75.95513916, 10.68763924], [75.95513916, 10.68819523], [75.9548645, 10.68819523], [75.9548645, 10.68875122], [75.95458221, 10.68875122], [75.95458221, 10.68958282], [75.95430756, 10.68958092], [75.95430756, 10.69014072], [75.95402527, 10.69013882], [75.95402527, 10.69069481], [75.95375061, 10.69069099], [75.95375061, 10.69152927], [75.95347595, 10.69152737], [75.95347595, 10.69208336], [75.95318604, 10.69208145], [75.95318604, 10.69292164], [75.95291901, 10.69291687], [75.95291901, 10.69347095], [75.95263672, 10.69347095], [75.95263672, 10.69403172], [75.95236206, 10.69402695], [75.95236206, 10.69486141], [75.95207977, 10.69486141], [75.95207977, 10.69543076], [75.95181274, 10.69543076], [75.95181274, 10.69653034], [75.95153046, 10.69653034], [75.95153046, 10.69764042], [75.95124817, 10.69764042], [75.95124817, 10.69902992], [75.95097351, 10.69902802], [75.95097351, 10.69986153], [75.95069122, 10.69985867], [75.95069122, 10.70014], [75.95041656, 10.70014], [75.95041656, 10.70069408], [75.95014191, 10.70069122], [75.95014191, 10.70153046], [75.94985962, 10.7015276], [75.94985962, 10.70347214], [75.94957733, 10.70347023], [75.94957733, 10.70374966], [75.94930267, 10.70374966], [75.94930267, 10.70403004], [75.94902802, 10.70402813], [75.94902802, 10.70430565], [75.94875336, 10.70430565], [75.94875336, 10.70485973], [75.94847107, 10.70485973], [75.94847107, 10.70542145], [75.94819641, 10.70541573], [75.94819641, 10.70597172], [75.94790649, 10.70597172], [75.94790649, 10.70653057], [75.94763947, 10.70652771], [75.94763947, 10.7070837], [75.94735718, 10.70708179], [75.94735718, 10.70763969], [75.94708252, 10.70763779], [75.94708252, 10.70819378], [75.94680786, 10.70819187], [75.94680786, 10.70874977], [75.9465332, 10.70874977], [75.9465332, 10.70931053], [75.94625092, 10.70930672], [75.94625092, 10.70985985], [75.94596863, 10.70985985], [75.94596863, 10.71043015], [75.94569397, 10.71041584], [75.94569397, 10.71097279], [75.94541931, 10.71096992], [75.94541931, 10.71153069], [75.94513702, 10.71152878], [75.94513702, 10.71208191], [75.94486237, 10.71208], [75.94486237, 10.71292114], [75.94458008, 10.71291733], [75.94458008, 10.71347332], [75.94431305, 10.71347046], [75.94431305, 10.71403122], [75.94403076, 10.7140274], [75.94403076, 10.7145834], [75.94374847, 10.71457958], [75.94374847, 10.7151413], [75.94347382, 10.71513939], [75.94347382, 10.71569538], [75.94319153, 10.71569538], [75.94319153, 10.71625137], [75.94291687, 10.71625137], [75.94291687, 10.71708298], [75.94264221, 10.71708107], [75.94264221, 10.71764088], [75.94235992, 10.71763897], [75.94235992, 10.71819496], [75.9420929, 10.71819115], [75.9420929, 10.71875095], [75.94180298, 10.71875095], [75.94180298, 10.71931171], [75.94152832, 10.71930504], [75.94152832, 10.71986103], [75.94125366, 10.71986103], [75.94125366, 10.72069454], [75.94097137, 10.72069073], [75.94097137, 10.72125053], [75.94069672, 10.72125053], [75.94069672, 10.72181034], [75.9404068, 10.72181034], [75.9404068, 10.7223711], [75.94013977, 10.7223711], [75.94013977, 10.72292042], [75.93985748, 10.72291756], [75.93985748, 10.72347355], [75.93958282, 10.72347069], [75.93958282, 10.72402954], [75.93930817, 10.72402668], [75.93930817, 10.72458363], [75.93902588, 10.72457886], [75.93902588, 10.72513962], [75.93875122, 10.72513962], [75.93875122, 10.72569561], [75.93846893, 10.72569084], [75.93846893, 10.72624969], [75.93818665, 10.72624969], [75.93818665, 10.72681046], [75.93791962, 10.72680569], [75.93791962, 10.72736168], [75.93763733, 10.72736168], [75.93763733, 10.72791958], [75.93736267, 10.72791576], [75.93736267, 10.72819424], [75.93708038, 10.72819424], [75.93708038, 10.72875023], [75.9367981, 10.72875023], [75.9367981, 10.72931004], [75.93653107, 10.72930622], [75.93653107, 10.72958374], [75.93624878, 10.72958183], [75.93624878, 10.73013973], [75.93597412, 10.73013783], [75.93597412, 10.73069382], [75.93569183, 10.73069191], [75.93569183, 10.73181057], [75.93541718, 10.73181057], [75.93541718, 10.73292065], [75.93514252, 10.73291588], [75.93514252, 10.73375034], [75.93486023, 10.73375034], [75.93486023, 10.73403072], [75.93458557, 10.73402786], [75.93458557, 10.73458195], [75.93430328, 10.73458195], [75.93430328, 10.7351408], [75.93402863, 10.7351408], [75.93402863, 10.73624992], [75.93374634, 10.73624992], [75.93374634, 10.73708153], [75.93347168, 10.73707962], [75.93347168, 10.73764133], [75.93319702, 10.73763847], [75.93319702, 10.73819542], [75.9329071, 10.7381897], [75.93291473, 10.73875141], [75.93264008, 10.73875141], [75.93264008, 10.73958302], [75.93235779, 10.73958015], [75.93235779, 10.74014091], [75.93208313, 10.74013901], [75.93208313, 10.74097347], [75.93180847, 10.74097061], [75.93180847, 10.74153137], [75.93152618, 10.7415266], [75.93152618, 10.74236107], [75.93125153, 10.74236107], [75.93125153, 10.74292088], [75.93096924, 10.74292088], [75.93096924, 10.74375057], [75.93069458, 10.74374866], [75.93069458, 10.74458313], [75.93041992, 10.74458122], [75.93041992, 10.74514103], [75.93013763, 10.74513912], [75.93013763, 10.74597263], [75.92986298, 10.74597073], [75.92986298, 10.74654102], [75.92958069, 10.74652672], [75.92958069, 10.74736118], [75.92930603, 10.74736118], [75.92930603, 10.74792194], [75.92903137, 10.74792194], [75.92903137, 10.74875164], [75.92874908, 10.74875164], [75.92874908, 10.74930954], [75.9284668, 10.74930954], [75.9284668, 10.75013924], [75.92819214, 10.75013924], [75.92819214, 10.75069332], [75.92791748, 10.75069332], [75.92791748, 10.75124931], [75.92763519, 10.75124931], [75.92763519, 10.75208378], [75.92736053, 10.75208092], [75.92736053, 10.75263977], [75.92708588, 10.75263977], [75.92708588, 10.75319576], [75.92679596, 10.75319099], [75.92679596, 10.75403023], [75.92652893, 10.75402832], [75.92652893, 10.75458431], [75.92624664, 10.75458241], [75.92624664, 10.75541973], [75.92597198, 10.75541782], [75.92597198, 10.75597191], [75.92569733, 10.75597191], [75.92569733, 10.7565279], [75.92541504, 10.7565279], [75.92541504, 10.75736237], [75.92514038, 10.75736046], [75.92514038, 10.75792027], [75.92485809, 10.75792027], [75.92485809, 10.75848103], [75.92457581, 10.75848103], [75.92457581, 10.75931072], [75.92430878, 10.75930595], [75.92430878, 10.75986004], [75.92402649, 10.75986004], [75.92402649, 10.7604208], [75.92375183, 10.7604208], [75.92375183, 10.76124954], [75.92346954, 10.76124954], [75.92346954, 10.76181126], [75.92318726, 10.76181126], [75.92318726, 10.76264095], [75.92292023, 10.76263809], [75.92292023, 10.76319408], [75.92263794, 10.76319027], [75.92263794, 10.76375008], [75.92236328, 10.76375008], [75.92236328, 10.76431084], [75.92208099, 10.76430416], [75.92208099, 10.76486015], [75.92179871, 10.76486015], [75.92179871, 10.76542091], [75.92152405, 10.7654171], [75.92152405, 10.76597309], [75.92124939, 10.76597023], [75.92124939, 10.76653099], [75.9209671, 10.76653099], [75.9209671, 10.76792145], [75.92069244, 10.76791668], [75.92069244, 10.76958275], [75.92041779, 10.76958275], [75.92041779, 10.77014065], [75.9201355, 10.77013874], [75.9201355, 10.77069473], [75.91986084, 10.77068996], [75.91986084, 10.77125072], [75.91958618, 10.77124882], [75.91958618, 10.77208328], [75.91929626, 10.77208138], [75.91929626, 10.77263927], [75.91902924, 10.77263927], [75.91902924, 10.77347088], [75.91873932, 10.77346039], [75.91873932, 10.77431202], [75.91847229, 10.77430534], [75.91847229, 10.77486134], [75.91819763, 10.77486134], [75.91819763, 10.77538109], [75.91819763, 10.77569485], [75.91792297, 10.77569103], [75.91792297, 10.77625179], [75.91764069, 10.77625179], [75.91764069, 10.77680969], [75.9173584, 10.77680492], [75.9173584, 10.7770834], [75.91707611, 10.77708054], [75.91707611, 10.77764034], [75.91680908, 10.77764034], [75.91680908, 10.77819347], [75.91652679, 10.77819347], [75.91652679, 10.77874947], [75.91625214, 10.77874947], [75.91625214, 10.77931023], [75.91596985, 10.77930641], [75.91596985, 10.7798624], [75.91570282, 10.77985859], [75.91570282, 10.7804203], [75.9154129, 10.7804203], [75.9154129, 10.78125191], [75.91513824, 10.78125191], [75.91513824, 10.78180981], [75.91485596, 10.78180981], [75.91486359, 10.78236198], [75.9145813, 10.78236198], [75.9145813, 10.78292274], [75.91430664, 10.78292274], [75.91430664, 10.78374958], [75.91401672, 10.78374958], [75.91401672, 10.78431129], [75.91374969, 10.78430557], [75.91374969, 10.78486156], [75.91348267, 10.78485966], [75.91348267, 10.78542137], [75.91319275, 10.78541565], [75.91319275, 10.78551197], [75.91319275, 10.78625011], [75.91291809, 10.78625011], [75.91291809, 10.78681087], [75.9126358, 10.78680611], [75.9126358, 10.78736019], [75.91236115, 10.78736019], [75.91236115, 10.7881937], [75.91208649, 10.7881918], [75.91208649, 10.78874969], [75.91179657, 10.78874969], [75.91179657, 10.78931141], [75.91152954, 10.78930569], [75.91152954, 10.78985977], [75.91124725, 10.78985977], [75.91124725, 10.79042053], [75.9109726, 10.79041576], [75.9109726, 10.79097176], [75.91069794, 10.79097176], [75.91069794, 10.7915287], [75.91041565, 10.7915287], [75.91041565, 10.79236031], [75.91014099, 10.79236031], [75.91014099, 10.79347324], [75.9098587, 10.79347038], [75.9098587, 10.7945919], [75.90958405, 10.79458332], [75.90958405, 10.7956953], [75.90930939, 10.7956953], [75.90930176, 10.7970829], [75.9090271, 10.7970829], [75.9090271, 10.79819489], [75.90875244, 10.79819107], [75.90875244, 10.79930973], [75.90847015, 10.79930973], [75.90847015, 10.80042171], [75.90820313, 10.80042171], [75.90820313, 10.80181026], [75.90791321, 10.80181026], [75.90791321, 10.80292034], [75.90763855, 10.80292034], [75.90763855, 10.80403042], [75.90735626, 10.80403042], [75.90735626, 10.80513954], [75.9070816, 10.80513954], [75.9070816, 10.80624962], [75.90680695, 10.80624962], [75.90680695, 10.8073616], [75.90652466, 10.8073616], [75.90652466, 10.80847168], [75.90625, 10.80847168], [75.90625, 10.80959129], [75.90597534, 10.80958366], [75.90597534, 10.81069374], [75.90569305, 10.81069183], [75.90569305, 10.81181145], [75.9054184, 10.81181145], [75.9054184, 10.81292057], [75.90513611, 10.81292057], [75.90513611, 10.81403065], [75.90486145, 10.81403065], [75.90486145, 10.81513977], [75.90458679, 10.81513786], [75.90458679, 10.81624985], [75.90429688, 10.81624985], [75.90429688, 10.81764126], [75.90402985, 10.81764126], [75.90402985, 10.81902885], [75.90376282, 10.81902885], [75.90376282, 10.82042122], [75.9034729, 10.8204174], [75.9034729, 10.82208347], [75.90319824, 10.82208347], [75.90319824, 10.82347298], [75.90291595, 10.82347298], [75.90291595, 10.82486057], [75.9026413, 10.82486057], [75.9026413, 10.82625103], [75.90235901, 10.82624912], [75.90235901, 10.82763863], [75.90207672, 10.82763004], [75.90207672, 10.82931042], [75.90180206, 10.82931042], [75.90180206, 10.83069992], [75.9015274, 10.83069324], [75.9015274, 10.8320837], [75.90125275, 10.8320837], [75.90125275, 10.83347225], [75.90097046, 10.83347225], [75.90097046, 10.83458424], [75.9006958, 10.83458424], [75.9006958, 10.83569431], [75.90041351, 10.83569431], [75.90041351, 10.83708382], [75.90013885, 10.83708382], [75.90013885, 10.83819389], [75.89985657, 10.83819199], [75.89985657, 10.83931065], [75.89958191, 10.83931065], [75.89958191, 10.84042072], [75.89930725, 10.84042072], [75.89930725, 10.84181118], [75.89901733, 10.84181118], [75.89901733, 10.84292126], [75.89875031, 10.84292126], [75.89875031, 10.84403133], [75.89848328, 10.84403133], [75.89848328, 10.84542084], [75.89819336, 10.84542084], [75.89819336, 10.84653091], [75.8979187, 10.84653091], [75.8979187, 10.84764099], [75.89762878, 10.84764099], [75.89762878, 10.84903145], [75.89736176, 10.84903145], [75.89736176, 10.85042095], [75.8970871, 10.85041714], [75.8970871, 10.85180473], [75.89680481, 10.85180473], [75.89680481, 10.85319519], [75.89653015, 10.85319519], [75.89653015, 10.85458279], [75.89624786, 10.85458279], [75.89624786, 10.85597134], [75.89597321, 10.85597134], [75.89597321, 10.85736084], [75.89569092, 10.85736084], [75.89569092, 10.85874939], [75.89541626, 10.85874939], [75.89541626, 10.86013985], [75.8951416, 10.86013985], [75.8951416, 10.8615303], [75.89485931, 10.8615303], [75.89485931, 10.8629179], [75.8945694, 10.8629179], [75.8945694, 10.86403179], [75.89430237, 10.86403179], [75.89430237, 10.86513996], [75.89402771, 10.86513996], [75.89402771, 10.86597157], [75.89375305, 10.86597157], [75.89375305, 10.86708355], [75.89347076, 10.86708355], [75.89347076, 10.8684721], [75.89319611, 10.86847019], [75.89319611, 10.87014103], [75.89290619, 10.87014103], [75.89290619, 10.87181091], [75.89263916, 10.87180424], [75.89263916, 10.87319469], [75.89235687, 10.87318993], [75.89235687, 10.87403107], [75.89208221, 10.87402916], [75.89208221, 10.87458324], [75.89180756, 10.87458324], [75.89180756, 10.87569523], [75.8915329, 10.87568092], [75.8915329, 10.87653065], [75.89125061, 10.87653065], [75.89125061, 10.87764072], [75.89097595, 10.87763882], [75.89097595, 10.88097095], [75.89041901, 10.88097095], [75.89041901, 10.88181019], [75.89013672, 10.88180542], [75.89013672, 10.8834734], [75.88986206, 10.88347054], [75.88986206, 10.88487053], [75.88957977, 10.88487053], [75.88957977, 10.88652992], [75.88930511, 10.88652802], [75.88930511, 10.88819408], [75.88903046, 10.88819408], [75.88903046, 10.88958359], [75.8887558, 10.88958168], [75.8887558, 10.89124966], [75.88846588, 10.89124966], [75.88846588, 10.89264011], [75.88819122, 10.89264011], [75.88819122, 10.89375019], [75.88791656, 10.89375019], [75.88791656, 10.89513969], [75.88764191, 10.89513969], [75.88764191, 10.89624977], [75.88735962, 10.89624977], [75.88735962, 10.89764118], [75.88707733, 10.89764118], [75.88708496, 10.89875126], [75.88680267, 10.89875126], [75.88680267, 10.90013885], [75.88652802, 10.90013885], [75.88652802, 10.90153122], [75.88625336, 10.90153122], [75.88625336, 10.9026413], [75.88597107, 10.9026413], [75.88597107, 10.90402889], [75.88568878, 10.90402889], [75.88568878, 10.90514088], [75.88539886, 10.90514088], [75.88539886, 10.90625095], [75.88513947, 10.90624905], [75.88513947, 10.90736103], [75.88486481, 10.90736103], [75.88486481, 10.90847111], [75.88458252, 10.90847111], [75.88458252, 10.90986061], [75.88430786, 10.90986061], [75.88430786, 10.91097355], [75.88402557, 10.91097355], [75.88402557, 10.9123621], [75.88375092, 10.9123621], [75.88375092, 10.91347122], [75.88346863, 10.91347122], [75.88346863, 10.91458416], [75.88319397, 10.91458416], [75.88319397, 10.91597176], [75.88291931, 10.91597176], [75.88291931, 10.91708374], [75.88263702, 10.91708374], [75.88263702, 10.91847229], [75.88236237, 10.91847229], [75.88236237, 10.91958427], [75.88208008, 10.91958046], [75.88208008, 10.92098141], [75.88180542, 10.92097187], [75.88180542, 10.92236233], [75.88153076, 10.92236233], [75.88153076, 10.9234724], [75.88124847, 10.9234724], [75.88124847, 10.92486], [75.88096619, 10.92486], [75.88097382, 10.92625141], [75.88069153, 10.92625141], [75.88069153, 10.92764091], [75.88041687, 10.92764091], [75.88041687, 10.92903137], [75.88014221, 10.92903137], [75.88014221, 10.93015003], [75.87985992, 10.93015003], [75.87985992, 10.93153095], [75.8795929, 10.93153095], [75.8795929, 10.93264103], [75.87930298, 10.93263912], [75.87930298, 10.93375111], [75.87902832, 10.93375111], [75.87902832, 10.93486118], [75.87875366, 10.93486118], [75.87875366, 10.93597126], [75.87847137, 10.93597126], [75.87847137, 10.93708324], [75.87819672, 10.93708324], [75.87819672, 10.93819332], [75.8779068, 10.93819141], [75.8779068, 10.93931007], [75.87763977, 10.93931007], [75.87763977, 10.94042015], [75.87735748, 10.94042015], [75.87735748, 10.94153023], [75.87708282, 10.94153023], [75.87708282, 10.9426403], [75.8768158, 10.9426403], [75.8768158, 10.9440279], [75.87652588, 10.9440279], [75.87652588, 10.94515133], [75.87625122, 10.94515133], [75.87625122, 10.94624996], [75.87596893, 10.94624996], [75.87596893, 10.94736004], [75.87569427, 10.94736004], [75.87569427, 10.94847202], [75.87541962, 10.94847202], [75.87541962, 10.9495821], [75.87513733, 10.9495821], [75.87513733, 10.95069408], [75.87486267, 10.95069027], [75.87486267, 10.95181084], [75.87458038, 10.95181084], [75.87458038, 10.95292091], [75.87431335, 10.95292091], [75.87431335, 10.95403099], [75.87403107, 10.95403099], [75.87403107, 10.95514107], [75.87374878, 10.95513916], [75.87374878, 10.95625114], [75.87347412, 10.95625114], [75.87347412, 10.95736122], [75.87319183, 10.95736122], [75.87319183, 10.95847321], [75.87291718, 10.95847321], [75.87291718, 10.95958328], [75.87264252, 10.95958138], [75.87264252, 10.96042156], [75.87236023, 10.96042156], [75.87236023, 10.96153164], [75.8720932, 10.96153164], [75.8720932, 10.96264172], [75.87180328, 10.96264172], [75.87180328, 10.96375084], [75.87152863, 10.96374893], [75.87152863, 10.96486092], [75.87124634, 10.96486092], [75.87124634, 10.96597099], [75.87097168, 10.96597099], [75.87097168, 10.96681023], [75.87068939, 10.96681023], [75.87068939, 10.9679203], [75.87039948, 10.9679203], [75.87039948, 10.96903038], [75.87014008, 10.96903038], [75.87014008, 10.97014046], [75.86985779, 10.97014046], [75.86985779, 10.97124958], [75.86958313, 10.97124958], [75.86958313, 10.97236156], [75.86930847, 10.97236156], [75.86930847, 10.97347164], [75.86902618, 10.97347164], [75.86902618, 10.97458363], [75.86875153, 10.97458363], [75.86875153, 10.9756937], [75.86846924, 10.9756918], [75.86846924, 10.97681141], [75.86818695, 10.97681141], [75.86818695, 10.97792053], [75.86791992, 10.97792053], [75.86791992, 10.97903061], [75.86765289, 10.97903061], [75.86765289, 10.98014069], [75.86736298, 10.98014069], [75.86736298, 10.9812603], [75.86708069, 10.9812603], [75.86708069, 10.98236275], [75.86680603, 10.98236084], [75.86680603, 10.98347282], [75.86653137, 10.98347282], [75.86653137, 10.9845829], [75.86624908, 10.9845829], [75.86624908, 10.98569489], [75.8659668, 10.98569012], [75.8659668, 10.98681164], [75.86569214, 10.98681164], [75.86569214, 10.98792171], [75.86541748, 10.98791695], [75.86541748, 10.98875141], [75.86513519, 10.98875141], [75.86513519, 10.98986053], [75.86486053, 10.98986053], [75.86486053, 10.99097347], [75.86458588, 10.99097347], [75.86458588, 10.9920826], [75.86429596, 10.99208069], [75.86429596, 10.9932003], [75.86402893, 10.9932003], [75.86402893, 10.99403191], [75.86374664, 10.99403191], [75.86374664, 10.99514198], [75.86347198, 10.99514198], [75.86347198, 10.99626064], [75.86319733, 10.99625015], [75.86319733, 10.99736214], [75.86291504, 10.99736214], [75.86291504, 10.99847221], [75.86235809, 10.99847031], [75.86235809, 10.99903011], [75.86208344, 10.99902821], [75.86208344, 10.99985981], [75.86180878, 10.99985981], [75.86180878, 11.00014019], [75.86180878, 11.00069427], [75.86151886, 11.00068855], [75.86152649, 11.00097179], [75.86125183, 11.00097179], [75.86125183, 11.00208378], [75.86096954, 11.00208187], [75.86096954, 11.0029211], [75.86069489, 11.00291634], [75.86069489, 11.00319386], [75.86096954, 11.00319386], [75.86096954, 11.00374985], [75.86068726, 11.00374985], [75.86069489, 11.00485992], [75.86042023, 11.00485992], [75.86042023, 11.00569439], [75.86013794, 11.00568962], [75.86013794, 11.00681114], [75.85986328, 11.00681114], [75.85986328, 11.00792122], [75.85958099, 11.00792122], [75.85958099, 11.0090313], [75.85930634, 11.00902653], [75.85930634, 11.00986099], [75.85902405, 11.00986099], [75.85902405, 11.01097298], [75.85874939, 11.01097298], [75.85874939, 11.01124859], [75.85901642, 11.01124191], [75.85901642, 11.01153088], [75.85874939, 11.01153088], [75.85874939, 11.01264095], [75.85847473, 11.01263905], [75.85847473, 11.01347256], [75.85819244, 11.01347065], [75.85819244, 11.01375103], [75.85791779, 11.01375103], [75.85791779, 11.01430511], [75.85764313, 11.01430035], [75.85764313, 11.01653194], [75.85736084, 11.01653194], [75.85736084, 11.01791954], [75.8576355, 11.01791668], [75.8576355, 11.01847076], [75.85791779, 11.01847363], [75.85791779, 11.01874924], [75.85902405, 11.01874924], [75.85901642, 11.01847076], [75.85958099, 11.01847076], [75.85958099, 11.01819324], [75.86013794, 11.01819324], [75.86013794, 11.01791668], [75.86042023, 11.01791954], [75.86042023, 11.01764202], [75.86096954, 11.01764202], [75.86096954, 11.01653194], [75.86125183, 11.01653194], [75.86125183, 11.01347065], [75.86152649, 11.01347256], [75.86152649, 11.01319504], [75.86180878, 11.01319504], [75.86180878, 11.01291656], [75.86207581, 11.01291943], [75.86207581, 11.01236057], [75.86235809, 11.01236057], [75.86235809, 11.01180458], [75.86264038, 11.01180935], [75.86264038, 11.00986099], [75.86235809, 11.00986099], [75.86235809, 11.00958347], [75.86208344, 11.00958347], [75.86208344, 11.00930691], [75.86180878, 11.00931072], [75.86180878, 11.00875092], [75.86207581, 11.00875092], [75.86207581, 11.00792122], [75.86180878, 11.00792122], [75.86180878, 11.00736046], [75.86208344, 11.00736046], [75.86208344, 11.00680447], [75.86235809, 11.00681114], [75.86235809, 11.00597], [75.86291504, 11.00597191], [75.86291504, 11.00541592], [75.86347198, 11.00543022], [75.86347198, 11.00514126], [75.86374664, 11.00514126], [75.86374664, 11.00485992], [75.86430359, 11.00485992], [75.86429596, 11.00457954], [75.86541748, 11.00458431], [75.86541748, 11.00485992], [75.86569214, 11.00485992], [75.86569214, 11.00514126], [75.8659668, 11.00514126], [75.8659668, 11.00543022], [75.86653137, 11.00541592], [75.86653137, 11.00569439], [75.86680603, 11.00569439], [75.86680603, 11.00597191], [75.86708069, 11.00597191], [75.86708069, 11.00625134], [75.86736298, 11.00625134], [75.86736298, 11.00652885], [75.86765289, 11.00652885], [75.86765289, 11.00931072], [75.86736298, 11.00930691], [75.86736298, 11.00986099], [75.86708069, 11.00986099], [75.86708069, 11.01124859], [75.86680603, 11.01125145], [75.86680603, 11.01236057], [75.86653137, 11.01236057], [75.86653137, 11.01291943], [75.86624908, 11.01291656], [75.86624908, 11.01319504], [75.86597443, 11.01319504], [75.86597443, 11.01347256], [75.86541748, 11.01347256], [75.86541748, 11.01291656], [75.86569214, 11.01291943], [75.86569214, 11.01097107], [75.86597443, 11.01097298], [75.86597443, 11.00986099], [75.86624908, 11.00986099], [75.86624908, 11.00875092], [75.86653137, 11.00875092], [75.86653137, 11.00846958], [75.86624908, 11.0084734], [75.86624908, 11.00708199], [75.86597443, 11.00708199], [75.86597443, 11.00680447], [75.86569214, 11.00681114], [75.86569214, 11.00652885], [75.86429596, 11.00652885], [75.86429596, 11.00681114], [75.86402893, 11.00680447], [75.86402893, 11.00736046], [75.86374664, 11.00736046], [75.86374664, 11.00764084], [75.86347198, 11.00764084], [75.86347198, 11.00792122], [75.86319733, 11.00792122], [75.86319733, 11.00820065], [75.86347198, 11.00819492], [75.86347198, 11.00958347], [75.86374664, 11.00957966], [75.86374664, 11.01014137], [75.86347198, 11.01014137], [75.86347198, 11.01153088], [75.86319733, 11.01153088], [75.86319733, 11.01291943], [75.86291504, 11.01291656], [75.86291504, 11.01347256], [75.86264038, 11.01347065], [75.86264038, 11.01403236], [75.86235809, 11.01402664], [75.86235809, 11.01458263], [75.86208344, 11.01458263], [75.86208344, 11.01569462], [75.86180878, 11.0156908], [75.86180878, 11.01681042], [75.86151886, 11.01681042], [75.86151886, 11.01791954], [75.86125183, 11.01791668], [75.86125183, 11.01874924], [75.86096954, 11.01874924], [75.86096954, 11.01902962], [75.86068726, 11.01902962], [75.86068726, 11.01931], [75.86042023, 11.01930523], [75.86042023, 11.01958275], [75.85930634, 11.01958275], [75.85930634, 11.01986217], [75.85901642, 11.01985931], [75.85901642, 11.02013969], [75.85874939, 11.02013969], [75.85874939, 11.02043056], [75.85845947, 11.02043056], [75.85845947, 11.02153015], [75.85791779, 11.02153015], [75.85791779, 11.02069092], [75.8576355, 11.02069569], [75.8576355, 11.02041531], [75.85708618, 11.02043056], [75.85708618, 11.02013969], [75.85652924, 11.02013969], [75.85652924, 11.02043056], [75.85624695, 11.02041531], [75.85624695, 11.02069569], [75.85597229, 11.02069569], [75.85597229, 11.0209713], [75.85624695, 11.0209713], [75.85624695, 11.02125168], [75.85597229, 11.02124977], [75.85597229, 11.02208424], [75.85569763, 11.02208424], [75.85569763, 11.02319431], [75.85542297, 11.02318001], [75.85542297, 11.02431011], [75.8548584, 11.0243063], [75.8548584, 11.02569389], [75.85457611, 11.02569199], [75.85457611, 11.02653027], [75.85430908, 11.02653027], [75.85430908, 11.02681065], [75.85402679, 11.02681065], [75.85402679, 11.02902985], [75.85375214, 11.02902794], [75.85375214, 11.0298624], [75.85346985, 11.02985954], [75.85346985, 11.03153133], [75.85320282, 11.03153133], [75.85320282, 11.03237247], [75.8529129, 11.03237247], [75.8529129, 11.03403091], [75.85263824, 11.03402901], [75.85263824, 11.03486061], [75.85235596, 11.03486061], [75.85235596, 11.03514099], [75.85263824, 11.03513908], [75.85263824, 11.03569508], [75.85235596, 11.03569031], [75.85235596, 11.03653145], [75.8520813, 11.03653145], [75.8520813, 11.03764057], [75.85180664, 11.03763866], [75.85180664, 11.03819466], [75.85151672, 11.0381813], [75.85151672, 11.03986073], [75.85124969, 11.03986073], [75.85124969, 11.04069519], [75.85098267, 11.04069138], [75.85098267, 11.04181194], [75.85069275, 11.04180527], [75.85069275, 11.04208279], [75.85098267, 11.04208088], [75.85098267, 11.04264069], [75.85069275, 11.04263878], [75.85069275, 11.04347324], [75.85041809, 11.04347324], [75.85041809, 11.04458332], [75.8501358, 11.04458141], [75.8501358, 11.04541969], [75.84986115, 11.04541683], [75.84986115, 11.0456934], [75.8501358, 11.0456934], [75.8501358, 11.04597092], [75.84986115, 11.04597092], [75.84986115, 11.04624939], [75.8501358, 11.04624939], [75.8501358, 11.04652977], [75.84986115, 11.04652691], [75.84986115, 11.04736233], [75.84958649, 11.04736233], [75.84958649, 11.0484724], [75.84929657, 11.0484724], [75.84929657, 11.0490303], [75.84902954, 11.0490284], [75.84902954, 11.04958439], [75.84874725, 11.04958439], [75.84874725, 11.0504179], [75.8484726, 11.05041122], [75.8484726, 11.05153179], [75.84874725, 11.05153179], [75.84874725, 11.05181026], [75.8484726, 11.05180645], [75.8484726, 11.05236244], [75.84819794, 11.05235958], [75.84819794, 11.05375004], [75.84792328, 11.05375004], [75.84792328, 11.05403042], [75.84819794, 11.05402756], [75.84819794, 11.05486012], [75.84791565, 11.05486012], [75.84791565, 11.0559721], [75.84764099, 11.05597019], [75.84764099, 11.05681133], [75.8473587, 11.05681133], [75.8473587, 11.05792141], [75.84708405, 11.05791569], [75.84708405, 11.05958462], [75.84680939, 11.05958462], [75.84680176, 11.06069469], [75.8465271, 11.06069469], [75.8465271, 11.06236076], [75.84625244, 11.06236076], [75.84625244, 11.06375122], [75.84597015, 11.06375122], [75.84597015, 11.06458282], [75.84570313, 11.06457996], [75.84570313, 11.0654192], [75.84541321, 11.06541729], [75.84541321, 11.06569481], [75.84513855, 11.06569004], [75.84513855, 11.06652927], [75.84485626, 11.06652927], [75.84485626, 11.06792164], [75.8445816, 11.06791687], [75.8445816, 11.06875134], [75.84430695, 11.06875134], [75.84430695, 11.06903172], [75.84402466, 11.06902695], [75.84402466, 11.06958294], [75.84375, 11.06958103], [75.84375, 11.07042027], [75.84348297, 11.07042027], [75.84348297, 11.07263947], [75.84319305, 11.07263947], [75.84319305, 11.07402992], [75.8429184, 11.07402706], [75.8429184, 11.07458401], [75.84263611, 11.07458401], [75.84263611, 11.07569408], [75.84236145, 11.07569408], [75.84236145, 11.07708359], [75.84208679, 11.07708359], [75.84208679, 11.07736206], [75.84179688, 11.07736015], [75.84179688, 11.07791996], [75.84152985, 11.07791805], [75.84152985, 11.07847214], [75.84124756, 11.07847023], [75.84124756, 11.07931137], [75.8409729, 11.07931137], [75.8409729, 11.08041954], [75.84070587, 11.08041954], [75.84070587, 11.08152962], [75.84041595, 11.08152771], [75.84041595, 11.08236217], [75.8401413, 11.08236217], [75.8401413, 11.08347225], [75.83985901, 11.08346081], [75.83985901, 11.08431053], [75.83957672, 11.08431053], [75.83957672, 11.08542061], [75.83930206, 11.08542061], [75.83930206, 11.08681107], [75.8390274, 11.08680439], [75.8390274, 11.0876379], [75.83875275, 11.0876379], [75.83875275, 11.08847332], [75.83847046, 11.08847046], [75.83847046, 11.08875084], [75.8381958, 11.08875084], [75.8381958, 11.08986092], [75.83790588, 11.08986092], [75.83790588, 11.09042072], [75.83763885, 11.09041691], [75.83763885, 11.09069538], [75.83791351, 11.09069538], [75.83791351, 11.0909729], [75.83763885, 11.0909729], [75.83763885, 11.09125137], [75.83790588, 11.09125137], [75.83790588, 11.09152889], [75.83763885, 11.09152889], [75.83763885, 11.09265041], [75.8373642, 11.09263897], [75.8373642, 11.09347343], [75.83708191, 11.09347057], [75.83708191, 11.09403133], [75.83680725, 11.09403133], [75.83680725, 11.09514141], [75.83652496, 11.09513855], [75.83652496, 11.09569454], [75.83625031, 11.09569073], [75.83625031, 11.09681034], [75.83598328, 11.09681034], [75.83598328, 11.09792042], [75.83569336, 11.09792042], [75.83569336, 11.09902954], [75.8354187, 11.09902668], [75.8354187, 11.09958267], [75.83513641, 11.09958076], [75.83513641, 11.10042], [75.83486176, 11.10042], [75.83486176, 11.1012516], [75.8345871, 11.10124874], [75.8345871, 11.10208416], [75.83428955, 11.1020813], [75.83428955, 11.10264015], [75.83403015, 11.10264015], [75.83403015, 11.10347176], [75.83374786, 11.10346889], [75.83374786, 11.10431004], [75.83347321, 11.10430622], [75.83347321, 11.10486221], [75.83319092, 11.10486221], [75.83319092, 11.10597229], [75.83291626, 11.10597229], [75.83291626, 11.10708427], [75.8326416, 11.10708427], [75.8326416, 11.10819435], [75.83235931, 11.10818863], [75.83235931, 11.10902977], [75.8326416, 11.10902786], [75.8326416, 11.10958195], [75.83235931, 11.10958195], [75.83235931, 11.10986233], [75.83207703, 11.10986042], [75.83207703, 11.11042118], [75.83180237, 11.11042118], [75.83180237, 11.11153126], [75.83152771, 11.1115284], [75.83152771, 11.11208439], [75.83125305, 11.11207962], [75.83125305, 11.11264133], [75.83097076, 11.11263847], [75.83097076, 11.11347198], [75.83069611, 11.11347198], [75.83069611, 11.11375141], [75.83040619, 11.11375141], [75.83040619, 11.1154213], [75.83013916, 11.11541653], [75.83013916, 11.115695], [75.82985687, 11.11569023], [75.82985687, 11.11653137], [75.82958221, 11.1165266], [75.82958221, 11.1170826], [75.82930756, 11.1170826], [75.82930756, 11.11736107], [75.8290329, 11.11736107], [75.8290329, 11.11792088], [75.82875061, 11.11791706], [75.82875061, 11.11819458], [75.82847595, 11.11819458], [75.82847595, 11.11847305], [75.82791901, 11.11847115], [75.82791901, 11.11930943], [75.82763672, 11.11930943], [75.82763672, 11.12042236], [75.82736206, 11.12041664], [75.82736206, 11.12069511], [75.82707977, 11.12069511], [75.82707977, 11.12125111], [75.82681274, 11.12125111], [75.82681274, 11.12153053], [75.82624817, 11.12153053], [75.82624817, 11.12181187], [75.82597351, 11.12180519], [75.82597351, 11.1226387], [75.82579041, 11.1226387], [75.82569122, 11.1226387], [75.82569122, 11.12292194], [75.82514191, 11.12291718], [75.82514191, 11.12319469], [75.82569122, 11.12319469], [75.82569122, 11.12347317], [75.82624817, 11.12347317], [75.82624817, 11.12319469], [75.82680511, 11.12319469], [75.82680511, 11.12291718], [75.82736206, 11.12292194], [75.82736206, 11.12263012], [75.82847595, 11.1226387], [75.82847595, 11.12236118], [75.82930756, 11.12236118], [75.82930756, 11.1226387], [75.82985687, 11.12263012], [75.82985687, 11.12292194], [75.83013916, 11.12291718], [75.83013916, 11.12319469], [75.83069611, 11.12319469], [75.83069611, 11.12347317], [75.83125305, 11.12347126], [75.83125305, 11.12375069], [75.83154297, 11.12375069], [75.83154297, 11.12403202], [75.83180237, 11.12402725], [75.83180237, 11.12458324], [75.83207703, 11.12458134], [75.83207703, 11.12541962], [75.83235931, 11.12541676], [75.83235931, 11.12569332], [75.8326416, 11.12569332], [75.8326416, 11.12597084], [75.83374786, 11.12597084], [75.83374786, 11.12624931], [75.83513641, 11.12624931], [75.83513641, 11.12652969], [75.83569336, 11.12652969], [75.83569336, 11.12681007], [75.83597565, 11.12680531], [75.83597565, 11.12708282], [75.83625031, 11.12708282], [75.83625031, 11.12736225], [75.83651733, 11.12735939], [75.83651733, 11.12764168], [75.83680725, 11.12764168], [75.83680725, 11.12792015], [75.83708191, 11.12791538], [75.83708191, 11.12819576], [75.83735657, 11.12819099], [75.83735657, 11.12876129], [75.83763885, 11.12876129], [75.83763885, 11.12930965], [75.83790588, 11.12930965], [75.83790588, 11.12986183], [75.8381958, 11.12986183], [75.8381958, 11.13041973], [75.83847046, 11.13041782], [75.83847046, 11.13097191], [75.83875275, 11.13097191], [75.83875275, 11.1315279], [75.8390274, 11.1315279], [75.8390274, 11.13208389], [75.83930206, 11.13208199], [75.83930206, 11.13264179], [75.83958435, 11.13263988], [75.83957672, 11.13409042], [75.83957672, 11.1354208], [75.83985901, 11.1354208], [75.83985901, 11.13624954], [75.8401413, 11.13624954], [75.8401413, 11.13681126], [75.84041595, 11.13680553], [75.84041595, 11.13736153], [75.84069824, 11.13736153], [75.84069824, 11.13763809], [75.8409729, 11.13763142], [75.8409729, 11.13792133], [75.84124756, 11.13791561], [75.84124756, 11.1384716], [75.84152985, 11.1384697], [75.84152985, 11.13875008], [75.84179688, 11.13875008], [75.84179688, 11.13903141], [75.84208679, 11.13903141], [75.84208679, 11.13931084], [75.84236145, 11.13930416], [75.84236145, 11.13986015], [75.84263611, 11.13986015], [75.84263611, 11.14014053], [75.8429184, 11.14014053], [75.8429184, 11.14042091], [75.84348297, 11.14042091], [75.84348297, 11.14070129], [75.84402466, 11.14069366], [75.84402466, 11.14097309], [75.84430695, 11.14097023], [75.84430695, 11.14125061], [75.84485626, 11.14125061], [75.84485626, 11.14153099], [75.84570313, 11.14153099], [75.84570313, 11.14181137], [75.84680176, 11.1418066], [75.84680939, 11.14236069], [75.84792328, 11.14236069], [75.84792328, 11.14264107], [75.8484726, 11.14264107], [75.8484726, 11.14236069], [75.84929657, 11.14236069], [75.84929657, 11.14264107], [75.84957886, 11.14264107], [75.84957886, 11.14236069], [75.84986115, 11.14236069], [75.84986115, 11.14208221], [75.8501358, 11.14208221], [75.8501358, 11.1418066], [75.85041809, 11.1418066], [75.85041809, 11.14152908], [75.85054016, 11.14152908], [75.85098267, 11.14153099], [75.85098267, 11.14181137], [75.85151672, 11.14181137], [75.85151672, 11.14153099], [75.8520813, 11.14153099], [75.8520813, 11.14125061], [75.85264587, 11.14125061], [75.85264587, 11.14097023], [75.8529129, 11.14097309], [75.8529129, 11.14069366], [75.85346985, 11.14070129], [75.85346985, 11.14042091], [75.85375214, 11.14042091], [75.85375214, 11.13986015], [75.85402679, 11.13986015], [75.85402679, 11.13930416], [75.85430908, 11.13931084], [75.85430908, 11.13903141], [75.8548584, 11.13903141], [75.8548584, 11.13875008], [75.85542297, 11.13875008], [75.85542297, 11.1384697], [75.85569763, 11.1384716], [75.85569763, 11.13819408], [75.85624695, 11.13819408], [75.85624695, 11.13763809], [75.85680389, 11.13763809], [75.85680389, 11.13736153], [75.85708618, 11.13736153], [75.85708618, 11.13680553], [75.85791779, 11.13681126], [75.85791779, 11.13569164], [75.85819244, 11.13569355], [75.85819244, 11.13374996], [75.85845947, 11.13374996], [75.85845947, 11.13264179], [75.85819244, 11.13264179], [75.85819244, 11.13236046], [75.8576355, 11.13236237], [75.8576355, 11.13180637], [75.85791779, 11.13182163], [75.85791779, 11.13125038], [75.85874939, 11.13125038], [75.85874939, 11.13069439], [75.85902405, 11.13069439], [75.85902405, 11.1301403], [75.85930634, 11.1301403], [75.85930634, 11.12986183], [75.85986328, 11.12986183], [75.85986328, 11.12958431], [75.86125183, 11.12958431], [75.86125183, 11.12986183], [75.86096954, 11.12986183], [75.86096954, 11.1301403], [75.86068726, 11.1301403], [75.86068726, 11.13041973], [75.86042023, 11.13041782], [75.86042023, 11.13069439], [75.86013794, 11.13069439], [75.86013794, 11.13097191], [75.85986328, 11.13097191], [75.85986328, 11.13125038], [75.85958099, 11.13125038], [75.85958099, 11.1315279], [75.85930634, 11.1315279], [75.85930634, 11.13182163], [75.85901642, 11.13182163], [75.85902405, 11.13624954], [75.85874939, 11.13624954], [75.85874939, 11.13763809], [75.85847473, 11.13763809], [75.85847473, 11.1384716], [75.85819244, 11.1384697], [75.85819244, 11.13875008], [75.85764313, 11.13875008], [75.85764313, 11.13903141], [75.85652924, 11.13903141], [75.85652924, 11.13931084], [75.85597229, 11.13930416], [75.85597229, 11.13958454], [75.85569763, 11.13958454], [75.85569763, 11.13986015], [75.85514069, 11.13986015], [75.85514069, 11.14014053], [75.8548584, 11.14014053], [75.8548584, 11.14042091], [75.85457611, 11.14042091], [75.85457611, 11.14070129], [75.85430908, 11.14069366], [75.85430908, 11.14097309], [75.85402679, 11.14097023], [75.85402679, 11.14125061], [75.85375214, 11.14125061], [75.85375214, 11.14153099], [75.85320282, 11.14153099], [75.85320282, 11.14181137], [75.8529129, 11.14181137], [75.8529129, 11.14264107], [75.85263824, 11.14263916], [75.85263824, 11.14319515], [75.8520813, 11.14319515], [75.8520813, 11.14347267], [75.85151672, 11.1434679], [75.85151672, 11.14375973], [75.85124969, 11.14375973], [75.85124969, 11.14403057], [75.85041809, 11.14403057], [75.85041809, 11.14319038], [75.84964752, 11.14319229], [75.8473587, 11.14319515], [75.8473587, 11.14347267], [75.84651947, 11.1434679], [75.84651947, 11.14375973], [75.84513855, 11.14375973], [75.84513855, 11.1434679], [75.84486389, 11.14347267], [75.84486389, 11.14319515], [75.8445816, 11.14319515], [75.8445816, 11.14263916], [75.84401703, 11.14264107], [75.84401703, 11.14236069], [75.84347534, 11.14236069], [75.84347534, 11.1418066], [75.84319305, 11.14181137], [75.84319305, 11.14153099], [75.8429184, 11.14153099], [75.8429184, 11.14125061], [75.84263611, 11.14125061], [75.84263611, 11.14097023], [75.84208679, 11.14097309], [75.84208679, 11.14069366], [75.84179688, 11.14070129], [75.84179688, 11.14042091], [75.84152985, 11.14042091], [75.84152985, 11.14014053], [75.84124756, 11.14014053], [75.84124756, 11.13957977], [75.8409729, 11.13958454], [75.8409729, 11.1390276], [75.84070587, 11.13903141], [75.84069061, 11.13875008], [75.84041595, 11.13875008], [75.84041595, 11.1384697], [75.8401413, 11.1384716], [75.8401413, 11.13791561], [75.83985901, 11.13792133], [75.83985901, 11.13763142], [75.83958435, 11.13763809], [75.83958435, 11.13736153], [75.83930206, 11.13736153], [75.83930206, 11.1370821], [75.8390274, 11.1370821], [75.8390274, 11.13652802], [75.83847046, 11.13652992], [75.83847046, 11.13624954], [75.8381958, 11.13624954], [75.8381958, 11.13597202], [75.83791351, 11.13597202], [75.83791351, 11.13569355], [75.83763885, 11.13569355], [75.83763885, 11.13541603], [75.83598328, 11.1354208], [75.83598328, 11.13514042], [75.83513641, 11.13514042], [75.83513641, 11.13486004], [75.83428955, 11.13486004], [75.83428955, 11.13457012], [75.83403015, 11.13458443], [75.83403015, 11.13319397], [75.83374786, 11.13319397], [75.83374786, 11.13291645], [75.83347321, 11.13292027], [75.83347321, 11.13264179], [75.83319092, 11.13264179], [75.83319092, 11.13208199], [75.83291626, 11.13208389], [75.83291626, 11.13180637], [75.8326416, 11.13182163], [75.8326416, 11.1315279], [75.83235931, 11.1315279], [75.83235931, 11.13125038], [75.83207703, 11.13125038], [75.83207703, 11.13097191], [75.83125305, 11.13097191], [75.83125305, 11.13125038], [75.82958221, 11.13125038], [75.82958221, 11.13069439], [75.82847595, 11.13069439], [75.82847595, 11.1301403], [75.82818604, 11.1301403], [75.82818604, 11.12958145], [75.82791901, 11.12958431], [75.82791901, 11.12930584], [75.82736206, 11.12930965], [75.82736206, 11.12876129], [75.82707977, 11.12876129], [75.82707977, 11.12847137], [75.82680511, 11.12847137], [75.82680511, 11.12819576], [75.82653046, 11.12819576], [75.82653046, 11.12763977], [75.82624817, 11.12764168], [75.82624817, 11.12569141], [75.82597351, 11.12569332], [75.82597351, 11.12541676], [75.82485962, 11.12541676], [75.82485962, 11.12597084], [75.82430267, 11.12597084], [75.82430267, 11.12624931], [75.82402802, 11.12624931], [75.82402802, 11.12681007], [75.82375336, 11.12680531], [75.82375336, 11.12708282], [75.82347107, 11.12708092], [75.82347107, 11.12764168], [75.82319641, 11.12763977], [75.82319641, 11.12819576], [75.82290649, 11.12819099], [75.82290649, 11.12930965], [75.82263947, 11.12930584], [75.82263947, 11.12986183], [75.82234955, 11.12986183], [75.82234955, 11.1301403], [75.82208252, 11.1301403], [75.82208252, 11.13097191], [75.82180786, 11.13097191], [75.82180786, 11.13182163], [75.82152557, 11.13180637], [75.82152557, 11.13208389], [75.82125092, 11.13208389], [75.82125092, 11.1331892], [75.82096863, 11.13320065], [75.82096863, 11.13403034], [75.82069397, 11.13402843], [75.82069397, 11.13458443], [75.82041931, 11.13457012], [75.82041931, 11.1354208], [75.82013702, 11.13541603], [75.82013702, 11.13569355], [75.81986237, 11.13569164], [75.81986237, 11.13624954], [75.81958008, 11.13624954], [75.81958008, 11.1370821], [75.81930542, 11.1370821], [75.81930542, 11.13763809], [75.81903076, 11.13763142], [75.81903076, 11.13792133], [75.81930542, 11.13791561], [75.81930542, 11.13819408], [75.81903076, 11.13819027], [75.81903076, 11.13875008], [75.81874847, 11.13875008], [75.81874847, 11.13903141], [75.81846619, 11.13903141], [75.81846619, 11.13931084], [75.81819153, 11.13931084], [75.81819153, 11.14042091], [75.81791687, 11.14041615], [75.81791687, 11.14097309], [75.81764221, 11.14097023], [75.81764221, 11.14125061], [75.81735992, 11.14125061], [75.81735992, 11.14208221], [75.8170929, 11.14208031], [75.8170929, 11.14375973], [75.81680298, 11.14375973], [75.81680298, 11.14403057], [75.81653595, 11.14403057], [75.81653595, 11.14514065], [75.81625366, 11.14513874], [75.81625366, 11.14569473], [75.81597137, 11.14568996], [75.81597137, 11.14625072], [75.81569672, 11.14625072], [75.81569672, 11.1465292], [75.81541443, 11.1465292], [75.81541443, 11.14708328], [75.81513977, 11.14708328], [75.81513977, 11.1473608], [75.81485748, 11.1473608], [75.81485748, 11.14792156], [75.81430817, 11.14791679], [75.81430817, 11.14847088], [75.81402588, 11.14847088], [75.81402588, 11.14903164], [75.81375122, 11.14903164], [75.81375122, 11.14931202], [75.81319427, 11.14930534], [75.81319427, 11.14958286], [75.81263733, 11.14958286], [75.81263733, 11.14986134], [75.81181335, 11.14986134], [75.81181335, 11.15014076], [75.81153107, 11.15014076], [75.81153107, 11.15042019], [75.81069183, 11.15041733], [75.81069183, 11.15069485], [75.81014252, 11.15069485], [75.81014252, 11.15097332], [75.80986023, 11.15097141], [75.80986023, 11.15125084], [75.8095932, 11.15125084], [75.8095932, 11.15152931], [75.80902863, 11.1515274], [75.80902863, 11.1520834], [75.80874634, 11.1520834], [75.80874634, 11.15236092], [75.80819702, 11.15236092], [75.80819702, 11.15291977], [75.80791473, 11.15291691], [75.80791473, 11.15319633], [75.80764008, 11.15319633], [75.80764008, 11.15347099], [75.80708313, 11.15347099], [75.80708313, 11.15361023], [75.80708313, 11.15402985], [75.80680847, 11.15402985], [75.80680847, 11.15431023], [75.80625153, 11.15430546], [75.80625153, 11.1548624], [75.80568695, 11.1548624], [75.80568695, 11.15514183], [75.80541992, 11.15514183], [75.80541992, 11.1554203], [75.80513763, 11.1554203], [75.80513763, 11.15569973], [75.80347443, 11.15569305], [75.80347443, 11.15597153], [75.80319214, 11.15597153], [75.80319214, 11.15625191], [75.80291748, 11.15625191], [75.80291748, 11.15653038], [75.80319214, 11.15653038], [75.80319214, 11.15680981], [75.8034668, 11.15680981], [75.8034668, 11.15736198], [75.80374908, 11.15736198], [75.80374908, 11.15764046], [75.80264282, 11.15764046], [75.80264282, 11.15792179], [75.80208588, 11.15791798], [75.80208588, 11.15819359], [75.80180359, 11.15819359], [75.80180359, 11.15874958], [75.80153656, 11.158741], [75.80153656, 11.15931034], [75.80180359, 11.15930557], [75.80180359, 11.15985966], [75.80236053, 11.15985966], [75.80236053, 11.16014004], [75.80291748, 11.16014004], [75.80291748, 11.16042042], [75.80319214, 11.16041565], [75.80319214, 11.16069412], [75.80347443, 11.16069412], [75.80347443, 11.16097164], [75.80374908, 11.16096973], [75.80374908, 11.16125011], [75.80430603, 11.16125011], [75.80430603, 11.16152954], [75.80458069, 11.16152763], [75.80458069, 11.16180611], [75.80513763, 11.16180611], [75.80513763, 11.16208363], [75.80596924, 11.16208363], [75.80596924, 11.1623621], [75.80652618, 11.16236019], [75.80652618, 11.16263962], [75.80902863, 11.16263962], [75.80902863, 11.15931034], [75.80930328, 11.15931034], [75.80930328, 11.158741], [75.80958557, 11.15874958], [75.80958557, 11.15791798], [75.80986023, 11.15792179], [75.80986023, 11.15764046], [75.81014252, 11.15764046], [75.81014252, 11.15736198], [75.81069183, 11.15736198], [75.81069183, 11.15708447], [75.81096649, 11.15708065], [75.81096649, 11.15736198], [75.81153107, 11.15736198], [75.81153107, 11.15764046], [75.81236267, 11.15764046], [75.81236267, 11.15792179], [75.81319427, 11.15791798], [75.81319427, 11.15819359], [75.81346893, 11.15819359], [75.81346893, 11.15847206], [75.81375122, 11.15847206], [75.81375122, 11.15874958], [75.81430817, 11.158741], [75.81430817, 11.15902996], [75.81458282, 11.15902996], [75.81458282, 11.15931034], [75.81513977, 11.15930557], [75.81513977, 11.15958405], [75.81597137, 11.15958405], [75.81597137, 11.15985966], [75.81719208, 11.15985966], [75.81735992, 11.15985966], [75.81735992, 11.15958405], [75.81764221, 11.15958405], [75.81764221, 11.15902805], [75.81819153, 11.15902996], [75.81819153, 11.158741], [75.81847382, 11.15874958], [75.81847382, 11.15847206], [75.81874847, 11.15847206], [75.81874847, 11.15791798], [75.81903076, 11.15792179], [75.81903076, 11.15764046], [75.81931305, 11.15764046], [75.81931305, 11.15736198], [75.81958008, 11.15736198], [75.81958008, 11.15708447], [75.82013702, 11.15708447], [75.82013702, 11.15680599], [75.82096863, 11.15680981], [75.82096863, 11.15653038], [75.82180786, 11.15653038], [75.82180786, 11.15625191], [75.82234955, 11.15625191], [75.82234955, 11.15597153], [75.82319641, 11.15597153], [75.82319641, 11.15625191], [75.82347107, 11.15625191], [75.82347107, 11.15653038], [75.82375336, 11.15653038], [75.82375336, 11.15680981], [75.82430267, 11.15680599], [75.82430267, 11.15708447], [75.82457733, 11.15708065], [75.82457733, 11.15736198], [75.82485962, 11.15736198], [75.82485962, 11.15764046], [75.82514191, 11.1576376], [75.82514191, 11.15819359], [75.82569122, 11.15819359], [75.82569122, 11.15874958], [75.82624817, 11.15874958], [75.82624817, 11.15847206], [75.82680511, 11.15847206], [75.82680511, 11.15819359], [75.82875061, 11.15819359], [75.82875061, 11.15847206], [75.82819366, 11.15847206], [75.82819366, 11.15874958], [75.82791901, 11.158741], [75.82791901, 11.15902996], [75.82763672, 11.15902996], [75.82763672, 11.15931034], [75.82736206, 11.15930557], [75.82736206, 11.15986156], [75.82707977, 11.15985966], [75.82707977, 11.16042042], [75.82680511, 11.16041565], [75.82680511, 11.16069412], [75.82707977, 11.16069412], [75.82707977, 11.16097164], [75.82736206, 11.16096973], [75.82736206, 11.16152954], [75.82763672, 11.16152763], [75.82763672, 11.16180611], [75.82736206, 11.16180611], [75.82736206, 11.16208363], [75.82514191, 11.16208363], [75.82514191, 11.16152763], [75.82457733, 11.16152954], [75.82457733, 11.16125011], [75.82430267, 11.16125011], [75.82430267, 11.16068935], [75.82402802, 11.16069412], [75.82402802, 11.16014004], [75.82375336, 11.16014004], [75.82375336, 11.15902996], [75.82347107, 11.15902996], [75.82347107, 11.158741], [75.82375336, 11.15874958], [75.82375336, 11.15819359], [75.82347107, 11.15819359], [75.82347107, 11.15791798], [75.82319641, 11.15792179], [75.82319641, 11.15736198], [75.82290649, 11.15736198], [75.82290649, 11.15708065], [75.82263947, 11.15708447], [75.82263947, 11.15680599], [75.82208252, 11.15680599], [75.82208252, 11.15708447], [75.82180786, 11.15708447], [75.82180786, 11.15736198], [75.82125092, 11.15736198], [75.82125092, 11.15764046], [75.82096863, 11.15764046], [75.82096863, 11.15792179], [75.82069397, 11.15791798], [75.82069397, 11.15819359], [75.82041931, 11.15819359], [75.82041931, 11.15847206], [75.82013702, 11.15847206], [75.82013702, 11.15874958], [75.81986237, 11.158741], [75.81986237, 11.15902996], [75.81958008, 11.15902996], [75.81958008, 11.15931034], [75.81930542, 11.15930557], [75.81930542, 11.15958405], [75.81903076, 11.15957928], [75.81903076, 11.16014004], [75.81874847, 11.16014004], [75.81874847, 11.16125011], [75.81847382, 11.16125011], [75.81847382, 11.16180611], [75.81735992, 11.16180611], [75.81735992, 11.16152763], [75.8170929, 11.16152954], [75.8170929, 11.16125011], [75.8167572, 11.16125011], [75.81569672, 11.16125011], [75.81569672, 11.16096973], [75.81485748, 11.16097164], [75.81485748, 11.16069412], [75.81402588, 11.16069412], [75.81402588, 11.16041565], [75.81375122, 11.16042042], [75.81375122, 11.16014004], [75.81347656, 11.16014004], [75.81347656, 11.15985966], [75.81319427, 11.15986156], [75.81319427, 11.15958405], [75.81291962, 11.15958405], [75.81291962, 11.15930557], [75.81236267, 11.15930557], [75.81236267, 11.1623621], [75.81263733, 11.16236019], [75.81263733, 11.16263962], [75.81291962, 11.16263771], [75.81291962, 11.1631937], [75.81319427, 11.1631937], [75.81318665, 11.16486931], [75.81318665, 11.16514015], [75.81346893, 11.16513824], [75.81346893, 11.16569424], [75.81375122, 11.16569424], [75.81375122, 11.16597176], [75.81402588, 11.16597176], [75.81402588, 11.16625023], [75.81430817, 11.16625023], [75.81430817, 11.16653061], [75.81458282, 11.16653061], [75.81458282, 11.16681099], [75.81513977, 11.16681099], [75.81513977, 11.16792965], [75.81541443, 11.1679163], [75.81541443, 11.16875076], [75.81569672, 11.1687479], [75.81569672, 11.16986275], [75.81597137, 11.16986084], [75.81597137, 11.1706953], [75.81624603, 11.170681], [75.81624603, 11.17153072], [75.81653595, 11.17153072], [75.81653595, 11.1718092], [75.81680298, 11.17180538], [75.81680298, 11.17236137], [75.8170929, 11.17236137], [75.8170929, 11.17263889], [75.81764221, 11.17263889], [75.81764221, 11.17291927], [75.81819153, 11.17291737], [75.81819153, 11.17319489], [75.81847382, 11.17319489], [75.81847382, 11.17347336], [75.81903076, 11.17347336], [75.81903076, 11.17375088], [75.81958008, 11.17374039], [75.81958008, 11.17403126], [75.82013702, 11.17402744], [75.82013702, 11.17458344], [75.82041931, 11.17458057], [75.82041931, 11.17514133], [75.82068634, 11.17514133], [75.82068634, 11.17542171], [75.82096863, 11.17541695], [75.82096863, 11.17597103], [75.82125092, 11.17597103], [75.82125092, 11.17681026], [75.8215332, 11.17681026], [75.8215332, 11.17764187], [75.82208252, 11.17763901], [75.82208252, 11.17819309], [75.82236481, 11.17819309], [75.82236481, 11.17847347], [75.82290649, 11.17847061], [75.82290649, 11.17875099], [75.82347107, 11.17875099], [75.82347107, 11.17903042], [75.82875061, 11.17903042], [75.82875061, 11.17930984], [75.82902527, 11.17930508], [75.82902527, 11.18069553], [75.82514191, 11.18069553], [75.82514191, 11.18097115], [75.82347107, 11.18096924], [75.82347107, 11.18125153], [75.82234955, 11.18125153], [75.82234955, 11.18153191], [75.8215332, 11.18153191], [75.8215332, 11.18181038], [75.82096863, 11.18180561], [75.82096863, 11.18208408], [75.82013702, 11.18208408], [75.82013702, 11.18180561], [75.81931305, 11.18181038], [75.81931305, 11.18153191], [75.81874847, 11.18153191], [75.81874847, 11.18125153], [75.81846619, 11.18125153], [75.81846619, 11.18096924], [75.81764221, 11.18097115], [75.81764221, 11.18069553], [75.81708527, 11.18069553], [75.81708527, 11.18041801], [75.81624603, 11.18041992], [75.81624603, 11.18013859], [75.81569672, 11.18013859], [75.81569672, 11.17987061], [75.81513977, 11.17987061], [75.81513977, 11.17958069], [75.81458282, 11.1795826], [75.81458282, 11.17930508], [75.81402588, 11.17930984], [75.81402588, 11.17875099], [75.81375122, 11.17875099], [75.81375122, 11.17819118], [75.81346893, 11.17819309], [75.81346893, 11.17708302], [75.81319427, 11.17708302], [75.81319427, 11.17680454], [75.81291962, 11.17681026], [75.81291962, 11.17653179], [75.81263733, 11.17653179], [75.81263733, 11.17597103], [75.81236267, 11.17597103], [75.81236267, 11.17569542], [75.81208038, 11.17569542], [75.81208038, 11.17513943], [75.81153107, 11.17514133], [75.81153107, 11.17458057], [75.81124878, 11.17458344], [75.81124878, 11.1712513], [75.81096649, 11.1712513], [75.81096649, 11.17097092], [75.81069183, 11.17097282], [75.81069183, 11.1706953], [75.81014252, 11.1706953], [75.81014252, 11.17041683], [75.80986023, 11.17042065], [75.80986023, 11.16986275], [75.8095932, 11.16986275], [75.8095932, 11.16958046], [75.80930328, 11.16958332], [75.80930328, 11.16847324], [75.80902863, 11.16847324], [75.80902863, 11.16625023], [75.80874634, 11.16625023], [75.80874634, 11.16597176], [75.80819702, 11.16597176], [75.80819702, 11.16541576], [75.80764008, 11.16542053], [75.80764008, 11.16514015], [75.80697632, 11.16514015], [75.80680847, 11.16514015], [75.80680847, 11.16499043], [75.80680847, 11.16485977], [75.80664825, 11.16486454], [75.80625153, 11.16486931], [75.80625153, 11.16458035], [75.80569458, 11.16458225], [75.80569458, 11.16430569], [75.80458069, 11.16431141], [75.80458069, 11.16374969], [75.80430603, 11.16374969], [75.80430603, 11.16347027], [75.80374908, 11.16347218], [75.80374908, 11.1631937], [75.80347443, 11.1631937], [75.80347443, 11.16291618], [75.80291748, 11.16292095], [75.80291748, 11.16263962], [75.80208588, 11.16263771], [75.80208588, 11.1631937], [75.80236053, 11.1631918], [75.80236053, 11.16431141], [75.80208588, 11.16431141], [75.80208588, 11.16514015], [75.80179596, 11.16514015], [75.80179596, 11.16542053], [75.80152893, 11.16541576], [75.80152893, 11.16597176], [75.80124664, 11.16596985], [75.80124664, 11.16681099], [75.80097198, 11.16681099], [75.80097198, 11.16764069], [75.80069733, 11.16764069], [75.80069733, 11.16903114], [75.80042267, 11.16903114], [75.80042267, 11.17014122], [75.80014038, 11.17013931], [75.80014038, 11.1706953], [75.79985809, 11.170681], [75.79985809, 11.17153072], [75.79957581, 11.17153072], [75.79957581, 11.1718092], [75.79985809, 11.17180538], [75.79985809, 11.17236137], [75.79958344, 11.17236137], [75.79958344, 11.17319489], [75.79930878, 11.17319489], [75.79930878, 11.17347336], [75.79902649, 11.17347336], [75.79902649, 11.17375088], [75.79875183, 11.17374039], [75.79875183, 11.17403126], [75.79846954, 11.17402744], [75.79846954, 11.17458344], [75.79817963, 11.17458057], [75.79819489, 11.17486095], [75.79763794, 11.17486095], [75.79763794, 11.17569542], [75.79792023, 11.17569065], [75.79792023, 11.17764187], [75.79736328, 11.17763901], [75.79736328, 11.17847347], [75.79708099, 11.17847061], [75.79708099, 11.17903042], [75.79680634, 11.17903042], [75.79680634, 11.18013859], [75.79651642, 11.18013859], [75.79651642, 11.18041992], [75.79680634, 11.18041801], [75.79680634, 11.18069553], [75.79651642, 11.18069077], [75.79651642, 11.18125153], [75.79624939, 11.18125153], [75.79624939, 11.18153191], [75.7959671, 11.18153191], [75.7959671, 11.18264198], [75.79569244, 11.18264008], [75.79569244, 11.18375015], [75.79541779, 11.18375015], [75.79541779, 11.18486214], [75.79514313, 11.18486023], [75.79514313, 11.18513966], [75.79486084, 11.18513775], [75.79486084, 11.18569374], [75.79458618, 11.18568039], [75.79458618, 11.18624973], [75.79429626, 11.18624973], [75.79429626, 11.18653011], [75.79402924, 11.18653011], [75.79402924, 11.18764019], [75.79374695, 11.18764019], [75.79374695, 11.18847179], [75.79347229, 11.18847179], [75.79347229, 11.18902969], [75.79319763, 11.18902779], [75.79319763, 11.18958378], [75.79291534, 11.18958378], [75.79291534, 11.19069386], [75.79264069, 11.19069386], [75.79264069, 11.19124985], [75.79236603, 11.19124985], [75.79236603, 11.19153118], [75.79208374, 11.19152832], [75.79208374, 11.19208431], [75.79180908, 11.19207954], [75.79180908, 11.19264126], [75.79152679, 11.1926384], [75.79152679, 11.19319439], [75.79125214, 11.19318962], [75.79125214, 11.19402885], [75.79096985, 11.19402885], [75.79096985, 11.19458199], [75.79070282, 11.19458008], [75.79070282, 11.19514084], [75.7904129, 11.19514084], [75.7904129, 11.19542122], [75.79070282, 11.19542122], [75.79070282, 11.1965313], [75.7904129, 11.1965313], [75.7904129, 11.19681072], [75.79013824, 11.19680691], [75.79013824, 11.19708347], [75.78985596, 11.19707966], [75.78985596, 11.19764137], [75.7895813, 11.19763947], [75.7895813, 11.19791698], [75.78986359, 11.19791698], [75.78986359, 11.19819546], [75.7895813, 11.19819546], [75.7895813, 11.19847298], [75.78930664, 11.19847107], [75.78930664, 11.19903088], [75.78902435, 11.19902897], [75.78902435, 11.19958305], [75.78874969, 11.19958019], [75.78874969, 11.20014095], [75.78847504, 11.20013905], [75.78847504, 11.20097256], [75.78819275, 11.20097065], [75.78819275, 11.20153141], [75.78791809, 11.20152664], [75.78791809, 11.20208263], [75.7876358, 11.20208073], [75.7876358, 11.20292187], [75.78736115, 11.2029171], [75.78736115, 11.20347309], [75.78708649, 11.20347118], [75.78708649, 11.20404053], [75.7868042, 11.20402718], [75.7868042, 11.20458317], [75.78708649, 11.20458126], [75.78708649, 11.20514202], [75.78679657, 11.20514202], [75.78679657, 11.20541954], [75.78652954, 11.20541668], [75.78652954, 11.20569324], [75.78623962, 11.20569134], [75.78623962, 11.20624924], [75.78652954, 11.20624924], [75.78652954, 11.20652962], [75.78623962, 11.20652962], [75.78623962, 11.20763969], [75.7859726, 11.20763969], [75.7859726, 11.20792198], [75.78569794, 11.20792198], [75.78569794, 11.20875168], [75.78541565, 11.20874882], [75.78541565, 11.20958424], [75.78514099, 11.20958138], [75.78514099, 11.21041965], [75.7848587, 11.21041775], [75.7848587, 11.21125031], [75.78457642, 11.21125031], [75.78457642, 11.21152973], [75.78430939, 11.21152782], [75.78430176, 11.21291637], [75.7840271, 11.21291637], [75.7840271, 11.21319389], [75.78375244, 11.21319103], [75.78375244, 11.21375179], [75.78347015, 11.21374989], [75.78347015, 11.21458435], [75.78320313, 11.21457863], [75.78320313, 11.21514034], [75.78291321, 11.21514034], [75.78291321, 11.21625042], [75.78263855, 11.21625042], [75.78263855, 11.21708202], [75.78235626, 11.21708202], [75.78235626, 11.21763992], [75.7820816, 11.21763992], [75.7820816, 11.21792126], [75.78180695, 11.21791553], [75.78180695, 11.21819401], [75.78151703, 11.21819019], [75.78151703, 11.21931076], [75.78125, 11.21930599], [75.78125, 11.22097206], [75.78098297, 11.22097015], [75.78098297, 11.22181129], [75.78069305, 11.22181129], [75.78069305, 11.22264099], [75.7804184, 11.22263908], [75.7804184, 11.2234726], [75.78013611, 11.22346973], [75.78013611, 11.22431087], [75.77986145, 11.22430515], [75.77986145, 11.22486115], [75.77958679, 11.22485161], [75.77958679, 11.22542095], [75.7793045, 11.22541714], [75.7793045, 11.22597313], [75.77902985, 11.22597122], [75.77902985, 11.22653103], [75.77874756, 11.22652912], [75.77874756, 11.22708321], [75.7784729, 11.2270813], [75.7784729, 11.23014069], [75.77819824, 11.23013878], [75.77819824, 11.23069477], [75.77791595, 11.23069096], [75.77791595, 11.23125076], [75.7776413, 11.23125076], [75.7776413, 11.23152924], [75.77735901, 11.23152924], [75.77735901, 11.23208332], [75.77707672, 11.23208141], [75.77707672, 11.23236084], [75.77680206, 11.23236084], [75.77680206, 11.23291969], [75.7765274, 11.23291683], [75.7765274, 11.23402691], [75.77625275, 11.23402691], [75.77625275, 11.2345829], [75.77597046, 11.23458099], [75.77597046, 11.23542023], [75.77541351, 11.23541546], [75.77541351, 11.23597145], [75.77513885, 11.23597145], [75.77513885, 11.23680973], [75.77485657, 11.23680973], [75.77485657, 11.23791981], [75.77458191, 11.2379179], [75.77458191, 11.23847198], [75.77429962, 11.23847198], [75.77429962, 11.23931026], [75.77402496, 11.23930645], [75.77402496, 11.23986244], [75.77375031, 11.23985958], [75.77375031, 11.24042034], [75.77348328, 11.24042034], [75.77348328, 11.24153042], [75.77319336, 11.24152756], [75.77319336, 11.24208355], [75.7729187, 11.24208164], [75.7729187, 11.24374962], [75.77263641, 11.24374962], [75.77263641, 11.24514008], [75.77236176, 11.24514008], [75.77236176, 11.24653053], [75.7720871, 11.24653053], [75.7720871, 11.24792099], [75.77179718, 11.24792099], [75.77179718, 11.24875069], [75.77153015, 11.24875069], [75.77153015, 11.24931145], [75.77124023, 11.24931145], [75.77124023, 11.25014114], [75.77097321, 11.25013924], [75.77097321, 11.25097275], [75.77069092, 11.25097275], [75.77069092, 11.25181103], [75.77041626, 11.25181103], [75.77041626, 11.25264072], [75.7701416, 11.25263882], [75.7701416, 11.25347328], [75.76985931, 11.25347137], [75.76985931, 11.25431156], [75.76957703, 11.25431156], [75.76957703, 11.2551527], [75.76930237, 11.25513935], [75.76930237, 11.25625134], [75.76902771, 11.25625134], [75.76902771, 11.25819302], [75.76875305, 11.25819492], [75.76875305, 11.2584734], [75.76847076, 11.25847054], [75.76847076, 11.25875092], [75.76819611, 11.25875092], [75.76819611, 11.25902939], [75.76847076, 11.25902653], [75.76847076, 11.25986099], [75.76819611, 11.25986099], [75.76819611, 11.26069641], [75.76790619, 11.26069069], [75.76790619, 11.26153183], [75.76763916, 11.26152706], [75.76763916, 11.26319313], [75.7673645, 11.26319313], [75.7673645, 11.2634716], [75.76708221, 11.2634716], [75.76708221, 11.26375198], [75.76680756, 11.26375198], [75.76680756, 11.26403046], [75.7665329, 11.26403046], [75.7665329, 11.26431274], [75.76625061, 11.26430607], [75.76625061, 11.26486206], [75.76597595, 11.26486206], [75.76597595, 11.26597214], [75.76568604, 11.26596928], [75.76568604, 11.26653004], [75.76542664, 11.26653004], [75.76542664, 11.2670908], [75.76513672, 11.2670908], [75.76513672, 11.26764011], [75.76486206, 11.26764011], [75.76486206, 11.26931095], [75.76513672, 11.26930618], [75.76513672, 11.2695837], [75.76541901, 11.2695837], [75.76541901, 11.26986217], [75.76513672, 11.26986027], [75.76513672, 11.27042103], [75.76457977, 11.27041626], [75.76457977, 11.27069378], [75.76430511, 11.27069378], [75.76430511, 11.27097225], [75.76403046, 11.27097034], [75.76403046, 11.27124977], [75.76374817, 11.27124977], [75.76374817, 11.27235985], [75.76347351, 11.27235985], [75.76347351, 11.27347183], [75.76374817, 11.27346992], [75.76374817, 11.27403069], [75.76403046, 11.27402782], [75.76403046, 11.27486038], [75.76374817, 11.27486038], [75.76374817, 11.27597332], [75.76346588, 11.27597046], [75.76346588, 11.27681065], [75.76319122, 11.27680683], [75.76319122, 11.27736092], [75.76291656, 11.27736092], [75.76291656, 11.27792072], [75.76264191, 11.27791691], [75.76264191, 11.2784729], [75.76235962, 11.2784729], [75.76235962, 11.27875137], [75.7620697, 11.27875137], [75.7620697, 11.27932072], [75.76180267, 11.27930546], [75.76180267, 11.27986145], [75.76125336, 11.27986145], [75.76125336, 11.28014088], [75.76069641, 11.28014088], [75.76069641, 11.28042126], [75.76040649, 11.28042126], [75.76040649, 11.28125095], [75.76013947, 11.28125095], [75.76013947, 11.28236103], [75.75985718, 11.28236103], [75.75985718, 11.28292179], [75.75958252, 11.28292179], [75.75958252, 11.28375053], [75.75930023, 11.28375053], [75.75930023, 11.28431034], [75.75902557, 11.28430462], [75.75902557, 11.28486061], [75.75875092, 11.28486061], [75.75875092, 11.28569317], [75.75846863, 11.28569126], [75.75846863, 11.28652954], [75.75819397, 11.28652668], [75.75819397, 11.28708267], [75.75875092, 11.28708267], [75.75875092, 11.28736115], [75.7590332, 11.28735924], [75.7590332, 11.28792191], [75.75875092, 11.28791809], [75.75875092, 11.28819561], [75.75818634, 11.28819084], [75.75818634, 11.2887516], [75.75791931, 11.2887516], [75.75791931, 11.28931046], [75.75763702, 11.28930569], [75.75763702, 11.28958416], [75.75736237, 11.2895813], [75.75736237, 11.29014015], [75.75708008, 11.29014015], [75.75708008, 11.29097176], [75.75681305, 11.29096889], [75.75681305, 11.29152966], [75.75653076, 11.29152966], [75.75653076, 11.29181004], [75.75624847, 11.29180622], [75.75624847, 11.29236221], [75.75597382, 11.29236221], [75.75597382, 11.29319382], [75.75569153, 11.29319096], [75.75569153, 11.29432201], [75.75541687, 11.2943058], [75.75541687, 11.29458427], [75.75514221, 11.29457855], [75.75514221, 11.29541969], [75.75485992, 11.29541588], [75.75485992, 11.29625034], [75.75458527, 11.29625034], [75.75458527, 11.29708195], [75.75430298, 11.29707146], [75.75430298, 11.29792118], [75.75402832, 11.29792118], [75.75402832, 11.29903126], [75.75375366, 11.2990284], [75.75375366, 11.29958439], [75.75347137, 11.29958439], [75.75347137, 11.30013847], [75.75319672, 11.30013847], [75.75319672, 11.30097198], [75.75291443, 11.30097198], [75.75291443, 11.30235958], [75.75263977, 11.30235958], [75.75263977, 11.3029213], [75.75235748, 11.3029213], [75.75235748, 11.30403137], [75.75208282, 11.30403137], [75.75208282, 11.30430889], [75.75235748, 11.30430698], [75.75235748, 11.3045826], [75.75208282, 11.3045826], [75.75208282, 11.30569458], [75.75180817, 11.30569458], [75.75180817, 11.30597305], [75.75152588, 11.30597115], [75.75152588, 11.30626011], [75.75096893, 11.30626011], [75.75096893, 11.30680943], [75.75068665, 11.30680943], [75.75068665, 11.30792141], [75.75041962, 11.30791664], [75.75041962, 11.30847263], [75.75068665, 11.30847073], [75.75069427, 11.30875111], [75.75041962, 11.30875111], [75.75041962, 11.31014061], [75.7501297, 11.31014061], [75.7501297, 11.31042194], [75.74986267, 11.31042194], [75.74986267, 11.31153202], [75.74958038, 11.31153202], [75.74958038, 11.31180954], [75.74930573, 11.31180477], [75.74930573, 11.31208324], [75.74903107, 11.31208134], [75.74903107, 11.31263924], [75.74874878, 11.31263924], [75.74874878, 11.31347084], [75.74846649, 11.31347084], [75.74846649, 11.31514168], [75.74819183, 11.31514168], [75.74819183, 11.31543064], [75.74791718, 11.31543064], [75.74791718, 11.31736183], [75.74764252, 11.31736183], [75.74764252, 11.31847191], [75.74736023, 11.31847191], [75.74736023, 11.31902981], [75.7470932, 11.31902981], [75.7470932, 11.31931019], [75.74680328, 11.31930637], [75.74680328, 11.31986237], [75.74624634, 11.31986046], [75.74624634, 11.32042027], [75.74597168, 11.32041645], [75.74597168, 11.32069397], [75.74375153, 11.32069397], [75.74375153, 11.32041645], [75.74319458, 11.32041645], [75.74318695, 11.3206892], [75.74180603, 11.32069588], [75.74180603, 11.32097244], [75.74124908, 11.32097244], [75.74124908, 11.32124996], [75.74041748, 11.32124138], [75.74041748, 11.32153034], [75.74014282, 11.32153034], [75.74014282, 11.32181072], [75.73986053, 11.32181072], [75.73986053, 11.32291985], [75.73958588, 11.32291603], [75.73958588, 11.32319355], [75.73930359, 11.32319355], [75.73930359, 11.32347202], [75.7381897, 11.32347202], [75.73819733, 11.32374954], [75.73792267, 11.32374954], [75.73792267, 11.32402992], [75.73735809, 11.32402802], [75.73735809, 11.3245821], [75.73707581, 11.32458019], [75.73707581, 11.3273716], [75.73680878, 11.32736015], [75.73680878, 11.32847214], [75.73652649, 11.32847023], [75.73652649, 11.32903099], [75.73625183, 11.32903099], [75.73625183, 11.32931137], [75.73596954, 11.3293066], [75.73596954, 11.33097267], [75.73568726, 11.3309679], [75.73568726, 11.33153057], [75.73542023, 11.33152866], [75.73542023, 11.33236122], [75.73513031, 11.33236122], [75.73513031, 11.33264065], [75.73486328, 11.33263874], [75.73486328, 11.33319473], [75.73458099, 11.33319473], [75.73458099, 11.33347321], [75.73430634, 11.3334713], [75.73430634, 11.33375072], [75.73401642, 11.33375072], [75.73400116, 11.33403111], [75.73374939, 11.3340292], [75.73374939, 11.3348608], [75.73401642, 11.3348608], [75.73401642, 11.33514118], [75.73430634, 11.33514118], [75.73430634, 11.33681202], [75.73458099, 11.33680534], [75.73458099, 11.33708286], [75.73486328, 11.33708286], [75.73486328, 11.33736134], [75.73513031, 11.33736134], [75.73513031, 11.33791924], [75.73542023, 11.33791924], [75.73542023, 11.33875084], [75.73568726, 11.33875084], [75.73568726, 11.33902931], [75.73542023, 11.33902931], [75.73542023, 11.33930969], [75.73568726, 11.33930969], [75.73568726, 11.33986092], [75.73596954, 11.33986092], [75.73596954, 11.34069538], [75.73625183, 11.34069538], [75.73625183, 11.34097099], [75.73596954, 11.34097099], [75.73596954, 11.34152985], [75.73625183, 11.34152985], [75.73625183, 11.34181023], [75.73596954, 11.34181023], [75.73596954, 11.34237099], [75.73568726, 11.34237099], [75.73568726, 11.34264183], [75.73542023, 11.34264183], [75.73542023, 11.34375191], [75.73513031, 11.34375191], [75.73513031, 11.34403038], [75.73542023, 11.34403038], [75.73542023, 11.34430981], [75.73569489, 11.34430599], [75.73569489, 11.34569359], [75.73596954, 11.34569359], [75.73596954, 11.34597206], [75.73625183, 11.3459692], [75.73625183, 11.34624958], [75.73652649, 11.34624958], [75.73652649, 11.34652996], [75.73680878, 11.34652805], [75.73680878, 11.34708405], [75.73707581, 11.34707928], [75.73707581, 11.34764004], [75.73735809, 11.34764004], [75.73735809, 11.34847164], [75.73707581, 11.34846973], [75.73707581, 11.34902954], [75.73680878, 11.34902763], [75.73687744, 11.34951305], [75.73652649, 11.34957981], [75.73652649, 11.35013962], [75.73625183, 11.35013771], [75.73625183, 11.3506937], [75.73596954, 11.3506937], [75.73596954, 11.35097218], [75.73625183, 11.35097027], [75.73625183, 11.35124969], [75.73596954, 11.35124969], [75.73596954, 11.35235977], [75.73569489, 11.35235977], [75.73569489, 11.35319424], [75.73542023, 11.35319042], [75.73542023, 11.35375023], [75.73513031, 11.35375023], [75.73513031, 11.35403061], [75.73486328, 11.35403061], [75.73486328, 11.35431099], [75.73458099, 11.35430431], [75.73458099, 11.35458469], [75.73430634, 11.35458469], [75.73430634, 11.35486031], [75.73347473, 11.35486031], [75.73347473, 11.35458469], [75.73374939, 11.35458469], [75.73374939, 11.35319424], [75.73347473, 11.35319424], [75.73347473, 11.35291576], [75.73319244, 11.35291576], [75.73319244, 11.35319424], [75.73291779, 11.35319424], [75.73291779, 11.35347176], [75.73236084, 11.35346985], [75.73236084, 11.35403061], [75.73208618, 11.35402775], [75.73208618, 11.35569382], [75.73180389, 11.35569382], [75.73180389, 11.35625076], [75.73152924, 11.35625076], [75.73152924, 11.35708237], [75.73124695, 11.35708046], [75.73124695, 11.35764122], [75.73097229, 11.35763931], [75.73097229, 11.3581953], [75.73069763, 11.3581953], [75.73069763, 11.35847282], [75.73042297, 11.35846996], [75.73042297, 11.35903072], [75.73014069, 11.35902882], [75.73014069, 11.3595829], [75.7298584, 11.35958004], [75.7298584, 11.36013889], [75.72958374, 11.36013889], [75.72958374, 11.36097336], [75.72931671, 11.36097145], [75.72931671, 11.36181164], [75.72902679, 11.36180496], [75.72902679, 11.36208344], [75.72875214, 11.36208057], [75.72875214, 11.36264133], [75.72846985, 11.36263943], [75.72846985, 11.36319542], [75.72819519, 11.36319542], [75.72819519, 11.36458302], [75.72763824, 11.36458111], [75.72763824, 11.36542034], [75.72735596, 11.36542034], [75.72735596, 11.36625099], [75.7270813, 11.36625099], [75.7270813, 11.36654091], [75.72680664, 11.3665266], [75.72680664, 11.3670826], [75.72651672, 11.36708069], [75.72651672, 11.36792183], [75.72624969, 11.36792183], [75.72624969, 11.36875153], [75.72598267, 11.36875153], [75.72598267, 11.36931038], [75.72569275, 11.36931038], [75.72569275, 11.3698616], [75.72541809, 11.3698616], [75.72541809, 11.37042046], [75.7251358, 11.37041759], [75.7251358, 11.37097073], [75.72486115, 11.37097073], [75.72486115, 11.37152958], [75.72458649, 11.37152767], [75.72458649, 11.37208366], [75.72429657, 11.3720789], [75.72429657, 11.37292004], [75.72374725, 11.37292004], [75.72374725, 11.37403011], [75.7234726, 11.37403011], [75.7234726, 11.37430954], [75.72319031, 11.37430954], [75.72319031, 11.37514019], [75.72291565, 11.37514019], [75.72292328, 11.37625027], [75.72264099, 11.37625027], [75.72264099, 11.37681103], [75.7223587, 11.37680626], [75.7223587, 11.37736225], [75.72207642, 11.37736034], [75.72207642, 11.37763977], [75.72180939, 11.37763977], [75.72180176, 11.37874985], [75.7215271, 11.37874985], [75.7215271, 11.37985992], [75.72125244, 11.37985992], [75.72125244, 11.38042068], [75.72097015, 11.38041592], [75.72097015, 11.38069439], [75.72070313, 11.38068962], [75.72070313, 11.38181114], [75.72041321, 11.38180733], [75.72041321, 11.38236046], [75.71986389, 11.38236046], [75.71985626, 11.38319016], [75.7195816, 11.38320065], [75.7195816, 11.38375092], [75.71930695, 11.38375092], [75.71930695, 11.3840313], [75.71901703, 11.3840313], [75.71901703, 11.38431072], [75.71875, 11.38431072], [75.71875, 11.38486099], [75.71819305, 11.38486099], [75.71819305, 11.38541889], [75.7179184, 11.38541698], [75.7179184, 11.38569546], [75.71763611, 11.38568974], [75.71763611, 11.38764095], [75.71736145, 11.38763905], [75.71736145, 11.38819504], [75.71708679, 11.38819027], [75.71708679, 11.38875103], [75.71679688, 11.38875103], [75.71679688, 11.38931179], [75.71652985, 11.38930511], [75.71652985, 11.38986111], [75.71624756, 11.38986111], [75.71624756, 11.39042187], [75.7159729, 11.3904171], [75.7159729, 11.39097309], [75.71569824, 11.39097118], [75.71569824, 11.39153194], [75.71541595, 11.39153194], [75.71541595, 11.39236069], [75.7151413, 11.39236069], [75.7151413, 11.39291954], [75.71430206, 11.39291668], [75.71430206, 11.39319324], [75.7140274, 11.39319324], [75.7140274, 11.39347267], [75.71291351, 11.39347267], [75.71291351, 11.39486122], [75.71263885, 11.39486122], [75.71263885, 11.39542198], [75.7123642, 11.39541531], [75.7123642, 11.3959713], [75.71208191, 11.3959713], [75.71208191, 11.39652729], [75.71180725, 11.39652729], [75.71180725, 11.39708424], [75.71151733, 11.39708138], [75.71151733, 11.39764023], [75.71125031, 11.39764023], [75.71125031, 11.39847183], [75.71097565, 11.39847183], [75.71098328, 11.39875031], [75.71069336, 11.39875031], [75.71069336, 11.40013981], [75.7104187, 11.40013981], [75.7104187, 11.40042019], [75.71013641, 11.40041637], [75.71013641, 11.4006958], [75.7104187, 11.4006958], [75.7104187, 11.40097237], [75.71013641, 11.40096855], [75.71013641, 11.40125179], [75.7095871, 11.40125179], [75.7095871, 11.40153027], [75.70929718, 11.40153027], [75.70929718, 11.40236187], [75.70903015, 11.40236187], [75.70903015, 11.40292263], [75.70874786, 11.40291595], [75.70874786, 11.40347195], [75.70847321, 11.40347195], [75.70847321, 11.40375042], [75.70819092, 11.40375042], [75.70819092, 11.40431118], [75.70791626, 11.40430641], [75.70791626, 11.4048624], [75.7076416, 11.40485954], [75.7076416, 11.40513992], [75.70735931, 11.40513802], [75.70735931, 11.40597153], [75.70707703, 11.40596962], [75.70707703, 11.40625], [75.70680237, 11.40625], [75.70680237, 11.40681076], [75.70625305, 11.40681076], [75.70625305, 11.40736008], [75.70597076, 11.40736008], [75.70597076, 11.40764141], [75.70541382, 11.4076376], [75.70541382, 11.40819359], [75.70514679, 11.40818977], [75.70514679, 11.40874958], [75.70485687, 11.40874958], [75.70485687, 11.40903091], [75.70458221, 11.40903091], [75.70458221, 11.40931129], [75.7048645, 11.40930653], [75.7048645, 11.40958214], [75.70458221, 11.40958023], [75.70458221, 11.40985966], [75.70485687, 11.40985966], [75.70485687, 11.41014099], [75.70458221, 11.41014099], [75.70458221, 11.41042137], [75.7048645, 11.41041565], [75.7048645, 11.41069508], [75.70458221, 11.41069508], [75.70458221, 11.41152859], [75.70430756, 11.41152859], [75.70430756, 11.41208267], [75.70402527, 11.41208267], [75.70402527, 11.41319466], [75.70375061, 11.41319466], [75.70375061, 11.41347313], [75.70347595, 11.41347122], [75.70347595, 11.41431236], [75.70318604, 11.41431236], [75.70318604, 11.41514111], [75.70291901, 11.4151392], [75.70291901, 11.41569519], [75.70263672, 11.41569519], [75.70263672, 11.4159708], [75.70236206, 11.4159708], [75.70236206, 11.41681194], [75.70207977, 11.41680527], [75.70207977, 11.41736126], [75.70181274, 11.41736126], [75.70181274, 11.41792202], [75.70153046, 11.41791725], [75.70153046, 11.41819477], [75.70124817, 11.41819096], [75.70124817, 11.41930962], [75.70041656, 11.41930962], [75.70041656, 11.41986084], [75.70014191, 11.41986084], [75.70014191, 11.42041969], [75.69985962, 11.42041969], [75.69985962, 11.42124939], [75.69957733, 11.42124939], [75.69957733, 11.42153168], [75.69930267, 11.42153168], [75.69930267, 11.42181015], [75.69902802, 11.42180538], [75.69902802, 11.42236137], [75.69875336, 11.42236137], [75.69875336, 11.42292023], [75.69847107, 11.42291546], [75.69847107, 11.42319584], [75.69819641, 11.42319107], [75.69819641, 11.42430973], [75.69791412, 11.42430592], [75.69791412, 11.42458439], [75.69763947, 11.42458057], [75.69763947, 11.42514038], [75.69708252, 11.42513657], [75.69708252, 11.42569447], [75.69680786, 11.42569065], [75.69680786, 11.42625046], [75.6965332, 11.42625046], [75.6965332, 11.42653179], [75.69625092, 11.42652798], [75.69625092, 11.42708397], [75.69596863, 11.42708397], [75.69596863, 11.42736244], [75.69568634, 11.42735958], [75.69568634, 11.42763996], [75.69541931, 11.42763996], [75.69541931, 11.42792034], [75.69513702, 11.42791557], [75.69513702, 11.42847157], [75.69486237, 11.42846966], [75.69486237, 11.42903042], [75.69458008, 11.42903042], [75.69458008, 11.42959118], [75.69403076, 11.42959118], [75.69403076, 11.42986202], [75.69374847, 11.42986202], [75.69374847, 11.43013954], [75.69346619, 11.43013954], [75.69346619, 11.43041992], [75.69319153, 11.43041992], [75.69319153, 11.43153], [75.69291687, 11.43152809], [75.69291687, 11.43208408], [75.69264221, 11.43208408], [75.69264221, 11.43263817], [75.69235992, 11.43263054], [75.69235992, 11.43292141], [75.69208527, 11.43291569], [75.69208527, 11.43347168], [75.69180298, 11.43346977], [75.69180298, 11.43375015], [75.69152832, 11.43375015], [75.69152832, 11.43431091], [75.69125366, 11.43430424], [75.69125366, 11.43458366], [75.69097137, 11.43457985], [75.69097137, 11.43514061], [75.69069672, 11.43514061], [75.69069672, 11.43542099], [75.69041443, 11.43541622], [75.69041443, 11.43597221], [75.6901474, 11.43597031], [75.6901474, 11.43624973], [75.68985748, 11.43624973], [75.68985748, 11.43708229], [75.68958282, 11.43708038], [75.68958282, 11.43764114], [75.68930817, 11.43764114], [75.68930817, 11.43792057], [75.68902588, 11.43792057], [75.68902588, 11.4387598], [75.68875122, 11.4387598], [75.68875122, 11.43903065], [75.68846893, 11.43902874], [75.68846893, 11.43958473], [75.68791962, 11.43957996], [75.68791962, 11.44014072], [75.68736267, 11.44014072], [75.68736267, 11.4404192], [75.68708038, 11.44041729], [75.68708038, 11.44097328], [75.68681335, 11.44097137], [75.68681335, 11.44153118], [75.68653107, 11.44153118], [75.68653107, 11.44236088], [75.68624878, 11.44236088], [75.68624878, 11.44292164], [75.68597412, 11.44291687], [75.68597412, 11.44347095], [75.68569183, 11.44347095], [75.68569183, 11.44375134], [75.68541718, 11.44375134], [75.68541718, 11.44403076], [75.68514252, 11.44403076], [75.68514252, 11.44431019], [75.68486023, 11.44430542], [75.68486023, 11.44458294], [75.68458557, 11.44458294], [75.68458557, 11.44486141], [75.68430328, 11.44486141], [75.68430328, 11.44514084], [75.684021, 11.44514084], [75.684021, 11.44541931], [75.68374634, 11.4454174], [75.68374634, 11.4459734], [75.68347168, 11.44597054], [75.68347168, 11.44680977], [75.68319702, 11.44680977], [75.68319702, 11.44736099], [75.68291473, 11.44736099], [75.68291473, 11.44763947], [75.68264008, 11.44763947], [75.68264008, 11.44819546], [75.68235779, 11.44819546], [75.68235779, 11.44847107], [75.68208313, 11.44847107], [75.68208313, 11.4487524], [75.68180847, 11.4487524], [75.68180847, 11.4493103], [75.68152618, 11.44930458], [75.68152618, 11.44958305], [75.68125153, 11.44958305], [75.68125153, 11.44986057], [75.68013763, 11.44986057], [75.68013763, 11.45014191], [75.67903137, 11.45014191], [75.67903137, 11.44986057], [75.67847443, 11.44986057], [75.67847443, 11.44958305], [75.67819214, 11.44958305], [75.67819214, 11.44930458], [75.67736053, 11.44930458], [75.67736053, 11.44958305], [75.67680359, 11.44958305], [75.67680359, 11.44986057], [75.67624664, 11.44986057], [75.67624664, 11.45014191], [75.67542267, 11.45014191], [75.67542267, 11.45069981], [75.67514038, 11.45069313], [75.67514038, 11.45097065], [75.67485046, 11.45097065], [75.67485046, 11.45153046], [75.67457581, 11.45153046], [75.67457581, 11.45181179], [75.67430878, 11.45180607], [75.67430878, 11.45208359], [75.67402649, 11.45208073], [75.67402649, 11.45263958], [75.67346954, 11.45263958], [75.67346954, 11.45291996], [75.67319489, 11.45291805], [75.67319489, 11.45319366], [75.67292023, 11.45319366], [75.67292023, 11.45347214], [75.67263794, 11.45346928], [75.67263794, 11.4537611], [75.67236328, 11.4537611], [75.67236328, 11.45431042], [75.67180634, 11.45430565], [75.67180634, 11.45458412], [75.67124939, 11.45457935], [75.67124939, 11.45514011], [75.6709671, 11.45514011], [75.6709671, 11.45541954], [75.67041779, 11.45541573], [75.67041779, 11.4556942], [75.6701355, 11.4556942], [75.67014313, 11.45625019], [75.66986084, 11.45625019], [75.66986084, 11.45652962], [75.66958618, 11.45652771], [75.66958618, 11.4570837], [75.66930389, 11.4570837], [75.66930389, 11.45736217], [75.66903687, 11.45736027], [75.66903687, 11.45763969], [75.66874695, 11.45763969], [75.66874695, 11.45792103], [75.66847229, 11.45791626], [75.66847229, 11.45819378], [75.66819763, 11.45819378], [75.66819763, 11.45847225], [75.66792297, 11.45847034], [75.66792297, 11.45874977], [75.6673584, 11.45874977], [75.6673584, 11.45903015], [75.66680908, 11.45903015], [75.66680908, 11.45931053], [75.66652679, 11.45930576], [75.66652679, 11.45985985], [75.66597748, 11.45985985], [75.66597748, 11.46014023], [75.66569519, 11.46014023], [75.66569519, 11.46069431], [75.66513824, 11.46068954], [75.66513824, 11.46125031], [75.6645813, 11.46125031], [75.6645813, 11.46153069], [75.66179657, 11.46153069], [75.66179657, 11.46181107], [75.66124725, 11.4618063], [75.66124725, 11.46208191], [75.66041565, 11.46208477], [75.66041565, 11.46236038], [75.66014099, 11.46236038], [75.66014099, 11.4626379], [75.65957642, 11.4626379], [75.65957642, 11.46292114], [75.6590271, 11.46291637], [75.6590271, 11.46319389], [75.65875244, 11.46319389], [75.65875244, 11.46347237], [75.65820313, 11.46347046], [75.65820313, 11.46403122], [75.65763855, 11.46403122], [75.65763855, 11.46431065], [75.65736389, 11.46430683], [75.65736389, 11.46458244], [75.6570816, 11.46457958], [75.6570816, 11.46485996], [75.65651703, 11.46485996], [75.65651703, 11.4651413], [75.65569305, 11.4651413], [75.65569305, 11.46542072], [75.6554184, 11.46542072], [75.6554184, 11.4656992], [75.65513611, 11.46569538], [75.65513611, 11.4659729], [75.65402985, 11.4659729], [75.65403748, 11.46625137], [75.65207672, 11.46625137], [75.65207672, 11.46652889], [75.65125275, 11.46652889], [75.65125275, 11.46680927], [75.65013885, 11.46680546], [75.65013885, 11.46708298], [75.64930725, 11.46708298], [75.64930725, 11.46736145], [75.64819336, 11.46736145], [75.64819336, 11.46764088], [75.6470871, 11.46764088], [75.6470871, 11.46792126], [75.64569092, 11.46792126], [75.64569092, 11.46764088], [75.6451416, 11.46764088], [75.6451416, 11.46708012], [75.64485931, 11.46708298], [75.64485931, 11.46680546], [75.64402771, 11.46680927], [75.64402771, 11.46652889], [75.64347076, 11.46652889], [75.64347076, 11.46625137], [75.64263916, 11.46625137], [75.64263916, 11.46597004], [75.64208221, 11.4659729], [75.64208221, 11.46569538], [75.64125061, 11.4656992], [75.64125061, 11.46542072], [75.63903046, 11.46542072], [75.63903046, 11.4651413], [75.63819122, 11.4651413], [75.63819122, 11.46485996], [75.63707733, 11.46485996], [75.63707733, 11.46457958], [75.63735962, 11.46458244], [75.63735962, 11.46402645], [75.63764191, 11.46403122], [75.63764191, 11.46347046], [75.63791656, 11.46347237], [75.63791656, 11.46208477], [75.63764191, 11.46208191], [75.63764191, 11.4618063], [75.63735962, 11.46181107], [75.63735962, 11.46153069], [75.63707733, 11.46153069], [75.63707733, 11.46125031], [75.63625336, 11.46125031], [75.63625336, 11.46153069], [75.63430786, 11.46153069], [75.63430786, 11.46181107], [75.63375092, 11.4618063], [75.63375092, 11.46208191], [75.63346863, 11.46208477], [75.63346863, 11.46236038], [75.63318634, 11.46236038], [75.63318634, 11.4626379], [75.63263702, 11.4626379], [75.63263702, 11.46319389], [75.63236237, 11.46319199], [75.63236237, 11.46485996], [75.63208008, 11.46485996], [75.63208008, 11.4651413], [75.63236237, 11.4651413], [75.63236237, 11.46542072], [75.63208008, 11.46542072], [75.63208008, 11.4656992], [75.63180542, 11.46569538], [75.63181305, 11.46625137], [75.63153076, 11.46625137], [75.63153076, 11.46680927], [75.63124847, 11.46680546], [75.63124847, 11.46708298], [75.63096619, 11.46708012], [75.63096619, 11.46764088], [75.63069153, 11.46763897], [75.63069153, 11.46819496], [75.63041687, 11.46819496], [75.63041687, 11.46875095], [75.63014221, 11.46874046], [75.63014221, 11.46903133], [75.62985992, 11.46902657], [75.62985992, 11.46958256], [75.6295929, 11.46958065], [75.6295929, 11.47014141], [75.62930298, 11.47014141], [75.62930298, 11.47042179], [75.62902832, 11.47041702], [75.62902832, 11.47069454], [75.62875366, 11.47069454], [75.62875366, 11.47097301], [75.62847137, 11.47097111], [75.62847137, 11.47125053], [75.62819672, 11.47125053], [75.62819672, 11.47153187], [75.62763977, 11.4715271], [75.62763977, 11.47208309], [75.62735748, 11.47208309], [75.62735748, 11.47236061], [75.62680054, 11.47236061], [75.62680054, 11.47292042], [75.62652588, 11.4729166], [75.62652588, 11.47319317], [75.62596893, 11.47319317], [75.62596893, 11.4734726], [75.62541962, 11.47347069], [75.62541962, 11.47375107], [75.62486267, 11.47375107], [75.62486267, 11.47402859], [75.62458038, 11.47402859], [75.62458038, 11.47430992], [75.62431335, 11.47430992], [75.62431335, 11.47402859], [75.62374115, 11.47402859], [75.62374115, 11.47430992], [75.62208557, 11.47430515], [75.62208557, 11.47458267], [75.62014008, 11.47458076], [75.62014008, 11.47486973], [75.6204071, 11.47486973], [75.6204071, 11.47514153], [75.62014008, 11.47514153], [75.62014008, 11.47542191], [75.61985779, 11.47541714], [75.61985779, 11.47569466], [75.61958313, 11.47569466], [75.61958313, 11.47597122], [75.61930847, 11.47597122], [75.61930847, 11.4762516], [75.61846924, 11.4762516], [75.61846924, 11.47653198], [75.61792755, 11.47653198], [75.61792755, 11.47681046], [75.61763763, 11.47680473], [75.61763763, 11.47708321], [75.61736298, 11.47708321], [75.61736298, 11.47819328], [75.61763763, 11.47819138], [75.61763763, 11.47902966], [75.61792755, 11.47902966], [75.61792755, 11.47931004], [75.61819458, 11.47930622], [75.61819458, 11.47958374], [75.61846924, 11.47958374], [75.61846924, 11.47986221], [75.61875153, 11.47986221], [75.61875153, 11.48069382], [75.61902618, 11.48069382], [75.61902618, 11.48375034], [75.61875153, 11.48374081], [75.61875153, 11.4843111], [75.61846924, 11.4843111], [75.61846924, 11.48681068], [75.61818695, 11.48681068], [75.61818695, 11.48764038], [75.61791992, 11.48763847], [75.61792755, 11.48875046], [75.61763763, 11.48875046], [75.61763763, 11.48931122], [75.61736298, 11.48931122], [75.61736298, 11.48987198], [75.61708069, 11.48987198], [75.61708069, 11.4904213], [75.61680603, 11.49041557], [75.61680603, 11.49097347], [75.61653137, 11.49096966], [75.61653137, 11.49180889], [75.61624908, 11.49180698], [75.61624908, 11.49208164], [75.6159668, 11.49207973], [75.6159668, 11.49264145], [75.61569214, 11.49263859], [75.61569214, 11.49347305], [75.61541748, 11.49347019], [75.61541748, 11.49431133], [75.61569214, 11.49430466], [75.61569214, 11.49569511], [75.61541748, 11.49569511], [75.61541748, 11.49597263], [75.61513519, 11.49597263], [75.61514282, 11.49625111], [75.61486053, 11.49625111], [75.61486053, 11.49653053], [75.61458588, 11.49652672], [75.61458588, 11.49708271], [75.61402893, 11.4970808], [75.61402893, 11.49792194], [75.61374664, 11.49791718], [75.61374664, 11.49819469], [75.61347198, 11.49819088], [75.61347198, 11.50013924], [75.61319733, 11.50013924], [75.61319733, 11.50041962], [75.61292267, 11.50041962], [75.61292267, 11.5015316], [75.61264038, 11.50152683], [75.61264038, 11.50208282], [75.61235809, 11.50208092], [75.61235809, 11.50403023], [75.61207581, 11.50403023], [75.61207581, 11.50430965], [75.61180115, 11.50430965], [75.61180115, 11.50487137], [75.61152649, 11.50486183], [75.61152649, 11.50597191], [75.61125183, 11.50597191], [75.61125183, 11.50681019], [75.61096954, 11.50680637], [75.61096954, 11.50736237], [75.61068726, 11.50736046], [75.61068726, 11.50764179], [75.61042023, 11.50764179], [75.61042023, 11.50874996], [75.61013794, 11.50874996], [75.61013794, 11.50903034], [75.60986328, 11.50903034], [75.60986328, 11.50986195], [75.60958099, 11.50986195], [75.60958099, 11.51041985], [75.60930634, 11.51041603], [75.60930634, 11.51069355], [75.60958099, 11.51069355], [75.60958099, 11.51097202], [75.60930634, 11.51097202], [75.60930634, 11.51152992], [75.60902405, 11.51152802], [75.60902405, 11.51208401], [75.60874939, 11.51208401], [75.60874939, 11.51236153], [75.6084671, 11.51235962], [75.6084671, 11.51264], [75.60819244, 11.51263809], [75.60819244, 11.51319408], [75.60847473, 11.51319408], [75.60847473, 11.5134716], [75.60819244, 11.5134716], [75.60819244, 11.51486015], [75.60791779, 11.51486015], [75.60791779, 11.51513958], [75.6076355, 11.51513767], [75.6076355, 11.51569366], [75.60736084, 11.51569366], [75.60736084, 11.51597214], [75.60708618, 11.51597023], [75.60708618, 11.51735973], [75.60680389, 11.51735973], [75.60680389, 11.51847267], [75.60652924, 11.5184679], [75.60652924, 11.51903057], [75.60624695, 11.51902866], [75.60624695, 11.51958466], [75.60597229, 11.51958275], [75.60597229, 11.52014065], [75.60569763, 11.52014065], [75.60569763, 11.52042103], [75.60541534, 11.52041721], [75.60541534, 11.52069473], [75.60514069, 11.52068996], [75.60514069, 11.52181244], [75.6048584, 11.52180481], [75.6048584, 11.5223608], [75.60514069, 11.5223608], [75.60514069, 11.52264118], [75.6048584, 11.52263927], [75.6048584, 11.52347088], [75.60457611, 11.52347088], [75.60457611, 11.52403069], [75.60430908, 11.52403069], [75.60430908, 11.52431202], [75.60402679, 11.52431202], [75.60402679, 11.52541924], [75.60375214, 11.52541733], [75.60375214, 11.52569485], [75.60402679, 11.52569103], [75.60402679, 11.52598], [75.60375214, 11.52598], [75.60375214, 11.52625084], [75.60346985, 11.52625084], [75.60346985, 11.52680969], [75.60319519, 11.52680492], [75.60320282, 11.52736092], [75.6029129, 11.52736092], [75.6029129, 11.52763939], [75.60263824, 11.52763939], [75.60263824, 11.52819538], [75.6029129, 11.52819538], [75.6029129, 11.52847099], [75.60263824, 11.52847099], [75.60263824, 11.52875137], [75.60235596, 11.52875137], [75.60235596, 11.52931023], [75.6020813, 11.52931023], [75.6020813, 11.5304203], [75.60180664, 11.5304184], [75.60180664, 11.53069305], [75.60151672, 11.53069115], [75.60151672, 11.53125191], [75.60124969, 11.53125191], [75.60124969, 11.53236198], [75.60097504, 11.53236198], [75.60097504, 11.53319359], [75.60069275, 11.53319073], [75.60069275, 11.53374958], [75.60041809, 11.53374958], [75.60041809, 11.53431034], [75.6001358, 11.53431034], [75.6001358, 11.53542042], [75.59986115, 11.53542042], [75.59986115, 11.53625202], [75.59958649, 11.53625202], [75.59958649, 11.53681087], [75.5993042, 11.53680611], [75.5993042, 11.5373621], [75.59902954, 11.5373621], [75.59902954, 11.5381937], [75.59874725, 11.5381918], [75.59874725, 11.53874969], [75.5984726, 11.53874969], [75.5984726, 11.53985977], [75.59819794, 11.53985977], [75.59819794, 11.54014015], [75.59792328, 11.54014015], [75.59792328, 11.54042053], [75.59764099, 11.54042053], [75.59764099, 11.54181099], [75.5973587, 11.54181099], [75.5973587, 11.54292107], [75.59708405, 11.5429163], [75.59708405, 11.54347229], [75.59680176, 11.54347038], [75.59680176, 11.54431057], [75.5965271, 11.54431057], [75.5965271, 11.54514122], [75.59625244, 11.54514122], [75.59625244, 11.5462513], [75.59597015, 11.5462513], [75.59597015, 11.54653072], [75.59570313, 11.54653072], [75.59570313, 11.5476408], [75.59541321, 11.54763889], [75.59541321, 11.54847336], [75.59486389, 11.54847336], [75.59486389, 11.55069542], [75.5945816, 11.5506897], [75.5945816, 11.55125141], [75.59430695, 11.55125141], [75.59430695, 11.55153084], [75.59402466, 11.55152702], [75.59402466, 11.55236053], [75.59375, 11.55236053], [75.59375, 11.55268002], [75.59375, 11.55319309], [75.59319305, 11.55319118], [75.59319305, 11.55375099], [75.5929184, 11.55374908], [75.5929184, 11.55569458], [75.59263611, 11.55569077], [75.59263611, 11.55625153], [75.59236145, 11.55625153], [75.59236145, 11.55681038], [75.59208679, 11.55681038], [75.59208679, 11.55792046], [75.5918045, 11.55791759], [75.5918045, 11.55819321], [75.59124756, 11.55819321], [75.59124756, 11.55902767], [75.5909729, 11.55902767], [75.5909729, 11.55986214], [75.59069824, 11.55986214], [75.59069824, 11.56097221], [75.59041595, 11.56096935], [75.59041595, 11.56347179], [75.58985901, 11.56347179], [75.58985901, 11.5654211], [75.5901413, 11.56541634], [75.5901413, 11.56597233], [75.59041595, 11.56597042], [75.59041595, 11.56735992], [75.5901413, 11.56735992], [75.5901413, 11.56875038], [75.59069824, 11.56875038], [75.59069824, 11.56819439], [75.5909729, 11.56819439], [75.5909729, 11.56735992], [75.59124756, 11.56735992], [75.59124756, 11.56624985], [75.59152985, 11.56624985], [75.59152985, 11.56569195], [75.59124756, 11.56569386], [75.59124756, 11.56541634], [75.5909729, 11.5654211], [75.5909729, 11.56514931], [75.59069824, 11.56514931], [75.59069824, 11.56458187], [75.59124756, 11.56458378], [75.59124756, 11.56430626], [75.59179688, 11.56431103], [75.59179688, 11.56375027], [75.59236145, 11.56375027], [75.59236145, 11.56153011], [75.59263611, 11.56153011], [75.59263611, 11.56124973], [75.5929184, 11.56124973], [75.5929184, 11.56096935], [75.59319305, 11.56097221], [75.59319305, 11.56069374], [75.59347534, 11.56069374], [75.59347534, 11.56013966], [75.59375763, 11.56013966], [75.59375763, 11.55930996], [75.59401703, 11.55930996], [75.59401703, 11.5587492], [75.59430695, 11.5587492], [75.59430695, 11.55847073], [75.5945816, 11.55847359], [75.5945816, 11.55764008], [75.59485626, 11.55764198], [75.59485626, 11.55653191], [75.59513855, 11.55653191], [75.59513855, 11.55625153], [75.59541321, 11.55625153], [75.59541321, 11.55569077], [75.59513855, 11.55569458], [75.59513855, 11.55486107], [75.59541321, 11.55486107], [75.59541321, 11.55431175], [75.59570313, 11.55431175], [75.59570313, 11.55264091], [75.59597015, 11.55264091], [75.59597015, 11.55125141], [75.5956955, 11.55125141], [75.5956955, 11.55069542], [75.59597015, 11.55069542], [75.59597015, 11.55041695], [75.59680176, 11.55042171], [75.59680176, 11.55014992], [75.59764099, 11.55014992], [75.59764099, 11.54903126], [75.5973587, 11.54903126], [75.5973587, 11.54875088], [75.59764099, 11.54875088], [75.59764099, 11.54847145], [75.59791565, 11.54847336], [75.59791565, 11.54791737], [75.59819794, 11.54792118], [75.59819794, 11.54736137], [75.5984726, 11.54736137], [75.5984726, 11.54680538], [75.59874725, 11.5468092], [75.59874725, 11.54596996], [75.5984726, 11.54597282], [75.5984726, 11.54541683], [75.59874725, 11.54542065], [75.59874725, 11.54514122], [75.59902954, 11.54514122], [75.59902954, 11.54431057], [75.59986115, 11.54430676], [75.59986115, 11.54458237], [75.6001358, 11.54458237], [75.6001358, 11.5470829], [75.59986115, 11.54708004], [75.59986115, 11.5476408], [75.59958649, 11.54763889], [75.59958649, 11.54819489], [75.5984726, 11.54819489], [75.5984726, 11.54847336], [75.59819794, 11.54847336], [75.59819794, 11.54958344], [75.5984726, 11.54958057], [75.5984726, 11.55014992], [75.59874725, 11.55013943], [75.59874725, 11.55069542], [75.5984726, 11.5506897], [75.5984726, 11.55181026], [75.59819794, 11.55180454], [75.59819794, 11.55225182], [75.59819794, 11.55264091], [75.59792328, 11.55264091], [75.59792328, 11.55375099], [75.59764099, 11.55375099], [75.59764099, 11.55431175], [75.5973587, 11.55430508], [75.5973587, 11.5545826], [75.59764099, 11.55458069], [75.59764099, 11.55486107], [75.5973587, 11.55486107], [75.5973587, 11.55597115], [75.59708405, 11.55597115], [75.59708405, 11.55708313], [75.59680939, 11.55708313], [75.59680176, 11.55958366], [75.5965271, 11.55958366], [75.5965271, 11.55991173], [75.5965271, 11.56042004], [75.59625244, 11.56041622], [75.59625244, 11.56097221], [75.59597015, 11.56096935], [75.59597015, 11.56124973], [75.59625244, 11.56124973], [75.59625244, 11.56153011], [75.59597015, 11.56153011], [75.59597015, 11.56209087], [75.5956955, 11.5620842], [75.5956955, 11.56235981], [75.59513855, 11.56235981], [75.59513855, 11.56264019], [75.59485626, 11.56264019], [75.59485626, 11.56291962], [75.59430695, 11.5629158], [75.59430695, 11.56319427], [75.59375, 11.56319427], [75.59375, 11.56375027], [75.59348297, 11.56375027], [75.59348297, 11.56431103], [75.59319305, 11.56430626], [75.59319305, 11.56458378], [75.59347534, 11.56458378], [75.59347534, 11.56486225], [75.59319305, 11.56486034], [75.59319305, 11.5654211], [75.5929184, 11.5654211], [75.5929184, 11.56653023], [75.59263611, 11.56652832], [75.59263611, 11.56708431], [75.59236145, 11.56708431], [75.59236145, 11.56847191], [75.5929184, 11.56847], [75.5929184, 11.56875038], [75.59375763, 11.56875038], [75.59375763, 11.56903076], [75.59430695, 11.5690279], [75.59430695, 11.56958199], [75.5945816, 11.56958199], [75.5945816, 11.57097244], [75.59430695, 11.570961], [75.59430695, 11.5715313], [75.59401703, 11.5715313], [75.59401703, 11.57181072], [75.59347534, 11.57180691], [75.59347534, 11.57208157], [75.5929184, 11.57207966], [75.5929184, 11.57236004], [75.59236145, 11.57236004], [75.59236145, 11.57264137], [75.59179688, 11.57264137], [75.59179688, 11.57291889], [75.5909729, 11.57291698], [75.5909729, 11.57319546], [75.59069824, 11.57319546], [75.59069824, 11.57347298], [75.5901413, 11.57347012], [75.5901413, 11.57375145], [75.58985901, 11.57375145], [75.58985901, 11.57458305], [75.58957672, 11.57458019], [75.58957672, 11.57514095], [75.58985901, 11.57513905], [75.58985901, 11.57567024], [75.58985901, 11.57597256], [75.5901413, 11.57597256], [75.5901413, 11.57736111], [75.58985901, 11.57736111], [75.58985901, 11.57847309], [75.58958435, 11.57847309], [75.58958435, 11.58013916], [75.58930206, 11.58013916], [75.58930206, 11.58069515], [75.5890274, 11.58069515], [75.5890274, 11.58208275], [75.58847046, 11.58208084], [75.58847046, 11.58292198], [75.5881958, 11.58291531], [75.5881958, 11.58319473], [75.58791351, 11.58319473], [75.58791351, 11.5834713], [75.58763123, 11.5834713], [75.58763123, 11.58403015], [75.58708191, 11.58402729], [75.58708191, 11.58458328], [75.58680725, 11.58458138], [75.58680725, 11.58514023], [75.58652496, 11.58514023], [75.58652496, 11.58569336], [75.58625031, 11.58569145], [75.58625031, 11.58625031], [75.58569336, 11.58625031], [75.58569336, 11.58569145], [75.58597565, 11.58569336], [75.58597565, 11.58458328], [75.58625031, 11.58458328], [75.58625031, 11.58374882], [75.58598328, 11.58375168], [75.58598328, 11.58292198], [75.58651733, 11.58292198], [75.58651733, 11.58236122], [75.58680725, 11.58236122], [75.58680725, 11.58208275], [75.58708191, 11.58208275], [75.58708191, 11.58124924], [75.58735657, 11.58124924], [75.58735657, 11.57958126], [75.58763885, 11.57958317], [75.58763885, 11.5793047], [75.58735657, 11.57931042], [75.58735657, 11.57875061], [75.58763123, 11.57875061], [75.58763123, 11.57681179], [75.58790588, 11.57681179], [75.58790588, 11.57653141], [75.5881958, 11.57653141], [75.5881958, 11.57597065], [75.58847046, 11.57597256], [75.58847046, 11.57541656], [75.58875275, 11.57542133], [75.58875275, 11.57403088], [75.58885956, 11.57402897], [75.5890274, 11.57403088], [75.5890274, 11.57291889], [75.58930206, 11.57291889], [75.58930206, 11.57069016], [75.58958435, 11.57069397], [75.58958435, 11.57013798], [75.58985901, 11.57014275], [75.58985901, 11.56986046], [75.58958435, 11.56986332], [75.58958435, 11.56930637], [75.58930206, 11.56931114], [75.58930206, 11.56903076], [75.5890274, 11.56903076], [75.5890274, 11.56875038], [75.58847046, 11.56875038], [75.58847046, 11.56903076], [75.5881958, 11.5690279], [75.5881958, 11.56986332], [75.58790588, 11.56986046], [75.58790588, 11.57042122], [75.58763885, 11.57041645], [75.58763885, 11.57097244], [75.58750153, 11.57096577], [75.58735657, 11.570961], [75.58735657, 11.57181072], [75.58708191, 11.57181072], [75.58708191, 11.57236004], [75.58680725, 11.57236004], [75.58680725, 11.57291889], [75.58652496, 11.57291698], [75.58652496, 11.57319546], [75.58680725, 11.57319546], [75.58680725, 11.57347298], [75.58651733, 11.57347012], [75.58651733, 11.57375145], [75.58625031, 11.57375145], [75.58625031, 11.57458305], [75.58598328, 11.57458019], [75.58598328, 11.57542133], [75.58569336, 11.57542133], [75.58569336, 11.57625103], [75.5854187, 11.57625103], [75.5854187, 11.57681179], [75.58513641, 11.57681179], [75.58513641, 11.57792187], [75.58486176, 11.5779171], [75.58486176, 11.57847309], [75.5845871, 11.57847118], [75.5845871, 11.57903194], [75.58429718, 11.57903194], [75.58429718, 11.57986069], [75.58403015, 11.57986069], [75.58403015, 11.58097267], [75.58374786, 11.58097076], [75.58374786, 11.58124924], [75.58347321, 11.58124924], [75.58347321, 11.5818119], [75.58319092, 11.58180523], [75.58319092, 11.58236122], [75.58347321, 11.58236122], [75.58347321, 11.58292198], [75.58319092, 11.58292198], [75.58319092, 11.58403015], [75.58291626, 11.58403015], [75.58291626, 11.58430958], [75.5826416, 11.58430958], [75.5826416, 11.58541965], [75.58235931, 11.58541775], [75.58235931, 11.58597088], [75.58207703, 11.58597088], [75.58207703, 11.58681011], [75.58180237, 11.5868063], [75.58180237, 11.58736229], [75.58152771, 11.58735943], [75.58152771, 11.58763981], [75.58125305, 11.58763981], [75.58125305, 11.58847237], [75.58097076, 11.58846855], [75.58097076, 11.58875179], [75.58069611, 11.58875179], [75.58069611, 11.59042263], [75.58041382, 11.59041595], [75.58041382, 11.59097195], [75.58013916, 11.59097195], [75.58013916, 11.59263992], [75.5798645, 11.59263802], [75.5798645, 11.59347153], [75.57958221, 11.59346962], [75.57958221, 11.59403133], [75.57930756, 11.59403133], [75.57930756, 11.59431076], [75.57902527, 11.59430599], [75.57902527, 11.59458447], [75.57875061, 11.59458447], [75.57875061, 11.59597206], [75.57847595, 11.59597015], [75.57847595, 11.59624958], [75.57818604, 11.59624958], [75.57818604, 11.59653091], [75.57791901, 11.59653091], [75.57791901, 11.59792137], [75.57763672, 11.59791565], [75.57763672, 11.5984726], [75.57736206, 11.59846973], [75.57736206, 11.59875107], [75.57707977, 11.59875107], [75.57707977, 11.59903145], [75.57736206, 11.59902859], [75.57736206, 11.59958458], [75.57707977, 11.59958458], [75.57707977, 11.59986115], [75.57736206, 11.59986115], [75.57736206, 11.60097313], [75.57707977, 11.60097027], [75.57707977, 11.60126019], [75.57681274, 11.60126019], [75.57681274, 11.60153103], [75.57653046, 11.60153103], [75.57653046, 11.60181141], [75.57624817, 11.60180473], [75.57624817, 11.60208321], [75.57597351, 11.60208321], [75.57597351, 11.6034708], [75.57569122, 11.6034708], [75.57569122, 11.60375118], [75.57541656, 11.60375118], [75.57541656, 11.60458279], [75.57514191, 11.60458279], [75.57514191, 11.60486126], [75.57485962, 11.60486126], [75.57485962, 11.60569477], [75.57457733, 11.60569096], [75.57457733, 11.60652924], [75.57430267, 11.60652924], [75.57430267, 11.60708332], [75.57402802, 11.60708332], [75.57402802, 11.60847092], [75.57375336, 11.60847092], [75.57375336, 11.60931015], [75.57347107, 11.60930538], [75.57347107, 11.60986137], [75.57319641, 11.60986137], [75.57319641, 11.61042023], [75.57290649, 11.61042023], [75.57290649, 11.61125183], [75.57263184, 11.61125183], [75.57263184, 11.61236191], [75.57235718, 11.61236191], [75.57235718, 11.61291981], [75.57208252, 11.61291981], [75.57208252, 11.61431026], [75.57180786, 11.61430645], [75.57180786, 11.61458397], [75.57152557, 11.61458397], [75.57152557, 11.61597157], [75.57125092, 11.61597157], [75.57125092, 11.61680984], [75.57068634, 11.61680984], [75.57068634, 11.61736202], [75.57041931, 11.61736202], [75.57041931, 11.61791992], [75.57013702, 11.61791801], [75.57013702, 11.6184721], [75.56986237, 11.6184721], [75.56986237, 11.61930561], [75.56958008, 11.61930561], [75.56958008, 11.6198597], [75.56930542, 11.6198616], [75.56930542, 11.62069416], [75.56903076, 11.62069035], [75.56903076, 11.62153053], [75.56874847, 11.62152767], [75.56874847, 11.62236023], [75.56847382, 11.62236023], [75.56847382, 11.62319374], [75.56819153, 11.62318993], [75.56819153, 11.62374973], [75.56791687, 11.62374973], [75.56791687, 11.62403107], [75.56764221, 11.62403107], [75.56764221, 11.62543011], [75.56735992, 11.6254158], [75.56735992, 11.62569523], [75.56764221, 11.62569046], [75.56764221, 11.62597275], [75.56735992, 11.62597275], [75.56735992, 11.62625122], [75.5670929, 11.62625122], [75.5670929, 11.62681103], [75.56680298, 11.62680435], [75.56680298, 11.6273613], [75.56652832, 11.6273613], [75.56652832, 11.62820244], [75.56624603, 11.62820244], [75.56624603, 11.6287508], [75.56597137, 11.6287508], [75.56597137, 11.62958336], [75.5654068, 11.62957954], [75.5654068, 11.63014126], [75.56513977, 11.63013935], [75.56513977, 11.63125134], [75.56485748, 11.6312418], [75.56485748, 11.63180923], [75.56458282, 11.63180542], [75.56458282, 11.63208294], [75.56430817, 11.63208103], [75.56430817, 11.63375092], [75.56402588, 11.63374901], [75.56402588, 11.63458347], [75.56375122, 11.63458061], [75.56375122, 11.63486099], [75.5634613, 11.63486099], [75.5634613, 11.63514233], [75.56319427, 11.63513947], [75.56319427, 11.63569546], [75.56291962, 11.63569069], [75.56291962, 11.63653183], [75.56263733, 11.63652706], [75.56263733, 11.63708305], [75.56236267, 11.63708305], [75.56236267, 11.63819313], [75.56208038, 11.63819122], [75.56208038, 11.63875198], [75.56181335, 11.63875198], [75.56181335, 11.63903046], [75.56153107, 11.63903046], [75.56153107, 11.64013958], [75.56124878, 11.64013958], [75.56124878, 11.64069366], [75.56097412, 11.64069366], [75.56097412, 11.64097214], [75.56069183, 11.64097214], [75.56069183, 11.64208412], [75.56041718, 11.64207935], [75.56041718, 11.64264202], [75.56014252, 11.64264202], [75.56014252, 11.64291954], [75.55986023, 11.64291573], [75.55986023, 11.6431942], [75.5595932, 11.64317989], [75.5595932, 11.64402962], [75.55930328, 11.64402771], [75.55930328, 11.6445837], [75.55902863, 11.64458179], [75.55902863, 11.64542007], [75.55874634, 11.64541626], [75.55874634, 11.64569378], [75.55847168, 11.64569187], [75.55847168, 11.64653015], [75.55819702, 11.64652824], [75.55819702, 11.64708424], [75.55791473, 11.64708424], [75.55791473, 11.64735985], [75.55764771, 11.64735985], [75.55764771, 11.64764023], [75.55735779, 11.64764023], [75.55735779, 11.64819431], [75.55708313, 11.64818954], [75.55708313, 11.64903069], [75.55680847, 11.64903069], [75.55680847, 11.64931107], [75.55708313, 11.6493063], [75.55708313, 11.64958191], [75.55680847, 11.64958], [75.55680847, 11.65014267], [75.55652618, 11.6501379], [75.55652618, 11.65069389], [75.55625153, 11.65069199], [75.55625153, 11.65153122], [75.55596924, 11.65153122], [75.55596924, 11.65237045], [75.55569458, 11.65235996], [75.55569458, 11.65319538], [75.55541992, 11.65318966], [75.55541992, 11.65375137], [75.55486298, 11.65375137], [75.55486298, 11.65458298], [75.55458832, 11.65458012], [75.55458832, 11.65514088], [75.55430603, 11.65513897], [75.55430603, 11.65541744], [75.55403137, 11.65540981], [75.55403137, 11.65653133], [75.55374908, 11.65653133], [75.55374908, 11.65681171], [75.5534668, 11.65681171], [75.5534668, 11.65736103], [75.55319214, 11.65736103], [75.55319214, 11.65875053], [75.55291748, 11.65874863], [75.55291748, 11.65986061], [75.55264282, 11.65986061], [75.55264282, 11.66014099], [75.55236053, 11.66014099], [75.55236053, 11.66041946], [75.55208588, 11.6604166], [75.55208588, 11.6609726], [75.55179596, 11.66097069], [75.55179596, 11.66125107], [75.5515213, 11.66125107], [75.5515213, 11.66154099], [75.55124664, 11.66152668], [75.55124664, 11.66208267], [75.55097198, 11.66208076], [75.55097198, 11.66264153], [75.55042267, 11.66264153], [75.55042267, 11.66292191], [75.55069733, 11.66291714], [75.55069733, 11.66347122], [75.55042267, 11.66347122], [75.55042267, 11.66403198], [75.55014038, 11.66403198], [75.55014038, 11.66431046], [75.54985809, 11.66430473], [75.54985809, 11.66458321], [75.54958344, 11.66458321], [75.54958344, 11.66569328], [75.54930878, 11.66569328], [75.54930878, 11.6659708], [75.54875183, 11.66596889], [75.54875183, 11.66624928], [75.54846191, 11.66624928], [75.54846191, 11.66681004], [75.54818726, 11.66681004], [75.54818726, 11.66792011], [75.54792023, 11.66792011], [75.54792023, 11.66903019], [75.54763794, 11.66902828], [75.54763794, 11.66958427], [75.54736328, 11.66958237], [75.54736328, 11.67014027], [75.54708099, 11.67014027], [75.54708099, 11.67097187], [75.54680634, 11.67097187], [75.54680634, 11.67153263], [75.54652405, 11.67152786], [75.54652405, 11.67319393], [75.54624939, 11.67319202], [75.54624939, 11.67374992], [75.5459671, 11.67374992], [75.5459671, 11.6740303], [75.54569244, 11.6740284], [75.54569244, 11.67458439], [75.54541779, 11.67457962], [75.54541779, 11.67514038], [75.54514313, 11.67514038], [75.54514313, 11.67542076], [75.54486084, 11.67541599], [75.54486084, 11.67597198], [75.54458618, 11.67597008], [75.54458618, 11.67681122], [75.54430389, 11.67680645], [75.54430389, 11.6773634], [75.54402924, 11.6773634], [75.54402924, 11.67819405], [75.54374695, 11.67819023], [75.54374695, 11.67875099], [75.54347229, 11.67875099], [75.54347229, 11.6793108], [75.54319763, 11.6793108], [75.54319763, 11.67986012], [75.54292297, 11.67986012], [75.54292297, 11.68014145], [75.54264069, 11.68013859], [75.54264069, 11.68069458], [75.5423584, 11.6806879], [75.5423584, 11.68181133], [75.54208374, 11.68180466], [75.54208374, 11.68208313], [75.54180908, 11.68208027], [75.54180908, 11.68264103], [75.54152679, 11.68263912], [75.54152679, 11.68319511], [75.54125214, 11.68319511], [75.54125214, 11.68347263], [75.54096985, 11.68347073], [75.54096985, 11.68403053], [75.54070282, 11.68403053], [75.54070282, 11.68431187], [75.5404129, 11.68430519], [75.5404129, 11.68486118], [75.54013824, 11.68486118], [75.54013824, 11.68569469], [75.53985596, 11.68568993], [75.53985596, 11.68625069], [75.5395813, 11.68625069], [75.5395813, 11.68653202], [75.53930664, 11.68653202], [75.53930664, 11.68680954], [75.53901672, 11.68680954], [75.53901672, 11.68763924], [75.53874969, 11.68763924], [75.53874969, 11.68848038], [75.53847504, 11.68847084], [75.53848267, 11.68875122], [75.53819275, 11.68875122], [75.53819275, 11.68931198], [75.53791809, 11.68930531], [75.53791809, 11.6898613], [75.5376358, 11.6898613], [75.5376358, 11.69014168], [75.53736115, 11.69013882], [75.53736115, 11.69069481], [75.53708649, 11.69069099], [75.53708649, 11.69124889], [75.53679657, 11.69124889], [75.53679657, 11.69180965], [75.53652954, 11.69180489], [75.53652954, 11.69208336], [75.53624725, 11.69208145], [75.53624725, 11.6926403], [75.5359726, 11.6926403], [75.5359726, 11.69319344], [75.53569794, 11.69319057], [75.53569794, 11.69375038], [75.53542328, 11.69375038], [75.53542328, 11.69402981], [75.53514099, 11.69402981], [75.53514099, 11.69514179], [75.5348587, 11.69513988], [75.5348587, 11.6956892], [75.53458405, 11.69569588], [75.53458405, 11.69597244], [75.53430939, 11.69596863], [75.53430176, 11.69653034], [75.5340271, 11.69652843], [75.5340271, 11.69708443], [75.53375244, 11.69708157], [75.53375244, 11.69736195], [75.53347778, 11.69736195], [75.53347778, 11.69791985], [75.5331955, 11.69791794], [75.5331955, 11.69819355], [75.53291321, 11.69819355], [75.53291321, 11.69847202], [75.53263855, 11.69847202], [75.53263855, 11.69902992], [75.53235626, 11.69902992], [75.53235626, 11.69931126], [75.5320816, 11.69930553], [75.5320816, 11.69986153], [75.53180695, 11.69985962], [75.53180695, 11.70014], [75.53151703, 11.70014], [75.53151703, 11.70042133], [75.53097534, 11.70041561], [75.53097534, 11.70069408], [75.5304184, 11.70069408], [75.5304184, 11.7009716], [75.53013611, 11.7009697], [75.53013611, 11.70153046], [75.52986145, 11.70153046], [75.52986145, 11.70263958], [75.5304184, 11.70263958], [75.5304184, 11.70292091], [75.53013611, 11.70294094], [75.53013611, 11.70374966], [75.52986145, 11.70374966], [75.52986145, 11.70403099], [75.53013611, 11.70403099], [75.53013611, 11.70431137], [75.52986145, 11.70430565], [75.52986145, 11.70458221], [75.52929688, 11.70458031], [75.52929688, 11.70514107], [75.52874756, 11.70513821], [75.52874756, 11.7056942], [75.5284729, 11.7056942], [75.5284729, 11.70597267], [75.52819824, 11.7059679], [75.52819824, 11.70625114], [75.52791595, 11.70625114], [75.52791595, 11.70652866], [75.52735901, 11.70652199], [75.52735901, 11.70681095], [75.52708435, 11.70680428], [75.52708435, 11.70708466], [75.5256958, 11.70708466], [75.5256958, 11.70680428], [75.52458191, 11.70680428], [75.52458191, 11.70708466], [75.52402496, 11.70708466], [75.52402496, 11.70819473], [75.52375031, 11.70818996], [75.52375031, 11.70875072], [75.52347565, 11.70875072], [75.52347565, 11.70958328], [75.52319336, 11.70958042], [75.52319336, 11.71042061], [75.5229187, 11.71041679], [75.5229187, 11.71069527], [75.52263641, 11.71068954], [75.52263641, 11.71125126], [75.52236176, 11.71125126], [75.52236176, 11.71153069], [75.5220871, 11.71152687], [75.5220871, 11.71208286], [75.52179718, 11.71208096], [75.52179718, 11.7126503], [75.52153015, 11.71263885], [75.52153015, 11.71347332], [75.52124786, 11.71347141], [75.52124786, 11.71402931], [75.52069092, 11.7140274], [75.52069092, 11.7145834], [75.52041626, 11.71458054], [75.52041626, 11.71486092], [75.51957703, 11.71486092], [75.51957703, 11.71513939], [75.51847839, 11.71513939], [75.51847839, 11.71542168], [75.51735687, 11.71542168], [75.51735687, 11.71513939], [75.51680756, 11.71513939], [75.51680756, 11.71819305], [75.51652527, 11.71819305], [75.51652527, 11.71847439], [75.51625061, 11.71846008], [75.51625061, 11.71875191], [75.51597595, 11.71874905], [75.51597595, 11.71958447], [75.51568604, 11.71958065], [75.51568604, 11.71986198], [75.51541901, 11.71986198], [75.51541901, 11.72014046], [75.51513672, 11.72014046], [75.51513672, 11.72069263], [75.51486206, 11.72069073], [75.51486206, 11.72124958], [75.51457977, 11.72124958], [75.51457977, 11.72152805], [75.51431274, 11.72152138], [75.51431274, 11.72181034], [75.51403046, 11.72180557], [75.51403046, 11.72236156], [75.51374817, 11.72235966], [75.51374817, 11.72264194], [75.51347351, 11.72264004], [75.51347351, 11.72319412], [75.51319122, 11.72319412], [75.51319122, 11.72347164], [75.51291656, 11.72347164], [75.51291656, 11.72375202], [75.51264191, 11.72375202], [75.51264191, 11.72459126], [75.51235962, 11.72458363], [75.51235962, 11.7248621], [75.51208496, 11.7248621], [75.51208496, 11.7256937], [75.51152802, 11.7256918], [75.51152802, 11.72653008], [75.51125336, 11.72653008], [75.51125336, 11.72681141], [75.51097107, 11.72681141], [75.51097107, 11.72792053], [75.51069641, 11.72791576], [75.51069641, 11.72819424], [75.51041412, 11.72819424], [75.51041412, 11.72847176], [75.51013947, 11.72846985], [75.51013947, 11.72875023], [75.50985718, 11.72875023], [75.50985718, 11.72931099], [75.50958252, 11.72930622], [75.50958252, 11.72958374], [75.50930786, 11.72957993], [75.50930786, 11.73013973], [75.50902557, 11.73013783], [75.50902557, 11.73069382], [75.50875092, 11.73069382], [75.50875092, 11.73097229], [75.50846863, 11.73097038], [75.50846863, 11.73153114], [75.50791931, 11.73152828], [75.50791931, 11.73208237], [75.50736237, 11.73208046], [75.50736237, 11.73236275], [75.50708008, 11.73236275], [75.50708008, 11.73264122], [75.50681305, 11.73264122], [75.50681305, 11.73292065], [75.50597382, 11.73291588], [75.50597382, 11.7331953], [75.50514221, 11.7331953], [75.50514221, 11.73347282], [75.50485992, 11.73346138], [75.50485992, 11.73403072], [75.5045929, 11.73403072], [75.5045929, 11.7343092], [75.50319672, 11.73430443], [75.50319672, 11.7345829], [75.50096893, 11.7345829], [75.50096893, 11.73430443], [75.50013733, 11.7343092], [75.50013733, 11.73318958], [75.49874878, 11.7331953], [75.49874878, 11.73180676], [75.49847412, 11.73180676], [75.49847412, 11.73208237], [75.49819183, 11.73208046], [75.49819183, 11.73236275], [75.49764252, 11.73236275], [75.49764252, 11.73264122], [75.4973526, 11.73264122], [75.4973526, 11.73292065], [75.49708557, 11.73291588], [75.49708557, 11.73347282], [75.4973526, 11.73346138], [75.4973526, 11.73403072], [75.49764252, 11.73403072], [75.49764252, 11.7343092], [75.49736023, 11.73430443], [75.49736023, 11.73597336], [75.4970932, 11.73597145], [75.4970932, 11.73625088], [75.49680328, 11.73625088], [75.49680328, 11.73653126], [75.49652863, 11.73653126], [75.49652863, 11.73682117], [75.49624634, 11.73682117], [75.49624634, 11.73736095], [75.49597168, 11.73736095], [75.49597168, 11.73764133], [75.49569702, 11.73763943], [75.49569702, 11.73819542], [75.49541473, 11.73819542], [75.49541473, 11.73847294], [75.49514008, 11.73847103], [75.49514008, 11.73875141], [75.49485779, 11.73875141], [75.49485779, 11.73903084], [75.49402618, 11.73902893], [75.49402618, 11.73986053], [75.49375153, 11.73986053], [75.49375153, 11.74041939], [75.49346924, 11.74041653], [75.49346924, 11.740695], [75.49318695, 11.74069118], [75.49318695, 11.74152946], [75.49291992, 11.7415266], [75.49291992, 11.7420826], [75.49263763, 11.7420826], [75.49263763, 11.74263859], [75.49208069, 11.74263], [75.49208069, 11.74292183], [75.49180603, 11.74291706], [75.49180603, 11.74319458], [75.49124908, 11.74319077], [75.49124908, 11.74375057], [75.4909668, 11.74375057], [75.4909668, 11.74431038], [75.49069214, 11.74430466], [75.49069214, 11.74458313], [75.49041748, 11.74458122], [75.49041748, 11.74486065], [75.48986053, 11.74486065], [75.48986053, 11.74514198], [75.48958588, 11.74514198], [75.48958588, 11.74542046], [75.48902893, 11.74541759], [75.48902893, 11.74569321], [75.48847198, 11.74569321], [75.48847198, 11.74597359], [75.48791504, 11.74597359], [75.48792267, 11.7462492], [75.48596954, 11.7462492], [75.48596954, 11.74652958], [75.48542023, 11.74652672], [75.48542023, 11.74708366], [75.48513794, 11.74708366], [75.48513794, 11.74736214], [75.48486328, 11.74736214], [75.48486328, 11.74819565], [75.48458099, 11.74819565], [75.48458099, 11.74847221], [75.48486328, 11.74846935], [75.48486328, 11.74903011], [75.48458099, 11.74902821], [75.48458099, 11.74986172], [75.48430634, 11.74985981], [75.48430634, 11.75125027], [75.48401642, 11.75125027], [75.48401642, 11.75152969], [75.48374939, 11.75152779], [75.48374939, 11.75208378], [75.48347473, 11.75208378], [75.48347473, 11.75236225], [75.48319244, 11.75236034], [75.48319244, 11.75292015], [75.48291779, 11.75291634], [75.48291779, 11.75347233], [75.4826355, 11.75347233], [75.4826355, 11.75374985], [75.48236847, 11.75374985], [75.48236847, 11.75403023], [75.48179626, 11.75403023], [75.48179626, 11.75431061], [75.48152924, 11.75431061], [75.48152924, 11.75485992], [75.48097229, 11.75485992], [75.48097229, 11.75542068], [75.48041534, 11.75541592], [75.48041534, 11.75569439], [75.4798584, 11.75569439], [75.4798584, 11.75597191], [75.47957611, 11.75597], [75.47957611, 11.75625038], [75.47930908, 11.75625038], [75.47930908, 11.75653076], [75.47875214, 11.75653076], [75.47875214, 11.75681114], [75.47819519, 11.75680637], [75.47819519, 11.75736237], [75.47763824, 11.75736237], [75.47763824, 11.75763798], [75.47736359, 11.75763798], [75.47735596, 11.75819016], [75.47680664, 11.75820065], [75.47680664, 11.75874996], [75.47651672, 11.75874996], [75.47651672, 11.7590313], [75.47624207, 11.7590313], [75.47624207, 11.75931072], [75.47597504, 11.75930691], [75.47597504, 11.75958157], [75.47569275, 11.75957966], [75.47569275, 11.75986004], [75.47541809, 11.75986004], [75.47541809, 11.76014137], [75.4751358, 11.76014137], [75.4751358, 11.76069927], [75.47486115, 11.76069546], [75.47486115, 11.76097298], [75.47458649, 11.76097012], [75.47458649, 11.76125145], [75.47429657, 11.76125145], [75.47429657, 11.76181126], [75.47402954, 11.76180458], [75.47402954, 11.76208305], [75.47374725, 11.76208305], [75.47374725, 11.76236057], [75.4734726, 11.76236057], [75.4734726, 11.76292133], [75.47291565, 11.76291656], [75.47291565, 11.76319504], [75.4723587, 11.76319027], [75.4723587, 11.76375961], [75.47207642, 11.76375961], [75.47207642, 11.76403141], [75.4723587, 11.76402664], [75.4723587, 11.76458263], [75.47291565, 11.76458263], [75.47291565, 11.76486111], [75.47319794, 11.76486111], [75.47319794, 11.76514053], [75.4734726, 11.76514053], [75.4734726, 11.76542187], [75.47402954, 11.7654171], [75.47402954, 11.76569462], [75.47486115, 11.76569462], [75.47486115, 11.7654171], [75.47598267, 11.76542187], [75.47598267, 11.76486111], [75.47652435, 11.76486111], [75.47652435, 11.76458263], [75.4770813, 11.76458263], [75.4770813, 11.76430511], [75.47763824, 11.76431179], [75.47763824, 11.76403141], [75.47875214, 11.76402664], [75.47875214, 11.76458263], [75.48097229, 11.76458263], [75.48097229, 11.76569462], [75.48347473, 11.76569462], [75.48347473, 11.7654171], [75.48513794, 11.76542187], [75.48513794, 11.76514053], [75.48596954, 11.76514053], [75.48596954, 11.76486111], [75.48625183, 11.76486111], [75.48625183, 11.76458263], [75.48680878, 11.76458263], [75.48680878, 11.76430511], [75.48707581, 11.76431179], [75.48707581, 11.76403141], [75.48735809, 11.76403141], [75.48735809, 11.76347065], [75.48764038, 11.76347256], [75.48764038, 11.76319504], [75.48791504, 11.76319504], [75.48791504, 11.76291656], [75.48819733, 11.76292133], [75.48819733, 11.76264095], [75.48847198, 11.76264095], [75.48847198, 11.76208019], [75.48874664, 11.76208305], [75.48874664, 11.76124763], [75.48902893, 11.76125145], [75.48902893, 11.76069927], [75.48929596, 11.76069927], [75.48929596, 11.75986004], [75.48958588, 11.75986004], [75.48958588, 11.7576313], [75.48986053, 11.75763798], [75.48986053, 11.75736237], [75.49013519, 11.75736237], [75.49013519, 11.75708199], [75.49041748, 11.75708199], [75.49041748, 11.75680637], [75.4909668, 11.75681114], [75.4909668, 11.75653076], [75.49180603, 11.75653076], [75.49180603, 11.75681114], [75.49318695, 11.75681114], [75.49318695, 11.75653076], [75.49346924, 11.75653076], [75.49346924, 11.75625038], [75.49375153, 11.75625038], [75.49375153, 11.75653076], [75.4954071, 11.75653076], [75.4954071, 11.75681114], [75.49597168, 11.75680637], [75.49597168, 11.75708199], [75.49624634, 11.75708199], [75.49624634, 11.75763798], [75.49680328, 11.7576313], [75.49680328, 11.75792122], [75.49736023, 11.75791645], [75.49736023, 11.75819397], [75.49764252, 11.75819397], [75.49764252, 11.75847244], [75.49819183, 11.75846958], [75.49819183, 11.75874996], [75.49874878, 11.75874996], [75.49874878, 11.75931072], [75.49930573, 11.75930691], [75.49930573, 11.75958157], [75.49986267, 11.75957966], [75.49986267, 11.75986004], [75.50013733, 11.75986004], [75.50013733, 11.76014137], [75.50041199, 11.76014137], [75.50041199, 11.76069927], [75.50068665, 11.76069927], [75.50068665, 11.76125145], [75.50096893, 11.76125145], [75.50096893, 11.76181126], [75.50152588, 11.76180458], [75.50152588, 11.76208305], [75.50180817, 11.76208305], [75.50180817, 11.76236057], [75.503479, 11.76236057], [75.503479, 11.76264095], [75.50430298, 11.76264095], [75.50430298, 11.76292133], [75.50458527, 11.76291656], [75.50458527, 11.76319504], [75.50541687, 11.76319504], [75.50541687, 11.76291656], [75.50569153, 11.76292133], [75.50569153, 11.76264095], [75.50596619, 11.76264095], [75.50596619, 11.76181126], [75.50624847, 11.76181126], [75.50624847, 11.76125145], [75.50763702, 11.76124763], [75.50763702, 11.76236057], [75.50791931, 11.76236057], [75.50791931, 11.76347256], [75.50818634, 11.76347065], [75.50818634, 11.76431179], [75.50791931, 11.76430511], [75.50791931, 11.76458263], [75.50708008, 11.76458263], [75.50708008, 11.76430511], [75.50653839, 11.76431179], [75.50653839, 11.76403141], [75.50596619, 11.76403141], [75.50596619, 11.76375961], [75.5045929, 11.76375961], [75.5045929, 11.76347065], [75.50375366, 11.76347256], [75.50375366, 11.76319504], [75.50347137, 11.76319504], [75.50347137, 11.76291656], [75.50152588, 11.76292133], [75.50152588, 11.76264095], [75.50125122, 11.76264095], [75.50125122, 11.76236057], [75.50069427, 11.76236057], [75.50069427, 11.76208305], [75.50041962, 11.76208305], [75.50041962, 11.76180458], [75.49986267, 11.76181126], [75.49986267, 11.76153088], [75.49958038, 11.76153088], [75.49958038, 11.76125145], [75.49931335, 11.76125145], [75.49931335, 11.76097012], [75.49903107, 11.76097298], [75.49903107, 11.76069546], [75.49874878, 11.76069927], [75.49874878, 11.76041889], [75.49764252, 11.76041889], [75.49764252, 11.76069927], [75.49736023, 11.76069546], [75.49736023, 11.76097298], [75.4970932, 11.76097012], [75.4970932, 11.76125145], [75.49624634, 11.76125145], [75.49624634, 11.76069927], [75.49597168, 11.76069927], [75.49597168, 11.76041889], [75.4954071, 11.76041889], [75.4954071, 11.76014137], [75.49485779, 11.76014137], [75.49485779, 11.75874996], [75.49458313, 11.75874996], [75.49458313, 11.75846958], [75.49375153, 11.75847244], [75.49375153, 11.75819397], [75.49236298, 11.75820065], [75.49236298, 11.75874996], [75.49208069, 11.75874996], [75.49208069, 11.75986004], [75.4909668, 11.75986004], [75.4909668, 11.76014137], [75.49124908, 11.76014137], [75.49124908, 11.76069927], [75.49153137, 11.76069927], [75.49153137, 11.76124763], [75.49014282, 11.76125145], [75.49014282, 11.76153088], [75.49041748, 11.76152897], [75.49041748, 11.76208305], [75.49069214, 11.76208305], [75.49069214, 11.76236057], [75.4909668, 11.76236057], [75.4909668, 11.76264095], [75.49124908, 11.76263905], [75.49124908, 11.76319504], [75.49069214, 11.76319504], [75.49069214, 11.76347256], [75.49041748, 11.76347065], [75.49041748, 11.76375961], [75.48958588, 11.76375961], [75.48958588, 11.76403141], [75.48930359, 11.76402664], [75.48930359, 11.76458263], [75.48902893, 11.76458073], [75.48902893, 11.76514053], [75.48874664, 11.76514053], [75.48874664, 11.76542187], [75.48847198, 11.7654171], [75.48847198, 11.76597309], [75.48819733, 11.76597118], [75.48819733, 11.76625061], [75.48792267, 11.76625061], [75.48792267, 11.76653099], [75.48735809, 11.76653099], [75.48735809, 11.76625061], [75.48596954, 11.76625061], [75.48596954, 11.76653099], [75.48569489, 11.76652908], [75.48569489, 11.7668047], [75.48542023, 11.7668047], [75.48542023, 11.76708317], [75.48458099, 11.76708126], [75.48458099, 11.76736069], [75.48430634, 11.76736069], [75.48430634, 11.76764107], [75.48208618, 11.76764107], [75.48208618, 11.76736069], [75.48179626, 11.76736069], [75.48179626, 11.76708126], [75.48152924, 11.76708317], [75.48152924, 11.7668047], [75.48069763, 11.7668047], [75.48069763, 11.76597309], [75.47875214, 11.76597309], [75.47875214, 11.76513863], [75.4770813, 11.76514053], [75.4770813, 11.76542187], [75.47652435, 11.7654171], [75.47652435, 11.76569462], [75.4751358, 11.76568985], [75.4751358, 11.76653099], [75.47486115, 11.76652908], [75.47486115, 11.76819515], [75.4751358, 11.76819515], [75.4751358, 11.76958275], [75.47541809, 11.76958275], [75.47541809, 11.76986122], [75.47569275, 11.76986122], [75.47569275, 11.77042198], [75.47597504, 11.77041721], [75.47597504, 11.77069473], [75.47652435, 11.77069473], [75.47652435, 11.7709713], [75.47680664, 11.7709713], [75.47680664, 11.77125168], [75.47735596, 11.77125168], [75.47735596, 11.77153015], [75.47763824, 11.77153015], [75.47763824, 11.77180958], [75.4779129, 11.77180481], [75.4779129, 11.77208328], [75.47820282, 11.77208138], [75.47820282, 11.77264023], [75.47846985, 11.77264023], [75.47846985, 11.77319336], [75.47902679, 11.77319336], [75.47902679, 11.77347088], [75.47930908, 11.77347088], [75.47930908, 11.77374935], [75.47957611, 11.77374935], [75.47957611, 11.77402973], [75.4798584, 11.77402973], [75.4798584, 11.77431011], [75.48069763, 11.7743063], [75.48069763, 11.77458382], [75.48152924, 11.77458382], [75.48152924, 11.7743063], [75.48208618, 11.77431011], [75.48208618, 11.77402973], [75.48236847, 11.77402973], [75.48236847, 11.77374935], [75.4826355, 11.77374935], [75.4826355, 11.77347088], [75.48291779, 11.77347088], [75.48291779, 11.77319336], [75.48319244, 11.77319336], [75.48319244, 11.77291775], [75.48374939, 11.77291775], [75.48374939, 11.77319336], [75.48430634, 11.77319145], [75.48430634, 11.77374935], [75.48458099, 11.77374935], [75.48458099, 11.77431011], [75.48430634, 11.7743063], [75.48430634, 11.77486229], [75.48401642, 11.77485943], [75.48401642, 11.77513981], [75.48374939, 11.77513981], [75.48374939, 11.77569962], [75.48430634, 11.7756958], [75.48430634, 11.77597237], [75.48652649, 11.77596855], [75.48652649, 11.77625179], [75.48680878, 11.77624989], [75.48680878, 11.77708435], [75.48652649, 11.77708244], [75.48652649, 11.77736187], [75.48625183, 11.77736187], [75.48625183, 11.77764034], [75.4854126, 11.77764034], [75.4854126, 11.77791977], [75.48513794, 11.77791786], [75.48513794, 11.77819443], [75.48486328, 11.77819443], [75.48486328, 11.77875042], [75.48513794, 11.77874088], [75.48513794, 11.77902985], [75.48568726, 11.77902985], [75.48568726, 11.77931118], [75.48625183, 11.77930641], [75.48625183, 11.7798624], [75.48652649, 11.7798624], [75.48652649, 11.78208447], [75.48680878, 11.7820797], [75.48680878, 11.78236008], [75.48735809, 11.78236008], [75.48735809, 11.78264046], [75.48764038, 11.78264046], [75.48764038, 11.78292084], [75.48792267, 11.78292084], [75.48792267, 11.78431129], [75.48764038, 11.78430557], [75.48764038, 11.78458214], [75.48708344, 11.78458214], [75.48708344, 11.78374958], [75.48596954, 11.78374958], [75.48596954, 11.78403091], [75.48513794, 11.78403091], [75.48513794, 11.78431129], [75.48402405, 11.78430557], [75.48402405, 11.78458214], [75.48374939, 11.78458023], [75.48374939, 11.78542137], [75.48402405, 11.78541565], [75.48402405, 11.78569412], [75.48430634, 11.78569412], [75.48430634, 11.78597164], [75.48401642, 11.78596973], [75.48401642, 11.78681087], [75.48430634, 11.7868042], [75.48430634, 11.78736019], [75.48458099, 11.78736019], [75.48458099, 11.78764057], [75.48486328, 11.78763866], [75.48486328, 11.78819466], [75.48458099, 11.78819466], [75.48458099, 11.78847313], [75.48569489, 11.78847313], [75.48569489, 11.78819466], [75.48596954, 11.78819466], [75.48596954, 11.78847313], [75.48625183, 11.78847027], [75.48625183, 11.78903103], [75.48652649, 11.78903103], [75.48652649, 11.78931141], [75.48680878, 11.78931141], [75.48680878, 11.78986073], [75.48764038, 11.78986073], [75.48764038, 11.79014111], [75.48792267, 11.79014111], [75.48792267, 11.79042053], [75.48819733, 11.79041672], [75.48819733, 11.79069519], [75.48874664, 11.79069519], [75.48874664, 11.79097271], [75.48958588, 11.7909708], [75.48958588, 11.79153061], [75.48986053, 11.79152679], [75.48986053, 11.79208279], [75.49069214, 11.79208279], [75.49069214, 11.79180527], [75.4909668, 11.79181194], [75.4909668, 11.79153061], [75.49124908, 11.79153061], [75.49124908, 11.79125118], [75.49153137, 11.79125118], [75.49153137, 11.7909708], [75.49263763, 11.79097271], [75.49263763, 11.79069519], [75.49291992, 11.79069519], [75.49291992, 11.79041672], [75.49375153, 11.79041672], [75.49375153, 11.79069519], [75.49402618, 11.79068089], [75.49402618, 11.79181194], [75.49375153, 11.79180527], [75.49375153, 11.79319477], [75.49402618, 11.79319477], [75.49402618, 11.79374886], [75.49430847, 11.79374027], [75.49430847, 11.79402924], [75.49458313, 11.79402924], [75.49458313, 11.79430962], [75.49514008, 11.79430485], [75.49514008, 11.79458332], [75.49597168, 11.79458141], [75.49597168, 11.79486084], [75.49624634, 11.79486084], [75.49624634, 11.79513931], [75.49652863, 11.79513931], [75.49652863, 11.7954216], [75.49680328, 11.7954216], [75.49680328, 11.79513931], [75.49764252, 11.79513931], [75.49764252, 11.79486084], [75.49791718, 11.79486084], [75.49791718, 11.79430962], [75.49819183, 11.79430962], [75.49819183, 11.79374027], [75.49874878, 11.79374886], [75.49874878, 11.79347324], [75.49930573, 11.79347324], [75.49930573, 11.79319477], [75.50013733, 11.79319477], [75.50013733, 11.79347324], [75.50041962, 11.79347324], [75.50041962, 11.79736137], [75.50013733, 11.79736137], [75.50013733, 11.79819489], [75.49986267, 11.79819489], [75.49986267, 11.79847431], [75.49903107, 11.79847431], [75.49903107, 11.79819489], [75.49874878, 11.79819489], [75.49874878, 11.79791737], [75.49847412, 11.79791737], [75.49847412, 11.79847431], [75.49819183, 11.79847145], [75.49819183, 11.7990303], [75.49791718, 11.7990303], [75.49791718, 11.79930973], [75.49764252, 11.79930496], [75.49764252, 11.79958344], [75.49652863, 11.79958344], [75.49652863, 11.79930496], [75.49624634, 11.79930973], [75.49624634, 11.7990303], [75.49569702, 11.7990303], [75.49569702, 11.79875183], [75.49514008, 11.79875183], [75.49514008, 11.79847145], [75.49458313, 11.79847431], [75.49458313, 11.79819489], [75.49319458, 11.79819489], [75.49319458, 11.79791737], [75.49263763, 11.79792023], [75.49263763, 11.79763889], [75.49124908, 11.79763889], [75.49124908, 11.79736137], [75.49069214, 11.79736137], [75.49069214, 11.7970829], [75.49041748, 11.7970829], [75.49041748, 11.79680538], [75.49014282, 11.79681015], [75.49014282, 11.79653168], [75.48902893, 11.79653168], [75.48902893, 11.7962513], [75.48764038, 11.7962513], [75.48764038, 11.79653168], [75.48707581, 11.79653168], [75.48707581, 11.79681015], [75.48680878, 11.79681015], [75.48680878, 11.79763889], [75.48652649, 11.79763889], [75.48652649, 11.79819489], [75.48625183, 11.79819489], [75.48625183, 11.79847431], [75.48596954, 11.79847145], [75.48596954, 11.79875183], [75.48625183, 11.79875183], [75.48625183, 11.7990303], [75.48596954, 11.7990303], [75.48596954, 11.79930973], [75.48568726, 11.79930973], [75.48568726, 11.7990303], [75.4854126, 11.7990303], [75.4854126, 11.79875183], [75.48319244, 11.79875183], [75.48319244, 11.79847145], [75.48264313, 11.79847145], [75.48264313, 11.79875183], [75.48236847, 11.79875183], [75.48236847, 11.79930973], [75.48097229, 11.79930973], [75.48097229, 11.80014038], [75.47957611, 11.80014038], [75.47957611, 11.80041981], [75.4779129, 11.80041981], [75.4779129, 11.80014038], [75.47735596, 11.80014038], [75.47735596, 11.80041981], [75.4770813, 11.8004179], [75.4770813, 11.80097103], [75.47680664, 11.80097103], [75.47680664, 11.80208397], [75.47652435, 11.80208397], [75.47652435, 11.80236244], [75.47569275, 11.80235863], [75.47569275, 11.80293179], [75.47541809, 11.80291557], [75.47541809, 11.80347157], [75.4743042, 11.80347157], [75.4743042, 11.80097103], [75.47458649, 11.80097103], [75.47458649, 11.79986191], [75.47486115, 11.79987144], [75.47486115, 11.79958057], [75.47541809, 11.79958344], [75.47541809, 11.79930496], [75.47569275, 11.79930973], [75.47569275, 11.7990303], [75.4770813, 11.7990303], [75.4770813, 11.79930973], [75.47930908, 11.79930973], [75.47930908, 11.7990303], [75.47957611, 11.7990303], [75.47957611, 11.79847145], [75.4798584, 11.79847431], [75.4798584, 11.79763889], [75.48042297, 11.79763889], [75.48042297, 11.79681015], [75.48069763, 11.79681015], [75.48069763, 11.79653168], [75.48124695, 11.79653168], [75.48124695, 11.79681015], [75.48180389, 11.79680538], [75.48180389, 11.7970829], [75.48236084, 11.7970829], [75.48236084, 11.79680538], [75.48264313, 11.79681015], [75.48264313, 11.79653168], [75.48374939, 11.79653168], [75.48374939, 11.7962513], [75.48430634, 11.7962513], [75.48430634, 11.79597092], [75.48458099, 11.79597092], [75.48458099, 11.7956953], [75.48486328, 11.7956953], [75.48486328, 11.79541683], [75.48513794, 11.7954216], [75.48513794, 11.79486084], [75.4854126, 11.79486084], [75.4854126, 11.79458141], [75.48569489, 11.79458332], [75.48569489, 11.79430485], [75.48596954, 11.79430962], [75.48596954, 11.79402924], [75.48625183, 11.79402924], [75.48625183, 11.79374027], [75.48596954, 11.79374886], [75.48596954, 11.79347324], [75.48625183, 11.79347324], [75.48625183, 11.79236126], [75.48680878, 11.79236126], [75.48680878, 11.79180527], [75.48652649, 11.79180527], [75.48652649, 11.79208279], [75.48569489, 11.79208279], [75.48569489, 11.79180527], [75.4854126, 11.79181194], [75.4854126, 11.79153061], [75.48486328, 11.79153061], [75.48486328, 11.7909708], [75.48430634, 11.7909708], [75.48430634, 11.79125118], [75.48458099, 11.79125118], [75.48458099, 11.79181194], [75.48486328, 11.79180527], [75.48486328, 11.79236126], [75.48401642, 11.79236126], [75.48401642, 11.79264069], [75.48236847, 11.79264069], [75.48236847, 11.79236126], [75.48180389, 11.79236126], [75.48180389, 11.79125118], [75.48124695, 11.79125118], [75.48124695, 11.79068089], [75.48069763, 11.79069519], [75.48069763, 11.79041672], [75.48042297, 11.79042053], [75.48042297, 11.79014111], [75.4798584, 11.79014111], [75.4798584, 11.78958035], [75.47958374, 11.78958321], [75.47958374, 11.78930473], [75.47902679, 11.78931141], [75.47902679, 11.78875065], [75.47875214, 11.78875065], [75.47875214, 11.78764057], [75.47902679, 11.78764057], [75.47902679, 11.78681087], [75.47875214, 11.78681087], [75.47875214, 11.78653145], [75.47820282, 11.78653145], [75.47820282, 11.78569031], [75.4779129, 11.78569412], [75.4779129, 11.78430557], [75.47820282, 11.78431129], [75.47820282, 11.78264046], [75.47846985, 11.78264046], [75.47846985, 11.78236008], [75.47875214, 11.78236008], [75.47875214, 11.7820797], [75.47958374, 11.78208447], [75.47958374, 11.78180599], [75.4798584, 11.78180599], [75.4798584, 11.78041553], [75.48014069, 11.7804203], [75.48014069, 11.78013992], [75.48042297, 11.78013992], [75.48042297, 11.77958202], [75.48069763, 11.77958393], [75.48069763, 11.77930641], [75.48042297, 11.77931118], [75.48042297, 11.77902985], [75.48014069, 11.77902985], [75.48014069, 11.77847195], [75.47958374, 11.77847195], [75.47958374, 11.77819443], [75.47930908, 11.77819443], [75.47930908, 11.77791786], [75.47902679, 11.77791977], [75.47902679, 11.77764034], [75.47875214, 11.77764034], [75.47875214, 11.77736187], [75.47846985, 11.77736187], [75.47846985, 11.77708244], [75.47819519, 11.77708435], [75.47819519, 11.77680588], [75.4779129, 11.77680969], [75.4779129, 11.77653027], [75.47763824, 11.77653027], [75.47763824, 11.77625179], [75.47735596, 11.77625179], [75.47735596, 11.77596855], [75.47680664, 11.77597237], [75.47680664, 11.7756958], [75.47651672, 11.77569962], [75.47651672, 11.77542019], [75.47569275, 11.77542019], [75.47569275, 11.77513981], [75.47486115, 11.77513981], [75.47486115, 11.77485943], [75.47374725, 11.77486229], [75.47374725, 11.77458382], [75.47319794, 11.77458382], [75.47319794, 11.7743063], [75.47292328, 11.77431011], [75.47292328, 11.77347088], [75.47264099, 11.77347088], [75.47264099, 11.7723608], [75.4723587, 11.7723608], [75.4723587, 11.77152729], [75.47207642, 11.77153015], [75.47207642, 11.7709713], [75.47180176, 11.7709713], [75.47180176, 11.77069473], [75.4715271, 11.77069473], [75.4715271, 11.77013874], [75.47125244, 11.7701416], [75.47125244, 11.76957035], [75.47097015, 11.76958275], [75.47097015, 11.76819515], [75.4706955, 11.76819515], [75.4706955, 11.76708317], [75.47041321, 11.76708317], [75.47041321, 11.76652908], [75.47013855, 11.76653099], [75.47013855, 11.76568985], [75.4695816, 11.76569462], [75.4695816, 11.7654171], [75.46930695, 11.76542187], [75.46930695, 11.76514053], [75.46901703, 11.76514053], [75.46901703, 11.76486111], [75.46875, 11.76486111], [75.46875, 11.76458263], [75.46819305, 11.76458263], [75.46819305, 11.76430511], [75.4679184, 11.76430511], [75.4679184, 11.76458263], [75.46736145, 11.76458263], [75.46736145, 11.76486111], [75.46708679, 11.76486111], [75.46708679, 11.76514053], [75.46679687, 11.76514053], [75.46679687, 11.76542187], [75.46652985, 11.7654171], [75.46652985, 11.76569462], [75.46624756, 11.76569462], [75.46624756, 11.76597309], [75.4659729, 11.76597118], [75.4659729, 11.76625061], [75.46485901, 11.76625061], [75.46485901, 11.76597118], [75.46430206, 11.76597309], [75.46430206, 11.76569462], [75.46347046, 11.76569462], [75.46347046, 11.7654171], [75.4631958, 11.7654171], [75.4631958, 11.76569462], [75.46263885, 11.76569462], [75.46263885, 11.76597309], [75.46152496, 11.76597309], [75.46152496, 11.76569462], [75.46097565, 11.76569462], [75.46097565, 11.7654171], [75.45986176, 11.7654171], [75.45986176, 11.76569462], [75.4595871, 11.76569462], [75.4595871, 11.7668047], [75.45903015, 11.76679993], [75.45903015, 11.76736069], [75.45874786, 11.76736069], [75.45874786, 11.76764107], [75.45819092, 11.76763916], [75.45819092, 11.76819515], [75.45789337, 11.76819515], [75.45777893, 11.76819515], [75.4576416, 11.76819515], [75.4576416, 11.76847267], [75.45735931, 11.76847076], [75.45735931, 11.76875114], [75.45680237, 11.76875114], [75.45680237, 11.76903152], [75.45625305, 11.76903152], [75.45625305, 11.7693119], [75.45569611, 11.76930523], [75.45569611, 11.76958275], [75.45541382, 11.76958275], [75.45541382, 11.76986122], [75.45485687, 11.76986122], [75.45485687, 11.7701416], [75.45458221, 11.7701416], [75.45458221, 11.76986122], [75.45430756, 11.76986122], [75.45430756, 11.7701416], [75.45375061, 11.77013874], [75.45375061, 11.77069473], [75.45347595, 11.77069092], [75.45347595, 11.77125168], [75.45375061, 11.77125168], [75.45375061, 11.77153015], [75.4540329, 11.77153015], [75.4540329, 11.77180958], [75.45430756, 11.77180481], [75.45430756, 11.77319336], [75.45458221, 11.77319336], [75.45458221, 11.77347088], [75.45458221, 11.77431011], [75.45430756, 11.77431011], [75.45430756, 11.77542019], [75.45458221, 11.77542019], [75.45458221, 11.77569962], [75.45485687, 11.77569962], [75.45485687, 11.77625179], [75.45513916, 11.77625179], [75.45513916, 11.77653027], [75.45540619, 11.77653027], [75.45540619, 11.77680969], [75.45597076, 11.77680588], [75.45597076, 11.77708435], [75.45652771, 11.77708435], [75.45652771, 11.77652836], [75.45680237, 11.77653027], [75.45680237, 11.77625179], [75.4576416, 11.77625179], [75.4576416, 11.77596855], [75.45819855, 11.77596855], [75.45819855, 11.77625179], [75.45903015, 11.77625179], [75.45903015, 11.77653027], [75.46013641, 11.77653027], [75.46013641, 11.77680969], [75.4604187, 11.77680969], [75.4604187, 11.77764034], [75.46069336, 11.77764034], [75.46069336, 11.77791977], [75.4604187, 11.77791786], [75.4604187, 11.77819443], [75.46069336, 11.77819443], [75.46069336, 11.77875042], [75.46098328, 11.77874088], [75.46098328, 11.77931118], [75.46125031, 11.77930641], [75.46125031, 11.7798624], [75.46151733, 11.77985954], [75.46151733, 11.78013992], [75.46180725, 11.78013802], [75.46180725, 11.78069401], [75.46208191, 11.78068924], [75.46208191, 11.78153038], [75.4623642, 11.78152847], [75.4623642, 11.78208447], [75.46263885, 11.78208447], [75.46263885, 11.78319359], [75.46290588, 11.78318977], [75.46290588, 11.78374958], [75.4631958, 11.78374958], [75.4631958, 11.78514099], [75.46347046, 11.78514099], [75.46347046, 11.78625107], [75.4631958, 11.78625107], [75.4631958, 11.78681087], [75.46347046, 11.78681087], [75.46347046, 11.79125118], [75.4631958, 11.79125118], [75.4631958, 11.79319477], [75.46291351, 11.79319477], [75.46291351, 11.79347324], [75.4631958, 11.79347134], [75.4631958, 11.79430962], [75.46291351, 11.79430485], [75.46291351, 11.7956953], [75.4631958, 11.79569054], [75.4631958, 11.7962513], [75.46347046, 11.7962513], [75.46347046, 11.79681015], [75.46375275, 11.79680538], [75.46375275, 11.7970829], [75.46347046, 11.79708099], [75.46347046, 11.7990303], [75.4631958, 11.7990303], [75.4631958, 11.80014038], [75.46290588, 11.80014038], [75.46290588, 11.80041981], [75.46263885, 11.8004179], [75.46263885, 11.80069256], [75.4623642, 11.80069256], [75.4623642, 11.80097103], [75.46208191, 11.80097103], [75.46208191, 11.80153179], [75.46180725, 11.80152798], [75.46180725, 11.80208397], [75.46151733, 11.8020792], [75.46151733, 11.80263996], [75.46125031, 11.80263996], [75.46125031, 11.80347157], [75.46098328, 11.80347157], [75.46098328, 11.80403042], [75.4604187, 11.80402756], [75.4604187, 11.80569363], [75.46013641, 11.80569363], [75.46013641, 11.80579185], [75.46013641, 11.8073597], [75.45874786, 11.8073597], [75.45874786, 11.80597019], [75.45847321, 11.8059721], [75.45847321, 11.80458355], [75.45874786, 11.80458355], [75.45874786, 11.80375004], [75.45903015, 11.80375195], [75.45903015, 11.80293179], [75.45923615, 11.80293179], [75.45929718, 11.80263996], [75.46013641, 11.80263996], [75.46013641, 11.80235863], [75.4604187, 11.80236244], [75.4604187, 11.80180645], [75.46069336, 11.80181026], [75.46069336, 11.80097103], [75.46097565, 11.80097103], [75.46097565, 11.8004179], [75.46124268, 11.80041981], [75.46124268, 11.79930973], [75.46098328, 11.79930973], [75.46098328, 11.79875183], [75.46124268, 11.79875183], [75.46124268, 11.79847145], [75.46208191, 11.79847431], [75.46208191, 11.79819489], [75.46180725, 11.79819489], [75.46180725, 11.79791737], [75.46208191, 11.79792023], [75.46208191, 11.79653168], [75.46180725, 11.79653168], [75.46180725, 11.79588032], [75.46180725, 11.79541683], [75.46153259, 11.7954216], [75.46153259, 11.79374027], [75.46180725, 11.79374886], [75.46180725, 11.79347324], [75.46152496, 11.79347324], [75.46152496, 11.79263878], [75.46124268, 11.79264069], [75.46124268, 11.79236126], [75.46152496, 11.79236126], [75.46152496, 11.79208279], [75.46125031, 11.79208279], [75.46125031, 11.79125118], [75.46097565, 11.79125118], [75.46097565, 11.78763866], [75.46124268, 11.78764057], [75.46124268, 11.78458023], [75.46097565, 11.78458214], [75.46097565, 11.78402805], [75.46069336, 11.78403091], [75.46069336, 11.78347015], [75.4604187, 11.78347206], [75.4604187, 11.78291607], [75.46069336, 11.78292084], [75.46069336, 11.78264046], [75.4604187, 11.78264046], [75.4604187, 11.7820797], [75.46013641, 11.78208447], [75.46013641, 11.77958393], [75.45986176, 11.77958393], [75.45986176, 11.77902794], [75.4595871, 11.77902985], [75.4595871, 11.77847195], [75.45930481, 11.77847195], [75.45930481, 11.77819443], [75.45735931, 11.77819443], [75.45735931, 11.77847195], [75.45652771, 11.77847195], [75.45652771, 11.77875042], [75.45625305, 11.77874088], [75.45625305, 11.77902985], [75.45540619, 11.77902985], [75.45540619, 11.77874088], [75.45513916, 11.77875042], [75.45513916, 11.77847195], [75.4548645, 11.77847195], [75.4548645, 11.77875042], [75.45458221, 11.77875042], [75.45458221, 11.77847195], [75.45402527, 11.77847195], [75.45402527, 11.77875042], [75.45347595, 11.77874088], [75.45347595, 11.77902985], [75.45318604, 11.77902985], [75.45318604, 11.77931118], [75.45263672, 11.77930641], [75.45263672, 11.77958393], [75.45207977, 11.77958393], [75.45207977, 11.7798624], [75.45153046, 11.77985954], [75.45153046, 11.78013992], [75.45069122, 11.78013992], [75.45069122, 11.7804203], [75.45014191, 11.78041553], [75.45014191, 11.78069401], [75.44958496, 11.78069401], [75.44958496, 11.78097153], [75.44847107, 11.78096962], [75.44847107, 11.78125], [75.44819641, 11.78125], [75.44819641, 11.78153038], [75.44763947, 11.78152847], [75.44763947, 11.78180599], [75.44736481, 11.78180599], [75.44736481, 11.78347206], [75.44763947, 11.78347015], [75.44763947, 11.78542137], [75.44790649, 11.78542137], [75.44790649, 11.78653145], [75.44763947, 11.78653145], [75.44763947, 11.78764057], [75.44736481, 11.78763866], [75.44736481, 11.78819466], [75.44708252, 11.7881918], [75.44708252, 11.78875065], [75.44680786, 11.78875065], [75.44680786, 11.78903103], [75.4465332, 11.78903103], [75.4465332, 11.79014111], [75.44625092, 11.7901392], [75.44625092, 11.79069519], [75.44596863, 11.79068089], [75.44596863, 11.79125118], [75.44541931, 11.79125118], [75.44541931, 11.79153061], [75.44513702, 11.79153061], [75.44513702, 11.79181194], [75.44486237, 11.79180527], [75.44486237, 11.79236126], [75.44458008, 11.79236126], [75.44458008, 11.79292202], [75.44430542, 11.79291725], [75.44430542, 11.79319477], [75.44374847, 11.79319477], [75.44374847, 11.79374886], [75.44347382, 11.79374886], [75.44347382, 11.79458332], [75.44319916, 11.79458141], [75.44319916, 11.79513931], [75.44291687, 11.79513931], [75.44291687, 11.79597092], [75.44264221, 11.79597092], [75.44264221, 11.79653168], [75.44235992, 11.79652691], [75.44235992, 11.79736137], [75.44152832, 11.79736137], [75.44152832, 11.79763889], [75.44069672, 11.79763889], [75.44069672, 11.79819489], [75.4404068, 11.79819107], [75.4404068, 11.79875183], [75.44013214, 11.79875183], [75.44013214, 11.7990303], [75.43985748, 11.79902744], [75.43985748, 11.79958344], [75.43958282, 11.79958344], [75.43958282, 11.80069256], [75.43902588, 11.80069256], [75.43902588, 11.80097103], [75.43875122, 11.80097103], [75.43875122, 11.80153179], [75.43846893, 11.80153179], [75.43846893, 11.80181026], [75.43791962, 11.80180645], [75.43791962, 11.80236244], [75.43763733, 11.80235863], [75.43763733, 11.80293179], [75.43707275, 11.80293179], [75.43707275, 11.80375195], [75.43681335, 11.80375195], [75.43681335, 11.80403042], [75.43653107, 11.80402756], [75.43653107, 11.80458355], [75.43596649, 11.80458164], [75.43596649, 11.80513954], [75.43569183, 11.80513954], [75.43569183, 11.80541992], [75.43541718, 11.80541801], [75.43541718, 11.8059721], [75.43514252, 11.80597019], [75.43514252, 11.80624962], [75.43486023, 11.80624962], [75.43486023, 11.80653], [75.4345932, 11.80653], [75.4345932, 11.80681133], [75.43402863, 11.80680561], [75.43402863, 11.80708408], [75.43374634, 11.80708027], [75.43374634, 11.8073597], [75.4329071, 11.8073597], [75.4329071, 11.80764008], [75.43264008, 11.80764008], [75.43264008, 11.80792141], [75.43208313, 11.80792141], [75.43208313, 11.80764008], [75.43180847, 11.80764008], [75.43180847, 11.8073597], [75.43152618, 11.8073597], [75.43152618, 11.80681133], [75.42958069, 11.80680561], [75.42958069, 11.80708408], [75.42930603, 11.80708027], [75.42930603, 11.8073597], [75.42903137, 11.8073597], [75.42903137, 11.80764008], [75.42874908, 11.80764008], [75.42874908, 11.80819416], [75.4284668, 11.80818939], [75.4284668, 11.80875015], [75.42819214, 11.80875015], [75.42819214, 11.80902958], [75.42764282, 11.80902958], [75.42764282, 11.80931091], [75.42736053, 11.80930614], [75.42736053, 11.80958366], [75.42708588, 11.80957985], [75.42708588, 11.81013966], [75.42652893, 11.81013966], [75.42652893, 11.81042099], [75.42569733, 11.81042099], [75.42569733, 11.81124973], [75.42542267, 11.81124973], [75.42542267, 11.81181145], [75.42485809, 11.81180573], [75.42485809, 11.81208229], [75.42402649, 11.81208038], [75.42402649, 11.81236267], [75.42375183, 11.81236267], [75.42375183, 11.81264114], [75.42346954, 11.81264114], [75.42346954, 11.81292057], [75.42375183, 11.81292057], [75.42375183, 11.81431103], [75.42346954, 11.81430435], [75.42346954, 11.81458473], [75.42318726, 11.81457996], [75.42318726, 11.81487179], [75.42292023, 11.81487179], [75.42292023, 11.81514072], [75.42263794, 11.81514072], [75.42263794, 11.8162508], [75.42236328, 11.8162508], [75.42236328, 11.81653118], [75.42180634, 11.81653118], [75.42180634, 11.81681061], [75.42151642, 11.81681061], [75.42151642, 11.81736088], [75.42124939, 11.81736088], [75.42124939, 11.81764126], [75.42097473, 11.81763935], [75.42097473, 11.81791687], [75.42069244, 11.81791687], [75.42069244, 11.81819534], [75.42041779, 11.81819534], [75.42041779, 11.81847286], [75.42014313, 11.81847095], [75.42014313, 11.81903076], [75.41958618, 11.81903076], [75.41958618, 11.81930923], [75.41902924, 11.81930542], [75.41902924, 11.81958294], [75.41847229, 11.81958103], [75.41847229, 11.82014084], [75.41819763, 11.82013893], [75.41819763, 11.82069111], [75.41792297, 11.82069969], [75.41792297, 11.82180977], [75.41764069, 11.82180977], [75.41764069, 11.82236099], [75.4173584, 11.82236099], [75.4173584, 11.82291985], [75.41708374, 11.82291698], [75.41708374, 11.82319546], [75.41652679, 11.82319069], [75.41652679, 11.82375145], [75.41625214, 11.82375145], [75.41625214, 11.8243103], [75.41596985, 11.82430458], [75.41596985, 11.82458305], [75.41570282, 11.82458115], [75.41570282, 11.82514191], [75.41513824, 11.82514191], [75.41513824, 11.82542038], [75.41486359, 11.82541656], [75.41486359, 11.82597446], [75.4145813, 11.82597065], [75.4145813, 11.82653046], [75.41401672, 11.82653046], [75.41401672, 11.82681179], [75.41374969, 11.82680511], [75.41374969, 11.82736206], [75.41319275, 11.8273592], [75.41319275, 11.82763958], [75.41291809, 11.82763958], [75.41291809, 11.82819557], [75.4126358, 11.8281889], [75.4126358, 11.82874966], [75.41236115, 11.82874966], [75.41236115, 11.82903004], [75.41208649, 11.82903004], [75.41208649, 11.82931042], [75.4118042, 11.82930565], [75.4118042, 11.82958412], [75.41152954, 11.82958412], [75.41152954, 11.82986164], [75.41124725, 11.8298502], [75.41124725, 11.83014202], [75.4109726, 11.83014202], [75.4109726, 11.83041954], [75.41069794, 11.83041573], [75.41069794, 11.8306942], [75.41041565, 11.8306942], [75.41041565, 11.83097172], [75.41014099, 11.83097172], [75.41014862, 11.83125019], [75.4098587, 11.83125019], [75.4098587, 11.83152962], [75.40957642, 11.83152962], [75.40957642, 11.83181], [75.4090271, 11.83180618], [75.4090271, 11.8320837], [75.40875244, 11.8320837], [75.40875244, 11.83236217], [75.40847015, 11.83236027], [75.40847015, 11.83263969], [75.40791321, 11.83263779], [75.40791321, 11.83347225], [75.40763855, 11.83347034], [75.40763855, 11.83403015], [75.40736389, 11.83402824], [75.40736389, 11.83485985], [75.40680695, 11.83485985], [75.40680695, 11.83542061], [75.40651703, 11.83542061], [75.40651703, 11.83598137], [75.40625, 11.83598137], [75.40625, 11.83625031], [75.40569305, 11.83625031], [75.40569305, 11.83653069], [75.4054184, 11.83653069], [75.4054184, 11.83681107], [75.40513611, 11.8368063], [75.40513611, 11.83819389], [75.4034729, 11.83819389], [75.4034729, 11.83791637], [75.40319824, 11.83791637], [75.40319824, 11.83819389], [75.40291595, 11.83819389], [75.40291595, 11.83847237], [75.4026413, 11.83847046], [75.4026413, 11.83875275], [75.40235901, 11.83875275], [75.40235901, 11.8390398], [75.40207672, 11.8390398], [75.40207672, 11.83931065], [75.4015274, 11.83930683], [75.4015274, 11.83958244], [75.40125275, 11.83957958], [75.40125275, 11.83985996], [75.40096283, 11.83985996], [75.40096283, 11.8401413], [75.4006958, 11.8401413], [75.4006958, 11.84042072], [75.40041351, 11.84041595], [75.40041351, 11.84069538], [75.39875031, 11.84069538], [75.39875031, 11.8409729], [75.39847565, 11.8409729], [75.39848328, 11.84125137], [75.39819336, 11.84125137], [75.39819336, 11.8415308], [75.39763641, 11.8415308], [75.39763641, 11.84181118], [75.39736176, 11.84180355], [75.39736176, 11.84236145], [75.3970871, 11.84236145], [75.3970871, 11.84264088], [75.39653015, 11.84264088], [75.39653015, 11.84375095], [75.39624786, 11.84375095], [75.39624786, 11.84431171], [75.39597321, 11.84430695], [75.39597321, 11.84486103], [75.39569092, 11.84485245], [75.39569092, 11.84514141], [75.39541626, 11.84513855], [75.39541626, 11.84569454], [75.3951416, 11.84569454], [75.3951416, 11.84597301], [75.39457703, 11.84597111], [75.39457703, 11.84653091], [75.39430237, 11.84653091], [75.39430237, 11.84680939], [75.39402771, 11.84680462], [75.39402771, 11.84736061], [75.39375305, 11.84736061], [75.39375305, 11.84791946], [75.39347076, 11.8479166], [75.39347076, 11.8484726], [75.39319611, 11.84847069], [75.39319611, 11.84875107], [75.39290619, 11.84875107], [75.39290619, 11.8490324], [75.39263916, 11.8490324], [75.39263916, 11.84931183], [75.39152527, 11.84930515], [75.39152527, 11.84958267], [75.39125061, 11.84958267], [75.39125061, 11.84986115], [75.39097595, 11.84986115], [75.39097595, 11.85014153], [75.39069366, 11.85013866], [75.39069366, 11.85069466], [75.39041901, 11.85069084], [75.39041901, 11.8509798], [75.39013672, 11.8509798], [75.39013672, 11.85125065], [75.38986206, 11.85125065], [75.38986206, 11.85153198], [75.38957977, 11.85153198], [75.38957977, 11.85181046], [75.38930511, 11.85180473], [75.38930511, 11.85208321], [75.38902283, 11.8520813], [75.38902283, 11.85236073], [75.38846588, 11.85236073], [75.38846588, 11.8526392], [75.38819122, 11.8526392], [75.38819122, 11.85291958], [75.38791656, 11.85291767], [75.38791656, 11.85319328], [75.38764191, 11.85319328], [75.38764191, 11.8534708], [75.38708496, 11.85347366], [75.38709259, 11.85374928], [75.38680267, 11.85374928], [75.38680267, 11.85402679], [75.38652802, 11.85402107], [75.38652802, 11.85431004], [75.38625336, 11.85430622], [75.38625336, 11.85458374], [75.38569641, 11.85458374], [75.38569641, 11.85486221], [75.38540649, 11.85485935], [75.38540649, 11.85513973], [75.38513947, 11.85513973], [75.38513947, 11.85542011], [75.38486481, 11.85541534], [75.38486481, 11.85569572], [75.38458252, 11.85569572], [75.38458252, 11.85597229], [75.38430786, 11.85597229], [75.38430786, 11.85624981], [75.3840332, 11.85624981], [75.3840332, 11.85653019], [75.38375092, 11.85653019], [75.38375092, 11.85680962], [75.38319397, 11.8568058], [75.38319397, 11.85708427], [75.38263702, 11.85708237], [75.38263702, 11.85736179], [75.38236237, 11.85736179], [75.38236237, 11.85764027], [75.38181305, 11.85764027], [75.38181305, 11.85791969], [75.38097382, 11.85791779], [75.38097382, 11.85819435], [75.38041687, 11.85819435], [75.38041687, 11.85847187], [75.37985992, 11.85847187], [75.37985992, 11.85875034], [75.37930298, 11.85875034], [75.37930298, 11.85902977], [75.37902832, 11.85902977], [75.37902832, 11.85875034], [75.37763977, 11.85875034], [75.37763977, 11.85847187], [75.37652588, 11.85847187], [75.37652588, 11.85819435], [75.37625122, 11.85819435], [75.37625122, 11.85791779], [75.37458038, 11.85791969], [75.37458038, 11.85736179], [75.37431335, 11.85736179], [75.37431335, 11.85680962], [75.37346649, 11.85680962], [75.37346649, 11.85653019], [75.37319183, 11.85653019], [75.37319183, 11.85624981], [75.37291718, 11.85624981], [75.37291718, 11.85597229], [75.37264252, 11.85597229], [75.37264252, 11.85513973], [75.37291718, 11.85513973], [75.37291718, 11.85431004], [75.37319183, 11.85431004], [75.37319183, 11.85402107], [75.37347412, 11.85402679], [75.37347412, 11.85374928], [75.37401581, 11.85374928], [75.37401581, 11.85346889], [75.37430573, 11.8534708], [75.37430573, 11.85319328], [75.37458038, 11.85319328], [75.37458038, 11.85291767], [75.37431335, 11.85291958], [75.37431335, 11.8526392], [75.37401581, 11.8526392], [75.37401581, 11.85236073], [75.37319183, 11.85236073], [75.37319183, 11.8526392], [75.37264252, 11.8526392], [75.37264252, 11.85291958], [75.37208557, 11.85291767], [75.37208557, 11.85319328], [75.37180328, 11.85319328], [75.37180328, 11.85291767], [75.37097168, 11.85291767], [75.37097168, 11.85319328], [75.37069702, 11.85319328], [75.37069702, 11.85291767], [75.37014008, 11.85291958], [75.37014008, 11.8526392], [75.36971283, 11.8526392], [75.36930847, 11.8526392], [75.36930847, 11.85236073], [75.36875153, 11.85236073], [75.36875153, 11.8520813], [75.36819458, 11.85208321], [75.36819458, 11.85180473], [75.36763763, 11.85181046], [75.36763763, 11.85125065], [75.36680603, 11.85125065], [75.36680603, 11.85181046], [75.36653137, 11.85180473], [75.36653137, 11.85208321], [75.36624908, 11.8520813], [75.36624908, 11.85236073], [75.3659668, 11.85236073], [75.3659668, 11.8526392], [75.36569214, 11.8526392], [75.36569214, 11.85236073], [75.36485291, 11.85236073], [75.36485291, 11.85291958], [75.36458588, 11.85291767], [75.36458588, 11.85319328], [75.36430359, 11.85319328], [75.36430359, 11.8534708], [75.36402893, 11.85346889], [75.36402893, 11.85374928], [75.36374664, 11.85374928], [75.36374664, 11.85486221], [75.36347198, 11.85485935], [75.36347198, 11.85542011], [75.36319733, 11.85541534], [75.36319733, 11.85569572], [75.36347198, 11.85569572], [75.36347198, 11.85624981], [75.36319733, 11.85624981], [75.36319733, 11.85653019], [75.36292267, 11.85653019], [75.36292267, 11.85680962], [75.36235809, 11.85680962], [75.36235809, 11.85653019], [75.36152649, 11.85653019], [75.36152649, 11.85680962], [75.36096954, 11.85680962], [75.36096954, 11.85736179], [75.36068726, 11.85736179], [75.36068726, 11.85791969], [75.36042023, 11.85791779], [75.36042023, 11.85819435], [75.36013794, 11.85819435], [75.36013794, 11.85847187], [75.35986328, 11.85847187], [75.35986328, 11.85875034], [75.35958099, 11.85875034], [75.35958099, 11.85902977], [75.35874939, 11.85902977], [75.35874939, 11.85931015], [75.35819244, 11.85930634], [75.35819244, 11.85958385], [75.35541534, 11.85958385], [75.35541534, 11.85986233], [75.35514069, 11.85986042], [75.35514069, 11.86236], [75.3548584, 11.86236], [75.3548584, 11.86347198], [75.35457611, 11.86347008], [75.35457611, 11.86431122], [75.35430908, 11.86430645], [75.35430908, 11.86486244], [75.35402679, 11.86485958], [75.35402679, 11.8654213], [75.35375214, 11.86541557], [75.35375214, 11.86597157], [75.35346985, 11.86596107], [75.35346985, 11.86625004], [75.3529129, 11.86625004], [75.3529129, 11.8668108], [75.35263824, 11.86680698], [75.35263824, 11.86708546], [75.35235596, 11.86707973], [75.35235596, 11.86792088], [75.35263824, 11.86791706], [75.35263824, 11.86819458], [75.3529129, 11.86819458], [75.3529129, 11.86958313], [75.35263824, 11.86958027], [75.35263824, 11.86986065], [75.35235596, 11.86986065], [75.35235596, 11.87014103], [75.3520813, 11.87014103], [75.3520813, 11.87125111], [75.35151672, 11.87125111], [75.35151672, 11.87153053], [75.35124969, 11.87153053], [75.35124969, 11.87181187], [75.35097504, 11.87180519], [75.35097504, 11.87236118], [75.35069275, 11.87236118], [75.35069275, 11.87264061], [75.35041809, 11.8726387], [75.35041809, 11.87319469], [75.3501358, 11.87318993], [75.3501358, 11.87375069], [75.34958649, 11.87375069], [75.34958649, 11.87403107], [75.3493042, 11.87402916], [75.3493042, 11.87458324], [75.34902954, 11.87458134], [75.34902954, 11.87514973], [75.34874725, 11.87514973], [75.34874725, 11.87542152], [75.3484726, 11.87542152], [75.3484726, 11.87597084], [75.34819794, 11.87597084], [75.34819794, 11.87625122], [75.34764099, 11.87625122], [75.34764099, 11.8765316], [75.3473587, 11.8765316], [75.3473587, 11.87681198], [75.34708405, 11.87680531], [75.34708405, 11.8773613], [75.34680939, 11.8773613], [75.34680939, 11.87764168], [75.34625244, 11.87763882], [75.34625244, 11.87819481], [75.34597015, 11.87819099], [75.34597015, 11.87874889], [75.34570313, 11.87874889], [75.34570313, 11.87930965], [75.34541321, 11.87930489], [75.34541321, 11.87958336], [75.34513855, 11.87958145], [75.34513855, 11.8801403], [75.3445816, 11.8801403], [75.3445816, 11.88041973], [75.34430695, 11.88041782], [75.34430695, 11.88097095], [75.34401703, 11.88096046], [75.34401703, 11.88152981], [75.34375, 11.88152981], [75.34375, 11.88181019], [75.34347534, 11.88180637], [75.34347534, 11.88208389], [75.34319305, 11.88208389], [75.34319305, 11.88236237], [75.3429184, 11.88235855], [75.3429184, 11.88292027], [75.34263611, 11.88291645], [75.34263611, 11.88319111], [75.34236145, 11.88319588], [75.34236145, 11.88347244], [75.34208679, 11.88347244], [75.34208679, 11.88375187], [75.34152985, 11.88375187], [75.34152985, 11.88403034], [75.34124756, 11.88402843], [75.34124756, 11.88458443], [75.3409729, 11.88458157], [75.3409729, 11.88514042], [75.34069824, 11.88514042], [75.34069824, 11.88541985], [75.34041595, 11.88541794], [75.34041595, 11.88569355], [75.34069824, 11.88569355], [75.34069824, 11.88597202], [75.3401413, 11.88597202], [75.3401413, 11.88652992], [75.33957672, 11.88652992], [75.33957672, 11.88681126], [75.33930206, 11.88680553], [75.33930206, 11.88736153], [75.3390274, 11.88735962], [75.3390274, 11.88764], [75.33875275, 11.88764], [75.33875275, 11.88819408], [75.3381958, 11.88819408], [75.3381958, 11.8884716], [75.33790588, 11.8884697], [75.33790588, 11.88903046], [75.33763885, 11.88903046], [75.33763885, 11.88931084], [75.3373642, 11.88930607], [75.3373642, 11.88958359], [75.33708191, 11.88958359], [75.33708191, 11.89013767], [75.33680725, 11.890131], [75.33680725, 11.89042091], [75.33652496, 11.89041615], [75.33652496, 11.89069366], [75.33625031, 11.89069366], [75.33625031, 11.89097214], [75.33598328, 11.89097023], [75.33598328, 11.89124966], [75.33569336, 11.89124966], [75.33569336, 11.89208221], [75.3354187, 11.89208031], [75.3354187, 11.89235973], [75.33513641, 11.89235973], [75.33513641, 11.89264107], [75.33486176, 11.89263821], [75.33486176, 11.8931942], [75.33429718, 11.89319038], [75.33429718, 11.89375114], [75.33403015, 11.89375114], [75.33403015, 11.89403057], [75.33347321, 11.89402866], [75.33347321, 11.89458466], [75.33319092, 11.89458179], [75.33319092, 11.89514065], [75.33291626, 11.89514065], [75.33291626, 11.89542103], [75.33235931, 11.89542103], [75.33235931, 11.89625072], [75.33207703, 11.89625072], [75.33207703, 11.89653111], [75.33181, 11.89653111], [75.33181, 11.89681053], [75.33152771, 11.89680672], [75.33152771, 11.8973608], [75.33125305, 11.8973608], [75.33125305, 11.89764118], [75.33097076, 11.89764118], [75.33097076, 11.89792061], [75.33069611, 11.89791679], [75.33069611, 11.89819527], [75.33041382, 11.89819527], [75.33041382, 11.89847279], [75.33013916, 11.89847088], [75.33013916, 11.89875126], [75.32930756, 11.89875126], [75.32930756, 11.89903069], [75.3290329, 11.89903069], [75.3290329, 11.8993206], [75.32875061, 11.89930534], [75.32875061, 11.89986134], [75.32818604, 11.89986134], [75.32818604, 11.90013885], [75.32763672, 11.90013885], [75.32763672, 11.90069485], [75.32707977, 11.90069008], [75.32707977, 11.90125084], [75.32681274, 11.90125084], [75.32681274, 11.90152931], [75.32624817, 11.9015274], [75.32624817, 11.9020834], [75.32596588, 11.90207195], [75.32596588, 11.90236092], [75.32567596, 11.90236092], [75.32567596, 11.90292168], [75.32541656, 11.90291691], [75.32541656, 11.90319538], [75.32514191, 11.90319538], [75.32514191, 11.90347099], [75.32485962, 11.90347099], [75.32485962, 11.90375137], [75.32290649, 11.90375137], [75.32290649, 11.90402889], [75.32235718, 11.90402889], [75.32235718, 11.90431023], [75.32180786, 11.90430546], [75.32180786, 11.90458298], [75.32069397, 11.90458298], [75.32069397, 11.90486145], [75.32041931, 11.90486145], [75.32041931, 11.90513897], [75.31986237, 11.90513897], [75.31986237, 11.90486145], [75.31960297, 11.90486145], [75.31903076, 11.90486145], [75.31903076, 11.90513897], [75.31846619, 11.90513039], [75.31846619, 11.9054203], [75.31819153, 11.90541744], [75.31819153, 11.90597439], [75.31847382, 11.90597439], [75.31846619, 11.9064703], [75.31846619, 11.90680981], [75.31835938, 11.90680504], [75.31819153, 11.90680504], [75.31819153, 11.9073], [75.31819153, 11.90764046], [75.31807709, 11.90764046], [75.31791687, 11.90764046], [75.31791687, 11.90812016], [75.31791687, 11.90847111], [75.31846619, 11.9084692], [75.31846619, 11.90874958], [75.31874847, 11.90874958], [75.31874847, 11.90931034], [75.31903076, 11.90931034], [75.31903076, 11.90986156], [75.31931305, 11.90986156], [75.31931305, 11.91014194], [75.31958008, 11.91014004], [75.31958008, 11.91069412], [75.31987, 11.91069126], [75.31987, 11.9112606], [75.32013702, 11.9112606], [75.32013702, 11.91152954], [75.31986237, 11.91152763], [75.31986237, 11.9131937], [75.31958008, 11.9131918], [75.31958008, 11.91403008], [75.31930542, 11.91402817], [75.31930542, 11.91458416], [75.31903076, 11.91458035], [75.31903076, 11.91514015], [75.31874847, 11.91514015], [75.31874847, 11.91597176], [75.31846619, 11.91596985], [75.31846619, 11.91625023], [75.31819153, 11.91625023], [75.31819153, 11.91681099], [75.31791687, 11.91680622], [75.31791687, 11.91736221], [75.31764221, 11.91736031], [75.31764221, 11.91763973], [75.31735992, 11.91763783], [75.31735992, 11.91819382], [75.3170929, 11.91819191], [75.3170929, 11.91875267], [75.31680298, 11.91875267], [75.31680298, 11.91903114], [75.31652832, 11.91903114], [75.31652832, 11.91931057], [75.31625366, 11.9193058], [75.31625366, 11.91958237], [75.31597137, 11.91958046], [75.31597137, 11.91986275], [75.31569672, 11.91986275], [75.31569672, 11.92042065], [75.31541443, 11.92041588], [75.31541443, 11.92069435], [75.31513977, 11.92069435], [75.31513977, 11.92097282], [75.31485748, 11.92096996], [75.31485748, 11.92153072], [75.31458282, 11.92153072], [75.31458282, 11.9218111], [75.31430817, 11.92180443], [75.31430817, 11.92208195], [75.31402588, 11.92208195], [75.31402588, 11.92236137], [75.31373596, 11.92236137], [75.31373596, 11.92320156], [75.31346893, 11.92319489], [75.31346893, 11.92347336], [75.31318665, 11.92346954], [75.31318665, 11.92375088], [75.31291962, 11.92375088], [75.31291962, 11.92431068], [75.31263733, 11.92430687], [75.31263733, 11.92458344], [75.31236267, 11.92457962], [75.31236267, 11.92486095], [75.31208038, 11.92486095], [75.31208038, 11.92514133], [75.31181335, 11.92514133], [75.31181335, 11.92542076], [75.31153107, 11.92541695], [75.31153107, 11.92597294], [75.31124878, 11.92597103], [75.31124878, 11.92625999], [75.31096649, 11.92625999], [75.31096649, 11.92680931], [75.31069183, 11.92680454], [75.31069183, 11.92736053], [75.31041718, 11.92736053], [75.31041718, 11.92764091], [75.31014252, 11.92764091], [75.31014252, 11.92791939], [75.30986023, 11.92791653], [75.30986023, 11.92847347], [75.3095932, 11.92847061], [75.3095932, 11.92875099], [75.30930328, 11.92875099], [75.30930328, 11.92903233], [75.30902863, 11.9290266], [75.30902863, 11.9295826], [75.30874634, 11.92958069], [75.30874634, 11.93014145], [75.30847168, 11.93014145], [75.30847168, 11.93042183], [75.30819702, 11.93041706], [75.30819702, 11.93069458], [75.30791473, 11.93069458], [75.30791473, 11.93097115], [75.30764008, 11.93097115], [75.30764008, 11.93153191], [75.30735779, 11.93152714], [75.30735779, 11.93208313], [75.30719757, 11.93208313], [75.30708313, 11.93208313], [75.30706787, 11.93247986], [75.30706024, 11.93264198], [75.30680847, 11.93263912], [75.30680847, 11.9327898], [75.30680847, 11.93319321], [75.30652618, 11.9331913], [75.30652618, 11.9337492], [75.30636597, 11.9337492], [75.30625153, 11.9337492], [75.30625153, 11.9342804], [75.30596924, 11.93430519], [75.30596924, 11.93486214], [75.30568695, 11.93485928], [75.30568695, 11.93513966], [75.30541992, 11.93513966], [75.30541992, 11.93543053], [75.30513763, 11.93541527], [75.30513763, 11.93569565], [75.30486298, 11.93569565], [75.30486298, 11.93597221], [75.30458069, 11.93596935], [75.30458069, 11.93653202], [75.30430603, 11.93653202], [75.30430603, 11.93680954], [75.30403137, 11.93680573], [75.30403137, 11.9370842], [75.30347443, 11.9370842], [75.30347443, 11.93736172], [75.30319214, 11.93735886], [75.30319214, 11.93764019], [75.30291748, 11.93764019], [75.30291748, 11.93791962], [75.30263519, 11.93791771], [75.30264282, 11.93875027], [75.30236053, 11.93875027], [75.30236053, 11.93902969], [75.30179596, 11.93902969], [75.30179596, 11.93931007], [75.30152893, 11.93930626], [75.30152893, 11.93958378], [75.30097198, 11.93958378], [75.30097198, 11.93986225], [75.30069733, 11.93986225], [75.30069733, 11.94069386], [75.30041504, 11.94069386], [75.30041504, 11.94124985], [75.30014038, 11.94124126], [75.30014038, 11.94153023], [75.29985809, 11.94153023], [75.29985809, 11.9426403], [75.29930878, 11.9426403], [75.29930878, 11.94292068], [75.29902649, 11.94291592], [75.29902649, 11.94347191], [75.29873657, 11.94347], [75.29873657, 11.94375038], [75.29930878, 11.94375038], [75.29930878, 11.94403267], [75.29985809, 11.9440279], [75.29985809, 11.94430637], [75.30069733, 11.94430637], [75.30069733, 11.94458199], [75.30124664, 11.94458199], [75.30124664, 11.94514275], [75.30179596, 11.94514275], [75.30179596, 11.94542122], [75.30208588, 11.94541645], [75.30208588, 11.94597244], [75.30236053, 11.94596958], [75.30236053, 11.94624996], [75.30291748, 11.94624996], [75.30291748, 11.94681072], [75.30319214, 11.94680691], [75.30319214, 11.94708538], [75.30541992, 11.94708538], [75.30541992, 11.94680691], [75.30596924, 11.94681072], [75.30596924, 11.9465313], [75.30652618, 11.9465313], [75.30652618, 11.94624996], [75.30735779, 11.94624996], [75.30735779, 11.94596958], [75.30902863, 11.94597244], [75.30902863, 11.94569397], [75.30958557, 11.94569397], [75.30958557, 11.94541645], [75.31041718, 11.94542122], [75.31041718, 11.94514275], [75.31096649, 11.94514275], [75.31096649, 11.94486046], [75.31153107, 11.94486237], [75.31153107, 11.94458199], [75.31208038, 11.94458199], [75.31208038, 11.94430637], [75.31291962, 11.94430637], [75.31291962, 11.9440279], [75.31346893, 11.94403267], [75.31346893, 11.94375038], [75.31402588, 11.94375038], [75.31402588, 11.94347], [75.31458282, 11.94347191], [75.31458282, 11.94319439], [75.31485748, 11.94319439], [75.31485748, 11.94291592], [75.3154068, 11.94292068], [75.3154068, 11.9426403], [75.31597137, 11.9426403], [75.31597137, 11.94235992], [75.31652832, 11.94235992], [75.31652832, 11.94207954], [75.31708527, 11.94208431], [75.31708527, 11.94180584], [75.31764221, 11.94181061], [75.31764221, 11.94153023], [75.31819153, 11.94153023], [75.31819153, 11.94124126], [75.31903076, 11.94124985], [75.31903076, 11.94097233], [75.31958008, 11.94097233], [75.31958008, 11.94069386], [75.32041931, 11.94069386], [75.32041931, 11.94041634], [75.32096863, 11.94042015], [75.32096863, 11.94013977], [75.32180786, 11.94013977], [75.32180786, 11.93986034], [75.32236481, 11.93986225], [75.32236481, 11.93958378], [75.32291412, 11.93958378], [75.32291412, 11.93930626], [75.32347107, 11.93931007], [75.32347107, 11.93902969], [75.32402802, 11.93902969], [75.32402802, 11.93875027], [75.32459259, 11.93875027], [75.32458496, 11.93847179], [75.32514191, 11.93847179], [75.32514191, 11.9382], [75.32596588, 11.9382], [75.32596588, 11.93791962], [75.32653046, 11.93791962], [75.32653046, 11.93764019], [75.32707977, 11.93764019], [75.32707977, 11.93735886], [75.32763672, 11.93736172], [75.32763672, 11.9370842], [75.32819366, 11.9370842], [75.32819366, 11.93680573], [75.32875061, 11.93680954], [75.32875061, 11.93653202], [75.32930756, 11.93653202], [75.32930756, 11.93624973], [75.33013916, 11.93624973], [75.33013916, 11.93596935], [75.33152771, 11.93597221], [75.33152771, 11.93569565], [75.33235931, 11.93569565], [75.33235931, 11.93541527], [75.33291626, 11.93543053], [75.33291626, 11.93513966], [75.33347321, 11.93513966], [75.33347321, 11.93485928], [75.33403015, 11.93486214], [75.33403015, 11.93458366], [75.33430481, 11.93458366], [75.33430481, 11.93430519], [75.33486938, 11.93430996], [75.33486938, 11.93402958], [75.3354187, 11.93402958], [75.3354187, 11.9337492], [75.33625031, 11.9337492], [75.33625031, 11.93347073], [75.33680725, 11.93347359], [75.33680725, 11.93291664], [75.33735657, 11.93292046], [75.33735657, 11.93264198], [75.33763885, 11.93264198], [75.33763885, 11.93236065], [75.33875275, 11.93236065], [75.33875275, 11.93208122], [75.33985901, 11.93208313], [75.33985901, 11.93180466], [75.34152985, 11.93181038], [75.34152985, 11.93153191], [75.34358978, 11.93153191], [75.34513855, 11.93153191], [75.34513855, 11.93181038], [75.3456955, 11.93180466], [75.3456955, 11.93208313], [75.34597015, 11.93208313], [75.34597015, 11.93180466], [75.34625244, 11.93181038], [75.34625244, 11.93153191], [75.34680939, 11.93153191], [75.34680939, 11.93125057], [75.34707642, 11.93125057], [75.34707642, 11.93069077], [75.3473587, 11.93069458], [75.3473587, 11.93013859], [75.34792328, 11.93014145], [75.34792328, 11.93042183], [75.3501358, 11.93041706], [75.3501358, 11.93069458], [75.35124969, 11.93069458], [75.35124969, 11.93097115], [75.3520813, 11.93097115], [75.3520813, 11.93125057], [75.35263824, 11.93125057], [75.35263824, 11.93153191], [75.3529129, 11.93153191], [75.3529129, 11.93125057], [75.35346985, 11.93125057], [75.35346985, 11.93097115], [75.35375214, 11.93097115], [75.35375214, 11.93069458], [75.35430908, 11.93069458], [75.35430908, 11.93013859], [75.3548584, 11.93014145], [75.3548584, 11.92986107], [75.35514069, 11.92986107], [75.35514069, 11.92930031], [75.35569763, 11.92930508], [75.35569763, 11.9290266], [75.35624695, 11.92903233], [75.35624695, 11.92875099], [75.35652924, 11.92875099], [75.35652924, 11.92847061], [75.35874939, 11.92847061], [75.35874939, 11.92875099], [75.35930634, 11.92875099], [75.35930634, 11.92903233], [75.35958099, 11.92903233], [75.35958099, 11.92875099], [75.35986328, 11.92875099], [75.35986328, 11.92903233], [75.36042023, 11.9290266], [75.36042023, 11.92930508], [75.36152649, 11.92930508], [75.36152649, 11.9295826], [75.36235809, 11.92958069], [75.36235809, 11.92986107], [75.36264038, 11.92986107], [75.36264038, 11.93014145], [75.36347198, 11.93014145], [75.36347198, 11.93042183], [75.36402893, 11.93041706], [75.36402893, 11.93097115], [75.36429596, 11.93097115], [75.36429596, 11.93153191], [75.36486053, 11.93152714], [75.36486053, 11.93208313], [75.36513519, 11.93208313], [75.36513519, 11.93236065], [75.36541748, 11.93236065], [75.36541748, 11.93347359], [75.36569214, 11.93347073], [75.36569214, 11.9337492], [75.3659668, 11.9337492], [75.3659668, 11.93430996], [75.36624908, 11.93430996], [75.36624908, 11.93513966], [75.36653137, 11.93513966], [75.36653137, 11.93569565], [75.36708069, 11.93569565], [75.36708069, 11.93597221], [75.36763763, 11.93596935], [75.36763763, 11.93624973], [75.36791992, 11.93624973], [75.36791992, 11.93653202], [75.36818695, 11.93653202], [75.36818695, 11.93680954], [75.36846924, 11.93680954], [75.36846924, 11.93791962], [75.36875153, 11.93791962], [75.36875153, 11.9382], [75.36930847, 11.9382], [75.36930847, 11.93847179], [75.36985779, 11.93847179], [75.36985779, 11.93875027], [75.37014008, 11.93875027], [75.37014008, 11.93902969], [75.3704071, 11.93902969], [75.3704071, 11.93931007], [75.37152863, 11.93930626], [75.37152863, 11.93958378], [75.37208557, 11.93958378], [75.37208557, 11.93930626], [75.37264252, 11.93931007], [75.37264252, 11.93902969], [75.37374878, 11.93902969], [75.37374878, 11.93875027], [75.37401581, 11.93875027], [75.37401581, 11.93847179], [75.37458038, 11.93847179], [75.37458038, 11.9382], [75.37486267, 11.9382], [75.37486267, 11.93791962], [75.37513733, 11.93791962], [75.37513733, 11.93735886], [75.37541962, 11.93736172], [75.37541962, 11.93624973], [75.37513733, 11.93624973], [75.37513733, 11.93569088], [75.37569427, 11.93569565], [75.37569427, 11.93458366], [75.37596893, 11.93458366], [75.37596893, 11.93291664], [75.37625122, 11.93292046], [75.37625122, 11.93125057], [75.37652588, 11.93125057], [75.37652588, 11.93069077], [75.37680817, 11.93069458], [75.37680817, 11.92986107], [75.37708282, 11.92986107], [75.37708282, 11.92903233], [75.37735748, 11.92903233], [75.37735748, 11.92819118], [75.37763977, 11.928195], [75.37763977, 11.92736053], [75.37819672, 11.92736053], [75.37819672, 11.92680454], [75.37847137, 11.92680931], [75.37847137, 11.92653084], [75.3795929, 11.92653084], [75.3795929, 11.92625999], [75.38153076, 11.92625999], [75.38153076, 11.92653084], [75.38263702, 11.92653084], [75.38263702, 11.92680931], [75.38318634, 11.92680931], [75.38318634, 11.92653084], [75.3840332, 11.92653084], [75.3840332, 11.92625999], [75.38430786, 11.92625999], [75.38430786, 11.92597103], [75.38486481, 11.92597294], [75.38486481, 11.92569542], [75.38541412, 11.92569542], [75.38541412, 11.92486095], [75.38513947, 11.92486095], [75.38513947, 11.92375088], [75.38485718, 11.92375088], [75.38485718, 11.9226408], [75.38458252, 11.9226408], [75.38458252, 11.9218111], [75.38430786, 11.9218111], [75.38430786, 11.9212513], [75.38458252, 11.9212513], [75.38458252, 11.92096996], [75.38430786, 11.92097282], [75.38430786, 11.92069435], [75.38458252, 11.92069435], [75.38458252, 11.91819382], [75.38486481, 11.91819382], [75.38486481, 11.91763783], [75.38513947, 11.91763973], [75.38513947, 11.91652966], [75.38625336, 11.91652966], [75.38625336, 11.91625023], [75.38652802, 11.91625023], [75.38652802, 11.91596985], [75.38708496, 11.91597176], [75.38708496, 11.91569424], [75.38764191, 11.91569424], [75.38764191, 11.91541576], [75.38791656, 11.91542053], [75.38791656, 11.91486168], [75.38846588, 11.91486168], [75.38846588, 11.91458035], [75.38931274, 11.91458035], [75.38931274, 11.91486168], [75.38957977, 11.91486168], [75.38957977, 11.91458035], [75.39013672, 11.91458035], [75.39013672, 11.91486168], [75.39125061, 11.91486168], [75.39125061, 11.91514015], [75.39208984, 11.91514015], [75.39208984, 11.91542053], [75.39319611, 11.91541576], [75.39319611, 11.91569424], [75.39375305, 11.91568947], [75.39375305, 11.91625023], [75.39430237, 11.91625023], [75.39430237, 11.91652966], [75.39514923, 11.91652966], [75.39514923, 11.91681099], [75.39569092, 11.91681099], [75.39569092, 11.91652966], [75.39624786, 11.91652966], [75.39624786, 11.91625023], [75.39679718, 11.91625023], [75.39679718, 11.91596985], [75.39763641, 11.91597176], [75.39763641, 11.91569424], [75.39819336, 11.91569424], [75.39819336, 11.91541576], [75.39930725, 11.91541576], [75.39930725, 11.91597176], [75.39958191, 11.91596985], [75.39958191, 11.91652966], [75.3998642, 11.91652775], [75.3998642, 11.91708374], [75.40013885, 11.91707134], [75.40013885, 11.91763973], [75.3998642, 11.91763783], [75.3998642, 11.91819382], [75.39958191, 11.91819191], [75.39958191, 11.91875267], [75.39930725, 11.91875267], [75.39930725, 11.91931057], [75.39902496, 11.9193058], [75.39902496, 11.91958237], [75.39847565, 11.91958237], [75.39847565, 11.9193058], [75.39763641, 11.91931057], [75.39763641, 11.91903114], [75.3970871, 11.91903114], [75.3970871, 11.91875267], [75.39653015, 11.91875267], [75.39653015, 11.91903114], [75.39485931, 11.91903114], [75.39485931, 11.91931057], [75.39458466, 11.9193058], [75.39458466, 11.91958237], [75.39263916, 11.91958237], [75.39263916, 11.9193058], [75.39208984, 11.91931057], [75.39208984, 11.91875267], [75.3915329, 11.91875267], [75.3915329, 11.91847038], [75.39097595, 11.91847229], [75.39097595, 11.91819382], [75.39013672, 11.91819382], [75.39013672, 11.9179163], [75.38986206, 11.91792107], [75.38986206, 11.91763973], [75.38957977, 11.91763973], [75.38957977, 11.91792107], [75.38931274, 11.91792107], [75.38931274, 11.91903114], [75.38957977, 11.91903114], [75.38957977, 11.91986275], [75.38986206, 11.91985989], [75.38986206, 11.92097282], [75.39013672, 11.92096996], [75.39013672, 11.92292118], [75.39041901, 11.92291737], [75.39041901, 11.92347336], [75.39068604, 11.92346954], [75.39068604, 11.92375088], [75.39097595, 11.92375088], [75.39097595, 11.92431068], [75.39125061, 11.92430687], [75.39125061, 11.92458344], [75.39097595, 11.92457962], [75.39097595, 11.92486095], [75.39125061, 11.92486095], [75.39125061, 11.92542076], [75.39097595, 11.92541695], [75.39097595, 11.92597294], [75.39068604, 11.92597103], [75.39068604, 11.92680931], [75.39041901, 11.92680454], [75.39041901, 11.92736053], [75.39013672, 11.92736053], [75.39013672, 11.92791939], [75.38986206, 11.92791939], [75.38986206, 11.92875099], [75.38957977, 11.92875099], [75.38957977, 11.92903233], [75.38903046, 11.9290266], [75.38903046, 11.9295826], [75.38874817, 11.92958069], [75.38874817, 11.92986107], [75.38819122, 11.92986107], [75.38819122, 11.93014145], [75.38764191, 11.93014145], [75.38764191, 11.93042183], [75.38652802, 11.93041706], [75.38652802, 11.93069458], [75.38625336, 11.93069458], [75.38625336, 11.93097115], [75.38595581, 11.93097115], [75.38595581, 11.93125057], [75.38485718, 11.93125057], [75.38485718, 11.93153191], [75.38458252, 11.93153191], [75.38458252, 11.93125057], [75.38375092, 11.93125057], [75.38375092, 11.93097115], [75.38319397, 11.93097115], [75.38319397, 11.93069458], [75.38263702, 11.93069458], [75.38263702, 11.93041706], [75.38181305, 11.93042183], [75.38181305, 11.93014145], [75.38124847, 11.93014145], [75.38124847, 11.92986107], [75.38014984, 11.92986107], [75.38014984, 11.93014145], [75.37875366, 11.93013859], [75.37875366, 11.93069458], [75.37847137, 11.93069077], [75.37847137, 11.93236065], [75.37875366, 11.93236065], [75.37875366, 11.93486214], [75.37847137, 11.93485928], [75.37847137, 11.93543053], [75.37819672, 11.93543053], [75.37819672, 11.93931007], [75.37791443, 11.93930626], [75.37791443, 11.93958378], [75.37763977, 11.93958378], [75.37763977, 11.93986225], [75.37708282, 11.93986034], [75.37708282, 11.94013977], [75.37680817, 11.94013977], [75.37680817, 11.94042015], [75.37625122, 11.94041634], [75.37625122, 11.94069386], [75.37569427, 11.94069386], [75.37569427, 11.94097233], [75.37541962, 11.94097233], [75.37541962, 11.94124985], [75.37486267, 11.94124126], [75.37486267, 11.94181061], [75.37319183, 11.94180584], [75.37319183, 11.94208431], [75.37291718, 11.94207954], [75.37291718, 11.94403267], [75.37264252, 11.94403267], [75.37264252, 11.94681072], [75.37291718, 11.94681072], [75.37291718, 11.94764137], [75.37319183, 11.94763756], [75.37319183, 11.94847298], [75.37346649, 11.94847012], [75.37346649, 11.94903088], [75.37374878, 11.94903088], [75.37374878, 11.95014095], [75.37401581, 11.95014095], [75.37401581, 11.95042992], [75.37374878, 11.95041656], [75.37374878, 11.95069504], [75.37401581, 11.95069027], [75.37401581, 11.95181084], [75.37431335, 11.95181084], [75.37431335, 11.95375061], [75.37458038, 11.9537487], [75.37458038, 11.95569515], [75.37486267, 11.95569134], [75.37486267, 11.95653152], [75.37458038, 11.95653152], [75.37458038, 11.9568119], [75.37430573, 11.95680523], [75.37430573, 11.95708275], [75.37374878, 11.95708275], [75.37374878, 11.95736122], [75.37347412, 11.95736122], [75.37347412, 11.95680523], [75.37319183, 11.9568119], [75.37319183, 11.95597076], [75.37291718, 11.95597267], [75.37291718, 11.95569515], [75.37264252, 11.95569515], [75.37264252, 11.95541668], [75.37236023, 11.95541859], [75.37236023, 11.95458126], [75.37208557, 11.95458317], [75.37208557, 11.95402908], [75.37180328, 11.95403099], [75.37180328, 11.95347118], [75.37152863, 11.95347309], [75.37152863, 11.95319462], [75.37124634, 11.95319462], [75.37124634, 11.9529171], [75.37097931, 11.95292091], [75.37097931, 11.95264053], [75.37069702, 11.95264053], [75.37069702, 11.95207977], [75.37041473, 11.95208263], [75.37041473, 11.95180511], [75.37014008, 11.95181084], [75.37014008, 11.95125103], [75.36958313, 11.95125103], [75.36958313, 11.95069027], [75.36930847, 11.95069504], [75.36930847, 11.95041656], [75.36902618, 11.95042992], [75.36902618, 11.95014095], [75.36846924, 11.95014095], [75.36846924, 11.94986057], [75.36791992, 11.94986057], [75.36791992, 11.94958305], [75.36763763, 11.94958305], [75.36763763, 11.94930363], [75.36708069, 11.94931126], [75.36708069, 11.94903088], [75.36680603, 11.94903088], [75.36680603, 11.94875145], [75.36653137, 11.94875145], [75.36653137, 11.94847012], [75.36597443, 11.94847298], [75.36597443, 11.94819546], [75.36569214, 11.94819546], [75.36569214, 11.94791603], [75.36514282, 11.94791889], [75.36514282, 11.94736862], [75.36458588, 11.94736862], [75.36458588, 11.94681072], [75.36429596, 11.94681072], [75.36429596, 11.9465313], [75.36402893, 11.9465313], [75.36402893, 11.94624996], [75.36374664, 11.94624996], [75.36374664, 11.94596958], [75.36347198, 11.94597244], [75.36347198, 11.94541645], [75.36319733, 11.94542122], [75.36319733, 11.94486046], [75.36291504, 11.94486237], [75.36291504, 11.94430637], [75.36264038, 11.94430637], [75.36264038, 11.94347191], [75.36235809, 11.94347191], [75.36235809, 11.94235992], [75.36207581, 11.94235992], [75.36207581, 11.94153023], [75.36180878, 11.94153023], [75.36180878, 11.94097042], [75.36152649, 11.94097233], [75.36152649, 11.94069386], [75.36180878, 11.94069386], [75.36180878, 11.93819427], [75.36207581, 11.9382], [75.36207581, 11.93543053], [75.36180878, 11.93543053], [75.36180878, 11.93430996], [75.36152649, 11.93430996], [75.36152649, 11.9337492], [75.36125183, 11.9337492], [75.36125183, 11.93347073], [75.36096954, 11.93347359], [75.36096954, 11.93319321], [75.36042023, 11.93319321], [75.36042023, 11.93263912], [75.36013794, 11.93264198], [75.36013794, 11.93236065], [75.35958099, 11.93236065], [75.35958099, 11.93208122], [75.35930634, 11.93208313], [75.35930634, 11.93180466], [75.35874939, 11.93181038], [75.35874939, 11.93153191], [75.35708618, 11.93153191], [75.35708618, 11.93125057], [75.35679626, 11.93125057], [75.35679626, 11.93153191], [75.35569763, 11.93153191], [75.35569763, 11.93181038], [75.35541534, 11.93180466], [75.35541534, 11.93208313], [75.3548584, 11.93208122], [75.3548584, 11.93236065], [75.35430908, 11.93236065], [75.35430908, 11.93264198], [75.35346985, 11.93264198], [75.35346985, 11.93292046], [75.3529129, 11.93291664], [75.3529129, 11.93319321], [75.3520813, 11.93319321], [75.3520813, 11.93347359], [75.35069275, 11.93347073], [75.35069275, 11.9337492], [75.35041809, 11.9337492], [75.35041809, 11.93402958], [75.34958649, 11.93402958], [75.34958649, 11.93430996], [75.3484726, 11.93430519], [75.3484726, 11.93458366], [75.34708405, 11.93458366], [75.34708405, 11.93486214], [75.3465271, 11.93485928], [75.3465271, 11.93513966], [75.34570313, 11.93513966], [75.34570313, 11.93543053], [75.34513855, 11.93541527], [75.34513855, 11.93569565], [75.34430695, 11.93569565], [75.34430695, 11.93597221], [75.34375, 11.93596935], [75.34375, 11.93624973], [75.34319305, 11.93624973], [75.34319305, 11.93653202], [75.3429184, 11.93653202], [75.3429184, 11.93680954], [75.34263611, 11.93680573], [75.34263611, 11.9370842], [75.34208679, 11.93708134], [75.34208679, 11.93764019], [75.34179688, 11.93764019], [75.34179688, 11.9382], [75.34124756, 11.9382], [75.34124756, 11.93847179], [75.3409729, 11.93847179], [75.3409729, 11.93875027], [75.34069824, 11.93875027], [75.34069824, 11.93902969], [75.34041595, 11.93902969], [75.34041595, 11.93931007], [75.3401413, 11.93930626], [75.3401413, 11.93958378], [75.33958435, 11.93958378], [75.33958435, 11.93986225], [75.33930206, 11.93986034], [75.33930206, 11.94013977], [75.3390274, 11.94013977], [75.3390274, 11.94042015], [75.33847046, 11.94041634], [75.33847046, 11.94069386], [75.33791351, 11.94069386], [75.33791351, 11.94124985], [75.33763885, 11.94124126], [75.33763885, 11.94153023], [75.33735657, 11.94153023], [75.33735657, 11.94181061], [75.33708191, 11.94180584], [75.33708191, 11.94208431], [75.33680725, 11.94207954], [75.33680725, 11.94235992], [75.33653259, 11.94235992], [75.33653259, 11.9426403], [75.33598328, 11.9426403], [75.33598328, 11.94292068], [75.33569336, 11.94291592], [75.33569336, 11.94319439], [75.3354187, 11.94319439], [75.3354187, 11.94347191], [75.3345871, 11.94347], [75.3345871, 11.94375038], [75.33347321, 11.94375038], [75.33347321, 11.94403267], [75.33235931, 11.9440279], [75.33235931, 11.94430637], [75.32875061, 11.94430637], [75.32875061, 11.9440279], [75.32847595, 11.9440279], [75.32847595, 11.94430637], [75.32736206, 11.94430637], [75.32736206, 11.94458199], [75.32707977, 11.94458199], [75.32707977, 11.94430637], [75.32680511, 11.94430637], [75.32680511, 11.94458199], [75.32653046, 11.94458199], [75.32653046, 11.94430637], [75.32597351, 11.94430637], [75.32597351, 11.94458199], [75.32569122, 11.94458199], [75.32569122, 11.94486237], [75.32514191, 11.94486046], [75.32514191, 11.94514275], [75.32430267, 11.94514275], [75.32430267, 11.94542122], [75.32402802, 11.94542122], [75.32402802, 11.94514275], [75.32375336, 11.94514275], [75.32375336, 11.94542122], [75.32096863, 11.94541645], [75.32096863, 11.94569016], [75.31930542, 11.94569397], [75.31930542, 11.94597244], [75.31874847, 11.94596958], [75.31874847, 11.94624996], [75.31791687, 11.94624996], [75.31791687, 11.9465313], [75.31735992, 11.9465313], [75.31735992, 11.94681072], [75.31680298, 11.94680691], [75.31680298, 11.94708538], [75.31652832, 11.94707966], [75.31652832, 11.94764137], [75.3170929, 11.94764137], [75.3170929, 11.94791889], [75.31735992, 11.94791603], [75.31735992, 11.94847298], [75.31764221, 11.94847012], [75.31764221, 11.94903088], [75.31791687, 11.94903088], [75.31791687, 11.95125103], [75.31764221, 11.95125103], [75.31764221, 11.95208263], [75.31735992, 11.95208263], [75.31735992, 11.95236111], [75.3170929, 11.95236111], [75.3170929, 11.95264053], [75.31680298, 11.95264053], [75.31680298, 11.95292091], [75.31652832, 11.95292091], [75.31652832, 11.95375061], [75.31624603, 11.95375061], [75.31624603, 11.95403099], [75.31597137, 11.95402908], [75.31597137, 11.95569515], [75.31569672, 11.95569515], [75.31569672, 11.95597267], [75.3154068, 11.95597076], [75.3154068, 11.95653152], [75.31513977, 11.95653152], [75.31513977, 11.9568119], [75.31485748, 11.95680523], [75.31485748, 11.95708275], [75.31458282, 11.95708084], [75.31458282, 11.95792198], [75.31430817, 11.95791721], [75.31430817, 11.95819473], [75.31402588, 11.95819473], [75.31402588, 11.9584713], [75.31373596, 11.9584713], [75.31373596, 11.95903015], [75.31346893, 11.95903015], [75.31346893, 11.95930958], [75.31319427, 11.95930481], [75.31319427, 11.95958328], [75.31291962, 11.95958138], [75.31291962, 11.96013927], [75.31263733, 11.96013927], [75.31263733, 11.96069336], [75.31236267, 11.96069145], [75.31236267, 11.96124935], [75.31208038, 11.96124935], [75.31208038, 11.96237087], [75.31180573, 11.96236229], [75.31180573, 11.96347237], [75.31153107, 11.96347237], [75.31153107, 11.96375179], [75.31067657, 11.96375179], [75.31067657, 11.96403027], [75.31041718, 11.96403027], [75.31041718, 11.96430969], [75.31014252, 11.96430588], [75.31014252, 11.96569443], [75.31041718, 11.96569443], [75.31041718, 11.9673624], [75.31014252, 11.96735954], [75.31014252, 11.96763992], [75.30986023, 11.96763992], [75.30986023, 11.96903038], [75.30958557, 11.96902847], [75.3095932, 11.96986008], [75.30930328, 11.96986008], [75.30930328, 11.97007179], [75.30902863, 11.97014046], [75.30902863, 11.97042274], [75.3079071, 11.97042274], [75.3079071, 11.96986008], [75.30764008, 11.96986008], [75.30764008, 11.9695797], [75.30680847, 11.9695797], [75.30680847, 11.97014046], [75.30652618, 11.97014046], [75.30652618, 11.97042274], [75.30625153, 11.97041607], [75.30625153, 11.97069359], [75.30596924, 11.97069168], [75.30596924, 11.97124958], [75.30430603, 11.97124958], [75.30430603, 11.97097015], [75.30403137, 11.97097206], [75.30403137, 11.97069359], [75.30374908, 11.97069359], [75.30374908, 11.96875], [75.30486298, 11.96875], [75.30486298, 11.96903038], [75.30541992, 11.96903038], [75.30541992, 11.96846962], [75.30569458, 11.96847153], [75.30569458, 11.96791553], [75.30596924, 11.9679203], [75.30596924, 11.96763992], [75.30625153, 11.96763992], [75.30625153, 11.96735954], [75.30652618, 11.9673624], [75.30652618, 11.96708393], [75.30708313, 11.96708393], [75.30708313, 11.96680641], [75.30735779, 11.96681023], [75.30735779, 11.96652985], [75.30764008, 11.96652985], [75.30764008, 11.96625042], [75.3079071, 11.96625042], [75.3079071, 11.96541119], [75.30764008, 11.96541786], [75.30764008, 11.96514034], [75.30735779, 11.96514034], [75.30735779, 11.96486187], [75.30708313, 11.96486187], [75.30708313, 11.96458054], [75.30652618, 11.96458435], [75.30652618, 11.96430588], [75.30625153, 11.96430969], [75.30625153, 11.96375179], [75.30652618, 11.96375179], [75.30652618, 11.96319103], [75.30680847, 11.9631958], [75.30680847, 11.96291542], [75.30735779, 11.96292019], [75.30735779, 11.96263981], [75.30760956, 11.96263981], [75.30764008, 11.96237087], [75.30819702, 11.96237087], [75.30819702, 11.96208096], [75.30874634, 11.96208382], [75.30874634, 11.9618063], [75.31014252, 11.96181011], [75.31014252, 11.96152973], [75.31041718, 11.96152973], [75.31041718, 11.96041965], [75.31067657, 11.96041965], [75.31067657, 11.95985889], [75.31097412, 11.9598608], [75.31097412, 11.95930481], [75.31124878, 11.95930958], [75.31124878, 11.95903015], [75.31153107, 11.95903015], [75.31153107, 11.95875072], [75.31181335, 11.95875072], [75.31181335, 11.9584713], [75.31236267, 11.9584713], [75.31236267, 11.95819473], [75.31291962, 11.95819473], [75.31291962, 11.95763874], [75.31318665, 11.9576416], [75.31318665, 11.95736122], [75.31346893, 11.95736122], [75.31346893, 11.95708275], [75.31402588, 11.95708275], [75.31402588, 11.95680523], [75.31430817, 11.9568119], [75.31430817, 11.95541859], [75.31458282, 11.95541859], [75.31458282, 11.95430946], [75.31485748, 11.95430946], [75.31485748, 11.95375061], [75.31513977, 11.95375061], [75.31513977, 11.95207977], [75.31541443, 11.95208263], [75.31541443, 11.95180511], [75.31513977, 11.95181084], [75.31513977, 11.95125103], [75.31485748, 11.95125103], [75.31485748, 11.9509697], [75.31458282, 11.95097256], [75.31458282, 11.95069504], [75.31430817, 11.95069504], [75.31430817, 11.95013905], [75.31458282, 11.95014095], [75.31458282, 11.94986057], [75.31430817, 11.94986057], [75.31430817, 11.94958305], [75.31346893, 11.94958305], [75.31346893, 11.94986057], [75.31318665, 11.94986057], [75.31318665, 11.95042992], [75.31291962, 11.95041656], [75.31291962, 11.95097256], [75.31263733, 11.9509697], [75.31263733, 11.95125103], [75.31236267, 11.95125103], [75.31236267, 11.95153141], [75.31208038, 11.95153141], [75.31208038, 11.95181084], [75.31180573, 11.95180511], [75.31180573, 11.95208263], [75.31124878, 11.95208263], [75.31124878, 11.95236111], [75.30986023, 11.95236111], [75.30986023, 11.95264053], [75.30930328, 11.95264053], [75.30930328, 11.95236111], [75.3079071, 11.95236111], [75.3079071, 11.95264053], [75.30764008, 11.95264053], [75.30764008, 11.95292091], [75.30708313, 11.9529171], [75.30708313, 11.95319462], [75.30680847, 11.95318127], [75.30680847, 11.95375061], [75.30652618, 11.95375061], [75.30652618, 11.95430946], [75.30625153, 11.9543047], [75.30625153, 11.95458317], [75.30652618, 11.95458126], [75.30652618, 11.95486069], [75.30680847, 11.95486069], [75.30680847, 11.95708275], [75.30652618, 11.95708275], [75.30652618, 11.95736122], [75.30625153, 11.95736122], [75.30625153, 11.95792198], [75.30596924, 11.95791721], [75.30596924, 11.95819473], [75.30569458, 11.95819473], [75.30569458, 11.9584713], [75.30513763, 11.9584713], [75.30513763, 11.95903015], [75.30486298, 11.95903015], [75.30486298, 11.95930958], [75.30458069, 11.95930481], [75.30458069, 11.95958328], [75.30403137, 11.95958138], [75.30403137, 11.96013927], [75.30374908, 11.96013927], [75.30374908, 11.96069336], [75.30347443, 11.96069336], [75.30347443, 11.96097088], [75.30319214, 11.96097088], [75.30319214, 11.96152973], [75.30291748, 11.96152973], [75.30291748, 11.96263981], [75.30263519, 11.96263981], [75.30263519, 11.9631958], [75.30208588, 11.96319103], [75.30208588, 11.96375179], [75.30179596, 11.96375179], [75.30179596, 11.96403027], [75.30152893, 11.96403027], [75.30152893, 11.96430969], [75.30124664, 11.96430588], [75.30124664, 11.96458435], [75.30097198, 11.96458054], [75.30097198, 11.96486187], [75.30069733, 11.96486187], [75.30069733, 11.96541786], [75.30041504, 11.96541786], [75.30041504, 11.96569443], [75.30014038, 11.96569061], [75.30014038, 11.96625042], [75.29985809, 11.96625042], [75.29985809, 11.96681023], [75.29958344, 11.96680641], [75.29958344, 11.96708393], [75.29930878, 11.96708202], [75.29930878, 11.9679203], [75.29902649, 11.96791553], [75.29902649, 11.96819401], [75.29875183, 11.96819401], [75.29875183, 11.96847153], [75.29846954, 11.96846962], [75.29846954, 11.96875], [75.29819489, 11.96875], [75.29819489, 11.96958447], [75.29792023, 11.9695797], [75.29792023, 11.97014046], [75.29763794, 11.9701376], [75.29763794, 11.97097206], [75.29736328, 11.97097015], [75.29736328, 11.97124958], [75.29708099, 11.97124958], [75.29708099, 11.97154045], [75.29680634, 11.97154045], [75.29680634, 11.97181129], [75.29652405, 11.97180557], [75.29652405, 11.97236156], [75.29624939, 11.97235966], [75.29624939, 11.97292137], [75.29651642, 11.97292137], [75.29651642, 11.97375011], [75.29624939, 11.97375011], [75.29624939, 11.97403145], [75.29569244, 11.97402859], [75.29569244, 11.97458458], [75.29541779, 11.97458172], [75.29541779, 11.97514057], [75.2951355, 11.97513771], [75.2951355, 11.97569466], [75.29486084, 11.9756918], [75.29486084, 11.97625065], [75.29458618, 11.97625065], [75.29458618, 11.97653103], [75.29430389, 11.97652912], [75.29430389, 11.97708321], [75.29402924, 11.97708321], [75.29402924, 11.97736073], [75.29374695, 11.97736073], [75.29374695, 11.97819519], [75.29347229, 11.97819519], [75.29347229, 11.97847271], [75.29319763, 11.9784708], [75.29319763, 11.97875118], [75.29292297, 11.97875118], [75.29292297, 11.97931194], [75.29264069, 11.97931194], [75.29264069, 11.98014069], [75.2923584, 11.98013878], [75.2923584, 11.98069477], [75.29208374, 11.98069477], [75.29208374, 11.98097324], [75.29180908, 11.98097134], [75.29180908, 11.98236084], [75.29152679, 11.98236084], [75.29152679, 11.98264122], [75.29125214, 11.98264122], [75.29125214, 11.9829216], [75.28930664, 11.9829216], [75.28930664, 11.98348045], [75.28956604, 11.98348045], [75.28956604, 11.98431015], [75.28986359, 11.98430538], [75.28986359, 11.98486137], [75.29013824, 11.98486137], [75.29013824, 11.98513889], [75.29070282, 11.98513889], [75.29070282, 11.98542023], [75.29096985, 11.98541737], [75.29096985, 11.98569489], [75.29070282, 11.98569107], [75.29070282, 11.98625183], [75.2904129, 11.98625183], [75.2904129, 11.98680973], [75.29013824, 11.98680496], [75.29013824, 11.98708344], [75.28985596, 11.98708057], [75.28985596, 11.98736095], [75.28956604, 11.98736095], [75.28956604, 11.98791981], [75.28930664, 11.9879179], [75.28930664, 11.98819256], [75.28819275, 11.98819065], [75.28819275, 11.98874855], [75.28791809, 11.98874855], [75.28791809, 11.98903179], [75.2876358, 11.98902798], [75.2876358, 11.98958397], [75.28708649, 11.98958397], [75.28708649, 11.98986244], [75.28679657, 11.98986244], [75.28679657, 11.99014187], [75.28624725, 11.99014187], [75.28624725, 11.99042034], [75.2859726, 11.99042034], [75.2859726, 11.99014187], [75.28569794, 11.99014187], [75.28569794, 11.99042034], [75.28514099, 11.99041462], [75.28514099, 11.99069405], [75.28458405, 11.99069405], [75.28458405, 11.99097157], [75.28430939, 11.99097157], [75.28430176, 11.99125195], [75.28376007, 11.99125195], [75.28376007, 11.99153042], [75.28347015, 11.99153042], [75.28347015, 11.99180984], [75.2831955, 11.99180603], [75.2831955, 11.99236202], [75.28291321, 11.99234962], [75.28291321, 11.99291992], [75.28236389, 11.99291801], [75.28236389, 11.99319363], [75.2820816, 11.99318886], [75.2820816, 11.99374962], [75.28180695, 11.99374962], [75.28180695, 11.99431133], [75.28151703, 11.99431133], [75.28152466, 11.9948597], [75.28125, 11.9948597], [75.28125, 11.99542046], [75.28097534, 11.99541569], [75.28097534, 11.99597168], [75.28070068, 11.99597168], [75.28070068, 11.99652958], [75.2804184, 11.99652767], [75.2804184, 11.99708366], [75.28070068, 11.99707985], [75.28070068, 11.9984808], [75.2804184, 11.9984808], [75.2804184, 11.99931145], [75.28013611, 11.99931145], [75.28013611, 11.99986267], [75.27986145, 11.99986267], [75.27986145, 12.00014114], [75.27986145, 12.00042057], [75.27958679, 12.00042057], [75.27958679, 12.00097179], [75.2793045, 12.00097179], [75.2793045, 12.00152874], [75.27902985, 12.00152874], [75.27902985, 12.00208473], [75.2784729, 12.00208473], [75.2784729, 12.00236034], [75.27791595, 12.00236034], [75.27791595, 12.00264072], [75.27735901, 12.00264072], [75.27735901, 12.0029211], [75.27680206, 12.00291729], [75.27680206, 12.00347328], [75.2765274, 12.00347042], [75.2765274, 12.0037508], [75.27625275, 12.0037508], [75.27625275, 12.00403118], [75.27597046, 12.00403118], [75.27597046, 12.00431061], [75.27513885, 12.00431061], [75.27513885, 12.00486088], [75.27485657, 12.00486088], [75.27485657, 12.00542068], [75.27458191, 12.00541687], [75.27458191, 12.00569534], [75.27430725, 12.00569534], [75.27430725, 12.00597286], [75.27403259, 12.00597095], [75.27403259, 12.00653076], [75.27348328, 12.00653076], [75.27348328, 12.00680923], [75.27319336, 12.00680923], [75.27319336, 12.00653076], [75.2729187, 12.00653076], [75.2729187, 12.00542068], [75.27263641, 12.00542068], [75.27263641, 12.00403118], [75.2729187, 12.00403118], [75.2729187, 12.00347042], [75.27375031, 12.00347328], [75.27375031, 12.00319481], [75.27430725, 12.00319481], [75.27430725, 12.00291729], [75.27456665, 12.0029211], [75.27456665, 12.00236034], [75.2748642, 12.00236034], [75.2748642, 12.00208473], [75.27541351, 12.00208473], [75.27541351, 12.00180435], [75.2756958, 12.00181103], [75.2756958, 12.0015192], [75.27597046, 12.00152874], [75.27597046, 12.00125122], [75.27625275, 12.00125122], [75.27625275, 12.00097179], [75.2765274, 12.00097179], [75.2765274, 12.00042057], [75.27707672, 12.00042057], [75.27707672, 12.00014114], [75.27735901, 12.00014114], [75.27735901, 11.99986267], [75.27762604, 11.99986267], [75.27762604, 11.99958038], [75.27791595, 11.99958229], [75.27791595, 11.99930573], [75.27819061, 11.99931145], [75.27819824, 11.99874973], [75.2784729, 11.99874973], [75.2784729, 11.99763966], [75.27874756, 11.99763966], [75.27874756, 11.99736023], [75.27902985, 11.99736214], [75.27902985, 11.99680614], [75.27929688, 11.99681091], [75.27929688, 11.99625015], [75.27958679, 11.99625015], [75.27958679, 11.99568939], [75.27986145, 11.99569416], [75.27986145, 11.9948616], [75.27958679, 11.9948597], [75.27958679, 11.99457932], [75.2784729, 11.99457932], [75.2784729, 11.9948597], [75.27762604, 11.9948597], [75.27762604, 11.99542046], [75.27735901, 11.99541569], [75.27735901, 11.99597168], [75.27707672, 11.99597168], [75.27707672, 11.99652958], [75.27680206, 11.99652958], [75.27680206, 11.99681091], [75.2765274, 11.99680614], [75.2765274, 11.99736214], [75.27625275, 11.99736023], [75.27625275, 11.99763966], [75.2756958, 11.99763775], [75.2756958, 11.99819374], [75.27540588, 11.99819183], [75.27540588, 11.99874973], [75.27485657, 11.99874973], [75.27485657, 11.99903107], [75.27458191, 11.99902821], [75.27458191, 11.99958229], [75.27403259, 11.99958038], [75.27403259, 11.99986267], [75.27348328, 11.99986267], [75.27348328, 12.00014114], [75.27319336, 12.00014114], [75.27319336, 12.00042057], [75.2729187, 12.0004158], [75.2729187, 12.00069427], [75.27236176, 12.00069046], [75.27236176, 12.00097179], [75.2720871, 12.00097179], [75.2720871, 12.00125122], [75.27180481, 12.00125122], [75.27180481, 12.00152874], [75.27124786, 12.0015192], [75.27124786, 12.00181103], [75.27097321, 12.00180435], [75.27097321, 12.00208473], [75.27069092, 12.00208473], [75.27069092, 12.00236034], [75.27041626, 12.00236034], [75.27041626, 12.00264072], [75.2701416, 12.00264072], [75.2701416, 12.0029211], [75.26985931, 12.00291729], [75.26985931, 12.00319481], [75.26958466, 12.00319481], [75.26958466, 12.00347328], [75.26930237, 12.00347042], [75.26930237, 12.00403118], [75.26902771, 12.00403118], [75.26902771, 12.00431061], [75.26875305, 12.00430679], [75.26875305, 12.00458336], [75.26847076, 12.00457954], [75.26847076, 12.00486088], [75.26819611, 12.00486088], [75.26819611, 12.00514126], [75.26763916, 12.00514126], [75.26763916, 12.00542068], [75.26680756, 12.00541687], [75.26680756, 12.00569534], [75.26625061, 12.00569534], [75.26625061, 12.00597286], [75.26597595, 12.00597095], [75.26597595, 12.00653076], [75.26569366, 12.00652885], [75.26569366, 12.00708294], [75.26541901, 12.00708103], [75.26541901, 12.01153183], [75.26568604, 12.01153183], [75.26568604, 12.01375198], [75.26597595, 12.01375198], [75.26597595, 12.01541996], [75.26625061, 12.01541805], [75.26625061, 12.0181942], [75.26652527, 12.0181942], [75.26652527, 12.01847172], [75.26680756, 12.01847172], [75.26680756, 12.0195837], [75.26708221, 12.01958179], [75.26708221, 12.02013969], [75.26735687, 12.02013969], [75.26735687, 12.02125168], [75.26763916, 12.02124977], [75.26763916, 12.02235985], [75.26790619, 12.02235985], [75.26790619, 12.02292061], [75.26819611, 12.02291584], [75.26819611, 12.02347183], [75.27097321, 12.02347183], [75.27097321, 12.02319431], [75.27375031, 12.02319431], [75.27375031, 12.02291584], [75.27485657, 12.02292061], [75.27485657, 12.02265167], [75.27625275, 12.02265167], [75.27625275, 12.02235985], [75.27735901, 12.02235985], [75.27735901, 12.02208424], [75.27819061, 12.02208424], [75.27819824, 12.02180576], [75.27929688, 12.02181053], [75.27929688, 12.02153015], [75.27958679, 12.02153015], [75.27958679, 12.02097034], [75.27986145, 12.02097225], [75.27986145, 12.02069378], [75.28013611, 12.02069378], [75.28013611, 12.02041626], [75.28098297, 12.02042007], [75.28098297, 12.02013969], [75.28151703, 12.02013969], [75.28151703, 12.01986027], [75.28236389, 12.01986217], [75.28236389, 12.0195837], [75.28291321, 12.0195837], [75.28291321, 12.01930618], [75.28376007, 12.01931], [75.28376007, 12.01902962], [75.28430176, 12.01902962], [75.28430176, 12.01875019], [75.28514099, 12.01875019], [75.28514099, 12.01819134], [75.28541565, 12.0181942], [75.28541565, 12.0162487], [75.28514099, 12.0162487], [75.28514099, 12.0156889], [75.2848587, 12.01569557], [75.2848587, 12.01541805], [75.28514099, 12.01541996], [75.28514099, 12.0148592], [75.28541565, 12.01486206], [75.28541565, 12.01458263], [75.28569794, 12.01458263], [75.28569794, 12.01402664], [75.2859726, 12.01403046], [75.2859726, 12.01375198], [75.28624725, 12.01375198], [75.28624725, 12.01319122], [75.28652954, 12.01319313], [75.28652954, 12.01291656], [75.28679657, 12.01292038], [75.28679657, 12.01236057], [75.28708649, 12.01236057], [75.28708649, 12.01208305], [75.28736115, 12.01208305], [75.28736115, 12.01152706], [75.2876358, 12.01153183], [75.2876358, 12.01097107], [75.28791809, 12.01097107], [75.28791809, 12.01041698], [75.28819275, 12.01041889], [75.28819275, 12.00986099], [75.28848267, 12.00986099], [75.28847504, 12.009305], [75.28874969, 12.00931168], [75.28874969, 12.0090313], [75.28901672, 12.0090313], [75.28901672, 12.00875092], [75.28930664, 12.00875092], [75.28930664, 12.00847054], [75.2895813, 12.0084734], [75.2895813, 12.00819492], [75.29013824, 12.00819492], [75.29013824, 12.0079174], [75.2904129, 12.00791931], [75.2904129, 12.00764084], [75.29070282, 12.00764084], [75.29070282, 12.00736141], [75.29096985, 12.00736141], [75.29096985, 12.00708294], [75.29125214, 12.00708294], [75.29125214, 12.00680542], [75.29180908, 12.00680923], [75.29180908, 12.00653076], [75.29207611, 12.00653076], [75.29207611, 12.00542068], [75.29180908, 12.00542068], [75.29180908, 12.00514126], [75.29207611, 12.00514126], [75.29207611, 12.00486088], [75.29319763, 12.00486088], [75.29319763, 12.00514126], [75.29347229, 12.00514126], [75.29347229, 12.00542068], [75.29374695, 12.00541687], [75.29374695, 12.00569534], [75.29402924, 12.00569534], [75.29402924, 12.00597286], [75.29429626, 12.00597095], [75.29429626, 12.00625134], [75.29458618, 12.00625134], [75.29458618, 12.00736141], [75.29430389, 12.00736141], [75.29430389, 12.00958347], [75.29486084, 12.00958061], [75.29486084, 12.00986099], [75.29514313, 12.00986099], [75.29514313, 12.01014137], [75.29541779, 12.01014137], [75.29541779, 12.00986099], [75.29570007, 12.00986099], [75.29569244, 12.009305], [75.2959671, 12.00931168], [75.2959671, 12.0090313], [75.29624939, 12.0090313], [75.29624939, 12.00875092], [75.29651642, 12.00875092], [75.29651642, 12.00819016], [75.29680634, 12.00819492], [75.29680634, 12.0079174], [75.29708099, 12.00791931], [75.29708099, 12.00736141], [75.29736328, 12.00736141], [75.29736328, 12.00708294], [75.29763794, 12.00708294], [75.29763794, 12.00652885], [75.29792023, 12.00653076], [75.29792023, 12.00457954], [75.29819489, 12.00458336], [75.29819489, 12.00402641], [75.29846954, 12.00403118], [75.29846954, 12.0037508], [75.29873657, 12.0037508], [75.29873657, 12.00347042], [75.29957581, 12.00347042], [75.29957581, 12.00431061], [75.29930878, 12.00430679], [75.29930878, 12.00569534], [75.29958344, 12.00569534], [75.29958344, 12.00597286], [75.30014038, 12.00597095], [75.30014038, 12.00625134], [75.30097198, 12.00625134], [75.30097198, 12.00653076], [75.30152893, 12.00653076], [75.30152893, 12.00680923], [75.30236053, 12.00680542], [75.30236053, 12.00708294], [75.30347443, 12.00708294], [75.30347443, 12.00680542], [75.30374908, 12.00680923], [75.30374908, 12.00653076], [75.30403137, 12.00653076], [75.30403137, 12.00625134], [75.30568695, 12.00625134], [75.30568695, 12.00653076], [75.30596924, 12.00653076], [75.30596924, 12.00680923], [75.30652618, 12.00680923], [75.30652618, 12.00653076], [75.30680847, 12.00653076], [75.30680847, 12.00625134], [75.30735779, 12.00625134], [75.30735779, 12.00597095], [75.30791473, 12.00597286], [75.30791473, 12.00569534], [75.30819702, 12.00569534], [75.30819702, 12.00486088], [75.30847168, 12.00486088], [75.30847168, 12.00431061], [75.30819702, 12.00431061], [75.30819702, 12.0037508], [75.3079071, 12.0037508], [75.3079071, 12.00347042], [75.30764008, 12.00347328], [75.30764008, 12.00319481], [75.30791473, 12.00319481], [75.30791473, 12.00291729], [75.30819702, 12.0029211], [75.30819702, 12.00264072], [75.30847168, 12.00264072], [75.30847168, 12.00236034], [75.30902863, 12.00236034], [75.30902863, 12.0029211], [75.30930328, 12.00291729], [75.30930328, 12.00319481], [75.31124878, 12.00319481], [75.31124878, 12.00347328], [75.31208038, 12.00347042], [75.31208038, 12.0037508], [75.31291962, 12.0037508], [75.31291962, 12.00403118], [75.31597137, 12.00403118], [75.31597137, 12.00431061], [75.31652832, 12.00430679], [75.31652832, 12.00458336], [75.31680298, 12.00457954], [75.31680298, 12.00542068], [75.31652832, 12.00541687], [75.31652832, 12.00599957], [75.31652832, 12.00625134], [75.31597137, 12.00625134], [75.31597137, 12.00653076], [75.3154068, 12.00653076], [75.3154068, 12.00680923], [75.31513977, 12.00680542], [75.31513977, 12.00708294], [75.31458282, 12.00708294], [75.31458282, 12.00736141], [75.31402588, 12.00736141], [75.31402588, 12.00764084], [75.31375122, 12.00763893], [75.31375122, 12.0084734], [75.31402588, 12.0084734], [75.31402588, 12.00958347], [75.31430817, 12.00958061], [75.31430817, 12.01041889], [75.31485748, 12.01041698], [75.31485748, 12.01069546], [75.31541443, 12.01069546], [75.31541443, 12.01097107], [75.31791687, 12.01097107], [75.31791687, 12.01125145], [75.31903076, 12.01125145], [75.31903076, 12.01153183], [75.32013702, 12.01153183], [75.32013702, 12.01125145], [75.32041931, 12.01125145], [75.32041931, 12.01097107], [75.32096863, 12.01097107], [75.32096863, 12.01069546], [75.32125092, 12.01069546], [75.32125092, 12.01041698], [75.3215332, 12.01041889], [75.3215332, 12.01014137], [75.32402802, 12.01014137], [75.32402802, 12.00986099], [75.32514191, 12.00986099], [75.32514191, 12.00958061], [75.32596588, 12.00958061], [75.32596588, 12.00986099], [75.32653046, 12.00986099], [75.32653046, 12.01014137], [75.32707977, 12.01014137], [75.32707977, 12.01041889], [75.32736206, 12.01041889], [75.32736206, 12.01125145], [75.32763672, 12.01125145], [75.32763672, 12.0118103], [75.32791901, 12.01180458], [75.32791901, 12.01208305], [75.32847595, 12.01208305], [75.32847595, 12.01236057], [75.32875061, 12.01236057], [75.32875061, 12.01125145], [75.32847595, 12.01125145], [75.32847595, 12.01014137], [75.32875061, 12.01014137], [75.32875061, 12.00931168], [75.32930756, 12.00931168], [75.32930756, 12.0090313], [75.32958221, 12.00902653], [75.32958221, 12.00958347], [75.32985687, 12.00958061], [75.32985687, 12.01014137], [75.33013916, 12.01013947], [75.33013916, 12.01069546], [75.33041382, 12.01069546], [75.33041382, 12.01097107], [75.33152771, 12.01097107], [75.33152771, 12.01069546], [75.33180237, 12.01069546], [75.33180237, 12.01041698], [75.33207703, 12.01041889], [75.33207703, 12.01014137], [75.33319092, 12.01014137], [75.33319092, 12.01125145], [75.33291626, 12.01125145], [75.33291626, 12.0118103], [75.33208466, 12.01180458], [75.33208466, 12.01208305], [75.33181, 12.01208115], [75.33181, 12.01292038], [75.33208466, 12.01291656], [75.33208466, 12.01347446], [75.33180237, 12.01347446], [75.33180237, 12.01319313], [75.33125305, 12.01319313], [75.33125305, 12.01347446], [75.32791901, 12.01347446], [75.32791901, 12.01319313], [75.32736206, 12.01319313], [75.32736206, 12.01291656], [75.32707977, 12.01292038], [75.32707977, 12.01264191], [75.32681274, 12.01264191], [75.32681274, 12.01236057], [75.32653046, 12.01236057], [75.32653046, 12.01208305], [75.32624817, 12.01208305], [75.32624817, 12.01180458], [75.32541656, 12.0118103], [75.32541656, 12.01153183], [75.32319641, 12.01153183], [75.32319641, 12.0118103], [75.32180786, 12.01180458], [75.32180786, 12.01236057], [75.3215332, 12.01236057], [75.3215332, 12.01264191], [75.32125092, 12.01264191], [75.32125092, 12.01292038], [75.32069397, 12.01291656], [75.32069397, 12.01319313], [75.32041931, 12.01319313], [75.32041931, 12.01347446], [75.32013702, 12.01346016], [75.32013702, 12.01375198], [75.31987, 12.01375198], [75.31987, 12.01403046], [75.31846619, 12.01403046], [75.31846619, 12.01431179], [75.31652832, 12.01431179], [75.31652832, 12.01403046], [75.31569672, 12.01403046], [75.31569672, 12.01375198], [75.31513977, 12.01375198], [75.31513977, 12.01403046], [75.31430817, 12.01403046], [75.31430817, 12.01431179], [75.31375122, 12.01430511], [75.31375122, 12.01458263], [75.31346893, 12.01458263], [75.31346893, 12.01486206], [75.31318665, 12.0148592], [75.31318665, 12.01513958], [75.31208038, 12.01513958], [75.31208038, 12.0148592], [75.31014252, 12.01486206], [75.31014252, 12.01430511], [75.30986023, 12.01431179], [75.30986023, 12.01375198], [75.3095932, 12.01375198], [75.3095932, 12.01319122], [75.30847168, 12.01319313], [75.30847168, 12.01347446], [75.3079071, 12.01346016], [75.3079071, 12.01403046], [75.30819702, 12.01402664], [75.30819702, 12.01486206], [75.3079071, 12.0148592], [75.3079071, 12.01513958], [75.30735779, 12.01513958], [75.30735779, 12.01541996], [75.30708313, 12.01541805], [75.30708313, 12.01569557], [75.30652618, 12.01569557], [75.30652618, 12.01597118], [75.30403137, 12.01597118], [75.30403137, 12.01569557], [75.30374908, 12.01569557], [75.30374908, 12.01541805], [75.30264282, 12.01541996], [75.30264282, 12.01513958], [75.30208588, 12.01513958], [75.30208588, 12.01541996], [75.30041504, 12.01541805], [75.30041504, 12.01569557], [75.29969025, 12.0156908], [75.29930878, 12.0156889], [75.29930878, 12.01681042], [75.29958344, 12.01680565], [75.29958344, 12.01708412], [75.29971313, 12.01708126], [75.29985809, 12.01708126], [75.29985809, 12.01764202], [75.30041504, 12.01764011], [75.30041504, 12.0181942], [75.30097198, 12.0181942], [75.30097198, 12.01847172], [75.30179596, 12.01846886], [75.30179596, 12.01875019], [75.30291748, 12.01875019], [75.30291748, 12.01791954], [75.30319214, 12.01791954], [75.30319214, 12.01764202], [75.30430603, 12.01764202], [75.30430603, 12.01791954], [75.30458069, 12.01791573], [75.30458069, 12.01847172], [75.30486298, 12.01846886], [75.30486298, 12.01875019], [75.30513763, 12.01875019], [75.30513763, 12.01902962], [75.30541992, 12.01902962], [75.30541992, 12.01931], [75.30568695, 12.01931], [75.30568695, 12.02013969], [75.30541992, 12.02013969], [75.30541992, 12.02042007], [75.30513763, 12.02041626], [75.30513763, 12.02069378], [75.30486298, 12.02069378], [75.30486298, 12.02097225], [75.30458069, 12.02097034], [75.30458069, 12.02153015], [75.30403137, 12.02153015], [75.30403137, 12.02181053], [75.30347443, 12.02180576], [75.30347443, 12.02208424], [75.30319214, 12.02208042], [75.30319214, 12.02265167], [75.30347443, 12.02264023], [75.30347443, 12.02319431], [75.30374908, 12.02318859], [75.30374908, 12.02375031], [75.30403137, 12.02375031], [75.30403137, 12.02486229], [75.30374908, 12.02486038], [75.30374908, 12.02542114], [75.30347443, 12.02541637], [75.30347443, 12.02569389], [75.30319214, 12.02569199], [75.30319214, 12.02625275], [75.30291748, 12.02625275], [75.30291748, 12.02653122], [75.30264282, 12.02653122], [75.30264282, 12.02681065], [75.30236053, 12.02680588], [75.30236053, 12.0270853], [75.30208588, 12.02707958], [75.30208588, 12.02735996], [75.30179596, 12.02735996], [75.30179596, 12.0276413], [75.30152893, 12.0276413], [75.30152893, 12.02792072], [75.30124664, 12.02791595], [75.30124664, 12.0284729], [75.30152893, 12.02846146], [75.30152893, 12.02875137], [75.30180359, 12.02875137], [75.30180359, 12.02958202], [75.30208588, 12.02958202], [75.30208588, 12.02985954], [75.30236053, 12.02985954], [75.30236053, 12.03014088], [75.30291748, 12.03014088], [75.30291748, 12.03042126], [75.30319214, 12.03041744], [75.30319214, 12.03069496], [75.30347443, 12.03069496], [75.30347443, 12.03097343], [75.30403137, 12.03096962], [75.30403137, 12.03125095], [75.30430603, 12.03125095], [75.30430603, 12.03152657], [75.30486298, 12.03151989], [75.30486298, 12.03181076], [75.30513763, 12.03180695], [75.30513763, 12.03208256], [75.30568695, 12.0320797], [75.30568695, 12.03236103], [75.30680847, 12.03236103], [75.30680847, 12.03264141], [75.30764008, 12.03264141], [75.30764008, 12.03292084], [75.30986023, 12.03291702], [75.30986023, 12.03319454], [75.31014252, 12.03319454], [75.31014252, 12.03347301], [75.31069183, 12.03347301], [75.31069183, 12.03263855], [75.31180573, 12.03263855], [75.31180573, 12.03319454], [75.31208038, 12.03319454], [75.31208038, 12.03486061], [75.31181335, 12.03486061], [75.31181335, 12.0365324], [75.31208038, 12.03652668], [75.31208038, 12.03708267], [75.31319427, 12.03708267], [75.31319427, 12.03736115], [75.31346893, 12.03736115], [75.31346893, 12.03819466], [75.31318665, 12.03819084], [75.31318665, 12.03875065], [75.31291962, 12.03875065], [75.31291962, 12.03903198], [75.31236267, 12.03902721], [75.31236267, 12.03958321], [75.31208038, 12.0395813], [75.31208038, 12.04124928], [75.31236267, 12.04124928], [75.31236267, 12.04181004], [75.31263733, 12.04180527], [75.31263733, 12.04236221], [75.31291962, 12.04235935], [75.31291962, 12.04292011], [75.31319427, 12.04291534], [75.31319427, 12.04319572], [75.31375122, 12.04319572], [75.31375122, 12.04347134], [75.31402588, 12.04347134], [75.31402588, 12.04374981], [75.31430817, 12.04374981], [75.31430817, 12.04430962], [75.31458282, 12.0443058], [75.31458282, 12.04458427], [75.31485748, 12.04458141], [75.31485748, 12.04486179], [75.31513977, 12.04486179], [75.31513977, 12.04514027], [75.31569672, 12.04514027], [75.31569672, 12.04569435], [75.31597137, 12.04569435], [75.31597137, 12.04597187], [75.31624603, 12.04597187], [75.31624603, 12.04625034], [75.31680298, 12.04625034], [75.31680298, 12.04652977], [75.31931305, 12.04652977], [75.31931305, 12.04625034], [75.31958008, 12.04625034], [75.31958008, 12.04597187], [75.32069397, 12.04597187], [75.32069397, 12.04569435], [75.32125092, 12.04569435], [75.32125092, 12.04541779], [75.3215332, 12.04541969], [75.3215332, 12.04514027], [75.32180786, 12.04514027], [75.32180786, 12.04486179], [75.32208252, 12.04486179], [75.32208252, 12.04430962], [75.32235718, 12.04430962], [75.32235718, 12.04374981], [75.32263947, 12.04374981], [75.32263947, 12.04319572], [75.32291412, 12.04319572], [75.32291412, 12.04263973], [75.32319641, 12.04263973], [75.32319641, 12.04152966], [75.32347107, 12.04152966], [75.32347107, 12.04124928], [75.32375336, 12.04124928], [75.32375336, 12.04096889], [75.32402802, 12.0409708], [75.32402802, 12.04041672], [75.32430267, 12.04041958], [75.32430267, 12.0401392], [75.32457733, 12.0401392], [75.32457733, 12.0395813], [75.32485962, 12.03958321], [75.32485962, 12.03899097], [75.32485962, 12.03874874], [75.32514191, 12.03875065], [75.32514191, 12.03819084], [75.32569122, 12.03819466], [75.32569122, 12.03791714], [75.32595062, 12.03792191], [75.32596588, 12.03736115], [75.32624817, 12.03736115], [75.32624817, 12.03708267], [75.32653046, 12.03708267], [75.32653046, 12.03652668], [75.32707977, 12.0365324], [75.32707977, 12.03625107], [75.32736206, 12.03625107], [75.32736206, 12.03597069], [75.32818604, 12.03597069], [75.32818604, 12.03625107], [75.32875061, 12.03625107], [75.32875061, 12.0365324], [75.3290329, 12.0365324], [75.3290329, 12.03625107], [75.32930756, 12.03625107], [75.32930756, 12.0365324], [75.32985687, 12.0365324], [75.32985687, 12.03681183], [75.33013916, 12.03680515], [75.33013916, 12.03708267], [75.33069611, 12.03708267], [75.33069611, 12.03736115], [75.33125305, 12.03736115], [75.33125305, 12.03765106], [75.33152771, 12.03765106], [75.33152771, 12.03792191], [75.33180237, 12.03791714], [75.33181763, 12.03816128], [75.33152771, 12.03819466], [75.33152771, 12.03847122], [75.33208466, 12.03847122], [75.33208466, 12.03862095], [75.33207703, 12.03875065], [75.33235931, 12.03874874], [75.33235931, 12.0391407], [75.33235931, 12.03931046], [75.3326416, 12.03930473], [75.3326416, 12.03969002], [75.3326416, 12.03986073], [75.33281708, 12.03986073], [75.33287811, 12.03990936], [75.33291626, 12.04041958], [75.33347321, 12.04041672], [75.33347321, 12.04069328], [75.33374786, 12.04069138], [75.33374786, 12.04124928], [75.33403015, 12.04124928], [75.33403015, 12.04208374], [75.33429718, 12.04208088], [75.33429718, 12.04263973], [75.3345871, 12.04263973], [75.3345871, 12.04319572], [75.33486176, 12.04319572], [75.33486176, 12.04347134], [75.33513641, 12.04347134], [75.33513641, 12.04374981], [75.33486938, 12.04374981], [75.33486938, 12.04430962], [75.3345871, 12.0443058], [75.3345871, 12.04458427], [75.33429718, 12.04458141], [75.33429718, 12.04514027], [75.3345871, 12.04514027], [75.3345871, 12.04652977], [75.33513641, 12.04652977], [75.33513641, 12.04681969], [75.3354187, 12.04680634], [75.3354187, 12.04708385], [75.33597565, 12.04708385], [75.33597565, 12.04736233], [75.33901215, 12.04736042], [75.3390274, 12.04763985], [75.33930206, 12.04763794], [75.33930206, 12.04819393], [75.3390274, 12.04819393], [75.3390274, 12.0484724], [75.33875275, 12.0484724], [75.33875275, 12.04819393], [75.3381958, 12.04819393], [75.3381958, 12.0484724], [75.33680725, 12.04846954], [75.33680725, 12.04874992], [75.33651733, 12.04874992], [75.33651733, 12.04846954], [75.33569336, 12.04843998], [75.33569336, 12.04819393], [75.33513641, 12.04819393], [75.33513641, 12.04791641], [75.3345871, 12.04792023], [75.3345871, 12.04763985], [75.33429718, 12.04763985], [75.33429718, 12.04708195], [75.33403015, 12.04708385], [75.33403015, 12.04625034], [75.33374786, 12.04625034], [75.33374786, 12.04597187], [75.33347321, 12.04597187], [75.33347321, 12.04541779], [75.33319092, 12.04541969], [75.33319092, 12.04403019], [75.33347321, 12.04403019], [75.33347321, 12.04345989], [75.33319092, 12.04347134], [75.33319092, 12.04263973], [75.33291626, 12.04263973], [75.33291626, 12.04181004], [75.33235931, 12.04181004], [75.33235931, 12.04152966], [75.3326416, 12.04152966], [75.3326416, 12.04124928], [75.33207703, 12.04124928], [75.33207703, 12.04096889], [75.33180237, 12.0409708], [75.33180237, 12.04069328], [75.33152771, 12.04069328], [75.33152771, 12.04041672], [75.33125305, 12.04041958], [75.33125305, 12.0401392], [75.33097076, 12.0401392], [75.33097076, 12.0395813], [75.33069611, 12.03958321], [75.33069611, 12.03930473], [75.33040619, 12.03931046], [75.33040619, 12.03903198], [75.33013916, 12.03903198], [75.33013916, 12.03875065], [75.32985687, 12.03875065], [75.32985687, 12.03847122], [75.32930756, 12.03847122], [75.32930756, 12.03819466], [75.32902527, 12.03819466], [75.32902527, 12.03791714], [75.32680511, 12.03791714], [75.32680511, 12.03819466], [75.32653046, 12.03819466], [75.32653046, 12.03847122], [75.32624817, 12.03847122], [75.32624817, 12.03875065], [75.32596588, 12.03875065], [75.32596588, 12.03903198], [75.32569122, 12.03902721], [75.32569122, 12.03958321], [75.32541656, 12.0395813], [75.32541656, 12.03986073], [75.32514191, 12.03986073], [75.32514191, 12.0409708], [75.32485962, 12.04096889], [75.32485962, 12.04152966], [75.32458496, 12.04152679], [75.32458496, 12.04236221], [75.32430267, 12.04235935], [75.32430267, 12.04292011], [75.32402802, 12.04291534], [75.32402802, 12.04374981], [75.32375336, 12.04374981], [75.32375336, 12.04486179], [75.32347107, 12.04486179], [75.32347107, 12.04541969], [75.32319641, 12.04541779], [75.32319641, 12.04569435], [75.32291412, 12.04569435], [75.32291412, 12.04597187], [75.32263947, 12.04597187], [75.32263947, 12.04625034], [75.32235718, 12.04625034], [75.32235718, 12.04652977], [75.32208252, 12.04652977], [75.32208252, 12.04681969], [75.32180786, 12.04680634], [75.32180786, 12.04708385], [75.32152557, 12.04708385], [75.32152557, 12.04736233], [75.32096863, 12.04736042], [75.32096863, 12.04763985], [75.32041931, 12.04763985], [75.32041931, 12.04736042], [75.31958008, 12.04736042], [75.31958008, 12.04763985], [75.31874847, 12.04763985], [75.31874847, 12.04792023], [75.31652832, 12.04792023], [75.31652832, 12.04763985], [75.31569672, 12.04763985], [75.31569672, 12.04736042], [75.31513977, 12.04736233], [75.31513977, 12.04708385], [75.31485748, 12.04708385], [75.31485748, 12.04680634], [75.31430817, 12.04681969], [75.31430817, 12.04652977], [75.31402588, 12.04652977], [75.31402588, 12.04597187], [75.31375122, 12.04597187], [75.31375122, 12.04569435], [75.31346893, 12.04569435], [75.31346893, 12.04541779], [75.31318665, 12.04541969], [75.31318665, 12.04514027], [75.31291962, 12.04514027], [75.31291962, 12.04486179], [75.31263733, 12.04486179], [75.31263733, 12.04458141], [75.31208038, 12.04458427], [75.31208038, 12.0443058], [75.31181335, 12.04430962], [75.31181335, 12.04403019], [75.31124878, 12.04403019], [75.31124878, 12.04345989], [75.31097412, 12.04347134], [75.31097412, 12.04291534], [75.31067657, 12.04292011], [75.31067657, 12.04235935], [75.31041718, 12.04236221], [75.31041718, 12.04069328], [75.31014252, 12.04069328], [75.31014252, 12.03902721], [75.31041718, 12.03903198], [75.31041718, 12.03819084], [75.31014252, 12.03819466], [75.31014252, 12.03791714], [75.31041718, 12.03792191], [75.31041718, 12.03708076], [75.31069183, 12.03708267], [75.31069183, 12.03680515], [75.31014252, 12.03681183], [75.31014252, 12.0365324], [75.30986023, 12.0365324], [75.30986023, 12.03597069], [75.30958557, 12.0359726], [75.30958557, 12.03569508], [75.30930328, 12.03569508], [75.30930328, 12.0354166], [75.30902863, 12.03541946], [75.30902863, 12.03486061], [75.30874634, 12.03486061], [75.30874634, 12.03458309], [75.30819702, 12.03458977], [75.30819702, 12.03430939], [75.30708313, 12.03430939], [75.30708313, 12.03458977], [75.30735779, 12.03458977], [75.30735779, 12.03486061], [75.30764008, 12.03486061], [75.30764008, 12.03514099], [75.30791473, 12.03513908], [75.30791473, 12.03569508], [75.30819702, 12.03569508], [75.30819702, 12.03708267], [75.3079071, 12.03708076], [75.3079071, 12.03765106], [75.30764008, 12.03763866], [75.30764008, 12.03819466], [75.30735779, 12.03819466], [75.30735779, 12.03847122], [75.30708313, 12.03847122], [75.30708313, 12.03875065], [75.30680847, 12.03874874], [75.30680847, 12.03958321], [75.30708313, 12.03958321], [75.30708313, 12.04069328], [75.30680847, 12.04069138], [75.30680847, 12.04152966], [75.30708313, 12.04152679], [75.30708313, 12.04208374], [75.30735779, 12.04208374], [75.30735779, 12.04236221], [75.30764008, 12.04235935], [75.30764008, 12.04263973], [75.3079071, 12.04263973], [75.3079071, 12.04292011], [75.30819702, 12.04291534], [75.30819702, 12.04374981], [75.3079071, 12.04374981], [75.3079071, 12.04514027], [75.30819702, 12.04514027], [75.30819702, 12.04625034], [75.30847168, 12.04625034], [75.30847168, 12.04681969], [75.30874634, 12.04680634], [75.30874634, 12.04736233], [75.30902863, 12.04736042], [75.30902863, 12.04763985], [75.30930328, 12.04763985], [75.30930328, 12.04792023], [75.30958557, 12.04791641], [75.30958557, 12.04819393], [75.30986023, 12.04819202], [75.30986023, 12.04874992], [75.31014252, 12.04874992], [75.31014252, 12.04846954], [75.31041718, 12.0484724], [75.31041718, 12.04819393], [75.31069183, 12.04819393], [75.31069183, 12.04791641], [75.31096649, 12.04792023], [75.31096649, 12.04763985], [75.31124878, 12.04763985], [75.31124878, 12.04736042], [75.31181335, 12.04736042], [75.31181335, 12.04792023], [75.31208038, 12.04791641], [75.31208038, 12.04867172], [75.31208038, 12.0490303], [75.31184387, 12.04904175], [75.31181335, 12.04931068], [75.3116684, 12.04930592], [75.30879211, 12.05379105], [75.30480957, 12.0529213], [75.30066681, 12.05802059], [75.2961731, 12.05924129], [75.29737091, 12.06365108], [75.29917145, 12.06679153], [75.30916595, 12.07843971], [75.3147583, 12.08760929], [75.30964661, 12.09063053], [75.30906677, 12.10266113], [75.31288147, 12.10531139], [75.31962585, 12.10665131], [75.32817841, 12.10727978], [75.32998657, 12.10258961], [75.33598328, 12.09864044], [75.3398819, 12.09825134], [75.35193634, 12.10885143], [75.3553009, 12.10936069], [75.35790253, 12.11290073], [75.36267853, 12.11610985], [75.36592102, 12.11693001], [75.3685379, 12.12126064], [75.37548065, 12.12341022], [75.37930298, 12.12213993], [75.37993622, 12.12639141], [75.38228607, 12.12912083], [75.38308716, 12.12397957], [75.39215088, 12.12634087], [75.39823914, 12.12987137], [75.4021759, 12.13414001], [75.40251923, 12.13684082], [75.39982605, 12.14050102], [75.39392853, 12.14548111], [75.38852692, 12.14629173], [75.37838745, 12.14603043], [75.37460327, 12.14908028], [75.37201691, 12.14647007], [75.37149048, 12.14262962], [75.36826324, 12.14007854], [75.36669159, 12.13537979], [75.36360931, 12.13496971], [75.34784698, 12.13530922], [75.34616089, 12.13861179], [75.34194946, 12.13718033], [75.33522797, 12.14400196], [75.33112335, 12.14515114], [75.32515717, 12.14489079], [75.32064056, 12.14352131], [75.31429291, 12.14009953], [75.31115723, 12.1364603], [75.3098526, 12.13204956], [75.31067657, 12.12473202], [75.29277039, 12.11613274], [75.28392792, 12.11498165], [75.28198242, 12.1091404], [75.27781677, 12.1017704], [75.2745285, 12.10026073], [75.26602173, 12.10366058], [75.25985718, 12.10893059], [75.25588989, 12.10857964], [75.24739075, 12.1036911], [75.24344635, 12.10467052], [75.24053192, 12.10926056], [75.23660278, 12.11023045], [75.22306061, 12.10484028], [75.22113037, 12.10095119], [75.22245789, 12.08556938], [75.22225952, 12.07815075], [75.22424316, 12.07438087], [75.2231369, 12.06444168], [75.22367096, 12.05447102], [75.22735596, 12.04430103], [75.22492218, 12.03195], [75.23105621, 12.02456188], [75.23069763, 12.02414036], [75.23069763, 12.02431107], [75.23014069, 12.02431107], [75.23014069, 12.02402973], [75.22930908, 12.02402973], [75.22930908, 12.02375031], [75.22846985, 12.02375031], [75.22846985, 12.02346992], [75.22819519, 12.02347183], [75.22819519, 12.02319431], [75.22763824, 12.02319431], [75.22763824, 12.02291584], [75.22680664, 12.02292061], [75.22680664, 12.02265167], [75.22651672, 12.02265167], [75.22651672, 12.02208042], [75.22624969, 12.02208424], [75.22624969, 12.02180576], [75.22651672, 12.02181053], [75.22651672, 12.02153015], [75.22598267, 12.02153015], [75.22598267, 12.02097034], [75.22569275, 12.02097225], [75.22569275, 12.02069378], [75.22541809, 12.02069378], [75.22541809, 12.02013779], [75.22486115, 12.02013969], [75.22486115, 12.01986027], [75.2243042, 12.01986217], [75.2243042, 12.01930618], [75.22374725, 12.01931], [75.22374725, 12.01902962], [75.22348022, 12.01902962], [75.22348022, 12.01846886], [75.22319794, 12.01847172], [75.22319794, 12.01764011], [75.22292328, 12.01764202], [75.22292328, 12.01736164], [75.22264099, 12.01736164], [75.22264099, 12.01681042], [75.2223587, 12.01681042], [75.2223587, 12.01596928], [75.22208405, 12.01597118], [75.22208405, 12.01486206], [75.22180176, 12.01486206], [75.22180176, 12.01402664], [75.2215271, 12.01403046], [75.2215271, 12.01375198], [75.22125244, 12.01375198], [75.22125244, 12.01346016], [75.2206955, 12.01347446], [75.2206955, 12.01263905], [75.21985626, 12.01264191], [75.21985626, 12.01236057], [75.21930695, 12.01236057], [75.21930695, 12.01208305], [75.21902466, 12.01208305], [75.21902466, 12.01180458], [75.21875, 12.0118103], [75.21875, 12.01153183], [75.21819305, 12.01153183], [75.21819305, 12.01125145], [75.21763611, 12.01125145], [75.21763611, 12.01069069], [75.21736145, 12.01069546], [75.21736145, 12.01041698], [75.21708679, 12.01041889], [75.21708679, 12.01014137], [75.21624756, 12.01014137], [75.21624756, 12.01041889], [75.21457672, 12.01041889], [75.21457672, 12.01014137], [75.21375275, 12.01014137], [75.21375275, 12.01041889], [75.21263885, 12.01041698], [75.21263885, 12.01069546], [75.2123642, 12.01069546], [75.2123642, 12.01041698], [75.21208191, 12.01041698], [75.21208191, 12.01069546], [75.21097565, 12.01069546], [75.21097565, 12.01097107], [75.2104187, 12.01097107], [75.2104187, 12.01125145], [75.2095871, 12.01125145], [75.2095871, 12.01097107], [75.20930481, 12.01097107], [75.20930481, 12.01069546], [75.20791626, 12.01069546], [75.20791626, 12.01041698], [75.2076416, 12.01041889], [75.2076416, 12.01014137], [75.20735931, 12.01014137], [75.20735931, 12.00986099], [75.20707703, 12.00986099], [75.20707703, 12.0090313], [75.20735931, 12.0090313], [75.20735931, 12.00875092], [75.2076416, 12.00875092], [75.2076416, 12.00791931], [75.20707703, 12.00791931], [75.20707703, 12.00708103], [75.20680237, 12.00708294], [75.20680237, 12.00680542], [75.20652771, 12.00680923], [75.20652771, 12.00653076], [75.20625305, 12.00653076], [75.20625305, 12.00625134], [75.20597076, 12.00625134], [75.20597076, 12.00597095], [75.20541382, 12.00597286], [75.20541382, 12.00569534], [75.2048645, 12.00569534], [75.2048645, 12.00513935], [75.20458221, 12.00514126], [75.20458221, 12.00486088], [75.20291901, 12.00486088], [75.20291901, 12.00514126], [75.20181274, 12.00514126], [75.20181274, 12.00542068], [75.20153046, 12.00541687], [75.20153046, 12.00597286], [75.20124817, 12.00597095], [75.20124817, 12.00653076], [75.20096588, 12.00653076], [75.20096588, 12.00680923], [75.20085144, 12.00680542], [75.20069122, 12.00680542], [75.20069122, 12.00736141], [75.20041656, 12.00736141], [75.20041656, 12.00819492], [75.20063019, 12.00819492], [75.20097351, 12.00819492], [75.20097351, 12.0084734], [75.20124817, 12.00847054], [75.20124817, 12.00875092], [75.20153046, 12.00875092], [75.20153046, 12.00986099], [75.20124817, 12.00986099], [75.20124817, 12.01041889], [75.20097351, 12.01041698], [75.20097351, 12.01097107], [75.20069122, 12.01097107], [75.20069122, 12.01153183], [75.20041656, 12.01152706], [75.20041656, 12.01208305], [75.20014191, 12.01208305], [75.20014191, 12.01236057], [75.19996643, 12.01236057], [75.19985962, 12.01236057], [75.19985962, 12.01299], [75.19985962, 12.01319313], [75.19958496, 12.01319313], [75.19958496, 12.01347446], [75.19928741, 12.01346016], [75.19928741, 12.01375198], [75.19902802, 12.01375198], [75.19902802, 12.01403046], [75.19875336, 12.01402664], [75.19875336, 12.01458263], [75.19847107, 12.01458073], [75.19847107, 12.01541996], [75.19819641, 12.01541805], [75.19819641, 12.01597118], [75.19791412, 12.01597118], [75.19791412, 12.01708412], [75.19763947, 12.01708126], [75.19763947, 12.01764202], [75.19736481, 12.01764011], [75.19736481, 12.0181942], [75.19708252, 12.01819134], [75.19708252, 12.01875019], [75.19680786, 12.01875019], [75.19680786, 12.01902962], [75.19652557, 12.01902771], [75.19652557, 12.0195837], [75.19625092, 12.0195837], [75.19625092, 12.01986217], [75.19596863, 12.01986027], [75.19596863, 12.02013969], [75.19569397, 12.02013779], [75.19569397, 12.02097225], [75.19541931, 12.02097034], [75.19541931, 12.02181053], [75.19513702, 12.02180576], [75.19513702, 12.02208424], [75.19486237, 12.02208424], [75.19486237, 12.02235985], [75.19458008, 12.02235985], [75.19458008, 12.02319431], [75.19430542, 12.02319431], [75.19431305, 12.02375031], [75.19403076, 12.02375031], [75.19403076, 12.02402973], [75.19374847, 12.02402782], [75.19374847, 12.02458191], [75.19347382, 12.02458382], [75.19347382, 12.02569389], [75.19319153, 12.02569199], [75.19319153, 12.02653122], [75.19291687, 12.02653122], [75.19291687, 12.02681065], [75.19264221, 12.02681065], [75.19264221, 12.02735996], [75.19235992, 12.02735996], [75.19235992, 12.0276413], [75.1920929, 12.0276413], [75.1920929, 12.02792072], [75.19180298, 12.02792072], [75.19180298, 12.02875137], [75.19152832, 12.02875137], [75.19152832, 12.0290308], [75.19124603, 12.0290308], [75.19124603, 12.02931118], [75.19097137, 12.02930355], [75.19097137, 12.02985954], [75.19069672, 12.02985954], [75.19069672, 12.03042126], [75.1904068, 12.03042126], [75.1904068, 12.03125095], [75.19013977, 12.03125095], [75.19013977, 12.03208256], [75.18985748, 12.0320797], [75.18985748, 12.03264141], [75.18958282, 12.03264141], [75.18958282, 12.03292084], [75.18930817, 12.03291702], [75.18930817, 12.03347301], [75.18902588, 12.03347111], [75.18902588, 12.03430939], [75.18875122, 12.03430939], [75.18875122, 12.03458977], [75.18846893, 12.03458309], [75.18846893, 12.03486061], [75.18818665, 12.03486061], [75.18818665, 12.03541946], [75.18791962, 12.0354166], [75.18791962, 12.0359726], [75.18763733, 12.03597069], [75.18763733, 12.0365324], [75.18734741, 12.0365324], [75.18734741, 12.03681183], [75.18708038, 12.03680515], [75.18708038, 12.03708267], [75.18680573, 12.03708267], [75.18680573, 12.03847122], [75.18653107, 12.03847122], [75.18653107, 12.03875065], [75.18624878, 12.03875065], [75.18624878, 12.03986073], [75.18596649, 12.03986073], [75.18596649, 12.04041958], [75.18541718, 12.04041672], [75.18541718, 12.0409708], [75.18514252, 12.04096889], [75.18514252, 12.04152966], [75.18486023, 12.04152679], [75.18486023, 12.04208374], [75.18460083, 12.04208088], [75.18460083, 12.04292011], [75.18430328, 12.04291534], [75.18430328, 12.04374981], [75.18402863, 12.04374981], [75.18402863, 12.04430962], [75.18347168, 12.0443058], [75.18347168, 12.04458427], [75.18319702, 12.04458141], [75.18319702, 12.04541969], [75.1829071, 12.04541969], [75.1829071, 12.04625034], [75.18264008, 12.04625034], [75.18264008, 12.04681969], [75.18235779, 12.04680634], [75.18235779, 12.04736233], [75.18208313, 12.04736042], [75.18208313, 12.04763985], [75.18180847, 12.04763794], [75.18180847, 12.04819393], [75.18152618, 12.04819202], [75.18152618, 12.04874992], [75.18208313, 12.04874992], [75.18208313, 12.04846954], [75.18264008, 12.0484724], [75.18264008, 12.04819393], [75.18291473, 12.04819393], [75.18291473, 12.04791641], [75.18319702, 12.04792023], [75.18319702, 12.04763985], [75.18347168, 12.04763985], [75.18347168, 12.04708195], [75.18374634, 12.04708385], [75.18374634, 12.04652786], [75.18402863, 12.04652977], [75.18402863, 12.04541969], [75.18431091, 12.04541969], [75.18431091, 12.04430962], [75.18460083, 12.04430962], [75.18460083, 12.04403019], [75.18486023, 12.04403019], [75.18486023, 12.04374981], [75.18569183, 12.04374981], [75.18569183, 12.04403019], [75.18596649, 12.04403019], [75.18596649, 12.04430962], [75.18624878, 12.0443058], [75.18624878, 12.04458427], [75.18681335, 12.04458141], [75.18681335, 12.04486179], [75.18708038, 12.04486179], [75.18708038, 12.04514027], [75.18734741, 12.04514027], [75.18734741, 12.04541969], [75.18763733, 12.04541779], [75.18763733, 12.04597187], [75.18734741, 12.04597187], [75.18734741, 12.04681969], [75.18708038, 12.04680634], [75.18708038, 12.04736233], [75.18681335, 12.04736042], [75.18681335, 12.04792023], [75.18653107, 12.04791641], [75.18653107, 12.0484724], [75.18624878, 12.04846954], [75.18624878, 12.04931068], [75.18596649, 12.04931068], [75.18596649, 12.04986], [75.18569183, 12.04986], [75.18569183, 12.05042076], [75.18541718, 12.05042076], [75.18541718, 12.05125046], [75.18514252, 12.05125046], [75.18514252, 12.05181122], [75.18486023, 12.05181122], [75.18486023, 12.0529213], [75.18514252, 12.05291557], [75.18514252, 12.05347157], [75.18541718, 12.05346966], [75.18541718, 12.05375004], [75.18569183, 12.05375004], [75.18569183, 12.0543108], [75.18597412, 12.05430698], [75.18597412, 12.05458546], [75.18624878, 12.05457973], [75.18624878, 12.05486012], [75.18653107, 12.05486012], [75.18653107, 12.05514145], [75.18680573, 12.05513763], [75.18680573, 12.05569363], [75.18653107, 12.05569172], [75.18653107, 12.05653095], [75.18596649, 12.05653095], [75.18596649, 12.05681133], [75.18569183, 12.05680656], [75.18569183, 12.05708218], [75.18514252, 12.05708027], [75.18514252, 12.05736065], [75.18486023, 12.05736065], [75.18486023, 12.05764103], [75.18460083, 12.05764103], [75.18460083, 12.05792141], [75.18430328, 12.05791664], [75.18430328, 12.05847263], [75.18402863, 12.05846977], [75.18402863, 12.05903053], [75.18374634, 12.05902672], [75.18374634, 12.05958271], [75.18347168, 12.05957985], [75.18347168, 12.06014061], [75.18319702, 12.06014061], [75.18319702, 12.06125069], [75.1829071, 12.06125069], [75.1829071, 12.06375122], [75.18264008, 12.06375122], [75.18264008, 12.06458282], [75.18235779, 12.06456947], [75.18235779, 12.06542015], [75.18208313, 12.06541729], [75.18208313, 12.06597328], [75.18180847, 12.06597137], [75.18180847, 12.06653023], [75.18152618, 12.06652737], [75.18152618, 12.06708336], [75.18125153, 12.06708145], [75.18125153, 12.06736088], [75.18096924, 12.06736088], [75.18096924, 12.06763935], [75.18068695, 12.06763268], [75.18068695, 12.06791973], [75.18041992, 12.06791782], [75.18041992, 12.06847095], [75.18013763, 12.06847095], [75.18013763, 12.06902981], [75.17986298, 12.06902695], [75.17986298, 12.06986237], [75.17958069, 12.06985855], [75.17958069, 12.07042027], [75.17930603, 12.07042027], [75.17930603, 12.07153034], [75.17903137, 12.07153034], [75.17903137, 12.07236195], [75.17874908, 12.07236195], [75.17874908, 12.07291985], [75.17847443, 12.07291794], [75.17847443, 12.07347202], [75.17817688, 12.07347202], [75.17817688, 12.07376099], [75.17791748, 12.07376099], [75.17791748, 12.07402992], [75.17764282, 12.07402992], [75.17764282, 12.07542038], [75.17791748, 12.07542038], [75.17791748, 12.07763958], [75.17817688, 12.07763958], [75.17817688, 12.07874966], [75.17847443, 12.07874966], [75.17847443, 12.07958221], [75.17874908, 12.07958221], [75.17874908, 12.0806942], [75.17903137, 12.08069038], [75.17903137, 12.08125019], [75.17930603, 12.08125019], [75.17930603, 12.08153057], [75.17958069, 12.08153057], [75.17958069, 12.08181095], [75.17986298, 12.08180428], [75.17986298, 12.08208466], [75.18013763, 12.08208466], [75.18013763, 12.08236027], [75.18068695, 12.08236027], [75.18068695, 12.08264065], [75.18096924, 12.08264065], [75.18096924, 12.08292103], [75.18125153, 12.08291626], [75.18125153, 12.08319473], [75.18180847, 12.08319473], [75.18180847, 12.08347321], [75.18235779, 12.08347034], [75.18235779, 12.08375072], [75.18319702, 12.08375072], [75.18319702, 12.08403111], [75.18374634, 12.0840292], [75.18374634, 12.08458328], [75.18402863, 12.08458042], [75.18402863, 12.08514118], [75.18431091, 12.08514118], [75.18431091, 12.08570194], [75.18458557, 12.08569527], [75.18458557, 12.08597279], [75.18514252, 12.08597088], [75.18514252, 12.08681202], [75.18541718, 12.08680534], [75.18541718, 12.08736134], [75.18569183, 12.08736134], [75.18569183, 12.08763885], [75.18597412, 12.08763885], [75.18597412, 12.08819485], [75.18653107, 12.08819485], [75.18653107, 12.08874893], [75.18681335, 12.08874035], [75.18681335, 12.08902931], [75.18734741, 12.08902931], [75.18734741, 12.0893116], [75.18875122, 12.08930492], [75.18875122, 12.0895834], [75.18930817, 12.0895834], [75.18930817, 12.08930492], [75.18985748, 12.0893116], [75.18985748, 12.08902931], [75.19013977, 12.08902931], [75.19013977, 12.08874035], [75.19041443, 12.08874893], [75.19041443, 12.08847332], [75.19069672, 12.08847332], [75.19069672, 12.08791733], [75.19097137, 12.08791924], [75.19097137, 12.08736134], [75.19125366, 12.08736134], [75.19125366, 12.08652878], [75.19152832, 12.08653069], [75.19152832, 12.08542061], [75.19180298, 12.08542061], [75.19180298, 12.08458042], [75.19152832, 12.08458328], [75.19152832, 12.08430672], [75.19180298, 12.08431053], [75.19180298, 12.08403111], [75.19152832, 12.08403111], [75.19152832, 12.08375072], [75.19124603, 12.08375072], [75.19124603, 12.08347034], [75.19097137, 12.08347321], [75.19097137, 12.08180428], [75.19124603, 12.08181095], [75.19124603, 12.08097172], [75.19152832, 12.08097172], [75.19152832, 12.08069038], [75.19125366, 12.0806942], [75.19125366, 12.08013821], [75.19152832, 12.08014107], [75.19152832, 12.07985973], [75.19124603, 12.07985973], [75.19124603, 12.07931137], [75.19152832, 12.07931137], [75.19152832, 12.07847023], [75.19180298, 12.07847214], [75.19180298, 12.07708359], [75.19208527, 12.07708359], [75.19208527, 12.0765276], [75.19235992, 12.07653046], [75.19235992, 12.07542038], [75.19264221, 12.07542038], [75.19264221, 12.07457924], [75.19291687, 12.07458401], [75.19291687, 12.07402802], [75.19319153, 12.07402992], [75.19319153, 12.07319069], [75.19347382, 12.07319355], [75.19347382, 12.07263756], [75.19374847, 12.07264042], [75.19374847, 12.07236195], [75.19403076, 12.07236195], [75.19403076, 12.07180977], [75.19431305, 12.07180977], [75.19431305, 12.07097244], [75.19458008, 12.07097244], [75.19458008, 12.07069302], [75.19486237, 12.07069969], [75.19486237, 12.07042027], [75.19513702, 12.07042027], [75.19513702, 12.07014179], [75.19654083, 12.07014179], [75.19654083, 12.06985855], [75.19763947, 12.06985855], [75.19763947, 12.07014179], [75.20014191, 12.07014179], [75.20014191, 12.07042027], [75.20153046, 12.07042027], [75.20153046, 12.07069969], [75.20207977, 12.07069302], [75.20207977, 12.07097244], [75.20263672, 12.07097244], [75.20263672, 12.07125187], [75.20318604, 12.07125187], [75.20318604, 12.07153034], [75.20375061, 12.07153034], [75.20375061, 12.07180977], [75.20430756, 12.07180977], [75.20430756, 12.07236195], [75.20458221, 12.07236195], [75.20458221, 12.07291985], [75.20513916, 12.07291985], [75.20513916, 12.07264042], [75.20541382, 12.07263756], [75.20541382, 12.07319355], [75.20597076, 12.07319355], [75.20597076, 12.07291794], [75.20652771, 12.07291794], [75.20652771, 12.07319355], [75.20735931, 12.07319355], [75.20735931, 12.07347202], [75.2076416, 12.07347202], [75.2076416, 12.07319355], [75.20819092, 12.07319355], [75.20819092, 12.07291794], [75.20874786, 12.07291985], [75.20874786, 12.07264042], [75.20929718, 12.07264042], [75.20929718, 12.07208061], [75.2095871, 12.07208443], [75.2095871, 12.07180595], [75.20986176, 12.07180977], [75.20986176, 12.07097244], [75.21013641, 12.07097244], [75.21013641, 12.07041454], [75.21069336, 12.07042027], [75.21069336, 12.07014179], [75.21098328, 12.07014179], [75.21098328, 12.06985855], [75.21152496, 12.06986237], [75.21152496, 12.06958389], [75.21180725, 12.06958389], [75.21180725, 12.06930542], [75.21208191, 12.06931019], [75.21208191, 12.06902981], [75.21235657, 12.06902981], [75.21235657, 12.06874943], [75.2131958, 12.06874943], [75.2131958, 12.06847095], [75.21347046, 12.06847095], [75.21347046, 12.06819344], [75.21375275, 12.06819344], [75.21375275, 12.06791782], [75.2140274, 12.06791973], [75.2140274, 12.06736088], [75.2142868, 12.06736088], [75.2142868, 12.06680965], [75.2151413, 12.06680489], [75.2151413, 12.06708336], [75.21569824, 12.06708145], [75.21569824, 12.06736088], [75.2168045, 12.06736088], [75.2168045, 12.06763935], [75.21736145, 12.06763268], [75.21736145, 12.06791973], [75.21819305, 12.06791973], [75.21819305, 12.06763268], [75.2195816, 12.06763268], [75.2195816, 12.06791973], [75.22013855, 12.06791782], [75.22013855, 12.06847095], [75.22042084, 12.06847095], [75.22042084, 12.06931019], [75.22013855, 12.06931019], [75.22013855, 12.07014179], [75.21985626, 12.07014179], [75.21985626, 12.07042027], [75.2195816, 12.07042027], [75.2195816, 12.07125187], [75.21901703, 12.07125187], [75.21901703, 12.07153034], [75.21875, 12.07153034], [75.21875, 12.07125187], [75.21848297, 12.07125187], [75.21848297, 12.07042027], [75.21819305, 12.07042027], [75.21819305, 12.06985855], [75.2179184, 12.06986237], [75.2179184, 12.06958389], [75.21763611, 12.06958389], [75.21763611, 12.06902695], [75.2159729, 12.06902981], [75.2159729, 12.06874943], [75.2151413, 12.06874943], [75.2151413, 12.06902981], [75.2142868, 12.06902981], [75.2142868, 12.06874943], [75.2140274, 12.06874943], [75.2140274, 12.06902981], [75.21347046, 12.06902981], [75.21347046, 12.06931019], [75.2131958, 12.06930542], [75.2131958, 12.06958389], [75.21291351, 12.06958389], [75.21291351, 12.06986237], [75.21235657, 12.06985855], [75.21235657, 12.07014179], [75.21208191, 12.07014179], [75.21208191, 12.07042027], [75.21180725, 12.07041454], [75.21180725, 12.07097244], [75.21151733, 12.07097244], [75.21151733, 12.07125187], [75.21125031, 12.07125187], [75.21125031, 12.07180977], [75.21097565, 12.07180595], [75.21098328, 12.07236195], [75.21069336, 12.07236195], [75.21069336, 12.07264042], [75.2104187, 12.07264042], [75.2104187, 12.07291985], [75.20986176, 12.07291794], [75.20986176, 12.07319355], [75.20903015, 12.07319355], [75.20903015, 12.07347202], [75.20874786, 12.07347202], [75.20874786, 12.07376099], [75.20848083, 12.07376099], [75.20848083, 12.07402992], [75.20791626, 12.07402992], [75.20791626, 12.0743103], [75.20680237, 12.07430553], [75.20680237, 12.07458401], [75.20652771, 12.07458401], [75.20652771, 12.07430553], [75.2040329, 12.0743103], [75.2040329, 12.07402992], [75.20375061, 12.07402992], [75.20375061, 12.07376099], [75.20347595, 12.07376099], [75.20347595, 12.07347202], [75.20319366, 12.07347202], [75.20319366, 12.07319355], [75.20291901, 12.07319355], [75.20291901, 12.07291794], [75.20263672, 12.07291985], [75.20263672, 12.07264042], [75.20207977, 12.07264042], [75.20207977, 12.07236195], [75.20180511, 12.07236195], [75.20180511, 12.07208443], [75.20153046, 12.07208443], [75.20153046, 12.07180595], [75.20096588, 12.07180977], [75.20096588, 12.07153034], [75.19875336, 12.07153034], [75.19875336, 12.07180977], [75.19763947, 12.07180977], [75.19763947, 12.07153034], [75.19568634, 12.07153034], [75.19568634, 12.07180977], [75.19541931, 12.07180595], [75.19541931, 12.07208443], [75.19513702, 12.07208061], [75.19513702, 12.07236195], [75.19486237, 12.07236195], [75.19486237, 12.07264042], [75.19458008, 12.07263756], [75.19458008, 12.07347202], [75.19431305, 12.07347202], [75.19431305, 12.07402992], [75.19403076, 12.07402802], [75.19403076, 12.0759716], [75.19374847, 12.0759716], [75.19374847, 12.07680607], [75.19347382, 12.07680607], [75.19347382, 12.07708359], [75.19319153, 12.07708168], [75.19319153, 12.07792091], [75.19291687, 12.07792091], [75.19291687, 12.07874966], [75.19264221, 12.07874966], [75.19264221, 12.07931137], [75.19291687, 12.07930565], [75.19291687, 12.07958221], [75.19264221, 12.07956791], [75.19264221, 12.08014107], [75.19235992, 12.08014107], [75.19235992, 12.08125019], [75.1920929, 12.08125019], [75.1920929, 12.08153057], [75.19235992, 12.08153057], [75.19235992, 12.08292103], [75.19208527, 12.08291626], [75.19208527, 12.08319473], [75.19235992, 12.08318996], [75.19235992, 12.08403111], [75.19264221, 12.0840292], [75.19264221, 12.08458328], [75.19291687, 12.08458328], [75.19291687, 12.08597279], [75.19264221, 12.08597279], [75.19264221, 12.08708286], [75.19235992, 12.08708286], [75.19235992, 12.08819485], [75.19208527, 12.08819485], [75.19208527, 12.08847332], [75.19180298, 12.08847141], [75.19180298, 12.08902931], [75.19152832, 12.08902931], [75.19152832, 12.0893116], [75.19124603, 12.0893116], [75.19124603, 12.08986092], [75.19097137, 12.08986092], [75.19097137, 12.0901413], [75.1904068, 12.0901413], [75.1904068, 12.09042168], [75.18958282, 12.09041691], [75.18958282, 12.09069538], [75.18930817, 12.09069538], [75.18930817, 12.09097099], [75.18902588, 12.09097099], [75.18902588, 12.09125137], [75.18791962, 12.09125137], [75.18791962, 12.09097099], [75.18736267, 12.09097099], [75.18736267, 12.09069538], [75.18680573, 12.09069538], [75.18680573, 12.09097099], [75.18597412, 12.09097099], [75.18597412, 12.08986092], [75.18569183, 12.08986092], [75.18569183, 12.0893116], [75.18514252, 12.0893116], [75.18514252, 12.08902931], [75.18486023, 12.08902931], [75.18486023, 12.08874035], [75.18430328, 12.08874893], [75.18430328, 12.08819485], [75.18374634, 12.08819485], [75.18374634, 12.08763885], [75.18319702, 12.08763885], [75.18319702, 12.08736134], [75.18291473, 12.08736134], [75.18291473, 12.08680534], [75.18264008, 12.08681202], [75.18264008, 12.08653069], [75.18235779, 12.08653069], [75.18235779, 12.08597088], [75.18208313, 12.08597279], [75.18208313, 12.08569527], [75.18180847, 12.08570194], [75.18180847, 12.08514118], [75.18125153, 12.08514118], [75.18125153, 12.08431053], [75.18096924, 12.08431053], [75.18096924, 12.08403111], [75.18041992, 12.08403111], [75.18041992, 12.08375072], [75.17986298, 12.08375072], [75.17986298, 12.08347034], [75.17958069, 12.08347321], [75.17958069, 12.08319473], [75.17903137, 12.08319473], [75.17903137, 12.08291626], [75.17874908, 12.08291626], [75.17874908, 12.08319473], [75.17847443, 12.08319473], [75.17847443, 12.08347321], [75.17791748, 12.08347034], [75.17791748, 12.08375072], [75.17736053, 12.08375072], [75.17736053, 12.08403111], [75.17624664, 12.08403111], [75.17624664, 12.08375072], [75.17485809, 12.08375072], [75.17485809, 12.08403111], [75.17458344, 12.0840292], [75.17458344, 12.0848608], [75.17485809, 12.0848608], [75.17485809, 12.08542061], [75.17514038, 12.08541679], [75.17514038, 12.08597279], [75.17485809, 12.08597088], [75.17485809, 12.08681202], [75.17430878, 12.08680534], [75.17430878, 12.08708286], [75.17346954, 12.08708286], [75.17346954, 12.08597279], [75.17292023, 12.08597279], [75.17292023, 12.08569527], [75.17263794, 12.08570194], [75.17263794, 12.08653069], [75.17236328, 12.08652878], [75.17236328, 12.08874893], [75.17263794, 12.08874035], [75.17263794, 12.0893116], [75.17292023, 12.08930492], [75.17292023, 12.0895834], [75.17346954, 12.08958054], [75.17346954, 12.08986092], [75.17375183, 12.08986092], [75.17375183, 12.0901413], [75.17457581, 12.0901413], [75.17457581, 12.09042168], [75.17514038, 12.09042168], [75.17514038, 12.0901413], [75.17597198, 12.0901413], [75.17597198, 12.09042168], [75.17708588, 12.09042168], [75.17708588, 12.09125137], [75.17680359, 12.09125137], [75.17680359, 12.09180546], [75.17652893, 12.09180546], [75.17652893, 12.09208298], [75.17597198, 12.09208107], [75.17597198, 12.09264183], [75.17569733, 12.09264183], [75.17569733, 12.0929203], [75.17541504, 12.09291744], [75.17541504, 12.09347343], [75.17514038, 12.09347057], [75.17510986, 12.09403038], [75.17485809, 12.09402657], [75.17485809, 12.09458256], [75.17458344, 12.09458256], [75.17458344, 12.09597111], [75.17485809, 12.0959692], [75.17485809, 12.09653187], [75.17514038, 12.09653187], [75.17514038, 12.09681034], [75.17540741, 12.09681034], [75.17541504, 12.09736156], [75.17569733, 12.09736156], [75.17569733, 12.09764194], [75.17597198, 12.09764194], [75.17597198, 12.09793091], [75.17624664, 12.0979147], [75.17624664, 12.09819412], [75.17652893, 12.09819412], [75.17652893, 12.09847164], [75.17679596, 12.09847164], [75.17679596, 12.09875202], [75.17708588, 12.09875202], [75.17708588, 12.09902954], [75.17736053, 12.09902954], [75.17736053, 12.09875202], [75.17791748, 12.09875202], [75.17791748, 12.09847164], [75.17819214, 12.09847164], [75.17819214, 12.09819412], [75.17847443, 12.09819412], [75.17847443, 12.0979147], [75.17874908, 12.09793091], [75.17874908, 12.09708118], [75.17903137, 12.09708405], [75.17903137, 12.09691048], [75.17903137, 12.09680557], [75.17930603, 12.09681034], [75.17930603, 12.09624863], [75.17958069, 12.09624863], [75.17958069, 12.09569073], [75.17986298, 12.09569645], [75.17986298, 12.09514046], [75.18013763, 12.09514046], [75.18013763, 12.09487057], [75.18068695, 12.09487057], [75.18068695, 12.09458065], [75.18125153, 12.09458256], [75.18125153, 12.09430504], [75.18152618, 12.09430981], [75.18152618, 12.09403038], [75.18264008, 12.09403038], [75.18264008, 12.09375191], [75.18461609, 12.09374905], [75.18489075, 12.09374905], [75.18541718, 12.09375191], [75.18541718, 12.09347057], [75.18596649, 12.09347057], [75.18596649, 12.09375191], [75.18763733, 12.09375191], [75.18763733, 12.09403038], [75.18818665, 12.09403038], [75.18818665, 12.09430981], [75.18846893, 12.09430504], [75.18846893, 12.09458256], [75.18875122, 12.09458256], [75.18875122, 12.09500027], [75.18875122, 12.09514046], [75.18902588, 12.09514046], [75.18902588, 12.09569645], [75.18958282, 12.09569645], [75.18958282, 12.09597111], [75.18985748, 12.0959692], [75.18985748, 12.09624863], [75.19029999, 12.09624863], [75.1904068, 12.09624863], [75.1904068, 12.09653187], [75.19069672, 12.09653187], [75.19069672, 12.09681034], [75.19097137, 12.09680557], [75.19097137, 12.09708405], [75.19124603, 12.09708118], [75.19124603, 12.09764194], [75.19097137, 12.09764004], [75.19097137, 12.09819412], [75.19069672, 12.09819126], [75.19069672, 12.09902954], [75.19097137, 12.09902763], [75.19097137, 12.09958363], [75.19124603, 12.09957886], [75.19124603, 12.10013962], [75.19152832, 12.10013962], [75.19152832, 12.10042], [75.19264221, 12.10041809], [75.19264221, 12.1006937], [75.19291687, 12.10068035], [75.19291687, 12.10181141], [75.19264221, 12.10180569], [75.19264221, 12.10208416], [75.19291687, 12.10207939], [75.19291687, 12.10236168], [75.19319153, 12.10236168], [75.19319153, 12.10264015], [75.19291687, 12.10264015], [75.19291687, 12.10291958], [75.19319153, 12.10291576], [75.19319153, 12.10319424], [75.19347382, 12.10319424], [75.19347382, 12.10375023], [75.19319153, 12.10374069], [75.19319153, 12.10431099], [75.19347382, 12.10430622], [75.19347382, 12.10486221], [75.19319153, 12.10486031], [75.19319153, 12.10542107], [75.19291687, 12.1054163], [75.19291687, 12.10597229], [75.19264221, 12.10597038], [75.19264221, 12.10625267], [75.19235992, 12.10625267], [75.19235992, 12.10681057], [75.19208527, 12.1068058], [75.19208527, 12.10708427], [75.19152832, 12.10708046], [75.19152832, 12.10736275], [75.19180298, 12.10735989], [75.19180298, 12.10847187], [75.1920929, 12.10846996], [75.1920929, 12.11181068], [75.19374847, 12.11180687], [75.19374847, 12.11208344], [75.19403076, 12.11207962], [75.19403076, 12.11236095], [75.19431305, 12.11236095], [75.19431305, 12.11264133], [75.19541931, 12.11264133], [75.19541931, 12.11236095], [75.19596863, 12.11236095], [75.19596863, 12.11264133], [75.19625092, 12.11264133], [75.19625092, 12.1129303], [75.19652557, 12.11291695], [75.19654083, 12.11375141], [75.19625092, 12.11375141], [75.19625092, 12.11430931], [75.19596863, 12.11430931], [75.19596863, 12.11514091], [75.19568634, 12.11514091], [75.19568634, 12.11541939], [75.19596863, 12.11541653], [75.19596863, 12.115695], [75.19625092, 12.11568069], [75.19625092, 12.11625099], [75.19654083, 12.11625099], [75.19654083, 12.11653137], [75.19708252, 12.11653137], [75.19708252, 12.11681175], [75.19735718, 12.11681175], [75.19735718, 12.11736107], [75.19708252, 12.11736107], [75.19708252, 12.11764145], [75.19680786, 12.11764145], [75.19680786, 12.11792183], [75.19596863, 12.11791706], [75.19596863, 12.11819458], [75.19569397, 12.11819458], [75.19569397, 12.11847115], [75.19541931, 12.11847115], [75.19541931, 12.11875057], [75.19513702, 12.11875057], [75.19513702, 12.11903191], [75.19486237, 12.11903191], [75.19486237, 12.11931038], [75.19458008, 12.11930466], [75.19458008, 12.11958313], [75.19403076, 12.11958122], [75.19403076, 12.12042046], [75.19347382, 12.12041664], [75.19347382, 12.12069321], [75.19319153, 12.12069321], [75.19319153, 12.12097359], [75.19291687, 12.12097073], [75.19291687, 12.12152958], [75.19264221, 12.12152672], [75.19264221, 12.12236118], [75.19291687, 12.12235928], [75.19291687, 12.12292004], [75.19264221, 12.12291527], [75.19264221, 12.12347126], [75.19235992, 12.12347126], [75.19235992, 12.12375164], [75.1920929, 12.12375164], [75.1920929, 12.12403202], [75.19180298, 12.12403202], [75.19180298, 12.12430954], [75.19097137, 12.12430573], [75.19097137, 12.1245842], [75.19069672, 12.12458134], [75.19069672, 12.12487125], [75.1904068, 12.12487125], [75.1904068, 12.12514019], [75.19013977, 12.12514019], [75.19013977, 12.12541962], [75.18985748, 12.12541771], [75.18985748, 12.12569427], [75.19013977, 12.12569141], [75.19013977, 12.12625027], [75.18985748, 12.12625027], [75.18985748, 12.12681007], [75.18958282, 12.12680626], [75.18958282, 12.12736225], [75.18930817, 12.12736225], [75.18930817, 12.12791634], [75.18902588, 12.12791634], [75.18902588, 12.12819386], [75.18875122, 12.12819386], [75.18875122, 12.12958431], [75.18902588, 12.12957954], [75.18902588, 12.12985992], [75.18930817, 12.12985992], [75.18930817, 12.1301403], [75.18985748, 12.1301403], [75.18985748, 12.13042068], [75.19069672, 12.13042068], [75.19069672, 12.1301403], [75.19124603, 12.1301403], [75.19124603, 12.12985992], [75.19152832, 12.12985992], [75.19152832, 12.12957954], [75.19208527, 12.12958431], [75.19208527, 12.12985992], [75.19235992, 12.12985992], [75.19235992, 12.13125038], [75.1920929, 12.13125038], [75.1920929, 12.13153267], [75.19180298, 12.13153267], [75.19180298, 12.13181114], [75.1920929, 12.13181114], [75.1920929, 12.13264275], [75.19069672, 12.13264275], [75.19069672, 12.13236046], [75.18930817, 12.13236237], [75.18930817, 12.13208199], [75.18902588, 12.13208199], [75.18902588, 12.1315279], [75.18875122, 12.13153267], [75.18875122, 12.13125038], [75.18846893, 12.13125038], [75.18846893, 12.13097191], [75.18815613, 12.13097191], [75.18791962, 12.13097191], [75.18791962, 12.13041592], [75.18763733, 12.13042068], [75.18763733, 12.12985992], [75.18734741, 12.12985992], [75.18734741, 12.12957954], [75.18708038, 12.12958431], [75.18708038, 12.12819386], [75.18736267, 12.12819386], [75.18736267, 12.12791634], [75.18791962, 12.12791634], [75.18791962, 12.12736225], [75.18819427, 12.12736225], [75.18819427, 12.12708378], [75.18846893, 12.12708378], [75.18846893, 12.12680626], [75.18875122, 12.12681007], [75.18875122, 12.12625027], [75.18902588, 12.12625027], [75.18902588, 12.12569141], [75.18930817, 12.12569427], [75.18930817, 12.12541771], [75.18958282, 12.12541962], [75.18958282, 12.12514019], [75.18985748, 12.12514019], [75.18985748, 12.12458134], [75.18958282, 12.1245842], [75.18958282, 12.12374878], [75.18985748, 12.12375164], [75.18985748, 12.12347126], [75.19013977, 12.12347126], [75.19013977, 12.12319565], [75.19041443, 12.12319565], [75.19041443, 12.12180519], [75.19069672, 12.12180996], [75.19069672, 12.1212492], [75.19097137, 12.1212492], [75.19097137, 12.12042046], [75.19124603, 12.12042046], [75.19124603, 12.11986065], [75.19152832, 12.11986065], [75.19152832, 12.11903191], [75.19180298, 12.11903191], [75.19180298, 12.11847115], [75.19208527, 12.11847115], [75.19208527, 12.11763859], [75.19235992, 12.11764145], [75.19235992, 12.11681175], [75.1920929, 12.11681175], [75.1920929, 12.11653137], [75.19180298, 12.11653137], [75.19180298, 12.11625099], [75.19124603, 12.11625099], [75.19124603, 12.11597061], [75.19097137, 12.11597347], [75.19097137, 12.115695], [75.19081116, 12.115695], [75.19013977, 12.115695], [75.19013977, 12.11513901], [75.18985748, 12.11514091], [75.18985748, 12.11486053], [75.18958282, 12.11486053], [75.18958282, 12.11430454], [75.18930817, 12.11430931], [75.18930817, 12.11375141], [75.18902588, 12.11375141], [75.18902588, 12.11334991], [75.18902588, 12.11263943], [75.18930817, 12.11264133], [75.18930817, 12.11207962], [75.18985748, 12.11208344], [75.18985748, 12.11180687], [75.19013977, 12.11181068], [75.19013977, 12.11153126], [75.1904068, 12.11153126], [75.1904068, 12.11096954], [75.19069672, 12.11097336], [75.19069672, 12.11041737], [75.19097137, 12.11042118], [75.19097137, 12.10818958], [75.19069672, 12.10819435], [75.19069672, 12.1068058], [75.1904068, 12.10681057], [75.1904068, 12.10597038], [75.19013977, 12.10597229], [75.19013977, 12.10569382], [75.19041443, 12.10569382], [75.19041443, 12.10486221], [75.19069672, 12.10486221], [75.19069672, 12.10430622], [75.19124603, 12.10431099], [75.19124603, 12.10374069], [75.19152832, 12.10375023], [75.19152832, 12.10291576], [75.19180298, 12.10291958], [75.19180298, 12.10264015], [75.19152832, 12.10264015], [75.19152832, 12.10124969], [75.19069672, 12.10124969], [75.19069672, 12.10068035], [75.19041443, 12.1006937], [75.19041443, 12.0998621], [75.1902771, 12.0998621], [75.19013977, 12.0998621], [75.19013977, 12.09930611], [75.18985748, 12.09930992], [75.18985748, 12.09875202], [75.18958282, 12.09875202], [75.18958282, 12.09819126], [75.18930817, 12.09819412], [75.18930817, 12.09680557], [75.18902588, 12.09681034], [75.18902588, 12.09653187], [75.18875122, 12.09653187], [75.18875122, 12.09624863], [75.18763733, 12.09624863], [75.18763733, 12.09653187], [75.18653107, 12.09653187], [75.18653107, 12.09624863], [75.18486023, 12.09624863], [75.18486023, 12.0959692], [75.18458557, 12.09597111], [75.18458557, 12.09569645], [75.18374634, 12.09569645], [75.18374634, 12.09541798], [75.18319702, 12.09542179], [75.18318176, 12.09514046], [75.18180847, 12.09514046], [75.18180847, 12.09542179], [75.18125153, 12.09541798], [75.18125153, 12.09597111], [75.18096924, 12.09597111], [75.18096924, 12.09623146], [75.18096924, 12.09736156], [75.18068695, 12.09736156], [75.18068695, 12.09764194], [75.18041992, 12.09764194], [75.18041992, 12.09793091], [75.18013763, 12.0979147], [75.18013763, 12.09819412], [75.17986298, 12.09819412], [75.17986298, 12.09847164], [75.17958069, 12.09847164], [75.17958069, 12.09875202], [75.17903137, 12.09875202], [75.17903137, 12.09902954], [75.17874908, 12.09902763], [75.17874908, 12.09958363], [75.17847443, 12.09958363], [75.17847443, 12.0998621], [75.17817688, 12.09986019], [75.17817688, 12.10013962], [75.17791748, 12.10013962], [75.17791748, 12.10042], [75.17708588, 12.10041809], [75.17708588, 12.1006937], [75.17624664, 12.1006937], [75.17624664, 12.10097218], [75.17430878, 12.10097218], [75.17430878, 12.1006937], [75.17318726, 12.10068035], [75.17318726, 12.10264015], [75.17346954, 12.10264015], [75.17346954, 12.10347176], [75.17318726, 12.10346985], [75.17318726, 12.10681057], [75.17292023, 12.1068058], [75.17292023, 12.10819435], [75.17263794, 12.10818958], [75.17263794, 12.10875034], [75.17236328, 12.10875034], [75.17236328, 12.11208344], [75.17263794, 12.11207962], [75.17263794, 12.11264133], [75.17236328, 12.11263943], [75.17236328, 12.11319542], [75.17208099, 12.1131897], [75.17208099, 12.11375141], [75.17152405, 12.11375141], [75.17152405, 12.11458302], [75.17124939, 12.11458111], [75.17124939, 12.11514091], [75.17069244, 12.11514091], [75.17069244, 12.11541939], [75.16986084, 12.11541653], [75.16986084, 12.115695], [75.16874695, 12.11568069], [75.16874695, 12.11625099], [75.16819763, 12.11625099], [75.16819763, 12.11681175], [75.16791534, 12.11680508], [75.16792297, 12.11736107], [75.16764069, 12.11736107], [75.16764069, 12.11764145], [75.1673584, 12.11764145], [75.1673584, 12.11792183], [75.16623688, 12.11792183], [75.16623688, 12.11736107], [75.1654129, 12.11736107], [75.1654129, 12.11708069], [75.16513824, 12.1170826], [75.16513824, 12.11680508], [75.16486359, 12.11680508], [75.16486359, 12.1170826], [75.16374969, 12.11708069], [75.16374969, 12.11736107], [75.16291809, 12.11736107], [75.16291809, 12.11792183], [75.16236115, 12.11791706], [75.16236115, 12.11819458], [75.16208649, 12.11819458], [75.16208649, 12.11847115], [75.16179657, 12.11847115], [75.16179657, 12.11903191], [75.16152954, 12.11903191], [75.16152954, 12.11931038], [75.16124725, 12.11931038], [75.16124725, 12.12042046], [75.16152954, 12.12042046], [75.16152954, 12.12152958], [75.1618042, 12.12152672], [75.1618042, 12.12236118], [75.16208649, 12.12236118], [75.16208649, 12.12347126], [75.16236115, 12.12347126], [75.16236115, 12.12375164], [75.1626358, 12.12375164], [75.1626358, 12.12430954], [75.16291809, 12.12430954], [75.16291809, 12.12541962], [75.16317749, 12.12541962], [75.16317749, 12.12625027], [75.16347504, 12.12625027], [75.16347504, 12.12736225], [75.16374969, 12.12736225], [75.16374969, 12.13069439], [75.16401672, 12.13068867], [75.16401672, 12.13181114], [75.16430664, 12.13180637], [75.16430664, 12.13319016], [75.16401672, 12.13320065], [75.16401672, 12.13374996], [75.16374969, 12.13374996], [75.16374969, 12.13431072], [75.16346741, 12.13431072], [75.16346741, 12.13625145], [75.16317749, 12.13625145], [75.16317749, 12.13653088], [75.16291809, 12.13652897], [75.16291809, 12.1370821], [75.1626358, 12.13708019], [75.1626358, 12.13764095], [75.16208649, 12.13764095], [75.16208649, 12.13875103], [75.16179657, 12.13875103], [75.16179657, 12.13931084], [75.16152954, 12.13930511], [75.16152954, 12.13986111], [75.1609726, 12.13985157], [75.1609726, 12.14014053], [75.16069794, 12.14014053], [75.16069794, 12.14042091], [75.16041565, 12.1404171], [75.16041565, 12.14069462], [75.1598587, 12.14069462], [75.1598587, 12.14097309], [75.15957642, 12.14097118], [75.15957642, 12.14153099], [75.15930939, 12.14153099], [75.15930176, 12.14264107], [75.1590271, 12.14263916], [75.1590271, 12.14347267], [75.15847015, 12.14346886], [75.15847015, 12.14375114], [75.15791321, 12.14375114], [75.15791321, 12.14403152], [75.15763855, 12.14403152], [75.15763855, 12.1443119], [75.1570816, 12.14430523], [75.1570816, 12.14458275], [75.15680695, 12.14458275], [75.15680695, 12.14486122], [75.15651703, 12.14486122], [75.15651703, 12.14542198], [75.15625, 12.14541721], [75.15625, 12.14569473], [75.15598297, 12.14569092], [75.15598297, 12.14598179], [75.15569305, 12.14598179], [75.15569305, 12.14625072], [75.1554184, 12.14625072], [75.1554184, 12.14680958], [75.15486145, 12.14680958], [75.15486145, 12.14763927], [75.15458679, 12.14763927], [75.15458679, 12.14847088], [75.15429688, 12.14847088], [75.15429688, 12.14904118], [75.15402985, 12.14904118], [75.15402985, 12.14931011], [75.15374756, 12.14930534], [75.15374756, 12.15208435], [75.1534729, 12.15208054], [75.1534729, 12.15375042], [75.15319824, 12.15375042], [75.15319824, 12.15458393], [75.1534729, 12.15458202], [75.1534729, 12.15513992], [75.15374756, 12.15513992], [75.15374756, 12.15764046], [75.1534729, 12.15764046], [75.1534729, 12.15903091], [75.15319824, 12.15902805], [75.15319824, 12.15958214], [75.15291595, 12.15958214], [75.15291595, 12.16069412], [75.1526413, 12.16069031], [75.1526413, 12.16125011], [75.15235901, 12.16125011], [75.15235901, 12.16181087], [75.15207672, 12.16181087], [75.15207672, 12.16264057], [75.15180206, 12.16263771], [75.15180206, 12.1631937], [75.1515274, 12.1631937], [75.1515274, 12.16402912], [75.15123749, 12.16401958], [75.15123749, 12.16431141], [75.15097046, 12.16431141], [75.15097046, 12.16514111], [75.1506958, 12.1651392], [75.1506958, 12.16569519], [75.15040588, 12.16569042], [75.15040588, 12.16625118], [75.15013885, 12.16625118], [75.15013885, 12.16708279], [75.14985657, 12.16707993], [75.14985657, 12.16764069], [75.14958191, 12.16763878], [75.14958191, 12.16847324], [75.14930725, 12.16847134], [75.14930725, 12.16902924], [75.14902496, 12.16902924], [75.14902496, 12.16958332], [75.14820099, 12.16958141], [75.14820099, 12.16986084], [75.14763641, 12.16986084], [75.14763641, 12.17015266], [75.14736176, 12.17015266], [75.14736176, 12.1704216], [75.14680481, 12.17041683], [75.14680481, 12.1706953], [75.14653015, 12.1706953], [75.14653015, 12.17097092], [75.14624786, 12.17097092], [75.14624786, 12.1712513], [75.14597321, 12.1712513], [75.14597321, 12.17181015], [75.14569092, 12.17180538], [75.14569092, 12.1720829], [75.14541626, 12.1720829], [75.14541626, 12.17236137], [75.1451416, 12.17236137], [75.1451416, 12.17292023], [75.14485931, 12.17291737], [75.14485931, 12.17347336], [75.14457703, 12.17347145], [75.14457703, 12.1740303], [75.14430237, 12.17402744], [75.14430237, 12.17458344], [75.14402771, 12.17458057], [75.14402771, 12.17486095], [75.14375305, 12.17486095], [75.14375305, 12.17541981], [75.14347076, 12.17541695], [75.14347076, 12.17597103], [75.14319611, 12.17595959], [75.14319611, 12.17653179], [75.14291382, 12.17652702], [75.14291382, 12.17708397], [75.14263916, 12.17708397], [75.14263916, 12.17819309], [75.14235687, 12.17819118], [75.14235687, 12.18013954], [75.14263916, 12.18013954], [75.14263916, 12.18153], [75.14235687, 12.18153], [75.1423645, 12.1823597], [75.14206696, 12.1823597], [75.14206696, 12.18292046], [75.14180756, 12.18291569], [75.14180756, 12.18347168], [75.1415329, 12.18347168], [75.1415329, 12.18402958], [75.14068604, 12.18402958], [75.14068604, 12.18431091], [75.14013672, 12.18430614], [75.14013672, 12.18458366], [75.13930511, 12.18458366], [75.13930511, 12.18486214], [75.13903046, 12.18486023], [75.13903046, 12.18514919], [75.13819122, 12.18514919], [75.13819122, 12.18542099], [75.13735962, 12.18541622], [75.13735962, 12.18569374], [75.13709259, 12.18569183], [75.13709259, 12.18624973], [75.13680267, 12.18624973], [75.13680267, 12.18653107], [75.13652802, 12.18653107], [75.13652802, 12.18681145], [75.13626099, 12.18681145], [75.13626099, 12.18792057], [75.13597107, 12.1879158], [75.13597107, 12.18819427], [75.13625336, 12.18819427], [75.13626099, 12.18847179], [75.13597107, 12.18847179], [75.13597107, 12.18931103], [75.13569641, 12.18931103], [75.13569641, 12.1904211], [75.13540649, 12.1904211], [75.13540649, 12.19153118], [75.13513947, 12.19153118], [75.13513947, 12.19181061], [75.13485718, 12.19181061], [75.13485718, 12.19236088], [75.13458252, 12.19236088], [75.13458252, 12.19292068], [75.13402557, 12.19291687], [75.13402557, 12.19319534], [75.13375092, 12.19318962], [75.13375092, 12.19375134], [75.13346863, 12.19375134], [75.13346863, 12.19430923], [75.1332016, 12.19430923], [75.1332016, 12.19541931], [75.13291931, 12.1954174], [75.13291931, 12.1959734], [75.13263702, 12.19597054], [75.13263702, 12.19681168], [75.13236237, 12.196805], [75.13236237, 12.19819546], [75.13208008, 12.19819069], [75.13208008, 12.1993103], [75.13236237, 12.19930458], [75.13236237, 12.19958305], [75.13263702, 12.19958305], [75.13263702, 12.19986057], [75.13291931, 12.19986057], [75.13291931, 12.20069313], [75.13263702, 12.20069122], [75.13263702, 12.20263863], [75.13236237, 12.20263863], [75.13236237, 12.20291996], [75.13208008, 12.20291805], [75.13208008, 12.20347118], [75.13181305, 12.20346928], [75.13181305, 12.20375156], [75.13153076, 12.20375156], [75.13153076, 12.20403194], [75.13124847, 12.20403194], [75.13124847, 12.20431042], [75.13096619, 12.20431042], [75.13096619, 12.20514202], [75.13069153, 12.20514011], [75.13069153, 12.2070837], [75.13041687, 12.20708179], [75.13041687, 12.20792007], [75.13014221, 12.20791626], [75.13014221, 12.20819378], [75.12985992, 12.20819092], [75.12985992, 12.20932198], [75.12958527, 12.20930576], [75.12958527, 12.21097183], [75.12930298, 12.21097183], [75.12930298, 12.21152973], [75.12902832, 12.21152782], [75.12902832, 12.21208191], [75.12847137, 12.21208382], [75.12847137, 12.21236229], [75.12763977, 12.21236038], [75.12763977, 12.21264267], [75.12680817, 12.21264267], [75.12680817, 12.21292114], [75.12596893, 12.21292114], [75.12596893, 12.21264267], [75.12513733, 12.21264267], [75.12513733, 12.21292114], [75.12486267, 12.21291637], [75.12486267, 12.21319389], [75.12430573, 12.21319389], [75.12430573, 12.21347237], [75.12403107, 12.21347046], [75.12403107, 12.21375275], [75.12346649, 12.21375275], [75.12346649, 12.21403122], [75.1220932, 12.21403122], [75.1220932, 12.21375275], [75.12152863, 12.21375275], [75.12152863, 12.21319199], [75.12124634, 12.21319389], [75.12124634, 12.2126379], [75.12097168, 12.21264267], [75.12097168, 12.21207142], [75.12069702, 12.21208191], [75.12069702, 12.21152782], [75.1204071, 12.21152973], [75.1204071, 12.21097183], [75.12014008, 12.21097183], [75.12014008, 12.21069431], [75.12041473, 12.21069431], [75.12041473, 12.21041584], [75.12014008, 12.21041965], [75.12014008, 12.20985985], [75.12041473, 12.20985985], [75.12041473, 12.20930576], [75.12069702, 12.20932198], [75.12069702, 12.20874977], [75.12097168, 12.20874977], [75.12097168, 12.20819092], [75.12124634, 12.20819378], [75.12124634, 12.20763779], [75.12152863, 12.20763969], [75.12152863, 12.20681], [75.12180328, 12.20681], [75.12180328, 12.20596886], [75.12208557, 12.20597172], [75.12208557, 12.20514011], [75.12236023, 12.20514202], [75.12236023, 12.20486164], [75.12208557, 12.20486164], [75.12208557, 12.20430565], [75.12180328, 12.20431042], [75.12180328, 12.20403194], [75.12152863, 12.20403194], [75.12152863, 12.20375156], [75.1212616, 12.20375156], [75.1212616, 12.20346928], [75.12068176, 12.20346928], [75.11985779, 12.20346928], [75.11985779, 12.20375156], [75.11958313, 12.20375156], [75.11958313, 12.20431042], [75.11930847, 12.20431042], [75.11930847, 12.20486164], [75.11902618, 12.20486164], [75.11902618, 12.20514202], [75.11875153, 12.20514202], [75.11875153, 12.20541954], [75.11846924, 12.20541763], [75.11846924, 12.2056942], [75.11791992, 12.20569134], [75.11791992, 12.20625019], [75.11763763, 12.20625019], [75.11763763, 12.2070837], [75.11736298, 12.20708179], [75.11736298, 12.20763969], [75.11708069, 12.20763969], [75.11708069, 12.20874977], [75.11680603, 12.20874977], [75.11680603, 12.20958424], [75.11653137, 12.20957947], [75.11653137, 12.21014023], [75.11624908, 12.21014023], [75.11624908, 12.21069431], [75.1159668, 12.21068859], [75.1159668, 12.21125031], [75.11569214, 12.21125031], [75.11569214, 12.21208191], [75.11541748, 12.21207142], [75.11541748, 12.21264267], [75.11513519, 12.2126379], [75.11513519, 12.21319389], [75.11486053, 12.21319199], [75.11486053, 12.21403122], [75.11458588, 12.21402836], [75.11458588, 12.21513844], [75.11429596, 12.2151289], [75.11429596, 12.21542072], [75.11402893, 12.21542072], [75.11402893, 12.2165308], [75.11374664, 12.2165308], [75.11374664, 12.21764088], [75.11347198, 12.21763802], [75.11347198, 12.21847343], [75.11319733, 12.21846962], [75.11319733, 12.21903133], [75.11292267, 12.21903133], [75.11292267, 12.21931076], [75.11264038, 12.21931076], [75.11264038, 12.21986103], [75.11235809, 12.21986103], [75.11235809, 12.22069454], [75.11206818, 12.22068977], [75.11206818, 12.22153091], [75.11180878, 12.22152901], [75.11180878, 12.22236061], [75.11152649, 12.22236061], [75.11152649, 12.22292233], [75.11125183, 12.22292233], [75.11125183, 12.22375107], [75.11096954, 12.22375107], [75.11096954, 12.22458267], [75.11068726, 12.2245779], [75.11068726, 12.22514057], [75.11042023, 12.22513866], [75.11042023, 12.22597313], [75.11013794, 12.22597122], [75.11013794, 12.22681046], [75.10986328, 12.22681046], [75.10986328, 12.22736073], [75.10958099, 12.22736073], [75.10958099, 12.22819328], [75.10932159, 12.22819138], [75.10932159, 12.22902966], [75.10902405, 12.22902679], [75.10902405, 12.22986126], [75.10874939, 12.22986126], [75.10874939, 12.23069572], [75.10847473, 12.23069572], [75.10847473, 12.23124886], [75.10819244, 12.23124886], [75.10819244, 12.23208427], [75.10791779, 12.23208141], [75.10791779, 12.23291969], [75.1076355, 12.23291779], [75.10764313, 12.23375034], [75.10736084, 12.23375034], [75.10736084, 12.23431015], [75.10708618, 12.23431015], [75.10707092, 12.23513985], [75.10680389, 12.23513985], [75.10680389, 12.23550034], [75.10680389, 12.2359724], [75.10652924, 12.2359724], [75.10652924, 12.23617935], [75.10652924, 12.23681068], [75.10626984, 12.23681068], [75.10624695, 12.23764038], [75.10597229, 12.23763847], [75.10597229, 12.2381916], [75.10569763, 12.23820972], [75.10569763, 12.23903275], [75.10541534, 12.23902798], [75.10541534, 12.23986244], [75.10514069, 12.23985958], [75.10514069, 12.2404213], [75.10498047, 12.24041843], [75.1048584, 12.24041557], [75.1048584, 12.24082184], [75.1048584, 12.24125004], [75.10457611, 12.24125004], [75.10457611, 12.2418108], [75.10430908, 12.2418108], [75.10430908, 12.24264145], [75.10402679, 12.24263763], [75.10402679, 12.24319363], [75.10375214, 12.24319172], [75.10375214, 12.24375057], [75.10346985, 12.24375057], [75.10346985, 12.24458218], [75.10318756, 12.24458027], [75.10318756, 12.24514103], [75.1029129, 12.24513912], [75.1029129, 12.2453804], [75.1029129, 12.24597263], [75.10276794, 12.24597263], [75.10263824, 12.24597263], [75.10263824, 12.24652195], [75.10236359, 12.24652863], [75.10236359, 12.24736118], [75.1020813, 12.24736118], [75.1020813, 12.24792099], [75.10180664, 12.24792099], [75.10180664, 12.24875069], [75.10151672, 12.24875069], [75.10151672, 12.2493124], [75.10124969, 12.2493124], [75.10124969, 12.25014114], [75.10097504, 12.25013924], [75.10097504, 12.25069523], [75.10069275, 12.25069523], [75.10069275, 12.25125122], [75.10041809, 12.25125122], [75.10041809, 12.25208282], [75.10015106, 12.25208092], [75.10015106, 12.25264072], [75.09986115, 12.25263882], [75.09986115, 12.25347328], [75.09958649, 12.25347137], [75.09958649, 12.25402927], [75.09929657, 12.25402927], [75.09929657, 12.25486088], [75.09902954, 12.25486088], [75.09902954, 12.25569534], [75.09874725, 12.25569057], [75.09874725, 12.25652981], [75.0984726, 12.25652695], [75.0984726, 12.25708294], [75.09819794, 12.25708103], [75.09819794, 12.25792027], [75.09792328, 12.25792027], [75.09792328, 12.25875187], [75.09764099, 12.25874996], [75.09764099, 12.25958443], [75.0973587, 12.25958061], [75.0973587, 12.26014042], [75.09708405, 12.26013756], [75.09708405, 12.26097202], [75.09680939, 12.26097202], [75.09680176, 12.26152992], [75.0965271, 12.26152802], [75.0965271, 12.2634716], [75.09625244, 12.2634697], [75.09625244, 12.26375008], [75.09597015, 12.26375008], [75.09597015, 12.26403046], [75.09570313, 12.26403046], [75.09570313, 12.26431274], [75.09541321, 12.26430607], [75.09541321, 12.26486206], [75.09513855, 12.26486015], [75.09513855, 12.26542091], [75.09486389, 12.26541615], [75.09486389, 12.26624966], [75.0945816, 12.26624107], [75.0945816, 12.26681137], [75.09430695, 12.26681137], [75.09430695, 12.26735973], [75.09402466, 12.26735973], [75.09402466, 12.2681942], [75.09375, 12.26819038], [75.09375, 12.26875019], [75.09348297, 12.26875019], [75.09348297, 12.26931095], [75.09319305, 12.26931095], [75.09319305, 12.27014065], [75.0929184, 12.27013779], [75.0929184, 12.27069378], [75.09263611, 12.27068996], [75.09263611, 12.27125072], [75.09236145, 12.27125072], [75.09236145, 12.27208233], [75.09208679, 12.27208042], [75.09208679, 12.27264118], [75.0918045, 12.27263927], [75.0918045, 12.27319527], [75.09152985, 12.27318954], [75.09152985, 12.27403069], [75.09124756, 12.27402878], [75.09124756, 12.27458286], [75.09095764, 12.27458], [75.09095764, 12.27514076], [75.09069824, 12.27513885], [75.09069824, 12.27597332], [75.09041595, 12.27597141], [75.09041595, 12.27653122], [75.0901413, 12.2765274], [75.0901413, 12.2770834], [75.08985901, 12.27708054], [75.08985901, 12.27792168], [75.08958435, 12.27791691], [75.08958435, 12.27847099], [75.08930206, 12.27847099], [75.08930206, 12.27902889], [75.0890274, 12.27902699], [75.0890274, 12.27986145], [75.08875275, 12.27986145], [75.08875275, 12.2804203], [75.08847046, 12.28041744], [75.08847046, 12.28097343], [75.08821106, 12.28097057], [75.08821106, 12.28180981], [75.08789825, 12.28180981], [75.08789825, 12.28236103], [75.08763885, 12.28236103], [75.08763885, 12.28292179], [75.08735657, 12.28292179], [75.08735657, 12.28375244], [75.08708191, 12.28375244], [75.08708191, 12.28431034], [75.08680725, 12.28431034], [75.08680725, 12.28514194], [75.08652496, 12.28514004], [75.08652496, 12.28569317], [75.08625031, 12.28569126], [75.08625031, 12.28625202], [75.08597565, 12.28625011], [75.08597565, 12.28708363], [75.08569336, 12.28707886], [75.08569336, 12.28763962], [75.0854187, 12.28763771], [75.0854187, 12.2881937], [75.08515167, 12.28819084], [75.08515167, 12.28903008], [75.08486176, 12.28902817], [75.08486176, 12.28958416], [75.0845871, 12.28957939], [75.0845871, 12.29014015], [75.08430481, 12.29014015], [75.08430481, 12.29097176], [75.08403015, 12.29096985], [75.08403015, 12.29152966], [75.08374786, 12.29152775], [75.08374786, 12.29208374], [75.08347321, 12.29208183], [75.08347321, 12.29292107], [75.08319092, 12.29292107], [75.08319092, 12.29348087], [75.08291626, 12.29348087], [75.08291626, 12.29403114], [75.0826416, 12.29403114], [75.0826416, 12.29486179], [75.08235931, 12.29486179], [75.08235931, 12.29542065], [75.08208466, 12.29541588], [75.08208466, 12.29597187], [75.08180237, 12.29596996], [75.08180237, 12.2968111], [75.08152771, 12.29680443], [75.08152771, 12.29736042], [75.08125305, 12.29736042], [75.08125305, 12.29792118], [75.08097076, 12.29792118], [75.08097076, 12.29875088], [75.08069611, 12.29875088], [75.08069611, 12.29931068], [75.08040619, 12.29931068], [75.08040619, 12.29986095], [75.08013916, 12.29986095], [75.08013916, 12.30069542], [75.07985687, 12.3006897], [75.07985687, 12.30125141], [75.07958221, 12.30125141], [75.07958221, 12.30208302], [75.07930756, 12.30208015], [75.07930756, 12.30264091], [75.07902527, 12.30263901], [75.07902527, 12.303195], [75.07875061, 12.30319023], [75.07875061, 12.30403137], [75.07847595, 12.3040266], [75.07847595, 12.3045826], [75.07818604, 12.30458069], [75.07818604, 12.30514145], [75.07791901, 12.30513859], [75.07791901, 12.30597305], [75.07763672, 12.30597115], [75.07763672, 12.30653191], [75.07736206, 12.30652714], [75.07736206, 12.30708313], [75.07707977, 12.30708122], [75.07707977, 12.30792046], [75.07681274, 12.30792046], [75.07681274, 12.30848026], [75.07653046, 12.30848026], [75.07653046, 12.30902958], [75.07624817, 12.30902672], [75.07624817, 12.30986118], [75.07595825, 12.30985928], [75.07595825, 12.31042194], [75.07569122, 12.31042194], [75.07569122, 12.31125164], [75.07541656, 12.31125164], [75.07541656, 12.31180954], [75.07514191, 12.31180573], [75.07514191, 12.31236172], [75.07485962, 12.31236172], [75.07485962, 12.31319427], [75.07458496, 12.31319427], [75.07459259, 12.31375027], [75.07430267, 12.31375027], [75.07430267, 12.31431007], [75.07402802, 12.31430626], [75.07402802, 12.31486225], [75.07375336, 12.31486225], [75.07375336, 12.31569386], [75.07347107, 12.31569099], [75.07347107, 12.31653023], [75.07319641, 12.31652832], [75.07319641, 12.31708431], [75.07292175, 12.31707859], [75.07292175, 12.31791973], [75.07263947, 12.31791592], [75.07263947, 12.31819439], [75.07235718, 12.31819153], [75.07235718, 12.31903267], [75.07208252, 12.3190279], [75.07208252, 12.31986237], [75.07180786, 12.31986046], [75.07180786, 12.32014275], [75.0715332, 12.32014275], [75.0715332, 12.32042122], [75.07125092, 12.32042122], [75.07125092, 12.32124996], [75.07096863, 12.32124996], [75.07096863, 12.3215313], [75.07068634, 12.3215313], [75.07068634, 12.32236004], [75.07041931, 12.32236004], [75.07041931, 12.3229208], [75.07013702, 12.32291603], [75.07013702, 12.32347202], [75.06986237, 12.32346058], [75.06986237, 12.32403088], [75.06958008, 12.32402897], [75.06958008, 12.32485962], [75.06930542, 12.32485962], [75.06931305, 12.32530022], [75.06931305, 12.32542133], [75.06919098, 12.32541943], [75.06903076, 12.32541656], [75.06903076, 12.32559013], [75.06903076, 12.32597256], [75.06886292, 12.32597256], [75.06874847, 12.32597256], [75.06874847, 12.32629204], [75.06874847, 12.32652569], [75.06847382, 12.32652569], [75.06847382, 12.32707977], [75.06847382, 12.32736111], [75.06819153, 12.32736111], [75.06819153, 12.32792091], [75.06791687, 12.3279171], [75.06791687, 12.32847309], [75.06764221, 12.32847309], [75.06764221, 12.3293047], [75.06735992, 12.3293047], [75.06735992, 12.32947063], [75.06735992, 12.32986069], [75.06707764, 12.32987022], [75.06707764, 12.3304224], [75.06694794, 12.33041668], [75.06680298, 12.33041668], [75.06679535, 12.33095932], [75.06678772, 12.33125114], [75.06652832, 12.33125114], [75.06652832, 12.33153057], [75.06625366, 12.33152676], [75.06624603, 12.33236122], [75.06624603, 12.33265114], [75.06613159, 12.33263874], [75.06597137, 12.33263874], [75.06597137, 12.33302021], [75.06597137, 12.33319473], [75.06569672, 12.33319473], [75.06569672, 12.33347321], [75.0654068, 12.3334713], [75.0654068, 12.33430958], [75.06513977, 12.33430481], [75.06513977, 12.33458328], [75.06485748, 12.33458328], [75.06485748, 12.33491135], [75.06485748, 12.33513927], [75.06458282, 12.33513927], [75.06458282, 12.33624935], [75.06430817, 12.33624935], [75.06430817, 12.33652973], [75.06401825, 12.33652973], [75.06401825, 12.33681011], [75.06375122, 12.33680534], [75.06375122, 12.33736134], [75.06346893, 12.33736134], [75.06346893, 12.33792019], [75.06319427, 12.33791542], [75.06319427, 12.33802032], [75.06319427, 12.3381958], [75.06346893, 12.3381958], [75.06346893, 12.33847141], [75.06318665, 12.33845997], [75.06318665, 12.33930969], [75.06291962, 12.33930969], [75.06291962, 12.33986187], [75.06263733, 12.33986187], [75.06263733, 12.34014034], [75.06236267, 12.34014034], [75.06236267, 12.34029007], [75.06236267, 12.34041977], [75.06263733, 12.34041786], [75.06263733, 12.34069443], [75.06319427, 12.34069443], [75.06319427, 12.34013653], [75.06346893, 12.34014034], [75.06346893, 12.33986187], [75.06318665, 12.33986187], [75.06318665, 12.33958054], [75.06346893, 12.33958435], [75.06346893, 12.33902836], [75.06375122, 12.33903027], [75.06375122, 12.33875179], [75.06401825, 12.33875179], [75.06401825, 12.33819103], [75.06430817, 12.3381958], [75.06430817, 12.33791542], [75.06401825, 12.33792019], [75.06401825, 12.33736134], [75.06430817, 12.33736134], [75.06430817, 12.33708286], [75.06458282, 12.33708286], [75.06458282, 12.33680534], [75.06485748, 12.33681011], [75.06485748, 12.33624935], [75.06513977, 12.33624935], [75.06513977, 12.33569145], [75.06541443, 12.33569527], [75.06541443, 12.33597088], [75.06569672, 12.33597088], [75.06569672, 12.33624935], [75.0654068, 12.33624935], [75.0654068, 12.33764172], [75.06513977, 12.33763981], [75.06513977, 12.33958435], [75.06485748, 12.33958054], [75.06485748, 12.34181023], [75.06458282, 12.34181023], [75.06458282, 12.3429203], [75.06430817, 12.34291553], [75.06430817, 12.34347153], [75.06401825, 12.34346962], [75.06401825, 12.34403038], [75.06375122, 12.34403038], [75.06375122, 12.34459114], [75.06346893, 12.34459114], [75.06346893, 12.34514046], [75.06319427, 12.3451376], [75.06319427, 12.34569359], [75.06291962, 12.34569359], [75.06291962, 12.34597206], [75.06263733, 12.34597015], [75.06263733, 12.34652996], [75.06236267, 12.34652805], [75.06236267, 12.34708214], [75.06208038, 12.34708023], [75.06208038, 12.34903145], [75.06180573, 12.34902763], [75.06180573, 12.34958363], [75.06153107, 12.34958172], [75.06153107, 12.35014057], [75.06124878, 12.35013771], [75.06124878, 12.3506937], [75.06098175, 12.3506918], [75.06098175, 12.35125065], [75.06069183, 12.35125065], [75.06069183, 12.35235977], [75.06041718, 12.35235977], [75.06041718, 12.35264111], [75.06014252, 12.3526392], [75.06014252, 12.35319519], [75.05986023, 12.35319042], [75.05986023, 12.35403061], [75.0595932, 12.35403061], [75.0595932, 12.35514069], [75.05930328, 12.35513878], [75.05930328, 12.35569477], [75.05902863, 12.35569477], [75.05902863, 12.35597324], [75.05874634, 12.35597134], [75.05874634, 12.35682106], [75.05847168, 12.35680485], [75.05847168, 12.35708332], [75.05821228, 12.35708141], [75.05821228, 12.35764122], [75.05791473, 12.35763931], [75.05791473, 12.35847092], [75.05764008, 12.35847092], [75.05764008, 12.35958958], [75.05735779, 12.35958958], [75.05735779, 12.36013889], [75.05708313, 12.36013889], [75.05708313, 12.36152935], [75.05680847, 12.36152935], [75.05680847, 12.36236095], [75.05652618, 12.36236095], [75.05652618, 12.36263943], [75.05569458, 12.36263943], [75.05569458, 12.36236095], [75.05541992, 12.36236095], [75.05541992, 12.36097145], [75.05569458, 12.36097336], [75.05569458, 12.36041737], [75.05596924, 12.36041927], [75.05596924, 12.35931015], [75.05625153, 12.35931015], [75.05625153, 12.3587513], [75.05652618, 12.3587513], [75.05652618, 12.35819054], [75.05680847, 12.3581953], [75.05680847, 12.35708332], [75.05708313, 12.35708332], [75.05708313, 12.35541725], [75.05735779, 12.35542107], [75.05735779, 12.35486126], [75.05764008, 12.35486126], [75.05764008, 12.35458279], [75.05819702, 12.35458279], [75.05819702, 12.3540287], [75.05847168, 12.35403061], [75.05847168, 12.35346127], [75.05874634, 12.35347271], [75.05874634, 12.35319519], [75.05902863, 12.35319519], [75.05902863, 12.35152912], [75.05930328, 12.35153103], [75.05930328, 12.3506918], [75.05958557, 12.3506937], [75.05958557, 12.35013771], [75.05986023, 12.35014057], [75.05986023, 12.34958172], [75.06014252, 12.34958363], [75.06014252, 12.34902763], [75.06041718, 12.34903145], [75.06041718, 12.34846973], [75.06069183, 12.34847164], [75.06069183, 12.34791565], [75.06098175, 12.34792137], [75.06098175, 12.34624958], [75.06124878, 12.34624958], [75.06124878, 12.34597015], [75.06097412, 12.34597206], [75.06097412, 12.34541607], [75.06124878, 12.34542274], [75.06124878, 12.34459114], [75.06153107, 12.34459114], [75.06153107, 12.34375], [75.06181335, 12.34375], [75.06181335, 12.34346962], [75.06208038, 12.34347153], [75.06208038, 12.34319401], [75.06236267, 12.34319401], [75.06236267, 12.34208393], [75.06263733, 12.34208393], [75.06263733, 12.34097195], [75.06208801, 12.34097195], [75.06208038, 12.34125042], [75.06180573, 12.34125042], [75.06180573, 12.34181023], [75.06180573, 12.34208393], [75.06153107, 12.34208393], [75.06153107, 12.34256172], [75.06153107, 12.34263992], [75.06124878, 12.34263992], [75.06124878, 12.34319401], [75.06097412, 12.34319401], [75.06098175, 12.34363079], [75.06098175, 12.34403038], [75.06069183, 12.34403038], [75.06069183, 12.34459114], [75.06041718, 12.34459114], [75.06041718, 12.34542274], [75.06014252, 12.34541607], [75.06014252, 12.34597206], [75.05986023, 12.34597015], [75.05986023, 12.34652996], [75.05958557, 12.34652805], [75.05958557, 12.34708214], [75.05930328, 12.34708023], [75.05930328, 12.34764862], [75.05902863, 12.34763813], [75.05902863, 12.34819412], [75.05874634, 12.34819031], [75.05874634, 12.34903145], [75.05847168, 12.34902763], [75.05847168, 12.34958363], [75.05821228, 12.34958172], [75.05821228, 12.35014057], [75.05791473, 12.35013771], [75.05791473, 12.3506937], [75.05764008, 12.3506918], [75.05764008, 12.35125065], [75.05735779, 12.35125065], [75.05735779, 12.35208225], [75.05708313, 12.35208035], [75.05708313, 12.35264111], [75.05680847, 12.3526392], [75.05680847, 12.35319519], [75.05652618, 12.35319519], [75.05652618, 12.35327435], [75.05652618, 12.35375118], [75.05625153, 12.35375118], [75.05625153, 12.35431099], [75.05596924, 12.35430527], [75.05596924, 12.35486126], [75.05569458, 12.35486126], [75.05569458, 12.35569477], [75.05541992, 12.35569477], [75.05541992, 12.35624886], [75.05513763, 12.35624886], [75.05513763, 12.35708332], [75.05484772, 12.35708141], [75.05484772, 12.35764122], [75.05458069, 12.35763931], [75.05458069, 12.3581953], [75.05430603, 12.35819054], [75.05430603, 12.35903168], [75.05403137, 12.35903168], [75.05403137, 12.35958958], [75.05374908, 12.35958958], [75.05374908, 12.36041927], [75.05347443, 12.36041737], [75.05347443, 12.36097336], [75.05319214, 12.36097145], [75.05319214, 12.36152935], [75.05291748, 12.36152935], [75.05291748, 12.36236095], [75.05264282, 12.36236095], [75.05264282, 12.36291981], [75.05236053, 12.36291981], [75.05236053, 12.36375237], [75.05207825, 12.36375237], [75.05207825, 12.36431026], [75.05180359, 12.36430454], [75.05180359, 12.36486244], [75.05152893, 12.36486244], [75.05152893, 12.36542034], [75.05124664, 12.36541843], [75.05124664, 12.36597061], [75.05097198, 12.36597061], [75.05097198, 12.36653042], [75.05069733, 12.36653042], [75.05069733, 12.36736202], [75.05042267, 12.36736202], [75.05042267, 12.36791992], [75.05014038, 12.36791801], [75.05014038, 12.3684721], [75.04985809, 12.36846924], [75.04985809, 12.36903], [75.04958344, 12.36902809], [75.04958344, 12.36958408], [75.04930878, 12.36957932], [75.04930878, 12.37014008], [75.04902649, 12.37014008], [75.04902649, 12.37097168], [75.04875183, 12.37096977], [75.04875183, 12.37152958], [75.04846954, 12.37152767], [75.04846954, 12.37208366], [75.04818726, 12.37207985], [75.04818726, 12.37263966], [75.04792023, 12.37263775], [75.04792023, 12.37319374], [75.04763794, 12.37319183], [75.04763794, 12.37374973], [75.04736328, 12.37374973], [75.04736328, 12.3745842], [75.04708099, 12.37457085], [75.04708099, 12.37514019], [75.04680634, 12.37513828], [75.04680634, 12.37569427], [75.04651642, 12.37569046], [75.04651642, 12.37625027], [75.04624939, 12.37625027], [75.04624939, 12.37681103], [75.04597473, 12.37680435], [75.04597473, 12.37736034], [75.04569244, 12.37736034], [75.04569244, 12.3779211], [75.04541779, 12.37791634], [75.04541779, 12.37847328], [75.04514313, 12.37847042], [75.04514313, 12.37903118], [75.04486084, 12.37902641], [75.04486084, 12.37958241], [75.04473114, 12.37958241], [75.04458618, 12.37958241], [75.04458618, 12.37983131], [75.04458618, 12.38014126], [75.04429626, 12.38014126], [75.04429626, 12.38070202], [75.04402924, 12.38070202], [75.04402924, 12.38125134], [75.04374695, 12.38125134], [75.04374695, 12.38153076], [75.04347229, 12.38152885], [75.04347229, 12.38208294], [75.04319763, 12.38208008], [75.04319763, 12.38264084], [75.04291534, 12.38263893], [75.04290771, 12.38319016], [75.04264069, 12.3832016], [75.04264069, 12.38376045], [75.0423584, 12.38376045], [75.0423584, 12.38431168], [75.04208374, 12.384305], [75.04208374, 12.38458347], [75.04180908, 12.38458061], [75.04180908, 12.38514137], [75.04152679, 12.38513947], [75.04152679, 12.38569546], [75.04125214, 12.38569069], [75.04125214, 12.38625145], [75.04096985, 12.38625145], [75.04096985, 12.38680458], [75.04069519, 12.38680458], [75.04069519, 12.38736057], [75.0404129, 12.38736057], [75.0404129, 12.38792038], [75.04013824, 12.38791656], [75.04013824, 12.38819313], [75.03986359, 12.38819313], [75.03986359, 12.38847256], [75.0395813, 12.38847065], [75.0395813, 12.38902855], [75.03930664, 12.38902855], [75.03930664, 12.38931179], [75.03902435, 12.38930511], [75.03902435, 12.38986111], [75.03874969, 12.3898592], [75.03874969, 12.39013863], [75.03847504, 12.39013863], [75.03847504, 12.39069557], [75.03819275, 12.3906908], [75.03819275, 12.39125156], [75.0376358, 12.39125156], [75.0376358, 12.39153194], [75.03710175, 12.39153194], [75.03710175, 12.39181042], [75.03652954, 12.3918047], [75.03652954, 12.39208412], [75.03569794, 12.39208412], [75.03569794, 12.3918047], [75.03542328, 12.39181042], [75.03542328, 12.39153194], [75.03514099, 12.39153194], [75.03514099, 12.3906908], [75.0349884, 12.3906908], [75.03458405, 12.39069557], [75.03458405, 12.3904171], [75.03404236, 12.39042187], [75.03404236, 12.39013863], [75.03320313, 12.39013863], [75.03320313, 12.39042187], [75.03236389, 12.3904171], [75.03236389, 12.39069557], [75.03180695, 12.39069557], [75.03180695, 12.39097118], [75.03151703, 12.39097118], [75.03151703, 12.39125156], [75.03096771, 12.39125156], [75.03096771, 12.39153194], [75.03069305, 12.39153194], [75.03069305, 12.39181042], [75.0304184, 12.39181042], [75.0304184, 12.39293098], [75.03013611, 12.39293098], [75.03013611, 12.39431], [75.02986145, 12.39430618], [75.02986145, 12.39486217], [75.02958679, 12.39486027], [75.02958679, 12.39542007], [75.02929688, 12.39542007], [75.02929688, 12.39624977], [75.02902985, 12.39624977], [75.02902985, 12.39680958], [75.02874756, 12.39680958], [75.02874756, 12.39764023], [75.0284729, 12.39764023], [75.0284729, 12.39819431], [75.02819824, 12.39819431], [75.02819824, 12.39875031], [75.02791595, 12.39875031], [75.02791595, 12.39958191], [75.0276413, 12.39958191], [75.0276413, 12.40014267], [75.02735901, 12.4001379], [75.02735901, 12.40069389], [75.02708435, 12.40069389], [75.02707672, 12.40113163], [75.02707672, 12.40125179], [75.02694702, 12.40124989], [75.02680206, 12.40124989], [75.02680206, 12.40139198], [75.02680206, 12.40180588], [75.0265274, 12.4017992], [75.0265274, 12.40235996], [75.02625275, 12.40235996], [75.02625275, 12.40292072], [75.02609253, 12.40291595], [75.02597046, 12.40291595], [75.02597046, 12.40347195], [75.02585602, 12.40347195], [75.0256958, 12.40347195], [75.0256958, 12.40360928], [75.0256958, 12.4040308], [75.02541351, 12.40402794], [75.02541351, 12.40458202], [75.02513885, 12.40458012], [75.02513885, 12.40514088], [75.0248642, 12.40513802], [75.0248642, 12.40569496], [75.02458191, 12.40569019], [75.02458191, 12.40625095], [75.02430725, 12.40625095], [75.02430725, 12.40681076], [75.02402496, 12.40680695], [75.02403259, 12.40736103], [75.02375031, 12.40736103], [75.02375031, 12.40764141], [75.02347565, 12.40763855], [75.02347565, 12.40819454], [75.02319336, 12.40818977], [75.02319336, 12.40930939], [75.0229187, 12.40930462], [75.0229187, 12.40986061], [75.02263641, 12.40986061], [75.02263641, 12.41014099], [75.02236176, 12.41013908], [75.02236176, 12.41069508], [75.02210236, 12.41067886], [75.02210236, 12.41153145], [75.02180481, 12.41152668], [75.02180481, 12.41208267], [75.02124786, 12.41208267], [75.02124786, 12.41236115], [75.02069092, 12.41236115], [75.02069092, 12.41292191], [75.02041626, 12.41291714], [75.02041626, 12.41347313], [75.0201416, 12.41347122], [75.0201416, 12.41403198], [75.01985931, 12.41402721], [75.01985931, 12.41458321], [75.01957703, 12.4145813], [75.01957703, 12.41486073], [75.01930237, 12.41486073], [75.01930237, 12.4151392], [75.01902771, 12.4151392], [75.01902771, 12.41541958], [75.01875305, 12.41541672], [75.01875305, 12.41569519], [75.01847076, 12.41569519], [75.01847076, 12.4159708], [75.01819611, 12.41596889], [75.01819611, 12.41624928], [75.01790619, 12.41624928], [75.01790619, 12.41652966], [75.01763916, 12.41652966], [75.01763916, 12.41681004], [75.01670074, 12.41681004], [75.01457977, 12.41681004], [75.01457977, 12.41764164], [75.01486206, 12.41763878], [75.01486206, 12.41819572], [75.01513672, 12.41819572], [75.01513672, 12.41847134], [75.01486206, 12.41847134], [75.01486206, 12.41958427], [75.01457977, 12.41958141], [75.01457977, 12.41987133], [75.01374817, 12.41987133], [75.01374817, 12.42041969], [75.01347351, 12.42041779], [75.01347351, 12.42069435], [75.01319122, 12.42069054], [75.01319122, 12.42181015], [75.01291656, 12.42180634], [75.01291656, 12.42236233], [75.01264191, 12.42236233], [75.01264191, 12.42319584], [75.01235962, 12.42319107], [75.01235962, 12.42374992], [75.01209259, 12.42374992], [75.01209259, 12.4240303], [75.01180267, 12.4240303], [75.01180267, 12.42431068], [75.01152802, 12.42430592], [75.01152802, 12.42458439], [75.01125336, 12.42457867], [75.01125336, 12.42514038], [75.01097107, 12.42514038], [75.01097107, 12.42542267], [75.01069641, 12.42542267], [75.01069641, 12.42625046], [75.01040649, 12.42625046], [75.01040649, 12.42681122], [75.01013947, 12.42680645], [75.01013184, 12.42761135], [75.00986481, 12.42763805], [75.00986481, 12.42805099], [75.00986481, 12.42819405], [75.00958252, 12.42819405], [75.00958252, 12.4285202], [75.00958252, 12.42875004], [75.00945282, 12.42875004], [75.00930786, 12.42875004], [75.00930023, 12.42900085], [75.00902557, 12.42902756], [75.00902557, 12.4294796], [75.00902557, 12.42958355], [75.00875092, 12.42958355], [75.00875092, 12.4300108], [75.00875092, 12.43124962], [75.00846863, 12.43124962], [75.00846863, 12.43181133], [75.00818634, 12.43181133], [75.00819397, 12.4323597], [75.00791931, 12.4323597], [75.00791931, 12.43292141], [75.00763702, 12.43291664], [75.00763702, 12.43347263], [75.00736237, 12.43346977], [75.00736237, 12.43403053], [75.00708008, 12.43402863], [75.00708008, 12.43458271], [75.00679779, 12.43457985], [75.00679779, 12.43514061], [75.00653076, 12.4351387], [75.00653076, 12.43569469], [75.00624847, 12.43568993], [75.00624847, 12.43625069], [75.006073, 12.43624878], [75.00597382, 12.43624878], [75.00595856, 12.43669128], [75.00595856, 12.4368124], [75.00569153, 12.43680477], [75.00569153, 12.43736076], [75.00541687, 12.43736076], [75.00541687, 12.43754101], [75.00541687, 12.43791676], [75.00514221, 12.43791676], [75.00514221, 12.43809891], [75.00514221, 12.43847084], [75.00485992, 12.43847084], [75.00485992, 12.43903065], [75.00458527, 12.43902683], [75.00458527, 12.44069481], [75.00485992, 12.44069099], [75.00485992, 12.44124889], [75.00514221, 12.44124889], [75.00514221, 12.44208336], [75.00485992, 12.44208145], [75.00485992, 12.44291973], [75.00458527, 12.44291687], [75.0045929, 12.44374943], [75.00430298, 12.44374943], [75.00430298, 12.44431019], [75.00458527, 12.44430542], [75.00458527, 12.44458294], [75.00485992, 12.44458103], [75.00485992, 12.44514179], [75.00430298, 12.44514179], [75.00430298, 12.44486141], [75.00402832, 12.44486141], [75.00402832, 12.44458294], [75.00375366, 12.44458294], [75.00375366, 12.44402695], [75.00347137, 12.44404125], [75.00347137, 12.44374943], [75.0029068, 12.44374943], [75.0029068, 12.44347095], [75.00263977, 12.44347095], [75.00263977, 12.44374943], [75.00235748, 12.44374943], [75.00235748, 12.44404125], [75.00208282, 12.44402695], [75.00208282, 12.44458294], [75.00180817, 12.44458103], [75.00180817, 12.44514179], [75.00152588, 12.44513988], [75.00152588, 12.44569111], [75.00125122, 12.44569969], [75.00125122, 12.44653034], [75.00096893, 12.44652843], [75.00096893, 12.44708443], [75.00067902, 12.44708061], [75.00067902, 12.44764042], [75.00036621, 12.44764042], [75.00028992, 12.44764042], [75.00013733, 12.44764042], [74.99986267, 12.4476366], [74.99986267, 12.44847202], [74.99931335, 12.44847202], [74.99931335, 12.44902992], [74.99903107, 12.44902992], [74.99903107, 12.4493103], [74.99874878, 12.44930553], [74.99874878, 12.44958401], [74.99819183, 12.44958401], [74.99819183, 12.44986153], [74.99791718, 12.44986153], [74.99791718, 12.45069408], [74.99764252, 12.45068932], [74.99764252, 12.45153046], [74.99793243, 12.45153046], [74.99793243, 12.45181274], [74.99764252, 12.45180607], [74.99764252, 12.45208359], [74.99736023, 12.45208359], [74.99736023, 12.45291805], [74.99708557, 12.45291805], [74.99708557, 12.45347214], [74.99736023, 12.45347023], [74.99736023, 12.45431137], [74.99708557, 12.45430565], [74.99708557, 12.45458412], [74.99680328, 12.45458031], [74.99680328, 12.45485973], [74.99652863, 12.45485973], [74.99652863, 12.45514011], [74.99624634, 12.45514011], [74.99624634, 12.45542145], [74.99597168, 12.45542145], [74.99597168, 12.45625019], [74.99624634, 12.45625019], [74.99624634, 12.45653057], [74.99597168, 12.45652771], [74.99597168, 12.4570837], [74.99569702, 12.4570837], [74.99569702, 12.45737171], [74.99569702, 12.45764065], [74.99541473, 12.45763779], [74.99541473, 12.45775032], [74.99541473, 12.45847225], [74.99524689, 12.45847034], [74.99485779, 12.45847034], [74.99485779, 12.45903969], [74.99458313, 12.4590292], [74.99458313, 12.45958233], [74.99430847, 12.45958042], [74.99430847, 12.46014118], [74.99402618, 12.46014118], [74.99402618, 12.46042061], [74.99375153, 12.46042061], [74.99375153, 12.46125126], [74.99346924, 12.46125126], [74.99346924, 12.46153069], [74.99375153, 12.46153069], [74.99375153, 12.46181107], [74.99346924, 12.46181107], [74.99346924, 12.46264076], [74.99263763, 12.46263885], [74.99263763, 12.46319485], [74.99291992, 12.46319485], [74.99291992, 12.46347332], [74.99263763, 12.46347332], [74.99263763, 12.4645834], [74.99236298, 12.4645834], [74.99236298, 12.46486092], [74.99208069, 12.46484947], [74.99208069, 12.4651413], [74.99236298, 12.4651413], [74.99236298, 12.46542168], [74.99208069, 12.46541691], [74.99208069, 12.46597099], [74.9917984, 12.46597099], [74.9917984, 12.46652889], [74.99153137, 12.46652889], [74.99153137, 12.46681023], [74.99180603, 12.46680546], [74.99180603, 12.46708298], [74.99153137, 12.46708298], [74.99153137, 12.46736145], [74.99124908, 12.46736145], [74.99124908, 12.46791935], [74.99097443, 12.46791744], [74.99097443, 12.46847343], [74.99069214, 12.46847057], [74.99069214, 12.46875095], [74.99041748, 12.46875095], [74.99041748, 12.46902943], [74.99013519, 12.46902657], [74.99014282, 12.46986103], [74.98986053, 12.46986103], [74.98986053, 12.47013855], [74.98930359, 12.47013855], [74.98930359, 12.47069454], [74.98902893, 12.47069073], [74.98902893, 12.47125244], [74.98873901, 12.47125244], [74.98873901, 12.47181034], [74.98847198, 12.47180462], [74.98847198, 12.47208309], [74.98819733, 12.47208118], [74.98819733, 12.47292042], [74.98791504, 12.47291756], [74.98791504, 12.47319317], [74.98764038, 12.47319126], [74.98764038, 12.47375202], [74.98735809, 12.47375202], [74.98735809, 12.47430992], [74.98708344, 12.47430611], [74.98708344, 12.47458363], [74.98680878, 12.47458363], [74.98680878, 12.4748621], [74.98707581, 12.47485924], [74.98707581, 12.47513962], [74.98680878, 12.47513962], [74.98680878, 12.4756937], [74.98652649, 12.4756937], [74.98652649, 12.47597218], [74.98625183, 12.47596931], [74.98625183, 12.47653008], [74.98596954, 12.47652817], [74.98596954, 12.47708416], [74.98625183, 12.47707939], [74.98625183, 12.47735977], [74.98596954, 12.47735977], [74.98596954, 12.47791958], [74.98569489, 12.47791576], [74.98569489, 12.47819424], [74.98542023, 12.47819233], [74.98542023, 12.47875023], [74.98513794, 12.47875023], [74.98513794, 12.47958374], [74.98486328, 12.47958183], [74.98486328, 12.48042107], [74.98458099, 12.4804163], [74.98458099, 12.48097229], [74.98430634, 12.48097038], [74.98430634, 12.48125172], [74.98401642, 12.48125172], [74.98400116, 12.48153019], [74.98374939, 12.48153019], [74.98374939, 12.48236179], [74.9834671, 12.48236179], [74.9834671, 12.48264027], [74.98319244, 12.48264027], [74.98319244, 12.48236179], [74.98291779, 12.48236179], [74.98291779, 12.48264027], [74.98236084, 12.48264027], [74.98236084, 12.48292065], [74.98208618, 12.48291588], [74.98208618, 12.48347187], [74.98179626, 12.48346996], [74.98179626, 12.48403072], [74.98152924, 12.48402786], [74.98152924, 12.48458195], [74.98124695, 12.48458004], [74.98124695, 12.4851408], [74.98097229, 12.48513794], [74.98097229, 12.48569393], [74.98042297, 12.48569202], [74.98042297, 12.48625088], [74.98014069, 12.48625088], [74.98014069, 12.48681068], [74.9798584, 12.48681068], [74.9798584, 12.48736095], [74.97958374, 12.48736095], [74.97957611, 12.48746967], [74.97956085, 12.48792076], [74.97930908, 12.48792076], [74.97930908, 12.48875141], [74.97902679, 12.48875141], [74.97902679, 12.48930931], [74.97875214, 12.48930454], [74.97875214, 12.48986053], [74.97846985, 12.48986053], [74.97846985, 12.490695], [74.97820282, 12.49069023], [74.97820282, 12.49125099], [74.9779129, 12.49125099], [74.9779129, 12.49180889], [74.97763824, 12.49180889], [74.97763824, 12.49264145], [74.97736359, 12.49263859], [74.97736359, 12.49319458], [74.9770813, 12.4931879], [74.9770813, 12.49375057], [74.97679901, 12.49375057], [74.97679901, 12.49403191], [74.97652435, 12.49402714], [74.97652435, 12.49458313], [74.97624969, 12.49458122], [74.97624969, 12.49515057], [74.97597504, 12.49513912], [74.97597504, 12.49597263], [74.97569275, 12.49597073], [74.97569275, 12.49680996], [74.97541809, 12.49680519], [74.97541809, 12.49736118], [74.9751358, 12.49736118], [74.9751358, 12.49764156], [74.97486115, 12.49764156], [74.97486115, 12.49792194], [74.97458649, 12.49791527], [74.97458649, 12.49847126], [74.97402954, 12.49847126], [74.97402954, 12.49875164], [74.9734726, 12.49874878], [74.9734726, 12.4995842], [74.97376251, 12.49958134], [74.97376251, 12.50041962], [74.9734726, 12.50041771], [74.9734726, 12.50097179], [74.97292328, 12.50096035], [74.97292328, 12.50181007], [74.97264099, 12.50180626], [74.97264099, 12.50208378], [74.97292328, 12.50208092], [74.97292328, 12.50263977], [74.97264099, 12.50263977], [74.97264099, 12.50374985], [74.9723587, 12.50374985], [74.9723587, 12.50430965], [74.97207642, 12.50430965], [74.97207642, 12.50541973], [74.97180939, 12.50541592], [74.97180176, 12.50597191], [74.9715271, 12.50597191], [74.9715271, 12.50625038], [74.97125244, 12.50625038], [74.97125244, 12.50653267], [74.97097015, 12.50653267], [74.97097015, 12.50709057], [74.9706955, 12.50708199], [74.9706955, 12.50847244], [74.97013855, 12.50846958], [74.97013855, 12.50874996], [74.97041321, 12.50874996], [74.97041321, 12.50931072], [74.97013855, 12.50931072], [74.97013855, 12.5104208], [74.96986389, 12.51041603], [74.96986389, 12.51069355], [74.9695816, 12.51068974], [74.9695816, 12.51292133], [74.96902466, 12.51291561], [74.96902466, 12.51319504], [74.96875, 12.51319027], [74.96875, 12.51403141], [74.96848297, 12.51403141], [74.96848297, 12.51514053], [74.96819305, 12.51513863], [74.96819305, 12.51597309], [74.9679184, 12.51597118], [74.9679184, 12.51625061], [74.96762848, 12.51625061], [74.96762848, 12.51681232], [74.96736145, 12.5168047], [74.96736145, 12.51708317], [74.96708679, 12.51708317], [74.96708679, 12.51819515], [74.96679688, 12.51819038], [74.96679688, 12.51875114], [74.96652985, 12.51875114], [74.96652985, 12.51986122], [74.96624756, 12.51986122], [74.96624756, 12.52125072], [74.9659729, 12.52125072], [74.9659729, 12.52180958], [74.96569824, 12.52180481], [74.96569824, 12.52208328], [74.96541595, 12.52208328], [74.96541595, 12.5223608], [74.9651413, 12.52235889], [74.9651413, 12.52291965], [74.96485901, 12.52291679], [74.96485901, 12.52319527], [74.96458435, 12.52319527], [74.96458435, 12.52458286], [74.96430206, 12.52458286], [74.96430206, 12.52513885], [74.9640274, 12.52513885], [74.9640274, 12.5256958], [74.96375275, 12.52569103], [74.96375275, 12.52625179], [74.96347046, 12.52625179], [74.96347046, 12.52680969], [74.9631958, 12.52680588], [74.9631958, 12.52708435], [74.96290588, 12.52708054], [74.96290588, 12.52875042], [74.96263885, 12.52875042], [74.96263885, 12.5298624], [74.9623642, 12.5298624], [74.9623642, 12.53040886], [74.9623642, 12.53069401], [74.96222687, 12.53069401], [74.96208191, 12.53069401], [74.96208191, 12.53099918], [74.96208191, 12.53126144], [74.96196747, 12.53125], [74.96180725, 12.53125], [74.96181488, 12.53152084], [74.96182251, 12.53180981], [74.96153259, 12.53180981], [74.96153259, 12.53264046], [74.96125031, 12.5326376], [74.96125031, 12.53319359], [74.96098328, 12.53319168], [74.96098328, 12.53374958], [74.96069336, 12.53374958], [74.96069336, 12.53681087], [74.9604187, 12.5368042], [74.9604187, 12.5381937], [74.96013641, 12.5381918], [74.96013641, 12.53985977], [74.95986176, 12.53985977], [74.95986176, 12.54125118], [74.9595871, 12.54125118], [74.9595871, 12.54236126], [74.95929718, 12.54236126], [74.95929718, 12.5432024], [74.95903015, 12.54319477], [74.95903015, 12.54375076], [74.95874786, 12.54375076], [74.95874786, 12.54458332], [74.95847321, 12.54458046], [74.95847321, 12.54514122], [74.95819092, 12.54513931], [74.95819092, 12.5456953], [74.95791626, 12.54568958], [74.95791626, 12.54626179], [74.9576416, 12.54626179], [74.9576416, 12.54653072], [74.95735931, 12.54652691], [74.95735931, 12.5470829], [74.95707703, 12.54708099], [74.95707703, 12.54763889], [74.95680237, 12.54763889], [74.95680237, 12.54819489], [74.95652771, 12.54819489], [74.95652771, 12.54847336], [74.95625305, 12.54847145], [74.95625305, 12.54902935], [74.95652771, 12.54902744], [74.95652771, 12.54958344], [74.95680237, 12.54958057], [74.95680237, 12.54986095], [74.95707703, 12.54986095], [74.95707703, 12.55013943], [74.95735931, 12.55013943], [74.95735931, 12.55042171], [74.9576416, 12.55041695], [74.9576416, 12.55069542], [74.95791626, 12.55069065], [74.95791626, 12.55125237], [74.9576416, 12.55125237], [74.9576416, 12.55181026], [74.95735931, 12.55180454], [74.95735931, 12.55208302], [74.95708466, 12.55208302], [74.95708466, 12.55236053], [74.95680237, 12.55236053], [74.95680237, 12.55264187], [74.95652771, 12.55263996], [74.95652771, 12.55319309], [74.95625305, 12.55319309], [74.95625305, 12.55347061], [74.95597076, 12.55347061], [74.95597076, 12.55375195], [74.95568848, 12.55375195], [74.95568848, 12.55403042], [74.95539856, 12.55403042], [74.95539856, 12.55431175], [74.95513916, 12.55431175], [74.95513916, 12.55403042], [74.95485687, 12.55403042], [74.95485687, 12.55375195], [74.95513916, 12.55375195], [74.95513916, 12.55347061], [74.95541382, 12.55347061], [74.95541382, 12.55291843], [74.95568848, 12.55292034], [74.95568848, 12.55264187], [74.95597076, 12.55264187], [74.95597076, 12.55236053], [74.95625305, 12.55236053], [74.95625305, 12.55208302], [74.95652771, 12.55208302], [74.95652771, 12.55013943], [74.95625305, 12.55013943], [74.95625305, 12.54986095], [74.95597076, 12.54986095], [74.95597076, 12.54958057], [74.95569611, 12.54958344], [74.95569611, 12.54930496], [74.95541382, 12.54930496], [74.95541382, 12.54902744], [74.95513916, 12.54902935], [74.95511627, 12.54875088], [74.95458221, 12.54874897], [74.95458221, 12.54930496], [74.95430756, 12.54930115], [74.95430756, 12.55013943], [74.95402527, 12.55013943], [74.95402527, 12.55069542], [74.95375061, 12.55069065], [74.95375061, 12.55153179], [74.95347595, 12.55152702], [74.95347595, 12.55236053], [74.95318604, 12.55236053], [74.95318604, 12.55292034], [74.95291901, 12.55291843], [74.95291901, 12.55347061], [74.95262909, 12.55347061], [74.95262909, 12.55403042], [74.95236206, 12.55402756], [74.95236206, 12.55458355], [74.95207977, 12.55458355], [74.95207977, 12.55569363], [74.95181274, 12.55568886], [74.95181274, 12.55624962], [74.95153046, 12.55624962], [74.95153046, 12.55653], [74.95124817, 12.55653], [74.95124817, 12.55764008], [74.95096588, 12.55764008], [74.95096588, 12.55931091], [74.95069122, 12.55930614], [74.95069122, 12.55986214], [74.95041656, 12.55986023], [74.95041656, 12.56042004], [74.95014191, 12.56041622], [74.95014191, 12.56097221], [74.94985962, 12.56097031], [74.94985962, 12.56153011], [74.94958496, 12.56152821], [74.94958496, 12.5620842], [74.94930267, 12.56208038], [74.94930267, 12.56264019], [74.94902802, 12.56264019], [74.94902802, 12.56319427], [74.94875336, 12.56319046], [74.94875336, 12.56375027], [74.94847107, 12.56375027], [74.94847107, 12.56430626], [74.94819641, 12.56430626], [74.94819641, 12.56486034], [74.94790649, 12.56486034], [74.94790649, 12.5654211], [74.94763947, 12.5654211], [74.94763947, 12.56653118], [74.94736481, 12.56652641], [74.94736481, 12.56708241], [74.94708252, 12.56707954], [74.94708252, 12.56792068], [74.94680786, 12.56791687], [74.94680786, 12.56819534], [74.9465332, 12.56818962], [74.9465332, 12.56930923], [74.94625092, 12.56930542], [74.94625092, 12.56986141], [74.94596863, 12.56986141], [74.94595337, 12.57138062], [74.94595337, 12.5715313], [74.94569397, 12.57152653], [74.94569397, 12.57208347], [74.94541931, 12.57208347], [74.94541931, 12.5725317], [74.94541931, 12.57264137], [74.94513702, 12.57263947], [74.94513702, 12.57347298], [74.94486237, 12.57347107], [74.94486237, 12.57375145], [74.94458008, 12.57375145], [74.94458008, 12.57458305], [74.94431305, 12.57458115], [74.94431305, 12.57541943], [74.94403076, 12.57541656], [74.94403076, 12.57569313], [74.9438858, 12.57569313], [74.94374847, 12.57569313], [74.94374847, 12.57624912], [74.94347382, 12.57624912], [74.94347382, 12.57708263], [74.94319153, 12.57708263], [74.94319153, 12.57796097], [74.94319153, 12.57819462], [74.94291687, 12.57819462], [74.94291687, 12.57862186], [74.94291687, 12.57903194], [74.94274902, 12.57903004], [74.94264221, 12.57902718], [74.94264221, 12.5792799], [74.94264221, 12.57958317], [74.94251251, 12.57958317], [74.94235992, 12.57958317], [74.94235992, 12.57995033], [74.94235992, 12.58014202], [74.94208527, 12.58014011], [74.94208527, 12.58069324], [74.94180298, 12.58069134], [74.94180298, 12.58125019], [74.94152832, 12.58125019], [74.94152832, 12.5819397], [74.94152832, 12.5820837], [74.94125366, 12.5820837], [74.94124603, 12.58260059], [74.94124603, 12.58292007], [74.94097137, 12.58292007], [74.94097137, 12.58403015], [74.94069672, 12.58402824], [74.94069672, 12.58458424], [74.94041443, 12.58458424], [74.94041443, 12.58486176], [74.94010925, 12.58486176], [74.93985748, 12.58486176], [74.93985748, 12.58569431], [74.93958282, 12.58569241], [74.93958282, 12.58625031], [74.93930817, 12.58625031], [74.93930817, 12.58708191], [74.93902588, 12.58708382], [74.93902588, 12.58819389], [74.93875122, 12.58819389], [74.93875122, 12.58847237], [74.93846893, 12.58847046], [74.93846893, 12.58875179], [74.93818665, 12.58875179], [74.93818665, 12.59014034], [74.93791962, 12.59014034], [74.93791962, 12.59042072], [74.93819427, 12.59041595], [74.93819427, 12.59069443], [74.93791962, 12.59068966], [74.93791962, 12.59125042], [74.93765259, 12.59125042], [74.93765259, 12.59154034], [74.93736267, 12.59152794], [74.93736267, 12.59208202], [74.93708038, 12.59208012], [74.93708038, 12.59264088], [74.93681335, 12.59264088], [74.93681335, 12.59292126], [74.93653107, 12.59291553], [74.93653107, 12.59347343], [74.93624878, 12.59346962], [74.93624878, 12.59403133], [74.93597412, 12.59402943], [74.93597412, 12.5945816], [74.93569183, 12.5945797], [74.93569183, 12.59486103], [74.93541718, 12.59486103], [74.93541718, 12.59542084], [74.93514252, 12.59541702], [74.93514252, 12.59597301], [74.93486023, 12.59597015], [74.93486023, 12.59625053], [74.93514252, 12.59625053], [74.93514252, 12.59653091], [74.93486023, 12.59653091], [74.93486023, 12.59681129], [74.93458557, 12.59680462], [74.93458557, 12.59736061], [74.93430328, 12.59735203], [74.93430328, 12.59792137], [74.93402863, 12.59792137], [74.93402863, 12.59875107], [74.93430328, 12.59875107], [74.93430328, 12.59903145], [74.93402863, 12.59903145], [74.93402863, 12.59931183], [74.93374634, 12.59930515], [74.93374634, 12.59958267], [74.93347168, 12.59958267], [74.93347168, 12.59986115], [74.93374634, 12.59986115], [74.93374634, 12.60014057], [74.93347168, 12.60013866], [74.93347168, 12.60069466], [74.93319702, 12.60069466], [74.93319702, 12.60097313], [74.9329071, 12.60097122], [74.9329071, 12.60125065], [74.93264008, 12.60125065], [74.93264008, 12.60291958], [74.93235779, 12.60291672], [74.93235779, 12.60319519], [74.93208313, 12.60319138], [74.93208313, 12.60374928], [74.93235779, 12.60374928], [74.93235779, 12.60403156], [74.93264008, 12.60403156], [74.93264008, 12.60348034], [74.9329071, 12.60348034], [74.9329071, 12.6026392], [74.93319702, 12.6026392], [74.93319702, 12.60236073], [74.93347168, 12.60236073], [74.93347168, 12.6020813], [74.93374634, 12.60208321], [74.93374634, 12.60069466], [74.93402863, 12.60069466], [74.93402863, 12.60041714], [74.93430328, 12.60041714], [74.93430328, 12.60013866], [74.9345932, 12.60014057], [74.9345932, 12.59903145], [74.93486023, 12.59903145], [74.93486023, 12.59875107], [74.93541718, 12.59875107], [74.93541718, 12.59819031], [74.93569183, 12.59819508], [74.93569183, 12.5979166], [74.93596649, 12.59792137], [74.93596649, 12.59735203], [74.93624878, 12.59736061], [74.93624878, 12.59708309], [74.93653107, 12.59708309], [74.93653107, 12.59652901], [74.93681335, 12.59653091], [74.93681335, 12.59597015], [74.93708038, 12.59597301], [74.93708038, 12.59569454], [74.93736267, 12.59569454], [74.93736267, 12.59513855], [74.93765259, 12.59514141], [74.93765259, 12.59486103], [74.93736267, 12.59486103], [74.93736267, 12.5945797], [74.93763733, 12.5945816], [74.93763733, 12.59430695], [74.93791962, 12.59431076], [74.93791962, 12.59403133], [74.93818665, 12.59403133], [74.93818665, 12.59375095], [74.93846893, 12.59375095], [74.93846893, 12.59346962], [74.93875122, 12.59347343], [74.93875122, 12.59319401], [74.93902588, 12.59319401], [74.93902588, 12.59263802], [74.93930817, 12.59264088], [74.93930817, 12.59208012], [74.93958282, 12.59208202], [74.93958282, 12.59125042], [74.93985748, 12.59125042], [74.93985748, 12.59068966], [74.94013977, 12.59069443], [74.94013977, 12.58985996], [74.94039917, 12.58985996], [74.94039917, 12.58931065], [74.94097137, 12.58930588], [74.94097137, 12.58958435], [74.94125366, 12.58958435], [74.94125366, 12.59069443], [74.94097137, 12.59068966], [74.94097137, 12.59125042], [74.94069672, 12.59125042], [74.94069672, 12.59236336], [74.94039917, 12.59235954], [74.94039917, 12.59264088], [74.94013977, 12.59263802], [74.94013977, 12.59347343], [74.93985748, 12.59346962], [74.93985748, 12.59486103], [74.93930817, 12.59486103], [74.93930817, 12.59597301], [74.93902588, 12.59597015], [74.93902588, 12.59625053], [74.93875122, 12.59625053], [74.93875122, 12.59681129], [74.93818665, 12.59681129], [74.93818665, 12.59792137], [74.93791962, 12.59792137], [74.93791962, 12.59875107], [74.93708038, 12.59875107], [74.93708038, 12.59931183], [74.93680573, 12.59930515], [74.93680573, 12.60097313], [74.93653107, 12.60097122], [74.93653107, 12.60125065], [74.93596649, 12.60125065], [74.93596649, 12.60181046], [74.93569183, 12.60180473], [74.93569183, 12.60208321], [74.93541718, 12.6020813], [74.93541718, 12.60291958], [74.93514252, 12.60291958], [74.93514252, 12.60403156], [74.93486023, 12.60402679], [74.93486023, 12.60458279], [74.9345932, 12.60458088], [74.9345932, 12.60514164], [74.93430328, 12.60513878], [74.93430328, 12.60569572], [74.93402863, 12.60569572], [74.93402863, 12.60597134], [74.93374634, 12.60597134], [74.93374634, 12.60764027], [74.93347168, 12.60764027], [74.93347168, 12.60791969], [74.93319702, 12.60791779], [74.93319702, 12.6081934], [74.93347168, 12.6081934], [74.93347168, 12.60847187], [74.93319702, 12.60847187], [74.93319702, 12.60875034], [74.9329071, 12.60875034], [74.9329071, 12.60931015], [74.93264008, 12.60930634], [74.93264008, 12.60958385], [74.93235779, 12.60958099], [74.93235779, 12.61013985], [74.93208313, 12.61013985], [74.93208313, 12.61069584], [74.93180847, 12.61069107], [74.93180847, 12.61180973], [74.93208313, 12.61180592], [74.93208313, 12.61319447], [74.93152618, 12.61319447], [74.93152618, 12.61347198], [74.93096924, 12.61347198], [74.93096924, 12.61375046], [74.93068695, 12.61375046], [74.93068695, 12.61403275], [74.93013763, 12.61403275], [74.93013763, 12.61375046], [74.92986298, 12.61375046], [74.92986298, 12.61347198], [74.92958069, 12.61347198], [74.92958069, 12.61263847], [74.92930603, 12.61264038], [74.92930603, 12.61235142], [74.92958069, 12.61236191], [74.92958069, 12.61180592], [74.92930603, 12.61180973], [74.92930603, 12.61096859], [74.92958069, 12.6109724], [74.92958069, 12.61041641], [74.92930603, 12.61042023], [74.92930603, 12.61013985], [74.92903137, 12.61013985], [74.92903137, 12.61042023], [74.92874908, 12.61041641], [74.92874908, 12.6109724], [74.92819214, 12.6109724], [74.92819214, 12.61208439], [74.92791748, 12.61208439], [74.92791748, 12.61236191], [74.92764282, 12.61235142], [74.92764282, 12.61264038], [74.92736053, 12.61264038], [74.92736053, 12.61403275], [74.92708588, 12.61402798], [74.92708588, 12.61486244], [74.92679596, 12.61485958], [74.92679596, 12.6154213], [74.92652893, 12.6154213], [74.92652893, 12.61653137], [74.92597198, 12.61653137], [74.92597198, 12.61763954], [74.92571259, 12.61763954], [74.92571259, 12.61931133], [74.92485809, 12.61930656], [74.92485809, 12.62097263], [74.92458344, 12.62097263], [74.92458344, 12.62152863], [74.92430878, 12.62152863], [74.92430878, 12.62236118], [74.92402649, 12.62236118], [74.92402649, 12.62292099], [74.92375183, 12.62292099], [74.92375183, 12.62375069], [74.92346954, 12.62375069], [74.92346954, 12.62431145], [74.92319489, 12.62430477], [74.92319489, 12.62486076], [74.92292023, 12.6248579], [74.92292023, 12.62542057], [74.92263794, 12.62541676], [74.9226532, 12.62625122], [74.92236328, 12.62625122], [74.92236328, 12.62653065], [74.92208099, 12.62652683], [74.92208099, 12.62708282], [74.92180634, 12.62708092], [74.92180634, 12.62764072], [74.92152405, 12.62763882], [74.92152405, 12.62819481], [74.92124939, 12.62819099], [74.92124939, 12.62874889], [74.9209671, 12.62874889], [74.9209671, 12.62902927], [74.92124939, 12.62902927], [74.92124939, 12.62930965], [74.92097473, 12.62930489], [74.92097473, 12.62958336], [74.92069244, 12.62958145], [74.92069244, 12.62986088], [74.92097473, 12.62986088], [74.92097473, 12.63050175], [74.92097473, 12.63069534], [74.92069244, 12.63069534], [74.92069244, 12.63111019], [74.92069244, 12.63125134], [74.92041779, 12.63125134], [74.92041779, 12.63181019], [74.9201355, 12.63180542], [74.9201355, 12.63208294], [74.91957855, 12.63208103], [74.91957855, 12.63375187], [74.91929626, 12.63375187], [74.91929626, 12.63403034], [74.91902924, 12.63403034], [74.91902924, 12.63486195], [74.91874695, 12.63486195], [74.91874695, 12.63542175], [74.91847229, 12.63542175], [74.91847229, 12.63624954], [74.91819763, 12.63624954], [74.91819763, 12.63652802], [74.91791534, 12.63652802], [74.91791534, 12.63736153], [74.91764069, 12.63735962], [74.91764069, 12.63903046], [74.91707611, 12.63903046], [74.91707611, 12.64013958], [74.91680908, 12.64013958], [74.91680908, 12.64041996], [74.91651917, 12.64041996], [74.91651917, 12.64124966], [74.91625214, 12.64124966], [74.91625214, 12.64208412], [74.91596985, 12.64208031], [74.91596985, 12.64292145], [74.91569519, 12.64291573], [74.91570282, 12.64375019], [74.9154129, 12.64375019], [74.9154129, 12.6445837], [74.91513824, 12.64458179], [74.91513824, 12.64514065], [74.91486359, 12.64513779], [74.91486359, 12.64569378], [74.9145813, 12.64568996], [74.9145813, 12.64624977], [74.91430664, 12.64624977], [74.91430664, 12.64708233], [74.91401672, 12.64708042], [74.91401672, 12.64764118], [74.91374969, 12.64763832], [74.91374969, 12.64819527], [74.91348267, 12.64818954], [74.91348267, 12.64903069], [74.91319275, 12.64902878], [74.91319275, 12.64958286], [74.91291809, 12.64958], [74.91291809, 12.65014076], [74.9126358, 12.65013885], [74.9126358, 12.65069485], [74.91236115, 12.65069485], [74.91236115, 12.6515274], [74.91208649, 12.6515274], [74.91208649, 12.6520834], [74.91179657, 12.65207958], [74.91179657, 12.6526413], [74.91152954, 12.65263939], [74.91152954, 12.6534729], [74.91124725, 12.65347099], [74.91124725, 12.65402889], [74.9109726, 12.65402889], [74.9109726, 12.65458965], [74.9107132, 12.65458965], [74.9107132, 12.65514088], [74.91041565, 12.65513897], [74.91041565, 12.65597343], [74.91014099, 12.65597057], [74.91014099, 12.65652943], [74.9098587, 12.65652657], [74.9098587, 12.65708256], [74.90957642, 12.65708065], [74.90957642, 12.65792179], [74.90930939, 12.65791702], [74.90930176, 12.65847111], [74.9090271, 12.65847111], [74.9090271, 12.65903187], [74.90875244, 12.6590271], [74.90875244, 12.65958309], [74.90847015, 12.65958118], [74.90847015, 12.66042042], [74.9081955, 12.66041756], [74.9081955, 12.66097355], [74.90791321, 12.66097069], [74.90791321, 12.66152954], [74.90763855, 12.66152763], [74.90763855, 12.66208363], [74.90735626, 12.66207886], [74.90735626, 12.66263962], [74.9070816, 12.66263962], [74.9070816, 12.6631937], [74.90680695, 12.66319084], [74.90680695, 12.66374969], [74.90651703, 12.66374969], [74.90651703, 12.66431046], [74.90625, 12.66431046], [74.90625, 12.66485977], [74.90598297, 12.66485977], [74.90598297, 12.66541958], [74.90569305, 12.66541576], [74.90569305, 12.66597176], [74.9054184, 12.66596985], [74.9054184, 12.66652966], [74.90513611, 12.66652775], [74.90513611, 12.66708374], [74.90486145, 12.66708183], [74.90486145, 12.66763973], [74.9043045, 12.66763783], [74.9043045, 12.66819382], [74.90402985, 12.66819191], [74.90402985, 12.66875172], [74.90374756, 12.66875172], [74.90374756, 12.66931057], [74.9034729, 12.66931057], [74.9034729, 12.67014027], [74.90319824, 12.67014027], [74.90319824, 12.67125034], [74.90291595, 12.67125034], [74.90291595, 12.6718111], [74.9026413, 12.67180634], [74.9026413, 12.67263794], [74.90235901, 12.67263794], [74.90235901, 12.67319393], [74.90207672, 12.67319202], [74.90207672, 12.67431068], [74.90180206, 12.67431068], [74.90180206, 12.67486], [74.9015274, 12.67486], [74.9015274, 12.67569542], [74.90125275, 12.6756897], [74.90125275, 12.67681122], [74.9015274, 12.67680454], [74.9015274, 12.67708302], [74.90097046, 12.67708302], [74.90097046, 12.67736053], [74.9006958, 12.67736053], [74.9006958, 12.678195], [74.90040588, 12.67819023], [74.90040588, 12.67930889], [74.90013885, 12.67930889], [74.90013885, 12.67986107], [74.89985657, 12.67986107], [74.89985657, 12.68014145], [74.89958191, 12.68013859], [74.89958191, 12.68069458], [74.89930725, 12.6806879], [74.89930725, 12.68125057], [74.89901733, 12.68125057], [74.89901733, 12.68182087], [74.89875031, 12.68180466], [74.89875031, 12.68208313], [74.89848328, 12.68208122], [74.89848328, 12.68264103], [74.89819336, 12.68264103], [74.89819336, 12.68291855], [74.8979187, 12.68291664], [74.8979187, 12.68347263], [74.89763641, 12.68347073], [74.89763641, 12.68402863], [74.89736176, 12.68402672], [74.89736176, 12.68458271], [74.8970871, 12.68457031], [74.8970871, 12.68514156], [74.89680481, 12.6851387], [74.89680481, 12.68569469], [74.89653015, 12.68569088], [74.89653015, 12.68625164], [74.89624786, 12.68625164], [74.89624786, 12.68680954], [74.89597321, 12.68680477], [74.89597321, 12.68736172], [74.89569092, 12.68735886], [74.89569092, 12.68791962], [74.89541626, 12.68791962], [74.89541626, 12.68847084], [74.8951416, 12.68847084], [74.8951416, 12.68902969], [74.89485931, 12.68902779], [74.89485931, 12.68958378], [74.89457703, 12.68958092], [74.89457703, 12.69013977], [74.89430237, 12.69013977], [74.89430237, 12.69069958], [74.89402771, 12.69069576], [74.89402771, 12.69208431], [74.89375305, 12.69208241], [74.89375305, 12.6926403], [74.89347076, 12.6926403], [74.89347076, 12.69347191], [74.89319611, 12.69347191], [74.89319611, 12.69376087], [74.89291382, 12.69375038], [74.89291382, 12.69458199], [74.89263916, 12.69458199], [74.89263916, 12.69514179], [74.8923645, 12.69513798], [74.8923645, 12.69597244], [74.89208221, 12.69597244], [74.89208221, 12.69680595], [74.89180756, 12.69679928], [74.89180756, 12.69764042], [74.89152527, 12.69763756], [74.89152527, 12.69819355], [74.89125061, 12.69818974], [74.89125061, 12.69903088], [74.89097595, 12.69902802], [74.89097595, 12.69986343], [74.89068604, 12.69985962], [74.89068604, 12.70042133], [74.89041901, 12.70042133], [74.89041901, 12.70125103], [74.89013672, 12.70125103], [74.89013672, 12.70208454], [74.88986206, 12.70207977], [74.88986206, 12.70264053], [74.88957977, 12.70263863], [74.88957977, 12.70347309], [74.88931274, 12.70347023], [74.88931274, 12.70375061], [74.88874817, 12.70375061], [74.88874817, 12.70403099], [74.88847351, 12.70402908], [74.88847351, 12.70458317], [74.88819122, 12.70458317], [74.88819122, 12.70497036], [74.88819122, 12.70514107], [74.88802338, 12.70514107], [74.88791656, 12.70514107], [74.88791656, 12.70570183], [74.88748169, 12.70569515], [74.88735962, 12.70569515], [74.88735962, 12.70582008], [74.88735962, 12.7068119], [74.88764191, 12.70680523], [74.88764191, 12.70708275], [74.88791656, 12.70708275], [74.88791656, 12.70736122], [74.88847351, 12.70736122], [74.88847351, 12.70708275], [74.88874817, 12.70708275], [74.88874817, 12.70680523], [74.88931274, 12.7068119], [74.88931274, 12.70653057], [74.88957977, 12.70653057], [74.88957977, 12.70625114], [74.89013672, 12.70625114], [74.89013672, 12.7059679], [74.89041901, 12.70597076], [74.89041901, 12.70569515], [74.89097595, 12.70570183], [74.89097595, 12.70542145], [74.89125061, 12.70542145], [74.89125061, 12.70514107], [74.8915329, 12.70514107], [74.8915329, 12.70458031], [74.89180756, 12.70458317], [74.89180756, 12.70402908], [74.89208221, 12.70403099], [74.89208221, 12.70347023], [74.89263916, 12.70347023], [74.89263916, 12.70431137], [74.8923645, 12.7043047], [74.8923645, 12.70597267], [74.89208221, 12.7059679], [74.89208221, 12.7068119], [74.89234924, 12.7068119], [74.89234924, 12.70792198], [74.89263916, 12.70791721], [74.89263916, 12.70847321], [74.8923645, 12.70847321], [74.8923645, 12.70874882], [74.89208221, 12.70874023], [74.89208221, 12.7090292], [74.89180756, 12.7090292], [74.89180756, 12.70930958], [74.89152527, 12.70930481], [74.89152527, 12.70958328], [74.89125061, 12.70958138], [74.89125061, 12.71041965], [74.89097595, 12.71041679], [74.89097595, 12.71069527], [74.89041901, 12.71069527], [74.89041901, 12.71097088], [74.88986206, 12.71097088], [74.88986206, 12.71125126], [74.88903046, 12.71125126], [74.88903046, 12.71097088], [74.88791656, 12.71097088], [74.88791656, 12.71125126], [74.88652802, 12.71125126], [74.88652802, 12.71097088], [74.88625336, 12.71097088], [74.88625336, 12.71013927], [74.88654327, 12.71013927], [74.88654327, 12.7090292], [74.88680267, 12.7090292], [74.88680267, 12.7084713], [74.88708496, 12.70847321], [74.88708496, 12.70819473], [74.88625336, 12.70819473], [74.88625336, 12.70791721], [74.88552094, 12.70791721], [74.88541412, 12.70791721], [74.88541412, 12.70819473], [74.88513947, 12.70819473], [74.88513947, 12.70847321], [74.88485718, 12.7084713], [74.88485718, 12.7090292], [74.88458252, 12.7090292], [74.88458252, 12.70930958], [74.88430786, 12.70930481], [74.88430786, 12.70958328], [74.88375092, 12.70958138], [74.88375092, 12.71041965], [74.88346863, 12.71041679], [74.88347626, 12.71125126], [74.88319397, 12.71125126], [74.88319397, 12.71180534], [74.88291931, 12.71180058], [74.88291931, 12.71264172], [74.88263702, 12.71263885], [74.88263702, 12.71347141], [74.88236237, 12.71347141], [74.88236237, 12.71430969], [74.88208008, 12.71430969], [74.88208008, 12.71487141], [74.88181305, 12.71487141], [74.88181305, 12.71541977], [74.88153076, 12.71541977], [74.88153076, 12.71625042], [74.88124847, 12.71625042], [74.88124847, 12.71681023], [74.88096619, 12.71681023], [74.88096619, 12.71763992], [74.88069153, 12.71763992], [74.88069153, 12.71847153], [74.88040924, 12.71847153], [74.88040924, 12.72014046], [74.87985992, 12.7201376], [74.87985992, 12.72069359], [74.87958527, 12.72069359], [74.87958527, 12.72097206], [74.87930298, 12.72097015], [74.87930298, 12.72124958], [74.8795929, 12.72124958], [74.8795929, 12.72181129], [74.87930298, 12.72181129], [74.87930298, 12.72292137], [74.87902832, 12.72291565], [74.87902832, 12.72375011], [74.87874603, 12.72374058], [74.87874603, 12.72431087], [74.87847137, 12.7243042], [74.87847137, 12.72458363], [74.87819672, 12.72458363], [74.87819672, 12.72597218], [74.8779068, 12.72597027], [74.8779068, 12.72653103], [74.87763977, 12.72652817], [74.87763977, 12.72708225], [74.87708282, 12.72708225], [74.87708282, 12.72819519], [74.87680817, 12.72819042], [74.87680817, 12.72931099], [74.87652588, 12.72930431], [74.87652588, 12.73012924], [74.87652588, 12.73042107], [74.87637329, 12.73041725], [74.87625122, 12.73041725], [74.87625122, 12.73064041], [74.87625122, 12.73153114], [74.87596893, 12.73152924], [74.87596893, 12.73208332], [74.87568665, 12.73208046], [74.87568665, 12.73264122], [74.87541962, 12.73263931], [74.87541962, 12.7331953], [74.87513733, 12.73318958], [74.87513733, 12.7337513], [74.87486267, 12.7337513], [74.87486267, 12.7343092], [74.87458038, 12.73430538], [74.87458038, 12.73486137], [74.87431335, 12.73486137], [74.87431335, 12.73541927], [74.87403107, 12.73541737], [74.87403107, 12.73597336], [74.87374878, 12.73597145], [74.87374878, 12.73652935], [74.87346649, 12.73652935], [74.87346649, 12.73736095], [74.87319183, 12.73736095], [74.87319183, 12.73792171], [74.87291718, 12.73791695], [74.87291718, 12.73847103], [74.87264252, 12.73847103], [74.87264252, 12.73903179], [74.87236023, 12.73902702], [74.87236023, 12.73958302], [74.8720932, 12.73958111], [74.8720932, 12.74014187], [74.87180328, 12.74013901], [74.87180328, 12.74069309], [74.87152863, 12.74069118], [74.87152863, 12.74125195], [74.87124634, 12.74125195], [74.87124634, 12.74181175], [74.87097168, 12.74181175], [74.87097168, 12.74236202], [74.87069702, 12.74236202], [74.87069702, 12.74291992], [74.8704071, 12.74291992], [74.8704071, 12.74374962], [74.87014008, 12.74374962], [74.87014008, 12.74431038], [74.86985779, 12.74431038], [74.86985779, 12.74514198], [74.86958313, 12.74514008], [74.86958313, 12.74569416], [74.86930847, 12.7456913], [74.86930847, 12.74652958], [74.86902618, 12.74652767], [74.86902618, 12.74736214], [74.86875153, 12.74736214], [74.86875153, 12.74791622], [74.86846924, 12.74791622], [74.86846924, 12.74847221], [74.86875153, 12.74847031], [74.86875153, 12.74874973], [74.86846924, 12.74874973], [74.86846924, 12.7495842], [74.86763763, 12.74958038], [74.86763763, 12.75042057], [74.86736298, 12.7504158], [74.86736298, 12.75069427], [74.86763763, 12.75069046], [74.86763763, 12.75097179], [74.86736298, 12.75097179], [74.86736298, 12.75153065], [74.86708069, 12.75152779], [74.86708069, 12.75208378], [74.86680603, 12.75207996], [74.86680603, 12.75264072], [74.86653137, 12.75264072], [74.86653137, 12.7529211], [74.86680603, 12.75291634], [74.86680603, 12.75319386], [74.86653137, 12.75319195], [74.86653137, 12.75374985], [74.86680603, 12.75374985], [74.86680603, 12.75403976], [74.86708069, 12.75402927], [74.86708069, 12.75445175], [74.87589264, 12.75529099], [74.87766266, 12.7523489], [74.87802887, 12.75024128], [74.87991333, 12.74927044], [74.88559723, 12.74877071], [74.8886795, 12.75237179], [74.89176178, 12.75452995], [74.89453125, 12.7560997], [74.89776611, 12.75540066], [74.90141296, 12.75953007], [74.90509796, 12.75993061], [74.90804291, 12.76257133], [74.90911102, 12.76303101], [74.92935181, 12.77133179], [74.93733215, 12.77219105], [74.95420074, 12.77928066], [74.96025848, 12.77904034], [74.96337128, 12.77482986], [74.96536255, 12.77480125], [74.96726227, 12.77685165], [74.96862793, 12.77626133], [74.96900177, 12.77292919], [74.97067261, 12.77256012], [74.98192596, 12.77523994], [74.98729706, 12.77792072], [74.9925766, 12.78362083], [74.98883057, 12.78923035], [74.98945618, 12.79081059], [74.99228668, 12.79045963], [74.9960022, 12.78798103], [75.00029755, 12.7834816], [75.00393677, 12.78561974], [75.00527954, 12.78549194], [75.0041275, 12.77355194], [75.00522614, 12.76933098], [75.00779724, 12.76509094], [75.00860596, 12.76043129], [75.0071106, 12.75706196], [75.00427246, 12.75399017], [75.0002594, 12.75155067], [74.99529266, 12.74484062], [74.99175262, 12.73816967], [74.98986053, 12.73728085], [74.9860611, 12.73847961], [74.98442841, 12.73594093], [74.98477936, 12.72988129], [74.98693848, 12.72879791], [74.98838043, 12.73192978], [74.99015045, 12.73110008], [74.99304962, 12.73313999], [75.00023651, 12.72740078], [75.01216888, 12.72284126], [75.01085663, 12.71928978], [75.00306702, 12.71369171], [75.00402832, 12.71172142], [75.00708008, 12.70920944], [75.01429749, 12.70780087], [75.01905823, 12.71475029], [75.02295685, 12.71562099], [75.0256958, 12.71431923], [75.0313797, 12.71695232], [75.03811646, 12.71858978], [75.04308319, 12.71552944], [75.04624176, 12.7163496], [75.04966736, 12.71469975], [75.05285645, 12.7098217], [75.05574799, 12.7034111], [75.0521698, 12.69817066], [75.05679321, 12.68672085], [75.05455017, 12.6835804], [75.05213165, 12.6870079], [75.04859924, 12.68832111], [75.04467773, 12.68744087], [75.04309082, 12.67057133], [75.04476166, 12.66330147], [75.04780579, 12.66008854], [75.05531311, 12.66006184], [75.05827332, 12.65863132], [75.0608902, 12.66148186], [75.06600952, 12.65795231], [75.07026672, 12.65802002], [75.07520294, 12.66543198], [75.079422, 12.6665802], [75.08309174, 12.66640854], [75.08490753, 12.67047977], [75.08670044, 12.67085075], [75.08743286, 12.67596054], [75.0849762, 12.68968201], [75.08242798, 12.69322968], [75.08609772, 12.69778156], [75.09163666, 12.69471169], [75.09925842, 12.69335079], [75.10441589, 12.69155121], [75.10865784, 12.68494129], [75.1126709, 12.67591095], [75.12078857, 12.67356968], [75.12689972, 12.67331123], [75.13188934, 12.67084026], [75.13667297, 12.67117119], [75.1391983, 12.67275047], [75.14450836, 12.6729002], [75.1506424, 12.67634201], [75.1506958, 12.66885853], [75.15571594, 12.66603088], [75.16113281, 12.66567993], [75.16129303, 12.66407108], [75.1550827, 12.65367985], [75.15164948, 12.64936066], [75.15123749, 12.64344025], [75.15032959, 12.64188957], [75.14122009, 12.63782024], [75.14296722, 12.63331032], [75.14766693, 12.62865067], [75.15487671, 12.61958027], [75.15917206, 12.61705017], [75.16279602, 12.61763954], [75.1700058, 12.61655998], [75.1774826, 12.62220955], [75.18257904, 12.62744141], [75.18985748, 12.62705135], [75.19438171, 12.62543106], [75.20143127, 12.62511063], [75.20279694, 12.62307167], [75.19946289, 12.61312103], [75.19870758, 12.60616016], [75.20244598, 12.60272121], [75.20729828, 12.59994984], [75.20954132, 12.59727192], [75.20897675, 12.59154034], [75.20749664, 12.58850193], [75.2045517, 12.58665085], [75.20340729, 12.58057022], [75.20752716, 12.58299065], [75.21084595, 12.58397961], [75.21404266, 12.57341194], [75.21691132, 12.57107067], [75.22290039, 12.56264019], [75.23129272, 12.56082153], [75.23629761, 12.56184006], [75.2381897, 12.56411266], [75.23867798, 12.57250023], [75.24003601, 12.57396984], [75.24948883, 12.57488155], [75.25019836, 12.5791893], [75.25617981, 12.58572102], [75.25881958, 12.59097004], [75.262146, 12.59300137], [75.26785278, 12.60568047], [75.27031708, 12.60898018], [75.27672577, 12.61166], [75.28103638, 12.60802937], [75.28885651, 12.60458088], [75.2911377, 12.59661961], [75.29390717, 12.59554195], [75.29833984, 12.59841061], [75.30149078, 12.59906101], [75.30561829, 12.59492016], [75.30825043, 12.58786964], [75.31852722, 12.58514023], [75.32785797, 12.58518124], [75.32846069, 12.57711124], [75.3263092, 12.57444191], [75.31936646, 12.57374191], [75.31619263, 12.56866169], [75.30977631, 12.57163239], [75.30314636, 12.57349968], [75.29496765, 12.57492924], [75.29139709, 12.57488155], [75.28676605, 12.56499004], [75.28349304, 12.56417179], [75.27683258, 12.56408978], [75.27258301, 12.55886173], [75.2709198, 12.55354023], [75.27240753, 12.53988075], [75.27961731, 12.52338028], [75.28114319, 12.51813984], [75.28581238, 12.51986122], [75.29177094, 12.52069092], [75.29611969, 12.51966], [75.30004883, 12.51689053], [75.30465698, 12.51729012], [75.30430603, 12.49751186], [75.3049469, 12.49675274], [75.30735016, 12.49741173], [75.31009674, 12.495821], [75.3141861, 12.49202061], [75.32064056, 12.49125099], [75.32805634, 12.49177074], [75.3348465, 12.49024105], [75.33557892, 12.48504925], [75.33898926, 12.48294067], [75.3393631, 12.47964954], [75.33833313, 12.47334194], [75.3405304, 12.46463108], [75.33676147, 12.45778179], [75.34086609, 12.45604992], [75.3556366, 12.45802116], [75.35941315, 12.45998096], [75.36273956, 12.46489143], [75.37206268, 12.46878147], [75.3730011, 12.47716141], [75.37055206, 12.48099041], [75.37000275, 12.48346996], [75.37223816, 12.48550987], [75.37721252, 12.48643112], [75.37950897, 12.48787975], [75.381073, 12.49149036], [75.3830719, 12.49265957], [75.38656616, 12.49192142], [75.39187622, 12.49254131], [75.39492798, 12.49755955], [75.39731598, 12.49781036], [75.40099335, 12.49057198], [75.40423584, 12.48960114], [75.40892029, 12.49419117], [75.41448975, 12.49671173], [75.42018127, 12.47966194], [75.42053986, 12.4715414], [75.42428589, 12.46625137], [75.42250824, 12.46006107], [75.41677094, 12.45888042], [75.41467285, 12.45409203], [75.40908051, 12.44985008], [75.40349579, 12.44756889], [75.39192963, 12.44508934], [75.38582611, 12.45070076], [75.36662292, 12.45166016], [75.3658905, 12.44908047], [75.36943817, 12.44563198], [75.3705368, 12.42894173], [75.36560059, 12.4070406], [75.36972046, 12.4017992], [75.37219238, 12.39573002], [75.3761673, 12.39246178], [75.37858582, 12.38667107], [75.38117218, 12.38479042], [75.38578796, 12.3855896], [75.39071655, 12.38344097], [75.39433289, 12.37983131], [75.39711761, 12.37524128], [75.40113831, 12.37570095], [75.40336609, 12.37255955], [75.41146088, 12.37457085], [75.41886902, 12.36952019], [75.42138672, 12.36672974], [75.4214325, 12.36190128], [75.4193573, 12.35254955], [75.4177475, 12.34843063], [75.41427612, 12.34393024], [75.41005707, 12.34134102], [75.41117859, 12.33782196], [75.41436768, 12.33375072], [75.41633606, 12.32147121], [75.41985321, 12.31946087], [75.41996002, 12.31446075], [75.42308044, 12.30814075], [75.42990875, 12.30223083], [75.43039703, 12.29952145], [75.42164612, 12.29096127], [75.41912842, 12.28639984], [75.42366791, 12.28703976], [75.42737579, 12.29067135], [75.43073273, 12.29200172], [75.43608093, 12.29181099], [75.44140625, 12.29001045], [75.45836639, 12.28855228], [75.46720886, 12.29537964], [75.48272705, 12.28618145], [75.48670197, 12.28146076], [75.49252319, 12.26681995], [75.4940033, 12.265131], [75.50200653, 12.2640419], [75.50392914, 12.26315975], [75.5038681, 12.25970173], [75.5111084, 12.25332069], [75.51140594, 12.25043964], [75.51307678, 12.24932098], [75.51667023, 12.24375057], [75.51928711, 12.23593998], [75.51994324, 12.23317146], [75.51850128, 12.23060036], [75.52336121, 12.22887039], [75.52482605, 12.22503185], [75.52532959, 12.21963024], [75.53793335, 12.21105194], [75.53804779, 12.20678139], [75.53688049, 12.20352173], [75.5329895, 12.19909096], [75.53373718, 12.19609165], [75.53791809, 12.19539165], [75.54036713, 12.19237041], [75.54386139, 12.19197083], [75.54875183, 12.18838978], [75.5511322, 12.18444061], [75.55240631, 12.17614174], [75.55525208, 12.17633057], [75.55961609, 12.16867065], [75.56384277, 12.16683197], [75.57038879, 12.16545963], [75.57684326, 12.15075016], [75.58271027, 12.15043068], [75.58715057, 12.14829063], [75.59144592, 12.14304924], [75.5931778, 12.14295959], [75.59471893, 12.14535999], [75.59760284, 12.1465292], [75.6020813, 12.1467514], [75.60814667, 12.1486702], [75.61131287, 12.14586163], [75.61708832, 12.14893246], [75.6268692, 12.14505005], [75.62937164, 12.14161968], [75.63508606, 12.1423912], [75.63678741, 12.14042091], [75.63761902, 12.13377953], [75.64068604, 12.13315105], [75.64250946, 12.13077164], [75.64385223, 12.12707043], [75.64433289, 12.12371063], [75.64298248, 12.11993027], [75.64745331, 12.11475086], [75.64807892, 12.10558033], [75.65155029, 12.10396194], [75.65278625, 12.10130024], [75.65822601, 12.09430122], [75.66242981, 12.0911808], [75.66760254, 12.09000015], [75.67273712, 12.09066963], [75.67830658, 12.09306145], [75.681633, 12.09657955], [75.68419647, 12.10224056], [75.6919632, 12.10258961], [75.70159912, 12.10033131], [75.70033264, 12.08803082], [75.70066071, 12.08353043], [75.70652771, 12.08280945], [75.71714783, 12.07843113], [75.71753693, 12.07745075], [75.71420288, 12.06921196], [75.71465302, 12.06534195], [75.71705627, 12.06208992], [75.72805023, 12.06410027], [75.73435974, 12.06770134], [75.73890686, 12.0721817], [75.74294281, 12.07178116], [75.74758911, 12.0734396], [75.75190735, 12.07740974], [75.75813293, 12.07721043], [75.76296234, 12.07858181], [75.7678833, 12.07752037], [75.78370667, 12.07643032], [75.7895813, 12.07461071], [75.79534912, 12.07423115], [75.79968262, 12.0711813], [75.80169678, 12.06797886], [75.79618073, 12.04949093], [75.79325867, 12.04751015], [75.79785919, 12.04164124], [75.79857635, 12.03966999], [75.79815674, 12.03267097], [75.79995728, 12.0302906], [75.81019592, 12.02406025], [75.81199646, 12.02196121], [75.81191254, 12.01611042], [75.8235321, 12.00933933], [75.82662964, 12.00579071], [75.82752228, 12.00284958], [75.82375336, 11.99456978], [75.82359314, 11.99456978], [75.8243866, 11.98427963], [75.82697296, 11.97797108], [75.83058929, 11.97463036], [75.83969116, 11.97281075], [75.84443665, 11.97027016], [75.84657288, 11.96465015], [75.85108948, 11.95704174], [75.86589813, 11.94563007], [75.87674713, 11.94071198], [75.88330078, 11.93891239], [75.88968658, 11.93814087], [75.89444733, 11.9365406], [75.90379333, 11.93476963], [75.91543579, 11.93402958], [75.91963196, 11.93562126], [75.92518616, 11.93287182], [75.93112183, 11.93111038], [75.93718719, 11.93283081], [75.94838715, 11.93391132], [75.95490265, 11.93151093], [75.95887756, 11.92860985], [75.9679184, 11.92697144], [75.97264862, 11.92755032], [75.97627258, 11.92496967], [75.9798584, 11.92466927], [75.98336792, 11.92544174], [75.9944458, 11.9233017], [75.99819183, 11.92362118], [76.00396729, 11.93192101], [76.01390076, 11.93326187], [76.01843262, 11.9350214], [76.02301788, 11.93465042], [76.02958679, 11.93278122], [76.03851318, 11.93900013], [76.04194641, 11.9433012], [76.04775238, 11.94447041], [76.06674957, 11.95827103], [76.07280731, 11.96128082], [76.08100128, 11.96067047], [76.09127045, 11.96158886], [76.10791016, 11.97063923], [76.10865021, 11.9280901], [76.10743713, 11.87633991], [76.10874939, 11.87059021], [76.10932159, 11.85859013], [76.10806274, 11.85118103], [76.11653137, 11.84304047], [76.12043762, 11.84429073], [76.1256485, 11.84477043], [76.13902283, 11.85711098], [76.14942169, 11.86101055], [76.16259003, 11.86003113], [76.1736908, 11.86244202], [76.18403625, 11.8637619], [76.19608307, 11.85554123], [76.20088959, 11.85412979], [76.20342255, 11.84906101], [76.20510864, 11.83865929], [76.20720673, 11.83176041], [76.205513, 11.81958103], [76.21199036, 11.81427002], [76.21431732, 11.80420971], [76.21852875, 11.80003929], [76.23210907, 11.79646969], [76.2443924, 11.79531002], [76.25312805, 11.79979992], [76.26544952, 11.80041122], [76.2720108, 11.80354023], [76.27509308, 11.80076027], [76.28365326, 11.78486919], [76.29469299, 11.7780714], [76.29995728, 11.77615166], [76.30311584, 11.76957035], [76.3105011, 11.7438612], [76.31758118, 11.7403717], [76.32434845, 11.73873138], [76.3349762, 11.73062992], [76.34091949, 11.73110008], [76.34625244, 11.73050117], [76.35114288, 11.73443031], [76.35604858, 11.73991108], [76.37233734, 11.73620129], [76.38376617, 11.74504089], [76.39071655, 11.74286938], [76.40441895, 11.74985027], [76.4076767, 11.75333118], [76.4108429, 11.7464819], [76.40661621, 11.74063969], [76.40558624, 11.73336124], [76.41197968, 11.73429108], [76.41726685, 11.72593117], [76.41899109, 11.7215004], [76.41889191, 11.71708107], [76.41793823, 11.71358013], [76.41108704, 11.70995045], [76.40867615, 11.70414925], [76.40628815, 11.70359993], [76.40310669, 11.70677853], [76.39640808, 11.70107937], [76.40293884, 11.69948196], [76.40219879, 11.68311977], [76.40740204, 11.66953087], [76.41020966, 11.66456985], [76.41757965, 11.66342068], [76.42346191, 11.65932083], [76.42767334, 11.64752197], [76.4298172, 11.6450901], [76.43461609, 11.64161015], [76.43557739, 11.63770103], [76.43421936, 11.63352108], [76.43070221, 11.62963104], [76.42588806, 11.62903118], [76.42479706, 11.62329006], [76.42128754, 11.62510014], [76.39618683, 11.62531185], [76.38006592, 11.62241936], [76.37674713, 11.61474133], [76.37683868, 11.60464001], [76.37106323, 11.60069942], [76.37069702, 11.59346962], [76.3653717, 11.59171867], [76.35011292, 11.58274174], [76.34034729, 11.58056068], [76.33558655, 11.57834053], [76.33349609, 11.58065033], [76.3334198, 11.58512974], [76.32858276, 11.58855057], [76.31109619, 11.57751083], [76.30919647, 11.56960011], [76.30517578, 11.57042122], [76.29789734, 11.56433105], [76.29377747, 11.56503105], [76.29316711, 11.57176113], [76.29064178, 11.58056068], [76.28588867, 11.58295155], [76.27793884, 11.5835104], [76.27600098, 11.58995056], [76.27097321, 11.59290886], [76.266716, 11.58932018], [76.25969696, 11.5869379], [76.22574615, 11.56443977], [76.22693634, 11.55968189], [76.23445892, 11.54648113], [76.2383194, 11.53335953], [76.24246979, 11.52879047], [76.24295807, 11.5241909], [76.23964691, 11.52094078], [76.23320007, 11.51867962], [76.24151611, 11.50479126], [76.24288177, 11.49868965], [76.24475861, 11.49432087], [76.24089813, 11.47521019], [76.24009705, 11.45964146], [76.24726868, 11.46414948], [76.25792694, 11.47322273], [76.26608276, 11.46869183], [76.27806091, 11.47453117], [76.28578949, 11.46857071], [76.28769684, 11.46599102], [76.28407288, 11.46243954], [76.28903961, 11.4563179], [76.297966, 11.4588604], [76.30593872, 11.45335102], [76.32090759, 11.44469929], [76.33368683, 11.45871067], [76.33905792, 11.45417976], [76.35308075, 11.45083046], [76.36148071, 11.44796085], [76.37058258, 11.44089985], [76.39057922, 11.42796135], [76.41039276, 11.43359089], [76.41004944, 11.42520142], [76.40817261, 11.41481972], [76.41838837, 11.40526962], [76.43934631, 11.39066982], [76.44838715, 11.38141918], [76.47286987, 11.37534142], [76.51007843, 11.36115074], [76.50945282, 11.3537302], [76.50673676, 11.34766006], [76.50949097, 11.34661198], [76.51637268, 11.34897137], [76.52986145, 11.34768105], [76.53820038, 11.35159016], [76.54075623, 11.32704067], [76.53978729, 11.32095146], [76.53524017, 11.3163414], [76.53048706, 11.30963993], [76.52854156, 11.30344963], [76.5304718, 11.29574203], [76.54016876, 11.29234791], [76.53405762, 11.28796101], [76.52194977, 11.28120136], [76.51593018, 11.2724514], [76.51309204, 11.26466084], [76.51352692, 11.26196003], [76.48812866, 11.25196171], [76.44638824, 11.23046112], [76.44287872, 11.20009136], [76.43802643, 11.19454956], [76.44030762, 11.19125938], [76.443573, 11.1908989], [76.45272064, 11.18021011], [76.45883179, 11.18412971], [76.46653748, 11.18609047], [76.46586609, 11.19874191], [76.474823, 11.20125961], [76.48764801, 11.20279026], [76.50231171, 11.20286179], [76.50601196, 11.20197964], [76.51024628, 11.19528198], [76.5212326, 11.19027042], [76.53611755, 11.18931103], [76.54801178, 11.19314194], [76.57778168, 11.19684124], [76.59333801, 11.19749069], [76.60205841, 11.1954689], [76.62303925, 11.18567085], [76.62966919, 11.19080067], [76.64164734, 11.19651031], [76.65344238, 11.20429134], [76.66819, 11.21068001], [76.67816925, 11.21883011], [76.67784119, 11.22280025], [76.67938995, 11.2270298], [76.69696808, 11.23133087], [76.71038818, 11.21831036], [76.72054291, 11.21163273], [76.72261047, 11.20810032], [76.72557831, 11.20889091], [76.72654724, 11.20646954], [76.71795654, 11.19831085], [76.71791077, 11.19240093], [76.72115326, 11.18451118], [76.71375275, 11.17801094], [76.70643616, 11.1796217], [76.70133209, 11.17453957], [76.69676971, 11.17187977], [76.6934967, 11.16672039], [76.68902588, 11.16508961], [76.68601227, 11.15770054], [76.69117737, 11.14451027], [76.6950531, 11.14023018], [76.69667816, 11.13268089], [76.70014954, 11.1314497], [76.70361328, 11.13201141], [76.70555878, 11.13612938], [76.70269012, 11.13862038], [76.70298767, 11.14178181], [76.70983124, 11.1402998], [76.71266174, 11.13286972], [76.71536255, 11.12842083], [76.72220612, 11.12251186], [76.72930908, 11.12539005], [76.73493195, 11.12512112], [76.73871613, 11.12129021], [76.7388916, 11.11485958], [76.74060822, 11.10991001], [76.73937225, 11.10361099], [76.73500061, 11.09910011], [76.73413849, 11.0933609], [76.73858643, 11.08395958], [76.74272919, 11.08600044], [76.74572754, 11.08392143], [76.7462616, 11.07885933], [76.74803925, 11.0751009], [76.74643707, 11.07087135], [76.73449707, 11.06389046], [76.73443604, 11.05832195], [76.73600006, 11.05445194], [76.73709869, 11.04751015], [76.74022675, 11.04562855], [76.74649048, 11.04697037], [76.75112915, 11.04675961], [76.754776, 11.03919983], [76.76232147, 11.03426075], [76.7671814, 11.03221035], [76.7754364, 11.03428173], [76.7899704, 11.04968166], [76.79342651, 11.04701138], [76.79247284, 11.0423727], [76.78678131, 11.03225136], [76.78183746, 11.02895069], [76.75697327, 11.02459145], [76.74401855, 11.02590084], [76.73239899, 11.02897072], [76.71205139, 11.03245068], [76.70652008, 11.03135109], [76.69883728, 11.0226717], [76.6904068, 11.01749992], [76.67978668, 10.99943066], [76.68081665, 10.99265957], [76.67868805, 10.98605061], [76.67777252, 10.97970104], [76.66044617, 10.96045971], [76.65931702, 10.95048046], [76.654953, 10.94219112], [76.65727997, 10.93868065], [76.65558624, 10.93427086], [76.64739227, 10.92897034], [76.64916229, 10.92415237], [76.65278625, 10.91996002], [76.67487335, 10.90640163], [76.68460083, 10.90243053], [76.69300079, 10.90227032], [76.70040131, 10.90079021], [76.71142578, 10.89556026], [76.71846008, 10.88984108], [76.72283936, 10.88762188], [76.7278595, 10.88679886], [76.73079681, 10.88408184], [76.7326889, 10.88097954], [76.73943329, 10.88443089], [76.74395752, 10.88492107], [76.74910736, 10.88478184], [76.76191711, 10.87977028], [76.76669312, 10.88174057], [76.77298737, 10.88164139], [76.77773285, 10.87897015], [76.78128052, 10.87390137], [76.78527069, 10.87147236], [76.79094696, 10.87096977], [76.81755829, 10.86180115], [76.82089233, 10.85891056], [76.82459259, 10.85044193], [76.82762909, 10.84714031], [76.83407593, 10.84270191], [76.83872986, 10.83762169], [76.84266663, 10.83185101], [76.84519196, 10.82650185], [76.84342957, 10.82250023], [76.83712769, 10.81553936], [76.84041595, 10.8076601], [76.85259247, 10.80850124], [76.85999298, 10.79980183], [76.88194275, 10.80107117], [76.88829803, 10.79988194], [76.89148712, 10.79216003], [76.89750671, 10.77079964], [76.89668274, 10.76607132], [76.89385986, 10.76055145], [76.89427948, 10.75535202], [76.8931427, 10.75040245], [76.89035034, 10.74749088], [76.88765717, 10.74300957], [76.88680267, 10.73674965], [76.88040161, 10.72614002], [76.87931824, 10.72023964], [76.88128662, 10.71292973], [76.88374329, 10.70735073], [76.88101196, 10.70606136], [76.87504578, 10.70672035], [76.8651123, 10.69293976], [76.86160278, 10.68626022], [76.86190033, 10.68056202], [76.85980225, 10.67714119], [76.8555069, 10.67527199], [76.85507202, 10.67240047], [76.86326599, 10.66695976], [76.86769867, 10.66623974], [76.87016296, 10.66409969], [76.87036896, 10.66076088], [76.86947632, 10.65635967], [76.87216949, 10.65353107], [76.87460327, 10.63922977], [76.87261963, 10.62943172], [76.85952759, 10.62520027], [76.85246277, 10.62394142], [76.84471893, 10.62627125], [76.83822632, 10.62671089], [76.83129883, 10.62588978], [76.82685089, 10.627141], [76.8224411, 10.62738132], [76.81468964, 10.6260004], [76.80499268, 10.62634087], [76.80568695, 10.62082958], [76.80326843, 10.61408043], [76.80497742, 10.60913181], [76.80847931, 10.60727024], [76.80961609, 10.60427856], [76.80861664, 10.59448147], [76.81539917, 10.58829975], [76.82450104, 10.58956146], [76.82834625, 10.58827972], [76.82972717, 10.58506203], [76.82932281, 10.5764513], [76.82601166, 10.56751919], [76.82546234, 10.56156158], [76.82907104, 10.55706024], [76.83017731, 10.55298138], [76.82572937, 10.54298019], [76.8245163, 10.53763962], [76.83196259, 10.52916145], [76.83143616, 10.52457142], [76.82525635, 10.50298119], [76.82028961, 10.49067974], [76.82097626, 10.48023129], [76.81745148, 10.43848991], [76.80732727, 10.41491985], [76.81196594, 10.41138935], [76.81503296, 10.40178967], [76.82145691, 10.40340996], [76.82264709, 10.39893246], [76.82264709, 10.39406109], [76.8156662, 10.38653088], [76.82048798, 10.38179016], [76.82460785, 10.37524033], [76.83069611, 10.37210178], [76.83815765, 10.36264133], [76.83934784, 10.35970974], [76.83624268, 10.35296059], [76.83577728, 10.34636974], [76.82756042, 10.33758163], [76.82569122, 10.33421135], [76.82676697, 10.33026123], [76.82585907, 10.32004166], [76.82419586, 10.31231117], [76.81961823, 10.30263996], [76.81967163, 10.2952404], [76.82492065, 10.29383087], [76.83000183, 10.29111004], [76.83194733, 10.28377056], [76.83525085, 10.2816906], [76.83854675, 10.27759933], [76.83988953, 10.27754021], [76.83985901, 10.28143978], [76.84056854, 10.28361034], [76.85073853, 10.2828207], [76.85788727, 10.28926182], [76.86057281, 10.29074097], [76.86427307, 10.29004097], [76.86206818, 10.28254986], [76.86157227, 10.26962852], [76.86229706, 10.26706123], [76.87081909, 10.26408195], [76.87705994, 10.25631046], [76.8846283, 10.25507927], [76.89182281, 10.24308014], [76.89356232, 10.23744106], [76.89231873, 10.23267078], [76.89872742, 10.2325592], [76.90123749, 10.22781181], [76.90547943, 10.22475147], [76.90934753, 10.22319889], [76.92030334, 10.22544098], [76.92500305, 10.22978115], [76.92777252, 10.22958946], [76.93920898, 10.2211113], [76.94587708, 10.22279072], [76.95226288, 10.2197504], [76.95878601, 10.21873188], [76.96176147, 10.21581173], [76.96734619, 10.21257973], [76.97078705, 10.20865059], [76.97458649, 10.21393204], [76.98145294, 10.21990967], [76.98726654, 10.21994019], [76.99141693, 10.22299957], [76.99372101, 10.22772121], [76.99577332, 10.22935009], [76.99939728, 10.22979927], [77.00666809, 10.23637009], [77.01522064, 10.23759174], [77.01603699, 10.24096012], [77.01859283, 10.24183083], [77.03025818, 10.24293232], [77.03855133, 10.24816036], [77.04250336, 10.26197147], [77.03383636, 10.27217102], [77.0460968, 10.27429008], [77.05332184, 10.27989006], [77.05111694, 10.2828598], [77.05187988, 10.28548145], [77.06078339, 10.28646088], [77.06755066, 10.29022121], [77.07344055, 10.29579163], [77.08170319, 10.29965019], [77.08795929, 10.30176067], [77.09224701, 10.30426979], [77.10072327, 10.30445004], [77.10832214, 10.30717087], [77.11425781, 10.31056023], [77.11933136, 10.31551075], [77.12673187, 10.32024193], [77.13405609, 10.32371998], [77.14823151, 10.33405972], [77.16295624, 10.34628105], [77.16883087, 10.34598923], [77.17312622, 10.34401131], [77.18136597, 10.34317017], [77.1889801, 10.34617043], [77.19274139, 10.3434], [77.19946289, 10.34195137], [77.21444702, 10.34136963], [77.22216034, 10.34030056], [77.22251129, 10.32853127], [77.21833038, 10.32201958], [77.2144928, 10.30580139], [77.21720886, 10.29800034], [77.22093201, 10.29603958], [77.23191833, 10.27723026], [77.24652863, 10.25755024], [77.25054932, 10.2537508], [77.24755859, 10.25157166], [77.24530029, 10.24857044], [77.24482727, 10.24518967], [77.24577332, 10.23215103], [77.2455368, 10.22625065], [77.24652863, 10.22060966], [77.24915314, 10.22205925], [77.2512207, 10.22436142], [77.25418854, 10.22332191], [77.25556946, 10.22552967], [77.25875092, 10.22385979], [77.26622772, 10.22509003], [77.26996613, 10.22433186], [77.27482605, 10.22054958], [77.28044891, 10.20725155], [77.27905273, 10.20401096], [77.27620697, 10.20366192], [77.27385712, 10.20146942], [77.27297974, 10.19776058], [77.26966858, 10.19678974], [77.2713623, 10.19406033], [77.26941681, 10.18710041], [77.26441193, 10.17973995], [77.25914764, 10.15535069], [77.25961304, 10.14122963], [77.25743103, 10.13588142], [77.25756073, 10.13222027], [77.26013947, 10.13066101], [77.26101685, 10.12869167], [77.25978088, 10.11908054], [77.25498962, 10.11631203], [77.25327301, 10.11140919], [77.24608612, 10.11235142], [77.23990631, 10.11413956], [77.23483276, 10.11665058], [77.2305069, 10.12012005], [77.22511292, 10.11845016], [77.22126007, 10.11537075], [77.21872711, 10.11129093], [77.2154007, 10.10929203], [77.21234894, 10.10876083], [77.20600128, 10.10603142], [77.20330048, 10.10362244], [77.19787598, 10.10647964], [77.19460297, 10.10624886], [77.18814087, 10.09565163], [77.18779755, 10.09250164], [77.18990326, 10.09097004], [77.18979645, 10.08655071], [77.19072723, 10.08115196], [77.19519806, 10.07354164], [77.19906616, 10.07066059], [77.20443726, 10.06849098], [77.2129364, 10.0584507], [77.21817017, 10.05686092], [77.22068024, 10.05061054], [77.2244873, 10.04554939], [77.23065948, 10.03952122], [77.23707581, 10.03520203], [77.2423172, 10.02615166], [77.24556732, 10.02362156], [77.24809265, 10.02023029], [77.24893188, 10.01581097], [77.24443054, 10.00774956], [77.2407074, 10.00289059], [77.24088287, 10.00013065], [77.24768066, 9.99484062], [77.24772644, 9.99116039], [77.2478714, 9.99116039], [77.24514771, 9.98622131], [77.24672699, 9.98149014], [77.25076294, 9.98140144], [77.2487793, 9.97740078], [77.24983978, 9.97278118], [77.25952148, 9.96620083], [77.2614212, 9.96372128], [77.25898743, 9.953372], [77.25527954, 9.95018959], [77.24991608, 9.94253922], [77.24021149, 9.94306087], [77.23661041, 9.94138145], [77.23594666, 9.94338036], [77.23471069, 9.94283104], [77.23448181, 9.93811131], [77.2219162, 9.92282009], [77.22094727, 9.91775131], [77.21689606, 9.90576077], [77.20443726, 9.89431953], [77.20654297, 9.87776184], [77.2027359, 9.87474155], [77.20144653, 9.869771], [77.19911194, 9.8659811], [77.20919037, 9.85379028], [77.21325684, 9.85198021], [77.2183075, 9.8534708], [77.22366333, 9.84901047], [77.22373962, 9.84296131], [77.21383667, 9.83854008], [77.21335602, 9.832901], [77.21502686, 9.83087063], [77.20892334, 9.81452179], [77.21235657, 9.81293201], [77.21898651, 9.81325054], [77.21945953, 9.80884075], [77.22708893, 9.80631065], [77.23282623, 9.79728985], [77.23203278, 9.79441071], [77.2339859, 9.78851986], [77.2266922, 9.78675079], [77.22254944, 9.78177071], [77.20981598, 9.77994061], [77.21069336, 9.76638889], [77.21859741, 9.76000977], [77.2124176, 9.75539017], [77.21135712, 9.74524975], [77.20603943, 9.7374897], [77.20822906, 9.72167015], [77.19991302, 9.71728992], [77.18992615, 9.71551037], [77.19021606, 9.70615196], [77.18900299, 9.69750023], [77.19168854, 9.68618202], [77.18589783, 9.67817116], [77.18477631, 9.67147923], [77.18219757, 9.66871929], [77.17959595, 9.66038036], [77.17251587, 9.65620041], [77.17308807, 9.65184021], [77.16887665, 9.65157986], [77.16565704, 9.6482296], [77.16588593, 9.6379509], [77.16062927, 9.63024139], [77.16065216, 9.6273098], [77.1622467, 9.61981106], [77.15457916, 9.61395168], [77.15487671, 9.60838127], [77.15187073, 9.60601997], [77.15550232, 9.60150146], [77.1672821, 9.60066891], [77.17456818, 9.59716129], [77.17914581, 9.60146046], [77.18398285, 9.6024313], [77.18596649, 9.60592175], [77.19593811, 9.60419178], [77.19657898, 9.59570026], [77.20081329, 9.5923996], [77.2053833, 9.59227943], [77.20861053, 9.58883953], [77.20910645, 9.58443928], [77.21466827, 9.57880116], [77.22280884, 9.57279015], [77.22989655, 9.57592201], [77.2388916, 9.57336044], [77.24198914, 9.57154083], [77.24475861, 9.56861115], [77.24672699, 9.56866074], [77.25054932, 9.56541061], [77.25501251, 9.564991], [77.25785828, 9.56816196], [77.26113892, 9.56667995], [77.27529144, 9.57658958], [77.27497101, 9.58095169], [77.27954102, 9.58006954], [77.28649139, 9.58729935], [77.30430603, 9.59304142], [77.30901337, 9.58883095], [77.31371307, 9.59013939], [77.31484985, 9.58862114], [77.31078339, 9.58450127], [77.31201172, 9.57815075], [77.30976105, 9.5759697], [77.31067657, 9.57036114], [77.32100677, 9.56737137], [77.32478333, 9.5632], [77.32850647, 9.57322979], [77.34089661, 9.59505081], [77.35106659, 9.58930016], [77.35132599, 9.58804035], [77.34922028, 9.58649921], [77.34623718, 9.58780956], [77.34481812, 9.58760929], [77.34320068, 9.58481121], [77.34091949, 9.57763958], [77.34525299, 9.56727028], [77.34371185, 9.56384945], [77.3405304, 9.56406116], [77.33587646, 9.55683041], [77.33743286, 9.55486012], [77.33805084, 9.55027008], [77.33996582, 9.54911041], [77.34655762, 9.5485611], [77.34880829, 9.5461998], [77.35057068, 9.54026031], [77.35054779, 9.52629185], [77.35470581, 9.52390957], [77.36097717, 9.51616955], [77.36625671, 9.51479053], [77.37071991, 9.50869179], [77.3867569, 9.51673985], [77.38639832, 9.50679111], [77.39008331, 9.50463104], [77.39486694, 9.50439072], [77.3962326, 9.49654198], [77.38788605, 9.49096012], [77.38551331, 9.48619175], [77.38391876, 9.47909069], [77.38405609, 9.46977997], [77.38683319, 9.46737099], [77.38220978, 9.46118069], [77.37737274, 9.45866013], [77.37858582, 9.45075035], [77.37223816, 9.44527054], [77.36765289, 9.44390106], [77.3636322, 9.4433012], [77.3602066, 9.44367981], [77.35655212, 9.44791031], [77.35160828, 9.44970131], [77.34542847, 9.445261], [77.34292603, 9.4404211], [77.3342514, 9.43105125], [77.33461761, 9.42393112], [77.33185577, 9.42138958], [77.33007813, 9.41521072], [77.3241272, 9.40818024], [77.32167816, 9.40565014], [77.32137299, 9.40180111], [77.3274231, 9.39406109], [77.32762909, 9.38980961], [77.32488251, 9.38354015], [77.32608795, 9.38046074], [77.32579041, 9.37868118], [77.31980133, 9.37613106], [77.31954193, 9.36326027], [77.32303619, 9.35856056], [77.32000732, 9.35480022], [77.32061005, 9.35109043], [77.30966187, 9.33464146], [77.31134033, 9.32790184], [77.30702972, 9.327631], [77.30010986, 9.32495022], [77.29055023, 9.327672], [77.28687286, 9.32690144], [77.28414154, 9.32747078], [77.28515625, 9.32123089], [77.28230286, 9.31961918], [77.2853775, 9.31560135], [77.28681946, 9.31006145], [77.28675842, 9.30811024], [77.28423309, 9.30506039], [77.28350067, 9.30091], [77.27768707, 9.29526043], [77.27345276, 9.29419136], [77.27011108, 9.29177094], [77.26682281, 9.2908802], [77.26714325, 9.28168964], [77.27411652, 9.26317024], [77.26760864, 9.26239967], [77.2678299, 9.25787067], [77.26590729, 9.25529099], [77.26566315, 9.24368095], [77.26248169, 9.24090958], [77.26364899, 9.23185921], [77.2594986, 9.22441101], [77.26139069, 9.21698093], [77.26680756, 9.20881939], [77.25817871, 9.20007038], [77.2532959, 9.19336033], [77.25026703, 9.19023991], [77.24704742, 9.18925953], [77.23973083, 9.18994999], [77.23957062, 9.18656063], [77.23661804, 9.17919064], [77.24328613, 9.17612076], [77.24550629, 9.17597008], [77.2483902, 9.17578125], [77.25229645, 9.16495132], [77.24960327, 9.15603924], [77.25177765, 9.14304066], [77.24606323, 9.13924026], [77.24537659, 9.13554955], [77.23766327, 9.1299696], [77.23258209, 9.11791134], [77.23015594, 9.1148119], [77.22572327, 9.1141386], [77.21704865, 9.10809135], [77.21173096, 9.10636139], [77.20935059, 9.09757042], [77.20482635, 9.09581089], [77.2022171, 9.09138012], [77.19586182, 9.08842182], [77.18974304, 9.07518005], [77.19062042, 9.06997013], [77.19284821, 9.06503105], [77.19148254, 9.06195164], [77.1886673, 9.05648041], [77.18434906, 9.05064011], [77.18286896, 9.04710102], [77.18019104, 9.04480076], [77.18208313, 9.03650093], [77.17014313, 9.03388023], [77.16742706, 9.0385313], [77.15376282, 9.03656006], [77.14824677, 9.03298187], [77.14533234, 9.02721977], [77.14689636, 9.02156067], [77.14055634, 9.01543045], [77.13648987, 9.01310062], [77.13217926, 9.01185036], [77.13326263, 9.00825119], [77.13510895, 9.00547028], [77.13424683, 8.99997997], [77.13725281, 8.99822044], [77.14319611, 8.99788094], [77.14392853, 8.99184132], [77.1440506, 8.99184132], [77.14689636, 8.98694992], [77.15844727, 8.97819138], [77.1632309, 8.96234035], [77.17473602, 8.95685196], [77.17529297, 8.95083046], [77.18016815, 8.94701958], [77.18123627, 8.94197083], [77.17967224, 8.93749046], [77.18164825, 8.93256092], [77.18187714, 8.92883015], [77.17919159, 8.92098045], [77.18061829, 8.91845131], [77.18044281, 8.91574955], [77.18476868, 8.9101696], [77.18966675, 8.91257], [77.18675232, 8.91567039], [77.18976593, 8.91957188], [77.19386292, 8.92191029], [77.1980896, 8.91930962], [77.20474243, 8.91741085], [77.20736694, 8.91389179], [77.20204163, 8.90668106], [77.20625305, 8.8931818], [77.2116394, 8.89305019], [77.21473694, 8.89212036], [77.22145081, 8.88813972], [77.22389984, 8.88514996], [77.22318268, 8.87781143], [77.22712708, 8.87181854], [77.23203278, 8.86905003], [77.23986816, 8.86806107], [77.24150085, 8.86478233], [77.24298859, 8.85927105], [77.24318695, 8.85509109], [77.24040985, 8.85147095], [77.24562073, 8.84508133], [77.24595642, 8.84307957], [77.2428894, 8.84123993], [77.24704742, 8.83187962], [77.23616791, 8.81762791], [77.23195648, 8.81346035], [77.23085785, 8.81157112], [77.23159027, 8.80709171], [77.22735596, 8.80056], [77.22396851, 8.79833126], [77.21736145, 8.79703045], [77.21536255, 8.78666019], [77.2146759, 8.77576065], [77.20960999, 8.77371025], [77.20529175, 8.77039146], [77.19837952, 8.76949978], [77.19933319, 8.76559067], [77.20224762, 8.76088047], [77.19780731, 8.75774193], [77.19143677, 8.75839138], [77.18300629, 8.76111031], [77.18076324, 8.75756168], [77.18344116, 8.75336075], [77.18370819, 8.74814034], [77.18107605, 8.74081039], [77.1765213, 8.73502064], [77.17093658, 8.73338032], [77.16274261, 8.73518085], [77.15724182, 8.74075985], [77.15531921, 8.73756027], [77.15737915, 8.73118114], [77.16294098, 8.720891], [77.16172791, 8.71516132], [77.16703033, 8.70763111], [77.17234802, 8.70324993], [77.17929077, 8.69961929], [77.18296814, 8.69003105], [77.18772125, 8.68376064], [77.18975067, 8.67737961], [77.19046783, 8.67118931], [77.18710327, 8.66229153], [77.19033813, 8.65489101], [77.19523621, 8.64868069], [77.1984787, 8.64109993], [77.20523071, 8.63528156], [77.20825195, 8.63115025], [77.21237946, 8.62877941], [77.21869659, 8.61837959], [77.22827911, 8.61290073], [77.22786713, 8.60309124], [77.22840881, 8.59781265], [77.2321167, 8.59211922], [77.23761749, 8.58842945], [77.24285889, 8.58055019], [77.25152588, 8.57098961], [77.25969696, 8.54906178], [77.26508331, 8.54255962], [77.26515961, 8.53744984], [77.25817108, 8.52812958], [77.25248718, 8.51708126], [77.24754333, 8.50137997], [77.24125671, 8.49812984], [77.23240662, 8.49591923], [77.22754669, 8.49059963], [77.22255707, 8.4883213], [77.21726227, 8.49613953], [77.20639038, 8.50443172], [77.19857788, 8.50393963], [77.1920166, 8.49938107], [77.18649292, 8.49337101], [77.19091797, 8.48819065], [77.19462585, 8.4693718], [77.19877625, 8.46023941], [77.20513153, 8.45551014], [77.2090683, 8.45068073], [77.21022797, 8.44305038], [77.20951843, 8.43771935], [77.19877625, 8.43677998], [77.18868256, 8.43474102], [77.18267059, 8.4274807], [77.18039703, 8.41860199], [77.17977905, 8.409091], [77.17222595, 8.40170002], [77.16709137, 8.39546013], [77.16448212, 8.38784027], [77.15368652, 8.37744141], [77.14939117, 8.37543964], [77.14579773, 8.38169956], [77.14074707, 8.38280964], [77.13481903, 8.37852955], [77.13584137, 8.37251091], [77.14121246, 8.36899185], [77.14322662, 8.36227131], [77.13537598, 8.35174084], [77.13577271, 8.34566975], [77.1415329, 8.3491497], [77.14749908, 8.35458088], [77.15203857, 8.35473061], [77.15460968, 8.35139942], [77.15680695, 8.34519958], [77.15093231, 8.3354702], [77.15106201, 8.33094025], [77.15318298, 8.32566071], [77.15966797, 8.31738091], [77.15965271, 8.31250095], [77.15483093, 8.31361103], [77.15210724, 8.31946182], [77.14977264, 8.32194233], [77.14470673, 8.32022953], [77.13703156, 8.32009125], [77.13062286, 8.32423019], [77.12194824, 8.32294178], [77.11152649, 8.31649017], [77.10883331, 8.31287956], [77.10085297, 8.31165123], [77.1046524, 8.30160046], [77.09822083, 8.30150032], [77.09648895, 8.29806995], [77.09069824, 8.29747009], [77.09069824, 8.29763889], [77.09041595, 8.29763889], [77.09041595, 8.29791927], [77.08985901, 8.29791737], [77.08985901, 8.29819489], [77.08930206, 8.29819489], [77.08930206, 8.29847336], [77.08847046, 8.29847145], [77.08847046, 8.29875088], [77.0881958, 8.29875088], [77.0881958, 8.29930973], [77.08763885, 8.29930496], [77.08763885, 8.29958344], [77.08708191, 8.29958344], [77.08708191, 8.29986095], [77.08680725, 8.29986095], [77.08680725, 8.30013943], [77.08651733, 8.30013943], [77.08651733, 8.30041981], [77.08569336, 8.30041695], [77.08569336, 8.30069542], [77.0854187, 8.30069542], [77.0854187, 8.30125237], [77.08513641, 8.30125237], [77.08513641, 8.30153179], [77.0854187, 8.30152702], [77.0854187, 8.30236053], [77.08513641, 8.30236053], [77.08513641, 8.30319309], [77.08569336, 8.30319309], [77.08569336, 8.30291843], [77.08652496, 8.30291843], [77.08652496, 8.30319309], [77.08625031, 8.30319309], [77.08625031, 8.30347061], [77.08598328, 8.30347061], [77.08598328, 8.30403042], [77.08569336, 8.30403042], [77.08569336, 8.30430984], [77.08513641, 8.30430603], [77.08513641, 8.30458355], [77.0845871, 8.30458355], [77.0845871, 8.30486202], [77.08403015, 8.30486202], [77.08403015, 8.30513954], [77.08348083, 8.30513954], [77.08348083, 8.30541992], [77.08319092, 8.30541801], [77.08319092, 8.30569363], [77.0826416, 8.30569363], [77.0826416, 8.3059721], [77.08235931, 8.30596924], [77.08235931, 8.30624962], [77.08180237, 8.30624962], [77.08180237, 8.30681038], [77.08152771, 8.30680561], [77.08152771, 8.3073597], [77.08125305, 8.3073597], [77.08125305, 8.30764008], [77.08071136, 8.30764008], [77.08071136, 8.30792046], [77.08041382, 8.30791569], [77.08041382, 8.30819416], [77.08013916, 8.30819416], [77.08013916, 8.30847168], [77.07958221, 8.30847168], [77.07958221, 8.30875015], [77.07930756, 8.30875015], [77.07930756, 8.30902958], [77.07847595, 8.30902958], [77.07847595, 8.30846024], [77.07791901, 8.30847168], [77.07791901, 8.30875015], [77.07707977, 8.30875015], [77.07707977, 8.30847168], [77.07680511, 8.30847168], [77.07680511, 8.30875015], [77.07653046, 8.30875015], [77.07653046, 8.30902958], [77.07624817, 8.30902958], [77.07624817, 8.30931091], [77.07597351, 8.30930614], [77.07597351, 8.30958366], [77.07569122, 8.30958366], [77.07569122, 8.30986214], [77.07541656, 8.30986023], [77.07541656, 8.31013966], [77.07514191, 8.31013966], [77.07514191, 8.31042004], [77.07458496, 8.31041622], [77.07458496, 8.31069374], [77.07402802, 8.31069374], [77.07402802, 8.31097221], [77.07375336, 8.31097031], [77.07375336, 8.31124973], [77.07319641, 8.31124973], [77.07319641, 8.31152821], [77.07290649, 8.31152058], [77.07290649, 8.31181145], [77.07236481, 8.31180573], [77.07236481, 8.3120842], [77.07208252, 8.31208038], [77.07208252, 8.31236172], [77.07154083, 8.31236172], [77.07154083, 8.31264019], [77.07125092, 8.31264019], [77.07125092, 8.31292057], [77.07069397, 8.3129158], [77.07069397, 8.31319427], [77.07041931, 8.31319427], [77.07041931, 8.31347179], [77.06986237, 8.31347179], [77.06986237, 8.31375027], [77.06958008, 8.31375027], [77.06958008, 8.31403065], [77.06903076, 8.31403065], [77.06903076, 8.31431103], [77.06874847, 8.31431103], [77.06874847, 8.31459141], [77.06819153, 8.31458378], [77.06819153, 8.31486034], [77.06791687, 8.31486034], [77.06791687, 8.31514072], [77.06764221, 8.31514072], [77.06764221, 8.3154211], [77.06735992, 8.31541634], [77.06735992, 8.31569386], [77.06708527, 8.31569386], [77.06708527, 8.31597233], [77.06680298, 8.31597042], [77.06680298, 8.31653118], [77.06652832, 8.31653118], [77.06652832, 8.31681061], [77.06625366, 8.31680679], [77.06625366, 8.31708241], [77.06597137, 8.31708241], [77.06597137, 8.31735992], [77.06542206, 8.31735992], [77.06542206, 8.31764984], [77.06513977, 8.31764984], [77.06513977, 8.31792068], [77.06485748, 8.31791687], [77.06485748, 8.31819534], [77.06458282, 8.31819534], [77.06458282, 8.31847286], [77.06402588, 8.31847286], [77.06402588, 8.31875134], [77.06318665, 8.31875134], [77.06318665, 8.31902885], [77.06181335, 8.31902885], [77.06181335, 8.31930923], [77.06153107, 8.31930542], [77.06153107, 8.31986141], [77.06124878, 8.31986141], [77.06124878, 8.32042122], [77.06069183, 8.3204174], [77.06069183, 8.3209734], [77.06041718, 8.32097054], [77.06041718, 8.32125092], [77.05960083, 8.32125092], [77.05960083, 8.3215313], [77.05902863, 8.3215313], [77.05902863, 8.32181168], [77.05874634, 8.32180691], [77.05874634, 8.32208347], [77.05847168, 8.32208347], [77.05847168, 8.32236099], [77.0579071, 8.32236099], [77.0579071, 8.32291889], [77.05735779, 8.32291698], [77.05735779, 8.32347298], [77.05708313, 8.32346153], [77.05708313, 8.32374859], [77.05680847, 8.32375145], [77.05680847, 8.32403088], [77.05654144, 8.32403088], [77.05654144, 8.3243103], [77.05625153, 8.32430458], [77.05625153, 8.32458305], [77.05569458, 8.32458305], [77.05569458, 8.32486057], [77.05541992, 8.32486057], [77.05541992, 8.32514095], [77.05513763, 8.32513905], [77.05513763, 8.32569313], [77.05458069, 8.32569313], [77.05458069, 8.32597256], [77.05403137, 8.32597065], [77.05403137, 8.32652855], [77.05348206, 8.32652855], [77.05348206, 8.32682133], [77.05291748, 8.32680511], [77.05291748, 8.32708263], [77.05263519, 8.32708263], [77.05263519, 8.32736111], [77.05208588, 8.3273592], [77.05208588, 8.32764244], [77.05152893, 8.32763863], [77.05152893, 8.32819462], [77.05124664, 8.32819462], [77.05124664, 8.32847118], [77.05097198, 8.32847118], [77.05097198, 8.32903194], [77.05040741, 8.32903194], [77.05040741, 8.32931042], [77.05014038, 8.32931042], [77.05014038, 8.32958984], [77.04957581, 8.32958984], [77.04957581, 8.33014202], [77.04930878, 8.33014202], [77.04930878, 8.33041954], [77.04902649, 8.33041763], [77.04902649, 8.33069324], [77.04875183, 8.33069324], [77.04875183, 8.33097363], [77.04846954, 8.33097363], [77.04846954, 8.33125019], [77.04818726, 8.33125019], [77.04818726, 8.33181], [77.04792023, 8.33180618], [77.04792023, 8.3320837], [77.04763794, 8.3320837], [77.04763794, 8.33263969], [77.04736328, 8.33263969], [77.04736328, 8.33319378], [77.04708099, 8.33319092], [77.04708099, 8.33374977], [77.0459671, 8.33374977], [77.0459671, 8.33403015], [77.04541779, 8.33403015], [77.04541779, 8.33430958], [77.0451355, 8.33430576], [77.0451355, 8.33458424], [77.04486084, 8.33458424], [77.04486084, 8.33485985], [77.04431152, 8.33485985], [77.04431152, 8.33514023], [77.04402924, 8.33514023], [77.04402924, 8.33541965], [77.04374695, 8.33541584], [77.04374695, 8.33569431], [77.04347229, 8.33569431], [77.04347229, 8.33597183], [77.04291534, 8.33597183], [77.04291534, 8.33625031], [77.0423584, 8.33625031], [77.0423584, 8.33652973], [77.04207611, 8.33652973], [77.04207611, 8.33681107], [77.04152679, 8.3368063], [77.04152679, 8.33736229], [77.04125214, 8.33736038], [77.04125214, 8.33764172], [77.04070282, 8.33764172], [77.04070282, 8.33792114], [77.0395813, 8.33791637], [77.0395813, 8.33819389], [77.03930664, 8.33819199], [77.03930664, 8.33875942], [77.03901672, 8.33875942], [77.03901672, 8.33903027], [77.03874969, 8.33903027], [77.03874969, 8.33931065], [77.03847504, 8.33930588], [77.03847504, 8.33958435], [77.03817749, 8.33957958], [77.03819275, 8.33985996], [77.03791809, 8.33985996], [77.03791809, 8.34042072], [77.0376358, 8.34041595], [77.0376358, 8.34069443], [77.03708649, 8.34069443], [77.03708649, 8.34097195], [77.03679657, 8.34097004], [77.0368042, 8.34125042], [77.03624725, 8.34125042], [77.03624725, 8.3415308], [77.0359726, 8.3415308], [77.0359726, 8.34181976], [77.03569794, 8.34180641], [77.03569794, 8.34208202], [77.03514099, 8.34208202], [77.03514099, 8.34236336], [77.0348587, 8.34235954], [77.0348587, 8.34264088], [77.03457642, 8.34264088], [77.03457642, 8.34292126], [77.0340271, 8.34291553], [77.0340271, 8.34319401], [77.03375244, 8.34319019], [77.03375244, 8.34375095], [77.03347015, 8.34375095], [77.03347015, 8.34403133], [77.03291321, 8.34403133], [77.03291321, 8.34430885], [77.03263855, 8.34430695], [77.03263855, 8.3445816], [77.0320816, 8.3445816], [77.0320816, 8.34486103], [77.03180695, 8.34486103], [77.03180695, 8.34514141], [77.03151703, 8.34514141], [77.03151703, 8.34542084], [77.03125, 8.34541702], [77.03125, 8.34569454], [77.03097534, 8.34569454], [77.03097534, 8.34597301], [77.03069305, 8.34597015], [77.03069305, 8.34625053], [77.0304184, 8.34625053], [77.0304184, 8.34653091], [77.02986145, 8.34653091], [77.02986145, 8.34681129], [77.02958679, 8.34680462], [77.02958679, 8.34708309], [77.0293045, 8.34708309], [77.0293045, 8.34763908], [77.02902985, 8.34762955], [77.02902985, 8.34792137], [77.02874756, 8.3479166], [77.02874756, 8.34819508], [77.02819824, 8.34819508], [77.02819824, 8.3484726], [77.02791595, 8.34847069], [77.02791595, 8.34875107], [77.0276413, 8.34875107], [77.0276413, 8.34903145], [77.02680206, 8.34903145], [77.02680206, 8.34931183], [77.02625275, 8.34930515], [77.02625275, 8.34958267], [77.02597046, 8.34958267], [77.02597046, 8.34986115], [77.0256958, 8.34986115], [77.0256958, 8.35014057], [77.02513885, 8.35014057], [77.02513885, 8.35042191], [77.02458191, 8.35042191], [77.02458191, 8.35070038], [77.02430725, 8.35069466], [77.02430725, 8.35097313], [77.02375031, 8.35097122], [77.02375031, 8.35125065], [77.02346802, 8.35125065], [77.02346802, 8.35153198], [77.0229187, 8.35153198], [77.0229187, 8.35181046], [77.02263641, 8.35180473], [77.02263641, 8.35208321], [77.0220871, 8.35208321], [77.0220871, 8.35236073], [77.02179718, 8.35236073], [77.02179718, 8.3526392], [77.02124786, 8.3526392], [77.02124786, 8.35291958], [77.02097321, 8.35291672], [77.02097321, 8.35319519], [77.02041626, 8.35319519], [77.02041626, 8.3534708], [77.0201416, 8.35346889], [77.0201416, 8.35376072], [77.01930237, 8.35376072], [77.01930237, 8.3540287], [77.01902771, 8.3540287], [77.01902771, 8.35431194], [77.01875305, 8.35430527], [77.01875305, 8.35486126], [77.01847076, 8.35486126], [77.01847076, 8.35514164], [77.01819611, 8.35514164], [77.01819611, 8.35542202], [77.01791382, 8.35541534], [77.01791382, 8.35597134], [77.01708221, 8.35597134], [77.01708221, 8.35624886], [77.01625061, 8.35624886], [77.01625061, 8.35653019], [77.01513672, 8.35653019], [77.01513672, 8.35624886], [77.01430511, 8.35624886], [77.01430511, 8.35569572], [77.01319122, 8.35569572], [77.01319122, 8.35597134], [77.01235962, 8.35597134], [77.01235962, 8.35624886], [77.00985718, 8.35624886], [77.00985718, 8.35653019], [77.00958252, 8.35652733], [77.00958252, 8.35680485], [77.00930786, 8.35680485], [77.00930786, 8.35708427], [77.00875092, 8.35708427], [77.00875092, 8.35736179], [77.00846863, 8.35736179], [77.00846863, 8.35931015], [77.0082016, 8.35931015], [77.0082016, 8.36013985], [77.00791931, 8.36013985], [77.00791931, 8.3615303], [77.00763702, 8.3615284], [77.00763702, 8.36208439], [77.00736237, 8.36208153], [77.00736237, 8.36264038], [77.00708008, 8.36263847], [77.00708008, 8.36319447], [77.00680542, 8.36319447], [77.00680542, 8.36347198], [77.00624847, 8.36347198], [77.00624847, 8.36375046], [77.00596619, 8.36375046], [77.00596619, 8.36403275], [77.00543213, 8.36403275], [77.00543213, 8.36431122], [77.00514221, 8.36430645], [77.00514221, 8.36458206], [77.00458527, 8.36458206], [77.00458527, 8.36486244], [77.00430298, 8.36485958], [77.00430298, 8.36513996], [77.00347137, 8.36513996], [77.00347137, 8.36570072], [77.00319672, 8.36569405], [77.00319672, 8.36874962], [77.0029068, 8.36874104], [77.0029068, 8.36931133], [77.00263977, 8.36930656], [77.00263977, 8.3698597], [77.00235748, 8.3698597], [77.00235748, 8.37042141], [77.00208282, 8.37041569], [77.00208282, 8.37097263], [77.00180817, 8.37097263], [77.00180817, 8.37125111], [77.00125122, 8.37125111], [77.00125122, 8.37153053], [77.00013733, 8.37153053], [76.99986267, 8.37152863], [76.99986267, 8.37180424], [76.99930573, 8.37180424], [76.99930573, 8.37236118], [76.99903107, 8.37236118], [76.99903107, 8.37292099], [76.99874878, 8.37291718], [76.99874878, 8.37347317], [76.99846649, 8.37347126], [76.99846649, 8.37375069], [76.99819183, 8.37375069], [76.99819183, 8.37403107], [76.99764252, 8.37403107], [76.99764252, 8.3743124], [76.99736023, 8.37430477], [76.99736023, 8.37458324], [76.99708557, 8.37458324], [76.99708557, 8.37486076], [76.99652863, 8.37485886], [76.99652863, 8.37514114], [76.9962616, 8.37514114], [76.9962616, 8.37542057], [76.99569702, 8.37541676], [76.99569702, 8.37597084], [76.9954071, 8.37597084], [76.99541473, 8.37625122], [76.99375153, 8.37625122], [76.99375153, 8.37653065], [76.99320221, 8.37653065], [76.99320221, 8.37625122], [76.99263763, 8.37625122], [76.99263763, 8.37569523], [76.99208069, 8.37569523], [76.99208069, 8.37513924], [76.99153137, 8.37513924], [76.99153137, 8.37569523], [76.99097443, 8.37569523], [76.99097443, 8.37597084], [76.99069214, 8.37597084], [76.99069214, 8.37681198], [76.99041748, 8.37680531], [76.99041748, 8.37708282], [76.99013519, 8.37708282], [76.99013519, 8.3773613], [76.98874664, 8.3773613], [76.98874664, 8.37708282], [76.98847198, 8.37708282], [76.98847198, 8.37597084], [76.98874664, 8.37597084], [76.98874664, 8.37541676], [76.98902893, 8.37542057], [76.98902893, 8.37485886], [76.98930359, 8.37486076], [76.98930359, 8.37458324], [76.98958588, 8.37458324], [76.98958588, 8.37430477], [76.98986053, 8.3743124], [76.98986053, 8.37403107], [76.99012756, 8.37403107], [76.99012756, 8.37292099], [76.98958588, 8.37291718], [76.98958588, 8.37319469], [76.98929596, 8.37318993], [76.98929596, 8.37375069], [76.98902893, 8.37375069], [76.98902893, 8.37403107], [76.98874664, 8.37403107], [76.98874664, 8.3743124], [76.98819733, 8.37430477], [76.98819733, 8.37458324], [76.98791504, 8.37458324], [76.98791504, 8.37486076], [76.98764038, 8.37485886], [76.98764038, 8.37514114], [76.98680878, 8.37514114], [76.98680878, 8.37542057], [76.98625183, 8.37541676], [76.98625183, 8.37569523], [76.98596954, 8.37569523], [76.98596954, 8.37597084], [76.98542023, 8.37597084], [76.98542023, 8.37625122], [76.98486328, 8.37625122], [76.98486328, 8.37708282], [76.98458099, 8.37708092], [76.98458099, 8.37793064], [76.98430634, 8.37791729], [76.98432159, 8.37874889], [76.98400879, 8.37874889], [76.98400879, 8.37930965], [76.98347473, 8.37930489], [76.98347473, 8.37958336], [76.98291779, 8.37958336], [76.98291779, 8.37986088], [76.98264313, 8.37986088], [76.98264313, 8.38013935], [76.98236084, 8.38013935], [76.98236084, 8.37986088], [76.98208618, 8.37986088], [76.98208618, 8.38041973], [76.98152924, 8.38041687], [76.98152924, 8.38069534], [76.98124695, 8.38069534], [76.98124695, 8.38097095], [76.98041534, 8.38097095], [76.98041534, 8.38125134], [76.98014069, 8.38125134], [76.98014069, 8.38152981], [76.97875214, 8.38152695], [76.97875214, 8.38236141], [76.97846985, 8.38236141], [76.97846985, 8.38403034], [76.97818756, 8.38403034], [76.97819519, 8.38486195], [76.97763824, 8.38486195], [76.97763824, 8.38513088], [76.97680664, 8.38514042], [76.97680664, 8.38486195], [76.97569275, 8.38486195], [76.97569275, 8.38458443], [76.97541809, 8.38458061], [76.97541809, 8.38514042], [76.97486115, 8.38514042], [76.97486115, 8.38624954], [76.9751358, 8.38624954], [76.9751358, 8.38708401], [76.97541809, 8.38707924], [76.97541809, 8.38764], [76.97569275, 8.38764], [76.97569275, 8.38792038], [76.97541809, 8.38792038], [76.97541809, 8.38875198], [76.97512817, 8.38875198], [76.97512817, 8.38903046], [76.97429657, 8.38903046], [76.97429657, 8.38931274], [76.97402954, 8.38930607], [76.97402954, 8.38958359], [76.97264099, 8.38958168], [76.97264099, 8.38987064], [76.97206879, 8.38987064], [76.97206879, 8.39041996], [76.97180939, 8.39041996], [76.97180176, 8.39124966], [76.9715271, 8.39124966], [76.9715271, 8.39208412], [76.97097015, 8.39208031], [76.97097015, 8.39264011], [76.97041321, 8.39263821], [76.97041321, 8.3931942], [76.97013855, 8.3931942], [76.97013855, 8.39347172], [76.96985626, 8.39347172], [76.96985626, 8.39403057], [76.9695816, 8.39403057], [76.9695816, 8.39431095], [76.96986389, 8.39430618], [76.96986389, 8.3945837], [76.97041321, 8.3945837], [76.97041321, 8.39486027], [76.97070313, 8.39486027], [76.97070313, 8.39514065], [76.9715271, 8.39513779], [76.9715271, 8.39569378], [76.97180176, 8.39569378], [76.97180939, 8.39597225], [76.97292328, 8.39597034], [76.97292328, 8.39624977], [76.97319794, 8.39624977], [76.97319794, 8.39708233], [76.97292328, 8.39708042], [76.97292328, 8.39764118], [76.97264099, 8.39764118], [76.97264099, 8.39792061], [76.9723587, 8.39791679], [76.9723587, 8.39819527], [76.97206879, 8.39818954], [76.97206879, 8.39903069], [76.97180939, 8.39903069], [76.97180939, 8.39931107], [76.97208405, 8.39930534], [76.97208405, 8.39958286], [76.9715271, 8.39958], [76.9715271, 8.40042114], [76.97125244, 8.40042114], [76.97125244, 8.4018116], [76.97097015, 8.4018116], [76.97097015, 8.4026413], [76.9706955, 8.40263939], [76.9706955, 8.4034729], [76.97041321, 8.4034729], [76.97041321, 8.40375137], [76.97013855, 8.40375137], [76.97013855, 8.40430927], [76.96985626, 8.40430927], [76.96985626, 8.40487003], [76.9695816, 8.40486145], [76.9695816, 8.40597343], [76.9693222, 8.40597057], [76.9693222, 8.40652943], [76.96903229, 8.40652943], [76.96903229, 8.40681171], [76.96875, 8.40681171], [76.96875, 8.40764236], [76.96847534, 8.40763855], [76.96847534, 8.40819454], [76.96819305, 8.40819454], [76.96819305, 8.40847111], [76.9679184, 8.40847111], [76.9679184, 8.40931034], [76.96763611, 8.40930462], [76.96763611, 8.40958309], [76.96736145, 8.40958309], [76.96736145, 8.40986061], [76.96708679, 8.40986061], [76.96708679, 8.41014194], [76.9668045, 8.41014004], [76.9668045, 8.41069317], [76.96624756, 8.41069126], [76.96624756, 8.41125202], [76.96569824, 8.41125202], [76.96569824, 8.41180992], [76.96541595, 8.41180611], [76.96541595, 8.4123621], [76.9651413, 8.4123621], [76.9651413, 8.4131937], [76.96485901, 8.41319084], [76.96485901, 8.41431046], [76.96430206, 8.41430569], [76.96430206, 8.41485977], [76.96375275, 8.41485977], [76.96375275, 8.41569424], [76.96347046, 8.41569138], [76.96347046, 8.41652966], [76.9631958, 8.41652775], [76.9631958, 8.41736221], [76.96263885, 8.41736031], [76.96263885, 8.41763973], [76.9623642, 8.41763783], [76.9623642, 8.41847229], [76.96180725, 8.41847038], [76.96180725, 8.41903019], [76.96152496, 8.41902828], [76.96152496, 8.41958427], [76.96097565, 8.41958427], [76.96097565, 8.41985989], [76.96069336, 8.4198513], [76.96069336, 8.42042065], [76.9604187, 8.42041588], [76.9604187, 8.42069435], [76.96012878, 8.42068958], [76.96013641, 8.42125034], [76.95986176, 8.42125034], [76.95986176, 8.4218111], [76.95930481, 8.42180634], [76.95930481, 8.42208195], [76.95903015, 8.42208004], [76.95903015, 8.4226408], [76.95874786, 8.42263794], [76.95874786, 8.42291641], [76.95847321, 8.42291641], [76.95847321, 8.42319393], [76.95791626, 8.42319393], [76.95791626, 8.4234724], [76.95735931, 8.42346954], [76.95735931, 8.42375088], [76.95709229, 8.42375088], [76.95709229, 8.42403126], [76.95680237, 8.42403126], [76.95680237, 8.42431068], [76.95652771, 8.42430687], [76.95652771, 8.42458153], [76.95625305, 8.42457962], [76.95625305, 8.42514133], [76.95597076, 8.42514133], [76.95597076, 8.42541885], [76.95569611, 8.42541885], [76.95569611, 8.42597961], [76.95540619, 8.42597961], [76.95541382, 8.42625141], [76.95513916, 8.42625141], [76.95513916, 8.42653084], [76.9548645, 8.42652893], [76.9548645, 8.42708302], [76.95458221, 8.42708302], [76.95458221, 8.42736053], [76.95430756, 8.42736053], [76.95430756, 8.4279213], [76.95402527, 8.42791653], [76.95402527, 8.428195], [76.95375061, 8.42819023], [76.95375061, 8.42875099], [76.95347595, 8.42875099], [76.95347595, 8.42903996], [76.95318604, 8.42903996], [76.95318604, 8.42930889], [76.95291901, 8.42930698], [76.95291901, 8.4295826], [76.95263672, 8.42958069], [76.95263672, 8.43014145], [76.95236206, 8.43014145], [76.95236206, 8.43042183], [76.95207977, 8.43042183], [76.95207977, 8.43181038], [76.95153046, 8.43180466], [76.95153046, 8.43208313], [76.95124817, 8.43208122], [76.95124817, 8.43264103], [76.95095825, 8.43264103], [76.95095825, 8.43291855], [76.95041656, 8.43291664], [76.95041656, 8.43347263], [76.94957733, 8.43347073], [76.94958496, 8.4337492], [76.94930267, 8.4337492], [76.94930267, 8.43431187], [76.94902802, 8.43430519], [76.94902802, 8.43458271], [76.94875336, 8.43458271], [76.94875336, 8.43486118], [76.94847107, 8.43484974], [76.94847107, 8.43514156], [76.94819641, 8.4351387], [76.94819641, 8.43569469], [76.94791412, 8.43569469], [76.94791412, 8.43597126], [76.94763947, 8.43597126], [76.94763947, 8.43625164], [76.94708252, 8.43625164], [76.94708252, 8.43680954], [76.94680786, 8.43680477], [76.94680786, 8.43736172], [76.94625092, 8.43735886], [76.94625092, 8.43764019], [76.94596863, 8.43764019], [76.94596863, 8.43791962], [76.94568634, 8.43791962], [76.94568634, 8.43902969], [76.94541931, 8.43902779], [76.94541931, 8.43958378], [76.94513702, 8.43958378], [76.94513702, 8.43986225], [76.94458008, 8.43985939], [76.94458008, 8.44013977], [76.94431305, 8.44013977], [76.94431305, 8.44042015], [76.94403076, 8.44041634], [76.94403076, 8.44124985], [76.94374847, 8.44124985], [76.94374847, 8.44153023], [76.94347382, 8.44152832], [76.94347382, 8.44208431], [76.94319153, 8.44208431], [76.94319153, 8.44236183], [76.94291687, 8.44236183], [76.94291687, 8.4426403], [76.94264221, 8.4426403], [76.94264221, 8.44291973], [76.94235992, 8.44291592], [76.94235992, 8.44319439], [76.94208527, 8.44319439], [76.94208527, 8.44347191], [76.94180298, 8.44347191], [76.94180298, 8.44375038], [76.94152832, 8.44375038], [76.94152832, 8.44431114], [76.94097137, 8.44430637], [76.94097137, 8.44458199], [76.94069672, 8.44458199], [76.94069672, 8.44486237], [76.9404068, 8.44486046], [76.9404068, 8.44514179], [76.94013977, 8.44513798], [76.94013977, 8.4456892], [76.93985748, 8.44570065], [76.93985748, 8.44624996], [76.93930817, 8.44624996], [76.93930817, 8.44653034], [76.93902588, 8.44652843], [76.93902588, 8.44708443], [76.93875122, 8.44708443], [76.93875122, 8.44736004], [76.93846893, 8.44736004], [76.93846893, 8.44764042], [76.93819427, 8.44763756], [76.93819427, 8.44847202], [76.93791962, 8.44847012], [76.93791962, 8.44903088], [76.93763733, 8.44903088], [76.93763733, 8.44931126], [76.93736267, 8.44930553], [76.93736267, 8.4495821], [76.93708038, 8.4495821], [76.93708038, 8.44986343], [76.93681335, 8.44985962], [76.93681335, 8.45014954], [76.93653107, 8.45014954], [76.93653107, 8.45042133], [76.93624878, 8.45041561], [76.93624878, 8.45069408], [76.93595886, 8.45069027], [76.93595886, 8.45125103], [76.93569183, 8.45125103], [76.93569183, 8.45153141], [76.93514252, 8.45153141], [76.93514252, 8.45181084], [76.93486023, 8.45180416], [76.93486023, 8.45208168], [76.9345932, 8.45207977], [76.9345932, 8.45264053], [76.93430328, 8.45264053], [76.93430328, 8.45292091], [76.93402863, 8.4529171], [76.93402863, 8.45319462], [76.93374634, 8.45318985], [76.93374634, 8.45375061], [76.93321228, 8.45375061], [76.93321228, 8.45403099], [76.93291473, 8.45402908], [76.93291473, 8.45458317], [76.93264008, 8.45458317], [76.93264008, 8.45486069], [76.93235779, 8.45486069], [76.93235779, 8.45514107], [76.93180847, 8.45514107], [76.93180847, 8.45542145], [76.93152618, 8.45541668], [76.93152618, 8.45597267], [76.93125153, 8.45597267], [76.93125153, 8.45625114], [76.93096924, 8.45625114], [76.93096924, 8.4568119], [76.93041992, 8.45680523], [76.93041992, 8.45736122], [76.93015289, 8.45736122], [76.93015289, 8.45792198], [76.92986298, 8.45791721], [76.92986298, 8.45819473], [76.92930603, 8.45819092], [76.92930603, 8.45875072], [76.92874908, 8.45875072], [76.92874908, 8.45930958], [76.92847443, 8.45930481], [76.92847443, 8.45958328], [76.92819214, 8.45958328], [76.92819214, 8.4598608], [76.92791748, 8.45985889], [76.92791748, 8.46041965], [76.92763519, 8.46041679], [76.92763519, 8.46069527], [76.92736053, 8.46069527], [76.92736053, 8.46125126], [76.92707825, 8.46125126], [76.92707825, 8.46153164], [76.92652893, 8.46153164], [76.92652893, 8.46181202], [76.92624664, 8.46180534], [76.92624664, 8.46236134], [76.92569733, 8.46236134], [76.92569733, 8.46263885], [76.92541504, 8.46263885], [76.92541504, 8.4631958], [76.92514038, 8.46319103], [76.92514038, 8.46430969], [76.92458344, 8.46430492], [76.92458344, 8.46458435], [76.92318726, 8.46458054], [76.92318726, 8.46515083], [76.92292023, 8.46514034], [76.92292023, 8.46569347], [76.92263794, 8.46569347], [76.92263794, 8.46597195], [76.92236328, 8.46597195], [76.92236328, 8.46652985], [76.92208099, 8.46652985], [76.92208099, 8.46681023], [76.92180634, 8.46680641], [76.92180634, 8.4673624], [76.92151642, 8.46735954], [76.92151642, 8.46763992], [76.92124939, 8.46763992], [76.92124939, 8.4679203], [76.92069244, 8.46791553], [76.92069244, 8.46819401], [76.92041779, 8.46818924], [76.92041779, 8.46875191], [76.92014313, 8.46875191], [76.92014313, 8.46931267], [76.91986084, 8.46930599], [76.91986084, 8.46958447], [76.91929626, 8.4695816], [76.91929626, 8.47014046], [76.91902924, 8.47014046], [76.91902924, 8.47042274], [76.91874695, 8.47041798], [76.91874695, 8.47069359], [76.91847229, 8.47069168], [76.91847229, 8.47124958], [76.91821289, 8.47124958], [76.91821289, 8.47152996], [76.91792297, 8.47152996], [76.91792297, 8.47181129], [76.9173584, 8.47180557], [76.9173584, 8.47208405], [76.91708374, 8.47208405], [76.91708374, 8.47236156], [76.91680908, 8.47235966], [76.91680908, 8.47264004], [76.91652679, 8.47263813], [76.91652679, 8.47319412], [76.91625214, 8.47319412], [76.91625214, 8.47347164], [76.91570282, 8.47346973], [76.91570282, 8.47403145], [76.9154129, 8.47402763], [76.9154129, 8.47458363], [76.91513824, 8.47458172], [76.91513824, 8.47513962], [76.91486359, 8.47513771], [76.91486359, 8.4756937], [76.91430664, 8.4756937], [76.91430664, 8.47597218], [76.91401672, 8.47597027], [76.91401672, 8.47624969], [76.91348267, 8.47624969], [76.91348267, 8.47653103], [76.91319275, 8.47653103], [76.91319275, 8.47681141], [76.91291809, 8.47681141], [76.91291809, 8.47709084], [76.9126358, 8.47709084], [76.9126358, 8.47764111], [76.91236115, 8.47764111], [76.91236115, 8.47792053], [76.91207886, 8.47792053], [76.91207886, 8.47875118], [76.91178894, 8.47875118], [76.91178894, 8.47931099], [76.91152954, 8.47930431], [76.91152954, 8.47958469], [76.91124725, 8.47958469], [76.91124725, 8.48013878], [76.91069794, 8.48012924], [76.91069794, 8.48042107], [76.91041565, 8.48041725], [76.91041565, 8.48069477], [76.91014099, 8.48069477], [76.91014099, 8.48097324], [76.90957642, 8.48097038], [76.90957642, 8.48153114], [76.90930939, 8.48153114], [76.90930176, 8.48181152], [76.90875244, 8.48180485], [76.90875244, 8.48208332], [76.90847015, 8.48208046], [76.90847015, 8.48264122], [76.90820313, 8.48264122], [76.90820313, 8.48292065], [76.90791321, 8.48291683], [76.90791321, 8.4831953], [76.90763855, 8.4831953], [76.90763855, 8.48347282], [76.90735626, 8.48347092], [76.90736389, 8.4837513], [76.9070816, 8.4837513], [76.9070816, 8.48403072], [76.90680695, 8.48403072], [76.90680695, 8.4843092], [76.90652466, 8.48430538], [76.90652466, 8.48486137], [76.90625, 8.48486137], [76.90625, 8.48513889], [76.90598297, 8.48513889], [76.90598297, 8.48541927], [76.9054184, 8.48541737], [76.9054184, 8.48597336], [76.90513611, 8.48597145], [76.90513611, 8.48625088], [76.90458679, 8.48625088], [76.90458679, 8.48680973], [76.9043045, 8.48680496], [76.9043045, 8.48708344], [76.90402985, 8.48708057], [76.90402985, 8.48763943], [76.90374756, 8.48763943], [76.90374756, 8.48792171], [76.90319824, 8.48791695], [76.90319824, 8.48847103], [76.90290833, 8.48847103], [76.90290833, 8.48903179], [76.90235901, 8.48902702], [76.90235901, 8.48958302], [76.90180206, 8.48958111], [76.90180206, 8.49014187], [76.9015274, 8.49013901], [76.9015274, 8.49069309], [76.90125275, 8.49069309], [76.90125275, 8.49097443], [76.9006958, 8.49097061], [76.9006958, 8.49153042], [76.90040588, 8.49153042], [76.90040588, 8.49180984], [76.8998642, 8.49180603], [76.8998642, 8.49208355], [76.89958191, 8.4920702], [76.89958191, 8.49291992], [76.89930725, 8.49291801], [76.89930725, 8.49319363], [76.89902496, 8.49319363], [76.89902496, 8.4934721], [76.89848328, 8.49346924], [76.89848328, 8.49374962], [76.89819336, 8.49374962], [76.89819336, 8.49403], [76.8979187, 8.49402809], [76.8979187, 8.49458408], [76.89763641, 8.49458408], [76.89763641, 8.49514008], [76.89736176, 8.49513054], [76.89736176, 8.49542046], [76.8970871, 8.49541569], [76.8970871, 8.49569416], [76.89680481, 8.49569416], [76.89680481, 8.49597168], [76.89653015, 8.49597168], [76.89653015, 8.49625015], [76.89624786, 8.49625015], [76.89624786, 8.49680996], [76.89569092, 8.49680614], [76.89569092, 8.49708366], [76.89541626, 8.49708366], [76.89541626, 8.49736214], [76.8951416, 8.49736023], [76.8951416, 8.49763966], [76.89485931, 8.49763775], [76.89485931, 8.49819374], [76.89458466, 8.49819374], [76.89458466, 8.49847221], [76.89430237, 8.49847031], [76.89430237, 8.49903011], [76.89404297, 8.49903011], [76.89404297, 8.49931145], [76.89375305, 8.49930573], [76.89375305, 8.4995842], [76.89319611, 8.49958038], [76.89319611, 8.49986172], [76.89290619, 8.49986172], [76.89290619, 8.50042057], [76.89263916, 8.5004158], [76.89263916, 8.50069427], [76.89235687, 8.50069046], [76.89235687, 8.50126171], [76.89208221, 8.50126171], [76.89208221, 8.50153065], [76.89180756, 8.50153065], [76.89180756, 8.50181103], [76.89152527, 8.50180626], [76.89152527, 8.50208378], [76.89125061, 8.50208378], [76.89125061, 8.50236034], [76.89096832, 8.50236034], [76.89096832, 8.50264072], [76.89041901, 8.50263786], [76.89041901, 8.50319386], [76.89013672, 8.50319386], [76.89013672, 8.50374985], [76.88986206, 8.50374985], [76.88986206, 8.50403118], [76.88957977, 8.50403118], [76.88957977, 8.50432014], [76.88930511, 8.50430679], [76.88930511, 8.50458241], [76.88903046, 8.50457954], [76.88903046, 8.50542068], [76.88874817, 8.50541687], [76.88874817, 8.50569534], [76.88847351, 8.50569534], [76.88847351, 8.50597286], [76.88819122, 8.50597286], [76.88819122, 8.50625134], [76.88790894, 8.50625134], [76.88790894, 8.50680923], [76.88735962, 8.50680542], [76.88735962, 8.50708294], [76.88708496, 8.50708294], [76.88708496, 8.50736141], [76.88680267, 8.50736141], [76.88680267, 8.50792122], [76.88652802, 8.5079174], [76.88652802, 8.50819492], [76.88625336, 8.50819492], [76.88625336, 8.5084734], [76.88597107, 8.50847054], [76.88597107, 8.50875092], [76.88569641, 8.50875092], [76.88569641, 8.5090313], [76.88541412, 8.50902653], [76.88541412, 8.50958347], [76.88513947, 8.50958347], [76.88513947, 8.50986099], [76.88487244, 8.50986099], [76.88487244, 8.51041889], [76.88458252, 8.51041698], [76.88458252, 8.51097298], [76.88430786, 8.51097298], [76.88430786, 8.51124859], [76.8840332, 8.51125145], [76.8840332, 8.51153088], [76.88375092, 8.51153088], [76.88375092, 8.51180935], [76.88346863, 8.51180458], [76.88346863, 8.51208305], [76.88318634, 8.51208115], [76.88318634, 8.51264095], [76.88291931, 8.51264095], [76.88291931, 8.51291943], [76.88263702, 8.51291943], [76.88263702, 8.51320171], [76.88236237, 8.51319504], [76.88236237, 8.51347256], [76.88208008, 8.51347065], [76.88208008, 8.51402855], [76.88181305, 8.51402855], [76.88181305, 8.51431179], [76.88153076, 8.51430511], [76.88153076, 8.51458263], [76.88124847, 8.51458263], [76.88124847, 8.51486111], [76.88096619, 8.51486111], [76.88096619, 8.51514244], [76.88041687, 8.51513863], [76.88041687, 8.51569462], [76.88014221, 8.5156908], [76.88014221, 8.5162611], [76.87985992, 8.5162611], [76.87985992, 8.51653194], [76.8795929, 8.51653194], [76.8795929, 8.51681042], [76.87930298, 8.5168047], [76.87930298, 8.51736069], [76.87847137, 8.51736069], [76.87847137, 8.51791954], [76.87819672, 8.51791763], [76.87819672, 8.51847363], [76.8779068, 8.51846886], [76.8779068, 8.51902962], [76.87763977, 8.51902771], [76.87763977, 8.51930618], [76.87735748, 8.51930618], [76.87735748, 8.51986217], [76.87708282, 8.51985931], [76.87708282, 8.52042007], [76.87680817, 8.52041626], [76.87680817, 8.52069569], [76.87652588, 8.52069092], [76.87652588, 8.52124977], [76.87625122, 8.52124977], [76.87625122, 8.52180958], [76.87596893, 8.52180576], [76.87596893, 8.52208424], [76.87569427, 8.52208424], [76.87569427, 8.52236176], [76.87541962, 8.52235985], [76.87541962, 8.52264023], [76.87513733, 8.52264023], [76.87513733, 8.52291965], [76.87486267, 8.52291584], [76.87486267, 8.52319431], [76.87458038, 8.52319431], [76.87458038, 8.52375031], [76.87431335, 8.52375031], [76.87431335, 8.52402973], [76.87403107, 8.52402782], [76.87403107, 8.52458191], [76.87374878, 8.52458382], [76.87374878, 8.52486229], [76.87346649, 8.52486038], [76.87346649, 8.52514172], [76.87319183, 8.52514172], [76.87319183, 8.52542973], [76.87291718, 8.52541637], [76.87291718, 8.52569389], [76.87264252, 8.52569389], [76.87264252, 8.52597237], [76.87236023, 8.52597046], [76.87236023, 8.52625179], [76.87180328, 8.52625179], [76.87180328, 8.52653027], [76.87152863, 8.52653027], [76.87152863, 8.52681065], [76.87124634, 8.52680588], [76.87124634, 8.52735996], [76.87097168, 8.52735996], [76.87097168, 8.52764034], [76.87069702, 8.52764034], [76.87069702, 8.5282011], [76.87041473, 8.52819443], [76.87041473, 8.52847195], [76.87014008, 8.52847195], [76.87014008, 8.52875042], [76.86987305, 8.52875042], [76.86987305, 8.5290308], [76.86930847, 8.52902794], [76.86930847, 8.52958202], [76.86902618, 8.52958202], [76.86902618, 8.53014088], [76.86875153, 8.53014088], [76.86875153, 8.53042126], [76.86846924, 8.53041553], [76.86846924, 8.53097153], [76.86818695, 8.53096962], [76.86818695, 8.53180885], [76.86736298, 8.53180695], [76.86736298, 8.53236008], [76.86708069, 8.53236008], [76.86708069, 8.53292084], [76.86680603, 8.53291702], [76.86680603, 8.53319454], [76.86653137, 8.53318977], [76.86653137, 8.53375053], [76.86624908, 8.53375053], [76.86624908, 8.53403091], [76.86597443, 8.53402901], [76.86597443, 8.53458309], [76.86569214, 8.53458309], [76.86569214, 8.53486061], [76.86541748, 8.53486061], [76.86541748, 8.53514099], [76.86513519, 8.53513908], [76.86513519, 8.5359726], [76.86486053, 8.53597069], [76.86486053, 8.53625107], [76.86458588, 8.53625107], [76.86458588, 8.53681183], [76.86402893, 8.53680515], [76.86402893, 8.53708267], [76.86373901, 8.5370779], [76.86373901, 8.53736973], [76.86347198, 8.53736973], [76.86347198, 8.53764057], [76.86292267, 8.53764057], [76.86292267, 8.53792191], [76.86264038, 8.53791714], [76.86264038, 8.53847313], [76.86207581, 8.53847122], [76.86207581, 8.53875065], [76.86235809, 8.53875065], [76.86235809, 8.53903103], [76.86180878, 8.53902912], [76.86180878, 8.53958321], [76.86125183, 8.53958321], [76.86125183, 8.53986073], [76.86096954, 8.53986073], [76.86096954, 8.5401392], [76.86069489, 8.5401392], [76.86069489, 8.54069519], [76.86042023, 8.54069519], [76.86042023, 8.5409708], [76.86013794, 8.54097271], [76.86013794, 8.54125118], [76.85986328, 8.54125118], [76.85986328, 8.54153156], [76.85958099, 8.54152679], [76.85958099, 8.54208279], [76.85930634, 8.54208279], [76.85930634, 8.54236126], [76.85901642, 8.54236126], [76.85901642, 8.54264164], [76.85874939, 8.54264164], [76.85874939, 8.54292202], [76.85819244, 8.54291725], [76.85819244, 8.54347134], [76.85793304, 8.54347134], [76.85793304, 8.54403019], [76.8576355, 8.54402733], [76.8576355, 8.54458332], [76.85736084, 8.54458332], [76.85736084, 8.54486179], [76.85708618, 8.54486179], [76.85708618, 8.54541969], [76.85652924, 8.54541779], [76.85652924, 8.5456934], [76.85624695, 8.5456934], [76.85624695, 8.54597092], [76.85597229, 8.54597092], [76.85597229, 8.54625034], [76.85569763, 8.54623985], [76.85569763, 8.54681015], [76.85541534, 8.54680634], [76.85541534, 8.54708385], [76.85514069, 8.54708099], [76.85514069, 8.54763985], [76.8548584, 8.54763985], [76.8548584, 8.54819584], [76.85430908, 8.54819584], [76.85430908, 8.5484724], [76.85402679, 8.54846859], [76.85402679, 8.5490303], [76.85375214, 8.5490303], [76.85375214, 8.54930973], [76.85346985, 8.54930592], [76.85346985, 8.54986191], [76.8529129, 8.54986191], [76.8529129, 8.55042267], [76.85236359, 8.5504179], [76.85236359, 8.55069447], [76.8520813, 8.55069447], [76.8520813, 8.55125046], [76.85179901, 8.55125046], [76.85179901, 8.55181122], [76.85150909, 8.55181122], [76.85150909, 8.55237103], [76.85124969, 8.55237103], [76.85124969, 8.5529213], [76.85097504, 8.55291557], [76.85097504, 8.55319405], [76.85041809, 8.55318928], [76.85041809, 8.55375004], [76.8501358, 8.55375004], [76.8501358, 8.55403042], [76.84958649, 8.55402756], [76.84958649, 8.55458355], [76.84929657, 8.55457973], [76.8493042, 8.55486012], [76.84902954, 8.55486012], [76.84902954, 8.55513954], [76.84874725, 8.55513763], [76.84874725, 8.55569363], [76.8484726, 8.55569363], [76.8484726, 8.5559721], [76.84819794, 8.55597019], [76.84819794, 8.55653095], [76.84791565, 8.55652809], [76.84791565, 8.55708218], [76.8473587, 8.55708218], [76.8473587, 8.5573597], [76.84707642, 8.5573597], [76.84707642, 8.55792141], [76.84680939, 8.55791569], [76.84680176, 8.55819416], [76.8465271, 8.55819416], [76.8465271, 8.55875111], [76.84597015, 8.55875111], [76.84597015, 8.55931091], [76.84541321, 8.55930424], [76.84541321, 8.55986118], [76.84513855, 8.55986118], [76.84513855, 8.56014061], [76.8445816, 8.5601387], [76.8445816, 8.56069469], [76.84430695, 8.56068993], [76.84430695, 8.56125069], [76.84375, 8.56125069], [76.84375, 8.56153965], [76.84347534, 8.56152916], [76.84347534, 8.56208324], [76.84319305, 8.56208038], [76.84319305, 8.56264114], [76.84263611, 8.56264114], [76.84263611, 8.56292057], [76.84236145, 8.56291676], [76.84236145, 8.56347275], [76.84208679, 8.56347084], [76.84208679, 8.56403065], [76.84179688, 8.56403065], [76.84179688, 8.56431198], [76.84152985, 8.56430531], [76.84152985, 8.56458282], [76.84124756, 8.56458282], [76.84124756, 8.5648613], [76.84069824, 8.5648613], [76.84069824, 8.5654192], [76.84041595, 8.56541729], [76.84041595, 8.56569481], [76.83985901, 8.56569481], [76.83985901, 8.56597328], [76.83930206, 8.56597137], [76.83930206, 8.56652927], [76.8390274, 8.56652737], [76.8390274, 8.56708336], [76.83875275, 8.56708145], [76.83875275, 8.56792164], [76.8381958, 8.56791687], [76.8381958, 8.56875134], [76.83790588, 8.56875134], [76.83790588, 8.56903172], [76.83763885, 8.56902695], [76.83763885, 8.56958294], [76.83708191, 8.56958294], [76.83708191, 8.56986141], [76.83680725, 8.56986141], [76.83680725, 8.5704174], [76.83652496, 8.5704174], [76.83652496, 8.57097435], [76.83598328, 8.57097054], [76.83598328, 8.57153034], [76.83569336, 8.57153034], [76.83569336, 8.57180977], [76.8354187, 8.571805], [76.8354187, 8.57236195], [76.83513641, 8.57236195], [76.83513641, 8.57264042], [76.83486176, 8.57264042], [76.83486176, 8.5731926], [76.83429718, 8.57319069], [76.83429718, 8.57348061], [76.83376312, 8.57348061], [76.83374786, 8.57374954], [76.83347321, 8.57374954], [76.83347321, 8.57402992], [76.83319092, 8.57402802], [76.83319092, 8.57458401], [76.83291626, 8.57458401], [76.83291626, 8.57486153], [76.83235931, 8.57486153], [76.83235931, 8.57569408], [76.83180237, 8.57569122], [76.83180237, 8.57625198], [76.83152771, 8.57625198], [76.83152771, 8.57681274], [76.83125305, 8.57680607], [76.83125305, 8.57736206], [76.83097076, 8.57736015], [76.83097076, 8.57791996], [76.83041382, 8.57791805], [76.83041382, 8.57819366], [76.83013916, 8.57819366], [76.83013916, 8.57847214], [76.82958221, 8.57847023], [76.82958221, 8.57903004], [76.82930756, 8.57903004], [76.82930756, 8.57931137], [76.82902527, 8.57930565], [76.82902527, 8.57958412], [76.82875061, 8.57958412], [76.82875061, 8.57985973], [76.82818604, 8.57985973], [76.82818604, 8.58042145], [76.82791901, 8.58041573], [76.82791901, 8.5806942], [76.82736206, 8.58069038], [76.82736206, 8.58181095], [76.82707977, 8.58180618], [76.82707977, 8.5820837], [76.82681274, 8.58207989], [76.82681274, 8.58263969], [76.82653046, 8.58263969], [76.82653046, 8.58292103], [76.82597351, 8.58291626], [76.82597351, 8.58319378], [76.82569122, 8.58319187], [76.82569122, 8.58374977], [76.82514191, 8.58374977], [76.82514191, 8.58403111], [76.82485962, 8.58402824], [76.82485962, 8.58485985], [76.8245697, 8.58485985], [76.8245697, 8.58514118], [76.82430267, 8.58513832], [76.82430267, 8.58569527], [76.82402802, 8.58569527], [76.82402802, 8.58597279], [76.82375336, 8.58597279], [76.82375336, 8.58625126], [76.82347107, 8.58625126], [76.82347107, 8.58653069], [76.82319641, 8.58652878], [76.82319641, 8.58708191], [76.82291412, 8.58708477], [76.82291412, 8.58736134], [76.82263947, 8.58736134], [76.82263947, 8.58792114], [76.82208252, 8.58792114], [76.82208252, 8.5884819], [76.82182312, 8.5884819], [76.82182312, 8.58875084], [76.8215332, 8.58875084], [76.8215332, 8.58903122], [76.82125092, 8.58903122], [76.82125092, 8.58931065], [76.82096863, 8.58930683], [76.82096863, 8.58986092], [76.82068634, 8.58986092], [76.82068634, 8.5901413], [76.82041931, 8.59013939], [76.82041931, 8.59069538], [76.81958008, 8.59068966], [76.81958008, 8.59154034], [76.81930542, 8.59152699], [76.81930542, 8.59208298], [76.81874847, 8.59208298], [76.81874847, 8.59236145], [76.81819153, 8.59236145], [76.81819153, 8.59291935], [76.81791687, 8.59291744], [76.81791687, 8.59347343], [76.81764221, 8.59347057], [76.81764221, 8.59402943], [76.81735992, 8.59402943], [76.81735992, 8.59431171], [76.81708527, 8.59430504], [76.81708527, 8.59458256], [76.81680298, 8.59458065], [76.81680298, 8.59514236], [76.81652832, 8.59514236], [76.81652832, 8.59542179], [76.81597137, 8.59541702], [76.81597137, 8.59597111], [76.81568909, 8.59597111], [76.81568909, 8.59653187], [76.81539917, 8.59653187], [76.81539917, 8.59681034], [76.81513977, 8.59680462], [76.81513977, 8.59708309], [76.81485748, 8.59708118], [76.81485748, 8.59764194], [76.81458282, 8.59763908], [76.81458282, 8.59819317], [76.81402588, 8.59819317], [76.81402588, 8.59847355], [76.81375122, 8.59847069], [76.81375122, 8.59902954], [76.81319427, 8.59902668], [76.81319427, 8.59958363], [76.81291962, 8.59958363], [76.81291962, 8.5998621], [76.8126297, 8.59985924], [76.8126297, 8.60042], [76.81236267, 8.60041809], [76.81236267, 8.60069561], [76.81208038, 8.60069561], [76.81208038, 8.60097218], [76.81181335, 8.60096931], [76.81181335, 8.60124969], [76.81124878, 8.60124969], [76.81124878, 8.60181046], [76.81096649, 8.60181046], [76.81097412, 8.60236168], [76.81069183, 8.60236168], [76.81069183, 8.60264015], [76.81041718, 8.60264015], [76.81041718, 8.60319424], [76.80986023, 8.60319424], [76.80986023, 8.60375023], [76.8095932, 8.60375023], [76.8095932, 8.60402966], [76.80930328, 8.60402775], [76.80930328, 8.60458374], [76.80902863, 8.60458183], [76.80902863, 8.60513973], [76.80847168, 8.60513973], [76.80847168, 8.60542011], [76.80819702, 8.6054163], [76.80819702, 8.60597229], [76.80764008, 8.60597229], [76.80764008, 8.60652828], [76.80735779, 8.60652828], [76.80735779, 8.60708427], [76.80708313, 8.60708427], [76.80708313, 8.60735989], [76.8068161, 8.60735989], [76.8068161, 8.60792065], [76.80652618, 8.60791588], [76.80652618, 8.60819435], [76.80596924, 8.60819435], [76.80596924, 8.60875034], [76.80568695, 8.60875034], [76.80568695, 8.60903072], [76.80541992, 8.60903072], [76.80541992, 8.6093111], [76.80513763, 8.60930634], [76.80513763, 8.60986233], [76.80486298, 8.60986042], [76.80486298, 8.6101408], [76.80458069, 8.6101408], [76.80458069, 8.61042118], [76.80430603, 8.61041641], [76.80430603, 8.6109724], [76.80403137, 8.61096954], [76.80403137, 8.61124992], [76.80374908, 8.61124992], [76.80374908, 8.61153126], [76.80345917, 8.61153126], [76.80345917, 8.61181068], [76.80319214, 8.61180687], [76.80319214, 8.61236], [76.80291748, 8.61236], [76.80291748, 8.61252022], [76.80291748, 8.61264992], [76.80264282, 8.61264992], [76.80264282, 8.61291885], [76.80236053, 8.61291695], [76.80236053, 8.61347294], [76.80179596, 8.61347008], [76.80180359, 8.61375141], [76.80152893, 8.61375141], [76.80152893, 8.61431122], [76.80124664, 8.61430359], [76.80124664, 8.61458302], [76.80097198, 8.61458015], [76.80097198, 8.61514091], [76.80069733, 8.61513901], [76.80069733, 8.615695], [76.80014038, 8.61569023], [76.80014038, 8.61625099], [76.79985809, 8.61625099], [76.79985809, 8.61653137], [76.79957581, 8.61653137], [76.79957581, 8.61680889], [76.79930878, 8.61680698], [76.79930878, 8.6170826], [76.79902649, 8.61707973], [76.79902649, 8.61764145], [76.79846954, 8.61764145], [76.79846954, 8.61792088], [76.79819489, 8.61791706], [76.79819489, 8.61847305], [76.79792023, 8.61846161], [76.79792023, 8.61903095], [76.79736328, 8.61903095], [76.79736328, 8.61930943], [76.79680634, 8.61930466], [76.79680634, 8.61986065], [76.79651642, 8.61986065], [76.79651642, 8.62041855], [76.79624939, 8.62041664], [76.79624939, 8.62097263], [76.79569244, 8.62097263], [76.79569244, 8.6212492], [76.79541779, 8.6212492], [76.79541779, 8.62181187], [76.7951355, 8.62180519], [76.7951355, 8.62236118], [76.79458618, 8.62236118], [76.79458618, 8.62264156], [76.79430389, 8.6226387], [76.79430389, 8.62319469], [76.79402924, 8.62319088], [76.79402924, 8.62375164], [76.79374695, 8.62375164], [76.79374695, 8.62403202], [76.79347229, 8.62403202], [76.79347229, 8.62430954], [76.79319763, 8.62430954], [76.79319763, 8.62458992], [76.79291534, 8.62458324], [76.79291534, 8.62486076], [76.79264069, 8.62485886], [76.79264069, 8.62514019], [76.79207611, 8.62514019], [76.79207611, 8.62541962], [76.79180908, 8.62541771], [76.79180908, 8.62569332], [76.79152679, 8.62569332], [76.79152679, 8.62597084], [76.79125214, 8.62597084], [76.79125214, 8.62652969], [76.79096985, 8.62652969], [76.79096985, 8.62681007], [76.79069519, 8.62680626], [76.79069519, 8.62708378], [76.7904129, 8.62708092], [76.7904129, 8.62765121], [76.79013824, 8.62765121], [76.79013824, 8.62792015], [76.78986359, 8.62791538], [76.78986359, 8.62847233], [76.78930664, 8.62847233], [76.78930664, 8.62874985], [76.78901672, 8.62874985], [76.78901672, 8.62903023], [76.78874969, 8.62903023], [76.78874969, 8.62930965], [76.78847504, 8.62930584], [76.78847504, 8.62958431], [76.78819275, 8.62958431], [76.78819275, 8.63069439], [76.78791809, 8.63069439], [76.78791809, 8.63125038], [76.78679657, 8.63125038], [76.78679657, 8.63153172], [76.78652954, 8.63153172], [76.78652954, 8.63181114], [76.78624725, 8.63180637], [76.78624725, 8.63208389], [76.7859726, 8.63208389], [76.7859726, 8.63236237], [76.7857132, 8.63236046], [76.7857132, 8.63292027], [76.78541565, 8.63291645], [76.78541565, 8.63347244], [76.78514099, 8.633461], [76.78514099, 8.63403034], [76.7848587, 8.63402843], [76.7848587, 8.63486004], [76.78457642, 8.63486004], [76.78457642, 8.6354208], [76.78430939, 8.63541603], [76.78430176, 8.63597202], [76.78375244, 8.63597012], [76.78375244, 8.63653088], [76.78347015, 8.63653088], [76.78347015, 8.63681984], [76.78291321, 8.63680553], [76.78291321, 8.6370821], [76.78263855, 8.6370821], [76.78263855, 8.63736343], [76.78235626, 8.63735962], [76.78235626, 8.63792133], [76.7820816, 8.63791561], [76.7820816, 8.63819408], [76.78152466, 8.63819408], [76.78152466, 8.6384716], [76.78125, 8.6384697], [76.78125, 8.63931084], [76.78097534, 8.63930416], [76.78097534, 8.63986015], [76.78069305, 8.63986015], [76.78069305, 8.64014053], [76.7804184, 8.64014053], [76.7804184, 8.64042091], [76.78013611, 8.6404171], [76.78013611, 8.64097309], [76.77986145, 8.64097023], [76.77986145, 8.64125061], [76.77957916, 8.64125061], [76.77957916, 8.64181137], [76.7793045, 8.6418047], [76.7793045, 8.64208317], [76.77902985, 8.64208317], [76.77902985, 8.64236069], [76.77874756, 8.64236069], [76.77874756, 8.64292145], [76.7784729, 8.64291668], [76.7784729, 8.64319515], [76.77819824, 8.64319515], [76.77819824, 8.64347267], [76.77791595, 8.6434679], [76.77791595, 8.64403057], [76.77735901, 8.64403057], [76.77735901, 8.6443119], [76.77708435, 8.64430523], [76.77708435, 8.64486122], [76.77680206, 8.64486122], [76.77680206, 8.64542198], [76.7765274, 8.64541721], [76.7765274, 8.64597321], [76.77625275, 8.6459713], [76.77625275, 8.64625072], [76.77597046, 8.64625072], [76.77597046, 8.6465292], [76.7756958, 8.6465292], [76.7756958, 8.64708328], [76.77541351, 8.64708328], [76.77541351, 8.6473608], [76.77513885, 8.64735889], [76.77513885, 8.64763927], [76.77485657, 8.64763927], [76.77485657, 8.64792156], [76.77458191, 8.64791679], [76.77458191, 8.64819527], [76.77401733, 8.64819145], [76.77401733, 8.6487627], [76.77375031, 8.6487627], [76.77375031, 8.64903164], [76.77348328, 8.64903164], [76.77348328, 8.64931202], [76.7729187, 8.64930534], [76.7729187, 8.64986134], [76.77263641, 8.64986134], [76.77263641, 8.65042019], [76.77236176, 8.65041733], [76.77236176, 8.65097141], [76.7720871, 8.65097141], [76.7720871, 8.65125179], [76.77179718, 8.65125179], [76.77179718, 8.65153027], [76.77153015, 8.65153027], [76.77153015, 8.65181923], [76.77124786, 8.65180492], [76.77124786, 8.6520834], [76.77097321, 8.65208054], [76.77097321, 8.65264034], [76.77069092, 8.65264034], [76.77069092, 8.65291977], [76.77041626, 8.65291786], [76.77041626, 8.65319347], [76.7701416, 8.65319347], [76.7701416, 8.65374947], [76.76985931, 8.65374947], [76.76985931, 8.65431023], [76.76930237, 8.65430641], [76.76930237, 8.6548624], [76.76902771, 8.65485859], [76.76902771, 8.65513992], [76.76875305, 8.65513992], [76.76875305, 8.65569401], [76.76847076, 8.65569115], [76.76847076, 8.65625191], [76.76790619, 8.65625191], [76.76790619, 8.65653038], [76.76763916, 8.65652847], [76.76763916, 8.65708447], [76.76735687, 8.6570816], [76.7673645, 8.65736198], [76.76708221, 8.65736198], [76.76708221, 8.6576376], [76.76680756, 8.65763092], [76.76680756, 8.65792274], [76.76652527, 8.65791798], [76.76652527, 8.65819359], [76.76625061, 8.65819359], [76.76625061, 8.65847206], [76.76597595, 8.65847015], [76.76597595, 8.65874958], [76.76568604, 8.65874958], [76.76568604, 8.65931129], [76.76541901, 8.65930557], [76.76541901, 8.65958405], [76.76513672, 8.65958023], [76.76513672, 8.66014004], [76.76486206, 8.66014004], [76.76486206, 8.66042137], [76.76457977, 8.66042137], [76.76457977, 8.6607008], [76.76431274, 8.6607008], [76.76431274, 8.66125011], [76.76403046, 8.66125011], [76.76403046, 8.66152954], [76.76374817, 8.66152954], [76.76374817, 8.66181087], [76.76347351, 8.66180611], [76.76347351, 8.66208363], [76.76291656, 8.66208172], [76.76291656, 8.66263962], [76.76264191, 8.66263962], [76.76264191, 8.66292095], [76.76235962, 8.66291618], [76.76235962, 8.66347218], [76.76180267, 8.66347027], [76.76180267, 8.66375923], [76.76154327, 8.66375923], [76.76154327, 8.66403103], [76.76125336, 8.66403103], [76.76125336, 8.66431141], [76.76097107, 8.66430569], [76.76097107, 8.66485977], [76.76069641, 8.66485977], [76.76069641, 8.66542053], [76.76041412, 8.66541576], [76.76041412, 8.66569424], [76.76013947, 8.66569424], [76.76013947, 8.66625118], [76.75986481, 8.66625118], [76.75986481, 8.66680431], [76.75958252, 8.66680431], [76.75958252, 8.66736031], [76.75930786, 8.66736031], [76.75930786, 8.66764069], [76.75875092, 8.66764069], [76.75875092, 8.66792107], [76.75846863, 8.66791725], [76.75846863, 8.66819477], [76.75819397, 8.66819477], [76.75819397, 8.66847324], [76.75791931, 8.66847324], [76.75791931, 8.66875076], [76.75763702, 8.6687479], [76.75763702, 8.66903114], [76.75736237, 8.66902924], [76.75736237, 8.66958332], [76.75708008, 8.66958332], [76.75708008, 8.66986084], [76.75653076, 8.66986084], [76.75653076, 8.67014122], [76.75569153, 8.67014122], [76.75569153, 8.67153072], [76.75541687, 8.67152691], [76.75541687, 8.6720829], [76.75514221, 8.6720829], [76.75514221, 8.67236137], [76.7545929, 8.67236137], [76.7545929, 8.67263889], [76.75430298, 8.67263889], [76.75430298, 8.67291927], [76.75402832, 8.67291737], [76.75402832, 8.67319489], [76.75375366, 8.67319489], [76.75375366, 8.67347336], [76.75347137, 8.67347145], [76.75347137, 8.67402935], [76.75319672, 8.67402935], [76.75319672, 8.67430973], [76.7529068, 8.67430973], [76.75291443, 8.67486095], [76.75263977, 8.67486095], [76.75263977, 8.67542171], [76.75208282, 8.67541695], [76.75208282, 8.67597103], [76.75180817, 8.67597103], [76.75180817, 8.67625141], [76.75152588, 8.67625141], [76.75152588, 8.67681026], [76.75096893, 8.67680454], [76.75096893, 8.67708302], [76.75069427, 8.67708302], [76.75069427, 8.67736053], [76.75041962, 8.67736053], [76.75041962, 8.67764187], [76.74986267, 8.67763901], [76.74986267, 8.67847443], [76.74958038, 8.67847443], [76.74958038, 8.67874908], [76.74903107, 8.67873955], [76.74903107, 8.67930984], [76.74874878, 8.67930984], [76.74874878, 8.68013954], [76.74819183, 8.68013954], [76.74819183, 8.68041992], [76.74791718, 8.68041801], [76.74791718, 8.68069553], [76.74764252, 8.68068886], [76.74764252, 8.68124962], [76.74736023, 8.68124962], [76.74736023, 8.68180561], [76.74680328, 8.68180561], [76.74680328, 8.6823616], [76.74653625, 8.6823616], [76.74653625, 8.68292046], [76.74624634, 8.68291569], [76.74624634, 8.68319416], [76.74597168, 8.68319416], [76.74597168, 8.68347168], [76.7454071, 8.68347168], [76.74541473, 8.68375015], [76.74514008, 8.68375015], [76.74514008, 8.68430996], [76.74485779, 8.68430614], [76.74485779, 8.68486214], [76.74458313, 8.68486023], [76.74458313, 8.68513966], [76.74430847, 8.68513966], [76.74430847, 8.68542004], [76.74402618, 8.68541622], [76.74402618, 8.68569374], [76.74375153, 8.68569183], [76.74375153, 8.68624973], [76.74318695, 8.68624973], [76.74318695, 8.68681145], [76.74291992, 8.68681145], [76.74291992, 8.68736172], [76.74236298, 8.68736172], [76.74236298, 8.68793201], [76.74208069, 8.6879158], [76.74208069, 8.68819427], [76.74180603, 8.68819427], [76.74180603, 8.68847179], [76.74153137, 8.68847179], [76.74153137, 8.68875027], [76.74124908, 8.68875027], [76.74124908, 8.68931103], [76.74097443, 8.68930626], [76.74097443, 8.68958378], [76.74040985, 8.68957996], [76.74040985, 8.69013977], [76.74013519, 8.69013786], [76.74013519, 8.69069386], [76.73986053, 8.69069386], [76.73986053, 8.69097233], [76.73958588, 8.69097233], [76.73958588, 8.69124985], [76.73929596, 8.69124985], [76.73929596, 8.69153118], [76.73902893, 8.69153118], [76.73902893, 8.69181061], [76.73874664, 8.69180679], [76.73874664, 8.69208241], [76.73847198, 8.69207954], [76.73847198, 8.69264126], [76.73819733, 8.69264126], [76.73819733, 8.69292068], [76.73791504, 8.69291592], [76.73791504, 8.69347286], [76.73764038, 8.69347], [76.73764038, 8.69402885], [76.73735046, 8.69402885], [76.73735046, 8.69431114], [76.73680878, 8.69430447], [76.73680878, 8.69486141], [76.73652649, 8.69486141], [76.73652649, 8.69542122], [76.73625183, 8.6954174], [76.73625183, 8.69569492], [76.73596954, 8.69569492], [76.73596954, 8.6959734], [76.73568726, 8.69596958], [76.73568726, 8.6965313], [76.73542023, 8.69652653], [76.73542023, 8.69680691], [76.73513794, 8.69680691], [76.73513794, 8.69736099], [76.73486328, 8.69736099], [76.73486328, 8.69791889], [76.73458099, 8.69791698], [76.73458099, 8.69819546], [76.73430634, 8.69819546], [76.73430634, 8.69847298], [76.73374939, 8.69847107], [76.73374939, 8.69875145], [76.7334671, 8.69875145], [76.7334671, 8.69903088], [76.73319244, 8.69903088], [76.73319244, 8.69930935], [76.73291779, 8.69930935], [76.73291779, 8.70014095], [76.73264313, 8.70014095], [76.73264313, 8.70041943], [76.73236084, 8.70041656], [76.73236084, 8.70069504], [76.73208618, 8.70069504], [76.73208618, 8.70097256], [76.73179626, 8.70097065], [76.73179626, 8.70125103], [76.73153687, 8.70125103], [76.73153687, 8.70153236], [76.73124695, 8.70153236], [76.73124695, 8.70181179], [76.73097229, 8.70180511], [76.73097229, 8.70208263], [76.73069763, 8.70208263], [76.73069763, 8.70236111], [76.73042297, 8.70236111], [76.73042297, 8.70264244], [76.73014069, 8.70264244], [76.73014069, 8.7029314], [76.7298584, 8.7029171], [76.7298584, 8.70319462], [76.72958374, 8.70319462], [76.72958374, 8.70347118], [76.72902679, 8.70347118], [76.72902679, 8.70375061], [76.72875214, 8.70375061], [76.72875214, 8.70431042], [76.72820282, 8.70431042], [76.72820282, 8.70514202], [76.7279129, 8.70513916], [76.7279129, 8.70569324], [76.72763824, 8.70569324], [76.72763824, 8.70597363], [76.72735596, 8.70596886], [76.72736359, 8.70624924], [76.7270813, 8.70624924], [76.7270813, 8.70681], [76.72680664, 8.70680523], [76.72680664, 8.7070837], [76.72651672, 8.70708084], [76.72651672, 8.70763969], [76.72597504, 8.70763969], [76.72597504, 8.70819569], [76.72569275, 8.70819569], [76.72569275, 8.70847225], [76.72541046, 8.70846939], [76.72541046, 8.70903015], [76.7251358, 8.70903015], [76.7251358, 8.70930958], [76.72486115, 8.70930576], [76.72486115, 8.70958424], [76.72458649, 8.70958424], [76.72458649, 8.70986176], [76.72429657, 8.70985985], [76.72429657, 8.71014023], [76.72402954, 8.71014023], [76.72402954, 8.71069431], [76.7234726, 8.71069431], [76.7234726, 8.71097183], [76.72319794, 8.71097183], [76.72319794, 8.71152973], [76.72291565, 8.71152782], [76.72291565, 8.71208382], [76.72264099, 8.71208382], [76.72264099, 8.71236229], [76.72236633, 8.71236038], [76.72236633, 8.71264172], [76.72207642, 8.71264172], [76.72207642, 8.71292019], [76.72180939, 8.71291637], [76.72180176, 8.71347237], [76.7215271, 8.71347046], [76.7215271, 8.71375179], [76.72125244, 8.71375179], [76.72125244, 8.71403027], [76.72097015, 8.71402836], [76.72097015, 8.71458435], [76.72070313, 8.71457958], [76.72070313, 8.71514034], [76.72041321, 8.71514034], [76.72041321, 8.71542072], [76.72013855, 8.71541595], [76.72013855, 8.71569443], [76.7195816, 8.71569443], [76.7195816, 8.71597195], [76.71930695, 8.71597195], [76.71930695, 8.71625042], [76.71901703, 8.71625042], [76.71901703, 8.7165308], [76.71875, 8.71652794], [76.71875, 8.71708202], [76.71848297, 8.71708202], [76.71848297, 8.71764088], [76.71819305, 8.71763802], [76.71819305, 8.71791553], [76.71763611, 8.71791553], [76.71763611, 8.71847153], [76.71736145, 8.71846962], [76.71736145, 8.71875], [76.71708679, 8.71875], [76.71708679, 8.71903133], [76.71679688, 8.71903133], [76.71679688, 8.71930885], [76.71652985, 8.71930695], [76.71652985, 8.71958542], [76.7159729, 8.71958542], [76.7159729, 8.71986008], [76.71569824, 8.71986008], [76.71569824, 8.72014141], [76.71541595, 8.72014141], [76.71541595, 8.72042084], [76.71485901, 8.72042084], [76.71485901, 8.72125053], [76.71457672, 8.72125053], [76.71457672, 8.72153091], [76.71430206, 8.72152901], [76.71430206, 8.72208309], [76.7140274, 8.72208309], [76.7140274, 8.72236061], [76.71375275, 8.72236061], [76.71375275, 8.72264099], [76.7131958, 8.72263908], [76.7131958, 8.72319508], [76.71291351, 8.72319508], [76.71291351, 8.7234726], [76.71263885, 8.72347069], [76.71263885, 8.72375107], [76.71235657, 8.72375107], [76.71235657, 8.72404003], [76.71208191, 8.72404003], [76.71208191, 8.72431183], [76.71152496, 8.72430515], [76.71152496, 8.72458267], [76.71097565, 8.72458267], [76.71097565, 8.72486115], [76.71069336, 8.72486115], [76.71069336, 8.72569466], [76.71042633, 8.72568989], [76.71042633, 8.72653103], [76.71013641, 8.72653103], [76.71013641, 8.72680855], [76.70986176, 8.72680473], [76.70986176, 8.72708321], [76.7095871, 8.7270813], [76.7095871, 8.72736073], [76.70847321, 8.72736073], [76.70847321, 8.72819519], [76.70791626, 8.72819519], [76.70791626, 8.72875118], [76.7076416, 8.72875118], [76.7076416, 8.72931194], [76.70708466, 8.72930527], [76.70708466, 8.72958279], [76.70680237, 8.72958279], [76.70680237, 8.72986126], [76.70625305, 8.72986126], [76.70625305, 8.73069477], [76.70569611, 8.73069096], [76.70569611, 8.73125172], [76.70541382, 8.73124886], [76.70541382, 8.73208332], [76.70513916, 8.73208332], [76.70513916, 8.73291779], [76.70485687, 8.73291111], [76.7048645, 8.73374939], [76.70458221, 8.73374939], [76.70458221, 8.73431015], [76.70430756, 8.73430634], [76.70430756, 8.73458385], [76.70402527, 8.73458385], [76.70402527, 8.73486233], [76.70375061, 8.73485947], [76.70375061, 8.73513985], [76.70318604, 8.73513985], [76.70318604, 8.73542023], [76.70291901, 8.73541546], [76.70291901, 8.73569584], [76.70263672, 8.73569107], [76.70263672, 8.73598099], [76.70236206, 8.73598099], [76.70236206, 8.7365303], [76.70124054, 8.7365303], [76.70124054, 8.73680973], [76.70069122, 8.73680592], [76.70069122, 8.73708439], [76.70014191, 8.73708439], [76.70014191, 8.73736191], [76.69985962, 8.73736191], [76.69985962, 8.73764038], [76.69958496, 8.73763847], [76.69958496, 8.73819447], [76.69930267, 8.73819447], [76.69930267, 8.73875046], [76.69902802, 8.73875046], [76.69902802, 8.73931122], [76.69875336, 8.73930645], [76.69875336, 8.73958397], [76.69902802, 8.7395792], [76.69902802, 8.74013996], [76.69875336, 8.74013996], [76.69875336, 8.74125004], [76.69847107, 8.74125004], [76.69847107, 8.74236012], [76.69819641, 8.74236012], [76.69819641, 8.74292088], [76.69790649, 8.74292088], [76.69790649, 8.74374962], [76.69763947, 8.74374962], [76.69763947, 8.74403095], [76.69735718, 8.74403095], [76.69735718, 8.74431133], [76.69680786, 8.74431133], [76.69680786, 8.74514103], [76.69652557, 8.74513817], [76.69652557, 8.74569416], [76.69625092, 8.74569416], [76.69625092, 8.74625015], [76.69596863, 8.74625015], [76.69596863, 8.74681091], [76.69569397, 8.74680424], [76.69569397, 8.74736023], [76.69542694, 8.74736023], [76.69542694, 8.74792099], [76.69486237, 8.74791718], [76.69486237, 8.74819469], [76.69458008, 8.74819469], [76.69458008, 8.74847317], [76.69431305, 8.74847031], [76.69431305, 8.74931145], [76.69403076, 8.74930668], [76.69403076, 8.74986076], [76.69374847, 8.74986076], [76.69374847, 8.75069523], [76.69346619, 8.75069046], [76.69346619, 8.75098038], [76.69319153, 8.75097275], [76.69319153, 8.75125122], [76.69291687, 8.75125122], [76.69291687, 8.75153065], [76.69264221, 8.75153065], [76.69264221, 8.75181198], [76.69235992, 8.75180531], [76.69235992, 8.75208282], [76.69180298, 8.75208092], [76.69180298, 8.75264072], [76.69124603, 8.75264072], [76.69124603, 8.7529192], [76.69097137, 8.75291729], [76.69097137, 8.75319481], [76.69069672, 8.75319481], [76.69069672, 8.75374889], [76.69041443, 8.75374889], [76.69041443, 8.75402737], [76.69013977, 8.75402737], [76.69013977, 8.75458336], [76.68985748, 8.75458336], [76.68985748, 8.75486088], [76.68958282, 8.75486088], [76.68958282, 8.75514126], [76.68930817, 8.75513935], [76.68930817, 8.75569534], [76.68902588, 8.75569534], [76.68902588, 8.75597095], [76.68875122, 8.75597095], [76.68875122, 8.75653172], [76.68846893, 8.75652695], [76.68846893, 8.75708294], [76.68818665, 8.75708103], [76.68818665, 8.75792027], [76.68791962, 8.75792027], [76.68791962, 8.75875187], [76.68763733, 8.75875187], [76.68763733, 8.75903034], [76.68736267, 8.75902653], [76.68736267, 8.75958347], [76.68708038, 8.75958061], [76.68708038, 8.76015091], [76.68681335, 8.76015091], [76.68681335, 8.76041985], [76.68653107, 8.76041794], [76.68653107, 8.7606926], [76.68624878, 8.7606926], [76.68624878, 8.76097107], [76.68596649, 8.76097107], [76.68597412, 8.76124859], [76.68569183, 8.76124859], [76.68569183, 8.7618103], [76.68541718, 8.76180553], [76.68541718, 8.76208401], [76.68514252, 8.76207924], [76.68514252, 8.76264191], [76.68486023, 8.76264191], [76.68486023, 8.76292038], [76.6845932, 8.76292038], [76.6845932, 8.76375198], [76.68430328, 8.76375198], [76.68430328, 8.76403046], [76.68374634, 8.76403046], [76.68374634, 8.76431274], [76.68347168, 8.76430607], [76.68347168, 8.76486206], [76.68319702, 8.76486206], [76.68319702, 8.76569366], [76.6829071, 8.7656889], [76.6829071, 8.76653004], [76.68319702, 8.76653004], [76.68319702, 8.76681137], [76.6829071, 8.76681137], [76.68291473, 8.76735973], [76.68264008, 8.76735973], [76.68264008, 8.76764011], [76.68235779, 8.76764011], [76.68235779, 8.76792145], [76.68208313, 8.76791573], [76.68208313, 8.76847172], [76.68180847, 8.76847172], [76.68180847, 8.76931095], [76.68152618, 8.76930618], [76.68152618, 8.7695837], [76.68125153, 8.7695837], [76.68125153, 8.76986217], [76.68096924, 8.76986027], [76.68096924, 8.77013969], [76.68068695, 8.77013969], [76.68068695, 8.77042103], [76.68041992, 8.77041626], [76.68041992, 8.77069378], [76.68013, 8.77069187], [76.68013, 8.77124977], [76.67986298, 8.77124977], [76.67986298, 8.77153111], [76.67958069, 8.77153111], [76.67958069, 8.77264118], [76.67930603, 8.77263832], [76.67930603, 8.77319431], [76.67903137, 8.77319431], [76.67903137, 8.77347183], [76.67874908, 8.77347183], [76.67874908, 8.77375126], [76.67819214, 8.77375126], [76.67819214, 8.77403069], [76.67791748, 8.77403069], [76.67791748, 8.77431107], [76.67763519, 8.77430439], [76.67763519, 8.77474022], [76.67763519, 8.77486038], [76.67736053, 8.77486038], [76.67736053, 8.7751503], [76.67708588, 8.7751503], [76.67708588, 8.77542114], [76.67680359, 8.77541733], [76.67680359, 8.77569485], [76.67662811, 8.77569485], [76.67652893, 8.77569485], [76.67652893, 8.77653122], [76.67624664, 8.7765274], [76.67624664, 8.7770834], [76.67597198, 8.77707958], [76.67597198, 8.7776413], [76.67569733, 8.7776413], [76.67569733, 8.77792072], [76.67541504, 8.77791691], [76.67541504, 8.77819538], [76.67514038, 8.77819538], [76.67514038, 8.7784729], [76.67457581, 8.77847099], [76.67457581, 8.77875137], [76.67514038, 8.77875137], [76.67514038, 8.77930927], [76.67485809, 8.77930927], [76.67485809, 8.77902889], [76.67457581, 8.77902889], [76.67457581, 8.77930927], [76.67431641, 8.77930927], [76.67431641, 8.78041935], [76.67402649, 8.78041744], [76.67402649, 8.78069496], [76.67318726, 8.78069115], [76.67318726, 8.78153229], [76.67292023, 8.78152657], [76.67292023, 8.78208256], [76.67236328, 8.78208256], [76.67236328, 8.78236103], [76.67208099, 8.78236103], [76.67208099, 8.78281021], [76.67208099, 8.78292179], [76.67180634, 8.78291702], [76.67180634, 8.7834301], [76.67180634, 8.78375053], [76.67151642, 8.78375053], [76.67151642, 8.78347111], [76.67124939, 8.78347111], [76.67125702, 8.78391075], [76.67125702, 8.78431034], [76.67069244, 8.78430462], [76.67069244, 8.78458309], [76.67041779, 8.78458309], [76.67041779, 8.78486061], [76.67069244, 8.78486061], [76.67069244, 8.78514194], [76.67041779, 8.78514194], [76.67041779, 8.78542042], [76.6701355, 8.7854166], [76.6701355, 8.78597355], [76.66958618, 8.78597069], [76.66958618, 8.78625202], [76.66929626, 8.78625202], [76.66929626, 8.78652954], [76.66902924, 8.78652954], [76.66902924, 8.78680992], [76.66819763, 8.78680515], [76.66819763, 8.7873621], [76.66792297, 8.78735924], [76.66792297, 8.78792], [76.66764069, 8.78791809], [76.66764069, 8.78847122], [76.6673584, 8.78846931], [76.6673584, 8.78874969], [76.66680908, 8.78874969], [76.66680908, 8.78931046], [76.66652679, 8.78930569], [76.66652679, 8.78958416], [76.66625214, 8.78958416], [76.66625214, 8.79014015], [76.66596985, 8.79013062], [76.66596985, 8.79041958], [76.66569519, 8.79041576], [76.66569519, 8.79069424], [76.6645813, 8.79069424], [76.6645813, 8.79097176], [76.66430664, 8.79096889], [76.66430664, 8.79152966], [76.66401672, 8.79152966], [76.66401672, 8.79181004], [76.66374969, 8.79181004], [76.66374969, 8.79263973], [76.66348267, 8.79263973], [76.66348267, 8.79292011], [76.66319275, 8.7929163], [76.66319275, 8.79319382], [76.66291809, 8.79319382], [76.66291809, 8.79347229], [76.6626358, 8.79347038], [76.6626358, 8.79403019], [76.66236115, 8.79403019], [76.66236115, 8.79431057], [76.6618042, 8.7943058], [76.6618042, 8.79458427], [76.66124725, 8.79458427], [76.66124725, 8.79485989], [76.6609726, 8.79485989], [76.6609726, 8.79514027], [76.66042328, 8.79514027], [76.66042328, 8.79542065], [76.66014099, 8.79541588], [76.66014099, 8.79597187], [76.6598587, 8.79597187], [76.6598587, 8.79625034], [76.65957642, 8.79625034], [76.65957642, 8.79763985], [76.65931702, 8.79763985], [76.65930176, 8.79792118], [76.6590271, 8.79791641], [76.6590271, 8.79819393], [76.65875244, 8.79819393], [76.65875244, 8.7984724], [76.65847015, 8.79846954], [76.65847015, 8.79903126], [76.6581955, 8.7990284], [76.6581955, 8.79958534], [76.65791321, 8.79958534], [76.65791321, 8.79986], [76.65763855, 8.79986], [76.65763855, 8.80014133], [76.6570816, 8.80014133], [76.6570816, 8.80041885], [76.65680695, 8.80041599], [76.65680695, 8.80069447], [76.65625, 8.80069447], [76.65625, 8.80125141], [76.65598297, 8.80125141], [76.65598297, 8.80153084], [76.65569305, 8.80152893], [76.65569305, 8.80208206], [76.6554184, 8.80207062], [76.6554184, 8.80264091], [76.65513611, 8.80263901], [76.65513611, 8.803195], [76.65486145, 8.803195], [76.65486145, 8.80347347], [76.65458679, 8.80346966], [76.65458679, 8.80375099], [76.65429688, 8.80375099], [76.65429688, 8.80403137], [76.65402985, 8.80403137], [76.65402985, 8.80430889], [76.65374756, 8.80430698], [76.65374756, 8.80486107], [76.6534729, 8.80486107], [76.6534729, 8.80513859], [76.65319061, 8.80513191], [76.65319061, 8.80542088], [76.65291595, 8.80541706], [76.65291595, 8.80597305], [76.65235901, 8.80597115], [76.65235901, 8.80653095], [76.65207672, 8.80653095], [76.65207672, 8.80680943], [76.65180206, 8.80680466], [76.65180206, 8.80708313], [76.6515274, 8.80708313], [76.6515274, 8.80736065], [76.65097046, 8.80736065], [76.65097046, 8.80764103], [76.6506958, 8.80764103], [76.6506958, 8.80791855], [76.65040588, 8.80791855], [76.65040588, 8.80875111], [76.65013123, 8.80875111], [76.65013123, 8.80903244], [76.6498642, 8.80902672], [76.6498642, 8.80958271], [76.64930725, 8.80958271], [76.64930725, 8.80986118], [76.64901733, 8.80986118], [76.64901733, 8.81014156], [76.64875031, 8.8101387], [76.64875031, 8.81069469], [76.64847565, 8.81069469], [76.64847565, 8.81097126], [76.64819336, 8.81097126], [76.64819336, 8.81208324], [76.6479187, 8.81208324], [76.6479187, 8.81347084], [76.64763641, 8.81347084], [76.64763641, 8.81402969], [76.64736176, 8.81402683], [76.64736176, 8.81458378], [76.6470871, 8.81458092], [76.6470871, 8.81513977], [76.64679718, 8.81513977], [76.64679718, 8.81542015], [76.64653015, 8.81541538], [76.64653015, 8.81624985], [76.64624786, 8.81624985], [76.64624786, 8.81653023], [76.64597321, 8.81653023], [76.64597321, 8.8176403], [76.64569092, 8.8176403], [76.64569092, 8.81791973], [76.6451416, 8.81791782], [76.6451416, 8.81847191], [76.64485931, 8.81847191], [76.64485931, 8.81875038], [76.64457703, 8.81875038], [76.64457703, 8.81931019], [76.64430237, 8.81930637], [76.64430237, 8.81958389], [76.64402771, 8.81958389], [76.64402771, 8.81986237], [76.64375305, 8.81986046], [76.64375305, 8.82042027], [76.64347076, 8.82041645], [76.64347076, 8.82097244], [76.64319611, 8.82096958], [76.64319611, 8.82124996], [76.64290619, 8.82124996], [76.64291382, 8.82236004], [76.64263916, 8.82236004], [76.64263916, 8.82264042], [76.64235687, 8.82264042], [76.64235687, 8.82320118], [76.64180756, 8.82319355], [76.64180756, 8.82374954], [76.6415329, 8.82374954], [76.6415329, 8.82431126], [76.64125061, 8.82430553], [76.64125061, 8.8245821], [76.64097595, 8.8245821], [76.64097595, 8.82486153], [76.64068604, 8.82485962], [76.64068604, 8.82514], [76.64041901, 8.82513809], [76.64041901, 8.82569408], [76.64013672, 8.82569408], [76.64013672, 8.8259716], [76.63957977, 8.8259697], [76.63957977, 8.82625961], [76.63931274, 8.82625961], [76.63931274, 8.82653141], [76.63903046, 8.8265276], [76.63903046, 8.82708454], [76.63874817, 8.82708454], [76.63874817, 8.82736015], [76.63846588, 8.82736015], [76.63846588, 8.82792091], [76.63819122, 8.82791615], [76.63819122, 8.82819462], [76.63764191, 8.82818985], [76.63764191, 8.82903099], [76.63735962, 8.82902908], [76.63735962, 8.8293066], [76.63708496, 8.8293066], [76.63708496, 8.82958317], [76.63652802, 8.82958317], [76.63652802, 8.82986069], [76.63625336, 8.82986069], [76.63625336, 8.83069515], [76.63597107, 8.83069515], [76.63597107, 8.83097267], [76.63569641, 8.83097267], [76.63569641, 8.83125114], [76.63514709, 8.83125114], [76.63514709, 8.8318119], [76.63486481, 8.83180523], [76.63486481, 8.83208275], [76.63458252, 8.83208275], [76.63458252, 8.83236122], [76.63430786, 8.83236122], [76.63430786, 8.83319473], [76.63402557, 8.83319473], [76.63402557, 8.83347321], [76.63375092, 8.8334713], [76.63375092, 8.83375072], [76.63346863, 8.83375072], [76.63346863, 8.8340292], [76.63318634, 8.8340292], [76.63318634, 8.83430862], [76.63291931, 8.83430481], [76.63291931, 8.83458328], [76.63263702, 8.83458138], [76.63263702, 8.83514118], [76.63208008, 8.83513927], [76.63208008, 8.83569527], [76.63180542, 8.83569527], [76.63180542, 8.83625126], [76.63153076, 8.83625126], [76.63153076, 8.83653164], [76.63097382, 8.83652687], [76.63097382, 8.83708286], [76.63069153, 8.83708286], [76.63069153, 8.83736134], [76.63041687, 8.83736134], [76.63041687, 8.83764172], [76.63014221, 8.83764172], [76.63014221, 8.83792019], [76.6295929, 8.83792019], [76.6295929, 8.83819962], [76.62930298, 8.83819962], [76.62930298, 8.83875084], [76.62902069, 8.83875084], [76.62902069, 8.83903027], [76.62874603, 8.83903027], [76.62874603, 8.83930969], [76.62847137, 8.83930492], [76.62847137, 8.83986092], [76.62819672, 8.83986092], [76.62819672, 8.84013939], [76.62791443, 8.84013939], [76.62791443, 8.84069347], [76.62735748, 8.84069347], [76.62735748, 8.84097099], [76.62708282, 8.84097099], [76.62708282, 8.84124947], [76.62680817, 8.84123993], [76.62680817, 8.84152985], [76.62652588, 8.84152699], [76.62652588, 8.84208393], [76.62625122, 8.84208393], [76.62625122, 8.8423624], [76.6259613, 8.84235859], [76.6259613, 8.84264183], [76.62568665, 8.84264183], [76.62568665, 8.8429203], [76.62513733, 8.84291458], [76.62513733, 8.84319401], [76.62486267, 8.84319115], [76.62486267, 8.84375191], [76.62458038, 8.84375191], [76.62458038, 8.84403038], [76.62430573, 8.84402847], [76.62430573, 8.84430599], [76.62374878, 8.84430599], [76.62374878, 8.84486198], [76.62319183, 8.84486198], [76.62319183, 8.84542274], [76.62264252, 8.84541798], [76.62264252, 8.84597206], [76.62236023, 8.84597015], [76.62236023, 8.84652996], [76.6220932, 8.84652996], [76.6220932, 8.84681129], [76.62152863, 8.84680557], [76.62152863, 8.84708405], [76.62124634, 8.84707928], [76.62124634, 8.84764004], [76.62097168, 8.84764004], [76.62097168, 8.84792042], [76.62069702, 8.84791565], [76.62069702, 8.84819412], [76.62041473, 8.84819412], [76.62041473, 8.84847164], [76.62014771, 8.84846973], [76.62014771, 8.84902954], [76.61985779, 8.84902954], [76.61985779, 8.84931087], [76.61958313, 8.84930611], [76.61958313, 8.8498621], [76.61930847, 8.84986019], [76.61930847, 8.85042953], [76.61902618, 8.85041618], [76.61902618, 8.8506937], [76.61875153, 8.8506937], [76.61875153, 8.85097218], [76.61818695, 8.85097027], [76.61818695, 8.85124969], [76.61791992, 8.85124969], [76.61791992, 8.85153103], [76.61736298, 8.85152817], [76.61736298, 8.85208225], [76.61708069, 8.85208225], [76.61708069, 8.85235977], [76.61680603, 8.85235977], [76.61680603, 8.85264111], [76.61653137, 8.85264111], [76.61653137, 8.85292053], [76.61624908, 8.85291576], [76.61624908, 8.85319424], [76.61597443, 8.85319424], [76.61597443, 8.85347176], [76.61541748, 8.85347176], [76.61541748, 8.85375023], [76.61514282, 8.85375023], [76.61514282, 8.85431099], [76.61458588, 8.85430431], [76.61458588, 8.85486031], [76.61429596, 8.85486031], [76.61429596, 8.85514069], [76.61402893, 8.85513783], [76.61402893, 8.85569477], [76.61347198, 8.85569477], [76.61347198, 8.85597324], [76.61319733, 8.85597324], [76.61319733, 8.85625076], [76.61292267, 8.85623932], [76.61292267, 8.85653114], [76.61264038, 8.85653114], [76.61264038, 8.85681057], [76.61235809, 8.85680676], [76.61235809, 8.85708332], [76.61207581, 8.85708046], [76.61208344, 8.85736084], [76.61180878, 8.85736084], [76.61180878, 8.85764122], [76.61152649, 8.85764122], [76.61152649, 8.85792065], [76.61125183, 8.85791683], [76.61125183, 8.8581953], [76.61069489, 8.8581953], [76.61069489, 8.85847282], [76.61042023, 8.85847282], [76.61042023, 8.8587513], [76.61013794, 8.8587513], [76.61013794, 8.85903072], [76.60986328, 8.85903072], [76.60986328, 8.8593092], [76.60958099, 8.85930538], [76.60958099, 8.8595829], [76.60930634, 8.8595829], [76.60930634, 8.85986137], [76.60901642, 8.85986137], [76.60901642, 8.86041927], [76.60874939, 8.86041737], [76.60874939, 8.86069489], [76.60819244, 8.86069012], [76.60819244, 8.86125088], [76.60764313, 8.86125088], [76.60764313, 8.86181164], [76.60736084, 8.86180496], [76.60736084, 8.86208344], [76.60708618, 8.86208057], [76.60708618, 8.86236954], [76.60679626, 8.86236954], [76.60679626, 8.86264133], [76.60624695, 8.86264133], [76.60624695, 8.86292171], [76.60597229, 8.86292171], [76.60597229, 8.86264133], [76.60569763, 8.86264133], [76.60569763, 8.86292171], [76.60514069, 8.86291695], [76.60514069, 8.86319542], [76.60485077, 8.86319065], [76.6048584, 8.86375141], [76.60430908, 8.86375141], [76.60430908, 8.86403179], [76.60402679, 8.86403179], [76.60402679, 8.86431026], [76.60375214, 8.86430454], [76.60375214, 8.86486053], [76.60320282, 8.86486053], [76.60320282, 8.86514187], [76.6029129, 8.86513901], [76.6029129, 8.86541653], [76.60263824, 8.86541653], [76.60263824, 8.86569309], [76.60236359, 8.86569309], [76.60236359, 8.86597347], [76.6020813, 8.86597061], [76.6020813, 8.86625195], [76.60180664, 8.86625195], [76.60180664, 8.86653042], [76.60124969, 8.86653042], [76.60124969, 8.86680984], [76.60097504, 8.86680508], [76.60097504, 8.8670826], [76.60069275, 8.8670826], [76.60069275, 8.86736107], [76.6001358, 8.86736107], [76.6001358, 8.86763954], [76.59986115, 8.86763954], [76.59986115, 8.86791992], [76.5993042, 8.86791801], [76.5993042, 8.86819553], [76.59874725, 8.86818027], [76.59874725, 8.86874866], [76.5984726, 8.86874866], [76.5984726, 8.86903191], [76.59819794, 8.86902809], [76.59819794, 8.86958408], [76.59791565, 8.86958408], [76.59791565, 8.8698616], [76.59707642, 8.8698616], [76.59707642, 8.87014198], [76.5965271, 8.87014198], [76.5965271, 8.87042046], [76.59625244, 8.87041569], [76.59625244, 8.87097168], [76.5956955, 8.87097168], [76.5956955, 8.87125015], [76.59513855, 8.87125015], [76.59513855, 8.87154102], [76.59485626, 8.87154102], [76.59485626, 8.87180996], [76.5945816, 8.87180614], [76.5945816, 8.87236214], [76.59430695, 8.87236023], [76.59430695, 8.87263966], [76.59402466, 8.87263775], [76.59402466, 8.87319374], [76.59375, 8.87319374], [76.59375, 8.87347221], [76.59348297, 8.87347031], [76.59348297, 8.87374973], [76.59263611, 8.87374973], [76.59263611, 8.87403011], [76.59236145, 8.87403011], [76.59236145, 8.87431145], [76.5918045, 8.87430573], [76.5918045, 8.8745842], [76.5909729, 8.87458038], [76.5909729, 8.87486172], [76.59041595, 8.87486172], [76.59041595, 8.87514019], [76.58985138, 8.87514019], [76.58985138, 8.87542057], [76.58930206, 8.8754158], [76.58930206, 8.87569427], [76.5890274, 8.87569427], [76.5890274, 8.87597179], [76.58875275, 8.87597179], [76.58875275, 8.87625027], [76.58847046, 8.87625027], [76.58847046, 8.87652969], [76.58763885, 8.87652969], [76.58763885, 8.87681103], [76.58708191, 8.87680626], [76.58708191, 8.87708378], [76.58652496, 8.87708378], [76.58652496, 8.87736225], [76.58625031, 8.87735081], [76.58625031, 8.87763977], [76.58569336, 8.87763977], [76.58569336, 8.8779211], [76.5854187, 8.87791634], [76.5854187, 8.87819386], [76.58486176, 8.87819386], [76.58486176, 8.87847233], [76.5845871, 8.87847233], [76.5845871, 8.87874985], [76.58403778, 8.87874985], [76.58403778, 8.87903118], [76.58347321, 8.87903118], [76.58347321, 8.87931061], [76.58319092, 8.87930584], [76.58319092, 8.87958431], [76.5826416, 8.87958431], [76.5826416, 8.87985992], [76.58207703, 8.87985992], [76.58207703, 8.88014126], [76.58152771, 8.8801384], [76.58152771, 8.88041592], [76.58097076, 8.88041592], [76.58097076, 8.88069439], [76.5798645, 8.88069439], [76.5798645, 8.88097191], [76.57930756, 8.88097191], [76.57930756, 8.88125134], [76.57818604, 8.88125134], [76.57818604, 8.88152885], [76.57707977, 8.88152885], [76.57707977, 8.88181114], [76.57597351, 8.88180447], [76.57597351, 8.88208199], [76.57402802, 8.88208199], [76.57402802, 8.88236046], [76.57152557, 8.88236046], [76.57152557, 8.88208199], [76.57096863, 8.88208199], [76.57096863, 8.88180447], [76.57041931, 8.88181114], [76.57041931, 8.88152885], [76.56958008, 8.88152885], [76.56958008, 8.88125134], [76.56930542, 8.88125134], [76.56930542, 8.88097191], [76.56903076, 8.88097191], [76.56903076, 8.88069439], [76.56847382, 8.88069439], [76.56847382, 8.88041592], [76.56791687, 8.88041592], [76.56791687, 8.87985992], [76.56819153, 8.87985992], [76.56819153, 8.87930584], [76.56846619, 8.87931061], [76.56846619, 8.87903118], [76.56903076, 8.87903118], [76.56903076, 8.87874985], [76.56930542, 8.87874985], [76.56930542, 8.87847233], [76.56958008, 8.87847233], [76.56958008, 8.87819386], [76.56986237, 8.87819386], [76.56986237, 8.87791634], [76.57013702, 8.8779211], [76.57013702, 8.87763977], [76.57068634, 8.87763977], [76.57068634, 8.87735081], [76.57096863, 8.87736225], [76.57096863, 8.87708378], [76.57236481, 8.87708378], [76.57236481, 8.87680626], [76.57290649, 8.87681103], [76.57290649, 8.87652969], [76.57319641, 8.87652969], [76.57319641, 8.87625027], [76.57375336, 8.87625027], [76.57375336, 8.87597179], [76.57430267, 8.87597179], [76.57430267, 8.87569427], [76.57541656, 8.87569427], [76.57541656, 8.8754158], [76.57624817, 8.87542057], [76.57624817, 8.87514019], [76.57707977, 8.87514019], [76.57707977, 8.87486172], [76.57763672, 8.87486172], [76.57763672, 8.87458038], [76.57791901, 8.8745842], [76.57791901, 8.87430573], [76.57818604, 8.87431145], [76.57818604, 8.87403011], [76.5790329, 8.87403011], [76.5790329, 8.87374973], [76.57985687, 8.87374973], [76.57985687, 8.87347031], [76.58041382, 8.87347221], [76.58041382, 8.87319374], [76.58069611, 8.87319374], [76.58069611, 8.87291622], [76.58097076, 8.87292004], [76.58097076, 8.87263966], [76.58235931, 8.87263966], [76.58235931, 8.87236023], [76.5826416, 8.87236214], [76.5826416, 8.87208366], [76.58291626, 8.87208366], [76.58291626, 8.87180614], [76.58319092, 8.87180996], [76.58319092, 8.87154102], [76.58347321, 8.87154102], [76.58347321, 8.87014198], [76.5826416, 8.87014198], [76.5826416, 8.87042046], [76.58208466, 8.87041569], [76.58208466, 8.87069416], [76.58180237, 8.87069416], [76.58180237, 8.87097168], [76.58152771, 8.87097168], [76.58152771, 8.87125015], [76.58125305, 8.87125015], [76.58125305, 8.87154102], [76.58097076, 8.87154102], [76.58097076, 8.87180996], [76.58041382, 8.87180614], [76.58041382, 8.87208366], [76.58013916, 8.87208366], [76.58013916, 8.87236214], [76.57985687, 8.87236023], [76.57985687, 8.87263966], [76.57930756, 8.87263966], [76.57930756, 8.87292004], [76.57875061, 8.87291622], [76.57875061, 8.87319374], [76.57736206, 8.87319374], [76.57736206, 8.87347221], [76.57681274, 8.87347031], [76.57681274, 8.87374973], [76.57624817, 8.87374973], [76.57624817, 8.87403011], [76.57569122, 8.87402821], [76.57569122, 8.8745842], [76.57514191, 8.87458038], [76.57514191, 8.87486172], [76.57402802, 8.87486172], [76.57402802, 8.87514019], [76.57347107, 8.87514019], [76.57347107, 8.87542057], [76.57291412, 8.8754158], [76.57291412, 8.87569427], [76.57236481, 8.87569427], [76.57236481, 8.87597179], [76.57125092, 8.87596989], [76.57125092, 8.87652969], [76.57096863, 8.87652969], [76.57096863, 8.87681103], [76.56986237, 8.87680626], [76.56986237, 8.87708378], [76.56930542, 8.87708378], [76.56930542, 8.87736225], [76.56903076, 8.87735081], [76.56903076, 8.87763977], [76.56874847, 8.87763977], [76.56874847, 8.8779211], [76.56847382, 8.87791634], [76.56847382, 8.87819386], [76.56819153, 8.87819386], [76.56819153, 8.87847233], [76.56791687, 8.87847233], [76.56791687, 8.87874985], [76.56764221, 8.87874985], [76.56764221, 8.87903118], [76.56735992, 8.87903118], [76.56735992, 8.87931061], [76.56597137, 8.87930584], [76.56597137, 8.87958431], [76.5654068, 8.87957954], [76.5654068, 8.88014126], [76.56513977, 8.8801384], [76.56513977, 8.88069439], [76.56485748, 8.88068962], [76.56485748, 8.88152885], [76.56458282, 8.88152885], [76.56458282, 8.88208199], [76.56430817, 8.88208199], [76.56430817, 8.88236046], [76.56402588, 8.88236046], [76.56402588, 8.88264084], [76.56375122, 8.88264084], [76.56375122, 8.88292122], [76.56346893, 8.8829174], [76.56346893, 8.88319016], [76.56292725, 8.88320065], [76.56292725, 8.88348198], [76.56263733, 8.88348198], [76.56263733, 8.88375092], [76.56236267, 8.88375092], [76.56236267, 8.88431072], [76.56208038, 8.88431072], [76.56208038, 8.88541889], [76.56181335, 8.88541889], [76.56180573, 8.88624859], [76.56153107, 8.88625145], [76.56153107, 8.88654041], [76.56124878, 8.88652897], [76.56124878, 8.88708305], [76.56097412, 8.88708305], [76.56097412, 8.88736057], [76.56069183, 8.88736057], [76.56069183, 8.88764095], [76.56041718, 8.88764095], [76.56041718, 8.88791943], [76.56014252, 8.88791656], [76.56014252, 8.88819504], [76.55986786, 8.88819122], [76.55986786, 8.88875103], [76.55930328, 8.88875103], [76.55930328, 8.88903236], [76.5579071, 8.88903236], [76.5579071, 8.88931179], [76.55764008, 8.88930511], [76.55764008, 8.88986111], [76.55735779, 8.88986111], [76.55735779, 8.89014053], [76.55708313, 8.89014053], [76.55708313, 8.89042187], [76.55652618, 8.8904171], [76.55652618, 8.89069462], [76.55596924, 8.8906908], [76.55596924, 8.89153194], [76.55568695, 8.89153194], [76.55568695, 8.89181042], [76.55513763, 8.89181042], [76.55513763, 8.89153194], [76.55486298, 8.89152718], [76.55486298, 8.89208317], [76.55458069, 8.89208317], [76.55458069, 8.89236069], [76.55403137, 8.89236069], [76.55403137, 8.89319324], [76.55374146, 8.89319134], [76.55374146, 8.89402962], [76.5534668, 8.89402962], [76.5534668, 8.89431], [76.55319214, 8.89430523], [76.55319214, 8.89458275], [76.55291748, 8.89458084], [76.55291748, 8.89513969], [76.55264282, 8.89513969], [76.55264282, 8.89542007], [76.55236053, 8.89541531], [76.55236053, 8.89569569], [76.55180359, 8.89569569], [76.55180359, 8.8959713], [76.55152893, 8.8959713], [76.55152893, 8.89653015], [76.55124664, 8.89652824], [76.55124664, 8.89708424], [76.55097198, 8.89708138], [76.55097198, 8.89764023], [76.55069733, 8.89764023], [76.55069733, 8.89819431], [76.55042267, 8.89819145], [76.55042267, 8.89848137], [76.55014038, 8.89847183], [76.55014038, 8.89875031], [76.54985809, 8.89875031], [76.54985809, 8.9001379], [76.54958344, 8.9001379], [76.54958344, 8.90069389], [76.54902649, 8.90069389], [76.54902649, 8.90097237], [76.54846954, 8.90097046], [76.54846954, 8.90125179], [76.54792786, 8.90125179], [76.54792786, 8.90154171], [76.54736328, 8.90154171], [76.54736328, 8.90181065], [76.54680634, 8.90180588], [76.54680634, 8.90208435], [76.54651642, 8.90207958], [76.54652405, 8.90235996], [76.54624939, 8.90235996], [76.54624939, 8.9048624], [76.54597473, 8.9048624], [76.54597473, 8.90569401], [76.54569244, 8.90569019], [76.54569244, 8.90625], [76.54541779, 8.90625], [76.54541779, 8.90680885], [76.5451355, 8.90680599], [76.5451355, 8.90736008], [76.54486084, 8.90736008], [76.54486084, 8.90764141], [76.54458618, 8.90764141], [76.54458618, 8.90792084], [76.54430389, 8.90791607], [76.54430389, 8.90847301], [76.54402924, 8.90847015], [76.54402924, 8.90903091], [76.54374695, 8.90902901], [76.54374695, 8.90958214], [76.54347229, 8.90958214], [76.54347229, 8.90986061], [76.54319763, 8.90986061], [76.54319763, 8.91042137], [76.54292297, 8.91042137], [76.54292297, 8.91153145], [76.54264069, 8.91152668], [76.54264069, 8.91236115], [76.5423584, 8.91236115], [76.5423584, 8.91319466], [76.54207611, 8.91318989], [76.54207611, 8.91348171], [76.54180145, 8.91348171], [76.54180145, 8.91486073], [76.54152679, 8.91486073], [76.54152679, 8.91542244], [76.54125214, 8.91542244], [76.54125214, 8.91875076], [76.54096985, 8.91874886], [76.54096985, 8.9206934], [76.54070282, 8.92069054], [76.54070282, 8.92152977], [76.5404129, 8.92152977], [76.5404129, 8.92265129], [76.54070282, 8.92265129], [76.54070282, 8.92292023], [76.5404129, 8.92291546], [76.5404129, 8.92319584], [76.54070282, 8.92319107], [76.54070282, 8.92375183], [76.5404129, 8.92375183], [76.5404129, 8.9240303], [76.54013824, 8.9240303], [76.54013824, 8.92430973], [76.5404129, 8.92430592], [76.5404129, 8.92708397], [76.54013824, 8.9270792], [76.54013824, 8.92763996], [76.53985596, 8.92763996], [76.53985596, 8.92875004], [76.5395813, 8.92875004], [76.5395813, 8.92903042], [76.53930664, 8.92902756], [76.53930664, 8.92957973], [76.53930664, 8.9309721], [76.53902435, 8.9309721], [76.53902435, 8.93152809], [76.53874207, 8.93152142], [76.53874207, 8.93181133], [76.53847504, 8.93180561], [76.53847504, 8.93208218], [76.53819275, 8.93208218], [76.53819275, 8.9323597], [76.5359726, 8.9323597], [76.5359726, 8.93264008], [76.53542328, 8.93264008], [76.53542328, 8.93292141], [76.53514099, 8.93291569], [76.53514099, 8.93347168], [76.53569794, 8.93347168], [76.53569794, 8.93375015], [76.53736115, 8.93375015], [76.53736115, 8.93514061], [76.53679657, 8.93514061], [76.53679657, 8.93542099], [76.53541565, 8.93541622], [76.53541565, 8.93597317], [76.53569794, 8.93597031], [76.53569794, 8.93625069], [76.5359726, 8.93625069], [76.5359726, 8.93653107], [76.53624725, 8.93653107], [76.53624725, 8.93681145], [76.53652954, 8.93680668], [76.53652954, 8.93708324], [76.53679657, 8.93708038], [76.5368042, 8.93875122], [76.53652954, 8.93875122], [76.53652954, 8.93903065], [76.53624725, 8.93902874], [76.53624725, 8.93958282], [76.5359726, 8.93958282], [76.5359726, 8.9398613], [76.53569794, 8.9398613], [76.53569794, 8.94124889], [76.53541565, 8.94124889], [76.53541565, 8.94347095], [76.53514099, 8.94346046], [76.53514099, 8.94431019], [76.5348587, 8.94431019], [76.5348587, 8.94542027], [76.53514099, 8.9454174], [76.53514099, 8.94736099], [76.5348587, 8.94736099], [76.5348587, 8.94791985], [76.53458405, 8.94791794], [76.53458405, 8.94819641], [76.53430939, 8.94819069], [76.53430176, 8.94902992], [76.5340271, 8.94902992], [76.5340271, 8.95014191], [76.53375244, 8.95014191], [76.53375244, 8.95125198], [76.53347015, 8.95125198], [76.53347015, 8.95181274], [76.5331955, 8.95180607], [76.5331955, 8.95263767], [76.53291321, 8.952631], [76.53291321, 8.95403004], [76.53263855, 8.95402813], [76.53263855, 8.95458412], [76.53235626, 8.95457935], [76.53235626, 8.95541954], [76.5320816, 8.95541573], [76.5320816, 8.95597172], [76.53180695, 8.95597172], [76.53180695, 8.95652962], [76.53151703, 8.95652962], [76.53151703, 8.95681095], [76.53180695, 8.95680618], [76.53180695, 8.95736217], [76.53151703, 8.95736027], [76.53151703, 8.95763969], [76.53125, 8.95763779], [76.53125, 8.95819378], [76.53098297, 8.95819187], [76.53098297, 8.95875931], [76.53069305, 8.95874977], [76.53069305, 8.95958233], [76.5304184, 8.95958233], [76.5304184, 8.96125031], [76.53013611, 8.96125031], [76.53013611, 8.96181965], [76.52986145, 8.96180439], [76.52986145, 8.9626379], [76.52958679, 8.9626379], [76.52958679, 8.96347332], [76.52929688, 8.96347046], [76.52929688, 8.96403122], [76.52902985, 8.96403122], [76.52902985, 8.9651413], [76.52874756, 8.96513939], [76.52874756, 8.96625137], [76.5284729, 8.96625137], [76.5284729, 8.96652889], [76.52819824, 8.96652889], [76.52819824, 8.96680927], [76.52791595, 8.96680546], [76.52791595, 8.96819496], [76.5276413, 8.96819496], [76.5276413, 8.96847343], [76.52791595, 8.96847057], [76.52791595, 8.96875095], [76.52819824, 8.96875095], [76.52819824, 8.96958256], [76.5284729, 8.96958256], [76.5284729, 8.96986103], [76.52819824, 8.96986103], [76.52819824, 8.97042179], [76.52791595, 8.97041702], [76.52791595, 8.97097111], [76.5276413, 8.97097111], [76.5276413, 8.97153187], [76.52735901, 8.9715271], [76.52735901, 8.97208309], [76.52707672, 8.97208118], [76.52707672, 8.97264194], [76.52680206, 8.97263908], [76.52680206, 8.9734726], [76.5265274, 8.97347069], [76.5265274, 8.97402954], [76.52625275, 8.97402668], [76.52625275, 8.97569561], [76.52597046, 8.97569561], [76.52597046, 8.97597122], [76.5256958, 8.97596931], [76.5256958, 8.9762516], [76.52597046, 8.9762516], [76.52597046, 8.97653198], [76.5256958, 8.97652817], [76.5256958, 8.97819424], [76.52540588, 8.97819138], [76.52541351, 8.97875023], [76.52513885, 8.97875023], [76.52513885, 8.98013973], [76.52485657, 8.98013973], [76.52485657, 8.98181057], [76.52458191, 8.9818058], [76.52458191, 8.98235989], [76.52430725, 8.98235989], [76.52430725, 8.98292065], [76.52402496, 8.98291588], [76.52402496, 8.98375034], [76.52375793, 8.98375034], [76.52375793, 8.98402977], [76.52402496, 8.98402786], [76.52402496, 8.98458195], [76.52375793, 8.98458195], [76.52375793, 8.98570061], [76.52401733, 8.98570061], [76.52401733, 8.98624992], [76.52375793, 8.98624992], [76.52375793, 8.98681068], [76.52348328, 8.98681068], [76.52348328, 8.98764133], [76.52319336, 8.98764133], [76.52319336, 8.98931122], [76.52347565, 8.98930359], [76.52347565, 8.98958206], [76.52375793, 8.98958015], [76.52375793, 8.99014091], [76.52348328, 8.99014091], [76.52348328, 8.9904213], [76.52319336, 8.99041653], [76.52319336, 8.99097347], [76.52263641, 8.99097347], [76.52263641, 8.99236107], [76.52236176, 8.99236107], [76.52236176, 8.99292088], [76.5220871, 8.99292088], [76.5220871, 8.99403095], [76.52179718, 8.99403095], [76.52179718, 8.99430943], [76.52153015, 8.99430466], [76.52153015, 8.99625111], [76.52124786, 8.99625111], [76.52124786, 9.00013924], [76.52124786, 9.00069332], [76.52097321, 9.00069332], [76.52097321, 9.00097084], [76.52124786, 9.00097084], [76.52124786, 9.00124931], [76.52153015, 9.00124931], [76.52153015, 9.00152969], [76.52179718, 9.00152969], [76.52179718, 9.00181007], [76.5220871, 9.00180531], [76.5220871, 9.00208282], [76.52179718, 9.00208092], [76.52179718, 9.00264168], [76.52153015, 9.00264168], [76.52153015, 9.00292015], [76.52124786, 9.00291538], [76.52124786, 9.00319576], [76.52153015, 9.00319099], [76.52153015, 9.0051403], [76.5220871, 9.0051403], [76.5220871, 9.00541973], [76.52236176, 9.00541782], [76.52236176, 9.00569439], [76.52263641, 9.00569057], [76.52263641, 9.0065279], [76.52236176, 9.0065279], [76.52236176, 9.00597191], [76.5220871, 9.00597191], [76.5220871, 9.00569439], [76.52180481, 9.00569439], [76.52180481, 9.00541782], [76.52069092, 9.00541782], [76.52069092, 9.00597191], [76.52041626, 9.00597191], [76.52041626, 9.0065279], [76.5201416, 9.0065279], [76.5201416, 9.00764179], [76.51985931, 9.00763988], [76.51985931, 9.00847244], [76.51957703, 9.00846958], [76.51957703, 9.00987053], [76.51930237, 9.00987053], [76.51930237, 9.0104208], [76.51902771, 9.01041603], [76.51902771, 9.01069355], [76.51875305, 9.01069164], [76.51875305, 9.01181126], [76.51902771, 9.01180553], [76.51902771, 9.0134716], [76.51875305, 9.0134716], [76.51875305, 9.01486015], [76.51847076, 9.01486015], [76.51847076, 9.01514053], [76.51875305, 9.01514053], [76.51875305, 9.01542091], [76.51847076, 9.01541615], [76.51847076, 9.01569366], [76.51875305, 9.01569366], [76.51875305, 9.01597309], [76.51847076, 9.01597023], [76.51847076, 9.01792145], [76.51875305, 9.01791668], [76.51875305, 9.01847267], [76.51819611, 9.01847267], [76.51819611, 9.01875114], [76.51790619, 9.01875114], [76.51790619, 9.01931095], [76.5173645, 9.01930523], [76.5173645, 9.01958275], [76.51708221, 9.01957989], [76.51708221, 9.02014065], [76.51680756, 9.02014065], [76.51680756, 9.02042103], [76.5165329, 9.02042103], [76.5165329, 9.0215292], [76.51625061, 9.0215292], [76.51625061, 9.02208328], [76.51597595, 9.02208328], [76.51597595, 9.0223608], [76.51541901, 9.0223608], [76.51541901, 9.02292156], [76.51513672, 9.02291679], [76.51513672, 9.02347088], [76.51486206, 9.02347088], [76.51486206, 9.02403164], [76.51457977, 9.02402687], [76.51457977, 9.02458286], [76.51431274, 9.02458096], [76.51431274, 9.02486992], [76.51403046, 9.02486992], [76.51403046, 9.02542019], [76.51374817, 9.02541733], [76.51374817, 9.02569485], [76.51347351, 9.02569485], [76.51347351, 9.02597332], [76.51319122, 9.02597141], [76.51319122, 9.02652931], [76.51291656, 9.0265274], [76.51291656, 9.0270834], [76.51264191, 9.0270834], [76.51264191, 9.02791691], [76.51235962, 9.02791691], [76.51235962, 9.02847099], [76.51207733, 9.02847099], [76.51207733, 9.02902985], [76.51152802, 9.02902985], [76.51152802, 9.02931023], [76.51125336, 9.02930546], [76.51125336, 9.02958393], [76.51097107, 9.02958107], [76.51097107, 9.0304203], [76.51069641, 9.03041458], [76.51069641, 9.03097153], [76.51040649, 9.03097153], [76.51040649, 9.03153038], [76.51013947, 9.03152847], [76.51013947, 9.03236198], [76.50985718, 9.03236198], [76.50985718, 9.03292179], [76.50958252, 9.03291798], [76.50958252, 9.03347206], [76.50930786, 9.0334692], [76.50930786, 9.03404236], [76.5090332, 9.03404236], [76.5090332, 9.03431034], [76.50875854, 9.03431034], [76.50875854, 9.03542042], [76.50846863, 9.03541565], [76.50846863, 9.03708363], [76.50819397, 9.03708363], [76.50819397, 9.0373621], [76.50791931, 9.03736019], [76.50791931, 9.03763962], [76.50763702, 9.03763962], [76.50763702, 9.03792095], [76.50736237, 9.03791618], [76.50736237, 9.03847218], [76.50708008, 9.03847027], [76.50708008, 9.03874969], [76.50681305, 9.03874969], [76.50681305, 9.03903103], [76.50708008, 9.03902817], [76.50708008, 9.03985977], [76.50681305, 9.03985119], [76.50681305, 9.04042053], [76.50653076, 9.04041576], [76.50653076, 9.04097176], [76.50624847, 9.04096985], [76.50624847, 9.04153061], [76.50596619, 9.04153061], [76.50596619, 9.04181099], [76.50569153, 9.04180431], [76.50569153, 9.04236031], [76.50541687, 9.04236031], [76.50541687, 9.04347324], [76.50514221, 9.04347324], [76.50514221, 9.04375076], [76.50541687, 9.0437479], [76.50541687, 9.04403114], [76.50514221, 9.04403114], [76.50514221, 9.04431057], [76.50485992, 9.04431057], [76.50485992, 9.04486275], [76.5045929, 9.04486275], [76.5045929, 9.04542065], [76.50430298, 9.04542065], [76.50430298, 9.04598045], [76.50402832, 9.04597282], [76.50402832, 9.0462513], [76.50374603, 9.0462513], [76.50374603, 9.04653072], [76.50347137, 9.04653072], [76.50347137, 9.04763889], [76.50319672, 9.04763889], [76.50319672, 9.04791927], [76.50291443, 9.04791737], [76.50291443, 9.04847336], [76.50263214, 9.04847145], [76.50263214, 9.04931164], [76.50235748, 9.04931164], [76.50235748, 9.05042171], [76.50208282, 9.05041695], [76.50208282, 9.05097103], [76.50180817, 9.05097103], [76.50180817, 9.05125141], [76.50208282, 9.05125141], [76.50208282, 9.05153179], [76.50180817, 9.05153179], [76.50180817, 9.05181026], [76.50152588, 9.05180454], [76.50152588, 9.05236053], [76.50125122, 9.05236053], [76.50125122, 9.05292034], [76.50096893, 9.05291653], [76.50096893, 9.05319309], [76.50068665, 9.05319118], [76.50068665, 9.05430984], [76.50041962, 9.05430508], [76.50041962, 9.05486107], [76.50013733, 9.05486107], [76.50013733, 9.05569553], [76.49958801, 9.05569077], [76.49958801, 9.05625153], [76.49930573, 9.05624866], [76.49930573, 9.0573616], [76.49903107, 9.0573616], [76.49903107, 9.05792046], [76.49874878, 9.05791759], [76.49874878, 9.05819416], [76.49847412, 9.05819416], [76.49847412, 9.05847168], [76.49819183, 9.05847168], [76.49819183, 9.05958366], [76.49791718, 9.0595789], [76.49791718, 9.06013966], [76.49764252, 9.06013966], [76.49764252, 9.06124973], [76.49736023, 9.06124973], [76.49736023, 9.06181145], [76.4970932, 9.06181145], [76.4970932, 9.06291962], [76.49680328, 9.0629158], [76.49680328, 9.06347179], [76.49652863, 9.06347179], [76.49652863, 9.06375027], [76.49624634, 9.06375027], [76.49624634, 9.06431103], [76.49597168, 9.06430626], [76.49597168, 9.06486225], [76.49569702, 9.06486225], [76.49569702, 9.06569386], [76.4954071, 9.06569195], [76.4954071, 9.06653118], [76.49514008, 9.06653118], [76.49514008, 9.06681061], [76.49485779, 9.06680584], [76.49485779, 9.06735992], [76.49458313, 9.06735992], [76.49458313, 9.06819439], [76.49430847, 9.06819439], [76.49430847, 9.06847191], [76.49402618, 9.06847], [76.49402618, 9.06902885], [76.49375153, 9.06902885], [76.49375153, 9.06931114], [76.49346924, 9.06930447], [76.49346924, 9.06986046], [76.49318695, 9.06986046], [76.49318695, 9.07125092], [76.49291992, 9.07125092], [76.49291992, 9.07181072], [76.49263763, 9.07181072], [76.49263763, 9.07264137], [76.49208069, 9.07264137], [76.49208069, 9.07374859], [76.49180603, 9.07375145], [76.49180603, 9.07458305], [76.49153137, 9.07458019], [76.49153137, 9.07514095], [76.49124908, 9.07513905], [76.49124908, 9.07569504], [76.4909668, 9.07569027], [76.4909668, 9.07625103], [76.49069214, 9.07625103], [76.49069214, 9.07653141], [76.49041748, 9.07653141], [76.49041748, 9.07681179], [76.49014282, 9.07681179], [76.49014282, 9.07764053], [76.48986053, 9.07763863], [76.48986053, 9.07847309], [76.48958588, 9.07847309], [76.48958588, 9.07902718], [76.48930359, 9.07902718], [76.48930359, 9.08069324], [76.48902893, 9.08069324], [76.48902893, 9.08124924], [76.48874664, 9.08124924], [76.48874664, 9.08152962], [76.48847198, 9.08152962], [76.48847198, 9.08209038], [76.48819733, 9.08209038], [76.48819733, 9.08263969], [76.48791504, 9.08263969], [76.48791504, 9.08319569], [76.48764038, 9.08319569], [76.48764038, 9.0834713], [76.48735809, 9.0834713], [76.48735809, 9.08458424], [76.48707581, 9.08458138], [76.48707581, 9.08515072], [76.48680878, 9.08514023], [76.48680878, 9.08569431], [76.48652649, 9.08569145], [76.48652649, 9.08652973], [76.48625183, 9.08652973], [76.48625183, 9.08681011], [76.48596954, 9.0868063], [76.48596954, 9.08736229], [76.48568726, 9.08736038], [76.48568726, 9.08792019], [76.48542023, 9.08792019], [76.48542023, 9.08903027], [76.48513794, 9.08902836], [76.48513794, 9.08958435], [76.48486328, 9.08957863], [76.48486328, 9.09041977], [76.48430634, 9.09041977], [76.48430634, 9.09152985], [76.48402405, 9.09152794], [76.48402405, 9.09208202], [76.48374939, 9.09208202], [76.48374939, 9.09319401], [76.48319244, 9.09319401], [76.48319244, 9.09347153], [76.48291779, 9.09346962], [76.48291779, 9.09403133], [76.4826355, 9.09402847], [76.4826355, 9.09486008], [76.48291779, 9.09486008], [76.48291779, 9.09542084], [76.48264313, 9.09542084], [76.48264313, 9.09514141], [76.48208618, 9.0951376], [76.48208618, 9.09569359], [76.48180389, 9.09569359], [76.48180389, 9.09597206], [76.48152161, 9.09597015], [76.48152161, 9.09653091], [76.48124695, 9.09652901], [76.48124695, 9.09735966], [76.48097229, 9.09735966], [76.48097229, 9.09764099], [76.48069763, 9.09764099], [76.48069763, 9.09792137], [76.48042297, 9.09792137], [76.48042297, 9.09903145], [76.48014069, 9.09902668], [76.48014069, 9.09958267], [76.4798584, 9.09958267], [76.4798584, 9.10013866], [76.47958374, 9.10013866], [76.47958374, 9.10069466], [76.47930908, 9.10068989], [76.47930908, 9.10180855], [76.47902679, 9.10180855], [76.47902679, 9.10236073], [76.47875214, 9.10236073], [76.47875214, 9.1034708], [76.47846985, 9.10347271], [76.47846985, 9.10375118], [76.47820282, 9.10375118], [76.47820282, 9.10431194], [76.4779129, 9.10430527], [76.4779129, 9.10486126], [76.47763824, 9.10486126], [76.47763824, 9.10542202], [76.47736359, 9.10541725], [76.47736359, 9.10569477], [76.4770813, 9.10569096], [76.4770813, 9.10625076], [76.47680664, 9.10625076], [76.47680664, 9.10680962], [76.47651672, 9.10680962], [76.47651672, 9.10736084], [76.47624969, 9.10736084], [76.47624969, 9.10763931], [76.47597504, 9.10763931], [76.47597504, 9.1081953], [76.47569275, 9.1081953], [76.47569275, 9.10847092], [76.47541809, 9.10847092], [76.47541809, 9.10902977], [76.4751358, 9.10902977], [76.4751358, 9.11013985], [76.47458649, 9.11013985], [76.47458649, 9.11125183], [76.47429657, 9.11125183], [76.47429657, 9.1115303], [76.47402954, 9.1115303], [76.47402954, 9.11180973], [76.47374725, 9.11180592], [76.47374725, 9.11208439], [76.4734726, 9.11208439], [76.4734726, 9.11319447], [76.47319794, 9.11319447], [76.47319794, 9.11347198], [76.47292328, 9.11347198], [76.47292328, 9.11403179], [76.47264099, 9.11402798], [76.47264099, 9.11458397], [76.4723587, 9.11458397], [76.4723587, 9.1147089], [76.4723587, 9.11569405], [76.47208405, 9.11569405], [76.47208405, 9.11597157], [76.47180939, 9.11596966], [76.47180176, 9.1168108], [76.4715271, 9.11680603], [76.4715271, 9.11736202], [76.47125244, 9.11736202], [76.47125244, 9.11819363], [76.47097015, 9.11819363], [76.47097015, 9.1184721], [76.47070313, 9.11847019], [76.47070313, 9.11903], [76.47041321, 9.11902809], [76.47041321, 9.11999035], [76.47041321, 9.12014008], [76.47013855, 9.12013817], [76.47013855, 9.12068081], [76.47013855, 9.12097168], [76.47003174, 9.12097168], [76.46986389, 9.12097168], [76.46985626, 9.12137985], [76.46985626, 9.12153053], [76.4695816, 9.12152767], [76.4695816, 9.12208462], [76.46930695, 9.12207985], [76.46930695, 9.12264061], [76.46901703, 9.12264061], [76.46901703, 9.12292099], [76.46875, 9.12291622], [76.46875, 9.12347317], [76.46848297, 9.12347031], [76.46848297, 9.12403107], [76.46819305, 9.12402916], [76.46819305, 9.12458229], [76.4679184, 9.12458229], [76.4679184, 9.12486076], [76.46763611, 9.12486076], [76.46763611, 9.12597275], [76.46736145, 9.12596989], [76.46736145, 9.12653065], [76.46708679, 9.12652874], [76.46708679, 9.1273613], [76.4668045, 9.1273613], [76.4668045, 9.12819481], [76.46652985, 9.12819481], [76.46652985, 9.12847328], [76.46624756, 9.12847137], [76.46624756, 9.12903118], [76.4659729, 9.12902737], [76.4659729, 9.12958336], [76.46569824, 9.12958336], [76.46569824, 9.13013935], [76.46541595, 9.13013935], [76.46541595, 9.13069534], [76.4651413, 9.13069534], [76.4651413, 9.13125134], [76.46485901, 9.13125134], [76.46485901, 9.13181019], [76.46458435, 9.13180542], [76.46458435, 9.13236141], [76.46430206, 9.13236141], [76.46430206, 9.13292027], [76.4640274, 9.13292027], [76.4640274, 9.13319969], [76.46375275, 9.13319969], [76.46375275, 9.13402939], [76.46347809, 9.13402939], [76.46347809, 9.13513947], [76.46736145, 9.13513947], [76.46736145, 9.13541985], [76.4679184, 9.13541698], [76.4679184, 9.13569641], [76.46819305, 9.13569641], [76.46819305, 9.13597107], [76.46848297, 9.13597107], [76.46848297, 9.13653183], [76.4690094, 9.13652992], [76.46930695, 9.13653183], [76.46930695, 9.13626099], [76.46930695, 9.13513947], [76.46901703, 9.13513947], [76.46901703, 9.13486099], [76.46875, 9.13486099], [76.46875, 9.134305], [76.46848297, 9.13430977], [76.46848297, 9.13402939], [76.46819305, 9.13402939], [76.46819305, 9.13375092], [76.4679184, 9.13375092], [76.4679184, 9.13347054], [76.46763611, 9.1334734], [76.46763611, 9.13319492], [76.46708679, 9.13319969], [76.46708679, 9.13292027], [76.46679688, 9.13292027], [76.46679688, 9.13097095], [76.4679184, 9.13097095], [76.4679184, 9.13069534], [76.46930695, 9.13069534], [76.46930695, 9.13041687], [76.47070313, 9.13042164], [76.47070313, 9.13012981], [76.47097015, 9.13013935], [76.47097015, 9.12958336], [76.47125244, 9.12958336], [76.47125244, 9.12902737], [76.4715271, 9.12903118], [76.47154999, 9.12819004], [76.47180176, 9.12819481], [76.47180176, 9.12708282], [76.47208405, 9.12708282], [76.47208405, 9.12652874], [76.47125244, 9.12653065], [76.47125244, 9.12596989], [76.4715271, 9.12597275], [76.4715271, 9.12569523], [76.47264099, 9.12569523], [76.47264099, 9.12430668], [76.4723587, 9.12432003], [76.4723587, 9.12375069], [76.47207642, 9.12375069], [76.47207642, 9.12292099], [76.47264099, 9.12291622], [76.47264099, 9.12347317], [76.47292328, 9.12347031], [76.47292328, 9.12403107], [76.47319794, 9.12402916], [76.47319794, 9.12458229], [76.47651672, 9.12458038], [76.47651672, 9.12542057], [76.47624969, 9.12542057], [76.47624969, 9.12653065], [76.47598267, 9.12653065], [76.47598267, 9.12681103], [76.4734726, 9.12681103], [76.4734726, 9.12764072], [76.47374725, 9.12763882], [76.47374725, 9.12819481], [76.47402954, 9.12819481], [76.47402954, 9.12874889], [76.47429657, 9.12874889], [76.47429657, 9.12931156], [76.47458649, 9.12931156], [76.47458649, 9.13042164], [76.47429657, 9.13042164], [76.47429657, 9.13153172], [76.47486115, 9.13153172], [76.47486115, 9.13125134], [76.47624969, 9.13125134], [76.47624969, 9.13153172], [76.47651672, 9.13153172], [76.47651672, 9.13181019], [76.47680664, 9.13180542], [76.47680664, 9.13208294], [76.4770813, 9.13208294], [76.4770813, 9.1334734], [76.47736359, 9.1334734], [76.47736359, 9.13319302], [76.47763824, 9.13319969], [76.47763824, 9.13264084], [76.4779129, 9.13264084], [76.4779129, 9.13208103], [76.47819519, 9.13208294], [76.47819519, 9.13152695], [76.47846222, 9.13153172], [76.47846222, 9.13097095], [76.47875214, 9.13097095], [76.47875214, 9.12902737], [76.47902679, 9.12903118], [76.47902679, 9.12819004], [76.47930908, 9.12819481], [76.47930908, 9.12763882], [76.47957611, 9.12764072], [76.47957611, 9.12707138], [76.4798584, 9.12708282], [76.4798584, 9.12680531], [76.48042297, 9.12681103], [76.48042297, 9.12625122], [76.48124695, 9.12625122], [76.48124695, 9.12597275], [76.48180389, 9.12597275], [76.48180389, 9.12569523], [76.4826355, 9.12569523], [76.4826355, 9.12597275], [76.48291779, 9.12597275], [76.48291779, 9.12625122], [76.48319244, 9.12625122], [76.48319244, 9.12653065], [76.4834671, 9.12653065], [76.4834671, 9.12681103], [76.48374939, 9.12680531], [76.48374939, 9.1273613], [76.4834671, 9.1273613], [76.4834671, 9.12903118], [76.48319244, 9.12902737], [76.48319244, 9.12958336], [76.4834671, 9.12958145], [76.48347473, 9.12986088], [76.48319244, 9.12986088], [76.48319244, 9.13013935], [76.4834671, 9.13012981], [76.4834671, 9.13181019], [76.48374939, 9.13181019], [76.48374939, 9.13402939], [76.4834671, 9.13402939], [76.4834671, 9.13513947], [76.48319244, 9.13513947], [76.48319244, 9.13708401], [76.48374939, 9.13708401], [76.48374939, 9.13736153], [76.48401642, 9.13736153], [76.48401642, 9.13764191], [76.48430634, 9.13764191], [76.48430634, 9.13792038], [76.48458099, 9.13791847], [76.48458099, 9.13819313], [76.48486328, 9.13819313], [76.48486328, 9.13930607], [76.48458862, 9.1393013], [76.48458862, 9.14013958], [76.48430634, 9.14013958], [76.48430634, 9.14153004], [76.48401642, 9.14153004], [76.48402405, 9.14235973], [76.48374939, 9.14235973], [76.48374939, 9.14291954], [76.48347473, 9.14291573], [76.48347473, 9.1445837], [76.48319244, 9.14458179], [76.48319244, 9.14542961], [76.48347473, 9.14541626], [76.48347473, 9.14597225], [76.48319244, 9.14597225], [76.48319244, 9.14708424], [76.48291779, 9.14708042], [76.48291779, 9.14764023], [76.48264313, 9.14764023], [76.48264313, 9.14792061], [76.48236084, 9.14792061], [76.48236084, 9.14820099], [76.48208618, 9.14819431], [76.48208618, 9.14875031], [76.48236084, 9.14875031], [76.48236084, 9.14903069], [76.48180389, 9.14902782], [76.48180389, 9.14986038], [76.48152924, 9.14986038], [76.48152924, 9.15069485], [76.48124695, 9.15069485], [76.48124695, 9.15125084], [76.48097229, 9.1512394], [76.48097229, 9.15153122], [76.48069763, 9.15152645], [76.48069763, 9.1520834], [76.48041534, 9.1520834], [76.48041534, 9.15375137], [76.48069763, 9.15375137], [76.48069763, 9.15569496], [76.48042297, 9.15569019], [76.48042297, 9.15653133], [76.48014069, 9.15652657], [76.48014069, 9.15708256], [76.4798584, 9.15708256], [76.4798584, 9.15819454], [76.47958374, 9.15819454], [76.47958374, 9.15986061], [76.4798584, 9.15986061], [76.4798584, 9.16014194], [76.48014069, 9.16013908], [76.48014069, 9.16069317], [76.48042297, 9.16069126], [76.48042297, 9.16263866], [76.48014069, 9.16263866], [76.48014069, 9.1637516], [76.4798584, 9.1637516], [76.4798584, 9.16403198], [76.48014069, 9.16403198], [76.48014069, 9.16431046], [76.4798584, 9.16430569], [76.4798584, 9.16458416], [76.48014069, 9.16458416], [76.48014069, 9.16486168], [76.4798584, 9.16486168], [76.4798584, 9.16514015], [76.48014069, 9.16514015], [76.48014069, 9.16569424], [76.48042297, 9.16569138], [76.48042297, 9.16681004], [76.48097229, 9.16680622], [76.48097229, 9.16708374], [76.48180389, 9.16708374], [76.48180389, 9.16736221], [76.48236084, 9.16736031], [76.48236084, 9.16763973], [76.48430634, 9.16763973], [76.48430634, 9.16736031], [76.48486328, 9.16736221], [76.48486328, 9.16708374], [76.48542023, 9.16708374], [76.48542023, 9.16680622], [76.48819733, 9.16680622], [76.48819733, 9.16708374], [76.48847198, 9.16708374], [76.48847198, 9.16736221], [76.48874664, 9.16736031], [76.48874664, 9.16763973], [76.48902893, 9.16763973], [76.48902893, 9.16819382], [76.48930359, 9.16819382], [76.48930359, 9.16847229], [76.48958588, 9.16847229], [76.48958588, 9.16874981], [76.48986053, 9.16874981], [76.48986053, 9.16903019], [76.49013519, 9.16902828], [76.49013519, 9.16958427], [76.49041748, 9.16957855], [76.49041748, 9.17014027], [76.49013519, 9.17014027], [76.49013519, 9.17069435], [76.48847198, 9.17069435], [76.48847198, 9.17041588], [76.48792267, 9.17041969], [76.48792267, 9.17014027], [76.48735809, 9.17014027], [76.48735809, 9.16986179], [76.48680878, 9.16986179], [76.48680878, 9.16957855], [76.48625183, 9.16958427], [76.48625183, 9.1693058], [76.48568726, 9.16930962], [76.48568726, 9.16903019], [76.48513794, 9.16903019], [76.48513794, 9.16874981], [76.48236084, 9.16874981], [76.48236084, 9.16903019], [76.48179626, 9.16903019], [76.48179626, 9.16930962], [76.48152924, 9.1693058], [76.48152924, 9.16958427], [76.48124695, 9.16957855], [76.48124695, 9.16986179], [76.48097229, 9.16986179], [76.48097229, 9.17014027], [76.48069763, 9.17014027], [76.48069763, 9.17069435], [76.48041534, 9.17069435], [76.48041534, 9.17097187], [76.4798584, 9.17097187], [76.4798584, 9.17014027], [76.47957611, 9.17014027], [76.47957611, 9.16930962], [76.47930908, 9.16930962], [76.47930908, 9.16903019], [76.47902679, 9.16903019], [76.47902679, 9.16874981], [76.47846985, 9.16874981], [76.47846985, 9.16847229], [76.47819519, 9.16847229], [76.47819519, 9.1679163], [76.4779129, 9.16792011], [76.4779129, 9.16736031], [76.47680664, 9.16736221], [76.47680664, 9.16708374], [76.47624969, 9.16708374], [76.47624969, 9.16652775], [76.47569275, 9.16652966], [76.47569275, 9.1645813], [76.47541809, 9.16458416], [76.47541809, 9.16402721], [76.47569275, 9.16403198], [76.47569275, 9.16292191], [76.47598267, 9.16292191], [76.47598267, 9.15986061], [76.47624969, 9.15986061], [76.47624969, 9.15874863], [76.47651672, 9.15875053], [76.47651672, 9.15764141], [76.4770813, 9.15764141], [76.4770813, 9.15681171], [76.47735596, 9.15681171], [76.47735596, 9.15653133], [76.47763824, 9.15653133], [76.47763824, 9.15625095], [76.4779129, 9.15625095], [76.4779129, 9.15569019], [76.47819519, 9.15569496], [76.47819519, 9.15513897], [76.47846222, 9.15514088], [76.47846222, 9.15486145], [76.47875214, 9.15486145], [76.47875214, 9.15402889], [76.47846222, 9.15402889], [76.47846222, 9.15318966], [76.47819519, 9.15319538], [76.47819519, 9.15291691], [76.4779129, 9.15292072], [76.4779129, 9.15236092], [76.47763824, 9.15236092], [76.47763824, 9.1520834], [76.47736359, 9.1520834], [76.47736359, 9.14930439], [76.47763824, 9.14931107], [76.47763824, 9.14903069], [76.47735596, 9.14903069], [76.47735596, 9.14875031], [76.47763824, 9.14875031], [76.47763824, 9.14847183], [76.47736359, 9.14847183], [76.47736359, 9.14791584], [76.47680664, 9.14792061], [76.47680664, 9.14735985], [76.47569275, 9.14735985], [76.47569275, 9.14708424], [76.4751358, 9.14708424], [76.4751358, 9.14680576], [76.47486115, 9.14681053], [76.47486115, 9.14624977], [76.47429657, 9.14624977], [76.47429657, 9.14513969], [76.47402954, 9.14513969], [76.47402954, 9.14486027], [76.4743042, 9.14486217], [76.4743042, 9.1445837], [76.47402954, 9.1445837], [76.47402954, 9.14402771], [76.47429657, 9.14402962], [76.47429657, 9.14375019], [76.47402954, 9.14375019], [76.47402954, 9.14347172], [76.4743042, 9.14347172], [76.4743042, 9.1431942], [76.47402954, 9.1431942], [76.47402954, 9.14264011], [76.47374725, 9.14264011], [76.47374725, 9.14235973], [76.4734726, 9.14235973], [76.4734726, 9.14208412], [76.47319794, 9.14208412], [76.47319794, 9.14235973], [76.47291565, 9.14235973], [76.47291565, 9.14208412], [76.4715271, 9.14208412], [76.4715271, 9.14235973], [76.47070313, 9.14235973], [76.47070313, 9.14291954], [76.47041321, 9.14291573], [76.47041321, 9.14375019], [76.47013855, 9.14375019], [76.47013855, 9.1445837], [76.46985626, 9.14458179], [76.46985626, 9.14542961], [76.47041321, 9.14541626], [76.47041321, 9.14569378], [76.47097015, 9.14569378], [76.47097015, 9.14597225], [76.47070313, 9.14597034], [76.47070313, 9.14653111], [76.47041321, 9.14653111], [76.47041321, 9.14681053], [76.46875, 9.14680576], [76.46875, 9.14708424], [76.46858215, 9.14708233], [76.46819305, 9.14708042], [76.46819305, 9.14764023], [76.46848297, 9.14764023], [76.46848297, 9.14792061], [76.46819305, 9.14791584], [76.46819305, 9.14847183], [76.4679184, 9.14847183], [76.4679184, 9.14958191], [76.46763611, 9.14958477], [76.46763611, 9.15069485], [76.46736145, 9.15069485], [76.46736145, 9.15097332], [76.46708679, 9.15097332], [76.46708679, 9.1520834], [76.46736145, 9.15207958], [76.46736145, 9.15625095], [76.46763611, 9.15625095], [76.46763611, 9.15708256], [76.46736145, 9.15708256], [76.46736145, 9.15819454], [76.46708679, 9.15819454], [76.46708679, 9.15847111], [76.46652222, 9.15847111], [76.46652222, 9.15875053], [76.46624756, 9.15875053], [76.46624756, 9.15903187], [76.4659729, 9.1590271], [76.4659729, 9.16069317], [76.46569824, 9.16069317], [76.46569824, 9.1609726], [76.46541595, 9.16097069], [76.46541595, 9.16152954], [76.4651413, 9.16152668], [76.4651413, 9.16208267], [76.46485901, 9.16208267], [76.46485901, 9.16236115], [76.46457672, 9.16235924], [76.46457672, 9.16292191], [76.46430206, 9.16291809], [76.46430206, 9.16319561], [76.4640274, 9.16319561], [76.4640274, 9.16347122], [76.46375275, 9.16347122], [76.46375275, 9.1637516], [76.4631958, 9.1637516], [76.4631958, 9.16403198], [76.46263885, 9.16402721], [76.46263885, 9.16486168], [76.46180725, 9.16486168], [76.46180725, 9.16458416], [76.4604187, 9.16458416], [76.4604187, 9.16486168], [76.45986176, 9.16486168], [76.45986176, 9.16514015], [76.4595871, 9.16514015], [76.4595871, 9.16569424], [76.45930481, 9.16569424], [76.45930481, 9.16597176], [76.45903015, 9.16597366], [76.45903015, 9.16625023], [76.45874786, 9.16623974], [76.45874786, 9.16681004], [76.45847321, 9.16680622], [76.45847321, 9.16708374], [76.45791626, 9.16708088], [76.45791626, 9.16763973], [76.4576416, 9.16763973], [76.4576416, 9.16819382], [76.45791626, 9.16819382], [76.45791626, 9.16874981], [76.4576416, 9.16874981], [76.4576416, 9.16930962], [76.45735931, 9.16930962], [76.45735931, 9.16986179], [76.45707703, 9.16986179], [76.45707703, 9.17041969], [76.45680237, 9.17041588], [76.45680237, 9.17097187], [76.45652771, 9.17097187], [76.45652771, 9.17152977], [76.45625305, 9.17152786], [76.45625305, 9.17208195], [76.45597076, 9.17208195], [76.45597076, 9.17237091], [76.45569611, 9.17237091], [76.45569611, 9.17292118], [76.45540619, 9.17292118], [76.45540619, 9.17374992], [76.45513916, 9.17374992], [76.45513916, 9.17431068], [76.4548645, 9.17430592], [76.4548645, 9.17458439], [76.45458221, 9.17458439], [76.45458221, 9.17541599], [76.45430756, 9.17540932], [76.45430756, 9.17653084], [76.45402527, 9.17652893], [76.45402527, 9.17735958], [76.45375061, 9.17735958], [76.45375061, 9.17847347], [76.45347595, 9.17846966], [76.45347595, 9.17903137], [76.45318604, 9.17903137], [76.45318604, 9.18014145], [76.45291901, 9.18013859], [76.45291901, 9.18069458], [76.45263672, 9.1806879], [76.45263672, 9.18125057], [76.45236206, 9.18125057], [76.45236206, 9.18153954], [76.45207977, 9.18153954], [76.45207977, 9.18180943], [76.45153046, 9.18180466], [76.45153046, 9.18236065], [76.45124817, 9.18236065], [76.45124817, 9.18347263], [76.45069122, 9.18347073], [76.45069122, 9.18403053], [76.45041656, 9.18402672], [76.45041656, 9.18458271], [76.45014191, 9.18458271], [76.45014191, 9.18486118], [76.44985962, 9.18486118], [76.44985962, 9.18542194], [76.44930267, 9.18541718], [76.44930267, 9.18597317], [76.44902802, 9.18597126], [76.44902802, 9.18653202], [76.44875336, 9.18653202], [76.44875336, 9.18680954], [76.4484787, 9.18680954], [76.4484787, 9.18763924], [76.44819641, 9.18763924], [76.44819641, 9.18847084], [76.44790649, 9.18847084], [76.44790649, 9.18902969], [76.44763947, 9.18902683], [76.44763947, 9.18958282], [76.44735718, 9.18958092], [76.44735718, 9.19014168], [76.44708252, 9.19013977], [76.44708252, 9.19069576], [76.44680786, 9.19069576], [76.44680786, 9.19097137], [76.44652557, 9.19097137], [76.44652557, 9.19124889], [76.44625092, 9.19124889], [76.44625092, 9.19208431], [76.44596863, 9.19208145], [76.44596863, 9.1926403], [76.44568634, 9.1926403], [76.44568634, 9.19348145], [76.44541931, 9.19347191], [76.44541931, 9.19375038], [76.44513702, 9.19375038], [76.44513702, 9.19458389], [76.44486237, 9.19458199], [76.44486237, 9.19514179], [76.44458008, 9.19513988], [76.44458008, 9.19569397], [76.44430542, 9.19569588], [76.44430542, 9.19597244], [76.44403076, 9.19596958], [76.44403076, 9.19681072], [76.44374847, 9.19680595], [76.44374847, 9.19736195], [76.44347382, 9.19736195], [76.44347382, 9.19819355], [76.44319153, 9.19819164], [76.44319153, 9.19931126], [76.44291687, 9.19930553], [76.44291687, 9.19986153], [76.44264221, 9.19985962], [76.44264221, 9.20042133], [76.44235229, 9.20042133], [76.44235229, 9.20153141], [76.44208527, 9.2015276], [76.44208527, 9.20236015], [76.44180298, 9.20235062], [76.44180298, 9.20264053], [76.44208527, 9.20263767], [76.44208527, 9.20319366], [76.44180298, 9.20319366], [76.44180298, 9.20458221], [76.44152832, 9.20458031], [76.44152832, 9.20681095], [76.44125366, 9.20680523], [76.44125366, 9.20708275], [76.44152832, 9.20708275], [76.44152832, 9.20736122], [76.44124603, 9.20736122], [76.44124603, 9.20848179], [76.44097137, 9.20847321], [76.44097137, 9.2098608], [76.44069672, 9.2098608], [76.44069672, 9.21069527], [76.4404068, 9.21068954], [76.4404068, 9.21154118], [76.44013977, 9.21152687], [76.44013977, 9.21208286], [76.43985748, 9.21208286], [76.43985748, 9.21319485], [76.44013977, 9.21319485], [76.44013977, 9.21347332], [76.44069672, 9.21347141], [76.44069672, 9.21430969], [76.4404068, 9.21430969], [76.4404068, 9.21541977], [76.44013977, 9.21541977], [76.44013977, 9.21652985], [76.43985748, 9.21652699], [76.43985748, 9.2173624], [76.43958282, 9.2173624], [76.43958282, 9.21819305], [76.43930817, 9.21819305], [76.43930817, 9.21958447], [76.43958282, 9.21958065], [76.43958282, 9.22375202], [76.43985748, 9.22375202], [76.43985748, 9.22513962], [76.44013977, 9.22513962], [76.44013977, 9.22624969], [76.4404068, 9.22624969], [76.4404068, 9.23042107], [76.44013977, 9.2304163], [76.44013977, 9.23069382], [76.43958282, 9.23069382], [76.43958282, 9.23097324], [76.43819427, 9.23097324], [76.43819427, 9.23069382], [76.43708038, 9.23069382], [76.43708038, 9.23097324], [76.43624878, 9.23097324], [76.43624878, 9.23069382], [76.43541718, 9.23069382], [76.43541718, 9.2304163], [76.43152618, 9.2304163], [76.43152618, 9.23069382], [76.43125153, 9.23069382], [76.43125153, 9.23125076], [76.43096924, 9.2312479], [76.43096924, 9.23181057], [76.43069458, 9.23180676], [76.43069458, 9.23208237], [76.43041229, 9.23208046], [76.43041229, 9.2326498], [76.43013763, 9.2326498], [76.43013763, 9.23292065], [76.42986298, 9.23291683], [76.42986298, 9.2331953], [76.42903137, 9.2331953], [76.42903137, 9.23347282], [76.42874908, 9.23347282], [76.42874908, 9.23486137], [76.42847443, 9.23486137], [76.42847443, 9.23597336], [76.42819214, 9.23597145], [76.42819214, 9.23653126], [76.42791748, 9.23653126], [76.42791748, 9.23681164], [76.42763519, 9.23680496], [76.42764282, 9.23736095], [76.42735291, 9.23736095], [76.42735291, 9.23792171], [76.42708588, 9.23791695], [76.42708588, 9.23847103], [76.42680359, 9.23847103], [76.42680359, 9.23958302], [76.42652893, 9.23958111], [76.42652893, 9.24014091], [76.42624664, 9.24013901], [76.42624664, 9.24069309], [76.42597198, 9.24069118], [76.42597198, 9.24125099], [76.42569733, 9.24125099], [76.42569733, 9.24180984], [76.42541504, 9.24180508], [76.42541504, 9.24236107], [76.42514038, 9.24236107], [76.42514038, 9.24291992], [76.42485809, 9.24291706], [76.42485809, 9.24319553], [76.42457581, 9.24319077], [76.42457581, 9.24375153], [76.42430878, 9.24375153], [76.42430878, 9.24431038], [76.42402649, 9.24430466], [76.42402649, 9.2448616], [76.42375183, 9.2448616], [76.42375183, 9.24514198], [76.42346954, 9.24514198], [76.42346954, 9.24542046], [76.42319489, 9.24541759], [76.42319489, 9.24569321], [76.42263794, 9.24569321], [76.42263794, 9.24514008], [76.42236328, 9.24514198], [76.42236328, 9.2448616], [76.42208099, 9.2448616], [76.42208099, 9.24430466], [76.42180634, 9.24431038], [76.42180634, 9.24375153], [76.42124939, 9.24375153], [76.42124939, 9.24319077], [76.42097473, 9.24319553], [76.42097473, 9.24236107], [76.42069244, 9.24236107], [76.42069244, 9.2415266], [76.42097473, 9.2415266], [76.42097473, 9.24097347], [76.42124939, 9.24097347], [76.42124939, 9.24041653], [76.42151642, 9.24042034], [76.42151642, 9.24014091], [76.42180634, 9.24014091], [76.42180634, 9.23958111], [76.42208099, 9.23958302], [76.42208099, 9.23930454], [76.42236328, 9.23931026], [76.42236328, 9.23875141], [76.42263794, 9.23874855], [76.42263794, 9.23845863], [76.42292023, 9.23847103], [76.42292023, 9.23791695], [76.42318726, 9.23792171], [76.42318726, 9.23743153], [76.42346954, 9.23736095], [76.42346954, 9.23715115], [76.42346954, 9.23680496], [76.42375183, 9.23681164], [76.42375183, 9.23625088], [76.42402649, 9.23625088], [76.42402649, 9.23569012], [76.42430878, 9.23569489], [76.42430878, 9.23513889], [76.42457581, 9.23513889], [76.42457581, 9.23458004], [76.42485809, 9.2345829], [76.42485809, 9.23402882], [76.42514038, 9.23403072], [76.42514038, 9.23346996], [76.42541504, 9.23347282], [76.42541504, 9.23291683], [76.42569733, 9.23292065], [76.42569733, 9.23236275], [76.42597198, 9.23236275], [76.42597198, 9.23208046], [76.42624664, 9.23208237], [76.42624664, 9.23152637], [76.42652893, 9.23153114], [76.42652893, 9.2312479], [76.42680359, 9.23125076], [76.42680359, 9.23097324], [76.42708588, 9.23097324], [76.42708588, 9.2304163], [76.42735291, 9.23042107], [76.42735291, 9.23014069], [76.42764282, 9.23014069], [76.42764282, 9.22986031], [76.42791748, 9.22986031], [76.42791748, 9.22930431], [76.42819214, 9.22931099], [76.42819214, 9.22875023], [76.42847443, 9.22875023], [76.4284668, 9.22819042], [76.42874908, 9.22819424], [76.42874908, 9.22800064], [76.42874908, 9.22763824], [76.42903137, 9.22764015], [76.42903137, 9.22708035], [76.42930603, 9.22708416], [76.42930603, 9.22652817], [76.42958069, 9.22652817], [76.42958069, 9.22597218], [76.42986298, 9.22597218], [76.42986298, 9.2256937], [76.43013763, 9.2256937], [76.43013763, 9.22541809], [76.43041229, 9.22542095], [76.43041229, 9.22513962], [76.43068695, 9.22513962], [76.43068695, 9.22457981], [76.43096924, 9.22458363], [76.43096924, 9.22430611], [76.43068695, 9.22431087], [76.43068695, 9.22402954], [76.43096924, 9.22402954], [76.43096924, 9.22292042], [76.43125153, 9.22292042], [76.43125153, 9.22207928], [76.43152618, 9.22208405], [76.43152618, 9.22180557], [76.43180847, 9.22181034], [76.43180847, 9.22124958], [76.43208313, 9.22124958], [76.43208313, 9.22042179], [76.43180847, 9.22042179], [76.43180847, 9.22014046], [76.43152618, 9.22014046], [76.43152618, 9.2193079], [76.43180847, 9.2193079], [76.43180847, 9.21903038], [76.43208313, 9.21903038], [76.43208313, 9.21875191], [76.43235779, 9.21875191], [76.43235779, 9.21819115], [76.43264008, 9.21819305], [76.43264008, 9.21763992], [76.4329071, 9.21764183], [76.4329071, 9.2173624], [76.43319702, 9.2173624], [76.43319702, 9.21680546], [76.43347931, 9.21681023], [76.43347931, 9.21624947], [76.43374634, 9.21624947], [76.43374634, 9.21569538], [76.43402863, 9.21569538], [76.43402863, 9.21513939], [76.43430328, 9.21513939], [76.43430328, 9.21458054], [76.43458557, 9.2145834], [76.43458557, 9.2140274], [76.43486023, 9.21402931], [76.43486023, 9.21319103], [76.43514252, 9.21319485], [76.43514252, 9.21236134], [76.43541718, 9.21236134], [76.43541718, 9.21180534], [76.43569183, 9.21181202], [76.43569183, 9.21125126], [76.43597412, 9.21125126], [76.43596649, 9.21042156], [76.43624878, 9.21042156], [76.43624878, 9.20958138], [76.43597412, 9.20958328], [76.43597412, 9.20874882], [76.43624878, 9.20875072], [76.43624878, 9.20848179], [76.43596649, 9.20848179], [76.43596649, 9.20818996], [76.43624878, 9.20819473], [76.43624878, 9.20680523], [76.4365387, 9.20681095], [76.4365387, 9.20625114], [76.43680573, 9.20625114], [76.43680573, 9.20597267], [76.43708038, 9.20597267], [76.43708038, 9.20541668], [76.43736267, 9.20542145], [76.43736267, 9.20485973], [76.43763733, 9.20485973], [76.43763733, 9.20458221], [76.43791962, 9.20458221], [76.43791962, 9.20402908], [76.43846893, 9.20403099], [76.43846893, 9.20181084], [76.43875122, 9.20181084], [76.43875122, 9.20069027], [76.43902588, 9.20069408], [76.43902588, 9.19902802], [76.43930817, 9.19902992], [76.43930817, 9.19654179], [76.43958282, 9.19654179], [76.43958282, 9.19624996], [76.43930817, 9.19624996], [76.43930817, 9.1956892], [76.43958282, 9.19569397], [76.43958282, 9.19541645], [76.43985748, 9.19542027], [76.43985748, 9.19458199], [76.44013977, 9.19458389], [76.44013977, 9.19319439], [76.44069672, 9.19319439], [76.44069672, 9.1926403], [76.4404068, 9.1926403], [76.4404068, 9.19208145], [76.44013977, 9.19208431], [76.44013977, 9.19152832], [76.43985748, 9.19153023], [76.43985748, 9.19097137], [76.43958282, 9.19097137], [76.43958282, 9.19013977], [76.43985748, 9.19014168], [76.43985748, 9.18958092], [76.44013977, 9.18958282], [76.44013977, 9.18930531], [76.4404068, 9.18931007], [76.4404068, 9.18902969], [76.44097137, 9.18902969], [76.44097137, 9.18874931], [76.44125366, 9.18874931], [76.44124603, 9.18847084], [76.44152832, 9.18847084], [76.44152832, 9.18819523], [76.44180298, 9.18819523], [76.44180298, 9.18791676], [76.44235229, 9.18791962], [76.44235229, 9.18708134], [76.44264221, 9.18708324], [76.44264221, 9.18680477], [76.44291687, 9.18680954], [76.44291687, 9.18653202], [76.44319153, 9.18653202], [76.44319153, 9.18625069], [76.44346619, 9.18625069], [76.44346619, 9.18597126], [76.44403076, 9.18597317], [76.44403076, 9.18569469], [76.44430542, 9.18569469], [76.44430542, 9.18541718], [76.44458008, 9.18542194], [76.44458008, 9.18514061], [76.44486237, 9.18514061], [76.44486237, 9.18486118], [76.44541931, 9.18486118], [76.44541931, 9.18458271], [76.44569397, 9.18458271], [76.44569397, 9.18430519], [76.44596863, 9.18431187], [76.44596863, 9.18403053], [76.44625092, 9.18403053], [76.44625092, 9.18319035], [76.44652557, 9.18319511], [76.44652557, 9.18236065], [76.44680786, 9.18236065], [76.44680786, 9.18180466], [76.44708252, 9.18180943], [76.44708252, 9.18153954], [76.44735718, 9.18153954], [76.44735718, 9.18125057], [76.44763947, 9.18125057], [76.44763947, 9.18097115], [76.44791412, 9.18097305], [76.44791412, 9.18069458], [76.44819641, 9.18069458], [76.44819641, 9.18041706], [76.4484787, 9.18042088], [76.4484787, 9.18014145], [76.44875336, 9.18014145], [76.44875336, 9.17986107], [76.44902802, 9.17986107], [76.44902802, 9.1795826], [76.44930267, 9.1795826], [76.44930267, 9.17930698], [76.44957733, 9.17930889], [76.44957733, 9.17903137], [76.44985962, 9.17903137], [76.44985962, 9.17875099], [76.45014191, 9.17875099], [76.45014191, 9.17846966], [76.45153046, 9.17847347], [76.45153046, 9.17791653], [76.45181274, 9.1779213], [76.45181274, 9.17708015], [76.45207977, 9.17708206], [76.45207977, 9.17513847], [76.45236206, 9.17514133], [76.45236206, 9.17457962], [76.45263672, 9.17458439], [76.45263672, 9.1740284], [76.45291901, 9.17403126], [76.45291901, 9.17374992], [76.45318604, 9.17374992], [76.45318604, 9.17319202], [76.45347595, 9.17319393], [76.45347595, 9.17291641], [76.45375061, 9.17292118], [76.45375061, 9.17237091], [76.45430756, 9.17237091], [76.45430756, 9.17208195], [76.45458221, 9.17208195], [76.45458221, 9.17097187], [76.4548645, 9.17097187], [76.4548645, 9.16985989], [76.45513916, 9.16986179], [76.45513916, 9.16930962], [76.45540619, 9.16930962], [76.45540619, 9.16874981], [76.45569611, 9.16874981], [76.45569611, 9.16819382], [76.45597076, 9.16819382], [76.45597076, 9.16763973], [76.45625305, 9.16763973], [76.45625305, 9.16652966], [76.45597076, 9.16652966], [76.45597076, 9.16623974], [76.45625305, 9.16625023], [76.45625305, 9.16597176], [76.45652771, 9.16597176], [76.45652771, 9.16569424], [76.45680237, 9.16569424], [76.45680237, 9.16541767], [76.45707703, 9.16541958], [76.45707703, 9.16514015], [76.45735931, 9.16514015], [76.45735931, 9.16486168], [76.4576416, 9.16486168], [76.4576416, 9.16458416], [76.45791626, 9.16458416], [76.45791626, 9.16347122], [76.45819092, 9.16347122], [76.45819092, 9.16263866], [76.45791626, 9.16263866], [76.45791626, 9.16208076], [76.4576416, 9.16208267], [76.4576416, 9.16180515], [76.45735931, 9.16180992], [76.45735931, 9.16125107], [76.45680237, 9.16125107], [76.45680237, 9.16097069], [76.45652771, 9.16097069], [76.45652771, 9.16125107], [76.45625305, 9.16125107], [76.45625305, 9.16152954], [76.45540619, 9.16152954], [76.45540619, 9.16125107], [76.45485687, 9.16125107], [76.45485687, 9.16097069], [76.45458221, 9.1609726], [76.45458221, 9.16069317], [76.45430756, 9.16069317], [76.45430756, 9.15847111], [76.4548645, 9.15847111], [76.4548645, 9.15819454], [76.45513916, 9.15819454], [76.45513916, 9.15791702], [76.45540619, 9.15792179], [76.45540619, 9.15764141], [76.45569611, 9.15764141], [76.45569611, 9.15708065], [76.45597076, 9.15708256], [76.45597076, 9.15625095], [76.45652771, 9.15625095], [76.45652771, 9.15597057], [76.4576416, 9.15597057], [76.4576416, 9.15625095], [76.45791626, 9.15625095], [76.45791626, 9.15681171], [76.45847321, 9.15680504], [76.45847321, 9.15847111], [76.45874786, 9.15847111], [76.45874786, 9.15931034], [76.45903015, 9.15930462], [76.45903015, 9.15986061], [76.4595871, 9.15986061], [76.4595871, 9.16014194], [76.45986176, 9.16014194], [76.45986176, 9.15986061], [76.46013641, 9.15986061], [76.46013641, 9.15958309], [76.4604187, 9.15958309], [76.4604187, 9.1590271], [76.46098328, 9.15903187], [76.46098328, 9.15850067], [76.46097565, 9.15763855], [76.46125031, 9.15764141], [76.46125031, 9.15681171], [76.46151733, 9.15681171], [76.46151733, 9.15625095], [76.46180725, 9.15625095], [76.46180725, 9.15597057], [76.46208191, 9.15597343], [76.46208191, 9.15513897], [76.46235657, 9.15514088], [76.46235657, 9.15486145], [76.46263885, 9.15486145], [76.46263885, 9.15430546], [76.46291351, 9.15430546], [76.46291351, 9.15402889], [76.4631958, 9.15402889], [76.4631958, 9.15375137], [76.46347046, 9.15375137], [76.46347046, 9.1520834], [76.4631958, 9.1520834], [76.4631958, 9.15152645], [76.4640274, 9.15153122], [76.4640274, 9.15097046], [76.46430206, 9.15097332], [76.46430206, 9.15041637], [76.46457672, 9.15042114], [76.46457672, 9.14986038], [76.46485901, 9.14986038], [76.46485901, 9.14930439], [76.4651413, 9.14931107], [76.4651413, 9.14820099], [76.46569061, 9.14820099], [76.46569061, 9.14792061], [76.46541595, 9.14792061], [76.46541595, 9.14735985], [76.46569061, 9.14735985], [76.46569824, 9.14680576], [76.4659729, 9.14681053], [76.4659729, 9.14597034], [76.46624756, 9.14597225], [76.46624756, 9.14513779], [76.46652222, 9.14513969], [76.46652222, 9.14458179], [76.4668045, 9.1445837], [76.4668045, 9.14375019], [76.46708679, 9.14375019], [76.46708679, 9.1431942], [76.46736145, 9.1431942], [76.46736145, 9.14291573], [76.4679184, 9.14291954], [76.4679184, 9.14235973], [76.46763611, 9.14235973], [76.46763611, 9.14180565], [76.4679184, 9.14181042], [76.4679184, 9.14124966], [76.46736145, 9.14124966], [76.46736145, 9.14096928], [76.4668045, 9.14097214], [76.4668045, 9.14069366], [76.46624756, 9.14069366], [76.46624756, 9.14041805], [76.4659729, 9.14041805], [76.4659729, 9.14069366], [76.46541595, 9.14069366], [76.46541595, 9.14097214], [76.46485901, 9.14096928], [76.46485901, 9.14124966], [76.46347809, 9.14124966], [76.46347809, 9.14096928], [76.46291351, 9.14097214], [76.46291351, 9.14069366], [76.46208191, 9.14069366], [76.46208191, 9.14013767], [76.46180725, 9.14013958], [76.46180725, 9.13958073], [76.46125031, 9.13958359], [76.46125031, 9.13986206], [76.46151733, 9.13986015], [76.46151733, 9.14041996], [76.46097565, 9.14041805], [76.46097565, 9.14069366], [76.4604187, 9.1406889], [76.4604187, 9.14181042], [76.46013641, 9.14180565], [76.46013641, 9.14235973], [76.46002197, 9.14235973], [76.45986176, 9.14235973], [76.45986176, 9.14291954], [76.4595871, 9.14291573], [76.4595871, 9.14347172], [76.45929718, 9.14346981], [76.45929718, 9.14402962], [76.45903015, 9.14402771], [76.45903015, 9.1445837], [76.45874786, 9.1445837], [76.45874786, 9.14569378], [76.45847321, 9.14569187], [76.45847321, 9.14653111], [76.45819092, 9.14652824], [76.45819092, 9.14708424], [76.45791626, 9.14708042], [76.45791626, 9.14792061], [76.4576416, 9.14792061], [76.4576416, 9.14820099], [76.45735931, 9.14819431], [76.45735931, 9.14875031], [76.45708466, 9.14875031], [76.45708466, 9.14986038], [76.45680237, 9.14986038], [76.45680237, 9.1501379], [76.45652771, 9.1501379], [76.45652771, 9.15069485], [76.45625305, 9.15069485], [76.45625305, 9.15125084], [76.45597076, 9.1512394], [76.45597076, 9.15153122], [76.45625305, 9.15153122], [76.45625305, 9.15181065], [76.45597076, 9.15181065], [76.45597076, 9.1526413], [76.45569611, 9.1526413], [76.45569611, 9.15292072], [76.45541382, 9.15291691], [76.45541382, 9.15319538], [76.45513916, 9.15319538], [76.45513916, 9.15375137], [76.4548645, 9.15375137], [76.4548645, 9.15430546], [76.45458221, 9.15430546], [76.45458221, 9.15458298], [76.45430756, 9.15458012], [76.45430756, 9.15514088], [76.4540329, 9.15514088], [76.4540329, 9.15625095], [76.45375061, 9.15625095], [76.45375061, 9.15681171], [76.45347595, 9.15680504], [76.45347595, 9.15708256], [76.45318604, 9.15708065], [76.45318604, 9.15764141], [76.45291901, 9.15764141], [76.45291901, 9.15792179], [76.45263672, 9.15791702], [76.45263672, 9.15847111], [76.45236206, 9.15847111], [76.45236206, 9.15931034], [76.45207977, 9.15930462], [76.45207977, 9.15958309], [76.45180511, 9.15958309], [76.45180511, 9.16069317], [76.45153809, 9.16069126], [76.45153809, 9.16125107], [76.45124817, 9.16124916], [76.45124817, 9.16208267], [76.45096588, 9.16208076], [76.45096588, 9.16263866], [76.45069122, 9.16263866], [76.45069122, 9.16319561], [76.45041656, 9.16319561], [76.45041656, 9.16347122], [76.45014191, 9.16347122], [76.45014191, 9.16403198], [76.44985962, 9.16402721], [76.44985962, 9.16458416], [76.44957733, 9.1645813], [76.44958496, 9.16486168], [76.44930267, 9.16486168], [76.44930267, 9.16541958], [76.44902802, 9.16541958], [76.44902802, 9.16652966], [76.44875336, 9.16652775], [76.44875336, 9.16708374], [76.4484787, 9.16708088], [76.4484787, 9.16763973], [76.44819641, 9.16763973], [76.44819641, 9.16792011], [76.44763947, 9.1679163], [76.44763947, 9.16819382], [76.44791412, 9.16819382], [76.44791412, 9.16847229], [76.44763947, 9.16847229], [76.44763947, 9.16874981], [76.44736481, 9.16874981], [76.44736481, 9.16958427], [76.44708252, 9.16957855], [76.44708252, 9.17041969], [76.44652557, 9.17041588], [76.44652557, 9.17097187], [76.44625092, 9.17097187], [76.44625092, 9.1718111], [76.44596863, 9.1718111], [76.44596863, 9.17237091], [76.44568634, 9.17237091], [76.44568634, 9.17292118], [76.44541931, 9.17291641], [76.44541931, 9.17319393], [76.44569397, 9.17319393], [76.44569397, 9.1734724], [76.44541931, 9.17346954], [76.44541931, 9.17374992], [76.44513702, 9.17374992], [76.44513702, 9.17431068], [76.44486237, 9.17430592], [76.44486237, 9.17486], [76.44458008, 9.17486], [76.44458008, 9.17541599], [76.44430542, 9.17541599], [76.44430542, 9.17625046], [76.44403076, 9.17625046], [76.44403076, 9.17681122], [76.44374847, 9.1768074], [76.44374847, 9.17735958], [76.44346619, 9.17735958], [76.44346619, 9.1779213], [76.44319153, 9.17791653], [76.44319153, 9.178195], [76.44291687, 9.17818069], [76.44291687, 9.17903137], [76.44264221, 9.17902565], [76.44264221, 9.17986107], [76.44235229, 9.17986107], [76.44235229, 9.18042088], [76.4420929, 9.18042088], [76.4420929, 9.18125057], [76.44180298, 9.18125057], [76.44180298, 9.18264103], [76.44152832, 9.18263912], [76.44152832, 9.18375111], [76.44124603, 9.18375111], [76.44124603, 9.18431187], [76.44097137, 9.18430519], [76.44097137, 9.18458271], [76.44069672, 9.18458271], [76.44069672, 9.18486118], [76.44041443, 9.18486118], [76.44041443, 9.18597317], [76.43985748, 9.18597126], [76.43985748, 9.18653202], [76.43958282, 9.18652725], [76.43958282, 9.18708324], [76.43930817, 9.18708134], [76.43930817, 9.18763924], [76.43875122, 9.18763924], [76.43875122, 9.18819523], [76.43846893, 9.18819523], [76.43846893, 9.18874931], [76.43819427, 9.18874931], [76.43819427, 9.18958282], [76.43791962, 9.18958092], [76.43791962, 9.19014168], [76.43763733, 9.19013977], [76.43763733, 9.19124889], [76.43736267, 9.19124889], [76.43736267, 9.19180965], [76.43708038, 9.19180965], [76.43708038, 9.1926403], [76.43680573, 9.1926403], [76.43680573, 9.19319439], [76.4365387, 9.19319057], [76.4365387, 9.19348145], [76.43624878, 9.19347191], [76.43624878, 9.19375038], [76.43597412, 9.19375038], [76.43597412, 9.19458389], [76.43569183, 9.19458199], [76.43569183, 9.19514179], [76.43541718, 9.19514179], [76.43541718, 9.19624996], [76.43514252, 9.19624996], [76.43514252, 9.19654179], [76.43486023, 9.19654179], [76.43486023, 9.19764042], [76.43458557, 9.19763756], [76.43458557, 9.19819355], [76.43430328, 9.19819164], [76.43430328, 9.19874954], [76.43402863, 9.19874954], [76.43402863, 9.1995821], [76.43374634, 9.1995821], [76.43374634, 9.20069408], [76.43347931, 9.20069027], [76.43347931, 9.20125008], [76.43319702, 9.20125008], [76.43319702, 9.20153141], [76.4329071, 9.20153141], [76.4329071, 9.20375061], [76.43264008, 9.20375061], [76.43264008, 9.20431137], [76.43235779, 9.2043066], [76.43235779, 9.20458221], [76.43208313, 9.20458031], [76.43208313, 9.20514107], [76.43152618, 9.20513916], [76.43152618, 9.20569515], [76.43125153, 9.20569038], [76.43125153, 9.20653057], [76.43096924, 9.20652866], [76.43096924, 9.20708275], [76.43068695, 9.20707989], [76.43068695, 9.20792103], [76.43041229, 9.20792103], [76.43041229, 9.20848179], [76.43013763, 9.20848179], [76.43013763, 9.20931244], [76.42986298, 9.20930481], [76.42986298, 9.2098608], [76.42958069, 9.2098608], [76.42958069, 9.21042156], [76.42930603, 9.21041679], [76.42930603, 9.21097088], [76.42903137, 9.21097088], [76.42903137, 9.21154118], [76.42891693, 9.21152687], [76.42874908, 9.21152687], [76.42874908, 9.21208286], [76.4284668, 9.21208096], [76.4284668, 9.21264076], [76.42819214, 9.21263885], [76.42819214, 9.21319485], [76.42791748, 9.21319103], [76.42791748, 9.21402931], [76.42735291, 9.21402931], [76.42735291, 9.21513939], [76.42708588, 9.21513939], [76.42708588, 9.21569538], [76.42679596, 9.21569061], [76.42680359, 9.21624947], [76.42652893, 9.21624947], [76.42652893, 9.21652985], [76.42624664, 9.21652699], [76.42624664, 9.21708298], [76.42597198, 9.21708107], [76.42597198, 9.2179203], [76.42569733, 9.2179184], [76.42569733, 9.21819305], [76.42541504, 9.21819305], [76.42541504, 9.21847057], [76.42514038, 9.21847057], [76.42514038, 9.21903038], [76.42485809, 9.21902847], [76.42485809, 9.21986198], [76.42457581, 9.21986198], [76.42457581, 9.22042179], [76.42430878, 9.22041798], [76.42430878, 9.22097206], [76.42402649, 9.2209692], [76.42402649, 9.22152996], [76.42375183, 9.22152805], [76.42375183, 9.22236156], [76.42346954, 9.22235966], [76.42346954, 9.22292042], [76.42318726, 9.22292042], [76.42318726, 9.22348118], [76.42292023, 9.22348118], [76.42292023, 9.22431087], [76.42263794, 9.22430611], [76.42263794, 9.2248621], [76.42236328, 9.22486019], [76.42236328, 9.22542095], [76.42208099, 9.22542095], [76.42208099, 9.22624969], [76.42180634, 9.22624969], [76.42180634, 9.22681141], [76.42151642, 9.22681141], [76.42152405, 9.22735977], [76.42124939, 9.22735977], [76.42124939, 9.22792053], [76.42097473, 9.22791576], [76.42097473, 9.22847176], [76.42069244, 9.22846985], [76.42069244, 9.22903061], [76.42041779, 9.22902775], [76.42041779, 9.22986031], [76.42014313, 9.22986031], [76.42014313, 9.23042107], [76.41986084, 9.2304163], [76.41986084, 9.23097324], [76.41958618, 9.23097038], [76.41958618, 9.23153114], [76.41930389, 9.23152924], [76.41930389, 9.23208237], [76.41902924, 9.23208046], [76.41902924, 9.23292065], [76.41874695, 9.23291683], [76.41874695, 9.23347282], [76.41847229, 9.23346996], [76.41847229, 9.23403072], [76.41819763, 9.23402882], [76.41819763, 9.2345829], [76.41792297, 9.23458004], [76.41792297, 9.23513889], [76.41764069, 9.23513889], [76.41764069, 9.23569489], [76.4173584, 9.23569012], [76.4173584, 9.23653126], [76.41708374, 9.23652744], [76.41708374, 9.23708344], [76.41680908, 9.23708057], [76.41680908, 9.23764133], [76.41652679, 9.23763943], [76.41652679, 9.23819542], [76.41625214, 9.23819542], [76.41625214, 9.23875141], [76.41596985, 9.23875141], [76.41596985, 9.23931026], [76.41569519, 9.23930454], [76.41569519, 9.23986053], [76.4154129, 9.23986053], [76.4154129, 9.24042034], [76.41513824, 9.24041653], [76.41513824, 9.24069309], [76.41486359, 9.24069309], [76.41486359, 9.2415266], [76.4145813, 9.2415266], [76.4145813, 9.24183941], [76.4145813, 9.2420826], [76.41430664, 9.24208069], [76.41430664, 9.24263859], [76.41402435, 9.24263859], [76.41402435, 9.24319553], [76.41374969, 9.24319077], [76.41374969, 9.24375153], [76.41348267, 9.24375153], [76.41348267, 9.24458981], [76.41319275, 9.24458981], [76.41319275, 9.24514198], [76.41291809, 9.24514008], [76.41291809, 9.24569321], [76.4126358, 9.24569321], [76.4126358, 9.24625015], [76.41236877, 9.24625015], [76.41236877, 9.24680996], [76.41208649, 9.24680614], [76.41208649, 9.24708366], [76.4118042, 9.24708366], [76.4118042, 9.24819374], [76.41152954, 9.24819374], [76.41152954, 9.24847221], [76.41124725, 9.24846935], [76.41124725, 9.24874973], [76.4109726, 9.24874973], [76.4109726, 9.24903011], [76.41069794, 9.24902821], [76.41069794, 9.25097179], [76.41041565, 9.25097179], [76.41041565, 9.25125027], [76.41014099, 9.25125027], [76.41014099, 9.25152969], [76.4098587, 9.25152779], [76.4098587, 9.25208378], [76.40958405, 9.25208378], [76.40958405, 9.25236225], [76.40930939, 9.25236034], [76.40930939, 9.2529211], [76.4090271, 9.2529211], [76.4090271, 9.25403118], [76.40875244, 9.25402832], [76.40875244, 9.25458431], [76.40847015, 9.25457954], [76.40847015, 9.2551403], [76.4081955, 9.2551403], [76.4081955, 9.25569439], [76.40791321, 9.25569439], [76.40791321, 9.25625038], [76.40763855, 9.25625038], [76.40763855, 9.25681973], [76.40736389, 9.25680733], [76.40736389, 9.25708199], [76.4070816, 9.25708008], [76.4070816, 9.25764084], [76.40680695, 9.25764084], [76.40680695, 9.2590313], [76.40624237, 9.2590313], [76.40624237, 9.2595892], [76.40598297, 9.2595892], [76.40598297, 9.26014137], [76.40569305, 9.26014137], [76.40569305, 9.26041889], [76.40625, 9.26041698], [76.40625, 9.26069546], [76.40598297, 9.26068974], [76.40597534, 9.26124859], [76.40569305, 9.26125145], [76.40569305, 9.26180935], [76.4054184, 9.26180458], [76.4054184, 9.26236057], [76.40513611, 9.26236057], [76.40513611, 9.26292133], [76.40486145, 9.26291656], [76.40486145, 9.26347256], [76.40458679, 9.26347065], [76.40458679, 9.26403141], [76.4043045, 9.26402664], [76.4043045, 9.26458263], [76.40402985, 9.26458073], [76.40402985, 9.26514053], [76.40374756, 9.26513863], [76.40374756, 9.26569462], [76.4034729, 9.2656908], [76.4034729, 9.26625061], [76.40319824, 9.26625061], [76.40319824, 9.26681042], [76.40291595, 9.2668047], [76.40291595, 9.26736069], [76.4026413, 9.26736069], [76.4026413, 9.26791954], [76.40235901, 9.26791668], [76.40235901, 9.26847267], [76.40207672, 9.26847076], [76.40207672, 9.26902962], [76.40180206, 9.26902676], [76.40180206, 9.26958275], [76.4015274, 9.26958084], [76.4015274, 9.2701416], [76.40125275, 9.27013874], [76.40125275, 9.27069569], [76.40097046, 9.27069092], [76.40097046, 9.27125168], [76.4006958, 9.27124882], [76.4006958, 9.27208424], [76.40040588, 9.27208138], [76.40040588, 9.27264023], [76.40013885, 9.27264023], [76.40013885, 9.27347183], [76.39985657, 9.27347183], [76.39985657, 9.27402973], [76.39958191, 9.27402782], [76.39958191, 9.27486229], [76.39930725, 9.27486038], [76.39930725, 9.27542019], [76.39901733, 9.27542019], [76.39901733, 9.27625179], [76.39875031, 9.27625179], [76.39875031, 9.27680969], [76.39847565, 9.27680588], [76.39847565, 9.27763844], [76.39819336, 9.27764034], [76.39819336, 9.27819443], [76.3979187, 9.27819157], [76.3979187, 9.27902985], [76.39763641, 9.27902794], [76.39763641, 9.27958202], [76.39736938, 9.27958202], [76.39736938, 9.28013992], [76.3970871, 9.28013992], [76.3970871, 9.28070068], [76.39679718, 9.28070068], [76.39679718, 9.28125], [76.39653015, 9.28125], [76.39653015, 9.28180885], [76.39624786, 9.28180599], [76.39624786, 9.28236008], [76.39597321, 9.28236008], [76.39597321, 9.28319359], [76.39569092, 9.28318977], [76.39569092, 9.28376198], [76.39541626, 9.28374958], [76.39541626, 9.28458214], [76.3951416, 9.28458023], [76.3951416, 9.28514099], [76.39485931, 9.28514099], [76.39485931, 9.28542137], [76.39458466, 9.2854166], [76.39458466, 9.28569508], [76.39430237, 9.28569508], [76.39430237, 9.2859726], [76.39402771, 9.28596973], [76.39402771, 9.28653145], [76.39375305, 9.28652859], [76.39375305, 9.28708267], [76.39347076, 9.2870779], [76.39347076, 9.28764057], [76.39319611, 9.28764057], [76.39319611, 9.28792095], [76.39291382, 9.28791714], [76.39291382, 9.28847313], [76.39263916, 9.28847122], [76.39263916, 9.28875065], [76.39290619, 9.28875065], [76.39290619, 9.28931236], [76.39263916, 9.28930473], [76.39263916, 9.28986073], [76.39235687, 9.28986073], [76.39235687, 9.29042053], [76.39208221, 9.29041672], [76.39208221, 9.29125118], [76.39180756, 9.29125118], [76.39180756, 9.29181194], [76.39152527, 9.29180527], [76.39152527, 9.29236126], [76.39125061, 9.29236126], [76.39125061, 9.29319477], [76.39097595, 9.29319096], [76.39097595, 9.29375076], [76.39068604, 9.29375076], [76.39068604, 9.29430962], [76.39041901, 9.29430962], [76.39041901, 9.29513931], [76.39013672, 9.29513931], [76.39013672, 9.29570007], [76.38986206, 9.2956953], [76.38986206, 9.29624939], [76.38957977, 9.29624939], [76.38957977, 9.2970829], [76.38931274, 9.29708099], [76.38931274, 9.29763985], [76.38903046, 9.29763985], [76.38903046, 9.29819584], [76.38874817, 9.29819584], [76.38874817, 9.29874897], [76.38846588, 9.29874039], [76.38846588, 9.29930973], [76.38819122, 9.29930592], [76.38819122, 9.29986191], [76.38791656, 9.29986191], [76.38791656, 9.3004179], [76.38764191, 9.3004179], [76.38764191, 9.30097198], [76.38735962, 9.30097198], [76.38735962, 9.30153179], [76.38708496, 9.30152798], [76.38708496, 9.30208397], [76.38680267, 9.3020792], [76.38680267, 9.30263996], [76.38625336, 9.30263996], [76.38619232, 9.30294514], [76.38597107, 9.30291557], [76.38597107, 9.30318928], [76.38625336, 9.30325794], [76.38625336, 9.30347157], [76.38597107, 9.30346966], [76.38597107, 9.30375004], [76.38569641, 9.30375004], [76.38569641, 9.3043108], [76.38540649, 9.3043108], [76.38541412, 9.30486202], [76.38513947, 9.30486202], [76.38513947, 9.30541992], [76.38486481, 9.30541801], [76.38486481, 9.30569363], [76.38458252, 9.30568886], [76.38458252, 9.30653], [76.38430786, 9.30652809], [76.38430786, 9.3073597], [76.3840332, 9.3073597], [76.3840332, 9.30764008], [76.38375092, 9.30763817], [76.38375092, 9.30819416], [76.38346863, 9.30819416], [76.38346863, 9.30847168], [76.38318634, 9.30846977], [76.38318634, 9.30903053], [76.38291931, 9.30902767], [76.38291931, 9.30986023], [76.38236237, 9.30986023], [76.38236237, 9.31014061], [76.38208008, 9.31013775], [76.38208008, 9.31097221], [76.38181305, 9.31097031], [76.38181305, 9.31125069], [76.38153076, 9.31125069], [76.38153076, 9.31153107], [76.38124847, 9.31152916], [76.38124847, 9.31208229], [76.38096619, 9.31208038], [76.38096619, 9.31264114], [76.38124847, 9.31264114], [76.38124847, 9.31403065], [76.38097382, 9.31402874], [76.38097382, 9.3148613], [76.38069153, 9.3148613], [76.38069153, 9.31569481], [76.38041687, 9.31569004], [76.38041687, 9.31653118], [76.38014221, 9.31652737], [76.38014221, 9.31708336], [76.37985992, 9.31708336], [76.37985992, 9.31736088], [76.37958527, 9.31736088], [76.37958527, 9.31819534], [76.37930298, 9.31819534], [76.37930298, 9.31875134], [76.37902832, 9.31875134], [76.37902832, 9.31958294], [76.37874603, 9.31958103], [76.37874603, 9.32014084], [76.37847137, 9.32013893], [76.37847137, 9.32069111], [76.37819672, 9.32069969], [76.37819672, 9.32152939], [76.37791443, 9.32152653], [76.37791443, 9.32208347], [76.37763977, 9.32208061], [76.37763977, 9.32293129], [76.37735748, 9.32291698], [76.37735748, 9.32347107], [76.37708282, 9.32347107], [76.37708282, 9.3243103], [76.37680817, 9.32430458], [76.37680817, 9.32486153], [76.37652588, 9.32486153], [76.37652588, 9.32542038], [76.37625885, 9.32542038], [76.37625885, 9.32625198], [76.37596893, 9.32625198], [76.37596893, 9.32681179], [76.37568665, 9.32681179], [76.37568665, 9.32763958], [76.37541962, 9.32763672], [76.37541962, 9.32819366], [76.37513733, 9.3281889], [76.37513733, 9.32874966], [76.37486267, 9.32874966], [76.37486267, 9.32958412], [76.37458038, 9.32957935], [76.37458038, 9.33014011], [76.37430573, 9.33014011], [76.37430573, 9.3306942], [76.37403107, 9.3306942], [76.37403107, 9.33125019], [76.37374878, 9.33125019], [76.37374878, 9.3320837], [76.37346649, 9.33208179], [76.37346649, 9.33263969], [76.37319183, 9.33263779], [76.37319183, 9.33319378], [76.37291718, 9.33319378], [76.37291718, 9.33347225], [76.37264252, 9.33347034], [76.37264252, 9.33487129], [76.37236023, 9.33487129], [76.37236023, 9.33542061], [76.3720932, 9.33542061], [76.3720932, 9.33681107], [76.37180328, 9.3368063], [76.37180328, 9.33708191], [76.37152863, 9.33708477], [76.37152863, 9.3376379], [76.37124634, 9.3376379], [76.37124634, 9.33819389], [76.37097168, 9.33819199], [76.37097168, 9.33903122], [76.37069702, 9.33902645], [76.37069702, 9.33958244], [76.3704071, 9.33957958], [76.3704071, 9.34042072], [76.37014008, 9.34041691], [76.37014008, 9.3409729], [76.36985779, 9.34097004], [76.36985779, 9.34180927], [76.36958313, 9.34180546], [76.36958313, 9.34208298], [76.36930847, 9.34208298], [76.36930847, 9.34319496], [76.36902618, 9.34319019], [76.36902618, 9.34375095], [76.36875153, 9.34375095], [76.36875153, 9.34431171], [76.36846924, 9.34430695], [76.36846924, 9.34486103], [76.36818695, 9.34486103], [76.36818695, 9.34514141], [76.36791992, 9.34513855], [76.36791992, 9.34569454], [76.36763763, 9.34569263], [76.36763763, 9.34625053], [76.36736298, 9.34625053], [76.36736298, 9.34653187], [76.36708069, 9.3465271], [76.36708069, 9.34708309], [76.36680603, 9.34708118], [76.36680603, 9.34764099], [76.36653137, 9.34763908], [76.36653137, 9.3484726], [76.36624908, 9.3484726], [76.36624908, 9.34958267], [76.3659668, 9.34958076], [76.3659668, 9.35014153], [76.36569214, 9.35014153], [76.36569214, 9.35042191], [76.36541748, 9.35041714], [76.36541748, 9.35069561], [76.36513519, 9.35069561], [76.36513519, 9.35097122], [76.36486053, 9.35097122], [76.36486053, 9.35153198], [76.36458588, 9.35152721], [76.36458588, 9.35208321], [76.36429596, 9.3520813], [76.36430359, 9.35236168], [76.36402893, 9.35236168], [76.36402893, 9.35264015], [76.36374664, 9.35264015], [76.36374664, 9.35319328], [76.36347198, 9.35319138], [76.36347198, 9.35402966], [76.36319733, 9.35402775], [76.36319733, 9.35486221], [76.36292267, 9.35485935], [76.36292267, 9.35542011], [76.36264038, 9.3554163], [76.36264038, 9.35624981], [76.36235809, 9.35624981], [76.36235809, 9.35708427], [76.36207581, 9.35707855], [76.36207581, 9.35764027], [76.36180878, 9.35764027], [76.36180878, 9.35819435], [76.36152649, 9.35819435], [76.36152649, 9.35847187], [76.36125183, 9.35847187], [76.36125183, 9.35875034], [76.36096954, 9.35875034], [76.36096954, 9.3593111], [76.36069489, 9.35930634], [76.36069489, 9.35986233], [76.36042023, 9.35986042], [76.36042023, 9.36013985], [76.36013794, 9.36013794], [76.36013794, 9.36069393], [76.35986328, 9.36069202], [76.35986328, 9.36153126], [76.35958099, 9.36153126], [76.35958099, 9.36181068], [76.35930634, 9.36180592], [76.35930634, 9.36319447], [76.35901642, 9.3631897], [76.35902405, 9.36375046], [76.35874939, 9.36375046], [76.35874939, 9.36458206], [76.35847473, 9.36458206], [76.35847473, 9.3648634], [76.35819244, 9.364851], [76.35819244, 9.3654213], [76.35791779, 9.3654213], [76.35791779, 9.36625099], [76.35764313, 9.36625099], [76.35764313, 9.36680889], [76.35736084, 9.36680698], [76.35736084, 9.36736107], [76.35708618, 9.36736107], [76.35708618, 9.36819458], [76.35679626, 9.3681879], [76.35679626, 9.36903095], [76.35652924, 9.36903095], [76.35652924, 9.36931133], [76.35624695, 9.36930466], [76.35624695, 9.36958313], [76.35597229, 9.36958313], [76.35597229, 9.36986065], [76.35569763, 9.36986065], [76.35569763, 9.37014103], [76.35541534, 9.37013912], [76.35541534, 9.37069511], [76.35513306, 9.37069035], [76.35514069, 9.37125111], [76.3548584, 9.37125111], [76.3548584, 9.37208271], [76.35457611, 9.3720808], [76.35457611, 9.37264061], [76.35430908, 9.3726387], [76.35430908, 9.37319469], [76.35402679, 9.37319088], [76.35402679, 9.37486076], [76.35375214, 9.37486076], [76.35375214, 9.37541962], [76.35346985, 9.37541676], [76.35346985, 9.37569523], [76.35319519, 9.37569523], [76.35319519, 9.37624931], [76.3529129, 9.37624931], [76.3529129, 9.37681198], [76.35263824, 9.37680531], [76.35263824, 9.37708282], [76.35235596, 9.37708092], [76.35235596, 9.37764168], [76.35206604, 9.37764168], [76.35206604, 9.37792015], [76.35180664, 9.37792015], [76.35180664, 9.38041973], [76.35152435, 9.38041782], [76.35152435, 9.38097191], [76.35098267, 9.38097191], [76.35098267, 9.38181019], [76.35069275, 9.38180637], [76.35069275, 9.38236237], [76.35041809, 9.38236046], [76.35041809, 9.38292027], [76.3501358, 9.38291645], [76.3501358, 9.38347244], [76.34986115, 9.38346863], [76.34986115, 9.38431263], [76.34958649, 9.38430595], [76.34958649, 9.38458443], [76.34929657, 9.38458157], [76.34929657, 9.38514042], [76.34902954, 9.38513756], [76.34902954, 9.38597202], [76.34874725, 9.38597202], [76.34874725, 9.38736153], [76.3484726, 9.38736153], [76.3484726, 9.38819408], [76.34819794, 9.38819408], [76.34819794, 9.3890276], [76.34791565, 9.3890276], [76.34791565, 9.38958359], [76.34764099, 9.38958359], [76.34764099, 9.39069366], [76.3473587, 9.39069366], [76.3473587, 9.39097214], [76.34707642, 9.39097023], [76.34707642, 9.39124966], [76.34680939, 9.39124966], [76.34680176, 9.39153099], [76.3465271, 9.39153099], [76.3465271, 9.39292145], [76.34625244, 9.39291573], [76.34625244, 9.39347267], [76.34597015, 9.3934679], [76.34597015, 9.39403057], [76.3456955, 9.39402866], [76.3456955, 9.39597321], [76.34541321, 9.3959713], [76.34541321, 9.39625072], [76.34513855, 9.39625072], [76.34513855, 9.39681244], [76.3445816, 9.39680481], [76.3445816, 9.39708328], [76.34430695, 9.39708328], [76.34430695, 9.39847088], [76.34402466, 9.39847088], [76.34402466, 9.39986134], [76.34375, 9.39986134], [76.34375, 9.40069485], [76.34348297, 9.40069103], [76.34348297, 9.40125084], [76.34319305, 9.40125084], [76.34319305, 9.40263939], [76.3429184, 9.40263939], [76.3429184, 9.40291977], [76.34263611, 9.40291691], [76.34263611, 9.40347099], [76.34236145, 9.40347099], [76.34236145, 9.40402985], [76.34208679, 9.40402699], [76.34208679, 9.40458298], [76.34179688, 9.40458107], [76.34179688, 9.4054203], [76.34152985, 9.4054184], [76.34152985, 9.40569305], [76.3418045, 9.40569305], [76.3418045, 9.40597057], [76.34152985, 9.40597057], [76.34152985, 9.4068079], [76.34124756, 9.4068079], [76.34124756, 9.40764046], [76.3409729, 9.40764046], [76.3409729, 9.40874958], [76.34069824, 9.40874958], [76.34069824, 9.40902996], [76.34041595, 9.40902805], [76.34041595, 9.40958405], [76.3401413, 9.40958405], [76.3401413, 9.41014004], [76.33985901, 9.41013145], [76.33985901, 9.41125202], [76.33957672, 9.41125202], [76.33957672, 9.41152954], [76.33930206, 9.41152763], [76.33930206, 9.41347218], [76.3390274, 9.41347027], [76.3390274, 9.41403008], [76.33875275, 9.41403008], [76.33875275, 9.41514015], [76.33847046, 9.41514015], [76.33847046, 9.41542053], [76.3381958, 9.41541576], [76.3381958, 9.41597176], [76.33791351, 9.41597176], [76.33791351, 9.41847229], [76.33763885, 9.41847038], [76.33763885, 9.41903114], [76.33735657, 9.41903114], [76.33735657, 9.41986275], [76.33708191, 9.41985989], [76.33708191, 9.4206953], [76.33680725, 9.4206953], [76.33680725, 9.42236137], [76.33652496, 9.42236137], [76.33652496, 9.42319489], [76.33680725, 9.42319012], [76.33680725, 9.42403126], [76.33651733, 9.42403126], [76.33651733, 9.42431164], [76.33625031, 9.42430687], [76.33625031, 9.42486095], [76.33598328, 9.42486095], [76.33598328, 9.42542171], [76.33569336, 9.42541695], [76.33569336, 9.42569542], [76.3354187, 9.4256897], [76.3354187, 9.42653084], [76.33513641, 9.42653084], [76.33513641, 9.42764091], [76.33486176, 9.42764091], [76.33486176, 9.42791939], [76.3345871, 9.42791939], [76.3345871, 9.42875099], [76.33430481, 9.42874908], [76.33430481, 9.43097115], [76.33403015, 9.43097115], [76.33403015, 9.43181038], [76.33374786, 9.43180466], [76.33374786, 9.43236065], [76.33347321, 9.43236065], [76.33347321, 9.43264198], [76.33319092, 9.43264008], [76.33319092, 9.43486214], [76.33347321, 9.43485928], [76.33347321, 9.43542004], [76.33374786, 9.43541622], [76.33374786, 9.43569374], [76.33403015, 9.43569374], [76.33403015, 9.43597221], [76.33374786, 9.43596935], [76.33374786, 9.43624973], [76.33347321, 9.43624973], [76.33347321, 9.43653011], [76.33319092, 9.43653011], [76.33319092, 9.43680954], [76.33291626, 9.43680573], [76.33291626, 9.43735981], [76.3326416, 9.43735981], [76.3326416, 9.43902969], [76.33235931, 9.43902779], [76.33235931, 9.43958378], [76.33180237, 9.43958378], [76.33180237, 9.43986225], [76.33152771, 9.43986034], [76.33152771, 9.4404211], [76.33125305, 9.44041634], [76.33125305, 9.44097233], [76.33152771, 9.44097233], [76.33152771, 9.44208431], [76.33125305, 9.44207954], [76.33125305, 9.44320107], [76.33096313, 9.44320107], [76.33097076, 9.44375038], [76.33069611, 9.44375038], [76.33069611, 9.44458199], [76.33040619, 9.44458008], [76.33040619, 9.44542122], [76.33013916, 9.44541645], [76.33013916, 9.44597244], [76.32985687, 9.44596958], [76.32985687, 9.44626045], [76.32958221, 9.44626045], [76.32958221, 9.44681072], [76.32930756, 9.44681072], [76.32930756, 9.44791889], [76.32902527, 9.44791698], [76.32902527, 9.44847298], [76.32875061, 9.44847298], [76.32875061, 9.45069504], [76.32847595, 9.45069027], [76.32847595, 9.45125103], [76.32819366, 9.45125103], [76.32819366, 9.45236111], [76.32791901, 9.45236111], [76.32791901, 9.45292187], [76.32763672, 9.4529171], [76.32763672, 9.45319462], [76.32736206, 9.45319462], [76.32736206, 9.45458317], [76.32707977, 9.45458126], [76.32707977, 9.4568119], [76.32681274, 9.4568119], [76.32681274, 9.45792198], [76.32653046, 9.45792198], [76.32653046, 9.45875168], [76.32596588, 9.45875168], [76.32596588, 9.46041965], [76.32569122, 9.46041775], [76.32569122, 9.46125031], [76.32541656, 9.46125031], [76.32541656, 9.46208382], [76.32514954, 9.46208096], [76.32514954, 9.46542263], [76.32485962, 9.46541595], [76.32485962, 9.46569443], [76.32457733, 9.46569157], [76.32457733, 9.46652985], [76.32430267, 9.46652794], [76.32430267, 9.46708202], [76.32402802, 9.46708202], [76.32402802, 9.46763992], [76.32375336, 9.46763802], [76.32375336, 9.46986008], [76.32347107, 9.46986008], [76.32347107, 9.47043037], [76.32319641, 9.47041607], [76.32319641, 9.47069359], [76.32291412, 9.47069359], [76.32291412, 9.47236347], [76.32263947, 9.47235966], [76.32263947, 9.47264099], [76.32236481, 9.47263813], [76.32236481, 9.47319412], [76.32263947, 9.47318077], [76.32263947, 9.47403145], [76.32236481, 9.47402859], [76.32236481, 9.47486115], [76.32209015, 9.47486115], [76.32209015, 9.47542095], [76.32180786, 9.47541714], [76.32180786, 9.47569466], [76.3215332, 9.47568989], [76.3215332, 9.47681141], [76.32125092, 9.47680473], [76.32125092, 9.47958279], [76.32096863, 9.47958279], [76.32096863, 9.47986126], [76.32068634, 9.47986126], [76.32068634, 9.48042202], [76.32041931, 9.48041725], [76.32041931, 9.48097324], [76.32013702, 9.48097134], [76.32013702, 9.48152924], [76.31986237, 9.48152924], [76.31986237, 9.48180962], [76.31958008, 9.48180962], [76.31958008, 9.48431015], [76.31931305, 9.48431015], [76.31931305, 9.4865303], [76.31903076, 9.48652744], [76.31903076, 9.48708439], [76.31931305, 9.48708057], [76.31931305, 9.48764038], [76.31958008, 9.48763657], [76.31958008, 9.48875046], [76.31931305, 9.48875046], [76.31931305, 9.49042034], [76.31903076, 9.49041557], [76.31903076, 9.49097157], [76.31874847, 9.49097157], [76.31874847, 9.49125195], [76.31846619, 9.49125195], [76.31846619, 9.49154186], [76.31819153, 9.49152756], [76.31819153, 9.49208355], [76.31791687, 9.49208164], [76.31791687, 9.49263954], [76.31819153, 9.49263763], [76.31819153, 9.49319363], [76.31846619, 9.49318886], [76.31846619, 9.49403], [76.31874847, 9.49403], [76.31874847, 9.49431133], [76.31847382, 9.49430561], [76.31847382, 9.49458408], [76.31819153, 9.49458027], [76.31819153, 9.49542141], [76.31791687, 9.49541569], [76.31791687, 9.49597168], [76.31764221, 9.49597168], [76.31764221, 9.49625015], [76.31735992, 9.49625015], [76.31735992, 9.49708366], [76.31708527, 9.49708366], [76.31708527, 9.49736023], [76.31680298, 9.49735069], [76.31680298, 9.49792099], [76.31652832, 9.49792099], [76.31652832, 9.49874973], [76.31625366, 9.49874973], [76.31625366, 9.49985981], [76.31595612, 9.4998579], [76.31595612, 9.50153065], [76.31569672, 9.50152874], [76.31569672, 9.5023613], [76.3154068, 9.5023613], [76.31541443, 9.5037508], [76.31513977, 9.5037508], [76.31513977, 9.50458336], [76.31485748, 9.50457954], [76.31485748, 9.50514126], [76.31458282, 9.50514126], [76.31458282, 9.50654125], [76.31430817, 9.50654125], [76.31430817, 9.50764084], [76.31402588, 9.50764084], [76.31402588, 9.50875092], [76.31375122, 9.50875092], [76.31375122, 9.51014233], [76.31346893, 9.51014233], [76.31346893, 9.5118103], [76.31319427, 9.51180458], [76.31319427, 9.51319313], [76.31291962, 9.51319122], [76.31291962, 9.51431179], [76.31263733, 9.51431179], [76.31263733, 9.51541996], [76.31236267, 9.51541996], [76.31236267, 9.51764202], [76.31208038, 9.51764011], [76.31208038, 9.5195837], [76.31181335, 9.51958179], [76.31181335, 9.52013969], [76.31153107, 9.52013779], [76.31153107, 9.52069378], [76.31124878, 9.52069187], [76.31124878, 9.52153969], [76.31096649, 9.52153969], [76.31096649, 9.52292061], [76.31069183, 9.52292061], [76.31069183, 9.52403069], [76.31041718, 9.52402782], [76.31041718, 9.5251379], [76.31069183, 9.5251379], [76.31069183, 9.52542114], [76.31041718, 9.52541637], [76.31041718, 9.52569389], [76.31069183, 9.52569199], [76.31069183, 9.52625275], [76.31015015, 9.52625275], [76.31015015, 9.5276413], [76.31041718, 9.5276413], [76.31041718, 9.52902889], [76.31015015, 9.52902889], [76.31015015, 9.53042126], [76.30986023, 9.53041744], [76.30986023, 9.53097343], [76.3095932, 9.53097057], [76.3095932, 9.53153133], [76.30930328, 9.53153133], [76.30930328, 9.53180885], [76.30958557, 9.53180695], [76.30958557, 9.53319454], [76.30930328, 9.53318977], [76.30930328, 9.53347969], [76.30902863, 9.53347969], [76.30902863, 9.53403091], [76.30874634, 9.53403091], [76.30874634, 9.53431034], [76.30902863, 9.53430462], [76.30902863, 9.53458309], [76.30874634, 9.53458309], [76.30874634, 9.53486061], [76.30902863, 9.53486061], [76.30902863, 9.53514099], [76.30874634, 9.53513908], [76.30874634, 9.53652668], [76.30847168, 9.53652668], [76.30847168, 9.53708267], [76.30874634, 9.53708076], [76.30874634, 9.53764153], [76.30847168, 9.53764153], [76.30847168, 9.53931046], [76.30819702, 9.53930473], [76.30819702, 9.5409708], [76.3079071, 9.54096889], [76.30791473, 9.54124928], [76.30764008, 9.54124928], [76.30764008, 9.54265118], [76.30791473, 9.54263973], [76.30791473, 9.54374981], [76.30764008, 9.54374981], [76.30764008, 9.54403019], [76.30735779, 9.54403019], [76.30735779, 9.54430962], [76.30708313, 9.5443058], [76.30708313, 9.54597187], [76.30680847, 9.54597187], [76.30680847, 9.54763985], [76.30652618, 9.54763985], [76.30652618, 9.5490303], [76.30625153, 9.5490284], [76.30625153, 9.55069447], [76.30596924, 9.5506897], [76.30596924, 9.5529213], [76.30569458, 9.55291557], [76.30569458, 9.55347157], [76.30541992, 9.55346966], [76.30541992, 9.55375099], [76.30568695, 9.55375099], [76.30568695, 9.55514145], [76.30541992, 9.55514145], [76.30541992, 9.55764961], [76.30513763, 9.55764961], [76.30513763, 9.55792141], [76.30486298, 9.55791664], [76.30486298, 9.55819511], [76.30458069, 9.55819511], [76.30458069, 9.55847263], [76.30486298, 9.55847263], [76.30486298, 9.55986118], [76.30458069, 9.55986118], [76.30458069, 9.56014061], [76.30486298, 9.56014061], [76.30486298, 9.56042194], [76.30458069, 9.56041718], [76.30458069, 9.56069469], [76.30430603, 9.56069088], [76.30430603, 9.56125069], [76.30458069, 9.56125069], [76.30458069, 9.56236076], [76.30430603, 9.56236076], [76.30430603, 9.56263924], [76.30403137, 9.56263924], [76.30403137, 9.56458282], [76.30374908, 9.56458092], [76.30374908, 9.56542015], [76.30347443, 9.56541729], [76.30347443, 9.56847095], [76.30319214, 9.56847095], [76.30319214, 9.57069397], [76.30291748, 9.57069588], [76.30291748, 9.57097244], [76.30264282, 9.57096863], [76.30264282, 9.57153034], [76.30291748, 9.57153034], [76.30291748, 9.57181263], [76.30319214, 9.57180595], [76.30319214, 9.57236195], [76.30291748, 9.57236195], [76.30291748, 9.57263756], [76.30264282, 9.57263088], [76.30264282, 9.57291985], [76.30236053, 9.57291794], [76.30236053, 9.57319355], [76.30208588, 9.57319164], [76.30208588, 9.57374954], [76.30236053, 9.57374954], [76.30236053, 9.57402992], [76.30208588, 9.57402992], [76.30208588, 9.57431126], [76.30236053, 9.57431126], [76.30236053, 9.57681084], [76.30208588, 9.57680416], [76.30208588, 9.57819366], [76.30179596, 9.57818985], [76.30179596, 9.57875919], [76.30152893, 9.57874966], [76.30152893, 9.57958221], [76.30179596, 9.57958031], [76.30180359, 9.57985973], [76.30152893, 9.57985973], [76.30152893, 9.58014107], [76.30124664, 9.58014107], [76.30124664, 9.58042145], [76.30152893, 9.58041573], [76.30152893, 9.58319473], [76.30180359, 9.58319473], [76.30180359, 9.58347321], [76.30152893, 9.58347034], [76.30152893, 9.58431053], [76.30124664, 9.58430481], [76.30124664, 9.58458328], [76.30097961, 9.58457088], [76.30097961, 9.58542061], [76.30069733, 9.58541679], [76.30069733, 9.58569527], [76.30041504, 9.58569527], [76.30041504, 9.58597279], [76.30014038, 9.58597279], [76.30014038, 9.58625126], [76.30041504, 9.58625126], [76.30041504, 9.58757114], [76.30042267, 9.59013939], [76.30014038, 9.59013939], [76.30014038, 9.59125137], [76.29985809, 9.59125137], [76.29985809, 9.5929203], [76.29957581, 9.5929203], [76.29957581, 9.59403038], [76.29930878, 9.59403038], [76.29930878, 9.5943079], [76.29957581, 9.5943079], [76.29957581, 9.59542179], [76.29985809, 9.59541798], [76.29985809, 9.59569263], [76.29958344, 9.59569263], [76.29958344, 9.59680557], [76.29930878, 9.59680557], [76.29930878, 9.59847164], [76.29902649, 9.59847164], [76.29902649, 9.59875202], [76.29930878, 9.59875202], [76.29930878, 9.59930992], [76.29902649, 9.59930992], [76.29902649, 9.60013962], [76.29875183, 9.60013771], [76.29875183, 9.60097218], [76.29846954, 9.60097218], [76.29846954, 9.60208416], [76.29875183, 9.60208035], [76.29875183, 9.60292053], [76.29846954, 9.60291576], [76.29846954, 9.60375023], [76.29819489, 9.60375023], [76.29819489, 9.60624981], [76.29792023, 9.6062479], [76.29792023, 9.60681057], [76.29763794, 9.60681057], [76.29763794, 9.60764122], [76.29792023, 9.60764122], [76.29792023, 9.6093092], [76.29763794, 9.60930443], [76.29763794, 9.61097336], [76.29736328, 9.61097336], [76.29736328, 9.61236095], [76.29763794, 9.61236095], [76.29763794, 9.61264133], [76.29736328, 9.61263943], [76.29736328, 9.61375141], [76.29708099, 9.61375141], [76.29708099, 9.61458302], [76.29736328, 9.61458302], [76.29736328, 9.61486053], [76.29708099, 9.61486053], [76.29708099, 9.6170826], [76.29680634, 9.61708069], [76.29680634, 9.61875057], [76.29652405, 9.61874866], [76.29652405, 9.61958313], [76.29624939, 9.61958122], [76.29624939, 9.62042046], [76.2959671, 9.62042046], [76.2959671, 9.62180996], [76.29624939, 9.62180614], [76.29624939, 9.62208366], [76.29652405, 9.62208366], [76.29652405, 9.62236214], [76.29680634, 9.62235928], [76.29680634, 9.62263966], [76.29736328, 9.62263966], [76.29736328, 9.62292004], [76.29763794, 9.62291527], [76.29763794, 9.62347221], [76.29680634, 9.62347221], [76.29680634, 9.62374973], [76.29624939, 9.62374115], [76.29624939, 9.62430954], [76.29597473, 9.62430573], [76.29597473, 9.62569427], [76.29569244, 9.62569141], [76.29569244, 9.62652969], [76.29541779, 9.62652969], [76.29541779, 9.62931061], [76.29514313, 9.62931061], [76.29514313, 9.63153076], [76.29486084, 9.6315279], [76.29486084, 9.63236237], [76.2951355, 9.63236237], [76.29514313, 9.63319016], [76.29485321, 9.63320065], [76.29485321, 9.63431072], [76.29458618, 9.63430691], [76.29458618, 9.63458157], [76.29485321, 9.63457966], [76.29485321, 9.63792133], [76.29458618, 9.63791656], [76.29458618, 9.63847256], [76.29430389, 9.63847256], [76.29430389, 9.63986111], [76.29458618, 9.63986111], [76.29458618, 9.64181042], [76.29429626, 9.64181042], [76.29429626, 9.64291859], [76.29458618, 9.64291668], [76.29458618, 9.64347267], [76.29429626, 9.64347076], [76.29429626, 9.64542198], [76.29402924, 9.64541721], [76.29402924, 9.64819336], [76.29374695, 9.64819145], [76.29374695, 9.65042019], [76.29402924, 9.65041637], [76.29402924, 9.6506958], [76.29430389, 9.6506958], [76.29430389, 9.65097237], [76.29458618, 9.65096855], [76.29458618, 9.65153027], [76.29429626, 9.65153027], [76.29429626, 9.65180969], [76.29402924, 9.65180588], [76.29402924, 9.65236187], [76.29374695, 9.65236187], [76.29374695, 9.65264034], [76.29347229, 9.65264034], [76.29347229, 9.65431118], [76.29319763, 9.65430641], [76.29319763, 9.65708447], [76.29291534, 9.65708447], [76.29291534, 9.65986347], [76.29264069, 9.65986347], [76.29264069, 9.66097164], [76.29291534, 9.66097164], [76.29291534, 9.66319466], [76.29264069, 9.66319466], [76.29264069, 9.66347313], [76.2923584, 9.66347027], [76.2923584, 9.66653061], [76.29207611, 9.66653061], [76.29207611, 9.66764069], [76.29180908, 9.66764069], [76.29180908, 9.66986084], [76.29152679, 9.66986084], [76.29152679, 9.67347431], [76.29125214, 9.67347145], [76.29125214, 9.67653179], [76.29096985, 9.67652798], [76.29096985, 9.67958355], [76.29070282, 9.67958164], [76.29070282, 9.68264008], [76.2904129, 9.68264008], [76.2904129, 9.68402767], [76.29013824, 9.68402767], [76.29013824, 9.68847275], [76.28986359, 9.68847275], [76.28986359, 9.68958473], [76.2895813, 9.68958473], [76.2895813, 9.6912508], [76.28930664, 9.6912508], [76.28930664, 9.69430923], [76.28901672, 9.69430923], [76.28902435, 9.69874859], [76.28874969, 9.69875145], [76.28874969, 9.70236206], [76.28847504, 9.70236206], [76.28847504, 9.70458412], [76.28819275, 9.70457935], [76.28819275, 9.70681], [76.28791809, 9.70681], [76.28791809, 9.70903015], [76.2876358, 9.70902824], [76.2876358, 9.71125031], [76.28736115, 9.71125031], [76.28736115, 9.71264267], [76.28708649, 9.71264267], [76.28708649, 9.71431065], [76.28736115, 9.71430683], [76.28736115, 9.71485996], [76.28708649, 9.71485996], [76.28708649, 9.71542072], [76.28679657, 9.71542072], [76.28679657, 9.71709156], [76.28708649, 9.71708298], [76.28708649, 9.71736145], [76.28679657, 9.71736145], [76.28679657, 9.71792126], [76.28652954, 9.71792126], [76.28652954, 9.72042084], [76.28624725, 9.72041702], [76.28624725, 9.72069454], [76.28652954, 9.72069454], [76.28652954, 9.72097301], [76.28624725, 9.72097111], [76.28624725, 9.72264099], [76.28598022, 9.72264099], [76.28598022, 9.72375107], [76.28624725, 9.72374916], [76.28624725, 9.72458267], [76.2859726, 9.72458267], [76.2859726, 9.72819328], [76.28569794, 9.72819138], [76.28569794, 9.72902966], [76.28541565, 9.72902679], [76.28541565, 9.73124981], [76.28514099, 9.73124981], [76.28514099, 9.73347187], [76.28542328, 9.73347187], [76.28542328, 9.73542023], [76.28514099, 9.73542023], [76.28514099, 9.73681068], [76.2848587, 9.73680592], [76.2848587, 9.73708439], [76.28457642, 9.73707962], [76.28457642, 9.73764038], [76.28430939, 9.73763847], [76.28430939, 9.73847198], [76.28457642, 9.73847008], [76.28457642, 9.73931122], [76.28430939, 9.73931122], [76.28430939, 9.7404213], [76.28458405, 9.74041557], [76.28458405, 9.74069405], [76.28430939, 9.74069023], [76.28430176, 9.74153137], [76.2840271, 9.74152946], [76.2840271, 9.74208546], [76.28430176, 9.74207973], [76.28430176, 9.74403095], [76.2840271, 9.74402905], [76.2840271, 9.74458313], [76.28375244, 9.74458027], [76.28375244, 9.74764061], [76.2840271, 9.74764061], [76.2840271, 9.74792194], [76.28514099, 9.74792194], [76.28514099, 9.74764061], [76.28598022, 9.74764061], [76.28598022, 9.74792194], [76.28624725, 9.74791718], [76.28624725, 9.74819469], [76.28652954, 9.74818993], [76.28652954, 9.74986076], [76.28624725, 9.74986076], [76.28624725, 9.75013924], [76.28598022, 9.7501297], [76.28598022, 9.75041866], [76.28542328, 9.75041866], [76.28542328, 9.7501297], [76.28375244, 9.7501297], [76.28375244, 9.75041866], [76.28347015, 9.75041676], [76.28347015, 9.75097084], [76.28320313, 9.75097084], [76.28320313, 9.7515316], [76.28291321, 9.7515316], [76.28291321, 9.75319958], [76.28320313, 9.75319958], [76.28320313, 9.75403023], [76.28291321, 9.75402737], [76.28291321, 9.75458336], [76.28263855, 9.75458145], [76.28263855, 9.75626087], [76.28235626, 9.75626087], [76.28235626, 9.75681019], [76.2820816, 9.75680637], [76.2820816, 9.75736237], [76.28236389, 9.75736237], [76.28236389, 9.75847244], [76.2820816, 9.75847244], [76.2820816, 9.75903034], [76.28180695, 9.75902843], [76.28180695, 9.76097202], [76.28151703, 9.76097202], [76.28151703, 9.76124954], [76.28180695, 9.76124954], [76.28180695, 9.76319408], [76.28151703, 9.76318932], [76.28151703, 9.76431084], [76.28125, 9.76431084], [76.28125, 9.76543045], [76.28097534, 9.76541615], [76.28097534, 9.76708221], [76.28069305, 9.76708221], [76.28069305, 9.76875114], [76.2804184, 9.76875114], [76.2804184, 9.76986027], [76.28013611, 9.76986027], [76.28013611, 9.77097321], [76.27986145, 9.77097321], [76.27986145, 9.77208328], [76.27958679, 9.77208042], [76.27958679, 9.77680969], [76.2793045, 9.77680492], [76.2793045, 9.7770834], [76.27902985, 9.7770834], [76.27902985, 9.77986145], [76.27874756, 9.77986145], [76.27874756, 9.78043079], [76.2784729, 9.78043079], [76.2784729, 9.78153038], [76.27819824, 9.78153038], [76.27819824, 9.78292179], [76.2784729, 9.78291798], [76.2784729, 9.78319263], [76.27819824, 9.78318024], [76.27819824, 9.78374958], [76.27791595, 9.78374958], [76.27791595, 9.78514194], [76.2776413, 9.78514004], [76.2776413, 9.78708363], [76.27735901, 9.78708363], [76.27735901, 9.7881937], [76.27707672, 9.7881918], [76.27707672, 9.78903008], [76.27680969, 9.78903008], [76.27680969, 9.79014015], [76.2765274, 9.79014015], [76.2765274, 9.79152966], [76.27625275, 9.79152966], [76.27625275, 9.79181099], [76.2765274, 9.79180622], [76.2765274, 9.79319382], [76.27625275, 9.79319382], [76.27625275, 9.79458237], [76.27597046, 9.79458046], [76.27597046, 9.79653072], [76.2756958, 9.79652882], [76.2756958, 9.79708195], [76.27540588, 9.79708004], [76.27540588, 9.7976408], [76.27513885, 9.79763889], [76.27513885, 9.79847336], [76.27541351, 9.79847336], [76.27541351, 9.79922009], [76.27541351, 9.79986095], [76.27513885, 9.79986095], [76.27513885, 9.80041885], [76.2748642, 9.80041695], [76.2748642, 9.803195], [76.27458191, 9.80319118], [76.27458191, 9.80403233], [76.27430725, 9.80403233], [76.27430725, 9.80430984], [76.27401733, 9.80430984], [76.27401733, 9.80514145], [76.27375031, 9.80513859], [76.27375031, 9.80597115], [76.27348328, 9.80597115], [76.27348328, 9.80792046], [76.27319336, 9.80792046], [76.27319336, 9.80902958], [76.2729187, 9.80902958], [76.2729187, 9.81013966], [76.27319336, 9.81013966], [76.27319336, 9.810812], [76.27319336, 9.81180954], [76.2729187, 9.81180954], [76.2729187, 9.81264019], [76.27263641, 9.81264019], [76.27263641, 9.81375027], [76.27236176, 9.81375027], [76.27236176, 9.81402969], [76.27263641, 9.81402969], [76.27263641, 9.81431007], [76.27236176, 9.81430626], [76.27236176, 9.81486225], [76.2720871, 9.81486034], [76.2720871, 9.81654167], [76.27179718, 9.81654167], [76.27179718, 9.81931114], [76.27153015, 9.81930637], [76.27153015, 9.81986237], [76.27124786, 9.81986046], [76.27124786, 9.82014275], [76.27097321, 9.82013798], [76.27097321, 9.82208538], [76.27124786, 9.82208538], [76.27124786, 9.82236004], [76.27097321, 9.82236004], [76.27097321, 9.82347298], [76.27086639, 9.82347298], [76.27069092, 9.82347012], [76.27069092, 9.82431126], [76.27041626, 9.82431126], [76.27041626, 9.82653141], [76.2701416, 9.82652664], [76.2701416, 9.82708263], [76.26985931, 9.82708263], [76.26985931, 9.83236122], [76.26957703, 9.83236122], [76.26957703, 9.83375072], [76.26930237, 9.83375072], [76.26930237, 9.83403015], [76.26902771, 9.83402729], [76.26902771, 9.83458328], [76.26875305, 9.83458328], [76.26875305, 9.83624935], [76.26847076, 9.83624935], [76.26847076, 9.83681011], [76.26875305, 9.8368063], [76.26875305, 9.8381958], [76.26847076, 9.83819103], [76.26847076, 9.83875179], [76.26819611, 9.83875179], [76.26819611, 9.84014034], [76.26791382, 9.84014034], [76.26791382, 9.84097195], [76.26763916, 9.84097195], [76.26763916, 9.84152985], [76.26735687, 9.84152985], [76.26735687, 9.84181023], [76.26763916, 9.84180641], [76.26763916, 9.84208393], [76.26790619, 9.84208202], [76.26790619, 9.84263992], [76.26763916, 9.84263992], [76.26763916, 9.84348106], [76.26735687, 9.84348106], [76.26735687, 9.84431076], [76.26708221, 9.84431076], [76.26708221, 9.84542274], [76.26680756, 9.84542274], [76.26680756, 9.84624958], [76.26652527, 9.84624958], [76.26652527, 9.84652805], [76.26625061, 9.84652805], [76.26625061, 9.84847164], [76.26597595, 9.84846973], [76.26597595, 9.84931087], [76.26568604, 9.84931087], [76.26568604, 9.85014057], [76.26597595, 9.85014057], [76.26597595, 9.85181141], [76.26568604, 9.85181141], [76.26569366, 9.85236073], [76.26541901, 9.85236073], [76.26541901, 9.85292053], [76.26513672, 9.85291672], [76.26513672, 9.85347271], [76.26486969, 9.8534708], [76.26486969, 9.85542107], [76.26513672, 9.85541725], [76.26513672, 9.85624886], [76.26486206, 9.85624886], [76.26486206, 9.85708332], [76.26457977, 9.85708141], [76.26457977, 9.85736084], [76.26430511, 9.85736084], [76.26430511, 9.85847092], [76.26403046, 9.85846043], [76.26403046, 9.85931015], [76.26374817, 9.85931015], [76.26374817, 9.86180973], [76.26347351, 9.86180496], [76.26347351, 9.86208344], [76.26319122, 9.86208057], [76.26319122, 9.86514187], [76.26291656, 9.86514187], [76.26291656, 9.86625195], [76.26264191, 9.86625195], [76.26264191, 9.86653042], [76.26235962, 9.86653042], [76.26235962, 9.86791992], [76.26264191, 9.86791801], [76.26264191, 9.86819363], [76.26291656, 9.86819363], [76.26291656, 9.8684721], [76.26319122, 9.8684721], [76.26319122, 9.8698597], [76.26291656, 9.8698597], [76.26291656, 9.87014008], [76.26235962, 9.87014008], [76.26235962, 9.87042046], [76.26180267, 9.87041569], [76.26180267, 9.87097168], [76.26152802, 9.87097168], [76.26152802, 9.87181091], [76.26125336, 9.87180614], [76.26125336, 9.87319374], [76.26097107, 9.87319183], [76.26097107, 9.87486267], [76.26069641, 9.87485981], [76.26069641, 9.87819481], [76.26040649, 9.87819004], [76.26040649, 9.87959194], [76.26013947, 9.87958336], [76.26013947, 9.88097286], [76.26040649, 9.88097095], [76.26040649, 9.88180923], [76.26013947, 9.88180542], [76.26013947, 9.88236141], [76.25986481, 9.88236141], [76.25986481, 9.88263893], [76.25958252, 9.88263893], [76.25958252, 9.8834734], [76.25930786, 9.8834734], [76.25930786, 9.88486099], [76.2590332, 9.88486099], [76.25902557, 9.88624859], [76.25875092, 9.88625145], [76.25875092, 9.88736057], [76.25846863, 9.88736057], [76.25846863, 9.88847446], [76.25818634, 9.88847065], [76.25818634, 9.89041996], [76.25791931, 9.89041805], [76.25791931, 9.89097118], [76.25763702, 9.89096928], [76.25763702, 9.89264202], [76.25736237, 9.89264011], [76.25736237, 9.89375019], [76.25708008, 9.89375019], [76.25708008, 9.89513969], [76.25680542, 9.89513779], [76.25680542, 9.89569378], [76.25653076, 9.89569187], [76.25653076, 9.89625168], [76.25624847, 9.89624977], [76.25624847, 9.89764023], [76.25597382, 9.89764023], [76.25597382, 9.89958191], [76.25567627, 9.89958191], [76.25567627, 9.90070057], [76.25541687, 9.90070057], [76.25541687, 9.90153122], [76.25514221, 9.90153122], [76.25514221, 9.90292072], [76.25485992, 9.90292072], [76.25485992, 9.9040308], [76.25458527, 9.90402889], [76.25458527, 9.90486145], [76.25430298, 9.90486145], [76.25430298, 9.90597343], [76.25402832, 9.90597343], [76.25402832, 9.90708256], [76.25374603, 9.9070797], [76.25374603, 9.90764141], [76.25347137, 9.90763855], [76.25347137, 9.90819454], [76.25319672, 9.90818977], [76.25319672, 9.90930939], [76.2529068, 9.90930939], [76.2529068, 9.91041946], [76.25263977, 9.91041946], [76.25263977, 9.91181183], [76.25235748, 9.91181183], [76.25235748, 9.91292191], [76.25208282, 9.91292191], [76.25208282, 9.91403198], [76.25180817, 9.91403198], [76.25180817, 9.91541958], [76.25152588, 9.91541958], [76.25152588, 9.91652966], [76.25125122, 9.91652966], [76.25125122, 9.91763973], [76.25096893, 9.91763973], [76.25096893, 9.91874981], [76.25069427, 9.91874981], [76.25069427, 9.91958427], [76.25041962, 9.91958141], [76.25041962, 9.92014027], [76.25013733, 9.92014027], [76.25013733, 9.92097187], [76.24986267, 9.92097187], [76.24986267, 9.92180634], [76.24958038, 9.92180634], [76.24958038, 9.92236233], [76.24930573, 9.92236233], [76.24930573, 9.92319393], [76.24903107, 9.92319202], [76.24903107, 9.9240303], [76.24874878, 9.9240284], [76.24874878, 9.92486], [76.24846649, 9.92486], [76.24846649, 9.92542076], [76.24819183, 9.92541599], [76.24819183, 9.92625046], [76.24791718, 9.92625046], [76.24791718, 9.92708206], [76.24764252, 9.92708015], [76.24764252, 9.92793179], [76.24736023, 9.92793179], [76.24736023, 9.92875004], [76.24708557, 9.92875004], [76.24708557, 9.92958546], [76.24680328, 9.92957973], [76.24680328, 9.93042088], [76.24652863, 9.93042088], [76.24652863, 9.93125057], [76.24624634, 9.93125057], [76.24624634, 9.93208218], [76.24597168, 9.93208027], [76.24597168, 9.93292141], [76.24569702, 9.93291664], [76.24569702, 9.93347263], [76.2454071, 9.93346977], [76.2454071, 9.93431091], [76.24514008, 9.93431091], [76.24514008, 9.93514061], [76.24485779, 9.9351387], [76.24485779, 9.93597317], [76.24458313, 9.93597126], [76.24458313, 9.93680859], [76.24430847, 9.93680477], [76.24430847, 9.93708324], [76.24402618, 9.93708324], [76.24402618, 9.93819523], [76.24373627, 9.93819141], [76.24373627, 9.93931198], [76.24346924, 9.93931198], [76.24346924, 9.94014168], [76.24319458, 9.94013882], [76.24319458, 9.94069481], [76.24291992, 9.94069099], [76.24291992, 9.94153023], [76.24263763, 9.94152737], [76.24263763, 9.94208336], [76.24236298, 9.94208145], [76.24236298, 9.94293118], [76.24208069, 9.94291782], [76.24208069, 9.94374943], [76.24180603, 9.94374943], [76.24180603, 9.94431019], [76.24153137, 9.94431019], [76.24153137, 9.94514179], [76.24124908, 9.94513988], [76.24124908, 9.94567966], [76.2409668, 9.94569969], [76.2409668, 9.94653034], [76.24069214, 9.94652843], [76.24069214, 9.94708443], [76.24041748, 9.94708061], [76.24041748, 9.94791985], [76.24013519, 9.94791794], [76.24013519, 9.94847202], [76.23986053, 9.94847202], [76.23986053, 9.9493103], [76.23958588, 9.94930553], [76.23958588, 9.94986153], [76.23930359, 9.94986153], [76.23930359, 9.95069408], [76.23902893, 9.95068932], [76.23902893, 9.95153046], [76.23874664, 9.95153046], [76.23874664, 9.95263958], [76.23847198, 9.95263767], [76.23847198, 9.95347214], [76.23819733, 9.95347023], [76.23819733, 9.95431137], [76.2379303, 9.95431137], [76.2379303, 9.95542145], [76.23764038, 9.95541573], [76.23764038, 9.95625019], [76.23735809, 9.95625019], [76.23735809, 9.95791721], [76.23707581, 9.95790958], [76.23707581, 9.96014118], [76.23680878, 9.96014118], [76.23680878, 9.96291924], [76.23708344, 9.96291733], [76.23708344, 9.96400166], [76.23707581, 9.96486092], [76.23735809, 9.96486092], [76.23735809, 9.96542168], [76.23764038, 9.96541691], [76.23764038, 9.96569538], [76.23791504, 9.96569538], [76.23791504, 9.96597099], [76.23819733, 9.96597099], [76.23819733, 9.96652889], [76.23847198, 9.96652889], [76.23847198, 9.96681023], [76.23902893, 9.96680546], [76.23902893, 9.96708298], [76.23958588, 9.96708298], [76.23958588, 9.96736145], [76.24041748, 9.96736145], [76.24041748, 9.96764183], [76.2409668, 9.96764183], [76.2409668, 9.9679203], [76.24124908, 9.96791744], [76.24124908, 9.96819305], [76.24291992, 9.96819115], [76.24291992, 9.96875191], [76.24318695, 9.96875191], [76.24318695, 9.96903038], [76.24485779, 9.96903038], [76.24485779, 9.96930981], [76.24569702, 9.96930504], [76.24569702, 9.96958256], [76.24764252, 9.96958256], [76.24764252, 9.96986103], [76.24846649, 9.96984959], [76.24846649, 9.97014046], [76.24903107, 9.97014046], [76.24903107, 9.96984959], [76.24986267, 9.96986103], [76.24986267, 9.96958256], [76.25125122, 9.96958256], [76.25125122, 9.96986103], [76.25263977, 9.96986103], [76.25263977, 9.96958256], [76.25319672, 9.96958256], [76.25319672, 9.96847343], [76.25347137, 9.96847343], [76.25347137, 9.96819305], [76.25375366, 9.96819305], [76.25375366, 9.96708298], [76.25430298, 9.96708298], [76.25430298, 9.96652699], [76.2545929, 9.96652889], [76.2545929, 9.96625137], [76.25514221, 9.96625137], [76.25514221, 9.96569538], [76.25541687, 9.96569538], [76.25541687, 9.96541691], [76.25596619, 9.96542168], [76.25596619, 9.9651413], [76.25624847, 9.9651413], [76.25624847, 9.96486092], [76.25653076, 9.96486092], [76.25653076, 9.9645834], [76.25680542, 9.9645834], [76.25680542, 9.96430492], [76.25736237, 9.9643116], [76.25736237, 9.96404266], [76.25791931, 9.96404266], [76.25791931, 9.96375084], [76.25818634, 9.96375084], [76.25818634, 9.96347141], [76.25846863, 9.96347332], [76.25846863, 9.96319485], [76.25875092, 9.96319485], [76.25875092, 9.96291733], [76.2590332, 9.96291924], [76.2590332, 9.96263885], [76.25930786, 9.96263885], [76.25930786, 9.96236134], [76.25986481, 9.96236134], [76.25986481, 9.96152878], [76.25958252, 9.96153069], [76.25958252, 9.96125126], [76.25986481, 9.96125126], [76.25985718, 9.96014118], [76.26013947, 9.96014118], [76.26013947, 9.95931053], [76.26040649, 9.95931053], [76.26040649, 9.95903111], [76.26069641, 9.95903111], [76.26069641, 9.95790958], [76.26097107, 9.95791721], [76.26097107, 9.95680428], [76.26125336, 9.95681095], [76.26125336, 9.95597172], [76.26152802, 9.95597172], [76.26152802, 9.95541573], [76.2618103, 9.95542145], [76.2618103, 9.95514107], [76.26152802, 9.95514107], [76.26152802, 9.95423985], [76.26152802, 9.95236015], [76.26125336, 9.95236015], [76.26125336, 9.95208359], [76.26097107, 9.95208359], [76.26097107, 9.95180607], [76.26125336, 9.95181084], [76.26125336, 9.95153046], [76.26097107, 9.95153046], [76.26097107, 9.95014], [76.26125336, 9.95014], [76.26125336, 9.94957924], [76.26152802, 9.94958401], [76.26152802, 9.94902802], [76.2618103, 9.94902992], [76.2618103, 9.94819069], [76.26208496, 9.94819355], [76.26208496, 9.94458389], [76.26180267, 9.94458389], [76.26180267, 9.94347095], [76.26208496, 9.94347095], [76.26208496, 9.94236088], [76.26235962, 9.94236088], [76.26235962, 9.94124889], [76.26264191, 9.94124889], [76.26264191, 9.94041729], [76.26291656, 9.94042015], [76.26291656, 9.94014168], [76.26319122, 9.94014168], [76.26319122, 9.93958092], [76.26347351, 9.93958282], [76.26347351, 9.93847084], [76.26374817, 9.93847084], [76.26374817, 9.93791676], [76.26403046, 9.93792152], [76.26403046, 9.93764114], [76.26431274, 9.93764114], [76.26431274, 9.93653107], [76.26457977, 9.93653107], [76.26457977, 9.93568993], [76.26486206, 9.93569469], [76.26486206, 9.93541718], [76.26513672, 9.93542099], [76.26513672, 9.93514061], [76.26541901, 9.93514061], [76.26541901, 9.93457985], [76.26569366, 9.93458271], [76.26569366, 9.93430519], [76.26597595, 9.93431091], [76.26597595, 9.93403053], [76.26625061, 9.93403053], [76.26625061, 9.93374157], [76.26680756, 9.93375111], [76.26680756, 9.93291664], [76.26708221, 9.93292141], [76.26708221, 9.93264103], [76.26735687, 9.93264103], [76.26735687, 9.93236065], [76.26763916, 9.93236065], [76.26763916, 9.93208218], [76.26875305, 9.93208218], [76.26875305, 9.93236065], [76.26902771, 9.93236065], [76.26902771, 9.93208218], [76.26930237, 9.93208218], [76.26930237, 9.93125057], [76.26985931, 9.93125057], [76.26985931, 9.93097019], [76.2701416, 9.93097305], [76.2701416, 9.93069458], [76.27041626, 9.93069458], [76.27041626, 9.93041611], [76.27069092, 9.93042088], [76.27069092, 9.93014145], [76.27097321, 9.93014145], [76.27097321, 9.92986012], [76.27124786, 9.92986012], [76.27124786, 9.92958546], [76.27180481, 9.92958546], [76.27180481, 9.92930698], [76.27263641, 9.92930889], [76.27263641, 9.92903137], [76.27319336, 9.92903137], [76.27319336, 9.92875004], [76.27348328, 9.92875004], [76.27348328, 9.92846966], [76.27402496, 9.92847157], [76.27402496, 9.92837048], [76.27402496, 9.92819405], [76.27458191, 9.92819405], [76.27458191, 9.92791557], [76.27513885, 9.92793179], [76.27513885, 9.92763996], [76.2756958, 9.92763996], [76.2756958, 9.92735958], [76.27625275, 9.92736244], [76.27625275, 9.92708206], [76.2765274, 9.92708206], [76.2765274, 9.92680645], [76.27707672, 9.92681122], [76.27707672, 9.92653275], [76.2776413, 9.92653275], [76.2776413, 9.92625046], [76.27819061, 9.92625046], [76.27819824, 9.92597198], [76.2784729, 9.92597198], [76.2784729, 9.92569447], [76.27902985, 9.92569447], [76.27902985, 9.92541599], [76.27958679, 9.92542076], [76.27958679, 9.92514038], [76.28013611, 9.92514038], [76.28013611, 9.92486], [76.28069305, 9.92486], [76.28069305, 9.92458439], [76.28097534, 9.92458439], [76.28097534, 9.92430592], [76.28151703, 9.92431068], [76.28151703, 9.9240303], [76.2820816, 9.9240303], [76.2820816, 9.92374992], [76.28263855, 9.92374992], [76.28263855, 9.92346954], [76.28347015, 9.9234724], [76.28347015, 9.92319393], [76.28430176, 9.92319393], [76.28430176, 9.92291641], [76.28542328, 9.92292023], [76.28542328, 9.92263985], [76.28624725, 9.92263985], [76.28624725, 9.92236042], [76.28708649, 9.92236233], [76.28708649, 9.92208385], [76.28819275, 9.92208385], [76.28819275, 9.92180634], [76.28930664, 9.92180634], [76.28930664, 9.92152786], [76.29264069, 9.92152977], [76.29264069, 9.92125034], [76.29291534, 9.92125034], [76.29291534, 9.92097187], [76.29319763, 9.92097187], [76.29319763, 9.92069435], [76.29347229, 9.92069435], [76.29347229, 9.92041779], [76.29374695, 9.92041969], [76.29374695, 9.92014027], [76.29429626, 9.92014027], [76.29429626, 9.91986179], [76.29458618, 9.91986179], [76.29458618, 9.91930962], [76.29485321, 9.91930962], [76.29485321, 9.91847229], [76.2951355, 9.91847229], [76.2951355, 9.91791534], [76.29541779, 9.91792011], [76.29541779, 9.91681004], [76.29569244, 9.91681004], [76.29569244, 9.91541958], [76.2959671, 9.91541958], [76.2959671, 9.91347122], [76.29624939, 9.91347122], [76.29624939, 9.90909958], [76.29624939, 9.89958191], [76.29652405, 9.89958191], [76.29652405, 9.89735985], [76.29680634, 9.89735985], [76.29680634, 9.89569378], [76.29708099, 9.89569378], [76.29708099, 9.89402771], [76.29680634, 9.89402962], [76.29680634, 9.89319134], [76.29666901, 9.89319134], [76.29652405, 9.8931942], [76.29652405, 9.89291573], [76.29569244, 9.89291573], [76.29569244, 9.89347172], [76.29541779, 9.89346886], [76.29541779, 9.89402962], [76.29514313, 9.89402962], [76.29514313, 9.89431], [76.29486084, 9.89430618], [76.29486084, 9.8945837], [76.29458618, 9.89457035], [76.29458618, 9.89513969], [76.29429626, 9.89513969], [76.29429626, 9.89542007], [76.29402924, 9.89541626], [76.29402924, 9.89569378], [76.29374695, 9.89569378], [76.29374695, 9.89597225], [76.29347229, 9.89597034], [76.29347229, 9.89625168], [76.29264069, 9.89625168], [76.29264069, 9.89653015], [76.2923584, 9.89653015], [76.2923584, 9.89681053], [76.29208374, 9.89680576], [76.29208374, 9.89708424], [76.29152679, 9.89708424], [76.29152679, 9.89735985], [76.29125214, 9.89735985], [76.29125214, 9.89764023], [76.29096985, 9.89763069], [76.29096985, 9.89792061], [76.29069519, 9.89791584], [76.29069519, 9.89819431], [76.2904129, 9.89819431], [76.2904129, 9.89875031], [76.29013824, 9.89875031], [76.29013824, 9.89958191], [76.2904129, 9.89958191], [76.2904129, 9.90181065], [76.29013824, 9.90180588], [76.29013824, 9.9020853], [76.28985596, 9.90207958], [76.28985596, 9.9026413], [76.2895813, 9.9026413], [76.2895813, 9.90376186], [76.28930664, 9.90376186], [76.28930664, 9.90625095], [76.29013824, 9.90625095], [76.29013824, 9.90542126], [76.2904129, 9.90542126], [76.2904129, 9.90347004], [76.29069519, 9.9034729], [76.29069519, 9.9020853], [76.29096985, 9.9020853], [76.29096985, 9.90180588], [76.29347229, 9.90181065], [76.29347229, 9.9026413], [76.29319763, 9.90263844], [76.29319763, 9.90382099], [76.29319763, 9.9040308], [76.29291534, 9.90402889], [76.29291534, 9.90489006], [76.29291534, 9.90569496], [76.29264069, 9.90569496], [76.29264069, 9.90592861], [76.29264069, 9.90708256], [76.2923584, 9.9070797], [76.2923584, 9.90792084], [76.29208374, 9.90791702], [76.29208374, 9.90806961], [76.29208374, 9.90847301], [76.29096985, 9.90847301], [76.29096985, 9.90819454], [76.29069519, 9.90819454], [76.29069519, 9.90791702], [76.2904129, 9.90792084], [76.2904129, 9.90736103], [76.29013824, 9.90736103], [76.29013824, 9.90708256], [76.28874969, 9.9070797], [76.28874969, 9.90764141], [76.28847504, 9.90763855], [76.28847504, 9.90819454], [76.28819275, 9.90818977], [76.28819275, 9.90875053], [76.28791809, 9.90875053], [76.28791809, 9.90930939], [76.28652954, 9.90930939], [76.28652954, 9.90903091], [76.28624725, 9.90903091], [76.28624725, 9.90875053], [76.28598022, 9.90875053], [76.28598022, 9.90764141], [76.28569794, 9.90764141], [76.28569794, 9.90596962], [76.2859726, 9.90597343], [76.2859726, 9.90430355], [76.28624725, 9.90431118], [76.28624725, 9.9026413], [76.28652954, 9.9026413], [76.28652954, 9.90207958], [76.28624725, 9.9020853], [76.28624725, 9.90235996], [76.28369904, 9.90235996], [76.28291321, 9.90235996], [76.28291321, 9.9026413], [76.28180695, 9.9026413], [76.28180695, 9.90207958], [76.28152466, 9.9020853], [76.28152466, 9.90152836], [76.27984619, 9.90153122], [76.27984619, 9.90125275], [76.27874756, 9.90125275], [76.27874756, 9.90097046], [76.2776413, 9.90097237], [76.2776413, 9.90069389], [76.2765274, 9.90070057], [76.2765274, 9.90042114], [76.27540588, 9.90042114], [76.27540588, 9.90014267], [76.27458191, 9.90014267], [76.27458191, 9.89986038], [76.27263641, 9.89986038], [76.27263641, 9.90042114], [76.27236176, 9.90042114], [76.27236176, 9.90125275], [76.2720871, 9.90124989], [76.2720871, 9.9020853], [76.27179718, 9.90207958], [76.27179718, 9.90292072], [76.27153015, 9.90292072], [76.27153015, 9.90376186], [76.27124786, 9.90376186], [76.27124786, 9.90431118], [76.27097321, 9.90430355], [76.27097321, 9.90486145], [76.27069092, 9.90486145], [76.27069092, 9.90542126], [76.27041626, 9.90541744], [76.27041626, 9.90597343], [76.2701416, 9.90596962], [76.2701416, 9.90653133], [76.26985931, 9.90652657], [76.26985931, 9.90708256], [76.26957703, 9.9070797], [76.26957703, 9.90764141], [76.26930237, 9.90764141], [76.26930237, 9.90792084], [76.26902771, 9.90791702], [76.26902771, 9.90819454], [76.26875305, 9.90818977], [76.26875305, 9.90875053], [76.26847076, 9.90875053], [76.26847076, 9.90903091], [76.26819611, 9.90903091], [76.26819611, 9.90930939], [76.26791382, 9.90930462], [76.26791382, 9.90958309], [76.26763916, 9.90957069], [76.26763916, 9.91014099], [76.26735687, 9.91014099], [76.26735687, 9.91181183], [76.26708221, 9.91180515], [76.26708221, 9.91208267], [76.26652527, 9.91208267], [76.26652527, 9.91236115], [76.26597595, 9.91236115], [76.26597595, 9.91208267], [76.26569366, 9.91208267], [76.26569366, 9.91125107], [76.26597595, 9.91125107], [76.26597595, 9.91041946], [76.26625061, 9.91041946], [76.26625061, 9.90957069], [76.26652527, 9.90958309], [76.26652527, 9.90902901], [76.26680756, 9.90903091], [76.26680756, 9.90847111], [76.26708221, 9.90847301], [76.26708221, 9.90791702], [76.26735687, 9.90792084], [76.26735687, 9.90736103], [76.26763916, 9.90736103], [76.26763916, 9.90680695], [76.26791382, 9.90680695], [76.26791382, 9.90625095], [76.26819611, 9.90625095], [76.26819611, 9.90569019], [76.26847076, 9.90569496], [76.26847076, 9.90513897], [76.26875305, 9.90514088], [76.26875305, 9.9040308], [76.26902771, 9.9040308], [76.26902771, 9.90376186], [76.2701416, 9.90376186], [76.2701416, 9.90125275], [76.26985931, 9.90125275], [76.26985931, 9.90097046], [76.26958466, 9.90097237], [76.26958466, 9.90069389], [76.26930237, 9.90070057], [76.26930237, 9.90014267], [76.26902771, 9.90014267], [76.26902771, 9.89986038], [76.26875305, 9.89986229], [76.26875305, 9.89958382], [76.26791382, 9.89958191], [76.26791382, 9.8993063], [76.26763916, 9.89931107], [76.26763916, 9.89902973], [76.26735687, 9.89902973], [76.26735687, 9.89875031], [76.26708221, 9.89875031], [76.26708221, 9.89708424], [76.26680756, 9.89708424], [76.26680756, 9.89680576], [76.2665329, 9.89681053], [76.2665329, 9.89653015], [76.26597595, 9.89653015], [76.26597595, 9.89681053], [76.26541901, 9.89680576], [76.26541901, 9.89708424], [76.26513672, 9.89708424], [76.26513672, 9.89764023], [76.26486969, 9.89763069], [76.26486969, 9.89902973], [76.26403046, 9.89902782], [76.26403046, 9.89958191], [76.26374817, 9.89958191], [76.26374817, 9.90014267], [76.26346588, 9.90014267], [76.26346588, 9.90070057], [76.26374817, 9.90069389], [76.26374817, 9.9020853], [76.26347351, 9.9020853], [76.26347351, 9.90319443], [76.26319122, 9.90318966], [76.26319122, 9.9040308], [76.26291656, 9.9040308], [76.26291656, 9.90514088], [76.26264191, 9.90514088], [76.26264191, 9.90625095], [76.26235962, 9.90625095], [76.26235962, 9.90708256], [76.26210022, 9.9070797], [76.26210022, 9.90792084], [76.26180267, 9.90791702], [76.26180267, 9.90847301], [76.26152802, 9.90847111], [76.26152802, 9.90930939], [76.26125336, 9.90930939], [76.26125336, 9.91014099], [76.26097107, 9.91013908], [76.26097107, 9.91069508], [76.26069641, 9.91069126], [76.26069641, 9.91125107], [76.26040649, 9.91125107], [76.26040649, 9.91181183], [76.26013947, 9.91180515], [76.26013947, 9.91236115], [76.25985718, 9.91236115], [76.25985718, 9.91264057], [76.25930786, 9.91264057], [76.25930786, 9.91431046], [76.25902557, 9.91430473], [76.25902557, 9.91486073], [76.25875092, 9.91486073], [76.25875092, 9.9151392], [76.25846863, 9.9151392], [76.25846863, 9.91541958], [76.25818634, 9.91541958], [76.25818634, 9.91569996], [76.25736237, 9.91569996], [76.25736237, 9.91292191], [76.25763702, 9.91292191], [76.25763702, 9.91236115], [76.25791931, 9.91236115], [76.25791931, 9.91208267], [76.25819397, 9.91208267], [76.25819397, 9.91152668], [76.25791931, 9.9115324], [76.25791931, 9.91097069], [76.25763702, 9.9109726], [76.25763702, 9.9104166], [76.25736237, 9.91041946], [76.25736237, 9.90986061], [76.25708008, 9.90986061], [76.25708008, 9.90930462], [76.25736237, 9.90930939], [76.25736237, 9.90903091], [76.25791931, 9.90903091], [76.25791931, 9.90875053], [76.25846863, 9.90875053], [76.25846863, 9.90818977], [76.25875092, 9.90819454], [76.25875092, 9.90763855], [76.2590332, 9.90764141], [76.2590332, 9.90569019], [76.25736237, 9.90569496], [76.25736237, 9.90541744], [76.25763702, 9.90542126], [76.25763702, 9.90486145], [76.25791931, 9.90486145], [76.25791931, 9.90430355], [76.25818634, 9.90431118], [76.25818634, 9.90097046], [76.25846863, 9.90097237], [76.25846863, 9.8993063], [76.25875092, 9.89931107], [76.25875092, 9.89846992], [76.25902557, 9.89847183], [76.25902557, 9.89764023], [76.25930786, 9.89764023], [76.25930786, 9.89680576], [76.25958252, 9.89681053], [76.25958252, 9.89597034], [76.25986481, 9.89597225], [76.25986481, 9.89541626], [76.26013947, 9.89542007], [76.26013947, 9.89486027], [76.26041412, 9.89486217], [76.26041412, 9.89402771], [76.26069641, 9.89402962], [76.26069641, 9.89346886], [76.26097107, 9.89347172], [76.26097107, 9.89291573], [76.26125336, 9.89291954], [76.26125336, 9.89153194], [76.26097107, 9.89153194], [76.26097107, 9.89124966], [76.26125336, 9.89124966], [76.26125336, 9.8906889], [76.26152802, 9.89069557], [76.26152802, 9.89013958], [76.2618103, 9.89013958], [76.2618103, 9.88903046], [76.26210022, 9.88903046], [76.26210022, 9.88819122], [76.26235962, 9.88819313], [76.26235962, 9.88708305], [76.26264191, 9.88708305], [76.26264191, 9.88541698], [76.26291656, 9.88541889], [76.26291656, 9.88402939], [76.26319122, 9.88402939], [76.26319122, 9.88319016], [76.26347351, 9.88319492], [76.26347351, 9.8829174], [76.26374817, 9.88291931], [76.26374817, 9.88236141], [76.26403046, 9.88236141], [76.26403046, 9.88208294], [76.26430511, 9.88208294], [76.26430511, 9.88180542], [76.26457977, 9.88180923], [76.26457977, 9.88125134], [76.26486206, 9.88125134], [76.26486206, 9.88097286], [76.26513672, 9.88097286], [76.26513672, 9.87958336], [76.26541901, 9.87959194], [76.26541901, 9.87847042], [76.26569366, 9.87847328], [76.26569366, 9.87736034], [76.26597595, 9.87736034], [76.26597595, 9.87625122], [76.26625061, 9.87625122], [76.26625061, 9.87513828], [76.2665329, 9.87514114], [76.2665329, 9.87374973], [76.26680756, 9.87374973], [76.26680756, 9.87263966], [76.26708221, 9.87263966], [76.26708221, 9.87181091], [76.26763916, 9.87181091], [76.26763916, 9.87152958], [76.26819611, 9.87152958], [76.26819611, 9.87097168], [76.26847076, 9.87097168], [76.26847076, 9.87014008], [76.26875305, 9.87014008], [76.26875305, 9.86903], [76.26902771, 9.86903], [76.26902771, 9.86791992], [76.26930237, 9.86791992], [76.26930237, 9.86680984], [76.26957703, 9.86680984], [76.26957703, 9.86625195], [76.27069092, 9.86625195], [76.27069092, 9.86653042], [76.27124786, 9.86653042], [76.27124786, 9.86680984], [76.2720871, 9.86680603], [76.2720871, 9.86708355], [76.27263641, 9.86708355], [76.27263641, 9.86736202], [76.27348328, 9.86736202], [76.27348328, 9.86765099], [76.27404022, 9.86765099], [76.27404022, 9.86791992], [76.27485657, 9.86791992], [76.27485657, 9.86931133], [76.27458191, 9.86931133], [76.27458191, 9.87042046], [76.27430725, 9.87042046], [76.27430725, 9.87152958], [76.27404022, 9.87152958], [76.27404022, 9.87263966], [76.27375031, 9.87263966], [76.27375031, 9.87374973], [76.27404022, 9.87374973], [76.27404022, 9.87431145], [76.27485657, 9.87431145], [76.27485657, 9.87403107], [76.27513885, 9.87403107], [76.27513885, 9.87374973], [76.2756958, 9.87374973], [76.2756958, 9.87345886], [76.27597046, 9.87347221], [76.27597046, 9.87263775], [76.27625275, 9.87263966], [76.27625275, 9.87207985], [76.27597046, 9.87208366], [76.27597046, 9.87152767], [76.27625275, 9.87152958], [76.27625275, 9.87068939], [76.2765274, 9.87069416], [76.2765274, 9.87014008], [76.27680969, 9.87014008], [76.27680969, 9.86957932], [76.27708435, 9.86958408], [76.27708435, 9.86930561], [76.27819824, 9.86930561], [76.27819824, 9.86958408], [76.27874756, 9.86958408], [76.27874756, 9.8698597], [76.27929688, 9.8698597], [76.27929688, 9.87014008], [76.27958679, 9.87014008], [76.27958679, 9.87069416], [76.27986145, 9.87069416], [76.27986145, 9.87097168], [76.28013611, 9.87097168], [76.28013611, 9.87125015], [76.2804184, 9.87125015], [76.2804184, 9.87152958], [76.28069305, 9.87152958], [76.28069305, 9.87181091], [76.28098297, 9.87181091], [76.28098297, 9.87374973], [76.28125, 9.87374973], [76.28125, 9.87403107], [76.28151703, 9.87403107], [76.28152466, 9.87597179], [76.28125, 9.87597179], [76.28125, 9.87708473], [76.28098297, 9.87707996], [76.28098297, 9.87764072], [76.28069305, 9.87763882], [76.28069305, 9.87819481], [76.2804184, 9.87819481], [76.2804184, 9.8787508], [76.28013611, 9.8787508], [76.28013611, 9.87931061], [76.27984619, 9.87931061], [76.27984619, 9.88180923], [76.27958679, 9.88180542], [76.27958679, 9.88319016], [76.27929688, 9.88319969], [76.27929688, 9.88375092], [76.27902985, 9.88374901], [76.27902985, 9.88458347], [76.27874756, 9.88458061], [76.27874756, 9.88514137], [76.2784729, 9.88513947], [76.2784729, 9.88736057], [76.27819824, 9.88736057], [76.27819824, 9.88764191], [76.27791595, 9.88764191], [76.27791595, 9.88792038], [76.2776413, 9.88791656], [76.2776413, 9.88819313], [76.27735901, 9.88819122], [76.27735901, 9.88876057], [76.27707672, 9.88876057], [76.27707672, 9.88931179], [76.27680969, 9.88931179], [76.27680969, 9.89013958], [76.2765274, 9.89013958], [76.2765274, 9.89124966], [76.27625275, 9.89124966], [76.27625275, 9.89208412], [76.27597046, 9.89208412], [76.27597046, 9.8931942], [76.2756958, 9.89319134], [76.2756958, 9.89402962], [76.27597046, 9.89402962], [76.27597046, 9.89431], [76.27625275, 9.89430618], [76.27625275, 9.8945837], [76.27735901, 9.8945837], [76.27735901, 9.89430618], [76.27791595, 9.89431], [76.27791595, 9.89402962], [76.2784729, 9.89402962], [76.2784729, 9.89375019], [76.27874756, 9.89375019], [76.27874756, 9.8931942], [76.27902985, 9.8931942], [76.27902985, 9.88791656], [76.27958679, 9.88791656], [76.27958679, 9.88819313], [76.27986145, 9.88819313], [76.27986145, 9.88847446], [76.28013611, 9.88847065], [76.28013611, 9.88903046], [76.2804184, 9.88903046], [76.2804184, 9.88931179], [76.28069305, 9.88930511], [76.28069305, 9.88958263], [76.28098297, 9.88958073], [76.28098297, 9.89013958], [76.28125, 9.89013958], [76.28125, 9.89041996], [76.28151703, 9.89041996], [76.28151703, 9.89182186], [76.28180695, 9.89180565], [76.28180695, 9.89764023], [76.2820816, 9.89764023], [76.2820816, 9.89875031], [76.28263855, 9.89875031], [76.28263855, 9.89902973], [76.28320313, 9.89902973], [76.28320313, 9.89931107], [76.28375244, 9.8993063], [76.28375244, 9.89958191], [76.28430176, 9.89958191], [76.28430939, 9.89986229], [76.2848587, 9.89986038], [76.2848587, 9.90042114], [76.28569794, 9.90042114], [76.28569794, 9.90070057], [76.28624725, 9.90070057], [76.28624725, 9.90042114], [76.28652954, 9.90042114], [76.28652954, 9.89986038], [76.2868042, 9.89986229], [76.2868042, 9.8993063], [76.28708649, 9.89931107], [76.28708649, 9.89902973], [76.28736115, 9.89902973], [76.28736115, 9.89846992], [76.2876358, 9.89847183], [76.2876358, 9.89819431], [76.28736115, 9.89819431], [76.28736115, 9.89791584], [76.28708649, 9.89792061], [76.28708649, 9.89763069], [76.2868042, 9.89764023], [76.2868042, 9.89735985], [76.28652954, 9.89735985], [76.28652954, 9.89708424], [76.28624725, 9.89708424], [76.28624725, 9.89680576], [76.28598022, 9.89681053], [76.28598022, 9.89625168], [76.28624725, 9.89625168], [76.28624725, 9.89542007], [76.28652954, 9.89542007], [76.28652954, 9.89431], [76.28679657, 9.89431], [76.28679657, 9.89319134], [76.28708649, 9.8931942], [76.28708649, 9.89208412], [76.28736115, 9.89208412], [76.28736115, 9.89124966], [76.28848267, 9.89124966], [76.28848267, 9.89041996], [76.28874969, 9.89041996], [76.28874969, 9.88958073], [76.28902435, 9.88958263], [76.28902435, 9.88847446], [76.28930664, 9.88847446], [76.28930664, 9.88736057], [76.2895813, 9.88736057], [76.2895813, 9.88624859], [76.28985596, 9.88625145], [76.28985596, 9.88486099], [76.29013824, 9.88486099], [76.29013824, 9.88374901], [76.2904129, 9.88375092], [76.2904129, 9.88347054], [76.29013824, 9.8834734], [76.29013824, 9.8829174], [76.2904129, 9.88291931], [76.2904129, 9.88180923], [76.29070282, 9.88180923], [76.29070282, 9.88042068], [76.29096985, 9.88042068], [76.29096985, 9.87931061], [76.29125214, 9.87931061], [76.29125214, 9.8787508], [76.29152679, 9.8787508], [76.29152679, 9.87813091], [76.29152679, 9.87680435], [76.29180908, 9.87681961], [76.29180908, 9.87486267], [76.29207611, 9.87486267], [76.29207611, 9.87319183], [76.2923584, 9.87319374], [76.2923584, 9.87208366], [76.29264069, 9.87208366], [76.29264069, 9.87152767], [76.29292297, 9.87152958], [76.29292297, 9.87068939], [76.29319763, 9.87069416], [76.29319763, 9.87014008], [76.29347229, 9.87014008], [76.29347229, 9.86957932], [76.29374695, 9.86958408], [76.29374695, 9.86874962], [76.29402924, 9.86874962], [76.29402924, 9.86818886], [76.29430389, 9.86819363], [76.29430389, 9.86736202], [76.29458618, 9.86736202], [76.29458618, 9.86652756], [76.29485321, 9.86653042], [76.29485321, 9.86291981], [76.29458618, 9.86291981], [76.29458618, 9.86125183], [76.29429626, 9.86125183], [76.29429626, 9.85986137], [76.29458618, 9.85986137], [76.29458618, 9.8587513], [76.29486084, 9.8587513], [76.29485321, 9.8579216], [76.29514313, 9.8579216], [76.29514313, 9.85736084], [76.29541779, 9.85736084], [76.29541779, 9.85708141], [76.29569244, 9.85708332], [76.29569244, 9.85652733], [76.2959671, 9.85652924], [76.2959671, 9.85624886], [76.29624939, 9.85624886], [76.29624939, 9.85569477], [76.29652405, 9.85569477], [76.29652405, 9.85513878], [76.29680634, 9.85514069], [76.29680634, 9.85457993], [76.29708099, 9.85458279], [76.29708099, 9.85291672], [76.29680634, 9.85292053], [76.29680634, 9.85236073], [76.29651642, 9.85236073], [76.29651642, 9.85181141], [76.29624939, 9.85181141], [76.29624939, 9.85125065], [76.29514313, 9.85125065], [76.29514313, 9.85097027], [76.2923584, 9.85097027], [76.2923584, 9.85125065], [76.29207611, 9.85125065], [76.29207611, 9.85181141], [76.29180908, 9.85180664], [76.29180908, 9.85208321], [76.2895813, 9.85208321], [76.2895813, 9.85180664], [76.28901672, 9.85181141], [76.28901672, 9.85153103], [76.28848267, 9.85153103], [76.28848267, 9.85125065], [76.28819275, 9.85125065], [76.28819275, 9.85097027], [76.2876358, 9.85097313], [76.2876358, 9.85069466], [76.28572083, 9.85069466], [76.2848587, 9.85069466], [76.2848587, 9.85041714], [76.28347015, 9.85042095], [76.28347015, 9.84986019], [76.28375244, 9.84986019], [76.28375244, 9.84875011], [76.2840271, 9.84875011], [76.2840271, 9.84792137], [76.28430176, 9.84792137], [76.28430176, 9.84708023], [76.28458405, 9.84708214], [76.28458405, 9.84624958], [76.2848587, 9.84624958], [76.2848587, 9.84569168], [76.28514099, 9.84569359], [76.28514099, 9.84486008], [76.28541565, 9.84486008], [76.28541565, 9.84460926], [76.28541565, 9.84402847], [76.28569794, 9.84403038], [76.28569794, 9.84348106], [76.28457642, 9.84348106], [76.28457642, 9.84318924], [76.28430176, 9.84319401], [76.28430176, 9.84263992], [76.2840271, 9.84263992], [76.2840271, 9.84208202], [76.28375244, 9.84208393], [76.28375244, 9.84125042], [76.28347015, 9.84125042], [76.28347015, 9.84041786], [76.28320313, 9.84041977], [76.28320313, 9.83958054], [76.28291321, 9.83958435], [76.28291321, 9.83902836], [76.28320313, 9.83903027], [76.28320313, 9.83847237], [76.28347015, 9.83847237], [76.28347015, 9.83791542], [76.28375244, 9.83792019], [76.28375244, 9.83681011], [76.2840271, 9.83681011], [76.2840271, 9.83513927], [76.28430176, 9.83513927], [76.28430176, 9.8334713], [76.28458405, 9.8334713], [76.28458405, 9.83263874], [76.28514099, 9.8326416], [76.28514099, 9.83292198], [76.2859726, 9.83291721], [76.2859726, 9.83319473], [76.28679657, 9.83319092], [76.28679657, 9.83375072], [76.28652954, 9.83375072], [76.28652954, 9.83430958], [76.28902435, 9.83430481], [76.28902435, 9.8348608], [76.28930664, 9.83485889], [76.28930664, 9.83541965], [76.2895813, 9.83541775], [76.2895813, 9.83736229], [76.28985596, 9.83735943], [76.28985596, 9.83763981], [76.29374695, 9.83763981], [76.29374695, 9.83792019], [76.29402924, 9.83792019], [76.29402924, 9.83875179], [76.29374695, 9.83875179], [76.29374695, 9.84041977], [76.29347229, 9.84041786], [76.29347229, 9.84208393], [76.29319763, 9.84208393], [76.29319763, 9.84319401], [76.29292297, 9.84318924], [76.29292297, 9.84348106], [76.29264069, 9.84348106], [76.29264069, 9.84403038], [76.29347229, 9.84402847], [76.29347229, 9.84486008], [76.29319763, 9.84486008], [76.29319763, 9.84597206], [76.29292297, 9.84597015], [76.29292297, 9.84624958], [76.2923584, 9.84624958], [76.2923584, 9.84652805], [76.29180908, 9.84652138], [76.29180908, 9.84681129], [76.29152679, 9.84680557], [76.29152679, 9.84736156], [76.29125214, 9.84735966], [76.29125214, 9.84792137], [76.29096985, 9.84791565], [76.29096985, 9.84819412], [76.29070282, 9.84819031], [76.29070282, 9.84875011], [76.2904129, 9.84875011], [76.2904129, 9.84903145], [76.29070282, 9.84903145], [76.29070282, 9.84931087], [76.29096985, 9.8493042], [76.29096985, 9.84958458], [76.29125214, 9.84958458], [76.29125214, 9.84986019], [76.2923584, 9.84986019], [76.2923584, 9.85014057], [76.29429626, 9.85014057], [76.29429626, 9.85042095], [76.29624939, 9.85041714], [76.29624939, 9.85069466], [76.29708099, 9.85069466], [76.29708099, 9.85041714], [76.29736328, 9.85042095], [76.29736328, 9.85014057], [76.29846954, 9.85014057], [76.29846954, 9.84986019], [76.29875183, 9.84986019], [76.29875183, 9.84958458], [76.29930878, 9.84958458], [76.29930878, 9.84902859], [76.29902649, 9.84903145], [76.29902649, 9.84764099], [76.29930878, 9.84764099], [76.29930878, 9.84514046], [76.29957581, 9.84514046], [76.29957581, 9.84375], [76.30069733, 9.84375], [76.30069733, 9.84403038], [76.30097198, 9.84402847], [76.30097198, 9.84458447], [76.30124664, 9.84458447], [76.30124664, 9.84486008], [76.30152893, 9.84486008], [76.30152893, 9.84542274], [76.30180359, 9.84541607], [76.30180359, 9.84569359], [76.30208588, 9.84569168], [76.30208588, 9.84624958], [76.30236053, 9.84624958], [76.30236053, 9.84681129], [76.30263519, 9.84680557], [76.30263519, 9.84735966], [76.30291748, 9.84735966], [76.30291748, 9.84931087], [76.30263519, 9.8493042], [76.30263519, 9.84986019], [76.30236053, 9.84986019], [76.30236053, 9.85042095], [76.30152893, 9.85042095], [76.30152893, 9.85014057], [76.29985809, 9.85013771], [76.29985809, 9.85069466], [76.29930878, 9.85069466], [76.29930878, 9.85097313], [76.29875183, 9.85097027], [76.29875183, 9.85125065], [76.29902649, 9.85125065], [76.29902649, 9.85153103], [76.29930878, 9.85152912], [76.29930878, 9.85208321], [76.30041504, 9.85208321], [76.30041504, 9.85236073], [76.30124664, 9.85236073], [76.30124664, 9.85264969], [76.30152893, 9.85264969], [76.30152893, 9.85292053], [76.30180359, 9.85291672], [76.30180359, 9.85319519], [76.30208588, 9.85319519], [76.30208588, 9.85347271], [76.30253601, 9.85347271], [76.30291748, 9.85347271], [76.30291748, 9.85375118], [76.30252838, 9.85375118], [76.30236053, 9.85375118], [76.30236053, 9.85403061], [76.30208588, 9.85403061], [76.30208588, 9.85431194], [76.30152893, 9.85430527], [76.30152893, 9.85458279], [76.30124664, 9.85458279], [76.30124664, 9.85486126], [76.30069733, 9.85486126], [76.30069733, 9.85514069], [76.29985809, 9.85514069], [76.29985809, 9.85542107], [76.29902649, 9.85541725], [76.29902649, 9.85569477], [76.29875183, 9.85569477], [76.29875183, 9.85597324], [76.29846954, 9.85597324], [76.29846954, 9.85624886], [76.29818726, 9.85624886], [76.29818726, 9.85652924], [76.29792023, 9.85652924], [76.29792023, 9.85680866], [76.29763794, 9.85680485], [76.29763794, 9.85708332], [76.29736328, 9.85708141], [76.29736328, 9.85764122], [76.29708099, 9.85763931], [76.29708099, 9.8587513], [76.29680634, 9.8587513], [76.29680634, 9.86042023], [76.29651642, 9.86042023], [76.29651642, 9.86264038], [76.29680634, 9.86264038], [76.29680634, 9.86431026], [76.29652405, 9.86430645], [76.29652405, 9.86569405], [76.29624939, 9.86569118], [76.29624939, 9.86625195], [76.2959671, 9.86625195], [76.2959671, 9.86903], [76.29624939, 9.86903], [76.29624939, 9.87014008], [76.29597473, 9.87014008], [76.29597473, 9.87097168], [76.29569244, 9.87097168], [76.29569244, 9.87181091], [76.29541779, 9.87180614], [76.29541779, 9.87319374], [76.29569244, 9.87319374], [76.29569244, 9.87434959], [76.29569244, 9.87542057], [76.29541779, 9.8754158], [76.29541779, 9.87597179], [76.2951355, 9.87597179], [76.2951355, 9.87625122], [76.29541779, 9.87625122], [76.29541779, 9.87681961], [76.29569244, 9.87680435], [76.29569244, 9.88069534], [76.2959671, 9.88068962], [76.29597473, 9.88125134], [76.29569244, 9.88125134], [76.29569244, 9.88263893], [76.29541779, 9.88263035], [76.29541779, 9.88291931], [76.2951355, 9.8829174], [76.2951355, 9.8834734], [76.29458618, 9.88347054], [76.29458618, 9.88431168], [76.29429626, 9.88431168], [76.29429626, 9.88514137], [76.29458618, 9.88514137], [76.29458618, 9.88541889], [76.29486084, 9.88541698], [76.29486084, 9.88569546], [76.29514313, 9.88569069], [76.29514313, 9.88625145], [76.29541779, 9.88624859], [76.29541779, 9.88708305], [76.29569244, 9.88708305], [76.29569244, 9.88986206], [76.29652405, 9.88986206], [76.29652405, 9.88958263], [76.29763794, 9.88958263], [76.29763794, 9.88930511], [76.29818726, 9.88931179], [76.29818726, 9.88903046], [76.29846954, 9.88903046], [76.29846954, 9.88876057], [76.29875183, 9.88876057], [76.29875183, 9.88847065], [76.29902649, 9.88847446], [76.29902649, 9.88819313], [76.29930878, 9.88819313], [76.29930878, 9.88791656], [76.29957581, 9.88792038], [76.29957581, 9.88764191], [76.29985809, 9.88764191], [76.29985809, 9.88736057], [76.30014038, 9.88736057], [76.30014038, 9.88708305], [76.30041504, 9.88708305], [76.30041504, 9.88652706], [76.30069733, 9.88653183], [76.30069733, 9.88625145], [76.30097961, 9.88625145], [76.30097961, 9.88597107], [76.30152893, 9.88597107], [76.30152893, 9.88569546], [76.30180359, 9.88569546], [76.30180359, 9.88541698], [76.30208588, 9.88541889], [76.30208588, 9.88514137], [76.30236053, 9.88514137], [76.30236053, 9.88486099], [76.30263519, 9.88486099], [76.30263519, 9.88458347], [76.30291748, 9.88458347], [76.30291748, 9.884305], [76.30319214, 9.88431168], [76.30319214, 9.88402939], [76.30374908, 9.88402939], [76.30374908, 9.88375092], [76.30401611, 9.88375092], [76.30401611, 9.88347054], [76.30486298, 9.8834734], [76.30486298, 9.88319492], [76.30513763, 9.88319492], [76.30513763, 9.8829174], [76.30568695, 9.88291931], [76.30568695, 9.88263035], [76.30596924, 9.88263893], [76.30596924, 9.88236141], [76.30652618, 9.88236141], [76.30652618, 9.88208294], [76.30680847, 9.88208294], [76.30680847, 9.88180542], [76.30735779, 9.88180923], [76.30735779, 9.88152885], [76.30764008, 9.88152885], [76.30764008, 9.88125134], [76.30819702, 9.88125134], [76.30819702, 9.88097286], [76.30847168, 9.88097286], [76.30847168, 9.88041687], [76.30902863, 9.88042068], [76.30902863, 9.88014126], [76.30930328, 9.88014126], [76.30930328, 9.87986088], [76.30986023, 9.87986088], [76.30986023, 9.87958336], [76.31041718, 9.87959194], [76.31041718, 9.87931061], [76.31096649, 9.87931061], [76.31096649, 9.87903118], [76.31181335, 9.87903118], [76.31181335, 9.8787508], [76.31236267, 9.8787508], [76.31236267, 9.87847328], [76.31291962, 9.87847328], [76.31291962, 9.87819481], [76.31346893, 9.87819481], [76.31346893, 9.87791729], [76.31430817, 9.8779211], [76.31430817, 9.87764072], [76.31485748, 9.87764072], [76.31485748, 9.87736034], [76.31569672, 9.87736034], [76.31569672, 9.87708473], [76.31652832, 9.87708473], [76.31652832, 9.87680435], [76.31735992, 9.87681961], [76.31735992, 9.87653065], [76.31846619, 9.87653065], [76.31846619, 9.87625122], [76.31931305, 9.87625122], [76.31930542, 9.87485981], [76.31902313, 9.87486267], [76.31902313, 9.87403107], [76.31874847, 9.87403107], [76.31874847, 9.87345886], [76.31847382, 9.87347221], [76.31847382, 9.87291622], [76.31819153, 9.87292099], [76.31819153, 9.87181091], [76.31791687, 9.87181091], [76.31791687, 9.87125015], [76.31764221, 9.87125015], [76.31764221, 9.87014008], [76.31735992, 9.87014008], [76.31735992, 9.86903], [76.3170929, 9.86903], [76.3170929, 9.86818886], [76.31680298, 9.86819363], [76.31680298, 9.86652756], [76.3170929, 9.86653042], [76.3170929, 9.86597157], [76.31735992, 9.86597157], [76.31735992, 9.86541557], [76.3170929, 9.86542034], [76.3170929, 9.86514187], [76.31735992, 9.86514187], [76.31735992, 9.86403179], [76.31764221, 9.86403179], [76.31764221, 9.86374855], [76.31735992, 9.86374855], [76.31735992, 9.86264038], [76.3170929, 9.86264038], [76.3170929, 9.86180973], [76.31680298, 9.86180973], [76.31680298, 9.86152267], [76.31708527, 9.86152744], [76.31708527, 9.86124897], [76.31680298, 9.86125183], [76.31680298, 9.86097145], [76.31708527, 9.86097336], [76.31708527, 9.86013889], [76.31680298, 9.86013889], [76.31680298, 9.8587513], [76.31708527, 9.8587513], [76.31708527, 9.85847092], [76.31680298, 9.85847092], [76.31680298, 9.85791683], [76.31708527, 9.85791683], [76.31708527, 9.85708332], [76.31735992, 9.85708332], [76.31735992, 9.85597324], [76.31764221, 9.85597324], [76.31764221, 9.85569477], [76.31735992, 9.85569477], [76.31735992, 9.85375118], [76.31764221, 9.85375118], [76.31764221, 9.85347271], [76.31735992, 9.85347271], [76.31735992, 9.85236073], [76.31764221, 9.85236073], [76.31764221, 9.85125065], [76.31791687, 9.85125065], [76.31791687, 9.85014057], [76.31819153, 9.85014057], [76.31819153, 9.8495779], [76.31791687, 9.84958458], [76.31791687, 9.8493042], [76.31819153, 9.84931087], [76.31819153, 9.84903145], [76.31791687, 9.84903145], [76.31791687, 9.84875011], [76.31819153, 9.84875011], [76.31819153, 9.84846973], [76.31791687, 9.84847164], [76.31791687, 9.84791565], [76.31764221, 9.84792137], [76.31764221, 9.84735966], [76.31708527, 9.84736156], [76.31708527, 9.84680557], [76.31680298, 9.84681129], [76.31680298, 9.84624958], [76.3170929, 9.84624958], [76.3170929, 9.84597015], [76.31680298, 9.84597206], [76.31680298, 9.84486008], [76.31708527, 9.84486008], [76.31708527, 9.84375], [76.31735992, 9.84375], [76.31735992, 9.84318924], [76.31764221, 9.84319401], [76.31764221, 9.8423624], [76.31791687, 9.8423624], [76.31791687, 9.84069443], [76.31819153, 9.84069443], [76.31819153, 9.83958435], [76.31847382, 9.83958435], [76.31847382, 9.83930588], [76.31930542, 9.83930588], [76.31930542, 9.83958435], [76.31958008, 9.83958435], [76.31958008, 9.83902836], [76.31986237, 9.83903027], [76.31986237, 9.83847237], [76.32013702, 9.83847237], [76.32013702, 9.83736229], [76.32041931, 9.83736229], [76.32041931, 9.83652687], [76.32068634, 9.83652973], [76.32068634, 9.83597088], [76.32096863, 9.83597088], [76.32096863, 9.83541775], [76.32125092, 9.83541965], [76.32125092, 9.83485889], [76.32152557, 9.8348608], [76.32152557, 9.83430481], [76.32180786, 9.83430958], [76.32180786, 9.83375072], [76.3215332, 9.83375072], [76.3215332, 9.83319092], [76.32125092, 9.83319473], [76.32125092, 9.83263874], [76.32096863, 9.8326416], [76.32096863, 9.83125114], [76.32068634, 9.83125114], [76.32068634, 9.82736111], [76.32096863, 9.82736111], [76.32096863, 9.82430363], [76.32125092, 9.82431126], [76.32125092, 9.82403088], [76.32096863, 9.82403088], [76.32096863, 9.82347012], [76.32125092, 9.82347298], [76.32125092, 9.82263756], [76.3215332, 9.82264137], [76.3215332, 9.82181072], [76.32180786, 9.82181072], [76.32180786, 9.82069016], [76.32208252, 9.82069397], [76.32208252, 9.81930637], [76.32180786, 9.81931114], [76.32180786, 9.81818962], [76.32152557, 9.81819439], [76.32152557, 9.81708431], [76.32125092, 9.81708431], [76.32125092, 9.81597233], [76.32152557, 9.81597233], [76.32152557, 9.81513786], [76.32180786, 9.81514168], [76.32180786, 9.81458187], [76.32208252, 9.81458378], [76.32208252, 9.81264019], [76.32180786, 9.81264019], [76.32180786, 9.80764198], [76.32209015, 9.80764198], [76.32209015, 9.80681038], [76.32235718, 9.80681038], [76.32235718, 9.80625057], [76.32263947, 9.80625057], [76.32263947, 9.80597115], [76.32291412, 9.80597115], [76.32291412, 9.80569458], [76.32514191, 9.80569458], [76.32514191, 9.80597115], [76.32541656, 9.80597115], [76.32541656, 9.80569458], [76.32569122, 9.80569458], [76.32569122, 9.8040266], [76.32596588, 9.80403233], [76.32596588, 9.80291939], [76.32624817, 9.80291939], [76.32624817, 9.80264091], [76.32596588, 9.80264091], [76.32596588, 9.80180931], [76.32624817, 9.80180931], [76.32624817, 9.80154037], [76.32596588, 9.80154037], [76.32596588, 9.80097103], [76.32624817, 9.80097294], [76.32624817, 9.79986095], [76.32596588, 9.79986095], [76.32596588, 9.79903126], [76.32624817, 9.79903126], [76.32624817, 9.79875088], [76.32596588, 9.79875088], [76.32596588, 9.79818058], [76.32569122, 9.79819489], [76.32569122, 9.79736137], [76.32541656, 9.79736137], [76.32541656, 9.79652882], [76.32569122, 9.79653072], [76.32569122, 9.79514122], [76.32596588, 9.79514122], [76.32596588, 9.79458046], [76.32569122, 9.79458237], [76.32569122, 9.7943058], [76.32596588, 9.79431057], [76.32596588, 9.79403114], [76.32569122, 9.79403114], [76.32569122, 9.79319191], [76.32624817, 9.79319382], [76.32624817, 9.79263783], [76.32681274, 9.79263973], [76.32681274, 9.79207993], [76.32707977, 9.79208374], [76.32707977, 9.79152775], [76.32681274, 9.79152966], [76.32681274, 9.79014015], [76.32707977, 9.79014015], [76.32707977, 9.78903008], [76.32736206, 9.78903008], [76.32736206, 9.7881918], [76.32763672, 9.7881937], [76.32763672, 9.78791809], [76.32791901, 9.78792], [76.32791901, 9.78736019], [76.32819366, 9.7873621], [76.32819366, 9.78680611], [76.32875061, 9.78680992], [76.32875061, 9.78652954], [76.3290329, 9.78652954], [76.3290329, 9.78597164], [76.32958221, 9.78597164], [76.32958221, 9.78569412], [76.33013916, 9.78569412], [76.33013916, 9.78541565], [76.33040619, 9.78542042], [76.33040619, 9.78514194], [76.33096313, 9.78514194], [76.33096313, 9.78486156], [76.33152771, 9.78486156], [76.33152771, 9.78458405], [76.33180237, 9.78458405], [76.33180237, 9.78430557], [76.33207703, 9.78431034], [76.33207703, 9.78402996], [76.33235931, 9.78402996], [76.33235931, 9.7834692], [76.3326416, 9.78347111], [76.3326416, 9.78264046], [76.33291626, 9.78264046], [76.33291626, 9.78236198], [76.33319092, 9.78236198], [76.33319092, 9.78180504], [76.33347321, 9.78180981], [76.33347321, 9.78097057], [76.33374786, 9.78097439], [76.33374786, 9.78069305], [76.33403015, 9.78069305], [76.33403015, 9.78013897], [76.33429718, 9.78014183], [76.33429718, 9.77986145], [76.33486176, 9.77986145], [76.33486176, 9.77902699], [76.3345871, 9.77902889], [76.3345871, 9.77875137], [76.33403015, 9.77875137], [76.33403015, 9.77847099], [76.33374786, 9.77847099], [76.33374786, 9.77819538], [76.33347321, 9.77819538], [76.33347321, 9.7770834], [76.33374786, 9.7770834], [76.33374786, 9.77680492], [76.33347321, 9.77680969], [76.33347321, 9.77569008], [76.33319092, 9.77569485], [76.33319092, 9.77375126], [76.33291626, 9.77375126], [76.33291626, 9.77319527], [76.33347321, 9.77319527], [76.33347321, 9.7723608], [76.33374786, 9.7723608], [76.33374786, 9.77180672], [76.33403015, 9.77181053], [76.33403015, 9.77097034], [76.33430481, 9.77097321], [76.33430481, 9.77069473], [76.3345871, 9.77069473], [76.3345871, 9.76986027], [76.33486176, 9.76986027], [76.33486176, 9.76930428], [76.33513641, 9.76931095], [76.33513641, 9.76875114], [76.3354187, 9.76875114], [76.3354187, 9.76735973], [76.33569336, 9.76735973], [76.33569336, 9.76597214], [76.33597565, 9.76597214], [76.33597565, 9.76569366], [76.33625031, 9.76569366], [76.33625031, 9.76541615], [76.33708954, 9.76543045], [76.33708954, 9.76513958], [76.33790588, 9.76513958], [76.33790588, 9.76486015], [76.3381958, 9.76486015], [76.3381958, 9.76458359], [76.33847046, 9.76458359], [76.33847046, 9.76430607], [76.33875275, 9.76431084], [76.33875275, 9.76403046], [76.3390274, 9.76403046], [76.3390274, 9.76375008], [76.33930206, 9.76375008], [76.33930206, 9.7634697], [76.33958435, 9.7634716], [76.33958435, 9.76319408], [76.33985901, 9.76319408], [76.33985901, 9.76291561], [76.34041595, 9.76292038], [76.34041595, 9.76124954], [76.34012604, 9.76124954], [76.34012604, 9.75819111], [76.34041595, 9.75819397], [76.34041595, 9.75680637], [76.34069061, 9.75681019], [76.34069061, 9.75626087], [76.34041595, 9.75626087], [76.34041595, 9.7551403], [76.34012604, 9.7551403], [76.34012604, 9.75403023], [76.34041595, 9.75403023], [76.34041595, 9.75374889], [76.34012604, 9.75374889], [76.34012604, 9.75347137], [76.34041595, 9.75347137], [76.34041595, 9.75319481], [76.33985901, 9.75319958], [76.33985901, 9.75264168], [76.33957672, 9.75264168], [76.33957672, 9.7523613], [76.33930206, 9.7523613], [76.33930206, 9.75264168], [76.3390274, 9.75264168], [76.3390274, 9.75208092], [76.33875275, 9.75208282], [76.33875275, 9.75180531], [76.3390274, 9.75181198], [76.3390274, 9.75097084], [76.33957672, 9.75097084], [76.33957672, 9.75125122], [76.33985901, 9.75125122], [76.33985901, 9.75097084], [76.34012604, 9.75097084], [76.34012604, 9.75125122], [76.34208679, 9.75125122], [76.34208679, 9.75097084], [76.34236145, 9.75097084], [76.34236145, 9.75041676], [76.34208679, 9.75041866], [76.34208679, 9.74875069], [76.34179688, 9.74875069], [76.34179688, 9.74764061], [76.34208679, 9.74764061], [76.34208679, 9.74736118], [76.3418045, 9.74736118], [76.3418045, 9.74680519], [76.34152985, 9.74681187], [76.34152985, 9.74625111], [76.34124756, 9.74625111], [76.34124756, 9.74513912], [76.3409729, 9.74514103], [76.3409729, 9.74431992], [76.34069824, 9.74431992], [76.34069824, 9.74236012], [76.3409729, 9.74236012], [76.3409729, 9.74125004], [76.34124756, 9.74125957], [76.34124756, 9.73681068], [76.34152985, 9.73681068], [76.34152985, 9.73596954], [76.3418045, 9.7359724], [76.3418045, 9.73541641], [76.34152985, 9.73542023], [76.34152985, 9.73486042], [76.34124756, 9.73486233], [76.34124756, 9.73152828], [76.34152985, 9.73153019], [76.34152985, 9.72985935], [76.3418045, 9.72986221], [76.3418045, 9.72874928], [76.34208679, 9.72874928], [76.34208679, 9.72791767], [76.34236145, 9.72791958], [76.34236145, 9.7276392], [76.34263611, 9.7276392], [76.34263611, 9.72736073], [76.3429184, 9.72736073], [76.3429184, 9.72708321], [76.34319305, 9.72708321], [76.34319305, 9.72680473], [76.34375, 9.72681046], [76.34375, 9.72597122], [76.34430695, 9.72597122], [76.34430695, 9.72541714], [76.3445816, 9.72542191], [76.3445816, 9.72431183], [76.34485626, 9.72431183], [76.34485626, 9.72375107], [76.34513855, 9.72375107], [76.34513855, 9.72153091], [76.34485626, 9.72153091], [76.34485626, 9.71875095], [76.34513855, 9.71875095], [76.34513855, 9.71709156], [76.34485626, 9.71709156], [76.34485626, 9.71597004], [76.34513855, 9.7159729], [76.34513855, 9.71569538], [76.34486389, 9.71569538], [76.34486389, 9.71374989], [76.34513855, 9.71375275], [76.34513855, 9.71319199], [76.3456955, 9.71319389], [76.3456955, 9.71291637], [76.34625244, 9.71292114], [76.34625244, 9.71264267], [76.34707642, 9.71264267], [76.34707642, 9.71208191], [76.34764099, 9.71208191], [76.34764099, 9.7118063], [76.34819794, 9.7118063], [76.34819794, 9.71208191], [76.34902954, 9.71208191], [76.34902954, 9.71319389], [76.34874725, 9.71319199], [76.34874725, 9.71431065], [76.3484726, 9.71430683], [76.3484726, 9.71458244], [76.34874725, 9.71458244], [76.34874725, 9.71736145], [76.34902954, 9.71736145], [76.34902954, 9.71792126], [76.3493042, 9.71791744], [76.3493042, 9.71819496], [76.34958649, 9.71819019], [76.34958649, 9.71903133], [76.34986115, 9.71903133], [76.34986115, 9.72042084], [76.34958649, 9.72041702], [76.34958649, 9.72069454], [76.34986115, 9.72069454], [76.34986115, 9.72097301], [76.34958649, 9.72097111], [76.34958649, 9.72153091], [76.34986115, 9.72153091], [76.34986115, 9.72180939], [76.34958649, 9.72180462], [76.34958649, 9.72208309], [76.34986115, 9.72208309], [76.34986115, 9.72486115], [76.34958649, 9.72486115], [76.34958649, 9.72597122], [76.34929657, 9.72597122], [76.34929657, 9.72681046], [76.34902954, 9.72680473], [76.34902954, 9.72708321], [76.34874725, 9.72708321], [76.34874725, 9.72736073], [76.3484726, 9.72736073], [76.3484726, 9.7284708], [76.34819794, 9.72847366], [76.34819794, 9.72986221], [76.34791565, 9.72986221], [76.34791565, 9.73069572], [76.34764099, 9.73069572], [76.34764099, 9.73124981], [76.3473587, 9.73124981], [76.3473587, 9.73153019], [76.34708405, 9.73152828], [76.34708405, 9.73208427], [76.34680939, 9.73206997], [76.34680176, 9.73291969], [76.3465271, 9.73291779], [76.3465271, 9.73319435], [76.34625244, 9.73319054], [76.34625244, 9.7343111], [76.34597015, 9.7343111], [76.34597015, 9.73624992], [76.34570312, 9.73624992], [76.34570312, 9.73931122], [76.34541321, 9.73931122], [76.34541321, 9.7404213], [76.3456955, 9.74041557], [76.3456955, 9.74097157], [76.34597015, 9.74096966], [76.34597015, 9.74125957], [76.3465271, 9.74125004], [76.3465271, 9.74236012], [76.34680176, 9.74236012], [76.34680176, 9.74292088], [76.3465271, 9.74291706], [76.3465271, 9.74347305], [76.34680176, 9.74347019], [76.34680939, 9.74375057], [76.34707642, 9.74375057], [76.34707642, 9.74542141], [76.34680939, 9.74542141], [76.34680176, 9.74681187], [76.3465271, 9.74680519], [76.3465271, 9.74736118], [76.34680176, 9.74736118], [76.34680176, 9.74792194], [76.3465271, 9.74792194], [76.3465271, 9.75041866], [76.34625244, 9.75041676], [76.34625244, 9.75069523], [76.34597015, 9.75069523], [76.34597015, 9.75125122], [76.3456955, 9.75125122], [76.3456955, 9.75208282], [76.34541321, 9.75208092], [76.34541321, 9.75319958], [76.34513855, 9.75319481], [76.34513855, 9.75374889], [76.34485626, 9.75374889], [76.34485626, 9.75430965], [76.3445816, 9.75430489], [76.3445816, 9.75486088], [76.34430695, 9.75486088], [76.34430695, 9.7551403], [76.34375, 9.7551403], [76.34375, 9.75541973], [76.3429184, 9.75541782], [76.3429184, 9.75569344], [76.34263611, 9.75569344], [76.34263611, 9.75597095], [76.34208679, 9.75597095], [76.34208679, 9.75652981], [76.3418045, 9.7565279], [76.3418045, 9.75708389], [76.34152985, 9.75708389], [76.34152985, 9.75958443], [76.3418045, 9.75958443], [76.3418045, 9.76097202], [76.34152985, 9.76097202], [76.34152985, 9.76208401], [76.34124756, 9.7620697], [76.34124756, 9.76264], [76.3409729, 9.76264], [76.3409729, 9.76292038], [76.34069824, 9.76291561], [76.34069824, 9.7634716], [76.34041595, 9.7634697], [76.34041595, 9.76375008], [76.34012604, 9.76375008], [76.34012604, 9.76403046], [76.33985901, 9.7640276], [76.33985901, 9.76458359], [76.33958435, 9.76458359], [76.33958435, 9.76486015], [76.33930206, 9.76486015], [76.33930206, 9.76513958], [76.3390274, 9.76513767], [76.3390274, 9.76569366], [76.33875275, 9.76569366], [76.33875275, 9.76597214], [76.33847046, 9.76597023], [76.33847046, 9.76624966], [76.33790588, 9.76624966], [76.33790588, 9.76653099], [76.33763885, 9.76652813], [76.33763885, 9.76708221], [76.33735657, 9.76708031], [76.33735657, 9.76764107], [76.33708191, 9.76763821], [76.33708191, 9.76847172], [76.33680725, 9.7684679], [76.33680725, 9.76931095], [76.33651733, 9.76931095], [76.33651733, 9.77042103], [76.33625031, 9.77042103], [76.33625031, 9.77153111], [76.33598328, 9.77153111], [76.33598328, 9.77264118], [76.33569336, 9.77263927], [76.33569336, 9.77319527], [76.3354187, 9.77319527], [76.3354187, 9.77375126], [76.33569336, 9.77375126], [76.33569336, 9.77430534], [76.33597565, 9.77430534], [76.33597565, 9.77486134], [76.33569336, 9.77486134], [76.33569336, 9.77597332], [76.33597565, 9.77597332], [76.33597565, 9.7770834], [76.33625031, 9.77708054], [76.33625031, 9.77737045], [76.33652496, 9.77736092], [76.33652496, 9.77819538], [76.33680725, 9.77819061], [76.33680725, 9.77902889], [76.33651733, 9.77902889], [76.33651733, 9.77931023], [76.33625031, 9.77930546], [76.33625031, 9.77958298], [76.33651733, 9.77958107], [76.33651733, 9.78043079], [76.33680725, 9.78041744], [76.33680725, 9.78069305], [76.33652496, 9.78069305], [76.33652496, 9.78097439], [76.33680725, 9.78097439], [76.33680725, 9.78208256], [76.33708191, 9.78208256], [76.33708191, 9.78236198], [76.3373642, 9.78236198], [76.3373642, 9.78347111], [76.33763885, 9.7834692], [76.33763885, 9.78542042], [76.3373642, 9.78541565], [76.3373642, 9.78569412], [76.33763885, 9.78569412], [76.33763885, 9.78625011], [76.3373642, 9.78625011], [76.3373642, 9.78708363], [76.33708954, 9.78707886], [76.33708954, 9.78763962], [76.33680725, 9.78763962], [76.33680725, 9.78792], [76.33651733, 9.78792], [76.33651733, 9.78874969], [76.33625031, 9.78874969], [76.33625031, 9.78903008], [76.33597565, 9.78902817], [76.33597565, 9.78958416], [76.33569336, 9.78958035], [76.33569336, 9.79014015], [76.33513641, 9.79014015], [76.33513641, 9.79069424], [76.33486176, 9.79069424], [76.33486176, 9.79097176], [76.33513641, 9.79096985], [76.33513641, 9.79152966], [76.33486176, 9.79152775], [76.33486176, 9.79208374], [76.3345871, 9.79208374], [76.3345871, 9.79319382], [76.33429718, 9.79319191], [76.33429718, 9.79375267], [76.33403015, 9.79375267], [76.33403015, 9.79403114], [76.33374786, 9.79403114], [76.33374786, 9.79514122], [76.33347321, 9.79513836], [76.33347321, 9.79569435], [76.33319092, 9.79569435], [76.33319092, 9.79597282], [76.33291626, 9.79596996], [76.33291626, 9.79653072], [76.3326416, 9.79652882], [76.3326416, 9.79708195], [76.33208466, 9.79708195], [76.33208466, 9.79736137], [76.33180237, 9.79736137], [76.33180237, 9.79792118], [76.33152771, 9.79791737], [76.33152771, 9.79819489], [76.33125305, 9.79819489], [76.33125305, 9.79847336], [76.33152771, 9.79846954], [76.33152771, 9.79903126], [76.33125305, 9.79902744], [76.33125305, 9.79958344], [76.33096313, 9.79957962], [76.33096313, 9.80041885], [76.33069611, 9.80041885], [76.33069611, 9.80154037], [76.33040619, 9.80154037], [76.33040619, 9.80180931], [76.33013916, 9.80180931], [76.33013916, 9.80430984], [76.3298645, 9.80430508], [76.3298645, 9.80569458], [76.33041382, 9.80569458], [76.33041382, 9.80597115], [76.33069611, 9.80597115], [76.33069611, 9.80625057], [76.33125305, 9.80625057], [76.33125305, 9.80653191], [76.33207703, 9.80653191], [76.33207703, 9.80681038], [76.3326416, 9.80680466], [76.3326416, 9.80736065], [76.33291626, 9.80735016], [76.33291626, 9.80792046], [76.33347321, 9.80791664], [76.33347321, 9.80819321], [76.33430481, 9.80819321], [76.33430481, 9.80847359], [76.33513641, 9.80847359], [76.33513641, 9.8087492], [76.33569336, 9.8087492], [76.33569336, 9.80902958], [76.33625031, 9.80902958], [76.33625031, 9.80930996], [76.33597565, 9.80930519], [76.33597565, 9.80986214], [76.33569336, 9.80986214], [76.33569336, 9.81041527], [76.3354187, 9.81041527], [76.3354187, 9.81097221], [76.33513641, 9.81096935], [76.33513641, 9.81153202], [76.33486176, 9.81152821], [76.33486176, 9.81236172], [76.3345871, 9.81236172], [76.3345871, 9.81319427], [76.33429718, 9.81319141], [76.33429718, 9.81402969], [76.33403015, 9.81402969], [76.33403015, 9.81514168], [76.33374786, 9.81513786], [76.33374786, 9.81847191], [76.33347321, 9.81847191], [76.33347321, 9.81875038], [76.33319092, 9.81875038], [76.33319092, 9.81931114], [76.33291626, 9.81931114], [76.33291626, 9.82014275], [76.3326416, 9.82014275], [76.3326416, 9.82181072], [76.33235931, 9.82180691], [76.33235931, 9.82319546], [76.33207703, 9.82318974], [76.33207703, 9.82431126], [76.33180237, 9.82431126], [76.33180237, 9.82514095], [76.33152771, 9.82514095], [76.33152771, 9.82625103], [76.33125305, 9.82625103], [76.33125305, 9.82681179], [76.33097076, 9.82680511], [76.33097076, 9.82736111], [76.33069611, 9.82736111], [76.33069611, 9.82792091], [76.33040619, 9.82792091], [76.33040619, 9.82847977], [76.33013916, 9.82847977], [76.33013916, 9.82903099], [76.32958221, 9.82903099], [76.32958221, 9.82875061], [76.32930756, 9.82875061], [76.32930756, 9.82818985], [76.32902527, 9.82819462], [76.32902527, 9.82736111], [76.32875061, 9.82736111], [76.32875061, 9.82569504], [76.32847595, 9.82569504], [76.32847595, 9.82430363], [76.32791901, 9.82430363], [76.32791901, 9.82458305], [76.32763672, 9.82458305], [76.32763672, 9.82486057], [76.32736206, 9.82486057], [76.32736206, 9.82514095], [76.32707977, 9.82514095], [76.32707977, 9.82542133], [76.32680511, 9.82541656], [76.32680511, 9.82569504], [76.32624817, 9.82569504], [76.32624817, 9.82597256], [76.32569122, 9.82597065], [76.32569122, 9.82625103], [76.32514954, 9.82625103], [76.32514954, 9.82653141], [76.32430267, 9.82653141], [76.32430267, 9.82681179], [76.32375336, 9.82680511], [76.32375336, 9.82708263], [76.32347107, 9.82708263], [76.32347107, 9.82736111], [76.32319641, 9.82736111], [76.32319641, 9.82764053], [76.32290649, 9.82764053], [76.32290649, 9.82792091], [76.32263947, 9.82792091], [76.32263947, 9.82847977], [76.32235718, 9.82847977], [76.32235718, 9.82903099], [76.32208252, 9.82902908], [76.32208252, 9.82958317], [76.32180786, 9.82958126], [76.32180786, 9.8318119], [76.32209015, 9.8318119], [76.32209015, 9.8326416], [76.32235718, 9.8326416], [76.32235718, 9.83375072], [76.32263947, 9.83375072], [76.32263947, 9.83513927], [76.32290649, 9.83513927], [76.32291412, 9.83624935], [76.32263947, 9.83624935], [76.32263947, 9.83681011], [76.32236481, 9.8368063], [76.32236481, 9.83736229], [76.32208252, 9.83736229], [76.32208252, 9.83763981], [76.32180786, 9.83763981], [76.32180786, 9.83792019], [76.32152557, 9.83791542], [76.32152557, 9.83847237], [76.32125092, 9.83847237], [76.32125092, 9.83875179], [76.32096863, 9.83875179], [76.32096863, 9.83903027], [76.32069397, 9.83902836], [76.32069397, 9.83958435], [76.32041931, 9.83958435], [76.32041931, 9.83986187], [76.32013702, 9.83986187], [76.32013702, 9.84014034], [76.31986237, 9.84014034], [76.31986237, 9.84069443], [76.31958008, 9.84069443], [76.31958008, 9.84125042], [76.31930542, 9.84125042], [76.31930542, 9.84208393], [76.31902313, 9.84208202], [76.31902313, 9.8429203], [76.31874847, 9.8429203], [76.31874847, 9.84375], [76.31846619, 9.84375], [76.31846619, 9.84403038], [76.31874847, 9.84403038], [76.31874847, 9.84431076], [76.31903076, 9.84430599], [76.31903076, 9.84458447], [76.31874847, 9.84458447], [76.31874847, 9.84486008], [76.31902313, 9.84486008], [76.31902313, 9.84542274], [76.31930542, 9.84541607], [76.31930542, 9.84597206], [76.31958008, 9.84597206], [76.31958008, 9.84652805], [76.31986237, 9.84652805], [76.31986237, 9.84735966], [76.32013702, 9.84735966], [76.32013702, 9.84764099], [76.32041931, 9.84763813], [76.32041931, 9.84819412], [76.32013702, 9.84819412], [76.32013702, 9.84847164], [76.32041931, 9.84846973], [76.32041931, 9.85042095], [76.32069397, 9.85041714], [76.32069397, 9.85069466], [76.32041931, 9.85068989], [76.32041931, 9.85153103], [76.32013702, 9.85152912], [76.32013702, 9.85208321], [76.31986237, 9.85208035], [76.31986237, 9.85264969], [76.32013702, 9.85264969], [76.32013702, 9.85292053], [76.31986237, 9.85291672], [76.31986237, 9.85347271], [76.32013702, 9.85347271], [76.32013702, 9.85375118], [76.31986237, 9.85375118], [76.31986237, 9.85431194], [76.31958008, 9.85430527], [76.31958008, 9.85486126], [76.31986237, 9.85486126], [76.31986237, 9.85542107], [76.32013702, 9.85541725], [76.32013702, 9.85597324], [76.32041931, 9.85597134], [76.32041931, 9.85652924], [76.32069397, 9.85652733], [76.32069397, 9.85708332], [76.32096863, 9.85708332], [76.32096863, 9.85738182], [76.32096863, 9.85764122], [76.32125092, 9.85763931], [76.32125092, 9.8581953], [76.3215332, 9.85819054], [76.3215332, 9.85931015], [76.32125092, 9.85931015], [76.32125092, 9.86042023], [76.32096863, 9.86041737], [76.32096863, 9.86097336], [76.32069397, 9.86097336], [76.32069397, 9.86152744], [76.32041931, 9.86152267], [76.32041931, 9.86180973], [76.32013702, 9.86180496], [76.32013702, 9.86236095], [76.31986237, 9.86236095], [76.31986237, 9.86458969], [76.31958008, 9.86458969], [76.31958008, 9.86765099], [76.31986237, 9.86763763], [76.31986237, 9.8684721], [76.32013702, 9.8684721], [76.32013702, 9.87069416], [76.32041931, 9.87069416], [76.32041931, 9.87097168], [76.32068634, 9.87097168], [76.32068634, 9.87125015], [76.32125092, 9.87125015], [76.32125092, 9.87152958], [76.3215332, 9.87152958], [76.3215332, 9.87181091], [76.32180786, 9.87181091], [76.32180786, 9.87152958], [76.32209015, 9.87152958], [76.32209015, 9.87125015], [76.32430267, 9.87125015], [76.32430267, 9.87152958], [76.32485962, 9.87152958], [76.32485962, 9.87181091], [76.32569122, 9.87180614], [76.32569122, 9.87208366], [76.32624817, 9.87208366], [76.32624817, 9.87236214], [76.32681274, 9.87236023], [76.32681274, 9.87263966], [76.33040619, 9.87263966], [76.33040619, 9.87236023], [76.33125305, 9.87236214], [76.33125305, 9.87208366], [76.33152771, 9.87208366], [76.33152771, 9.87152767], [76.33180237, 9.87152958], [76.33180237, 9.87125015], [76.33208466, 9.87125015], [76.33207703, 9.87097168], [76.33235931, 9.87097168], [76.33235931, 9.87041569], [76.3326416, 9.87042046], [76.3326416, 9.87014008], [76.33291626, 9.87014008], [76.33291626, 9.8698597], [76.33319092, 9.8698597], [76.33319092, 9.86930561], [76.33347321, 9.86931133], [76.33347321, 9.86874962], [76.33374786, 9.86874962], [76.33374786, 9.86818886], [76.33403015, 9.86819363], [76.33403015, 9.86763763], [76.33429718, 9.86765099], [76.33429718, 9.86708164], [76.3345871, 9.86708355], [76.3345871, 9.86652756], [76.33486176, 9.86653042], [76.33486176, 9.86625195], [76.33598328, 9.86625195], [76.33598328, 9.86597157], [76.33625031, 9.86597157], [76.33625031, 9.86569405], [76.33652496, 9.86569405], [76.33652496, 9.86541557], [76.33680725, 9.86542034], [76.33680725, 9.86514187], [76.33708954, 9.86514187], [76.33708954, 9.86486244], [76.3373642, 9.86486244], [76.3373642, 9.86347103], [76.33763885, 9.86347103], [76.33763885, 9.8629179], [76.33790588, 9.86291981], [76.33790588, 9.86208057], [76.3381958, 9.86208344], [76.3381958, 9.86097336], [76.33847046, 9.86097336], [76.33847046, 9.86033058], [76.33847046, 9.86013889], [76.33875275, 9.86013889], [76.33875275, 9.85903168], [76.3390274, 9.85903168], [76.3390274, 9.8579216], [76.33957672, 9.8579216], [76.33957672, 9.85736084], [76.33985901, 9.85736084], [76.33985901, 9.85680866], [76.34012604, 9.85680866], [76.34012604, 9.85652924], [76.33985901, 9.85652924], [76.33985901, 9.85624886], [76.3401413, 9.85624886], [76.3401413, 9.85347271], [76.34041595, 9.85347271], [76.34041595, 9.85291672], [76.34012604, 9.85292053], [76.34012604, 9.85236073], [76.34041595, 9.85236073], [76.34041595, 9.84902859], [76.34012604, 9.84903145], [76.34012604, 9.84846973], [76.34041595, 9.84847164], [76.34041595, 9.84819412], [76.3401413, 9.84819412], [76.3401413, 9.84652805], [76.34041595, 9.84652805], [76.34041595, 9.84597206], [76.3401413, 9.84597206], [76.3401413, 9.84541607], [76.33985901, 9.84542274], [76.33985901, 9.84486008], [76.3401413, 9.84486008], [76.34012604, 9.8445797], [76.33985901, 9.84458447], [76.33985901, 9.84402847], [76.34012604, 9.84403038], [76.34012604, 9.84208202], [76.34041595, 9.84208393], [76.34041595, 9.84180641], [76.34012604, 9.84181023], [76.34012604, 9.84152985], [76.34041595, 9.84152985], [76.34041595, 9.84041977], [76.34069061, 9.84041977], [76.34069824, 9.83986187], [76.3409729, 9.83986187], [76.3409729, 9.83958435], [76.34124756, 9.83958435], [76.34124756, 9.83847237], [76.34152985, 9.83847237], [76.34152985, 9.8368063], [76.34179688, 9.83681011], [76.34179688, 9.83624935], [76.34208679, 9.83624935], [76.34208679, 9.83597088], [76.34236145, 9.83597088], [76.34236145, 9.83541775], [76.34263611, 9.83541965], [76.34263611, 9.83485889], [76.3429184, 9.8348608], [76.3429184, 9.83430481], [76.34319305, 9.83430958], [76.34319305, 9.83403015], [76.34375, 9.83403015], [76.34375, 9.83375072], [76.34401703, 9.83375072], [76.34401703, 9.8334713], [76.34430695, 9.8334713], [76.34430695, 9.83319473], [76.3445816, 9.83319473], [76.3445816, 9.83291721], [76.34485626, 9.83292198], [76.34485626, 9.8326416], [76.34541321, 9.8326416], [76.34541321, 9.8318119], [76.34570312, 9.8318119], [76.34570312, 9.83154106], [76.34625244, 9.83154106], [76.34625244, 9.83125114], [76.34680176, 9.83125114], [76.34680176, 9.83097267], [76.3473587, 9.83097076], [76.3473587, 9.83069515], [76.34764099, 9.83069515], [76.34764099, 9.83041668], [76.34819794, 9.83041859], [76.34819794, 9.83014107], [76.3484726, 9.83014107], [76.3484726, 9.82903099], [76.34874725, 9.82903099], [76.34874725, 9.82875061], [76.34902954, 9.82875061], [76.34902954, 9.82792091], [76.34958649, 9.82792091], [76.34958649, 9.82764053], [76.34986115, 9.82764053], [76.34986115, 9.82736111], [76.35069275, 9.82736111], [76.35069275, 9.82708263], [76.35097504, 9.82708263], [76.35097504, 9.82680511], [76.35124969, 9.82681179], [76.35124969, 9.82653141], [76.35151672, 9.82653141], [76.35151672, 9.82625103], [76.35180664, 9.82625103], [76.35180664, 9.82597065], [76.3520813, 9.82597256], [76.3520813, 9.82541656], [76.35263824, 9.82542133], [76.35263824, 9.82514095], [76.35320282, 9.82514095], [76.35320282, 9.82458019], [76.35346985, 9.82458305], [76.35346985, 9.82430363], [76.35375214, 9.82431126], [76.35375214, 9.82403088], [76.35402679, 9.82403088], [76.35402679, 9.82375145], [76.35430908, 9.82375145], [76.35430908, 9.82347012], [76.35430908, 9.82319546], [76.3548584, 9.82319546], [76.3548584, 9.82291603], [76.35542297, 9.82291889], [76.35542297, 9.82264137], [76.35597229, 9.82264137], [76.35597229, 9.82235146], [76.35624695, 9.82236004], [76.35624695, 9.82208538], [76.35708618, 9.82208538], [76.35708618, 9.82180691], [76.35736084, 9.82181072], [76.35736084, 9.8215313], [76.35930634, 9.8215313], [76.35930634, 9.82124996], [76.35958099, 9.82124996], [76.35958099, 9.82096958], [76.35986328, 9.82097244], [76.35986328, 9.82069397], [76.36069489, 9.82069397], [76.36069489, 9.82041645], [76.36096954, 9.82041645], [76.36096954, 9.82069397], [76.36125183, 9.82069397], [76.36125183, 9.82041645], [76.36152649, 9.82042122], [76.36152649, 9.82014275], [76.36207581, 9.82014275], [76.36207581, 9.82042122], [76.36235809, 9.82042122], [76.36235809, 9.82014275], [76.36429596, 9.82014275], [76.36429596, 9.82042122], [76.36458588, 9.82041645], [76.36458588, 9.82069397], [76.36514282, 9.82069016], [76.36514282, 9.82124996], [76.36486053, 9.82124996], [76.36486053, 9.8215313], [76.36514282, 9.8215313], [76.36514282, 9.82291889], [76.36541748, 9.82291889], [76.36541748, 9.82264137], [76.36569214, 9.82264137], [76.36569214, 9.82235146], [76.3659668, 9.82235146], [76.3659668, 9.82264137], [76.36653137, 9.82264137], [76.36653137, 9.82291889], [76.36736298, 9.82291889], [76.36736298, 9.82264137], [76.36791992, 9.82264137], [76.36791992, 9.82235146], [76.36819458, 9.82236004], [76.36819458, 9.82208538], [76.36875153, 9.82208538], [76.36875153, 9.82180691], [76.36930847, 9.82181072], [76.36930847, 9.8215313], [76.36958313, 9.8215313], [76.36958313, 9.82124996], [76.36985779, 9.82124996], [76.36985779, 9.82096958], [76.37014008, 9.82097244], [76.37014008, 9.82069397], [76.37041473, 9.82069397], [76.37041473, 9.82013798], [76.37069702, 9.82014275], [76.37069702, 9.81735992], [76.3704071, 9.81735992], [76.3704071, 9.81624985], [76.37013245, 9.81624985], [76.37013245, 9.81569195], [76.36985779, 9.81569386], [76.36985779, 9.81513786], [76.36958313, 9.81514168], [76.36958313, 9.81458187], [76.36930847, 9.81458378], [76.36930847, 9.81430626], [76.36846924, 9.81431007], [76.36846924, 9.81402969], [76.36818695, 9.81402969], [76.36818695, 9.81431007], [76.36791992, 9.81430626], [76.36791992, 9.81458378], [76.36763763, 9.81458187], [76.36763763, 9.81514168], [76.36736298, 9.81514168], [76.36736298, 9.81542015], [76.36624908, 9.81542015], [76.36624908, 9.81514168], [76.36486053, 9.81514168], [76.36486053, 9.81458187], [76.36458588, 9.81458378], [76.36458588, 9.81430626], [76.36680603, 9.81431007], [76.36680603, 9.81402969], [76.36707306, 9.81402969], [76.36707306, 9.81348133], [76.36736298, 9.81348133], [76.36736298, 9.81264019], [76.36707306, 9.81264019], [76.36707306, 9.81096935], [76.36680603, 9.81097221], [76.36680603, 9.81069565], [76.36653137, 9.81069565], [76.36653137, 9.81041527], [76.36597443, 9.81041527], [76.36597443, 9.81013966], [76.36569214, 9.81013966], [76.36569214, 9.80985928], [76.36541748, 9.80986214], [76.36541748, 9.80958366], [76.36513519, 9.80958366], [76.36513519, 9.80930519], [76.36486053, 9.80930996], [76.36486053, 9.80902958], [76.36458588, 9.80902958], [76.36458588, 9.8087492], [76.36429596, 9.8087492], [76.36429596, 9.80847073], [76.36402893, 9.80847359], [76.36402893, 9.80819321], [76.36374664, 9.80819321], [76.36374664, 9.80791664], [76.36347198, 9.80792046], [76.36347198, 9.80764198], [76.36319733, 9.80764198], [76.36319733, 9.80735016], [76.36291504, 9.80736065], [76.36291504, 9.80708313], [76.36264038, 9.80708313], [76.36264038, 9.80652714], [76.36235809, 9.80653191], [76.36235809, 9.80625057], [76.36207581, 9.80625057], [76.36207581, 9.80569077], [76.36180878, 9.80569458], [76.36180878, 9.80541706], [76.36152649, 9.80542183], [76.36152649, 9.80486107], [76.36125183, 9.80486107], [76.36125183, 9.80430508], [76.36096954, 9.80430984], [76.36096954, 9.80375099], [76.36068726, 9.80375099], [76.36068726, 9.80291939], [76.36042023, 9.80291939], [76.36042023, 9.80236053], [76.36013794, 9.80236053], [76.36013794, 9.80097294], [76.35986328, 9.80097294], [76.35986328, 9.79875088], [76.35958099, 9.79875088], [76.35958099, 9.7968111], [76.35986328, 9.7968111], [76.35986328, 9.79541016], [76.36013794, 9.79541588], [76.36013794, 9.79458237], [76.36042023, 9.79458237], [76.36042023, 9.79374981], [76.36068726, 9.79375267], [76.36068726, 9.79292107], [76.36096954, 9.79292107], [76.36096954, 9.79207993], [76.36125183, 9.79208374], [76.36125183, 9.79097176], [76.36152649, 9.79097176], [76.36152649, 9.78958416], [76.36180878, 9.78958416], [76.36180878, 9.78902817], [76.36207581, 9.78903008], [76.36207581, 9.78874969], [76.36235809, 9.78874969], [76.36235809, 9.78792], [76.36264038, 9.78792], [76.36264038, 9.78707886], [76.36291504, 9.78708363], [76.36291504, 9.78652763], [76.36319733, 9.78652954], [76.36319733, 9.78597164], [76.36347198, 9.78597164], [76.36347198, 9.78578854], [76.36347198, 9.78541565], [76.36374664, 9.78542042], [76.36374664, 9.78486156], [76.36402893, 9.78486156], [76.36402893, 9.78430557], [76.36429596, 9.78431034], [76.36429596, 9.78374958], [76.36458588, 9.78374958], [76.36458588, 9.78318024], [76.36486053, 9.78319263], [76.36486053, 9.78236198], [76.36513519, 9.78236198], [76.36513519, 9.78180504], [76.36541748, 9.78180981], [76.36541748, 9.78125191], [76.36569214, 9.78125191], [76.36569214, 9.78069115], [76.36597443, 9.78069305], [76.36597443, 9.78013897], [76.36624908, 9.78014183], [76.36624908, 9.77958107], [76.36653137, 9.77958298], [76.36653137, 9.77902699], [76.36680603, 9.77902889], [76.36680603, 9.77847099], [76.36708069, 9.77847099], [76.36708069, 9.77763939], [76.36736298, 9.7776413], [76.36736298, 9.77708054], [76.36763763, 9.7770834], [76.36763763, 9.77680492], [76.36791992, 9.77680969], [76.36791992, 9.77541924], [76.36818695, 9.77541924], [76.36818695, 9.77486134], [76.36846924, 9.77486134], [76.36846924, 9.77430534], [76.36875153, 9.77430534], [76.36875153, 9.77263927], [76.36902618, 9.77264118], [76.36902618, 9.7723608], [76.36875153, 9.7723608], [76.36875153, 9.77125072], [76.36902618, 9.77125072], [76.36902618, 9.76763821], [76.36875153, 9.76764107], [76.36875153, 9.76735973], [76.36846924, 9.76735973], [76.36846924, 9.76652813], [76.36818695, 9.76653099], [76.36818695, 9.76513958], [76.36791992, 9.76513958], [76.36791992, 9.76292038], [76.36763763, 9.76292038], [76.36763763, 9.76264], [76.36791992, 9.76264], [76.36791992, 9.76235962], [76.36763763, 9.76236153], [76.36763763, 9.76180553], [76.36736298, 9.76181126], [76.36736298, 9.76124954], [76.36763763, 9.76124954], [76.36763763, 9.75986195], [76.36791992, 9.75986195], [76.36791992, 9.75874996], [76.36818695, 9.75875187], [76.36818695, 9.75847244], [76.36791992, 9.75847244], [76.36791992, 9.75791645], [76.36818695, 9.75792027], [76.36819458, 9.75704002], [76.36819458, 9.75680637], [76.36846924, 9.75681019], [76.36846924, 9.75597095], [76.36875153, 9.75597095], [76.36875153, 9.75541782], [76.36846924, 9.75541973], [76.36846924, 9.7551403], [76.36875153, 9.7551403], [76.36875153, 9.75430965], [76.36902618, 9.75430965], [76.36902618, 9.75319958], [76.36930847, 9.75319958], [76.36930847, 9.75208092], [76.36958313, 9.75208282], [76.36958313, 9.75125122], [76.36985779, 9.75125122], [76.36985779, 9.74986076], [76.37013245, 9.74986076], [76.37013245, 9.74875069], [76.3704071, 9.74875069], [76.3704071, 9.74653053], [76.37013245, 9.74653053], [76.37013245, 9.74514103], [76.36985779, 9.74514103], [76.36985779, 9.74458027], [76.36958313, 9.74458313], [76.36958313, 9.74375057], [76.36930847, 9.74375057], [76.36930847, 9.74264145], [76.36958313, 9.74264145], [76.36958313, 9.74236012], [76.37014008, 9.74236012], [76.37013245, 9.74207973], [76.37069702, 9.74208546], [76.37069702, 9.74180698], [76.37124634, 9.74180889], [76.37124634, 9.74153137], [76.37180328, 9.74153137], [76.37180328, 9.73847008], [76.37208557, 9.73847198], [76.37208557, 9.73791599], [76.37180328, 9.73792076], [76.37180328, 9.73764038], [76.37152863, 9.73764038], [76.37152863, 9.73707962], [76.37124634, 9.73708439], [76.37124634, 9.73680592], [76.37152863, 9.73681068], [76.37152863, 9.7365303], [76.37124634, 9.7365303], [76.37124634, 9.73596954], [76.37097168, 9.7359724], [76.37097168, 9.73541641], [76.37124634, 9.73542023], [76.37124634, 9.73513126], [76.37097168, 9.73513794], [76.37097168, 9.73458385], [76.37124634, 9.73458385], [76.37124634, 9.73430634], [76.37097168, 9.7343111], [76.37097168, 9.73403168], [76.37069702, 9.73403168], [76.37069702, 9.73347187], [76.37041473, 9.73347187], [76.37041473, 9.7318058], [76.37013245, 9.73180962], [76.37013245, 9.73096943], [76.36985779, 9.73097229], [76.36985779, 9.73069572], [76.36958313, 9.73069572], [76.36958313, 9.73013973], [76.36875153, 9.73013973], [76.36875153, 9.72985935], [76.36846924, 9.72986221], [76.36846924, 9.72958374], [76.36736298, 9.72958374], [76.36736298, 9.72902679], [76.36680603, 9.72902966], [76.36680603, 9.72846889], [76.36653137, 9.7284708], [76.36653137, 9.7276392], [76.36624908, 9.7276392], [76.36624908, 9.72736073], [76.36653137, 9.72736073], [76.36653137, 9.72597122], [76.36624908, 9.72597122], [76.36624908, 9.72263908], [76.3659668, 9.72264099], [76.3659668, 9.72068977], [76.36624908, 9.72069454], [76.36624908, 9.71986103], [76.36680603, 9.71986103], [76.36680603, 9.71902657], [76.36707306, 9.71903133], [76.36707306, 9.71736145], [76.36680603, 9.71736145], [76.36680603, 9.71569538], [76.36653137, 9.71569538], [76.36653137, 9.71374989], [76.36680603, 9.71375275], [76.36680603, 9.71347046], [76.36653137, 9.71347237], [76.36653137, 9.7118063], [76.36624908, 9.71181107], [76.36624908, 9.71068954], [76.36597443, 9.71069431], [76.36597443, 9.71041584], [76.36569214, 9.71042061], [76.36569214, 9.70985985], [76.36541748, 9.70985985], [76.36541748, 9.70930576], [76.36514282, 9.70931053], [76.36514282, 9.70903015], [76.36486053, 9.70903015], [76.36486053, 9.70847034], [76.36458588, 9.70847225], [76.36458588, 9.7056942], [76.36430359, 9.7056942], [76.36430359, 9.70430565], [76.36402893, 9.70431042], [76.36402893, 9.70346928], [76.36374664, 9.70347214], [76.36374664, 9.70291805], [76.36319733, 9.70291996], [76.36319733, 9.70263958], [76.36235809, 9.70263958], [76.36235809, 9.70291996], [76.36125946, 9.70291996], [76.36125946, 9.70263958], [76.36096954, 9.70263958], [76.36096954, 9.7023592], [76.36069489, 9.70236206], [76.36069489, 9.70041656], [76.36096954, 9.70042038], [76.36096954, 9.70014191], [76.36125946, 9.70014191], [76.36125946, 9.69958115], [76.36180878, 9.69958305], [76.36180878, 9.69930458], [76.36235809, 9.69930458], [76.36235809, 9.69958305], [76.36291504, 9.69958305], [76.36291504, 9.69874859], [76.36319733, 9.69875145], [76.36319733, 9.69847107], [76.36347198, 9.69847107], [76.36347198, 9.69791698], [76.36374664, 9.69791985], [76.36374664, 9.69764137], [76.36402893, 9.69764137], [76.36402893, 9.69736099], [76.36458588, 9.69736099], [76.36458588, 9.69708347], [76.36486053, 9.69708347], [76.36486053, 9.696805], [76.36514282, 9.69680977], [76.36514282, 9.69625092], [76.36541748, 9.69625092], [76.36541748, 9.69569111], [76.36569214, 9.69569492], [76.36569214, 9.69513893], [76.36541748, 9.69514084], [76.36541748, 9.69375134], [76.36569214, 9.69375134], [76.36569214, 9.69319534], [76.36597443, 9.69319534], [76.36597443, 9.69263935], [76.36653137, 9.69264126], [76.36653137, 9.69207954], [76.36680603, 9.69208336], [76.36680603, 9.69180679], [76.36736298, 9.69181061], [76.36736298, 9.69153118], [76.36763763, 9.69153118], [76.36763763, 9.6912508], [76.36791992, 9.6912508], [76.36791992, 9.69097328], [76.36875153, 9.69097328], [76.36875153, 9.69041729], [76.36902618, 9.6904211], [76.36902618, 9.6898613], [76.36958313, 9.6898613], [76.36958313, 9.68958473], [76.36985779, 9.68958473], [76.36985779, 9.68875122], [76.37014008, 9.68875122], [76.37013245, 9.68847275], [76.3704071, 9.68847275], [76.3704071, 9.68819046], [76.37069702, 9.68819427], [76.37069702, 9.68708229], [76.37097168, 9.68708229], [76.37097168, 9.68624973], [76.37124634, 9.68624973], [76.37124634, 9.68597031], [76.37152863, 9.68597221], [76.37152863, 9.68541622], [76.37180328, 9.68542099], [76.37180328, 9.68513966], [76.37236023, 9.68513966], [76.37236023, 9.68486023], [76.37291718, 9.68486023], [76.37291718, 9.68458366], [76.37458038, 9.68458366], [76.37458038, 9.68430614], [76.37513733, 9.68430614], [76.37513733, 9.68458366], [76.37708282, 9.68458366], [76.37708282, 9.68430614], [76.37735748, 9.68431091], [76.37735748, 9.684021], [76.37819672, 9.68402767], [76.37819672, 9.68375015], [76.37902832, 9.68375015], [76.37902832, 9.68347168], [76.38097382, 9.68347168], [76.38097382, 9.68319416], [76.38153076, 9.68319416], [76.38153076, 9.68291569], [76.38207245, 9.68292141], [76.38207245, 9.68264008], [76.38263702, 9.68264008], [76.38263702, 9.6823597], [76.38291931, 9.6823597], [76.38291931, 9.68208408], [76.38319397, 9.68208408], [76.38319397, 9.68152809], [76.38346863, 9.68153], [76.38346863, 9.68013954], [76.38318634, 9.68013954], [76.38318634, 9.67986202], [76.38346863, 9.67986202], [76.38346863, 9.67930603], [76.38375092, 9.67930984], [76.38375092, 9.67903042], [76.38430786, 9.67903042], [76.38430786, 9.67875195], [76.38735962, 9.67875195], [76.38735962, 9.67903042], [76.38846588, 9.67903042], [76.38846588, 9.67930984], [76.38930511, 9.67930603], [76.38930511, 9.67958355], [76.39097595, 9.67958355], [76.39097595, 9.67930603], [76.3915329, 9.67930984], [76.3915329, 9.67903042], [76.39235687, 9.67903042], [76.39235687, 9.67875195], [76.39319611, 9.67875195], [76.39319611, 9.67847157], [76.39347076, 9.67847157], [76.39347076, 9.67819405], [76.39375305, 9.67819405], [76.39375305, 9.67763996], [76.39430237, 9.67763996], [76.39430237, 9.6770792], [76.39458466, 9.67708397], [76.39458466, 9.67680645], [76.39541626, 9.67681026], [76.39541626, 9.67653179], [76.39597321, 9.67653179], [76.39597321, 9.67625046], [76.39653015, 9.67625046], [76.39653015, 9.67597103], [76.39679718, 9.67597103], [76.39679718, 9.67625046], [76.39736938, 9.67625046], [76.39736938, 9.67597103], [76.39875031, 9.67597103], [76.39875031, 9.67430496], [76.39819336, 9.67430973], [76.39819336, 9.6740303], [76.39763641, 9.6740303], [76.39763641, 9.67430973], [76.39736176, 9.67430496], [76.39736176, 9.67458344], [76.39680481, 9.67458344], [76.39680481, 9.67486191], [76.39597321, 9.67485046], [76.39597321, 9.67541981], [76.39541626, 9.6754179], [76.39541626, 9.67569256], [76.3951416, 9.67569256], [76.3951416, 9.6754179], [76.39485931, 9.6754179], [76.39485931, 9.67569256], [76.39458466, 9.67569256], [76.39458466, 9.67514038], [76.39430237, 9.67514038], [76.39430237, 9.67541981], [76.39402771, 9.67541981], [76.39402771, 9.67514038], [76.39375305, 9.67514038], [76.39375305, 9.67541981], [76.39347076, 9.67541981], [76.39347076, 9.67514038], [76.39319611, 9.67514038], [76.39319611, 9.67430973], [76.39290619, 9.67430973], [76.39290619, 9.67347145], [76.39263916, 9.67347431], [76.39263916, 9.67291737], [76.39235687, 9.67292023], [76.39235687, 9.67236137], [76.39208221, 9.67236137], [76.39208221, 9.6712513], [76.39180756, 9.6712513], [76.39180756, 9.66902733], [76.39208221, 9.66904068], [76.39208221, 9.66875076], [76.39180756, 9.66875076], [76.39180756, 9.66792202], [76.39208221, 9.66792202], [76.39208221, 9.66736126], [76.39180756, 9.66736126], [76.39180756, 9.66375065], [76.39208221, 9.66375065], [76.39208221, 9.66264057], [76.39180756, 9.66264057], [76.39180756, 9.66236019], [76.39208221, 9.66236019], [76.39208221, 9.66125107], [76.39180756, 9.66125107], [76.39180756, 9.66069031], [76.39152527, 9.66069412], [76.39152527, 9.65986347], [76.39125061, 9.65986347], [76.39125061, 9.65930557], [76.39097595, 9.65931129], [76.39097595, 9.65874958], [76.39068604, 9.65874958], [76.39068604, 9.65818977], [76.39013672, 9.65819359], [76.39013672, 9.6576376], [76.38986206, 9.65764046], [76.38986206, 9.65736008], [76.38930511, 9.65736008], [76.38930511, 9.65708447], [76.38903046, 9.65708447], [76.38903046, 9.65652847], [76.38846588, 9.65653038], [76.38846588, 9.65625], [76.38819885, 9.65625], [76.38819885, 9.65596962], [76.38791656, 9.65597153], [76.38791656, 9.65569401], [76.38735962, 9.65569401], [76.38735962, 9.65541553], [76.38707733, 9.65542126], [76.38707733, 9.65513992], [76.38680267, 9.65513992], [76.38680267, 9.65485954], [76.38625336, 9.6548624], [76.38625336, 9.65458393], [76.38513947, 9.65458393], [76.38513947, 9.65430641], [76.38430786, 9.65431118], [76.38430786, 9.65403938], [76.38375092, 9.65403938], [76.38375092, 9.65375042], [76.38318634, 9.65375042], [76.38318634, 9.65319157], [76.38291931, 9.65319443], [76.38291931, 9.65291786], [76.38263702, 9.65292263], [76.38263702, 9.65264034], [76.38236237, 9.65264034], [76.38236237, 9.65208244], [76.38208008, 9.65208435], [76.38208008, 9.65152836], [76.38236237, 9.65153027], [76.38236237, 9.64874935], [76.38207245, 9.64874935], [76.38207245, 9.64791107], [76.38180542, 9.64791775], [76.38180542, 9.64764023], [76.38153076, 9.64764023], [76.38153076, 9.64569092], [76.38124847, 9.64569473], [76.38124847, 9.64486122], [76.38096619, 9.6448698], [76.38096619, 9.64291859], [76.38069153, 9.64291859], [76.38069153, 9.64181042], [76.38014221, 9.64181042], [76.38014221, 9.64153099], [76.37985992, 9.64153099], [76.37985992, 9.64125061], [76.38014221, 9.64125061], [76.38014221, 9.64097118], [76.37985992, 9.64097309], [76.37985992, 9.63902664], [76.38014221, 9.63903141], [76.38014221, 9.63819027], [76.38041687, 9.63819504], [76.38041687, 9.63763905], [76.38069153, 9.63764095], [76.38069153, 9.63681126], [76.38096619, 9.63681126], [76.38096619, 9.63597012], [76.38124847, 9.63597298], [76.38124847, 9.63347244], [76.38097382, 9.63347244], [76.38097382, 9.63263798], [76.38041687, 9.63264275], [76.38041687, 9.63208199], [76.38014221, 9.63208199], [76.38014221, 9.63125038], [76.37985992, 9.63125038], [76.37985992, 9.63069439], [76.37958527, 9.63069439], [76.37958527, 9.6301403], [76.37930298, 9.6301403], [76.37930298, 9.62931061], [76.37902832, 9.62931061], [76.37902832, 9.62874985], [76.37874603, 9.62874985], [76.37874603, 9.62792015], [76.37847137, 9.62792015], [76.37847137, 9.62708187], [76.37819672, 9.62708378], [76.37819672, 9.62652779], [76.3779068, 9.62652969], [76.3779068, 9.62569141], [76.37763977, 9.62569427], [76.37763977, 9.62514019], [76.37735748, 9.62514019], [76.37735748, 9.62458229], [76.37708282, 9.6245842], [76.37708282, 9.62430573], [76.37680817, 9.62430954], [76.37680817, 9.62319088], [76.37652588, 9.62319565], [76.37652588, 9.62291527], [76.37625885, 9.62292004], [76.37625885, 9.62263966], [76.37596893, 9.62263966], [76.37596893, 9.62180996], [76.37568665, 9.62180996], [76.37568665, 9.62152958], [76.37458038, 9.62152958], [76.37458038, 9.6212492], [76.37403107, 9.6212492], [76.37403107, 9.62097359], [76.37374878, 9.62097359], [76.37374878, 9.62041759], [76.37346649, 9.62042046], [76.37346649, 9.61986065], [76.37291718, 9.61986065], [76.37291718, 9.61874866], [76.37264252, 9.61875057], [76.37264252, 9.61847115], [76.37236023, 9.61847115], [76.37236023, 9.61819458], [76.37208557, 9.61819458], [76.37208557, 9.61791706], [76.37180328, 9.61793137], [76.37180328, 9.6176424], [76.37152863, 9.6176424], [76.37152863, 9.61736107], [76.37124634, 9.61736107], [76.37124634, 9.6170826], [76.37097168, 9.6170826], [76.37097168, 9.61597347], [76.37041473, 9.61597347], [76.37041473, 9.61541653], [76.36985779, 9.61541939], [76.36985779, 9.61458111], [76.36958313, 9.61458302], [76.36958313, 9.61319542], [76.36930847, 9.61319542], [76.36930847, 9.61291695], [76.36902618, 9.61291885], [76.36902618, 9.61264133], [76.36875153, 9.61264133], [76.36875153, 9.61236095], [76.36846924, 9.61236095], [76.36846924, 9.61208344], [76.36819458, 9.61208344], [76.36819458, 9.61180687], [76.36791992, 9.61180687], [76.36791992, 9.61152744], [76.36736298, 9.61153126], [76.36736298, 9.61097145], [76.36708069, 9.61097336], [76.36708069, 9.60847282], [76.36736298, 9.60847282], [76.36736298, 9.60763836], [76.36707306, 9.60764122], [76.36707306, 9.60708046], [76.36680603, 9.60708237], [76.36680603, 9.60652828], [76.36653137, 9.60653114], [76.36653137, 9.60570145], [76.36624908, 9.60570145], [76.36624908, 9.60486031], [76.36597443, 9.60486031], [76.36597443, 9.60347176], [76.36624908, 9.60347176], [76.36624908, 9.60264015], [76.3659668, 9.60264015], [76.3659668, 9.60124969], [76.36569214, 9.60124969], [76.36569214, 9.60042], [76.36541748, 9.60042], [76.36541748, 9.59986019], [76.36486053, 9.5998621], [76.36486053, 9.59958363], [76.36458588, 9.59958363], [76.36458588, 9.59930611], [76.36429596, 9.59930992], [76.36429596, 9.59875202], [76.36402893, 9.59875202], [76.36402893, 9.59847164], [76.36374664, 9.59847164], [76.36374664, 9.59764004], [76.36402893, 9.59764004], [76.36402893, 9.59707928], [76.36374664, 9.59708405], [76.36374664, 9.59680557], [76.36402893, 9.59680557], [76.36402893, 9.59430504], [76.36429596, 9.5943079], [76.36429596, 9.59403038], [76.36458588, 9.59403038], [76.36458588, 9.59347057], [76.36513519, 9.59347439], [76.36513519, 9.59319305], [76.36597443, 9.59319305], [76.36597443, 9.59263897], [76.36624908, 9.59264183], [76.36624908, 9.59181023], [76.3659668, 9.59181023], [76.3659668, 9.59125137], [76.36569214, 9.59125137], [76.36569214, 9.59013939], [76.36541748, 9.59013939], [76.36541748, 9.58930969], [76.36514282, 9.58930969], [76.36514282, 9.58902931], [76.36541748, 9.58902931], [76.36541748, 9.58847141], [76.36569214, 9.58847332], [76.36569214, 9.58763885], [76.36597443, 9.58763885], [76.36597443, 9.58736134], [76.36624908, 9.58736134], [76.36624908, 9.58708286], [76.36708069, 9.58708286], [76.36708069, 9.58652687], [76.36736298, 9.58653069], [76.36736298, 9.58514118], [76.36763763, 9.58514118], [76.36763763, 9.58331108]]], [[[76.25208282, 10.0162487], [76.25208282, 10.01708317], [76.25291443, 10.01708317], [76.25291443, 10.01375103], [76.25347137, 10.01375103], [76.25347137, 10.0134697], [76.25375366, 10.01347256], [76.25375366, 10.01291656], [76.25347137, 10.01292133], [76.25347137, 10.01264095], [76.25374603, 10.01264095], [76.25374603, 10.01235962], [76.25180817, 10.01235962], [76.25180817, 10.01319504], [76.25125122, 10.01319504], [76.25125122, 10.01347256], [76.25096893, 10.0134697], [76.25096893, 10.01375103], [76.25041962, 10.01375103], [76.25041962, 10.01431084], [76.25152588, 10.01431084], [76.25152588, 10.01403141], [76.25208282, 10.01403141], [76.25208282, 10.01515007], [76.25180817, 10.01515007], [76.25180817, 10.01625061], [76.25208282, 10.0162487]]], [[[76.26569366, 10.03041553], [76.26569366, 10.03069401], [76.26597595, 10.03069401], [76.26597595, 10.03013992], [76.26569366, 10.03013992], [76.26569366, 10.02791786], [76.26597595, 10.02791977], [76.26597595, 10.02709103], [76.26625061, 10.02709103], [76.26625061, 10.02653027], [76.2665329, 10.02653027], [76.2665329, 10.02597141], [76.26680756, 10.02597141], [76.26680756, 10.02541542], [76.26708221, 10.02542019], [76.26708221, 10.02291965], [76.26568604, 10.02291965], [76.26568604, 10.02263927], [76.26403046, 10.02263927], [76.26403046, 10.02235889], [76.26264191, 10.0223608], [76.26264191, 10.02180481], [76.26319122, 10.02180958], [76.26319122, 10.0215292], [76.26346588, 10.0215292], [76.26346588, 10.02095985], [76.26374817, 10.02097321], [76.26374817, 10.02069473], [76.26403046, 10.02069473], [76.26403046, 10.02041721], [76.26431274, 10.02042198], [76.26431274, 10.01986122], [76.26457977, 10.01986122], [76.26457977, 10.01958275], [76.26486206, 10.01958275], [76.26486206, 10.01930523], [76.26513672, 10.0193119], [76.26513672, 10.01875114], [76.26486206, 10.01875114], [76.26486206, 10.01847267], [76.26264191, 10.01847267], [76.26264191, 10.01875114], [76.26207733, 10.01875114], [76.26207733, 10.01903152], [76.2618103, 10.01903152], [76.2618103, 10.0193119], [76.26152802, 10.01930523], [76.26152802, 10.01986122], [76.26125336, 10.01986122], [76.26125336, 10.02014065], [76.26069641, 10.02014065], [76.26069641, 10.02042198], [76.26041412, 10.02041721], [76.26041412, 10.02069473], [76.25986481, 10.02069473], [76.25986481, 10.02097321], [76.2590332, 10.02095985], [76.2590332, 10.0215292], [76.25875092, 10.0215292], [76.25875092, 10.02180958], [76.25846863, 10.02180481], [76.25846863, 10.0223608], [76.25818634, 10.02235889], [76.25818634, 10.02291965], [76.25791931, 10.02291679], [76.25791931, 10.02374935], [76.25818634, 10.02374935], [76.25818634, 10.02431011], [76.25902557, 10.02430534], [76.25902557, 10.02458286], [76.25930786, 10.02458286], [76.25930786, 10.02486229], [76.25985718, 10.02485943], [76.25985718, 10.02513981], [76.26013947, 10.02513981], [76.26013947, 10.02542019], [76.26041412, 10.02541542], [76.26041412, 10.0256958], [76.26069641, 10.0256958], [76.26069641, 10.02736187], [76.26125336, 10.02736187], [76.26125336, 10.02764034], [76.26152802, 10.02764034], [76.26152802, 10.02819443], [76.26180267, 10.02819443], [76.26180267, 10.02875042], [76.26235962, 10.02875042], [76.26235962, 10.02902985], [76.26264191, 10.02902985], [76.26264191, 10.02931023], [76.26235962, 10.02930641], [76.26235962, 10.02958393], [76.26208496, 10.02958393], [76.26208496, 10.03013992], [76.2618103, 10.03013134], [76.2618103, 10.0304203], [76.26569366, 10.03041553]]], [[[76.26041412, 10.02958393], [76.26041412, 10.0298624], [76.26180267, 10.0298624], [76.26180267, 10.02930641], [76.26152802, 10.02931023], [76.26152802, 10.02902985], [76.26125336, 10.02902985], [76.26125336, 10.02875042], [76.26097107, 10.02875042], [76.26097107, 10.02847195], [76.26041412, 10.02847195], [76.26041412, 10.02736187], [76.26013947, 10.02736187], [76.26013947, 10.02652836], [76.25958252, 10.02653027], [76.25958252, 10.02569103], [76.25930786, 10.0256958], [76.25930786, 10.02513981], [76.25819397, 10.02513981], [76.25819397, 10.0256958], [76.25846863, 10.02569103], [76.25846863, 10.02709103], [76.25875092, 10.02709103], [76.25875092, 10.02764034], [76.25902557, 10.02764034], [76.25902557, 10.02819443], [76.25930786, 10.02819443], [76.25930786, 10.02875042], [76.25958252, 10.02875042], [76.25958252, 10.02931023], [76.25986481, 10.02930641], [76.25986481, 10.02958393], [76.26041412, 10.02958393]]]]}}, {\\\"id\\\": \\\"16\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.19_1\\\", \\\"HASC_1\\\": \\\"IN.MP\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Madhya Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -21.2, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1013.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1789.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -776.0, \\\"geo-id\\\": 16, \\\"hpm25_child_popweighted\\\": -206.4, \\\"hpm25_female_popweighted\\\": -237.3, \\\"hpm25_male_popweighted\\\": -170.8, \\\"location\\\": \\\"Madhya Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 24034.0, \\\"mort_hpm25_6cod_mean_total\\\": -43608.0, \\\"mort_tpm25_6cod_mean_total\\\": -19574.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[80.40444183, 21.37581062], [80.40336609, 21.37648964], [80.40196991, 21.37781143], [80.40112305, 21.3782711], [80.39935303, 21.38049126], [80.39792633, 21.3841095], [80.39653778, 21.38784981], [80.39389801, 21.39215088], [80.3915329, 21.39663124], [80.38983154, 21.40087128], [80.38906097, 21.40431976], [80.38907623, 21.40737915], [80.38990021, 21.40888977], [80.39347076, 21.41267014], [80.39678192, 21.41534996], [80.39924622, 21.41790962], [80.39996338, 21.41948128], [80.39803314, 21.42308998], [80.39891815, 21.42494011], [80.40161133, 21.42807961], [80.40426636, 21.4307003], [80.40600586, 21.43245125], [80.40862274, 21.43482971], [80.41024017, 21.43639946], [80.41130829, 21.4382019], [80.41055298, 21.44016075], [80.40947723, 21.4435997], [80.40825653, 21.44721985], [80.40644073, 21.45119286], [80.40535736, 21.45440102], [80.40467834, 21.45635986], [80.40453339, 21.45861053], [80.40367889, 21.46130943], [80.40223694, 21.46337128], [80.40096283, 21.46543121], [80.39904022, 21.46640015], [80.39659119, 21.46723938], [80.39528656, 21.46787071], [80.39209747, 21.46939087], [80.38994598, 21.47092819], [80.38685608, 21.47343254], [80.38445282, 21.47635078], [80.38366699, 21.47900009], [80.38272095, 21.48244095], [80.38170624, 21.48480034], [80.38021088, 21.48727036], [80.37858582, 21.48933029], [80.37767792, 21.49012947], [80.37578583, 21.49094009], [80.37532806, 21.49114037], [80.37494659, 21.49287033], [80.37486267, 21.49483109], [80.37483978, 21.49591064], [80.3745575, 21.49897957], [80.37422943, 21.50110054], [80.37388611, 21.50306129], [80.37386322, 21.50508118], [80.3735733, 21.50945091], [80.3724823, 21.51279068], [80.37117767, 21.51514816], [80.37085724, 21.51709175], [80.3707962, 21.51786995], [80.3706131, 21.52096939], [80.36923218, 21.52291107], [80.36762238, 21.52467918], [80.36582947, 21.52634048], [80.36219025, 21.52849007], [80.35691071, 21.53079987], [80.35189056, 21.53300285], [80.3463974, 21.53572083], [80.34229279, 21.53742027], [80.3396759, 21.53790283], [80.3380127, 21.53874969], [80.33516693, 21.54074097], [80.33294678, 21.54220963], [80.33097839, 21.54370117], [80.32968903, 21.54444122], [80.32740784, 21.54609108], [80.32443237, 21.5487175], [80.32559204, 21.55034065], [80.32728577, 21.55174065], [80.3290863, 21.55365944], [80.33009338, 21.55470085], [80.32977295, 21.55631065], [80.32858276, 21.5582695], [80.32746887, 21.55964088], [80.32628632, 21.56158066], [80.324646, 21.56410027], [80.32283783, 21.5674305], [80.32139587, 21.57059097], [80.3201828, 21.57357979], [80.31884003, 21.57455063], [80.31693268, 21.57568169], [80.31299591, 21.57709122], [80.30988312, 21.57734108], [80.30764008, 21.57674026], [80.30336761, 21.57612991], [80.29908752, 21.57538986], [80.29537201, 21.57547951], [80.29191589, 21.57802963], [80.29026794, 21.58263016], [80.28978729, 21.5859127], [80.28909302, 21.5884304], [80.28864288, 21.58965111], [80.28800964, 21.59229088], [80.28658295, 21.59343147], [80.28282928, 21.59511948], [80.27980042, 21.59613037], [80.2754364, 21.59907913], [80.27374268, 21.60263062], [80.27237701, 21.60712051], [80.27086639, 21.6106205], [80.2649765, 21.61655807], [80.26022339, 21.62014961], [80.25665283, 21.62028122], [80.25527954, 21.62072945], [80.25206757, 21.6222496], [80.24762726, 21.62249947], [80.24269867, 21.62049103], [80.24014282, 21.62051964], [80.23596954, 21.6207695], [80.23207092, 21.62045288], [80.22688293, 21.62010193], [80.22058868, 21.61963081], [80.21630859, 21.62034035], [80.21465302, 21.62124062], [80.21203613, 21.62421989], [80.21039581, 21.62627983], [80.20797729, 21.62965012], [80.20469666, 21.63354111], [80.20040131, 21.63470078], [80.19515228, 21.63493919], [80.19210815, 21.63462067], [80.18942261, 21.63425064], [80.18821716, 21.63420105], [80.18618774, 21.63266945], [80.18519592, 21.63064003], [80.18369293, 21.62849045], [80.18237305, 21.62704086], [80.18031311, 21.62552071], [80.17672729, 21.62392044], [80.1749115, 21.62396049], [80.17339325, 21.62412071], [80.17112732, 21.62374115], [80.16895294, 21.62320137], [80.16499329, 21.6217308], [80.16210175, 21.61948967], [80.15991974, 21.61749077], [80.15673828, 21.61412048], [80.15499115, 21.61179924], [80.1526413, 21.60970116], [80.14998627, 21.60741997], [80.14787292, 21.60630035], [80.1439209, 21.60497284], [80.14068604, 21.60472107], [80.13751984, 21.60519981], [80.13298798, 21.60560989], [80.12622833, 21.60830116], [80.12409973, 21.60861015], [80.12145233, 21.60906029], [80.11857605, 21.60889816], [80.11493683, 21.60700989], [80.11286926, 21.60377121], [80.11242676, 21.6008091], [80.11219025, 21.59955025], [80.11157227, 21.59647942], [80.10990143, 21.59341049], [80.10793304, 21.59211922], [80.10560608, 21.59111023], [80.10209656, 21.5893898], [80.10040283, 21.5887394], [80.09874725, 21.58865929], [80.09632111, 21.58743286], [80.09401703, 21.5862999], [80.09329987, 21.58537102], [80.09081268, 21.58356285], [80.0896759, 21.58228111], [80.08669281, 21.57855988], [80.08483887, 21.5761795], [80.08201599, 21.57176971], [80.07875824, 21.56839943], [80.07704163, 21.56675911], [80.07508087, 21.56513977], [80.07332611, 21.5638504], [80.07115936, 21.56200027], [80.07002258, 21.56038094], [80.06845856, 21.55847168], [80.06658936, 21.5568409], [80.06356812, 21.55458069], [80.06211853, 21.55424118], [80.06118774, 21.55401993], [80.05964661, 21.55373001], [80.05719757, 21.55360031], [80.05419922, 21.55354118], [80.0507431, 21.55411911], [80.05007172, 21.55411911], [80.04815674, 21.55414963], [80.04557037, 21.55475044], [80.04403687, 21.55514908], [80.04155731, 21.55624962], [80.03840637, 21.55685997], [80.03439331, 21.55747032], [80.03199005, 21.55755806], [80.02822876, 21.55734062], [80.02617645, 21.55665016], [80.02265167, 21.55381966], [80.01912689, 21.55079079], [80.01689911, 21.54885101], [80.01465607, 21.54735184], [80.01223755, 21.54598045], [80.01000977, 21.5445919], [80.00746918, 21.54256821], [80.00476074, 21.54087067], [80.00208282, 21.53897095], [79.99819946, 21.53664017], [79.99669647, 21.53531075], [79.99355316, 21.53471184], [79.98558044, 21.5367794], [79.97177887, 21.55512047], [79.96624756, 21.55727005], [79.96144867, 21.55800056], [79.94709778, 21.55525017], [79.93638611, 21.55680084], [79.9310379, 21.55561066], [79.92719269, 21.55373001], [79.92124939, 21.5461998], [79.91831207, 21.54031181], [79.91581726, 21.52448082], [79.90119171, 21.52436066], [79.89228821, 21.52326012], [79.88976288, 21.52388], [79.88582611, 21.5296402], [79.8766861, 21.52847099], [79.87187958, 21.52956009], [79.85707855, 21.53092194], [79.85475922, 21.53252029], [79.85056305, 21.5375309], [79.84153748, 21.54181862], [79.82504272, 21.5467205], [79.81819153, 21.55900955], [79.81165314, 21.56430054], [79.80319214, 21.57262993], [79.79181671, 21.58140945], [79.76879883, 21.59043121], [79.74488831, 21.59786987], [79.73262024, 21.60252953], [79.71382141, 21.59113121], [79.70617676, 21.59090042], [79.69934082, 21.5923214], [79.69380951, 21.59095192], [79.69122314, 21.58789063], [79.68934631, 21.58364105], [79.68483734, 21.58069038], [79.66294098, 21.57971001], [79.65814209, 21.57733154], [79.65394592, 21.56345177], [79.65061951, 21.55880928], [79.6474762, 21.55717278], [79.64074707, 21.55548096], [79.63426971, 21.55495071], [79.62534332, 21.55486107], [79.61682129, 21.55721092], [79.60871124, 21.55593109], [79.59938812, 21.55076981], [79.59490967, 21.54965973], [79.58952332, 21.54955864], [79.57614899, 21.54335976], [79.57135773, 21.54380035], [79.56031036, 21.54801941], [79.54738617, 21.54429817], [79.53662109, 21.54421806], [79.53423309, 21.54816818], [79.5338974, 21.55076027], [79.53605652, 21.55496979], [79.53952026, 21.56520081], [79.53755951, 21.56899071], [79.53214264, 21.57298088], [79.52765656, 21.57480049], [79.52171326, 21.58032036], [79.51066589, 21.5831604], [79.50582123, 21.59028053], [79.50681305, 21.60238075], [79.50308228, 21.60750961], [79.49819183, 21.61236954], [79.50112915, 21.61964989], [79.50324249, 21.62236023], [79.50473022, 21.62326813], [79.50850677, 21.62286186], [79.5124588, 21.6264801], [79.51161957, 21.63113022], [79.50959778, 21.63336182], [79.50263977, 21.63459969], [79.50026703, 21.6405201], [79.50113678, 21.64571762], [79.49929047, 21.64784813], [79.49738312, 21.65193939], [79.49456024, 21.66053963], [79.4908905, 21.66370964], [79.48963928, 21.66580009], [79.4885788, 21.67412186], [79.45851135, 21.68732262], [79.45101166, 21.68433762], [79.44072723, 21.68223953], [79.43224335, 21.68349075], [79.42796326, 21.68526077], [79.42298126, 21.69057274], [79.41577911, 21.69144821], [79.41139984, 21.69096756], [79.40772247, 21.68556023], [79.40045166, 21.67964935], [79.3970871, 21.67564011], [79.39473724, 21.67459106], [79.38307953, 21.67539024], [79.36178589, 21.67951012], [79.34902191, 21.67889023], [79.34832001, 21.68440819], [79.34261322, 21.68451118], [79.32213593, 21.6883812], [79.32025146, 21.68659973], [79.31733704, 21.68581963], [79.28481293, 21.6939106], [79.27680206, 21.70022964], [79.27478027, 21.70523071], [79.27175903, 21.70903969], [79.26486969, 21.71492004], [79.25766754, 21.71754074], [79.2286911, 21.72392845], [79.22808075, 21.72191048], [79.22892761, 21.7204895], [79.23477173, 21.71520805], [79.22187805, 21.70059967], [79.22091675, 21.69659042], [79.21817017, 21.68126106], [79.22016144, 21.67700005], [79.22455597, 21.67588043], [79.22682953, 21.67439079], [79.22840118, 21.67139053], [79.22693634, 21.65764999], [79.22157288, 21.65690994], [79.21990204, 21.65081024], [79.21660614, 21.65019035], [79.18618774, 21.65442848], [79.14782715, 21.66052055], [79.14713287, 21.6565609], [79.14109039, 21.63953018], [79.13707733, 21.63685036], [79.12773895, 21.62805939], [79.11123657, 21.62556267], [79.09916687, 21.6189003], [79.09873199, 21.61631012], [79.09947968, 21.61227036], [79.10411072, 21.60935974], [79.09809875, 21.60284042], [79.09203339, 21.60342979], [79.08808899, 21.59918976], [79.0815506, 21.60715103], [79.07608032, 21.60768127], [79.05075073, 21.60394287], [79.0479126, 21.60569], [79.0429306, 21.60470963], [79.03096008, 21.60560989], [79.009552, 21.60149956], [79.00579834, 21.60402107], [78.99999237, 21.60979843], [78.99738312, 21.61577988], [78.9944458, 21.61874962], [78.98149109, 21.6171608], [78.97476196, 21.61755943], [78.96227264, 21.60588074], [78.94586182, 21.59604073], [78.94034576, 21.59375954], [78.92906189, 21.5946312], [78.92267609, 21.59260941], [78.91323853, 21.59235954], [78.91217804, 21.58518028], [78.91163635, 21.5709095], [78.91433716, 21.56964111], [78.91989899, 21.56895828], [78.9283905, 21.56443024], [78.92782593, 21.56028938], [78.92398071, 21.56015015], [78.91271973, 21.56312943], [78.90909576, 21.56175041], [78.90442657, 21.55484009], [78.92179871, 21.5431881], [78.92457581, 21.53868103], [78.92340088, 21.53308105], [78.92343903, 21.52378845], [78.92623901, 21.52164078], [78.9363327, 21.51939011], [78.93869781, 21.51728821], [78.94064331, 21.51370049], [78.93689728, 21.51044083], [78.93379974, 21.49238968], [78.93183136, 21.48740005], [78.92057037, 21.48763084], [78.90792847, 21.49425125], [78.90273285, 21.49801826], [78.89576721, 21.50056839], [78.89048767, 21.49823952], [78.88537598, 21.48559189], [78.87985229, 21.48497009], [78.87513733, 21.48792839], [78.85154724, 21.49570084], [78.84771729, 21.4914608], [78.84417725, 21.48997116], [78.82794952, 21.48995972], [78.82337952, 21.49111938], [78.81925964, 21.48962975], [78.81313324, 21.48872948], [78.81009674, 21.49086952], [78.79281616, 21.48986053], [78.78968811, 21.4885006], [78.78462219, 21.48913956], [78.78016663, 21.48080826], [78.7770462, 21.47907829], [78.77552032, 21.47351265], [78.77218628, 21.46713066], [78.76438141, 21.4742794], [78.76078796, 21.48471069], [78.76103973, 21.48975945], [78.7505188, 21.4907608], [78.74648285, 21.49386978], [78.74040222, 21.48371124], [78.7388382, 21.47290039], [78.73512268, 21.47141075], [78.7297287, 21.47136116], [78.72418976, 21.46438026], [78.71975708, 21.46462059], [78.71391296, 21.46795082], [78.70388031, 21.47120094], [78.70162201, 21.47470093], [78.69574738, 21.47443008], [78.69618225, 21.47741127], [78.6919632, 21.47868156], [78.68830109, 21.47886086], [78.68444061, 21.47795105], [78.68406677, 21.4819603], [78.66417694, 21.48073006], [78.65908813, 21.47888947], [78.65065765, 21.48282051], [78.64354706, 21.48425102], [78.63745117, 21.48419762], [78.63046265, 21.48133087], [78.62532806, 21.47783089], [78.62097168, 21.47754097], [78.61606598, 21.4815197], [78.6053772, 21.4883709], [78.60102081, 21.48715973], [78.59863281, 21.48480988], [78.59326172, 21.48768997], [78.58486938, 21.48688126], [78.58119202, 21.48964119], [78.57325745, 21.49850082], [78.56529999, 21.50597954], [78.56468964, 21.50932121], [78.56652832, 21.51569748], [78.56004333, 21.51461029], [78.55648804, 21.51581955], [78.55239868, 21.51939011], [78.54647064, 21.51996994], [78.53727722, 21.52456284], [78.52835083, 21.52462006], [78.52474213, 21.52583122], [78.52007294, 21.52537918], [78.50856018, 21.52843285], [78.50434875, 21.52670288], [78.50208282, 21.5266304], [78.49791718, 21.52296066], [78.49600983, 21.51797104], [78.49075317, 21.51797104], [78.48561859, 21.51203918], [78.48339844, 21.50774002], [78.48040009, 21.50612068], [78.47209167, 21.5069294], [78.47090912, 21.50486946], [78.46530151, 21.50353813], [78.46167755, 21.50353813], [78.45922852, 21.50463104], [78.45627594, 21.50445175], [78.45419312, 21.49831009], [78.4516983, 21.49733162], [78.44467926, 21.5019207], [78.43858337, 21.50375938], [78.43009949, 21.50175095], [78.43026733, 21.5091629], [78.43218231, 21.51991081], [78.42782593, 21.52675056], [78.42685699, 21.53019905], [78.42752838, 21.53832054], [78.42550659, 21.54227066], [78.42195129, 21.54584122], [78.42060089, 21.54878044], [78.42073059, 21.55479813], [78.42225647, 21.5637207], [78.41906738, 21.57160187], [78.41594696, 21.57308006], [78.41349792, 21.57773972], [78.41584778, 21.58815002], [78.42256165, 21.60194969], [78.41925812, 21.60429955], [78.41086578, 21.60659981], [78.40448761, 21.61009979], [78.39904785, 21.61108017], [78.39256287, 21.61009979], [78.38932037, 21.61056137], [78.38355255, 21.61663818], [78.3795166, 21.61865044], [78.37571716, 21.61745071], [78.37165833, 21.61503029], [78.37203979, 21.61076927], [78.37763214, 21.59560013], [78.37415314, 21.58996964], [78.36605072, 21.58192062], [78.36096191, 21.57829857], [78.35468292, 21.57690811], [78.34768677, 21.57886124], [78.34203339, 21.58287048], [78.33677673, 21.59052086], [78.32846069, 21.58118057], [78.32293701, 21.57738113], [78.31874084, 21.57558823], [78.30882263, 21.57369041], [78.30410767, 21.57143021], [78.30184937, 21.57287025], [78.3017807, 21.58040047], [78.30000305, 21.58505821], [78.2816391, 21.58675957], [78.27107239, 21.59296036], [78.26612091, 21.59428024], [78.26220703, 21.59375954], [78.25762177, 21.59184074], [78.25517273, 21.58984184], [78.25540924, 21.58523941], [78.25853729, 21.58189964], [78.26902008, 21.57472992], [78.27024841, 21.57237053], [78.26925659, 21.57071114], [78.24655914, 21.56401062], [78.23871613, 21.56549072], [78.22666931, 21.55644035], [78.21547699, 21.55373001], [78.18094635, 21.55868149], [78.17726898, 21.55669975], [78.17273712, 21.55330276], [78.17061615, 21.54219055], [78.17167664, 21.53576279], [78.17106628, 21.52873993], [78.1680069, 21.52604103], [78.17764282, 21.51431847], [78.17134094, 21.50850105], [78.17057037, 21.50205994], [78.16934204, 21.49850082], [78.14280701, 21.48211098], [78.12722778, 21.47340012], [78.10906219, 21.4641819], [78.10074615, 21.46095085], [78.09249115, 21.45601082], [78.0785675, 21.44571114], [78.06371307, 21.43885994], [78.05105591, 21.4370327], [78.04345703, 21.43503189], [78.0291214, 21.42535973], [78.01957703, 21.42058945], [78.00707245, 21.41841125], [78.00443268, 21.4158802], [77.99973297, 21.41616249], [77.99582672, 21.41378021], [77.98027802, 21.40279961], [77.97599792, 21.40209961], [77.97154999, 21.40138054], [77.95995331, 21.40142822], [77.95774841, 21.40114021], [77.94111633, 21.39895058], [77.93878174, 21.38690948], [77.9317627, 21.38581848], [77.92488861, 21.38606071], [77.91825104, 21.38474083], [77.91176605, 21.382761], [77.90550995, 21.37957001], [77.90071869, 21.3787117], [77.89904022, 21.37841988], [77.8923111, 21.3790493], [77.88664246, 21.38042068], [77.88186646, 21.37769127], [77.88337708, 21.38549042], [77.8762207, 21.38643074], [77.86321259, 21.38812065], [77.85473633, 21.39072037], [77.84661102, 21.39410973], [77.83392334, 21.40151978], [77.81801605, 21.40872955], [77.80449677, 21.41200066], [77.79936981, 21.41230011], [77.79847717, 21.41070938], [77.79598999, 21.40625954], [77.79522705, 21.40377808], [77.7939682, 21.39961052], [77.7934494, 21.39073944], [77.7901001, 21.38924026], [77.78552246, 21.38939095], [77.77655029, 21.3880291], [77.76506805, 21.38466263], [77.76140594, 21.38442039], [77.75689697, 21.38640976], [77.74993896, 21.38570976], [77.74649048, 21.38421059], [77.74336243, 21.38006973], [77.73834991, 21.36663055], [77.73387909, 21.36473083], [77.72489929, 21.36415291], [77.70524597, 21.35906982], [77.70519257, 21.36728096], [77.70514679, 21.37345123], [77.70433044, 21.37770081], [77.69554138, 21.37775993], [77.69259644, 21.38064957], [77.69425201, 21.39454269], [77.69352722, 21.3965416], [77.69113159, 21.39706993], [77.68827057, 21.39673042], [77.68109131, 21.38549042], [77.67520142, 21.37881088], [77.6700058, 21.3729229], [77.66877747, 21.3723011], [77.66722107, 21.37149048], [77.66481018, 21.37363052], [77.66307831, 21.37745094], [77.66335297, 21.38562965], [77.66208649, 21.38797188], [77.65158081, 21.39019012], [77.65097046, 21.39339066], [77.64589691, 21.39336014], [77.6425705, 21.39141083], [77.6414566, 21.3886795], [77.63920593, 21.38793945], [77.63617706, 21.38949966], [77.62931061, 21.39097977], [77.61519623, 21.39065933], [77.61145782, 21.39381027], [77.60154724, 21.3935585], [77.60067749, 21.39318085], [77.59919739, 21.39254951], [77.59938812, 21.39208984], [77.60064697, 21.3891201], [77.60066223, 21.3859024], [77.60204315, 21.38420105], [77.60575867, 21.37035179], [77.60481262, 21.36699295], [77.60148621, 21.36527061], [77.58701324, 21.36775017], [77.58444214, 21.36447906], [77.58262634, 21.36680031], [77.58081055, 21.36913109], [77.5759964, 21.37047005], [77.57089233, 21.3732605], [77.56533051, 21.37262917], [77.5625, 21.37338066], [77.54840851, 21.3812294], [77.5398407, 21.38117027], [77.52876282, 21.37907028], [77.52427673, 21.37973022], [77.52072144, 21.37730026], [77.51785278, 21.37784958], [77.516922, 21.37803268], [77.51052856, 21.37676048], [77.50173187, 21.37924957], [77.4870224, 21.3777504], [77.48298645, 21.39038086], [77.48419189, 21.39850998], [77.48175049, 21.41566849], [77.47709656, 21.42086029], [77.47302246, 21.43268967], [77.46920776, 21.43704987], [77.46884155, 21.44292068], [77.46975708, 21.44868088], [77.46858215, 21.45290947], [77.46930695, 21.45689964], [77.45716095, 21.46707153], [77.45378876, 21.46729279], [77.45236206, 21.46799088], [77.4489212, 21.46967125], [77.43875885, 21.47278023], [77.43830872, 21.47291946], [77.43808746, 21.47555923], [77.43785095, 21.47820282], [77.43515015, 21.48163986], [77.43737793, 21.48353195], [77.43921661, 21.48932266], [77.43112946, 21.50222015], [77.42079926, 21.51628113], [77.41880035, 21.52083969], [77.4169693, 21.53306007], [77.41990662, 21.5386982], [77.42350769, 21.54256058], [77.42894745, 21.54566002], [77.43187714, 21.54640007], [77.44207001, 21.54464912], [77.44664001, 21.54561043], [77.45024872, 21.5483799], [77.45030975, 21.55194092], [77.45195007, 21.55561066], [77.4575119, 21.55657005], [77.46472931, 21.55597115], [77.46872711, 21.55449104], [77.48400116, 21.55330276], [77.50435638, 21.55466843], [77.50726318, 21.5508194], [77.51191711, 21.54751015], [77.52919006, 21.54076958], [77.53533936, 21.53904915], [77.54073334, 21.53891945], [77.55339813, 21.53617287], [77.56698608, 21.52975082], [77.57789612, 21.52921104], [77.58924866, 21.53034973], [77.59488678, 21.5331707], [77.6071167, 21.54277039], [77.60575867, 21.55091095], [77.59068298, 21.56161118], [77.58551788, 21.55880928], [77.57972717, 21.55815125], [77.57408905, 21.55750084], [77.57099915, 21.56262016], [77.56999969, 21.56978989], [77.57022858, 21.57566833], [77.57219696, 21.58767128], [77.56993103, 21.6111412], [77.56817627, 21.61623192], [77.56784058, 21.62105942], [77.570961, 21.6235199], [77.57132721, 21.62704086], [77.5655365, 21.63503265], [77.56037903, 21.64518166], [77.55754089, 21.65558815], [77.55856323, 21.66867256], [77.55050659, 21.67628288], [77.54736328, 21.68156052], [77.54566956, 21.6860714], [77.54457092, 21.6924324], [77.54218292, 21.70103073], [77.53592682, 21.70825958], [77.53338623, 21.71269035], [77.52610779, 21.71503258], [77.52345276, 21.71354103], [77.52308655, 21.71362114], [77.52104187, 21.7141304], [77.51882935, 21.72116089], [77.51832581, 21.72437096], [77.51790619, 21.72701073], [77.50836182, 21.7352829], [77.50605011, 21.74121284], [77.49986267, 21.74489021], [77.49687195, 21.74920082], [77.4923172, 21.74979019], [77.48882294, 21.75024986], [77.47586823, 21.75788116], [77.47550964, 21.76185036], [77.47515106, 21.76573944], [77.47701263, 21.76795959], [77.47776794, 21.77022171], [77.4754715, 21.77144051], [77.47138214, 21.77124977], [77.45868683, 21.76818085], [77.45262909, 21.76432037], [77.44988251, 21.76341057], [77.44387817, 21.76351929], [77.43850708, 21.76272011], [77.42665863, 21.76040077], [77.41298676, 21.75773048], [77.40531158, 21.75673103], [77.40113068, 21.75617981], [77.37592316, 21.7571106], [77.35338593, 21.75946045], [77.34229279, 21.76183128], [77.33912659, 21.76165962], [77.33738708, 21.76156044], [77.32598114, 21.75736046], [77.32129669, 21.75703049], [77.3088913, 21.75964928], [77.29367065, 21.75991821], [77.28623962, 21.76275063], [77.27997589, 21.76126289], [77.27707672, 21.75980949], [77.27774811, 21.75375938], [77.27826691, 21.74913979], [77.28227234, 21.7481308], [77.28446198, 21.74644852], [77.28308868, 21.74164963], [77.28328705, 21.73849106], [77.28501892, 21.73750114], [77.28690338, 21.73644257], [77.28581238, 21.7288208], [77.28314972, 21.72422028], [77.26737976, 21.72907066], [77.26277161, 21.72363091], [77.25802612, 21.71582985], [77.25518036, 21.71519089], [77.23993683, 21.71712112], [77.22460175, 21.71788979], [77.22323608, 21.70418167], [77.22223663, 21.70167923], [77.22159576, 21.70010948], [77.21797943, 21.69842911], [77.21021271, 21.69712067], [77.20742035, 21.69400978], [77.20136261, 21.69631958], [77.18432617, 21.70446014], [77.18766022, 21.72072983], [77.18802643, 21.72257042], [77.18383026, 21.72450066], [77.17144775, 21.72726059], [77.16803741, 21.72575951], [77.16506195, 21.71692085], [77.16242218, 21.71410751], [77.16004944, 21.7137394], [77.15777588, 21.71340942], [77.14750671, 21.71465111], [77.13333893, 21.72232056], [77.12110138, 21.72534943], [77.11416626, 21.72486115], [77.10411072, 21.72289085], [77.10330963, 21.7226429], [77.09393311, 21.7196312], [77.08377838, 21.71862984], [77.08024597, 21.71869278], [77.07530975, 21.72237015], [77.07406616, 21.72261047], [77.07232666, 21.72293091], [77.06903839, 21.72180939], [77.0620575, 21.71504974], [77.05948639, 21.70940018], [77.03427124, 21.70051193], [77.02916718, 21.69606018], [77.02333832, 21.6937809], [77.0181427, 21.69079971], [77.01016235, 21.68439102], [77.00158691, 21.68215942], [76.99727631, 21.68161011], [76.97866821, 21.66597939], [76.91155243, 21.61493111], [76.90567017, 21.60449982], [76.90112305, 21.6008091], [76.89174652, 21.60070038], [76.86073303, 21.61230278], [76.85214996, 21.61503029], [76.84776306, 21.61330032], [76.83863068, 21.60050011], [76.8335495, 21.59306908], [76.82318115, 21.59268188], [76.80387115, 21.59683037], [76.79534912, 21.5975399], [76.793396, 21.59517288], [76.79148865, 21.58741951], [76.78359222, 21.5779705], [76.78024292, 21.56246758], [76.78283691, 21.5514698], [76.78457642, 21.54605293], [76.78782654, 21.54013062], [76.78553772, 21.53530121], [76.7753067, 21.53202057], [76.76751709, 21.52754021], [76.76293182, 21.52264977], [76.77023315, 21.51074982], [76.78649139, 21.49922943], [76.79180145, 21.48989105], [76.79017639, 21.48236084], [76.78513336, 21.47672081], [76.78418732, 21.46648979], [76.77578735, 21.46013069], [76.75654602, 21.44992828], [76.74339294, 21.44314003], [76.73842621, 21.42938042], [76.73722839, 21.41529083], [76.73208618, 21.40880966], [76.71909332, 21.40065002], [76.66841125, 21.3694706], [76.62864685, 21.33977127], [76.62452698, 21.33510017], [76.62583923, 21.32974052], [76.63973236, 21.31064987], [76.64862823, 21.3000412], [76.66107178, 21.28242111], [76.66017914, 21.27359962], [76.65944672, 21.26213074], [76.6590271, 21.25324821], [76.65849304, 21.24781036], [76.64987946, 21.24901962], [76.64257813, 21.24772072], [76.63728333, 21.23911285], [76.63169098, 21.22890091], [76.63134003, 21.21564102], [76.63157654, 21.20536995], [76.6268692, 21.19881058], [76.62336731, 21.19265938], [76.62003326, 21.19544029], [76.61678314, 21.19857025], [76.61231995, 21.19591141], [76.60562897, 21.19716263], [76.58674622, 21.19868279], [76.5760498, 21.20366287], [76.57518005, 21.20407295], [76.55938721, 21.20581055], [76.54129791, 21.19629097], [76.52919769, 21.18929291], [76.52078247, 21.18922043], [76.49807739, 21.19614029], [76.49117279, 21.19782066], [76.48737335, 21.19606018], [76.48245239, 21.18823051], [76.47828674, 21.17568016], [76.47673798, 21.16128922], [76.47702026, 21.15530014], [76.47489166, 21.152071], [76.46897125, 21.15056992], [76.46675873, 21.1472683], [76.46700287, 21.14319038], [76.46549988, 21.13924026], [76.4575119, 21.13834], [76.45593262, 21.13191986], [76.45291901, 21.1244297], [76.45269012, 21.11486816], [76.44770813, 21.11285973], [76.44107056, 21.11213112], [76.4375, 21.10758972], [76.43373871, 21.10668945], [76.41182709, 21.10726929], [76.40943909, 21.09408951], [76.39682007, 21.09057045], [76.3901062, 21.08805084], [76.38275909, 21.07956123], [76.38104248, 21.07907104], [76.37961578, 21.07847977], [76.37637329, 21.07731056], [76.37198639, 21.07855988], [76.36862183, 21.07870102], [76.36579132, 21.07907104], [76.3613205, 21.08000183], [76.35697937, 21.07966995], [76.33481598, 21.07718086], [76.29711914, 21.07718086], [76.2857666, 21.07649994], [76.2817688, 21.07530975], [76.27776337, 21.07802963], [76.27324677, 21.08541107], [76.26924896, 21.09295082], [76.26210785, 21.09470177], [76.23510742, 21.09391022], [76.22749329, 21.09144974], [76.20868683, 21.09017944], [76.18907166, 21.09031105], [76.18386078, 21.08995056], [76.1807785, 21.08741951], [76.17727661, 21.08549118], [76.17263794, 21.08460045], [76.16864777, 21.08582115], [76.16702271, 21.089571], [76.1681366, 21.0932312], [76.16927338, 21.09865952], [76.16931152, 21.10141945], [76.16911316, 21.10371971], [76.16845703, 21.10541153], [76.16744232, 21.10629845], [76.16221619, 21.10996056], [76.15146637, 21.11499977], [76.14214325, 21.12107086], [76.13566589, 21.12621117], [76.13417053, 21.1303196], [76.13934326, 21.13363075], [76.14092255, 21.13602257], [76.1399231, 21.14006805], [76.13169098, 21.15267944], [76.12841797, 21.15670967], [76.12409973, 21.15909958], [76.11891174, 21.1601181], [76.11396027, 21.16464043], [76.11431885, 21.17045975], [76.1193924, 21.17468071], [76.12741852, 21.17791939], [76.13070679, 21.17555046], [76.14298248, 21.17313194], [76.15505981, 21.17256165], [76.16088867, 21.17200089], [76.16684723, 21.17072105], [76.16913605, 21.17448044], [76.17063904, 21.18217278], [76.17272186, 21.18828964], [76.16908264, 21.19188118], [76.16590881, 21.19548988], [76.16571808, 21.20004845], [76.16705322, 21.20358086], [76.16770935, 21.20588112], [76.16794586, 21.20812035], [76.16427612, 21.21181107], [76.16152191, 21.21668816], [76.16314697, 21.22195053], [76.16403198, 21.22417259], [76.15933228, 21.22725105], [76.15328979, 21.22981834], [76.14801025, 21.2316494], [76.1455307, 21.23319054], [76.14440155, 21.23809052], [76.14409637, 21.24147987], [76.14412689, 21.24258041], [76.15091705, 21.24561119], [76.15428925, 21.24913979], [76.15809631, 21.25354958], [76.15921783, 21.25914192], [76.15603638, 21.2632103], [76.15386963, 21.26881981], [76.14980316, 21.27420998], [76.1471405, 21.28137016], [76.14499664, 21.28777122], [76.13987732, 21.28899956], [76.13497162, 21.29150009], [76.1292572, 21.29751015], [76.12726593, 21.30734062], [76.12224579, 21.32163811], [76.1159668, 21.33877945], [76.10694885, 21.36020279], [76.09867096, 21.37392807], [76.095047, 21.37267113], [76.08815002, 21.3699894], [76.07724762, 21.36426926], [76.06565857, 21.35919952], [76.05237579, 21.35270119], [76.04704285, 21.35519981], [76.04202271, 21.35889244], [76.0345993, 21.36527061], [76.02749634, 21.36813927], [76.01597595, 21.36988258], [76.00023651, 21.37481117], [75.99160767, 21.3760891], [75.98487854, 21.37717819], [75.96874237, 21.39397049], [75.95939636, 21.39619064], [75.94796753, 21.39298058], [75.93737793, 21.39286995], [75.93234253, 21.39151001], [75.91654205, 21.38982773], [75.91227722, 21.3906498], [75.9050827, 21.39563942], [75.89705658, 21.39726067], [75.89563751, 21.39874077], [75.8881073, 21.39962959], [75.88212585, 21.39842987], [75.87615204, 21.39819145], [75.87226105, 21.39550018], [75.86818695, 21.39048958], [75.86277771, 21.38730049], [75.85932922, 21.38730049], [75.85135651, 21.38935089], [75.84662628, 21.38813972], [75.84342194, 21.38945007], [75.83262634, 21.38330078], [75.8125, 21.38733101], [75.80545807, 21.38903046], [75.80140686, 21.39015007], [75.79220581, 21.38921165], [75.7738266, 21.38664818], [75.76013947, 21.38570023], [75.75894165, 21.38549042], [75.75467682, 21.38838959], [75.74610138, 21.39171028], [75.74408722, 21.39319038], [75.73834991, 21.39343262], [75.73558044, 21.39270973], [75.73294067, 21.39332962], [75.72271729, 21.38915253], [75.72158813, 21.39099121], [75.71385193, 21.3916111], [75.70675659, 21.39132118], [75.69483185, 21.38956261], [75.68972015, 21.38750076], [75.68782043, 21.38433075], [75.68479156, 21.38223076], [75.6784668, 21.38217163], [75.67507935, 21.38145065], [75.67341614, 21.38035011], [75.65882111, 21.38274956], [75.65487671, 21.38202095], [75.64575958, 21.38247108], [75.63986206, 21.38149071], [75.63263702, 21.38177109], [75.6294632, 21.3812294], [75.62679291, 21.38200951], [75.62361145, 21.38428116], [75.62111664, 21.38787079], [75.6194458, 21.39346123], [75.60891724, 21.39500046], [75.60295105, 21.39052963], [75.59126282, 21.3917408], [75.5877533, 21.38890076], [75.58486176, 21.38759995], [75.57655334, 21.38552094], [75.5815506, 21.38084984], [75.58125305, 21.37985992], [75.57209015, 21.37822914], [75.56598663, 21.37915039], [75.56420898, 21.37809944], [75.56027222, 21.37881088], [75.56111145, 21.38117027], [75.55980682, 21.38226128], [75.555336, 21.37745094], [75.55133057, 21.37544823], [75.54814911, 21.37248993], [75.54714966, 21.37265968], [75.54530334, 21.37579918], [75.53994751, 21.37719154], [75.52939606, 21.38472939], [75.52458191, 21.38716125], [75.51628113, 21.38673019], [75.51013184, 21.38799286], [75.50048828, 21.39157295], [75.49643707, 21.39073181], [75.48480225, 21.39126015], [75.46840668, 21.39420128], [75.46559906, 21.39136124], [75.46005249, 21.39302254], [75.45443726, 21.3920517], [75.45007324, 21.39240265], [75.44615173, 21.3904705], [75.44361877, 21.39101982], [75.43628693, 21.39072037], [75.43165588, 21.39394951], [75.41996765, 21.39027023], [75.41337585, 21.3910675], [75.40925598, 21.38992119], [75.40381622, 21.38377953], [75.40091705, 21.3839798], [75.39839172, 21.38298035], [75.39537811, 21.38467979], [75.39308929, 21.38406944], [75.38448334, 21.3855896], [75.3813324, 21.38763046], [75.37866211, 21.39241982], [75.36694336, 21.39891052], [75.36138153, 21.40323067], [75.35800171, 21.3961792], [75.35378265, 21.39348984], [75.33487701, 21.39466858], [75.32681274, 21.39423943], [75.32090759, 21.39240265], [75.31195831, 21.39528084], [75.30866241, 21.39450073], [75.30190277, 21.3892498], [75.30182648, 21.39241982], [75.30316162, 21.39519119], [75.30184937, 21.41483116], [75.29962921, 21.41566086], [75.29162598, 21.41390991], [75.28856659, 21.41181183], [75.27662659, 21.4088707], [75.26702118, 21.4088707], [75.2591095, 21.40521812], [75.2539978, 21.40613937], [75.24768066, 21.41067123], [75.24347687, 21.41493988], [75.23636627, 21.41710091], [75.23226166, 21.41658974], [75.21985626, 21.4108696], [75.21055603, 21.41422081], [75.2074585, 21.41584015], [75.20372009, 21.41731834], [75.19599915, 21.42285919], [75.18802643, 21.42731094], [75.15737152, 21.43827248], [75.14743805, 21.4433403], [75.129776, 21.44927979], [75.12297821, 21.4533329], [75.11509705, 21.45956039], [75.10666656, 21.46962929], [75.10044098, 21.48531151], [75.09487915, 21.49381256], [75.09266663, 21.50090981], [75.08999634, 21.51433182], [75.08355713, 21.52575111], [75.07832336, 21.5321312], [75.07624054, 21.53801918], [75.07221985, 21.54165077], [75.06503296, 21.5508194], [75.06359863, 21.55500031], [75.06018829, 21.55933952], [75.05774689, 21.5649395], [75.05356598, 21.56719017], [75.03183746, 21.56930923], [75.01783752, 21.57261086], [75.01584625, 21.57788086], [75.01341248, 21.5811882], [75.004776, 21.5860424], [75.00356293, 21.58670807], [75.00267792, 21.58716965], [75.00183105, 21.58764267], [75.0009613, 21.58811951], [75.00009918, 21.58859062], [74.99923706, 21.58905029], [74.99835205, 21.58950043], [74.99745941, 21.58992958], [74.99656677, 21.59033012], [74.99565125, 21.59070015], [74.99474335, 21.59109116], [74.9937973, 21.59144974], [74.99289703, 21.59183121], [74.99195862, 21.5921917], [74.99104309, 21.59255028], [74.99011993, 21.59290123], [74.98918152, 21.59325027], [74.9882431, 21.59358978], [74.98731232, 21.59392166], [74.98638916, 21.59424973], [74.98544312, 21.59456062], [74.98449707, 21.59486961], [74.98353577, 21.59517288], [74.98258972, 21.59546089], [74.98162842, 21.59574127], [74.98068237, 21.59601974], [74.9797287, 21.59626961], [74.97875977, 21.59651947], [74.97780609, 21.59674072], [74.97683716, 21.59696007], [74.9758606, 21.59717178], [74.9748764, 21.59737015], [74.97390747, 21.59756088], [74.97293091, 21.59774971], [74.97194672, 21.59793282], [74.97096252, 21.59811974], [74.96997833, 21.59828949], [74.96898651, 21.59847069], [74.96800232, 21.59864998], [74.96702576, 21.59883118], [74.96604919, 21.5990181], [74.96507263, 21.5992012], [74.96408844, 21.59941101], [74.96312714, 21.59959984], [74.96214294, 21.59980965], [74.96116638, 21.60001945], [74.96018982, 21.60026932], [74.95923615, 21.60050964], [74.95826721, 21.60077286], [74.95732117, 21.60103035], [74.95635986, 21.60128975], [74.95539856, 21.60155106], [74.95443726, 21.60181046], [74.95349884, 21.60207939], [74.95252991, 21.60235023], [74.95157623, 21.60263062], [74.9506073, 21.6029129], [74.94966888, 21.60318184], [74.94869995, 21.60346985], [74.94776154, 21.60375023], [74.94682312, 21.60403061], [74.94584656, 21.60432053], [74.94489288, 21.60460091], [74.94394684, 21.60490036], [74.94300079, 21.60518265], [74.94204712, 21.60548973], [74.94108582, 21.60577965], [74.94016266, 21.60608292], [74.93920135, 21.60637093], [74.93824768, 21.60667038], [74.93731689, 21.60697174], [74.93636322, 21.60728073], [74.93541718, 21.60757065], [74.93447113, 21.60787964], [74.93353271, 21.60819054], [74.93258667, 21.6084919], [74.931633, 21.60880089], [74.93067932, 21.60910034], [74.92974091, 21.60942078], [74.92880249, 21.60972023], [74.92785645, 21.61003113], [74.92691803, 21.61033821], [74.92595673, 21.61065292], [74.92502594, 21.61099052], [74.92408752, 21.61131859], [74.92314911, 21.6116581], [74.92222595, 21.61202049], [74.9213028, 21.61236954], [74.92038727, 21.61275101], [74.91947937, 21.61314011], [74.9185791, 21.61352921], [74.91770172, 21.61395264], [74.91680145, 21.61437988], [74.91591644, 21.61482811], [74.91504669, 21.61531067], [74.91416168, 21.61580849], [74.91333771, 21.61634064], [74.9125061, 21.61689949], [74.91172791, 21.61749077], [74.91095734, 21.61811066], [74.91026306, 21.61876106], [74.90962219, 21.61944962], [74.90907288, 21.62020111], [74.90860748, 21.62102127], [74.90818024, 21.62187958], [74.9078064, 21.62277031], [74.90743256, 21.62366104], [74.90703583, 21.6245594], [74.90661621, 21.62543106], [74.90618134, 21.62625122], [74.90563965, 21.62702942], [74.90500641, 21.62779045], [74.90434265, 21.6285305], [74.90358734, 21.62922287], [74.90276337, 21.6298008], [74.90187836, 21.63022995], [74.90093994, 21.63047981], [74.90001678, 21.63068962], [74.89904785, 21.63086128], [74.89807129, 21.63101959], [74.8970871, 21.63116264], [74.89610291, 21.6312809], [74.89512634, 21.63138962], [74.89411926, 21.63146973], [74.89309692, 21.63155937], [74.89208221, 21.63162994], [74.89105988, 21.63167953], [74.8900528, 21.63171959], [74.88903809, 21.63175964], [74.88803101, 21.63178253], [74.8870163, 21.6317997], [74.88601685, 21.6317997], [74.8850174, 21.6317997], [74.88401031, 21.63179016], [74.88302612, 21.63171959], [74.88204956, 21.63158035], [74.88105774, 21.6314106], [74.88006592, 21.63120079], [74.87909698, 21.63099098], [74.87812805, 21.63078117], [74.87713623, 21.63059044], [74.87613678, 21.63043976], [74.87516022, 21.63034058], [74.87415314, 21.63029099], [74.87312317, 21.63026047], [74.8720932, 21.63023949], [74.87106323, 21.63023949], [74.87001038, 21.63029099], [74.8690033, 21.63039017], [74.8680191, 21.6305294], [74.86709595, 21.63074112], [74.86630249, 21.63112068], [74.86575317, 21.63212013], [74.86534119, 21.63330269], [74.86486053, 21.63402939], [74.86415863, 21.6338501], [74.86342621, 21.633461], [74.86266327, 21.6330204], [74.86193085, 21.63251114], [74.86115265, 21.63195992], [74.86038208, 21.63137054], [74.85964966, 21.63074112], [74.85884857, 21.63010979], [74.858078, 21.62944984], [74.85727692, 21.6287899], [74.85647583, 21.62811089], [74.85568237, 21.62745094], [74.85488129, 21.62681007], [74.85407257, 21.62619019], [74.85321808, 21.62560081], [74.85237885, 21.62504005], [74.85153198, 21.62451935], [74.85066223, 21.62407112], [74.84976959, 21.62366104], [74.84884644, 21.62327957], [74.84793854, 21.62294006], [74.84697723, 21.62263107], [74.84601593, 21.62232971], [74.84506989, 21.62206078], [74.84409332, 21.62179947], [74.84310913, 21.62153053], [74.8421402, 21.62128258], [74.84115601, 21.62100983], [74.84020233, 21.62072945], [74.83924866, 21.62044144], [74.83833313, 21.62013054], [74.83740997, 21.61979103], [74.8365097, 21.61940956], [74.83564758, 21.61897087], [74.8348999, 21.61833], [74.83423615, 21.6175518], [74.83370972, 21.61669922], [74.83336639, 21.61584091], [74.83329773, 21.61487007], [74.83348846, 21.61379051], [74.83368683, 21.61273956], [74.83367157, 21.61186028], [74.83320618, 21.61129951], [74.8324585, 21.61090088], [74.83156586, 21.6106205], [74.83055878, 21.61041832], [74.82946777, 21.61029243], [74.82836151, 21.61021042], [74.82726288, 21.61018944], [74.82624054, 21.61018944], [74.82524109, 21.61021042], [74.8242569, 21.61029243], [74.82327271, 21.61038017], [74.82227325, 21.6104908], [74.82128906, 21.61063194], [74.82028961, 21.61079025], [74.81928253, 21.61094093], [74.81830597, 21.61112022], [74.81732178, 21.61129951], [74.81633759, 21.61147118], [74.81536865, 21.61164093], [74.81437683, 21.61182976], [74.81339264, 21.61203194], [74.81240845, 21.61225128], [74.8114624, 21.6125412], [74.81053925, 21.61287117], [74.80963135, 21.61326981], [74.8087616, 21.61372948], [74.8079071, 21.61422157], [74.80702209, 21.61469841], [74.80613708, 21.61514282], [74.8052063, 21.6154995], [74.80404663, 21.61586952], [74.80287933, 21.61613083], [74.80207062, 21.61605072], [74.80190277, 21.61548996], [74.80207062, 21.61463928], [74.80245972, 21.61363029], [74.80284119, 21.61255836], [74.80306244, 21.61156082], [74.80288696, 21.61073112], [74.80206299, 21.6100502], [74.80103302, 21.60983086], [74.80004883, 21.60985947], [74.79907227, 21.60989952], [74.79808807, 21.60996056], [74.79708862, 21.61001968], [74.7960968, 21.61009026], [74.79509735, 21.61016273], [74.79408264, 21.61025047], [74.79308319, 21.61033821], [74.792099, 21.61046982], [74.79106903, 21.61058044], [74.79007721, 21.61071968], [74.7890625, 21.61086082], [74.78808594, 21.61102104], [74.78710175, 21.61117935], [74.78611755, 21.61136055], [74.78514862, 21.61156082], [74.78417969, 21.61177063], [74.78324127, 21.61203194], [74.78231049, 21.61235046], [74.78137207, 21.61270142], [74.78045654, 21.61308098], [74.77954865, 21.61349106], [74.77863312, 21.61391068], [74.77774048, 21.61433029], [74.77683258, 21.61475945], [74.77593231, 21.61515999], [74.77501678, 21.61553955], [74.77397156, 21.61553955], [74.77297974, 21.61551094], [74.77197266, 21.61548042], [74.77097321, 21.61547089], [74.76996613, 21.61543083], [74.76896667, 21.61541176], [74.76796722, 21.61541939], [74.76698303, 21.61547089], [74.76599121, 21.61552048], [74.76499939, 21.61561966], [74.76399994, 21.61573982], [74.76303101, 21.61585808], [74.76203156, 21.6160202], [74.76104736, 21.61618042], [74.76006317, 21.61634064], [74.75907898, 21.61651993], [74.75808716, 21.6167202], [74.75712585, 21.61691093], [74.75614929, 21.61712074], [74.75515747, 21.61731911], [74.75419617, 21.61751938], [74.75319672, 21.61771965], [74.75224304, 21.61791992], [74.75126648, 21.61812973], [74.75028992, 21.61832047], [74.74931335, 21.61853027], [74.74833679, 21.61874008], [74.7473526, 21.61894035], [74.74637604, 21.61914063], [74.7454071, 21.61935043], [74.74443817, 21.61955261], [74.74346161, 21.61976051], [74.74249268, 21.61996078], [74.74151611, 21.6201725], [74.74053955, 21.62037086], [74.73956299, 21.62059021], [74.73860168, 21.62079239], [74.73761749, 21.62100029], [74.73664093, 21.62120056], [74.73565674, 21.62142181], [74.73468781, 21.62162971], [74.73371887, 21.62183952], [74.73274231, 21.62205124], [74.73177338, 21.62226105], [74.73079681, 21.62248039], [74.72981262, 21.6226902], [74.72885132, 21.62290955], [74.72786713, 21.6231308], [74.72690582, 21.62334061], [74.72592163, 21.62356186], [74.72496796, 21.6237812], [74.72397614, 21.62399101], [74.72302246, 21.62421989], [74.72203827, 21.62445068], [74.72107697, 21.62467194], [74.72012329, 21.62489128], [74.71914673, 21.62512016], [74.71816254, 21.62537003], [74.71720886, 21.62559128], [74.71624756, 21.62581062], [74.71527863, 21.62606049], [74.71430206, 21.62629128], [74.71334076, 21.62654114], [74.71237946, 21.62680244], [74.71141815, 21.62705994], [74.71044922, 21.62732124], [74.70948792, 21.62759018], [74.70852661, 21.62787056], [74.7075882, 21.62816048], [74.70662689, 21.62844086], [74.70567322, 21.62874985], [74.70474243, 21.62905121], [74.70379639, 21.6293602], [74.70285797, 21.62968826], [74.70192719, 21.63002968], [74.70101166, 21.63035965], [74.70008087, 21.63071823], [74.69917297, 21.6310997], [74.69827271, 21.63150978], [74.69738007, 21.63195038], [74.69651794, 21.63240051], [74.69564819, 21.6328907], [74.69477844, 21.63338089], [74.6939621, 21.63389969], [74.69313049, 21.63442039], [74.69230652, 21.63496017], [74.69149017, 21.63552284], [74.69069672, 21.63607979], [74.68990326, 21.63663292], [74.68910217, 21.63721085], [74.68830872, 21.63777924], [74.68753052, 21.63836098], [74.68675232, 21.63894081], [74.68596649, 21.63953018], [74.68517303, 21.64011002], [74.68438721, 21.64069939], [74.68360901, 21.64128113], [74.68282318, 21.6418705], [74.68205261, 21.64245987], [74.68126678, 21.6430397], [74.68047333, 21.64361954], [74.67970276, 21.64418983], [74.67888641, 21.64476013], [74.67809296, 21.6453228], [74.6772995, 21.64587975], [74.67648315, 21.64641953], [74.67565918, 21.64698982], [74.67487335, 21.64754295], [74.67402649, 21.6480999], [74.67320251, 21.64862061], [74.67237091, 21.64915085], [74.67151642, 21.64965057], [74.67066193, 21.65011024], [74.66977692, 21.65055847], [74.66887665, 21.65097046], [74.66797638, 21.65134048], [74.66706085, 21.65168953], [74.66612244, 21.6520195], [74.66517639, 21.65232086], [74.66420746, 21.65261078], [74.66326141, 21.65287018], [74.66227722, 21.65312195], [74.66131592, 21.65335083], [74.66033173, 21.6535511], [74.6593399, 21.65374947], [74.65837097, 21.65393066], [74.65740204, 21.65410042], [74.65643311, 21.65427017], [74.65542603, 21.65442085], [74.65444946, 21.65457153], [74.65342712, 21.65471077], [74.65245819, 21.65484047], [74.65146637, 21.65497971], [74.65046692, 21.6551075], [74.64949036, 21.65522957], [74.64850616, 21.65534973], [74.64749908, 21.6554718], [74.64650726, 21.65559959], [74.6455307, 21.6557312], [74.64453888, 21.65583992], [74.6435318, 21.65596962], [74.64254761, 21.65610123], [74.64155579, 21.65624046], [74.64057159, 21.65637016], [74.6395874, 21.6565094], [74.63858032, 21.65666008], [74.63761139, 21.6568203], [74.63661194, 21.65698051], [74.63564301, 21.65715027], [74.63465118, 21.65733147], [74.63368988, 21.65752029], [74.63269806, 21.6577282], [74.63173676, 21.65793037], [74.63076019, 21.65814018], [74.62980652, 21.65835953], [74.62882233, 21.65859032], [74.62784576, 21.65882111], [74.62687683, 21.65904808], [74.6259079, 21.65928268], [74.62494659, 21.6595211], [74.6239624, 21.65975952], [74.6230011, 21.65999985], [74.62201691, 21.66023064], [74.62106323, 21.66047096], [74.62008667, 21.66070747], [74.619133, 21.66094971], [74.61814117, 21.66118813], [74.61717987, 21.66139984], [74.61621094, 21.66163063], [74.615242, 21.66184044], [74.61427307, 21.66205025], [74.61329651, 21.66226006], [74.61231232, 21.66246033], [74.61134338, 21.66263008], [74.61036682, 21.66282082], [74.60939026, 21.66299057], [74.60839844, 21.66315269], [74.60742188, 21.66328049], [74.60639954, 21.66337967], [74.6053772, 21.66341972], [74.60434723, 21.66343117], [74.60330963, 21.66341972], [74.60227966, 21.66337967], [74.60122681, 21.66332817], [74.60018921, 21.66328049], [74.59913635, 21.6632309], [74.59809875, 21.66319847], [74.59709167, 21.66316986], [74.59607697, 21.66316986], [74.59509277, 21.66321182], [74.5941391, 21.66328049], [74.59319305, 21.66340828], [74.59227753, 21.66358948], [74.59140778, 21.66383171], [74.59055328, 21.66415977], [74.58976746, 21.66464806], [74.58899689, 21.66526985], [74.58831024, 21.66601944], [74.587677, 21.66683006], [74.58708954, 21.66772079], [74.58657074, 21.66862106], [74.58615112, 21.66953087], [74.58574677, 21.67041016], [74.58545685, 21.67124939], [74.58547211, 21.6721096], [74.58579254, 21.67300034], [74.58627319, 21.67391968], [74.58670044, 21.67485809], [74.58693695, 21.67579269], [74.58689117, 21.67670059], [74.58677673, 21.6776619], [74.58661652, 21.67865944], [74.58644104, 21.6796627], [74.5861969, 21.68066025], [74.58589935, 21.68163109], [74.58557129, 21.68254089], [74.5851593, 21.68338013], [74.58470154, 21.68412018], [74.58416748, 21.68474007], [74.58345032, 21.68513107], [74.58248901, 21.68527985], [74.58141327, 21.68527031], [74.58027649, 21.68514061], [74.5791626, 21.68499947], [74.57814026, 21.68486977], [74.57713318, 21.68478012], [74.57611847, 21.68466949], [74.57507324, 21.68456268], [74.5740509, 21.68443108], [74.57302094, 21.68431091], [74.57200623, 21.68416023], [74.57099152, 21.68399048], [74.57000732, 21.68380165], [74.56906128, 21.68357086], [74.56813812, 21.68332291], [74.56726074, 21.68302917], [74.56652069, 21.68259811], [74.56636047, 21.68153954], [74.56626129, 21.68045044], [74.56569672, 21.67996025], [74.56476593, 21.67984962], [74.56371307, 21.67990112], [74.5626297, 21.68008995], [74.56160736, 21.68042183], [74.56072998, 21.68086052], [74.55980682, 21.68143082], [74.55887604, 21.68208122], [74.55800629, 21.68279076], [74.55729675, 21.68353271], [74.55680084, 21.68425941], [74.55661011, 21.68494034], [74.5569458, 21.68555069], [74.55773926, 21.68610954], [74.55877686, 21.68667984], [74.55977631, 21.68729019], [74.56054688, 21.68799019], [74.56086731, 21.68882751], [74.56105804, 21.68970108], [74.56121063, 21.69059944], [74.56130981, 21.69151115], [74.56137848, 21.69244194], [74.56143951, 21.69338989], [74.56147003, 21.69433975], [74.5614624, 21.69530106], [74.56141663, 21.69627953], [74.56137848, 21.69722939], [74.5613327, 21.69820023], [74.56124878, 21.69915962], [74.56115723, 21.70012093], [74.5610733, 21.7010498], [74.56096649, 21.70198059], [74.56079865, 21.7028904], [74.56056976, 21.7038002], [74.56024933, 21.70470047], [74.55989838, 21.70560074], [74.55948639, 21.70646286], [74.55903625, 21.70730972], [74.55856323, 21.7081604], [74.55806732, 21.70898056], [74.55760956, 21.70984077], [74.55713654, 21.71073914], [74.55667877, 21.71166992], [74.55621338, 21.71261024], [74.55573273, 21.71355057], [74.55522919, 21.71447945], [74.55471039, 21.71537018], [74.55417633, 21.71623039], [74.55362701, 21.71701813], [74.55303192, 21.71774101], [74.55237579, 21.71839905], [74.55171967, 21.71894836], [74.55098724, 21.71939278], [74.55020142, 21.71970749], [74.54940033, 21.7199192], [74.54852295, 21.72002983], [74.54762268, 21.72002983], [74.54664612, 21.7199707], [74.54567719, 21.71982956], [74.5446701, 21.71965027], [74.54366302, 21.71940994], [74.5426178, 21.71915054], [74.54155731, 21.7188797], [74.54049683, 21.71861076], [74.53943634, 21.71832848], [74.53839111, 21.71809006], [74.53734589, 21.71787071], [74.53631592, 21.71769905], [74.53530884, 21.7175827], [74.53431702, 21.71754074], [74.53333282, 21.71749115], [74.53231049, 21.71747017], [74.53131866, 21.71747017], [74.53031921, 21.71747971], [74.52929688, 21.71754074], [74.52832031, 21.7175827], [74.52731323, 21.71763039], [74.52630615, 21.71772194], [74.5253067, 21.71780968], [74.52433014, 21.7179184], [74.52333832, 21.71808052], [74.5223465, 21.7182827], [74.52139282, 21.71850967], [74.52041626, 21.71879005], [74.51947784, 21.71911049], [74.51854706, 21.71947098], [74.51763153, 21.71986961], [74.516716, 21.72029114], [74.51583862, 21.72076035], [74.5149765, 21.72128105], [74.51422119, 21.72187996], [74.51352692, 21.72253036], [74.51288605, 21.72326088], [74.51226044, 21.72409058], [74.5117569, 21.72495079], [74.51138306, 21.72585106], [74.51122284, 21.72674942], [74.51125336, 21.72764969], [74.51135254, 21.72854805], [74.51152039, 21.72944069], [74.51174927, 21.73033905], [74.51197815, 21.73125076], [74.51226807, 21.73216248], [74.51255798, 21.73307991], [74.51286316, 21.73398018], [74.51317596, 21.73490906], [74.51348877, 21.73582268], [74.5137558, 21.73676109], [74.51403809, 21.7376709], [74.51425934, 21.73858261], [74.51447296, 21.73950958], [74.51463318, 21.74043083], [74.5147171, 21.74135017], [74.5147171, 21.74228096], [74.51461792, 21.74323082], [74.51447296, 21.74416924], [74.51426697, 21.74513054], [74.51407623, 21.74608994], [74.51386261, 21.74703979], [74.51365662, 21.74798012], [74.51354218, 21.7489109], [74.51348877, 21.74981117], [74.51352692, 21.75069046], [74.51378632, 21.75152969], [74.51436615, 21.75226021], [74.51516724, 21.75293922], [74.51599121, 21.75361061], [74.5166626, 21.75435066], [74.51700592, 21.75518036], [74.51721191, 21.75608063], [74.51740265, 21.75699997], [74.5175705, 21.75794029], [74.51769257, 21.75889969], [74.51780701, 21.75987053], [74.5178833, 21.76083183], [74.51790619, 21.76178932], [74.51789856, 21.76276016], [74.51786041, 21.76370811], [74.51773071, 21.76463127], [74.51759338, 21.76554108], [74.51735687, 21.76639938], [74.51700592, 21.76723099], [74.5165329, 21.76803017], [74.51596832, 21.76880074], [74.51529694, 21.7695694], [74.51463318, 21.77030945], [74.51393127, 21.77103043], [74.51320648, 21.77176094], [74.51257324, 21.77247047], [74.51185608, 21.77312088], [74.51101685, 21.77370071], [74.51021576, 21.77427101], [74.50946045, 21.77490807], [74.50888062, 21.77561951], [74.50840759, 21.77642822], [74.50800323, 21.77726936], [74.50763702, 21.77814102], [74.50728607, 21.77902985], [74.50695801, 21.77993965], [74.50665283, 21.78083038], [74.5063324, 21.78174019], [74.50596619, 21.78260994], [74.50315857, 21.79780006], [74.50364685, 21.80718231], [74.50932312, 21.81587982], [74.51181793, 21.82122993], [74.51699829, 21.85649109], [74.51747894, 21.87490082], [74.51776123, 21.88624001], [74.51843262, 21.89011002], [74.52146912, 21.89550972], [74.52746582, 21.90345001], [74.52749634, 21.90878105], [74.52398682, 21.91306114], [74.51735687, 21.91755104], [74.51464081, 21.92246819], [74.51560974, 21.9278717], [74.51555634, 21.93391991], [74.4967804, 21.94641113], [74.49233246, 21.94546127], [74.48985291, 21.94714928], [74.49340057, 21.95449066], [74.48928833, 21.95676041], [74.48568726, 21.95753288], [74.48449707, 21.96075058], [74.48293304, 21.96244049], [74.4778595, 21.96154976], [74.47512054, 21.96270943], [74.47218323, 21.96552086], [74.4673233, 21.96479988], [74.4641571, 21.96321106], [74.45996857, 21.9628315], [74.45170593, 21.96750069], [74.44863892, 21.97113037], [74.4471817, 21.97627068], [74.44303894, 21.98306847], [74.44262695, 21.99362946], [74.44107819, 21.99644089], [74.4362793, 21.9994812], [74.43621826, 22.00222969], [74.44380951, 22.00616074], [74.44573212, 22.0068512], [74.44995117, 22.00546265], [74.45391846, 22.00226974], [74.45381927, 22.00617027], [74.45150757, 22.00896835], [74.44764709, 22.01247978], [74.44451904, 22.01599121], [74.44255829, 22.02160072], [74.44603729, 22.02651978], [74.43945313, 22.02651978], [74.43554688, 22.03099823], [74.4177475, 22.02581024], [74.40651703, 22.02440071], [74.3964386, 22.02370262], [74.38831329, 22.02017975], [74.38366699, 22.01175117], [74.37818146, 22.00217056], [74.37718964, 22.00085068], [74.37664032, 22.00004005], [74.37609863, 21.99925041], [74.37552643, 21.99843979], [74.37496185, 21.99767113], [74.37438202, 21.9969101], [74.37375641, 21.99618912], [74.37310791, 21.99549103], [74.37238312, 21.99487114], [74.37159729, 21.9943428], [74.37069702, 21.99391937], [74.36974335, 21.99356842], [74.36875916, 21.99324989], [74.36778259, 21.99291039], [74.36685181, 21.99253082], [74.3660202, 21.99204063], [74.36531067, 21.99144173], [74.36463928, 21.9907608], [74.36400604, 21.99003983], [74.36342621, 21.98929024], [74.36286926, 21.9885006], [74.36235046, 21.98769951], [74.36180878, 21.98689079], [74.36126709, 21.98608017], [74.36074829, 21.98526001], [74.36019135, 21.98446274], [74.35962677, 21.98368073], [74.35901642, 21.98291969], [74.35842133, 21.98220062], [74.35775757, 21.98151016], [74.35700989, 21.98088074], [74.35626221, 21.98028946], [74.35546112, 21.97972107], [74.35463715, 21.97919846], [74.35378265, 21.9786911], [74.35289764, 21.97821045], [74.35202026, 21.97774124], [74.35114288, 21.97729111], [74.35024261, 21.97682953], [74.3493576, 21.97639084], [74.34844971, 21.97599983], [74.34749603, 21.97565079], [74.3465271, 21.97541046], [74.34555817, 21.97521973], [74.34455109, 21.97509956], [74.34358215, 21.97500992], [74.3425827, 21.97492027], [74.34158325, 21.97486115], [74.34057617, 21.97477913], [74.33957672, 21.97470856], [74.33859253, 21.97466278], [74.33757782, 21.97459984], [74.33660126, 21.97455025], [74.33557892, 21.97451019], [74.3345871, 21.97445107], [74.33360291, 21.97441101], [74.33258057, 21.97437286], [74.33158875, 21.97431946], [74.33058167, 21.97426987], [74.32958984, 21.97421837], [74.32858276, 21.97417259], [74.32758331, 21.97412109], [74.3265686, 21.97405052], [74.32557678, 21.97397995], [74.32459259, 21.97392082], [74.32359314, 21.97383118], [74.32260132, 21.97372818], [74.32158661, 21.97364998], [74.32058716, 21.97359085], [74.31958008, 21.97352028], [74.318573, 21.9734211], [74.31755829, 21.97333145], [74.31655121, 21.97323036], [74.31555176, 21.97310066], [74.31455231, 21.97296906], [74.31356812, 21.97281075], [74.31260681, 21.9726181], [74.31165314, 21.97240067], [74.31067657, 21.9721508], [74.30976105, 21.97186089], [74.30883026, 21.97151947], [74.3079071, 21.97113037], [74.30699921, 21.97068977], [74.30610657, 21.97022057], [74.30523682, 21.96972084], [74.30439758, 21.96917915], [74.30358887, 21.9686203], [74.30280304, 21.96804047], [74.3020401, 21.96743965], [74.30136108, 21.96680069], [74.30079651, 21.9660511], [74.3003006, 21.9652195], [74.29987335, 21.96433067], [74.29947662, 21.96344948], [74.29910278, 21.96257019], [74.29875946, 21.9616909], [74.2984314, 21.96081924], [74.29808044, 21.95992088], [74.29776001, 21.95903015], [74.29749298, 21.95813179], [74.29721069, 21.95721817], [74.29696655, 21.95631027], [74.29677582, 21.95540047], [74.29656982, 21.95449066], [74.29641724, 21.95356941], [74.29631042, 21.952631], [74.29621124, 21.9516983], [74.29611969, 21.95075989], [74.29603577, 21.9498291], [74.29593658, 21.94889069], [74.29585266, 21.94795036], [74.2957077, 21.94703293], [74.29559326, 21.94609833], [74.29538727, 21.94518089], [74.29521179, 21.94425011], [74.29502106, 21.94330025], [74.29480743, 21.94236755], [74.29454803, 21.94145012], [74.29425812, 21.94055939], [74.29387665, 21.93970108], [74.29345703, 21.93888092], [74.29290771, 21.93806076], [74.29225922, 21.93725014], [74.29148865, 21.93658257], [74.29064941, 21.93605995], [74.289711, 21.93579102], [74.28874969, 21.9356308], [74.28779602, 21.93548012], [74.28681946, 21.93534279], [74.2858429, 21.93518829], [74.28486633, 21.93507957], [74.2838974, 21.93494987], [74.28291321, 21.93483925], [74.28190613, 21.93474007], [74.28092194, 21.93464088], [74.27992249, 21.93455124], [74.27893066, 21.93445969], [74.27793121, 21.93437958], [74.2769165, 21.93429947], [74.27591705, 21.9342308], [74.27490997, 21.93416023], [74.27390289, 21.93409157], [74.27288818, 21.93401909], [74.27189636, 21.93394089], [74.27086639, 21.93388176], [74.26988983, 21.93380928], [74.26888275, 21.93374062], [74.26786041, 21.93366814], [74.26685333, 21.93359756], [74.26584625, 21.93352127], [74.26483154, 21.93344116], [74.26383972, 21.93336105], [74.26284027, 21.9332695], [74.26183319, 21.93317032], [74.26085663, 21.93307114], [74.25985718, 21.93296051], [74.25885773, 21.93285179], [74.25785828, 21.93272972], [74.25686646, 21.93259048], [74.255867, 21.93244171], [74.25489044, 21.9323101], [74.25390625, 21.93214989], [74.2529068, 21.93200111], [74.25193024, 21.93182945], [74.25093079, 21.93168259], [74.24994659, 21.93149948], [74.2489624, 21.93134117], [74.24798584, 21.93117905], [74.24700165, 21.9310112], [74.24603271, 21.93084145], [74.24503326, 21.93069077], [74.24402618, 21.93053055], [74.24304199, 21.9303894], [74.24208069, 21.93025017], [74.24108124, 21.93011093], [74.24009705, 21.92999077], [74.2390976, 21.92987061], [74.23809052, 21.92975998], [74.23710632, 21.9296608], [74.23610687, 21.92963028], [74.23510742, 21.92963982], [74.23412323, 21.92970085], [74.23310852, 21.92978096], [74.23208618, 21.92988014], [74.23108673, 21.92996025], [74.23008728, 21.93001938], [74.22908783, 21.93004036], [74.22809601, 21.93000984], [74.22709656, 21.92990112], [74.22614288, 21.92975998], [74.2251358, 21.92958832], [74.22416687, 21.92941284], [74.22319031, 21.92920113], [74.22219849, 21.92900085], [74.22122955, 21.9287796], [74.22026825, 21.92855072], [74.21927643, 21.92831993], [74.2183075, 21.92809105], [74.21733093, 21.92784119], [74.21636963, 21.92759132], [74.21539307, 21.92736053], [74.21440887, 21.92712021], [74.21343231, 21.92687988], [74.21246338, 21.92666054], [74.21147919, 21.92645073], [74.21051788, 21.92624092], [74.20952606, 21.92605972], [74.20855713, 21.9258709], [74.20758057, 21.92571831], [74.20658875, 21.92557907], [74.20561981, 21.92547035], [74.20464325, 21.92541122], [74.20362091, 21.92539978], [74.20262146, 21.92543983], [74.20163727, 21.92552948], [74.20063782, 21.92564964], [74.19962311, 21.92580032], [74.19863129, 21.92597008], [74.19763947, 21.92613983], [74.1966629, 21.9263382], [74.19567108, 21.92651939], [74.19467926, 21.92671013], [74.19367981, 21.92690086], [74.19268799, 21.92711067], [74.19169617, 21.92733955], [74.19069672, 21.92760277], [74.18974304, 21.92790031], [74.18882751, 21.92822266], [74.18792725, 21.92864037], [74.18708801, 21.92910767], [74.18630981, 21.92963982], [74.18554688, 21.93022156], [74.18480682, 21.93084145], [74.18408966, 21.93151093], [74.18341827, 21.93219948], [74.18273163, 21.93292046], [74.18206787, 21.93365097], [74.18144226, 21.93439102], [74.18080902, 21.93514061], [74.18016052, 21.93588066], [74.17952728, 21.93661118], [74.17893219, 21.93735123], [74.1783905, 21.93814087], [74.1778717, 21.93894958], [74.17735291, 21.93976021], [74.17681122, 21.94055939], [74.17624664, 21.9413414], [74.17563629, 21.94205284], [74.17494202, 21.94273186], [74.17418671, 21.94338036], [74.17343903, 21.94398117], [74.17260742, 21.94454956], [74.17179108, 21.94509125], [74.17095184, 21.94557953], [74.17011261, 21.94608116], [74.16924286, 21.94655037], [74.168396, 21.94704056], [74.16752625, 21.94752121], [74.16665649, 21.94800949], [74.16578674, 21.94846153], [74.16490936, 21.94893837], [74.16404724, 21.94939995], [74.16316223, 21.94985008], [74.16226959, 21.95030022], [74.16140747, 21.95074081], [74.1605072, 21.95116997], [74.15962219, 21.95158958], [74.15872192, 21.95201111], [74.1578064, 21.95240974], [74.15692139, 21.95280075], [74.15598297, 21.95310974], [74.15500641, 21.95334816], [74.15400696, 21.95356941], [74.15302277, 21.95369911], [74.15202332, 21.95386124], [74.15101624, 21.95396042], [74.15003204, 21.95401001], [74.14904022, 21.95403099], [74.14803314, 21.95404053], [74.14702606, 21.95404053], [74.14601898, 21.9540596], [74.14467621, 21.95656967], [74.14890289, 21.96071053], [74.1453476, 21.96461105], [74.14335632, 21.96988106], [74.14366913, 21.97222137], [74.14560699, 21.97400093], [74.15320587, 21.97557068], [74.1518631, 21.98089027], [74.15384674, 21.98641968], [74.14959717, 21.98880959], [74.14198303, 21.99123192], [74.12773132, 21.99376106], [74.11688995, 21.99863052], [74.1082077, 21.99835968], [74.10500336, 21.99893951], [74.1003418, 22.00159264], [74.10045624, 22.01055908], [74.09770203, 22.01545906], [74.10118866, 22.01828003], [74.10890198, 22.02181053], [74.11664581, 22.02464104], [74.12088776, 22.03026962], [74.1251297, 22.03589058], [74.13208008, 22.03873062], [74.14100647, 22.04086113], [74.14523315, 22.04368019], [74.14404297, 22.04788971], [74.13939667, 22.0506897], [74.13783264, 22.05350113], [74.14906311, 22.05632019], [74.15447998, 22.0577507], [74.16298676, 22.06056976], [74.16336823, 22.06409073], [74.16179657, 22.07110977], [74.16487885, 22.07393265], [74.16602325, 22.07814026], [74.16755676, 22.08236122], [74.17064667, 22.08447075], [74.17646027, 22.08449173], [74.18070984, 22.08660126], [74.17875671, 22.09011078], [74.17527008, 22.09151077], [74.17215729, 22.09360123], [74.17411041, 22.09641075], [74.17214203, 22.09852982], [74.17021179, 22.1013298], [74.1655426, 22.10271835], [74.16204834, 22.10271072], [74.15856171, 22.10200119], [74.15621185, 22.10409927], [74.15466309, 22.10550117], [74.15000916, 22.10408974], [74.14382172, 22.10126114], [74.13800049, 22.09845161], [74.13259125, 22.09632111], [74.13027191, 22.09770966], [74.12906647, 22.10333824], [74.12905884, 22.10825157], [74.13020325, 22.11387062], [74.13134766, 22.1201992], [74.13130951, 22.12441063], [74.12782288, 22.12721062], [74.12663269, 22.13212013], [74.12738037, 22.13774109], [74.12967682, 22.14266014], [74.13355255, 22.14619255], [74.13314056, 22.15321922], [74.13349152, 22.15813065], [74.13504028, 22.1616497], [74.13189697, 22.16444016], [74.1264801, 22.16654015], [74.12490845, 22.17215919], [74.12409973, 22.17776108], [74.12291718, 22.18198013], [74.12211609, 22.18760109], [74.12364197, 22.19252014], [74.12245941, 22.19812965], [74.12124634, 22.2051506], [74.12240601, 22.20866013], [74.12277985, 22.21290016], [74.11927032, 22.21638107], [74.11383057, 22.21918106], [74.10761261, 22.22056961], [74.10177612, 22.22056007], [74.09440613, 22.221241], [74.08744049, 22.22051048], [74.08159637, 22.22050095], [74.07578278, 22.22187805], [74.07338715, 22.22960091], [74.07454681, 22.2345295], [74.07842255, 22.23735809], [74.08460999, 22.23805809], [74.0892868, 22.24019051], [74.09158325, 22.24370003], [74.08922577, 22.24720955], [74.08535004, 22.24790001], [74.08067322, 22.24999046], [74.07872772, 22.25278091], [74.07987213, 22.25842094], [74.07943726, 22.26333809], [74.07826996, 22.2682476], [74.07242584, 22.26893044], [74.06891632, 22.27243042], [74.06463623, 22.2759304], [74.06149292, 22.28084183], [74.0591507, 22.28574944], [74.05989075, 22.29067039], [74.05832672, 22.29348183], [74.0579071, 22.29980087], [74.05905151, 22.30541039], [74.06254578, 22.3068409], [74.06643677, 22.30544281], [74.06680298, 22.31105995], [74.06674194, 22.31739044], [74.06828308, 22.32582283], [74.06826782, 22.33073044], [74.07405853, 22.33638191], [74.07596588, 22.34130287], [74.0743866, 22.34621048], [74.07164764, 22.34901047], [74.07084656, 22.35462952], [74.07198334, 22.36024094], [74.07702637, 22.36238098], [74.08364105, 22.36239052], [74.08985901, 22.36241913], [74.09527588, 22.36244011], [74.09836578, 22.36876106], [74.09989929, 22.37297821], [74.10534668, 22.37299156], [74.11196136, 22.37161255], [74.11508942, 22.36740112], [74.1162796, 22.36108971], [74.11709595, 22.35757065], [74.12445831, 22.35830116], [74.12914276, 22.35268974], [74.13034821, 22.34355927], [74.13153076, 22.33794975], [74.1342926, 22.3323307], [74.14362335, 22.33026123], [74.15409851, 22.32887077], [74.16384125, 22.32678986], [74.17588806, 22.32471275], [74.18406677, 22.32261086], [74.19106293, 22.32192993], [74.19568634, 22.32543945], [74.19644165, 22.33390045], [74.19484711, 22.34371948], [74.19483185, 22.34934044], [74.19754028, 22.35073853], [74.1979599, 22.34793282], [74.198349, 22.34301949], [74.2022171, 22.34303093], [74.20533752, 22.34794998], [74.20609283, 22.35357094], [74.20565796, 22.35989952], [74.20603943, 22.36341095], [74.20680237, 22.36762047], [74.20993042, 22.36621094], [74.21111298, 22.36273003], [74.21344757, 22.35921097], [74.21656036, 22.35781288], [74.22355652, 22.35783005], [74.22704315, 22.35853958], [74.22663116, 22.36485291], [74.22738647, 22.36907005], [74.22737885, 22.37259293], [74.22582245, 22.37540054], [74.22543335, 22.37820053], [74.23085022, 22.37962151], [74.2351532, 22.37821007], [74.24019623, 22.37681961], [74.24563599, 22.37753105], [74.24600983, 22.38315964], [74.24951935, 22.38315964], [74.25300598, 22.38387108], [74.25611115, 22.38599014], [74.25685883, 22.39019966], [74.25723267, 22.39511108], [74.25798798, 22.40003014], [74.26345062, 22.39653969], [74.26850891, 22.39443016], [74.27394867, 22.3930397], [74.28135681, 22.39375114], [74.2871933, 22.39306068], [74.29106903, 22.39166069], [74.29418182, 22.39446831], [74.28830719, 22.39797974], [74.28172302, 22.40007973], [74.27820587, 22.40287971], [74.27471161, 22.40357971], [74.27120972, 22.40498161], [74.2700119, 22.41059113], [74.26999664, 22.41481018], [74.26648712, 22.4183197], [74.26412201, 22.42464066], [74.25945282, 22.42885017], [74.25402069, 22.43305969], [74.24659729, 22.4365406], [74.23725891, 22.43934059], [74.22831726, 22.44003105], [74.22364044, 22.44001007], [74.22054291, 22.4421196], [74.21856689, 22.4428196], [74.21663666, 22.43931961], [74.21626282, 22.43439102], [74.21160126, 22.43437004], [74.20461273, 22.43717194], [74.20459747, 22.44067955], [74.2045517, 22.44701004], [74.20493317, 22.45474052], [74.20450592, 22.46105003], [74.20449066, 22.46668053], [74.20252991, 22.47229958], [74.19785309, 22.47509956], [74.19082642, 22.47788048], [74.18541718, 22.46944046], [74.18270874, 22.46453094], [74.18234253, 22.46030045], [74.18430328, 22.45609093], [74.18624878, 22.45259285], [74.18743134, 22.44767189], [74.18667603, 22.44415092], [74.18280029, 22.44275093], [74.17267609, 22.44201279], [74.17153931, 22.43779182], [74.17077637, 22.4335804], [74.1672821, 22.43217087], [74.16107178, 22.43215942], [74.15873718, 22.43494987], [74.15598297, 22.43987274], [74.15596008, 22.44548988], [74.15672302, 22.45041084], [74.15628815, 22.4567318], [74.15122986, 22.45671844], [74.14424896, 22.45671082], [74.14074707, 22.4538784], [74.13728333, 22.44824982], [74.13417816, 22.44262123], [74.13111115, 22.43629074], [74.1307373, 22.42996979], [74.13037872, 22.42505074], [74.13037872, 22.42154121], [74.12689972, 22.42012978], [74.1230011, 22.4208107], [74.11637115, 22.42642021], [74.11051941, 22.42921066], [74.10507202, 22.43341064], [74.10270691, 22.4397316], [74.10073853, 22.44534111], [74.10225677, 22.4509697], [74.10573578, 22.45589066], [74.10610962, 22.4622097], [74.10334778, 22.46783066], [74.10024261, 22.46923256], [74.0951767, 22.46920967], [74.09050751, 22.46920013], [74.08583832, 22.46707916], [74.07808685, 22.46564293], [74.07843018, 22.47339058], [74.07878876, 22.48111153], [74.08030701, 22.48603058], [74.08344269, 22.48463058], [74.08538818, 22.48182106], [74.08889771, 22.47973251], [74.09043884, 22.48254967], [74.08963776, 22.48887062], [74.08727264, 22.49378014], [74.08570099, 22.4987011], [74.08644867, 22.50502014], [74.08526611, 22.50851822], [74.08136749, 22.50851822], [74.07865143, 22.50921059], [74.07396698, 22.51059914], [74.06968689, 22.50988007], [74.0650177, 22.51057053], [74.06188965, 22.51126099], [74.05879974, 22.51054955], [74.05609894, 22.50562859], [74.0545578, 22.50139809], [74.0499115, 22.49998283], [74.04640961, 22.49715996], [74.04566956, 22.49294281], [74.04293823, 22.49082947], [74.03708649, 22.49151039], [74.03591919, 22.49641991], [74.03511047, 22.50274277], [74.03466797, 22.50836945], [74.0389328, 22.51400185], [74.04358673, 22.51682091], [74.04315948, 22.52384949], [74.04078674, 22.5301609], [74.04231262, 22.53718948], [74.04463959, 22.54212189], [74.0500412, 22.54565048], [74.05628204, 22.5477829], [74.06674957, 22.55089951], [74.07805634, 22.55162811], [74.08428955, 22.54955101], [74.09327698, 22.54465103], [74.10069275, 22.54117012], [74.10575104, 22.53767014], [74.10964966, 22.53839111], [74.11351776, 22.54120064], [74.11859894, 22.53981018], [74.12211609, 22.53560829], [74.12484741, 22.53000069], [74.12760925, 22.52437973], [74.12995911, 22.52158928], [74.13347626, 22.51877975], [74.13852692, 22.52019119], [74.14321136, 22.51880074], [74.14788818, 22.51811028], [74.15332031, 22.51741982], [74.15680695, 22.52094078], [74.15795135, 22.52656937], [74.15753937, 22.53219032], [74.15869141, 22.53429985], [74.16295624, 22.53712082], [74.16802216, 22.54134941], [74.1726532, 22.54486847], [74.17887115, 22.54840088], [74.18431854, 22.54981041], [74.19171143, 22.55335045], [74.19519806, 22.55686951], [74.19557953, 22.56038094], [74.19519043, 22.56248856], [74.19007874, 22.56740189], [74.19941711, 22.57022095], [74.20332336, 22.56812096], [74.20955658, 22.5667305], [74.21383667, 22.56744003], [74.21652222, 22.57798958], [74.2184906, 22.58151054], [74.22274017, 22.58152008], [74.22622681, 22.5850296], [74.22737122, 22.59065819], [74.23008728, 22.59699059], [74.23432922, 22.6068306], [74.23665619, 22.61387062], [74.24365997, 22.61387062], [74.24754333, 22.61740112], [74.24986267, 22.62302017], [74.25374603, 22.62302971], [74.25763702, 22.62444115], [74.25840759, 22.62655067], [74.25644684, 22.63076019], [74.25641632, 22.63568115], [74.25914764, 22.63639069], [74.26226807, 22.63850975], [74.26342773, 22.64272118], [74.26535797, 22.6448307], [74.26925659, 22.64344025], [74.27160645, 22.64133263], [74.27355194, 22.64063263], [74.27472687, 22.64274025], [74.27822113, 22.64766121], [74.28991699, 22.64344978], [74.29458618, 22.64136124], [74.29888153, 22.64067078], [74.30433655, 22.63997078], [74.3094101, 22.63928032], [74.31328583, 22.63858032], [74.31720734, 22.63646126], [74.32227325, 22.63647842], [74.32537079, 22.63858986], [74.32653046, 22.64211082], [74.32807922, 22.64421082], [74.33081055, 22.64351082], [74.33434296, 22.64141083], [74.33705139, 22.64071274], [74.34406281, 22.6421299], [74.35224915, 22.63932037], [74.36395264, 22.63652039], [74.37288666, 22.63652992], [74.38108826, 22.63863945], [74.38418579, 22.64356995], [74.38456726, 22.65057945], [74.38414001, 22.66043091], [74.38490295, 22.66957092], [74.38994598, 22.67801285], [74.39424133, 22.68573952], [74.39692688, 22.69207001], [74.39691162, 22.70050049], [74.40080261, 22.70681953], [74.40117645, 22.71244049], [74.40078735, 22.72017097], [74.40307617, 22.73070908], [74.40851593, 22.73705101], [74.41438293, 22.74477959], [74.41707611, 22.75111008], [74.42057037, 22.75743103], [74.42523956, 22.76024055], [74.43107605, 22.77008057], [74.43534851, 22.77922249], [74.43923187, 22.78555107], [74.44039917, 22.79327965], [74.44078064, 22.79961014], [74.43881989, 22.80521965], [74.4391861, 22.80944061], [74.4438858, 22.81014061], [74.45168304, 22.81085968], [74.45947266, 22.81225967], [74.46494293, 22.81508064], [74.46881866, 22.82351112], [74.4719162, 22.83265114], [74.47891998, 22.85864067], [74.47540283, 22.86497116], [74.47421265, 22.86778069], [74.47380066, 22.87479973], [74.47146606, 22.88043976], [74.46871185, 22.88746071], [74.46636963, 22.8944912], [74.466362, 22.90081024], [74.46360016, 22.90714073], [74.46282196, 22.91345978], [74.45812988, 22.91628265], [74.45500946, 22.91838074], [74.45147705, 22.92399979], [74.44406128, 22.92259979], [74.43859863, 22.9176712], [74.43585968, 22.92048073], [74.4319458, 22.92258072], [74.42843628, 22.91978073], [74.42375946, 22.91978073], [74.41870117, 22.9183712], [74.41243744, 22.91274834], [74.40817261, 22.90431023], [74.400383, 22.89937973], [74.39293671, 22.90219116], [74.38826752, 22.90710258], [74.38160706, 22.90990829], [74.37769318, 22.91553116], [74.37454987, 22.9225502], [74.37140656, 22.92605972], [74.36553955, 22.92957115], [74.3620224, 22.93309021], [74.36003876, 22.94222069], [74.35417938, 22.9471302], [74.34792328, 22.95344925], [74.34438324, 22.95836258], [74.34163666, 22.96469116], [74.34971619, 22.96876907], [74.35481262, 22.97511101], [74.35713959, 22.97722054], [74.36297607, 22.97793007], [74.36805725, 22.97653008], [74.3707962, 22.97723007], [74.3707962, 22.98005295], [74.3687973, 22.98355103], [74.36546326, 22.98981094], [74.35771179, 23.00037193], [74.35536194, 23.00307083], [74.35066223, 23.01552963], [74.34919739, 23.03024101], [74.3467865, 23.03394127], [74.33886719, 23.03582954], [74.33191681, 23.03919029], [74.32772064, 23.04269028], [74.32531738, 23.04817009], [74.32277679, 23.06269073], [74.33927917, 23.06697083], [74.3478775, 23.07080078], [74.35510254, 23.07580185], [74.35954285, 23.08049965], [74.36112213, 23.09031105], [74.36696625, 23.09552002], [74.38767242, 23.11044121], [74.39118958, 23.11199951], [74.40683746, 23.11177063], [74.41409302, 23.11096191], [74.41884613, 23.10847092], [74.42610168, 23.10602951], [74.4331665, 23.10568047], [74.4393158, 23.09807968], [74.4454422, 23.09293175], [74.45823669, 23.08706093], [74.46724701, 23.08525848], [74.49140167, 23.08838272], [74.51228333, 23.08883095], [74.51360321, 23.09590149], [74.52327728, 23.09891129], [74.53543854, 23.10151291], [74.54265594, 23.10690117], [74.54650116, 23.11280823], [74.54751587, 23.11849022], [74.54570007, 23.13207054], [74.56604004, 23.13523293], [74.57363129, 23.1371994], [74.58007812, 23.13997078], [74.58863068, 23.14146996], [74.59723663, 23.14199257], [74.60806274, 23.14482117], [74.61415863, 23.14833069], [74.61782837, 23.15193176], [74.62567902, 23.16294098], [74.64198303, 23.17266273], [74.65474701, 23.18202972], [74.65983582, 23.18789101], [74.66532135, 23.19824982], [74.66915894, 23.2014904], [74.68756866, 23.19670105], [74.71552277, 23.19466972], [74.721138, 23.19697952], [74.73477936, 23.20639992], [74.74569702, 23.21211052], [74.74603271, 23.21536064], [74.75083923, 23.23038101], [74.7457962, 23.23270988], [74.74098206, 23.2293396], [74.74053955, 23.22904015], [74.73995972, 23.22863007], [74.7329483, 23.22375107], [74.72431946, 23.22011948], [74.71895599, 23.21943283], [74.712883, 23.22135925], [74.7026062, 23.21970177], [74.69960785, 23.22034073], [74.69500732, 23.22307968], [74.69554138, 23.22859001], [74.70381165, 23.23315048], [74.71324921, 23.2363205], [74.72215271, 23.24251175], [74.71853638, 23.24600983], [74.71489716, 23.25296021], [74.71026611, 23.25814056], [74.70334625, 23.26164246], [74.70162201, 23.26675034], [74.70114899, 23.27214241], [74.68048859, 23.27526283], [74.67312622, 23.27486992], [74.66649628, 23.27111053], [74.65222168, 23.26081276], [74.64624786, 23.25971985], [74.63214111, 23.26340103], [74.62956238, 23.26584053], [74.6265564, 23.27599907], [74.62229156, 23.28133965], [74.61530304, 23.28460121], [74.60669708, 23.28536034], [74.59905243, 23.28363037], [74.592659, 23.28358078], [74.58676147, 23.28446007], [74.57728577, 23.29734993], [74.5719223, 23.30089188], [74.56735229, 23.29846191], [74.56210327, 23.29208946], [74.55822754, 23.28531075], [74.5534668, 23.28252029], [74.54856873, 23.28676033], [74.54390717, 23.30005264], [74.54062653, 23.30511284], [74.53568268, 23.30952263], [74.53421021, 23.31398964], [74.53450775, 23.32036972], [74.53366089, 23.32303047], [74.53032684, 23.32414055], [74.52085114, 23.32160187], [74.51924896, 23.32193756], [74.51830292, 23.32872963], [74.52028656, 23.33169174], [74.53839874, 23.33399963], [74.54271698, 23.3386898], [74.5437088, 23.35898972], [74.54582977, 23.36379814], [74.55580902, 23.36297989], [74.56022644, 23.36449051], [74.56521606, 23.37522125], [74.57071686, 23.3777504], [74.57241058, 23.38332939], [74.57314301, 23.41924286], [74.57402039, 23.42254257], [74.57966614, 23.4224205], [74.59146881, 23.42513084], [74.59845734, 23.42975998], [74.61312103, 23.45155144], [74.61338043, 23.46136093], [74.62699127, 23.46198082], [74.63642883, 23.46406174], [74.65223694, 23.46339035], [74.65473175, 23.46442032], [74.65894318, 23.46680069], [74.66409302, 23.47334099], [74.66932678, 23.48389244], [74.67446136, 23.48568153], [74.68093872, 23.48509026], [74.68371582, 23.48658943], [74.68776703, 23.49220085], [74.68740845, 23.49580956], [74.70066071, 23.50368118], [74.71089935, 23.50563049], [74.71877289, 23.50358009], [74.72589111, 23.49846077], [74.73365784, 23.50052071], [74.73777771, 23.50678062], [74.74237061, 23.51947975], [74.75707245, 23.52217293], [74.7639389, 23.52471161], [74.77072906, 23.53577042], [74.77406311, 23.54330254], [74.78501129, 23.54803085], [74.792099, 23.5486412], [74.79633331, 23.54626083], [74.79875946, 23.54043961], [74.80288696, 23.5340519], [74.81230927, 23.53843117], [74.81575775, 23.53961945], [74.81923676, 23.54079819], [74.83009338, 23.54952049], [74.83757782, 23.55321121], [74.84542084, 23.55417061], [74.85147858, 23.55739975], [74.8589859, 23.56949997], [74.86171722, 23.57234001], [74.86933136, 23.57479858], [74.87265015, 23.57822037], [74.87502289, 23.5835495], [74.87457275, 23.59011078], [74.87732697, 23.59439087], [74.87937927, 23.59596062], [74.8849411, 23.60330963], [74.88609314, 23.60642815], [74.89803314, 23.61218262], [74.90602875, 23.62295151], [74.90956879, 23.62416077], [74.92193604, 23.62231064], [74.92787933, 23.62438011], [74.93972015, 23.63037109], [74.94034576, 23.63692284], [74.9389801, 23.64318848], [74.93061066, 23.64821815], [74.92838287, 23.6531601], [74.92421722, 23.6685009], [74.90991211, 23.67690086], [74.90762329, 23.68283081], [74.91043854, 23.68798065], [74.91745758, 23.6921196], [74.92304993, 23.69658089], [74.92289734, 23.71386909], [74.92424011, 23.71915054], [74.93199158, 23.72834015], [74.94056702, 23.73487091], [74.93810272, 23.74287987], [74.93192291, 23.75641823], [74.93187714, 23.75811005], [74.93992615, 23.76585007], [74.93947601, 23.77067184], [74.93785095, 23.77671051], [74.92993164, 23.79420853], [74.92761993, 23.79833031], [74.91500854, 23.79918861], [74.91033936, 23.80084038], [74.91191864, 23.81261063], [74.91326141, 23.83662987], [74.91581726, 23.8456707], [74.91313934, 23.84986115], [74.91024017, 23.85213089], [74.90688324, 23.85638046], [74.90518951, 23.86811066], [74.9056778, 23.8739109], [74.90724182, 23.87675095], [74.91049957, 23.88850975], [74.91385651, 23.90336037], [74.91461945, 23.91246986], [74.91742706, 23.91757011], [74.92337799, 23.92490959], [74.92360687, 23.92926979], [74.92131042, 23.93571281], [74.92431641, 23.93861008], [74.92984772, 23.94096184], [74.93112183, 23.94491005], [74.93151855, 23.94681931], [74.93760681, 23.95608139], [74.94145966, 23.96051979], [74.96334839, 23.97367096], [74.96869659, 23.97973061], [74.97292328, 23.99105263], [74.972229, 24.00362968], [74.97981262, 24.00989914], [74.98779297, 24.01433182], [74.99236298, 24.02323151], [74.99298859, 24.02970123], [74.99038696, 24.03343964], [74.98121643, 24.04104042], [74.97940826, 24.07201195], [74.97625732, 24.07600975], [74.97155762, 24.07785988], [74.96517181, 24.08272171], [74.96186066, 24.08963013], [74.96074677, 24.09416008], [74.96089172, 24.10550117], [74.95951843, 24.11009026], [74.95487213, 24.11203957], [74.93914032, 24.12111092], [74.93618011, 24.12376976], [74.9389801, 24.12788963], [74.93665314, 24.13898087], [74.92469025, 24.14523125], [74.92350769, 24.14928055], [74.92751312, 24.15715027], [74.92146301, 24.16024971], [74.9201889, 24.16284752], [74.90033722, 24.17430115], [74.89948273, 24.17844009], [74.8976593, 24.18237114], [74.89729309, 24.18704033], [74.8811264, 24.21350288], [74.88017273, 24.21648026], [74.88671112, 24.22492027], [74.88970947, 24.22689056], [74.89821625, 24.22907066], [74.90271759, 24.23101044], [74.90585327, 24.23372078], [74.90725708, 24.24081039], [74.90544128, 24.24530983], [74.90405273, 24.24587822], [74.89700317, 24.24917984], [74.89428711, 24.2616806], [74.88905334, 24.26684952], [74.88530731, 24.2687397], [74.87542725, 24.27802086], [74.86972046, 24.28070831], [74.86403656, 24.27396011], [74.86255646, 24.27370071], [74.85975647, 24.27299118], [74.85659027, 24.27219963], [74.85331726, 24.26997948], [74.84390259, 24.27016068], [74.83891296, 24.27123833], [74.83264923, 24.27157021], [74.82578278, 24.27330017], [74.81964874, 24.27626038], [74.81516266, 24.27700996], [74.79029846, 24.27187157], [74.77968597, 24.27260971], [74.77253723, 24.27198029], [74.76647949, 24.27342033], [74.75479126, 24.27897072], [74.75280762, 24.28265953], [74.75302124, 24.28939056], [74.75746155, 24.29622078], [74.7670517, 24.30446053], [74.78363037, 24.31680107], [74.78482056, 24.32113075], [74.78317261, 24.3194294], [74.78379059, 24.33609962], [74.78633881, 24.34386063], [74.78621674, 24.34880066], [74.78276062, 24.35466003], [74.78167725, 24.35835075], [74.78462219, 24.36736107], [74.7869873, 24.3716507], [74.78835297, 24.37177086], [74.79315948, 24.37614059], [74.79833221, 24.384161], [74.80227661, 24.38734055], [74.80541229, 24.39545059], [74.81231689, 24.40915108], [74.81479645, 24.41069031], [74.82524109, 24.40833282], [74.82639313, 24.41069031], [74.82723236, 24.41680908], [74.82701111, 24.42360115], [74.8351593, 24.42951965], [74.84586334, 24.44073105], [74.8477478, 24.44355965], [74.85389709, 24.44950294], [74.85749817, 24.45150185], [74.85817719, 24.4555397], [74.85695648, 24.46327972], [74.85813141, 24.46733284], [74.85411072, 24.47020912], [74.85066986, 24.4688282], [74.8493576, 24.46664047], [74.84455109, 24.46590996], [74.84085083, 24.46722031], [74.8365097, 24.46539116], [74.83378601, 24.46042061], [74.81826782, 24.4619503], [74.82010651, 24.47290039], [74.8246994, 24.47923088], [74.82419586, 24.48354912], [74.82238007, 24.4878006], [74.81684113, 24.49117088], [74.81450653, 24.49221039], [74.81083679, 24.49200058], [74.80800629, 24.49304008], [74.801651, 24.49208069], [74.79595184, 24.49324989], [74.79187775, 24.49327087], [74.78495789, 24.48989105], [74.78153229, 24.48486137], [74.77899933, 24.48338127], [74.77330017, 24.48509979], [74.7661972, 24.49065018], [74.76081848, 24.48857117], [74.75731659, 24.48882294], [74.75065613, 24.49200058], [74.73504639, 24.50362015], [74.73082733, 24.51003075], [74.72718811, 24.5107708], [74.72370911, 24.51040077], [74.71555328, 24.50823975], [74.71290588, 24.50922012], [74.71193695, 24.51094055], [74.71570587, 24.52283096], [74.72342682, 24.53115082], [74.7285614, 24.53479004], [74.74771118, 24.53623962], [74.74961853, 24.5425396], [74.74759674, 24.5476799], [74.74854279, 24.5517292], [74.75234222, 24.55237007], [74.75675201, 24.55462074], [74.75746155, 24.55681992], [74.75634766, 24.55989075], [74.7569809, 24.56365013], [74.75547791, 24.57098961], [74.75377655, 24.57838058], [74.75154114, 24.58611107], [74.75031281, 24.58866119], [74.74668884, 24.59299278], [74.74797058, 24.59680939], [74.75595093, 24.6006794], [74.76017761, 24.60139084], [74.77065277, 24.60584259], [74.77723694, 24.60539055], [74.78176117, 24.6071701], [74.78633118, 24.61010933], [74.79012299, 24.61075974], [74.79055023, 24.61740112], [74.7873764, 24.61759186], [74.78781891, 24.62078094], [74.78483582, 24.62928963], [74.78344727, 24.63676071], [74.79138947, 24.64542961], [74.79350281, 24.64944077], [74.79302216, 24.65155983], [74.79493713, 24.65470123], [74.79934692, 24.65657043], [74.80237579, 24.65691948], [74.8049469, 24.65956116], [74.80873871, 24.66996193], [74.81137848, 24.6716404], [74.81482697, 24.66977119], [74.81710815, 24.67167091], [74.81774902, 24.6764698], [74.81775665, 24.6799202], [74.81333923, 24.6861496], [74.80966949, 24.68653107], [74.79234314, 24.68432045], [74.79197693, 24.68157959], [74.78946686, 24.67893982], [74.7857132, 24.67994118], [74.77606201, 24.68605995], [74.77527618, 24.68773079], [74.77786255, 24.69321823], [74.77731323, 24.69668961], [74.77964783, 24.70066071], [74.78089142, 24.70508957], [74.78385925, 24.7095108], [74.7844162, 24.71264076], [74.78315735, 24.71821976], [74.78753662, 24.72192955], [74.78965759, 24.72663116], [74.78837585, 24.72803116], [74.78386688, 24.73035049], [74.78137207, 24.74085045], [74.78005219, 24.74274826], [74.78607941, 24.74691963], [74.79254913, 24.7501812], [74.79978943, 24.75171089], [74.80314636, 24.75485229], [74.80191803, 24.76654053], [74.80114746, 24.78668976], [74.79847717, 24.7905407], [74.79931641, 24.79564095], [74.80980682, 24.79640007], [74.81495667, 24.78145027], [74.81854248, 24.76534081], [74.8292923, 24.74590111], [74.83487701, 24.73200035], [74.84884644, 24.70872116], [74.84970856, 24.70633125], [74.84984589, 24.69865036], [74.85182953, 24.69659042], [74.85431671, 24.69671059], [74.85531616, 24.69922066], [74.85396576, 24.70412064], [74.85636139, 24.70517921], [74.85853577, 24.70218086], [74.85983276, 24.69388962], [74.86245728, 24.69234276], [74.86521149, 24.69207001], [74.86691284, 24.69052124], [74.86975861, 24.67878914], [74.87268829, 24.67592049], [74.87343597, 24.66948128], [74.87502289, 24.66748047], [74.87767029, 24.66578102], [74.88018036, 24.66801071], [74.88791656, 24.65772247], [74.89285278, 24.65534973], [74.89450836, 24.65814972], [74.8935318, 24.66098022], [74.8935318, 24.66385841], [74.89700317, 24.66555977], [74.90246582, 24.65631104], [74.90563965, 24.66033936], [74.90854645, 24.66157913], [74.90965271, 24.66043091], [74.91300964, 24.66041183], [74.91478729, 24.65942001], [74.91986847, 24.65842056], [74.92945099, 24.65917015], [74.93476105, 24.66184807], [74.93718719, 24.66015053], [74.93917847, 24.66171074], [74.94285583, 24.66039085], [74.94387817, 24.66228294], [74.94181824, 24.66682053], [74.94300842, 24.66889763], [74.95202637, 24.67031288], [74.95265961, 24.67385101], [74.95197296, 24.67646027], [74.95728302, 24.68268967], [74.95923615, 24.67990112], [74.96116638, 24.67889023], [74.96198273, 24.67958069], [74.96182251, 24.68370056], [74.96102905, 24.68609047], [74.95990753, 24.68671989], [74.9598999, 24.68875122], [74.96485901, 24.69454193], [74.96216583, 24.7008419], [74.96411133, 24.70046806], [74.99043274, 24.70634842], [74.99371338, 24.70578957], [74.99655914, 24.70684242], [74.99989319, 24.70848846], [75.00035095, 24.71056938], [74.99941254, 24.71379089], [74.99664307, 24.71599007], [74.99521637, 24.71614075], [74.99211884, 24.72826195], [74.99075317, 24.73376846], [74.99202728, 24.74381065], [74.99343109, 24.75272942], [74.9970932, 24.75420952], [75.02023315, 24.75276756], [75.02131653, 24.76716042], [75.02133942, 24.77026939], [75.02137756, 24.77285957], [75.02005005, 24.7744503], [75.01795959, 24.7807312], [75.01629639, 24.78594971], [75.01293182, 24.79380989], [75.00705719, 24.79606056], [74.99832916, 24.79771042], [74.99001312, 24.79381943], [74.97038269, 24.79086113], [74.96157837, 24.79117012], [74.95542145, 24.79244041], [74.94595337, 24.79171944], [74.93855286, 24.79479027], [74.92941284, 24.79548264], [74.92207336, 24.7884407], [74.91694641, 24.78718185], [74.90997314, 24.78821945], [74.90518188, 24.79746056], [74.89743805, 24.79920959], [74.89195251, 24.79911041], [74.8846817, 24.80243111], [74.88053894, 24.80796814], [74.88014984, 24.8105011], [74.87805176, 24.81318092], [74.87023163, 24.81205177], [74.86785126, 24.81311989], [74.85856628, 24.81306076], [74.85946655, 24.7995491], [74.85794067, 24.79462051], [74.85144806, 24.79265976], [74.84889221, 24.79265976], [74.84078217, 24.80341911], [74.83751678, 24.80846024], [74.84597778, 24.81484032], [74.85296631, 24.81553078], [74.85746002, 24.81784821], [74.85903931, 24.82015991], [74.85903168, 24.82901001], [74.85748291, 24.8429985], [74.85604858, 24.84716988], [74.85588837, 24.85320091], [74.8529129, 24.86033058], [74.84565735, 24.87210274], [74.84237671, 24.87496948], [74.84015656, 24.88055038], [74.8394165, 24.89286995], [74.83783722, 24.89721107], [74.83512115, 24.89703941], [74.83161926, 24.89892006], [74.82713318, 24.89912987], [74.82411194, 24.91481018], [74.8236084, 24.92850113], [74.82421875, 24.94009972], [74.82534027, 24.94045067], [74.82498932, 24.94589043], [74.82627106, 24.95220947], [74.83114624, 24.95730972], [74.83061218, 24.96191025], [74.83271027, 24.9674511], [74.84635162, 24.97429085], [74.85320282, 24.97472], [74.86209869, 24.96583939], [74.86203766, 24.96282959], [74.86351776, 24.95729065], [74.86387634, 24.9475708], [74.86572266, 24.94326973], [74.86720276, 24.93694115], [74.87085724, 24.93720055], [74.87728119, 24.93939018], [74.87911987, 24.9487896], [74.88469696, 24.94976044], [74.8899231, 24.94145012], [74.90054321, 24.93974113], [74.90260315, 24.93727112], [74.90265656, 24.93468094], [74.90428925, 24.93011093], [74.90735626, 24.92867088], [74.91293335, 24.9283886], [74.91100311, 24.92328072], [74.91174316, 24.91887283], [74.90688324, 24.90715981], [74.91252136, 24.89909935], [74.91615295, 24.89944077], [74.91951752, 24.8948307], [74.92008209, 24.89184952], [74.92368317, 24.89207077], [74.92695618, 24.89036942], [74.92951202, 24.88788986], [74.9307785, 24.89397049], [74.93547058, 24.8952198], [74.93969727, 24.8934803], [74.9462204, 24.8939209], [74.9487381, 24.89480019], [74.95020294, 24.89295006], [74.95043182, 24.88997078], [74.94480896, 24.87791061], [74.94883728, 24.87812042], [74.95633698, 24.87495995], [74.96353912, 24.87408066], [74.97173309, 24.8753891], [74.97733307, 24.87747955], [74.98416901, 24.87763023], [74.98751068, 24.87597275], [74.99104309, 24.87500191], [74.99767303, 24.8766098], [75.01261139, 24.87408066], [75.01508331, 24.87020111], [75.0194931, 24.86693001], [75.0229187, 24.86561966], [75.02974701, 24.86054039], [75.03411102, 24.85860062], [75.04338837, 24.85922813], [75.05108643, 24.86488914], [75.05713654, 24.87105179], [75.0598526, 24.87473106], [75.05877686, 24.87771034], [75.05626678, 24.88091087], [75.05634308, 24.88194084], [75.0592804, 24.88129997], [75.0631485, 24.87746811], [75.06620026, 24.87839127], [75.0735321, 24.88731003], [75.07685089, 24.88883972], [75.08167267, 24.88913918], [75.08532715, 24.88889122], [75.0866394, 24.88657951], [75.0870285, 24.88347054], [75.08834076, 24.8810997], [75.09011078, 24.87973022], [75.1149826, 24.88713837], [75.11886597, 24.88903999], [75.11943054, 24.89583015], [75.1177063, 24.9051609], [75.11493683, 24.91184044], [75.11942291, 24.91814041], [75.11772919, 24.94634056], [75.11569214, 24.95364952], [75.11534882, 24.96112823], [75.1157074, 24.96539116], [75.1190567, 24.97475243], [75.11982727, 24.97575951], [75.13352966, 24.97524261], [75.13471985, 24.97772026], [75.13656616, 24.97874069], [75.14685059, 24.97957993], [75.149086, 24.98122025], [75.14775848, 24.98163986], [75.13432312, 24.98266029], [75.13802338, 24.98636246], [75.14037323, 24.98713112], [75.14385986, 24.98705292], [75.14582825, 24.98643112], [75.15215302, 24.98868942], [75.1608963, 24.98761177], [75.16131592, 24.99008942], [75.16256714, 24.99170113], [75.16439819, 24.99166107], [75.16676331, 25.00610924], [75.16924286, 25.00996971], [75.16860199, 25.01319122], [75.16525269, 25.02231979], [75.15921021, 25.02407074], [75.15470886, 25.02886963], [75.15628052, 25.03544044], [75.15912628, 25.04547119], [75.16696167, 25.0442009], [75.17378235, 25.05379295], [75.18209076, 25.04758072], [75.18531036, 25.04253006], [75.1917572, 25.03836823], [75.19441986, 25.03770065], [75.19509125, 25.03751945], [75.20056152, 25.03449821], [75.20355225, 25.0388298], [75.20548248, 25.0424099], [75.21821594, 25.04144096], [75.2270813, 25.03853035], [75.2375412, 25.04191971], [75.24459076, 25.03993034], [75.25562286, 25.04004288], [75.26597595, 25.04306984], [75.27826691, 25.04470062], [75.29255676, 25.04288292], [75.30016327, 25.0440197], [75.31048584, 25.04607964], [75.32266998, 25.0442524], [75.33615875, 25.04488945], [75.34558868, 25.0428009], [75.349617, 25.04173088], [75.35424042, 25.03737068], [75.35005188, 25.03327179], [75.35362244, 25.02873039], [75.35154724, 25.02515984], [75.35061646, 25.0248394], [75.3431015, 25.02230072], [75.32949066, 25.01762962], [75.32248688, 25.01338959], [75.31894684, 25.00650978], [75.32311249, 25.00090981], [75.32203674, 24.99612999], [75.32208252, 24.98961258], [75.32312012, 24.98224068], [75.32636261, 24.97616005], [75.33127594, 24.9760704], [75.3337326, 24.9674511], [75.33541107, 24.96471024], [75.33748627, 24.96310043], [75.33426666, 24.95061111], [75.32875061, 24.94563103], [75.32540894, 24.93809128], [75.31754303, 24.90722084], [75.31387329, 24.90044022], [75.31210327, 24.8999176], [75.31217194, 24.91106033], [75.30832672, 24.92629051], [75.30610657, 24.92897987], [75.30316162, 24.93061256], [75.30229187, 24.9348793], [75.30351257, 24.94017982], [75.30267334, 24.94316101], [75.30018616, 24.94682121], [75.29429626, 24.94870949], [75.29045868, 24.95202065], [75.28980255, 24.95611191], [75.28778076, 24.95963287], [75.28814697, 24.96263123], [75.28556061, 24.96412277], [75.28536224, 24.97669029], [75.27590179, 24.97673035], [75.271492, 24.96821976], [75.26844788, 24.9655304], [75.26631165, 24.96191978], [75.26999664, 24.95627022], [75.27165222, 24.94942093], [75.27722168, 24.94790077], [75.27580261, 24.94027138], [75.28488159, 24.93712044], [75.28790283, 24.9262619], [75.29116821, 24.92496109], [75.29308319, 24.92317963], [75.29190063, 24.92091751], [75.28793335, 24.92053032], [75.28482819, 24.92280006], [75.28237152, 24.92254066], [75.27867889, 24.91749191], [75.27796936, 24.91308022], [75.27485657, 24.91432953], [75.274086, 24.9170475], [75.27171326, 24.91786957], [75.26702881, 24.91421127], [75.26425171, 24.90731049], [75.26077271, 24.90534019], [75.25965881, 24.89982033], [75.26145172, 24.88965988], [75.26508331, 24.88817024], [75.27265167, 24.88693047], [75.27928162, 24.88455009], [75.28807831, 24.87968063], [75.29411316, 24.87137985], [75.29904938, 24.87026024], [75.31130219, 24.86945915], [75.31765747, 24.87515068], [75.32124329, 24.88266182], [75.32596588, 24.88700867], [75.33534241, 24.88667107], [75.35006714, 24.88496971], [75.37197113, 24.87798119], [75.3986969, 24.88834953], [75.40753937, 24.89191055], [75.41416931, 24.89300919], [75.42421722, 24.89275169], [75.42059326, 24.88163185], [75.42063141, 24.87733078], [75.4172821, 24.86861038], [75.417099, 24.86390114], [75.4105072, 24.86123848], [75.39965057, 24.8549099], [75.36396027, 24.84252167], [75.35505676, 24.83743095], [75.34407806, 24.83279037], [75.33744049, 24.83370972], [75.33023071, 24.83172989], [75.32361603, 24.82396126], [75.31981659, 24.81779289], [75.31301117, 24.81353951], [75.30573273, 24.8133297], [75.30049133, 24.81524277], [75.29841614, 24.81990814], [75.29769897, 24.82637024], [75.29421997, 24.83037949], [75.29042053, 24.84091949], [75.28382111, 24.85001945], [75.27893829, 24.85349083], [75.27121735, 24.85635948], [75.25979614, 24.85752106], [75.25234985, 24.85950851], [75.24769592, 24.85950851], [75.24169159, 24.86094093], [75.23406982, 24.8583107], [75.22953033, 24.857481], [75.22738647, 24.85914993], [75.23667145, 24.87088966], [75.24797058, 24.88088989], [75.24994659, 24.89569092], [75.24774933, 24.8999176], [75.24437714, 24.90204048], [75.24124146, 24.90263176], [75.23612976, 24.89929962], [75.23059845, 24.89442062], [75.22341919, 24.89002991], [75.21969604, 24.89220047], [75.22135162, 24.90279961], [75.21920013, 24.90648842], [75.21264648, 24.91007042], [75.20819092, 24.90999985], [75.20742798, 24.90464973], [75.20820618, 24.89775085], [75.20609283, 24.8916111], [75.20288086, 24.88809967], [75.20131683, 24.88420105], [75.20670319, 24.8791008], [75.21038055, 24.87142944], [75.21848297, 24.8594799], [75.22170258, 24.85819054], [75.22601318, 24.85485077], [75.22550201, 24.85103989], [75.22773743, 24.84775925], [75.23378754, 24.84662056], [75.24104309, 24.84686089], [75.24616241, 24.84416962], [75.24968719, 24.84081078], [75.25192261, 24.83716965], [75.25154877, 24.83221817], [75.2494812, 24.82639122], [75.24671173, 24.82184029], [75.24134064, 24.8194294], [75.23661041, 24.82024002], [75.22247314, 24.81896019], [75.21737671, 24.82046127], [75.2064209, 24.8099308], [75.2035675, 24.80168915], [75.20269775, 24.79628754], [75.20358276, 24.79247093], [75.20271301, 24.78880119], [75.19532776, 24.789711], [75.19229889, 24.78874969], [75.18950653, 24.77464104], [75.18768311, 24.77007294], [75.18551636, 24.76805115], [75.18559265, 24.76304054], [75.1868515, 24.76032066], [75.19561768, 24.76000977], [75.19818878, 24.75690079], [75.20191193, 24.74614143], [75.21694946, 24.7224102], [75.21936798, 24.72305107], [75.22141266, 24.73345947], [75.22406006, 24.73546028], [75.22840881, 24.7351017], [75.24246979, 24.73048019], [75.24954224, 24.72914124], [75.26200104, 24.73306084], [75.26724243, 24.73271942], [75.2858429, 24.72590065], [75.30436707, 24.72074127], [75.35086823, 24.71710014], [75.36389923, 24.70951843], [75.37814331, 24.7063694], [75.3964386, 24.70455933], [75.41970062, 24.69996071], [75.43753815, 24.69552994], [75.45189667, 24.69321823], [75.4834671, 24.69762039], [75.505867, 24.70942116], [75.52748108, 24.71791077], [75.53507996, 24.72001839], [75.54122162, 24.71669006], [75.54854584, 24.71556091], [75.55210114, 24.71376991], [75.56899261, 24.71990013], [75.58190155, 24.72270012], [75.6026001, 24.70127106], [75.60943604, 24.6899929], [75.61332703, 24.68842125], [75.63400269, 24.69115067], [75.65918732, 24.70170021], [75.68004608, 24.72783089], [75.71177673, 24.74542999], [75.72306824, 24.7501297], [75.73075867, 24.75555038], [75.74180603, 24.76036072], [75.7596817, 24.76479912], [75.77259827, 24.76204109], [75.78064728, 24.76316071], [75.78618622, 24.76552963], [75.80545807, 24.75626945], [75.82781219, 24.73635292], [75.83875275, 24.72986984], [75.84202576, 24.71746063], [75.83368683, 24.68595123], [75.83154297, 24.67974091], [75.82714081, 24.67150116], [75.82818604, 24.66822243], [75.83706665, 24.66999817], [75.84390259, 24.66934967], [75.84864807, 24.66455078], [75.84880829, 24.65306091], [75.84393311, 24.63927078], [75.84411621, 24.63472176], [75.84620667, 24.63140106], [75.84287262, 24.62611961], [75.83812714, 24.62360191], [75.83428955, 24.62375069], [75.83036041, 24.61995125], [75.82814789, 24.61334991], [75.83920288, 24.60874939], [75.83544159, 24.59756279], [75.83835602, 24.59568977], [75.84233093, 24.60024261], [75.84501648, 24.6103611], [75.84816742, 24.61116028], [75.85254669, 24.61432076], [75.86345673, 24.61292076], [75.86566162, 24.60733986], [75.87407684, 24.60711098], [75.8766861, 24.59964943], [75.87581635, 24.59078026], [75.88436127, 24.58173943], [75.89372253, 24.58167076], [75.89771271, 24.58045006], [75.90287018, 24.57681084], [75.91107178, 24.57705116], [75.91512299, 24.57459068], [75.91739655, 24.5714798], [75.91584778, 24.56736946], [75.91320801, 24.56529045], [75.90956116, 24.56450844], [75.90782166, 24.56536293], [75.90570831, 24.56059265], [75.90661621, 24.55220032], [75.90703583, 24.55046082], [75.91671753, 24.54668808], [75.92051697, 24.54380989], [75.92501831, 24.53829956], [75.9250412, 24.53339958], [75.92204285, 24.52728081], [75.90934753, 24.51488113], [75.90289307, 24.51972008], [75.90216064, 24.52202034], [75.89694977, 24.52226067], [75.89256287, 24.52153015], [75.89105225, 24.50958824], [75.9054718, 24.50530815], [75.90674591, 24.49804115], [75.91181946, 24.4924202], [75.9124527, 24.48558044], [75.90811157, 24.47813034], [75.9072876, 24.46951103], [75.90943909, 24.46363068], [75.90899658, 24.45614052], [75.90335083, 24.45393944], [75.90338898, 24.44613075], [75.89862061, 24.44159126], [75.88648987, 24.4369297], [75.87522888, 24.43028069], [75.86120605, 24.42333031], [75.84725189, 24.41897011], [75.82900238, 24.42251968], [75.8241272, 24.43078995], [75.81254578, 24.43678093], [75.80964661, 24.44123077], [75.81417084, 24.4480896], [75.81646729, 24.45852089], [75.81510925, 24.46511269], [75.80502319, 24.47277069], [75.79564667, 24.47312164], [75.79113007, 24.47520256], [75.78675842, 24.47183037], [75.78409576, 24.46473122], [75.78608704, 24.4584198], [75.78575134, 24.45508957], [75.78357697, 24.45182991], [75.78128052, 24.45391083], [75.77617645, 24.45388031], [75.77567291, 24.44826126], [75.76824188, 24.44034958], [75.75241852, 24.43157005], [75.74872589, 24.42840958], [75.75640869, 24.42766953], [75.75583649, 24.42105293], [75.75527954, 24.40930939], [75.74500275, 24.4070797], [75.7432785, 24.40501022], [75.73581696, 24.40343285], [75.72979736, 24.40360832], [75.728302, 24.40749168], [75.72688293, 24.40527916], [75.72968292, 24.38949966], [75.7353363, 24.39439964], [75.73857117, 24.39529991], [75.73957825, 24.38893127], [75.73829651, 24.36618996], [75.73869324, 24.36125755], [75.74178314, 24.36107254], [75.74180603, 24.35296822], [75.74051666, 24.34974289], [75.73792267, 24.34797096], [75.7562561, 24.32722282], [75.76509094, 24.31065941], [75.77085114, 24.30877113], [75.78103638, 24.30863953], [75.79001617, 24.3110981], [75.79741669, 24.31434822], [75.8030014, 24.31233025], [75.811203, 24.30344963], [75.81299591, 24.30067825], [75.81095123, 24.29804039], [75.81682587, 24.2907505], [75.81143188, 24.28472137], [75.81289673, 24.27709007], [75.81178284, 24.27042961], [75.81852722, 24.26822281], [75.81253052, 24.26065063], [75.81269073, 24.25688171], [75.81806183, 24.24995995], [75.82250977, 24.24733925], [75.82688141, 24.24641037], [75.82636261, 24.24257088], [75.82129669, 24.24102974], [75.81659698, 24.24194908], [75.81424713, 24.23959923], [75.81060791, 24.2419796], [75.80776215, 24.24067116], [75.805336, 24.22971916], [75.79953003, 24.22923088], [75.79534912, 24.22686958], [75.79189301, 24.22324181], [75.77883911, 24.2244091], [75.77350616, 24.22089195], [75.76782227, 24.20754814], [75.76967621, 24.19774055], [75.76862335, 24.19330025], [75.76365662, 24.18978119], [75.75891113, 24.17961121], [75.75827789, 24.17455292], [75.75331879, 24.16434097], [75.75065613, 24.1616497], [75.74349213, 24.13960075], [75.75942993, 24.14035034], [75.76213837, 24.14101028], [75.7651062, 24.13663101], [75.77316284, 24.13944244], [75.77629852, 24.13896179], [75.77868652, 24.13467026], [75.77902985, 24.12462044], [75.78317261, 24.12268066], [75.78478241, 24.11834908], [75.78961182, 24.10980034], [75.80239868, 24.11833], [75.80834961, 24.11335945], [75.81218719, 24.10287094], [75.8306427, 24.10792923], [75.83579254, 24.11135101], [75.83586121, 24.10400009], [75.83267212, 24.09574127], [75.83055115, 24.08159065], [75.83139038, 24.07712173], [75.83376312, 24.07542992], [75.82950592, 24.07195282], [75.82073975, 24.07060051], [75.81334686, 24.07162094], [75.80726624, 24.06760025], [75.78901672, 24.06329918], [75.77961731, 24.06208038], [75.77771759, 24.05714035], [75.78024292, 24.0362606], [75.77778625, 24.02751923], [75.77377319, 24.01910973], [75.77127075, 24.01221085], [75.76782227, 24.0116806], [75.76319885, 24.01396751], [75.76088715, 24.01291084], [75.76008606, 24.00843048], [75.76415253, 24.00530052], [75.76405334, 24.00458145], [75.76431274, 24.00242805], [75.76203918, 23.99795151], [75.75533295, 23.99492264], [75.74957275, 23.99509048], [75.74756622, 23.99347115], [75.73784637, 23.99533272], [75.73738098, 23.99406052], [75.73815155, 23.98816109], [75.73602295, 23.98475075], [75.73626709, 23.9823494], [75.73551178, 23.9805603], [75.73309326, 23.97892952], [75.72776794, 23.9795208], [75.72647858, 23.97877121], [75.72515869, 23.97451973], [75.72331238, 23.97313118], [75.71382141, 23.97208023], [75.70040894, 23.9690609], [75.69845581, 23.97007942], [75.69789886, 23.97208023], [75.69544983, 23.98590088], [75.6964798, 23.98751068], [75.69613647, 23.99039078], [75.6931076, 23.98921013], [75.69065094, 23.98948097], [75.68638611, 23.99054909], [75.68406677, 23.99311066], [75.68354034, 23.99821091], [75.68533325, 24.00234985], [75.68431091, 24.00463104], [75.68580627, 24.01794052], [75.68228912, 24.01695251], [75.67703247, 24.02011108], [75.67269135, 24.03089905], [75.66919708, 24.03354263], [75.65936279, 24.03149986], [75.65313721, 24.02757835], [75.64766693, 24.02320099], [75.64814758, 24.02073097], [75.64591217, 24.01746941], [75.64147186, 24.01836967], [75.63922119, 24.00463104], [75.63846588, 24.00283051], [75.63474274, 23.99983025], [75.6312027, 24.00031281], [75.63051605, 23.99966812], [75.62471771, 23.99882126], [75.61174774, 23.99876022], [75.60678864, 23.99625015], [75.60412598, 23.99628067], [75.59742737, 23.99864006], [75.59262848, 23.9948597], [75.59004974, 23.9963398], [75.58693695, 23.99563026], [75.58383942, 23.99192047], [75.58036804, 23.99430275], [75.57779694, 23.99962044], [75.57596588, 24.00062943], [75.57376862, 23.99847984], [75.56932068, 23.99937057], [75.568367, 24.00114059], [75.56881714, 24.00461006], [75.57171631, 24.01740074], [75.56693268, 24.0227108], [75.56111908, 24.02357864], [75.55264282, 24.0227108], [75.54264832, 24.02556038], [75.53192139, 24.03148079], [75.51438141, 24.04873276], [75.49176788, 24.00455093], [75.48919678, 24.00031281], [75.48597717, 23.99833107], [75.48058319, 23.99233055], [75.47055817, 23.98719978], [75.46720886, 23.9845295], [75.46476746, 23.98072815], [75.46237946, 23.9681015], [75.46170044, 23.95342064], [75.46058655, 23.94762039], [75.45722961, 23.93818092], [75.45636749, 23.93214989], [75.45593262, 23.92543983], [75.45649719, 23.92074013], [75.46089935, 23.91728973], [75.47683716, 23.91473961], [75.48742676, 23.9108429], [75.49957275, 23.90052032], [75.49993134, 23.89690971], [75.50409698, 23.89191055], [75.50734711, 23.89062119], [75.51674652, 23.88875008], [75.52876282, 23.88026047], [75.53787994, 23.87672997], [75.55252838, 23.86515808], [75.55715942, 23.86279106], [75.56062317, 23.85995102], [75.56246185, 23.85814285], [75.56536865, 23.84986115], [75.56720734, 23.84762955], [75.57306671, 23.84647942], [75.57640076, 23.84329033], [75.5761795, 23.84151077], [75.57485962, 23.83801079], [75.57229614, 23.83483124], [75.56931305, 23.8346405], [75.56150818, 23.83698082], [75.56008148, 23.83685112], [75.556633, 23.83160973], [75.55606079, 23.82593155], [75.5585022, 23.82015991], [75.56253052, 23.81693077], [75.56603241, 23.81568909], [75.57279205, 23.81685066], [75.58331299, 23.81520844], [75.5844574, 23.81402016], [75.5848999, 23.80881119], [75.58294678, 23.80380058], [75.58252716, 23.80035973], [75.59168243, 23.80239105], [75.60608673, 23.80364037], [75.60797882, 23.80550003], [75.61213684, 23.80661964], [75.61662292, 23.80597115], [75.6239624, 23.80051994], [75.62594604, 23.80026054], [75.63703918, 23.80236053], [75.64108276, 23.80225945], [75.64367676, 23.80183029], [75.64930725, 23.79935074], [75.65183258, 23.80194855], [75.65680695, 23.7917881], [75.65908813, 23.78894043], [75.6626358, 23.78816032], [75.66747284, 23.78819847], [75.6712265, 23.78680038], [75.67440796, 23.7844677], [75.67605591, 23.78212929], [75.67906952, 23.76954842], [75.68447876, 23.76056862], [75.68515015, 23.76664925], [75.68734741, 23.77333069], [75.69007874, 23.7759819], [75.69671631, 23.78528976], [75.69828796, 23.78800011], [75.69866943, 23.7918396], [75.69451904, 23.79754257], [75.69403839, 23.80455017], [75.68826294, 23.81408119], [75.68692017, 23.8176899], [75.68740082, 23.81925011], [75.69024658, 23.8196106], [75.70259094, 23.81713104], [75.70878601, 23.81809807], [75.71321869, 23.8164711], [75.71569061, 23.81705093], [75.71784973, 23.81903267], [75.71588135, 23.82102013], [75.7167511, 23.82212067], [75.72083282, 23.82364082], [75.72216797, 23.82691193], [75.71872711, 23.83236122], [75.71794891, 23.84004021], [75.71572113, 23.84559059], [75.71787262, 23.84698105], [75.72067261, 23.84678078], [75.72396088, 23.84801102], [75.72637177, 23.8534317], [75.72815704, 23.85505104], [75.72911072, 23.85820961], [75.72754669, 23.86450958], [75.71753693, 23.8647728], [75.70656586, 23.86818123], [75.70474243, 23.87475967], [75.70355225, 23.87543106], [75.70131683, 23.87495995], [75.69812775, 23.87710762], [75.69773865, 23.88772011], [75.69863892, 23.89122963], [75.70094299, 23.89491081], [75.7008667, 23.90127945], [75.70233154, 23.90405083], [75.70707703, 23.90288925], [75.71057892, 23.90040016], [75.71299744, 23.89995956], [75.71549225, 23.90151978], [75.72281647, 23.90061951], [75.72821808, 23.90209961], [75.73132324, 23.9015007], [75.73420715, 23.89952278], [75.73647308, 23.89409065], [75.7400589, 23.89422035], [75.74974823, 23.89002037], [75.75712585, 23.88418961], [75.75917053, 23.88132858], [75.75994873, 23.86199188], [75.7616272, 23.85688972], [75.7696228, 23.85444069], [75.77706146, 23.85387039], [75.77992249, 23.85470009], [75.78385162, 23.85773087], [75.78505707, 23.85980988], [75.78514862, 23.8653698], [75.79102325, 23.87215042], [75.79421997, 23.87430954], [75.80265808, 23.87111092], [75.81394196, 23.87426949], [75.81785583, 23.8793602], [75.83040619, 23.8847599], [75.83703613, 23.88132858], [75.83973694, 23.88256073], [75.84142303, 23.88843918], [75.85341644, 23.89420128], [75.85661316, 23.89400101], [75.86065674, 23.89558983], [75.86351776, 23.895401], [75.86709595, 23.89398956], [75.87236786, 23.88818169], [75.87861633, 23.88455963], [75.88633728, 23.8885994], [75.88878632, 23.89171982], [75.89393616, 23.89308167], [75.89655304, 23.8927002], [75.90126038, 23.89501953], [75.9054718, 23.89606285], [75.9212265, 23.90417099], [75.92695618, 23.9018898], [75.93180847, 23.90193939], [75.93808746, 23.91220856], [75.94433594, 23.91620827], [75.94658661, 23.92071152], [75.94822693, 23.92226028], [75.96652222, 23.92987061], [75.97409058, 23.93153], [75.97582245, 23.93293953], [75.9759903, 23.93898964], [75.98092651, 23.94301987], [75.97981262, 23.95215988], [75.98123169, 23.96241951], [75.98018646, 23.96875954], [75.98018646, 23.97438049], [75.97823334, 23.98007011], [75.97675323, 23.98195076], [75.96353149, 23.99165916], [75.96131897, 23.99484062], [75.96024323, 23.99746132], [75.96092987, 24.00427055], [75.95910645, 24.00997162], [75.96018219, 24.02536964], [75.97336578, 24.03144073], [75.97962189, 24.03209114], [75.97975159, 24.03104973], [75.99008942, 24.03006935], [75.99450684, 24.03190041], [76.00028229, 24.0354805], [76.00213623, 24.03523064], [76.00894165, 24.04030037], [76.01793671, 24.04455948], [76.02672577, 24.05046272], [76.03299713, 24.0642128], [76.0399704, 24.06690979], [76.04335022, 24.07396126], [76.04695892, 24.07567024], [76.05748749, 24.07785034], [76.06372833, 24.07790947], [76.08024597, 24.0839901], [76.08454132, 24.08214951], [76.09082794, 24.08574104], [76.09899902, 24.08918953], [76.10515594, 24.09590912], [76.1085968, 24.09712982], [76.11244965, 24.09650993], [76.12327576, 24.09233284], [76.13469696, 24.09528923], [76.13469696, 24.09972954], [76.13128662, 24.10662079], [76.13005066, 24.11214066], [76.12922668, 24.11893272], [76.1307373, 24.12290955], [76.1368866, 24.13133812], [76.13442993, 24.13933945], [76.13173676, 24.14394188], [76.13047028, 24.15366936], [76.13088989, 24.16905022], [76.12889099, 24.17485809], [76.1254425, 24.17814064], [76.12059784, 24.17823982], [76.11995697, 24.18013954], [76.12085724, 24.18359947], [76.12132263, 24.19639015], [76.12335968, 24.20540047], [76.13156891, 24.21244812], [76.14180756, 24.22384071], [76.14704895, 24.22776985], [76.15236664, 24.23545837], [76.15445709, 24.24376106], [76.14977264, 24.26098061], [76.14836121, 24.26403046], [76.1455307, 24.26576042], [76.14222717, 24.28115082], [76.143013, 24.28528976], [76.14666748, 24.29031944], [76.14952087, 24.29223061], [76.1627121, 24.29336166], [76.1692276, 24.29609108], [76.17002106, 24.30340958], [76.1725769, 24.30722046], [76.1713562, 24.31032944], [76.17212677, 24.31558037], [76.18112946, 24.3248806], [76.18548584, 24.33151054], [76.19004822, 24.32995033], [76.19402313, 24.32086945], [76.20252228, 24.31315994], [76.20623016, 24.31092072], [76.20498657, 24.30570984], [76.19908905, 24.29730034], [76.19560242, 24.29009819], [76.19465637, 24.28479958], [76.20218658, 24.27675056], [76.20437622, 24.26902008], [76.20363617, 24.25058937], [76.205513, 24.2418499], [76.20622253, 24.23274994], [76.21057129, 24.22284126], [76.21556854, 24.21680832], [76.21821594, 24.21738052], [76.22335052, 24.22327042], [76.23612213, 24.22388077], [76.24046326, 24.22618103], [76.24767303, 24.22792053], [76.25180817, 24.22481918], [76.26538086, 24.22154999], [76.27639771, 24.21651077], [76.28277588, 24.21571159], [76.28716278, 24.21825027], [76.28884125, 24.22557068], [76.28964996, 24.23703003], [76.29392242, 24.24067116], [76.3028717, 24.24443054], [76.31012726, 24.24638939], [76.31787872, 24.25113106], [76.32689667, 24.25361824], [76.33499146, 24.25396919], [76.34417725, 24.25189972], [76.35299683, 24.2489109], [76.35829926, 24.24607086], [76.36120605, 24.24448967], [76.3651886, 24.24131012], [76.3735199, 24.23769951], [76.39124298, 24.22561073], [76.40009308, 24.22278976], [76.41179657, 24.20955086], [76.41443634, 24.20742035], [76.41873169, 24.20833969], [76.42253113, 24.21422005], [76.42172241, 24.2206707], [76.4181366, 24.22435951], [76.42360687, 24.22694969], [76.42945099, 24.22706032], [76.43601227, 24.22500038], [76.44184113, 24.2218895], [76.44742584, 24.21774101], [76.45324707, 24.21682167], [76.45862579, 24.22085953], [76.46102142, 24.22541046], [76.46343231, 24.22891998], [76.46994781, 24.23139954], [76.47457123, 24.22870255], [76.47941589, 24.21751022], [76.48442078, 24.21504021], [76.49693298, 24.21203995], [76.50180054, 24.20903015], [76.50538635, 24.20546913], [76.50836945, 24.20023155], [76.51048279, 24.17902946], [76.51333618, 24.1728611], [76.51737976, 24.16657829], [76.52319336, 24.1631794], [76.53143311, 24.16346931], [76.53578186, 24.16421127], [76.53985596, 24.16674995], [76.5459671, 24.16801071], [76.55475616, 24.16822052], [76.5625, 24.1724205], [76.56632996, 24.17645073], [76.57266998, 24.1772995], [76.57972717, 24.18067932], [76.57698822, 24.19131088], [76.56980896, 24.19628906], [76.5669632, 24.19715118], [76.56577301, 24.20079994], [76.567276, 24.20691109], [76.57148743, 24.21347809], [76.58586121, 24.21956062], [76.59255981, 24.22387123], [76.59738922, 24.22991943], [76.5966568, 24.2352829], [76.58747864, 24.24604988], [76.58802032, 24.2495594], [76.59324646, 24.25089073], [76.60047913, 24.24497986], [76.610466, 24.24148941], [76.61395264, 24.24217987], [76.61634827, 24.26284027], [76.62336731, 24.26460838], [76.63008118, 24.26470947], [76.63482666, 24.26405907], [76.64006042, 24.26231956], [76.64222717, 24.26624107], [76.64245605, 24.27011108], [76.64724731, 24.27240944], [76.65821075, 24.26781273], [76.66829681, 24.26738167], [76.67082977, 24.27100945], [76.67874908, 24.27063942], [76.68476868, 24.28269005], [76.69296265, 24.28504944], [76.69491577, 24.28231049], [76.69330597, 24.27404976], [76.69480896, 24.26781273], [76.69664764, 24.26119995], [76.69967651, 24.2578392], [76.70137024, 24.2543602], [76.70249939, 24.24880028], [76.69876099, 24.245121], [76.69523621, 24.24207115], [76.68778229, 24.23245049], [76.68488312, 24.22483253], [76.6767807, 24.21054077], [76.67420959, 24.19342995], [76.68438721, 24.18864059], [76.6893692, 24.18370819], [76.69519043, 24.1760006], [76.70114136, 24.17144012], [76.71247864, 24.16662979], [76.71470642, 24.16418266], [76.72071075, 24.16172028], [76.72683716, 24.16508293], [76.72939301, 24.17056084], [76.73589325, 24.17184258], [76.74938202, 24.17254066], [76.75499725, 24.17209053], [76.75733948, 24.16970253], [76.7594986, 24.16586113], [76.76261902, 24.16421127], [76.76885986, 24.16468048], [76.77308655, 24.15877914], [76.77562714, 24.15307999], [76.7909317, 24.12575912], [76.79721832, 24.12181091], [76.80111694, 24.12034035], [76.81466675, 24.12651062], [76.82183075, 24.12667274], [76.82772827, 24.12559128], [76.83547211, 24.13125038], [76.84233093, 24.13227081], [76.84607697, 24.13614082], [76.85600281, 24.13894081], [76.86628723, 24.13883018], [76.87332916, 24.13978958], [76.87657166, 24.13837814], [76.87758636, 24.13492966], [76.88625336, 24.1317482], [76.89994049, 24.13111115], [76.90579987, 24.15319252], [76.91118622, 24.17690086], [76.91487122, 24.18337059], [76.9161377, 24.1887207], [76.92723846, 24.18666077], [76.9331665, 24.18687057], [76.94386292, 24.19885063], [76.94483185, 24.20330048], [76.94444275, 24.2062912], [76.94254303, 24.20835114], [76.9368515, 24.20979118], [76.93165588, 24.20953941], [76.9282608, 24.21354103], [76.9225769, 24.21679115], [76.91928864, 24.22068977], [76.91855621, 24.22640038], [76.9164505, 24.23196983], [76.91117096, 24.23761177], [76.90389252, 24.24167824], [76.89736176, 24.24708939], [76.87419891, 24.27108955], [76.86994171, 24.27658272], [76.86705017, 24.28085136], [76.86360931, 24.28976059], [76.86380005, 24.29381943], [76.86264038, 24.29883194], [76.85980225, 24.30529022], [76.85878754, 24.31231117], [76.84490967, 24.32798195], [76.84017944, 24.33872032], [76.83888245, 24.34262276], [76.83821106, 24.35495949], [76.83696747, 24.36070824], [76.83883667, 24.36470032], [76.84906006, 24.36820984], [76.85167694, 24.37024117], [76.85231781, 24.37486839], [76.84799957, 24.37883186], [76.8501358, 24.38896942], [76.8483429, 24.39627075], [76.8423996, 24.4085083], [76.83587646, 24.41657066], [76.83769226, 24.41808128], [76.84226227, 24.4181881], [76.84603119, 24.41934013], [76.84926605, 24.42525291], [76.85109711, 24.43539047], [76.85066223, 24.43736076], [76.84117126, 24.4428196], [76.837883, 24.45058823], [76.83862305, 24.45416069], [76.84591675, 24.4532795], [76.84844971, 24.45876122], [76.84897614, 24.46438026], [76.85132599, 24.46910858], [76.85057831, 24.47394943], [76.84629822, 24.47545815], [76.8467865, 24.48755074], [76.84527588, 24.49090004], [76.8423233, 24.49374008], [76.83532715, 24.49438095], [76.83454895, 24.49830055], [76.82810974, 24.51036263], [76.8192215, 24.52462006], [76.81442261, 24.52964973], [76.81416321, 24.53227997], [76.81459045, 24.53437042], [76.81902313, 24.53656006], [76.82675171, 24.53878021], [76.83114624, 24.54319], [76.8381958, 24.54846954], [76.84604645, 24.55101967], [76.85282135, 24.55101967], [76.86620331, 24.54936028], [76.87195587, 24.54589081], [76.87413025, 24.54305077], [76.87475586, 24.54045105], [76.87290192, 24.53203964], [76.87573242, 24.52618027], [76.87954712, 24.52531052], [76.88896942, 24.5267601], [76.89359283, 24.53545952], [76.8928833, 24.53969002], [76.89776611, 24.54370117], [76.89982605, 24.5478096], [76.90238953, 24.54752159], [76.91287231, 24.54356956], [76.91568756, 24.54038048], [76.91838074, 24.53560066], [76.91877747, 24.52998161], [76.91890717, 24.52439117], [76.91734314, 24.51696968], [76.91526031, 24.51140022], [76.91464996, 24.48765945], [76.92288208, 24.48065186], [76.93083954, 24.47669983], [76.93708801, 24.47239113], [76.94108582, 24.46735001], [76.95287323, 24.46393013], [76.96016693, 24.46022987], [76.96531677, 24.46086121], [76.9749527, 24.46492958], [76.97753906, 24.47198105], [76.97966003, 24.47462845], [76.99252319, 24.47344971], [76.99819946, 24.47548294], [77.00152588, 24.47789955], [77.00255585, 24.48349953], [77.00688934, 24.48755074], [77.00496674, 24.48938942], [77.00473022, 24.49196053], [77.0059967, 24.49394989], [77.00866699, 24.4949398], [77.01233673, 24.49436951], [77.01589203, 24.49489975], [77.0206604, 24.49793053], [77.02407074, 24.50132942], [77.02478027, 24.51704979], [77.02670288, 24.5214119], [77.02910614, 24.52376175], [77.02997589, 24.52705956], [77.0319519, 24.52879906], [77.03904724, 24.5266304], [77.05030823, 24.52653122], [77.05092621, 24.53714752], [77.05195618, 24.54125023], [77.05338287, 24.54417038], [77.06153107, 24.55477905], [77.06433868, 24.56412125], [77.06469727, 24.56991005], [77.06355286, 24.5853405], [77.05845642, 24.59481049], [77.05832672, 24.6011982], [77.06034851, 24.60609055], [77.06111908, 24.61050987], [77.06112671, 24.62458992], [77.06028748, 24.63770294], [77.05945587, 24.64241982], [77.05414581, 24.65410805], [77.04894257, 24.6613102], [77.03701019, 24.6827507], [77.03491974, 24.68856049], [77.03450012, 24.69846916], [77.03346252, 24.70294952], [77.0266571, 24.71092033], [77.02265167, 24.71372032], [77.01924896, 24.71495056], [77.01407623, 24.71541977], [77.00422668, 24.71366119], [76.99214172, 24.71739769], [76.98230743, 24.72487259], [76.97197723, 24.73167038], [76.96848297, 24.73608971], [76.96533203, 24.74410057], [76.96383667, 24.75045967], [76.96330261, 24.75955009], [76.95632172, 24.76431084], [76.95173645, 24.76546097], [76.94577789, 24.76404953], [76.92169189, 24.7488308], [76.90939331, 24.74681091], [76.90325928, 24.74604988], [76.8983078, 24.74777031], [76.89692688, 24.75060081], [76.88668823, 24.75415039], [76.86812592, 24.74958038], [76.86084747, 24.74869919], [76.84729767, 24.75040054], [76.84501648, 24.75213814], [76.84702301, 24.76505089], [76.84674072, 24.76999283], [76.83587646, 24.78507042], [76.82579041, 24.79338074], [76.8157196, 24.80367088], [76.80869293, 24.81497955], [76.80410767, 24.8166008], [76.80158234, 24.81983948], [76.80066681, 24.82456017], [76.80229187, 24.82657051], [76.81118774, 24.82823944], [76.81672668, 24.83249855], [76.82308197, 24.83485031], [76.82714081, 24.83835983], [76.83164978, 24.84024239], [76.83750153, 24.84106064], [76.84217834, 24.84011269], [76.85131073, 24.84023094], [76.85748291, 24.84098053], [76.86332703, 24.84169006], [76.8780899, 24.83955193], [76.89504242, 24.83950996], [76.90843201, 24.84509277], [76.91153717, 24.84760094], [76.91506195, 24.84869957], [76.9265213, 24.84978294], [76.9332428, 24.85394096], [76.94312286, 24.86005974], [76.94425964, 24.86547279], [76.94664001, 24.86825943], [76.9489212, 24.87286949], [76.94671631, 24.87419128], [76.9432373, 24.8745594], [76.94185638, 24.87470818], [76.93572998, 24.87868118], [76.93398285, 24.88428116], [76.92176819, 24.8837204], [76.91751862, 24.88479042], [76.91385651, 24.88788033], [76.91216278, 24.89313126], [76.91269684, 24.89724159], [76.91575623, 24.90118027], [76.92032623, 24.90488052], [76.92463684, 24.91037178], [76.92353058, 24.91426086], [76.92086792, 24.91678047], [76.9074173, 24.92325974], [76.89122772, 24.91967964], [76.89015961, 24.92305946], [76.89247131, 24.9290905], [76.89322662, 24.93542099], [76.87970734, 24.94576073], [76.87520599, 24.9509697], [76.87206268, 24.95460129], [76.87336731, 24.95757294], [76.87156677, 24.96130943], [76.86727905, 24.96544075], [76.86643982, 24.97179031], [76.86965942, 24.99189186], [76.86871338, 24.99751091], [76.86805725, 25.00136948], [76.85952759, 25.00691032], [76.85434723, 25.01031113], [76.86055756, 25.01038933], [76.8693161, 25.01110268], [76.87448883, 25.01311111], [76.87680817, 25.01606178], [76.87676239, 25.01801109], [76.87671661, 25.01993942], [76.87828064, 25.02583122], [76.88202667, 25.03409958], [76.90106201, 25.03404045], [76.90976715, 25.03567123], [76.91767883, 25.04003143], [76.92987823, 25.0415802], [76.95349884, 25.0484581], [76.96131134, 25.05398941], [76.96866608, 25.05594063], [76.97126007, 25.06058121], [76.97183228, 25.06683922], [76.97466278, 25.07067108], [76.9836731, 25.07756042], [76.99372864, 25.07995033], [77.00029755, 25.07973099], [77.00595093, 25.07856941], [77.01235199, 25.07491112], [77.01764679, 25.07217026], [77.02039337, 25.07143974], [77.02472687, 25.07180023], [77.02934265, 25.07189941], [77.03929901, 25.06810951], [77.04432678, 25.0657711], [77.0549469, 25.06326294], [77.0613327, 25.06139183], [77.06801605, 25.05969048], [77.07723236, 25.05798912], [77.08426666, 25.06264114], [77.09041595, 25.06636047], [77.10249329, 25.06924057], [77.11445618, 25.06908989], [77.12827301, 25.08905029], [77.14016724, 25.09620094], [77.14045715, 25.09090042], [77.15770721, 25.08827972], [77.1645813, 25.09856987], [77.1628418, 25.10972023], [77.16957855, 25.11371994], [77.18305969, 25.11180115], [77.18876648, 25.11180115], [77.1973877, 25.11667061], [77.20581055, 25.11242104], [77.22083282, 25.11024284], [77.24164581, 25.11272049], [77.26226044, 25.11926079], [77.2755661, 25.11213112], [77.28443146, 25.10421944], [77.29133606, 25.09411049], [77.29593658, 25.08710289], [77.30285645, 25.08386993], [77.30700684, 25.08575058], [77.3098526, 25.08639145], [77.31389618, 25.08756065], [77.32038116, 25.09070969], [77.32801819, 25.09340096], [77.33244324, 25.09657097], [77.34867859, 25.09779167], [77.35714722, 25.10155106], [77.36078644, 25.10434914], [77.36850739, 25.10849953], [77.36839294, 25.11413002], [77.37516022, 25.11681938], [77.38667297, 25.12195969], [77.39227295, 25.11741066], [77.39318848, 25.11528015], [77.39554596, 25.11199951], [77.39852905, 25.11327171], [77.39810944, 25.11641121], [77.39388275, 25.12330055], [77.38861084, 25.12725067], [77.38694, 25.13296127], [77.38739014, 25.13809013], [77.38931274, 25.15103912], [77.38918304, 25.15994072], [77.38961029, 25.16838837], [77.39129639, 25.17469978], [77.3913269, 25.17964935], [77.39070892, 25.18819046], [77.40306091, 25.1865406], [77.4076767, 25.19005966], [77.41475677, 25.18943024], [77.41799164, 25.1930294], [77.41372681, 25.19952965], [77.41133881, 25.20659065], [77.40952301, 25.21243095], [77.40640259, 25.22629166], [77.40081787, 25.22770119], [77.39164734, 25.23114967], [77.38004303, 25.24542046], [77.3755722, 25.24902153], [77.37046814, 25.2509594], [77.36271667, 25.25007057], [77.36203766, 25.25593185], [77.3602829, 25.26085281], [77.35668182, 25.26579094], [77.34966278, 25.27177048], [77.36000061, 25.28022003], [77.36302948, 25.28375816], [77.36672211, 25.28540039], [77.36946869, 25.28852844], [77.37258911, 25.29429054], [77.37336731, 25.29936981], [77.37377167, 25.30018044], [77.37480164, 25.30585098], [77.37462616, 25.31057167], [77.37364197, 25.31549263], [77.37178802, 25.32022095], [77.36894989, 25.32464981], [77.36580658, 25.32850075], [77.3637619, 25.33300018], [77.35317993, 25.33234978], [77.34934235, 25.32413292], [77.33641815, 25.3255806], [77.34391785, 25.33736038], [77.35511017, 25.36437988], [77.35604095, 25.3678894], [77.3538208, 25.36954117], [77.3516922, 25.37235069], [77.34841919, 25.37555122], [77.34474945, 25.3798027], [77.34467316, 25.38334084], [77.34426117, 25.38792992], [77.34610748, 25.39249992], [77.3497467, 25.39838028], [77.35395813, 25.4036293], [77.35764313, 25.40928841], [77.36134338, 25.41296005], [77.35434723, 25.42402267], [77.34371185, 25.42243195], [77.33706665, 25.42475128], [77.32923126, 25.4285717], [77.31690979, 25.43284035], [77.30529785, 25.4364109], [77.29556274, 25.43169022], [77.28298187, 25.42358971], [77.27295685, 25.41200256], [77.25995636, 25.39945984], [77.24964142, 25.39491081], [77.24415588, 25.38961029], [77.23467255, 25.38506126], [77.22564697, 25.37924957], [77.22026062, 25.37342834], [77.22113037, 25.36108017], [77.21701813, 25.34925079], [77.2173996, 25.33724976], [77.21803284, 25.33131027], [77.21502686, 25.32450104], [77.21039581, 25.32447052], [77.20942688, 25.32864952], [77.2131958, 25.33175087], [77.21070099, 25.33369064], [77.20526123, 25.33304977], [77.19815826, 25.33052063], [77.19860077, 25.32464981], [77.2003479, 25.3187294], [77.20514679, 25.31142998], [77.1973877, 25.31097984], [77.19055176, 25.31166077], [77.18210602, 25.31331062], [77.17340851, 25.31517029], [77.16776276, 25.31552124], [77.16159058, 25.31365013], [77.15355682, 25.31324959], [77.14900208, 25.31536293], [77.13630676, 25.32413292], [77.12890625, 25.32541847], [77.12142181, 25.33125114], [77.11576843, 25.33506012], [77.10811615, 25.33527946], [77.10176849, 25.33512115], [77.09262848, 25.33727074], [77.08306122, 25.33980179], [77.07546997, 25.33969116], [77.07142639, 25.33584023], [77.06785583, 25.32966995], [77.0634613, 25.32415009], [77.05825806, 25.32191277], [77.0530014, 25.32069016], [77.04817963, 25.3210907], [77.04479218, 25.32245064], [77.03936005, 25.32505035], [77.03804779, 25.31936073], [77.03412628, 25.3118782], [77.02419281, 25.30109024], [77.01760101, 25.30155945], [77.01010132, 25.30154037], [77.00337219, 25.30183029], [76.99266815, 25.30183029], [76.95874023, 25.29718018], [76.9566803, 25.29142761], [76.95526886, 25.2845993], [76.95272064, 25.2785511], [76.94838715, 25.27652168], [76.94182587, 25.27536011], [76.93393707, 25.27590179], [76.92870331, 25.27915192], [76.93260956, 25.28746986], [76.92920685, 25.29729843], [76.92295837, 25.30137825], [76.91535187, 25.30898094], [76.90463257, 25.31785965], [76.89322662, 25.32240105], [76.88156891, 25.32286072], [76.87258911, 25.32427979], [76.86699677, 25.32516289], [76.85373688, 25.32971191], [76.84297943, 25.33054161], [76.83976746, 25.32928848], [76.83348083, 25.32685089], [76.82614899, 25.32698059], [76.82174683, 25.3270607], [76.79527283, 25.32182121], [76.77282715, 25.31591034], [76.77009583, 25.31219101], [76.75984192, 25.32267952], [76.76225281, 25.32798958], [76.76584625, 25.33204079], [76.76669312, 25.33296967], [76.76673126, 25.33623123], [76.7587204, 25.33869171], [76.75372314, 25.33934021], [76.74040222, 25.34778976], [76.73204803, 25.34787941], [76.72229767, 25.34592056], [76.7145462, 25.34243965], [76.70321655, 25.34761047], [76.68107605, 25.34547997], [76.6727829, 25.35003281], [76.66483307, 25.35750961], [76.65750122, 25.36144066], [76.64360046, 25.37639809], [76.6362915, 25.38033104], [76.62549591, 25.37511063], [76.62262726, 25.37675095], [76.61915588, 25.37873077], [76.61686707, 25.38161278], [76.61487579, 25.3841095], [76.60957336, 25.38830948], [76.60585022, 25.38866997], [76.60254669, 25.38898087], [76.59905243, 25.40530014], [76.58896637, 25.43148994], [76.58297729, 25.43569183], [76.5742569, 25.4366703], [76.56427765, 25.44240189], [76.56066895, 25.44985008], [76.5595932, 25.47326088], [76.55632019, 25.47981071], [76.55066681, 25.48430824], [76.54669189, 25.48968124], [76.54210663, 25.4974308], [76.54016876, 25.50573921], [76.53787231, 25.51020813], [76.53456879, 25.51350021], [76.52854919, 25.51770973], [76.52259827, 25.52429008], [76.52030945, 25.52993011], [76.52246094, 25.54146957], [76.52220917, 25.55035973], [76.52027893, 25.55690002], [76.51634216, 25.56553078], [76.51239777, 25.5717926], [76.50978088, 25.57982063], [76.50985718, 25.5872097], [76.51579285, 25.60700989], [76.51473236, 25.63367844], [76.51077271, 25.63816833], [76.50538635, 25.63821983], [76.50076294, 25.64330292], [76.4994278, 25.64834023], [76.51080322, 25.67283821], [76.50779724, 25.67612076], [76.48906708, 25.68340111], [76.48175812, 25.68939972], [76.4777832, 25.69506073], [76.4779129, 25.70603943], [76.48239136, 25.71813011], [76.50299835, 25.72860909], [76.51075745, 25.73001289], [76.52655029, 25.73104286], [76.53061676, 25.73397064], [76.53040314, 25.74374008], [76.52223969, 25.76634026], [76.5226593, 25.77434158], [76.52931213, 25.79797173], [76.53549194, 25.80917168], [76.54164886, 25.81740189], [76.54946136, 25.82504082], [76.56678009, 25.83967018], [76.58528137, 25.86771965], [76.59272766, 25.8741684], [76.59747314, 25.8764801], [76.61653137, 25.87125015], [76.62660217, 25.87087059], [76.63168335, 25.87524033], [76.6355896, 25.89592934], [76.63833618, 25.90151978], [76.64141846, 25.90625], [76.64612579, 25.90885162], [76.65656281, 25.91081047], [76.67436218, 25.91180038], [76.68405914, 25.91020966], [76.69645691, 25.90711021], [76.70548248, 25.9034729], [76.71452332, 25.90098953], [76.72220612, 25.90031052], [76.73332977, 25.90254974], [76.74546814, 25.90923119], [76.75563049, 25.91623116], [76.76241302, 25.92206955], [76.76278687, 25.92531013], [76.75676727, 25.92835045], [76.75344849, 25.93223953], [76.75283051, 25.93581009], [76.75356293, 25.93963051], [76.75591278, 25.94169044], [76.76065063, 25.94252968], [76.7767868, 25.93938065], [76.78591156, 25.94046974], [76.7947998, 25.9442215], [76.80631256, 25.95297813], [76.81624603, 25.96713066], [76.8188858, 25.97125053], [76.81804657, 25.98427963], [76.81984711, 25.98867989], [76.82328033, 25.99272156], [76.82962799, 25.99592972], [76.83705139, 26.00204086], [76.84024048, 26.0112896], [76.83040619, 26.02959061], [76.83809662, 26.0363903], [76.84572601, 26.04027939], [76.85176849, 26.04351044], [76.85774231, 26.0485611], [76.86392975, 26.05167961], [76.87042236, 26.05644989], [76.87255859, 26.06414986], [76.87696838, 26.07205009], [76.88223267, 26.07860947], [76.88288116, 26.0864296], [76.88777924, 26.09332275], [76.89531708, 26.09802055], [76.90631866, 26.10110092], [76.91834259, 26.10264969], [76.92897034, 26.10268021], [76.93871307, 26.1060791], [76.9418869, 26.10811043], [76.95352173, 26.11531067], [76.96856689, 26.1240406], [76.98603821, 26.13235283], [76.99447632, 26.13778114], [76.99646759, 26.14772034], [76.99968719, 26.15262985], [77.00480652, 26.15924072], [77.00773621, 26.16057968], [77.01123047, 26.16530037], [77.02388, 26.17617035], [77.03473663, 26.18193054], [77.04499054, 26.18494987], [77.05264282, 26.18617058], [77.05893707, 26.18535042], [77.06893921, 26.18540955], [77.0846405, 26.18717003], [77.09168243, 26.19087982], [77.09644318, 26.19544029], [77.09822083, 26.20225906], [77.10508728, 26.2091198], [77.10587311, 26.21936035], [77.10938263, 26.22507286], [77.11364746, 26.23135948], [77.12403107, 26.23795128], [77.12954712, 26.23965073], [77.1432724, 26.2382412], [77.15276337, 26.23795128], [77.15804291, 26.23852921], [77.16130066, 26.24222946], [77.16493988, 26.24450111], [77.17022705, 26.24451065], [77.17753601, 26.2390995], [77.18453217, 26.23682022], [77.19447327, 26.23597145], [77.20310974, 26.23740005], [77.20838928, 26.24423981], [77.23784637, 26.26272011], [77.25144958, 26.26703072], [77.26703644, 26.27617073], [77.28994751, 26.29559135], [77.3081665, 26.31500053], [77.30847931, 26.32155991], [77.31179047, 26.33382988], [77.31804657, 26.34638023], [77.32405853, 26.34810257], [77.32704163, 26.34724045], [77.32937622, 26.34810257], [77.33467102, 26.35723114], [77.3466568, 26.36038017], [77.36025238, 26.36952019], [77.36624908, 26.37151909], [77.37889862, 26.3638382], [77.38288879, 26.36240959], [77.38585663, 26.36242294], [77.39451599, 26.36670113], [77.40184021, 26.3686924], [77.40782166, 26.36898041], [77.41546631, 26.36811829], [77.43242645, 26.36499977], [77.43676758, 26.36814117], [77.43942261, 26.37298965], [77.43972778, 26.37869072], [77.43373871, 26.38753128], [77.42640686, 26.39550972], [77.42542267, 26.40205956], [77.42771912, 26.40690994], [77.43405151, 26.40920067], [77.45899963, 26.41119957], [77.47496796, 26.41463089], [77.493927, 26.41357994], [77.50591278, 26.41291046], [77.52288055, 26.41491127], [77.52986908, 26.41804123], [77.53717804, 26.4234581], [77.54250336, 26.42945099], [77.54715729, 26.4362812], [77.55148315, 26.44055939], [77.55914307, 26.44083977], [77.56912994, 26.44310951], [77.57910156, 26.45108986], [77.59908295, 26.45422173], [77.60874176, 26.45934105], [77.61538696, 26.46646118], [77.61673737, 26.47187042], [77.62007141, 26.47700119], [77.62671661, 26.48299026], [77.63938141, 26.48924065], [77.64636993, 26.49379921], [77.65470123, 26.49722099], [77.66768646, 26.50831032], [77.67102814, 26.50972939], [77.67800903, 26.5054512], [77.68598938, 26.50259018], [77.69503021, 26.50086975], [77.71398163, 26.50424957], [77.72099304, 26.50852013], [77.72698212, 26.51536179], [77.73066711, 26.52988052], [77.73935699, 26.54269028], [77.74434662, 26.54524994], [77.75, 26.54667091], [77.75801849, 26.55064964], [77.76700592, 26.55347824], [77.78299713, 26.55258942], [77.7976532, 26.55027962], [77.80430603, 26.55140114], [77.81299591, 26.55480957], [77.81765747, 26.56021118], [77.82467651, 26.57274055], [77.8243866, 26.58443069], [77.81842041, 26.59385109], [77.82041168, 26.59983826], [77.82543182, 26.60524178], [77.83409882, 26.61178017], [77.84243774, 26.61517906], [77.85144043, 26.61601067], [77.87037659, 26.61861992], [77.8793869, 26.62029076], [77.88877869, 26.63281059], [77.89015198, 26.64051819], [77.89087677, 26.65450287], [77.89457703, 26.66221046], [77.9036026, 26.66617966], [77.92391205, 26.66499138], [77.93990326, 26.66270828], [77.94789124, 26.66504097], [77.95355988, 26.66942024], [77.96053314, 26.67152977], [77.96879578, 26.67663956], [77.97572327, 26.68330193], [77.98855591, 26.69999123], [77.99221802, 26.70264053], [78.01190186, 26.70014763], [78.01920319, 26.69762039], [78.03156281, 26.69133949], [78.04312134, 26.69106293], [78.04911041, 26.68980026], [78.05622101, 26.68589973], [78.06092834, 26.68184853], [78.06511688, 26.67964172], [78.06938934, 26.67851067], [78.07537079, 26.67819023], [78.07863617, 26.68032074], [78.08573914, 26.68305016], [78.08805847, 26.68666077], [78.08898926, 26.70072174], [78.0865097, 26.72445107], [78.08676147, 26.73176956], [78.08914948, 26.73810959], [78.09600067, 26.74376106], [78.11167908, 26.74965096], [78.11605835, 26.7546196], [78.11482239, 26.75881195], [78.11104584, 26.76214027], [78.10051727, 26.76637077], [78.09709167, 26.76942062], [78.09568024, 26.77179909], [78.09442139, 26.7834301], [78.09538269, 26.78943062], [78.09983063, 26.79700851], [78.10552216, 26.80075264], [78.1129303, 26.80256081], [78.11902618, 26.80256081], [78.13131714, 26.79916954], [78.14048004, 26.79364014], [78.14581299, 26.79173088], [78.15978241, 26.79112053], [78.17611694, 26.79149246], [78.17975616, 26.79356956], [78.18044281, 26.79704094], [78.17936707, 26.80116081], [78.16340637, 26.81993103], [78.16094971, 26.82703972], [78.16355133, 26.82985115], [78.16757202, 26.83195114], [78.17327881, 26.83257103], [78.1795578, 26.83102036], [78.19210052, 26.8298111], [78.20278931, 26.83231926], [78.20979309, 26.83609009], [78.21700287, 26.83767128], [78.22299194, 26.8372097], [78.23680115, 26.83169937], [78.24754333, 26.82387924], [78.2556076, 26.82028961], [78.26088715, 26.82094955], [78.26531219, 26.82467079], [78.26677704, 26.8328228], [78.2664566, 26.8409996], [78.26779175, 26.84966087], [78.27075195, 26.85559082], [78.27623749, 26.86048126], [78.28206635, 26.86408806], [78.29470062, 26.86828995], [78.30200958, 26.86911964], [78.315979, 26.86936188], [78.32375336, 26.8686409], [78.34120178, 26.87395096], [78.35135651, 26.87437057], [78.36250305, 26.87133026], [78.36464691, 26.86884117], [78.36688232, 26.8625927], [78.37010956, 26.85758972], [78.37480927, 26.84683037], [78.38065338, 26.83609009], [78.38559723, 26.82793999], [78.38973999, 26.82489967], [78.40032196, 26.82600975], [78.41337585, 26.83043098], [78.4258728, 26.83231926], [78.430336, 26.82887268], [78.43427277, 26.82411194], [78.44557953, 26.80343056], [78.45078278, 26.79805183], [78.45813751, 26.79523277], [78.46631622, 26.79341125], [78.47632599, 26.79225159], [78.49199677, 26.78795052], [78.51557159, 26.78511047], [78.52632904, 26.77853966], [78.53427124, 26.77200127], [78.53504944, 26.77166176], [78.55490112, 26.76482964], [78.56009674, 26.76221275], [78.5658493, 26.75769043], [78.57521057, 26.75599289], [78.60196686, 26.75605965], [78.60646057, 26.75752068], [78.60938263, 26.76102066], [78.61178589, 26.76711273], [78.61569214, 26.77190018], [78.62043762, 26.77519989], [78.62857056, 26.77539063], [78.65036774, 26.76972961], [78.65901947, 26.76922989], [78.66750336, 26.77424049], [78.67282867, 26.78774834], [78.67736053, 26.79238129], [78.6834259, 26.79461288], [78.69007111, 26.79602814], [78.71534729, 26.80021286], [78.72142792, 26.79771042], [78.72033691, 26.79274178], [78.7178421, 26.78717995], [78.71837616, 26.78170013], [78.72293854, 26.77934265], [78.72586823, 26.77962112], [78.73145294, 26.78310966], [78.73596954, 26.78898048], [78.74108124, 26.79252052], [78.74479675, 26.78940964], [78.74904633, 26.78440094], [78.75447845, 26.77571106], [78.762146, 26.76683044], [78.76638031, 26.76453972], [78.77070618, 26.76419067], [78.77414703, 26.76606941], [78.79868317, 26.76911163], [78.80610657, 26.7687912], [78.81138611, 26.7654705], [78.84068298, 26.7260704], [78.85114288, 26.71642113], [78.85431671, 26.71232033], [78.8649292, 26.70466995], [78.87123871, 26.70360947], [78.87708282, 26.7035408], [78.88288879, 26.70440102], [78.90394592, 26.71338081], [78.90792084, 26.71294022], [78.91278839, 26.71038055], [78.93076324, 26.70426941], [78.94814301, 26.6967411], [78.95015717, 26.6940403], [78.94991302, 26.69194031], [78.93698883, 26.67228127], [78.93579102, 26.6679306], [78.9360733, 26.66488075], [78.93791199, 26.66269112], [78.9437027, 26.6610508], [78.94789124, 26.66262817], [78.96393585, 26.67651749], [78.9696579, 26.6805706], [78.97387695, 26.68254089], [78.98388672, 26.68571091], [78.98728943, 26.68604088], [78.99124908, 26.68444061], [78.99317932, 26.68457031], [78.99732208, 26.68099022], [79.00041199, 26.67671013], [79.0011673, 26.6739006], [78.99814606, 26.66662025], [78.99572754, 26.66356277], [78.9912796, 26.65456963], [78.98899078, 26.65142059], [78.98686981, 26.64736748], [78.98722076, 26.6441803], [78.99130249, 26.64143944], [78.99530029, 26.63596916], [79.00084686, 26.63041115], [79.0030899, 26.62665939], [79.00311279, 26.61923027], [79.00520325, 26.61413765], [79.00566101, 26.61046982], [79.00372314, 26.60637093], [78.99133301, 26.60464096], [78.9821167, 26.59417915], [78.97802734, 26.59243011], [78.98100281, 26.58600807], [78.97952271, 26.58156967], [78.97962189, 26.57407951], [78.99134064, 26.58230972], [78.9935379, 26.5788002], [78.99820709, 26.57422256], [78.99785614, 26.57215118], [78.99912262, 26.5667305], [78.99797058, 26.56401062], [79.00437927, 26.55862045], [79.00673676, 26.55780029], [79.00518799, 26.55623055], [78.99768829, 26.55586052], [78.99575043, 26.55411148], [78.99798584, 26.55093956], [79.00284576, 26.54993057], [79.00598907, 26.55142021], [79.00804138, 26.54778099], [79.01278687, 26.54871941], [79.01724243, 26.55212975], [79.02054596, 26.55166054], [79.01863098, 26.5433197], [79.01963043, 26.54144096], [79.03309631, 26.53598976], [79.03366852, 26.53341103], [79.03129578, 26.52477074], [79.03325653, 26.52262115], [79.03946686, 26.5233593], [79.04102325, 26.52276039], [79.03959656, 26.5196991], [79.03930664, 26.5157299], [79.04374695, 26.51046944], [79.04975128, 26.50666046], [79.04971313, 26.50276947], [79.05088043, 26.50077057], [79.05335999, 26.50121117], [79.0565567, 26.50316048], [79.06093597, 26.50329971], [79.06114197, 26.49095917], [79.06230927, 26.48987961], [79.06433868, 26.4868412], [79.0634613, 26.48476028], [79.04707336, 26.46142006], [79.04676056, 26.45786095], [79.04846191, 26.45605087], [79.05323029, 26.45561028], [79.05748749, 26.45614052], [79.05802917, 26.45128059], [79.06062317, 26.45182991], [79.06130219, 26.44943047], [79.06355286, 26.44895935], [79.06684875, 26.44940948], [79.06710052, 26.44700813], [79.06906891, 26.44651985], [79.07279205, 26.44779015], [79.07417297, 26.44556808], [79.07769775, 26.44723129], [79.08094025, 26.44390106], [79.08304596, 26.44973946], [79.08274841, 26.45231056], [79.08329773, 26.4530201], [79.08943176, 26.45092964], [79.09113312, 26.45240021], [79.09118652, 26.45527077], [79.09287262, 26.45730019], [79.0949173, 26.45709991], [79.09989166, 26.45602989], [79.10515594, 26.45360184], [79.11030579, 26.45301056], [79.12098694, 26.44789124], [79.12400818, 26.4455204], [79.12676239, 26.44481087], [79.12328339, 26.4406395], [79.11911011, 26.4328804], [79.11682129, 26.42421913], [79.11723328, 26.41712189], [79.11489868, 26.41558838], [79.10067749, 26.41173172], [79.09703827, 26.41259956], [79.09268951, 26.41614914], [79.09192657, 26.41674042], [79.08682251, 26.41782188], [79.08072662, 26.40550041], [79.08699799, 26.39108276], [79.08959198, 26.38820076], [79.08849335, 26.38313293], [79.09047699, 26.37939072], [79.08911896, 26.37713051], [79.07924652, 26.37288094], [79.07675934, 26.3660202], [79.07679749, 26.36269188], [79.08421326, 26.3597126], [79.08857727, 26.3599205], [79.0930481, 26.36013985], [79.0951767, 26.35981941], [79.09673309, 26.35956955], [79.09644318, 26.35560989], [79.10038757, 26.35509109], [79.10340118, 26.35951042], [79.10526276, 26.35598946], [79.10858154, 26.35449028], [79.11662292, 26.35357285], [79.11952209, 26.35103989], [79.12320709, 26.34473038], [79.13137817, 26.34589958], [79.13374329, 26.3449707], [79.13257599, 26.34276009], [79.12680054, 26.33992004], [79.12499237, 26.33793068], [79.12731171, 26.33349037], [79.12703705, 26.33165932], [79.12586212, 26.33143806], [79.12423706, 26.33114052], [79.11564636, 26.33509064], [79.11569214, 26.33130074], [79.11573029, 26.32849121], [79.11798859, 26.32634163], [79.12724304, 26.32138062], [79.12658691, 26.3160305], [79.11911774, 26.31492805], [79.11457825, 26.31314087], [79.10875702, 26.30862045], [79.10154724, 26.3138504], [79.09797668, 26.31464958], [79.09384918, 26.31194115], [79.09147644, 26.30845261], [79.09178925, 26.30404282], [79.08769226, 26.2990303], [79.083992, 26.29708099], [79.08309937, 26.29389954], [79.08635712, 26.28367043], [79.08357239, 26.27240944], [79.07964325, 26.27260971], [79.07720184, 26.27359962], [79.07610321, 26.27519035], [79.07657623, 26.27882195], [79.07872772, 26.28034019], [79.0786972, 26.28448105], [79.07769012, 26.28721809], [79.07553101, 26.28713036], [79.07206726, 26.28523064], [79.06865692, 26.28777122], [79.06726837, 26.28762054], [79.0640564, 26.28263092], [79.05789185, 26.28380013], [79.05327606, 26.27960014], [79.04679871, 26.27059174], [79.04853058, 26.26597023], [79.04677582, 26.26531982], [79.03703308, 26.26699066], [79.03793335, 26.26287079], [79.04219818, 26.25996017], [79.04535675, 26.26029968], [79.04692078, 26.25539017], [79.04892731, 26.25369072], [79.05191803, 26.25324059], [79.05551147, 26.25415039], [79.05844116, 26.25391006], [79.06266785, 26.24693108], [79.06112671, 26.24369049], [79.05652618, 26.24188995], [79.05555725, 26.23964119], [79.05705261, 26.23289108], [79.05526733, 26.23238945], [79.0521698, 26.23211288], [79.04603577, 26.23354912], [79.04055023, 26.22928047], [79.03425598, 26.23154068], [79.02960968, 26.23207092], [79.02684784, 26.23336029], [79.02466583, 26.23425293], [79.02039337, 26.23425293], [79.01714325, 26.2321682], [79.01690674, 26.22800064], [79.01761627, 26.22340012], [79.01729584, 26.22369194], [79.01872253, 26.21582985], [79.01819611, 26.2125206], [79.02070618, 26.20967293], [79.02062225, 26.20857048], [79.00990295, 26.2049408], [79.01039124, 26.20277977], [79.01257324, 26.20140076], [79.01502991, 26.19815063], [79.01494598, 26.19746971], [79.0129776, 26.19686127], [79.00232697, 26.19676971], [78.99655151, 26.19898033], [78.9944458, 26.2004509], [78.99175262, 26.20396805], [78.98403931, 26.20067024], [78.98091888, 26.19841003], [78.97737885, 26.19549942], [78.97574615, 26.19281006], [78.99178314, 26.17728043], [78.99598694, 26.17551041], [79.00340271, 26.17295837], [79.002388, 26.16472816], [79.00092316, 26.16026115], [79.00071716, 26.15497971], [78.99459839, 26.15278053], [78.99179077, 26.15205956], [78.98966217, 26.15070915], [78.98623657, 26.1505394], [78.97064209, 26.15540123], [78.96533966, 26.15578079], [78.96032715, 26.15427017], [78.95230103, 26.14260101], [78.94576263, 26.14106178], [78.94267273, 26.13914108], [78.94438934, 26.13751984], [78.95464325, 26.13286018], [78.95810699, 26.12990952], [78.96652985, 26.12565041], [78.96922302, 26.1234417], [78.97049713, 26.12028122], [78.96977997, 26.11230087], [78.9718399, 26.1086998], [78.99011993, 26.09589958], [78.99185181, 26.09526062], [79.00049591, 26.09671021], [79.00350952, 26.09431076], [79.00437927, 26.09008026], [79.00219727, 26.08660126], [79.00315094, 26.08179283], [79.00113678, 26.0783596], [78.99915314, 26.07709122], [78.99711609, 26.07393074], [78.99188232, 26.07464027], [78.98602295, 26.07608032], [78.98248291, 26.07375908], [78.9786911, 26.0646801], [78.97579956, 26.05988121], [78.9681778, 26.05916023], [78.96144867, 26.0508194], [78.95266724, 26.04203033], [78.94863129, 26.03881264], [78.94432831, 26.03695107], [78.94618988, 26.03107262], [78.95050049, 26.02582169], [78.95040131, 26.01986122], [78.94534302, 26.01390076], [78.94441986, 26.00889015], [78.94613647, 26.00616074], [78.94658661, 26.00506973], [78.94610596, 26.00155067], [78.94330597, 25.99822807], [78.9438858, 25.99324036], [78.94316864, 25.99069023], [78.93947601, 25.98637009], [78.93621826, 25.98531914], [78.93102264, 25.98553085], [78.92720032, 25.98651123], [78.92459106, 25.98431015], [78.92362213, 25.9808712], [78.9261322, 25.97776985], [78.93113708, 25.97631073], [78.92951965, 25.9716301], [78.92547607, 25.96541977], [78.92582703, 25.95889282], [78.92742157, 25.95549965], [78.93009949, 25.95158005], [78.92952728, 25.94935989], [78.92735291, 25.94832039], [78.92484283, 25.9487114], [78.92215729, 25.95012093], [78.92112732, 25.95084763], [78.92384338, 25.95275116], [78.91532898, 25.94936943], [78.90978241, 25.94608116], [78.90394592, 25.94110107], [78.90125275, 25.9375], [78.89808655, 25.93087006], [78.89427185, 25.92585182], [78.87638092, 25.91566086], [78.8768692, 25.91448021], [78.87741852, 25.91316986], [78.88034821, 25.90955162], [78.8829422, 25.90635109], [78.88719177, 25.89897156], [78.88511658, 25.89286041], [78.88134003, 25.8884201], [78.88371277, 25.87647057], [78.88345337, 25.87491989], [78.8826828, 25.87026978], [78.87689209, 25.8698597], [78.87268829, 25.87302017], [78.86798096, 25.87498093], [78.86606598, 25.87485123], [78.86358643, 25.87467194], [78.86071777, 25.87332916], [78.85782623, 25.87201118], [78.85051727, 25.86561012], [78.84662628, 25.86050034], [78.84397888, 25.84531021], [78.84622192, 25.83876038], [78.85293579, 25.84361076], [78.86575317, 25.83435059], [78.86646271, 25.8296299], [78.86396027, 25.81627083], [78.8633194, 25.80208015], [78.86192322, 25.79919815], [78.8559494, 25.79443932], [78.8496933, 25.79586029], [78.8436203, 25.80130959], [78.84129333, 25.80520058], [78.84073639, 25.81208038], [78.84179688, 25.81680107], [78.84098053, 25.82064056], [78.83512878, 25.82409286], [78.81582642, 25.83114052], [78.81124878, 25.83012009], [78.80198669, 25.82220078], [78.79885864, 25.8182106], [78.80046082, 25.81287956], [78.80401611, 25.81022072], [78.80766296, 25.81151962], [78.813797, 25.81681061], [78.81623077, 25.81758118], [78.82227325, 25.81522751], [78.82363892, 25.81236076], [78.82376862, 25.81082153], [78.82408142, 25.80760956], [78.82050323, 25.79940033], [78.8167572, 25.7992897], [78.81169891, 25.79914093], [78.80497742, 25.80019188], [78.80413055, 25.80033112], [78.79955292, 25.79936028], [78.79606628, 25.79593086], [78.79360199, 25.7935009], [78.79062653, 25.7882309], [78.77996826, 25.77511978], [78.77578735, 25.7614994], [78.76582336, 25.75891113], [78.76241302, 25.75226021], [78.75567627, 25.75299072], [78.75128174, 25.75270081], [78.74681854, 25.74909019], [78.74550629, 25.74411964], [78.7457962, 25.73801994], [78.74803925, 25.73265076], [78.75240326, 25.72741127], [78.76074982, 25.72079086], [78.77752686, 25.71370125], [78.79123688, 25.71054077], [78.79255676, 25.70717049], [78.79070282, 25.70285034], [78.78940582, 25.69983101], [78.79576111, 25.69614029], [78.80938721, 25.67807007], [78.8113327, 25.67448044], [78.81060791, 25.66506195], [78.81124878, 25.64545059], [78.80979156, 25.63836098], [78.806427, 25.63302994], [78.80519104, 25.6245575], [78.79815674, 25.61922073], [78.79454803, 25.6175499], [78.78485107, 25.61548996], [78.76597595, 25.61314964], [78.75541687, 25.60959053], [78.7489624, 25.60834122], [78.74095154, 25.60387993], [78.73284149, 25.60305977], [78.72431946, 25.60844994], [78.71116638, 25.60659027], [78.70658875, 25.60327911], [78.7003479, 25.60131073], [78.69570923, 25.59984016], [78.68798828, 25.59515953], [78.67701721, 25.59410095], [78.672966, 25.59180069], [78.66535187, 25.58484077], [78.64862061, 25.5656395], [78.64434052, 25.56541824], [78.62883759, 25.56900024], [78.62341309, 25.57100105], [78.62020874, 25.57356071], [78.62133026, 25.58218002], [78.6181488, 25.58699036], [78.60862732, 25.58908081], [78.60573578, 25.58887291], [78.6042099, 25.58728981], [78.60015106, 25.57835007], [78.59799194, 25.57561111], [78.59525299, 25.57493019], [78.59027863, 25.57522011], [78.58706665, 25.57294083], [78.583992, 25.56554985], [78.58119202, 25.56430817], [78.57608032, 25.56528854], [78.57096863, 25.56735992], [78.56548309, 25.56787109], [78.55974579, 25.56780052], [78.54714966, 25.56470108], [78.54178619, 25.56513977], [78.53604889, 25.56686974], [78.53240204, 25.57028961], [78.52751923, 25.57292938], [78.51143646, 25.57296181], [78.49149323, 25.58188057], [78.48626709, 25.58222961], [78.48108673, 25.58043289], [78.46894073, 25.57298088], [78.46212006, 25.56747055], [78.46003723, 25.56455994], [78.45733643, 25.55540085], [78.45519257, 25.55195045], [78.44915009, 25.5527401], [78.44496918, 25.55499077], [78.44303894, 25.5570507], [78.43974304, 25.55895996], [78.43707275, 25.56435013], [78.43353271, 25.56524086], [78.42933655, 25.56385994], [78.4261322, 25.56145096], [78.41230774, 25.54224968], [78.40997314, 25.53771973], [78.40866089, 25.53290176], [78.411026, 25.52738953], [78.41529846, 25.52139091], [78.41674805, 25.51777267], [78.41628265, 25.51573944], [78.41433716, 25.51531029], [78.41124725, 25.51902008], [78.40956879, 25.51864815], [78.408638, 25.50799942], [78.40940857, 25.50427055], [78.412323, 25.49766159], [78.41947937, 25.49054146], [78.42156982, 25.47970963], [78.42072296, 25.47761917], [78.41646576, 25.47750282], [78.40672302, 25.47921944], [78.40142822, 25.47297096], [78.3960495, 25.47177124], [78.39375305, 25.47125053], [78.39309692, 25.47042084], [78.39189911, 25.46884918], [78.38568878, 25.45416069], [78.38340759, 25.45193291], [78.38088989, 25.4504509], [78.37738037, 25.44837952], [78.37077332, 25.44717026], [78.36614227, 25.44631767], [78.36097717, 25.44660187], [78.35266876, 25.45531273], [78.34925842, 25.45579147], [78.34758759, 25.45483971], [78.34378815, 25.44617844], [78.33656311, 25.43498993], [78.33518982, 25.43105125], [78.33407593, 25.41815186], [78.33248901, 25.40455055], [78.33027649, 25.40099907], [78.32151031, 25.3952198], [78.31690979, 25.39090919], [78.31067657, 25.3850708], [78.30716705, 25.3841629], [78.30340576, 25.38479042], [78.29972076, 25.38375282], [78.29551697, 25.37479973], [78.2942276, 25.36762047], [78.2962265, 25.36499023], [78.30162048, 25.36437988], [78.31626892, 25.35961914], [78.32319641, 25.35526848], [78.32657623, 25.34902], [78.32756042, 25.34645081], [78.3312912, 25.33671951], [78.33078003, 25.33128929], [78.32782745, 25.32761002], [78.32710266, 25.32720947], [78.31543732, 25.32073021], [78.31057739, 25.31615829], [78.30802917, 25.31098938], [78.31163788, 25.3075695], [78.31645203, 25.30458069], [78.33007813, 25.30038071], [78.34130859, 25.29927063], [78.34516144, 25.29794121], [78.34506989, 25.28297043], [78.35526276, 25.2757206], [78.36222076, 25.26543045], [78.36029816, 25.25856972], [78.35521698, 25.24996948], [78.35453033, 25.2460804], [78.35708618, 25.24417114], [78.3645401, 25.24391174], [78.36888885, 25.24166107], [78.37075806, 25.23336029], [78.37516785, 25.22575188], [78.38108826, 25.2238102], [78.39215088, 25.22234917], [78.39553833, 25.22118187], [78.39775848, 25.21775055], [78.39450073, 25.21463966], [78.38577271, 25.20868111], [78.38394928, 25.20600128], [78.3838501, 25.20486069], [78.3835907, 25.20195007], [78.38427734, 25.19933128], [78.38536072, 25.19515991], [78.38889313, 25.1928196], [78.3913269, 25.19120026], [78.40355682, 25.18894005], [78.40725708, 25.1857605], [78.4090271, 25.18202972], [78.41726685, 25.17278099], [78.42823029, 25.16964149], [78.435112, 25.17036057], [78.43746185, 25.17140961], [78.43913269, 25.17214966], [78.44394684, 25.17255974], [78.44645691, 25.16902161], [78.44631195, 25.1667099], [78.44284821, 25.15788078], [78.44198608, 25.15735054], [78.42870331, 25.15833092], [78.42089844, 25.15764046], [78.41829681, 25.1534996], [78.41882324, 25.15109062], [78.42294312, 25.14537048], [78.43235779, 25.13754082], [78.44291687, 25.12877083], [78.43097687, 25.1244812], [78.42468262, 25.12469101], [78.41765594, 25.12697029], [78.41072845, 25.1292305], [78.40226746, 25.13097], [78.39531708, 25.1305275], [78.38968658, 25.12699127], [78.37869263, 25.11269951], [78.37441254, 25.10853958], [78.36699677, 25.1045208], [78.35784149, 25.10235023], [78.34781647, 25.09996986], [78.33265686, 25.09324265], [78.33090973, 25.09163094], [78.32776642, 25.08876991], [78.32675934, 25.08688164], [78.32524872, 25.08406067], [78.32498932, 25.07249832], [78.32717896, 25.06791115], [78.33078003, 25.0453701], [78.3380661, 25.02733994], [78.33751678, 25.0207901], [78.33460999, 25.01073837], [78.33020782, 25.00374031], [78.32753754, 24.9995594], [78.30961609, 24.99124908], [78.3066864, 24.98899269], [78.30256653, 24.98397064], [78.28959656, 24.96813965], [78.2822876, 24.96320915], [78.26271057, 24.95260048], [78.25991821, 24.94924927], [78.25604248, 24.94203949], [78.25244904, 24.93950081], [78.24936676, 24.93848038], [78.22878265, 24.9240799], [78.21391296, 24.91557121], [78.21070862, 24.91234016], [78.2039566, 24.90050125], [78.19973755, 24.8962307], [78.18917084, 24.89280128], [78.17704773, 24.88733101], [78.1704483, 24.88526917], [78.1653595, 24.88174057], [78.16470337, 24.87829971], [78.16332245, 24.87099266], [78.16355133, 24.8642807], [78.1638031, 24.85709953], [78.16532898, 24.84817123], [78.1700058, 24.84647942], [78.17357635, 24.8461895], [78.18689728, 24.84280968], [78.19158173, 24.83967018], [78.19403076, 24.83156013], [78.19587708, 24.82859039], [78.20896912, 24.8130703], [78.21836853, 24.79191971], [78.22387695, 24.78300095], [78.22582245, 24.77657127], [78.22518921, 24.76639175], [78.22428894, 24.76403046], [78.21987152, 24.75819016], [78.21888733, 24.75379944], [78.22039032, 24.74736977], [78.22631836, 24.73624992], [78.23654938, 24.72463989], [78.25078583, 24.70557022], [78.25280762, 24.70094109], [78.25460815, 24.69248962], [78.25699615, 24.68593025], [78.26799774, 24.66959953], [78.26847839, 24.66710091], [78.26789856, 24.66352081], [78.25834656, 24.65283966], [78.25669098, 24.64862061], [78.25847626, 24.63780022], [78.26339722, 24.62812042], [78.26753235, 24.62191963], [78.26985168, 24.61538124], [78.26940155, 24.60502052], [78.26808167, 24.59697914], [78.2637558, 24.57872009], [78.26035309, 24.56923294], [78.25888824, 24.55818939], [78.25531769, 24.5522995], [78.24610901, 24.5486908], [78.23654938, 24.5463295], [78.22418213, 24.54133987], [78.21839905, 24.53569031], [78.21653748, 24.53164291], [78.21971893, 24.52277946], [78.2281723, 24.51645279], [78.23806, 24.5116806], [78.24017334, 24.50958061], [78.24150848, 24.50484276], [78.23768616, 24.49617958], [78.23789978, 24.49358177], [78.23963165, 24.48945999], [78.24621582, 24.48671913], [78.2545929, 24.4858284], [78.263237, 24.48308182], [78.26682281, 24.47999954], [78.2696228, 24.47618294], [78.26966095, 24.47310829], [78.26030731, 24.46001053], [78.26074982, 24.45393944], [78.26687622, 24.44737053], [78.28121185, 24.43721008], [78.28985596, 24.43312073], [78.29985046, 24.42654991], [78.31150055, 24.41744041], [78.31520081, 24.41284943], [78.31830597, 24.4103508], [78.33244324, 24.40597153], [78.33673096, 24.40386963], [78.3449173, 24.39204025], [78.35040283, 24.38953018], [78.3588562, 24.38718987], [78.36094666, 24.38578987], [78.36292267, 24.38161087], [78.36257172, 24.37815094], [78.34651947, 24.36269951], [78.34092712, 24.35242081], [78.33544922, 24.3450985], [78.33112335, 24.34255028], [78.32657623, 24.33846855], [78.32543182, 24.33436966], [78.3259964, 24.32961845], [78.32852173, 24.32550049], [78.33181, 24.32249069], [78.33551788, 24.31917953], [78.33943176, 24.31735992], [78.34130859, 24.31151962], [78.34140015, 24.30780983], [78.34243774, 24.30538177], [78.34453583, 24.30328941], [78.35141754, 24.29927063], [78.36168671, 24.29610062], [78.3639679, 24.29235077], [78.36624908, 24.29030991], [78.36989594, 24.28908157], [78.3730011, 24.28635979], [78.37742615, 24.27806091], [78.37963867, 24.27556038], [78.38237, 24.2739296], [78.38566589, 24.27305031], [78.39296722, 24.2747612], [78.40326691, 24.27547264], [78.4069519, 24.27700996], [78.41130829, 24.28758049], [78.41448975, 24.28884125], [78.41861725, 24.28946114], [78.42315674, 24.28915024], [78.42648315, 24.29018021], [78.43477631, 24.29766083], [78.43332672, 24.30900955], [78.4335022, 24.31340981], [78.44029236, 24.32553101], [78.45082855, 24.32987976], [78.45459747, 24.33322144], [78.45892334, 24.33568954], [78.46779633, 24.33934021], [78.47077179, 24.34338188], [78.47167969, 24.35709], [78.47280121, 24.36235046], [78.47532654, 24.36742973], [78.48430634, 24.37762833], [78.48977661, 24.38605118], [78.49819183, 24.3927803], [78.49993896, 24.39433098], [78.50537109, 24.39394951], [78.51455688, 24.39055824], [78.51922607, 24.38735008], [78.52207184, 24.38414955], [78.52511597, 24.37713814], [78.52762604, 24.37447166], [78.55258179, 24.36062813], [78.5568924, 24.3611908], [78.56265259, 24.35935974], [78.56651306, 24.35732079], [78.57489777, 24.3593502], [78.57843781, 24.35708046], [78.57888031, 24.35396194], [78.58071899, 24.34983063], [78.58470154, 24.3434391], [78.58777618, 24.34135056], [78.59364319, 24.33936119], [78.59900665, 24.32318115], [78.6020813, 24.31830025], [78.6047821, 24.31574059], [78.61492157, 24.31257248], [78.61962891, 24.31184006], [78.62281036, 24.30985069], [78.62351227, 24.30690193], [78.61788177, 24.2992897], [78.61734009, 24.2961216], [78.61940002, 24.28944969], [78.62171936, 24.2862606], [78.62602234, 24.28646278], [78.6313858, 24.29018974], [78.6341629, 24.28936958], [78.63923645, 24.28619957], [78.64363861, 24.28149986], [78.65444946, 24.27374077], [78.65779877, 24.26805115], [78.66316223, 24.25263023], [78.66535187, 24.24844933], [78.66912079, 24.24501991], [78.67311096, 24.24435043], [78.67809296, 24.24489975], [78.68113708, 24.24407005], [78.69258118, 24.23701096], [78.69886017, 24.2344799], [78.7071228, 24.23876953], [78.71111298, 24.23944092], [78.71858215, 24.239151], [78.72110748, 24.24122047], [78.72653961, 24.25270081], [78.73221588, 24.25382042], [78.73526001, 24.25177956], [78.73610687, 24.24510956], [78.73751831, 24.24210167], [78.74085236, 24.24016953], [78.74371338, 24.23945045], [78.74588776, 24.23927116], [78.74977112, 24.24073982], [78.75255585, 24.24367905], [78.75428772, 24.2472496], [78.75668335, 24.25972939], [78.76027679, 24.25848961], [78.76642609, 24.25057983], [78.7607193, 24.2390995], [78.76000977, 24.23651123], [78.76053619, 24.23385048], [78.76774597, 24.21777916], [78.76983643, 24.215271], [78.77488708, 24.21228981], [78.77625275, 24.21002007], [78.77831268, 24.2010498], [78.78205872, 24.19152069], [78.7845993, 24.18514061], [78.78848267, 24.18135834], [78.79168701, 24.18024063], [78.80224609, 24.18190002], [78.80570984, 24.18429947], [78.80795288, 24.19331932], [78.80908203, 24.20465088], [78.8105011, 24.20852089], [78.81352234, 24.21027946], [78.81638336, 24.20865059], [78.81886292, 24.20243835], [78.82007599, 24.20121956], [78.8242569, 24.20129967], [78.82772064, 24.20318985], [78.83277893, 24.20928192], [78.83876801, 24.21467972], [78.84654236, 24.21693039], [78.8582077, 24.21354103], [78.86283112, 24.21404076], [78.87368011, 24.2189312], [78.87886047, 24.22305107], [78.88105011, 24.22888947], [78.87982178, 24.24411964], [78.87827301, 24.24868965], [78.87909698, 24.25401115], [78.88558197, 24.25928116], [78.90985107, 24.27292061], [78.91172028, 24.2765007], [78.91322327, 24.28590965], [78.91284943, 24.28944969], [78.9077301, 24.29487038], [78.9070816, 24.29643059], [78.90776062, 24.30123138], [78.9241333, 24.31421852], [78.92874146, 24.31620979], [78.93245697, 24.31888962], [78.94536591, 24.33130074], [78.95088959, 24.34041023], [78.95493317, 24.34392929], [78.96099091, 24.34716988], [78.9648819, 24.35044289], [78.96687317, 24.35366058], [78.96813965, 24.35695076], [78.96833801, 24.36024284], [78.96692657, 24.37034988], [78.96717072, 24.37358284], [78.97097778, 24.38472939], [78.97422028, 24.39863968], [78.97621155, 24.40289116], [78.98087311, 24.41782951], [78.9868927, 24.42324066], [78.98777771, 24.42797089], [78.98651123, 24.43403053], [78.98438263, 24.44136047], [78.981987, 24.44724083], [78.97183228, 24.44473267], [78.96203613, 24.44407082], [78.95552826, 24.44512749], [78.94713593, 24.44313049], [78.94439697, 24.44325829], [78.94065857, 24.44598007], [78.93107605, 24.4599781], [78.92724609, 24.4621315], [78.91279602, 24.46351051], [78.90859222, 24.46677017], [78.9026413, 24.47837067], [78.90088654, 24.48357964], [78.90093994, 24.4883709], [78.90808105, 24.49316025], [78.91381073, 24.50084114], [78.91757965, 24.50251007], [78.92182922, 24.50107956], [78.92436218, 24.49908066], [78.92607117, 24.49638748], [78.92569733, 24.49183083], [78.92334747, 24.48839951], [78.92517853, 24.48599052], [78.93071747, 24.48454094], [78.94313812, 24.48488045], [78.94856262, 24.4861927], [78.95455933, 24.48855972], [78.96391296, 24.49378014], [78.96639252, 24.49694824], [78.96549225, 24.50028038], [78.96340942, 24.50204086], [78.95018768, 24.50447845], [78.94708252, 24.50598907], [78.94416809, 24.50950813], [78.943367, 24.51662064], [78.94477081, 24.52363014], [78.94393921, 24.52664757], [78.94042206, 24.53120995], [78.94001007, 24.53408051], [78.94036865, 24.54314995], [78.94550323, 24.55331039], [78.94465637, 24.55620956], [78.94299316, 24.55787849], [78.93038177, 24.56439018], [78.91314697, 24.58130074], [78.90850067, 24.58880997], [78.90561676, 24.602211], [78.90438843, 24.60430908], [78.89295197, 24.6138382], [78.89186859, 24.61680031], [78.89144135, 24.62207031], [78.8817215, 24.63969994], [78.87306976, 24.64694977], [78.866539, 24.64549255], [78.86280823, 24.64112091], [78.85919189, 24.62817955], [78.85579681, 24.62298965], [78.85240173, 24.62094116], [78.84916687, 24.62166023], [78.84436798, 24.62899017], [78.83905792, 24.6282196], [78.83599854, 24.62557983], [78.83345032, 24.62079048], [78.83084869, 24.60889053], [78.82878113, 24.60781097], [78.82039642, 24.6078701], [78.8140564, 24.60560036], [78.81112671, 24.60533905], [78.80667877, 24.6071701], [78.80182648, 24.60782814], [78.79788208, 24.60531998], [78.79382324, 24.59822845], [78.77690125, 24.59309006], [78.76661682, 24.59756279], [78.75199127, 24.60246277], [78.74946594, 24.60498047], [78.74803162, 24.61152077], [78.7485733, 24.62471008], [78.74797821, 24.63705063], [78.74635315, 24.64319038], [78.74208069, 24.65063095], [78.7405777, 24.65607071], [78.74006653, 24.65995979], [78.74427032, 24.66682053], [78.74487305, 24.66930962], [78.75498962, 24.67357063], [78.75753784, 24.67715073], [78.75878143, 24.68217087], [78.75998688, 24.69356918], [78.76534271, 24.69532967], [78.76760101, 24.69692993], [78.77239227, 24.70414162], [78.77297974, 24.70691109], [78.77308655, 24.71165085], [78.76980591, 24.71884918], [78.76912689, 24.72354126], [78.76748657, 24.74341011], [78.76895142, 24.75110054], [78.76862335, 24.7548008], [78.76319885, 24.76675987], [78.76454926, 24.79499245], [78.76722717, 24.79851151], [78.77781677, 24.80487251], [78.78011322, 24.80698967], [78.78109741, 24.81051064], [78.78054047, 24.81497192], [78.77256775, 24.83048058], [78.76888275, 24.84374809], [78.76740265, 24.84891129], [78.76716614, 24.85567093], [78.76448059, 24.86136818], [78.76135254, 24.86295128], [78.75343323, 24.86496925], [78.75061035, 24.86886024], [78.74668121, 24.87084961], [78.73838043, 24.86963081], [78.73441315, 24.87099266], [78.73163605, 24.87234116], [78.72254181, 24.88071823], [78.71887207, 24.88266182], [78.7128067, 24.88379097], [78.70289612, 24.88402748], [78.70056915, 24.88648033], [78.69634247, 24.89466095], [78.69171906, 24.89590073], [78.67965698, 24.89719009], [78.6754303, 24.8985405], [78.668396, 24.90239906], [78.66301727, 24.9092617], [78.65947723, 24.91752052], [78.65709686, 24.92506027], [78.65371704, 24.94421959], [78.6421814, 24.93976974], [78.64050293, 24.94036293], [78.6400528, 24.94532967], [78.64251709, 24.95029068], [78.64243317, 24.95265007], [78.62491608, 24.96194077], [78.62204742, 24.96490097], [78.62290192, 24.9677906], [78.63201904, 24.98372078], [78.63510895, 25.00432968], [78.6361618, 25.01089287], [78.6361618, 25.02136993], [78.6371994, 25.02555084], [78.64418793, 25.03524971], [78.64192963, 25.06149101], [78.63941193, 25.06637192], [78.6355896, 25.07101059], [78.63482666, 25.07419014], [78.62948608, 25.08242989], [78.6247406, 25.08641052], [78.62032318, 25.09159279], [78.61760712, 25.09271049], [78.60555267, 25.09422112], [78.59716797, 25.09787178], [78.59667969, 25.10345078], [78.59829712, 25.10808945], [78.59816742, 25.12708092], [78.59597778, 25.14858055], [78.59371185, 25.15739059], [78.56976318, 25.20195961], [78.56456757, 25.22096062], [78.56259155, 25.22602272], [78.56149292, 25.22744942], [78.56254578, 25.23867035], [78.5657959, 25.24945068], [78.56816864, 25.25405121], [78.56858063, 25.25860977], [78.56437683, 25.26521111], [78.55702209, 25.26932907], [78.55237579, 25.27087975], [78.54226685, 25.27203941], [78.53601837, 25.27194977], [78.52849579, 25.27450943], [78.52555847, 25.27817154], [78.52516937, 25.28549957], [78.52085114, 25.28803825], [78.50531769, 25.28154755], [78.50257874, 25.28342056], [78.50080872, 25.28824806], [78.49668121, 25.29385948], [78.48932648, 25.29208946], [78.4540329, 25.27060127], [78.44445038, 25.26995087], [78.43575287, 25.27324104], [78.42871094, 25.28083038], [78.42736053, 25.28867149], [78.4298172, 25.29701042], [78.43517303, 25.30252075], [78.44059753, 25.30416107], [78.44851685, 25.30328941], [78.45680237, 25.2993412], [78.45928955, 25.29665947], [78.46705627, 25.29301071], [78.46926117, 25.30332184], [78.47175598, 25.30583954], [78.47792053, 25.30869102], [78.48324585, 25.31418991], [78.4875412, 25.32019043], [78.49217224, 25.32382965], [78.49492645, 25.32069016], [78.49581146, 25.3101902], [78.50025177, 25.30413055], [78.50511169, 25.30211067], [78.51586151, 25.30433083], [78.51872253, 25.30581284], [78.52507782, 25.30653], [78.53098297, 25.31706047], [78.53356171, 25.31870079], [78.5389328, 25.32039261], [78.54083252, 25.3224411], [78.54145813, 25.32659912], [78.53768921, 25.32949829], [78.53359222, 25.33089256], [78.53150177, 25.33485031], [78.53069305, 25.33916855], [78.53108978, 25.34859085], [78.53044891, 25.35205078], [78.52480316, 25.35474968], [78.52336884, 25.3583107], [78.52514648, 25.36301231], [78.52806091, 25.36588097], [78.53505707, 25.36400986], [78.54473114, 25.3586998], [78.55602264, 25.34860992], [78.56204987, 25.34795189], [78.57621765, 25.35193062], [78.5789032, 25.35531807], [78.57950592, 25.36057091], [78.57775879, 25.37714005], [78.57440186, 25.38223076], [78.57034302, 25.38478279], [78.56463623, 25.38396072], [78.56009674, 25.38204956], [78.55690002, 25.38414955], [78.56112671, 25.39569283], [78.56344604, 25.39792061], [78.5686264, 25.39619064], [78.5761261, 25.39109039], [78.5789032, 25.39009094], [78.58409882, 25.3902607], [78.58834076, 25.39211273], [78.59163666, 25.39653969], [78.59461212, 25.40911293], [78.59895325, 25.41522026], [78.60349274, 25.41707039], [78.61435699, 25.41633034], [78.61692047, 25.41007042], [78.61921692, 25.40703964], [78.62362671, 25.4059906], [78.62858582, 25.40646172], [78.63379669, 25.4095211], [78.63680267, 25.41411018], [78.63749695, 25.41978836], [78.63250732, 25.4330101], [78.63365936, 25.43806076], [78.63883972, 25.44042969], [78.64541626, 25.43785095], [78.64901733, 25.44239235], [78.65271759, 25.44400024], [78.65796661, 25.44383049], [78.67041016, 25.43889046], [78.67488861, 25.43814087], [78.67751312, 25.43972969], [78.67893219, 25.44389915], [78.6816864, 25.44740105], [78.6857605, 25.44779015], [78.68924713, 25.44535065], [78.69332123, 25.43922043], [78.69983673, 25.43230057], [78.70140076, 25.42885971], [78.70024109, 25.42612076], [78.68448639, 25.41601181], [78.66909027, 25.40388107], [78.66493988, 25.40446091], [78.65930176, 25.4183712], [78.65651703, 25.42012978], [78.65367889, 25.41681099], [78.6520462, 25.41314125], [78.65666962, 25.4005394], [78.65688324, 25.39599037], [78.65592957, 25.39217186], [78.65789032, 25.38797951], [78.66117096, 25.38656044], [78.66493225, 25.38800049], [78.66940308, 25.39290047], [78.67376709, 25.39116096], [78.67352295, 25.38799095], [78.67156219, 25.38456154], [78.68386078, 25.38047981], [78.68717957, 25.3806324], [78.68914032, 25.3830204], [78.6905899, 25.38673973], [78.69275665, 25.38773918], [78.69610596, 25.38552856], [78.69711304, 25.38329124], [78.69982147, 25.38170052], [78.70903015, 25.37874985], [78.70976257, 25.37626839], [78.70455933, 25.36559105], [78.70361328, 25.36170006], [78.70384979, 25.3586483], [78.70944214, 25.35432053], [78.71362305, 25.3529892], [78.71794891, 25.35280991], [78.72112274, 25.3538208], [78.72524261, 25.35398293], [78.735672, 25.34919167], [78.74978638, 25.35211945], [78.75628662, 25.35750961], [78.76438141, 25.35840034], [78.76532745, 25.36044121], [78.76574707, 25.36477089], [78.76216125, 25.37437057], [78.76122284, 25.38216019], [78.75482178, 25.38619041], [78.75286102, 25.39034081], [78.75302887, 25.39195061], [78.75437164, 25.39307022], [78.75726318, 25.39252281], [78.75888824, 25.39352036], [78.75988007, 25.39775085], [78.75962067, 25.402071], [78.75863647, 25.40409088], [78.7546463, 25.40621948], [78.75115967, 25.40526962], [78.74754333, 25.4005394], [78.74349976, 25.39767075], [78.74156189, 25.39858055], [78.74030304, 25.40307045], [78.7405014, 25.40654182], [78.74314117, 25.41270065], [78.7454071, 25.4155407], [78.74938202, 25.41756058], [78.7562027, 25.41929817], [78.77604675, 25.42119026], [78.78823853, 25.42358017], [78.79046631, 25.42568016], [78.79464722, 25.4265995], [78.80766296, 25.42523956], [78.81138611, 25.42735291], [78.81291199, 25.43042755], [78.8117981, 25.43308067], [78.80345154, 25.43819046], [78.79528809, 25.44132805], [78.7894516, 25.44202042], [78.78218079, 25.43992043], [78.77629089, 25.43696976], [78.77207947, 25.4329319], [78.76537323, 25.43003273], [78.75997162, 25.43056107], [78.75506592, 25.43385124], [78.75180817, 25.43843079], [78.74812317, 25.44844055], [78.7436676, 25.45210075], [78.7323761, 25.45566177], [78.72766876, 25.4587307], [78.72464752, 25.46330833], [78.72631836, 25.49007034], [78.73175049, 25.50065041], [78.7360611, 25.50432968], [78.73931885, 25.49987984], [78.74154663, 25.48993111], [78.74359131, 25.48489189], [78.7494812, 25.48221016], [78.75654602, 25.47615051], [78.76051331, 25.47575951], [78.76432037, 25.4766407], [78.77297211, 25.48283005], [78.77677155, 25.48339081], [78.78172302, 25.48414993], [78.78952789, 25.48351288], [78.81019592, 25.47544098], [78.81526184, 25.47241974], [78.82549286, 25.46837044], [78.82985687, 25.46569061], [78.83339691, 25.46165085], [78.83590698, 25.45998955], [78.83764648, 25.45885086], [78.84211731, 25.45714951], [78.8457489, 25.45438957], [78.84200287, 25.45000267], [78.83718872, 25.44798088], [78.83268738, 25.44765282], [78.83036041, 25.44748116], [78.81645966, 25.44890976], [78.81387329, 25.44630814], [78.81569672, 25.44175911], [78.81973267, 25.43778038], [78.83097839, 25.43203163], [78.83426666, 25.43246078], [78.83660126, 25.43424988], [78.84533691, 25.44497108], [78.85369873, 25.45230103], [78.8572464, 25.46215248], [78.8571701, 25.4671402], [78.85164642, 25.47779083], [78.84880066, 25.48757172], [78.84603882, 25.4913826], [78.83071899, 25.49837112], [78.82699585, 25.50370026], [78.82832336, 25.50998116], [78.83394623, 25.51600075], [78.83673096, 25.51678848], [78.84120178, 25.51807022], [78.84706879, 25.51853943], [78.85128784, 25.51889038], [78.87600708, 25.5243206], [78.87837219, 25.52865982], [78.87757111, 25.53318977], [78.8684082, 25.54417992], [78.8690033, 25.55116081], [78.87435913, 25.55701256], [78.88109589, 25.5601902], [78.88276672, 25.56040955], [78.88553619, 25.56077003], [78.89678955, 25.55939102], [78.90595245, 25.56060028], [78.91036987, 25.55933952], [78.91332245, 25.54552078], [78.9168396, 25.54129028], [78.9185791, 25.54332161], [78.9204483, 25.54957008], [78.92263794, 25.55682945], [78.92568207, 25.5599575], [78.93074036, 25.55972099], [78.93566132, 25.55709076], [78.94168854, 25.55144119], [78.94381714, 25.54092026], [78.9418869, 25.53115082], [78.93844604, 25.52753067], [78.93224335, 25.52435112], [78.9196167, 25.52744293], [78.91726685, 25.52547073], [78.91638184, 25.52075005], [78.91668701, 25.51675034], [78.91918182, 25.51355171], [78.92617798, 25.50761032], [78.93315125, 25.4982605], [78.93518066, 25.49430084], [78.93612671, 25.48778152], [78.93563843, 25.48002052], [78.93003845, 25.46858978], [78.92745972, 25.46569061], [78.9197464, 25.46216011], [78.91340637, 25.4520607], [78.90631104, 25.4504509], [78.90322876, 25.44693756], [78.91259003, 25.43867111], [78.92913055, 25.42832947], [78.93415833, 25.4318924], [78.93782043, 25.43753815], [78.94258881, 25.44170189], [78.94696808, 25.44254112], [78.96012878, 25.43889046], [78.96248627, 25.43635941], [78.96891022, 25.42513275], [78.97022247, 25.42045975], [78.9655304, 25.41147995], [78.96817017, 25.39655113], [78.97106171, 25.39184952], [78.97580719, 25.38869095], [78.97840881, 25.38286018], [78.978508, 25.3760128], [78.97447205, 25.3725605], [78.95527649, 25.37308121], [78.94844055, 25.37000275], [78.93871307, 25.35283089], [78.92862701, 25.35180092], [78.9171524, 25.35999107], [78.90638733, 25.36338043], [78.8969574, 25.36520958], [78.89322662, 25.36901093], [78.89245605, 25.37529755], [78.89539337, 25.38079071], [78.90912628, 25.38056183], [78.92636871, 25.37734032], [78.93113708, 25.37712288], [78.93885803, 25.38907051], [78.94725037, 25.39318085], [78.95123291, 25.39645958], [78.94935608, 25.40015984], [78.94341278, 25.40312004], [78.9310379, 25.4031601], [78.92266846, 25.4004612], [78.9154129, 25.39962959], [78.91201019, 25.39699936], [78.90830994, 25.39237022], [78.90107727, 25.38925934], [78.89055634, 25.38883018], [78.88301849, 25.38951111], [78.87474823, 25.38765907], [78.86142731, 25.37702942], [78.8453598, 25.36091042], [78.83773804, 25.35217285], [78.83586121, 25.34703064], [78.8431778, 25.34208107], [78.84541321, 25.33867073], [78.84567261, 25.33518982], [78.84350586, 25.33236122], [78.84026337, 25.33185005], [78.83566284, 25.33298111], [78.8332901, 25.33134079], [78.82659912, 25.31985283], [78.8216629, 25.31874275], [78.81667328, 25.31657028], [78.81456757, 25.31096077], [78.81022644, 25.31085968], [78.79802704, 25.31452179], [78.79193878, 25.31479263], [78.78674316, 25.30972099], [78.78328705, 25.30318069], [78.7832489, 25.29761124], [78.78692627, 25.29494095], [78.79120636, 25.29301071], [78.79328918, 25.29310036], [78.80367279, 25.30199814], [78.80699158, 25.30297089], [78.81167603, 25.29984093], [78.81272125, 25.29776001], [78.81215668, 25.29409981], [78.80635071, 25.27946091], [78.80562592, 25.27093124], [78.81128693, 25.26600075], [78.82367706, 25.25107956], [78.83505249, 25.23320007], [78.8417511, 25.22916031], [78.84462738, 25.23110962], [78.84594727, 25.23378944], [78.85028839, 25.25342751], [78.85288239, 25.2588501], [78.85791779, 25.26624107], [78.86228943, 25.28313065], [78.87059021, 25.28486824], [78.87242889, 25.28820992], [78.87185669, 25.29179955], [78.86763763, 25.30134964], [78.86686707, 25.31098938], [78.85954285, 25.31455994], [78.85643768, 25.31695938], [78.85823822, 25.3208828], [78.86245728, 25.32460976], [78.87306976, 25.33082962], [78.87560272, 25.33401108], [78.87679291, 25.33921051], [78.87651825, 25.34445953], [78.87895966, 25.34687996], [78.88524628, 25.34669113], [78.89552307, 25.34351921], [78.9034729, 25.3400898], [78.90788269, 25.33940125], [78.91121674, 25.34213066], [78.91467285, 25.34644127], [78.91886902, 25.34599113], [78.92453003, 25.34192848], [78.92546082, 25.33843994], [78.92537689, 25.33457947], [78.9276123, 25.33171082], [78.93122864, 25.33241272], [78.93547058, 25.33620071], [78.94277954, 25.34511948], [78.94581604, 25.34725952], [78.94999695, 25.34827995], [78.95285797, 25.34987068], [78.9557724, 25.34776115], [78.95202637, 25.31738091], [78.95279694, 25.3118782], [78.97027588, 25.29109192], [78.970047, 25.28520966], [78.96469879, 25.2838707], [78.95384979, 25.28562927], [78.94754028, 25.28370094], [78.94378662, 25.28007126], [78.94447327, 25.27544975], [78.94799042, 25.2717495], [78.94838715, 25.2659111], [78.94618225, 25.26377106], [78.94061279, 25.26268959], [78.93643951, 25.26267815], [78.93348694, 25.26354027], [78.92581177, 25.26782036], [78.92276764, 25.27148056], [78.91828918, 25.27517128], [78.91520691, 25.27569008], [78.90859985, 25.27436066], [78.89644623, 25.24994087], [78.89169312, 25.24546051], [78.88456726, 25.24723053], [78.88022614, 25.25362015], [78.87587738, 25.25576973], [78.87217712, 25.25078964], [78.86725616, 25.23769188], [78.86707306, 25.23254013], [78.87325287, 25.22608185], [78.88162231, 25.21547127], [78.88241577, 25.21105957], [78.88011932, 25.20589828], [78.8757019, 25.20014954], [78.87104797, 25.19616127], [78.86738586, 25.18996048], [78.86759949, 25.18634033], [78.86979675, 25.18291283], [78.86921692, 25.17811966], [78.87325287, 25.17200279], [78.87184143, 25.16600037], [78.87393188, 25.16327095], [78.87713623, 25.16218185], [78.89340973, 25.17322922], [78.9006424, 25.18053818], [78.90159607, 25.18326187], [78.90804291, 25.19352913], [78.91529083, 25.20259094], [78.91916656, 25.2062397], [78.92423248, 25.2105999], [78.94235992, 25.21836281], [78.94834137, 25.22018051], [78.95284271, 25.22069168], [78.96392059, 25.21943092], [78.96920776, 25.21663284], [78.97767639, 25.20420074], [78.98240662, 25.19915009], [78.98774719, 25.19677925], [78.99275208, 25.19652176], [78.99581146, 25.19593811], [78.99733734, 25.19828987], [78.99749756, 25.2075901], [79.00035858, 25.2160511], [78.99330902, 25.22221947], [78.99453735, 25.22545052], [78.99500275, 25.23228073], [78.99466705, 25.23374939], [78.99269867, 25.23500252], [78.98741913, 25.23592949], [78.97231293, 25.24283028], [78.97116852, 25.24492073], [78.97331238, 25.25368118], [78.97722626, 25.2616806], [78.98677063, 25.27495956], [78.99265289, 25.27773094], [79.00496674, 25.27696991], [79.01235962, 25.27404022], [79.01431274, 25.27103043], [79.01599121, 25.26515007], [79.01167297, 25.25284958], [79.01161957, 25.24933052], [79.01212311, 25.24824905], [79.01474762, 25.24775124], [79.02937317, 25.24934006], [79.03103638, 25.24628067], [79.0283432, 25.24102974], [79.02648163, 25.23467064], [79.04506683, 25.23063087], [79.05232239, 25.22813034], [79.05644226, 25.22570992], [79.05673981, 25.21922112], [79.05513, 25.21722031], [79.04847717, 25.20979118], [79.04277802, 25.21014023], [79.02459717, 25.18657112], [79.02572632, 25.18259048], [79.02796173, 25.1803112], [79.03144836, 25.17850113], [79.03578186, 25.1739006], [79.02523804, 25.15579033], [79.02162933, 25.14693069], [79.02176666, 25.14319038], [79.02823639, 25.13993073], [79.0355072, 25.13784027], [79.03888702, 25.13722992], [79.04305267, 25.13817024], [79.04889679, 25.14751053], [79.0545578, 25.14887047], [79.05805206, 25.15081978], [79.06285858, 25.16274261], [79.06407928, 25.17249107], [79.07025909, 25.17776108], [79.08429718, 25.19252968], [79.08722687, 25.18783951], [79.08841705, 25.18372917], [79.08872986, 25.17832947], [79.09057617, 25.17622948], [79.10256195, 25.17119026], [79.10710907, 25.16814041], [79.11920929, 25.1634407], [79.12042236, 25.16418076], [79.11859131, 25.15839195], [79.10781097, 25.14369965], [79.1247406, 25.12957954], [79.12510681, 25.12921906], [79.11482239, 25.11779976], [79.12084961, 25.11340141], [79.12433624, 25.11186981], [79.12917328, 25.11076927], [79.13337708, 25.1110611], [79.13820648, 25.11841011], [79.14480591, 25.1165905], [79.15661621, 25.11190033], [79.16887665, 25.11186028], [79.17236328, 25.11847115], [79.17411804, 25.11903], [79.17930603, 25.11769295], [79.17987823, 25.12882996], [79.16879272, 25.13157082], [79.16652679, 25.13953018], [79.16677856, 25.14234924], [79.16837311, 25.14530754], [79.17730713, 25.14595032], [79.18110657, 25.14762115], [79.1848526, 25.15113258], [79.18768311, 25.15092278], [79.1889801, 25.14935112], [79.19010925, 25.14565086], [79.19373322, 25.1436615], [79.19671631, 25.14293098], [79.19632721, 25.13804817], [79.19616699, 25.13167], [79.19793701, 25.12818909], [79.20709991, 25.12439156], [79.20638275, 25.1137619], [79.21067047, 25.11445045], [79.21369934, 25.11647987], [79.21843719, 25.11819077], [79.22010803, 25.12099075], [79.22278595, 25.12325096], [79.22598267, 25.12240982], [79.23488617, 25.11746025], [79.23838043, 25.11636925], [79.2396698, 25.11783981], [79.24014282, 25.12018967], [79.23810577, 25.12672043], [79.23767853, 25.13133049], [79.24353027, 25.14079094], [79.24151611, 25.14092064], [79.23980713, 25.14273071], [79.2375412, 25.1428299], [79.2248764, 25.14023018], [79.22408295, 25.14082909], [79.22399139, 25.14318085], [79.22252655, 25.14562035], [79.21391296, 25.14838028], [79.21965027, 25.15456963], [79.22518158, 25.1581707], [79.23583984, 25.16096115], [79.24584198, 25.1619606], [79.25060272, 25.16120911], [79.2559967, 25.15728188], [79.25920105, 25.15327263], [79.25934601, 25.14694023], [79.25836182, 25.14390945], [79.26194763, 25.14191055], [79.26207733, 25.14115906], [79.25454712, 25.13046074], [79.25807953, 25.12401962], [79.2600708, 25.12210083], [79.26875305, 25.12623024], [79.26999664, 25.12615013], [79.27381897, 25.12168121], [79.27654266, 25.12026024], [79.28218079, 25.13352013], [79.29110718, 25.13125992], [79.30098724, 25.13083076], [79.30322266, 25.13332939], [79.30570984, 25.13990021], [79.31388855, 25.15096092], [79.31453705, 25.15187836], [79.31060028, 25.16090012], [79.30874634, 25.16512108], [79.30188751, 25.17534065], [79.29077911, 25.18390083], [79.28872681, 25.18626976], [79.28351593, 25.18946075], [79.27880096, 25.19739914], [79.27777863, 25.20351028], [79.27802277, 25.21063995], [79.27963257, 25.22171021], [79.28106689, 25.22434044], [79.28148651, 25.22714043], [79.27822876, 25.23829079], [79.27416992, 25.24518967], [79.27391052, 25.24650002], [79.27359772, 25.24811935], [79.27855682, 25.24782944], [79.28401184, 25.24650002], [79.29332733, 25.24020004], [79.29782104, 25.23444939], [79.30047607, 25.22744942], [79.30858612, 25.22319031], [79.31078339, 25.21948051], [79.31339264, 25.21955109], [79.31491089, 25.21960068], [79.3229599, 25.22274971], [79.32433319, 25.22257042], [79.32534027, 25.22244072], [79.32508087, 25.21387291], [79.32578278, 25.21081161], [79.32656097, 25.20850945], [79.3325882, 25.20083046], [79.34337616, 25.20998955], [79.34696198, 25.21424103], [79.33490753, 25.22286987], [79.32911682, 25.22990036], [79.33078003, 25.23207092], [79.33197784, 25.23200035], [79.33953094, 25.22809029], [79.34111786, 25.23048973], [79.34127808, 25.2390995], [79.34028625, 25.24308014], [79.34086609, 25.25607109], [79.34129333, 25.25864983], [79.3445282, 25.26429939], [79.34008789, 25.27276039], [79.33789825, 25.27318764], [79.33454132, 25.27571106], [79.33190155, 25.27626991], [79.32338715, 25.26684952], [79.31873322, 25.26307106], [79.31468964, 25.26139259], [79.31004333, 25.26192093], [79.30391693, 25.26540184], [79.29830933, 25.27577019], [79.28775024, 25.29024124], [79.28646088, 25.28107071], [79.27787018, 25.27100182], [79.27529907, 25.26929092], [79.27111053, 25.26650238], [79.26877594, 25.26646042], [79.26566315, 25.26639938], [79.26196289, 25.26773071], [79.25945282, 25.27144051], [79.25901031, 25.27420998], [79.25650787, 25.27947044], [79.25627899, 25.28211975], [79.25683594, 25.28499031], [79.25601196, 25.29171944], [79.25798798, 25.29837036], [79.26013947, 25.31023979], [79.26760101, 25.31875038], [79.27651978, 25.32703018], [79.27760315, 25.32805061], [79.28341675, 25.33008957], [79.2913208, 25.32928848], [79.29371643, 25.33236122], [79.29408264, 25.33937073], [79.29473114, 25.3402195], [79.30422211, 25.33984947], [79.30930328, 25.33856964], [79.32512665, 25.33724976], [79.33023071, 25.3337307], [79.3337326, 25.33258057], [79.34458923, 25.33444977], [79.34588623, 25.33304024], [79.33837891, 25.32492828], [79.33448029, 25.31739807], [79.33769989, 25.31090927], [79.3414917, 25.30768967], [79.34187317, 25.30458069], [79.33075714, 25.29404831], [79.33104706, 25.29277992], [79.33164978, 25.29257965], [79.33249664, 25.29230118], [79.34308624, 25.29042053], [79.34970856, 25.28841972], [79.35161591, 25.27799034], [79.35109711, 25.26995087], [79.35296631, 25.26538086], [79.35829926, 25.26351929], [79.36168671, 25.26427078], [79.36573792, 25.26807022], [79.36724091, 25.27242088], [79.36717224, 25.27557945], [79.36444855, 25.29252052], [79.36741638, 25.29432106], [79.36975098, 25.29409981], [79.37256622, 25.2933197], [79.37561798, 25.29109955], [79.37931061, 25.28672028], [79.38353729, 25.28360939], [79.38600159, 25.28415108], [79.38861084, 25.28624916], [79.39229584, 25.28486061], [79.40188599, 25.2792511], [79.40122223, 25.26235962], [79.41530609, 25.25922012], [79.42665863, 25.25842285], [79.43121338, 25.25955009], [79.45157623, 25.27360916], [79.4527359, 25.27526855], [79.45307159, 25.28256035], [79.45741272, 25.2838707], [79.47312164, 25.2821312], [79.4752121, 25.27917099], [79.47525024, 25.27749062], [79.47527313, 25.27671051], [79.47532654, 25.27487946], [79.4763031, 25.27316093], [79.47772217, 25.27238274], [79.48446655, 25.27273941], [79.49040222, 25.2703495], [79.49082947, 25.26901054], [79.48973846, 25.26564026], [79.48396301, 25.26498032], [79.47911835, 25.26516914], [79.47453308, 25.26657295], [79.46401215, 25.26799965], [79.46070099, 25.26960945], [79.45919037, 25.26945114], [79.45522308, 25.26521111], [79.45285034, 25.25650024], [79.44834137, 25.25081062], [79.44490814, 25.24811935], [79.44358826, 25.2486496], [79.4417572, 25.25172043], [79.43855286, 25.24827194], [79.43418121, 25.24178123], [79.43297577, 25.23600006], [79.42701721, 25.22503853], [79.43231201, 25.22180176], [79.44239807, 25.22095108], [79.44270325, 25.21256065], [79.43578339, 25.20465851], [79.43213654, 25.20277977], [79.42800903, 25.20353127], [79.42617798, 25.20305824], [79.42460632, 25.20264816], [79.42125702, 25.20323944], [79.41734314, 25.20392036], [79.40957642, 25.20876122], [79.40809631, 25.20751953], [79.40455627, 25.19947052], [79.40421295, 25.19441032], [79.40389252, 25.18958092], [79.39150238, 25.17964935], [79.38387299, 25.17028046], [79.38006592, 25.15372086], [79.38022614, 25.14912033], [79.38212585, 25.14593124], [79.38389587, 25.14003944], [79.38704681, 25.13614273], [79.38873291, 25.13162994], [79.38928986, 25.12058067], [79.39080811, 25.11790276], [79.39317322, 25.1161499], [79.39914703, 25.11346054], [79.40196991, 25.11335945], [79.40918732, 25.11565971], [79.41496277, 25.12299919], [79.41710663, 25.12726974], [79.418396, 25.13352013], [79.4178009, 25.1350708], [79.41477203, 25.13736916], [79.41512299, 25.13909912], [79.41760254, 25.1384697], [79.42590332, 25.13839912], [79.43113708, 25.13540077], [79.43297577, 25.13141823], [79.43525696, 25.1265316], [79.4344101, 25.12170029], [79.43344879, 25.12000084], [79.43115997, 25.11594963], [79.42945862, 25.1117897], [79.42951965, 25.11148262], [79.42990875, 25.10913277], [79.43067169, 25.10806084], [79.43106842, 25.10750961], [79.43637085, 25.10782051], [79.44478607, 25.11309052], [79.45022583, 25.11783028], [79.45656586, 25.12499046], [79.46837616, 25.13445091], [79.46951294, 25.13404083], [79.4701767, 25.13380051], [79.4701767, 25.13068008], [79.46053314, 25.09633064], [79.4715271, 25.08719063], [79.48243713, 25.08510971], [79.48987579, 25.08275032], [79.49106598, 25.08329964], [79.49112701, 25.08488274], [79.49118042, 25.08612251], [79.4937973, 25.0920105], [79.50016022, 25.0992012], [79.50527191, 25.10130119], [79.5133667, 25.10025024], [79.51535797, 25.10104179], [79.51722717, 25.10178757], [79.51828766, 25.10443115], [79.51815796, 25.10770035], [79.51394653, 25.12210083], [79.51377106, 25.12572289], [79.51795959, 25.1312294], [79.52658844, 25.13563919], [79.52868652, 25.13738251], [79.52857971, 25.13801193], [79.52731323, 25.14310074], [79.52864838, 25.14497948], [79.53363037, 25.14644051], [79.53494263, 25.14762115], [79.53795624, 25.15262985], [79.5427475, 25.16055107], [79.55033875, 25.16940117], [79.5595932, 25.17597008], [79.56552124, 25.17755127], [79.56893921, 25.17552185], [79.57396698, 25.15945053], [79.5762558, 25.15705109], [79.58573914, 25.15286255], [79.58969879, 25.14727974], [79.59052277, 25.14680099], [79.59144592, 25.14627075], [79.59233856, 25.14631081], [79.59326935, 25.14635086], [79.60003662, 25.15497971], [79.60280609, 25.1547699], [79.60279083, 25.15384293], [79.60276794, 25.15310097], [79.59854889, 25.1453495], [79.59748077, 25.13955116], [79.59541321, 25.13562012], [79.59516907, 25.13413239], [79.5978775, 25.13143158], [79.60209656, 25.1313591], [79.60514832, 25.13223076], [79.60608673, 25.13249969], [79.62003326, 25.14266968], [79.63285065, 25.13282967], [79.6378479, 25.13108063], [79.64070129, 25.13239861], [79.64302826, 25.13236046], [79.65419006, 25.1304512], [79.65659332, 25.12951279], [79.66053772, 25.12796021], [79.66616821, 25.12712097], [79.67079163, 25.13208961], [79.67418671, 25.13577843], [79.6765976, 25.13698959], [79.68698883, 25.13686943], [79.70728302, 25.13331985], [79.71776581, 25.13381958], [79.72455597, 25.13540077], [79.72603607, 25.13573265], [79.73957825, 25.14295959], [79.74563599, 25.14388275], [79.74781799, 25.14260101], [79.75110626, 25.14066124], [79.75772095, 25.13452911], [79.76274872, 25.12982941], [79.76921844, 25.1252594], [79.78833771, 25.12039185], [79.79325104, 25.11837959], [79.80516815, 25.11097908], [79.81640625, 25.11086273], [79.8187027, 25.11015129], [79.82327271, 25.10640907], [79.82434082, 25.10370064], [79.8272171, 25.10012054], [79.8312912, 25.0981102], [79.84085846, 25.09639931], [79.84921265, 25.09698105], [79.855896, 25.09850121], [79.85309601, 25.10275078], [79.84580994, 25.11046982], [79.84268188, 25.1163311], [79.84657288, 25.12227058], [79.84796906, 25.12823105], [79.84767151, 25.13339043], [79.85161591, 25.13977814], [79.85740662, 25.14281082], [79.86483002, 25.14499283], [79.87217712, 25.14851189], [79.87210083, 25.15030289], [79.86300659, 25.15390968], [79.86058807, 25.15606117], [79.85965729, 25.16205025], [79.86260223, 25.17696953], [79.86154175, 25.17906952], [79.85810852, 25.18185806], [79.85878754, 25.19022942], [79.8547821, 25.19909286], [79.85185242, 25.20347977], [79.85411835, 25.21042061], [79.85618591, 25.2136097], [79.86303711, 25.2191906], [79.86136627, 25.22095108], [79.85285187, 25.2250309], [79.84716034, 25.23241043], [79.8452301, 25.23655128], [79.84572601, 25.23838234], [79.84713745, 25.24020004], [79.8509903, 25.24156952], [79.85755157, 25.2419014], [79.86097717, 25.24299049], [79.86595917, 25.24682045], [79.87245941, 25.25379181], [79.87500763, 25.25299072], [79.8866272, 25.24641037], [79.89360046, 25.2462101], [79.89615631, 25.24753952], [79.8972702, 25.24959946], [79.89834595, 25.25510025], [79.89962006, 25.25657082], [79.90239716, 25.25691986], [79.90532684, 25.25547028], [79.90629578, 25.25418091], [79.91056061, 25.24497986], [79.91062927, 25.23604965], [79.91220856, 25.23376274], [79.91345215, 25.2334404], [79.92099762, 25.25070953], [79.92410278, 25.25155067], [79.93257141, 25.25032043], [79.93196106, 25.25985909], [79.93332672, 25.26301956], [79.93437958, 25.26486969], [79.94095612, 25.26971054], [79.94256592, 25.2718792], [79.94921875, 25.26530075], [79.96304321, 25.26824951], [79.96717072, 25.26847076], [79.96951294, 25.26816177], [79.97727966, 25.26494026], [79.99221039, 25.26930046], [79.99672699, 25.26865005], [79.99733734, 25.27013016], [79.99534607, 25.27466011], [79.99559784, 25.27672958], [79.9921875, 25.28098106], [79.99125671, 25.28316116], [79.99220276, 25.28524971], [79.99385834, 25.28884125], [79.998703, 25.29376984], [80.0083313, 25.30067825], [80.01264954, 25.30171967], [80.00991058, 25.32475281], [80.01265717, 25.33011055], [80.01449585, 25.33111], [80.02073669, 25.34316063], [80.02419281, 25.34459114], [80.0371933, 25.34096909], [80.04444122, 25.34185028], [80.05486298, 25.34129906], [80.06150055, 25.34204102], [80.07002258, 25.34309959], [80.07234192, 25.34509087], [80.07839966, 25.35344124], [80.08329773, 25.35583115], [80.09337616, 25.35383034], [80.09609222, 25.35157967], [80.106987, 25.34418106], [80.119133, 25.34269905], [80.12329865, 25.3384304], [80.12708282, 25.34061813], [80.13273621, 25.35032082], [80.13712311, 25.35573006], [80.14496613, 25.36010933], [80.15315247, 25.3628006], [80.15912628, 25.36619949], [80.15828705, 25.37265968], [80.15917969, 25.37764931], [80.16668701, 25.37895012], [80.17201233, 25.38069153], [80.18261719, 25.38151932], [80.18789673, 25.38364983], [80.18916321, 25.38922119], [80.18882751, 25.4064312], [80.19093323, 25.40904045], [80.19143677, 25.41271019], [80.19391632, 25.41623116], [80.19724274, 25.4149704], [80.19832611, 25.41269112], [80.19786835, 25.41056061], [80.20244598, 25.40673065], [80.21137238, 25.40394974], [80.2140274, 25.40423012], [80.22657776, 25.41064072], [80.22956085, 25.4109211], [80.24518585, 25.40489006], [80.24739838, 25.40738106], [80.24730682, 25.41146088], [80.25241089, 25.41877174], [80.253479, 25.42346954], [80.255867, 25.42871094], [80.26123047, 25.42617989], [80.27372742, 25.42503929], [80.28431702, 25.41588974], [80.28964233, 25.41271973], [80.29532623, 25.40776062], [80.30857849, 25.39233017], [80.30905151, 25.39183998], [80.31075287, 25.38731766], [80.31121063, 25.3810997], [80.31324768, 25.37225914], [80.30861664, 25.36372948], [80.30536652, 25.36207962], [80.30262756, 25.35828018], [80.30358887, 25.35251236], [80.30980682, 25.34127045], [80.31173706, 25.33420944], [80.31069183, 25.31065178], [80.30912018, 25.30585098], [80.30267334, 25.29696083], [80.30307007, 25.2911396], [80.30404663, 25.28889275], [80.31201172, 25.28215027], [80.31983948, 25.28049088], [80.33766174, 25.27941132], [80.3409729, 25.27860069], [80.34926605, 25.26955032], [80.35041046, 25.2652626], [80.35173798, 25.26024055], [80.35359192, 25.25638962], [80.35771179, 25.25113106], [80.36289215, 25.24682999], [80.37802887, 25.23751068], [80.3813324, 25.23829842], [80.3829422, 25.24195099], [80.39070129, 25.24568748], [80.39906311, 25.24296951], [80.4016571, 25.22095108], [80.40423584, 25.21404076], [80.4095459, 25.20586014], [80.41162872, 25.19943047], [80.41812897, 25.19192123], [80.42237854, 25.18136024], [80.42369843, 25.17414284], [80.42256927, 25.17221069], [80.41548157, 25.16529274], [80.40358734, 25.16505051], [80.3867569, 25.16288185], [80.38066864, 25.16077995], [80.37343597, 25.15517807], [80.36245728, 25.14973068], [80.35614777, 25.14841843], [80.35128784, 25.14490128], [80.34861755, 25.14069176], [80.34752655, 25.13002014], [80.34411621, 25.12491989], [80.33835602, 25.12125015], [80.32283783, 25.1066494], [80.31327057, 25.10117149], [80.31472015, 25.0940609], [80.3132019, 25.0892601], [80.31051636, 25.08195114], [80.30478668, 25.07551003], [80.2947464, 25.06909943], [80.2876358, 25.06689072], [80.28195953, 25.06322098], [80.28157043, 25.06005096], [80.28115845, 25.05673981], [80.27941132, 25.05267906], [80.27780151, 25.04397964], [80.2771759, 25.04294014], [80.27487946, 25.03903961], [80.27327728, 25.0371418], [80.27078247, 25.03417969], [80.26876831, 25.03269958], [80.26727295, 25.0316124], [80.26693726, 25.03024292], [80.27849579, 25.02164841], [80.28919983, 25.02114105], [80.29897308, 25.01603127], [80.31236267, 25.00629807], [80.31278229, 25.00432014], [80.31410217, 25.00350952], [80.31462097, 25.00342178], [80.31511688, 25.0033493], [80.31564331, 25.0032692], [80.31614685, 25.00320053], [80.31665039, 25.0031414], [80.31716919, 25.0030899], [80.31768036, 25.00303078], [80.31819916, 25.0030117], [80.31871033, 25.00296974], [80.31922913, 25.00294113], [80.31973267, 25.00291824], [80.32025909, 25.00291061], [80.32079315, 25.00291061], [80.32128143, 25.00290108], [80.3217926, 25.00291061], [80.32231903, 25.00291061], [80.32285309, 25.00294113], [80.323349, 25.00296021], [80.32388306, 25.00298119], [80.3243866, 25.00303078], [80.32491302, 25.00307083], [80.32594299, 25.00311089], [80.32739258, 25.00434113], [80.3289566, 25.00543022], [80.33798218, 25.02094078], [80.34456635, 25.01947021], [80.34793854, 25.01646805], [80.35257721, 25.01988029], [80.35507202, 25.02449036], [80.35884857, 25.02607918], [80.36782074, 25.02543068], [80.36885834, 25.02383995], [80.36921692, 25.01888084], [80.37283325, 25.00832939], [80.38218689, 25.00974083], [80.38739014, 25.01242065], [80.38915253, 25.01490974], [80.38304138, 25.01869011], [80.38088226, 25.02765846], [80.37612915, 25.02799988], [80.3723526, 25.02918053], [80.37177277, 25.03276062], [80.37287903, 25.03470039], [80.3747406, 25.03660011], [80.37831116, 25.03680992], [80.38043213, 25.03890038], [80.38020325, 25.04160118], [80.37906647, 25.04440117], [80.37520599, 25.0456295], [80.36750793, 25.04609108], [80.36406708, 25.04771996], [80.36627197, 25.05307961], [80.3657608, 25.05776024], [80.36724854, 25.05886078], [80.3792572, 25.05595016], [80.38347626, 25.0616703], [80.38414764, 25.06534004], [80.38640594, 25.0673008], [80.38944244, 25.0682106], [80.39412689, 25.07202148], [80.39807892, 25.06928062], [80.39746857, 25.06562042], [80.40268707, 25.06095123], [80.40525055, 25.06085014], [80.40677643, 25.06344986], [80.40991974, 25.07671928], [80.42272949, 25.07131958], [80.42450714, 25.07150078], [80.42951202, 25.07254028], [80.4311676, 25.07394028], [80.43292236, 25.07839012], [80.43509674, 25.0809803], [80.44071198, 25.0820694], [80.4417572, 25.08101273], [80.44428253, 25.0812912], [80.44513702, 25.08017159], [80.44342041, 25.07733917], [80.44164276, 25.07600021], [80.44225311, 25.07328033], [80.44464111, 25.07081032], [80.44420624, 25.06817055], [80.445961, 25.06583023], [80.45297241, 25.06878281], [80.45593262, 25.07382011], [80.45996857, 25.06970024], [80.46142578, 25.05798912], [80.4701767, 25.04469109], [80.47331238, 25.04358292], [80.47693634, 25.04388809], [80.47901154, 25.04434967], [80.48314667, 25.04725075], [80.48583221, 25.04730988], [80.49420929, 25.04532051], [80.49317169, 25.05431938], [80.49724579, 25.0560112], [80.50019836, 25.05877113], [80.50231934, 25.06286049], [80.5021286, 25.06735039], [80.50007629, 25.07097054], [80.49059296, 25.07821083], [80.49453735, 25.07956123], [80.49842834, 25.08257103], [80.49997711, 25.08955956], [80.49777222, 25.09139061], [80.49433136, 25.09205055], [80.48729706, 25.09180069], [80.47759247, 25.09641266], [80.47471619, 25.09906006], [80.47447968, 25.10182953], [80.47612762, 25.10225105], [80.48030853, 25.10157967], [80.48391724, 25.10281944], [80.49212646, 25.10223007], [80.49471283, 25.10494041], [80.50190735, 25.10413933], [80.50950623, 25.10102081], [80.51288605, 25.0982399], [80.51425934, 25.09577751], [80.51515961, 25.08846092], [80.51731873, 25.08479118], [80.51899719, 25.08193016], [80.52812958, 25.07705116], [80.53203583, 25.07591057], [80.53882599, 25.06965828], [80.54341888, 25.06766129], [80.54676819, 25.06797028], [80.54862213, 25.06931114], [80.55245209, 25.06928062], [80.55536652, 25.07089806], [80.55766296, 25.07292175], [80.55999756, 25.07498932], [80.56117249, 25.07928276], [80.56109619, 25.08876991], [80.56243896, 25.0914402], [80.56562805, 25.08718109], [80.56804657, 25.08528137], [80.57263947, 25.08580017], [80.57866669, 25.08826256], [80.58011627, 25.08695984], [80.58757782, 25.08587074], [80.58872223, 25.08434105], [80.5932312, 25.08152962], [80.59594727, 25.07818031], [80.60452271, 25.07262993], [80.60678101, 25.07217979], [80.60710144, 25.07273293], [80.60730743, 25.07308006], [80.60675812, 25.07620049], [80.60002136, 25.09075165], [80.59435272, 25.09295082], [80.59333801, 25.09420967], [80.59188843, 25.09600258], [80.58777618, 25.10910034], [80.59137726, 25.11799049], [80.59642029, 25.12202072], [80.60144806, 25.12281036], [80.60037994, 25.1253109], [80.59757233, 25.1281395], [80.59075928, 25.13158035], [80.59011078, 25.13482094], [80.59105682, 25.14129066], [80.59458923, 25.15524101], [80.59960938, 25.15546989], [80.60269928, 25.1523819], [80.60578918, 25.14928055], [80.6056366, 25.14278984], [80.60547638, 25.13635063], [80.6083374, 25.13294983], [80.6159668, 25.13812065], [80.62245178, 25.13606071], [80.62496185, 25.13767052], [80.62802124, 25.13029099], [80.63239288, 25.12328148], [80.63123322, 25.11980057], [80.62229919, 25.12202072], [80.61923218, 25.12021065], [80.61875153, 25.11808014], [80.61823273, 25.11580086], [80.61476898, 25.11386108], [80.61506653, 25.11120987], [80.61329651, 25.10654068], [80.60682678, 25.1065197], [80.60135651, 25.10440826], [80.60655212, 25.10157967], [80.6084671, 25.09860039], [80.617836, 25.09366035], [80.62004089, 25.08958054], [80.62230682, 25.08929062], [80.62195587, 25.09338951], [80.62354279, 25.09519958], [80.62516785, 25.09555817], [80.62861633, 25.09328842], [80.63391876, 25.09379959], [80.63434601, 25.09717941], [80.63523865, 25.09756088], [80.63574982, 25.09605026], [80.63645172, 25.09395981], [80.6414566, 25.09314919], [80.64554596, 25.0906105], [80.65052795, 25.08753014], [80.65373993, 25.07645988], [80.65629578, 25.07444191], [80.66422272, 25.07839012], [80.66580963, 25.08019066], [80.66610718, 25.08053017], [80.66670227, 25.08426285], [80.66828918, 25.08675194], [80.67926025, 25.08181953], [80.67896271, 25.07578087], [80.67788696, 25.07310104], [80.67421722, 25.0680809], [80.67180634, 25.06732941], [80.67192078, 25.06456947], [80.67507935, 25.06253052], [80.67465973, 25.06019974], [80.67356873, 25.05417061], [80.67829895, 25.05457115], [80.68688965, 25.05879021], [80.69801331, 25.06155014], [80.70533752, 25.06142044], [80.70831299, 25.06492996], [80.70948792, 25.06632042], [80.71096039, 25.06726265], [80.7144165, 25.06775284], [80.72720337, 25.07182121], [80.72921753, 25.06553268], [80.7335968, 25.06244087], [80.74410248, 25.06233025], [80.7514267, 25.06399918], [80.75566864, 25.06257057], [80.76595306, 25.06114006], [80.77593994, 25.06169128], [80.77825928, 25.06386948], [80.7813797, 25.069561], [80.77961731, 25.07786942], [80.77597809, 25.08430099], [80.76703644, 25.08559036], [80.75112152, 25.09111977], [80.75100708, 25.09428978], [80.75205231, 25.09540939], [80.74931335, 25.09777069], [80.74577332, 25.09939957], [80.73343658, 25.1013298], [80.72931671, 25.09729767], [80.72524261, 25.09795952], [80.72049713, 25.10139275], [80.7190094, 25.10402107], [80.7199173, 25.11725807], [80.72537231, 25.12288284], [80.72244263, 25.12599182], [80.71730042, 25.1289196], [80.70746613, 25.12743187], [80.7008667, 25.12803841], [80.69847107, 25.13137245], [80.69963837, 25.13714981], [80.70092773, 25.1380806], [80.71061707, 25.13844109], [80.71478271, 25.14328003], [80.71530914, 25.14665985], [80.71763611, 25.14660072], [80.72305298, 25.14878273], [80.7277298, 25.14740181], [80.72865295, 25.14289856], [80.73227692, 25.14236259], [80.73206329, 25.14052963], [80.73545837, 25.13521957], [80.73809814, 25.13459969], [80.74043274, 25.13741112], [80.75086212, 25.14170074], [80.75956726, 25.14059067], [80.76605988, 25.14088821], [80.77403259, 25.1466198], [80.7766571, 25.14484024], [80.78214264, 25.13708115], [80.78369904, 25.13836288], [80.78613281, 25.13796043], [80.7906723, 25.14273071], [80.79367065, 25.14232063], [80.79786682, 25.14624023], [80.79957581, 25.14641762], [80.8032074, 25.1435318], [80.80828094, 25.14081955], [80.80771637, 25.13310051], [80.80961609, 25.13070107], [80.81864166, 25.13055038], [80.82139587, 25.12560081], [80.82168579, 25.12285042], [80.82151794, 25.1200428], [80.82315826, 25.11777115], [80.82393646, 25.11465263], [80.82769775, 25.1103096], [80.83344269, 25.11327171], [80.8377533, 25.12751007], [80.83479309, 25.13252068], [80.83209991, 25.14141083], [80.83384705, 25.14561272], [80.83744049, 25.16031075], [80.84188843, 25.16794014], [80.84230042, 25.1711998], [80.84111023, 25.17525291], [80.83589172, 25.18540955], [80.83515167, 25.19046974], [80.83628082, 25.19268036], [80.84108734, 25.19347954], [80.84858704, 25.19003105], [80.86036682, 25.1905899], [80.86315155, 25.18921089], [80.86416626, 25.18786049], [80.86953735, 25.18865967], [80.8780365, 25.19560051], [80.8861618, 25.17717171], [80.88902283, 25.17469025], [80.89597321, 25.17126083], [80.90556335, 25.16448021], [80.90492249, 25.16031075], [80.90157318, 25.15797997], [80.89029694, 25.14635086], [80.8884201, 25.14123917], [80.88526917, 25.14001274], [80.87541962, 25.14443016], [80.87275696, 25.13389015], [80.8690033, 25.12791061], [80.86585236, 25.12552071], [80.8649826, 25.1236496], [80.86650848, 25.11943054], [80.87224579, 25.10930061], [80.87298584, 25.10256958], [80.87121582, 25.09824944], [80.86730957, 25.09402084], [80.86425018, 25.08815956], [80.86480713, 25.08434105], [80.87507629, 25.07953835], [80.87065125, 25.07105064], [80.8557663, 25.06244087], [80.84687042, 25.05327988], [80.84113312, 25.05127907], [80.83522034, 25.03968048], [80.82668304, 25.03919029], [80.82911682, 25.02997971], [80.84005737, 25.02021027], [80.84192657, 25.0125103], [80.85025024, 25.0031414], [80.84818268, 24.99814034], [80.845047, 24.99349976], [80.83640289, 24.98608971], [80.82470703, 24.9860611], [80.82109833, 24.98250008], [80.81864166, 24.97363091], [80.81257629, 24.97367096], [80.8065033, 24.97500992], [80.79879761, 24.97489166], [80.79360962, 24.97365189], [80.78999329, 24.97178268], [80.78994751, 24.96718025], [80.79164124, 24.96391106], [80.80290985, 24.9569397], [80.80220032, 24.94445992], [80.81542969, 24.93790817], [80.82081604, 24.93659019], [80.82901001, 24.93844986], [80.83490753, 24.93452835], [80.84091949, 24.93556023], [80.85661316, 24.93595123], [80.87500763, 24.94071007], [80.87684631, 24.94506073], [80.88123322, 24.94820023], [80.88482666, 24.94889069], [80.88870239, 24.9474411], [80.8948288, 24.94244003], [80.89795685, 24.94169044], [80.9000473, 24.93958092], [80.90278625, 24.94016075], [80.90119934, 24.94334984], [80.89331818, 24.95046043], [80.89431763, 24.95389938], [80.89730072, 24.95672035], [80.91152191, 24.96228027], [80.91596222, 24.96479034], [80.92162323, 24.96657944], [80.9284668, 24.96769905], [80.93374634, 24.97010994], [80.93682098, 24.97249985], [80.94249725, 24.97113991], [80.94484711, 24.96800995], [80.9467392, 24.96114159], [80.94668579, 24.95691109], [80.94386292, 24.95070076], [80.94481659, 24.94713974], [80.9498291, 24.94638062], [80.9522171, 24.94288063], [80.95287323, 24.93943977], [80.95111084, 24.92702293], [80.95523071, 24.92571068], [80.95838928, 24.93224907], [80.96566772, 24.93861961], [80.97225952, 24.9396019], [80.97928619, 24.93807983], [80.97792816, 24.93315125], [80.98101044, 24.9296608], [80.98448944, 24.93258095], [80.99124146, 24.93712044], [80.99672699, 24.93959045], [81.00002289, 24.94021034], [81.0087204, 24.93246078], [81.0118866, 24.9332428], [81.01467133, 24.93160057], [81.01677704, 24.93246078], [81.01799011, 24.93554115], [81.02128601, 24.93712044], [81.02114105, 24.93825912], [81.01531219, 24.94005966], [81.01258087, 24.94371986], [81.00715637, 24.95262909], [81.00952911, 24.95432091], [81.01698303, 24.94643974], [81.01924896, 24.94499969], [81.0207901, 24.94607925], [81.02139282, 24.94839096], [81.01991272, 24.95198059], [81.02320099, 24.95235062], [81.02667236, 24.95496941], [81.04312134, 24.95263863], [81.04715729, 24.9552002], [81.0508194, 24.95527267], [81.05741882, 24.95311928], [81.07641602, 24.95226097], [81.08120728, 24.95021057], [81.08246613, 24.94769096], [81.08049774, 24.9383812], [81.08156586, 24.93575096], [81.08487701, 24.93435287], [81.08950043, 24.92448044], [81.09449768, 24.92378044], [81.09654236, 24.92253113], [81.09871674, 24.91843033], [81.10381317, 24.91270065], [81.10748291, 24.91214752], [81.11073303, 24.91068077], [81.11292267, 24.90552139], [81.11678314, 24.90182114], [81.12265015, 24.89870071], [81.1281662, 24.89361954], [81.13244629, 24.89207077], [81.1342392, 24.89384079], [81.13289642, 24.90050125], [81.13331604, 24.90557098], [81.14008331, 24.91643906], [81.14272308, 24.91736984], [81.14813995, 24.91768074], [81.15231323, 24.91628075], [81.15249634, 24.91962242], [81.15090179, 24.92374039], [81.15116119, 24.92720985], [81.15233612, 24.92937279], [81.15548706, 24.9319706], [81.15602112, 24.93982124], [81.15779877, 24.94267082], [81.1568985, 24.94571114], [81.15956116, 24.95473289], [81.16143036, 24.95851135], [81.16419983, 24.95976257], [81.16967773, 24.95675087], [81.17212677, 24.95350075], [81.17658997, 24.95496941], [81.18062592, 24.94945908], [81.1884079, 24.94505119], [81.19895935, 24.93473816], [81.19828033, 24.93404961], [81.19303894, 24.93461037], [81.18441772, 24.9292202], [81.19579315, 24.92900848], [81.19948578, 24.92694092], [81.20249939, 24.92780113], [81.20729828, 24.93110275], [81.21098328, 24.93259048], [81.21260834, 24.93452072], [81.21148682, 24.93622971], [81.20749664, 24.93725014], [81.20600128, 24.9392395], [81.20437622, 24.95047951], [81.20639038, 24.95408058], [81.20600891, 24.95808983], [81.20407867, 24.96284103], [81.20001221, 24.96685028], [81.20127869, 24.97026253], [81.21230316, 24.97774124], [81.21273041, 24.98166275], [81.21129608, 24.98680115], [81.20733643, 24.9912796], [81.2016983, 24.99572945], [81.20381927, 24.99755287], [81.20482635, 25.00280952], [81.20511627, 25.00311089], [81.20581055, 25.00342941], [81.20641327, 25.00374031], [81.20735931, 25.0035305], [81.20854187, 25.00312042], [81.20900726, 25.00291824], [81.20974731, 25.0021801], [81.21016693, 25.00181961], [81.21070099, 25.00165939], [81.2113266, 25.00169182], [81.21656799, 25.00444984], [81.22023773, 25.0072403], [81.22309875, 25.01132965], [81.23069, 25.0180912], [81.23600769, 25.02930069], [81.23921204, 25.03136063], [81.2425766, 25.03630066], [81.24756622, 25.04149246], [81.25229645, 25.05257988], [81.25338745, 25.05443001], [81.25602722, 25.05571938], [81.25527191, 25.06082916], [81.26158905, 25.06846046], [81.26222229, 25.0728302], [81.25997925, 25.07562256], [81.25302887, 25.07904816], [81.25911713, 25.08730125], [81.25443268, 25.09270096], [81.25206757, 25.09857941], [81.24878693, 25.10071945], [81.24648285, 25.10326958], [81.24569702, 25.10554123], [81.24812317, 25.1117382], [81.25617981, 25.11454964], [81.25795746, 25.1168499], [81.25817871, 25.12363243], [81.25683594, 25.12862968], [81.262146, 25.13108063], [81.25974274, 25.14118195], [81.26122284, 25.1439209], [81.26146698, 25.14434814], [81.26558685, 25.14487076], [81.27059174, 25.14843941], [81.27477264, 25.15341949], [81.27390289, 25.15836906], [81.26864624, 25.16518974], [81.26911926, 25.16773987], [81.27143097, 25.16893959], [81.27522278, 25.16899109], [81.28147888, 25.1654892], [81.28468323, 25.16530991], [81.29133606, 25.16679764], [81.29254913, 25.16798019], [81.30487061, 25.16745949], [81.30638885, 25.16599274], [81.30699921, 25.15966988], [81.30429077, 25.14529037], [81.30490112, 25.14307022], [81.30802155, 25.1388607], [81.30657959, 25.13517189], [81.30696869, 25.13339043], [81.30880737, 25.13158989], [81.30838776, 25.12583923], [81.31005096, 25.12402916], [81.31195068, 25.12343025], [81.31302643, 25.11741066], [81.31466675, 25.11629105], [81.31700897, 25.1160183], [81.31830597, 25.11684036], [81.31852722, 25.11869049], [81.32301331, 25.11839294], [81.32221222, 25.12072945], [81.32026672, 25.1224308], [81.31678009, 25.12808037], [81.31598663, 25.1350708], [81.31680298, 25.14066124], [81.31225586, 25.14621925], [81.31096649, 25.14896011], [81.31073761, 25.15263939], [81.31297302, 25.16354752], [81.31964111, 25.1680603], [81.32995605, 25.17249107], [81.33103943, 25.16955757], [81.33603668, 25.16634941], [81.34459686, 25.16547012], [81.34941101, 25.16735077], [81.35089874, 25.16391945], [81.3533783, 25.16147995], [81.35549927, 25.15764999], [81.35720825, 25.15232086], [81.36251068, 25.14571953], [81.36560822, 25.14425087], [81.36643982, 25.14172935], [81.36453247, 25.13929749], [81.36450958, 25.13785934], [81.36688232, 25.13743973], [81.37428284, 25.13877106], [81.37898254, 25.13445091], [81.3843689, 25.13508034], [81.38652039, 25.13393021], [81.38500214, 25.1301403], [81.38722992, 25.12895012], [81.38903046, 25.12426186], [81.39122009, 25.1231308], [81.39753723, 25.12170029], [81.4005661, 25.1217308], [81.40431976, 25.12216759], [81.40624237, 25.12339973], [81.40667725, 25.1251297], [81.40181732, 25.13082123], [81.40020752, 25.13380051], [81.41326904, 25.13169098], [81.41604614, 25.13228035], [81.41783905, 25.13517189], [81.41970062, 25.13560295], [81.42778015, 25.13360977], [81.43022156, 25.13363075], [81.42913818, 25.12953949], [81.43437195, 25.12194061], [81.43856812, 25.11400032], [81.43910217, 25.11198997], [81.43833923, 25.11044121], [81.43546295, 25.11103821], [81.42717743, 25.1106205], [81.41147614, 25.11230087], [81.40689087, 25.11201859], [81.40300751, 25.1115799], [81.400383, 25.10914993], [81.40084839, 25.10777092], [81.40306854, 25.10640907], [81.41314697, 25.10399055], [81.42082977, 25.1015892], [81.42479706, 25.09943962], [81.436409, 25.09616089], [81.4588623, 25.09299088], [81.45781708, 25.08934975], [81.45829773, 25.08677101], [81.46539307, 25.08184052], [81.47305298, 25.08093071], [81.47740173, 25.07925034], [81.48118591, 25.07590294], [81.4837265, 25.07493973], [81.4851532, 25.0775795], [81.4864502, 25.08410072], [81.49224091, 25.08192062], [81.49462128, 25.08210945], [81.49740601, 25.09604073], [81.4942627, 25.10169983], [81.50054932, 25.10083008], [81.50286865, 25.10172081], [81.50701904, 25.10532188], [81.50757599, 25.10680962], [81.50319672, 25.11051941], [81.49314117, 25.11065292], [81.48562622, 25.11586952], [81.48171997, 25.11732101], [81.47772217, 25.12108994], [81.47812653, 25.12792015], [81.4720459, 25.13303947], [81.47175598, 25.13499069], [81.4728775, 25.1371212], [81.4746933, 25.13812065], [81.47743225, 25.13842964], [81.4801712, 25.13770103], [81.48452759, 25.13434982], [81.48960876, 25.13422012], [81.49054718, 25.13504028], [81.48995972, 25.14191818], [81.49199677, 25.14875984], [81.4954071, 25.15234947], [81.50063324, 25.1528492], [81.50496674, 25.15122032], [81.51091003, 25.14840126], [81.51566315, 25.14533997], [81.51846313, 25.14254761], [81.52465057, 25.14364052], [81.525177, 25.14753151], [81.51873779, 25.15183067], [81.5199585, 25.15365982], [81.52884674, 25.16133118], [81.53000641, 25.16333961], [81.52728271, 25.16662025], [81.51074219, 25.17368126], [81.5078125, 25.17625046], [81.50711823, 25.17854118], [81.50778961, 25.18497086], [81.50956726, 25.18703079], [81.5128479, 25.18790054], [81.52007294, 25.1872406], [81.52321625, 25.1857605], [81.53253937, 25.18542099], [81.53333282, 25.18756104], [81.53401184, 25.18826103], [81.53991699, 25.18765831], [81.54876709, 25.18865013], [81.54902649, 25.18658066], [81.55844116, 25.18919182], [81.56639862, 25.19574928], [81.5716629, 25.1929512], [81.57718658, 25.19129944], [81.58560944, 25.18662071], [81.58799744, 25.1837883], [81.58194733, 25.17033005], [81.58177948, 25.16827011], [81.59657288, 25.16553116], [81.599823, 25.16603088], [81.60114288, 25.16736984], [81.6029129, 25.16588974], [81.60549164, 25.16562843], [81.60703278, 25.16805077], [81.60675812, 25.17057037], [81.60810852, 25.17276955], [81.61000061, 25.17365265], [81.61347198, 25.17052078], [81.61441803, 25.16506958], [81.61737061, 25.16389847], [81.61898804, 25.1596508], [81.61965942, 25.15563965], [81.618927, 25.14908981], [81.61763763, 25.14624977], [81.61506653, 25.14393044], [81.61223602, 25.14660072], [81.61001587, 25.14717102], [81.60430145, 25.14281082], [81.59918213, 25.13982964], [81.59417725, 25.13801193], [81.59211731, 25.13638115], [81.59414673, 25.12951279], [81.59146881, 25.12735939], [81.59102631, 25.12298965], [81.60230255, 25.11750984], [81.60180664, 25.1160183], [81.60280609, 25.11244965], [81.60122681, 25.10021019], [81.60426331, 25.09966278], [81.60639191, 25.10594177], [81.6100769, 25.11170959], [81.61302948, 25.11322975], [81.61483002, 25.1198597], [81.61675262, 25.12261963], [81.62329102, 25.12193108], [81.62506104, 25.12044907], [81.62534332, 25.1178112], [81.62265015, 25.11124039], [81.63195038, 25.10326958], [81.63166046, 25.10148048], [81.62930298, 25.09972954], [81.62583923, 25.09988976], [81.62153625, 25.09836006], [81.62088776, 25.09507942], [81.61486816, 25.09404755], [81.60949707, 25.08515167], [81.60443878, 25.08299065], [81.59591675, 25.08182907], [81.59379578, 25.07979965], [81.59446716, 25.07693291], [81.60280609, 25.07183075], [81.6039505, 25.06954193], [81.60811615, 25.06682014], [81.60971069, 25.06469917], [81.60855103, 25.06331062], [81.60558319, 25.0645504], [81.6032486, 25.06435966], [81.60272217, 25.06304169], [81.60434723, 25.06074905], [81.60852051, 25.05887985], [81.61725616, 25.05712128], [81.62190247, 25.05692101], [81.62525177, 25.06245995], [81.63201141, 25.06147957], [81.63559723, 25.06179047], [81.64418793, 25.06835937], [81.64598083, 25.07055092], [81.64684296, 25.07504082], [81.65307617, 25.07503128], [81.65650177, 25.07862091], [81.65869141, 25.07973099], [81.65989685, 25.07818031], [81.66040802, 25.07146072], [81.66221619, 25.06513977], [81.66398621, 25.06394958], [81.67137909, 25.06624985], [81.67582703, 25.06598091], [81.67780304, 25.06467819], [81.68306732, 25.0567627], [81.68371582, 25.05079079], [81.6818924, 25.04377174], [81.68553925, 25.04218292], [81.70536041, 25.03790283], [81.71012115, 25.03912926], [81.71338654, 25.04006004], [81.71382141, 25.04725075], [81.71640778, 25.05297279], [81.73239136, 25.04870987], [81.7350769, 25.04452133], [81.73446655, 25.0431385], [81.73723602, 25.04194069], [81.73821259, 25.03907013], [81.74150085, 25.03697014], [81.74646759, 25.0357399], [81.74740601, 25.03362274], [81.74977112, 25.03162193], [81.77139282, 25.02323914], [81.77871704, 25.01762009], [81.78011322, 25.01519012], [81.78922272, 25.01013947], [81.79165649, 25.01000977], [81.82936859, 25.01933289], [81.8349762, 25.01828194], [81.84002686, 25.01497269], [81.84629822, 25.00712013], [81.84938049, 25.00601006], [81.86371613, 25.00357056], [81.86454773, 25.00039291], [81.86683655, 25.00015068], [81.86837006, 25.00222969], [81.8735199, 25.00214005], [81.8813858, 24.99949265], [81.88331604, 24.99365044], [81.88613129, 24.99282074], [81.88772583, 24.99340057], [81.89058685, 24.99636841], [81.89309692, 24.99982071], [81.89402008, 25.00345993], [81.89160919, 25.00505066], [81.88861084, 25.00954819], [81.88822937, 25.01098061], [81.889328, 25.01311111], [81.89142609, 25.0134697], [81.89846802, 25.00962067], [81.89997101, 25.0072403], [81.89994812, 25.00344086], [81.89922333, 24.99924088], [81.89483643, 24.99109077], [81.89450073, 24.98740005], [81.90052032, 24.98483086], [81.90164185, 24.98282051], [81.89845276, 24.97686958], [81.89834595, 24.97532082], [81.90096283, 24.97305107], [81.90410614, 24.94226837], [81.90962219, 24.93714905], [81.91204071, 24.93091965], [81.91030884, 24.9204998], [81.90242004, 24.91150093], [81.89846039, 24.90518188], [81.89879608, 24.8993206], [81.89644623, 24.89250946], [81.90265656, 24.88413048], [81.90628815, 24.88354111], [81.91010284, 24.88043976], [81.91339111, 24.88041115], [81.91513062, 24.87779045], [81.92366791, 24.87627029], [81.92838287, 24.87306023], [81.92672729, 24.86079025], [81.93177032, 24.85649109], [81.93466949, 24.85144997], [81.93718719, 24.85005951], [81.94615173, 24.84671021], [81.94772339, 24.84259033], [81.95488739, 24.83924103], [81.95717621, 24.83213043], [81.95915222, 24.83061028], [81.96156311, 24.83172989], [81.96498108, 24.84142113], [81.96806335, 24.84386063], [81.97544861, 24.84246063], [81.99154663, 24.8465004], [81.99793243, 24.84744072], [82.00489044, 24.85069084], [82.02427673, 24.8446312], [82.03720093, 24.83296013], [82.04232788, 24.83424187], [82.05648804, 24.82807922], [82.06520081, 24.82344055], [82.07084656, 24.82493973], [82.08187103, 24.82211113], [82.08972931, 24.8159008], [82.0946579, 24.81036949], [82.1000061, 24.80994987], [82.10475922, 24.80560112], [82.10769653, 24.8008194], [82.10778809, 24.79368019], [82.11219025, 24.79226112], [82.12637329, 24.79394913], [82.12892151, 24.79976273], [82.13224792, 24.8044796], [82.14657593, 24.79730988], [82.15939331, 24.79226112], [82.16323853, 24.79577065], [82.17336273, 24.80096054], [82.16281128, 24.80498123], [82.17176056, 24.8088398], [82.17373657, 24.81418991], [82.18244171, 24.81678963], [82.18791962, 24.82071114], [82.19596863, 24.82452965], [82.19126892, 24.81772041], [82.18090057, 24.80821991], [82.17900848, 24.80465126], [82.1812973, 24.80084991], [82.18855286, 24.79821968], [82.19491577, 24.79694939], [82.20136261, 24.80065155], [82.20871735, 24.79776955], [82.20545959, 24.79144096], [82.20493317, 24.78550911], [82.20947266, 24.78149033], [82.20179749, 24.7806797], [82.19403839, 24.78326035], [82.18936157, 24.78228188], [82.19129181, 24.77486038], [82.19061279, 24.76955986], [82.19567108, 24.76374817], [82.1914978, 24.75316048], [82.17288208, 24.73957062], [82.18873596, 24.74377823], [82.19512939, 24.73994064], [82.2026062, 24.74078941], [82.20841217, 24.7389698], [82.21375275, 24.72866058], [82.21604919, 24.73615074], [82.21340179, 24.74420929], [82.2022171, 24.74817085], [82.19948578, 24.75206947], [82.20918274, 24.75951004], [82.22280884, 24.7517395], [82.22157288, 24.75991058], [82.21853638, 24.76498032], [82.22091675, 24.76704979], [82.22338867, 24.76417923], [82.22773743, 24.76556015], [82.2323761, 24.75814819], [82.2383728, 24.75440979], [82.24108887, 24.76827049], [82.24031067, 24.77547073], [82.24365997, 24.77575111], [82.24659729, 24.75976181], [82.24962616, 24.75636864], [82.24590302, 24.74065971], [82.24143982, 24.73846054], [82.24101257, 24.7269001], [82.24394989, 24.71638107], [82.24046326, 24.71055984], [82.24304962, 24.70176125], [82.23400116, 24.69656944], [82.2286911, 24.69075966], [82.22885132, 24.67459106], [82.22992706, 24.66963959], [82.23509979, 24.66591072], [82.23420715, 24.67193985], [82.23551941, 24.67638969], [82.24797821, 24.67556953], [82.24952698, 24.66833115], [82.25305176, 24.66609192], [82.26674652, 24.67840958], [82.25834656, 24.68209076], [82.2633667, 24.6864109], [82.2694931, 24.68186951], [82.27851105, 24.68087959], [82.28173828, 24.67174149], [82.28520966, 24.67001152], [82.29107666, 24.67086983], [82.29641724, 24.67001152], [82.29189301, 24.66477966], [82.29808807, 24.65654945], [82.29469299, 24.65385246], [82.29611206, 24.64332008], [82.29579926, 24.63624191], [82.29841614, 24.6280117], [82.29302979, 24.61689949], [82.29393005, 24.61374092], [82.29833984, 24.61242104], [82.30940247, 24.61293983], [82.31530762, 24.61535072], [82.31915283, 24.6202507], [82.32373047, 24.62254906], [82.32977295, 24.62375069], [82.33506012, 24.6229496], [82.34596252, 24.61880112], [82.35051727, 24.60820961], [82.35391998, 24.60447121], [82.36084747, 24.60200119], [82.38564301, 24.59737968], [82.39359283, 24.59749985], [82.40081787, 24.59869957], [82.40917206, 24.59782982], [82.41456604, 24.60639191], [82.40567017, 24.61751175], [82.40789032, 24.62281036], [82.40364838, 24.63097954], [82.40352631, 24.6361618], [82.40904999, 24.64306068], [82.40896606, 24.64956093], [82.41178894, 24.65784836], [82.4054718, 24.66682053], [82.40679932, 24.6744194], [82.40159607, 24.68379974], [82.40738678, 24.69514084], [82.42015076, 24.70525169], [82.43231201, 24.70628166], [82.44484711, 24.69637108], [82.44838715, 24.69062042], [82.44480896, 24.68008995], [82.44885254, 24.67790031], [82.4640274, 24.68007088], [82.47667694, 24.6835804], [82.486763, 24.67550087], [82.501297, 24.67840958], [82.50905609, 24.6790905], [82.51843262, 24.67834091], [82.52398682, 24.65714073], [82.52926636, 24.65196037], [82.54425812, 24.65487862], [82.57396698, 24.66300011], [82.58764648, 24.67373085], [82.60299683, 24.67945099], [82.62996674, 24.68670082], [82.63643646, 24.68783951], [82.64569855, 24.69454956], [82.65792847, 24.70039749], [82.66555023, 24.69986153], [82.68543243, 24.68652153], [82.69230652, 24.68022919], [82.69595337, 24.67572021], [82.69586945, 24.66871262], [82.69345856, 24.66157913], [82.69169617, 24.64863968], [82.6951828, 24.64425278], [82.70207214, 24.64211273], [82.70921326, 24.64371109], [82.71460724, 24.6421299], [82.72746277, 24.64647293], [82.74312592, 24.64406967], [82.76278687, 24.64566994], [82.76580048, 24.64163017], [82.76716614, 24.62943077], [82.76789093, 24.61061287], [82.7629776, 24.60481071], [82.76007843, 24.59981918], [82.76825714, 24.59754181], [82.78542328, 24.59951019], [82.79637146, 24.59976006], [82.79644012, 24.58749962], [82.80076599, 24.55268097], [82.78093719, 24.54606819], [82.74601746, 24.54152107], [82.74536133, 24.55251122], [82.74120331, 24.55459023], [82.73352814, 24.55162048], [82.71611023, 24.55714035], [82.71253204, 24.5562191], [82.7150116, 24.54811096], [82.71414948, 24.53619957], [82.71563721, 24.51329994], [82.73654938, 24.49977112], [82.73377991, 24.48723984], [82.72377014, 24.4763298], [82.73060608, 24.47033119], [82.72602081, 24.46084023], [82.72503662, 24.44473267], [82.72730255, 24.43414116], [82.73271179, 24.43274117], [82.72572327, 24.42625809], [82.72019196, 24.42967987], [82.71936798, 24.42163086], [82.71496582, 24.41617012], [82.70758057, 24.38937759], [82.70716095, 24.38517952], [82.71286011, 24.37520981], [82.71849823, 24.37122154], [82.73478699, 24.37117958], [82.74677277, 24.37252045], [82.7544632, 24.37951088], [82.75688934, 24.37594032], [82.76058197, 24.37304115], [82.75875854, 24.36931038], [82.75892639, 24.36314964], [82.75981903, 24.35838127], [82.76449585, 24.34754944], [82.76326752, 24.34243011], [82.76299286, 24.32982826], [82.76045227, 24.32310104], [82.75981903, 24.31908035], [82.76603699, 24.31220818], [82.76413727, 24.29243088], [82.75705719, 24.27569962], [82.75460815, 24.2716198], [82.75058746, 24.26813126], [82.74938965, 24.25662041], [82.75157166, 24.24586105], [82.74991608, 24.23612976], [82.74331665, 24.23161125], [82.73706055, 24.23031044], [82.73223114, 24.22797012], [82.72699738, 24.22326088], [82.73190308, 24.20107269], [82.73478699, 24.1830101], [82.73613739, 24.16835022], [82.72307587, 24.15681076], [82.72132111, 24.1498127], [82.72036743, 24.1389904], [82.68836212, 24.14422989], [82.6794281, 24.15673065], [82.67085266, 24.15847015], [82.66519928, 24.15112114], [82.66587067, 24.14278984], [82.65738678, 24.13479805], [82.66352844, 24.12392998], [82.70136261, 24.09707069], [82.70522308, 24.0857296], [82.70839691, 24.08076096], [82.72628021, 24.08256912], [82.73768616, 24.07872963], [82.74146271, 24.07509041], [82.74803925, 24.08053017], [82.75174713, 24.07959747], [82.75492096, 24.07324028], [82.76055145, 24.07967949], [82.76625824, 24.07786751], [82.76220703, 24.05988121], [82.75576782, 24.04359818], [82.74314117, 24.03487968], [82.73992157, 24.03104973], [82.74199677, 24.02140045], [82.74588776, 24.01311111], [82.75235748, 24.00843048], [82.76628876, 24.00605011], [82.78266907, 24.00695992], [82.78990173, 24.00677109], [82.79727173, 24.0051403], [82.8014679, 24.00106239], [82.80065155, 23.99655914], [82.80050659, 23.98533058], [82.79872131, 23.97661972], [82.79888153, 23.97089005], [82.80046844, 23.96748161], [82.8077774, 23.96305847], [82.79865265, 23.96218109], [82.79680634, 23.96142006], [82.79210663, 23.95570946], [82.7902832, 23.95061111], [82.77484894, 23.93857002], [82.75377655, 23.93588066], [82.75019836, 23.93005943], [82.75006866, 23.92653275], [82.74810028, 23.92228127], [82.74333191, 23.92064095], [82.71811676, 23.92144966], [82.70667267, 23.92461967], [82.70192719, 23.92493248], [82.68987274, 23.92042923], [82.68900299, 23.91953087], [82.68733978, 23.91777039], [82.68186188, 23.91226959], [82.67708588, 23.90982056], [82.67090607, 23.90977097], [82.66812134, 23.9076004], [82.66290283, 23.90867043], [82.65905762, 23.90863991], [82.65651703, 23.90786171], [82.65473938, 23.90629005], [82.64730072, 23.89499092], [82.64611816, 23.88873291], [82.65727234, 23.87815094], [82.65953064, 23.87458038], [82.66020966, 23.87033844], [82.65795898, 23.86558151], [82.65492249, 23.86271095], [82.65335846, 23.85778046], [82.65202332, 23.85650063], [82.64541626, 23.85782051], [82.64354706, 23.85962105], [82.64064026, 23.85803032], [82.63772583, 23.84988976], [82.63482666, 23.84767914], [82.6312561, 23.84633064], [82.63130188, 23.84168243], [82.6295166, 23.8390007], [82.60591125, 23.83616257], [82.60051727, 23.83391953], [82.58963776, 23.82479095], [82.58598328, 23.82286072], [82.57849121, 23.8224411], [82.56633759, 23.82472992], [82.56115723, 23.82278061], [82.54821777, 23.82690048], [82.54207611, 23.82674026], [82.53874969, 23.82410812], [82.53366089, 23.82499123], [82.52735138, 23.82407951], [82.52910614, 23.82159996], [82.53196716, 23.81982994], [82.53399658, 23.81479836], [82.53690338, 23.81249046], [82.53975677, 23.81182861], [82.54086304, 23.81015015], [82.54399109, 23.80282021], [82.54477692, 23.79831123], [82.54451752, 23.79418945], [82.54026794, 23.79120064], [82.53578949, 23.79210091], [82.52879333, 23.79134941], [82.5161972, 23.78423119], [82.50670624, 23.7854805], [82.4966507, 23.78504944], [82.49175262, 23.78570747], [82.4850769, 23.78837967], [82.48375702, 23.79057121], [82.4826889, 23.79751968], [82.46987915, 23.80764961], [82.46350861, 23.81084824], [82.46002197, 23.81139946], [82.44904327, 23.81165123], [82.44576263, 23.81085968], [82.44023895, 23.80572128], [82.43644714, 23.80470848], [82.42323303, 23.80608749], [82.40296936, 23.80277824], [82.39335632, 23.80241013], [82.38822937, 23.80137062], [82.3839798, 23.80487061], [82.37985229, 23.80704117], [82.36834717, 23.81110001], [82.35658264, 23.80833054], [82.34703064, 23.80371094], [82.3429184, 23.80389977], [82.33854675, 23.8060112], [82.33125305, 23.80536079], [82.32823181, 23.80367088], [82.32096863, 23.80874062], [82.31505585, 23.81030846], [82.31112671, 23.81118965], [82.30715942, 23.81116295], [82.30432129, 23.80986023], [82.29759216, 23.80816078], [82.29511261, 23.80854988], [82.28382874, 23.81290054], [82.27767181, 23.81713104], [82.27121735, 23.81869125], [82.26476288, 23.81874084], [82.25528717, 23.82188988], [82.24855042, 23.81979942], [82.23152924, 23.80779076], [82.22899628, 23.80667114], [82.22614288, 23.80693245], [82.22107697, 23.8100605], [82.21611023, 23.82096291], [82.21160126, 23.82393265], [82.20136261, 23.82829285], [82.1992569, 23.83192062], [82.20096588, 23.83453941], [82.20435333, 23.83712006], [82.20664978, 23.84103012], [82.20687103, 23.84404182], [82.20388794, 23.8529911], [82.19557953, 23.85038185], [82.18933868, 23.84370995], [82.17875671, 23.84204292], [82.17352295, 23.83909035], [82.17249298, 23.8379097], [82.16971588, 23.82467842], [82.1682663, 23.82269287], [82.16525269, 23.82075119], [82.16240692, 23.81995964], [82.15573883, 23.82197762], [82.14456177, 23.81925011], [82.13407898, 23.81816101], [82.12576294, 23.81966972], [82.11746216, 23.82312012], [82.10875702, 23.81868172], [82.10678864, 23.81849098], [82.10018158, 23.82010078], [82.08911133, 23.81789017], [82.07801819, 23.8170681], [82.07202148, 23.81978035], [82.06328583, 23.81911087], [82.04540253, 23.82058907], [82.04234314, 23.82496071], [82.04052734, 23.82632828], [82.03217316, 23.82930946], [82.03100586, 23.83189964], [82.03433228, 23.83867073], [82.03515625, 23.84255981], [82.03251648, 23.84507942], [82.02849579, 23.84770012], [82.01161194, 23.85227966], [82.00759888, 23.85495186], [82.00567627, 23.85880089], [82.00073242, 23.86314011], [81.99214935, 23.86264038], [81.98394012, 23.86199951], [81.97154999, 23.85835075], [81.96238708, 23.85707855], [81.95070648, 23.85289001], [81.94490051, 23.85692978], [81.94004822, 23.85777092], [81.93856049, 23.86096954], [81.93685913, 23.86206245], [81.93390656, 23.86193275], [81.93228149, 23.86261177], [81.93289948, 23.86675072], [81.93164825, 23.86791039], [81.91644287, 23.87298965], [81.91470337, 23.87187958], [81.90983582, 23.8640995], [81.90425873, 23.85852051], [81.90077972, 23.85122108], [81.89807129, 23.84828949], [81.89409637, 23.8440609], [81.88535309, 23.84173965], [81.87843323, 23.83790016], [81.86207581, 23.83481026], [81.85765839, 23.82876968], [81.85293579, 23.82431984], [81.83164978, 23.82130241], [81.82863617, 23.8170929], [81.82411957, 23.81641006], [81.81741333, 23.81124115], [81.81172943, 23.80949974], [81.80564117, 23.81043816], [81.80058289, 23.81355095], [81.79341888, 23.8144207], [81.78748322, 23.8119297], [81.78266144, 23.81184006], [81.77262878, 23.81419945], [81.74518585, 23.83092117], [81.73443604, 23.83619118], [81.7305069, 23.83936119], [81.72685242, 23.84095955], [81.71906281, 23.84042931], [81.71835327, 23.84338951], [81.72141266, 23.8490715], [81.72389221, 23.85071754], [81.72384644, 23.85688972], [81.7230072, 23.85898018], [81.72091675, 23.86082268], [81.71495056, 23.86188126], [81.71253204, 23.86296272], [81.7026825, 23.86339951], [81.70228577, 23.86898994], [81.70297241, 23.87285042], [81.69845581, 23.87799072], [81.69966888, 23.88149071], [81.6973877, 23.88596153], [81.68692017, 23.8849411], [81.68239594, 23.88978958], [81.67949677, 23.90764809], [81.67733002, 23.91024017], [81.66771698, 23.91570091], [81.66491699, 23.92207909], [81.66159821, 23.92559814], [81.65740967, 23.92456818], [81.6516571, 23.91782951], [81.64811707, 23.91616058], [81.6414566, 23.91517067], [81.63728333, 23.91362], [81.62921906, 23.90765953], [81.62451172, 23.90691948], [81.61444855, 23.90827942], [81.61051178, 23.90697289], [81.60756683, 23.90327072], [81.60555267, 23.89585114], [81.60338593, 23.89240074], [81.59690857, 23.88902283], [81.59757996, 23.88624191], [81.60019684, 23.88339806], [81.60874939, 23.87817955], [81.61485291, 23.87277031], [81.61142731, 23.86702919], [81.60620117, 23.86395073], [81.5983429, 23.86421967], [81.59738922, 23.86194038], [81.59738922, 23.85746002], [81.59844208, 23.85367966], [81.60456085, 23.84383965], [81.60497284, 23.84139061], [81.60582733, 23.83820915], [81.60733032, 23.83624077], [81.60942078, 23.83579063], [81.62023163, 23.8368206], [81.62570953, 23.83582115], [81.62811279, 23.83432961], [81.63053894, 23.83081055], [81.63601685, 23.81635094], [81.64256287, 23.80458069], [81.64362335, 23.79889107], [81.64348602, 23.7918396], [81.6383667, 23.77787971], [81.63816833, 23.77478981], [81.63965607, 23.77112961], [81.64415741, 23.76807976], [81.65354919, 23.76427078], [81.66178131, 23.75991058], [81.66932678, 23.75735092], [81.67408752, 23.7539711], [81.67829132, 23.74887085], [81.6733017, 23.74336052], [81.67209625, 23.74002075], [81.67749786, 23.73460007], [81.68234253, 23.72561073], [81.68688965, 23.72262001], [81.68728638, 23.72134972], [81.68464661, 23.71364021], [81.67321014, 23.69343185], [81.64949799, 23.6834507], [81.64795685, 23.66799927], [81.64640808, 23.66320992], [81.64312744, 23.66033173], [81.63500977, 23.65896988], [81.61849213, 23.66138077], [81.6132431, 23.66098022], [81.60951233, 23.63298988], [81.60652161, 23.62445831], [81.60437775, 23.62137032], [81.60108948, 23.61394119], [81.60267639, 23.60003281], [81.59984589, 23.59692192], [81.59480286, 23.59547043], [81.58024597, 23.59679031], [81.57505798, 23.59202194], [81.57077026, 23.59091949], [81.56973267, 23.58864975], [81.57042694, 23.5798111], [81.57444763, 23.56668091], [81.57550812, 23.5587101], [81.57707214, 23.55488968], [81.58392334, 23.5539608], [81.58690643, 23.55451012], [81.60227203, 23.55367279], [81.60569763, 23.55048943], [81.60665131, 23.54496956], [81.60546875, 23.5247612], [81.60632324, 23.52067947], [81.60521698, 23.51088905], [81.60704803, 23.50688934], [81.61443329, 23.49776077], [81.61721802, 23.49486923], [81.62422943, 23.49105072], [81.62822723, 23.4903698], [81.63109589, 23.49174118], [81.63524628, 23.49835968], [81.63717651, 23.49930191], [81.64398956, 23.50012016], [81.64765167, 23.50242996], [81.6536026, 23.51389122], [81.65396118, 23.5199604], [81.65309906, 23.52769279], [81.65453339, 23.53155136], [81.66203308, 23.53243828], [81.66718292, 23.53190041], [81.68187714, 23.5272007], [81.68744659, 23.5244503], [81.69309235, 23.52334023], [81.70638275, 23.53358078], [81.71034241, 23.54124069], [81.7130661, 23.5426693], [81.71675873, 23.54834938], [81.71923065, 23.55605125], [81.72344208, 23.55882835], [81.72595215, 23.56245041], [81.72923279, 23.56509972], [81.73603058, 23.5674305], [81.7407074, 23.56764984], [81.74796295, 23.5653801], [81.75060272, 23.5630703], [81.75361633, 23.55856133], [81.7563858, 23.55252075], [81.76299286, 23.55076981], [81.79756165, 23.54883194], [81.80127716, 23.54776001], [81.80461884, 23.5458107], [81.81104279, 23.53392029], [81.81150818, 23.53067017], [81.81019592, 23.52634048], [81.81006622, 23.52260971], [81.81257629, 23.51762962], [81.81653595, 23.51486015], [81.82717896, 23.5112896], [81.83410645, 23.51216125], [81.85074615, 23.51646042], [81.85507202, 23.51645088], [81.86223602, 23.51387024], [81.86968994, 23.51457024], [81.87935638, 23.51843262], [81.88448334, 23.52248001], [81.89624786, 23.53194809], [81.89997101, 23.5341301], [81.90392303, 23.53508949], [81.9094162, 23.53502274], [81.91375732, 23.53375816], [81.91635895, 23.53209114], [81.92767334, 23.51754951], [81.92829895, 23.51324081], [81.93444824, 23.50555038], [81.94471741, 23.50014114], [81.94893646, 23.49674034], [81.94702911, 23.47548103], [81.94761658, 23.4716301], [81.95033264, 23.46606064], [81.95674133, 23.46336937], [81.96124268, 23.45979118], [81.96660614, 23.45372009], [81.96821594, 23.45036125], [81.9713974, 23.44746971], [81.97190857, 23.44520187], [81.97145844, 23.44164085], [81.9750824, 23.4318409], [81.97338104, 23.42628288], [81.97054291, 23.42387009], [81.97158813, 23.41973114], [81.97360992, 23.41759109], [81.97589111, 23.41557121], [81.97612, 23.41311073], [81.97886658, 23.41152954], [81.98739624, 23.41951942], [81.99191284, 23.41929245], [81.99545288, 23.41559982], [81.99952698, 23.41281128], [82.00977325, 23.42052841], [82.01597595, 23.4235096], [82.01841736, 23.42111969], [82.02324677, 23.41018295], [82.01735687, 23.40806007], [82.01751709, 23.40551949], [82.01992035, 23.4009304], [82.01719666, 23.39639091], [82.01428986, 23.39351082], [82.0136261, 23.39026833], [82.01451874, 23.38791847], [82.02039337, 23.38430023], [82.02323914, 23.38376045], [82.02561188, 23.38593292], [82.02941895, 23.38755035], [82.03285217, 23.38539124], [82.03707123, 23.37955093], [82.04573822, 23.37787056], [82.04923248, 23.37873077], [82.052742, 23.38513947], [82.05396271, 23.39048958], [82.05677032, 23.39353943], [82.06307983, 23.39246941], [82.06929779, 23.39502907], [82.07995605, 23.39719009], [82.08364868, 23.39677238], [82.08512878, 23.39331055], [82.09488678, 23.3985405], [82.09848022, 23.39770126], [82.09876251, 23.39469147], [82.10079193, 23.3907795], [82.10411835, 23.38682175], [82.1051712, 23.38282967], [82.10546112, 23.36928177], [82.10449982, 23.36317825], [82.10788727, 23.35847092], [82.11090088, 23.35584068], [82.11444855, 23.35403061], [82.11844635, 23.35448074], [82.12905121, 23.36103821], [82.13247681, 23.36217117], [82.13783264, 23.3618412], [82.14282227, 23.35440826], [82.1452179, 23.34921074], [82.15130615, 23.3455677], [82.15358734, 23.34249115], [82.15553284, 23.33548927], [82.15808105, 23.33332062], [82.16007996, 23.33218956], [82.179039, 23.3270607], [82.18428802, 23.32689095], [82.18585968, 23.32538986], [82.18750763, 23.32222939], [82.18998718, 23.31153107], [82.18884277, 23.30873108], [82.18990326, 23.30348969], [82.188797, 23.29837036], [82.1869812, 23.29499054], [82.1869812, 23.29023933], [82.18946075, 23.28458977], [82.18638611, 23.27765846], [82.18419647, 23.27526283], [82.17402649, 23.27248955], [82.16982269, 23.27017975], [82.1681366, 23.2674408], [82.16652679, 23.26140022], [82.1598587, 23.25291824], [82.15953064, 23.24915123], [82.15371704, 23.24596977], [82.14698792, 23.23191833], [82.14248657, 23.22770119], [82.14292908, 23.22237968], [82.14634705, 23.21384048], [82.14665985, 23.20944977], [82.14057159, 23.19807053], [82.1401825, 23.19034958], [82.13765717, 23.18812943], [82.13698578, 23.18279839], [82.1374588, 23.18020058], [82.14095306, 23.17848969], [82.14170837, 23.17473984], [82.13790131, 23.16833115], [82.13732147, 23.1649704], [82.1401062, 23.16372108], [82.14494324, 23.16314125], [82.15138245, 23.16055107], [82.15376282, 23.158041], [82.15406799, 23.15114021], [82.15107727, 23.1417408], [82.13276672, 23.13162041], [82.13098907, 23.12895012], [82.12961578, 23.12507057], [82.12924194, 23.11403084], [82.12825012, 23.11211014], [82.11936188, 23.10746956], [82.11588287, 23.10379982], [82.10951996, 23.10548973], [82.10164642, 23.10851097], [82.08590698, 23.10925293], [82.0791626, 23.1121006], [82.07550812, 23.11215019], [82.07189178, 23.11359978], [82.06912231, 23.11488914], [82.06713104, 23.11681747], [82.06137085, 23.11594009], [82.04767609, 23.10335922], [82.04567719, 23.09910965], [82.03952026, 23.09151077], [82.02825165, 23.08166122], [82.024086, 23.08012009], [82.01616669, 23.07933044], [82.01278687, 23.07929993], [82.0102005, 23.08061981], [82.00218964, 23.07840919], [81.99680328, 23.08032036], [81.99253845, 23.08489037], [81.99048615, 23.08467102], [81.98545837, 23.08613014], [81.98214722, 23.08624268], [81.97997284, 23.08554268], [81.9748764, 23.08176041], [81.97215271, 23.08140945], [81.96930695, 23.0793705], [81.96507263, 23.08037186], [81.96127319, 23.08018112], [81.95262909, 23.07645035], [81.93810272, 23.07781029], [81.93747711, 23.07658005], [81.93786621, 23.06960106], [81.93501282, 23.0668602], [81.92608643, 23.06221008], [81.92394257, 23.05829811], [81.92138672, 23.04746056], [81.91842651, 23.04097939], [81.91941833, 23.03668022], [81.92597198, 23.02854156], [81.92707062, 23.02603912], [81.92679596, 23.02238083], [81.93229675, 23.01742172], [81.93721771, 23.00949287], [81.93701172, 23.00329971], [81.9385376, 23.00081062], [81.93844604, 22.99165154], [81.94120789, 22.98494911], [81.94241333, 22.97526932], [81.94256592, 22.96453094], [81.94024658, 22.95709038], [81.93327332, 22.95476151], [81.92797852, 22.95420074], [81.92344666, 22.9511795], [81.91385651, 22.94822121], [81.90567017, 22.94046021], [81.90146637, 22.93305969], [81.89488983, 22.92817116], [81.88654327, 22.9251709], [81.88027954, 22.91986084], [81.8746109, 22.91332054], [81.87050629, 22.91184044], [81.86000824, 22.91500092], [81.86194611, 22.90460968], [81.86110687, 22.89394951], [81.85634613, 22.8908596], [81.83558655, 22.88647079], [81.83142853, 22.88297081], [81.82644653, 22.88227081], [81.82065582, 22.88286018], [81.79582977, 22.88025093], [81.78592682, 22.87708092], [81.76940155, 22.87350845], [81.77005005, 22.86042976], [81.76931763, 22.85116005], [81.7648468, 22.84069061], [81.76085663, 22.83433914], [81.76159668, 22.82933044], [81.77300262, 22.8091507], [81.77590179, 22.80013847], [81.77440643, 22.78560066], [81.78128052, 22.7747097], [81.78427887, 22.76662064], [81.77815247, 22.75803947], [81.76397705, 22.74677086], [81.76277924, 22.74151039], [81.76249695, 22.73530006], [81.74912262, 22.73316956], [81.74661255, 22.72648811], [81.74833679, 22.71953964], [81.7559433, 22.69765091], [81.76288605, 22.68535995], [81.76597595, 22.67612076], [81.76506042, 22.66905975], [81.76272583, 22.66358948], [81.74893188, 22.64607048], [81.74053955, 22.64806938], [81.73934937, 22.6613903], [81.73693848, 22.66905022], [81.73014069, 22.67327118], [81.72294617, 22.6762104], [81.71962738, 22.67002106], [81.71800232, 22.66373062], [81.71411133, 22.65563011], [81.70701599, 22.64964104], [81.6988678, 22.64588165], [81.68839264, 22.64663124], [81.6785965, 22.64888], [81.66316223, 22.63272095], [81.65654755, 22.63200188], [81.65479279, 22.62158966], [81.64840698, 22.6199894], [81.64353943, 22.61440086], [81.64138794, 22.60754013], [81.64163208, 22.59209061], [81.64012146, 22.58654976], [81.64441681, 22.58337975], [81.64942169, 22.57608032], [81.64868927, 22.56895065], [81.64565277, 22.56589127], [81.63791656, 22.5621109], [81.63250732, 22.56199837], [81.6235733, 22.56427765], [81.61940765, 22.55855942], [81.61942291, 22.55327988], [81.62136078, 22.5477829], [81.62188721, 22.54383087], [81.61579132, 22.53902054], [81.60896301, 22.5364399], [81.59976959, 22.53570938], [81.59274292, 22.53765106], [81.58795929, 22.54403114], [81.5831604, 22.54453087], [81.5697403, 22.55005074], [81.56305695, 22.55100822], [81.55741882, 22.54689026], [81.55731201, 22.53759003], [81.56278229, 22.53417969], [81.55693054, 22.53216171], [81.54720306, 22.53126144], [81.54222107, 22.52992058], [81.53595734, 22.53324127], [81.52797699, 22.53979111], [81.51906586, 22.53998184], [81.51541901, 22.53675079], [81.51467133, 22.53403091], [81.5147171, 22.52869034], [81.51197052, 22.52352905], [81.50656128, 22.52177811], [81.50293732, 22.52679062], [81.49320984, 22.5196209], [81.49175262, 22.51733017], [81.49011993, 22.50843048], [81.48574829, 22.5033493], [81.4798584, 22.49331093], [81.47637177, 22.4921608], [81.46996307, 22.49398994], [81.46067047, 22.49435806], [81.45330811, 22.4910202], [81.44624329, 22.49586105], [81.43805695, 22.49394035], [81.43908691, 22.4910202], [81.44422913, 22.48702049], [81.44081116, 22.48464966], [81.43907928, 22.47947121], [81.44391632, 22.47867012], [81.44332886, 22.47154045], [81.45028687, 22.47256279], [81.44802856, 22.46739006], [81.44246674, 22.46615982], [81.43595886, 22.46948814], [81.43357086, 22.47771835], [81.43177795, 22.48049164], [81.42443848, 22.47923851], [81.41758728, 22.47363091], [81.41783142, 22.46515083], [81.42064667, 22.45940018], [81.41893005, 22.45421982], [81.41411591, 22.44852066], [81.39655304, 22.44132042], [81.38887024, 22.44483948], [81.38617706, 22.45116043], [81.38305664, 22.46260262], [81.38479614, 22.47784042], [81.38067627, 22.48534966], [81.37914276, 22.49339104], [81.37960815, 22.49790955], [81.3787384, 22.50530052], [81.37325287, 22.51075172], [81.36650085, 22.51436996], [81.36177826, 22.5153904], [81.35569, 22.51324272], [81.34794617, 22.51408958], [81.33188629, 22.52236938], [81.32293701, 22.52433014], [81.31939697, 22.51955032], [81.31481171, 22.5159111], [81.31414795, 22.4996109], [81.31591034, 22.48970985], [81.30396271, 22.48175049], [81.2977829, 22.4865799], [81.29170227, 22.48931122], [81.28019714, 22.49882126], [81.27546692, 22.49944115], [81.27146912, 22.49584961], [81.26674652, 22.49414063], [81.26045227, 22.49356079], [81.25623322, 22.48806953], [81.25551605, 22.47248268], [81.24038696, 22.45918083], [81.23310852, 22.45513153], [81.22355652, 22.45160866], [81.21839142, 22.45165062], [81.2097702, 22.45384979], [81.20214081, 22.45676994], [81.19419098, 22.46208], [81.19503784, 22.46775818], [81.1932373, 22.47370911], [81.19264221, 22.4824791], [81.18686676, 22.48921013], [81.18004608, 22.49015045], [81.17066193, 22.48800087], [81.16407013, 22.48191071], [81.15782166, 22.47448158], [81.14807892, 22.4558506], [81.13404083, 22.45199966], [81.12275696, 22.44762039], [81.10999298, 22.44112015], [81.10491943, 22.43279076], [81.10346985, 22.42208099], [81.1046524, 22.41080284], [81.10266113, 22.39126968], [81.10093689, 22.38323975], [81.1068573, 22.36218071], [81.11054993, 22.35300064], [81.11566162, 22.34408951], [81.1120224, 22.3346405], [81.10926819, 22.32963943], [81.11045837, 22.32149124], [81.11470032, 22.31258965], [81.11501312, 22.30323982], [81.11384583, 22.29438019], [81.09681702, 22.2774601], [81.09178162, 22.26786041], [81.08467865, 22.24674988], [81.07258606, 22.24174118], [81.06923676, 22.24625969], [81.06282043, 22.24685287], [81.05452728, 22.24387169], [81.04886627, 22.24419022], [81.04043579, 22.24057007], [81.03631592, 22.23771858], [81.01944733, 22.22919083], [81.01570892, 22.22021103], [81.01579285, 22.21410942], [81.01922607, 22.20779037], [81.02349091, 22.20282936], [81.02575684, 22.19769096], [81.02477264, 22.19313049], [81.02511597, 22.18882179], [81.02150726, 22.18703079], [81.01551056, 22.18840981], [81.01169586, 22.18400955], [81.01328278, 22.17749023], [81.01715088, 22.17103958], [81.0190506, 22.16526031], [81.01761627, 22.15384865], [81.01740265, 22.14027977], [81.01579285, 22.1327095], [81.00517273, 22.13272285], [80.992836, 22.13153076], [80.98670197, 22.13087082], [80.97342682, 22.12368965], [80.97175598, 22.12148094], [80.97081757, 22.11465073], [80.97226715, 22.11189079], [80.97432709, 22.11136055], [80.97666931, 22.11280823], [80.98020935, 22.11280823], [80.98725128, 22.11065102], [80.99027252, 22.10907936], [80.99282074, 22.10519028], [81.00006866, 22.10083008], [81.00369263, 22.0968895], [81.00395203, 22.0944519], [80.99991608, 22.08965111], [80.99742889, 22.08086967], [81.00427246, 22.07002068], [80.99916077, 22.06150055], [80.99282074, 22.05766106], [80.99117279, 22.05808067], [80.98972321, 22.05649757], [80.98808289, 22.05220985], [80.98776245, 22.04847908], [80.98259735, 22.04895973], [80.97885132, 22.04831123], [80.97364044, 22.05177116], [80.97181702, 22.05429077], [80.96341705, 22.05836105], [80.96208954, 22.0619297], [80.96573639, 22.07917023], [80.96553802, 22.08197975], [80.95752716, 22.0971508], [80.95052338, 22.11301041], [80.94552612, 22.11748123], [80.93891907, 22.11901093], [80.92479706, 22.12067032], [80.9171524, 22.12088966], [80.9108429, 22.1191597], [80.90608978, 22.11444092], [80.89817047, 22.1013298], [80.8947525, 22.07650948], [80.89122772, 22.06595993], [80.88844299, 22.06241035], [80.88498688, 22.06071091], [80.87895966, 22.06060028], [80.87663269, 22.0567894], [80.87735748, 22.05071259], [80.87011719, 22.03858948], [80.86894989, 22.03359032], [80.86950684, 22.01650047], [80.86859894, 22.01120949], [80.85933685, 22.0001297], [80.85929871, 21.99776077], [80.85840607, 21.99543953], [80.85719299, 21.99324036], [80.85640717, 21.99185181], [80.85546875, 21.98880959], [80.85456848, 21.9872303], [80.85312653, 21.98348045], [80.85309601, 21.98129272], [80.85253143, 21.97841072], [80.8516922, 21.97512054], [80.85037231, 21.97281075], [80.84851074, 21.97001076], [80.84745026, 21.96690941], [80.84673309, 21.96362114], [80.84577179, 21.96089935], [80.8433609, 21.95841026], [80.83938599, 21.95774078], [80.83583832, 21.95761108], [80.83178711, 21.95794106], [80.82885742, 21.95743942], [80.8245163, 21.95684052], [80.82168579, 21.95819855], [80.82022095, 21.95813179], [80.8184433, 21.95679092], [80.81958771, 21.95356941], [80.82102966, 21.95145035], [80.82115936, 21.95058823], [80.82221985, 21.94835091], [80.82338715, 21.94732094], [80.82627106, 21.94711113], [80.8289566, 21.94701958], [80.83074188, 21.94719124], [80.83184814, 21.9474411], [80.83338928, 21.94664001], [80.83502197, 21.94089127], [80.83561707, 21.93703079], [80.83656311, 21.93565941], [80.83654022, 21.93180084], [80.83589935, 21.92793083], [80.83452606, 21.92601967], [80.83251953, 21.92175102], [80.83139038, 21.92012024], [80.83006287, 21.91843033], [80.82699585, 21.91358185], [80.82620239, 21.9119606], [80.82453156, 21.9084301], [80.82544708, 21.90388107], [80.82380676, 21.89788055], [80.82456207, 21.89470863], [80.82422638, 21.89103127], [80.82405853, 21.88936043], [80.82543945, 21.88665009], [80.83010864, 21.88479042], [80.83141327, 21.88427925], [80.83406067, 21.88249969], [80.83660126, 21.87854958], [80.83959198, 21.87540054], [80.8396759, 21.87158012], [80.83763885, 21.86881256], [80.83666229, 21.86701965], [80.83702087, 21.86248016], [80.83994293, 21.85881042], [80.84117126, 21.85645294], [80.84041595, 21.85276031], [80.837677, 21.8518219], [80.8343277, 21.85069847], [80.83289337, 21.8490696], [80.8316803, 21.8461895], [80.83230591, 21.84013939], [80.83280945, 21.83749962], [80.83368683, 21.83479118], [80.83587646, 21.83214951], [80.83709717, 21.83176041], [80.837677, 21.82985115], [80.83660126, 21.82719994], [80.83558655, 21.82454109], [80.83380127, 21.8202095], [80.83304596, 21.81691933], [80.83238983, 21.81380081], [80.83183289, 21.81057167], [80.83171082, 21.80867004], [80.83170319, 21.80480957], [80.82990265, 21.80070114], [80.82797241, 21.79682159], [80.82550049, 21.79450035], [80.82388306, 21.79091072], [80.82110596, 21.78697968], [80.82081604, 21.78478813], [80.82041931, 21.78226089], [80.81918335, 21.77815819], [80.8182373, 21.77601051], [80.81682587, 21.77421761], [80.81446075, 21.76832008], [80.81355286, 21.76749992], [80.81156158, 21.7639904], [80.8106308, 21.7610302], [80.81044769, 21.75844002], [80.81033325, 21.75538063], [80.8116684, 21.7508297], [80.811203, 21.74749184], [80.80813599, 21.74644089], [80.80362701, 21.74605942], [80.79899597, 21.74535179], [80.79582977, 21.74427032], [80.79258728, 21.74322128], [80.78845978, 21.7412796], [80.78272247, 21.73957062], [80.77709198, 21.74086189], [80.77683258, 21.74430847], [80.7738266, 21.74982071], [80.76982117, 21.75205231], [80.76641846, 21.75513077], [80.76210022, 21.75791931], [80.75874329, 21.75715065], [80.75463867, 21.75700951], [80.74962616, 21.75773048], [80.74503326, 21.75826073], [80.74297333, 21.75796127], [80.74005127, 21.75649071], [80.73841858, 21.75354004], [80.73699951, 21.75065041], [80.73483276, 21.74764061], [80.73101044, 21.73919868], [80.72891235, 21.73516083], [80.72632599, 21.73102951], [80.72580719, 21.72948074], [80.72570801, 21.72578049], [80.72445679, 21.72249031], [80.72387695, 21.71970749], [80.72341919, 21.71747017], [80.72312927, 21.71562004], [80.72267151, 21.71447945], [80.7199173, 21.71364021], [80.71852875, 21.71186066], [80.7197113, 21.7097702], [80.72200775, 21.70730972], [80.72390747, 21.70583153], [80.72490692, 21.70433044], [80.72529602, 21.70100021], [80.72511292, 21.69828987], [80.72492218, 21.69777107], [80.72374725, 21.69360161], [80.72212982, 21.69059944], [80.72027588, 21.6877594], [80.71877289, 21.68481064], [80.71781921, 21.68307114], [80.71631622, 21.68081093], [80.71510315, 21.67867088], [80.71408844, 21.67728043], [80.712883, 21.67584038], [80.71190643, 21.67485046], [80.71089172, 21.67408943], [80.70923615, 21.67361069], [80.70735168, 21.67158127], [80.70874023, 21.66934967], [80.71003723, 21.66773987], [80.70944977, 21.66571045], [80.70749664, 21.66410065], [80.7078476, 21.6619606], [80.70833588, 21.66098976], [80.70909882, 21.65815926], [80.70979309, 21.65615082], [80.71050262, 21.65369034], [80.71045685, 21.65241051], [80.71121979, 21.64907074], [80.71235657, 21.64613914], [80.71463776, 21.64495087], [80.71684265, 21.64427948], [80.71910858, 21.64365959], [80.72049713, 21.64067078], [80.71955872, 21.63663292], [80.71968842, 21.63582039], [80.72025299, 21.63422012], [80.72097015, 21.63047028], [80.72117615, 21.62783051], [80.72210693, 21.62500191], [80.72245789, 21.62276077], [80.72138977, 21.62050056], [80.7216568, 21.61721992], [80.71990967, 21.61461067], [80.71781158, 21.61246109], [80.71617126, 21.60956955], [80.71351624, 21.60741043], [80.71083832, 21.60624123], [80.70939636, 21.60398102], [80.70903015, 21.60075951], [80.70935059, 21.59810066], [80.70915985, 21.59447289], [80.70905304, 21.59238815], [80.70913696, 21.58980942], [80.70923615, 21.58675003], [80.70955658, 21.58478928], [80.71164703, 21.58319092], [80.71253204, 21.58216095], [80.71369934, 21.58130074], [80.71598053, 21.57953072], [80.71689606, 21.57740974], [80.71821594, 21.57476807], [80.71884918, 21.57356071], [80.71953583, 21.57150078], [80.71922302, 21.56814957], [80.71723938, 21.56501961], [80.71608734, 21.56311035], [80.7151413, 21.5615406], [80.71383667, 21.55865097], [80.71354675, 21.55571175], [80.71492767, 21.55455971], [80.71935272, 21.55200005], [80.72087097, 21.5506897], [80.72412109, 21.54673958], [80.72583771, 21.54421043], [80.72807312, 21.54180908], [80.72972107, 21.54002953], [80.73065948, 21.53872108], [80.7308197, 21.53543091], [80.72988129, 21.53144836], [80.72833252, 21.52813911], [80.72702026, 21.52536964], [80.72583008, 21.52218819], [80.72477722, 21.51825905], [80.72442627, 21.51619148], [80.72437286, 21.51185989], [80.72426605, 21.50926018], [80.72429657, 21.50597954], [80.72464752, 21.50223923], [80.72377014, 21.49871063], [80.72197723, 21.4956398], [80.72233582, 21.49081039], [80.72426605, 21.48794174], [80.72583771, 21.48437119], [80.72727203, 21.48074913], [80.72824097, 21.4769001], [80.72891235, 21.47460175], [80.73021698, 21.47205162], [80.72911072, 21.46825981], [80.72770691, 21.46329117], [80.72624207, 21.45786095], [80.72392273, 21.45317078], [80.72120667, 21.44940186], [80.71803284, 21.44540024], [80.71482086, 21.44226074], [80.71209717, 21.43942833], [80.70818329, 21.43621063], [80.70423126, 21.43365288], [80.70162964, 21.43138123], [80.69904327, 21.42974091], [80.69754791, 21.42719841], [80.69764709, 21.42259026], [80.6985321, 21.41913033], [80.6992569, 21.41411972], [80.69814301, 21.41117859], [80.69706726, 21.40858078], [80.69507599, 21.4057312], [80.69287109, 21.40145111], [80.69335175, 21.39817047], [80.69326782, 21.3937912], [80.69165039, 21.38818169], [80.68946838, 21.3842392], [80.68781281, 21.38008118], [80.68583679, 21.37683105], [80.68416595, 21.37261009], [80.68097687, 21.36919022], [80.67827606, 21.36623001], [80.67517853, 21.36355019], [80.67150879, 21.35856056], [80.66998291, 21.35423088], [80.66845703, 21.34856987], [80.66638184, 21.34428978], [80.66494751, 21.34093285], [80.66291809, 21.3373394], [80.66130066, 21.33547974], [80.65991211, 21.3344326], [80.65653229, 21.3307724], [80.65177155, 21.33119011], [80.65042877, 21.32993126], [80.64829254, 21.32637978], [80.64438629, 21.32547951], [80.63817596, 21.32485962], [80.63356018, 21.32418823], [80.63179016, 21.32372093], [80.62832642, 21.32258987], [80.62491608, 21.32182121], [80.62328339, 21.32146072], [80.6206665, 21.32015991], [80.61775208, 21.31917191], [80.61299133, 21.32034111], [80.61096191, 21.32170105], [80.61009216, 21.32262039], [80.60851288, 21.32393265], [80.60531616, 21.3243103], [80.60234833, 21.32372093], [80.59941101, 21.32323074], [80.59739685, 21.32349968], [80.59316254, 21.32479095], [80.59127045, 21.32674026], [80.58946991, 21.32834053], [80.58672333, 21.32946014], [80.58307648, 21.33116913], [80.58188629, 21.33432961], [80.58241272, 21.33722115], [80.58162689, 21.34159088], [80.58027649, 21.34210014], [80.57788849, 21.34300041], [80.57543945, 21.34379005], [80.57176971, 21.34560966], [80.5690918, 21.34443092], [80.56636047, 21.34280014], [80.56417847, 21.34277916], [80.56136322, 21.3433094], [80.56053925, 21.34546089], [80.55982971, 21.34856987], [80.5580368, 21.35103035], [80.5583725, 21.35316277], [80.56109619, 21.35440254], [80.56376648, 21.35573959], [80.56417084, 21.3578701], [80.55967712, 21.36038017], [80.55901337, 21.36112976], [80.55821991, 21.36128807], [80.55519867, 21.36271095], [80.55023193, 21.36474037], [80.54577637, 21.36626053], [80.54424286, 21.3672905], [80.54091644, 21.36812019], [80.53964996, 21.36852074], [80.53688049, 21.36913109], [80.53424835, 21.37205124], [80.53311157, 21.37486076], [80.53203583, 21.37728119], [80.52971649, 21.38095093], [80.5268631, 21.38166809], [80.52420044, 21.3837204], [80.52166748, 21.38734055], [80.52037048, 21.38825035], [80.51943207, 21.38957024], [80.51651001, 21.39051819], [80.5147171, 21.39101982], [80.51140594, 21.39186096], [80.50887299, 21.39109039], [80.50569153, 21.39072037], [80.50289154, 21.39058113], [80.50055695, 21.3907795], [80.49633026, 21.39294052], [80.49343872, 21.39423943], [80.48989868, 21.39635086], [80.48549652, 21.39763832], [80.48396301, 21.3972702], [80.48145294, 21.39697075], [80.47897339, 21.39590836], [80.47561646, 21.39472961], [80.47476196, 21.39575005], [80.47387695, 21.3993206], [80.47135162, 21.39583969], [80.4681778, 21.39524078], [80.46676636, 21.39557076], [80.46431732, 21.39590073], [80.46285248, 21.39635086], [80.46016693, 21.3970108], [80.45635986, 21.39870071], [80.45475006, 21.39966011], [80.45333862, 21.40036011], [80.45069885, 21.40234947], [80.44831848, 21.4023304], [80.44764709, 21.39846039], [80.44706726, 21.39557076], [80.44558716, 21.39256096], [80.44426727, 21.39052963], [80.44320679, 21.38799286], [80.44329071, 21.38463974], [80.44374847, 21.37969017], [80.44364166, 21.37639999], [80.44294739, 21.37379837], [80.4404068, 21.37210083], [80.4372406, 21.37137985], [80.43560791, 21.37125015], [80.43353271, 21.37118149], [80.43048096, 21.37189293], [80.42758179, 21.37290955], [80.42685699, 21.37308121], [80.42494202, 21.37450027], [80.422966, 21.37524033], [80.42095184, 21.37568283], [80.41760254, 21.37565041], [80.41407776, 21.37527275], [80.41028595, 21.37545967], [80.40844727, 21.3760891], [80.40656281, 21.37640953], [80.40444183, 21.37581062]]]}}, {\\\"id\\\": \\\"17\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.20_1\\\", \\\"HASC_1\\\": \\\"IN.MH\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Maharashtra\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -8.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 460.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -844.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -385.0, \\\"geo-id\\\": 17, \\\"hpm25_child_popweighted\\\": -110.2, \\\"hpm25_female_popweighted\\\": -126.7, \\\"hpm25_male_popweighted\\\": -91.2, \\\"location\\\": \\\"Maharashtra\\\", \\\"mort_apm25_6cod_mean_total\\\": 17013.0, \\\"mort_hpm25_6cod_mean_total\\\": -30494.0, \\\"mort_tpm25_6cod_mean_total\\\": -13482.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[73.45597076, 15.88986206], [73.45597076, 15.88958359], [73.45625305, 15.88958359], [73.45625305, 15.88930607], [73.45652771, 15.88931179], [73.45652771, 15.88875198], [73.45680237, 15.88875198], [73.45680237, 15.88708115], [73.45625305, 15.88708305], [73.45625305, 15.88736057], [73.45597076, 15.88736057], [73.45597076, 15.88764191], [73.45569611, 15.88764191], [73.45569611, 15.88792038], [73.45541382, 15.88791847], [73.45541382, 15.88819313], [73.4548645, 15.88819313], [73.4548645, 15.88847446], [73.45458221, 15.88847446], [73.45458221, 15.88958359], [73.4548645, 15.88958359], [73.4548645, 15.88986206], [73.45597076, 15.88986206]]], [[[73.46263885, 15.89041996], [73.46263885, 15.89015102], [73.46347046, 15.89015102], [73.46347046, 15.8898592], [73.4640274, 15.88986206], [73.4640274, 15.88958359], [73.46430206, 15.88958359], [73.46430206, 15.88874912], [73.46457672, 15.88875198], [73.46457672, 15.88708115], [73.46430206, 15.88708305], [73.46430206, 15.88680458], [73.46375275, 15.88680458], [73.46375275, 15.88708305], [73.46347046, 15.88708115], [73.46347046, 15.88792038], [73.4631958, 15.88791847], [73.4631958, 15.88847446], [73.46263885, 15.88847065], [73.46263885, 15.88875198], [73.46180725, 15.88875198], [73.46180725, 15.88903046], [73.46152496, 15.88902664], [73.46152496, 15.88986206], [73.46180725, 15.8898592], [73.46180725, 15.89015102], [73.46208191, 15.89015102], [73.46208191, 15.89041996], [73.46263885, 15.89041996]]], [[[73.46624756, 15.89597225], [73.46624756, 15.89569378], [73.4668045, 15.89569378], [73.4668045, 15.89541626], [73.46708679, 15.89542007], [73.46708679, 15.89513969], [73.46736145, 15.89513969], [73.46736145, 15.89458179], [73.46763611, 15.8945837], [73.46763611, 15.89402771], [73.46736145, 15.89402962], [73.46736145, 15.89347172], [73.46624756, 15.89347172], [73.46624756, 15.89375019], [73.4659729, 15.89375019], [73.4659729, 15.89402962], [73.46569824, 15.89402962], [73.46568298, 15.89431095], [73.46541595, 15.89430618], [73.46541595, 15.89486217], [73.4651413, 15.89486217], [73.4651413, 15.89569378], [73.46541595, 15.89569378], [73.46541595, 15.89597225], [73.46624756, 15.89597225]]], [[[73.44319153, 16.10263824], [73.44319153, 16.10235977], [73.44347382, 16.10236168], [73.44347382, 16.10208321], [73.44374847, 16.10208321], [73.44374847, 16.10180473], [73.44403076, 16.10180473], [73.44403076, 16.10152626], [73.44431305, 16.10153008], [73.44431305, 16.10013962], [73.44403076, 16.10013962], [73.44403076, 16.09986115], [73.44374847, 16.09986115], [73.44374847, 16.09958076], [73.44346619, 16.09958076], [73.44346619, 16.09986115], [73.44319153, 16.09986115], [73.44319153, 16.10013962], [73.44291687, 16.10013962], [73.44291687, 16.10042], [73.44264221, 16.10041618], [73.44264221, 16.10097313], [73.44235992, 16.10097122], [73.44235992, 16.10263824], [73.44319153, 16.10263824]]], [[[73.46013641, 16.04569435], [73.46013641, 16.04541588], [73.4604187, 16.04541969], [73.4604187, 16.04514122], [73.46098328, 16.04514122], [73.46098328, 16.04486084], [73.46152496, 16.04486084], [73.46151733, 16.04458046], [73.46208191, 16.04458427], [73.46208191, 16.0443058], [73.46235657, 16.04430962], [73.46235657, 16.04346275], [73.46208191, 16.04347229], [73.46208191, 16.04319382], [73.46180725, 16.04319382], [73.46180725, 16.04291725], [73.46151733, 16.04292107], [73.46151733, 16.04125023], [73.46180725, 16.04125023], [73.46180725, 16.04071045], [73.46208191, 16.04071045], [73.46208191, 16.04042053], [73.46180725, 16.04042053], [73.46180725, 16.03957939], [73.46152496, 16.03958321], [73.46152496, 16.03902817], [73.46125031, 16.03903008], [73.46125031, 16.0387516], [73.4604187, 16.0387516], [73.4604187, 16.03903008], [73.45986176, 16.03902817], [73.45986176, 16.03930473], [73.4595871, 16.03930473], [73.4595871, 16.03958321], [73.45930481, 16.03958321], [73.45930481, 16.03986168], [73.45903015, 16.03986168], [73.45903015, 16.04014015], [73.45847321, 16.04014015], [73.45847321, 16.04042053], [73.45735931, 16.04042053], [73.45735931, 16.04071045], [73.45707703, 16.04071045], [73.45707703, 16.0418129], [73.45735931, 16.0418129], [73.45735931, 16.04264069], [73.4576416, 16.04263878], [73.4576416, 16.04319382], [73.45791626, 16.04319382], [73.45791626, 16.04347229], [73.45819092, 16.04346275], [73.45819092, 16.04403114], [73.45847321, 16.04403114], [73.45847321, 16.04430962], [73.45874786, 16.0443058], [73.45874786, 16.04569435], [73.46013641, 16.04569435]]], [[[73.03819275, 18.05208397], [73.03819275, 18.05152512], [73.03848267, 18.05153084], [73.03848267, 18.05097961], [73.03874969, 18.05097961], [73.03874969, 18.05014038], [73.0376358, 18.05014038], [73.0376358, 18.05042076], [73.0368042, 18.05041695], [73.0368042, 18.05069351], [73.03652954, 18.0506897], [73.03652954, 18.05153084], [73.03679657, 18.05153084], [73.03679657, 18.05181122], [73.03791809, 18.0518055], [73.03791809, 18.05208397], [73.03819275, 18.05208397]]], [[[72.9659729, 18.30125046], [72.9659729, 18.30014038], [72.96652985, 18.30014038], [72.96652985, 18.29986191], [72.9668045, 18.29986382], [72.9668045, 18.29958344], [72.96708679, 18.29958344], [72.96708679, 18.29930496], [72.96679688, 18.29931068], [72.96679688, 18.2990303], [72.96652985, 18.2990303], [72.96652985, 18.29875183], [72.9659729, 18.29875183], [72.9659729, 18.29846954], [72.96347046, 18.29846954], [72.96347046, 18.2990303], [72.9631958, 18.2990303], [72.9631958, 18.29931068], [72.96291351, 18.29930496], [72.96291351, 18.29986382], [72.96263885, 18.29986191], [72.96263885, 18.30014038], [72.96291351, 18.30013847], [72.96290588, 18.30068016], [72.96375275, 18.30069542], [72.96375275, 18.30097389], [72.96485901, 18.30097008], [72.96485901, 18.30125046], [72.9659729, 18.30125046]]], [[[73.07847595, 18.31014061], [73.07847595, 18.31041908], [73.0790329, 18.31041908], [73.0790329, 18.31014061], [73.07930756, 18.31014061], [73.07930756, 18.30987167], [73.07958221, 18.30987167], [73.07958221, 18.30931091], [73.07985687, 18.30931091], [73.07985687, 18.30903053], [73.07958221, 18.30903053], [73.07958221, 18.30874825], [73.07985687, 18.30874825], [73.07985687, 18.30846977], [73.07958221, 18.30847168], [73.07958221, 18.30708313], [73.07930756, 18.30708313], [73.07930756, 18.30624962], [73.07902527, 18.30624962], [73.07902527, 18.30597305], [73.07847595, 18.30597305], [73.07847595, 18.30569458], [73.07791901, 18.30569458], [73.07791901, 18.30541611], [73.07765198, 18.30541992], [73.07765198, 18.30513954], [73.07707977, 18.30513954], [73.07707977, 18.30486107], [73.07624817, 18.30486107], [73.07624817, 18.30541992], [73.07597351, 18.30541611], [73.07597351, 18.30569458], [73.07569122, 18.30569458], [73.07569122, 18.30597305], [73.07541656, 18.30597115], [73.07541656, 18.30652809], [73.07569122, 18.30652809], [73.07569122, 18.30792046], [73.07624817, 18.30791664], [73.07624817, 18.30847168], [73.07680511, 18.30847168], [73.07680511, 18.30874825], [73.07707977, 18.30874825], [73.07707977, 18.30931091], [73.07765198, 18.30931091], [73.07765198, 18.30987167], [73.07791901, 18.30987167], [73.07791901, 18.31014061], [73.07847595, 18.31014061]]], [[[73.08180237, 18.32180595], [73.08180237, 18.32208252], [73.08208466, 18.32208252], [73.08208466, 18.32125092], [73.08235931, 18.32125092], [73.08235931, 18.32097054], [73.08208466, 18.32097244], [73.08208466, 18.31902695], [73.08180237, 18.31903076], [73.08180237, 18.31875038], [73.08125305, 18.31875038], [73.08125305, 18.31903076], [73.08041382, 18.31902695], [73.08041382, 18.31958389], [73.08068848, 18.31958008], [73.08068848, 18.32014084], [73.08097076, 18.32013893], [73.08097076, 18.32069397], [73.08125305, 18.32069016], [73.08125305, 18.32152748], [73.08152771, 18.32152748], [73.08152771, 18.32180977], [73.08180237, 18.32180595]]], [[[73.08429718, 17.81875038], [73.08429718, 17.81847191], [73.0845871, 17.81847191], [73.0845871, 17.81819534], [73.08486176, 17.81820107], [73.08486176, 17.81792259], [73.08513641, 17.81792259], [73.08513641, 17.8176403], [73.0854187, 17.8176403], [73.0854187, 17.81736183], [73.08569336, 17.81736183], [73.08569336, 17.81708336], [73.08597565, 17.81708336], [73.08597565, 17.81652832], [73.08569336, 17.81653023], [73.08569336, 17.81568909], [73.0854187, 17.81569481], [73.0854187, 17.8148613], [73.08486176, 17.8148613], [73.08486176, 17.81458282], [73.0845871, 17.81458282], [73.0845871, 17.81430626], [73.08374786, 17.81430817], [73.08374786, 17.81402969], [73.08345795, 17.81402969], [73.08345795, 17.81430817], [73.08319092, 17.81430817], [73.08319092, 17.81541824], [73.08347321, 17.81541634], [73.08347321, 17.81569481], [73.08319092, 17.81568909], [73.08319092, 17.81653023], [73.08291626, 17.81652832], [73.08291626, 17.81708336], [73.0826416, 17.81708336], [73.0826416, 17.81736183], [73.08235931, 17.81736183], [73.08235931, 17.81820107], [73.0826416, 17.81819534], [73.0826416, 17.81847191], [73.08319092, 17.81847191], [73.08319092, 17.81875038], [73.08429718, 17.81875038]]], [[[72.78180695, 19.13541985], [72.78180695, 19.13513947], [72.78263092, 19.13513947], [72.78263092, 19.13486099], [72.78347015, 19.13486099], [72.78347015, 19.13236046], [72.78180695, 19.13236046], [72.78180695, 19.13264084], [72.78098297, 19.13264084], [72.78098297, 19.13292122], [72.7804184, 19.1329174], [72.7804184, 19.13347244], [72.78013611, 19.13347054], [72.78013611, 19.13402939], [72.7804184, 19.13402939], [72.7804184, 19.13430977], [72.78069305, 19.13430977], [72.78069305, 19.13486099], [72.78097534, 19.13486099], [72.78097534, 19.13513947], [72.78125, 19.13513947], [72.78125, 19.13541985], [72.78180695, 19.13541985]]], [[[72.81263733, 18.70652962], [72.81263733, 18.70625114], [72.81291962, 18.70625114], [72.81291962, 18.70597076], [72.81319427, 18.70597267], [72.81319427, 18.70541763], [72.81375122, 18.70541954], [72.81375122, 18.70514107], [72.81402588, 18.70514107], [72.81402588, 18.70486069], [72.81458282, 18.70486069], [72.81458282, 18.70458031], [72.81485748, 18.70458412], [72.81485748, 18.70375061], [72.81513977, 18.70375061], [72.81513977, 18.70292091], [72.81430817, 18.70292091], [72.81430817, 18.70264053], [72.81375122, 18.70264053], [72.81375122, 18.70236015], [72.81263733, 18.70236015], [72.81263733, 18.70292091], [72.81236267, 18.7029171], [72.81236267, 18.70347214], [72.81208038, 18.70347023], [72.81208038, 18.70486069], [72.81180573, 18.70486069], [72.81180573, 18.70597267], [72.81208038, 18.70597076], [72.81208038, 18.70652962], [72.81263733, 18.70652962]]], [[[72.84263611, 18.7084713], [72.84263611, 18.70819473], [72.8429184, 18.70819473], [72.8429184, 18.70736122], [72.84263611, 18.70736122], [72.84263611, 18.70625114], [72.84236145, 18.70625114], [72.84236145, 18.70569038], [72.84208679, 18.7056942], [72.84208679, 18.70513916], [72.84124756, 18.70514107], [72.84124756, 18.70625114], [72.84152985, 18.70625114], [72.84152985, 18.70709038], [72.8418045, 18.70708275], [72.8418045, 18.70819473], [72.84208679, 18.70819473], [72.84208679, 18.7084713], [72.84263611, 18.7084713]]], [[[72.86486053, 18.6356945], [72.86486053, 18.63513947], [72.86514282, 18.63513947], [72.86513519, 18.63458061], [72.86541748, 18.63458061], [72.86541748, 18.63402748], [72.86514282, 18.63402939], [72.86514282, 18.63347054], [72.86486053, 18.63347054], [72.86486053, 18.63319206], [72.86402893, 18.63319206], [72.86402893, 18.63264084], [72.86347198, 18.63264084], [72.86347198, 18.63347054], [72.86374664, 18.63347054], [72.86374664, 18.63375282], [72.86402893, 18.63375282], [72.86402893, 18.6348629], [72.86430359, 18.6348629], [72.86430359, 18.6356945], [72.86486053, 18.6356945]]], [[[72.9015274, 18.9643116], [72.9015274, 18.96402931], [72.90207672, 18.96402931], [72.90207672, 18.96375084], [72.9026413, 18.96375084], [72.9026413, 18.96347046], [72.9034729, 18.96347237], [72.9034729, 18.96319389], [72.90374756, 18.96319389], [72.90374756, 18.96152878], [72.90402985, 18.96153069], [72.90402985, 18.96096992], [72.90486145, 18.96096992], [72.90486145, 18.96125031], [72.90569305, 18.96125031], [72.90569305, 18.96070099], [72.90598297, 18.96070099], [72.90598297, 18.96014023], [72.90625, 18.96014023], [72.90625, 18.95930099], [72.90652466, 18.95930672], [72.90652466, 18.95874977], [72.90763855, 18.95874977], [72.90763855, 18.95930672], [72.90791321, 18.95930672], [72.90791321, 18.95958328], [72.90847015, 18.95958328], [72.90847015, 18.9584713], [72.90875244, 18.9584713], [72.90875244, 18.95569229], [72.90847015, 18.95569229], [72.90847015, 18.95375252], [72.90875244, 18.95375252], [72.90875244, 18.95319176], [72.90763855, 18.95319176], [72.90763855, 18.95404053], [72.90791321, 18.95404053], [72.90791321, 18.95514107], [72.90763855, 18.95513916], [72.90763855, 18.95597458], [72.90791321, 18.95597076], [72.90791321, 18.95736122], [72.90763855, 18.95736122], [72.90763855, 18.95792007], [72.90598297, 18.95792007], [72.90598297, 18.95736122], [72.90513611, 18.95736122], [72.90513611, 18.95708084], [72.90402985, 18.95708466], [72.90402985, 18.95680618], [72.90374756, 18.95681], [72.90374756, 18.95652962], [72.9034729, 18.95652962], [72.9034729, 18.95597076], [72.90319824, 18.95597458], [72.90319824, 18.95541573], [72.9026413, 18.95541954], [72.9026413, 18.95458031], [72.90235901, 18.95458221], [72.90235901, 18.95402718], [72.90207672, 18.95404053], [72.90207672, 18.95319176], [72.90180206, 18.95319366], [72.90180206, 18.95208359], [72.9015274, 18.95208359], [72.9015274, 18.95069504], [72.90125275, 18.95070076], [72.90125275, 18.9493103], [72.90097046, 18.94930077], [72.90097046, 18.94763947], [72.9006958, 18.94763947], [72.9006958, 18.94514084], [72.90040588, 18.94514084], [72.90040588, 18.94347], [72.9015274, 18.94347382], [72.9015274, 18.94291687], [72.90125275, 18.94292068], [72.90125275, 18.9426403], [72.90097046, 18.9426403], [72.90097046, 18.94235992], [72.9006958, 18.94236374], [72.9006958, 18.94208145], [72.90041351, 18.94208145], [72.90041351, 18.94152832], [72.90014648, 18.94153023], [72.90014648, 18.94124985], [72.89958191, 18.94124985], [72.89958191, 18.94096947], [72.89875031, 18.94096947], [72.89875031, 18.94181061], [72.89901733, 18.94181061], [72.89901733, 18.9426403], [72.89930725, 18.9426403], [72.89930725, 18.94431114], [72.89958191, 18.94431114], [72.89958191, 18.94625092], [72.8998642, 18.94625092], [72.8998642, 18.94791794], [72.90013885, 18.94791794], [72.90013885, 18.94958305], [72.90040588, 18.94958115], [72.90040588, 18.95124817], [72.9006958, 18.95124817], [72.9006958, 18.95264244], [72.90097046, 18.95264244], [72.90097046, 18.95430946], [72.90125275, 18.95430946], [72.90125275, 18.95514107], [72.9015274, 18.95513916], [72.9015274, 18.95569229], [72.90180206, 18.95569038], [72.90180206, 18.95625114], [72.90207672, 18.95625114], [72.90207672, 18.95681], [72.90235901, 18.95681], [72.90235901, 18.95792007], [72.90208435, 18.95791626], [72.90208435, 18.9584713], [72.90180206, 18.95846939], [72.90180206, 18.95874977], [72.9015274, 18.95874977], [72.9015274, 18.95903015], [72.90125275, 18.95902824], [72.90125275, 18.95930672], [72.90097046, 18.95930672], [72.90097046, 18.95958328], [72.9006958, 18.95958328], [72.9006958, 18.95986176], [72.90040588, 18.95985031], [72.90040588, 18.96014023], [72.89958191, 18.96014023], [72.89958191, 18.96125031], [72.89930725, 18.96125031], [72.89930725, 18.96181107], [72.89902496, 18.96180534], [72.89902496, 18.96208382], [72.89930725, 18.96208], [72.89930725, 18.96236038], [72.89958191, 18.96236038], [72.89958191, 18.96291733], [72.8998642, 18.96291733], [72.8998642, 18.96319389], [72.90013885, 18.96319389], [72.90013885, 18.96375084], [72.90040588, 18.96375084], [72.90040588, 18.9643116], [72.9015274, 18.9643116]]], [[[72.93902588, 18.97236061], [72.93902588, 18.97208023], [72.93958282, 18.97208595], [72.93958282, 18.9715271], [72.93985748, 18.97153091], [72.93985748, 18.97125053], [72.9404068, 18.97125053], [72.9404068, 18.97097015], [72.94097137, 18.97097206], [72.94097137, 18.97041702], [72.94124603, 18.97042084], [72.94124603, 18.96986008], [72.94152832, 18.96986389], [72.94152832, 18.9695816], [72.94180298, 18.9695816], [72.94180298, 18.96902847], [72.94152832, 18.96903992], [72.94152832, 18.96875191], [72.94180298, 18.96875191], [72.94180298, 18.96820068], [72.94152832, 18.96820068], [72.94152832, 18.9679203], [72.94180298, 18.9679203], [72.94180298, 18.96764183], [72.9420929, 18.96764183], [72.9420929, 18.96569061], [72.94180298, 18.96569443], [72.94180298, 18.9652195], [72.94180298, 18.96486092], [72.94152832, 18.96486092], [72.94152832, 18.9643116], [72.94124603, 18.9643116], [72.94124603, 18.96402931], [72.94097137, 18.96402931], [72.94097137, 18.96375084], [72.94069672, 18.96375084], [72.94069672, 18.96318817], [72.94041443, 18.96319389], [72.94041443, 18.96263885], [72.94013977, 18.96264076], [72.94013977, 18.96236038], [72.93985748, 18.96236038], [72.93985748, 18.96181107], [72.93958282, 18.96181107], [72.93958282, 18.96125031], [72.93930817, 18.96125031], [72.93930817, 18.96097183], [72.93902588, 18.96097183], [72.93902588, 18.96041679], [72.93875122, 18.96042061], [72.93875122, 18.96014023], [72.93846893, 18.96014023], [72.93846893, 18.95957947], [72.93819427, 18.95958328], [72.93819427, 18.95930672], [72.93791962, 18.95930672], [72.93791962, 18.95902824], [72.93763733, 18.95903015], [72.93763733, 18.95846939], [72.93736267, 18.9584713], [72.93736267, 18.95791626], [72.93708038, 18.95792007], [72.93708038, 18.95708084], [72.93680573, 18.95708466], [72.93680573, 18.95597458], [72.93653107, 18.95597458], [72.93653107, 18.95513916], [72.93624878, 18.95514107], [72.93624878, 18.95404053], [72.93596649, 18.95404053], [72.93596649, 18.95375252], [72.93569183, 18.95375252], [72.93569183, 18.95264244], [72.93514252, 18.95264244], [72.93514252, 18.95207977], [72.93402863, 18.95207977], [72.93402863, 18.95236015], [72.93374634, 18.95236015], [72.93374634, 18.95264244], [72.93347168, 18.95264244], [72.93347168, 18.95375252], [72.93318939, 18.95375252], [72.93318939, 18.95404053], [72.93289948, 18.95404053], [72.93289948, 18.95430946], [72.93264008, 18.95430565], [72.93264008, 18.95458221], [72.93041992, 18.95458031], [72.93041992, 18.95486069], [72.92986298, 18.95486069], [72.92986298, 18.95514107], [72.92930603, 18.95514107], [72.92930603, 18.95541954], [72.92903137, 18.95541573], [72.92903137, 18.95569229], [72.92874908, 18.95569229], [72.92874908, 18.95597458], [72.9284668, 18.95597076], [72.9284668, 18.95681], [72.92819214, 18.95680618], [72.92819214, 18.95708466], [72.92791748, 18.95708084], [72.92791748, 18.95763969], [72.92736053, 18.95763969], [72.92736053, 18.95792007], [72.92708588, 18.95792007], [72.92708588, 18.95763969], [72.92679596, 18.95763969], [72.92679596, 18.95792007], [72.92569733, 18.95791626], [72.92569733, 18.9584713], [72.92542267, 18.95846939], [72.92542267, 18.95903015], [72.92508698, 18.95902824], [72.92485809, 18.95902824], [72.92485809, 18.95930672], [72.92457581, 18.95930099], [72.92457581, 18.96014023], [72.92430878, 18.96013832], [72.92430878, 18.9630127], [72.92430878, 18.96347237], [72.92457581, 18.96347046], [72.92457581, 18.96402931], [72.92485809, 18.96402931], [72.92485809, 18.9643116], [72.92514038, 18.9643116], [72.92514038, 18.96486092], [72.92541504, 18.96486092], [72.92541504, 18.96513939], [72.92569733, 18.96513939], [72.92569733, 18.96598053], [72.92652893, 18.96598053], [72.92652893, 18.96653175], [72.92708588, 18.96653175], [72.92708588, 18.96681023], [72.92736053, 18.96680641], [72.92736053, 18.96736336], [72.92791748, 18.96735954], [72.92791748, 18.96764183], [72.9284668, 18.96764183], [72.9284668, 18.9679203], [72.92930603, 18.9679203], [72.92930603, 18.96820068], [72.93041992, 18.96819305], [72.93041992, 18.96847153], [72.93068695, 18.96846962], [72.93068695, 18.96875191], [72.93096924, 18.96875191], [72.93096924, 18.96903992], [72.93152618, 18.96902847], [72.93152618, 18.9695816], [72.93208313, 18.9695816], [72.93208313, 18.96986389], [72.93318939, 18.96986008], [72.93318939, 18.97014046], [72.93402863, 18.97014046], [72.93402863, 18.97042084], [72.93458557, 18.97041702], [72.93458557, 18.9706955], [72.93514252, 18.9706955], [72.93514252, 18.97097206], [72.93569183, 18.97097015], [72.93569183, 18.97125053], [72.93624878, 18.97125053], [72.93624878, 18.97180939], [72.93680573, 18.97180557], [72.93680573, 18.97208595], [72.93736267, 18.97208023], [72.93736267, 18.97236061], [72.93846893, 18.97236061], [72.93846893, 18.97208023], [72.93875122, 18.97208023], [72.93875122, 18.97236061], [72.93902588, 18.97236061]]], [[[73.02597046, 18.99986076], [73.02597046, 18.99958038], [73.02708435, 18.9995842], [73.02708435, 18.99930573], [73.02735901, 18.99930954], [73.02735901, 18.99901962], [73.0276413, 18.99902725], [73.0276413, 18.99875069], [73.02819824, 18.99875069], [73.02819824, 18.99792099], [73.0284729, 18.99792099], [73.0284729, 18.99625015], [73.02874756, 18.99625015], [73.02874756, 18.9948597], [73.0284729, 18.99486351], [73.0284729, 18.99291611], [73.0276413, 18.99291611], [73.0276413, 18.99319458], [73.02735901, 18.99319458], [73.02735901, 18.99458122], [73.02707672, 18.99458122], [73.02707672, 18.99514008], [73.02680206, 18.99514008], [73.02680206, 18.99542046], [73.0265274, 18.99541664], [73.02654266, 18.99625015], [73.02625275, 18.99625015], [73.02625275, 18.99708557], [73.02597046, 18.99707985], [73.02597046, 18.99736023], [73.0256958, 18.99736023], [73.0256958, 18.99986076], [73.02597046, 18.99986076]]], [[[72.73124695, 19.46847153], [72.73124695, 19.46819687], [72.73153687, 19.46820068], [72.73153687, 19.4679203], [72.73179626, 19.4679203], [72.73179626, 19.46735954], [72.73291779, 19.46736145], [72.73291779, 19.46708488], [72.73347473, 19.46708488], [72.73347473, 19.46736145], [72.73430634, 19.46736145], [72.73430634, 19.46680641], [72.73542023, 19.46681023], [72.73542023, 19.46652985], [72.73625183, 19.46652985], [72.73625183, 19.46569061], [72.73652649, 19.46569633], [72.73652649, 19.46541405], [72.73596954, 19.46541977], [72.73596954, 19.46513939], [72.73568726, 19.46513939], [72.73568726, 19.46458054], [72.73542023, 19.46458244], [72.73542023, 19.4640274], [72.73513794, 19.46403122], [72.73513794, 19.46375084], [72.73486328, 19.46375084], [72.73486328, 19.46347046], [72.73458099, 19.46347237], [72.73458099, 19.46263885], [72.73374939, 19.4626503], [72.73374939, 19.46236038], [72.7334671, 19.46236038], [72.7334671, 19.46042252], [72.73374939, 19.46042252], [72.73374939, 19.46014023], [72.73401642, 19.46014023], [72.73401642, 19.45959282], [72.73430634, 19.45959282], [72.73430634, 19.45929909], [72.73458099, 19.45930481], [72.73458099, 19.45902824], [72.73513794, 19.45902824], [72.73513794, 19.45846748], [72.73430634, 19.4584713], [72.73430634, 19.45819473], [72.73374939, 19.45819473], [72.73374939, 19.45791626], [72.73319244, 19.45791817], [72.73319244, 19.45763969], [72.73291779, 19.45763969], [72.73291779, 19.45736122], [72.73179626, 19.45736122], [72.73179626, 19.45791817], [72.73152924, 19.45791626], [72.73152924, 19.45819473], [72.73124695, 19.45819473], [72.73124695, 19.4584713], [72.73097229, 19.45846748], [72.73097229, 19.45874977], [72.73069763, 19.45874977], [72.73069763, 19.45902824], [72.73041534, 19.45902824], [72.73041534, 19.45930481], [72.7298584, 19.45929909], [72.7298584, 19.45959282], [72.72957611, 19.45959282], [72.72957611, 19.46014023], [72.72930908, 19.46014023], [72.72930908, 19.46042252], [72.72902679, 19.46042252], [72.72902679, 19.4607029], [72.72875214, 19.4607029], [72.72875214, 19.46125031], [72.72847748, 19.46125031], [72.72847748, 19.46153259], [72.72819519, 19.46152687], [72.72819519, 19.46208382], [72.7279129, 19.46208191], [72.7279129, 19.46403122], [72.72763824, 19.46403122], [72.72763824, 19.46430969], [72.72735596, 19.46430969], [72.72735596, 19.46486092], [72.7270813, 19.46486092], [72.7270813, 19.46569633], [72.72652435, 19.46569633], [72.72652435, 19.46708488], [72.72624969, 19.46708107], [72.72624969, 19.46763992], [72.7270813, 19.46763992], [72.7270813, 19.4679203], [72.72735596, 19.4679203], [72.72735596, 19.46820068], [72.72847748, 19.46820068], [72.72847748, 19.46763992], [72.72930908, 19.46763992], [72.72930908, 19.4679203], [72.72957611, 19.4679203], [72.72957611, 19.46820068], [72.73041534, 19.46819687], [72.73041534, 19.46847153], [72.73124695, 19.46847153]]], [[[79.51481628, 19.54076195], [79.51595306, 19.53680992], [79.51584625, 19.52235985], [79.51339722, 19.51806068], [79.49331665, 19.5051918], [79.48004913, 19.50381279], [79.47042084, 19.49745178], [79.46512604, 19.50901031], [79.45818329, 19.51896095], [79.44126129, 19.53351021], [79.43028259, 19.53510094], [79.42318726, 19.53284073], [79.41361237, 19.53347969], [79.40184784, 19.53983116], [79.38896942, 19.54891968], [79.38070679, 19.55585098], [79.37119293, 19.56154823], [79.36902618, 19.57123184], [79.34088898, 19.57377052], [79.3296814, 19.57368088], [79.32150269, 19.57175064], [79.31426239, 19.56552124], [79.30961609, 19.58201027], [79.30484009, 19.59015083], [79.29323578, 19.59672165], [79.26786041, 19.60666084], [79.25522614, 19.61120987], [79.24386597, 19.61255264], [79.23709106, 19.60948944], [79.23770142, 19.59954071], [79.24378204, 19.59334183], [79.24868011, 19.58686066], [79.25010681, 19.57768059], [79.23976898, 19.55948067], [79.23816681, 19.55093193], [79.23934174, 19.54204941], [79.23835754, 19.53276062], [79.2366333, 19.52679825], [79.23200226, 19.52075005], [79.22342682, 19.51700974], [79.21570587, 19.51058006], [79.20807648, 19.4986496], [79.20684814, 19.49167061], [79.20877838, 19.48479843], [79.22068787, 19.47558975], [79.22293854, 19.4677906], [79.21871185, 19.46450043], [79.18904114, 19.45870018], [79.17778778, 19.46069145], [79.1690979, 19.46776962], [79.15696716, 19.48554993], [79.14026642, 19.50111008], [79.12644958, 19.50649071], [79.11281586, 19.50978088], [79.10473633, 19.51274109], [79.10235596, 19.51935959], [79.10286713, 19.52795029], [79.09661102, 19.53047943], [79.07383728, 19.52861023], [79.06339264, 19.53125], [79.060112, 19.53872108], [79.0515213, 19.54527283], [79.03881836, 19.54499054], [79.01835632, 19.5399704], [79.01219177, 19.5437603], [79.00006104, 19.55937004], [78.99556732, 19.5610199], [78.99285889, 19.56204033], [78.98635101, 19.5570507], [78.97847748, 19.55092239], [78.97355652, 19.54990005], [78.96485138, 19.55033112], [78.9545517, 19.55183029], [78.94956207, 19.55747032], [78.95446014, 19.56272125], [78.96470642, 19.57028008], [78.96898651, 19.57345963], [78.97785187, 19.5799427], [78.98052979, 19.5850811], [78.978302, 19.59041023], [78.97132874, 19.59725952], [78.96562195, 19.60451126], [78.96286011, 19.61732292], [78.9646759, 19.62955284], [78.96800232, 19.63936996], [78.96895599, 19.64923286], [78.96167755, 19.65876961], [78.95419312, 19.66341019], [78.94359589, 19.66514015], [78.93498993, 19.66217995], [78.91590881, 19.66773033], [78.90379333, 19.66455841], [78.89097595, 19.65526009], [78.87793732, 19.65680122], [78.8588028, 19.65631104], [78.85912323, 19.66890907], [78.86321259, 19.67949295], [78.86398315, 19.68670082], [78.86347961, 19.69676971], [78.86167145, 19.70590019], [78.8573761, 19.71973991], [78.85691833, 19.73130035], [78.85357666, 19.73800087], [78.84562683, 19.75835037], [78.84433746, 19.75900078], [78.83830261, 19.76208115], [78.82528687, 19.76037979], [78.8171463, 19.76041985], [78.80760956, 19.75798988], [78.80317688, 19.7600708], [78.79695129, 19.76857948], [78.78486633, 19.77874947], [78.77321625, 19.77937126], [78.76322937, 19.77563095], [78.75224304, 19.77729034], [78.74308777, 19.77965927], [78.73834991, 19.77943039], [78.73184204, 19.77285004], [78.72473145, 19.76897049], [78.71644592, 19.76679993], [78.70918274, 19.7727108], [78.70178986, 19.78557968], [78.69590759, 19.789711], [78.68637085, 19.78993988], [78.64833832, 19.80146027], [78.63520813, 19.8037796], [78.61933899, 19.8087101], [78.61434174, 19.81326103], [78.60365295, 19.81750107], [78.59527588, 19.81735039], [78.5917511, 19.81541061], [78.58499146, 19.81168938], [78.57370758, 19.81380272], [78.55792236, 19.81561089], [78.52626801, 19.82165909], [78.51921082, 19.81990051], [78.51239014, 19.81427956], [78.50961304, 19.80118942], [78.50366974, 19.79241943], [78.49391937, 19.79314995], [78.48947144, 19.7985096], [78.48429108, 19.80718994], [78.47618866, 19.81636047], [78.46465302, 19.8162117], [78.44458771, 19.81923103], [78.42867279, 19.82311058], [78.40904236, 19.82986069], [78.3976593, 19.83640289], [78.38923645, 19.84617805], [78.38593292, 19.85270119], [78.38597107, 19.85569954], [78.38417816, 19.86362076], [78.38497162, 19.87389183], [78.38414764, 19.87922287], [78.37446594, 19.87927055], [78.36575317, 19.8828907], [78.34668732, 19.88140106], [78.33625031, 19.88319016], [78.32524109, 19.89048195], [78.32296753, 19.89497185], [78.32660675, 19.89937973], [78.3345871, 19.9043026], [78.3351059, 19.91011047], [78.32837677, 19.9160881], [78.31951141, 19.91546822], [78.31019592, 19.91274071], [78.30761719, 19.90849113], [78.29769135, 19.87329292], [78.29421234, 19.85555077], [78.29412842, 19.84955025], [78.30316925, 19.84583092], [78.33899689, 19.83917999], [78.34136963, 19.83294106], [78.33598328, 19.81866074], [78.33921051, 19.81351089], [78.35161591, 19.81035042], [78.36048889, 19.80574036], [78.36699677, 19.79454041], [78.36773682, 19.78108025], [78.36479187, 19.76733971], [78.3608017, 19.75398064], [78.35320282, 19.73775101], [78.34541321, 19.73442268], [78.34429932, 19.72433281], [78.34527588, 19.71356964], [78.33251953, 19.70850945], [78.32269287, 19.70364952], [78.32010651, 19.69671059], [78.31606293, 19.69055176], [78.3049469, 19.68843079], [78.28581238, 19.68967056], [78.27339172, 19.67015076], [78.26972198, 19.66312981], [78.2726593, 19.6601696], [78.28755951, 19.65446091], [78.29242706, 19.64416122], [78.29550171, 19.63183022], [78.29897308, 19.62341118], [78.3088913, 19.6114006], [78.31098938, 19.60417938], [78.31004333, 19.58671188], [78.31204224, 19.57856178], [78.3111496, 19.57176971], [78.30612183, 19.56744194], [78.2999115, 19.56678009], [78.29928589, 19.56129265], [78.29650879, 19.55838013], [78.28534698, 19.56034088], [78.27910614, 19.55820084], [78.28460693, 19.55039024], [78.2914505, 19.5431118], [78.29502869, 19.53728104], [78.29548645, 19.53083992], [78.29870605, 19.51356125], [78.29943085, 19.50412941], [78.30361176, 19.49376106], [78.31001282, 19.48643112], [78.31204987, 19.47925949], [78.31195831, 19.46590042], [78.3088913, 19.45640945], [78.29733276, 19.44882965], [78.29115295, 19.44879913], [78.28199005, 19.45298958], [78.27321625, 19.45384026], [78.26692963, 19.44792938], [78.26183319, 19.44009972], [78.2519989, 19.4300499], [78.24581146, 19.42898941], [78.23361969, 19.43288994], [78.22426605, 19.43403244], [78.21508026, 19.42705154], [78.20548248, 19.41435051], [78.19811249, 19.40744972], [78.18216705, 19.41176987], [78.18756866, 19.39562035], [78.18698883, 19.38454819], [78.18482208, 19.37629128], [78.18445587, 19.36821938], [78.18136597, 19.3607502], [78.17959595, 19.35301018], [78.18225098, 19.34544754], [78.18711853, 19.3386097], [78.19715118, 19.33172989], [78.19506073, 19.32496071], [78.19551086, 19.31438065], [78.19317627, 19.30294037], [78.18315125, 19.27896118], [78.18325806, 19.26116943], [78.186409, 19.24934959], [78.18331909, 19.24154091], [78.1700592, 19.23633003], [78.14974213, 19.23005104], [78.13926697, 19.23944092], [78.12670898, 19.24640274], [78.09938812, 19.24547958], [78.09512329, 19.24985123], [78.0822525, 19.25477028], [78.07514191, 19.24654961], [78.05755615, 19.23974991], [78.0511322, 19.24176025], [78.04804993, 19.24751282], [78.04762268, 19.25563049], [78.04944611, 19.26272964], [78.04574585, 19.27086067], [78.03288269, 19.27411079], [78.02728271, 19.2786808], [78.01824951, 19.29632759], [78.01161194, 19.30111122], [77.99588776, 19.30571747], [77.98549652, 19.30899048], [77.97690582, 19.32105064], [77.96665192, 19.3273201], [77.96270752, 19.33176994], [77.9489212, 19.34127998], [77.94062805, 19.34250069], [77.93723297, 19.33575058], [77.92632294, 19.33190918], [77.92204285, 19.32591248], [77.91227722, 19.3179512], [77.90577698, 19.31578064], [77.8995285, 19.31779099], [77.89325714, 19.32116127], [77.88804626, 19.31241035], [77.87522888, 19.30890083], [77.87111664, 19.30573082], [77.86087799, 19.30212975], [77.86264038, 19.2953701], [77.86084747, 19.28763962], [77.86192322, 19.28409958], [77.8753891, 19.27977943], [77.89305878, 19.27839279], [77.90067291, 19.27712822], [77.90570831, 19.26721954], [77.90039062, 19.25612068], [77.89187622, 19.25709915], [77.8846283, 19.26023102], [77.86738586, 19.25526047], [77.86808014, 19.24611092], [77.86540222, 19.2379303], [77.86228943, 19.23396111], [77.86152649, 19.22629166], [77.85845184, 19.21846962], [77.85233307, 19.20971107], [77.85267639, 19.20459175], [77.84654999, 19.19697952], [77.84453583, 19.18819046], [77.85839081, 19.18077278], [77.85301971, 19.17682076], [77.85423279, 19.1722908], [77.85385895, 19.16943169], [77.85035706, 19.16765022], [77.85016632, 19.16231155], [77.84874725, 19.15942955], [77.84924316, 19.15528107], [77.837677, 19.13830948], [77.83109283, 19.13565254], [77.83393097, 19.13273811], [77.83863831, 19.11885071], [77.84519196, 19.11421013], [77.84414673, 19.09607124], [77.84818268, 19.09259987], [77.8481369, 19.09008026], [77.84658813, 19.08851814], [77.84218597, 19.08677101], [77.8338089, 19.08653259], [77.82861328, 19.08494186], [77.8254776, 19.0916996], [77.82237244, 19.09639931], [77.81517029, 19.10366249], [77.80576324, 19.10334015], [77.80265045, 19.10196114], [77.80024719, 19.09887123], [77.79976654, 19.0945797], [77.80130768, 19.08440971], [77.79728699, 19.07459068], [77.79445648, 19.07336998], [77.79353333, 19.07121086], [77.79715729, 19.06488037], [77.79566956, 19.0610199], [77.79718018, 19.05130959], [77.79454041, 19.05019188], [77.7911377, 19.05065918], [77.78309631, 19.05483055], [77.77794647, 19.05437088], [77.77098846, 19.05615997], [77.76168823, 19.06204033], [77.75955963, 19.05930138], [77.76093292, 19.0512104], [77.75739288, 19.0285511], [77.76023865, 19.02264023], [77.76216125, 19.02050972], [77.76426697, 19.0196209], [77.76532745, 19.0153904], [77.76574707, 19.00737953], [77.76843262, 18.99938011], [77.76735687, 18.98142052], [77.7815094, 18.97632027], [77.78713226, 18.98428154], [77.81713867, 18.98237038], [77.81286621, 18.96006012], [77.81520081, 18.95923996], [77.81269073, 18.94945908], [77.82739258, 18.94572067], [77.83049774, 18.95020103], [77.85372925, 18.95227814], [77.84870148, 18.93138123], [77.84430695, 18.93032074], [77.84113312, 18.92146111], [77.84049988, 18.91130066], [77.85663605, 18.90607071], [77.8692627, 18.91032028], [77.88157654, 18.90853119], [77.88260651, 18.89637947], [77.88767242, 18.88512039], [77.89865875, 18.88373947], [77.89920044, 18.86792755], [77.90606689, 18.86731911], [77.92533875, 18.85921097], [77.92459869, 18.85414124], [77.93235779, 18.85093117], [77.92964935, 18.84649086], [77.94413757, 18.84229088], [77.94522858, 18.83210945], [77.94255066, 18.82229042], [77.92874908, 18.82172012], [77.90759277, 18.82951927], [77.85922241, 18.81406021], [77.83746338, 18.80746078], [77.8275528, 18.78601265], [77.82318115, 18.76850128], [77.81038666, 18.74024963], [77.80271912, 18.72924995], [77.80222321, 18.71611977], [77.78650665, 18.69432068], [77.78643799, 18.68412018], [77.76940155, 18.6905899], [77.76879883, 18.7016201], [77.76438141, 18.70793915], [77.75762939, 18.70709038], [77.74990845, 18.6978302], [77.74949646, 18.68978119], [77.74466705, 18.68388939], [77.73285675, 18.6760006], [77.72811127, 18.66420937], [77.73324585, 18.66212845], [77.73317719, 18.65570068], [77.73092651, 18.65532112], [77.73011017, 18.64812279], [77.72975922, 18.64558983], [77.72972107, 18.64273262], [77.73602295, 18.63089752], [77.74298859, 18.62140083], [77.74809265, 18.60531044], [77.74716187, 18.58908081], [77.73538208, 18.56318092], [77.73651123, 18.55480957], [77.72793579, 18.55154037], [77.71235657, 18.55443954], [77.68274689, 18.54080963], [77.67590332, 18.54133987], [77.66207886, 18.53325081], [77.65756989, 18.5272007], [77.64528656, 18.53630066], [77.64946747, 18.54133034], [77.65219879, 18.54963112], [77.64955139, 18.54966164], [77.64881134, 18.55261993], [77.64048004, 18.55393028], [77.63440704, 18.54518127], [77.62906647, 18.55064011], [77.61633301, 18.54866982], [77.61582184, 18.54294014], [77.61329651, 18.54239082], [77.61087036, 18.54776955], [77.59726715, 18.54754066], [77.59819031, 18.5350399], [77.59329224, 18.52802086], [77.59329224, 18.52314186], [77.60040283, 18.52497101], [77.60144806, 18.52194977], [77.59646606, 18.51499939], [77.58706665, 18.50984955], [77.58627319, 18.50292015], [77.59388733, 18.49386978], [77.60283661, 18.49138069], [77.60375214, 18.4852581], [77.60106659, 18.47421074], [77.59311676, 18.47351074], [77.59075928, 18.48110962], [77.57652283, 18.48377991], [77.57063293, 18.46685982], [77.56040192, 18.46749115], [77.55809021, 18.465271], [77.54651642, 18.46571922], [77.54619598, 18.46338272], [77.54888153, 18.46080971], [77.54979706, 18.45796967], [77.55908966, 18.45800018], [77.58364868, 18.45355034], [77.58328247, 18.44719124], [77.58521271, 18.44544983], [77.5826416, 18.44306946], [77.57411957, 18.4393425], [77.56693268, 18.43861008], [77.56017303, 18.43504906], [77.54644775, 18.44055939], [77.53450775, 18.44239998], [77.52848053, 18.44048119], [77.52593994, 18.427351], [77.53598022, 18.42345047], [77.53515625, 18.42118073], [77.54413605, 18.42041016], [77.5552063, 18.4178524], [77.54930115, 18.3877182], [77.54155731, 18.38521957], [77.53050232, 18.37577057], [77.52140045, 18.36465073], [77.51950073, 18.3492527], [77.52732849, 18.33940125], [77.54219055, 18.33390045], [77.55335999, 18.33122253], [77.56691742, 18.3179493], [77.57022858, 18.30817986], [77.55503082, 18.29831123], [77.54995728, 18.29134941], [77.5395813, 18.29383087], [77.52388763, 18.30303192], [77.51978302, 18.30736923], [77.50950623, 18.30673027], [77.50843048, 18.3021698], [77.51264191, 18.28198051], [77.51020813, 18.27844048], [77.4977417, 18.27334976], [77.49223328, 18.26588058], [77.48034668, 18.26865959], [77.47480774, 18.26229095], [77.46923065, 18.26316071], [77.46539307, 18.25996017], [77.45079041, 18.26596069], [77.44522095, 18.27012062], [77.44489288, 18.27724075], [77.4369278, 18.28203964], [77.43461609, 18.29298019], [77.43637085, 18.30649185], [77.42780304, 18.30917931], [77.42500305, 18.30467033], [77.4078064, 18.29956055], [77.39628601, 18.30298042], [77.3925705, 18.30093002], [77.38128662, 18.30595016], [77.36252594, 18.30829048], [77.35881042, 18.31064987], [77.35542297, 18.31851959], [77.36701965, 18.32232285], [77.37394714, 18.32950974], [77.37800598, 18.32868958], [77.38089752, 18.33193016], [77.37930298, 18.33910179], [77.38617706, 18.33819008], [77.38922882, 18.34078979], [77.3928299, 18.34054947], [77.39277649, 18.3456707], [77.39594269, 18.34464073], [77.39833069, 18.34749985], [77.39824677, 18.35353088], [77.39182281, 18.36593056], [77.40067291, 18.37017059], [77.40788269, 18.37849045], [77.41011047, 18.38853073], [77.40049744, 18.39780045], [77.39263916, 18.39702988], [77.36975098, 18.40070915], [77.3644104, 18.42984962], [77.36535645, 18.43808937], [77.36962891, 18.44765091], [77.35407257, 18.44874191], [77.34529114, 18.43437195], [77.34207916, 18.43029022], [77.33731079, 18.43544006], [77.33338165, 18.44189072], [77.33271027, 18.44845963], [77.32601929, 18.44885063], [77.32557678, 18.45512009], [77.31741333, 18.45379066], [77.31327057, 18.43938065], [77.30226135, 18.43847084], [77.29476929, 18.43268013], [77.26455688, 18.41838074], [77.25836182, 18.41041946], [77.24912262, 18.40825272], [77.24022675, 18.40864754], [77.23639679, 18.39981079], [77.23287201, 18.38612747], [77.24503326, 18.3705883], [77.24163055, 18.3663826], [77.23081207, 18.36557961], [77.22136688, 18.34720993], [77.22727203, 18.34490013], [77.22297668, 18.33780098], [77.21691132, 18.32489014], [77.2099762, 18.31374168], [77.20014954, 18.31917], [77.19541168, 18.31270981], [77.19764709, 18.29552078], [77.20446014, 18.29047966], [77.20617676, 18.27795982], [77.19882965, 18.27923012], [77.19165039, 18.27429008], [77.17784119, 18.28185081], [77.17053223, 18.28087044], [77.16738129, 18.27345085], [77.16567993, 18.25592041], [77.15719604, 18.25309181], [77.15141296, 18.23793983], [77.14776611, 18.23764992], [77.14768982, 18.22140121], [77.14879608, 18.22145271], [77.1506424, 18.22153091], [77.14998627, 18.21656036], [77.14221954, 18.21604919], [77.13949585, 18.20724106], [77.13114929, 18.20618057], [77.12098694, 18.20670128], [77.11662292, 18.20240974], [77.10659027, 18.20181084], [77.09554291, 18.19510078], [77.09886169, 18.19114113], [77.10292816, 18.18630981], [77.11633301, 18.16760826], [77.10888672, 18.15269089], [77.09661865, 18.15813065], [77.09268188, 18.15697861], [77.08925629, 18.15596008], [77.08618164, 18.15027046], [77.06910706, 18.14944077], [77.05767059, 18.15236282], [77.05767059, 18.15592957], [77.05031586, 18.16127968], [77.04944611, 18.17320824], [77.0381012, 18.18131065], [77.03283691, 18.18378067], [77.03238678, 18.18300056], [77.03032684, 18.17934036], [77.02171326, 18.17822075], [77.02274323, 18.17124939], [77.02398682, 18.16267967], [76.99775696, 18.16684914], [76.99529266, 18.17333031], [76.99547577, 18.1783905], [76.99295044, 18.1820507], [76.99146271, 18.18665123], [76.98789215, 18.18847847], [76.98055267, 18.18939972], [76.97985077, 18.18740082], [76.97090149, 18.18686104], [76.95881653, 18.18614006], [76.95410919, 18.18489075], [76.95095825, 18.17247963], [76.9437561, 18.15473938], [76.93335724, 18.15790939], [76.92536926, 18.14481926], [76.92765808, 18.13986015], [76.9317627, 18.13657951], [76.92999268, 18.13225174], [76.92417908, 18.12446022], [76.92228699, 18.12018967], [76.92256165, 18.11610985], [76.93215179, 18.11098289], [76.94252777, 18.11141014], [76.95339203, 18.11011124], [76.95857239, 18.10643005], [76.96827698, 18.09711075], [76.96734619, 18.09263992], [76.96431732, 18.08821106], [76.95482635, 18.08535957], [76.94973755, 18.0823307], [76.94702911, 18.07376099], [76.94948578, 18.06826973], [76.95266724, 18.06340981], [76.9506073, 18.0582695], [76.94844818, 18.04866028], [76.94863129, 18.04572105], [76.95430756, 18.04273033], [76.95464325, 18.03968048], [76.95205688, 18.03771019], [76.93863678, 18.03722954], [76.91771698, 18.03322983], [76.91940308, 18.0220108], [76.92024994, 18.01375961], [76.9176712, 18.01234055], [76.91816711, 18.00187111], [76.91848755, 17.99868965], [76.91763306, 17.99625969], [76.9196701, 17.99064064], [76.91958618, 17.98538017], [76.91823578, 17.9728508], [76.91726685, 17.96047974], [76.91322327, 17.93720818], [76.91918945, 17.93666077], [76.91834259, 17.92310905], [76.91644287, 17.91509056], [76.91320038, 17.91379929], [76.90020752, 17.91468811], [76.89659882, 17.90802002], [76.89366913, 17.90737152], [76.89240265, 17.9028511], [76.88938141, 17.89718056], [76.88320923, 17.89707947], [76.88117981, 17.89305115], [76.87526703, 17.89273071], [76.87185669, 17.89474106], [76.85383606, 17.89783859], [76.8469162, 17.89640045], [76.83175659, 17.89067268], [76.83307648, 17.88274956], [76.82036591, 17.88445282], [76.81713104, 17.88309097], [76.81108093, 17.88408852], [76.80822754, 17.88309097], [76.80535126, 17.87420845], [76.80625153, 17.87049294], [76.80280304, 17.86832047], [76.7974472, 17.8693409], [76.77456665, 17.87696075], [76.77326202, 17.8786602], [76.77379608, 17.8822403], [76.77310944, 17.88515091], [76.7701416, 17.89236069], [76.76595306, 17.89842987], [76.74297333, 17.89902115], [76.74067688, 17.89801025], [76.73958588, 17.89204979], [76.73964691, 17.88362122], [76.73745728, 17.85705948], [76.74578857, 17.8583107], [76.75456238, 17.85658836], [76.75972748, 17.85206032], [76.76434326, 17.84950066], [76.76573944, 17.85079956], [76.77974701, 17.83633041], [76.78546906, 17.83146286], [76.78816986, 17.82647133], [76.78481293, 17.81963921], [76.78141785, 17.8151207], [76.77947998, 17.81028938], [76.77979279, 17.80591965], [76.77628326, 17.79938126], [76.77002716, 17.79701996], [76.7663269, 17.79664993], [76.76275635, 17.78710938], [76.74887848, 17.78635025], [76.74777222, 17.78360939], [76.74401093, 17.78346062], [76.74355316, 17.78079033], [76.73943329, 17.77913094], [76.72463226, 17.78507805], [76.71938324, 17.7852993], [76.71570587, 17.78191948], [76.71244812, 17.77509117], [76.7128067, 17.7713604], [76.71720123, 17.76984978], [76.72096252, 17.76758957], [76.71909332, 17.76133156], [76.7179718, 17.74786949], [76.72193146, 17.74802971], [76.72650146, 17.7403698], [76.72760773, 17.73699951], [76.70347595, 17.72912025], [76.69815063, 17.72603989], [76.70210266, 17.72371101], [76.70345306, 17.7186203], [76.70079803, 17.70726967], [76.69235992, 17.70526123], [76.69087219, 17.70194054], [76.69122314, 17.6981411], [76.69313049, 17.69376183], [76.69055176, 17.67995262], [76.68826294, 17.67851067], [76.67814636, 17.68734169], [76.67164612, 17.68914032], [76.66313934, 17.68786049], [76.65983582, 17.69919014], [76.65812683, 17.70853043], [76.6552124, 17.71640015], [76.65083313, 17.72083092], [76.63743591, 17.72410965], [76.63065338, 17.72900009], [76.62979889, 17.74187088], [76.62695313, 17.75596046], [76.62336731, 17.7578907], [76.61444855, 17.76831245], [76.60951233, 17.76597977], [76.60690308, 17.75958061], [76.60405731, 17.75583076], [76.59880066, 17.72797012], [76.59324646, 17.71755981], [76.5870285, 17.70788956], [76.57720947, 17.70314026], [76.57322693, 17.70216942], [76.56942749, 17.70374107], [76.5681076, 17.7397995], [76.56459045, 17.7536602], [76.56936646, 17.75638008], [76.57330322, 17.76000023], [76.56754303, 17.76288986], [76.55977631, 17.76313972], [76.53820801, 17.75893974], [76.53159332, 17.75852966], [76.52632141, 17.75936127], [76.5236969, 17.75889015], [76.52503967, 17.73467255], [76.52482605, 17.72290993], [76.52363586, 17.71523094], [76.51095581, 17.71591949], [76.49225616, 17.71494102], [76.48636627, 17.71352005], [76.48562622, 17.69269943], [76.48442841, 17.68442917], [76.48464966, 17.66963005], [76.48929596, 17.66066933], [76.45230103, 17.6555481], [76.45153809, 17.65151024], [76.4408493, 17.64937019], [76.44275665, 17.6418705], [76.43477631, 17.64453125], [76.4287262, 17.64441109], [76.42723083, 17.63978004], [76.42579651, 17.62832069], [76.42410278, 17.62154007], [76.42074585, 17.61424065], [76.41818237, 17.60583115], [76.4156723, 17.60420036], [76.38207245, 17.60078049], [76.37301636, 17.59793854], [76.35948181, 17.5962925], [76.34870148, 17.59539986], [76.33641052, 17.59604073], [76.33167267, 17.59486961], [76.33290863, 17.57383156], [76.33423615, 17.56348991], [76.33724213, 17.5551796], [76.34002686, 17.54257011], [76.34583282, 17.54021072], [76.35481262, 17.53873062], [76.36090088, 17.5362606], [76.36460876, 17.52852058], [76.36612701, 17.52217293], [76.3664093, 17.51671028], [76.35601807, 17.51337051], [76.34633636, 17.51148033], [76.34372711, 17.50811958], [76.34348297, 17.49435043], [76.34594727, 17.49159813], [76.35518646, 17.49416924], [76.36659241, 17.49529266], [76.37503815, 17.49352074], [76.37229919, 17.48578072], [76.3500061, 17.47212982], [76.3427887, 17.47037125], [76.33776855, 17.47040939], [76.33080292, 17.46881866], [76.33084106, 17.46162033], [76.33365631, 17.43229294], [76.34195709, 17.43383026], [76.3638916, 17.43555069], [76.37317657, 17.43441963], [76.36988068, 17.42304039], [76.37004852, 17.40789986], [76.36199951, 17.37508011], [76.4080658, 17.3692894], [76.4105072, 17.35413933], [76.4106369, 17.34769058], [76.4020462, 17.34399033], [76.39299011, 17.33628082], [76.38389587, 17.31954193], [76.38170624, 17.31180954], [76.35936737, 17.31028938], [76.35227203, 17.31059074], [76.3506012, 17.32772064], [76.34361267, 17.34993172], [76.33473969, 17.3498497], [76.31704712, 17.34540939], [76.31301117, 17.34327126], [76.318367, 17.33184052], [76.31720734, 17.32944107], [76.30502319, 17.32845116], [76.29589844, 17.32863808], [76.2857666, 17.33035088], [76.27587891, 17.33053017], [76.27263641, 17.34794998], [76.27017975, 17.35653114], [76.26494598, 17.35816193], [76.25627899, 17.35738945], [76.25, 17.35790062], [76.248909, 17.36213112], [76.2504425, 17.36667061], [76.24671173, 17.3678894], [76.24436188, 17.37467957], [76.2303772, 17.37026024], [76.22899628, 17.36322975], [76.20352173, 17.35878944], [76.19320679, 17.35859108], [76.1829071, 17.35650063], [76.17603302, 17.35238075], [76.17233276, 17.34873009], [76.17350769, 17.33223915], [76.1763382, 17.32146072], [76.17891693, 17.31391907], [76.18260193, 17.31430054], [76.18383026, 17.31104279], [76.17575836, 17.29721069], [76.17188263, 17.29758072], [76.1638031, 17.30033112], [76.16422272, 17.31925964], [76.16314697, 17.34090996], [76.14566803, 17.34793282], [76.1375885, 17.35256958], [76.12120819, 17.36634064], [76.11667633, 17.36622047], [76.10199738, 17.36226082], [76.09596252, 17.35781288], [76.09276581, 17.35444069], [76.09046936, 17.35056114], [76.09407806, 17.34709167], [76.09252167, 17.34367943], [76.08696747, 17.33844757], [76.08685303, 17.3337307], [76.08499146, 17.3321209], [76.07874298, 17.3300705], [76.0734787, 17.33232117], [76.0632019, 17.3519001], [76.06046295, 17.35393143], [76.05452728, 17.35429955], [76.03666687, 17.34896278], [76.02127838, 17.34931183], [76.01545715, 17.35061073], [76.00914001, 17.34752274], [76.00417328, 17.3427906], [76.00026703, 17.33774948], [75.98071289, 17.33620071], [75.9715271, 17.33646011], [75.95981598, 17.33383179], [75.94174957, 17.32485962], [75.93115234, 17.32411003], [75.91622162, 17.33897018], [75.9107132, 17.34581947], [75.89808655, 17.35075951], [75.8936615, 17.35362053], [75.89198303, 17.36079979], [75.89639282, 17.3699894], [75.89697266, 17.37700081], [75.89643097, 17.39497948], [75.89435577, 17.40590286], [75.89025879, 17.41360092], [75.88723755, 17.41732979], [75.88243103, 17.41900063], [75.87844849, 17.41654015], [75.8771286, 17.41135025], [75.87909698, 17.40493965], [75.87890625, 17.40032959], [75.87666321, 17.39697075], [75.86487579, 17.38644028], [75.86196899, 17.38585091], [75.85910797, 17.38896942], [75.85600281, 17.40768242], [75.8478775, 17.41534042], [75.83889008, 17.42054176], [75.82779694, 17.42371941], [75.82472229, 17.42284966], [75.82199097, 17.41967964], [75.82025146, 17.4065609], [75.81729126, 17.40121078], [75.81627655, 17.39781189], [75.81768799, 17.38804054], [75.81759644, 17.38072968], [75.81505585, 17.37384987], [75.8113327, 17.3699398], [75.80233765, 17.37010193], [75.79102325, 17.37298012], [75.78231812, 17.37881279], [75.77661896, 17.38820267], [75.76976776, 17.40684128], [75.76412201, 17.40842056], [75.75875854, 17.40841103], [75.75052643, 17.41290092], [75.73703766, 17.4218998], [75.7339859, 17.42165947], [75.72901154, 17.41950989], [75.72236633, 17.4117794], [75.71517944, 17.40893173], [75.70806122, 17.40831947], [75.69721222, 17.41056824], [75.69119263, 17.41261101], [75.68711853, 17.41730118], [75.68080902, 17.43616295], [75.68081665, 17.45397186], [75.6775589, 17.45797157], [75.6704483, 17.45932007], [75.66230011, 17.45968056], [75.65618134, 17.46751022], [75.64955902, 17.47340965], [75.6355896, 17.47751045], [75.63288879, 17.46964073], [75.63127136, 17.46117973], [75.62532806, 17.45811081], [75.61873627, 17.43911171], [75.61543274, 17.4220295], [75.61013794, 17.41954041], [75.61055756, 17.41711998], [75.61495209, 17.40956116], [75.61672211, 17.39863968], [75.61580658, 17.39185905], [75.61057281, 17.39200974], [75.60331726, 17.38986015], [75.59815979, 17.38610077], [75.58817291, 17.3830204], [75.58371735, 17.38220024], [75.57853699, 17.38293076], [75.58405304, 17.35134125], [75.58483124, 17.34977913], [75.58994293, 17.34968948], [75.59810638, 17.34511948], [75.61310577, 17.34229088], [75.61604309, 17.32876015], [75.61374664, 17.31944084], [75.60595703, 17.3032608], [75.62468719, 17.29380035], [75.62786865, 17.28812027], [75.63109589, 17.2798481], [75.63336945, 17.27738953], [75.63231659, 17.27222061], [75.65747833, 17.27057076], [75.65988922, 17.26144028], [75.66091919, 17.23999977], [75.66281891, 17.22793961], [75.66387939, 17.21375084], [75.662117, 17.20833015], [75.65743256, 17.20378113], [75.64359283, 17.19408035], [75.64264679, 17.18815994], [75.63069916, 17.18616104], [75.63018799, 17.18144989], [75.62851715, 17.18074989], [75.62802124, 17.17012024], [75.6313858, 17.16007042], [75.64273071, 17.14763832], [75.64871216, 17.13880157], [75.64968872, 17.13318062], [75.65273285, 17.13273048], [75.65363312, 17.11313057], [75.67410278, 17.11355019], [75.67550659, 17.10112953], [75.67848969, 17.09417152], [75.67739105, 17.08774948], [75.68013763, 17.07826805], [75.68107605, 17.07114029], [75.67840576, 17.06286049], [75.6709671, 17.06157112], [75.66268921, 17.06178284], [75.65439606, 17.05508995], [75.64787292, 17.04657173], [75.64375305, 17.03639984], [75.64819336, 17.03269005], [75.65399933, 17.03063965], [75.66216278, 17.03244972], [75.67224121, 17.03573036], [75.67310333, 17.02617073], [75.67053986, 16.9988308], [75.66867828, 16.98321915], [75.66883087, 16.97776031], [75.66938019, 16.97562981], [75.67263031, 16.97408104], [75.67459106, 16.96935081], [75.67842102, 16.96394157], [75.67460632, 16.96026993], [75.67137909, 16.95853806], [75.66374969, 16.95788193], [75.65561676, 16.95611], [75.64962769, 16.95199966], [75.64502716, 16.95103264], [75.63938904, 16.95915985], [75.63633728, 16.96581078], [75.6309433, 16.96714973], [75.62101746, 16.96775055], [75.61065674, 16.96961975], [75.60965729, 16.99893951], [75.60951996, 17.00311089], [75.59944153, 17.00522041], [75.57579803, 17.00779915], [75.56991577, 17.00617027], [75.56929779, 16.99885941], [75.57034302, 16.96362114], [75.55847168, 16.96434975], [75.54281616, 16.96314049], [75.53286743, 16.96665192], [75.53000641, 16.96582985], [75.52406311, 16.95874023], [75.51700592, 16.95193291], [75.51065063, 16.94730949], [75.5092926, 16.94859123], [75.50187683, 16.94540977], [75.49249268, 16.9428997], [75.49301147, 16.94518089], [75.49263, 16.95150948], [75.49178314, 16.95783043], [75.48969269, 16.96538925], [75.48249817, 16.97595024], [75.46858978, 16.97957039], [75.46791077, 16.98533058], [75.45353699, 16.98265076], [75.44380188, 16.97949028], [75.4388504, 16.97088051], [75.43102264, 16.96346092], [75.41683197, 16.96949959], [75.39476013, 16.97639275], [75.37168884, 16.96869087], [75.36435699, 16.9636097], [75.35957336, 16.9568882], [75.34532928, 16.95252037], [75.33796692, 16.9535408], [75.30612946, 16.95466995], [75.2947464, 16.95412827], [75.28843689, 16.95477295], [75.28462219, 16.95355034], [75.28359985, 16.94294167], [75.28557587, 16.90943146], [75.29177856, 16.90113831], [75.28749847, 16.88321114], [75.28565216, 16.87879944], [75.28277588, 16.87424088], [75.26830292, 16.86086082], [75.25797272, 16.86213112], [75.24867249, 16.86452866], [75.24344635, 16.86449051], [75.24099731, 16.86296082], [75.23565674, 16.85419083], [75.23291016, 16.84554291], [75.23001099, 16.84091949], [75.21585846, 16.84033966], [75.18828583, 16.84089088], [75.18319702, 16.84204102], [75.18900299, 16.86189842], [75.19252014, 16.86955833], [75.18965912, 16.87350082], [75.18084717, 16.86751175], [75.17175293, 16.86479759], [75.16438293, 16.86557961], [75.15052795, 16.86940956], [75.14112854, 16.87354088], [75.13838959, 16.8782692], [75.13710785, 16.88459969], [75.13839722, 16.89292145], [75.12763214, 16.89718056], [75.1235733, 16.90043831], [75.12200165, 16.90723038], [75.11875916, 16.90997124], [75.10692596, 16.9095211], [75.09796906, 16.91386986], [75.0947113, 16.92115021], [75.09414673, 16.94722939], [75.09041595, 16.94865036], [75.08294678, 16.94659805], [75.0654068, 16.93926048], [75.05523682, 16.93885994], [75.05078888, 16.93966103], [75.04814911, 16.93871117], [75.04535675, 16.93425941], [75.03449249, 16.92873955], [75.03190613, 16.92567062], [75.03011322, 16.93114281], [75.03029633, 16.94153023], [75.01140594, 16.94258118], [75.00370026, 16.94582748], [74.99954224, 16.94189835], [74.99449158, 16.93503952], [74.98581696, 16.92901993], [74.98142242, 16.93061066], [74.97528839, 16.93460083], [74.96949768, 16.93591118], [74.96671295, 16.93564987], [74.95999908, 16.9329319], [74.95802307, 16.92914009], [74.95453644, 16.93000031], [74.95243073, 16.93622017], [74.94834137, 16.93581963], [74.93839264, 16.94099045], [74.9285202, 16.93520164], [74.92703247, 16.92562294], [74.93694305, 16.92073059], [74.9382019, 16.91646957], [74.94407654, 16.91327095], [74.94803619, 16.90917015], [74.95284271, 16.90648079], [74.96726227, 16.90538025], [74.96409607, 16.8778801], [74.95606995, 16.87729073], [74.94861603, 16.88009071], [74.94513702, 16.87712288], [74.93966675, 16.87652016], [74.93984985, 16.87232018], [74.93708038, 16.86916161], [74.9315033, 16.86954117], [74.92778778, 16.86334991], [74.91195679, 16.85593987], [74.91330719, 16.84144974], [74.91306305, 16.83074951], [74.91581726, 16.81022072], [74.91586304, 16.78568077], [74.9238205, 16.76995087], [74.90701294, 16.76979065], [74.89263916, 16.76869011], [74.86836243, 16.77108002], [74.85497284, 16.77076912], [74.8503418, 16.76032066], [74.80410767, 16.75076294], [74.80040741, 16.74565125], [74.79110718, 16.74814987], [74.77900696, 16.74859047], [74.77555847, 16.74399948], [74.7750473, 16.74077988], [74.76940918, 16.73946953], [74.76381683, 16.73680115], [74.75614166, 16.72962952], [74.75409698, 16.72619057], [74.74820709, 16.72212029], [74.73661804, 16.71583939], [74.72244263, 16.71329117], [74.70783234, 16.7130909], [74.69819641, 16.71520042], [74.69593811, 16.71054077], [74.69503784, 16.69244194], [74.69561005, 16.68583107], [74.68895721, 16.68412018], [74.68752289, 16.68166161], [74.68727875, 16.67901039], [74.69458008, 16.67864037], [74.69610596, 16.67498016], [74.67173767, 16.66353035], [74.66880035, 16.65555191], [74.6605072, 16.63758087], [74.66304779, 16.63216972], [74.66600037, 16.62872124], [74.67386627, 16.62845993], [74.68531036, 16.61988068], [74.69122314, 16.61814117], [74.69431305, 16.61519051], [74.69462585, 16.61082077], [74.69338226, 16.60727119], [74.69037628, 16.60445976], [74.67855072, 16.60655975], [74.67529297, 16.60598946], [74.66882324, 16.60268021], [74.66387177, 16.60107994], [74.65174866, 16.60697937], [74.64771271, 16.60807037], [74.64280701, 16.60677147], [74.64113617, 16.60469055], [74.63974762, 16.59953117], [74.63938141, 16.59435272], [74.64051819, 16.5819397], [74.6363678, 16.57574081], [74.63066101, 16.57765007], [74.62695313, 16.58093071], [74.62393951, 16.58192062], [74.62438965, 16.57755089], [74.62264252, 16.57364082], [74.61699677, 16.56797028], [74.60484314, 16.56214142], [74.59588623, 16.56439018], [74.59335327, 16.56382942], [74.59179688, 16.56072044], [74.5916214, 16.55883026], [74.59253693, 16.55727005], [74.59195709, 16.55554962], [74.58152008, 16.55500031], [74.58152008, 16.55183983], [74.5740509, 16.55196953], [74.56907654, 16.55639839], [74.56552887, 16.55779076], [74.56220245, 16.55803108], [74.55966949, 16.5597496], [74.55908966, 16.56710815], [74.55970001, 16.57137108], [74.56510162, 16.57463074], [74.56981659, 16.58122063], [74.56555939, 16.59037971], [74.55459595, 16.59242058], [74.54985046, 16.59218025], [74.55024719, 16.60902023], [74.54937744, 16.61552048], [74.55143738, 16.63321114], [74.53009033, 16.63060951], [74.51029205, 16.63145065], [74.50167084, 16.62713814], [74.49800873, 16.62664032], [74.49550629, 16.62767029], [74.49178314, 16.63233948], [74.48983765, 16.63607025], [74.48587036, 16.6391201], [74.4813385, 16.6540699], [74.47738647, 16.66077995], [74.47013855, 16.65518951], [74.46479797, 16.65295029], [74.46518707, 16.64689827], [74.46283722, 16.64448929], [74.46446991, 16.63398933], [74.46981049, 16.62347984], [74.47136688, 16.6217804], [74.47080231, 16.61495018], [74.47245789, 16.60481071], [74.44698334, 16.60033989], [74.44081879, 16.59869194], [74.43354034, 16.59436035], [74.42883301, 16.58272934], [74.42228699, 16.58350182], [74.41371918, 16.58023834], [74.40348053, 16.5786705], [74.40216064, 16.57472992], [74.40120697, 16.57094002], [74.39839935, 16.56542969], [74.40077209, 16.56347275], [74.40113068, 16.56088829], [74.39550018, 16.55952263], [74.39565277, 16.53567123], [74.39289856, 16.53107071], [74.3899231, 16.5279007], [74.38543701, 16.52740288], [74.37110138, 16.53765106], [74.36611938, 16.53763962], [74.36258698, 16.53874016], [74.36464691, 16.54368019], [74.36287689, 16.5485611], [74.36923218, 16.55327034], [74.36561584, 16.55706978], [74.36308289, 16.55620193], [74.35974884, 16.55368996], [74.35507202, 16.55311012], [74.34612274, 16.54644966], [74.34020233, 16.55013275], [74.33215332, 16.55369949], [74.32940674, 16.55347061], [74.32377625, 16.55146027], [74.32222748, 16.54450035], [74.32216644, 16.53905106], [74.3232193, 16.5322094], [74.32267761, 16.51900101], [74.32390594, 16.50629807], [74.32145691, 16.50267029], [74.31411743, 16.50209808], [74.31346893, 16.50325966], [74.31157684, 16.50692749], [74.30845642, 16.52187157], [74.30892181, 16.52399826], [74.30692291, 16.52917099], [74.29762268, 16.53193092], [74.29447937, 16.53154182], [74.29483795, 16.52929115], [74.28961945, 16.52256966], [74.28955841, 16.52526283], [74.28713226, 16.52732086], [74.28672791, 16.52940941], [74.28822327, 16.53947067], [74.28431702, 16.54309273], [74.27636719, 16.54453278], [74.27155304, 16.53866005], [74.27197266, 16.5334301], [74.2755127, 16.52515984], [74.27662659, 16.52061081], [74.28190613, 16.52055168], [74.28440094, 16.51647949], [74.28668976, 16.50677109], [74.28575897, 16.50337029], [74.27864075, 16.50102043], [74.26313019, 16.49895287], [74.25570679, 16.49677086], [74.25315857, 16.49488068], [74.26008606, 16.49090767], [74.262146, 16.48867035], [74.26452637, 16.48545074], [74.26516724, 16.48240089], [74.26877594, 16.47603035], [74.27842712, 16.47963905], [74.28253937, 16.48257065], [74.28099823, 16.48579025], [74.28051758, 16.48936081], [74.28330994, 16.49603271], [74.28894806, 16.50378036], [74.29989624, 16.50263023], [74.30055237, 16.49963188], [74.2975769, 16.48161125], [74.29483795, 16.47435188], [74.2964325, 16.46671104], [74.29631805, 16.45901108], [74.30139923, 16.45906067], [74.30239868, 16.46108055], [74.30464935, 16.46079063], [74.30709076, 16.45959091], [74.31482697, 16.45319939], [74.32193756, 16.45004082], [74.33052826, 16.45279121], [74.33555603, 16.45308113], [74.33886719, 16.45216179], [74.33998871, 16.44812965], [74.33876038, 16.44664192], [74.33904266, 16.44486046], [74.34246063, 16.44232941], [74.34223175, 16.43956947], [74.34062195, 16.43617058], [74.34052277, 16.43297958], [74.34375, 16.42554092], [74.33728027, 16.42020988], [74.33818054, 16.41337013], [74.34194183, 16.40521049], [74.34265137, 16.40049171], [74.34928131, 16.39940071], [74.34916687, 16.4039402], [74.35954285, 16.40398979], [74.36457062, 16.4032383], [74.36782074, 16.39846992], [74.36911011, 16.39432907], [74.36868286, 16.3911705], [74.35961151, 16.37882042], [74.36165619, 16.36474991], [74.35189819, 16.36630058], [74.35108185, 16.37676048], [74.34858704, 16.38038254], [74.34771729, 16.38601112], [74.34577179, 16.38952065], [74.34306335, 16.39067078], [74.34033203, 16.3909626], [74.33596039, 16.38964272], [74.33500671, 16.38871956], [74.33474731, 16.38285828], [74.33255005, 16.3755703], [74.32546234, 16.37924957], [74.32776642, 16.37034035], [74.32762909, 16.36811066], [74.33223724, 16.35695076], [74.33152008, 16.35556984], [74.32370758, 16.35361099], [74.33156586, 16.34649086], [74.33439636, 16.34052277], [74.32823181, 16.34110069], [74.32345581, 16.33989143], [74.32480621, 16.33666992], [74.32911682, 16.3325901], [74.32727814, 16.32920074], [74.32401276, 16.32742119], [74.32302094, 16.32512283], [74.32993317, 16.3223629], [74.33335876, 16.32374191], [74.33727264, 16.32339287], [74.3400116, 16.31693077], [74.33569336, 16.31500053], [74.33152008, 16.31641006], [74.33101654, 16.31502151], [74.33210754, 16.3107605], [74.34059143, 16.31162071], [74.34233093, 16.30509186], [74.34012604, 16.30398941], [74.34115601, 16.30282021], [74.34484863, 16.30326843], [74.34871674, 16.29146957], [74.34268188, 16.28877068], [74.33637238, 16.29017067], [74.33178711, 16.2861805], [74.33215332, 16.28409958], [74.32932281, 16.28106117], [74.32868958, 16.27943039], [74.33065796, 16.27293968], [74.33383942, 16.26807022], [74.33705139, 16.26572037], [74.34041595, 16.2675705], [74.34390259, 16.27212143], [74.34945679, 16.27326965], [74.3493576, 16.27506065], [74.35074615, 16.27625847], [74.35212708, 16.27448273], [74.35514069, 16.27449036], [74.35986328, 16.27960968], [74.3603363, 16.28190994], [74.35169983, 16.28820992], [74.35328674, 16.2918396], [74.35459137, 16.28976059], [74.35611725, 16.29092026], [74.35853577, 16.28880119], [74.36257172, 16.28713989], [74.36960602, 16.29072189], [74.37377167, 16.29031944], [74.38006592, 16.2935009], [74.38742065, 16.29034805], [74.39038086, 16.29024124], [74.39126587, 16.27560043], [74.40075684, 16.27625084], [74.41802216, 16.28092957], [74.4212265, 16.28059006], [74.42159271, 16.27145958], [74.42082214, 16.26387978], [74.42253113, 16.2574501], [74.4363327, 16.25476837], [74.44094086, 16.25266075], [74.44184113, 16.25415039], [74.44277954, 16.2495594], [74.46122742, 16.24843025], [74.4614563, 16.24377823], [74.46343231, 16.24183083], [74.47318268, 16.23851967], [74.47606659, 16.23903084], [74.48079681, 16.24432945], [74.48412323, 16.2467308], [74.49482727, 16.23801994], [74.49507141, 16.23596954], [74.50311279, 16.23104095], [74.5083313, 16.22294044], [74.50772095, 16.22128105], [74.50296021, 16.21622086], [74.50211334, 16.21413994], [74.5031662, 16.2115612], [74.51329803, 16.2012291], [74.51322937, 16.19922066], [74.51081085, 16.19881821], [74.51252747, 16.19584084], [74.51288605, 16.18939972], [74.51287842, 16.18826294], [74.50908661, 16.18783951], [74.50177002, 16.18543053], [74.49781799, 16.18133926], [74.49532318, 16.16900063], [74.49466705, 16.15504074], [74.48996735, 16.14722252], [74.48580933, 16.14698982], [74.48710632, 16.1430912], [74.49095154, 16.1420002], [74.49710846, 16.11236954], [74.49640656, 16.10157967], [74.49349976, 16.09859276], [74.49263, 16.09553909], [74.49279785, 16.09283829], [74.490448, 16.09037018], [74.48908997, 16.08732033], [74.4818573, 16.08696938], [74.47891235, 16.08789063], [74.47796631, 16.09189987], [74.4645462, 16.10211182], [74.46000671, 16.102911], [74.45491028, 16.10267067], [74.44452667, 16.10518074], [74.43795013, 16.10816002], [74.4345932, 16.1106205], [74.42276001, 16.10256958], [74.41845703, 16.10089111], [74.41607666, 16.09600067], [74.41520691, 16.09181976], [74.40760803, 16.09069824], [74.40406036, 16.09097862], [74.39731598, 16.08712959], [74.39830017, 16.08011818], [74.39724731, 16.07838821], [74.39045715, 16.07992935], [74.38680267, 16.07809067], [74.3809967, 16.07826042], [74.3795929, 16.07682037], [74.3806076, 16.07302094], [74.38008118, 16.06958008], [74.37510681, 16.06336975], [74.37098694, 16.05957031], [74.36815643, 16.05295944], [74.37075043, 16.05101967], [74.38014221, 16.05476761], [74.38173676, 16.05356979], [74.37888336, 16.04339981], [74.37822723, 16.03926086], [74.37858582, 16.03662109], [74.3900528, 16.03512955], [74.39607239, 16.03960037], [74.40931702, 16.04533005], [74.40960693, 16.04709816], [74.41121674, 16.04901123], [74.4155426, 16.05105972], [74.4229126, 16.05319023], [74.43213654, 16.05513191], [74.4363327, 16.05673027], [74.44048309, 16.05702019], [74.44803619, 16.05240059], [74.45587158, 16.05216026], [74.46383667, 16.0477314], [74.46795654, 16.04669952], [74.47027588, 16.0405407], [74.467659, 16.03364944], [74.46710205, 16.03026962], [74.46391296, 16.02256012], [74.45643616, 16.00890923], [74.45336914, 16.00580978], [74.44966888, 15.99853134], [74.45017242, 15.99260139], [74.44843292, 15.98829079], [74.44847107, 15.9864006], [74.4499588, 15.98323059], [74.44394684, 15.9743309], [74.44229126, 15.9654789], [74.43522644, 15.95116997], [74.41226959, 15.92520046], [74.40203857, 15.9110508], [74.39186859, 15.90115929], [74.39234924, 15.89926147], [74.39836121, 15.8977108], [74.39930725, 15.89577103], [74.40164185, 15.88726997], [74.40254974, 15.87826061], [74.39919281, 15.87434959], [74.41221619, 15.85763931], [74.41158295, 15.85259056], [74.4065094, 15.8519001], [74.40312195, 15.84895992], [74.39343262, 15.8517704], [74.39228821, 15.85744953], [74.3884964, 15.8572197], [74.38794708, 15.86394119], [74.38556671, 15.87323093], [74.38313293, 15.87776184], [74.3765564, 15.8849411], [74.37277985, 15.88768959], [74.3744812, 15.88994122], [74.37412262, 15.89161015], [74.37052155, 15.8903904], [74.3706131, 15.88000202], [74.36997986, 15.87568092], [74.36743164, 15.87321854], [74.36702728, 15.87109089], [74.3640976, 15.87016106], [74.35295868, 15.85924053], [74.35340118, 15.85573196], [74.34453583, 15.85205078], [74.3463974, 15.84934998], [74.3537674, 15.84810066], [74.38741302, 15.8471117], [74.38931274, 15.84414005], [74.38944244, 15.83631134], [74.38626862, 15.83326244], [74.37454987, 15.82750034], [74.37336731, 15.82583237], [74.3707428, 15.81722069], [74.36637115, 15.81549072], [74.36915588, 15.81216145], [74.37400818, 15.81044102], [74.37454987, 15.80452156], [74.37580109, 15.80120087], [74.37551117, 15.79671955], [74.37084198, 15.78218174], [74.36789703, 15.7816], [74.36485291, 15.77365112], [74.35093689, 15.76336002], [74.34677124, 15.76311016], [74.34227753, 15.76552105], [74.33454132, 15.76767921], [74.32975006, 15.77038002], [74.32756805, 15.76820087], [74.32495117, 15.76130009], [74.32408142, 15.75652981], [74.31864929, 15.75341034], [74.31465149, 15.75214863], [74.31299591, 15.7482996], [74.29216766, 15.73931122], [74.28494263, 15.74331093], [74.2740097, 15.75312042], [74.27086639, 15.75191021], [74.2660675, 15.74702072], [74.25892639, 15.74339104], [74.25006866, 15.74118042], [74.24386597, 15.74440002], [74.23898315, 15.75214005], [74.23523712, 15.75397015], [74.23516846, 15.75961113], [74.24034119, 15.78075027], [74.23892975, 15.78454018], [74.23549652, 15.7868309], [74.22734833, 15.78567123], [74.22247314, 15.78170109], [74.21740723, 15.77876091], [74.21570587, 15.77387047], [74.2146225, 15.76599121], [74.2113266, 15.75858974], [74.20439911, 15.7534008], [74.19706726, 15.75022125], [74.17115021, 15.74995041], [74.1676712, 15.74925041], [74.16226959, 15.74207115], [74.16013336, 15.73434925], [74.1553421, 15.73228168], [74.1505127, 15.7317009], [74.14737701, 15.73007107], [74.14296722, 15.72719097], [74.14186859, 15.72317886], [74.14045715, 15.7216711], [74.13485718, 15.72218132], [74.13062286, 15.71792126], [74.13475037, 15.71603203], [74.13553619, 15.70925236], [74.13891602, 15.70634079], [74.1415329, 15.70036125], [74.13889313, 15.69903183], [74.14042664, 15.69456005], [74.13887787, 15.68622971], [74.13359833, 15.67840099], [74.12700653, 15.67374039], [74.11752319, 15.67078018], [74.10624695, 15.67064095], [74.10056305, 15.67234993], [74.0965271, 15.6708498], [74.09802246, 15.6659708], [74.10453033, 15.65920162], [74.11205292, 15.6550312], [74.12136841, 15.65367031], [74.12602997, 15.65028954], [74.12275696, 15.64522076], [74.11263275, 15.64308071], [74.10804749, 15.63887024], [74.10243988, 15.63896084], [74.08055115, 15.62617016], [74.0735321, 15.62667179], [74.06770325, 15.62471199], [74.05680084, 15.62272167], [74.03929901, 15.62085056], [74.03557587, 15.60929108], [74.02793121, 15.60459995], [74.01317596, 15.60934067], [74.00784302, 15.60829926], [74.002388, 15.6090517], [73.998703, 15.61112976], [73.99294281, 15.61631107], [73.99021149, 15.62063026], [73.98606873, 15.62338066], [73.98142242, 15.62503147], [73.97598267, 15.62894154], [73.96926117, 15.64432144], [73.97072601, 15.64966106], [73.97422791, 15.65467072], [73.97570038, 15.65978146], [73.97158813, 15.66839123], [73.97219849, 15.67669201], [73.97130585, 15.68725109], [73.96573639, 15.69502068], [73.95723724, 15.6967392], [73.9586792, 15.70125198], [73.9560318, 15.70479107], [73.95778656, 15.70735073], [73.95886993, 15.71129131], [73.95593262, 15.71692085], [73.95082092, 15.72322941], [73.94976044, 15.73263073], [73.94536591, 15.74152184], [73.92415619, 15.74282074], [73.91793823, 15.74540138], [73.91483307, 15.74549198], [73.90860748, 15.74233055], [73.8859024, 15.74726105], [73.88244629, 15.74935055], [73.88024139, 15.75255108], [73.88260651, 15.75669193], [73.88432312, 15.76462078], [73.88684082, 15.7671299], [73.88685608, 15.77029133], [73.88024902, 15.77739143], [73.87986755, 15.779212], [73.87509918, 15.78289986], [73.87483978, 15.78634071], [73.87593079, 15.79323101], [73.87349701, 15.79532146], [73.86548615, 15.79752922], [73.86158752, 15.79388046], [73.8600769, 15.78779125], [73.85579681, 15.78326035], [73.856987, 15.77822971], [73.85190582, 15.77841187], [73.84963226, 15.77602959], [73.84716797, 15.76613045], [73.84512329, 15.76336002], [73.83878326, 15.76089001], [73.84030151, 15.75620174], [73.83846283, 15.7488308], [73.83303833, 15.73775196], [73.82039642, 15.73991013], [73.81603241, 15.73526955], [73.81262207, 15.73351955], [73.80284119, 15.73219967], [73.79756927, 15.72509193], [73.79321289, 15.72366047], [73.78649139, 15.72325039], [73.77578735, 15.73053169], [73.75824738, 15.73275185], [73.74871063, 15.73057079], [73.7440567, 15.72564125], [73.7410202, 15.71872139], [73.73703766, 15.71725082], [73.73226166, 15.72058105], [73.72764587, 15.72247982], [73.72255707, 15.7228899], [73.71856689, 15.72161961], [73.71098328, 15.7202301], [73.70658875, 15.72173023], [73.70265961, 15.72491074], [73.69734192, 15.72623062], [73.69185638, 15.72690964], [73.68530273, 15.72587109], [73.68245697, 15.7252512], [73.68013763, 15.72437096], [73.68013763, 15.72486115], [73.67986298, 15.72486115], [73.67986298, 15.72514153], [73.67930603, 15.72514153], [73.67930603, 15.72542191], [73.67708588, 15.72541714], [73.67708588, 15.72569466], [73.67680359, 15.72569466], [73.67680359, 15.72597122], [73.6765213, 15.72597122], [73.6765213, 15.7262516], [73.67624664, 15.7262516], [73.67624664, 15.72653198], [73.67597198, 15.72653198], [73.67597198, 15.72681046], [73.67569733, 15.72680473], [73.67569733, 15.72708321], [73.67514038, 15.7270813], [73.67514038, 15.72764015], [73.67485809, 15.72764015], [73.67485809, 15.72791958], [73.67458344, 15.72791767], [73.67458344, 15.72819328], [73.67430878, 15.72819138], [73.67430878, 15.72875023], [73.67402649, 15.72875023], [73.67402649, 15.72902966], [73.67375183, 15.72902966], [73.67375183, 15.72931004], [73.67319489, 15.72930622], [73.67319489, 15.72986221], [73.67263794, 15.72985935], [73.67263794, 15.73013973], [73.67208099, 15.73013973], [73.67208099, 15.73069572], [73.67180634, 15.73069572], [73.67180634, 15.73097229], [73.67151642, 15.73096943], [73.67151642, 15.73124981], [73.67124939, 15.73124981], [73.67124939, 15.73096943], [73.6709671, 15.73096943], [73.6709671, 15.73124981], [73.67041779, 15.73124981], [73.67041779, 15.73153019], [73.67014313, 15.73153019], [73.67014313, 15.73124981], [73.66902924, 15.73124981], [73.66902924, 15.73096943], [73.66819763, 15.73096943], [73.66819763, 15.73153019], [73.66792297, 15.73153019], [73.66792297, 15.73180962], [73.6673584, 15.73180962], [73.6673584, 15.73236179], [73.66707611, 15.73236179], [73.66707611, 15.73264027], [73.66680908, 15.73264027], [73.66680908, 15.73347187], [73.66652679, 15.73347187], [73.66652679, 15.73458195], [73.66625214, 15.73458195], [73.66625214, 15.73486233], [73.66596985, 15.73486042], [73.66596985, 15.73513985], [73.66569519, 15.73513794], [73.66569519, 15.73569393], [73.6654129, 15.73569393], [73.6654129, 15.7359724], [73.66513824, 15.7359724], [73.66513824, 15.7365284], [73.66485596, 15.73651886], [73.66485596, 15.73736], [73.6645813, 15.73736], [73.6645813, 15.73764038], [73.66430664, 15.73764038], [73.66430664, 15.73792076], [73.66374969, 15.73791599], [73.66374969, 15.73819447], [73.6618042, 15.73819447], [73.6618042, 15.73791599], [73.66152954, 15.73791599], [73.66152954, 15.73847198], [73.6609726, 15.73847008], [73.6609726, 15.73903084], [73.66069794, 15.73903084], [73.66069794, 15.73931122], [73.65958405, 15.73930645], [73.65958405, 15.73958206], [73.65930939, 15.73958206], [73.65930176, 15.7398634], [73.6590271, 15.73985958], [73.6590271, 15.74014091], [73.65875244, 15.74014091], [73.65875244, 15.7404213], [73.65847015, 15.74041557], [73.65847015, 15.74069405], [73.6581955, 15.74069405], [73.6581955, 15.74097347], [73.65598297, 15.74096966], [73.65598297, 15.74125099], [73.65569305, 15.74125099], [73.65569305, 15.7418108], [73.6554184, 15.74180698], [73.6554184, 15.74208164], [73.65458679, 15.74207973], [73.65458679, 15.74236107], [73.65402985, 15.74236107], [73.65402985, 15.74265003], [73.65374756, 15.74265003], [73.65374756, 15.74292088], [73.6534729, 15.74291706], [73.6534729, 15.74319458], [73.65319824, 15.74319458], [73.65319824, 15.74569511], [73.65291595, 15.74569511], [73.65291595, 15.74597263], [73.65180206, 15.74597263], [73.65180206, 15.74569511], [73.65097046, 15.74569511], [73.65097046, 15.74541664], [73.64902496, 15.74541664], [73.64902496, 15.74569511], [73.64848328, 15.74569035], [73.64848328, 15.74653053], [73.64901733, 15.74653053], [73.64901733, 15.74681187], [73.65097046, 15.74681187], [73.65097046, 15.74653053], [73.6526413, 15.74653053], [73.6526413, 15.74681187], [73.65319824, 15.74680519], [73.65319824, 15.74708271], [73.6534729, 15.7470808], [73.6534729, 15.74792194], [73.65319824, 15.74792194], [73.65319824, 15.74875069], [73.65429688, 15.74875069], [73.65429688, 15.74845886], [73.6554184, 15.74847317], [73.6554184, 15.74819469], [73.65597534, 15.74819469], [73.65597534, 15.74791718], [73.65651703, 15.74792194], [73.65651703, 15.74764061], [73.65735626, 15.74764061], [73.65735626, 15.74736118], [73.65763855, 15.74736118], [73.65763855, 15.74764061], [73.65820313, 15.74764061], [73.65820313, 15.74792194], [73.65847015, 15.74791718], [73.65847015, 15.74819469], [73.65875244, 15.74819469], [73.65875244, 15.74847317], [73.6590271, 15.74845886], [73.6590271, 15.74903202], [73.65930176, 15.74903202], [73.65930939, 15.74930954], [73.65958405, 15.74930477], [73.65958405, 15.74958324], [73.6598587, 15.74958134], [73.6598587, 15.74986076], [73.66014099, 15.74986076], [73.66014099, 15.75041962], [73.66041565, 15.75041676], [73.66041565, 15.75097084], [73.66069794, 15.75097084], [73.66069794, 15.75152683], [73.6609726, 15.75152683], [73.6609726, 15.75208282], [73.66152954, 15.75208282], [73.66152954, 15.7523613], [73.66208649, 15.7523613], [73.66208649, 15.75264168], [73.66236115, 15.75264168], [73.66236115, 15.75292015], [73.66347504, 15.75291538], [73.66347504, 15.75319576], [73.66402435, 15.75319576], [73.66402435, 15.75347137], [73.6645813, 15.75347137], [73.6645813, 15.75375175], [73.66485596, 15.75375175], [73.66485596, 15.75403023], [73.66513824, 15.75403023], [73.66513824, 15.75430965], [73.6654129, 15.75430965], [73.6654129, 15.75459003], [73.66570282, 15.75459003], [73.66570282, 15.7551403], [73.66596985, 15.7551403], [73.66596985, 15.75652981], [73.66652679, 15.75652981], [73.66652679, 15.75681019], [73.66680908, 15.75681019], [73.66680908, 15.75652981], [73.66764069, 15.75652981], [73.66764069, 15.75625038], [73.66792297, 15.75625038], [73.66791534, 15.75597191], [73.66819763, 15.75597191], [73.66819763, 15.75541782], [73.66929626, 15.75541973], [73.66929626, 15.7551403], [73.66986084, 15.7551403], [73.66986084, 15.75486183], [73.67041779, 15.75486183], [73.67041779, 15.75459003], [73.6709671, 15.75459003], [73.6709671, 15.75430965], [73.67124939, 15.75430965], [73.67124939, 15.75375175], [73.67151642, 15.75375175], [73.67151642, 15.75319099], [73.67208099, 15.75319576], [73.67208099, 15.75291538], [73.67263794, 15.75292015], [73.67263794, 15.75264168], [73.67402649, 15.75264168], [73.67402649, 15.75292015], [73.67430878, 15.75291538], [73.67430878, 15.75319576], [73.67457581, 15.75319099], [73.67457581, 15.75403023], [73.67430878, 15.75403023], [73.67430878, 15.75486183], [73.67402649, 15.75486183], [73.67402649, 15.7551403], [73.67346954, 15.7551403], [73.67346954, 15.75569344], [73.67292023, 15.75569344], [73.67292023, 15.75597191], [73.67208099, 15.75597191], [73.67208099, 15.75625038], [73.67151642, 15.75625038], [73.67151642, 15.75652981], [73.67124939, 15.75652981], [73.67124939, 15.75681019], [73.67069244, 15.75680637], [73.67069244, 15.75708389], [73.6701355, 15.75708389], [73.6701355, 15.75736237], [73.66986084, 15.75736046], [73.66986084, 15.75765133], [73.66929626, 15.75765133], [73.66929626, 15.75792027], [73.66874695, 15.75791645], [73.66874695, 15.7581892], [73.66791534, 15.75819588], [73.66791534, 15.75847244], [73.6673584, 15.75847244], [73.6673584, 15.75819588], [73.66680908, 15.75819588], [73.66680908, 15.75847244], [73.66570282, 15.75846863], [73.66570282, 15.75874996], [73.6654129, 15.75874996], [73.6654129, 15.75846863], [73.66486359, 15.75847244], [73.66486359, 15.75819588], [73.6645813, 15.7581892], [73.6645813, 15.75791645], [73.66401672, 15.75792027], [73.66401672, 15.75765133], [73.66319275, 15.75763988], [73.66319275, 15.7581892], [73.66291809, 15.75820065], [73.66291809, 15.75903034], [73.66319275, 15.75902843], [73.66319275, 15.75958443], [73.66291809, 15.75958157], [73.66291809, 15.75986195], [73.66319275, 15.75986195], [73.66319275, 15.76014042], [73.66348267, 15.76014042], [73.66348267, 15.76041985], [73.66319275, 15.76041985], [73.66319275, 15.76124954], [73.66291809, 15.76124954], [73.66291809, 15.76181126], [73.66319275, 15.76181126], [73.66319275, 15.76292133], [73.66291809, 15.76292133], [73.66291809, 15.76375008], [73.6626358, 15.76375008], [73.6626358, 15.76542091], [73.66236115, 15.76542091], [73.66236115, 15.76681995], [73.66208649, 15.76681995], [73.66208649, 15.76735973], [73.66179657, 15.76735973], [73.66179657, 15.76764107], [73.66152954, 15.76763821], [73.66153717, 15.76875114], [73.66124725, 15.76875114], [73.66124725, 15.76958942], [73.6609726, 15.76958466], [73.6609726, 15.77097321], [73.66069794, 15.7709713], [73.66069794, 15.77181244], [73.66041565, 15.77180481], [73.66041565, 15.77208328], [73.66014099, 15.77208328], [73.66014099, 15.77263927], [73.6598587, 15.77263927], [73.6598587, 15.77347088], [73.65958405, 15.77347088], [73.65958405, 15.77458286], [73.65930939, 15.77458096], [73.65930176, 15.77541924], [73.6590271, 15.77541733], [73.6590271, 15.77597332], [73.65875244, 15.77597141], [73.65875244, 15.77652931], [73.65847778, 15.77652931], [73.65847778, 15.77680969], [73.6581955, 15.77680492], [73.6581955, 15.7770834], [73.65847015, 15.7770834], [73.65847015, 15.77736092], [73.65820313, 15.77736092], [73.65820313, 15.77791977], [73.65791321, 15.77791691], [73.65791321, 15.77847099], [73.65763855, 15.77847099], [73.65763855, 15.7804203], [73.65735626, 15.7804203], [73.65735626, 15.78125191], [73.6570816, 15.78125191], [73.6570816, 15.78181934], [73.65680695, 15.78180599], [73.65680695, 15.78208447], [73.65651703, 15.78208065], [73.65651703, 15.78264046], [73.65625, 15.78264046], [73.65625, 15.78374958], [73.65598297, 15.78374958], [73.65598297, 15.78431034], [73.65569305, 15.78431034], [73.65569305, 15.78514004], [73.6554184, 15.78514004], [73.6554184, 15.78542042], [73.65569305, 15.78541565], [73.65569305, 15.78569412], [73.6554184, 15.78568935], [73.6554184, 15.78652954], [73.65513611, 15.78652763], [73.65513611, 15.78708363], [73.65486145, 15.78708363], [73.65486145, 15.7873621], [73.65458679, 15.7873621], [73.65458679, 15.78763771], [73.65429688, 15.78763103], [73.65429688, 15.78903008], [73.65402985, 15.78903008], [73.65402985, 15.79042053], [73.65374756, 15.79041576], [73.65374756, 15.79097176], [73.65402985, 15.79096985], [73.65402985, 15.79181099], [73.65458679, 15.79180622], [73.65458679, 15.79208374], [73.65625, 15.79207993], [73.65625, 15.79264069], [73.65652466, 15.79263783], [73.65652466, 15.79319382], [73.65680695, 15.79319382], [73.65680695, 15.79347229], [73.6570816, 15.79347038], [73.6570816, 15.7937603], [73.65680695, 15.7937603], [73.65680695, 15.79403114], [73.6570816, 15.79403114], [73.6570816, 15.79431057], [73.65680695, 15.79431057], [73.65680695, 15.7962513], [73.6570816, 15.7962513], [73.6570816, 15.79819489], [73.65736389, 15.79819489], [73.65736389, 15.79847336], [73.65763855, 15.79847145], [73.65763855, 15.79931164], [73.65791321, 15.79930687], [73.65791321, 15.80069542], [73.6581955, 15.80069542], [73.6581955, 15.80097294], [73.65875244, 15.80097103], [73.65875244, 15.80125141], [73.6590271, 15.80125141], [73.6590271, 15.80153084], [73.65930176, 15.80153084], [73.65930939, 15.80181026], [73.65958405, 15.80180454], [73.65958405, 15.80208302], [73.66014099, 15.80208302], [73.66014099, 15.80236053], [73.66069794, 15.80236053], [73.66069794, 15.80264091], [73.6609726, 15.80263901], [73.6609726, 15.80291653], [73.66124725, 15.80291653], [73.66124725, 15.80319309], [73.66152954, 15.80319309], [73.66152954, 15.80347347], [73.66179657, 15.80347061], [73.66179657, 15.80375099], [73.66208649, 15.80375099], [73.66208649, 15.80431175], [73.66236115, 15.80430508], [73.66236115, 15.8045826], [73.66208649, 15.80458069], [73.66208649, 15.8051424], [73.66153717, 15.8051424], [73.66153717, 15.80458069], [73.66124725, 15.8045826], [73.66124725, 15.80430508], [73.6609726, 15.80431175], [73.6609726, 15.80375099], [73.66069794, 15.80375099], [73.66069794, 15.80347061], [73.66041565, 15.80347347], [73.66041565, 15.80319309], [73.66014099, 15.80319309], [73.66014099, 15.80291653], [73.6598587, 15.80293083], [73.6598587, 15.80264091], [73.65930176, 15.80264091], [73.65930176, 15.80236053], [73.65847015, 15.80236053], [73.65847015, 15.80208302], [73.65791321, 15.80208302], [73.65791321, 15.80180454], [73.6570816, 15.80181026], [73.6570816, 15.80153084], [73.65651703, 15.80153084], [73.65651703, 15.80097103], [73.65625, 15.80097294], [73.65625, 15.80041695], [73.65598297, 15.80042171], [73.65598297, 15.80014133], [73.65625, 15.80014133], [73.65625, 15.79903126], [73.65598297, 15.79903126], [73.65598297, 15.79847145], [73.6554184, 15.79847336], [73.6554184, 15.79819489], [73.65513611, 15.79819489], [73.65513611, 15.79763889], [73.65486145, 15.7976408], [73.65486145, 15.7962513], [73.65458679, 15.7962513], [73.65458679, 15.79596996], [73.6543045, 15.79597282], [73.6543045, 15.79513836], [73.65402985, 15.79514122], [73.65402985, 15.79458046], [73.65374756, 15.79458237], [73.65374756, 15.79430676], [73.6534729, 15.79431057], [73.6534729, 15.79403114], [73.6526413, 15.79403114], [73.6526413, 15.79486275], [73.65235901, 15.79485989], [73.65235901, 15.7956953], [73.65208435, 15.7956953], [73.65208435, 15.79680538], [73.65180206, 15.79680538], [73.65180206, 15.7970829], [73.6515274, 15.79708004], [73.6515274, 15.7976408], [73.65125275, 15.7976408], [73.65125275, 15.79792118], [73.65097046, 15.79792118], [73.65097046, 15.79875088], [73.65125275, 15.79875088], [73.65125275, 15.79903126], [73.65097046, 15.79902744], [73.65097046, 15.79958344], [73.6506958, 15.79957104], [73.6506958, 15.80014133], [73.65041351, 15.80013943], [73.65041351, 15.80069542], [73.6506958, 15.8006897], [73.6506958, 15.80181026], [73.65041351, 15.80180454], [73.65041351, 15.80236053], [73.65013885, 15.80236053], [73.65013885, 15.80293083], [73.6498642, 15.80291653], [73.6498642, 15.80319309], [73.64958191, 15.80319309], [73.64958191, 15.80347347], [73.64901733, 15.80347061], [73.64901733, 15.80375099], [73.64875031, 15.80375099], [73.64875031, 15.80402946], [73.64848328, 15.80402946], [73.64848328, 15.80431175], [73.64763641, 15.80430508], [73.64763641, 15.8045826], [73.64680481, 15.8045826], [73.64680481, 15.80430508], [73.64653015, 15.80430508], [73.64653015, 15.8045826], [73.64597321, 15.80458069], [73.64597321, 15.80486107], [73.64541626, 15.80486107], [73.64541626, 15.80542183], [73.64485931, 15.80542183], [73.64485931, 15.8057003], [73.64458466, 15.80569458], [73.64458466, 15.80597115], [73.64430237, 15.80597115], [73.64430237, 15.80653191], [73.64458466, 15.80652714], [73.64458466, 15.80708313], [73.64430237, 15.80708122], [73.64430237, 15.80764198], [73.64458466, 15.80764008], [73.64458466, 15.80819321], [73.64430237, 15.80819321], [73.64430237, 15.80958366], [73.64402771, 15.8095789], [73.64402771, 15.81013966], [73.64375305, 15.81013966], [73.64375305, 15.81097221], [73.64319611, 15.81096935], [73.64319611, 15.81124973], [73.64208221, 15.81124973], [73.64208221, 15.81096935], [73.64041138, 15.81096935], [73.64041138, 15.81153011], [73.64013672, 15.81153011], [73.64013672, 15.81264019], [73.63986206, 15.81264019], [73.63986206, 15.81291962], [73.63957977, 15.8129158], [73.63957977, 15.81319427], [73.63930511, 15.81319427], [73.63931274, 15.81347179], [73.63903046, 15.81347179], [73.63903046, 15.81375027], [73.63874817, 15.81375027], [73.63874817, 15.81402969], [73.63764191, 15.81402969], [73.63764191, 15.81431103], [73.63735199, 15.81431103], [73.63735199, 15.81487083], [73.63707733, 15.81487083], [73.63707733, 15.81514168], [73.63680267, 15.81514168], [73.63680267, 15.81542015], [73.63652802, 15.81541634], [73.63652802, 15.81569386], [73.63625336, 15.81569386], [73.63625336, 15.81708431], [73.63652802, 15.81707954], [73.63652802, 15.8176403], [73.63680267, 15.8176403], [73.63680267, 15.81793022], [73.63764191, 15.81791592], [73.63764191, 15.81819439], [73.63791656, 15.81819439], [73.63791656, 15.81791592], [73.63819122, 15.81793022], [73.63819122, 15.8176403], [73.63846588, 15.8176403], [73.63846588, 15.81793022], [73.63903046, 15.81791592], [73.63903046, 15.81958199], [73.63874817, 15.81958199], [73.63874817, 15.81986332], [73.63903046, 15.81986046], [73.63903046, 15.82042122], [73.63874817, 15.82042122], [73.63874817, 15.8215313], [73.63847351, 15.82152939], [73.63847351, 15.82208157], [73.63819122, 15.82207966], [73.63819122, 15.8229208], [73.63791656, 15.82291698], [73.63791656, 15.82319546], [73.63764191, 15.82318974], [73.63764191, 15.82431126], [73.63735962, 15.82430458], [73.63735962, 15.82458305], [73.63708496, 15.82458305], [73.63708496, 15.82569504], [73.63680267, 15.82569027], [73.63680267, 15.82653141], [73.63652802, 15.82652664], [73.63652802, 15.82708263], [73.63625336, 15.82708073], [73.63625336, 15.82764053], [73.63597107, 15.82763863], [73.63597107, 15.82847309], [73.63569641, 15.82847309], [73.63569641, 15.82958317], [73.63540649, 15.82958126], [73.63540649, 15.82987022], [73.63513947, 15.82987022], [73.63513947, 15.83041859], [73.63485718, 15.83041859], [73.63485718, 15.83153152], [73.63458252, 15.83152676], [73.63458252, 15.83236122], [73.63430786, 15.83236122], [73.63430786, 15.83319473], [73.6340332, 15.83319092], [73.6340332, 15.83403015], [73.63375092, 15.83402729], [73.63375092, 15.83458328], [73.63346863, 15.83458138], [73.63346863, 15.83514023], [73.63319397, 15.83514023], [73.63319397, 15.83569336], [73.63291931, 15.83569336], [73.63291931, 15.83597088], [73.63263702, 15.83597088], [73.63263702, 15.83681011], [73.63236237, 15.83681011], [73.63236237, 15.83763981], [73.63208008, 15.83763981], [73.63208008, 15.8381958], [73.63180542, 15.8381958], [73.63180542, 15.83958435], [73.63153076, 15.83958244], [73.63153076, 15.83986187], [73.63124847, 15.83986187], [73.63124847, 15.84041977], [73.63096619, 15.84041977], [73.63096619, 15.84152985], [73.63069153, 15.84152794], [73.63069153, 15.84208393], [73.63041687, 15.84208202], [73.63041687, 15.84263992], [73.63014221, 15.84263802], [73.63014221, 15.84319401], [73.62985992, 15.84318924], [73.62985992, 15.84431076], [73.6295929, 15.84431076], [73.6295929, 15.84514046], [73.62930298, 15.84514046], [73.62930298, 15.84542084], [73.62958527, 15.84541607], [73.62958527, 15.84569359], [73.62930298, 15.84568977], [73.62930298, 15.84624958], [73.62902832, 15.84624958], [73.62902832, 15.84653091], [73.62875366, 15.84652805], [73.62875366, 15.84708214], [73.62847137, 15.84708214], [73.62847137, 15.84736347], [73.62819672, 15.84736347], [73.62819672, 15.84791565], [73.62791443, 15.84791565], [73.62791443, 15.8484726], [73.62763977, 15.84846973], [73.62763977, 15.84903145], [73.62735748, 15.84903145], [73.62735748, 15.84931087], [73.62708282, 15.84931087], [73.62708282, 15.85014057], [73.62680817, 15.85013866], [73.62680817, 15.85069466], [73.62652588, 15.8506918], [73.62652588, 15.85125065], [73.62625122, 15.85125065], [73.62625122, 15.85153103], [73.62652588, 15.85153103], [73.62652588, 15.85181141], [73.62625122, 15.85180473], [73.62625122, 15.85208321], [73.62596893, 15.85208035], [73.62596893, 15.85264111], [73.62541199, 15.85264111], [73.62541199, 15.85292053], [73.62513733, 15.85291672], [73.62513733, 15.8534708], [73.62458038, 15.8534708], [73.62458038, 15.85375118], [73.62431335, 15.85375118], [73.62431335, 15.85404015], [73.62374878, 15.85404015], [73.62374878, 15.85431194], [73.62347412, 15.85430527], [73.62347412, 15.85458279], [73.62291718, 15.85458088], [73.62291718, 15.85514069], [73.62264252, 15.85514069], [73.62264252, 15.85542202], [73.62236023, 15.85541725], [73.62236023, 15.85569477], [73.6220932, 15.85569096], [73.6220932, 15.85625076], [73.62180328, 15.85625076], [73.62180328, 15.85652924], [73.62152863, 15.85652924], [73.62152863, 15.85680962], [73.62124634, 15.85680485], [73.62124634, 15.85708332], [73.62152863, 15.85708141], [73.62152863, 15.85763931], [73.62180328, 15.85763931], [73.62180328, 15.85791969], [73.62152863, 15.85791683], [73.62152863, 15.85847092], [73.62124634, 15.85847092], [73.62124634, 15.8587513], [73.62014008, 15.8587513], [73.62014008, 15.85819054], [73.61985779, 15.8581953], [73.61985779, 15.85763931], [73.61902618, 15.85763931], [73.61902618, 15.85736084], [73.61846924, 15.85736084], [73.61846924, 15.85708141], [73.61819458, 15.85708332], [73.61819458, 15.85680485], [73.61763763, 15.85680962], [73.61763763, 15.85514069], [73.61791992, 15.85514069], [73.61791992, 15.85458088], [73.61819458, 15.85458279], [73.61819458, 15.85430527], [73.61875153, 15.85431194], [73.61875153, 15.85404015], [73.61902618, 15.85404015], [73.61902618, 15.85375118], [73.61930847, 15.85375118], [73.61930847, 15.85236073], [73.61875153, 15.85236073], [73.61875153, 15.85208035], [73.61818695, 15.85208035], [73.61818695, 15.85264111], [73.61791992, 15.85264111], [73.61791992, 15.85292053], [73.61708069, 15.85291672], [73.61708069, 15.85319519], [73.61569214, 15.85319519], [73.61569214, 15.85291672], [73.61541748, 15.85291672], [73.61541748, 15.85319519], [73.61513519, 15.85319519], [73.61513519, 15.8534708], [73.61486053, 15.8534708], [73.61486053, 15.85375118], [73.61429596, 15.85375118], [73.61429596, 15.85404015], [73.61374664, 15.85404015], [73.61374664, 15.85431194], [73.61319733, 15.85430527], [73.61319733, 15.85458279], [73.61292267, 15.85458088], [73.61292267, 15.85514069], [73.61319733, 15.85513878], [73.61319733, 15.85597324], [73.61292267, 15.85597134], [73.61292267, 15.85652924], [73.61264038, 15.85652924], [73.61264038, 15.85708332], [73.61235809, 15.85708141], [73.61235809, 15.85763931], [73.61208344, 15.85763931], [73.61208344, 15.8581953], [73.61180878, 15.8581953], [73.61180878, 15.85847092], [73.61152649, 15.85847092], [73.61152649, 15.85931015], [73.61125183, 15.85930538], [73.61125183, 15.8595829], [73.61096954, 15.8595829], [73.61096954, 15.85986137], [73.61125183, 15.85984993], [73.61125183, 15.86014175], [73.61096954, 15.86014175], [73.61096954, 15.86264038], [73.61069489, 15.86263657], [73.61069489, 15.86347198], [73.61042786, 15.86347198], [73.61042786, 15.86403179], [73.61013794, 15.86403179], [73.61013794, 15.86431026], [73.60986328, 15.86430645], [73.60986328, 15.86486244], [73.60958099, 15.86485958], [73.60958099, 15.86513996], [73.60986328, 15.86513996], [73.60986328, 15.86542034], [73.61013794, 15.86541557], [73.61013794, 15.86569405], [73.61042786, 15.86568928], [73.61042786, 15.86653042], [73.61013794, 15.86653042], [73.61013794, 15.86791992], [73.60986328, 15.86791992], [73.60986328, 15.86874962], [73.60958099, 15.86874962], [73.60958099, 15.86903858], [73.60930634, 15.86903858], [73.60930634, 15.86931133], [73.60901642, 15.86931133], [73.60902405, 15.8698597], [73.6084671, 15.8698597], [73.6084671, 15.87125015], [73.60874939, 15.87125015], [73.60874939, 15.87153053], [73.6084671, 15.87153053], [73.6084671, 15.87181091], [73.60819244, 15.87180614], [73.60819244, 15.87208366], [73.60791779, 15.87207985], [73.60791779, 15.87263966], [73.6076355, 15.87263775], [73.6076355, 15.87319374], [73.60736084, 15.87319374], [73.60736084, 15.87347221], [73.60708618, 15.87347031], [73.60708618, 15.87374973], [73.60679626, 15.87374973], [73.60679626, 15.87403107], [73.60652924, 15.87402821], [73.60652924, 15.87458229], [73.60624695, 15.87458038], [73.60624695, 15.87542057], [73.60597229, 15.8754158], [73.60597229, 15.87569523], [73.60569763, 15.87569046], [73.60569763, 15.87625122], [73.60541534, 15.87625122], [73.60541534, 15.8773613], [73.60514069, 15.8773613], [73.60514069, 15.8779211], [73.6048584, 15.8779211], [73.6048584, 15.8787508], [73.60457611, 15.8787508], [73.60457611, 15.87986088], [73.60430145, 15.87986088], [73.60430145, 15.88014126], [73.60402679, 15.88014126], [73.60402679, 15.88097954], [73.60375214, 15.88097954], [73.60375214, 15.88153076], [73.60346985, 15.88152695], [73.60346985, 15.88208294], [73.6029129, 15.88208294], [73.6029129, 15.88236141], [73.60320282, 15.88236141], [73.60320282, 15.88264084], [73.6029129, 15.88264084], [73.6029129, 15.88291931], [73.60263824, 15.8829174], [73.60263824, 15.88319302], [73.6029129, 15.88319111], [73.6029129, 15.88514233], [73.60235596, 15.88514233], [73.60235596, 15.88542175], [73.60152435, 15.88541698], [73.60152435, 15.88569546], [73.60097504, 15.88569546], [73.60097504, 15.88597107], [73.59958649, 15.88597107], [73.59958649, 15.88625145], [73.59929657, 15.88625145], [73.59929657, 15.88653183], [73.59874725, 15.88653183], [73.59874725, 15.88792038], [73.5984726, 15.88791847], [73.5984726, 15.88819313], [73.59874725, 15.88819313], [73.59874725, 15.88847446], [73.59929657, 15.88847065], [73.59929657, 15.88875198], [73.59958649, 15.88875198], [73.59958649, 15.88903046], [73.59986115, 15.88903046], [73.59986115, 15.88931179], [73.59958649, 15.88930607], [73.59958649, 15.88986206], [73.59874725, 15.8898592], [73.59874725, 15.89015102], [73.5984726, 15.89015102], [73.5984726, 15.89041996], [73.59819794, 15.89041805], [73.59819794, 15.89069366], [73.59708405, 15.89069366], [73.59708405, 15.89097214], [73.59680939, 15.89096928], [73.59680176, 15.89153004], [73.5965271, 15.89153004], [73.5965271, 15.89235973], [73.59680176, 15.89235973], [73.59680176, 15.89264202], [73.5965271, 15.89264202], [73.5965271, 15.89291954], [73.59680176, 15.89291573], [73.59680176, 15.89347172], [73.5965271, 15.89347172], [73.5965271, 15.89375019], [73.59680176, 15.89375019], [73.59680176, 15.89431095], [73.5965271, 15.89431095], [73.5965271, 15.89513969], [73.59625244, 15.89513779], [73.59625244, 15.89569378], [73.59597015, 15.89569187], [73.59597015, 15.89653015], [73.59570313, 15.89653015], [73.59570313, 15.89681053], [73.59541321, 15.89680576], [73.59541321, 15.89735985], [73.59513855, 15.89735985], [73.59513855, 15.89764023], [73.59485626, 15.89764023], [73.59485626, 15.89792061], [73.5945816, 15.89791584], [73.5945816, 15.89847183], [73.59430695, 15.89846992], [73.59430695, 15.89875031], [73.59402466, 15.89875031], [73.59402466, 15.89902782], [73.59375, 15.89901924], [73.59375, 15.89931107], [73.59319305, 15.8993063], [73.59319305, 15.89958191], [73.59263611, 15.89958382], [73.59263611, 15.89986229], [73.59208679, 15.89986038], [73.59208679, 15.90014267], [73.59179688, 15.90014267], [73.59179688, 15.90042114], [73.59124756, 15.90042114], [73.59124756, 15.90125275], [73.5909729, 15.90125275], [73.5909729, 15.90181065], [73.59124756, 15.90181065], [73.59124756, 15.9026413], [73.5909729, 15.9026413], [73.5909729, 15.90375137], [73.59069824, 15.90375137], [73.59069824, 15.90486145], [73.59041595, 15.90486145], [73.59041595, 15.90597343], [73.5901413, 15.90597057], [73.5901413, 15.90653133], [73.58985901, 15.90653133], [73.58985901, 15.90681171], [73.58957672, 15.90681171], [73.58957672, 15.90736103], [73.58930206, 15.90736103], [73.58930206, 15.90764141], [73.5890274, 15.90764141], [73.5890274, 15.90792084], [73.58875275, 15.90791702], [73.58875275, 15.90819454], [73.58847046, 15.90819454], [73.58847046, 15.90847301], [73.5881958, 15.90847111], [73.5881958, 15.90903091], [73.58791351, 15.90902901], [73.58791351, 15.90958309], [73.58985901, 15.90958309], [73.58985901, 15.90930462], [73.59069824, 15.90930462], [73.59069824, 15.90948009], [73.59069824, 15.91181183], [73.59041595, 15.91180515], [73.59041595, 15.91236115], [73.58985901, 15.91236115], [73.58985901, 15.91208267], [73.58930206, 15.91208267], [73.58930206, 15.91180515], [73.5890274, 15.91181183], [73.5890274, 15.91152859], [73.58875275, 15.91152859], [73.58875275, 15.9109602], [73.58847046, 15.9109726], [73.58847046, 15.91069508], [73.5881958, 15.91069508], [73.5881958, 15.9104166], [73.58680725, 15.9104166], [73.58680725, 15.91013908], [73.58625793, 15.91014099], [73.58625793, 15.90986061], [73.58597565, 15.90986061], [73.58597565, 15.90930462], [73.58569336, 15.90930462], [73.58569336, 15.90986061], [73.5854187, 15.90986061], [73.5854187, 15.90958309], [73.58513641, 15.90958309], [73.58513641, 15.90986061], [73.58180237, 15.90986061], [73.58180237, 15.91014099], [73.57930756, 15.91014099], [73.57930756, 15.90986061], [73.57875061, 15.90986061], [73.57875061, 15.91041946], [73.57847595, 15.91041946], [73.57847595, 15.91152859], [73.57736206, 15.91152859], [73.57736206, 15.91181183], [73.57681274, 15.91181183], [73.57681274, 15.91152859], [73.57624817, 15.91152859], [73.57624817, 15.91181183], [73.57402802, 15.91180515], [73.57402802, 15.91208267], [73.57236481, 15.91208267], [73.57236481, 15.91180515], [73.57152557, 15.91180515], [73.57152557, 15.91208267], [73.57013702, 15.91208267], [73.57013702, 15.91236115], [73.56958008, 15.91236115], [73.56958008, 15.91264153], [73.56874847, 15.91263866], [73.56874847, 15.91319466], [73.56846619, 15.91319084], [73.56846619, 15.91431046], [73.56819153, 15.91431046], [73.56819153, 15.91514015], [73.56791687, 15.91514015], [73.56791687, 15.91569328], [73.56764221, 15.91569138], [73.56764221, 15.9159708], [73.56735992, 15.9159708], [73.56735992, 15.91624928], [73.56708527, 15.91624928], [73.56708527, 15.91847229], [73.56680298, 15.91846943], [73.56680298, 15.91874981], [73.56624603, 15.91874981], [73.56624603, 15.91903019], [73.56597137, 15.91903019], [73.56597137, 15.91930962], [73.56569672, 15.9193058], [73.56569672, 15.91958427], [73.5654068, 15.91958237], [73.5654068, 15.91986179], [73.56513977, 15.91986179], [73.56513977, 15.92014027], [73.56402588, 15.92013073], [73.56402588, 15.92041969], [73.56375122, 15.92041588], [73.56375122, 15.92069435], [73.56346893, 15.92069435], [73.56346893, 15.92097187], [73.56263733, 15.92097187], [73.56263733, 15.92125034], [73.56181335, 15.92125034], [73.56181335, 15.92152977], [73.56124878, 15.92152977], [73.56124878, 15.9218111], [73.56069183, 15.92180634], [73.56069183, 15.92236233], [73.55986023, 15.92236042], [73.55986023, 15.92263985], [73.55930328, 15.92263794], [73.55930328, 15.92319393], [73.55902863, 15.92319202], [73.55902863, 15.92374992], [73.55874634, 15.92374992], [73.55874634, 15.9240303], [73.55819702, 15.9240303], [73.55819702, 15.92431068], [73.55708313, 15.92430592], [73.55708313, 15.92458439], [73.55652618, 15.92457962], [73.55652618, 15.92486], [73.55596924, 15.92486], [73.55596924, 15.92514038], [73.55568695, 15.92514038], [73.55568695, 15.92542076], [73.55541992, 15.92541599], [73.55541992, 15.92569447], [73.55513763, 15.92569447], [73.55513763, 15.92597198], [73.55486298, 15.92597008], [73.55486298, 15.9262619], [73.55403137, 15.9262619], [73.55403137, 15.92681122], [73.55208588, 15.92680645], [73.55208588, 15.9273634], [73.54957581, 15.92735958], [73.54957581, 15.92764091], [73.54930878, 15.92763805], [73.54930878, 15.92819405], [73.54875183, 15.92819405], [73.54875183, 15.92847157], [73.54846954, 15.92846966], [73.54846954, 15.92875099], [73.54792023, 15.92875099], [73.54792023, 15.92903137], [73.54763794, 15.92903137], [73.54763794, 15.92932034], [73.54708099, 15.92930698], [73.54708099, 15.92958546], [73.54680634, 15.92957973], [73.54680634, 15.93014145], [73.54651642, 15.93014145], [73.54651642, 15.93042088], [73.54624939, 15.93041706], [73.54624939, 15.93069458], [73.5459671, 15.93068981], [73.5459671, 15.93125057], [73.54585266, 15.93125057], [73.54541779, 15.93125057], [73.54541779, 15.93153095], [73.54514313, 15.93153095], [73.54514313, 15.93181133], [73.54458618, 15.93181133], [73.54458618, 15.93236065], [73.54402924, 15.93236065], [73.54402924, 15.93264103], [73.54374695, 15.93264103], [73.54374695, 15.93292141], [73.54347229, 15.93291664], [73.54347229, 15.93347263], [73.54319763, 15.93347073], [73.54319763, 15.93375111], [73.54264069, 15.93375111], [73.54264069, 15.93403053], [73.5423584, 15.93403053], [73.5423584, 15.93431187], [73.54180908, 15.93430519], [73.54180908, 15.93458271], [73.54152679, 15.93458271], [73.54152679, 15.9351387], [73.54096985, 15.9351387], [73.54096985, 15.93569469], [73.54069519, 15.93569469], [73.54069519, 15.93597317], [73.54013824, 15.93597126], [73.54013824, 15.93653107], [73.53848267, 15.93653107], [73.53848267, 15.93680954], [73.53819275, 15.93680477], [73.53819275, 15.93708324], [73.53708649, 15.93708134], [73.53708649, 15.93763924], [73.53514862, 15.93763924], [73.53514862, 15.93736076], [73.5348587, 15.93736076], [73.5348587, 15.93653107], [73.53457642, 15.93653107], [73.53457642, 15.93597126], [73.53430176, 15.93597317], [73.53430176, 15.93569469], [73.5340271, 15.93569469], [73.5340271, 15.9351387], [73.53375244, 15.9351387], [73.53375244, 15.93458271], [73.5331955, 15.93458271], [73.5331955, 15.93402672], [73.53292847, 15.93403053], [73.53291321, 15.93375111], [73.53263855, 15.93375111], [73.53263855, 15.93347073], [73.53236389, 15.93347263], [73.53236389, 15.93319511], [73.5320816, 15.93319511], [73.5320816, 15.93291664], [73.53069305, 15.93291664], [73.53069305, 15.93319511], [73.52958679, 15.93319035], [73.52958679, 15.93375111], [73.5284729, 15.93375111], [73.5284729, 15.93403053], [73.52791595, 15.93403053], [73.52791595, 15.93431187], [73.5276413, 15.93430519], [73.5276413, 15.93458271], [73.5265274, 15.93458271], [73.5265274, 15.93486118], [73.52625275, 15.93486118], [73.52625275, 15.9351387], [73.52596283, 15.93513203], [73.52596283, 15.93542194], [73.5256958, 15.93541718], [73.5256958, 15.93597317], [73.52540588, 15.93597126], [73.52540588, 15.93625069], [73.52485657, 15.93625069], [73.52485657, 15.93653107], [73.52458191, 15.93652916], [73.52458191, 15.93667126], [73.52458191, 15.93680954], [73.52402496, 15.93680477], [73.52402496, 15.93708324], [73.52375031, 15.93708134], [73.52375031, 15.93736076], [73.52348328, 15.93736076], [73.52348328, 15.93763924], [73.5229187, 15.93763924], [73.5229187, 15.93791866], [73.52263641, 15.93791866], [73.52263641, 15.9382], [73.5220871, 15.9382], [73.5220871, 15.93847084], [73.52131653, 15.93847084], [73.52041626, 15.93847084], [73.52041626, 15.93875122], [73.5201416, 15.93875122], [73.5201416, 15.93847084], [73.51957703, 15.93847084], [73.51957703, 15.9382], [73.51930237, 15.9382], [73.51930237, 15.93847084], [73.51790619, 15.93847084], [73.51790619, 15.9382], [73.51708221, 15.9382], [73.51708221, 15.93791866], [73.51680756, 15.93791866], [73.51680756, 15.9382], [73.51652527, 15.93819523], [73.5165329, 15.93875122], [73.51625061, 15.93875122], [73.51625061, 15.93931198], [73.51431274, 15.93931198], [73.51431274, 15.9390316], [73.51402283, 15.9390316], [73.51402283, 15.93875122], [73.51374817, 15.93875122], [73.51374817, 15.93847084], [73.51346588, 15.93847084], [73.51346588, 15.9382], [73.51319122, 15.9382], [73.51319122, 15.93763924], [73.51291656, 15.93763924], [73.51291656, 15.93708134], [73.51264191, 15.93708324], [73.51264191, 15.93680477], [73.51069641, 15.93680477], [73.51069641, 15.93708324], [73.51013947, 15.93708134], [73.51013947, 15.93736076], [73.50985718, 15.93736076], [73.50985718, 15.93791866], [73.50958252, 15.93791866], [73.50958252, 15.9390316], [73.50986481, 15.93902683], [73.50986481, 15.93958282], [73.51013947, 15.93958092], [73.51013947, 15.94014168], [73.50986481, 15.94013882], [73.50986481, 15.94069481], [73.50958252, 15.94069099], [73.50958252, 15.94153023], [73.50930786, 15.94153023], [73.50930786, 15.94180965], [73.5090332, 15.94180965], [73.5090332, 15.9426403], [73.50875092, 15.9426403], [73.50875092, 15.94319344], [73.50846863, 15.94319057], [73.50846863, 15.94375038], [73.50818634, 15.94375038], [73.50818634, 15.94402981], [73.50791931, 15.9440279], [73.50791931, 15.94458389], [73.50736237, 15.94458389], [73.50736237, 15.94486237], [73.50708008, 15.94485855], [73.50708008, 15.94542027], [73.50680542, 15.94541645], [73.50681305, 15.9456892], [73.50653076, 15.94569588], [73.50653076, 15.94597244], [73.50624847, 15.94597244], [73.50624847, 15.94625187], [73.50597382, 15.94624996], [73.50597382, 15.94708443], [73.50569153, 15.94708443], [73.50569153, 15.94819355], [73.50541687, 15.94819164], [73.50541687, 15.94931126], [73.50514221, 15.94930553], [73.50514221, 15.94958401], [73.50485992, 15.94958401], [73.50485992, 15.94986153], [73.5045929, 15.94985962], [73.5045929, 15.95042133], [73.50402832, 15.95041561], [73.50402832, 15.9509716], [73.50374603, 15.9509697], [73.50374603, 15.95125008], [73.50319672, 15.95125008], [73.50319672, 15.95292091], [73.5029068, 15.95292091], [73.5029068, 15.95374966], [73.50263977, 15.95374966], [73.50263977, 15.95458221], [73.50235748, 15.95458031], [73.50235748, 15.95485973], [73.50208282, 15.95485973], [73.50208282, 15.95514107], [73.50180817, 15.95514107], [73.50180817, 15.95542145], [73.50152588, 15.95542145], [73.50152588, 15.95597267], [73.50180817, 15.95597267], [73.50180817, 15.95653057], [73.50235748, 15.95652866], [73.50235748, 15.95708466], [73.50319672, 15.95708466], [73.50319672, 15.95680428], [73.50347137, 15.95680428], [73.50347137, 15.95708466], [73.50402832, 15.95708179], [73.50402832, 15.95764065], [73.50430298, 15.95764065], [73.50430298, 15.95903111], [73.50458527, 15.9590292], [73.50458527, 15.95930672], [73.50485992, 15.95930672], [73.50485992, 15.95958328], [73.50514221, 15.95958042], [73.50514221, 15.96014118], [73.50541687, 15.96014118], [73.50541687, 15.96042061], [73.50569153, 15.96041679], [73.50569153, 15.96069527], [73.50596619, 15.96068954], [73.50596619, 15.96125126], [73.50624847, 15.96125126], [73.50624847, 15.96236134], [73.50653076, 15.96236134], [73.50653076, 15.96569538], [73.50624847, 15.96569538], [73.50624847, 15.96736145], [73.50596619, 15.96736145], [73.50596619, 15.96819973], [73.50569153, 15.96819305], [73.50569153, 15.96847439], [73.50430298, 15.96847057], [73.50430298, 15.96875191], [73.50263977, 15.96875191], [73.50263977, 15.96847057], [73.50208282, 15.96847439], [73.50208282, 15.96819305], [73.50152588, 15.96819305], [73.50152588, 15.96847439], [73.50125122, 15.96847057], [73.50125122, 15.96875191], [73.50096893, 15.96875191], [73.50096893, 15.96903038], [73.50068665, 15.96903038], [73.50068665, 15.96930981], [73.50041962, 15.96930504], [73.50041962, 15.96958447], [73.49986267, 15.96958447], [73.49986267, 15.97069263], [73.49958038, 15.97069263], [73.49958038, 15.97124958], [73.49931335, 15.97124004], [73.49931335, 15.97152996], [73.49903107, 15.97152805], [73.49903107, 15.97208405], [73.49874878, 15.97207928], [73.49874878, 15.97264194], [73.49846649, 15.97264194], [73.49846649, 15.97292042], [73.49819183, 15.97291565], [73.49819183, 15.97319412], [73.49791718, 15.97319412], [73.49791718, 15.97347164], [73.49764252, 15.97347164], [73.49764252, 15.97402954], [73.49736023, 15.97402763], [73.49736023, 15.97458363], [73.49708557, 15.97458363], [73.49708557, 15.9748621], [73.49680328, 15.97486019], [73.49680328, 15.97542], [73.49652863, 15.97541809], [73.49652863, 15.9756937], [73.49624634, 15.9756918], [73.49624634, 15.97653008], [73.49597931, 15.97653008], [73.49597931, 15.97681141], [73.49541473, 15.97680569], [73.49541473, 15.97708416], [73.49514008, 15.97708035], [73.49514008, 15.97764015], [73.49485779, 15.97764015], [73.49485779, 15.97819424], [73.49458313, 15.97819424], [73.49458313, 15.97847176], [73.49430847, 15.97846985], [73.49430847, 15.97903061], [73.49402618, 15.97903061], [73.49402618, 15.97931099], [73.49375153, 15.97930622], [73.49375153, 15.97958374], [73.49346924, 15.97958374], [73.49346924, 15.97986031], [73.49291992, 15.97986031], [73.49291992, 15.98069382], [73.49263763, 15.98069382], [73.49263763, 15.98097229], [73.49236298, 15.98097038], [73.49236298, 15.98125267], [73.49208069, 15.98125267], [73.49208069, 15.98153114], [73.49180603, 15.98152828], [73.49180603, 15.98208237], [73.49153137, 15.98208046], [73.49153137, 15.98264122], [73.49124908, 15.98263836], [73.49124908, 15.9831953], [73.4909668, 15.983181], [73.4909668, 15.9837513], [73.49069214, 15.9837513], [73.49069214, 15.98403072], [73.49041748, 15.98402882], [73.49041748, 15.9845829], [73.49014282, 15.98458004], [73.49014282, 15.9851408], [73.48986053, 15.98513889], [73.48986053, 15.98569489], [73.48958588, 15.98569012], [73.48958588, 15.98681164], [73.48930359, 15.98680687], [73.48930359, 15.98708344], [73.48902893, 15.98707962], [73.48902893, 15.98792076], [73.48874664, 15.98791695], [73.48874664, 15.99102974], [73.48874664, 15.99236965], [73.48847198, 15.99236107], [73.48847198, 15.99319458], [73.48874664, 15.99319458], [73.48874664, 15.99347115], [73.48847198, 15.99347115], [73.48847198, 15.99486065], [73.48874664, 15.99486065], [73.48874664, 15.99708366], [73.48902893, 15.99708366], [73.48902893, 15.99847221], [73.48874664, 15.99846935], [73.48874664, 15.99903011], [73.48902893, 15.99903011], [73.48902893, 15.99930954], [73.48929596, 15.99930954], [73.48930359, 15.99986172], [73.48930359, 16.0023613], [73.48958588, 16.0023613], [73.48958588, 16.00319481], [73.48986053, 16.00319481], [73.48986053, 16.00708389], [73.49013519, 16.00708389], [73.49013519, 16.00736046], [73.49041748, 16.00735092], [73.49041748, 16.00764084], [73.49069214, 16.00763893], [73.49069214, 16.00958252], [73.4909668, 16.00958061], [73.4909668, 16.01153183], [73.49069214, 16.01153183], [73.49069214, 16.0118103], [73.49041748, 16.01180649], [73.49041748, 16.01236153], [73.49014282, 16.01236153], [73.49014282, 16.01264191], [73.48985291, 16.01264191], [73.48985291, 16.01375008], [73.48958588, 16.01375008], [73.48958588, 16.01597214], [73.48930359, 16.01597214], [73.48930359, 16.01708412], [73.48902893, 16.01708412], [73.48902893, 16.01847267], [73.48874664, 16.01847076], [73.48874664, 16.01902962], [73.48847198, 16.01902962], [73.48847198, 16.01931], [73.48819733, 16.01930428], [73.48819733, 16.01958275], [73.48792267, 16.01958084], [73.48792267, 16.02042007], [73.48764038, 16.02041626], [73.48764038, 16.0209713], [73.48735809, 16.02096939], [73.48735809, 16.02153015], [73.48708344, 16.02152634], [73.48708344, 16.02236176], [73.48680878, 16.02236176], [73.48680878, 16.02347183], [73.48652649, 16.02346992], [73.48652649, 16.0237484], [73.48625183, 16.0237484], [73.48625183, 16.02403069], [73.48596954, 16.02403069], [73.48596954, 16.02485847], [73.48568726, 16.02485847], [73.48568726, 16.02514076], [73.48596954, 16.02514076], [73.48596954, 16.02569389], [73.48568726, 16.02568817], [73.48568726, 16.02653122], [73.48542023, 16.02653122], [73.48542023, 16.02763939], [73.48513794, 16.02763939], [73.48513794, 16.02931023], [73.48486328, 16.02930641], [73.48486328, 16.02986145], [73.48458099, 16.02985954], [73.48458099, 16.0304203], [73.48430634, 16.03041649], [73.48430634, 16.03152847], [73.48401642, 16.03152084], [73.48401642, 16.03292084], [73.48374939, 16.03292084], [73.48374939, 16.03403091], [73.4834671, 16.03403091], [73.4834671, 16.03514099], [73.48319244, 16.03513718], [73.48319244, 16.0359726], [73.48291779, 16.03597069], [73.48291779, 16.03652954], [73.4826355, 16.03652954], [73.4826355, 16.03708267], [73.48236084, 16.03708076], [73.48236084, 16.03763962], [73.48208618, 16.03763962], [73.48208618, 16.03819466], [73.48180389, 16.03819466], [73.48180389, 16.03847313], [73.48152924, 16.03846931], [73.48152924, 16.0387516], [73.48124695, 16.0387516], [73.48124695, 16.03930473], [73.48097229, 16.03930473], [73.48097229, 16.03958321], [73.48069763, 16.03957939], [73.48069763, 16.04014015], [73.48014069, 16.04014015], [73.48014069, 16.04042053], [73.4798584, 16.04042053], [73.4798584, 16.04071045], [73.47957611, 16.04071045], [73.47957611, 16.04125023], [73.47930908, 16.04125023], [73.47930908, 16.04153061], [73.47902679, 16.04153061], [73.47902679, 16.0418129], [73.47846985, 16.04180527], [73.47846985, 16.04208374], [73.47819519, 16.04208374], [73.47820282, 16.04236031], [73.4779129, 16.04236031], [73.4779129, 16.04292107], [73.47763824, 16.04291725], [73.47763824, 16.04347229], [73.47735596, 16.04346275], [73.47735596, 16.04375076], [73.4770813, 16.04375076], [73.4770813, 16.04403114], [73.47569275, 16.04403114], [73.47569275, 16.04430962], [73.47486115, 16.0443058], [73.47486115, 16.04458427], [73.47429657, 16.04458046], [73.47429657, 16.04514122], [73.4734726, 16.04514122], [73.4734726, 16.04541969], [73.47264099, 16.04541588], [73.47264099, 16.04569435], [73.47180939, 16.04569435], [73.47180176, 16.04597282], [73.47097015, 16.04597092], [73.47097015, 16.04624939], [73.46902466, 16.04624939], [73.46902466, 16.04652786], [73.46847534, 16.04652786], [73.46847534, 16.0470829], [73.46819305, 16.04708099], [73.46819305, 16.04792023], [73.46847534, 16.04791641], [73.46847534, 16.04847145], [73.46875, 16.04847145], [73.46875, 16.04986191], [73.46848297, 16.04985809], [73.46848297, 16.05180931], [73.46819305, 16.0518055], [73.46819305, 16.05208397], [73.4679184, 16.05207825], [73.4679184, 16.05265045], [73.46763611, 16.05265045], [73.46763611, 16.05291939], [73.46736145, 16.05291748], [73.46736145, 16.05347252], [73.46708679, 16.05347252], [73.46708679, 16.0537529], [73.46679688, 16.0537529], [73.46679688, 16.05402946], [73.46624756, 16.05402946], [73.46624756, 16.05430984], [73.46569824, 16.05430603], [73.46569824, 16.0545826], [73.46541595, 16.0545826], [73.46541595, 16.05486107], [73.46347046, 16.05486107], [73.46347046, 16.05513954], [73.46263885, 16.05513954], [73.46263885, 16.05541992], [73.46097565, 16.05541611], [73.46097565, 16.05569458], [73.45930481, 16.05569458], [73.45930481, 16.05541611], [73.45903015, 16.05541992], [73.45903015, 16.05486107], [73.45874786, 16.05486107], [73.45874786, 16.05347252], [73.45847321, 16.05347252], [73.45847321, 16.05319405], [73.45652771, 16.05319405], [73.45652771, 16.05347252], [73.45625305, 16.05347252], [73.45625305, 16.0537529], [73.45597076, 16.0537529], [73.45597076, 16.05402946], [73.45569611, 16.05402946], [73.45569611, 16.05430984], [73.45541382, 16.05430603], [73.45541382, 16.0545826], [73.45513916, 16.0545826], [73.45513916, 16.05513954], [73.4548645, 16.05513954], [73.4548645, 16.05569458], [73.45513916, 16.05569458], [73.45513916, 16.05597305], [73.45569611, 16.05597305], [73.45569611, 16.05569458], [73.45625305, 16.05569458], [73.45625305, 16.05597305], [73.45652771, 16.05597115], [73.45652771, 16.05653], [73.45680237, 16.05652809], [73.45680237, 16.0573616], [73.45652771, 16.0573597], [73.45652771, 16.05764008], [73.45625305, 16.05764008], [73.45625305, 16.05792046], [73.45597076, 16.05792046], [73.45597076, 16.05820084], [73.45569611, 16.05819321], [73.45569611, 16.05847168], [73.45540619, 16.05846024], [73.45540619, 16.05875015], [73.45569611, 16.05875015], [73.45569611, 16.05931091], [73.45597076, 16.05930519], [73.45597076, 16.06069374], [73.45569611, 16.06069374], [73.45569611, 16.06097221], [73.45541382, 16.06097221], [73.45541382, 16.06152534], [73.45513916, 16.06152534], [73.45513916, 16.0620842], [73.45485687, 16.06208038], [73.45485687, 16.06291962], [73.45513916, 16.0629158], [73.45513916, 16.06319427], [73.45652771, 16.06319427], [73.45652771, 16.0629158], [73.45680237, 16.0629158], [73.45680237, 16.06319427], [73.45819092, 16.06319427], [73.45819092, 16.0629158], [73.45847321, 16.06291962], [73.45847321, 16.06264114], [73.45874786, 16.06264114], [73.45874786, 16.06236076], [73.45986938, 16.06236076], [73.45986938, 16.06264114], [73.4604187, 16.06264114], [73.4604187, 16.06291962], [73.46097565, 16.0629158], [73.46097565, 16.06319427], [73.46151733, 16.06319046], [73.46151733, 16.06375122], [73.46208191, 16.06375122], [73.46208191, 16.06430817], [73.4623642, 16.06430626], [73.4623642, 16.0648613], [73.46290588, 16.0648613], [73.46290588, 16.06542015], [73.4631958, 16.06541634], [73.4631958, 16.06569481], [73.46347046, 16.06569481], [73.46347046, 16.06680489], [73.46375275, 16.06679916], [73.46375275, 16.06764984], [73.4640274, 16.06764984], [73.4640274, 16.06792068], [73.46430206, 16.06792068], [73.46430206, 16.06875038], [73.4640274, 16.06875038], [73.4640274, 16.06903076], [73.46375275, 16.06903076], [73.46375275, 16.06931114], [73.46347046, 16.06930542], [73.46347046, 16.06958389], [73.4631958, 16.06958008], [73.4631958, 16.07042122], [73.46347046, 16.0704174], [73.46347046, 16.07069588], [73.4640274, 16.07069588], [73.4640274, 16.07097244], [73.46430206, 16.07097054], [73.46430206, 16.07125092], [73.46485901, 16.07125092], [73.46485901, 16.07152939], [73.46541595, 16.07152939], [73.46541595, 16.07125092], [73.46568298, 16.07125092], [73.46569824, 16.07097054], [73.4659729, 16.07097244], [73.4659729, 16.0704174], [73.46624756, 16.07042122], [73.46624756, 16.06986046], [73.46652985, 16.06986046], [73.46652985, 16.06958008], [73.46736145, 16.06958008], [73.46736145, 16.06986046], [73.46763611, 16.06986046], [73.46763611, 16.07125092], [73.46736145, 16.07125092], [73.46736145, 16.07208252], [73.46708679, 16.07208061], [73.46708679, 16.07263947], [73.4668045, 16.07263947], [73.4668045, 16.0731945], [73.46652985, 16.0731945], [73.46652985, 16.07347298], [73.4659729, 16.07347107], [73.4659729, 16.07374954], [73.46569824, 16.07374954], [73.46569824, 16.07402992], [73.46541595, 16.07402992], [73.46541595, 16.07542038], [73.4651413, 16.07542038], [73.4651413, 16.07570076], [73.46485901, 16.07570076], [73.46485901, 16.07764053], [73.46430206, 16.07764053], [73.46430206, 16.07819366], [73.46375275, 16.07818985], [73.46375275, 16.07902908], [73.46347046, 16.07902908], [73.46347046, 16.07930946], [73.46290588, 16.07930946], [73.46290588, 16.07959175], [73.46263885, 16.07959175], [73.46263885, 16.07986259], [73.46235657, 16.07986259], [73.46235657, 16.08014107], [73.45874786, 16.08014107], [73.45874786, 16.07986259], [73.4576416, 16.07986259], [73.4576416, 16.08014107], [73.45735931, 16.08013916], [73.45735931, 16.0806942], [73.45707703, 16.08069038], [73.45707703, 16.08181], [73.45735931, 16.08180618], [73.45735931, 16.08208275], [73.45791626, 16.08208275], [73.45791626, 16.08263969], [73.45847321, 16.08263016], [73.45847321, 16.08292007], [73.45874786, 16.08291626], [73.45874786, 16.08319473], [73.45903015, 16.08319283], [73.45903015, 16.08403015], [73.45874786, 16.08402824], [73.45874786, 16.08458328], [73.45847321, 16.08457947], [73.45847321, 16.08514023], [73.45819092, 16.08514023], [73.45819092, 16.08542061], [73.45791626, 16.08541679], [73.45791626, 16.08569527], [73.4576416, 16.08569527], [73.4576416, 16.08597183], [73.45791626, 16.08596992], [73.45791626, 16.08625031], [73.45874786, 16.08625031], [73.45874786, 16.08596992], [73.45930481, 16.08597183], [73.45930481, 16.08569527], [73.46097565, 16.08569527], [73.46097565, 16.08597183], [73.46180725, 16.08596992], [73.46180725, 16.08625031], [73.46263885, 16.08625031], [73.46263885, 16.08653069], [73.46235657, 16.08653069], [73.46235657, 16.08736038], [73.46208191, 16.08736038], [73.46208191, 16.08958244], [73.46180725, 16.08958054], [73.46180725, 16.09181976], [73.46151733, 16.09181976], [73.46151733, 16.09403038], [73.46125031, 16.09403038], [73.46125031, 16.09625053], [73.46097565, 16.09625053], [73.46097565, 16.09708214], [73.46069336, 16.09708023], [73.46069336, 16.09736061], [73.4604187, 16.09736061], [73.4604187, 16.09819412], [73.46013641, 16.09819031], [73.46013641, 16.09875107], [73.45986938, 16.09875107], [73.45986938, 16.09930992], [73.4595871, 16.09930992], [73.4595871, 16.10013962], [73.45929718, 16.10013962], [73.45929718, 16.10042], [73.45903015, 16.10042], [73.45903015, 16.10070038], [73.45874786, 16.10070038], [73.45874786, 16.10153008], [73.45847321, 16.10152626], [73.45847321, 16.10208321], [73.45819092, 16.10208321], [73.45819092, 16.10347176], [73.45791626, 16.10346985], [73.45791626, 16.10403061], [73.4576416, 16.10403061], [73.4576416, 16.10958481], [73.45735931, 16.10958481], [73.45735931, 16.10986137], [73.4576416, 16.10985947], [73.4576416, 16.11042023], [73.45791626, 16.11042023], [73.45791626, 16.11124992], [73.45819092, 16.11124992], [73.45819092, 16.11181068], [73.45791626, 16.11181068], [73.45791626, 16.11652946], [73.4576416, 16.11652946], [73.4576416, 16.11763763], [73.45735931, 16.11763763], [73.45735931, 16.11930466], [73.45708466, 16.11930466], [73.45708466, 16.11958313], [73.45735931, 16.11958313], [73.45735931, 16.12097168], [73.45707703, 16.12097168], [73.45707703, 16.12153053], [73.45680237, 16.12152863], [73.45680237, 16.12208366], [73.45652771, 16.12207985], [73.45652771, 16.12292099], [73.45625305, 16.12292099], [73.45625305, 16.12375069], [73.45597076, 16.12375069], [73.45597076, 16.1245842], [73.45569611, 16.12458038], [73.45569611, 16.12541962], [73.45540619, 16.12541962], [73.45540619, 16.12625122], [73.45513916, 16.12624931], [73.45513916, 16.12708282], [73.4548645, 16.12708282], [73.4548645, 16.12819481], [73.45458221, 16.12819099], [73.45458221, 16.12903023], [73.45430756, 16.12902641], [73.45430756, 16.12986183], [73.4540329, 16.12985992], [73.4540329, 16.1301403], [73.45374298, 16.1301403], [73.45374298, 16.13180923], [73.45347595, 16.13180923], [73.45347595, 16.13292122], [73.45318604, 16.13292122], [73.45318604, 16.13402939], [73.45291901, 16.13402939], [73.45291901, 16.13513947], [73.45263672, 16.13513947], [73.45263672, 16.1356945], [73.45236206, 16.13569069], [73.45236206, 16.13792038], [73.45207977, 16.13792038], [73.45207977, 16.13931084], [73.45180511, 16.13930511], [73.45180511, 16.13958359], [73.45207977, 16.13957977], [73.45207977, 16.14180946], [73.45180511, 16.14180565], [73.45180511, 16.14347267], [73.45153046, 16.14347076], [73.45153046, 16.14402962], [73.45124817, 16.14402962], [73.45124817, 16.14458275], [73.45097351, 16.14458275], [73.45097351, 16.14596939], [73.45067596, 16.14596939], [73.45067596, 16.14653015], [73.45041656, 16.14653015], [73.45041656, 16.14792061], [73.45014191, 16.14792061], [73.45014191, 16.14931107], [73.44985962, 16.14930534], [73.44985962, 16.15097237], [73.44958496, 16.15097237], [73.44958496, 16.15208244], [73.44985962, 16.15208054], [73.44985962, 16.15291977], [73.44958496, 16.15291405], [73.44958496, 16.1534729], [73.44930267, 16.15347099], [73.44930267, 16.15431023], [73.44902802, 16.15431023], [73.44902802, 16.15513992], [73.44875336, 16.15513992], [73.44875336, 16.1554203], [73.44847107, 16.1554203], [73.44847107, 16.15624809], [73.44819641, 16.15624809], [73.44819641, 16.15681076], [73.44791412, 16.15680504], [73.44791412, 16.15736198], [73.44763947, 16.15735817], [73.44763947, 16.15764046], [73.44736481, 16.15764046], [73.44736481, 16.15847015], [73.44708252, 16.15846825], [73.44708252, 16.15874863], [73.44680786, 16.15874863], [73.44680786, 16.15930939], [73.44652557, 16.15930557], [73.44652557, 16.16069412], [73.44625092, 16.16069031], [73.44625092, 16.16292], [73.44596863, 16.16291618], [73.44596863, 16.16486168], [73.44568634, 16.16485977], [73.44568634, 16.16625023], [73.44541931, 16.16625023], [73.44541931, 16.16764069], [73.44513702, 16.16763878], [73.44513702, 16.16847229], [73.44486237, 16.16847038], [73.44486237, 16.16903114], [73.44458008, 16.16902733], [73.44458008, 16.16986084], [73.44430542, 16.16986084], [73.44431305, 16.17124748], [73.44403076, 16.17124748], [73.44403076, 16.17235947], [73.44374847, 16.17235947], [73.44374847, 16.17319489], [73.44346619, 16.17318916], [73.44346619, 16.1740303], [73.44319153, 16.1740303], [73.44319153, 16.17514038], [73.44291687, 16.17514038], [73.44291687, 16.17597961], [73.44264221, 16.17597961], [73.44264221, 16.17681122], [73.44235992, 16.17681122], [73.44235992, 16.17791939], [73.4420929, 16.17791939], [73.4420929, 16.17875099], [73.44180298, 16.17875099], [73.44180298, 16.17986107], [73.44152832, 16.17986107], [73.44152832, 16.18569374], [73.44124603, 16.18568993], [73.44124603, 16.18625259], [73.44097137, 16.18625259], [73.44097137, 16.18680954], [73.44069672, 16.18680954], [73.44069672, 16.18736267], [73.4404068, 16.18736267], [73.4404068, 16.18764114], [73.44013977, 16.18764114], [73.44013977, 16.18875122], [73.43985748, 16.18874931], [73.43985748, 16.18958473], [73.43958282, 16.18958282], [73.43958282, 16.19042015], [73.43930817, 16.19042015], [73.43930817, 16.19124985], [73.43902588, 16.19124985], [73.43902588, 16.19208336], [73.43873596, 16.19207954], [73.43873596, 16.19292068], [73.43846893, 16.19291687], [73.43846893, 16.19402695], [73.43818665, 16.19402122], [73.43818665, 16.19486046], [73.43791962, 16.19486046], [73.43791962, 16.19597244], [73.43763733, 16.19597054], [73.43763733, 16.19652748], [73.43736267, 16.19652748], [73.43736267, 16.19680977], [73.43708038, 16.19680977], [73.43708038, 16.19735909], [73.43681335, 16.19735909], [73.43681335, 16.19791985], [73.43653107, 16.19791603], [73.43653107, 16.1981945], [73.43624878, 16.19819069], [73.43624878, 16.19875145], [73.43596649, 16.19875145], [73.43596649, 16.19903183], [73.43569183, 16.19902992], [73.43569183, 16.2009697], [73.43596649, 16.2009697], [73.43596649, 16.20125008], [73.43653107, 16.20125008], [73.43653107, 16.20153046], [73.43681335, 16.20153046], [73.43681335, 16.20125008], [73.43708038, 16.20125008], [73.43708038, 16.2009697], [73.43736267, 16.2009697], [73.43736267, 16.20069504], [73.43763733, 16.20070267], [73.43763733, 16.20042038], [73.43791962, 16.20042038], [73.43791962, 16.20014954], [73.43930817, 16.20014954], [73.43930817, 16.20042038], [73.44069672, 16.20042038], [73.44069672, 16.20014954], [73.44124603, 16.20014954], [73.44124603, 16.19986153], [73.44152832, 16.19986153], [73.44152832, 16.19958115], [73.44235992, 16.19958115], [73.44235992, 16.19902992], [73.44264221, 16.19903183], [73.44264221, 16.19846916], [73.44291687, 16.19847298], [73.44291687, 16.1981945], [73.44403076, 16.1981945], [73.44403076, 16.19847298], [73.44430542, 16.19847298], [73.44430542, 16.19875145], [73.44458008, 16.19875145], [73.44458008, 16.19903183], [73.44486237, 16.19902992], [73.44486237, 16.19986153], [73.44458008, 16.19986153], [73.44458008, 16.20181084], [73.44430542, 16.20180511], [73.44430542, 16.20236206], [73.44403076, 16.20236015], [73.44403076, 16.20264053], [73.4420929, 16.20263863], [73.44180298, 16.20264053], [73.44180298, 16.20207977], [73.44152832, 16.20208359], [73.44152832, 16.20180511], [73.44124603, 16.20181084], [73.44124603, 16.20153046], [73.44097137, 16.20153046], [73.44097137, 16.20125008], [73.43958282, 16.20125008], [73.43958282, 16.20153046], [73.43902588, 16.20153046], [73.43902588, 16.20292091], [73.43930817, 16.2029171], [73.43930817, 16.20347214], [73.43902588, 16.20347023], [73.43902588, 16.20375061], [73.43930817, 16.20375061], [73.43930817, 16.20514107], [73.43958282, 16.20514107], [73.43958282, 16.20541954], [73.43985748, 16.20541573], [73.43985748, 16.2056942], [73.44041443, 16.2056942], [73.44041443, 16.20597267], [73.44069672, 16.20596123], [73.44069672, 16.20625114], [73.44095612, 16.20624924], [73.44124603, 16.20625114], [73.44124603, 16.20596123], [73.44208527, 16.20597267], [73.44208527, 16.20541573], [73.44235992, 16.20541954], [73.44235992, 16.20486069], [73.44264221, 16.20486069], [73.44264221, 16.20430946], [73.44319153, 16.20430565], [73.44319153, 16.20458412], [73.44374847, 16.20458031], [73.44374847, 16.20486069], [73.44513702, 16.20486069], [73.44513702, 16.20514107], [73.44625092, 16.20514107], [73.44625092, 16.20541954], [73.44680786, 16.20541573], [73.44680786, 16.2056942], [73.44735718, 16.20569038], [73.44735718, 16.20625114], [73.44763947, 16.20625114], [73.44763947, 16.20652962], [73.44791412, 16.20652771], [73.44791412, 16.20708275], [73.44819641, 16.20708084], [73.44819641, 16.20736122], [73.44847107, 16.20736122], [73.44847107, 16.20763969], [73.44875336, 16.20763969], [73.44875336, 16.20792007], [73.44902802, 16.20791626], [73.44902802, 16.20819473], [73.44875336, 16.20819473], [73.44875336, 16.20986176], [73.44902802, 16.20985985], [73.44902802, 16.21042061], [73.44930267, 16.21042061], [73.44930267, 16.21153069], [73.44902802, 16.21153069], [73.44902802, 16.21208954], [73.44847107, 16.21208954], [73.44847107, 16.21180916], [73.44819641, 16.21180916], [73.44819641, 16.21042061], [73.44790649, 16.21042061], [73.44790649, 16.20902061], [73.44763947, 16.20902634], [73.44763947, 16.2084713], [73.44736481, 16.2084713], [73.44736481, 16.20791626], [73.44708252, 16.20792007], [73.44708252, 16.20763969], [73.44680786, 16.20763969], [73.44680786, 16.20736122], [73.44652557, 16.20736122], [73.44652557, 16.20708275], [73.44569397, 16.20708275], [73.44569397, 16.20680428], [73.44486237, 16.20681], [73.44486237, 16.20652962], [73.44403076, 16.20652962], [73.44403076, 16.20625114], [73.44374847, 16.20625114], [73.44374847, 16.20652962], [73.44291687, 16.20652962], [73.44291687, 16.20681], [73.44235992, 16.20680428], [73.44235992, 16.20708275], [73.44264221, 16.20708084], [73.44264221, 16.20792007], [73.44291687, 16.20791626], [73.44291687, 16.20819473], [73.44347382, 16.20819473], [73.44347382, 16.2084713], [73.44374847, 16.20846939], [73.44374847, 16.20874977], [73.44403076, 16.20874977], [73.44403076, 16.20902634], [73.44431305, 16.20902061], [73.44431305, 16.21013832], [73.44458008, 16.21013832], [73.44458008, 16.21235847], [73.44486237, 16.21235847], [73.44486237, 16.21458054], [73.44513702, 16.21458054], [73.44513702, 16.21541977], [73.44541931, 16.21541595], [73.44541931, 16.21597481], [73.44596863, 16.2159729], [73.44596863, 16.21652985], [73.44625092, 16.21652985], [73.44625092, 16.21763992], [73.44596863, 16.21763992], [73.44596863, 16.2179203], [73.44625092, 16.2179203], [73.44625092, 16.21903038], [73.44652557, 16.21902847], [73.44652557, 16.21986198], [73.44680786, 16.21986008], [73.44680786, 16.22153091], [73.44708252, 16.22152519], [73.44708252, 16.22319412], [73.44736481, 16.22319412], [73.44736481, 16.22458267], [73.44708252, 16.22458267], [73.44708252, 16.22430611], [73.4465332, 16.22430992], [73.4465332, 16.22374916], [73.44625092, 16.22374916], [73.44625092, 16.22291946], [73.44596863, 16.22291946], [73.44596863, 16.22236061], [73.44568634, 16.22236061], [73.44568634, 16.22125053], [73.44541931, 16.22125053], [73.44541931, 16.21986008], [73.44569397, 16.21986198], [73.44569397, 16.21958351], [73.44541931, 16.21958351], [73.44541931, 16.21902847], [73.44513702, 16.21903038], [73.44513702, 16.21846962], [73.44486237, 16.21847153], [73.44486237, 16.21791649], [73.44513702, 16.2179203], [73.44513702, 16.21763992], [73.44458008, 16.21763992], [73.44458008, 16.21681023], [73.44431305, 16.21681023], [73.44431305, 16.2159729], [73.44403076, 16.21597481], [73.44403076, 16.21569443], [73.44374847, 16.21569443], [73.44374847, 16.21513939], [73.44346619, 16.21515083], [73.44346619, 16.21153069], [73.44319153, 16.21153069], [73.44319153, 16.21096992], [73.44291687, 16.21097183], [73.44291687, 16.21069527], [73.44264221, 16.21069908], [73.44264221, 16.21042061], [73.44235992, 16.21042061], [73.44235992, 16.21013832], [73.4420929, 16.21013832], [73.4420929, 16.20985985], [73.44125366, 16.20986176], [73.44125366, 16.20958328], [73.44097137, 16.20958328], [73.44097137, 16.20930481], [73.44069672, 16.20930481], [73.44069672, 16.20902634], [73.44041443, 16.20902634], [73.44041443, 16.20874977], [73.44013977, 16.20874977], [73.44013977, 16.2084713], [73.43985748, 16.2084713], [73.43985748, 16.20819473], [73.43958282, 16.20819473], [73.43958282, 16.20763969], [73.43930817, 16.20763969], [73.43930817, 16.20708084], [73.43902588, 16.20708275], [73.43902588, 16.20652771], [73.43873596, 16.20652962], [73.43873596, 16.20625114], [73.43846893, 16.20625114], [73.43846893, 16.20596123], [73.43819427, 16.20597267], [73.43819427, 16.2056942], [73.43763733, 16.2056942], [73.43763733, 16.20541763], [73.43736267, 16.20541954], [73.43736267, 16.20514107], [73.43708038, 16.20514107], [73.43708038, 16.20458031], [73.43680573, 16.20458412], [73.43680573, 16.20375061], [73.43653107, 16.20375061], [73.43653107, 16.20318985], [73.43624878, 16.20319366], [73.43624878, 16.2029171], [73.43596649, 16.20292091], [73.43596649, 16.20264053], [73.43569946, 16.20264053], [73.43569946, 16.20236015], [73.43541718, 16.20236206], [73.43541718, 16.20208359], [73.43486023, 16.20208359], [73.43486023, 16.20180511], [73.43430328, 16.20181084], [73.43430328, 16.20153046], [73.43402863, 16.20153046], [73.43402863, 16.20125008], [73.43374634, 16.20125008], [73.43374634, 16.2009697], [73.43347168, 16.2009697], [73.43347168, 16.20069504], [73.4329071, 16.20070267], [73.4329071, 16.20014954], [73.43235779, 16.20014954], [73.43235779, 16.19986153], [73.43180847, 16.19986153], [73.43180847, 16.19958115], [73.43152618, 16.19958115], [73.43152618, 16.19930649], [73.43125153, 16.1993103], [73.43125153, 16.19903183], [73.43096924, 16.19903183], [73.43096924, 16.19875145], [73.43068695, 16.19875145], [73.43068695, 16.19903183], [73.42986298, 16.19903183], [73.42986298, 16.1993103], [73.42958069, 16.19930649], [73.42958069, 16.19958115], [73.42930603, 16.19958115], [73.42930603, 16.19986153], [73.42903137, 16.19986153], [73.42903137, 16.20014954], [73.42874908, 16.20014954], [73.42874908, 16.20042038], [73.4284668, 16.20042038], [73.4284668, 16.20070267], [73.42819214, 16.20069504], [73.42819214, 16.2009697], [73.42791748, 16.2009697], [73.42791748, 16.20153046], [73.42763519, 16.20152855], [73.42763519, 16.20208359], [73.42736053, 16.20207977], [73.42736053, 16.20264053], [73.42708588, 16.20263863], [73.42708588, 16.20319366], [73.42679596, 16.20318985], [73.42679596, 16.20430946], [73.42652893, 16.20430946], [73.42652893, 16.20652962], [73.42679596, 16.20652962], [73.42679596, 16.20736122], [73.42708588, 16.20736122], [73.42708588, 16.20792007], [73.42736053, 16.20791626], [73.42736053, 16.2084713], [73.42763519, 16.2084713], [73.42763519, 16.20930481], [73.42736053, 16.20930099], [73.42736053, 16.21013832], [73.42708588, 16.21013832], [73.42708588, 16.21069908], [73.42679596, 16.21069908], [73.42679596, 16.21235847], [73.42708588, 16.21235847], [73.42708588, 16.21292114], [73.42736053, 16.21292114], [73.42736053, 16.21403122], [73.42708588, 16.21403122], [73.42708588, 16.21486282], [73.42679596, 16.21486282], [73.42679596, 16.21541977], [73.42624664, 16.21541595], [73.42624664, 16.21569443], [73.42597198, 16.21569443], [73.42597198, 16.21597481], [73.42569733, 16.2159729], [73.42569733, 16.21624947], [73.42542267, 16.21624947], [73.42542267, 16.21652985], [73.42514038, 16.21652794], [73.42514038, 16.21708488], [73.42485809, 16.21708488], [73.42485809, 16.21736145], [73.42458344, 16.21736145], [73.42458344, 16.21986198], [73.42485809, 16.21986008], [73.42485809, 16.22402763], [73.42457581, 16.22402763], [73.42457581, 16.22514153], [73.42430878, 16.22514153], [73.42430878, 16.2262516], [73.42402649, 16.2262516], [73.42402649, 16.22736168], [73.42375183, 16.22736168], [73.42375183, 16.22847366], [73.42346954, 16.22847366], [73.42346954, 16.22958374], [73.42319489, 16.22958374], [73.42319489, 16.23069382], [73.42292023, 16.23069], [73.42292023, 16.23180962], [73.42263794, 16.23180962], [73.42263794, 16.23264122], [73.42236328, 16.23263931], [73.42236328, 16.23319435], [73.42208099, 16.23319054], [73.42208099, 16.23374939], [73.42180634, 16.23374939], [73.42180634, 16.23431015], [73.42152405, 16.23430634], [73.42152405, 16.23486137], [73.42124939, 16.23485947], [73.42124939, 16.23542023], [73.4209671, 16.23542023], [73.4209671, 16.2365303], [73.42070007, 16.2365303], [73.42070007, 16.23763847], [73.42041779, 16.23763847], [73.42041779, 16.24041939], [73.42014313, 16.24041939], [73.42014313, 16.24152946], [73.41986084, 16.24152946], [73.41986084, 16.24403], [73.41958618, 16.24402809], [73.41958618, 16.24430466], [73.41930389, 16.24430466], [73.41930389, 16.24458313], [73.41847229, 16.24458313], [73.41847229, 16.2448616], [73.41791534, 16.2448616], [73.41791534, 16.24513817], [73.4173584, 16.24513054], [73.4173584, 16.24542046], [73.41707611, 16.24542046], [73.41707611, 16.24570084], [73.41680908, 16.24570084], [73.41680908, 16.24681091], [73.41652679, 16.24681091], [73.41652679, 16.24736023], [73.41625214, 16.24736023], [73.41625214, 16.25041962], [73.41652679, 16.25041962], [73.41652679, 16.25126266], [73.41625214, 16.25124741], [73.41625214, 16.25208282], [73.41569519, 16.25208282], [73.41570282, 16.25375175], [73.4154129, 16.25375175], [73.4154129, 16.25458336], [73.41513824, 16.25457954], [73.41513824, 16.25653076], [73.41485596, 16.25653076], [73.41485596, 16.25764084], [73.4145813, 16.25763893], [73.4145813, 16.25819588], [73.41430664, 16.25819016], [73.41430664, 16.25875092], [73.41401672, 16.25875092], [73.41401672, 16.26013947], [73.41374969, 16.26013947], [73.41374969, 16.26097298], [73.41347504, 16.26097298], [73.41347504, 16.2634716], [73.41319275, 16.2634697], [73.41319275, 16.26542091], [73.41291809, 16.2654171], [73.41291809, 16.26597023], [73.4126358, 16.26596832], [73.4126358, 16.26680946], [73.41236115, 16.26680946], [73.41236115, 16.26736259], [73.41208649, 16.26736259], [73.41208649, 16.26902962], [73.41179657, 16.26902962], [73.41179657, 16.27042007], [73.41152954, 16.27042007], [73.41152954, 16.27153015], [73.41124725, 16.27152824], [73.41124725, 16.27347183], [73.4109726, 16.27346992], [73.4109726, 16.27486038], [73.41124725, 16.27486038], [73.41124725, 16.27514076], [73.41152954, 16.27514076], [73.41152954, 16.27543068], [73.41179657, 16.27543068], [73.41179657, 16.27625084], [73.41208649, 16.27625084], [73.41208649, 16.27708244], [73.41236115, 16.27708054], [73.41236115, 16.27791977], [73.4126358, 16.27791977], [73.4126358, 16.27820015], [73.41291809, 16.27819443], [73.41291809, 16.2784729], [73.41319275, 16.27846909], [73.41319275, 16.27875137], [73.41348267, 16.27875137], [73.41348267, 16.27931023], [73.41374969, 16.27931023], [73.41374969, 16.28014183], [73.41401672, 16.28014183], [73.41401672, 16.28070068], [73.41430664, 16.28070068], [73.41430664, 16.28264046], [73.41456604, 16.28264046], [73.41456604, 16.28292084], [73.41486359, 16.28291702], [73.41486359, 16.28319359], [73.41791534, 16.28319359], [73.41791534, 16.28291702], [73.41874695, 16.28291702], [73.41874695, 16.28319359], [73.41902924, 16.28319359], [73.41902924, 16.28347206], [73.41929626, 16.28347015], [73.41929626, 16.28375053], [73.42085266, 16.28375053], [73.42151642, 16.28375053], [73.42151642, 16.28403091], [73.42236328, 16.28403091], [73.42236328, 16.28375053], [73.42263794, 16.28375053], [73.42263794, 16.28347015], [73.42292023, 16.28347206], [73.42292023, 16.28319359], [73.42402649, 16.28319359], [73.42402649, 16.28291702], [73.42430878, 16.28291702], [73.42430878, 16.28319359], [73.42708588, 16.28319359], [73.42708588, 16.28347206], [73.42874908, 16.28347206], [73.42874908, 16.28319359], [73.42986298, 16.28319359], [73.42986298, 16.28347206], [73.43096924, 16.28347015], [73.43096924, 16.28375053], [73.43347168, 16.28375053], [73.43347168, 16.28403091], [73.43430328, 16.2840271], [73.43430328, 16.28458595], [73.4345932, 16.28458023], [73.4345932, 16.28514099], [73.43486023, 16.28514099], [73.43486023, 16.28541946], [73.43514252, 16.28541756], [73.43514252, 16.28569412], [73.43541718, 16.28569412], [73.43541718, 16.2859726], [73.43569946, 16.28597069], [73.43569946, 16.28652954], [73.43541718, 16.28652954], [73.43541718, 16.28680992], [73.43514252, 16.28680992], [73.43514252, 16.28652954], [73.4345932, 16.28652954], [73.4345932, 16.28625107], [73.43430328, 16.28625107], [73.43430328, 16.28597069], [73.43402863, 16.2859726], [73.43402863, 16.28569412], [73.43374634, 16.28569412], [73.43374634, 16.28541756], [73.43347168, 16.28541946], [73.43347168, 16.28514099], [73.43319702, 16.28514099], [73.43319702, 16.28486061], [73.4329071, 16.28486061], [73.4329071, 16.28458023], [73.43208313, 16.28458595], [73.43208313, 16.28430557], [73.43096924, 16.28430557], [73.43096924, 16.28458595], [73.42930603, 16.28458023], [73.42930603, 16.28486061], [73.4284668, 16.28486061], [73.4284668, 16.28458023], [73.42736053, 16.28458023], [73.42736053, 16.28486061], [73.42541504, 16.28486061], [73.42541504, 16.28458595], [73.42514038, 16.28458595], [73.42514038, 16.28430557], [73.42236328, 16.28430557], [73.42236328, 16.28458595], [73.42208099, 16.28458023], [73.42208099, 16.28486061], [73.42180634, 16.28486061], [73.42180634, 16.28514099], [73.42124939, 16.28514099], [73.42124939, 16.28541946], [73.42041779, 16.28541756], [73.42041779, 16.28569412], [73.42003632, 16.28569412], [73.41986084, 16.28569412], [73.41986084, 16.2859726], [73.41930389, 16.2859726], [73.41930389, 16.28569412], [73.41708374, 16.28569412], [73.41708374, 16.2859726], [73.41680908, 16.28597069], [73.41680908, 16.28625107], [73.41652679, 16.28625107], [73.41652679, 16.28652954], [73.41625214, 16.28652954], [73.41625214, 16.28680992], [73.41596985, 16.28680992], [73.41596985, 16.28737068], [73.41625214, 16.28737068], [73.41625214, 16.28763962], [73.41652679, 16.28763962], [73.41652679, 16.28792], [73.41791534, 16.28791618], [73.41791534, 16.28847313], [73.41819763, 16.28847313], [73.41819763, 16.28930473], [73.41791534, 16.28930473], [73.41791534, 16.28986168], [73.41764069, 16.28986168], [73.41764069, 16.29097176], [73.41791534, 16.29097176], [73.41791534, 16.29208374], [73.4173584, 16.29208374], [73.4173584, 16.29219055], [73.4173584, 16.2923584], [73.41680908, 16.2923584], [73.41680908, 16.29180908], [73.41652679, 16.29180908], [73.41652679, 16.29124832], [73.41625214, 16.29124832], [73.41625214, 16.29070091], [73.41596985, 16.29070091], [73.41596985, 16.28985977], [73.41569519, 16.28986168], [73.41569519, 16.28930473], [73.4154129, 16.28930473], [73.4154129, 16.28874969], [73.41513824, 16.28874969], [73.41513824, 16.28792], [73.41485596, 16.28792], [73.41485596, 16.28737068], [73.41430664, 16.28737068], [73.41430664, 16.28708076], [73.41374969, 16.28708267], [73.41374969, 16.2868042], [73.41348267, 16.28680992], [73.41348267, 16.28652954], [73.41291809, 16.28652954], [73.41291809, 16.28625107], [73.4126358, 16.28625107], [73.4126358, 16.28597069], [73.41236115, 16.2859726], [73.41236115, 16.28541756], [73.41179657, 16.28541946], [73.41179657, 16.28514099], [73.4109726, 16.28514099], [73.4109726, 16.28429985], [73.41069794, 16.28430557], [73.41069794, 16.28180504], [73.4109726, 16.28181076], [73.4109726, 16.28123856], [73.41124725, 16.28125191], [73.41124725, 16.28096962], [73.41152954, 16.28096962], [73.41152954, 16.28041649], [73.41179657, 16.2804203], [73.41179657, 16.28014183], [73.41208649, 16.28014183], [73.41208649, 16.27931023], [73.41179657, 16.27931023], [73.41179657, 16.27875137], [73.41152954, 16.27875137], [73.41152954, 16.27846909], [73.41124725, 16.2784729], [73.41124725, 16.27819443], [73.4109726, 16.27820015], [73.4109726, 16.27791977], [73.41042328, 16.27791977], [73.41042328, 16.27931023], [73.41014099, 16.27930641], [73.41014099, 16.27958107], [73.4098587, 16.27957916], [73.4098587, 16.28014183], [73.40957642, 16.28014183], [73.40957642, 16.28070068], [73.40930939, 16.28069496], [73.40930176, 16.28208351], [73.4090271, 16.2820797], [73.4090271, 16.28375053], [73.40875244, 16.28375053], [73.40876007, 16.28486061], [73.40847015, 16.28486061], [73.40847015, 16.28569412], [73.40820312, 16.28569031], [73.40820312, 16.28680992], [73.40791321, 16.28680992], [73.40791321, 16.28763962], [73.40763855, 16.28763962], [73.40763855, 16.28874969], [73.40736389, 16.28874969], [73.40736389, 16.28986168], [73.4070816, 16.28985977], [73.4070816, 16.29070091], [73.40680695, 16.29069519], [73.40680695, 16.29208374], [73.40651703, 16.29207993], [73.40651703, 16.29291916], [73.40625, 16.29291916], [73.40625, 16.29403114], [73.40598297, 16.29403114], [73.40598297, 16.29514122], [73.40569305, 16.29513931], [73.40569305, 16.29624939], [73.4054184, 16.29624939], [73.4054184, 16.29708481], [73.40513611, 16.29708481], [73.40513611, 16.29736137], [73.40486145, 16.29735947], [73.40486145, 16.29763985], [73.40458679, 16.29763985], [73.40458679, 16.29792023], [73.40429688, 16.29792023], [73.40429688, 16.2990303], [73.40402985, 16.2990303], [73.40402985, 16.29931068], [73.40374756, 16.29930687], [73.40374756, 16.29958344], [73.40180206, 16.29958344], [73.40180206, 16.29930687], [73.40125275, 16.29930687], [73.40125275, 16.29958344], [73.40041351, 16.29958344], [73.40041351, 16.29986191], [73.40013885, 16.29986], [73.40013885, 16.30042076], [73.3998642, 16.30041695], [73.39985657, 16.3006897], [73.39958191, 16.30069542], [73.39958191, 16.30097198], [73.39930725, 16.30097008], [73.39930725, 16.30153084], [73.39901733, 16.30153084], [73.39901733, 16.30402756], [73.39875031, 16.30402756], [73.39875031, 16.30514145], [73.39847565, 16.30514145], [73.39847565, 16.30569458], [73.39819336, 16.30569077], [73.39819336, 16.30820274], [73.3979187, 16.30820274], [73.3979187, 16.30875015], [73.39763641, 16.30875015], [73.39763641, 16.30903053], [73.39736176, 16.30903053], [73.39736176, 16.30931091], [73.3970871, 16.30930519], [73.3970871, 16.30958366], [73.39679718, 16.30957985], [73.39679718, 16.30986023], [73.39624786, 16.30986023], [73.39624786, 16.31014061], [73.39597321, 16.31014061], [73.39597321, 16.31042099], [73.39569092, 16.31041718], [73.39569092, 16.31069374], [73.39541626, 16.31069374], [73.39541626, 16.3120842], [73.3951416, 16.31208038], [73.3951416, 16.31264114], [73.39485931, 16.31263924], [73.39485931, 16.31319427], [73.39458466, 16.31319427], [73.39458466, 16.31347275], [73.39430237, 16.31347084], [73.39430237, 16.31431007], [73.39402771, 16.31430626], [73.39402771, 16.31458282], [73.39375305, 16.31458282], [73.39375305, 16.31736183], [73.39402771, 16.31735039], [73.39402771, 16.3176384], [73.39430237, 16.3176384], [73.39430237, 16.31792068], [73.39541626, 16.31792068], [73.39541626, 16.31819916], [73.39569092, 16.31819534], [73.39569092, 16.31847191], [73.39597321, 16.31846809], [73.39597321, 16.31986237], [73.39624786, 16.31986237], [73.39624786, 16.32208061], [73.39597321, 16.32208061], [73.39597321, 16.32291985], [73.39569092, 16.32291985], [73.39569092, 16.32374954], [73.39541626, 16.32374954], [73.39541626, 16.3243103], [73.3951416, 16.3243103], [73.3951416, 16.32514], [73.39485931, 16.32514], [73.39485931, 16.32542038], [73.39457703, 16.32542038], [73.39457703, 16.32625008], [73.39430237, 16.32625008], [73.39430237, 16.32681084], [73.39458466, 16.32680511], [73.39458466, 16.32847214], [73.39485931, 16.32847023], [73.39485931, 16.32903099], [73.3951416, 16.32903099], [73.3951416, 16.32930946], [73.39569092, 16.32930565], [73.39569092, 16.33097267], [73.39541626, 16.33097076], [73.39541626, 16.3318119], [73.3951416, 16.33180618], [73.3951416, 16.33208275], [73.39485931, 16.33208275], [73.39485931, 16.33235931], [73.39457703, 16.33234978], [73.39457703, 16.3326416], [73.39430237, 16.3326416], [73.39430237, 16.33234978], [73.39319611, 16.33234978], [73.39319611, 16.3326416], [73.39263916, 16.3326416], [73.39263916, 16.33292007], [73.3923645, 16.33291626], [73.3923645, 16.33319473], [73.39180756, 16.33319473], [73.39180756, 16.33346939], [73.39097595, 16.33346939], [73.39097595, 16.33375168], [73.39041901, 16.33375168], [73.39041901, 16.33403015], [73.39013672, 16.33402824], [73.39013672, 16.33430481], [73.38930511, 16.33430481], [73.38930511, 16.33458328], [73.38903046, 16.33458328], [73.38903046, 16.33486366], [73.38819122, 16.33486176], [73.38819122, 16.33514023], [73.38735962, 16.33514023], [73.38735962, 16.33542061], [73.38707733, 16.33542061], [73.38707733, 16.3357029], [73.38680267, 16.33569527], [73.38680267, 16.33597374], [73.38625336, 16.33597183], [73.38625336, 16.33625031], [73.38569641, 16.33625031], [73.38569641, 16.33653069], [73.38540649, 16.33653069], [73.38540649, 16.33736038], [73.38569641, 16.33736038], [73.38569641, 16.33764076], [73.38597107, 16.33763885], [73.38597107, 16.3381958], [73.38625336, 16.33819008], [73.38625336, 16.33848], [73.38652802, 16.33848], [73.38652802, 16.33875084], [73.38680267, 16.33875084], [73.38680267, 16.33903122], [73.38708496, 16.3390274], [73.38708496, 16.33958244], [73.38735962, 16.33958244], [73.38735962, 16.34236145], [73.38764954, 16.34235954], [73.38764954, 16.34320068], [73.38791656, 16.34320068], [73.38791656, 16.34403038], [73.38819122, 16.34403038], [73.38819122, 16.34458351], [73.38847351, 16.34458351], [73.38847351, 16.34486008], [73.38874817, 16.34485817], [73.38874817, 16.34542084], [73.38930511, 16.34541893], [73.38930511, 16.34569359], [73.38957977, 16.34569359], [73.38957977, 16.34597015], [73.38986206, 16.34596825], [73.38986206, 16.34624863], [73.39013672, 16.34624863], [73.39013672, 16.34653282], [73.39041901, 16.34653282], [73.39041901, 16.3476429], [73.39013672, 16.3476429], [73.39013672, 16.34791946], [73.38986206, 16.34791756], [73.38986206, 16.3484726], [73.38957977, 16.3484726], [73.38957977, 16.34875107], [73.38931274, 16.34875107], [73.38931274, 16.34902954], [73.38903046, 16.34902763], [73.38903046, 16.35069466], [73.38874817, 16.35069466], [73.38874817, 16.35208321], [73.38846588, 16.35207939], [73.38846588, 16.35292053], [73.38819122, 16.35292053], [73.38819122, 16.35403061], [73.38791656, 16.35403061], [73.38791656, 16.35486031], [73.38764191, 16.35486031], [73.38764191, 16.35597229], [73.38735962, 16.35597038], [73.38735962, 16.35736084], [73.38707733, 16.35736084], [73.38707733, 16.35791969], [73.38735962, 16.35791588], [73.38735962, 16.35853958], [73.38735962, 16.35874939], [73.38764191, 16.35874939], [73.38764191, 16.35985947], [73.38791656, 16.35985947], [73.38791656, 16.36042023], [73.38819122, 16.36041641], [73.38819122, 16.36069489], [73.38846588, 16.36068916], [73.38846588, 16.36125183], [73.38874817, 16.36125183], [73.38874817, 16.3615303], [73.38903046, 16.3615303], [73.38903046, 16.36181068], [73.38930511, 16.36180496], [73.38930511, 16.36208344], [73.38957977, 16.36208344], [73.38957977, 16.36180496], [73.38986206, 16.36181068], [73.38986206, 16.3615303], [73.39041901, 16.3615303], [73.39041901, 16.36042023], [73.39068604, 16.36042023], [73.39068604, 16.35957909], [73.39097595, 16.3595829], [73.39097595, 16.35930634], [73.39125061, 16.35931015], [73.39125061, 16.35874939], [73.3915329, 16.35874939], [73.39152527, 16.35819435], [73.39180756, 16.35819435], [73.39180756, 16.35791588], [73.39208221, 16.35791969], [73.39208221, 16.35708046], [73.3923645, 16.35708237], [73.3923645, 16.35652733], [73.39263916, 16.35652733], [73.39263916, 16.35625076], [73.39290619, 16.35625076], [73.39290619, 16.35597038], [73.39319611, 16.35597229], [73.39319611, 16.35581017], [73.39319611, 16.35569382], [73.39347076, 16.35569382], [73.39347076, 16.35541725], [73.39375305, 16.35542107], [73.39375305, 16.35514069], [73.39430237, 16.35514069], [73.39430237, 16.35486031], [73.39736176, 16.35486031], [73.39736176, 16.35514069], [73.3979187, 16.35514069], [73.3979187, 16.35542107], [73.39847565, 16.35541725], [73.39847565, 16.35569382], [73.39902496, 16.35569382], [73.39902496, 16.35597229], [73.39958191, 16.35597229], [73.39958191, 16.35625076], [73.40235901, 16.35625076], [73.40235901, 16.35597038], [73.40402985, 16.35597038], [73.40402985, 16.35625076], [73.40458679, 16.35625076], [73.40458679, 16.35652733], [73.40569305, 16.35652733], [73.40569305, 16.35708237], [73.40651703, 16.35708046], [73.40651703, 16.35736084], [73.40735626, 16.35736084], [73.40735626, 16.35764122], [73.40820312, 16.35764122], [73.40820312, 16.35791969], [73.40930176, 16.35791588], [73.40930176, 16.35805511], [73.40930939, 16.35819435], [73.41041565, 16.35819435], [73.41041565, 16.35847282], [73.41069794, 16.35847092], [73.41069794, 16.35874939], [73.4109726, 16.35874939], [73.4109726, 16.35903168], [73.41124725, 16.35902977], [73.41124725, 16.35921097], [73.41124725, 16.35930634], [73.41152954, 16.35930634], [73.41152954, 16.35985947], [73.41179657, 16.35985947], [73.41179657, 16.36042023], [73.41152954, 16.36041641], [73.41152954, 16.36069489], [73.41124725, 16.36069489], [73.41124725, 16.36208344], [73.41069794, 16.36208344], [73.41069794, 16.36180496], [73.41014099, 16.36181068], [73.41014099, 16.3615303], [73.4098587, 16.3615303], [73.4098587, 16.36125183], [73.40957642, 16.36125183], [73.40957642, 16.36096954], [73.40930176, 16.36096954], [73.40930176, 16.36069489], [73.40898132, 16.36069489], [73.40875244, 16.36069489], [73.40875244, 16.36041641], [73.40847015, 16.36042023], [73.40847015, 16.36014175], [73.40791321, 16.36014175], [73.40791321, 16.35903168], [73.40763855, 16.35903168], [73.40763855, 16.35819054], [73.40680695, 16.35819435], [73.40680695, 16.35791588], [73.40625, 16.35791588], [73.40625, 16.35819435], [73.40569305, 16.35819054], [73.40569305, 16.35903168], [73.40486145, 16.35903168], [73.40486145, 16.35931015], [73.4026413, 16.35930634], [73.4026413, 16.3595829], [73.39990997, 16.3595829], [73.39930725, 16.3595829], [73.39930725, 16.35985947], [73.39819336, 16.35985947], [73.39819336, 16.3595829], [73.39653015, 16.3595829], [73.39653015, 16.35930634], [73.39541626, 16.35931015], [73.39541626, 16.35903168], [73.3951416, 16.35903168], [73.3951416, 16.35931015], [73.39485931, 16.35931015], [73.39485931, 16.35903168], [73.39375305, 16.35903168], [73.39375305, 16.35874939], [73.39319611, 16.35874939], [73.39319611, 16.35903168], [73.39291382, 16.35902977], [73.39291382, 16.3595829], [73.39263916, 16.35957909], [73.39263916, 16.36014175], [73.39290619, 16.36014175], [73.39290619, 16.36042023], [73.39319611, 16.36041641], [73.39319611, 16.36069489], [73.39291382, 16.36069489], [73.39291382, 16.36208344], [73.39263916, 16.36208344], [73.39263916, 16.36236382], [73.39208221, 16.36236191], [73.39208221, 16.36375046], [73.39180756, 16.36375046], [73.39180756, 16.36486053], [73.3915329, 16.36486053], [73.3915329, 16.36541939], [73.39125061, 16.36541748], [73.39125061, 16.36569595], [73.38986206, 16.36569595], [73.38986206, 16.36541748], [73.38957977, 16.36541939], [73.38957977, 16.36486053], [73.38930511, 16.36486053], [73.38930511, 16.36458588], [73.38903046, 16.36458588], [73.38903046, 16.3643055], [73.38874817, 16.36431122], [73.38874817, 16.36403084], [73.38846588, 16.36403084], [73.38846588, 16.36375046], [73.38819122, 16.36375046], [73.38819122, 16.36347008], [73.38764191, 16.36347389], [73.38764191, 16.36319542], [73.38652802, 16.3631897], [73.38652802, 16.36069489], [73.38625336, 16.36069489], [73.38625336, 16.36041641], [73.38597107, 16.36042023], [73.38597107, 16.36014175], [73.38569641, 16.36014175], [73.38569641, 16.35985947], [73.38541412, 16.35985947], [73.38541412, 16.3595829], [73.38486481, 16.3595829], [73.38486481, 16.35930634], [73.38430786, 16.35931015], [73.38430786, 16.35903168], [73.38375092, 16.35903168], [73.38375092, 16.35874939], [73.38318634, 16.35874939], [73.38318634, 16.35903168], [73.38291931, 16.35902977], [73.38291931, 16.3595829], [73.38263702, 16.3595829], [73.38263702, 16.35985947], [73.38291931, 16.35985947], [73.38291931, 16.36014175], [73.38263702, 16.36014175], [73.38263702, 16.36069489], [73.38236237, 16.36069489], [73.38236237, 16.36096954], [73.38208008, 16.36096954], [73.38208008, 16.36125183], [73.38124847, 16.36125183], [73.38124847, 16.3615303], [73.37902832, 16.3615303], [73.37902832, 16.36181068], [73.37819672, 16.36180496], [73.37819672, 16.36208344], [73.37763977, 16.36208344], [73.37763977, 16.36236382], [73.37735748, 16.36236382], [73.37735748, 16.36208344], [73.37708282, 16.36208344], [73.37708282, 16.36180496], [73.37680817, 16.36181068], [73.37680817, 16.36125183], [73.37652588, 16.36125183], [73.37652588, 16.36096954], [73.37625122, 16.36096954], [73.37625122, 16.36069489], [73.37596893, 16.36069489], [73.37596893, 16.36041641], [73.37568665, 16.36042023], [73.37568665, 16.36014175], [73.37541962, 16.36014175], [73.37541962, 16.35985947], [73.37236023, 16.35985947], [73.37236023, 16.36042023], [73.37208557, 16.36041641], [73.37208557, 16.36069489], [73.37124634, 16.36069489], [73.37124634, 16.36096954], [73.37069702, 16.36096954], [73.37069702, 16.36125183], [73.3704071, 16.36125183], [73.3704071, 16.3615303], [73.37014008, 16.3615303], [73.37014008, 16.36181068], [73.36985779, 16.36180496], [73.36985779, 16.36208344], [73.36930847, 16.36208344], [73.36930847, 16.36236382], [73.36875153, 16.36236191], [73.36875153, 16.36264992], [73.36846924, 16.36264992], [73.36846924, 16.36292076], [73.36819458, 16.36291695], [73.36819458, 16.36347389], [73.36791992, 16.36347008], [73.36791992, 16.36486053], [73.36818695, 16.36486053], [73.36818695, 16.36541939], [73.36846924, 16.36541748], [73.36846924, 16.36597252], [73.36875153, 16.36597061], [73.36875153, 16.36680984], [73.36902618, 16.36680984], [73.36902618, 16.36736107], [73.36930847, 16.36736107], [73.36930847, 16.36763954], [73.36958313, 16.36763954], [73.36958313, 16.36819458], [73.36985779, 16.36819077], [73.36985779, 16.36874962], [73.37014008, 16.36874962], [73.37014008, 16.36930466], [73.37041473, 16.36930466], [73.37041473, 16.3698616], [73.37069702, 16.3698597], [73.37069702, 16.37042046], [73.37124634, 16.37041664], [73.37124634, 16.37097168], [73.37152863, 16.37096977], [73.37152863, 16.37124825], [73.37180328, 16.37124825], [73.37180328, 16.37181091], [73.37208557, 16.37180519], [73.37208557, 16.37347031], [73.37180328, 16.37347031], [73.37180328, 16.37403107], [73.37152863, 16.37403107], [73.37152863, 16.37458992], [73.37124634, 16.37458992], [73.37124634, 16.37514114], [73.37069702, 16.37514114], [73.37069702, 16.37541962], [73.3704071, 16.37541962], [73.3704071, 16.37514114], [73.36875153, 16.37514114], [73.36875153, 16.37541962], [73.36819458, 16.3754158], [73.36819458, 16.37569427], [73.36763763, 16.37569427], [73.36763763, 16.37597275], [73.36736298, 16.37597275], [73.36736298, 16.37625122], [73.36708069, 16.37625122], [73.36708069, 16.37681007], [73.36680603, 16.37680626], [73.36680603, 16.3773613], [73.36653137, 16.3773613], [73.36653137, 16.37930679], [73.36680603, 16.37930679], [73.36680603, 16.37958336], [73.36708069, 16.37958336], [73.36708069, 16.37986183], [73.36763763, 16.37985992], [73.36763763, 16.3801403], [73.36846924, 16.3801403], [73.36846924, 16.38042068], [73.36875153, 16.38041687], [73.36875153, 16.38069534], [73.36902618, 16.38068962], [73.36902618, 16.38292122], [73.36930847, 16.3829174], [73.36930847, 16.38458252], [73.36958313, 16.38458061], [73.36958313, 16.38514137], [73.36985779, 16.38514137], [73.36985779, 16.3856945], [73.37014008, 16.38569069], [73.37014008, 16.38792038], [73.37041473, 16.38791656], [73.37041473, 16.38847351], [73.37069702, 16.3884697], [73.37069702, 16.38903046], [73.37097168, 16.38903046], [73.37097168, 16.38959122], [73.37124634, 16.38959122], [73.37124634, 16.38986015], [73.37180328, 16.38986015], [73.37180328, 16.39014053], [73.37236023, 16.39014053], [73.37236023, 16.38986015], [73.37291718, 16.38986015], [73.37291718, 16.38959122], [73.37346649, 16.38959122], [73.37346649, 16.38931084], [73.37403107, 16.38931084], [73.37403107, 16.38875008], [73.37431335, 16.38875008], [73.37430573, 16.38791656], [73.37458038, 16.38792038], [73.37458038, 16.38707924], [73.37486267, 16.38708115], [73.37486267, 16.38625145], [73.37513733, 16.38625145], [73.37513733, 16.38514137], [73.37486267, 16.38514137], [73.37486267, 16.38458061], [73.37458038, 16.38458252], [73.37458038, 16.38402748], [73.37431335, 16.38402748], [73.37431335, 16.38181114], [73.37403107, 16.38181114], [73.37403107, 16.38153076], [73.37374878, 16.38153076], [73.37374878, 16.38097], [73.37347412, 16.38097191], [73.37347412, 16.38041687], [73.37319183, 16.38042068], [73.37319183, 16.37985992], [73.37291718, 16.37986183], [73.37291718, 16.37680626], [73.37319183, 16.37681007], [73.37319183, 16.37652969], [73.37346649, 16.37652969], [73.37346649, 16.37625122], [73.37374878, 16.37625122], [73.37374878, 16.37652969], [73.37431335, 16.37652969], [73.37431335, 16.37681007], [73.37458038, 16.37680626], [73.37458038, 16.3773613], [73.37486267, 16.37735939], [73.37486267, 16.37792015], [73.37513733, 16.37791634], [73.37513733, 16.37847137], [73.37541962, 16.37846947], [73.37541962, 16.37874985], [73.37568665, 16.37874985], [73.37568665, 16.37903023], [73.37625122, 16.37902832], [73.37625122, 16.37930679], [73.37735748, 16.37930679], [73.37735748, 16.37958336], [73.37763977, 16.37958336], [73.37763977, 16.37986183], [73.3779068, 16.37985992], [73.3779068, 16.38042068], [73.37819672, 16.38041687], [73.37819672, 16.38208389], [73.37845612, 16.38208008], [73.37845612, 16.38236046], [73.37874603, 16.38236046], [73.37874603, 16.38430977], [73.37902832, 16.38430977], [73.37902832, 16.38485909], [73.37930298, 16.38485909], [73.37930298, 16.38514137], [73.37902832, 16.38514137], [73.37902832, 16.38735962], [73.37930298, 16.38735962], [73.37930298, 16.38764191], [73.3795929, 16.38764191], [73.3795929, 16.38792038], [73.37985992, 16.38791656], [73.37985992, 16.38847351], [73.38041687, 16.3884697], [73.38041687, 16.38875008], [73.38096619, 16.38875008], [73.38096619, 16.38903046], [73.38152313, 16.38903046], [73.38152313, 16.38931084], [73.38181305, 16.38931084], [73.38181305, 16.38959122], [73.38208008, 16.38959122], [73.38208008, 16.38986015], [73.38263702, 16.38986015], [73.38263702, 16.39014053], [73.38318634, 16.39014053], [73.38318634, 16.39042091], [73.38430786, 16.3904171], [73.38430786, 16.39069366], [73.38458252, 16.39069366], [73.38458252, 16.39097214], [73.38486481, 16.39097214], [73.38486481, 16.39118958], [73.38485718, 16.39153099], [73.38513947, 16.39153099], [73.38513947, 16.39180946], [73.38541412, 16.39180565], [73.38541412, 16.39208412], [73.38569641, 16.39208412], [73.38569641, 16.39263916], [73.38597107, 16.39263916], [73.38597107, 16.3931942], [73.38625336, 16.3931942], [73.38625336, 16.39347267], [73.38652802, 16.39347076], [73.38652802, 16.39375114], [73.38680267, 16.39375114], [73.38680267, 16.39402962], [73.38735962, 16.39402962], [73.38735962, 16.39431], [73.38791656, 16.39430618], [73.38791656, 16.39458275], [73.38819122, 16.39458084], [73.38819122, 16.39486122], [73.38874817, 16.39486122], [73.38874817, 16.39513969], [73.39013672, 16.39513969], [73.39013672, 16.39486122], [73.39097595, 16.39486122], [73.39097595, 16.39458084], [73.39152527, 16.39458275], [73.39152527, 16.39430618], [73.39180756, 16.39431], [73.39180756, 16.39402962], [73.39208221, 16.39402962], [73.39208221, 16.39347076], [73.3923645, 16.39347267], [73.3923645, 16.39291573], [73.39263916, 16.39291954], [73.39263916, 16.39262962], [73.39291382, 16.39263916], [73.39291382, 16.39208412], [73.39319611, 16.39208412], [73.39319611, 16.39180565], [73.39346313, 16.39180946], [73.39346313, 16.39153099], [73.39375305, 16.39153099], [73.39375305, 16.39097023], [73.39402771, 16.39097214], [73.39402771, 16.39069366], [73.39430237, 16.39069366], [73.39430237, 16.3904171], [73.39485931, 16.39042091], [73.39485931, 16.39014053], [73.39541626, 16.39014053], [73.39541626, 16.38986015], [73.39597321, 16.38986015], [73.39597321, 16.38959122], [73.39653015, 16.38959122], [73.39653015, 16.38931084], [73.39819336, 16.38931084], [73.39819336, 16.38903046], [73.40013885, 16.38903046], [73.40013885, 16.38931084], [73.4006958, 16.38931084], [73.4006958, 16.38959122], [73.40125275, 16.38959122], [73.40125275, 16.38986015], [73.4015274, 16.38986015], [73.4015274, 16.39014053], [73.40180206, 16.39013863], [73.40180206, 16.39069366], [73.40208435, 16.39069366], [73.40208435, 16.39097214], [73.40235901, 16.39097023], [73.40235901, 16.39125061], [73.40262604, 16.39125061], [73.40262604, 16.39153099], [73.40291595, 16.39153099], [73.40291595, 16.39236069], [73.40319824, 16.39236069], [73.40319824, 16.39291954], [73.4034729, 16.39291573], [73.4034729, 16.3931942], [73.40374756, 16.3931942], [73.40374756, 16.39347267], [73.40402985, 16.39347076], [73.40402985, 16.39402962], [73.40429688, 16.39402962], [73.40429688, 16.39431], [73.40458679, 16.39431], [73.40458679, 16.39486122], [73.40486145, 16.39486122], [73.40486145, 16.39569473], [73.40513611, 16.39569473], [73.40513611, 16.39680481], [73.4054184, 16.39680481], [73.4054184, 16.39963913], [73.4054184, 16.40097046], [73.40513611, 16.40097046], [73.40513611, 16.40208054], [73.40486145, 16.40208054], [73.40486145, 16.40431023], [73.40513611, 16.40430641], [73.40513611, 16.40458488], [73.4054184, 16.40458488], [73.4054184, 16.40486145], [73.4034729, 16.40486145], [73.4034729, 16.40458488], [73.40319824, 16.40458488], [73.40319061, 16.40430641], [73.40291595, 16.40431023], [73.40291595, 16.40402985], [73.40262604, 16.40402985], [73.40262604, 16.40374947], [73.40235901, 16.40374947], [73.40235901, 16.4034729], [73.40180206, 16.40347481], [73.40180206, 16.40319443], [73.40125275, 16.40319443], [73.40125275, 16.40291595], [73.40097046, 16.40291977], [73.40097046, 16.40263939], [73.40040588, 16.40263939], [73.40040588, 16.40236282], [73.39985657, 16.40236282], [73.39985657, 16.40208054], [73.39958191, 16.40208054], [73.39958191, 16.40180588], [73.39930725, 16.40182114], [73.39930725, 16.40153122], [73.39848328, 16.40153122], [73.39848328, 16.40125275], [73.39736176, 16.40125275], [73.39736176, 16.40097046], [73.39653015, 16.40097046], [73.39653015, 16.40069389], [73.39541626, 16.40069389], [73.39541626, 16.40041733], [73.3951416, 16.40041733], [73.3951416, 16.40069389], [73.39430237, 16.40069389], [73.39430237, 16.40041733], [73.39291382, 16.40041733], [73.39291382, 16.40069389], [73.39069366, 16.40069389], [73.39069366, 16.40097046], [73.39041901, 16.40097046], [73.39041901, 16.40125275], [73.38986206, 16.40125275], [73.38986206, 16.40153122], [73.38931274, 16.40153122], [73.38931274, 16.40182114], [73.38874817, 16.40180588], [73.38874817, 16.40208054], [73.38819122, 16.40208054], [73.38819122, 16.40263939], [73.38791656, 16.40263939], [73.38791656, 16.40291977], [73.38735962, 16.40291595], [73.38735962, 16.40319443], [73.38708496, 16.40319443], [73.38708496, 16.40347481], [73.38625336, 16.40347481], [73.38625336, 16.40319443], [73.38597107, 16.40319443], [73.38597107, 16.40263939], [73.38569641, 16.40263939], [73.38569641, 16.40236282], [73.38540649, 16.40236282], [73.38540649, 16.40125275], [73.38513947, 16.40125275], [73.38513947, 16.40042114], [73.38485718, 16.40042114], [73.38485718, 16.40014267], [73.38459015, 16.40014267], [73.38459015, 16.39985847], [73.38430786, 16.39985847], [73.38430786, 16.39930916], [73.3840332, 16.39930916], [73.3840332, 16.39903069], [73.38375092, 16.39903069], [73.38375092, 16.39846992], [73.38346863, 16.39847183], [73.38346863, 16.39819527], [73.38291931, 16.39819908], [73.38291931, 16.39792061], [73.38263702, 16.39792061], [73.38263702, 16.39763832], [73.38208008, 16.39763832], [73.38208008, 16.39735985], [73.38153076, 16.39736176], [73.38153076, 16.39708328], [73.38124847, 16.39708328], [73.38124847, 16.39680481], [73.38097382, 16.39680481], [73.38097382, 16.39652634], [73.38069153, 16.39652824], [73.38069153, 16.39624977], [73.38014221, 16.39624977], [73.38014221, 16.39596939], [73.37985992, 16.3959713], [73.37985992, 16.39569473], [73.37864685, 16.39569473], [73.37763977, 16.39569473], [73.37763977, 16.3959713], [73.37708282, 16.39596939], [73.37708282, 16.39624977], [73.37680817, 16.39624977], [73.37680817, 16.39680481], [73.37652588, 16.39680481], [73.37652588, 16.39708328], [73.37569427, 16.39708328], [73.37569427, 16.39736176], [73.37541962, 16.39736176], [73.37541962, 16.39708328], [73.37486267, 16.39708328], [73.37486267, 16.39680481], [73.37458038, 16.39680481], [73.37458038, 16.39652634], [73.37431335, 16.39652824], [73.37431335, 16.39624977], [73.37374878, 16.39624977], [73.37374878, 16.39596939], [73.37291718, 16.3959713], [73.37291718, 16.39569473], [73.37264252, 16.39569473], [73.37264252, 16.3959713], [73.36985779, 16.3959713], [73.36985779, 16.39569473], [73.36930847, 16.39569473], [73.36930847, 16.3959713], [73.36875153, 16.3959713], [73.36875153, 16.39569473], [73.36846924, 16.39569473], [73.36846924, 16.3959713], [73.36818695, 16.39596939], [73.36818695, 16.39624977], [73.36763763, 16.39624977], [73.36763763, 16.39652824], [73.36736298, 16.39652634], [73.36736298, 16.39680481], [73.36680603, 16.39680481], [73.36680603, 16.39708328], [73.36597443, 16.39708328], [73.36597443, 16.39736176], [73.36569214, 16.39735985], [73.36569214, 16.39763832], [73.36541748, 16.39763832], [73.36541748, 16.39903069], [73.36569214, 16.39903069], [73.36569214, 16.39930916], [73.36597443, 16.39930534], [73.36597443, 16.39958382], [73.36624908, 16.39957809], [73.36624908, 16.39985847], [73.36651611, 16.39985847], [73.36651611, 16.40014267], [73.36680603, 16.40014267], [73.36680603, 16.40042114], [73.36708069, 16.40041733], [73.36708069, 16.40069389], [73.36736298, 16.40069008], [73.36736298, 16.40125275], [73.36708069, 16.40125275], [73.36708069, 16.40153122], [73.36680603, 16.40153122], [73.36680603, 16.40182114], [73.36624908, 16.40182114], [73.36624908, 16.40236282], [73.3659668, 16.40236282], [73.3659668, 16.40291977], [73.36569214, 16.40291977], [73.36569214, 16.40402985], [73.36541748, 16.40402985], [73.36541748, 16.4054203], [73.36513519, 16.40541649], [73.36513519, 16.40763855], [73.36541748, 16.40763092], [73.36541748, 16.40792084], [73.36569214, 16.40791512], [73.36569214, 16.40819359], [73.36597443, 16.40819359], [73.36597443, 16.40847206], [73.36624908, 16.40847015], [73.36624908, 16.40875053], [73.36680603, 16.40875053], [73.36680603, 16.40903091], [73.36708069, 16.40903091], [73.36708069, 16.40986061], [73.36680603, 16.40986061], [73.36680603, 16.41013908], [73.36651611, 16.41013908], [73.36651611, 16.41069984], [73.36624908, 16.41069984], [73.36624908, 16.41124916], [73.3659668, 16.41124916], [73.3659668, 16.41181183], [73.36569214, 16.41181183], [73.36569214, 16.41376114], [73.36541748, 16.4137516], [73.36541748, 16.4145813], [73.36514282, 16.41457939], [73.36514282, 16.41514015], [73.36486053, 16.41514015], [73.36486053, 16.41570282], [73.36458588, 16.41569519], [73.36458588, 16.41597366], [73.36429596, 16.41596985], [73.36429596, 16.41653061], [73.36402893, 16.4165287], [73.36402893, 16.41680527], [73.36374664, 16.41680527], [73.36374664, 16.41708374], [73.36319733, 16.41707993], [73.36319733, 16.41736031], [73.36292267, 16.41736031], [73.36292267, 16.41764069], [73.36264038, 16.41764069], [73.36264038, 16.41792107], [73.36235809, 16.41791725], [73.36235809, 16.41819572], [73.36207581, 16.41819], [73.36207581, 16.41903114], [73.36180878, 16.41903114], [73.36180878, 16.41986084], [73.36152649, 16.41986084], [73.36152649, 16.42041969], [73.36125183, 16.42041969], [73.36125183, 16.42124939], [73.36096954, 16.42124939], [73.36096954, 16.42319489], [73.36068726, 16.42319107], [73.36068726, 16.42374992], [73.36042023, 16.42374992], [73.36042023, 16.4240284], [73.35791779, 16.4240284], [73.35791779, 16.42569923], [73.35819244, 16.42569351], [73.35819244, 16.42708397], [73.3584671, 16.42708015], [73.3584671, 16.42736244], [73.35874939, 16.42736244], [73.35874939, 16.42764282], [73.35901642, 16.42764282], [73.35901642, 16.42791939], [73.35930634, 16.42791748], [73.35930634, 16.42819214], [73.35958099, 16.42819023], [73.35958099, 16.43013954], [73.35930634, 16.43013954], [73.35930634, 16.4323616], [73.35902405, 16.4323616], [73.35902405, 16.43347168], [73.35874939, 16.43346977], [73.35874939, 16.43514061], [73.35847473, 16.4351387], [73.35847473, 16.4370842], [73.35819244, 16.4370842], [73.35819244, 16.43819427], [73.35791779, 16.43819046], [73.35791779, 16.43874931], [73.35764313, 16.43874931], [73.35764313, 16.43931007], [73.35736084, 16.43930626], [73.35736084, 16.43985939], [73.35708618, 16.43985939], [73.35708618, 16.44042015], [73.35736084, 16.44042015], [73.35736084, 16.44125175], [73.35764313, 16.44125175], [73.35764313, 16.44153023], [73.3584671, 16.44153023], [73.3584671, 16.44125175], [73.35874939, 16.44125175], [73.35874939, 16.44096947], [73.36152649, 16.44096947], [73.36152649, 16.44069481], [73.36208344, 16.44069481], [73.36208344, 16.44041634], [73.36235809, 16.44042015], [73.36235809, 16.44014168], [73.36264038, 16.44014168], [73.36264038, 16.43985939], [73.36291504, 16.43985939], [73.36291504, 16.43958282], [73.36319733, 16.43958282], [73.36319733, 16.43930626], [73.36374664, 16.43931007], [73.36374664, 16.4390316], [73.36486053, 16.43902779], [73.36486053, 16.43958282], [73.36458588, 16.43958282], [73.36458588, 16.43985939], [73.36374664, 16.43985939], [73.36374664, 16.44014168], [73.36347961, 16.44014168], [73.36347961, 16.44042015], [73.36319733, 16.44041634], [73.36319733, 16.44096947], [73.36291504, 16.44096947], [73.36292267, 16.44125175], [73.36264038, 16.44125175], [73.36264038, 16.44180489], [73.36235809, 16.44180489], [73.36235809, 16.44208336], [73.36207581, 16.44207954], [73.36207581, 16.4426403], [73.36152649, 16.4426403], [73.36152649, 16.44292068], [73.36068726, 16.44292068], [73.36068726, 16.4426403], [73.36013794, 16.4426403], [73.36013794, 16.44236183], [73.35930634, 16.44236183], [73.35930634, 16.4426403], [73.35874939, 16.4426403], [73.35874939, 16.44292068], [73.35819244, 16.44292068], [73.35819244, 16.44320107], [73.3576355, 16.44319534], [73.3576355, 16.44347382], [73.35736084, 16.44347382], [73.35736084, 16.44375038], [73.35708618, 16.44374275], [73.35708618, 16.44403076], [73.35652924, 16.44402695], [73.35652924, 16.4445858], [73.35624695, 16.44458008], [73.35624695, 16.44514084], [73.35597229, 16.44513893], [73.35597229, 16.44569588], [73.35569763, 16.44569588], [73.35569763, 16.44597244], [73.35541534, 16.44597244], [73.35542297, 16.44625092], [73.35514069, 16.44625092], [73.35514069, 16.44652939], [73.35402679, 16.44652939], [73.35402679, 16.44625092], [73.35375214, 16.44625092], [73.35375214, 16.44486046], [73.35319519, 16.44486046], [73.35319519, 16.4445858], [73.3520813, 16.44458008], [73.3520813, 16.44486046], [73.35180664, 16.44486046], [73.35180664, 16.44514084], [73.35124969, 16.44514084], [73.35124969, 16.44542122], [73.35097504, 16.4454174], [73.35097504, 16.44569588], [73.35069275, 16.44569588], [73.35069275, 16.44597244], [73.35041809, 16.44597054], [73.35041809, 16.44652939], [73.3501358, 16.44652748], [73.3501358, 16.44708252], [73.34986115, 16.44708061], [73.34986115, 16.44763947], [73.34958649, 16.44763947], [73.34958649, 16.44791985], [73.34929657, 16.44791985], [73.34929657, 16.44874954], [73.34902954, 16.44874954], [73.34902954, 16.44958305], [73.34874725, 16.44958115], [73.34874725, 16.45013809], [73.34848022, 16.45013809], [73.34848022, 16.45042038], [73.34819794, 16.45042038], [73.34819794, 16.45070076], [73.34792328, 16.45070076], [73.34792328, 16.45153046], [73.34764099, 16.45153046], [73.34764099, 16.45293045], [73.3473587, 16.45293045], [73.3473587, 16.45375252], [73.34707642, 16.45375252], [73.34707642, 16.45430946], [73.3473587, 16.45430565], [73.3473587, 16.4556942], [73.34707642, 16.45568085], [73.34707642, 16.45792007], [73.34680939, 16.45791626], [73.34680176, 16.4584713], [73.3465271, 16.45846939], [73.3465271, 16.45903015], [73.34625244, 16.45902824], [73.34625244, 16.45958328], [73.34597015, 16.45957947], [73.34597015, 16.46042061], [73.3456955, 16.46041679], [73.3456955, 16.46097183], [73.34541321, 16.46097183], [73.34542084, 16.46125031], [73.34513855, 16.46125031], [73.34513855, 16.46181107], [73.34486389, 16.46180534], [73.34486389, 16.46208382], [73.3445816, 16.46208], [73.3445816, 16.46236038], [73.34430695, 16.46236038], [73.34430695, 16.46264076], [73.34402466, 16.46263885], [73.34402466, 16.46319389], [73.34375, 16.46319008], [73.34375, 16.46375084], [73.34347534, 16.46375084], [73.34347534, 16.46458244], [73.34319305, 16.46458054], [73.34319305, 16.46513748], [73.3429184, 16.46513748], [73.3429184, 16.46542168], [73.34263611, 16.46542168], [73.34263611, 16.46624947], [73.34236145, 16.46624947], [73.34236145, 16.46708107], [73.34208679, 16.46707916], [73.34208679, 16.46875191], [73.34179688, 16.46875191], [73.34179688, 16.47042084], [73.34152985, 16.47042084], [73.34152985, 16.47153091], [73.3418045, 16.4715271], [73.3418045, 16.47208595], [73.34208679, 16.47208023], [73.34208679, 16.47291946], [73.34236145, 16.47291756], [73.34236145, 16.47569466], [73.34208679, 16.47569084], [73.34208679, 16.47624969], [73.34179688, 16.47624969], [73.34179688, 16.47763824], [73.34152985, 16.47763824], [73.34152985, 16.47847176], [73.34124756, 16.47846985], [73.34124756, 16.47874832], [73.3409729, 16.47874832], [73.3409729, 16.47930908], [73.34069824, 16.47930527], [73.34069824, 16.47958374], [73.33930206, 16.47958374], [73.33930206, 16.4798584], [73.33875275, 16.4798584], [73.33875275, 16.47958374], [73.33791351, 16.47958374], [73.33791351, 16.4798584], [73.33735657, 16.47985077], [73.33735657, 16.48014259], [73.33708191, 16.48014259], [73.33708191, 16.48042107], [73.33652496, 16.48041725], [73.33652496, 16.48069382], [73.33625031, 16.48069382], [73.33625031, 16.48208427], [73.33597565, 16.48208427], [73.33597565, 16.48291588], [73.33569336, 16.48291588], [73.33569336, 16.48347473], [73.3354187, 16.48347282], [73.3354187, 16.48374939], [73.33513641, 16.48374939], [73.33513641, 16.48402977], [73.33486176, 16.48402977], [73.33486176, 16.48431015], [73.3345871, 16.48430634], [73.3345871, 16.48458481], [73.33430481, 16.48458481], [73.33430481, 16.48486137], [73.33403015, 16.48485947], [73.33403015, 16.48513985], [73.33374786, 16.48513985], [73.33374786, 16.48542023], [73.33347321, 16.48542023], [73.33347321, 16.48598099], [73.33319092, 16.48598099], [73.33319092, 16.4865303], [73.33291626, 16.4865284], [73.33291626, 16.48708344], [73.3326416, 16.48707962], [73.3326416, 16.48792076], [73.33235931, 16.48791695], [73.33235931, 16.4881897], [73.33208466, 16.48819542], [73.33208466, 16.48847198], [73.33180237, 16.48847008], [73.33180237, 16.48904037], [73.33152771, 16.48904037], [73.33152771, 16.49041748], [73.33125305, 16.49041748], [73.33125305, 16.49097252], [73.33152771, 16.49097252], [73.33152771, 16.4920826], [73.33125305, 16.4920826], [73.33125305, 16.49347115], [73.33097076, 16.49346924], [73.33097076, 16.49403191], [73.33013916, 16.49403191], [73.33013916, 16.49514008], [73.3298645, 16.49513817], [73.3298645, 16.49708366], [73.32958221, 16.49707985], [73.32958221, 16.49792099], [73.32930756, 16.49792099], [73.32930756, 16.50041962], [73.32902527, 16.5004158], [73.3290329, 16.50263977], [73.32875061, 16.50263977], [73.32875061, 16.50347137], [73.32847595, 16.50347137], [73.32847595, 16.50430489], [73.32818604, 16.50430107], [73.32818604, 16.50542068], [73.32791901, 16.50542068], [73.32791901, 16.50653076], [73.32763672, 16.50653076], [73.32763672, 16.50736237], [73.3273468, 16.50736237], [73.3273468, 16.50792122], [73.32707977, 16.5079174], [73.32707977, 16.50847054], [73.32681274, 16.50847054], [73.32681274, 16.50930977], [73.32653046, 16.50930977], [73.32653046, 16.51015091], [73.32624817, 16.51013947], [73.32624817, 16.5106945], [73.32596588, 16.51069069], [73.32596588, 16.51124954], [73.32569122, 16.51124954], [73.32569122, 16.51208305], [73.32541656, 16.51208115], [73.32541656, 16.51292038], [73.32514191, 16.51292038], [73.32514191, 16.51375008], [73.32485962, 16.51375008], [73.32485962, 16.51403046], [73.32457733, 16.51403046], [73.32457733, 16.51431084], [73.32430267, 16.51430511], [73.32430267, 16.51486206], [73.32402802, 16.51486015], [73.32402802, 16.51514053], [73.32375336, 16.51514053], [73.32375336, 16.51542091], [73.32347107, 16.51541519], [73.32347107, 16.51569366], [73.32319641, 16.51569366], [73.32319641, 16.51597214], [73.32290649, 16.51596069], [73.32290649, 16.51625061], [73.32263947, 16.51625061], [73.32263947, 16.51652908], [73.32096863, 16.51652908], [73.32096863, 16.51625061], [73.32013702, 16.51625061], [73.32013702, 16.51596069], [73.31986237, 16.51597214], [73.31986237, 16.51569366], [73.31903076, 16.51569366], [73.31903076, 16.51541519], [73.31874847, 16.51542091], [73.31874847, 16.51514053], [73.31817627, 16.51514053], [73.31817627, 16.51486015], [73.31791687, 16.51486206], [73.31791687, 16.51458359], [73.31764221, 16.51458359], [73.31764221, 16.51430511], [73.31735992, 16.51431084], [73.31735992, 16.51403046], [73.3170929, 16.51403046], [73.3170929, 16.51375008], [73.31680298, 16.51375008], [73.31680298, 16.5134697], [73.31624603, 16.5134697], [73.31624603, 16.51514053], [73.31652832, 16.51513863], [73.31652832, 16.51597214], [73.31680298, 16.51596069], [73.31680298, 16.51680946], [73.31708527, 16.51680565], [73.31708527, 16.51708412], [73.31735992, 16.51708031], [73.31735992, 16.51763916], [73.31764221, 16.51763916], [73.31764221, 16.51791763], [73.31791687, 16.51791573], [73.31791687, 16.51847267], [73.31817627, 16.51847076], [73.31817627, 16.51874924], [73.31846619, 16.51874924], [73.31846619, 16.51985931], [73.31817627, 16.51985931], [73.31817627, 16.5201416], [73.31791687, 16.5201416], [73.31791687, 16.52069473], [73.31764221, 16.52069092], [73.31764221, 16.52264023], [73.31735992, 16.52264023], [73.31735992, 16.52292061], [73.31708527, 16.52291679], [73.31708527, 16.52347374], [73.31680298, 16.52346992], [73.31680298, 16.52375031], [73.31652832, 16.52375031], [73.31652832, 16.52403069], [73.31624603, 16.52403069], [73.31624603, 16.52625084], [73.31597137, 16.52625084], [73.31597137, 16.52680969], [73.31569672, 16.52680969], [73.31569672, 16.52763939], [73.31597137, 16.52763939], [73.31597137, 16.52819443], [73.31625366, 16.52819443], [73.31625366, 16.5284729], [73.31652832, 16.52847099], [73.31652832, 16.52874947], [73.31680298, 16.52874947], [73.31680298, 16.52931023], [73.3170929, 16.52931023], [73.3170929, 16.53013992], [73.31735992, 16.53013992], [73.31735992, 16.53070068], [73.31708527, 16.53069496], [73.31708527, 16.53097153], [73.31680298, 16.53096008], [73.31680298, 16.53124809], [73.31625366, 16.53124809], [73.31625366, 16.53208351], [73.31597137, 16.53208351], [73.31597137, 16.53236008], [73.31569672, 16.53235817], [73.31569672, 16.53263855], [73.3154068, 16.53263855], [73.3154068, 16.53292084], [73.31485748, 16.53291702], [73.31485748, 16.53319359], [73.31458282, 16.53319359], [73.31458282, 16.53347015], [73.31402588, 16.53346825], [73.31402588, 16.53375244], [73.31375122, 16.53375244], [73.31375122, 16.53403282], [73.31346893, 16.53403282], [73.31346893, 16.53430939], [73.31319427, 16.53430557], [73.31319427, 16.53458405], [73.31291962, 16.53458023], [73.31291962, 16.53486252], [73.31263733, 16.53486252], [73.31263733, 16.5351429], [73.3123703, 16.5351429], [73.3123703, 16.5370903], [73.31208038, 16.5370903], [73.31208038, 16.53736115], [73.31181335, 16.53736115], [73.31181335, 16.53792], [73.31153107, 16.53791618], [73.31153107, 16.53819466], [73.31124878, 16.53819466], [73.31124878, 16.53791618], [73.31014252, 16.53792], [73.31014252, 16.53903008], [73.31041718, 16.53902817], [73.31041718, 16.53958321], [73.31124878, 16.53958321], [73.31124878, 16.53930473], [73.31180573, 16.53930473], [73.31180573, 16.53902817], [73.31263733, 16.53902817], [73.31263733, 16.53930473], [73.31236267, 16.53930473], [73.31236267, 16.53958321], [73.31208038, 16.53958321], [73.31208038, 16.53986168], [73.31180573, 16.53986168], [73.31180573, 16.54013824], [73.31124878, 16.54013062], [73.31124878, 16.54042053], [73.31097412, 16.54041672], [73.31097412, 16.54097176], [73.31069183, 16.54096985], [73.31069183, 16.54153061], [73.31097412, 16.5415287], [73.31097412, 16.54208374], [73.31124878, 16.54207993], [73.31124878, 16.54236031], [73.31208038, 16.54236031], [73.31208038, 16.54207993], [73.31236267, 16.54208374], [73.31236267, 16.54180527], [73.31263733, 16.54181099], [73.31263733, 16.54153061], [73.31291962, 16.54153061], [73.31291962, 16.54125023], [73.31318665, 16.54125023], [73.31318665, 16.54153061], [73.31430817, 16.5415287], [73.31430817, 16.54208374], [73.31458282, 16.54207993], [73.31458282, 16.54264069], [73.31430817, 16.54264069], [73.31430817, 16.54486084], [73.31458282, 16.54486084], [73.31458282, 16.54513931], [73.31485748, 16.54513931], [73.31485748, 16.5454216], [73.31513977, 16.54541588], [73.31513977, 16.54569435], [73.3154068, 16.54569054], [73.3154068, 16.54626274], [73.31569672, 16.54626274], [73.31569672, 16.54653168], [73.31597137, 16.54653168], [73.31597137, 16.54681015], [73.31625366, 16.54680634], [73.31625366, 16.5470829], [73.31652832, 16.5470829], [73.31652832, 16.54735947], [73.3170929, 16.54735947], [73.3170929, 16.54764175], [73.31735992, 16.54763794], [73.31735992, 16.54819489], [73.31764221, 16.54819489], [73.31764221, 16.54847336], [73.31791687, 16.54846954], [73.31791687, 16.5490303], [73.31817627, 16.5490303], [73.31817627, 16.54932022], [73.31847382, 16.54930305], [73.31847382, 16.54958344], [73.31874847, 16.54958344], [73.31874847, 16.54986382], [73.31903076, 16.54986191], [73.31903076, 16.55042076], [73.31930542, 16.55041695], [73.31931305, 16.55236053], [73.31903076, 16.55236053], [73.31903076, 16.55264091], [73.31874847, 16.55264091], [73.31874847, 16.55291939], [73.31847382, 16.55291748], [73.31847382, 16.55347252], [73.31817627, 16.55347061], [73.31817627, 16.55402946], [73.31791687, 16.55402946], [73.31791687, 16.55486107], [73.31764221, 16.55486107], [73.31764221, 16.55624962], [73.31817627, 16.55624962], [73.31817627, 16.55652809], [73.31874847, 16.55652618], [73.31874847, 16.55680466], [73.31930542, 16.55680466], [73.31930542, 16.55652618], [73.31986237, 16.55652809], [73.31986237, 16.55597115], [73.32013702, 16.55597305], [73.32013702, 16.55569458], [73.32041931, 16.55569458], [73.32041931, 16.55486107], [73.32068634, 16.55486107], [73.32068634, 16.55430984], [73.3215332, 16.55430984], [73.3215332, 16.55375099], [73.32180786, 16.55375099], [73.32180786, 16.55319023], [73.32152557, 16.55319595], [73.32152557, 16.55263901], [73.32125092, 16.55264091], [73.32125092, 16.55181122], [73.32208252, 16.5518055], [73.32208252, 16.55208588], [73.32263947, 16.55207062], [73.32263947, 16.55236053], [73.32290649, 16.55236053], [73.32290649, 16.55264091], [73.32319641, 16.55264091], [73.32319641, 16.55291939], [73.32430267, 16.55291748], [73.32430267, 16.55347252], [73.32457733, 16.55347061], [73.32457733, 16.55402946], [73.32485962, 16.55402756], [73.32485962, 16.5545826], [73.32514191, 16.5545826], [73.32514191, 16.55513954], [73.32541656, 16.55513], [73.32541656, 16.55541992], [73.32569122, 16.55541992], [73.32569122, 16.55624962], [73.32597351, 16.55624962], [73.32597351, 16.5573616], [73.32624817, 16.5573597], [73.32624817, 16.55792046], [73.32818604, 16.55792046], [73.32818604, 16.55763817], [73.32847595, 16.55763817], [73.32847595, 16.5573597], [73.32930756, 16.5573616], [73.32930756, 16.55708313], [73.32958221, 16.55708313], [73.32958221, 16.55680466], [73.33013916, 16.55680466], [73.33013916, 16.55652618], [73.33152771, 16.55652618], [73.33152771, 16.55680466], [73.33208466, 16.55680466], [73.33208466, 16.55708313], [73.33235931, 16.55708313], [73.33235931, 16.5573616], [73.3326416, 16.5573597], [73.3326416, 16.55763817], [73.33291626, 16.55763817], [73.33291626, 16.55792046], [73.33319092, 16.55792046], [73.33319092, 16.55903053], [73.33291626, 16.55903053], [73.33291626, 16.55958366], [73.33235931, 16.55957985], [73.33235931, 16.55985832], [73.33207703, 16.55985832], [73.33207703, 16.5601387], [73.33180237, 16.5601387], [73.33180237, 16.5604229], [73.33152771, 16.56041718], [73.33152771, 16.56097031], [73.33125305, 16.56097031], [73.33125305, 16.56180954], [73.33152771, 16.56180573], [73.33152771, 16.5620842], [73.33180237, 16.56208038], [73.33180237, 16.56236267], [73.33207703, 16.56236267], [73.33207703, 16.56208038], [73.33291626, 16.56208038], [73.33291626, 16.56236267], [73.33347321, 16.56236267], [73.33347321, 16.56208038], [73.33403015, 16.5620842], [73.33403015, 16.56180573], [73.33429718, 16.56180954], [73.33429718, 16.56153107], [73.33486176, 16.56153107], [73.33486176, 16.56126022], [73.33513641, 16.56126022], [73.33513641, 16.56097031], [73.3354187, 16.56097031], [73.3354187, 16.5601387], [73.33569336, 16.5601387], [73.33569336, 16.55846977], [73.33597565, 16.55847168], [73.33597565, 16.55791664], [73.33625031, 16.55792046], [73.33625031, 16.5573597], [73.33680725, 16.5573616], [73.33680725, 16.55708313], [73.33708191, 16.55708313], [73.33708191, 16.55680466], [73.3373642, 16.55680466], [73.3373642, 16.55652618], [73.33790588, 16.55652809], [73.33790588, 16.55569077], [73.3381958, 16.55569458], [73.3381958, 16.55486107], [73.33847046, 16.55486107], [73.33847046, 16.55458069], [73.33875275, 16.5545826], [73.33875275, 16.55430794], [73.3390274, 16.55430984], [73.3390274, 16.55401039], [73.3390274, 16.55347252], [73.33930206, 16.55347252], [73.33930206, 16.55319595], [73.33958435, 16.55319595], [73.33958435, 16.55236053], [73.33985901, 16.55236053], [73.33985901, 16.55181122], [73.3401413, 16.55181122], [73.3401413, 16.55153084], [73.34041595, 16.55153084], [73.34041595, 16.5506897], [73.34069061, 16.5506916], [73.34069061, 16.5490284], [73.34041595, 16.5490303], [73.34041595, 16.54846954], [73.3401413, 16.54847336], [73.3401413, 16.54735947], [73.34041595, 16.54735947], [73.34041595, 16.5470829], [73.34069061, 16.5470829], [73.34069824, 16.54680634], [73.34124756, 16.54681015], [73.34124756, 16.54653168], [73.34152985, 16.54653168], [73.34152985, 16.54626274], [73.34179688, 16.54626274], [73.34179688, 16.54597092], [73.34236145, 16.54597282], [73.34236145, 16.54569435], [73.34263611, 16.54569435], [73.34263611, 16.54513741], [73.3429184, 16.54513931], [73.3429184, 16.54486084], [73.34319305, 16.54486084], [73.34319305, 16.54458046], [73.34375, 16.54458237], [73.34375, 16.5443058], [73.34401703, 16.54430962], [73.34401703, 16.54403114], [73.34430695, 16.54403114], [73.34430695, 16.54375076], [73.3445816, 16.54375076], [73.3445816, 16.54319], [73.34486389, 16.54319382], [73.34486389, 16.54291725], [73.34513855, 16.54292107], [73.34513855, 16.54264069], [73.34542084, 16.54264069], [73.34542084, 16.54153061], [73.34570313, 16.54153061], [73.34570313, 16.53985977], [73.34597015, 16.53986168], [73.34597015, 16.5340271], [73.34625244, 16.53403282], [73.34625244, 16.53181076], [73.3465271, 16.53181076], [73.3465271, 16.53070068], [73.34680176, 16.53070068], [73.34680176, 16.52985954], [73.34708405, 16.52986145], [73.34708405, 16.52958298], [73.3473587, 16.52958298], [73.3473587, 16.52930641], [73.34764099, 16.52931023], [73.34764099, 16.52902985], [73.34819794, 16.52902985], [73.34819794, 16.52874947], [73.34848022, 16.52874947], [73.3484726, 16.5284729], [73.34874725, 16.5284729], [73.34874725, 16.52819443], [73.34902954, 16.52819443], [73.34902954, 16.52791786], [73.34929657, 16.52791977], [73.34929657, 16.52736092], [73.34958649, 16.52736092], [73.34958649, 16.52708054], [73.34986115, 16.52708244], [73.34986115, 16.52680588], [73.3501358, 16.52680969], [73.3501358, 16.52653122], [73.35069275, 16.52653122], [73.35069275, 16.52597046], [73.35124969, 16.52597237], [73.35124969, 16.52513885], [73.35151672, 16.5251503], [73.35151672, 16.52486038], [73.35180664, 16.52486038], [73.35180664, 16.52458], [73.3520813, 16.52458572], [73.3520813, 16.52402687], [73.35235596, 16.52403069], [73.35235596, 16.52346992], [73.3529129, 16.52347374], [73.3529129, 16.52291679], [73.35346985, 16.52292061], [73.35346985, 16.52264023], [73.35375214, 16.52264023], [73.35375214, 16.52236176], [73.35430908, 16.52236176], [73.35430908, 16.52264023], [73.3548584, 16.52264023], [73.3548584, 16.52236176], [73.35652924, 16.52236366], [73.35652924, 16.52208138], [73.35679626, 16.52209282], [73.35679626, 16.5218029], [73.35736084, 16.52180481], [73.35736084, 16.52152824], [73.35764313, 16.52153015], [73.35764313, 16.52096939], [73.35819244, 16.52096939], [73.35819244, 16.52069473], [73.35874939, 16.52069473], [73.35874939, 16.52041626], [73.35930634, 16.52042007], [73.35930634, 16.5201416], [73.35958099, 16.5201416], [73.35958099, 16.51958084], [73.35986328, 16.51958275], [73.35986328, 16.51930618], [73.36042023, 16.5193119], [73.36042023, 16.51901817], [73.36096954, 16.51902771], [73.36096954, 16.51874924], [73.36152649, 16.51874924], [73.36152649, 16.51847076], [73.36208344, 16.51847267], [73.36208344, 16.5181942], [73.36235809, 16.5181942], [73.36235809, 16.51791573], [73.36264038, 16.51791763], [73.36264038, 16.51763916], [73.36292267, 16.51763916], [73.36292267, 16.51736069], [73.36319733, 16.51736069], [73.36319733, 16.51652908], [73.36347961, 16.51652908], [73.36347961, 16.51596069], [73.36402893, 16.51597214], [73.36402893, 16.51319695], [73.36374664, 16.5132103], [73.36374664, 16.51264], [73.36347961, 16.51264], [73.36347961, 16.5118103], [73.36292267, 16.5118103], [73.36292267, 16.51152992], [73.36264038, 16.51152992], [73.36264038, 16.51124954], [73.36152649, 16.51124954], [73.36152649, 16.51097107], [73.36042023, 16.51097488], [73.36042023, 16.5106945], [73.35902405, 16.5106945], [73.35902405, 16.51041603], [73.35819244, 16.51041985], [73.35819244, 16.51015091], [73.35791779, 16.51015091], [73.35791779, 16.5098629], [73.35736084, 16.5098629], [73.35736084, 16.50958061], [73.35652924, 16.50958061], [73.35652924, 16.50902748], [73.35542297, 16.50902939], [73.35542297, 16.50875282], [73.35430908, 16.50875282], [73.35430908, 16.50847054], [73.35319519, 16.50847054], [73.35319519, 16.5079174], [73.35180664, 16.50792122], [73.35180664, 16.50764275], [73.35124969, 16.50764275], [73.35124969, 16.50736237], [73.35069275, 16.50736237], [73.35069275, 16.50708008], [73.3501358, 16.50708389], [73.3501358, 16.50680542], [73.34986115, 16.50681114], [73.34986115, 16.50653076], [73.34929657, 16.50653076], [73.34929657, 16.50624847], [73.34902954, 16.50624847], [73.34902954, 16.50430107], [73.34986115, 16.50430489], [73.34986115, 16.50486183], [73.3501358, 16.50485992], [73.3501358, 16.50569916], [73.35041809, 16.50569534], [73.35041809, 16.50597191], [73.35069275, 16.50596809], [73.35069275, 16.50624847], [73.35124969, 16.50624847], [73.35124969, 16.50653076], [73.35180664, 16.50653076], [73.35180664, 16.50681114], [73.35236359, 16.50680542], [73.35236359, 16.50708389], [73.35402679, 16.50708008], [73.35402679, 16.50736237], [73.35457611, 16.50736237], [73.35457611, 16.50708008], [73.35514069, 16.50708008], [73.35514069, 16.50736237], [73.35597229, 16.50736237], [73.35597229, 16.50764275], [73.35708618, 16.50764275], [73.35708618, 16.50792122], [73.35736084, 16.5079174], [73.35736084, 16.50819206], [73.35791779, 16.50819206], [73.35791779, 16.50847054], [73.35874939, 16.50847054], [73.35874939, 16.50902939], [73.35958099, 16.50902939], [73.35958099, 16.50930977], [73.36013794, 16.50930595], [73.36013794, 16.50958061], [73.360466, 16.50958061], [73.36068726, 16.50958061], [73.36068726, 16.5098629], [73.36207581, 16.5098629], [73.36207581, 16.51015091], [73.36429596, 16.51015091], [73.36429596, 16.51041985], [73.36513519, 16.51041603], [73.36513519, 16.5106945], [73.36541748, 16.5106945], [73.36541748, 16.51097488], [73.36569214, 16.51097107], [73.36569214, 16.51124954], [73.36597443, 16.51124954], [73.36597443, 16.51217079], [73.36597443, 16.51236153], [73.36651611, 16.51235962], [73.36651611, 16.51292038], [73.36680603, 16.51292038], [73.36680603, 16.5132103], [73.36736298, 16.5132103], [73.36736298, 16.51292038], [73.36791992, 16.51292038], [73.36791992, 16.51264], [73.36846924, 16.51264], [73.36846924, 16.51208115], [73.36875153, 16.51208305], [73.36875153, 16.51176071], [73.36875153, 16.51152802], [73.36902618, 16.51152992], [73.36902618, 16.51097107], [73.37014008, 16.51097107], [73.37014008, 16.51124954], [73.37291718, 16.51124954], [73.37291718, 16.51152992], [73.37374878, 16.51152802], [73.37374878, 16.51180458], [73.37430573, 16.51180458], [73.37430573, 16.51152802], [73.37541962, 16.51152992], [73.37541962, 16.51124954], [73.37568665, 16.51124954], [73.37568665, 16.51152992], [73.37652588, 16.51152802], [73.37652588, 16.51180077], [73.37875366, 16.51180649], [73.37875366, 16.51208305], [73.37930298, 16.51208305], [73.37930298, 16.51180649], [73.37985992, 16.51180649], [73.37985992, 16.51208305], [73.38153076, 16.51208305], [73.38153076, 16.51236153], [73.38180542, 16.51236153], [73.38180542, 16.51208305], [73.38208008, 16.51208305], [73.38208008, 16.51180649], [73.38318634, 16.51180077], [73.38319397, 16.51152802], [73.38346863, 16.51152992], [73.38346863, 16.51124954], [73.38375092, 16.51124954], [73.38375092, 16.51097107], [73.38430786, 16.51097488], [73.38430786, 16.5106945], [73.38458252, 16.5106945], [73.38458252, 16.51041603], [73.38513947, 16.51041985], [73.38513947, 16.51015091], [73.38597107, 16.51015091], [73.38597107, 16.5098629], [73.38680267, 16.5098629], [73.38680267, 16.51015091], [73.38819122, 16.51015091], [73.38819122, 16.5098629], [73.39013672, 16.5098629], [73.39013672, 16.51399231], [73.39013672, 16.51431084], [73.38931274, 16.51431084], [73.38931274, 16.51403046], [73.38903046, 16.51403046], [73.38903046, 16.5134697], [73.38874817, 16.5134716], [73.38874817, 16.51319695], [73.38764191, 16.51319695], [73.38764191, 16.5134716], [73.38680267, 16.5134697], [73.38680267, 16.51375008], [73.38540649, 16.51375008], [73.38540649, 16.51403046], [73.38485718, 16.51403046], [73.38485718, 16.51431084], [73.38430786, 16.51430511], [73.38430023, 16.515131], [73.38402557, 16.51513863], [73.3840332, 16.51529121], [73.3840332, 16.51542091], [73.38375092, 16.51541519], [73.38375092, 16.51569366], [73.38346863, 16.51569366], [73.38346863, 16.51597214], [73.38318634, 16.51596069], [73.38318634, 16.51625061], [73.38291931, 16.51625061], [73.38291931, 16.51680946], [73.38208008, 16.51680565], [73.38208008, 16.51708412], [73.38091278, 16.51708412], [73.38041687, 16.51708412], [73.38041687, 16.51680565], [73.37985992, 16.51680946], [73.37985992, 16.51652908], [73.37874603, 16.51652908], [73.37874603, 16.51680946], [73.37845612, 16.51680946], [73.37845612, 16.51652908], [73.37680817, 16.51652908], [73.37680817, 16.51680946], [73.37652588, 16.51680565], [73.37652588, 16.51708412], [73.37568665, 16.51708031], [73.37568665, 16.51736069], [73.37541962, 16.51736069], [73.37541962, 16.51763916], [73.37513733, 16.51763916], [73.37513733, 16.51791763], [73.37486267, 16.51791763], [73.37486267, 16.5181942], [73.37458038, 16.5181942], [73.37458038, 16.51847267], [73.37431335, 16.51847076], [73.37431335, 16.51874924], [73.37374878, 16.51874924], [73.37374878, 16.51902771], [73.37319183, 16.51901817], [73.37319183, 16.5193119], [73.37264252, 16.51930618], [73.37264252, 16.51958275], [73.37236023, 16.51958084], [73.37236023, 16.51985931], [73.37152863, 16.51985931], [73.37152863, 16.5201416], [73.37069702, 16.5201416], [73.37069702, 16.52042007], [73.37041473, 16.52041626], [73.37041473, 16.52069473], [73.36985779, 16.52069473], [73.36985779, 16.52096939], [73.36958313, 16.52096939], [73.36958313, 16.52153015], [73.36902618, 16.52152824], [73.36902618, 16.52180481], [73.36818695, 16.5218029], [73.36818695, 16.52209282], [73.36763763, 16.52208138], [73.36763763, 16.52236366], [73.36708069, 16.52236176], [73.36708069, 16.52264023], [73.36651611, 16.52264023], [73.36651611, 16.52292061], [73.36624908, 16.52292061], [73.36624908, 16.5232029], [73.36541748, 16.52319527], [73.36541748, 16.52347374], [73.36486053, 16.52346992], [73.36486053, 16.52375031], [73.36374664, 16.52375031], [73.36374664, 16.52403069], [73.36347961, 16.52403069], [73.36347961, 16.52431107], [73.36291504, 16.52430534], [73.36291504, 16.52458572], [73.36264038, 16.52458], [73.36264038, 16.5251503], [73.36180878, 16.5251503], [73.36180878, 16.52542114], [73.36125183, 16.52541733], [73.36125183, 16.5256958], [73.36061859, 16.5256958], [73.35958099, 16.5256958], [73.35958099, 16.52597237], [73.35901642, 16.52597046], [73.35901642, 16.52625084], [73.35791779, 16.52625084], [73.35791779, 16.52680969], [73.3576355, 16.52680588], [73.35764313, 16.52736092], [73.35736084, 16.52736092], [73.35736084, 16.52874947], [73.35597229, 16.52874947], [73.35597229, 16.52902985], [73.35569763, 16.52902794], [73.35569763, 16.52958298], [73.35542297, 16.52958107], [73.35542297, 16.53013992], [73.35514069, 16.53013611], [73.35514069, 16.53097153], [73.3548584, 16.53097153], [73.3548584, 16.53208351], [73.35514069, 16.5320797], [73.35514069, 16.53263855], [73.35542297, 16.53263855], [73.35542297, 16.53292084], [73.35569763, 16.53291702], [73.35569763, 16.53347015], [73.35542297, 16.53346825], [73.35542297, 16.53403282], [73.35514069, 16.53403282], [73.35514069, 16.53486252], [73.3548584, 16.53486252], [73.3548584, 16.53541946], [73.35458374, 16.53541756], [73.35458374, 16.5359726], [73.35430908, 16.5359726], [73.35430908, 16.53763962], [73.35402679, 16.53763962], [73.35402679, 16.53903008], [73.35430908, 16.53902817], [73.35430908, 16.53930473], [73.3548584, 16.53930473], [73.3548584, 16.53958321], [73.35541534, 16.53958321], [73.35541534, 16.5397625], [73.35541534, 16.53986168], [73.35708618, 16.53986168], [73.35708618, 16.53958321], [73.35791779, 16.53958321], [73.35791779, 16.53930473], [73.35819244, 16.53930473], [73.35819244, 16.53902817], [73.3584671, 16.53903008], [73.3584671, 16.53874969], [73.35930634, 16.53874969], [73.35930634, 16.53903008], [73.35958099, 16.53902817], [73.35958099, 16.53930473], [73.35986328, 16.53930473], [73.35986328, 16.53958321], [73.36042023, 16.53958321], [73.36042023, 16.53986168], [73.36152649, 16.53986168], [73.36152649, 16.53958321], [73.36208344, 16.53958321], [73.36208344, 16.53986168], [73.36235809, 16.53986168], [73.36235809, 16.53958321], [73.36624908, 16.53958321], [73.36624908, 16.54097176], [73.3659668, 16.54096985], [73.3659668, 16.54125023], [73.36569214, 16.54125023], [73.36569214, 16.54153061], [73.36624908, 16.54153061], [73.36624908, 16.54181099], [73.36653137, 16.54180527], [73.36653137, 16.54208374], [73.36680603, 16.54207993], [73.36680603, 16.54236031], [73.36736298, 16.54236031], [73.36736298, 16.54264069], [73.36846924, 16.54264069], [73.36846924, 16.54236031], [73.36875153, 16.54236031], [73.36875153, 16.54207993], [73.36902618, 16.54208374], [73.36902618, 16.54180527], [73.36930847, 16.54181099], [73.36930847, 16.54153061], [73.36958313, 16.54153061], [73.36958313, 16.54125023], [73.36985779, 16.54125023], [73.36985779, 16.54096985], [73.37041473, 16.54097176], [73.37041473, 16.54069519], [73.37069702, 16.54070091], [73.37069702, 16.54042053], [73.37097168, 16.54042053], [73.37097168, 16.53985977], [73.37124634, 16.53986168], [73.37124634, 16.53958321], [73.37152863, 16.53958321], [73.37152863, 16.53930473], [73.37208557, 16.53930473], [73.37208557, 16.53902817], [73.37236023, 16.53903008], [73.37236023, 16.53874969], [73.37264252, 16.53874969], [73.37264252, 16.53930473], [73.37291718, 16.53930473], [73.37291718, 16.53986168], [73.37265015, 16.53985977], [73.37265015, 16.54042053], [73.37180328, 16.54042053], [73.37180328, 16.54070091], [73.37124634, 16.54069519], [73.37124634, 16.54097176], [73.37097168, 16.54096985], [73.37097168, 16.54125023], [73.37069702, 16.54125023], [73.37069702, 16.54181099], [73.37041473, 16.54180527], [73.37041473, 16.54208374], [73.36985779, 16.54207993], [73.36985779, 16.54236031], [73.36958313, 16.54236031], [73.36958313, 16.54264069], [73.36930847, 16.54264069], [73.36930847, 16.54292107], [73.36902618, 16.54291725], [73.36902618, 16.54319382], [73.36875153, 16.54319382], [73.36875153, 16.54347229], [73.36846924, 16.54347038], [73.36846924, 16.54375076], [73.36818695, 16.54375076], [73.36818695, 16.54403114], [73.36791992, 16.54402733], [73.36791992, 16.54475021], [73.36791992, 16.54486084], [73.36708069, 16.54486084], [73.36708069, 16.54472923], [73.36708069, 16.54458427], [73.36680603, 16.54458427], [73.36680603, 16.54402733], [73.36651611, 16.54403114], [73.36651611, 16.54375076], [73.3659668, 16.54375076], [73.3659668, 16.54347038], [73.36541748, 16.54347229], [73.36541748, 16.54319382], [73.36513519, 16.54319382], [73.36513519, 16.54291725], [73.36486053, 16.54292107], [73.36486053, 16.54264069], [73.36429596, 16.54264069], [73.36429596, 16.54236031], [73.36367035, 16.54236031], [73.36319733, 16.54236031], [73.36319733, 16.54207993], [73.36291504, 16.54208374], [73.36292267, 16.54236031], [73.36235809, 16.54236031], [73.36235809, 16.54264069], [73.36152649, 16.54264069], [73.36152649, 16.54236031], [73.36068726, 16.54236031], [73.36068726, 16.54264069], [73.35958099, 16.54264069], [73.35958099, 16.54125023], [73.35930634, 16.54125023], [73.35930634, 16.54096985], [73.35902405, 16.54097176], [73.35902405, 16.54069519], [73.35847473, 16.54069519], [73.35847473, 16.54097176], [73.3576355, 16.54097176], [73.35764313, 16.54125023], [73.35708618, 16.54125023], [73.35708618, 16.54153061], [73.35652924, 16.54153061], [73.35652924, 16.54181099], [73.35514069, 16.54181099], [73.35514069, 16.54153061], [73.3548584, 16.54153061], [73.3548584, 16.54181099], [73.35473633, 16.54180527], [73.35458374, 16.54180527], [73.35458374, 16.54208374], [73.35402679, 16.54207993], [73.35402679, 16.54236031], [73.35375214, 16.54236031], [73.35375214, 16.54347229], [73.35346985, 16.54347038], [73.35346985, 16.54375076], [73.35263824, 16.54375076], [73.35263824, 16.54347038], [73.3520813, 16.54347229], [73.3520813, 16.54319382], [73.35180664, 16.54319382], [73.35180664, 16.54347229], [73.35069275, 16.54347038], [73.35069275, 16.54375076], [73.35041809, 16.54375076], [73.35041809, 16.54458427], [73.3501358, 16.54458046], [73.3501358, 16.54513931], [73.34986115, 16.54513931], [73.34986115, 16.5454216], [73.34958649, 16.54541588], [73.34958649, 16.54597282], [73.34929657, 16.54597092], [73.34929657, 16.54626274], [73.34902954, 16.54626274], [73.34902954, 16.54653168], [73.34874725, 16.54653168], [73.34874725, 16.54681015], [73.34902954, 16.54680634], [73.34902954, 16.5470829], [73.34874725, 16.54707909], [73.34874725, 16.54764175], [73.34929657, 16.54764175], [73.34929657, 16.54792023], [73.34958649, 16.54791641], [73.34958649, 16.54819489], [73.34929657, 16.54818916], [73.34929657, 16.54932022], [73.34958649, 16.54930305], [73.34958649, 16.54958344], [73.34986115, 16.54958344], [73.34986115, 16.54986382], [73.35090637, 16.54986382], [73.3520813, 16.54986191], [73.3520813, 16.55014038], [73.35235596, 16.55014038], [73.35235596, 16.55042076], [73.3520813, 16.55041695], [73.3520813, 16.5506897], [73.35180664, 16.55069542], [73.35180664, 16.55097389], [73.35124969, 16.55097389], [73.35124969, 16.55069542], [73.35069275, 16.55069542], [73.35069275, 16.55097389], [73.35041809, 16.55097008], [73.35041809, 16.55125046], [73.35024261, 16.55125046], [73.34958649, 16.55125046], [73.34958649, 16.55153084], [73.34902954, 16.55153084], [73.34902954, 16.55125046], [73.34819794, 16.55125046], [73.34819794, 16.55153084], [73.3473587, 16.55153084], [73.3473587, 16.55181122], [73.34707642, 16.55181122], [73.34707642, 16.55236053], [73.34680939, 16.55236053], [73.34680176, 16.55264091], [73.3465271, 16.55263901], [73.3465271, 16.55319595], [73.34625244, 16.55319023], [73.34625244, 16.55375099], [73.34597015, 16.55374908], [73.34597015, 16.55569458], [73.3456955, 16.55569458], [73.3456955, 16.55582047], [73.34570313, 16.55652809], [73.34597015, 16.55652618], [73.34597015, 16.55680466], [73.34625244, 16.55680466], [73.34625244, 16.55708313], [73.3501358, 16.55708313], [73.3501358, 16.5573616], [73.35152435, 16.5573616], [73.35152435, 16.55708313], [73.3520813, 16.55708313], [73.3520813, 16.55680466], [73.35236359, 16.55680466], [73.35236359, 16.55652618], [73.35263824, 16.55652809], [73.35263824, 16.55624962], [73.3529129, 16.55624962], [73.3529129, 16.55597115], [73.35319519, 16.55597305], [73.35319519, 16.55541611], [73.35346985, 16.55541992], [73.35346985, 16.55513], [73.35402679, 16.55513954], [73.35402679, 16.55486107], [73.35430908, 16.55486107], [73.35430908, 16.55458069], [73.35458374, 16.5545826], [73.35458374, 16.55430794], [73.35514069, 16.55430984], [73.35514069, 16.55402946], [73.35597229, 16.55402946], [73.35597229, 16.55375099], [73.35624695, 16.55375099], [73.35624695, 16.55319023], [73.35652924, 16.55319595], [73.35652924, 16.55291748], [73.35679626, 16.55291939], [73.35679626, 16.55264091], [73.35736084, 16.55264091], [73.35736084, 16.55291939], [73.35791779, 16.55291748], [73.35791779, 16.55319595], [73.35819244, 16.55319595], [73.35819244, 16.55291748], [73.35874939, 16.55291939], [73.35874939, 16.55264091], [73.35901642, 16.55264091], [73.35901642, 16.55236053], [73.35930634, 16.55236053], [73.35930634, 16.55207062], [73.35958099, 16.55208588], [73.35958099, 16.5518055], [73.35986328, 16.55181122], [73.35986328, 16.55153084], [73.36013794, 16.55153084], [73.36013794, 16.55125046], [73.36235809, 16.55125046], [73.36235809, 16.55153084], [73.3659668, 16.55153084], [73.3659668, 16.55125046], [73.36624908, 16.55125046], [73.36624908, 16.55153084], [73.36680603, 16.55153084], [73.36680603, 16.55125046], [73.36846924, 16.55125046], [73.36846924, 16.55097008], [73.37041473, 16.55097389], [73.37041473, 16.5506916], [73.37291718, 16.5506916], [73.37291718, 16.55041695], [73.37346649, 16.55042076], [73.37346649, 16.55014038], [73.37458038, 16.55014038], [73.37458038, 16.55042076], [73.37680817, 16.55041695], [73.37680817, 16.5506916], [73.37708282, 16.5506916], [73.37708282, 16.55097389], [73.37735748, 16.55097008], [73.37735748, 16.55125046], [73.37763977, 16.55125046], [73.37763977, 16.55208588], [73.37735748, 16.55208588], [73.37735748, 16.55319595], [73.37763977, 16.55319595], [73.37763977, 16.55347252], [73.37819672, 16.55347061], [73.37819672, 16.55375099], [73.37874603, 16.55375099], [73.37874603, 16.55402946], [73.38208008, 16.55402946], [73.38208008, 16.55430984], [73.38263702, 16.55430794], [73.38263702, 16.5545826], [73.38430786, 16.5545826], [73.38430786, 16.55430794], [73.38764954, 16.55430984], [73.38764954, 16.55402946], [73.38799286, 16.55402756], [73.38819122, 16.55402946], [73.38819122, 16.55375099], [73.38874817, 16.55375099], [73.38874817, 16.55347061], [73.38957977, 16.55347252], [73.38957977, 16.55319595], [73.39263916, 16.55319595], [73.39263916, 16.55291748], [73.39319611, 16.55291939], [73.39319611, 16.55264091], [73.39402771, 16.55264091], [73.39402771, 16.55375099], [73.39375305, 16.55375099], [73.39375305, 16.55430984], [73.39291382, 16.55430794], [73.39291382, 16.5544796], [73.39291382, 16.5545826], [73.39152527, 16.5545826], [73.3915329, 16.55486107], [73.39013672, 16.55486107], [73.39013672, 16.55458069], [73.38986206, 16.55458069], [73.38986206, 16.55486107], [73.38903046, 16.55486107], [73.38903046, 16.55513954], [73.38735962, 16.55513], [73.38735962, 16.55541992], [73.38597107, 16.55541611], [73.38597107, 16.55569458], [73.38541412, 16.55569458], [73.38541412, 16.55597305], [73.38430786, 16.55597305], [73.38430786, 16.55569458], [73.38402557, 16.55569458], [73.38402557, 16.55597305], [73.38318634, 16.55597115], [73.38318634, 16.55624962], [73.38236237, 16.55624962], [73.38236237, 16.55597115], [73.38208008, 16.55597305], [73.38208008, 16.55569458], [73.38097382, 16.55569458], [73.38097382, 16.55541611], [73.38069153, 16.55541611], [73.38069153, 16.55569458], [73.38041687, 16.55569458], [73.38041687, 16.55597305], [73.38069153, 16.55597115], [73.38069153, 16.55652809], [73.38097382, 16.55652618], [73.38097382, 16.55680466], [73.38124847, 16.55680466], [73.38124847, 16.55708313], [73.38153076, 16.55708313], [73.38153076, 16.5573616], [73.38124847, 16.5573597], [73.38124847, 16.55763817], [73.38069153, 16.55763817], [73.38069153, 16.5573597], [73.38014221, 16.5573616], [73.38014221, 16.55708313], [73.37985992, 16.55708313], [73.37985992, 16.55652618], [73.37902832, 16.55652809], [73.37902832, 16.55624962], [73.37845612, 16.55624962], [73.37845612, 16.55597115], [73.37819672, 16.55597305], [73.37819672, 16.55569458], [73.37791443, 16.55569458], [73.37791443, 16.55541611], [73.37763977, 16.55541992], [73.37763977, 16.55486107], [73.37735748, 16.55486107], [73.37735748, 16.55430984], [73.37708282, 16.55430984], [73.37708282, 16.55402946], [73.37680817, 16.55402946], [73.37680817, 16.55375099], [73.37652588, 16.55375099], [73.37652588, 16.55347061], [73.37625122, 16.55347252], [73.37625122, 16.55319595], [73.37596893, 16.55319595], [73.37596893, 16.55291748], [73.37568665, 16.55291939], [73.37568665, 16.55264091], [73.37513733, 16.55264091], [73.37513733, 16.55236053], [73.37486267, 16.55236053], [73.37486267, 16.55207062], [73.37374878, 16.55207062], [73.37374878, 16.55236053], [73.37346649, 16.55236053], [73.37346649, 16.55264091], [73.37265015, 16.55264091], [73.37265015, 16.55236053], [73.37208557, 16.55236053], [73.37208557, 16.55208588], [73.37152863, 16.55207062], [73.37152863, 16.55236053], [73.37097168, 16.55236053], [73.37097168, 16.55291939], [73.36902618, 16.55291748], [73.36902618, 16.55319595], [73.36819458, 16.55319595], [73.36819458, 16.55347252], [73.36708069, 16.55347061], [73.36708069, 16.55375099], [73.36651611, 16.55375099], [73.36651611, 16.55402946], [73.3663559, 16.55402946], [73.36624908, 16.55402946], [73.36624908, 16.55430984], [73.36541748, 16.55430984], [73.36541748, 16.55402946], [73.36514282, 16.55402946], [73.36514282, 16.55375099], [73.36429596, 16.55375099], [73.36429596, 16.55347061], [73.36374664, 16.55347061], [73.36374664, 16.55375099], [73.36264038, 16.55375099], [73.36264038, 16.55402946], [73.36235809, 16.55402756], [73.36235809, 16.5545826], [73.36152649, 16.5545826], [73.36152649, 16.55430794], [73.36069489, 16.55430794], [73.36069489, 16.5545826], [73.36042023, 16.55458069], [73.36042023, 16.55486107], [73.36013794, 16.55486107], [73.36013794, 16.55513954], [73.35930634, 16.55513], [73.35930634, 16.55541992], [73.35847473, 16.55541611], [73.35847473, 16.55569458], [73.35819244, 16.55569458], [73.35819244, 16.55597305], [73.35791779, 16.55597115], [73.35791779, 16.55624962], [73.3576355, 16.55624962], [73.3576355, 16.55597305], [73.35708618, 16.55597305], [73.35708618, 16.55569458], [73.35680389, 16.55569458], [73.35680389, 16.55541611], [73.35624695, 16.55541611], [73.35624695, 16.55569458], [73.35597229, 16.55569458], [73.35597229, 16.55597305], [73.35569763, 16.55597115], [73.35569763, 16.55652809], [73.35541534, 16.55652618], [73.35541534, 16.5573616], [73.35569763, 16.5573597], [73.35569763, 16.55763817], [73.35597229, 16.55763817], [73.35597229, 16.55820084], [73.35624695, 16.55820084], [73.35624695, 16.55874825], [73.35652924, 16.55874825], [73.35652924, 16.56069374], [73.35624695, 16.56069374], [73.35624695, 16.56097031], [73.35652924, 16.56097031], [73.35652924, 16.56153107], [73.35679626, 16.56153107], [73.35679626, 16.56264114], [73.35652924, 16.56264114], [73.35652924, 16.56291962], [73.35624695, 16.5629158], [73.35624695, 16.56319427], [73.35597229, 16.56319046], [73.35597229, 16.56402969], [73.35569763, 16.56402969], [73.35569763, 16.56431961], [73.35541534, 16.56430626], [73.35541534, 16.56458473], [73.35514069, 16.56458282], [73.35514069, 16.56513977], [73.3548584, 16.56513977], [73.3548584, 16.56597137], [73.35514069, 16.56596947], [73.35514069, 16.56624985], [73.35679626, 16.56624985], [73.35679626, 16.56653023], [73.35708618, 16.56653023], [73.35708618, 16.56624985], [73.35733795, 16.56624985], [73.35736084, 16.56653023], [73.3584671, 16.56653023], [73.3584671, 16.56624985], [73.35874939, 16.56624985], [73.35874939, 16.56596947], [73.35986328, 16.56596947], [73.35986328, 16.56624985], [73.36042023, 16.56624985], [73.36042023, 16.56653023], [73.36096954, 16.56653023], [73.36096954, 16.56624985], [73.36208344, 16.56624985], [73.36208344, 16.56680679], [73.36235809, 16.56680679], [73.36235809, 16.56847191], [73.36180878, 16.56847191], [73.36180878, 16.56819534], [73.36152649, 16.56820107], [73.36152649, 16.56792068], [73.36125183, 16.56792068], [73.36125183, 16.5676403], [73.36042023, 16.5676403], [73.36042023, 16.56735992], [73.35986328, 16.56735992], [73.35986328, 16.5676403], [73.35901642, 16.5676403], [73.35901642, 16.56820107], [73.35874939, 16.56819534], [73.35874939, 16.56847191], [73.3575058, 16.56847191], [73.35736084, 16.56847191], [73.35736084, 16.56791687], [73.35652924, 16.56792068], [73.35652924, 16.5676403], [73.35514069, 16.5676403], [73.35514069, 16.56735992], [73.3548584, 16.56736183], [73.3548584, 16.56708336], [73.35458374, 16.56708336], [73.35458374, 16.56680679], [73.35430908, 16.56680679], [73.35430908, 16.56597137], [73.35402679, 16.56597137], [73.35402679, 16.56569481], [73.35375214, 16.56569481], [73.35375214, 16.56513977], [73.35346985, 16.56513977], [73.35346985, 16.56458282], [73.3529129, 16.56458473], [73.3529129, 16.56430626], [73.3520813, 16.56430626], [73.3520813, 16.5648613], [73.35151672, 16.56485939], [73.35151672, 16.56513977], [73.34874725, 16.56513977], [73.34874725, 16.56485939], [73.34791565, 16.5648613], [73.34791565, 16.56458473], [73.34680939, 16.56458473], [73.34680176, 16.5648613], [73.3465271, 16.56485939], [73.3465271, 16.56513977], [73.34542084, 16.56513977], [73.34542084, 16.56542015], [73.3445816, 16.56541634], [73.3445816, 16.56569481], [73.34375, 16.56569481], [73.34375, 16.56597137], [73.34319305, 16.56596947], [73.34319305, 16.56624985], [73.34263611, 16.56624985], [73.34263611, 16.56680679], [73.34236145, 16.56680679], [73.34236145, 16.56708336], [73.34208679, 16.56707001], [73.34208679, 16.56792068], [73.34236145, 16.56791687], [73.34236145, 16.56847191], [73.34263611, 16.56847], [73.34263611, 16.56903076], [73.3429184, 16.56903076], [73.3429184, 16.56931114], [73.34319305, 16.56931114], [73.34319305, 16.56986046], [73.34348297, 16.56986046], [73.34348297, 16.57042122], [73.34375, 16.5704174], [73.34375, 16.57069397], [73.34430695, 16.57069016], [73.34430695, 16.57125092], [73.3445816, 16.57125092], [73.3445816, 16.57152748], [73.34486389, 16.57152748], [73.34486389, 16.57208252], [73.34513855, 16.57208061], [73.34513855, 16.57374954], [73.34485626, 16.57374954], [73.34485626, 16.57403183], [73.3445816, 16.57403183], [73.3445816, 16.5743103], [73.34430695, 16.57430649], [73.34430695, 16.57458115], [73.34401703, 16.57457924], [73.34401703, 16.57542038], [73.3445816, 16.57542038], [73.3445816, 16.57570076], [73.34485626, 16.57570076], [73.34485626, 16.57625961], [73.3445816, 16.57625961], [73.3445816, 16.57653046], [73.34430695, 16.57653046], [73.34430695, 16.57681084], [73.34402466, 16.57680511], [73.34402466, 16.57708359], [73.34375, 16.57708359], [73.34375, 16.57736206], [73.34348297, 16.57736015], [73.34348297, 16.57764053], [73.34319305, 16.57764053], [73.34319305, 16.57792091], [73.3429184, 16.5779171], [73.3429184, 16.57847214], [73.34263611, 16.57847023], [73.34263611, 16.57875061], [73.34234619, 16.57875061], [73.34234619, 16.57903099], [73.34208679, 16.57902718], [73.34208679, 16.57930565], [73.3418045, 16.57930565], [73.3418045, 16.57958412], [73.34124756, 16.57958031], [73.34124756, 16.57986069], [73.3409729, 16.57986069], [73.3409729, 16.58014107], [73.34041595, 16.58014107], [73.34041595, 16.58041954], [73.33985901, 16.58041954], [73.33985901, 16.58014107], [73.3390274, 16.58014107], [73.3390274, 16.57986069], [73.33833313, 16.57986069], [73.33680725, 16.57986069], [73.33680725, 16.57958031], [73.33625031, 16.57958412], [73.33625031, 16.57902718], [73.33598328, 16.57903099], [73.33598328, 16.57875061], [73.3354187, 16.57875061], [73.3354187, 16.57847023], [73.33513641, 16.57847214], [73.33513641, 16.57763863], [73.33486176, 16.57764053], [73.33486176, 16.57707977], [73.3345871, 16.57708359], [73.3345871, 16.57680511], [73.3326416, 16.57680511], [73.3326416, 16.57708359], [73.33097076, 16.57708359], [73.33097076, 16.57736206], [73.33040619, 16.57736015], [73.33040619, 16.57764053], [73.33013916, 16.57764053], [73.33013916, 16.57792091], [73.3298645, 16.5779171], [73.3298645, 16.57847214], [73.32958221, 16.57847023], [73.32958221, 16.57875061], [73.32930756, 16.57875061], [73.32930756, 16.57903099], [73.32875061, 16.57902718], [73.32875061, 16.57930565], [73.32791901, 16.57930565], [73.32791901, 16.57958412], [73.32763672, 16.57958031], [73.32763672, 16.57986069], [73.3273468, 16.57986069], [73.3273468, 16.58041954], [73.32707977, 16.58041763], [73.32707977, 16.5806942], [73.32680511, 16.5806942], [73.32680511, 16.58097267], [73.32624817, 16.58097076], [73.32624817, 16.58125114], [73.32541656, 16.58125114], [73.32541656, 16.58152962], [73.32457733, 16.58152962], [73.32457733, 16.58180809], [73.32402802, 16.58180618], [73.32402802, 16.58208275], [73.32375336, 16.58208084], [73.32375336, 16.58236122], [73.32347107, 16.58236122], [73.32347107, 16.58263969], [73.32319641, 16.58263969], [73.32319641, 16.58291817], [73.32291412, 16.58291626], [73.32291412, 16.58319473], [73.32263947, 16.58319092], [73.32263947, 16.58374977], [73.32236481, 16.58374977], [73.32236481, 16.58430481], [73.32208252, 16.58430481], [73.32208252, 16.58458328], [73.32235718, 16.58457947], [73.32235718, 16.58569908], [73.32263947, 16.58569908], [73.32263947, 16.5862484], [73.32290649, 16.5862484], [73.32290649, 16.58792114], [73.32263947, 16.58791733], [73.32263947, 16.58847046], [73.32290649, 16.58847046], [73.32290649, 16.58930969], [73.32263947, 16.58930969], [73.32263947, 16.58986282], [73.32236481, 16.58986282], [73.32236481, 16.59069443], [73.32208252, 16.59069443], [73.32208252, 16.59097481], [73.32180786, 16.59097481], [73.32180786, 16.59124947], [73.3215332, 16.59124184], [73.3215332, 16.59152985], [73.32068634, 16.59152985], [73.32068634, 16.59181023], [73.32013702, 16.59180641], [73.32013702, 16.59208488], [73.31986237, 16.59208488], [73.31986237, 16.59236145], [73.31958008, 16.59235954], [73.31958008, 16.59263992], [73.31931305, 16.59263992], [73.31931305, 16.59320068], [73.31903076, 16.59319687], [73.31903076, 16.59458351], [73.31874847, 16.5945797], [73.31874847, 16.59514046], [73.31846619, 16.59514046], [73.31846619, 16.59653091], [73.31874847, 16.5965271], [73.31874847, 16.59708405], [73.31903076, 16.59708023], [73.31903076, 16.59736824], [73.31958008, 16.59736824], [73.31958008, 16.59763908], [73.31986237, 16.59763908], [73.31986237, 16.59791756], [73.31958008, 16.59791756], [73.31958008, 16.59874916], [73.31931305, 16.59874916], [73.31931305, 16.59903145], [73.31903076, 16.59903145], [73.31903076, 16.59931183], [73.31874847, 16.59930611], [73.31874847, 16.59958267], [73.31846619, 16.59958076], [73.31846619, 16.59985924], [73.31791687, 16.59985924], [73.31791687, 16.60014153], [73.31735992, 16.60014153], [73.31735992, 16.60042953], [73.31708527, 16.60041618], [73.31708527, 16.60097122], [73.31680298, 16.60096931], [73.31680298, 16.60153008], [73.31708527, 16.60152817], [73.31708527, 16.6020813], [73.31735992, 16.6020813], [73.31735992, 16.60236359], [73.31764221, 16.60235977], [73.31764221, 16.60264015], [73.31791687, 16.60264015], [73.31791687, 16.60292053], [73.31846619, 16.60292053], [73.31846619, 16.60320091], [73.31903076, 16.60319519], [73.31903076, 16.60347366], [73.31931305, 16.60346985], [73.31931305, 16.60514069], [73.31958008, 16.60514069], [73.31958008, 16.60542107], [73.31986237, 16.60541725], [73.31986237, 16.60569572], [73.32013702, 16.60569572], [73.32013702, 16.60708237], [73.32041931, 16.60708046], [73.32041931, 16.60736084], [73.32180786, 16.60736084], [73.32180786, 16.60708046], [73.32236481, 16.60708237], [73.32236481, 16.6068058], [73.32290649, 16.60680962], [73.32290649, 16.60653114], [73.32347107, 16.60653114], [73.32347107, 16.60624123], [73.32375336, 16.60625076], [73.32375336, 16.60597229], [73.32402802, 16.60597229], [73.32402802, 16.60569572], [73.32485962, 16.60569572], [73.32485962, 16.60597229], [73.32514191, 16.60597229], [73.32514191, 16.60625076], [73.32541656, 16.60624123], [73.32541656, 16.60680962], [73.32569122, 16.6068058], [73.32569122, 16.60708237], [73.32596588, 16.60708046], [73.32596588, 16.60736084], [73.32624817, 16.60736084], [73.32624817, 16.60764122], [73.32818604, 16.60764122], [73.32818604, 16.60791969], [73.32902527, 16.60791779], [73.32902527, 16.60819435], [73.33041382, 16.60819435], [73.33041382, 16.60847282], [73.33069611, 16.60847282], [73.33069611, 16.60819435], [73.33180237, 16.60819435], [73.33180237, 16.60791779], [73.33291626, 16.60791969], [73.33291626, 16.60764122], [73.33347321, 16.60764122], [73.33347321, 16.60736084], [73.33403015, 16.60736084], [73.33403015, 16.60708046], [73.3345871, 16.60708237], [73.3345871, 16.6068058], [73.33486176, 16.60680962], [73.33486176, 16.60653114], [73.33513641, 16.60653114], [73.33513641, 16.60624123], [73.3354187, 16.60625076], [73.3354187, 16.60569572], [73.33597565, 16.60569572], [73.33597565, 16.60541725], [73.33652496, 16.60541725], [73.33652496, 16.60569572], [73.33791351, 16.60569572], [73.33791351, 16.60541725], [73.33847046, 16.60542107], [73.33847046, 16.60514069], [73.33875275, 16.60514069], [73.33875275, 16.60486031], [73.3392868, 16.60486031], [73.3392868, 16.60457993], [73.33958435, 16.60458374], [73.33958435, 16.60430527], [73.33985901, 16.60431099], [73.33985901, 16.60403061], [73.3401413, 16.60403061], [73.3401413, 16.60375023], [73.34041595, 16.60375023], [73.34041595, 16.60235977], [73.3401413, 16.60236359], [73.3401413, 16.60152817], [73.3409729, 16.60153008], [73.3409729, 16.6012516], [73.34124756, 16.6012516], [73.34124756, 16.60096931], [73.34152985, 16.60097122], [73.34152985, 16.60069466], [73.3418045, 16.60069466], [73.3418045, 16.60041618], [73.3429184, 16.60042953], [73.3429184, 16.60014153], [73.34375, 16.60014153], [73.34375, 16.59985924], [73.34401703, 16.59985924], [73.34401703, 16.59931183], [73.34430695, 16.59931183], [73.34430695, 16.59903145], [73.34597015, 16.59903145], [73.34597015, 16.59874916], [73.3465271, 16.59874916], [73.3465271, 16.59847069], [73.34680176, 16.5984726], [73.34680176, 16.59736061], [73.3465271, 16.59736824], [73.3465271, 16.59568977], [73.34680176, 16.59569359], [73.34680176, 16.59541512], [73.34707642, 16.59542084], [73.34707642, 16.59514046], [73.3473587, 16.59514046], [73.3473587, 16.59542084], [73.34764099, 16.59541512], [73.34764099, 16.59569359], [73.34791565, 16.59569359], [73.34791565, 16.59597206], [73.34874725, 16.59597015], [73.34874725, 16.59625053], [73.34929657, 16.59625053], [73.34929657, 16.59597015], [73.34986115, 16.59597206], [73.34986115, 16.59569359], [73.35041809, 16.59569359], [73.35041809, 16.59541512], [73.35069275, 16.59542084], [73.35069275, 16.59514046], [73.35098267, 16.59514046], [73.35098267, 16.59486008], [73.35124969, 16.59486198], [73.35124969, 16.59458351], [73.35180664, 16.59458351], [73.35180664, 16.59486198], [73.3520813, 16.59486008], [73.3520813, 16.59514046], [73.35236359, 16.59513855], [73.35235596, 16.59638023], [73.35235596, 16.59653091], [73.35263824, 16.59653091], [73.35263824, 16.59680748], [73.35236359, 16.59680557], [73.35236359, 16.59708405], [73.35180664, 16.59708405], [73.35180664, 16.59680557], [73.35163879, 16.59680557], [73.35097504, 16.59680557], [73.35097504, 16.59708405], [73.35069275, 16.59708023], [73.35069275, 16.59736824], [73.35041809, 16.59736061], [73.35041809, 16.59753036], [73.35041809, 16.59791756], [73.3501358, 16.59791756], [73.3501358, 16.59903145], [73.34986115, 16.59903145], [73.34986115, 16.59931183], [73.3501358, 16.59930611], [73.3501358, 16.59958267], [73.34986115, 16.59958076], [73.34986115, 16.59985924], [73.34958649, 16.59985924], [73.34958649, 16.60097122], [73.34929657, 16.60096931], [73.34929657, 16.6012516], [73.34958649, 16.6012516], [73.34958649, 16.60292053], [73.34929657, 16.60292053], [73.34929657, 16.60320091], [73.34902954, 16.60319519], [73.34902954, 16.60347366], [73.3484726, 16.60347366], [73.3484726, 16.60319519], [73.34819794, 16.60320091], [73.34819794, 16.60264015], [73.34792328, 16.60264015], [73.34792328, 16.60207939], [73.34764099, 16.6020813], [73.34764099, 16.60152817], [73.3473587, 16.60153008], [73.3473587, 16.6012516], [73.34680939, 16.6012516], [73.34680176, 16.60153008], [73.3456955, 16.60152817], [73.3456955, 16.60236359], [73.34542084, 16.60235977], [73.34542084, 16.60292053], [73.34513855, 16.60292053], [73.34513855, 16.60320091], [73.34485626, 16.60320091], [73.34485626, 16.60375023], [73.34430695, 16.60375023], [73.34430695, 16.60403061], [73.34401703, 16.60403061], [73.34401703, 16.60431099], [73.34375, 16.60430527], [73.34375, 16.60458374], [73.34234619, 16.60457993], [73.34234619, 16.60486031], [73.34152985, 16.60486031], [73.34152985, 16.60514069], [73.3409729, 16.60514069], [73.3409729, 16.60542107], [73.34069824, 16.60542107], [73.34069824, 16.60680962], [73.3409729, 16.6068058], [73.3409729, 16.60708237], [73.34124756, 16.60708046], [73.34124756, 16.60736084], [73.34152985, 16.60736084], [73.34152985, 16.60764122], [73.34179688, 16.60764122], [73.34179688, 16.60791969], [73.34208679, 16.60791779], [73.34208679, 16.60819435], [73.34236145, 16.60819435], [73.34236145, 16.60847282], [73.34263611, 16.60847092], [73.34263611, 16.60902977], [73.3429184, 16.60902786], [73.3429184, 16.60986137], [73.34319305, 16.60985947], [73.34319305, 16.61013985], [73.34375, 16.61013985], [73.34375, 16.61041832], [73.34430695, 16.61041641], [73.34430695, 16.61069489], [73.3445816, 16.61069107], [73.3445816, 16.61124992], [73.34485626, 16.61124992], [73.34485626, 16.61181068], [73.34541321, 16.61180496], [73.34541321, 16.61208344], [73.34570313, 16.61207962], [73.34570313, 16.61236954], [73.34597015, 16.61236954], [73.34597015, 16.61263847], [73.34680176, 16.61263847], [73.34680939, 16.61292076], [73.3473587, 16.61291695], [73.3473587, 16.61319351], [73.3484726, 16.61319351], [73.3484726, 16.61291695], [73.34874725, 16.61292076], [73.34874725, 16.61263847], [73.34902954, 16.61263847], [73.34902954, 16.61236954], [73.34929657, 16.61236954], [73.34929657, 16.61207962], [73.34958649, 16.61208344], [73.34958649, 16.61180496], [73.3501358, 16.61181068], [73.3501358, 16.6115284], [73.35069275, 16.6115284], [73.35069275, 16.61181068], [73.35098267, 16.61181068], [73.35098267, 16.61236954], [73.35124969, 16.61236191], [73.35124969, 16.61319351], [73.35151672, 16.6131897], [73.35151672, 16.61375237], [73.35180664, 16.61375237], [73.35180664, 16.61568069], [73.35180664, 16.61819458], [73.35152435, 16.61819458], [73.35152435, 16.62208366], [73.35180664, 16.62207985], [73.35180664, 16.62264061], [73.3520813, 16.62264061], [73.3520813, 16.62292099], [73.35263824, 16.62291718], [73.35263824, 16.62319374], [73.35235596, 16.62318993], [73.35235596, 16.62375069], [73.3520813, 16.62375069], [73.3520813, 16.62392998], [73.3520813, 16.6245842], [73.35180664, 16.62458038], [73.35180664, 16.62513924], [73.35124969, 16.62513924], [73.35124969, 16.62458038], [73.35069275, 16.6245842], [73.35069275, 16.62430573], [73.35041809, 16.62430954], [73.35041809, 16.62375069], [73.34986115, 16.62375069], [73.34986115, 16.62347031], [73.34958649, 16.62347221], [73.34958649, 16.62319374], [73.3493042, 16.62319374], [73.3493042, 16.62291718], [73.34874725, 16.62292099], [73.34874725, 16.62264061], [73.34848022, 16.62264061], [73.34848022, 16.62207985], [73.34791565, 16.62208366], [73.34791565, 16.62180519], [73.3473587, 16.62181091], [73.3473587, 16.62153816], [73.3465271, 16.62153816], [73.3465271, 16.62125015], [73.34541321, 16.62125015], [73.34541321, 16.62097168], [73.34069824, 16.62096977], [73.34069824, 16.62125015], [73.3401413, 16.62125015], [73.3401413, 16.62236023], [73.33985901, 16.62236023], [73.33985901, 16.62264061], [73.33958435, 16.6226387], [73.33958435, 16.62319374], [73.33930206, 16.62319374], [73.33930206, 16.62347221], [73.3390274, 16.62347031], [73.3390274, 16.62375069], [73.33875275, 16.62375069], [73.33875275, 16.62402916], [73.33735657, 16.62402916], [73.33735657, 16.62375069], [73.33708191, 16.62375069], [73.33708191, 16.62347031], [73.33680725, 16.62347221], [73.33680725, 16.62291718], [73.33651733, 16.62292099], [73.33651733, 16.62264061], [73.33625031, 16.62264061], [73.33625031, 16.62236023], [73.33597565, 16.62236023], [73.33597565, 16.62097168], [73.33569336, 16.62097168], [73.33569336, 16.6198616], [73.33513641, 16.6198616], [73.33513641, 16.61958313], [73.33486176, 16.61958313], [73.33486176, 16.61930466], [73.33291626, 16.61930466], [73.33291626, 16.61958313], [73.33180237, 16.61958313], [73.33180237, 16.6198616], [73.33125305, 16.6198597], [73.33125305, 16.62014008], [73.33069611, 16.62014008], [73.33069611, 16.62042046], [73.33040619, 16.62042046], [73.33040619, 16.62070084], [73.33013916, 16.62069511], [73.33013916, 16.62208366], [73.33040619, 16.62207985], [73.33040619, 16.62236023], [73.33069611, 16.62236023], [73.33069611, 16.62264061], [73.33097076, 16.62264061], [73.33097076, 16.62292099], [73.33125305, 16.62291718], [73.33125305, 16.62319374], [73.33152771, 16.62318993], [73.33152771, 16.62375069], [73.33180237, 16.62375069], [73.33180237, 16.62402916], [73.33207703, 16.62402916], [73.33207703, 16.62430954], [73.33235931, 16.62430573], [73.33235931, 16.6245842], [73.3326416, 16.62458038], [73.3326416, 16.62486076], [73.33291626, 16.62486076], [73.33291626, 16.62513924], [73.33319092, 16.62513924], [73.33319092, 16.62542152], [73.33374786, 16.6254158], [73.33374786, 16.62569427], [73.33403015, 16.62569427], [73.33403015, 16.62597275], [73.33429718, 16.62597084], [73.33429718, 16.62624931], [73.3345871, 16.62624931], [73.3345871, 16.6265316], [73.33486176, 16.6265316], [73.33486176, 16.62681007], [73.33513641, 16.62680626], [73.33513641, 16.62708282], [73.3354187, 16.62708282], [73.3354187, 16.62735939], [73.33680725, 16.62734985], [73.33680725, 16.62764168], [73.33708191, 16.62764168], [73.33708191, 16.62792015], [73.33791351, 16.62791634], [73.33791351, 16.62819481], [73.33847046, 16.62819481], [73.33847046, 16.62791634], [73.3390274, 16.62792015], [73.3390274, 16.62764168], [73.3392868, 16.62764168], [73.3392868, 16.62734985], [73.33958435, 16.62735939], [73.33958435, 16.62708282], [73.3401413, 16.62708282], [73.3401413, 16.62680626], [73.34069824, 16.62680626], [73.34069824, 16.62708282], [73.34124756, 16.62708282], [73.34124756, 16.62735939], [73.34152985, 16.62734985], [73.34152985, 16.62792015], [73.3418045, 16.62791634], [73.3418045, 16.62819481], [73.34208679, 16.62818909], [73.34208679, 16.62875175], [73.34179688, 16.62875175], [73.34179688, 16.62903023], [73.34152985, 16.62902832], [73.34152985, 16.62930489], [73.34124756, 16.62930489], [73.34124756, 16.62958145], [73.3409729, 16.62958145], [73.3409729, 16.62986374], [73.34069824, 16.62986183], [73.34069824, 16.6301403], [73.34041595, 16.6301403], [73.34041595, 16.63070107], [73.3401413, 16.63069534], [73.3401413, 16.63097382], [73.33985901, 16.63097], [73.33985901, 16.63125038], [73.33957672, 16.63125038], [73.33957672, 16.63181114], [73.3392868, 16.63181114], [73.3392868, 16.63292122], [73.33958435, 16.6329174], [73.33958435, 16.63319588], [73.33985901, 16.63319588], [73.33985901, 16.63344955], [73.3401413, 16.63348007], [73.3401413, 16.63402939], [73.34041595, 16.63402939], [73.34041595, 16.63486099], [73.3401413, 16.63486099], [73.3401413, 16.63541985], [73.33985901, 16.63541794], [73.33985901, 16.63597298], [73.33958435, 16.63597298], [73.33958435, 16.63708305], [73.33985901, 16.63708115], [73.33985901, 16.63820076], [73.3390274, 16.63820076], [73.3390274, 16.63792038], [73.3373642, 16.63791656], [73.3373642, 16.6380806], [73.3373642, 16.6384716], [73.33680725, 16.6384697], [73.33680725, 16.63902855], [73.33625031, 16.63902855], [73.33625031, 16.63958359], [73.33597565, 16.63958359], [73.33597565, 16.63986015], [73.33569336, 16.63985825], [73.33569336, 16.64013863], [73.33429718, 16.64013863], [73.33429718, 16.64042282], [73.33374786, 16.6404171], [73.33374786, 16.64069366], [73.33347321, 16.64069176], [73.33347321, 16.64125252], [73.33291626, 16.64125252], [73.33291626, 16.6415329], [73.32985687, 16.6415329], [73.32985687, 16.64125252], [73.32930756, 16.64125252], [73.32930756, 16.64097023], [73.32902527, 16.64097023], [73.32902527, 16.6404171], [73.32875061, 16.64042282], [73.32875061, 16.63957977], [73.32902527, 16.63958359], [73.32902527, 16.63930511], [73.32930756, 16.63931084], [73.32930756, 16.63902855], [73.32958221, 16.63902855], [73.32958221, 16.6384697], [73.32930756, 16.6384716], [73.32930756, 16.63819504], [73.3290329, 16.63820076], [73.3290329, 16.63792038], [73.32875061, 16.63792038], [73.32875061, 16.63763809], [73.32847595, 16.63763809], [73.32847595, 16.63735962], [73.32763672, 16.63736153], [73.32763672, 16.63708305], [73.32707977, 16.63708305], [73.32707977, 16.63680649], [73.32624817, 16.6368103], [73.32624817, 16.63653755], [73.32485962, 16.63653755], [73.32485962, 16.63624954], [73.32375336, 16.63624954], [73.32375336, 16.63653755], [73.32347107, 16.63653755], [73.32347107, 16.63820076], [73.32319641, 16.63819504], [73.32319641, 16.6384716], [73.32290649, 16.6384697], [73.32290649, 16.63902855], [73.32263947, 16.63902855], [73.32263947, 16.64042282], [73.32235718, 16.64042282], [73.32235718, 16.6415329], [73.32208252, 16.64152718], [73.32208252, 16.64236259], [73.32180786, 16.64236259], [73.32180786, 16.64458466], [73.32208252, 16.64458084], [73.32208252, 16.64486122], [73.32235718, 16.64486122], [73.32235718, 16.64513969], [73.32263947, 16.64513969], [73.32263947, 16.64542007], [73.32319641, 16.64541626], [73.32319641, 16.64569473], [73.32347107, 16.64569473], [73.32347107, 16.6459713], [73.32375336, 16.64596939], [73.32375336, 16.64624977], [73.32402802, 16.64624977], [73.32402802, 16.64736176], [73.32375336, 16.64735985], [73.32375336, 16.64792061], [73.32402802, 16.64792061], [73.32402802, 16.64820099], [73.3243103, 16.64820099], [73.3243103, 16.64847946], [73.32485962, 16.64847946], [73.32485962, 16.64820099], [73.32653046, 16.64820099], [73.32653046, 16.64792061], [73.32681274, 16.64792061], [73.32681274, 16.64764023], [73.32707977, 16.64764023], [73.32707977, 16.64735985], [73.32736206, 16.64736176], [73.32736206, 16.64680672], [73.32763672, 16.64680672], [73.32763672, 16.64652824], [73.32791901, 16.64653015], [73.32791901, 16.64624977], [73.32847595, 16.64624977], [73.32847595, 16.64653015], [73.32875061, 16.64652824], [73.32875061, 16.64680672], [73.32930756, 16.64680672], [73.32930756, 16.64708328], [73.3298645, 16.64708328], [73.3298645, 16.64736176], [73.33013916, 16.64735985], [73.33013916, 16.64764023], [73.33040619, 16.64764023], [73.33040619, 16.64820099], [73.33069611, 16.64820099], [73.33069611, 16.64847946], [73.33097076, 16.64847946], [73.33097076, 16.64903069], [73.33125305, 16.64902687], [73.33125305, 16.64958382], [73.33152771, 16.64958], [73.33152771, 16.65014076], [73.33180237, 16.65013885], [73.33180237, 16.65069389], [73.33208466, 16.65069389], [73.33208466, 16.65097237], [73.33235931, 16.65097046], [73.33235931, 16.65263939], [73.3326416, 16.65263939], [73.3326416, 16.65292168], [73.33291626, 16.65291595], [73.33291626, 16.6534729], [73.33319092, 16.65346909], [73.33319092, 16.65764046], [73.33291626, 16.65764046], [73.33291626, 16.65930939], [73.3326416, 16.65930557], [73.3326416, 16.66069412], [73.33235931, 16.66069031], [73.33235931, 16.66263962], [73.33207703, 16.66263962], [73.33207703, 16.66513824], [73.33180237, 16.66513824], [73.33180237, 16.66736031], [73.33152771, 16.66736031], [73.33152771, 16.66819382], [73.33125305, 16.66819382], [73.33125305, 16.66847038], [73.33152771, 16.66847038], [73.33152771, 16.66903114], [73.33125305, 16.66903114], [73.33125305, 16.66986275], [73.33097076, 16.66986275], [73.33097076, 16.67152977], [73.33069611, 16.67152977], [73.33069611, 16.6740303], [73.33040619, 16.6740303], [73.33040619, 16.67681122], [73.33013916, 16.67681122], [73.33013916, 16.67791748], [73.32985687, 16.67791748], [73.32985687, 16.67874908], [73.32958221, 16.67874718], [73.32958221, 16.6795826], [73.32930756, 16.67958069], [73.32930756, 16.68292046], [73.32958221, 16.68291664], [73.32958221, 16.68569565], [73.3298645, 16.68569565], [73.3298645, 16.68597221], [73.33403015, 16.68597221], [73.33403015, 16.68569565], [73.3345871, 16.68569565], [73.3345871, 16.68541718], [73.33486176, 16.68542099], [73.33486176, 16.68514061], [73.33680725, 16.68514061], [73.33680725, 16.68486023], [73.33735657, 16.68486023], [73.33735657, 16.68458939], [73.3392868, 16.68458939], [73.3392868, 16.68514061], [73.33958435, 16.6851387], [73.33958435, 16.68569565], [73.33930206, 16.68569565], [73.33930206, 16.68597221], [73.33875275, 16.68597031], [73.33875275, 16.68653107], [73.33790588, 16.68653107], [73.33790588, 16.68625069], [73.33735657, 16.68625069], [73.33735657, 16.68597031], [73.33597565, 16.68597221], [73.33598328, 16.68625069], [73.3354187, 16.68625069], [73.3354187, 16.68653107], [73.33513641, 16.68653107], [73.33513641, 16.68680954], [73.33486176, 16.68680954], [73.33486176, 16.68736076], [73.3345871, 16.68736076], [73.3345871, 16.68765068], [73.33429718, 16.68765068], [73.33429718, 16.68791962], [73.33235931, 16.68791962], [73.33235931, 16.68765068], [73.33152771, 16.68765068], [73.33152771, 16.68736076], [73.33013916, 16.68736076], [73.33013916, 16.68765068], [73.32985687, 16.68765068], [73.32985687, 16.68791962], [73.32958221, 16.68791771], [73.32958221, 16.68819427], [73.32930756, 16.68819427], [73.32930756, 16.68847275], [73.32875061, 16.68847084], [73.32875061, 16.68875122], [73.32847595, 16.68875122], [73.32847595, 16.68902969], [73.32818604, 16.68902969], [73.32818604, 16.68930817], [73.32763672, 16.68930626], [73.32763672, 16.68958282], [73.32680511, 16.68958282], [73.32680511, 16.6898613], [73.32624817, 16.68985939], [73.32624817, 16.69013977], [73.32569122, 16.69013977], [73.32569122, 16.69041824], [73.32541656, 16.69041634], [73.32541656, 16.69069481], [73.32485962, 16.69069481], [73.32485962, 16.69097137], [73.3243103, 16.69096947], [73.3243103, 16.69152832], [73.32402802, 16.69152832], [73.32402802, 16.69208336], [73.32347107, 16.69208336], [73.32347107, 16.69236183], [73.32319641, 16.69235992], [73.32319641, 16.6926384], [73.32290649, 16.6926384], [73.32290649, 16.69292068], [73.32263947, 16.69291687], [73.32263947, 16.69347191], [73.32235718, 16.69346809], [73.32235718, 16.69375229], [73.32180786, 16.69375229], [73.32180786, 16.69403267], [73.3215332, 16.69403267], [73.3215332, 16.69431114], [73.32125092, 16.69430542], [73.32125092, 16.69458389], [73.32096863, 16.69458008], [73.32096863, 16.69486046], [73.32068634, 16.69486046], [73.32068634, 16.69514275], [73.32013702, 16.69514275], [73.32013702, 16.69542122], [73.31958008, 16.6954174], [73.31958008, 16.69569206], [73.31930542, 16.69569206], [73.31930542, 16.69597054], [73.31903076, 16.69597054], [73.31903076, 16.69625282], [73.31846619, 16.69625282], [73.31846619, 16.69652939], [73.31817627, 16.69652939], [73.31817627, 16.6973629], [73.31791687, 16.6973629], [73.31791687, 16.69791985], [73.31764221, 16.69791603], [73.31764221, 16.69847488], [73.31735992, 16.69847107], [73.31735992, 16.70042038], [73.31764221, 16.70042038], [73.31764221, 16.70236015], [73.31791687, 16.70236206], [73.31791687, 16.70263863], [73.31846619, 16.702631], [73.31846619, 16.70292091], [73.31874847, 16.7029171], [73.31874847, 16.70347214], [73.31903076, 16.70347023], [73.31903076, 16.70430756], [73.31874847, 16.70430565], [73.31874847, 16.70458412], [73.31847382, 16.70458412], [73.31847382, 16.7056942], [73.31817627, 16.70569038], [73.31817627, 16.70624924], [73.31791687, 16.70624924], [73.31791687, 16.7068119], [73.31764221, 16.7068119], [73.31764221, 16.70735931], [73.31735992, 16.70735931], [73.31735992, 16.7076416], [73.3170929, 16.7076416], [73.3170929, 16.70876122], [73.31680298, 16.70875168], [73.31680298, 16.70958138], [73.31652832, 16.70957947], [73.31652832, 16.71070099], [73.31625366, 16.71069527], [73.31625366, 16.71097374], [73.31597137, 16.71096992], [73.31597137, 16.71153069], [73.31569672, 16.71152687], [73.31569672, 16.71208572], [73.3154068, 16.71208], [73.3154068, 16.71264076], [73.31513977, 16.71264076], [73.31513977, 16.71292114], [73.31430817, 16.71291733], [73.31430817, 16.7131958], [73.31375122, 16.7131958], [73.31375122, 16.71347237], [73.31291962, 16.71347046], [73.31291962, 16.71375084], [73.31263733, 16.71375084], [73.31263733, 16.71430969], [73.31236267, 16.71430588], [73.31236267, 16.71458244], [73.31208038, 16.714571], [73.31208038, 16.71486092], [73.31153107, 16.71486092], [73.31153107, 16.71513939], [73.31124878, 16.71513939], [73.31124878, 16.7159729], [73.31097412, 16.7159729], [73.31097412, 16.71736145], [73.31124878, 16.71736145], [73.31124878, 16.71847153], [73.31153107, 16.71846962], [73.31153107, 16.72153282], [73.31124878, 16.72153282], [73.31124878, 16.72180939], [73.31097412, 16.72180557], [73.31097412, 16.72208214], [73.31069183, 16.72208023], [73.31069183, 16.72236252], [73.31041718, 16.72236252], [73.31041718, 16.7226429], [73.30986023, 16.7226429], [73.30986023, 16.7237606], [73.31014252, 16.7237606], [73.31014252, 16.72486115], [73.30986023, 16.72486115], [73.30986023, 16.72542], [73.30958557, 16.72541618], [73.30958557, 16.72624969], [73.30930328, 16.72624969], [73.30930328, 16.72680664], [73.30735779, 16.72680664], [73.30735779, 16.72736168], [73.30708313, 16.72735977], [73.30708313, 16.72792053], [73.30680847, 16.72792053], [73.30680847, 16.72820091], [73.30652618, 16.72819519], [73.30652618, 16.72847176], [73.30596924, 16.72846985], [73.30596924, 16.72875023], [73.30568695, 16.72875023], [73.30568695, 16.72931099], [73.30541992, 16.72930527], [73.30541992, 16.73069382], [73.30569458, 16.73069382], [73.30569458, 16.73097229], [73.30596924, 16.73097038], [73.30596924, 16.73125076], [73.30623627, 16.73125076], [73.30623627, 16.73180962], [73.30652618, 16.73180962], [73.30652618, 16.73431015], [73.30623627, 16.73431015], [73.30623627, 16.73542023], [73.30596924, 16.73541641], [73.30596924, 16.73597336], [73.30568695, 16.73596954], [73.30568695, 16.7365303], [73.30541992, 16.7365303], [73.30541992, 16.73681068], [73.30568695, 16.73681068], [73.30568695, 16.73986053], [73.30541992, 16.73986053], [73.30541992, 16.74152946], [73.30569458, 16.74152756], [73.30569458, 16.7420826], [73.30596924, 16.7420826], [73.30596924, 16.74319458], [73.30568695, 16.74319077], [73.30568695, 16.74652863], [73.30623627, 16.74652863], [73.30623627, 16.74681091], [73.30652618, 16.74680519], [73.30652618, 16.74708366], [73.30680847, 16.74707985], [73.30680847, 16.74736023], [73.30708313, 16.74736023], [73.30708313, 16.74764252], [73.30735779, 16.74764252], [73.30735779, 16.74930954], [73.30708313, 16.74930573], [73.30708313, 16.7495842], [73.30652618, 16.74958038], [73.30652618, 16.74986267], [73.30596924, 16.74986267], [73.30596924, 16.75014114], [73.30568695, 16.75014114], [73.30568695, 16.75041962], [73.30486298, 16.75041962], [73.30486298, 16.75125122], [73.30513763, 16.75124931], [73.30513763, 16.75208473], [73.30541992, 16.75208473], [73.30541992, 16.75347137], [73.30513763, 16.75346947], [73.30513763, 16.75681114], [73.30541992, 16.75680542], [73.30541992, 16.7606945], [73.30568695, 16.76069069], [73.30568695, 16.76153183], [73.30541992, 16.76153183], [73.30541992, 16.76375008], [73.30513763, 16.76375008], [73.30513763, 16.76708412], [73.30541992, 16.76708412], [73.30541992, 16.76847267], [73.30568695, 16.76847076], [73.30568695, 16.76875114], [73.30596924, 16.76875114], [73.30596924, 16.76902962], [73.30623627, 16.76902962], [73.30623627, 16.76930809], [73.30652618, 16.76930809], [73.30652618, 16.76986122], [73.30680847, 16.76986122], [73.30680847, 16.77041817], [73.30708313, 16.77041817], [73.30708313, 16.77124977], [73.30735779, 16.77124977], [73.30735779, 16.77347183], [73.30708313, 16.77346992], [73.30708313, 16.77403259], [73.30680847, 16.77402687], [73.30680847, 16.77458382], [73.30652618, 16.77458191], [73.30652618, 16.77542114], [73.30680847, 16.77542114], [73.30680847, 16.77625275], [73.30708313, 16.77625275], [73.30708313, 16.77708435], [73.30735779, 16.77708054], [73.30735779, 16.77874947], [73.30764008, 16.77874947], [73.30764008, 16.78013992], [73.3079071, 16.78013992], [73.3079071, 16.78070068], [73.30819702, 16.78069687], [73.30819702, 16.78097153], [73.30847168, 16.78096962], [73.30847168, 16.78153038], [73.30874634, 16.78152847], [73.30874634, 16.78208351], [73.30902863, 16.7820797], [73.30902863, 16.78264046], [73.30930328, 16.78263855], [73.30930328, 16.78375053], [73.3095932, 16.78375053], [73.3095932, 16.78513908], [73.30986023, 16.78513718], [73.30986023, 16.78569412], [73.31014252, 16.78569031], [73.31014252, 16.78624916], [73.31041718, 16.78624916], [73.31041718, 16.78681183], [73.31069183, 16.78680611], [73.31069183, 16.78708267], [73.31096649, 16.78708076], [73.31096649, 16.78764153], [73.31124878, 16.78764153], [73.31124878, 16.78819466], [73.31153107, 16.78819466], [73.31153107, 16.78847122], [73.31180573, 16.78847122], [73.31180573, 16.78874969], [73.31236267, 16.78874969], [73.31236267, 16.78930473], [73.31263733, 16.78930473], [73.31263733, 16.78986359], [73.31318665, 16.78985023], [73.31318665, 16.79042053], [73.31346893, 16.79041672], [73.31346893, 16.79097366], [73.31375122, 16.79096985], [73.31375122, 16.79125023], [73.31402588, 16.79125023], [73.31402588, 16.79153061], [73.31430817, 16.7915287], [73.31430817, 16.79208565], [73.31458282, 16.79207993], [73.31458282, 16.79236031], [73.31485748, 16.79236031], [73.31485748, 16.79264069], [73.31513977, 16.79263878], [73.31513977, 16.79291725], [73.31541443, 16.79291725], [73.31541443, 16.79319572], [73.31569672, 16.79319572], [73.31569672, 16.79347229], [73.31597137, 16.79347038], [73.31597137, 16.79375076], [73.31624603, 16.79375076], [73.31624603, 16.79430962], [73.31652832, 16.7943058], [73.31652832, 16.79458237], [73.31708527, 16.79458427], [73.31708527, 16.79486084], [73.31735992, 16.79486084], [73.31735992, 16.79514122], [73.31764221, 16.79514122], [73.31764221, 16.79652977], [73.31735992, 16.79652977], [73.31735992, 16.79680824], [73.31708527, 16.79680634], [73.31708527, 16.79736137], [73.31680298, 16.79735947], [73.31680298, 16.79791832], [73.31652832, 16.79791832], [73.31652832, 16.80042076], [73.31624603, 16.80042076], [73.31624603, 16.80181122], [73.31652832, 16.80181122], [73.31652832, 16.80236053], [73.31680298, 16.80236053], [73.31680298, 16.80319214], [73.3170929, 16.80319023], [73.3170929, 16.80402946], [73.31735992, 16.80402946], [73.31735992, 16.80430984], [73.31764221, 16.80430603], [73.31764221, 16.80597305], [73.31817627, 16.80597115], [73.31817627, 16.80624962], [73.31846619, 16.80624962], [73.31846619, 16.80653], [73.31903076, 16.80652809], [73.31903076, 16.80680656], [73.31952667, 16.80680656], [73.32013702, 16.80680656], [73.32013702, 16.80708313], [73.32096863, 16.80708313], [73.32096863, 16.8073616], [73.3215332, 16.8073597], [73.3215332, 16.80764008], [73.32180786, 16.80764008], [73.32180786, 16.80792046], [73.32235718, 16.80792046], [73.32235718, 16.80821037], [73.32263947, 16.80819511], [73.32263947, 16.80847168], [73.32290649, 16.80846977], [73.32290649, 16.80903053], [73.32319641, 16.80902863], [73.32319641, 16.80958366], [73.32347107, 16.80957985], [73.32347107, 16.80986023], [73.32375336, 16.80986023], [73.32375336, 16.81014061], [73.32402802, 16.81014061], [73.32402802, 16.81041908], [73.32430267, 16.81041718], [73.32430267, 16.81069374], [73.32458496, 16.81069374], [73.32458496, 16.81125069], [73.32485962, 16.81125069], [73.32485962, 16.81180763], [73.32514191, 16.81180573], [73.32514191, 16.8120842], [73.32541656, 16.81208038], [73.32541656, 16.81236076], [73.32569122, 16.81236076], [73.32569122, 16.81263924], [73.32624817, 16.81263924], [73.32624817, 16.81292152], [73.32958221, 16.81292152], [73.32958221, 16.81263924], [73.33069611, 16.81263924], [73.33069611, 16.81236076], [73.33152771, 16.81236076], [73.33152771, 16.81292152], [73.33180237, 16.8129158], [73.33180237, 16.81347275], [73.33208466, 16.81347275], [73.33208466, 16.81402779], [73.33235931, 16.81402779], [73.33235931, 16.81458282], [73.3326416, 16.81458092], [73.3326416, 16.81514168], [73.33291626, 16.81514168], [73.33291626, 16.81569481], [73.33319092, 16.8156929], [73.33319092, 16.81653023], [73.3326416, 16.81652832], [73.3326416, 16.81708145], [73.33235931, 16.81708145], [73.33235931, 16.81736374], [73.33207703, 16.81735992], [73.33207703, 16.81792068], [73.33180237, 16.81792068], [73.33180237, 16.81820107], [73.33152771, 16.81820107], [73.33152771, 16.81875038], [73.33125305, 16.81875038], [73.33125305, 16.81903076], [73.33097076, 16.81902695], [73.33097076, 16.8195858], [73.33069611, 16.81958008], [73.33069611, 16.81986046], [73.32985687, 16.81986046], [73.32985687, 16.82015038], [73.3290329, 16.82015038], [73.3290329, 16.82042122], [73.32847595, 16.8204174], [73.32847595, 16.82069588], [73.32653046, 16.82069588], [73.32653046, 16.82013893], [73.32624817, 16.82015038], [73.32624817, 16.81931114], [73.32596588, 16.81931114], [73.32596588, 16.81820107], [73.32569122, 16.81820107], [73.32569122, 16.81792068], [73.32541656, 16.81792068], [73.32541656, 16.8176403], [73.32514191, 16.8176403], [73.32514191, 16.81735992], [73.32458496, 16.81736374], [73.32458496, 16.81680489], [73.32430267, 16.81680489], [73.32430267, 16.81652832], [73.32402802, 16.81653023], [73.32402802, 16.8156929], [73.32375336, 16.81569481], [73.32375336, 16.81541634], [73.32347107, 16.81542015], [73.32347107, 16.81458092], [73.32319641, 16.81458282], [73.32319641, 16.81374931], [73.32290649, 16.81374931], [73.32290649, 16.81319046], [73.32263947, 16.81319427], [73.32263947, 16.81263924], [73.32235718, 16.81263924], [73.32235718, 16.81236076], [73.32208252, 16.81236076], [73.32208252, 16.81180763], [73.3215332, 16.81180763], [73.3215332, 16.81125069], [73.32096863, 16.81125069], [73.32096863, 16.81068993], [73.32069397, 16.81069374], [73.32069397, 16.81041718], [73.32041931, 16.81041908], [73.32041931, 16.81014061], [73.31986237, 16.81014061], [73.31986237, 16.80986023], [73.31874847, 16.80986023], [73.31874847, 16.80957985], [73.31791687, 16.80958366], [73.31791687, 16.80902863], [73.31764221, 16.80903053], [73.31764221, 16.80875015], [73.31708527, 16.80875015], [73.31708527, 16.80847168], [73.31680298, 16.80847168], [73.31680298, 16.80819511], [73.31652832, 16.80821037], [73.31652832, 16.80792046], [73.31624603, 16.80792046], [73.31624603, 16.80764008], [73.31597137, 16.80764008], [73.31597137, 16.8073597], [73.31569672, 16.8073616], [73.31569672, 16.80708313], [73.31236267, 16.80708313], [73.31236267, 16.80680656], [73.31124878, 16.80680656], [73.31124878, 16.80708313], [73.31069183, 16.80708313], [73.31069183, 16.8073616], [73.31041718, 16.8073597], [73.31041718, 16.80764008], [73.30986023, 16.80764008], [73.30986023, 16.80792046], [73.30931091, 16.80792046], [73.30931091, 16.80821037], [73.30902863, 16.80819511], [73.30902863, 16.80847168], [73.30819702, 16.80846977], [73.30819702, 16.80875015], [73.3034668, 16.80875015], [73.3034668, 16.80903053], [73.30317688, 16.80903053], [73.30317688, 16.80931091], [73.30263519, 16.80930519], [73.30263519, 16.80958366], [73.30236053, 16.80957985], [73.30236053, 16.80986023], [73.30179596, 16.80986023], [73.30179596, 16.81014061], [73.30152893, 16.81014061], [73.30152893, 16.81041908], [73.30124664, 16.81041718], [73.30124664, 16.81069374], [73.30097198, 16.81068993], [73.30097198, 16.81097984], [73.30041504, 16.81097221], [73.3004303, 16.81125069], [73.30014038, 16.81125069], [73.30014038, 16.81152916], [73.29985809, 16.81152916], [73.29985809, 16.81180763], [73.29958344, 16.81180573], [73.29958344, 16.8120842], [73.29930878, 16.81208038], [73.29930878, 16.81236076], [73.29902649, 16.81236076], [73.29902649, 16.81263924], [73.29875183, 16.81263924], [73.29875183, 16.81292152], [73.29846954, 16.8129158], [73.29846954, 16.81319427], [73.29819489, 16.81319427], [73.29819489, 16.81347275], [73.29792023, 16.81347084], [73.29792023, 16.81374931], [73.29763794, 16.81374931], [73.29763794, 16.81402779], [73.29737091, 16.81401825], [73.29737091, 16.81431007], [73.29708099, 16.81430626], [73.29708099, 16.81458282], [73.29680634, 16.81458092], [73.29680634, 16.81514168], [73.29651642, 16.81514168], [73.29651642, 16.81542015], [73.29624939, 16.81541634], [73.29624939, 16.81569481], [73.2959671, 16.8156929], [73.2959671, 16.81625175], [73.29569244, 16.81625175], [73.29569244, 16.81680489], [73.29541779, 16.81679153], [73.29541779, 16.81903076], [73.29514313, 16.81903076], [73.29514313, 16.82152939], [73.29541779, 16.82152748], [73.29541779, 16.82208252], [73.2959671, 16.82208061], [73.2959671, 16.82236099], [73.29651642, 16.82236099], [73.29651642, 16.82263947], [73.29680634, 16.82263947], [73.29680634, 16.82291985], [73.29708099, 16.82291985], [73.29708099, 16.82402992], [73.29680634, 16.82402992], [73.29680634, 16.8243103], [73.29652405, 16.82430649], [73.29652405, 16.82486153], [73.29624939, 16.82485962], [73.29624939, 16.82681084], [73.29652405, 16.82680511], [73.29652405, 16.82819366], [73.29624939, 16.82819366], [73.29624939, 16.82847023], [73.2959671, 16.82847023], [73.2959671, 16.82875252], [73.29569244, 16.82875252], [73.29569244, 16.82902718], [73.29541779, 16.82902145], [73.29541779, 16.82930946], [73.2951355, 16.82930565], [73.29514313, 16.82986259], [73.29486084, 16.82986259], [73.29486084, 16.83014107], [73.29458618, 16.83014107], [73.29458618, 16.83041954], [73.29430389, 16.83041763], [73.29430389, 16.83097458], [73.29402924, 16.83097076], [73.29402924, 16.83181], [73.29429626, 16.83181], [73.29429626, 16.83292007], [73.29458618, 16.83292007], [73.29458618, 16.83374977], [73.29429626, 16.83374977], [73.29429626, 16.83403015], [73.29374695, 16.83402824], [73.29374695, 16.83430672], [73.29347229, 16.83430672], [73.29347229, 16.83458328], [73.29319763, 16.83458328], [73.29319763, 16.83486176], [73.29292297, 16.83485985], [73.29292297, 16.83542061], [73.29264069, 16.83542061], [73.29264069, 16.83625031], [73.29291534, 16.83625031], [73.29291534, 16.83736038], [73.29319763, 16.83736038], [73.29319763, 16.83819389], [73.29402924, 16.83818817], [73.29402924, 16.83875084], [73.29374695, 16.83875084], [73.29374695, 16.8393116], [73.29347229, 16.8393116], [73.29347229, 16.83986092], [73.29319763, 16.83986092], [73.29319763, 16.84042168], [73.29291534, 16.84041595], [73.29291534, 16.8409729], [73.29264069, 16.84095955], [73.29264069, 16.84153175], [73.2923584, 16.84152794], [73.2923584, 16.84208107], [73.29207611, 16.84207916], [73.29207611, 16.84264183], [73.29180908, 16.84264183], [73.29180908, 16.8429203], [73.29152679, 16.8429203], [73.29152679, 16.84320068], [73.29125214, 16.84319305], [73.29125214, 16.84347153], [73.29096985, 16.84346962], [73.29096985, 16.84375191], [73.29013824, 16.84375191], [73.29013824, 16.84346962], [73.28986359, 16.84347153], [73.28986359, 16.84319305], [73.2895813, 16.84320068], [73.2895813, 16.8429203], [73.28901672, 16.8429203], [73.28901672, 16.84320068], [73.28819275, 16.84319305], [73.28819275, 16.84347153], [73.28791809, 16.84347153], [73.28791809, 16.84486389], [73.28820038, 16.84486008], [73.28820038, 16.84514046], [73.2884903, 16.84514046], [73.2884903, 16.84542084], [73.28874969, 16.84541702], [73.28874969, 16.8456955], [73.28930664, 16.8456955], [73.28930664, 16.84597206], [73.28985596, 16.84597015], [73.28985596, 16.84653091], [73.2904129, 16.84653091], [73.2904129, 16.84680939], [73.29070282, 16.84680939], [73.29070282, 16.84708977], [73.29123688, 16.84708977], [73.29123688, 16.84736061], [73.29152679, 16.84736061], [73.29152679, 16.84764099], [73.29207611, 16.84764099], [73.29207611, 16.84791946], [73.2923584, 16.84791756], [73.2923584, 16.84819412], [73.29264069, 16.84819412], [73.29264069, 16.8484726], [73.29292297, 16.84847069], [73.29292297, 16.84902954], [73.29319763, 16.84902763], [73.29319763, 16.84958267], [73.29292297, 16.84958076], [73.29292297, 16.85152817], [73.29264069, 16.85152817], [73.29264069, 16.85180473], [73.29180908, 16.85180473], [73.29180908, 16.85152817], [73.29152679, 16.85152817], [73.29152679, 16.85124969], [73.29070282, 16.85124969], [73.29070282, 16.85152817], [73.2904129, 16.85152817], [73.2904129, 16.85208321], [73.29013824, 16.85207939], [73.29013824, 16.85292053], [73.29096985, 16.85291672], [73.29096985, 16.85319519], [73.2923584, 16.85319519], [73.2923584, 16.85347176], [73.29264069, 16.85346985], [73.29264069, 16.85542107], [73.2923584, 16.85541725], [73.2923584, 16.85569382], [73.29208374, 16.85569382], [73.29208374, 16.85597038], [73.29096985, 16.85597038], [73.29096985, 16.8562603], [73.28985596, 16.8562603], [73.28985596, 16.85653114], [73.28930664, 16.85653114], [73.28930664, 16.85680962], [73.28820038, 16.85680962], [73.28820038, 16.85764122], [73.28791809, 16.85763931], [73.28791809, 16.85819244], [73.28847504, 16.85819244], [73.28847504, 16.85847473], [73.28874969, 16.85847092], [73.28874969, 16.85874939], [73.28930664, 16.85874939], [73.28930664, 16.85902977], [73.28985596, 16.85902977], [73.28985596, 16.85931969], [73.29069519, 16.85930634], [73.29069519, 16.85958481], [73.29152679, 16.85958481], [73.29152679, 16.85986137], [73.29207611, 16.85985947], [73.29207611, 16.86013985], [73.29347229, 16.86013985], [73.29347229, 16.85985947], [73.29402924, 16.85986137], [73.29402924, 16.85930634], [73.29429626, 16.85931969], [73.29429626, 16.85847092], [73.29458618, 16.85847473], [73.29458618, 16.85819244], [73.2951355, 16.85819244], [73.2951355, 16.85958481], [73.29486084, 16.85958481], [73.29486084, 16.86208344], [73.29458618, 16.86207008], [73.29458618, 16.86375046], [73.29429626, 16.86375046], [73.29429626, 16.86403084], [73.29402924, 16.86403084], [73.29402924, 16.86653137], [73.29374695, 16.86653137], [73.29374695, 16.86763954], [73.29347229, 16.86763954], [73.29347229, 16.8682003], [73.29319763, 16.86819458], [73.29319763, 16.86986351], [73.29292297, 16.8698597], [73.29292297, 16.87070084], [73.29264069, 16.87069321], [73.29264069, 16.87097359], [73.29207611, 16.87096977], [73.29207611, 16.87125969], [73.29152679, 16.87125969], [73.29152679, 16.87070084], [73.29125214, 16.87069321], [73.29125214, 16.87097359], [73.29096985, 16.87097359], [73.29096985, 16.87041664], [73.29013824, 16.87042046], [73.29013824, 16.87070084], [73.2895813, 16.87069321], [73.2895813, 16.87097359], [73.28930664, 16.87097359], [73.28930664, 16.87208557], [73.28901672, 16.87207985], [73.28901672, 16.87264061], [73.28874969, 16.87264061], [73.28874969, 16.87292099], [73.28847504, 16.87291718], [73.28847504, 16.87319565], [73.28624725, 16.87319565], [73.28624725, 16.87347221], [73.2859726, 16.87347031], [73.2859726, 16.87625122], [73.28624725, 16.87625122], [73.28624725, 16.87680817], [73.28652954, 16.87680626], [73.28652954, 16.87708282], [73.2868042, 16.87708282], [73.2868042, 16.87819481], [73.28652954, 16.87819481], [73.28652954, 16.87847137], [73.28624725, 16.87847137], [73.28624725, 16.87930489], [73.2859726, 16.87930489], [73.2859726, 16.87958336], [73.28569794, 16.87957954], [73.28569794, 16.88070107], [73.2859726, 16.88070107], [73.2859726, 16.88125038], [73.28624725, 16.88125038], [73.28624725, 16.88153267], [73.28652954, 16.88153267], [73.28652954, 16.88181114], [73.28708649, 16.88180542], [73.28708649, 16.88208389], [73.28736115, 16.88208008], [73.28736115, 16.88236046], [73.2876358, 16.88236046], [73.2876358, 16.88264275], [73.2884903, 16.88264275], [73.2884903, 16.88292122], [73.28901672, 16.88292122], [73.28901672, 16.88319969], [73.28986359, 16.88319206], [73.28986359, 16.88347054], [73.29069519, 16.88347054], [73.29069519, 16.88375282], [73.29123688, 16.88375282], [73.29123688, 16.88402939], [73.29152679, 16.88402939], [73.29152679, 16.88430977], [73.29180908, 16.88430405], [73.29180908, 16.88458443], [73.29207611, 16.88458061], [73.29207611, 16.8848629], [73.29264069, 16.8848629], [73.29264069, 16.88513947], [73.29291534, 16.88513947], [73.29291534, 16.8856926], [73.29319763, 16.88569069], [73.29319763, 16.88652992], [73.29347229, 16.88652802], [73.29347229, 16.88708305], [73.29374695, 16.88708115], [73.29374695, 16.88764], [73.29402924, 16.88764], [73.29402924, 16.88792038], [73.29458618, 16.88792038], [73.29458618, 16.88820076], [73.2951355, 16.88819695], [73.2951355, 16.8884716], [73.29541779, 16.8884697], [73.29541779, 16.88875008], [73.29597473, 16.88875008], [73.29597473, 16.88930511], [73.29652405, 16.88930511], [73.29652405, 16.88958359], [73.29680634, 16.88957977], [73.29680634, 16.88986015], [73.29792023, 16.88986015], [73.29792023, 16.89014053], [73.30014038, 16.89014053], [73.30014038, 16.89042091], [73.30097198, 16.8904171], [73.30097198, 16.89069366], [73.30180359, 16.89069366], [73.30180359, 16.8904171], [73.30291748, 16.89042091], [73.30291748, 16.89014053], [73.30374908, 16.89014053], [73.30374908, 16.88986015], [73.30403137, 16.88986015], [73.30403137, 16.88957977], [73.30458069, 16.88958359], [73.30458069, 16.88930511], [73.30625153, 16.88930511], [73.30625153, 16.88958359], [73.30652618, 16.88957977], [73.30652618, 16.88986015], [73.30680847, 16.88986015], [73.30680847, 16.89014053], [73.30735779, 16.89014053], [73.30735779, 16.89042091], [73.30764008, 16.89042091], [73.30764008, 16.89014053], [73.30819702, 16.89014053], [73.30819702, 16.89042091], [73.30874634, 16.89042091], [73.30874634, 16.89014053], [73.31014252, 16.89014053], [73.31014252, 16.88986015], [73.31069183, 16.88986015], [73.31069183, 16.88957977], [73.31124878, 16.88958359], [73.31124878, 16.88930511], [73.31180573, 16.88930511], [73.31180573, 16.88875008], [73.31208038, 16.88875008], [73.31208038, 16.88820076], [73.3123703, 16.88820076], [73.3123703, 16.88764], [73.31291962, 16.88764], [73.31291962, 16.88792038], [73.31346893, 16.88792038], [73.31346893, 16.88903046], [73.31319427, 16.88902855], [73.31319427, 16.88958359], [73.31263733, 16.88958359], [73.31263733, 16.88986206], [73.3123703, 16.88986015], [73.3123703, 16.89014053], [73.31181335, 16.89014053], [73.31181335, 16.89042091], [73.31153107, 16.8904171], [73.31153107, 16.89069366], [73.31097412, 16.89069366], [73.31097412, 16.89097214], [73.31041718, 16.89097023], [73.31041718, 16.89125061], [73.30902863, 16.89125061], [73.30902863, 16.89152908], [73.30647278, 16.89152718], [73.30625153, 16.89152718], [73.30625153, 16.89125061], [73.30596924, 16.89125061], [73.30596924, 16.89145088], [73.30596924, 16.89152718], [73.30568695, 16.89152908], [73.30568695, 16.89141273], [73.30569458, 16.89125061], [73.30465698, 16.89125061], [73.30430603, 16.89125061], [73.30430603, 16.89097214], [73.30374908, 16.89097214], [73.30374908, 16.89110947], [73.30374908, 16.89125061], [73.30317688, 16.89125061], [73.30317688, 16.89152908], [73.30264282, 16.89152908], [73.30264282, 16.89180756], [73.30208588, 16.89180565], [73.30208588, 16.89208412], [73.30152893, 16.89208031], [73.30152893, 16.89236069], [73.30097198, 16.89236069], [73.30097198, 16.89263916], [73.30041504, 16.89263916], [73.30041504, 16.8931942], [73.30014038, 16.8931942], [73.30014038, 16.89347267], [73.29985809, 16.89347076], [73.29985809, 16.89374924], [73.29958344, 16.89374924], [73.29958344, 16.89458275], [73.29930878, 16.89458084], [73.29930878, 16.89485931], [73.29902649, 16.89485931], [73.29902649, 16.8951416], [73.29875183, 16.8951416], [73.29875183, 16.89542961], [73.29846954, 16.89541626], [73.29846954, 16.89569473], [73.29818726, 16.89569283], [73.29818726, 16.89624977], [73.29792023, 16.89624977], [73.29792023, 16.89653015], [73.29763794, 16.89652824], [73.29763794, 16.89680481], [73.29708099, 16.89680481], [73.29708099, 16.89708138], [73.29652405, 16.89708138], [73.29652405, 16.89736366], [73.29569244, 16.89735985], [73.29569244, 16.89764023], [73.29476929, 16.89763832], [73.29374695, 16.89764023], [73.29374695, 16.89792061], [73.29347229, 16.89792061], [73.29347229, 16.89764023], [73.29152679, 16.89764023], [73.29152679, 16.89735985], [73.29069519, 16.89736366], [73.29069519, 16.89680481], [73.2904129, 16.89680481], [73.2904129, 16.89652824], [73.2895813, 16.89653015], [73.2895813, 16.89624977], [73.28901672, 16.89624977], [73.28901672, 16.89653015], [73.28847504, 16.89652824], [73.28847504, 16.89680481], [73.2876358, 16.89680481], [73.2876358, 16.89652824], [73.28736115, 16.89653015], [73.28736115, 16.89624977], [73.28708649, 16.89624977], [73.28708649, 16.89596939], [73.28736115, 16.8959713], [73.28736115, 16.89569473], [73.2876358, 16.89569473], [73.2876358, 16.89374924], [73.28736115, 16.89374924], [73.28736115, 16.89319038], [73.28708649, 16.8931942], [73.28708649, 16.89291763], [73.28652954, 16.89292145], [73.28652954, 16.89263916], [73.28543091, 16.89263916], [73.28543091, 16.89292145], [73.28514099, 16.89291763], [73.28514099, 16.8931942], [73.2848587, 16.8931942], [73.2848587, 16.89291763], [73.28347015, 16.89292145], [73.28347015, 16.89263916], [73.28320313, 16.89263916], [73.28320313, 16.89208031], [73.28236389, 16.89208412], [73.28236389, 16.89180565], [73.28151703, 16.89180756], [73.28151703, 16.89152908], [73.28069305, 16.89152908], [73.28069305, 16.89180756], [73.2804184, 16.89180565], [73.2804184, 16.89208412], [73.27986145, 16.89208412], [73.27986145, 16.89180565], [73.27958679, 16.89180756], [73.27958679, 16.89152908], [73.2784729, 16.89152908], [73.2784729, 16.89180756], [73.27819824, 16.89180565], [73.27819824, 16.89208412], [73.27708435, 16.89208412], [73.27708435, 16.89347267], [73.27735901, 16.89347076], [73.27735901, 16.89403152], [73.2776413, 16.89403152], [73.2776413, 16.8943119], [73.27791595, 16.8943119], [73.27791595, 16.89485931], [73.27819824, 16.89485931], [73.27819824, 16.8951416], [73.2784729, 16.8951416], [73.2784729, 16.89542961], [73.27874756, 16.89541626], [73.27874756, 16.8959713], [73.27902985, 16.89596939], [73.27902985, 16.89624977], [73.27929688, 16.89624977], [73.27929688, 16.89653015], [73.27958679, 16.89652824], [73.27958679, 16.89680481], [73.27986145, 16.89680481], [73.27986145, 16.89708138], [73.28013611, 16.89708138], [73.28013611, 16.89847374], [73.27986145, 16.89846992], [73.27986145, 16.89875031], [73.27958679, 16.89875031], [73.27958679, 16.90263939], [73.2793045, 16.90263939], [73.2793045, 16.90319443], [73.27902985, 16.90319061], [73.27902985, 16.90402985], [73.2793045, 16.90402794], [73.2793045, 16.90430641], [73.27958679, 16.90430641], [73.27958679, 16.90486145], [73.27986145, 16.90486145], [73.27986145, 16.90458298], [73.28013611, 16.90458298], [73.28013611, 16.90486145], [73.2804184, 16.90485954], [73.2804184, 16.90513992], [73.28069305, 16.90513992], [73.28069305, 16.90570068], [73.28097534, 16.90569496], [73.28097534, 16.90597153], [73.28125, 16.90596962], [73.28125, 16.90624809], [73.28206635, 16.90624809], [73.28206635, 16.90652847], [73.28263855, 16.90652847], [73.28263855, 16.90681076], [73.28291321, 16.90680504], [73.28291321, 16.90708351], [73.28320313, 16.9070797], [73.28320313, 16.90736961], [73.28347015, 16.90736961], [73.28347015, 16.90764236], [73.28375244, 16.90764236], [73.28375244, 16.90792274], [73.2840271, 16.90792274], [73.2840271, 16.90986061], [73.28375244, 16.90986061], [73.28375244, 16.9101429], [73.2840271, 16.91013908], [73.2840271, 16.91069221], [73.28430176, 16.91069221], [73.28430939, 16.91124916], [73.28430939, 16.91152954], [73.28457642, 16.91152954], [73.28457642, 16.91180992], [73.2848587, 16.91180992], [73.2848587, 16.91236115], [73.28541565, 16.91236115], [73.28541565, 16.91263962], [73.28569794, 16.91263962], [73.28569794, 16.91319466], [73.28543091, 16.9131794], [73.28543091, 16.91403008], [73.28514099, 16.91402817], [73.28514099, 16.91458321], [73.2848587, 16.91457939], [73.2848587, 16.91514015], [73.28514099, 16.91514015], [73.28514099, 16.91542053], [73.28543091, 16.91542053], [73.28543091, 16.91570091], [73.2859726, 16.91569519], [73.2859726, 16.91597176], [73.28652954, 16.91597176], [73.28652954, 16.91625023], [73.28679657, 16.91624069], [73.28679657, 16.91764069], [73.28652954, 16.91764069], [73.28652954, 16.91931152], [73.28624725, 16.91931152], [73.28624725, 16.92013931], [73.2859726, 16.92013931], [73.2859726, 16.9204216], [73.28569794, 16.92041588], [73.28569794, 16.92069435], [73.28541565, 16.92069435], [73.28541565, 16.92097282], [73.28457642, 16.92097092], [73.28457642, 16.92181015], [73.28430939, 16.92181015], [73.28430176, 16.92237282], [73.2840271, 16.92237282], [73.2840271, 16.92292023], [73.28347015, 16.92291641], [73.28347015, 16.92347145], [73.2831955, 16.92347145], [73.28320313, 16.92374992], [73.28291321, 16.92374992], [73.28291321, 16.92431068], [73.28263855, 16.92430305], [73.28263855, 16.92486382], [73.28236389, 16.92486382], [73.28236389, 16.92569542], [73.28263855, 16.92569542], [73.28263855, 16.92597389], [73.28291321, 16.92597008], [73.28291321, 16.92653084], [73.28263855, 16.92653084], [73.28263855, 16.92681122], [73.28236389, 16.9268055], [73.28236389, 16.92708588], [73.28206635, 16.92708015], [73.28206635, 16.92930984], [73.28235626, 16.92930984], [73.28235626, 16.93041992], [73.28263855, 16.93041992], [73.28263855, 16.93124962], [73.28320313, 16.93124962], [73.28320313, 16.93154144], [73.28375244, 16.93152809], [73.28375244, 16.93180466], [73.28514099, 16.93180466], [73.28514099, 16.93208313], [73.28541565, 16.93208313], [73.28541565, 16.93180466], [73.28569794, 16.93180466], [73.28569794, 16.93152809], [73.2868042, 16.93152809], [73.2868042, 16.93180466], [73.28708649, 16.93180084], [73.28708649, 16.93291855], [73.28736115, 16.93291855], [73.28736115, 16.93514252], [73.28708649, 16.9351387], [73.28708649, 16.93597031], [73.28679657, 16.93597031], [73.28679657, 16.93625259], [73.28652954, 16.93625259], [73.28652954, 16.93708229], [73.28624725, 16.93708229], [73.28624725, 16.93736076], [73.2859726, 16.93734932], [73.2859726, 16.93875122], [73.28569794, 16.93875122], [73.28569794, 16.93931007], [73.28541565, 16.93930626], [73.28541565, 16.9398613], [73.28514099, 16.93985939], [73.28514099, 16.94013977], [73.2848587, 16.94013977], [73.2848587, 16.94069672], [73.28458405, 16.94069672], [73.28458405, 16.94097137], [73.28430939, 16.94096947], [73.28430176, 16.94153023], [73.28375244, 16.94152832], [73.28375244, 16.94180679], [73.28347015, 16.94180679], [73.28347015, 16.94208336], [73.28375244, 16.94207954], [73.28375244, 16.94292068], [73.2840271, 16.94292068], [73.2840271, 16.94320107], [73.28430176, 16.94320107], [73.28430939, 16.94347954], [73.28457642, 16.94347954], [73.28457642, 16.94375038], [73.28430939, 16.94375038], [73.28430176, 16.94431114], [73.2840271, 16.94431114], [73.2840271, 16.94542122], [73.28347015, 16.9454174], [73.28347015, 16.94597244], [73.28320313, 16.94597054], [73.28320313, 16.94681168], [73.28291321, 16.94680595], [73.28291321, 16.94708252], [73.28263855, 16.94708061], [73.28263855, 16.94735909], [73.28235626, 16.94735909], [73.28235626, 16.94763947], [73.28206635, 16.94763947], [73.28206635, 16.94792175], [73.28180695, 16.94791603], [73.28180695, 16.94958115], [73.28206635, 16.94958115], [73.28206635, 16.95042038], [73.28235626, 16.95042038], [73.28235626, 16.95125008], [73.28263855, 16.95125008], [73.28263855, 16.95181084], [73.28291321, 16.95180321], [73.28291321, 16.95236015], [73.28320313, 16.95235062], [73.28320313, 16.95264053], [73.28347015, 16.95264053], [73.28347015, 16.95292091], [73.28375244, 16.9529171], [73.28375244, 16.95347214], [73.28430176, 16.95347023], [73.28430939, 16.95375061], [73.2848587, 16.95375061], [73.2848587, 16.95347023], [73.28514099, 16.95347214], [73.28514099, 16.95319557], [73.28541565, 16.95319557], [73.28541565, 16.9529171], [73.28569794, 16.95292091], [73.28569794, 16.95264053], [73.2859726, 16.95264053], [73.2859726, 16.95235062], [73.28624725, 16.95236015], [73.28624725, 16.95208549], [73.28819275, 16.95208549], [73.28819275, 16.95319557], [73.28847504, 16.95319557], [73.28847504, 16.95347214], [73.28874969, 16.95347023], [73.28874969, 16.95430946], [73.28902435, 16.95430565], [73.28902435, 16.95458412], [73.28930664, 16.95458031], [73.28930664, 16.95486069], [73.2895813, 16.95486069], [73.2895813, 16.95514107], [73.28985596, 16.95514107], [73.28985596, 16.95541954], [73.2904129, 16.95541763], [73.2904129, 16.9556942], [73.29152679, 16.95569038], [73.29152679, 16.95625114], [73.29180908, 16.95625114], [73.29180908, 16.95680809], [73.29208374, 16.95680618], [73.29208374, 16.95930481], [73.29180908, 16.95929909], [73.29180908, 16.96264267], [73.29152679, 16.96263885], [73.29152679, 16.96347046], [73.29180908, 16.96347046], [73.29180908, 16.96375275], [73.29207611, 16.96375275], [73.29207611, 16.96403122], [73.2923584, 16.9640274], [73.2923584, 16.96458244], [73.29264069, 16.96458054], [73.29264069, 16.96486282], [73.29291534, 16.96486282], [73.29291534, 16.96513939], [73.29319763, 16.96513939], [73.29319763, 16.96541977], [73.29347229, 16.96541977], [73.29347229, 16.96624947], [73.29374695, 16.96624947], [73.29374695, 16.96681023], [73.29402924, 16.96681023], [73.29402924, 16.96763992], [73.29374695, 16.96763802], [73.29374695, 16.96958351], [73.29430389, 16.96958351], [73.29430389, 16.96986198], [73.29402924, 16.96986008], [73.29402924, 16.97180748], [73.29374695, 16.97180748], [73.29374695, 16.97236061], [73.29402924, 16.97236061], [73.29402924, 16.97292137], [73.29374695, 16.97292137], [73.29374695, 16.97403145], [73.29402924, 16.97403145], [73.29402924, 16.97764015], [73.29374695, 16.97764015], [73.29374695, 16.97820091], [73.29402924, 16.97820091], [73.29402924, 16.97875023], [73.29430389, 16.97875023], [73.29430389, 16.97958565], [73.29458618, 16.97957993], [73.29458618, 16.98042107], [73.29486084, 16.98042107], [73.29486084, 16.98125076], [73.29458618, 16.98125076], [73.29458618, 16.98153114], [73.29430389, 16.98152733], [73.29430389, 16.98597145], [73.29374695, 16.98596954], [73.29374695, 16.98624992], [73.29347229, 16.98624992], [73.29347229, 16.9865284], [73.29319763, 16.9865284], [73.29319763, 16.98681068], [73.29291534, 16.98680496], [73.29291534, 16.98708344], [73.29264069, 16.98708344], [73.29264069, 16.98736191], [73.2923584, 16.98735809], [73.2923584, 16.98764229], [73.29207611, 16.98764229], [73.29207611, 16.98792267], [73.29196167, 16.98791695], [73.29152679, 16.98791695], [73.29152679, 16.9881916], [73.29125214, 16.98819542], [73.29125214, 16.98847008], [73.29069519, 16.98847008], [73.29070282, 16.98875046], [73.2904129, 16.98875046], [73.2904129, 16.98903275], [73.28457642, 16.98903275], [73.28457642, 16.98931122], [73.2840271, 16.9893055], [73.2840271, 16.98958206], [73.28375244, 16.98958015], [73.28375244, 16.98986053], [73.28336334, 16.98986053], [73.28291321, 16.98986053], [73.28291321, 16.99014282], [73.28263855, 16.99014282], [73.28263855, 16.99041939], [73.28236389, 16.99041748], [73.28236389, 16.99069214], [73.2820816, 16.99069214], [73.2820816, 16.99097443], [73.28180695, 16.99097061], [73.28180695, 16.9912529], [73.28125, 16.9912529], [73.28125, 16.99152946], [73.28069305, 16.99152946], [73.28069305, 16.99180984], [73.2804184, 16.99180412], [73.2804184, 16.9920845], [73.27986145, 16.99208069], [73.27986145, 16.99236107], [73.27791595, 16.99236107], [73.27791595, 16.99208069], [73.27680206, 16.9920845], [73.27680206, 16.99124908], [73.2765274, 16.9912529], [73.2765274, 16.99097061], [73.27625275, 16.99097443], [73.27625275, 16.99069214], [73.27597046, 16.99069214], [73.27597046, 16.99013901], [73.2756958, 16.99014282], [73.2756958, 16.98958015], [73.27513885, 16.98958206], [73.27513885, 16.98902702], [73.27485657, 16.98903275], [73.27485657, 16.98820114], [73.27458191, 16.9881916], [73.27458191, 16.98763847], [73.27485657, 16.98764229], [73.27485657, 16.98735809], [73.27458191, 16.98736191], [73.27458191, 16.9865284], [73.27430725, 16.9865284], [73.27430725, 16.98624992], [73.27375031, 16.98624992], [73.27375031, 16.98569107], [73.2720871, 16.98569489], [73.2720871, 16.98597145], [73.27179718, 16.98596954], [73.27179718, 16.98624992], [73.27153015, 16.98624992], [73.27153015, 16.9865284], [73.27097321, 16.9865284], [73.27097321, 16.98708344], [73.27069092, 16.98707962], [73.27069092, 16.98792267], [73.27041626, 16.98791695], [73.27041626, 16.98847008], [73.27012634, 16.98846054], [73.27012634, 16.98931122], [73.26985931, 16.98931122], [73.26985931, 16.98986053], [73.26847076, 16.98986053], [73.26847076, 16.99014282], [73.26819611, 16.99014282], [73.26819611, 16.99236107], [73.26847076, 16.99236107], [73.26847076, 16.99319267], [73.26875305, 16.99319077], [73.26875305, 16.99514008], [73.26790619, 16.99514008], [73.26790619, 16.99653053], [73.26819611, 16.99653053], [73.26819611, 16.99681091], [73.26847076, 16.99681091], [73.26847076, 16.99764824], [73.26875305, 16.99764824], [73.26875305, 16.99791908], [73.26902771, 16.99791908], [73.26902771, 16.99930763], [73.26957703, 16.99930763], [73.26957703, 16.99986076], [73.26930237, 16.99986076], [73.26930237, 16.99999809], [73.26930237, 17.00013924], [73.26957703, 17.00013924], [73.26957703, 17.00042152], [73.26985931, 17.00042152], [73.26985931, 17.00013924], [73.27012634, 17.00013924], [73.27012634, 16.99986076], [73.27012634, 16.99930763], [73.27041626, 16.99930763], [73.27041626, 16.99902916], [73.27097321, 16.99902916], [73.27097321, 16.99930763], [73.27153015, 16.99930573], [73.27153015, 16.9995842], [73.27179718, 16.99958038], [73.27179718, 16.99986076], [73.27320099, 16.99986076], [73.27319336, 16.9976387], [73.27430725, 16.99764824], [73.27430725, 16.99791908], [73.27541351, 16.99791718], [73.27541351, 16.99819374], [73.2756958, 16.99819374], [73.2756958, 16.99847221], [73.27625275, 16.99847221], [73.27625275, 16.9995842], [73.27680206, 16.99958038], [73.27680206, 16.99986076], [73.27708435, 16.99986076], [73.27708435, 17.00097275], [73.2776413, 17.00097084], [73.2776413, 17.00124931], [73.27791595, 17.00124931], [73.27791595, 17.00069046], [73.27819061, 17.00069427], [73.27819824, 17.0004158], [73.28013611, 17.0004158], [73.28013611, 17.00069427], [73.28097534, 17.00069427], [73.28097534, 17.00097275], [73.28291321, 17.00097084], [73.28291321, 17.0015316], [73.28320313, 17.0015316], [73.28320313, 17.00181007], [73.28347015, 17.00180626], [73.28347015, 17.00208282], [73.28375244, 17.00208092], [73.28375244, 17.00403023], [73.2831955, 17.00402832], [73.2831955, 17.00458145], [73.28375244, 17.00457954], [73.28375244, 17.0051403], [73.28347015, 17.0051403], [73.28347015, 17.00542068], [73.28375244, 17.00542068], [73.28375244, 17.00625038], [73.2840271, 17.00625038], [73.2840271, 17.00819588], [73.28430176, 17.00819588], [73.28430176, 17.0106945], [73.2840271, 17.01069069], [73.2840271, 17.01124954], [73.28375244, 17.01124954], [73.28375244, 17.01208305], [73.28347015, 17.01208305], [73.28347015, 17.01263809], [73.28320313, 17.01263046], [73.28320313, 17.01320076], [73.28291321, 17.01320076], [73.28291321, 17.01374817], [73.28263855, 17.01374817], [73.28263855, 17.01402855], [73.28236389, 17.01402855], [73.28236389, 17.01458359], [73.2820816, 17.01458359], [73.2820816, 17.01486015], [73.28180695, 17.01486015], [73.28180695, 17.01625061], [73.28125, 17.01625061], [73.28125, 17.01680946], [73.28097534, 17.01680565], [73.28098297, 17.01736069], [73.28069305, 17.01736069], [73.28069305, 17.01756287], [73.28069305, 17.01763916], [73.2804184, 17.01763916], [73.2804184, 17.01819229], [73.28013611, 17.01819229], [73.28013611, 17.01847458], [73.27986145, 17.01847076], [73.27986145, 17.01876068], [73.27958679, 17.01876068], [73.27958679, 17.01931], [73.2793045, 17.01930618], [73.2793045, 17.01958466], [73.27902985, 17.01958084], [73.27902985, 17.01986122], [73.27874756, 17.01986122], [73.27874756, 17.02042007], [73.2784729, 17.02041435], [73.2784729, 17.0209713], [73.27819824, 17.02096939], [73.27819824, 17.02124977], [73.27791595, 17.02124977], [73.27791595, 17.02153015], [73.2776413, 17.02152824], [73.2776413, 17.02208328], [73.27735901, 17.02208328], [73.27735901, 17.02236176], [73.27707672, 17.02235985], [73.27707672, 17.02292061], [73.2765274, 17.02292061], [73.2765274, 17.02320099], [73.27625275, 17.02319527], [73.27625275, 17.02347183], [73.27458191, 17.02346992], [73.27458191, 17.02375031], [73.27347565, 17.02375031], [73.27347565, 17.02347183], [73.2729187, 17.02347183], [73.2729187, 17.02319527], [73.27263641, 17.02320099], [73.27263641, 17.02292061], [73.27236176, 17.02292061], [73.27236176, 17.02264023], [73.27124786, 17.02264023], [73.27124786, 17.02292061], [73.27153015, 17.02292061], [73.27153015, 17.02375031], [73.27124786, 17.02375031], [73.27124786, 17.02431107], [73.27069092, 17.02430534], [73.26902771, 17.02430534], [73.26902771, 17.02458382], [73.26652527, 17.02458382], [73.26652527, 17.02347183], [73.26625061, 17.02347183], [73.26625061, 17.02236176], [73.26597595, 17.02236176], [73.26597595, 17.02208328], [73.26569366, 17.02208328], [73.26569366, 17.02180672], [73.26541901, 17.02180672], [73.26541901, 17.02152824], [73.26513672, 17.02153015], [73.26513672, 17.02124977], [73.26486206, 17.02124977], [73.26486206, 17.02069092], [73.26457977, 17.02069664], [73.26457977, 17.02041435], [73.26291656, 17.02041435], [73.26291656, 17.02069664], [73.26235962, 17.02069664], [73.26235962, 17.0209713], [73.26097107, 17.0209713], [73.26097107, 17.02069664], [73.26041412, 17.02069664], [73.26041412, 17.02041435], [73.26013947, 17.02042007], [73.26013947, 17.02013969], [73.25958252, 17.02013969], [73.25958252, 17.01986122], [73.25875092, 17.01986122], [73.25875092, 17.01958084], [73.25736237, 17.01958084], [73.25736237, 17.02042007], [73.25708008, 17.02041435], [73.25708008, 17.0209713], [73.25681305, 17.02096939], [73.25681305, 17.02153015], [73.25653076, 17.02152824], [73.25653076, 17.02180672], [73.25624847, 17.02180672], [73.25624847, 17.02347183], [73.25596619, 17.02346992], [73.25596619, 17.02375031], [73.25569153, 17.02375031], [73.25569153, 17.02541924], [73.25541687, 17.02541733], [73.25541687, 17.02597237], [73.25512695, 17.02597046], [73.25512695, 17.02625084], [73.25485992, 17.02625084], [73.25485992, 17.02652931], [73.25458527, 17.0265274], [73.25458527, 17.02708244], [73.25430298, 17.02708054], [73.25430298, 17.02736092], [73.2545929, 17.02736092], [73.2545929, 17.02792168], [73.25514221, 17.02791595], [73.25514221, 17.0284729], [73.25541687, 17.02846909], [73.25541687, 17.02874947], [73.25569153, 17.02874947], [73.25569153, 17.02958107], [73.25596619, 17.02958107], [73.25596619, 17.0304203], [73.25624847, 17.03041649], [73.25624847, 17.03097153], [73.25653076, 17.03096962], [73.25653076, 17.03181076], [73.25681305, 17.03181076], [73.25681305, 17.03153038], [73.25736237, 17.03153038], [73.25736237, 17.03181076], [73.25763702, 17.03180313], [73.25763702, 17.0331955], [73.25736237, 17.03318977], [73.25736237, 17.03376007], [73.25763702, 17.03376007], [73.25763702, 17.03652954], [73.25736237, 17.03652954], [73.25736237, 17.03736115], [73.25708008, 17.03736115], [73.25708008, 17.03763962], [73.25680542, 17.03763962], [73.25680542, 17.03819466], [73.25708008, 17.03819466], [73.25708008, 17.03986168], [73.25681305, 17.03985977], [73.25681305, 17.04013824], [73.25653076, 17.04013824], [73.25653076, 17.04070091], [73.25624847, 17.04070091], [73.25624847, 17.04125023], [73.25569153, 17.04125023], [73.25569153, 17.0429306], [73.25541687, 17.0429306], [73.25541687, 17.04486084], [73.25569153, 17.04486084], [73.25569153, 17.04541969], [73.25596619, 17.04541969], [73.25596619, 17.04652977], [73.25569153, 17.04652786], [73.25569153, 17.04736137], [73.25596619, 17.04735947], [73.25596619, 17.04792023], [73.25624847, 17.04791641], [73.25624847, 17.04819679], [73.25653076, 17.04819679], [73.25653076, 17.04847145], [73.25680542, 17.04847145], [73.25680542, 17.04874992], [73.25791931, 17.04874992], [73.25791931, 17.04847145], [73.25846863, 17.04847145], [73.25846863, 17.04874992], [73.26041412, 17.04874992], [73.26041412, 17.04847145], [73.26152802, 17.04847145], [73.26152802, 17.04874992], [73.26180267, 17.04874039], [73.26180267, 17.0490303], [73.26209259, 17.0490303], [73.26209259, 17.04874039], [73.26347351, 17.04874992], [73.26347351, 17.04847145], [73.26403046, 17.04847145], [73.26403046, 17.04819679], [73.26457977, 17.04819679], [73.26457977, 17.04791641], [73.26541901, 17.04792023], [73.26541901, 17.04763985], [73.26597595, 17.04763985], [73.26597595, 17.04681015], [73.2665329, 17.04681015], [73.2665329, 17.04570007], [73.26680756, 17.04570007], [73.26680756, 17.04541969], [73.26706696, 17.04541969], [73.26706696, 17.04514122], [73.26790619, 17.04514122], [73.26790619, 17.04541969], [73.26847076, 17.04541969], [73.26847076, 17.04458046], [73.26875305, 17.04458237], [73.26875305, 17.04402733], [73.26902771, 17.04403114], [73.26902771, 17.04375267], [73.26930237, 17.04375267], [73.26930237, 17.04347038], [73.26985931, 17.04347038], [73.26985931, 17.04330063], [73.26985931, 17.04291725], [73.26957703, 17.0429306], [73.26957703, 17.04236031], [73.26930237, 17.04236031], [73.26930237, 17.04125023], [73.26902771, 17.04125023], [73.26902771, 17.04070091], [73.27012634, 17.04070091], [73.27012634, 17.03985977], [73.26958466, 17.03986168], [73.26958466, 17.03930473], [73.26985931, 17.03930473], [73.26985931, 17.03874969], [73.27070618, 17.03874969], [73.27179718, 17.03874969], [73.27179718, 17.03902817], [73.2720871, 17.03902817], [73.2720871, 17.03958321], [73.27263641, 17.03958321], [73.27263641, 17.03930473], [73.27319336, 17.03930473], [73.27319336, 17.03902817], [73.27349091, 17.03902817], [73.27349091, 17.03847122], [73.27375031, 17.03847313], [73.27375031, 17.03791618], [73.27403259, 17.03791809], [73.27403259, 17.03763962], [73.27430725, 17.03763962], [73.27430725, 17.03736115], [73.27485657, 17.03736115], [73.27485657, 17.03708076], [73.27513885, 17.03708267], [73.27513885, 17.03652763], [73.27540588, 17.03652954], [73.27540588, 17.03625107], [73.2756958, 17.03625107], [73.2756958, 17.03597069], [73.27597046, 17.0359726], [73.27597046, 17.03569412], [73.27625275, 17.03569412], [73.27625275, 17.03513908], [73.2765274, 17.03514099], [73.2765274, 17.03430939], [73.27680206, 17.03430939], [73.27680206, 17.03403091], [73.2776413, 17.03403091], [73.2776413, 17.03292084], [73.27791595, 17.03292084], [73.27791595, 17.0320797], [73.2776413, 17.03208542], [73.2776413, 17.02986145], [73.27735901, 17.02986145], [73.27735901, 17.02930641], [73.27707672, 17.02931023], [73.27707672, 17.02903175], [73.27680206, 17.02903175], [73.27680206, 17.02874947], [73.2765274, 17.02874947], [73.2765274, 17.02792168], [73.2756958, 17.02792168], [73.2756958, 17.02597046], [73.27541351, 17.02597237], [73.27541351, 17.02541733], [73.2756958, 17.02541924], [73.2756958, 17.02514076], [73.2765274, 17.02514076], [73.2765274, 17.02486038], [73.27680206, 17.02486038], [73.27680206, 17.02457047], [73.27708435, 17.02458382], [73.27708435, 17.02430534], [73.27735901, 17.02431107], [73.27735901, 17.02403069], [73.27791595, 17.02403069], [73.27791595, 17.02375031], [73.27819061, 17.02375031], [73.27819824, 17.02346992], [73.27874756, 17.02347183], [73.27874756, 17.02319527], [73.27902985, 17.02320099], [73.27902985, 17.02235985], [73.2793045, 17.02236176], [73.2793045, 17.02152824], [73.27986145, 17.02153015], [73.27986145, 17.02124977], [73.28013611, 17.02124977], [73.28013611, 17.02069092], [73.28097534, 17.02069664], [73.28097534, 17.02041435], [73.28125, 17.02042007], [73.28125, 17.01958084], [73.28152466, 17.01958466], [73.28152466, 17.01930618], [73.28180695, 17.01931], [73.28180695, 17.01876068], [73.28206635, 17.01876068], [73.28206635, 17.01848984], [73.28235626, 17.01847076], [73.28236389, 17.01819229], [73.28263855, 17.01819229], [73.28263855, 17.01791573], [73.28347015, 17.01791954], [73.28347015, 17.01876068], [73.28430176, 17.01876068], [73.28430939, 17.01902962], [73.28458405, 17.01902771], [73.28458405, 17.01958466], [73.2848587, 17.01958084], [73.2848587, 17.01986122], [73.2859726, 17.01986122], [73.2859726, 17.02013969], [73.28679657, 17.02013969], [73.28679657, 17.02042007], [73.28652954, 17.02041435], [73.28652954, 17.02069664], [73.2868042, 17.02069664], [73.2868042, 17.02095985], [73.28679657, 17.02124977], [73.28708649, 17.02124977], [73.28708649, 17.02153015], [73.28819275, 17.02152824], [73.28819275, 17.02180672], [73.28986359, 17.02180672], [73.28986359, 17.0209713], [73.2895813, 17.0209713], [73.2895813, 17.02013969], [73.28930664, 17.02013969], [73.28930664, 17.01986122], [73.28874969, 17.01986122], [73.28874969, 17.01958084], [73.28847504, 17.01958466], [73.28847504, 17.01847458], [73.2876358, 17.01847458], [73.2876358, 17.01819229], [73.28736115, 17.01819229], [73.28736115, 17.01791763], [73.28624725, 17.01791954], [73.28624725, 17.01736069], [73.28679657, 17.01736069], [73.28679657, 17.01680946], [73.28736115, 17.01680565], [73.28736115, 17.01708221], [73.28791809, 17.01708221], [73.28791809, 17.01680565], [73.2876358, 17.01680946], [73.2876358, 17.01625061], [73.28736115, 17.01625061], [73.28736115, 17.01597023], [73.2876358, 17.01597023], [73.2876358, 17.0154171], [73.28679657, 17.01542282], [73.28679657, 17.01486015], [73.28652954, 17.01486015], [73.28652954, 17.01180649], [73.28624725, 17.0118084], [73.28624725, 17.00930977], [73.28679657, 17.00930977], [73.28679657, 17.00902939], [73.28736115, 17.00902939], [73.28736115, 17.00875092], [73.2876358, 17.00875092], [73.2876358, 17.00819016], [73.28791809, 17.00819588], [73.28791809, 17.00763893], [73.28820038, 17.00764084], [73.28820038, 17.00708008], [73.28847504, 17.0070858], [73.28847504, 17.00680351], [73.28930664, 17.00682068], [73.28930664, 17.00875092], [73.28901672, 17.00875092], [73.28901672, 17.00902939], [73.28874969, 17.00902939], [73.28874969, 17.00930977], [73.2884903, 17.00930977], [73.2884903, 17.00959015], [73.28874969, 17.00959015], [73.28874969, 17.01013947], [73.28985596, 17.01013947], [73.28985596, 17.01041985], [73.29013824, 17.01041794], [73.29013824, 17.0106945], [73.28930664, 17.0106945], [73.28930664, 17.01097298], [73.28847504, 17.01097298], [73.28847504, 17.01263809], [73.28874969, 17.01263046], [73.28874969, 17.01291847], [73.28901672, 17.01291847], [73.28901672, 17.01374817], [73.28930664, 17.01374817], [73.28930664, 17.01402855], [73.2895813, 17.01402855], [73.2895813, 17.01458359], [73.28985596, 17.01458168], [73.28985596, 17.01514244], [73.29013824, 17.01514244], [73.29013824, 17.01542282], [73.2904129, 17.0154171], [73.2904129, 17.01597023], [73.29069519, 17.01597023], [73.29070282, 17.01625061], [73.2904129, 17.01625061], [73.2904129, 17.01680946], [73.29069519, 17.01680565], [73.29070282, 17.01733017], [73.29070282, 17.01764107], [73.29096985, 17.01764107], [73.29096985, 17.01902962], [73.29123688, 17.01902962], [73.29123688, 17.01931], [73.29152679, 17.01930618], [73.29152679, 17.01958466], [73.29264069, 17.01958084], [73.29264069, 17.01986122], [73.29292297, 17.01986122], [73.29292297, 17.02042007], [73.29319763, 17.02041435], [73.29319763, 17.02069664], [73.29264069, 17.02069664], [73.29264069, 17.0209713], [73.29291534, 17.0209713], [73.29291534, 17.02208328], [73.29319763, 17.02207947], [73.29319763, 17.02264023], [73.29292297, 17.02264023], [73.29292297, 17.02292061], [73.29264069, 17.02291679], [73.29264069, 17.02347183], [73.2923584, 17.02346992], [73.2923584, 17.02403069], [73.29208374, 17.02402878], [73.29208374, 17.02458382], [73.29180908, 17.02457047], [73.29180908, 17.02486038], [73.29152679, 17.02486038], [73.29152679, 17.02514076], [73.29123688, 17.02514076], [73.29123688, 17.02541924], [73.29069519, 17.02541733], [73.29069519, 17.02569389], [73.29013824, 17.02569389], [73.29013824, 17.02597237], [73.28985596, 17.02597046], [73.28985596, 17.02625084], [73.28930664, 17.02625084], [73.28930664, 17.02763939], [73.28901672, 17.02762985], [73.28901672, 17.02792168], [73.28874969, 17.02791595], [73.28874969, 17.0284729], [73.2884903, 17.02846909], [73.2884903, 17.02931023], [73.28708649, 17.02930641], [73.28708649, 17.02958107], [73.2859726, 17.02958107], [73.2859726, 17.02986145], [73.2848587, 17.02985954], [73.2848587, 17.03014183], [73.28375244, 17.03014183], [73.28375244, 17.0304203], [73.28347015, 17.0304203], [73.28347015, 17.03070068], [73.2831955, 17.03069305], [73.2831955, 17.03097153], [73.28291321, 17.03096962], [73.28291321, 17.03125], [73.28180695, 17.03125], [73.28180695, 17.03153038], [73.28125, 17.03153038], [73.28125, 17.03181076], [73.28097534, 17.03180313], [73.28097534, 17.03208542], [73.2804184, 17.0320797], [73.2804184, 17.03292084], [73.28069305, 17.03292084], [73.28069305, 17.03376007], [73.2804184, 17.03376007], [73.2804184, 17.03430939], [73.28069305, 17.03430939], [73.28069305, 17.03486061], [73.28125, 17.03486061], [73.28125, 17.03514099], [73.28180695, 17.03514099], [73.28180695, 17.03541946], [73.2820816, 17.03541756], [73.2820816, 17.03569412], [73.28263855, 17.03569412], [73.28263855, 17.0359726], [73.28291321, 17.03597069], [73.28291321, 17.03625107], [73.28320313, 17.03625107], [73.28320313, 17.03652954], [73.28347015, 17.03652763], [73.28347015, 17.03680611], [73.28375244, 17.03680038], [73.28375244, 17.03736115], [73.2840271, 17.03736115], [73.2840271, 17.03874969], [73.28430176, 17.03874969], [73.28430939, 17.04013824], [73.2848587, 17.04013824], [73.2848587, 17.04041862], [73.28514099, 17.04041672], [73.28515625, 17.04062653], [73.28541565, 17.04069519], [73.28541565, 17.04097176], [73.28624725, 17.04097176], [73.28624725, 17.04069519], [73.28708649, 17.04070091], [73.28708649, 17.04041862], [73.2876358, 17.04041862], [73.2876358, 17.04013824], [73.28820038, 17.04013824], [73.28820038, 17.03956985], [73.28791809, 17.03958321], [73.28791809, 17.03902817], [73.2876358, 17.03902817], [73.2876358, 17.03874969], [73.28736115, 17.03874969], [73.28736115, 17.03902817], [73.28708649, 17.03902817], [73.28708649, 17.03930473], [73.28662109, 17.03930473], [73.28514099, 17.03930473], [73.28514099, 17.03791618], [73.28736115, 17.03791809], [73.28736115, 17.03763962], [73.2876358, 17.03763962], [73.2876358, 17.03736115], [73.28847504, 17.03736115], [73.28847504, 17.03837967], [73.28847504, 17.03874969], [73.28930664, 17.03874969], [73.28930664, 17.03902817], [73.2904129, 17.03902817], [73.2904129, 17.03847122], [73.29069519, 17.03847313], [73.29069519, 17.03791618], [73.29096985, 17.03791809], [73.29096985, 17.03708076], [73.29069519, 17.03708267], [73.29069519, 17.03680611], [73.29208374, 17.03680611], [73.29208374, 17.03708267], [73.29220581, 17.03708267], [73.2923584, 17.03708076], [73.2923584, 17.03736115], [73.29216766, 17.03736115], [73.29180908, 17.03736115], [73.29180908, 17.03819466], [73.29207611, 17.03819084], [73.29207611, 17.03902817], [73.29152679, 17.03902817], [73.29152679, 17.03930473], [73.29125214, 17.03930473], [73.29125214, 17.03958321], [73.29152679, 17.03958321], [73.29152679, 17.03986168], [73.29374695, 17.03986168], [73.29374695, 17.03902817], [73.29402924, 17.03902817], [73.29402924, 17.03847122], [73.29486084, 17.03847122], [73.29486084, 17.03902817], [73.29458618, 17.03902817], [73.29458618, 17.03958321], [73.29430389, 17.03958321], [73.29430389, 17.03986168], [73.29569244, 17.03986168], [73.29569244, 17.03930473], [73.29597473, 17.03930473], [73.29597473, 17.03902817], [73.29624939, 17.03902817], [73.29624939, 17.03874969], [73.29651642, 17.03874969], [73.29651642, 17.03847122], [73.29680634, 17.03847313], [73.29680634, 17.03819466], [73.29708099, 17.03819466], [73.29708099, 17.03791618], [73.29818726, 17.03791809], [73.29818726, 17.03763962], [73.29792023, 17.03763962], [73.29792023, 17.03736115], [73.29846954, 17.03736115], [73.29846954, 17.03708076], [73.29902649, 17.03708267], [73.29902649, 17.03680611], [73.29930878, 17.03680611], [73.29930878, 17.03652763], [73.29985809, 17.03652954], [73.29985809, 17.03625107], [73.3004303, 17.03625107], [73.3004303, 17.03597069], [73.30097198, 17.0359726], [73.30097198, 17.03569412], [73.30152893, 17.03569412], [73.30152893, 17.03541756], [73.30208588, 17.03541946], [73.30208588, 17.03514099], [73.30264282, 17.03514099], [73.30264282, 17.03486061], [73.30319214, 17.03486061], [73.30317688, 17.03458023], [73.30403137, 17.03458595], [73.30403137, 17.03430557], [73.30486298, 17.03430939], [73.30486298, 17.03403091], [73.30680847, 17.03403091], [73.30680847, 17.03430939], [73.30708313, 17.03430557], [73.30708313, 17.03458595], [73.3079071, 17.03458023], [73.3079071, 17.03486061], [73.30819702, 17.03486061], [73.30819702, 17.03514099], [73.30902863, 17.03514099], [73.30902863, 17.03486061], [73.30931091, 17.03486061], [73.30931091, 17.03514099], [73.3095932, 17.03514099], [73.3095932, 17.03486061], [73.31069183, 17.03486061], [73.31069183, 17.03458023], [73.31180573, 17.03458595], [73.31180573, 17.03430557], [73.3119812, 17.03430748], [73.3123703, 17.03430939], [73.3123703, 17.03403091], [73.31263733, 17.03403091], [73.31263733, 17.03376007], [73.31318665, 17.03376007], [73.31318665, 17.03347015], [73.31375122, 17.03347206], [73.31375122, 17.0331955], [73.31513977, 17.0331955], [73.31513977, 17.03347206], [73.31569672, 17.03347015], [73.31569672, 17.03376007], [73.31624603, 17.03376007], [73.31624603, 17.03403091], [73.31652832, 17.03403091], [73.31652832, 17.03430939], [73.31597137, 17.03430557], [73.31597137, 17.03458595], [73.31569672, 17.03458023], [73.31569672, 17.03486061], [73.31625366, 17.03486061], [73.31625366, 17.03513908], [73.31652832, 17.03513908], [73.31652832, 17.03569412], [73.31485748, 17.03569412], [73.31485748, 17.0359726], [73.31430817, 17.03597069], [73.31430817, 17.03625107], [73.31402588, 17.03625107], [73.31402588, 17.03652954], [73.31346893, 17.03652954], [73.31346893, 17.03763962], [73.31375122, 17.03763962], [73.31375122, 17.03791809], [73.31458282, 17.03791809], [73.31458282, 17.03763962], [73.3154068, 17.03763962], [73.3154068, 17.03736115], [73.31569672, 17.03736115], [73.31569672, 17.03680038], [73.31513977, 17.03680611], [73.31513977, 17.03652763], [73.3154068, 17.03652954], [73.3154068, 17.03625107], [73.31597137, 17.03625107], [73.31597137, 17.03652954], [73.31652832, 17.03652763], [73.31652832, 17.03680611], [73.31708527, 17.03680611], [73.31708527, 17.03624916], [73.31735992, 17.03625107], [73.31735992, 17.03597069], [73.31791687, 17.0359726], [73.31791687, 17.03541756], [73.31958008, 17.03541756], [73.31958008, 17.03569412], [73.31930542, 17.03569412], [73.31930542, 17.0359726], [73.31817627, 17.03597069], [73.31817627, 17.03652954], [73.31847382, 17.03652763], [73.31847382, 17.03708267], [73.31874847, 17.03708076], [73.31874847, 17.03763962], [73.31986237, 17.03763962], [73.31986237, 17.03819466], [73.31847382, 17.03819466], [73.31847382, 17.03791618], [73.3170929, 17.03791809], [73.3170929, 17.03763962], [73.31652832, 17.03763962], [73.31652832, 17.03819466], [73.31708527, 17.03819466], [73.31708527, 17.03847313], [73.31735992, 17.03847122], [73.31735992, 17.03874969], [73.31708527, 17.03874969], [73.31708527, 17.03930473], [73.31680298, 17.03930473], [73.31680298, 17.03958321], [73.31597137, 17.03958321], [73.31597137, 17.03930473], [73.31569672, 17.03930473], [73.31569672, 17.03958321], [73.31541443, 17.03958321], [73.31541443, 17.03986168], [73.31485748, 17.03986168], [73.31485748, 17.03958321], [73.31458282, 17.03958321], [73.31458282, 17.03930473], [73.31430817, 17.03930473], [73.31430817, 17.03902817], [73.31263733, 17.03902817], [73.31263733, 17.03874969], [73.31180573, 17.03874969], [73.31180573, 17.03847313], [73.31153107, 17.03847313], [73.31153107, 17.03819466], [73.31124878, 17.03819466], [73.31124878, 17.03763962], [73.31014252, 17.03763962], [73.31014252, 17.03736115], [73.30930328, 17.03736115], [73.30930328, 17.03708267], [73.30708313, 17.03708267], [73.30708313, 17.03680611], [73.30569458, 17.03680611], [73.30569458, 17.03708267], [73.30513763, 17.03708076], [73.30513763, 17.03736115], [73.30263519, 17.03736115], [73.30263519, 17.03763962], [73.30291748, 17.03763962], [73.30291748, 17.03791809], [73.30319214, 17.03791618], [73.30319214, 17.03819466], [73.30374908, 17.03819466], [73.30374908, 17.03847313], [73.30403137, 17.03847122], [73.30403137, 17.03902817], [73.30374908, 17.03902817], [73.30374908, 17.03930473], [73.30347443, 17.03930473], [73.30347443, 17.03958321], [73.30263519, 17.03958321], [73.30263519, 17.03986168], [73.30179596, 17.03985977], [73.30179596, 17.04013824], [73.3004303, 17.04013824], [73.3004303, 17.04041862], [73.29875183, 17.04041862], [73.29875183, 17.04070091], [73.29819489, 17.04069519], [73.29819489, 17.04097176], [73.29792023, 17.04096985], [73.29792023, 17.04125023], [73.29763794, 17.04125023], [73.29763794, 17.0418129], [73.29736328, 17.04180527], [73.29736328, 17.04208374], [73.29708099, 17.04208183], [73.29708099, 17.04236031], [73.29680634, 17.04236031], [73.29680634, 17.0429306], [73.29652405, 17.04291725], [73.29652405, 17.04319382], [73.29624939, 17.04319382], [73.29624939, 17.04347038], [73.29541779, 17.04347038], [73.29541779, 17.04375267], [73.29514313, 17.04375267], [73.29514313, 17.04430962], [73.29486084, 17.0443058], [73.29486084, 17.04458237], [73.28902435, 17.04458237], [73.28902435, 17.0443058], [73.28874969, 17.04430962], [73.28874969, 17.04403114], [73.2876358, 17.04403114], [73.2876358, 17.04430962], [73.28736115, 17.0443058], [73.28736115, 17.04458237], [73.28708649, 17.04458046], [73.28708649, 17.04514122], [73.28736115, 17.04514122], [73.28736115, 17.04541969], [73.2876358, 17.04541969], [73.2876358, 17.04570007], [73.28791809, 17.04569244], [73.28791809, 17.04597473], [73.28819275, 17.04597473], [73.28819275, 17.04624939], [73.2884903, 17.04624939], [73.2884903, 17.04652977], [73.29070282, 17.04652977], [73.29070282, 17.04681015], [73.29125214, 17.04680634], [73.29125214, 17.04708481], [73.29152679, 17.04708481], [73.29152679, 17.04736137], [73.29013824, 17.04735947], [73.29013824, 17.04763985], [73.2884903, 17.04763985], [73.2884903, 17.04735947], [73.2876358, 17.04736137], [73.2876358, 17.04680634], [73.28736115, 17.04681015], [73.28736115, 17.04624939], [73.28708649, 17.04624939], [73.28708649, 17.04570007], [73.28624725, 17.04570007], [73.28624725, 17.04541969], [73.28569794, 17.04541969], [73.28569794, 17.04514122], [73.28514099, 17.04514122], [73.28514099, 17.04458046], [73.28458405, 17.04458237], [73.28458405, 17.0443058], [73.28430176, 17.04430962], [73.28430176, 17.04403114], [73.2840271, 17.04403114], [73.2840271, 17.04375267], [73.28375244, 17.04375267], [73.28375244, 17.04347038], [73.28347015, 17.04347038], [73.28347015, 17.04319382], [73.28291321, 17.04319382], [73.28291321, 17.04291725], [73.28263855, 17.0429306], [73.28263855, 17.04264259], [73.28235626, 17.04264259], [73.28235626, 17.04236031], [73.28206635, 17.04236031], [73.28206635, 17.0418129], [73.28180695, 17.0418129], [73.28180695, 17.04153252], [73.28151703, 17.04153252], [73.28151703, 17.04125023], [73.28125, 17.04125023], [73.28125, 17.04096985], [73.28097534, 17.04097176], [73.28097534, 17.04069519], [73.28069305, 17.04070091], [73.28069305, 17.04041862], [73.2804184, 17.04041862], [73.2804184, 17.03985977], [73.28013611, 17.03986168], [73.28013611, 17.03958321], [73.27986145, 17.03958321], [73.27986145, 17.03930473], [73.27958679, 17.03930473], [73.27958679, 17.03958321], [73.2793045, 17.03958321], [73.2793045, 17.03986168], [73.27902985, 17.03985977], [73.27902985, 17.04013824], [73.27874756, 17.04013824], [73.27874756, 17.04041862], [73.2784729, 17.04041862], [73.2784729, 17.04070091], [73.27874756, 17.04070091], [73.27874756, 17.04125023], [73.27929688, 17.04125023], [73.27929688, 17.04153252], [73.27958679, 17.04153252], [73.27958679, 17.0418129], [73.27986145, 17.04180527], [73.27986145, 17.04208374], [73.28013611, 17.04208183], [73.28013611, 17.04236031], [73.2804184, 17.04236031], [73.2804184, 17.04264259], [73.28069305, 17.04263878], [73.28069305, 17.04319382], [73.28097534, 17.04319382], [73.28097534, 17.04375267], [73.28125, 17.04375267], [73.28125, 17.04403114], [73.28140259, 17.04403114], [73.28180695, 17.04403114], [73.28180695, 17.04430962], [73.28206635, 17.04430962], [73.28206635, 17.04486084], [73.28235626, 17.04486084], [73.28235626, 17.04541969], [73.28263855, 17.04541588], [73.28263855, 17.04597473], [73.28291321, 17.04597092], [73.28291321, 17.04624939], [73.28320313, 17.04624939], [73.28320313, 17.04652977], [73.28347015, 17.04652977], [73.28347015, 17.04681015], [73.28375244, 17.04680634], [73.28375244, 17.04736137], [73.2840271, 17.04735947], [73.2840271, 17.04763985], [73.28430176, 17.04763985], [73.28430939, 17.04792023], [73.28458405, 17.04791641], [73.28458405, 17.04819679], [73.2848587, 17.04819679], [73.2848587, 17.04874992], [73.28514099, 17.04874039], [73.28514099, 17.04931068], [73.28541565, 17.04930687], [73.28541565, 17.04986191], [73.28569794, 17.04986], [73.28569794, 17.05042076], [73.2859726, 17.05041885], [73.2859726, 17.05097198], [73.28624725, 17.05097008], [73.28624725, 17.05125046], [73.28652954, 17.05125046], [73.28652954, 17.0518055], [73.28679657, 17.05179977], [73.28679657, 17.05236053], [73.28708649, 17.05236053], [73.28708649, 17.0529213], [73.28736115, 17.05291748], [73.28736115, 17.05347252], [73.2876358, 17.05347061], [73.2876358, 17.05431175], [73.28791809, 17.05431175], [73.28791809, 17.05653191], [73.28820038, 17.05653191], [73.28820038, 17.05792999], [73.28847504, 17.05791664], [73.28847504, 17.06347275], [73.28820038, 17.06347084], [73.28820038, 17.06652832], [73.28791809, 17.06652832], [73.28791809, 17.07042122], [73.28819275, 17.0704174], [73.28819275, 17.0731926], [73.28791809, 17.0731926], [73.28791809, 17.07347488], [73.28820038, 17.07347107], [73.28820038, 17.07542038], [73.28874969, 17.07542038], [73.28874969, 17.07570076], [73.28930664, 17.07569695], [73.28930664, 17.0759716], [73.2895813, 17.0759697], [73.2895813, 17.07653046], [73.28985596, 17.07653046], [73.28985596, 17.07681084], [73.29013824, 17.07681084], [73.29013824, 17.07736015], [73.29096985, 17.07736015], [73.29096985, 17.07707977], [73.29125214, 17.07708359], [73.29125214, 17.07680511], [73.29180908, 17.07681084], [73.29180908, 17.07653046], [73.29319763, 17.07653046], [73.29319763, 17.07625008], [73.29347229, 17.07625008], [73.29347229, 17.0759697], [73.29402924, 17.0759716], [73.29402924, 17.07569695], [73.29597473, 17.07569695], [73.29597473, 17.07708359], [73.29680634, 17.07708359], [73.29680634, 17.07652855], [73.29708099, 17.07653046], [73.29708099, 17.07625008], [73.29737091, 17.07625008], [73.29736328, 17.07569695], [73.29763794, 17.07570076], [73.29763794, 17.07514], [73.29792023, 17.07514], [73.29792023, 17.07485962], [73.29846954, 17.07485962], [73.29846954, 17.07514], [73.29875183, 17.07514], [73.29875183, 17.07570076], [73.29846954, 17.07570076], [73.29846954, 17.07625008], [73.29819489, 17.07625008], [73.29819489, 17.07847214], [73.29792023, 17.07847023], [73.29792023, 17.07875061], [73.29680634, 17.07875061], [73.29680634, 17.07847023], [73.29597473, 17.07847214], [73.29597473, 17.07819366], [73.29569244, 17.07819366], [73.29569244, 17.07847214], [73.29152679, 17.07847214], [73.29152679, 17.07819366], [73.29096985, 17.07819366], [73.29096985, 17.0779171], [73.2904129, 17.0779171], [73.2904129, 17.07819366], [73.2876358, 17.07819366], [73.2876358, 17.07847214], [73.28679657, 17.07847023], [73.28679657, 17.07875061], [73.28514099, 17.07875061], [73.28514099, 17.07902908], [73.2840271, 17.07902908], [73.2840271, 17.07930756], [73.28375244, 17.07930565], [73.28375244, 17.07958412], [73.28320313, 17.07958031], [73.28320313, 17.08042145], [73.28291321, 17.08041763], [73.28291321, 17.0806942], [73.2831955, 17.0806942], [73.2831955, 17.08097267], [73.28347015, 17.08097076], [73.28347015, 17.08124924], [73.28375244, 17.08124924], [73.28375244, 17.08152962], [73.2840271, 17.08152962], [73.2840271, 17.0818119], [73.28430176, 17.08180618], [73.28430939, 17.08208275], [73.28457642, 17.08208084], [73.28457642, 17.08235931], [73.28514099, 17.08235931], [73.28514099, 17.08292007], [73.28541565, 17.08291626], [73.28541565, 17.08319473], [73.28569794, 17.08319473], [73.28569794, 17.08430481], [73.2859726, 17.08430481], [73.2859726, 17.08458138], [73.28543091, 17.08457947], [73.28543091, 17.08542061], [73.28569794, 17.08541679], [73.28569794, 17.08597374], [73.2859726, 17.08596992], [73.2859726, 17.08681107], [73.28624725, 17.08680344], [73.28624725, 17.08708572], [73.2859726, 17.08708], [73.2859726, 17.08764076], [73.28569794, 17.08763885], [73.28569794, 17.0881958], [73.28541565, 17.0881958], [73.28543091, 17.08986092], [73.28514099, 17.08986092], [73.28514099, 17.09013939], [73.2848587, 17.09013939], [73.2848587, 17.09041977], [73.28458405, 17.09041786], [73.28458405, 17.0909729], [73.2848587, 17.0909729], [73.2848587, 17.09236145], [73.28457642, 17.09235954], [73.28457642, 17.09542274], [73.28430939, 17.09541702], [73.28430939, 17.09597015], [73.28458405, 17.09597015], [73.28458405, 17.09708214], [73.2848587, 17.09708023], [73.2848587, 17.09875107], [73.28514099, 17.09874916], [73.28514099, 17.09958458], [73.28543091, 17.09958076], [73.28543091, 17.10042], [73.28514099, 17.10041428], [73.28514099, 17.10236168], [73.2848587, 17.10236168], [73.2848587, 17.10291672], [73.28458405, 17.10291672], [73.28458405, 17.10347176], [73.2848587, 17.10346985], [73.2848587, 17.10403061], [73.28514099, 17.10403061], [73.28514099, 17.10514069], [73.28541565, 17.10513878], [73.28541565, 17.10569382], [73.28514099, 17.1056881], [73.28514099, 17.10625076], [73.2848587, 17.10625076], [73.2848587, 17.10681152], [73.28457642, 17.10681152], [73.28457642, 17.10736084], [73.2840271, 17.10736084], [73.2840271, 17.1079216], [73.28347015, 17.10791588], [73.28347015, 17.10819435], [73.28291321, 17.10819054], [73.28291321, 17.10874939], [73.28263855, 17.10874939], [73.28263855, 17.10931015], [73.28235626, 17.10931015], [73.28235626, 17.11042023], [73.2820816, 17.11041641], [73.2820816, 17.11097145], [73.28235626, 17.11096954], [73.28235626, 17.11124992], [73.28263855, 17.11124992], [73.28263855, 17.1115303], [73.28291321, 17.1115303], [73.28291321, 17.11181068], [73.28263855, 17.11180305], [73.28263855, 17.11236382], [73.28291321, 17.11236], [73.28291321, 17.11264038], [73.28320313, 17.11264038], [73.28320313, 17.11292076], [73.28347015, 17.11291695], [73.28347015, 17.11319542], [73.2832489, 17.11319542], [73.28263855, 17.11319542], [73.28263855, 17.11291695], [73.28235626, 17.11292076], [73.28235626, 17.11236], [73.28152466, 17.11236382], [73.28152466, 17.11208153], [73.28125, 17.11208153], [73.28125, 17.11180305], [73.28098297, 17.11181068], [73.28098297, 17.1115303], [73.28013611, 17.1115303], [73.28013611, 17.11181068], [73.27958679, 17.11180305], [73.27958679, 17.11236382], [73.28098297, 17.11236], [73.28098297, 17.11264038], [73.28125, 17.11263847], [73.28125, 17.11319542], [73.28152466, 17.11319542], [73.28152466, 17.11347389], [73.28263855, 17.11347008], [73.28263855, 17.11403084], [73.28125, 17.11403084], [73.28125, 17.11375046], [73.27986145, 17.11375046], [73.27986145, 17.11347008], [73.2748642, 17.11347389], [73.2748642, 17.11319542], [73.27320099, 17.1131897], [73.27319336, 17.11291695], [73.2729187, 17.11292076], [73.2729187, 17.11264038], [73.26930237, 17.11264038], [73.26930237, 17.11207962], [73.26902771, 17.11208153], [73.26902771, 17.11180305], [73.26680756, 17.11180305], [73.26680756, 17.11236382], [73.26625061, 17.11236], [73.26625061, 17.11292076], [73.26597595, 17.11291695], [73.26597595, 17.11319542], [73.26652527, 17.11319542], [73.26652527, 17.11347389], [73.26706696, 17.11347008], [73.26706696, 17.11375046], [73.26735687, 17.11375046], [73.26735687, 17.11403084], [73.26763916, 17.11402512], [73.26763916, 17.11458588], [73.26790619, 17.11458015], [73.26790619, 17.11541939], [73.26819611, 17.11541748], [73.26819611, 17.11569595], [73.26847076, 17.11569023], [73.26847076, 17.11625099], [73.26875305, 17.11625099], [73.26875305, 17.11652946], [73.26902771, 17.11652756], [73.26902771, 17.1170826], [73.26930237, 17.11708069], [73.26930237, 17.11736107], [73.26957703, 17.11736107], [73.26957703, 17.11791992], [73.26985931, 17.11791611], [73.26985931, 17.11819458], [73.27041626, 17.11819458], [73.27041626, 17.11847305], [73.27153015, 17.11847115], [73.27153015, 17.11874962], [73.27236176, 17.11874962], [73.27236176, 17.11930466], [73.27263641, 17.11930084], [73.27263641, 17.12041855], [73.27236176, 17.12041855], [73.27236176, 17.12181282], [73.2720871, 17.12181282], [73.2720871, 17.12236023], [73.27179718, 17.12236023], [73.27179718, 17.1229229], [73.27153015, 17.12291718], [73.27153015, 17.12458229], [73.27124786, 17.12458038], [73.27124786, 17.12514114], [73.27097321, 17.12513924], [73.27097321, 17.1273613], [73.27124786, 17.12735939], [73.27124786, 17.12763977], [73.27097321, 17.12763977], [73.27097321, 17.12847137], [73.27069092, 17.12847137], [73.27069092, 17.12958336], [73.26930237, 17.12957954], [73.26930237, 17.13042068], [73.26902771, 17.13042068], [73.26902771, 17.13070107], [73.26875305, 17.13069534], [73.26875305, 17.13097191], [73.26902771, 17.13097], [73.26902771, 17.13153076], [73.26875305, 17.13152885], [73.26875305, 17.13208389], [73.26847076, 17.13207817], [73.26847076, 17.13236046], [73.26819611, 17.13236046], [73.26819611, 17.13347244], [73.26791382, 17.13347244], [73.26791382, 17.1356945], [73.26819611, 17.1356945], [73.26819611, 17.13736153], [73.26735687, 17.13735962], [73.26735687, 17.13792038], [73.26763916, 17.13792038], [73.26763916, 17.13875008], [73.26790619, 17.13875008], [73.26790619, 17.13931084], [73.26763916, 17.13930321], [73.26763916, 17.13958549], [73.2673645, 17.13958549], [73.2673645, 17.14069557], [73.26706696, 17.14068985], [73.26706696, 17.14180946], [73.26680756, 17.14180946], [73.26680756, 17.14208984], [73.2665329, 17.14208984], [73.2665329, 17.14264107], [73.26625061, 17.14264107], [73.26625061, 17.14430809], [73.26597595, 17.14430809], [73.26597595, 17.14486122], [73.26569366, 17.14486122], [73.26569366, 17.14569473], [73.26597595, 17.14569092], [73.26597595, 17.14652824], [73.26569366, 17.14652824], [73.26569366, 17.14680481], [73.26541901, 17.14680481], [73.26541901, 17.14708328], [73.26513672, 17.14707756], [73.26513672, 17.14792252], [73.26486206, 17.14792252], [73.26486206, 17.14903259], [73.26457977, 17.14903259], [73.26457977, 17.14931107], [73.26486206, 17.14931107], [73.26486206, 17.14986038], [73.26457977, 17.14986038], [73.26457977, 17.15153122], [73.26430511, 17.1515274], [73.26430511, 17.15208244], [73.26346588, 17.15208054], [73.26346588, 17.15236092], [73.26374817, 17.15236092], [73.26374817, 17.15319252], [73.26347351, 17.15319252], [73.26347351, 17.15458488], [73.26374817, 17.15458107], [73.26374817, 17.15570068], [73.26346588, 17.15570068], [73.26346588, 17.15625], [73.26403046, 17.15625], [73.26403046, 17.15596962], [73.26430511, 17.15597153], [73.26430511, 17.15569687], [73.26457977, 17.15569687], [73.26457977, 17.15597153], [73.26486206, 17.15596962], [73.26486206, 17.15681076], [73.26432037, 17.15681076], [73.26432037, 17.15709114], [73.26403046, 17.15708351], [73.26403046, 17.15736198], [73.26374817, 17.15736008], [73.26374817, 17.15792084], [73.26347351, 17.15791893], [73.26347351, 17.15847206], [73.26319122, 17.15847015], [73.26319122, 17.15903091], [73.26291656, 17.1590271], [73.26291656, 17.15958405], [73.26264191, 17.15957832], [73.26264191, 17.15986061], [73.26235962, 17.15986061], [73.26235962, 17.16013908], [73.26209259, 17.16012955], [73.26209259, 17.16042137], [73.26126099, 17.16042137], [73.26126099, 17.16124916], [73.26097107, 17.16124916], [73.26097107, 17.16181183], [73.26069641, 17.16181183], [73.26069641, 17.16235924], [73.26097107, 17.16235924], [73.26097107, 17.16347122], [73.26069641, 17.16347122], [73.26069641, 17.16403008], [73.26041412, 17.16402817], [73.26041412, 17.1645813], [73.26013947, 17.1645813], [73.26013947, 17.16486359], [73.25985718, 17.16485977], [73.25985718, 17.16542053], [73.25958252, 17.16541672], [73.25958252, 17.16597176], [73.25930786, 17.16596985], [73.25930786, 17.16653061], [73.25958252, 17.1665287], [73.25958252, 17.16708565], [73.25930786, 17.16707993], [73.25930786, 17.16764069], [73.2590332, 17.16764069], [73.2590332, 17.16792107], [73.25930786, 17.16791725], [73.25930786, 17.16958237], [73.25958252, 17.16958046], [73.25958252, 17.16986084], [73.25985718, 17.16986084], [73.25985718, 17.17041969], [73.25958252, 17.17041969], [73.25958252, 17.17152977], [73.25986481, 17.17152786], [73.25986481, 17.1720829], [73.25958252, 17.1720829], [73.25958252, 17.17180634], [73.25930786, 17.17180634], [73.25930786, 17.1720829], [73.25846863, 17.17206955], [73.25846863, 17.17431068], [73.25819397, 17.17430496], [73.25819397, 17.17513847], [73.25763702, 17.17513847], [73.25763702, 17.1756916], [73.25736237, 17.17570114], [73.25736237, 17.17653275], [73.25708008, 17.17652702], [73.25708008, 17.17708206], [73.25681305, 17.17708015], [73.25681305, 17.1787529], [73.25653076, 17.1787529], [73.25653076, 17.17902946], [73.25624847, 17.17902946], [73.25624847, 17.17930984], [73.25597382, 17.17930412], [73.25597382, 17.1795826], [73.25569153, 17.17958069], [73.25569153, 17.18013954], [73.25541687, 17.18013954], [73.25541687, 17.18069649], [73.25569153, 17.18069077], [73.25569153, 17.18126106], [73.25541687, 17.18124962], [73.25541687, 17.18180656], [73.25514221, 17.18180656], [73.25514221, 17.18208313], [73.25485992, 17.18208313], [73.25485992, 17.1823616], [73.2545929, 17.1823597], [73.2545929, 17.18292046], [73.25430298, 17.18291664], [73.25430298, 17.18458366], [73.25402832, 17.18457985], [73.25402832, 17.18486023], [73.25374603, 17.18486023], [73.25374603, 17.18541908], [73.25347137, 17.18541908], [73.25347137, 17.18681145], [73.25319672, 17.18681145], [73.25319672, 17.18736076], [73.2529068, 17.18736076], [73.2529068, 17.18902969], [73.25263977, 17.18902969], [73.25263977, 17.18931007], [73.25235748, 17.18930626], [73.25235748, 17.1898613], [73.25208282, 17.1898613], [73.25209045, 17.19013977], [73.25180817, 17.19013977], [73.25180817, 17.19042015], [73.25096893, 17.19041634], [73.25096893, 17.19069481], [73.25125122, 17.19069481], [73.25125122, 17.19097137], [73.25096893, 17.19096947], [73.25096893, 17.19124985], [73.25041962, 17.19124985], [73.25041962, 17.19153023], [73.25013733, 17.19152832], [73.25013733, 17.19180489], [73.24986267, 17.19180489], [73.24986267, 17.19208145], [73.24764252, 17.19208145], [73.24764252, 17.19180489], [73.24736023, 17.19180489], [73.24736023, 17.19152832], [73.24680328, 17.19153023], [73.24680328, 17.19124985], [73.24652863, 17.19124985], [73.24652863, 17.19096947], [73.24569702, 17.19097137], [73.24569702, 17.19069481], [73.24485779, 17.19069481], [73.24485779, 17.19097137], [73.24430847, 17.19097137], [73.24430847, 17.19069481], [73.24402618, 17.19069481], [73.24402618, 17.19097137], [73.24346924, 17.19096947], [73.24346924, 17.19124985], [73.24263763, 17.19124985], [73.24263763, 17.19180489], [73.24236298, 17.19180489], [73.24236298, 17.19236374], [73.24124908, 17.19235992], [73.24124908, 17.19320107], [73.24041748, 17.19319344], [73.24041748, 17.19347382], [73.23986053, 17.19347], [73.23986053, 17.19375038], [73.23958588, 17.19375038], [73.23958588, 17.19403076], [73.23902893, 17.19403076], [73.23902893, 17.19431114], [73.23764038, 17.19431114], [73.23764038, 17.19403076], [73.23680878, 17.19403076], [73.23680878, 17.19375038], [73.23542023, 17.19375038], [73.23542023, 17.19403076], [73.23513794, 17.19403076], [73.23513794, 17.19431114], [73.23486328, 17.19430351], [73.23486328, 17.19569588], [73.23402405, 17.19569588], [73.23402405, 17.19597244], [73.23319244, 17.19597054], [73.23319244, 17.19652939], [73.2326355, 17.19652748], [73.2326355, 17.19708252], [73.23236084, 17.19708061], [73.23236084, 17.19736099], [73.23208618, 17.19736099], [73.23208618, 17.19763947], [73.23179626, 17.19763947], [73.23179626, 17.19791985], [73.23152924, 17.19791794], [73.23152924, 17.1981945], [73.23124695, 17.1981945], [73.23124695, 17.19930649], [73.23095703, 17.19930077], [73.23095703, 17.20070076], [73.23124695, 17.20069504], [73.23124695, 17.2009716], [73.23152924, 17.2009697], [73.23152924, 17.20125008], [73.23179626, 17.20125008], [73.23179626, 17.20153236], [73.23236084, 17.20153236], [73.23236084, 17.20181274], [73.2326355, 17.20180511], [73.2326355, 17.20208359], [73.23458099, 17.20208359], [73.23458099, 17.20152855], [73.23709106, 17.20153236], [73.23709106, 17.20125008], [73.23764038, 17.20125008], [73.23764038, 17.2009697], [73.23847198, 17.2009716], [73.23847198, 17.20069504], [73.23902893, 17.20070076], [73.23902893, 17.20041847], [73.23929596, 17.20041847], [73.23929596, 17.20013809], [73.23958588, 17.20013809], [73.23958588, 17.19985962], [73.23986053, 17.19986153], [73.23986053, 17.19958305], [73.24013519, 17.19958305], [73.24013519, 17.19930649], [73.24041748, 17.19930458], [73.24041748, 17.19902992], [73.2409668, 17.19902992], [73.2409668, 17.19874954], [73.24208069, 17.19874954], [73.24208069, 17.19847107], [73.24263763, 17.19847298], [73.24263763, 17.1981945], [73.24319458, 17.1981945], [73.24319458, 17.19791794], [73.24346924, 17.19791985], [73.24346924, 17.19763947], [73.24375153, 17.19763947], [73.24375153, 17.19736099], [73.24402618, 17.19736099], [73.24402618, 17.19680977], [73.24430847, 17.19680977], [73.24430847, 17.19652939], [73.24514008, 17.19652939], [73.24514008, 17.19680977], [73.2454071, 17.19680977], [73.2454071, 17.19763947], [73.24514008, 17.19763947], [73.24514008, 17.19791985], [73.24430847, 17.19791794], [73.24430847, 17.1981945], [73.24375153, 17.1981945], [73.24375153, 17.19847298], [73.24346924, 17.19847107], [73.24346924, 17.19874954], [73.24319458, 17.19874954], [73.24319458, 17.19930649], [73.24291992, 17.19930077], [73.24291992, 17.20013809], [73.24318695, 17.20013809], [73.24318695, 17.20070076], [73.24346924, 17.20070076], [73.24346924, 17.20125008], [73.24375153, 17.20125008], [73.24375153, 17.20181274], [73.24402618, 17.20180511], [73.24402618, 17.20208359], [73.24430847, 17.20208168], [73.24430847, 17.20236015], [73.24458313, 17.20236015], [73.24458313, 17.20292282], [73.24485779, 17.2029171], [73.24485779, 17.20347023], [73.24514008, 17.20347023], [73.24514008, 17.20375061], [73.2454071, 17.20375061], [73.2454071, 17.2040329], [73.24624634, 17.2040329], [73.24624634, 17.20514107], [73.24569702, 17.20514107], [73.24569702, 17.20486069], [73.24485779, 17.20486069], [73.24485779, 17.20514107], [73.24514008, 17.20513916], [73.24514008, 17.20569229], [73.24541473, 17.20569229], [73.24541473, 17.20597458], [73.24597168, 17.20597076], [73.24597168, 17.20736122], [73.24624634, 17.20736122], [73.24624634, 17.20874977], [73.24652863, 17.20874977], [73.24652863, 17.21014023], [73.2470932, 17.21014023], [73.2470932, 17.21042061], [73.24680328, 17.21042061], [73.24680328, 17.21070099], [73.24652863, 17.21070099], [73.24652863, 17.21153069], [73.24624634, 17.21153069], [73.24624634, 17.21291924], [73.24597168, 17.21291733], [73.24597168, 17.21430588], [73.24569702, 17.21429825], [73.24569702, 17.21624947], [73.24597168, 17.21624947], [73.24597168, 17.21681023], [73.24514008, 17.21681023], [73.24514008, 17.21737289], [73.24569702, 17.21737289], [73.24569702, 17.21763992], [73.2454071, 17.21763992], [73.2454071, 17.21820068], [73.24514008, 17.21819305], [73.24514008, 17.21847153], [73.24485779, 17.21846962], [73.24485779, 17.21931076], [73.24458313, 17.21930313], [73.24458313, 17.21958542], [73.24485779, 17.21958542], [73.24485779, 17.21986389], [73.24458313, 17.21986389], [73.24458313, 17.2206955], [73.24485779, 17.2206955], [73.24485779, 17.22097206], [73.24458313, 17.22097015], [73.24458313, 17.22125053], [73.24430847, 17.22125053], [73.24430847, 17.22264099], [73.24402618, 17.22263908], [73.24402618, 17.2234726], [73.24375153, 17.22347069], [73.24375153, 17.22430992], [73.24346924, 17.22430992], [73.24346924, 17.22486115], [73.24319458, 17.22486115], [73.24319458, 17.22597313], [73.24263763, 17.22597313], [73.24263763, 17.22624969], [73.24236298, 17.22624016], [73.24236298, 17.22652817], [73.24180603, 17.22652817], [73.24180603, 17.22680473], [73.24153137, 17.22680473], [73.24153137, 17.22708321], [73.24124908, 17.22708321], [73.24124908, 17.22736168], [73.2409668, 17.22735977], [73.2409668, 17.22792244], [73.24069214, 17.22792244], [73.24069214, 17.22820282], [73.24041748, 17.22819519], [73.24041748, 17.22847176], [73.23986053, 17.22847176], [73.23986053, 17.22819519], [73.23958588, 17.22820282], [73.23958588, 17.22792244], [73.23902893, 17.22792244], [73.23902893, 17.22763824], [73.23819733, 17.22763824], [73.23819733, 17.22735977], [73.23764038, 17.22736168], [73.23764038, 17.22708321], [73.23680878, 17.22708321], [73.23680878, 17.22680473], [73.23513794, 17.22680473], [73.23513794, 17.22708321], [73.23486328, 17.22707748], [73.23486328, 17.22763824], [73.23458099, 17.22763824], [73.23458099, 17.22820282], [73.23430634, 17.22819519], [73.23430634, 17.22958374], [73.23403168, 17.22958183], [73.23403168, 17.23042107], [73.23374939, 17.23041725], [73.23374939, 17.23097229], [73.2334671, 17.23097038], [73.2334671, 17.23125076], [73.23319244, 17.23125076], [73.23319244, 17.23180962], [73.23291779, 17.2318058], [73.23291779, 17.23208237], [73.23264313, 17.23208046], [73.23264313, 17.23237038], [73.23236084, 17.23237038], [73.23236084, 17.23264122], [73.23208618, 17.23263931], [73.23208618, 17.23319244], [73.23179626, 17.23319054], [73.23179626, 17.23513985], [73.23208618, 17.23513794], [73.23208618, 17.23569679], [73.23236084, 17.23569679], [73.23236084, 17.23597145], [73.2326355, 17.23597145], [73.2326355, 17.23624992], [73.23319244, 17.23624992], [73.23319244, 17.2365303], [73.2334671, 17.2365303], [73.2334671, 17.23681068], [73.23374939, 17.23680687], [73.23374939, 17.23736191], [73.23403168, 17.23736], [73.23403168, 17.23792076], [73.23430634, 17.23791885], [73.23430634, 17.23847198], [73.2334671, 17.23847008], [73.2334671, 17.23903084], [73.23319244, 17.23902893], [73.23319244, 17.23958397], [73.23291779, 17.23957825], [73.23291779, 17.24014091], [73.23264313, 17.24014091], [73.23264313, 17.24041939], [73.23236084, 17.24041748], [73.23236084, 17.24097252], [73.23208618, 17.24097061], [73.23208618, 17.24154282], [73.23180389, 17.24152756], [73.23180389, 17.2420826], [73.23152924, 17.2420826], [73.23152924, 17.24597168], [73.23124695, 17.24596977], [73.23124695, 17.24625015], [73.23095703, 17.24625015], [73.23095703, 17.24681091], [73.23069763, 17.24680328], [73.23069763, 17.24708557], [73.23014069, 17.24708557], [73.23014069, 17.24625015], [73.22821045, 17.24625015], [73.22821045, 17.24653053], [73.22651672, 17.24653053], [73.22651672, 17.24681091], [73.22541809, 17.24680328], [73.22541809, 17.24708557], [73.22402954, 17.24708557], [73.22402954, 17.24736023], [73.2234726, 17.24735069], [73.2234726, 17.24764061], [73.22319794, 17.2476387], [73.22319794, 17.24847221], [73.2234726, 17.24847031], [73.2234726, 17.24875069], [73.22374725, 17.24875069], [73.22374725, 17.24903107], [73.22402954, 17.24903107], [73.22402954, 17.24930954], [73.22486115, 17.24930763], [73.22486115, 17.2495842], [73.22597504, 17.2495842], [73.22597504, 17.24930763], [73.2270813, 17.24930763], [73.2270813, 17.2495842], [73.22735596, 17.24958038], [73.22735596, 17.25014114], [73.22763824, 17.25013924], [73.22763824, 17.25041771], [73.22846985, 17.25041771], [73.22846985, 17.25097275], [73.22875214, 17.25097084], [73.22875214, 17.25152969], [73.2279129, 17.25152779], [73.2279129, 17.25208282], [73.22763824, 17.25208092], [73.22763824, 17.25263977], [73.22736359, 17.25263977], [73.22736359, 17.25319481], [73.2270813, 17.25318909], [73.2270813, 17.25374985], [73.22680664, 17.25374985], [73.22680664, 17.25570107], [73.22624969, 17.25569534], [73.22624969, 17.25597191], [73.22597504, 17.25597191], [73.22598267, 17.25625038], [73.22458649, 17.25625038], [73.22458649, 17.25597191], [73.22402954, 17.25597191], [73.22402954, 17.25569534], [73.22374725, 17.25570107], [73.22374725, 17.25542259], [73.2234726, 17.25542259], [73.2234726, 17.2551403], [73.22209167, 17.2551403], [73.22209167, 17.25542259], [73.22180939, 17.25542259], [73.22180176, 17.25570107], [73.2215271, 17.25569534], [73.2215271, 17.25597191], [73.22180176, 17.25597191], [73.22180176, 17.25618172], [73.22180939, 17.25681114], [73.22209167, 17.25681114], [73.22209167, 17.25792122], [73.22180939, 17.2579174], [73.22180176, 17.25847244], [73.2215271, 17.25847054], [73.2215271, 17.25875282], [73.22125244, 17.25875282], [73.22125244, 17.25930977], [73.22097015, 17.25930977], [73.22097015, 17.26041985], [73.2206955, 17.26041412], [73.2206955, 17.26097488], [73.22097015, 17.26097107], [73.22097015, 17.26124954], [73.22180176, 17.26124954], [73.22180939, 17.26180077], [73.22208405, 17.26180649], [73.22208405, 17.26236153], [73.2223587, 17.26235008], [73.2223587, 17.26264], [73.22292328, 17.26264], [73.22292328, 17.26292038], [73.22319794, 17.26291656], [73.22319794, 17.26458359], [73.22291565, 17.26458359], [73.22291565, 17.26597214], [73.2234726, 17.26597023], [73.2234726, 17.26652908], [73.22264099, 17.26652908], [73.22264099, 17.26625061], [73.2223587, 17.26625061], [73.2223587, 17.26652908], [73.22209167, 17.26652908], [73.22209167, 17.26681137], [73.22180939, 17.26680565], [73.22180176, 17.26708412], [73.2215271, 17.2670784], [73.2215271, 17.26736069], [73.22125244, 17.26736069], [73.22125244, 17.26763916], [73.22097015, 17.26763916], [73.22097015, 17.26791954], [73.2206955, 17.26791763], [73.2206955, 17.2681942], [73.22041321, 17.26818848], [73.22041321, 17.2684803], [73.22070312, 17.2684803], [73.22070312, 17.26874924], [73.22097015, 17.26874924], [73.22097015, 17.2693119], [73.2206955, 17.26930618], [73.22070312, 17.27013969], [73.21901703, 17.27013969], [73.21901703, 17.26986122], [73.21875, 17.26986122], [73.21875, 17.26958084], [73.21736145, 17.26958084], [73.21736145, 17.26986122], [73.21708679, 17.26986122], [73.21708679, 17.27042007], [73.2168045, 17.27041626], [73.2168045, 17.2709713], [73.21708679, 17.2709713], [73.21708679, 17.27152824], [73.2168045, 17.27152824], [73.2168045, 17.27180481], [73.21652985, 17.27180481], [73.21652985, 17.27208138], [73.2159729, 17.27208138], [73.2159729, 17.27236366], [73.21569824, 17.27235985], [73.21569824, 17.27264023], [73.21541595, 17.27264023], [73.21541595, 17.27292061], [73.2151413, 17.27291679], [73.2151413, 17.27347183], [73.21485901, 17.27346992], [73.21485901, 17.27403069], [73.21458435, 17.27402687], [73.21458435, 17.27458572], [73.21208191, 17.27458], [73.21208191, 17.27514076], [73.21180725, 17.27513885], [73.21180725, 17.2756958], [73.21125031, 17.2756958], [73.21125031, 17.27513885], [73.21098328, 17.27514076], [73.21098328, 17.27320099], [73.21069336, 17.27320099], [73.21069336, 17.27235985], [73.2104187, 17.27236366], [73.2104187, 17.27180481], [73.21013641, 17.27180481], [73.21013641, 17.27152824], [73.2104187, 17.27152824], [73.2104187, 17.27124977], [73.21013641, 17.27124977], [73.21013641, 17.27041626], [73.20929718, 17.27042007], [73.20929718, 17.27013969], [73.20903015, 17.27013969], [73.20903015, 17.26958084], [73.20791626, 17.26958275], [73.20791626, 17.26930618], [73.20735931, 17.2693119], [73.20735931, 17.26902962], [73.20652771, 17.26902962], [73.20652771, 17.26874924], [73.20625305, 17.26874924], [73.20625305, 17.2684803], [73.20458221, 17.2684803], [73.20458221, 17.26874924], [73.20430756, 17.26874924], [73.20430756, 17.26902962], [73.20401764, 17.26902962], [73.20401764, 17.2693119], [73.20375061, 17.2693119], [73.20375061, 17.26986122], [73.20347595, 17.26986122], [73.20347595, 17.27069473], [73.20318604, 17.27069283], [73.20318604, 17.27124977], [73.20291901, 17.27124977], [73.20291901, 17.27320099], [73.20263672, 17.27320099], [73.20263672, 17.27431107], [73.20236206, 17.27431107], [73.20236206, 17.27653122], [73.20207977, 17.27653122], [73.20207977, 17.27736092], [73.20180511, 17.27736092], [73.20181274, 17.27874947], [73.20153046, 17.27874947], [73.20153046, 17.27930832], [73.20124817, 17.27930832], [73.20124817, 17.28013992], [73.20098114, 17.28013992], [73.20098114, 17.28071022], [73.20069122, 17.28071022], [73.20069122, 17.28181267], [73.20041656, 17.28181267], [73.20041656, 17.28292274], [73.20069122, 17.28291702], [73.20069122, 17.28347015], [73.20098114, 17.28346062], [73.20098114, 17.28403282], [73.20124817, 17.28403282], [73.20124817, 17.28430939], [73.20236206, 17.28430557], [73.20236206, 17.28458214], [73.20263672, 17.28458023], [73.20263672, 17.28486061], [73.20291901, 17.28486061], [73.20291901, 17.28541946], [73.20319366, 17.28541756], [73.20319366, 17.28569221], [73.20291901, 17.28569031], [73.20291901, 17.28680992], [73.20263672, 17.28680992], [73.20263672, 17.28736115], [73.20236206, 17.28736115], [73.20236206, 17.28819656], [73.20207977, 17.28819656], [73.20207977, 17.28847313], [73.20124817, 17.28847313], [73.20124817, 17.28819656], [73.20014191, 17.28819656], [73.20014191, 17.28847313], [73.19958496, 17.28847313], [73.19959259, 17.28874969], [73.19902802, 17.28874969], [73.19902802, 17.28903008], [73.19875336, 17.28902817], [73.19875336, 17.28930664], [73.19847107, 17.28930664], [73.19847107, 17.28958321], [73.19819641, 17.28958321], [73.19819641, 17.28986168], [73.19792175, 17.28985977], [73.19792175, 17.29014015], [73.19763947, 17.29014015], [73.19763947, 17.29070091], [73.19735718, 17.29070091], [73.19735718, 17.29264832], [73.19708252, 17.29264832], [73.19708252, 17.29291916], [73.19680786, 17.29291725], [73.19680786, 17.29319382], [73.19596863, 17.29319382], [73.19596863, 17.29347229], [73.19541931, 17.29347038], [73.19541931, 17.29375076], [73.19513702, 17.29375076], [73.19513702, 17.29402924], [73.19484711, 17.29402924], [73.19484711, 17.29513931], [73.19458008, 17.29513931], [73.19458008, 17.29569435], [73.19430542, 17.29569435], [73.19431305, 17.29624939], [73.19235992, 17.29624939], [73.19235992, 17.29652977], [73.19178772, 17.29652977], [73.19178772, 17.29681015], [73.19152832, 17.29680634], [73.19152832, 17.2970829], [73.19069672, 17.2970829], [73.19069672, 17.29736137], [73.18985748, 17.29735947], [73.18985748, 17.29763985], [73.18958282, 17.29763985], [73.18958282, 17.29792023], [73.18930817, 17.29792023], [73.18930817, 17.2990303], [73.18958282, 17.2990284], [73.18958282, 17.29958534], [73.19013977, 17.29958534], [73.19013977, 17.29986382], [73.19097137, 17.29986], [73.19097137, 17.30014038], [73.19124603, 17.30014038], [73.19124603, 17.30042076], [73.19152832, 17.30041695], [73.19152832, 17.30097389], [73.19178772, 17.30097008], [73.19178772, 17.30125046], [73.19124603, 17.30125046], [73.19124603, 17.30181122], [73.19097137, 17.30181122], [73.19097137, 17.30430984], [73.19124603, 17.30430984], [73.19124603, 17.30459023], [73.19152832, 17.30459023], [73.19152832, 17.30486107], [73.19430542, 17.30486107], [73.19430542, 17.30513954], [73.19484711, 17.30513954], [73.19484711, 17.30541992], [73.19513702, 17.30541611], [73.19513702, 17.30569458], [73.19541931, 17.30569077], [73.19541931, 17.30624962], [73.19569397, 17.30624962], [73.19569397, 17.30680466], [73.19680786, 17.30680466], [73.19680786, 17.30652809], [73.19708252, 17.30652809], [73.19708252, 17.30624962], [73.19735718, 17.30624962], [73.19735718, 17.30597115], [73.19763947, 17.30597305], [73.19763947, 17.30569458], [73.19819641, 17.30569458], [73.19819641, 17.30541611], [73.19847107, 17.30541992], [73.19847107, 17.30513954], [73.19875336, 17.30513954], [73.19875336, 17.30486107], [73.19930267, 17.30486107], [73.19930267, 17.30459023], [73.19959259, 17.30459023], [73.19959259, 17.30430984], [73.19985962, 17.30430984], [73.19985962, 17.30208015], [73.20069122, 17.30208588], [73.20069122, 17.30152512], [73.20153046, 17.30153084], [73.20153046, 17.30125046], [73.20173645, 17.30125046], [73.20181274, 17.30097008], [73.20236206, 17.30097389], [73.20236206, 17.30069351], [73.20263672, 17.30069351], [73.20263672, 17.30041695], [73.20291901, 17.30042076], [73.20291901, 17.30014038], [73.20318604, 17.30014038], [73.20318604, 17.29931068], [73.20347595, 17.29931068], [73.20347595, 17.2990303], [73.20401764, 17.2990303], [73.20401764, 17.29931068], [73.20430756, 17.29931068], [73.20430756, 17.2990303], [73.20485687, 17.2990303], [73.20485687, 17.29874992], [73.20569611, 17.29874992], [73.20569611, 17.29931068], [73.20597076, 17.29930305], [73.20597076, 17.29958534], [73.20680237, 17.29958534], [73.20680237, 17.29986382], [73.20735931, 17.29986], [73.20735931, 17.30014038], [73.2076416, 17.30014038], [73.2076416, 17.30042076], [73.20791626, 17.30041695], [73.20791626, 17.30069351], [73.20819092, 17.30069351], [73.20819092, 17.30097389], [73.20847321, 17.30097008], [73.20847321, 17.30125046], [73.20874786, 17.30125046], [73.20874786, 17.30208588], [73.20903015, 17.30208015], [73.20903015, 17.30291939], [73.20930481, 17.30291748], [73.20930481, 17.30319595], [73.2095871, 17.30319595], [73.2095871, 17.30347252], [73.20986176, 17.30347061], [73.20986176, 17.30375099], [73.21006012, 17.30374908], [73.21013641, 17.30374908], [73.21015167, 17.30402946], [73.2104187, 17.30402946], [73.2104187, 17.30430984], [73.21098328, 17.30430984], [73.21098328, 17.30402946], [73.21153259, 17.30402946], [73.21153259, 17.30347061], [73.21180725, 17.30347252], [73.21180725, 17.30319595], [73.21347046, 17.30319595], [73.21347046, 17.30291748], [73.21430206, 17.30291939], [73.21430206, 17.30264091], [73.21541595, 17.30264091], [73.21541595, 17.30236053], [73.21679688, 17.30236053], [73.21679688, 17.30264091], [73.21736145, 17.30264091], [73.21736145, 17.30291939], [73.21763611, 17.30291748], [73.21763611, 17.30319595], [73.2179184, 17.30319595], [73.2179184, 17.30291748], [73.21875, 17.30291939], [73.21875, 17.30264091], [73.2195816, 17.30264091], [73.2195816, 17.30236053], [73.22097015, 17.30236053], [73.22097015, 17.30291939], [73.22209167, 17.30291939], [73.22209167, 17.30264091], [73.2223587, 17.30264091], [73.2223587, 17.30236053], [73.22264099, 17.30236053], [73.22264099, 17.30181122], [73.22292328, 17.30181122], [73.22292328, 17.30153084], [73.2234726, 17.30153084], [73.2234726, 17.30125046], [73.22374725, 17.30125046], [73.22374725, 17.30097008], [73.22402954, 17.30097389], [73.22402954, 17.30083084], [73.22402954, 17.30069351], [73.2243042, 17.30069351], [73.2243042, 17.29958534], [73.22402954, 17.29958534], [73.22402954, 17.29930305], [73.22374725, 17.29931068], [73.22374725, 17.29874992], [73.2234726, 17.29874992], [73.2234726, 17.29819107], [73.22319794, 17.29819489], [73.22319794, 17.29763985], [73.22292328, 17.29763985], [73.22292328, 17.29624939], [73.22264099, 17.29624939], [73.22264099, 17.29568863], [73.2223587, 17.29569435], [73.2223587, 17.29541588], [73.22180176, 17.2954216], [73.22180176, 17.29486084], [73.22209167, 17.29486084], [73.22208405, 17.29458427], [73.2223587, 17.29458237], [73.2223587, 17.2943058], [73.22264099, 17.29431152], [73.22264099, 17.29402924], [73.22292328, 17.29402924], [73.22292328, 17.29375076], [73.22319794, 17.29375076], [73.22319794, 17.29347038], [73.2234726, 17.29347229], [73.2234726, 17.29319382], [73.22374725, 17.29319382], [73.22374725, 17.29291725], [73.22402954, 17.29291916], [73.22402954, 17.29207993], [73.22374725, 17.29208374], [73.22374725, 17.29180527], [73.22319794, 17.29180908], [73.22319794, 17.29153061], [73.22374725, 17.29153061], [73.22374725, 17.29125023], [73.22429657, 17.29125023], [73.22429657, 17.29096985], [73.22402954, 17.29097176], [73.22402954, 17.29069519], [73.22429657, 17.29070091], [73.22429657, 17.28874969], [73.22402954, 17.28874969], [73.22402954, 17.28625107], [73.22429657, 17.28625107], [73.22429657, 17.28569031], [73.22458649, 17.28569221], [73.22458649, 17.28541756], [73.22486115, 17.28541946], [73.22486115, 17.28458023], [73.22458649, 17.28458214], [73.22458649, 17.2840271], [73.22486115, 17.28403282], [73.22486115, 17.28346062], [73.2251358, 17.28347015], [73.2251358, 17.28319359], [73.22541809, 17.28319359], [73.22541809, 17.28263855], [73.22569275, 17.28264046], [73.22569275, 17.2820816], [73.22597504, 17.28208351], [73.22597504, 17.28152847], [73.22763824, 17.28153038], [73.22763824, 17.28181267], [73.22821045, 17.28181267], [73.22821045, 17.28264046], [73.22875214, 17.28264046], [73.22875214, 17.28292274], [73.22930908, 17.28291702], [73.22930908, 17.28319359], [73.2298584, 17.28319359], [73.2298584, 17.28347015], [73.23014069, 17.28346062], [73.23014069, 17.28403282], [73.23042297, 17.28403282], [73.23042297, 17.28430939], [73.23069763, 17.28430939], [73.23069763, 17.28486061], [73.23095703, 17.28486061], [73.23095703, 17.28541946], [73.23152924, 17.28541756], [73.23152924, 17.28569221], [73.23180389, 17.28569221], [73.23180389, 17.2859745], [73.23236084, 17.28597069], [73.23236084, 17.28625107], [73.23458099, 17.28625107], [73.23458099, 17.28680992], [73.23486328, 17.28680992], [73.23486328, 17.28763962], [73.23513794, 17.28763962], [73.23513794, 17.28847313], [73.23542023, 17.28847313], [73.23542023, 17.28930664], [73.23569489, 17.28930664], [73.23569489, 17.28986168], [73.23596954, 17.28985977], [73.23596954, 17.29070091], [73.23625183, 17.29070091], [73.23626709, 17.29153061], [73.23652649, 17.2915287], [73.23652649, 17.29208374], [73.23680878, 17.29207993], [73.23680878, 17.29264832], [73.23603058, 17.29263878], [73.23513794, 17.29263878], [73.23513794, 17.29319382], [73.23486328, 17.29319382], [73.23486328, 17.29347229], [73.23513794, 17.29347038], [73.23513794, 17.29431152], [73.23542023, 17.2943058], [73.23542023, 17.29458237], [73.23557281, 17.29458046], [73.23568726, 17.29458046], [73.23568726, 17.29486084], [73.23596954, 17.29486084], [73.23596954, 17.29513931], [73.23652649, 17.29513931], [73.23652649, 17.2954216], [73.23708344, 17.29541588], [73.23708344, 17.29569435], [73.23680878, 17.29568863], [73.23680878, 17.29624939], [73.23708344, 17.29624939], [73.23708344, 17.2970829], [73.23735809, 17.2970829], [73.23735809, 17.29763985], [73.23764038, 17.29763985], [73.23764038, 17.29792023], [73.23791504, 17.29791641], [73.23791504, 17.29819489], [73.23819733, 17.29819107], [73.23819733, 17.29874992], [73.23847198, 17.29874992], [73.23847198, 17.29931068], [73.23874664, 17.29930305], [73.23874664, 17.29986382], [73.23902893, 17.29986382], [73.23902893, 17.30069351], [73.23930359, 17.30069351], [73.23930359, 17.30097389], [73.23958588, 17.30097008], [73.23958588, 17.30153084], [73.23986053, 17.30153084], [73.23986053, 17.30236053], [73.23958588, 17.30236053], [73.23958588, 17.30319595], [73.23929596, 17.30319023], [73.23929596, 17.30486107], [73.23986053, 17.30486107], [73.23986053, 17.30513954], [73.24013519, 17.30513954], [73.24013519, 17.30569458], [73.24041748, 17.30569458], [73.24041748, 17.30597305], [73.24069214, 17.30597115], [73.24069214, 17.30624962], [73.2409668, 17.30624962], [73.2409668, 17.30652809], [73.24236298, 17.30652809], [73.24236298, 17.30680466], [73.24402618, 17.30680466], [73.24402618, 17.3073616], [73.24346924, 17.3073597], [73.24346924, 17.30764961], [73.24318695, 17.30764961], [73.24318695, 17.30791855], [73.24263763, 17.30791855], [73.24263763, 17.3073597], [73.24236298, 17.3073597], [73.24236298, 17.30764961], [73.24208069, 17.30764961], [73.24208069, 17.30791855], [73.24180603, 17.30791855], [73.24180603, 17.30875015], [73.24153137, 17.30875015], [73.24153137, 17.30903244], [73.24180603, 17.30903244], [73.24180603, 17.30986023], [73.24208069, 17.30986023], [73.24208069, 17.31125069], [73.24236298, 17.31125069], [73.24236298, 17.31236076], [73.24208069, 17.31236076], [73.24208069, 17.31264114], [73.24180603, 17.31263924], [73.24180603, 17.31319237], [73.24153137, 17.31319046], [73.24153137, 17.31513977], [73.24180603, 17.31513977], [73.24180603, 17.31597137], [73.24153137, 17.31596947], [73.24153137, 17.31653023], [73.24208069, 17.31653023], [73.24208069, 17.31792068], [73.24236298, 17.31791878], [73.24236298, 17.31847191], [73.24263763, 17.31846809], [73.24263763, 17.31875038], [73.24180603, 17.31875038], [73.24180603, 17.31846809], [73.24153137, 17.31847191], [73.24153137, 17.31791878], [73.24124908, 17.31792068], [73.24124908, 17.3176403], [73.2409668, 17.3176403], [73.2409668, 17.31735992], [73.23929596, 17.31735992], [73.23929596, 17.3176403], [73.23902893, 17.3176403], [73.23902893, 17.31792068], [73.23847198, 17.31792068], [73.23847198, 17.31820107], [73.23819733, 17.31819534], [73.23819733, 17.31847191], [73.23735809, 17.31846809], [73.23735809, 17.31875038], [73.23430634, 17.31875038], [73.23430634, 17.31903076], [73.23374939, 17.31903076], [73.23374939, 17.31930923], [73.23208618, 17.31930923], [73.23208618, 17.31903076], [73.22930908, 17.31903076], [73.22930908, 17.31930923], [73.22902679, 17.31930923], [73.22902679, 17.31958771], [73.22875214, 17.31958771], [73.22875214, 17.32041931], [73.22819519, 17.3204174], [73.22819519, 17.32069397], [73.2279129, 17.32069397], [73.2279129, 17.32097244], [73.22763824, 17.32097054], [73.22763824, 17.32235909], [73.22736359, 17.32235909], [73.22736359, 17.32263947], [73.22680664, 17.32262993], [73.22680664, 17.32292175], [73.22652435, 17.32291603], [73.22652435, 17.3231945], [73.22624969, 17.3231945], [73.22624969, 17.32347107], [73.22569275, 17.32347107], [73.22569275, 17.32374954], [73.22541809, 17.32374954], [73.22541809, 17.32403183], [73.22515106, 17.32403183], [73.22515106, 17.3243103], [73.22458649, 17.32430649], [73.22458649, 17.32458115], [73.2243042, 17.32458115], [73.2243042, 17.32486153], [73.22374725, 17.32485962], [73.22374725, 17.32514], [73.2234726, 17.32514], [73.2234726, 17.32542038], [73.22291565, 17.32541656], [73.22291565, 17.32569313], [73.2223587, 17.32569313], [73.2223587, 17.3259716], [73.22208405, 17.3259716], [73.22209167, 17.32625008], [73.2215271, 17.32625008], [73.2215271, 17.32653046], [73.22125244, 17.32653046], [73.22125244, 17.32681084], [73.2206955, 17.32680321], [73.2206955, 17.32708549], [73.22041321, 17.32708549], [73.22041321, 17.32736206], [73.22013855, 17.32736015], [73.22013855, 17.32792091], [73.21985626, 17.32792091], [73.21985626, 17.32876015], [73.2195816, 17.32876015], [73.2195816, 17.32903099], [73.21901703, 17.32903099], [73.21901703, 17.32930946], [73.21875, 17.32930756], [73.21875, 17.33097267], [73.21901703, 17.33097076], [73.21901703, 17.33152962], [73.21930695, 17.33152771], [73.21930695, 17.33208275], [73.2195816, 17.33208084], [73.2195816, 17.33236122], [73.21985626, 17.33236122], [73.21985626, 17.33263969], [73.22013855, 17.33263969], [73.22013855, 17.33291817], [73.22041321, 17.33291626], [73.22041321, 17.33319473], [73.22125244, 17.33319473], [73.22125244, 17.3334713], [73.2223587, 17.33346748], [73.2223587, 17.33374977], [73.22319794, 17.33374977], [73.22319794, 17.33346748], [73.22651672, 17.33346748], [73.22651672, 17.33374977], [73.22680664, 17.33374977], [73.22680664, 17.33430481], [73.22597504, 17.33430481], [73.22597504, 17.33458328], [73.22569275, 17.33458328], [73.22569275, 17.33486176], [73.22541809, 17.33486176], [73.22541809, 17.33681107], [73.2251358, 17.33680534], [73.2251358, 17.33736038], [73.22569275, 17.33736038], [73.22569275, 17.33763885], [73.22515106, 17.33762932], [73.22515106, 17.33792114], [73.22458649, 17.33791733], [73.22458649, 17.33819389], [73.22319794, 17.33819389], [73.22319794, 17.33847237], [73.22264099, 17.33847046], [73.22264099, 17.33875084], [73.2223587, 17.33875084], [73.2223587, 17.33903122], [73.22209167, 17.33903122], [73.22209167, 17.33930969], [73.22180939, 17.33930588], [73.22180176, 17.33958244], [73.22125244, 17.33958054], [73.22125244, 17.33986092], [73.22097015, 17.33986092], [73.22097015, 17.34013939], [73.22070312, 17.34013939], [73.22070312, 17.34041977], [73.22041321, 17.34041405], [73.22041321, 17.34097481], [73.22013855, 17.34097099], [73.22013855, 17.34124947], [73.21985626, 17.34124947], [73.21985626, 17.34181023], [73.2195816, 17.34180641], [73.2195816, 17.34208488], [73.21930695, 17.34208107], [73.21930695, 17.34263992], [73.21875, 17.34263992], [73.21875, 17.3429203], [73.2179184, 17.3429203], [73.2179184, 17.34320068], [73.21736145, 17.34319687], [73.21736145, 17.34347153], [73.21679688, 17.34346962], [73.21679688, 17.34375954], [73.21652985, 17.34375954], [73.21652985, 17.34403038], [73.21624756, 17.34403038], [73.21624756, 17.34431076], [73.2159729, 17.34430695], [73.2159729, 17.34458351], [73.21569824, 17.34458351], [73.21569824, 17.34486198], [73.21541595, 17.34486008], [73.21541595, 17.34514046], [73.21485901, 17.34513855], [73.21485901, 17.34569359], [73.21458435, 17.34569359], [73.21458435, 17.34680557], [73.21430206, 17.34680557], [73.21430206, 17.34819412], [73.21457672, 17.3481884], [73.21457672, 17.34902954], [73.21485901, 17.34902954], [73.21485901, 17.34931183], [73.2151413, 17.34930611], [73.2151413, 17.34958267], [73.21541595, 17.34957123], [73.21541595, 17.34986115], [73.21624756, 17.34986115], [73.21624756, 17.35013962], [73.21652985, 17.35013962], [73.21652985, 17.35069466], [73.2168045, 17.35069466], [73.2168045, 17.35097122], [73.21736145, 17.35097122], [73.21736145, 17.35124969], [73.21875, 17.35124969], [73.21875, 17.35180473], [73.21902466, 17.35180473], [73.21902466, 17.35236168], [73.2195816, 17.35235977], [73.2195816, 17.35264015], [73.21985626, 17.35264015], [73.21985626, 17.35293007], [73.22013855, 17.35293007], [73.22013855, 17.35431099], [73.21985626, 17.35431099], [73.21985626, 17.35653114], [73.2195816, 17.35653114], [73.2195816, 17.35680962], [73.21930695, 17.35680771], [73.21930695, 17.35708427], [73.21901703, 17.35708046], [73.21901703, 17.35736084], [73.21819305, 17.35736084], [73.21819305, 17.35764122], [73.21624756, 17.35763931], [73.21624756, 17.35819435], [73.21595764, 17.35819054], [73.21595764, 17.35930824], [73.21624756, 17.35930634], [73.21624756, 17.3595829], [73.21595764, 17.35957909], [73.21595764, 17.36013985], [73.21569824, 17.36013985], [73.21569824, 17.36041832], [73.21541595, 17.36041641], [73.21541595, 17.36069489], [73.2151413, 17.36068916], [73.2151413, 17.36124992], [73.21485901, 17.36124992], [73.21485901, 17.3615303], [73.21458435, 17.3615284], [73.21458435, 17.36180496], [73.21430206, 17.36180496], [73.21430206, 17.36208344], [73.2140274, 17.36208153], [73.2140274, 17.36292267], [73.21375275, 17.36292267], [73.21375275, 17.36375046], [73.2140274, 17.36375046], [73.2140274, 17.36431122], [73.21430206, 17.3643055], [73.21430206, 17.36458206], [73.21457672, 17.36458015], [73.21457672, 17.36514282], [73.21485901, 17.36513901], [73.21485901, 17.36569214], [73.2151413, 17.36569023], [73.2151413, 17.3662529], [73.21541595, 17.3662529], [73.21541595, 17.36680984], [73.21569824, 17.36680984], [73.21569824, 17.36736107], [73.21595764, 17.36736107], [73.21595764, 17.36792946], [73.21624756, 17.3679142], [73.21624756, 17.36847305], [73.21652985, 17.36847115], [73.21652985, 17.36903], [73.2168045, 17.36902809], [73.2168045, 17.36958313], [73.21652985, 17.36958122], [73.21652985, 17.37014008], [73.21624756, 17.37013626], [73.21624756, 17.37097168], [73.21485901, 17.37097168], [73.21485901, 17.37069511], [73.21457672, 17.37070084], [73.21457672, 17.37042046], [73.21375275, 17.37042046], [73.21375275, 17.37070084], [73.2095871, 17.37069511], [73.2095871, 17.37097168], [73.20929718, 17.37096977], [73.20929718, 17.37125015], [73.20903015, 17.37125015], [73.20903015, 17.37153053], [73.20874786, 17.37153053], [73.20874786, 17.37236023], [73.20903015, 17.37236023], [73.20903015, 17.37291908], [73.20930481, 17.37291718], [73.20930481, 17.37375069], [73.2095871, 17.37374115], [73.2095871, 17.37486076], [73.20986176, 17.37486076], [73.20986176, 17.37541962], [73.21013641, 17.3754158], [73.21013641, 17.37597275], [73.2104187, 17.37597275], [73.2104187, 17.3773613], [73.21015167, 17.37735939], [73.21015167, 17.37792015], [73.20986176, 17.37792015], [73.20986176, 17.37874985], [73.2095871, 17.37874985], [73.2095871, 17.37958336], [73.20929718, 17.37957954], [73.20929718, 17.3801403], [73.20903015, 17.3801403], [73.20903015, 17.38042068], [73.20874786, 17.38042068], [73.20874786, 17.38181114], [73.20847321, 17.38180351], [73.20847321, 17.3820858], [73.20819092, 17.38208008], [73.20819092, 17.38236046], [73.20791626, 17.38236046], [73.20791626, 17.3829174], [73.2076416, 17.3829174], [73.2076416, 17.38347244], [73.20735931, 17.38347054], [73.20735931, 17.38375092], [73.20707703, 17.38375092], [73.20707703, 17.38430977], [73.20652771, 17.38430786], [73.20652771, 17.38458252], [73.20625305, 17.38458061], [73.20625305, 17.38513947], [73.20540619, 17.38513947], [73.20540619, 17.38486099], [73.20513916, 17.38486099], [73.20513916, 17.38458061], [73.20430756, 17.38458252], [73.20430756, 17.38430786], [73.20295715, 17.38430786], [73.20236206, 17.38430786], [73.20236206, 17.38458252], [73.20207977, 17.38458061], [73.20207977, 17.38486099], [73.20180511, 17.38486099], [73.20181274, 17.38513947], [73.20153046, 17.38513947], [73.20153046, 17.3856945], [73.20124817, 17.3856945], [73.20124817, 17.38597298], [73.20097351, 17.38597298], [73.20097351, 17.38736153], [73.19985962, 17.38735962], [73.19985962, 17.38763809], [73.19957733, 17.38763809], [73.19957733, 17.38791847], [73.19902802, 17.38791847], [73.19902802, 17.38763809], [73.19735718, 17.38763809], [73.19735718, 17.38735962], [73.19708252, 17.38736153], [73.19708252, 17.38708305], [73.19736481, 17.38708305], [73.19736481, 17.38652992], [73.19763947, 17.38652992], [73.19763947, 17.38624954], [73.19625092, 17.38624954], [73.19625092, 17.38652992], [73.19596863, 17.38652992], [73.19596863, 17.3868084], [73.19569397, 17.38680649], [73.19569397, 17.38708305], [73.19541931, 17.38708305], [73.19541931, 17.38736153], [73.19484711, 17.38735962], [73.19484711, 17.38791847], [73.19458008, 17.38791847], [73.19458008, 17.38820267], [73.19291687, 17.38819504], [73.19291687, 17.3884716], [73.19264221, 17.3884716], [73.19264221, 17.38875008], [73.19097137, 17.38875008], [73.19097137, 17.3884716], [73.19041443, 17.3884716], [73.19041443, 17.38763809], [73.19013977, 17.38763809], [73.19013977, 17.3873024], [73.19013977, 17.38708305], [73.19041443, 17.38708305], [73.19041443, 17.38624954], [73.19069672, 17.38624954], [73.19069672, 17.38486099], [73.1904068, 17.38486099], [73.1904068, 17.38458061], [73.19013977, 17.38458252], [73.19013977, 17.38430786], [73.18958282, 17.38430977], [73.18958282, 17.38486099], [73.18930817, 17.38486099], [73.18930817, 17.38513947], [73.18875122, 17.38513947], [73.18875122, 17.38541985], [73.18763733, 17.38541985], [73.18763733, 17.38513947], [73.18541718, 17.38513947], [73.18541718, 17.38458061], [73.18514252, 17.38458061], [73.18514252, 17.38486099], [73.18374634, 17.38486099], [73.18374634, 17.38513947], [73.18347168, 17.38513947], [73.18347168, 17.3856945], [73.18291473, 17.3856945], [73.18291473, 17.38597298], [73.18235779, 17.38597107], [73.18235779, 17.38624954], [73.18152618, 17.38624954], [73.18152618, 17.3868084], [73.18125153, 17.38680649], [73.18125153, 17.38708305], [73.17958069, 17.38708305], [73.17958069, 17.38680649], [73.17903137, 17.38680649], [73.17903137, 17.38708305], [73.17708588, 17.38708305], [73.17708588, 17.38736153], [73.17652893, 17.38735962], [73.17652893, 17.38791847], [73.17624664, 17.38791656], [73.17624664, 17.3884716], [73.17597198, 17.3884716], [73.17597198, 17.38931274], [73.17569733, 17.38930511], [73.17569733, 17.38986015], [73.17485809, 17.38986015], [73.17485809, 17.39014053], [73.17458344, 17.39013863], [73.17458344, 17.39069366], [73.17430878, 17.39069176], [73.17430878, 17.3915329], [73.17402649, 17.39152718], [73.17404175, 17.39236069], [73.17375183, 17.39236069], [73.17375183, 17.39431], [73.17346954, 17.39431], [73.17346954, 17.39542007], [73.17319489, 17.39541435], [73.17319489, 17.39569664], [73.17292023, 17.39569092], [73.17292023, 17.39624977], [73.17263794, 17.39624977], [73.17263794, 17.39653015], [73.17208099, 17.39652824], [73.17208099, 17.39708328], [73.17180634, 17.39708328], [73.17180634, 17.39736176], [73.17151642, 17.39735985], [73.17151642, 17.39764023], [73.17124939, 17.39763641], [73.17124939, 17.3979187], [73.1709671, 17.39791107], [73.1709671, 17.39819908], [73.17067719, 17.39819908], [73.17067719, 17.39903069], [73.17041779, 17.39902878], [73.17041779, 17.39958382], [73.1701355, 17.39958382], [73.17014313, 17.39986038], [73.16986084, 17.39986038], [73.16986084, 17.40041924], [73.16958618, 17.40041733], [73.16958618, 17.40069389], [73.16930389, 17.40069389], [73.16930389, 17.40097237], [73.16902924, 17.40097046], [73.16902924, 17.40152931], [73.16874695, 17.40152931], [73.16874695, 17.4018116], [73.16847229, 17.4018116], [73.16847229, 17.40236092], [73.16819763, 17.40236092], [73.16819763, 17.40292168], [73.16791534, 17.40291595], [73.16791534, 17.40319443], [73.16764069, 17.40319252], [73.16764069, 17.40431023], [73.1673584, 17.40431023], [73.1673584, 17.40513992], [73.16708374, 17.40513802], [73.16708374, 17.40597153], [73.1673584, 17.40596962], [73.1673584, 17.40681076], [73.16764069, 17.40680313], [73.16764069, 17.40708542], [73.16791534, 17.40708542], [73.16791534, 17.40736389], [73.16847229, 17.40736008], [73.16847229, 17.40764046], [73.17014313, 17.40764046], [73.17014313, 17.40736008], [73.17041779, 17.40736008], [73.17041779, 17.40764046], [73.17067719, 17.40764046], [73.17067719, 17.40736008], [73.17236328, 17.40736389], [73.17236328, 17.40680313], [73.17263794, 17.40681076], [73.17263794, 17.40653038], [73.17318726, 17.40653038], [73.17318726, 17.40681076], [73.17346954, 17.40680313], [73.17346954, 17.40708542], [73.17457581, 17.4070797], [73.17457581, 17.40792084], [73.17514038, 17.40792084], [73.17514038, 17.40764046], [73.17542267, 17.40764046], [73.17542267, 17.40681076], [73.17514038, 17.40681076], [73.17514038, 17.40653038], [73.17681122, 17.40653038], [73.17681122, 17.40681076], [73.17874908, 17.40680313], [73.17874908, 17.40736389], [73.17847443, 17.40736389], [73.17847443, 17.40819359], [73.17819214, 17.40818977], [73.17819214, 17.40875053], [73.1784668, 17.40875053], [73.1784668, 17.40930939], [73.17874908, 17.40930748], [73.17874908, 17.40986061], [73.1784668, 17.40985107], [73.1784668, 17.41041946], [73.17903137, 17.41041756], [73.17903137, 17.4109726], [73.17930603, 17.41097069], [73.17930603, 17.41125107], [73.17958069, 17.41125107], [73.17958069, 17.41152954], [73.17984772, 17.41152954], [73.17984772, 17.41180992], [73.18013763, 17.41180611], [73.18013763, 17.41208267], [73.18096924, 17.41208076], [73.18096924, 17.41236115], [73.1829071, 17.41236115], [73.1829071, 17.41263962], [73.18319702, 17.41263962], [73.18319702, 17.41236115], [73.18347168, 17.41236115], [73.18347168, 17.41208076], [73.18430328, 17.41208076], [73.18430328, 17.41374969], [73.18458557, 17.41374969], [73.18458557, 17.41430473], [73.18653107, 17.41430473], [73.18653107, 17.41458321], [73.18708038, 17.41457748], [73.18708038, 17.41542244], [73.18653107, 17.41542244], [73.18653107, 17.41570282], [73.18624878, 17.41570282], [73.18624878, 17.41625023], [73.18569183, 17.41625023], [73.18569183, 17.41653252], [73.18514252, 17.41653252], [73.18514252, 17.4168129], [73.18486023, 17.4168129], [73.18486023, 17.41736031], [73.18514252, 17.41736031], [73.18514252, 17.41819382], [73.18541718, 17.41819191], [73.18541718, 17.41875076], [73.18569183, 17.41875076], [73.18569183, 17.41904068], [73.18541718, 17.41904068], [73.18541718, 17.41930962], [73.18569183, 17.41930962], [73.18569183, 17.41986084], [73.18597412, 17.41986084], [73.18597412, 17.42069244], [73.18569183, 17.42069054], [73.18569183, 17.42124939], [73.18541718, 17.42124939], [73.18541718, 17.42292023], [73.18514252, 17.42291451], [73.18514252, 17.42319679], [73.18569183, 17.42319107], [73.18569183, 17.42374992], [73.18598175, 17.42374992], [73.18597412, 17.42319679], [73.18624878, 17.42319679], [73.18624878, 17.42291451], [73.18680573, 17.42291451], [73.18680573, 17.42319679], [73.18708038, 17.42319107], [73.18708038, 17.42431068], [73.18680573, 17.42430687], [73.18680573, 17.42486191], [73.18653107, 17.42486191], [73.18653107, 17.42569351], [73.18681335, 17.4256897], [73.18681335, 17.42653084], [73.18708038, 17.42653084], [73.18708038, 17.42902946], [73.18680573, 17.42902756], [73.18680573, 17.43069458], [73.18708038, 17.43069267], [73.18708038, 17.43098068], [73.18763733, 17.43098068], [73.18763733, 17.43124962], [73.18791962, 17.43124962], [73.18791962, 17.43153191], [73.18819427, 17.43152809], [73.18819427, 17.43180466], [73.18930817, 17.43180466], [73.18930817, 17.43208122], [73.18985748, 17.43208122], [73.18985748, 17.4323616], [73.1904068, 17.4323597], [73.1904068, 17.43264008], [73.19207764, 17.43264008], [73.19207764, 17.4323597], [73.19235992, 17.4323616], [73.19235992, 17.43208122], [73.19291687, 17.43208122], [73.19291687, 17.4323616], [73.19319153, 17.4323597], [73.19319153, 17.43292046], [73.19346619, 17.43292046], [73.19346619, 17.43375015], [73.19374847, 17.43375015], [73.19374847, 17.43402863], [73.19403076, 17.4340229], [73.19403076, 17.43431091], [73.19431305, 17.43431091], [73.19431305, 17.43514061], [73.19458008, 17.43514061], [73.19458008, 17.43542099], [73.19541931, 17.43541527], [73.19541931, 17.43569565], [73.19568634, 17.43568993], [73.19568634, 17.43625069], [73.19596863, 17.43625069], [73.19596863, 17.43653107], [73.19625092, 17.43652534], [73.19625092, 17.4370842], [73.19652557, 17.4370842], [73.19652557, 17.43736076], [73.19735718, 17.43736076], [73.19735718, 17.43764114], [73.19847107, 17.43764114], [73.19847107, 17.43791962], [73.19958496, 17.43791771], [73.19958496, 17.43819427], [73.19985962, 17.43819427], [73.19985962, 17.43847275], [73.20041656, 17.43847275], [73.20041656, 17.43819427], [73.20069122, 17.43819427], [73.20069122, 17.43791771], [73.20180511, 17.43791771], [73.20180511, 17.43819427], [73.20236206, 17.43819427], [73.20236206, 17.43847275], [73.20401764, 17.43847084], [73.20401764, 17.43875122], [73.20485687, 17.43875122], [73.20485687, 17.43847084], [73.20569611, 17.43847084], [73.20569611, 17.43902969], [73.20430756, 17.43902969], [73.20430756, 17.43930817], [73.20153046, 17.43930626], [73.20153046, 17.43958282], [73.20069122, 17.43958282], [73.20069122, 17.4398613], [73.19985962, 17.43985748], [73.19985962, 17.44014931], [73.19902802, 17.44014931], [73.19902802, 17.44041824], [73.19875336, 17.44041634], [73.19875336, 17.44097137], [73.19847107, 17.44096756], [73.19847107, 17.44124985], [73.19792175, 17.44124985], [73.19792175, 17.44152832], [73.19763947, 17.44152832], [73.19763947, 17.44180489], [73.19680786, 17.44180489], [73.19680786, 17.44208336], [73.19541931, 17.44208336], [73.19541931, 17.44180489], [73.19513702, 17.44180489], [73.19513702, 17.44236183], [73.19346619, 17.44236183], [73.19346619, 17.4426403], [73.19207764, 17.4426403], [73.19207764, 17.44236183], [73.19180298, 17.44236183], [73.19180298, 17.44180489], [73.19152832, 17.44180489], [73.19152832, 17.44152832], [73.1904068, 17.44152832], [73.1904068, 17.44124985], [73.18818665, 17.44124985], [73.18818665, 17.44152832], [73.18680573, 17.44152832], [73.18680573, 17.44180489], [73.18597412, 17.44180489], [73.18597412, 17.44236183], [73.18569183, 17.44236183], [73.18569183, 17.4426403], [73.18598175, 17.4426403], [73.18598175, 17.44292259], [73.18624878, 17.44292259], [73.18624878, 17.4432106], [73.18597412, 17.44319534], [73.18598175, 17.44375038], [73.18569183, 17.44375038], [73.18569183, 17.44431114], [73.18597412, 17.44430542], [73.18597412, 17.44486046], [73.18624878, 17.44486046], [73.18624878, 17.44569206], [73.18597412, 17.44569206], [73.18597412, 17.44847488], [73.18624878, 17.44847107], [73.18624878, 17.4493103], [73.18598175, 17.4493103], [73.18598175, 17.45042038], [73.18624878, 17.45042038], [73.18624878, 17.45125008], [73.18653107, 17.45125008], [73.18653107, 17.45181084], [73.18624878, 17.45181084], [73.18624878, 17.45209122], [73.18597412, 17.45208359], [73.18597412, 17.45236206], [73.18569183, 17.45236015], [73.18569183, 17.45264053], [73.18541718, 17.45264053], [73.18541718, 17.45292091], [73.18514252, 17.4529171], [73.18514252, 17.45319366], [73.18458557, 17.45319366], [73.18458557, 17.45347214], [73.18430328, 17.45346832], [73.18430328, 17.45402908], [73.18458557, 17.45402718], [73.18458557, 17.45458412], [73.18430328, 17.4545784], [73.18430328, 17.45486069], [73.18402863, 17.45486069], [73.18402863, 17.4556942], [73.18430328, 17.45568848], [73.18430328, 17.45624924], [73.18458557, 17.45624924], [73.18458557, 17.45708275], [73.18486023, 17.45708275], [73.18486023, 17.45736122], [73.18514252, 17.45736122], [73.18514252, 17.45763969], [73.18541718, 17.45763969], [73.18541718, 17.45792007], [73.18597412, 17.45791626], [73.18597412, 17.45819473], [73.18624878, 17.45819473], [73.18624878, 17.4584713], [73.18653107, 17.45846939], [73.18653107, 17.45874977], [73.18681335, 17.45874977], [73.18682098, 17.45903015], [73.18708038, 17.45902824], [73.18708038, 17.45930481], [73.18763733, 17.45930481], [73.18763733, 17.45958328], [73.18819427, 17.45958328], [73.18819427, 17.45986176], [73.18846893, 17.45985985], [73.18846893, 17.46014023], [73.18930817, 17.46014023], [73.18930817, 17.46042061], [73.18985748, 17.46041679], [73.18985748, 17.46097183], [73.19013977, 17.46096039], [73.19013977, 17.46125031], [73.1904068, 17.46125031], [73.1904068, 17.46153069], [73.19069672, 17.46153069], [73.19069672, 17.46181107], [73.19097137, 17.46180344], [73.19097137, 17.46208572], [73.19124603, 17.46208], [73.19124603, 17.46236038], [73.19152832, 17.46236038], [73.19152832, 17.46292114], [73.19208527, 17.46291733], [73.19208527, 17.46347237], [73.19264221, 17.46347046], [73.19264221, 17.46541977], [73.19374847, 17.46541786], [73.19374847, 17.4659729], [73.19347382, 17.4659729], [73.19347382, 17.46736145], [73.19374847, 17.46736145], [73.19374847, 17.46847153], [73.19346619, 17.46847153], [73.19346619, 17.46903038], [73.19319153, 17.46902847], [73.19319153, 17.47013855], [73.19291687, 17.47013855], [73.19291687, 17.47069359], [73.19264221, 17.47069359], [73.19264221, 17.47208214], [73.19235992, 17.47208023], [73.19235992, 17.47236061], [73.19207764, 17.47236061], [73.19207764, 17.4726429], [73.19178772, 17.4726429], [73.19178772, 17.47291946], [73.19125366, 17.47291756], [73.19125366, 17.47319221], [73.19097137, 17.47319031], [73.19097137, 17.47375107], [73.19069672, 17.47375107], [73.19069672, 17.47542], [73.19041443, 17.47541428], [73.19041443, 17.47569656], [73.19013977, 17.47569656], [73.19013977, 17.47597313], [73.18985748, 17.47597122], [73.18985748, 17.47626114], [73.18958282, 17.47624969], [73.18958282, 17.47708321], [73.18930817, 17.47707939], [73.18930817, 17.47792053], [73.18902588, 17.47791862], [73.18902588, 17.47847176], [73.18875122, 17.47846985], [73.18875122, 17.47903061], [73.18846893, 17.47903061], [73.18846893, 17.47931862], [73.18875122, 17.47930527], [73.18875122, 17.47958374], [73.18902588, 17.47958374], [73.18902588, 17.48097229], [73.18875122, 17.48097038], [73.18875122, 17.48152924], [73.18846893, 17.48152924], [73.18846893, 17.48181152], [73.18818665, 17.48181152], [73.18818665, 17.48236084], [73.18791962, 17.48236084], [73.18791962, 17.48291969], [73.18763733, 17.48291588], [73.18763733, 17.48347282], [73.18736267, 17.48347282], [73.18736267, 17.48402977], [73.18708038, 17.48402786], [73.18708038, 17.48486137], [73.18681335, 17.48485947], [73.18681335, 17.48542023], [73.18653107, 17.48541641], [73.18653107, 17.48597145], [73.18624878, 17.48596954], [73.18624878, 17.48681068], [73.18597412, 17.48680305], [73.18597412, 17.48736382], [73.18569183, 17.48736], [73.18569183, 17.48792076], [73.18541718, 17.48791695], [73.18541718, 17.48847198], [73.18486023, 17.48847198], [73.18486023, 17.48958588], [73.1845932, 17.48958015], [73.1845932, 17.49014091], [73.18486023, 17.4901371], [73.18486023, 17.49069595], [73.18514252, 17.49069023], [73.18514252, 17.49126053], [73.18486023, 17.49126053], [73.18486023, 17.49180984], [73.18458557, 17.49180794], [73.18458557, 17.4920826], [73.18430328, 17.4920826], [73.18430328, 17.4948616], [73.18347168, 17.4948597], [73.18347168, 17.49514008], [73.18319702, 17.49514008], [73.18319702, 17.49570274], [73.18291473, 17.49569511], [73.18291473, 17.49597168], [73.18347168, 17.49597168], [73.18347168, 17.49625015], [73.18319702, 17.49625015], [73.18319702, 17.49681282], [73.1829071, 17.49681282], [73.1829071, 17.4979229], [73.18264008, 17.4979229], [73.18264008, 17.49875069], [73.18235779, 17.49875069], [73.18235779, 17.50041962], [73.18152618, 17.50041962], [73.18152618, 17.50125122], [73.18180847, 17.50124931], [73.18180847, 17.50208282], [73.18125153, 17.50208282], [73.18125153, 17.5023613], [73.18152618, 17.50235939], [73.18152618, 17.50292015], [73.18180847, 17.50292015], [73.18180847, 17.50320053], [73.18319702, 17.50319672], [73.18319702, 17.50347137], [73.18347168, 17.50346947], [73.18347168, 17.50374985], [73.18374634, 17.50374985], [73.18374634, 17.50403023], [73.18402863, 17.50403023], [73.18402863, 17.50569916], [73.18347168, 17.50569916], [73.18347168, 17.5051403], [73.18319702, 17.5051403], [73.18319702, 17.50457954], [73.18291473, 17.50458336], [73.18291473, 17.50402832], [73.18235779, 17.50402832], [73.18235779, 17.50430679], [73.18180847, 17.50430679], [73.18180847, 17.50458336], [73.18152618, 17.50457954], [73.18152618, 17.50764084], [73.18125153, 17.50764084], [73.18125153, 17.50791931], [73.18096924, 17.5079174], [73.18096924, 17.50819397], [73.18069458, 17.50819397], [73.18069458, 17.50847244], [73.18013763, 17.50847054], [73.18013763, 17.50985909], [73.17984772, 17.50985909], [73.17984772, 17.51042175], [73.17958069, 17.51041603], [73.17958069, 17.5106945], [73.17903137, 17.5106945], [73.17903137, 17.51041603], [73.17791748, 17.51041603], [73.17791748, 17.5106945], [73.17763519, 17.5106945], [73.17763519, 17.51097107], [73.17736053, 17.51097107], [73.17736053, 17.5118103], [73.17708588, 17.51180649], [73.17708588, 17.51236153], [73.17681122, 17.51235962], [73.17681122, 17.51320076], [73.17652893, 17.51319313], [73.17652893, 17.5134716], [73.17624664, 17.5134716], [73.17624664, 17.51458549], [73.17569733, 17.51458549], [73.17569733, 17.51486206], [73.17542267, 17.51486015], [73.17542267, 17.51514053], [73.17569733, 17.51514053], [73.17569733, 17.51653099], [73.17541504, 17.51652527], [73.17542267, 17.51736069], [73.17485809, 17.51736069], [73.17485809, 17.51764107], [73.17457581, 17.51764107], [73.17457581, 17.51791954], [73.17404175, 17.51791954], [73.17404175, 17.51819992], [73.17375183, 17.5181942], [73.17375183, 17.51847267], [73.17346954, 17.51847076], [73.17346954, 17.51875114], [73.17236328, 17.51875114], [73.17236328, 17.51847076], [73.17208099, 17.51847267], [73.17208099, 17.5181942], [73.17152405, 17.5181942], [73.17152405, 17.51847267], [73.1709671, 17.51847076], [73.1709671, 17.51875114], [73.17041779, 17.51875114], [73.17041779, 17.51930809], [73.1701355, 17.51930618], [73.1701355, 17.51958275], [73.16986084, 17.51958084], [73.16986084, 17.51986122], [73.16958618, 17.51986122], [73.16958618, 17.52041817], [73.16930389, 17.52041626], [73.16930389, 17.52124977], [73.16874695, 17.52124023], [73.16874695, 17.52152824], [73.16847229, 17.52152824], [73.16847229, 17.52180481], [73.16819763, 17.52179909], [73.16819763, 17.52292252], [73.16790771, 17.52292252], [73.16790771, 17.52375031], [73.16764069, 17.52375031], [73.16764069, 17.52403259], [73.1673584, 17.52402687], [73.1673584, 17.52430534], [73.16708374, 17.52430534], [73.16708374, 17.52458382], [73.16680908, 17.52458191], [73.16680908, 17.52514076], [73.16652679, 17.52513885], [73.16652679, 17.52597237], [73.16596985, 17.52597046], [73.16596985, 17.52625084], [73.16570282, 17.52625084], [73.16570282, 17.52653122], [73.16513824, 17.52653122], [73.16513824, 17.52680969], [73.16486359, 17.52680588], [73.16486359, 17.52708244], [73.16430664, 17.52708054], [73.16430664, 17.52737045], [73.16401672, 17.52737045], [73.16401672, 17.52763939], [73.16374969, 17.52763939], [73.16374969, 17.52791977], [73.16347504, 17.52791405], [73.16347504, 17.52819633], [73.16319275, 17.52819633], [73.16319275, 17.52847481], [73.16291809, 17.52847099], [73.16291809, 17.52874947], [73.1626358, 17.52874947], [73.1626358, 17.52931023], [73.16236115, 17.5293045], [73.16236115, 17.52986145], [73.16210175, 17.52985954], [73.16210175, 17.53013992], [73.1609726, 17.53013992], [73.1609726, 17.52985954], [73.16069794, 17.52986145], [73.16069794, 17.52958298], [73.16014099, 17.52958298], [73.16014099, 17.5293045], [73.15957642, 17.52931023], [73.15957642, 17.52902985], [73.1590271, 17.52902985], [73.1590271, 17.52874947], [73.1581955, 17.52874947], [73.1581955, 17.52847481], [73.15763855, 17.52847481], [73.15763855, 17.52819633], [73.15569305, 17.52819633], [73.15569305, 17.52847481], [73.1554184, 17.52847099], [73.1554184, 17.52874947], [73.15513611, 17.52874947], [73.15513611, 17.52902985], [73.15458679, 17.52902985], [73.15458679, 17.52931023], [73.1543045, 17.5293045], [73.1543045, 17.52986145], [73.15402985, 17.52985954], [73.15402985, 17.53125], [73.15374756, 17.53125], [73.15374756, 17.53153038], [73.1534729, 17.53152847], [73.1534729, 17.53319359], [73.15374756, 17.53318024], [73.15374756, 17.53430939], [73.15319824, 17.53430939], [73.15319061, 17.53403091], [73.1526413, 17.53403091], [73.1526413, 17.53375053], [73.15180206, 17.53375053], [73.15180206, 17.53458405], [73.1515274, 17.53457832], [73.1515274, 17.53513908], [73.15180206, 17.53513908], [73.15180206, 17.5359726], [73.15208435, 17.5359726], [73.15208435, 17.53624916], [73.15319824, 17.53623962], [73.15319824, 17.53652954], [73.15291595, 17.53652763], [73.15291595, 17.53736115], [73.15319824, 17.53736115], [73.15319824, 17.53819466], [73.15208435, 17.53819466], [73.15208435, 17.53847122], [73.1515274, 17.53847122], [73.1515274, 17.53874969], [73.15125275, 17.53874969], [73.15125275, 17.53903008], [73.15040588, 17.53903008], [73.15040588, 17.53874969], [73.1498642, 17.53874969], [73.1498642, 17.53847122], [73.14930725, 17.53847122], [73.14930725, 17.53874969], [73.14901733, 17.53874969], [73.14901733, 17.53903008], [73.14875031, 17.53902817], [73.14875031, 17.53958321], [73.14819336, 17.53958321], [73.14819336, 17.53986168], [73.14763641, 17.53985977], [73.14763641, 17.54042053], [73.14736176, 17.54042053], [73.14736176, 17.54070091], [73.1470871, 17.54070091], [73.1470871, 17.54125023], [73.14679718, 17.54125023], [73.14679718, 17.54096985], [73.14653015, 17.54096985], [73.14653015, 17.54125023], [73.14624786, 17.54125023], [73.14624786, 17.54153061], [73.14597321, 17.54153061], [73.14597321, 17.54181099], [73.14569092, 17.54180336], [73.14569092, 17.54208565], [73.14541626, 17.54207993], [73.14541626, 17.54236984], [73.14485931, 17.54236984], [73.14485931, 17.54264069], [73.14457703, 17.54264069], [73.14457703, 17.54292107], [73.14430237, 17.54291534], [73.14430237, 17.54319382], [73.14402771, 17.54319], [73.14402771, 17.54375076], [73.14373779, 17.54375076], [73.14373779, 17.54403114], [73.14347076, 17.54403114], [73.14347076, 17.54430962], [73.14291382, 17.54430771], [73.14291382, 17.54458427], [73.14263916, 17.54458046], [73.14263916, 17.54486084], [73.14235687, 17.54486084], [73.14235687, 17.54514122], [73.14208221, 17.54513931], [73.14208221, 17.54597282], [73.14180756, 17.54597282], [73.14180756, 17.54819489], [73.14152527, 17.54819489], [73.1415329, 17.54875183], [73.14125061, 17.54875183], [73.14125061, 17.54931259], [73.14097595, 17.54930496], [73.14097595, 17.54958344], [73.14069366, 17.54958344], [73.14069366, 17.54986191], [73.14041901, 17.54986191], [73.14041901, 17.55014038], [73.14013672, 17.55014038], [73.14013672, 17.55042267], [73.13986206, 17.55041695], [73.13986206, 17.5506916], [73.13957977, 17.55069542], [73.13957977, 17.55097008], [73.13930511, 17.55097008], [73.13931274, 17.55125046], [73.13903046, 17.55125046], [73.13903046, 17.55181122], [73.13874817, 17.5518055], [73.13874817, 17.55402946], [73.13874817, 17.55430984], [73.13847351, 17.55430412], [73.13847351, 17.5545826], [73.13819122, 17.55458069], [73.13819122, 17.55513954], [73.13793182, 17.55513954], [73.13793182, 17.55541992], [73.13764191, 17.5554142], [73.13764191, 17.55569649], [73.13735962, 17.55569649], [73.13735962, 17.55597305], [73.13708496, 17.55597305], [73.13708496, 17.5573616], [73.13735962, 17.55735016], [73.13735962, 17.55820084], [73.13764191, 17.55820084], [73.13764191, 17.55986023], [73.13791656, 17.55986023], [73.13791656, 17.56041718], [73.13819122, 17.56041718], [73.13819122, 17.56069374], [73.13846588, 17.56068993], [73.13846588, 17.56180954], [73.13874817, 17.56180954], [73.13874817, 17.56236076], [73.13903046, 17.56236076], [73.13903046, 17.56263924], [73.13931274, 17.56263924], [73.13931274, 17.56291962], [73.13986206, 17.56291962], [73.13986206, 17.56792068], [73.14013672, 17.56792068], [73.14013672, 17.56820107], [73.14041901, 17.56819344], [73.14041901, 17.56847191], [73.14125061, 17.56847], [73.14125061, 17.56875038], [73.14180756, 17.56875038], [73.14180756, 17.56903076], [73.14263916, 17.56903076], [73.14263916, 17.56931114], [73.14290619, 17.56931114], [73.14290619, 17.56986046], [73.14319611, 17.56986046], [73.14319611, 17.57014084], [73.14347076, 17.57014084], [73.14347076, 17.57042122], [73.14375305, 17.5704155], [73.14375305, 17.57069588], [73.14430237, 17.57069588], [73.14430237, 17.57097244], [73.14485931, 17.57097244], [73.14485931, 17.57069588], [73.14541626, 17.57069588], [73.14541626, 17.57097244], [73.14597321, 17.57097054], [73.14597321, 17.57125092], [73.14624786, 17.57125092], [73.14624786, 17.57152939], [73.14653015, 17.57152939], [73.14653015, 17.57180977], [73.14680481, 17.57180786], [73.14680481, 17.57208252], [73.14819336, 17.57208252], [73.14819336, 17.57236099], [73.14847565, 17.57236099], [73.14847565, 17.57263947], [73.14875031, 17.57263947], [73.14875031, 17.57291985], [73.14930725, 17.57291794], [73.14930725, 17.5731945], [73.14958191, 17.5731945], [73.14958191, 17.57347298], [73.1515274, 17.57347107], [73.1515274, 17.57374954], [73.15235901, 17.57374954], [73.15235901, 17.57347107], [73.1526413, 17.57347298], [73.1526413, 17.5731945], [73.15291595, 17.5731945], [73.15291595, 17.57291794], [73.1534729, 17.57291985], [73.1534729, 17.57263947], [73.15374756, 17.57263947], [73.15374756, 17.57234955], [73.15402985, 17.57236099], [73.15402985, 17.57180786], [73.15429688, 17.57180977], [73.15429688, 17.57125092], [73.15458679, 17.57125092], [73.15458679, 17.57102966], [73.15458679, 17.57069588], [73.15486145, 17.57069588], [73.15486145, 17.5704155], [73.15513611, 17.57042122], [73.15513611, 17.57014084], [73.1554184, 17.57014084], [73.1554184, 17.56986046], [73.1556778, 17.56986046], [73.1556778, 17.56847], [73.15513611, 17.56847191], [73.15513611, 17.56819344], [73.1554184, 17.56820107], [73.1554184, 17.5676403], [73.1556778, 17.5676403], [73.1556778, 17.56707954], [73.15597534, 17.56708336], [73.15597534, 17.56680489], [73.1570816, 17.56680489], [73.1570816, 17.56708336], [73.15736389, 17.56708336], [73.15736389, 17.56736183], [73.15763855, 17.56735992], [73.15763855, 17.5676403], [73.1598587, 17.5676403], [73.1598587, 17.56792068], [73.16014099, 17.56792068], [73.16014099, 17.56820107], [73.1609726, 17.56819344], [73.1609726, 17.56847191], [73.16319275, 17.56847], [73.16319275, 17.57014084], [73.16304016, 17.57014084], [73.16291809, 17.57014084], [73.16291809, 17.57042122], [73.1626358, 17.5704155], [73.1626358, 17.57069588], [73.16236115, 17.57069588], [73.16236115, 17.57097244], [73.16208649, 17.57097244], [73.16208649, 17.57125092], [73.1618042, 17.57125092], [73.1618042, 17.57236099], [73.16208649, 17.57236099], [73.16210175, 17.57430077], [73.16236115, 17.5743084], [73.16236115, 17.57513809], [73.16210175, 17.57513809], [73.16210175, 17.57542038], [73.16236115, 17.57542038], [73.16236115, 17.57570267], [73.1626358, 17.57570267], [73.1626358, 17.57625008], [73.16291809, 17.57625008], [73.16291809, 17.57653046], [73.16319275, 17.57653046], [73.16319275, 17.57681274], [73.16374969, 17.57680511], [73.16374969, 17.57708359], [73.16625214, 17.57708168], [73.16625214, 17.57736015], [73.16652679, 17.57736015], [73.16652679, 17.57792282], [73.16680908, 17.57792282], [73.16680908, 17.57875061], [73.16707611, 17.57875061], [73.16707611, 17.57930946], [73.1673584, 17.57930946], [73.1673584, 17.58014107], [73.16764069, 17.58013916], [73.16764069, 17.58069229], [73.16791534, 17.58069229], [73.16791534, 17.58152771], [73.16819763, 17.58152771], [73.16819763, 17.58208275], [73.16847229, 17.58208084], [73.16847229, 17.58236122], [73.1673584, 17.58236122], [73.1673584, 17.58292007], [73.16708374, 17.58291435], [73.16708374, 17.5834713], [73.16680908, 17.58346939], [73.16680908, 17.58374977], [73.16625214, 17.58374977], [73.16625214, 17.58403015], [73.16596985, 17.58402634], [73.16596985, 17.58430672], [73.16569519, 17.58430672], [73.16569519, 17.58486176], [73.1654129, 17.58485985], [73.1654129, 17.58514023], [73.16513824, 17.58514023], [73.16513824, 17.58569908], [73.16487122, 17.58569908], [73.16487122, 17.58680916], [73.16430664, 17.58680916], [73.16430664, 17.58764076], [73.16374969, 17.58764076], [73.16374969, 17.58791924], [73.16348267, 17.58791924], [73.16348267, 17.58902931], [73.16291809, 17.58902931], [73.16291809, 17.5893116], [73.1626358, 17.5893116], [73.16265106, 17.59013939], [73.16208649, 17.59013939], [73.16208649, 17.59032059], [73.16210175, 17.59124947], [73.16124725, 17.59124947], [73.16124725, 17.59152985], [73.16042328, 17.59152985], [73.16042328, 17.59181023], [73.15958405, 17.59180641], [73.15958405, 17.59208107], [73.15847015, 17.59208107], [73.15847015, 17.59180641], [73.15734863, 17.59180641], [73.15652466, 17.59180641], [73.15652466, 17.59208107], [73.1554184, 17.59208107], [73.1554184, 17.59236145], [73.15513611, 17.59235954], [73.15513611, 17.59263992], [73.15486145, 17.59263992], [73.15486145, 17.5929203], [73.15458679, 17.5929203], [73.15458679, 17.59320068], [73.15402985, 17.59320068], [73.15402985, 17.59375], [73.15374756, 17.59375], [73.15374756, 17.59403038], [73.1534729, 17.59403038], [73.1534729, 17.59431076], [73.15235901, 17.59431076], [73.15235901, 17.59514046], [73.15208435, 17.59513855], [73.15208435, 17.59567261], [73.15208435, 17.59597206], [73.15235901, 17.59597015], [73.15235901, 17.59680939], [73.1526413, 17.59680939], [73.1526413, 17.59736061], [73.15291595, 17.59736061], [73.15291595, 17.5984726], [73.15125275, 17.5984726], [73.15125275, 17.59819412], [73.1498642, 17.59819412], [73.1498642, 17.59791756], [73.14962769, 17.59791756], [73.14902496, 17.59791756], [73.14902496, 17.59819412], [73.14819336, 17.59819412], [73.14819336, 17.5984726], [73.1479187, 17.59847069], [73.1479187, 17.59875107], [73.14736176, 17.59875107], [73.14736176, 17.59902954], [73.1470871, 17.59902954], [73.1470871, 17.59958267], [73.14679718, 17.59958076], [73.14679718, 17.60013962], [73.14597321, 17.60013962], [73.14597321, 17.60041809], [73.14541626, 17.60041618], [73.14541626, 17.60069466], [73.14485931, 17.60069466], [73.14485931, 17.60097313], [73.14457703, 17.60097122], [73.14457703, 17.60124969], [73.14430237, 17.60124969], [73.14430237, 17.60152817], [73.14402771, 17.60152817], [73.14402771, 17.60180473], [73.14373779, 17.60180092], [73.14373779, 17.60292244], [73.14347076, 17.60292244], [73.14347076, 17.60320282], [73.14319611, 17.60320282], [73.14319611, 17.60375023], [73.14290619, 17.60375023], [73.14290619, 17.60403061], [73.1423645, 17.6040287], [73.1423645, 17.60458374], [73.14208221, 17.60458183], [73.14208221, 17.60514069], [73.14152527, 17.60513878], [73.14152527, 17.60569382], [73.14125061, 17.60569382], [73.14125061, 17.60597229], [73.14067841, 17.60597038], [73.14067841, 17.60653114], [73.14041901, 17.60653114], [73.14041901, 17.60736084], [73.14013672, 17.60736084], [73.14013672, 17.60791969], [73.13986206, 17.60791969], [73.13986206, 17.60874939], [73.13957977, 17.60874939], [73.13957977, 17.60902977], [73.13931274, 17.60902977], [73.13931274, 17.60931015], [73.13903046, 17.60930443], [73.13903046, 17.6095829], [73.13846588, 17.60958099], [73.13846588, 17.61013985], [73.13819122, 17.61013985], [73.13819122, 17.61042023], [73.13791656, 17.61041451], [73.13791656, 17.61097145], [73.13735962, 17.61096954], [73.13735962, 17.61181068], [73.13708496, 17.61180687], [73.13708496, 17.61236191], [73.13680267, 17.61235809], [73.13680267, 17.61292076], [73.13652802, 17.61291885], [73.13652802, 17.61347198], [73.13625336, 17.61346817], [73.13625336, 17.61375046], [73.13597107, 17.61375046], [73.13597107, 17.61430931], [73.13569641, 17.61430931], [73.13569641, 17.6145916], [73.13597107, 17.6145916], [73.13597107, 17.61486053], [73.13569641, 17.61486053], [73.13569641, 17.61624908], [73.13541412, 17.61624908], [73.13541412, 17.6170826], [73.13513947, 17.6170826], [73.13513947, 17.61847115], [73.13486481, 17.61847115], [73.13486481, 17.62069321], [73.13458252, 17.62069321], [73.13458252, 17.62097168], [73.13430786, 17.62096977], [73.13430786, 17.62181091], [73.1340332, 17.62181091], [73.1340332, 17.62430954], [73.13375092, 17.62430954], [73.13375092, 17.62541962], [73.13346863, 17.62541771], [73.13346863, 17.6273613], [73.13319397, 17.6273613], [73.13319397, 17.62819481], [73.13291931, 17.62818909], [73.13291931, 17.62875175], [73.13263702, 17.62875175], [73.13263702, 17.62903023], [73.13236237, 17.62903023], [73.13236237, 17.6295929], [73.13180542, 17.62958336], [73.13180542, 17.62986183], [73.13153076, 17.62986183], [73.13153076, 17.63070107], [73.13124847, 17.63069534], [73.13124847, 17.63298035], [73.13124847, 17.63319206], [73.13097382, 17.63319206], [73.13096619, 17.63356972], [73.13096619, 17.63375092], [73.13069153, 17.63375092], [73.13066864, 17.63416862], [73.13066101, 17.63430977], [73.13041687, 17.63430405], [73.13039398, 17.6347599], [73.13038635, 17.63486099], [73.13014221, 17.63486099], [73.13014221, 17.63513947], [73.12930298, 17.63513947], [73.12930298, 17.63541985], [73.12902832, 17.63541412], [73.12902832, 17.6356945], [73.12847137, 17.6356945], [73.12847137, 17.63597488], [73.1279068, 17.63597107], [73.1279068, 17.63624954], [73.12763977, 17.63624954], [73.12763977, 17.63652992], [73.12735748, 17.63652611], [73.12735748, 17.63708305], [73.12708282, 17.63708115], [73.12708282, 17.63764], [73.12735748, 17.63764], [73.12735748, 17.63875961], [73.12763977, 17.63875961], [73.12763977, 17.63903046], [73.1279068, 17.63903046], [73.1279068, 17.63931084], [73.12819672, 17.63930511], [73.12819672, 17.63986206], [73.12791443, 17.63986206], [73.12791443, 17.64069366], [73.12819672, 17.64068985], [73.12819672, 17.64125061], [73.12847137, 17.64125061], [73.12847137, 17.64152908], [73.12902832, 17.64152908], [73.12902832, 17.64182281], [73.12930298, 17.64180565], [73.12930298, 17.64208412], [73.12958527, 17.64208412], [73.12958527, 17.64236069], [73.12985992, 17.64236069], [73.12985992, 17.64263916], [73.13014221, 17.64263916], [73.13014221, 17.6431942], [73.13041687, 17.6431942], [73.13041687, 17.64347267], [73.13069153, 17.64347076], [73.13069153, 17.64375114], [73.13153076, 17.64375114], [73.13153076, 17.64402962], [73.13208008, 17.64402962], [73.13208008, 17.6443119], [73.133461, 17.6443119], [73.13346863, 17.64402962], [73.1340332, 17.64402962], [73.1340332, 17.64375114], [73.13485718, 17.64375114], [73.13485718, 17.64402962], [73.13513947, 17.64402962], [73.13513947, 17.6443119], [73.13569641, 17.64430618], [73.13569641, 17.64458275], [73.13540649, 17.6445694], [73.13540649, 17.64486122], [73.13513947, 17.64486122], [73.13513947, 17.64513969], [73.13485718, 17.64513969], [73.13485718, 17.64820099], [73.13458252, 17.64820099], [73.13458252, 17.64903069], [73.13430786, 17.64903069], [73.13430786, 17.65042114], [73.13402557, 17.65041542], [73.13402557, 17.65097237], [73.13375092, 17.65097046], [73.13375092, 17.65125084], [73.13346863, 17.65125084], [73.13346863, 17.65319443], [73.13318634, 17.65319061], [73.13318634, 17.65376091], [73.13291931, 17.65376091], [73.13291931, 17.65402985], [73.13263702, 17.65402985], [73.13263702, 17.65458298], [73.13236237, 17.65458298], [73.13236237, 17.65486145], [73.13208008, 17.65485764], [73.13208008, 17.6554203], [73.13179779, 17.6554203], [73.13179779, 17.65570259], [73.13153076, 17.65569496], [73.13153076, 17.65597153], [73.13124847, 17.65597153], [73.13124847, 17.65680504], [73.13041687, 17.65680504], [73.13041687, 17.65708351], [73.13014221, 17.6570816], [73.13014221, 17.65764046], [73.12985992, 17.65763855], [73.12985992, 17.65819359], [73.12958527, 17.65819359], [73.12958527, 17.65847206], [73.12798309, 17.65847015], [73.12708282, 17.65847015], [73.12708282, 17.65875053], [73.12652588, 17.65875053], [73.12652588, 17.65930939], [73.12625122, 17.65930939], [73.12625122, 17.66041946], [73.12652588, 17.66041946], [73.12652588, 17.66152954], [73.12625122, 17.66152954], [73.12625122, 17.66180992], [73.12596893, 17.66180992], [73.12596893, 17.66236115], [73.12513733, 17.66236115], [73.12513733, 17.66319656], [73.12541962, 17.66319656], [73.12541962, 17.66430473], [73.12403107, 17.66430473], [73.12403107, 17.66458321], [73.12291718, 17.66458321], [73.12291718, 17.66486168], [73.1220932, 17.66485977], [73.1220932, 17.66514015], [73.12180328, 17.66513634], [73.12180328, 17.66597176], [73.12152863, 17.66596985], [73.12152863, 17.66653061], [73.12124634, 17.66653061], [73.12124634, 17.66736031], [73.12097168, 17.66736031], [73.12097168, 17.66791916], [73.12069702, 17.66791725], [73.12069702, 17.66819382], [73.12097168, 17.66819382], [73.12097168, 17.66875076], [73.12124634, 17.66875076], [73.12124634, 17.67069435], [73.12069702, 17.67069435], [73.12069702, 17.67097282], [73.11985779, 17.67097282], [73.11985779, 17.67124939], [73.11930847, 17.67124939], [73.11930847, 17.67152977], [73.11902618, 17.67152786], [73.11902618, 17.67180634], [73.11875153, 17.67180634], [73.11875153, 17.67236137], [73.11846924, 17.67236137], [73.11846924, 17.67347145], [73.11819458, 17.67347145], [73.11819458, 17.67458344], [73.11791992, 17.67458344], [73.11791992, 17.6756897], [73.11763763, 17.67570114], [73.11763763, 17.67653084], [73.11791992, 17.67653084], [73.11791992, 17.67764091], [73.11763763, 17.6776371], [73.11763763, 17.67847252], [73.11653137, 17.67847061], [73.11653137, 17.67875099], [73.1159668, 17.67875099], [73.1159668, 17.67930984], [73.11569214, 17.67930984], [73.11569214, 17.67986107], [73.11541748, 17.67986107], [73.11541748, 17.68124962], [73.11514282, 17.68124962], [73.11514282, 17.68320274], [73.11541748, 17.68319511], [73.11541748, 17.68375015], [73.11458588, 17.68375015], [73.11458588, 17.68458366], [73.11430359, 17.68458366], [73.11430359, 17.68569374], [73.11458588, 17.68569183], [73.11458588, 17.68625069], [73.11486053, 17.68625069], [73.11486053, 17.68653107], [73.11458588, 17.68653107], [73.11458588, 17.68764114], [73.11429596, 17.68764114], [73.11429596, 17.68875122], [73.11402893, 17.68875122], [73.11402893, 17.68931007], [73.11374664, 17.68930435], [73.11374664, 17.69097137], [73.11402893, 17.69096947], [73.11402893, 17.69153023], [73.11430359, 17.69152641], [73.11430359, 17.69236183], [73.11458588, 17.69235992], [73.11458588, 17.69403076], [73.11402893, 17.69403076], [73.11402893, 17.69430923], [73.11429596, 17.69430923], [73.11429596, 17.69486046], [73.11458588, 17.69486046], [73.11458588, 17.69541931], [73.11486053, 17.6954174], [73.11486053, 17.69569397], [73.11513519, 17.69569397], [73.11513519, 17.69597244], [73.11541748, 17.69597054], [73.11541748, 17.69625092], [73.11569214, 17.69625092], [73.11569214, 17.69652939], [73.1159668, 17.69652939], [73.1159668, 17.69681168], [73.11624908, 17.69680595], [73.11624908, 17.69708252], [73.11653137, 17.69708252], [73.11653137, 17.69763947], [73.1167984, 17.69763947], [73.1167984, 17.69791985], [73.11708069, 17.69791603], [73.11708069, 17.6981945], [73.11736298, 17.6981926], [73.11736298, 17.69874954], [73.11902618, 17.69874954], [73.11902618, 17.69930458], [73.11985779, 17.69930458], [73.11985779, 17.69902802], [73.12097168, 17.69902802], [73.12097168, 17.69930267], [73.12124634, 17.6993103], [73.12124634, 17.70014], [73.12152863, 17.70014], [73.12152863, 17.70042038], [73.12291718, 17.70042038], [73.12291718, 17.70014], [73.12319183, 17.70014], [73.12319183, 17.70042038], [73.12374878, 17.70042038], [73.12374878, 17.70014954], [73.12458038, 17.70014], [73.12458038, 17.70042038], [73.12486267, 17.70041656], [73.12486267, 17.70087051], [73.12486267, 17.7009716], [73.12502289, 17.7009697], [73.12513733, 17.7009697], [73.12513733, 17.70125008], [73.12486267, 17.70125008], [73.12486267, 17.70181084], [73.12513733, 17.70180321], [73.12513733, 17.70208359], [73.12596893, 17.70207977], [73.12596893, 17.70236015], [73.12680054, 17.70236206], [73.12708282, 17.70236206], [73.12708282, 17.70283127], [73.12708282, 17.70319366], [73.12727356, 17.70319366], [73.12735748, 17.70319366], [73.12735748, 17.70403099], [73.12763977, 17.70402527], [73.12763977, 17.70458412], [73.1279068, 17.70458031], [73.1279068, 17.70514107], [73.12847137, 17.70516014], [73.12847137, 17.70541954], [73.12861633, 17.70541763], [73.12875366, 17.70541763], [73.12875366, 17.7056942], [73.12930298, 17.7056942], [73.12930298, 17.70597267], [73.12985992, 17.70597076], [73.12985992, 17.70625114], [73.13041687, 17.70625114], [73.13041687, 17.70652962], [73.13179779, 17.70652962], [73.13179779, 17.70625114], [73.13291931, 17.70625114], [73.13291931, 17.70652962], [73.13318634, 17.70652962], [73.13318634, 17.70680809], [73.13346863, 17.70680618], [73.13346863, 17.70708275], [73.13375092, 17.70708084], [73.13375092, 17.70736122], [73.13458252, 17.70736122], [73.13458252, 17.70791626], [73.13486481, 17.70791626], [73.13486481, 17.70763969], [73.13569641, 17.70763969], [73.13569641, 17.70791626], [73.13513947, 17.70791626], [73.13513947, 17.70819473], [73.13485718, 17.70819092], [73.13485718, 17.70874977], [73.13458252, 17.70874977], [73.13458252, 17.70930481], [73.13486481, 17.70930481], [73.13486481, 17.70986176], [73.13513947, 17.70986176], [73.13513947, 17.71153069], [73.13540649, 17.71153069], [73.13540649, 17.71181107], [73.13513947, 17.71181107], [73.13513947, 17.71292114], [73.13486481, 17.71291733], [73.13486481, 17.71319389], [73.13458252, 17.71319008], [73.13458252, 17.71486092], [73.13486481, 17.71486092], [73.13486481, 17.71569443], [73.13513947, 17.71569061], [73.13513947, 17.71624947], [73.13485718, 17.71624947], [73.13485718, 17.71652985], [73.13458252, 17.71652985], [73.13458252, 17.71681023], [73.13430786, 17.71681023], [73.13430786, 17.71763992], [73.1340332, 17.71763992], [73.1340332, 17.7179203], [73.13375092, 17.7179203], [73.13375092, 17.71874809], [73.13346863, 17.71874809], [73.13346863, 17.72125053], [73.13318634, 17.72125053], [73.13318634, 17.72180939], [73.13291931, 17.72180939], [73.13291931, 17.72236061], [73.13263702, 17.72236061], [73.13263702, 17.72319412], [73.13236237, 17.72319412], [73.13236237, 17.7234726], [73.13263702, 17.72347069], [73.13263702, 17.72402954], [73.13291931, 17.72402954], [73.13291931, 17.72431183], [73.13236237, 17.72430611], [73.13236237, 17.72458267], [73.13208008, 17.72458267], [73.13208008, 17.72513962], [73.13179779, 17.72513962], [73.13179779, 17.72624969], [73.13153076, 17.72624969], [73.13153076, 17.72680473], [73.13180542, 17.72680473], [73.13180542, 17.72708321], [73.13124847, 17.72707939], [73.13124847, 17.72792053], [73.13153076, 17.72792053], [73.13153076, 17.72820091], [73.13124847, 17.72820091], [73.13124847, 17.72875023], [73.13096619, 17.72875023], [73.13096619, 17.72931099], [73.13069153, 17.72930336], [73.13069153, 17.72958374], [73.13041687, 17.72957993], [73.13041687, 17.72986031], [73.12985992, 17.72986031], [73.12985992, 17.73014069], [73.12902832, 17.73013878], [73.12902832, 17.73097229], [73.1287384, 17.73097038], [73.1287384, 17.73180962], [73.12847137, 17.73180962], [73.12847137, 17.73264122], [73.12819672, 17.73263931], [73.12819672, 17.73319435], [73.1279068, 17.73319054], [73.1279068, 17.7365303], [73.12819672, 17.7365284], [73.12819672, 17.73736191], [73.12847137, 17.73736191], [73.12847137, 17.73792267], [73.12819672, 17.73791695], [73.12819672, 17.7381916], [73.12791443, 17.73819542], [73.12791443, 17.73847389], [73.12819672, 17.73847008], [73.12819672, 17.73875046], [73.12847137, 17.73875046], [73.12847137, 17.73903275], [73.12819672, 17.73902702], [73.12819672, 17.73958206], [73.1279068, 17.73958015], [73.1279068, 17.74014091], [73.12763977, 17.74013901], [73.12763977, 17.74069214], [73.12708282, 17.74069023], [73.12708282, 17.74098015], [73.1257019, 17.74098015], [73.1257019, 17.74125099], [73.12541962, 17.74125099], [73.12541962, 17.74152946], [73.12486267, 17.74152946], [73.12486267, 17.74263954], [73.12541962, 17.74263954], [73.12541962, 17.74291992], [73.12569427, 17.7429142], [73.12569427, 17.74319458], [73.12541962, 17.74319458], [73.12541962, 17.74347305], [73.12513733, 17.74347305], [73.12513733, 17.74458313], [73.12486267, 17.74458122], [73.12486267, 17.74570084], [73.12458038, 17.74569511], [73.12458038, 17.74597168], [73.12431335, 17.74596977], [73.12431335, 17.74653053], [73.12403107, 17.74652863], [73.12403107, 17.74708366], [73.12374878, 17.74707985], [73.12374878, 17.74791908], [73.12346649, 17.74791908], [73.12346649, 17.75125122], [73.12374878, 17.75125122], [73.12374878, 17.75181007], [73.12403107, 17.75181007], [73.12403107, 17.75263977], [73.12374878, 17.75263977], [73.12374878, 17.75292015], [73.12347412, 17.75291634], [73.12347412, 17.75319481], [73.12319183, 17.75319481], [73.12319183, 17.75347137], [73.12291718, 17.75346947], [73.12291718, 17.75374985], [73.12264252, 17.75374985], [73.12264252, 17.75430489], [73.12236023, 17.75430489], [73.12236023, 17.75486183], [73.1220932, 17.75485992], [73.1220932, 17.7551403], [73.12180328, 17.7551403], [73.12180328, 17.75542068], [73.12152863, 17.75542068], [73.12152863, 17.75625038], [73.12124634, 17.75625038], [73.12124634, 17.75653076], [73.12097168, 17.75652695], [73.12097168, 17.7570858], [73.12069702, 17.75708008], [73.12069702, 17.75736046], [73.1204071, 17.75736046], [73.1204071, 17.75764084], [73.12014008, 17.75763893], [73.12014008, 17.75819397], [73.11985779, 17.75819016], [73.11985779, 17.75875092], [73.11956787, 17.75875092], [73.11956787, 17.75930977], [73.11930847, 17.75930786], [73.11930847, 17.75947189], [73.11930847, 17.76097298], [73.11902618, 17.76096916], [73.11902618, 17.76124954], [73.11930847, 17.76124954], [73.11930847, 17.7618084], [73.11902618, 17.7618084], [73.11902618, 17.76209259], [73.11875153, 17.76209259], [73.11875153, 17.76292038], [73.11846924, 17.76291656], [73.11846924, 17.76569366], [73.11819458, 17.76569366], [73.11819458, 17.76597214], [73.11763763, 17.76597023], [73.11763763, 17.7665329], [73.11736298, 17.76652718], [73.11736298, 17.76708221], [73.11721039, 17.76708221], [73.11708069, 17.76708221], [73.11708069, 17.76756287], [73.11708069, 17.76763916], [73.1167984, 17.76764107], [73.1167984, 17.76791954], [73.11653137, 17.76791763], [73.11653137, 17.76847267], [73.11624908, 17.76847076], [73.11624908, 17.76875114], [73.11653137, 17.76874924], [73.11653137, 17.76958275], [73.11624908, 17.76958084], [73.11624908, 17.76986122], [73.11569214, 17.76986122], [73.11569214, 17.77042007], [73.11513519, 17.77041435], [73.11514282, 17.77124977], [73.11486053, 17.77124977], [73.11486053, 17.77292061], [73.11458588, 17.77292061], [73.11458588, 17.77319908], [73.11430359, 17.77319527], [73.11430359, 17.77347183], [73.11402893, 17.77346992], [73.11402893, 17.77403069], [73.1137619, 17.77403069], [73.1137619, 17.77541924], [73.11347198, 17.77541733], [73.11347198, 17.77597237], [73.11319733, 17.77596855], [73.11319733, 17.77652931], [73.11292267, 17.77652931], [73.11292267, 17.77709007], [73.11319733, 17.77708244], [73.11319733, 17.77819443], [73.11291504, 17.77819443], [73.11291504, 17.77958107], [73.11264038, 17.77958107], [73.11264038, 17.7799511], [73.11264038, 17.78013802], [73.11250305, 17.78013802], [73.11235809, 17.78013802], [73.11235809, 17.78030968], [73.11235809, 17.78097153], [73.11207581, 17.78096962], [73.11207581, 17.78153038], [73.11180878, 17.78153038], [73.11180878, 17.78292084], [73.11152649, 17.78292084], [73.11152649, 17.78430939], [73.11125183, 17.78430939], [73.11125183, 17.78541946], [73.11096954, 17.78541946], [73.11096954, 17.7862606], [73.11069489, 17.78624725], [73.11069489, 17.78708267], [73.11042023, 17.78708076], [73.11042023, 17.78763962], [73.11013794, 17.78763962], [73.11013794, 17.78791809], [73.10986328, 17.78791618], [73.10986328, 17.78819466], [73.10958099, 17.78819466], [73.10958099, 17.78847313], [73.10986328, 17.78847122], [73.10986328, 17.78903008], [73.11013794, 17.78903008], [73.11013794, 17.78874969], [73.11042023, 17.78874969], [73.11042023, 17.78847122], [73.11096954, 17.78847313], [73.11096954, 17.78791618], [73.11125183, 17.78791809], [73.11125183, 17.78763962], [73.11069489, 17.78763962], [73.11069489, 17.78736115], [73.11096954, 17.78736115], [73.11096954, 17.78708076], [73.11125183, 17.78708267], [73.11125183, 17.78680611], [73.11235809, 17.78680992], [73.11235809, 17.78736115], [73.11208344, 17.78736115], [73.11208344, 17.78819466], [73.11180878, 17.78819084], [73.11180878, 17.78903008], [73.11208344, 17.78902817], [73.11208344, 17.78958321], [73.11125183, 17.78958321], [73.11125183, 17.78986168], [73.11096954, 17.78986168], [73.11096954, 17.79014015], [73.10901642, 17.79014015], [73.10901642, 17.79042053], [73.1084671, 17.79042053], [73.1084671, 17.79070282], [73.10819244, 17.79069519], [73.10819244, 17.79097176], [73.10791779, 17.79097176], [73.10791779, 17.79125023], [73.10762787, 17.79125023], [73.10762787, 17.7918129], [73.10736084, 17.79180527], [73.10736084, 17.79208374], [73.10708618, 17.79206848], [73.10708618, 17.79264069], [73.10680389, 17.79263878], [73.10680389, 17.79319382], [73.10652924, 17.79319382], [73.10652924, 17.79347229], [73.10624695, 17.79347038], [73.10624695, 17.79375076], [73.10597229, 17.79375076], [73.10597229, 17.79486084], [73.10569763, 17.79486084], [73.10569763, 17.79513931], [73.10514069, 17.79512978], [73.10514069, 17.79541969], [73.1048584, 17.79541588], [73.1048584, 17.79597282], [73.10514069, 17.79597092], [73.10514069, 17.79652977], [73.1048584, 17.79652786], [73.1048584, 17.7970829], [73.10456848, 17.79708099], [73.10456848, 17.79763985], [73.10430908, 17.79763985], [73.10430908, 17.79820061], [73.10402679, 17.79819679], [73.10402679, 17.79847145], [73.10346985, 17.79847145], [73.10346985, 17.79986191], [73.10375214, 17.79985809], [73.10375214, 17.80042076], [73.10346985, 17.80041885], [73.10346985, 17.80097198], [73.10320282, 17.80096817], [73.10320282, 17.80291939], [73.10263824, 17.80291748], [73.10263824, 17.80319405], [73.10236359, 17.80319405], [73.10236359, 17.80347252], [73.1018219, 17.80347061], [73.1018219, 17.8037529], [73.10124969, 17.8037529], [73.10124969, 17.80318832], [73.10069275, 17.80319405], [73.10069275, 17.80347252], [73.10041809, 17.80347061], [73.10041809, 17.80486107], [73.10069275, 17.80486107], [73.10069275, 17.80569458], [73.10041809, 17.80569458], [73.10041809, 17.80597115], [73.1001358, 17.80597115], [73.1001358, 17.80624962], [73.09986115, 17.80624962], [73.09986115, 17.80653], [73.09958649, 17.80652809], [73.09958649, 17.80680466], [73.0993042, 17.80680466], [73.0993042, 17.80708313], [73.09874725, 17.80708313], [73.09874725, 17.8073616], [73.0984726, 17.8073597], [73.0984726, 17.80792046], [73.09625244, 17.80792046], [73.09625244, 17.80875015], [73.0965271, 17.80875015], [73.0965271, 17.81014061], [73.09625244, 17.81014061], [73.09625244, 17.81042099], [73.09597015, 17.81041527], [73.09597015, 17.81069374], [73.0956955, 17.81069374], [73.0956955, 17.81097221], [73.09485626, 17.81097031], [73.09485626, 17.81125069], [73.09430695, 17.81125069], [73.09430695, 17.81153107], [73.09179688, 17.81153107], [73.09179688, 17.81180954], [73.09041595, 17.81180954], [73.09041595, 17.81153107], [73.0901413, 17.81153107], [73.0901413, 17.81098747], [73.08985901, 17.81097031], [73.08985901, 17.81041527], [73.08959198, 17.81042099], [73.08959198, 17.80986023], [73.08930206, 17.80986023], [73.08930206, 17.80931091], [73.08959198, 17.80931091], [73.08959198, 17.80903053], [73.08985901, 17.80903053], [73.08985901, 17.80846977], [73.08958435, 17.80847168], [73.08958435, 17.80819321], [73.08930206, 17.80820084], [73.08930206, 17.80792046], [73.08875275, 17.80792046], [73.08875275, 17.80820084], [73.08847046, 17.80820084], [73.08847046, 17.80931091], [73.08875275, 17.80930328], [73.08875275, 17.81069374], [73.0890274, 17.81068993], [73.0890274, 17.81180954], [73.08875275, 17.81180954], [73.08875275, 17.81236076], [73.0890274, 17.81236076], [73.0890274, 17.81291962], [73.08918762, 17.81291962], [73.08959198, 17.81291962], [73.08959198, 17.81319809], [73.08985901, 17.81319809], [73.08985901, 17.81291962], [73.09069824, 17.81291962], [73.09069824, 17.81319809], [73.0909729, 17.81319809], [73.0909729, 17.81402969], [73.09069824, 17.81402969], [73.09069824, 17.81430817], [73.09041595, 17.81430626], [73.09041595, 17.81458282], [73.0901413, 17.81458282], [73.0901413, 17.8148613], [73.08930206, 17.8148613], [73.08930206, 17.81569481], [73.0890274, 17.81569481], [73.0890274, 17.81597137], [73.08930206, 17.81597137], [73.08930206, 17.81625938], [73.08959198, 17.81625938], [73.08959198, 17.81653023], [73.0901413, 17.81652832], [73.0901413, 17.81680489], [73.09263611, 17.81680489], [73.09263611, 17.81708336], [73.09319305, 17.81708336], [73.09319305, 17.81736183], [73.09348297, 17.81736183], [73.09348297, 17.81820107], [73.09319305, 17.81820107], [73.09319305, 17.81875038], [73.0929184, 17.81875038], [73.0929184, 17.81958389], [73.09319305, 17.81958008], [73.09319305, 17.82014084], [73.09375, 17.82014084], [73.09375, 17.82042122], [73.09402466, 17.8204174], [73.09402466, 17.82069206], [73.0945816, 17.82069206], [73.0945816, 17.82097244], [73.09485626, 17.82097054], [73.09485626, 17.82152939], [73.0945816, 17.82152939], [73.0945816, 17.82180977], [73.09430695, 17.82180405], [73.09430695, 17.82208252], [73.0945816, 17.82208061], [73.0945816, 17.82263947], [73.09430695, 17.82263947], [73.09430695, 17.82291985], [73.0945816, 17.82291985], [73.0945816, 17.82374954], [73.09485626, 17.82374954], [73.09485626, 17.82402992], [73.0945816, 17.82402992], [73.0945816, 17.82514], [73.09430695, 17.82514], [73.09430695, 17.82624817], [73.09402466, 17.82624817], [73.09402466, 17.82708359], [73.09375, 17.82707977], [73.09375, 17.82764053], [73.09347534, 17.82764053], [73.09347534, 17.82819366], [73.09319305, 17.82818031], [73.09319305, 17.82875061], [73.0929184, 17.82875061], [73.0929184, 17.82930946], [73.09263611, 17.82930565], [73.09263611, 17.82958412], [73.09236145, 17.8295784], [73.09236145, 17.83013916], [73.09208679, 17.83013916], [73.09208679, 17.83097267], [73.09236145, 17.83097267], [73.09236145, 17.83124924], [73.09208679, 17.83124161], [73.09208679, 17.8318119], [73.09179688, 17.8318119], [73.09179688, 17.83236122], [73.09152985, 17.83236122], [73.09152985, 17.83319473], [73.09041595, 17.83319283], [73.09041595, 17.83374977], [73.0901413, 17.83374977], [73.0901413, 17.83430481], [73.08943176, 17.83430481], [73.08875275, 17.83430481], [73.08875275, 17.83511162], [73.08875275, 17.83542061], [73.08959198, 17.83542061], [73.08959198, 17.83570099], [73.08930206, 17.83569336], [73.08930206, 17.83597183], [73.0890274, 17.83596992], [73.0890274, 17.83625031], [73.08875275, 17.83625031], [73.08875275, 17.83653069], [73.08847046, 17.83653069], [73.08847046, 17.83681107], [73.0881958, 17.83680534], [73.0881958, 17.83708382], [73.08805084, 17.83708191], [73.08790588, 17.83708], [73.08790588, 17.83736992], [73.08763885, 17.83736038], [73.08763885, 17.83819389], [73.08735657, 17.83819008], [73.08735657, 17.83875084], [73.08763885, 17.83875084], [73.08763885, 17.83903122], [73.0881958, 17.8390255], [73.0881958, 17.83961105], [73.0881958, 17.84013939], [73.08847046, 17.84013939], [73.08847046, 17.84069443], [73.08875275, 17.84069443], [73.08875275, 17.8409729], [73.0890274, 17.84096909], [73.0890274, 17.84124756], [73.08930206, 17.84124756], [73.08930206, 17.84152985], [73.08985901, 17.84152985], [73.08985901, 17.84124756], [73.09069824, 17.84124756], [73.09069824, 17.84152985], [73.09262848, 17.84152985], [73.09262848, 17.84180832], [73.09375, 17.84180832], [73.09375, 17.84152985], [73.09485626, 17.84152985], [73.09485626, 17.84096909], [73.09597015, 17.84096909], [73.09597015, 17.84124756], [73.0965271, 17.84124756], [73.0965271, 17.84152985], [73.09707642, 17.84152985], [73.09707642, 17.84124756], [73.0973587, 17.84124756], [73.0973587, 17.84096909], [73.09874725, 17.8409729], [73.09874725, 17.84069443], [73.0993042, 17.84069443], [73.0993042, 17.84041786], [73.10098267, 17.84042931], [73.10098267, 17.84013939], [73.1029129, 17.84013939], [73.1029129, 17.83986092], [73.10346985, 17.83986092], [73.10346985, 17.83958054], [73.10375214, 17.83958244], [73.10375214, 17.8390255], [73.10514069, 17.83903122], [73.10514069, 17.83875084], [73.10569763, 17.83875084], [73.10569763, 17.83847046], [73.10597229, 17.83847237], [73.10597229, 17.83791542], [73.10679626, 17.83792114], [73.10679626, 17.83764076], [73.10708618, 17.83764076], [73.10708618, 17.83736992], [73.10736084, 17.83736992], [73.10736084, 17.83708], [73.1076355, 17.83708382], [73.1076355, 17.83680534], [73.10791779, 17.83681107], [73.10791779, 17.83653069], [73.10819244, 17.83653069], [73.10819244, 17.83625031], [73.1084671, 17.83625031], [73.1084671, 17.83596992], [73.10874939, 17.83597183], [73.10874939, 17.83569336], [73.10930634, 17.83570099], [73.10930634, 17.83542061], [73.10958099, 17.83542061], [73.10958099, 17.83514023], [73.10986328, 17.83514023], [73.10986328, 17.83485985], [73.11125183, 17.83486176], [73.11125183, 17.83458328], [73.11291504, 17.83458328], [73.11291504, 17.83430481], [73.11402893, 17.83430481], [73.11402893, 17.83402824], [73.11458588, 17.83403015], [73.11458588, 17.83374977], [73.11486053, 17.83374977], [73.11486053, 17.83346939], [73.11708069, 17.83346939], [73.11708069, 17.83374977], [73.11819458, 17.83374977], [73.11819458, 17.83430481], [73.11958313, 17.83430481], [73.11958313, 17.83458328], [73.11985779, 17.83458328], [73.11985779, 17.83486176], [73.12014008, 17.83485985], [73.12014008, 17.83514023], [73.12069702, 17.83514023], [73.12069702, 17.83542061], [73.12291718, 17.83542061], [73.12291718, 17.83570099], [73.12430573, 17.83569336], [73.12430573, 17.83597183], [73.12486267, 17.83597183], [73.12486267, 17.83541679], [73.12513733, 17.83542061], [73.12513733, 17.83514023], [73.1257019, 17.83514023], [73.1257019, 17.83485985], [73.12625122, 17.83486176], [73.12625122, 17.83458328], [73.12652588, 17.83458328], [73.12652588, 17.83430481], [73.12708282, 17.83430481], [73.12708282, 17.83402824], [73.12735748, 17.83403015], [73.12735748, 17.83374977], [73.12847137, 17.83374977], [73.12847137, 17.83346939], [73.12902832, 17.8334713], [73.12902832, 17.83319473], [73.12930298, 17.83319473], [73.12930298, 17.83263969], [73.1295929, 17.83263969], [73.12958527, 17.83236122], [73.12985992, 17.83236122], [73.12985992, 17.8318119], [73.13014221, 17.8318119], [73.13014221, 17.83152962], [73.13041687, 17.83152962], [73.13041687, 17.83097267], [73.13069153, 17.83097267], [73.13069153, 17.83041573], [73.13096619, 17.83041954], [73.13096619, 17.82986069], [73.13124847, 17.82986069], [73.13124847, 17.82930946], [73.13153076, 17.82930946], [73.13153076, 17.82875061], [73.13179779, 17.82875061], [73.13179779, 17.82818031], [73.13208008, 17.82819366], [73.13208008, 17.82764053], [73.13236237, 17.82764053], [73.13236237, 17.82542992], [73.13263702, 17.82542992], [73.13263702, 17.82514], [73.13291931, 17.82514], [73.13291931, 17.82485962], [73.13319397, 17.82486153], [73.13319397, 17.82458305], [73.1340332, 17.82458115], [73.1340332, 17.82514], [73.13375092, 17.82514], [73.13375092, 17.82542992], [73.13346863, 17.82541847], [73.13346863, 17.8259716], [73.13318634, 17.8259697], [73.13318634, 17.82764053], [73.13291931, 17.82764053], [73.13291931, 17.82902908], [73.13263702, 17.82902908], [73.13263702, 17.83013916], [73.13236237, 17.83013916], [73.13236237, 17.8306942], [73.13180542, 17.8306942], [73.13180542, 17.83097267], [73.13153076, 17.83097267], [73.13153076, 17.8318119], [73.13124847, 17.8318119], [73.13124847, 17.83236122], [73.13096619, 17.83236122], [73.13096619, 17.83263969], [73.13069153, 17.83263969], [73.13069153, 17.83292007], [73.13041687, 17.83291626], [73.13041687, 17.83319473], [73.12985992, 17.83319473], [73.12985992, 17.8334713], [73.12958527, 17.8334713], [73.1295929, 17.83374977], [73.12930298, 17.83374977], [73.12930298, 17.83430481], [73.12902832, 17.83430481], [73.12902832, 17.83458328], [73.12875366, 17.83458328], [73.12875366, 17.83486176], [73.12819672, 17.83485985], [73.12819672, 17.83514023], [73.12763977, 17.83514023], [73.12763977, 17.83542061], [73.12708282, 17.83542061], [73.12708282, 17.83570099], [73.12652588, 17.83569336], [73.12652588, 17.83597183], [73.12625122, 17.83596992], [73.12625122, 17.83625031], [73.1257019, 17.83625031], [73.1257019, 17.83653069], [73.12513733, 17.83653069], [73.12513733, 17.83681107], [73.12346649, 17.83681107], [73.12346649, 17.83653069], [73.12264252, 17.83653069], [73.12264252, 17.83625031], [73.12152863, 17.83625031], [73.12152863, 17.83596992], [73.12069702, 17.83597183], [73.12069702, 17.83569336], [73.11985779, 17.83570099], [73.11985779, 17.83542061], [73.11875153, 17.83542061], [73.11875153, 17.83514023], [73.11791992, 17.83514023], [73.11791992, 17.83485985], [73.11569214, 17.83486176], [73.11569214, 17.83458328], [73.11402893, 17.83458328], [73.11402893, 17.83486176], [73.11347198, 17.83485985], [73.11347198, 17.83514023], [73.11319733, 17.83514023], [73.11319733, 17.83542061], [73.11264038, 17.83542061], [73.11264038, 17.83570099], [73.11208344, 17.83569336], [73.11208344, 17.83597183], [73.11180878, 17.83596992], [73.11180878, 17.83625031], [73.11125183, 17.83625031], [73.11125183, 17.83653069], [73.11096954, 17.83653069], [73.11096954, 17.83681107], [73.11042023, 17.83680534], [73.11042023, 17.83708382], [73.11013794, 17.83708], [73.11013794, 17.83736992], [73.10958099, 17.83736992], [73.10958099, 17.83764076], [73.10930634, 17.83764076], [73.10930634, 17.83792114], [73.10874939, 17.83791542], [73.10874939, 17.83819389], [73.10847473, 17.83819389], [73.10847473, 17.83847237], [73.10791779, 17.83847046], [73.10791779, 17.83875084], [73.10762787, 17.83875084], [73.10762787, 17.83903122], [73.10708618, 17.8390255], [73.10708618, 17.83958244], [73.10679626, 17.83958054], [73.10679626, 17.83986092], [73.10624695, 17.83986092], [73.10624695, 17.84013939], [73.10597229, 17.84013939], [73.10597229, 17.84042931], [73.10569763, 17.84041786], [73.10569763, 17.84069443], [73.1048584, 17.84069443], [73.1048584, 17.8409729], [73.10375214, 17.84096909], [73.10375214, 17.84124756], [73.1018219, 17.84124756], [73.1018219, 17.84152985], [73.10098267, 17.84152985], [73.10098267, 17.84180832], [73.10041809, 17.84180641], [73.10041809, 17.84208298], [73.09958649, 17.84208298], [73.09958649, 17.84236145], [73.09902954, 17.84236145], [73.09902954, 17.84264183], [73.09707642, 17.84264183], [73.09707642, 17.8429203], [73.09680939, 17.8429203], [73.09680939, 17.84403038], [73.09708405, 17.84402847], [73.09708405, 17.84458351], [73.09874725, 17.84458351], [73.09874725, 17.84430504], [73.09958649, 17.84431267], [73.09958649, 17.84403038], [73.10041809, 17.84403038], [73.10041809, 17.84375191], [73.10098267, 17.84375191], [73.10097504, 17.84347153], [73.10152435, 17.84347153], [73.10152435, 17.84319496], [73.10263824, 17.84320259], [73.10263824, 17.84403038], [73.10235596, 17.84403038], [73.10235596, 17.84431267], [73.10180664, 17.84430504], [73.10180664, 17.84458351], [73.10069275, 17.84458351], [73.10069275, 17.84486008], [73.09986115, 17.84486008], [73.09986115, 17.84514046], [73.09819794, 17.84514046], [73.09819794, 17.84542274], [73.09708405, 17.84541702], [73.09708405, 17.84569359], [73.0965271, 17.84569359], [73.0965271, 17.84541702], [73.09513855, 17.84541702], [73.09513855, 17.84569359], [73.0945816, 17.84569359], [73.0945816, 17.84541702], [73.09430695, 17.84542274], [73.09430695, 17.84514046], [73.09375, 17.84514046], [73.09375, 17.8445816], [73.09347534, 17.84458351], [73.09347534, 17.84430504], [73.09319305, 17.84431267], [73.09319305, 17.84375191], [73.09262848, 17.84375191], [73.09262848, 17.84347153], [73.0909729, 17.84347153], [73.0909729, 17.84375191], [73.09041595, 17.84375191], [73.09041595, 17.84403038], [73.0901413, 17.84403038], [73.0901413, 17.84431267], [73.08985901, 17.84430504], [73.08985901, 17.84458351], [73.08958435, 17.84458351], [73.08958435, 17.84486008], [73.08930206, 17.84486008], [73.08930206, 17.84514046], [73.0890274, 17.84514046], [73.0890274, 17.84542274], [73.08875275, 17.84541702], [73.08875275, 17.84569359], [73.08847046, 17.84569359], [73.08847046, 17.84597206], [73.0881958, 17.84597015], [73.0881958, 17.84653091], [73.08791351, 17.8465271], [73.08791351, 17.84708214], [73.08763885, 17.84708023], [73.08763885, 17.84736061], [73.0873642, 17.84736061], [73.0873642, 17.8484726], [73.08708191, 17.84847069], [73.08708191, 17.84875107], [73.08682251, 17.84875107], [73.08682251, 17.84930992], [73.08652496, 17.8493042], [73.08652496, 17.84958267], [73.08625031, 17.84958076], [73.08625031, 17.85013962], [73.08597565, 17.85013962], [73.08597565, 17.85069466], [73.08569336, 17.85069084], [73.08569336, 17.85153008], [73.0854187, 17.85153008], [73.0854187, 17.85237122], [73.08513641, 17.85237122], [73.08513641, 17.85403061], [73.08486176, 17.8540287], [73.08486176, 17.85597229], [73.0845871, 17.85596848], [73.0845871, 17.85652924], [73.08430481, 17.85652733], [73.08430481, 17.85708427], [73.08403015, 17.85708427], [73.08403015, 17.85847282], [73.08374786, 17.85847282], [73.08374786, 17.85874939], [73.08345795, 17.85874939], [73.08345795, 17.85902977], [73.08207703, 17.85902977], [73.08207703, 17.85931015], [73.08180237, 17.85930634], [73.08180237, 17.8595829], [73.08152771, 17.8595829], [73.08152771, 17.85986137], [73.08125305, 17.85985947], [73.08125305, 17.86013985], [73.08097076, 17.86013985], [73.08097076, 17.86069489], [73.08068848, 17.86069107], [73.08068848, 17.86124992], [73.08041382, 17.86124992], [73.08041382, 17.86208344], [73.08013916, 17.86208344], [73.08013916, 17.86239052], [73.08013916, 17.86292076], [73.08041382, 17.86291695], [73.08041382, 17.86319351], [73.08069611, 17.86319351], [73.08069611, 17.86347198], [73.08097076, 17.86347008], [73.08097076, 17.86375046], [73.08125305, 17.86375046], [73.08125305, 17.86403084], [73.08152771, 17.86403084], [73.08152771, 17.86431122], [73.08180237, 17.8643055], [73.08180237, 17.86458588], [73.08152771, 17.86458015], [73.08152771, 17.86541939], [73.08125305, 17.86541939], [73.08125305, 17.86625099], [73.08097076, 17.86625099], [73.08097076, 17.86652946], [73.08068848, 17.86652946], [73.08068848, 17.86763954], [73.08039856, 17.86763954], [73.08039856, 17.86791992], [73.08013916, 17.86791611], [73.08013916, 17.86847305], [73.07985687, 17.86846924], [73.07985687, 17.86903191], [73.07958221, 17.86902809], [73.07958221, 17.86930466], [73.07930756, 17.86930084], [73.07930756, 17.87014008], [73.07875061, 17.87013817], [73.07875061, 17.87041664], [73.07847595, 17.87041092], [73.07847595, 17.87070274], [73.07819366, 17.87069511], [73.07819366, 17.87097168], [73.07791901, 17.87097168], [73.07791901, 17.87125015], [73.07765198, 17.87125015], [73.07765198, 17.87153053], [73.07707977, 17.87153053], [73.07707977, 17.87181282], [73.07680511, 17.87180519], [73.07680511, 17.87208366], [73.07624817, 17.87208366], [73.07624817, 17.87319374], [73.07596588, 17.87319183], [73.07596588, 17.87403107], [73.07569122, 17.87403107], [73.07569122, 17.87430954], [73.07541656, 17.87430954], [73.07541656, 17.87486076], [73.07514191, 17.87486076], [73.07514191, 17.87795258], [73.07514191, 17.87958336], [73.07485962, 17.87957954], [73.07485962, 17.88042068], [73.07458496, 17.88041878], [73.07458496, 17.88208389], [73.07430267, 17.88207817], [73.07430267, 17.88291931], [73.07375336, 17.8829174], [73.07375336, 17.88319397], [73.07347107, 17.88318825], [73.07347107, 17.88402939], [73.07319641, 17.88402939], [73.07319641, 17.8848629], [73.07290649, 17.8848629], [73.07290649, 17.88541985], [73.07263947, 17.88541985], [73.07263947, 17.8868103], [73.07235718, 17.8868103], [73.07235718, 17.88764], [73.07208252, 17.88764], [73.07208252, 17.88820076], [73.07180786, 17.88820076], [73.07180786, 17.88848114], [73.07151794, 17.88848114], [73.07151794, 17.88875008], [73.07125092, 17.88875008], [73.07125092, 17.89042091], [73.07151794, 17.89042091], [73.07151794, 17.89180946], [73.07180786, 17.89180756], [73.07180786, 17.8931942], [73.07208252, 17.89319038], [73.07208252, 17.89402962], [73.07236481, 17.89402962], [73.07236481, 17.89458275], [73.07290649, 17.89458084], [73.07290649, 17.89486122], [73.07319641, 17.89486122], [73.07319641, 17.89513969], [73.07375336, 17.89513969], [73.07375336, 17.89541817], [73.07430267, 17.89541626], [73.07430267, 17.89569473], [73.07458496, 17.89569473], [73.07458496, 17.8959713], [73.07541656, 17.8959713], [73.07541656, 17.89625168], [73.07597351, 17.89625168], [73.07597351, 17.89680481], [73.07485962, 17.89680481], [73.07485962, 17.89708328], [73.07458496, 17.89708328], [73.07458496, 17.89652824], [73.07430267, 17.89653015], [73.07430267, 17.89625168], [73.07402802, 17.89625168], [73.07402802, 17.8959713], [73.07375336, 17.8959713], [73.07375336, 17.89569473], [73.07319641, 17.89569473], [73.07319641, 17.89541626], [73.07290649, 17.89541817], [73.07290649, 17.89513969], [73.07263947, 17.89513969], [73.07263947, 17.89486122], [73.07125092, 17.89486122], [73.07125092, 17.89430809], [73.07096863, 17.89430809], [73.07096863, 17.89402962], [73.07125092, 17.89402962], [73.07125092, 17.89347076], [73.07096863, 17.89347267], [73.07096863, 17.89291954], [73.07068634, 17.89291954], [73.07068634, 17.89264107], [73.07041931, 17.89264107], [73.07041931, 17.89236069], [73.06958008, 17.89236069], [73.06958008, 17.89180946], [73.06931305, 17.89180946], [73.06931305, 17.89125061], [73.06903076, 17.89125061], [73.06903076, 17.89097023], [73.06652832, 17.89097214], [73.06652832, 17.89069366], [73.06569672, 17.89069366], [73.06569672, 17.89041519], [73.06485748, 17.89041519], [73.06485748, 17.89069366], [73.06346893, 17.89069366], [73.06346893, 17.89097023], [73.0632019, 17.89097977], [73.06319427, 17.89125061], [73.06291962, 17.89125061], [73.06291962, 17.89152527], [73.06278229, 17.89152527], [73.06153107, 17.89151955], [73.06153107, 17.89180946], [73.06124878, 17.89180946], [73.06124878, 17.89236069], [73.06097412, 17.89236069], [73.06097412, 17.8931942], [73.06069183, 17.8931942], [73.06069183, 17.89347267], [73.06041718, 17.89347076], [73.06041718, 17.89375114], [73.06014252, 17.89375114], [73.06014252, 17.89402962], [73.05986023, 17.89402962], [73.05986023, 17.89430809], [73.05958557, 17.89430618], [73.05958557, 17.89458275], [73.05902863, 17.89458084], [73.05902863, 17.89513969], [73.05874634, 17.89513969], [73.05874634, 17.89569473], [73.05847168, 17.89569473], [73.05847168, 17.8959713], [73.05819702, 17.8959713], [73.05819702, 17.89625168], [73.0579071, 17.89625168], [73.0579071, 17.89653015], [73.05764008, 17.89652824], [73.05764008, 17.89680481], [73.05735779, 17.89680481], [73.05735779, 17.89736176], [73.05708313, 17.89736176], [73.05708313, 17.89764023], [73.05680847, 17.89764023], [73.05680847, 17.89792061], [73.05651855, 17.89792061], [73.05651855, 17.8982029], [73.05625153, 17.89819527], [73.05625153, 17.89847183], [73.05568695, 17.89847183], [73.05568695, 17.89875031], [73.05541992, 17.89875031], [73.05541992, 17.89903069], [73.05513763, 17.89903069], [73.05513763, 17.89931107], [73.05486298, 17.89931107], [73.05486298, 17.89986038], [73.05458069, 17.89986038], [73.05458069, 17.90014076], [73.05430603, 17.90014076], [73.05430603, 17.90042114], [73.05403137, 17.90042114], [73.05403137, 17.90153122], [73.05430603, 17.90153122], [73.05430603, 17.90180969], [73.05403137, 17.90180969], [73.05403137, 17.90236092], [73.05374908, 17.90236092], [73.05374908, 17.90291977], [73.05347443, 17.90291405], [73.05347443, 17.90319443], [73.05319214, 17.90319443], [73.05319214, 17.9034729], [73.05236053, 17.90345955], [73.05236053, 17.90374947], [73.05179596, 17.90374947], [73.05179596, 17.90402985], [73.05152893, 17.90402794], [73.05152893, 17.90458298], [73.05124664, 17.90458107], [73.05124664, 17.90513992], [73.05097198, 17.90513992], [73.05097198, 17.9054203], [73.05071259, 17.9054203], [73.05071259, 17.90570068], [73.05097198, 17.90569687], [73.05097198, 17.90597153], [73.05069733, 17.90597153], [73.05069733, 17.90652657], [73.05042267, 17.90652084], [73.05042267, 17.90681076], [73.05014038, 17.90680695], [73.05014038, 17.90736198], [73.05042267, 17.90735817], [73.05042267, 17.90764046], [73.05179596, 17.90764046], [73.05179596, 17.90735817], [73.05236053, 17.90735817], [73.05236053, 17.90764046], [73.05271149, 17.90764046], [73.05291748, 17.90764046], [73.05291748, 17.90792084], [73.05347443, 17.90791893], [73.05347443, 17.90819359], [73.05374908, 17.90818977], [73.05374908, 17.90986061], [73.05403137, 17.90986061], [73.05403137, 17.91041946], [73.05430603, 17.91041756], [73.05430603, 17.91069412], [73.05403137, 17.91069412], [73.05403137, 17.91144943], [73.05403137, 17.91208267], [73.05417633, 17.91208267], [73.05430603, 17.91208267], [73.05430603, 17.91263962], [73.05458069, 17.91263962], [73.05458069, 17.91282082], [73.05458069, 17.91319466], [73.05513763, 17.91319466], [73.05513763, 17.91347122], [73.05486298, 17.91347122], [73.05486298, 17.91374969], [73.05458069, 17.91374969], [73.05458069, 17.91514015], [73.05486298, 17.91514015], [73.05486298, 17.91571045], [73.05513763, 17.91571045], [73.05513763, 17.91625023], [73.05486298, 17.91625023], [73.05486298, 17.91708374], [73.05458069, 17.91708374], [73.05458069, 17.91847229], [73.05430603, 17.91847229], [73.05430603, 17.91958427], [73.05403137, 17.91958427], [73.05403137, 17.92097282], [73.05374908, 17.92097282], [73.05374908, 17.9220829], [73.05403137, 17.92207909], [73.05403137, 17.92263985], [73.05347443, 17.92264175], [73.05347443, 17.92319489], [73.05319214, 17.92318916], [73.05319214, 17.9240303], [73.05291748, 17.9240284], [73.05291748, 17.92486191], [73.05263519, 17.92486191], [73.05264282, 17.9256897], [73.05236053, 17.92569542], [73.05236053, 17.92732811], [73.05208588, 17.92736053], [73.05208588, 17.92902946], [73.05374908, 17.92902946], [73.05374908, 17.92875099], [73.05403137, 17.92875099], [73.05403137, 17.92847061], [73.05458069, 17.92847252], [73.05458069, 17.92819214], [73.05513763, 17.92819214], [73.05513763, 17.92791748], [73.05541992, 17.92791939], [73.05541992, 17.92765045], [73.05568695, 17.92765045], [73.05568695, 17.92736053], [73.05596924, 17.92736053], [73.05596924, 17.92708015], [73.05625153, 17.92708206], [73.05625153, 17.92652702], [73.05735779, 17.92652702], [73.05735779, 17.92690086], [73.05735779, 17.92736053], [73.05764008, 17.92736053], [73.05764008, 17.92791939], [73.05847168, 17.92791748], [73.05847168, 17.92819214], [73.05930328, 17.92819214], [73.05930328, 17.92791748], [73.05986023, 17.92791939], [73.05986023, 17.92765045], [73.06014252, 17.92765045], [73.06014252, 17.92736053], [73.06041718, 17.92736053], [73.06041718, 17.92681122], [73.06096649, 17.92681122], [73.06098938, 17.92659569], [73.06124878, 17.92653084], [73.06124878, 17.92625046], [73.06236267, 17.92625046], [73.06236267, 17.92650032], [73.06265259, 17.92653084], [73.06265259, 17.92681122], [73.06542206, 17.92681122], [73.06542206, 17.92653084], [73.06680298, 17.92653084], [73.06680298, 17.92681122], [73.06708527, 17.9268055], [73.06708527, 17.92708206], [73.06680298, 17.92708015], [73.06680298, 17.92765045], [73.06597137, 17.92765045], [73.06597137, 17.92736053], [73.06208038, 17.92736053], [73.06208038, 17.92819214], [73.06236267, 17.92819023], [73.06236267, 17.92930984], [73.06263733, 17.92930412], [73.06263733, 17.9295826], [73.06291962, 17.92958069], [73.06291962, 17.92986107], [73.06318665, 17.92986107], [73.06318665, 17.93013954], [73.06346893, 17.93013954], [73.06346893, 17.93069458], [73.06375122, 17.93069077], [73.06375122, 17.93124962], [73.06402588, 17.93124962], [73.06402588, 17.93180466], [73.06458282, 17.93180466], [73.06458282, 17.93208313], [73.06485748, 17.93208313], [73.06485748, 17.9323616], [73.06542206, 17.9323597], [73.06542206, 17.93264008], [73.06597137, 17.93264008], [73.06597137, 17.9323597], [73.06652832, 17.9323616], [73.06652832, 17.93180466], [73.06680298, 17.93180466], [73.06680298, 17.9295826], [73.06708527, 17.9295826], [73.06708527, 17.92902756], [73.06735992, 17.92902946], [73.06735992, 17.92875099], [73.06764221, 17.92875099], [73.06764221, 17.92847061], [73.06791687, 17.92847252], [73.06791687, 17.92791748], [73.06819153, 17.92791939], [73.06819153, 17.92681122], [73.07013702, 17.9268055], [73.07013702, 17.92708206], [73.07096863, 17.92708015], [73.07096863, 17.92736053], [73.07235718, 17.92736053], [73.07235718, 17.92765045], [73.07263947, 17.92763901], [73.07263947, 17.92819214], [73.07291412, 17.92819214], [73.07291412, 17.92847252], [73.07319641, 17.92847061], [73.07319641, 17.92875099], [73.07347107, 17.92875099], [73.07347107, 17.92930984], [73.07375336, 17.92930412], [73.07375336, 17.9295826], [73.07458496, 17.9295826], [73.07458496, 17.92986107], [73.07514191, 17.92986107], [73.07514191, 17.93041992], [73.07541656, 17.9304142], [73.07541656, 17.93097305], [73.07569122, 17.93097115], [73.07569122, 17.93153], [73.07596588, 17.93153], [73.07596588, 17.93292046], [73.07624817, 17.93292046], [73.07624817, 17.93320084], [73.07653046, 17.93319511], [73.07653046, 17.93347168], [73.07707977, 17.93346977], [73.07707977, 17.93374825], [73.07736206, 17.93374825], [73.07736206, 17.93403053], [73.07791901, 17.93403053], [73.07791901, 17.93431091], [73.07819366, 17.93430519], [73.07819366, 17.93458366], [73.07875061, 17.93457985], [73.07875061, 17.93485832], [73.07930756, 17.93485832], [73.07930756, 17.93514061], [73.07958221, 17.93514061], [73.07958221, 17.93541908], [73.08041382, 17.93541718], [73.08041382, 17.93569374], [73.08125305, 17.93569374], [73.08125305, 17.93597221], [73.08207703, 17.9359684], [73.08207703, 17.93652916], [73.08235931, 17.93652916], [73.08235931, 17.93682289], [73.0826416, 17.93682289], [73.0826416, 17.93736267], [73.08291626, 17.93736267], [73.08291626, 17.93764114], [73.08374786, 17.93764114], [73.08374786, 17.93791962], [73.08430481, 17.9379158], [73.08430481, 17.93819427], [73.08486176, 17.93819427], [73.08486176, 17.93847275], [73.0854187, 17.93847275], [73.0854187, 17.93875122], [73.08625031, 17.93875122], [73.08625031, 17.93902969], [73.08682251, 17.93902969], [73.08682251, 17.93931007], [73.08763885, 17.93931007], [73.08763885, 17.93959045], [73.0881958, 17.93958282], [73.0881958, 17.9398613], [73.08875275, 17.93985939], [73.08875275, 17.94013977], [73.08985901, 17.94013977], [73.08985901, 17.94042015], [73.09236145, 17.94041634], [73.09236145, 17.94069481], [73.09124756, 17.94069481], [73.09124756, 17.94097137], [73.08875275, 17.94097137], [73.08875275, 17.94069481], [73.0881958, 17.94069481], [73.0881958, 17.94041634], [73.08708191, 17.94042015], [73.08708191, 17.94013977], [73.0854187, 17.94013977], [73.0854187, 17.93985939], [73.08513641, 17.9398613], [73.08513641, 17.93958282], [73.0845871, 17.93959045], [73.0845871, 17.93931007], [73.08429718, 17.93931007], [73.08429718, 17.93902969], [73.08374786, 17.93902969], [73.08374786, 17.93875122], [73.08319092, 17.93875122], [73.08319092, 17.93847275], [73.08291626, 17.93847275], [73.08291626, 17.93819427], [73.08235931, 17.93819427], [73.08235931, 17.9379158], [73.08207703, 17.93791962], [73.08207703, 17.93764114], [73.08180237, 17.93764114], [73.08180237, 17.93736267], [73.08039856, 17.93736267], [73.08039856, 17.93707848], [73.08013916, 17.9370842], [73.08013916, 17.93680573], [73.07985687, 17.93682289], [73.07985687, 17.93652916], [73.07958221, 17.93652916], [73.07958221, 17.93625069], [73.07902527, 17.93625069], [73.07902527, 17.93597221], [73.07819366, 17.93597221], [73.07819366, 17.93569374], [73.07736206, 17.93569374], [73.07736206, 17.93541718], [73.07624817, 17.93541908], [73.07624817, 17.93514061], [73.07596588, 17.93514061], [73.07596588, 17.93457985], [73.07541656, 17.93458366], [73.07541656, 17.93402863], [73.07459259, 17.93403053], [73.07459259, 17.93374825], [73.07430267, 17.93374825], [73.07430267, 17.93346977], [73.07402802, 17.93347168], [73.07402802, 17.93291855], [73.07375336, 17.93292046], [73.07375336, 17.9323597], [73.07347107, 17.9323616], [73.07347107, 17.93180466], [73.07319641, 17.93180466], [73.07319641, 17.93097305], [73.07291412, 17.93097305], [73.07291412, 17.92986107], [73.07263947, 17.92986107], [73.07263947, 17.92958069], [73.07236481, 17.9295826], [73.07236481, 17.92930412], [73.07208252, 17.92930984], [73.07208252, 17.92902946], [73.07041931, 17.92902946], [73.07041931, 17.92930984], [73.06986237, 17.92930412], [73.06986237, 17.9295826], [73.06958008, 17.92958069], [73.06958008, 17.92986107], [73.06931305, 17.92986107], [73.06931305, 17.93041992], [73.06958008, 17.93041992], [73.06958008, 17.93124962], [73.06931305, 17.93124962], [73.06931305, 17.93153], [73.06903076, 17.93152618], [73.06903076, 17.93208313], [73.06874847, 17.93208122], [73.06874847, 17.93264008], [73.06847382, 17.93263626], [73.06847382, 17.93347168], [73.06791687, 17.93346977], [73.06791687, 17.93374825], [73.06735992, 17.93374825], [73.06735992, 17.93403053], [73.0670929, 17.93403053], [73.0670929, 17.93374825], [73.06680298, 17.93374825], [73.06680298, 17.93403053], [73.06652832, 17.93403053], [73.06652832, 17.93374825], [73.06597137, 17.93374825], [73.06597137, 17.93346977], [73.06541443, 17.93347168], [73.06541443, 17.93319511], [73.06402588, 17.93320084], [73.06402588, 17.93292046], [73.06181335, 17.93292046], [73.06181335, 17.93264008], [73.06124878, 17.93264008], [73.06124878, 17.9323597], [73.05764008, 17.9323616], [73.05764008, 17.93208313], [73.05708313, 17.93208313], [73.05708313, 17.93180466], [73.05680847, 17.93180466], [73.05680847, 17.93152618], [73.05652618, 17.93152618], [73.05652618, 17.93180466], [73.05430603, 17.93180466], [73.05430603, 17.93152618], [73.05236053, 17.93152618], [73.05236053, 17.93180466], [73.05097198, 17.93180466], [73.05097198, 17.93208313], [73.04985809, 17.93208313], [73.04985809, 17.9323616], [73.04763794, 17.9323597], [73.04763794, 17.93264008], [73.04708099, 17.93264008], [73.04708099, 17.93292046], [73.04680634, 17.93292046], [73.04680634, 17.93320084], [73.04652405, 17.93319511], [73.04652405, 17.93347168], [73.04624939, 17.93346977], [73.04624939, 17.93374825], [73.04541779, 17.93374825], [73.04541779, 17.93403053], [73.04428864, 17.93403053], [73.04428864, 17.93374825], [73.04402924, 17.93374825], [73.04402924, 17.93346977], [73.04374695, 17.93347168], [73.04374695, 17.93319511], [73.04347229, 17.93320084], [73.04347229, 17.93264008], [73.0423584, 17.93264008], [73.0423584, 17.9323597], [73.04184723, 17.9323597], [73.04154205, 17.9323597], [73.04154205, 17.93264008], [73.04125214, 17.93263626], [73.04122925, 17.93291092], [73.0404129, 17.93292046], [73.0404129, 17.93320084], [73.0395813, 17.93319511], [73.0395813, 17.93347168], [73.03930664, 17.93346977], [73.03930664, 17.93374825], [73.03874969, 17.93374825], [73.03874969, 17.93403053], [73.03848267, 17.93403053], [73.03848267, 17.93431091], [73.03791809, 17.93431091], [73.03791809, 17.93485832], [73.0376358, 17.93485832], [73.0376358, 17.93541908], [73.03736115, 17.93541718], [73.03736115, 17.93597221], [73.03708649, 17.9359684], [73.03708649, 17.93625069], [73.03679657, 17.93625069], [73.03679657, 17.93652916], [73.03652954, 17.93652916], [73.03652954, 17.93682289], [73.03624725, 17.93680573], [73.03624725, 17.9370842], [73.0359726, 17.93707848], [73.0359726, 17.93764114], [73.03569794, 17.93763924], [73.03569794, 17.93819427], [73.03542328, 17.93819046], [73.03542328, 17.93902969], [73.03514099, 17.93902969], [73.03514099, 17.93931007], [73.0340271, 17.93931007], [73.0340271, 17.93959045], [73.03375244, 17.93958282], [73.03375244, 17.9398613], [73.03347015, 17.93985939], [73.03347015, 17.94013977], [73.03263855, 17.94013977], [73.03263855, 17.94042015], [73.0320816, 17.94041634], [73.0320816, 17.94097137], [73.03180695, 17.94096947], [73.03180695, 17.94124985], [73.03152466, 17.94124985], [73.03152466, 17.94180489], [73.03125, 17.94180489], [73.03125, 17.94236183], [73.03098297, 17.94235992], [73.03098297, 17.94320107], [73.03069305, 17.94319534], [73.03069305, 17.94347191], [73.0304184, 17.94347], [73.0304184, 17.94375038], [73.03013611, 17.94375038], [73.03013611, 17.94403076], [73.02986145, 17.94403076], [73.02986145, 17.94431114], [73.02960205, 17.94431114], [73.02960205, 17.94680977], [73.02928925, 17.94680977], [73.02928925, 17.94735909], [73.02902985, 17.94735909], [73.02902985, 17.94791985], [73.02874756, 17.94791985], [73.02874756, 17.94902992], [73.0284729, 17.94902992], [73.0284729, 17.94958305], [73.02874756, 17.94957924], [73.02874756, 17.95375061], [73.02902985, 17.95375061], [73.02902985, 17.95403099], [73.02986145, 17.95403099], [73.02986145, 17.95430946], [73.03013611, 17.95430565], [73.03013611, 17.95458221], [73.0304184, 17.95457268], [73.0304184, 17.95486069], [73.03069305, 17.95486069], [73.03069305, 17.95514107], [73.03097534, 17.95513916], [73.03097534, 17.9556942], [73.03125, 17.95569038], [73.03125, 17.95736122], [73.03098297, 17.95736122], [73.03098297, 17.95792007], [73.03069305, 17.95791435], [73.03069305, 17.95819473], [73.0304184, 17.95819092], [73.0304184, 17.95874977], [73.03013611, 17.95874977], [73.03013611, 17.95958328], [73.02986145, 17.95957947], [73.02986145, 17.96125031], [73.02958679, 17.96125031], [73.02960205, 17.96513939], [73.0293045, 17.96513939], [73.0293045, 17.96680641], [73.02958679, 17.96680641], [73.02958679, 17.96736145], [73.03013611, 17.96735954], [73.03013611, 17.96763992], [73.03069305, 17.96763992], [73.03069305, 17.9679203], [73.03097534, 17.96791649], [73.03097534, 17.96847153], [73.03125, 17.96846962], [73.03125, 17.96903038], [73.03151703, 17.96903038], [73.03151703, 17.96931076], [73.03180695, 17.96930313], [73.03180695, 17.96986198], [73.0320816, 17.96986008], [73.0320816, 17.97014046], [73.03234863, 17.97014046], [73.03234863, 17.97042084], [73.03263855, 17.97041512], [73.03263855, 17.97069359], [73.0331955, 17.97069359], [73.0331955, 17.97097206], [73.03375244, 17.97097015], [73.03375244, 17.97125053], [73.03430176, 17.97125053], [73.03430939, 17.97153091], [73.03457642, 17.97153091], [73.03457642, 17.97180939], [73.0348587, 17.97180557], [73.0348587, 17.97208595], [73.03514099, 17.97208023], [73.03514099, 17.97264099], [73.03542328, 17.97264099], [73.03542328, 17.97293091], [73.03569794, 17.97291946], [73.03569794, 17.97319412], [73.03652954, 17.97319412], [73.03652954, 17.9734726], [73.03708649, 17.97347069], [73.03708649, 17.97375107], [73.03736115, 17.97375107], [73.03736115, 17.97430992], [73.0376358, 17.97430992], [73.0376358, 17.97486115], [73.03791809, 17.97486115], [73.03791809, 17.97513962], [73.03819275, 17.97513962], [73.03819275, 17.97541809], [73.03848267, 17.97541809], [73.03848267, 17.97570229], [73.03874969, 17.97570229], [73.03874969, 17.97653008], [73.03902435, 17.97652817], [73.03902435, 17.97680473], [73.03930664, 17.97680473], [73.03930664, 17.97736168], [73.0395813, 17.97736168], [73.0395813, 17.97764015], [73.03985596, 17.97764015], [73.03985596, 17.97792053], [73.04013824, 17.97792053], [73.04013824, 17.97820282], [73.03985596, 17.97820282], [73.03985596, 17.97903061], [73.0395813, 17.97903061], [73.0395813, 17.97986031], [73.03930664, 17.97986031], [73.03930664, 17.98069382], [73.03901672, 17.98069191], [73.03901672, 17.98153114], [73.03874969, 17.98153114], [73.03874969, 17.98264122], [73.03847504, 17.98263931], [73.03847504, 17.98347282], [73.03819275, 17.98347092], [73.03819275, 17.98431015], [73.03791809, 17.98430443], [73.03791809, 17.9845829], [73.0376358, 17.9845829], [73.0376358, 17.98430443], [73.03736115, 17.98431015], [73.03734589, 17.98486328], [73.03708649, 17.98489952], [73.03708649, 17.98513985], [73.03679657, 17.98513985], [73.03679657, 17.98542023], [73.03652954, 17.98541641], [73.03652954, 17.98569679], [73.03514099, 17.98569679], [73.03514099, 17.98597145], [73.03430939, 17.98596954], [73.03430176, 17.98624992], [73.0340271, 17.98624992], [73.0340271, 17.9865303], [73.03347015, 17.9865303], [73.03347015, 17.98681068], [73.0331955, 17.98680496], [73.0331955, 17.98708344], [73.03291321, 17.98708344], [73.03291321, 17.98736191], [73.03263855, 17.98735809], [73.03263855, 17.9879303], [73.03291321, 17.98791885], [73.03291321, 17.9881897], [73.03263855, 17.98819923], [73.03263855, 17.98875046], [73.03291321, 17.98875046], [73.03291321, 17.98930931], [73.03236389, 17.9893055], [73.03236389, 17.98958397], [73.03180695, 17.98957825], [73.03180695, 17.98986053], [73.03151703, 17.98986053], [73.03151703, 17.99014091], [73.03098297, 17.99014091], [73.03098297, 17.99041939], [73.03013611, 17.99041748], [73.03013611, 17.99069405], [73.02986145, 17.99069405], [73.02986145, 17.99097252], [73.02960205, 17.99097252], [73.02960205, 17.9912529], [73.02902985, 17.9912529], [73.02902985, 17.99041939], [73.02874756, 17.99041939], [73.02874756, 17.99014091], [73.0284729, 17.99014091], [73.0284729, 17.98986053], [73.02819824, 17.98986053], [73.02819061, 17.98957825], [73.02791595, 17.98958397], [73.02791595, 17.9893055], [73.02735901, 17.98930931], [73.02735901, 17.98903084], [73.02654266, 17.98903084], [73.02654266, 17.98875046], [73.02513885, 17.98875046], [73.02513885, 17.98903084], [73.02403259, 17.98903084], [73.02403259, 17.98930931], [73.02319336, 17.9893055], [73.02319336, 17.98958397], [73.02236176, 17.98957825], [73.02236176, 17.98986053], [73.02179718, 17.98986053], [73.02179718, 17.99014091], [73.02040863, 17.99014091], [73.02040863, 17.98986053], [73.01985931, 17.98986053], [73.01985931, 17.99014091], [73.01902771, 17.99014091], [73.01902771, 17.99041939], [73.01875305, 17.99041748], [73.01875305, 17.99069405], [73.01847076, 17.99069405], [73.01847076, 17.99097252], [73.01791382, 17.99097252], [73.01791382, 17.99111938], [73.01791382, 17.9920826], [73.01819611, 17.9920826], [73.01819611, 17.99263954], [73.01875305, 17.99263954], [73.01875305, 17.99291992], [73.0201416, 17.99291992], [73.0201416, 17.99263954], [73.02097321, 17.99263954], [73.02097321, 17.99291992], [73.02124786, 17.99291611], [73.02124786, 17.99319458], [73.02153015, 17.99319458], [73.02153015, 17.99374962], [73.02124786, 17.99374008], [73.02124786, 17.99403], [73.02097321, 17.99402809], [73.02097321, 17.99430466], [73.02041626, 17.99430466], [73.02041626, 17.99458313], [73.0201416, 17.99458313], [73.0201416, 17.9948616], [73.01985931, 17.9948597], [73.01985931, 17.99570084], [73.01957703, 17.99570084], [73.01957703, 17.99653053], [73.01930237, 17.99652863], [73.01930237, 17.99708366], [73.01902771, 17.99707985], [73.01902771, 17.99792099], [73.01875305, 17.99792099], [73.01875305, 17.99875069], [73.01847076, 17.99875069], [73.01847076, 17.9995842], [73.01819611, 17.99958038], [73.01819611, 18.00014114], [73.01819611, 18.00152969], [73.01791382, 18.00152969], [73.01791382, 18.00291634], [73.01763916, 18.00291061], [73.01763916, 18.00403023], [73.0173645, 18.00402832], [73.0173645, 18.00486183], [73.01708221, 18.00486183], [73.01708221, 18.00542068], [73.01680756, 18.00542068], [73.01680756, 18.00653076], [73.0165329, 18.00653076], [73.0165329, 18.00681114], [73.01625061, 18.00680542], [73.01625061, 18.00708389], [73.01597595, 18.00708008], [73.01597595, 18.00764084], [73.01568604, 18.00764084], [73.01568604, 18.00792122], [73.01541901, 18.0079174], [73.01541901, 18.00819206], [73.01513672, 18.00819206], [73.01513672, 18.00847244], [73.01457977, 18.00847054], [73.01457977, 18.00902939], [73.01431274, 18.00902939], [73.01431274, 18.00930977], [73.01403046, 18.00930977], [73.01403046, 18.00902939], [73.01319122, 18.00902939], [73.01319122, 18.00930977], [73.01291656, 18.00930405], [73.01291656, 18.00958252], [73.01264191, 18.00958061], [73.01264191, 18.00986099], [73.01235962, 18.00986099], [73.01235962, 18.01013947], [73.01209259, 18.01013947], [73.01209259, 18.01041985], [73.00985718, 18.01041985], [73.00985718, 18.01013947], [73.00914764, 18.01013947], [73.00902557, 18.01013947], [73.00902557, 18.0102787], [73.00894165, 18.01041412], [73.00846863, 18.01041412], [73.00846863, 18.0106945], [73.00819397, 18.0106945], [73.00819397, 18.01097298], [73.00791931, 18.01097107], [73.00791931, 18.01152992], [73.00763702, 18.01152611], [73.00763702, 18.01208305], [73.00736237, 18.01208305], [73.00736237, 18.01236153], [73.00681305, 18.01235962], [73.00681305, 18.01263809], [73.00653076, 18.01263809], [73.00653076, 18.01292038], [73.00624847, 18.01291847], [73.00624847, 18.0134716], [73.00597382, 18.0134716], [73.00595856, 18.01429939], [73.00569153, 18.01430511], [73.00569153, 18.01464081], [73.00569153, 18.01625061], [73.00540924, 18.01625061], [73.00540924, 18.01652908], [73.00514221, 18.01652718], [73.00514221, 18.01708412], [73.00485992, 18.0170784], [73.00485992, 18.01902962], [73.0045929, 18.01902962], [73.0045929, 18.01931], [73.00430298, 18.01930618], [73.00430298, 18.01958275], [73.00402832, 18.01958275], [73.00402832, 18.01986122], [73.00347137, 18.01986122], [73.00347137, 18.02013969], [73.00237274, 18.02013969], [73.00237274, 18.02042007], [73.00208282, 18.02042007], [73.00208282, 18.02124977], [73.00237274, 18.02124977], [73.00237274, 18.02153015], [73.00347137, 18.02152824], [73.00347137, 18.02180481], [73.00402832, 18.02180481], [73.00402832, 18.02208328], [73.00430298, 18.02208328], [73.00430298, 18.02180481], [73.00514221, 18.02180481], [73.00514221, 18.02152824], [73.00624847, 18.02152824], [73.00624847, 18.02180481], [73.00680542, 18.02180481], [73.00680542, 18.02208328], [73.00736237, 18.02208328], [73.00736237, 18.02236176], [73.00763702, 18.02235985], [73.00763702, 18.02264023], [73.00791931, 18.02264023], [73.00791931, 18.02292061], [73.00819397, 18.02291679], [73.00819397, 18.02347183], [73.00875092, 18.02346992], [73.00875092, 18.02375031], [73.0090332, 18.02375031], [73.0090332, 18.02404022], [73.00985718, 18.02404022], [73.00985718, 18.02431107], [73.01013947, 18.02430534], [73.01013947, 18.02458382], [73.01069641, 18.02458], [73.01069641, 18.02486038], [73.01125336, 18.02486038], [73.01125336, 18.02458], [73.01152802, 18.02458], [73.01152802, 18.02486038], [73.01235962, 18.02486038], [73.01235962, 18.02514076], [73.01280212, 18.02513885], [73.01291656, 18.02513885], [73.01457977, 18.02514076], [73.01457977, 18.02542114], [73.01486206, 18.02541542], [73.01486206, 18.02569389], [73.01791382, 18.02569389], [73.01791382, 18.02597237], [73.01812744, 18.02597237], [73.01902771, 18.02597237], [73.01902771, 18.02541542], [73.01930237, 18.02542114], [73.01930237, 18.02514076], [73.01957703, 18.02514076], [73.01957703, 18.02458], [73.01985931, 18.02458382], [73.01985931, 18.02430534], [73.0201416, 18.02431107], [73.0201416, 18.02404022], [73.02069092, 18.02404022], [73.02069092, 18.02375031], [73.02124786, 18.02375031], [73.02124786, 18.02346992], [73.02263641, 18.02346992], [73.02263641, 18.02375031], [73.02346802, 18.02375031], [73.02346802, 18.02431107], [73.02402496, 18.02430534], [73.02402496, 18.02458382], [73.02458191, 18.02458], [73.02458191, 18.02486038], [73.02485657, 18.02486038], [73.02485657, 18.02514076], [73.02513885, 18.02514076], [73.02513885, 18.02542114], [73.02541351, 18.02541542], [73.02541351, 18.02569389], [73.0256958, 18.02569389], [73.0256958, 18.02597237], [73.0265274, 18.02597237], [73.0265274, 18.02625084], [73.02680206, 18.02625084], [73.02680206, 18.02653122], [73.02707672, 18.02653122], [73.02707672, 18.02625084], [73.02735901, 18.02625084], [73.02735901, 18.02653122], [73.0276413, 18.02653122], [73.0276413, 18.02680969], [73.02791595, 18.02680779], [73.02791595, 18.02708244], [73.02819824, 18.02708054], [73.02819824, 18.02736092], [73.02874756, 18.02736092], [73.02874756, 18.02763748], [73.02928925, 18.02763748], [73.02928925, 18.02791977], [73.02958679, 18.02791786], [73.02958679, 18.02874756], [73.03013611, 18.02874756], [73.03013611, 18.02902985], [73.0304184, 18.02902985], [73.0304184, 18.02931023], [73.03069305, 18.02930641], [73.03069305, 18.02986145], [73.03125, 18.0298481], [73.03125, 18.0304203], [73.03151703, 18.0304203], [73.03151703, 18.03070259], [73.03180695, 18.03069496], [73.03180695, 18.03097153], [73.0320816, 18.03097153], [73.0320816, 18.03125191], [73.03234863, 18.03125191], [73.03234863, 18.03153038], [73.03291321, 18.03153038], [73.03291321, 18.03181267], [73.0331955, 18.03180504], [73.0331955, 18.03236389], [73.03430176, 18.03236008], [73.03430939, 18.03264046], [73.03458405, 18.03263855], [73.03458405, 18.03291702], [73.0348587, 18.03291702], [73.0348587, 18.03347206], [73.03514099, 18.03347015], [73.03514099, 18.03375053], [73.03569794, 18.03375053], [73.03569794, 18.03403091], [73.0359726, 18.0340271], [73.0359726, 18.03458214], [73.03652954, 18.03458023], [73.03652954, 18.03486061], [73.03679657, 18.03486061], [73.03679657, 18.03514099], [73.03708649, 18.03514099], [73.03708649, 18.03541946], [73.03736115, 18.03541756], [73.03736115, 18.03569412], [73.0376358, 18.03569031], [73.0376358, 18.03598022], [73.03791809, 18.03598022], [73.03791809, 18.03625107], [73.03848267, 18.03625107], [73.03848267, 18.03652954], [73.03874969, 18.03652954], [73.03874969, 18.03680992], [73.03901672, 18.03680992], [73.03901672, 18.03874969], [73.03930664, 18.03874969], [73.03930664, 18.03903961], [73.0395813, 18.03902626], [73.0395813, 18.03986168], [73.03985596, 18.03985977], [73.03985596, 18.04042053], [73.04013824, 18.04042053], [73.04013824, 18.04124832], [73.03986359, 18.04124832], [73.03986359, 18.04208374], [73.04013824, 18.04207993], [73.04013824, 18.0423584], [73.0404129, 18.0423584], [73.0404129, 18.04291916], [73.04069519, 18.04291725], [73.04069519, 18.04319382], [73.04125214, 18.04319382], [73.04125214, 18.04347229], [73.04152679, 18.04347229], [73.04152679, 18.04319382], [73.04291534, 18.04319382], [73.04291534, 18.04264069], [73.04319763, 18.04264069], [73.04319763, 18.04207993], [73.04347229, 18.04208374], [73.04347229, 18.04180527], [73.04374695, 18.04180908], [73.04374695, 18.04153061], [73.04428864, 18.04153061], [73.04428864, 18.04124832], [73.04457855, 18.04124832], [73.04457855, 18.04096985], [73.04486084, 18.04097176], [73.04486084, 18.04069519], [73.0451355, 18.04069519], [73.0451355, 18.04097176], [73.04541779, 18.04096985], [73.04541779, 18.04153061], [73.04514313, 18.04153061], [73.04514313, 18.04180908], [73.04486084, 18.04180527], [73.04486084, 18.04208374], [73.04457855, 18.04207993], [73.04457855, 18.04264069], [73.04428864, 18.04264069], [73.04428864, 18.04291916], [73.04402924, 18.04291725], [73.04402924, 18.04319382], [73.04374695, 18.04319382], [73.04374695, 18.04347229], [73.04347229, 18.04346848], [73.04347229, 18.04375076], [73.04319763, 18.04375076], [73.04319763, 18.04403114], [73.0423584, 18.04403114], [73.0423584, 18.04430962], [73.04070282, 18.04430962], [73.04070282, 18.04403114], [73.0404129, 18.04403114], [73.0404129, 18.04375076], [73.04013824, 18.04375076], [73.04013824, 18.04346848], [73.03986359, 18.04347229], [73.03986359, 18.04319382], [73.0395813, 18.04319382], [73.0395813, 18.04264069], [73.03930664, 18.04264069], [73.03930664, 18.04207993], [73.03902435, 18.04208374], [73.03902435, 18.04013634], [73.03874969, 18.04014015], [73.03874969, 18.03985977], [73.03847504, 18.03986168], [73.03847504, 18.03958321], [73.03819275, 18.03958321], [73.03819275, 18.03902626], [73.03791809, 18.03903961], [73.03791809, 18.03819084], [73.0376358, 18.03819466], [73.0376358, 18.03791428], [73.03736115, 18.03792], [73.03736115, 18.03736115], [73.03708649, 18.03736115], [73.03708649, 18.03708076], [73.0368042, 18.03708267], [73.0368042, 18.0368042], [73.0359726, 18.03680992], [73.0359726, 18.03652954], [73.03572083, 18.03652954], [73.03569794, 18.03625107], [73.03542328, 18.03625107], [73.03542328, 18.03569031], [73.0348587, 18.03569412], [73.0348587, 18.03541756], [73.03457642, 18.03541946], [73.03457642, 18.03514099], [73.03430176, 18.03514099], [73.03430176, 18.03486061], [73.0340271, 18.03486061], [73.0340271, 18.03458023], [73.03375244, 18.03458214], [73.03375244, 18.03430557], [73.03347015, 18.03430939], [73.03347015, 18.03375053], [73.03291321, 18.03375053], [73.03291321, 18.03347015], [73.03263855, 18.03347206], [73.03263855, 18.03319359], [73.0320816, 18.03319359], [73.0320816, 18.03291702], [73.03152466, 18.03291702], [73.03152466, 18.03263855], [73.03125, 18.03264046], [73.03125, 18.03236008], [73.03097534, 18.03236389], [73.03097534, 18.03208351], [73.02958679, 18.03208351], [73.02958679, 18.03291702], [73.0293045, 18.03291702], [73.0293045, 18.03319359], [73.02902985, 18.03319359], [73.02902985, 18.03347206], [73.02874756, 18.03347015], [73.02874756, 18.03375053], [73.02819824, 18.03375053], [73.02819824, 18.03430939], [73.02791595, 18.03430939], [73.02791595, 18.03514099], [73.0276413, 18.03514099], [73.0276413, 18.03541946], [73.02735901, 18.03541756], [73.02735901, 18.03569412], [73.02654266, 18.03569031], [73.02654266, 18.03652954], [73.02680206, 18.03652954], [73.02680206, 18.03763962], [73.02654266, 18.03763962], [73.02654266, 18.03792], [73.02625275, 18.03792], [73.02625275, 18.03763962], [73.02513885, 18.03763962], [73.02513885, 18.03736115], [73.02430725, 18.03736115], [73.02430725, 18.03708076], [73.02402496, 18.03708267], [73.02402496, 18.0368042], [73.02430725, 18.03680992], [73.02430725, 18.03652954], [73.02458191, 18.03652954], [73.02458191, 18.03625107], [73.02403259, 18.03625107], [73.02403259, 18.03652954], [73.02346802, 18.03652954], [73.02346802, 18.03680992], [73.02319336, 18.0368042], [73.02319336, 18.03708267], [73.02263641, 18.03708267], [73.02263641, 18.0368042], [73.02153015, 18.0368042], [73.02153015, 18.03930473], [73.02180481, 18.03930473], [73.02180481, 18.03958321], [73.02236176, 18.03958321], [73.02236176, 18.03986168], [73.02263641, 18.03985977], [73.02263641, 18.04014015], [73.0229187, 18.04014015], [73.0229187, 18.04042053], [73.02319336, 18.04041862], [73.02319336, 18.04097176], [73.02346802, 18.04096985], [73.02346802, 18.04124832], [73.02375031, 18.04124832], [73.02375031, 18.04153061], [73.02402496, 18.04153061], [73.02402496, 18.0423584], [73.02458191, 18.0423584], [73.02458191, 18.04264069], [73.02485657, 18.04264069], [73.02485657, 18.04291916], [73.02513885, 18.04291725], [73.02513885, 18.04319382], [73.02541351, 18.04319382], [73.02541351, 18.04347229], [73.0256958, 18.04346848], [73.0256958, 18.04375076], [73.02597046, 18.04375076], [73.02597046, 18.04458427], [73.0256958, 18.04458237], [73.0256958, 18.04514122], [73.02597046, 18.04514122], [73.02597046, 18.04541969], [73.02625275, 18.04541588], [73.02625275, 18.04569435], [73.02680206, 18.04569435], [73.02680206, 18.04597282], [73.02735901, 18.04597282], [73.02735901, 18.04624939], [73.0284729, 18.04624939], [73.0284729, 18.04652977], [73.02874756, 18.04652977], [73.02874756, 18.04681015], [73.0293045, 18.04680634], [73.0293045, 18.0470829], [73.02986145, 18.0470829], [73.02986145, 18.04736137], [73.03069305, 18.04735947], [73.03069305, 18.04763985], [73.03180695, 18.04763985], [73.03180695, 18.04792023], [73.03291321, 18.04791641], [73.03291321, 18.04819489], [73.0331955, 18.04819489], [73.0331955, 18.04847145], [73.03375244, 18.04846954], [73.03375244, 18.04874992], [73.0340271, 18.04874992], [73.0340271, 18.0490303], [73.03514099, 18.0490303], [73.03514099, 18.04931068], [73.0359726, 18.04930305], [73.0359726, 18.04958344], [73.0376358, 18.04958344], [73.0376358, 18.04930305], [73.03874969, 18.04931068], [73.03874969, 18.0490303], [73.03930664, 18.0490303], [73.03930664, 18.04874992], [73.0395813, 18.04874992], [73.0395813, 18.0490303], [73.03986359, 18.0490284], [73.03986359, 18.04958344], [73.0395813, 18.04958344], [73.0395813, 18.04986191], [73.03985596, 18.04986], [73.03985596, 18.05014038], [73.04013824, 18.05014038], [73.04013824, 18.05042076], [73.03985596, 18.05042076], [73.03985596, 18.05181122], [73.0395813, 18.0518055], [73.0395813, 18.05208397], [73.03985596, 18.05208015], [73.03985596, 18.05236053], [73.04013824, 18.05236053], [73.04013824, 18.05291939], [73.0404129, 18.05291557], [73.0404129, 18.05319405], [73.04013824, 18.05319405], [73.04013824, 18.05347252], [73.03985596, 18.05347061], [73.03985596, 18.05375099], [73.03901672, 18.05375099], [73.03901672, 18.05347061], [73.03874969, 18.05347252], [73.03874969, 18.05291557], [73.03848267, 18.05291939], [73.03848267, 18.05236053], [73.03791809, 18.05236053], [73.03791809, 18.05264091], [73.03679657, 18.05264091], [73.03679657, 18.05236053], [73.03624725, 18.05236053], [73.03624725, 18.05208015], [73.03569794, 18.05208015], [73.03569794, 18.05236053], [73.03542328, 18.05236053], [73.03542328, 18.05264091], [73.03514099, 18.05264091], [73.03514099, 18.05236053], [73.0348587, 18.05236053], [73.0348587, 18.05208015], [73.03458405, 18.05208397], [73.03458405, 18.0518055], [73.0348587, 18.05181122], [73.0348587, 18.05153084], [73.03430176, 18.05153084], [73.03430176, 18.05125046], [73.03375244, 18.05125046], [73.03375244, 18.05097961], [73.03347015, 18.05097961], [73.03347015, 18.05070114], [73.03291321, 18.0506897], [73.03291321, 18.05041695], [73.03234863, 18.05042076], [73.03234863, 18.05014038], [73.0320816, 18.05014038], [73.0320816, 18.05042076], [73.03180695, 18.05042076], [73.03180695, 18.05014038], [73.03098297, 18.05014038], [73.03098297, 18.04986], [73.02986145, 18.04986], [73.02986145, 18.05014038], [73.02928925, 18.05014038], [73.02928925, 18.05042076], [73.02902985, 18.05041695], [73.02902985, 18.05069351], [73.0284729, 18.05069351], [73.0284729, 18.05041695], [73.02819824, 18.05042076], [73.02819824, 18.04999924], [73.02819061, 18.04957962], [73.02735901, 18.04958344], [73.02735901, 18.04930305], [73.02625275, 18.04931068], [73.02625275, 18.05014038], [73.02597046, 18.05014038], [73.02597046, 18.05042076], [73.02513885, 18.05042076], [73.02513885, 18.05014038], [73.02485657, 18.05014038], [73.02485657, 18.04986], [73.02458191, 18.04986191], [73.02458191, 18.04874992], [73.02485657, 18.04874992], [73.02485657, 18.04846954], [73.02541351, 18.04847145], [73.02541351, 18.04819489], [73.02513885, 18.04819489], [73.02513885, 18.04791641], [73.02485657, 18.04792023], [73.02485657, 18.04735947], [73.02458191, 18.04736137], [73.02458191, 18.04680634], [73.02430725, 18.04680634], [73.02430725, 18.0470829], [73.02375031, 18.0470829], [73.02375031, 18.04680634], [73.02346802, 18.04681015], [73.02346802, 18.04597282], [73.02319336, 18.04597282], [73.02319336, 18.04513931], [73.0229187, 18.04514122], [73.0229187, 18.04458237], [73.02263641, 18.04458427], [73.02263641, 18.0443058], [73.0229187, 18.04430962], [73.0229187, 18.04375076], [73.02263641, 18.04375076], [73.02263641, 18.04291916], [73.0220871, 18.04291916], [73.0220871, 18.04264069], [73.02179718, 18.04264069], [73.02179718, 18.0423584], [73.02124786, 18.0423584], [73.02124786, 18.04180908], [73.02097321, 18.04180908], [73.02097321, 18.04070091], [73.02040863, 18.04070091], [73.02040863, 18.04014015], [73.0201416, 18.04014015], [73.0201416, 18.03930092], [73.01985931, 18.03930473], [73.01985931, 18.03847313], [73.01958466, 18.03847313], [73.01958466, 18.03708267], [73.01930237, 18.03708267], [73.01930237, 18.0368042], [73.01902771, 18.03680992], [73.01902771, 18.03652954], [73.01875305, 18.03652954], [73.01875305, 18.03598022], [73.01847076, 18.03598022], [73.01847076, 18.03458023], [73.01819611, 18.03458214], [73.01819611, 18.03319359], [73.01791382, 18.03319359], [73.01791382, 18.03291702], [73.0173645, 18.03291702], [73.0173645, 18.03236389], [73.01708221, 18.03236389], [73.01708221, 18.03208351], [73.01569366, 18.03208351], [73.01569366, 18.03236389], [73.01541901, 18.03236008], [73.01541901, 18.03264046], [73.01513672, 18.03263855], [73.01513672, 18.03291702], [73.01457977, 18.03291702], [73.01457977, 18.03347206], [73.01431274, 18.03347015], [73.01431274, 18.03430939], [73.01403046, 18.03430939], [73.01403046, 18.03486061], [73.01346588, 18.03486061], [73.01346588, 18.03514099], [73.01291656, 18.03514099], [73.01291656, 18.03541946], [73.01264191, 18.03541946], [73.01264191, 18.03598022], [73.01235962, 18.0359726], [73.01235962, 18.03708267], [73.01208496, 18.03708267], [73.01209259, 18.03874969], [73.01180267, 18.03874969], [73.01180267, 18.03958321], [73.01152802, 18.03958321], [73.01152802, 18.03986168], [73.01125336, 18.03985977], [73.01125336, 18.04042053], [73.01152802, 18.04042053], [73.01152802, 18.04070091], [73.01125336, 18.04069519], [73.01125336, 18.04097176], [73.01097107, 18.04096985], [73.01097107, 18.04124832], [73.01069641, 18.04124832], [73.01069641, 18.04180908], [73.01013947, 18.04180908], [73.01013947, 18.0423584], [73.01040649, 18.0423584], [73.01040649, 18.04264069], [73.01069641, 18.04264069], [73.01069641, 18.04375076], [73.01040649, 18.04375076], [73.01040649, 18.04430962], [73.01013947, 18.0443058], [73.01013947, 18.04458427], [73.00985718, 18.04458237], [73.00985718, 18.04514122], [73.00958252, 18.04514122], [73.00958252, 18.04541969], [73.00930786, 18.04541969], [73.00930786, 18.04652977], [73.0090332, 18.04652977], [73.0090332, 18.04763985], [73.00875092, 18.04763985], [73.00875092, 18.04847145], [73.00846863, 18.04846954], [73.00846863, 18.04874992], [73.00817871, 18.04874992], [73.00817871, 18.04931068], [73.00791931, 18.04930305], [73.00791931, 18.04958344], [73.00763702, 18.04958344], [73.00763702, 18.04986191], [73.00736237, 18.04986], [73.00736237, 18.05014038], [73.00708008, 18.05014038], [73.00708008, 18.05042076], [73.00653076, 18.05042076], [73.00653076, 18.05097961], [73.00624847, 18.05097961], [73.00624847, 18.05125046], [73.00596619, 18.05125046], [73.00596619, 18.05153084], [73.00569153, 18.05153084], [73.00569153, 18.05181122], [73.00541687, 18.0518055], [73.00541687, 18.05208397], [73.00514221, 18.05208015], [73.00514221, 18.05236053], [73.00485992, 18.05236053], [73.00485992, 18.05264091], [73.00430298, 18.05264091], [73.00430298, 18.05291939], [73.00375366, 18.05291557], [73.00375366, 18.05319405], [73.00319672, 18.05319405], [73.00319672, 18.05347252], [73.00237274, 18.05347061], [73.00237274, 18.05430984], [73.00208282, 18.05430794], [73.00208282, 18.0545826], [73.00152588, 18.0545826], [73.00152588, 18.05430794], [73.00125122, 18.05430984], [73.00125122, 18.05375099], [73.00096893, 18.05375099], [73.00096893, 18.05347061], [73.00069427, 18.05347252], [73.00069427, 18.05291557], [73.00041962, 18.05291939], [73.00041962, 18.05153084], [72.99986267, 18.05153084], [72.99986267, 18.05125046], [72.99958038, 18.05125046], [72.99958038, 18.05097961], [72.99931335, 18.05097961], [72.99931335, 18.05070114], [72.99903107, 18.0506897], [72.99903107, 18.05041695], [72.99874878, 18.05042076], [72.99874878, 18.05014038], [72.99846649, 18.05014038], [72.99846649, 18.04986], [72.99791718, 18.04986191], [72.99791718, 18.04958344], [72.99736023, 18.04958344], [72.99736023, 18.04930305], [72.99687958, 18.04930305], [72.99485779, 18.04930305], [72.99485779, 18.04958344], [72.99430847, 18.04958344], [72.99430847, 18.04986191], [72.99375153, 18.04986], [72.99375153, 18.05014038], [72.99346924, 18.05014038], [72.99346924, 18.05153084], [72.99317932, 18.05153084], [72.99317932, 18.05181122], [72.99291992, 18.0518055], [72.99291992, 18.05208397], [72.99263763, 18.05208015], [72.99263763, 18.05236053], [72.99208069, 18.05236053], [72.99208069, 18.05264091], [72.99180603, 18.05264091], [72.99180603, 18.05291939], [72.99153137, 18.05291557], [72.99153137, 18.05347252], [72.99124908, 18.05347061], [72.99124908, 18.05375099], [72.9909668, 18.05375099], [72.9909668, 18.05430984], [72.99069214, 18.05430794], [72.99069214, 18.0545826], [72.99041748, 18.0545826], [72.99041748, 18.05485916], [72.99013519, 18.05485916], [72.99014282, 18.05513954], [72.98986053, 18.05513954], [72.98986053, 18.05597305], [72.98958588, 18.05597305], [72.98958588, 18.05708313], [72.98986053, 18.05707932], [72.98986053, 18.05820274], [72.99013519, 18.05819511], [72.99013519, 18.05875015], [72.99043274, 18.05875015], [72.99043274, 18.05931282], [72.99069214, 18.05931282], [72.99069214, 18.06125069], [72.9909668, 18.06125069], [72.9909668, 18.06153107], [72.99124908, 18.06153107], [72.99124908, 18.06180954], [72.99153137, 18.06180573], [72.99153137, 18.0620842], [72.99180603, 18.06208038], [72.99180603, 18.06236076], [72.99208069, 18.06236076], [72.99208069, 18.06291962], [72.99236298, 18.0629158], [72.99236298, 18.06319427], [72.99263763, 18.06319427], [72.99263763, 18.06347275], [72.99291992, 18.06347084], [72.99291992, 18.06375122], [72.99319458, 18.06374931], [72.99319458, 18.06406021], [72.99319458, 18.0648613], [72.99346924, 18.06485939], [72.99346924, 18.06653023], [72.99375153, 18.06652641], [72.99375153, 18.06680489], [72.99430847, 18.06680489], [72.99430847, 18.06708336], [72.99458313, 18.06708336], [72.99458313, 18.06736183], [72.99485779, 18.06735992], [72.99485779, 18.0676403], [72.99514008, 18.0676403], [72.99514008, 18.06792068], [72.9954071, 18.06792068], [72.9954071, 18.06819916], [72.99743652, 18.06819534], [72.99764252, 18.06819534], [72.99764252, 18.06847191], [72.99819183, 18.06846809], [72.99819183, 18.06875038], [72.99847412, 18.06875038], [72.99847412, 18.06902885], [72.99874878, 18.06902885], [72.99874878, 18.06958389], [72.99903107, 18.06957817], [72.99903107, 18.06985855], [72.99931335, 18.06985855], [72.99931335, 18.07041931], [73.00013733, 18.07041931], [73.00041962, 18.0704174], [73.00041962, 18.07069397], [73.00152588, 18.07069397], [73.00152588, 18.07097244], [73.00180817, 18.07097244], [73.00180817, 18.07152939], [73.00208282, 18.07152939], [73.00208282, 18.07291985], [73.00235748, 18.07291603], [73.00235748, 18.07458305], [73.00263977, 18.07458115], [73.00263977, 18.07514954], [73.0029068, 18.07514954], [73.0029068, 18.07570076], [73.00263977, 18.07569313], [73.00263977, 18.0759716], [73.00208282, 18.0759716], [73.00208282, 18.07541656], [73.00125122, 18.07542038], [73.00125122, 18.07570076], [73.00096893, 18.07569313], [73.00096893, 18.0759716], [73.00068665, 18.0759697], [73.00068665, 18.07653046], [73.00041962, 18.07653046], [73.00041962, 18.07681084], [73.00013733, 18.07681084], [72.99986267, 18.07681084], [72.99986267, 18.07374954], [72.99958038, 18.07374954], [72.99958038, 18.07402992], [72.99931335, 18.07402992], [72.99931335, 18.0743103], [72.99903107, 18.07430649], [72.99903107, 18.07458305], [72.99874878, 18.07458115], [72.99874878, 18.07542038], [72.99846649, 18.07542038], [72.99846649, 18.07625008], [72.99819183, 18.07625008], [72.99819183, 18.07653046], [72.99764252, 18.07653046], [72.99764252, 18.07681084], [72.99736023, 18.07680511], [72.99736023, 18.07819366], [72.99708557, 18.07819366], [72.99708557, 18.07847214], [72.99680328, 18.07847023], [72.99680328, 18.07903099], [72.99652863, 18.07902527], [72.99652863, 18.07958412], [72.99680328, 18.07958031], [72.99680328, 18.08014107], [72.99652863, 18.08013725], [72.99652863, 18.0806942], [72.99624634, 18.0806942], [72.99624634, 18.08208275], [72.99597168, 18.08208275], [72.99597168, 18.08346939], [72.99569702, 18.08346939], [72.99569702, 18.08403015], [72.99541473, 18.08402824], [72.99541473, 18.08486176], [72.99514008, 18.08486176], [72.99514008, 18.08542061], [72.99485779, 18.08542061], [72.99485779, 18.0857029], [72.99458313, 18.0857029], [72.99458313, 18.08681107], [72.99430847, 18.08681107], [72.99430847, 18.08792114], [72.99402618, 18.08791733], [72.99402618, 18.08847237], [72.99375153, 18.08847046], [72.99375153, 18.08986092], [72.99346924, 18.08986092], [72.99346924, 18.09069443], [72.99317932, 18.09069061], [72.99317932, 18.09181023], [72.99291992, 18.09180832], [72.99291992, 18.09236145], [72.99263763, 18.09236145], [72.99263763, 18.09347153], [72.99236298, 18.09347153], [72.99236298, 18.09458351], [72.99208069, 18.0945797], [72.99208069, 18.09514046], [72.99180603, 18.09514046], [72.99180603, 18.09569359], [72.99153137, 18.09568977], [72.99153137, 18.09626007], [72.99124908, 18.09626007], [72.99124908, 18.09680939], [72.9909668, 18.09680939], [72.9909668, 18.0976429], [72.99069214, 18.09763908], [72.99069214, 18.09819412], [72.99043274, 18.09819031], [72.99043274, 18.09902954], [72.99013519, 18.09902763], [72.99013519, 18.09958267], [72.98986053, 18.09958267], [72.98986053, 18.10013962], [72.98958588, 18.10013962], [72.98958588, 18.10042], [72.98930359, 18.10041618], [72.98930359, 18.10069466], [72.98902893, 18.10069466], [72.98902893, 18.10097313], [72.98874664, 18.10097122], [72.98874664, 18.10124969], [72.98847198, 18.10124969], [72.98847198, 18.10153008], [72.98819733, 18.10152817], [72.98819733, 18.10180473], [72.98791504, 18.10180473], [72.98791504, 18.10208321], [72.98652649, 18.10208321], [72.98652649, 18.10180473], [72.98569489, 18.10180473], [72.98569489, 18.10208321], [72.98513794, 18.10208321], [72.98513794, 18.10236168], [72.98458099, 18.10235977], [72.98458099, 18.10264015], [72.98400879, 18.10264015], [72.98400879, 18.10292053], [72.98347473, 18.10291672], [72.98347473, 18.10347176], [72.98319244, 18.10346985], [72.98319244, 18.10403061], [72.98291779, 18.10403061], [72.98291779, 18.10431099], [72.9826355, 18.10430527], [72.9826355, 18.10513878], [72.98236084, 18.10513115], [72.98236084, 18.10542107], [72.98208618, 18.10541534], [72.98208618, 18.10569382], [72.98097229, 18.10569], [72.98097229, 18.10625076], [72.98069763, 18.10625076], [72.98069763, 18.10680962], [72.98041534, 18.10680771], [72.98042297, 18.10736084], [72.98014069, 18.10736084], [72.98014069, 18.10764122], [72.97957611, 18.10764122], [72.97957611, 18.10791969], [72.97930908, 18.10791969], [72.97930908, 18.10819817], [72.97902679, 18.10819435], [72.97902679, 18.10986137], [72.97875214, 18.10986137], [72.97875214, 18.11181068], [72.97902679, 18.11180496], [72.97902679, 18.11208344], [72.97930908, 18.11207962], [72.97930908, 18.11375046], [72.97902679, 18.11375046], [72.97902679, 18.11403084], [72.97820282, 18.11403084], [72.97820282, 18.11432076], [72.9770813, 18.11432076], [72.9770813, 18.11486053], [72.97680664, 18.11486053], [72.97680664, 18.11597252], [72.9770813, 18.11597252], [72.9770813, 18.1170826], [72.97735596, 18.11707115], [72.97735596, 18.11736107], [72.9770813, 18.11736107], [72.9770813, 18.11791992], [72.97680664, 18.1179142], [72.97680664, 18.11847305], [72.97651672, 18.11847115], [72.97651672, 18.11903], [72.97680664, 18.11902618], [72.97680664, 18.11958313], [72.97651672, 18.11958122], [72.97651672, 18.12013817], [72.97624969, 18.12013817], [72.97624969, 18.12070084], [72.97598267, 18.12070084], [72.97598267, 18.12181091], [72.97569275, 18.12181091], [72.97569275, 18.12235832], [72.97543335, 18.12235832], [72.97543335, 18.12291908], [72.9751358, 18.12291908], [72.9751358, 18.12319946], [72.97458649, 18.12319374], [72.97458649, 18.12347221], [72.9743042, 18.12347221], [72.9743042, 18.12319374], [72.97402954, 18.12319374], [72.97402954, 18.12347221], [72.97374725, 18.1234684], [72.97374725, 18.12375069], [72.97319794, 18.12375069], [72.97319794, 18.12402916], [72.97292328, 18.12402916], [72.97292328, 18.12430954], [72.97264099, 18.12430954], [72.97264099, 18.12486267], [72.9723587, 18.12486267], [72.9723587, 18.12652969], [72.97215271, 18.12652969], [72.97206879, 18.12763977], [72.97180939, 18.12763977], [72.97180176, 18.12986183], [72.9715271, 18.12986183], [72.9715271, 18.13097191], [72.97125244, 18.13097191], [72.97125244, 18.13208389], [72.97097015, 18.13208008], [72.97097015, 18.13292122], [72.97264099, 18.13292122], [72.97264099, 18.13264084], [72.97292328, 18.13264084], [72.97292328, 18.13292122], [72.97319794, 18.1329155], [72.97319794, 18.13347244], [72.9734726, 18.13347054], [72.9734726, 18.13375092], [72.97374725, 18.13375092], [72.97374725, 18.13422012], [72.97374725, 18.13430786], [72.97486115, 18.13430786], [72.97486115, 18.13458252], [72.97541809, 18.13458252], [72.97541809, 18.13485909], [72.97597504, 18.13485909], [72.97597504, 18.13513756], [72.97651672, 18.13513756], [72.97651672, 18.13542938], [72.97846985, 18.13541794], [72.97846985, 18.1356945], [72.97902679, 18.1356945], [72.97902679, 18.13597298], [72.97930908, 18.13596916], [72.97930908, 18.13625145], [72.9798584, 18.13625145], [72.9798584, 18.13653183], [72.98097229, 18.13652992], [72.98097229, 18.13680077], [72.98152924, 18.13680649], [72.98152924, 18.13708305], [72.98180389, 18.13708305], [72.98180389, 18.14097214], [72.98208618, 18.14097023], [72.98208618, 18.14153099], [72.98236084, 18.14152718], [72.98236084, 18.14208412], [72.9826355, 18.14208412], [72.9826355, 18.14236069], [72.9834671, 18.14236069], [72.9834671, 18.14264107], [72.98486328, 18.14264107], [72.98486328, 18.14291954], [72.98513794, 18.14291573], [72.98513794, 18.14347267], [72.98542023, 18.14347076], [72.98542023, 18.14736748], [72.98569489, 18.14736176], [72.98569489, 18.14847183], [72.98596954, 18.14846992], [72.98596954, 18.1487484], [72.98625183, 18.1487484], [72.98625183, 18.14903069], [72.98680878, 18.14902878], [72.98680878, 18.14958382], [72.98652649, 18.14957809], [72.98652649, 18.15014076], [72.98625183, 18.15014076], [72.98625183, 18.15097237], [72.98596954, 18.15096855], [72.98596954, 18.15153122], [72.98569489, 18.1515274], [72.98569489, 18.15208244], [72.98596954, 18.15208244], [72.98596954, 18.15263939], [72.98569489, 18.15263939], [72.98569489, 18.1534729], [72.98542023, 18.1534729], [72.98542023, 18.15431023], [72.98568726, 18.15431023], [72.98568726, 18.15513992], [72.98596954, 18.15513992], [72.98596954, 18.15570068], [72.98625183, 18.15570068], [72.98625183, 18.15681076], [72.98652649, 18.15680313], [72.98652649, 18.15736198], [72.98680878, 18.15736008], [72.98680878, 18.15764046], [72.98707581, 18.15764046], [72.98707581, 18.15792084], [72.98792267, 18.15792084], [72.98792267, 18.15764046], [72.98874664, 18.15764046], [72.98874664, 18.15736008], [72.98986053, 18.15736008], [72.98986053, 18.15764046], [72.99014282, 18.15764046], [72.99014282, 18.15792084], [72.99041748, 18.15791512], [72.99041748, 18.15986061], [72.99013519, 18.15986061], [72.99013519, 18.15958405], [72.98930359, 18.15958405], [72.98930359, 18.15930557], [72.98847198, 18.15930939], [72.98847198, 18.15986061], [72.98792267, 18.15986061], [72.98792267, 18.16041946], [72.98764038, 18.16041946], [72.98764038, 18.16152954], [72.98735809, 18.16152954], [72.98735809, 18.16319466], [72.98707581, 18.16319084], [72.98707581, 18.16403008], [72.98680878, 18.16402817], [72.98680878, 18.16486168], [72.98652649, 18.16486168], [72.98652649, 18.16570282], [72.98625183, 18.16570282], [72.98625183, 18.16764069], [72.98596954, 18.16763878], [72.98596954, 18.16819382], [72.98568726, 18.16818047], [72.98568726, 18.16875076], [72.98542023, 18.16875076], [72.98542023, 18.17041969], [72.98513794, 18.17041588], [72.98513794, 18.17097282], [72.98486328, 18.17097092], [72.98486328, 18.17154121], [72.98458099, 18.17152786], [72.98458099, 18.17347145], [72.98430634, 18.17347145], [72.98430634, 18.17486191], [72.98400879, 18.17485809], [72.98400879, 18.17542076], [72.98374939, 18.17541885], [72.98374939, 18.1756897], [72.9834671, 18.17569923], [72.9834671, 18.17653084], [72.98374939, 18.17652893], [72.98374939, 18.17708397], [72.98347473, 18.17708397], [72.98347473, 18.17735863], [72.98319244, 18.17734909], [72.98319244, 18.17791939], [72.98291779, 18.17791939], [72.98291779, 18.1787529], [72.98264313, 18.1787529], [72.98264313, 18.17930984], [72.98236084, 18.17930984], [72.98236084, 18.18013954], [72.98208618, 18.18013954], [72.98208618, 18.18208313], [72.98179626, 18.18208122], [72.98179626, 18.18292046], [72.98152924, 18.18292046], [72.98152924, 18.18348122], [72.98124695, 18.18347168], [72.98124695, 18.18458366], [72.98097229, 18.18457985], [72.98097229, 18.18514061], [72.98069763, 18.18514061], [72.98069763, 18.18542099], [72.98041534, 18.18541527], [72.98042297, 18.18625069], [72.98014069, 18.18625069], [72.98014069, 18.18736076], [72.9798584, 18.18736076], [72.9798584, 18.18875122], [72.97957611, 18.18875122], [72.97957611, 18.18930817], [72.97930908, 18.18930817], [72.97930908, 18.1926403], [72.97902679, 18.1926384], [72.97902679, 18.19347382], [72.97930908, 18.19347191], [72.97930908, 18.19375038], [72.97957611, 18.19375038], [72.97957611, 18.19403076], [72.98014069, 18.19403076], [72.98014069, 18.19375038], [72.98042297, 18.19375038], [72.98041534, 18.19347382], [72.98069763, 18.19347382], [72.98069763, 18.19319534], [72.98123932, 18.19320107], [72.98123932, 18.19292068], [72.98236084, 18.19292068], [72.98236084, 18.19320107], [72.98319244, 18.19320107], [72.98319244, 18.19292068], [72.98374939, 18.19292068], [72.98374939, 18.1926403], [72.98486328, 18.1926403], [72.98486328, 18.19292068], [72.98513794, 18.19292068], [72.98513794, 18.1926403], [72.98542023, 18.1926403], [72.98542023, 18.19292068], [72.98569489, 18.19291687], [72.98569489, 18.19347382], [72.98764038, 18.19347191], [72.98764038, 18.19403076], [72.98792267, 18.19403076], [72.98792267, 18.19431114], [72.98764038, 18.19431114], [72.98764038, 18.19514084], [72.98737335, 18.19514084], [72.98737335, 18.19542122], [72.98458099, 18.19542122], [72.98458099, 18.19514084], [72.98429871, 18.19514084], [72.98429871, 18.19542122], [72.98400879, 18.19542122], [72.98400879, 18.19514084], [72.98291779, 18.19514084], [72.98291779, 18.19486046], [72.98264313, 18.19486046], [72.98264313, 18.19514084], [72.98208618, 18.19514084], [72.98208618, 18.19542122], [72.98124695, 18.1954174], [72.98124695, 18.19597244], [72.98041534, 18.19597244], [72.98042297, 18.19625092], [72.98014069, 18.19625092], [72.98014069, 18.19652939], [72.9798584, 18.19652939], [72.9798584, 18.19680977], [72.97958374, 18.19680405], [72.97958374, 18.19708252], [72.97930908, 18.19708061], [72.97930908, 18.19736099], [72.97902679, 18.19736099], [72.97902679, 18.19763947], [72.97875214, 18.19763947], [72.97875214, 18.19791985], [72.97846985, 18.19791412], [72.97846985, 18.1981945], [72.97820282, 18.19819069], [72.97820282, 18.19848061], [72.97763824, 18.19848061], [72.97763824, 18.1993103], [72.97736359, 18.1993084], [72.97736359, 18.19958305], [72.9770813, 18.19958115], [72.9770813, 18.20013809], [72.97680664, 18.20013809], [72.97680664, 18.20042038], [72.97624969, 18.20042038], [72.97624969, 18.20070076], [72.97541809, 18.20069695], [72.97541809, 18.2009716], [72.9751358, 18.2009697], [72.9751358, 18.20124817], [72.97486115, 18.20124817], [72.97486115, 18.20153046], [72.97458649, 18.20152092], [72.97458649, 18.20181084], [72.9743042, 18.20180511], [72.9743042, 18.20208359], [72.97374725, 18.20208359], [72.97374725, 18.20236206], [72.9734726, 18.20235825], [72.9734726, 18.20264053], [72.97319794, 18.20264053], [72.97319794, 18.20319366], [72.97291565, 18.20319366], [72.97291565, 18.20347023], [72.9723587, 18.20346832], [72.9723587, 18.20375061], [72.9715271, 18.20375061], [72.9715271, 18.20346832], [72.97125244, 18.20347023], [72.97125244, 18.20319366], [72.97097015, 18.20319366], [72.97097015, 18.20347023], [72.97041321, 18.20346832], [72.97041321, 18.20375061], [72.97013855, 18.20375061], [72.97013855, 18.20458412], [72.96985626, 18.20458031], [72.96985626, 18.20514107], [72.9695816, 18.20514107], [72.9695816, 18.20541954], [72.96929932, 18.20541954], [72.96929932, 18.20514107], [72.96819305, 18.20514107], [72.96819305, 18.20541954], [72.9679184, 18.20541954], [72.9679184, 18.20625114], [72.96763611, 18.20625114], [72.96763611, 18.20681], [72.96736145, 18.20680618], [72.96736145, 18.20708275], [72.96708679, 18.20708275], [72.96708679, 18.20763969], [72.9668045, 18.20763969], [72.9668045, 18.20819473], [72.96652985, 18.20819473], [72.96652985, 18.20930481], [72.96624756, 18.20930481], [72.96624756, 18.20986176], [72.9659729, 18.20985985], [72.9659729, 18.21014023], [72.96569824, 18.21014023], [72.96569824, 18.21042061], [72.96541595, 18.21042061], [72.96541595, 18.21071053], [72.9651413, 18.21069527], [72.9651413, 18.21097183], [72.96485901, 18.21096992], [72.96485901, 18.21153069], [72.96457672, 18.21153069], [72.96457672, 18.21181107], [72.96430206, 18.21180534], [72.96430206, 18.21208382], [72.96263885, 18.21208], [72.96263885, 18.21236038], [72.96235657, 18.21236038], [72.96235657, 18.21292114], [72.96208191, 18.21291542], [72.96208191, 18.21319389], [72.96180725, 18.21319389], [72.96180725, 18.21347237], [72.96152496, 18.21347237], [72.96152496, 18.21375084], [72.96098328, 18.21375084], [72.96098328, 18.21403122], [72.96069336, 18.21403122], [72.96069336, 18.21430969], [72.9604187, 18.21430779], [72.9604187, 18.21458244], [72.96012878, 18.21458054], [72.96012878, 18.21486092], [72.95986176, 18.21486092], [72.95986176, 18.21541977], [72.9595871, 18.21541595], [72.9595871, 18.21569443], [72.95929718, 18.21569061], [72.95929718, 18.21624756], [72.95903015, 18.21624756], [72.95903015, 18.21681023], [72.95874786, 18.21680641], [72.95874786, 18.21708107], [72.95819092, 18.21708107], [72.95819092, 18.21736145], [72.95791626, 18.21736145], [72.95791626, 18.2179203], [72.95735931, 18.2179203], [72.95735931, 18.21820259], [72.95708466, 18.21819496], [72.95708466, 18.21846962], [72.95680237, 18.21846962], [72.95680237, 18.21875191], [72.95652771, 18.21875191], [72.95652771, 18.21903038], [72.95625305, 18.21903038], [72.95625305, 18.21931076], [72.95569611, 18.21931076], [72.95569611, 18.21959114], [72.95347595, 18.21959114], [72.95347595, 18.21931076], [72.95318604, 18.21931076], [72.95318604, 18.21903038], [72.95291901, 18.21903038], [72.95291901, 18.21875191], [72.95181274, 18.21875191], [72.95181274, 18.21903038], [72.95153046, 18.21903038], [72.95153046, 18.21931076], [72.95124817, 18.21930504], [72.95124817, 18.21986389], [72.95096588, 18.21986008], [72.95096588, 18.22042084], [72.95069122, 18.22041702], [72.95069122, 18.22069359], [72.95041656, 18.22069359], [72.95041656, 18.22097206], [72.95014191, 18.22097015], [72.95014191, 18.22125053], [72.94985962, 18.22125053], [72.94985962, 18.22153091], [72.94930267, 18.22153091], [72.94930267, 18.22180939], [72.94847107, 18.22180557], [72.94847107, 18.22208214], [72.94790649, 18.22208023], [72.94790649, 18.22236061], [72.94735718, 18.22236061], [72.94735718, 18.22265053], [72.94708252, 18.22265053], [72.94708252, 18.22291946], [72.94652557, 18.22291756], [72.94652557, 18.22319412], [72.94458008, 18.22319412], [72.94458008, 18.22263908], [72.94431305, 18.22265053], [72.94431305, 18.22236061], [72.94374847, 18.22236061], [72.94374847, 18.22208023], [72.94319153, 18.22208214], [72.94319153, 18.22180557], [72.94291687, 18.22180939], [72.94291687, 18.22014046], [72.94264221, 18.22014046], [72.94264221, 18.21986008], [72.94180298, 18.21986008], [72.94180298, 18.22014046], [72.94124603, 18.22014046], [72.94124603, 18.21986008], [72.94097137, 18.21986389], [72.94097137, 18.21958351], [72.9404068, 18.21959114], [72.9404068, 18.21931076], [72.9393158, 18.21931076], [72.9393158, 18.21903038], [72.93902588, 18.21903038], [72.93902588, 18.21820259], [72.9393158, 18.21820259], [72.9393158, 18.21681023], [72.93819427, 18.21680641], [72.93819427, 18.21708107], [72.93736267, 18.21708107], [72.93736267, 18.21680641], [72.93569183, 18.21680641], [72.93569183, 18.21708107], [72.93541718, 18.21708107], [72.93541718, 18.21736145], [72.93486023, 18.21736145], [72.93486023, 18.21764183], [72.93374634, 18.21764183], [72.93374634, 18.2179203], [72.93318939, 18.2179203], [72.93318939, 18.21820259], [72.93264008, 18.21819496], [72.93264008, 18.21846962], [72.93235779, 18.21846962], [72.93235779, 18.21875191], [72.93208313, 18.21875191], [72.93208313, 18.21903038], [72.93180847, 18.21903038], [72.93180847, 18.21931076], [72.93152618, 18.21930504], [72.93152618, 18.21986389], [72.93125153, 18.21986008], [72.93125153, 18.22042084], [72.93096924, 18.22041702], [72.93096924, 18.22064972], [72.93096924, 18.22125053], [72.93125153, 18.22125053], [72.93125153, 18.22153091], [72.93096924, 18.22153091], [72.93096924, 18.22375107], [72.93125153, 18.22375107], [72.93125153, 18.22402954], [72.93180847, 18.22402954], [72.93180847, 18.22430992], [72.93287659, 18.2243042], [72.93319702, 18.2243042], [72.93319702, 18.22458267], [72.93347168, 18.22458267], [72.93347168, 18.22543907], [72.93347168, 18.22597313], [72.93374634, 18.22597122], [72.93374634, 18.22653008], [72.93402863, 18.22653008], [72.93402863, 18.22763824], [72.93430328, 18.22763634], [72.93430328, 18.22847176], [72.9345932, 18.22846031], [72.9345932, 18.22903061], [72.93486023, 18.22903061], [72.93486023, 18.22930908], [72.93514252, 18.22930527], [72.93514252, 18.22958374], [72.93541718, 18.22957993], [72.93541718, 18.2298584], [72.93569183, 18.2298584], [72.93569183, 18.23014069], [72.93624878, 18.23014069], [72.93624878, 18.23041916], [72.93708038, 18.23041725], [72.93708038, 18.23069382], [72.93736267, 18.23069382], [72.93736267, 18.23097229], [72.93763733, 18.23096848], [72.93763733, 18.23264122], [72.93791962, 18.23264122], [72.93791962, 18.23291969], [72.93846893, 18.23291588], [72.93846893, 18.23319435], [72.93930817, 18.23319435], [72.93930817, 18.23291588], [72.93985748, 18.23291588], [72.93985748, 18.23319435], [72.94013977, 18.23319435], [72.94013977, 18.23347282], [72.94069672, 18.23347282], [72.94069672, 18.23374939], [72.94097137, 18.23374939], [72.94097137, 18.23402977], [72.94124603, 18.23402977], [72.94124603, 18.23459053], [72.94152832, 18.23458481], [72.94152832, 18.23736191], [72.94125366, 18.23736191], [72.94125366, 18.23847198], [72.94097137, 18.23847008], [72.94097137, 18.23875046], [72.94069672, 18.23875046], [72.94069672, 18.23903084], [72.9404068, 18.23903084], [72.9404068, 18.23986053], [72.94013977, 18.23986053], [72.94013977, 18.2420826], [72.93985748, 18.2420826], [72.93985748, 18.24319458], [72.94041443, 18.24319458], [72.94041443, 18.24347305], [72.94069672, 18.24346924], [72.94069672, 18.24375153], [72.94097137, 18.24375153], [72.94097137, 18.24430466], [72.94124603, 18.24430084], [72.94124603, 18.24514008], [72.94097137, 18.24514008], [72.94097137, 18.24542046], [72.94152832, 18.24542046], [72.94152832, 18.24570274], [72.94180298, 18.24569511], [72.94180298, 18.24597359], [72.94208527, 18.24597359], [72.94208527, 18.24625015], [72.94235992, 18.24625015], [72.94235992, 18.24682045], [72.94264221, 18.24682045], [72.94264221, 18.24792099], [72.94235992, 18.24791718], [72.94235992, 18.24847221], [72.9420929, 18.24847031], [72.9420929, 18.24903107], [72.94180298, 18.24903107], [72.94180298, 18.24930954], [72.94152832, 18.24930954], [72.94152832, 18.24986076], [72.9420929, 18.24986076], [72.9420929, 18.25014114], [72.94235992, 18.25014114], [72.94235992, 18.25181007], [72.94208527, 18.25180435], [72.94208527, 18.25208282], [72.94180298, 18.25208282], [72.94180298, 18.2523613], [72.94152832, 18.2523613], [72.94152832, 18.25347137], [72.94180298, 18.25346947], [72.94180298, 18.2551384], [72.94152832, 18.2551384], [72.94152832, 18.25542068], [72.94125366, 18.25541878], [72.94125366, 18.25597191], [72.94097137, 18.25596809], [72.94097137, 18.25680923], [72.94069672, 18.25680923], [72.94069672, 18.25735855], [72.9404068, 18.25735855], [72.9404068, 18.25792122], [72.94013977, 18.2579174], [72.94013977, 18.25847244], [72.93985748, 18.25847244], [72.93985748, 18.25902939], [72.93958282, 18.25902939], [72.93958282, 18.2598629], [72.93930817, 18.2598629], [72.93930817, 18.2606945], [72.93958282, 18.2606945], [72.93958282, 18.26097488], [72.93985748, 18.26097107], [72.93985748, 18.26264], [72.93958282, 18.26264], [72.93958282, 18.26431084], [72.93930817, 18.26430511], [72.93930817, 18.26458359], [72.93902588, 18.26458359], [72.93902588, 18.26486206], [72.93875122, 18.26486015], [72.93875122, 18.26542091], [72.93846893, 18.26541519], [72.93846893, 18.26597214], [72.93818665, 18.26597023], [72.93818665, 18.26625061], [72.93791962, 18.26625061], [72.93791962, 18.26653099], [72.93763733, 18.26653099], [72.93763733, 18.26902962], [72.93736267, 18.26902962], [72.93736267, 18.26958275], [72.93708038, 18.26958084], [72.93708038, 18.26985931], [72.93680573, 18.26985931], [72.93681335, 18.2701416], [72.93653107, 18.2701416], [72.93653107, 18.27042007], [72.93624878, 18.27042007], [72.93624878, 18.27070045], [72.93597412, 18.27069473], [72.93597412, 18.27096939], [72.93569183, 18.27096939], [72.93569183, 18.27123833], [72.93514252, 18.27125168], [72.93514252, 18.27153015], [72.93486023, 18.27152824], [72.93486023, 18.27180481], [72.9345932, 18.27179909], [72.9345932, 18.27292061], [72.93486023, 18.27291679], [72.93486023, 18.27347374], [72.93514252, 18.27347183], [72.93514252, 18.27375984], [72.93541718, 18.27375984], [72.93541718, 18.27403069], [72.93569183, 18.27403069], [72.93569183, 18.27431107], [72.93597412, 18.27430534], [72.93597412, 18.27458382], [72.93611908, 18.27458382], [72.93653107, 18.27458191], [72.93653107, 18.27486038], [72.93708038, 18.27486038], [72.93708038, 18.27514076], [72.93736267, 18.27513885], [72.93736267, 18.2756958], [72.93708038, 18.2756958], [72.93708038, 18.27597237], [72.93680573, 18.27597237], [72.93681335, 18.27625084], [72.93653107, 18.27625084], [72.93653107, 18.27653122], [72.93636322, 18.27652931], [72.93624878, 18.27653122], [72.93624878, 18.27874947], [72.93596649, 18.27874947], [72.93596649, 18.27902985], [72.93569183, 18.27902985], [72.93569183, 18.27931023], [72.93541718, 18.27930641], [72.93541718, 18.27986145], [72.93514252, 18.27986145], [72.93514252, 18.28097153], [72.93541718, 18.28096962], [72.93541718, 18.28153038], [72.93569183, 18.28153038], [72.93569183, 18.28181076], [72.93597412, 18.28180504], [72.93597412, 18.28208351], [72.93624878, 18.28208351], [72.93624878, 18.28236008], [72.93653107, 18.28235817], [72.93653107, 18.28264046], [72.93680573, 18.28264046], [72.93680573, 18.28319359], [72.93708038, 18.28319359], [72.93708038, 18.28347015], [72.93736267, 18.28346825], [72.93736267, 18.28374863], [72.93791962, 18.28374863], [72.93791962, 18.28403091], [72.93818665, 18.28403091], [72.93818665, 18.28430939], [72.93875122, 18.28430557], [72.93875122, 18.28458405], [72.93902588, 18.28458405], [72.93902588, 18.28430557], [72.93958282, 18.28430939], [72.93958282, 18.28403091], [72.94013977, 18.28403091], [72.94013977, 18.28430939], [72.94069672, 18.28430939], [72.94069672, 18.28486252], [72.94097137, 18.28486252], [72.94097137, 18.2851429], [72.94152832, 18.2851429], [72.94152832, 18.28541946], [72.9420929, 18.28541946], [72.9420929, 18.2851429], [72.94458008, 18.2851429], [72.94458008, 18.28486252], [72.94596863, 18.28486252], [72.94596863, 18.2851429], [72.9465332, 18.2851429], [72.9465332, 18.28541946], [72.94790649, 18.28541946], [72.94790649, 18.2851429], [72.94847107, 18.2851429], [72.94847107, 18.28486252], [72.94902802, 18.28486252], [72.94902802, 18.28457832], [72.94958496, 18.28458405], [72.94958496, 18.28430557], [72.95014191, 18.28430939], [72.95014191, 18.28403091], [72.95069122, 18.28403091], [72.95069122, 18.28346825], [72.95097351, 18.28347015], [72.95097351, 18.28291893], [72.9512558, 18.28293037], [72.9512558, 18.28256989], [72.95124817, 18.28153038], [72.95096588, 18.28153038], [72.95096588, 18.28013992], [72.9512558, 18.28013992], [72.9512558, 18.27985954], [72.95180511, 18.27986145], [72.95180511, 18.27958298], [72.95291901, 18.27958298], [72.95291901, 18.27930641], [72.95318604, 18.27931023], [72.95318604, 18.27902985], [72.95347595, 18.27902985], [72.95347595, 18.27874947], [72.95375061, 18.27874947], [72.95375061, 18.27819061], [72.95458221, 18.27819443], [72.95458221, 18.27791405], [72.95513916, 18.27791977], [72.95513916, 18.27763939], [72.95625305, 18.27763939], [72.95625305, 18.27791977], [72.95708466, 18.27791405], [72.95708466, 18.27819443], [72.95735931, 18.27819443], [72.95735931, 18.2784729], [72.95847321, 18.27847099], [72.95847321, 18.27902985], [72.95903015, 18.27902985], [72.95903015, 18.27931023], [72.95930481, 18.27930641], [72.95930481, 18.27986145], [72.9595871, 18.27985954], [72.9595871, 18.28013992], [72.96012878, 18.28013992], [72.96012878, 18.2804203], [72.96125031, 18.2804203], [72.96125031, 18.28070068], [72.962677, 18.28069878], [72.9631958, 18.28070068], [72.9631958, 18.2804203], [72.96375275, 18.2804203], [72.96375275, 18.28013992], [72.96457672, 18.28013992], [72.96457672, 18.27985954], [72.96485901, 18.27986145], [72.96485901, 18.27958298], [72.96541595, 18.27958298], [72.96541595, 18.27930641], [72.96569061, 18.27931023], [72.96569824, 18.27902985], [72.9659729, 18.27902985], [72.9659729, 18.27874947], [72.96626282, 18.27874947], [72.96624756, 18.2784729], [72.96652985, 18.2784729], [72.96652985, 18.27791405], [72.96679688, 18.27791977], [72.96679688, 18.27680016], [72.96652985, 18.27680588], [72.96652985, 18.27629089], [72.96652985, 18.27597237], [72.9668045, 18.27597237], [72.9668045, 18.27541733], [72.96708679, 18.27542114], [72.96708679, 18.27514076], [72.96819305, 18.27514076], [72.96819305, 18.27486038], [72.96875, 18.27486038], [72.96875, 18.27458191], [72.96930695, 18.27458382], [72.96930695, 18.27430534], [72.9695816, 18.27431107], [72.9695816, 18.27236176], [72.96986389, 18.27236176], [72.96986389, 18.27208328], [72.97041321, 18.27208328], [72.97041321, 18.27125168], [72.97070313, 18.27125168], [72.9706955, 18.26930618], [72.97041321, 18.26930809], [72.97041321, 18.26902962], [72.96985626, 18.26902962], [72.96985626, 18.26874924], [72.9695816, 18.26874924], [72.9695816, 18.26791954], [72.96985626, 18.26791954], [72.96985626, 18.26762962], [72.97013855, 18.26763725], [72.97013855, 18.26652527], [72.97041321, 18.26653099], [72.97041321, 18.26514053], [72.97013855, 18.26514053], [72.97013855, 18.26457024], [72.96986389, 18.26458359], [72.96986389, 18.26430511], [72.97070313, 18.26431084], [72.97070313, 18.26403046], [72.97125244, 18.26403046], [72.97125244, 18.26375008], [72.9715271, 18.26375008], [72.9715271, 18.2634697], [72.97374725, 18.2634716], [72.97374725, 18.26291656], [72.97402954, 18.26292038], [72.97402954, 18.26235962], [72.97374725, 18.26236153], [72.97374725, 18.26208305], [72.9734726, 18.26208305], [72.9734726, 18.26152802], [72.97319794, 18.26152992], [72.97319794, 18.26124954], [72.97291565, 18.26124954], [72.97291565, 18.26097488], [72.97264099, 18.26097488], [72.97264099, 18.2606945], [72.97208405, 18.2606945], [72.97208405, 18.26041603], [72.97180176, 18.26041985], [72.97180176, 18.26013947], [72.97125244, 18.26013947], [72.97125244, 18.25707817], [72.9715271, 18.25708389], [72.9715271, 18.25597191], [72.97180176, 18.25597191], [72.97180176, 18.2551384], [72.97206879, 18.2551384], [72.97206879, 18.25430107], [72.9723587, 18.25430489], [72.9723587, 18.25319481], [72.97264099, 18.25319481], [72.97264099, 18.25263977], [72.97291565, 18.25263977], [72.97291565, 18.25208282], [72.97319794, 18.25208282], [72.97319794, 18.25152779], [72.9734726, 18.25152969], [72.9734726, 18.25097084], [72.97374725, 18.25097275], [72.97374725, 18.2504158], [72.97402954, 18.25041962], [72.97402954, 18.24903107], [72.97374725, 18.24903107], [72.97374725, 18.24764061], [72.97402954, 18.24764061], [72.97402954, 18.24682045], [72.97429657, 18.24682045], [72.97429657, 18.24653053], [72.9751358, 18.24653053], [72.9751358, 18.24682045], [72.97598267, 18.24682045], [72.97598267, 18.24653053], [72.97651672, 18.24653053], [72.97651672, 18.24625015], [72.97735596, 18.24625015], [72.97735596, 18.24597168], [72.97819519, 18.24597359], [72.97819519, 18.24569511], [72.9798584, 18.24570274], [72.9798584, 18.24542046], [72.98042297, 18.24542046], [72.98042297, 18.2448616], [72.98069763, 18.2448616], [72.98069763, 18.24430466], [72.98097229, 18.24430466], [72.98097229, 18.24375153], [72.98123932, 18.24375153], [72.98123932, 18.24292183], [72.98152924, 18.24292183], [72.98152924, 18.24208069], [72.98236084, 18.24208069], [72.98236084, 18.24235916], [72.9826355, 18.24235916], [72.9826355, 18.24263763], [72.98291779, 18.24263763], [72.98291779, 18.24291611], [72.98319244, 18.24291611], [72.98319244, 18.24319458], [72.98430634, 18.24319458], [72.98430634, 18.24347305], [72.98486328, 18.24347305], [72.98486328, 18.24319458], [72.98652649, 18.24319458], [72.98652649, 18.24347305], [72.98791504, 18.24347305], [72.98791504, 18.24375153], [72.98847198, 18.24375153], [72.98847198, 18.24403191], [72.98930359, 18.24402809], [72.98930359, 18.24430466], [72.98986053, 18.24430466], [72.98986053, 18.24458313], [72.99041748, 18.24458313], [72.99041748, 18.2448616], [72.99069214, 18.2448616], [72.99069214, 18.24514008], [72.99124908, 18.24514008], [72.99124908, 18.24542046], [72.99153137, 18.24542046], [72.99153137, 18.24570274], [72.99180603, 18.24569511], [72.99180603, 18.24597359], [72.99263763, 18.24597168], [72.99263763, 18.24625015], [72.99317932, 18.24625015], [72.99317932, 18.24597168], [72.99402618, 18.24597359], [72.99402618, 18.24569511], [72.99458313, 18.24570274], [72.99458313, 18.24542046], [72.9954071, 18.24542046], [72.9954071, 18.24514008], [72.99623871, 18.24514008], [72.99623871, 18.2448616], [72.99764252, 18.2448616], [72.99764252, 18.24514008], [72.99791718, 18.24514008], [72.99791718, 18.24764061], [72.99819183, 18.24764061], [72.99819183, 18.24792099], [72.99847412, 18.24791718], [72.99847412, 18.24819374], [72.99874878, 18.24819374], [72.99874878, 18.24847221], [72.99993896, 18.24847221], [73.00041962, 18.24847221], [73.00041962, 18.24819374], [73.00096893, 18.24819374], [73.00096893, 18.24791718], [73.00152588, 18.24792099], [73.00152588, 18.24764061], [73.00180817, 18.24764061], [73.00180817, 18.24736023], [73.00208282, 18.24736023], [73.00208282, 18.24707985], [73.00235748, 18.24708366], [73.00235748, 18.24652863], [73.00263977, 18.24653053], [73.00263977, 18.24625015], [73.00430298, 18.24625015], [73.00430298, 18.24597168], [73.00458527, 18.24597359], [73.00458527, 18.24569511], [73.00485992, 18.24570274], [73.00485992, 18.24542046], [73.00514221, 18.24542046], [73.00514221, 18.24514008], [73.00540924, 18.24514008], [73.00540924, 18.2448616], [73.00763702, 18.2448616], [73.00763702, 18.24514008], [73.00875092, 18.24514008], [73.00875092, 18.2448616], [73.01041412, 18.2448616], [73.01041412, 18.24458313], [73.01097107, 18.24458313], [73.01097107, 18.24430466], [73.01125336, 18.24430466], [73.01125336, 18.24402809], [73.01152802, 18.24403191], [73.01152802, 18.24346924], [73.01180267, 18.24347305], [73.01180267, 18.24319458], [73.01208496, 18.24319458], [73.01208496, 18.24291611], [73.01235962, 18.24292183], [73.01235962, 18.24235916], [73.01249695, 18.24235916], [73.01264191, 18.24235916], [73.01264191, 18.24208069], [73.01319122, 18.24208069], [73.01319122, 18.24235916], [73.01364899, 18.24235916], [73.01457977, 18.24235916], [73.01457977, 18.24263763], [73.01541901, 18.24263763], [73.01541901, 18.24308968], [73.01541901, 18.24319458], [73.01569366, 18.24319458], [73.01569366, 18.24347305], [73.01541901, 18.24346924], [73.01541901, 18.24403191], [73.01569366, 18.24402809], [73.01569366, 18.24430466], [73.01597595, 18.24430466], [73.01597595, 18.24458313], [73.01625061, 18.24458313], [73.01625061, 18.2448616], [73.0165329, 18.2448616], [73.0165329, 18.24514008], [73.01680756, 18.24514008], [73.01680756, 18.24542046], [73.01708221, 18.24542046], [73.01708221, 18.24570274], [73.01790619, 18.24570274], [73.01790619, 18.24457932], [73.01819611, 18.24458313], [73.01819611, 18.24378967], [73.01819611, 18.24347305], [73.01847076, 18.24347305], [73.01847076, 18.24291611], [73.01875305, 18.24292183], [73.01875305, 18.24263763], [73.01930237, 18.24263763], [73.01930237, 18.24208069], [73.01958466, 18.2420826], [73.01958466, 18.24152756], [73.0201416, 18.24152756], [73.0201416, 18.24124908], [73.02040863, 18.24124908], [73.02040863, 18.24152756], [73.02124786, 18.24152756], [73.02124786, 18.24180984], [73.02153015, 18.24180984], [73.02153015, 18.24152756], [73.02179718, 18.24152756], [73.02179718, 18.24097061], [73.02236176, 18.24097252], [73.02236176, 18.24069405], [73.02263641, 18.24069405], [73.02263641, 18.24097252], [73.0229187, 18.24097252], [73.0229187, 18.24069405], [73.02347565, 18.24069405], [73.02347565, 18.24097252], [73.02513885, 18.24097252], [73.02513885, 18.24069405], [73.02625275, 18.24069405], [73.02625275, 18.24041939], [73.02680206, 18.24041939], [73.02680206, 18.24069405], [73.02700043, 18.24069405], [73.02735901, 18.24069405], [73.02735901, 18.24041939], [73.02819061, 18.24041939], [73.02819824, 18.24014091], [73.02874756, 18.24014091], [73.02874756, 18.23986053], [73.02928925, 18.23986053], [73.02928925, 18.23958015], [73.03013611, 18.23958397], [73.03013611, 18.2393055], [73.03069305, 18.23931122], [73.03069305, 18.23903084], [73.03125, 18.23903084], [73.03125, 18.23875046], [73.03151703, 18.23875046], [73.03151703, 18.23847008], [73.03180695, 18.23847198], [73.03180695, 18.23819351], [73.03263855, 18.23819351], [73.03263855, 18.23791695], [73.03320313, 18.23792076], [73.03320313, 18.23764992], [73.03347015, 18.23764992], [73.03347015, 18.23736], [73.0340271, 18.23736191], [73.0340271, 18.23708344], [73.0348587, 18.23708344], [73.0348587, 18.23680305], [73.03542328, 18.23681068], [73.03542328, 18.23624992], [73.0359726, 18.23624992], [73.0359726, 18.23596954], [73.03624725, 18.23597145], [73.03624725, 18.23541641], [73.03652954, 18.23542023], [73.03652954, 18.23485947], [73.03848267, 18.23485947], [73.03848267, 18.23542023], [73.03902435, 18.23541641], [73.03902435, 18.23569489], [73.04096985, 18.23569489], [73.04096985, 18.23541641], [73.04180908, 18.23542023], [73.04180908, 18.23513985], [73.0423584, 18.23513985], [73.0423584, 18.23485947], [73.04291534, 18.23486137], [73.04291534, 18.23458481], [73.04402924, 18.23459053], [73.04402924, 18.23431015], [73.04428864, 18.23431015], [73.04428864, 18.23402977], [73.04486084, 18.23402977], [73.04486084, 18.23374939], [73.04514313, 18.23374939], [73.04514313, 18.23402977], [73.04569244, 18.23402977], [73.04569244, 18.23374939], [73.04624939, 18.23374939], [73.04624939, 18.23347282], [73.04680634, 18.23347282], [73.04680634, 18.23319435], [73.04736328, 18.23319435], [73.04736328, 18.23291588], [73.04875183, 18.23291969], [73.04875183, 18.23208046], [73.04902649, 18.23208046], [73.04902649, 18.23152733], [73.04930878, 18.23153114], [73.04930878, 18.23125267], [73.04902649, 18.23125267], [73.04902649, 18.2306881], [73.04875183, 18.23069382], [73.04875183, 18.23041725], [73.04902649, 18.23041916], [73.04902649, 18.23014069], [73.04930878, 18.23014069], [73.04930878, 18.2298584], [73.04957581, 18.2298584], [73.04957581, 18.23014069], [73.04985809, 18.23014069], [73.04985809, 18.23041916], [73.05014038, 18.23041725], [73.05014038, 18.23069382], [73.05041504, 18.23069382], [73.05041504, 18.23097229], [73.05069733, 18.23097229], [73.05069733, 18.23125267], [73.05097198, 18.23125267], [73.05097198, 18.23180962], [73.05124664, 18.2318058], [73.05124664, 18.23208046], [73.05180359, 18.23208046], [73.05180359, 18.2318058], [73.05291748, 18.23180962], [73.05291748, 18.23153114], [73.05319214, 18.23153114], [73.05319214, 18.23125267], [73.05374908, 18.23125267], [73.05374908, 18.23096848], [73.05486298, 18.23097229], [73.05486298, 18.23069382], [73.05513763, 18.23069382], [73.05513763, 18.23041725], [73.05625153, 18.23041916], [73.05625153, 18.23014069], [73.05708313, 18.23014069], [73.05708313, 18.2298584], [73.0579071, 18.2298584], [73.0579071, 18.22957993], [73.05847168, 18.22958374], [73.05847168, 18.22930527], [73.05902863, 18.22930908], [73.05902863, 18.22903061], [73.05930328, 18.22903061], [73.05930328, 18.22874832], [73.06014252, 18.22874832], [73.06014252, 18.22846031], [73.06069183, 18.22847176], [73.06069183, 18.22819519], [73.06124878, 18.22820091], [73.06124878, 18.22792053], [73.06181335, 18.22792053], [73.06181335, 18.22763824], [73.06208038, 18.22763824], [73.06208038, 18.22735977], [73.06291962, 18.22736168], [73.06291962, 18.22708321], [73.06375122, 18.22708321], [73.06375122, 18.22680473], [73.06402588, 18.22680473], [73.06402588, 18.22652626], [73.06430817, 18.22653008], [73.06430817, 18.22624969], [73.06458282, 18.22624969], [73.06458282, 18.22597122], [73.06513977, 18.22597313], [73.06513977, 18.22569466], [73.06541443, 18.22569466], [73.06541443, 18.22541618], [73.06571198, 18.22542], [73.06571198, 18.22513962], [73.06625366, 18.22513962], [73.06624603, 18.22458076], [73.06652832, 18.22458267], [73.06652832, 18.2243042], [73.06680298, 18.22430992], [73.06680298, 18.22402954], [73.06735992, 18.22402954], [73.06735992, 18.22347069], [73.06791687, 18.2234726], [73.06791687, 18.22319412], [73.06819153, 18.22319412], [73.06819153, 18.22291756], [73.06845856, 18.22291946], [73.06845856, 18.22236061], [73.06903076, 18.22236061], [73.06903076, 18.22208023], [73.06930542, 18.22208214], [73.06930542, 18.22125053], [73.06958008, 18.22125053], [73.06958008, 18.22097015], [73.06986237, 18.22097206], [73.06986237, 18.21930504], [73.07013702, 18.21931076], [73.07013702, 18.21569061], [73.07041931, 18.21569443], [73.07041931, 18.21097183], [73.07069397, 18.21097183], [73.07069397, 18.20986176], [73.07096863, 18.20986176], [73.07096863, 18.20930481], [73.07069397, 18.20930481], [73.07069397, 18.20819473], [73.07041931, 18.20819473], [73.07041931, 18.20763969], [73.07068634, 18.20763969], [73.07068634, 18.20736122], [73.07041931, 18.20736122], [73.07041931, 18.20681], [73.07013702, 18.20681], [73.07013702, 18.20597267], [73.06986237, 18.20597267], [73.06986237, 18.2056942], [73.06958008, 18.2056942], [73.06958008, 18.20541763], [73.06931305, 18.20541954], [73.06931305, 18.20514107], [73.06874847, 18.20514107], [73.06874847, 18.20486259], [73.06845856, 18.20486259], [73.06845856, 18.20458031], [73.06791687, 18.20458412], [73.06791687, 18.20430565], [73.06764221, 18.20430946], [73.06764221, 18.20402908], [73.0670929, 18.20402908], [73.0670929, 18.20375061], [73.06680298, 18.20375061], [73.06680298, 18.20346832], [73.06625366, 18.20347023], [73.06625366, 18.20319366], [73.06597137, 18.20319366], [73.06597137, 18.2029171], [73.06491852, 18.20292091], [73.06485748, 18.20264053], [73.06430817, 18.20264053], [73.06430817, 18.20235825], [73.06402588, 18.20236206], [73.06402588, 18.20208359], [73.06346893, 18.20208359], [73.06346893, 18.20180511], [73.06291962, 18.20181084], [73.06291962, 18.20152092], [73.06153107, 18.20153046], [73.06153107, 18.20124817], [73.06069183, 18.20124817], [73.06069183, 18.2009697], [73.06014252, 18.2009716], [73.06014252, 18.20069695], [73.05986023, 18.20070076], [73.05986023, 18.20042038], [73.05957794, 18.20042038], [73.05957794, 18.20013809], [73.05930328, 18.20013809], [73.05930328, 18.19985962], [73.05874634, 18.19986153], [73.05874634, 18.19958305], [73.05819702, 18.19958305], [73.05819702, 18.19902611], [73.05764008, 18.19902992], [73.05764008, 18.19819069], [73.05735779, 18.1981945], [73.05735779, 18.19791412], [73.05708313, 18.19791985], [73.05708313, 18.19736099], [73.05680847, 18.19736099], [73.05680847, 18.19680977], [73.05651855, 18.19680977], [73.05651855, 18.19652939], [73.05625153, 18.19652939], [73.05625153, 18.19597054], [73.05596924, 18.19597244], [73.05596924, 18.1954174], [73.05568695, 18.19542122], [73.05568695, 18.19514084], [73.05541992, 18.19514084], [73.05541992, 18.19431114], [73.05513763, 18.19431114], [73.05513763, 18.19403076], [73.05541992, 18.19403076], [73.05541992, 18.19347191], [73.05513763, 18.19347382], [73.05513763, 18.19069481], [73.05541992, 18.19069481], [73.05541992, 18.19014168], [73.05513763, 18.19014168], [73.05513763, 18.18985939], [73.05541992, 18.18985939], [73.05541992, 18.18819427], [73.05569458, 18.18819427], [73.05569458, 18.1870842], [73.05596924, 18.1870842], [73.05596924, 18.18625069], [73.05625153, 18.18625069], [73.05625153, 18.18568993], [73.05652618, 18.18569374], [73.05652618, 18.18541527], [73.05680847, 18.18542099], [73.05680847, 18.18514061], [73.05708313, 18.18514061], [73.05708313, 18.18457985], [73.05764008, 18.18458366], [73.05764008, 18.18402863], [73.0579071, 18.18403053], [73.0579071, 18.18348122], [73.05847168, 18.18348122], [73.05847168, 18.18292046], [73.05874634, 18.18292046], [73.05874634, 18.18264008], [73.05930328, 18.18264008], [73.05930328, 18.1823597], [73.05958557, 18.1823616], [73.05958557, 18.18208313], [73.05986023, 18.18208313], [73.05986023, 18.18180466], [73.06014252, 18.18180466], [73.06014252, 18.18152809], [73.06069183, 18.18153], [73.06069183, 18.18097115], [73.06124878, 18.18097305], [73.06124878, 18.18041611], [73.06153107, 18.18041611], [73.06153107, 18.18013954], [73.06181335, 18.18013954], [73.06180573, 18.17986107], [73.06208038, 18.17986107], [73.06208038, 18.17930984], [73.06236267, 18.17930984], [73.06236267, 18.17902946], [73.06291962, 18.17902946], [73.06291962, 18.1787529], [73.06346893, 18.1787529], [73.06346893, 18.17847252], [73.06387329, 18.17847252], [73.06402588, 18.17847252], [73.06402588, 18.17819405], [73.06458282, 18.17819405], [73.06458282, 18.17748833], [73.06458282, 18.17735863], [73.06485748, 18.17735863], [73.06485748, 18.17708397], [73.06513977, 18.17708397], [73.06513977, 18.1768055], [73.06571198, 18.17680931], [73.06571198, 18.17653084], [73.06597137, 18.17653084], [73.06597137, 18.17624855], [73.06652832, 18.17624855], [73.06652832, 18.17596817], [73.06708527, 18.17597008], [73.06708527, 18.17569351], [73.06735992, 18.17569351], [73.06735992, 18.17541885], [73.06764221, 18.17542076], [73.06764221, 18.17514038], [73.06819153, 18.17514038], [73.06819153, 18.17485809], [73.06847382, 18.17486191], [73.06847382, 18.17458344], [73.06874847, 18.17458344], [73.06874847, 18.17430496], [73.06903076, 18.17430496], [73.06903076, 18.17458344], [73.06958008, 18.17458344], [73.06958008, 18.17430496], [73.06986237, 18.17431068], [73.06986237, 18.1740303], [73.07013702, 18.1740303], [73.07013702, 18.17346954], [73.07041931, 18.17347145], [73.07041931, 18.17291641], [73.07096863, 18.17292023], [73.07096863, 18.17235947], [73.07152557, 18.17236137], [73.07152557, 18.17152786], [73.07180786, 18.17154121], [73.07180786, 18.17069054], [73.07208252, 18.17069435], [73.07208252, 18.17041588], [73.07180786, 18.17041969], [73.07180786, 18.17014122], [73.07125092, 18.17014122], [73.07125092, 18.16958046], [73.07096863, 18.16958427], [73.07096863, 18.1693058], [73.07068634, 18.16930962], [73.07068634, 18.16903114], [73.07041931, 18.16903114], [73.07041931, 18.16847038], [73.07013702, 18.16847229], [73.07013702, 18.16819382], [73.06986237, 18.16819382], [73.06986237, 18.16763878], [73.06958008, 18.16764069], [73.06958008, 18.16708183], [73.06930542, 18.16708374], [73.06930542, 18.16680527], [73.06903076, 18.1668129], [73.06903076, 18.16570282], [73.06874847, 18.16570282], [73.06874847, 18.16540909], [73.06903076, 18.16541672], [73.06903076, 18.16513824], [73.06930542, 18.16513824], [73.06930542, 18.16597366], [73.06958008, 18.16597176], [73.06958008, 18.16625023], [73.06986237, 18.16625023], [73.06986237, 18.1668129], [73.07013702, 18.16680527], [73.07013702, 18.16708374], [73.07041931, 18.16708183], [73.07041931, 18.16736031], [73.07068634, 18.16736031], [73.07068634, 18.16792107], [73.07096863, 18.16791725], [73.07096863, 18.16819382], [73.07125092, 18.16819382], [73.07125092, 18.16847229], [73.07138824, 18.16847038], [73.07151794, 18.16847038], [73.07151794, 18.16903114], [73.07180786, 18.16902733], [73.07180786, 18.16958237], [73.07208252, 18.16958046], [73.07208252, 18.16986084], [73.07319641, 18.16986084], [73.07319641, 18.16958046], [73.07347107, 18.16958237], [73.07347107, 18.1693058], [73.07375336, 18.16930962], [73.07375336, 18.16875076], [73.07402802, 18.16875076], [73.07402802, 18.16818047], [73.07430267, 18.16819382], [73.07430267, 18.16763878], [73.07485962, 18.16764069], [73.07485962, 18.16708183], [73.07514191, 18.16708374], [73.07514191, 18.16680527], [73.07541656, 18.1668129], [73.07541656, 18.16597176], [73.07569122, 18.16597366], [73.07569122, 18.16569519], [73.07596588, 18.16570282], [73.07596588, 18.16540909], [73.07653046, 18.16541672], [73.07653046, 18.16513824], [73.07681274, 18.16514015], [73.07681274, 18.16486168], [73.07707977, 18.16486168], [73.07707977, 18.1637516], [73.07680511, 18.1637516], [73.07680511, 18.16263771], [73.07653046, 18.16263771], [73.07653046, 18.16180992], [73.07624817, 18.16180992], [73.07624817, 18.16097069], [73.07597351, 18.1609726], [73.07597351, 18.1608696], [73.07597351, 18.16069412], [73.07569122, 18.16069412], [73.07569122, 18.16041946], [73.07541656, 18.16041946], [73.07541656, 18.16014099], [73.07514191, 18.16014099], [73.07514191, 18.15986061], [73.07485962, 18.15986061], [73.07485962, 18.15958023], [73.07458496, 18.15958405], [73.07458496, 18.15930557], [73.07402802, 18.15930939], [73.07402802, 18.15903091], [73.07375336, 18.15903091], [73.07375336, 18.15847015], [73.07347107, 18.15847206], [73.07347107, 18.15763855], [73.07319641, 18.15764046], [73.07319641, 18.15736008], [73.07291412, 18.15736198], [73.07291412, 18.15680313], [73.07263947, 18.15681076], [73.07263947, 18.15653038], [73.07319641, 18.15653038], [73.07319641, 18.15681076], [73.07347107, 18.15680313], [73.07347107, 18.15708351], [73.07375336, 18.15708351], [73.07375336, 18.15736198], [73.07402802, 18.15736008], [73.07402802, 18.15764046], [73.07430267, 18.15764046], [73.07430267, 18.15792084], [73.07458496, 18.15791512], [73.07458496, 18.15847206], [73.07485962, 18.15847015], [73.07485962, 18.15903091], [73.07514191, 18.15903091], [73.07514191, 18.15930939], [73.07541656, 18.15930557], [73.07541656, 18.15958405], [73.07596588, 18.15958023], [73.07596588, 18.15986061], [73.07656097, 18.15986061], [73.07707977, 18.15986061], [73.07707977, 18.16014099], [73.07736206, 18.16013718], [73.07736206, 18.16069412], [73.07765198, 18.16069031], [73.07765198, 18.16152954], [73.07791901, 18.16152954], [73.07791901, 18.16208267], [73.07818604, 18.16208076], [73.07818604, 18.16237068], [73.07930756, 18.16237068], [73.07930756, 18.16208076], [73.0798645, 18.16208267], [73.0798645, 18.16180611], [73.08039856, 18.16180992], [73.08039856, 18.16152954], [73.08068848, 18.16152954], [73.08068848, 18.16069031], [73.08097076, 18.16069412], [73.08097076, 18.15986061], [73.08125305, 18.15986061], [73.08125305, 18.15903091], [73.08152771, 18.15903091], [73.08152771, 18.15818977], [73.08125305, 18.15819359], [73.08125305, 18.15652847], [73.08152771, 18.15653038], [73.08152771, 18.15624046], [73.08180237, 18.15624046], [73.08180237, 18.15653038], [73.08208466, 18.15652847], [73.08208466, 18.15736198], [73.08235931, 18.15736008], [73.08235931, 18.15764046], [73.08319092, 18.15764046], [73.08319092, 18.15792084], [73.08403015, 18.15792084], [73.08403015, 18.15736008], [73.08430481, 18.15736198], [73.08430481, 18.15680313], [73.08513641, 18.15681076], [73.08513641, 18.15653038], [73.0854187, 18.15653038], [73.0854187, 18.15596962], [73.08569336, 18.15597153], [73.08569336, 18.15541649], [73.08598328, 18.1554203], [73.08598328, 18.15485954], [73.08625031, 18.15486145], [73.08625031, 18.15402794], [73.08653259, 18.15402985], [73.08653259, 18.15263939], [73.08625031, 18.15263939], [73.08625031, 18.15134048], [73.08625031, 18.15069389], [73.08652496, 18.15069389], [73.08652496, 18.15041733], [73.08708191, 18.15041733], [73.08708191, 18.15069389], [73.0873642, 18.15069389], [73.0873642, 18.15082932], [73.0873642, 18.15097237], [73.08763885, 18.15096855], [73.08763885, 18.15125275], [73.08790588, 18.15125275], [73.08790588, 18.15153122], [73.0881958, 18.1515274], [73.0881958, 18.15208244], [73.08790588, 18.15208244], [73.08790588, 18.1554203], [73.08763885, 18.1554203], [73.08763885, 18.15570068], [73.0873642, 18.15569305], [73.0873642, 18.15625], [73.08708191, 18.15625], [73.08708191, 18.15708351], [73.08682251, 18.1570797], [73.08682251, 18.15764046], [73.08708191, 18.15764046], [73.08708191, 18.15792084], [73.0873642, 18.15791512], [73.0873642, 18.15819359], [73.08708191, 18.15819359], [73.08708191, 18.15847206], [73.08625031, 18.15847015], [73.08625031, 18.15875053], [73.08569336, 18.15875053], [73.08569336, 18.15903091], [73.0854187, 18.15903091], [73.0854187, 18.15930939], [73.08513641, 18.15930557], [73.08513641, 18.15958405], [73.08486176, 18.15958023], [73.08486176, 18.15986061], [73.08429718, 18.15986061], [73.08429718, 18.16041946], [73.08403015, 18.16041946], [73.08403015, 18.16125107], [73.08374786, 18.16125107], [73.08374786, 18.16180992], [73.08430481, 18.16180611], [73.08430481, 18.16208267], [73.08486176, 18.16208076], [73.08486176, 18.16237068], [73.08513641, 18.16237068], [73.08513641, 18.16263771], [73.08625031, 18.16263771], [73.08625031, 18.16292191], [73.08680725, 18.16291618], [73.08680725, 18.16319466], [73.08708191, 18.16319466], [73.08708191, 18.16347313], [73.08763885, 18.16346931], [73.08763885, 18.1637516], [73.0881958, 18.1637516], [73.0881958, 18.16403008], [73.0890274, 18.16402817], [73.0890274, 18.16430473], [73.08930206, 18.16430473], [73.08930206, 18.16347313], [73.08958435, 18.16347313], [73.08958435, 18.16319466], [73.08985901, 18.16319466], [73.08985901, 18.16291618], [73.0901413, 18.16292191], [73.0901413, 18.16263771], [73.09041595, 18.16263771], [73.09041595, 18.16237068], [73.09124756, 18.16237068], [73.09124756, 18.16208076], [73.09179688, 18.16208076], [73.09179688, 18.16237068], [73.09208679, 18.16237068], [73.09208679, 18.16263771], [73.09236145, 18.16263771], [73.09236145, 18.16292191], [73.09263611, 18.16291618], [73.09263611, 18.16319466], [73.09236145, 18.16319466], [73.09236145, 18.16347313], [73.09208679, 18.16346931], [73.09208679, 18.16403008], [73.0918045, 18.16402817], [73.0918045, 18.16430473], [73.09152985, 18.16430473], [73.09152985, 18.16486168], [73.09124756, 18.16486168], [73.09124756, 18.16514015], [73.09069824, 18.16513824], [73.09069824, 18.16541672], [73.09041595, 18.16541672], [73.09041595, 18.16513824], [73.0901413, 18.16513824], [73.0901413, 18.16541672], [73.08985901, 18.16540909], [73.08985901, 18.16570282], [73.08958435, 18.16569519], [73.08958435, 18.16708374], [73.08985901, 18.16708183], [73.08985901, 18.16736031], [73.0901413, 18.16736031], [73.0901413, 18.16764069], [73.09069061, 18.16764069], [73.09069824, 18.16736031], [73.09124756, 18.16736031], [73.09124756, 18.16764069], [73.09152985, 18.16764069], [73.09152985, 18.16792107], [73.09124756, 18.16791725], [73.09124756, 18.16819382], [73.0909729, 18.16819382], [73.0909729, 18.16847229], [73.09069824, 18.16847038], [73.09069824, 18.16903114], [73.09041595, 18.16903114], [73.09041595, 18.16930962], [73.08985901, 18.1693058], [73.08985901, 18.16958427], [73.08958435, 18.16958427], [73.08959198, 18.16986084], [73.08875275, 18.16986084], [73.08875275, 18.17014122], [73.0881958, 18.17014122], [73.0881958, 18.17041969], [73.08791351, 18.17041588], [73.08791351, 18.17069435], [73.08763885, 18.17069435], [73.08763885, 18.17097282], [73.0873642, 18.17097282], [73.0873642, 18.17069435], [73.08708191, 18.17069435], [73.08708191, 18.17013931], [73.08682251, 18.17014122], [73.08682251, 18.16986084], [73.08597565, 18.16986084], [73.08597565, 18.16958427], [73.08569336, 18.16958046], [73.08569336, 18.16986084], [73.0854187, 18.16986084], [73.0854187, 18.16958046], [73.08513641, 18.16958046], [73.08513641, 18.16986084], [73.08403015, 18.16986084], [73.08403015, 18.17014122], [73.08374786, 18.17014122], [73.08374786, 18.16986084], [73.08319092, 18.16986084], [73.08319092, 18.17014122], [73.08291626, 18.17014122], [73.08291626, 18.17041969], [73.0826416, 18.17041588], [73.0826416, 18.17069435], [73.08235931, 18.17069435], [73.08235931, 18.17097282], [73.08207703, 18.17097092], [73.08207703, 18.17124939], [73.08180237, 18.17124939], [73.08180237, 18.17154121], [73.08125305, 18.17152786], [73.08125305, 18.1720829], [73.08097076, 18.17208099], [73.08097076, 18.17292023], [73.08068848, 18.17292023], [73.08068848, 18.1740303], [73.08097076, 18.1740303], [73.08097076, 18.17431068], [73.08069611, 18.17430496], [73.08069611, 18.17597008], [73.08039856, 18.17596817], [73.08039856, 18.17680931], [73.08013916, 18.1768055], [73.08013916, 18.17708397], [73.07985687, 18.17707825], [73.07985687, 18.17764282], [73.08013916, 18.17764282], [73.08013916, 18.17791939], [73.08041382, 18.17791748], [73.08041382, 18.17819405], [73.08068848, 18.17819023], [73.08068848, 18.17902946], [73.08039856, 18.17902946], [73.08039856, 18.17930984], [73.08013916, 18.17930984], [73.08013916, 18.17902946], [73.07985687, 18.17902946], [73.07985687, 18.1787529], [73.07624817, 18.1787529], [73.07624817, 18.17902946], [73.07596588, 18.17902946], [73.07596588, 18.17986107], [73.07569122, 18.17986107], [73.07569122, 18.18069458], [73.07541656, 18.18069458], [73.07541656, 18.18097305], [73.07514191, 18.18097305], [73.07514191, 18.18069458], [73.07485962, 18.18069458], [73.07485962, 18.17986107], [73.07375336, 18.17986107], [73.07375336, 18.18013954], [73.07347107, 18.18013954], [73.07347107, 18.18041611], [73.07236481, 18.18041611], [73.07236481, 18.18069458], [73.07180786, 18.18069458], [73.07180786, 18.18097305], [73.07151794, 18.18097115], [73.07151794, 18.18124962], [73.07096863, 18.18124962], [73.07096863, 18.18153], [73.07041931, 18.18152809], [73.07041931, 18.18180466], [73.06986237, 18.18180466], [73.06986237, 18.18208313], [73.06958008, 18.18208313], [73.06958008, 18.1823616], [73.06903076, 18.1823597], [73.06903076, 18.18264008], [73.06874847, 18.18264008], [73.06874847, 18.18292046], [73.06819153, 18.18292046], [73.06819153, 18.18320084], [73.06764221, 18.18320084], [73.06764221, 18.18348122], [73.06708527, 18.18347168], [73.0670929, 18.18375015], [73.06680298, 18.18375015], [73.06680298, 18.18431091], [73.06652832, 18.18430519], [73.06652832, 18.18458366], [73.06597137, 18.18457985], [73.06597137, 18.18486023], [73.06571198, 18.18486023], [73.06571198, 18.18514061], [73.06513977, 18.18514061], [73.06513977, 18.18542099], [73.06458282, 18.18541527], [73.06458282, 18.18569374], [73.06430817, 18.18569374], [73.06430817, 18.18597221], [73.06402588, 18.18597031], [73.06402588, 18.18625069], [73.06346893, 18.18625069], [73.06346893, 18.18680954], [73.06319427, 18.18680573], [73.06319427, 18.1870842], [73.06291962, 18.18708038], [73.06291962, 18.18736076], [73.06265259, 18.18736076], [73.06265259, 18.18764114], [73.06236267, 18.18764114], [73.06236267, 18.18791962], [73.06208038, 18.1879158], [73.06208038, 18.18819427], [73.06180573, 18.18819427], [73.06180573, 18.18847275], [73.06153107, 18.18847084], [73.06153107, 18.18875122], [73.06124878, 18.18875122], [73.06124878, 18.18902969], [73.06096649, 18.18902969], [73.06096649, 18.18930817], [73.06069183, 18.18930626], [73.06069183, 18.18958282], [73.06041718, 18.18958092], [73.06041718, 18.19014168], [73.06014252, 18.19014168], [73.06014252, 18.19042015], [73.05986023, 18.19041634], [73.05986023, 18.19069481], [73.05958557, 18.19069481], [73.05958557, 18.19347382], [73.05986023, 18.19347191], [73.05986023, 18.19375038], [73.06014252, 18.19375038], [73.06014252, 18.19486046], [73.06041718, 18.19486046], [73.06041718, 18.19514084], [73.06069183, 18.19513893], [73.06069183, 18.19569588], [73.06124878, 18.19569588], [73.06124878, 18.19597244], [73.06153107, 18.19597054], [73.06153107, 18.19625092], [73.06181335, 18.19625092], [73.06181335, 18.19652939], [73.06265259, 18.19652939], [73.06265259, 18.19680977], [73.06291962, 18.19680405], [73.06291962, 18.19708252], [73.06346893, 18.19708061], [73.06346893, 18.19736099], [73.06402588, 18.19736099], [73.06402588, 18.19763947], [73.06485748, 18.19763947], [73.06485748, 18.19791985], [73.06513977, 18.19791985], [73.06513977, 18.19763947], [73.06533051, 18.19763947], [73.06597137, 18.19763947], [73.06597137, 18.19791985], [73.06791687, 18.19791985], [73.06791687, 18.19763947], [73.06845856, 18.19763947], [73.06845856, 18.19736099], [73.06903076, 18.19736099], [73.06903076, 18.19708061], [73.06958008, 18.19708061], [73.06958008, 18.19736099], [73.07068634, 18.19736099], [73.07068634, 18.19763947], [73.07180786, 18.19763947], [73.07180786, 18.19791985], [73.07208252, 18.19791412], [73.07208252, 18.1981945], [73.07263947, 18.19819069], [73.07263947, 18.19848061], [73.07319641, 18.19848061], [73.07319641, 18.19874954], [73.07375336, 18.19874954], [73.07375336, 18.19902992], [73.07458496, 18.19902611], [73.07459259, 18.19930077], [73.07514191, 18.1993084], [73.07514191, 18.19986153], [73.07549286, 18.19985962], [73.07569122, 18.19985962], [73.07569122, 18.20070076], [73.07596588, 18.20070076], [73.07596588, 18.20181084], [73.07624817, 18.20181084], [73.07624817, 18.20235825], [73.07653046, 18.20235825], [73.07653046, 18.20402908], [73.07624817, 18.20402908], [73.07624817, 18.20430946], [73.07653046, 18.20430565], [73.07653046, 18.20458412], [73.07624817, 18.20458031], [73.07624817, 18.20763969], [73.07653046, 18.20763969], [73.07653046, 18.20874977], [73.07680511, 18.20874977], [73.07680511, 18.20930481], [73.07707977, 18.2093029], [73.07707977, 18.21014023], [73.07736206, 18.21014023], [73.07736206, 18.21071053], [73.07791901, 18.21071053], [73.07791901, 18.21153069], [73.07819366, 18.21152687], [73.07819366, 18.21208382], [73.07847595, 18.21208], [73.07847595, 18.21264076], [73.07875061, 18.21263885], [73.07875061, 18.21319389], [73.07902527, 18.21319389], [73.07902527, 18.21375084], [73.07930756, 18.21375084], [73.07930756, 18.21403122], [73.07958221, 18.2140274], [73.07958221, 18.21458244], [73.07985687, 18.21458054], [73.07985687, 18.21513748], [73.08013916, 18.21513748], [73.08013916, 18.21541977], [73.08069611, 18.21541595], [73.08069611, 18.21569443], [73.08097076, 18.21569061], [73.08097076, 18.21624756], [73.08069611, 18.21624756], [73.08069611, 18.21652985], [73.08039856, 18.21652031], [73.08039856, 18.21681023], [73.08013916, 18.21681023], [73.08013916, 18.2179203], [73.08039856, 18.2179203], [73.08039856, 18.21820259], [73.08068848, 18.21820259], [73.08068848, 18.22153091], [73.08039856, 18.22153091], [73.08039856, 18.22180939], [73.08013916, 18.22180939], [73.08013916, 18.22236061], [73.07985687, 18.22236061], [73.07985687, 18.22265053], [73.07930756, 18.22265053], [73.07930756, 18.22291946], [73.07902527, 18.22291756], [73.07902527, 18.22319412], [73.07875061, 18.22319031], [73.07875061, 18.22375107], [73.07847595, 18.22375107], [73.07847595, 18.22513962], [73.07875061, 18.22513962], [73.07875061, 18.22597313], [73.07958221, 18.22597122], [73.07958221, 18.22624969], [73.08039856, 18.22624969], [73.08039856, 18.22653008], [73.08069611, 18.22652626], [73.08069611, 18.22708321], [73.08041382, 18.22708321], [73.08041382, 18.22736168], [73.07985687, 18.22735977], [73.07985687, 18.22763824], [73.08013916, 18.22763634], [73.08013916, 18.22847176], [73.08041382, 18.22847176], [73.08041382, 18.22958374], [73.08068848, 18.22957993], [73.08068848, 18.23014069], [73.08039856, 18.23014069], [73.08039856, 18.23125267], [73.08013916, 18.23125267], [73.08013916, 18.23153114], [73.07985687, 18.23153114], [73.07985687, 18.23180962], [73.07958221, 18.2318058], [73.07958221, 18.23208427], [73.07875061, 18.23208046], [73.07875061, 18.23236275], [73.07818604, 18.23236275], [73.07818604, 18.23374939], [73.07847595, 18.23374939], [73.07847595, 18.23569489], [73.07819366, 18.23569489], [73.07819366, 18.23597145], [73.07791901, 18.23596954], [73.07791901, 18.23624992], [73.07736206, 18.23624992], [73.07736206, 18.23596954], [73.07707977, 18.23597145], [73.07707977, 18.23569489], [73.07653046, 18.23569489], [73.07653046, 18.23597145], [73.07624817, 18.23596954], [73.07624817, 18.23875046], [73.07596588, 18.23875046], [73.07596588, 18.23903084], [73.07485962, 18.23903084], [73.07485962, 18.23931122], [73.07375336, 18.2393055], [73.07375336, 18.23958397], [73.07290649, 18.23958015], [73.07290649, 18.23986053], [73.07180786, 18.23986053], [73.07180786, 18.24014091], [73.07152557, 18.2401371], [73.07152557, 18.24069405], [73.07125092, 18.24069405], [73.07125092, 18.24097252], [73.07041931, 18.24097061], [73.07041931, 18.24124908], [73.06986237, 18.24124908], [73.06986237, 18.24152756], [73.06958008, 18.24152756], [73.06958008, 18.24180984], [73.06903076, 18.24180794], [73.06903076, 18.2420826], [73.06845856, 18.24208069], [73.06845856, 18.24263763], [73.06819153, 18.24263763], [73.06819153, 18.24319458], [73.06791687, 18.24319077], [73.06791687, 18.24403191], [73.06764221, 18.24402809], [73.06764221, 18.24458313], [73.06735992, 18.24458313], [73.06735992, 18.2448616], [73.0670929, 18.2448616], [73.0670929, 18.24542046], [73.06652832, 18.24542046], [73.06652832, 18.24570274], [73.06624603, 18.24570274], [73.06625366, 18.24625015], [73.06571198, 18.24625015], [73.06571198, 18.24682045], [73.06541443, 18.24680519], [73.06541443, 18.24708366], [73.06485748, 18.24707985], [73.06485748, 18.24792099], [73.06458282, 18.24791718], [73.06458282, 18.24819374], [73.06402588, 18.24819374], [73.06402588, 18.24847221], [73.06346893, 18.24847031], [73.06346893, 18.24903107], [73.06318665, 18.24903107], [73.06318665, 18.24930954], [73.06291962, 18.24930954], [73.06291962, 18.24958992], [73.06263733, 18.2495842], [73.06265259, 18.24986076], [73.06208038, 18.24986076], [73.06208038, 18.25041962], [73.06180573, 18.2504158], [73.06180573, 18.25097275], [73.06153107, 18.25097275], [73.06153107, 18.2523613], [73.06124878, 18.2523613], [73.06124878, 18.25263977], [73.06153107, 18.25263977], [73.06153107, 18.25430489], [73.06181335, 18.25430107], [73.06181335, 18.25680923], [73.06208038, 18.25680542], [73.06208038, 18.25708389], [73.06236267, 18.25707817], [73.06236267, 18.25735855], [73.06208038, 18.25735855], [73.06208038, 18.25764084], [73.06236267, 18.25764084], [73.06236267, 18.25819397], [73.06263733, 18.25819397], [73.06263733, 18.25847244], [73.06291962, 18.25847244], [73.06291962, 18.25876045], [73.06318665, 18.25876045], [73.06318665, 18.25902939], [73.06346893, 18.25902939], [73.06346893, 18.25930977], [73.06375122, 18.25930977], [73.06375122, 18.2598629], [73.06402588, 18.2598629], [73.06402588, 18.26013947], [73.06458282, 18.26013947], [73.06458282, 18.2606945], [73.06485748, 18.2606945], [73.06485748, 18.26097488], [73.06541443, 18.26097488], [73.06541443, 18.26124954], [73.06569672, 18.26124954], [73.06571198, 18.26180077], [73.06652832, 18.26180649], [73.06652832, 18.26208305], [73.06680298, 18.26208305], [73.06680298, 18.26236153], [73.06735992, 18.26235962], [73.06735992, 18.26292038], [73.06764221, 18.26292038], [73.06764221, 18.26320076], [73.06791687, 18.26320076], [73.06791687, 18.26403046], [73.06819153, 18.26403046], [73.06819153, 18.26431084], [73.06845856, 18.26431084], [73.06845856, 18.26514053], [73.06874847, 18.26514053], [73.06874847, 18.26542091], [73.06903076, 18.26542091], [73.06903076, 18.26680946], [73.06874847, 18.26680946], [73.06874847, 18.26791954], [73.06845856, 18.26791954], [73.06845856, 18.26902962], [73.06819153, 18.26902962], [73.06819153, 18.26930809], [73.06791687, 18.26930809], [73.06791687, 18.2701416], [73.06764221, 18.2701416], [73.06764221, 18.27042007], [73.06735992, 18.27041626], [73.06735992, 18.27096939], [73.0670929, 18.27096939], [73.0670929, 18.27153015], [73.06680298, 18.27152824], [73.06680298, 18.27180481], [73.06652832, 18.27180481], [73.06652832, 18.27208328], [73.06625366, 18.27208328], [73.06625366, 18.27236176], [73.06597137, 18.27236176], [73.06597137, 18.27264023], [73.06571198, 18.27264023], [73.06571198, 18.2732029], [73.06541443, 18.27319527], [73.06541443, 18.27347374], [73.06513977, 18.27347183], [73.06513977, 18.27431107], [73.06485748, 18.27430534], [73.06485748, 18.27458382], [73.06458282, 18.27458191], [73.06458282, 18.27486038], [73.06430817, 18.27486038], [73.06430817, 18.27514076], [73.06402588, 18.27514076], [73.06402588, 18.27542114], [73.06375122, 18.27541733], [73.06375122, 18.2756958], [73.06346893, 18.2756958], [73.06346893, 18.27597237], [73.06318665, 18.27597046], [73.06318665, 18.27653122], [73.06291962, 18.27653122], [73.06291962, 18.27763939], [73.06319427, 18.27763939], [73.06319427, 18.27819443], [73.06291962, 18.27819443], [73.06291962, 18.2784729], [73.06263733, 18.2784729], [73.06263733, 18.27819443], [73.06208038, 18.27819443], [73.06208038, 18.27791405], [73.06180573, 18.27791405], [73.06180573, 18.27819443], [73.06124878, 18.27819443], [73.06124878, 18.27791405], [73.05986023, 18.27791405], [73.05986023, 18.27819443], [73.05874634, 18.27819443], [73.05874634, 18.2784729], [73.05847168, 18.27847099], [73.05847168, 18.27874947], [73.0579071, 18.27874947], [73.0579071, 18.27902985], [73.05735779, 18.27902985], [73.05735779, 18.27931023], [73.05680847, 18.27930641], [73.05680847, 18.27958298], [73.05562592, 18.27957153], [73.05541992, 18.27956963], [73.05545044, 18.27988052], [73.05264282, 18.27985954], [73.05264282, 18.2804203], [73.05291748, 18.28041649], [73.05291748, 18.28097153], [73.05263519, 18.28097153], [73.05264282, 18.28124809], [73.05236053, 18.28124809], [73.05236053, 18.28153038], [73.05208588, 18.28153038], [73.05208588, 18.28181076], [73.05180359, 18.28180504], [73.05180359, 18.28208351], [73.05152893, 18.2820797], [73.05152893, 18.28293037], [73.05124664, 18.28291893], [73.05124664, 18.28319359], [73.05097198, 18.28318977], [73.05097198, 18.28374863], [73.05042267, 18.28374863], [73.05042267, 18.28430939], [73.05014038, 18.28430557], [73.05014038, 18.28458405], [73.04985809, 18.28458405], [73.04985809, 18.28490067], [73.04985809, 18.28569984], [73.04958344, 18.28569412], [73.04958344, 18.2859726], [73.04930878, 18.2859726], [73.04930878, 18.28680992], [73.04902649, 18.28680992], [73.04902649, 18.28792], [73.04875183, 18.28792], [73.04875183, 18.28903008], [73.04846954, 18.28902817], [73.04846954, 18.28930473], [73.04819489, 18.28930473], [73.04819489, 18.28958321], [73.04792023, 18.28957939], [73.04792023, 18.29042053], [73.04763794, 18.29041672], [73.04763794, 18.29097176], [73.04736328, 18.29096985], [73.04736328, 18.29153061], [73.04708099, 18.2915287], [73.04708099, 18.29180527], [73.04680634, 18.29179955], [73.04680634, 18.29264069], [73.04652405, 18.29263878], [73.04652405, 18.29319382], [73.04624939, 18.29319], [73.04624939, 18.29375076], [73.0459671, 18.29375076], [73.0459671, 18.29403114], [73.04569244, 18.29403114], [73.04569244, 18.29486847], [73.04541779, 18.29486847], [73.04541779, 18.29514122], [73.0451355, 18.29513741], [73.0451355, 18.29569435], [73.04458618, 18.29569435], [73.04458618, 18.29597282], [73.04402924, 18.29597092], [73.04402924, 18.29624748], [73.04337311, 18.29624748], [73.04319763, 18.29624748], [73.04319763, 18.2970829], [73.04292297, 18.29707909], [73.04292297, 18.2990303], [73.04319763, 18.2990284], [73.04319763, 18.29986382], [73.04347229, 18.29986191], [73.04347229, 18.30042076], [73.04402924, 18.30042076], [73.04402924, 18.30125046], [73.04428864, 18.30125046], [73.04428864, 18.30181122], [73.04486084, 18.3018055], [73.04486084, 18.30208206], [73.0451355, 18.30208206], [73.0451355, 18.30236053], [73.04569244, 18.30236053], [73.04569244, 18.30264091], [73.04624939, 18.30264091], [73.04624939, 18.30291939], [73.04708099, 18.30291748], [73.04708099, 18.30319595], [73.04819489, 18.30319595], [73.04819489, 18.30374908], [73.05124664, 18.30374908], [73.05124664, 18.30347252], [73.05208588, 18.30347252], [73.05208588, 18.30319595], [73.05263519, 18.30319595], [73.05263519, 18.30291748], [73.05301666, 18.30291748], [73.05319214, 18.30291939], [73.05319214, 18.30264091], [73.05374908, 18.30264091], [73.05374908, 18.30236053], [73.05403137, 18.30236053], [73.05403137, 18.30208015], [73.05486298, 18.30208206], [73.05486298, 18.3018055], [73.05513763, 18.30181122], [73.05513763, 18.30153084], [73.05541992, 18.30153084], [73.05541992, 18.30125046], [73.05568695, 18.30125046], [73.05568695, 18.30097008], [73.05596924, 18.30097389], [73.05596924, 18.30069351], [73.05625153, 18.30069351], [73.05625153, 18.30041695], [73.05708313, 18.30042076], [73.05708313, 18.30014038], [73.06069183, 18.30014038], [73.06069183, 18.29986191], [73.06180573, 18.29986382], [73.06180573, 18.29958344], [73.06319427, 18.29958344], [73.06319427, 18.29930496], [73.06513977, 18.29931068], [73.06513977, 18.2990303], [73.06597137, 18.2990303], [73.06597137, 18.29931068], [73.06625366, 18.29930496], [73.06625366, 18.29958344], [73.06791687, 18.29958344], [73.06791687, 18.29930496], [73.06874847, 18.29931068], [73.06874847, 18.2990303], [73.07013702, 18.2990303], [73.07013702, 18.29931068], [73.07041931, 18.29931068], [73.07041931, 18.2990303], [73.07208252, 18.2990303], [73.07208252, 18.29875183], [73.07290649, 18.29875183], [73.07290649, 18.29846954], [73.07680511, 18.29846954], [73.07680511, 18.29819489], [73.07653046, 18.29819489], [73.07653046, 18.29624748], [73.07681274, 18.29624748], [73.07680511, 18.29597282], [73.07707977, 18.29597282], [73.07707977, 18.29569435], [73.07736206, 18.29569435], [73.07736206, 18.29541588], [73.07958221, 18.29541969], [73.07958221, 18.29514122], [73.08152771, 18.29514122], [73.08152771, 18.29486847], [73.08180237, 18.29486847], [73.08180237, 18.29458046], [73.08208466, 18.29458237], [73.08208466, 18.29402733], [73.08235931, 18.29403114], [73.08235931, 18.29375076], [73.0826416, 18.29375076], [73.0826416, 18.29347038], [73.08291626, 18.29347229], [73.08291626, 18.29291534], [73.08319092, 18.29292107], [73.08319092, 18.29207993], [73.08347321, 18.29208374], [73.08347321, 18.2915287], [73.08374786, 18.29153061], [73.08374786, 18.29096985], [73.08403015, 18.29097176], [73.08403015, 18.29041672], [73.08429718, 18.29042053], [73.08429718, 18.29022026], [73.08430481, 18.28958321], [73.0845871, 18.28958321], [73.0845871, 18.28930473], [73.08486176, 18.28930473], [73.08486176, 18.28874969], [73.08513641, 18.28874969], [73.08513641, 18.28847313], [73.0854187, 18.28847313], [73.0854187, 18.28819466], [73.08597565, 18.28819466], [73.08597565, 18.28791618], [73.08625031, 18.28791618], [73.08625031, 18.28819466], [73.08652496, 18.28819466], [73.08652496, 18.28847313], [73.08625031, 18.28847313], [73.08625031, 18.28874969], [73.08598328, 18.28874016], [73.08598328, 18.28903008], [73.08569336, 18.28902817], [73.08569336, 18.28930473], [73.0854187, 18.28930473], [73.0854187, 18.28958321], [73.08513641, 18.28958321], [73.08513641, 18.28982925], [73.08513641, 18.29042053], [73.08486176, 18.29041672], [73.08486176, 18.29097176], [73.0845871, 18.29096985], [73.0845871, 18.29153061], [73.08430481, 18.2915287], [73.08430481, 18.29208374], [73.08403015, 18.29207993], [73.08403015, 18.29292107], [73.08374786, 18.29291534], [73.08374786, 18.29347229], [73.08345795, 18.29347038], [73.08345795, 18.29403114], [73.08319092, 18.29403114], [73.08319092, 18.29430962], [73.08291626, 18.29430962], [73.08291626, 18.29486847], [73.0826416, 18.29486084], [73.0826416, 18.29569435], [73.08235931, 18.29569435], [73.08235931, 18.29597282], [73.08207703, 18.29597092], [73.08207703, 18.29624748], [73.08097076, 18.29624748], [73.08097076, 18.29653168], [73.07847595, 18.29653168], [73.07847595, 18.29681015], [73.07819366, 18.29680634], [73.07819366, 18.2970829], [73.07791901, 18.2970829], [73.07791901, 18.29735947], [73.07763672, 18.29735947], [73.07763672, 18.29846954], [73.07791901, 18.29846954], [73.07791901, 18.29875183], [73.07818604, 18.29875183], [73.07818604, 18.2990303], [73.07847595, 18.2990284], [73.07847595, 18.29958344], [73.07875061, 18.29957962], [73.07875061, 18.30014038], [73.0790329, 18.30014038], [73.0790329, 18.30042076], [73.0798645, 18.30041695], [73.0798645, 18.30069351], [73.08041382, 18.30069351], [73.08041382, 18.30097389], [73.08235931, 18.30097008], [73.08235931, 18.30125046], [73.0826416, 18.30125046], [73.0826416, 18.30381012], [73.0826416, 18.30486107], [73.08291626, 18.30486107], [73.08291626, 18.30513954], [73.0826416, 18.30513954], [73.0826416, 18.30541992], [73.08291626, 18.30541992], [73.08291626, 18.30820084], [73.08319092, 18.30820084], [73.08319092, 18.30874825], [73.08291626, 18.30874825], [73.08291626, 18.30931091], [73.0826416, 18.30931091], [73.0826416, 18.31014061], [73.08235931, 18.31014061], [73.08235931, 18.31041908], [73.08208466, 18.31041718], [73.08208466, 18.3120842], [73.08235931, 18.3120842], [73.08235931, 18.3129158], [73.0826416, 18.3129158], [73.0826416, 18.31347275], [73.08291626, 18.31347275], [73.08291626, 18.31402969], [73.08319092, 18.31402969], [73.08319092, 18.31431007], [73.08347321, 18.31430626], [73.08347321, 18.31458473], [73.08319092, 18.31458473], [73.08319092, 18.3148613], [73.08345795, 18.31485939], [73.08345795, 18.31513977], [73.08374786, 18.31513977], [73.08374786, 18.31569481], [73.08430481, 18.31569481], [73.08430481, 18.31597137], [73.0845871, 18.31596947], [73.0845871, 18.31624985], [73.08486176, 18.31624985], [73.08486176, 18.31680489], [73.08513641, 18.31680489], [73.08513641, 18.31736183], [73.0854187, 18.31736183], [73.0854187, 18.31847191], [73.08569336, 18.31847], [73.08569336, 18.31875038], [73.08598328, 18.31875038], [73.08598328, 18.31903076], [73.08653259, 18.31903076], [73.08653259, 18.31931114], [73.08625031, 18.31930542], [73.08625031, 18.31958389], [73.08653259, 18.31958008], [73.08653259, 18.32014084], [73.08682251, 18.32014084], [73.08682251, 18.32042122], [73.08708191, 18.32042122], [73.08708191, 18.32125092], [73.08735657, 18.32125092], [73.08735657, 18.32235909], [73.08763885, 18.32235909], [73.08763885, 18.32263756], [73.08790588, 18.32263756], [73.08790588, 18.32291985], [73.0881958, 18.32291603], [73.0881958, 18.32347298], [73.08847046, 18.32346916], [73.08847046, 18.32375145], [73.0881958, 18.32375145], [73.0881958, 18.32403183], [73.08763885, 18.32403183], [73.08763885, 18.32375145], [73.08735657, 18.32375145], [73.08735657, 18.32319069], [73.08708191, 18.3231945], [73.08708191, 18.32291603], [73.08682251, 18.32291985], [73.08682251, 18.32263756], [73.08652496, 18.32263756], [73.08652496, 18.32235909], [73.08625031, 18.32235909], [73.08625031, 18.32152748], [73.08598328, 18.32152748], [73.08598328, 18.32014084], [73.08569336, 18.32014084], [73.08569336, 18.32042122], [73.08513641, 18.32041931], [73.08513641, 18.32069397], [73.08486176, 18.32069397], [73.08486176, 18.32097244], [73.0845871, 18.32097054], [73.0845871, 18.32263756], [73.08429718, 18.32263756], [73.08429718, 18.32291985], [73.08403015, 18.32291603], [73.08403015, 18.32486153], [73.08374786, 18.32484818], [73.08374786, 18.32542038], [73.08403015, 18.32542038], [73.08403015, 18.32653046], [73.08429718, 18.32653046], [73.08429718, 18.32681084], [73.08513641, 18.32681084], [73.08513641, 18.32653046], [73.08598328, 18.32653046], [73.08598328, 18.32625008], [73.08790588, 18.32625008], [73.08790588, 18.32681084], [73.08597565, 18.32680511], [73.08597565, 18.32708359], [73.0854187, 18.32708359], [73.0854187, 18.32736206], [73.08513641, 18.32736015], [73.08513641, 18.32764053], [73.08486176, 18.32763863], [73.08486176, 18.32819366], [73.08513641, 18.32819366], [73.08513641, 18.32958412], [73.08486176, 18.32958031], [73.08486176, 18.32986069], [73.0845871, 18.32986069], [73.0845871, 18.32958031], [73.08430481, 18.32958412], [73.08430481, 18.32930565], [73.08403015, 18.32930946], [73.08403015, 18.32736015], [73.08374786, 18.32736206], [73.08374786, 18.32708359], [73.08347321, 18.32708359], [73.08347321, 18.32680511], [73.08319092, 18.32681084], [73.08319092, 18.32653046], [73.08291626, 18.32653046], [73.08291626, 18.32484818], [73.0826416, 18.32486153], [73.0826416, 18.32458115], [73.08235931, 18.32458115], [73.08235931, 18.32347298], [73.08208466, 18.32347298], [73.08208466, 18.3231945], [73.08180237, 18.3231945], [73.08180237, 18.32291603], [73.08152771, 18.32291985], [73.08152771, 18.32263756], [73.08125305, 18.32263756], [73.08125305, 18.32235909], [73.08097076, 18.32235909], [73.08097076, 18.32180977], [73.08068848, 18.32180977], [73.08068848, 18.32152748], [73.08039856, 18.32152748], [73.08039856, 18.32097054], [73.08013916, 18.32097244], [73.08013916, 18.32013893], [73.07985687, 18.32014084], [73.07985687, 18.31958008], [73.07958221, 18.31958389], [73.07958221, 18.31930542], [73.07930756, 18.31931114], [73.07930756, 18.3176403], [73.0790329, 18.3176403], [73.0790329, 18.31680107], [73.07875061, 18.31680489], [73.07875061, 18.31624985], [73.0790329, 18.31624985], [73.07902527, 18.31569481], [73.07875061, 18.31569481], [73.07875061, 18.31458473], [73.07847595, 18.31458473], [73.07847595, 18.31430626], [73.07791901, 18.31431007], [73.07791901, 18.31402969], [73.07765198, 18.31402969], [73.07765198, 18.31375122], [73.07736206, 18.31375122], [73.07736206, 18.31319046], [73.07707977, 18.31319427], [73.07707977, 18.3129158], [73.07680511, 18.3129158], [73.07680511, 18.31263924], [73.07653046, 18.31264114], [73.07653046, 18.31236267], [73.07624817, 18.31236267], [73.07624817, 18.31208038], [73.07597351, 18.3120842], [73.07597351, 18.31180573], [73.07569122, 18.31180954], [73.07569122, 18.31125259], [73.07541656, 18.31125259], [73.07541656, 18.3109684], [73.07485962, 18.31097031], [73.07485962, 18.31069374], [73.07458496, 18.31069374], [73.07458496, 18.30985832], [73.07430267, 18.30987167], [73.07430267, 18.30957985], [73.07402802, 18.30958366], [73.07402802, 18.30930519], [73.07375336, 18.30931091], [73.07375336, 18.30874825], [73.07347107, 18.30874825], [73.07347107, 18.30846977], [73.07263947, 18.30847168], [73.07263947, 18.30819511], [73.07235718, 18.30820084], [73.07235718, 18.30792046], [73.07180786, 18.30792046], [73.07180786, 18.30763817], [73.07151794, 18.30763817], [73.07151794, 18.3073597], [73.07096863, 18.3073616], [73.07096863, 18.30708313], [73.07069397, 18.30708313], [73.07069397, 18.30680466], [73.06986237, 18.30681038], [73.06986237, 18.30652809], [73.06958008, 18.30652809], [73.06958008, 18.30624962], [73.06930542, 18.30624962], [73.06930542, 18.30597305], [73.06903076, 18.30597305], [73.06903076, 18.30569458], [73.06874847, 18.30569458], [73.06874847, 18.30541611], [73.06845856, 18.30541992], [73.06845856, 18.30513954], [73.06819153, 18.30513954], [73.06819153, 18.30486107], [73.06735992, 18.30486107], [73.06735992, 18.30458069], [73.06680298, 18.3045826], [73.06680298, 18.30430412], [73.06597137, 18.30430984], [73.06597137, 18.30402946], [73.06571198, 18.30402946], [73.06571198, 18.30373955], [73.06375122, 18.30374908], [73.06375122, 18.30347252], [73.06319427, 18.30347252], [73.06319427, 18.30319595], [73.06263733, 18.30319595], [73.06263733, 18.30291748], [73.06153107, 18.30291748], [73.06153107, 18.30319595], [73.06097412, 18.30319595], [73.06097412, 18.30347252], [73.05986023, 18.30347252], [73.05986023, 18.30374908], [73.05847168, 18.30373955], [73.05847168, 18.30402946], [73.05819702, 18.30402946], [73.05819702, 18.30430984], [73.05764008, 18.30430412], [73.05764008, 18.3045826], [73.05625153, 18.30458069], [73.05625153, 18.30486107], [73.05596924, 18.30486107], [73.05596924, 18.30513954], [73.05541992, 18.30513954], [73.05541992, 18.30541992], [73.05486298, 18.30541611], [73.05486298, 18.30569458], [73.05458069, 18.30569458], [73.05458069, 18.30597305], [73.05410004, 18.30597115], [73.05403137, 18.30624962], [73.05374908, 18.30624962], [73.05374908, 18.30652809], [73.05291748, 18.30652809], [73.05291748, 18.30681038], [73.05236053, 18.30680466], [73.05236053, 18.30708313], [73.05180359, 18.30708313], [73.05180359, 18.3073616], [73.05124664, 18.3073597], [73.05124664, 18.30763817], [73.05071259, 18.30763817], [73.05071259, 18.30792046], [73.05042267, 18.30792046], [73.05042267, 18.30763817], [73.04902649, 18.30763817], [73.04902649, 18.3073597], [73.04846954, 18.3073616], [73.04846954, 18.30708313], [73.04819489, 18.30708313], [73.04819489, 18.30680466], [73.04763794, 18.30681038], [73.04763794, 18.30652809], [73.04680634, 18.30652809], [73.04680634, 18.30681038], [73.04651642, 18.30681038], [73.04651642, 18.30652809], [73.04541779, 18.30652809], [73.04541779, 18.30597115], [73.04486084, 18.30597305], [73.04486084, 18.30569458], [73.04458618, 18.30569458], [73.04458618, 18.30541611], [73.04402924, 18.30541992], [73.04402924, 18.30513954], [73.04374695, 18.30513954], [73.04374695, 18.30486107], [73.04345703, 18.30486107], [73.04344177, 18.30430984], [73.04292297, 18.30430984], [73.04292297, 18.30373955], [73.0423584, 18.30374908], [73.0423584, 18.30347252], [73.04208374, 18.30347252], [73.04208374, 18.30291748], [73.04180908, 18.30291939], [73.04180908, 18.30264091], [73.04125214, 18.30264091], [73.04125214, 18.30208015], [73.04069519, 18.30208206], [73.04069519, 18.3018055], [73.0404129, 18.30181122], [73.0404129, 18.30153084], [73.04013824, 18.30153084], [73.04013824, 18.30097008], [73.03986359, 18.30097389], [73.03986359, 18.30069542], [73.0395813, 18.30068016], [73.0395813, 18.29958344], [73.03930664, 18.29958344], [73.03930664, 18.29791641], [73.0395813, 18.29792976], [73.0395813, 18.29764175], [73.03930664, 18.29764175], [73.03930664, 18.29681015], [73.0395813, 18.29681015], [73.0395813, 18.29653168], [73.03930664, 18.29653168], [73.03930664, 18.29624748], [73.0395813, 18.29624748], [73.0395813, 18.29597092], [73.03930664, 18.29597282], [73.03930664, 18.29569435], [73.0395813, 18.29569435], [73.0395813, 18.29458427], [73.03986359, 18.29458237], [73.03986359, 18.29375076], [73.04013824, 18.29375076], [73.04013824, 18.29292107], [73.0404129, 18.29292107], [73.0404129, 18.29236031], [73.04070282, 18.29236031], [73.04069519, 18.29180527], [73.04096985, 18.29180527], [73.04096985, 18.2915287], [73.04125214, 18.29153061], [73.04125214, 18.29096985], [73.04152679, 18.29097176], [73.04152679, 18.29069519], [73.04207611, 18.29070091], [73.04207611, 18.29014015], [73.0423584, 18.29014015], [73.0423584, 18.28985977], [73.04264069, 18.28986168], [73.04264069, 18.28958321], [73.04291534, 18.28958321], [73.04291534, 18.28930473], [73.04319763, 18.28930473], [73.04319763, 18.28902817], [73.04347229, 18.28903008], [73.04347229, 18.28847122], [73.04374695, 18.28847313], [73.04374695, 18.28763962], [73.04402924, 18.28763962], [73.04402924, 18.28708267], [73.04430389, 18.28708267], [73.04430389, 18.28652763], [73.04457855, 18.28652954], [73.04457855, 18.2859726], [73.04486084, 18.2859726], [73.04486084, 18.28486252], [73.04514313, 18.28486252], [73.0451355, 18.28430557], [73.04541779, 18.28430939], [73.04541779, 18.28374863], [73.0459671, 18.28374863], [73.0459671, 18.28346825], [73.04569244, 18.28347015], [73.04569244, 18.28264046], [73.0459671, 18.28264046], [73.0459671, 18.28124809], [73.04624939, 18.28124809], [73.04624939, 18.28096962], [73.04652405, 18.28097153], [73.04652405, 18.28069496], [73.04736328, 18.28070068], [73.04736328, 18.2804203], [73.04792023, 18.2804203], [73.04792023, 18.27985954], [73.04819489, 18.27986145], [73.04819489, 18.27930641], [73.04846954, 18.27931023], [73.04846954, 18.27902985], [73.04875183, 18.27902985], [73.04875183, 18.27847099], [73.04930878, 18.2784729], [73.04930878, 18.27819443], [73.04958344, 18.27819443], [73.04958344, 18.27763939], [73.04985809, 18.27763939], [73.04985809, 18.27736092], [73.05042267, 18.27736092], [73.05041504, 18.27708244], [73.05069733, 18.27708244], [73.05069733, 18.27680588], [73.05124664, 18.27680588], [73.05124664, 18.2765274], [73.05152893, 18.27653122], [73.05152893, 18.27625084], [73.05179596, 18.27625084], [73.05179596, 18.27597046], [73.05208588, 18.27597237], [73.05208588, 18.27541733], [73.05236053, 18.27542114], [73.05236053, 18.27514076], [73.05264282, 18.27514076], [73.05264282, 18.27486038], [73.05319214, 18.27486038], [73.05319214, 18.27458191], [73.05347443, 18.27458382], [73.05347443, 18.27402687], [73.05374908, 18.27403069], [73.05374908, 18.27375984], [73.05403137, 18.27375984], [73.05403137, 18.2732029], [73.05430603, 18.2732029], [73.05430603, 18.27292061], [73.05458069, 18.27292061], [73.05458069, 18.27179909], [73.05486298, 18.27180481], [73.05486298, 18.27152824], [73.05458069, 18.27153015], [73.05458069, 18.27042007], [73.05430603, 18.27042007], [73.05430603, 18.26985931], [73.05403137, 18.26985931], [73.05403137, 18.26958084], [73.05374908, 18.26958275], [73.05374908, 18.26930618], [73.05348206, 18.26930809], [73.05348206, 18.26902962], [73.05319214, 18.26902962], [73.05319214, 18.26874924], [73.05264282, 18.26874924], [73.05264282, 18.26847076], [73.05236053, 18.26847267], [73.05236053, 18.2681942], [73.05208588, 18.2681942], [73.05208588, 18.26847267], [73.05069733, 18.26847267], [73.05069733, 18.2681942], [73.04958344, 18.2681942], [73.04958344, 18.26791954], [73.04902649, 18.26791954], [73.04902649, 18.26762962], [73.04819489, 18.26763725], [73.04819489, 18.26736069], [73.04736328, 18.26736069], [73.04736328, 18.26708031], [73.04624939, 18.26708412], [73.04624939, 18.26680565], [73.04541779, 18.26680946], [73.04541779, 18.26653099], [73.04374695, 18.26653099], [73.04374695, 18.26597023], [73.04347229, 18.26597214], [73.04347229, 18.26569366], [73.04291534, 18.26569366], [73.04291534, 18.26541519], [73.0423584, 18.26542091], [73.0423584, 18.26514053], [73.04180908, 18.26514053], [73.04180908, 18.26486015], [73.04152679, 18.26486206], [73.04152679, 18.26458359], [73.03986359, 18.26458359], [73.03986359, 18.26486206], [73.03820801, 18.26486206], [73.0359726, 18.26486206], [73.0359726, 18.26458359], [73.03569794, 18.26458359], [73.03569794, 18.26486206], [73.03514099, 18.26486015], [73.03514099, 18.26514053], [73.0348587, 18.26514053], [73.0348587, 18.26542091], [73.03458405, 18.26541519], [73.03458405, 18.26569366], [73.03375244, 18.26569366], [73.03375244, 18.26597214], [73.03263855, 18.26597023], [73.03263855, 18.26625061], [73.03151703, 18.26625061], [73.03151703, 18.26597023], [73.03125, 18.26597214], [73.03125, 18.26569366], [73.03069305, 18.26569366], [73.03069305, 18.26541519], [73.0304184, 18.26542091], [73.0304184, 18.26514053], [73.03013611, 18.26514053], [73.03013611, 18.26486015], [73.02958679, 18.26486206], [73.02958679, 18.26458359], [73.02902985, 18.26458359], [73.02902985, 18.26430511], [73.02791595, 18.26430511], [73.02791595, 18.26597214], [73.02819824, 18.26597023], [73.02819824, 18.26680946], [73.02791595, 18.26680565], [73.02791595, 18.26708412], [73.02735901, 18.26708031], [73.02735901, 18.26736069], [73.02708435, 18.26736069], [73.02708435, 18.26763725], [73.02680206, 18.26762962], [73.02680206, 18.26791954], [73.02654266, 18.26791954], [73.02654266, 18.26874924], [73.02625275, 18.26874924], [73.02625275, 18.26902962], [73.02597046, 18.26902962], [73.02597046, 18.26930809], [73.02541351, 18.26930618], [73.02541351, 18.26958275], [73.02513885, 18.26958275], [73.02513885, 18.26930618], [73.02485657, 18.26930809], [73.02485657, 18.26874924], [73.02458191, 18.26874924], [73.02458191, 18.26847076], [73.02346802, 18.26847076], [73.02346802, 18.26874924], [73.0229187, 18.26874924], [73.0229187, 18.26902962], [73.02153015, 18.26902962], [73.02153015, 18.26958275], [73.02097321, 18.26958084], [73.02097321, 18.26985931], [73.02069092, 18.26985931], [73.02069092, 18.27042007], [73.02041626, 18.27041626], [73.02041626, 18.27180481], [73.02097321, 18.27180481], [73.02097321, 18.27208328], [73.02124786, 18.27208328], [73.02124786, 18.27236176], [73.02179718, 18.27236176], [73.02179718, 18.27264023], [73.0220871, 18.27264023], [73.0220871, 18.27292061], [73.02236176, 18.27292061], [73.02236176, 18.2732029], [73.02263641, 18.2732029], [73.02263641, 18.27403069], [73.02236176, 18.27403069], [73.02236176, 18.27514076], [73.0220871, 18.27514076], [73.0220871, 18.27542114], [73.02179718, 18.27542114], [73.02179718, 18.27653122], [73.0220871, 18.2765274], [73.0220871, 18.27680588], [73.02236176, 18.27680016], [73.02236176, 18.27736092], [73.0220871, 18.27736092], [73.0220871, 18.27791977], [73.02180481, 18.27791405], [73.02180481, 18.27819443], [73.02153015, 18.27819443], [73.02153015, 18.2784729], [73.02069092, 18.27847099], [73.02069092, 18.27902985], [73.02040863, 18.27902985], [73.02040863, 18.27931023], [73.0201416, 18.27930641], [73.0201416, 18.27958298], [73.01985931, 18.27958298], [73.01985931, 18.27986145], [73.01930237, 18.27985954], [73.01930237, 18.28013992], [73.01875305, 18.28013992], [73.01875305, 18.2804203], [73.01847076, 18.2804203], [73.01847076, 18.28070068], [73.01791382, 18.28069496], [73.01791382, 18.28097153], [73.01734924, 18.28096962], [73.01734924, 18.28124809], [73.01680756, 18.28124809], [73.01680756, 18.28153038], [73.01654053, 18.28153038], [73.0165329, 18.28181076], [73.01597595, 18.28180504], [73.01597595, 18.28208351], [73.01513672, 18.28208351], [73.01513672, 18.28236008], [73.01457977, 18.28235817], [73.01457977, 18.28264046], [73.01431274, 18.28264046], [73.01431274, 18.28293037], [73.01374817, 18.28291893], [73.01374817, 18.28319359], [73.01291656, 18.28319359], [73.01291656, 18.28347015], [73.01235962, 18.28346825], [73.01235962, 18.28374863], [73.01125336, 18.28374863], [73.01125336, 18.28403091], [73.00958252, 18.28403091], [73.00958252, 18.28430939], [73.00875092, 18.28430557], [73.00875092, 18.28458405], [73.00291443, 18.28458405], [73.00291443, 18.28430557], [73.00041962, 18.28430939], [73.00041962, 18.28346825], [72.99986267, 18.28347015], [72.99930573, 18.28347015], [72.99930573, 18.28319359], [72.99874878, 18.28319359], [72.99874878, 18.28291893], [72.99791718, 18.28293037], [72.99791718, 18.2820797], [72.99819183, 18.28208351], [72.99819183, 18.28124809], [72.99791718, 18.28124809], [72.99791718, 18.28070068], [72.99764252, 18.28070068], [72.99764252, 18.28013992], [72.99736023, 18.28013992], [72.99736023, 18.27956963], [72.99708557, 18.27958298], [72.99708557, 18.27819443], [72.99680328, 18.27819443], [72.99680328, 18.27708244], [72.99652863, 18.27708244], [72.99652863, 18.2765274], [72.99623871, 18.27653122], [72.99623871, 18.27625084], [72.99597168, 18.27625084], [72.99597168, 18.27597046], [72.99569702, 18.27597237], [72.99569702, 18.2756958], [72.99541473, 18.2756958], [72.99541473, 18.27541733], [72.99514008, 18.27542114], [72.99514008, 18.27514076], [72.99485779, 18.27514076], [72.99485779, 18.27486038], [72.99430847, 18.27486038], [72.99430847, 18.27431107], [72.99402618, 18.27431107], [72.99402618, 18.27347183], [72.99291992, 18.27347183], [72.99291992, 18.27514076], [72.99263763, 18.27514076], [72.99263763, 18.27625084], [72.99236298, 18.27625084], [72.99236298, 18.27680588], [72.99180603, 18.27680016], [72.99180603, 18.27902985], [72.99208069, 18.27902985], [72.99208069, 18.28013992], [72.99180603, 18.28013992], [72.99180603, 18.28070068], [72.99153137, 18.28070068], [72.99153137, 18.28124809], [72.99124908, 18.28124809], [72.99124908, 18.28153038], [72.99097443, 18.28153038], [72.99097443, 18.28208351], [72.99069214, 18.28208351], [72.99069214, 18.28236008], [72.99043274, 18.28235817], [72.99043274, 18.28403091], [72.99069214, 18.2840271], [72.99069214, 18.28458405], [72.99043274, 18.28457832], [72.99043274, 18.28541946], [72.99014282, 18.28541946], [72.99014282, 18.28652954], [72.98986053, 18.28652763], [72.98986053, 18.28708267], [72.98958588, 18.28708267], [72.98958588, 18.28736115], [72.98764038, 18.28736115], [72.98764038, 18.28708267], [72.98707581, 18.28708267], [72.98707581, 18.28763962], [72.98680878, 18.28763962], [72.98680878, 18.28847313], [72.98652649, 18.28847313], [72.98652649, 18.28958321], [72.98680878, 18.28957939], [72.98680878, 18.29042053], [72.98652649, 18.29042053], [72.98652649, 18.29153061], [72.98625183, 18.2915287], [72.98625183, 18.29180527], [72.98596954, 18.29179955], [72.98596954, 18.29236031], [72.98513794, 18.29236031], [72.98513794, 18.29264069], [72.98400879, 18.29264069], [72.98400879, 18.29292107], [72.98374939, 18.29292107], [72.98374939, 18.29403114], [72.98347473, 18.29402733], [72.98347473, 18.29458427], [72.98319244, 18.29458046], [72.98319244, 18.29514122], [72.98291779, 18.29513741], [72.98291779, 18.29597282], [72.98264313, 18.29597092], [72.98264313, 18.29681015], [72.98236084, 18.29680634], [72.98236084, 18.29717064], [72.98236084, 18.29792976], [72.98208618, 18.29791641], [72.98208618, 18.29846954], [72.98179626, 18.29846954], [72.98179626, 18.29931068], [72.98152924, 18.29930496], [72.98152924, 18.29986382], [72.98060608, 18.29986191], [72.98042297, 18.29986191], [72.98042297, 18.30014038], [72.97902679, 18.30014038], [72.97902679, 18.29957962], [72.97930908, 18.29958344], [72.97930908, 18.2990284], [72.97846985, 18.2990303], [72.97846985, 18.29875183], [72.9779129, 18.29875183], [72.9779129, 18.2990303], [72.9770813, 18.2990303], [72.9770813, 18.29931068], [72.97624969, 18.29930496], [72.97624969, 18.29958344], [72.97569275, 18.29958344], [72.97569275, 18.29986382], [72.97458649, 18.29986191], [72.97458649, 18.30014038], [72.97429657, 18.30014038], [72.97429657, 18.30042076], [72.97402954, 18.30041695], [72.97402954, 18.30068016], [72.97374725, 18.30069542], [72.97374725, 18.30097389], [72.9734726, 18.30097008], [72.9734726, 18.30125046], [72.97319794, 18.30125046], [72.97319794, 18.30181122], [72.9723587, 18.30181122], [72.9723587, 18.30153084], [72.97180176, 18.30153084], [72.97180176, 18.30125046], [72.97097015, 18.30125046], [72.97097015, 18.29957962], [72.97041321, 18.29958344], [72.97041321, 18.29986382], [72.97013855, 18.29986191], [72.97013855, 18.30014038], [72.96986389, 18.30013847], [72.96985626, 18.30068016], [72.9695816, 18.30070114], [72.9695816, 18.30125046], [72.96929932, 18.30125046], [72.96929932, 18.30181122], [72.9690094, 18.30181122], [72.9690094, 18.30236053], [72.96875, 18.30236053], [72.96875, 18.30374908], [72.96847534, 18.30374908], [72.96847534, 18.3045826], [72.96819305, 18.3045826], [72.96819305, 18.30569458], [72.9679184, 18.30569458], [72.9679184, 18.30708313], [72.96819305, 18.30708313], [72.96819305, 18.3074398], [72.96819305, 18.30792046], [72.96848297, 18.30792046], [72.96848297, 18.30903053], [72.96819305, 18.30903053], [72.96819305, 18.30931091], [72.9679184, 18.30930519], [72.9679184, 18.30958366], [72.96763611, 18.30957985], [72.96763611, 18.31014061], [72.96736145, 18.31014061], [72.96736145, 18.31041908], [72.96708679, 18.31041718], [72.96708679, 18.31069374], [72.9668045, 18.31069374], [72.9668045, 18.31097031], [72.96652985, 18.3109684], [72.96652985, 18.31125259], [72.96626282, 18.31125259], [72.96626282, 18.31153107], [72.9659729, 18.31153107], [72.9659729, 18.31180954], [72.96541595, 18.31180573], [72.96541595, 18.3120842], [72.9651413, 18.31208038], [72.9651413, 18.31236267], [72.96485901, 18.31236267], [72.96485901, 18.31264114], [72.96458435, 18.31263924], [72.96458435, 18.3129158], [72.96430206, 18.3129158], [72.96430206, 18.31319427], [72.96263885, 18.31319427], [72.96263885, 18.3129158], [72.9623642, 18.3129158], [72.9623642, 18.3120842], [72.96180725, 18.3120842], [72.96180725, 18.31180573], [72.96125031, 18.31180954], [72.96125031, 18.3116703], [72.96125031, 18.31152725], [72.95986176, 18.31153107], [72.95986176, 18.31125259], [72.9595871, 18.31125259], [72.9595871, 18.31153107], [72.95903015, 18.31153107], [72.95903015, 18.31180954], [72.95874786, 18.31180954], [72.95874786, 18.31236267], [72.95847321, 18.31236267], [72.95847321, 18.31264114], [72.95819092, 18.31263924], [72.95819092, 18.3129158], [72.95791626, 18.3129158], [72.95791626, 18.31319427], [72.9576416, 18.31319427], [72.9576416, 18.31347275], [72.95735931, 18.31347275], [72.95735931, 18.31402969], [72.9570694, 18.31402969], [72.9570694, 18.31431007], [72.95680237, 18.31430626], [72.95680237, 18.31458473], [72.95652771, 18.31458473], [72.95652771, 18.3148613], [72.95625305, 18.31485939], [72.95625305, 18.31513977], [72.95597076, 18.31513977], [72.95597076, 18.31569481], [72.95569611, 18.31569481], [72.95569611, 18.31597137], [72.95540619, 18.31596947], [72.95540619, 18.31653023], [72.95569611, 18.31652832], [72.95569611, 18.31736183], [72.95597076, 18.31735992], [72.95597076, 18.31792068], [72.95625305, 18.31792068], [72.95625305, 18.31820107], [72.95680237, 18.31819534], [72.95680237, 18.31847191], [72.95735931, 18.31847], [72.95735931, 18.31875038], [72.95791626, 18.31875038], [72.95791626, 18.31903076], [72.95819092, 18.31902695], [72.95819092, 18.31958389], [72.95847321, 18.31958008], [72.95847321, 18.31986046], [72.95874786, 18.31986046], [72.95874786, 18.31958008], [72.95930481, 18.31958389], [72.95930481, 18.31930542], [72.96097565, 18.31930542], [72.96097565, 18.31958389], [72.96069336, 18.31958008], [72.96069336, 18.31986046], [72.9604187, 18.31986046], [72.9604187, 18.32014084], [72.96012878, 18.32014084], [72.96012878, 18.32042122], [72.95986176, 18.32041931], [72.95986176, 18.32069397], [72.9595871, 18.32069397], [72.9595871, 18.32097244], [72.95929718, 18.32097054], [72.95929718, 18.32125092], [72.95903015, 18.32125092], [72.95903015, 18.32152748], [72.95874786, 18.32152748], [72.95874786, 18.32180977], [72.95847321, 18.32180595], [72.95847321, 18.32208252], [72.95819092, 18.32208061], [72.95819092, 18.32263756], [72.95791626, 18.32263756], [72.95791626, 18.32291985], [72.9576416, 18.32291603], [72.9576416, 18.3231945], [72.95735931, 18.32319069], [72.95735931, 18.32375145], [72.95680237, 18.32375145], [72.95680237, 18.3243103], [72.95652771, 18.32430649], [72.95652771, 18.32458115], [72.95625305, 18.32457924], [72.95625305, 18.32514191], [72.95597076, 18.32514191], [72.95597076, 18.32570267], [72.95569611, 18.32569504], [72.95569611, 18.3259697], [72.95540619, 18.3259697], [72.95540619, 18.32653046], [72.95513916, 18.32653046], [72.95513916, 18.32681084], [72.9548645, 18.32680511], [72.9548645, 18.3279171], [72.95458221, 18.3279171], [72.95458221, 18.32819366], [72.95432281, 18.32818985], [72.95432281, 18.32903099], [72.95402527, 18.32902718], [72.95402527, 18.32958412], [72.95375061, 18.32958031], [72.95375061, 18.33014107], [72.95347595, 18.33013916], [72.95347595, 18.3306942], [72.95318604, 18.33069038], [72.95318604, 18.33152962], [72.95291901, 18.33152962], [72.95291901, 18.33374977], [72.95263672, 18.33374977], [72.95263672, 18.33403969], [72.95207977, 18.33402634], [72.95207977, 18.33430481], [72.95180511, 18.33430481], [72.95180511, 18.33486176], [72.95153046, 18.33485985], [72.95153046, 18.33513832], [72.95096588, 18.33513832], [72.95096588, 18.3362484], [72.95069122, 18.3362484], [72.95069122, 18.33653069], [72.95041656, 18.33653069], [72.95041656, 18.33680916], [72.95014191, 18.33680534], [72.95014191, 18.33708382], [72.94985962, 18.33707809], [72.94985962, 18.33735847], [72.94957733, 18.33735847], [72.94957733, 18.33764076], [72.94902802, 18.33764076], [72.94902802, 18.33792114], [72.94875336, 18.33791733], [72.94875336, 18.33819389], [72.94763947, 18.33819389], [72.94763947, 18.33847237], [72.94680786, 18.33847237], [72.94680786, 18.33875275], [72.94625092, 18.33875275], [72.94625092, 18.33903122], [72.94568634, 18.33903122], [72.94568634, 18.33930969], [72.94541931, 18.33930588], [72.94541931, 18.34069443], [72.94512939, 18.34069061], [72.94512939, 18.34152985], [72.94431305, 18.34152985], [72.94431305, 18.34181023], [72.94403076, 18.34180641], [72.94403076, 18.34236145], [72.94374847, 18.34235954], [72.94374847, 18.34263992], [72.94347382, 18.34263802], [72.94347382, 18.34291649], [72.94291687, 18.34291077], [72.94291687, 18.34320068], [72.94235992, 18.34319305], [72.94235992, 18.34347153], [72.94208527, 18.34347153], [72.9420929, 18.34375], [72.94152832, 18.34375], [72.94152832, 18.34403038], [72.94069672, 18.34403038], [72.94069672, 18.34431076], [72.93958282, 18.34431076], [72.93958282, 18.34403038], [72.9393158, 18.34403038], [72.9393158, 18.34346962], [72.93902588, 18.34347153], [72.93902588, 18.34319305], [72.93875122, 18.34320068], [72.93875122, 18.34263992], [72.93819427, 18.34263802], [72.93819427, 18.34291649], [72.93763733, 18.34291077], [72.93763733, 18.34320068], [72.93736267, 18.34319305], [72.93736267, 18.34347153], [72.93624878, 18.34347153], [72.93624878, 18.34319305], [72.93596649, 18.34320068], [72.93596649, 18.34291077], [72.93569183, 18.34291649], [72.93569183, 18.34263802], [72.93458557, 18.34263802], [72.93458557, 18.34291649], [72.93402863, 18.34291649], [72.93402863, 18.34458351], [72.93430328, 18.3445797], [72.93430328, 18.34514046], [72.93458557, 18.34513855], [72.93458557, 18.34569359], [72.93486023, 18.34568977], [72.93486023, 18.34597969], [72.93514252, 18.34597969], [72.93514252, 18.34653091], [72.93541718, 18.34652519], [72.93541718, 18.34708405], [72.93569183, 18.34708023], [72.93569183, 18.34763908], [72.93597412, 18.34763718], [72.93597412, 18.34819412], [72.93624878, 18.34819031], [72.93624878, 18.34874916], [72.93596649, 18.34874916], [72.93596649, 18.34930992], [72.93569183, 18.34930611], [72.93569183, 18.34958267], [72.93514252, 18.34958076], [72.93514252, 18.34985924], [72.93486023, 18.34985924], [72.93486023, 18.35014153], [72.93458557, 18.35014153], [72.93458557, 18.35069466], [72.93430328, 18.35069466], [72.93430328, 18.35097313], [72.93208313, 18.35097313], [72.93208313, 18.35041618], [72.93180847, 18.35042191], [72.93180847, 18.35014153], [72.93152618, 18.35014153], [72.93152618, 18.34985924], [72.93125153, 18.34985924], [72.93125153, 18.34958076], [72.93041992, 18.34958076], [72.93041992, 18.34985924], [72.92903137, 18.34985924], [72.92903137, 18.34958076], [72.92847443, 18.34958267], [72.92847443, 18.34930611], [72.92680359, 18.34930611], [72.92680359, 18.34958267], [72.92624664, 18.34958076], [72.92624664, 18.34985924], [72.92597198, 18.34985924], [72.92597198, 18.35014153], [72.92542267, 18.35014153], [72.92542267, 18.35042191], [72.92430878, 18.35042191], [72.92430878, 18.35014153], [72.92457581, 18.35014153], [72.92457581, 18.34985924], [72.92430878, 18.34985924], [72.92430878, 18.34958076], [72.92402649, 18.34958267], [72.92402649, 18.34930611], [72.92318726, 18.34930992], [72.92318726, 18.34903908], [72.92208099, 18.34903908], [72.92208099, 18.34819031], [72.92236328, 18.34819412], [72.92236328, 18.34763718], [72.92208099, 18.34763908], [72.92208099, 18.34736061], [72.92180634, 18.34736061], [72.92180634, 18.34708023], [72.92152405, 18.34708405], [72.92152405, 18.34680557], [72.91986084, 18.34680557], [72.91986084, 18.34708405], [72.91929626, 18.34708023], [72.91929626, 18.34736061], [72.91902924, 18.34736061], [72.91902924, 18.34763908], [72.91847229, 18.34763908], [72.91847229, 18.34791946], [72.91791534, 18.34791946], [72.91791534, 18.34819412], [72.91764069, 18.34819412], [72.91764069, 18.3484726], [72.9173584, 18.34847069], [72.9173584, 18.34903908], [72.91708374, 18.34902763], [72.91708374, 18.35069466], [72.91680908, 18.35069084], [72.91680908, 18.3512516], [72.91652679, 18.3512516], [72.91652679, 18.35180473], [72.91625214, 18.35180473], [72.91625214, 18.35236168], [72.91596985, 18.35236168], [72.91596985, 18.35292053], [72.91570282, 18.35292053], [72.91570282, 18.35320282], [72.9154129, 18.35319519], [72.9154129, 18.35347366], [72.91513824, 18.35347366], [72.91514587, 18.35375023], [72.91485596, 18.35375023], [72.91485596, 18.35403061], [72.9145813, 18.3540287], [72.9145813, 18.35458374], [72.91430664, 18.35458374], [72.91430664, 18.35486031], [72.91401672, 18.35485268], [72.91401672, 18.35542107], [72.91430664, 18.35542107], [72.91430664, 18.35625076], [72.9145813, 18.35625076], [72.9145813, 18.35736084], [72.91486359, 18.35736084], [72.91486359, 18.35819435], [72.9145813, 18.35819054], [72.9145813, 18.35902977], [72.91430664, 18.35902977], [72.91430664, 18.35931015], [72.91402435, 18.35930634], [72.91402435, 18.3595829], [72.91374969, 18.3595829], [72.91374969, 18.35986137], [72.91348267, 18.35985947], [72.91348267, 18.36013985], [72.91319275, 18.36013985], [72.91319275, 18.36042023], [72.91291809, 18.36041641], [72.91291809, 18.36069489], [72.91236115, 18.36069107], [72.91236115, 18.36097908], [72.91208649, 18.36097908], [72.91208649, 18.3615303], [72.9118042, 18.36152649], [72.91179657, 18.3631897], [72.91152954, 18.36319923], [72.91152954, 18.36514282], [72.91124725, 18.36514282], [72.91124725, 18.36680984], [72.91152954, 18.36680984], [72.91152954, 18.36736107], [72.91179657, 18.36736107], [72.91179657, 18.36791992], [72.91208649, 18.36791611], [72.91208649, 18.36847305], [72.91236115, 18.36847115], [72.91236115, 18.36874962], [72.9126358, 18.36874962], [72.9126358, 18.36903], [72.91291809, 18.36902809], [72.91291809, 18.36958313], [72.91319275, 18.36958313], [72.91319275, 18.3698616], [72.91348267, 18.3698597], [72.91348267, 18.37014961], [72.91374969, 18.37014961], [72.91374969, 18.37042046], [72.91430664, 18.37042046], [72.91430664, 18.37070084], [72.9145813, 18.37069511], [72.9145813, 18.37097168], [72.91513824, 18.37097168], [72.91513824, 18.37125015], [72.9154129, 18.37125015], [72.9154129, 18.37153053], [72.91596985, 18.37153053], [72.91596985, 18.37181091], [72.91625214, 18.37180519], [72.91625214, 18.37208366], [72.91680908, 18.37207985], [72.91680908, 18.37264061], [72.91764069, 18.37264061], [72.91764069, 18.37207985], [72.91791534, 18.37208366], [72.91791534, 18.37180519], [72.91958618, 18.37180519], [72.91958618, 18.37208366], [72.9201355, 18.37208366], [72.9201355, 18.37236023], [72.92069244, 18.37236023], [72.92069244, 18.37264061], [72.92124939, 18.37264061], [72.92124939, 18.37292099], [72.92152405, 18.37291527], [72.92152405, 18.37319374], [72.92208099, 18.37319374], [72.92208099, 18.37347221], [72.92236328, 18.37347031], [72.92236328, 18.37375069], [72.92318726, 18.37375069], [72.92318726, 18.37347031], [72.92375183, 18.37347221], [72.92375183, 18.37319374], [72.92402649, 18.37319374], [72.92402649, 18.37347221], [72.92430878, 18.37347221], [72.92430878, 18.37319374], [72.92485809, 18.37319374], [72.92485809, 18.37291527], [72.92624664, 18.37291527], [72.92624664, 18.37319374], [72.92597198, 18.37319374], [72.92597198, 18.37347221], [72.92514038, 18.37347031], [72.92514038, 18.37375069], [72.92457581, 18.37375069], [72.92457581, 18.37403107], [72.92485809, 18.37403107], [72.92485809, 18.37430954], [72.92458344, 18.37430573], [72.92458344, 18.37569427], [72.92485809, 18.37569046], [72.92485809, 18.37681007], [72.92514038, 18.37681007], [72.92514038, 18.37792015], [72.92541504, 18.37791634], [72.92541504, 18.37875175], [72.92569733, 18.37875175], [72.92569733, 18.3801403], [72.92597198, 18.3801403], [72.92597198, 18.38125038], [72.92624664, 18.38125038], [72.92624664, 18.38264084], [72.92597198, 18.38264084], [72.92597198, 18.38292122], [72.92624664, 18.38292122], [72.92624664, 18.38652992], [72.92597198, 18.38652992], [72.92597198, 18.38792038], [72.92569733, 18.38791656], [72.92569733, 18.3884716], [72.92542267, 18.3884697], [72.92542267, 18.38931084], [72.92514038, 18.38931084], [72.92514038, 18.39014053], [72.92485809, 18.39014053], [72.92485809, 18.39069366], [72.92457581, 18.39068985], [72.92457581, 18.3912487], [72.92430878, 18.3912487], [72.92430878, 18.3915329], [72.92402649, 18.39152718], [72.92402649, 18.39208412], [72.92346954, 18.39208031], [72.92346954, 18.39236259], [72.92292023, 18.39236259], [72.92292023, 18.39264107], [72.92208099, 18.39264107], [72.92208099, 18.39291954], [72.92124939, 18.39291763], [72.92124939, 18.3931942], [72.9173584, 18.3931942], [72.9173584, 18.39291763], [72.91707611, 18.39291954], [72.91707611, 18.39236259], [72.91596985, 18.39236259], [72.91596985, 18.39291954], [72.9154129, 18.39291763], [72.9154129, 18.39347267], [72.91514587, 18.39347267], [72.91514587, 18.39375114], [72.91430664, 18.39375114], [72.91430664, 18.39319038], [72.91343689, 18.3931942], [72.91319275, 18.3931942], [72.91319275, 18.39347267], [72.91308594, 18.39347267], [72.91291809, 18.39347267], [72.91291809, 18.39361191], [72.91291809, 18.39375114], [72.91274261, 18.39375114], [72.9126358, 18.39375114], [72.9126358, 18.39402962], [72.91236877, 18.39404106], [72.91236115, 18.39431953], [72.91208649, 18.39431953], [72.91208649, 18.39513969], [72.91236115, 18.39513969], [72.91236115, 18.39653015], [72.91208649, 18.39653015], [72.91208649, 18.39709091], [72.91179657, 18.39709091], [72.91179657, 18.39764023], [72.91152954, 18.39764023], [72.91152954, 18.39792061], [72.91124725, 18.39792061], [72.91124725, 18.39820099], [72.9109726, 18.39819527], [72.9109726, 18.39847183], [72.91069794, 18.39846992], [72.91069794, 18.39875031], [72.90901947, 18.39875031], [72.90901947, 18.39903069], [72.90875244, 18.39903069], [72.90875244, 18.39931107], [72.90847015, 18.39931107], [72.90847015, 18.39986038], [72.90820313, 18.39986038], [72.90820313, 18.40042114], [72.90847015, 18.40041733], [72.90847015, 18.40097237], [72.90875244, 18.40097046], [72.90875244, 18.40153122], [72.90901947, 18.40153122], [72.90901947, 18.40180969], [72.90875244, 18.40180588], [72.90875244, 18.40208244], [72.90847015, 18.40208054], [72.90847015, 18.40236092], [72.9081955, 18.40236092], [72.90820313, 18.40263748], [72.90652466, 18.40263748], [72.90652466, 18.4034729], [72.90680695, 18.40346909], [72.90680695, 18.40403175], [72.90763855, 18.40403175], [72.90763855, 18.40431023], [72.90820313, 18.40431023], [72.90820313, 18.40570068], [72.90735626, 18.40570068], [72.90735626, 18.40681076], [72.90763855, 18.40681076], [72.90763855, 18.40903091], [72.90736389, 18.4090271], [72.90736389, 18.40958595], [72.9070816, 18.40958023], [72.9070816, 18.40986061], [72.90680695, 18.40986061], [72.90680695, 18.41014099], [72.90569305, 18.41014099], [72.90569305, 18.41152954], [72.9070816, 18.41152763], [72.9070816, 18.41430473], [72.90736389, 18.41430473], [72.90736389, 18.41458321], [72.90763855, 18.41457939], [72.90763855, 18.41570091], [72.90736389, 18.41569519], [72.90736389, 18.41597176], [72.90680695, 18.41596985], [72.90680695, 18.41624832], [72.90651703, 18.41624832], [72.90651703, 18.41680908], [72.90625, 18.41680908], [72.90625, 18.4173584], [72.90651703, 18.4173584], [72.90651703, 18.41764069], [72.90680695, 18.41764069], [72.90680695, 18.4173584], [72.9070816, 18.4173584], [72.9070816, 18.41764069], [72.90763855, 18.41764069], [72.90763855, 18.41819954], [72.90791321, 18.41819382], [72.90791321, 18.41847038], [72.90820313, 18.41847038], [72.90820313, 18.41903114], [72.90847015, 18.41903114], [72.90847015, 18.41986275], [72.90875244, 18.41986275], [72.90875244, 18.42069435], [72.90901947, 18.42069054], [72.90901947, 18.42181015], [72.90875244, 18.42180634], [72.90875244, 18.42236137], [72.90847015, 18.42236137], [72.90847015, 18.42319489], [72.9081955, 18.42319489], [72.90820313, 18.42374992], [72.90735626, 18.42374992], [72.90735626, 18.4240303], [72.9070816, 18.4240303], [72.9070816, 18.42432022], [72.90680695, 18.42430687], [72.90680695, 18.42458344], [72.90651703, 18.42457962], [72.90651703, 18.42514038], [72.90625, 18.42513847], [72.90625, 18.4256897], [72.90598297, 18.42570114], [72.90598297, 18.42681122], [72.90569305, 18.42681122], [72.90569305, 18.42736053], [72.9054184, 18.42736053], [72.9054184, 18.42764091], [72.90486145, 18.42764091], [72.90486145, 18.42791748], [72.9043045, 18.42791748], [72.9043045, 18.42819405], [72.90402985, 18.42819023], [72.90402985, 18.43014145], [72.9043045, 18.43014145], [72.9043045, 18.43069458], [72.90458679, 18.43069458], [72.90458679, 18.43097305], [72.90486145, 18.43096924], [72.90486145, 18.43125153], [72.90513611, 18.43125153], [72.90513611, 18.43151093], [72.90513611, 18.43180466], [72.90569305, 18.43180466], [72.90569305, 18.43208122], [72.9061203, 18.43207932], [72.90625, 18.43207932], [72.90625, 18.43292046], [72.90651703, 18.43292046], [72.90651703, 18.43514061], [72.90625, 18.43514061], [72.90625, 18.43653107], [72.90597534, 18.43652725], [72.90598297, 18.43736076], [72.90569305, 18.43736076], [72.90569305, 18.43902969], [72.9054184, 18.43902779], [72.9054184, 18.44097137], [72.90513611, 18.44096947], [72.90513611, 18.44152832], [72.90486145, 18.44152641], [72.90486145, 18.44208336], [72.90458679, 18.44207954], [72.90458679, 18.44292068], [72.9043045, 18.44291687], [72.9043045, 18.44347191], [72.90402985, 18.44346809], [72.90402985, 18.44374847], [72.90374756, 18.44374847], [72.90374756, 18.44403076], [72.9034729, 18.44402695], [72.9034729, 18.44597244], [72.90319824, 18.44597244], [72.90320587, 18.44625282], [72.90291595, 18.44625282], [72.90291595, 18.44652939], [72.9026413, 18.44652748], [72.9026413, 18.44708061], [72.90235901, 18.44708061], [72.90235901, 18.4481945], [72.90207672, 18.44818115], [72.90207672, 18.44902992], [72.90180206, 18.44902802], [72.90180206, 18.44958305], [72.9015274, 18.44958115], [72.9015274, 18.45014], [72.90125275, 18.45014], [72.90125275, 18.45153046], [72.90097046, 18.45153046], [72.90097046, 18.45181084], [72.9006958, 18.45180511], [72.9006958, 18.45236206], [72.90041351, 18.45236206], [72.90041351, 18.45319366], [72.90014648, 18.45318985], [72.90014648, 18.45403099], [72.89985657, 18.45403099], [72.89985657, 18.45486069], [72.89958191, 18.45486069], [72.89958191, 18.45541954], [72.89930725, 18.45541954], [72.89930725, 18.4556942], [72.89902496, 18.4556942], [72.89902496, 18.45597267], [72.89875031, 18.45597076], [72.89875031, 18.45624924], [72.89848328, 18.45624924], [72.89848328, 18.4568119], [72.89819336, 18.45680618], [72.89819336, 18.45708275], [72.8979187, 18.45708084], [72.8979187, 18.45737267], [72.89763641, 18.45737267], [72.89763641, 18.45792007], [72.89624786, 18.45792007], [72.89624786, 18.4576416], [72.89569092, 18.4576416], [72.89569092, 18.45737267], [72.89541626, 18.45737267], [72.89541626, 18.45708084], [72.89458466, 18.45708275], [72.89458466, 18.45819473], [72.89485931, 18.45819092], [72.89485931, 18.46375084], [72.8951416, 18.46375084], [72.8951416, 18.46486092], [72.89541626, 18.46486092], [72.89541626, 18.4679203], [72.89569092, 18.46791649], [72.89569092, 18.47097015], [72.89541626, 18.47096825], [72.89541626, 18.4726429], [72.89597321, 18.4726429], [72.89597321, 18.47291946], [72.89624786, 18.47291756], [72.89624786, 18.47319412], [72.89680481, 18.47319412], [72.89680481, 18.47291756], [72.89707947, 18.47291946], [72.89707947, 18.4726429], [72.89736176, 18.4726429], [72.89736176, 18.47237015], [72.89819336, 18.47237015], [72.89819336, 18.4726429], [72.89848328, 18.4726429], [72.89848328, 18.47291946], [72.89902496, 18.47291756], [72.89902496, 18.47319412], [72.89958191, 18.47319412], [72.89958191, 18.4734726], [72.89985657, 18.4734726], [72.89985657, 18.47402954], [72.90013885, 18.47402763], [72.90013885, 18.47458458], [72.90041351, 18.47458458], [72.90041351, 18.47569466], [72.9006958, 18.47569084], [72.9006958, 18.47624969], [72.90125275, 18.47624969], [72.90125275, 18.47820091], [72.90097046, 18.47820091], [72.90097046, 18.47875023], [72.90125275, 18.47875023], [72.90125275, 18.47903061], [72.90097046, 18.4790287], [72.90097046, 18.47958374], [72.90125275, 18.47957993], [72.90125275, 18.47986031], [72.9015274, 18.47986031], [72.9015274, 18.48291969], [72.90125275, 18.48291969], [72.90125275, 18.48764038], [72.90097046, 18.48764038], [72.90097046, 18.48792076], [72.9006958, 18.48792076], [72.9006958, 18.48986053], [72.90097046, 18.48986053], [72.90097046, 18.49097252], [72.90125275, 18.49097252], [72.90125275, 18.4920826], [72.9015274, 18.49208069], [72.9015274, 18.49291992], [72.90180206, 18.49291992], [72.90180206, 18.49348068], [72.90291595, 18.49348068], [72.90291595, 18.49374962], [72.90319824, 18.49374962], [72.90319824, 18.49430466], [72.9034729, 18.49430466], [72.9034729, 18.49458313], [72.90374756, 18.49458122], [72.90374756, 18.49570084], [72.90402985, 18.49570084], [72.90402985, 18.49791908], [72.90374756, 18.49791908], [72.90374756, 18.49875259], [72.9034729, 18.49875259], [72.9034729, 18.49930954], [72.90374756, 18.49930954], [72.90374756, 18.49986267], [72.90402985, 18.49986267], [72.90402985, 18.50152969], [72.9043045, 18.50152779], [72.9043045, 18.50208473], [72.90458679, 18.50208282], [72.90458679, 18.50263977], [72.90486145, 18.50263977], [72.90486145, 18.50292015], [72.90513611, 18.50291634], [72.90513611, 18.50319481], [72.9054184, 18.50319481], [72.9054184, 18.50347137], [72.90597534, 18.50347137], [72.90597534, 18.50374985], [72.90625, 18.50374985], [72.90625, 18.50403023], [72.90763855, 18.50403023], [72.90763855, 18.5031929], [72.9090271, 18.50319481], [72.9090271, 18.50347137], [72.9098587, 18.50347137], [72.9098587, 18.50291634], [72.91069794, 18.50291634], [72.91069794, 18.50319481], [72.91124725, 18.5031929], [72.91124725, 18.50403023], [72.90958405, 18.50402832], [72.90958405, 18.50430679], [72.9098587, 18.50430679], [72.9098587, 18.50458336], [72.91069794, 18.50457954], [72.91069794, 18.5051403], [72.9109726, 18.5051403], [72.9109726, 18.50570107], [72.91124725, 18.50570107], [72.91124725, 18.50930977], [72.9109726, 18.50930977], [72.9109726, 18.51014137], [72.91069794, 18.51014137], [72.91069794, 18.51097107], [72.91041565, 18.51097107], [72.91042328, 18.51180077], [72.91069794, 18.5118103], [72.91069794, 18.51264191], [72.91042328, 18.51264191], [72.91042328, 18.51292038], [72.91014099, 18.51292038], [72.91014099, 18.51320076], [72.91041565, 18.51319504], [72.91041565, 18.51486015], [72.91069794, 18.51486206], [72.91069794, 18.51569366], [72.9109726, 18.51568985], [72.9109726, 18.51653099], [72.91124725, 18.51652718], [72.91124725, 18.5181942], [72.9109726, 18.5181942], [72.9109726, 18.51958275], [72.91124725, 18.51958084], [72.91124725, 18.52124977], [72.9109726, 18.52124977], [72.9109726, 18.52180481], [72.91069794, 18.52180099], [72.91069794, 18.52292061], [72.9109726, 18.52292061], [72.9109726, 18.52319908], [72.91124725, 18.52319527], [72.91124725, 18.52347183], [72.9109726, 18.52347183], [72.9109726, 18.52458382], [72.91069794, 18.52457809], [72.91069794, 18.52542114], [72.91014099, 18.52541733], [72.91014099, 18.52708054], [72.9098587, 18.52708054], [72.9098587, 18.52791977], [72.90957642, 18.52791977], [72.90957642, 18.52902985], [72.90930939, 18.52902985], [72.90930176, 18.53013992], [72.90901947, 18.53013992], [72.90901947, 18.5304203], [72.90875244, 18.53041649], [72.90875244, 18.53097153], [72.90847015, 18.53096962], [72.90847015, 18.53181076], [72.9081955, 18.53180695], [72.9081955, 18.53208351], [72.90791321, 18.53208351], [72.90791321, 18.53236198], [72.90763855, 18.53236008], [72.90763855, 18.53292084], [72.9070816, 18.53291512], [72.9070816, 18.53319359], [72.90736389, 18.53319359], [72.90736389, 18.53347206], [72.9070816, 18.53347015], [72.9070816, 18.53403091], [72.90680695, 18.5340271], [72.90680695, 18.53458405], [72.90651703, 18.53458023], [72.90651703, 18.53513908], [72.90625, 18.53513908], [72.90625, 18.53652763], [72.90598297, 18.53652763], [72.90598297, 18.53681183], [72.90458679, 18.53681183], [72.90458679, 18.53735924], [72.9043045, 18.53735924], [72.9043045, 18.53847313], [72.90458679, 18.53847313], [72.90458679, 18.53930473], [72.90513611, 18.53930473], [72.90513611, 18.5395813], [72.9054184, 18.53957939], [72.9054184, 18.54014015], [72.90569305, 18.54013824], [72.90569305, 18.54097366], [72.90625, 18.54096985], [72.90625, 18.54125023], [72.9070816, 18.54125023], [72.9070816, 18.54096985], [72.90736389, 18.54097366], [72.90736389, 18.54069519], [72.90763855, 18.54070282], [72.90763855, 18.54014015], [72.90791321, 18.54014015], [72.90791321, 18.53957939], [72.9081955, 18.5395813], [72.9081955, 18.53902817], [72.90847015, 18.53903008], [72.90847015, 18.5387516], [72.90875244, 18.5387516], [72.90875244, 18.53819084], [72.9090271, 18.53819466], [72.9090271, 18.53764153], [72.90930176, 18.53764153], [72.90930176, 18.53735924], [72.90957642, 18.53735924], [72.90957642, 18.53624916], [72.9098587, 18.53624916], [72.9098587, 18.53541756], [72.91014099, 18.53541756], [72.91014099, 18.53486061], [72.91042328, 18.53486061], [72.91041565, 18.53375053], [72.91069794, 18.53375053], [72.91069794, 18.53153038], [72.9109726, 18.53153038], [72.9109726, 18.53096962], [72.91124725, 18.53097153], [72.91124725, 18.53041649], [72.91152954, 18.5304203], [72.91152954, 18.53013992], [72.91208649, 18.53013992], [72.91208649, 18.52985954], [72.91402435, 18.52986145], [72.91402435, 18.52958488], [72.9145813, 18.52959061], [72.9145813, 18.52931023], [72.91514587, 18.52931023], [72.91514587, 18.52902985], [72.91654968, 18.52902985], [72.9173584, 18.52902985], [72.9173584, 18.52931023], [72.91764069, 18.52931023], [72.91764069, 18.52959061], [72.91791534, 18.52958488], [72.91791534, 18.52986145], [72.91847229, 18.52985954], [72.91847229, 18.53013992], [72.91874695, 18.53013992], [72.91874695, 18.5304203], [72.91902924, 18.5304203], [72.91902924, 18.53070068], [72.91930389, 18.53069305], [72.91930389, 18.53097153], [72.91986084, 18.53096962], [72.91986084, 18.53125], [72.92124939, 18.53125], [72.92124939, 18.53153038], [72.92236328, 18.53153038], [72.92236328, 18.53181076], [72.92263794, 18.53180695], [72.92263794, 18.53208351], [72.92292023, 18.53208351], [72.92292023, 18.53236198], [72.92318726, 18.53236008], [72.92318726, 18.53264809], [72.92345428, 18.53270531], [72.92346954, 18.53292084], [72.92458344, 18.53291512], [72.92458344, 18.53319359], [72.92485809, 18.53319359], [72.92485809, 18.53347206], [72.92514038, 18.53347015], [72.92514038, 18.53375053], [72.92624664, 18.53375053], [72.92624664, 18.53403091], [72.92652893, 18.53403091], [72.92652893, 18.53430939], [72.92679596, 18.53430939], [72.92679596, 18.53486061], [72.92708588, 18.53486061], [72.92708588, 18.53513908], [72.92791748, 18.53513908], [72.92791748, 18.53541756], [72.92874908, 18.53541756], [72.92874908, 18.53569412], [72.9284668, 18.53569031], [72.9284668, 18.54181099], [72.92819214, 18.54180527], [72.92819214, 18.54208374], [72.92791748, 18.54207993], [72.92791748, 18.54236031], [72.92764282, 18.54236031], [72.92764282, 18.54264069], [72.92736053, 18.54264069], [72.92736053, 18.54292107], [72.92708588, 18.54291725], [72.92708588, 18.54319572], [72.92680359, 18.54319572], [72.92680359, 18.54347229], [72.92652893, 18.54347038], [72.92652893, 18.54375076], [72.92624664, 18.54375076], [72.92624664, 18.54403114], [72.92542267, 18.54403114], [72.92542267, 18.54430962], [72.92514038, 18.54430962], [72.92514038, 18.54486084], [72.92457581, 18.54486084], [72.92457581, 18.54514122], [72.92430878, 18.54514122], [72.92430878, 18.54652977], [72.92402649, 18.54652977], [72.92402649, 18.54764748], [72.92375183, 18.54764748], [72.92375183, 18.55013847], [72.92346954, 18.55013847], [72.92346954, 18.55181122], [72.92318726, 18.55181122], [72.92318726, 18.55236244], [72.92292023, 18.55236244], [72.92292023, 18.55291939], [72.92263794, 18.55291748], [72.92263794, 18.55347252], [72.92236328, 18.55347252], [72.92236328, 18.55402946], [72.92208099, 18.55402756], [72.92208099, 18.55458069], [72.92180634, 18.55458069], [72.92180634, 18.55513954], [72.92152405, 18.55513954], [72.92152405, 18.55569458], [72.92124939, 18.55569077], [72.92124939, 18.55653], [72.92097473, 18.55652809], [72.92097473, 18.5573616], [72.92069244, 18.5573597], [72.92069244, 18.55792046], [72.92041779, 18.55792046], [72.92041779, 18.55986023], [72.92014313, 18.55986023], [72.92014313, 18.56014061], [72.91986084, 18.56014061], [72.91986084, 18.56042099], [72.91958618, 18.56041527], [72.91958618, 18.56097221], [72.91929626, 18.56097031], [72.91929626, 18.56125069], [72.91902924, 18.56125069], [72.91902924, 18.56153107], [72.91874695, 18.56153107], [72.91874695, 18.56180954], [72.91847229, 18.56180954], [72.91847229, 18.56236076], [72.91819763, 18.56236076], [72.91819763, 18.56263733], [72.91791534, 18.56263733], [72.91791534, 18.56319427], [72.91764069, 18.56319427], [72.91764069, 18.56347275], [72.9173584, 18.56347084], [72.9173584, 18.5640316], [72.91707611, 18.5640316], [72.91707611, 18.56514168], [72.91680908, 18.56514168], [72.91680908, 18.56542015], [72.91652679, 18.56541634], [72.91652679, 18.56596947], [72.91625214, 18.56596947], [72.91625214, 18.56625175], [72.91596985, 18.56625175], [72.91596985, 18.56680489], [72.91569519, 18.56680489], [72.91569519, 18.56736374], [72.9154129, 18.56736183], [72.9154129, 18.5676403], [72.91514587, 18.5676403], [72.91514587, 18.56820107], [72.91485596, 18.56820107], [72.91485596, 18.56875992], [72.9145813, 18.56875038], [72.9145813, 18.5695858], [72.91430664, 18.56958008], [72.91430664, 18.57042122], [72.91402435, 18.5704174], [72.91402435, 18.57097244], [72.91374969, 18.57097054], [72.91374969, 18.57125092], [72.91348267, 18.57125092], [72.91348267, 18.57182121], [72.91319275, 18.57180405], [72.91319275, 18.57208252], [72.91291809, 18.57208061], [72.91291809, 18.57236099], [72.9126358, 18.57236099], [72.9126358, 18.57263947], [72.91236115, 18.57263947], [72.91236115, 18.5731945], [72.91208649, 18.5731945], [72.91208649, 18.57347298], [72.9118042, 18.57347298], [72.9118042, 18.57458305], [72.91152954, 18.5745697], [72.91152954, 18.57570076], [72.91124725, 18.57570076], [72.91124725, 18.57681084], [72.9109726, 18.57681084], [72.9109726, 18.57792091], [72.91069794, 18.5779171], [72.91069794, 18.57847023], [72.91041565, 18.57847023], [72.91042328, 18.57875252], [72.90930939, 18.57875252], [72.90930176, 18.57930946], [72.90901947, 18.57930946], [72.90901947, 18.57986259], [72.90875244, 18.57986259], [72.90875244, 18.58069992], [72.90847015, 18.58069992], [72.90847015, 18.58125114], [72.90820313, 18.58125114], [72.90820313, 18.58376122], [72.90847015, 18.58376122], [72.90847015, 18.58403015], [72.90875244, 18.58402824], [72.90875244, 18.58458328], [72.9090271, 18.58458328], [72.9090271, 18.58486176], [72.90930176, 18.58485985], [72.90930176, 18.58499908], [72.90930939, 18.58514023], [72.9098587, 18.58514023], [72.9098587, 18.58542061], [72.91014099, 18.58541679], [72.91014099, 18.58597183], [72.9098587, 18.58596992], [72.9098587, 18.58625031], [72.9081955, 18.58625031], [72.9081955, 18.58597183], [72.90763855, 18.58597183], [72.90763855, 18.58569527], [72.90735626, 18.58570099], [72.90735626, 18.58542061], [72.9070816, 18.58542061], [72.9070816, 18.58570099], [72.90652466, 18.58569527], [72.90652466, 18.58597183], [72.90625, 18.58596992], [72.90625, 18.58625031], [72.90569305, 18.58625031], [72.90569305, 18.58680534], [72.9054184, 18.58679962], [72.9054184, 18.58736038], [72.90513611, 18.58736038], [72.90513611, 18.58847237], [72.90486145, 18.58847046], [72.90486145, 18.58903122], [72.90458679, 18.58903122], [72.90458679, 18.58986092], [72.90429688, 18.58986092], [72.90429688, 18.59042168], [72.90402985, 18.59041595], [72.90402985, 18.59069443], [72.90374756, 18.59069061], [72.90374756, 18.59124947], [72.9034729, 18.59124947], [72.9034729, 18.59153175], [72.90320587, 18.59153175], [72.90320587, 18.59181023], [72.90291595, 18.59181023], [72.90291595, 18.59264183], [72.9026413, 18.59264183], [72.9026413, 18.59320068], [72.90235901, 18.59320068], [72.90235901, 18.59403038], [72.90207672, 18.59403038], [72.90207672, 18.59431076], [72.90180206, 18.59430504], [72.90180206, 18.59597206], [72.9015274, 18.59597015], [72.9015274, 18.59625053], [72.90125275, 18.59625053], [72.90125275, 18.59653091], [72.90097046, 18.59653091], [72.90097046, 18.59736061], [72.9006958, 18.59736061], [72.9006958, 18.59819412], [72.90041351, 18.59819412], [72.90041351, 18.5984726], [72.90014648, 18.59847069], [72.90014648, 18.59902954], [72.89985657, 18.59902954], [72.89985657, 18.59986115], [72.89958191, 18.59986115], [72.89958191, 18.60124969], [72.89930725, 18.60124969], [72.89930725, 18.60152817], [72.89902496, 18.60152626], [72.89902496, 18.60180473], [72.89847565, 18.60180473], [72.89847565, 18.60236168], [72.89819336, 18.60235977], [72.89819336, 18.60320091], [72.8979187, 18.60319519], [72.8979187, 18.60347176], [72.89763641, 18.60346985], [72.89763641, 18.60403061], [72.89736176, 18.60403061], [72.89736176, 18.60487175], [72.89707947, 18.60487175], [72.89707947, 18.60542107], [72.89678955, 18.60542107], [72.89678955, 18.60625267], [72.89653015, 18.60625267], [72.89653015, 18.60653114], [72.89624786, 18.60653114], [72.89624786, 18.60680962], [72.89597321, 18.60680962], [72.89597321, 18.60736275], [72.89569092, 18.60736275], [72.89569092, 18.60819435], [72.89541626, 18.60819435], [72.89541626, 18.60847473], [72.8951416, 18.60847282], [72.8951416, 18.60902977], [72.89485931, 18.60902977], [72.89485931, 18.61042023], [72.89457703, 18.61042023], [72.89457703, 18.61124992], [72.89430237, 18.61124992], [72.89430237, 18.61208344], [72.89402771, 18.61208344], [72.89402771, 18.61236191], [72.89375305, 18.61236], [72.89375305, 18.61264038], [72.89347076, 18.61264038], [72.89347076, 18.61292076], [72.89319611, 18.61291695], [72.89319611, 18.61347198], [72.89291382, 18.61347198], [72.89291382, 18.61375046], [72.89263916, 18.61374092], [72.89263916, 18.61431122], [72.89235687, 18.61431122], [72.89235687, 18.61514091], [72.89208221, 18.61514091], [72.89208221, 18.61541748], [72.89180756, 18.61541748], [72.89180756, 18.61597252], [72.89125061, 18.61597061], [72.89125061, 18.61624908], [72.89097595, 18.61624908], [72.89097595, 18.61735916], [72.89068604, 18.61735916], [72.89068604, 18.61792183], [72.89041901, 18.61791611], [72.89041901, 18.61847115], [72.89013672, 18.61846924], [72.89013672, 18.61903191], [72.88986206, 18.61902809], [72.88986206, 18.61930466], [72.88931274, 18.61930084], [72.88931274, 18.61987114], [72.88874817, 18.61987114], [72.88874817, 18.62014008], [72.88846588, 18.62014008], [72.88846588, 18.62042046], [72.88819122, 18.62041664], [72.88819122, 18.62097359], [72.88791656, 18.62096977], [72.88791656, 18.62153053], [72.88764191, 18.62153053], [72.88764191, 18.62264061], [72.88735962, 18.6226387], [72.88735962, 18.62291718], [72.88707733, 18.62290955], [72.88707733, 18.62375069], [72.88680267, 18.62375069], [72.88680267, 18.6245842], [72.88652802, 18.62458038], [72.88652802, 18.62486076], [72.88625336, 18.62486076], [72.88625336, 18.62541962], [72.88597107, 18.6254158], [72.88597107, 18.62597275], [72.88569641, 18.62597084], [72.88569641, 18.62625122], [72.88540649, 18.62625122], [72.88540649, 18.62763977], [72.88513947, 18.62763977], [72.88513947, 18.62986183], [72.88484955, 18.62985992], [72.88484955, 18.63264275], [72.88458252, 18.63264084], [72.88458252, 18.63458061], [72.88430786, 18.63458061], [72.88430786, 18.63513947], [72.88402557, 18.63513947], [72.88402557, 18.6384716], [72.88486481, 18.6384716], [72.88486481, 18.63819695], [72.88735962, 18.63820076], [72.88735962, 18.63791084], [72.88791656, 18.63791656], [72.88791656, 18.63763809], [72.88846588, 18.63764], [72.88846588, 18.63735962], [72.88903046, 18.63736153], [72.88903046, 18.63708305], [72.89111328, 18.63708305], [72.89125061, 18.63708305], [72.89125061, 18.63652802], [72.8915329, 18.63652992], [72.8915329, 18.63624954], [72.89180756, 18.63624954], [72.89180756, 18.63597107], [72.89208221, 18.63597488], [72.89208221, 18.6356945], [72.89597321, 18.6356945], [72.89597321, 18.63541603], [72.89707947, 18.63541985], [72.89707947, 18.63484955], [72.89736176, 18.6348629], [72.89736176, 18.63430595], [72.89763641, 18.63430977], [72.89763641, 18.63375282], [72.8979187, 18.63375282], [72.8979187, 18.63257027], [72.8979187, 18.63208389], [72.89819336, 18.63208389], [72.89819336, 18.63041687], [72.89848328, 18.63042068], [72.89848328, 18.62957954], [72.89930725, 18.62958336], [72.89930725, 18.62986183], [72.90040588, 18.62985992], [72.90040588, 18.6301384], [72.9006958, 18.6301384], [72.9006958, 18.63069916], [72.90097046, 18.63069916], [72.90097046, 18.63124847], [72.90125275, 18.63124847], [72.90125275, 18.63181114], [72.9015274, 18.63181114], [72.9015274, 18.63236237], [72.90180206, 18.63236237], [72.90180206, 18.63264275], [72.9015274, 18.63264084], [72.9015274, 18.63319206], [72.90125275, 18.63319206], [72.90125275, 18.63347054], [72.90097046, 18.63347054], [72.90097046, 18.63402939], [72.9006958, 18.63402939], [72.9006958, 18.63430977], [72.90041351, 18.63430595], [72.90041351, 18.63458061], [72.90013885, 18.63458061], [72.90013885, 18.6348629], [72.89985657, 18.63484955], [72.89985657, 18.63513947], [72.89958191, 18.63513947], [72.89958191, 18.63541985], [72.89930725, 18.63541603], [72.89930725, 18.6356945], [72.89875031, 18.6356945], [72.89875031, 18.63597488], [72.89819336, 18.63597107], [72.89819336, 18.63624954], [72.89678955, 18.63624954], [72.89678955, 18.63652992], [72.89653015, 18.63652992], [72.89653015, 18.6368103], [72.89597321, 18.63680649], [72.89597321, 18.63708305], [72.89569092, 18.63708305], [72.89569092, 18.63736153], [72.8951416, 18.63735962], [72.8951416, 18.63764], [72.89430237, 18.63763809], [72.89430237, 18.63791656], [72.89375305, 18.63791656], [72.89375305, 18.63804054], [72.89375305, 18.63820076], [72.89291382, 18.63819695], [72.89291382, 18.6384716], [72.89235687, 18.6384697], [72.89235687, 18.63875008], [72.89180756, 18.63875008], [72.89180756, 18.63903046], [72.89125061, 18.63903046], [72.89125061, 18.63931084], [72.89069366, 18.63930511], [72.89069366, 18.63958359], [72.89013672, 18.63958359], [72.89013672, 18.63986206], [72.88957977, 18.63986015], [72.88957977, 18.64014053], [72.88903046, 18.64014053], [72.88903046, 18.64042091], [72.88847351, 18.64041519], [72.88847351, 18.64069366], [72.88791656, 18.64069366], [72.88791656, 18.64097214], [72.88735962, 18.64097023], [72.88735962, 18.64125061], [72.88430786, 18.64125061], [72.88430786, 18.64097023], [72.88375092, 18.64097214], [72.88375092, 18.64069366], [72.88346863, 18.64069366], [72.88346863, 18.64041519], [72.88291931, 18.64042091], [72.88291931, 18.63903046], [72.88273621, 18.63903046], [72.88263702, 18.63902855], [72.88263702, 18.63820076], [72.88236237, 18.63820076], [72.88236237, 18.63764], [72.88208008, 18.63764], [72.88208008, 18.63735962], [72.87763977, 18.63735962], [72.87763977, 18.63764], [72.87735748, 18.63763809], [72.87735748, 18.63791656], [72.87708282, 18.63791656], [72.87708282, 18.63763809], [72.87652588, 18.63763809], [72.87652588, 18.63791656], [72.87597656, 18.63791084], [72.87597656, 18.63820076], [72.87513733, 18.63819695], [72.87513733, 18.6384716], [72.87264252, 18.6384697], [72.87264252, 18.63875008], [72.8720932, 18.63875008], [72.8720932, 18.63903046], [72.87152863, 18.63903046], [72.87152863, 18.63931084], [72.87097168, 18.63930511], [72.87097168, 18.63958359], [72.8704071, 18.63957977], [72.8704071, 18.64014053], [72.87014008, 18.64013863], [72.87014008, 18.64097214], [72.86985016, 18.64097023], [72.86985016, 18.64152908], [72.86958313, 18.64152908], [72.86958313, 18.64236069], [72.86930847, 18.64236069], [72.86930847, 18.64291763], [72.86902618, 18.64291763], [72.86902618, 18.6431942], [72.86875153, 18.64319038], [72.86875153, 18.64374924], [72.86846924, 18.64374924], [72.86846924, 18.6443119], [72.86818695, 18.6443119], [72.86818695, 18.6451416], [72.86791992, 18.6451416], [72.86791992, 18.64542007], [72.86763763, 18.64541626], [72.86763763, 18.64596939], [72.86736298, 18.64596939], [72.86736298, 18.64625168], [72.86708069, 18.64625168], [72.86708069, 18.64653015], [72.86680603, 18.64652824], [72.86680603, 18.64708138], [72.86653137, 18.64707947], [72.86653137, 18.64764023], [72.86624908, 18.64764023], [72.86624908, 18.6482029], [72.8659668, 18.6482029], [72.8659668, 18.64903069], [72.86569214, 18.64903069], [72.86569214, 18.65014076], [72.86541748, 18.65014076], [72.86541748, 18.65153122], [72.86513519, 18.6515274], [72.86513519, 18.65291786], [72.86486053, 18.65291023], [72.86486053, 18.65402985], [72.86458588, 18.65402985], [72.86458588, 18.65513992], [72.86429596, 18.65513992], [72.86430359, 18.65624809], [72.86402893, 18.65624809], [72.86402893, 18.65736008], [72.86374664, 18.65736008], [72.86374664, 18.65847015], [72.86347198, 18.65847015], [72.86347198, 18.66069221], [72.86319733, 18.66069221], [72.86319733, 18.66347313], [72.86347198, 18.66347122], [72.86347198, 18.66542053], [72.86374664, 18.66542053], [72.86374664, 18.66681099], [72.86402893, 18.66680527], [72.86402893, 18.66736031], [72.86430359, 18.66736031], [72.86430359, 18.66819382], [72.86458588, 18.66819], [72.86458588, 18.66875076], [72.86429596, 18.66875076], [72.86429596, 18.66930962], [72.86402893, 18.6693058], [72.86403656, 18.66986084], [72.86374664, 18.66986084], [72.86374664, 18.6704216], [72.86347198, 18.6704216], [72.86347198, 18.67098045], [72.86319733, 18.67098045], [72.86319733, 18.67181015], [72.86292267, 18.67181015], [72.86292267, 18.67264175], [72.86264038, 18.67264175], [72.86264038, 18.67375183], [72.86235809, 18.67375183], [72.86235809, 18.67458344], [72.86207581, 18.67457962], [72.86207581, 18.67542076], [72.86180878, 18.67542076], [72.86180878, 18.67653084], [72.86152649, 18.67653084], [72.86152649, 18.67791939], [72.86125183, 18.67791748], [72.86125183, 18.6795826], [72.86096954, 18.67958069], [72.86096954, 18.68124962], [72.86067963, 18.68124962], [72.86067963, 18.68321037], [72.86042023, 18.68321037], [72.86042023, 18.6854229], [72.86013794, 18.6854229], [72.86013794, 18.68764114], [72.85986328, 18.68763924], [72.85986328, 18.68958473], [72.85958099, 18.68958473], [72.85958099, 18.69069481], [72.85930634, 18.69069099], [72.85930634, 18.69124985], [72.85902405, 18.69124985], [72.85902405, 18.69180679], [72.85874939, 18.69180679], [72.85874939, 18.69236183], [72.8584671, 18.69235992], [72.8584671, 18.69292068], [72.85819244, 18.69292068], [72.85819244, 18.69320107], [72.8576355, 18.69319534], [72.8576355, 18.69347191], [72.85736084, 18.69347], [72.85736084, 18.69375038], [72.85708618, 18.69375038], [72.85708618, 18.69403076], [72.85680389, 18.69402695], [72.85680389, 18.69458389], [72.85652924, 18.69458008], [72.85652924, 18.69486046], [72.85624695, 18.69486046], [72.85624695, 18.69514847], [72.85597229, 18.69513893], [72.85597229, 18.69569397], [72.85569763, 18.69569397], [72.85569763, 18.69597244], [72.85542297, 18.69597054], [72.85542297, 18.69680977], [72.85514069, 18.69680977], [72.85514069, 18.69735909], [72.85569763, 18.69735909], [72.85569763, 18.6981945], [72.85597229, 18.69819069], [72.85597229, 18.69903183], [72.85624695, 18.69902992], [72.85624695, 18.69958115], [72.85652924, 18.69957924], [72.85652924, 18.70042038], [72.85680389, 18.70041656], [72.85680389, 18.70097351], [72.85708618, 18.70097351], [72.85708618, 18.70069504], [72.85736084, 18.70069504], [72.85736084, 18.70097351], [72.85791016, 18.70096016], [72.85791016, 18.70153046], [72.85819244, 18.70152855], [72.85819244, 18.70208359], [72.8584671, 18.70207977], [72.8584671, 18.70264053], [72.85874939, 18.70263863], [72.85874939, 18.70319557], [72.85902405, 18.70319557], [72.85902405, 18.70347214], [72.85930634, 18.70347023], [72.85930634, 18.70403099], [72.85958099, 18.70402718], [72.85958099, 18.70458412], [72.85986328, 18.70458031], [72.85986328, 18.70514107], [72.86013794, 18.70513916], [72.86013794, 18.7056942], [72.86042023, 18.70569038], [72.86042023, 18.70709038], [72.86067963, 18.70709038], [72.86067963, 18.70874977], [72.86096954, 18.70874977], [72.86096954, 18.70958328], [72.86125183, 18.70957947], [72.86125183, 18.71042061], [72.86152649, 18.71042061], [72.86152649, 18.7112484], [72.86180878, 18.7112484], [72.86180878, 18.71236038], [72.86208344, 18.71236038], [72.86208344, 18.71347046], [72.86235809, 18.71347046], [72.86235809, 18.71458054], [72.86264038, 18.71458054], [72.86264038, 18.71569443], [72.86292267, 18.71569061], [72.86292267, 18.71681023], [72.86319733, 18.71681023], [72.86319733, 18.7179203], [72.86347198, 18.7179203], [72.86347198, 18.71903038], [72.86374664, 18.71903038], [72.86374664, 18.72014046], [72.86402893, 18.72013855], [72.86402893, 18.72125053], [72.86429596, 18.72125053], [72.86429596, 18.73180962], [72.86402893, 18.7318058], [72.86402893, 18.7345829], [72.86374664, 18.7345829], [72.86374664, 18.73569489], [72.86347198, 18.73569107], [72.86347198, 18.7365284], [72.86319733, 18.7365284], [72.86319733, 18.73763847], [72.86291504, 18.73763847], [72.86291504, 18.73847008], [72.86264038, 18.73846817], [72.86264038, 18.73931122], [72.86235809, 18.73931122], [72.86235809, 18.7432003], [72.86264038, 18.74319458], [72.86264038, 18.74430466], [72.86292267, 18.74430084], [72.86292267, 18.74542046], [72.86319733, 18.74542046], [72.86319733, 18.74653053], [72.86347198, 18.74653053], [72.86347198, 18.74764061], [72.86374664, 18.74764061], [72.86374664, 18.74875069], [72.86402893, 18.74875069], [72.86402893, 18.74930573], [72.86429596, 18.7492981], [72.86429596, 18.75013924], [72.86458588, 18.75013924], [72.86458588, 18.7515316], [72.86486053, 18.75152779], [72.86486053, 18.75319481], [72.86513519, 18.75319481], [72.86513519, 18.75458145], [72.86541748, 18.75457954], [72.86541748, 18.75543022], [72.86569214, 18.75543022], [72.86569214, 18.75625038], [72.8659668, 18.75625038], [72.8659668, 18.75681114], [72.86680603, 18.75681114], [72.86680603, 18.75653076], [72.86708069, 18.75653076], [72.86708069, 18.75570107], [72.86736298, 18.75570107], [72.86736298, 18.75543022], [72.86791992, 18.75543022], [72.86791992, 18.75570107], [72.86818695, 18.75570107], [72.86818695, 18.75625038], [72.86791992, 18.75625038], [72.86791992, 18.75653076], [72.86763763, 18.75653076], [72.86763763, 18.75681114], [72.86736298, 18.75680542], [72.86736298, 18.7570858], [72.86708069, 18.75708008], [72.86708069, 18.75764084], [72.86680603, 18.75764084], [72.86680603, 18.75875092], [72.86624908, 18.75875092], [72.86624908, 18.75930977], [72.86597443, 18.75930405], [72.86597443, 18.75958252], [72.86569214, 18.75958061], [72.86569214, 18.76013947], [72.86541748, 18.76013947], [72.86541748, 18.7606945], [72.86513519, 18.7606945], [72.86513519, 18.76124954], [72.86486053, 18.76124001], [72.86486053, 18.76263809], [72.86458588, 18.76263809], [72.86458588, 18.76320076], [72.86486053, 18.76319504], [72.86486053, 18.76458359], [72.86458588, 18.76457977], [72.86458588, 18.7665329], [72.86429596, 18.7665329], [72.86429596, 18.76737022], [72.86541748, 18.76736259], [72.86541748, 18.76819229], [72.86513519, 18.76819229], [72.86513519, 18.76847458], [72.86486053, 18.76847267], [72.86486053, 18.76875114], [72.86458588, 18.76875114], [72.86458588, 18.76902962], [72.86429596, 18.76902962], [72.86429596, 18.76931], [72.86402893, 18.76930618], [72.86402893, 18.76958466], [72.86374664, 18.76958084], [72.86374664, 18.77013969], [72.86347198, 18.77013969], [72.86347198, 18.77069473], [72.86319733, 18.77069092], [72.86319733, 18.77124977], [72.86347198, 18.77124977], [72.86347198, 18.77264023], [72.86319733, 18.77263832], [72.86319733, 18.77347183], [72.86347198, 18.77346992], [72.86347198, 18.77403069], [72.86319733, 18.77402687], [72.86319733, 18.77458382], [72.86347198, 18.77458], [72.86347198, 18.77792168], [72.86319733, 18.77791595], [72.86319733, 18.7784729], [72.86347198, 18.7784729], [72.86347198, 18.77985954], [72.86319733, 18.77985954], [72.86319733, 18.7804203], [72.86347198, 18.7804203], [72.86347198, 18.78125191], [72.86374664, 18.78125191], [72.86374664, 18.78181076], [72.86347198, 18.78181076], [72.86347198, 18.78403091], [72.86319733, 18.78403091], [72.86319733, 18.78486061], [72.86347198, 18.78486061], [72.86347198, 18.79124832], [72.86374664, 18.79124832], [72.86374664, 18.79347038], [72.86403656, 18.79347038], [72.86403656, 18.79430962], [72.86429596, 18.79430962], [72.86429596, 18.79541969], [72.86458588, 18.79541588], [72.86458588, 18.79597473], [72.86486053, 18.79597282], [72.86486053, 18.79652977], [72.86514282, 18.79652977], [72.86514282, 18.79681015], [72.86653137, 18.79680634], [72.86653137, 18.79708481], [72.86708069, 18.79708481], [72.86708069, 18.79736137], [72.86736298, 18.79734993], [72.86736298, 18.79792023], [72.86763763, 18.79792023], [72.86763763, 18.79874992], [72.86791992, 18.79874992], [72.86791992, 18.80014038], [72.86818695, 18.80014038], [72.86818695, 18.80181122], [72.86846924, 18.80181122], [72.86846924, 18.80236053], [72.86875153, 18.80236053], [72.86875153, 18.80374908], [72.86902618, 18.80374908], [72.86902618, 18.80431175], [72.86930847, 18.80430603], [72.86930847, 18.8045826], [72.86958313, 18.8045826], [72.86958313, 18.80430603], [72.87069702, 18.80431175], [72.87069702, 18.80403137], [72.87097168, 18.80403137], [72.87097168, 18.80347824], [72.87124634, 18.80347824], [72.87124634, 18.80291748], [72.87152863, 18.80291748], [72.87152863, 18.80264091], [72.87180328, 18.80264091], [72.87180328, 18.80236053], [72.87236023, 18.80236053], [72.87236023, 18.80208015], [72.87319183, 18.80208397], [72.87319183, 18.8018055], [72.87680817, 18.8018055], [72.87680817, 18.80208397], [72.87725067, 18.80208206], [72.87763977, 18.80208015], [72.87763977, 18.80236053], [72.87847137, 18.80236053], [72.87847137, 18.80264091], [72.87903595, 18.80264091], [72.87903595, 18.80291748], [72.87930298, 18.80291748], [72.87930298, 18.80319405], [72.87985992, 18.80319023], [72.87985992, 18.80347824], [72.88041687, 18.80347824], [72.88041687, 18.80374908], [72.88069153, 18.80374908], [72.88069153, 18.80403137], [72.88124847, 18.80403137], [72.88124847, 18.80431175], [72.88153076, 18.80430603], [72.88153076, 18.8045826], [72.88208008, 18.80458069], [72.88208008, 18.80485916], [72.88263702, 18.80485916], [72.88263702, 18.80431175], [72.88291931, 18.80431175], [72.88291931, 18.80403137], [72.88597107, 18.80403137], [72.88597107, 18.80374908], [72.88707733, 18.80374908], [72.88707733, 18.80347824], [72.88764191, 18.80347824], [72.88764191, 18.80291748], [72.88791656, 18.80291748], [72.88791656, 18.80208015], [72.88764191, 18.80208397], [72.88764191, 18.80152893], [72.88735962, 18.80153084], [72.88735962, 18.80125046], [72.88707733, 18.80125046], [72.88707733, 18.80070114], [72.88680267, 18.8006897], [72.88680267, 18.79986191], [72.88708496, 18.79986191], [72.88708496, 18.7997303], [72.88708496, 18.79958344], [72.88735962, 18.79958344], [72.88735962, 18.79819679], [72.88819122, 18.79819107], [72.88819122, 18.79874992], [72.89180756, 18.79874992], [72.89180756, 18.7990303], [72.89263916, 18.7990303], [72.89263916, 18.79931068], [72.89319611, 18.79930687], [72.89319611, 18.79958344], [72.89402771, 18.79958344], [72.89402771, 18.79986191], [72.89457703, 18.79986], [72.89457703, 18.80014038], [72.8951416, 18.80013847], [72.8951416, 18.80041695], [72.89541626, 18.80041695], [72.89541626, 18.80069351], [72.89597321, 18.80069351], [72.89597321, 18.80097198], [72.89653015, 18.80097008], [72.89653015, 18.80181122], [72.89707947, 18.80181122], [72.89707947, 18.80153084], [72.8979187, 18.80153084], [72.8979187, 18.80125046], [72.89819336, 18.80125046], [72.89819336, 18.80153084], [72.89847565, 18.80152893], [72.89847565, 18.80208397], [72.89875031, 18.80208397], [72.89875031, 18.80319405], [72.89901733, 18.80319023], [72.89901733, 18.80347824], [72.89958191, 18.80347824], [72.89958191, 18.80374908], [72.89985657, 18.80374908], [72.89985657, 18.80403137], [72.9006958, 18.80403137], [72.9006958, 18.80374908], [72.90097046, 18.80374908], [72.90097046, 18.80347824], [72.90125275, 18.80347824], [72.90125275, 18.80319023], [72.9015274, 18.80319405], [72.9015274, 18.80291748], [72.9026413, 18.80291748], [72.9026413, 18.80264091], [72.90291595, 18.80264091], [72.90291595, 18.80236053], [72.90319061, 18.80236053], [72.90320587, 18.80208015], [72.90374756, 18.80208397], [72.90374756, 18.8018055], [72.90402985, 18.80181122], [72.90402985, 18.80153084], [72.90429688, 18.80153084], [72.90429688, 18.80125046], [72.90458679, 18.80125046], [72.90458679, 18.80097008], [72.90486145, 18.80097198], [72.90486145, 18.80069351], [72.90513611, 18.80069351], [72.90513611, 18.80041695], [72.9054184, 18.80041695], [72.9054184, 18.79958344], [72.90569305, 18.79958344], [72.90569305, 18.79939079], [72.90569305, 18.79874992], [72.9054184, 18.79874992], [72.9054184, 18.79763985], [72.90513611, 18.79763985], [72.90513611, 18.79652977], [72.9054184, 18.79652977], [72.9054184, 18.79541969], [72.90569305, 18.79541969], [72.90569305, 18.79458046], [72.90625, 18.79458046], [72.90625, 18.7943058], [72.90651703, 18.79430962], [72.90651703, 18.79403114], [72.9070816, 18.79403114], [72.9070816, 18.79375267], [72.90763855, 18.79375267], [72.90763855, 18.79347038], [72.9081955, 18.79347038], [72.9081955, 18.79319382], [72.90847015, 18.79319382], [72.90847015, 18.79291725], [72.90901947, 18.79292107], [72.90901947, 18.79264259], [72.90957642, 18.79264259], [72.90957642, 18.79236031], [72.91069794, 18.79236031], [72.91069794, 18.79207993], [72.91430664, 18.79207993], [72.91430664, 18.79236031], [72.91512299, 18.79236031], [72.91625214, 18.79236031], [72.91625214, 18.79264259], [72.91680908, 18.79264259], [72.91680908, 18.79292107], [72.91708374, 18.79291725], [72.91708374, 18.79319382], [72.9173584, 18.79319382], [72.9173584, 18.79347038], [72.91791534, 18.79347038], [72.91791534, 18.79375267], [72.91821289, 18.79375267], [72.91821289, 18.79403114], [72.91847229, 18.79403114], [72.91847229, 18.79430962], [72.91902924, 18.7943058], [72.91902924, 18.79458046], [72.91929626, 18.79458046], [72.91929626, 18.79486275], [72.91958618, 18.79486275], [72.91958618, 18.79541969], [72.9201355, 18.79541588], [72.9201355, 18.79569244], [72.92041779, 18.79569244], [72.92041779, 18.79597473], [72.92069244, 18.79597282], [72.92069244, 18.79624939], [72.92095947, 18.79624939], [72.92095947, 18.79652977], [72.92124939, 18.79652977], [72.92124939, 18.79681015], [72.92152405, 18.79680634], [72.92152405, 18.79708481], [72.92180634, 18.79708481], [72.92180634, 18.79736137], [72.92208099, 18.79734993], [72.92208099, 18.79763985], [72.92236328, 18.79763985], [72.92236328, 18.79792023], [72.92263794, 18.79791641], [72.92263794, 18.79847145], [72.92292023, 18.79846954], [72.92292023, 18.79874992], [72.92318726, 18.79874992], [72.92318726, 18.7990303], [72.92346954, 18.7990303], [72.92346954, 18.79931068], [72.92375183, 18.79930687], [72.92375183, 18.79986191], [72.92402649, 18.79986], [72.92402649, 18.80014038], [72.92430878, 18.80013847], [72.92430878, 18.80041695], [72.92458344, 18.80041695], [72.92458344, 18.80097198], [72.92485809, 18.80097008], [72.92485809, 18.80125046], [72.92514038, 18.80125046], [72.92514038, 18.80153084], [72.92542267, 18.80153084], [72.92542267, 18.80181122], [72.92569733, 18.8018055], [72.92569733, 18.80208397], [72.92597198, 18.80208015], [72.92597198, 18.80236053], [72.92624664, 18.80236053], [72.92624664, 18.80264091], [72.92652893, 18.8026371], [72.92652893, 18.80319405], [72.92679596, 18.80319023], [72.92679596, 18.80347824], [72.92708588, 18.80347824], [72.92708588, 18.80374908], [72.92736053, 18.80374908], [72.92736053, 18.80403137], [72.92764282, 18.80403137], [72.92764282, 18.80431175], [72.92791748, 18.80430603], [72.92791748, 18.8045826], [72.92819214, 18.80458069], [72.92819214, 18.80514145], [72.92847443, 18.80514145], [72.92847443, 18.80569458], [72.92903137, 18.80569077], [72.92903137, 18.80624962], [72.92930603, 18.80624962], [72.92930603, 18.80820084], [72.92958069, 18.80820084], [72.92958069, 18.80903053], [72.92986298, 18.80902863], [72.92986298, 18.80958366], [72.93015289, 18.80957985], [72.93015289, 18.81014061], [72.93069458, 18.8101387], [72.93069458, 18.81097221], [72.93096924, 18.81097031], [72.93096924, 18.81180954], [72.93125153, 18.81180954], [72.93125153, 18.81264114], [72.93152618, 18.81263924], [72.93152618, 18.81319427], [72.93180847, 18.81319046], [72.93180847, 18.81375122], [72.93208313, 18.81375122], [72.93208313, 18.81430817], [72.93235779, 18.81430626], [72.93235779, 18.8148613], [72.93264008, 18.81485939], [72.93264008, 18.81513977], [72.93289948, 18.81513977], [72.93289948, 18.81541824], [72.93319702, 18.81541634], [72.93319702, 18.81569481], [72.93347168, 18.81569099], [72.93347168, 18.81624985], [72.93374634, 18.81624985], [72.93374634, 18.81708336], [72.93402863, 18.81707954], [72.93402863, 18.81792068], [72.93430328, 18.81792068], [72.93430328, 18.81875229], [72.9345932, 18.81875229], [72.9345932, 18.81931114], [72.93486023, 18.81931114], [72.93486023, 18.82014275], [72.93514252, 18.82014084], [72.93514252, 18.82097054], [72.93541718, 18.82097054], [72.93541718, 18.82152748], [72.93569183, 18.82152176], [72.93569183, 18.8223629], [72.93597412, 18.8223629], [72.93597412, 18.8231945], [72.93624878, 18.82319069], [72.93624878, 18.82374954], [72.93653107, 18.82374954], [72.93653107, 18.82429123], [72.93680573, 18.82430649], [72.93680573, 18.82486153], [72.93708038, 18.82485962], [72.93708038, 18.82514], [72.93736267, 18.82514], [72.93736267, 18.82570076], [72.93763733, 18.82569695], [72.93763733, 18.8259716], [72.93791962, 18.8259697], [72.93791962, 18.82625008], [72.93818665, 18.82625008], [72.93818665, 18.82653046], [72.93846893, 18.82652855], [72.93846893, 18.82708359], [72.93902588, 18.82707977], [72.93902588, 18.82736015], [72.9393158, 18.82736015], [72.93930817, 18.82708359], [72.93985748, 18.82707977], [72.93985748, 18.82736015], [72.94069672, 18.82736015], [72.94069672, 18.82792091], [72.94346619, 18.82792091], [72.94346619, 18.82707977], [72.94374847, 18.82708359], [72.94374847, 18.82625008], [72.94403076, 18.82625008], [72.94403076, 18.82542038], [72.94431305, 18.82542038], [72.94431305, 18.82458115], [72.94458008, 18.82458305], [72.94458008, 18.82374954], [72.94486237, 18.82374954], [72.94486237, 18.82319069], [72.94513702, 18.8231945], [72.94513702, 18.8223629], [72.94541931, 18.8223629], [72.94541931, 18.82208061], [72.94596863, 18.82208443], [72.94596863, 18.82180595], [72.9465332, 18.82180977], [72.9465332, 18.82069016], [72.94708252, 18.82069206], [72.94708252, 18.8204174], [72.94735718, 18.82042122], [72.94735718, 18.82014275], [72.94763947, 18.82014275], [72.94763947, 18.81986046], [72.94790649, 18.81986046], [72.94790649, 18.81958008], [72.94819641, 18.81958389], [72.94819641, 18.81930542], [72.94847107, 18.81931114], [72.94847107, 18.81903267], [72.94875336, 18.81903267], [72.94875336, 18.81875229], [72.94902802, 18.81875229], [72.94902802, 18.81819916], [72.94930267, 18.81819916], [72.94930267, 18.81792068], [72.94957733, 18.81792068], [72.94957733, 18.81735992], [72.94985962, 18.81736183], [72.94985962, 18.81680489], [72.95014191, 18.81680489], [72.95014191, 18.81624985], [72.95041656, 18.81624985], [72.95041656, 18.81569099], [72.95069122, 18.81569481], [72.95069122, 18.8148613], [72.95097351, 18.8148613], [72.95097351, 18.81430626], [72.9512558, 18.81430817], [72.9512558, 18.81375122], [72.95153046, 18.81375122], [72.95153046, 18.81319046], [72.95180511, 18.81319427], [72.95180511, 18.81236076], [72.95207977, 18.81236076], [72.95207977, 18.81180573], [72.95236206, 18.81180954], [72.95236206, 18.81125069], [72.95263672, 18.81125069], [72.95263672, 18.81068993], [72.95291901, 18.81069565], [72.95291901, 18.8101387], [72.95318604, 18.81014061], [72.95318604, 18.80957985], [72.95347595, 18.80958366], [72.95347595, 18.80902863], [72.95375061, 18.80903053], [72.95375061, 18.80846977], [72.95402527, 18.80847359], [72.95402527, 18.80791664], [72.95432281, 18.80792046], [72.95432281, 18.8073597], [72.95458221, 18.80736351], [72.95458221, 18.80680466], [72.9548645, 18.80680466], [72.9548645, 18.80624962], [72.95513916, 18.80624962], [72.95513916, 18.80569077], [72.95541382, 18.80569458], [72.95541382, 18.80514145], [72.95569611, 18.80514145], [72.95569611, 18.80458069], [72.95597076, 18.8045826], [72.95597076, 18.80402756], [72.95625305, 18.80403137], [72.95625305, 18.80347824], [72.95652771, 18.80347824], [72.95652771, 18.80291748], [72.95680237, 18.80291748], [72.95680237, 18.80236053], [72.9570694, 18.80236053], [72.9570694, 18.80181122], [72.95735931, 18.80181122], [72.95735931, 18.80125046], [72.9576416, 18.80125046], [72.9576416, 18.80097008], [72.95791626, 18.80097198], [72.95791626, 18.80069351], [72.95819092, 18.80069351], [72.95819092, 18.80041695], [72.95847321, 18.80041695], [72.95847321, 18.79986191], [72.95874786, 18.79986191], [72.95874786, 18.79958344], [72.95903015, 18.79958344], [72.95903015, 18.79930687], [72.95929718, 18.79931068], [72.95929718, 18.7990303], [72.9595871, 18.7990303], [72.9595871, 18.79874992], [72.95986176, 18.79874992], [72.95986176, 18.79846954], [72.96013641, 18.79847145], [72.96013641, 18.79819679], [72.9604187, 18.79819679], [72.9604187, 18.79763794], [72.96069336, 18.79763985], [72.96069336, 18.79734993], [72.96097565, 18.79736137], [72.96097565, 18.79708481], [72.96125031, 18.79708481], [72.96125031, 18.79680634], [72.96151733, 18.79681015], [72.96151733, 18.79652977], [72.96180725, 18.79652977], [72.96180725, 18.79624939], [72.96208191, 18.79624939], [72.96208191, 18.79597282], [72.9623642, 18.79597473], [72.9623642, 18.79569244], [72.96263885, 18.79569244], [72.96263885, 18.79541588], [72.96290588, 18.79541969], [72.96290588, 18.79514122], [72.9631958, 18.79514122], [72.9631958, 18.79486275], [72.96347046, 18.79486275], [72.96347046, 18.79458046], [72.96375275, 18.79458046], [72.96375275, 18.7943058], [72.96430206, 18.79430962], [72.96430206, 18.79403114], [72.96457672, 18.79403114], [72.96457672, 18.79375267], [72.96485901, 18.79375267], [72.96485901, 18.79347038], [72.96541595, 18.79347038], [72.96541595, 18.79319382], [72.96569061, 18.79319382], [72.96569824, 18.79291725], [72.9659729, 18.79292107], [72.9659729, 18.79264259], [72.96652985, 18.79264259], [72.96652985, 18.79236031], [72.96679688, 18.79236031], [72.96679688, 18.79207993], [72.96736145, 18.79208374], [72.96736145, 18.79180527], [72.96763611, 18.79180908], [72.96763611, 18.79154015], [72.96819305, 18.79154015], [72.96819305, 18.79124832], [72.96848297, 18.79124832], [72.96847534, 18.79097176], [72.96902466, 18.79097176], [72.96902466, 18.79069519], [72.96929932, 18.79070091], [72.96929932, 18.79042053], [72.96985626, 18.79042053], [72.96985626, 18.79013824], [72.97041321, 18.79013824], [72.97041321, 18.78985977], [72.97125244, 18.78985977], [72.97125244, 18.79013824], [72.9715271, 18.79013824], [72.9715271, 18.79042053], [72.97180176, 18.79041672], [72.97180939, 18.79084969], [72.97180939, 18.79097176], [72.97206879, 18.79096985], [72.97206879, 18.79154015], [72.9723587, 18.79153061], [72.9723587, 18.79208374], [72.97264099, 18.79207993], [72.97264099, 18.79264259], [72.97292328, 18.79264259], [72.97292328, 18.79292107], [72.97319794, 18.79291725], [72.97319794, 18.79347038], [72.9734726, 18.79347038], [72.9734726, 18.79403114], [72.97374725, 18.79402733], [72.97374725, 18.79458046], [72.97402954, 18.79458046], [72.97402954, 18.79486275], [72.97429657, 18.79486275], [72.97429657, 18.79541969], [72.97458649, 18.79541588], [72.97458649, 18.79597473], [72.97486115, 18.79597282], [72.97486115, 18.79652977], [72.9751358, 18.79652786], [72.9751358, 18.79708481], [72.97541809, 18.79708481], [72.97541809, 18.79736137], [72.97569275, 18.79734993], [72.97569275, 18.79792023], [72.97597504, 18.79791641], [72.97597504, 18.79847145], [72.97624969, 18.79846954], [72.97624969, 18.7990303], [72.97651672, 18.7990303], [72.97651672, 18.79931068], [72.97680664, 18.79930687], [72.97680664, 18.79958344], [72.9770813, 18.79958344], [72.9770813, 18.79986191], [72.97680664, 18.79986191], [72.97680664, 18.8006897], [72.97651672, 18.80070114], [72.97651672, 18.80153084], [72.97624969, 18.80152893], [72.97624969, 18.80208397], [72.97598267, 18.80208015], [72.97598267, 18.80291748], [72.97569275, 18.80291748], [72.97569275, 18.80374908], [72.97598267, 18.80374908], [72.97598267, 18.80431175], [72.97652435, 18.80430603], [72.97652435, 18.8045826], [72.97680664, 18.80458069], [72.97680664, 18.80485916], [72.9770813, 18.80485916], [72.9770813, 18.80514145], [72.97846985, 18.80514145], [72.97846985, 18.80485916], [72.97930908, 18.80485916], [72.97930908, 18.80458069], [72.97957611, 18.80458069], [72.97957611, 18.80485916], [72.9798584, 18.80485916], [72.9798584, 18.80542183], [72.98014069, 18.80541611], [72.98014069, 18.80597115], [72.98041534, 18.80597115], [72.98041534, 18.80624962], [72.98069763, 18.80624962], [72.98069763, 18.80680466], [72.98097229, 18.80680466], [72.98097229, 18.80736351], [72.98123932, 18.8073597], [72.98123932, 18.80792046], [72.98152924, 18.80792046], [72.98152924, 18.80820084], [72.98179626, 18.80820084], [72.98179626, 18.80875015], [72.98208618, 18.80875015], [72.98208618, 18.80931091], [72.98236084, 18.80930328], [72.98236084, 18.80958366], [72.98264313, 18.80957985], [72.98264313, 18.81014061], [72.98236084, 18.81014061], [72.98236084, 18.81042099], [72.98208618, 18.81041718], [72.98208618, 18.81069565], [72.98179626, 18.81068993], [72.98179626, 18.81125069], [72.98152924, 18.81125069], [72.98152924, 18.81153107], [72.98124695, 18.81152725], [72.98124695, 18.8120842], [72.98097229, 18.81208038], [72.98097229, 18.81291962], [72.98069763, 18.81291962], [72.98069763, 18.81375122], [72.98041534, 18.81374931], [72.98041534, 18.81458282], [72.98014069, 18.81458092], [72.98014069, 18.81541824], [72.9798584, 18.81541634], [72.9798584, 18.81708336], [72.97958374, 18.81708336], [72.97958374, 18.82208443], [72.9798584, 18.82208061], [72.9798584, 18.82263947], [72.98014069, 18.82263947], [72.98014069, 18.8231945], [72.98041534, 18.8231945], [72.98041534, 18.82374954], [72.98069763, 18.82374954], [72.98069763, 18.82429123], [72.98097229, 18.82430649], [72.98097229, 18.82486153], [72.98123932, 18.82485962], [72.98123932, 18.82542038], [72.98152924, 18.82542038], [72.98152924, 18.82570076], [72.98179626, 18.82570076], [72.98179626, 18.82625008], [72.98208618, 18.82625008], [72.98208618, 18.82653046], [72.98236084, 18.82653046], [72.98236084, 18.82681084], [72.9826355, 18.82680511], [72.9826355, 18.82736015], [72.98291779, 18.82736015], [72.98291779, 18.82764053], [72.98319244, 18.82764053], [72.98319244, 18.82792091], [72.98347473, 18.8279171], [72.98347473, 18.82847214], [72.98374939, 18.82847023], [72.98374939, 18.82875061], [72.9834671, 18.82875061], [72.9834671, 18.82902908], [72.98319244, 18.82902908], [72.98319244, 18.82930756], [72.98291779, 18.82930756], [72.98291779, 18.82986069], [72.9826355, 18.82986069], [72.9826355, 18.8306942], [72.98291779, 18.8306942], [72.98291779, 18.83208275], [72.98319244, 18.83208275], [72.98319244, 18.83319473], [72.9834671, 18.83319092], [72.9834671, 18.83403015], [72.98319244, 18.83403015], [72.98319244, 18.83570099], [72.98291779, 18.83570099], [72.98291779, 18.83681107], [72.9826355, 18.83680534], [72.98264313, 18.83736038], [72.98236084, 18.83736038], [72.98236084, 18.83792114], [72.98208618, 18.83791733], [72.98208618, 18.83847237], [72.98179626, 18.83847046], [72.98179626, 18.83875084], [72.98208618, 18.83875084], [72.98208618, 18.84124947], [72.98180389, 18.84124947], [72.98180389, 18.84236145], [72.98152924, 18.84236145], [72.98152924, 18.84347153], [72.98124695, 18.84347153], [72.98124695, 18.84486008], [72.98097229, 18.84486008], [72.98097229, 18.84597015], [72.98069763, 18.84597015], [72.98069763, 18.84669113], [72.98069763, 18.84708214], [72.9808197, 18.84708214], [72.98097229, 18.84708214], [72.98097229, 18.84760094], [72.98097229, 18.84819221], [72.98124695, 18.84819221], [72.98123932, 18.84851837], [72.98123932, 18.84875107], [72.98097229, 18.84875107], [72.98097229, 18.84930992], [72.98069763, 18.84930611], [72.98069763, 18.85069466], [72.98097229, 18.85069466], [72.98097229, 18.85208321], [72.98124695, 18.85208321], [72.98124695, 18.85236168], [72.98152924, 18.85235977], [72.98152924, 18.85264015], [72.98179626, 18.85264015], [72.98179626, 18.85320091], [72.98208618, 18.85319519], [72.98208618, 18.85347176], [72.98236084, 18.85346985], [72.98236084, 18.85375023], [72.98264313, 18.85375023], [72.98264313, 18.85431099], [72.98291779, 18.85431099], [72.98291779, 18.85458946], [72.98319244, 18.85458946], [72.98319244, 18.85514069], [72.9834671, 18.85514069], [72.9834671, 18.85542107], [72.98374939, 18.85541725], [72.98374939, 18.85597229], [72.98400879, 18.85597038], [72.98400879, 18.85625076], [72.98429871, 18.85625076], [72.98429871, 18.85680962], [72.98458099, 18.8568058], [72.98458099, 18.85708237], [72.98486328, 18.85708046], [72.98486328, 18.85765266], [72.98513794, 18.85765266], [72.98513794, 18.8579216], [72.98542023, 18.85791588], [72.98542023, 18.85847282], [72.98568726, 18.85847092], [72.98568726, 18.85903168], [72.98596954, 18.85902786], [72.98596954, 18.8595829], [72.98625183, 18.85957909], [72.98625183, 18.86014175], [72.98652649, 18.86013794], [72.98652649, 18.86069489], [72.98680878, 18.86069107], [72.98680878, 18.86125183], [72.98707581, 18.86125183], [72.98707581, 18.86181068], [72.98735809, 18.86180305], [72.98735809, 18.86236382], [72.98764038, 18.86236], [72.98764038, 18.86292076], [72.98791504, 18.86291695], [72.98791504, 18.86347389], [72.98819733, 18.86347008], [72.98819733, 18.86403084], [72.98847198, 18.86403084], [72.98847198, 18.86486053], [72.98874664, 18.86486053], [72.98874664, 18.86597252], [72.98847198, 18.86597061], [72.98847198, 18.86625099], [72.98792267, 18.86625099], [72.98792267, 18.86652946], [72.98764038, 18.86652946], [72.98764038, 18.86681747], [72.98708344, 18.86680794], [72.98708344, 18.8670826], [72.98680878, 18.8670826], [72.98680878, 18.86680794], [72.98652649, 18.86681747], [72.98652649, 18.86652946], [72.98625183, 18.86652946], [72.98625183, 18.86625099], [72.98596954, 18.86625099], [72.98596954, 18.86597061], [72.98542023, 18.86597252], [72.98542023, 18.86569595], [72.98513794, 18.86569595], [72.98513794, 18.86541748], [72.98486328, 18.86541939], [72.98486328, 18.86514091], [72.98458099, 18.86514091], [72.98458099, 18.86486053], [72.98400879, 18.86486053], [72.98400879, 18.86458015], [72.98374939, 18.86458588], [72.98374939, 18.8643055], [72.98319244, 18.86431122], [72.98319244, 18.86403084], [72.98264313, 18.86403084], [72.98264313, 18.86375046], [72.98014069, 18.86375046], [72.98014069, 18.86347008], [72.97902679, 18.86347389], [72.97902679, 18.86319542], [72.97792053, 18.8631897], [72.9779129, 18.86291695], [72.97763824, 18.86292076], [72.97763824, 18.86264038], [72.97735596, 18.86264038], [72.97735596, 18.86236], [72.9770813, 18.86236382], [72.9770813, 18.86208153], [72.97652435, 18.86208153], [72.97652435, 18.86180305], [72.97624969, 18.86181068], [72.97624969, 18.8615303], [72.97576904, 18.8615303], [72.97569275, 18.8615284], [72.97569275, 18.86125183], [72.97541809, 18.86125183], [72.97541809, 18.86097336], [72.97486115, 18.86097336], [72.97486115, 18.86069489], [72.97458649, 18.86069489], [72.97458649, 18.86041641], [72.97429657, 18.86042023], [72.97429657, 18.86014175], [72.97374725, 18.86014175], [72.97374725, 18.85985947], [72.9734726, 18.85985947], [72.9734726, 18.8595829], [72.97319794, 18.8595829], [72.97319794, 18.85930634], [72.97292328, 18.85931015], [72.97292328, 18.85903168], [72.97264099, 18.85903168], [72.97264099, 18.85874939], [72.9723587, 18.85874939], [72.9723587, 18.85847092], [72.97180176, 18.85847282], [72.97180176, 18.85819435], [72.9715271, 18.85819435], [72.9715271, 18.85791588], [72.97125244, 18.8579216], [72.97125244, 18.85765266], [72.97097015, 18.85765266], [72.97097015, 18.85736084], [72.97041321, 18.85736084], [72.97041321, 18.85708046], [72.97013855, 18.85708427], [72.97013855, 18.8568058], [72.9695816, 18.85680962], [72.9695816, 18.85652924], [72.96929932, 18.85652924], [72.96929932, 18.85625076], [72.9690094, 18.85625076], [72.9690094, 18.85597038], [72.96819305, 18.85597229], [72.96819305, 18.85569382], [72.96763611, 18.85569382], [72.96763611, 18.85541725], [72.96736145, 18.85542107], [72.96736145, 18.85514069], [72.96708679, 18.85514069], [72.96708679, 18.85486031], [72.96679688, 18.85486031], [72.96679688, 18.85458946], [72.96652985, 18.85458946], [72.96652985, 18.85431099], [72.96626282, 18.85431099], [72.96626282, 18.85403061], [72.9659729, 18.85403061], [72.9659729, 18.85375023], [72.96582794, 18.85375023], [72.96569824, 18.85375023], [72.96569061, 18.85346985], [72.9651413, 18.85347176], [72.9651413, 18.85319519], [72.96485901, 18.85320091], [72.96485901, 18.85292053], [72.96430206, 18.85292053], [72.96430206, 18.85264015], [72.9640274, 18.85264015], [72.9640274, 18.85292053], [72.96347046, 18.85292053], [72.96347046, 18.85320091], [72.9631958, 18.85319519], [72.9631958, 18.85347176], [72.9623642, 18.85347176], [72.9623642, 18.85319519], [72.96208191, 18.85320091], [72.96208191, 18.85292053], [72.96151733, 18.85292053], [72.96151733, 18.85264015], [72.96125031, 18.85264015], [72.96125031, 18.85235977], [72.96097565, 18.85236168], [72.96097565, 18.85180664], [72.9604187, 18.85180664], [72.9604187, 18.85152817], [72.95986176, 18.85153008], [72.95986176, 18.85124969], [72.95903015, 18.85124969], [72.95903015, 18.85097122], [72.95847321, 18.85097313], [72.95847321, 18.85069466], [72.95791626, 18.85069466], [72.95791626, 18.85041618], [72.95680237, 18.85042], [72.95680237, 18.85013962], [72.95625305, 18.85013962], [72.95625305, 18.84986115], [72.95513916, 18.84986115], [72.95513916, 18.84958076], [72.95347595, 18.84958458], [72.95347595, 18.84930611], [72.95318604, 18.84930992], [72.95318604, 18.84902954], [72.95291901, 18.84902954], [72.95291901, 18.84875107], [72.95263672, 18.84875107], [72.95263672, 18.84845924], [72.95207977, 18.8484745], [72.95207977, 18.84819221], [72.95153046, 18.84819221], [72.95153046, 18.84791756], [72.95096588, 18.84791946], [72.95096588, 18.8476429], [72.95014191, 18.8476429], [72.95014191, 18.84736252], [72.94930267, 18.84736252], [72.94930267, 18.84708023], [72.94847107, 18.84708214], [72.94847107, 18.84680557], [72.94735718, 18.84680939], [72.94735718, 18.84653282], [72.9465332, 18.84653282], [72.9465332, 18.84625244], [72.94512939, 18.84625244], [72.94512939, 18.84597015], [72.94416046, 18.84597015], [72.94374847, 18.84597015], [72.94374847, 18.84569359], [72.94291687, 18.84569359], [72.94291687, 18.84597015], [72.94264221, 18.84597015], [72.94264221, 18.84614944], [72.94264221, 18.84625244], [72.9420929, 18.84625244], [72.9420929, 18.84653282], [72.94180298, 18.84653282], [72.94180298, 18.84680939], [72.94152832, 18.84680557], [72.94152832, 18.84708214], [72.94124603, 18.84708023], [72.94124603, 18.84736252], [72.94069672, 18.84736252], [72.94069672, 18.8476429], [72.9404068, 18.8476429], [72.9404068, 18.84791946], [72.94013977, 18.84791756], [72.94013977, 18.84819221], [72.93958282, 18.84819221], [72.93958282, 18.8484745], [72.9393158, 18.84845924], [72.9393158, 18.84875107], [72.93875122, 18.84875107], [72.93875122, 18.84902954], [72.93846893, 18.84902954], [72.93846893, 18.84930992], [72.93688965, 18.84930801], [72.93264008, 18.84930611], [72.93264008, 18.84958458], [72.93235779, 18.84958076], [72.93235779, 18.84986115], [72.93208313, 18.84986115], [72.93208313, 18.85013962], [72.93180847, 18.85013962], [72.93180847, 18.85042], [72.93152618, 18.85041618], [72.93152618, 18.85069466], [72.93125153, 18.85069466], [72.93125153, 18.85097313], [72.93068695, 18.85097122], [72.93069458, 18.85124969], [72.93015289, 18.85124969], [72.93015289, 18.85153008], [72.92764282, 18.85153008], [72.92764282, 18.85124969], [72.92736053, 18.85124969], [72.92736053, 18.85097122], [72.92652893, 18.85097122], [72.92652893, 18.85124969], [72.92624664, 18.85124969], [72.92624664, 18.85153008], [72.92569733, 18.85152817], [72.92569733, 18.85180664], [72.92541504, 18.85180664], [72.92541504, 18.85236168], [72.92514038, 18.85236168], [72.92514038, 18.85347176], [72.92485809, 18.85346985], [72.92485809, 18.85431099], [72.92430878, 18.85431099], [72.92430878, 18.85458946], [72.92402649, 18.85458946], [72.92402649, 18.85486031], [72.92263794, 18.85486031], [72.92263794, 18.85514069], [72.92292023, 18.85514069], [72.92292023, 18.85680962], [72.92319489, 18.8568058], [72.92319489, 18.85819435], [72.92346954, 18.85819054], [72.92346954, 18.85874939], [72.92375183, 18.85874939], [72.92375183, 18.86347389], [72.92346954, 18.86347389], [72.92346954, 18.86458588], [72.92318726, 18.86458015], [72.92318726, 18.86541939], [72.92292023, 18.86541748], [72.92292023, 18.86569595], [72.92263794, 18.86569595], [72.92263794, 18.86597252], [72.92236328, 18.86597061], [72.92236328, 18.86652946], [72.92208099, 18.86652946], [72.92208099, 18.86763954], [72.92180634, 18.86763954], [72.92180634, 18.86819458], [72.92124939, 18.86819458], [72.92124939, 18.86847305], [72.92095947, 18.86847115], [72.92095947, 18.86874962], [72.92069244, 18.86874962], [72.92069244, 18.86930466], [72.92014313, 18.86930084], [72.92014313, 18.87013817], [72.91986084, 18.87013817], [72.91986084, 18.87070084], [72.91958618, 18.87069511], [72.91958618, 18.87097168], [72.91929626, 18.87096977], [72.91929626, 18.87124825], [72.91902924, 18.87124825], [72.91902924, 18.87152863], [72.91874695, 18.87152863], [72.91874695, 18.87181091], [72.91847229, 18.87181091], [72.91847229, 18.87236023], [72.91819763, 18.87236023], [72.91819763, 18.8726387], [72.91792297, 18.87262917], [72.91792297, 18.8729229], [72.91764069, 18.87291718], [72.91764069, 18.87347031], [72.9173584, 18.87347031], [72.9173584, 18.87403107], [72.91708374, 18.87402725], [72.91708374, 18.87458229], [72.91680908, 18.87458038], [72.91680908, 18.87514114], [72.91652679, 18.87513924], [72.91652679, 18.87569237], [72.91625214, 18.87569046], [72.91625214, 18.87652969], [72.91596985, 18.87652779], [72.91596985, 18.87708473], [72.91570282, 18.87708092], [72.91570282, 18.87792015], [72.9154129, 18.87792015], [72.9154129, 18.87875938], [72.91513824, 18.87874985], [72.91513824, 18.87930679], [72.91486359, 18.87930679], [72.91486359, 18.87986183], [72.9145813, 18.87985992], [72.9145813, 18.8801403], [72.91430664, 18.8801403], [72.91430664, 18.88070107], [72.91402435, 18.88069534], [72.91402435, 18.88097191], [72.91374969, 18.88097], [72.91374969, 18.88125038], [72.91348267, 18.88125038], [72.91348267, 18.88182068], [72.91319275, 18.88180542], [72.91319275, 18.88208389], [72.91291809, 18.88208008], [72.91291809, 18.88236046], [72.9126358, 18.88236046], [72.9126358, 18.88292122], [72.9109726, 18.8829174], [72.9109726, 18.88347244], [72.91069794, 18.88347054], [72.91069794, 18.88375092], [72.91042328, 18.88375092], [72.91042328, 18.88431168], [72.91014099, 18.88430595], [72.91014099, 18.88458252], [72.9098587, 18.88457108], [72.9098587, 18.88485909], [72.90930939, 18.88485909], [72.90930176, 18.88513947], [72.90901947, 18.88513947], [72.90901947, 18.88542175], [72.90847015, 18.88541603], [72.90847015, 18.8856945], [72.9081955, 18.8856945], [72.9081955, 18.88847351], [72.90847015, 18.8884697], [72.90847015, 18.89125061], [72.90820313, 18.89125061], [72.90820313, 18.89264107], [72.90847015, 18.89263916], [72.90847015, 18.89708328], [72.90875244, 18.89707947], [72.90875244, 18.89819908], [72.9081955, 18.89819527], [72.9081955, 18.89847183], [72.90791321, 18.89846992], [72.90791321, 18.89903259], [72.90763855, 18.89903259], [72.90763855, 18.90042114], [72.90791321, 18.90041733], [72.90791321, 18.90208435], [72.90847015, 18.90208054], [72.90847015, 18.90236282], [72.90875244, 18.90236282], [72.90875244, 18.90263939], [72.90930176, 18.90263939], [72.90930939, 18.90293121], [72.90958405, 18.90291405], [72.90958405, 18.90319252], [72.9098587, 18.90319061], [72.9098587, 18.90374947], [72.91014099, 18.90374947], [72.91014099, 18.90431023], [72.91069794, 18.90431023], [72.91069794, 18.90402985], [72.91291809, 18.90402985], [72.91291809, 18.90374947], [72.91514587, 18.90374947], [72.91514587, 18.90402985], [72.9154129, 18.90402985], [72.9154129, 18.90431023], [72.91569519, 18.90430641], [72.91569519, 18.90458488], [72.91625214, 18.90458488], [72.91625214, 18.90486145], [72.91652679, 18.90485954], [72.91652679, 18.9054203], [72.91680908, 18.90541649], [72.91680908, 18.90597153], [72.91707611, 18.90596962], [72.91707611, 18.90653038], [72.9173584, 18.90653038], [72.9173584, 18.90792084], [72.91707611, 18.90792084], [72.91707611, 18.90903091], [72.91680908, 18.90903091], [72.91680908, 18.91041756], [72.9173584, 18.91041756], [72.9173584, 18.91013908], [72.91792297, 18.91013908], [72.91792297, 18.90986061], [72.91847229, 18.90986061], [72.91847229, 18.90958023], [72.91958618, 18.90958023], [72.91958618, 18.90986061], [72.91986084, 18.90986061], [72.91986084, 18.91041756], [72.9201355, 18.91041756], [72.9201355, 18.91069412], [72.92041779, 18.91069412], [72.92041779, 18.9109726], [72.92124939, 18.91097069], [72.92124939, 18.91153145], [72.92180634, 18.91152763], [72.92180634, 18.91180611], [72.92263794, 18.91180611], [72.92263794, 18.91208267], [72.92346954, 18.91208267], [72.92346954, 18.91180611], [72.92402649, 18.91180611], [72.92402649, 18.91152763], [72.92736053, 18.91153145], [72.92736053, 18.91124916], [72.9284668, 18.91124916], [72.9284668, 18.91097069], [72.92903137, 18.9109726], [72.92903137, 18.91069412], [72.92958069, 18.91069412], [72.92958069, 18.91041756], [72.92986298, 18.91041756], [72.92986298, 18.90958023], [72.93013763, 18.90958405], [72.93013763, 18.90875053], [72.93041992, 18.90875053], [72.93041992, 18.90763855], [72.93068695, 18.90764046], [72.93068695, 18.90736008], [72.93096924, 18.90736198], [72.93096924, 18.90708351], [72.93125153, 18.90708351], [72.93125153, 18.90652847], [72.93152618, 18.90653038], [72.93152618, 18.90596962], [72.93180847, 18.90597153], [72.93180847, 18.90569687], [72.93208313, 18.90570068], [72.93208313, 18.9054203], [72.93235779, 18.9054203], [72.93235779, 18.90513992], [72.93264008, 18.90513992], [72.93264008, 18.90485954], [72.93291473, 18.90486145], [72.93291473, 18.90430641], [72.93374634, 18.90431023], [72.93374634, 18.90402985], [72.93430328, 18.90402985], [72.93430328, 18.90374947], [72.9345932, 18.90374947], [72.93458557, 18.90347481], [72.93486023, 18.90347481], [72.93486023, 18.90319252], [72.93514252, 18.90319252], [72.93514252, 18.90291405], [72.93569183, 18.90293121], [72.93569183, 18.90236282], [72.93624878, 18.90236282], [72.93624878, 18.90208054], [72.93653107, 18.90208435], [72.93653107, 18.90180588], [72.93681335, 18.90180969], [72.93681335, 18.90153122], [72.93708038, 18.90153122], [72.93708038, 18.90125275], [72.93763733, 18.90125275], [72.93763733, 18.90097046], [72.93791962, 18.90097046], [72.93791962, 18.90041733], [72.93818665, 18.90042114], [72.93818665, 18.90014267], [72.93875122, 18.90014267], [72.93875122, 18.89986038], [72.93902588, 18.89986038], [72.93902588, 18.89957047], [72.93930817, 18.89958382], [72.93930817, 18.89930534], [72.93958282, 18.89931107], [72.93958282, 18.89903259], [72.93985748, 18.89903259], [72.93985748, 18.8987484], [72.94013977, 18.8987484], [72.94013977, 18.89846992], [72.94041443, 18.89847183], [72.94041443, 18.89819527], [72.94069672, 18.89819908], [72.94069672, 18.89792061], [72.94097137, 18.89792061], [72.94097137, 18.89652824], [72.94069672, 18.89652824], [72.94069672, 18.89541817], [72.94180298, 18.89541626], [72.94180298, 18.89708328], [72.94190979, 18.89708138], [72.9420929, 18.89707947], [72.9420929, 18.89792061], [72.94235992, 18.89792061], [72.94235992, 18.89903259], [72.94264221, 18.89903259], [72.94264221, 18.89986038], [72.94291687, 18.89986038], [72.94291687, 18.9054203], [72.94264221, 18.9054203], [72.94264221, 18.90570068], [72.94235992, 18.90570068], [72.94235992, 18.90625], [72.94208527, 18.90625], [72.94208527, 18.90875053], [72.94235992, 18.908741], [72.94235992, 18.90930748], [72.94319153, 18.90930748], [72.94319153, 18.90903091], [72.94458008, 18.90903091], [72.94458008, 18.90930748], [72.94486237, 18.90930748], [72.94486237, 18.91013908], [72.94513702, 18.91013718], [72.94513702, 18.9109726], [72.94625092, 18.9109726], [72.94625092, 18.91069412], [72.94985962, 18.91069412], [72.94985962, 18.91041756], [72.95041656, 18.91041756], [72.95041656, 18.91013908], [72.95069122, 18.91013908], [72.95069122, 18.90986061], [72.95096588, 18.90986061], [72.95096588, 18.90958023], [72.95153046, 18.90958405], [72.95153046, 18.9090271], [72.95207977, 18.90903091], [72.95207977, 18.908741], [72.95236206, 18.90875053], [72.95236206, 18.90847206], [72.95291901, 18.90847206], [72.95291901, 18.90819359], [72.95402527, 18.90819359], [72.95402527, 18.90847206], [72.95513916, 18.90847206], [72.95513916, 18.90819359], [72.95569611, 18.90819359], [72.95569611, 18.90847206], [72.95597076, 18.90847206], [72.95597076, 18.90819359], [72.95652771, 18.90819359], [72.95652771, 18.90791893], [72.95708466, 18.90791893], [72.95708466, 18.90819359], [72.95735931, 18.90819359], [72.95735931, 18.90847206], [72.9576416, 18.90847206], [72.9576416, 18.90875053], [72.95735931, 18.90875053], [72.95735931, 18.90958405], [72.9576416, 18.90958023], [72.9576416, 18.91013908], [72.95791626, 18.91013908], [72.95791626, 18.91041756], [72.95819092, 18.91041756], [72.95819092, 18.9109726], [72.95847321, 18.91097069], [72.95847321, 18.91124916], [72.95874786, 18.91124916], [72.95874786, 18.91180611], [72.95903015, 18.91180038], [72.95903015, 18.91235924], [72.95929718, 18.91235924], [72.95929718, 18.91264153], [72.9595871, 18.91264153], [72.9595871, 18.91292191], [72.95986176, 18.91291618], [72.95986176, 18.91347122], [72.96012878, 18.91346931], [72.96012878, 18.91403008], [72.9604187, 18.91402817], [72.9604187, 18.9145813], [72.96069336, 18.91457939], [72.96069336, 18.91514015], [72.96097565, 18.91513824], [72.96098328, 18.91625023], [72.96069336, 18.91625023], [72.96069336, 18.9179306], [72.96098328, 18.9179306], [72.96098328, 18.91903114], [72.96125031, 18.91902733], [72.96125031, 18.91958237], [72.96151733, 18.91958046], [72.96151733, 18.92041969], [72.96180725, 18.92041969], [72.96180725, 18.92180824], [72.96151733, 18.92180824], [72.96151733, 18.92263985], [72.96125031, 18.92263985], [72.96125031, 18.92319489], [72.96097565, 18.92319489], [72.96097565, 18.92374992], [72.95986176, 18.92374039], [72.95986176, 18.9240284], [72.95929718, 18.9240284], [72.95929718, 18.92431068], [72.95903015, 18.92430496], [72.95903015, 18.92458344], [72.95847321, 18.92458344], [72.95847321, 18.92486191], [72.95819092, 18.92485809], [72.95819092, 18.92513847], [72.9576416, 18.92513847], [72.9576416, 18.92542267], [72.95735931, 18.92541695], [72.95735931, 18.9256897], [72.95708466, 18.92569542], [72.95708466, 18.92597008], [72.95680237, 18.92597008], [72.95680237, 18.92625237], [72.95652771, 18.92625237], [72.95652771, 18.92653275], [72.95625305, 18.92653275], [72.95625305, 18.92681122], [72.95597076, 18.9268055], [72.95597076, 18.92708206], [72.95569611, 18.92708015], [72.95569611, 18.92736053], [72.95540619, 18.92736053], [72.95540619, 18.92764282], [72.95513916, 18.92764282], [72.95513916, 18.92791939], [72.9548645, 18.92791748], [72.9548645, 18.92819214], [72.95458221, 18.92819214], [72.95458221, 18.92847061], [72.95432281, 18.92847061], [72.95432281, 18.9287529], [72.9540329, 18.9287529], [72.9540329, 18.92902946], [72.95375061, 18.92902946], [72.95375061, 18.92930984], [72.95347595, 18.92930603], [72.95347595, 18.9295845], [72.95318604, 18.92958069], [72.95318604, 18.92987061], [72.95291901, 18.92987061], [72.95291901, 18.93013954], [72.95263672, 18.93013954], [72.95263672, 18.93041992], [72.95236206, 18.9304142], [72.95236206, 18.93069458], [72.95207977, 18.93069458], [72.95207977, 18.93097305], [72.95153046, 18.93097115], [72.95153046, 18.93124962], [72.9512558, 18.93124962], [72.9512558, 18.93153], [72.95097351, 18.93152809], [72.95097351, 18.93180656], [72.95069122, 18.93180656], [72.95069122, 18.93208313], [72.95014191, 18.93208313], [72.95014191, 18.9323616], [72.94985962, 18.9323597], [72.94985962, 18.93264008], [72.94958496, 18.93263817], [72.94958496, 18.93291664], [72.94930267, 18.93291092], [72.94930267, 18.93320084], [72.94902802, 18.93319511], [72.94902802, 18.93347168], [72.94875336, 18.93346977], [72.94875336, 18.93403053], [72.94847107, 18.93403053], [72.94847107, 18.93431091], [72.94819641, 18.93430519], [72.94819641, 18.93458366], [72.94790649, 18.93457985], [72.94790649, 18.93486023], [72.94763947, 18.93486023], [72.94763947, 18.93514061], [72.94735718, 18.93514061], [72.94735718, 18.93541908], [72.94680786, 18.93541718], [72.94680786, 18.93569374], [72.94652557, 18.93569374], [72.94652557, 18.93597221], [72.94625092, 18.93597031], [72.94625092, 18.93625069], [72.94596863, 18.93625069], [72.94596863, 18.93680763], [72.94569397, 18.93680573], [72.94569397, 18.93958282], [72.94541931, 18.93958092], [72.94541931, 18.94014168], [72.94512939, 18.94014168], [72.94512939, 18.94042015], [72.94486237, 18.94041634], [72.94486237, 18.94097137], [72.94458008, 18.94096947], [72.94458008, 18.94124985], [72.94431305, 18.94124985], [72.94431305, 18.94153023], [72.94374847, 18.94153023], [72.94374847, 18.94181061], [72.94347382, 18.94180489], [72.94347382, 18.94236374], [72.94319153, 18.94235992], [72.94319153, 18.94292068], [72.94291687, 18.94292068], [72.94291687, 18.94320107], [72.94264221, 18.94319534], [72.94264221, 18.94347382], [72.94208527, 18.94347382], [72.9420929, 18.94375038], [72.94180298, 18.94375038], [72.94180298, 18.94403076], [72.94152832, 18.94403076], [72.94152832, 18.94431114], [72.94125366, 18.94430542], [72.94125366, 18.9445858], [72.94097137, 18.9445858], [72.94097137, 18.94486046], [72.94069672, 18.94485283], [72.94069672, 18.94514084], [72.94013977, 18.94514084], [72.94013977, 18.94542122], [72.93958282, 18.9454174], [72.93958282, 18.94597244], [72.9393158, 18.94597054], [72.9393158, 18.94652939], [72.93958282, 18.94652748], [72.93958282, 18.94708252], [72.93985748, 18.94708061], [72.93985748, 18.94736099], [72.94013977, 18.94736099], [72.94013977, 18.94791794], [72.94041443, 18.94791794], [72.94041443, 18.9481945], [72.94069672, 18.9481945], [72.94069672, 18.94847298], [72.94097137, 18.94847107], [72.94097137, 18.94874954], [72.94124603, 18.94874954], [72.94124603, 18.94902992], [72.94152832, 18.94902611], [72.94152832, 18.94930077], [72.94180298, 18.94930649], [72.94180298, 18.94986153], [72.9420929, 18.94985962], [72.9420929, 18.95013809], [72.94264221, 18.95013809], [72.94264221, 18.95041847], [72.94291687, 18.95041847], [72.94291687, 18.95070076], [72.94319153, 18.95069504], [72.94319153, 18.9509716], [72.94346619, 18.9509697], [72.94346619, 18.95124817], [72.94403076, 18.95124817], [72.94403076, 18.95152855], [72.94431305, 18.95152855], [72.94431305, 18.95181084], [72.94458008, 18.95180511], [72.94458008, 18.95208359], [72.94486237, 18.95207977], [72.94486237, 18.95236015], [72.94512939, 18.95236015], [72.94512939, 18.95292282], [72.94541931, 18.95292282], [72.94541931, 18.95430946], [72.94569397, 18.95430565], [72.94569397, 18.95557022], [72.94569397, 18.95569229], [72.94596863, 18.95569229], [72.94596863, 18.95598984], [72.94596863, 18.95625114], [72.94613647, 18.95624924], [72.94625092, 18.95624924], [72.94625854, 18.95643044], [72.94626617, 18.95652962], [72.9465332, 18.95652962], [72.9465332, 18.95681], [72.94680786, 18.95681], [72.94680786, 18.95736122], [72.94708252, 18.95736122], [72.94708252, 18.95763969], [72.94736481, 18.95763969], [72.94736481, 18.95819664], [72.94763947, 18.95819092], [72.94763947, 18.95903015], [72.94791412, 18.95902824], [72.94791412, 18.95958328], [72.94818878, 18.95957947], [72.94818878, 18.96042061], [72.94847107, 18.96041679], [72.94847107, 18.96112061], [72.94847107, 18.96125031], [72.94875336, 18.96125031], [72.94875336, 18.96167755], [72.94875336, 18.96208382], [72.94902802, 18.96208382], [72.94902802, 18.9622097], [72.94902802, 18.96236038], [72.94930267, 18.96236038], [72.94930267, 18.96264076], [72.94958496, 18.96263885], [72.94958496, 18.96291733], [72.95041656, 18.96291733], [72.95041656, 18.96180534], [72.95014191, 18.96181107], [72.95014191, 18.96070099], [72.94985962, 18.96070099], [72.94985962, 18.96014023], [72.94957733, 18.96014023], [72.94957733, 18.95985031], [72.94930267, 18.95986176], [72.94930267, 18.95930672], [72.94902802, 18.95930672], [72.94902802, 18.95874977], [72.94875336, 18.95874977], [72.94875336, 18.95819092], [72.94847107, 18.95819664], [72.94847107, 18.95736122], [72.94818878, 18.95736122], [72.94818878, 18.95681], [72.94790649, 18.95681], [72.94790649, 18.95625114], [72.94763947, 18.95625114], [72.94763947, 18.95541954], [72.94735718, 18.95541954], [72.94735718, 18.95458031], [72.94708252, 18.95458221], [72.94708252, 18.95402718], [72.94680786, 18.95404053], [72.94680786, 18.95347023], [72.94708252, 18.95347023], [72.94708252, 18.9529171], [72.94763947, 18.95292282], [72.94763947, 18.95264244], [72.94819641, 18.95263863], [72.94819641, 18.95319366], [72.94847107, 18.95319176], [72.94847107, 18.95404053], [72.94875336, 18.95404053], [72.94875336, 18.95486069], [72.94902802, 18.95486069], [72.94902802, 18.95541954], [72.94930267, 18.95541573], [72.94930267, 18.95569229], [72.94957733, 18.95569038], [72.94957733, 18.95625114], [72.94985962, 18.95625114], [72.94985962, 18.95681], [72.95014191, 18.95681], [72.95014191, 18.95763969], [72.95041656, 18.95763969], [72.95041656, 18.95819664], [72.95069122, 18.95819092], [72.95069122, 18.95874977], [72.95097351, 18.95874977], [72.95097351, 18.95958328], [72.9512558, 18.95957947], [72.9512558, 18.96014023], [72.95153046, 18.96014023], [72.95153046, 18.96042061], [72.95181274, 18.96042061], [72.95181274, 18.96014023], [72.95263672, 18.96014023], [72.95263672, 18.96070099], [72.95291901, 18.96070099], [72.95291901, 18.96125031], [72.95318604, 18.96125031], [72.95318604, 18.96153069], [72.95347595, 18.96152878], [72.95347595, 18.96208382], [72.95375061, 18.96208], [72.95375061, 18.96236038], [72.95402527, 18.96236038], [72.95402527, 18.96291733], [72.95430756, 18.96291733], [72.95430756, 18.96347237], [72.95458221, 18.96347046], [72.95458221, 18.96375084], [72.95485687, 18.96375084], [72.95485687, 18.9643116], [72.95430756, 18.96430588], [72.95430756, 18.96458244], [72.95458221, 18.96458054], [72.95458221, 18.96486092], [72.95485687, 18.96486092], [72.95485687, 18.96513939], [72.95513916, 18.96513939], [72.95513916, 18.96569443], [72.95540619, 18.96569061], [72.95540619, 18.96681023], [72.95569611, 18.96681023], [72.95569611, 18.96820068], [72.95540619, 18.96820068], [72.95540619, 18.96875191], [72.95513916, 18.96875191], [72.95513916, 18.96903992], [72.95485687, 18.96903992], [72.95485687, 18.96931076], [72.95458221, 18.96930313], [72.95458221, 18.9695816], [72.95402527, 18.9695816], [72.95402527, 18.96986389], [72.95375061, 18.96986008], [72.95375061, 18.97014046], [72.95347595, 18.97014046], [72.95347595, 18.97125053], [72.95375061, 18.97125053], [72.95375061, 18.97153091], [72.95432281, 18.97153091], [72.95432281, 18.97180939], [72.95458221, 18.97180939], [72.95458221, 18.97236061], [72.95485687, 18.97236061], [72.95485687, 18.97264099], [72.95513916, 18.97263908], [72.95513916, 18.97319412], [72.95541382, 18.97319412], [72.95541382, 18.9734726], [72.95569611, 18.97347069], [72.95569611, 18.97402954], [72.95680237, 18.97402954], [72.95680237, 18.97347069], [72.95735931, 18.9734726], [72.95735931, 18.97319412], [72.9595871, 18.97319412], [72.9595871, 18.9734726], [72.95986176, 18.9734726], [72.95986176, 18.97319412], [72.96013641, 18.97319412], [72.96013641, 18.97263908], [72.9604187, 18.97264099], [72.9604187, 18.97236061], [72.96069336, 18.97236061], [72.96069336, 18.97208023], [72.96097565, 18.97208595], [72.96097565, 18.9715271], [72.96125031, 18.97153091], [72.96125031, 18.97125053], [72.96151733, 18.97125053], [72.96151733, 18.97068977], [72.96180725, 18.9706955], [72.96180725, 18.97041702], [72.96208191, 18.97042084], [72.96208191, 18.96986008], [72.9623642, 18.96986389], [72.9623642, 18.9695816], [72.96263885, 18.9695816], [72.96263885, 18.96902847], [72.96290588, 18.96903992], [72.96290588, 18.96875191], [72.9631958, 18.96875191], [72.9631958, 18.96846962], [72.96347046, 18.96847153], [72.96347046, 18.96791649], [72.96375275, 18.9679203], [72.96375275, 18.96764183], [72.9640274, 18.96764183], [72.9640274, 18.96735954], [72.96458435, 18.96736336], [72.96458435, 18.96708107], [72.96485901, 18.96708107], [72.96485901, 18.96680641], [72.9668045, 18.96680641], [72.9668045, 18.96708107], [72.96763611, 18.96708107], [72.96763611, 18.96680641], [72.96819305, 18.96681023], [72.96819305, 18.96653175], [72.96848297, 18.96653175], [72.96848297, 18.96624947], [72.96902466, 18.96624947], [72.9690094, 18.96598053], [72.9695816, 18.96598053], [72.9695816, 18.96569061], [72.96986389, 18.96569443], [72.96985626, 18.9654007], [72.97013855, 18.96542168], [72.97013855, 18.96513939], [72.97041321, 18.96513939], [72.97041321, 18.96458054], [72.9706955, 18.96458244], [72.9706955, 18.96430588], [72.97125244, 18.9643116], [72.97125244, 18.96402931], [72.9715271, 18.96402931], [72.9715271, 18.96375084], [72.97206879, 18.96375084], [72.97206879, 18.96347046], [72.9751358, 18.96347237], [72.9751358, 18.96319389], [72.97541809, 18.96319389], [72.97541809, 18.96291733], [72.97736359, 18.96291733], [72.97736359, 18.96263885], [72.97930908, 18.96263885], [72.97930908, 18.96291733], [72.9798584, 18.96291733], [72.9798584, 18.96319389], [72.98097229, 18.96319389], [72.98097229, 18.96347237], [72.98152924, 18.96347046], [72.98152924, 18.96375084], [72.98179626, 18.96375084], [72.98179626, 18.9643116], [72.98208618, 18.9643116], [72.98208618, 18.96486092], [72.98236084, 18.96486092], [72.98236084, 18.96542168], [72.98264313, 18.96542168], [72.98264313, 18.96598053], [72.98291779, 18.96598053], [72.98291779, 18.96624947], [72.98319244, 18.96624947], [72.98319244, 18.96681023], [72.98347473, 18.96680641], [72.98347473, 18.96736336], [72.98374939, 18.96735954], [72.98374939, 18.9679203], [72.98402405, 18.96791649], [72.98402405, 18.96847153], [72.98429871, 18.96846962], [72.98429871, 18.96903992], [72.98458099, 18.96902847], [72.98458099, 18.9695816], [72.98486328, 18.9695816], [72.98486328, 18.96986389], [72.98542023, 18.96986008], [72.98542023, 18.97014046], [72.98625183, 18.97014046], [72.98625183, 18.96986008], [72.98652649, 18.96986389], [72.98652649, 18.9695816], [72.98680878, 18.9695816], [72.98680878, 18.96902847], [72.98707581, 18.96903992], [72.98707581, 18.96875191], [72.98737335, 18.96875191], [72.98735809, 18.96847153], [72.98819733, 18.96847153], [72.98819733, 18.96819305], [72.99014282, 18.96820068], [72.99014282, 18.9679203], [72.99317932, 18.9679203], [72.99317932, 18.96820068], [72.99485779, 18.96819305], [72.99485779, 18.96847153], [72.99623871, 18.96846962], [72.99623871, 18.96875191], [72.99680328, 18.96875191], [72.99680328, 18.96903992], [72.99736023, 18.96903992], [72.99736023, 18.96931076], [72.99791718, 18.96930313], [72.99791718, 18.9695816], [72.99847412, 18.9695816], [72.99847412, 18.96986389], [72.99903107, 18.96986008], [72.99903107, 18.97014046], [72.99958038, 18.97014046], [72.99958038, 18.97042084], [73.00013733, 18.97042084], [73.00041962, 18.97041702], [73.00041962, 18.9706955], [73.00125122, 18.97068977], [73.00125122, 18.97125053], [73.00237274, 18.97125053], [73.00237274, 18.97180939], [73.00263977, 18.97180557], [73.00263977, 18.97208595], [73.0029068, 18.97208023], [73.0029068, 18.97236061], [73.00319672, 18.97236061], [73.00319672, 18.97264099], [73.00347137, 18.97264099], [73.00347137, 18.97291946], [73.00375366, 18.97291756], [73.00375366, 18.97319412], [73.00402832, 18.97319412], [73.00402832, 18.9734726], [73.00430298, 18.97347069], [73.00430298, 18.97375107], [73.00402832, 18.97375107], [73.00402832, 18.97430992], [73.00374603, 18.97430992], [73.00374603, 18.97541809], [73.00485992, 18.97541809], [73.00485992, 18.97513962], [73.00569153, 18.97513962], [73.00569153, 18.97541809], [73.00596619, 18.97541809], [73.00596619, 18.97624969], [73.00569153, 18.97624969], [73.00569153, 18.97652817], [73.00597382, 18.97652817], [73.00597382, 18.97680473], [73.00680542, 18.97680473], [73.00680542, 18.97708321], [73.00902557, 18.97708321], [73.00902557, 18.97680473], [73.01125336, 18.97680473], [73.01125336, 18.97708321], [73.01180267, 18.97708321], [73.01180267, 18.97736168], [73.01207733, 18.97735977], [73.01207733, 18.97763824], [73.01264191, 18.97763824], [73.01264191, 18.97792053], [73.01291656, 18.97791672], [73.01291656, 18.97847176], [73.01346588, 18.97846985], [73.01346588, 18.97874832], [73.01374817, 18.97874832], [73.01374817, 18.97903252], [73.01431274, 18.97903252], [73.01431274, 18.9793129], [73.01486206, 18.97930527], [73.01486206, 18.97958374], [73.01513672, 18.97958183], [73.01513672, 18.97986031], [73.01568604, 18.97986031], [73.01568604, 18.98014259], [73.01625061, 18.98014259], [73.01625061, 18.98042107], [73.0165329, 18.98042107], [73.0165329, 18.98097992], [73.01708221, 18.98097992], [73.01708221, 18.98264122], [73.01734924, 18.98264122], [73.01734924, 18.98374939], [73.01708221, 18.98374939], [73.01708221, 18.98542023], [73.01680756, 18.98541641], [73.01680756, 18.98597145], [73.01708221, 18.98596954], [73.01708221, 18.9865303], [73.01734924, 18.9865303], [73.01734924, 18.98681068], [73.01902771, 18.98680687], [73.01902771, 18.98708344], [73.01930237, 18.98708344], [73.01930237, 18.98736191], [73.01985931, 18.98736], [73.01985931, 18.98764038], [73.0201416, 18.98764038], [73.0201416, 18.98792076], [73.02041626, 18.98791885], [73.02041626, 18.98819351], [73.02069092, 18.98819351], [73.02069092, 18.98847198], [73.02097321, 18.98847008], [73.02097321, 18.98903084], [73.02124786, 18.98903084], [73.02124786, 18.98986053], [73.02153015, 18.98986053], [73.02153015, 18.99014854], [73.02179718, 18.99014854], [73.02179718, 18.99041748], [73.0220871, 18.99041748], [73.0220871, 18.99069405], [73.02236176, 18.99069405], [73.02236176, 18.99041748], [73.02263641, 18.99041748], [73.02263641, 18.99014854], [73.02319336, 18.9901371], [73.02319336, 18.99097252], [73.02402496, 18.99097252], [73.02402496, 18.99069405], [73.02430725, 18.99069405], [73.02430725, 18.99041748], [73.02458191, 18.99041748], [73.02458191, 18.99014854], [73.02430725, 18.99014854], [73.02430725, 18.98986053], [73.02458191, 18.98986053], [73.02458191, 18.98958015], [73.0248642, 18.98958397], [73.0248642, 18.9893055], [73.02513885, 18.98931122], [73.02513885, 18.98903084], [73.02625275, 18.98903084], [73.02625275, 18.98875046], [73.02735901, 18.98875046], [73.02735901, 18.98903084], [73.0276413, 18.98902893], [73.0276413, 18.98958397], [73.02735901, 18.98958015], [73.02735901, 18.99041748], [73.02708435, 18.99041748], [73.02708435, 18.99069405], [73.02735901, 18.99069023], [73.02735901, 18.99124908], [73.0276413, 18.99124908], [73.0276413, 18.9920826], [73.02819061, 18.9920826], [73.02819824, 18.99180603], [73.0284729, 18.99181175], [73.0284729, 18.99124908], [73.02902985, 18.99124908], [73.02902985, 18.99153137], [73.02960205, 18.99153137], [73.02960205, 18.99181175], [73.02986145, 18.99181175], [73.02986145, 18.99235916], [73.03013611, 18.99235916], [73.03013611, 18.99263954], [73.03098297, 18.99263954], [73.03098297, 18.99292183], [73.03125, 18.99291611], [73.03125, 18.99319458], [73.03151703, 18.99319077], [73.03151703, 18.99374962], [73.03180695, 18.99374962], [73.03180695, 18.99430466], [73.0320816, 18.99430466], [73.0320816, 18.99458122], [73.03234863, 18.99458122], [73.03234863, 18.99681091], [73.0320816, 18.99680328], [73.0320816, 18.99708557], [73.03180695, 18.99707985], [73.03180695, 18.99792099], [73.0320816, 18.99791718], [73.0320816, 18.99819565], [73.03236389, 18.99819565], [73.03234863, 18.99915123], [73.03234863, 18.99930954], [73.03180695, 18.99930573], [73.03180695, 18.9995842], [73.03151703, 18.99958038], [73.03152466, 19.00013924], [73.03152466, 19.00069427], [73.03125, 19.00069427], [73.03125, 19.00097275], [73.03098297, 19.00097084], [73.03098297, 19.00125122], [73.0304184, 19.00125122], [73.0304184, 19.00152969], [73.03013611, 19.00152969], [73.03013611, 19.00180817], [73.02986145, 19.00180817], [73.02986145, 19.00209045], [73.02928925, 19.00209045], [73.02928925, 19.00180817], [73.02819824, 19.00180817], [73.02819061, 19.00152969], [73.02625275, 19.00152969], [73.02625275, 19.00180817], [73.02597046, 19.00180817], [73.02597046, 19.00209045], [73.02541351, 19.00208282], [73.02541351, 19.0023613], [73.02375031, 19.0023613], [73.02375031, 19.00208282], [73.02319336, 19.00209045], [73.02319336, 19.00152969], [73.01985931, 19.00152969], [73.01985931, 19.00097084], [73.01958466, 19.00097275], [73.01958466, 19.00013924], [73.01957703, 18.99958038], [73.01902771, 18.9995842], [73.01902771, 18.99930573], [73.01763916, 18.99930954], [73.01763916, 18.99901962], [73.01708221, 18.99902725], [73.01708221, 18.99875069], [73.01680756, 18.99875069], [73.01680756, 18.99847031], [73.01597595, 18.99847031], [73.01597595, 18.99875069], [73.01457977, 18.99875069], [73.01457977, 18.99902725], [73.01403046, 18.99902725], [73.01403046, 18.99875069], [73.01264191, 18.99875069], [73.01264191, 18.99902725], [73.01180267, 18.99902725], [73.01180267, 18.99875069], [73.00875092, 18.99875069], [73.00875092, 18.9995842], [73.00791931, 18.99958038], [73.00791931, 19.00014114], [73.00791931, 19.00041962], [73.00763702, 19.00041771], [73.00763702, 19.00069427], [73.00680542, 19.00069427], [73.00680542, 19.00097275], [73.00653076, 19.00097084], [73.00653076, 19.00125122], [73.00596619, 19.00125122], [73.00596619, 19.00152969], [73.00374603, 19.00152969], [73.00374603, 19.00125122], [73.00319672, 19.00125122], [73.00319672, 19.00152969], [73.0029068, 19.00152969], [73.0029068, 19.00291824], [73.00263977, 19.00291634], [73.00263977, 19.00347137], [73.00235748, 19.00347137], [73.00235748, 19.00486183], [73.00208282, 19.00485992], [73.00208282, 19.00625038], [73.00180817, 19.00625038], [73.00180817, 19.00681114], [73.00152588, 19.00681114], [73.00152588, 19.0098629], [73.00180817, 19.0098629], [73.00180817, 19.0118103], [73.00152588, 19.01180649], [73.00152588, 19.01236153], [73.00180817, 19.01235962], [73.00180817, 19.01264], [73.00208282, 19.01264], [73.00208282, 19.01432037], [73.00180817, 19.01430511], [73.00180817, 19.01458359], [73.00152588, 19.01458359], [73.00152588, 19.01486206], [73.00096893, 19.01486015], [73.00096893, 19.01542091], [73.00068665, 19.01542091], [73.00068665, 19.01680756], [73.00096893, 19.01680756], [73.00096893, 19.01736069], [73.00125122, 19.01736069], [73.00125122, 19.01763916], [73.00152588, 19.01763916], [73.00152588, 19.01792145], [73.00180817, 19.01791573], [73.00180817, 19.0181942], [73.00208282, 19.0181942], [73.00208282, 19.01847267], [73.00237274, 19.01847076], [73.00237274, 19.01903152], [73.00263977, 19.01903152], [73.00263977, 19.0193119], [73.00291443, 19.01930618], [73.00291443, 19.02069473], [73.00263977, 19.02069473], [73.00263977, 19.0209713], [73.0029068, 19.02096939], [73.0029068, 19.02124977], [73.00319672, 19.02124977], [73.00319672, 19.02153015], [73.00347137, 19.02152824], [73.00347137, 19.02180481], [73.00319672, 19.02180481], [73.00319672, 19.02236366], [73.00347137, 19.02235985], [73.00347137, 19.02292061], [73.00319672, 19.02292061], [73.00319672, 19.02486038], [73.00347137, 19.02486038], [73.00347137, 19.02542114], [73.00374603, 19.02542114], [73.00374603, 19.02626038], [73.00402832, 19.02626038], [73.00402832, 19.02763939], [73.00374603, 19.02763939], [73.00374603, 19.02932167], [73.00347137, 19.02930641], [73.00347137, 19.02958298], [73.00319672, 19.02958107], [73.00319672, 19.03013992], [73.00291443, 19.03013992], [73.00291443, 19.03097153], [73.00263977, 19.03096962], [73.00263977, 19.03124809], [73.00235748, 19.03124809], [73.00235748, 19.03236008], [73.00208282, 19.03235817], [73.00208282, 19.03292274], [73.00180817, 19.03292274], [73.00180817, 19.03430939], [73.00152588, 19.03430557], [73.00152588, 19.03458214], [73.00180817, 19.03458023], [73.00180817, 19.03541946], [73.00152588, 19.03541756], [73.00152588, 19.03569221], [73.00125122, 19.03569221], [73.00125122, 19.0359745], [73.00096893, 19.03597069], [73.00096893, 19.03625107], [73.00068665, 19.03625107], [73.00068665, 19.03680992], [73.00041962, 19.03680611], [73.00041962, 19.03708458], [73.00068665, 19.03708076], [73.00068665, 19.03736115], [73.00041962, 19.03736115], [73.00041962, 19.03763962], [73.00069427, 19.03763962], [73.00069427, 19.03958321], [73.00041962, 19.03957939], [73.00041962, 19.04042053], [73.00013733, 19.04042053], [72.99958038, 19.04041672], [72.99958038, 19.04097176], [72.99930573, 19.04097176], [72.99930573, 19.04208374], [72.99903107, 19.04207993], [72.99903107, 19.04375076], [72.99874878, 19.04375076], [72.99874878, 19.04486084], [72.99846649, 19.04486084], [72.99846649, 19.04874992], [72.99819183, 19.04874992], [72.99819183, 19.0490303], [72.99791718, 19.0490284], [72.99791718, 19.04958153], [72.99764252, 19.04957962], [72.99764252, 19.05014038], [72.99736023, 19.05014038], [72.99736023, 19.05042076], [72.99708557, 19.05041695], [72.99708557, 19.05097389], [72.99680328, 19.05097008], [72.99680328, 19.05125046], [72.99652863, 19.05125046], [72.99652863, 19.05153084], [72.99623871, 19.05153084], [72.99623871, 19.05181122], [72.99597168, 19.05181122], [72.99597168, 19.05264091], [72.99569702, 19.05263901], [72.99568176, 19.05318069], [72.9954071, 19.05319977], [72.9954071, 19.05375099], [72.99514008, 19.05375099], [72.99514008, 19.05430984], [72.99485779, 19.05430984], [72.99485779, 19.05486107], [72.99458313, 19.05486107], [72.99458313, 19.05541992], [72.99430847, 19.05541611], [72.99430847, 19.05597305], [72.99402618, 19.05597115], [72.99402618, 19.05625916], [72.99430847, 19.05624962], [72.99430847, 19.05680466], [72.99402618, 19.05680466], [72.99402618, 19.05708313], [72.99375153, 19.05708122], [72.99375153, 19.05791855], [72.99346924, 19.05791664], [72.99346924, 19.05847168], [72.99317932, 19.05846977], [72.99317932, 19.05874825], [72.99291992, 19.05874825], [72.99291992, 19.05903244], [72.99236298, 19.05902863], [72.99236298, 19.05930519], [72.99208069, 19.05930519], [72.99208069, 19.05958366], [72.99124908, 19.05958176], [72.99124908, 19.05986023], [72.99069214, 19.05986023], [72.99069214, 19.06014252], [72.98986053, 19.06014252], [72.98986053, 19.0604229], [72.98874664, 19.06041718], [72.98874664, 19.06069374], [72.98847198, 19.06069374], [72.98847198, 19.06097031], [72.98819733, 19.06097031], [72.98819733, 19.06108093], [72.98819733, 19.06125259], [72.98792267, 19.06125259], [72.98792267, 19.06153107], [72.98707581, 19.06153107], [72.98707581, 19.06180954], [72.98680878, 19.06180573], [72.98680878, 19.06208229], [72.98568726, 19.06208038], [72.98568726, 19.06236076], [72.98486328, 19.06236076], [72.98486328, 19.06264114], [72.98236084, 19.06264114], [72.98236084, 19.06236076], [72.98014069, 19.06236076], [72.98014069, 19.06208038], [72.97846985, 19.06208229], [72.97846985, 19.06180573], [72.9779129, 19.06180954], [72.9779129, 19.06153107], [72.97598267, 19.06153107], [72.97598267, 19.06125259], [72.97458649, 19.06125259], [72.97458649, 19.06097031], [72.9734726, 19.06097031], [72.9734726, 19.06069374], [72.97264099, 19.06069374], [72.97264099, 19.06041718], [72.9715271, 19.0604229], [72.9715271, 19.06014252], [72.97070313, 19.06014252], [72.97070313, 19.05986023], [72.96985626, 19.05986023], [72.96985626, 19.05958176], [72.9695816, 19.05958176], [72.9695816, 19.05986023], [72.96847534, 19.05986023], [72.96847534, 19.05958366], [72.96819305, 19.05958366], [72.96819305, 19.05930519], [72.9679184, 19.05930519], [72.9679184, 19.05902863], [72.96626282, 19.05903244], [72.96626282, 19.05874825], [72.96541595, 19.05874825], [72.96541595, 19.05846977], [72.9631958, 19.05847168], [72.9631958, 19.05819511], [72.96263885, 19.05820084], [72.96263885, 19.05791855], [72.96235657, 19.05791855], [72.96235657, 19.05680084], [72.96208191, 19.05680466], [72.96208191, 19.0518055], [72.96235657, 19.05181122], [72.96235657, 19.04957962], [72.96208191, 19.04958153], [72.96208191, 19.04930305], [72.96235657, 19.04931068], [72.96235657, 19.0490303], [72.96208191, 19.0490303], [72.96208191, 19.04706764], [72.96180725, 19.0470829], [72.96180725, 19.04680634], [72.96208191, 19.04681015], [72.96208191, 19.04653168], [72.96180725, 19.04653168], [72.96180725, 19.04569054], [72.96152496, 19.04569435], [72.96152496, 19.04541588], [72.96125031, 19.0454216], [72.96125031, 19.04236031], [72.96097565, 19.04236031], [72.96097565, 19.03958321], [72.96069336, 19.03958321], [72.96069336, 19.03847313], [72.9604187, 19.03847313], [72.9604187, 19.03791428], [72.96012878, 19.03792], [72.96012878, 19.03680992], [72.95986176, 19.03680992], [72.95986176, 19.03597069], [72.9595871, 19.0359745], [72.9595871, 19.03569221], [72.95930481, 19.03569221], [72.95930481, 19.03541756], [72.95903015, 19.03541946], [72.95903015, 19.03486061], [72.95871735, 19.0348568], [72.9587326, 19.03458023], [72.95874786, 19.03430557], [72.95847321, 19.03430939], [72.95847321, 19.03403282], [72.95819092, 19.03403282], [72.95819092, 19.03347015], [72.95791626, 19.03347015], [72.95791626, 19.03319359], [72.9576416, 19.03319359], [72.9576416, 19.03263855], [72.95735931, 19.03264236], [72.95735931, 19.03206825], [72.95708466, 19.03208351], [72.95708466, 19.03157043], [72.95708466, 19.03069496], [72.95680237, 19.03070068], [72.95680237, 19.03013992], [72.95652771, 19.03013992], [72.95652771, 19.02932167], [72.95625305, 19.02932167], [72.95625305, 19.02902985], [72.95597076, 19.02902985], [72.95597076, 19.02874947], [72.95569611, 19.02874947], [72.95569611, 19.02819061], [72.95541382, 19.02819443], [72.95541382, 19.02763939], [72.95513916, 19.02763939], [72.95513916, 19.02736092], [72.95485687, 19.02736092], [72.95485687, 19.02708054], [72.95402527, 19.02708244], [72.95402527, 19.02680779], [72.95347595, 19.02680969], [72.95347595, 19.02597046], [72.95319366, 19.02597237], [72.95319366, 19.0256958], [72.95263672, 19.0256958], [72.95263672, 19.02541733], [72.95207977, 19.02542114], [72.95207977, 19.02514076], [72.95181274, 19.02514076], [72.95181274, 19.02486038], [72.95153046, 19.02486038], [72.95153046, 19.02431107], [72.95096588, 19.02431107], [72.95096588, 19.02403069], [72.95069122, 19.02403069], [72.95069122, 19.02375031], [72.95041656, 19.02375031], [72.95041656, 19.02346992], [72.95014191, 19.02347374], [72.95014191, 19.02319527], [72.94985962, 19.02319527], [72.94985962, 19.02263832], [72.94957733, 19.02264023], [72.94957733, 19.02235985], [72.94930267, 19.02236366], [72.94930267, 19.02180481], [72.94847107, 19.02180481], [72.94847107, 19.02152824], [72.94790649, 19.02153015], [72.94790649, 19.02124977], [72.94763947, 19.02124977], [72.94763947, 19.02069283], [72.94736481, 19.02069473], [72.94736481, 19.02041626], [72.9465332, 19.02042007], [72.9465332, 19.02012825], [72.94625092, 19.02013969], [72.94625092, 19.01985931], [72.94568634, 19.01985931], [72.94568634, 19.01958084], [72.94513702, 19.01958275], [72.94513702, 19.01902771], [72.94486237, 19.01903152], [72.94486237, 19.01874924], [72.94458008, 19.01874924], [72.94458008, 19.01903152], [72.94431305, 19.01903152], [72.94431305, 19.01874924], [72.94403076, 19.01874924], [72.94403076, 19.01847076], [72.94374847, 19.01847267], [72.94374847, 19.0181942], [72.94347382, 19.0181942], [72.94347382, 19.01791763], [72.94317627, 19.01792145], [72.94291687, 19.01792145], [72.94291687, 19.01763916], [72.94264221, 19.01763916], [72.94264221, 19.01736069], [72.94235992, 19.01736069], [72.94235992, 19.01708984], [72.94097137, 19.01708984], [72.94097137, 19.01680756], [72.9404068, 19.01680756], [72.9404068, 19.01652908], [72.94013977, 19.01652908], [72.94013977, 19.01625061], [72.93985748, 19.01625061], [72.93985748, 19.01597023], [72.93902588, 19.01597214], [72.93902588, 19.01569366], [72.93875122, 19.01569366], [72.93875122, 19.0154171], [72.93846893, 19.01542091], [72.93846893, 19.01514053], [72.93818665, 19.01514053], [72.93818665, 19.01486015], [72.93791962, 19.01486206], [72.93791962, 19.01458359], [72.93763733, 19.01458359], [72.93763733, 19.01430511], [72.93736267, 19.01432037], [72.93736267, 19.01403046], [72.93653107, 19.01403046], [72.93653107, 19.01375008], [72.93624878, 19.01375008], [72.93624878, 19.0134697], [72.93569183, 19.0134716], [72.93569183, 19.01319695], [72.93541718, 19.01320076], [72.93541718, 19.01292038], [72.93514252, 19.01292038], [72.93514252, 19.01264], [72.93486023, 19.01264], [72.93486023, 19.01235962], [72.93458557, 19.01236153], [72.93458557, 19.01208305], [72.93430328, 19.01208305], [72.93430328, 19.01180649], [72.93402863, 19.0118103], [72.93402863, 19.01152992], [72.93374634, 19.01152992], [72.93374634, 19.01124954], [72.93289948, 19.01124954], [72.93289948, 19.01069069], [72.93235779, 19.0106926], [72.93235779, 19.01041412], [72.93180847, 19.01041985], [72.93180847, 19.0098629], [72.93152618, 19.0098629], [72.93152618, 19.00958061], [72.93096924, 19.00958443], [72.93096924, 19.00930405], [72.93015289, 19.00930977], [72.93015289, 19.00875282], [72.92986298, 19.00875282], [72.92986298, 19.00847054], [72.92930603, 19.00847054], [72.92930603, 19.00819206], [72.92874908, 19.00819206], [72.92874908, 19.0079174], [72.9284668, 19.00792122], [72.9284668, 19.00764275], [72.92819214, 19.00764275], [72.92819214, 19.00736046], [72.92763519, 19.00736046], [72.92763519, 19.00708389], [72.92736053, 19.00708389], [72.92736053, 19.00680542], [72.92679596, 19.00681114], [72.92679596, 19.00653267], [72.92652893, 19.00653267], [72.92652893, 19.00625038], [72.92597198, 19.00625038], [72.92597198, 19.00597191], [72.92569733, 19.00597191], [72.92569733, 19.00569534], [72.92514038, 19.00570107], [72.92514038, 19.00542068], [72.92457581, 19.00542068], [72.92457581, 19.00515175], [72.92430878, 19.00515175], [72.92430878, 19.00457954], [72.92402649, 19.00458336], [72.92402649, 19.00430489], [72.92430878, 19.00430489], [72.92430878, 19.00402832], [72.92375183, 19.00402832], [72.92375183, 19.00374985], [72.92318726, 19.00374985], [72.92318726, 19.00346947], [72.92263794, 19.00347137], [72.92263794, 19.00319481], [72.92208099, 19.00319481], [72.92208099, 19.00291634], [72.92180634, 19.00291824], [72.92180634, 19.00209045], [72.92151642, 19.00209045], [72.92151642, 19.00180817], [72.92069244, 19.00180817], [72.92069244, 19.00152969], [72.92014313, 19.00152969], [72.92014313, 19.00125122], [72.91986084, 19.00125122], [72.91986084, 19.00097084], [72.91958618, 19.00097275], [72.91958618, 19.00069427], [72.91902924, 19.00069427], [72.91902924, 19.00013924], [72.91847229, 19.00014114], [72.91847229, 18.99958038], [72.91374969, 18.99958038], [72.91374969, 18.99986076], [72.91347504, 18.99986076], [72.91347504, 18.9995842], [72.91319275, 18.9995842], [72.91319275, 18.99930573], [72.91179657, 18.99930954], [72.91179657, 18.99901962], [72.91152954, 18.99901962], [72.91152954, 18.99930954], [72.90875244, 18.99930573], [72.90875244, 18.9995842], [72.90736389, 18.9995842], [72.90736389, 18.99930573], [72.90680695, 18.99930954], [72.90680695, 18.99818993], [72.90631104, 18.99819183], [72.90597534, 18.99819565], [72.90597534, 18.9976387], [72.90625, 18.99764061], [72.90625, 18.99707985], [72.90652466, 18.99708557], [72.90652466, 18.99652863], [72.90625, 18.99653053], [72.90625, 18.99681091], [72.90597534, 18.99680328], [72.90597534, 18.99708557], [72.90569305, 18.99707985], [72.90569305, 18.99736023], [72.90513611, 18.99736023], [72.90513611, 18.99653053], [72.9054184, 18.99653053], [72.9054184, 18.99596024], [72.90569305, 18.99597359], [72.90569305, 18.99569321], [72.90598297, 18.99570084], [72.90598297, 18.99542046], [72.90625, 18.99542046], [72.90625, 18.99514008], [72.90651703, 18.99514008], [72.90651703, 18.9948597], [72.90680695, 18.99486351], [72.90680695, 18.99458122], [72.9070816, 18.99458122], [72.9070816, 18.99430466], [72.90736389, 18.99430466], [72.90736389, 18.99402809], [72.90763855, 18.99403191], [72.90763855, 18.99374962], [72.90791321, 18.99374962], [72.90791321, 18.99346924], [72.9081955, 18.99347115], [72.9081955, 18.99319458], [72.90847015, 18.99319458], [72.90847015, 18.99291611], [72.90875244, 18.99292183], [72.90875244, 18.99263954], [72.90930176, 18.99263954], [72.90930176, 18.99124908], [72.90791321, 18.99124908], [72.90791321, 18.99153137], [72.9081955, 18.99152756], [72.9081955, 18.9920826], [72.90763855, 18.99208069], [72.90763855, 18.99263954], [72.90736389, 18.99263954], [72.90736389, 18.99319458], [72.9070816, 18.99319458], [72.9070816, 18.99347115], [72.90680695, 18.99346924], [72.90680695, 18.99374962], [72.90651703, 18.99374962], [72.90651703, 18.99403191], [72.90625, 18.99402809], [72.90625, 18.99430466], [72.90597534, 18.99430466], [72.90597534, 18.99486351], [72.90569305, 18.9948597], [72.90569305, 18.99514008], [72.9054184, 18.99514008], [72.9054184, 18.99542046], [72.90486145, 18.99542046], [72.90486145, 18.9948597], [72.90458679, 18.99486351], [72.90458679, 18.99402809], [72.90486145, 18.99403191], [72.90486145, 18.99346924], [72.90513611, 18.99347115], [72.90513611, 18.99263954], [72.9054184, 18.99263954], [72.9054184, 18.99181175], [72.90569305, 18.99181175], [72.90569305, 18.99153137], [72.90625, 18.99153137], [72.90625, 18.99097061], [72.90652466, 18.99097252], [72.90652466, 18.99069405], [72.90597534, 18.99069405], [72.90597534, 18.99041748], [72.9054184, 18.99041748], [72.9054184, 18.99014854], [72.90513611, 18.99014854], [72.90513611, 18.99041748], [72.90486145, 18.99041748], [72.90486145, 18.9920826], [72.90458679, 18.99208069], [72.90458679, 18.99263954], [72.9043045, 18.99263954], [72.9043045, 18.99319458], [72.90402985, 18.99319077], [72.90402985, 18.99570084], [72.90374756, 18.99570084], [72.90374756, 18.99625015], [72.9034729, 18.99625015], [72.9034729, 18.99681091], [72.90319824, 18.99680328], [72.90319824, 18.99708557], [72.90291595, 18.99707985], [72.90291595, 18.99736023], [72.89875031, 18.99736023], [72.89875031, 18.99707985], [72.89763641, 18.99708557], [72.89763641, 18.99680328], [72.89653015, 18.99681091], [72.89653015, 18.99653053], [72.89597321, 18.99652863], [72.89597321, 18.99819565], [72.89653015, 18.99819565], [72.89653015, 18.99791718], [72.89763641, 18.99791718], [72.89763641, 18.99819565], [72.89736176, 18.99819565], [72.89736176, 18.99902725], [72.89678955, 18.99901962], [72.89678955, 18.99930954], [72.89569092, 18.99930954], [72.89569092, 18.99901962], [72.89541626, 18.99902725], [72.89541626, 18.9995842], [72.89524078, 18.9995842], [72.89041901, 18.99958038], [72.89041901, 18.99986076], [72.88986206, 18.99986076], [72.88986206, 18.99958038], [72.88597107, 18.99958038], [72.88597107, 19.00014114], [72.88597107, 19.00374985], [72.88569641, 19.00374985], [72.88569641, 19.00764275], [72.88540649, 19.00764275], [72.88541412, 19.00819206], [72.88513947, 19.00819016], [72.88513947, 19.00902939], [72.88412476, 19.00902939], [72.88181305, 19.00902939], [72.88181305, 19.00875282], [72.88180542, 19.0079174], [72.88069153, 19.00792122], [72.88069153, 19.00764275], [72.87985992, 19.00764275], [72.87985992, 19.00736046], [72.87902832, 19.00736046], [72.87902832, 19.00708389], [72.87430573, 19.00708389], [72.87430573, 19.00680542], [72.87319183, 19.00681114], [72.87319183, 19.00653267], [72.87236023, 19.00653267], [72.87236023, 19.00625038], [72.87097168, 19.00625038], [72.87097168, 19.00597191], [72.87069702, 19.00597191], [72.87069702, 19.00541687], [72.87014008, 19.00542068], [72.87014008, 19.00515175], [72.86930847, 19.00515175], [72.86930847, 19.00485992], [72.86791992, 19.00486183], [72.86791992, 19.00458336], [72.86736298, 19.00458336], [72.86736298, 19.00486183], [72.86569214, 19.00486183], [72.86569214, 19.00458336], [72.86486053, 19.00458336], [72.86486053, 19.00430489], [72.86430359, 19.00430489], [72.86430359, 19.00402832], [72.86403656, 19.00402832], [72.86403656, 19.00374985], [72.86374664, 19.00374985], [72.86374664, 19.00346947], [72.86319733, 19.00347137], [72.86319733, 19.00319481], [72.86264038, 19.00319481], [72.86264038, 19.00291634], [72.86207581, 19.00291824], [72.86207581, 19.00180817], [72.86180878, 19.00180817], [72.86180878, 19.00069046], [72.86152649, 19.00069427], [72.86152649, 19.00041771], [72.86096954, 19.00041962], [72.86096954, 19.00014114], [72.86067963, 19.00014114], [72.86067963, 18.99986076], [72.86042023, 18.99986076], [72.86042023, 18.99958038], [72.86013794, 18.9995842], [72.86013794, 18.99875069], [72.85986328, 18.99875069], [72.85986328, 18.99818993], [72.86013794, 18.99819565], [72.86013794, 18.99791718], [72.86042023, 18.99792099], [72.86042023, 18.99736023], [72.86067963, 18.99736023], [72.86067963, 18.99707985], [72.86096954, 18.99708557], [72.86096954, 18.99652863], [72.86125183, 18.99653053], [72.86125183, 18.99596024], [72.86152649, 18.99597359], [72.86152649, 18.99569321], [72.86042023, 18.99570084], [72.86042023, 18.99403191], [72.86013794, 18.99403191], [72.86013794, 18.99374962], [72.85986328, 18.99374962], [72.85986328, 18.99346924], [72.85874939, 18.99347115], [72.85874939, 18.99319458], [72.85902405, 18.99319458], [72.85902405, 18.99291611], [72.85874939, 18.99292183], [72.85874939, 18.99263954], [72.8584671, 18.99263954], [72.8584671, 18.99235916], [72.85708618, 18.99235916], [72.85708618, 18.99208069], [72.85680389, 18.9920826], [72.85680389, 18.99152756], [72.85708618, 18.99153137], [72.85708618, 18.99097061], [72.85736084, 18.99097252], [72.85736084, 18.9901371], [72.85764313, 18.99014854], [72.85764313, 18.98958015], [72.85791779, 18.98958397], [72.85791779, 18.98902893], [72.85819244, 18.98903084], [72.85819244, 18.9881897], [72.85847473, 18.98819351], [72.85847473, 18.98763847], [72.85874939, 18.98764038], [72.85874939, 18.98707962], [72.85902405, 18.98708344], [72.85902405, 18.9865284], [72.85930634, 18.9865303], [72.85930634, 18.98596954], [72.85958099, 18.98597145], [72.85958099, 18.98541641], [72.85986328, 18.98542023], [72.85986328, 18.98485947], [72.86013794, 18.98486137], [72.86013794, 18.98430634], [72.86042023, 18.98431015], [72.86042023, 18.98347092], [72.86069489, 18.98347473], [72.86069489, 18.98236275], [72.86096954, 18.98236275], [72.86096954, 18.98153114], [72.86067963, 18.98153114], [72.86067963, 18.98125267], [72.86042023, 18.98125267], [72.86042023, 18.98097992], [72.86013794, 18.98097992], [72.86013794, 18.98069191], [72.85986328, 18.98069382], [72.85986328, 18.98041725], [72.85930634, 18.98042107], [72.85930634, 18.98014259], [72.85901642, 18.98014259], [72.85901642, 18.97986031], [72.85874939, 18.97986031], [72.85874939, 18.97958183], [72.85847473, 18.97958374], [72.85847473, 18.97930527], [72.85819244, 18.9793129], [72.85819244, 18.97874832], [72.85791016, 18.97874832], [72.85791016, 18.97846985], [72.8576355, 18.97847176], [72.8576355, 18.97819519], [72.85736084, 18.97819519], [72.85736084, 18.97847176], [72.85624695, 18.97846985], [72.85624695, 18.97874832], [72.85514069, 18.97874832], [72.85514069, 18.97903252], [72.85402679, 18.97903252], [72.85402679, 18.9793129], [72.85263824, 18.9793129], [72.85263824, 18.97874832], [72.8529129, 18.97874832], [72.8529129, 18.97846985], [72.85402679, 18.97847176], [72.85402679, 18.97819519], [72.85486603, 18.97821045], [72.85486603, 18.97792053], [72.85569763, 18.97792053], [72.85569763, 18.97680092], [72.85541534, 18.97680473], [72.85541534, 18.97652817], [72.8548584, 18.97652817], [72.8548584, 18.97680473], [72.85375214, 18.97680473], [72.85375214, 18.97708321], [72.85263824, 18.97708321], [72.85263824, 18.97736168], [72.85124969, 18.97736168], [72.85124969, 18.97680473], [72.85180664, 18.97680473], [72.85180664, 18.97652817], [72.85263824, 18.97652817], [72.85263824, 18.97624969], [72.85402679, 18.97624969], [72.85402679, 18.97597122], [72.85541534, 18.97597313], [72.85541534, 18.97430611], [72.8548584, 18.97430611], [72.8548584, 18.97458267], [72.85375214, 18.97458267], [72.85375214, 18.97486115], [72.85152435, 18.97486115], [72.85152435, 18.97458267], [72.85124969, 18.97458267], [72.85124969, 18.97430611], [72.85151672, 18.97430992], [72.85151672, 18.97402954], [72.8529129, 18.97402954], [72.8529129, 18.97375107], [72.85375214, 18.97375107], [72.85375214, 18.97347069], [72.85346985, 18.9734726], [72.85346985, 18.97291756], [72.85320282, 18.97291946], [72.85320282, 18.97236061], [72.8529129, 18.97236061], [72.8529129, 18.97208023], [72.85180664, 18.97208023], [72.85180664, 18.97236061], [72.85124969, 18.97236061], [72.85124969, 18.97264099], [72.8501358, 18.97264099], [72.8501358, 18.97208023], [72.85041809, 18.97208595], [72.85041809, 18.97125053], [72.85069275, 18.97125053], [72.85069275, 18.97068977], [72.85097504, 18.9706955], [72.85097504, 18.96930313], [72.85151672, 18.96931076], [72.85151672, 18.96903992], [72.8520813, 18.96903992], [72.8520813, 18.96764183], [72.85124969, 18.96764183], [72.85124969, 18.96735954], [72.85097504, 18.96736336], [72.85097504, 18.96708107], [72.85069275, 18.96708107], [72.85069275, 18.96680641], [72.85041809, 18.96681023], [72.85041809, 18.96653175], [72.8501358, 18.96653175], [72.8501358, 18.96624947], [72.84986115, 18.96624947], [72.84986115, 18.96542168], [72.84958649, 18.96542168], [72.84958649, 18.9643116], [72.84929657, 18.9643116], [72.84929657, 18.96318817], [72.84902954, 18.96319389], [72.84902954, 18.96208382], [72.84874725, 18.96208382], [72.84874725, 18.96097183], [72.8484726, 18.96097183], [72.8484726, 18.95958328], [72.84819794, 18.95958328], [72.84819794, 18.95791626], [72.84792328, 18.95792007], [72.84792328, 18.95681], [72.84764099, 18.95681], [72.84764099, 18.95597076], [72.8473587, 18.95597458], [72.8473587, 18.95486069], [72.84707642, 18.95486069], [72.84707642, 18.95375252], [72.84680176, 18.95375252], [72.84680176, 18.94819069], [72.8465271, 18.9481945], [72.8465271, 18.94736099], [72.84625244, 18.94736099], [72.84625244, 18.94625092], [72.84597015, 18.94625092], [72.84597015, 18.94431114], [72.84570313, 18.94431114], [72.84570313, 18.94153023], [72.84541321, 18.94153023], [72.84541321, 18.93985939], [72.84513855, 18.93985939], [72.84513855, 18.93930626], [72.84485626, 18.93931007], [72.84485626, 18.93736076], [72.8445816, 18.93736076], [72.8445816, 18.93708038], [72.84430695, 18.9370842], [72.84430695, 18.93680573], [72.84401703, 18.93680763], [72.84401703, 18.93652916], [72.84375, 18.93652916], [72.84375, 18.93597031], [72.84347534, 18.93597221], [72.84347534, 18.93569374], [72.84319305, 18.93569374], [72.84319305, 18.9351387], [72.84348297, 18.93514061], [72.84348297, 18.93375015], [72.84375, 18.93375015], [72.84375, 18.93208122], [72.84402466, 18.93208313], [72.84402466, 18.92986107], [72.84430695, 18.92987061], [72.84430695, 18.92902946], [72.84401703, 18.92902946], [72.84401703, 18.92847061], [72.84347534, 18.92847061], [72.84347534, 18.92819214], [72.84263611, 18.92819214], [72.84263611, 18.92847061], [72.84236145, 18.92847061], [72.84236145, 18.9287529], [72.84208679, 18.9287529], [72.84208679, 18.93124962], [72.8418045, 18.93124962], [72.8418045, 18.93208313], [72.84152985, 18.93208313], [72.84152985, 18.9323616], [72.84069824, 18.9323616], [72.84069061, 18.9304142], [72.84041595, 18.93041992], [72.84041595, 18.93013954], [72.83985901, 18.93013954], [72.83985901, 18.9295845], [72.83958435, 18.9295845], [72.83958435, 18.92930603], [72.83930206, 18.92930984], [72.83930206, 18.92902946], [72.83875275, 18.92902946], [72.83875275, 18.9287529], [72.83847046, 18.9287529], [72.83847046, 18.92847061], [72.8381958, 18.92847061], [72.8381958, 18.92819214], [72.83847046, 18.92819214], [72.83847046, 18.92791748], [72.83875275, 18.92791939], [72.83875275, 18.92764282], [72.83930206, 18.92764282], [72.83930206, 18.92791939], [72.84041595, 18.92791939], [72.84041595, 18.92764282], [72.84069061, 18.92764282], [72.84069061, 18.92736053], [72.84041595, 18.92736053], [72.84041595, 18.92681122], [72.8401413, 18.92681122], [72.8401413, 18.92653275], [72.83957672, 18.92653275], [72.83957672, 18.92625237], [72.83930206, 18.92625237], [72.83930206, 18.92597008], [72.83875275, 18.92597008], [72.83875275, 18.92569542], [72.83847046, 18.9256897], [72.83847046, 18.92541695], [72.83875275, 18.92542267], [72.83875275, 18.92485809], [72.8390274, 18.92486191], [72.8390274, 18.92430496], [72.83930206, 18.92431068], [72.83930206, 18.9240284], [72.83957672, 18.9240284], [72.83957672, 18.92346954], [72.83985901, 18.92347145], [72.83985901, 18.92291641], [72.8401413, 18.92291832], [72.8401413, 18.92235947], [72.8409729, 18.92235947], [72.8409729, 18.92263985], [72.84124756, 18.92263985], [72.84124756, 18.92291832], [72.84152985, 18.92291641], [72.84152985, 18.92319489], [72.8418045, 18.92319489], [72.8418045, 18.92347145], [72.84236145, 18.92347145], [72.84236145, 18.92374992], [72.84263611, 18.92374039], [72.84263611, 18.9240284], [72.8429184, 18.9240284], [72.8429184, 18.92458344], [72.84319305, 18.92458344], [72.84319305, 18.92486191], [72.84375, 18.92485809], [72.84375, 18.92542267], [72.84402466, 18.92541695], [72.84402466, 18.92569351], [72.84430695, 18.92569351], [72.84430695, 18.92597008], [72.84486389, 18.92597008], [72.84486389, 18.92486191], [72.8445816, 18.92486191], [72.8445816, 18.92430496], [72.84430695, 18.92431068], [72.84430695, 18.9240284], [72.84375, 18.9240284], [72.84375, 18.92374039], [72.84347534, 18.92374992], [72.84347534, 18.92347145], [72.84319305, 18.92347145], [72.84319305, 18.92319489], [72.8429184, 18.92319489], [72.8429184, 18.92291641], [72.84263611, 18.92291832], [72.84263611, 18.92235947], [72.84236145, 18.92236137], [72.84236145, 18.9220829], [72.84208679, 18.9220829], [72.84208679, 18.92180634], [72.84179688, 18.92180824], [72.84179688, 18.92152977], [72.84152985, 18.92152977], [72.84152985, 18.92097092], [72.84124756, 18.92097282], [72.84124756, 18.92069435], [72.8409729, 18.92069435], [72.8409729, 18.92041779], [72.84041595, 18.92041969], [72.84041595, 18.92014122], [72.83957672, 18.92014122], [72.83957672, 18.91986084], [72.83875275, 18.91986084], [72.83875275, 18.92014122], [72.8381958, 18.92014122], [72.8381958, 18.92041969], [72.83791351, 18.92041779], [72.83791351, 18.92069435], [72.8373642, 18.92069435], [72.8373642, 18.92097282], [72.83679962, 18.92097092], [72.83679962, 18.92124939], [72.83651733, 18.92124939], [72.83651733, 18.92152977], [72.83625031, 18.92152977], [72.83625031, 18.92180824], [72.83597565, 18.92180634], [72.83597565, 18.9220829], [72.8354187, 18.9220829], [72.8354187, 18.92236137], [72.83486176, 18.92236137], [72.83486176, 18.92180634], [72.83513641, 18.92180824], [72.83513641, 18.92124939], [72.8345871, 18.92124939], [72.8345871, 18.92152977], [72.83403015, 18.92152977], [72.83403015, 18.92124939], [72.83319092, 18.92124939], [72.83319092, 18.92041969], [72.83291626, 18.92041969], [72.83291626, 18.91930962], [72.8326416, 18.91930962], [72.8326416, 18.91847038], [72.83235931, 18.91847229], [72.83235931, 18.91791725], [72.83207703, 18.9179306], [72.83207703, 18.91736031], [72.83180237, 18.91736031], [72.83180237, 18.91707993], [72.83152771, 18.91708565], [72.83152771, 18.91680336], [72.83125305, 18.91681099], [72.83125305, 18.91653061], [72.83097076, 18.91653061], [72.83097076, 18.91625023], [72.83040619, 18.91625023], [72.83040619, 18.91596985], [72.83097076, 18.91597366], [72.83097076, 18.91569519], [72.83125305, 18.91570091], [72.83125305, 18.91457939], [72.83097076, 18.9145813], [72.83097076, 18.91430473], [72.83069611, 18.91430473], [72.83069611, 18.91402817], [72.83040619, 18.91403008], [72.83040619, 18.91374969], [72.83013916, 18.91374969], [72.83013916, 18.91403008], [72.82958221, 18.91403008], [72.82958221, 18.91319084], [72.82930756, 18.91319466], [72.82930756, 18.91291618], [72.8290329, 18.91292191], [72.8290329, 18.91264153], [72.82875061, 18.91264153], [72.82875061, 18.91235924], [72.82847595, 18.91235924], [72.82847595, 18.91208076], [72.82819366, 18.91208267], [72.82819366, 18.91180611], [72.82791901, 18.91180611], [72.82791901, 18.91152763], [72.82763672, 18.91153145], [72.82763672, 18.91124916], [72.82736206, 18.91124916], [72.82736206, 18.91097069], [72.82707977, 18.9109726], [72.82707977, 18.90986061], [72.82680511, 18.90986061], [72.82680511, 18.9090271], [72.82653046, 18.90903091], [72.82653046, 18.90847015], [72.82624817, 18.90847206], [72.82624817, 18.90819359], [72.82597351, 18.90819359], [72.82597351, 18.90791893], [72.82569122, 18.90792084], [72.82569122, 18.90764046], [72.82541656, 18.90764046], [72.82541656, 18.90736008], [72.82514191, 18.90736008], [72.82514191, 18.90764046], [72.82485962, 18.90764046], [72.82485962, 18.90792084], [72.82458496, 18.90791893], [72.82458496, 18.90819359], [72.82430267, 18.90819359], [72.82430267, 18.90847206], [72.82375336, 18.90847206], [72.82375336, 18.90875053], [72.82347107, 18.908741], [72.82347107, 18.90903091], [72.82319641, 18.90903091], [72.82319641, 18.90930748], [72.82291412, 18.90930557], [72.82291412, 18.90958405], [72.82235718, 18.90958023], [72.82235718, 18.90986061], [72.82180023, 18.90986061], [72.82180023, 18.90958023], [72.82152557, 18.90958405], [72.82152557, 18.90930557], [72.82096863, 18.90930748], [72.82096863, 18.90903091], [72.82068634, 18.90903091], [72.82068634, 18.90847015], [72.82096863, 18.90847206], [72.82096863, 18.90819359], [72.82069397, 18.90819359], [72.82069397, 18.90763855], [72.82041931, 18.90764046], [72.82041931, 18.90736008], [72.81986237, 18.90736198], [72.81986237, 18.90708351], [72.81903076, 18.90708351], [72.81903076, 18.90680695], [72.8188858, 18.90680695], [72.81874084, 18.90681076], [72.81874084, 18.90653038], [72.81846619, 18.90653038], [72.81846619, 18.9034729], [72.81819153, 18.90347481], [72.81819153, 18.90263939], [72.81791687, 18.90263939], [72.81791687, 18.90153122], [72.81764221, 18.90153122], [72.81764221, 18.90097046], [72.81735992, 18.90097046], [72.81735992, 18.90041733], [72.8170929, 18.90042114], [72.8170929, 18.90014267], [72.81680298, 18.90014267], [72.81680298, 18.89957047], [72.81652832, 18.89958382], [72.81652832, 18.89902687], [72.81624603, 18.89903259], [72.81624603, 18.8987484], [72.8154068, 18.8987484], [72.8154068, 18.89819908], [72.81513977, 18.89819908], [72.81513977, 18.89735985], [72.81485748, 18.89736176], [72.81485748, 18.89708328], [72.81458282, 18.89708328], [72.81458282, 18.89680481], [72.81430817, 18.89680481], [72.81430817, 18.89624977], [72.81402588, 18.89624977], [72.81402588, 18.89596939], [72.81375122, 18.8959713], [72.81375122, 18.89569473], [72.81346893, 18.89569473], [72.81346893, 18.89513969], [72.81318665, 18.89513969], [72.81318665, 18.89486122], [72.81291962, 18.89486122], [72.81291962, 18.89458084], [72.81263733, 18.89458275], [72.81263733, 18.89402771], [72.81181335, 18.89402962], [72.81181335, 18.89319038], [72.81153107, 18.8931942], [72.81153107, 18.89263916], [72.81096649, 18.89264107], [72.81096649, 18.89236069], [72.80986023, 18.89236069], [72.80986023, 18.89208031], [72.80930328, 18.89208412], [72.80930328, 18.89180565], [72.80847168, 18.89180946], [72.80847168, 18.89097023], [72.80819702, 18.89097214], [72.80819702, 18.89069557], [72.80791473, 18.89069557], [72.80791473, 18.89097214], [72.80764008, 18.89097023], [72.80764008, 18.89180946], [72.8079071, 18.89180946], [72.8079071, 18.89264107], [72.80819702, 18.89263916], [72.80819702, 18.89347267], [72.80847168, 18.89347076], [72.80847168, 18.89430809], [72.80819702, 18.89430618], [72.80819702, 18.89458275], [72.8079071, 18.89458084], [72.8079071, 18.89486122], [72.80764008, 18.89486122], [72.80764008, 18.89513969], [72.80735779, 18.89513969], [72.80735779, 18.89569473], [72.80708313, 18.89569473], [72.80708313, 18.8959713], [72.80680084, 18.89596939], [72.80680084, 18.89624977], [72.80652618, 18.89624977], [72.80652618, 18.89652824], [72.80625153, 18.89652824], [72.80625153, 18.89708328], [72.80596924, 18.89708328], [72.80596924, 18.89736176], [72.80568695, 18.89735985], [72.80568695, 18.89792061], [72.80541992, 18.89792061], [72.80541992, 18.89819908], [72.80513763, 18.89819908], [72.80513763, 18.8987484], [72.80486298, 18.8987484], [72.80486298, 18.89931107], [72.80458069, 18.89931107], [72.80458069, 18.90014267], [72.80430603, 18.90013885], [72.80430603, 18.90097046], [72.80403137, 18.90097046], [72.80403137, 18.90236282], [72.80374908, 18.90236282], [72.80375671, 18.90374947], [72.80347443, 18.90374947], [72.80347443, 18.90736198], [72.80374908, 18.90736198], [72.80374908, 18.90847206], [72.80403137, 18.90847015], [72.80403137, 18.90930748], [72.80430603, 18.90930557], [72.80430603, 18.90958405], [72.80458069, 18.90958023], [72.80458069, 18.91013908], [72.80486298, 18.91013908], [72.80486298, 18.91041756], [72.80513763, 18.91041756], [72.80513763, 18.9109726], [72.80541992, 18.91097069], [72.80541992, 18.91153145], [72.80569458, 18.91152763], [72.80569458, 18.91180611], [72.80596924, 18.91180038], [72.80596924, 18.91235924], [72.80625153, 18.91235924], [72.80625153, 18.91292191], [72.80652618, 18.91291618], [72.80652618, 18.91319466], [72.80680847, 18.91319466], [72.80680847, 18.91347122], [72.80708313, 18.91346931], [72.80708313, 18.91403008], [72.80735779, 18.91402817], [72.80735779, 18.91430473], [72.80764008, 18.91430473], [72.80764008, 18.9145813], [72.80819702, 18.91457939], [72.80819702, 18.91487122], [72.80847168, 18.91487122], [72.80847168, 18.91457939], [72.80874634, 18.9145813], [72.80874634, 18.91430473], [72.80902863, 18.91430473], [72.80902863, 18.91402817], [72.80930328, 18.91403008], [72.80930328, 18.91374969], [72.8095932, 18.91374969], [72.80958557, 18.91347122], [72.80986023, 18.91347122], [72.80986023, 18.91319466], [72.81014252, 18.91319466], [72.81014252, 18.91291618], [72.81069183, 18.91292191], [72.81069183, 18.91264153], [72.81096649, 18.91264153], [72.81096649, 18.91235924], [72.81124878, 18.91235924], [72.81124878, 18.91208076], [72.81153107, 18.91208267], [72.81153107, 18.91152763], [72.81181335, 18.91153145], [72.81181335, 18.91124916], [72.81291962, 18.91124916], [72.81291962, 18.91153145], [72.81346893, 18.91152763], [72.81346893, 18.91180611], [72.81375122, 18.91180611], [72.81375122, 18.91208267], [72.81402588, 18.91208076], [72.81402588, 18.91235924], [72.81458282, 18.91235924], [72.81458282, 18.91292191], [72.81485748, 18.91291618], [72.81485748, 18.91319466], [72.81541443, 18.91319466], [72.81541443, 18.9145813], [72.81569672, 18.91457939], [72.81569672, 18.91487122], [72.81597137, 18.91487122], [72.81597137, 18.91514015], [72.81624603, 18.91514015], [72.81624603, 18.91542053], [72.81652832, 18.91542053], [72.81652832, 18.91625023], [72.81624603, 18.91625023], [72.81624603, 18.91653061], [72.81597137, 18.91653061], [72.81597137, 18.91764069], [72.81625366, 18.91763878], [72.81625366, 18.91819572], [72.81652832, 18.91819572], [72.81652832, 18.91847229], [72.81764221, 18.91847229], [72.81764221, 18.91819572], [72.81847382, 18.91819572], [72.81847382, 18.91791725], [72.81958008, 18.9179306], [72.81958008, 18.91764069], [72.82096863, 18.91764069], [72.82096863, 18.91736031], [72.82125092, 18.91736031], [72.82125092, 18.91707993], [72.82152557, 18.91708565], [72.82152557, 18.91680336], [72.82236481, 18.91680336], [72.82236481, 18.91708565], [72.82263947, 18.91707993], [72.82263947, 18.91736031], [72.82290649, 18.91736031], [72.82290649, 18.9179306], [72.82319641, 18.91791725], [72.82319641, 18.91819572], [72.82347107, 18.91819], [72.82347107, 18.91875076], [72.82375336, 18.91875076], [72.82375336, 18.91903114], [72.82406616, 18.91903114], [72.82430267, 18.91903114], [72.82430267, 18.91930962], [72.82458496, 18.9193058], [72.82458496, 18.91958237], [72.82541656, 18.91958046], [72.82541656, 18.92014122], [72.82485962, 18.92013931], [72.82485962, 18.92035103], [72.82485962, 18.92180824], [72.82514191, 18.92180824], [72.82514191, 18.92263985], [72.82430267, 18.92263985], [72.82430267, 18.92235947], [72.82375336, 18.92236137], [72.82375336, 18.9220829], [72.82319641, 18.92208099], [72.82319641, 18.92263985], [72.82290649, 18.92263985], [72.82290649, 18.92291832], [72.82236481, 18.92291641], [72.82236481, 18.92319489], [72.82180786, 18.92319489], [72.82180786, 18.92347145], [72.82096863, 18.92347145], [72.82096863, 18.92374992], [72.81986237, 18.92374039], [72.81986237, 18.9240284], [72.81931305, 18.9240284], [72.81931305, 18.92431068], [72.81903076, 18.92430496], [72.81903076, 18.92458344], [72.81874847, 18.92458344], [72.81874847, 18.92486191], [72.81847382, 18.92486191], [72.81847382, 18.92569351], [72.81874084, 18.9256897], [72.81874084, 18.92653275], [72.81903076, 18.92653275], [72.81903076, 18.92681122], [72.81930542, 18.9268055], [72.81930542, 18.92708206], [72.81986237, 18.92708015], [72.81986237, 18.92736053], [72.82013702, 18.92736053], [72.82013702, 18.92791939], [72.82041931, 18.92791748], [72.82041931, 18.92819214], [72.82068634, 18.92819023], [72.82068634, 18.9287529], [72.82096863, 18.9287529], [72.82096863, 18.92930984], [72.82125092, 18.92930603], [72.82125092, 18.9295845], [72.82152557, 18.9295845], [72.82152557, 18.93013954], [72.82180023, 18.93013954], [72.82180023, 18.93041992], [72.82208252, 18.9304142], [72.82208252, 18.93097305], [72.82235718, 18.93097115], [72.82235718, 18.93153], [72.82263947, 18.93152809], [72.82263947, 18.93208313], [72.82291412, 18.93208313], [72.82291412, 18.93291664], [72.82319641, 18.93291092], [72.82319641, 18.93375015], [72.82347107, 18.93375015], [72.82347107, 18.93486023], [72.82375336, 18.93486023], [72.82375336, 18.94014168], [72.82347107, 18.94014168], [72.82347107, 18.94153023], [72.82319641, 18.94152832], [72.82319641, 18.94236374], [72.82290649, 18.94235992], [72.82290649, 18.94320107], [72.82263947, 18.94320107], [72.82263947, 18.94403076], [72.82236481, 18.94402695], [72.82236481, 18.9445858], [72.82208252, 18.94458008], [72.82208252, 18.94514084], [72.82180786, 18.94513893], [72.82180786, 18.94569588], [72.82152557, 18.94569588], [72.8215332, 18.94625092], [72.82125092, 18.94625092], [72.82125092, 18.94680977], [72.82096863, 18.94680786], [72.82096863, 18.94708252], [72.82068634, 18.94708061], [72.82068634, 18.94763947], [72.82041931, 18.94763947], [72.82041931, 18.94791794], [72.82013702, 18.94791794], [72.82013702, 18.9481945], [72.81986237, 18.9481945], [72.81986237, 18.94832039], [72.81986237, 18.94874954], [72.81958008, 18.94874954], [72.81958008, 18.94902992], [72.81931305, 18.94902992], [72.81931305, 18.9493103], [72.81903076, 18.94930649], [72.81903076, 18.94958305], [72.81874847, 18.94958305], [72.81874847, 18.94986153], [72.81819153, 18.94985962], [72.81819153, 18.95013809], [72.81791687, 18.95013809], [72.81791687, 18.95070076], [72.81764221, 18.95069504], [72.81764221, 18.9509716], [72.81708527, 18.9509716], [72.8170929, 18.95124817], [72.81680298, 18.95124817], [72.81680298, 18.95152855], [72.81624603, 18.95152855], [72.81624603, 18.95181084], [72.81569672, 18.95180511], [72.81569672, 18.95208359], [72.81541443, 18.95208359], [72.81541443, 18.95236015], [72.81485748, 18.95236015], [72.81485748, 18.95264244], [72.81458282, 18.95264244], [72.81458282, 18.95292282], [72.81430817, 18.9529171], [72.81430817, 18.95319366], [72.81402588, 18.95319366], [72.81402588, 18.95347023], [72.81346893, 18.95347023], [72.81346893, 18.95375252], [72.81291962, 18.95375252], [72.81291962, 18.95404053], [72.81263733, 18.95404053], [72.81263733, 18.95430946], [72.81236267, 18.95430565], [72.81236267, 18.95458221], [72.81041718, 18.95458031], [72.81041718, 18.95486069], [72.80819702, 18.95486069], [72.80819702, 18.95458031], [72.80791473, 18.95458221], [72.80791473, 18.95430565], [72.80764008, 18.95430946], [72.80764008, 18.95404053], [72.80735779, 18.95404053], [72.80735779, 18.95375252], [72.80708313, 18.95375252], [72.80708313, 18.95347023], [72.80680847, 18.95347023], [72.80680847, 18.9529171], [72.80625153, 18.95292282], [72.80625153, 18.95264244], [72.80580139, 18.95264244], [72.80541992, 18.95264244], [72.80541229, 18.95210075], [72.80486298, 18.95207977], [72.80486298, 18.95152855], [72.80458069, 18.95152855], [72.80458069, 18.95124817], [72.80430603, 18.95124817], [72.80430603, 18.9509697], [72.80403137, 18.9509716], [72.80403137, 18.95069504], [72.80375671, 18.95070076], [72.80375671, 18.95013809], [72.80319214, 18.95013809], [72.80319214, 18.94958115], [72.80263519, 18.94958305], [72.80263519, 18.94930649], [72.80236053, 18.9493103], [72.80236053, 18.94902992], [72.80208588, 18.94902992], [72.80208588, 18.94874954], [72.80152893, 18.94874954], [72.80152893, 18.94847107], [72.80097198, 18.94847298], [72.80097198, 18.9481945], [72.80014038, 18.9481945], [72.80014038, 18.94791794], [72.79958344, 18.94791794], [72.79958344, 18.94763947], [72.79875183, 18.94763947], [72.79875183, 18.94708061], [72.79846954, 18.94708252], [72.79846954, 18.94680786], [72.79818726, 18.94680977], [72.79818726, 18.94652939], [72.79792023, 18.94652939], [72.79792023, 18.94625092], [72.79763031, 18.94625092], [72.79763031, 18.94514084], [72.79736328, 18.94514084], [72.79736328, 18.94485283], [72.79680634, 18.94486046], [72.79680634, 18.9445858], [72.79652405, 18.9445858], [72.79652405, 18.94430542], [72.79624939, 18.94431114], [72.79624939, 18.94403076], [72.7959671, 18.94403076], [72.7959671, 18.94347], [72.79569244, 18.94347382], [72.79569244, 18.94236374], [72.79541779, 18.94236374], [72.79541779, 18.94124985], [72.7951355, 18.94124985], [72.7951355, 18.94041634], [72.79486084, 18.94042015], [72.79486084, 18.93958092], [72.79458618, 18.93958282], [72.79458618, 18.93930626], [72.79429626, 18.93931007], [72.79429626, 18.9390316], [72.79402924, 18.9390316], [72.79402924, 18.93874931], [72.79319763, 18.93874931], [72.79319763, 18.9390316], [72.79292297, 18.9390316], [72.79292297, 18.93931007], [72.79264069, 18.93930626], [72.79264069, 18.93958282], [72.79208374, 18.93958282], [72.79208374, 18.93985939], [72.79180908, 18.93985939], [72.79180908, 18.94069481], [72.79208374, 18.94069481], [72.79208374, 18.94097137], [72.7923584, 18.94096947], [72.7923584, 18.94153023], [72.79264069, 18.94152832], [72.79264069, 18.94208145], [72.79292297, 18.94207954], [72.79292297, 18.9426403], [72.79319763, 18.9426403], [72.79319763, 18.94375038], [72.79291534, 18.94375038], [72.79291534, 18.9445858], [72.79264069, 18.94458008], [72.79264069, 18.94542122], [72.7923584, 18.94542122], [72.7923584, 18.94652939], [72.79208374, 18.94652748], [72.79208374, 18.94708252], [72.79180908, 18.94708252], [72.79181671, 18.94763947], [72.79152679, 18.94763947], [72.79152679, 18.9481945], [72.79181671, 18.94819069], [72.79181671, 18.95070076], [72.7923584, 18.95070076], [72.7923584, 18.95124817], [72.79264069, 18.95124817], [72.79264069, 18.95181084], [72.79291534, 18.95180511], [72.79291534, 18.95236015], [72.79319763, 18.95236015], [72.79319763, 18.95264244], [72.79347229, 18.95264244], [72.79347229, 18.95292282], [72.79374695, 18.9529171], [72.79374695, 18.95347023], [72.79402924, 18.95347023], [72.79402924, 18.95375252], [72.79429626, 18.95375252], [72.79429626, 18.95404053], [72.79458618, 18.95404053], [72.79458618, 18.95430946], [72.79486084, 18.95430565], [72.79486084, 18.95458221], [72.7951355, 18.95458221], [72.7951355, 18.95569229], [72.79541779, 18.95569229], [72.79541779, 18.95597458], [72.79569244, 18.95597076], [72.79569244, 18.95625114], [72.7959671, 18.95625114], [72.7959671, 18.95652962], [72.79624939, 18.95652962], [72.79624939, 18.95681], [72.79652405, 18.95680618], [72.79652405, 18.95708466], [72.79708099, 18.95708084], [72.79708099, 18.95736122], [72.79736328, 18.95736122], [72.79736328, 18.95763969], [72.79763031, 18.95763969], [72.79763031, 18.95792007], [72.79818726, 18.95792007], [72.79818726, 18.95903015], [72.79930878, 18.95902824], [72.79930878, 18.95930672], [72.79957581, 18.95930099], [72.79957581, 18.96014023], [72.79930878, 18.96013832], [72.79930878, 18.96097183], [72.79957581, 18.96096992], [72.79957581, 18.96153069], [72.79985809, 18.96153069], [72.79985809, 18.96181107], [72.80014038, 18.96181107], [72.80014038, 18.96236038], [72.80042267, 18.96236038], [72.80042267, 18.96264076], [72.80069733, 18.96263885], [72.80069733, 18.96319389], [72.80097198, 18.96319389], [72.80097198, 18.96347237], [72.80124664, 18.96347046], [72.80124664, 18.96402931], [72.80152893, 18.96402931], [72.80152893, 18.96542168], [72.80208588, 18.96541595], [72.80208588, 18.96569443], [72.80263519, 18.96569443], [72.80263519, 18.96847153], [72.80208588, 18.96846962], [72.80208588, 18.96875191], [72.80179596, 18.96875191], [72.80179596, 18.96903992], [72.80152893, 18.96902847], [72.80152893, 18.96986389], [72.80180359, 18.96986389], [72.80180359, 18.9706955], [72.80208588, 18.97068977], [72.80208588, 18.97125053], [72.80236053, 18.97125053], [72.80236053, 18.97180939], [72.80263519, 18.97180557], [72.80263519, 18.97236061], [72.80319214, 18.97236061], [72.80319214, 18.97264099], [72.8034668, 18.97264099], [72.8034668, 18.97291946], [72.80374908, 18.97291756], [72.80374908, 18.97319412], [72.80403137, 18.97319412], [72.80403137, 18.9734726], [72.80430603, 18.97347069], [72.80430603, 18.97375107], [72.80458069, 18.97375107], [72.80458069, 18.97430992], [72.80486298, 18.97430611], [72.80486298, 18.97486115], [72.80513763, 18.9748497], [72.80513763, 18.97541809], [72.80569458, 18.97541618], [72.80569458, 18.97597313], [72.80596924, 18.97597122], [72.80596924, 18.97652817], [72.80568695, 18.97652817], [72.80568695, 18.97821045], [72.80847168, 18.97819519], [72.80847168, 18.97847176], [72.80874634, 18.97846985], [72.80874634, 18.97874832], [72.80902863, 18.97874832], [72.80902863, 18.97903252], [72.80930328, 18.97903252], [72.80930328, 18.97874832], [72.81124878, 18.97874832], [72.81124878, 18.97903252], [72.81153107, 18.97903252], [72.81153107, 18.9793129], [72.81180573, 18.97930527], [72.81180573, 18.97958374], [72.81208038, 18.97958183], [72.81208038, 18.97986031], [72.81236267, 18.97986031], [72.81236267, 18.98014259], [72.81263733, 18.98013878], [72.81263733, 18.98069382], [72.81318665, 18.98069191], [72.81318665, 18.98125267], [72.81375122, 18.98125267], [72.81375122, 18.98180962], [72.81402588, 18.98180962], [72.81402588, 18.98291969], [72.81430817, 18.98291969], [72.81430817, 18.98513985], [72.81402588, 18.98513985], [72.81402588, 18.98624992], [72.81375122, 18.98624992], [72.81375122, 18.9865303], [72.81346893, 18.9865284], [72.81346893, 18.98708344], [72.81291962, 18.98708344], [72.81291962, 18.98680687], [72.81236267, 18.98680687], [72.81236267, 18.98708344], [72.81124878, 18.98708344], [72.81124878, 18.98736191], [72.81097412, 18.98736191], [72.81097412, 18.98847198], [72.81069183, 18.98847008], [72.81069183, 18.98903084], [72.81097412, 18.98902893], [72.81097412, 18.98958397], [72.81124878, 18.98958015], [72.81124878, 18.99014854], [72.81153107, 18.9901371], [72.81153107, 18.99069405], [72.81181335, 18.99069023], [72.81181335, 18.99124908], [72.81208038, 18.99124908], [72.81208038, 18.99235916], [72.81236267, 18.99235916], [72.81236267, 18.99347115], [72.81208038, 18.99346924], [72.81208038, 18.99403191], [72.81153107, 18.99402809], [72.81153107, 18.99430466], [72.81180573, 18.99430466], [72.81180573, 18.99597359], [72.81153107, 18.99596024], [72.81153107, 18.99792099], [72.81124878, 18.99792099], [72.81124878, 18.99930954], [72.81096649, 18.99930954], [72.81096649, 18.99986076], [72.81124878, 18.99986076], [72.81124878, 19.0023613], [72.81153107, 19.0023613], [72.81153107, 19.00347137], [72.81181335, 19.00346947], [72.81181335, 19.00402832], [72.81208038, 19.00402832], [72.81208038, 19.00458336], [72.81236267, 19.00457954], [72.81236267, 19.00515175], [72.81263733, 19.00515175], [72.81263733, 19.00570107], [72.81291962, 19.00569534], [72.81291962, 19.00597191], [72.81318665, 19.00597191], [72.81318665, 19.00653267], [72.81346893, 19.00652695], [72.81346893, 19.00708389], [72.81375122, 19.00708389], [72.81375122, 19.00958443], [72.81402588, 19.00958061], [72.81402588, 19.0098629], [72.81430817, 19.0098629], [72.81430817, 19.01013947], [72.81458282, 19.01013947], [72.81458282, 19.0106926], [72.81485748, 19.01069069], [72.81485748, 19.01124954], [72.81513977, 19.01124954], [72.81513977, 19.01180077], [72.81541443, 19.01180649], [72.81541443, 19.01208305], [72.81569672, 19.01208305], [72.81569672, 19.01236153], [72.81597137, 19.01235962], [72.81597137, 19.01320076], [72.81624603, 19.01320076], [72.81624603, 19.01652908], [72.81597137, 19.01652908], [72.81597137, 19.01763916], [72.81569672, 19.01763916], [72.81569672, 19.02069473], [72.8154068, 19.02069283], [72.8154068, 19.02403069], [72.81513977, 19.02402687], [72.81513977, 19.02458572], [72.81485748, 19.02458], [72.81485748, 19.02514076], [72.81458282, 19.02513885], [72.81458282, 19.02708244], [72.81541443, 19.02708244], [72.81541443, 19.02680779], [72.81569672, 19.02680969], [72.81569672, 19.02569008], [72.81597137, 19.0256958], [72.81597137, 19.02513885], [72.81624603, 19.02514076], [72.81624603, 19.02486038], [72.81652832, 19.02486038], [72.81652832, 19.02458], [72.81680298, 19.02458572], [72.81680298, 19.02430344], [72.8170929, 19.02431107], [72.8170929, 19.02403069], [72.81735992, 19.02403069], [72.81735992, 19.02375031], [72.81764221, 19.02375031], [72.81764221, 19.02346992], [72.81791687, 19.02347374], [72.81791687, 19.02291679], [72.81819153, 19.02292061], [72.81819153, 19.02264023], [72.81846619, 19.02264023], [72.81846619, 19.02235985], [72.81874847, 19.02236366], [72.81874847, 19.02069473], [72.81903076, 19.02069473], [72.81903076, 19.02013969], [72.81930542, 19.02013969], [72.81930542, 19.01930618], [72.81958008, 19.0193119], [72.81958008, 19.01847076], [72.81986237, 19.01847267], [72.81986237, 19.0181942], [72.82013702, 19.0181942], [72.82013702, 19.01791573], [72.82041931, 19.01792145], [72.82041931, 19.01763916], [72.82290649, 19.01763916], [72.82290649, 19.01792145], [72.82514191, 19.01791573], [72.82514191, 19.0181942], [72.82541656, 19.0181942], [72.82541656, 19.01847267], [72.82653046, 19.01847076], [72.82653046, 19.01874924], [72.82681274, 19.01874924], [72.82681274, 19.01903152], [72.82707977, 19.01903152], [72.82707977, 19.0193119], [72.82736206, 19.01930618], [72.82736206, 19.01958275], [72.82763672, 19.01958084], [72.82763672, 19.01985931], [72.82819366, 19.01985931], [72.82819366, 19.02013969], [72.82847595, 19.02012825], [72.82847595, 19.02042007], [72.82902527, 19.02041626], [72.82902527, 19.02069473], [72.82958221, 19.02069473], [72.82958221, 19.0209713], [72.82985687, 19.02096939], [72.82985687, 19.02124977], [72.83040619, 19.02124977], [72.83040619, 19.02153015], [72.83069611, 19.02152824], [72.83069611, 19.02180481], [72.83097076, 19.02180481], [72.83097076, 19.02208138], [72.83125305, 19.02208138], [72.83125305, 19.02236366], [72.83152771, 19.02235985], [72.83152771, 19.02264023], [72.83180237, 19.02264023], [72.83180237, 19.02292061], [72.83208466, 19.02291679], [72.83208466, 19.02319527], [72.83235931, 19.02319527], [72.83235931, 19.02347374], [72.8326416, 19.02346992], [72.8326416, 19.02403069], [72.83291626, 19.02403069], [72.83291626, 19.02431107], [72.83319092, 19.02430344], [72.83319092, 19.02458572], [72.83347321, 19.02458], [72.83347321, 19.02486038], [72.83374023, 19.02486038], [72.83374023, 19.02514076], [72.83403015, 19.02514076], [72.83403015, 19.02626038], [72.83429718, 19.02626038], [72.83429718, 19.02653122], [72.83486176, 19.02653122], [72.83486176, 19.02680969], [72.83513641, 19.02680969], [72.83513641, 19.02736092], [72.8354187, 19.02736092], [72.8354187, 19.02763939], [72.83569336, 19.02763939], [72.83569336, 19.02819443], [72.83597565, 19.02819443], [72.83597565, 19.02874947], [72.83625031, 19.02874947], [72.83625031, 19.02932167], [72.83651733, 19.02932167], [72.83651733, 19.03013992], [72.83679962, 19.03013992], [72.83679962, 19.0304184], [72.83708191, 19.0304184], [72.83708191, 19.03124809], [72.8373642, 19.03124809], [72.8373642, 19.03208351], [72.83763885, 19.03206825], [72.83763885, 19.03292274], [72.83790588, 19.03292274], [72.83790588, 19.03486061], [72.8381958, 19.03486061], [72.8381958, 19.03928185], [72.83790588, 19.03930092], [72.83790588, 19.04181099], [72.83763885, 19.04180527], [72.83763885, 19.04375267], [72.83763885, 19.04458427], [72.83735657, 19.04458046], [72.83735657, 19.04513931], [72.83708191, 19.04513931], [72.83708191, 19.0454216], [72.83680725, 19.04541588], [72.83680725, 19.04597282], [72.83652496, 19.04597282], [72.83652496, 19.04819489], [72.83625031, 19.04819107], [72.83625031, 19.04874992], [72.83598328, 19.04874992], [72.83598328, 19.0490303], [72.83569336, 19.0490303], [72.83569336, 19.04931068], [72.83513641, 19.04930305], [72.83513641, 19.04958153], [72.83486176, 19.04958153], [72.83486176, 19.04986382], [72.83347321, 19.04986382], [72.83347321, 19.04958153], [72.8326416, 19.04958153], [72.8326416, 19.04930305], [72.83235931, 19.04931068], [72.83235931, 19.0490303], [72.83125305, 19.0490303], [72.83125305, 19.04819107], [72.83069611, 19.04819489], [72.83069611, 19.04791641], [72.83040619, 19.04792023], [72.83040619, 19.04735947], [72.83013916, 19.04736137], [72.83013916, 19.04680634], [72.82985687, 19.04681015], [72.82985687, 19.04653168], [72.82958221, 19.04653168], [72.82958221, 19.04597092], [72.8298645, 19.04597282], [72.8298645, 19.04569435], [72.82958221, 19.04569435], [72.82958221, 19.04541588], [72.8290329, 19.0454216], [72.8290329, 19.04513931], [72.82847595, 19.04513931], [72.82847595, 19.04486084], [72.82791901, 19.04486084], [72.82791901, 19.04458427], [72.82763672, 19.04458427], [72.82763672, 19.0443058], [72.82736206, 19.04432106], [72.82736206, 19.04402924], [72.82653046, 19.04402924], [72.82653046, 19.04375076], [72.82624817, 19.04375076], [72.82624817, 19.04347038], [72.82541656, 19.04347229], [72.82541656, 19.04319382], [72.82514191, 19.04319382], [72.82514191, 19.04291725], [72.82485962, 19.04291916], [72.82485962, 19.04264069], [72.82430267, 19.04264069], [72.82430267, 19.04236031], [72.82402802, 19.04236031], [72.82402802, 19.04207993], [72.82375336, 19.04208374], [72.82375336, 19.04041672], [72.82402802, 19.04042053], [72.82402802, 19.03985977], [72.82430267, 19.03986168], [72.82430267, 19.03930664], [72.82458496, 19.03930664], [72.82458496, 19.03819466], [72.82430267, 19.03820038], [72.82430267, 19.03763962], [72.82375336, 19.03763962], [72.82375336, 19.03792], [72.82347107, 19.03792], [72.82347107, 19.03820038], [72.82319641, 19.03819466], [72.82319641, 19.03847313], [72.82290649, 19.03847122], [72.82290649, 19.03903008], [72.82263947, 19.03902817], [72.82263947, 19.03958321], [72.82235718, 19.03957939], [72.82235718, 19.04070091], [72.82208252, 19.04070091], [72.82208252, 19.04181099], [72.82180023, 19.04181099], [72.82180786, 19.04236031], [72.8215332, 19.04236031], [72.8215332, 19.04264069], [72.82096863, 19.04264069], [72.82096863, 19.04236031], [72.82068634, 19.04236031], [72.82068634, 19.04207993], [72.82013702, 19.04208374], [72.82013702, 19.04180527], [72.81903076, 19.04181099], [72.81903076, 19.04153061], [72.81874084, 19.04153061], [72.81874084, 19.04125977], [72.81764221, 19.04125977], [72.81764221, 19.04153061], [72.81735992, 19.04153061], [72.81735992, 19.04181099], [72.81680298, 19.04181099], [72.81680298, 19.04153061], [72.81652832, 19.04153061], [72.81652832, 19.04181099], [72.81624603, 19.04181099], [72.81624603, 19.04236031], [72.81597137, 19.04236031], [72.81597137, 19.04264069], [72.81624603, 19.04264069], [72.81624603, 19.04291916], [72.81652832, 19.04291725], [72.81652832, 19.04347229], [72.8170929, 19.04347038], [72.8170929, 19.04402924], [72.81764221, 19.04402924], [72.81764221, 19.04486084], [72.81791687, 19.04486084], [72.81791687, 19.0454216], [72.81819153, 19.0454216], [72.81819153, 19.04653168], [72.81846619, 19.04653168], [72.81846619, 19.04624939], [72.81874084, 19.04624939], [72.81874084, 19.04653168], [72.81903076, 19.04653168], [72.81903076, 19.04681015], [72.81930542, 19.04680634], [72.81930542, 19.0470829], [72.81958008, 19.0470829], [72.81958008, 19.04736137], [72.81986237, 19.04736137], [72.81986237, 19.04847145], [72.82013702, 19.04846954], [72.82013702, 19.0490303], [72.82041931, 19.0490284], [72.82041931, 19.04986382], [72.82096863, 19.04986], [72.82096863, 19.05014038], [72.82125092, 19.05014038], [72.82125092, 19.05153084], [72.82152557, 19.05152512], [72.82152557, 19.05236053], [72.82180023, 19.05236053], [72.82180023, 19.05264091], [72.82208252, 19.05264091], [72.82208252, 19.05319977], [72.82235718, 19.05319977], [72.82235718, 19.05402946], [72.82263947, 19.05402946], [72.82263947, 19.05486107], [72.82347107, 19.05486107], [72.82347107, 19.05513954], [72.82375336, 19.05513954], [72.82375336, 19.05597305], [72.82347107, 19.05597115], [72.82347107, 19.05625916], [72.82319641, 19.05624962], [72.82319641, 19.05680466], [72.82291412, 19.05680466], [72.82291412, 19.0573616], [72.82263947, 19.0573597], [72.82263947, 19.05763817], [72.82096863, 19.05763817], [72.82096863, 19.05847168], [72.82069397, 19.05847168], [72.82069397, 19.06069374], [72.82096863, 19.06069374], [72.82096863, 19.06097031], [72.82152557, 19.06097031], [72.82152557, 19.06125259], [72.82180023, 19.06125259], [72.82180023, 19.06236076], [72.82208252, 19.06236076], [72.82208252, 19.06347466], [72.82180786, 19.06347466], [72.82180786, 19.0648613], [72.8215332, 19.06485939], [72.8215332, 19.06653023], [72.82125092, 19.06652832], [72.82125092, 19.06680679], [72.82096863, 19.06680107], [72.82096863, 19.06792068], [72.82152557, 19.06791687], [72.82152557, 19.06847191], [72.82235718, 19.06847], [72.82235718, 19.06875038], [72.82263947, 19.06875038], [72.82263947, 19.06986046], [72.82236481, 19.06986046], [72.82236481, 19.07097244], [72.82208252, 19.07097054], [72.82208252, 19.07235909], [72.82180023, 19.07235909], [72.82180023, 19.07570076], [72.82096863, 19.07570076], [72.82096863, 19.07764053], [72.82152557, 19.07763863], [72.82152557, 19.07819557], [72.82208252, 19.07819557], [72.82208252, 19.07847214], [72.82235718, 19.07847023], [72.82235718, 19.07875061], [72.82290649, 19.07875061], [72.82290649, 19.07903099], [72.82375336, 19.07903099], [72.82375336, 19.07930946], [72.82430267, 19.07930946], [72.82430267, 19.07875061], [72.82457733, 19.07875061], [72.82457733, 19.07847023], [72.82485962, 19.07847214], [72.82485962, 19.0779171], [72.82597351, 19.0779171], [72.82597351, 19.07819557], [72.82624817, 19.07818985], [72.82624817, 19.07986069], [72.82596588, 19.07986069], [72.82596588, 19.08152962], [72.82624817, 19.08152962], [72.82624817, 19.08236122], [72.82596588, 19.08236122], [72.82596588, 19.08291817], [72.82569122, 19.08291626], [72.82569122, 19.0834713], [72.82541656, 19.08346939], [72.82541656, 19.08542061], [72.82597351, 19.08541679], [72.82597351, 19.08625031], [72.82624817, 19.08624077], [72.82624817, 19.08764267], [72.82653046, 19.08763885], [72.82653046, 19.08847046], [72.82681274, 19.08847046], [72.82681274, 19.09403038], [72.82653046, 19.09402847], [72.82653046, 19.09541893], [72.82624817, 19.09541893], [72.82624817, 19.09819412], [72.82596588, 19.09818077], [72.82596588, 19.09874916], [72.82569122, 19.09874916], [72.82569122, 19.10013962], [72.82541656, 19.10013962], [72.82541656, 19.1020813], [72.82514191, 19.10207939], [72.82514191, 19.10264015], [72.82485962, 19.10264015], [72.82485962, 19.10320091], [72.82457733, 19.10320091], [72.82457733, 19.10431099], [72.82430267, 19.10431099], [72.82430267, 19.10514069], [72.82402802, 19.10513878], [72.82402802, 19.10597229], [72.82375336, 19.10597038], [72.82375336, 19.10764122], [72.82347107, 19.10763931], [72.82347107, 19.10986137], [72.82319641, 19.10986137], [72.82319641, 19.11097145], [72.82290649, 19.11096954], [72.82290649, 19.1115284], [72.82263947, 19.1115284], [72.82263947, 19.11236191], [72.82236481, 19.11236191], [72.82235718, 19.11374092], [72.82208252, 19.11375046], [72.82208252, 19.11431122], [72.82180023, 19.11431122], [72.82180786, 19.11486053], [72.8215332, 19.11486053], [72.8215332, 19.11541939], [72.82125092, 19.11541748], [72.82125092, 19.11597443], [72.82096863, 19.11597061], [72.82096863, 19.11654091], [72.82068634, 19.11654091], [72.82068634, 19.11736107], [72.82041931, 19.11736107], [72.82041931, 19.11763954], [72.82013702, 19.11763954], [72.82013702, 19.12042046], [72.82041931, 19.12042046], [72.82041931, 19.12070084], [72.82152557, 19.12069511], [72.82152557, 19.12208366], [72.82096863, 19.12208366], [72.82096863, 19.12236023], [72.82068634, 19.12235069], [72.82068634, 19.12291908], [72.82041931, 19.12291718], [72.82041931, 19.12319374], [72.81986237, 19.12318993], [72.81986237, 19.12375069], [72.81958008, 19.12375069], [72.81958008, 19.12402916], [72.81931305, 19.12402916], [72.81931305, 19.12431145], [72.81847382, 19.12430573], [72.81847382, 19.1245842], [72.81791687, 19.12458038], [72.81791687, 19.12486076], [72.81764221, 19.12486076], [72.81764221, 19.12513924], [72.81735992, 19.12513924], [72.81735992, 19.12542152], [72.81708527, 19.1254158], [72.81708527, 19.12569427], [72.81680298, 19.12569427], [72.81680298, 19.12597275], [72.81652832, 19.12597084], [72.81652832, 19.12624931], [72.81624603, 19.12624931], [72.81624603, 19.1265316], [72.81597137, 19.1265316], [72.81597137, 19.12681007], [72.81541443, 19.12680626], [72.81541443, 19.12708282], [72.81513977, 19.12708282], [72.81513977, 19.1273613], [72.81485748, 19.12735939], [72.81485748, 19.12763977], [72.81458282, 19.12763977], [72.81458282, 19.12819481], [72.81485748, 19.1281929], [72.81485748, 19.12848091], [72.81458282, 19.12848091], [72.81458282, 19.12903023], [72.81402588, 19.12902832], [72.81402588, 19.12930489], [72.81375122, 19.12930489], [72.81375122, 19.12902832], [72.81346893, 19.12902832], [72.81346893, 19.12958145], [72.81319427, 19.12958145], [72.81319427, 19.12986374], [72.81291962, 19.12986374], [72.81291962, 19.13097382], [72.81263733, 19.13097], [72.81263733, 19.13125038], [72.81236267, 19.13125038], [72.81236267, 19.13152695], [72.81208038, 19.13152122], [72.81208038, 19.13181114], [72.81180573, 19.13180351], [72.81180573, 19.1320858], [72.81153107, 19.13208008], [72.81153107, 19.13236046], [72.81124878, 19.13236046], [72.81124878, 19.13264084], [72.81097412, 19.13263893], [72.81097412, 19.13319588], [72.81041718, 19.13319588], [72.81041718, 19.13347244], [72.81014252, 19.13347054], [72.81014252, 19.13402939], [72.80986023, 19.13402939], [72.80986023, 19.13430977], [72.80958557, 19.13430786], [72.80958557, 19.13458252], [72.80930328, 19.13458061], [72.80930328, 19.13513947], [72.80902863, 19.13513947], [72.80902863, 19.13541985], [72.80874634, 19.13541794], [72.80874634, 19.1356945], [72.80847168, 19.1356945], [72.80847168, 19.13597298], [72.80819702, 19.13597107], [72.80819702, 19.13624954], [72.8079071, 19.13624954], [72.8079071, 19.13652992], [72.80764008, 19.13652992], [72.80764008, 19.1368084], [72.80708313, 19.13680649], [72.80708313, 19.13708305], [72.80680084, 19.13708115], [72.80680084, 19.13763809], [72.80652618, 19.13763809], [72.80652618, 19.13791847], [72.80625153, 19.13791847], [72.80625153, 19.13820076], [72.80596924, 19.13819504], [72.80596924, 19.1384716], [72.80568695, 19.1384697], [72.80568695, 19.13874817], [72.80541992, 19.13874817], [72.80541992, 19.13902855], [72.80486298, 19.13902855], [72.80486298, 19.13958359], [72.80458069, 19.13958359], [72.80458069, 19.13986015], [72.80403137, 19.13986015], [72.80403137, 19.14014244], [72.80374908, 19.14013863], [72.80374908, 19.14069366], [72.8034668, 19.14069176], [72.8034668, 19.1415329], [72.80374908, 19.14152718], [72.80374908, 19.14208221], [72.80403137, 19.14208221], [72.80403137, 19.14347458], [72.80430603, 19.14346123], [72.80430603, 19.14402962], [72.80458069, 19.14402962], [72.80458069, 19.14431], [72.80486298, 19.14431], [72.80486298, 19.14486122], [72.80541992, 19.14486122], [72.80541992, 19.14513969], [72.80569458, 19.14513969], [72.80569458, 19.14569664], [72.80596924, 19.14569092], [72.80596924, 19.14875031], [72.80625153, 19.14875031], [72.80625153, 19.14931107], [72.80652618, 19.14931107], [72.80652618, 19.14958954], [72.80708313, 19.14958954], [72.80708313, 19.15014076], [72.80764008, 19.15014076], [72.80764008, 19.15041924], [72.80791473, 19.15041733], [72.80791473, 19.15069389], [72.80819702, 19.15069389], [72.80819702, 19.15097237], [72.80847168, 19.15097046], [72.80847168, 19.15125084], [72.80874634, 19.15125084], [72.80874634, 19.15152931], [72.80902863, 19.15152931], [72.80902863, 19.1518116], [72.80930328, 19.15180588], [72.80930328, 19.15208244], [72.80958557, 19.15208244], [72.80958557, 19.15236092], [72.80986023, 19.15236092], [72.80986023, 19.15265274], [72.81014252, 19.15263939], [72.81014252, 19.15319443], [72.81069183, 19.15319443], [72.81069183, 19.1534729], [72.81096649, 19.15346909], [72.81096649, 19.15403175], [72.81153107, 19.15403175], [72.81153107, 19.15431023], [72.81208038, 19.15430641], [72.81208038, 19.15458107], [72.81236267, 19.15458107], [72.81236267, 19.15486145], [72.81291962, 19.15485954], [72.81291962, 19.1554203], [72.81319427, 19.15541649], [72.81319427, 19.15597153], [72.81375122, 19.15596962], [72.81375122, 19.15625], [72.81402588, 19.15625], [72.81402588, 19.15653038], [72.81430817, 19.15652847], [72.81430817, 19.15708542], [72.81485748, 19.15708542], [72.81485748, 19.15736389], [72.81513977, 19.15736008], [72.81513977, 19.15792084], [72.81569672, 19.15791702], [72.81569672, 19.1581955], [72.81597137, 19.1581955], [72.81597137, 19.15847206], [72.81652832, 19.15846062], [72.81652832, 19.15903091], [72.81735992, 19.15903091], [72.81735992, 19.15930939], [72.81764221, 19.15930557], [72.81764221, 19.15958595], [72.81819153, 19.15958023], [72.81819153, 19.15986061], [72.81846619, 19.15986061], [72.81846619, 19.16014099], [72.81874084, 19.16014099], [72.81874084, 19.16041946], [72.81903076, 19.16041756], [72.81903076, 19.1609726], [72.81931305, 19.16097069], [72.81931305, 19.16125107], [72.81958008, 19.16125107], [72.81958008, 19.16180992], [72.82013702, 19.16180611], [72.82013702, 19.16208267], [72.82041931, 19.16208076], [72.82041931, 19.16236115], [72.82096863, 19.16236115], [72.82096863, 19.16263962], [72.82125092, 19.16263962], [72.82125092, 19.16291809], [72.82152557, 19.16291618], [72.82152557, 19.16319466], [72.82180786, 19.16319466], [72.82180786, 19.16347313], [72.82208252, 19.16347122], [72.82208252, 19.16402817], [72.82263947, 19.16402817], [72.82263947, 19.16430473], [72.82291412, 19.16430473], [72.82291412, 19.16486168], [72.82347107, 19.16485977], [72.82347107, 19.16513824], [72.82375336, 19.16513824], [72.82375336, 19.16541862], [72.82402802, 19.16541672], [72.82402802, 19.16597176], [72.82514191, 19.16596985], [72.82514191, 19.16625023], [72.82596588, 19.16625023], [72.82596588, 19.16596985], [72.82680511, 19.16597176], [72.82680511, 19.16541672], [72.82736206, 19.16541862], [72.82736206, 19.16513824], [72.82818604, 19.16513824], [72.82818604, 19.16541862], [72.82875061, 19.16541862], [72.82875061, 19.16570091], [72.82930756, 19.16569519], [72.82930756, 19.16597176], [72.82958221, 19.16596985], [72.82958221, 19.1668129], [72.82930756, 19.1668129], [72.82930756, 19.16765022], [72.8290329, 19.16765022], [72.8290329, 19.16792107], [72.82847595, 19.16791725], [72.82847595, 19.16819382], [72.82792664, 19.16819191], [72.82792664, 19.16903114], [72.82819366, 19.16902733], [72.82819366, 19.16958237], [72.82875061, 19.16958046], [72.82875061, 19.16986084], [72.8290329, 19.16986084], [72.8290329, 19.17014122], [72.82930756, 19.17013931], [72.82930756, 19.17069244], [72.82958221, 19.17069054], [72.82958221, 19.17152977], [72.82985687, 19.17152977], [72.82985687, 19.17181015], [72.83013916, 19.17181015], [72.83013916, 19.17263985], [72.83041382, 19.17263794], [72.83041382, 19.17347145], [72.83013916, 19.17346954], [72.83013916, 19.17514038], [72.8298645, 19.17513847], [72.8298645, 19.17569351], [72.83041382, 19.17569351], [72.83041382, 19.17597198], [72.83069611, 19.17597008], [72.83069611, 19.17653084], [72.83097076, 19.17653084], [72.83097076, 19.17764091], [72.83069611, 19.1776371], [72.83069611, 19.17847252], [72.83040619, 19.17847061], [72.83040619, 19.17985916], [72.83013916, 19.17985916], [72.83013916, 19.18097115], [72.8298645, 19.18097115], [72.8298645, 19.18236351], [72.82958221, 19.18236351], [72.82958221, 19.18263817], [72.82930756, 19.18263054], [72.82930756, 19.18292046], [72.8290329, 19.18292046], [72.8290329, 19.18320084], [72.82847595, 19.18319321], [72.82847595, 19.18347168], [72.82818604, 19.18346977], [72.82819366, 19.18375015], [72.82791901, 19.18375015], [72.82791901, 19.18347168], [72.82763672, 19.18347168], [72.82763672, 19.18263817], [72.82791901, 19.18263817], [72.82791901, 19.18236351], [72.82819366, 19.18236351], [72.82819366, 19.18152809], [72.82847595, 19.18153191], [72.82847595, 19.18097115], [72.82875061, 19.18097115], [72.82875061, 19.18069458], [72.82902527, 19.18069458], [72.82902527, 19.1795826], [72.82930756, 19.17959023], [72.82930756, 19.1779213], [72.8290329, 19.1779213], [72.8290329, 19.17736053], [72.82875061, 19.17736053], [72.82875061, 19.17682076], [72.82818604, 19.17682076], [72.82818604, 19.17653084], [72.82792664, 19.17653084], [72.82792664, 19.17625046], [72.82763672, 19.17625046], [72.82763672, 19.17597008], [72.82736206, 19.17597198], [72.82736206, 19.17569542], [72.82707977, 19.1756897], [72.82707977, 19.17541885], [72.82681274, 19.17542076], [72.82681274, 19.17514038], [72.82653046, 19.17514038], [72.82653046, 19.17486], [72.82624817, 19.17486191], [72.82624817, 19.17458344], [72.82569122, 19.17458344], [72.82569122, 19.17430687], [72.82541656, 19.17431068], [72.82541656, 19.1740303], [72.82485962, 19.1740303], [72.82485962, 19.17374992], [72.82458496, 19.17374992], [72.82458496, 19.17347145], [72.82430267, 19.17347145], [72.82430267, 19.17319679], [72.82375336, 19.17319679], [72.82375336, 19.17291641], [72.82347107, 19.17292023], [72.82347107, 19.17263985], [72.82319641, 19.17263985], [72.82319641, 19.17235947], [72.82291412, 19.17236137], [72.82291412, 19.17208481], [72.82263947, 19.17208481], [72.82263947, 19.17180634], [72.82235718, 19.17181015], [72.82235718, 19.17152977], [72.82180023, 19.17152977], [72.82180023, 19.17181015], [72.82013702, 19.17181015], [72.82013702, 19.17152977], [72.81986237, 19.17152977], [72.81986237, 19.17124939], [72.81930542, 19.17124939], [72.81930542, 19.17097473], [72.81903076, 19.17097473], [72.81903076, 19.17069244], [72.81874847, 19.17069244], [72.81874847, 19.17013931], [72.81846619, 19.17014122], [72.81846619, 19.16903114], [72.81819153, 19.16903114], [72.81819153, 19.16847038], [72.81764221, 19.16847038], [72.81764221, 19.16819382], [72.81735992, 19.16819382], [72.81735992, 19.16791725], [72.8170929, 19.16792107], [72.8170929, 19.16765022], [72.81680298, 19.16765022], [72.81680298, 19.16736031], [72.81652832, 19.16736031], [72.81652832, 19.16708183], [72.81625366, 19.16708374], [72.81625366, 19.16680527], [72.81597137, 19.1668129], [72.81597137, 19.16653252], [72.81569672, 19.16653252], [72.81569672, 19.16596985], [72.81541443, 19.16597176], [72.81541443, 19.16569519], [72.81513977, 19.16570091], [72.81513977, 19.16513824], [72.81485748, 19.16513824], [72.81485748, 19.16485977], [72.81458282, 19.16486168], [72.81458282, 19.16458321], [72.81430817, 19.16459084], [72.81430817, 19.16402817], [72.81402588, 19.16402817], [72.81402588, 19.16374969], [72.81375122, 19.16374969], [72.81375122, 19.16347122], [72.81346893, 19.16347313], [72.81346893, 19.16319466], [72.81319427, 19.16319466], [72.81319427, 19.16291618], [72.81291962, 19.16291809], [72.81291962, 19.16236115], [72.81263733, 19.16236115], [72.81263733, 19.16180992], [72.81236267, 19.16180992], [72.81236267, 19.16125107], [72.81208038, 19.16125107], [72.81208038, 19.16041946], [72.81181335, 19.16041946], [72.81181335, 19.15986061], [72.81153107, 19.15986061], [72.81153107, 19.15958023], [72.81180573, 19.15958595], [72.81180573, 19.15902519], [72.81153107, 19.15903091], [72.81153107, 19.15846062], [72.81124878, 19.15847206], [72.81124878, 19.15791702], [72.81096649, 19.15792084], [72.81096649, 19.15736008], [72.81069183, 19.15736389], [72.81069183, 19.15708542], [72.81014252, 19.15708542], [72.81014252, 19.15680313], [72.80986023, 19.15681076], [72.80986023, 19.15653038], [72.80902863, 19.15653038], [72.80902863, 19.15625], [72.80847168, 19.15625], [72.80847168, 19.15596962], [72.80791473, 19.15597153], [72.80791473, 19.15569305], [72.80735779, 19.15571022], [72.80735779, 19.15514183], [72.80708313, 19.15514183], [72.80708313, 19.15485954], [72.80652618, 19.15486145], [72.80652618, 19.15458107], [72.80625153, 19.15458107], [72.80625153, 19.15486145], [72.80596924, 19.15486145], [72.80596924, 19.15458107], [72.80569458, 19.15458107], [72.80569458, 19.15402794], [72.80541992, 19.15403175], [72.80541992, 19.15374947], [72.80513763, 19.15374947], [72.80513763, 19.15319061], [72.80486298, 19.15319443], [72.80486298, 19.15263939], [72.80458069, 19.15265274], [72.80458069, 19.15152931], [72.80430603, 19.15152931], [72.80430603, 19.15097046], [72.80374908, 19.15097237], [72.80375671, 19.15125084], [72.8034668, 19.15125084], [72.8034668, 19.15152931], [72.80236053, 19.15152931], [72.80236053, 19.1518116], [72.80208588, 19.15180588], [72.80208588, 19.15208244], [72.80179596, 19.15208054], [72.80179596, 19.15236092], [72.80124664, 19.15236092], [72.80124664, 19.15265274], [72.80097198, 19.15265274], [72.80097198, 19.15292168], [72.80069733, 19.15291595], [72.80069733, 19.15319443], [72.80041504, 19.15319443], [72.80041504, 19.1534729], [72.80014038, 19.15346909], [72.80014038, 19.15374947], [72.79957581, 19.15374947], [72.79957581, 19.15403175], [72.79985809, 19.15403175], [72.79985809, 19.15431023], [72.79958344, 19.15430641], [72.79958344, 19.15458107], [72.79930878, 19.15458107], [72.79930878, 19.15514183], [72.79902649, 19.15514183], [72.79902649, 19.15571022], [72.79875183, 19.15569305], [72.79875183, 19.15597153], [72.79846954, 19.15596962], [72.79846954, 19.15625], [72.79818726, 19.15625], [72.79818726, 19.15596962], [72.79792023, 19.15597153], [72.79792023, 19.15541649], [72.79818726, 19.1554203], [72.79818726, 19.15458107], [72.79846954, 19.15458107], [72.79846954, 19.15430641], [72.79875183, 19.15431023], [72.79875183, 19.15403175], [72.79902649, 19.15403175], [72.79902649, 19.15346909], [72.79930878, 19.1534729], [72.79930878, 19.15319443], [72.79958344, 19.15319443], [72.79958344, 19.15291595], [72.80014038, 19.15292168], [72.80014038, 19.15236092], [72.79985809, 19.15236092], [72.79985809, 19.15208054], [72.80014038, 19.15208244], [72.80014038, 19.15180588], [72.80069733, 19.1518116], [72.80069733, 19.15125084], [72.80097198, 19.15125084], [72.80097198, 19.15097046], [72.80124664, 19.15097237], [72.80124664, 19.15069389], [72.80152893, 19.15069389], [72.80152893, 19.15041733], [72.80208588, 19.15041924], [72.80208588, 19.14875031], [72.80236053, 19.14875031], [72.80236053, 19.14652061], [72.80263519, 19.14652824], [72.80263519, 19.14513969], [72.80236053, 19.14513969], [72.80236053, 19.14402962], [72.80152893, 19.14402962], [72.80152893, 19.14375114], [72.80097198, 19.14375114], [72.80097198, 19.14346123], [72.80069733, 19.14347458], [72.80069733, 19.14208221], [72.80041504, 19.14208221], [72.80041504, 19.14152718], [72.80029297, 19.14152908], [72.80014038, 19.1415329], [72.80014038, 19.14125061], [72.79985809, 19.14125061], [72.79985809, 19.14097023], [72.79958344, 19.14097023], [72.79958344, 19.14069366], [72.79930878, 19.14069366], [72.79930878, 19.1404171], [72.79902649, 19.14042282], [72.79902649, 19.14014244], [72.79792023, 19.14014244], [72.79792023, 19.14042282], [72.79763794, 19.1404171], [72.79763794, 19.14069366], [72.7951355, 19.14069366], [72.7951355, 19.1404171], [72.79486084, 19.14042282], [72.79486084, 19.14014244], [72.79514313, 19.14014244], [72.79514313, 19.13986015], [72.79597473, 19.13986015], [72.7959671, 19.13708115], [72.79624939, 19.13708305], [72.79624939, 19.13652992], [72.79651642, 19.13652992], [72.79651642, 19.13624954], [72.79680634, 19.13624954], [72.79680634, 19.13347054], [72.79652405, 19.13347244], [72.79652405, 19.1329174], [72.79624939, 19.13292122], [72.79624939, 19.13264084], [72.7959671, 19.13264084], [72.7959671, 19.13236046], [72.79569244, 19.13236046], [72.79569244, 19.13208008], [72.79541779, 19.1320858], [72.79541779, 19.13152695], [72.7951355, 19.13152695], [72.7951355, 19.13097382], [72.79486084, 19.13097382], [72.79486084, 19.13069534], [72.79458618, 19.13070107], [72.79458618, 19.13042068], [72.79374695, 19.13042068], [72.79374695, 19.1301403], [72.79347229, 19.1301403], [72.79347229, 19.12985992], [72.79152679, 19.12985992], [72.79152679, 19.1301403], [72.79096985, 19.1301403], [72.79096985, 19.13042068], [72.78985596, 19.13042068], [72.78985596, 19.1301403], [72.7895813, 19.1301403], [72.7895813, 19.12957954], [72.78930664, 19.12958145], [72.78930664, 19.12930489], [72.78791809, 19.12930489], [72.78791809, 19.12902832], [72.7868042, 19.12902832], [72.7868042, 19.12930489], [72.78652954, 19.12930489], [72.78652954, 19.12958145], [72.78624725, 19.12957954], [72.78624725, 19.13042068], [72.78652954, 19.13042068], [72.78652954, 19.13070107], [72.78736115, 19.13069534], [72.78736115, 19.13097382], [72.78791809, 19.13097382], [72.78791809, 19.13152695], [72.7876358, 19.13152122], [72.7876358, 19.13181114], [72.78652954, 19.13180351], [72.78652954, 19.1320858], [72.7859726, 19.13208008], [72.7859726, 19.13264084], [72.78569031, 19.13264084], [72.78569031, 19.13292122], [72.7859726, 19.1329174], [72.7859726, 19.13347244], [72.7876358, 19.13347054], [72.7876358, 19.13402939], [72.78791809, 19.13402939], [72.78791809, 19.13486099], [72.78819275, 19.13486099], [72.78819275, 19.13958359], [72.78791809, 19.13958168], [72.78791809, 19.14014244], [72.7876358, 19.14014244], [72.7876358, 19.1415329], [72.78736115, 19.14152718], [72.78736115, 19.14319229], [72.7876358, 19.14319038], [72.7876358, 19.14375114], [72.78791809, 19.14375114], [72.78791809, 19.14431], [72.78819275, 19.14430618], [72.78819275, 19.14458466], [72.78847504, 19.14458466], [72.78847504, 19.14486122], [72.78875732, 19.14486122], [72.78875732, 19.14542007], [72.78901672, 19.14542007], [72.78901672, 19.15014076], [72.78875732, 19.15014076], [72.78875732, 19.15041924], [72.78847504, 19.15041733], [72.78847504, 19.15069389], [72.78819275, 19.15068817], [72.78819275, 19.15125084], [72.78791809, 19.15125084], [72.78791809, 19.15208244], [72.7876358, 19.15208054], [72.7876358, 19.15236092], [72.78736115, 19.15236092], [72.78736115, 19.15265274], [72.78708649, 19.15265274], [72.78708649, 19.15292168], [72.7868042, 19.15291595], [72.7868042, 19.15319443], [72.78652954, 19.15319443], [72.78652954, 19.1534729], [72.7859726, 19.15346909], [72.7859726, 19.15374947], [72.78542328, 19.15374947], [72.78542328, 19.15403175], [72.78457642, 19.15403175], [72.78457642, 19.15431023], [72.78430939, 19.15430641], [72.78430176, 19.15486145], [72.7840271, 19.15485954], [72.7840271, 19.1554203], [72.78430176, 19.1554203], [72.78430939, 19.15625], [72.78457642, 19.15625], [72.78457642, 19.15653038], [72.78430939, 19.15652847], [72.78430176, 19.15708542], [72.7840271, 19.15708542], [72.7840271, 19.15736389], [72.78347015, 19.15736008], [72.78347015, 19.15764046], [72.78125, 19.15763855], [72.78125, 19.1581955], [72.78151703, 19.15818977], [72.78151703, 19.15875053], [72.78180695, 19.15875053], [72.78180695, 19.15930939], [72.78236389, 19.15930557], [72.78236389, 19.15958595], [72.7831955, 19.15958595], [72.7831955, 19.15986061], [72.78375244, 19.15986061], [72.78375244, 19.16014099], [72.7840271, 19.16014099], [72.7840271, 19.16236115], [72.78375244, 19.16236115], [72.78375244, 19.16263962], [72.78320313, 19.16263962], [72.78320313, 19.16291809], [72.78263855, 19.16291618], [72.78263855, 19.16319466], [72.78125, 19.16319466], [72.78125, 19.16347313], [72.78097534, 19.16347313], [72.78097534, 19.16430473], [72.78069305, 19.16430092], [72.78069305, 19.16513824], [72.7804184, 19.16513824], [72.7804184, 19.16597176], [72.78013611, 19.16596985], [72.78013611, 19.16625023], [72.7804184, 19.16625023], [72.7804184, 19.16653252], [72.78069305, 19.16653252], [72.78069305, 19.16736031], [72.78098297, 19.16736031], [72.78098297, 19.16765022], [72.78125, 19.16765022], [72.78125, 19.16792107], [72.78152466, 19.16791725], [72.78152466, 19.16819382], [72.78236389, 19.16819382], [72.78236389, 19.16791725], [72.7840271, 19.16792107], [72.7840271, 19.16765022], [72.78457642, 19.16765022], [72.78457642, 19.16708183], [72.7848587, 19.16708374], [72.7848587, 19.16680527], [72.78514099, 19.1668129], [72.78514099, 19.16653252], [72.78624725, 19.16653252], [72.78624725, 19.1668129], [72.78679657, 19.1668129], [72.78679657, 19.16736031], [72.78708649, 19.16736031], [72.78708649, 19.16792107], [72.78736115, 19.16791725], [72.78736115, 19.16819382], [72.7876358, 19.16819191], [72.7876358, 19.16875267], [72.78791809, 19.16875267], [72.78791809, 19.16930962], [72.78819275, 19.1693058], [72.78819275, 19.16958237], [72.79013824, 19.16958046], [72.79013824, 19.16986084], [72.7904129, 19.16986084], [72.7904129, 19.17014122], [72.79069519, 19.17013931], [72.79069519, 19.17097473], [72.79096985, 19.17097092], [72.79096985, 19.17124939], [72.79207611, 19.17124939], [72.79207611, 19.17152977], [72.7923584, 19.17152977], [72.7923584, 19.17181015], [72.79430389, 19.17180634], [72.79430389, 19.17208481], [72.79458618, 19.17208099], [72.79458618, 19.17292023], [72.79486084, 19.17291641], [72.79486084, 19.17347145], [72.7951355, 19.17347145], [72.7951355, 19.17374992], [72.79541779, 19.17374992], [72.79541779, 19.17486191], [72.79569244, 19.17486], [72.79569244, 19.17542076], [72.7959671, 19.17542076], [72.7959671, 19.17764091], [72.79624939, 19.17764091], [72.79624939, 19.1779213], [72.79652405, 19.17791748], [72.79652405, 19.18069458], [72.79624939, 19.18069077], [72.79624939, 19.18153191], [72.79597473, 19.18152809], [72.79597473, 19.18180466], [72.79624939, 19.18180466], [72.79624939, 19.18236351], [72.7959671, 19.1823597], [72.7959671, 19.18292046], [72.79624939, 19.18292046], [72.79624939, 19.18403053], [72.79651642, 19.18403053], [72.79651642, 19.18486023], [72.79624939, 19.18486023], [72.79624939, 19.18736076], [72.7959671, 19.18736076], [72.7959671, 19.18791962], [72.79569244, 19.18791771], [72.79569244, 19.18847275], [72.7959671, 19.18847084], [72.7959671, 19.19124985], [72.79624939, 19.19124985], [72.79624939, 19.19152832], [72.79597473, 19.19152832], [72.79597473, 19.19180489], [72.79624939, 19.19179916], [72.79624939, 19.19375038], [72.79652405, 19.19375038], [72.79652405, 19.19458389], [72.79663086, 19.19457817], [72.79680634, 19.19457054], [72.79680634, 19.19486046], [72.79652405, 19.19486046], [72.79652405, 19.19542122], [72.79652405, 19.1981926], [72.79680634, 19.1981926], [72.79680634, 19.19847488], [72.79708099, 19.19847107], [72.79708099, 19.19874954], [72.79680634, 19.19874954], [72.79680634, 19.19902992], [72.79708099, 19.19902802], [72.79708099, 19.19958305], [72.79736328, 19.19958305], [72.79736328, 19.19986153], [72.79792023, 19.19986153], [72.79792023, 19.19958305], [72.79875183, 19.19958305], [72.79875183, 19.19986153], [72.79902649, 19.19986153], [72.79902649, 19.19958305], [72.80041504, 19.19958305], [72.80041504, 19.19986153], [72.80069733, 19.19985962], [72.80069733, 19.20042038], [72.80097198, 19.20042038], [72.80097198, 19.20070076], [72.80124664, 19.20069695], [72.80124664, 19.2009716], [72.80152893, 19.2009697], [72.80152893, 19.20153046], [72.80180359, 19.20152855], [72.80180359, 19.20208359], [72.80208588, 19.20207977], [72.80208588, 19.20264053], [72.80264282, 19.20264053], [72.80264282, 19.20513916], [72.80291748, 19.20513916], [72.80291748, 19.20624924], [72.80319214, 19.20624924], [72.80319214, 19.20652962], [72.80347443, 19.20652771], [72.80347443, 19.20680618], [72.80374908, 19.20680618], [72.80374908, 19.2084713], [72.80403137, 19.20846939], [72.80403137, 19.20874977], [72.80430603, 19.20874977], [72.80430603, 19.20903015], [72.80458069, 19.20902824], [72.80458069, 19.20930481], [72.80513763, 19.20930481], [72.80513763, 19.20958138], [72.80541992, 19.20958138], [72.80541992, 19.20986366], [72.80568695, 19.20985985], [72.80568695, 19.21014023], [72.80596924, 19.21014023], [72.80596924, 19.21042061], [72.80625153, 19.21042061], [72.80625153, 19.21070099], [72.80680847, 19.21069336], [72.80680847, 19.21097374], [72.80764008, 19.21096992], [72.80764008, 19.21125031], [72.8079071, 19.21125031], [72.8079071, 19.21153069], [72.80819702, 19.21153069], [72.80819702, 19.21181107], [72.80902863, 19.21180344], [72.80902863, 19.21208572], [72.80930328, 19.21208], [72.80930328, 19.21236038], [72.8095932, 19.21236038], [72.8095932, 19.21264076], [72.80986023, 19.21264076], [72.80986023, 19.21293068], [72.81014252, 19.21291733], [72.81014252, 19.2131958], [72.81041718, 19.21319008], [72.81041718, 19.21375084], [72.81069183, 19.21375084], [72.81069183, 19.21430969], [72.81124878, 19.21430779], [72.81124878, 19.21458244], [72.81153107, 19.21458054], [72.81153107, 19.21513939], [72.81124878, 19.21513939], [72.81124878, 19.21541977], [72.81096649, 19.21541977], [72.81096649, 19.21569824], [72.81124878, 19.21569824], [72.81124878, 19.21624947], [72.81096649, 19.21624947], [72.81096649, 19.22014046], [72.81124878, 19.22014046], [72.81124878, 19.22125053], [72.81153107, 19.22125053], [72.81153107, 19.22153282], [72.81180573, 19.2215271], [72.81180573, 19.22208214], [72.81208038, 19.22208023], [72.81208038, 19.22236061], [72.81236267, 19.22236061], [72.81236267, 19.22291946], [72.81263733, 19.22291756], [72.81263733, 19.2234745], [72.81430817, 19.22347069], [72.81430817, 19.22375107], [72.81513977, 19.22375107], [72.81513977, 19.22402954], [72.81569672, 19.22402954], [72.81569672, 19.22430992], [72.81597137, 19.2243042], [72.81597137, 19.22458458], [72.81652832, 19.22458076], [72.81652832, 19.22487068], [72.81680298, 19.22487068], [72.81680298, 19.22513962], [72.8170929, 19.22513962], [72.8170929, 19.22542], [72.81735992, 19.22541428], [72.81735992, 19.22569656], [72.81764221, 19.22569656], [72.81764221, 19.22597313], [72.81791687, 19.22597122], [72.81791687, 19.22624969], [72.81846619, 19.22624969], [72.81846619, 19.22653008], [72.81874847, 19.22652817], [72.81874847, 19.22680664], [72.81903076, 19.22680664], [72.81903076, 19.22708321], [72.81930542, 19.22708321], [72.81930542, 19.22736168], [72.81958008, 19.22735977], [72.81958008, 19.22792816], [72.81986237, 19.22792816], [72.81986237, 19.22820091], [72.82013702, 19.22819519], [72.82013702, 19.22847176], [72.82041931, 19.22846985], [72.82041931, 19.22875023], [72.82068634, 19.22875023], [72.82068634, 19.22903061], [72.82096863, 19.2290287], [72.82096863, 19.22958374], [72.82125092, 19.22957993], [72.82125092, 19.22986031], [72.8215332, 19.22986031], [72.8215332, 19.23041916], [72.82180786, 19.23041725], [72.82180786, 19.23069382], [72.82208252, 19.23069382], [72.82208252, 19.23097229], [72.82235718, 19.23097038], [72.82235718, 19.23152924], [72.82263947, 19.23152733], [72.82263947, 19.23208237], [72.82291412, 19.23208427], [72.82291412, 19.23347282], [72.82319641, 19.23347282], [72.82319641, 19.23374939], [72.82347107, 19.23373985], [72.82347107, 19.23431015], [72.82375336, 19.23430634], [72.82375336, 19.2345829], [72.82402802, 19.2345829], [72.82402802, 19.23486137], [72.82430267, 19.23485947], [72.82430267, 19.23542023], [72.82458496, 19.23541641], [72.82458496, 19.23624992], [72.82514191, 19.23624992], [72.82514191, 19.2365303], [72.82541656, 19.2365284], [72.82541656, 19.23708153], [72.82569122, 19.23708153], [72.82569122, 19.23958588], [72.82596588, 19.23958015], [72.82596588, 19.24041939], [72.82624817, 19.24041748], [72.82624817, 19.24069595], [72.82653046, 19.24069023], [72.82653046, 19.24152946], [72.82681274, 19.24152946], [72.82681274, 19.24180984], [72.82653046, 19.24180794], [72.82653046, 19.2420826], [72.82680511, 19.2420826], [72.82680511, 19.24263954], [72.82707977, 19.24263954], [72.82707977, 19.24291611], [72.82680511, 19.24291611], [72.82680511, 19.24319458], [72.82707977, 19.24319077], [72.82707977, 19.24374962], [72.82736206, 19.24374962], [72.82736206, 19.24430466], [72.82763672, 19.24430466], [72.82763672, 19.2448616], [72.82792664, 19.2448597], [72.82792664, 19.24513817], [72.82818604, 19.24513817], [72.82818604, 19.24570084], [72.82847595, 19.24569511], [72.82847595, 19.24596977], [72.82878876, 19.24601364], [72.82875061, 19.24625015], [72.8290329, 19.24625015], [72.8290329, 19.24653244], [72.82930756, 19.24653244], [72.82930756, 19.24681282], [72.83041382, 19.24680519], [72.83041382, 19.24708366], [72.83125305, 19.24708176], [72.83125305, 19.24736023], [72.83180237, 19.24736023], [72.83180237, 19.24764252], [72.83374023, 19.24764252], [72.83374023, 19.2479229], [72.83403015, 19.24791718], [72.83403015, 19.24819374], [72.83569336, 19.24819374], [72.83569336, 19.24847031], [72.83625031, 19.24847031], [72.83625031, 19.24875069], [72.83679962, 19.24875069], [72.83679962, 19.24903107], [72.83708191, 19.24903107], [72.83708191, 19.24930954], [72.83763885, 19.24930573], [72.83763885, 19.24958229], [72.83790588, 19.24958038], [72.83790588, 19.24986076], [72.8381958, 19.24986076], [72.8381958, 19.25014114], [72.83875275, 19.25014114], [72.83875275, 19.25041962], [72.83930206, 19.2504158], [72.83930206, 19.25069237], [72.83958435, 19.25069237], [72.83958435, 19.2523613], [72.83986664, 19.25235939], [72.83986664, 19.25292015], [72.83958435, 19.25291443], [72.83958435, 19.25347137], [72.83986664, 19.25346947], [72.83986664, 19.25403023], [72.83958435, 19.25402832], [72.83958435, 19.25458336], [72.83930206, 19.25457954], [72.83930206, 19.25542068], [72.8390274, 19.25542068], [72.8390274, 19.25570107], [72.83875275, 19.25569534], [72.83875275, 19.25597191], [72.83847046, 19.25597], [72.83847046, 19.25625038], [72.8381958, 19.25625038], [72.8381958, 19.25653076], [72.83763885, 19.25652885], [72.83763885, 19.25708389], [72.83742523, 19.25708008], [72.83735657, 19.25764084], [72.83708191, 19.25763893], [72.83708191, 19.25819397], [72.83680725, 19.25819397], [72.83680725, 19.25847244], [72.83652496, 19.25847244], [72.83652496, 19.25875092], [72.83598328, 19.25875092], [72.83598328, 19.25902939], [72.83569336, 19.25902748], [72.83569336, 19.25958252], [72.8354187, 19.25958061], [72.8354187, 19.26042175], [72.83513641, 19.26041603], [72.83513641, 19.2606945], [72.8354187, 19.26069069], [72.8354187, 19.26153183], [72.83569336, 19.26152802], [72.83569336, 19.26208115], [72.83597565, 19.26208115], [72.83597565, 19.26236153], [72.83625031, 19.26236153], [72.83625031, 19.2634716], [72.83652496, 19.2634716], [72.83652496, 19.26375008], [72.83679962, 19.26375008], [72.83679962, 19.26403999], [72.83708191, 19.26403999], [72.83708191, 19.26486015], [72.83735657, 19.26486015], [72.83735657, 19.26514053], [72.83763885, 19.26514053], [72.83763885, 19.26542091], [72.83791351, 19.2654171], [72.83791351, 19.26569557], [72.8381958, 19.26569557], [72.8381958, 19.26597214], [72.83847046, 19.26597023], [72.83847046, 19.26625061], [72.83875275, 19.26625061], [72.83875275, 19.26653099], [72.8390274, 19.26653099], [72.8390274, 19.26680946], [72.83930206, 19.26680565], [72.83930206, 19.26708412], [72.83957672, 19.26708031], [72.83957672, 19.26736069], [72.83930206, 19.26736069], [72.83930206, 19.26764107], [72.8390274, 19.26764107], [72.8390274, 19.26736069], [72.83875275, 19.26736069], [72.83875275, 19.26708031], [72.8381958, 19.26708412], [72.8381958, 19.26680565], [72.83790588, 19.26680946], [72.83790588, 19.26653099], [72.83763885, 19.26653099], [72.83763885, 19.26625061], [72.83735657, 19.26625061], [72.83735657, 19.26597023], [72.83708191, 19.26597214], [72.83708191, 19.26569557], [72.83680725, 19.26569557], [72.83680725, 19.26513863], [72.83653259, 19.26514053], [72.83653259, 19.26486015], [72.83625031, 19.26486206], [72.83625031, 19.26402855], [72.83598328, 19.26403999], [72.83598328, 19.26375008], [72.83569336, 19.26375008], [72.83569336, 19.2634697], [72.8354187, 19.2634716], [72.8354187, 19.26236153], [72.83513641, 19.26236153], [72.83513641, 19.26208115], [72.83486176, 19.26208115], [72.83486176, 19.26152802], [72.8345871, 19.26153183], [72.8345871, 19.26069069], [72.83430481, 19.2606945], [72.83430481, 19.26013947], [72.8345871, 19.26013947], [72.8345871, 19.25931168], [72.83486176, 19.25931168], [72.83486176, 19.25875092], [72.83513641, 19.25875092], [72.83513641, 19.25847054], [72.83569336, 19.25847244], [72.83569336, 19.25819397], [72.83597565, 19.25819397], [72.83597565, 19.2579174], [72.83625031, 19.2579174], [72.83625031, 19.25763893], [72.83653259, 19.25764084], [72.83653259, 19.25707817], [72.83680725, 19.25708389], [72.83680725, 19.25652885], [72.83708191, 19.25653076], [72.83708191, 19.25625038], [72.83735657, 19.25625038], [72.83735657, 19.25597], [72.83763885, 19.25597191], [72.83763885, 19.25569534], [72.83790588, 19.25570107], [72.83790588, 19.25374985], [72.83763885, 19.25374985], [72.83763885, 19.25346947], [72.8373642, 19.25347137], [72.8373642, 19.25291443], [72.83708191, 19.25292015], [72.83708191, 19.25263977], [72.83679962, 19.25263977], [72.83679962, 19.25208092], [72.83652496, 19.25208473], [72.83652496, 19.25124931], [72.83598328, 19.25125122], [72.83598328, 19.25097084], [72.8345871, 19.25097466], [72.8345871, 19.25069237], [72.83347321, 19.25069237], [72.83347321, 19.2504158], [72.83069611, 19.25041962], [72.83069611, 19.25014114], [72.8290329, 19.25014114], [72.8290329, 19.24986076], [72.82847595, 19.24986076], [72.82847595, 19.24958038], [72.82763672, 19.24958229], [72.82763672, 19.24930573], [72.82736206, 19.24930573], [72.82736206, 19.24958229], [72.82707977, 19.24958229], [72.82707977, 19.24930573], [72.82681274, 19.24930954], [72.82681274, 19.24903107], [72.82624817, 19.24903107], [72.82624817, 19.24875069], [72.82569885, 19.24875069], [72.82569122, 19.24847031], [72.82541656, 19.24847031], [72.82541656, 19.24819374], [72.82514191, 19.24819374], [72.82514191, 19.24791718], [72.82485962, 19.2479229], [72.82485962, 19.24764252], [72.82457733, 19.24764252], [72.82457733, 19.24736023], [72.82430267, 19.24736023], [72.82430267, 19.24708176], [72.82375336, 19.24708366], [72.82375336, 19.24680519], [72.82347107, 19.24681282], [72.82347107, 19.24653244], [72.82319641, 19.24653244], [72.82319641, 19.24625015], [72.82290649, 19.24625015], [72.82290649, 19.24596977], [72.82263947, 19.24597168], [72.82263947, 19.24569511], [72.82235718, 19.24570084], [72.82235718, 19.24541855], [72.82180023, 19.24541855], [72.82180023, 19.24513817], [72.82096863, 19.24513817], [72.82096863, 19.24541855], [72.82041931, 19.24541855], [72.82041931, 19.2448597], [72.82069397, 19.2448616], [72.82069397, 19.24458313], [72.82096863, 19.24458313], [72.82096863, 19.24374962], [72.8215332, 19.24374962], [72.82152557, 19.2420826], [72.82125092, 19.2420826], [72.82125092, 19.24180794], [72.8215332, 19.24180984], [72.8215332, 19.24152946], [72.82125092, 19.24152946], [72.82125092, 19.24069023], [72.82096863, 19.24069595], [72.82096863, 19.24013901], [72.82068634, 19.24014091], [72.82068634, 19.23931122], [72.82041931, 19.23931122], [72.82041931, 19.23847008], [72.82013702, 19.23847389], [72.82013702, 19.23763847], [72.81986237, 19.23764038], [72.81986237, 19.23681068], [72.81958008, 19.23681068], [72.81958008, 19.23624992], [72.81930542, 19.23624992], [72.81930542, 19.23597145], [72.81903076, 19.23597145], [72.81903076, 19.23541641], [72.81846619, 19.23542023], [72.81846619, 19.23513985], [72.81819153, 19.23513985], [72.81819153, 19.2345829], [72.81791687, 19.2345829], [72.81791687, 19.23430634], [72.81764221, 19.23431015], [72.81764221, 19.23403168], [72.8170929, 19.23403168], [72.8170929, 19.23347092], [72.81680298, 19.23347282], [72.81680298, 19.23291588], [72.81652832, 19.2329216], [72.81652832, 19.23263931], [72.81624603, 19.23263931], [72.81624603, 19.23208046], [72.81597137, 19.23208427], [72.81597137, 19.2318058], [72.81569672, 19.23181152], [72.81569672, 19.23125076], [72.81513977, 19.23125076], [72.81513977, 19.23097038], [72.81485748, 19.23097229], [72.81485748, 19.23069382], [72.81458282, 19.23069382], [72.81458282, 19.23041725], [72.81430817, 19.23041916], [72.81430817, 19.23014069], [72.81318665, 19.23014069], [72.81318665, 19.22986031], [72.81236267, 19.22986031], [72.81236267, 19.22957993], [72.81208038, 19.22958374], [72.81208038, 19.22930527], [72.81181335, 19.22930908], [72.81181335, 19.22903061], [72.81153107, 19.22903061], [72.81153107, 19.22875023], [72.81124878, 19.22875023], [72.81124878, 19.22846985], [72.81097412, 19.22847176], [72.81097412, 19.22819519], [72.81069183, 19.22820091], [72.81069183, 19.22792816], [72.81041718, 19.22792816], [72.81041718, 19.22764015], [72.81014252, 19.22764015], [72.81014252, 19.22735977], [72.80986023, 19.22736168], [72.80986023, 19.22680664], [72.80958557, 19.22680664], [72.80958557, 19.22652817], [72.80930328, 19.22653008], [72.80930328, 19.22624969], [72.80902863, 19.22624969], [72.80902863, 19.22597122], [72.80847168, 19.22597313], [72.80847168, 19.22569656], [72.80819702, 19.22569656], [72.80819702, 19.22541428], [72.8079071, 19.22542], [72.8079071, 19.22513962], [72.80764008, 19.22513962], [72.80764008, 19.22487068], [72.80735779, 19.22487068], [72.80735779, 19.22458076], [72.80708313, 19.22458458], [72.80708313, 19.22402763], [72.80680084, 19.22402954], [72.80680084, 19.22347069], [72.80652618, 19.2234745], [72.80652618, 19.22319221], [72.80625153, 19.22319221], [72.80625153, 19.22291756], [72.80596924, 19.22291946], [72.80596924, 19.22236061], [72.80568695, 19.22236061], [72.80568695, 19.22208023], [72.80541992, 19.22208214], [72.80541992, 19.22180557], [72.80513763, 19.22180557], [72.80513763, 19.22097015], [72.80430603, 19.22097015], [72.80430603, 19.22125053], [72.80403137, 19.22125053], [72.80403137, 19.22153282], [72.80347443, 19.2215271], [72.80347443, 19.22180557], [72.80291748, 19.22180557], [72.80291748, 19.22208214], [72.80236053, 19.22208023], [72.80236053, 19.22236061], [72.80069733, 19.22236061], [72.80069733, 19.22291946], [72.80041504, 19.22291756], [72.80041504, 19.22319221], [72.79985809, 19.22319221], [72.79985809, 19.2234745], [72.79875183, 19.2234745], [72.79875183, 19.22319221], [72.79846954, 19.22319221], [72.79846954, 19.22263908], [72.79875183, 19.2226429], [72.79875183, 19.22236061], [72.79930878, 19.22236061], [72.79930878, 19.22208023], [72.80014038, 19.22208214], [72.80014038, 19.22180557], [72.80069733, 19.22180557], [72.80069733, 19.2215271], [72.80124664, 19.22153282], [72.80124664, 19.22125053], [72.80152893, 19.22125053], [72.80152893, 19.22097015], [72.80263519, 19.22097015], [72.80263519, 19.22069359], [72.80291748, 19.22069359], [72.80291748, 19.22041702], [72.80319214, 19.22042274], [72.80319214, 19.22014046], [72.8034668, 19.22014046], [72.8034668, 19.21986008], [72.80374908, 19.21986008], [72.80374908, 19.21930504], [72.80403137, 19.21931267], [72.80403137, 19.21874046], [72.80374908, 19.21874809], [72.80374908, 19.21736145], [72.80347443, 19.21736145], [72.80347443, 19.21680641], [72.80319214, 19.21680832], [72.80319214, 19.21652985], [72.80291748, 19.21652985], [72.80291748, 19.21624947], [72.80264282, 19.21624947], [72.80264282, 19.21652985], [72.80236053, 19.21652985], [72.80236053, 19.21624947], [72.80208588, 19.21624947], [72.80208588, 19.21569824], [72.80179596, 19.21569824], [72.80179596, 19.21541977], [72.80152893, 19.21541977], [72.80152893, 19.21513939], [72.80124664, 19.21513939], [72.80124664, 19.21486092], [72.80097198, 19.21486092], [72.80097198, 19.21458054], [72.80069733, 19.21458244], [72.80069733, 19.21430779], [72.80014038, 19.21430969], [72.80014038, 19.21347046], [72.79985809, 19.21347237], [72.79985809, 19.21291733], [72.79957581, 19.21293068], [72.79957581, 19.21264076], [72.79930878, 19.21264076], [72.79930878, 19.21236038], [72.79902649, 19.21236038], [72.79902649, 19.21208], [72.79875183, 19.21208572], [72.79875183, 19.21180344], [72.79846954, 19.21181107], [72.79846954, 19.21153069], [72.79818726, 19.21153069], [72.79818726, 19.21125031], [72.79792023, 19.21125031], [72.79792023, 19.21070099], [72.79763031, 19.21070099], [72.79763031, 19.21042061], [72.79736328, 19.21042061], [72.79736328, 19.20985985], [72.79708099, 19.20986366], [72.79708099, 19.20930481], [72.79680634, 19.20930481], [72.79680634, 19.20874977], [72.79651642, 19.20874977], [72.79651642, 19.20792007], [72.79624939, 19.20792007], [72.79624939, 19.20763969], [72.7959671, 19.20763969], [72.7959671, 19.20708084], [72.79486084, 19.20708275], [72.79486084, 19.20680618], [72.79458618, 19.20680618], [72.79458618, 19.20652771], [72.79429626, 19.20652962], [72.79429626, 19.20624924], [72.79402924, 19.20624924], [72.79402924, 19.20597076], [72.79374695, 19.20597267], [72.79374695, 19.20541763], [72.79319763, 19.20542145], [72.79319763, 19.20513916], [72.79292297, 19.20513916], [72.79292297, 19.20458031], [72.79264069, 19.20458412], [72.79264069, 19.20430565], [72.7923584, 19.20430756], [72.7923584, 19.20375824], [72.79207611, 19.20375824], [72.79207611, 19.20264053], [72.79181671, 19.20264053], [72.79181671, 19.20070076], [72.79207611, 19.20070076], [72.79207611, 19.20014], [72.7923584, 19.20014], [72.7923584, 19.19985962], [72.79264069, 19.19986153], [72.79264069, 19.19958305], [72.79291534, 19.19958305], [72.79291534, 19.19902802], [72.79319763, 19.19902992], [72.79319763, 19.19847107], [72.79347229, 19.19847488], [72.79347229, 19.19763947], [72.79374695, 19.19763947], [72.79374695, 19.19597435], [72.79347229, 19.19597435], [72.79347229, 19.19569206], [72.79319763, 19.19569206], [72.79319763, 19.19513893], [72.79292297, 19.19514275], [72.79292297, 19.19486046], [72.79264069, 19.19486046], [72.79264069, 19.19457054], [72.7923584, 19.19458389], [72.7923584, 19.19430542], [72.79207611, 19.19431114], [72.79207611, 19.19403267], [72.79181671, 19.19403267], [72.79181671, 19.19375038], [72.79152679, 19.19375038], [72.79152679, 19.19347191], [72.79125214, 19.19347191], [72.79125214, 19.19319534], [72.79096985, 19.19320107], [72.79096985, 19.19292259], [72.79013824, 19.19292259], [72.79013824, 19.1926403], [72.78901672, 19.1926403], [72.78901672, 19.19292259], [72.78875732, 19.19292259], [72.78875732, 19.19320107], [72.78847504, 19.19319534], [72.78847504, 19.19347191], [72.78791809, 19.19347191], [72.78791809, 19.19319534], [72.78708649, 19.19320107], [72.78708649, 19.19292259], [72.7859726, 19.19292259], [72.7859726, 19.1926403], [72.78569031, 19.1926403], [72.78569031, 19.19235992], [72.78542328, 19.19235992], [72.78542328, 19.1926403], [72.78457642, 19.1926403], [72.78457642, 19.19235992], [72.78375244, 19.19235992], [72.78375244, 19.1926403], [72.78347015, 19.1926403], [72.78347015, 19.19292259], [72.78320313, 19.19292259], [72.78320313, 19.19320107], [72.78236389, 19.19319534], [72.78236389, 19.19347191], [72.7820816, 19.19347191], [72.7820816, 19.19375038], [72.78180695, 19.19375038], [72.78180695, 19.19403267], [72.78152466, 19.19402695], [72.78152466, 19.19458389], [72.78125, 19.19457054], [72.78125, 19.19652939], [72.78152466, 19.19652748], [72.78152466, 19.19708252], [72.78180695, 19.19708252], [72.78180695, 19.19930077], [72.7820816, 19.1993103], [72.7820816, 19.20014], [72.78235626, 19.20014], [72.78235626, 19.20070076], [72.78263855, 19.20069695], [72.78263855, 19.2009716], [72.78291321, 19.2009697], [72.78291321, 19.20125008], [72.78457642, 19.20125008], [72.78457642, 19.2009697], [72.78514099, 19.2009697], [72.78514099, 19.20125008], [72.78569031, 19.20125008], [72.78569031, 19.20153046], [72.7859726, 19.20153046], [72.7859726, 19.20181084], [72.78624725, 19.20181084], [72.78624725, 19.20264053], [72.7859726, 19.20263863], [72.7859726, 19.20347214], [72.78569031, 19.20347023], [72.78569031, 19.20375824], [72.78514099, 19.20375824], [72.78514099, 19.20513916], [72.7848587, 19.20513916], [72.7848587, 19.20542145], [72.78458405, 19.20541763], [72.78458405, 19.2056942], [72.78430939, 19.2056942], [72.78430176, 19.20597267], [72.78375244, 19.20597076], [72.78375244, 19.20624924], [72.78151703, 19.20624924], [72.78151703, 19.20597076], [72.78125, 19.20597267], [72.78125, 19.2056942], [72.78097534, 19.2056942], [72.78097534, 19.20541763], [72.77929688, 19.20542145], [72.77929688, 19.20735931], [72.77958679, 19.20735931], [72.77958679, 19.20763969], [72.77986145, 19.20763969], [72.77986145, 19.20792007], [72.78013611, 19.20791626], [72.78013611, 19.2084713], [72.7804184, 19.20846939], [72.7804184, 19.20903015], [72.78069305, 19.20902824], [72.78069305, 19.20930481], [72.78098297, 19.2093029], [72.78098297, 19.21014023], [72.78125, 19.21014023], [72.78125, 19.21153069], [72.78151703, 19.21153069], [72.78151703, 19.21513939], [72.78125, 19.21513939], [72.78125, 19.21569824], [72.78098297, 19.21569824], [72.78098297, 19.21652985], [72.78069305, 19.21652985], [72.78069305, 19.21680832], [72.7804184, 19.21680641], [72.7804184, 19.21708298], [72.78013611, 19.21708298], [72.78013611, 19.21736145], [72.77986145, 19.21735954], [72.77986145, 19.21763992], [72.77958679, 19.21763992], [72.77958679, 19.2179184], [72.77902985, 19.2179184], [72.77902985, 19.21931267], [72.77874756, 19.21930504], [72.77874756, 19.21986008], [72.7784729, 19.21986008], [72.7784729, 19.22014046], [72.77819824, 19.22014046], [72.77819824, 19.21999931], [72.77819061, 19.21986008], [72.77791595, 19.21986008], [72.77791595, 19.22014046], [72.7776413, 19.22013855], [72.7776413, 19.22069359], [72.77735901, 19.22069359], [72.77735901, 19.22097015], [72.77680206, 19.22097015], [72.77680206, 19.22125053], [72.7765274, 19.22125053], [72.7765274, 19.22153282], [72.77625275, 19.2215271], [72.77625275, 19.22208214], [72.77597046, 19.22208214], [72.77597046, 19.22458458], [72.77625275, 19.22458458], [72.77625275, 19.22569656], [72.7765274, 19.22569084], [72.7765274, 19.22624969], [72.77680206, 19.22624969], [72.77680206, 19.22680664], [72.77735901, 19.22680664], [72.77735901, 19.22708321], [72.7776413, 19.22708321], [72.7776413, 19.22736168], [72.77791595, 19.22735977], [72.77791595, 19.22764015], [72.7784729, 19.22764015], [72.7784729, 19.22792816], [72.77874756, 19.22792816], [72.77874756, 19.22820091], [72.77902985, 19.22820091], [72.77902985, 19.22875023], [72.77929688, 19.22875023], [72.77929688, 19.22986031], [72.77958679, 19.22986031], [72.77958679, 19.23041916], [72.77986145, 19.23041725], [72.77986145, 19.23319435], [72.77958679, 19.23319054], [72.77958679, 19.23542023], [72.7793045, 19.23541641], [72.7793045, 19.23597145], [72.77902985, 19.23596954], [72.77902985, 19.23624992], [72.77874756, 19.23624992], [72.77874756, 19.2365303], [72.77819824, 19.2365284], [72.77819824, 19.23708153], [72.77791595, 19.23707962], [72.77791595, 19.23792076], [72.77958679, 19.23791695], [72.77958679, 19.23819542], [72.77986145, 19.23819542], [72.77986145, 19.23847389], [72.78013611, 19.23847008], [72.78013611, 19.23931122], [72.7804184, 19.23931122], [72.7804184, 19.23987007], [72.78069305, 19.23986053], [72.78069305, 19.24097252], [72.7804184, 19.24097061], [72.7804184, 19.24125099], [72.78013611, 19.24125099], [72.78013611, 19.24236107], [72.7804184, 19.24236107], [72.7804184, 19.24319458], [72.78069305, 19.24319458], [72.78069305, 19.24347305], [72.78097534, 19.24347305], [72.78097534, 19.24374962], [72.78125, 19.24374962], [72.78125, 19.24430466], [72.78098297, 19.24430084], [72.78098297, 19.24541855], [72.78125, 19.24541664], [72.78125, 19.24597168], [72.78151703, 19.24596977], [72.78151703, 19.24681282], [72.78180695, 19.24681282], [72.78180695, 19.2479229], [72.7820816, 19.2479229], [72.7820816, 19.24903107], [72.78235626, 19.24903107], [72.78235626, 19.24986076], [72.78263092, 19.24986076], [72.78263092, 19.25014114], [72.78291321, 19.25014114], [72.78291321, 19.25181007], [72.78263855, 19.25180626], [72.78263855, 19.25319672], [72.78235626, 19.25319099], [72.78235626, 19.25653076], [72.7820816, 19.25652885], [72.7820816, 19.25708389], [72.78180695, 19.25708389], [72.78180695, 19.25819397], [72.78152466, 19.25819397], [72.78152466, 19.25958252], [72.78180695, 19.25958061], [72.78180695, 19.26013947], [72.78291321, 19.26013947], [72.78291321, 19.26042175], [72.7831955, 19.26041603], [72.7831955, 19.2606945], [72.78347015, 19.26069069], [72.78347015, 19.26153183], [72.78375244, 19.26152802], [72.78375244, 19.26180267], [72.7840271, 19.26180649], [72.7840271, 19.2634716], [72.78375244, 19.2634697], [72.78375244, 19.26403999], [72.78347015, 19.26403999], [72.78347015, 19.26514053], [72.78375244, 19.26514053], [72.78375244, 19.26542091], [72.78430176, 19.2654171], [72.78430939, 19.26569557], [72.78458405, 19.26569557], [72.78458405, 19.26597214], [72.78430939, 19.26597214], [72.78430176, 19.2681942], [72.7840271, 19.2681942], [72.7840271, 19.26847267], [72.78375244, 19.26847076], [72.78375244, 19.26875114], [72.78347015, 19.26875114], [72.78347015, 19.26902962], [72.7820816, 19.26902962], [72.7820816, 19.26930809], [72.78152466, 19.26930618], [72.78152466, 19.26958275], [72.78125, 19.26958275], [72.78125, 19.27180481], [72.78097534, 19.27180481], [72.78097534, 19.27208328], [72.78069305, 19.27208328], [72.78069305, 19.27291679], [72.7804184, 19.27291679], [72.7804184, 19.27347183], [72.78013611, 19.27347183], [72.78013611, 19.27542114], [72.77986145, 19.27542114], [72.77986145, 19.27625275], [72.77958679, 19.27625275], [72.77958679, 19.27653122], [72.7793045, 19.2765274], [72.7793045, 19.27708244], [72.77902985, 19.27708054], [72.77902985, 19.27791977], [72.77874756, 19.27791405], [72.77874756, 19.27819252], [72.7784729, 19.27819252], [72.7784729, 19.27847481], [72.77819824, 19.27847099], [72.77819824, 19.27903938], [72.77874756, 19.27903938], [72.77874756, 19.27931023], [72.77986145, 19.27930641], [72.77986145, 19.27958488], [72.78180695, 19.27958488], [72.78180695, 19.27930641], [72.7831955, 19.27930641], [72.7831955, 19.27986145], [72.78347015, 19.27985954], [72.78347015, 19.2804203], [72.78375244, 19.2804203], [72.78375244, 19.28763962], [72.7840271, 19.28763962], [72.7840271, 19.28847122], [72.78430176, 19.28847122], [72.78430939, 19.28903008], [72.78457642, 19.28903008], [72.78457642, 19.29153061], [72.78430939, 19.29153061], [72.78430939, 19.29375076], [72.78457642, 19.29375076], [72.78457642, 19.30042267], [72.78430939, 19.30042267], [72.78430939, 19.30264282], [72.78458405, 19.30263901], [72.78458405, 19.30347443], [72.7848587, 19.30347061], [72.7848587, 19.3037529], [72.78514099, 19.3037529], [72.78514099, 19.30402946], [72.78542328, 19.30402946], [72.78542328, 19.30430984], [72.78569794, 19.30430412], [72.78569794, 19.30597305], [72.7859726, 19.3059597], [72.7859726, 19.30624962], [72.78624725, 19.30624962], [72.78624725, 19.30653], [72.78652954, 19.30652809], [72.78652954, 19.30680656], [72.78624725, 19.30680656], [72.78624725, 19.30708313], [72.78652954, 19.30708313], [72.78652954, 19.3073616], [72.78679657, 19.3073597], [72.78679657, 19.30764008], [72.78708649, 19.30764008], [72.78708649, 19.30792046], [72.78736115, 19.30792046], [72.78736115, 19.30820084], [72.78791809, 19.30819511], [72.78791809, 19.30847168], [72.78847504, 19.30847168], [72.78847504, 19.30875015], [72.78902435, 19.30875015], [72.78902435, 19.30902863], [72.7895813, 19.309021], [72.7895813, 19.30931091], [72.78986359, 19.30930519], [72.78986359, 19.30958366], [72.79096985, 19.30957985], [72.79096985, 19.30986023], [72.79181671, 19.30986023], [72.79181671, 19.31014061], [72.7923584, 19.31014061], [72.7923584, 19.31041908], [72.79319763, 19.31042862], [72.79319763, 19.31125069], [72.79347229, 19.31125069], [72.79347229, 19.31209183], [72.79374695, 19.3120842], [72.79374695, 19.31319427], [72.79402924, 19.31318855], [72.79402924, 19.31431007], [72.79429626, 19.31431007], [72.79429626, 19.31515121], [72.79458618, 19.31515121], [72.79458618, 19.31624985], [72.79486084, 19.31624985], [72.79486084, 19.31708145], [72.7951355, 19.31708145], [72.7951355, 19.31819344], [72.79541779, 19.31818962], [72.79541779, 19.31931114], [72.79569244, 19.31931114], [72.79569244, 19.32014084], [72.7959671, 19.32014084], [72.7959671, 19.32125092], [72.79624939, 19.32125092], [72.79624939, 19.32208252], [72.79652405, 19.32208252], [72.79652405, 19.3231945], [72.79680634, 19.3231945], [72.79680634, 19.32430077], [72.79708099, 19.32432175], [72.79708099, 19.32513809], [72.79736328, 19.32513809], [72.79736328, 19.32625008], [72.79763031, 19.32625008], [72.79763031, 19.32709122], [72.79792023, 19.32708359], [72.79792023, 19.32819366], [72.79818726, 19.32819176], [72.79818726, 19.32930946], [72.79846954, 19.32930565], [72.79846954, 19.33013916], [72.79875183, 19.33013916], [72.79875183, 19.33097458], [72.79902649, 19.33097076], [72.79902649, 19.33125114], [72.79846954, 19.33125114], [72.79846954, 19.33152962], [72.79818726, 19.33152962], [72.79818726, 19.33181], [72.79792023, 19.33180428], [72.79792023, 19.33208466], [72.79763031, 19.33208084], [72.79763031, 19.33236122], [72.79708099, 19.33236122], [72.79708099, 19.33263969], [72.79680634, 19.33263969], [72.79680634, 19.33292007], [72.79652405, 19.33291435], [72.79652405, 19.33319664], [72.79624939, 19.33319092], [72.79624939, 19.33374977], [72.79569244, 19.33374977], [72.79569244, 19.33403015], [72.79541779, 19.33402824], [72.79541779, 19.33458328], [72.7951355, 19.33458328], [72.7951355, 19.33486176], [72.79486084, 19.33485985], [72.79486084, 19.33514023], [72.79429626, 19.33514023], [72.79429626, 19.33570099], [72.79374695, 19.33569527], [72.79374695, 19.33597183], [72.79347229, 19.33596992], [72.79347229, 19.33653069], [72.79319763, 19.33653069], [72.79319763, 19.33680916], [72.79291534, 19.33680534], [72.79292297, 19.33736038], [72.79264069, 19.33736038], [72.79264069, 19.33764076], [72.7923584, 19.33764076], [72.7923584, 19.33791924], [72.79208374, 19.33791733], [72.79208374, 19.33819389], [72.79180908, 19.33819389], [72.79180908, 19.33847237], [72.79152679, 19.33847046], [72.79152679, 19.33875084], [72.79125214, 19.33875084], [72.79125214, 19.33932114], [72.79069519, 19.33930588], [72.79070282, 19.33986092], [72.7904129, 19.33986092], [72.7904129, 19.34042168], [72.79013824, 19.34041595], [72.79013824, 19.34069443], [72.78986359, 19.34069443], [72.78986359, 19.3409729], [72.7895813, 19.34096909], [72.7895813, 19.34153175], [72.78930664, 19.34153175], [72.78930664, 19.34181023], [72.78902435, 19.34180641], [72.78902435, 19.34208107], [72.78875732, 19.34207153], [72.78875732, 19.34263992], [72.78848267, 19.34263992], [72.78848267, 19.3429203], [72.78791809, 19.3429203], [72.78791809, 19.34320068], [72.7876358, 19.34319305], [72.7876358, 19.34347153], [72.78708649, 19.34346962], [72.78708649, 19.34403038], [72.7868042, 19.34402847], [72.7868042, 19.34458542], [72.78652954, 19.34458542], [72.78652954, 19.34486389], [72.78569031, 19.34486008], [72.78569031, 19.34542084], [72.78541565, 19.34541512], [72.78541565, 19.3456955], [72.78514099, 19.3456955], [72.78514099, 19.34597206], [72.7848587, 19.34597015], [72.7848587, 19.34625053], [72.78457642, 19.34625053], [72.78457642, 19.34653091], [72.78430939, 19.34653091], [72.78430176, 19.34680939], [72.7840271, 19.34680367], [72.7840271, 19.34708595], [72.78375244, 19.34708023], [72.78375244, 19.34736061], [72.78347015, 19.34736061], [72.78347015, 19.34819984], [72.7831955, 19.34819412], [72.7831955, 19.3484726], [72.78291321, 19.34847069], [72.78291321, 19.34902954], [72.78263092, 19.34902954], [72.78263092, 19.34930992], [72.7820816, 19.34930611], [72.7820816, 19.34958267], [72.78180695, 19.34958076], [72.78180695, 19.34986115], [72.78151703, 19.34986115], [72.78151703, 19.35013962], [72.78125, 19.35013962], [72.78125, 19.35041809], [72.7804184, 19.35041618], [72.7804184, 19.35069466], [72.78013611, 19.35069466], [72.78013611, 19.35097313], [72.77986145, 19.35097122], [72.77986145, 19.35125923], [72.77791595, 19.35125923], [72.77791595, 19.35152817], [72.7776413, 19.35152817], [72.7776413, 19.35180473], [72.77735901, 19.35180473], [72.77735901, 19.35236168], [72.77707672, 19.35235977], [72.77707672, 19.35263824], [72.7765274, 19.35263824], [72.7765274, 19.35292244], [72.7756958, 19.35292244], [72.7756958, 19.35320282], [72.77540588, 19.35320282], [72.77540588, 19.35403252], [72.77513885, 19.3540287], [72.77513885, 19.35458374], [72.77485657, 19.35458183], [72.77485657, 19.35486031], [72.77458191, 19.35486031], [72.77458191, 19.35542107], [72.77430725, 19.35541725], [72.77430725, 19.35597229], [72.77401733, 19.35597038], [72.77401733, 19.35653114], [72.77375031, 19.35652733], [72.77375031, 19.35708237], [72.77347565, 19.35708237], [72.77348328, 19.35736084], [72.77319336, 19.35736084], [72.77319336, 19.35819244], [72.7729187, 19.35819054], [72.7729187, 19.35874939], [72.77263641, 19.35874939], [72.77263641, 19.35958481], [72.77236176, 19.35958099], [72.77236176, 19.36013985], [72.7720871, 19.36013985], [72.7720871, 19.3615303], [72.77179718, 19.3615303], [72.77179718, 19.36181068], [72.77153015, 19.36180687], [72.77153015, 19.36208344], [72.77124786, 19.36208344], [72.77124786, 19.36236191], [72.77097321, 19.36236], [72.77097321, 19.36264038], [72.77069092, 19.36264038], [72.77069092, 19.36292076], [72.77041626, 19.36292076], [72.77041626, 19.36320114], [72.7701416, 19.36319542], [72.7701416, 19.36347198], [72.76985931, 19.36346817], [72.76985931, 19.36375046], [72.76957703, 19.36375046], [72.76957703, 19.36430931], [72.76930237, 19.3643055], [72.76930237, 19.36458397], [72.76902771, 19.36457825], [72.76902771, 19.36486053], [72.76875305, 19.36486053], [72.76875305, 19.36514091], [72.76847076, 19.36514091], [72.76847076, 19.36541939], [72.76819611, 19.36541748], [72.76819611, 19.36597252], [72.76764679, 19.36597061], [72.76764679, 19.36626053], [72.76735687, 19.36626053], [72.76735687, 19.36652946], [72.76680756, 19.36652946], [72.76680756, 19.36681175], [72.76652527, 19.36680603], [72.7665329, 19.36735916], [72.76625061, 19.36735916], [72.76625061, 19.36763954], [72.76568604, 19.36763954], [72.76568604, 19.36792183], [72.76541901, 19.36791611], [72.76541901, 19.36819458], [72.76513672, 19.36819458], [72.76513672, 19.36847115], [72.76486206, 19.36847115], [72.76486206, 19.36874962], [72.7645874, 19.36874962], [72.7645874, 19.36903191], [72.76403046, 19.36902809], [72.76403046, 19.36930466], [72.76374817, 19.36930466], [72.76374817, 19.36958122], [72.76319122, 19.36958122], [72.76319122, 19.3698616], [72.76291656, 19.3698597], [72.76291656, 19.37014008], [72.76264191, 19.37014008], [72.76264191, 19.37042046], [72.76235962, 19.37042046], [72.76235962, 19.37070084], [72.76208496, 19.37069321], [72.76208496, 19.37097168], [72.76152039, 19.37096977], [72.76152039, 19.37125015], [72.76125336, 19.37125015], [72.76125336, 19.37181091], [72.76097107, 19.37180328], [72.76097107, 19.37208557], [72.76069641, 19.37207985], [72.76069641, 19.37236023], [72.76013947, 19.37236023], [72.76013947, 19.37264061], [72.75986481, 19.3726387], [72.75986481, 19.37319565], [72.75958252, 19.37319565], [72.75958252, 19.37347221], [72.7590332, 19.37347031], [72.7590332, 19.37403107], [72.75875092, 19.37403107], [72.75875092, 19.37430954], [72.758461, 19.37430954], [72.758461, 19.37486076], [72.75818634, 19.37486076], [72.75818634, 19.37542915], [72.75791931, 19.37541771], [72.75791931, 19.37597275], [72.75763702, 19.37597275], [72.75763702, 19.37819481], [72.75736237, 19.37819481], [72.75736237, 19.37958336], [72.75763702, 19.37957764], [72.75763702, 19.3801403], [72.75791931, 19.3801384], [72.75791931, 19.38125038], [72.75818634, 19.38124084], [72.75818634, 19.38264275], [72.758461, 19.38264275], [72.758461, 19.38402939], [72.75875092, 19.38402748], [72.75875092, 19.38430405], [72.75902557, 19.38430405], [72.75902557, 19.38513947], [72.75930786, 19.38513947], [72.75930786, 19.38569641], [72.75958252, 19.38569641], [72.75958252, 19.38597488], [72.75985718, 19.38597107], [72.75985718, 19.38652992], [72.76013947, 19.38652992], [72.76013947, 19.38764], [72.76040649, 19.38764], [72.76040649, 19.38820076], [72.76069641, 19.38820076], [72.76069641, 19.38903046], [72.76097107, 19.38903046], [72.76097107, 19.38931084], [72.76125336, 19.38930511], [72.76125336, 19.38958359], [72.76152039, 19.38957977], [72.76152039, 19.39042854], [72.76180267, 19.3904171], [72.76180267, 19.39069366], [72.76208496, 19.39069366], [72.76208496, 19.39097214], [72.76235962, 19.39097023], [72.76235962, 19.39152908], [72.76568604, 19.39152908], [72.76568604, 19.39181137], [72.76597595, 19.39180565], [72.76597595, 19.3931942], [72.76569366, 19.3931942], [72.76569366, 19.39347267], [72.76513672, 19.39347076], [72.76513672, 19.39374924], [72.7645874, 19.39374924], [72.7645874, 19.39402962], [72.76403046, 19.39402962], [72.76403046, 19.3943119], [72.76374817, 19.39430618], [72.76374817, 19.39458275], [72.76346588, 19.39458275], [72.76346588, 19.39486122], [72.76319122, 19.39486122], [72.76319122, 19.39513969], [72.76291656, 19.39513969], [72.76291656, 19.39542007], [72.76235962, 19.39541626], [72.76235962, 19.3959713], [72.76208496, 19.3959713], [72.76208496, 19.39624977], [72.76180267, 19.39624977], [72.76180267, 19.39847183], [72.76152039, 19.39846992], [72.76152039, 19.40014076], [72.76180267, 19.40014076], [72.76180267, 19.40291977], [72.76152802, 19.40291786], [72.76152802, 19.40541649], [72.76125336, 19.40541649], [72.76125336, 19.40708351], [72.76097107, 19.4070816], [72.76097107, 19.40792274], [72.76069641, 19.40792274], [72.76069641, 19.40903282], [72.76040649, 19.40903282], [72.76040649, 19.40986061], [72.76013947, 19.40986061], [72.76013947, 19.41041946], [72.76041412, 19.41041756], [72.76041412, 19.41486168], [72.76013947, 19.41486168], [72.76013947, 19.41597176], [72.75985718, 19.41596985], [72.75985718, 19.41653061], [72.75958252, 19.41653061], [72.75958252, 19.41791916], [72.75930786, 19.41791916], [72.75930786, 19.41875076], [72.75902557, 19.41875076], [72.75902557, 19.41958427], [72.75875092, 19.41958046], [72.75875092, 19.42124939], [72.75818634, 19.42124939], [72.75818634, 19.42292023], [72.75791931, 19.42292023], [72.75791931, 19.4240303], [72.75763702, 19.4240284], [72.75763702, 19.42486382], [72.75736237, 19.42486382], [72.75736237, 19.42597389], [72.75708008, 19.42597008], [72.75708008, 19.42681122], [72.75680542, 19.42680359], [72.75681305, 19.42736053], [72.75653076, 19.42736053], [72.75653076, 19.42819595], [72.75624847, 19.42819595], [72.75624847, 19.42847252], [72.75596619, 19.42847061], [72.75596619, 19.42930984], [72.75569153, 19.42930794], [72.75569153, 19.43180466], [72.75514221, 19.43180466], [72.75514221, 19.43208313], [72.75485992, 19.43208313], [72.75485992, 19.4323616], [72.7545929, 19.43235016], [72.7545929, 19.43320274], [72.75430298, 19.43320274], [72.75430298, 19.43403244], [72.75402832, 19.43403244], [72.75402832, 19.43486023], [72.75375366, 19.43486023], [72.75375366, 19.43597031], [72.75347137, 19.43597031], [72.75347137, 19.43625069], [72.75319672, 19.43625069], [72.75319672, 19.43680954], [72.7529068, 19.43680954], [72.75291443, 19.43736076], [72.7526474, 19.43736076], [72.7526474, 19.43848038], [72.75235748, 19.43848038], [72.75235748, 19.43931007], [72.75208282, 19.43931007], [72.75208282, 19.44042015], [72.75180817, 19.44042015], [72.75180817, 19.44124985], [72.75152588, 19.44124985], [72.75152588, 19.44180679], [72.75125122, 19.44180679], [72.75125122, 19.44208336], [72.75096893, 19.44207954], [72.75096893, 19.44292068], [72.75125122, 19.44292068], [72.75125122, 19.44319916], [72.75068665, 19.44319916], [72.75068665, 19.44375038], [72.75041962, 19.44375038], [72.75041962, 19.44458389], [72.75013733, 19.44457817], [72.75013733, 19.44541931], [72.74986267, 19.44541931], [72.74986267, 19.44625092], [72.74958038, 19.44625092], [72.74958038, 19.44681168], [72.74930573, 19.44680595], [72.74931335, 19.44763947], [72.74903107, 19.44763947], [72.74903107, 19.4481945], [72.74874878, 19.4481945], [72.74874878, 19.44986153], [72.74846649, 19.44985962], [72.74846649, 19.45042038], [72.74819183, 19.45042038], [72.74819183, 19.4507103], [72.74791718, 19.4507103], [72.74791718, 19.45125008], [72.74764252, 19.45125008], [72.74764252, 19.4515686], [72.74764252, 19.45236206], [72.74736023, 19.45236206], [72.74736023, 19.45319557], [72.7470932, 19.45318985], [72.7470932, 19.45403099], [72.74680328, 19.45403099], [72.74680328, 19.45430946], [72.74652863, 19.45430756], [72.74652863, 19.45458412], [72.74597168, 19.45458031], [72.74597168, 19.45486069], [72.74569702, 19.45486069], [72.74569702, 19.45541954], [72.74541473, 19.45541763], [72.74541473, 19.4556942], [72.74514008, 19.4556942], [72.74514008, 19.45708275], [72.74485779, 19.45708084], [72.74485779, 19.45874977], [72.74458313, 19.45874977], [72.74458313, 19.46210098], [72.74458313, 19.46292114], [72.74485779, 19.46291733], [72.74485779, 19.46347237], [72.74514008, 19.46347046], [72.74514008, 19.46403122], [72.7454071, 19.46403122], [72.7454071, 19.46430969], [72.74569702, 19.46430588], [72.74569702, 19.46458244], [72.74597168, 19.46458054], [72.74597168, 19.46486092], [72.74624634, 19.46486092], [72.74624634, 19.46513939], [72.746521, 19.46513939], [72.746521, 19.46541977], [72.74680328, 19.46541405], [72.74680328, 19.46569633], [72.74708557, 19.46569633], [72.74708557, 19.46597481], [72.74764252, 19.46597099], [72.74764252, 19.46624947], [72.74791718, 19.46624947], [72.74791718, 19.46652985], [72.74819183, 19.46652985], [72.74819183, 19.46681023], [72.74847412, 19.46680641], [72.74847412, 19.46708488], [72.74903107, 19.46708107], [72.74903107, 19.46763992], [72.74958038, 19.46763992], [72.74958038, 19.4679203], [72.74986267, 19.4679203], [72.74986267, 19.46820068], [72.75013733, 19.46819687], [72.75013733, 19.46847153], [72.75041962, 19.46846008], [72.75041962, 19.46903038], [72.75068665, 19.46903038], [72.75068665, 19.46931076], [72.75096893, 19.46930695], [72.75096893, 19.46986198], [72.75125122, 19.46986008], [72.75125122, 19.47014046], [72.75152588, 19.47013855], [72.75152588, 19.47069359], [72.75180817, 19.47068977], [72.75180817, 19.47125053], [72.75235748, 19.47125053], [72.75235748, 19.47153091], [72.7526474, 19.47153091], [72.7526474, 19.47180939], [72.75291443, 19.47180557], [72.75291443, 19.47208405], [72.75319672, 19.47207832], [72.75319672, 19.47236061], [72.75347137, 19.47236061], [72.75347137, 19.47263908], [72.75375366, 19.47263908], [72.75375366, 19.47319412], [72.75402832, 19.47319412], [72.75402832, 19.4734726], [72.75430298, 19.47347069], [72.75430298, 19.47374916], [72.7545929, 19.47374916], [72.7545929, 19.47431183], [72.75541687, 19.47431183], [72.75541687, 19.4745903], [72.75596619, 19.4745903], [72.75596619, 19.47513962], [72.75653076, 19.47513962], [72.75653076, 19.47542191], [72.75736237, 19.47541618], [72.75736237, 19.47569466], [72.75986481, 19.47569466], [72.75986481, 19.47597122], [72.75995636, 19.47597122], [72.76069641, 19.47597122], [72.76069641, 19.47624969], [72.76125336, 19.47624969], [72.76125336, 19.47653008], [72.76208496, 19.47652817], [72.76208496, 19.47680473], [72.76291656, 19.47680473], [72.76291656, 19.47652817], [72.76346588, 19.47653008], [72.76346588, 19.47624969], [72.76431274, 19.47624969], [72.76431274, 19.47653008], [72.76457977, 19.47652817], [72.76457977, 19.47680473], [72.76486206, 19.47680473], [72.76486206, 19.47736168], [72.76541901, 19.47735977], [72.76541901, 19.47820091], [72.76568604, 19.47820091], [72.76568604, 19.47875023], [72.76597595, 19.47875023], [72.76597595, 19.47931099], [72.76625061, 19.47931099], [72.76625061, 19.47986031], [72.7665329, 19.47986031], [72.7665329, 19.48042107], [72.76680756, 19.48041725], [72.76680756, 19.48097229], [72.76708221, 19.48097038], [72.76708221, 19.48153114], [72.76735687, 19.48153114], [72.76735687, 19.48236084], [72.76708221, 19.48236084], [72.76708221, 19.48347282], [72.76735687, 19.48347092], [72.76735687, 19.48402977], [72.76790619, 19.48402977], [72.76790619, 19.48430824], [72.76819611, 19.48430634], [72.76819611, 19.4845829], [72.76847076, 19.4845829], [72.76847076, 19.48486137], [72.76875305, 19.48485947], [72.76875305, 19.48513985], [72.76930237, 19.48513985], [72.76930237, 19.48541832], [72.76958466, 19.48541641], [72.76958466, 19.48597145], [72.76985931, 19.48596764], [72.76985931, 19.48624992], [72.7701416, 19.48624992], [72.7701416, 19.4865303], [72.77097321, 19.4865303], [72.77097321, 19.48682022], [72.77236176, 19.48682022], [72.77236176, 19.48596764], [72.77263641, 19.48597145], [72.77263641, 19.48541641], [72.7729187, 19.48541832], [72.7729187, 19.48513985], [72.77319336, 19.48513985], [72.77319336, 19.48374939], [72.77348328, 19.48374939], [72.77348328, 19.48402977], [72.77403259, 19.48402977], [72.77403259, 19.48430824], [72.77430725, 19.48430634], [72.77430725, 19.4845829], [72.77458191, 19.4845829], [72.77458191, 19.48486137], [72.77485657, 19.48485947], [72.77485657, 19.48541832], [72.77513885, 19.48541641], [72.77513885, 19.48597145], [72.7748642, 19.48597145], [72.77485657, 19.4881916], [72.77458191, 19.48820114], [72.77458191, 19.48903275], [72.77485657, 19.48903275], [72.77485657, 19.48986053], [72.77513885, 19.48986053], [72.77513885, 19.49014282], [72.77540588, 19.49014282], [72.77540588, 19.49041939], [72.7756958, 19.49041748], [72.7756958, 19.49069214], [72.77625275, 19.49069214], [72.77625275, 19.49097252], [72.7765274, 19.49097061], [72.7765274, 19.4912529], [72.77819824, 19.4912529], [72.77819824, 19.49152946], [72.77874756, 19.49152946], [72.77874756, 19.4912529], [72.78013611, 19.4912529], [72.78013611, 19.49152946], [72.77986145, 19.49152756], [72.77986145, 19.49597168], [72.77958679, 19.49596977], [72.77958679, 19.50542068], [72.77986145, 19.50541687], [72.77986145, 19.50597191], [72.77958679, 19.50597], [72.77958679, 19.50653076], [72.77929688, 19.50653076], [72.77929688, 19.50681114], [72.77902985, 19.50681114], [72.77902985, 19.50736046], [72.77874756, 19.50736046], [72.77874756, 19.50875092], [72.77929688, 19.50875092], [72.77929688, 19.50930977], [72.77958679, 19.50930786], [72.77958679, 19.50958252], [72.78013611, 19.50958061], [72.78013611, 19.50986099], [72.7804184, 19.50986099], [72.7804184, 19.51013947], [72.78069305, 19.51013947], [72.78069305, 19.51041985], [72.78097534, 19.51041794], [72.78097534, 19.51097298], [72.78125, 19.51097107], [72.78125, 19.51124954], [72.78151703, 19.51124954], [72.78151703, 19.51152992], [72.7820816, 19.51152992], [72.7820816, 19.51180077], [72.78236389, 19.51180649], [72.78236389, 19.51236153], [72.78291321, 19.51235962], [72.78291321, 19.51263809], [72.78320313, 19.51263809], [72.78320313, 19.51291847], [72.78347015, 19.51291847], [72.78347015, 19.51320267], [72.78375244, 19.51320267], [72.78375244, 19.51403046], [72.7840271, 19.51402855], [72.7840271, 19.51458359], [72.78430176, 19.51458168], [72.78430939, 19.51514053], [72.78458405, 19.51513863], [72.78458405, 19.51597023], [72.7848587, 19.51597023], [72.7848587, 19.5165329], [72.78514099, 19.5165329], [72.78514099, 19.51736069], [72.78541565, 19.51736069], [72.78541565, 19.51819229], [72.78569031, 19.51819038], [72.78569031, 19.51875114], [72.78542328, 19.51875114], [72.78542328, 19.51931], [72.78569031, 19.51931], [72.78569031, 19.52042007], [72.7859726, 19.52042007], [72.7859726, 19.52124977], [72.78652954, 19.52124977], [72.78652954, 19.52430916], [72.78624725, 19.52430534], [72.78624725, 19.52597237], [72.7859726, 19.52597046], [72.7859726, 19.5268116], [72.78569031, 19.5268116], [72.78569794, 19.52736092], [72.78542328, 19.52736092], [72.78542328, 19.52792168], [72.7848587, 19.52791595], [72.7848587, 19.52819443], [72.78375244, 19.52819443], [72.78375244, 19.5284729], [72.7831955, 19.5284729], [72.7831955, 19.52874947], [72.77874756, 19.52874947], [72.77874756, 19.5284729], [72.7784729, 19.5284729], [72.7784729, 19.52819443], [72.77791595, 19.52819443], [72.77791595, 19.52791595], [72.77735901, 19.52792168], [72.77735901, 19.52763939], [72.77680206, 19.52763939], [72.77680206, 19.52736092], [72.7765274, 19.52736092], [72.7765274, 19.52708054], [72.77625275, 19.52708244], [72.77625275, 19.52680588], [72.7756958, 19.5268116], [72.7756958, 19.52652931], [72.77540588, 19.52652931], [72.77540588, 19.52597046], [72.7765274, 19.52597046], [72.7765274, 19.52625084], [72.77707672, 19.52625084], [72.77707672, 19.52652931], [72.7776413, 19.52652931], [72.7776413, 19.5268116], [72.77791595, 19.52680588], [72.77791595, 19.52708244], [72.77874756, 19.52708054], [72.77874756, 19.52736092], [72.77986145, 19.52736092], [72.77986145, 19.52763939], [72.78013611, 19.52763939], [72.78013611, 19.52736092], [72.78125, 19.52736092], [72.78125, 19.52708054], [72.7820816, 19.52708244], [72.7820816, 19.5265274], [72.78235626, 19.52652931], [72.78235626, 19.52625084], [72.78291321, 19.52625084], [72.78291321, 19.52597046], [72.78347015, 19.52597237], [72.78347015, 19.52569389], [72.7840271, 19.52570152], [72.7840271, 19.52235985], [72.78375244, 19.52236176], [72.78375244, 19.52124977], [72.78347015, 19.52124977], [72.78347015, 19.51625061], [72.7831955, 19.51625061], [72.7831955, 19.51569366], [72.78291321, 19.51569366], [72.78291321, 19.5154171], [72.78263092, 19.51542282], [72.78263092, 19.51514053], [72.78235626, 19.51514053], [72.78235626, 19.51486015], [72.7820816, 19.51486015], [72.7820816, 19.51430511], [72.78180695, 19.51431274], [72.78180695, 19.51403046], [72.78151703, 19.51403046], [72.78151703, 19.51375961], [72.78125, 19.51375961], [72.78125, 19.51320267], [72.78069305, 19.51320267], [72.78069305, 19.51291847], [72.78013611, 19.51291847], [72.78013611, 19.51263809], [72.77986145, 19.51263809], [72.77986145, 19.51235962], [72.77958679, 19.51236153], [72.77958679, 19.51208305], [72.7793045, 19.51208305], [72.7793045, 19.51152992], [72.77902985, 19.51152992], [72.77902985, 19.51124954], [72.77874756, 19.51124954], [72.77874756, 19.51097107], [72.7784729, 19.51097298], [72.7784729, 19.5106945], [72.77819824, 19.51069832], [72.77819061, 19.51041985], [72.77791595, 19.51041985], [72.77791595, 19.50986099], [72.77735901, 19.50986099], [72.77735901, 19.50958061], [72.77680206, 19.50958252], [72.77680206, 19.50902557], [72.7765274, 19.50902939], [72.7765274, 19.50875092], [72.7756958, 19.50875092], [72.7756958, 19.50847054], [72.77541351, 19.50847244], [72.77541351, 19.50763893], [72.77513885, 19.50763893], [72.77513885, 19.5070858], [72.7748642, 19.5070858], [72.7748642, 19.50680351], [72.77458191, 19.50681114], [72.77458191, 19.50653076], [72.77403259, 19.50653076], [72.77403259, 19.50625038], [72.77375031, 19.50625038], [72.77375031, 19.50570107], [72.77348328, 19.50570107], [72.77348328, 19.50542068], [72.77319336, 19.50542068], [72.77319336, 19.5051403], [72.7729187, 19.5051403], [72.7729187, 19.50485992], [72.77263641, 19.50486374], [72.77263641, 19.50458336], [72.76958466, 19.50458336], [72.76958466, 19.50430489], [72.76486206, 19.50430489], [72.76486206, 19.50486374], [72.7645874, 19.50485992], [72.7645874, 19.5051403], [72.76319122, 19.5051403], [72.76319122, 19.50542068], [72.76264191, 19.50542068], [72.76264191, 19.50570107], [72.76235962, 19.50569344], [72.76235962, 19.50597191], [72.76152039, 19.50597], [72.76152039, 19.50625038], [72.76069641, 19.50625038], [72.76069641, 19.50653076], [72.75985718, 19.50653076], [72.75985718, 19.50681114], [72.75875092, 19.50680351], [72.75875092, 19.5070858], [72.75818634, 19.50708008], [72.75819397, 19.50736046], [72.75680542, 19.50736046], [72.75680542, 19.5070858], [72.75653076, 19.50708008], [72.75653076, 19.50736046], [72.75569153, 19.50736046], [72.75569153, 19.50763893], [72.75541687, 19.50763893], [72.75541687, 19.50819588], [72.75514221, 19.50819588], [72.75514221, 19.50847244], [72.75458527, 19.50847244], [72.7545929, 19.50875092], [72.7529068, 19.50875092], [72.7529068, 19.50902939], [72.7526474, 19.50902939], [72.7526474, 19.50930977], [72.75235748, 19.50930786], [72.75235748, 19.50958252], [72.75208282, 19.50958061], [72.75208282, 19.50986099], [72.75180817, 19.50986099], [72.75180817, 19.51013947], [72.75125122, 19.51013947], [72.75125122, 19.51041985], [72.75041962, 19.51041985], [72.75041962, 19.51069832], [72.75013733, 19.5106945], [72.75013733, 19.51097298], [72.74986267, 19.51097107], [72.74986267, 19.51124954], [72.74903107, 19.51124954], [72.74903107, 19.51152992], [72.74819183, 19.51152992], [72.74819183, 19.5118084], [72.74764252, 19.51180649], [72.74764252, 19.51236153], [72.74736023, 19.51235962], [72.74736023, 19.51263809], [72.74680328, 19.51263809], [72.74680328, 19.51291847], [72.746521, 19.51291847], [72.746521, 19.51320267], [72.74597168, 19.51320267], [72.74597168, 19.51375961], [72.74569702, 19.51375961], [72.74569702, 19.51403046], [72.74485779, 19.51403046], [72.74485779, 19.51431274], [72.74458313, 19.51430511], [72.74458313, 19.51458359], [72.74402618, 19.51458359], [72.74402618, 19.51486015], [72.74347687, 19.51486015], [72.74347687, 19.51514053], [72.74291992, 19.51514053], [72.74291992, 19.51542282], [72.74236298, 19.5154171], [72.74236298, 19.51569366], [72.74180603, 19.51569366], [72.74180603, 19.51597023], [72.74153137, 19.51597023], [72.74153137, 19.5165329], [72.74124908, 19.51652718], [72.74124908, 19.51680565], [72.74097443, 19.51680565], [72.74097443, 19.51708221], [72.74069214, 19.51708031], [72.74066162, 19.51764107], [72.74041748, 19.51764107], [72.74041748, 19.51791954], [72.74013519, 19.51791763], [72.74013519, 19.51847458], [72.73986053, 19.51847076], [72.73986053, 19.51902962], [72.73929596, 19.51902962], [72.73929596, 19.51931], [72.73902893, 19.51931], [72.73902893, 19.51986122], [72.73874664, 19.51986122], [72.73874664, 19.52099037], [72.73874664, 19.52236176], [72.73847198, 19.52235985], [72.73847198, 19.52264023], [72.73819733, 19.52264023], [72.73819733, 19.52292824], [72.73735809, 19.5229187], [72.73735809, 19.52347183], [72.73707581, 19.52346992], [72.73707581, 19.52430916], [72.73680878, 19.52430916], [72.73680878, 19.52514076], [72.73652649, 19.52514076], [72.73652649, 19.52652931], [72.73486328, 19.52652931], [72.73486328, 19.5268116], [72.73313904, 19.52680588], [72.73291779, 19.5268116], [72.73291779, 19.52652931], [72.73153687, 19.52652931], [72.73153687, 19.5268116], [72.73124695, 19.5268116], [72.73124695, 19.52736092], [72.73097229, 19.52736092], [72.73097229, 19.52763939], [72.73014069, 19.52763939], [72.73014069, 19.52792168], [72.7298584, 19.52791595], [72.7298584, 19.5284729], [72.72958374, 19.5284729], [72.72958374, 19.52874947], [72.72902679, 19.52874947], [72.72902679, 19.52958107], [72.72875214, 19.52958107], [72.72875214, 19.53180313], [72.72846985, 19.53180313], [72.72846985, 19.53236389], [72.72820282, 19.53236008], [72.72820282, 19.53264046], [72.72763824, 19.53264046], [72.72763824, 19.53292084], [72.72736359, 19.53291512], [72.72736359, 19.53347206], [72.7270813, 19.53347015], [72.7270813, 19.53375053], [72.72680664, 19.53375053], [72.72680664, 19.53403091], [72.72651672, 19.53403091], [72.72651672, 19.53375053], [72.72624969, 19.53375053], [72.72624969, 19.53264046], [72.72598267, 19.53264046], [72.72598267, 19.5320797], [72.72569275, 19.53208542], [72.72569275, 19.53180313], [72.72458649, 19.53180313], [72.72458649, 19.53236389], [72.72486115, 19.53236008], [72.72486115, 19.53292084], [72.7251358, 19.53291512], [72.7251358, 19.53347206], [72.72569275, 19.53347015], [72.72569275, 19.53375053], [72.72598267, 19.53375053], [72.72598267, 19.53487015], [72.72624969, 19.53487015], [72.72624969, 19.53514099], [72.72651672, 19.53514099], [72.72651672, 19.53680992], [72.72624969, 19.53680611], [72.72624969, 19.53708267], [72.72597504, 19.53708267], [72.72598267, 19.53736115], [72.72541809, 19.53736115], [72.72541809, 19.53792953], [72.7251358, 19.53791618], [72.7251358, 19.53819466], [72.72486115, 19.53819084], [72.72486115, 19.53874969], [72.72458649, 19.53874969], [72.72458649, 19.53902817], [72.72402954, 19.53902817], [72.72402954, 19.53930473], [72.72291565, 19.53930473], [72.72291565, 19.53902817], [72.72235107, 19.53902817], [72.72235107, 19.53874969], [72.72180176, 19.53874969], [72.72180176, 19.53847122], [72.72125244, 19.53847122], [72.72125244, 19.53874969], [72.72070313, 19.53874969], [72.72070313, 19.53902817], [72.72013855, 19.53902817], [72.72013855, 19.53874969], [72.71985626, 19.53874969], [72.71985626, 19.53847122], [72.71901703, 19.53847122], [72.71901703, 19.53874969], [72.71819305, 19.53874969], [72.71819305, 19.54042244], [72.71848297, 19.54042244], [72.71848297, 19.54070282], [72.71875, 19.54069519], [72.71875, 19.54097176], [72.71901703, 19.54097176], [72.71901703, 19.54236031], [72.72013855, 19.54236031], [72.72013855, 19.54264069], [72.7206955, 19.54263878], [72.7206955, 19.54347229], [72.72041321, 19.54347229], [72.72041321, 19.54375076], [72.71930695, 19.54374123], [72.71930695, 19.54403114], [72.71708679, 19.54402733], [72.71708679, 19.54458237], [72.71679688, 19.54458046], [72.71679688, 19.54541969], [72.71848297, 19.54541969], [72.71848297, 19.54514122], [72.71875, 19.54514122], [72.71875, 19.54486084], [72.71930695, 19.54486084], [72.71930695, 19.54458046], [72.7195816, 19.54458237], [72.7195816, 19.5443058], [72.72013855, 19.54430962], [72.72013855, 19.54403114], [72.72125244, 19.54403114], [72.72125244, 19.54374123], [72.72180176, 19.54375076], [72.72180176, 19.54347229], [72.7223587, 19.54347229], [72.7223587, 19.54375076], [72.72264099, 19.54374123], [72.72264099, 19.54403114], [72.72292328, 19.54403114], [72.72292328, 19.54514122], [72.72180939, 19.54514122], [72.72180176, 19.54541969], [72.72125244, 19.54541588], [72.72125244, 19.54569244], [72.7206955, 19.54569244], [72.7206955, 19.54597473], [72.72041321, 19.54597092], [72.72041321, 19.54624939], [72.72013855, 19.54624939], [72.72013855, 19.54708481], [72.72041321, 19.54708099], [72.72041321, 19.54763985], [72.7215271, 19.54763985], [72.7215271, 19.54792023], [72.72180176, 19.54791451], [72.72180939, 19.54819679], [72.72208405, 19.54819679], [72.72208405, 19.55208397], [72.72180939, 19.55207825], [72.72180176, 19.55236053], [72.7215271, 19.55236053], [72.7215271, 19.55319405], [72.72180176, 19.55319405], [72.72180176, 19.55347252], [72.7215271, 19.55347061], [72.7215271, 19.55374908], [72.72180176, 19.55374908], [72.72180176, 19.55486107], [72.7215271, 19.55486107], [72.7215271, 19.55569458], [72.72125244, 19.55567932], [72.72125244, 19.55624962], [72.72097015, 19.55624962], [72.72097015, 19.55653191], [72.7206955, 19.55652809], [72.7206955, 19.5573616], [72.72041321, 19.5573597], [72.72041321, 19.55792046], [72.72013855, 19.55792046], [72.72013855, 19.55931091], [72.71985626, 19.55931091], [72.71985626, 19.55986023], [72.7195816, 19.55986023], [72.7195816, 19.56069374], [72.71985626, 19.56068993], [72.71985626, 19.56236076], [72.72013855, 19.56236076], [72.72013855, 19.56375122], [72.72041321, 19.56374931], [72.72041321, 19.5648613], [72.72070313, 19.56484985], [72.72070313, 19.56541824], [72.72097015, 19.56541824], [72.72097015, 19.56653023], [72.72013855, 19.56652832], [72.72013855, 19.56680489], [72.71985626, 19.56679916], [72.71985626, 19.5676403], [72.7195816, 19.5676384], [72.7195816, 19.56791687], [72.71902466, 19.56791687], [72.71902466, 19.56847191], [72.71875, 19.56847191], [72.71875, 19.56903267], [72.71848297, 19.56903267], [72.71848297, 19.56931114], [72.71819305, 19.56931114], [72.71819305, 19.56986046], [72.7179184, 19.56986046], [72.7179184, 19.57014275], [72.71763611, 19.57014275], [72.71763611, 19.57042122], [72.71736145, 19.5704174], [72.71736145, 19.57097244], [72.71708679, 19.57097054], [72.71708679, 19.57152939], [72.7168045, 19.57152748], [72.7168045, 19.57208252], [72.71652985, 19.57208252], [72.71653748, 19.57263947], [72.71624756, 19.57263947], [72.71624756, 19.57514], [72.7159729, 19.57514], [72.7159729, 19.57542038], [72.71624756, 19.57542038], [72.71624756, 19.57625008], [72.71652985, 19.57625008], [72.71652985, 19.57708359], [72.71679688, 19.57707977], [72.71679688, 19.57792091], [72.71708679, 19.57792091], [72.71708679, 19.57930946], [72.71736145, 19.57930565], [72.71736145, 19.57986069], [72.71763611, 19.57985115], [72.71763611, 19.5818119], [72.7179184, 19.5818119], [72.7179184, 19.58263969], [72.71763611, 19.58263969], [72.71763611, 19.58403015], [72.71736145, 19.58402824], [72.71736145, 19.58430481], [72.71708679, 19.58430481], [72.71708679, 19.58486176], [72.71679688, 19.58485985], [72.71679688, 19.58681107], [72.71652985, 19.58680344], [72.71652985, 19.5881958], [72.71569824, 19.58819008], [72.71569824, 19.59013939], [72.71541595, 19.59013939], [72.71541595, 19.59041977], [72.71485901, 19.59041786], [72.71485901, 19.59069443], [72.71430206, 19.59069443], [72.71430206, 19.5909729], [72.7140274, 19.59097099], [72.7140274, 19.59124947], [72.71347046, 19.59124947], [72.71347046, 19.59263992], [72.7131958, 19.59263992], [72.7131958, 19.5929184], [72.71290588, 19.5929184], [72.71290588, 19.59320259], [72.71263885, 19.59319496], [72.71263885, 19.59347153], [72.71235657, 19.59347153], [72.71235657, 19.59403038], [72.71263885, 19.59402847], [72.71263885, 19.59597015], [72.71347046, 19.59597015], [72.71347046, 19.59569359], [72.71458435, 19.59569359], [72.71458435, 19.59541702], [72.71541595, 19.59541702], [72.71541595, 19.59569359], [72.7159729, 19.59569359], [72.7159729, 19.59513855], [72.71848297, 19.59514046], [72.71848297, 19.59542274], [72.7195816, 19.59541702], [72.7195816, 19.59569359], [72.72013855, 19.59569359], [72.72013855, 19.59597015], [72.72041321, 19.59597015], [72.72041321, 19.59653282], [72.72097015, 19.59653282], [72.72097015, 19.59680939], [72.7215271, 19.59680557], [72.7215271, 19.59708214], [72.72235107, 19.59708023], [72.72235107, 19.59736061], [72.72319794, 19.59736061], [72.72319794, 19.59680939], [72.72374725, 19.59680939], [72.72374725, 19.59625053], [72.72402954, 19.59625053], [72.72402954, 19.59597015], [72.7243042, 19.59597015], [72.7243042, 19.59569359], [72.72458649, 19.59569359], [72.72458649, 19.59541702], [72.7251358, 19.59542274], [72.7251358, 19.59486008], [72.72569275, 19.59486008], [72.72569275, 19.59458351], [72.72763824, 19.59458351], [72.72763824, 19.59486008], [72.72847748, 19.59486008], [72.72847748, 19.59514046], [72.72875214, 19.59514046], [72.72875214, 19.59542274], [72.72902679, 19.59541702], [72.72902679, 19.59597015], [72.72930908, 19.59597015], [72.72930908, 19.59625053], [72.72958374, 19.59625053], [72.72958374, 19.59708214], [72.73014069, 19.59708023], [72.73014069, 19.59736061], [72.73041534, 19.59736061], [72.73041534, 19.5984726], [72.73097229, 19.59847069], [72.73097229, 19.59875107], [72.73285675, 19.59875107], [72.73291779, 19.59847069], [72.73347473, 19.5984726], [72.73347473, 19.59819221], [72.73374939, 19.59819221], [72.73374939, 19.59791756], [72.73401642, 19.59791946], [72.73401642, 19.5976429], [72.73430634, 19.5976429], [72.73430634, 19.59736061], [72.73735809, 19.59736061], [72.73735809, 19.5976429], [72.73792267, 19.5976429], [72.73792267, 19.59791946], [72.73680878, 19.59791756], [72.73680878, 19.5984726], [72.73652649, 19.59847069], [72.73652649, 19.59875107], [72.73568726, 19.59875107], [72.73568726, 19.59930992], [72.73542023, 19.59930992], [72.73542023, 19.59986115], [72.73458099, 19.59986115], [72.73458099, 19.60013962], [72.73430634, 19.60013962], [72.73430634, 19.60042], [72.73402405, 19.60041428], [72.73402405, 19.60069656], [72.73374939, 19.60069084], [72.73374939, 19.60098076], [72.7335968, 19.60097313], [72.73179626, 19.60098076], [72.73179626, 19.60042], [72.73097229, 19.60041428], [72.73097229, 19.60069656], [72.73069763, 19.60069084], [72.73069763, 19.60098076], [72.73041534, 19.60097313], [72.73042297, 19.60124969], [72.73014069, 19.60124969], [72.73014069, 19.60264015], [72.7298584, 19.60263634], [72.7298584, 19.60569382], [72.73014069, 19.60569382], [72.73014069, 19.60541725], [72.73041534, 19.60541725], [72.73041534, 19.60569382], [72.73069763, 19.60569382], [72.73069763, 19.60847282], [72.73042297, 19.60847282], [72.73042297, 19.61014938], [72.73014069, 19.61014938], [72.73014069, 19.61124992], [72.7298584, 19.61124992], [72.7298584, 19.61292076], [72.72957611, 19.61292076], [72.72957611, 19.61375046], [72.72930908, 19.61375046], [72.72930908, 19.61514091], [72.72902679, 19.6151371], [72.72902679, 19.61569595], [72.72875214, 19.61569023], [72.72875214, 19.61625099], [72.72846985, 19.61624718], [72.72846985, 19.6170826], [72.72819519, 19.6170826], [72.72820282, 19.61763954], [72.7279129, 19.61763954], [72.7279129, 19.61791992], [72.72736359, 19.61791611], [72.72736359, 19.62097168], [72.72763824, 19.62097168], [72.72763824, 19.62125015], [72.7279129, 19.62125015], [72.7279129, 19.62177086], [72.7279129, 19.62208939], [72.72819519, 19.62208366], [72.72819519, 19.62347221], [72.7279129, 19.62347031], [72.7279129, 19.62486076], [72.72735596, 19.62486076], [72.72735596, 19.62541962], [72.7270813, 19.6254158], [72.7270813, 19.62569237], [72.72680664, 19.62569237], [72.72680664, 19.62597466], [72.72651672, 19.62597084], [72.72651672, 19.62681007], [72.72624969, 19.62680435], [72.72624969, 19.6273613], [72.72597504, 19.6273613], [72.72597504, 19.62847137], [72.72569275, 19.62846947], [72.72569275, 19.62874985], [72.7251358, 19.62874985], [72.7251358, 19.62846947], [72.72486115, 19.62847137], [72.72486115, 19.62763977], [72.7251358, 19.62763977], [72.7251358, 19.62708092], [72.72541809, 19.62708282], [72.72541809, 19.62652779], [72.72569275, 19.62652969], [72.72569275, 19.62597084], [72.72486115, 19.62597466], [72.72486115, 19.62569237], [72.72458649, 19.62569237], [72.72458649, 19.62597466], [72.7234726, 19.62597084], [72.7234726, 19.62625122], [72.72319794, 19.62625122], [72.72319794, 19.62652969], [72.72291565, 19.62652779], [72.72291565, 19.62708282], [72.72264099, 19.62708092], [72.72264099, 19.62763977], [72.72235107, 19.62763977], [72.72235107, 19.62792015], [72.72208405, 19.62791443], [72.72208405, 19.62819672], [72.72180939, 19.62819099], [72.72180176, 19.62874985], [72.7215271, 19.62874985], [72.7215271, 19.62930679], [72.72125244, 19.62930679], [72.72125244, 19.62958336], [72.72097015, 19.62958336], [72.72097015, 19.62986183], [72.72041321, 19.62985992], [72.72041321, 19.6301403], [72.72013855, 19.6301403], [72.72013855, 19.63042068], [72.71985626, 19.63042068], [72.71985626, 19.63125038], [72.7195816, 19.63125038], [72.7195816, 19.63180923], [72.71930695, 19.63180923], [72.71930695, 19.63236046], [72.71901703, 19.63236046], [72.71901703, 19.63264084], [72.71875, 19.63264084], [72.71875, 19.63347244], [72.71847534, 19.63347244], [72.71848297, 19.63375092], [72.71819305, 19.63375092], [72.71819305, 19.63458252], [72.7179184, 19.63458061], [72.7179184, 19.63542175], [72.71763611, 19.63541603], [72.71763611, 19.6356945], [72.71736145, 19.6356926], [72.71736145, 19.63624954], [72.71708679, 19.63624954], [72.71708679, 19.6368103], [72.71679688, 19.6368103], [72.71679688, 19.63709068], [72.71652985, 19.63708115], [72.71652985, 19.63736153], [72.71624756, 19.63735962], [72.71624756, 19.63764], [72.7159729, 19.63764], [72.7159729, 19.63820076], [72.71569824, 19.63819313], [72.71569824, 19.6384716], [72.71541595, 19.6384697], [72.71541595, 19.63903046], [72.7151413, 19.63903046], [72.7151413, 19.63931084], [72.71485901, 19.63930321], [72.71485901, 19.64013863], [72.71457672, 19.640131], [72.71457672, 19.64125061], [72.71430206, 19.64125061], [72.71430206, 19.64208412], [72.7140274, 19.64208412], [72.7140274, 19.6431942], [72.71375275, 19.64319038], [72.71375275, 19.64375114], [72.71347046, 19.64375114], [72.71347046, 19.64430809], [72.7131958, 19.64430618], [72.7131958, 19.64458275], [72.71290588, 19.64458084], [72.71290588, 19.64652824], [72.71263885, 19.64652824], [72.71263885, 19.64708328], [72.71235657, 19.64708138], [72.71235657, 19.64764023], [72.71208191, 19.64763832], [72.71208191, 19.64958382], [72.71180725, 19.64958191], [72.71180725, 19.65042114], [72.71153259, 19.65042114], [72.71153259, 19.65291977], [72.71125031, 19.65291405], [72.71125031, 19.65347481], [72.71097565, 19.65347481], [72.71097565, 19.65597153], [72.71069336, 19.65596962], [72.71069336, 19.65681076], [72.71098328, 19.65681076], [72.71098328, 19.65819931], [72.71069336, 19.65819359], [72.71069336, 19.65847206], [72.71097565, 19.65847206], [72.71097565, 19.65958405], [72.71125031, 19.65957832], [72.71125031, 19.66013908], [72.71097565, 19.66013908], [72.71097565, 19.66069412], [72.71069336, 19.6606884], [72.71069336, 19.66181183], [72.71097565, 19.66180611], [72.71097565, 19.66208267], [72.71125031, 19.66208267], [72.71125031, 19.66263962], [72.71098328, 19.66263962], [72.71098328, 19.66292191], [72.71069336, 19.66291618], [72.71069336, 19.66319466], [72.7104187, 19.66319466], [72.7104187, 19.66347122], [72.71069336, 19.66347122], [72.71069336, 19.66681099], [72.71097565, 19.66680336], [72.71098328, 19.66736031], [72.71069336, 19.66736031], [72.71069336, 19.66764069], [72.71013641, 19.66764069], [72.71013641, 19.66792107], [72.70986176, 19.66791534], [72.70986176, 19.66819382], [72.7095871, 19.66819], [72.7095871, 19.66903114], [72.70929718, 19.66903114], [72.70929718, 19.66986084], [72.70903015, 19.66986084], [72.70903015, 19.67041969], [72.70874786, 19.67045021], [72.70874786, 19.67152977], [72.70847321, 19.67152977], [72.70847321, 19.67180824], [72.70819092, 19.67180634], [72.70819092, 19.6720829], [72.7076416, 19.6720829], [72.7076416, 19.67236137], [72.70735168, 19.67235756], [72.70735168, 19.67375183], [72.70707703, 19.67375183], [72.70707703, 19.67902946], [72.70680237, 19.67902756], [72.70680237, 19.68097305], [72.70652771, 19.68097305], [72.70652771, 19.6823616], [72.70625305, 19.6823597], [72.70625305, 19.68292046], [72.70652771, 19.68291855], [72.70652771, 19.68458366], [72.70680237, 19.68457985], [72.70680237, 19.68625069], [72.70707703, 19.68625069], [72.70707703, 19.68680954], [72.70735931, 19.68680573], [72.70735931, 19.6870842], [72.70791626, 19.68707848], [72.70791626, 19.68736076], [72.70819092, 19.68736076], [72.70819092, 19.68819427], [72.70847321, 19.68818092], [72.70847321, 19.68902969], [72.70874786, 19.68902779], [72.70874786, 19.68958282], [72.70903015, 19.68958282], [72.70903015, 19.69013977], [72.70930481, 19.69013977], [72.70930481, 19.69069481], [72.7095871, 19.69069481], [72.7095871, 19.69124985], [72.70986176, 19.69124031], [72.70986176, 19.6926403], [72.71013641, 19.6926384], [72.71013641, 19.69430733], [72.7104187, 19.69430733], [72.7104187, 19.69847298], [72.71069336, 19.69847298], [72.71069336, 19.70208359], [72.71041107, 19.70208168], [72.71041107, 19.70375061], [72.71013641, 19.70375061], [72.71013641, 19.70514107], [72.70986176, 19.70514107], [72.70986176, 19.70681], [72.7095871, 19.70681], [72.7095871, 19.70763969], [72.70930481, 19.70763969], [72.70930481, 19.70819664], [72.70903015, 19.70819092], [72.70903015, 19.70874977], [72.70874786, 19.70874977], [72.70874786, 19.70931053], [72.70847321, 19.70930672], [72.70847321, 19.70986176], [72.70819092, 19.70985985], [72.70819092, 19.71042061], [72.70791626, 19.7104187], [72.70791626, 19.71097183], [72.7076416, 19.71096992], [72.7076416, 19.71153069], [72.70735931, 19.71152878], [72.70735931, 19.71208382], [72.70707703, 19.71207809], [72.70707703, 19.71237183], [72.70680237, 19.71237183], [72.70680237, 19.71291924], [72.70652771, 19.71291733], [72.70652771, 19.71319389], [72.70625305, 19.71319389], [72.70625305, 19.71347237], [72.70597076, 19.71347046], [72.70597076, 19.71402931], [72.70569611, 19.71402931], [72.70569611, 19.7143116], [72.70541382, 19.71430588], [72.70541382, 19.71458244], [72.70513916, 19.71457863], [72.70513916, 19.71513939], [72.7048645, 19.71513939], [72.7048645, 19.71541595], [72.70458221, 19.71541595], [72.70458221, 19.71569443], [72.70430756, 19.71569443], [72.70430756, 19.71624947], [72.7040329, 19.71624947], [72.7040329, 19.71652985], [72.70375061, 19.71652794], [72.70375061, 19.71708107], [72.70347595, 19.71708107], [72.70347595, 19.71736145], [72.70318604, 19.71735954], [72.70318604, 19.71763992], [72.70291901, 19.71763992], [72.70291901, 19.71820068], [72.70236206, 19.71819305], [72.70236206, 19.71847153], [72.70207977, 19.71846962], [72.70207977, 19.71875], [72.70181274, 19.71875], [72.70181274, 19.71903038], [72.70153046, 19.71903038], [72.70153046, 19.71931076], [72.70124817, 19.71930313], [72.70124817, 19.71958351], [72.70069122, 19.71958351], [72.70069122, 19.71986198], [72.70041656, 19.71986008], [72.70041656, 19.72042084], [72.70014191, 19.72041512], [72.70014191, 19.72097206], [72.69985962, 19.72097015], [72.69985962, 19.72125053], [72.69959259, 19.72125053], [72.69959259, 19.72180939], [72.69930267, 19.72180748], [72.69930267, 19.72208595], [72.69902802, 19.72208023], [72.69902802, 19.72236061], [72.69819641, 19.72236061], [72.69819641, 19.72291946], [72.69763947, 19.72291756], [72.69763947, 19.7234726], [72.69735718, 19.72347069], [72.69735718, 19.72375107], [72.69680786, 19.72375107], [72.69680786, 19.72402954], [72.6965332, 19.72402954], [72.6965332, 19.72430992], [72.69625092, 19.72430611], [72.69625092, 19.72458267], [72.69596863, 19.72458076], [72.69596863, 19.72513962], [72.69568634, 19.72513962], [72.69568634, 19.72541809], [72.69541931, 19.72541618], [72.69541931, 19.72597313], [72.69513702, 19.72597122], [72.69513702, 19.72624969], [72.69486237, 19.72624969], [72.69486237, 19.72652817], [72.69458008, 19.72652817], [72.69458008, 19.72680473], [72.69430542, 19.72680473], [72.69430542, 19.72708321], [72.69403076, 19.72708321], [72.69403076, 19.72736168], [72.69374847, 19.72734833], [72.69374847, 19.7293129], [72.69403076, 19.72930527], [72.69403076, 19.73041725], [72.69430542, 19.73041725], [72.69430542, 19.72986031], [72.69458008, 19.72986031], [72.69458008, 19.72958183], [72.69486237, 19.72958374], [72.69486237, 19.72930527], [72.69513702, 19.7293129], [72.69513702, 19.72875023], [72.69568634, 19.72875023], [72.69568634, 19.72847176], [72.69596863, 19.72847176], [72.69596863, 19.72791672], [72.69625092, 19.72792244], [72.69625092, 19.72764015], [72.6965332, 19.72764015], [72.6965332, 19.72734833], [72.69708252, 19.72736168], [72.69708252, 19.72708321], [72.69736481, 19.72708321], [72.69736481, 19.72652817], [72.69819641, 19.72652817], [72.69819641, 19.72680473], [72.69875336, 19.72680473], [72.69875336, 19.72624969], [72.70236206, 19.72624969], [72.70236206, 19.72652817], [72.70652771, 19.72652817], [72.70652771, 19.72624969], [72.70874786, 19.72624969], [72.70874786, 19.72792244], [72.70903015, 19.72792244], [72.70903015, 19.7293129], [72.70929718, 19.7293129], [72.70929718, 19.72986031], [72.7095871, 19.72986031], [72.7095871, 19.73041725], [72.70986176, 19.73041725], [72.70986176, 19.73069382], [72.7104187, 19.73069382], [72.7104187, 19.73097229], [72.71098328, 19.73097038], [72.71098328, 19.73153114], [72.71125031, 19.73152733], [72.71125031, 19.73208237], [72.71153259, 19.73208046], [72.71153259, 19.73264122], [72.71180725, 19.73264122], [72.71180725, 19.73374939], [72.71208191, 19.73374939], [72.71208191, 19.73764038], [72.71235657, 19.73764038], [72.71235657, 19.74181175], [72.71263885, 19.74181175], [72.71263885, 19.74292183], [72.71291351, 19.74291611], [72.71291351, 19.74430466], [72.7131958, 19.74430275], [72.7131958, 19.74625015], [72.71347046, 19.74625015], [72.71347046, 19.74792099], [72.71375275, 19.74792099], [72.71375275, 19.74875069], [72.7140274, 19.74875069], [72.7140274, 19.74930954], [72.71430206, 19.74930954], [72.71430206, 19.74986076], [72.71457672, 19.74986076], [72.71457672, 19.75041962], [72.71485901, 19.75041771], [72.71485901, 19.75097275], [72.71541595, 19.75097275], [72.71541595, 19.75152969], [72.7159729, 19.75152969], [72.7159729, 19.7523613], [72.71624756, 19.75235748], [72.71624756, 19.75263977], [72.71653748, 19.75263977], [72.71653748, 19.75291824], [72.7168045, 19.75291634], [72.7168045, 19.75347137], [72.71736145, 19.75346756], [72.71736145, 19.75375175], [72.7179184, 19.75375175], [72.7179184, 19.75403023], [72.71819305, 19.75402832], [72.71819305, 19.75430489], [72.71875, 19.75430489], [72.71875, 19.75458336], [72.71930695, 19.75458145], [72.71930695, 19.7551403], [72.71848297, 19.7551403], [72.71848297, 19.75542259], [72.71736145, 19.75542259], [72.71736145, 19.7551403], [72.71679688, 19.7551403], [72.71679688, 19.75486183], [72.71653748, 19.75486183], [72.71653748, 19.7551403], [72.7159729, 19.7551403], [72.7159729, 19.75486183], [72.71541595, 19.75486183], [72.71541595, 19.75458336], [72.7151413, 19.75458336], [72.7151413, 19.75402832], [72.71485901, 19.75403023], [72.71485901, 19.75346756], [72.71458435, 19.75347137], [72.71458435, 19.75291634], [72.71430206, 19.75291824], [72.71430206, 19.75263977], [72.7140274, 19.75263977], [72.7140274, 19.75208092], [72.71375275, 19.75208282], [72.71375275, 19.75124741], [72.71347046, 19.75125122], [72.71347046, 19.75069046], [72.7131958, 19.75069427], [72.7131958, 19.75041771], [72.71290588, 19.75041962], [72.71290588, 19.74986076], [72.71263885, 19.74986076], [72.71263885, 19.74903107], [72.71235657, 19.74903107], [72.71235657, 19.74818993], [72.71208191, 19.74819374], [72.71208191, 19.74791527], [72.71180725, 19.74792099], [72.71180725, 19.74764061], [72.71153259, 19.74764061], [72.71153259, 19.74681091], [72.71125031, 19.74681091], [72.71125031, 19.74625015], [72.71097565, 19.74625015], [72.71097565, 19.74402809], [72.71069336, 19.74403], [72.71069336, 19.74235153], [72.7104187, 19.74236107], [72.7104187, 19.74152756], [72.71013641, 19.74152946], [72.71013641, 19.74041939], [72.70986176, 19.74041939], [72.70986176, 19.73986053], [72.7095871, 19.73986053], [72.7095871, 19.73903084], [72.70929718, 19.73903084], [72.70929718, 19.73846817], [72.70903015, 19.73847198], [72.70903015, 19.73763657], [72.70874786, 19.73764038], [72.70874786, 19.73624992], [72.70847321, 19.73624992], [72.70847321, 19.73569107], [72.70819092, 19.73569679], [72.70819092, 19.73513985], [72.70791626, 19.73513985], [72.70791626, 19.73485947], [72.7076416, 19.73486137], [72.7076416, 19.73374939], [72.70735168, 19.73374939], [72.70735168, 19.73319054], [72.70708466, 19.73319435], [72.70708466, 19.73291588], [72.70680237, 19.73291969], [72.70680237, 19.73236084], [72.70458221, 19.73236084], [72.70458221, 19.73208046], [72.70069122, 19.73208046], [72.70069122, 19.73236084], [72.69985962, 19.73236084], [72.69985962, 19.73264122], [72.69902802, 19.73264122], [72.69902802, 19.73291969], [72.69847107, 19.73291588], [72.69847107, 19.73319435], [72.69708252, 19.73319054], [72.69708252, 19.73348045], [72.69680786, 19.73348045], [72.69680786, 19.73374939], [72.69625092, 19.73374939], [72.69625092, 19.73431015], [72.69596863, 19.73431015], [72.69596863, 19.73542023], [72.69569397, 19.73541451], [72.69569397, 19.73569679], [72.69346619, 19.73569107], [72.69346619, 19.73624992], [72.69319153, 19.73624992], [72.69319153, 19.73653984], [72.69291687, 19.7365284], [72.69291687, 19.7381897], [72.69236755, 19.73819923], [72.69236755, 19.73930931], [72.69208527, 19.7393055], [72.69208527, 19.73958397], [72.69152832, 19.73957825], [72.69152832, 19.73986053], [72.69125366, 19.73986053], [72.69125366, 19.74097252], [72.69097137, 19.74097061], [72.69097137, 19.74152946], [72.69069672, 19.74152756], [72.69069672, 19.74236107], [72.69041443, 19.74236107], [72.69041443, 19.74319458], [72.6901474, 19.74319267], [72.69013977, 19.74374962], [72.68985748, 19.74374962], [72.68985748, 19.7448616], [72.68958282, 19.7448616], [72.68958282, 19.74542046], [72.68958282, 19.74570084], [72.68930817, 19.74569321], [72.68930817, 19.74597168], [72.68902588, 19.74596977], [72.68902588, 19.74653053], [72.68875122, 19.74653053], [72.68875122, 19.74681091], [72.68846893, 19.74680328], [72.68846893, 19.74708366], [72.68818665, 19.74707985], [72.68818665, 19.74736023], [72.68763733, 19.74736023], [72.68763733, 19.74764061], [72.68736267, 19.74764061], [72.68736267, 19.74930954], [72.68708038, 19.74930954], [72.68708038, 19.75014114], [72.68680573, 19.75013924], [72.68680573, 19.75069427], [72.68653107, 19.75069046], [72.68653107, 19.75180817], [72.68624878, 19.75180626], [72.68624878, 19.7523613], [72.68596649, 19.75235748], [72.68596649, 19.75291824], [72.68624878, 19.75291634], [72.68624878, 19.75458336], [72.68596649, 19.75458145], [72.68596649, 19.75625038], [72.68569183, 19.75625038], [72.68569183, 19.75708389], [72.68541718, 19.75708008], [72.68541718, 19.76013947], [72.68569183, 19.76013947], [72.68569183, 19.76152992], [72.68597412, 19.76152611], [72.68597412, 19.76236153], [72.68624878, 19.76236153], [72.68624878, 19.76263618], [72.68641663, 19.76264], [72.68653107, 19.76264], [72.68653107, 19.76375008], [72.68681335, 19.76375008], [72.68681335, 19.76403046], [72.68708038, 19.76403046], [72.68708038, 19.76431084], [72.68736267, 19.76431084], [72.68736267, 19.76485825], [72.68763733, 19.76485825], [72.68763733, 19.76680946], [72.68791962, 19.76680946], [72.68791962, 19.76875114], [72.68819427, 19.76874924], [72.68819427, 19.77069473], [72.68846893, 19.77069283], [72.68846893, 19.77320099], [72.68818665, 19.77320099], [72.68818665, 19.77431107], [72.68791962, 19.77431107], [72.68791962, 19.77625084], [72.68763733, 19.77625084], [72.68763733, 19.77930832], [72.68736267, 19.77930641], [72.68736267, 19.77986145], [72.68708038, 19.77985764], [72.68708038, 19.78070259], [72.68736267, 19.78070259], [72.68736267, 19.78514099], [72.68763733, 19.78514099], [72.68763733, 19.78680992], [72.68791962, 19.78680992], [72.68791962, 19.78874969], [72.68819427, 19.78874969], [72.68819427, 19.78958321], [72.68846893, 19.78957939], [72.68846893, 19.79014015], [72.68875122, 19.79013634], [72.68875122, 19.79069519], [72.68902588, 19.79068947], [72.68902588, 19.79125023], [72.68930817, 19.79125023], [72.68930817, 19.79180908], [72.68958282, 19.79180527], [72.68958282, 19.79208374], [72.68985748, 19.79207993], [72.68985748, 19.79236031], [72.69013977, 19.79236031], [72.69013977, 19.79291916], [72.69041443, 19.79291725], [72.69041443, 19.79347229], [72.69069672, 19.79346848], [72.69069672, 19.79402924], [72.69097137, 19.79402924], [72.69097137, 19.79430962], [72.69124603, 19.79430962], [72.69124603, 19.79514122], [72.69097137, 19.79513931], [72.69097137, 19.79569435], [72.69069672, 19.79569244], [72.69069672, 19.79763985], [72.6904068, 19.79763985], [72.6904068, 19.79792023], [72.69013977, 19.79791641], [72.69013977, 19.79847145], [72.68985748, 19.79846954], [72.68985748, 19.79931068], [72.68958282, 19.79930305], [72.68958282, 19.8006897], [72.68930817, 19.80070114], [72.68930817, 19.80153084], [72.68958282, 19.80153084], [72.68958282, 19.80291939], [72.68985748, 19.80291557], [72.68985748, 19.80319595], [72.69013977, 19.80319023], [72.69013977, 19.80375099], [72.6904068, 19.80375099], [72.6904068, 19.80430984], [72.69169617, 19.80430794], [72.69208527, 19.80430794], [72.69208527, 19.8045826], [72.69319153, 19.8045826], [72.69319153, 19.80430794], [72.69374847, 19.80430984], [72.69374847, 19.80376053], [72.69386292, 19.80375671], [72.69403076, 19.80375099], [72.69403076, 19.80291939], [72.69513702, 19.80291557], [72.69513702, 19.80319595], [72.69569397, 19.80319595], [72.69568634, 19.80422974], [72.69568634, 19.80486107], [72.69513702, 19.80486107], [72.69513702, 19.80513954], [72.69403076, 19.80513954], [72.69403076, 19.80541992], [72.69347382, 19.80541611], [72.69347382, 19.80569458], [72.69097137, 19.80569458], [72.69097137, 19.80597305], [72.68943787, 19.80597305], [72.68902588, 19.80597305], [72.68902588, 19.80569458], [72.68846893, 19.80569458], [72.68846893, 19.80486107], [72.68818665, 19.80486107], [72.68818665, 19.80430984], [72.68791962, 19.80430984], [72.68791962, 19.80402946], [72.68763733, 19.80402946], [72.68763733, 19.80375099], [72.68736267, 19.80375099], [72.68736267, 19.80208015], [72.68763733, 19.80208588], [72.68763733, 19.80041695], [72.68791962, 19.80042076], [72.68791962, 19.79846954], [72.68819427, 19.79847145], [72.68819427, 19.79513931], [72.68846893, 19.79514122], [72.68846893, 19.79486084], [72.68818665, 19.79486084], [72.68818665, 19.79430962], [72.68708038, 19.79430962], [72.68708038, 19.79514122], [72.68680573, 19.79513931], [72.68680573, 19.79569435], [72.68653107, 19.79569435], [72.68653107, 19.79597282], [72.68624115, 19.79597282], [72.68624115, 19.79652977], [72.68596649, 19.79652977], [72.68596649, 19.79681969], [72.68624878, 19.79680634], [72.68624878, 19.7970829], [72.68597412, 19.7970829], [72.68597412, 19.79736137], [72.68569183, 19.79735947], [72.68569183, 19.7990303], [72.68541718, 19.7990303], [72.68541718, 19.79959106], [72.68514252, 19.79959106], [72.68514252, 19.80181122], [72.68486023, 19.80181122], [72.68486023, 19.80236053], [72.68458557, 19.80236053], [72.68458557, 19.8026371], [72.68430328, 19.8026371], [72.68430328, 19.80319595], [72.68402863, 19.80319023], [72.68402863, 19.80375099], [72.68374634, 19.80375099], [72.68374634, 19.80541992], [72.68347168, 19.80541611], [72.68347168, 19.80569458], [72.68319702, 19.80569458], [72.68319702, 19.80597305], [72.6829071, 19.80597115], [72.6829071, 19.80624962], [72.68264008, 19.80624962], [72.68264008, 19.80652809], [72.68235779, 19.80652809], [72.68235779, 19.80680466], [72.68208313, 19.80680466], [72.68208313, 19.80708313], [72.68180847, 19.80707932], [72.68180847, 19.80764008], [72.68152618, 19.80764008], [72.68152618, 19.80792046], [72.68125153, 19.80791664], [72.68125153, 19.80847168], [72.68152618, 19.80847168], [72.68152618, 19.80875969], [72.68125153, 19.80875969], [72.68125153, 19.80931282], [72.68096924, 19.80931282], [72.68096924, 19.81014061], [72.68069458, 19.8101387], [72.68069458, 19.81069374], [72.68042755, 19.81069183], [72.68042755, 19.81182098], [72.68013763, 19.81182098], [72.68013763, 19.81236076], [72.67986298, 19.81236076], [72.67986298, 19.81291962], [72.67958069, 19.8129158], [72.67958069, 19.81347275], [72.67903137, 19.81347084], [72.67903137, 19.81375122], [72.67874908, 19.81375122], [72.67874908, 19.81402969], [72.67791748, 19.81402779], [72.67791748, 19.81458282], [72.67763519, 19.81458282], [72.67763519, 19.8148613], [72.67708588, 19.81485939], [72.67708588, 19.81513977], [72.67680359, 19.81513977], [72.67680359, 19.81569672], [72.67652893, 19.81569672], [72.67652893, 19.81680679], [72.67624664, 19.81680679], [72.67624664, 19.81708336], [72.6756897, 19.81708336], [72.67541504, 19.81708336], [72.67541504, 19.81736183], [72.67514038, 19.81735992], [72.67514038, 19.81792068], [72.67485809, 19.81792068], [72.67485809, 19.81819916], [72.67402649, 19.81819534], [72.67402649, 19.81847191], [72.67292023, 19.81847191], [72.67292023, 19.81819534], [72.67263794, 19.81819916], [72.67263794, 19.81792068], [72.67069244, 19.81792068], [72.67069244, 19.81819916], [72.6701355, 19.81819534], [72.67014313, 19.81875038], [72.66902924, 19.81875038], [72.66902924, 19.81903076], [72.66874695, 19.81903076], [72.66874695, 19.81930923], [72.66847229, 19.81930542], [72.66847229, 19.81958389], [72.66819763, 19.81957817], [72.66819763, 19.81986046], [72.66764069, 19.81986046], [72.66764069, 19.82014084], [72.6673584, 19.82014084], [72.6673584, 19.82041931], [72.66707611, 19.82041931], [72.66707611, 19.8207016], [72.66652679, 19.82069397], [72.66652679, 19.82097244], [72.66625214, 19.82097054], [72.66625214, 19.82125092], [72.66570282, 19.82125092], [72.66570282, 19.82152939], [72.6654129, 19.82152939], [72.6654129, 19.82181168], [72.66430664, 19.82181168], [72.66430664, 19.82041931], [72.66401672, 19.82041931], [72.66374969, 19.82041931], [72.66374969, 19.81986046], [72.66347504, 19.81986046], [72.66347504, 19.81958389], [72.66179657, 19.81957817], [72.66179657, 19.81986046], [72.66208649, 19.81986046], [72.66208649, 19.82041931], [72.66152954, 19.82041931], [72.66152954, 19.8207016], [72.66124725, 19.82069397], [72.66124725, 19.82097244], [72.6598587, 19.82097244], [72.6598587, 19.82069397], [72.65958405, 19.82069397], [72.65958405, 19.82097244], [72.65930176, 19.82097054], [72.65930176, 19.82181168], [72.6590271, 19.82181168], [72.6590271, 19.8223629], [72.66014099, 19.8223629], [72.66014099, 19.82376099], [72.65957642, 19.82376099], [72.65957642, 19.82402992], [72.6590271, 19.82402802], [72.6590271, 19.82458115], [72.65763855, 19.82458115], [72.65763855, 19.82486153], [72.65735626, 19.82485962], [72.65735626, 19.82514], [72.65680695, 19.82514], [72.65680695, 19.82542038], [72.65651703, 19.82542038], [72.65651703, 19.82570076], [72.65625, 19.82569313], [72.65625, 19.82625008], [72.65598297, 19.82625008], [72.65598297, 19.82653046], [72.6554184, 19.82652855], [72.6554184, 19.82680321], [72.65513611, 19.82679939], [72.65513611, 19.82736015], [72.6554184, 19.82736015], [72.6554184, 19.82930946], [72.65513611, 19.82930756], [72.65513611, 19.82958412], [72.6534729, 19.82958412], [72.6534729, 19.83097267], [72.65319824, 19.83097076], [72.65319824, 19.83152962], [72.65291595, 19.83152962], [72.65291595, 19.83263969], [72.6526413, 19.83263969], [72.6526413, 19.83458328], [72.65235901, 19.83458138], [72.65235901, 19.83514023], [72.6526413, 19.83513832], [72.6526413, 19.83597183], [72.65235901, 19.83597183], [72.65235901, 19.83681107], [72.65208435, 19.83680534], [72.65208435, 19.83708382], [72.6515274, 19.83708191], [72.6515274, 19.83792114], [72.65125275, 19.83791733], [72.65125275, 19.83875084], [72.65097046, 19.83875084], [72.65097046, 19.83958244], [72.6506958, 19.83958054], [72.6506958, 19.83986092], [72.65125275, 19.83986092], [72.65125275, 19.84013939], [72.6515274, 19.84013939], [72.6515274, 19.84041977], [72.65180206, 19.84041405], [72.65180206, 19.84069443], [72.65207672, 19.84069061], [72.65207672, 19.84152985], [72.65180206, 19.84152794], [72.65180206, 19.8418045], [72.6515274, 19.8418045], [72.6515274, 19.84236145], [72.65208435, 19.84236145], [72.65208435, 19.84208298], [72.65319824, 19.84208298], [72.65319824, 19.84236145], [72.65458679, 19.84235954], [72.65458679, 19.84263992], [72.65486145, 19.84263992], [72.65486145, 19.84403038], [72.65458679, 19.84403038], [72.65458679, 19.84653091], [72.65429688, 19.84653091], [72.65429688, 19.84680939], [72.65402985, 19.84680939], [72.65402985, 19.84736061], [72.65374756, 19.84736061], [72.65374756, 19.84763908], [72.6534729, 19.84763908], [72.6534729, 19.85124969], [72.65319824, 19.85124969], [72.65319824, 19.85153008], [72.65291595, 19.85152817], [72.65291595, 19.85180473], [72.6526413, 19.85180473], [72.6526413, 19.85208321], [72.65235901, 19.85208321], [72.65235901, 19.85236168], [72.65207672, 19.85235977], [72.65207672, 19.85264015], [72.6515274, 19.85264015], [72.6515274, 19.85292053], [72.65125275, 19.85292053], [72.65125275, 19.85320091], [72.6506958, 19.85320091], [72.6506958, 19.85431099], [72.65097046, 19.85431099], [72.65097046, 19.85542107], [72.65125275, 19.85542107], [72.65125275, 19.85791969], [72.6515274, 19.85791779], [72.6515274, 19.85819435], [72.65180206, 19.85819435], [72.65180206, 19.85847282], [72.65319824, 19.85847092], [72.65319824, 19.85874748], [72.6534729, 19.85874748], [72.6534729, 19.85847092], [72.65374756, 19.85847092], [72.65374756, 19.85902977], [72.65458679, 19.85902977], [72.65458679, 19.85819054], [72.65486145, 19.85819435], [72.65486145, 19.85791779], [72.6554184, 19.85791969], [72.6554184, 19.85764122], [72.65598297, 19.85764122], [72.65598297, 19.85708046], [72.65652466, 19.85708237], [72.65652466, 19.85680771], [72.65664673, 19.85680771], [72.65680695, 19.85680962], [72.65680695, 19.85653114], [72.6570816, 19.85653114], [72.6570816, 19.85625076], [72.65735626, 19.85625076], [72.65735626, 19.85597038], [72.65791321, 19.85597229], [72.65791321, 19.85569382], [72.65875244, 19.85569382], [72.65875244, 19.85513878], [72.6590271, 19.85514069], [72.6590271, 19.85403061], [72.65930176, 19.85403061], [72.65930176, 19.85374069], [72.65958405, 19.85375023], [72.65958405, 19.85347176], [72.66041565, 19.85347176], [72.66041565, 19.85319328], [72.66069794, 19.85320091], [72.66069794, 19.85292053], [72.6609726, 19.85292053], [72.6609726, 19.85264015], [72.66152954, 19.85264015], [72.66152954, 19.85235977], [72.66208649, 19.85236168], [72.66208649, 19.85208321], [72.6626358, 19.85208321], [72.6626358, 19.85180473], [72.66291809, 19.85180473], [72.66291809, 19.85097122], [72.66402435, 19.85097122], [72.66402435, 19.85180473], [72.66625214, 19.85180473], [72.66625214, 19.85208321], [72.66652679, 19.85208321], [72.66652679, 19.85236168], [72.66680908, 19.85235977], [72.66680908, 19.85264015], [72.66707611, 19.85264015], [72.66707611, 19.85292053], [72.6673584, 19.85292053], [72.6673584, 19.85320091], [72.66874695, 19.85320091], [72.66874695, 19.85292053], [72.66902924, 19.85292053], [72.66902924, 19.85235977], [72.66930389, 19.85236168], [72.66930389, 19.85180473], [72.6701355, 19.85180473], [72.6701355, 19.85208321], [72.67069244, 19.85208321], [72.67069244, 19.85236168], [72.67180634, 19.85235977], [72.67180634, 19.85264015], [72.67263794, 19.85264015], [72.67263794, 19.85292053], [72.67318726, 19.85292053], [72.67318726, 19.85320091], [72.67346954, 19.85319328], [72.67346954, 19.85347176], [72.67375183, 19.85346985], [72.67375183, 19.85403061], [72.67346954, 19.85403061], [72.67346954, 19.85514069], [72.67319489, 19.85513878], [72.67319489, 19.85597229], [72.67346954, 19.85597038], [72.67346954, 19.85653114], [72.67375183, 19.85653114], [72.67375183, 19.85680962], [72.67402649, 19.85680962], [72.67402649, 19.85736084], [72.67430115, 19.85736084], [72.67430115, 19.85791969], [72.67457581, 19.85791969], [72.67457581, 19.85874748], [72.67485809, 19.85874748], [72.67485809, 19.85930824], [72.67541504, 19.85930634], [72.67541504, 19.8595829], [72.67569733, 19.85957909], [72.67569733, 19.85987091], [72.67597198, 19.85987091], [72.67597198, 19.86013985], [72.67624664, 19.86013985], [72.67624664, 19.86042023], [72.67652893, 19.86041641], [72.67652893, 19.86097145], [72.67679596, 19.86097145], [72.67679596, 19.8615303], [72.67708588, 19.8615284], [72.67708588, 19.86208344], [72.6772995, 19.86208344], [72.67763519, 19.86208344], [72.67763519, 19.86236191], [72.67791748, 19.86236191], [72.67791748, 19.86291695], [72.67847443, 19.86291695], [72.67847443, 19.86319351], [72.67903137, 19.86319351], [72.67903137, 19.86347389], [72.67930603, 19.86347008], [72.67930603, 19.86375046], [72.67958069, 19.86375046], [72.67958069, 19.86403275], [72.68013763, 19.86403275], [72.68013763, 19.86431122], [72.68041992, 19.8643055], [72.68041992, 19.86458206], [72.68070221, 19.86457253], [72.68068695, 19.86486053], [72.68093872, 19.86486053], [72.68096924, 19.86514091], [72.68112183, 19.86513901], [72.68125153, 19.86513901], [72.68125153, 19.86533165], [72.68125153, 19.86541748], [72.68096924, 19.86541748], [72.68096924, 19.86569214], [72.68069458, 19.86569214], [72.68069458, 19.86597252], [72.68096924, 19.86597061], [72.68096924, 19.86625099], [72.68068695, 19.86625099], [72.68069458, 19.86736107], [72.68041992, 19.86736107], [72.68041992, 19.86847305], [72.68013763, 19.86847305], [72.68013763, 19.8698616], [72.68041992, 19.8698616], [72.68041992, 19.87235832], [72.68069458, 19.87235832], [72.68069458, 19.87486076], [72.68096924, 19.87486076], [72.68096924, 19.87597275], [72.68125153, 19.87597275], [72.68125153, 19.87652969], [72.68152618, 19.87652969], [72.68152618, 19.87763977], [72.68180847, 19.87763977], [72.68180847, 19.8801403], [72.68208313, 19.8801403], [72.68208313, 19.88070107], [72.68235779, 19.88070107], [72.68235779, 19.88292122], [72.68264008, 19.8829155], [72.68264008, 19.88736153], [72.68291473, 19.88736153], [72.68291473, 19.8884716], [72.68264008, 19.8884716], [72.68264008, 19.88903046], [72.68235779, 19.88902855], [72.68235779, 19.88958359], [72.68264008, 19.88958359], [72.68264008, 19.89073753], [72.68264008, 19.89125061], [72.68235779, 19.89125061], [72.68235016, 19.89141083], [72.68234253, 19.8915329], [72.68208313, 19.8915329], [72.68208313, 19.89180946], [72.68152618, 19.89180946], [72.68152618, 19.89236069], [72.68125153, 19.89236069], [72.68125153, 19.8931942], [72.68096924, 19.89319038], [72.68096924, 19.89486122], [72.68068695, 19.89486122], [72.68068695, 19.89542007], [72.68041992, 19.89541435], [72.68041992, 19.89641953], [72.68042755, 19.89764023], [72.68069458, 19.89763641], [72.68069458, 19.90069389], [72.68041992, 19.90069389], [72.68041992, 19.90097237], [72.67986298, 19.90096855], [72.67986298, 19.90125084], [72.67903137, 19.90125084], [72.67903137, 19.90152931], [72.67819214, 19.90152931], [72.67819214, 19.90180969], [72.67791748, 19.90180588], [72.67791748, 19.90208244], [72.67763519, 19.90208244], [72.67763519, 19.90263939], [72.67736816, 19.90263939], [72.67736816, 19.90291977], [72.67708588, 19.90291595], [72.67708588, 19.90319443], [72.67652893, 19.90319252], [72.67652893, 19.90402985], [72.67624664, 19.90402794], [72.67624664, 19.90458107], [72.67597198, 19.90458107], [72.67597198, 19.90486145], [72.67569733, 19.90486145], [72.67569733, 19.90736198], [72.67542267, 19.90736008], [72.67542267, 19.90792084], [72.67569733, 19.90791512], [72.67569733, 19.90847206], [72.67597198, 19.90847015], [72.67597198, 19.90903091], [72.67652893, 19.90902519], [72.67652893, 19.90958595], [72.676651, 19.90958214], [72.67679596, 19.90958023], [72.67679596, 19.91041946], [72.67708588, 19.91041946], [72.67708588, 19.91236115], [72.67736816, 19.91236115], [72.67736816, 19.91291809], [72.67763519, 19.91291618], [72.67763519, 19.91374969], [72.67791748, 19.91374969], [72.67791748, 19.91486168], [72.67763519, 19.91486168], [72.67763519, 19.91625023], [72.67736816, 19.91625023], [72.67736816, 19.91653061], [72.67708588, 19.91653061], [72.67708588, 19.91930962], [72.67680359, 19.9193058], [72.67680359, 19.91958237], [72.67652893, 19.91958046], [72.67652893, 19.91986084], [72.67624664, 19.91986084], [72.67624664, 19.92041969], [72.67597198, 19.92041588], [72.67597198, 19.92069435], [72.67541504, 19.92069435], [72.67541504, 19.92097282], [72.67514038, 19.92097092], [72.67514038, 19.92124939], [72.67485809, 19.92124939], [72.67485809, 19.92181015], [72.67458344, 19.92180443], [72.67458344, 19.92236137], [72.67430115, 19.92235947], [72.67430115, 19.92292023], [72.67402649, 19.92291832], [72.67402649, 19.92319679], [72.67375183, 19.92319679], [72.67375183, 19.92347145], [72.67346954, 19.92346954], [72.67346954, 19.92374992], [72.67292023, 19.92374992], [72.67292023, 19.9240303], [72.67263794, 19.92402649], [72.67263794, 19.92486191], [72.67236328, 19.92485809], [72.67236328, 19.92514038], [72.67208099, 19.92514038], [72.67208099, 19.92542076], [72.67180634, 19.92541885], [72.67180634, 19.92597198], [72.67151642, 19.92596054], [72.67151642, 19.92653084], [72.67124176, 19.92653084], [72.67124176, 19.92680931], [72.67097473, 19.9268055], [72.67097473, 19.92708397], [72.67069244, 19.92707825], [72.67069244, 19.92764091], [72.66764069, 19.92764091], [72.66764069, 19.92791939], [72.6673584, 19.92791748], [72.6673584, 19.92819405], [72.66707611, 19.92819405], [72.66680908, 19.92819405], [72.66680908, 19.92847252], [72.66625214, 19.92847061], [72.66625214, 19.9287529], [72.66569519, 19.92874908], [72.66569519, 19.92902756], [72.6654129, 19.92902184], [72.6654129, 19.92931175], [72.66513824, 19.92930603], [72.66513824, 19.9295826], [72.66485596, 19.9295826], [72.66485596, 19.92986107], [72.6645813, 19.92986107], [72.6645813, 19.93013954], [72.66430664, 19.93013954], [72.66430664, 19.93292046], [72.6645813, 19.93291664], [72.6645813, 19.93347168], [72.66485596, 19.93346977], [72.66485596, 19.93403053], [72.66513824, 19.93402863], [72.66513824, 19.93458366], [72.6654129, 19.93457985], [72.6654129, 19.93486023], [72.66680908, 19.93486023], [72.66680908, 19.93457985], [72.66707611, 19.93457985], [72.66707611, 19.93486023], [72.6673584, 19.93486023], [72.6673584, 19.93515015], [72.66764069, 19.93515015], [72.66764069, 19.93542099], [72.66847229, 19.93541527], [72.66847229, 19.93569374], [72.66874695, 19.93569374], [72.66874695, 19.93597221], [72.66902924, 19.93597031], [72.66902924, 19.93625069], [72.66986084, 19.93625069], [72.66986084, 19.93653107], [72.67014313, 19.93653107], [72.67014313, 19.93680954], [72.67041779, 19.93680763], [72.67041779, 19.9370842], [72.67069244, 19.93708038], [72.67069244, 19.93764114], [72.6709671, 19.93764114], [72.6709671, 19.93791962], [72.67124939, 19.93791771], [72.67124939, 19.93819427], [72.67152405, 19.93819427], [72.67152405, 19.93847275], [72.67236328, 19.93847084], [72.67236328, 19.93875122], [72.67263794, 19.93875122], [72.67263794, 19.93902969], [72.67318726, 19.93902969], [72.67318726, 19.93930817], [72.67430878, 19.93930626], [72.67430878, 19.93958282], [72.67541504, 19.93958282], [72.67541504, 19.9398613], [72.67597198, 19.93985748], [72.67597198, 19.94013977], [72.67624664, 19.94013977], [72.67624664, 19.94041824], [72.67652893, 19.94041634], [72.67652893, 19.94069481], [72.67791748, 19.94069481], [72.67791748, 19.94097137], [72.67819214, 19.94095993], [72.67819214, 19.94125175], [72.67903137, 19.94125175], [72.67903137, 19.94153023], [72.67930603, 19.94152832], [72.67930603, 19.94180489], [72.67958069, 19.94180489], [72.67958069, 19.94208336], [72.67986298, 19.94208336], [72.67986298, 19.94236183], [72.68013763, 19.94236183], [72.68013763, 19.94292259], [72.68042755, 19.94292259], [72.68042755, 19.94320107], [72.68096924, 19.94319534], [72.68096924, 19.94347191], [72.68152618, 19.94347191], [72.68152618, 19.94375038], [72.68180847, 19.94375038], [72.68180847, 19.94403076], [72.68235779, 19.94403076], [72.68235779, 19.94432068], [72.68264008, 19.94430542], [72.68264008, 19.94458389], [72.6829071, 19.94458008], [72.6829071, 19.94486046], [72.68319702, 19.94486046], [72.68319702, 19.94514084], [72.68347168, 19.94514084], [72.68347168, 19.94542122], [72.68374634, 19.94542122], [72.68374634, 19.94625092], [72.68402863, 19.94625092], [72.68402863, 19.94709015], [72.68430328, 19.94709015], [72.68430328, 19.94763947], [72.68458557, 19.94763947], [72.68458557, 19.9481945], [72.68486023, 19.94819069], [72.68486023, 19.94874954], [72.68514252, 19.94874954], [72.68514252, 19.94902992], [72.68541718, 19.94902611], [72.68541718, 19.94958305], [72.68569183, 19.94958305], [72.68569183, 19.95013618], [72.68597412, 19.95013618], [72.68597412, 19.9509716], [72.68624115, 19.9509697], [72.68624115, 19.95181084], [72.68653107, 19.95181084], [72.68653107, 19.95235825], [72.68681335, 19.95235825], [72.68681335, 19.95292091], [72.68708038, 19.9529171], [72.68708038, 19.95319366], [72.68736267, 19.95318985], [72.68736267, 19.95375061], [72.68763733, 19.95375061], [72.68763733, 19.95430946], [72.68791962, 19.95430946], [72.68791962, 19.95486069], [72.68818665, 19.95486069], [72.68818665, 19.95541954], [72.68846893, 19.95541573], [72.68846893, 19.95597267], [72.68875122, 19.95597267], [72.68875122, 19.95626068], [72.68902588, 19.95624924], [72.68902588, 19.95708275], [72.68930817, 19.95708275], [72.68930817, 19.95736122], [72.68958282, 19.95736122], [72.68958282, 19.95763969], [72.68985748, 19.95763969], [72.68985748, 19.95792007], [72.69013977, 19.95791626], [72.69013977, 19.95819473], [72.69097137, 19.95819473], [72.69097137, 19.9584713], [72.69180298, 19.95846939], [72.69180298, 19.95874977], [72.69236755, 19.95874977], [72.69236755, 19.95903015], [72.69264221, 19.95902824], [72.69264221, 19.95930481], [72.69319153, 19.95930481], [72.69319153, 19.95958328], [72.69374847, 19.95958328], [72.69374847, 19.95986176], [72.69403076, 19.95985985], [72.69403076, 19.96014023], [72.69625092, 19.96013832], [72.69625092, 19.96097183], [72.6965332, 19.96096992], [72.6965332, 19.96153069], [72.69680786, 19.96153069], [72.69680786, 19.96096992], [72.69736481, 19.96097183], [72.69736481, 19.96069336], [72.69958496, 19.96069336], [72.69958496, 19.96097183], [72.70041656, 19.96096992], [72.70041656, 19.96125031], [72.70096588, 19.96125031], [72.70096588, 19.96153069], [72.70124817, 19.96153069], [72.70124817, 19.96181107], [72.70153046, 19.96180534], [72.70153046, 19.96208382], [72.70180511, 19.96208382], [72.70180511, 19.96236038], [72.70207977, 19.96236038], [72.70207977, 19.96264076], [72.70236206, 19.96263885], [72.70236206, 19.96319389], [72.70263672, 19.96319389], [72.70263672, 19.96347237], [72.70318604, 19.96347046], [72.70318604, 19.96375084], [72.70347595, 19.96375084], [72.70347595, 19.96403122], [72.70375061, 19.9640255], [72.70375061, 19.96513939], [72.7040329, 19.96512985], [72.7040329, 19.96541977], [72.70430756, 19.96541786], [72.70430756, 19.96569443], [72.70458221, 19.96569443], [72.70458221, 19.9659729], [72.70485687, 19.96596909], [72.70485687, 19.96624756], [72.70540619, 19.96624756], [72.70540619, 19.96652985], [72.70569611, 19.96652985], [72.70569611, 19.96680832], [72.70625305, 19.96680641], [72.70625305, 19.96708298], [72.70680237, 19.96708298], [72.70680237, 19.96736145], [72.70707703, 19.96736145], [72.70707703, 19.96764183], [72.7076416, 19.96764183], [72.7076416, 19.9679203], [72.70791626, 19.9679203], [72.70791626, 19.96820259], [72.71013641, 19.96819496], [72.71013641, 19.96847153], [72.71041107, 19.96847153], [72.71041107, 19.96875191], [72.71069336, 19.96875191], [72.71069336, 19.96903038], [72.71098328, 19.96903038], [72.71098328, 19.96931267], [72.71263885, 19.96930504], [72.71263885, 19.96958351], [72.71375275, 19.96958351], [72.71375275, 19.96930504], [72.7179184, 19.96931267], [72.7179184, 19.96903038], [72.71819305, 19.96903038], [72.71819305, 19.96875191], [72.71985626, 19.96875191], [72.71985626, 19.96847153], [72.72041321, 19.96847153], [72.72041321, 19.96791649], [72.72070313, 19.9679203], [72.72070313, 19.96764183], [72.72097015, 19.96764183], [72.72097015, 19.96736145], [72.72125244, 19.96736145], [72.72125244, 19.96680641], [72.72180176, 19.96680832], [72.72180176, 19.96652985], [72.72207642, 19.96652985], [72.72207642, 19.96624756], [72.72264099, 19.96624756], [72.72264099, 19.96569061], [72.72319794, 19.96569443], [72.72319794, 19.96486092], [72.7234726, 19.96486092], [72.7234726, 19.96458054], [72.72402954, 19.96458244], [72.72402954, 19.96430779], [72.72429657, 19.96430969], [72.72429657, 19.96403122], [72.72458649, 19.96403122], [72.72458649, 19.96375084], [72.72486115, 19.96375084], [72.72486115, 19.96347046], [72.7251358, 19.96347237], [72.7251358, 19.96291542], [72.72541809, 19.96292114], [72.72541809, 19.96264076], [72.72598267, 19.96264076], [72.72598267, 19.96236038], [72.72652435, 19.96236038], [72.72651672, 19.96207047], [72.72624969, 19.96208382], [72.72624969, 19.96152687], [72.72651672, 19.96153069], [72.72651672, 19.96125031], [72.7270813, 19.96125031], [72.7270813, 19.96096992], [72.72736359, 19.96097183], [72.72736359, 19.96069336], [72.72763824, 19.96070099], [72.72763824, 19.96042061], [72.72820282, 19.96042061], [72.72820282, 19.95985985], [72.72846985, 19.95986176], [72.72846985, 19.95958328], [72.72875214, 19.95958328], [72.72875214, 19.95930481], [72.72902679, 19.95930481], [72.72902679, 19.95902824], [72.72957611, 19.95903015], [72.72957611, 19.95874977], [72.73014069, 19.95874977], [72.73014069, 19.95846939], [72.73041534, 19.9584713], [72.73041534, 19.95819473], [72.73069763, 19.95819473], [72.73069763, 19.95708275], [72.73097229, 19.95708275], [72.73097229, 19.95157051], [72.73097229, 19.95013618], [72.73124695, 19.95013618], [72.73124695, 19.94791412], [72.73153687, 19.94791985], [72.73153687, 19.94736099], [72.73180389, 19.94736099], [72.73179626, 19.94597054], [72.73208618, 19.94597244], [72.73208618, 19.9454174], [72.73236084, 19.94542122], [72.73236084, 19.94514084], [72.73264313, 19.94514084], [72.73264313, 19.94458008], [72.73291779, 19.94458389], [72.73291779, 19.94430542], [72.73319244, 19.94432068], [72.73319244, 19.94403076], [72.7334671, 19.94403076], [72.7334671, 19.94375038], [72.73374939, 19.94375038], [72.73374939, 19.94347191], [72.73430634, 19.94347191], [72.73430634, 19.94318962], [72.73430634, 19.9426384], [72.73513794, 19.9426403], [72.73513794, 19.94236183], [72.73542023, 19.94236183], [72.73542023, 19.94208336], [72.73596954, 19.94208336], [72.73596954, 19.94152832], [72.73874664, 19.94153023], [72.73874664, 19.94125175], [72.73986053, 19.94125175], [72.73986053, 19.94095993], [72.74013519, 19.94097137], [72.74013519, 19.94069481], [72.74263763, 19.94069481], [72.74263763, 19.94097137], [72.74318695, 19.94095993], [72.74318695, 19.94125175], [72.74347687, 19.94125175], [72.74347687, 19.94153023], [72.74541473, 19.94152832], [72.74541473, 19.94180489], [72.74597168, 19.94180489], [72.74597168, 19.94208336], [72.74652863, 19.94208336], [72.74652863, 19.94236183], [72.7470932, 19.94236183], [72.7470932, 19.9426403], [72.74986267, 19.9426403], [72.74986267, 19.94236183], [72.75069427, 19.94236183], [72.75069427, 19.94208336], [72.75096893, 19.94208336], [72.75096893, 19.94180489], [72.75152588, 19.94180489], [72.75152588, 19.94152832], [72.75180817, 19.94153023], [72.75180817, 19.94095993], [72.75235748, 19.94097137], [72.75235748, 19.94041634], [72.7526474, 19.94041824], [72.7526474, 19.94013977], [72.75291443, 19.94013977], [72.7529068, 19.93985748], [72.75319672, 19.9398613], [72.75319672, 19.93958282], [72.75347137, 19.93958282], [72.75347137, 19.93930626], [72.75374603, 19.93930817], [72.75374603, 19.93902969], [72.75402832, 19.93902969], [72.75402832, 19.93457985], [72.75375366, 19.93458366], [72.75375366, 19.93263817], [72.75347137, 19.93264008], [72.75347137, 19.92791939], [72.75374603, 19.92791939], [72.75374603, 19.92736053], [72.75485992, 19.92736053], [72.75485992, 19.93431091], [72.75514221, 19.93431091], [72.75514221, 19.93542099], [72.75541687, 19.93542099], [72.75541687, 19.93902969], [72.75514221, 19.93902969], [72.75514221, 19.93930817], [72.75485992, 19.93930626], [72.75485992, 19.9398613], [72.7545929, 19.93985748], [72.7545929, 19.94041824], [72.75430298, 19.94041634], [72.75430298, 19.94069481], [72.75402832, 19.94069481], [72.75402832, 19.94097137], [72.75375366, 19.94097137], [72.75375366, 19.94180489], [72.75347137, 19.94180489], [72.75347137, 19.94208336], [72.75374603, 19.94208145], [72.75374603, 19.9426403], [72.75347137, 19.9426403], [72.75347137, 19.94292259], [72.75319672, 19.94292259], [72.75319672, 19.94320107], [72.75291443, 19.94319534], [72.75291443, 19.94347191], [72.75235748, 19.94347191], [72.75235748, 19.94403076], [72.74680328, 19.94403076], [72.74680328, 19.94375038], [72.74485779, 19.94375038], [72.74485779, 19.94347191], [72.74458313, 19.94347191], [72.74458313, 19.94319534], [72.74097443, 19.94319534], [72.74097443, 19.94347191], [72.74069214, 19.94347191], [72.74069214, 19.94375038], [72.73958588, 19.94375038], [72.73958588, 19.94403076], [72.73847198, 19.94403076], [72.73847198, 19.94432068], [72.73791504, 19.94430542], [72.73791504, 19.94458389], [72.73764038, 19.94458008], [72.73764038, 19.94514084], [72.73735809, 19.94514084], [72.73735809, 19.94542122], [72.73708344, 19.9454174], [72.73708344, 19.94569206], [72.73680878, 19.94569016], [72.73680878, 19.94625092], [72.73652649, 19.94625092], [72.73652649, 19.94652939], [72.73639679, 19.94652748], [72.73625183, 19.94652939], [72.73625183, 19.94709015], [72.73596954, 19.94709015], [72.73596954, 19.94791985], [72.73568726, 19.94791985], [72.73568726, 19.94902992], [72.73542023, 19.94902611], [72.73542023, 19.9509716], [72.73513794, 19.9509716], [72.73513794, 19.95112038], [72.73513794, 19.95430946], [72.73486328, 19.95430946], [72.73486328, 19.95652962], [72.73458099, 19.95652962], [72.73458099, 19.95763969], [72.73430634, 19.95763969], [72.73430634, 19.95792007], [72.73402405, 19.95791626], [72.73402405, 19.9584713], [72.7334671, 19.95846939], [72.7334671, 19.96014023], [72.73319244, 19.96014023], [72.73319244, 19.96070099], [72.73291779, 19.96070099], [72.73291779, 19.96125031], [72.73264313, 19.96125031], [72.73264313, 19.96153069], [72.73097229, 19.96153069], [72.73097229, 19.96181107], [72.73069763, 19.96180534], [72.73069763, 19.96208382], [72.73041534, 19.96208382], [72.73042297, 19.96236038], [72.73014069, 19.96236038], [72.73014069, 19.96264076], [72.7298584, 19.96264076], [72.7298584, 19.96292114], [72.73014069, 19.96291542], [72.73014069, 19.96319389], [72.7298584, 19.96319389], [72.7298584, 19.96347237], [72.72957611, 19.96347046], [72.72957611, 19.96375084], [72.72930908, 19.96375084], [72.72930908, 19.96403122], [72.72902679, 19.96403122], [72.72902679, 19.96430969], [72.72875214, 19.96430779], [72.72875214, 19.96458244], [72.72846985, 19.96458244], [72.72846985, 19.96486092], [72.72819519, 19.96486092], [72.72819519, 19.96513939], [72.7279129, 19.96513939], [72.7279129, 19.96569443], [72.72763824, 19.96569443], [72.72763824, 19.9659729], [72.72735596, 19.96596909], [72.72735596, 19.96652985], [72.7270813, 19.96652985], [72.7270813, 19.96680832], [72.72680664, 19.96680641], [72.72680664, 19.96708298], [72.72651672, 19.96707916], [72.72651672, 19.96764183], [72.72624969, 19.96764183], [72.72624969, 19.9679203], [72.72598267, 19.9679203], [72.72598267, 19.96820259], [72.72541809, 19.96820259], [72.72541809, 19.96875191], [72.7251358, 19.96875191], [72.7251358, 19.96903038], [72.72486115, 19.96903038], [72.72486115, 19.96931267], [72.7243042, 19.96930504], [72.7243042, 19.96958351], [72.72374725, 19.96958351], [72.72374725, 19.96986008], [72.72264099, 19.96986008], [72.72264099, 19.97014046], [72.7215271, 19.97013855], [72.7215271, 19.97069359], [72.72097015, 19.97069359], [72.72097015, 19.97097206], [72.72013855, 19.97097015], [72.72013855, 19.97153091], [72.7168045, 19.9715271], [72.7168045, 19.97208214], [72.71652985, 19.97208214], [72.71653748, 19.97236061], [72.71624756, 19.97236061], [72.71624756, 19.97402954], [72.71652985, 19.97402763], [72.71652985, 19.97486115], [72.71679688, 19.97486115], [72.71679688, 19.97513962], [72.71708679, 19.97513962], [72.71708679, 19.97542], [72.71736145, 19.97542], [72.71736145, 19.97624969], [72.71763611, 19.97624969], [72.71763611, 19.97708321], [72.7179184, 19.97708321], [72.7179184, 19.97736168], [72.71819305, 19.97735977], [72.71819305, 19.97764015], [72.71848297, 19.97764015], [72.71848297, 19.97820091], [72.71875, 19.97820091], [72.71875, 19.97875023], [72.71901703, 19.97875023], [72.71901703, 19.98041916], [72.71930695, 19.98041725], [72.71930695, 19.98097229], [72.7195816, 19.98096848], [72.7195816, 19.98180962], [72.71986389, 19.9818058], [72.71986389, 19.98208237], [72.72013855, 19.98208427], [72.72013855, 19.98347282], [72.72041321, 19.98347282], [72.72041321, 19.98402977], [72.7206955, 19.98402786], [72.7206955, 19.98597145], [72.72097015, 19.98597145], [72.72097015, 19.98624992], [72.72125244, 19.98624039], [72.72125244, 19.9865303], [72.7215271, 19.9865284], [72.7215271, 19.98736191], [72.72180176, 19.98736191], [72.72180939, 19.9893055], [72.72208405, 19.9893055], [72.72208405, 19.98958588], [72.72180939, 19.98958015], [72.72180939, 19.99152946], [72.72207642, 19.99152946], [72.72207642, 19.99291992], [72.72180939, 19.99291992], [72.72180176, 19.99736023], [72.7215271, 19.99736023], [72.7215271, 19.99903107], [72.72125244, 19.99903107], [72.72125244, 19.99998283], [72.72125244, 20.00069427], [72.7215271, 20.00069427], [72.7215271, 20.00124931], [72.72125244, 20.00123978], [72.72125244, 20.00152969], [72.72097015, 20.00152779], [72.72097015, 20.0023613], [72.72070313, 20.00235939], [72.72070313, 20.00569916], [72.72041321, 20.00569534], [72.72041321, 20.00597191], [72.72013855, 20.00596809], [72.72013855, 20.00680923], [72.71986389, 20.00680542], [72.71986389, 20.00847244], [72.7195816, 20.00846863], [72.7195816, 20.00902939], [72.71986389, 20.00902748], [72.71986389, 20.00958252], [72.7195816, 20.00958252], [72.7195816, 20.01042938], [72.71930695, 20.01041603], [72.71930695, 20.0106945], [72.71901703, 20.0106926], [72.71901703, 20.01152992], [72.71875, 20.01152802], [72.71875, 20.01208305], [72.71901703, 20.01208115], [72.71901703, 20.01320076], [72.71875, 20.01320076], [72.71875, 20.01375008], [72.71847534, 20.01375008], [72.71847534, 20.01486206], [72.71819305, 20.01486015], [72.71819305, 20.01542091], [72.7179184, 20.01542091], [72.7179184, 20.01764107], [72.71763611, 20.01764107], [72.71763611, 20.01791954], [72.71708679, 20.01791954], [72.71708679, 20.01847267], [72.71679688, 20.01847076], [72.71679688, 20.01902962], [72.71652985, 20.01902962], [72.71653748, 20.01986122], [72.71624756, 20.01986122], [72.71624756, 20.02041817], [72.7159729, 20.02041626], [72.7159729, 20.0209713], [72.71569824, 20.0209713], [72.71569824, 20.02125168], [72.71541595, 20.02125168], [72.71541595, 20.02180481], [72.7151413, 20.02179909], [72.7151413, 20.02264023], [72.71485901, 20.02264023], [72.71485901, 20.02514076], [72.7151413, 20.02514076], [72.7151413, 20.02653122], [72.71541595, 20.0265274], [72.71541595, 20.02819443], [72.71569824, 20.02819443], [72.71569824, 20.02986145], [72.71541595, 20.02985954], [72.71541595, 20.03153992], [72.7151413, 20.03153992], [72.7151413, 20.03264046], [72.71541595, 20.03264046], [72.71541595, 20.03403091], [72.7151413, 20.03403091], [72.7151413, 20.03625107], [72.71541595, 20.03624916], [72.71541595, 20.03708267], [72.7151413, 20.03708267], [72.7151413, 20.03736115], [72.71485901, 20.03735161], [72.71485901, 20.03792], [72.7151413, 20.03792], [72.7151413, 20.03874969], [72.71485901, 20.03874969], [72.71485901, 20.03930473], [72.7151413, 20.03930473], [72.7151413, 20.04041672], [72.71485901, 20.0404129], [72.71485901, 20.04264069], [72.71457672, 20.04264069], [72.71457672, 20.04292107], [72.71430206, 20.04292107], [72.71430206, 20.04347992], [72.71457672, 20.04347992], [72.71457672, 20.04403114], [72.71430206, 20.04403114], [72.71430206, 20.04430962], [72.7140274, 20.04430962], [72.7140274, 20.04541969], [72.71375275, 20.04541969], [72.71375275, 20.04624748], [72.71347046, 20.04624748], [72.71347046, 20.04764175], [72.7131958, 20.04764175], [72.7131958, 20.04819489], [72.71290588, 20.04818916], [72.71290588, 20.0490303], [72.71263885, 20.0490284], [72.71263885, 20.0506897], [72.7123642, 20.05069542], [72.7123642, 20.05097389], [72.71208191, 20.05097008], [72.71208191, 20.05181122], [72.71180725, 20.0518055], [72.71180725, 20.05236053], [72.71152496, 20.05236053], [72.71152496, 20.05347252], [72.71125031, 20.05347252], [72.71125031, 20.0545826], [72.71097565, 20.0545826], [72.71098328, 20.05624962], [72.71069336, 20.05624962], [72.71069336, 20.05708313], [72.71041107, 20.05708122], [72.71041107, 20.06041908], [72.71013641, 20.06041718], [72.71013641, 20.0620842], [72.70986176, 20.0620842], [72.70986176, 20.06319427], [72.7095871, 20.06319046], [72.7095871, 20.06513977], [72.70929718, 20.06513977], [72.70929718, 20.06624985], [72.70903015, 20.06624985], [72.70903015, 20.06653023], [72.70874786, 20.06652832], [72.70874786, 20.06736183], [72.70847321, 20.06735992], [72.70847321, 20.06820107], [72.70819092, 20.06820107], [72.70819092, 20.06875038], [72.70791626, 20.06875038], [72.70791626, 20.07014084], [72.7076416, 20.07014084], [72.7076416, 20.07042122], [72.70791626, 20.07042122], [72.70791626, 20.07125092], [72.70819092, 20.07125092], [72.70819092, 20.07208252], [72.70847321, 20.07208061], [72.70847321, 20.07263947], [72.70874786, 20.07263947], [72.70874786, 20.07347298], [72.70903015, 20.07347298], [72.70903015, 20.07430077], [72.70929718, 20.0743103], [72.70929718, 20.07514191], [72.7095871, 20.07513809], [72.7095871, 20.0759716], [72.70986176, 20.0759716], [72.70986176, 20.07681274], [72.71013641, 20.07681274], [72.71013641, 20.07736015], [72.71041107, 20.07736015], [72.71041107, 20.07764053], [72.71069336, 20.07763863], [72.71069336, 20.07819366], [72.71097565, 20.07819366], [72.71097565, 20.07875061], [72.71125031, 20.07875061], [72.71125031, 20.07903099], [72.71153259, 20.07903099], [72.71153259, 20.07930946], [72.71208191, 20.07930946], [72.71208191, 20.07958984], [72.71235657, 20.07958984], [72.71235657, 20.07986069], [72.71290588, 20.07986069], [72.71290588, 20.07958984], [72.7131958, 20.07958984], [72.7131958, 20.07986069], [72.71430206, 20.07986069], [72.71430206, 20.08014107], [72.7151413, 20.08014107], [72.7151413, 20.08041954], [72.71624756, 20.08041573], [72.71624756, 20.0806942], [72.71644592, 20.0806942], [72.71708679, 20.0806942], [72.71708679, 20.08097267], [72.71847534, 20.08097267], [72.71847534, 20.0806942], [72.7206955, 20.0806942], [72.7206955, 20.08097267], [72.72486115, 20.08097076], [72.72486115, 20.08125114], [72.72541809, 20.08125114], [72.72541809, 20.08152962], [72.72598267, 20.08152962], [72.72598267, 20.08181], [72.72569275, 20.08180428], [72.72569275, 20.08208275], [72.72541809, 20.08208084], [72.72541809, 20.08265114], [72.72569275, 20.08265114], [72.72569275, 20.08236122], [72.72598267, 20.08236122], [72.72597504, 20.08208275], [72.72624969, 20.08208084], [72.72624969, 20.08265114], [72.72652435, 20.08263969], [72.72652435, 20.08319473], [72.72680664, 20.08319092], [72.72680664, 20.08403015], [72.7270813, 20.08402634], [72.7270813, 20.08458328], [72.72735596, 20.08457947], [72.72735596, 20.08542061], [72.72763824, 20.0854187], [72.72763824, 20.08597183], [72.7279129, 20.08596992], [72.7279129, 20.08680916], [72.72819519, 20.08680534], [72.72819519, 20.08819389], [72.72846985, 20.08819389], [72.72846985, 20.08875084], [72.72875214, 20.08875084], [72.72875214, 20.09013939], [72.72902679, 20.09013939], [72.72902679, 20.09236145], [72.72930908, 20.09235954], [72.72930908, 20.0929203], [72.72958374, 20.09291649], [72.72958374, 20.09347153], [72.7298584, 20.09346962], [72.7298584, 20.09403038], [72.73014069, 20.09402847], [72.73014069, 20.09486198], [72.73041534, 20.09486198], [72.73041534, 20.09569359], [72.73097229, 20.09568977], [72.73097229, 20.09625053], [72.73124695, 20.09625053], [72.73124695, 20.09653091], [72.73152924, 20.09652519], [72.73152924, 20.09708595], [72.73179626, 20.09708023], [72.73179626, 20.09765053], [72.73208618, 20.09763718], [72.73208618, 20.09819412], [72.73236084, 20.09819031], [72.73236084, 20.09902954], [72.7326355, 20.09902954], [72.7326355, 20.09986115], [72.73291779, 20.09986115], [72.73291779, 20.10069466], [72.73319244, 20.10069084], [72.73319244, 20.10153008], [72.73347473, 20.10152817], [72.73347473, 20.10236168], [72.73374939, 20.10236168], [72.73374939, 20.10320282], [72.73401642, 20.10320282], [72.73401642, 20.10375023], [72.73430634, 20.10375023], [72.73430634, 20.10458374], [72.73458099, 20.10458183], [72.73458099, 20.10514069], [72.73486328, 20.10513878], [72.73486328, 20.10597229], [72.73513794, 20.10597038], [72.73513794, 20.10653114], [72.73542023, 20.10653114], [72.73542023, 20.10736084], [72.73568726, 20.10736084], [72.73568726, 20.10791969], [72.73596954, 20.10791969], [72.73596954, 20.10874939], [72.73625183, 20.10874939], [72.73625183, 20.10931015], [72.73652649, 20.10931015], [72.73652649, 20.11013985], [72.73680878, 20.11013985], [72.73680878, 20.11042023], [72.73708344, 20.11041641], [72.73708344, 20.11069679], [72.73735809, 20.11069107], [72.73735809, 20.11292076], [72.73764038, 20.11292076], [72.73764038, 20.11375046], [72.73791504, 20.11375046], [72.73791504, 20.11458397], [72.73819733, 20.11458397], [72.73819733, 20.11840057], [72.73819733, 20.12292099], [72.73791504, 20.12291527], [72.73791504, 20.12569427], [72.73764038, 20.12569427], [72.73764038, 20.1273613], [72.73792267, 20.12735748], [72.73792267, 20.12903023], [72.73764038, 20.12903023], [72.73764038, 20.13264084], [72.73735809, 20.13264084], [72.73735809, 20.13541985], [72.73764038, 20.13541412], [72.73764038, 20.13653946], [72.74106598, 20.13595963], [72.74830627, 20.13441086], [72.7546463, 20.13303947], [72.7618103, 20.13149834], [72.7745285, 20.13080025], [72.78761292, 20.13008118], [72.79447174, 20.12817955], [72.80184937, 20.12501907], [72.80352783, 20.12601089], [72.80519867, 20.12701035], [72.8012619, 20.13780975], [72.80066681, 20.14526939], [72.80148315, 20.14711761], [72.80206299, 20.14846992], [72.80536652, 20.15003014], [72.80912781, 20.15180016], [72.81195068, 20.15242004], [72.81585693, 20.15328026], [72.82604218, 20.14628029], [72.83229828, 20.14402008], [72.83534241, 20.14464188], [72.83416748, 20.14973068], [72.82884216, 20.15657043], [72.83361816, 20.18357086], [72.8346405, 20.18577003], [72.83553314, 20.18766022], [72.83725739, 20.18868065], [72.84220123, 20.18886948], [72.84352112, 20.19004059], [72.84967041, 20.18925095], [72.84905243, 20.19094276], [72.84571838, 20.19413948], [72.8441391, 20.19779015], [72.846138, 20.20356941], [72.85028839, 20.20794106], [72.85508728, 20.20911026], [72.86438751, 20.20862961], [72.87200165, 20.20824051], [72.87287903, 20.21251106], [72.87188721, 20.22256088], [72.87454224, 20.2258091], [72.88432312, 20.22657967], [72.88873291, 20.22582054], [72.89984131, 20.22167015], [72.90538025, 20.22623253], [72.91086578, 20.22606087], [72.91680908, 20.22476959], [72.92218781, 20.22359848], [72.92842865, 20.2233696], [72.94181061, 20.21780968], [72.95101929, 20.21598053], [72.96082306, 20.21404076], [72.96924591, 20.2109108], [72.97042847, 20.21232986], [72.97592163, 20.18959808], [72.97619629, 20.18001938], [72.98603821, 20.17654991], [72.98668671, 20.17131042], [72.98623657, 20.16271973], [72.98596191, 20.15752983], [72.97322845, 20.13080025], [72.97962952, 20.12529945], [72.98532104, 20.113451], [72.98924255, 20.11321259], [72.9941864, 20.11390114], [73.00431061, 20.11791992], [73.00665283, 20.12125015], [73.00727844, 20.12412071], [73.00778198, 20.12639046], [73.00771332, 20.12940025], [73.00763702, 20.13246918], [73.00875854, 20.13701057], [73.01051331, 20.14022255], [73.01747894, 20.13495827], [73.01702118, 20.1324501], [73.01667023, 20.13049126], [73.01499176, 20.12486076], [73.01020813, 20.11040115], [73.01954651, 20.10502052], [73.02468109, 20.09630013], [73.03177643, 20.08442116], [73.03852844, 20.0780983], [73.04527283, 20.07178116], [73.05281067, 20.06767082], [73.05921173, 20.06793022], [73.05799103, 20.09673119], [73.06063843, 20.09906006], [73.07823181, 20.09527016], [73.08831787, 20.09446907], [73.09844971, 20.09366989], [73.1051712, 20.08721924], [73.10794067, 20.08732033], [73.11038208, 20.08461189], [73.11183167, 20.08301163], [73.11754608, 20.07880974], [73.1231308, 20.07793999], [73.12612152, 20.07809067], [73.12773895, 20.07816124], [73.12967682, 20.07884026], [73.13140106, 20.07942963], [73.13669586, 20.08525085], [73.13954163, 20.08427048], [73.1444931, 20.07785988], [73.15674591, 20.07395935], [73.16329956, 20.07311058], [73.17022705, 20.06560135], [73.17539215, 20.05805016], [73.18144226, 20.05162048], [73.18379974, 20.0522995], [73.18586731, 20.05290031], [73.19890594, 20.06227112], [73.19803619, 20.07781029], [73.20289612, 20.08105087], [73.20691681, 20.08371162], [73.21393585, 20.09064102], [73.21911621, 20.09749985], [73.21774292, 20.10634041], [73.21631622, 20.12199974], [73.22148895, 20.12079811], [73.22672272, 20.12257957], [73.23033142, 20.12816048], [73.22952271, 20.13315964], [73.23046875, 20.13771057], [73.23264313, 20.1406002], [73.23548889, 20.14099121], [73.23690796, 20.13692284], [73.23667908, 20.1297226], [73.23812103, 20.12811089], [73.24391937, 20.12903976], [73.25361633, 20.12852097], [73.25614929, 20.12788963], [73.25946808, 20.12463951], [73.2612915, 20.12559128], [73.26280975, 20.12795067], [73.2649765, 20.13376045], [73.26846313, 20.13928986], [73.28347015, 20.14575958], [73.28907776, 20.14956284], [73.29363251, 20.15388107], [73.29321289, 20.16216087], [73.29065704, 20.17440987], [73.29073334, 20.177351], [73.29374695, 20.18597984], [73.29405975, 20.19386101], [73.2948761, 20.19621086], [73.29821777, 20.19616127], [73.3111496, 20.20721054], [73.31416321, 20.20767021], [73.32047272, 20.20433235], [73.32787323, 20.20249939], [73.33642578, 20.20409966], [73.34806061, 20.1990509], [73.35285187, 20.19847107], [73.35481262, 20.1996212], [73.35721588, 20.20249939], [73.35930634, 20.20911026], [73.36178589, 20.21198845], [73.36759949, 20.21337128], [73.36923981, 20.21170807], [73.36760712, 20.20940018], [73.3647995, 20.20099831], [73.36691284, 20.19634056], [73.37431335, 20.19265938], [73.37594604, 20.19497108], [73.37528992, 20.20290947], [73.37632751, 20.20532036], [73.38366699, 20.20239067], [73.38851929, 20.20630074], [73.39528656, 20.20916939], [73.39736176, 20.20594025], [73.39626312, 20.20163155], [73.39807892, 20.19600105], [73.40281677, 20.19502068], [73.4054718, 20.19796944], [73.40920258, 20.20049095], [73.41681671, 20.20030975], [73.42682648, 20.20157051], [73.42991638, 20.20623016], [73.43031311, 20.21232033], [73.42788696, 20.21543121], [73.42607117, 20.22359848], [73.42237854, 20.23176193], [73.42280579, 20.23676109], [73.42032623, 20.24228096], [73.42227936, 20.24809074], [73.42160797, 20.25371933], [73.42041016, 20.25699997], [73.42180634, 20.26356125], [73.42442322, 20.26914024], [73.42314148, 20.27368927], [73.42462158, 20.27683067], [73.436203, 20.27902031], [73.43694305, 20.28212166], [73.43076324, 20.29804993], [73.42854309, 20.31191063], [73.42611694, 20.31592941], [73.42531586, 20.32072067], [73.42539978, 20.33767128], [73.42373657, 20.34181023], [73.4234314, 20.35209084], [73.42173767, 20.35560036], [73.41478729, 20.38157082], [73.41200256, 20.38352966], [73.4076767, 20.38392067], [73.40310669, 20.3817997], [73.39807892, 20.3747406], [73.39454651, 20.3729496], [73.39157867, 20.37289047], [73.39025116, 20.3801899], [73.39134979, 20.39019966], [73.39550781, 20.39801979], [73.39772797, 20.39923286], [73.40762329, 20.39628983], [73.40952301, 20.40134811], [73.40879059, 20.40422058], [73.41306305, 20.40784836], [73.41461182, 20.40566063], [73.41583252, 20.40619087], [73.41633606, 20.41065979], [73.42288971, 20.41432953], [73.42974091, 20.41439056], [73.42928314, 20.41996956], [73.43080902, 20.42881966], [73.43585968, 20.43606949], [73.43792725, 20.44572258], [73.44901276, 20.4666996], [73.45204163, 20.47140121], [73.45594025, 20.47537041], [73.46109009, 20.47813034], [73.46523285, 20.48415947], [73.46669769, 20.48830032], [73.46983337, 20.49233055], [73.47593689, 20.49501991], [73.47413635, 20.50106049], [73.47226715, 20.51404953], [73.47380829, 20.51531982], [73.47690582, 20.52203751], [73.48474121, 20.52570915], [73.49729919, 20.53622246], [73.50074005, 20.54024124], [73.49327087, 20.54220009], [73.48179626, 20.54335976], [73.48584747, 20.56405067], [73.4837265, 20.57843018], [73.4808197, 20.58359909], [73.47670746, 20.58630943], [73.46855927, 20.58876991], [73.45482635, 20.59458923], [73.44036102, 20.59511948], [73.4375, 20.59747124], [73.43908691, 20.60126114], [73.43382263, 20.61471939], [73.43078613, 20.62053108], [73.42764282, 20.62449074], [73.41596222, 20.62616158], [73.41512299, 20.62805939], [73.41797638, 20.63047028], [73.414711, 20.63570023], [73.41134644, 20.63858032], [73.40273285, 20.64259911], [73.40158081, 20.64920998], [73.40364838, 20.65237045], [73.40983582, 20.65501022], [73.41496277, 20.65604019], [73.41752625, 20.65789032], [73.41916656, 20.66047096], [73.43035889, 20.66088104], [73.43551636, 20.66237259], [73.43991852, 20.6648407], [73.44325256, 20.67437935], [73.443573, 20.6779995], [73.4500885, 20.68075943], [73.45288086, 20.68300056], [73.45452881, 20.68605042], [73.45654297, 20.69339943], [73.44729614, 20.70111084], [73.4536972, 20.7104702], [73.45868683, 20.71431923], [73.47518921, 20.72167015], [73.48049927, 20.71965027], [73.48261261, 20.71722984], [73.48416901, 20.70907021], [73.48873901, 20.70660019], [73.49336243, 20.6942997], [73.49375916, 20.68952942], [73.49729156, 20.6860199], [73.4972229, 20.6809597], [73.49205017, 20.68033028], [73.48918915, 20.67850113], [73.4874115, 20.67555046], [73.48777771, 20.67212105], [73.4895401, 20.66963959], [73.49250793, 20.66843033], [73.49336243, 20.66555977], [73.49547577, 20.66269112], [73.49843597, 20.65341949], [73.50087738, 20.65274048], [73.50788116, 20.65864944], [73.5123291, 20.66302109], [73.51780701, 20.67014122], [73.51998901, 20.66633987], [73.52516174, 20.66714287], [73.52697754, 20.67012978], [73.53040314, 20.6731205], [73.53837585, 20.67386055], [73.54476166, 20.6692009], [73.55365753, 20.65533066], [73.5629425, 20.64739037], [73.56732941, 20.64791107], [73.57419586, 20.65105057], [73.58418274, 20.64789963], [73.59120941, 20.64511108], [73.60275269, 20.63786125], [73.60730743, 20.63630104], [73.62219238, 20.62529945], [73.62594604, 20.62111092], [73.62948608, 20.61230087], [73.63038635, 20.60602951], [73.63217163, 20.60223961], [73.63506317, 20.59165955], [73.63448334, 20.58229065], [73.63677216, 20.57929039], [73.63949585, 20.57790947], [73.64328766, 20.57715988], [73.64710236, 20.57749939], [73.65093994, 20.57641029], [73.65705109, 20.57219124], [73.6618576, 20.56574059], [73.66584015, 20.5628109], [73.6707077, 20.56233978], [73.67617798, 20.56415939], [73.68136597, 20.56767082], [73.68550873, 20.57168961], [73.69243622, 20.57534981], [73.70101929, 20.57838058], [73.70964813, 20.57450294], [73.71985626, 20.57632065], [73.72428131, 20.57580185], [73.72902679, 20.5741291], [73.73766327, 20.57398987], [73.74154663, 20.57261848], [73.74820709, 20.56735992], [73.76394653, 20.58333015], [73.76906586, 20.58716965], [73.7756958, 20.58876038], [73.77997589, 20.59185982], [73.78135681, 20.59507942], [73.78705597, 20.60225868], [73.79273224, 20.60431099], [73.80237579, 20.60579109], [73.80596161, 20.60152054], [73.81656647, 20.60936928], [73.82538605, 20.61401939], [73.83068848, 20.61491966], [73.83390808, 20.61412048], [73.83828735, 20.6157608], [73.84641266, 20.6235199], [73.84310913, 20.64441109], [73.8434906, 20.65032959], [73.84707642, 20.65636253], [73.84535217, 20.66707039], [73.84150696, 20.67513847], [73.83425903, 20.67353821], [73.82543182, 20.67361832], [73.82264709, 20.69382095], [73.82874298, 20.69646072], [73.83362579, 20.69960976], [73.83917999, 20.70190048], [73.84275818, 20.70211983], [73.86360168, 20.6942997], [73.87362671, 20.7077198], [73.87728119, 20.72133064], [73.88194275, 20.72687912], [73.88556671, 20.72961044], [73.88886261, 20.73108101], [73.90379333, 20.73064041], [73.90875244, 20.72522926], [73.92090607, 20.72352982], [73.92756653, 20.73044014], [73.93506622, 20.73461914], [73.93596649, 20.73150063], [73.94953156, 20.74230957], [73.94845581, 20.74670029], [73.94523621, 20.74929047], [73.94750214, 20.75247002], [73.9471817, 20.76078033], [73.93834686, 20.76078987], [73.94056702, 20.76885986], [73.93811798, 20.78967094], [73.94114685, 20.80378151], [73.94019318, 20.80886078], [73.94626617, 20.81867027], [73.94763947, 20.82509041], [73.94760895, 20.82939911], [73.94509888, 20.84013176], [73.93589783, 20.8434391], [73.93373108, 20.8449707], [73.93106079, 20.84839058], [73.9315567, 20.85250282], [73.93013, 20.86011124], [73.9316864, 20.86473274], [73.92967987, 20.86887169], [73.93123627, 20.8766098], [73.9310379, 20.88591766], [73.92732239, 20.89911079], [73.92443848, 20.90283966], [73.92273712, 20.90774918], [73.92032623, 20.91123009], [73.91681671, 20.91505051], [73.91221619, 20.91794014], [73.90956116, 20.92140007], [73.90396118, 20.92536926], [73.89633942, 20.93300056], [73.89501953, 20.94013977], [73.89509583, 20.94652176], [73.89694214, 20.95255089], [73.9017868, 20.96170044], [73.91123199, 20.96235275], [73.91538239, 20.96482086], [73.91396332, 20.96996117], [73.91116333, 20.97542953], [73.90644836, 20.98315048], [73.89863586, 20.98222923], [73.87918854, 20.98647118], [73.87268829, 20.99073029], [73.85721588, 20.99770927], [73.8537674, 20.99911118], [73.85012817, 21.00141907], [73.84683228, 20.99398994], [73.84078217, 20.99313927], [73.83769226, 20.99483109], [73.82752991, 20.99607086], [73.82050323, 20.99504089], [73.81640625, 20.99605179], [73.81404877, 21.00080109], [73.81208038, 21.01066017], [73.80770111, 21.02255821], [73.79382324, 21.01976967], [73.78470612, 21.0195694], [73.77485657, 21.01045036], [73.76944733, 21.01452065], [73.77392578, 21.0216198], [73.7756424, 21.02760124], [73.7660675, 21.04005051], [73.76300049, 21.03864098], [73.7569809, 21.03917122], [73.747612, 21.03997993], [73.7421875, 21.05550003], [73.74373627, 21.0641613], [73.74079895, 21.07287025], [73.744133, 21.08167076], [73.74224091, 21.08156967], [73.74046326, 21.08486938], [73.73906708, 21.0948391], [73.74946594, 21.1077404], [73.75260925, 21.11408997], [73.74337006, 21.10824966], [73.7388916, 21.1013298], [73.7358017, 21.10322952], [73.71478271, 21.10719109], [73.70897675, 21.11234093], [73.71058655, 21.11902237], [73.70323944, 21.10896111], [73.69338989, 21.1009903], [73.68937683, 21.10598946], [73.67890167, 21.10925102], [73.65994263, 21.10837936], [73.6577301, 21.12104988], [73.65537262, 21.12179947], [73.6530304, 21.12254143], [73.64924622, 21.12274933], [73.64546204, 21.12295914], [73.63802338, 21.12170982], [73.62872314, 21.12014961], [73.62359619, 21.13799095], [73.62634277, 21.1398201], [73.62908173, 21.14166069], [73.61885071, 21.14417267], [73.61422729, 21.14698029], [73.61345673, 21.15043068], [73.61258698, 21.15219116], [73.61147308, 21.15446091], [73.60491943, 21.15505981], [73.60027313, 21.15433121], [73.59667969, 21.15273094], [73.59229279, 21.15294075], [73.58879852, 21.15419006], [73.58751678, 21.15674019], [73.58875275, 21.16086006], [73.58830261, 21.16790009], [73.59819794, 21.17472076], [73.60691833, 21.17846107], [73.60991669, 21.17667961], [73.61316681, 21.17605972], [73.61418915, 21.17245102], [73.61384583, 21.16797066], [73.61470032, 21.16348076], [73.61969757, 21.15794945], [73.63745117, 21.15313911], [73.63897705, 21.14734077], [73.63639832, 21.13265991], [73.67150879, 21.14513969], [73.67460632, 21.15102005], [73.68131256, 21.15212059], [73.68943024, 21.15116119], [73.69824219, 21.15011024], [73.7131958, 21.1504612], [73.71517944, 21.14310074], [73.71707153, 21.1417408], [73.72235107, 21.13924026], [73.73668671, 21.13828087], [73.73983765, 21.14016151], [73.74318695, 21.1468029], [73.74603271, 21.14760971], [73.74797058, 21.15153122], [73.74619293, 21.15483093], [73.7407608, 21.16039848], [73.74162292, 21.16711044], [73.75306702, 21.16818047], [73.77966309, 21.16455269], [73.78366089, 21.16506004], [73.78720093, 21.1663208], [73.78975677, 21.16867828], [73.7911377, 21.17622948], [73.79631042, 21.18173027], [73.80253601, 21.1785717], [73.80753326, 21.1746006], [73.81212616, 21.17206764], [73.81793976, 21.17143822], [73.82254791, 21.17192078], [73.82917786, 21.18234062], [73.83048248, 21.18439293], [73.83232117, 21.1853981], [73.83590698, 21.19518089], [73.83405304, 21.19719124], [73.82134247, 21.19532013], [73.81951141, 21.19960976], [73.81877899, 21.20385933], [73.81859589, 21.20857048], [73.81841278, 21.21372032], [73.82013702, 21.22186089], [73.82316589, 21.22756958], [73.8274765, 21.23314095], [73.83634949, 21.24234009], [73.83650208, 21.245821], [73.83223724, 21.25830269], [73.83213806, 21.26745033], [73.85840607, 21.26995087], [73.87174225, 21.26737976], [73.88432312, 21.26263046], [73.89199066, 21.26241112], [73.92354584, 21.28101921], [73.93358612, 21.28532982], [73.94848633, 21.2975502], [73.94992065, 21.30658913], [73.95015717, 21.30805016], [73.95127869, 21.31500816], [73.9519577, 21.33060074], [73.95700836, 21.3444519], [73.95658875, 21.36161041], [73.95530701, 21.37425995], [73.95562744, 21.39001083], [73.95284271, 21.40237045], [73.95545959, 21.4025383], [73.96193695, 21.39311028], [73.96869659, 21.39206123], [73.97193909, 21.39479828], [73.97741699, 21.39496994], [73.98155975, 21.39733124], [73.98529053, 21.40191078], [73.98883057, 21.40448952], [74.00547791, 21.4118309], [74.00765991, 21.41257286], [74.00949097, 21.41337013], [74.01107788, 21.4145298], [74.01251984, 21.41584015], [74.0140686, 21.41703033], [74.01579285, 21.41798019], [74.0177002, 21.41855812], [74.01959991, 21.41798019], [74.02133942, 21.4170208], [74.02332306, 21.41710091], [74.0252533, 21.41751099], [74.0271759, 21.41804123], [74.02908325, 21.41862106], [74.03098297, 21.41916084], [74.03292084, 21.41958046], [74.03491211, 21.41981125], [74.03690338, 21.41966057], [74.03885651, 21.41930008], [74.04081726, 21.41896057], [74.04280853, 21.41876984], [74.04479218, 21.41852951], [74.04679108, 21.41852188], [74.04854584, 21.41942978], [74.0496521, 21.42098045], [74.05046082, 21.42270088], [74.05110168, 21.42448997], [74.05162811, 21.42628098], [74.05208588, 21.42811012], [74.05251312, 21.42995071], [74.05285645, 21.4317894], [74.05316925, 21.43366051], [74.05343628, 21.43551064], [74.05371094, 21.4373703], [74.05396271, 21.43923187], [74.05417633, 21.44110107], [74.05426025, 21.44297028], [74.05432129, 21.44485092], [74.05444336, 21.44672966], [74.05471802, 21.44860077], [74.05513, 21.45041847], [74.05565643, 21.45223999], [74.05634308, 21.45399094], [74.05716705, 21.45570946], [74.0580368, 21.45738983], [74.05893707, 21.45907021], [74.05988312, 21.4607296], [74.06082916, 21.46236992], [74.0623703, 21.46508026], [74.0632782, 21.4667511], [74.06413269, 21.46842957], [74.06497192, 21.47014999], [74.06569672, 21.47190094], [74.06616974, 21.47372055], [74.06648254, 21.47557068], [74.06665802, 21.47744179], [74.06642914, 21.47930145], [74.06598663, 21.4811306], [74.06716156, 21.48193169], [74.06891632, 21.48106956], [74.07042694, 21.47986031], [74.07176971, 21.47845078], [74.07301331, 21.47698021], [74.07418823, 21.47546959], [74.07527161, 21.4738903], [74.07624054, 21.47224808], [74.07701111, 21.47051811], [74.07740021, 21.46867943], [74.07752228, 21.46681023], [74.07758331, 21.46494293], [74.07740784, 21.46305847], [74.0770874, 21.46121025], [74.07704926, 21.45934105], [74.07814789, 21.45781136], [74.08001709, 21.45720291], [74.08197784, 21.45684052], [74.08394623, 21.45652962], [74.08592224, 21.45625114], [74.08789825, 21.45597076], [74.0898819, 21.4557209], [74.09185791, 21.45548058], [74.09382629, 21.45524025], [74.09581757, 21.45500946], [74.09778595, 21.45474052], [74.09976959, 21.45449066], [74.10175323, 21.45420074], [74.10372925, 21.45388985], [74.10536194, 21.45293999], [74.10558319, 21.45108986], [74.10560608, 21.44922066], [74.106987, 21.44812012], [74.1089859, 21.44802284], [74.11097717, 21.44810104], [74.11297607, 21.44831085], [74.1149292, 21.44861031], [74.11688995, 21.44896126], [74.11885834, 21.4493084], [74.12081909, 21.4496994], [74.12245941, 21.45070076], [74.12290192, 21.45251274], [74.1228714, 21.45438004], [74.12269592, 21.45625114], [74.12255859, 21.45812988], [74.122612, 21.46000099], [74.12332916, 21.46170998], [74.12506104, 21.46267128], [74.12697601, 21.46320152], [74.12892151, 21.46352005], [74.1309433, 21.46367073], [74.13292694, 21.46370125], [74.13491058, 21.46360016], [74.1368866, 21.46339035], [74.13887024, 21.4630394], [74.14076996, 21.46249008], [74.14187622, 21.46099091], [74.14258575, 21.4577198], [74.14318085, 21.45593071], [74.14465332, 21.45471954], [74.14659119, 21.45428085], [74.14858246, 21.45409012], [74.1505661, 21.45388985], [74.15252686, 21.45360947], [74.15450287, 21.45334053], [74.15648651, 21.45313072], [74.15847015, 21.45308113], [74.16046906, 21.45335007], [74.16127777, 21.4549675], [74.16159821, 21.45683098], [74.16322327, 21.45759964], [74.1652298, 21.4574604], [74.16664124, 21.4586525], [74.16723633, 21.46044159], [74.16786957, 21.46222115], [74.16931915, 21.4634304], [74.17128754, 21.46371078], [74.17325592, 21.46352005], [74.17507172, 21.46273994], [74.17650604, 21.46145058], [74.1783371, 21.46087074], [74.18017578, 21.4615612], [74.18154907, 21.46291924], [74.18274689, 21.46442032], [74.18395996, 21.46590042], [74.18553925, 21.46702194], [74.18752289, 21.46702957], [74.1894989, 21.46681023], [74.19145203, 21.46636963], [74.19328308, 21.46562195], [74.19497681, 21.4646492], [74.19661713, 21.46355247], [74.19815063, 21.46236038], [74.19940186, 21.46090126], [74.20091248, 21.45969963], [74.20287323, 21.45944023], [74.20485687, 21.45959091], [74.20684052, 21.45988083], [74.2088089, 21.46014023], [74.21082306, 21.46018982], [74.21279144, 21.45998001], [74.21475983, 21.4596405], [74.21671295, 21.45927048], [74.21868896, 21.45895004], [74.22065735, 21.45877838], [74.22263336, 21.4589901], [74.22358704, 21.46056747], [74.22376251, 21.46241951], [74.22383118, 21.4643116], [74.22373199, 21.46618271], [74.22350311, 21.46805954], [74.22323608, 21.46990967], [74.22302246, 21.47178268], [74.22290039, 21.47365952], [74.22303009, 21.47552109], [74.22374725, 21.47726059], [74.22525024, 21.47846031], [74.22709656, 21.4791584], [74.22904968, 21.47960091], [74.23103333, 21.47982025], [74.23303223, 21.47986984], [74.23501587, 21.47970772], [74.23696136, 21.4792881], [74.23873138, 21.47841263], [74.24059296, 21.47555923], [74.24121094, 21.47376823], [74.24169922, 21.47195053], [74.24215698, 21.47013283], [74.24269104, 21.46831131], [74.24333191, 21.46653938], [74.24430084, 21.46491051], [74.24581909, 21.46370125], [74.24769592, 21.46310043], [74.24967194, 21.46286964], [74.2516861, 21.46286964], [74.25367737, 21.4630394], [74.25563812, 21.46333122], [74.25759125, 21.46375084], [74.2594986, 21.46426964], [74.26138306, 21.46491051], [74.26319122, 21.46570015], [74.26415253, 21.46729279], [74.26439667, 21.46915245], [74.26454926, 21.47101021], [74.26502991, 21.47284126], [74.26654053, 21.47402], [74.26837921, 21.47473907], [74.27028656, 21.47525024], [74.27224731, 21.47562027], [74.27423096, 21.47590065], [74.27620697, 21.4761219], [74.27819824, 21.47631073], [74.28018188, 21.47649956], [74.28217316, 21.47672081], [74.28414154, 21.47696114], [74.28613281, 21.47717285], [74.28811646, 21.4773407], [74.29013062, 21.47747993], [74.29210663, 21.4776001], [74.2940979, 21.47774124], [74.2960968, 21.47788048], [74.29807281, 21.4780407], [74.30005646, 21.47824097], [74.30204773, 21.47850037], [74.30400848, 21.47887039], [74.30591583, 21.4793911], [74.30776215, 21.48011971], [74.30943298, 21.48118019], [74.31057739, 21.48266029], [74.31125641, 21.48443985], [74.31173706, 21.48625946], [74.31236267, 21.48805809], [74.3134079, 21.48962021], [74.31497955, 21.49078178], [74.31678009, 21.49156952], [74.3187027, 21.49217033], [74.32061005, 21.4926796], [74.32253265, 21.49319267], [74.32443237, 21.4937706], [74.32624054, 21.49454117], [74.32772064, 21.49575043], [74.32821655, 21.4975605], [74.32859802, 21.49939919], [74.32907104, 21.50123024], [74.32950592, 21.50306129], [74.32995605, 21.50488281], [74.33039093, 21.50672913], [74.33082581, 21.50855064], [74.33125305, 21.51037979], [74.33165741, 21.51222992], [74.3320694, 21.51402092], [74.33335876, 21.51980972], [74.33551788, 21.5402298], [74.33274078, 21.54116058], [74.33164978, 21.54117966], [74.33065033, 21.54117966], [74.32962036, 21.54116058], [74.32861328, 21.54115105], [74.32762146, 21.54112053], [74.32727051, 21.54112053], [74.32659149, 21.54111099], [74.32559204, 21.54109955], [74.32457733, 21.54111099], [74.32406616, 21.54112053], [74.32357788, 21.54113007], [74.32260895, 21.54117966], [74.32161713, 21.54125023], [74.32064819, 21.54137039], [74.31968689, 21.54152107], [74.31867218, 21.54175949], [74.31764984, 21.54211998], [74.31665802, 21.54259109], [74.31581879, 21.54317093], [74.31520081, 21.54385948], [74.31484985, 21.54466248], [74.31461334, 21.54551125], [74.31443024, 21.54636955], [74.31430054, 21.54726982], [74.3141861, 21.54818153], [74.31410217, 21.54911995], [74.3140564, 21.55006981], [74.31404877, 21.55055046], [74.31402588, 21.55103111], [74.31401825, 21.55200958], [74.31401062, 21.55298042], [74.31401062, 21.55395126], [74.3139801, 21.5549202], [74.31391144, 21.55589104], [74.31387329, 21.55655289], [74.3138504, 21.55685043], [74.31378174, 21.55779266], [74.31369781, 21.55828285], [74.31363678, 21.55871964], [74.31346893, 21.55965042], [74.3132782, 21.56056023], [74.3130188, 21.56149101], [74.3127594, 21.56240082], [74.31246185, 21.56328964], [74.31212616, 21.56417084], [74.31175995, 21.56507111], [74.31127167, 21.56604958], [74.31066895, 21.56688118], [74.30996704, 21.56732178], [74.30909729, 21.56732178], [74.30805969, 21.56705284], [74.30706024, 21.56656265], [74.30623627, 21.56595993], [74.30568695, 21.56520081], [74.30532837, 21.56429291], [74.30523682, 21.56398964], [74.30504608, 21.56328011], [74.30478668, 21.5622406], [74.30451202, 21.56126976], [74.30409241, 21.56043053], [74.30354309, 21.55982018], [74.30275726, 21.55945969], [74.30190277, 21.55922127], [74.30095673, 21.55909157], [74.30052185, 21.55906105], [74.29995728, 21.55903244], [74.29892731, 21.55901909], [74.29785156, 21.55904007], [74.29677582, 21.55909157], [74.29633331, 21.55912018], [74.2957077, 21.55912971], [74.29516602, 21.55912971], [74.29464722, 21.55914116], [74.29360962, 21.55909157], [74.2926178, 21.55898094], [74.2917099, 21.55878067], [74.29103088, 21.55817032], [74.29052734, 21.55725288], [74.2899704, 21.55641174], [74.28916931, 21.5559597], [74.28819275, 21.55574989], [74.28713226, 21.55562973], [74.28656006, 21.55549049], [74.28617096, 21.55540085], [74.28534698, 21.5549202], [74.28460693, 21.55428123], [74.28396606, 21.5535202], [74.28343201, 21.55270958], [74.28327179, 21.552351], [74.28305817, 21.55185127], [74.28292084, 21.5508194], [74.28282166, 21.54981041], [74.2824173, 21.54906845], [74.28163147, 21.54868126], [74.28063202, 21.54850006], [74.27951813, 21.54841995], [74.27839661, 21.54833031], [74.27735138, 21.54816818], [74.27651215, 21.54780006], [74.27590942, 21.54718018], [74.2754364, 21.54639053], [74.27501678, 21.54552078], [74.27469635, 21.54455948], [74.27440643, 21.54356956], [74.27413177, 21.5425396], [74.27387238, 21.54150009], [74.27361298, 21.5404911], [74.27332306, 21.53950119], [74.27297974, 21.5385685], [74.27258301, 21.53775024], [74.27211761, 21.53701973], [74.27155304, 21.53642082], [74.27086639, 21.53597069], [74.27011108, 21.53563118], [74.26924133, 21.53536987], [74.26834106, 21.53517914], [74.26737213, 21.53507042], [74.26638031, 21.53499985], [74.26535034, 21.53499031], [74.26426697, 21.53502083], [74.26368713, 21.53507042], [74.26319122, 21.53510094], [74.26209259, 21.53520012], [74.26098633, 21.53534126], [74.25992584, 21.5354805], [74.2588501, 21.53564072], [74.2578125, 21.53580093], [74.25679779, 21.53595161], [74.25583649, 21.53611946], [74.25496674, 21.53646088], [74.25414276, 21.53701019], [74.25335693, 21.53770065], [74.25267029, 21.53844261], [74.25197601, 21.53915024], [74.25138092, 21.53989983], [74.25078583, 21.54068947], [74.25025177, 21.54150963], [74.24970245, 21.54232979], [74.24936676, 21.54282951], [74.24916077, 21.54314041], [74.2485733, 21.54391289], [74.24796295, 21.54462051], [74.24732208, 21.5452404], [74.24646759, 21.54561043], [74.24539185, 21.54556274], [74.24429321, 21.54549026], [74.2434082, 21.54574013], [74.24279022, 21.54640961], [74.24237061, 21.54730988], [74.24194336, 21.54829979], [74.24147797, 21.54919815], [74.24125671, 21.54951286], [74.24093628, 21.54989815], [74.24017334, 21.5502491], [74.23919678, 21.55029106], [74.23810577, 21.5501194], [74.23705292, 21.54985046], [74.23668671, 21.54976082], [74.23607635, 21.54959106], [74.23506927, 21.54924011], [74.23406982, 21.54883957], [74.23323822, 21.54833031], [74.23258972, 21.54771996], [74.23246765, 21.54737091], [74.23232269, 21.54691124], [74.2323761, 21.54588127], [74.2325058, 21.54482079], [74.2325058, 21.54387093], [74.23233032, 21.54356194], [74.23213196, 21.54322052], [74.23111725, 21.54305077], [74.22994995, 21.54304123], [74.22910309, 21.54269981], [74.22875977, 21.54187965], [74.22866058, 21.5408802], [74.22856903, 21.53982162], [74.22834015, 21.53890038], [74.2277832, 21.53827095], [74.2269516, 21.53787994], [74.22595215, 21.53762054], [74.2248764, 21.53745079], [74.22383118, 21.53730965], [74.22283173, 21.53716087], [74.2218399, 21.53707123], [74.22077942, 21.53703117], [74.21974182, 21.53698921], [74.21869659, 21.53693962], [74.21820831, 21.53689957], [74.21769714, 21.53685188], [74.21673584, 21.5367012], [74.21586609, 21.53647041], [74.21514893, 21.53600121], [74.21478271, 21.53508949], [74.21444702, 21.53405952], [74.21386719, 21.53334999], [74.21304321, 21.53293037], [74.21208954, 21.53261948], [74.21108246, 21.53236008], [74.21054077, 21.53222084], [74.21009064, 21.53211021], [74.20915222, 21.53178024], [74.20897675, 21.53168106], [74.20831299, 21.53128052], [74.20797729, 21.5309124], [74.20762634, 21.53050995], [74.20726013, 21.53009987], [74.2069397, 21.52975082], [74.20617676, 21.52930069], [74.20523834, 21.52921104], [74.204216, 21.52924919], [74.20314789, 21.52939034], [74.20211792, 21.52963066], [74.20115662, 21.5299511], [74.20030975, 21.53033829], [74.19969177, 21.53100014], [74.19930267, 21.53193855], [74.19901276, 21.53290939], [74.19890594, 21.53342056], [74.19882965, 21.53383064], [74.1987915, 21.53420067], [74.19873047, 21.53475952], [74.19869995, 21.5352211], [74.19866943, 21.53570938], [74.19860077, 21.5366497], [74.19850159, 21.53759956], [74.19831848, 21.53849983], [74.19801331, 21.53938103], [74.19758606, 21.5402298], [74.19711304, 21.54107285], [74.19654083, 21.54186058], [74.19595337, 21.54261971], [74.19532013, 21.54334068], [74.19464111, 21.54402924], [74.19391632, 21.54470825], [74.1932373, 21.5453701], [74.19251251, 21.54603958], [74.19184875, 21.54673958], [74.19122314, 21.54746819], [74.19068146, 21.54823112], [74.19011688, 21.54902267], [74.18961334, 21.54982758], [74.18933105, 21.55027962], [74.18910217, 21.55065918], [74.18863678, 21.55150032], [74.18821716, 21.552351], [74.18782806, 21.55321121], [74.18750763, 21.55409813], [74.18736267, 21.55505943], [74.18725586, 21.5560627], [74.18718719, 21.55706024], [74.18704987, 21.5580101], [74.1867981, 21.55887032], [74.18634033, 21.55960083], [74.18569183, 21.56021118], [74.18483734, 21.5607605], [74.18387604, 21.56121063], [74.18286896, 21.56155968], [74.18183136, 21.56176949], [74.18081665, 21.56183815], [74.17984772, 21.56183052], [74.17888641, 21.56182098], [74.1778717, 21.56178093], [74.17687988, 21.56175041], [74.1758728, 21.56167984], [74.17485809, 21.56161118], [74.17383575, 21.56153107], [74.17282104, 21.56142807], [74.17182159, 21.56132126], [74.17079926, 21.56118011], [74.17034149, 21.56112099], [74.1697998, 21.56104279], [74.16945648, 21.56098938], [74.16879272, 21.56088066], [74.1678009, 21.56072044], [74.16681671, 21.56052971], [74.16584778, 21.5603199], [74.16488647, 21.56010056], [74.16394806, 21.55986023], [74.16301727, 21.55960083], [74.16213989, 21.55927086], [74.16133118, 21.55875969], [74.16057587, 21.55813026], [74.15988922, 21.55741119], [74.15921021, 21.55665016], [74.15854645, 21.55587959], [74.15789795, 21.55517006], [74.15735626, 21.55438042], [74.15686035, 21.5535202], [74.15632629, 21.55273056], [74.15563965, 21.55212975], [74.15473938, 21.55171967], [74.1537323, 21.55143166], [74.15276337, 21.55122948], [74.15180206, 21.55105019], [74.15078735, 21.5508709], [74.14980316, 21.55070114], [74.14879608, 21.55056953], [74.14782715, 21.55045128], [74.14681244, 21.55038071], [74.14582825, 21.55034065], [74.14483643, 21.55034065], [74.14444733, 21.55035973], [74.14380646, 21.55038071], [74.14274597, 21.55046082], [74.14170074, 21.55060959], [74.14071655, 21.55085945], [74.13983917, 21.5512104], [74.13910675, 21.55173111], [74.1385498, 21.55251122], [74.13809967, 21.55348015], [74.1377182, 21.55450058], [74.13729858, 21.55548096], [74.13677216, 21.55623055], [74.13609314, 21.55669975], [74.1352005, 21.55688095], [74.13430786, 21.55698013], [74.13334656, 21.55702972], [74.13288116, 21.55701828], [74.13240051, 21.55701828], [74.13143921, 21.5569706], [74.13041687, 21.55689049], [74.12940979, 21.5567894], [74.12840271, 21.55665016], [74.12734985, 21.55649948], [74.12631989, 21.55636024], [74.12526703, 21.55622101], [74.1242218, 21.55607986], [74.12319183, 21.55598068], [74.12216949, 21.55590057], [74.12114716, 21.55584908], [74.12016296, 21.55586052], [74.11917114, 21.55590057], [74.11821747, 21.55615044], [74.11728668, 21.55652809], [74.11637115, 21.5569706], [74.11546326, 21.55744171], [74.11453247, 21.55783081], [74.11358643, 21.55809975], [74.11260986, 21.55815125], [74.11160278, 21.55815125], [74.11062622, 21.55813026], [74.10964203, 21.55811119], [74.10913849, 21.55808067], [74.10864258, 21.55804825], [74.10813904, 21.55801964], [74.10765839, 21.55798912], [74.10665894, 21.55792236], [74.10566711, 21.55784035], [74.10463715, 21.55774117], [74.10367584, 21.55763817], [74.10264587, 21.55754089], [74.10166931, 21.55742836], [74.10064697, 21.55731964], [74.09966278, 21.55721092], [74.09866333, 21.5571003], [74.09764862, 21.55700111], [74.0966568, 21.55690956], [74.09564972, 21.55682182], [74.0946579, 21.55673981], [74.09416199, 21.5567112], [74.09365082, 21.55668259], [74.09321594, 21.55665016], [74.09266663, 21.55661964], [74.09168243, 21.55657959], [74.09068298, 21.55655289], [74.08970642, 21.55656052], [74.08914185, 21.55657005], [74.08872223, 21.55657005], [74.08776855, 21.55677032], [74.08683014, 21.55714035], [74.08592987, 21.55758286], [74.08522797, 21.5579319], [74.08502197, 21.55804062], [74.08407593, 21.55842972], [74.08315277, 21.55869293], [74.08216095, 21.5588398], [74.08117676, 21.5589695], [74.08019257, 21.55907822], [74.07920837, 21.55919075], [74.07818604, 21.55927086], [74.07727051, 21.55933952], [74.07621002, 21.55941963], [74.07518768, 21.55945969], [74.07483673, 21.55948067], [74.07418823, 21.55949974], [74.07367706, 21.55952263], [74.07318115, 21.55953026], [74.07285309, 21.55953026], [74.07218933, 21.55953979], [74.07118988, 21.55953979], [74.07019043, 21.55953979], [74.06978607, 21.55953026], [74.06920624, 21.55950928], [74.06822205, 21.55937195], [74.06723022, 21.55914116], [74.06626892, 21.55886078], [74.06534576, 21.55852127], [74.06440735, 21.55817986], [74.06349945, 21.55779266], [74.06260681, 21.55738068], [74.0617218, 21.55695152], [74.06082916, 21.55652046], [74.05993652, 21.5560894], [74.05905914, 21.55568123], [74.0542984, 21.5521698], [74.04714966, 21.54968071], [74.04168701, 21.55134964], [74.02555847, 21.55261993], [74.0190506, 21.55051041], [74.00534058, 21.54076958], [73.98352051, 21.54204178], [73.98178864, 21.53977013], [73.98252106, 21.53573036], [73.9875412, 21.52240944], [73.98568726, 21.5213604], [73.98219299, 21.5218029], [73.97445679, 21.52408028], [73.97335815, 21.53141022], [73.96985626, 21.5385685], [73.96631622, 21.53907013], [73.96276093, 21.53787994], [73.96111298, 21.51929855], [73.95728302, 21.51647186], [73.95358276, 21.51580048], [73.93940735, 21.51011086], [73.93762207, 21.5206604], [73.93614197, 21.52244949], [73.93377686, 21.52359009], [73.93099213, 21.52299118], [73.92839813, 21.52062988], [73.9260788, 21.51959991], [73.91047668, 21.52017021], [73.91004944, 21.51330185], [73.9036026, 21.50875282], [73.89707184, 21.50604248], [73.8866272, 21.50468063], [73.88256836, 21.50978279], [73.88020325, 21.5078907], [73.87684631, 21.50118828], [73.87030029, 21.49725914], [73.86078644, 21.49582291], [73.85401154, 21.50726128], [73.84989166, 21.51098061], [73.84503174, 21.5215683], [73.84015656, 21.5369091], [73.83376312, 21.55348015], [73.82905579, 21.57295036], [73.82450104, 21.59828949], [73.82315063, 21.6006794], [73.81845093, 21.60233116], [73.80683899, 21.60237122], [73.79057312, 21.61850929], [73.78952789, 21.62091064], [73.78761292, 21.62504959], [73.79086304, 21.6287899], [73.80013275, 21.63463974], [73.80882263, 21.63571167], [73.8290329, 21.63978958], [73.83854675, 21.63537979], [73.84523773, 21.63315964], [73.8530426, 21.63586998], [73.86025238, 21.64184761], [73.87026978, 21.63879013], [73.88562775, 21.64505959], [73.89126587, 21.65151024], [73.89444733, 21.6570797], [73.89810181, 21.66727066], [73.8963623, 21.70028114], [73.89396667, 21.70314026], [73.8902359, 21.71064949], [73.88504791, 21.71442986], [73.8783493, 21.71693039], [73.87123108, 21.72191811], [73.86511993, 21.72937965], [73.86029816, 21.73301125], [73.85633087, 21.73464012], [73.84635925, 21.74200058], [73.83120728, 21.76288986], [73.84129333, 21.76865005], [73.84294891, 21.77213097], [73.83837891, 21.7841301], [73.8441391, 21.78711128], [73.84496307, 21.79068184], [73.83567047, 21.79347992], [73.83421326, 21.79661179], [73.83893585, 21.8001709], [73.83351898, 21.80516052], [73.83210754, 21.81085014], [73.82759857, 21.81193924], [73.81759644, 21.80850029], [73.81356812, 21.81011963], [73.81051636, 21.82333755], [73.8162384, 21.82856941], [73.82792664, 21.83485985], [73.84152222, 21.83850098], [73.86374664, 21.83665085], [73.87960052, 21.83864021], [73.89951324, 21.85449028], [73.90666962, 21.85363007], [73.92192841, 21.85658264], [73.93636322, 21.86314964], [73.9491806, 21.87034035], [73.9608078, 21.87599182], [73.97973633, 21.88750076], [74.00489044, 21.89936066], [74.01168823, 21.9005394], [74.02304077, 21.90597153], [74.03560638, 21.9160099], [74.04666901, 21.9228096], [74.056427, 21.92641068], [74.06162262, 21.92805099], [74.07151031, 21.92960167], [74.09867096, 21.9376297], [74.11364746, 21.94470024], [74.13816071, 21.95337105], [74.14601898, 21.9540596], [74.14702606, 21.95404053], [74.14803314, 21.95404053], [74.14904022, 21.95403099], [74.15003204, 21.95401001], [74.15101624, 21.95396042], [74.15202332, 21.95386124], [74.15302277, 21.95369911], [74.15400696, 21.95356941], [74.15500641, 21.95334816], [74.15598297, 21.95310974], [74.15692139, 21.95280075], [74.1578064, 21.95240974], [74.15872192, 21.95201111], [74.15962219, 21.95158958], [74.1605072, 21.95116997], [74.16140747, 21.95074081], [74.16226959, 21.95030022], [74.16316223, 21.94985008], [74.16404724, 21.94939995], [74.16490936, 21.94893837], [74.16578674, 21.94846153], [74.16665649, 21.94800949], [74.16752625, 21.94752121], [74.168396, 21.94704056], [74.16924286, 21.94655037], [74.17011261, 21.94608116], [74.17095184, 21.94557953], [74.17179108, 21.94509125], [74.17260742, 21.94454956], [74.17343903, 21.94398117], [74.17418671, 21.94338036], [74.17494202, 21.94273186], [74.17563629, 21.94205284], [74.17624664, 21.9413414], [74.17681122, 21.94055939], [74.17735291, 21.93976021], [74.1778717, 21.93894958], [74.1783905, 21.93814087], [74.17893219, 21.93735123], [74.17952728, 21.93661118], [74.18016052, 21.93588066], [74.18080902, 21.93514061], [74.18144226, 21.93439102], [74.18206787, 21.93365097], [74.18273163, 21.93292046], [74.18341827, 21.93219948], [74.18408966, 21.93151093], [74.18480682, 21.93084145], [74.18554688, 21.93022156], [74.18630981, 21.92963982], [74.18708801, 21.92910767], [74.18792725, 21.92864037], [74.18882751, 21.92822266], [74.18974304, 21.92790031], [74.19069672, 21.92760277], [74.19169617, 21.92733955], [74.19268799, 21.92711067], [74.19367981, 21.92690086], [74.19467926, 21.92671013], [74.19567108, 21.92651939], [74.1966629, 21.9263382], [74.19763947, 21.92613983], [74.19863129, 21.92597008], [74.19962311, 21.92580032], [74.20063782, 21.92564964], [74.20163727, 21.92552948], [74.20262146, 21.92543983], [74.20362091, 21.92539978], [74.20464325, 21.92541122], [74.20561981, 21.92547035], [74.20658875, 21.92557907], [74.20758057, 21.92571831], [74.20855713, 21.9258709], [74.20952606, 21.92605972], [74.21051788, 21.92624092], [74.21147919, 21.92645073], [74.21246338, 21.92666054], [74.21343231, 21.92687988], [74.21440887, 21.92712021], [74.21539307, 21.92736053], [74.21636963, 21.92759132], [74.21733093, 21.92784119], [74.2183075, 21.92809105], [74.21927643, 21.92831993], [74.22026825, 21.92855072], [74.22122955, 21.9287796], [74.22219849, 21.92900085], [74.22319031, 21.92920113], [74.22416687, 21.92941284], [74.2251358, 21.92958832], [74.22614288, 21.92975998], [74.22709656, 21.92990112], [74.22809601, 21.93000984], [74.22908783, 21.93004036], [74.23008728, 21.93001938], [74.23108673, 21.92996025], [74.23208618, 21.92988014], [74.23310852, 21.92978096], [74.23412323, 21.92970085], [74.23510742, 21.92963982], [74.23610687, 21.92963028], [74.23710632, 21.9296608], [74.23809052, 21.92975998], [74.2390976, 21.92987061], [74.24009705, 21.92999077], [74.24108124, 21.93011093], [74.24208069, 21.93025017], [74.24304199, 21.9303894], [74.24402618, 21.93053055], [74.24503326, 21.93069077], [74.24603271, 21.93084145], [74.24700165, 21.9310112], [74.24798584, 21.93117905], [74.2489624, 21.93134117], [74.24994659, 21.93149948], [74.25093079, 21.93168259], [74.25193024, 21.93182945], [74.2529068, 21.93200111], [74.25390625, 21.93214989], [74.25489044, 21.9323101], [74.255867, 21.93244171], [74.25686646, 21.93259048], [74.25785828, 21.93272972], [74.25885773, 21.93285179], [74.25985718, 21.93296051], [74.26085663, 21.93307114], [74.26183319, 21.93317032], [74.26284027, 21.9332695], [74.26383972, 21.93336105], [74.26483154, 21.93344116], [74.26584625, 21.93352127], [74.26685333, 21.93359756], [74.26786041, 21.93366814], [74.26888275, 21.93374062], [74.26988983, 21.93380928], [74.27086639, 21.93388176], [74.27189636, 21.93394089], [74.27288818, 21.93401909], [74.27390289, 21.93409157], [74.27490997, 21.93416023], [74.27591705, 21.9342308], [74.2769165, 21.93429947], [74.27793121, 21.93437958], [74.27893066, 21.93445969], [74.27992249, 21.93455124], [74.28092194, 21.93464088], [74.28190613, 21.93474007], [74.28291321, 21.93483925], [74.2838974, 21.93494987], [74.28486633, 21.93507957], [74.2858429, 21.93518829], [74.28681946, 21.93534279], [74.28779602, 21.93548012], [74.28874969, 21.9356308], [74.289711, 21.93579102], [74.29064941, 21.93605995], [74.29148865, 21.93658257], [74.29225922, 21.93725014], [74.29290771, 21.93806076], [74.29345703, 21.93888092], [74.29387665, 21.93970108], [74.29425812, 21.94055939], [74.29454803, 21.94145012], [74.29480743, 21.94236755], [74.29502106, 21.94330025], [74.29521179, 21.94425011], [74.29538727, 21.94518089], [74.29559326, 21.94609833], [74.2957077, 21.94703293], [74.29585266, 21.94795036], [74.29593658, 21.94889069], [74.29603577, 21.9498291], [74.29611969, 21.95075989], [74.29621124, 21.9516983], [74.29631042, 21.952631], [74.29641724, 21.95356941], [74.29656982, 21.95449066], [74.29677582, 21.95540047], [74.29696655, 21.95631027], [74.29721069, 21.95721817], [74.29749298, 21.95813179], [74.29776001, 21.95903015], [74.29808044, 21.95992088], [74.2984314, 21.96081924], [74.29875946, 21.9616909], [74.29910278, 21.96257019], [74.29947662, 21.96344948], [74.29987335, 21.96433067], [74.3003006, 21.9652195], [74.30079651, 21.9660511], [74.30136108, 21.96680069], [74.3020401, 21.96743965], [74.30280304, 21.96804047], [74.30358887, 21.9686203], [74.30439758, 21.96917915], [74.30523682, 21.96972084], [74.30610657, 21.97022057], [74.30699921, 21.97068977], [74.3079071, 21.97113037], [74.30883026, 21.97151947], [74.30976105, 21.97186089], [74.31067657, 21.9721508], [74.31165314, 21.97240067], [74.31260681, 21.9726181], [74.31356812, 21.97281075], [74.31455231, 21.97296906], [74.31555176, 21.97310066], [74.31655121, 21.97323036], [74.31755829, 21.97333145], [74.318573, 21.9734211], [74.31958008, 21.97352028], [74.32058716, 21.97359085], [74.32158661, 21.97364998], [74.32260132, 21.97372818], [74.32359314, 21.97383118], [74.32459259, 21.97392082], [74.32557678, 21.97397995], [74.3265686, 21.97405052], [74.32758331, 21.97412109], [74.32858276, 21.97417259], [74.32958984, 21.97421837], [74.33058167, 21.97426987], [74.33158875, 21.97431946], [74.33258057, 21.97437286], [74.33360291, 21.97441101], [74.3345871, 21.97445107], [74.33557892, 21.97451019], [74.33660126, 21.97455025], [74.33757782, 21.97459984], [74.33859253, 21.97466278], [74.33957672, 21.97470856], [74.34057617, 21.97477913], [74.34158325, 21.97486115], [74.3425827, 21.97492027], [74.34358215, 21.97500992], [74.34455109, 21.97509956], [74.34555817, 21.97521973], [74.3465271, 21.97541046], [74.34749603, 21.97565079], [74.34844971, 21.97599983], [74.3493576, 21.97639084], [74.35024261, 21.97682953], [74.35114288, 21.97729111], [74.35202026, 21.97774124], [74.35289764, 21.97821045], [74.35378265, 21.9786911], [74.35463715, 21.97919846], [74.35546112, 21.97972107], [74.35626221, 21.98028946], [74.35700989, 21.98088074], [74.35775757, 21.98151016], [74.35842133, 21.98220062], [74.35901642, 21.98291969], [74.35962677, 21.98368073], [74.36019135, 21.98446274], [74.36074829, 21.98526001], [74.36126709, 21.98608017], [74.36180878, 21.98689079], [74.36235046, 21.98769951], [74.36286926, 21.9885006], [74.36342621, 21.98929024], [74.36400604, 21.99003983], [74.36463928, 21.9907608], [74.36531067, 21.99144173], [74.3660202, 21.99204063], [74.36685181, 21.99253082], [74.36778259, 21.99291039], [74.36875916, 21.99324989], [74.36974335, 21.99356842], [74.37069702, 21.99391937], [74.37159729, 21.9943428], [74.37238312, 21.99487114], [74.37310791, 21.99549103], [74.37375641, 21.99618912], [74.37438202, 21.9969101], [74.37496185, 21.99767113], [74.37552643, 21.99843979], [74.37609863, 21.99925041], [74.37664032, 22.00004005], [74.37718964, 22.00085068], [74.37818146, 22.00217056], [74.38366699, 22.01175117], [74.38831329, 22.02017975], [74.3964386, 22.02370262], [74.40651703, 22.02440071], [74.4177475, 22.02581024], [74.43554688, 22.03099823], [74.43945313, 22.02651978], [74.44603729, 22.02651978], [74.44255829, 22.02160072], [74.44451904, 22.01599121], [74.44764709, 22.01247978], [74.45150757, 22.00896835], [74.45381927, 22.00617027], [74.45391846, 22.00226974], [74.44995117, 22.00546265], [74.44573212, 22.0068512], [74.44380951, 22.00616074], [74.43621826, 22.00222969], [74.4362793, 21.9994812], [74.44107819, 21.99644089], [74.44262695, 21.99362946], [74.44303894, 21.98306847], [74.4471817, 21.97627068], [74.44863892, 21.97113037], [74.45170593, 21.96750069], [74.45996857, 21.9628315], [74.4641571, 21.96321106], [74.4673233, 21.96479988], [74.47218323, 21.96552086], [74.47512054, 21.96270943], [74.4778595, 21.96154976], [74.48293304, 21.96244049], [74.48449707, 21.96075058], [74.48568726, 21.95753288], [74.48928833, 21.95676041], [74.49340057, 21.95449066], [74.48985291, 21.94714928], [74.49233246, 21.94546127], [74.4967804, 21.94641113], [74.51555634, 21.93391991], [74.51560974, 21.9278717], [74.51464081, 21.92246819], [74.51735687, 21.91755104], [74.52398682, 21.91306114], [74.52749634, 21.90878105], [74.52746582, 21.90345001], [74.52146912, 21.89550972], [74.51843262, 21.89011002], [74.51776123, 21.88624001], [74.51747894, 21.87490082], [74.51699829, 21.85649109], [74.51181793, 21.82122993], [74.50932312, 21.81587982], [74.50364685, 21.80718231], [74.50315857, 21.79780006], [74.50596619, 21.78260994], [74.5063324, 21.78174019], [74.50665283, 21.78083038], [74.50695801, 21.77993965], [74.50728607, 21.77902985], [74.50763702, 21.77814102], [74.50800323, 21.77726936], [74.50840759, 21.77642822], [74.50888062, 21.77561951], [74.50946045, 21.77490807], [74.51021576, 21.77427101], [74.51101685, 21.77370071], [74.51185608, 21.77312088], [74.51257324, 21.77247047], [74.51320648, 21.77176094], [74.51393127, 21.77103043], [74.51463318, 21.77030945], [74.51529694, 21.7695694], [74.51596832, 21.76880074], [74.5165329, 21.76803017], [74.51700592, 21.76723099], [74.51735687, 21.76639938], [74.51759338, 21.76554108], [74.51773071, 21.76463127], [74.51786041, 21.76370811], [74.51789856, 21.76276016], [74.51790619, 21.76178932], [74.5178833, 21.76083183], [74.51780701, 21.75987053], [74.51769257, 21.75889969], [74.5175705, 21.75794029], [74.51740265, 21.75699997], [74.51721191, 21.75608063], [74.51700592, 21.75518036], [74.5166626, 21.75435066], [74.51599121, 21.75361061], [74.51516724, 21.75293922], [74.51436615, 21.75226021], [74.51378632, 21.75152969], [74.51352692, 21.75069046], [74.51348877, 21.74981117], [74.51354218, 21.7489109], [74.51365662, 21.74798012], [74.51386261, 21.74703979], [74.51407623, 21.74608994], [74.51426697, 21.74513054], [74.51447296, 21.74416924], [74.51461792, 21.74323082], [74.5147171, 21.74228096], [74.5147171, 21.74135017], [74.51463318, 21.74043083], [74.51447296, 21.73950958], [74.51425934, 21.73858261], [74.51403809, 21.7376709], [74.5137558, 21.73676109], [74.51348877, 21.73582268], [74.51317596, 21.73490906], [74.51286316, 21.73398018], [74.51255798, 21.73307991], [74.51226807, 21.73216248], [74.51197815, 21.73125076], [74.51174927, 21.73033905], [74.51152039, 21.72944069], [74.51135254, 21.72854805], [74.51125336, 21.72764969], [74.51122284, 21.72674942], [74.51138306, 21.72585106], [74.5117569, 21.72495079], [74.51226044, 21.72409058], [74.51288605, 21.72326088], [74.51352692, 21.72253036], [74.51422119, 21.72187996], [74.5149765, 21.72128105], [74.51583862, 21.72076035], [74.516716, 21.72029114], [74.51763153, 21.71986961], [74.51854706, 21.71947098], [74.51947784, 21.71911049], [74.52041626, 21.71879005], [74.52139282, 21.71850967], [74.5223465, 21.7182827], [74.52333832, 21.71808052], [74.52433014, 21.7179184], [74.5253067, 21.71780968], [74.52630615, 21.71772194], [74.52731323, 21.71763039], [74.52832031, 21.7175827], [74.52929688, 21.71754074], [74.53031921, 21.71747971], [74.53131866, 21.71747017], [74.53231049, 21.71747017], [74.53333282, 21.71749115], [74.53431702, 21.71754074], [74.53530884, 21.7175827], [74.53631592, 21.71769905], [74.53734589, 21.71787071], [74.53839111, 21.71809006], [74.53943634, 21.71832848], [74.54049683, 21.71861076], [74.54155731, 21.7188797], [74.5426178, 21.71915054], [74.54366302, 21.71940994], [74.5446701, 21.71965027], [74.54567719, 21.71982956], [74.54664612, 21.7199707], [74.54762268, 21.72002983], [74.54852295, 21.72002983], [74.54940033, 21.7199192], [74.55020142, 21.71970749], [74.55098724, 21.71939278], [74.55171967, 21.71894836], [74.55237579, 21.71839905], [74.55303192, 21.71774101], [74.55362701, 21.71701813], [74.55417633, 21.71623039], [74.55471039, 21.71537018], [74.55522919, 21.71447945], [74.55573273, 21.71355057], [74.55621338, 21.71261024], [74.55667877, 21.71166992], [74.55713654, 21.71073914], [74.55760956, 21.70984077], [74.55806732, 21.70898056], [74.55856323, 21.7081604], [74.55903625, 21.70730972], [74.55948639, 21.70646286], [74.55989838, 21.70560074], [74.56024933, 21.70470047], [74.56056976, 21.7038002], [74.56079865, 21.7028904], [74.56096649, 21.70198059], [74.5610733, 21.7010498], [74.56115723, 21.70012093], [74.56124878, 21.69915962], [74.5613327, 21.69820023], [74.56137848, 21.69722939], [74.56141663, 21.69627953], [74.5614624, 21.69530106], [74.56147003, 21.69433975], [74.56143951, 21.69338989], [74.56137848, 21.69244194], [74.56130981, 21.69151115], [74.56121063, 21.69059944], [74.56105804, 21.68970108], [74.56086731, 21.68882751], [74.56054688, 21.68799019], [74.55977631, 21.68729019], [74.55877686, 21.68667984], [74.55773926, 21.68610954], [74.5569458, 21.68555069], [74.55661011, 21.68494034], [74.55680084, 21.68425941], [74.55729675, 21.68353271], [74.55800629, 21.68279076], [74.55887604, 21.68208122], [74.55980682, 21.68143082], [74.56072998, 21.68086052], [74.56160736, 21.68042183], [74.5626297, 21.68008995], [74.56371307, 21.67990112], [74.56476593, 21.67984962], [74.56569672, 21.67996025], [74.56626129, 21.68045044], [74.56636047, 21.68153954], [74.56652069, 21.68259811], [74.56726074, 21.68302917], [74.56813812, 21.68332291], [74.56906128, 21.68357086], [74.57000732, 21.68380165], [74.57099152, 21.68399048], [74.57200623, 21.68416023], [74.57302094, 21.68431091], [74.5740509, 21.68443108], [74.57507324, 21.68456268], [74.57611847, 21.68466949], [74.57713318, 21.68478012], [74.57814026, 21.68486977], [74.5791626, 21.68499947], [74.58027649, 21.68514061], [74.58141327, 21.68527031], [74.58248901, 21.68527985], [74.58345032, 21.68513107], [74.58416748, 21.68474007], [74.58470154, 21.68412018], [74.5851593, 21.68338013], [74.58557129, 21.68254089], [74.58589935, 21.68163109], [74.5861969, 21.68066025], [74.58644104, 21.6796627], [74.58661652, 21.67865944], [74.58677673, 21.6776619], [74.58689117, 21.67670059], [74.58693695, 21.67579269], [74.58670044, 21.67485809], [74.58627319, 21.67391968], [74.58579254, 21.67300034], [74.58547211, 21.6721096], [74.58545685, 21.67124939], [74.58574677, 21.67041016], [74.58615112, 21.66953087], [74.58657074, 21.66862106], [74.58708954, 21.66772079], [74.587677, 21.66683006], [74.58831024, 21.66601944], [74.58899689, 21.66526985], [74.58976746, 21.66464806], [74.59055328, 21.66415977], [74.59140778, 21.66383171], [74.59227753, 21.66358948], [74.59319305, 21.66340828], [74.5941391, 21.66328049], [74.59509277, 21.66321182], [74.59607697, 21.66316986], [74.59709167, 21.66316986], [74.59809875, 21.66319847], [74.59913635, 21.6632309], [74.60018921, 21.66328049], [74.60122681, 21.66332817], [74.60227966, 21.66337967], [74.60330963, 21.66341972], [74.60434723, 21.66343117], [74.6053772, 21.66341972], [74.60639954, 21.66337967], [74.60742188, 21.66328049], [74.60839844, 21.66315269], [74.60939026, 21.66299057], [74.61036682, 21.66282082], [74.61134338, 21.66263008], [74.61231232, 21.66246033], [74.61329651, 21.66226006], [74.61427307, 21.66205025], [74.615242, 21.66184044], [74.61621094, 21.66163063], [74.61717987, 21.66139984], [74.61814117, 21.66118813], [74.619133, 21.66094971], [74.62008667, 21.66070747], [74.62106323, 21.66047096], [74.62201691, 21.66023064], [74.6230011, 21.65999985], [74.6239624, 21.65975952], [74.62494659, 21.6595211], [74.6259079, 21.65928268], [74.62687683, 21.65904808], [74.62784576, 21.65882111], [74.62882233, 21.65859032], [74.62980652, 21.65835953], [74.63076019, 21.65814018], [74.63173676, 21.65793037], [74.63269806, 21.6577282], [74.63368988, 21.65752029], [74.63465118, 21.65733147], [74.63564301, 21.65715027], [74.63661194, 21.65698051], [74.63761139, 21.6568203], [74.63858032, 21.65666008], [74.6395874, 21.6565094], [74.64057159, 21.65637016], [74.64155579, 21.65624046], [74.64254761, 21.65610123], [74.6435318, 21.65596962], [74.64453888, 21.65583992], [74.6455307, 21.6557312], [74.64650726, 21.65559959], [74.64749908, 21.6554718], [74.64850616, 21.65534973], [74.64949036, 21.65522957], [74.65046692, 21.6551075], [74.65146637, 21.65497971], [74.65245819, 21.65484047], [74.65342712, 21.65471077], [74.65444946, 21.65457153], [74.65542603, 21.65442085], [74.65643311, 21.65427017], [74.65740204, 21.65410042], [74.65837097, 21.65393066], [74.6593399, 21.65374947], [74.66033173, 21.6535511], [74.66131592, 21.65335083], [74.66227722, 21.65312195], [74.66326141, 21.65287018], [74.66420746, 21.65261078], [74.66517639, 21.65232086], [74.66612244, 21.6520195], [74.66706085, 21.65168953], [74.66797638, 21.65134048], [74.66887665, 21.65097046], [74.66977692, 21.65055847], [74.67066193, 21.65011024], [74.67151642, 21.64965057], [74.67237091, 21.64915085], [74.67320251, 21.64862061], [74.67402649, 21.6480999], [74.67487335, 21.64754295], [74.67565918, 21.64698982], [74.67648315, 21.64641953], [74.6772995, 21.64587975], [74.67809296, 21.6453228], [74.67888641, 21.64476013], [74.67970276, 21.64418983], [74.68047333, 21.64361954], [74.68126678, 21.6430397], [74.68205261, 21.64245987], [74.68282318, 21.6418705], [74.68360901, 21.64128113], [74.68438721, 21.64069939], [74.68517303, 21.64011002], [74.68596649, 21.63953018], [74.68675232, 21.63894081], [74.68753052, 21.63836098], [74.68830872, 21.63777924], [74.68910217, 21.63721085], [74.68990326, 21.63663292], [74.69069672, 21.63607979], [74.69149017, 21.63552284], [74.69230652, 21.63496017], [74.69313049, 21.63442039], [74.6939621, 21.63389969], [74.69477844, 21.63338089], [74.69564819, 21.6328907], [74.69651794, 21.63240051], [74.69738007, 21.63195038], [74.69827271, 21.63150978], [74.69917297, 21.6310997], [74.70008087, 21.63071823], [74.70101166, 21.63035965], [74.70192719, 21.63002968], [74.70285797, 21.62968826], [74.70379639, 21.6293602], [74.70474243, 21.62905121], [74.70567322, 21.62874985], [74.70662689, 21.62844086], [74.7075882, 21.62816048], [74.70852661, 21.62787056], [74.70948792, 21.62759018], [74.71044922, 21.62732124], [74.71141815, 21.62705994], [74.71237946, 21.62680244], [74.71334076, 21.62654114], [74.71430206, 21.62629128], [74.71527863, 21.62606049], [74.71624756, 21.62581062], [74.71720886, 21.62559128], [74.71816254, 21.62537003], [74.71914673, 21.62512016], [74.72012329, 21.62489128], [74.72107697, 21.62467194], [74.72203827, 21.62445068], [74.72302246, 21.62421989], [74.72397614, 21.62399101], [74.72496796, 21.6237812], [74.72592163, 21.62356186], [74.72690582, 21.62334061], [74.72786713, 21.6231308], [74.72885132, 21.62290955], [74.72981262, 21.6226902], [74.73079681, 21.62248039], [74.73177338, 21.62226105], [74.73274231, 21.62205124], [74.73371887, 21.62183952], [74.73468781, 21.62162971], [74.73565674, 21.62142181], [74.73664093, 21.62120056], [74.73761749, 21.62100029], [74.73860168, 21.62079239], [74.73956299, 21.62059021], [74.74053955, 21.62037086], [74.74151611, 21.6201725], [74.74249268, 21.61996078], [74.74346161, 21.61976051], [74.74443817, 21.61955261], [74.7454071, 21.61935043], [74.74637604, 21.61914063], [74.7473526, 21.61894035], [74.74833679, 21.61874008], [74.74931335, 21.61853027], [74.75028992, 21.61832047], [74.75126648, 21.61812973], [74.75224304, 21.61791992], [74.75319672, 21.61771965], [74.75419617, 21.61751938], [74.75515747, 21.61731911], [74.75614929, 21.61712074], [74.75712585, 21.61691093], [74.75808716, 21.6167202], [74.75907898, 21.61651993], [74.76006317, 21.61634064], [74.76104736, 21.61618042], [74.76203156, 21.6160202], [74.76303101, 21.61585808], [74.76399994, 21.61573982], [74.76499939, 21.61561966], [74.76599121, 21.61552048], [74.76698303, 21.61547089], [74.76796722, 21.61541939], [74.76896667, 21.61541176], [74.76996613, 21.61543083], [74.77097321, 21.61547089], [74.77197266, 21.61548042], [74.77297974, 21.61551094], [74.77397156, 21.61553955], [74.77501678, 21.61553955], [74.77593231, 21.61515999], [74.77683258, 21.61475945], [74.77774048, 21.61433029], [74.77863312, 21.61391068], [74.77954865, 21.61349106], [74.78045654, 21.61308098], [74.78137207, 21.61270142], [74.78231049, 21.61235046], [74.78324127, 21.61203194], [74.78417969, 21.61177063], [74.78514862, 21.61156082], [74.78611755, 21.61136055], [74.78710175, 21.61117935], [74.78808594, 21.61102104], [74.7890625, 21.61086082], [74.79007721, 21.61071968], [74.79106903, 21.61058044], [74.792099, 21.61046982], [74.79308319, 21.61033821], [74.79408264, 21.61025047], [74.79509735, 21.61016273], [74.7960968, 21.61009026], [74.79708862, 21.61001968], [74.79808807, 21.60996056], [74.79907227, 21.60989952], [74.80004883, 21.60985947], [74.80103302, 21.60983086], [74.80206299, 21.6100502], [74.80288696, 21.61073112], [74.80306244, 21.61156082], [74.80284119, 21.61255836], [74.80245972, 21.61363029], [74.80207062, 21.61463928], [74.80190277, 21.61548996], [74.80207062, 21.61605072], [74.80287933, 21.61613083], [74.80404663, 21.61586952], [74.8052063, 21.6154995], [74.80613708, 21.61514282], [74.80702209, 21.61469841], [74.8079071, 21.61422157], [74.8087616, 21.61372948], [74.80963135, 21.61326981], [74.81053925, 21.61287117], [74.8114624, 21.6125412], [74.81240845, 21.61225128], [74.81339264, 21.61203194], [74.81437683, 21.61182976], [74.81536865, 21.61164093], [74.81633759, 21.61147118], [74.81732178, 21.61129951], [74.81830597, 21.61112022], [74.81928253, 21.61094093], [74.82028961, 21.61079025], [74.82128906, 21.61063194], [74.82227325, 21.6104908], [74.82327271, 21.61038017], [74.8242569, 21.61029243], [74.82524109, 21.61021042], [74.82624054, 21.61018944], [74.82726288, 21.61018944], [74.82836151, 21.61021042], [74.82946777, 21.61029243], [74.83055878, 21.61041832], [74.83156586, 21.6106205], [74.8324585, 21.61090088], [74.83320618, 21.61129951], [74.83367157, 21.61186028], [74.83368683, 21.61273956], [74.83348846, 21.61379051], [74.83329773, 21.61487007], [74.83336639, 21.61584091], [74.83370972, 21.61669922], [74.83423615, 21.6175518], [74.8348999, 21.61833], [74.83564758, 21.61897087], [74.8365097, 21.61940956], [74.83740997, 21.61979103], [74.83833313, 21.62013054], [74.83924866, 21.62044144], [74.84020233, 21.62072945], [74.84115601, 21.62100983], [74.8421402, 21.62128258], [74.84310913, 21.62153053], [74.84409332, 21.62179947], [74.84506989, 21.62206078], [74.84601593, 21.62232971], [74.84697723, 21.62263107], [74.84793854, 21.62294006], [74.84884644, 21.62327957], [74.84976959, 21.62366104], [74.85066223, 21.62407112], [74.85153198, 21.62451935], [74.85237885, 21.62504005], [74.85321808, 21.62560081], [74.85407257, 21.62619019], [74.85488129, 21.62681007], [74.85568237, 21.62745094], [74.85647583, 21.62811089], [74.85727692, 21.6287899], [74.858078, 21.62944984], [74.85884857, 21.63010979], [74.85964966, 21.63074112], [74.86038208, 21.63137054], [74.86115265, 21.63195992], [74.86193085, 21.63251114], [74.86266327, 21.6330204], [74.86342621, 21.633461], [74.86415863, 21.6338501], [74.86486053, 21.63402939], [74.86534119, 21.63330269], [74.86575317, 21.63212013], [74.86630249, 21.63112068], [74.86709595, 21.63074112], [74.8680191, 21.6305294], [74.8690033, 21.63039017], [74.87001038, 21.63029099], [74.87106323, 21.63023949], [74.8720932, 21.63023949], [74.87312317, 21.63026047], [74.87415314, 21.63029099], [74.87516022, 21.63034058], [74.87613678, 21.63043976], [74.87713623, 21.63059044], [74.87812805, 21.63078117], [74.87909698, 21.63099098], [74.88006592, 21.63120079], [74.88105774, 21.6314106], [74.88204956, 21.63158035], [74.88302612, 21.63171959], [74.88401031, 21.63179016], [74.8850174, 21.6317997], [74.88601685, 21.6317997], [74.8870163, 21.6317997], [74.88803101, 21.63178253], [74.88903809, 21.63175964], [74.8900528, 21.63171959], [74.89105988, 21.63167953], [74.89208221, 21.63162994], [74.89309692, 21.63155937], [74.89411926, 21.63146973], [74.89512634, 21.63138962], [74.89610291, 21.6312809], [74.8970871, 21.63116264], [74.89807129, 21.63101959], [74.89904785, 21.63086128], [74.90001678, 21.63068962], [74.90093994, 21.63047981], [74.90187836, 21.63022995], [74.90276337, 21.6298008], [74.90358734, 21.62922287], [74.90434265, 21.6285305], [74.90500641, 21.62779045], [74.90563965, 21.62702942], [74.90618134, 21.62625122], [74.90661621, 21.62543106], [74.90703583, 21.6245594], [74.90743256, 21.62366104], [74.9078064, 21.62277031], [74.90818024, 21.62187958], [74.90860748, 21.62102127], [74.90907288, 21.62020111], [74.90962219, 21.61944962], [74.91026306, 21.61876106], [74.91095734, 21.61811066], [74.91172791, 21.61749077], [74.9125061, 21.61689949], [74.91333771, 21.61634064], [74.91416168, 21.61580849], [74.91504669, 21.61531067], [74.91591644, 21.61482811], [74.91680145, 21.61437988], [74.91770172, 21.61395264], [74.9185791, 21.61352921], [74.91947937, 21.61314011], [74.92038727, 21.61275101], [74.9213028, 21.61236954], [74.92222595, 21.61202049], [74.92314911, 21.6116581], [74.92408752, 21.61131859], [74.92502594, 21.61099052], [74.92595673, 21.61065292], [74.92691803, 21.61033821], [74.92785645, 21.61003113], [74.92880249, 21.60972023], [74.92974091, 21.60942078], [74.93067932, 21.60910034], [74.931633, 21.60880089], [74.93258667, 21.6084919], [74.93353271, 21.60819054], [74.93447113, 21.60787964], [74.93541718, 21.60757065], [74.93636322, 21.60728073], [74.93731689, 21.60697174], [74.93824768, 21.60667038], [74.93920135, 21.60637093], [74.94016266, 21.60608292], [74.94108582, 21.60577965], [74.94204712, 21.60548973], [74.94300079, 21.60518265], [74.94394684, 21.60490036], [74.94489288, 21.60460091], [74.94584656, 21.60432053], [74.94682312, 21.60403061], [74.94776154, 21.60375023], [74.94869995, 21.60346985], [74.94966888, 21.60318184], [74.9506073, 21.6029129], [74.95157623, 21.60263062], [74.95252991, 21.60235023], [74.95349884, 21.60207939], [74.95443726, 21.60181046], [74.95539856, 21.60155106], [74.95635986, 21.60128975], [74.95732117, 21.60103035], [74.95826721, 21.60077286], [74.95923615, 21.60050964], [74.96018982, 21.60026932], [74.96116638, 21.60001945], [74.96214294, 21.59980965], [74.96312714, 21.59959984], [74.96408844, 21.59941101], [74.96507263, 21.5992012], [74.96604919, 21.5990181], [74.96702576, 21.59883118], [74.96800232, 21.59864998], [74.96898651, 21.59847069], [74.96997833, 21.59828949], [74.97096252, 21.59811974], [74.97194672, 21.59793282], [74.97293091, 21.59774971], [74.97390747, 21.59756088], [74.9748764, 21.59737015], [74.9758606, 21.59717178], [74.97683716, 21.59696007], [74.97780609, 21.59674072], [74.97875977, 21.59651947], [74.9797287, 21.59626961], [74.98068237, 21.59601974], [74.98162842, 21.59574127], [74.98258972, 21.59546089], [74.98353577, 21.59517288], [74.98449707, 21.59486961], [74.98544312, 21.59456062], [74.98638916, 21.59424973], [74.98731232, 21.59392166], [74.9882431, 21.59358978], [74.98918152, 21.59325027], [74.99011993, 21.59290123], [74.99104309, 21.59255028], [74.99195862, 21.5921917], [74.99289703, 21.59183121], [74.9937973, 21.59144974], [74.99474335, 21.59109116], [74.99565125, 21.59070015], [74.99656677, 21.59033012], [74.99745941, 21.58992958], [74.99835205, 21.58950043], [74.99923706, 21.58905029], [75.00009918, 21.58859062], [75.0009613, 21.58811951], [75.00183105, 21.58764267], [75.00267792, 21.58716965], [75.00356293, 21.58670807], [75.004776, 21.5860424], [75.01341248, 21.5811882], [75.01584625, 21.57788086], [75.01783752, 21.57261086], [75.03183746, 21.56930923], [75.05356598, 21.56719017], [75.05774689, 21.5649395], [75.06018829, 21.55933952], [75.06359863, 21.55500031], [75.06503296, 21.5508194], [75.07221985, 21.54165077], [75.07624054, 21.53801918], [75.07832336, 21.5321312], [75.08355713, 21.52575111], [75.08999634, 21.51433182], [75.09266663, 21.50090981], [75.09487915, 21.49381256], [75.10044098, 21.48531151], [75.10666656, 21.46962929], [75.11509705, 21.45956039], [75.12297821, 21.4533329], [75.129776, 21.44927979], [75.14743805, 21.4433403], [75.15737152, 21.43827248], [75.18802643, 21.42731094], [75.19599915, 21.42285919], [75.20372009, 21.41731834], [75.2074585, 21.41584015], [75.21055603, 21.41422081], [75.21985626, 21.4108696], [75.23226166, 21.41658974], [75.23636627, 21.41710091], [75.24347687, 21.41493988], [75.24768066, 21.41067123], [75.2539978, 21.40613937], [75.2591095, 21.40521812], [75.26702118, 21.4088707], [75.27662659, 21.4088707], [75.28856659, 21.41181183], [75.29162598, 21.41390991], [75.29962921, 21.41566086], [75.30184937, 21.41483116], [75.30316162, 21.39519119], [75.30182648, 21.39241982], [75.30190277, 21.3892498], [75.30866241, 21.39450073], [75.31195831, 21.39528084], [75.32090759, 21.39240265], [75.32681274, 21.39423943], [75.33487701, 21.39466858], [75.35378265, 21.39348984], [75.35800171, 21.3961792], [75.36138153, 21.40323067], [75.36694336, 21.39891052], [75.37866211, 21.39241982], [75.3813324, 21.38763046], [75.38448334, 21.3855896], [75.39308929, 21.38406944], [75.39537811, 21.38467979], [75.39839172, 21.38298035], [75.40091705, 21.3839798], [75.40381622, 21.38377953], [75.40925598, 21.38992119], [75.41337585, 21.3910675], [75.41996765, 21.39027023], [75.43165588, 21.39394951], [75.43628693, 21.39072037], [75.44361877, 21.39101982], [75.44615173, 21.3904705], [75.45007324, 21.39240265], [75.45443726, 21.3920517], [75.46005249, 21.39302254], [75.46559906, 21.39136124], [75.46840668, 21.39420128], [75.48480225, 21.39126015], [75.49643707, 21.39073181], [75.50048828, 21.39157295], [75.51013184, 21.38799286], [75.51628113, 21.38673019], [75.52458191, 21.38716125], [75.52939606, 21.38472939], [75.53994751, 21.37719154], [75.54530334, 21.37579918], [75.54714966, 21.37265968], [75.54814911, 21.37248993], [75.55133057, 21.37544823], [75.555336, 21.37745094], [75.55980682, 21.38226128], [75.56111145, 21.38117027], [75.56027222, 21.37881088], [75.56420898, 21.37809944], [75.56598663, 21.37915039], [75.57209015, 21.37822914], [75.58125305, 21.37985992], [75.5815506, 21.38084984], [75.57655334, 21.38552094], [75.58486176, 21.38759995], [75.5877533, 21.38890076], [75.59126282, 21.3917408], [75.60295105, 21.39052963], [75.60891724, 21.39500046], [75.6194458, 21.39346123], [75.62111664, 21.38787079], [75.62361145, 21.38428116], [75.62679291, 21.38200951], [75.6294632, 21.3812294], [75.63263702, 21.38177109], [75.63986206, 21.38149071], [75.64575958, 21.38247108], [75.65487671, 21.38202095], [75.65882111, 21.38274956], [75.67341614, 21.38035011], [75.67507935, 21.38145065], [75.6784668, 21.38217163], [75.68479156, 21.38223076], [75.68782043, 21.38433075], [75.68972015, 21.38750076], [75.69483185, 21.38956261], [75.70675659, 21.39132118], [75.71385193, 21.3916111], [75.72158813, 21.39099121], [75.72271729, 21.38915253], [75.73294067, 21.39332962], [75.73558044, 21.39270973], [75.73834991, 21.39343262], [75.74408722, 21.39319038], [75.74610138, 21.39171028], [75.75467682, 21.38838959], [75.75894165, 21.38549042], [75.76013947, 21.38570023], [75.7738266, 21.38664818], [75.79220581, 21.38921165], [75.80140686, 21.39015007], [75.80545807, 21.38903046], [75.8125, 21.38733101], [75.83262634, 21.38330078], [75.84342194, 21.38945007], [75.84662628, 21.38813972], [75.85135651, 21.38935089], [75.85932922, 21.38730049], [75.86277771, 21.38730049], [75.86818695, 21.39048958], [75.87226105, 21.39550018], [75.87615204, 21.39819145], [75.88212585, 21.39842987], [75.8881073, 21.39962959], [75.89563751, 21.39874077], [75.89705658, 21.39726067], [75.9050827, 21.39563942], [75.91227722, 21.3906498], [75.91654205, 21.38982773], [75.93234253, 21.39151001], [75.93737793, 21.39286995], [75.94796753, 21.39298058], [75.95939636, 21.39619064], [75.96874237, 21.39397049], [75.98487854, 21.37717819], [75.99160767, 21.3760891], [76.00023651, 21.37481117], [76.01597595, 21.36988258], [76.02749634, 21.36813927], [76.0345993, 21.36527061], [76.04202271, 21.35889244], [76.04704285, 21.35519981], [76.05237579, 21.35270119], [76.06565857, 21.35919952], [76.07724762, 21.36426926], [76.08815002, 21.3699894], [76.095047, 21.37267113], [76.09867096, 21.37392807], [76.10694885, 21.36020279], [76.1159668, 21.33877945], [76.12224579, 21.32163811], [76.12726593, 21.30734062], [76.1292572, 21.29751015], [76.13497162, 21.29150009], [76.13987732, 21.28899956], [76.14499664, 21.28777122], [76.1471405, 21.28137016], [76.14980316, 21.27420998], [76.15386963, 21.26881981], [76.15603638, 21.2632103], [76.15921783, 21.25914192], [76.15809631, 21.25354958], [76.15428925, 21.24913979], [76.15091705, 21.24561119], [76.14412689, 21.24258041], [76.14409637, 21.24147987], [76.14440155, 21.23809052], [76.1455307, 21.23319054], [76.14801025, 21.2316494], [76.15328979, 21.22981834], [76.15933228, 21.22725105], [76.16403198, 21.22417259], [76.16314697, 21.22195053], [76.16152191, 21.21668816], [76.16427612, 21.21181107], [76.16794586, 21.20812035], [76.16770935, 21.20588112], [76.16705322, 21.20358086], [76.16571808, 21.20004845], [76.16590881, 21.19548988], [76.16908264, 21.19188118], [76.17272186, 21.18828964], [76.17063904, 21.18217278], [76.16913605, 21.17448044], [76.16684723, 21.17072105], [76.16088867, 21.17200089], [76.15505981, 21.17256165], [76.14298248, 21.17313194], [76.13070679, 21.17555046], [76.12741852, 21.17791939], [76.1193924, 21.17468071], [76.11431885, 21.17045975], [76.11396027, 21.16464043], [76.11891174, 21.1601181], [76.12409973, 21.15909958], [76.12841797, 21.15670967], [76.13169098, 21.15267944], [76.1399231, 21.14006805], [76.14092255, 21.13602257], [76.13934326, 21.13363075], [76.13417053, 21.1303196], [76.13566589, 21.12621117], [76.14214325, 21.12107086], [76.15146637, 21.11499977], [76.16221619, 21.10996056], [76.16744232, 21.10629845], [76.16845703, 21.10541153], [76.16911316, 21.10371971], [76.16931152, 21.10141945], [76.16927338, 21.09865952], [76.1681366, 21.0932312], [76.16702271, 21.089571], [76.16864777, 21.08582115], [76.17263794, 21.08460045], [76.17727661, 21.08549118], [76.1807785, 21.08741951], [76.18386078, 21.08995056], [76.18907166, 21.09031105], [76.20868683, 21.09017944], [76.22749329, 21.09144974], [76.23510742, 21.09391022], [76.26210785, 21.09470177], [76.26924896, 21.09295082], [76.27324677, 21.08541107], [76.27776337, 21.07802963], [76.2817688, 21.07530975], [76.2857666, 21.07649994], [76.29711914, 21.07718086], [76.33481598, 21.07718086], [76.35697937, 21.07966995], [76.3613205, 21.08000183], [76.36579132, 21.07907104], [76.36862183, 21.07870102], [76.37198639, 21.07855988], [76.37637329, 21.07731056], [76.37961578, 21.07847977], [76.38104248, 21.07907104], [76.38275909, 21.07956123], [76.3901062, 21.08805084], [76.39682007, 21.09057045], [76.40943909, 21.09408951], [76.41182709, 21.10726929], [76.43373871, 21.10668945], [76.4375, 21.10758972], [76.44107056, 21.11213112], [76.44770813, 21.11285973], [76.45269012, 21.11486816], [76.45291901, 21.1244297], [76.45593262, 21.13191986], [76.4575119, 21.13834], [76.46549988, 21.13924026], [76.46700287, 21.14319038], [76.46675873, 21.1472683], [76.46897125, 21.15056992], [76.47489166, 21.152071], [76.47702026, 21.15530014], [76.47673798, 21.16128922], [76.47828674, 21.17568016], [76.48245239, 21.18823051], [76.48737335, 21.19606018], [76.49117279, 21.19782066], [76.49807739, 21.19614029], [76.52078247, 21.18922043], [76.52919769, 21.18929291], [76.54129791, 21.19629097], [76.55938721, 21.20581055], [76.57518005, 21.20407295], [76.5760498, 21.20366287], [76.58674622, 21.19868279], [76.60562897, 21.19716263], [76.61231995, 21.19591141], [76.61678314, 21.19857025], [76.62003326, 21.19544029], [76.62336731, 21.19265938], [76.6268692, 21.19881058], [76.63157654, 21.20536995], [76.63134003, 21.21564102], [76.63169098, 21.22890091], [76.63728333, 21.23911285], [76.64257813, 21.24772072], [76.64987946, 21.24901962], [76.65849304, 21.24781036], [76.6590271, 21.25324821], [76.65944672, 21.26213074], [76.66017914, 21.27359962], [76.66107178, 21.28242111], [76.64862823, 21.3000412], [76.63973236, 21.31064987], [76.62583923, 21.32974052], [76.62452698, 21.33510017], [76.62864685, 21.33977127], [76.66841125, 21.3694706], [76.71909332, 21.40065002], [76.73208618, 21.40880966], [76.73722839, 21.41529083], [76.73842621, 21.42938042], [76.74339294, 21.44314003], [76.75654602, 21.44992828], [76.77578735, 21.46013069], [76.78418732, 21.46648979], [76.78513336, 21.47672081], [76.79017639, 21.48236084], [76.79180145, 21.48989105], [76.78649139, 21.49922943], [76.77023315, 21.51074982], [76.76293182, 21.52264977], [76.76751709, 21.52754021], [76.7753067, 21.53202057], [76.78553772, 21.53530121], [76.78782654, 21.54013062], [76.78457642, 21.54605293], [76.78283691, 21.5514698], [76.78024292, 21.56246758], [76.78359222, 21.5779705], [76.79148865, 21.58741951], [76.793396, 21.59517288], [76.79534912, 21.5975399], [76.80387115, 21.59683037], [76.82318115, 21.59268188], [76.8335495, 21.59306908], [76.83863068, 21.60050011], [76.84776306, 21.61330032], [76.85214996, 21.61503029], [76.86073303, 21.61230278], [76.89174652, 21.60070038], [76.90112305, 21.6008091], [76.90567017, 21.60449982], [76.91155243, 21.61493111], [76.97866821, 21.66597939], [76.99727631, 21.68161011], [77.00158691, 21.68215942], [77.01016235, 21.68439102], [77.0181427, 21.69079971], [77.02333832, 21.6937809], [77.02916718, 21.69606018], [77.03427124, 21.70051193], [77.05948639, 21.70940018], [77.0620575, 21.71504974], [77.06903839, 21.72180939], [77.07232666, 21.72293091], [77.07406616, 21.72261047], [77.07530975, 21.72237015], [77.08024597, 21.71869278], [77.08377838, 21.71862984], [77.09393311, 21.7196312], [77.10330963, 21.7226429], [77.10411072, 21.72289085], [77.11416626, 21.72486115], [77.12110138, 21.72534943], [77.13333893, 21.72232056], [77.14750671, 21.71465111], [77.15777588, 21.71340942], [77.16004944, 21.7137394], [77.16242218, 21.71410751], [77.16506195, 21.71692085], [77.16803741, 21.72575951], [77.17144775, 21.72726059], [77.18383026, 21.72450066], [77.18802643, 21.72257042], [77.18766022, 21.72072983], [77.18432617, 21.70446014], [77.20136261, 21.69631958], [77.20742035, 21.69400978], [77.21021271, 21.69712067], [77.21797943, 21.69842911], [77.22159576, 21.70010948], [77.22223663, 21.70167923], [77.22323608, 21.70418167], [77.22460175, 21.71788979], [77.23993683, 21.71712112], [77.25518036, 21.71519089], [77.25802612, 21.71582985], [77.26277161, 21.72363091], [77.26737976, 21.72907066], [77.28314972, 21.72422028], [77.28581238, 21.7288208], [77.28690338, 21.73644257], [77.28501892, 21.73750114], [77.28328705, 21.73849106], [77.28308868, 21.74164963], [77.28446198, 21.74644852], [77.28227234, 21.7481308], [77.27826691, 21.74913979], [77.27774811, 21.75375938], [77.27707672, 21.75980949], [77.27997589, 21.76126289], [77.28623962, 21.76275063], [77.29367065, 21.75991821], [77.3088913, 21.75964928], [77.32129669, 21.75703049], [77.32598114, 21.75736046], [77.33738708, 21.76156044], [77.33912659, 21.76165962], [77.34229279, 21.76183128], [77.35338593, 21.75946045], [77.37592316, 21.7571106], [77.40113068, 21.75617981], [77.40531158, 21.75673103], [77.41298676, 21.75773048], [77.42665863, 21.76040077], [77.43850708, 21.76272011], [77.44387817, 21.76351929], [77.44988251, 21.76341057], [77.45262909, 21.76432037], [77.45868683, 21.76818085], [77.47138214, 21.77124977], [77.4754715, 21.77144051], [77.47776794, 21.77022171], [77.47701263, 21.76795959], [77.47515106, 21.76573944], [77.47550964, 21.76185036], [77.47586823, 21.75788116], [77.48882294, 21.75024986], [77.4923172, 21.74979019], [77.49687195, 21.74920082], [77.49986267, 21.74489021], [77.50605011, 21.74121284], [77.50836182, 21.7352829], [77.51790619, 21.72701073], [77.51832581, 21.72437096], [77.51882935, 21.72116089], [77.52104187, 21.7141304], [77.52308655, 21.71362114], [77.52345276, 21.71354103], [77.52610779, 21.71503258], [77.53338623, 21.71269035], [77.53592682, 21.70825958], [77.54218292, 21.70103073], [77.54457092, 21.6924324], [77.54566956, 21.6860714], [77.54736328, 21.68156052], [77.55050659, 21.67628288], [77.55856323, 21.66867256], [77.55754089, 21.65558815], [77.56037903, 21.64518166], [77.5655365, 21.63503265], [77.57132721, 21.62704086], [77.570961, 21.6235199], [77.56784058, 21.62105942], [77.56817627, 21.61623192], [77.56993103, 21.6111412], [77.57219696, 21.58767128], [77.57022858, 21.57566833], [77.56999969, 21.56978989], [77.57099915, 21.56262016], [77.57408905, 21.55750084], [77.57972717, 21.55815125], [77.58551788, 21.55880928], [77.59068298, 21.56161118], [77.60575867, 21.55091095], [77.6071167, 21.54277039], [77.59488678, 21.5331707], [77.58924866, 21.53034973], [77.57789612, 21.52921104], [77.56698608, 21.52975082], [77.55339813, 21.53617287], [77.54073334, 21.53891945], [77.53533936, 21.53904915], [77.52919006, 21.54076958], [77.51191711, 21.54751015], [77.50726318, 21.5508194], [77.50435638, 21.55466843], [77.48400116, 21.55330276], [77.46872711, 21.55449104], [77.46472931, 21.55597115], [77.4575119, 21.55657005], [77.45195007, 21.55561066], [77.45030975, 21.55194092], [77.45024872, 21.5483799], [77.44664001, 21.54561043], [77.44207001, 21.54464912], [77.43187714, 21.54640007], [77.42894745, 21.54566002], [77.42350769, 21.54256058], [77.41990662, 21.5386982], [77.4169693, 21.53306007], [77.41880035, 21.52083969], [77.42079926, 21.51628113], [77.43112946, 21.50222015], [77.43921661, 21.48932266], [77.43737793, 21.48353195], [77.43515015, 21.48163986], [77.43785095, 21.47820282], [77.43808746, 21.47555923], [77.43830872, 21.47291946], [77.43875885, 21.47278023], [77.4489212, 21.46967125], [77.45236206, 21.46799088], [77.45378876, 21.46729279], [77.45716095, 21.46707153], [77.46930695, 21.45689964], [77.46858215, 21.45290947], [77.46975708, 21.44868088], [77.46884155, 21.44292068], [77.46920776, 21.43704987], [77.47302246, 21.43268967], [77.47709656, 21.42086029], [77.48175049, 21.41566849], [77.48419189, 21.39850998], [77.48298645, 21.39038086], [77.4870224, 21.3777504], [77.50173187, 21.37924957], [77.51052856, 21.37676048], [77.516922, 21.37803268], [77.51785278, 21.37784958], [77.52072144, 21.37730026], [77.52427673, 21.37973022], [77.52876282, 21.37907028], [77.5398407, 21.38117027], [77.54840851, 21.3812294], [77.5625, 21.37338066], [77.56533051, 21.37262917], [77.57089233, 21.3732605], [77.5759964, 21.37047005], [77.58081055, 21.36913109], [77.58262634, 21.36680031], [77.58444214, 21.36447906], [77.58701324, 21.36775017], [77.60148621, 21.36527061], [77.60481262, 21.36699295], [77.60575867, 21.37035179], [77.60204315, 21.38420105], [77.60066223, 21.3859024], [77.60064697, 21.3891201], [77.59938812, 21.39208984], [77.59919739, 21.39254951], [77.60067749, 21.39318085], [77.60154724, 21.3935585], [77.61145782, 21.39381027], [77.61519623, 21.39065933], [77.62931061, 21.39097977], [77.63617706, 21.38949966], [77.63920593, 21.38793945], [77.6414566, 21.3886795], [77.6425705, 21.39141083], [77.64589691, 21.39336014], [77.65097046, 21.39339066], [77.65158081, 21.39019012], [77.66208649, 21.38797188], [77.66335297, 21.38562965], [77.66307831, 21.37745094], [77.66481018, 21.37363052], [77.66722107, 21.37149048], [77.66877747, 21.3723011], [77.6700058, 21.3729229], [77.67520142, 21.37881088], [77.68109131, 21.38549042], [77.68827057, 21.39673042], [77.69113159, 21.39706993], [77.69352722, 21.3965416], [77.69425201, 21.39454269], [77.69259644, 21.38064957], [77.69554138, 21.37775993], [77.70433044, 21.37770081], [77.70514679, 21.37345123], [77.70519257, 21.36728096], [77.70524597, 21.35906982], [77.72489929, 21.36415291], [77.73387909, 21.36473083], [77.73834991, 21.36663055], [77.74336243, 21.38006973], [77.74649048, 21.38421059], [77.74993896, 21.38570976], [77.75689697, 21.38640976], [77.76140594, 21.38442039], [77.76506805, 21.38466263], [77.77655029, 21.3880291], [77.78552246, 21.38939095], [77.7901001, 21.38924026], [77.7934494, 21.39073944], [77.7939682, 21.39961052], [77.79522705, 21.40377808], [77.79598999, 21.40625954], [77.79847717, 21.41070938], [77.79936981, 21.41230011], [77.80449677, 21.41200066], [77.81801605, 21.40872955], [77.83392334, 21.40151978], [77.84661102, 21.39410973], [77.85473633, 21.39072037], [77.86321259, 21.38812065], [77.8762207, 21.38643074], [77.88337708, 21.38549042], [77.88186646, 21.37769127], [77.88664246, 21.38042068], [77.8923111, 21.3790493], [77.89904022, 21.37841988], [77.90071869, 21.3787117], [77.90550995, 21.37957001], [77.91176605, 21.382761], [77.91825104, 21.38474083], [77.92488861, 21.38606071], [77.9317627, 21.38581848], [77.93878174, 21.38690948], [77.94111633, 21.39895058], [77.95774841, 21.40114021], [77.95995331, 21.40142822], [77.97154999, 21.40138054], [77.97599792, 21.40209961], [77.98027802, 21.40279961], [77.99582672, 21.41378021], [77.99973297, 21.41616249], [78.00443268, 21.4158802], [78.00707245, 21.41841125], [78.01957703, 21.42058945], [78.0291214, 21.42535973], [78.04345703, 21.43503189], [78.05105591, 21.4370327], [78.06371307, 21.43885994], [78.0785675, 21.44571114], [78.09249115, 21.45601082], [78.10074615, 21.46095085], [78.10906219, 21.4641819], [78.12722778, 21.47340012], [78.14280701, 21.48211098], [78.16934204, 21.49850082], [78.17057037, 21.50205994], [78.17134094, 21.50850105], [78.17764282, 21.51431847], [78.1680069, 21.52604103], [78.17106628, 21.52873993], [78.17167664, 21.53576279], [78.17061615, 21.54219055], [78.17273712, 21.55330276], [78.17726898, 21.55669975], [78.18094635, 21.55868149], [78.21547699, 21.55373001], [78.22666931, 21.55644035], [78.23871613, 21.56549072], [78.24655914, 21.56401062], [78.26925659, 21.57071114], [78.27024841, 21.57237053], [78.26902008, 21.57472992], [78.25853729, 21.58189964], [78.25540924, 21.58523941], [78.25517273, 21.58984184], [78.25762177, 21.59184074], [78.26220703, 21.59375954], [78.26612091, 21.59428024], [78.27107239, 21.59296036], [78.2816391, 21.58675957], [78.30000305, 21.58505821], [78.3017807, 21.58040047], [78.30184937, 21.57287025], [78.30410767, 21.57143021], [78.30882263, 21.57369041], [78.31874084, 21.57558823], [78.32293701, 21.57738113], [78.32846069, 21.58118057], [78.33677673, 21.59052086], [78.34203339, 21.58287048], [78.34768677, 21.57886124], [78.35468292, 21.57690811], [78.36096191, 21.57829857], [78.36605072, 21.58192062], [78.37415314, 21.58996964], [78.37763214, 21.59560013], [78.37203979, 21.61076927], [78.37165833, 21.61503029], [78.37571716, 21.61745071], [78.3795166, 21.61865044], [78.38355255, 21.61663818], [78.38932037, 21.61056137], [78.39256287, 21.61009979], [78.39904785, 21.61108017], [78.40448761, 21.61009979], [78.41086578, 21.60659981], [78.41925812, 21.60429955], [78.42256165, 21.60194969], [78.41584778, 21.58815002], [78.41349792, 21.57773972], [78.41594696, 21.57308006], [78.41906738, 21.57160187], [78.42225647, 21.5637207], [78.42073059, 21.55479813], [78.42060089, 21.54878044], [78.42195129, 21.54584122], [78.42550659, 21.54227066], [78.42752838, 21.53832054], [78.42685699, 21.53019905], [78.42782593, 21.52675056], [78.43218231, 21.51991081], [78.43026733, 21.5091629], [78.43009949, 21.50175095], [78.43858337, 21.50375938], [78.44467926, 21.5019207], [78.4516983, 21.49733162], [78.45419312, 21.49831009], [78.45627594, 21.50445175], [78.45922852, 21.50463104], [78.46167755, 21.50353813], [78.46530151, 21.50353813], [78.47090912, 21.50486946], [78.47209167, 21.5069294], [78.48040009, 21.50612068], [78.48339844, 21.50774002], [78.48561859, 21.51203918], [78.49075317, 21.51797104], [78.49600983, 21.51797104], [78.49791718, 21.52296066], [78.50208282, 21.5266304], [78.50434875, 21.52670288], [78.50856018, 21.52843285], [78.52007294, 21.52537918], [78.52474213, 21.52583122], [78.52835083, 21.52462006], [78.53727722, 21.52456284], [78.54647064, 21.51996994], [78.55239868, 21.51939011], [78.55648804, 21.51581955], [78.56004333, 21.51461029], [78.56652832, 21.51569748], [78.56468964, 21.50932121], [78.56529999, 21.50597954], [78.57325745, 21.49850082], [78.58119202, 21.48964119], [78.58486938, 21.48688126], [78.59326172, 21.48768997], [78.59863281, 21.48480988], [78.60102081, 21.48715973], [78.6053772, 21.4883709], [78.61606598, 21.4815197], [78.62097168, 21.47754097], [78.62532806, 21.47783089], [78.63046265, 21.48133087], [78.63745117, 21.48419762], [78.64354706, 21.48425102], [78.65065765, 21.48282051], [78.65908813, 21.47888947], [78.66417694, 21.48073006], [78.68406677, 21.4819603], [78.68444061, 21.47795105], [78.68830109, 21.47886086], [78.6919632, 21.47868156], [78.69618225, 21.47741127], [78.69574738, 21.47443008], [78.70162201, 21.47470093], [78.70388031, 21.47120094], [78.71391296, 21.46795082], [78.71975708, 21.46462059], [78.72418976, 21.46438026], [78.7297287, 21.47136116], [78.73512268, 21.47141075], [78.7388382, 21.47290039], [78.74040222, 21.48371124], [78.74648285, 21.49386978], [78.7505188, 21.4907608], [78.76103973, 21.48975945], [78.76078796, 21.48471069], [78.76438141, 21.4742794], [78.77218628, 21.46713066], [78.77552032, 21.47351265], [78.7770462, 21.47907829], [78.78016663, 21.48080826], [78.78462219, 21.48913956], [78.78968811, 21.4885006], [78.79281616, 21.48986053], [78.81009674, 21.49086952], [78.81313324, 21.48872948], [78.81925964, 21.48962975], [78.82337952, 21.49111938], [78.82794952, 21.48995972], [78.84417725, 21.48997116], [78.84771729, 21.4914608], [78.85154724, 21.49570084], [78.87513733, 21.48792839], [78.87985229, 21.48497009], [78.88537598, 21.48559189], [78.89048767, 21.49823952], [78.89576721, 21.50056839], [78.90273285, 21.49801826], [78.90792847, 21.49425125], [78.92057037, 21.48763084], [78.93183136, 21.48740005], [78.93379974, 21.49238968], [78.93689728, 21.51044083], [78.94064331, 21.51370049], [78.93869781, 21.51728821], [78.9363327, 21.51939011], [78.92623901, 21.52164078], [78.92343903, 21.52378845], [78.92340088, 21.53308105], [78.92457581, 21.53868103], [78.92179871, 21.5431881], [78.90442657, 21.55484009], [78.90909576, 21.56175041], [78.91271973, 21.56312943], [78.92398071, 21.56015015], [78.92782593, 21.56028938], [78.9283905, 21.56443024], [78.91989899, 21.56895828], [78.91433716, 21.56964111], [78.91163635, 21.5709095], [78.91217804, 21.58518028], [78.91323853, 21.59235954], [78.92267609, 21.59260941], [78.92906189, 21.5946312], [78.94034576, 21.59375954], [78.94586182, 21.59604073], [78.96227264, 21.60588074], [78.97476196, 21.61755943], [78.98149109, 21.6171608], [78.9944458, 21.61874962], [78.99738312, 21.61577988], [78.99999237, 21.60979843], [79.00579834, 21.60402107], [79.009552, 21.60149956], [79.03096008, 21.60560989], [79.0429306, 21.60470963], [79.0479126, 21.60569], [79.05075073, 21.60394287], [79.07608032, 21.60768127], [79.0815506, 21.60715103], [79.08808899, 21.59918976], [79.09203339, 21.60342979], [79.09809875, 21.60284042], [79.10411072, 21.60935974], [79.09947968, 21.61227036], [79.09873199, 21.61631012], [79.09916687, 21.6189003], [79.11123657, 21.62556267], [79.12773895, 21.62805939], [79.13707733, 21.63685036], [79.14109039, 21.63953018], [79.14713287, 21.6565609], [79.14782715, 21.66052055], [79.18618774, 21.65442848], [79.21660614, 21.65019035], [79.21990204, 21.65081024], [79.22157288, 21.65690994], [79.22693634, 21.65764999], [79.22840118, 21.67139053], [79.22682953, 21.67439079], [79.22455597, 21.67588043], [79.22016144, 21.67700005], [79.21817017, 21.68126106], [79.22091675, 21.69659042], [79.22187805, 21.70059967], [79.23477173, 21.71520805], [79.22892761, 21.7204895], [79.22808075, 21.72191048], [79.2286911, 21.72392845], [79.25766754, 21.71754074], [79.26486969, 21.71492004], [79.27175903, 21.70903969], [79.27478027, 21.70523071], [79.27680206, 21.70022964], [79.28481293, 21.6939106], [79.31733704, 21.68581963], [79.32025146, 21.68659973], [79.32213593, 21.6883812], [79.34261322, 21.68451118], [79.34832001, 21.68440819], [79.34902191, 21.67889023], [79.36178589, 21.67951012], [79.38307953, 21.67539024], [79.39473724, 21.67459106], [79.3970871, 21.67564011], [79.40045166, 21.67964935], [79.40772247, 21.68556023], [79.41139984, 21.69096756], [79.41577911, 21.69144821], [79.42298126, 21.69057274], [79.42796326, 21.68526077], [79.43224335, 21.68349075], [79.44072723, 21.68223953], [79.45101166, 21.68433762], [79.45851135, 21.68732262], [79.4885788, 21.67412186], [79.48963928, 21.66580009], [79.4908905, 21.66370964], [79.49456024, 21.66053963], [79.49738312, 21.65193939], [79.49929047, 21.64784813], [79.50113678, 21.64571762], [79.50026703, 21.6405201], [79.50263977, 21.63459969], [79.50959778, 21.63336182], [79.51161957, 21.63113022], [79.5124588, 21.6264801], [79.50850677, 21.62286186], [79.50473022, 21.62326813], [79.50324249, 21.62236023], [79.50112915, 21.61964989], [79.49819183, 21.61236954], [79.50308228, 21.60750961], [79.50681305, 21.60238075], [79.50582123, 21.59028053], [79.51066589, 21.5831604], [79.52171326, 21.58032036], [79.52765656, 21.57480049], [79.53214264, 21.57298088], [79.53755951, 21.56899071], [79.53952026, 21.56520081], [79.53605652, 21.55496979], [79.5338974, 21.55076027], [79.53423309, 21.54816818], [79.53662109, 21.54421806], [79.54738617, 21.54429817], [79.56031036, 21.54801941], [79.57135773, 21.54380035], [79.57614899, 21.54335976], [79.58952332, 21.54955864], [79.59490967, 21.54965973], [79.59938812, 21.55076981], [79.60871124, 21.55593109], [79.61682129, 21.55721092], [79.62534332, 21.55486107], [79.63426971, 21.55495071], [79.64074707, 21.55548096], [79.6474762, 21.55717278], [79.65061951, 21.55880928], [79.65394592, 21.56345177], [79.65814209, 21.57733154], [79.66294098, 21.57971001], [79.68483734, 21.58069038], [79.68934631, 21.58364105], [79.69122314, 21.58789063], [79.69380951, 21.59095192], [79.69934082, 21.5923214], [79.70617676, 21.59090042], [79.71382141, 21.59113121], [79.73262024, 21.60252953], [79.74488831, 21.59786987], [79.76879883, 21.59043121], [79.79181671, 21.58140945], [79.80319214, 21.57262993], [79.81165314, 21.56430054], [79.81819153, 21.55900955], [79.82504272, 21.5467205], [79.84153748, 21.54181862], [79.85056305, 21.5375309], [79.85475922, 21.53252029], [79.85707855, 21.53092194], [79.87187958, 21.52956009], [79.8766861, 21.52847099], [79.88582611, 21.5296402], [79.88976288, 21.52388], [79.89228821, 21.52326012], [79.90119171, 21.52436066], [79.91581726, 21.52448082], [79.91831207, 21.54031181], [79.92124939, 21.5461998], [79.92719269, 21.55373001], [79.9310379, 21.55561066], [79.93638611, 21.55680084], [79.94709778, 21.55525017], [79.96144867, 21.55800056], [79.96624756, 21.55727005], [79.97177887, 21.55512047], [79.98558044, 21.5367794], [79.99355316, 21.53471184], [79.99669647, 21.53531075], [79.99819946, 21.53664017], [80.00208282, 21.53897095], [80.00476074, 21.54087067], [80.00746918, 21.54256821], [80.01000977, 21.5445919], [80.01223755, 21.54598045], [80.01465607, 21.54735184], [80.01689911, 21.54885101], [80.01912689, 21.55079079], [80.02265167, 21.55381966], [80.02617645, 21.55665016], [80.02822876, 21.55734062], [80.03199005, 21.55755806], [80.03439331, 21.55747032], [80.03840637, 21.55685997], [80.04155731, 21.55624962], [80.04403687, 21.55514908], [80.04557037, 21.55475044], [80.04815674, 21.55414963], [80.05007172, 21.55411911], [80.0507431, 21.55411911], [80.05419922, 21.55354118], [80.05719757, 21.55360031], [80.05964661, 21.55373001], [80.06118774, 21.55401993], [80.06211853, 21.55424118], [80.06356812, 21.55458069], [80.06658936, 21.5568409], [80.06845856, 21.55847168], [80.07002258, 21.56038094], [80.07115936, 21.56200027], [80.07332611, 21.5638504], [80.07508087, 21.56513977], [80.07704163, 21.56675911], [80.07875824, 21.56839943], [80.08201599, 21.57176971], [80.08483887, 21.5761795], [80.08669281, 21.57855988], [80.0896759, 21.58228111], [80.09081268, 21.58356285], [80.09329987, 21.58537102], [80.09401703, 21.5862999], [80.09632111, 21.58743286], [80.09874725, 21.58865929], [80.10040283, 21.5887394], [80.10209656, 21.5893898], [80.10560608, 21.59111023], [80.10793304, 21.59211922], [80.10990143, 21.59341049], [80.11157227, 21.59647942], [80.11219025, 21.59955025], [80.11242676, 21.6008091], [80.11286926, 21.60377121], [80.11493683, 21.60700989], [80.11857605, 21.60889816], [80.12145233, 21.60906029], [80.12409973, 21.60861015], [80.12622833, 21.60830116], [80.13298798, 21.60560989], [80.13751984, 21.60519981], [80.14068604, 21.60472107], [80.1439209, 21.60497284], [80.14787292, 21.60630035], [80.14998627, 21.60741997], [80.1526413, 21.60970116], [80.15499115, 21.61179924], [80.15673828, 21.61412048], [80.15991974, 21.61749077], [80.16210175, 21.61948967], [80.16499329, 21.6217308], [80.16895294, 21.62320137], [80.17112732, 21.62374115], [80.17339325, 21.62412071], [80.1749115, 21.62396049], [80.17672729, 21.62392044], [80.18031311, 21.62552071], [80.18237305, 21.62704086], [80.18369293, 21.62849045], [80.18519592, 21.63064003], [80.18618774, 21.63266945], [80.18821716, 21.63420105], [80.18942261, 21.63425064], [80.19210815, 21.63462067], [80.19515228, 21.63493919], [80.20040131, 21.63470078], [80.20469666, 21.63354111], [80.20797729, 21.62965012], [80.21039581, 21.62627983], [80.21203613, 21.62421989], [80.21465302, 21.62124062], [80.21630859, 21.62034035], [80.22058868, 21.61963081], [80.22688293, 21.62010193], [80.23207092, 21.62045288], [80.23596954, 21.6207695], [80.24014282, 21.62051964], [80.24269867, 21.62049103], [80.24762726, 21.62249947], [80.25206757, 21.6222496], [80.25527954, 21.62072945], [80.25665283, 21.62028122], [80.26022339, 21.62014961], [80.2649765, 21.61655807], [80.27086639, 21.6106205], [80.27237701, 21.60712051], [80.27374268, 21.60263062], [80.2754364, 21.59907913], [80.27980042, 21.59613037], [80.28282928, 21.59511948], [80.28658295, 21.59343147], [80.28800964, 21.59229088], [80.28864288, 21.58965111], [80.28909302, 21.5884304], [80.28978729, 21.5859127], [80.29026794, 21.58263016], [80.29191589, 21.57802963], [80.29537201, 21.57547951], [80.29908752, 21.57538986], [80.30336761, 21.57612991], [80.30764008, 21.57674026], [80.30988312, 21.57734108], [80.31299591, 21.57709122], [80.31693268, 21.57568169], [80.31884003, 21.57455063], [80.3201828, 21.57357979], [80.32139587, 21.57059097], [80.32283783, 21.5674305], [80.324646, 21.56410027], [80.32628632, 21.56158066], [80.32746887, 21.55964088], [80.32858276, 21.5582695], [80.32977295, 21.55631065], [80.33009338, 21.55470085], [80.3290863, 21.55365944], [80.32728577, 21.55174065], [80.32559204, 21.55034065], [80.32443237, 21.5487175], [80.32740784, 21.54609108], [80.32968903, 21.54444122], [80.33097839, 21.54370117], [80.33294678, 21.54220963], [80.33516693, 21.54074097], [80.3380127, 21.53874969], [80.3396759, 21.53790283], [80.34229279, 21.53742027], [80.3463974, 21.53572083], [80.35189056, 21.53300285], [80.35691071, 21.53079987], [80.36219025, 21.52849007], [80.36582947, 21.52634048], [80.36762238, 21.52467918], [80.36923218, 21.52291107], [80.3706131, 21.52096939], [80.3707962, 21.51786995], [80.37085724, 21.51709175], [80.37117767, 21.51514816], [80.3724823, 21.51279068], [80.3735733, 21.50945091], [80.37386322, 21.50508118], [80.37388611, 21.50306129], [80.37422943, 21.50110054], [80.3745575, 21.49897957], [80.37483978, 21.49591064], [80.37486267, 21.49483109], [80.37494659, 21.49287033], [80.37532806, 21.49114037], [80.37578583, 21.49094009], [80.37767792, 21.49012947], [80.37858582, 21.48933029], [80.38021088, 21.48727036], [80.38170624, 21.48480034], [80.38272095, 21.48244095], [80.38366699, 21.47900009], [80.38445282, 21.47635078], [80.38685608, 21.47343254], [80.38994598, 21.47092819], [80.39209747, 21.46939087], [80.39528656, 21.46787071], [80.39659119, 21.46723938], [80.39904022, 21.46640015], [80.40096283, 21.46543121], [80.40223694, 21.46337128], [80.40367889, 21.46130943], [80.40453339, 21.45861053], [80.40467834, 21.45635986], [80.40535736, 21.45440102], [80.40644073, 21.45119286], [80.40825653, 21.44721985], [80.40947723, 21.4435997], [80.41055298, 21.44016075], [80.41130829, 21.4382019], [80.41024017, 21.43639946], [80.40862274, 21.43482971], [80.40600586, 21.43245125], [80.40426636, 21.4307003], [80.40161133, 21.42807961], [80.39891815, 21.42494011], [80.39803314, 21.42308998], [80.39996338, 21.41948128], [80.39924622, 21.41790962], [80.39678192, 21.41534996], [80.39347076, 21.41267014], [80.38990021, 21.40888977], [80.38907623, 21.40737915], [80.38906097, 21.40431976], [80.38983154, 21.40087128], [80.3915329, 21.39663124], [80.39389801, 21.39215088], [80.39653778, 21.38784981], [80.39792633, 21.3841095], [80.39935303, 21.38049126], [80.40112305, 21.3782711], [80.40196991, 21.37781143], [80.40336609, 21.37648964], [80.40444183, 21.37581062], [80.40656281, 21.37640953], [80.40844727, 21.3760891], [80.41028595, 21.37545967], [80.41407776, 21.37527275], [80.41760254, 21.37565041], [80.42095184, 21.37568283], [80.422966, 21.37524033], [80.42494202, 21.37450027], [80.42685699, 21.37308121], [80.42758179, 21.37290955], [80.43048096, 21.37189293], [80.43353271, 21.37118149], [80.43560791, 21.37125015], [80.4372406, 21.37137985], [80.4404068, 21.37210083], [80.44294739, 21.37379837], [80.44364166, 21.37639999], [80.44374847, 21.37969017], [80.44329071, 21.38463974], [80.44320679, 21.38799286], [80.44426727, 21.39052963], [80.44558716, 21.39256096], [80.44706726, 21.39557076], [80.44764709, 21.39846039], [80.44831848, 21.4023304], [80.45069885, 21.40234947], [80.45333862, 21.40036011], [80.45475006, 21.39966011], [80.45635986, 21.39870071], [80.46016693, 21.3970108], [80.46285248, 21.39635086], [80.46431732, 21.39590073], [80.46676636, 21.39557076], [80.4681778, 21.39524078], [80.47135162, 21.39583969], [80.47387695, 21.3993206], [80.47476196, 21.39575005], [80.47561646, 21.39472961], [80.47897339, 21.39590836], [80.48145294, 21.39697075], [80.48396301, 21.3972702], [80.48549652, 21.39763832], [80.48989868, 21.39635086], [80.49343872, 21.39423943], [80.49633026, 21.39294052], [80.50055695, 21.3907795], [80.50289154, 21.39058113], [80.50569153, 21.39072037], [80.50887299, 21.39109039], [80.51140594, 21.39186096], [80.5147171, 21.39101982], [80.51651001, 21.39051819], [80.51943207, 21.38957024], [80.52037048, 21.38825035], [80.52166748, 21.38734055], [80.52420044, 21.3837204], [80.5268631, 21.38166809], [80.52971649, 21.38095093], [80.53203583, 21.37728119], [80.53311157, 21.37486076], [80.53424835, 21.37205124], [80.53688049, 21.36913109], [80.53964996, 21.36852074], [80.54091644, 21.36812019], [80.54424286, 21.3672905], [80.54577637, 21.36626053], [80.55023193, 21.36474037], [80.55519867, 21.36271095], [80.55821991, 21.36128807], [80.55901337, 21.36112976], [80.55967712, 21.36038017], [80.56417084, 21.3578701], [80.56376648, 21.35573959], [80.56109619, 21.35440254], [80.5583725, 21.35316277], [80.5580368, 21.35103035], [80.55982971, 21.34856987], [80.56053925, 21.34546089], [80.56136322, 21.3433094], [80.56417847, 21.34277916], [80.56636047, 21.34280014], [80.5690918, 21.34443092], [80.57176971, 21.34560966], [80.57543945, 21.34379005], [80.57788849, 21.34300041], [80.58027649, 21.34210014], [80.58162689, 21.34159088], [80.58241272, 21.33722115], [80.58188629, 21.33432961], [80.58307648, 21.33116913], [80.58672333, 21.32946014], [80.58946991, 21.32834053], [80.59127045, 21.32674026], [80.59316254, 21.32479095], [80.59739685, 21.32349968], [80.59941101, 21.32323074], [80.60234833, 21.32372093], [80.60531616, 21.3243103], [80.60851288, 21.32393265], [80.61009216, 21.32262039], [80.61096191, 21.32170105], [80.61299133, 21.32034111], [80.61775208, 21.31917191], [80.6206665, 21.32015991], [80.62328339, 21.32146072], [80.62491608, 21.32182121], [80.62832642, 21.32258987], [80.63179016, 21.32372093], [80.63356018, 21.32418823], [80.63817596, 21.32485962], [80.64438629, 21.32547951], [80.64829254, 21.32637978], [80.65042877, 21.32993126], [80.65177155, 21.33119011], [80.65653229, 21.3307724], [80.6579361, 21.3293705], [80.65986633, 21.32777023], [80.66239929, 21.32612038], [80.66355896, 21.32485962], [80.66559601, 21.32211113], [80.66654205, 21.3193512], [80.66699982, 21.31618118], [80.6680603, 21.31381989], [80.67095184, 21.31228065], [80.67273712, 21.31126976], [80.67378998, 21.30908012], [80.67237091, 21.30588913], [80.67308807, 21.30117989], [80.67295074, 21.29828835], [80.67095947, 21.29590988], [80.66828918, 21.29399109], [80.66526794, 21.29229164], [80.66332245, 21.29095078], [80.6608963, 21.28977966], [80.65808868, 21.28940964], [80.65480804, 21.28951073], [80.65368652, 21.28604126], [80.65215302, 21.28325272], [80.65080261, 21.28158951], [80.64862061, 21.28017044], [80.64676666, 21.27814293], [80.64488983, 21.27600288], [80.64340973, 21.27229118], [80.64264679, 21.2690506], [80.64190674, 21.26442909], [80.64111328, 21.26143074], [80.63948059, 21.25749969], [80.63873291, 21.25478172], [80.63735962, 21.25269127], [80.63530731, 21.25013924], [80.6322403, 21.24729919], [80.62767029, 21.24570084], [80.62464142, 21.2442894], [80.62010193, 21.24236107], [80.61572266, 21.24002075], [80.61344147, 21.23682976], [80.61170959, 21.23456955], [80.61048889, 21.23329163], [80.60868835, 21.23179054], [80.60766602, 21.23125076], [80.60608673, 21.22997093], [80.60507965, 21.22875977], [80.60344696, 21.22742271], [80.60099792, 21.22618294], [80.59889984, 21.22512817], [80.59622192, 21.22453117], [80.5923233, 21.22484016], [80.58938599, 21.22471046], [80.58447266, 21.22306061], [80.5815506, 21.22177124], [80.57810211, 21.21990013], [80.57483673, 21.21825981], [80.57183838, 21.21685028], [80.56842804, 21.21388245], [80.56661224, 21.21080971], [80.56611633, 21.21027946], [80.56402588, 21.20802116], [80.56124115, 21.20581055], [80.55779266, 21.20393944], [80.55367279, 21.20251083], [80.55063629, 21.20117188], [80.54930115, 21.20098114], [80.54656982, 21.20066833], [80.54351044, 21.20001984], [80.54187775, 21.19919014], [80.53888702, 21.19928932], [80.53498077, 21.19960976], [80.532341, 21.20022011], [80.53045654, 21.20084], [80.5279007, 21.20202065], [80.52501678, 21.2026329], [80.52073669, 21.2035408], [80.51822662, 21.20108032], [80.51624298, 21.19829941], [80.51480103, 21.1960392], [80.51316833, 21.19361115], [80.5115509, 21.19111061], [80.51081085, 21.18890953], [80.5103302, 21.18649101], [80.50932312, 21.18347931], [80.50763702, 21.18244171], [80.50453186, 21.18304062], [80.50257111, 21.18330956], [80.49989319, 21.18404007], [80.49787903, 21.18403244], [80.49549866, 21.18325806], [80.49230957, 21.17994118], [80.48953247, 21.17756081], [80.48600006, 21.17719078], [80.48181152, 21.17657089], [80.47943878, 21.17493057], [80.47709656, 21.17307091], [80.47490692, 21.17143059], [80.4733429, 21.17131042], [80.46784973, 21.17148972], [80.46418762, 21.17209053], [80.46163177, 21.17282104], [80.45729828, 21.17284012], [80.45526886, 21.16908073], [80.45426941, 21.1654377], [80.45400238, 21.16174126], [80.45391846, 21.15862274], [80.45281982, 21.15434074], [80.45157623, 21.14965057], [80.45009613, 21.14691925], [80.44921875, 21.14442825], [80.44821167, 21.14152908], [80.44696045, 21.13814926], [80.44602966, 21.13578033], [80.44402313, 21.13060951], [80.44246674, 21.12816048], [80.44072723, 21.12547112], [80.43865204, 21.12140083], [80.44037628, 21.12030983], [80.44387054, 21.11925125], [80.44618988, 21.11816978], [80.44822693, 21.1162796], [80.44914246, 21.11531067], [80.44933319, 21.114851], [80.44924927, 21.11194038], [80.44696045, 21.1110611], [80.44550323, 21.11125946], [80.44371796, 21.11165047], [80.44226074, 21.11186981], [80.43950653, 21.11178017], [80.4390564, 21.10917091], [80.43872833, 21.10696983], [80.43766022, 21.10453033], [80.4367218, 21.10267067], [80.4360733, 21.10104752], [80.43518066, 21.09901047], [80.43419647, 21.09802246], [80.43331909, 21.0971508], [80.43550873, 21.09518051], [80.43640137, 21.09271049], [80.43813324, 21.08880806], [80.44000244, 21.08531952], [80.44095612, 21.08325195], [80.4420166, 21.08060074], [80.44254303, 21.07743073], [80.44275665, 21.07419014], [80.44261169, 21.07246017], [80.44097137, 21.07040024], [80.44259644, 21.06698036], [80.44297791, 21.06592941], [80.44399261, 21.06324005], [80.44474792, 21.06158066], [80.44610596, 21.05998993], [80.44727325, 21.0566597], [80.44763184, 21.05448914], [80.44822693, 21.05196953], [80.44850159, 21.04961014], [80.44786835, 21.04687119], [80.44706726, 21.04432106], [80.44734955, 21.04076195], [80.44754791, 21.03961945], [80.44734192, 21.03662109], [80.4465332, 21.03362083], [80.44523621, 21.03094292], [80.44325256, 21.02918816], [80.44085693, 21.02800941], [80.43860626, 21.02717018], [80.43675995, 21.02501106], [80.43596649, 21.02205086], [80.43454742, 21.01923943], [80.43247223, 21.01713181], [80.43010712, 21.01635933], [80.42881012, 21.01357079], [80.42758179, 21.01246071], [80.42375946, 21.00959015], [80.42475128, 21.00733948], [80.42662811, 21.00505066], [80.42948914, 21.00263977], [80.43334198, 20.99975014], [80.43808746, 20.99209976], [80.43894196, 20.97155952], [80.44069672, 20.96545982], [80.4437561, 20.96103287], [80.448349, 20.95101166], [80.4487915, 20.94530106], [80.45658875, 20.93724823], [80.45555878, 20.93210983], [80.45909119, 20.92815018], [80.46531677, 20.92728806], [80.47392273, 20.92736053], [80.48274994, 20.92847061], [80.4912796, 20.92785072], [80.50067902, 20.92891121], [80.51062012, 20.92880058], [80.52641296, 20.93210983], [80.5352478, 20.93132019], [80.5418396, 20.93391991], [80.53813171, 20.9260807], [80.53910065, 20.92106056], [80.54618835, 20.90307999], [80.54975891, 20.88891029], [80.54891205, 20.86808968], [80.55060577, 20.85991096], [80.55036926, 20.8456707], [80.55478668, 20.82942009], [80.55589294, 20.81968117], [80.55076599, 20.81546021], [80.54889679, 20.80841064], [80.54569244, 20.80137253], [80.54334259, 20.79179955], [80.54545593, 20.78227806], [80.54553223, 20.76536942], [80.54817963, 20.75908089], [80.55200958, 20.75345039], [80.55454254, 20.74715042], [80.55587006, 20.72257042], [80.56018829, 20.71177292], [80.56394958, 20.70718956], [80.57492065, 20.69842911], [80.57772064, 20.69407082], [80.5792923, 20.68997955], [80.58011627, 20.68364143], [80.57833862, 20.67877007], [80.57279205, 20.6742897], [80.56680298, 20.67292976], [80.55271149, 20.67308998], [80.54738617, 20.67126083], [80.53742218, 20.66402054], [80.5255661, 20.66319084], [80.51891327, 20.66176033], [80.50760651, 20.65460014], [80.50203705, 20.6491909], [80.48964691, 20.6398983], [80.48484802, 20.63517952], [80.48159027, 20.62976265], [80.48095703, 20.62355042], [80.4815979, 20.61709976], [80.48419189, 20.61195946], [80.49291229, 20.60408974], [80.49717712, 20.59580994], [80.50009918, 20.58686256], [80.51190186, 20.58511925], [80.51950836, 20.58468056], [80.52983093, 20.59008026], [80.55140686, 20.59907913], [80.55903625, 20.60997963], [80.56730652, 20.61240768], [80.57866669, 20.61412048], [80.58573151, 20.61415291], [80.59246826, 20.61309814], [80.60256958, 20.60738945], [80.60896301, 20.60598946], [80.61767578, 20.60617065], [80.62232208, 20.60386276], [80.61949158, 20.59791946], [80.61286163, 20.59057808], [80.61460876, 20.58527184], [80.61746979, 20.58103752], [80.61424255, 20.576931], [80.61972046, 20.56731987], [80.61707306, 20.56223106], [80.6121521, 20.55958939], [80.6099472, 20.55632973], [80.61178589, 20.55096054], [80.61029816, 20.5450592], [80.61341095, 20.54157066], [80.61273956, 20.53726006], [80.61003113, 20.53198051], [80.60852814, 20.51620293], [80.60688782, 20.51254082], [80.6072464, 20.50391006], [80.60620117, 20.48707008], [80.60494232, 20.48115158], [80.60331726, 20.46241951], [80.60166931, 20.45726013], [80.59468842, 20.44642067], [80.59715271, 20.44207001], [80.60144806, 20.4373703], [80.60343933, 20.43325043], [80.5998764, 20.42692184], [80.5944519, 20.42070961], [80.59173584, 20.41505051], [80.5897522, 20.41277122], [80.58651733, 20.40072823], [80.58602142, 20.39561081], [80.58598328, 20.39204979], [80.58744049, 20.38789177], [80.59017181, 20.38434982], [80.5983963, 20.38068008], [80.60222626, 20.37644005], [80.60072327, 20.37260056], [80.60089874, 20.36919022], [80.60513306, 20.36615944], [80.60620117, 20.36079025], [80.60601044, 20.35642052], [80.61149597, 20.34934235], [80.61071014, 20.34526062], [80.61667633, 20.33761024], [80.61776733, 20.33368111], [80.61669159, 20.32574081], [80.60671234, 20.32534981], [80.60542297, 20.32019043], [80.58423615, 20.3192997], [80.55158234, 20.31153107], [80.54202271, 20.30684853], [80.53930664, 20.30039024], [80.53582001, 20.29467964], [80.52667999, 20.2847805], [80.51082611, 20.26961136], [80.49447632, 20.27479935], [80.47587585, 20.27368927], [80.46544647, 20.2716217], [80.45646667, 20.26890945], [80.44838715, 20.26388168], [80.43730927, 20.25847816], [80.42294312, 20.25260925], [80.4196167, 20.25156021], [80.41526794, 20.25229073], [80.4090271, 20.24913025], [80.40371704, 20.24769974], [80.3862381, 20.24461174], [80.38295746, 20.2417202], [80.38803864, 20.23061943], [80.39800262, 20.21278], [80.40982056, 20.20528984], [80.41201782, 20.20220947], [80.41398621, 20.19023132], [80.41340637, 20.18753052], [80.40406036, 20.1844101], [80.39827728, 20.18344116], [80.39459229, 20.18158913], [80.39279938, 20.17740059], [80.39190674, 20.17073059], [80.39045715, 20.16627121], [80.38601685, 20.16280937], [80.38456726, 20.15851021], [80.38762665, 20.15158081], [80.39383698, 20.14402008], [80.40149689, 20.13951111], [80.42695618, 20.13023949], [80.4319458, 20.13134003], [80.4396286, 20.12911987], [80.44413757, 20.13034248], [80.44787598, 20.14157104], [80.45133972, 20.14487076], [80.45865631, 20.14455032], [80.46678162, 20.14268112], [80.47730255, 20.13853073], [80.48293304, 20.13788986], [80.4911499, 20.14147949], [80.49803162, 20.13891983], [80.50358582, 20.1287899], [80.51053619, 20.12693024], [80.51815033, 20.12683105], [80.52359009, 20.12447166], [80.52668762, 20.12137985], [80.52880859, 20.11750031], [80.53575897, 20.11384964], [80.54036713, 20.10983276], [80.54125214, 20.10494995], [80.53523254, 20.09218025], [80.53495789, 20.08539963], [80.54183197, 20.07668114], [80.54615784, 20.06571007], [80.54522705, 20.05957031], [80.54109192, 20.04818916], [80.54158783, 20.03722191], [80.53542328, 20.01120949], [80.53253937, 20.00393295], [80.53578949, 19.99991989], [80.53994751, 19.99772072], [80.54353333, 19.99508286], [80.54554749, 19.98718071], [80.54415131, 19.98151016], [80.53775787, 19.97356033], [80.53473663, 19.97092056], [80.53237152, 19.96706009], [80.53383636, 19.95302963], [80.52628326, 19.94862747], [80.52600861, 19.94112015], [80.52037811, 19.93087959], [80.50875092, 19.92591095], [80.5017395, 19.92475128], [80.48047638, 19.92780113], [80.47289276, 19.93124962], [80.469841, 19.93366051], [80.46875, 19.94026947], [80.46450043, 19.94625092], [80.45300293, 19.94523811], [80.4437027, 19.95267105], [80.43855286, 19.9471302], [80.43100739, 19.94094086], [80.42510986, 19.93730927], [80.42059326, 19.93622971], [80.40931702, 19.93538094], [80.40629578, 19.93250084], [80.40577698, 19.92545128], [80.40265656, 19.90960121], [80.4076767, 19.90590286], [80.41474915, 19.90291977], [80.43100739, 19.8984108], [80.43579865, 19.89551926], [80.44444275, 19.89355087], [80.45278931, 19.90000916], [80.46121979, 19.90343094], [80.46895599, 19.90336037], [80.48265076, 19.89889908], [80.48983765, 19.89367294], [80.49166107, 19.89053917], [80.4969101, 19.8771801], [80.49752045, 19.86874962], [80.48764038, 19.86512947], [80.47502136, 19.85705948], [80.47103119, 19.8426609], [80.46861267, 19.83753014], [80.46363068, 19.8358326], [80.46029663, 19.82802963], [80.45511627, 19.82379913], [80.44696808, 19.82032013], [80.43165588, 19.81030083], [80.42459106, 19.80804062], [80.41731262, 19.8091507], [80.40497589, 19.81542015], [80.3975296, 19.81623077], [80.39842987, 19.80319023], [80.39470673, 19.79457855], [80.40014648, 19.7936306], [80.41768646, 19.79714012], [80.42900848, 19.7951107], [80.43579102, 19.79185104], [80.44270325, 19.7905407], [80.44953918, 19.79265976], [80.45243835, 19.79290009], [80.46176147, 19.7882328], [80.46679688, 19.78487968], [80.47808838, 19.77240944], [80.4825592, 19.78071022], [80.48207092, 19.78950119], [80.48023987, 19.79544067], [80.47714233, 19.80122948], [80.47480774, 19.8033905], [80.46290588, 19.80575943], [80.45954895, 19.8113308], [80.46916199, 19.82466125], [80.47602844, 19.82800102], [80.4907074, 19.82536125], [80.49839783, 19.82947159], [80.50750732, 19.82994843], [80.51780701, 19.82886124], [80.5353775, 19.81813049], [80.54242706, 19.81927109], [80.54424286, 19.8112011], [80.54194641, 19.80315018], [80.54244232, 19.79424286], [80.53887177, 19.78070259], [80.53967285, 19.77459908], [80.55021667, 19.76455116], [80.56765747, 19.75667953], [80.57052612, 19.75473976], [80.57868195, 19.74392128], [80.58207703, 19.73807144], [80.59033203, 19.73443031], [80.61313629, 19.72892952], [80.62020874, 19.72377014], [80.63350677, 19.7184906], [80.64029694, 19.71245956], [80.64563751, 19.7064991], [80.66133881, 19.69750023], [80.66584015, 19.69221115], [80.66455078, 19.69075012], [80.666008, 19.68626976], [80.66538239, 19.67296982], [80.66220093, 19.66258049], [80.6561203, 19.62515068], [80.65589142, 19.6169796], [80.65685272, 19.61226082], [80.66203308, 19.60873032], [80.6830368, 19.61060905], [80.69668579, 19.61083031], [80.7077713, 19.61045837], [80.72099304, 19.60839081], [80.75795746, 19.59017181], [80.76426697, 19.58483124], [80.76503754, 19.57426071], [80.76641083, 19.56831932], [80.78515625, 19.56040955], [80.80922699, 19.56451035], [80.8196106, 19.56540108], [80.8276062, 19.56267166], [80.83352661, 19.55597115], [80.83605194, 19.54898071], [80.83737946, 19.54063034], [80.84082794, 19.53357124], [80.84538269, 19.5291729], [80.85225677, 19.52416992], [80.86334991, 19.52194977], [80.87359619, 19.52235031], [80.87905121, 19.51902962], [80.88553619, 19.50925064], [80.88970184, 19.49925041], [80.8914032, 19.49084091], [80.89215851, 19.4815197], [80.89206696, 19.46568108], [80.88562775, 19.45650291], [80.87599945, 19.44795036], [80.86749268, 19.44346046], [80.85748291, 19.44254112], [80.83508301, 19.44238091], [80.82524872, 19.43912125], [80.80799866, 19.43161964], [80.79432678, 19.42876816], [80.78793335, 19.42670059], [80.79244995, 19.42266083], [80.79538727, 19.4187603], [80.79795074, 19.4116497], [80.80854797, 19.39703941], [80.81273651, 19.38274002], [80.815979, 19.37907028], [80.8232193, 19.3747406], [80.83499908, 19.37068176], [80.84282684, 19.36610985], [80.84500885, 19.36091042], [80.83908081, 19.35515022], [80.82641602, 19.34803963], [80.81649017, 19.34247017], [80.81282806, 19.33813095], [80.80634308, 19.33490944], [80.80282593, 19.33228111], [80.79934692, 19.32516289], [80.7950058, 19.32476044], [80.78790283, 19.32411194], [80.78246307, 19.3217411], [80.77809143, 19.31854057], [80.7661972, 19.30813026], [80.76397705, 19.30527115], [80.75974274, 19.29975128], [80.75505066, 19.2952404], [80.74923706, 19.28674126], [80.7434082, 19.28597069], [80.73673248, 19.2869606], [80.73065948, 19.28403091], [80.7183075, 19.28549957], [80.70918274, 19.28330994], [80.70043945, 19.2822628], [80.6987381, 19.28227043], [80.69374847, 19.28232193], [80.68860626, 19.28348923], [80.68356323, 19.28691101], [80.68180084, 19.29584122], [80.68528748, 19.31260109], [80.68419647, 19.32002831], [80.67922211, 19.32414055], [80.67189026, 19.32644844], [80.66439056, 19.32657814], [80.65788269, 19.32427979], [80.63530731, 19.3128376], [80.62549591, 19.30681038], [80.61772156, 19.30481911], [80.6101532, 19.30714035], [80.60394287, 19.31176949], [80.60006714, 19.31809044], [80.59851837, 19.3246727], [80.59568024, 19.33131981], [80.59266663, 19.3352108], [80.58862305, 19.34440041], [80.58558655, 19.35301971], [80.58226013, 19.36833954], [80.5847168, 19.3737011], [80.5839386, 19.37715912], [80.57286072, 19.39842033], [80.57084656, 19.39942169], [80.56781769, 19.40092087], [80.55934143, 19.39755249], [80.53153992, 19.3743], [80.52612305, 19.36721039], [80.52271271, 19.35975075], [80.51898193, 19.35400963], [80.51383972, 19.34819984], [80.50720978, 19.34359169], [80.5003891, 19.34129906], [80.48110199, 19.33782005], [80.47558594, 19.33504295], [80.47049713, 19.32892036], [80.46530151, 19.31591988], [80.46450043, 19.31395149], [80.46212769, 19.3081398], [80.45680237, 19.2991581], [80.44542694, 19.26988983], [80.43702698, 19.26107025], [80.42807007, 19.25438118], [80.41916656, 19.25028038], [80.41446686, 19.24918938], [80.40818024, 19.24770164], [80.40157318, 19.24682999], [80.39684296, 19.2462101], [80.38845062, 19.24331093], [80.38334656, 19.23913956], [80.37918091, 19.2326107], [80.37702179, 19.21736908], [80.37993622, 19.20870972], [80.38611603, 19.19563293], [80.38667297, 19.18902016], [80.38111115, 19.18073082], [80.37290192, 19.1751194], [80.36235809, 19.16932106], [80.34546661, 19.16291046], [80.34411621, 19.16180992], [80.34059143, 19.15891838], [80.33963013, 19.15302086], [80.3355484, 19.14756966], [80.32485199, 19.1415329], [80.32086182, 19.12449074], [80.32235718, 19.12022018], [80.3296814, 19.10741997], [80.33154297, 19.10107994], [80.32411957, 19.09493065], [80.31994629, 19.0882206], [80.32256317, 19.08216095], [80.32211304, 19.07487106], [80.31996155, 19.06940269], [80.31577301, 19.06458092], [80.30224609, 19.05554962], [80.29170227, 19.04980087], [80.28884125, 19.04628944], [80.2905426, 19.04001045], [80.29528809, 19.02873993], [80.29341125, 19.02159119], [80.28811646, 19.01393127], [80.27230835, 18.99744034], [80.26772308, 18.98732948], [80.26753235, 18.98396111], [80.26734924, 18.98067093], [80.26902008, 18.96416092], [80.26747894, 18.95257187], [80.26531982, 18.94699287], [80.26412964, 18.94052124], [80.26468658, 18.93732071], [80.26516724, 18.93456078], [80.26763916, 18.92878914], [80.27046967, 18.92491913], [80.29138947, 18.90759087], [80.29810333, 18.9004612], [80.30856323, 18.88616753], [80.30990601, 18.88480186], [80.31346893, 18.88117981], [80.3216629, 18.87483025], [80.32565308, 18.86996078], [80.33573151, 18.85611916], [80.33963776, 18.8483429], [80.34558105, 18.83393097], [80.34850311, 18.82394028], [80.34778595, 18.81594086], [80.34622192, 18.81108093], [80.33470154, 18.80611038], [80.31873322, 18.79598045], [80.30589294, 18.79434967], [80.29943848, 18.79353142], [80.29415894, 18.79059029], [80.29017639, 18.78625107], [80.27953339, 18.76785278], [80.27655029, 18.76485062], [80.27182007, 18.76222038], [80.26541901, 18.76316071], [80.26291656, 18.76428986], [80.26145172, 18.76497078], [80.26065063, 18.7650795], [80.25456238, 18.76595116], [80.24900055, 18.76525116], [80.24215698, 18.75974846], [80.2405014, 18.75661087], [80.23956299, 18.75221062], [80.24079895, 18.74868965], [80.24745178, 18.74355125], [80.25480652, 18.73613167], [80.25753784, 18.7312603], [80.26753998, 18.71796989], [80.26036835, 18.71409988], [80.24666595, 18.70132065], [80.24169159, 18.70022011], [80.23557281, 18.70042038], [80.22998047, 18.69753075], [80.22531891, 18.69614983], [80.22000885, 18.69919014], [80.2143631, 18.70112991], [80.20787811, 18.70046043], [80.20191193, 18.6974411], [80.19410706, 18.68853188], [80.19165802, 18.6836319], [80.19095612, 18.67897034], [80.18895721, 18.67558098], [80.17565155, 18.67589951], [80.1709671, 18.67733955], [80.16739655, 18.68007088], [80.16462708, 18.69029808], [80.1619873, 18.69403076], [80.15808105, 18.69594002], [80.15220642, 18.69527817], [80.14874268, 18.69324112], [80.14227295, 18.68625259], [80.13658905, 18.68680191], [80.130867, 18.68541145], [80.12129211, 18.68120956], [80.11841583, 18.67913246], [80.11599731, 18.67584991], [80.11081696, 18.67618942], [80.10655975, 18.67752838], [80.10054779, 18.68495941], [80.08695221, 18.6975708], [80.08444214, 18.70084], [80.0821228, 18.7024498], [80.0789032, 18.70133972], [80.07470703, 18.70256042], [80.06790924, 18.70870972], [80.06549072, 18.71326256], [80.06189728, 18.71651268], [80.05326843, 18.71779823], [80.0463562, 18.72092056], [80.0328598, 18.74644089], [80.02966309, 18.74869919], [80.01870728, 18.75101089], [80.0165329, 18.75702095], [80.01448822, 18.76012993], [80.01235199, 18.76675987], [80.00908661, 18.76857948], [79.99291992, 18.77351952], [79.98153687, 18.77428055], [79.95014954, 18.77990913], [79.94007111, 18.78179169], [79.93199158, 18.78442955], [79.9162674, 18.79734039], [79.90909576, 18.80669022], [79.89401245, 18.83083916], [79.90409851, 18.83488083], [79.92082214, 18.83621025], [79.92550659, 18.83754158], [79.93332672, 18.84504128], [79.93900299, 18.85889244], [79.94094849, 18.87738991], [79.94011688, 18.89673805], [79.94135284, 18.91576958], [79.94094086, 18.93766022], [79.93588257, 18.95763969], [79.93221283, 18.97158051], [79.93134308, 18.97479057], [79.93279266, 18.99570084], [79.93448639, 19.02169991], [79.93306732, 19.02968979], [79.92597961, 19.04249001], [79.91610718, 19.04735947], [79.90293884, 19.04797935], [79.89084625, 19.04545021], [79.88111115, 19.04138947], [79.87103271, 19.03554153], [79.85958862, 19.03462982], [79.85700989, 19.04220009], [79.86109924, 19.05994987], [79.8600769, 19.09095955], [79.85804749, 19.10411072], [79.86310577, 19.11582184], [79.87120819, 19.12269974], [79.90596771, 19.14178848], [79.92230988, 19.15712929], [79.92611694, 19.16094971], [79.94069672, 19.1644001], [79.94320679, 19.17060089], [79.94243622, 19.17588043], [79.93525696, 19.18385124], [79.92250824, 19.20340919], [79.91932678, 19.21501923], [79.92016602, 19.22640991], [79.93190002, 19.25932121], [79.9451828, 19.28412056], [79.94895935, 19.28886032], [79.96177673, 19.29749107], [79.96364594, 19.30653954], [79.9573822, 19.32447052], [79.95715332, 19.33456993], [79.96452332, 19.3506794], [79.96652222, 19.36088943], [79.96724701, 19.37458038], [79.9707489, 19.38212967], [79.97260284, 19.39158058], [79.97305298, 19.40102005], [79.97000122, 19.40946007], [79.95923615, 19.42591095], [79.94577026, 19.44078064], [79.94621277, 19.45093918], [79.94499969, 19.45881844], [79.94020844, 19.46450996], [79.93725586, 19.46696091], [79.93286896, 19.46912193], [79.92354584, 19.47758102], [79.91779327, 19.48554039], [79.911026, 19.49234009], [79.90223694, 19.49649048], [79.87822723, 19.5007019], [79.87021637, 19.50496101], [79.86379242, 19.51359749], [79.85623169, 19.51711082], [79.82821655, 19.53701019], [79.82315826, 19.54430962], [79.82063293, 19.552351], [79.81954956, 19.56148911], [79.81659698, 19.56900978], [79.81109619, 19.57384109], [79.8052063, 19.57675934], [79.79329681, 19.58008957], [79.78629303, 19.58965111], [79.78542328, 19.59358978], [79.77754974, 19.59767914], [79.76628876, 19.60015106], [79.7542572, 19.60233116], [79.74032593, 19.60313988], [79.7299118, 19.59656906], [79.71292877, 19.58333015], [79.70511627, 19.58122063], [79.69568634, 19.58109093], [79.68479156, 19.57916832], [79.67801666, 19.57656288], [79.66504669, 19.57716942], [79.65261841, 19.57669258], [79.6397171, 19.57500076], [79.6213913, 19.56509972], [79.61580658, 19.55862999], [79.61090851, 19.54917908], [79.60721588, 19.53946114], [79.60293579, 19.52106857], [79.60243988, 19.51452065], [79.60085297, 19.50795174], [79.59805298, 19.50377083], [79.59134674, 19.50173187], [79.58265686, 19.50305176], [79.57344055, 19.50663948], [79.56559753, 19.5109005], [79.55249786, 19.52004242], [79.54769897, 19.52608109], [79.54519653, 19.5340004], [79.5447464, 19.54271126], [79.54265594, 19.54852295], [79.53499603, 19.54807091], [79.52622223, 19.54606056], [79.51499176, 19.54195023], [79.51481628, 19.54076195]]]]}}, {\\\"id\\\": \\\"18\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.21_1\\\", \\\"HASC_1\\\": \\\"IN.MN\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Manipur\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -2.6, \\\"dalys_apm25_rate_6cod_mean_total\\\": 792.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1782.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -990.0, \\\"geo-id\\\": 18, \\\"hpm25_child_popweighted\\\": -149.0, \\\"hpm25_female_popweighted\\\": -171.3, \\\"hpm25_male_popweighted\\\": -123.3, \\\"location\\\": \\\"Manipur\\\", \\\"mort_apm25_6cod_mean_total\\\": 824.0, \\\"mort_hpm25_6cod_mean_total\\\": -1814.0, \\\"mort_tpm25_6cod_mean_total\\\": -990.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[94.25923157, 24.11981964], [94.2567215, 24.1066494], [94.25833893, 24.10159111], [94.26004791, 24.096241], [94.25969696, 24.08955956], [94.25403595, 24.0776825], [94.25022125, 24.07047844], [94.24717712, 24.06256294], [94.24645233, 24.06290054], [94.23993683, 24.06595039], [94.23307037, 24.06690025], [94.23522186, 24.05866051], [94.23677063, 24.05667877], [94.24357605, 24.04795074], [94.24532318, 24.04424286], [94.2315979, 24.02148056], [94.2256012, 24.0141201], [94.2203064, 24.00602913], [94.2154007, 23.99746132], [94.21029663, 23.99236107], [94.20130157, 23.97796822], [94.19449615, 23.96500969], [94.19354248, 23.95120049], [94.19683075, 23.9440403], [94.19596863, 23.93772125], [94.19042206, 23.93406105], [94.1834259, 23.9371109], [94.18180084, 23.93782043], [94.17690277, 23.93884087], [94.17077637, 23.93509293], [94.16951752, 23.92868996], [94.16896057, 23.91150093], [94.16822815, 23.88913918], [94.16503906, 23.86486053], [94.16146088, 23.85277939], [94.15766907, 23.85194778], [94.15544891, 23.8514595], [94.14714813, 23.85611916], [94.14614868, 23.85609245], [94.13929749, 23.85589981], [94.13514709, 23.84607124], [94.12882996, 23.84277916], [94.1228714, 23.84273148], [94.12264252, 23.84272957], [94.11479187, 23.85245132], [94.11476135, 23.85316277], [94.11411285, 23.86663055], [94.11161041, 23.87088013], [94.10418701, 23.87717056], [94.10096741, 23.88902283], [94.09609222, 23.89357185], [94.09060669, 23.89450073], [94.08545685, 23.89318085], [94.075737, 23.89306068], [94.06848145, 23.89562035], [94.06092834, 23.89730263], [94.05661011, 23.89760017], [94.05111694, 23.90043068], [94.04931641, 23.90739059], [94.04691315, 23.91337013], [94.04322052, 23.91800117], [94.03794098, 23.92056084], [94.03410339, 23.9221096], [94.02774811, 23.92604256], [94.021492, 23.93149185], [94.01769257, 23.93395042], [94.0133667, 23.93452072], [94.00804138, 23.93320084], [94.00152588, 23.93115997], [93.99543762, 23.93153954], [93.98963165, 23.93202972], [93.98158264, 23.93325996], [93.97638702, 23.93526077], [93.96938324, 23.93394089], [93.96224213, 23.93714905], [93.96179199, 23.94338989], [93.95996857, 23.94692039], [93.95378113, 23.95019913], [93.94161987, 23.95279121], [93.93580627, 23.95337105], [93.92637634, 23.95541], [93.9209671, 23.95677948], [93.91390228, 23.95745087], [93.90702057, 23.95713997], [93.90207672, 23.95561028], [93.89608002, 23.95482826], [93.89103699, 23.95178032], [93.88706207, 23.94746971], [93.88156128, 23.94713974], [93.87702179, 23.94688034], [93.87316895, 23.94391823], [93.8662262, 23.93791962], [93.84863281, 23.93807983], [93.8375473, 23.93208122], [93.82821655, 23.9314003], [93.81598663, 23.92982864], [93.80928802, 23.93261147], [93.80805969, 23.93312073], [93.80573273, 23.9373703], [93.80531311, 23.94721985], [93.80356598, 23.95111084], [93.80113983, 23.95555115], [93.79721832, 23.95664978], [93.79428864, 23.96282005], [93.79354858, 23.96751022], [93.78562164, 23.96944046], [93.77934265, 23.97787094], [93.77349091, 23.98240089], [93.77027893, 23.99001122], [93.7665863, 23.99698067], [93.76222229, 24.00414085], [93.75694275, 24.00949287], [93.74661255, 24.00854111], [93.7443924, 24.00123024], [93.73995209, 23.9991703], [93.73280334, 24.00180817], [93.72677612, 24.00383186], [93.72020721, 24.00556946], [93.71272278, 24.00523949], [93.70613098, 24.00643921], [93.69699097, 24.00747108], [93.68647766, 24.00967979], [93.67752075, 24.01106834], [93.67444611, 24.00808907], [93.6675415, 24.00540924], [93.66281891, 24.00470924], [93.65880585, 24.00724983], [93.65497589, 24.00998116], [93.65244293, 24.01350975], [93.6449585, 24.01408005], [93.63532257, 24.01338005], [93.62766266, 24.01522064], [93.62065887, 24.01424026], [93.61630249, 24.01074028], [93.61666107, 24.00296974], [93.61959839, 24.00000381], [93.62007904, 23.99952126], [93.62075043, 23.99529076], [93.62091064, 23.99119949], [93.61593628, 23.98147011], [93.61225891, 23.97714806], [93.60929108, 23.97344971], [93.60614777, 23.97136879], [93.60346222, 23.96959114], [93.59715271, 23.96726036], [93.59263611, 23.96799088], [93.58386993, 23.96846962], [93.58049011, 23.97008514], [93.58006287, 23.97029114], [93.57714844, 23.97789001], [93.57244873, 23.98324013], [93.56884003, 23.98867035], [93.5635376, 23.98957825], [93.56124878, 23.9856205], [93.55725861, 23.97966003], [93.55751801, 23.9701004], [93.55493164, 23.9652195], [93.5463562, 23.96326065], [93.53946686, 23.96327972], [93.53050232, 23.96077919], [93.52416992, 23.95473099], [93.51986694, 23.95049667], [93.51941681, 23.95005035], [93.51508331, 23.94716835], [93.50871277, 23.94890022], [93.50254059, 23.95578003], [93.49594879, 23.95716095], [93.48938751, 23.9615097], [93.48577118, 23.9675808], [93.47802734, 23.96949005], [93.47220612, 23.97068024], [93.46885681, 23.9739399], [93.46615601, 23.97919083], [93.46669769, 23.9875927], [93.46739197, 23.99201965], [93.46735382, 23.99282837], [93.46697998, 23.99930954], [93.46614075, 24.00024033], [93.46312714, 24.00358963], [93.45881653, 24.00966072], [93.45736694, 24.01506805], [93.45326233, 24.02285004], [93.44403076, 24.02775955], [93.44111633, 24.03471947], [93.43995667, 24.04356956], [93.43286896, 24.06166267], [93.42473602, 24.07171059], [93.42022705, 24.0760498], [93.41542816, 24.07921982], [93.4105072, 24.08167076], [93.40422058, 24.08429909], [93.39112854, 24.0882206], [93.38336182, 24.08932114], [93.37046051, 24.09222984], [93.36863708, 24.09255981], [93.36643219, 24.09296989], [93.36151886, 24.10020256], [93.35674286, 24.10906982], [93.3514328, 24.11241913], [93.3469162, 24.11296844], [93.34903717, 24.10510063], [93.35089874, 24.10156822], [93.35383606, 24.09768105], [93.34681702, 24.0922699], [93.34358215, 24.09436035], [93.33934021, 24.09320068], [93.33400726, 24.09012985], [93.33583069, 24.08537483], [93.33598328, 24.08497047], [93.33761597, 24.07892036], [93.33886719, 24.07232094], [93.3420105, 24.06743813], [93.33734894, 24.06093979], [93.33634949, 24.05669975], [93.33737183, 24.05340004], [93.31254578, 24.05413055], [93.29824829, 24.05158997], [93.28819275, 24.05154991], [93.28536987, 24.04652023], [93.27677917, 24.04021072], [93.27394867, 24.03392029], [93.25528717, 24.02379036], [93.25670624, 24.0288105], [93.25238037, 24.03383064], [93.2623291, 24.05772972], [93.26374054, 24.05774117], [93.26660919, 24.06026077], [93.26373291, 24.06778908], [93.26371765, 24.07282066], [93.24801636, 24.08533859], [93.24233246, 24.08657074], [93.2366333, 24.08403969], [93.22667694, 24.08653069], [93.22383881, 24.08401108], [93.22241974, 24.08148956], [93.22525024, 24.07396126], [93.22242737, 24.06767273], [93.22100067, 24.06137085], [93.21673584, 24.05006027], [93.19825745, 24.05249977], [93.19400787, 24.0562706], [93.17838287, 24.05409622], [93.17552185, 24.05369949], [93.16983795, 24.05495262], [93.16697693, 24.06121826], [93.16986847, 24.07127953], [93.1698761, 24.0750618], [93.16131592, 24.07756042], [93.15846252, 24.08381844], [93.14791107, 24.0880909], [93.14219666, 24.08678818], [93.13508606, 24.07921028], [93.13507843, 24.07291985], [93.12937164, 24.06408119], [93.12081909, 24.06026077], [93.11940765, 24.05647278], [93.11231232, 24.05519104], [93.11087799, 24.05014992], [93.10662842, 24.04886055], [93.10092163, 24.04508972], [93.09951019, 24.04883957], [93.1037674, 24.05262947], [93.10092926, 24.05639076], [93.1023407, 24.06269264], [93.10090637, 24.06645012], [93.10234833, 24.07401085], [93.09520721, 24.0802803], [93.08950806, 24.08405113], [93.08522797, 24.0903511], [93.07949066, 24.10297012], [93.07377625, 24.10049057], [93.06519318, 24.09427071], [93.05368805, 24.09069061], [93.03769684, 24.09518051], [93.03469849, 24.09924126], [93.03029633, 24.10083008], [93.02729797, 24.1036396], [93.021492, 24.10145187], [93.01410675, 24.10453033], [93.0096817, 24.10995293], [93.00068665, 24.11519241], [92.99642181, 24.11672974], [92.98929596, 24.1163311], [92.98477936, 24.11482048], [92.97637939, 24.11482048], [92.97486877, 24.11701965], [92.97360229, 24.12388039], [92.97756195, 24.12639046], [92.98606873, 24.12887955], [92.9894104, 24.13178062], [92.99286652, 24.1403904], [92.99092102, 24.14686966], [92.99112701, 24.15032959], [92.99308014, 24.15317917], [93.00067139, 24.15673065], [93.00544739, 24.1606102], [93.00550079, 24.16321182], [93.00331116, 24.17404938], [93.01091766, 24.18221283], [93.00309753, 24.19431114], [93.0030365, 24.19752121], [93.01236725, 24.19754028], [93.01661682, 24.20003128], [93.01799774, 24.20754814], [93.02229309, 24.21006012], [93.02368164, 24.21756935], [93.01940155, 24.22508812], [93.01940918, 24.22884941], [93.02658844, 24.23263168], [93.01803589, 24.23637009], [93.00670624, 24.25395966], [93.00673676, 24.26279068], [93.01391602, 24.27166939], [93.00821686, 24.28047943], [93.01107788, 24.28808022], [93.01821899, 24.29315948], [93.02391815, 24.3007412], [93.03523254, 24.31839943], [93.04337311, 24.34338951], [93.03176117, 24.34449005], [93.0215683, 24.34682083], [93.01933289, 24.35884857], [93.02011108, 24.36597252], [93.0220871, 24.37421989], [93.01709747, 24.37996101], [93.02435303, 24.3904705], [93.00049591, 24.40327072], [93.00644684, 24.41193008], [93.00889587, 24.40537071], [93.01599121, 24.40253067], [93.02921295, 24.40633965], [93.03916931, 24.41113091], [93.03932953, 24.41756821], [93.03215027, 24.42885971], [93.03674316, 24.44394112], [93.03790283, 24.46115112], [93.04825592, 24.46396065], [93.04852295, 24.47548294], [93.04572296, 24.48181915], [93.0357666, 24.49694824], [93.04432678, 24.50580025], [93.04001617, 24.51081085], [93.04141998, 24.51459122], [93.05282593, 24.51964951], [93.05282593, 24.52466965], [93.04846954, 24.53091049], [93.05130005, 24.53718948], [93.05268097, 24.5447197], [93.06121826, 24.55477905], [93.0655365, 24.54726982], [93.07269287, 24.56109047], [93.06111908, 24.57483292], [93.07122803, 24.57613182], [93.07845306, 24.57491112], [93.08714294, 24.57118034], [93.09622955, 24.58022118], [93.09726715, 24.58254051], [93.10447693, 24.58257294], [93.10697937, 24.58356094], [93.10675049, 24.58395958], [93.10444641, 24.58760262], [93.09866333, 24.59134293], [93.08854675, 24.59003067], [93.07981873, 24.59250069], [93.07541656, 24.59622955], [93.07538605, 24.60000038], [93.07678223, 24.60377121], [93.08676147, 24.61133003], [93.08673096, 24.61382103], [93.08233643, 24.61758041], [93.079422, 24.62132263], [93.07935333, 24.62634087], [93.08220673, 24.62760162], [93.08938599, 24.62763023], [93.08930206, 24.63389015], [93.0848465, 24.64767075], [93.08625793, 24.65143967], [93.08912659, 24.65270996], [93.09628296, 24.6527195], [93.09626007, 24.6564827], [93.09765625, 24.6590004], [93.09763336, 24.66276169], [93.09903717, 24.66653061], [93.103302, 24.67156029], [93.10470581, 24.67534256], [93.10469055, 24.67910004], [93.1018219, 24.68035126], [93.09754181, 24.67782021], [93.09324646, 24.67654991], [93.09179688, 24.67781067], [93.09179688, 24.68032074], [93.09320068, 24.68408012], [93.09319305, 24.68785286], [93.09028625, 24.69286919], [93.08452606, 24.69787025], [93.08306885, 24.70164108], [93.08020782, 24.70414162], [93.0758667, 24.71039009], [93.0786972, 24.71417046], [93.08878326, 24.70919037], [93.09303284, 24.71548271], [93.09443665, 24.72050858], [93.09298706, 24.72426033], [93.09442902, 24.7242794], [93.09729004, 24.72805023], [93.09725952, 24.73180962], [93.10441589, 24.73686981], [93.1072464, 24.74189949], [93.10579681, 24.74566078], [93.10292053, 24.74690056], [93.10293579, 24.74315071], [93.10150146, 24.74188042], [93.09864044, 24.74438095], [93.10147095, 24.74941063], [93.10003662, 24.75066948], [93.10002899, 24.75444031], [93.10427856, 24.76324081], [93.10566711, 24.76953125], [93.10280609, 24.77329063], [93.10132599, 24.77831078], [93.10706329, 24.78334045], [93.10562897, 24.78460121], [93.10558319, 24.78837013], [93.10845947, 24.7908802], [93.11270142, 24.80220985], [93.10978699, 24.80974007], [93.11122131, 24.81226158], [93.11979675, 24.81731033], [93.12267303, 24.81982994], [93.12269592, 24.8148098], [93.11984253, 24.81102943], [93.12127686, 24.80853081], [93.12700653, 24.80854034], [93.13134003, 24.80604172], [93.13706207, 24.81109047], [93.13994598, 24.80480957], [93.14285278, 24.80105972], [93.14428711, 24.79980087], [93.14861298, 24.7985611], [93.15148163, 24.79605103], [93.15293121, 24.79353905], [93.15294647, 24.78977966], [93.15724182, 24.79231071], [93.16153717, 24.79734039], [93.16581726, 24.79861069], [93.16867828, 24.80112839], [93.17442322, 24.80367088], [93.1758728, 24.79738808], [93.1772995, 24.79611969], [93.17875671, 24.79614067], [93.18017578, 24.79865074], [93.18017578, 24.80241966], [93.18158722, 24.80493927], [93.18589783, 24.80495071], [93.19020081, 24.80622101], [93.19307709, 24.80623055], [93.19449615, 24.80875015], [93.19735718, 24.81126022], [93.19877625, 24.81504059], [93.19590759, 24.8162899], [93.19159698, 24.82256126], [93.19300079, 24.82632065], [93.19728851, 24.83388138], [93.19297791, 24.83386993], [93.19297028, 24.83638191], [93.19438934, 24.83764076], [93.1958313, 24.83764076], [93.19870758, 24.83638954], [93.20155334, 24.84017181], [93.20012665, 24.84143066], [93.19869995, 24.84016037], [93.19727325, 24.84016037], [93.19438171, 24.84391975], [93.19580078, 24.84644127], [93.20155334, 24.84394073], [93.20152283, 24.85021973], [93.19864655, 24.8527298], [93.19719696, 24.85649109], [93.20007324, 24.85775948], [93.20584106, 24.85526085], [93.20870209, 24.85653114], [93.21013641, 24.85904121], [93.2142868, 24.86194992], [93.21618652, 24.86469078], [93.21906281, 24.86972046], [93.22194672, 24.87099266], [93.22480774, 24.87478065], [93.22908783, 24.87730026], [93.22621918, 24.88106918], [93.22908783, 24.88484001], [93.23339081, 24.88484955], [93.23483276, 24.88989067], [93.23049164, 24.89490128], [93.23338318, 24.89491081], [93.23338318, 24.89869118], [93.23622131, 24.90245056], [93.24195099, 24.90122032], [93.24337769, 24.90374184], [93.24336243, 24.90750122], [93.24188995, 24.91127014], [93.23899078, 24.91502953], [93.24043274, 24.91628075], [93.24185944, 24.91504097], [93.25045776, 24.91506195], [93.25325775, 24.91883087], [93.25019836, 24.93008041], [93.24450684, 24.93008041], [93.24304962, 24.93132973], [93.24720001, 24.93634033], [93.24849701, 24.94009972], [93.24707794, 24.94009972], [93.24143982, 24.93758965], [93.24003601, 24.93758011], [93.2399826, 24.93884277], [93.24131775, 24.94133949], [93.24407959, 24.94384003], [93.24693298, 24.94384956], [93.24983978, 24.94260025], [93.25411987, 24.94261932], [93.25110626, 24.94634819], [93.25092316, 24.95009995], [93.24938965, 24.95259285], [93.24923706, 24.95508003], [93.25354004, 24.95508957], [93.25950623, 24.9513607], [93.26241302, 24.95137024], [93.26082611, 24.95387077], [93.2605896, 24.95887184], [93.26332855, 24.96388054], [93.263237, 24.96637917], [93.25871277, 24.97265053], [93.2529068, 24.97262955], [93.25287628, 24.97514915], [93.25432587, 24.97891998], [93.25152588, 24.98142052], [93.25302124, 24.98266029], [93.25325775, 24.98637009], [93.25202179, 24.98880959], [93.25525665, 24.99240112], [93.25695801, 24.99602127], [93.25705719, 24.99847031], [93.25562286, 24.99971008], [93.25567627, 25.00220108], [93.2571106, 25.00094032], [93.26143646, 25.00092125], [93.26332092, 25.00423813], [93.26245117, 25.00602913], [93.25990295, 25.00645065], [93.25800323, 25.00420952], [93.2576828, 25.00350189], [93.25710297, 25.00319099], [93.2564621, 25.00311089], [93.25580597, 25.00325966], [93.25533295, 25.00364113], [93.25521088, 25.00420952], [93.253479, 25.00637054], [93.2518158, 25.00418091], [93.25121307, 25.00348091], [93.25064087, 25.00316048], [93.25, 25.00295067], [93.24935913, 25.00287247], [93.24868774, 25.00290108], [93.24807739, 25.00303078], [93.24746704, 25.00328064], [93.24694824, 25.00363159], [93.24669647, 25.00416756], [93.24916077, 25.01316071], [93.25171661, 25.01601982], [93.24884033, 25.01880074], [93.25382996, 25.02135086], [93.25778961, 25.02174187], [93.25836945, 25.02519989], [93.2556076, 25.0286808], [93.25984955, 25.03207016], [93.2638092, 25.0359211], [93.26391602, 25.03890991], [93.26291656, 25.0418396], [93.26835632, 25.04409027], [93.26946259, 25.04659081], [93.26779938, 25.04880905], [93.26818085, 25.04968071], [93.28449249, 25.05154991], [93.28687286, 25.04680061], [93.29189301, 25.04709053], [93.29698181, 25.04767036], [93.29933929, 25.05046082], [93.30008698, 25.05260086], [93.30240631, 25.05194092], [93.30245972, 25.04818916], [93.30459595, 25.04799271], [93.30425262, 25.05603027], [93.30892944, 25.05852127], [93.30607605, 25.0644207], [93.30879211, 25.07059288], [93.31079102, 25.07262993], [93.31272125, 25.07795906], [93.32234192, 25.08838081], [93.32363129, 25.09167099], [93.32950592, 25.09449959], [93.33577728, 25.09584045], [93.33917236, 25.10640907], [93.34046173, 25.11441994], [93.34435272, 25.1161499], [93.34436035, 25.12133026], [93.34644318, 25.12508965], [93.34921265, 25.12540817], [93.3470459, 25.12746048], [93.34607697, 25.12986946], [93.34889984, 25.13479042], [93.34686279, 25.13770103], [93.35101318, 25.14454079], [93.34855652, 25.15349007], [93.34883881, 25.15717125], [93.3473587, 25.16389084], [93.34915161, 25.16673088], [93.35307312, 25.18180084], [93.36081696, 25.19195938], [93.36222076, 25.19560814], [93.3685379, 25.20005035], [93.37056732, 25.20359039], [93.36958313, 25.20806122], [93.3780899, 25.21610069], [93.37950134, 25.22079086], [93.38198853, 25.22386932], [93.38479614, 25.2257309], [93.38551331, 25.22855759], [93.38762665, 25.23204041], [93.38710022, 25.24239159], [93.38871765, 25.24592018], [93.39459229, 25.25029945], [93.40357208, 25.26307106], [93.40634155, 25.26408005], [93.41205597, 25.26345062], [93.4207077, 25.26626015], [93.42330933, 25.27216148], [93.42331696, 25.27791023], [93.42642975, 25.28106117], [93.43863678, 25.28655052], [93.44481659, 25.29231071], [93.45197296, 25.29474831], [93.45996857, 25.29473114], [93.46559143, 25.29905128], [93.47402191, 25.3092804], [93.4751358, 25.29968071], [93.47463226, 25.29241943], [93.47258759, 25.28544044], [93.47675323, 25.27903938], [93.48338318, 25.27663994], [93.4875412, 25.2759304], [93.49489594, 25.27872086], [93.50437927, 25.27577019], [93.51078796, 25.27560806], [93.50417328, 25.25338173], [93.50514221, 25.24413109], [93.50843048, 25.24370956], [93.51642609, 25.24477005], [93.52060699, 25.2487812], [93.52935791, 25.24835968], [93.54120636, 25.2453804], [93.54717255, 25.24849129], [93.55471039, 25.25052834], [93.56313324, 25.24658966], [93.57009888, 25.23560905], [93.57076263, 25.23245049], [93.57485199, 25.22755051], [93.57820129, 25.22569084], [93.58164978, 25.22600937], [93.58584595, 25.22231102], [93.58805847, 25.22216988], [93.59028625, 25.21994972], [93.59197998, 25.21390915], [93.594841, 25.21113014], [93.59285736, 25.20667076], [93.59303284, 25.20391273], [93.5970993, 25.20429993], [93.60103607, 25.20239258], [93.60428619, 25.20432091], [93.60801697, 25.20205116], [93.61257935, 25.20619011], [93.62114716, 25.22491264], [93.62890625, 25.23574829], [93.63186646, 25.24291992], [93.63809204, 25.25039864], [93.64311981, 25.26001167], [93.64354706, 25.26588249], [93.64990997, 25.26911926], [93.65136719, 25.27366066], [93.65161896, 25.27902031], [93.66561127, 25.29842949], [93.66474915, 25.30424118], [93.66609192, 25.30828094], [93.67294312, 25.31151009], [93.67395782, 25.31728172], [93.67207336, 25.32871056], [93.68392181, 25.3296299], [93.68712616, 25.33121109], [93.69145203, 25.34741974], [93.69277954, 25.36158943], [93.69998169, 25.35942268], [93.711586, 25.35808945], [93.71804047, 25.36160088], [93.71897888, 25.37035942], [93.72310638, 25.37558174], [93.73100281, 25.38037109], [93.73979187, 25.38441849], [93.74131775, 25.38944054], [93.74006653, 25.39517975], [93.74198914, 25.39991951], [93.74666595, 25.40571022], [93.76033783, 25.41411972], [93.76441956, 25.41813087], [93.78106689, 25.42471123], [93.78053284, 25.42950058], [93.78447723, 25.43193817], [93.78810883, 25.43588066], [93.79020691, 25.44338036], [93.79374695, 25.4486599], [93.79836273, 25.45393181], [93.8024292, 25.46040916], [93.80522919, 25.46342087], [93.80899811, 25.46558952], [93.81388855, 25.48472977], [93.80760956, 25.49555969], [93.80404663, 25.49902916], [93.79724884, 25.50438118], [93.78846741, 25.50649071], [93.77339172, 25.49784088], [93.76934814, 25.49677277], [93.76579285, 25.49990082], [93.76428986, 25.51548195], [93.76931763, 25.51770973], [93.76818085, 25.52529144], [93.76895142, 25.53071022], [93.77097321, 25.53602028], [93.77063751, 25.54027939], [93.77182007, 25.54080963], [93.77948761, 25.5380497], [93.80784607, 25.54451942], [93.81594086, 25.5454483], [93.81971741, 25.54438972], [93.823349, 25.54816246], [93.82504272, 25.55599976], [93.83325958, 25.55642128], [93.83347321, 25.56137276], [93.83648682, 25.56306076], [93.84420776, 25.56169128], [93.85231781, 25.55864906], [93.86223602, 25.55752945], [93.87837219, 25.5619812], [93.89196014, 25.56842041], [93.90023804, 25.5687294], [93.90484619, 25.56742859], [93.9108963, 25.56752968], [93.91709137, 25.56672096], [93.91932678, 25.56402969], [93.93012238, 25.56538963], [93.94351959, 25.56343269], [93.94516754, 25.56263924], [93.95738983, 25.55675125], [93.96521759, 25.55657768], [93.97264862, 25.56118011], [93.97785187, 25.5661602], [93.98046875, 25.57125282], [94.00061035, 25.57388115], [94.00744629, 25.56985092], [94.01042175, 25.57131195], [94.01159668, 25.57274818], [94.01228333, 25.57529831], [94.0117569, 25.57909012], [94.00782776, 25.58752823], [94.00765228, 25.59094048], [94.01039886, 25.59539986], [94.01473236, 25.59613037], [94.0255127, 25.59338951], [94.02726746, 25.58798981], [94.03340912, 25.58470154], [94.03489685, 25.58148956], [94.03791809, 25.58192825], [94.03916168, 25.5830307], [94.03900909, 25.57986069], [94.04361725, 25.57748032], [94.04599762, 25.58094978], [94.05412292, 25.57675934], [94.06469727, 25.56637001], [94.06941986, 25.55898094], [94.08003998, 25.56159973], [94.08595276, 25.55973053], [94.09496307, 25.54644012], [94.09619904, 25.54171944], [94.09252167, 25.53796959], [94.09210968, 25.5327301], [94.1060791, 25.52890015], [94.12850952, 25.52588081], [94.13873291, 25.52370071], [94.14523315, 25.52763939], [94.14820099, 25.5316906], [94.15184021, 25.54185104], [94.15287781, 25.54784012], [94.16011047, 25.55525017], [94.16352844, 25.54992104], [94.16790771, 25.54701042], [94.17954254, 25.55018997], [94.18276978, 25.55325127], [94.19184875, 25.550951], [94.19487, 25.5524292], [94.19390869, 25.54219818], [94.19013977, 25.53462982], [94.19072723, 25.53078079], [94.19924927, 25.52276993], [94.20688629, 25.51395035], [94.20690155, 25.51164055], [94.21292877, 25.50817108], [94.2128067, 25.50282097], [94.21485138, 25.50024033], [94.21985626, 25.49962997], [94.22297668, 25.49677277], [94.22914124, 25.49600983], [94.23174286, 25.49831009], [94.25205994, 25.49907112], [94.25726318, 25.50341988], [94.26693726, 25.5024395], [94.27414703, 25.50299072], [94.27986908, 25.5054512], [94.28674316, 25.51169968], [94.29074097, 25.50951958], [94.29899597, 25.50070953], [94.30264282, 25.49463272], [94.30898285, 25.49380112], [94.3135376, 25.4944706], [94.32068634, 25.49928093], [94.32901001, 25.50835037], [94.3646698, 25.5214901], [94.38854218, 25.5365696], [94.40448761, 25.54089928], [94.4108963, 25.54351807], [94.41680908, 25.54194069], [94.42027283, 25.54265022], [94.42559052, 25.55291939], [94.4263916, 25.56145096], [94.42510223, 25.57299995], [94.42237854, 25.57599068], [94.42565918, 25.58147049], [94.43002319, 25.59272194], [94.43773651, 25.59585953], [94.44428253, 25.59601021], [94.44782257, 25.59804153], [94.44927216, 25.60108948], [94.47403717, 25.62164116], [94.49118042, 25.61979866], [94.49111176, 25.61865044], [94.49341583, 25.61433029], [94.4992981, 25.61650276], [94.49993896, 25.61881828], [94.5, 25.61885643], [94.50183105, 25.62002182], [94.50537109, 25.61699295], [94.50779724, 25.61894989], [94.50866699, 25.62689972], [94.5109024, 25.62990952], [94.51451111, 25.63049126], [94.52419281, 25.64343262], [94.52818298, 25.64429092], [94.53066254, 25.64258957], [94.53154755, 25.65012932], [94.53954315, 25.65108109], [94.54473877, 25.65754128], [94.5517807, 25.66246033], [94.55222321, 25.6674118], [94.56507874, 25.68082047], [94.56799316, 25.69222069], [94.57301331, 25.69765091], [94.57861328, 25.69599915], [94.58297729, 25.69320107], [94.58705139, 25.69189072], [94.5956192, 25.69128036], [94.59694672, 25.68691063], [94.58996582, 25.68124962], [94.58812714, 25.67727089], [94.58532715, 25.67485046], [94.58737183, 25.67180061], [94.58558655, 25.67000961], [94.58344269, 25.66522026], [94.58522034, 25.6617794], [94.58204651, 25.6606102], [94.58135223, 25.6573925], [94.57678986, 25.65283012], [94.57723236, 25.64833069], [94.57608795, 25.644701], [94.58693695, 25.64659119], [94.59519958, 25.64385033], [94.59455109, 25.6426506], [94.59050751, 25.64027023], [94.58377075, 25.63449097], [94.57850647, 25.62625122], [94.57691956, 25.62037277], [94.57282257, 25.61131287], [94.5686264, 25.6077919], [94.56690979, 25.60410118], [94.5651474, 25.6026001], [94.55957031, 25.59411049], [94.55574036, 25.58581161], [94.5615387, 25.57833099], [94.56040955, 25.56798935], [94.56465912, 25.56793976], [94.56137848, 25.56051064], [94.56289673, 25.54951096], [94.55986786, 25.54570961], [94.56347656, 25.53967285], [94.55827332, 25.53487968], [94.56125641, 25.53069115], [94.55899811, 25.52433968], [94.55741882, 25.5127697], [94.56817627, 25.50658989], [94.57459259, 25.50522995], [94.58500671, 25.49687004], [94.58719635, 25.49245071], [94.5908432, 25.48974991], [94.59488678, 25.48814964], [94.59736633, 25.48625946], [94.60748291, 25.48244095], [94.62534332, 25.46908951], [94.63297272, 25.46565819], [94.64823151, 25.46162033], [94.65645599, 25.458601], [94.65873718, 25.45705032], [94.66597748, 25.45540047], [94.66976166, 25.45536041], [94.68242645, 25.45973015], [94.68229675, 25.45659065], [94.68205261, 25.45050049], [94.67965698, 25.44240189], [94.67912292, 25.4329319], [94.67811584, 25.42653084], [94.67624664, 25.42058945], [94.67382813, 25.41620064], [94.67095184, 25.4125309], [94.65879822, 25.40951538], [94.65627289, 25.40889168], [94.64919281, 25.40635109], [94.64441681, 25.40160942], [94.6438446, 25.40029335], [94.64176941, 25.39902115], [94.638237, 25.39351082], [94.63495636, 25.39235115], [94.63117981, 25.38729095], [94.62741852, 25.37466812], [94.62760925, 25.36207008], [94.62770844, 25.35539818], [94.62211609, 25.33675957], [94.62162018, 25.33605766], [94.61898041, 25.33193016], [94.61519623, 25.32520103], [94.61315918, 25.32196045], [94.60957336, 25.31352043], [94.60688782, 25.30831718], [94.60192108, 25.29870033], [94.59867859, 25.28907013], [94.59887695, 25.28112984], [94.59809113, 25.27463913], [94.59925842, 25.2668705], [94.59716797, 25.25696182], [94.59353638, 25.24616814], [94.59192657, 25.23743057], [94.58872986, 25.22987938], [94.586586, 25.2250309], [94.58535767, 25.21574974], [94.59208679, 25.20548058], [94.59758759, 25.2000103], [94.60167694, 25.19519043], [94.60887146, 25.19104767], [94.61312866, 25.18947983], [94.61738586, 25.18979836], [94.62268066, 25.19128036], [94.63092041, 25.1903801], [94.63385773, 25.18720055], [94.63813782, 25.18156052], [94.64354706, 25.17653847], [94.64778137, 25.17441177], [94.6576767, 25.1724205], [94.66696167, 25.16818047], [94.67743683, 25.16500092], [94.68115997, 25.16126823], [94.68718719, 25.15787125], [94.6936264, 25.1595211], [94.69863892, 25.16063118], [94.70347595, 25.1597805], [94.70816803, 25.15385056], [94.71357727, 25.14990997], [94.72888184, 25.14371109], [94.73581696, 25.1428299], [94.74194336, 25.13941956], [94.74565887, 25.13659096], [94.74521637, 25.12684059], [94.74568939, 25.11870956], [94.74529266, 25.11123085], [94.74539948, 25.10689926], [94.7455368, 25.10166168], [94.74814606, 25.08989906], [94.74977875, 25.07995033], [94.75100708, 25.07542992], [94.75063324, 25.07064247], [94.75071716, 25.06351852], [94.74923706, 25.05793953], [94.74771881, 25.04927826], [94.74568176, 25.04442978], [94.74501038, 25.0394783], [94.74298096, 25.03010941], [94.74221039, 25.02524948], [94.73945618, 25.02049255], [94.73519135, 25.01268959], [94.73446655, 25.01178741], [94.72609711, 25.00131989], [94.71318817, 24.99369049], [94.70580292, 24.9835701], [94.70314026, 24.97827148], [94.70302582, 24.97736931], [94.70189667, 24.96844101], [94.70381165, 24.96355057], [94.70572662, 24.9596405], [94.70913696, 24.95582008], [94.71357727, 24.95297813], [94.71714783, 24.94645119], [94.71907043, 24.94247055], [94.7146759, 24.93952942], [94.70585632, 24.9342804], [94.70150757, 24.92756081], [94.70097351, 24.92631912], [94.69379425, 24.90971184], [94.69300842, 24.90789032], [94.6920929, 24.89986229], [94.68894196, 24.89502144], [94.68601227, 24.8924427], [94.67971039, 24.88689995], [94.67201233, 24.8821907], [94.66162872, 24.87742043], [94.65683746, 24.8735981], [94.65792084, 24.86717033], [94.65608978, 24.86285019], [94.65445709, 24.8612442], [94.64816284, 24.85507011], [94.64122009, 24.84873962], [94.63967896, 24.84581947], [94.6378479, 24.84235954], [94.63478851, 24.82930946], [94.63540649, 24.82306099], [94.63536072, 24.8224926], [94.63478851, 24.81476021], [94.63244629, 24.81092072], [94.62732697, 24.80429077], [94.62483215, 24.7958107], [94.62530518, 24.78602982], [94.62536621, 24.78479958], [94.62961578, 24.77727127], [94.63301849, 24.77281189], [94.63330841, 24.76496124], [94.62504578, 24.75402069], [94.62408447, 24.75285339], [94.62121582, 24.74936104], [94.61767578, 24.74407005], [94.61238861, 24.73356056], [94.61219025, 24.73279953], [94.61134338, 24.72960091], [94.61084747, 24.72211266], [94.60721588, 24.71994972], [94.59937286, 24.7152729], [94.59098816, 24.71092987], [94.5845108, 24.71486282], [94.58650208, 24.72233963], [94.58580017, 24.73002815], [94.58165741, 24.73134041], [94.5776062, 24.73019028], [94.57456207, 24.72561836], [94.57344055, 24.7220211], [94.57537079, 24.71857071], [94.57556152, 24.71751022], [94.57656097, 24.71206093], [94.57061768, 24.71157074], [94.56739044, 24.7139492], [94.56247711, 24.71833038], [94.55665588, 24.7191906], [94.55098724, 24.71653938], [94.54662323, 24.7074604], [94.5493927, 24.70217705], [94.55076599, 24.6995697], [94.55294037, 24.69277954], [94.5507431, 24.67491913], [94.54714966, 24.66646004], [94.54059601, 24.64901161], [94.53771973, 24.64376068], [94.53148651, 24.63239098], [94.52079773, 24.61679077], [94.50753021, 24.60154915], [94.50241852, 24.59635925], [94.5, 24.5942955], [94.49823761, 24.5927906], [94.48987579, 24.58916092], [94.4853363, 24.58224106], [94.47828674, 24.57905006], [94.47252655, 24.57793999], [94.46549225, 24.57555962], [94.45954895, 24.56676102], [94.45829773, 24.56291008], [94.45584106, 24.55532074], [94.45015717, 24.54273033], [94.44547272, 24.53148842], [94.44049072, 24.52042961], [94.43657684, 24.51594925], [94.43512726, 24.51107979], [94.43238831, 24.50424004], [94.42959595, 24.49333954], [94.42154694, 24.49051094], [94.42021942, 24.49041748], [94.40898132, 24.48963165], [94.40341949, 24.48777962], [94.40618134, 24.48158836], [94.41149902, 24.46965027], [94.4031601, 24.46503067], [94.40045166, 24.46207047], [94.40796661, 24.45379066], [94.40891266, 24.44412041], [94.40748596, 24.43122101], [94.40390778, 24.42114067], [94.39916992, 24.41314125], [94.39163971, 24.40969086], [94.39093781, 24.40950966], [94.38340759, 24.40757942], [94.37438965, 24.40476036], [94.36680603, 24.40455055], [94.36534119, 24.39967918], [94.36752319, 24.39831924], [94.37631989, 24.3928299], [94.3861084, 24.38462067], [94.38336945, 24.37940979], [94.37754822, 24.37105942], [94.36936188, 24.36190987], [94.35573578, 24.34648132], [94.35175323, 24.3420105], [94.34706879, 24.33942032], [94.3400116, 24.33896255], [94.33481598, 24.33862114], [94.32634735, 24.3389492], [94.3252182, 24.33416939], [94.32685852, 24.33064079], [94.32753754, 24.32300949], [94.32789612, 24.31899071], [94.32824707, 24.30607033], [94.32798767, 24.29243088], [94.32177734, 24.27594948], [94.31478882, 24.25975037], [94.31324768, 24.25407982], [94.30725861, 24.24864006], [94.3037796, 24.24548149], [94.29514313, 24.239851], [94.29161072, 24.22307968], [94.29037476, 24.22000885], [94.28765869, 24.21327019], [94.28507233, 24.20261955], [94.28444672, 24.19161987], [94.28372955, 24.17988014], [94.27973938, 24.17593193], [94.27861023, 24.17561531], [94.26650238, 24.17224121], [94.2627182, 24.1677475], [94.26010895, 24.15575981], [94.25992584, 24.15466118], [94.25798798, 24.14294815], [94.25905609, 24.13165092], [94.25923157, 24.11981964]]]}}, {\\\"id\\\": \\\"19\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.22_1\\\", \\\"HASC_1\\\": \\\"IN.ML\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Meghalaya\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -13.6, \\\"dalys_apm25_rate_6cod_mean_total\\\": 736.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1813.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1077.0, \\\"geo-id\\\": 19, \\\"hpm25_child_popweighted\\\": -186.6, \\\"hpm25_female_popweighted\\\": -214.5, \\\"hpm25_male_popweighted\\\": -154.4, \\\"location\\\": \\\"Meghalaya\\\", \\\"mort_apm25_6cod_mean_total\\\": 923.0, \\\"mort_hpm25_6cod_mean_total\\\": -2232.0, \\\"mort_tpm25_6cod_mean_total\\\": -1308.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[91.28647614, 25.1854763], [91.28707123, 25.18662834], [91.28801727, 25.18741226], [91.28809357, 25.18811798], [91.2885437, 25.18954086], [91.28861237, 25.18993759], [91.28858185, 25.19023323], [91.2893219, 25.19075584], [91.29007721, 25.19115067], [91.29115295, 25.19153023], [91.29141998, 25.19176674], [91.2919693, 25.19232368], [91.29203033, 25.19238281], [91.29213715, 25.19343758], [91.2912674, 25.19379044], [91.29042816, 25.19431114], [91.28981018, 25.19463539], [91.28913879, 25.19499016], [91.28797913, 25.19537544], [91.28616333, 25.19593811], [91.28512573, 25.19630432], [91.28462982, 25.19644737], [91.28256989, 25.19673729], [91.28166199, 25.19681358], [91.27887726, 25.19792366], [91.27613068, 25.19916725], [91.27527618, 25.20006752], [91.27488708, 25.20043373], [91.27358246, 25.20149994], [91.27256012, 25.20249939], [91.27159882, 25.20339966], [91.27098083, 25.20397758], [91.26966095, 25.20382118], [91.26580811, 25.20246124], [91.2637558, 25.2005806], [91.26117706, 25.19952011], [91.25881195, 25.19874191], [91.25798798, 25.19618034], [91.2557373, 25.19511032], [91.25154877, 25.19462013], [91.2505722, 25.19459534], [91.25053406, 25.19507599], [91.25058746, 25.19527626], [91.25063324, 25.19548416], [91.25074768, 25.19577599], [91.25019073, 25.19610596], [91.24925995, 25.19669724], [91.24861145, 25.19710922], [91.24813843, 25.19738007], [91.24768066, 25.19768333], [91.24726105, 25.19789505], [91.24649811, 25.19768906], [91.24638367, 25.1979084], [91.24613953, 25.19782448], [91.24597931, 25.19761467], [91.24494934, 25.19734192], [91.24391937, 25.19707298], [91.24312592, 25.19706345], [91.24274445, 25.19703484], [91.24121094, 25.19687653], [91.24088287, 25.19685364], [91.24063873, 25.19683647], [91.23990631, 25.19687271], [91.23802185, 25.19577026], [91.2354126, 25.1953392], [91.2335434, 25.1955204], [91.23139191, 25.19703102], [91.23091125, 25.19711304], [91.2305069, 25.1970005], [91.23022461, 25.19700623], [91.22995758, 25.19705772], [91.22988129, 25.19707108], [91.22920227, 25.19740677], [91.2289505, 25.19745064], [91.22858429, 25.1977272], [91.22803497, 25.19824028], [91.22789001, 25.19837379], [91.22763824, 25.19860268], [91.22756958, 25.1985321], [91.22740936, 25.19836235], [91.22673798, 25.19885254], [91.22511292, 25.19993019], [91.22491455, 25.20002937], [91.22441864, 25.20028305], [91.22328186, 25.19920349], [91.22319794, 25.19912529], [91.22184753, 25.1995182], [91.22108459, 25.19985199], [91.22079468, 25.19998169], [91.21971893, 25.20016098], [91.21912384, 25.20018005], [91.21814728, 25.20023918], [91.21729279, 25.20025635], [91.21697998, 25.20029831], [91.2166748, 25.20025063], [91.21577454, 25.20035934], [91.21521759, 25.20038414], [91.21458435, 25.20028305], [91.21450043, 25.20028305], [91.21401978, 25.20029068], [91.21376038, 25.20032501], [91.21352386, 25.20035553], [91.21324921, 25.20034981], [91.21156311, 25.20041466], [91.2110672, 25.20043373], [91.21076202, 25.20045662], [91.20987701, 25.20057678], [91.20851135, 25.20070648], [91.20781708, 25.20081329], [91.20701599, 25.20092773], [91.20693207, 25.20094109], [91.20623016, 25.20100975], [91.20565033, 25.20106888], [91.2046814, 25.20107651], [91.20249176, 25.20109749], [91.20052338, 25.20111656], [91.19957733, 25.20121002], [91.19868469, 25.20144272], [91.19776154, 25.20176888], [91.19709015, 25.20184517], [91.19631195, 25.20185661], [91.19513702, 25.20190811], [91.1946106, 25.20192528], [91.19374847, 25.20179939], [91.19291687, 25.20163727], [91.19303131, 25.20137596], [91.19364929, 25.1999321], [91.1937027, 25.19980049], [91.19377136, 25.19958305], [91.19378662, 25.19945145], [91.19384003, 25.19927788], [91.19389343, 25.19913292], [91.19393921, 25.19894409], [91.19400787, 25.19874001], [91.1940918, 25.19850731], [91.1941452, 25.19835281], [91.18997192, 25.19712067], [91.18353271, 25.19590187], [91.17736053, 25.19483948], [91.17215729, 25.19433022], [91.16526794, 25.19422913], [91.16055298, 25.19442749], [91.15608215, 25.19608116], [91.1525116, 25.19556046], [91.14576721, 25.19490051], [91.14420319, 25.19474983], [91.13828278, 25.19357109], [91.13201904, 25.19332123], [91.12754059, 25.19336128], [91.12119293, 25.1939106], [91.11734009, 25.19458961], [91.11673737, 25.19457436], [91.11507416, 25.19471359], [91.1129837, 25.19485092], [91.10875702, 25.19496918], [91.10845184, 25.19500923], [91.10810852, 25.19501305], [91.10784149, 25.19504929], [91.10736084, 25.19512177], [91.10597229, 25.19533348], [91.10562134, 25.19537163], [91.10498047, 25.19560051], [91.10439301, 25.19581032], [91.10384369, 25.19598007], [91.10295868, 25.19611168], [91.10194397, 25.1962471], [91.10047913, 25.19645882], [91.09929657, 25.19651985], [91.09909821, 25.19650269], [91.09823608, 25.19653893], [91.09731293, 25.19656944], [91.09382629, 25.19685173], [91.09331512, 25.19688225], [91.09129333, 25.19700432], [91.09085846, 25.19690323], [91.08905792, 25.19669724], [91.08853912, 25.1967144], [91.0872879, 25.19647598], [91.08683014, 25.19642639], [91.08520508, 25.19643784], [91.08482361, 25.19643211], [91.08290863, 25.19673538], [91.08290863, 25.19688225], [91.08118439, 25.19696236], [91.08057404, 25.19691277], [91.08016968, 25.1969738], [91.0797348, 25.19707489], [91.07872009, 25.19731331], [91.07730865, 25.19769287], [91.0769043, 25.19776154], [91.07535553, 25.19835281], [91.07495117, 25.1985054], [91.07442474, 25.19870186], [91.07424927, 25.19874001], [91.07395172, 25.19880295], [91.0735321, 25.19880295], [91.07341003, 25.1987648], [91.07234192, 25.19851112], [91.07150269, 25.19837952], [91.07110596, 25.19835472], [91.06996918, 25.19842911], [91.06957245, 25.19852066], [91.06951904, 25.19807625], [91.06950378, 25.19746971], [91.06956482, 25.19699669], [91.06957245, 25.19692039], [91.06967926, 25.19656372], [91.06977844, 25.19631195], [91.07001495, 25.19614029], [91.07089996, 25.19572258], [91.07119751, 25.1955471], [91.07143402, 25.19535446], [91.07170105, 25.19489479], [91.07165527, 25.19424057], [91.07167053, 25.19372368], [91.07181549, 25.19347], [91.07009888, 25.19234467], [91.06951141, 25.19239235], [91.06908417, 25.19210625], [91.06829834, 25.19199371], [91.0680542, 25.19187737], [91.06781006, 25.19164276], [91.06748199, 25.19173241], [91.06703186, 25.1916523], [91.06581116, 25.19164467], [91.06539917, 25.19151115], [91.06461334, 25.1913681], [91.06390381, 25.19136047], [91.06286621, 25.19134712], [91.06195068, 25.19149971], [91.06082153, 25.19175529], [91.05774689, 25.19205666], [91.05702972, 25.19223404], [91.05581665, 25.19244576], [91.05508423, 25.19255066], [91.054245, 25.19238853], [91.05413055, 25.19236946], [91.05340576, 25.19219589], [91.05324554, 25.19213104], [91.05290985, 25.19194221], [91.0524826, 25.19158936], [91.05223083, 25.19135666], [91.05190277, 25.19113159], [91.05157471, 25.19099236], [91.05149841, 25.19099045], [91.0511322, 25.19098282], [91.05107117, 25.19070053], [91.05086517, 25.1903553], [91.0506897, 25.19018364], [91.05033112, 25.19001579], [91.05019379, 25.18996239], [91.04992676, 25.18986511], [91.04969025, 25.1898613], [91.04901886, 25.18999481], [91.04888916, 25.19004822], [91.0488205, 25.19007683], [91.04850006, 25.19040108], [91.04795837, 25.19028854], [91.04748535, 25.18979454], [91.04724121, 25.18960381], [91.04677582, 25.18935776], [91.04524994, 25.18891144], [91.04512024, 25.18887711], [91.04340363, 25.18826675], [91.04264069, 25.18825722], [91.04226685, 25.18812561], [91.04153442, 25.18776894], [91.04118347, 25.18775368], [91.04084015, 25.18773842], [91.04023743, 25.1877594], [91.04023743, 25.18811035], [91.04017639, 25.18838882], [91.0401001, 25.18872261], [91.03948212, 25.18863487], [91.03935242, 25.18806839], [91.03913879, 25.18723106], [91.03900909, 25.18694115], [91.03847504, 25.1864624], [91.03833771, 25.18639565], [91.03813934, 25.18638039], [91.03797913, 25.18640327], [91.03786469, 25.18642235], [91.03773499, 25.18644333], [91.03697968, 25.18673897], [91.03670502, 25.18686104], [91.03630829, 25.18690872], [91.03538513, 25.18682671], [91.03522491, 25.18673325], [91.03477478, 25.18639183], [91.03425598, 25.18643951], [91.03406525, 25.18644524], [91.03395081, 25.18644142], [91.03348541, 25.1864357], [91.03214264, 25.18640709], [91.03193665, 25.18576813], [91.03070068, 25.18578529], [91.03033447, 25.18524361], [91.02967072, 25.18541527], [91.027771, 25.18587875], [91.02700043, 25.18593788], [91.02666473, 25.18557549], [91.02597809, 25.18566132], [91.02561951, 25.18572426], [91.02477264, 25.18580437], [91.02465057, 25.1857872], [91.02437592, 25.18574905], [91.0236969, 25.1856575], [91.02326965, 25.185812], [91.02272034, 25.1861763], [91.02232361, 25.18654251], [91.02185059, 25.18656731], [91.02137756, 25.18682098], [91.02095795, 25.1870842], [91.02063751, 25.18679428], [91.02011871, 25.1870842], [91.01967621, 25.18708992], [91.01903534, 25.18708611], [91.01903534, 25.18679047], [91.01908875, 25.18632126], [91.0190506, 25.18589783], [91.01885223, 25.18464088], [91.01869202, 25.18392944], [91.01735687, 25.18385887], [91.01609802, 25.18377876], [91.01594543, 25.18317604], [91.01284027, 25.18313599], [91.01221466, 25.18306541], [91.01184082, 25.18297768], [91.01137543, 25.18281555], [91.01092529, 25.18264389], [91.01048279, 25.18247032], [91.01011658, 25.18268394], [91.00957489, 25.18317604], [91.00939178, 25.18331146], [91.00809479, 25.18281555], [91.00817871, 25.1815052], [91.00730133, 25.18090439], [91.00682831, 25.18064117], [91.00653076, 25.18053246], [91.00543976, 25.18025589], [91.0045929, 25.18030548], [91.00360107, 25.18048668], [91.00357819, 25.18058205], [91.00335693, 25.18152046], [91.00191498, 25.18141747], [91.00195313, 25.18102455], [91.00195313, 25.18069458], [91.00196075, 25.18051338], [91.00165558, 25.18051147], [91.00119019, 25.18055344], [91.00065613, 25.18020058], [90.99910736, 25.17941666], [90.99887848, 25.17934799], [90.9985733, 25.17928314], [90.99797058, 25.17918205], [90.99784851, 25.17944145], [90.99777985, 25.17959023], [90.99728394, 25.1794014], [90.99718475, 25.17898369], [90.99596405, 25.17877769], [90.99555969, 25.17871094], [90.99554443, 25.17856216], [90.99455261, 25.17841339], [90.99367523, 25.17825699], [90.9927597, 25.177948], [90.99235535, 25.17827797], [90.99188995, 25.1779995], [90.99127197, 25.17770195], [90.98944855, 25.17673111], [90.98908234, 25.17652702], [90.98786926, 25.17603111], [90.98726654, 25.17632103], [90.98554993, 25.17552185], [90.98530579, 25.17535782], [90.98493958, 25.17517471], [90.98468781, 25.17511559], [90.98432922, 25.17506218], [90.98339081, 25.17500496], [90.98309326, 25.17499542], [90.98287201, 25.17501259], [90.98208618, 25.17506599], [90.9803009, 25.17527008], [90.98009491, 25.1750946], [90.98000336, 25.17503166], [90.97952271, 25.17477608], [90.97919464, 25.17464447], [90.97763824, 25.17420769], [90.97727966, 25.17412758], [90.9770813, 25.17414093], [90.97593689, 25.174263], [90.97528839, 25.17438507], [90.97377777, 25.17499352], [90.97354126, 25.1751461], [90.97322083, 25.17502403], [90.97303772, 25.17516899], [90.97251129, 25.17469788], [90.97237396, 25.17484474], [90.97144318, 25.1746254], [90.97097778, 25.17442322], [90.97033691, 25.17374039], [90.96920013, 25.17306519], [90.96846008, 25.17253113], [90.96792603, 25.17232132], [90.96729279, 25.17196655], [90.96595764, 25.17141533], [90.96533203, 25.17102814], [90.96508026, 25.17101288], [90.96507263, 25.17183304], [90.96485138, 25.17187881], [90.96418762, 25.17201042], [90.96413422, 25.17142677], [90.9631424, 25.17146111], [90.96303558, 25.17146492], [90.96192169, 25.17103004], [90.96157837, 25.17105293], [90.96131134, 25.17089081], [90.96109009, 25.17080688], [90.96096802, 25.17059708], [90.96077728, 25.17043495], [90.96070099, 25.17040443], [90.96065521, 25.17028427], [90.96033478, 25.17035294], [90.96014404, 25.17037582], [90.95983887, 25.17038345], [90.95874023, 25.17028427], [90.95864868, 25.17043495], [90.95870209, 25.17053413], [90.95830536, 25.17056084], [90.95738983, 25.17064095], [90.95691681, 25.1707077], [90.95645142, 25.17081833], [90.95555878, 25.17097092], [90.95484924, 25.17090988], [90.9540329, 25.17080116], [90.95353699, 25.17071533], [90.95272064, 25.17050552], [90.95237732, 25.17039108], [90.95191956, 25.17020988], [90.95154572, 25.17030144], [90.95162201, 25.17053223], [90.95094299, 25.17062378], [90.95056915, 25.17068863], [90.95024109, 25.17071533], [90.9499588, 25.17074966], [90.94876099, 25.17089272], [90.94829559, 25.17002296], [90.94802856, 25.16952515], [90.94769287, 25.16883659], [90.94759369, 25.16838837], [90.94644165, 25.16768456], [90.94497681, 25.16765976], [90.94307709, 25.16764259], [90.94242859, 25.16713142], [90.9416275, 25.16652298], [90.94058228, 25.16644669], [90.93930817, 25.16599274], [90.93822479, 25.16564941], [90.93771362, 25.16535378], [90.93687439, 25.16488647], [90.93597412, 25.1648941], [90.93497467, 25.16490364], [90.93375397, 25.16471672], [90.9331665, 25.16472244], [90.93187714, 25.16425705], [90.93051147, 25.16387558], [90.92878723, 25.16340637], [90.92871857, 25.16342926], [90.92850494, 25.16338539], [90.92857361, 25.16324615], [90.92848206, 25.16308594], [90.9282608, 25.16307068], [90.92816925, 25.16299057], [90.92815399, 25.16275024], [90.92796326, 25.1625042], [90.92789459, 25.16233826], [90.92657471, 25.16254234], [90.92210388, 25.16321564], [90.92191315, 25.16321182], [90.92127991, 25.16322708], [90.92067719, 25.16322327], [90.91996002, 25.16320419], [90.91957092, 25.16336823], [90.91929626, 25.16335487], [90.91915131, 25.1633873], [90.91887665, 25.16345596], [90.9187088, 25.16347313], [90.91847229, 25.16343689], [90.91828918, 25.16321564], [90.91817474, 25.16318893], [90.91808319, 25.16314507], [90.91794586, 25.1628952], [90.91747284, 25.16288376], [90.91573334, 25.16274071], [90.9146347, 25.16277313], [90.9136734, 25.16280937], [90.91307068, 25.16274261], [90.91307831, 25.16293716], [90.91278076, 25.16317749], [90.91255951, 25.16313362], [90.91249847, 25.16333389], [90.91207123, 25.16316605], [90.91220093, 25.16289902], [90.91203308, 25.16270638], [90.9108963, 25.16265678], [90.91002655, 25.16262627], [90.90953064, 25.16253853], [90.90885925, 25.16249847], [90.90785217, 25.16239548], [90.90764618, 25.16265869], [90.9074707, 25.16269684], [90.9072876, 25.162714], [90.90724945, 25.16252708], [90.90718842, 25.1624279], [90.90692902, 25.16237831], [90.90679932, 25.16230774], [90.90550232, 25.16210938], [90.90448761, 25.16200066], [90.90407562, 25.16211128], [90.90401459, 25.16230202], [90.90372467, 25.16261292], [90.90352631, 25.16267586], [90.90338898, 25.16275215], [90.90322876, 25.16285706], [90.90297699, 25.16296768], [90.902771, 25.16275406], [90.90262604, 25.16277122], [90.9022522, 25.162817], [90.90171051, 25.16268158], [90.90158844, 25.16266441], [90.90142822, 25.16283035], [90.90129089, 25.16292], [90.90114594, 25.16307068], [90.90080261, 25.16334152], [90.90084839, 25.16348839], [90.90060425, 25.16353989], [90.90026855, 25.16378593], [90.90032196, 25.16385651], [90.9005661, 25.16414642], [90.89990234, 25.16405487], [90.90015411, 25.16437149], [90.8996582, 25.16464424], [90.89903259, 25.16444969], [90.89480591, 25.16280174], [90.88568878, 25.16426277], [90.87934875, 25.16115189], [90.87610626, 25.15857124], [90.8758316, 25.15834999], [90.87091064, 25.1587429], [90.86695862, 25.1561203], [90.86358643, 25.15785027], [90.85835266, 25.15584946], [90.85353851, 25.15577126], [90.8499527, 25.15666008], [90.84636688, 25.1580677], [90.84615326, 25.158041], [90.84511566, 25.15835762], [90.84439087, 25.15857697], [90.84420013, 25.15891647], [90.84342194, 25.15921974], [90.84028625, 25.15899086], [90.83670044, 25.15974045], [90.82726288, 25.1609211], [90.82446289, 25.16113091], [90.82357788, 25.16288376], [90.82328033, 25.16296577], [90.82305145, 25.16301918], [90.82212067, 25.1632328], [90.82144165, 25.16336823], [90.82040405, 25.16314507], [90.82032776, 25.16305542], [90.82021332, 25.16307259], [90.81984711, 25.16292191], [90.81971741, 25.16292763], [90.81948853, 25.16274261], [90.81912231, 25.16305161], [90.81904602, 25.16324234], [90.81913757, 25.16356277], [90.81923676, 25.16394424], [90.81917572, 25.16425323], [90.81874847, 25.16520691], [90.81713104, 25.16419029], [90.81440735, 25.16250038], [90.80896759, 25.16504097], [90.80879211, 25.16512108], [90.80858612, 25.16521835], [90.80851746, 25.16525078], [90.80831909, 25.16535759], [90.80779266, 25.16550446], [90.80769348, 25.16557121], [90.80751038, 25.16558647], [90.80710602, 25.1658268], [90.80691528, 25.1658268], [90.80661774, 25.16588593], [90.80623627, 25.16601181], [90.80583191, 25.16605377], [90.80529785, 25.16638374], [90.80501556, 25.16640091], [90.80487061, 25.16646194], [90.80477142, 25.1667347], [90.80467224, 25.16682434], [90.80467987, 25.16692352], [90.80471802, 25.16723251], [90.80450439, 25.16742897], [90.80440521, 25.16730118], [90.80418396, 25.16750526], [90.80394745, 25.16810989], [90.80406189, 25.16968536], [90.80444336, 25.17102432], [90.80450439, 25.17112923], [90.80462646, 25.17139626], [90.80443573, 25.17180061], [90.80439758, 25.17187881], [90.80445099, 25.17197037], [90.80423737, 25.1720295], [90.80312347, 25.17325211], [90.80306244, 25.17317581], [90.80273438, 25.17296982], [90.80263519, 25.17284966], [90.80214691, 25.17305183], [90.80168915, 25.17318726], [90.8014679, 25.17328453], [90.80116272, 25.17336273], [90.80104065, 25.17340851], [90.80032349, 25.17359924], [90.80014038, 25.17369461], [90.79992676, 25.17390633], [90.79954529, 25.17410278], [90.79884338, 25.17437363], [90.79867554, 25.17447662], [90.79839325, 25.17472267], [90.79758453, 25.17542267], [90.79745483, 25.17560196], [90.79701233, 25.17598343], [90.79654694, 25.17663956], [90.79627228, 25.17697144], [90.79620361, 25.17699814], [90.79593658, 25.17730331], [90.79589081, 25.17738152], [90.79581451, 25.17762947], [90.7957077, 25.17779922], [90.79560852, 25.17807579], [90.79560852, 25.17819023], [90.79534149, 25.17853546], [90.79523468, 25.17914581], [90.79504395, 25.18023682], [90.79489136, 25.18129158], [90.79464722, 25.18137932], [90.79386139, 25.18122101], [90.79370117, 25.18091774], [90.79268646, 25.18032646], [90.79235077, 25.18039322], [90.79226685, 25.18060684], [90.79190826, 25.18057251], [90.79149628, 25.18042374], [90.78983307, 25.17980385], [90.78904724, 25.17972755], [90.78822327, 25.17934418], [90.78790283, 25.17925835], [90.78723907, 25.1788311], [90.78713989, 25.17887878], [90.78694916, 25.17892075], [90.78668213, 25.17914009], [90.78657532, 25.17923355], [90.78546143, 25.1791153], [90.78543091, 25.17900467], [90.78525543, 25.17892265], [90.78491211, 25.17922783], [90.78474426, 25.17925453], [90.78443146, 25.17962646], [90.7842865, 25.17967796], [90.78412628, 25.179636], [90.78407288, 25.1795845], [90.78398895, 25.17951393], [90.78392792, 25.1794529], [90.7838974, 25.17957497], [90.78388977, 25.17988586], [90.78404236, 25.18004608], [90.78411865, 25.18023491], [90.78421021, 25.18045235], [90.78408813, 25.18071175], [90.78404236, 25.18089104], [90.78409576, 25.18142319], [90.78382874, 25.1812439], [90.78367615, 25.18124771], [90.78353119, 25.18124962], [90.78304291, 25.18110085], [90.78300476, 25.18094444], [90.78266907, 25.18041801], [90.78258514, 25.18038177], [90.78239441, 25.1804142], [90.7822113, 25.1804924], [90.78214264, 25.18059921], [90.78195953, 25.18061256], [90.7817688, 25.18065643], [90.78166962, 25.18073082], [90.78150177, 25.18081474], [90.78142548, 25.18103409], [90.78151703, 25.18126488], [90.78166962, 25.18149376], [90.78119659, 25.18118286], [90.77854156, 25.17977905], [90.77445984, 25.17900085], [90.77197266, 25.17788124], [90.76970673, 25.17686081], [90.76724243, 25.1739006], [90.7652359, 25.1718998], [90.7639389, 25.16999245], [90.76537323, 25.1683712], [90.76586151, 25.16781044], [90.76449585, 25.16624069], [90.76290894, 25.1664505], [90.75896454, 25.16697121], [90.75797272, 25.16710281], [90.75473022, 25.164711], [90.7544632, 25.16451073], [90.75100708, 25.16406059], [90.75029755, 25.16472054], [90.74878693, 25.16610909], [90.74838257, 25.16548538], [90.74803162, 25.16488266], [90.74756622, 25.16412354], [90.74738312, 25.16420937], [90.74699402, 25.16441917], [90.7454834, 25.16523361], [90.74510193, 25.16543579], [90.74501038, 25.16547775], [90.74474335, 25.16560364], [90.74307251, 25.16581917], [90.74208832, 25.16598892], [90.74200439, 25.16600227], [90.74178314, 25.16691589], [90.74172974, 25.16699409], [90.74176788, 25.16710091], [90.74156952, 25.16734886], [90.74153137, 25.1677494], [90.74180603, 25.16831398], [90.74185944, 25.168396], [90.74189758, 25.16859818], [90.74201965, 25.16912651], [90.74219513, 25.16965294], [90.74229431, 25.16996002], [90.74230194, 25.17007637], [90.74197388, 25.17017174], [90.74197388, 25.17025757], [90.74180603, 25.17034912], [90.74136353, 25.17030144], [90.74146271, 25.17011261], [90.74137115, 25.1700573], [90.7412262, 25.17013741], [90.74069977, 25.16940498], [90.74073029, 25.16923332], [90.74061584, 25.16917229], [90.73985291, 25.16938591], [90.73973846, 25.1688633], [90.73968506, 25.16851997], [90.73960114, 25.1682663], [90.73950195, 25.16790581], [90.73944092, 25.16735077], [90.73947144, 25.16722488], [90.73959351, 25.16719818], [90.73978424, 25.16715622], [90.73972321, 25.16691971], [90.73959351, 25.16677475], [90.73937225, 25.16676521], [90.73919678, 25.16659546], [90.73912048, 25.16659927], [90.73912048, 25.16669655], [90.73825073, 25.16671371], [90.73648071, 25.16684914], [90.73583984, 25.16685486], [90.73535156, 25.16685486], [90.73512268, 25.16692162], [90.73416901, 25.1669445], [90.73421478, 25.16610909], [90.734375, 25.16602707], [90.73455811, 25.16593552], [90.7346344, 25.165802], [90.73455048, 25.16556931], [90.73455811, 25.16548157], [90.73461151, 25.16537857], [90.73423767, 25.16533279], [90.73410034, 25.16531563], [90.7336731, 25.16533661], [90.73353577, 25.16530609], [90.73339081, 25.16534233], [90.73316956, 25.16527367], [90.73309326, 25.16492653], [90.73331451, 25.16489601], [90.73326874, 25.16475487], [90.73392487, 25.16456985], [90.73382568, 25.16421509], [90.73362732, 25.16424561], [90.73360443, 25.16411781], [90.7335968, 25.16377258], [90.73358154, 25.16347122], [90.73351288, 25.16315079], [90.73349762, 25.16293526], [90.73331451, 25.16254044], [90.73313904, 25.16251183], [90.73313904, 25.16212082], [90.73339081, 25.16205978], [90.73360443, 25.16203117], [90.73407745, 25.16196823], [90.73410797, 25.16214371], [90.73439789, 25.16203499], [90.73442841, 25.16231346], [90.73466492, 25.1624279], [90.73477173, 25.16295815], [90.73542786, 25.16323471], [90.73610687, 25.16360092], [90.73623657, 25.1637001], [90.73612213, 25.16385078], [90.73645782, 25.16412354], [90.73658752, 25.1641674], [90.73659515, 25.16427231], [90.73680878, 25.16431427], [90.73738861, 25.16432953], [90.73767853, 25.1644268], [90.73783875, 25.16441917], [90.7383728, 25.16432762], [90.73859406, 25.16387177], [90.73871613, 25.16380692], [90.73886108, 25.16363525], [90.73913574, 25.16344452], [90.73931122, 25.16335487], [90.73931885, 25.16322899], [90.73958588, 25.16312027], [90.73988342, 25.16265106], [90.7399826, 25.16257095], [90.74008942, 25.16251755], [90.74012756, 25.16238785], [90.74023438, 25.16226578], [90.74034882, 25.16218758], [90.74289703, 25.16180038], [90.74584961, 25.16037941], [90.74640656, 25.15870094], [90.74534607, 25.15661049], [90.74217987, 25.15677834], [90.7392807, 25.15443039], [90.73861694, 25.15451241], [90.73645782, 25.1554203], [90.73431396, 25.15739441], [90.73423767, 25.15714455], [90.73419952, 25.15707779], [90.73407745, 25.15681458], [90.7335968, 25.15582848], [90.73319244, 25.15501404], [90.73228455, 25.15509415], [90.73209381, 25.15509796], [90.73186493, 25.15510368], [90.73183441, 25.15540695], [90.73184204, 25.15555191], [90.73184204, 25.15571022], [90.73182678, 25.15595818], [90.73177338, 25.15619469], [90.73155975, 25.15658951], [90.73138428, 25.15688324], [90.73123932, 25.15712166], [90.73134613, 25.15728188], [90.73139191, 25.15748024], [90.73117065, 25.15750694], [90.73110199, 25.15753746], [90.73046875, 25.15757751], [90.7303772, 25.15767479], [90.7301178, 25.15784264], [90.72984314, 25.15750504], [90.7298584, 25.157341], [90.72962952, 25.157341], [90.72947693, 25.15737343], [90.72881317, 25.15733528], [90.72866058, 25.15725136], [90.72855377, 25.15732193], [90.72846985, 25.15741348], [90.72817993, 25.15769768], [90.72800446, 25.15748405], [90.72792053, 25.1573658], [90.72724152, 25.1577549], [90.72716522, 25.15779495], [90.72688293, 25.15792274], [90.72678375, 25.15804482], [90.72665405, 25.15813065], [90.72657013, 25.15818977], [90.72651672, 25.15856934], [90.72655487, 25.15874672], [90.72662354, 25.15901947], [90.7265625, 25.1590786], [90.72635651, 25.15918922], [90.72622681, 25.15927505], [90.72612, 25.15934753], [90.72606659, 25.15939903], [90.72599792, 25.15967178], [90.72577667, 25.160429], [90.72567749, 25.16046715], [90.72560883, 25.16060448], [90.72554016, 25.16074371], [90.72556305, 25.16093254], [90.72585297, 25.16106606], [90.7259903, 25.16129112], [90.72599792, 25.16136742], [90.72606659, 25.16146851], [90.72609711, 25.16157913], [90.72610474, 25.16175652], [90.7259903, 25.16205406], [90.72587585, 25.16229439], [90.724617, 25.16334534], [90.72453308, 25.16329002], [90.72441101, 25.16337585], [90.72425842, 25.16363907], [90.72399139, 25.16361427], [90.72405243, 25.16381264], [90.72393799, 25.16388893], [90.72372437, 25.16403389], [90.72314453, 25.164505], [90.72277069, 25.16462517], [90.72200775, 25.16482162], [90.72132111, 25.16422653], [90.72116089, 25.16413307], [90.72068024, 25.16400909], [90.72041321, 25.16396713], [90.72019196, 25.16391945], [90.71969604, 25.16392708], [90.71828461, 25.16386986], [90.71819305, 25.16381645], [90.71767426, 25.1638279], [90.71756744, 25.16386414], [90.71743011, 25.1639843], [90.71737671, 25.16413689], [90.7170639, 25.16469955], [90.71662903, 25.16485023], [90.71607208, 25.16558647], [90.7159729, 25.1657238], [90.71578979, 25.16588593], [90.71576691, 25.16599274], [90.71574402, 25.16612625], [90.71470642, 25.16766167], [90.71353912, 25.16786766], [90.71307373, 25.16792679], [90.71271515, 25.16796303], [90.71033478, 25.16818428], [90.70992279, 25.16821098], [90.7093811, 25.16796684], [90.7091217, 25.16777611], [90.7086792, 25.16730881], [90.70856476, 25.16722298], [90.70800018, 25.16666031], [90.7077713, 25.16616631], [90.70757294, 25.16558266], [90.70749664, 25.16526794], [90.70749664, 25.16503716], [90.70772552, 25.16432571], [90.70774841, 25.16410255], [90.70780182, 25.16353035], [90.70761108, 25.16353416], [90.70714569, 25.16344833], [90.7065506, 25.16330719], [90.70638275, 25.16287994], [90.70670319, 25.16238022], [90.70685577, 25.16210175], [90.70665741, 25.16178322], [90.70650482, 25.16121292], [90.70597839, 25.16137505], [90.7053299, 25.16140556], [90.70381165, 25.16178894], [90.70340729, 25.16189575], [90.70269775, 25.16208267], [90.70231628, 25.16218376], [90.70172882, 25.16278458], [90.701828, 25.1633358], [90.70171356, 25.16399956], [90.70166779, 25.16427422], [90.70059204, 25.16493416], [90.70020294, 25.1635952], [90.70056915, 25.16287422], [90.7004776, 25.16270638], [90.69999695, 25.16189766], [90.69959259, 25.16168213], [90.69924164, 25.1613121], [90.69947052, 25.16097832], [90.69949341, 25.16080284], [90.69944, 25.16031837], [90.69934845, 25.16032982], [90.6993103, 25.16015434], [90.69953156, 25.16023254], [90.69983673, 25.16003227], [90.69985962, 25.15995407], [90.69978333, 25.1597805], [90.69988251, 25.15981865], [90.69997406, 25.15985298], [90.70011139, 25.15984917], [90.70052338, 25.15946007], [90.70044708, 25.15936661], [90.69995117, 25.15877533], [90.69984436, 25.15864563], [90.69963837, 25.15797424], [90.69940948, 25.15740776], [90.69895172, 25.15695381], [90.69850159, 25.15685463], [90.69801331, 25.15695381], [90.69659424, 25.15786362], [90.69560242, 25.15859413], [90.69542694, 25.15872574], [90.69519806, 25.15871239], [90.69513702, 25.15882683], [90.69499969, 25.15929794], [90.69499207, 25.15976524], [90.69501495, 25.15995598], [90.69498444, 25.16013908], [90.69415283, 25.16039848], [90.69307709, 25.16068649], [90.69281769, 25.16066742], [90.69256592, 25.16067314], [90.69248199, 25.16065407], [90.69211578, 25.16080093], [90.69197845, 25.16087151], [90.69177246, 25.16097641], [90.69169617, 25.16101456], [90.6917572, 25.16138458], [90.69169617, 25.16155052], [90.69176483, 25.16181374], [90.69174957, 25.16192245], [90.69141388, 25.16266251], [90.69111633, 25.16331863], [90.69096375, 25.16365051], [90.68984985, 25.1642704], [90.68830872, 25.16395569], [90.68814087, 25.16406441], [90.68791199, 25.164217], [90.68753052, 25.16446304], [90.68680573, 25.16493416], [90.68669891, 25.16480827], [90.68649292, 25.16464233], [90.68613434, 25.16432571], [90.68544769, 25.16373062], [90.68514252, 25.16351318], [90.68411255, 25.16340828], [90.68379974, 25.16334724], [90.68365479, 25.16334343], [90.68345642, 25.16341209], [90.68315887, 25.16356468], [90.68273926, 25.16378212], [90.68218994, 25.16439629], [90.68208313, 25.16437721], [90.68196869, 25.1646595], [90.68183136, 25.16493034], [90.68180084, 25.16559792], [90.68184662, 25.16582489], [90.68172455, 25.16607285], [90.68136597, 25.16731644], [90.68128967, 25.16757584], [90.68109131, 25.16777992], [90.68117523, 25.16794586], [90.68115997, 25.1680584], [90.68109894, 25.16814041], [90.6809845, 25.16818237], [90.68066406, 25.16829872], [90.68045807, 25.16844368], [90.68050385, 25.16859627], [90.68049622, 25.16866875], [90.68044281, 25.1688118], [90.68048096, 25.16910934], [90.6804657, 25.16931725], [90.68042755, 25.16942787], [90.68055725, 25.16954422], [90.68064117, 25.16939926], [90.68087006, 25.16942406], [90.68100739, 25.16966438], [90.68169403, 25.16972923], [90.68196106, 25.16988945], [90.68235016, 25.17023468], [90.68347168, 25.17081451], [90.68397522, 25.17120934], [90.68462372, 25.17171478], [90.68543243, 25.17234802], [90.68549347, 25.17256927], [90.68549347, 25.17409134], [90.6856842, 25.17423058], [90.68584442, 25.1742878], [90.68603516, 25.17439461], [90.68585205, 25.17448425], [90.6856308, 25.17458725], [90.68545532, 25.17463112], [90.68447876, 25.17410851], [90.68440247, 25.17424774], [90.68400574, 25.17400551], [90.68402863, 25.17390823], [90.68354797, 25.17373848], [90.68309021, 25.17357635], [90.68291473, 25.17359161], [90.68230438, 25.17331123], [90.68190002, 25.17273521], [90.68154144, 25.17233086], [90.6812439, 25.1722641], [90.68093872, 25.17224693], [90.68058777, 25.17251587], [90.68047333, 25.17250824], [90.68039703, 25.17248726], [90.68015289, 25.17238808], [90.67957306, 25.17226219], [90.67953491, 25.17271614], [90.67922211, 25.17260361], [90.67900848, 25.17243004], [90.67891693, 25.17228699], [90.67871094, 25.17233467], [90.67868042, 25.17247963], [90.6787262, 25.17270851], [90.67850494, 25.17268562], [90.67835236, 25.17238235], [90.67797089, 25.17239571], [90.67782593, 25.17243767], [90.67768097, 25.17253304], [90.67760468, 25.17254639], [90.67746735, 25.17254639], [90.67720795, 25.17259598], [90.67713928, 25.1724968], [90.67709351, 25.17241669], [90.67685699, 25.17247963], [90.67687988, 25.1727829], [90.676651, 25.1729641], [90.67536163, 25.17310333], [90.6752243, 25.1726265], [90.67507935, 25.17259979], [90.67500305, 25.17262459], [90.67454529, 25.17276192], [90.67481232, 25.17338181], [90.67487335, 25.17354393], [90.67486572, 25.17380333], [90.67482758, 25.17405891], [90.67481232, 25.17424965], [90.6749115, 25.17443085], [90.67523193, 25.17479706], [90.67542267, 25.17501259], [90.6756897, 25.17522049], [90.67613983, 25.17565155], [90.67620087, 25.17575836], [90.67626953, 25.17592239], [90.67630005, 25.17607307], [90.67630768, 25.17630768], [90.67614746, 25.17639923], [90.67601013, 25.17643738], [90.67559814, 25.17651367], [90.67523956, 25.17654991], [90.67455292, 25.17666626], [90.67433929, 25.17648697], [90.67428589, 25.1761322], [90.67427826, 25.17604256], [90.67404938, 25.1755619], [90.67378998, 25.17528152], [90.67351532, 25.17461395], [90.67326355, 25.17393684], [90.67303467, 25.17343903], [90.67274475, 25.17298508], [90.67254639, 25.17243576], [90.67235565, 25.17231941], [90.67224121, 25.17230225], [90.67211151, 25.17209435], [90.67218018, 25.17196274], [90.67227173, 25.17176056], [90.67230988, 25.17098427], [90.6723175, 25.17086792], [90.67227936, 25.17056847], [90.67224121, 25.17036057], [90.67219543, 25.17019272], [90.67212677, 25.1699028], [90.67208099, 25.16983604], [90.67201996, 25.16975403], [90.67189789, 25.16966438], [90.67180634, 25.16958427], [90.67178345, 25.16944885], [90.67175293, 25.16916275], [90.6717453, 25.16884613], [90.67163849, 25.16875458], [90.67151642, 25.16875076], [90.67106628, 25.16897202], [90.67098236, 25.16901398], [90.67082977, 25.16906738], [90.6706543, 25.16906357], [90.67055511, 25.16899681], [90.6704483, 25.16890907], [90.67024994, 25.16863823], [90.67019653, 25.16851997], [90.6701889, 25.16827965], [90.67024231, 25.16804695], [90.67031097, 25.16790771], [90.67034912, 25.16773224], [90.67004395, 25.16754913], [90.6700058, 25.16744423], [90.67003632, 25.16717148], [90.66996765, 25.16687775], [90.66993713, 25.16652489], [90.6698761, 25.1664257], [90.66976166, 25.16630936], [90.66965485, 25.16627502], [90.66956329, 25.16627693], [90.66944122, 25.16635132], [90.66938019, 25.16644287], [90.66931152, 25.16654205], [90.66916656, 25.16684151], [90.66910553, 25.16691208], [90.66902924, 25.16693306], [90.66891479, 25.1668644], [90.66881561, 25.16677094], [90.66860199, 25.16656685], [90.66848755, 25.16654587], [90.66840363, 25.16653633], [90.66830444, 25.16653252], [90.66783905, 25.16627121], [90.66767883, 25.16608047], [90.66734314, 25.16619682], [90.66728973, 25.16638184], [90.66709137, 25.1665535], [90.66671753, 25.1663208], [90.66614532, 25.16605186], [90.66593933, 25.1659565], [90.66592407, 25.16617203], [90.66588593, 25.16628456], [90.66585541, 25.16646385], [90.66576385, 25.16667366], [90.66574097, 25.16679192], [90.6657486, 25.16747284], [90.66567993, 25.16769981], [90.66562653, 25.16786575], [90.66609955, 25.16790771], [90.6659317, 25.16917229], [90.66622925, 25.1691761], [90.66647339, 25.16918182], [90.66648102, 25.16966629], [90.66629028, 25.16978645], [90.6656189, 25.1698246], [90.66571045, 25.17033195], [90.66578674, 25.17061424], [90.66602325, 25.17063332], [90.66604614, 25.17080116], [90.66580963, 25.17084312], [90.66566467, 25.17088127], [90.66563416, 25.17119408], [90.66562653, 25.17131042], [90.6654892, 25.17133331], [90.66555023, 25.17148209], [90.66549683, 25.17159081], [90.66563416, 25.17164993], [90.66563416, 25.17203903], [90.66544342, 25.17210388], [90.66539764, 25.17227554], [90.66521454, 25.17233658], [90.66477203, 25.17256927], [90.664711, 25.17263412], [90.66455078, 25.1726799], [90.66434479, 25.17276955], [90.6639328, 25.17294884], [90.66375732, 25.1730423], [90.66404724, 25.17370224], [90.66415405, 25.17373466], [90.66426849, 25.17397308], [90.66453552, 25.17420578], [90.66467285, 25.17455101], [90.66475677, 25.17485428], [90.6651001, 25.17640686], [90.66506958, 25.17656326], [90.6649704, 25.17681694], [90.66442871, 25.17690277], [90.66355896, 25.17757988], [90.6635437, 25.17849922], [90.6633606, 25.17897415], [90.66344452, 25.17965508], [90.66357422, 25.1796608], [90.66371918, 25.18001556], [90.66375732, 25.18009949], [90.66403198, 25.18032646], [90.66416168, 25.18049431], [90.66432953, 25.18085289], [90.66440582, 25.18066406], [90.66464233, 25.180439], [90.66495514, 25.18070602], [90.66539001, 25.18088341], [90.66546631, 25.18109512], [90.66526031, 25.18112564], [90.66532898, 25.18128967], [90.66532135, 25.18136978], [90.66525269, 25.18157578], [90.66523743, 25.18173981], [90.66527557, 25.1818943], [90.66526794, 25.18206406], [90.66508484, 25.18315887], [90.66505432, 25.18334389], [90.66500854, 25.18375397], [90.66499329, 25.18401909], [90.66495514, 25.18429565], [90.66480255, 25.18466949], [90.66468048, 25.18518829], [90.66472626, 25.18545532], [90.66418457, 25.18549347], [90.66390991, 25.1854744], [90.66377258, 25.18546486], [90.66370392, 25.18542862], [90.66342926, 25.18533134], [90.66326904, 25.18543625], [90.66262054, 25.18540192], [90.6606369, 25.18581009], [90.65814209, 25.18364906], [90.65804291, 25.18345451], [90.65795898, 25.18356514], [90.6579361, 25.18373871], [90.65792084, 25.18389511], [90.65788269, 25.18405151], [90.65785217, 25.18412971], [90.65785217, 25.18422508], [90.65782166, 25.18444061], [90.65779114, 25.18458939], [90.65777588, 25.18473053], [90.6577301, 25.18488312], [90.65766907, 25.18498611], [90.65762329, 25.18509674], [90.65765381, 25.18546104], [90.65730286, 25.18558693], [90.65721893, 25.18566513], [90.65667725, 25.18621254], [90.65592957, 25.18710518], [90.6556015, 25.18843842], [90.65493774, 25.19027519], [90.6530838, 25.19192314], [90.65192413, 25.19330788], [90.6506424, 25.19498825], [90.64962769, 25.19524574], [90.64793396, 25.1943531], [90.64736176, 25.1943779], [90.64743042, 25.19392776], [90.64755249, 25.19391251], [90.64770508, 25.19396782], [90.64783478, 25.19393158], [90.64793396, 25.19392586], [90.64825439, 25.19381523], [90.64835358, 25.19383621], [90.64853668, 25.19372177], [90.64874268, 25.19360161], [90.64892578, 25.19347572], [90.64948273, 25.19306374], [90.65009308, 25.19240952], [90.65034485, 25.19219398], [90.6505127, 25.19197273], [90.65063477, 25.19175529], [90.65102386, 25.1911335], [90.65114594, 25.19094849], [90.65126801, 25.19080162], [90.651474, 25.19050217], [90.65187073, 25.1897831], [90.65193939, 25.18968773], [90.65214539, 25.18934059], [90.65234375, 25.18900681], [90.65251923, 25.18878365], [90.65238953, 25.18872452], [90.6521759, 25.18862152], [90.65184021, 25.18858719], [90.65146637, 25.18836594], [90.65133667, 25.18822861], [90.65143585, 25.18806839], [90.65148926, 25.18800926], [90.65158844, 25.18794441], [90.65227509, 25.18754578], [90.65232086, 25.18698692], [90.65135956, 25.1852169], [90.65153503, 25.18480301], [90.65156555, 25.18455505], [90.65153503, 25.1843586], [90.65148163, 25.18425179], [90.65116119, 25.18354416], [90.65100861, 25.18275833], [90.65102386, 25.18257141], [90.65104675, 25.18234062], [90.65110016, 25.18217468], [90.65109253, 25.18209076], [90.65055084, 25.18179512], [90.65008545, 25.18153], [90.64982605, 25.18137741], [90.64942169, 25.18110657], [90.64904785, 25.18083572], [90.64893341, 25.18078804], [90.64868927, 25.18073273], [90.64846802, 25.1807003], [90.64833069, 25.18068886], [90.64787292, 25.18083572], [90.64768219, 25.1803112], [90.64700317, 25.17851067], [90.64832306, 25.17679977], [90.64878082, 25.17333984], [90.64232635, 25.17459106], [90.6397171, 25.17328835], [90.63687897, 25.17217827], [90.63391113, 25.17243004], [90.6333313, 25.17247009], [90.62742615, 25.17300034], [90.62719727, 25.17290306], [90.62733459, 25.17259979], [90.6269455, 25.1723156], [90.62670135, 25.17237854], [90.62666321, 25.17268181], [90.62592316, 25.17237091], [90.62463379, 25.17413712], [90.62363434, 25.17411423], [90.62200928, 25.17410851], [90.62200928, 25.17398071], [90.6219101, 25.17402267], [90.62184143, 25.17421722], [90.62166595, 25.17404747], [90.62153625, 25.17414665], [90.62122345, 25.17437935], [90.6210022, 25.17437172], [90.62081146, 25.17433929], [90.62049866, 25.17440987], [90.62029266, 25.17430878], [90.62030792, 25.17422104], [90.62000275, 25.17407036], [90.61994934, 25.17383575], [90.61987305, 25.17361641], [90.61981964, 25.17334938], [90.61981964, 25.17323112], [90.61960602, 25.17312622], [90.61927795, 25.17321205], [90.61920166, 25.1731987], [90.61869812, 25.17302704], [90.61846924, 25.17368889], [90.61821747, 25.17350769], [90.61821747, 25.17267418], [90.61814117, 25.17269516], [90.6179657, 25.17274857], [90.61788177, 25.17277527], [90.61782837, 25.1728363], [90.61779785, 25.17290497], [90.61687469, 25.17424393], [90.61679077, 25.17438698], [90.61682892, 25.17461014], [90.61677551, 25.17474174], [90.61668396, 25.17537498], [90.6166687, 25.17601395], [90.61651611, 25.17601013], [90.61632538, 25.1760788], [90.61637878, 25.17636681], [90.61637115, 25.17646217], [90.61643219, 25.17677116], [90.61636353, 25.1770401], [90.6164093, 25.17734528], [90.61642456, 25.17747116], [90.61624908, 25.17739105], [90.61561584, 25.17755127], [90.61553955, 25.17754555], [90.61550903, 25.17747498], [90.61521149, 25.17708015], [90.61499023, 25.17652893], [90.61476898, 25.17591095], [90.61474609, 25.17570686], [90.61456299, 25.17549706], [90.61425781, 25.17505455], [90.61418152, 25.17479706], [90.61412811, 25.17439079], [90.61403656, 25.17420578], [90.61382294, 25.17381859], [90.6134491, 25.17519188], [90.61334991, 25.17530251], [90.60954285, 25.17525291], [90.60482025, 25.17609024], [90.60469055, 25.17607307], [90.60468292, 25.17588997], [90.60466003, 25.17579842], [90.60464478, 25.17570877], [90.60466003, 25.17558861], [90.60481262, 25.17521477], [90.60461426, 25.17479324], [90.60454559, 25.17499924], [90.60423279, 25.17544365], [90.60415649, 25.17543983], [90.60405731, 25.17503738], [90.60366058, 25.17507172], [90.60353088, 25.17485619], [90.60308838, 25.17506218], [90.60308838, 25.17515182], [90.60247803, 25.17533493], [90.60237122, 25.1751709], [90.60214996, 25.17519379], [90.60165405, 25.17513847], [90.60116577, 25.17513466], [90.60092926, 25.17523384], [90.60071564, 25.17536545], [90.60018158, 25.17547798], [90.60010529, 25.17549324], [90.59994507, 25.17550087], [90.59988403, 25.17564011], [90.59965515, 25.17572594], [90.59945679, 25.17584038], [90.59938812, 25.17617989], [90.5993576, 25.17654037], [90.59934235, 25.17664909], [90.59923553, 25.17664337], [90.59907532, 25.17661095], [90.59889221, 25.17656136], [90.59864044, 25.17658043], [90.59814453, 25.17676163], [90.59706879, 25.17663193], [90.59486389, 25.17635727], [90.59381866, 25.17625809], [90.59359741, 25.17619324], [90.59356689, 25.1757679], [90.59355164, 25.17542267], [90.59358215, 25.17531204], [90.59349823, 25.1752739], [90.5933609, 25.17529297], [90.59269714, 25.17555046], [90.5925827, 25.17573738], [90.59254456, 25.17581177], [90.59209442, 25.1759243], [90.59192657, 25.17593575], [90.59128571, 25.17594719], [90.59077454, 25.17579651], [90.5905304, 25.17572212], [90.59042358, 25.17566299], [90.59021759, 25.17557907], [90.58986664, 25.17535591], [90.58968353, 25.17526245], [90.58911896, 25.17530823], [90.5890274, 25.17556763], [90.58894348, 25.17605209], [90.58887482, 25.17618752], [90.58869934, 25.17651367], [90.58862305, 25.17664337], [90.58782196, 25.17662621], [90.58763123, 25.17636871], [90.5872345, 25.17578506], [90.58700562, 25.17529678], [90.58683014, 25.17521667], [90.58656311, 25.17532539], [90.58625793, 25.17464447], [90.58613586, 25.17447281], [90.58610535, 25.1742115], [90.58615112, 25.1738987], [90.58625793, 25.17384338], [90.58621216, 25.17359924], [90.58560181, 25.17363167], [90.58551788, 25.17383194], [90.58517456, 25.17388916], [90.58505249, 25.17389488], [90.58479309, 25.17390633], [90.58451843, 25.17415047], [90.58432007, 25.17411804], [90.58412933, 25.17374611], [90.583992, 25.17370224], [90.58361816, 25.17373848], [90.58350372, 25.17361069], [90.58342743, 25.17348289], [90.58300781, 25.17350197], [90.58301544, 25.17386818], [90.58293152, 25.17394829], [90.58280945, 25.17405891], [90.58269501, 25.17492485], [90.58231354, 25.17483521], [90.58240509, 25.17435837], [90.5823288, 25.17403603], [90.58223724, 25.17392159], [90.58205414, 25.17367744], [90.58197021, 25.17378998], [90.58179474, 25.17397308], [90.5815506, 25.17416763], [90.58143616, 25.17454529], [90.58135223, 25.17466545], [90.58101654, 25.17465019], [90.58106995, 25.17427063], [90.58105469, 25.17385864], [90.58085632, 25.1739006], [90.5806427, 25.17393684], [90.58052826, 25.17397308], [90.58020782, 25.17407036], [90.5800705, 25.17407608], [90.57894135, 25.17487335], [90.57840729, 25.17445564], [90.57814789, 25.17412567], [90.57789612, 25.17368889], [90.57776642, 25.17372513], [90.57775116, 25.17364693], [90.57757568, 25.17354012], [90.57752991, 25.17347908], [90.57723236, 25.17292023], [90.57717896, 25.17274857], [90.57705688, 25.17255783], [90.57696533, 25.17194176], [90.57683563, 25.17206764], [90.57675934, 25.17185783], [90.57624817, 25.17187309], [90.57595825, 25.17176056], [90.57565308, 25.17181206], [90.57540894, 25.17180252], [90.57491302, 25.17186737], [90.57454681, 25.17189598], [90.57444763, 25.17191315], [90.5743103, 25.17197418], [90.57389069, 25.17220306], [90.57393646, 25.17244911], [90.5738678, 25.17251205], [90.57368469, 25.17255783], [90.57368469, 25.17273903], [90.57359314, 25.17285347], [90.57349396, 25.17292213], [90.5719223, 25.17144012], [90.57147217, 25.1710186], [90.57058716, 25.17131042], [90.5687027, 25.17192078], [90.56416321, 25.1719017], [90.56404114, 25.17151451], [90.56360626, 25.17189217], [90.56076813, 25.17176819], [90.55961609, 25.17359734], [90.55893707, 25.17341042], [90.55874634, 25.17350388], [90.55867004, 25.17353439], [90.55847168, 25.17336082], [90.55834961, 25.17318344], [90.55809021, 25.17287636], [90.55786133, 25.17257118], [90.55769348, 25.17257118], [90.55741882, 25.17266273], [90.55755615, 25.17313957], [90.55740356, 25.17327309], [90.55703735, 25.17328644], [90.55680084, 25.1727066], [90.5557251, 25.171978], [90.55536652, 25.1719532], [90.55522156, 25.17183495], [90.55503845, 25.17188644], [90.55493164, 25.17177391], [90.55456543, 25.17192268], [90.55438995, 25.17200661], [90.55427551, 25.17208862], [90.55412292, 25.17224121], [90.55404663, 25.17228889], [90.55395508, 25.1723156], [90.55379486, 25.17232132], [90.5537262, 25.17254066], [90.55368805, 25.17272186], [90.55327606, 25.1728878], [90.5531311, 25.17289543], [90.55270386, 25.17310524], [90.55261993, 25.17318153], [90.55253601, 25.17332649], [90.55231476, 25.17359352], [90.55210114, 25.17403603], [90.55192566, 25.17441177], [90.55171967, 25.17480659], [90.55146027, 25.17530441], [90.55126953, 25.17533875], [90.55093384, 25.17491531], [90.55045319, 25.17500305], [90.55033875, 25.17473602], [90.54992676, 25.1747818], [90.54988098, 25.17468071], [90.54955292, 25.17473793], [90.54915619, 25.17484283], [90.54904938, 25.17469597], [90.5480957, 25.17472649], [90.54764557, 25.17458344], [90.54740906, 25.17436409], [90.54710388, 25.1740036], [90.54649353, 25.17381668], [90.5459137, 25.17368507], [90.54550171, 25.17371368], [90.54535675, 25.17372322], [90.54516602, 25.1736908], [90.54071808, 25.17292976], [90.53617096, 25.17307091], [90.53321838, 25.17344666], [90.53200531, 25.17353058], [90.53179169, 25.17354774], [90.52848816, 25.17274094], [90.5247879, 25.17200279], [90.5223999, 25.17314529], [90.52205658, 25.17331123], [90.52153778, 25.17321205], [90.5211792, 25.17304611], [90.52107239, 25.17304802], [90.52096558, 25.17293167], [90.52050781, 25.17273331], [90.52019501, 25.17261696], [90.51997375, 25.17258263], [90.51945496, 25.17254066], [90.51942444, 25.17244339], [90.51859283, 25.17232704], [90.51846313, 25.17233467], [90.51737976, 25.17275429], [90.51694489, 25.17294884], [90.51667023, 25.1730423], [90.51663971, 25.17058945], [90.51573944, 25.16982079], [90.5118866, 25.17040253], [90.50964355, 25.17098618], [90.50980377, 25.16987038], [90.50982666, 25.1697197], [90.50982666, 25.16952133], [90.50882721, 25.16986275], [90.50884247, 25.17010117], [90.50816345, 25.16996384], [90.50754547, 25.16983986], [90.50720978, 25.16979408], [90.50697327, 25.16979218], [90.5067749, 25.16991615], [90.50662231, 25.17003059], [90.50260162, 25.16638947], [90.49756622, 25.16505814], [90.49608612, 25.16356087], [90.49571991, 25.1631794], [90.49402618, 25.1614399], [90.48787689, 25.16002846], [90.48442841, 25.15909004], [90.4763031, 25.15689087], [90.46510315, 25.15328026], [90.462677, 25.15282249], [90.4596405, 25.15225029], [90.45939636, 25.15180969], [90.45791626, 25.14896965], [90.45658112, 25.14596939], [90.45497894, 25.14443016], [90.45236206, 25.14450264], [90.44928741, 25.14528656], [90.44924927, 25.14504623], [90.44913483, 25.14504051], [90.44863129, 25.14501381], [90.44782257, 25.14497375], [90.44659424, 25.14490891], [90.44592285, 25.14487648], [90.44482422, 25.14482117], [90.44409943, 25.14478493], [90.44268799, 25.14471245], [90.44181061, 25.14466858], [90.440979, 25.14462662], [90.44032288, 25.14490128], [90.43943024, 25.14527321], [90.43891907, 25.14552307], [90.43894196, 25.14560699], [90.4380188, 25.14596367], [90.43727875, 25.14624786], [90.43653107, 25.14653587], [90.43580627, 25.14681435], [90.43481445, 25.14707565], [90.43385315, 25.14732742], [90.43156433, 25.14791298], [90.43125153, 25.14797592], [90.43008423, 25.14821053], [90.42830658, 25.14861107], [90.42734528, 25.14885139], [90.4254303, 25.14931679], [90.4246521, 25.14950371], [90.42388153, 25.14969063], [90.42311096, 25.14987755], [90.42224121, 25.15064621], [90.42198181, 25.15065384], [90.42192841, 25.1507473], [90.42176819, 25.15061951], [90.42153931, 25.15069389], [90.42093658, 25.15077782], [90.42053223, 25.15064621], [90.42046356, 25.15079689], [90.41999817, 25.1511116], [90.41984558, 25.15112114], [90.41968536, 25.15114403], [90.41934967, 25.15123367], [90.41928864, 25.1511631], [90.41909027, 25.15120506], [90.41885376, 25.15104485], [90.41860199, 25.150877], [90.41863251, 25.15112686], [90.41864014, 25.15122795], [90.41872406, 25.15144157], [90.41884613, 25.15164375], [90.41769409, 25.15209579], [90.41574097, 25.15286064], [90.41455078, 25.15334511], [90.41362762, 25.15372467], [90.41252899, 25.15459824], [90.41156006, 25.1553688], [90.41049194, 25.15622711], [90.40794373, 25.15828133], [90.40743256, 25.15869904], [90.40705109, 25.1590023], [90.40605927, 25.15939713], [90.40535736, 25.15967178], [90.40440369, 25.16004562], [90.40365601, 25.15988159], [90.40171814, 25.15944862], [90.40016174, 25.15909386], [90.39976501, 25.15920448], [90.39900208, 25.15940857], [90.39822388, 25.15961838], [90.39746857, 25.15982437], [90.39730835, 25.15977859], [90.39498901, 25.16012573], [90.39393616, 25.1602211], [90.39342499, 25.16020775], [90.39274597, 25.16055679], [90.39203644, 25.16091919], [90.39128113, 25.16094398], [90.39048767, 25.16096878], [90.38957214, 25.1612072], [90.38890839, 25.16138077], [90.3885498, 25.16141701], [90.38796997, 25.16147423], [90.38707733, 25.1615696], [90.38604736, 25.16147804], [90.38519287, 25.16145515], [90.38417053, 25.16130829], [90.38352966, 25.16124916], [90.38288879, 25.16119194], [90.38206482, 25.16111755], [90.38109589, 25.16120148], [90.38048553, 25.16125107], [90.37960052, 25.16131592], [90.37737274, 25.16153145], [90.37574005, 25.16173744], [90.37421417, 25.16211128], [90.37387085, 25.16219711], [90.37308502, 25.16238403], [90.37299347, 25.16243362], [90.37258911, 25.16253281], [90.37220001, 25.16263771], [90.3717804, 25.16270447], [90.371521, 25.16277122], [90.3709259, 25.16287994], [90.3705368, 25.16293335], [90.37010193, 25.16330147], [90.36952209, 25.16378021], [90.36862946, 25.16452789], [90.36817932, 25.16490364], [90.36651611, 25.16628456], [90.36593628, 25.16676712], [90.36527252, 25.16732979], [90.3649826, 25.16745186], [90.36473083, 25.16760063], [90.36288452, 25.16864204], [90.36116028, 25.16958046], [90.35934448, 25.17056656], [90.35826874, 25.17115211], [90.35566711, 25.17255974], [90.35399628, 25.17348289], [90.3521347, 25.17477417], [90.35157776, 25.17510605], [90.34812164, 25.1774826], [90.34671021, 25.17845535], [90.34621429, 25.1788826], [90.34606934, 25.17897797], [90.34591675, 25.17913818], [90.34577179, 25.17922974], [90.34560394, 25.17940521], [90.34545898, 25.17951584], [90.34526825, 25.17969513], [90.34519196, 25.17974091], [90.34359741, 25.18114662], [90.34318542, 25.18151283], [90.34242249, 25.18219185], [90.34135437, 25.18315125], [90.34128571, 25.18333626], [90.34041595, 25.18448067], [90.34012604, 25.18485832], [90.33982086, 25.18525505], [90.33860779, 25.18684387], [90.33816528, 25.18748665], [90.33718109, 25.18889999], [90.33670044, 25.18958855], [90.33565521, 25.19029999], [90.33565521, 25.19046021], [90.33546448, 25.19055367], [90.33531952, 25.19056892], [90.33519745, 25.19060707], [90.33508301, 25.19069672], [90.33495331, 25.19080544], [90.33480072, 25.19091606], [90.33467865, 25.19102669], [90.33356476, 25.19180679], [90.33283997, 25.19227219], [90.33218384, 25.19268799], [90.33207703, 25.19282913], [90.33190155, 25.19292068], [90.33162689, 25.1930294], [90.33097076, 25.19342995], [90.33026886, 25.19381905], [90.33013153, 25.19389343], [90.32953644, 25.19375229], [90.32940674, 25.19373512], [90.32926941, 25.19371796], [90.32909393, 25.19369507], [90.32874298, 25.19366074], [90.32515717, 25.19284058], [90.32142639, 25.19100189], [90.31807709, 25.18965912], [90.31391144, 25.19120979], [90.31326294, 25.19077492], [90.31315613, 25.19074249], [90.31293488, 25.19067192], [90.31290436, 25.19060516], [90.31288147, 25.19052315], [90.31058502, 25.18908119], [90.31035614, 25.1888752], [90.30997467, 25.18898964], [90.3087616, 25.18935204], [90.30748749, 25.18972778], [90.30609894, 25.19013405], [90.30488586, 25.19049454], [90.30378723, 25.19082642], [90.30335236, 25.19075012], [90.30223083, 25.19064903], [90.30223083, 25.1907959], [90.30093384, 25.19091988], [90.29990387, 25.19109917], [90.29943848, 25.19127083], [90.29903412, 25.19138908], [90.29718781, 25.19192314], [90.29659271, 25.19209671], [90.29637909, 25.19205475], [90.29614258, 25.19208336], [90.29605103, 25.19208145], [90.29566956, 25.19212723], [90.29549408, 25.19220924], [90.29534912, 25.19231033], [90.29521179, 25.19236374], [90.2948761, 25.19244957], [90.29464722, 25.19246292], [90.29371643, 25.19272423], [90.29328156, 25.19291496], [90.29290009, 25.19308281], [90.29157257, 25.19366837], [90.28987885, 25.19422722], [90.2881012, 25.19505882], [90.28651428, 25.1958046], [90.2844162, 25.19599533], [90.28382874, 25.19598579], [90.283638, 25.195755], [90.28299713, 25.19590187], [90.28282166, 25.19539452], [90.28269958, 25.195364], [90.28253937, 25.19551659], [90.28253174, 25.19566345], [90.28248596, 25.19574547], [90.282341, 25.19575882], [90.28227997, 25.19550323], [90.28192139, 25.19537735], [90.28153229, 25.19543457], [90.27971649, 25.19583321], [90.27890778, 25.19605255], [90.27759552, 25.19639397], [90.27693176, 25.19656754], [90.27585602, 25.19684792], [90.27410889, 25.19730377], [90.27275848, 25.19765663], [90.27193451, 25.19786835], [90.27191162, 25.19796562], [90.27144623, 25.19805145], [90.26925659, 25.19835663], [90.26886749, 25.19840813], [90.26847076, 25.19845963], [90.2682724, 25.19848442], [90.26805115, 25.19851303], [90.26792145, 25.19841194], [90.26663971, 25.19784546], [90.26629639, 25.19763756], [90.26470947, 25.19649124], [90.26421356, 25.19639206], [90.26399231, 25.19634628], [90.26302338, 25.19664574], [90.26261902, 25.19676781], [90.26209259, 25.19693184], [90.26128387, 25.19693375], [90.26063538, 25.19706345], [90.25994873, 25.19720268], [90.25865173, 25.1979847], [90.25811005, 25.19831276], [90.25691986, 25.19903183], [90.25578308, 25.19972229], [90.25460815, 25.20000839], [90.25352478, 25.20027351], [90.25293732, 25.20023346], [90.25217438, 25.20016861], [90.25187683, 25.20013428], [90.25167847, 25.20010948], [90.25146484, 25.20008469], [90.25106049, 25.2000351], [90.25042725, 25.19998741], [90.2492981, 25.20011711], [90.24909973, 25.20014381], [90.2489624, 25.20016289], [90.24859619, 25.20028305], [90.24836731, 25.20038033], [90.24713135, 25.20093727], [90.24703217, 25.20100212], [90.24510956, 25.20223808], [90.24462891, 25.20254898], [90.24420166, 25.20257187], [90.24356079, 25.20260429], [90.2409668, 25.20326805], [90.24082184, 25.20326805], [90.24069214, 25.20328712], [90.24060059, 25.20330811], [90.24007416, 25.20345116], [90.23961639, 25.20368195], [90.23912811, 25.20392799], [90.23857117, 25.20408058], [90.23836517, 25.20409966], [90.2358551, 25.20461273], [90.23574829, 25.20463753], [90.2352829, 25.20476532], [90.23511505, 25.20480156], [90.23490143, 25.20484734], [90.23392487, 25.20501709], [90.2338028, 25.20501518], [90.23339844, 25.20494461], [90.233284, 25.20492744], [90.2326889, 25.2047081], [90.23239899, 25.20454407], [90.23210144, 25.20437431], [90.23193359, 25.20427895], [90.23152924, 25.20419121], [90.23130035, 25.20413208], [90.23000336, 25.20379448], [90.2296524, 25.20370674], [90.22912598, 25.20358276], [90.22895813, 25.20343971], [90.22883606, 25.2033329], [90.22856903, 25.20294571], [90.22780609, 25.20184326], [90.22663879, 25.20124245], [90.22547913, 25.20056725], [90.22514343, 25.20077515], [90.2248764, 25.20093918], [90.22479248, 25.20098495], [90.22454834, 25.20113373], [90.22396088, 25.20141792], [90.22350311, 25.20163918], [90.2233963, 25.20235443], [90.22324371, 25.20342064], [90.22322083, 25.20354843], [90.22272491, 25.20398903], [90.22205353, 25.20457268], [90.22120667, 25.20531464], [90.22065735, 25.20579147], [90.22002411, 25.2063446], [90.21971893, 25.20654297], [90.21942139, 25.2067318], [90.21936035, 25.20677185], [90.21909332, 25.20652199], [90.21898651, 25.20642281], [90.21868896, 25.20613861], [90.21843719, 25.20617104], [90.21832275, 25.20618629], [90.2175827, 25.20628548], [90.21727753, 25.20632744], [90.21696472, 25.2063694], [90.21646118, 25.20643616], [90.21619415, 25.2057991], [90.21603394, 25.20540619], [90.2154541, 25.2054615], [90.21516418, 25.20549011], [90.21460724, 25.20573997], [90.21398163, 25.20601845], [90.21357727, 25.20619965], [90.212883, 25.20651436], [90.21279144, 25.20655251], [90.21250153, 25.20674324], [90.21192932, 25.2071209], [90.21122742, 25.20758247], [90.20929718, 25.20825768], [90.20881653, 25.20893288], [90.20851898, 25.20934868], [90.20791626, 25.21018791], [90.20781708, 25.21032906], [90.20733643, 25.21031761], [90.20722961, 25.2103157], [90.20632172, 25.210392], [90.20600128, 25.21039391], [90.20410156, 25.21043205], [90.20277405, 25.21046829], [90.20201111, 25.21052551], [90.20077515, 25.21082497], [90.20029449, 25.21059418], [90.19980621, 25.21068954], [90.19855499, 25.21093559], [90.19690704, 25.21105957], [90.19585419, 25.21113396], [90.19534302, 25.21139145], [90.19526672, 25.21143532], [90.19467163, 25.21173477], [90.1940155, 25.21261787], [90.19277191, 25.2131958], [90.19226837, 25.2134304], [90.19213104, 25.21369362], [90.19190216, 25.21414757], [90.19189453, 25.21476936], [90.19189453, 25.21516418], [90.19109344, 25.21523476], [90.18958282, 25.21528053], [90.18910217, 25.21530724], [90.1889801, 25.21531296], [90.18847656, 25.21527672], [90.18792725, 25.21522141], [90.18733215, 25.21554184], [90.1868515, 25.21579933], [90.18447113, 25.21708679], [90.18208313, 25.21832848], [90.1796875, 25.21934891], [90.17713165, 25.22044563], [90.17676544, 25.22060394], [90.17611694, 25.22088051], [90.17584991, 25.22100449], [90.17401123, 25.22184181], [90.1727066, 25.22251129], [90.17142487, 25.22317123], [90.17058563, 25.22319031], [90.1676712, 25.22325134], [90.16634369, 25.22327614], [90.16423035, 25.2233429], [90.16146851, 25.22356606], [90.1606369, 25.22365761], [90.16023254, 25.22370338], [90.15795898, 25.22408867], [90.15527344, 25.22414589], [90.15323639, 25.22418976], [90.15172577, 25.22422218], [90.15085602, 25.22426605], [90.14894867, 25.22435951], [90.1463089, 25.22444534], [90.14428711, 25.22444725], [90.14401245, 25.22444725], [90.14295197, 25.22444916], [90.14170074, 25.22444344], [90.14002228, 25.2244339], [90.13801575, 25.22451401], [90.13706207, 25.22455406], [90.13682556, 25.22458649], [90.13613892, 25.22467422], [90.13512421, 25.22480583], [90.13349915, 25.22500801], [90.13261414, 25.22511482], [90.1313324, 25.22526169], [90.13062286, 25.2253418], [90.12885284, 25.22561646], [90.12857056, 25.22565842], [90.12806702, 25.22573662], [90.1270752, 25.22570419], [90.12607574, 25.22567177], [90.12527466, 25.22564697], [90.12471008, 25.2255764], [90.12422943, 25.22551727], [90.12224579, 25.22527885], [90.1214447, 25.22518349], [90.12135315, 25.22501373], [90.12103271, 25.22443771], [90.12063599, 25.22432709], [90.11920166, 25.22390366], [90.11806488, 25.22356606], [90.11786652, 25.22364426], [90.11759186, 25.2237606], [90.11630249, 25.2242794], [90.11495972, 25.22481918], [90.11441803, 25.22503853], [90.11345673, 25.22522163], [90.11278534, 25.22536469], [90.11226654, 25.22547531], [90.11194611, 25.22566032], [90.11149597, 25.22591782], [90.1108551, 25.22627831], [90.11030579, 25.22658157], [90.10868073, 25.22748566], [90.10758209, 25.22809601], [90.10629272, 25.22880745], [90.10527039, 25.22937584], [90.10466003, 25.22990608], [90.10449982, 25.23004723], [90.10358429, 25.23085403], [90.10340118, 25.23101234], [90.10333252, 25.23107529], [90.10286713, 25.23148918], [90.10259247, 25.23171997], [90.10230255, 25.2319622], [90.10037231, 25.23310852], [90.10002899, 25.23359489], [90.09975433, 25.23398399], [90.09920502, 25.23475075], [90.09902191, 25.23481369], [90.09753418, 25.23532486], [90.0971756, 25.23544693], [90.09612274, 25.23614311], [90.09562683, 25.2364502], [90.09499359, 25.23689842], [90.09418488, 25.23743248], [90.0938797, 25.23756409], [90.0920105, 25.23835945], [90.08997345, 25.23897171], [90.08966064, 25.23904228], [90.08797455, 25.23919678], [90.08760071, 25.23923111], [90.08664703, 25.23931503], [90.08584595, 25.2393856], [90.08488464, 25.23956299], [90.08351898, 25.23981667], [90.0819931, 25.24025917], [90.08123779, 25.24047661], [90.08068085, 25.24075127], [90.0785675, 25.24182892], [90.07844543, 25.24188614], [90.07836151, 25.24192619], [90.07757568, 25.24233055], [90.07683563, 25.2426815], [90.07676697, 25.24271584], [90.07628632, 25.24295044], [90.07617188, 25.24302292], [90.07591248, 25.24313354], [90.07510376, 25.24354935], [90.07406616, 25.24405861], [90.07324982, 25.24487495], [90.07311249, 25.24497795], [90.07203674, 25.24602127], [90.07077026, 25.24718666], [90.06985474, 25.24787331], [90.06967163, 25.24799728], [90.06930542, 25.24827576], [90.06903839, 25.24846268], [90.0688858, 25.24857712], [90.06647491, 25.25001526], [90.06480408, 25.25098801], [90.06343079, 25.25180054], [90.06326294, 25.25189972], [90.06206512, 25.25259781], [90.06143951, 25.25309944], [90.06100464, 25.25347519], [90.05978394, 25.25394821], [90.05948639, 25.25473595], [90.059021, 25.25557327], [90.05840302, 25.25670433], [90.05817413, 25.25712967], [90.05808258, 25.25731087], [90.0579071, 25.2576313], [90.05762482, 25.25813484], [90.05741119, 25.25852013], [90.05727386, 25.2587738], [90.0568924, 25.25947762], [90.05673981, 25.25981712], [90.05664063, 25.2599411], [90.05657196, 25.26007652], [90.05632019, 25.2605381], [90.0558548, 25.26075935], [90.0555954, 25.26089668], [90.05504608, 25.26119041], [90.05445862, 25.26146317], [90.0533371, 25.26135063], [90.05235291, 25.26120949], [90.05012512, 25.26103401], [90.04828644, 25.26088524], [90.04735565, 25.26081276], [90.04665375, 25.26074219], [90.04571533, 25.26091003], [90.04399109, 25.26120949], [90.04338837, 25.26124191], [90.04119873, 25.26133919], [90.04075623, 25.26130295], [90.03916168, 25.26116943], [90.03777313, 25.2612896], [90.0373764, 25.26132202], [90.03546143, 25.26177597], [90.03404236, 25.26226044], [90.03366852, 25.26239014], [90.03334808, 25.26260757], [90.03243256, 25.26324463], [90.03196716, 25.26363373], [90.03146362, 25.26407814], [90.03134918, 25.26412964], [90.02922058, 25.26502037], [90.02772522, 25.26565361], [90.02671051, 25.26627731], [90.02655029, 25.26636124], [90.02479553, 25.26730919], [90.02337646, 25.26811981], [90.02139282, 25.26920891], [90.02108765, 25.26960945], [90.02077484, 25.27005768], [90.02059937, 25.27034378], [90.02053833, 25.27043343], [90.02027893, 25.27079391], [90.02007294, 25.2711277], [90.01999664, 25.27120781], [90.01985168, 25.27142906], [90.01969147, 25.27166939], [90.01963806, 25.27174568], [90.01934052, 25.27215576], [90.0191803, 25.27224159], [90.01869202, 25.27247429], [90.01822662, 25.27267456], [90.0168457, 25.27331352], [90.01641083, 25.27349663], [90.01609039, 25.27365303], [90.01538086, 25.27397728], [90.01527405, 25.27403641], [90.01418304, 25.27444649], [90.0140152, 25.27451324], [90.01364899, 25.27465248], [90.01145172, 25.27549744], [90.01135254, 25.27553558], [90.01136017, 25.27562714], [90.01096344, 25.27568245], [90.01082611, 25.27573967], [90.01013947, 25.27605629], [90.00983429, 25.27621078], [90.0093689, 25.27649117], [90.00904846, 25.27670097], [90.00806427, 25.27742004], [90.00786591, 25.27759743], [90.00751495, 25.27792549], [90.00714874, 25.27831078], [90.0069046, 25.27860069], [90.00676727, 25.27877235], [90.00632477, 25.27921295], [90.00549316, 25.27961159], [90.00482178, 25.28016853], [90.00466156, 25.28033257], [90.00445557, 25.28052521], [90.00432587, 25.28059387], [90.00419617, 25.28063202], [90.00410461, 25.28064919], [90.00399017, 25.28063011], [90.00327301, 25.28033829], [90.00296783, 25.28024101], [90.00267029, 25.27991295], [90.00254059, 25.27979851], [90.00241089, 25.27968788], [90.00228882, 25.27964401], [90.00217438, 25.27953529], [90.00126648, 25.27909851], [90.00067139, 25.2788372], [89.99992371, 25.27842903], [89.9993515, 25.27826309], [89.99925995, 25.27824783], [89.99874115, 25.2781353], [89.99855042, 25.27791214], [89.99762726, 25.27707481], [89.99719238, 25.2769928], [89.99595642, 25.27675629], [89.99485779, 25.27720261], [89.99333191, 25.27777481], [89.9932251, 25.27779198], [89.9927063, 25.27786446], [89.99209595, 25.27798462], [89.99147797, 25.27812767], [89.99111938, 25.278265], [89.9908371, 25.27843666], [89.99074554, 25.27850342], [89.99065399, 25.27865982], [89.99049377, 25.2786808], [89.98763275, 25.2795639], [89.98690796, 25.27977562], [89.98552704, 25.28022575], [89.98500061, 25.28027725], [89.98461914, 25.2803421], [89.98423767, 25.28039169], [89.98088837, 25.28094673], [89.98070526, 25.28097725], [89.98052216, 25.28278923], [89.98049927, 25.28345871], [89.98043823, 25.28462029], [89.98046112, 25.28477287], [89.98058319, 25.28560638], [89.98052979, 25.28602219], [89.98052216, 25.28621864], [89.98042297, 25.2874279], [89.98039246, 25.28773499], [89.98029327, 25.28998756], [89.98029327, 25.29015541], [89.98028564, 25.29031563], [89.9803009, 25.29043961], [89.98030853, 25.29062653], [89.9803009, 25.29079437], [89.97908783, 25.29292107], [89.978302, 25.29439545], [89.97811127, 25.29474831], [89.9773407, 25.29620171], [89.97718048, 25.29651451], [89.97688293, 25.29707718], [89.97669983, 25.29720688], [89.97528076, 25.29815674], [89.97483063, 25.29843903], [89.97457886, 25.29859734], [89.97380066, 25.29907799], [89.9728241, 25.29976654], [89.97249603, 25.29999733], [89.97194672, 25.30037498], [89.97159576, 25.30060196], [89.97106171, 25.3010006], [89.9694519, 25.30219841], [89.96910858, 25.30241013], [89.96833801, 25.30278778], [89.9678421, 25.30303001], [89.96735382, 25.30331612], [89.96716309, 25.30332947], [89.96498108, 25.30306053], [89.96424103, 25.30266571], [89.96412659, 25.30241203], [89.96391296, 25.30203438], [89.96375275, 25.30199814], [89.96360779, 25.30201149], [89.96349335, 25.30202293], [89.962677, 25.30209732], [89.9616394, 25.30219269], [89.96115112, 25.30227661], [89.96055603, 25.30212975], [89.95658875, 25.29994011], [89.9561615, 25.29931068], [89.9546814, 25.29718971], [89.95337677, 25.29564857], [89.95092773, 25.29590988], [89.95056152, 25.29626274], [89.95021057, 25.29538155], [89.94992828, 25.29469872], [89.94972992, 25.29420471], [89.9495163, 25.29367638], [89.94917297, 25.2928257], [89.94855499, 25.29335785], [89.94839478, 25.2935009], [89.94820404, 25.29366302], [89.94781494, 25.29400063], [89.94726563, 25.29446793], [89.94685364, 25.29482079], [89.94677734, 25.29596519], [89.94676208, 25.29644203], [89.94672394, 25.29681396], [89.94670868, 25.29724312], [89.94623566, 25.29820442], [89.94582367, 25.29912567], [89.94568634, 25.30030441], [89.94551849, 25.3015995], [89.94551849, 25.30264854], [89.94559479, 25.30290413], [89.94467926, 25.30370522], [89.94439697, 25.30395317], [89.94407654, 25.30423737], [89.94384003, 25.30445099], [89.94322968, 25.30377007], [89.94252777, 25.302948], [89.9413681, 25.30166054], [89.94114685, 25.30141258], [89.94094849, 25.3011837], [89.94078827, 25.3010273], [89.94037628, 25.30059624], [89.93978119, 25.29998207], [89.93894958, 25.29914474], [89.93836975, 25.29925728], [89.93810272, 25.29931641], [89.93795013, 25.29935074], [89.9371109, 25.29954338], [89.93654633, 25.29966927], [89.93618011, 25.29975319], [89.93516541, 25.29998207], [89.93501282, 25.3000164], [89.9348526, 25.30010223], [89.93473053, 25.30020332], [89.9339447, 25.30081749], [89.93371582, 25.30083656], [89.93357849, 25.30084801], [89.93238831, 25.30092812], [89.9322052, 25.30095291], [89.93188477, 25.30098915], [89.93099976, 25.30111313], [89.93069458, 25.30113983], [89.92942047, 25.30130005], [89.9291687, 25.30127335], [89.92906189, 25.30127907], [89.92850494, 25.30130196], [89.92835999, 25.3013134], [89.92733765, 25.30141068], [89.92701721, 25.30142593], [89.92668915, 25.30171585], [89.92661285, 25.30179214], [89.92608643, 25.3022728], [89.92591095, 25.30246162], [89.92545319, 25.30288887], [89.92388153, 25.30406189], [89.92345428, 25.30436325], [89.92301941, 25.30439377], [89.92261505, 25.30442047], [89.92205048, 25.30446053], [89.92114258, 25.30451965], [89.9208374, 25.30454063], [89.92025757, 25.30458641], [89.91977692, 25.30463982], [89.91937256, 25.30467606], [89.91899872, 25.304739], [89.9187088, 25.30477715], [89.9183197, 25.30485344], [89.91801453, 25.30496979], [89.9174118, 25.30522537], [89.91702271, 25.30538368], [89.91670227, 25.30551529], [89.91611481, 25.30595779], [89.915802, 25.30616188], [89.91517639, 25.30661774], [89.9144516, 25.30712891], [89.91365814, 25.30730629], [89.91329956, 25.30738258], [89.9131012, 25.30741501], [89.91281128, 25.30748177], [89.9123764, 25.30751991], [89.91216278, 25.30753517], [89.91139984, 25.30757523], [89.9101181, 25.30790901], [89.90965271, 25.30799294], [89.90908813, 25.30812454], [89.9063797, 25.30742073], [89.905159, 25.30632019], [89.90164948, 25.30321121], [89.89412689, 25.29536057], [89.88968658, 25.28988075], [89.8864212, 25.2877903], [89.88259888, 25.28720284], [89.88210297, 25.28672218], [89.88079071, 25.28647041], [89.87765503, 25.28570938], [89.87653351, 25.28544617], [89.87522888, 25.28556061], [89.87451935, 25.28583336], [89.87421417, 25.28594398], [89.87375641, 25.28609657], [89.87257385, 25.28681374], [89.8720932, 25.28682327], [89.87091827, 25.28684616], [89.87086487, 25.28677177], [89.87055969, 25.28684807], [89.86988068, 25.28685951], [89.86945343, 25.28689003], [89.86934662, 25.2869091], [89.8684845, 25.28713226], [89.86811066, 25.28723717], [89.86755371, 25.28739166], [89.86655426, 25.28760529], [89.86608887, 25.28770447], [89.8655777, 25.28781128], [89.86472321, 25.28786087], [89.86452484, 25.28788948], [89.86429596, 25.28786469], [89.86309814, 25.28803253], [89.86267853, 25.28781319], [89.86251831, 25.28772926], [89.86238098, 25.28765678], [89.86186218, 25.28738403], [89.86079407, 25.28738022], [89.86000061, 25.28737831], [89.85923767, 25.28615761], [89.85888672, 25.28624725], [89.85795593, 25.28647995], [89.85680389, 25.28676987], [89.85678101, 25.28685951], [89.85671997, 25.28715706], [89.85664368, 25.28751373], [89.85624695, 25.28762054], [89.85540009, 25.28785133], [89.85497284, 25.28796577], [89.85440826, 25.28876686], [89.85387421, 25.28953362], [89.85370636, 25.28953171], [89.85311127, 25.28952789], [89.85186005, 25.28955841], [89.85157776, 25.2895813], [89.85124969, 25.28960228], [89.85094452, 25.28959274], [89.85025787, 25.28959465], [89.84971619, 25.28956413], [89.84926605, 25.28956032], [89.84849548, 25.28949165], [89.84836578, 25.29024696], [89.84822845, 25.29096603], [89.84709167, 25.29101372], [89.84692383, 25.29102135], [89.84618378, 25.29105377], [89.84609222, 25.29105759], [89.84607697, 25.29120445], [89.84603882, 25.29180145], [89.84490204, 25.29203224], [89.84487915, 25.29210472], [89.84476471, 25.29249382], [89.84300995, 25.29267693], [89.84256744, 25.29268265], [89.84194183, 25.29273796], [89.84086609, 25.29281998], [89.84033203, 25.29287148], [89.83934784, 25.29307175], [89.83837891, 25.29327202], [89.83791351, 25.29403114], [89.83752441, 25.2946682], [89.83698273, 25.29467773], [89.83649445, 25.29468727], [89.83622742, 25.29469299], [89.83538055, 25.29471207], [89.83478546, 25.29472542], [89.83447266, 25.29484558], [89.83390808, 25.29506683], [89.83280945, 25.29549599], [89.831604, 25.29566193], [89.8311615, 25.29614067], [89.83193207, 25.29683876], [89.83204651, 25.29693985], [89.832901, 25.2977066], [89.83401489, 25.29854393], [89.83486176, 25.29924774], [89.83617401, 25.30059814], [89.83666992, 25.3011055], [89.8367691, 25.30124283], [89.83690643, 25.30145454], [89.83719635, 25.30183601], [89.83764648, 25.30247307], [89.83763885, 25.30392838], [89.83760071, 25.30402756], [89.83724976, 25.30522346], [89.83718872, 25.30542564], [89.83896637, 25.30703545], [89.84013367, 25.30758858], [89.84046173, 25.30774307], [89.84155273, 25.30826378], [89.84080505, 25.30948448], [89.84113312, 25.31085396], [89.84134674, 25.31249428], [89.84136963, 25.31273079], [89.84135437, 25.31301498], [89.841362, 25.31415558], [89.84123993, 25.31558418], [89.84113312, 25.31620979], [89.84107971, 25.3165226], [89.84034729, 25.31780243], [89.84014893, 25.31818581], [89.84049988, 25.31903267], [89.83972168, 25.32036972], [89.83844757, 25.32308197], [89.83827209, 25.32353783], [89.83665466, 25.32634735], [89.83551788, 25.3279171], [89.835289, 25.32820129], [89.8345108, 25.32915115], [89.83344269, 25.33039474], [89.83324432, 25.33060646], [89.83300018, 25.33089828], [89.83290863, 25.33109283], [89.8328476, 25.33123398], [89.83272552, 25.33148766], [89.83249664, 25.3319912], [89.83105469, 25.33512688], [89.8303833, 25.33659744], [89.83026886, 25.33693695], [89.8291626, 25.3397789], [89.82898712, 25.34030151], [89.82886505, 25.34057999], [89.82855225, 25.34139633], [89.82788849, 25.34349632], [89.8273468, 25.34510422], [89.82674408, 25.34688187], [89.82531738, 25.34668541], [89.82511902, 25.34668159], [89.82386017, 25.34754181], [89.82350159, 25.34797478], [89.82332611, 25.3482666], [89.8230896, 25.34880638], [89.82299042, 25.34904289], [89.82279205, 25.34965706], [89.82269287, 25.34996605], [89.82262421, 25.35012627], [89.82247925, 25.35080528], [89.82245636, 25.35095787], [89.8224411, 25.35119629], [89.82238007, 25.35157967], [89.82217407, 25.35322571], [89.82221985, 25.35387611], [89.82196808, 25.35439682], [89.82190704, 25.35462189], [89.82136536, 25.35562515], [89.8212738, 25.35657883], [89.8212204, 25.35706139], [89.82112885, 25.3578949], [89.82105255, 25.35887337], [89.82096863, 25.35977745], [89.82090759, 25.36159134], [89.82084656, 25.36355782], [89.820961, 25.36481476], [89.8211441, 25.3670578], [89.82115936, 25.36856461], [89.82109833, 25.37005234], [89.82103729, 25.37130547], [89.82118988, 25.37244415], [89.82121277, 25.37283516], [89.82119751, 25.37320518], [89.82121277, 25.37343216], [89.82115936, 25.37450027], [89.82093048, 25.375], [89.82060242, 25.37579918], [89.81999969, 25.37743187], [89.81959534, 25.37909126], [89.81950378, 25.37947273], [89.81958008, 25.3807869], [89.81972504, 25.38148499], [89.81990814, 25.38216019], [89.81997681, 25.38259697], [89.82051086, 25.38360405], [89.82066345, 25.3839016], [89.82250977, 25.38736725], [89.82279968, 25.38805008], [89.82325745, 25.38868141], [89.82339478, 25.38887215], [89.82344055, 25.38909912], [89.82349396, 25.38926888], [89.82351685, 25.38945961], [89.82370758, 25.3907814], [89.82398224, 25.39255524], [89.82410431, 25.393116], [89.82418823, 25.39380836], [89.82479095, 25.39632034], [89.8263092, 25.39944458], [89.82675934, 25.40065193], [89.82678986, 25.40077209], [89.82700348, 25.40163231], [89.82720947, 25.40301514], [89.82730865, 25.40406418], [89.82733917, 25.40466499], [89.82732391, 25.40561676], [89.8272934, 25.40598488], [89.82728577, 25.40634537], [89.82590485, 25.4066658], [89.82530975, 25.40781593], [89.82529449, 25.40835381], [89.82523346, 25.40890694], [89.82518768, 25.40948296], [89.8252182, 25.41018867], [89.82524872, 25.41091156], [89.82531738, 25.41227722], [89.82530975, 25.41286278], [89.82534027, 25.41332436], [89.82536316, 25.41347694], [89.82550049, 25.41387177], [89.82559204, 25.41419983], [89.82561493, 25.41498184], [89.82562256, 25.41521835], [89.82565308, 25.41661453], [89.82855988, 25.42372131], [89.83052063, 25.42851257], [89.83123016, 25.43238449], [89.83155823, 25.43415642], [89.83181763, 25.43554878], [89.83194733, 25.43585587], [89.83209229, 25.43618202], [89.83226013, 25.43697357], [89.83246613, 25.43759537], [89.83260345, 25.43836021], [89.83266449, 25.43887138], [89.83291626, 25.43932915], [89.83448792, 25.4422226], [89.8345871, 25.44238091], [89.83472443, 25.44260025], [89.83479309, 25.44271088], [89.83496094, 25.44299126], [89.83576965, 25.44445801], [89.83627319, 25.44534874], [89.83782196, 25.44842339], [89.83811951, 25.44884682], [89.83818054, 25.44898987], [89.83852386, 25.44960976], [89.83854675, 25.44969749], [89.83863831, 25.44979095], [89.83868408, 25.44989014], [89.83892822, 25.45027924], [89.83900452, 25.45049858], [89.83945465, 25.4511528], [89.84029388, 25.45248985], [89.84053802, 25.45290184], [89.8409729, 25.45360565], [89.84112549, 25.45379448], [89.84135437, 25.45414734], [89.84146881, 25.45433807], [89.84210968, 25.45525551], [89.84243774, 25.45579338], [89.84375763, 25.45745659], [89.84436035, 25.4581089], [89.84462738, 25.45851326], [89.84502411, 25.45882607], [89.84544373, 25.45916557], [89.84562683, 25.45942116], [89.8458252, 25.45969391], [89.84627533, 25.46016312], [89.84651947, 25.46045303], [89.84698486, 25.46095276], [89.84716797, 25.46120644], [89.84796143, 25.4624157], [89.84870911, 25.46303368], [89.84882355, 25.4631443], [89.84841919, 25.46318817], [89.8473053, 25.46330833], [89.84820557, 25.46333694], [89.84881592, 25.46347618], [89.84923553, 25.46357155], [89.84942627, 25.46372223], [89.84965515, 25.46393394], [89.85015106, 25.46425056], [89.85015869, 25.46450424], [89.85030365, 25.46466446], [89.85057068, 25.46487427], [89.85115051, 25.46535683], [89.85144043, 25.46558952], [89.85164642, 25.46572304], [89.85197449, 25.46588898], [89.85211945, 25.46595001], [89.85215759, 25.4662075], [89.85215759, 25.46629906], [89.8522644, 25.46636963], [89.852005, 25.46675301], [89.85202789, 25.46690369], [89.85202789, 25.46698761], [89.85202789, 25.46707535], [89.85206604, 25.46717453], [89.85205841, 25.46724701], [89.85181427, 25.46741676], [89.85173798, 25.46747017], [89.85159302, 25.46757507], [89.85159302, 25.46788025], [89.85160065, 25.46834564], [89.85166168, 25.46848106], [89.85176086, 25.46866608], [89.85185242, 25.46886253], [89.85193634, 25.4691143], [89.85193634, 25.46936417], [89.85197449, 25.46992302], [89.85201263, 25.4700489], [89.852005, 25.47020149], [89.85198212, 25.47059059], [89.85197449, 25.47071075], [89.85206604, 25.47137451], [89.85208893, 25.47175026], [89.85205841, 25.47219849], [89.85220337, 25.47242546], [89.85214233, 25.47261429], [89.85205841, 25.47273827], [89.85195923, 25.47286224], [89.85182953, 25.47295189], [89.85157013, 25.47307777], [89.85137939, 25.47317314], [89.85083008, 25.47358322], [89.8507309, 25.47364616], [89.85060883, 25.47372437], [89.85040283, 25.47380829], [89.84997559, 25.47392845], [89.84972382, 25.47397232], [89.84922791, 25.47401428], [89.84923553, 25.47411728], [89.84928894, 25.47513962], [89.84933472, 25.4753685], [89.84944153, 25.47681999], [89.84949493, 25.47724533], [89.84954071, 25.47840309], [89.84955597, 25.4789238], [89.84962463, 25.48045731], [89.84960938, 25.48068428], [89.8495636, 25.48085594], [89.84949493, 25.48133469], [89.84957886, 25.48199654], [89.84976959, 25.48278999], [89.84988403, 25.48330688], [89.8501358, 25.48406219], [89.85021973, 25.48424149], [89.85038757, 25.4846077], [89.85022736, 25.48469925], [89.85001373, 25.48478699], [89.84989929, 25.48483467], [89.84998322, 25.48497963], [89.85005188, 25.48511124], [89.8502655, 25.48513794], [89.85032654, 25.48519325], [89.85037231, 25.48538589], [89.85045624, 25.48585892], [89.85028076, 25.48615456], [89.85015869, 25.48631096], [89.84973907, 25.48683929], [89.849617, 25.48725128], [89.8495636, 25.48760796], [89.8494339, 25.48791313], [89.84938049, 25.48812866], [89.84928131, 25.48831749], [89.84916687, 25.48853493], [89.84912872, 25.48866081], [89.84907532, 25.48890877], [89.84905243, 25.48908043], [89.84898376, 25.48945427], [89.84896851, 25.49003601], [89.84910583, 25.49032021], [89.84920502, 25.49119186], [89.84936523, 25.49203491], [89.84926605, 25.49206924], [89.84912872, 25.49211502], [89.84913635, 25.49223709], [89.84915924, 25.4925251], [89.84921265, 25.49272156], [89.84962463, 25.49349213], [89.84983063, 25.49380302], [89.85048676, 25.49391174], [89.85094452, 25.49400902], [89.85113525, 25.4940815], [89.85131073, 25.49412727], [89.8514328, 25.49413109], [89.85155487, 25.49419022], [89.85170746, 25.49422836], [89.85179901, 25.49429321], [89.85223389, 25.49449921], [89.85258484, 25.49471474], [89.85277557, 25.49481773], [89.85293579, 25.49492264], [89.85313416, 25.49512482], [89.85345459, 25.49537849], [89.85355377, 25.49549484], [89.8536911, 25.49559212], [89.85388947, 25.49577141], [89.8547821, 25.49701118], [89.85504913, 25.49729729], [89.85514832, 25.4975338], [89.85516357, 25.49775505], [89.85486603, 25.49829102], [89.854599, 25.49906921], [89.85453033, 25.49941826], [89.85423279, 25.50017166], [89.85409546, 25.50050926], [89.85391235, 25.50106812], [89.85377502, 25.50152588], [89.85366821, 25.50203705], [89.85359192, 25.50244904], [89.85356903, 25.50294685], [89.85359955, 25.50349236], [89.85370636, 25.50403976], [89.85385132, 25.50434494], [89.85393524, 25.50428009], [89.85412598, 25.50423622], [89.85558319, 25.50363922], [89.85700989, 25.50445366], [89.85704041, 25.50454903], [89.85753632, 25.50603867], [89.85788727, 25.50650406], [89.8579483, 25.50670052], [89.85823059, 25.50781822], [89.85829926, 25.50816727], [89.85848999, 25.5089016], [89.8585434, 25.50972748], [89.8587265, 25.51025772], [89.85883331, 25.51025772], [89.85909271, 25.51124382], [89.85933685, 25.51220894], [89.85936737, 25.51241493], [89.85945892, 25.5129528], [89.85953522, 25.51320839], [89.85960388, 25.51371384], [89.8596344, 25.51390457], [89.85965729, 25.5142231], [89.85967255, 25.51436806], [89.85974121, 25.51464844], [89.85982513, 25.51531219], [89.8599472, 25.51598358], [89.85998535, 25.51639938], [89.8600769, 25.51692963], [89.86012268, 25.51728439], [89.86018372, 25.51772308], [89.85997009, 25.51821327], [89.85964966, 25.51896477], [89.85933685, 25.51961517], [89.85864258, 25.5210762], [89.8584137, 25.52163124], [89.85812378, 25.52229309], [89.85758972, 25.523489], [89.85748291, 25.52377129], [89.85738373, 25.52415276], [89.85709381, 25.52495956], [89.85695648, 25.52534294], [89.85676575, 25.52571297], [89.85652924, 25.52636909], [89.85648346, 25.52646065], [89.8562088, 25.52723312], [89.85610199, 25.52758408], [89.85559082, 25.52884674], [89.85553741, 25.5291481], [89.85529327, 25.52970123], [89.85509491, 25.5301857], [89.85494995, 25.5305481], [89.85478973, 25.53093338], [89.85464478, 25.53121948], [89.85437775, 25.53189278], [89.85430145, 25.53206062], [89.85426331, 25.53220749], [89.85401917, 25.53277779], [89.85397339, 25.53295326], [89.85373688, 25.53343964], [89.85356903, 25.53388214], [89.8532486, 25.53458595], [89.85308838, 25.53494072], [89.85302734, 25.53512192], [89.85294342, 25.53526115], [89.85286713, 25.53538895], [89.85280609, 25.53561974], [89.85266876, 25.53580856], [89.85236359, 25.53642464], [89.8521347, 25.53688812], [89.8513031, 25.53854942], [89.85121918, 25.53871918], [89.85144806, 25.53909683], [89.85208893, 25.53929138], [89.85502625, 25.54023933], [89.85575104, 25.54033089], [89.85612488, 25.54055214], [89.85630798, 25.54066277], [89.85673523, 25.54080582], [89.85785675, 25.54154396], [89.85817719, 25.54178238], [89.85848999, 25.54200172], [89.85914612, 25.54227257], [89.8595047, 25.54243088], [89.85972595, 25.54250336], [89.86039734, 25.54270172], [89.8608551, 25.54276085], [89.86110687, 25.54281616], [89.86196899, 25.54297256], [89.86217499, 25.5430069], [89.86235809, 25.54302216], [89.86273193, 25.54319382], [89.86621094, 25.54284096], [89.87015533, 25.54494286], [89.87010193, 25.54422188], [89.87380219, 25.54928017], [89.87758636, 25.54893112], [89.88636017, 25.55787086], [89.90441132, 25.55949974], [89.91809845, 25.5626297], [89.92605591, 25.56352997], [89.93583679, 25.56270981], [89.94164276, 25.56762123], [89.94937897, 25.56825066], [89.95675659, 25.57046127], [89.96646118, 25.57170105], [89.97280884, 25.57460976], [89.97505188, 25.58350945], [89.97915649, 25.59073067], [89.98950195, 25.58880997], [89.99536133, 25.58634949], [90.00212097, 25.58419037], [90.00582123, 25.58836937], [90.01106262, 25.59835052], [90.01729584, 25.60219193], [90.01844025, 25.60839081], [90.00453949, 25.62382126], [90.00138092, 25.62443161], [89.99933624, 25.62185097], [89.99529266, 25.62302971], [89.98332214, 25.62671089], [89.98230743, 25.62843132], [89.98043823, 25.63756943], [89.94695282, 25.65883064], [89.94184875, 25.67365074], [89.94172668, 25.67811966], [89.93699646, 25.68663025], [89.93235016, 25.68996048], [89.92112732, 25.69442177], [89.91954803, 25.69676971], [89.91850281, 25.70268822], [89.91427612, 25.7040081], [89.9126358, 25.70706177], [89.90487671, 25.71478081], [89.89424133, 25.72723961], [89.89261627, 25.73500061], [89.89541626, 25.74411964], [89.899086, 25.74405098], [89.91137695, 25.74156952], [89.9161377, 25.73919106], [89.92186737, 25.73916817], [89.92794037, 25.74135017], [89.93350983, 25.7445507], [89.93464661, 25.74753952], [89.93371582, 25.75253105], [89.94351959, 25.76054192], [89.94668579, 25.76472092], [89.95239258, 25.77017021], [89.95524597, 25.77445984], [89.95501709, 25.78164101], [89.9526062, 25.78342056], [89.95081329, 25.79198074], [89.95199585, 25.81091118], [89.94935608, 25.81442261], [89.94561768, 25.81610107], [89.94581604, 25.82023048], [89.94458008, 25.82447815], [89.95056915, 25.82487106], [89.95886993, 25.8265686], [89.96795654, 25.82615089], [89.97354889, 25.82814026], [89.97589874, 25.83403969], [89.99080658, 25.83551025], [89.99471283, 25.83876038], [89.99780273, 25.83967018], [90.00160217, 25.84224129], [89.99983215, 25.84369087], [89.99743652, 25.84420967], [89.99756622, 25.84670067], [90.00026703, 25.84860039], [90.00831604, 25.84683037], [90.01152039, 25.84967041], [90.02076721, 25.86161041], [90.02191925, 25.86552811], [90.02137756, 25.86849022], [90.01872253, 25.87137032], [90.01436615, 25.87178993], [90.00977325, 25.87573051], [90.00473785, 25.87868118], [90.01525116, 25.88862038], [90.02126312, 25.89319038], [90.02791595, 25.89431], [90.03450775, 25.89351082], [90.042099, 25.89075089], [90.05219269, 25.89868927], [90.0550766, 25.90809059], [90.05892181, 25.91027069], [90.06330872, 25.91554832], [90.06761932, 25.91616058], [90.07242584, 25.91933823], [90.07797241, 25.91768074], [90.07945251, 25.9192791], [90.08072662, 25.92452812], [90.08738708, 25.92626953], [90.09192657, 25.92876053], [90.08795929, 25.93619919], [90.09612274, 25.93951988], [90.09913635, 25.93926048], [90.10051727, 25.9420681], [90.10536957, 25.94193077], [90.10788727, 25.95059013], [90.11091614, 25.9541111], [90.11377716, 25.95743942], [90.11865234, 25.96125984], [90.12000275, 25.9577198], [90.12322998, 25.95716286], [90.12844849, 25.95877075], [90.13407898, 25.95780945], [90.14002991, 25.95813942], [90.14739227, 25.96447945], [90.15339661, 25.9647007], [90.15448761, 25.9602108], [90.15838623, 25.95825958], [90.16349792, 25.95736122], [90.16848755, 25.95738029], [90.1726532, 25.95874977], [90.17611694, 25.95708275], [90.18052673, 25.9470005], [90.18251038, 25.94445038], [90.18566895, 25.94556999], [90.18945313, 25.95323944], [90.1939621, 25.95700073], [90.20844269, 25.96157265], [90.21112061, 25.95564079], [90.21276093, 25.95388985], [90.22737122, 25.95513916], [90.27781677, 25.96317291], [90.28658295, 25.96389961], [90.32434082, 25.97438049], [90.32905579, 25.98269844], [90.32994843, 25.9885006], [90.33692169, 25.99016953], [90.33931732, 25.9968605], [90.34485626, 26.00123978], [90.3466568, 26.00295258], [90.36499023, 26.01032066], [90.38080597, 26.01164818], [90.38736725, 26.01126289], [90.39395142, 26.01410103], [90.39649963, 26.01415062], [90.39729309, 26.01222992], [90.40019226, 26.00928116], [90.40756226, 26.00756073], [90.41104126, 26.00587082], [90.41394043, 26.00131989], [90.41649628, 25.99685097], [90.41742706, 25.99234009], [90.42862701, 25.98904037], [90.44711304, 25.99653053], [90.45751953, 25.99957275], [90.45791626, 26.00134087], [90.45909882, 26.00323105], [90.46530151, 26.00722122], [90.47090149, 26.01259995], [90.47728729, 26.0152607], [90.48121643, 26.01402283], [90.48958588, 26.00963974], [90.49236298, 26.00650978], [90.49793243, 26.00365067], [90.50013733, 26.00136185], [90.5057373, 25.99602127], [90.51355743, 25.98237038], [90.52406311, 25.96990013], [90.52983856, 25.96186066], [90.53446198, 25.95802116], [90.53479767, 25.94564056], [90.53378296, 25.93629265], [90.5322113, 25.93255234], [90.52616119, 25.92827988], [90.51851654, 25.90940094], [90.51110077, 25.90014076], [90.51254272, 25.89624023], [90.518013, 25.89648056], [90.52548218, 25.90101051], [90.53360748, 25.90880013], [90.53917694, 25.91546059], [90.54682159, 25.91987991], [90.55335999, 25.92912102], [90.56324005, 25.93556976], [90.57137299, 25.93902969], [90.57273865, 25.94400024], [90.57277679, 25.94815063], [90.57879639, 25.9580307], [90.5824585, 25.95979118], [90.58727264, 25.95391273], [90.59185028, 25.95211983], [90.60193634, 25.95178032], [90.60539246, 25.94695091], [90.62901306, 25.93742943], [90.60756683, 25.91958046], [90.60650635, 25.91228104], [90.60809326, 25.90801811], [90.61074829, 25.90744972], [90.61419678, 25.89950943], [90.62480927, 25.89889908], [90.62671661, 25.90135956], [90.62893677, 25.90654945], [90.62686157, 25.91127014], [90.62732697, 25.91699028], [90.63783264, 25.92333031], [90.6539917, 25.9296627], [90.6701889, 25.93425941], [90.67565155, 25.93647957], [90.68604279, 25.95080948], [90.71309662, 25.95218277], [90.71774292, 25.9547081], [90.72068024, 25.94917107], [90.72540283, 25.94877052], [90.73226929, 25.95256042], [90.74028778, 25.95491028], [90.74355316, 25.95667267], [90.74743652, 25.95732117], [90.74604797, 25.95264053], [90.74378967, 25.94943047], [90.74469757, 25.94650078], [90.74030304, 25.94089127], [90.744133, 25.93279076], [90.74746704, 25.93231964], [90.75070953, 25.93408012], [90.75263977, 25.93395996], [90.74619293, 25.92193031], [90.74053955, 25.91521072], [90.74234009, 25.91295052], [90.74543762, 25.91229057], [90.75006104, 25.91924095], [90.75894928, 25.9216404], [90.75762939, 25.91657066], [90.75772095, 25.91107178], [90.7690506, 25.90851021], [90.77806091, 25.90829086], [90.77848816, 25.91430092], [90.78167725, 25.92124939], [90.79170227, 25.93573952], [90.79709625, 25.9414711], [90.80869293, 25.94718933], [90.80989075, 25.95215988], [90.82044983, 25.94842911], [90.82388306, 25.94510078], [90.82800293, 25.94742966], [90.83226013, 25.94528008], [90.8361969, 25.9472599], [90.83676147, 25.93819046], [90.83983612, 25.93843269], [90.84104156, 25.94317055], [90.84323883, 25.94481087], [90.85679626, 25.94433022], [90.86960602, 25.94239998], [90.87288666, 25.94292259], [90.87240601, 25.94672966], [90.87523651, 25.94911957], [90.88022614, 25.94625092], [90.88143921, 25.95063972], [90.88298035, 25.9517498], [90.88835907, 25.94362068], [90.89238739, 25.93906021], [90.89646149, 25.93746948], [90.89704132, 25.93538094], [90.89537811, 25.93151093], [90.90119171, 25.92959023], [90.91252899, 25.92029953], [90.91607666, 25.91505814], [90.91911316, 25.913311], [90.91629791, 25.92814064], [90.9158783, 25.94316101], [90.91834259, 25.94316101], [90.93206787, 25.93967247], [90.93466187, 25.94114113], [90.93749237, 25.94476128], [90.94274902, 25.9475708], [90.9455719, 25.93912125], [90.95384979, 25.93670273], [90.95791626, 25.93394279], [90.96063995, 25.92769814], [90.96689606, 25.90533066], [90.96730804, 25.89664078], [90.96660614, 25.89100075], [90.967453, 25.88718033], [90.97132874, 25.88767052], [90.97538757, 25.88945007], [90.98480225, 25.88993263], [90.99688721, 25.8886795], [91.00132751, 25.88648987], [91.01373291, 25.88431931], [91.02060699, 25.88727951], [91.02568054, 25.88838005], [91.02828979, 25.88857079], [91.02922058, 25.88804817], [91.02910614, 25.87985039], [91.02651978, 25.86662102], [91.0218277, 25.86133194], [91.01512909, 25.85906029], [91.0131073, 25.85719109], [91.01274109, 25.84884071], [91.00866699, 25.83823967], [91.00158691, 25.82579994], [91.00078583, 25.82225037], [91.00611115, 25.8207798], [91.01270294, 25.8210907], [91.02081299, 25.82262039], [91.02494049, 25.82756042], [91.0419693, 25.83940125], [91.04910278, 25.84880829], [91.06590271, 25.84642029], [91.07853699, 25.85261917], [91.07299805, 25.84247971], [91.07287598, 25.83833122], [91.06751251, 25.83630943], [91.0617981, 25.83608055], [91.05722046, 25.83204269], [91.04988098, 25.82889938], [91.059021, 25.82226944], [91.06326294, 25.82036972], [91.06653595, 25.82575989], [91.08135223, 25.82934189], [91.12078094, 25.83134079], [91.12634277, 25.83819962], [91.13168335, 25.84194946], [91.13790894, 25.84213066], [91.14539337, 25.84733963], [91.15286255, 25.85007286], [91.16165161, 25.84931946], [91.16819, 25.84563065], [91.17901611, 25.84275055], [91.1817627, 25.84412193], [91.18547058, 25.84996986], [91.19303894, 25.85523033], [91.1964798, 25.8590107], [91.19812012, 25.8548317], [91.1986618, 25.84763908], [91.20262909, 25.84054184], [91.19451904, 25.83061028], [91.19431305, 25.82640076], [91.18987274, 25.8207798], [91.18815613, 25.81557083], [91.19095612, 25.81069946], [91.18724823, 25.80328941], [91.18474579, 25.79503059], [91.18396759, 25.78259087], [91.17993164, 25.7763195], [91.18118286, 25.77334976], [91.18591309, 25.76993942], [91.18569946, 25.76687813], [91.18917847, 25.7634697], [91.18871307, 25.73892975], [91.19233704, 25.73608971], [91.19198608, 25.72958183], [91.19799805, 25.73097992], [91.21586609, 25.72390938], [91.22144318, 25.72604942], [91.22387695, 25.72341919], [91.23249817, 25.7291584], [91.25537109, 25.74782944], [91.26228333, 25.74929047], [91.27562714, 25.74694061], [91.27646637, 25.75167084], [91.27958679, 25.75666237], [91.28729248, 25.76411057], [91.29689789, 25.77824974], [91.30632782, 25.79636955], [91.32498932, 25.8237896], [91.33242798, 25.83209038], [91.33217621, 25.83370018], [91.33355713, 25.83884048], [91.33642578, 25.83840942], [91.34249115, 25.83609962], [91.3443985, 25.83943939], [91.34855652, 25.8403511], [91.35330963, 25.83773994], [91.35688782, 25.84146118], [91.36370087, 25.84049034], [91.37049866, 25.84430122], [91.3768692, 25.84487915], [91.38211823, 25.84693909], [91.38851929, 25.84729958], [91.40119171, 25.85110092], [91.40509033, 25.84988022], [91.41272736, 25.85391808], [91.41889954, 25.85472107], [91.42430115, 25.85355949], [91.43084717, 25.84776115], [91.44122314, 25.84163094], [91.44439697, 25.84102058], [91.44740295, 25.84566116], [91.45495605, 25.85131264], [91.46872711, 25.85902977], [91.47496033, 25.85719109], [91.47840118, 25.85768127], [91.48303986, 25.86289978], [91.49603271, 25.86234093], [91.50788116, 25.8647995], [91.51275635, 25.86655807], [91.51911926, 25.87312126], [91.52176666, 25.87434959], [91.52540588, 25.87289047], [91.52887726, 25.88087082], [91.53262329, 25.88406944], [91.53205872, 25.88815117], [91.52973938, 25.88968086], [91.52577972, 25.89010811], [91.5222168, 25.88593292], [91.51976776, 25.87802124], [91.51725006, 25.87467194], [91.5135498, 25.8709507], [91.50778198, 25.86744118], [91.49830627, 25.86720276], [91.49369049, 25.86552811], [91.47738647, 25.86872292], [91.47476196, 25.87123108], [91.47593689, 25.87803841], [91.47867584, 25.8846817], [91.48338318, 25.89105988], [91.48853302, 25.89484978], [91.49291992, 25.89557838], [91.49861145, 25.8924675], [91.50325775, 25.89216042], [91.50115204, 25.89846992], [91.50853729, 25.90975952], [91.52478027, 25.92078972], [91.53132629, 25.92371178], [91.5358963, 25.93400192], [91.521698, 25.92485046], [91.51685333, 25.92002106], [91.51078033, 25.91543007], [91.50557709, 25.91308022], [91.50334167, 25.9143219], [91.50163269, 25.92076111], [91.51628876, 25.9383297], [91.51978302, 25.94089127], [91.51818848, 25.95280266], [91.51850128, 25.95815086], [91.52379608, 25.95940971], [91.52584839, 25.96132088], [91.53240967, 25.96224022], [91.53717041, 25.96210098], [91.53727722, 25.96838951], [91.54894257, 25.97509766], [91.5512619, 25.97489929], [91.55484009, 25.98661041], [91.56536865, 26.00184059], [91.56608582, 26.00375938], [91.56513214, 26.00750923], [91.56859589, 26.01194954], [91.56971741, 26.01684189], [91.56880951, 26.02174187], [91.57003021, 26.02748108], [91.57583618, 26.03310966], [91.58409882, 26.03198051], [91.58812714, 26.03014946], [91.59706116, 26.01706123], [91.59680939, 26.02079964], [91.60186768, 26.02263069], [91.61654663, 26.02472115], [91.62029266, 26.02703094], [91.62610626, 26.02396965], [91.63215637, 26.02240944], [91.63339996, 26.01785088], [91.63210297, 26.01395988], [91.63302612, 26.00490952], [91.63207245, 26.00187111], [91.63044739, 25.99982834], [91.62671661, 25.99765015], [91.62866974, 25.99513054], [91.62471771, 25.98590279], [91.62679291, 25.98238945], [91.62802124, 25.97697067], [91.63214111, 25.97079086], [91.63794708, 25.96484947], [91.63408661, 25.96050072], [91.63011932, 25.94463921], [91.62462616, 25.94597054], [91.6109314, 25.94460106], [91.61115265, 25.93992043], [91.62275696, 25.93099022], [91.63282776, 25.92576981], [91.6479187, 25.91374016], [91.65148926, 25.90766907], [91.65688324, 25.90788078], [91.66194153, 25.90987968], [91.66723633, 25.90818977], [91.66931152, 25.90538979], [91.67598724, 25.91183281], [91.6785965, 25.91732025], [91.68641663, 25.92124939], [91.69232178, 25.92910194], [91.70197296, 25.93792915], [91.70091248, 25.94189072], [91.70816803, 25.94437027], [91.71393585, 25.94722939], [91.7201767, 25.95407104], [91.72162628, 25.96507835], [91.71977997, 25.97830009], [91.72116852, 26.00184059], [91.72276306, 26.01979828], [91.72466278, 26.02725983], [91.72318268, 26.03032112], [91.72640991, 26.04691124], [91.73295593, 26.05102921], [91.73458862, 26.05664063], [91.73126221, 26.05920982], [91.75948334, 26.07129288], [91.77206421, 26.08448219], [91.77851868, 26.09124947], [91.78042603, 26.0883007], [91.78457642, 26.08658028], [91.79036713, 26.08702087], [91.80178833, 26.10494041], [91.80805969, 26.10382271], [91.81080627, 26.1051712], [91.81555939, 26.11144066], [91.81931305, 26.11874008], [91.82655334, 26.11814117], [91.85383606, 26.10478973], [91.86470032, 26.10034752], [91.87578583, 26.09773064], [91.87523651, 26.08456039], [91.86934662, 26.05685997], [91.87016296, 26.05219078], [91.88323212, 26.03000069], [91.89195251, 26.02955246], [91.90091705, 26.02626991], [91.90746307, 26.02711105], [91.91165161, 26.02383041], [91.9169693, 26.02146149], [91.91684723, 26.01375961], [91.91565704, 26.01032829], [91.91871643, 26.0072403], [91.91953278, 26.00159073], [91.91957092, 26.0001297], [91.92209625, 25.99953079], [91.92582703, 25.9997406], [91.92681122, 26.0016098], [91.93396759, 26.01466942], [91.94129181, 26.01400185], [91.94631958, 26.01449966], [91.9524231, 26.01781273], [91.95781708, 26.01889038], [91.9781723, 26.0258503], [91.98423004, 26.03054047], [91.98739624, 26.03872108], [91.99106598, 26.04103279], [91.99765015, 26.03884125], [92.0004425, 26.03918076], [92.00337982, 26.03803062], [92.00817871, 26.03944969], [92.01761627, 26.03959084], [92.02218628, 26.03926086], [92.02387238, 26.03843117], [92.02789307, 26.03989983], [92.03475189, 26.03968811], [92.03610229, 26.0394001], [92.03961182, 26.03622055], [92.05018616, 26.033041], [92.05285645, 26.03283119], [92.06321716, 26.03471756], [92.07045746, 26.03784943], [92.07363129, 26.04027939], [92.0788269, 26.04178047], [92.08113098, 26.04362106], [92.0933609, 26.04852104], [92.10888672, 26.04971123], [92.1162262, 26.04655266], [92.12338257, 26.04488945], [92.12702179, 26.04590034], [92.13311768, 26.04589081], [92.13816833, 26.0528183], [92.14377594, 26.05764008], [92.14621735, 26.05855942], [92.14898682, 26.06163025], [92.15052032, 26.06489944], [92.15467834, 26.06805992], [92.16909027, 26.07759094], [92.17830658, 26.07950974], [92.18094635, 26.0761795], [92.17888641, 26.06921005], [92.18044281, 26.06850052], [92.18232727, 26.07034111], [92.18460083, 26.06918907], [92.18834686, 26.06887054], [92.1893692, 26.06688118], [92.20182037, 26.07002068], [92.20826721, 26.06856918], [92.20934296, 26.06918907], [92.2088089, 26.07065964], [92.21042633, 26.07110023], [92.21201324, 26.07097054], [92.21356201, 26.06967926], [92.21611023, 26.0692997], [92.21835327, 26.07015038], [92.22834015, 26.0676403], [92.24117279, 26.06254005], [92.25145721, 26.06436157], [92.26568604, 26.06539917], [92.26864624, 26.0679493], [92.27231598, 26.0666008], [92.27372742, 26.06589127], [92.27368927, 26.06501961], [92.2807312, 26.06918907], [92.28806305, 26.06999016], [92.29014587, 26.07279968], [92.29004669, 26.0737896], [92.29392242, 26.07779121], [92.29598236, 26.07888985], [92.2973175, 26.07914925], [92.29966736, 26.07673073], [92.30158234, 26.0764904], [92.25572205, 26.02893257], [92.22141266, 26.00225067], [92.22168732, 25.99860191], [92.2191925, 26.00078011], [92.21520233, 25.99627113], [92.21100616, 25.99465942], [92.2077179, 25.99174118], [92.2091217, 25.9896698], [92.20738983, 25.98823166], [92.20089722, 25.98560905], [92.19161987, 25.98520279], [92.18097687, 25.97523117], [92.17694092, 25.97310066], [92.17311096, 25.97219849], [92.16739655, 25.96769905], [92.16555023, 25.96443939], [92.16732788, 25.95876122], [92.16532898, 25.95395088], [92.16075897, 25.95152092], [92.15631866, 25.94479942], [92.15609741, 25.94300079], [92.15751648, 25.93927956], [92.16142273, 25.93254089], [92.16017151, 25.92596054], [92.15992737, 25.91518974], [92.16369629, 25.91179085], [92.17431641, 25.90918922], [92.18089294, 25.90859032], [92.18315125, 25.91091919], [92.18364716, 25.91283035], [92.1867218, 25.91580963], [92.19203949, 25.91578293], [92.1971817, 25.91802979], [92.19700623, 25.91366005], [92.19773102, 25.91125107], [92.20059967, 25.90824127], [92.20513916, 25.90871048], [92.20752716, 25.91053009], [92.2175293, 25.90991974], [92.22260284, 25.91131973], [92.22380066, 25.91036034], [92.22547913, 25.90704918], [92.22503662, 25.90162086], [92.22384644, 25.90068817], [92.2182312, 25.90019989], [92.21560669, 25.89384079], [92.21286011, 25.8921299], [92.20641327, 25.89145279], [92.20332336, 25.89009094], [92.19496155, 25.88126945], [92.18694305, 25.87481117], [92.1810379, 25.87162018], [92.17988586, 25.8701725], [92.17910004, 25.86791039], [92.18078613, 25.86321068], [92.18096161, 25.85136032], [92.17830658, 25.84807968], [92.17524719, 25.84654236], [92.17144012, 25.83773041], [92.16934204, 25.8353405], [92.16551971, 25.83304024], [92.16326141, 25.82575035], [92.16308594, 25.82183075], [92.15573883, 25.81659126], [92.15310669, 25.81274986], [92.15368652, 25.79549026], [92.15116882, 25.78745079], [92.15099335, 25.78364944], [92.15479279, 25.77977943], [92.15518188, 25.77864265], [92.15421295, 25.77672958], [92.15410614, 25.77292061], [92.15596771, 25.76454163], [92.15738678, 25.76197052], [92.15824127, 25.75719833], [92.1648407, 25.74475098], [92.16552734, 25.73444939], [92.16423035, 25.72873116], [92.16092682, 25.72625923], [92.15629578, 25.72481155], [92.15371704, 25.72270012], [92.15101624, 25.71936989], [92.14956665, 25.71450806], [92.15106201, 25.71183014], [92.15585327, 25.70914268], [92.15757751, 25.70103836], [92.16104889, 25.69729042], [92.16145325, 25.69598007], [92.16044617, 25.69090271], [92.16435242, 25.68485069], [92.16546631, 25.67840958], [92.1605072, 25.67329025], [92.16069794, 25.67185974], [92.16445923, 25.66931915], [92.16976166, 25.66640091], [92.17095184, 25.66687965], [92.17495728, 25.67021751], [92.18477631, 25.6811409], [92.18791962, 25.68343163], [92.19198608, 25.68632126], [92.19407654, 25.68611908], [92.19692993, 25.68695068], [92.19831085, 25.68635941], [92.2000885, 25.68728828], [92.20156097, 25.68972015], [92.21063995, 25.69592094], [92.22490692, 25.71397018], [92.22899628, 25.71620941], [92.23262787, 25.71511078], [92.23384857, 25.71006966], [92.23475647, 25.70882034], [92.23684692, 25.70839119], [92.24804688, 25.71096039], [92.25357819, 25.71012115], [92.25570679, 25.7107296], [92.260849, 25.7103405], [92.27052307, 25.71093178], [92.28460693, 25.71586037], [92.28797913, 25.71590042], [92.29358673, 25.71730042], [92.30610657, 25.72313118], [92.30825806, 25.72615051], [92.31150055, 25.72607994], [92.3139267, 25.72468185], [92.31768036, 25.72379112], [92.33354187, 25.72523117], [92.33901215, 25.72685051], [92.34805298, 25.73193169], [92.35179901, 25.73487091], [92.36299896, 25.73651123], [92.36830902, 25.74044037], [92.36753845, 25.74238014], [92.37146759, 25.7464695], [92.38510132, 25.75356293], [92.38694763, 25.752491], [92.38433838, 25.75032997], [92.38353729, 25.7474308], [92.38495636, 25.74475098], [92.38696289, 25.74311066], [92.39212799, 25.74259949], [92.39476776, 25.74147987], [92.40479279, 25.74369049], [92.41073608, 25.74312973], [92.41639709, 25.7404995], [92.41246796, 25.73739052], [92.41326141, 25.73396111], [92.41277313, 25.73298073], [92.41697693, 25.72968102], [92.42134857, 25.72945023], [92.43200684, 25.7319603], [92.4331665, 25.73145294], [92.4420166, 25.72085953], [92.43644714, 25.71560097], [92.42962646, 25.71326828], [92.42722321, 25.71041107], [92.43152618, 25.70425034], [92.43334198, 25.69523048], [92.43213654, 25.69100952], [92.43434143, 25.68753052], [92.44046783, 25.68812943], [92.44001007, 25.68922043], [92.44303894, 25.68765259], [92.45128632, 25.68661118], [92.45524597, 25.6842308], [92.45987701, 25.68297005], [92.46544647, 25.68246078], [92.47154999, 25.67494965], [92.47466278, 25.67331123], [92.48134613, 25.66389275], [92.48828888, 25.64999008], [92.49326324, 25.63613129], [92.49790192, 25.62696075], [92.50170898, 25.62293053], [92.51055145, 25.61720085], [92.51727295, 25.62008286], [92.5332489, 25.61594963], [92.54043579, 25.61777115], [92.54453278, 25.61425018], [92.55323792, 25.6138401], [92.55761719, 25.61198807], [92.55861664, 25.60895157], [92.55618286, 25.6058712], [92.55724335, 25.59621048], [92.55632019, 25.59280014], [92.56092834, 25.58273125], [92.56095886, 25.57425117], [92.56468201, 25.56825829], [92.56954193, 25.56446075], [92.57250214, 25.56042099], [92.57610321, 25.55965042], [92.58141327, 25.55977249], [92.58747864, 25.55298805], [92.59346771, 25.55393028], [92.60259247, 25.55738068], [92.60349274, 25.56108284], [92.60871124, 25.56573105], [92.61248779, 25.56550026], [92.62110138, 25.56830978], [92.62610626, 25.5680294], [92.6288681, 25.56949043], [92.63056946, 25.57066917], [92.63323212, 25.57479095], [92.63414764, 25.57888031], [92.64063263, 25.58736992], [92.64833832, 25.59235001], [92.65119171, 25.59272957], [92.65345764, 25.59218025], [92.65760803, 25.58906174], [92.66047668, 25.58506012], [92.66072083, 25.58184052], [92.66065216, 25.57031822], [92.65735626, 25.5633812], [92.64987946, 25.56001091], [92.64496613, 25.54660034], [92.6446991, 25.53744125], [92.63762665, 25.52852821], [92.62760925, 25.52221107], [92.62162781, 25.51575089], [92.60959625, 25.51260948], [92.60559082, 25.50811958], [92.59358215, 25.50308037], [92.58950043, 25.49951935], [92.58104706, 25.49515915], [92.57559204, 25.49043083], [92.56783295, 25.48077011], [92.56655121, 25.47512054], [92.56741333, 25.46747017], [92.56912994, 25.46479034], [92.5714798, 25.46407127], [92.58229065, 25.47289085], [92.58544159, 25.4675808], [92.59369659, 25.47101021], [92.59815979, 25.47165108], [92.60138702, 25.46413994], [92.59976959, 25.45705032], [92.60018921, 25.45387268], [92.60114288, 25.45239067], [92.60450745, 25.4501915], [92.60555267, 25.44836044], [92.60529327, 25.4419117], [92.60775757, 25.43035126], [92.60697174, 25.42718124], [92.60700989, 25.41853905], [92.60909271, 25.41657066], [92.61183929, 25.41612053], [92.61477661, 25.41743088], [92.6178894, 25.42202187], [92.62063599, 25.42371941], [92.62864685, 25.42502975], [92.62931061, 25.42699051], [92.62851715, 25.43061066], [92.62930298, 25.43464088], [92.63265991, 25.43314171], [92.63791656, 25.42881966], [92.63791656, 25.42266083], [92.63922882, 25.4203701], [92.63961029, 25.41963005], [92.64163208, 25.41953278], [92.65054321, 25.43166924], [92.65428162, 25.43534088], [92.65365601, 25.42394066], [92.65688324, 25.41570091], [92.66010284, 25.41036034], [92.66368866, 25.40937042], [92.66703796, 25.41407967], [92.67093658, 25.41671944], [92.67376709, 25.41714096], [92.68004608, 25.40858078], [92.68817139, 25.40442085], [92.69351959, 25.39999008], [92.70037842, 25.38779068], [92.70292664, 25.38661957], [92.70973206, 25.38611984], [92.71289825, 25.38454056], [92.716362, 25.37934113], [92.7181015, 25.37498283], [92.7205658, 25.37490273], [92.72136688, 25.37549019], [92.72543335, 25.38043022], [92.73480988, 25.38249969], [92.73705292, 25.38125038], [92.73610687, 25.37380981], [92.74059296, 25.36678123], [92.74009705, 25.36464119], [92.74060822, 25.36372948], [92.7456665, 25.3611393], [92.74823761, 25.35811043], [92.75009918, 25.35437965], [92.75115967, 25.34847069], [92.75875854, 25.33986092], [92.76056671, 25.33527946], [92.76326752, 25.33559036], [92.76947021, 25.33950806], [92.77245331, 25.33961105], [92.78246307, 25.33428955], [92.78437042, 25.3325386], [92.78801727, 25.31760979], [92.78473663, 25.31152916], [92.78383636, 25.30800056], [92.78691101, 25.30067062], [92.78882599, 25.29154015], [92.79222107, 25.28679848], [92.79222107, 25.28518105], [92.78913879, 25.27852249], [92.78211975, 25.27592087], [92.77947235, 25.27376175], [92.76976013, 25.26893044], [92.77617645, 25.26293945], [92.77670288, 25.2605381], [92.76464844, 25.24934959], [92.77028656, 25.24020004], [92.77223969, 25.2332592], [92.78630829, 25.23140144], [92.79434967, 25.22600937], [92.80309296, 25.22150993], [92.80442047, 25.21932983], [92.80356598, 25.21723938], [92.7984314, 25.21344948], [92.79289246, 25.21235275], [92.78775024, 25.20952988], [92.77957153, 25.20310974], [92.76764679, 25.2047596], [92.76345062, 25.20384979], [92.75889587, 25.20402908], [92.75453949, 25.20537186], [92.7516861, 25.20734978], [92.74713898, 25.20776939], [92.74202728, 25.20309067], [92.7333374, 25.20322037], [92.72416687, 25.19919968], [92.71621704, 25.19415855], [92.70461273, 25.19052124], [92.69393921, 25.18135071], [92.68762207, 25.18231964], [92.68284607, 25.18204117], [92.6794281, 25.18309021], [92.6770401, 25.18218994], [92.67224121, 25.17815971], [92.66690826, 25.17706108], [92.66433716, 25.17535973], [92.66297913, 25.1729908], [92.66081238, 25.16225243], [92.65953827, 25.15912056], [92.65571594, 25.15413094], [92.65120697, 25.15240097], [92.64826965, 25.15265274], [92.6440506, 25.15117073], [92.63800812, 25.1452198], [92.6324234, 25.13755989], [92.63079834, 25.13183975], [92.62996674, 25.12503052], [92.62470245, 25.11869049], [92.62164307, 25.11770058], [92.61003113, 25.12409973], [92.60314941, 25.12499046], [92.59842682, 25.12471008], [92.59443665, 25.12829018], [92.58168793, 25.13187027], [92.5790329, 25.13200951], [92.56803894, 25.13009071], [92.56549835, 25.1312809], [92.55784607, 25.12997055], [92.55316925, 25.1307106], [92.54312897, 25.1350193], [92.53993988, 25.13727951], [92.53562927, 25.13441277], [92.53018951, 25.13682175], [92.52746582, 25.13994026], [92.52466583, 25.14002991], [92.52522278, 25.12557983], [92.53024292, 25.1218605], [92.53132629, 25.11990166], [92.53305817, 25.11214828], [92.54081726, 25.10412979], [92.54294586, 25.09959984], [92.53804779, 25.09931183], [92.53201294, 25.10396004], [92.52651215, 25.10585022], [92.50978088, 25.10547066], [92.49910736, 25.10814857], [92.48429871, 25.10806084], [92.48031616, 25.10040855], [92.47975922, 25.09574127], [92.48017883, 25.08584023], [92.47654724, 25.07825279], [92.474617, 25.07080078], [92.47091675, 25.06689072], [92.46750641, 25.06137085], [92.46598816, 25.05715752], [92.46366882, 25.0555706], [92.46203613, 25.05583], [92.45983887, 25.0546608], [92.46015167, 25.04959106], [92.46286011, 25.05014992], [92.46466064, 25.04722977], [92.46325684, 25.03712845], [92.45976257, 25.03518105], [92.45680237, 25.03503036], [92.45420837, 25.03660965], [92.45101929, 25.04095078], [92.4465332, 25.04204178], [92.44178009, 25.03985023], [92.43788147, 25.03375244], [92.43192291, 25.03290749], [92.42590332, 25.0318203], [92.4262619, 25.03164101], [92.42782593, 25.03157043], [92.4306488, 25.03226089], [92.43284607, 25.03102112], [92.43325043, 25.02808952], [92.43219757, 25.02507973], [92.43099976, 25.0216198], [92.43105316, 25.01581955], [92.43036652, 25.01280975], [92.42945099, 25.00969124], [92.4258728, 25.00319099], [92.42363739, 24.99609947], [92.42446899, 24.98257065], [92.42948151, 24.97988129], [92.42855072, 24.97290993], [92.42849731, 24.97257996], [92.43161011, 24.97066116], [92.43515778, 24.96637917], [92.44003296, 24.96680069], [92.44590759, 24.96696281], [92.44904327, 24.97154808], [92.44940948, 24.97208977], [92.45445251, 24.97318077], [92.4605484, 24.97615051], [92.4640274, 24.97077942], [92.46711731, 24.96858025], [92.47103119, 24.96409988], [92.47371674, 24.95709991], [92.47158051, 24.9559803], [92.46470642, 24.95478058], [92.46328735, 24.95591736], [92.46361542, 24.95598793], [92.46416473, 24.95616913], [92.46488953, 24.95653915], [92.4657135, 24.95697021], [92.46607971, 24.95719337], [92.46646881, 24.95757866], [92.46718597, 24.95828438], [92.46768188, 24.95890999], [92.46796417, 24.9593544], [92.46833038, 24.96022606], [92.46839142, 24.96099281], [92.46842957, 24.96180725], [92.46842957, 24.96230125], [92.46831512, 24.96273232], [92.46777344, 24.96351051], [92.46661377, 24.96440125], [92.46561432, 24.96507454], [92.46498871, 24.96560097], [92.46382904, 24.96648788], [92.46258545, 24.96781731], [92.46178436, 24.96884918], [92.460289, 24.96983147], [92.45940399, 24.97033119], [92.45875549, 24.97052193], [92.45801544, 24.97062111], [92.45787811, 24.97063446], [92.45738983, 24.97068024], [92.45608521, 24.97016335], [92.45520782, 24.96963501], [92.45500183, 24.96945381], [92.45413971, 24.96870422], [92.45276642, 24.96755028], [92.45158386, 24.96673393], [92.44959259, 24.96604538], [92.44778442, 24.96584892], [92.44618988, 24.96575737], [92.44350433, 24.96627998], [92.44276428, 24.96639633], [92.44199371, 24.96632767], [92.4407196, 24.96639442], [92.44017792, 24.96640015], [92.43971252, 24.96634293], [92.43897247, 24.96634293], [92.43863678, 24.96638489], [92.43733978, 24.96626854], [92.43585968, 24.96608353], [92.43041992, 24.96556091], [92.42863464, 24.96540451], [92.42765808, 24.96540642], [92.42673492, 24.96523094], [92.42597961, 24.96509743], [92.42553711, 24.96508408], [92.4249649, 24.96503258], [92.42446899, 24.96497536], [92.42360687, 24.96494102], [92.42186737, 24.96559525], [92.42068481, 24.96608734], [92.41943359, 24.96756744], [92.41952515, 24.96957588], [92.42008209, 24.97143745], [92.42042542, 24.97277832], [92.42072296, 24.97448158], [92.42095184, 24.97575378], [92.42126465, 24.97771835], [92.4214325, 24.97871208], [92.42163086, 24.97998047], [92.42176056, 24.98139], [92.42189026, 24.9829998], [92.42193604, 24.9840889], [92.42195892, 24.98516273], [92.42201996, 24.98624039], [92.42211151, 24.98732376], [92.42205048, 24.98848915], [92.42196655, 24.98873711], [92.42160797, 24.98911095], [92.4214859, 24.98922729], [92.42132568, 24.98994255], [92.42115784, 24.99017143], [92.42087555, 24.99031067], [92.4203949, 24.99048996], [92.41977692, 24.9905262], [92.41938782, 24.99053192], [92.41886139, 24.99048805], [92.41832733, 24.99041367], [92.41790009, 24.99026871], [92.41716766, 24.99015617], [92.41627502, 24.99005127], [92.41516876, 24.98978996], [92.4149704, 24.98974419], [92.41429901, 24.98978233], [92.41433716, 24.99031448], [92.41647339, 24.9919281], [92.41671753, 24.9924984], [92.41708374, 24.99329758], [92.41738892, 24.99396324], [92.41753387, 24.99428558], [92.418396, 24.99625969], [92.41877747, 24.99711418], [92.41938019, 24.99843407], [92.42056274, 25.00104523], [92.42173767, 25.00362015], [92.42238617, 25.00492096], [92.42279053, 25.00605965], [92.42325592, 25.00749779], [92.42372894, 25.00907135], [92.4240799, 25.01024818], [92.42449951, 25.01199341], [92.42463684, 25.01260948], [92.4246521, 25.0126915], [92.42467499, 25.01281738], [92.42480469, 25.01340675], [92.42450714, 25.01400757], [92.42433167, 25.01434135], [92.42430878, 25.01531601], [92.42429352, 25.01608658], [92.42427826, 25.01677513], [92.42424774, 25.0178299], [92.42421722, 25.01894951], [92.42420197, 25.01950455], [92.42431641, 25.01958466], [92.42440796, 25.01962471], [92.42449188, 25.01950073], [92.42454529, 25.01940536], [92.42460632, 25.01936722], [92.42469788, 25.01938629], [92.42485809, 25.01947212], [92.4249649, 25.01952744], [92.42525482, 25.01959419], [92.42532349, 25.01962662], [92.42538452, 25.01970863], [92.42554474, 25.0197506], [92.4257431, 25.01980019], [92.4258728, 25.02019119], [92.42586517, 25.02058029], [92.42584991, 25.02132797], [92.42584991, 25.0219574], [92.42584229, 25.02272034], [92.42583466, 25.02332687], [92.42582703, 25.02443314], [92.42581177, 25.02544212], [92.42578888, 25.02653503], [92.42577362, 25.02759933], [92.42576599, 25.02879524], [92.42562866, 25.02901077], [92.42521667, 25.02965927], [92.42420959, 25.02994728], [92.42382813, 25.03014183], [92.4236908, 25.03013992], [92.42337036, 25.02986336], [92.42320251, 25.0296669], [92.42306519, 25.02932358], [92.42274475, 25.02884102], [92.42218781, 25.02867889], [92.42201996, 25.02833557], [92.42140961, 25.02793312], [92.42116547, 25.02802658], [92.42082214, 25.02815437], [92.42030334, 25.0284481], [92.41911316, 25.02904701], [92.41899109, 25.02969933], [92.41821289, 25.03002167], [92.41740417, 25.03013229], [92.41692352, 25.03040695], [92.41629028, 25.03034592], [92.41598511, 25.03016472], [92.41576385, 25.03003693], [92.41545868, 25.029953], [92.41481781, 25.02977371], [92.41371155, 25.0291996], [92.41307068, 25.02895737], [92.41301727, 25.02890778], [92.41285706, 25.02876472], [92.41259766, 25.02883339], [92.41236115, 25.02889824], [92.41204071, 25.02913475], [92.41118622, 25.02956009], [92.41101837, 25.02971077], [92.41053009, 25.02994156], [92.41028595, 25.03036308], [92.40995026, 25.03060341], [92.40959167, 25.03069878], [92.40905762, 25.03063393], [92.40850067, 25.03064156], [92.40814209, 25.03107452], [92.40782928, 25.03117943], [92.407547, 25.03139687], [92.40717316, 25.03165436], [92.40657806, 25.03197098], [92.40615845, 25.03203011], [92.40542603, 25.03241158], [92.40504456, 25.03274727], [92.4041748, 25.03250885], [92.40394592, 25.03242874], [92.40283203, 25.03203583], [92.40251923, 25.03217125], [92.40241241, 25.03215408], [92.4023056, 25.03213501], [92.40216827, 25.03222466], [92.40225983, 25.03203583], [92.40218353, 25.03193855], [92.40214539, 25.03203583], [92.40190887, 25.03214836], [92.40161896, 25.0322361], [92.40155792, 25.03232765], [92.40111542, 25.0324955], [92.40053558, 25.0329895], [92.40048218, 25.0330925], [92.40065765, 25.03385925], [92.40060425, 25.03399849], [92.40060425, 25.03415489], [92.40039063, 25.03421211], [92.40033722, 25.03414536], [92.3996582, 25.03420067], [92.39936829, 25.03408432], [92.39926147, 25.03403282], [92.39916992, 25.03360176], [92.39912415, 25.0333786], [92.3990097, 25.03338623], [92.39898682, 25.03292847], [92.39872742, 25.03303528], [92.39852905, 25.03311539], [92.39793396, 25.03386879], [92.39709473, 25.0346489], [92.39630127, 25.03509903], [92.39576721, 25.03557205], [92.39461517, 25.03676414], [92.39411163, 25.03730392], [92.39334869, 25.03794098], [92.39304352, 25.0391407], [92.39272308, 25.03990936], [92.39110565, 25.03996468], [92.38921356, 25.03995705], [92.38825226, 25.03985786], [92.38814545, 25.0398674], [92.3881073, 25.03998947], [92.38787079, 25.04009819], [92.38768005, 25.04010201], [92.38639069, 25.04061317], [92.3861084, 25.0405426], [92.38582611, 25.04068184], [92.38549805, 25.04060745], [92.3853302, 25.04066467], [92.38513184, 25.04084778], [92.38483429, 25.04090691], [92.38469696, 25.04099464], [92.38470459, 25.04111862], [92.38481903, 25.04128456], [92.3849411, 25.04158974], [92.3848877, 25.04173851], [92.38481903, 25.04177856], [92.3846817, 25.04183197], [92.38457489, 25.0419445], [92.38456726, 25.04214478], [92.38412476, 25.04221344], [92.38397217, 25.04226303], [92.3838501, 25.04241753], [92.3837204, 25.0424633], [92.38363647, 25.04229546], [92.38356018, 25.04221344], [92.38356018, 25.04196167], [92.38365936, 25.04179382], [92.38388062, 25.04190254], [92.38417053, 25.04152489], [92.38433075, 25.04141045], [92.38458252, 25.04146194], [92.384552, 25.04132271], [92.38442993, 25.04116631], [92.38424683, 25.04088974], [92.38427734, 25.04055595], [92.38425446, 25.04046631], [92.3841095, 25.0403595], [92.38375854, 25.04018211], [92.3837204, 25.04007721], [92.38372803, 25.03973579], [92.38346863, 25.03915215], [92.38336182, 25.03883553], [92.38327026, 25.03873634], [92.38317108, 25.03861809], [92.38302612, 25.03863716], [92.38295746, 25.03892708], [92.38287354, 25.03896713], [92.38273621, 25.03903198], [92.38267517, 25.03930283], [92.38233948, 25.03934288], [92.38280487, 25.04008102], [92.38285828, 25.04034805], [92.38263702, 25.04050636], [92.38250732, 25.04058266], [92.38240814, 25.04057693], [92.38233185, 25.04044342], [92.38225555, 25.04000664], [92.38200378, 25.03985596], [92.38208008, 25.03968048], [92.38202667, 25.03960991], [92.38188171, 25.03941154], [92.38175201, 25.03934479], [92.38167572, 25.0391674], [92.38152313, 25.03918648], [92.38130188, 25.03921127], [92.3812027, 25.03926849], [92.38108826, 25.03943825], [92.381073, 25.03961563], [92.38131714, 25.03994751], [92.38124847, 25.0400753], [92.38118744, 25.04012108], [92.38100433, 25.04019165], [92.3809967, 25.04033279], [92.38106537, 25.04051971], [92.38098145, 25.04055786], [92.38097382, 25.04065514], [92.38072968, 25.04060364], [92.38071442, 25.04077911], [92.38057709, 25.04091835], [92.38061523, 25.04144859], [92.38053894, 25.04152107], [92.38026428, 25.04125977], [92.38013458, 25.0410347], [92.38007355, 25.04092407], [92.38015747, 25.04084587], [92.38085175, 25.04019928], [92.38097382, 25.0400219], [92.38095093, 25.03985977], [92.38084412, 25.03975868], [92.38072968, 25.03964615], [92.38063812, 25.039608], [92.38031769, 25.03962708], [92.37996674, 25.03962898], [92.37942505, 25.0396328], [92.37928772, 25.03967667], [92.37902832, 25.04014778], [92.37887573, 25.04019547], [92.37844086, 25.04030418], [92.37830353, 25.04034996], [92.37807465, 25.04066277], [92.37753296, 25.04102707], [92.37738037, 25.04118538], [92.37742615, 25.04162025], [92.37714386, 25.042099], [92.37690735, 25.04229736], [92.37683105, 25.04246902], [92.37684631, 25.04258537], [92.37695313, 25.04280663], [92.37680054, 25.04293251], [92.37609863, 25.04272652], [92.37585449, 25.04265594], [92.37551117, 25.0427227], [92.37537384, 25.04275322], [92.37498474, 25.0427742], [92.37467957, 25.04257584], [92.37441254, 25.04249573], [92.37412262, 25.04254913], [92.37400818, 25.04261589], [92.37368774, 25.04280281], [92.37377167, 25.04320335], [92.37397766, 25.04339981], [92.37411499, 25.04343414], [92.37419891, 25.04324913], [92.37458801, 25.04312325], [92.37505341, 25.04335022], [92.37502289, 25.04363251], [92.37470245, 25.04371643], [92.37462616, 25.0436039], [92.37441254, 25.04369354], [92.37425232, 25.0436039], [92.37409973, 25.04359436], [92.3735199, 25.0437851], [92.37351227, 25.04366493], [92.37349701, 25.04345512], [92.37319183, 25.04327583], [92.37298584, 25.04302979], [92.37284088, 25.04311371], [92.37281036, 25.04337311], [92.3727417, 25.04350662], [92.37265778, 25.04359436], [92.37252808, 25.04360008], [92.37245178, 25.04350471], [92.37252808, 25.04314423], [92.37255859, 25.04298401], [92.37284088, 25.04266167], [92.3727951, 25.04252052], [92.3724823, 25.04236794], [92.37207794, 25.04238701], [92.37184906, 25.04267883], [92.3716507, 25.0423851], [92.37143707, 25.04231834], [92.37119293, 25.04219246], [92.37103271, 25.04226112], [92.3710022, 25.04239082], [92.37116241, 25.04249763], [92.37108612, 25.0426178], [92.37088013, 25.04252434], [92.37076569, 25.04283905], [92.37065887, 25.04273224], [92.37050629, 25.04210091], [92.37050629, 25.04199982], [92.3707428, 25.0418396], [92.37084961, 25.041605], [92.37062836, 25.04150391], [92.37039948, 25.04161644], [92.37015533, 25.04173088], [92.36981964, 25.04189301], [92.3697052, 25.0417099], [92.36960602, 25.0415535], [92.36958313, 25.04146194], [92.36978912, 25.04133987], [92.3699646, 25.04122543], [92.36977386, 25.04107094], [92.36962128, 25.04100037], [92.3693924, 25.04117966], [92.36902618, 25.04146767], [92.36831665, 25.04202271], [92.36771393, 25.04251289], [92.36816406, 25.04305267], [92.36834717, 25.04319191], [92.36872864, 25.04348183], [92.36888123, 25.04368019], [92.36896515, 25.04387093], [92.36882019, 25.04395676], [92.36894226, 25.04416466], [92.36897278, 25.04427147], [92.368927, 25.04443932], [92.36870575, 25.04474831], [92.36858368, 25.0447731], [92.3684845, 25.0453186], [92.36857605, 25.04559898], [92.3685379, 25.04571724], [92.36824799, 25.04605865], [92.36830902, 25.04634666], [92.36811829, 25.04636383], [92.36794281, 25.04631615], [92.36695862, 25.04733658], [92.36670685, 25.0477562], [92.36657715, 25.04788208], [92.36636353, 25.04803276], [92.36598206, 25.04822731], [92.36565399, 25.04850006], [92.3651123, 25.04867554], [92.36486816, 25.04887772], [92.36481476, 25.04910469], [92.36449432, 25.04916], [92.36437988, 25.04918861], [92.3640213, 25.04937935], [92.36375427, 25.04950142], [92.36357117, 25.04958534], [92.36339569, 25.0496273], [92.36323547, 25.04966736], [92.36316681, 25.04973412], [92.36304474, 25.04995346], [92.36290741, 25.05002213], [92.36260986, 25.04994392], [92.36224365, 25.04994774], [92.36218262, 25.04986763], [92.36211395, 25.04970551], [92.3616333, 25.048666], [92.36167145, 25.04839325], [92.3616333, 25.04813957], [92.36157227, 25.04789162], [92.36148071, 25.04766464], [92.36115265, 25.04706001], [92.36079407, 25.04686928], [92.36064148, 25.046875], [92.36024475, 25.04688835], [92.35999298, 25.04689026], [92.35960388, 25.04711914], [92.35907745, 25.04718208], [92.35869598, 25.04724884], [92.35836792, 25.04735184], [92.35829926, 25.04752159], [92.358284, 25.04792213], [92.35824585, 25.04828072], [92.35813904, 25.04857635], [92.35808563, 25.048666], [92.35786438, 25.04879951], [92.35778809, 25.04889679], [92.35769653, 25.04916191], [92.35766602, 25.04924774], [92.35779572, 25.04939079], [92.35786438, 25.04941559], [92.35790253, 25.04927444], [92.35797882, 25.04924011], [92.35822296, 25.04938126], [92.35832977, 25.04935074], [92.3585434, 25.04929161], [92.35873413, 25.04931831], [92.35873413, 25.0494194], [92.35861206, 25.04995728], [92.35860443, 25.05003548], [92.35807037, 25.05015564], [92.35801697, 25.05025101], [92.35704803, 25.05021858], [92.35692596, 25.0502491], [92.35652924, 25.05013847], [92.35653687, 25.04977608], [92.35654449, 25.04944229], [92.35653687, 25.04925156], [92.35633087, 25.04900551], [92.35623932, 25.04881477], [92.35627747, 25.04856682], [92.35636139, 25.04813957], [92.35639191, 25.04791832], [92.35662079, 25.04790306], [92.35662842, 25.04756546], [92.35617828, 25.04754829], [92.35549927, 25.04757118], [92.35515594, 25.04781151], [92.35513306, 25.04806709], [92.35440826, 25.04789352], [92.35430908, 25.04795456], [92.35417938, 25.0486145], [92.35448456, 25.04917336], [92.35415649, 25.0495739], [92.3538208, 25.04931259], [92.35368347, 25.04920769], [92.35324097, 25.04939079], [92.35292053, 25.04938126], [92.35251617, 25.04932785], [92.35202026, 25.04896164], [92.35172272, 25.04868317], [92.35118866, 25.04852104], [92.35114288, 25.04858208], [92.35109711, 25.0486393], [92.35095978, 25.04855347], [92.35085297, 25.04854012], [92.35070801, 25.0486908], [92.35036469, 25.04868889], [92.35033417, 25.04876137], [92.35041046, 25.0493412], [92.35034943, 25.04956245], [92.35018158, 25.04968643], [92.34990692, 25.04953766], [92.34947968, 25.04950142], [92.34931183, 25.04926682], [92.34922791, 25.04880905], [92.34925842, 25.0486908], [92.34864044, 25.04840469], [92.34853363, 25.04840469], [92.34824371, 25.04840469], [92.34809875, 25.04836273], [92.34798431, 25.04821587], [92.34775543, 25.04791069], [92.34729767, 25.04779625], [92.34645081, 25.04816818], [92.34615326, 25.04870987], [92.34601593, 25.04874039], [92.34597015, 25.0491848], [92.34547424, 25.04916763], [92.34537506, 25.04896164], [92.34528351, 25.04876328], [92.34518433, 25.04881287], [92.34506989, 25.04878044], [92.34492493, 25.04882431], [92.34484863, 25.04880333], [92.34460449, 25.04876518], [92.34442902, 25.04869652], [92.34396362, 25.04865074], [92.34375763, 25.04866791], [92.34368134, 25.04867363], [92.34333801, 25.04877472], [92.3428421, 25.04911232], [92.34267426, 25.04922867], [92.34207153, 25.04896545], [92.34184265, 25.04892159], [92.3418045, 25.04876518], [92.34168243, 25.04866028], [92.34140778, 25.04866409], [92.34137726, 25.04887581], [92.34142303, 25.04894066], [92.34130096, 25.04920578], [92.34124756, 25.04931641], [92.34040833, 25.04967117], [92.3394165, 25.05009842], [92.3392334, 25.05047607], [92.33940125, 25.05062866], [92.33978271, 25.05097961], [92.34022522, 25.05142212], [92.34052277, 25.05187607], [92.34083557, 25.05236244], [92.34114075, 25.05264854], [92.34123993, 25.05285645], [92.3414917, 25.05333519], [92.34181976, 25.05374527], [92.34230042, 25.05434799], [92.34197235, 25.05417824], [92.34159088, 25.05379486], [92.34119415, 25.05308151], [92.34111023, 25.052845], [92.34091949, 25.05259132], [92.34052277, 25.05220604], [92.34025574, 25.05172348], [92.3398819, 25.05130196], [92.33911133, 25.05058289], [92.33895874, 25.0507412], [92.33809662, 25.05163956], [92.33829498, 25.05171585], [92.33846283, 25.05184555], [92.33864594, 25.05204964], [92.33907318, 25.05255127], [92.34016418, 25.05358696], [92.34047699, 25.05379486], [92.3405838, 25.05386543], [92.34094238, 25.05410194], [92.341362, 25.0543499], [92.3421936, 25.05471992], [92.34255981, 25.05485916], [92.34327698, 25.055233], [92.34382629, 25.05545616], [92.34414673, 25.05564499], [92.34436035, 25.05582428], [92.34449768, 25.05645752], [92.3447113, 25.05778503], [92.34553528, 25.05811882], [92.34552765, 25.05831528], [92.34601593, 25.05830956], [92.34651947, 25.05817032], [92.34679413, 25.05809402], [92.34696198, 25.05818939], [92.34736633, 25.05849075], [92.34773254, 25.05888748], [92.34791565, 25.05908585], [92.3483429, 25.05986023], [92.34887695, 25.06097031], [92.34898376, 25.06125641], [92.34902191, 25.06160736], [92.34902954, 25.0620842], [92.34902191, 25.06233788], [92.34899139, 25.06346893], [92.34912109, 25.06399155], [92.34929657, 25.06461143], [92.34931183, 25.06477928], [92.34918213, 25.06517792], [92.34899902, 25.06559181], [92.34883118, 25.06602287], [92.34857941, 25.06645584], [92.348526, 25.06657791], [92.34832764, 25.0670681], [92.34802246, 25.06716537], [92.34777832, 25.06724739], [92.34767914, 25.06826401], [92.34802246, 25.06854248], [92.34841156, 25.06885529], [92.3480072, 25.0695076], [92.34766388, 25.07007027], [92.3477478, 25.07074738], [92.3477478, 25.07134438], [92.34804535, 25.07201195], [92.34822845, 25.0724411], [92.34848022, 25.07277298], [92.34849548, 25.07304001], [92.34841919, 25.0731163], [92.34848022, 25.07363701], [92.34777069, 25.07413292], [92.34721375, 25.07406616], [92.34662628, 25.0739975], [92.34618378, 25.07383347], [92.34547424, 25.07392311], [92.34526062, 25.07405853], [92.34352875, 25.07516479], [92.34204865, 25.07559395], [92.34177399, 25.07561302], [92.34086609, 25.07567787], [92.3406601, 25.07568359], [92.34010315, 25.07569885], [92.338974, 25.07607651], [92.33834076, 25.07583618], [92.33812714, 25.07585716], [92.3380661, 25.07593727], [92.33750153, 25.07665443], [92.33659363, 25.07714081], [92.33618164, 25.07719994], [92.33575439, 25.07726479], [92.33534241, 25.07732391], [92.33446503, 25.07861328], [92.33438873, 25.07846642], [92.33422089, 25.07815933], [92.33388519, 25.07813644], [92.33364868, 25.07812119], [92.33339691, 25.07810402], [92.33330536, 25.07824516], [92.3328476, 25.07900047], [92.3318634, 25.07916451], [92.33176422, 25.07916069], [92.33156586, 25.07915497], [92.33146667, 25.07913399], [92.33119965, 25.07904816], [92.33024597, 25.07906914], [92.33020782, 25.0788765], [92.32956696, 25.07805061], [92.32919312, 25.07780075], [92.32880402, 25.07756996], [92.32805634, 25.07759285], [92.32746887, 25.0778389], [92.32707977, 25.07800293], [92.32681274, 25.07785606], [92.32555389, 25.07822418], [92.32543182, 25.07843971], [92.32454681, 25.07720947], [92.32250214, 25.07442093], [92.31961823, 25.07464027], [92.31951904, 25.07440758], [92.31910706, 25.07439041], [92.31890106, 25.07438278], [92.31886292, 25.07420921], [92.31877899, 25.07382202], [92.31891632, 25.07322693], [92.31871796, 25.07317352], [92.31854248, 25.07312965], [92.31851196, 25.07283211], [92.31877136, 25.07283974], [92.31877899, 25.0726223], [92.31891632, 25.07264328], [92.3190155, 25.07265854], [92.31909943, 25.07261848], [92.31928253, 25.07243347], [92.31904602, 25.07187653], [92.31930542, 25.07139397], [92.31897736, 25.07105446], [92.31898499, 25.07086945], [92.3192215, 25.07044601], [92.31907654, 25.07038879], [92.31902313, 25.07003212], [92.3187561, 25.07004929], [92.318367, 25.07012558], [92.31832123, 25.07005119], [92.31817627, 25.06979942], [92.31807709, 25.06981277], [92.31790924, 25.07008743], [92.31783295, 25.07021332], [92.31764984, 25.07027817], [92.31759644, 25.07063675], [92.31744385, 25.07082748], [92.31735229, 25.07094193], [92.31684113, 25.07068253], [92.31661224, 25.07102776], [92.31656647, 25.07118607], [92.31620789, 25.07142067], [92.31622314, 25.07156563], [92.31614685, 25.07165337], [92.31604004, 25.07167053], [92.31599426, 25.07161331], [92.31594086, 25.07143784], [92.31581116, 25.07138824], [92.31549072, 25.07152176], [92.31495667, 25.07148552], [92.31486511, 25.07147789], [92.31490326, 25.07156944], [92.31477356, 25.07169533], [92.31421661, 25.07207108], [92.31403351, 25.07209396], [92.31368256, 25.07201767], [92.31356812, 25.07199097], [92.3131485, 25.07135963], [92.31269836, 25.07087326], [92.31220245, 25.07044411], [92.31182098, 25.07000732], [92.31185913, 25.06945992], [92.31157684, 25.06932068], [92.31139374, 25.06938362], [92.3111496, 25.06934929], [92.31091309, 25.06937599], [92.31072235, 25.06947708], [92.31064606, 25.06949806], [92.31056976, 25.0694561], [92.31058502, 25.06932259], [92.31059265, 25.06923485], [92.31054688, 25.06916809], [92.31036377, 25.06933403], [92.31032562, 25.06940269], [92.3102951, 25.06954956], [92.31022644, 25.06968689], [92.31015015, 25.06969452], [92.30988312, 25.06970596], [92.30988312, 25.06952286], [92.30970001, 25.06972504], [92.30954742, 25.06969643], [92.30937195, 25.06958199], [92.30927277, 25.06970596], [92.30912018, 25.06989098], [92.30896759, 25.06995964], [92.3088913, 25.06995392], [92.3087616, 25.06974602], [92.30867004, 25.06970787], [92.30857849, 25.0697403], [92.30836487, 25.06991959], [92.30827332, 25.07001114], [92.30774689, 25.07015419], [92.30757141, 25.07013321], [92.30731201, 25.070158], [92.30701447, 25.07022285], [92.30699921, 25.0704422], [92.3068924, 25.07048035], [92.30690765, 25.07058716], [92.30683136, 25.07064819], [92.30671692, 25.07058525], [92.30651855, 25.07050705], [92.30645752, 25.07037926], [92.30619049, 25.07042885], [92.30612946, 25.07053566], [92.30592346, 25.07057953], [92.30579376, 25.07065773], [92.30593109, 25.07090569], [92.30631256, 25.07130432], [92.30638885, 25.07143593], [92.30661011, 25.07146835], [92.30661774, 25.07156181], [92.30661774, 25.07167244], [92.30678558, 25.07164764], [92.30685425, 25.07172966], [92.30639648, 25.07202148], [92.30641174, 25.07209778], [92.30630493, 25.07211494], [92.30619812, 25.0721035], [92.30612183, 25.07205009], [92.30634308, 25.07177162], [92.30638123, 25.07162857], [92.30612183, 25.0714016], [92.30586243, 25.07127571], [92.30548859, 25.07100487], [92.30539703, 25.07097435], [92.30529022, 25.07087135], [92.30499268, 25.07087517], [92.30497742, 25.07061768], [92.30487823, 25.07065392], [92.30445099, 25.07081413], [92.3035965, 25.07108688], [92.30317688, 25.07125092], [92.30271912, 25.07123756], [92.3022995, 25.0712986], [92.30171967, 25.07130241], [92.30059052, 25.0717659], [92.30051422, 25.07195473], [92.30010986, 25.07199478], [92.29988098, 25.07193947], [92.29972839, 25.07190132], [92.29951477, 25.07180214], [92.29925537, 25.07190895], [92.29890442, 25.07198906], [92.29841614, 25.07220459], [92.29823303, 25.07229614], [92.29733276, 25.07274246], [92.29614258, 25.07331276], [92.29561615, 25.07339859], [92.2952652, 25.0734539], [92.29388428, 25.07395554], [92.29221344, 25.07450676], [92.29205322, 25.07455826], [92.29199219, 25.07466507], [92.29187775, 25.07473946], [92.29149628, 25.07485771], [92.29144287, 25.07478523], [92.29101563, 25.07499695], [92.29091644, 25.0751152], [92.29079437, 25.07519913], [92.29039764, 25.07560349], [92.29019928, 25.07564163], [92.28978729, 25.07583427], [92.2896347, 25.07598495], [92.28947449, 25.07595253], [92.28939819, 25.07596779], [92.28905487, 25.07613373], [92.28895569, 25.07612801], [92.28883362, 25.07606697], [92.28878784, 25.07597351], [92.28890228, 25.07572746], [92.28884888, 25.0756321], [92.28876495, 25.07559776], [92.28852081, 25.07593155], [92.28840637, 25.07595062], [92.28824615, 25.07570648], [92.28794861, 25.07575607], [92.28780365, 25.07574654], [92.28768921, 25.07591629], [92.2877121, 25.07600784], [92.28755188, 25.07608986], [92.28765869, 25.07619476], [92.28775024, 25.07668114], [92.28765869, 25.07675934], [92.28744507, 25.07673073], [92.28696442, 25.07695389], [92.28593445, 25.07715797], [92.28523254, 25.07732773], [92.28475189, 25.07701302], [92.2844162, 25.07683945], [92.28429413, 25.07679749], [92.28374481, 25.07662201], [92.28331757, 25.07702255], [92.28252411, 25.07739258], [92.28171539, 25.07765198], [92.28145599, 25.07773781], [92.28022766, 25.07812691], [92.28001404, 25.07819366], [92.2795639, 25.07805634], [92.27922058, 25.07795143], [92.27911377, 25.07791328], [92.27885437, 25.07787132], [92.2786026, 25.07785988], [92.27854156, 25.07795715], [92.27838135, 25.07768822], [92.27819061, 25.07767487], [92.27796936, 25.07810974], [92.27771759, 25.07844925], [92.27771759, 25.07873917], [92.27754974, 25.07896805], [92.27701569, 25.07955742], [92.27692413, 25.07938004], [92.27680969, 25.07893562], [92.2766571, 25.07891273], [92.27646637, 25.07884789], [92.27626801, 25.07897377], [92.27587891, 25.07921791], [92.27576447, 25.0794735], [92.27545929, 25.07933044], [92.27537537, 25.07933998], [92.27516174, 25.07951927], [92.275177, 25.07964134], [92.27519989, 25.07987595], [92.27497864, 25.08004761], [92.27458954, 25.08025551], [92.27436829, 25.0803566], [92.27336884, 25.08081818], [92.27326202, 25.08066368], [92.27310181, 25.08055496], [92.27288055, 25.0807476], [92.27255249, 25.08092117], [92.27246857, 25.08096504], [92.27207184, 25.08099747], [92.27185822, 25.08124924], [92.271492, 25.08101082], [92.27133179, 25.08089066], [92.27098083, 25.0808773], [92.27042389, 25.0811367], [92.27028656, 25.08124352], [92.27013397, 25.08137131], [92.26969147, 25.08175278], [92.26959229, 25.08183289], [92.26906586, 25.08202744], [92.26908112, 25.0825386], [92.26836395, 25.08269501], [92.26805115, 25.08288383], [92.26750946, 25.08302307], [92.26696014, 25.08324814], [92.26667023, 25.08333588], [92.26622009, 25.08343506], [92.26563263, 25.08347511], [92.26527405, 25.08345413], [92.26493835, 25.08337402], [92.26473999, 25.08356476], [92.26409149, 25.08340263], [92.26326752, 25.08361435], [92.26262665, 25.08369064], [92.26152039, 25.08390999], [92.26126099, 25.0839653], [92.26103973, 25.08383751], [92.26082611, 25.08379173], [92.26089478, 25.08400154], [92.26083374, 25.08430099], [92.26041412, 25.08436203], [92.26004028, 25.08434105], [92.25978851, 25.08439636], [92.259552, 25.0845089], [92.25938416, 25.08462715], [92.25917053, 25.0846386], [92.25912476, 25.08456993], [92.25854492, 25.08476448], [92.25827789, 25.08475685], [92.25754547, 25.08519554], [92.25713348, 25.08513832], [92.2565918, 25.08512688], [92.25643158, 25.08515358], [92.25595856, 25.08528709], [92.25549316, 25.08534241], [92.25521851, 25.08537674], [92.25481415, 25.08555412], [92.25478363, 25.08563232], [92.25430298, 25.08686829], [92.25413513, 25.08683586], [92.25396729, 25.08684158], [92.25357056, 25.08685493], [92.25340271, 25.08687782], [92.25281525, 25.08704376], [92.25254059, 25.08730316], [92.25226593, 25.08734894], [92.25206757, 25.08739281], [92.25153351, 25.08750725], [92.25102234, 25.08767128], [92.25029755, 25.08790207], [92.25021362, 25.0879631], [92.24983978, 25.08823395], [92.24914551, 25.08851624], [92.24897003, 25.08860016], [92.24884033, 25.0886116], [92.24872589, 25.08871841], [92.24849701, 25.08883095], [92.24832916, 25.0889492], [92.24812317, 25.08899498], [92.24801636, 25.08908272], [92.24776459, 25.08919716], [92.24743652, 25.08927917], [92.24729919, 25.08923912], [92.24720001, 25.08926392], [92.24705505, 25.08926964], [92.24695587, 25.08938599], [92.24685669, 25.08948326], [92.24668121, 25.08944511], [92.24662781, 25.08960533], [92.24643707, 25.08974075], [92.24636078, 25.08970261], [92.24621582, 25.08974648], [92.24613953, 25.0898838], [92.24597168, 25.08986092], [92.24582672, 25.08988953], [92.24573517, 25.09001923], [92.24559021, 25.09002686], [92.24549103, 25.09010696], [92.24542236, 25.09014702], [92.24533844, 25.09016418], [92.24515533, 25.09022903], [92.24474335, 25.09039879], [92.2438736, 25.09077263], [92.24349976, 25.09104919], [92.24275208, 25.09140587], [92.24268341, 25.09147453], [92.24246979, 25.09157562], [92.24236298, 25.09166908], [92.2421875, 25.09178352], [92.24202728, 25.0918045], [92.24182129, 25.09180069], [92.24156952, 25.09179497], [92.24121857, 25.09189987], [92.24085999, 25.09204674], [92.24061584, 25.09216309], [92.24024963, 25.09233093], [92.23999023, 25.09244919], [92.23937225, 25.09284973], [92.23873138, 25.09324646], [92.23825836, 25.09337044], [92.23789215, 25.09347916], [92.23743439, 25.09396744], [92.23690033, 25.09404755], [92.2365036, 25.09408951], [92.2363739, 25.09414673], [92.23589325, 25.09435654], [92.23496246, 25.09468079], [92.23405457, 25.09477043], [92.23324585, 25.09498024], [92.23259735, 25.09543228], [92.2323761, 25.09558868], [92.23148346, 25.09623337], [92.23149109, 25.09694099], [92.23116302, 25.09713554], [92.2310791, 25.09709358], [92.23059082, 25.09684563], [92.22969055, 25.09607887], [92.22928619, 25.09591675], [92.22834778, 25.09553528], [92.22822571, 25.09493446], [92.22810364, 25.09436607], [92.22812653, 25.0941391], [92.22773743, 25.0936985], [92.2273941, 25.09385681], [92.2271347, 25.09403229], [92.22683716, 25.09423256], [92.22687531, 25.09451675], [92.22645569, 25.09516907], [92.22640991, 25.09568977], [92.22634125, 25.09576797], [92.22564697, 25.09617996], [92.22518921, 25.09649086], [92.22485352, 25.09665108], [92.22453308, 25.0969696], [92.22410583, 25.09716225], [92.22400665, 25.09751892], [92.22370148, 25.0977459], [92.22312927, 25.09817886], [92.22298431, 25.09833717], [92.22292328, 25.09869385], [92.22278595, 25.09915352], [92.22274017, 25.09947014], [92.22270966, 25.09967995], [92.22268677, 25.10012054], [92.22292328, 25.10093307], [92.22309113, 25.10119629], [92.22328949, 25.10149384], [92.22338867, 25.10178757], [92.22341919, 25.10206604], [92.22345734, 25.10254478], [92.22328186, 25.10282516], [92.22325134, 25.10317612], [92.2230072, 25.10339546], [92.22234344, 25.10367966], [92.2220993, 25.10388374], [92.22202301, 25.10395432], [92.22179413, 25.10417747], [92.22125244, 25.10412025], [92.22031403, 25.10438538], [92.21994781, 25.104496], [92.21959686, 25.10454941], [92.21906281, 25.10466576], [92.21883392, 25.10476494], [92.21865082, 25.10486603], [92.21857452, 25.10490799], [92.21820068, 25.10496902], [92.21809387, 25.10499954], [92.21786499, 25.10507011], [92.21749115, 25.10518265], [92.21736908, 25.10524178], [92.21715546, 25.10534668], [92.21649933, 25.10570145], [92.216362, 25.10583687], [92.21577454, 25.10615921], [92.21548462, 25.10620117], [92.21517181, 25.10658646], [92.21432495, 25.10686874], [92.21392059, 25.10703659], [92.21376801, 25.10709953], [92.21279907, 25.10741043], [92.2124939, 25.10750771], [92.21240234, 25.10752106], [92.21157837, 25.10763168], [92.21146393, 25.10770798], [92.21103668, 25.10778236], [92.2105484, 25.10801125], [92.21044159, 25.10806084], [92.21032715, 25.10807991], [92.20986176, 25.10815239], [92.20935059, 25.10825539], [92.20884705, 25.10837555], [92.20872498, 25.10838699], [92.20829773, 25.10852814], [92.20780182, 25.10859489], [92.20741272, 25.10868454], [92.20690918, 25.10877419], [92.20664215, 25.10856628], [92.20637512, 25.1083622], [92.20631409, 25.1083107], [92.20599365, 25.1081543], [92.20558167, 25.10795021], [92.2049408, 25.10790634], [92.2047348, 25.10771751], [92.20385742, 25.10691261], [92.2036972, 25.10677528], [92.20355225, 25.10664749], [92.20344543, 25.1066246], [92.20322418, 25.10657501], [92.20266724, 25.10650444], [92.20258331, 25.10678482], [92.20233154, 25.10695648], [92.20226288, 25.10700417], [92.20207214, 25.10714531], [92.20144653, 25.10754776], [92.20096588, 25.10767937], [92.20045471, 25.10777664], [92.19994354, 25.10783195], [92.19961548, 25.10788345], [92.19934082, 25.10788918], [92.19906616, 25.10794067], [92.19889069, 25.10780716], [92.19865417, 25.10749435], [92.19824982, 25.10749245], [92.19818115, 25.10753632], [92.19785309, 25.1077404], [92.19777679, 25.10774422], [92.19743347, 25.10776711], [92.1973114, 25.10805702], [92.19694519, 25.10808754], [92.19642639, 25.108078], [92.1963501, 25.10809517], [92.1960907, 25.10816574], [92.19635773, 25.10891914], [92.19658661, 25.10956573], [92.19702911, 25.11081314], [92.19718933, 25.11127853], [92.19767761, 25.11265564], [92.19790649, 25.11330032], [92.19812775, 25.11314201], [92.1985321, 25.112854], [92.1982193, 25.11340904], [92.19805145, 25.11370468], [92.19837189, 25.1145916], [92.19867706, 25.11547089], [92.19893646, 25.11621475], [92.19921112, 25.11696815], [92.19966125, 25.11733055], [92.19994354, 25.11736488], [92.20042419, 25.1174221], [92.20050049, 25.1179142], [92.20056915, 25.11836433], [92.2006073, 25.11865425], [92.20061493, 25.11875534], [92.20018768, 25.11877441], [92.19986725, 25.11878777], [92.19996643, 25.11914063], [92.20034027, 25.12011909], [92.2010498, 25.12031746], [92.20186615, 25.12032509], [92.20290375, 25.12015152], [92.20397186, 25.11997223], [92.20513916, 25.11976624], [92.20623016, 25.11957359], [92.20632172, 25.11955833], [92.20722961, 25.11925888], [92.20871735, 25.11878204], [92.20939636, 25.11856079], [92.21022034, 25.11829376], [92.21043396, 25.1182251], [92.21102905, 25.11803818], [92.21174622, 25.11780739], [92.21261597, 25.11752892], [92.21305847, 25.11738586], [92.21377563, 25.11715508], [92.21524811, 25.11668396], [92.21624756, 25.11636353], [92.21736145, 25.11600685], [92.21899414, 25.11548233], [92.21929932, 25.11538887], [92.21961975, 25.11536598], [92.21953583, 25.11610985], [92.2193222, 25.11713219], [92.21871948, 25.11753273], [92.21839142, 25.11796761], [92.21802521, 25.11795425], [92.21775055, 25.11794281], [92.21675873, 25.11869049], [92.21614838, 25.11908531], [92.21511841, 25.11969757], [92.21503448, 25.11975288], [92.21476746, 25.11995888], [92.21417236, 25.12035179], [92.21364594, 25.12067223], [92.21296692, 25.12108994], [92.21100616, 25.12169647], [92.20968628, 25.12211418], [92.20948029, 25.12217331], [92.20921326, 25.1222496], [92.20900726, 25.12249756], [92.20793915, 25.12279892], [92.20768738, 25.12262726], [92.20726013, 25.12282181], [92.20728302, 25.12298393], [92.2067337, 25.12309265], [92.20600891, 25.12346649], [92.20578766, 25.12357903], [92.20549011, 25.12373543], [92.2042923, 25.12390137], [92.20291901, 25.12440491], [92.20224762, 25.12462234], [92.20174408, 25.12478256], [92.20064545, 25.12516403], [92.20050049, 25.12521744], [92.19923401, 25.12564659], [92.1989212, 25.1257534], [92.19515991, 25.12475014], [92.19309998, 25.12288284], [92.19198608, 25.12091827], [92.18754578, 25.12195969], [92.18657684, 25.12277985], [92.18584442, 25.12338257], [92.18558502, 25.12293625], [92.18382263, 25.11819649], [92.18338776, 25.11831284], [92.18263245, 25.11851501], [92.18241119, 25.11860275], [92.18193817, 25.11885834], [92.18151855, 25.11919975], [92.18115234, 25.11992836], [92.18108368, 25.12004471], [92.1810379, 25.12013817], [92.18099976, 25.12020302], [92.18087006, 25.120327], [92.18069458, 25.12058258], [92.1804657, 25.12082481], [92.18042755, 25.12093544], [92.180336, 25.12102318], [92.1802597, 25.12102509], [92.18006134, 25.12133026], [92.18018341, 25.12149048], [92.17996216, 25.12151337], [92.17978668, 25.12149239], [92.17978668, 25.12157249], [92.1796875, 25.12161255], [92.17906189, 25.1218586], [92.17858887, 25.121912], [92.17845154, 25.12197113], [92.17824554, 25.12209702], [92.17745972, 25.12233162], [92.17689514, 25.12269211], [92.17665863, 25.12298203], [92.17810822, 25.1233139], [92.17837524, 25.12345695], [92.17886353, 25.12377357], [92.17892456, 25.12395096], [92.17913818, 25.12403679], [92.17923737, 25.12408829], [92.17932892, 25.12420082], [92.17935944, 25.12429428], [92.17931366, 25.1244278], [92.17916107, 25.12458992], [92.17919922, 25.12474442], [92.17922974, 25.12488556], [92.1791153, 25.12522507], [92.17904663, 25.12566757], [92.17891693, 25.12576103], [92.17879486, 25.12584305], [92.17882538, 25.12592888], [92.17888641, 25.12598419], [92.17896271, 25.12609863], [92.17890167, 25.12638283], [92.17865753, 25.12628555], [92.17842865, 25.12631607], [92.17834473, 25.12631798], [92.1782074, 25.12631035], [92.17796326, 25.12616158], [92.17787933, 25.12605476], [92.1778717, 25.12579346], [92.17774963, 25.12557793], [92.17759705, 25.12525368], [92.17755127, 25.12504768], [92.1776123, 25.12473679], [92.17761993, 25.12460518], [92.17758179, 25.12453651], [92.1774292, 25.12461281], [92.17736053, 25.12470245], [92.17732239, 25.12479782], [92.17734528, 25.12506104], [92.17718506, 25.1250782], [92.17695618, 25.12451172], [92.17684937, 25.12412071], [92.17665863, 25.12399864], [92.17654419, 25.12407303], [92.17645264, 25.12424088], [92.17636871, 25.12436295], [92.1762619, 25.12455368], [92.17625427, 25.12467766], [92.17623138, 25.12485695], [92.17617798, 25.12512589], [92.17614746, 25.12527466], [92.17604828, 25.12553215], [92.17608643, 25.12577248], [92.1761322, 25.1259079], [92.17620087, 25.12603569], [92.17616272, 25.12643433], [92.17554474, 25.12634659], [92.17467499, 25.12667084], [92.17398834, 25.12655258], [92.17378235, 25.12653923], [92.17357635, 25.12652969], [92.17327118, 25.12657738], [92.17259216, 25.12686348], [92.17247772, 25.12690926], [92.17243958, 25.1269722], [92.17240143, 25.12721634], [92.17230988, 25.12724876], [92.17216492, 25.12722588], [92.17201996, 25.12720299], [92.17190552, 25.12718773], [92.1717453, 25.12723732], [92.17164612, 25.12751961], [92.17157745, 25.12767601], [92.1714859, 25.12777519], [92.17134857, 25.12793541], [92.1714325, 25.12804413], [92.17192078, 25.12825966], [92.17195892, 25.12833405], [92.17182922, 25.12849045], [92.17167664, 25.12851143], [92.17157745, 25.12852478], [92.17140198, 25.12852859], [92.1712265, 25.12853432], [92.17110443, 25.12857437], [92.17086029, 25.12870026], [92.17073822, 25.12868881], [92.17049408, 25.12851524], [92.1704483, 25.12843513], [92.17038727, 25.12830925], [92.17034912, 25.12822342], [92.17012787, 25.1280365], [92.17012787, 25.12793541], [92.17011261, 25.12776947], [92.17011261, 25.12765884], [92.16999054, 25.12767029], [92.16986084, 25.12776756], [92.16976166, 25.12796021], [92.16970062, 25.12807846], [92.16954803, 25.12803268], [92.16950989, 25.12792015], [92.16950226, 25.12783051], [92.169487, 25.12768364], [92.16947174, 25.12758255], [92.16941833, 25.1274662], [92.16873932, 25.12695313], [92.16721344, 25.12691879], [92.16644287, 25.12690353], [92.16539001, 25.12645531], [92.16413879, 25.12555313], [92.16383362, 25.12578011], [92.16378784, 25.12584496], [92.16329956, 25.12604523], [92.16259003, 25.12636566], [92.162323, 25.12668991], [92.16140747, 25.12628746], [92.16093445, 25.12652969], [92.1605835, 25.12662315], [92.16035461, 25.12656975], [92.16000366, 25.12655258], [92.15949249, 25.12671089], [92.15920258, 25.1272049], [92.15927887, 25.12766838], [92.15950012, 25.12788963], [92.15981293, 25.12788963], [92.16060638, 25.1280899], [92.16074371, 25.1280632], [92.16086578, 25.12804031], [92.16122437, 25.12808037], [92.16175079, 25.12807083], [92.16247559, 25.12846756], [92.16265869, 25.12853432], [92.16279602, 25.12856674], [92.1630249, 25.12867165], [92.16351318, 25.12907219], [92.16381073, 25.12931252], [92.16401672, 25.12947845], [92.16461182, 25.13017273], [92.16481018, 25.13060379], [92.16478729, 25.13069534], [92.16441345, 25.13067627], [92.1643219, 25.13067055], [92.16402435, 25.13059616], [92.16355896, 25.13047409], [92.16268921, 25.13014603], [92.16217804, 25.13002586], [92.16138458, 25.12971115], [92.16099548, 25.12984467], [92.1608429, 25.12998581], [92.16046143, 25.13000107], [92.16009521, 25.13005066], [92.15976715, 25.13007355], [92.15943146, 25.1301136], [92.15924835, 25.13048363], [92.15911102, 25.13070488], [92.15925598, 25.13101387], [92.15925598, 25.13110924], [92.15911865, 25.13173866], [92.15899658, 25.13193512], [92.15895081, 25.13200569], [92.15891266, 25.13208771], [92.15886688, 25.13220978], [92.15884399, 25.13229179], [92.15883636, 25.13238335], [92.15877533, 25.13289261], [92.15874481, 25.13310814], [92.15904999, 25.13315392], [92.16036224, 25.13356209], [92.16046143, 25.13365936], [92.16108704, 25.13362312], [92.16190338, 25.1335659], [92.16216278, 25.13354492], [92.16268158, 25.13350296], [92.16291809, 25.13358116], [92.16322327, 25.13407898], [92.16324615, 25.1342659], [92.16329193, 25.13458061], [92.1635437, 25.13464165], [92.16436005, 25.134758], [92.16481018, 25.1348114], [92.16518402, 25.13495636], [92.16567993, 25.13512993], [92.1656723, 25.13582993], [92.16566467, 25.13602066], [92.16539001, 25.13609695], [92.16494751, 25.13605118], [92.16436768, 25.13599014], [92.16409302, 25.13600159], [92.16394043, 25.13605309], [92.16371155, 25.13617897], [92.16352844, 25.13625526], [92.1632843, 25.13635826], [92.16298676, 25.13614655], [92.16287231, 25.13618469], [92.16260529, 25.13634491], [92.16242218, 25.13629341], [92.16213226, 25.13616562], [92.16184998, 25.13598061], [92.16179657, 25.13527107], [92.16146851, 25.13501167], [92.16120148, 25.13515854], [92.16081238, 25.13518333], [92.16054535, 25.13515663], [92.16013336, 25.13496208], [92.16013336, 25.13471985], [92.15987396, 25.13430977], [92.15968323, 25.13416862], [92.15934753, 25.13418579], [92.15903473, 25.13406372], [92.15879059, 25.13399696], [92.15820312, 25.13382721], [92.15791321, 25.13363266], [92.15765381, 25.13350105], [92.15749359, 25.13334846], [92.15727997, 25.1333847], [92.15692139, 25.13336372], [92.15577698, 25.13334084], [92.15546417, 25.13334846], [92.15499878, 25.13342094], [92.15431213, 25.13352966], [92.15418243, 25.13368607], [92.1541748, 25.13385963], [92.1539917, 25.13390541], [92.15390778, 25.13383675], [92.15371704, 25.13365173], [92.15306854, 25.13374901], [92.15262604, 25.13381767], [92.15274811, 25.13448524], [92.15293121, 25.13543701], [92.15309143, 25.13633728], [92.15248871, 25.13728905], [92.1521225, 25.13772774], [92.15112305, 25.1381855], [92.15076447, 25.13835335], [92.14978027, 25.13782501], [92.14900208, 25.13741112], [92.14820862, 25.13659286], [92.14775848, 25.13585091], [92.14743805, 25.13578796], [92.14737701, 25.13565063], [92.14732361, 25.13540268], [92.14717102, 25.13541794], [92.14665985, 25.13558197], [92.1461792, 25.13570023], [92.14564514, 25.13569641], [92.14452362, 25.13588333], [92.14310455, 25.1358757], [92.14238739, 25.13606071], [92.14196014, 25.13616943], [92.14173126, 25.13635254], [92.14162445, 25.13647461], [92.14154816, 25.13661766], [92.14163971, 25.13684654], [92.14173126, 25.13696289], [92.1420517, 25.1373024], [92.14212036, 25.13743973], [92.14209747, 25.13752174], [92.1420517, 25.1376667], [92.14186859, 25.13771057], [92.14160919, 25.13768196], [92.14146423, 25.13759232], [92.14122772, 25.13742638], [92.14102173, 25.13754654], [92.14076996, 25.13769722], [92.14054871, 25.13783836], [92.14009857, 25.13805962], [92.13981628, 25.13812637], [92.13889313, 25.1382637], [92.13834381, 25.13829613], [92.13816833, 25.13830757], [92.13795471, 25.13822556], [92.1378479, 25.13818359], [92.13722992, 25.13843536], [92.13669586, 25.1386261], [92.13660431, 25.13862991], [92.13650513, 25.13860893], [92.13640594, 25.13866615], [92.13637543, 25.13851357], [92.13576508, 25.13885498], [92.13578033, 25.13910294], [92.13582611, 25.13964653], [92.13607788, 25.13983536], [92.13637543, 25.13990784], [92.13728333, 25.14010048], [92.13806152, 25.14019966], [92.13841248, 25.14013672], [92.13848877, 25.14023209], [92.13838959, 25.14052963], [92.13847351, 25.14056969], [92.13900757, 25.14066315], [92.13930511, 25.14047623], [92.13937378, 25.14076233], [92.1394577, 25.14107323], [92.14000702, 25.14073944], [92.14013672, 25.14050484], [92.13972473, 25.14020157], [92.13944244, 25.14012718], [92.13946533, 25.13997841], [92.14029694, 25.14020348], [92.14044952, 25.14024353], [92.14064026, 25.14020348], [92.1408844, 25.1402626], [92.14096069, 25.14027977], [92.14105225, 25.14003563], [92.14112854, 25.1399231], [92.14118958, 25.13978386], [92.14144135, 25.13986206], [92.14131927, 25.14024162], [92.14128876, 25.1403389], [92.14179993, 25.14059639], [92.14186096, 25.14025879], [92.1419754, 25.14008141], [92.14225769, 25.14008331], [92.14233398, 25.14008331], [92.14253998, 25.13983345], [92.14261627, 25.13977623], [92.14287567, 25.13992882], [92.14375305, 25.1395607], [92.14393616, 25.13947868], [92.144104, 25.13956833], [92.14450073, 25.13978767], [92.14438629, 25.14002228], [92.14411163, 25.14000702], [92.1437912, 25.13983345], [92.14324951, 25.14011002], [92.14278412, 25.14040375], [92.14208984, 25.14085388], [92.14186859, 25.14101601], [92.14161682, 25.14112854], [92.14151001, 25.14117622], [92.14125061, 25.14088821], [92.14085388, 25.14106178], [92.14070129, 25.14112854], [92.14031219, 25.14149857], [92.14025116, 25.14155769], [92.14012146, 25.14168167], [92.13980865, 25.1415329], [92.13950348, 25.14139175], [92.13812256, 25.14154625], [92.13802338, 25.14143181], [92.13754272, 25.14153481], [92.13697052, 25.14152908], [92.13678741, 25.14162064], [92.13631439, 25.14188194], [92.13504791, 25.14216805], [92.13461304, 25.1426239], [92.13446808, 25.14274979], [92.13430023, 25.14296913], [92.13414764, 25.14372253], [92.13443756, 25.14462852], [92.134758, 25.14467049], [92.13509369, 25.14574432], [92.13478088, 25.14723206], [92.13456726, 25.14738083], [92.13415527, 25.14804649], [92.13380432, 25.14846802], [92.13420105, 25.14904594], [92.1341629, 25.14952278], [92.13466644, 25.14977455], [92.13580322, 25.15151978], [92.13574982, 25.15190887], [92.13524628, 25.15224838], [92.13412476, 25.1525898], [92.13409424, 25.15329552], [92.1348877, 25.15328407], [92.13588715, 25.15268898], [92.13613892, 25.15254402], [92.1367569, 25.15232849], [92.13794708, 25.15189362], [92.13828278, 25.15220451], [92.13842773, 25.15234756], [92.13902283, 25.15367508], [92.13915253, 25.15398788], [92.13959503, 25.15473557], [92.13906097, 25.15530777], [92.13867188, 25.15499878], [92.13840485, 25.15505219], [92.13800812, 25.15519333], [92.13721466, 25.15544891], [92.13668823, 25.15537453], [92.13616943, 25.15529823], [92.13594818, 25.15533066], [92.13568878, 25.15540314], [92.13398743, 25.15612793], [92.13359833, 25.15646172], [92.133461, 25.15650177], [92.13272858, 25.15645599], [92.13262939, 25.15660095], [92.13196564, 25.15756416], [92.13233948, 25.1587429], [92.13259888, 25.1595459], [92.13278961, 25.16014481], [92.13283539, 25.16027069], [92.13172913, 25.16014481], [92.130867, 25.16004944], [92.13077545, 25.16003799], [92.13017273, 25.16120911], [92.12953949, 25.16150856], [92.12903595, 25.16174316], [92.128479, 25.16200638], [92.1272583, 25.16183472], [92.12578583, 25.16223526], [92.12479401, 25.16250038], [92.12340546, 25.16295052], [92.12243652, 25.16326523], [92.12130737, 25.16361809], [92.1210556, 25.1636982], [92.1198349, 25.16449928], [92.11975098, 25.16460037], [92.11880493, 25.16570473], [92.11806488, 25.16656113], [92.11768341, 25.16674614], [92.11753845, 25.16681671], [92.11735535, 25.16690826], [92.11707306, 25.16704941], [92.11371613, 25.16870308], [92.11329651, 25.16890907], [92.11296844, 25.16902924], [92.11185455, 25.16942406], [92.10944366, 25.17027855], [92.10894012, 25.17045784], [92.10839844, 25.17138672], [92.10777283, 25.17245865], [92.10762024, 25.17272949], [92.10700226, 25.17272186], [92.10562134, 25.17271042], [92.10547638, 25.17271042], [92.10514832, 25.17270851], [92.10472107, 25.17380142], [92.10435486, 25.17474937], [92.10373688, 25.17487907], [92.1026535, 25.17510223], [92.10179138, 25.17528152], [92.10093689, 25.17545891], [92.09999847, 25.17565346], [92.09947205, 25.17575836], [92.09871674, 25.17591476], [92.09746552, 25.17653084], [92.09516144, 25.17765427], [92.09506226, 25.17769814], [92.09428406, 25.17807579], [92.0921936, 25.1776619], [92.09038544, 25.17847061], [92.08955383, 25.17884445], [92.0890274, 25.17907906], [92.08805847, 25.17951393], [92.0875473, 25.17974091], [92.08673859, 25.18023491], [92.08627319, 25.1805191], [92.08496857, 25.18131256], [92.08426666, 25.18173599], [92.08383942, 25.18198967], [92.0831604, 25.18240356], [92.08205414, 25.18257713], [92.08112335, 25.182724], [92.08097839, 25.18274498], [92.08053589, 25.18240738], [92.07952118, 25.18163681], [92.0789032, 25.18117142], [92.07875061, 25.18105316], [92.076828, 25.18261909], [92.07489014, 25.18416977], [92.07427979, 25.18465614], [92.07376099, 25.18505859], [92.07141113, 25.18514442], [92.07086182, 25.18516159], [92.06817627, 25.18524933], [92.06768799, 25.18526459], [92.06708527, 25.18528366], [92.06653595, 25.18549538], [92.06636047, 25.18555832], [92.06496429, 25.18604851], [92.06426239, 25.18629265], [92.06282806, 25.1867981], [92.0622406, 25.18698883], [92.06183624, 25.18711853], [92.06049347, 25.18655014], [92.05973816, 25.18621635], [92.05935669, 25.18604279], [92.05884552, 25.185812], [92.05846405, 25.18564224], [92.05836487, 25.18576813], [92.0582962, 25.18585968], [92.05821991, 25.18595886], [92.05792999, 25.18639565], [92.05776215, 25.18652153], [92.05756378, 25.1866684], [92.05742645, 25.18674278], [92.05721283, 25.18672562], [92.05700684, 25.1866951], [92.05680084, 25.18650246], [92.056427, 25.18596649], [92.0561676, 25.18575859], [92.0561142, 25.18570518], [92.05593109, 25.18553925], [92.05590057, 25.18540955], [92.05584717, 25.1853447], [92.05571747, 25.18523026], [92.05545044, 25.18443108], [92.05538177, 25.18439865], [92.05513763, 25.18440437], [92.05492401, 25.1844883], [92.05418396, 25.18489647], [92.0539093, 25.18514442], [92.05381012, 25.18530846], [92.05383301, 25.18537903], [92.05392456, 25.1855278], [92.05409241, 25.18582153], [92.05416107, 25.18599892], [92.05432892, 25.18635559], [92.05410767, 25.18658066], [92.05400848, 25.18652534], [92.05391693, 25.18647957], [92.05378723, 25.1864109], [92.05361176, 25.18638802], [92.05343628, 25.18636513], [92.0530014, 25.1864624], [92.05251312, 25.18665314], [92.05212402, 25.18678474], [92.05184174, 25.18679237], [92.05160522, 25.1867485], [92.05150604, 25.18672943], [92.05130005, 25.18675804], [92.05113983, 25.18681908], [92.0508728, 25.18692589], [92.05066681, 25.18692589], [92.0506134, 25.18679237], [92.05046844, 25.18642426], [92.05021667, 25.18670082], [92.04982758, 25.18675232], [92.04961395, 25.18688011], [92.04949951, 25.18694878], [92.04930115, 25.18707275], [92.04883575, 25.18679047], [92.04862213, 25.18657875], [92.04855347, 25.18651581], [92.04827881, 25.1863575], [92.04781342, 25.18637276], [92.04740906, 25.18647385], [92.04697418, 25.18651581], [92.04660034, 25.18639755], [92.04647064, 25.18640518], [92.04601288, 25.18645668], [92.04595184, 25.18650246], [92.04582977, 25.18659401], [92.04558563, 25.18645668], [92.04551697, 25.18641853], [92.0453186, 25.18636894], [92.04505157, 25.18623734], [92.04489899, 25.18619919], [92.04460144, 25.18629265], [92.04451752, 25.18630791], [92.04429626, 25.18634415], [92.04341888, 25.18622017], [92.04317474, 25.18631363], [92.04055023, 25.18580055], [92.04016113, 25.18570709], [92.04004669, 25.1853714], [92.04006958, 25.18505096], [92.03983307, 25.18481445], [92.03955841, 25.1847229], [92.03938293, 25.1846962], [92.03922272, 25.18472481], [92.03903961, 25.18446922], [92.03890991, 25.18407822], [92.03887939, 25.18380356], [92.0389328, 25.18358994], [92.03901672, 25.18333054], [92.03903961, 25.18325043], [92.03902435, 25.18299866], [92.03900909, 25.18283653], [92.03900146, 25.18272972], [92.03898621, 25.18258667], [92.03890228, 25.18242073], [92.03866577, 25.18240929], [92.03839874, 25.18239594], [92.03817749, 25.18235588], [92.03783417, 25.18224525], [92.03726196, 25.18209076], [92.03701782, 25.18218231], [92.03691101, 25.18221855], [92.03640747, 25.18234253], [92.03585815, 25.18266869], [92.03540039, 25.18298531], [92.03504181, 25.1832428], [92.0341568, 25.1834774], [92.03411865, 25.18429565], [92.03392792, 25.18439293], [92.03366089, 25.18431091], [92.03355408, 25.18402672], [92.03348541, 25.18392372], [92.03339386, 25.18386078], [92.03323364, 25.18382072], [92.03330231, 25.18373299], [92.03336334, 25.18367767], [92.03340912, 25.18359756], [92.03336334, 25.18353844], [92.03327179, 25.18348503], [92.0331192, 25.18352127], [92.03296661, 25.18355942], [92.03265381, 25.18358612], [92.03213501, 25.18358803], [92.03149414, 25.18370819], [92.02988434, 25.18323326], [92.02845764, 25.18359947], [92.02820587, 25.18353271], [92.0279541, 25.18360138], [92.02783203, 25.18353653], [92.02772522, 25.18324852], [92.02766418, 25.1830368], [92.02764893, 25.18278122], [92.02766418, 25.18192863], [92.02761841, 25.18177032], [92.02742767, 25.18139458], [92.02722168, 25.18112755], [92.02687836, 25.18085289], [92.02651978, 25.18061638], [92.02623749, 25.1803627], [92.02616119, 25.18004608], [92.02613831, 25.17964172], [92.02610779, 25.17930603], [92.02598572, 25.1793251], [92.02536774, 25.17960548], [92.02452087, 25.17999458], [92.02348328, 25.18047333], [92.02217102, 25.18107605], [92.02084351, 25.18168449], [92.02030945, 25.18192863], [92.01984406, 25.18214226], [92.01835632, 25.18282509], [92.01805878, 25.1832428], [92.01774597, 25.18450546], [92.01746368, 25.18561172], [92.01702881, 25.18618584], [92.01691437, 25.18622398], [92.01205444, 25.18662453], [92.01180267, 25.18664551], [92.01109314, 25.18654633], [92.00933075, 25.18629646], [92.00913239, 25.18630981], [92.00823975, 25.18637657], [92.00717926, 25.18640327], [92.00640869, 25.18638992], [92.00485992, 25.18636131], [92.00461578, 25.1863575], [92.00341797, 25.18624115], [92.00291443, 25.18609238], [92.00246429, 25.18595886], [91.99970245, 25.18362999], [91.99582672, 25.17959023], [91.99221039, 25.17698288], [91.98925781, 25.17578316], [91.98795319, 25.17456818], [91.98699951, 25.17397499], [91.98532104, 25.17288399], [91.9849472, 25.1727829], [91.98439789, 25.17253494], [91.9838028, 25.17228317], [91.98352051, 25.17216301], [91.98329926, 25.17206383], [91.98286438, 25.17201042], [91.98225403, 25.17198181], [91.98123932, 25.17185211], [91.9805069, 25.17178917], [91.97956085, 25.17188454], [91.97891998, 25.17201233], [91.97859192, 25.17212868], [91.97826385, 25.17230034], [91.97789764, 25.17261887], [91.97682953, 25.17337418], [91.97637939, 25.17360115], [91.97601318, 25.17374802], [91.97535706, 25.1739521], [91.97449493, 25.17416763], [91.97338867, 25.17467499], [91.97232056, 25.17504501], [91.97197723, 25.17525101], [91.97172546, 25.17536926], [91.97136688, 25.17547989], [91.97094727, 25.17562294], [91.97009277, 25.17594528], [91.96954346, 25.1759491], [91.96911621, 25.17599297], [91.96875763, 25.17605591], [91.96733856, 25.1762867], [91.96696472, 25.17643738], [91.96673584, 25.17650223], [91.96651459, 25.17654419], [91.96601868, 25.17655182], [91.96435547, 25.17637825], [91.96295929, 25.17638206], [91.9626236, 25.1764679], [91.96203613, 25.17665482], [91.96004486, 25.17704773], [91.95853424, 25.17740631], [91.95803833, 25.17746162], [91.95731354, 25.17760658], [91.95545959, 25.17772675], [91.95314789, 25.17773247], [91.95200348, 25.17769432], [91.9499054, 25.17747879], [91.94855499, 25.17738533], [91.94705963, 25.17720413], [91.94596863, 25.17777634], [91.94572449, 25.17761993], [91.94536591, 25.17777443], [91.9451828, 25.17785263], [91.94457245, 25.17797852], [91.94387054, 25.17799759], [91.94360352, 25.17796898], [91.94255066, 25.17802429], [91.94200897, 25.17811394], [91.94155121, 25.17817879], [91.94054413, 25.17825699], [91.93780518, 25.17866707], [91.93743896, 25.17870712], [91.93650818, 25.17862892], [91.93561554, 25.17849541], [91.93530273, 25.17839241], [91.93476868, 25.17825127], [91.93451691, 25.17819977], [91.93434906, 25.17819977], [91.93425751, 25.17819786], [91.93395996, 25.17844582], [91.93352509, 25.17930984], [91.93345642, 25.1794281], [91.93281555, 25.18056107], [91.93247986, 25.18045998], [91.93157959, 25.18089867], [91.93093872, 25.18121147], [91.93060303, 25.18027878], [91.92928314, 25.18025017], [91.92777252, 25.18021202], [91.92731476, 25.18015671], [91.92661285, 25.18011093], [91.92591858, 25.18006516], [91.92520905, 25.18027115], [91.92436218, 25.18048668], [91.92333984, 25.18058968], [91.9223175, 25.18069267], [91.92172241, 25.18118477], [91.92070007, 25.18134499], [91.91934204, 25.18117905], [91.91833496, 25.18116379], [91.91732788, 25.18115044], [91.91616058, 25.18148041], [91.91537476, 25.18135834], [91.91452026, 25.18142891], [91.91310883, 25.18125725], [91.9118576, 25.18083572], [91.91124725, 25.18061638], [91.91083527, 25.18050575], [91.91043091, 25.1803875], [91.90984344, 25.18022728], [91.90917206, 25.18004036], [91.90812683, 25.17968941], [91.90734863, 25.17944145], [91.90682983, 25.17952347], [91.90583038, 25.17966461], [91.90493011, 25.1797905], [91.90460205, 25.17984009], [91.90399933, 25.17992973], [91.90305328, 25.17998505], [91.9019165, 25.18004608], [91.90097809, 25.18008614], [91.90003967, 25.18013191], [91.89925385, 25.18016815], [91.8984375, 25.18020248], [91.89759827, 25.1795311], [91.89741516, 25.17938042], [91.89735413, 25.17875099], [91.89730072, 25.17819214], [91.89555359, 25.1783371], [91.89459229, 25.17842102], [91.89422607, 25.17845154], [91.89382172, 25.17848778], [91.89426422, 25.17733383], [91.89451599, 25.1766758], [91.89463043, 25.17637253], [91.89349365, 25.17622948], [91.89282227, 25.17613983], [91.89225006, 25.17606163], [91.89092255, 25.17618179], [91.88956451, 25.17629051], [91.88821411, 25.1764164], [91.88732147, 25.17663956], [91.88468933, 25.17715836], [91.88442993, 25.17720795], [91.88302612, 25.17610741], [91.8824234, 25.17559624], [91.88183594, 25.17510223], [91.88152313, 25.17459488], [91.8812027, 25.17407227], [91.88082123, 25.17344475], [91.88056183, 25.17302895], [91.87944794, 25.17346764], [91.87825012, 25.17393875], [91.87767029, 25.17440414], [91.87709808, 25.17486], [91.87606812, 25.1756897], [91.87599182, 25.17647934], [91.87588501, 25.17754555], [91.87541199, 25.17725563], [91.87407684, 25.17644119], [91.8735733, 25.1761322], [91.87284088, 25.17567825], [91.87147522, 25.17482376], [91.87081909, 25.17442131], [91.87042999, 25.17447853], [91.87000275, 25.17454147], [91.8685379, 25.17477417], [91.86801147, 25.17485619], [91.86711884, 25.17501068], [91.86638641, 25.17512703], [91.86516571, 25.17531204], [91.86450195, 25.17539978], [91.86431122, 25.17542458], [91.86308289, 25.17420959], [91.86227417, 25.17342567], [91.86196899, 25.17312813], [91.86142731, 25.17259407], [91.86096954, 25.17268372], [91.86049652, 25.17277527], [91.85947418, 25.17298317], [91.85849762, 25.17316246], [91.8582077, 25.17311668], [91.85791016, 25.17306709], [91.85774231, 25.17304993], [91.8572464, 25.17299652], [91.85683441, 25.17290878], [91.85642242, 25.17282295], [91.85551453, 25.17262077], [91.85507965, 25.17266655], [91.85443878, 25.17274475], [91.85263062, 25.17319298], [91.85131073, 25.17348099], [91.85050201, 25.1734066], [91.84973145, 25.17333603], [91.84880066, 25.17362404], [91.84792328, 25.17389679], [91.84638977, 25.1743927], [91.84487152, 25.17487907], [91.8445282, 25.17498779], [91.84405518, 25.17544937], [91.84365082, 25.17584991], [91.84309387, 25.17640114], [91.84207153, 25.176651], [91.84158325, 25.17676926], [91.84120178, 25.17687035], [91.84069824, 25.17705154], [91.83956146, 25.1770134], [91.83879852, 25.17719078], [91.83785248, 25.17731667], [91.83686829, 25.17746353], [91.83608246, 25.17746925], [91.835289, 25.17747307], [91.8347702, 25.17759514], [91.83418274, 25.17773247], [91.83339691, 25.17790794], [91.83256531, 25.17813301], [91.83244324, 25.17799759], [91.8323288, 25.17798233], [91.8322525, 25.17793655], [91.8320694, 25.17792511], [91.83206177, 25.17774391], [91.83205414, 25.17747307], [91.83203888, 25.17736053], [91.83189392, 25.17737389], [91.83180237, 25.1775856], [91.83174133, 25.17776871], [91.83165741, 25.17791557], [91.83154297, 25.1779232], [91.83148193, 25.17780113], [91.83146667, 25.17772293], [91.83146667, 25.17764282], [91.83151245, 25.17739487], [91.83153534, 25.1773243], [91.83157349, 25.17724609], [91.83157349, 25.17713547], [91.83144379, 25.17714691], [91.83136749, 25.17725563], [91.83126068, 25.17741203], [91.83118439, 25.17747307], [91.83107758, 25.17753601], [91.8306427, 25.17754745], [91.83053589, 25.17738342], [91.83043671, 25.177248], [91.8303833, 25.17703247], [91.83018494, 25.17711067], [91.83013153, 25.17725372], [91.83009338, 25.17736626], [91.82989502, 25.17743683], [91.82983398, 25.17755127], [91.82967377, 25.1775856], [91.82962036, 25.1775341], [91.82946014, 25.17745781], [91.82935333, 25.17733383], [91.82923126, 25.17749214], [91.82909393, 25.17750931], [91.82899475, 25.17752266], [91.82894897, 25.17786789], [91.82886505, 25.17793465], [91.82879639, 25.17788506], [91.82876587, 25.17780495], [91.82872009, 25.1776123], [91.82855225, 25.17771721], [91.82847595, 25.17779732], [91.82842255, 25.17787361], [91.82830811, 25.17790604], [91.82819366, 25.17785072], [91.82807159, 25.17766571], [91.82788086, 25.17770958], [91.82780457, 25.1777668], [91.82769775, 25.17785454], [91.82761383, 25.17789268], [91.8274765, 25.17793846], [91.82733917, 25.17794037], [91.82726288, 25.17794037], [91.8271637, 25.17794991], [91.82698822, 25.17792702], [91.82646942, 25.17778015], [91.82649231, 25.17768669], [91.82652283, 25.17759323], [91.82658386, 25.17705917], [91.82658386, 25.17692757], [91.82653809, 25.17650223], [91.82652283, 25.17633057], [91.82598114, 25.17631149], [91.82543945, 25.17625999], [91.8250885, 25.17618942], [91.82453918, 25.1764164], [91.82369232, 25.17673683], [91.82318115, 25.17641068], [91.82228088, 25.1762104], [91.8221283, 25.176054], [91.82202148, 25.17584801], [91.82191467, 25.17563629], [91.82152557, 25.17521858], [91.82058716, 25.17453003], [91.81984711, 25.17387009], [91.81976318, 25.1737957], [91.81904602, 25.17319489], [91.81859589, 25.1729126], [91.81841278, 25.17279434], [91.81813812, 25.17248917], [91.81800079, 25.17220497], [91.81758881, 25.17133141], [91.81687164, 25.17130661], [91.81639862, 25.17136574], [91.81607056, 25.171381], [91.81554413, 25.1714077], [91.81492615, 25.17143822], [91.81429291, 25.17146301], [91.81385803, 25.17147255], [91.81349182, 25.17148972], [91.81295013, 25.17149353], [91.81245422, 25.1715126], [91.81171417, 25.17154121], [91.81124115, 25.17156029], [91.81080627, 25.17156982], [91.81034851, 25.17158508], [91.80974579, 25.17161369], [91.80930328, 25.17160606], [91.80860901, 25.1715889], [91.80819702, 25.17159081], [91.80783844, 25.17162514], [91.80735016, 25.17165184], [91.80697632, 25.17166138], [91.80661774, 25.17167854], [91.80590057, 25.17170715], [91.80529022, 25.17173386], [91.80480957, 25.17171669], [91.80477142, 25.17181396], [91.80442047, 25.1718502], [91.8041153, 25.17188263], [91.80393982, 25.17185211], [91.80386353, 25.17140388], [91.80368042, 25.17096329], [91.80352783, 25.17068481], [91.80355072, 25.17056847], [91.80376434, 25.17031479], [91.80410004, 25.17019653], [91.80432129, 25.17020226], [91.80447388, 25.17015457], [91.80461884, 25.16988564], [91.80535889, 25.16957283], [91.80544281, 25.16986084], [91.80545807, 25.17005157], [91.80550385, 25.17020226], [91.80561829, 25.17035103], [91.80596924, 25.17036057], [91.80627441, 25.1702652], [91.80696869, 25.16985512], [91.80695343, 25.16953659], [91.80679321, 25.1691494], [91.80667114, 25.16887093], [91.80661774, 25.16872025], [91.80656433, 25.16854858], [91.80643463, 25.16836357], [91.80627441, 25.16831398], [91.8052063, 25.16807175], [91.80513, 25.16817856], [91.80403137, 25.16823006], [91.80266571, 25.16834259], [91.8017807, 25.16823578], [91.80037689, 25.1681881], [91.800354, 25.16829491], [91.79998779, 25.16848373], [91.79965973, 25.16857338], [91.79885864, 25.16870117], [91.79878998, 25.16851044], [91.7978363, 25.16872787], [91.7973175, 25.16884613], [91.79718018, 25.16891861], [91.7970047, 25.1688118], [91.79679871, 25.16869736], [91.79668427, 25.1686554], [91.79655457, 25.16859627], [91.79632568, 25.16856575], [91.79611206, 25.16851425], [91.79594421, 25.1684227], [91.79576111, 25.16833305], [91.7951889, 25.16814232], [91.79484558, 25.16809082], [91.79415894, 25.1680336], [91.79349518, 25.16804314], [91.79335785, 25.16803551], [91.79292297, 25.16801834], [91.79281616, 25.16800308], [91.7927475, 25.1679554], [91.7926178, 25.16784286], [91.79257202, 25.16777611], [91.79241943, 25.16765213], [91.79219055, 25.16769028], [91.79209137, 25.16777992], [91.79176331, 25.1678009], [91.79151917, 25.16781044], [91.79138184, 25.16778946], [91.79110718, 25.16777039], [91.79075623, 25.16770744], [91.79061127, 25.16766548], [91.79037476, 25.16769981], [91.79029846, 25.16767883], [91.7902298, 25.16763115], [91.79008484, 25.16751862], [91.78990173, 25.1674881], [91.78983307, 25.16753578], [91.78973389, 25.16756058], [91.78960419, 25.16755867], [91.78946686, 25.1675663], [91.78913116, 25.16755295], [91.7884903, 25.16751671], [91.78825378, 25.16752434], [91.78788757, 25.1674614], [91.78742218, 25.16724014], [91.78707886, 25.1670742], [91.78603363, 25.16701889], [91.78497314, 25.1669426], [91.78418732, 25.16685104], [91.78360748, 25.16676521], [91.78281403, 25.16656876], [91.78194427, 25.16637802], [91.7809906, 25.16618347], [91.78026581, 25.1660347], [91.77945709, 25.16545486], [91.77939606, 25.16540718], [91.77874756, 25.16491508], [91.7774353, 25.16429329], [91.77663422, 25.16383362], [91.77573395, 25.16332245], [91.77446747, 25.16328049], [91.77416992, 25.16336632], [91.77400208, 25.16344261], [91.77389526, 25.16351318], [91.77332306, 25.16392708], [91.77321625, 25.16402245], [91.7729187, 25.16433907], [91.77216339, 25.1651783], [91.77204132, 25.16536331], [91.77191925, 25.16553688], [91.77173615, 25.16541481], [91.77174377, 25.16526031], [91.77160645, 25.16521645], [91.77153015, 25.1651516], [91.77144623, 25.16513062], [91.7713623, 25.16513443], [91.77122498, 25.16535759], [91.77115631, 25.16521645], [91.77085876, 25.16540146], [91.77067566, 25.1654911], [91.77022552, 25.16563034], [91.76982117, 25.16584015], [91.7697525, 25.16590118], [91.76940155, 25.16617966], [91.76889038, 25.16606522], [91.76863098, 25.16626167], [91.76820374, 25.16635513], [91.76792145, 25.16637802], [91.76778412, 25.166399], [91.76735687, 25.16640091], [91.76712799, 25.16643143], [91.76659393, 25.16697311], [91.76629639, 25.16728973], [91.76622772, 25.16736221], [91.76623535, 25.16761971], [91.76499939, 25.16754532], [91.7639389, 25.16734695], [91.76344299, 25.1664257], [91.76208496, 25.16727066], [91.76132965, 25.16748619], [91.7611084, 25.16754913], [91.76097107, 25.16759109], [91.76056671, 25.16769981], [91.76025391, 25.16779327], [91.7598114, 25.16793823], [91.75982666, 25.16827011], [91.75944519, 25.16835213], [91.75891876, 25.168396], [91.75865936, 25.16845322], [91.75846863, 25.16849709], [91.75832367, 25.16866112], [91.75805664, 25.16909027], [91.75788879, 25.16934013], [91.7576828, 25.16963196], [91.75759125, 25.16986847], [91.75730896, 25.17006683], [91.75712585, 25.17036247], [91.75708008, 25.17042923], [91.75692749, 25.17056274], [91.7568512, 25.17061043], [91.75657654, 25.17112732], [91.75640869, 25.17135429], [91.75567627, 25.17146111], [91.75493622, 25.17156601], [91.75376129, 25.17269897], [91.75466156, 25.17293167], [91.75476074, 25.17295837], [91.75476074, 25.17331314], [91.75483704, 25.17359924], [91.75512695, 25.1741581], [91.75512695, 25.17443275], [91.75558472, 25.17522621], [91.75597382, 25.17591858], [91.7563324, 25.17656136], [91.75636292, 25.17670441], [91.75610352, 25.1774292], [91.75595093, 25.17760086], [91.75515747, 25.17749214], [91.75359344, 25.17695045], [91.75267792, 25.17650795], [91.75158691, 25.17601967], [91.75176239, 25.1749897], [91.75094604, 25.17283058], [91.75022125, 25.17181969], [91.74925232, 25.17048264], [91.74681091, 25.1667881], [91.74625397, 25.16596603], [91.74633026, 25.16553116], [91.7463913, 25.16521454], [91.74668884, 25.16462326], [91.74702454, 25.16411209], [91.74741364, 25.1635952], [91.74776459, 25.16306686], [91.74816132, 25.16260338], [91.74887848, 25.16143608], [91.74902344, 25.16119385], [91.74924469, 25.1607933], [91.7495575, 25.16014481], [91.74973297, 25.15938187], [91.74959564, 25.15864372], [91.74951172, 25.15820885], [91.74947357, 25.15803146], [91.74938965, 25.15781784], [91.74929047, 25.15755463], [91.74916077, 25.15722275], [91.74909973, 25.15711594], [91.74892426, 25.15681648], [91.74887085, 25.15672302], [91.74874878, 25.15654945], [91.74856567, 25.15630722], [91.74800873, 25.15592003], [91.74658966, 25.15519524], [91.74602509, 25.15498161], [91.7456665, 25.15473938], [91.74539948, 25.15449715], [91.74539185, 25.15434647], [91.74533844, 25.15289116], [91.7440033, 25.15122032], [91.74356079, 25.15115547], [91.74358368, 25.15055847], [91.74359131, 25.15023232], [91.7436142, 25.1496315], [91.74373627, 25.14912605], [91.74404144, 25.1479187], [91.74398804, 25.14763451], [91.74395752, 25.14744186], [91.74401855, 25.14703178], [91.74395752, 25.14656258], [91.7433548, 25.14605331], [91.74308014, 25.14587212], [91.74256897, 25.14531517], [91.74240112, 25.14498138], [91.74243164, 25.14448929], [91.74385071, 25.14354324], [91.74447632, 25.14307022], [91.74472046, 25.1428566], [91.74584198, 25.14233971], [91.74697113, 25.14173889], [91.74716187, 25.1414299], [91.74772644, 25.14053535], [91.74767303, 25.14044189], [91.74757385, 25.14027214], [91.74704742, 25.14033318], [91.74677277, 25.1403656], [91.74575806, 25.14048767], [91.74436951, 25.14091682], [91.74301147, 25.14128494], [91.74290466, 25.14153671], [91.74256134, 25.14185524], [91.74221039, 25.14175224], [91.74183655, 25.14164352], [91.74166107, 25.14153671], [91.74133301, 25.14168549], [91.74121094, 25.14174843], [91.74084473, 25.14224052], [91.74047089, 25.14239311], [91.73983765, 25.14210701], [91.73971558, 25.14223671], [91.73945618, 25.14236641], [91.73912811, 25.14231682], [91.73896027, 25.14229202], [91.73878479, 25.14245605], [91.73865509, 25.14257622], [91.73843384, 25.1425972], [91.73809814, 25.14263153], [91.73762512, 25.14252853], [91.73751831, 25.14272881], [91.73766327, 25.14284325], [91.73760223, 25.14305878], [91.73751831, 25.14310265], [91.73641205, 25.14368057], [91.73628235, 25.14351082], [91.73616028, 25.14363861], [91.73631287, 25.14391708], [91.73604584, 25.14549446], [91.73596954, 25.14574051], [91.73590851, 25.14587402], [91.7358017, 25.14740753], [91.73577881, 25.14782715], [91.73575592, 25.14832497], [91.7355957, 25.14913177], [91.73539734, 25.14982796], [91.73477173, 25.149786], [91.73434448, 25.14970398], [91.73392487, 25.14958572], [91.73358154, 25.14921761], [91.73282623, 25.14814758], [91.73266602, 25.14791107], [91.73254395, 25.14792252], [91.73196411, 25.14808273], [91.73168945, 25.14822197], [91.73175812, 25.14850616], [91.73213196, 25.14905739], [91.7323761, 25.14944458], [91.7325592, 25.14972878], [91.73288727, 25.1503315], [91.73264313, 25.15038681], [91.7317276, 25.1505909], [91.73165131, 25.15060616], [91.73027039, 25.15091515], [91.72840881, 25.15124893], [91.7266922, 25.1514225], [91.72632599, 25.15146065], [91.72454071, 25.15163803], [91.72276306, 25.15181541], [91.71964264, 25.1521244], [91.71813965, 25.15227509], [91.71646881, 25.15243912], [91.71651459, 25.15276146], [91.71626282, 25.15290833], [91.71619415, 25.15308571], [91.71607208, 25.15333748], [91.71591949, 25.15363121], [91.71559143, 25.15426826], [91.71534729, 25.15490532], [91.71530914, 25.15529251], [91.71517181, 25.15599823], [91.71504974, 25.15656662], [91.71473694, 25.15732765], [91.71442413, 25.15763283], [91.71430969, 25.15766335], [91.71286011, 25.15805626], [91.71212769, 25.15799904], [91.71133423, 25.15804863], [91.71057892, 25.15820885], [91.71009064, 25.15831375], [91.70915985, 25.1587677], [91.70867157, 25.15907288], [91.70852661, 25.15913391], [91.70841217, 25.15915298], [91.70822144, 25.15918159], [91.70774078, 25.15895844], [91.70754242, 25.15886497], [91.70745087, 25.15878677], [91.70728302, 25.15864372], [91.70719147, 25.15856743], [91.70670319, 25.15786552], [91.70619965, 25.15718269], [91.70611572, 25.15714645], [91.70585632, 25.15702438], [91.70540619, 25.15701866], [91.70488739, 25.15725136], [91.7046814, 25.15745163], [91.70453644, 25.1575985], [91.70438385, 25.15782356], [91.70423126, 25.15907097], [91.70433807, 25.1596489], [91.7040329, 25.16007233], [91.70363617, 25.16008568], [91.70352173, 25.1600132], [91.70307159, 25.15947342], [91.70291901, 25.15919876], [91.70236206, 25.157938], [91.70227051, 25.1576786], [91.70222473, 25.15754509], [91.70188141, 25.15712547], [91.70178223, 25.15707588], [91.70147705, 25.15691948], [91.70068359, 25.15656662], [91.70050812, 25.15634155], [91.70045471, 25.15607071], [91.70057678, 25.15551567], [91.70072937, 25.15532112], [91.70103455, 25.15504837], [91.7013092, 25.15486908], [91.70139313, 25.15481186], [91.70174408, 25.15469551], [91.70278931, 25.15412712], [91.70306396, 25.1537571], [91.70318604, 25.15359497], [91.70331573, 25.15306282], [91.70333862, 25.15281487], [91.70336914, 25.15190315], [91.70352936, 25.15153885], [91.70363617, 25.15133476], [91.70375061, 25.15102959], [91.70391846, 25.15096855], [91.70399475, 25.15094185], [91.70410156, 25.15088844], [91.70422363, 25.15084076], [91.70432281, 25.15080452], [91.70450592, 25.15076065], [91.70465088, 25.1507225], [91.70478821, 25.15055847], [91.70490265, 25.15017128], [91.70491791, 25.1500988], [91.70484924, 25.14994621], [91.70479584, 25.14982224], [91.70419312, 25.14949989], [91.70262146, 25.14715004], [91.70127106, 25.14698029], [91.70020294, 25.14683914], [91.69930267, 25.14502907], [91.69921875, 25.14439011], [91.69880676, 25.14149094], [91.69584656, 25.13908005], [91.69265747, 25.13840103], [91.69235229, 25.13774872], [91.69231415, 25.13766861], [91.69194794, 25.13737869], [91.69185638, 25.13733101], [91.69163513, 25.13721657], [91.69152069, 25.13720322], [91.69081879, 25.13724709], [91.69041443, 25.13726234], [91.68960571, 25.13708305], [91.68920898, 25.13698578], [91.6884613, 25.13731384], [91.68811798, 25.13730431], [91.68790436, 25.13738823], [91.68779755, 25.13736534], [91.68756866, 25.13765907], [91.68742371, 25.13784599], [91.68621826, 25.13784981], [91.68627167, 25.13758659], [91.68585205, 25.13734818], [91.68526459, 25.13701248], [91.68476105, 25.13672638], [91.6835022, 25.13639259], [91.68243408, 25.13605118], [91.68186951, 25.13586807], [91.68120575, 25.13546181], [91.68062592, 25.13506889], [91.67919159, 25.13590431], [91.6788559, 25.13619232], [91.67791748, 25.13676834], [91.67744446, 25.13709641], [91.67665863, 25.13741493], [91.67521667, 25.13692093], [91.67262268, 25.13528824], [91.67080688, 25.1334095], [91.67003632, 25.13159943], [91.6684494, 25.13027954], [91.66530609, 25.1304512], [91.66472626, 25.13086128], [91.66480255, 25.12998962], [91.6648407, 25.12992668], [91.6648941, 25.12983131], [91.66488647, 25.12911224], [91.66490173, 25.1289463], [91.66493225, 25.12867165], [91.66494751, 25.12855148], [91.6647644, 25.12852097], [91.66399384, 25.12845802], [91.66351318, 25.12843895], [91.66318512, 25.12837791], [91.66192627, 25.12789917], [91.66105652, 25.12735939], [91.66093445, 25.12723351], [91.6605835, 25.12714767], [91.66007996, 25.12712669], [91.65966797, 25.12724686], [91.65940094, 25.12748528], [91.65913391, 25.12832069], [91.65869141, 25.12886429], [91.65855408, 25.12900162], [91.65833282, 25.12963867], [91.6583786, 25.13027763], [91.65892029, 25.13076782], [91.65919495, 25.13109016], [91.65930939, 25.13127136], [91.65914154, 25.13120079], [91.6550293, 25.12945938], [91.65172577, 25.12756729], [91.65125275, 25.1273098], [91.65115356, 25.12719154], [91.65032196, 25.12739563], [91.64958191, 25.12766075], [91.64945221, 25.12769508], [91.64862061, 25.12791252], [91.64854431, 25.12791061], [91.64845276, 25.1279068], [91.64680481, 25.12709427], [91.64537048, 25.12733269], [91.64469147, 25.12664795], [91.64457703, 25.12654877], [91.64437866, 25.12636948], [91.64356995, 25.12565422], [91.64308167, 25.12504005], [91.64295197, 25.12487411], [91.64244843, 25.12397957], [91.64216614, 25.12347412], [91.64199066, 25.12316704], [91.64161682, 25.12306595], [91.64057159, 25.12299538], [91.64028168, 25.12304115], [91.63964844, 25.12364388], [91.63897705, 25.12324142], [91.63847351, 25.123106], [91.63828278, 25.12310791], [91.63785553, 25.12265396], [91.63657379, 25.12282753], [91.63619995, 25.12297821], [91.63583374, 25.12325287], [91.63581085, 25.1236763], [91.63569641, 25.12411118], [91.63552856, 25.12425995], [91.6352005, 25.12412453], [91.63505554, 25.12393761], [91.63488007, 25.12381744], [91.63451385, 25.12380409], [91.63398743, 25.123909], [91.63389587, 25.12397385], [91.63389587, 25.12418365], [91.6337738, 25.12432098], [91.63357544, 25.12446022], [91.63289642, 25.12439919], [91.63265991, 25.12442589], [91.63258362, 25.12443352], [91.63205719, 25.12449265], [91.63108063, 25.12466812], [91.63087463, 25.1246891], [91.62979889, 25.12479782], [91.62953949, 25.12487411], [91.62911224, 25.12499809], [91.62692261, 25.12552643], [91.62665558, 25.12566948], [91.62602997, 25.12610435], [91.62521362, 25.12680817], [91.62460327, 25.12726593], [91.62411499, 25.12754631], [91.62332153, 25.127882], [91.62310791, 25.12801743], [91.62295532, 25.1282692], [91.62272644, 25.12867737], [91.62258911, 25.12891579], [91.622612, 25.12901306], [91.62265015, 25.12916756], [91.62264252, 25.12949371], [91.62239075, 25.13067055], [91.6223526, 25.13096046], [91.62232971, 25.13109398], [91.62231445, 25.13149643], [91.6224823, 25.13212204], [91.62261963, 25.13246536], [91.62274933, 25.13277054], [91.62306213, 25.13425255], [91.62295532, 25.13571358], [91.62297058, 25.13593483], [91.62300873, 25.13613319], [91.62308502, 25.13649178], [91.62306976, 25.13663864], [91.6227417, 25.1381588], [91.62268829, 25.13840675], [91.62249756, 25.13855171], [91.62199402, 25.13894081], [91.62173462, 25.13915634], [91.62161255, 25.13942337], [91.62160492, 25.139534], [91.621521, 25.14010239], [91.62128448, 25.14056587], [91.62129211, 25.14075279], [91.62162018, 25.14151192], [91.62138367, 25.14200211], [91.62123108, 25.142416], [91.62122345, 25.14254761], [91.62133789, 25.14304543], [91.62142181, 25.14325142], [91.62141418, 25.14351463], [91.62081146, 25.14369774], [91.62034607, 25.14383888], [91.62010956, 25.14390945], [91.61891174, 25.14424133], [91.61703491, 25.14476585], [91.61614227, 25.14500999], [91.6157074, 25.14513016], [91.61536407, 25.14522362], [91.61506653, 25.14468002], [91.61470032, 25.14380646], [91.61450195, 25.14334488], [91.61434937, 25.14298439], [91.61404419, 25.14247131], [91.61389923, 25.14217186], [91.61374664, 25.14187622], [91.6133194, 25.14113617], [91.61312866, 25.14120293], [91.61260223, 25.14138794], [91.61244202, 25.14108467], [91.61221313, 25.14106941], [91.61186981, 25.14122391], [91.61156464, 25.14163208], [91.61159515, 25.14204025], [91.61174011, 25.14232254], [91.6120224, 25.14258957], [91.61240387, 25.1428318], [91.61239624, 25.14305496], [91.61239624, 25.14339447], [91.61228943, 25.14419556], [91.6121521, 25.14480782], [91.61207581, 25.14513969], [91.61188507, 25.14528275], [91.61160278, 25.14508057], [91.61003876, 25.14397049], [91.60714722, 25.14305115], [91.60682678, 25.14361954], [91.60643768, 25.14430237], [91.60612488, 25.14363289], [91.60599518, 25.14328766], [91.60587311, 25.14273262], [91.60475159, 25.14223099], [91.60446167, 25.14160538], [91.60430908, 25.14126778], [91.60371399, 25.14032555], [91.60351563, 25.14037514], [91.60321808, 25.14070892], [91.60284424, 25.14139557], [91.60241699, 25.14219284], [91.60224915, 25.14241982], [91.60160828, 25.14369965], [91.60137177, 25.144207], [91.60057831, 25.14593506], [91.60048676, 25.14618683], [91.60028076, 25.14691925], [91.60029602, 25.14716148], [91.59999847, 25.14834213], [91.599823, 25.1491909], [91.59951019, 25.15068626], [91.59938812, 25.15129662], [91.60097504, 25.15293694], [91.60158539, 25.15368843], [91.60190582, 25.1541214], [91.60228729, 25.15457344], [91.60248566, 25.15485764], [91.60259247, 25.15504074], [91.60275269, 25.15574455], [91.6031723, 25.15755272], [91.60344696, 25.15840912], [91.60349274, 25.15873337], [91.60355377, 25.1591301], [91.60335541, 25.15914536], [91.60139465, 25.15924644], [91.60044098, 25.15921974], [91.59992981, 25.15929031], [91.59984589, 25.15956688], [91.59990692, 25.15972519], [91.60043335, 25.16036797], [91.60063934, 25.16057587], [91.60106659, 25.16100883], [91.60124207, 25.16116524], [91.60150146, 25.1614151], [91.60206604, 25.16210747], [91.6021347, 25.16220665], [91.60223389, 25.16239357], [91.60293579, 25.16392899], [91.60329437, 25.16513443], [91.603302, 25.16526413], [91.60317993, 25.16568184], [91.6036911, 25.16688156], [91.60396576, 25.16755295], [91.60414124, 25.16761589], [91.60434723, 25.16769218], [91.60528564, 25.16809464], [91.60647583, 25.16885185], [91.60680389, 25.16911125], [91.60704041, 25.16932487], [91.60719299, 25.16939545], [91.60818481, 25.16985321], [91.60960388, 25.17009544], [91.6102829, 25.17000008], [91.61123657, 25.17002869], [91.61148071, 25.17003632], [91.6121521, 25.17033005], [91.6124649, 25.17031288], [91.61315918, 25.17004776], [91.6140213, 25.1696949], [91.61438751, 25.16969681], [91.61465454, 25.16969872], [91.61536407, 25.16970062], [91.61528015, 25.17041016], [91.6151886, 25.1710453], [91.61516571, 25.17192078], [91.61511993, 25.17374992], [91.61511993, 25.17435646], [91.61511993, 25.17485619], [91.61505127, 25.1748867], [91.61471558, 25.17503929], [91.61411285, 25.17534828], [91.60824585, 25.17435074], [91.60616302, 25.1742382], [91.60612488, 25.17411423], [91.60540771, 25.17376518], [91.60516357, 25.17400932], [91.60439301, 25.17404556], [91.60294342, 25.17405701], [91.6029129, 25.17421532], [91.59856415, 25.17425346], [91.59807587, 25.17429161], [91.59727478, 25.17435646], [91.59629822, 25.17448807], [91.5956955, 25.17443085], [91.59470367, 25.17384911], [91.59449005, 25.17372131], [91.59429932, 25.1737957], [91.59354401, 25.17408371], [91.59324646, 25.17416763], [91.59238434, 25.17434502], [91.59197235, 25.17443085], [91.59151459, 25.17431831], [91.59122467, 25.17424965], [91.59123993, 25.17386055], [91.59114838, 25.17377853], [91.59077454, 25.17376328], [91.59036255, 25.17306709], [91.59021759, 25.17282677], [91.59013367, 25.1726284], [91.58983612, 25.17256546], [91.58969116, 25.17201996], [91.58906555, 25.1717701], [91.58847809, 25.17172432], [91.58809662, 25.17176056], [91.58681488, 25.17233276], [91.58660126, 25.17228699], [91.58631897, 25.17189026], [91.58621979, 25.17173958], [91.58605957, 25.17162895], [91.58449554, 25.17178345], [91.58306885, 25.1719265], [91.58106232, 25.17214775], [91.58081055, 25.17261887], [91.58017731, 25.17252731], [91.57817078, 25.16819954], [91.57637787, 25.1643219], [91.5791626, 25.16060066], [91.57572937, 25.16072464], [91.57588196, 25.16056824], [91.5762558, 25.16003418], [91.57598877, 25.15974808], [91.57591248, 25.15966606], [91.57585144, 25.15960121], [91.57571411, 25.15968323], [91.57557678, 25.15976334], [91.57518005, 25.15989685], [91.5749054, 25.15990829], [91.57396698, 25.1598053], [91.57379913, 25.15990639], [91.57339478, 25.16020966], [91.57314301, 25.16012955], [91.56919098, 25.15942955], [91.56694794, 25.15875053], [91.56115723, 25.15121078], [91.55885315, 25.14929008], [91.55686951, 25.14884567], [91.54627991, 25.14647102], [91.53777313, 25.14437294], [91.53353882, 25.1441803], [91.52954865, 25.14398003], [91.5218811, 25.14464188], [91.51819611, 25.1449585], [91.51364899, 25.1453495], [91.51258087, 25.14516068], [91.51026917, 25.14472961], [91.50830841, 25.14324951], [91.50672913, 25.14068031], [91.50595856, 25.139431], [91.50463867, 25.13729668], [91.5042572, 25.1366806], [91.50263214, 25.13548088], [91.49946594, 25.13541985], [91.49932861, 25.13544464], [91.49882507, 25.1355381], [91.49827576, 25.1356411], [91.49693298, 25.13589096], [91.49684906, 25.13590622], [91.49607086, 25.13579941], [91.49562836, 25.13578987], [91.49552155, 25.13580322], [91.49514008, 25.135849], [91.49478912, 25.13615608], [91.49427795, 25.13638306], [91.4925766, 25.13669968], [91.49038696, 25.13620377], [91.48995209, 25.13591766], [91.48970795, 25.13568306], [91.48920441, 25.13521576], [91.48886108, 25.13546753], [91.4884491, 25.13566589], [91.48812866, 25.13573074], [91.48741913, 25.13576698], [91.48682404, 25.13563156], [91.48674011, 25.13578606], [91.48651886, 25.13593292], [91.48542786, 25.13631058], [91.48512268, 25.13632965], [91.48236847, 25.13557053], [91.48240662, 25.13525963], [91.48255157, 25.13406944], [91.48152161, 25.13401985], [91.47843933, 25.13387108], [91.47813416, 25.13387108], [91.47732544, 25.13401222], [91.47690582, 25.13386726], [91.47640228, 25.13373375], [91.47520447, 25.13354301], [91.47432709, 25.13351822], [91.47190094, 25.13363838], [91.47055054, 25.13374901], [91.47032928, 25.13383102], [91.4699173, 25.13412094], [91.46949005, 25.13446808], [91.46915436, 25.13445091], [91.46756744, 25.1343708], [91.46643066, 25.13440514], [91.46457672, 25.13495827], [91.4641571, 25.13491249], [91.46411133, 25.13576126], [91.46463013, 25.13668442], [91.4647522, 25.13689995], [91.4649353, 25.13710785], [91.46542358, 25.13733292], [91.4655304, 25.13738251], [91.4657135, 25.13737488], [91.46604156, 25.13735771], [91.46682739, 25.13736916], [91.4675827, 25.13758278], [91.46800232, 25.13796616], [91.46851349, 25.13862419], [91.46870422, 25.1389389], [91.46920776, 25.13965034], [91.46977234, 25.13972282], [91.4703598, 25.13983536], [91.47041321, 25.1403141], [91.47026825, 25.14066315], [91.47000885, 25.14124489], [91.46972656, 25.14117432], [91.46915436, 25.14103699], [91.46863556, 25.14099503], [91.46792603, 25.14172554], [91.46787262, 25.14213371], [91.4678421, 25.14236641], [91.46768188, 25.14299202], [91.46740723, 25.14361954], [91.4669342, 25.14391327], [91.46720123, 25.14450073], [91.46733856, 25.1448822], [91.46743774, 25.14530563], [91.4675293, 25.14565659], [91.4675827, 25.1460762], [91.46794128, 25.14645958], [91.4680481, 25.14657211], [91.46805573, 25.14668655], [91.46798706, 25.14682388], [91.46775818, 25.147295], [91.46788788, 25.14740944], [91.46840668, 25.14777946], [91.46850586, 25.14790916], [91.46869659, 25.14817047], [91.46862793, 25.14840126], [91.46853638, 25.14853477], [91.4681778, 25.1490593], [91.4682312, 25.14932823], [91.46835327, 25.14952087], [91.46848297, 25.14972687], [91.46865845, 25.14997673], [91.46791077, 25.14980125], [91.4621582, 25.14851952], [91.45652008, 25.14803123], [91.45065308, 25.14818001], [91.445961, 25.14910126], [91.44288635, 25.15071869], [91.44272614, 25.15068626], [91.44232178, 25.15039635], [91.44204712, 25.15025902], [91.44109344, 25.1498642], [91.44090271, 25.14980125], [91.44072723, 25.14975357], [91.44049072, 25.14975357], [91.44034576, 25.15003204], [91.44004059, 25.15058327], [91.43992615, 25.15098381], [91.43991089, 25.15105438], [91.43978119, 25.15108871], [91.43923187, 25.15123177], [91.43912506, 25.15146828], [91.4389267, 25.15168571], [91.43856049, 25.15216255], [91.43845367, 25.15216446], [91.43732452, 25.15320015], [91.43726349, 25.15386009], [91.43714142, 25.15422821], [91.43659973, 25.15426064], [91.43624115, 25.15427971], [91.43550873, 25.15501213], [91.4354248, 25.15509415], [91.43488312, 25.15550995], [91.43482208, 25.15555763], [91.43457031, 25.15569115], [91.43424225, 25.15576744], [91.43390656, 25.15584564], [91.43358612, 25.15621376], [91.43341827, 25.15636063], [91.43287659, 25.1567688], [91.43264771, 25.15687752], [91.43257904, 25.15690613], [91.43247223, 25.15681839], [91.43236542, 25.15680695], [91.43188477, 25.15699387], [91.43134308, 25.15720367], [91.43051147, 25.15737343], [91.43013, 25.15739632], [91.42996216, 25.15737152], [91.42974854, 25.1573391], [91.42952728, 25.15733528], [91.42912292, 25.15740395], [91.42849731, 25.15751076], [91.42725372, 25.15736771], [91.42631531, 25.15728951], [91.42610931, 25.15731621], [91.42544556, 25.15708733], [91.42514801, 25.15704536], [91.42494965, 25.15717697], [91.42485809, 25.15729904], [91.42462158, 25.1575985], [91.42434692, 25.1582737], [91.42419434, 25.15830612], [91.42388153, 25.15820122], [91.42378998, 25.15823746], [91.42359161, 25.15831375], [91.42350006, 25.15846825], [91.42344666, 25.15887642], [91.42338562, 25.15956688], [91.4233551, 25.15969086], [91.4230423, 25.1606369], [91.42294312, 25.16082954], [91.42279053, 25.16111374], [91.42249298, 25.16159248], [91.42256927, 25.16183472], [91.42259979, 25.1620121], [91.42261505, 25.16212654], [91.42242432, 25.16233826], [91.42230988, 25.16247177], [91.42201233, 25.16266632], [91.42189026, 25.1627636], [91.42158508, 25.16299629], [91.42137146, 25.16305923], [91.42120361, 25.16302109], [91.42115784, 25.16308022], [91.42053223, 25.16385078], [91.41975403, 25.16482162], [91.41880035, 25.16599274], [91.41814423, 25.16680527], [91.4178772, 25.16713524], [91.41603088, 25.16942215], [91.41527557, 25.17036438], [91.41456604, 25.17124176], [91.41419983, 25.17075348], [91.41388702, 25.17040634], [91.41368103, 25.17022133], [91.41313934, 25.16986465], [91.41243744, 25.16959953], [91.41207886, 25.1695385], [91.4119873, 25.1693325], [91.4119873, 25.16892815], [91.41179657, 25.16869354], [91.41186523, 25.16855431], [91.4122467, 25.16813087], [91.41277313, 25.16758919], [91.41277313, 25.16734695], [91.41249847, 25.16689301], [91.41196442, 25.16600609], [91.41149902, 25.16506004], [91.41143799, 25.16493988], [91.41100311, 25.16409111], [91.4108429, 25.16378021], [91.40990448, 25.16387558], [91.40966034, 25.1639328], [91.4090271, 25.16402245], [91.40886688, 25.16404533], [91.40879059, 25.16410828], [91.40853119, 25.16431808], [91.40796661, 25.16483116], [91.40766907, 25.16514969], [91.40711975, 25.16572571], [91.40672302, 25.16621399], [91.40575409, 25.16612434], [91.40548706, 25.16609764], [91.40457916, 25.16582298], [91.40441132, 25.16577148], [91.40399933, 25.16572762], [91.40372467, 25.16569901], [91.40350342, 25.16569328], [91.40261078, 25.16555977], [91.4024353, 25.16579247], [91.40179443, 25.1656971], [91.40086365, 25.16549683], [91.3996048, 25.16517448], [91.39936066, 25.16509056], [91.3990097, 25.16496468], [91.39886475, 25.16482735], [91.39855194, 25.16457176], [91.39844513, 25.16463089], [91.39745331, 25.1651783], [91.39678955, 25.1654911], [91.396492, 25.16556931], [91.39602661, 25.16570473], [91.39454651, 25.16609573], [91.39401245, 25.16626358], [91.39270782, 25.16659737], [91.39135742, 25.16690636], [91.3911438, 25.16695786], [91.39048767, 25.16711617], [91.38976288, 25.16730118], [91.38903809, 25.16752434], [91.38894653, 25.16757584], [91.38884735, 25.16659164], [91.38861084, 25.16710472], [91.38853455, 25.16750908], [91.38848114, 25.16782761], [91.38774109, 25.16822433], [91.38622284, 25.16904068], [91.38453674, 25.1698494], [91.38435364, 25.16993713], [91.38374329, 25.16984558], [91.38323975, 25.16973686], [91.38265991, 25.16926384], [91.38202667, 25.16874313], [91.38156891, 25.16843987], [91.38114166, 25.16834641], [91.3796463, 25.16826439], [91.3779068, 25.16815186], [91.37739563, 25.16813469], [91.37614441, 25.16809273], [91.37592316, 25.16815186], [91.37549591, 25.16826248], [91.37454224, 25.16858482], [91.37419128, 25.16867256], [91.37401581, 25.16874123], [91.37387085, 25.16879845], [91.37334442, 25.16902733], [91.37274933, 25.1693306], [91.37205505, 25.16959953], [91.37177277, 25.1697216], [91.3711319, 25.1700592], [91.36955261, 25.170784], [91.36875153, 25.17071533], [91.36843872, 25.17082405], [91.36814117, 25.17100143], [91.36769104, 25.1713028], [91.36685181, 25.17253113], [91.36651611, 25.17305946], [91.36633301, 25.17331505], [91.36571503, 25.17411804], [91.36527252, 25.1746273], [91.36508942, 25.17482185], [91.36508179, 25.17518616], [91.36506653, 25.17579842], [91.36476898, 25.17694664], [91.36471558, 25.17728996], [91.36464691, 25.17753029], [91.36444092, 25.17801476], [91.36418915, 25.17807388], [91.36373138, 25.17816544], [91.36301422, 25.17824173], [91.36211395, 25.17823601], [91.36110687, 25.17799759], [91.36064148, 25.17770958], [91.3596344, 25.17692375], [91.35959625, 25.17679787], [91.35939789, 25.17611694], [91.35929108, 25.17592239], [91.35900116, 25.17558289], [91.35884094, 25.17546654], [91.35832977, 25.17530632], [91.35804749, 25.17520714], [91.35739136, 25.17489815], [91.3571167, 25.17462158], [91.35643768, 25.17377281], [91.35569763, 25.17307854], [91.35531616, 25.17283249], [91.35476685, 25.17234802], [91.35448456, 25.1721077], [91.35429382, 25.17194176], [91.35366821, 25.17133331], [91.35354614, 25.1715374], [91.35346985, 25.17152214], [91.35321808, 25.17199898], [91.35295868, 25.17248344], [91.35240173, 25.17353821], [91.35230255, 25.17375565], [91.35225677, 25.17393303], [91.35211182, 25.1744957], [91.35198975, 25.17496872], [91.35190582, 25.17528534], [91.35168457, 25.17576218], [91.35148621, 25.17592239], [91.35107422, 25.17592621], [91.35072327, 25.17588425], [91.35041046, 25.17580605], [91.34954834, 25.17540932], [91.34931183, 25.1752758], [91.34850311, 25.17466354], [91.34804535, 25.17446518], [91.34770966, 25.1744175], [91.34718323, 25.17429161], [91.34580231, 25.17429543], [91.34522247, 25.17428017], [91.34375, 25.17415619], [91.34324646, 25.17406082], [91.3429184, 25.17398453], [91.3419342, 25.17371941], [91.34054565, 25.17369843], [91.34014893, 25.17366028], [91.33912659, 25.17366982], [91.33712006, 25.17365074], [91.33680725, 25.17378235], [91.33624268, 25.17401314], [91.33566284, 25.17424965], [91.33519745, 25.17459679], [91.33503723, 25.17481804], [91.33468628, 25.17604065], [91.33443451, 25.17675972], [91.33329773, 25.17710495], [91.33303833, 25.17718315], [91.33232117, 25.17739677], [91.33130646, 25.17760468], [91.33094788, 25.17753792], [91.32998657, 25.1771698], [91.32966614, 25.17703056], [91.32910156, 25.17684746], [91.32832336, 25.17657852], [91.32752228, 25.17631149], [91.32739258, 25.17629814], [91.32713318, 25.17626953], [91.32694244, 25.17629623], [91.32665253, 25.1764183], [91.32639313, 25.1765976], [91.32602692, 25.17712975], [91.32591248, 25.1778698], [91.32584381, 25.17832375], [91.32536316, 25.17951393], [91.32527161, 25.17974663], [91.32478333, 25.1803894], [91.3242569, 25.18083191], [91.32380676, 25.18120193], [91.32265472, 25.18190575], [91.32228088, 25.18207741], [91.32123566, 25.18239975], [91.32097626, 25.18247986], [91.32022858, 25.18247986], [91.32017517, 25.18234253], [91.31955719, 25.18248367], [91.31937408, 25.18264771], [91.31903076, 25.18323517], [91.31897736, 25.18331909], [91.31768036, 25.18379211], [91.31671143, 25.18384361], [91.31635284, 25.18386269], [91.31571198, 25.18394279], [91.31374359, 25.18410873], [91.31265259, 25.18421555], [91.31040192, 25.18411636], [91.30886078, 25.18395615], [91.30789948, 25.18377686], [91.30765533, 25.1836834], [91.30670929, 25.18315125], [91.3065033, 25.1830349], [91.30591583, 25.18272781], [91.3045578, 25.18270683], [91.30439758, 25.18272018], [91.30268097, 25.18336296], [91.30054474, 25.18416595], [91.30005646, 25.18435097], [91.29975891, 25.18432999], [91.29886627, 25.18426323], [91.29663849, 25.18408966], [91.29388428, 25.18396568], [91.29240417, 25.18392372], [91.29206085, 25.18410492], [91.29151154, 25.18447495], [91.29019928, 25.18542099], [91.28952789, 25.18587685], [91.28835297, 25.18661118], [91.2876358, 25.18617439], [91.28664398, 25.1855793], [91.28647614, 25.1854763]]]}}, {\\\"id\\\": \\\"20\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.23_1\\\", \\\"HASC_1\\\": \\\"IN.MZ\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Mizoram\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -4.0, \\\"dalys_apm25_rate_6cod_mean_total\\\": 373.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -899.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -526.0, \\\"geo-id\\\": 20, \\\"hpm25_child_popweighted\\\": -105.4, \\\"hpm25_female_popweighted\\\": -121.1, \\\"hpm25_male_popweighted\\\": -87.2, \\\"location\\\": \\\"Mizoram\\\", \\\"mort_apm25_6cod_mean_total\\\": 175.0, \\\"mort_hpm25_6cod_mean_total\\\": -409.0, \\\"mort_tpm25_6cod_mean_total\\\": -234.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[92.856987, 22.06563187], [92.85463715, 22.06488991], [92.84902191, 22.06235123], [92.84464264, 22.06343269], [92.84464264, 22.06813049], [92.84144592, 22.07201004], [92.8365097, 22.07635117], [92.83249664, 22.07644081], [92.82563782, 22.07966995], [92.82028961, 22.09033966], [92.8170929, 22.09556961], [92.81040955, 22.09764099], [92.80332947, 22.10225105], [92.79515839, 22.10621071], [92.78878784, 22.10890961], [92.78312683, 22.10863113], [92.77741241, 22.1097908], [92.77675629, 22.11001587], [92.77374268, 22.11104965], [92.77305603, 22.11178017], [92.76925659, 22.11584091], [92.77012634, 22.12306976], [92.76567078, 22.12631989], [92.751297, 22.1327095], [92.74314117, 22.13594818], [92.73781586, 22.13900948], [92.73275757, 22.14958954], [92.71788788, 22.15262985], [92.70797729, 22.15351105], [92.70343781, 22.15378189], [92.70034027, 22.14964294], [92.69935608, 22.1483326], [92.70062256, 22.13838959], [92.69966888, 22.12239075], [92.69896698, 22.11822128], [92.69713593, 22.09930992], [92.69754791, 22.08622169], [92.69695282, 22.08088112], [92.69355774, 22.07724953], [92.69132233, 22.08113098], [92.69062805, 22.09478951], [92.68955994, 22.1070919], [92.68644714, 22.10942078], [92.68383789, 22.10534859], [92.68453217, 22.09205055], [92.68530273, 22.08555031], [92.68550873, 22.08173943], [92.68578339, 22.07650948], [92.68685913, 22.06991005], [92.68725586, 22.06312752], [92.68628693, 22.05859947], [92.68667603, 22.05001068], [92.68997955, 22.04097939], [92.6894989, 22.0357399], [92.6879425, 22.03239059], [92.68817139, 22.03071976], [92.68843842, 22.02858925], [92.68727112, 22.0238781], [92.68435669, 22.01791], [92.6807785, 22.01419067], [92.67681122, 22.01409149], [92.67154694, 22.01471138], [92.66322327, 22.01550102], [92.65924072, 22.01472282], [92.64929962, 22.00341415], [92.6446991, 21.99818993], [92.64100647, 21.99221039], [92.63791656, 21.98867035], [92.63006592, 21.98495293], [92.62895203, 21.98461723], [92.61812592, 21.98138046], [92.61231995, 21.98028946], [92.61193085, 21.98184967], [92.61178589, 21.9817028], [92.60968018, 21.97683716], [92.60926819, 21.97923088], [92.60923004, 21.98274994], [92.60878754, 21.98384285], [92.60877991, 21.98409462], [92.61048889, 21.98500443], [92.61130524, 21.98616982], [92.61185455, 21.98840332], [92.61183929, 21.99004555], [92.6126709, 21.9913826], [92.61228943, 21.99279213], [92.61045837, 21.99459839], [92.61003876, 21.99501228], [92.61024475, 21.99621201], [92.60983276, 21.99775505], [92.60997009, 21.99818993], [92.60929871, 21.9984169], [92.60876465, 21.99947357], [92.60635376, 21.99961281], [92.60577393, 21.99964523], [92.60578156, 21.99996376], [92.60579681, 22.00054359], [92.60424805, 22.00224686], [92.6025238, 22.00336838], [92.60250092, 22.00427628], [92.60144806, 22.00697708], [92.59914398, 22.00862885], [92.59914398, 22.00904083], [92.59804535, 22.01124763], [92.597435, 22.01196098], [92.597435, 22.01211166], [92.59745026, 22.01298332], [92.59764862, 22.01314926], [92.59902191, 22.01429749], [92.5990448, 22.01539612], [92.59867859, 22.01641655], [92.5993042, 22.01816177], [92.59991455, 22.01987457], [92.60054016, 22.0224781], [92.59988403, 22.02490044], [92.59947968, 22.02871895], [92.59815979, 22.02953911], [92.59784698, 22.02973175], [92.59715271, 22.03016281], [92.59660339, 22.03050423], [92.59661102, 22.03060722], [92.59662628, 22.03161049], [92.59451294, 22.03232002], [92.59402466, 22.03248405], [92.59383392, 22.03293037], [92.59335327, 22.03404617], [92.59339905, 22.03628922], [92.5931778, 22.03810883], [92.59263611, 22.04113007], [92.59352875, 22.04196358], [92.59910583, 22.04241371], [92.59786224, 22.04454041], [92.59790802, 22.04681587], [92.59785461, 22.0479393], [92.59837341, 22.04939842], [92.60027313, 22.05315781], [92.60033417, 22.0559864], [92.60035706, 22.05781746], [92.60018921, 22.0590992], [92.60089111, 22.06030846], [92.60115051, 22.06050491], [92.60227203, 22.06137085], [92.60263824, 22.06185913], [92.60220337, 22.06214714], [92.60119629, 22.06163788], [92.60079193, 22.06162453], [92.59844208, 22.0615406], [92.59622955, 22.06199837], [92.59528351, 22.06219292], [92.59479523, 22.06275558], [92.59365845, 22.06407166], [92.59225464, 22.06564903], [92.59140778, 22.06833839], [92.58979797, 22.07079315], [92.59063721, 22.07176781], [92.5900116, 22.07458496], [92.58959961, 22.07611084], [92.59039307, 22.0777626], [92.59015656, 22.07916832], [92.59056854, 22.08104324], [92.58907318, 22.08129692], [92.58856201, 22.08138466], [92.58622742, 22.08199692], [92.58496094, 22.08248329], [92.58525085, 22.08471489], [92.58532715, 22.08528137], [92.5845108, 22.08592796], [92.58367157, 22.08658981], [92.58322906, 22.08729935], [92.58330536, 22.08748245], [92.58417511, 22.08942795], [92.58410645, 22.09050179], [92.58165741, 22.09178352], [92.58197021, 22.09243774], [92.58274841, 22.09316635], [92.58207703, 22.09474564], [92.58236694, 22.09610176], [92.58253479, 22.09770775], [92.58124542, 22.09943962], [92.58050537, 22.10090637], [92.57924652, 22.10263634], [92.578125, 22.10347366], [92.57781982, 22.10442924], [92.57662201, 22.10511017], [92.57598114, 22.10761452], [92.57579041, 22.1090374], [92.57620239, 22.11008453], [92.57582855, 22.11136246], [92.57483673, 22.1124115], [92.57530975, 22.11531639], [92.57516479, 22.1162014], [92.57369995, 22.11742401], [92.57246399, 22.11977386], [92.56926727, 22.12200356], [92.56729126, 22.12407684], [92.56552887, 22.12449646], [92.56369781, 22.12581825], [92.56250763, 22.12827301], [92.56357574, 22.12998581], [92.56317902, 22.13090134], [92.56381989, 22.13253975], [92.56388092, 22.13374329], [92.56583405, 22.13503647], [92.56668091, 22.13534355], [92.56775665, 22.13573456], [92.56827545, 22.13578415], [92.57097626, 22.13603973], [92.57637787, 22.13595581], [92.57745361, 22.13752937], [92.5762558, 22.13973808], [92.57845306, 22.14200783], [92.57831573, 22.14291382], [92.57820129, 22.14360428], [92.57904816, 22.14324188], [92.5816803, 22.14211273], [92.58395386, 22.14149475], [92.58646393, 22.14103508], [92.58840942, 22.14068604], [92.59149933, 22.13965797], [92.5918808, 22.13953209], [92.59322357, 22.13764191], [92.59096527, 22.1337738], [92.59046936, 22.13334274], [92.58888245, 22.13194656], [92.58930206, 22.13075066], [92.59075165, 22.12911034], [92.59133911, 22.12844467], [92.59308624, 22.12657928], [92.5940094, 22.12558937], [92.59633636, 22.12425232], [92.59959412, 22.12315178], [92.6003952, 22.12365723], [92.6029129, 22.12311554], [92.60548401, 22.1233139], [92.60626221, 22.12473869], [92.60691071, 22.12592888], [92.60775757, 22.12809944], [92.6081543, 22.13005638], [92.6080246, 22.13221931], [92.60777283, 22.13304901], [92.60824585, 22.13454247], [92.6100769, 22.13523483], [92.61054993, 22.13794899], [92.61094666, 22.13853455], [92.61047363, 22.13933563], [92.60980988, 22.14200592], [92.61013794, 22.14414406], [92.60916901, 22.14651489], [92.60882568, 22.14916039], [92.60897064, 22.15167427], [92.60803223, 22.15354919], [92.60795593, 22.15614891], [92.60823059, 22.1584549], [92.60738373, 22.160532], [92.60820007, 22.1612606], [92.60928345, 22.16421127], [92.60788727, 22.16518593], [92.60662079, 22.16607475], [92.60719299, 22.16788101], [92.60755157, 22.16831017], [92.60752869, 22.17087936], [92.60751343, 22.17213249], [92.60683441, 22.17279625], [92.60507965, 22.17274666], [92.60482788, 22.17229652], [92.60476685, 22.17222595], [92.60424042, 22.17166519], [92.60144806, 22.17285538], [92.59857941, 22.17447662], [92.59645844, 22.17547989], [92.59505463, 22.17546463], [92.59666443, 22.1767807], [92.59706116, 22.17762375], [92.59636688, 22.17857742], [92.59568787, 22.17878342], [92.59555054, 22.17882347], [92.59555054, 22.17905998], [92.59555817, 22.18100929], [92.59477997, 22.18106842], [92.59440613, 22.18109703], [92.59545135, 22.18288422], [92.59557343, 22.18296242], [92.59688568, 22.18379021], [92.59488678, 22.18395042], [92.59577942, 22.18525505], [92.59622192, 22.18673134], [92.59574127, 22.18910599], [92.59568787, 22.18938255], [92.59599304, 22.18972206], [92.59654999, 22.1903553], [92.59533691, 22.19351387], [92.59626007, 22.1934967], [92.5953598, 22.19453621], [92.59486389, 22.19649315], [92.59417725, 22.19607544], [92.59397125, 22.19594955], [92.59433746, 22.19730568], [92.5944519, 22.19770622], [92.5951767, 22.19863319], [92.59407043, 22.20166779], [92.59392548, 22.20207214], [92.59400177, 22.20228767], [92.59474945, 22.20441628], [92.59370422, 22.2041893], [92.59368134, 22.20732498], [92.59356689, 22.20856476], [92.59308624, 22.20939827], [92.59263611, 22.21006775], [92.59304047, 22.21072006], [92.59246826, 22.21099472], [92.59248352, 22.21180344], [92.59039307, 22.21332741], [92.59195709, 22.21389198], [92.59142303, 22.21442986], [92.58802795, 22.21603775], [92.58894348, 22.21780968], [92.58807373, 22.21865082], [92.59024811, 22.2210865], [92.59029388, 22.22308159], [92.58908081, 22.22437477], [92.58821869, 22.2239933], [92.58802032, 22.22467422], [92.5892868, 22.22582436], [92.58842468, 22.2269783], [92.58927155, 22.22838211], [92.58840942, 22.23028755], [92.58820343, 22.23074532], [92.58877563, 22.23085022], [92.59059143, 22.23118019], [92.58943939, 22.23204231], [92.59040833, 22.23270035], [92.58901978, 22.23281097], [92.58876801, 22.23283005], [92.58932495, 22.23381042], [92.5904007, 22.23431206], [92.59153748, 22.2348423], [92.58965302, 22.23568153], [92.58961487, 22.23576736], [92.58969879, 22.23651505], [92.58986664, 22.23795128], [92.59066772, 22.23854256], [92.5917511, 22.23933601], [92.59143066, 22.24028587], [92.59124756, 22.24082184], [92.59039307, 22.24451828], [92.59059906, 22.24457169], [92.59169769, 22.24486542], [92.59133148, 22.24677849], [92.5898056, 22.24727249], [92.58905792, 22.24751282], [92.58964539, 22.2479744], [92.59089661, 22.24896431], [92.59049988, 22.24953651], [92.58985901, 22.25046921], [92.58958435, 22.25217438], [92.58995819, 22.25274849], [92.58985138, 22.25365257], [92.5894165, 22.25415802], [92.58986664, 22.25437737], [92.59044647, 22.25466347], [92.59072876, 22.25527191], [92.59036255, 22.2562027], [92.58914185, 22.25584412], [92.58872223, 22.25572205], [92.58879852, 22.25634766], [92.58895111, 22.25754929], [92.58808899, 22.25742912], [92.58738708, 22.25733185], [92.5870285, 22.25868988], [92.58692932, 22.25907326], [92.58660126, 22.25894356], [92.5854187, 22.25847244], [92.585289, 22.25902748], [92.58518219, 22.25946808], [92.58659363, 22.25972176], [92.58476257, 22.26123619], [92.58428955, 22.2616291], [92.58467102, 22.26360893], [92.5848465, 22.26450729], [92.58686829, 22.26409149], [92.58493805, 22.26516533], [92.58432007, 22.26744652], [92.58099365, 22.26928139], [92.58257294, 22.27061462], [92.58319855, 22.27274895], [92.58228302, 22.27416039], [92.58081818, 22.27357674], [92.58076477, 22.27485847], [92.58071899, 22.27588272], [92.58071136, 22.27603722], [92.58342743, 22.2762928], [92.58325958, 22.27739334], [92.58528137, 22.27654839], [92.58641815, 22.2768898], [92.58509827, 22.27733421], [92.58430481, 22.27848625], [92.58441925, 22.27936935], [92.5848999, 22.27988434], [92.58598328, 22.28001595], [92.58653259, 22.28040314], [92.58540344, 22.28075409], [92.58427429, 22.28169823], [92.58182526, 22.28184319], [92.58167267, 22.28339386], [92.58254242, 22.28428268], [92.5840683, 22.28449249], [92.58429718, 22.28481865], [92.58329773, 22.28578568], [92.58109283, 22.28660965], [92.5827179, 22.28798294], [92.58210754, 22.28923225], [92.5812149, 22.29069328], [92.58261108, 22.29120255], [92.58283234, 22.2947979], [92.58268738, 22.29656601], [92.58272552, 22.29841423], [92.58343506, 22.29922485], [92.58139038, 22.30038643], [92.58182526, 22.30216026], [92.58126831, 22.30202484], [92.58101654, 22.30195999], [92.58074951, 22.30268097], [92.58068085, 22.3028698], [92.58057404, 22.30315781], [92.58166504, 22.30288887], [92.58202362, 22.30280113], [92.58347321, 22.30414391], [92.58227539, 22.3037529], [92.58159637, 22.3038044], [92.58057404, 22.3038826], [92.58062744, 22.30448341], [92.58074951, 22.30592728], [92.5800705, 22.30607605], [92.5796814, 22.30615997], [92.58092499, 22.30669022], [92.58113098, 22.30677795], [92.58144379, 22.30871964], [92.57936859, 22.30982971], [92.57796478, 22.3104744], [92.57792664, 22.31067085], [92.57769012, 22.3120079], [92.5789032, 22.31107712], [92.58000946, 22.31185722], [92.58026886, 22.31204224], [92.57994843, 22.31218529], [92.57854462, 22.31281662], [92.57989502, 22.31479836], [92.58000946, 22.31497574], [92.5794754, 22.31542206], [92.57796478, 22.31666374], [92.57892609, 22.31800842], [92.5796814, 22.31875229], [92.58045959, 22.31951523], [92.57946777, 22.32098579], [92.58122253, 22.32180405], [92.57858276, 22.3236084], [92.57997131, 22.32401276], [92.58028412, 22.32519722], [92.57836914, 22.32544518], [92.57686615, 22.32524681], [92.57673645, 22.32522774], [92.57671356, 22.32533836], [92.57644653, 22.32676125], [92.57630157, 22.32980919], [92.57588196, 22.33151627], [92.57434082, 22.3321228], [92.57577515, 22.33283806], [92.5763092, 22.33348846], [92.57432556, 22.33452415], [92.5741806, 22.33460045], [92.57444, 22.33469963], [92.57601166, 22.33530998], [92.57505798, 22.33640099], [92.5760498, 22.33725739], [92.57540131, 22.33790398], [92.57509613, 22.33821487], [92.57450867, 22.33764839], [92.57379913, 22.33827209], [92.57486725, 22.34003448], [92.57491302, 22.34052086], [92.57509613, 22.34242439], [92.57320404, 22.34259415], [92.57279205, 22.34263039], [92.57315826, 22.34431458], [92.57343292, 22.34559059], [92.57269287, 22.34581375], [92.57232666, 22.34592438], [92.57221985, 22.34734535], [92.573349, 22.34793663], [92.57317352, 22.34905815], [92.57276154, 22.35169411], [92.57187653, 22.35390472], [92.57100677, 22.35677528], [92.57201385, 22.35877991], [92.57211304, 22.35923386], [92.57055664, 22.3603878], [92.56861115, 22.36016655], [92.56803131, 22.36071014], [92.56835938, 22.36161041], [92.56693268, 22.36543274], [92.56812286, 22.36750793], [92.56718445, 22.36873055], [92.56651306, 22.37095451], [92.56275177, 22.37145233], [92.56352997, 22.37387276], [92.56415558, 22.37547493], [92.56365204, 22.37597466], [92.56250763, 22.37586784], [92.56217957, 22.37583542], [92.56201172, 22.37633133], [92.56161499, 22.37750244], [92.56209564, 22.37798309], [92.56227875, 22.37843323], [92.56351471, 22.38018608], [92.55934143, 22.38207817], [92.55968475, 22.38284302], [92.56018066, 22.38396072], [92.56122589, 22.38534355], [92.5594101, 22.38756371], [92.56116486, 22.38881111], [92.56034851, 22.38959312], [92.55943298, 22.39046669], [92.55838776, 22.39146233], [92.5598526, 22.3915596], [92.55853271, 22.39414215], [92.55989075, 22.3956852], [92.55978394, 22.39609146], [92.55716705, 22.39746857], [92.55596161, 22.39876938], [92.55749512, 22.39994431], [92.55908966, 22.39990997], [92.55931854, 22.39990425], [92.55934906, 22.40004349], [92.55980682, 22.40208244], [92.5577774, 22.40264702], [92.55741119, 22.40275002], [92.55711365, 22.40283394], [92.55690765, 22.40317917], [92.55608368, 22.40454483], [92.5552597, 22.40516663], [92.5546875, 22.4056015], [92.55578613, 22.40705109], [92.55738831, 22.40732574], [92.55770874, 22.4081955], [92.55796814, 22.40888596], [92.55680847, 22.40944099], [92.55444336, 22.41076279], [92.55361176, 22.40929413], [92.55299377, 22.40918922], [92.55205536, 22.40903282], [92.55307007, 22.41115952], [92.55236053, 22.41307068], [92.5528183, 22.41378784], [92.55290985, 22.41392708], [92.55284119, 22.41408157], [92.55223083, 22.41550827], [92.55358887, 22.41667938], [92.55452728, 22.41703415], [92.55400848, 22.41836548], [92.55347443, 22.41973686], [92.55194092, 22.42087173], [92.55181122, 22.42096329], [92.55078888, 22.42279816], [92.55133057, 22.4234066], [92.55300903, 22.42279816], [92.55413818, 22.42333031], [92.55453491, 22.42351341], [92.55518341, 22.42267609], [92.55638885, 22.42523003], [92.55492401, 22.42523956], [92.55505371, 22.42734146], [92.55450439, 22.42714119], [92.55331421, 22.42671204], [92.55220795, 22.42693901], [92.55124664, 22.42761803], [92.55188751, 22.42851257], [92.55345917, 22.42753601], [92.55464935, 22.428442], [92.55531311, 22.42894554], [92.5548172, 22.43283463], [92.5534668, 22.43397331], [92.55435944, 22.43630981], [92.55177307, 22.43788338], [92.55262756, 22.43856812], [92.55142975, 22.44077682], [92.55208588, 22.44241714], [92.55036163, 22.44326019], [92.54953766, 22.44365883], [92.54987335, 22.44485092], [92.55095673, 22.44581413], [92.55146027, 22.44626617], [92.55105591, 22.44675446], [92.55007172, 22.44794083], [92.55146027, 22.44857597], [92.55045319, 22.45127678], [92.55066681, 22.45268822], [92.55097198, 22.45465279], [92.54930115, 22.45546722], [92.54871368, 22.45615005], [92.54825592, 22.45668221], [92.54916382, 22.45653915], [92.54972076, 22.45644951], [92.5502243, 22.45714188], [92.55002594, 22.45718002], [92.54836273, 22.45750618], [92.5485611, 22.45824432], [92.54940796, 22.45851898], [92.54814911, 22.46077538], [92.5477829, 22.46143723], [92.54724121, 22.46182823], [92.54637909, 22.46245193], [92.54652405, 22.46307945], [92.54686737, 22.46459007], [92.54800415, 22.46555901], [92.54647064, 22.46657753], [92.54579926, 22.46865273], [92.54576111, 22.47092247], [92.5461731, 22.47359848], [92.5472641, 22.47473335], [92.54755402, 22.47600746], [92.54694366, 22.47667885], [92.54679108, 22.47771454], [92.54614258, 22.4787159], [92.54537201, 22.48005104], [92.54553223, 22.48116302], [92.5456543, 22.48293495], [92.54532623, 22.48302269], [92.54433441, 22.48328781], [92.54524231, 22.48643684], [92.5459137, 22.48689079], [92.54542542, 22.48785019], [92.54613495, 22.48886871], [92.54421234, 22.48973465], [92.54327393, 22.49015808], [92.5438385, 22.49145699], [92.54414368, 22.49216461], [92.54364777, 22.49269676], [92.54320526, 22.49317169], [92.54390717, 22.49476814], [92.54612732, 22.49520302], [92.54680634, 22.49533463], [92.54823303, 22.49592781], [92.54920959, 22.49574661], [92.54956818, 22.49672318], [92.54957581, 22.4983387], [92.54892731, 22.49838638], [92.54590607, 22.49825668], [92.54325867, 22.49825859], [92.54319, 22.49828911], [92.54261017, 22.49853897], [92.54264832, 22.49957657], [92.54322815, 22.50051689], [92.54379272, 22.50046158], [92.54478455, 22.49973488], [92.54494476, 22.49961662], [92.5456543, 22.49960709], [92.54631805, 22.50018311], [92.54658508, 22.5009079], [92.54675293, 22.50137138], [92.54708862, 22.50172615], [92.54784393, 22.50159073], [92.5486145, 22.50119019], [92.5487442, 22.50111961], [92.54915619, 22.50130653], [92.54923248, 22.50146484], [92.54940796, 22.50183487], [92.54949188, 22.50271606], [92.54918671, 22.50281334], [92.5490799, 22.50284576], [92.54754639, 22.50309372], [92.54724884, 22.50336838], [92.54714966, 22.50345993], [92.54701233, 22.50376892], [92.54774475, 22.50454712], [92.54785156, 22.50466919], [92.54824829, 22.50596237], [92.54827881, 22.50605202], [92.54811859, 22.5068512], [92.54805756, 22.50716591], [92.54826355, 22.50752449], [92.54872894, 22.50765038], [92.54922485, 22.50712395], [92.55017853, 22.50678635], [92.55003357, 22.50821495], [92.54993439, 22.50980949], [92.55005646, 22.51007462], [92.54924774, 22.5098877], [92.54885101, 22.50979805], [92.54727936, 22.50979614], [92.54670715, 22.50990677], [92.54649353, 22.50995064], [92.54650116, 22.51036835], [92.54669189, 22.51068115], [92.54826355, 22.51134682], [92.54953003, 22.51174355], [92.55056763, 22.51226234], [92.55078125, 22.51252556], [92.55102539, 22.51282501], [92.55117035, 22.5130024], [92.55117798, 22.51373291], [92.55104065, 22.51382256], [92.5500946, 22.51444626], [92.54934692, 22.51458168], [92.54771423, 22.51488113], [92.54737091, 22.51499557], [92.54693604, 22.51514244], [92.54668427, 22.51566315], [92.54681396, 22.51696014], [92.54655457, 22.51704788], [92.54612732, 22.51680183], [92.54559326, 22.51524734], [92.54496765, 22.51369286], [92.54405212, 22.5133667], [92.543396, 22.51393318], [92.54330444, 22.51401138], [92.54312134, 22.51455116], [92.54341125, 22.51568794], [92.54380798, 22.51645851], [92.5448761, 22.51708794], [92.54547119, 22.51743889], [92.54538727, 22.51805115], [92.54530334, 22.51861954], [92.54471588, 22.51984787], [92.54384613, 22.52149582], [92.54317474, 22.52165031], [92.54211426, 22.52150345], [92.54177094, 22.52160072], [92.54153442, 22.52217293], [92.54149628, 22.52227402], [92.54128265, 22.52309608], [92.54155731, 22.52409172], [92.54222107, 22.52465439], [92.54333496, 22.52487755], [92.54364777, 22.5249424], [92.54042816, 22.52603149], [92.54032898, 22.52628136], [92.54092407, 22.52713585], [92.54112244, 22.52742195], [92.54085541, 22.5277729], [92.53944397, 22.52859879], [92.53910828, 22.52906799], [92.53899384, 22.52927208], [92.53936005, 22.52949333], [92.53994751, 22.52964592], [92.54122925, 22.5296669], [92.54131317, 22.53014755], [92.54109955, 22.53069305], [92.54090118, 22.53117752], [92.54058075, 22.53196526], [92.54068756, 22.53281212], [92.54103088, 22.5330925], [92.54136658, 22.53336143], [92.54146576, 22.53372955], [92.54127502, 22.53396797], [92.5408783, 22.53446579], [92.54057312, 22.53486061], [92.53918457, 22.5342083], [92.53896332, 22.5341053], [92.53871155, 22.53425217], [92.53833771, 22.53521538], [92.53840637, 22.53575516], [92.5388031, 22.53639793], [92.53953552, 22.53696632], [92.53981781, 22.53718567], [92.53942108, 22.5378685], [92.53903961, 22.53853607], [92.53967285, 22.54045105], [92.53981018, 22.54085922], [92.53918457, 22.54130363], [92.53820038, 22.54151344], [92.53755188, 22.54177856], [92.53694153, 22.54202461], [92.53688812, 22.54260445], [92.5371933, 22.54374504], [92.53723145, 22.54434013], [92.53701782, 22.54494286], [92.53688049, 22.54532814], [92.53627014, 22.54530907], [92.53529358, 22.54503059], [92.53405762, 22.5443058], [92.53154755, 22.54525948], [92.53096008, 22.54615593], [92.53134918, 22.54809761], [92.53219604, 22.55027962], [92.53201294, 22.55169487], [92.53195953, 22.55210304], [92.53164673, 22.55283356], [92.53010559, 22.55547523], [92.52766418, 22.55721474], [92.52607727, 22.55777931], [92.52548218, 22.55780411], [92.52416992, 22.55786324], [92.52315521, 22.5586071], [92.52248383, 22.5590992], [92.52177429, 22.56025124], [92.52392578, 22.56116104], [92.52788544, 22.56571198], [92.52787018, 22.56581688], [92.52768707, 22.56732178], [92.52729034, 22.57006454], [92.52695465, 22.57255173], [92.52714539, 22.57286072], [92.52737427, 22.57323265], [92.5293045, 22.57331848], [92.53063965, 22.57292747], [92.53245544, 22.57165527], [92.53327179, 22.57218742], [92.53358459, 22.57239151], [92.53372955, 22.57498932], [92.53449249, 22.57538033], [92.53505707, 22.57519913], [92.53575134, 22.57568932], [92.5368576, 22.57517052], [92.53808594, 22.57535934], [92.53807831, 22.57701874], [92.53645325, 22.57881355], [92.53638458, 22.57888985], [92.53643799, 22.57894897], [92.53729248, 22.57990646], [92.537323, 22.58047485], [92.53743744, 22.58246231], [92.5373764, 22.58279991], [92.53704071, 22.58477974], [92.53723907, 22.58496666], [92.53838348, 22.58603668], [92.53741455, 22.58633423], [92.5366745, 22.58573151], [92.53625488, 22.58538818], [92.53448486, 22.58517265], [92.53440857, 22.58522415], [92.53314972, 22.58604813], [92.53250122, 22.5867424], [92.53250122, 22.58704185], [92.53247833, 22.58792114], [92.53292084, 22.58827591], [92.53329468, 22.58857918], [92.53572845, 22.58670235], [92.53700256, 22.58779907], [92.5389328, 22.58945465], [92.53916931, 22.58965302], [92.53865814, 22.58964157], [92.53765106, 22.58962059], [92.53607178, 22.58958626], [92.53484344, 22.59163094], [92.53476715, 22.59175491], [92.53704834, 22.59318733], [92.53757477, 22.59352112], [92.53721619, 22.59401131], [92.53585052, 22.59586334], [92.53572083, 22.59763908], [92.53497314, 22.59885025], [92.53512573, 22.59925079], [92.53540039, 22.59999847], [92.53205872, 22.60233498], [92.53049469, 22.60342979], [92.53043365, 22.60409164], [92.5302887, 22.60569382], [92.5300293, 22.6084919], [92.529953, 22.60938263], [92.53322601, 22.60758972], [92.53423309, 22.60845184], [92.53479004, 22.60892487], [92.53482056, 22.60913658], [92.53504944, 22.61061478], [92.53521729, 22.61184692], [92.53208923, 22.61182022], [92.52946472, 22.61450958], [92.52909851, 22.61510468], [92.52879333, 22.61560631], [92.52861786, 22.61588669], [92.52849579, 22.61673737], [92.52873993, 22.61836624], [92.52950287, 22.61969185], [92.52988434, 22.62041664], [92.53000641, 22.62064934], [92.52935791, 22.62091446], [92.52774811, 22.62097359], [92.52748108, 22.62098312], [92.52745819, 22.6215744], [92.52837372, 22.62346268], [92.52894592, 22.62432289], [92.52981567, 22.62564659], [92.53255463, 22.62770271], [92.53220367, 22.62908745], [92.5318985, 22.63027382], [92.53222656, 22.63208389], [92.53224945, 22.63254738], [92.53227234, 22.63332176], [92.53219604, 22.63332558], [92.52980042, 22.63344002], [92.52626801, 22.63360977], [92.52627563, 22.63468933], [92.52627563, 22.63479042], [92.52771759, 22.63573265], [92.52787781, 22.63583565], [92.52763367, 22.63604546], [92.5265274, 22.63698959], [92.52639771, 22.63767815], [92.52663422, 22.63890457], [92.52675629, 22.63952827], [92.52667999, 22.63987541], [92.52503204, 22.63997269], [92.52479553, 22.64029884], [92.52448273, 22.64073181], [92.52457428, 22.64273071], [92.52470398, 22.64338493], [92.5250473, 22.64515686], [92.52446747, 22.6471653], [92.52417755, 22.64937782], [92.52458954, 22.65071106], [92.52481842, 22.6509285], [92.52510071, 22.65118599], [92.52696228, 22.6507988], [92.5271225, 22.65076637], [92.52648163, 22.65421104], [92.5244751, 22.65398216], [92.52348328, 22.6554203], [92.5242157, 22.65909004], [92.52423096, 22.65917969], [92.52433014, 22.65917015], [92.52603149, 22.65902328], [92.52720642, 22.65892029], [92.52823639, 22.65913582], [92.52842712, 22.65937233], [92.52867889, 22.6597023], [92.52840424, 22.6601429], [92.5265274, 22.66044044], [92.52697754, 22.66161728], [92.52829742, 22.66506958], [92.52842712, 22.66541862], [92.52856445, 22.66577148], [92.52799988, 22.66560364], [92.52632141, 22.66510201], [92.52548981, 22.67169762], [92.52547455, 22.67182922], [92.52584076, 22.67271614], [92.52598572, 22.67305756], [92.5247345, 22.67361641], [92.52276611, 22.67398071], [92.5226059, 22.67400932], [92.52246094, 22.67445755], [92.5223999, 22.67464447], [92.52220917, 22.67523575], [92.52233887, 22.67563438], [92.52287292, 22.6773243], [92.5231781, 22.67925835], [92.52172089, 22.68180275], [92.52112579, 22.68251228], [92.52108002, 22.68257332], [92.52113342, 22.68334961], [92.52119446, 22.68418884], [92.52019501, 22.68577003], [92.51880646, 22.68796349], [92.51880646, 22.68814659], [92.51872253, 22.69352913], [92.51740265, 22.69838905], [92.51637268, 22.70459938], [92.51526642, 22.70736122], [92.5147171, 22.70750809], [92.51435852, 22.70760536], [92.51428986, 22.70775795], [92.51376343, 22.70893288], [92.51409912, 22.71047592], [92.51504517, 22.71169853], [92.51567078, 22.71281242], [92.5150528, 22.71443939], [92.5134201, 22.71931076], [92.51052856, 22.72492981], [92.50717926, 22.73236847], [92.50434113, 22.73554039], [92.50589752, 22.73576927], [92.50792694, 22.73608017], [92.50773621, 22.73688316], [92.5071106, 22.73752594], [92.50531769, 22.73936081], [92.50510406, 22.73958015], [92.50444031, 22.73909378], [92.50242615, 22.73762131], [92.50209808, 22.73766708], [92.49937439, 22.73803902], [92.49795532, 22.73997116], [92.4957962, 22.7400589], [92.49425507, 22.74011993], [92.49421692, 22.74042511], [92.493927, 22.74276733], [92.49100494, 22.74129486], [92.49034119, 22.74475098], [92.49015808, 22.74568176], [92.48819733, 22.74658394], [92.48218536, 22.74720192], [92.48016357, 22.74657822], [92.47649384, 22.74544525], [92.47463989, 22.74583244], [92.47386932, 22.74634933], [92.47399902, 22.74708176], [92.47584534, 22.74865913], [92.47775269, 22.75055122], [92.47868347, 22.75147438], [92.47935486, 22.75392151], [92.478302, 22.75408745], [92.47698975, 22.75429344], [92.47610474, 22.75681114], [92.47637177, 22.75698853], [92.47737122, 22.75787926], [92.4765625, 22.75979233], [92.47623444, 22.75985909], [92.47545624, 22.7600174], [92.47377014, 22.759552], [92.4744873, 22.76100349], [92.47626495, 22.76462555], [92.47525787, 22.76520157], [92.47429657, 22.7650528], [92.47297668, 22.76484871], [92.47279358, 22.76528358], [92.47319794, 22.76664162], [92.47373962, 22.76775742], [92.47389984, 22.76809311], [92.4756012, 22.77088737], [92.47521973, 22.77323532], [92.47431946, 22.77446938], [92.47357178, 22.77550125], [92.47263336, 22.77638817], [92.47242737, 22.7817421], [92.47200012, 22.78272438], [92.47151184, 22.78383827], [92.47012329, 22.78275299], [92.4693222, 22.78212738], [92.46930695, 22.78718948], [92.47061157, 22.78951836], [92.47116852, 22.79432869], [92.47221375, 22.79575539], [92.47120667, 22.79807663], [92.47013092, 22.79868317], [92.46755981, 22.80013084], [92.467453, 22.80029488], [92.46501923, 22.80403519], [92.46474457, 22.80445671], [92.46525574, 22.80526161], [92.46679688, 22.80768204], [92.46655273, 22.80887604], [92.46461487, 22.81093597], [92.46315765, 22.8119545], [92.46243286, 22.8113327], [92.46264648, 22.80761337], [92.46193695, 22.80739021], [92.46135712, 22.80720711], [92.46028137, 22.81274796], [92.45829773, 22.81728363], [92.458992, 22.81865883], [92.45864105, 22.81919861], [92.45858002, 22.81930161], [92.4584198, 22.81929016], [92.45420074, 22.81900597], [92.45401001, 22.82018471], [92.45507813, 22.82125092], [92.45661926, 22.82217598], [92.4575119, 22.82279015], [92.45748901, 22.82298851], [92.45812225, 22.82321358], [92.45782471, 22.82406044], [92.45576477, 22.82495117], [92.45517731, 22.82575798], [92.45567322, 22.82605171], [92.45727539, 22.82700157], [92.45950317, 22.82885361], [92.46021271, 22.82944298], [92.46180725, 22.83077049], [92.46154022, 22.83106995], [92.45960236, 22.83327675], [92.45736694, 22.83798027], [92.45281219, 22.84198189], [92.45263672, 22.84273911], [92.45324707, 22.84346008], [92.45391846, 22.84320259], [92.45506287, 22.84276772], [92.45769501, 22.84098816], [92.45832062, 22.84102821], [92.4575119, 22.84173012], [92.46125031, 22.84339142], [92.46313477, 22.84255409], [92.46343231, 22.84291077], [92.45832062, 22.8454361], [92.45926666, 22.84603882], [92.458992, 22.84784317], [92.45996857, 22.85055161], [92.45672607, 22.85058212], [92.45802307, 22.85295486], [92.45870209, 22.85277939], [92.45962524, 22.85254097], [92.46121216, 22.85213089], [92.46323395, 22.85292053], [92.46336365, 22.85313606], [92.46430969, 22.85473633], [92.46308136, 22.85615158], [92.46286011, 22.85632133], [92.46008301, 22.85774803], [92.45951843, 22.85845184], [92.46006775, 22.85941696], [92.46165466, 22.86080551], [92.4618454, 22.86097527], [92.46192932, 22.86105156], [92.46115875, 22.8616848], [92.46060181, 22.8616066], [92.4566803, 22.8610611], [92.45594025, 22.8609581], [92.45329285, 22.86133385], [92.45212555, 22.86300468], [92.4519043, 22.86507416], [92.45367432, 22.86756134], [92.45392609, 22.86846542], [92.45495605, 22.87015724], [92.45606232, 22.87036896], [92.45721436, 22.87029648], [92.4574585, 22.87046814], [92.45826721, 22.87195969], [92.4569397, 22.87313843], [92.45629883, 22.87337685], [92.45140076, 22.87540245], [92.44927979, 22.87648392], [92.44821167, 22.87702751], [92.44818878, 22.87752342], [92.44825745, 22.87777138], [92.44837952, 22.87821388], [92.4486618, 22.88246918], [92.44953156, 22.88587189], [92.44837189, 22.88669014], [92.44789886, 22.89056969], [92.44753265, 22.89359093], [92.44552612, 22.89489365], [92.44521332, 22.89509964], [92.44507599, 22.89495659], [92.4432373, 22.89307022], [92.44193268, 22.89158058], [92.44168091, 22.89116478], [92.44113159, 22.89027023], [92.44082642, 22.88957024], [92.44039917, 22.88858032], [92.43940735, 22.88689041], [92.43829346, 22.8867054], [92.43784332, 22.8866291], [92.43765259, 22.88667107], [92.43726349, 22.88675499], [92.43649292, 22.88589859], [92.4363327, 22.88554955], [92.43621826, 22.88559723], [92.43418121, 22.8856678], [92.43404388, 22.88579369], [92.43302155, 22.88671875], [92.43304443, 22.88687325], [92.43289948, 22.88693047], [92.43071747, 22.88972092], [92.4309082, 22.89382935], [92.42750549, 22.89639473], [92.42641449, 22.8972187], [92.42355347, 22.90264511], [92.42341614, 22.9029026], [92.42118073, 22.90753555], [92.42092896, 22.90806389], [92.420784, 22.90893555], [92.41876221, 22.91296005], [92.42037964, 22.91719055], [92.42050171, 22.91745186], [92.42006683, 22.9186306], [92.41927338, 22.91935539], [92.41849518, 22.91875648], [92.41602325, 22.91576195], [92.41508484, 22.91462898], [92.41226196, 22.91378593], [92.41168213, 22.91388702], [92.40975189, 22.91537285], [92.40874481, 22.91623116], [92.40715027, 22.91605949], [92.40563202, 22.91609955], [92.40441132, 22.91653061], [92.4040451, 22.91702652], [92.40392303, 22.91719055], [92.40354156, 22.91773224], [92.40345764, 22.91697121], [92.4032135, 22.91476059], [92.40312958, 22.91398239], [92.40259552, 22.91228867], [92.40133667, 22.91199875], [92.40055084, 22.91270256], [92.39854431, 22.91451454], [92.3974762, 22.91771126], [92.3972702, 22.91833496], [92.39868164, 22.92036057], [92.39907837, 22.92092896], [92.40114594, 22.92402458], [92.40068054, 22.92471695], [92.40047455, 22.92499733], [92.3999176, 22.92576218], [92.39782715, 22.92943001], [92.39606476, 22.93039322], [92.39498901, 22.93065834], [92.39363098, 22.93075943], [92.39279175, 22.93082047], [92.39078522, 22.93058968], [92.38974762, 22.93016624], [92.38919067, 22.92993927], [92.38576508, 22.92943001], [92.38516235, 22.92934036], [92.38354492, 22.92925453], [92.38144684, 22.92914581], [92.38057709, 22.92937469], [92.37986755, 22.92956161], [92.37930298, 22.92942619], [92.37647247, 22.92875862], [92.37623596, 22.92942429], [92.37620544, 22.92951584], [92.3761673, 22.93039894], [92.37731171, 22.93175125], [92.3757782, 22.9337616], [92.37542725, 22.93488121], [92.37541199, 22.93526649], [92.37471771, 22.93503952], [92.37290955, 22.93477249], [92.37197113, 22.9358902], [92.3717041, 22.93621254], [92.37197113, 22.93626213], [92.37477875, 22.93677521], [92.37506104, 22.93682671], [92.37534332, 22.9368782], [92.37532806, 22.93731117], [92.37534332, 22.93741798], [92.37269592, 22.94020081], [92.37316895, 22.9411068], [92.37347412, 22.94169044], [92.37343597, 22.94388008], [92.37458038, 22.94635391], [92.37468719, 22.94757462], [92.37567139, 22.94758224], [92.37582397, 22.94714928], [92.37683868, 22.94735527], [92.37713623, 22.94795036], [92.37741089, 22.94850159], [92.37630463, 22.94956207], [92.3757019, 22.95014191], [92.37632751, 22.9506073], [92.37788391, 22.95177269], [92.37757874, 22.95532799], [92.37670135, 22.95582199], [92.37622833, 22.95500183], [92.37545776, 22.9536705], [92.3743515, 22.95331001], [92.37475586, 22.95662117], [92.37278748, 22.95853806], [92.37483978, 22.95908356], [92.37713623, 22.95969391], [92.37669373, 22.96022224], [92.37475586, 22.96102715], [92.37397766, 22.96134949], [92.37395477, 22.96208572], [92.37472534, 22.9628582], [92.37538147, 22.96352196], [92.37445068, 22.96518898], [92.37482452, 22.96674347], [92.37431335, 22.97010422], [92.37562561, 22.97268295], [92.37730408, 22.97428131], [92.37760162, 22.97530365], [92.37823486, 22.97701645], [92.37915039, 22.977108], [92.37941742, 22.97577667], [92.37967682, 22.97696114], [92.38012695, 22.97962379], [92.37987518, 22.97968864], [92.37947083, 22.97984314], [92.37911224, 22.97989082], [92.37947845, 22.98114014], [92.38010406, 22.98204231], [92.38111877, 22.98265076], [92.383461, 22.98549843], [92.38485718, 22.98648071], [92.38473511, 22.98688507], [92.38430023, 22.98703575], [92.38332367, 22.98674393], [92.3825531, 22.98712349], [92.38239288, 22.9872303], [92.3819809, 22.98749733], [92.38217163, 22.98839188], [92.38218689, 22.98849869], [92.38223267, 22.98890305], [92.38231659, 22.98970413], [92.38246155, 22.99040413], [92.38269043, 22.99099541], [92.38308716, 22.99135208], [92.38333893, 22.99155807], [92.38399506, 22.99188805], [92.38414764, 22.99204254], [92.38498688, 22.99287415], [92.38478088, 22.99336624], [92.38409424, 22.99433899], [92.38382721, 22.99508286], [92.38326263, 22.99665642], [92.38272858, 22.99795341], [92.38257599, 22.99814415], [92.382164, 22.9986248], [92.38211823, 23.00020218], [92.38187408, 23.00113106], [92.38219452, 23.00173759], [92.38240051, 23.00178146], [92.38290405, 23.00189018], [92.38337708, 23.00321198], [92.38367462, 23.00416374], [92.38393402, 23.00567055], [92.38383484, 23.00649834], [92.38378906, 23.00684547], [92.38333893, 23.00801277], [92.38304901, 23.00875664], [92.38343811, 23.008955], [92.38446045, 23.00947762], [92.38407898, 23.01013565], [92.38313293, 23.0104332], [92.3822403, 23.01052094], [92.38191986, 23.01055336], [92.38121796, 23.01062202], [92.38004303, 23.01099586], [92.37960815, 23.01194], [92.37957764, 23.0120163], [92.37953186, 23.01211166], [92.37961578, 23.01221085], [92.38045502, 23.01317024], [92.38011932, 23.01440811], [92.38008881, 23.01451302], [92.38014221, 23.0162468], [92.38054657, 23.01736259], [92.38168335, 23.01945686], [92.38173676, 23.0206871], [92.38191223, 23.02112961], [92.38239288, 23.02191353], [92.38309479, 23.02272034], [92.38337708, 23.02309418], [92.38354492, 23.02332306], [92.38314056, 23.02401733], [92.3829422, 23.02435684], [92.38301086, 23.02452278], [92.38337708, 23.02539825], [92.38330078, 23.02598953], [92.38323975, 23.02641678], [92.3839035, 23.02680206], [92.38476563, 23.02729988], [92.38419342, 23.02926636], [92.38328552, 23.03053856], [92.38297272, 23.03097916], [92.38298035, 23.03199577], [92.38298035, 23.03246498], [92.38262177, 23.03290939], [92.38227081, 23.03333664], [92.38249207, 23.03380775], [92.3829422, 23.03476143], [92.38305664, 23.03608131], [92.38336945, 23.03679466], [92.38353729, 23.03785706], [92.38609314, 23.0393486], [92.38789368, 23.03986549], [92.38749695, 23.04120255], [92.38745117, 23.04135704], [92.38755035, 23.0418911], [92.38808441, 23.04469872], [92.38903046, 23.04578209], [92.38931274, 23.04738617], [92.38895416, 23.04787445], [92.38830566, 23.04876709], [92.38838196, 23.04924393], [92.38907623, 23.04920959], [92.39086914, 23.04911995], [92.39110565, 23.04964447], [92.39097595, 23.04982185], [92.38973236, 23.05154991], [92.39001465, 23.05208206], [92.39104462, 23.05202293], [92.39141846, 23.05295753], [92.39176178, 23.05343437], [92.3921051, 23.05390358], [92.39067078, 23.05475426], [92.39055634, 23.0549736], [92.3903656, 23.05534554], [92.39053345, 23.05545044], [92.39225006, 23.0565033], [92.39156342, 23.05808258], [92.3903656, 23.06072998], [92.38873291, 23.06099701], [92.38827515, 23.06106949], [92.38726807, 23.06201172], [92.38706207, 23.06272507], [92.3879776, 23.06392479], [92.38813782, 23.06410599], [92.38866425, 23.0646801], [92.38777924, 23.06530762], [92.38712311, 23.0657711], [92.38736725, 23.0666523], [92.38744354, 23.06692314], [92.38725281, 23.06703758], [92.38532257, 23.06819725], [92.3848877, 23.06959152], [92.38458252, 23.06998825], [92.38284302, 23.07226944], [92.38280487, 23.07304573], [92.38467407, 23.07411194], [92.38478851, 23.07417679], [92.38513184, 23.07589722], [92.38542175, 23.07689857], [92.38459778, 23.07818413], [92.38284302, 23.07953453], [92.38174438, 23.08007431], [92.38148499, 23.08015633], [92.38098145, 23.08031845], [92.3804245, 23.0810051], [92.3802948, 23.08164215], [92.38062286, 23.08252907], [92.37917328, 23.08376694], [92.37923431, 23.08442688], [92.37986755, 23.08498192], [92.38034821, 23.08539963], [92.38000488, 23.08628845], [92.37910461, 23.08711243], [92.37796021, 23.08723068], [92.37784576, 23.08722687], [92.37705231, 23.08718872], [92.37663269, 23.08669281], [92.37673187, 23.08525276], [92.37575531, 23.08460999], [92.37502289, 23.08466339], [92.37445831, 23.08551407], [92.37389374, 23.08643341], [92.37364197, 23.08668327], [92.37337494, 23.08696175], [92.37329865, 23.08695412], [92.37243652, 23.08686256], [92.37246704, 23.08718681], [92.37256622, 23.08816338], [92.3722229, 23.0883007], [92.37171936, 23.08850098], [92.37123108, 23.08902168], [92.37096405, 23.08973312], [92.37046051, 23.09105682], [92.3704071, 23.09214783], [92.37039948, 23.09224701], [92.37026978, 23.09240723], [92.36975861, 23.09304237], [92.36953735, 23.09372711], [92.36923218, 23.09467697], [92.36903381, 23.09519386], [92.36999512, 23.09621811], [92.36976624, 23.09683228], [92.36882019, 23.09659767], [92.36689758, 23.09612083], [92.36588287, 23.09708977], [92.36503601, 23.0979023], [92.36417389, 23.09809113], [92.36366272, 23.09784317], [92.36297607, 23.09751511], [92.36207581, 23.09837341], [92.36121368, 23.0985527], [92.36165619, 23.10017395], [92.36174011, 23.10049248], [92.36157227, 23.10056114], [92.35970306, 23.1013279], [92.36068726, 23.10160828], [92.35951233, 23.10306549], [92.35813904, 23.10303879], [92.35786438, 23.10353088], [92.35900879, 23.10430336], [92.35916901, 23.10440826], [92.35988617, 23.10520554], [92.35990143, 23.10624695], [92.35849762, 23.10592651], [92.35821533, 23.10586166], [92.35826874, 23.10604286], [92.35895538, 23.10821152], [92.36034393, 23.11050034], [92.36094666, 23.11252022], [92.36036682, 23.11290169], [92.3604126, 23.11326408], [92.36050415, 23.11336327], [92.36260223, 23.11546707], [92.36264038, 23.11607742], [92.36290741, 23.11692238], [92.36237335, 23.11745834], [92.36231232, 23.11751938], [92.36238098, 23.11778259], [92.36269379, 23.11803818], [92.36460114, 23.11958694], [92.36377716, 23.12034416], [92.36480713, 23.12091255], [92.36644745, 23.1225605], [92.3666153, 23.12320328], [92.36621094, 23.123909], [92.36592102, 23.12442017], [92.36621857, 23.12511635], [92.36682892, 23.12520981], [92.36714935, 23.12525749], [92.36790466, 23.12710381], [92.3680191, 23.12753868], [92.36561584, 23.12715912], [92.3655014, 23.12719727], [92.36501312, 23.12851524], [92.36290741, 23.13040733], [92.36184692, 23.13125229], [92.36219788, 23.13066673], [92.36131287, 23.13121986], [92.36022186, 23.13169098], [92.3586731, 23.13320351], [92.35868835, 23.13383865], [92.35767365, 23.13458252], [92.35681915, 23.13426781], [92.35738373, 23.13565254], [92.3571701, 23.13611412], [92.35704041, 23.1363945], [92.35718536, 23.13698578], [92.35744476, 23.13698196], [92.35790253, 23.13697433], [92.35852051, 23.13873863], [92.3587265, 23.14049149], [92.3588028, 23.14111328], [92.3595047, 23.14135551], [92.35982513, 23.14146805], [92.35988617, 23.14284515], [92.35962677, 23.14307785], [92.35940552, 23.14326668], [92.35961151, 23.14424515], [92.36022186, 23.14475822], [92.36083221, 23.14526558], [92.36053467, 23.14609718], [92.35997009, 23.14697266], [92.35874176, 23.14634895], [92.35834503, 23.14614868], [92.35810852, 23.14660835], [92.35936737, 23.14811516], [92.3596344, 23.14838219], [92.36027527, 23.14904022], [92.36022186, 23.14968491], [92.35985565, 23.14994431], [92.35967255, 23.15007401], [92.36030579, 23.1506176], [92.36076355, 23.15101433], [92.36036682, 23.15201759], [92.3602066, 23.15241051], [92.36039734, 23.1531353], [92.36138153, 23.15305901], [92.36205292, 23.15300751], [92.36158752, 23.1536274], [92.36128998, 23.15403557], [92.36158752, 23.15556717], [92.36199188, 23.15569305], [92.36200714, 23.15655136], [92.36345673, 23.15655518], [92.36412811, 23.15655708], [92.36289215, 23.15857697], [92.36257935, 23.16034889], [92.36158752, 23.16143608], [92.3608017, 23.16229439], [92.36235809, 23.16505051], [92.36138916, 23.16697502], [92.36141968, 23.16772652], [92.35871124, 23.16883659], [92.35814667, 23.17059708], [92.35775757, 23.17134666], [92.35752106, 23.17178726], [92.35733032, 23.17407036], [92.35649109, 23.1761322], [92.35649109, 23.17710686], [92.35669708, 23.17741966], [92.35713196, 23.17807007], [92.35616302, 23.17833328], [92.35437775, 23.17881966], [92.35532379, 23.17958641], [92.35546112, 23.17970085], [92.35548401, 23.18012428], [92.35549164, 23.18025398], [92.35746002, 23.17978287], [92.35795593, 23.17989159], [92.35952759, 23.18023491], [92.3598175, 23.18029785], [92.36083984, 23.18024635], [92.36063385, 23.18115807], [92.3611145, 23.18279457], [92.36011505, 23.18271255], [92.36032867, 23.183815], [92.3591156, 23.18427277], [92.3584137, 23.18448257], [92.358284, 23.18516159], [92.35732269, 23.18507957], [92.3559494, 23.18541527], [92.35606384, 23.18495178], [92.35395813, 23.1847477], [92.35424805, 23.18575859], [92.35331726, 23.18585587], [92.35379028, 23.18733406], [92.3537674, 23.18836784], [92.35312653, 23.18898964], [92.35411835, 23.19025993], [92.3535614, 23.19088936], [92.35342407, 23.19155312], [92.35281372, 23.19209862], [92.35323334, 23.19314194], [92.35294342, 23.19424438], [92.35280609, 23.19423485], [92.35240936, 23.19420433], [92.35254669, 23.19459724], [92.35218811, 23.19477654], [92.35279846, 23.19500732], [92.35274506, 23.19590759], [92.35289764, 23.19611168], [92.35325623, 23.19659233], [92.35427094, 23.19722748], [92.35413361, 23.19818878], [92.35464478, 23.19925308], [92.35314178, 23.19982338], [92.35485077, 23.2003231], [92.35362244, 23.20182228], [92.3539505, 23.20240402], [92.35358429, 23.20279121], [92.35316467, 23.20324135], [92.35348511, 23.20330048], [92.35399628, 23.20339394], [92.35406494, 23.20421791], [92.35340118, 23.2043457], [92.35332489, 23.2048912], [92.35314178, 23.20497894], [92.3527832, 23.2051487], [92.35308838, 23.20529366], [92.35340881, 23.20544243], [92.353302, 23.20567513], [92.35325623, 23.20577621], [92.35334778, 23.20616341], [92.35241699, 23.20639229], [92.35343933, 23.20674706], [92.35362244, 23.20724869], [92.35427094, 23.2072525], [92.35437775, 23.2072525], [92.35455322, 23.20661354], [92.35506439, 23.20696831], [92.35418701, 23.20918846], [92.35404205, 23.20954514], [92.35379028, 23.21025085], [92.35372925, 23.21615791], [92.35333252, 23.22132492], [92.35332489, 23.22351456], [92.35334778, 23.22429848], [92.35312653, 23.22473526], [92.35137177, 23.22817039], [92.35118866, 23.22905159], [92.35083771, 23.23078156], [92.35081482, 23.23124695], [92.35071564, 23.23360634], [92.35068512, 23.23425293], [92.35043335, 23.23426628], [92.34873199, 23.23435783], [92.34738159, 23.23482132], [92.34671021, 23.23578835], [92.34996033, 23.23584938], [92.36125946, 23.23604012], [92.36109924, 23.23753738], [92.36251831, 23.23851967], [92.36437225, 23.23841858], [92.36795807, 23.23854828], [92.36934662, 23.23885727], [92.37264252, 23.23958588], [92.37316132, 23.23970032], [92.37631226, 23.23974991], [92.3782196, 23.23997116], [92.38342285, 23.23991013], [92.38484955, 23.23994064], [92.38620758, 23.24002266], [92.38684082, 23.24008179], [92.38928986, 23.24008942], [92.39029694, 23.24040985], [92.39154816, 23.24053001], [92.39260101, 23.24064255], [92.39756012, 23.24060059], [92.39839172, 23.24070358], [92.39933777, 23.24081993], [92.40022278, 23.24094009], [92.40337372, 23.24142838], [92.40245819, 23.2425499], [92.39958191, 23.24189568], [92.39697266, 23.24999237], [92.39563751, 23.25005722], [92.39743042, 23.25250435], [92.39838409, 23.25579071], [92.39440918, 23.25821304], [92.38951874, 23.25949287], [92.38935089, 23.26209641], [92.38922119, 23.26243019], [92.38834381, 23.26549911], [92.38860321, 23.26609612], [92.38871765, 23.26636124], [92.38947296, 23.26614189], [92.39021301, 23.26513672], [92.39051819, 23.26472092], [92.3918457, 23.26416016], [92.39338684, 23.26394463], [92.39458466, 23.26448631], [92.3942337, 23.26639175], [92.39362335, 23.2671032], [92.39186859, 23.27079201], [92.39009857, 23.27500916], [92.38924408, 23.27721214], [92.38904572, 23.27918053], [92.38852692, 23.28033829], [92.38799286, 23.28152847], [92.38668823, 23.28274536], [92.3860321, 23.28335381], [92.38472748, 23.28385353], [92.38425446, 23.28403282], [92.38092804, 23.28528023], [92.38182068, 23.28815651], [92.38227081, 23.2907505], [92.38278198, 23.29163361], [92.38318634, 23.2918663], [92.38437653, 23.29235268], [92.38450623, 23.29240608], [92.38451385, 23.2925415], [92.38452911, 23.2926693], [92.38247681, 23.29652786], [92.3833847, 23.29717445], [92.38440704, 23.29846954], [92.38284302, 23.30153465], [92.38298798, 23.30216026], [92.38482666, 23.30251694], [92.38574982, 23.30374146], [92.38568878, 23.30626106], [92.38511658, 23.30713844], [92.38381958, 23.30806732], [92.38289642, 23.30882645], [92.38061523, 23.30998039], [92.37611389, 23.31312943], [92.37722778, 23.31847763], [92.37688446, 23.3191452], [92.37619781, 23.3197155], [92.37615967, 23.3196106], [92.37557983, 23.31900978], [92.37532806, 23.31818962], [92.37451935, 23.31957817], [92.37380981, 23.31916618], [92.37342072, 23.31893921], [92.37253571, 23.31862259], [92.37190247, 23.31813812], [92.37145233, 23.31814575], [92.37086487, 23.31844521], [92.36968231, 23.32139587], [92.36945343, 23.32189941], [92.36895752, 23.32297707], [92.36784363, 23.32316208], [92.36704254, 23.32267952], [92.36842346, 23.31976509], [92.36872864, 23.31868172], [92.3687973, 23.31843758], [92.36857605, 23.31736755], [92.36795044, 23.31729507], [92.36606598, 23.32044983], [92.36443329, 23.32263947], [92.36425018, 23.32326317], [92.36466217, 23.32366943], [92.36564636, 23.32422256], [92.36815643, 23.325634], [92.3684082, 23.32619858], [92.36846924, 23.32633018], [92.3706665, 23.33034134], [92.37199402, 23.33180618], [92.37297821, 23.33379555], [92.37348938, 23.33500099], [92.3744812, 23.33688354], [92.37471008, 23.33803749], [92.37502289, 23.34050941], [92.37511444, 23.34267998], [92.37593079, 23.3468132], [92.37715149, 23.34844398], [92.37943268, 23.35001564], [92.38079071, 23.35168648], [92.38059998, 23.35379982], [92.3804245, 23.35573959], [92.38007355, 23.35611725], [92.37937927, 23.35625267], [92.37767029, 23.35677719], [92.37683105, 23.35671234], [92.37632751, 23.35675812], [92.37634277, 23.35732841], [92.37718964, 23.3580246], [92.37766266, 23.35875893], [92.37815857, 23.36019516], [92.37874603, 23.36138344], [92.37904358, 23.36210632], [92.37779236, 23.36309242], [92.37750244, 23.36318779], [92.37713623, 23.36372375], [92.37654877, 23.36439323], [92.37585449, 23.36510086], [92.3757782, 23.36527824], [92.37574005, 23.36554909], [92.37484741, 23.36566162], [92.37368011, 23.36571693], [92.37083435, 23.36585236], [92.36938477, 23.36709404], [92.36769867, 23.36688042], [92.36640167, 23.36738014], [92.36587524, 23.36766624], [92.36525726, 23.36696243], [92.36389923, 23.36625671], [92.36133575, 23.36696053], [92.35973358, 23.36826897], [92.35933685, 23.36870003], [92.35842133, 23.36969376], [92.35829926, 23.36971474], [92.35813904, 23.36973953], [92.35610962, 23.37274742], [92.35617065, 23.37332535], [92.35726929, 23.37475204], [92.35988617, 23.37572479], [92.3609848, 23.37711334], [92.36167908, 23.37777519], [92.36278534, 23.37816048], [92.36382294, 23.37847328], [92.36425018, 23.37900543], [92.36471558, 23.37952614], [92.36488342, 23.37971306], [92.36460114, 23.380373], [92.36431885, 23.38088417], [92.3637085, 23.38109779], [92.36332703, 23.38123322], [92.36192322, 23.38102722], [92.36136627, 23.38094521], [92.3605423, 23.38082504], [92.35878754, 23.38072968], [92.35715485, 23.38026237], [92.35604095, 23.37984657], [92.35584259, 23.37977219], [92.35372162, 23.38009644], [92.35277557, 23.38066483], [92.35256195, 23.38119698], [92.35277557, 23.38286209], [92.35404205, 23.38376617], [92.35540009, 23.38446999], [92.3560257, 23.38447762], [92.35661316, 23.38488007], [92.35659027, 23.38570595], [92.35581207, 23.38724709], [92.35578156, 23.38782692], [92.35614777, 23.38823318], [92.35676575, 23.38851166], [92.35707855, 23.38871384], [92.35790253, 23.38890648], [92.35837555, 23.39003181], [92.35871124, 23.39081764], [92.35852051, 23.39130211], [92.3579483, 23.39178848], [92.35715485, 23.3917923], [92.35614777, 23.39075279], [92.35567474, 23.3891983], [92.35490417, 23.38899612], [92.35478973, 23.38910103], [92.35440063, 23.38945961], [92.35413361, 23.39056206], [92.35377502, 23.39143562], [92.35371399, 23.39219666], [92.35349274, 23.39367104], [92.35372162, 23.39484024], [92.35360718, 23.39593697], [92.35355377, 23.39636993], [92.35346222, 23.39703178], [92.35317993, 23.39764023], [92.35292053, 23.39947891], [92.35308075, 23.40096283], [92.35305786, 23.40193748], [92.35273743, 23.40311623], [92.35286713, 23.40451813], [92.35294342, 23.40539932], [92.35381317, 23.40623665], [92.35417175, 23.40585899], [92.35433197, 23.40519524], [92.35479736, 23.40405655], [92.35487366, 23.40358543], [92.35495758, 23.40307808], [92.35501099, 23.40132713], [92.35534668, 23.40092468], [92.3558197, 23.40124702], [92.35683441, 23.40304756], [92.35721588, 23.40397453], [92.35780334, 23.40447617], [92.3580246, 23.40525818], [92.35812378, 23.4056282], [92.35781097, 23.40715981], [92.35730743, 23.41030693], [92.35734558, 23.41062164], [92.3571701, 23.41088867], [92.35547638, 23.41207314], [92.35480499, 23.41249657], [92.35422516, 23.41306877], [92.35247803, 23.41365051], [92.35150909, 23.41341972], [92.35089111, 23.41347122], [92.3483963, 23.41276932], [92.34776306, 23.41282082], [92.34751892, 23.41332054], [92.34785461, 23.41494942], [92.34816742, 23.41847038], [92.34803772, 23.41971207], [92.34725189, 23.42134857], [92.34729767, 23.42226982], [92.34767151, 23.42310524], [92.34790039, 23.42394829], [92.34786224, 23.42550087], [92.34755707, 23.42637062], [92.34719086, 23.42691231], [92.34648132, 23.42788124], [92.34630585, 23.42860031], [92.34648132, 23.42943382], [92.34682465, 23.43026352], [92.34748077, 23.43115044], [92.34714508, 23.43240929], [92.34645844, 23.43311882], [92.34626007, 23.43341064], [92.34555054, 23.43366241], [92.34527588, 23.43368149], [92.34455109, 23.43372917], [92.34409332, 23.43340683], [92.34303284, 23.43408394], [92.34233093, 23.43500519], [92.34225464, 23.43558311], [92.34198761, 23.43567085], [92.34159088, 23.43571854], [92.34000397, 23.43475342], [92.33985901, 23.43452454], [92.33946991, 23.43389702], [92.33840942, 23.4321785], [92.33781433, 23.43194008], [92.33746338, 23.43209457], [92.33725739, 23.43229675], [92.33603668, 23.43347359], [92.33559418, 23.43362999], [92.33544922, 23.43323517], [92.33522797, 23.43095016], [92.33535004, 23.43032837], [92.3351593, 23.4295063], [92.3350296, 23.42866516], [92.3346405, 23.42840004], [92.33395386, 23.42860031], [92.33346558, 23.42900085], [92.33302307, 23.42975426], [92.33298492, 23.42998505], [92.33281708, 23.43103218], [92.33308411, 23.43329811], [92.3323822, 23.43649101], [92.33208466, 23.43712234], [92.3313446, 23.4382], [92.33061981, 23.4400959], [92.33105469, 23.44171524], [92.33099365, 23.4432869], [92.33080292, 23.44378471], [92.33070374, 23.44477844], [92.33035278, 23.44573402], [92.33037567, 23.44598961], [92.32951355, 23.4479351], [92.32858276, 23.44840622], [92.32810211, 23.44852066], [92.32791138, 23.44826698], [92.32726288, 23.44830322], [92.32699585, 23.44855499], [92.327034, 23.44913292], [92.32704926, 23.45004082], [92.32826233, 23.45002174], [92.3285675, 23.45001602], [92.32862091, 23.45029831], [92.32905579, 23.45275879], [92.33084869, 23.45303535], [92.33139801, 23.45346451], [92.33210754, 23.45425987], [92.33319855, 23.45547485], [92.33325958, 23.45649719], [92.3323822, 23.45713997], [92.3319397, 23.45739555], [92.33157349, 23.45731735], [92.33161926, 23.45537376], [92.33162689, 23.45523643], [92.33061981, 23.4541378], [92.32939148, 23.45442772], [92.32917786, 23.45451355], [92.32905579, 23.45483971], [92.32860565, 23.45521927], [92.32832336, 23.45581055], [92.32780457, 23.45686722], [92.32697296, 23.45739365], [92.32569885, 23.45881844], [92.32527161, 23.45923805], [92.32531738, 23.45956802], [92.3258667, 23.4598732], [92.32762146, 23.46002579], [92.32854462, 23.45968056], [92.32939148, 23.4594841], [92.33045197, 23.45951653], [92.33065796, 23.46009254], [92.33082581, 23.46014786], [92.33207703, 23.46457863], [92.3316803, 23.46635246], [92.33068848, 23.46707916], [92.33004761, 23.46721268], [92.32915497, 23.46681213], [92.32845306, 23.46649742], [92.32728577, 23.46688652], [92.32710266, 23.46715927], [92.3267746, 23.46766472], [92.32561493, 23.46774101], [92.3210907, 23.4696312], [92.3197937, 23.46975327], [92.31887054, 23.47027779], [92.31874084, 23.47035599], [92.31786346, 23.47125435], [92.3170166, 23.4718132], [92.31747437, 23.47234344], [92.31790924, 23.47297096], [92.3189621, 23.47317696], [92.3188324, 23.47431183], [92.32010651, 23.47534752], [92.32019806, 23.47471046], [92.32042694, 23.47397995], [92.32083893, 23.47393227], [92.32202911, 23.4737606], [92.32254028, 23.47357368], [92.32325745, 23.47356224], [92.32341003, 23.47363853], [92.32371521, 23.47379494], [92.32372284, 23.47439194], [92.32368469, 23.4746685], [92.32359314, 23.4752903], [92.32344818, 23.47681999], [92.32312775, 23.47727966], [92.32238007, 23.47830772], [92.32293701, 23.47905922], [92.32388306, 23.47858429], [92.32454681, 23.4782486], [92.32517242, 23.47815514], [92.32559204, 23.47846603], [92.32614899, 23.47888184], [92.32520294, 23.47965813], [92.32500458, 23.47980881], [92.32431793, 23.48031616], [92.32324982, 23.48044205], [92.32274628, 23.48043633], [92.32234955, 23.48043251], [92.32199097, 23.48019028], [92.32090759, 23.48062134], [92.32074738, 23.4808712], [92.32184601, 23.48217392], [92.3219223, 23.48244667], [92.3216095, 23.48308754], [92.32054138, 23.48402214], [92.3197937, 23.48485184], [92.31830597, 23.48560333], [92.31695557, 23.48613739], [92.31637573, 23.48643494], [92.31603241, 23.48697853], [92.31630707, 23.48740387], [92.31721497, 23.48803329], [92.31821442, 23.48871803], [92.31881714, 23.48932838], [92.31955719, 23.48972893], [92.32110596, 23.49028206], [92.32180786, 23.49022865], [92.32199097, 23.49142265], [92.32185364, 23.49192047], [92.32123566, 23.49205589], [92.32015991, 23.49207306], [92.31881714, 23.49228477], [92.31807709, 23.49313927], [92.31742859, 23.49430656], [92.31742859, 23.49455452], [92.3177948, 23.49471283], [92.31893921, 23.49462128], [92.32038116, 23.49450493], [92.32041168, 23.49545479], [92.32043457, 23.49642181], [92.32044983, 23.49687576], [92.32001495, 23.49851799], [92.31939697, 23.49986649], [92.31915283, 23.50039101], [92.31933594, 23.50061798], [92.31942749, 23.5006485], [92.32015228, 23.50086975], [92.32271576, 23.50103378], [92.32266235, 23.5013237], [92.32042694, 23.50152588], [92.31885529, 23.50338554], [92.31941986, 23.50497055], [92.31906128, 23.50658798], [92.31876373, 23.50803757], [92.31995392, 23.50938034], [92.31971741, 23.5109539], [92.31970215, 23.51256561], [92.31925964, 23.51269531], [92.31895447, 23.51268005], [92.31867218, 23.51266479], [92.31764221, 23.5122261], [92.31606293, 23.51196289], [92.31533051, 23.51354599], [92.31590271, 23.5139904], [92.31616974, 23.51408958], [92.31826782, 23.51487732], [92.31838226, 23.51521301], [92.31796265, 23.51606941], [92.31724548, 23.5175209], [92.31680298, 23.51769257], [92.31607819, 23.51725006], [92.31505585, 23.51549149], [92.313797, 23.5152626], [92.31352997, 23.51535034], [92.31345367, 23.51617813], [92.3141861, 23.51690865], [92.3139267, 23.51760483], [92.31360626, 23.51844978], [92.3131485, 23.51965141], [92.3130722, 23.52027321], [92.31309509, 23.52076721], [92.31365204, 23.52166748], [92.31374359, 23.52173424], [92.31728363, 23.52437592], [92.31771851, 23.52521133], [92.31781769, 23.52624893], [92.31726837, 23.52724648], [92.31609344, 23.52939224], [92.31469727, 23.52957916], [92.31416321, 23.52963066], [92.31398773, 23.52992249], [92.31406403, 23.53144836], [92.31378937, 23.53240395], [92.31388855, 23.53274345], [92.31394196, 23.533144], [92.31376648, 23.53332329], [92.31360626, 23.53347969], [92.31311798, 23.53359604], [92.31298065, 23.53354263], [92.31056213, 23.53257942], [92.30957794, 23.53241348], [92.30831146, 23.53273201], [92.30679321, 23.53400421], [92.30615997, 23.53517151], [92.30686951, 23.536026], [92.30735779, 23.53829002], [92.30793762, 23.54121399], [92.30860138, 23.54159355], [92.31002045, 23.54240227], [92.30989075, 23.54304123], [92.30981445, 23.54341316], [92.30983734, 23.54461098], [92.31032562, 23.54606628], [92.31054688, 23.5467453], [92.31059265, 23.54716682], [92.31049347, 23.5474968], [92.31009674, 23.54877663], [92.30927277, 23.54936981], [92.30862427, 23.5500412], [92.30884552, 23.55135918], [92.31069946, 23.55560684], [92.31110382, 23.55480766], [92.311409, 23.55420685], [92.31255341, 23.5531559], [92.31297302, 23.55352211], [92.31330109, 23.554739], [92.31324768, 23.55669785], [92.31203461, 23.5588398], [92.31166077, 23.55990219], [92.30976105, 23.56179237], [92.30794525, 23.56267357], [92.30764008, 23.56294632], [92.30706024, 23.56346321], [92.30667877, 23.56451035], [92.30666351, 23.56472969], [92.30661011, 23.56572533], [92.3068924, 23.56625938], [92.30754089, 23.56500816], [92.30802917, 23.56496048], [92.30860901, 23.56623077], [92.30905151, 23.57020569], [92.30901337, 23.57040787], [92.30882263, 23.57136536], [92.30860901, 23.5717659], [92.30807495, 23.57188034], [92.30754852, 23.57169151], [92.30735016, 23.57162094], [92.30673218, 23.57187843], [92.30685425, 23.57128143], [92.30771637, 23.57063484], [92.30796051, 23.57045364], [92.30821228, 23.56964874], [92.30757141, 23.56918907], [92.30658722, 23.57014656], [92.30622101, 23.57115936], [92.30506134, 23.57368088], [92.30549622, 23.57422447], [92.30685425, 23.57594109], [92.30722046, 23.57633018], [92.30736542, 23.57686615], [92.30809784, 23.5777626], [92.3073349, 23.57866287], [92.30661011, 23.57952118], [92.30653381, 23.58008194], [92.30635071, 23.58139229], [92.30628967, 23.58185768], [92.30621338, 23.58241844], [92.30582428, 23.58304405], [92.305336, 23.58329964], [92.30519104, 23.58328056], [92.30479431, 23.58322716], [92.30438995, 23.58286095], [92.30393982, 23.58295059], [92.30363464, 23.58341026], [92.30384827, 23.58505821], [92.3037796, 23.58525848], [92.30342102, 23.58638763], [92.3030014, 23.58678246], [92.30211639, 23.58760643], [92.30139923, 23.5884037], [92.30141449, 23.58856201], [92.30129242, 23.58871078], [92.29943085, 23.59033966], [92.29914093, 23.59106064], [92.29808044, 23.59215355], [92.29786682, 23.59126854], [92.29761505, 23.58985138], [92.29673767, 23.58814812], [92.29653168, 23.58832359], [92.29470825, 23.5898819], [92.29394531, 23.59236526], [92.29331207, 23.59321404], [92.29311371, 23.59347725], [92.29309082, 23.59427834], [92.29317474, 23.59449196], [92.29346466, 23.59522247], [92.29290009, 23.59517097], [92.29230499, 23.59511757], [92.29131317, 23.59542274], [92.2909317, 23.59589767], [92.28990173, 23.59718895], [92.28929901, 23.59793282], [92.28886414, 23.59827042], [92.28849792, 23.59790421], [92.2885437, 23.59571457], [92.28799438, 23.59531021], [92.287117, 23.59615135], [92.28713226, 23.59626389], [92.28769684, 23.60076714], [92.28742981, 23.60221672], [92.28786469, 23.60349083], [92.28738403, 23.60552216], [92.28818512, 23.60736847], [92.28730774, 23.61010742], [92.2878952, 23.61131287], [92.28747559, 23.61250114], [92.28757477, 23.61394501], [92.28740692, 23.61539078], [92.28723907, 23.61684227], [92.2873764, 23.61716461], [92.28752136, 23.6174984], [92.28800964, 23.61848068], [92.28881073, 23.61925316], [92.28971863, 23.61989021], [92.29077911, 23.61986542], [92.29206085, 23.62035751], [92.29319, 23.62066841], [92.29547119, 23.62063217], [92.29592133, 23.62081528], [92.29584503, 23.62147713], [92.29529572, 23.62239456], [92.29410553, 23.62435532], [92.29058838, 23.62773323], [92.28966522, 23.6284008], [92.28848267, 23.62722969], [92.28655243, 23.62783051], [92.2857666, 23.62765503], [92.28476715, 23.62778854], [92.28379822, 23.6280899], [92.28356934, 23.62899971], [92.28144836, 23.63000679], [92.28134918, 23.62999535], [92.2806015, 23.63070297], [92.28031158, 23.63050652], [92.27964783, 23.63005638], [92.27906799, 23.6292572], [92.27907562, 23.62833023], [92.27993011, 23.62656593], [92.27999115, 23.6259613], [92.27986145, 23.62551308], [92.27977753, 23.62523842], [92.27877045, 23.6249485], [92.27826691, 23.62574196], [92.27820587, 23.62760162], [92.27804565, 23.62818336], [92.27697754, 23.62976837], [92.27663422, 23.6306591], [92.27642822, 23.63160324], [92.27668762, 23.63218498], [92.27711487, 23.63277245], [92.27731323, 23.63304329], [92.27818298, 23.6343174], [92.27933502, 23.63491821], [92.27957153, 23.63559151], [92.27934265, 23.63630676], [92.27957153, 23.63674927], [92.28013611, 23.6367569], [92.28092957, 23.63627243], [92.28138733, 23.63676834], [92.28153992, 23.63779068], [92.28171539, 23.63869667], [92.28141022, 23.63877678], [92.27975464, 23.63920784], [92.27775574, 23.6404953], [92.2771225, 23.64116669], [92.27507782, 23.64212418], [92.27332306, 23.64155769], [92.27293396, 23.64172935], [92.27302551, 23.64280128], [92.27336121, 23.64395332], [92.27359772, 23.64439964], [92.27484131, 23.64682007], [92.27433014, 23.64770317], [92.2750473, 23.65012169], [92.27637482, 23.65206528], [92.27748108, 23.65305519], [92.27790833, 23.6534214], [92.27805328, 23.65383148], [92.27835846, 23.65440559], [92.27855682, 23.65543365], [92.27839661, 23.65630341], [92.28022766, 23.65829849], [92.28088379, 23.65989876], [92.28108215, 23.66101074], [92.28141022, 23.66141891], [92.28204346, 23.66171455], [92.28284454, 23.66168404], [92.28329468, 23.66170311], [92.28343201, 23.66193199], [92.28356171, 23.66406822], [92.28429413, 23.66467667], [92.284729, 23.66557884], [92.28469086, 23.66610527], [92.28457642, 23.66760445], [92.28510284, 23.66962051], [92.28529358, 23.67019463], [92.28599548, 23.67173767], [92.28630829, 23.67310333], [92.2868042, 23.67394638], [92.28837585, 23.676548], [92.28842926, 23.67704201], [92.28875732, 23.67769814], [92.28894806, 23.67835617], [92.28897858, 23.68008995], [92.28958893, 23.68123627], [92.2902298, 23.68118858], [92.29102325, 23.68113136], [92.29133606, 23.68129158], [92.29138947, 23.68170357], [92.2909317, 23.68225098], [92.29069519, 23.6828289], [92.29093933, 23.6840229], [92.29064178, 23.68497849], [92.28955078, 23.68635941], [92.28957367, 23.68751526], [92.29084778, 23.69096375], [92.28953552, 23.69255447], [92.28984833, 23.69490433], [92.28914642, 23.69569969], [92.28935242, 23.69817352], [92.28937531, 23.6985054], [92.28934479, 23.69862556], [92.28920746, 23.6991272], [92.28940582, 23.69944191], [92.2897644, 23.70002747], [92.28937531, 23.70004654], [92.28855133, 23.7000885], [92.28901672, 23.70061684], [92.28879547, 23.70095062], [92.28903961, 23.70149231], [92.28926086, 23.70197678], [92.28885651, 23.70176506], [92.2884903, 23.70157623], [92.28800201, 23.70178986], [92.28701782, 23.70180702], [92.28713226, 23.70252991], [92.28717041, 23.70279503], [92.2868042, 23.70282936], [92.28609467, 23.70289421], [92.28538513, 23.70331955], [92.28535461, 23.7039814], [92.28486633, 23.704319], [92.28469849, 23.70490074], [92.28436279, 23.70606232], [92.28451538, 23.70709229], [92.28463745, 23.70741653], [92.28353119, 23.70710754], [92.28321075, 23.70686531], [92.28294373, 23.70711708], [92.28250122, 23.70741463], [92.28179169, 23.7075901], [92.28063965, 23.70847702], [92.28069305, 23.70853424], [92.28128052, 23.70916748], [92.28020477, 23.70910263], [92.27941132, 23.70977592], [92.27873993, 23.70992661], [92.27842712, 23.70999908], [92.27830505, 23.71074486], [92.27812958, 23.7111187], [92.27827454, 23.7113781], [92.27850342, 23.71181488], [92.27877808, 23.71193504], [92.27878571, 23.71243095], [92.27919769, 23.71267128], [92.27845001, 23.71346855], [92.27859497, 23.71408463], [92.27841949, 23.71446037], [92.27861023, 23.71503448], [92.27941895, 23.71526909], [92.27965546, 23.71568108], [92.27670288, 23.72106171], [92.27626038, 23.72187042], [92.2691803, 23.72811127], [92.26850128, 23.72861099], [92.26848602, 23.72869682], [92.26647949, 23.7387085], [92.26824188, 23.75640488], [92.26824951, 23.75651741], [92.26711273, 23.76189995], [92.26728058, 23.76273346], [92.26802826, 23.7665081], [92.26779938, 23.76997185], [92.26374054, 23.79168892], [92.26348877, 23.79968262], [92.2623291, 23.80487061], [92.26068115, 23.80712891], [92.25939941, 23.814991], [92.25953674, 23.81502914], [92.26947784, 23.81777954], [92.2766571, 23.81520844], [92.27911377, 23.81671143], [92.28084564, 23.81515884], [92.28374481, 23.81623459], [92.28588867, 23.81567383], [92.28681183, 23.81676102], [92.28568268, 23.82263184], [92.28346252, 23.82349968], [92.28366852, 23.82418633], [92.28159332, 23.82616043], [92.28160858, 23.82630157], [92.28210449, 23.83087158], [92.27713013, 23.8366127], [92.2770462, 23.83670998], [92.27587891, 23.83990479], [92.27393341, 23.84169769], [92.2741394, 23.84361076], [92.27474976, 23.84905815], [92.2765274, 23.8528862], [92.28530121, 23.85747147], [92.28592682, 23.85886574], [92.28790283, 23.86309814], [92.28790283, 23.86688232], [92.29201508, 23.87140846], [92.29338074, 23.87134743], [92.29388428, 23.87127686], [92.29514313, 23.87010956], [92.29510498, 23.86547852], [92.30068207, 23.8664608], [92.30426025, 23.8638649], [92.30432129, 23.86382294], [92.30731201, 23.8638916], [92.30987549, 23.8626709], [92.31552887, 23.86352539], [92.3156662, 23.86354637], [92.31954956, 23.86524773], [92.31968689, 23.86530876], [92.32022095, 23.86581039], [92.3203125, 23.86590576], [92.31824493, 23.86713982], [92.31845856, 23.86799431], [92.32198334, 23.86982536], [92.32208252, 23.86987305], [92.32209015, 23.87379074], [92.32209015, 23.87390327], [92.32198334, 23.87415886], [92.32041168, 23.8780098], [92.3190918, 23.87768555], [92.31710815, 23.87918091], [92.31712341, 23.87926483], [92.31747437, 23.8813858], [92.31750488, 23.88153076], [92.31671143, 23.88171387], [92.31628418, 23.88330078], [92.31642151, 23.88343811], [92.31713104, 23.88408852], [92.31932831, 23.88372421], [92.31952667, 23.88610077], [92.31832886, 23.88793182], [92.31902313, 23.88915443], [92.3184967, 23.89048958], [92.31863403, 23.89053917], [92.31919861, 23.89066887], [92.3192749, 23.89068604], [92.31988525, 23.88989258], [92.32067871, 23.89129639], [92.32157898, 23.8914547], [92.32171631, 23.89147949], [92.32315063, 23.90426636], [92.32331085, 23.90441322], [92.32360077, 23.90467834], [92.32372284, 23.90466881], [92.32579041, 23.90449524], [92.32592773, 23.90447998], [92.32778168, 23.90621948], [92.32989502, 23.90551758], [92.33048248, 23.90759659], [92.330513, 23.90771484], [92.33052826, 23.90783119], [92.33114624, 23.91180229], [92.32939148, 23.91885948], [92.33065796, 23.92144966], [92.32971191, 23.9230957], [92.3278656, 23.92401695], [92.32128906, 23.92607498], [92.32116699, 23.92611122], [92.31807709, 23.93035126], [92.31347656, 23.93450928], [92.31268311, 23.94128418], [92.31347656, 23.94329834], [92.31123352, 23.94568443], [92.31265259, 23.95750618], [92.31144714, 23.96058273], [92.31155396, 23.96060562], [92.31333923, 23.96096992], [92.3133316, 23.96108818], [92.31269836, 23.9702301], [92.31360626, 23.97049141], [92.31530762, 23.97088623], [92.31513977, 23.97216606], [92.31768036, 23.97210121], [92.31964111, 23.97532082], [92.32208252, 23.97528076], [92.32274628, 23.97981071], [92.32285309, 23.97978592], [92.32409668, 23.97949219], [92.32552338, 23.98326111], [92.32614899, 23.98365974], [92.32778931, 23.98470116], [92.32769775, 23.98571777], [92.32736969, 23.98604584], [92.32579803, 23.98747063], [92.32589722, 23.98753548], [92.32905579, 23.98965073], [92.32727051, 24.00189209], [92.32746124, 24.00420952], [92.32470703, 24.00653076], [92.31713867, 24.01761246], [92.31750488, 24.0189209], [92.31890869, 24.01928711], [92.32092285, 24.0178833], [92.32165527, 24.0188446], [92.32171631, 24.0189209], [92.31848145, 24.02270508], [92.3190918, 24.0255127], [92.31669617, 24.02797127], [92.3167572, 24.02802467], [92.3192749, 24.03027344], [92.3192749, 24.03131104], [92.31413269, 24.03471184], [92.31506348, 24.0355587], [92.31719971, 24.03750038], [92.31754303, 24.03952026], [92.31549072, 24.04492188], [92.31526947, 24.0486908], [92.31682587, 24.05135155], [92.31904602, 24.0501194], [92.32028961, 24.05116272], [92.31999969, 24.05231667], [92.31871033, 24.05735016], [92.32176971, 24.05866051], [92.3190918, 24.0612793], [92.31880188, 24.06202126], [92.3168869, 24.06689835], [92.3182373, 24.06904411], [92.31828308, 24.06912422], [92.3192749, 24.06951904], [92.32128906, 24.06848145], [92.32330322, 24.06970215], [92.32293701, 24.07180023], [92.32292175, 24.07187462], [92.32369232, 24.07326317], [92.32727051, 24.07452393], [92.3270874, 24.07647705], [92.32287598, 24.07695961], [92.32284546, 24.07726669], [92.32282257, 24.07748032], [92.32805634, 24.08062744], [92.32814026, 24.08068085], [92.32904816, 24.08225632], [92.32811737, 24.08502007], [92.32814026, 24.08515549], [92.32878113, 24.08912086], [92.32794952, 24.09370232], [92.33014679, 24.09602356], [92.33027649, 24.09615326], [92.33068085, 24.09697342], [92.33142853, 24.09874535], [92.32834625, 24.09859848], [92.32967377, 24.10109329], [92.3296814, 24.10132408], [92.32950592, 24.10293007], [92.33227539, 24.10528564], [92.33229065, 24.10680962], [92.33229065, 24.10688782], [92.32937622, 24.11036682], [92.33188629, 24.11176109], [92.33187103, 24.11187363], [92.33174133, 24.11314583], [92.32867432, 24.11590576], [92.32832336, 24.12468338], [92.33101654, 24.12799072], [92.33111572, 24.12811279], [92.32888031, 24.1296463], [92.32878113, 24.12972069], [92.329216, 24.13162613], [92.32816315, 24.13516998], [92.32830048, 24.13862038], [92.32928467, 24.13989258], [92.33227539, 24.14050293], [92.33227539, 24.14402962], [92.33296967, 24.14419365], [92.33353424, 24.14426804], [92.3336792, 24.14428711], [92.33532715, 24.14367676], [92.33627319, 24.14432335], [92.33688354, 24.14677811], [92.33691406, 24.14691162], [92.33447266, 24.15087891], [92.33190918, 24.16369629], [92.32946777, 24.16452026], [92.32855988, 24.1661129], [92.32993317, 24.17465019], [92.33002472, 24.1800499], [92.33002472, 24.18013763], [92.33087158, 24.18212891], [92.33040619, 24.18483162], [92.3270874, 24.18609619], [92.32958221, 24.18818855], [92.32971191, 24.18829346], [92.32891083, 24.18911171], [92.32949066, 24.19114113], [92.32476044, 24.19476128], [92.32470703, 24.19628906], [92.32557678, 24.19753647], [92.32510376, 24.1989994], [92.32506561, 24.19908333], [92.3203125, 24.20269775], [92.3203125, 24.20430946], [92.32480621, 24.20470428], [92.32489014, 24.20471191], [92.32470703, 24.20587158], [92.3190918, 24.20910645], [92.31610107, 24.21331787], [92.31265259, 24.21109772], [92.30974579, 24.21479988], [92.30966949, 24.21612167], [92.31359863, 24.22113037], [92.31375122, 24.22288322], [92.31083679, 24.2225399], [92.30353546, 24.22163582], [92.30342102, 24.22165298], [92.30088043, 24.22204018], [92.30113983, 24.22448158], [92.30187988, 24.22509766], [92.30105591, 24.22553444], [92.29769897, 24.22731781], [92.29920959, 24.22934151], [92.29931641, 24.22949219], [92.29946899, 24.23162079], [92.29632568, 24.23388672], [92.29632568, 24.23608398], [92.296875, 24.23809814], [92.29492188, 24.24072266], [92.29412842, 24.24432373], [92.2953186, 24.24806976], [92.29709625, 24.24954033], [92.29668427, 24.25174141], [92.30349731, 24.25269127], [92.3105011, 24.2513485], [92.31407166, 24.25260162], [92.37652588, 24.25131035], [92.39570618, 24.25252914], [92.40683746, 24.25193977], [92.4164505, 24.25342941], [92.42237854, 24.25311089], [92.42253113, 24.24817085], [92.42005157, 24.23520279], [92.41851807, 24.22164917], [92.42018127, 24.21788979], [92.41822052, 24.2109108], [92.41971588, 24.20247078], [92.41897583, 24.19436073], [92.42214966, 24.18852997], [92.43321228, 24.1832695], [92.43419647, 24.18138123], [92.43445587, 24.17414093], [92.43775177, 24.1704998], [92.43814087, 24.16913033], [92.43522644, 24.16257858], [92.43656921, 24.15242958], [92.43743134, 24.15135002], [92.43875885, 24.15125084], [92.44182587, 24.1528511], [92.4438858, 24.15309906], [92.45063019, 24.14369011], [92.45722198, 24.14350128], [92.4630661, 24.13636971], [92.46483612, 24.13663101], [92.4659729, 24.13475037], [92.46682739, 24.13504028], [92.46858978, 24.13800049], [92.47335052, 24.13996124], [92.47332001, 24.14203072], [92.474823, 24.14291], [92.47960663, 24.14089966], [92.48087311, 24.14132118], [92.48149872, 24.14294052], [92.47875214, 24.14871025], [92.48062897, 24.15011024], [92.48065948, 24.15229988], [92.48293304, 24.1527195], [92.48355865, 24.15393066], [92.48118591, 24.1570797], [92.48264313, 24.15709114], [92.48396301, 24.15814018], [92.48490143, 24.15930939], [92.48493958, 24.16138077], [92.48586273, 24.16220093], [92.48808289, 24.16221809], [92.49475861, 24.15994072], [92.50013733, 24.16052055], [92.50245667, 24.16211128], [92.50325775, 24.16666985], [92.50488281, 24.16731071], [92.50678253, 24.16682053], [92.50953674, 24.16288948], [92.51283264, 24.16257858], [92.51200104, 24.16481972], [92.50863647, 24.1692009], [92.51373291, 24.16926003], [92.5147934, 24.17020035], [92.51357269, 24.17358017], [92.51512909, 24.17548752], [92.51759338, 24.1762104], [92.52175903, 24.17292976], [92.52539825, 24.17292976], [92.52966309, 24.17480087], [92.52990723, 24.17641068], [92.53151703, 24.17741966], [92.53289032, 24.18053055], [92.53346252, 24.18083191], [92.53147888, 24.18346024], [92.53781891, 24.19647026], [92.53639984, 24.19989967], [92.53726959, 24.201931], [92.54147339, 24.20622826], [92.54242706, 24.21062088], [92.54223633, 24.21417809], [92.54574585, 24.21990013], [92.54738617, 24.2244091], [92.5477829, 24.23188972], [92.54693604, 24.23476028], [92.54709625, 24.23769951], [92.54882812, 24.24323082], [92.55063629, 24.2458992], [92.55893707, 24.24789047], [92.56455994, 24.25008965], [92.58184052, 24.24535942], [92.5880127, 24.2448616], [92.59140015, 24.24598122], [92.59356689, 24.24858856], [92.59596252, 24.24930954], [92.60595703, 24.24920082], [92.60795593, 24.25008011], [92.61158752, 24.2533493], [92.61308289, 24.25583839], [92.61550903, 24.26362038], [92.61576843, 24.2705307], [92.61682129, 24.27531052], [92.61904144, 24.28132057], [92.61940002, 24.2867794], [92.6190567, 24.28787041], [92.61723328, 24.28906059], [92.61678314, 24.29123116], [92.61830902, 24.29970932], [92.61802673, 24.30435944], [92.61963654, 24.30846024], [92.61943817, 24.31150818], [92.62310028, 24.32028961], [92.62335205, 24.33077049], [92.62428284, 24.33265114], [92.6261673, 24.33447266], [92.63063812, 24.33337021], [92.6359024, 24.33574104], [92.6377182, 24.33551979], [92.638237, 24.33443069], [92.63654327, 24.33423805], [92.63668823, 24.33269119], [92.63925934, 24.33175087], [92.63983917, 24.32973099], [92.64099121, 24.32871056], [92.6450119, 24.32767105], [92.64594269, 24.32923126], [92.64524841, 24.33181], [92.64904022, 24.32875061], [92.64978027, 24.32922173], [92.6493988, 24.33082008], [92.65184021, 24.33033943], [92.65203857, 24.33286095], [92.65239716, 24.33529091], [92.65645599, 24.33912086], [92.65759277, 24.34155083], [92.65751648, 24.34350967], [92.65847015, 24.34346008], [92.66072083, 24.34514999], [92.6622467, 24.3434391], [92.6632309, 24.34379959], [92.66410828, 24.34674072], [92.66525269, 24.34521103], [92.66699982, 24.34560966], [92.6747818, 24.34980011], [92.67964172, 24.34778023], [92.68379974, 24.34748077], [92.684021, 24.34988976], [92.68799591, 24.35201073], [92.6906662, 24.35480118], [92.69167328, 24.35642052], [92.69177246, 24.36216927], [92.69391632, 24.36363029], [92.69420624, 24.36495972], [92.69325256, 24.36782074], [92.69500732, 24.36956978], [92.69687653, 24.37400055], [92.69827271, 24.37496185], [92.70240784, 24.3752327], [92.70410919, 24.3762207], [92.70343781, 24.38380051], [92.70745087, 24.38701057], [92.70742035, 24.39241028], [92.71421814, 24.40532112], [92.71412659, 24.40777969], [92.71508789, 24.40876961], [92.71420288, 24.41036987], [92.71411896, 24.41296005], [92.71511841, 24.41452026], [92.71813965, 24.41621971], [92.72376251, 24.43594933], [92.73053741, 24.45275116], [92.74360657, 24.47462845], [92.74884033, 24.48854065], [92.7507782, 24.49149132], [92.75132751, 24.49436951], [92.75450134, 24.50111961], [92.75364685, 24.50704193], [92.75918579, 24.51176071], [92.76451111, 24.51883125], [92.76519775, 24.52084923], [92.77913666, 24.48649979], [92.78222656, 24.47480011], [92.78437805, 24.47120285], [92.78624725, 24.4637394], [92.78987885, 24.45607948], [92.79390717, 24.4440403], [92.7977829, 24.43470955], [92.80031586, 24.4319706], [92.80284882, 24.42728043], [92.80425262, 24.4229908], [92.80381775, 24.42172241], [92.80004883, 24.42146111], [92.80079651, 24.41905022], [92.80370331, 24.41879082], [92.80715942, 24.41986275], [92.80948639, 24.41930008], [92.80887604, 24.4168911], [92.80944061, 24.4152317], [92.81140137, 24.41537285], [92.8111496, 24.41364288], [92.81645203, 24.41225052], [92.81832886, 24.41272926], [92.82112885, 24.40678024], [92.82479095, 24.40418053], [92.8303299, 24.40175056], [92.83136749, 24.40050125], [92.83167267, 24.39934158], [92.82659912, 24.39355278], [92.82504272, 24.39049149], [92.82541656, 24.38842964], [92.82826233, 24.38557816], [92.82816315, 24.37931061], [92.82898712, 24.37776947], [92.83270264, 24.37636948], [92.8396225, 24.38080025], [92.84427643, 24.37986946], [92.84690857, 24.38229942], [92.84909058, 24.38613129], [92.85164642, 24.39237022], [92.85447693, 24.39400101], [92.85906219, 24.3984108], [92.86289978, 24.39949989], [92.87178802, 24.39705086], [92.87386322, 24.39725113], [92.87819672, 24.39888954], [92.88424683, 24.40303993], [92.88800812, 24.4016304], [92.89077759, 24.40229034], [92.89173126, 24.40179062], [92.89438629, 24.39530945], [92.8963623, 24.39430046], [92.90097809, 24.39343071], [92.90516663, 24.39445114], [92.90587616, 24.39537048], [92.9057312, 24.3990593], [92.90930939, 24.40316963], [92.91153717, 24.41290092], [92.92339325, 24.40571976], [92.92259979, 24.40415955], [92.92366028, 24.40261078], [92.92537689, 24.40221977], [92.92765045, 24.39862823], [92.93570709, 24.39554024], [92.93773651, 24.39670944], [92.93855286, 24.39902115], [92.94055176, 24.40105057], [92.94415283, 24.40183258], [92.95124817, 24.40483093], [92.95388794, 24.40462112], [92.95469666, 24.40388107], [92.95813751, 24.39805031], [92.96032715, 24.39588165], [92.97083282, 24.40121269], [92.97564697, 24.40776062], [92.98026276, 24.40969086], [92.98542786, 24.40756035], [92.98832703, 24.40764999], [92.99192047, 24.40549278], [92.99534607, 24.40195084], [92.99804688, 24.40157127], [93.00049591, 24.40327072], [93.02435303, 24.3904705], [93.01709747, 24.37996101], [93.0220871, 24.37421989], [93.02011108, 24.36597252], [93.01933289, 24.35884857], [93.0215683, 24.34682083], [93.03176117, 24.34449005], [93.04337311, 24.34338951], [93.03523254, 24.31839943], [93.02391815, 24.3007412], [93.01821899, 24.29315948], [93.01107788, 24.28808022], [93.00821686, 24.28047943], [93.01391602, 24.27166939], [93.00673676, 24.26279068], [93.00670624, 24.25395966], [93.01803589, 24.23637009], [93.02658844, 24.23263168], [93.01940918, 24.22884941], [93.01940155, 24.22508812], [93.02368164, 24.21756935], [93.02229309, 24.21006012], [93.01799774, 24.20754814], [93.01661682, 24.20003128], [93.01236725, 24.19754028], [93.0030365, 24.19752121], [93.00309753, 24.19431114], [93.01091766, 24.18221283], [93.00331116, 24.17404938], [93.00550079, 24.16321182], [93.00544739, 24.1606102], [93.00067139, 24.15673065], [92.99308014, 24.15317917], [92.99112701, 24.15032959], [92.99092102, 24.14686966], [92.99286652, 24.1403904], [92.9894104, 24.13178062], [92.98606873, 24.12887955], [92.97756195, 24.12639046], [92.97360229, 24.12388039], [92.97486877, 24.11701965], [92.97637939, 24.11482048], [92.98477936, 24.11482048], [92.98929596, 24.1163311], [92.99642181, 24.11672974], [93.00068665, 24.11519241], [93.0096817, 24.10995293], [93.01410675, 24.10453033], [93.021492, 24.10145187], [93.02729797, 24.1036396], [93.03029633, 24.10083008], [93.03469849, 24.09924126], [93.03769684, 24.09518051], [93.05368805, 24.09069061], [93.06519318, 24.09427071], [93.07377625, 24.10049057], [93.07949066, 24.10297012], [93.08522797, 24.0903511], [93.08950806, 24.08405113], [93.09520721, 24.0802803], [93.10234833, 24.07401085], [93.10090637, 24.06645012], [93.1023407, 24.06269264], [93.10092926, 24.05639076], [93.1037674, 24.05262947], [93.09951019, 24.04883957], [93.10092163, 24.04508972], [93.10662842, 24.04886055], [93.11087799, 24.05014992], [93.11231232, 24.05519104], [93.11940765, 24.05647278], [93.12081909, 24.06026077], [93.12937164, 24.06408119], [93.13507843, 24.07291985], [93.13508606, 24.07921028], [93.14219666, 24.08678818], [93.14791107, 24.0880909], [93.15846252, 24.08381844], [93.16131592, 24.07756042], [93.1698761, 24.0750618], [93.16986847, 24.07127953], [93.16697693, 24.06121826], [93.16983795, 24.05495262], [93.17552185, 24.05369949], [93.17838287, 24.05409622], [93.19400787, 24.0562706], [93.19825745, 24.05249977], [93.21673584, 24.05006027], [93.22100067, 24.06137085], [93.22242737, 24.06767273], [93.22525024, 24.07396126], [93.22241974, 24.08148956], [93.22383881, 24.08401108], [93.22667694, 24.08653069], [93.2366333, 24.08403969], [93.24233246, 24.08657074], [93.24801636, 24.08533859], [93.26371765, 24.07282066], [93.26373291, 24.06778908], [93.26660919, 24.06026077], [93.26374054, 24.05774117], [93.2623291, 24.05772972], [93.25238037, 24.03383064], [93.25670624, 24.0288105], [93.25528717, 24.02379036], [93.27394867, 24.03392029], [93.27677917, 24.04021072], [93.28536987, 24.04652023], [93.28819275, 24.05154991], [93.29824829, 24.05158997], [93.31254578, 24.05413055], [93.33737183, 24.05340004], [93.33828735, 24.05019188], [93.34221649, 24.0445919], [93.33600616, 24.04261017], [93.33323669, 24.03980064], [93.33764648, 24.0342083], [93.34216309, 24.03067017], [93.33810425, 24.02535629], [93.33692169, 24.02380943], [93.33750153, 24.0212307], [93.33779144, 24.01992035], [93.34031677, 24.01243019], [93.33934784, 24.00291824], [93.33927155, 24.00221062], [93.33895874, 23.99588966], [93.33442688, 23.98694992], [93.33744812, 23.98278999], [93.34236908, 23.98232841], [93.34739685, 23.98069954], [93.35160828, 23.97798157], [93.35315704, 23.9720211], [93.35587311, 23.96125984], [93.35988617, 23.95465279], [93.36241913, 23.95075989], [93.36493683, 23.94597054], [93.36781311, 23.94343948], [93.37104034, 23.94054031], [93.37573242, 23.93782043], [93.38124847, 23.93619156], [93.39097595, 23.93400002], [93.39871979, 23.93028069], [93.39961243, 23.92440033], [93.39919281, 23.91899109], [93.39758301, 23.91292953], [93.39673615, 23.89866829], [93.39559174, 23.88727951], [93.39544678, 23.87670135], [93.39642334, 23.87094116], [93.3968811, 23.86377907], [93.39656067, 23.85853958], [93.39671326, 23.85070038], [93.39705658, 23.84093285], [93.40010071, 23.83532143], [93.39916229, 23.82421112], [93.40141296, 23.81941032], [93.4068985, 23.81714821], [93.40982819, 23.81361008], [93.41098022, 23.80772972], [93.41005707, 23.79879189], [93.40756989, 23.79021072], [93.40444946, 23.77505112], [93.40422821, 23.76898956], [93.4052887, 23.76159096], [93.40712738, 23.75562096], [93.41053772, 23.7486496], [93.41442871, 23.74348068], [93.41539764, 23.73842049], [93.41773224, 23.73254967], [93.41584015, 23.72686005], [93.41493225, 23.72261047], [93.41551971, 23.71809959], [93.41694641, 23.71212959], [93.41912079, 23.70842171], [93.4233017, 23.70399094], [93.42957306, 23.7007103], [93.43651581, 23.69617844], [93.43865967, 23.69219971], [93.44139862, 23.68832016], [93.44470215, 23.68242836], [93.44094086, 23.67819977], [93.43908691, 23.67573929], [93.43611908, 23.67178917], [93.4334259, 23.66719055], [93.43036652, 23.66023064], [93.42827606, 23.65354919], [93.42861938, 23.64515114], [93.42867279, 23.64480972], [93.43271637, 23.61876106], [93.43341064, 23.59509087], [93.43474579, 23.58884048], [93.43305206, 23.58243942], [93.42710876, 23.57169151], [93.42397308, 23.5693512], [93.42402649, 23.56158066], [93.42724609, 23.55298042], [93.42809296, 23.54520035], [93.42775726, 23.53824806], [93.42764282, 23.53437042], [93.42556, 23.53121185], [93.42192841, 23.52716064], [93.41620636, 23.52048111], [93.41116333, 23.51325035], [93.40762329, 23.50848007], [93.4072876, 23.50197029], [93.40814972, 23.49646187], [93.40437317, 23.48498917], [93.40593719, 23.48101044], [93.40706635, 23.47531128], [93.40596008, 23.4672699], [93.40141296, 23.45697975], [93.39977264, 23.44687271], [93.39850616, 23.44288063], [93.39718628, 23.43331146], [93.3973465, 23.42617035], [93.3968277, 23.42247009], [93.39759827, 23.41550064], [93.39826202, 23.4112606], [93.40390778, 23.40166855], [93.40576172, 23.39760017], [93.40975189, 23.39190102], [93.41423798, 23.38801193], [93.40460968, 23.38349915], [93.4016571, 23.37953949], [93.39644623, 23.37402916], [93.39652252, 23.36806107], [93.39875031, 23.36427116], [93.38983917, 23.36275101], [93.37631989, 23.36259079], [93.37162018, 23.3597908], [93.36746979, 23.35808945], [93.36580658, 23.35448074], [93.36629486, 23.35347748], [93.36802673, 23.34994125], [93.37201691, 23.34424973], [93.37534332, 23.34099007], [93.3777771, 23.33754921], [93.37932587, 23.33267975], [93.37754822, 23.32679939], [93.37673187, 23.3194809], [93.37699127, 23.31278992], [93.3776474, 23.30655289], [93.379776, 23.30122185], [93.3812027, 23.29361916], [93.3812027, 23.28992081], [93.37825012, 23.28676033], [93.37539673, 23.28261948], [93.37506104, 23.27457047], [93.37726593, 23.26416969], [93.37841797, 23.25613022], [93.38326263, 23.2448101], [93.38841248, 23.23496056], [93.39470673, 23.2242794], [93.39480591, 23.2195797], [93.38743591, 23.21120071], [93.38659668, 23.20198059], [93.38526154, 23.18797112], [93.38150024, 23.17488289], [93.38057709, 23.16690826], [93.37811279, 23.16349983], [93.3760376, 23.15888023], [93.37394714, 23.15030098], [93.37911224, 23.14361], [93.38292694, 23.14468193], [93.39066315, 23.14792061], [93.39447784, 23.14440155], [93.39364624, 23.13861275], [93.38195801, 23.12751007], [93.37609863, 23.12399101], [93.37227631, 23.12264252], [93.3690567, 23.12058067], [93.36502075, 23.11668968], [93.3640213, 23.11273003], [93.36399841, 23.10621071], [93.36353302, 23.10309029], [93.36308289, 23.10007095], [93.36199951, 23.09537125], [93.35736847, 23.09095001], [93.35246277, 23.08462906], [93.35108948, 23.08030128], [93.35820007, 23.07794189], [93.35781097, 23.07539368], [93.35740662, 23.07278061], [93.35296631, 23.06483078], [93.34516907, 23.06476021], [93.34503937, 23.06448364], [93.34063721, 23.05519104], [93.33676147, 23.04362106], [93.3326416, 23.03567123], [93.32959747, 23.03161049], [93.32408905, 23.02493095], [93.32124329, 23.02186012], [93.31550598, 23.02211761], [93.31498718, 23.0221405], [93.31176758, 23.01871109], [93.3061676, 23.01365089], [93.30195618, 23.00831985], [93.29772186, 23.00579834], [93.29590607, 23.00546455], [93.29332733, 23.00498962], [93.28816223, 23.00462914], [93.27858734, 23.00564003], [93.27391815, 23.01025963], [93.26806641, 23.01234055], [93.25905609, 23.00872993], [93.25319672, 23.00648117], [93.2477417, 23.00955963], [93.24120331, 23.01408005], [93.2378006, 23.01761818], [93.23409271, 23.02186012], [93.23166656, 23.02711105], [93.22815704, 23.03281975], [93.2201767, 23.04520035], [93.21405792, 23.04935074], [93.20616913, 23.05686951], [93.2011795, 23.05778122], [93.19445038, 23.06031036], [93.19093323, 23.05822945], [93.1871109, 23.05715179], [93.18693542, 23.05718422], [93.18302155, 23.05796814], [93.17682648, 23.0530777], [93.17672729, 23.0529995], [93.17211914, 23.05083084], [93.16783142, 23.04902077], [93.16197968, 23.05191994], [93.15563965, 23.05807114], [93.14733887, 23.06169128], [93.14185333, 23.06060982], [93.14028931, 23.0564518], [93.13848114, 23.05482101], [93.13761902, 23.05404282], [93.13687134, 23.05336952], [93.1329422, 23.04750061], [93.13335419, 23.04636955], [93.1350708, 23.04162979], [93.13582611, 23.03520966], [93.13436127, 23.03123093], [93.13162994, 23.02589989], [93.13414001, 23.01984024], [93.13578796, 23.01288033], [93.13021088, 23.00645065], [93.12919617, 23.00076866], [93.13340759, 22.99607086], [93.13739014, 22.99417114], [93.1425705, 22.9937191], [93.14499664, 22.98775101], [93.14762115, 22.98060036], [93.14808655, 22.97555161], [93.14652252, 22.97084808], [93.14272308, 22.96858978], [93.14250183, 22.96442032], [93.14620972, 22.96118164], [93.1488266, 22.95647049], [93.15164185, 22.94997025], [93.15260315, 22.9414711], [93.15344238, 22.93062019], [93.15724945, 22.92673111], [93.16172028, 22.9244709], [93.16610718, 22.92247963], [93.16835022, 22.91913033], [93.16648865, 22.9158802], [93.16366577, 22.91409492], [93.16277313, 22.91353035], [93.15857697, 22.91362], [93.15233612, 22.91291046], [93.14597321, 22.91290283], [93.1387558, 22.9131794], [93.13522339, 22.90722084], [93.1388092, 22.90017128], [93.13832855, 22.89339066], [93.137146, 22.88959122], [93.13555145, 22.88255119], [93.1332016, 22.87520981], [93.13024902, 22.86943054], [93.12387848, 22.86591148], [93.12166595, 22.86275291], [93.12084961, 22.85479164], [93.12151337, 22.84340286], [93.1207962, 22.8373394], [93.11664581, 22.83261871], [93.1156311, 22.83146286], [93.11122131, 22.82821274], [93.11266327, 22.82216072], [93.11544037, 22.82125854], [93.11656952, 22.82089043], [93.11618805, 22.81628036], [93.11435699, 22.81537056], [93.10925293, 22.81283951], [93.10426331, 22.81176186], [93.09926605, 22.81040955], [93.10283661, 22.79214287], [93.10365295, 22.7887001], [93.10402679, 22.78711128], [93.10797119, 22.77026939], [93.11134338, 22.75300026], [93.11268616, 22.74423981], [93.10916138, 22.73781967], [93.10456085, 22.73167038], [93.10192108, 22.72742081], [93.10083771, 22.71955109], [93.09906006, 22.71430969], [93.09545135, 22.71107101], [93.0917511, 22.70934105], [93.09794617, 22.70129967], [93.10417175, 22.69614983], [93.10688782, 22.68629074], [93.10668945, 22.68177032], [93.10315704, 22.67869949], [93.10354614, 22.67408943], [93.10482025, 22.67020035], [93.1074295, 22.6641407], [93.11062622, 22.65908051], [93.11451721, 22.65492058], [93.11849976, 22.65148163], [93.11477661, 22.63919067], [93.11689758, 22.63512039], [93.12428284, 22.63005066], [93.12954712, 22.62924194], [93.13635254, 22.62290955], [93.1390686, 22.61820984], [93.14292908, 22.60762978], [93.14437103, 22.59885979], [93.14560699, 22.58612251], [93.13664246, 22.5818367], [93.13595581, 22.58151054], [93.13371277, 22.57733917], [93.13352966, 22.57722282], [93.12921906, 22.57446289], [93.12442017, 22.56705093], [93.12159729, 22.56000137], [93.11778259, 22.55891037], [93.11553192, 22.55474854], [93.11562347, 22.5538826], [93.11649323, 22.54580116], [93.11599731, 22.54047012], [93.11441803, 22.53685951], [93.11192322, 22.53223228], [93.11168671, 22.53178978], [93.11206818, 22.53164673], [93.11985016, 22.52870941], [93.12578583, 22.52853966], [93.13085175, 22.52610016], [93.13365936, 22.51993942], [93.13062286, 22.51398087], [93.12886047, 22.50982094], [93.13059235, 22.50592995], [93.13272095, 22.50177193], [93.13526154, 22.49897003], [93.13777924, 22.49509048], [93.13832855, 22.48658943], [93.13626862, 22.47961998], [93.13452148, 22.4748497], [93.13514709, 22.47390556], [93.13819122, 22.4693203], [93.14206696, 22.46326065], [93.14575195, 22.45846939], [93.14972687, 22.45593071], [93.15672302, 22.45214081], [93.16277313, 22.45376015], [93.17542267, 22.45132065], [93.17811584, 22.44662094], [93.18218994, 22.43875122], [93.18789673, 22.43367004], [93.19081116, 22.42725945], [93.18904114, 22.42328072], [93.18826294, 22.41893959], [93.1889267, 22.41351128], [93.19425964, 22.40890121], [93.19551086, 22.40330124], [93.19325256, 22.3991394], [93.19149017, 22.39587975], [93.19226837, 22.3908329], [93.19641113, 22.38412285], [93.19738007, 22.37997246], [93.19258881, 22.37083817], [93.19451141, 22.36343002], [93.1971283, 22.35863113], [93.19998169, 22.34361839], [93.19948578, 22.33719826], [93.20266724, 22.33366966], [93.20656586, 22.32953072], [93.20287323, 22.32726288], [93.19634247, 22.32464027], [93.19843292, 22.32011032], [93.1995163, 22.3177681], [93.20057678, 22.31315041], [93.20133972, 22.30610085], [93.2016983, 22.29986], [93.20108795, 22.29199028], [93.20155334, 22.28647995], [93.20192719, 22.28087044], [93.2039566, 22.2757225], [93.2073288, 22.26967049], [93.20925903, 22.26622009], [93.20858002, 22.26106834], [93.19641113, 22.25564957], [93.19036865, 22.24969292], [93.18366241, 22.24913979], [93.17093658, 22.24970055], [93.16597748, 22.24888039], [93.16033936, 22.24707985], [93.15718842, 22.24743271], [93.15463257, 22.24771881], [93.15149689, 22.24806976], [93.14710999, 22.24654007], [93.14643097, 22.24111176], [93.15194702, 22.23468971], [93.1565094, 22.22871971], [93.15764618, 22.22311974], [93.15627289, 22.21742058], [93.15856934, 22.21120262], [93.15907288, 22.20984077], [93.16594696, 22.20522118], [93.16982269, 22.20005989], [93.16677094, 22.19434166], [93.16639709, 22.19363976], [93.16537476, 22.19028473], [93.16295624, 22.18234062], [93.15441132, 22.17819023], [93.14839172, 22.17683029], [93.14286804, 22.1767807], [93.13868713, 22.17674065], [93.13070679, 22.1790905], [93.1275177, 22.18235016], [93.12277985, 22.18904114], [93.11988068, 22.1985302], [93.11717987, 22.20133018], [93.11238861, 22.20080376], [93.11154175, 22.2007103], [93.10221863, 22.19880104], [93.09726715, 22.19934082], [93.08882141, 22.20260048], [93.08769226, 22.20357513], [93.08589935, 22.20512962], [93.08154297, 22.20839119], [93.07698822, 22.21010971], [93.07247162, 22.20852661], [93.07154083, 22.20820045], [93.06764984, 22.20639038], [93.05977631, 22.20395279], [93.0538559, 22.2032299], [93.0491333, 22.19954491], [93.04830933, 22.19890022], [93.04666138, 22.19762039], [93.04608917, 22.19658852], [93.0456543, 22.19579697], [93.04450989, 22.1937294], [93.04653931, 22.19001961], [93.05370331, 22.1758194], [93.05493927, 22.16543007], [93.05200958, 22.15666008], [93.05082703, 22.15014076], [93.04801941, 22.14581108], [93.04698944, 22.13905907], [93.04692841, 22.13866997], [93.05409241, 22.13170052], [93.05921936, 22.12754059], [93.06260681, 22.12086105], [93.06648254, 22.11326981], [93.06556702, 22.10205269], [93.05976105, 22.09979057], [93.05208588, 22.09924126], [93.04627228, 22.10132027], [93.03917694, 22.10493088], [93.03649139, 22.10493088], [93.03219604, 22.10493088], [93.02297974, 22.10564995], [93.01597595, 22.10547066], [93.01326752, 22.102211], [93.01325226, 22.09805107], [93.01558685, 22.09308052], [93.01449585, 22.0852108], [93.0117569, 22.07933044], [93.0080719, 22.06991959], [93.00377655, 22.0611496], [93.00076294, 22.05564117], [92.99996948, 22.05038071], [92.99994659, 22.03954124], [93.00066376, 22.03629875], [93.00158691, 22.03212166], [93.00671387, 22.02301216], [93.00845337, 22.01992035], [93.01037598, 22.01115036], [93.00958252, 22.00265121], [93.01014709, 21.99578094], [93.00985718, 21.9917202], [93.00924683, 21.98393059], [93.00662994, 21.97986031], [92.99897766, 21.97794914], [92.99238586, 21.98084068], [92.98802948, 21.98291969], [92.98739624, 21.98496056], [92.98580933, 21.99006271], [92.98175049, 22.00189972], [92.97953033, 22.0064106], [92.9731369, 22.00995255], [92.9694519, 22.01411057], [92.96692657, 22.02025986], [92.96656799, 22.02712059], [92.9609375, 22.03018951], [92.95580292, 22.02992058], [92.95281982, 22.02738571], [92.95111847, 22.02593994], [92.94843292, 22.02286148], [92.94210815, 22.01834106], [92.94023895, 22.0187664], [92.93463898, 22.02004051], [92.93161011, 22.01750946], [92.93395996, 22.01475143], [92.93569183, 22.01272011], [92.93908691, 22.00855827], [92.93216705, 22.00186157], [92.92771149, 21.99588966], [92.92479706, 21.98711014], [92.92225647, 21.98080254], [92.91944885, 21.97382164], [92.91575623, 21.96504974], [92.91446686, 21.95663071], [92.91610718, 21.94940948], [92.91088867, 21.94622993], [92.90797424, 21.95045471], [92.90583801, 21.95355034], [92.90471649, 21.98076057], [92.90133667, 21.99035072], [92.89640808, 22.00390053], [92.89425659, 22.01196289], [92.88942719, 22.01818275], [92.88574219, 22.02152061], [92.87953949, 22.02593994], [92.87467957, 22.03009987], [92.87246704, 22.03651047], [92.87130737, 22.04664993], [92.87014771, 22.05424118], [92.87016296, 22.06075096], [92.86773682, 22.06536293], [92.86328125, 22.06762123], [92.856987, 22.06563187]]]}}, {\\\"id\\\": \\\"21\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.24_1\\\", \\\"HASC_1\\\": \\\"IN.NL\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Nagaland\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -2.3, \\\"dalys_apm25_rate_6cod_mean_total\\\": 752.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1847.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1095.0, \\\"geo-id\\\": 21, \\\"hpm25_child_popweighted\\\": -152.5, \\\"hpm25_female_popweighted\\\": -175.2, \\\"hpm25_male_popweighted\\\": -126.2, \\\"location\\\": \\\"Nagaland\\\", \\\"mort_apm25_6cod_mean_total\\\": 453.0, \\\"mort_hpm25_6cod_mean_total\\\": -1085.0, \\\"mort_tpm25_6cod_mean_total\\\": -632.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[93.33174133, 25.54681015], [93.33338165, 25.54902077], [93.34126282, 25.55485916], [93.34546661, 25.56112099], [93.34831238, 25.56321907], [93.35439301, 25.56520081], [93.36070251, 25.56043816], [93.36418152, 25.56064987], [93.36598206, 25.56326103], [93.36515808, 25.56976128], [93.36943817, 25.57025909], [93.37342072, 25.56917191], [93.37599182, 25.57104111], [93.37683868, 25.57374001], [93.37648773, 25.57731056], [93.38269806, 25.5761795], [93.38474274, 25.57792091], [93.38503265, 25.58119965], [93.38311005, 25.58279991], [93.38240051, 25.58475113], [93.39063263, 25.58909988], [93.3900528, 25.59472084], [93.40019989, 25.59628105], [93.40683746, 25.59647942], [93.40924835, 25.60041046], [93.40963745, 25.60410118], [93.40722656, 25.60649109], [93.40763855, 25.60942078], [93.40904999, 25.61169052], [93.41227722, 25.61367989], [93.41677856, 25.61488914], [93.41487122, 25.61664009], [93.41829681, 25.62105942], [93.42247009, 25.62226105], [93.42753601, 25.63145828], [93.43102264, 25.62920189], [93.43418121, 25.62986946], [93.43908691, 25.63233948], [93.4391861, 25.63439941], [93.44152069, 25.63478088], [93.44439697, 25.63804245], [93.4467926, 25.63881111], [93.44993591, 25.63493156], [93.45198059, 25.63747978], [93.45935822, 25.63312912], [93.46195984, 25.63339043], [93.46121979, 25.6365509], [93.45860291, 25.6384201], [93.45713806, 25.64059067], [93.46070099, 25.64154816], [93.46556854, 25.64419174], [93.46852875, 25.64376068], [93.47477722, 25.64429092], [93.47593689, 25.64798927], [93.48335266, 25.64576912], [93.4835968, 25.6517601], [93.48721313, 25.65047073], [93.49072266, 25.65343857], [93.49019623, 25.65596962], [93.49394226, 25.65526009], [93.49991608, 25.65652084], [93.50208282, 25.66201973], [93.50829315, 25.66681099], [93.51019287, 25.67102051], [93.52028656, 25.68367004], [93.51938629, 25.68597031], [93.51683807, 25.6880703], [93.52272797, 25.69320107], [93.52593994, 25.6996727], [93.52855682, 25.69376945], [93.53057098, 25.69269943], [93.53149414, 25.69400597], [93.53797913, 25.70319939], [93.54355621, 25.70170021], [93.54441833, 25.70590019], [93.54592896, 25.71018982], [93.54881287, 25.7147007], [93.5497818, 25.71897125], [93.54619598, 25.72151947], [93.54483795, 25.72697067], [93.54669952, 25.73447037], [93.54988098, 25.73244095], [93.55692291, 25.73773956], [93.55626678, 25.7419281], [93.56194305, 25.74094963], [93.56548309, 25.74134064], [93.57006073, 25.7517395], [93.56925201, 25.7550106], [93.57341766, 25.75661087], [93.57382202, 25.75966072], [93.57324982, 25.76079941], [93.58377075, 25.75774956], [93.58718872, 25.75945091], [93.58712006, 25.76555061], [93.58822632, 25.76815033], [93.59266663, 25.76624107], [93.59371185, 25.76428986], [93.5983429, 25.76836014], [93.60275269, 25.77082062], [93.60556793, 25.76745987], [93.60571289, 25.77263069], [93.60807037, 25.77687073], [93.61141205, 25.77649117], [93.62232971, 25.77983093], [93.62355804, 25.78392029], [93.6211319, 25.78523064], [93.62381744, 25.79042816], [93.62695313, 25.79160118], [93.62753296, 25.79862976], [93.62979889, 25.79998016], [93.6289978, 25.80439949], [93.63334656, 25.80524063], [93.63405609, 25.80997086], [93.63611603, 25.81368065], [93.64029694, 25.81343079], [93.64099884, 25.81792068], [93.64435577, 25.81957054], [93.64849091, 25.82397079], [93.65235901, 25.82282066], [93.65673828, 25.82635117], [93.66082764, 25.82438087], [93.66860962, 25.82463074], [93.66950989, 25.82879257], [93.67256165, 25.82812119], [93.67806244, 25.82887077], [93.68287659, 25.83575058], [93.68250275, 25.84070015], [93.6920166, 25.84412956], [93.6905365, 25.84756851], [93.69377136, 25.84724998], [93.69785309, 25.85131264], [93.70359039, 25.85350037], [93.70363617, 25.84970093], [93.70237732, 25.84699059], [93.70548248, 25.84863091], [93.70643616, 25.85329056], [93.69090271, 25.88927078], [93.68582916, 25.90493965], [93.68768311, 25.90944099], [93.69767761, 25.91706848], [93.70506287, 25.92127991], [93.71250916, 25.92267036], [93.71650696, 25.9217205], [93.72894287, 25.92839813], [93.7364502, 25.93053818], [93.75009155, 25.93728065], [93.75184631, 25.93637085], [93.75202179, 25.9396019], [93.74941254, 25.94205093], [93.7588501, 25.94869041], [93.76278687, 25.95492935], [93.76841736, 25.95504951], [93.77025604, 25.95350075], [93.76954651, 25.95799065], [93.77301788, 25.96602058], [93.77881622, 25.96325111], [93.78028107, 25.96060944], [93.78518677, 25.95829964], [93.78660583, 25.95423126], [93.78942108, 25.95258141], [93.7891922, 25.94901085], [93.78659821, 25.9474411], [93.78940582, 25.94602013], [93.79067993, 25.94419098], [93.79141998, 25.94005013], [93.7932663, 25.93674088], [93.78862, 25.93296051], [93.79321289, 25.93098068], [93.79360962, 25.92604065], [93.79226685, 25.92251968], [93.7963028, 25.91819191], [93.79833221, 25.90969276], [93.79811096, 25.90628815], [93.79573059, 25.90121078], [93.79514313, 25.89804077], [93.79184723, 25.89491272], [93.79145813, 25.89005852], [93.7874527, 25.87892914], [93.78827667, 25.87572098], [93.79064178, 25.8737812], [93.79181671, 25.86969185], [93.78578186, 25.86689949], [93.78528595, 25.86326027], [93.78147125, 25.8592701], [93.78359222, 25.85392952], [93.78296661, 25.85140038], [93.78380585, 25.84996033], [93.7798233, 25.84630966], [93.78108978, 25.84464073], [93.78259277, 25.8382206], [93.78452301, 25.8357811], [93.78734589, 25.82796288], [93.78875732, 25.82601929], [93.79070282, 25.82080078], [93.7913208, 25.8160305], [93.79576111, 25.81435013], [93.80758667, 25.81633759], [93.81157684, 25.82126999], [93.81884003, 25.8262291], [93.82137299, 25.83240128], [93.82430267, 25.84709167], [93.83274078, 25.85625076], [93.84233856, 25.86260986], [93.85170746, 25.86297035], [93.86872864, 25.85540962], [93.87362671, 25.85091972], [93.88273621, 25.84590912], [93.8885498, 25.85246086], [93.89161682, 25.85864067], [93.89340973, 25.86481094], [93.89861298, 25.86375046], [93.90184021, 25.87103081], [93.91382599, 25.88176918], [93.91590118, 25.88766289], [93.92385101, 25.88980293], [93.93463135, 25.8914299], [93.94019318, 25.90096092], [93.94835663, 25.90120125], [93.95983887, 25.90525055], [93.96075439, 25.90585518], [93.96916962, 25.91142273], [93.97197723, 25.9175396], [93.97939301, 25.91967964], [93.98268127, 25.92626953], [93.97109222, 25.94485283], [93.97084808, 25.95326042], [93.96920776, 25.96084023], [93.95600891, 25.97418976], [93.95804596, 25.9815712], [93.96058655, 25.99700928], [93.95897675, 26.00245857], [93.95598602, 26.00457001], [93.95488739, 26.00732994], [93.95838165, 26.01189041], [93.96266174, 26.02215958], [93.96312714, 26.0333519], [93.96588898, 26.04240036], [93.97263336, 26.04496193], [93.97450256, 26.05216026], [93.98081207, 26.0586319], [93.99111938, 26.07263947], [93.98938751, 26.07411957], [93.98602295, 26.08356857], [93.98642731, 26.0883007], [93.9909668, 26.08949089], [93.99249268, 26.09278107], [93.99217224, 26.09782982], [93.994133, 26.10608864], [93.99957275, 26.10847092], [94.00216675, 26.11137962], [94.00213623, 26.11486053], [93.99986267, 26.11590958], [93.99495697, 26.11570168], [93.99124146, 26.11812019], [93.99282074, 26.12026978], [93.99648285, 26.12236977], [93.99661255, 26.1281395], [93.99832916, 26.12935829], [93.99830627, 26.13097954], [93.99326324, 26.13281822], [93.99075317, 26.13387108], [93.99320221, 26.13739014], [93.99627686, 26.13741112], [93.99965668, 26.1364994], [94.00309753, 26.13902092], [94.00522614, 26.14186096], [94.00636292, 26.14723969], [94.0029068, 26.15133858], [93.99965668, 26.15824127], [94.00434875, 26.16407013], [94.00389862, 26.16938019], [94.00480652, 26.17327118], [94.00876617, 26.18053055], [94.01300049, 26.1862812], [94.0219574, 26.19145966], [94.02661896, 26.19714928], [94.03109741, 26.19939041], [94.03573608, 26.20318985], [94.03681946, 26.20972061], [94.03656006, 26.21771049], [94.04046631, 26.22351074], [94.03816986, 26.22951126], [94.04178619, 26.23389053], [94.04421997, 26.23996925], [94.0491333, 26.25021172], [94.05285645, 26.25579071], [94.06463623, 26.26177025], [94.07047272, 26.26003075], [94.07601929, 26.26923943], [94.07781982, 26.27535057], [94.07682037, 26.28520012], [94.08006287, 26.28881073], [94.08444214, 26.28860092], [94.08722687, 26.29042053], [94.09028625, 26.29713058], [94.09807587, 26.30294037], [94.10267639, 26.30869102], [94.10447693, 26.32204056], [94.10804749, 26.32640076], [94.11128998, 26.3260498], [94.1184082, 26.32271957], [94.12872314, 26.32324982], [94.11936188, 26.33049011], [94.11936951, 26.33370018], [94.12397003, 26.3359108], [94.13565826, 26.33821869], [94.13877106, 26.34155273], [94.14264679, 26.34213066], [94.14383698, 26.34020042], [94.14224243, 26.3360405], [94.14671326, 26.33542061], [94.14932251, 26.33908081], [94.15453339, 26.33998108], [94.16452026, 26.33934021], [94.17214966, 26.34440994], [94.17550659, 26.34421921], [94.17928314, 26.35083961], [94.17999268, 26.35412025], [94.17533875, 26.35513115], [94.16938019, 26.35406113], [94.1676712, 26.35330963], [94.16446686, 26.36012077], [94.17357635, 26.36757851], [94.17560577, 26.37175941], [94.17549133, 26.37445068], [94.17404938, 26.37782288], [94.17909241, 26.38872147], [94.17694092, 26.39956093], [94.17684174, 26.41341019], [94.17401123, 26.42089081], [94.1765213, 26.42807007], [94.17575836, 26.43180084], [94.18654633, 26.46051025], [94.20111847, 26.46990013], [94.20936584, 26.48372269], [94.21148682, 26.48984909], [94.22361755, 26.5005703], [94.22891998, 26.50326157], [94.23989105, 26.51143074], [94.24482727, 26.51692009], [94.25205231, 26.52773285], [94.25331879, 26.53252983], [94.26257324, 26.54394913], [94.27674103, 26.5588398], [94.2822876, 26.56353951], [94.28978729, 26.5641098], [94.28890991, 26.55990028], [94.28530884, 26.55824089], [94.28483582, 26.5553627], [94.28562164, 26.54656982], [94.28494263, 26.54029083], [94.28562164, 26.53409195], [94.2890625, 26.52517128], [94.28878784, 26.51831818], [94.28707123, 26.51496124], [94.28723907, 26.50852013], [94.29023743, 26.49596977], [94.29242706, 26.49003029], [94.29392242, 26.4807415], [94.30330658, 26.46726036], [94.31098175, 26.46606064], [94.31347656, 26.46500015], [94.31651306, 26.46293068], [94.32430267, 26.47070122], [94.32478333, 26.47220993], [94.32388306, 26.47937965], [94.32932281, 26.48384094], [94.33259583, 26.48502922], [94.33693695, 26.48481941], [94.34340668, 26.49003983], [94.34963226, 26.49284172], [94.35206604, 26.49575043], [94.3518219, 26.49920273], [94.3535614, 26.50215912], [94.35552979, 26.50345039], [94.35372162, 26.50481033], [94.35111237, 26.50862122], [94.35459137, 26.51028061], [94.35874939, 26.50914192], [94.36445618, 26.5103302], [94.36924744, 26.50999069], [94.37761688, 26.51312065], [94.37806702, 26.51716042], [94.37690735, 26.52317047], [94.37827301, 26.52526093], [94.39141083, 26.53282928], [94.39408875, 26.53264046], [94.39656067, 26.52973175], [94.39945221, 26.53232002], [94.39891815, 26.53454971], [94.40248108, 26.53880119], [94.40133667, 26.54408073], [94.40267944, 26.54686165], [94.40674591, 26.5482502], [94.40795135, 26.54971123], [94.40763855, 26.55240059], [94.40479279, 26.55523109], [94.40609741, 26.55738068], [94.40896606, 26.55713081], [94.41195679, 26.5584507], [94.41057587, 26.56059837], [94.40776062, 26.56142807], [94.40930939, 26.56899071], [94.41188049, 26.5734005], [94.41484833, 26.58328056], [94.40600586, 26.60193062], [94.40857697, 26.6097908], [94.40786743, 26.61433029], [94.40988159, 26.61643982], [94.43448639, 26.62537956], [94.45452118, 26.63902092], [94.45681, 26.63664055], [94.46250153, 26.6354599], [94.46482086, 26.63871002], [94.46446228, 26.64036942], [94.46166229, 26.64384079], [94.46141815, 26.64809036], [94.45857239, 26.65534973], [94.46183014, 26.66316032], [94.46452332, 26.66751099], [94.46794128, 26.66982079], [94.48574829, 26.67370033], [94.49279785, 26.67225266], [94.49826813, 26.67371178], [94.5, 26.67516708], [94.50300598, 26.67769051], [94.50714111, 26.68297958], [94.50994873, 26.68342972], [94.51550293, 26.68729973], [94.51967621, 26.69460106], [94.52009583, 26.70145035], [94.52272797, 26.70436859], [94.52776337, 26.70128059], [94.54087067, 26.70963287], [94.5450592, 26.71090126], [94.55036926, 26.71017075], [94.55467224, 26.70844078], [94.56112671, 26.70813942], [94.56343842, 26.70737076], [94.56472778, 26.70600128], [94.56233215, 26.69383049], [94.56295013, 26.69063187], [94.56608582, 26.68992805], [94.57086945, 26.69005966], [94.57469177, 26.69102097], [94.57150269, 26.69622231], [94.58278656, 26.70557976], [94.58538818, 26.70331001], [94.58898163, 26.70244026], [94.59240723, 26.70273018], [94.59493256, 26.7065506], [94.59501648, 26.71236038], [94.59616852, 26.7181797], [94.59831238, 26.71994019], [94.60372162, 26.71617126], [94.60468292, 26.71721077], [94.60463715, 26.71985245], [94.60318756, 26.7238102], [94.60048676, 26.72525978], [94.59333038, 26.72613144], [94.5951767, 26.72989082], [94.59993744, 26.73772049], [94.60414886, 26.7392807], [94.61006165, 26.74010277], [94.61044312, 26.73586082], [94.61194611, 26.73265076], [94.61740112, 26.73055077], [94.62014771, 26.72673988], [94.62108612, 26.72117043], [94.62271881, 26.71953011], [94.6282959, 26.71862984], [94.63197327, 26.71965027], [94.64028931, 26.72397041], [94.64621735, 26.72451019], [94.65338898, 26.72363091], [94.65853882, 26.72480011], [94.66513824, 26.72776031], [94.68660736, 26.73258972], [94.69148254, 26.73575974], [94.69687653, 26.73969078], [94.71140289, 26.75282288], [94.71969604, 26.75803947], [94.73188019, 26.76400948], [94.73651123, 26.76741028], [94.73773193, 26.76885033], [94.74167633, 26.77357101], [94.74236298, 26.77864075], [94.7457962, 26.78214073], [94.75071716, 26.77967072], [94.75409698, 26.77431107], [94.75637054, 26.7722683], [94.75934601, 26.7741375], [94.76003265, 26.77662849], [94.76235962, 26.77993011], [94.76832581, 26.78339767], [94.76906586, 26.79109955], [94.77308655, 26.79496193], [94.7856369, 26.79857063], [94.79078674, 26.80145264], [94.79496002, 26.80373192], [94.80220795, 26.80606079], [94.80535889, 26.81219101], [94.80161285, 26.81381035], [94.79664612, 26.81851959], [94.80671692, 26.82122993], [94.80918121, 26.82328033], [94.81305695, 26.82476044], [94.81507111, 26.8300209], [94.8154068, 26.83680916], [94.81669617, 26.84147072], [94.8210907, 26.84486961], [94.82173157, 26.84930992], [94.82108307, 26.85445976], [94.82628632, 26.85931015], [94.83226013, 26.86271095], [94.8364563, 26.8684597], [94.83878326, 26.87400055], [94.84584045, 26.876791], [94.85153198, 26.88134003], [94.85334778, 26.88533974], [94.85900879, 26.89328003], [94.8653183, 26.90690994], [94.86862183, 26.90989113], [94.86963654, 26.91500854], [94.88154602, 26.92671013], [94.88622284, 26.93246078], [94.89447021, 26.93733025], [94.90129089, 26.94034004], [94.90882111, 26.94227028], [94.91385651, 26.94256973], [94.91799164, 26.94514275], [94.92376709, 26.95033073], [94.92816162, 26.95210075], [94.93360138, 26.93853951], [94.93855286, 26.93797112], [94.94122314, 26.93927193], [94.94709015, 26.94020081], [94.95728302, 26.94355011], [94.96417236, 26.9406414], [94.96676636, 26.93618011], [94.96794128, 26.93148994], [94.97067261, 26.92836189], [94.97425842, 26.92760277], [94.97966003, 26.92462158], [94.985672, 26.91824913], [94.98944855, 26.91782951], [94.99205017, 26.91838837], [94.99118805, 26.92292023], [94.99305725, 26.92616081], [94.99946594, 26.9242897], [95.00579071, 26.92486954], [95.01657104, 26.92435265], [95.02134705, 26.92539978], [95.02855682, 26.93251038], [95.03804779, 26.93848038], [95.05464935, 26.94087982], [95.06533813, 26.94819069], [95.08686066, 26.95274162], [95.11004639, 26.96690941], [95.11322021, 26.97232056], [95.1135025, 26.97758102], [95.11694336, 26.98368073], [95.12638092, 26.98690987], [95.13698578, 26.99357986], [95.14276123, 26.99830055], [95.14948273, 26.99983978], [95.15450287, 27.00604057], [95.19551849, 27.04294968], [95.19579315, 27.03250122], [95.19785309, 27.01984024], [95.19761658, 27.01568985], [95.20008087, 27.0062294], [95.19982147, 26.99935913], [95.19626617, 26.99781036], [95.19519806, 26.98999023], [95.20043945, 26.98555946], [95.20775604, 26.98470116], [95.20996094, 26.98262978], [95.20522308, 26.9821701], [95.20655823, 26.9788208], [95.20877075, 26.97508049], [95.21504211, 26.97037125], [95.21366882, 26.96812057], [95.20883942, 26.9653511], [95.20675659, 26.96259117], [95.20851135, 26.9607296], [95.21341705, 26.95878983], [95.20923615, 26.95667076], [95.21219635, 26.94334984], [95.21444702, 26.93695068], [95.21705627, 26.93420029], [95.22556305, 26.93442917], [95.22930908, 26.93063164], [95.23184967, 26.92614174], [95.23396301, 26.92060089], [95.23396301, 26.91875267], [95.23195648, 26.91789055], [95.23208618, 26.91483116], [95.23410034, 26.9096508], [95.23377228, 26.90590286], [95.23132324, 26.89834976], [95.2338562, 26.89084053], [95.22992706, 26.88566971], [95.21782684, 26.88686943], [95.21285248, 26.88560295], [95.21135712, 26.88173294], [95.20642853, 26.87787056], [95.18450165, 26.86483002], [95.18576813, 26.85963058], [95.19304657, 26.85116959], [95.19561005, 26.84962082], [95.19732666, 26.84939194], [95.19770813, 26.85153961], [95.20423889, 26.8489399], [95.20860291, 26.85071945], [95.20641327, 26.84628105], [95.20050812, 26.84287834], [95.19904327, 26.83992958], [95.20056152, 26.83288956], [95.20258331, 26.82875061], [95.20355225, 26.82131958], [95.20684052, 26.81169128], [95.21511841, 26.7983799], [95.22157288, 26.79354095], [95.2274704, 26.79234123], [95.23501587, 26.78928947], [95.24025726, 26.78917122], [95.24172211, 26.78693008], [95.24491882, 26.78733063], [95.24253845, 26.78451157], [95.23467255, 26.78034973], [95.23163605, 26.77769279], [95.23330688, 26.77371979], [95.23317719, 26.77193069], [95.22920227, 26.76847076], [95.22408295, 26.76172256], [95.2201004, 26.75982094], [95.21926117, 26.75555038], [95.22136688, 26.75152016], [95.22097778, 26.7474308], [95.21685028, 26.74130058], [95.21614075, 26.73531914], [95.22820282, 26.72384834], [95.2296524, 26.71688271], [95.23610687, 26.7122097], [95.23369598, 26.69709969], [95.23596954, 26.69152069], [95.23597717, 26.68823051], [95.23763275, 26.68629074], [95.23449707, 26.68307114], [95.23166656, 26.6776104], [95.22805786, 26.67307091], [95.22743225, 26.67202187], [95.22473145, 26.66752052], [95.21948242, 26.66065025], [95.21485901, 26.6556797], [95.20983887, 26.65150833], [95.20780945, 26.65019608], [95.20616913, 26.64912987], [95.1969986, 26.64735985], [95.19127655, 26.64771843], [95.18202209, 26.64326096], [95.17431641, 26.63418007], [95.17141724, 26.63006973], [95.16478729, 26.62660217], [95.16137695, 26.62482262], [95.15833282, 26.62322998], [95.15470886, 26.61948967], [95.1537323, 26.60957909], [95.15248871, 26.60183907], [95.15220642, 26.59761047], [95.1530304, 26.59361839], [95.15622711, 26.58681107], [95.15448761, 26.58080292], [95.15081787, 26.57681847], [95.14875031, 26.5745697], [95.14450073, 26.56788063], [95.14442444, 26.56365013], [95.14441681, 26.56301117], [95.14274597, 26.56228828], [95.1385498, 26.56047249], [95.13384247, 26.56235123], [95.1268158, 26.56235123], [95.12468719, 26.55661011], [95.12132263, 26.55295181], [95.11479187, 26.54800034], [95.11642456, 26.5447979], [95.1190567, 26.53964806], [95.12077332, 26.53447914], [95.12078094, 26.52979088], [95.11315155, 26.51871109], [95.11251068, 26.51838112], [95.10684967, 26.51547813], [95.10349274, 26.51288986], [95.10462189, 26.50909996], [95.10241699, 26.50317955], [95.09599304, 26.49847984], [95.09099579, 26.49459076], [95.08790588, 26.49065971], [95.08403015, 26.48594284], [95.08200836, 26.48358917], [95.08042145, 26.48174095], [95.07920074, 26.48060799], [95.07602692, 26.47766113], [95.07578278, 26.47587013], [95.07543945, 26.47333908], [95.07232666, 26.46982956], [95.07196045, 26.46941948], [95.06878662, 26.4666729], [95.06720734, 26.46154976], [95.06630707, 26.45677948], [95.06640625, 26.45037079], [95.07171631, 26.4503994], [95.07508087, 26.45243263], [95.07630157, 26.4525795], [95.08161926, 26.4532299], [95.08702087, 26.45198822], [95.09056091, 26.44725037], [95.09681702, 26.43939972], [95.09998322, 26.43602943], [95.10151672, 26.43267059], [95.10618591, 26.42999077], [95.1086731, 26.42373085], [95.1076889, 26.41880035], [95.1058197, 26.41502953], [95.10544586, 26.41106033], [95.10495758, 26.40646935], [95.10476685, 26.40125084], [95.12166595, 26.39804077], [95.12503815, 26.39546967], [95.13085175, 26.39060974], [95.13574219, 26.38783264], [95.13594055, 26.38323021], [95.13458252, 26.37568283], [95.13191223, 26.36670113], [95.12973022, 26.36203957], [95.1282959, 26.35466194], [95.13165283, 26.3465004], [95.13347626, 26.34259987], [95.12753296, 26.3359108], [95.1280365, 26.33068085], [95.12822723, 26.32925987], [95.12874603, 26.32534981], [95.12937164, 26.32164192], [95.12989807, 26.3172226], [95.13123322, 26.30737114], [95.13153839, 26.30258179], [95.13082886, 26.29655075], [95.13114929, 26.29249954], [95.12979126, 26.28872108], [95.12709045, 26.28498077], [95.12126923, 26.27937126], [95.12069702, 26.27487183], [95.12268829, 26.26870918], [95.12490845, 26.2642498], [95.1287384, 26.26023293], [95.12966919, 26.25617027], [95.12831879, 26.25258064], [95.1257782, 26.24583817], [95.12290192, 26.2425499], [95.12123108, 26.23870087], [95.12313843, 26.23298073], [95.12837219, 26.22949028], [95.13320923, 26.22564125], [95.14058685, 26.21813011], [95.14253998, 26.21424103], [95.13822937, 26.20924187], [95.13420105, 26.20767021], [95.1282959, 26.2031498], [95.12467194, 26.19662094], [95.12773132, 26.19395828], [95.12581635, 26.18272018], [95.12298584, 26.1763382], [95.12021637, 26.17225075], [95.11805725, 26.16893959], [95.11683655, 26.16300964], [95.12049866, 26.15510941], [95.12378693, 26.14911079], [95.12787628, 26.13697052], [95.12535858, 26.13132286], [95.12317657, 26.12766266], [95.12088776, 26.12199974], [95.12056732, 26.10974121], [95.12325287, 26.1042099], [95.12671661, 26.10099983], [95.13150024, 26.10031128], [95.13804626, 26.10255814], [95.14422607, 26.10095024], [95.14797974, 26.09791946], [95.15162659, 26.09489059], [95.15746307, 26.0961628], [95.16591644, 26.09901047], [95.17098999, 26.09678268], [95.17698669, 26.09227943], [95.18015289, 26.08980942], [95.18535614, 26.08468246], [95.18569946, 26.08035088], [95.18357086, 26.07451057], [95.18161011, 26.07258797], [95.18031311, 26.07131004], [95.17752838, 26.0675602], [95.17302704, 26.06175995], [95.16805267, 26.05776978], [95.16557312, 26.05337906], [95.16519165, 26.04455948], [95.16500092, 26.03887177], [95.16488647, 26.03725052], [95.16471863, 26.03500175], [95.1626358, 26.03141975], [95.16140747, 26.0302906], [95.14891052, 26.01881027], [95.14264679, 26.01086807], [95.14066315, 26.00647163], [95.1366272, 26.00418091], [95.13154602, 26.00010109], [95.12798309, 25.99527931], [95.11753845, 25.9877491], [95.11010742, 25.9756794], [95.10971832, 25.9748764], [95.1064682, 25.96815109], [95.10016632, 25.96494675], [95.09335327, 25.96148109], [95.08847809, 25.95757294], [95.07894897, 25.95083809], [95.07344055, 25.94902992], [95.06549835, 25.94767952], [95.05741119, 25.94697762], [95.05306244, 25.94450188], [95.04995728, 25.93922043], [95.04489899, 25.93478966], [95.03669739, 25.93507004], [95.0358429, 25.93147087], [95.03617859, 25.92861176], [95.03636169, 25.9270401], [95.03311157, 25.92438126], [95.0280304, 25.9198494], [95.02186584, 25.90999985], [95.02146149, 25.90901947], [95.02009583, 25.90570068], [95.01933289, 25.90102005], [95.01978302, 25.89800072], [95.02030182, 25.89451027], [95.02217102, 25.88754082], [95.01902771, 25.88479042], [95.01747894, 25.8829422], [95.01557159, 25.88067245], [95.01557159, 25.88053703], [95.01541138, 25.87202072], [95.01824188, 25.86783028], [95.02142334, 25.86185074], [95.02436829, 25.85847092], [95.02754974, 25.85148048], [95.0300293, 25.84931946], [95.03322601, 25.84653091], [95.03371429, 25.84041977], [95.03423309, 25.83389091], [95.03462982, 25.82896042], [95.03475189, 25.8274498], [95.03497314, 25.82641983], [95.03604889, 25.82376289], [95.03748322, 25.82022285], [95.04032898, 25.81703949], [95.04384613, 25.81302071], [95.04937744, 25.81007195], [95.05179596, 25.80517006], [95.05149078, 25.79911995], [95.04759216, 25.78771019], [95.04550171, 25.78279114], [95.04564667, 25.7786293], [95.05252838, 25.76265907], [95.04440308, 25.75329971], [95.04238892, 25.75019646], [95.04068756, 25.74757957], [95.03369141, 25.74143982], [95.02719879, 25.74061966], [95.01888275, 25.73846817], [95.00939941, 25.73851013], [95.00241089, 25.73262978], [94.99931335, 25.72663116], [94.9987793, 25.72210121], [94.99872589, 25.72167969], [94.99323273, 25.7142601], [94.98903656, 25.70907974], [94.9836731, 25.70428085], [94.97991943, 25.70189285], [94.9763031, 25.69950104], [94.97386932, 25.69735718], [94.97316742, 25.6967411], [94.95376587, 25.68344116], [94.94287109, 25.67527962], [94.93757629, 25.66903114], [94.93509674, 25.66455078], [94.9341507, 25.6610527], [94.93263245, 25.65402031], [94.93186951, 25.65201569], [94.92983246, 25.64665985], [94.92662811, 25.64056015], [94.92550659, 25.63235092], [94.92227936, 25.62446976], [94.92090607, 25.61483192], [94.91967773, 25.6111412], [94.91722107, 25.60765266], [94.91146088, 25.60330009], [94.90468597, 25.60140419], [94.90345764, 25.60106087], [94.89572144, 25.59799957], [94.88897705, 25.59311104], [94.88892365, 25.59287453], [94.88916779, 25.59218025], [94.88871765, 25.59200287], [94.88770294, 25.58761978], [94.89189148, 25.58205986], [94.89707947, 25.57740021], [94.90415955, 25.57118034], [94.90499115, 25.56711006], [94.88783264, 25.56541824], [94.85855103, 25.56340218], [94.85678101, 25.56344032], [94.85647583, 25.56332588], [94.85301208, 25.56330109], [94.84993744, 25.56087494], [94.84944153, 25.56068993], [94.84799957, 25.55934906], [94.84342194, 25.55574036], [94.83686066, 25.55048943], [94.83392334, 25.54673004], [94.82979584, 25.53839111], [94.82967377, 25.53486061], [94.82961273, 25.53297997], [94.82884216, 25.52811813], [94.82533264, 25.52094078], [94.82209015, 25.51719093], [94.82023621, 25.51368141], [94.81864929, 25.5068512], [94.81555939, 25.49992752], [94.81249237, 25.49537086], [94.80587769, 25.49336052], [94.79711914, 25.49373055], [94.78983307, 25.49119949], [94.78452301, 25.49017906], [94.77896118, 25.48427963], [94.77274323, 25.48129272], [94.76705933, 25.4824295], [94.76452637, 25.48543167], [94.76232147, 25.49150085], [94.75668335, 25.49201965], [94.75576019, 25.48900032], [94.75541687, 25.48788071], [94.75154877, 25.48250961], [94.74651337, 25.47912979], [94.73921204, 25.47677994], [94.73088837, 25.47470093], [94.7217865, 25.47245979], [94.71463013, 25.47100258], [94.70243073, 25.46860123], [94.70092773, 25.46849632], [94.69567108, 25.46813011], [94.68863678, 25.46549988], [94.68242645, 25.45973015], [94.66976166, 25.45536041], [94.66597748, 25.45540047], [94.65873718, 25.45705032], [94.65645599, 25.458601], [94.64823151, 25.46162033], [94.63297272, 25.46565819], [94.62534332, 25.46908951], [94.60748291, 25.48244095], [94.59736633, 25.48625946], [94.59488678, 25.48814964], [94.5908432, 25.48974991], [94.58719635, 25.49245071], [94.58500671, 25.49687004], [94.57459259, 25.50522995], [94.56817627, 25.50658989], [94.55741882, 25.5127697], [94.55899811, 25.52433968], [94.56125641, 25.53069115], [94.55827332, 25.53487968], [94.56347656, 25.53967285], [94.55986786, 25.54570961], [94.56289673, 25.54951096], [94.56137848, 25.56051064], [94.56465912, 25.56793976], [94.56040955, 25.56798935], [94.5615387, 25.57833099], [94.55574036, 25.58581161], [94.55957031, 25.59411049], [94.5651474, 25.6026001], [94.56690979, 25.60410118], [94.5686264, 25.6077919], [94.57282257, 25.61131287], [94.57691956, 25.62037277], [94.57850647, 25.62625122], [94.58377075, 25.63449097], [94.59050751, 25.64027023], [94.59455109, 25.6426506], [94.59519958, 25.64385033], [94.58693695, 25.64659119], [94.57608795, 25.644701], [94.57723236, 25.64833069], [94.57678986, 25.65283012], [94.58135223, 25.6573925], [94.58204651, 25.6606102], [94.58522034, 25.6617794], [94.58344269, 25.66522026], [94.58558655, 25.67000961], [94.58737183, 25.67180061], [94.58532715, 25.67485046], [94.58812714, 25.67727089], [94.58996582, 25.68124962], [94.59694672, 25.68691063], [94.5956192, 25.69128036], [94.58705139, 25.69189072], [94.58297729, 25.69320107], [94.57861328, 25.69599915], [94.57301331, 25.69765091], [94.56799316, 25.69222069], [94.56507874, 25.68082047], [94.55222321, 25.6674118], [94.5517807, 25.66246033], [94.54473877, 25.65754128], [94.53954315, 25.65108109], [94.53154755, 25.65012932], [94.53066254, 25.64258957], [94.52818298, 25.64429092], [94.52419281, 25.64343262], [94.51451111, 25.63049126], [94.5109024, 25.62990952], [94.50866699, 25.62689972], [94.50779724, 25.61894989], [94.50537109, 25.61699295], [94.50183105, 25.62002182], [94.5, 25.61885643], [94.49993896, 25.61881828], [94.4992981, 25.61650276], [94.49341583, 25.61433029], [94.49111176, 25.61865044], [94.49118042, 25.61979866], [94.47403717, 25.62164116], [94.44927216, 25.60108948], [94.44782257, 25.59804153], [94.44428253, 25.59601021], [94.43773651, 25.59585953], [94.43002319, 25.59272194], [94.42565918, 25.58147049], [94.42237854, 25.57599068], [94.42510223, 25.57299995], [94.4263916, 25.56145096], [94.42559052, 25.55291939], [94.42027283, 25.54265022], [94.41680908, 25.54194069], [94.4108963, 25.54351807], [94.40448761, 25.54089928], [94.38854218, 25.5365696], [94.3646698, 25.5214901], [94.32901001, 25.50835037], [94.32068634, 25.49928093], [94.3135376, 25.4944706], [94.30898285, 25.49380112], [94.30264282, 25.49463272], [94.29899597, 25.50070953], [94.29074097, 25.50951958], [94.28674316, 25.51169968], [94.27986908, 25.5054512], [94.27414703, 25.50299072], [94.26693726, 25.5024395], [94.25726318, 25.50341988], [94.25205994, 25.49907112], [94.23174286, 25.49831009], [94.22914124, 25.49600983], [94.22297668, 25.49677277], [94.21985626, 25.49962997], [94.21485138, 25.50024033], [94.2128067, 25.50282097], [94.21292877, 25.50817108], [94.20690155, 25.51164055], [94.20688629, 25.51395035], [94.19924927, 25.52276993], [94.19072723, 25.53078079], [94.19013977, 25.53462982], [94.19390869, 25.54219818], [94.19487, 25.5524292], [94.19184875, 25.550951], [94.18276978, 25.55325127], [94.17954254, 25.55018997], [94.16790771, 25.54701042], [94.16352844, 25.54992104], [94.16011047, 25.55525017], [94.15287781, 25.54784012], [94.15184021, 25.54185104], [94.14820099, 25.5316906], [94.14523315, 25.52763939], [94.13873291, 25.52370071], [94.12850952, 25.52588081], [94.1060791, 25.52890015], [94.09210968, 25.5327301], [94.09252167, 25.53796959], [94.09619904, 25.54171944], [94.09496307, 25.54644012], [94.08595276, 25.55973053], [94.08003998, 25.56159973], [94.06941986, 25.55898094], [94.06469727, 25.56637001], [94.05412292, 25.57675934], [94.04599762, 25.58094978], [94.04361725, 25.57748032], [94.03900909, 25.57986069], [94.03916168, 25.5830307], [94.03791809, 25.58192825], [94.03489685, 25.58148956], [94.03340912, 25.58470154], [94.02726746, 25.58798981], [94.0255127, 25.59338951], [94.01473236, 25.59613037], [94.01039886, 25.59539986], [94.00765228, 25.59094048], [94.00782776, 25.58752823], [94.0117569, 25.57909012], [94.01228333, 25.57529831], [94.01159668, 25.57274818], [94.01042175, 25.57131195], [94.00744629, 25.56985092], [94.00061035, 25.57388115], [93.98046875, 25.57125282], [93.97785187, 25.5661602], [93.97264862, 25.56118011], [93.96521759, 25.55657768], [93.95738983, 25.55675125], [93.94516754, 25.56263924], [93.94351959, 25.56343269], [93.93012238, 25.56538963], [93.91932678, 25.56402969], [93.91709137, 25.56672096], [93.9108963, 25.56752968], [93.90484619, 25.56742859], [93.90023804, 25.5687294], [93.89196014, 25.56842041], [93.87837219, 25.5619812], [93.86223602, 25.55752945], [93.85231781, 25.55864906], [93.84420776, 25.56169128], [93.83648682, 25.56306076], [93.83347321, 25.56137276], [93.83325958, 25.55642128], [93.82504272, 25.55599976], [93.823349, 25.54816246], [93.81971741, 25.54438972], [93.81594086, 25.5454483], [93.80784607, 25.54451942], [93.77948761, 25.5380497], [93.77182007, 25.54080963], [93.77063751, 25.54027939], [93.77097321, 25.53602028], [93.76895142, 25.53071022], [93.76818085, 25.52529144], [93.76931763, 25.51770973], [93.76428986, 25.51548195], [93.76579285, 25.49990082], [93.76934814, 25.49677277], [93.77339172, 25.49784088], [93.78846741, 25.50649071], [93.79724884, 25.50438118], [93.80404663, 25.49902916], [93.80760956, 25.49555969], [93.81388855, 25.48472977], [93.80899811, 25.46558952], [93.80522919, 25.46342087], [93.8024292, 25.46040916], [93.79836273, 25.45393181], [93.79374695, 25.4486599], [93.79020691, 25.44338036], [93.78810883, 25.43588066], [93.78447723, 25.43193817], [93.78053284, 25.42950058], [93.78106689, 25.42471123], [93.76441956, 25.41813087], [93.76033783, 25.41411972], [93.74666595, 25.40571022], [93.74198914, 25.39991951], [93.74006653, 25.39517975], [93.74131775, 25.38944054], [93.73979187, 25.38441849], [93.73100281, 25.38037109], [93.72310638, 25.37558174], [93.71897888, 25.37035942], [93.71804047, 25.36160088], [93.711586, 25.35808945], [93.69998169, 25.35942268], [93.69277954, 25.36158943], [93.69145203, 25.34741974], [93.68712616, 25.33121109], [93.68392181, 25.3296299], [93.67207336, 25.32871056], [93.67395782, 25.31728172], [93.67294312, 25.31151009], [93.66609192, 25.30828094], [93.66474915, 25.30424118], [93.66561127, 25.29842949], [93.65161896, 25.27902031], [93.65136719, 25.27366066], [93.64990997, 25.26911926], [93.64354706, 25.26588249], [93.64311981, 25.26001167], [93.63809204, 25.25039864], [93.63186646, 25.24291992], [93.62890625, 25.23574829], [93.62114716, 25.22491264], [93.61257935, 25.20619011], [93.60801697, 25.20205116], [93.60428619, 25.20432091], [93.60103607, 25.20239258], [93.5970993, 25.20429993], [93.59303284, 25.20391273], [93.59285736, 25.20667076], [93.594841, 25.21113014], [93.59197998, 25.21390915], [93.59028625, 25.21994972], [93.58805847, 25.22216988], [93.58584595, 25.22231102], [93.58164978, 25.22600937], [93.57820129, 25.22569084], [93.57485199, 25.22755051], [93.57076263, 25.23245049], [93.57009888, 25.23560905], [93.56313324, 25.24658966], [93.55471039, 25.25052834], [93.54717255, 25.24849129], [93.54120636, 25.2453804], [93.52935791, 25.24835968], [93.52060699, 25.2487812], [93.51642609, 25.24477005], [93.50843048, 25.24370956], [93.50514221, 25.24413109], [93.50417328, 25.25338173], [93.51078796, 25.27560806], [93.50437927, 25.27577019], [93.49489594, 25.27872086], [93.4875412, 25.2759304], [93.48338318, 25.27663994], [93.47675323, 25.27903938], [93.47258759, 25.28544044], [93.47463226, 25.29241943], [93.4751358, 25.29968071], [93.47402191, 25.3092804], [93.46797943, 25.31381035], [93.46312714, 25.31986046], [93.45670319, 25.32526016], [93.45796967, 25.33005142], [93.46193695, 25.33658981], [93.45790863, 25.34091949], [93.45188904, 25.3441906], [93.45374298, 25.34811974], [93.46231842, 25.35886955], [93.46626282, 25.36173058], [93.47821808, 25.37988281], [93.47728729, 25.38600922], [93.47393799, 25.39311028], [93.46718597, 25.40306091], [93.46325684, 25.41096115], [93.46540833, 25.41587067], [93.46514893, 25.42340279], [93.46186829, 25.4346981], [93.45687103, 25.44194984], [93.44359589, 25.45060921], [93.43495941, 25.45477295], [93.42751312, 25.45526123], [93.42201996, 25.45479965], [93.41710663, 25.45279121], [93.40291595, 25.45918274], [93.3959198, 25.46412086], [93.39041901, 25.46916962], [93.39190674, 25.4742012], [93.39103699, 25.4780426], [93.39131165, 25.48143005], [93.39050293, 25.48562813], [93.38710022, 25.49031067], [93.3863678, 25.49335098], [93.38304138, 25.49756813], [93.37181854, 25.50113106], [93.37114716, 25.50514984], [93.36689758, 25.50786972], [93.36502075, 25.51013947], [93.36682129, 25.5128727], [93.36472321, 25.51616859], [93.36004639, 25.5203228], [93.35756683, 25.52766991], [93.35417938, 25.53119087], [93.35016632, 25.53367043], [93.3523407, 25.53757095], [93.34922791, 25.53832817], [93.3445816, 25.53607941], [93.34039307, 25.53729057], [93.33574677, 25.54541016], [93.33174133, 25.54681015]]]}}, {\\\"id\\\": \\\"22\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.25_1\\\", \\\"HASC_1\\\": \\\"IN.DL\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"NCT of Delhi\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -24.2, \\\"dalys_apm25_rate_6cod_mean_total\\\": 847.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1536.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -689.0, \\\"geo-id\\\": 22, \\\"hpm25_child_popweighted\\\": -260.0, \\\"hpm25_female_popweighted\\\": -299.0, \\\"hpm25_male_popweighted\\\": -215.0, \\\"location\\\": \\\"NCT of Delhi\\\", \\\"mort_apm25_6cod_mean_total\\\": 2663.0, \\\"mort_hpm25_6cod_mean_total\\\": -4994.0, \\\"mort_tpm25_6cod_mean_total\\\": -2331.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[77.32713318, 28.68515968], [77.32538605, 28.68250275], [77.31791687, 28.67934036], [77.31756592, 28.67161942], [77.31542969, 28.66327095], [77.31533051, 28.651371], [77.31307983, 28.64666939], [77.31121063, 28.64464188], [77.31358337, 28.64320183], [77.32095337, 28.63602066], [77.33045959, 28.6314106], [77.33422089, 28.62699127], [77.33708191, 28.62190056], [77.33753204, 28.61749268], [77.33618164, 28.60886955], [77.33315277, 28.60671234], [77.32784271, 28.60488129], [77.31694031, 28.59996033], [77.30992126, 28.59896088], [77.30713654, 28.59691048], [77.29490662, 28.58242989], [77.29364777, 28.57971954], [77.29380035, 28.5667305], [77.2951889, 28.5612011], [77.30306244, 28.55045128], [77.31069946, 28.54368973], [77.314888, 28.54149055], [77.32151031, 28.53585052], [77.330513, 28.52410126], [77.33396912, 28.52070236], [77.33682251, 28.51568031], [77.33773804, 28.50897026], [77.33447266, 28.51108932], [77.32898712, 28.50831985], [77.32668304, 28.50345039], [77.32170105, 28.49938965], [77.31488037, 28.49456978], [77.30686951, 28.49068069], [77.3009491, 28.49011993], [77.29627228, 28.4911499], [77.28578949, 28.49627113], [77.27805328, 28.49814987], [77.27111053, 28.49703026], [77.26010132, 28.48842812], [77.25396729, 28.48554039], [77.24265289, 28.48460007], [77.23673248, 28.47969055], [77.23239899, 28.47579956], [77.22763062, 28.46974945], [77.22574615, 28.46401024], [77.2264328, 28.46026039], [77.23311615, 28.45944977], [77.23986816, 28.45360756], [77.2432785, 28.44749069], [77.24430084, 28.44166946], [77.24318695, 28.43367958], [77.24061584, 28.42885971], [77.2227478, 28.41897011], [77.21530914, 28.41574097], [77.20590973, 28.41340065], [77.19522095, 28.4125309], [77.17948914, 28.41237068], [77.16577148, 28.40846062], [77.15434265, 28.4213028], [77.1518631, 28.42831993], [77.14243317, 28.43571091], [77.1313858, 28.43870163], [77.12407684, 28.43923759], [77.11830139, 28.4424305], [77.11251068, 28.45023155], [77.10874939, 28.45735168], [77.10604858, 28.46590042], [77.10273743, 28.47044945], [77.10154724, 28.47647858], [77.10334015, 28.48310852], [77.10766602, 28.49386978], [77.10352325, 28.49745941], [77.09031677, 28.5054512], [77.08598328, 28.51086044], [77.07247925, 28.52028084], [77.06746674, 28.52065086], [77.05696106, 28.5138607], [77.04876709, 28.51524162], [77.04165649, 28.51896095], [77.03314209, 28.52833939], [77.01963806, 28.53327179], [77.01566315, 28.53331947], [77.00609589, 28.54277992], [77.00020599, 28.54199982], [76.99594879, 28.53689957], [76.99820709, 28.53215027], [77.00499725, 28.52873993], [77.01139832, 28.52411079], [77.01093292, 28.51803017], [77.00554657, 28.51444054], [76.99027252, 28.51978111], [76.97653198, 28.52380943], [76.96846771, 28.52758026], [76.94462585, 28.51362991], [76.93321991, 28.5160408], [76.9226532, 28.51926994], [76.90847778, 28.51490974], [76.89745331, 28.51777077], [76.89372253, 28.51614189], [76.8868103, 28.51122856], [76.87937164, 28.50905037], [76.87380981, 28.51439095], [76.8794632, 28.52399826], [76.87631226, 28.52840042], [76.85920715, 28.54191971], [76.85674286, 28.54782104], [76.83761597, 28.55698967], [76.83291626, 28.58250809], [76.8350296, 28.59140015], [76.85022736, 28.59011841], [76.85481262, 28.59235191], [76.86090088, 28.60251045], [76.87793732, 28.63763046], [76.89367676, 28.63275146], [76.8972702, 28.63280106], [76.90400696, 28.63793945], [76.91034698, 28.63783073], [76.92366028, 28.62865067], [76.92597961, 28.62924957], [76.93390656, 28.63764954], [76.91821289, 28.65327072], [76.9174881, 28.65727043], [76.92310333, 28.66921043], [76.92973328, 28.6744194], [76.94255066, 28.67511177], [76.94725037, 28.67716026], [76.94595337, 28.68348122], [76.94838715, 28.68799019], [76.94999695, 28.69412994], [76.954216, 28.7005291], [76.95459747, 28.70537186], [76.95095825, 28.70976067], [76.94126129, 28.71702957], [76.95066071, 28.73645973], [76.94919586, 28.74150276], [76.95031738, 28.7466507], [76.9474411, 28.75113106], [76.93820953, 28.75962067], [76.94657135, 28.77403069], [76.94396973, 28.77853012], [76.94233704, 28.78775978], [76.94309235, 28.79512024], [76.93746948, 28.80350113], [76.93736267, 28.8091507], [76.94230652, 28.82068062], [76.94822693, 28.81766129], [76.95578003, 28.82002068], [76.95800781, 28.8303299], [76.96083069, 28.83167076], [76.9705658, 28.82510185], [76.97368622, 28.82583046], [76.97955322, 28.83670044], [76.98349762, 28.83908081], [76.98972321, 28.83916092], [77.00662994, 28.83526039], [77.01880646, 28.83706284], [77.02466583, 28.83628082], [77.03153992, 28.83679008], [77.03766632, 28.85277748], [77.04975891, 28.87318993], [77.06565857, 28.8730011], [77.07013702, 28.8800106], [77.07585144, 28.88451195], [77.08335114, 28.87461853], [77.09945679, 28.87244034], [77.10713196, 28.86845016], [77.10970306, 28.86613274], [77.12854004, 28.86539078], [77.13508606, 28.85848999], [77.1355896, 28.85268974], [77.13381195, 28.84472275], [77.1391983, 28.84166908], [77.14237976, 28.84247017], [77.15065002, 28.84844971], [77.1595993, 28.85744286], [77.16458893, 28.86063004], [77.18363953, 28.86230087], [77.18686676, 28.86681938], [77.19348907, 28.86535072], [77.199646, 28.86494064], [77.20479584, 28.86291122], [77.20783234, 28.86021996], [77.21147156, 28.85493088], [77.21061707, 28.84529114], [77.2173233, 28.83527946], [77.21364594, 28.81349945], [77.1946106, 28.81536293], [77.19444275, 28.80229187], [77.1969223, 28.79528046], [77.20269012, 28.78940964], [77.20845032, 28.78718948], [77.21305084, 28.7864399], [77.21826935, 28.78762817], [77.22467804, 28.78762817], [77.22206879, 28.783741], [77.21710205, 28.78168106], [77.22090912, 28.7779007], [77.22904205, 28.77243805], [77.23799133, 28.75922012], [77.24585724, 28.75735092], [77.24846649, 28.75753021], [77.25319672, 28.75279045], [77.25187683, 28.74550056], [77.25617218, 28.73991966], [77.25991821, 28.73812294], [77.26637268, 28.7392807], [77.27111816, 28.7381897], [77.2768631, 28.7343998], [77.28069305, 28.73002052], [77.2844162, 28.72393036], [77.28365326, 28.7189827], [77.28489685, 28.71245956], [77.29294586, 28.7097702], [77.29563141, 28.7130394], [77.30146027, 28.71673012], [77.30622101, 28.71767044], [77.31716156, 28.71722031], [77.32348633, 28.71587181], [77.32167816, 28.71183014], [77.31983948, 28.70364189], [77.32092285, 28.69967079], [77.32758331, 28.69184113], [77.32713318, 28.68515968]]]}}, {\\\"id\\\": \\\"23\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.26_1\\\", \\\"HASC_1\\\": \\\"IN.OR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Odisha\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -24.8, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1103.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -2177.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1074.0, \\\"geo-id\\\": 23, \\\"hpm25_child_popweighted\\\": -248.9, \\\"hpm25_female_popweighted\\\": -286.1, \\\"hpm25_male_popweighted\\\": -206.0, \\\"location\\\": \\\"Odisha\\\", \\\"mort_apm25_6cod_mean_total\\\": 14296.0, \\\"mort_hpm25_6cod_mean_total\\\": -29616.0, \\\"mort_tpm25_6cod_mean_total\\\": -15320.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[84.73021698, 19.08930588], [84.73236084, 19.08930588], [84.73236084, 19.08958244], [84.73291779, 19.08958054], [84.73291779, 19.08986282], [84.7334671, 19.08986282], [84.7334671, 19.09013939], [84.73374939, 19.09013939], [84.73374939, 19.09041977], [84.73402405, 19.09041405], [84.73402405, 19.09069252], [84.73432159, 19.09069061], [84.73432159, 19.09152985], [84.73596954, 19.09152985], [84.73596954, 19.09181023], [84.73764038, 19.09180641], [84.73764038, 19.09208488], [84.73930359, 19.09208488], [84.73930359, 19.09152794], [84.73958588, 19.09152985], [84.73958588, 19.09069061], [84.73986053, 19.09069252], [84.73986053, 19.09041405], [84.74014282, 19.09041977], [84.74014282, 19.08986282], [84.74097443, 19.08986282], [84.7409668, 19.08930969], [84.74124908, 19.08930969], [84.74124908, 19.08847046], [84.74180603, 19.08847046], [84.74180603, 19.08819389], [84.74208069, 19.08819389], [84.74208069, 19.08791733], [84.74263763, 19.08792114], [84.74263763, 19.08764267], [84.74375153, 19.08764267], [84.74375153, 19.08792114], [84.74402618, 19.08791733], [84.74402618, 19.08819389], [84.74430847, 19.08819389], [84.74430847, 19.08847046], [84.74485779, 19.08847046], [84.74485779, 19.08875275], [84.74514008, 19.08875275], [84.74514008, 19.08903122], [84.7454071, 19.08903122], [84.7454071, 19.08930969], [84.74569702, 19.08930969], [84.74569702, 19.09041977], [84.74597168, 19.09041405], [84.74597168, 19.09069252], [84.74736023, 19.09069252], [84.74736023, 19.09041405], [84.74819183, 19.09041977], [84.74819183, 19.09013939], [84.74903107, 19.09013939], [84.74903107, 19.08986282], [84.7492981, 19.08986282], [84.7492981, 19.08958054], [84.74958038, 19.08958244], [84.74958038, 19.08847046], [84.74930573, 19.08847046], [84.74930573, 19.08763885], [84.75013733, 19.08764267], [84.75013733, 19.08736038], [84.75125122, 19.08736038], [84.75125122, 19.08764267], [84.75152588, 19.08764267], [84.75152588, 19.08792114], [84.75208282, 19.08792114], [84.75208282, 19.08708191], [84.75152588, 19.08708382], [84.75152588, 19.08680534], [84.75096893, 19.08681107], [84.75096893, 19.08597183], [84.75069427, 19.08597183], [84.75069427, 19.08458328], [84.75041962, 19.08458328], [84.75041962, 19.08263969], [84.75068665, 19.08263969], [84.75068665, 19.08208084], [84.75096893, 19.08208084], [84.75096893, 19.08236122], [84.75152588, 19.08236122], [84.75152588, 19.08291817], [84.75180817, 19.08291817], [84.75180817, 19.08402824], [84.75208282, 19.08402824], [84.75208282, 19.08430481], [84.75235748, 19.08430481], [84.75235748, 19.08458328], [84.75263977, 19.08458328], [84.75263977, 19.08486176], [84.7529068, 19.08485985], [84.7529068, 19.08513832], [84.75319672, 19.08513832], [84.75319672, 19.08542061], [84.75514221, 19.08542061], [84.75514221, 19.0857029], [84.75541687, 19.08569527], [84.75541687, 19.08597183], [84.75597382, 19.08597183], [84.75597382, 19.08625031], [84.75708008, 19.08624077], [84.75708008, 19.08653259], [84.75736237, 19.08653259], [84.75736237, 19.08681107], [84.75763702, 19.08680534], [84.75763702, 19.08708382], [84.75791931, 19.08708191], [84.75791931, 19.08736038], [84.75819397, 19.08736038], [84.7582016, 19.08875275], [84.75791931, 19.08875275], [84.75791931, 19.08958244], [84.7582016, 19.08958054], [84.7582016, 19.09152985], [84.75791931, 19.09152985], [84.75791931, 19.09181023], [84.7582016, 19.09181023], [84.7582016, 19.09237099], [84.75846863, 19.09236145], [84.75846863, 19.09486198], [84.75819397, 19.09486198], [84.75819397, 19.09569359], [84.75791931, 19.09568977], [84.75791931, 19.09625053], [84.75763702, 19.09625053], [84.75763702, 19.09736061], [84.75736237, 19.09736061], [84.75736237, 19.0984726], [84.75763702, 19.09847069], [84.75763702, 19.09874916], [84.75791931, 19.09874916], [84.75791931, 19.09903145], [84.7582016, 19.09903145], [84.7582016, 19.09931183], [84.75875092, 19.09930611], [84.75875092, 19.09958267], [84.75902557, 19.09958267], [84.75902557, 19.10013962], [84.75930786, 19.10013962], [84.75930786, 19.10069466], [84.75958252, 19.10069466], [84.75958252, 19.10041618], [84.76040649, 19.10042191], [84.76040649, 19.10013962], [84.76180267, 19.10013962], [84.76180267, 19.10042191], [84.76486206, 19.10042191], [84.76486206, 19.09985924], [84.76513672, 19.09985924], [84.76513672, 19.09958076], [84.76568604, 19.09958076], [84.76568604, 19.10042191], [84.76625061, 19.10041618], [84.76625061, 19.10069466], [84.76680756, 19.10069466], [84.76680756, 19.10097122], [84.76708221, 19.10097122], [84.76708221, 19.10124969], [84.76763916, 19.10124969], [84.76763916, 19.10153961], [84.76819611, 19.10152817], [84.76819611, 19.1020813], [84.76847076, 19.1020813], [84.76847076, 19.10236359], [84.76902771, 19.10235977], [84.76902771, 19.10264015], [84.76930237, 19.10264015], [84.76930237, 19.10292053], [84.76957703, 19.10292053], [84.76957703, 19.10320091], [84.76985931, 19.10319328], [84.76985931, 19.10347366], [84.7701416, 19.10346985], [84.7701416, 19.10375023], [84.77043152, 19.10375023], [84.77043152, 19.10403061], [84.77069092, 19.10403061], [84.77069092, 19.10431099], [84.7720871, 19.10430336], [84.7720871, 19.10458565], [84.77236176, 19.10457993], [84.77236176, 19.10486031], [84.7729187, 19.10486031], [84.7729187, 19.10514069], [84.77346802, 19.10514069], [84.77346802, 19.10542107], [84.77402496, 19.10541725], [84.77402496, 19.10569572], [84.77458191, 19.10569572], [84.77458191, 19.10597229], [84.77513885, 19.10597038], [84.77513885, 19.10625076], [84.7756958, 19.10625076], [84.7756958, 19.10653114], [84.77623749, 19.10653114], [84.77623749, 19.10680962], [84.7765274, 19.10680771], [84.7765274, 19.10708237], [84.77680206, 19.10708427], [84.77680206, 19.10736084], [84.77707672, 19.1073494], [84.77707672, 19.10764122], [84.77735901, 19.10764122], [84.77735901, 19.10791969], [84.77791595, 19.10791779], [84.77791595, 19.10819435], [84.7784729, 19.10819435], [84.7784729, 19.10847282], [84.77902985, 19.10847092], [84.77902985, 19.10874939], [84.77931213, 19.10874939], [84.77931213, 19.10902977], [84.78013611, 19.10902977], [84.78013611, 19.10930824], [84.7804184, 19.10930634], [84.7804184, 19.1095829], [84.78069305, 19.1095829], [84.78069305, 19.10986137], [84.78098297, 19.10985947], [84.78098297, 19.11013985], [84.78125, 19.11013985], [84.78125, 19.11041641], [84.78180695, 19.11041641], [84.78180695, 19.11069489], [84.78236389, 19.11069489], [84.78236389, 19.11097145], [84.7831955, 19.11097145], [84.7831955, 19.11069489], [84.78347015, 19.11069489], [84.78347015, 19.11013985], [84.78320313, 19.11013985], [84.78320313, 19.10985947], [84.78263855, 19.10986137], [84.78263855, 19.10847282], [84.78236389, 19.10847282], [84.78236389, 19.10791779], [84.7820816, 19.10791969], [84.7820816, 19.10764122], [84.78180695, 19.10764122], [84.78180695, 19.10542107], [84.78151703, 19.10542107], [84.78151703, 19.10457993], [84.78125, 19.10458565], [84.78125, 19.1040287], [84.78098297, 19.10403061], [84.78098297, 19.10320091], [84.78069305, 19.10320091], [84.78069305, 19.10292053], [84.7804184, 19.10292053], [84.7804184, 19.10264015], [84.78013611, 19.10264015], [84.78013611, 19.10235977], [84.77986145, 19.10236359], [84.77986145, 19.1020813], [84.77958679, 19.1020813], [84.77958679, 19.10180473], [84.7793045, 19.10180473], [84.7793045, 19.10152817], [84.77902985, 19.10153961], [84.77902985, 19.10097122], [84.77874756, 19.10097122], [84.77874756, 19.10041618], [84.7784729, 19.10042191], [84.7784729, 19.10013962], [84.77819824, 19.10013962], [84.77819061, 19.09985924], [84.77791595, 19.09985924], [84.77791595, 19.09958076], [84.7776413, 19.09958267], [84.7776413, 19.09930611], [84.77735901, 19.09931183], [84.77735901, 19.09792137], [84.77707672, 19.09792137], [84.77707672, 19.09763908], [84.77680206, 19.09763908], [84.77680206, 19.09708023], [84.7765274, 19.09708405], [84.7765274, 19.0965271], [84.7756958, 19.09653091], [84.7756958, 19.09597015], [84.77541351, 19.09597206], [84.77541351, 19.09569359], [84.77513885, 19.09569359], [84.77513885, 19.09541893], [84.7748642, 19.09541893], [84.7748642, 19.09430695], [84.77458191, 19.09431076], [84.77458191, 19.09375], [84.77430725, 19.09375], [84.77430725, 19.0929203], [84.77403259, 19.0929203], [84.77403259, 19.09208107], [84.77375031, 19.09208488], [84.77375031, 19.09152794], [84.77346802, 19.09152985], [84.77346802, 19.09124947], [84.7731781, 19.09124947], [84.7731781, 19.09069061], [84.7729187, 19.09069252], [84.7729187, 19.09041405], [84.77263641, 19.09041977], [84.77263641, 19.09013939], [84.7720871, 19.09013939], [84.7720871, 19.08958054], [84.77180481, 19.08958244], [84.77180481, 19.08875275], [84.77153015, 19.08875275], [84.77153015, 19.08792114], [84.77124786, 19.08792114], [84.77124786, 19.08736038], [84.77097321, 19.08736038], [84.77097321, 19.08653259], [84.77069092, 19.08653259], [84.77069092, 19.08624077], [84.77041626, 19.08625031], [84.77041626, 19.08569527], [84.7701416, 19.0857029], [84.7701416, 19.08513832], [84.76985931, 19.08513832], [84.76985931, 19.08457947], [84.76958466, 19.08458328], [84.76958466, 19.08402824], [84.76930237, 19.08402824], [84.76930237, 19.08374977], [84.76902771, 19.08374977], [84.76902771, 19.08317947], [84.76875305, 19.08319473], [84.76875305, 19.08263969], [84.76847076, 19.08263969], [84.76847076, 19.08208084], [84.76819611, 19.08208275], [84.76819611, 19.08152771], [84.76790619, 19.08152962], [84.76790619, 19.08125114], [84.76763916, 19.08125114], [84.76763916, 19.08097076], [84.7673645, 19.08097267], [84.7673645, 19.08041763], [84.76708221, 19.08042908], [84.76708221, 19.07986069], [84.76680756, 19.07986069], [84.76680756, 19.07958031], [84.76652527, 19.07958412], [84.76652527, 19.07902718], [84.76625061, 19.07903099], [84.76625061, 19.07847023], [84.76597595, 19.07847214], [84.76597595, 19.07819557], [84.76569366, 19.07819557], [84.76569366, 19.0779171], [84.76541901, 19.07792091], [84.76541901, 19.07736969], [84.76513672, 19.07736969], [84.76513672, 19.07707977], [84.76486206, 19.07708549], [84.76486206, 19.07569313], [84.76457977, 19.07570076], [84.76457977, 19.07485962], [84.76430511, 19.07486343], [84.76430511, 19.07458115], [84.76347351, 19.07458115], [84.76347351, 19.07430649], [84.76319122, 19.07430649], [84.76319122, 19.07374954], [84.76291656, 19.07374954], [84.76291656, 19.07346916], [84.76264191, 19.07347107], [84.76264191, 19.0731945], [84.76235962, 19.0731945], [84.76235962, 19.07263947], [84.76208496, 19.07263947], [84.76208496, 19.07235909], [84.76180267, 19.07235909], [84.76180267, 19.07208061], [84.76152802, 19.07208252], [84.76152802, 19.07152748], [84.7612381, 19.07152939], [84.76125336, 19.07125092], [84.76114655, 19.07127762], [84.76101685, 19.07131195], [84.73021698, 19.08930588]]], [[[84.76985931, 19.10597229], [84.76985931, 19.10486031], [84.76957703, 19.10486031], [84.76957703, 19.10431099], [84.76930237, 19.10431099], [84.76930237, 19.10403061], [84.76902771, 19.10403061], [84.76902771, 19.10375023], [84.76875305, 19.10375023], [84.76875305, 19.10346985], [84.76847076, 19.10347366], [84.76847076, 19.10319328], [84.76790619, 19.10320091], [84.76790619, 19.10264015], [84.76763916, 19.10264015], [84.76763916, 19.10207939], [84.7673645, 19.1020813], [84.7673645, 19.10180473], [84.76680756, 19.10180473], [84.76680756, 19.10152817], [84.7665329, 19.10153961], [84.7665329, 19.10124969], [84.76597595, 19.10124969], [84.76597595, 19.10097122], [84.76568604, 19.10097122], [84.76568604, 19.10124969], [84.76513672, 19.10124969], [84.76513672, 19.10153961], [84.76486206, 19.10152817], [84.76486206, 19.10180473], [84.76513672, 19.10180473], [84.76513672, 19.1020813], [84.76541901, 19.1020813], [84.76541901, 19.10236359], [84.76568604, 19.10235977], [84.76568604, 19.10292053], [84.76597595, 19.10292053], [84.76597595, 19.10320091], [84.76625061, 19.10320091], [84.76625061, 19.10375023], [84.76652527, 19.10375023], [84.76652527, 19.10458565], [84.76708221, 19.10457993], [84.76708221, 19.10486031], [84.76737213, 19.10486031], [84.76737213, 19.10514069], [84.76791382, 19.10513878], [84.76791382, 19.10569572], [84.76875305, 19.10569572], [84.76875305, 19.10597229], [84.76985931, 19.10597229]]], [[[84.75653076, 19.11097145], [84.75653076, 19.11041641], [84.75680542, 19.11041641], [84.75680542, 19.10986137], [84.75708008, 19.10986137], [84.75708008, 19.1095829], [84.75736237, 19.1095829], [84.75736237, 19.10902786], [84.75708008, 19.10902977], [84.75708008, 19.10847092], [84.75791931, 19.10847092], [84.75791931, 19.10930824], [84.7582016, 19.10930824], [84.7582016, 19.11013985], [84.75875092, 19.11013985], [84.75875092, 19.10958099], [84.76069641, 19.1095829], [84.76069641, 19.10902786], [84.75985718, 19.10902977], [84.75985718, 19.10874939], [84.75958252, 19.10874939], [84.75958252, 19.10819054], [84.75930786, 19.10819435], [84.75930786, 19.10763931], [84.7590332, 19.10764122], [84.7590332, 19.1073494], [84.75763702, 19.10736084], [84.75763702, 19.10680771], [84.75791931, 19.10680962], [84.75791931, 19.10569], [84.75819397, 19.10569572], [84.75819397, 19.10513878], [84.75846863, 19.10514069], [84.75846863, 19.10486031], [84.75985718, 19.10486031], [84.75985718, 19.10514069], [84.76069641, 19.10514069], [84.76069641, 19.10542107], [84.76125336, 19.10541725], [84.76125336, 19.10569572], [84.76235962, 19.10569572], [84.76235962, 19.10597229], [84.76264191, 19.10597229], [84.76264191, 19.10736084], [84.76291656, 19.10736084], [84.76291656, 19.10708427], [84.76430511, 19.10708427], [84.76430511, 19.10736084], [84.76541901, 19.10736084], [84.76541901, 19.10708427], [84.76569366, 19.10708427], [84.76569366, 19.10486031], [84.76541901, 19.10486031], [84.76541901, 19.10403061], [84.76513672, 19.10403061], [84.76513672, 19.10375023], [84.76457977, 19.10375023], [84.76457977, 19.10320091], [84.76429749, 19.10320091], [84.76429749, 19.10292053], [84.76403046, 19.10292053], [84.76403046, 19.10264015], [84.76374817, 19.10264015], [84.76374817, 19.10235977], [84.76291656, 19.10236359], [84.76291656, 19.1020813], [84.76208496, 19.1020813], [84.76208496, 19.10236359], [84.76040649, 19.10235977], [84.76040649, 19.10264015], [84.75930786, 19.10264015], [84.75930786, 19.10235977], [84.75875092, 19.10236359], [84.75875092, 19.1020813], [84.75846863, 19.1020813], [84.75846863, 19.10180473], [84.75819397, 19.10180473], [84.75819397, 19.10152817], [84.75680542, 19.10152817], [84.75680542, 19.10180473], [84.75653076, 19.10180283], [84.75653076, 19.10431099], [84.75708008, 19.10430336], [84.75708008, 19.10458565], [84.75736237, 19.10457993], [84.75736237, 19.10542107], [84.75708008, 19.10541725], [84.75708008, 19.10569572], [84.75680542, 19.10569572], [84.75680542, 19.10597229], [84.75653076, 19.10597038], [84.75653076, 19.10625076], [84.75624847, 19.10625076], [84.75624847, 19.10680962], [84.75597382, 19.10680771], [84.75597382, 19.10708427], [84.75624847, 19.10708427], [84.75624847, 19.10736084], [84.75596619, 19.1073494], [84.75596619, 19.10764122], [84.75624847, 19.10764122], [84.75624847, 19.10874939], [84.75596619, 19.10874939], [84.75596619, 19.10902977], [84.75569153, 19.10902977], [84.75569153, 19.10930824], [84.75541687, 19.10930634], [84.75541687, 19.10986137], [84.75514221, 19.10986137], [84.75514221, 19.11069489], [84.75541687, 19.11069489], [84.75541687, 19.11097145], [84.75653076, 19.11097145]]], [[[86.38694763, 19.96277618], [86.38694763, 19.96223068], [86.38582611, 19.96111107], [86.38555908, 19.96111107], [86.38471985, 19.96027946], [86.38445282, 19.96027946], [86.3842392, 19.96007347], [86.3841629, 19.95999908], [86.38388824, 19.95972061], [86.38361359, 19.95972252], [86.3833313, 19.95944214], [86.38277435, 19.95944214], [86.38249969, 19.95916748], [86.38166809, 19.95916748], [86.38137817, 19.95893669], [86.38083649, 19.95889091], [86.38054657, 19.95861053], [86.37999725, 19.95861053], [86.3797226, 19.95889091], [86.37944794, 19.95888901], [86.37889099, 19.95944214], [86.37916565, 19.95972252], [86.3797226, 19.95972061], [86.37999725, 19.96000099], [86.38054657, 19.96000099], [86.38111115, 19.96055984], [86.3813858, 19.96055412], [86.38166809, 19.9608326], [86.38194275, 19.96083069], [86.38249969, 19.96138954], [86.38276672, 19.96138954], [86.38305664, 19.96166992], [86.3833313, 19.9616642], [86.38361359, 19.96194458], [86.38388824, 19.96194458], [86.38444519, 19.96249962], [86.38500214, 19.96249962], [86.38527679, 19.96278], [86.38555908, 19.96277618], [86.3859024, 19.96312523], [86.3861084, 19.96333313], [86.38639069, 19.96333313], [86.38694763, 19.96277618]]], [[[86.39248657, 19.96610832], [86.39221954, 19.96582985], [86.39194489, 19.96583366], [86.39104462, 19.96551132], [86.39047241, 19.96550941], [86.39047241, 19.96618843], [86.39061737, 19.96645927], [86.39194489, 19.96722221], [86.39221954, 19.96722221], [86.39264679, 19.96765137], [86.39407349, 19.9688015], [86.39570618, 19.97007942], [86.39620972, 19.97063065], [86.39723969, 19.97145271], [86.39837646, 19.97225952], [86.39877319, 19.97238731], [86.39905548, 19.97252464], [86.3992691, 19.97238731], [86.39935303, 19.97232056], [86.39913177, 19.97150993], [86.39836121, 19.97074127], [86.39778137, 19.97028351], [86.39649963, 19.96900368], [86.39499664, 19.96805573], [86.39332581, 19.96639061], [86.39305878, 19.96639061], [86.39277649, 19.96610832], [86.39248657, 19.96610832]]], [[[86.37249756, 19.95444489], [86.37166595, 19.95361137], [86.37150574, 19.95375824], [86.37093353, 19.95389366], [86.37043762, 19.95389366], [86.37020111, 19.95380402], [86.37007904, 19.95375824], [86.36962128, 19.95331955], [86.36908722, 19.9529705], [86.36824036, 19.95235825], [86.36782074, 19.95215988], [86.36660004, 19.95222282], [86.36620331, 19.95216179], [86.36572266, 19.9519043], [86.36447906, 19.95166016], [86.36326599, 19.95158958], [86.3629303, 19.95152473], [86.3611145, 19.95111084], [86.36083221, 19.95083046], [86.36000061, 19.95083427], [86.35972595, 19.95055771], [86.35945129, 19.95055962], [86.35939026, 19.95050049], [86.35916901, 19.95029068], [86.35861206, 19.95029068], [86.35832977, 19.95000076], [86.35703278, 19.94972038], [86.35639191, 19.94972229], [86.35540771, 19.94958878], [86.35513306, 19.94992065], [86.35526276, 19.95020103], [86.35547638, 19.95033073], [86.35700989, 19.95075607], [86.35730743, 19.95083427], [86.35740662, 19.95085907], [86.35876465, 19.95113182], [86.36018372, 19.95140266], [86.36289215, 19.95228004], [86.36517334, 19.95318985], [86.36746216, 19.95346069], [86.36846161, 19.95421028], [86.36917877, 19.95441055], [86.36989594, 19.95462608], [86.37007904, 19.95479012], [86.37082672, 19.95497513], [86.37110901, 19.95531082], [86.37125397, 19.95578766], [86.37132263, 19.95599174], [86.37132263, 19.95653343], [86.3713913, 19.9569397], [86.3720932, 19.95763969], [86.37229919, 19.95763969], [86.37265778, 19.95722961], [86.37258148, 19.95654106], [86.37223053, 19.95601082], [86.3722229, 19.9552803], [86.37249756, 19.95472145], [86.37249756, 19.95444489]]], [[[86.24055481, 19.90944672], [86.24028015, 19.90916443], [86.23990631, 19.90916443], [86.23972321, 19.90916443], [86.23944092, 19.90944672], [86.23860931, 19.90944672], [86.23777771, 19.9086113], [86.23777771, 19.90833282], [86.23722076, 19.90777779], [86.23694611, 19.90805435], [86.23665619, 19.90833092], [86.23666382, 19.90888977], [86.23722076, 19.90944672], [86.23722076, 19.90971947], [86.23777771, 19.91027641], [86.23777771, 19.91055489], [86.23799896, 19.91077423], [86.23833466, 19.91111183], [86.24021912, 19.91111183], [86.24055481, 19.91111183], [86.24111176, 19.91055489], [86.24111176, 19.91027641], [86.24054718, 19.90971947], [86.24055481, 19.90944672]]], [[[86.36860657, 19.9738903], [86.36888885, 19.97360992], [86.37046051, 19.97361183], [86.37232971, 19.97351837], [86.37252808, 19.97351074], [86.37281036, 19.97336769], [86.37302399, 19.97296715], [86.37301636, 19.97270012], [86.37281036, 19.97243118], [86.37252808, 19.97216034], [86.3713913, 19.9719429], [86.3713913, 19.97166634], [86.3722229, 19.97083282], [86.3722229, 19.9691658], [86.37169647, 19.96864128], [86.37088776, 19.96820259], [86.3706665, 19.96805954], [86.36972046, 19.96805573], [86.36958313, 19.96819496], [86.3694458, 19.9683342], [86.36916351, 19.96805573], [86.36805725, 19.96805573], [86.36777496, 19.9683342], [86.36723328, 19.96832848], [86.36694336, 19.96861076], [86.36499786, 19.96861076], [86.36486816, 19.96874046], [86.36416626, 19.96944427], [86.36444092, 19.96972275], [86.36444092, 19.96999931], [86.36528015, 19.97083282], [86.36528015, 19.97110176], [86.36499786, 19.97138977], [86.36499786, 19.97194481], [86.36555481, 19.97249985], [86.3658371, 19.97278023], [86.36611176, 19.97277832], [86.36638641, 19.97305489], [86.3666687, 19.97305489], [86.36694336, 19.97333336], [86.36722565, 19.97333336], [86.36750031, 19.97361183], [86.36808014, 19.97363663], [86.36831665, 19.9738903], [86.36860657, 19.9738903]]], [[[87.05751038, 20.74435806], [87.05760956, 20.74394989], [87.05742645, 20.74367905], [87.05712891, 20.74386978], [87.05671692, 20.74406052], [87.05628204, 20.7440815], [87.05608368, 20.74400711], [87.05589294, 20.74393463], [87.05547333, 20.74382019], [87.05510712, 20.74357414], [87.05477142, 20.74335289], [87.05421448, 20.7435112], [87.05369568, 20.74359322], [87.05317688, 20.74358177], [87.0526123, 20.74346352], [87.05195618, 20.74331474], [87.05164337, 20.74329185], [87.05132294, 20.74314308], [87.0508728, 20.7429924], [87.05047607, 20.74273109], [87.05013275, 20.74258995], [87.04981232, 20.74273109], [87.04953003, 20.74307632], [87.04927826, 20.74347115], [87.04902649, 20.74384117], [87.04911804, 20.74421883], [87.04953003, 20.74452209], [87.04995728, 20.74473953], [87.05036163, 20.74498749], [87.05075073, 20.74517059], [87.05116272, 20.74525833], [87.05158997, 20.74529076], [87.05201721, 20.74537086], [87.05246735, 20.74551773], [87.05293274, 20.74559975], [87.05335999, 20.74578094], [87.05378723, 20.74598122], [87.05430603, 20.7460804], [87.05488586, 20.74591064], [87.0554657, 20.74568367], [87.05599213, 20.7454052], [87.05648041, 20.74518013], [87.05692291, 20.74498177], [87.05728912, 20.74480057], [87.05742645, 20.74460983], [87.05751038, 20.74435806]]], [[[87.09083557, 20.75752068], [87.09111023, 20.75718689], [87.09140015, 20.75688171], [87.09172058, 20.75662231], [87.09210205, 20.7563858], [87.09249878, 20.75613022], [87.09290314, 20.75584602], [87.09333801, 20.75556946], [87.09379578, 20.75536919], [87.09422302, 20.75517082], [87.09440613, 20.75484848], [87.09442139, 20.7544899], [87.0943222, 20.75416756], [87.09414673, 20.75386047], [87.09393311, 20.75352097], [87.09368134, 20.7531414], [87.09334564, 20.7528019], [87.09288025, 20.75252533], [87.0923233, 20.75234032], [87.09205627, 20.75222969], [87.09176636, 20.75222015], [87.09136963, 20.75223923], [87.09088898, 20.75231743], [87.09059143, 20.75240135], [87.09037018, 20.75246048], [87.08983612, 20.75250053], [87.08930969, 20.75255966], [87.08882904, 20.75272369], [87.08837128, 20.75276947], [87.08792877, 20.75278091], [87.08750153, 20.75278091], [87.08706665, 20.75279045], [87.08664703, 20.75284004], [87.08624268, 20.75294113], [87.08583832, 20.75280952], [87.0854187, 20.75269127], [87.08493805, 20.75267982], [87.08439636, 20.75290108], [87.08393097, 20.75307655], [87.08349609, 20.75325203], [87.0830307, 20.7533226], [87.08268738, 20.75332642], [87.08257294, 20.75333023], [87.0823822, 20.75330544], [87.08213043, 20.7532692], [87.0817337, 20.75313568], [87.0812912, 20.7530899], [87.08088684, 20.75304031], [87.08048248, 20.7531414], [87.08003998, 20.7532444], [87.07985687, 20.75318527], [87.07958984, 20.75310326], [87.0790863, 20.75303078], [87.07860565, 20.75290489], [87.07816315, 20.75276375], [87.07779694, 20.75260544], [87.07752228, 20.75247955], [87.07731628, 20.75237846], [87.0769043, 20.75245094], [87.07653046, 20.75248337], [87.07639313, 20.75246811], [87.0761795, 20.75244522], [87.07582855, 20.75226974], [87.07543182, 20.75217056], [87.07502747, 20.7520771], [87.07460022, 20.75223923], [87.07418823, 20.75247955], [87.07382965, 20.75267982], [87.07345581, 20.75280952], [87.07311249, 20.75299835], [87.07272339, 20.75332069], [87.07247925, 20.7541008], [87.0725174, 20.75455856], [87.07264709, 20.75502968], [87.07285309, 20.75555038], [87.073349, 20.75587082], [87.07395935, 20.75612259], [87.07457733, 20.75637817], [87.07520294, 20.75658035], [87.07578278, 20.75674248], [87.07628632, 20.75692749], [87.07676697, 20.75705719], [87.0772171, 20.75723267], [87.07766724, 20.75745964], [87.07818604, 20.75766945], [87.07861328, 20.75799179], [87.07901764, 20.75830078], [87.07942963, 20.75847054], [87.07995605, 20.75831032], [87.08044434, 20.7579422], [87.08079529, 20.75763321], [87.08110046, 20.75741768], [87.08142853, 20.75729942], [87.08180237, 20.75726128], [87.0821991, 20.75727844], [87.08257294, 20.75735855], [87.08291626, 20.75748062], [87.08325195, 20.75765991], [87.08352661, 20.75789833], [87.08374023, 20.75823021], [87.08383942, 20.75866127], [87.08383942, 20.75917053], [87.08376312, 20.75970078], [87.08362579, 20.7602005], [87.08342743, 20.76067162], [87.08318329, 20.76108932], [87.08287048, 20.76151276], [87.08249664, 20.76200294], [87.08216095, 20.76264], [87.08200836, 20.76303291], [87.08216858, 20.76325035], [87.08250427, 20.76336479], [87.08283234, 20.76355362], [87.08317566, 20.76375389], [87.08349609, 20.76402092], [87.08394623, 20.76424026], [87.08452606, 20.76439095], [87.08469391, 20.76436996], [87.08534241, 20.76428986], [87.08615112, 20.76411057], [87.08642578, 20.76387024], [87.08666992, 20.76358986], [87.08690643, 20.76325417], [87.08714294, 20.76287079], [87.08737183, 20.76250076], [87.08759308, 20.76214027], [87.0878067, 20.76176834], [87.08805847, 20.76137161], [87.08833313, 20.76092148], [87.08862305, 20.76045036], [87.08893585, 20.76003456], [87.08929443, 20.75972557], [87.0896225, 20.75943947], [87.08991241, 20.75912094], [87.0901413, 20.75872993], [87.09034729, 20.75828552], [87.09057617, 20.75788116], [87.09083557, 20.75752068]]], [[[87.07055664, 20.73621368], [87.07038879, 20.73551559], [87.06999969, 20.73527718], [87.06944275, 20.73583412], [87.06916809, 20.73583412], [87.06824493, 20.73674393], [87.06804657, 20.73694038], [87.06804657, 20.73777962], [87.06833649, 20.73805618], [87.06833649, 20.73861122], [87.06916809, 20.73944473], [87.06948853, 20.73944473], [87.06972504, 20.73944473], [87.06999969, 20.7397213], [87.06977844, 20.7400074], [87.06965637, 20.7401619], [87.06955719, 20.74061012], [87.06967926, 20.74086761], [87.06971741, 20.74119186], [87.06973267, 20.74156952], [87.06972504, 20.74201775], [87.06972504, 20.74252129], [87.06976318, 20.74304962], [87.06990814, 20.74352837], [87.07003021, 20.74401093], [87.07023621, 20.74446106], [87.07026672, 20.74502945], [87.07028198, 20.74560928], [87.0703125, 20.74614716], [87.07048035, 20.74661064], [87.07056427, 20.74704552], [87.07068634, 20.74748039], [87.07087708, 20.74798965], [87.07116699, 20.74846077], [87.07149506, 20.74878311], [87.0717926, 20.74881172], [87.07192993, 20.74867249], [87.07205963, 20.74853897], [87.07205963, 20.74818993], [87.07212067, 20.74776077], [87.07200623, 20.74724007], [87.07195282, 20.74671364], [87.07194519, 20.74621964], [87.07195282, 20.7457695], [87.07194519, 20.74536133], [87.07194519, 20.74495888], [87.07193756, 20.7445507], [87.07187653, 20.74411011], [87.07174683, 20.74370003], [87.07170868, 20.74323082], [87.07174683, 20.74273109], [87.07161713, 20.7422905], [87.07144165, 20.74187469], [87.07138824, 20.74140167], [87.07132721, 20.74094772], [87.07113647, 20.74057961], [87.07104492, 20.7403717], [87.07097626, 20.74022293], [87.07084656, 20.73981667], [87.07071686, 20.73937035], [87.0705719, 20.7389946], [87.07043457, 20.73861885], [87.0703125, 20.73822021], [87.07028961, 20.73775864], [87.07032013, 20.73727036], [87.07045746, 20.7367897], [87.07055664, 20.73621368]]], [[[87.12388611, 21.51972008], [87.12388611, 21.5177784], [87.12375641, 21.51749992], [87.12361145, 21.51499939], [87.12387848, 21.51472092], [87.12361145, 21.51444435], [87.12304688, 21.51444054], [87.12249756, 21.51499939], [87.12243652, 21.51528931], [87.1222229, 21.51555824], [87.12210083, 21.51570129], [87.12194824, 21.51571083], [87.1213913, 21.51555824], [87.12110901, 21.51556396], [87.12083435, 21.51556396], [87.12055206, 21.51555634], [87.1202774, 21.51555824], [87.11916351, 21.51666641], [87.11888123, 21.51721954], [87.11888885, 21.51749992], [87.11888885, 21.5177784], [87.11909485, 21.51812363], [87.11915588, 21.51833153], [87.1194458, 21.51874924], [87.1194458, 21.51889038], [87.11972046, 21.51909065], [87.1202774, 21.51944351], [87.12055206, 21.5194416], [87.12166595, 21.5205555], [87.12243652, 21.52082443], [87.1230545, 21.52082443], [87.12365723, 21.52050209], [87.12388611, 21.51972008]]], [[[86.87416077, 20.67361069], [86.87388611, 20.67333031], [86.87361145, 20.67333412], [86.87319946, 20.67314339], [86.87241364, 20.67267227], [86.87206268, 20.67267036], [86.87197876, 20.67308998], [86.8722229, 20.67388916], [86.8722229, 20.67416954], [86.87333679, 20.67527771], [86.87333679, 20.67555046], [86.87555695, 20.67778015], [86.8758316, 20.67778015], [86.87611389, 20.67805862], [86.87695313, 20.67889023], [86.87722015, 20.67889023], [86.8777771, 20.6794529], [86.87832642, 20.6794529], [86.87889099, 20.67889023], [86.87889099, 20.67861176], [86.87833405, 20.67805481], [86.87833405, 20.67777824], [86.87638855, 20.67583084], [86.87638855, 20.67555618], [86.87444305, 20.67361069], [86.87416077, 20.67361069]]], [[[86.80278015, 20.42083359], [86.80361176, 20.41999817], [86.80388641, 20.41999817], [86.8041687, 20.4197197], [86.80444336, 20.4197216], [86.80472565, 20.41944504], [86.80555725, 20.41944504], [86.80583191, 20.4197216], [86.80722046, 20.4197216], [86.8077774, 20.41916656], [86.80805206, 20.41917038], [86.80832672, 20.41945076], [86.80860901, 20.41945076], [86.8088913, 20.41917038], [86.8088913, 20.41888809], [86.80944824, 20.41833115], [86.80944824, 20.41805649], [86.8097229, 20.41777992], [86.80999756, 20.41777992], [86.81223297, 20.41555977], [86.81223297, 20.41527939], [86.81305695, 20.41444016], [86.81305695, 20.4141674], [86.8133316, 20.41389084], [86.81305695, 20.41362], [86.81305695, 20.41333008], [86.8133316, 20.41305542], [86.8133316, 20.41250038], [86.81360626, 20.41222191], [86.81361389, 20.41166687], [86.81388092, 20.4113903], [86.81388092, 20.41111183], [86.81416321, 20.41083336], [86.81416321, 20.41055489], [86.81445313, 20.41028023], [86.81445313, 20.40806007], [86.81472015, 20.40777969], [86.81472015, 20.40722084], [86.81486511, 20.4066906], [86.81468201, 20.40624619], [86.81446075, 20.40584946], [86.81434631, 20.40545273], [86.81446075, 20.40504074], [86.81463623, 20.40462112], [86.81465912, 20.40414047], [86.81450653, 20.40367889], [86.81439209, 20.40316963], [86.81420135, 20.40267944], [86.81404877, 20.40218735], [86.81391144, 20.40172005], [86.81377411, 20.40130043], [86.81373596, 20.40076828], [86.81360626, 20.40028], [86.81360626, 20.39999962], [86.81276703, 20.39916992], [86.81276703, 20.39862061], [86.8125, 20.3983326], [86.8125, 20.39777756], [86.81223297, 20.3975029], [86.81223297, 20.39722252], [86.81194305, 20.39694405], [86.81194305, 20.39639091], [86.8116684, 20.39610863], [86.81141663, 20.39571953], [86.81118011, 20.39534187], [86.81095886, 20.39491653], [86.81079102, 20.39444923], [86.81054688, 20.39402962], [86.81031799, 20.39363289], [86.81015778, 20.39322281], [86.81010437, 20.39276695], [86.810112, 20.39227104], [86.80992889, 20.39190292], [86.80966949, 20.3915596], [86.80950165, 20.3911705], [86.80944824, 20.3908329], [86.80944824, 20.39027786], [86.80916595, 20.38999939], [86.80916595, 20.38943291], [86.80860901, 20.38888931], [86.80860901, 20.38861084], [86.80832672, 20.38833046], [86.80833435, 20.38722229], [86.80805206, 20.38694382], [86.80805206, 20.38638878], [86.8077774, 20.38611031], [86.8077774, 20.38528061], [86.80750275, 20.38500023], [86.80750275, 20.38389015], [86.8077774, 20.38362122], [86.8077774, 20.38194084], [86.80750275, 20.38166618], [86.80750275, 20.38110924], [86.8077774, 20.38083076], [86.8077774, 20.38055611], [86.80750275, 20.38027954], [86.80750275, 20.37833023], [86.80722046, 20.37805557], [86.80722046, 20.375], [86.8069458, 20.37471962], [86.8069458, 20.37444305], [86.80665588, 20.3741703], [86.80665588, 20.37388992], [86.80444336, 20.37166977], [86.8041687, 20.37166977], [86.80388641, 20.37138939], [86.80361176, 20.37166595], [86.80361176, 20.37194443], [86.8033371, 20.3722229], [86.8033371, 20.37249947], [86.80361176, 20.37277985], [86.80361176, 20.37388802], [86.80444336, 20.37472153], [86.80304718, 20.37611008], [86.80304718, 20.37667084], [86.80444336, 20.37805939], [86.80444336, 20.37861061], [86.80473328, 20.37889099], [86.80472565, 20.37916946], [86.80500031, 20.37944412], [86.80500031, 20.37972069], [86.80526733, 20.37999916], [86.80527496, 20.38027954], [86.80555725, 20.38055038], [86.80555725, 20.38110924], [86.80565643, 20.38121033], [86.80583191, 20.38139153], [86.80583191, 20.38166618], [86.8061142, 20.38194466], [86.80610657, 20.38221931], [86.80583191, 20.3825016], [86.80583191, 20.38333321], [86.80580902, 20.38389969], [86.80578613, 20.38443947], [86.80563354, 20.38495445], [86.80570984, 20.38542938], [86.80580902, 20.38588905], [86.80583191, 20.38636208], [86.80587769, 20.38685226], [86.80606079, 20.38735008], [86.80605316, 20.38786125], [86.80589294, 20.38834], [86.80587006, 20.38884926], [86.80589294, 20.38931084], [86.80570221, 20.38962173], [86.80543518, 20.38975143], [86.80508423, 20.38950157], [86.80474091, 20.38900757], [86.80466461, 20.38887405], [86.80440521, 20.38843536], [86.80404663, 20.38792038], [86.80370331, 20.38748169], [86.80269623, 20.3864975], [86.80220032, 20.38609505], [86.80169678, 20.38610268], [86.80155182, 20.38656807], [86.8015213, 20.38713074], [86.80145264, 20.38766098], [86.80124664, 20.38812065], [86.80105591, 20.38863754], [86.80073547, 20.38921356], [86.80049133, 20.3895874], [86.80030823, 20.3898716], [86.80041504, 20.39044952], [86.80057526, 20.39105225], [86.80083466, 20.39155006], [86.80110931, 20.39194107], [86.80194092, 20.3927803], [86.80194092, 20.39305496], [86.80222321, 20.39333344], [86.80222321, 20.39471817], [86.80194092, 20.39499855], [86.80194092, 20.3955555], [86.80166626, 20.39582825], [86.80166626, 20.39610863], [86.80110931, 20.39666939], [86.80098724, 20.39692116], [86.8006897, 20.39712524], [86.80033112, 20.3973484], [86.80000305, 20.39770508], [86.79977417, 20.39822388], [86.79973602, 20.39883995], [86.79989624, 20.39937782], [86.80055237, 20.39964294], [86.80097198, 20.4000206], [86.80122375, 20.40039063], [86.8013916, 20.40083122], [86.80222321, 20.40167999], [86.80222321, 20.40195084], [86.80110931, 20.40305519], [86.80110931, 20.40332985], [86.8013916, 20.40361023], [86.8013916, 20.40416527], [86.80166626, 20.40443039], [86.80166626, 20.40611076], [86.8013916, 20.40639114], [86.8013916, 20.4066658], [86.80110931, 20.40694046], [86.80110931, 20.40750122], [86.80082703, 20.40777969], [86.80110931, 20.40806007], [86.80110931, 20.40889168], [86.8013916, 20.40916634], [86.8013916, 20.40971947], [86.80083466, 20.41027832], [86.80047607, 20.41052055], [86.80046844, 20.4109211], [86.80059052, 20.41135979], [86.80086517, 20.41177559], [86.8013916, 20.41222382], [86.80166626, 20.41222191], [86.80194092, 20.41250038], [86.80222321, 20.41250038], [86.80249786, 20.41278076], [86.80278015, 20.41278076], [86.8033371, 20.41222191], [86.80361176, 20.41222382], [86.80388641, 20.41194534], [86.8041687, 20.41195107], [86.80473328, 20.4113903], [86.80500031, 20.4113903], [86.80555725, 20.41082954], [86.80555725, 20.41055489], [86.80583191, 20.41028023], [86.80638885, 20.41027832], [86.8069458, 20.41082954], [86.8061142, 20.41166687], [86.80610657, 20.41222191], [86.80638885, 20.41250038], [86.80638885, 20.41277695], [86.8069458, 20.41333389], [86.80583191, 20.41444588], [86.80500031, 20.41444016], [86.8041687, 20.41527748], [86.8041687, 20.41583061], [86.80361176, 20.41638947], [86.8033371, 20.41638947], [86.80304718, 20.41666031], [86.80305481, 20.41777611], [86.80222321, 20.41860962], [86.80222321, 20.41888809], [86.80166626, 20.41945076], [86.80166626, 20.41999817], [86.80249786, 20.42083359], [86.80278015, 20.42083359]]], [[[86.80272675, 20.45947266], [86.80259705, 20.45947266], [86.80202484, 20.45953751], [86.8015213, 20.45967293], [86.80130768, 20.45994377], [86.80123901, 20.46047974], [86.80123901, 20.46115685], [86.80137634, 20.46183014], [86.80145264, 20.46224976], [86.80194855, 20.46250725], [86.80245209, 20.46264267], [86.80281067, 20.46264267], [86.80330658, 20.46250725], [86.8035965, 20.46197128], [86.8035965, 20.46149063], [86.80323792, 20.46081924], [86.80287933, 20.46027756], [86.80272675, 20.45947266]]], [[[86.80527496, 20.49194527], [86.80638885, 20.49083328], [86.80638885, 20.49055481], [86.8069458, 20.49000168], [86.8069458, 20.48971939], [86.80722046, 20.48944473], [86.80722046, 20.48916626], [86.80750275, 20.48887825], [86.80750275, 20.48860931], [86.8077774, 20.48833084], [86.8077774, 20.48777962], [86.80805206, 20.48749924], [86.8077774, 20.48722076], [86.8077774, 20.4869442], [86.80805206, 20.48666573], [86.80805206, 20.48639107], [86.80832672, 20.48611069], [86.80832672, 20.48555946], [86.80860901, 20.48528099], [86.80860901, 20.48443985], [86.80944824, 20.48361206], [86.80916595, 20.48333359], [86.80916595, 20.48305511], [86.80860901, 20.48250008], [86.8088913, 20.4822197], [86.8088913, 20.48166656], [86.80860901, 20.48139], [86.80944824, 20.4805603], [86.80944824, 20.47999954], [86.80916595, 20.47970963], [86.80916595, 20.4794445], [86.8088913, 20.47916603], [86.8088913, 20.47805977], [86.80916595, 20.47777939], [86.80916595, 20.47722244], [86.80944824, 20.47694206], [86.80944824, 20.4766674], [86.80860901, 20.47582817], [86.80833435, 20.47444534], [86.80832672, 20.47417068], [86.80805206, 20.47390175], [86.8077774, 20.47390175], [86.80715179, 20.47326279], [86.8069458, 20.47305489], [86.8069458, 20.47277641], [86.80665588, 20.47249985], [86.80665588, 20.47194099], [86.80583191, 20.4711113], [86.80583191, 20.4691658], [86.80603027, 20.46838188], [86.80603027, 20.46757126], [86.80594635, 20.46689034], [86.80573273, 20.46669006], [86.80558777, 20.46648788], [86.8055191, 20.46600914], [86.80530548, 20.46567726], [86.80523682, 20.46521187], [86.80487823, 20.46459961], [86.80478668, 20.46445274], [86.80444336, 20.46388817], [86.8041687, 20.4636116], [86.80361176, 20.4636116], [86.80249786, 20.46470833], [86.80278015, 20.46500015], [86.80278015, 20.46555519], [86.80304718, 20.46582985], [86.80305481, 20.46666718], [86.80278015, 20.46694374], [86.80278015, 20.46776962], [86.80249786, 20.46805573], [86.80249786, 20.46972084], [86.80222321, 20.47000122], [86.80222321, 20.47056007], [86.80194092, 20.47083282], [86.80194092, 20.47222137], [86.80110931, 20.47305489], [86.80110931, 20.47333336], [86.80082703, 20.47360992], [86.80082703, 20.47390175], [86.80110931, 20.47417068], [86.80110931, 20.47444534], [86.8013916, 20.47471809], [86.8013916, 20.47527695], [86.80153656, 20.47542572], [86.80166626, 20.47555542], [86.80166626, 20.47582817], [86.80194092, 20.47610855], [86.80194092, 20.47639084], [86.80388641, 20.47833061], [86.80526733, 20.47970963], [86.80527496, 20.48027802], [86.80583191, 20.48083305], [86.80583191, 20.48110962], [86.8041687, 20.48278046], [86.80388641, 20.48277855], [86.8033371, 20.48332977], [86.80388641, 20.48389053], [86.80388641, 20.48416519], [86.80361176, 20.48443985], [86.80361176, 20.48500061], [86.8041687, 20.48555946], [86.8041687, 20.48583984], [86.80388641, 20.48611069], [86.80388641, 20.48639107], [86.8041687, 20.48666954], [86.80444336, 20.48666573], [86.80472565, 20.4869442], [86.80473328, 20.48722076], [86.80500031, 20.48749733], [86.80500031, 20.48833275], [86.80444336, 20.48887825], [86.80444336, 20.48916626], [86.8041687, 20.48944473], [86.8041687, 20.48971939], [86.80444336, 20.49000168], [86.80444336, 20.49083328], [86.8041687, 20.49111176], [86.8041687, 20.49139023], [86.80444336, 20.49167061], [86.80500031, 20.49166679], [86.80527496, 20.49194527]]], [[[87.0085144, 20.70812225], [87.00765991, 20.70798874], [87.00522614, 20.70799065], [87.00444794, 20.70806122], [87.00366211, 20.70833015], [87.00243378, 20.70866585], [87.00243378, 20.70900345], [87.00286102, 20.70953751], [87.00328827, 20.70994949], [87.00378418, 20.71042061], [87.00443268, 20.71089172], [87.00463867, 20.71108437], [87.00508118, 20.71150017], [87.00585938, 20.71237946], [87.00628662, 20.71305084], [87.00656891, 20.71359062], [87.00714111, 20.71426964], [87.00734711, 20.71480942], [87.00764465, 20.7154808], [87.00814056, 20.71622276], [87.0087204, 20.71696281], [87.00928497, 20.71770668], [87.00992584, 20.7183094], [87.01064301, 20.71905518], [87.01107025, 20.71937943], [87.0114975, 20.7198658], [87.01199341, 20.72040558], [87.01264954, 20.72081184], [87.01328278, 20.72114754], [87.01391602, 20.72154808], [87.01441956, 20.7218895], [87.01513672, 20.72216034], [87.01550293, 20.72223091], [87.01572418, 20.72222328], [87.01583099, 20.72222137], [87.01611328, 20.72194481], [87.01642609, 20.72154045], [87.01657867, 20.72120094], [87.01686096, 20.72079659], [87.01706696, 20.72032928], [87.01721191, 20.71992111], [87.01743317, 20.71945], [87.01750183, 20.71898079], [87.0175705, 20.71857071], [87.0175705, 20.71768951], [87.01763916, 20.71742439], [87.01778412, 20.71722031], [87.01778412, 20.71668434], [87.01750183, 20.71610832], [87.01748657, 20.71602058], [87.01743317, 20.7156105], [87.01743317, 20.71500587], [87.01721954, 20.71433067], [87.01693726, 20.71393013], [87.01657867, 20.71325111], [87.01615143, 20.71244049], [87.01586914, 20.7121048], [87.01551056, 20.71183205], [87.01486969, 20.7110939], [87.01415253, 20.71041679], [87.01373291, 20.7100811], [87.01315308, 20.70981026], [87.01258087, 20.70935249], [87.01180267, 20.70900154], [87.01115417, 20.70879745], [87.01072693, 20.70853043], [87.00987244, 20.70833015], [87.0091629, 20.70819092], [87.0085144, 20.70812225]]], [[[87.00302124, 20.71079063], [87.00230408, 20.71033287], [87.00216675, 20.7105999], [87.00216675, 20.71087265], [87.00238037, 20.71114159], [87.0025177, 20.71141052], [87.00266266, 20.71181488], [87.00295258, 20.71215057], [87.0030899, 20.71249008], [87.00323486, 20.71289635], [87.00330353, 20.71343231], [87.00402069, 20.71423912], [87.00430298, 20.71471977], [87.0045929, 20.71525955], [87.00502014, 20.71572876], [87.00526428, 20.71611595], [87.005867, 20.71707916], [87.0063858, 20.71762085], [87.00686646, 20.71870041], [87.00786591, 20.7197094], [87.00830078, 20.72005081], [87.00872803, 20.72024918], [87.00901794, 20.72024918], [87.0091629, 20.71997833], [87.00908661, 20.7197094], [87.00879669, 20.7193718], [87.00880432, 20.71883392], [87.00865936, 20.71849442], [87.0085144, 20.71809006], [87.00830078, 20.71767807], [87.00815582, 20.71707726], [87.00765991, 20.7166729], [87.00737762, 20.71640205], [87.00694275, 20.71559334], [87.00687408, 20.71518707], [87.00630188, 20.71430969], [87.00601959, 20.71336555], [87.00559235, 20.71289063], [87.00523376, 20.71242142], [87.00504303, 20.71223831], [87.00487518, 20.71208382], [87.00437927, 20.71174622], [87.00395203, 20.71147919], [87.00358582, 20.71128273], [87.00337982, 20.71114159], [87.00302124, 20.71079063]]], [[[87.01651001, 20.80282974], [87.01651001, 20.80067062], [87.0167923, 20.79904938], [87.0167923, 20.79824066], [87.01651001, 20.79770088], [87.01566315, 20.79743958], [87.01499939, 20.79722023], [87.01444244, 20.79722023], [87.01416779, 20.79750252], [87.01389313, 20.79750252], [87.01333618, 20.79805946], [87.01333618, 20.79861259], [87.01361084, 20.79888153], [87.01361084, 20.79916573], [87.01399994, 20.79958344], [87.01399994, 20.80120277], [87.01342773, 20.80201149], [87.01314545, 20.80228233], [87.01315308, 20.80255127], [87.01228333, 20.80282974], [87.01200104, 20.80282974], [87.01171875, 20.80308914], [87.01142883, 20.80336189], [87.00858307, 20.80606079], [87.00743103, 20.80714035], [87.00685883, 20.80795097], [87.00657654, 20.80821991], [87.00572205, 20.80957031], [87.00543213, 20.81038094], [87.00514984, 20.81118965], [87.00457764, 20.81226921], [87.00457764, 20.81578827], [87.00430298, 20.81659126], [87.00401306, 20.8168602], [87.00343323, 20.81793594], [87.00343323, 20.81874084], [87.00286865, 20.81955528], [87.00257874, 20.82090378], [87.00229645, 20.82198334], [87.00200653, 20.82333374], [87.00172424, 20.8244133], [87.00115204, 20.8257637], [87.00086975, 20.82683945], [87.00057983, 20.82846069], [87.00086975, 20.82953835], [87.00250244, 20.83222198], [87.0027771, 20.83222198], [87.00487518, 20.83232117], [87.0065918, 20.83232117], [87.00830078, 20.83177948], [87.00944519, 20.83097267], [87.01087189, 20.82989311], [87.01258087, 20.82827568], [87.01429749, 20.82665443], [87.01544189, 20.82584381], [87.01629639, 20.82449532], [87.0174408, 20.82368088], [87.01857758, 20.82287407], [87.01914978, 20.82152748], [87.01972198, 20.81991005], [87.01999664, 20.81855965], [87.01999664, 20.81478119], [87.0194397, 20.81343079], [87.0187912, 20.81226921], [87.0187912, 20.81064987], [87.01822662, 20.80903244], [87.01822662, 20.80768585], [87.0173645, 20.80444527], [87.0167923, 20.80336952], [87.01651001, 20.80282974]]], [[[86.98416901, 20.78222275], [86.98444366, 20.78194427], [86.98500061, 20.78194427], [86.9861145, 20.7808342], [86.98665619, 20.78083992], [86.98722076, 20.78028107], [86.98750305, 20.78028107], [86.98750305, 20.77943993], [86.98666382, 20.77861023], [86.98527527, 20.77861023], [86.98500061, 20.77833366], [86.98305511, 20.77833366], [86.98278046, 20.77805519], [86.98194122, 20.77805519], [86.98166656, 20.77833366], [86.98139191, 20.77832985], [86.98055267, 20.77916718], [86.98055267, 20.77944374], [86.98027802, 20.77972031], [86.98027802, 20.78000069], [86.98055267, 20.78028107], [86.98055267, 20.78055954], [86.98166656, 20.78166771], [86.98222351, 20.7816658], [86.98249817, 20.78194427], [86.98278046, 20.78194427], [86.98305511, 20.78222275], [86.98416901, 20.78222275]]], [[[86.87527466, 20.77583313], [86.87555695, 20.77555466], [86.87611389, 20.77555466], [86.8769455, 20.77472305], [86.87722015, 20.77472305], [86.8777771, 20.77416611], [86.8777771, 20.77318954], [86.8777771, 20.77305603], [86.87750244, 20.77277946], [86.87695313, 20.77277946], [86.87666321, 20.77305984], [86.87611389, 20.77305603], [86.8758316, 20.7733345], [86.87555695, 20.77333069], [86.87526703, 20.77361107], [86.875, 20.77361107], [86.87444305, 20.77416611], [86.87444305, 20.77444077], [86.87388611, 20.77499962], [86.87388611, 20.77555466], [86.8741684, 20.77583313], [86.87472534, 20.77583313], [86.875, 20.77555466], [86.87516022, 20.77571869], [86.87527466, 20.77583313]]], [[[86.86499023, 20.78111076], [86.86528015, 20.78083992], [86.86554718, 20.78083992], [86.8658371, 20.78055954], [86.86638641, 20.78055954], [86.8666687, 20.78028107], [86.86723328, 20.78028107], [86.86776733, 20.77972031], [86.86805725, 20.77972221], [86.86833191, 20.77944374], [86.8686142, 20.77944374], [86.87166595, 20.77638817], [86.87166595, 20.7761097], [86.87083435, 20.77527809], [86.8702774, 20.77527809], [86.87000275, 20.77555466], [86.8694458, 20.77555466], [86.86916351, 20.77583313], [86.8686142, 20.77583313], [86.86833191, 20.7761116], [86.86805725, 20.7761097], [86.86750031, 20.77667046], [86.86722565, 20.77666664], [86.8666687, 20.77722168], [86.86638641, 20.77722168], [86.8658371, 20.77777863], [86.86554718, 20.777771], [86.86444092, 20.77889061], [86.86444092, 20.77916718], [86.86416626, 20.77943993], [86.86416626, 20.78055954], [86.86472321, 20.78111076], [86.86499023, 20.78111076]]], [[[86.88194275, 20.78861046], [86.88223267, 20.78833008], [86.88666534, 20.7883358], [86.88694763, 20.78805542], [86.89083099, 20.78806114], [86.89111328, 20.78778076], [86.89277649, 20.78778076], [86.89305878, 20.78750038], [86.89417267, 20.78750038], [86.89444733, 20.78722382], [86.89666748, 20.78722382], [86.89694214, 20.78694534], [86.89833069, 20.78694534], [86.89861298, 20.78666687], [86.90000153, 20.78667068], [86.90027618, 20.7863903], [86.90083313, 20.7863903], [86.90110016, 20.78611183], [86.90193176, 20.78611374], [86.90249634, 20.78611374], [86.90277863, 20.78583145], [86.90305328, 20.78583145], [86.90333557, 20.78555489], [86.90416718, 20.78555489], [86.90444183, 20.78527832], [86.90471649, 20.78528023], [86.90499878, 20.78500175], [86.90556335, 20.78500175], [86.90583038, 20.78471947], [86.90611267, 20.78471947], [86.90638733, 20.78444481], [86.90777588, 20.78444481], [86.90805817, 20.78416634], [86.90888977, 20.78417015], [86.9091568, 20.78390121], [86.90999603, 20.78390121], [86.91028595, 20.78360939], [86.91139221, 20.78360939], [86.91166687, 20.78333282], [86.91305542, 20.78333282], [86.91333008, 20.78305626], [86.91361237, 20.78306007], [86.91388702, 20.7827816], [86.91443634, 20.7827816], [86.91471863, 20.78249931], [86.91694641, 20.78249931], [86.91722107, 20.78222084], [86.91777802, 20.78222275], [86.91805267, 20.78194427], [86.91944122, 20.78194427], [86.91972351, 20.7816658], [86.92193604, 20.78166771], [86.92222595, 20.78138924], [86.92415619, 20.78138924], [86.92444611, 20.78111076], [86.92610931, 20.78111076], [86.9263916, 20.78083992], [86.92694092, 20.78083992], [86.92722321, 20.78055954], [86.92778015, 20.78055954], [86.92804718, 20.78083992], [86.92861176, 20.78083992], [86.92888641, 20.78055954], [86.93055725, 20.78055954], [86.93083191, 20.78028107], [86.93222046, 20.78028107], [86.93250275, 20.78055954], [86.93360901, 20.78055954], [86.9338913, 20.78028107], [86.93638611, 20.78028107], [86.9366684, 20.78028107], [86.93694305, 20.78000069], [86.93723297, 20.78000069], [86.9375, 20.78028107], [86.9383316, 20.78028107], [86.93860626, 20.78000069], [86.94026947, 20.78000069], [86.94055176, 20.77972031], [86.94194794, 20.77972221], [86.9422226, 20.77944374], [86.94249725, 20.77944374], [86.94277954, 20.77916718], [86.94361115, 20.77917099], [86.94481659, 20.77840805], [86.94610596, 20.77786827], [86.94760895, 20.77726173], [86.94944, 20.77667046], [86.95024872, 20.77639961], [86.95096588, 20.77579117], [86.95153046, 20.77518082], [86.95153046, 20.7747097], [86.95054626, 20.77388954], [86.94999695, 20.77333069], [86.94944763, 20.7733345], [86.94927979, 20.77316666], [86.94916534, 20.77305603], [86.94902802, 20.77305603], [86.9486084, 20.77305984], [86.94832611, 20.77277946], [86.94695282, 20.77277946], [86.9466629, 20.7725029], [86.94555664, 20.7725029], [86.94526672, 20.77277946], [86.9422226, 20.77277946], [86.94194794, 20.7725029], [86.9411087, 20.7725029], [86.94082642, 20.77222061], [86.94055176, 20.77222061], [86.94026947, 20.77194023], [86.93972015, 20.7725029], [86.93945313, 20.7725029], [86.93916321, 20.77277946], [86.93527985, 20.77277946], [86.93499756, 20.77305984], [86.93416595, 20.77305603], [86.9338913, 20.7733345], [86.93222046, 20.77333069], [86.9319458, 20.77361107], [86.93110657, 20.77361107], [86.93083191, 20.77388954], [86.92804718, 20.77388954], [86.92778015, 20.77416992], [86.92666626, 20.77416992], [86.9263916, 20.77388954], [86.92555237, 20.77388954], [86.92527008, 20.77416992], [86.92082977, 20.77416992], [86.92073822, 20.77407646], [86.92055511, 20.77388954], [86.92028046, 20.77388954], [86.91999817, 20.77416992], [86.91832733, 20.77416992], [86.91805267, 20.77388954], [86.91777802, 20.77388954], [86.91750336, 20.77416992], [86.91666412, 20.77416611], [86.91638947, 20.77444458], [86.91444397, 20.77444458], [86.91416931, 20.77472305], [86.91388702, 20.77472305], [86.91361237, 20.77444458], [86.91333008, 20.77472305], [86.91194153, 20.77472305], [86.91166687, 20.77444458], [86.91083527, 20.77444458], [86.91055298, 20.77472305], [86.90777588, 20.77472305], [86.90750122, 20.77444458], [86.90694427, 20.77444458], [86.90638733, 20.77388954], [86.90611267, 20.77388954], [86.90583038, 20.77361107], [86.90471649, 20.77361107], [86.90444183, 20.77333069], [86.90333557, 20.7733345], [86.90313721, 20.77313805], [86.90305328, 20.77305603], [86.90277863, 20.77305984], [86.90249634, 20.77277946], [86.90222168, 20.77277946], [86.90194702, 20.7725029], [86.90139008, 20.7725029], [86.90110016, 20.77222061], [86.90027618, 20.77222061], [86.90000153, 20.77194214], [86.89722443, 20.77194214], [86.89694214, 20.77166748], [86.89527893, 20.77166748], [86.89499664, 20.77194214], [86.89083099, 20.77194214], [86.89055634, 20.77222061], [86.88722229, 20.77222061], [86.88694763, 20.7725029], [86.88500214, 20.7725029], [86.88471985, 20.77277946], [86.88360596, 20.77277946], [86.8833313, 20.77305984], [86.88083649, 20.77305603], [86.8805542, 20.7733345], [86.87999725, 20.7733345], [86.87889099, 20.77444077], [86.87944794, 20.77499962], [86.88028717, 20.77499962], [86.8805542, 20.77472305], [86.88111115, 20.77472305], [86.8813858, 20.77444458], [86.88222504, 20.77444458], [86.88249969, 20.77416611], [86.88361359, 20.77416611], [86.88388824, 20.77444458], [86.8841629, 20.77444458], [86.88445282, 20.7747097], [86.8841629, 20.77499962], [86.88388824, 20.77499962], [86.88360596, 20.77528], [86.88277435, 20.77527809], [86.88249969, 20.77555466], [86.88222504, 20.77555466], [86.88194275, 20.77583313], [86.88166809, 20.77583313], [86.8813858, 20.7761116], [86.88083649, 20.7761097], [86.88054657, 20.77639008], [86.87999725, 20.77639008], [86.8797226, 20.77667046], [86.87944794, 20.77667046], [86.87917328, 20.77695084], [86.87889099, 20.77695084], [86.87722015, 20.77861023], [86.87670135, 20.77861023], [86.87638855, 20.77861023], [86.87631226, 20.77853584], [86.87611389, 20.77833366], [86.8758316, 20.77833366], [86.87555695, 20.77806091], [86.87444305, 20.77917099], [86.87388611, 20.77916718], [86.87361145, 20.77944374], [86.8730545, 20.77944374], [86.87277985, 20.77916718], [86.87249756, 20.77944374], [86.87194824, 20.77944374], [86.87166595, 20.77972221], [86.87082672, 20.77972031], [86.87055206, 20.78000069], [86.87000275, 20.78000069], [86.86972046, 20.78028107], [86.8694458, 20.78028107], [86.86915588, 20.78055954], [86.86888885, 20.78055954], [86.86860657, 20.78083992], [86.86833191, 20.78083992], [86.86805725, 20.78111076], [86.86776733, 20.78111076], [86.86750031, 20.78138924], [86.86723328, 20.78138924], [86.86694336, 20.78166771], [86.8666687, 20.7816658], [86.86638641, 20.78194427], [86.86611176, 20.78194427], [86.8658371, 20.78222275], [86.86554718, 20.78222084], [86.86528015, 20.78249931], [86.86528015, 20.78305626], [86.86555481, 20.78333282], [86.86555481, 20.78360939], [86.86638641, 20.78444481], [86.8666687, 20.78444481], [86.86722565, 20.78500175], [86.86750031, 20.78500175], [86.86805725, 20.78555489], [86.86833191, 20.78555489], [86.8686142, 20.78583145], [86.86888885, 20.78583145], [86.86916351, 20.78611374], [86.86972046, 20.78611183], [86.87000275, 20.7863903], [86.87082672, 20.7863903], [86.87111664, 20.78667068], [86.8713913, 20.78666687], [86.87194824, 20.78722382], [86.87304688, 20.78722], [86.87333679, 20.78750038], [86.87472534, 20.78750038], [86.87490845, 20.78768539], [86.875, 20.78778076], [86.87555695, 20.78778076], [86.8758316, 20.78806114], [86.87638855, 20.78805542], [86.87666321, 20.7883358], [86.87906647, 20.78833389], [86.88083649, 20.78833008], [86.88111115, 20.78861046], [86.88194275, 20.78861046]]], [[[86.94812775, 20.78457069], [86.94813538, 20.78423691], [86.94777679, 20.78390121], [86.94728088, 20.78390121], [86.94670868, 20.78396988], [86.94556427, 20.78430557], [86.94535065, 20.78437233], [86.94456482, 20.78437233], [86.94428253, 20.78423691], [86.94371033, 20.78430939], [86.94364166, 20.78443909], [86.94361115, 20.78500175], [86.94361115, 20.78528023], [86.94499969, 20.78667068], [86.94610596, 20.78667068], [86.94621277, 20.78619003], [86.94656372, 20.78565407], [86.94734955, 20.78531647], [86.94783783, 20.78498077], [86.94812775, 20.78457069]]], [[[86.79166412, 20.37361145], [86.79194641, 20.37333488], [86.79222107, 20.37333488], [86.79250336, 20.37305641], [86.79360962, 20.37305641], [86.79380035, 20.37324142], [86.79389191, 20.37333488], [86.79416656, 20.37333488], [86.79444122, 20.37305641], [86.79471588, 20.37306023], [86.79556274, 20.3722229], [86.79582977, 20.3722229], [86.79582977, 20.37166595], [86.79528046, 20.37111282], [86.79528046, 20.37000275], [86.7950058, 20.36965942], [86.79483795, 20.36925697], [86.79466248, 20.3687706], [86.79444122, 20.36832047], [86.79424286, 20.36791039], [86.79411316, 20.36748505], [86.79389954, 20.36713028], [86.79360962, 20.36667061], [86.79232788, 20.36538696], [86.79222107, 20.36527634], [86.79166412, 20.36527634], [86.79111481, 20.36583328], [86.79111481, 20.36611176], [86.7910614, 20.36624908], [86.79083252, 20.36681938], [86.7906189, 20.36735725], [86.79046631, 20.36792183], [86.79038239, 20.36857986], [86.79038239, 20.36929512], [86.79037476, 20.36997414], [86.79042816, 20.37067032], [86.79052734, 20.37136078], [86.79055786, 20.37205124], [86.79062653, 20.37269974], [86.79103088, 20.37322044], [86.79166412, 20.37361145]]], [[[86.79390717, 20.3799305], [86.7943573, 20.37966919], [86.79469299, 20.37936974], [86.79490662, 20.37907028], [86.79503632, 20.37874413], [86.79521179, 20.37842369], [86.79534912, 20.37804222], [86.79554749, 20.37770081], [86.79574585, 20.37741089], [86.7958374, 20.37722015], [86.79676819, 20.37661171], [86.79711914, 20.37607193], [86.79698181, 20.37505913], [86.79638672, 20.37471962], [86.79638672, 20.37444305], [86.7958374, 20.37445068], [86.79555511, 20.37416649], [86.79499817, 20.37471962], [86.79416656, 20.37556076], [86.79389191, 20.37556076], [86.79389191, 20.375], [86.79360962, 20.37471962], [86.79277802, 20.37471962], [86.79250336, 20.375], [86.79222107, 20.375], [86.79166412, 20.37555695], [86.79165649, 20.3758297], [86.79110718, 20.37639046], [86.79110718, 20.37778091], [86.79083252, 20.37805557], [86.79083252, 20.37833023], [86.79110718, 20.37861061], [86.79111481, 20.37888718], [86.79194641, 20.3797226], [86.79222107, 20.37972069], [86.79250336, 20.37999916], [86.79332733, 20.37999916], [86.79390717, 20.3799305]]], [[[86.79305267, 20.38417053], [86.79277802, 20.38389015], [86.79110718, 20.3855629], [86.79165649, 20.38611031], [86.79194641, 20.38611031], [86.79332733, 20.38750076], [86.79389191, 20.38750076], [86.79444122, 20.38694], [86.79444122, 20.38666725], [86.79416656, 20.38639069], [86.79389191, 20.38639069], [86.79389191, 20.38445282], [86.79389191, 20.38417053], [86.79305267, 20.38417053]]], [[[86.50166321, 20.17584038], [86.50195312, 20.17556], [86.50250244, 20.17556], [86.5027771, 20.17527962], [86.5036087, 20.17527962], [86.50417328, 20.17472076], [86.50444794, 20.17472267], [86.5047226, 20.1744442], [86.50499725, 20.1744442], [86.50527954, 20.17416573], [86.50583649, 20.17416954], [86.50611115, 20.17389107], [86.50723267, 20.17389107], [86.50805664, 20.17305946], [86.50805664, 20.17250061], [86.50694275, 20.17139053], [86.50666809, 20.17139053], [86.50554657, 20.17028046], [86.50499725, 20.17028046], [86.50499725, 20.17000008], [86.50388336, 20.16889191], [86.5027771, 20.16889191], [86.50250244, 20.16861153], [86.50236511, 20.16875076], [86.50222015, 20.16889191], [86.50166321, 20.16832924], [86.50027466, 20.16833305], [86.5, 20.16805649], [86.5, 20.16778183], [86.49994659, 20.16721916], [86.49978638, 20.16676712], [86.49951172, 20.16634941], [86.4992218, 20.16589737], [86.4989624, 20.16539001], [86.49861908, 20.16489983], [86.4982605, 20.1644268], [86.49793243, 20.16390991], [86.49773407, 20.1632309], [86.49746704, 20.16254997], [86.49710846, 20.16195869], [86.49656677, 20.1616993], [86.49594879, 20.1616993], [86.4956665, 20.1616993], [86.4953537, 20.16183662], [86.49488831, 20.16197395], [86.49440765, 20.16221237], [86.49395752, 20.16245079], [86.49363708, 20.16277122], [86.49346924, 20.16312027], [86.49358368, 20.16348457], [86.49371338, 20.16383934], [86.49388885, 20.16419029], [86.4940567, 20.16455078], [86.49423218, 20.16489029], [86.49446869, 20.16519928], [86.49462891, 20.1654644], [86.49440002, 20.16570282], [86.49394226, 20.16586685], [86.4938736, 20.16589355], [86.49352264, 20.16594124], [86.49311829, 20.16580009], [86.49272156, 20.16556931], [86.49228668, 20.16530991], [86.49185944, 20.16489029], [86.49156952, 20.1648922], [86.4913559, 20.16525078], [86.49111938, 20.16572762], [86.49091339, 20.16628075], [86.49085999, 20.16685677], [86.4908905, 20.16739464], [86.49079132, 20.16788101], [86.49054718, 20.16834259], [86.49025726, 20.16883278], [86.48993683, 20.16935921], [86.48960876, 20.16990089], [86.48963928, 20.17038727], [86.49008179, 20.17073059], [86.49066162, 20.17098045], [86.49117279, 20.17128944], [86.4916687, 20.17152023], [86.49222565, 20.1716671], [86.49250031, 20.17194366], [86.49277496, 20.17194366], [86.49305725, 20.17222214], [86.49333191, 20.17222023], [86.49388885, 20.17278099], [86.49388885, 20.17305565], [86.49416351, 20.17333221], [86.4944458, 20.17333221], [86.49500275, 20.17277718], [86.4952774, 20.17278099], [86.49555206, 20.17305946], [86.49583435, 20.17305565], [86.49610901, 20.17345238], [86.49645233, 20.1738205], [86.49675751, 20.17416954], [86.49700928, 20.17451096], [86.49717712, 20.17484283], [86.49732208, 20.17519951], [86.4974823, 20.17556763], [86.49767303, 20.17597198], [86.49798584, 20.17632675], [86.49835968, 20.176651], [86.49884033, 20.17681122], [86.49944305, 20.17661095], [86.50004578, 20.17637062], [86.50061798, 20.17613029], [86.50119019, 20.17588997], [86.50166321, 20.17584038]]], [[[86.43722534, 20.05944443], [86.43805695, 20.05861092], [86.43776703, 20.058321], [86.4375, 20.05833244], [86.43694305, 20.05777931], [86.4366684, 20.05778122], [86.43638611, 20.05750084], [86.43611145, 20.05750084], [86.43527985, 20.05667114], [86.43527985, 20.05611038], [86.43444824, 20.05528069], [86.43444824, 20.05500031], [86.43360901, 20.05417061], [86.43360901, 20.05278015], [86.43416595, 20.05221939], [86.43444824, 20.0522213], [86.4347229, 20.05194473], [86.4347229, 20.05166626], [86.43416595, 20.05111122], [86.43360901, 20.05111122], [86.43332672, 20.05083275], [86.43305206, 20.05111122], [86.43222046, 20.05111122], [86.43222046, 20.05221939], [86.4319458, 20.05251122], [86.4319458, 20.05444336], [86.43165588, 20.05471992], [86.43166351, 20.05527687], [86.43222046, 20.05583], [86.43222046, 20.05611038], [86.43250275, 20.05638885], [86.43250275, 20.05694389], [86.4338913, 20.05833244], [86.43416595, 20.058321], [86.43444824, 20.05861092], [86.43527985, 20.05861092], [86.43554688, 20.05888748], [86.43611145, 20.05888748], [86.43638611, 20.05916977], [86.4366684, 20.05916786], [86.43694305, 20.05944443], [86.43722534, 20.05944443]]], [[[86.49111176, 20.14972305], [86.49138641, 20.14944458], [86.4916687, 20.14944458], [86.4916687, 20.14805412], [86.49223328, 20.14750099], [86.49276733, 20.14750099], [86.49333191, 20.14805984], [86.49333191, 20.14861107], [86.49360657, 20.14890099], [86.49472046, 20.14890099], [86.49472046, 20.14805984], [86.49360657, 20.14694023], [86.4936142, 20.14666748], [86.49276733, 20.14583015], [86.49250031, 20.14583206], [86.49222565, 20.1455555], [86.49111176, 20.1455555], [86.4908371, 20.14583206], [86.49028015, 20.14583015], [86.48999786, 20.14611053], [86.48972321, 20.14611053], [86.48916626, 20.14666748], [86.48916626, 20.14694595], [86.48944092, 20.14722061], [86.48944092, 20.14805412], [86.48916626, 20.14833069], [86.48916626, 20.14861107], [86.48999786, 20.14944458], [86.49055481, 20.14944458], [86.4908371, 20.14972305], [86.49111176, 20.14972305]]], [[[86.55297089, 20.20527077], [86.5526123, 20.20527077], [86.5526886, 20.20581055], [86.55332947, 20.20641708], [86.554039, 20.20681953], [86.55503845, 20.20735931], [86.55532837, 20.20708847], [86.55539703, 20.20675468], [86.55511475, 20.20628166], [86.55432892, 20.20614624], [86.55368042, 20.20569038], [86.55297089, 20.20527077]]], [[[86.4263916, 20.03861046], [86.42610931, 20.03833008], [86.42555237, 20.03833389], [86.42472076, 20.03750038], [86.42472076, 20.03722191], [86.42500305, 20.03694534], [86.42500305, 20.0363903], [86.42444611, 20.03582954], [86.42444611, 20.03555489], [86.42305756, 20.03416634], [86.42279053, 20.03417015], [86.42279053, 20.03388977], [86.42166901, 20.03277969], [86.42166901, 20.03250122], [86.42138672, 20.03222084], [86.42111206, 20.03222275], [86.42082977, 20.03194427], [86.42056274, 20.03222084], [86.42056274, 20.03250122], [86.42028046, 20.03277969], [86.42055511, 20.03305626], [86.42055511, 20.03333282], [86.42082977, 20.03360748], [86.42082977, 20.03416634], [86.42111206, 20.03444481], [86.42111206, 20.03472137], [86.42138672, 20.03500175], [86.42138672, 20.03555489], [86.42166901, 20.03583336], [86.42166901, 20.03611183], [86.42138672, 20.0363903], [86.42138672, 20.03750992], [86.42166901, 20.03777695], [86.42166901, 20.03833008], [86.42360687, 20.04027939], [86.42360687, 20.04057121], [86.42415619, 20.04111099], [86.42415619, 20.04138947], [86.42444611, 20.04166412], [86.42444611, 20.0419445], [86.42472076, 20.04222107], [86.42472076, 20.04249954], [86.42583466, 20.04361153], [86.4263916, 20.04361153], [86.42722321, 20.04277611], [86.42722321, 20.04249954], [86.42749786, 20.04222107], [86.42749786, 20.04166412], [86.42722321, 20.04138947], [86.42722321, 20.04111099], [86.42694092, 20.04083061], [86.42694092, 20.04027748], [86.42666626, 20.04000092], [86.42666626, 20.03944016], [86.4263916, 20.0391674], [86.4263916, 20.03861046]]], [[[86.41085052, 20.01832962], [86.41027832, 20.01777649], [86.40999603, 20.0177803], [86.40972137, 20.01749992], [86.40944672, 20.01749992], [86.4088974, 20.01805115], [86.40888977, 20.01889038], [86.40916443, 20.01916885], [86.4091568, 20.01971817], [86.40944672, 20.02000046], [86.40944672, 20.0205555], [86.40972137, 20.02082825], [86.40972137, 20.02166748], [86.41004181, 20.02203941], [86.41027069, 20.02240944], [86.41049957, 20.02272987], [86.41083527, 20.02305603], [86.41085052, 20.02361107], [86.41110992, 20.02388954], [86.41110992, 20.02416611], [86.41139221, 20.02444458], [86.41139221, 20.02472115], [86.41166687, 20.02499962], [86.41166687, 20.02527809], [86.41222382, 20.02583313], [86.41249847, 20.02583313], [86.41293335, 20.02540016], [86.41305542, 20.02527809], [86.41278076, 20.02499962], [86.41278076, 20.02472115], [86.41249847, 20.02444458], [86.41249847, 20.02388954], [86.41221619, 20.02361107], [86.41221619, 20.0233326], [86.41166687, 20.02277756], [86.41166687, 20.02166939], [86.41221619, 20.02111053], [86.41221619, 20.02055931], [86.4119873, 20.02011108], [86.41178894, 20.01963806], [86.41158295, 20.01908684], [86.41118622, 20.01863289], [86.41085052, 20.01832962]]], [[[86.32110596, 19.98806], [86.32055664, 19.98806], [86.31999969, 19.98861122], [86.31999969, 19.98916435], [86.31972504, 19.98944473], [86.31972504, 19.99055481], [86.31887054, 19.99183273], [86.31879425, 19.9925766], [86.31861115, 19.99332047], [86.31861115, 19.99360847], [86.31833649, 19.99389076], [86.31833649, 19.99471855], [86.31861115, 19.99500084], [86.31944275, 19.99416924], [86.31944275, 19.99360847], [86.31973267, 19.99332809], [86.31972504, 19.99305534], [86.32073212, 19.9914093], [86.32094574, 19.9907341], [86.32137299, 19.98945808], [86.32150269, 19.98908043], [86.32144928, 19.98839569], [86.32110596, 19.98806]]], [[[86.32138824, 19.99888992], [86.32138824, 19.99777985], [86.3216629, 19.99749947], [86.3216629, 19.99666977], [86.32195282, 19.99638939], [86.32194519, 19.99500084], [86.3216629, 19.99472237], [86.3216629, 19.99389076], [86.32110596, 19.99332809], [86.3208313, 19.99332809], [86.32027435, 19.99389076], [86.31999969, 19.99443817], [86.31999969, 19.99500084], [86.31973267, 19.99526978], [86.31972504, 19.99555588], [86.31944275, 19.99583244], [86.31944275, 19.99611282], [86.31861115, 19.99694443], [86.31861115, 19.9972229], [86.31833649, 19.99749947], [86.31833649, 19.99777794], [86.31777954, 19.99833107], [86.31749725, 19.99833107], [86.3172226, 19.99861145], [86.3161087, 19.99860954], [86.31583405, 19.99888802], [86.31561279, 19.99916458], [86.31604004, 19.99943352], [86.31667328, 20.0], [86.31685638, 20.00038719], [86.31735229, 20.00065231], [86.31749725, 20.00083351], [86.31777954, 20.00111008], [86.31817627, 20.00119019], [86.31826782, 20.00172806], [86.31859589, 20.00213051], [86.31900787, 20.00233269], [86.31944275, 20.00226021], [86.31990051, 20.00214577], [86.32021332, 20.00188065], [86.32032776, 20.00148201], [86.32047272, 20.00112534], [86.32064056, 20.00078964], [86.32095337, 20.00043488], [86.32055664, 20.0], [86.32110596, 19.9991703], [86.32138824, 19.99888992]]], [[[86.33557129, 19.99082947], [86.33556366, 19.98981667], [86.33557129, 19.98954964], [86.33528137, 19.98888969], [86.33528137, 19.98861122], [86.33499908, 19.98833084], [86.3347168, 19.98833084], [86.33389282, 19.98917007], [86.33361053, 19.98916435], [86.33305359, 19.9897213], [86.33277893, 19.98971939], [86.33249664, 19.98999977], [86.33220673, 19.98999977], [86.33140564, 19.99081421], [86.33028412, 19.99238205], [86.32993317, 19.99394035], [86.32927704, 19.99570274], [86.32800293, 19.99698639], [86.3272171, 19.99860954], [86.3272171, 20.0], [86.32694244, 20.00027847], [86.32694244, 20.00111008], [86.32672882, 20.00132942], [86.3266983, 20.00140381], [86.32655334, 20.00179291], [86.3263855, 20.00229836], [86.32623291, 20.00284004], [86.32620239, 20.00337791], [86.32640076, 20.00381088], [86.32662201, 20.00419235], [86.32743835, 20.00574112], [86.32779694, 20.00682259], [86.32804871, 20.00797844], [86.32816315, 20.00851059], [86.32836914, 20.00905037], [86.32888794, 20.01000023], [86.32943726, 20.0105629], [86.330513, 20.00975037], [86.33065033, 20.00926971], [86.33095551, 20.00894928], [86.3312912, 20.00859833], [86.33333588, 20.00720978], [86.33333588, 20.00694466], [86.33455658, 20.00572395], [86.33472443, 20.00555611], [86.33472443, 20.00513077], [86.33472443, 20.00499725], [86.33499908, 20.00472069], [86.33499908, 20.00444412], [86.33528137, 20.00416565], [86.33528137, 20.00389099], [86.33557129, 20.00361061], [86.33555603, 20.00333595], [86.33583069, 20.00305557], [86.33557129, 20.00278091], [86.33561707, 20.00242996], [86.33583069, 20.00208092], [86.33603668, 20.00172997], [86.33613586, 20.00131989], [86.33625793, 20.0009594], [86.33634949, 20.00062561], [86.3364563, 20.00031853], [86.33666992, 20.0], [86.33657074, 19.99971962], [86.33686066, 19.99776077], [86.33677673, 19.99613953], [86.33642578, 19.99416924], [86.33637238, 19.99401093], [86.33555603, 19.9916687], [86.33557129, 19.99082947]]], [[[86.32213593, 20.01102448], [86.32194519, 20.01083374], [86.32194519, 20.01055527], [86.32138824, 20.01000023], [86.32111359, 20.01000023], [86.3208313, 20.01026917], [86.3208313, 20.0105629], [86.32027435, 20.01111031], [86.32027435, 20.01194382], [86.31999969, 20.01222229], [86.31999969, 20.01249123], [86.31999969, 20.01305962], [86.31972504, 20.01333427], [86.31973267, 20.01361084], [86.31944275, 20.01389122], [86.31944275, 20.01416588], [86.3188858, 20.01472092], [86.3188858, 20.01499939], [86.31861115, 20.01527977], [86.31861115, 20.01556015], [86.31777954, 20.01638794], [86.31777954, 20.01694679], [86.31749725, 20.01721954], [86.31749725, 20.01749992], [86.3172226, 20.01777649], [86.3172226, 20.01833344], [86.31694794, 20.01860809], [86.31694794, 20.01917076], [86.31672668, 20.01954079], [86.31661987, 20.0199604], [86.31643677, 20.02037048], [86.31638336, 20.02078056], [86.31639099, 20.02111053], [86.3161087, 20.02139091], [86.31582642, 20.02166939], [86.3152771, 20.02111053], [86.31472015, 20.02111053], [86.31414795, 20.02055931], [86.31361389, 20.0205555], [86.3133316, 20.02083397], [86.31305695, 20.02082825], [86.31276703, 20.02111053], [86.3125, 20.02111053], [86.31223297, 20.02139091], [86.31194305, 20.02139091], [86.31111145, 20.02222252], [86.31027985, 20.02139091], [86.30833435, 20.0233326], [86.30750275, 20.0233326], [86.30722046, 20.02361107], [86.3069458, 20.02361107], [86.30665588, 20.02388954], [86.30638885, 20.02388954], [86.30610657, 20.02416992], [86.30555725, 20.02416611], [86.30527496, 20.02444458], [86.30473328, 20.02444267], [86.3041687, 20.02499962], [86.30361176, 20.02499962], [86.3033371, 20.02528], [86.30223083, 20.02528], [86.30110931, 20.02639008], [86.30110931, 20.02667046], [86.30194092, 20.02750015], [86.30223083, 20.02750015], [86.30249786, 20.02778053], [86.3033371, 20.02777863], [86.30377197, 20.02792168], [86.30419922, 20.02806282], [86.30666351, 20.02777863], [86.3069458, 20.02778053], [86.30722046, 20.02750015], [86.3077774, 20.02750015], [86.30805206, 20.02778053], [86.30805206, 20.02806091], [86.30832672, 20.02833939], [86.30860901, 20.02833939], [86.3088913, 20.02861023], [86.30944824, 20.02861023], [86.31027985, 20.02944374], [86.30999756, 20.02972031], [86.30999756, 20.03000069], [86.31027985, 20.03028107], [86.31027985, 20.03055763], [86.3105545, 20.0308342], [86.31138611, 20.0308342], [86.3116684, 20.03055763], [86.31194305, 20.03055954], [86.31276703, 20.02972031], [86.31472015, 20.03166962], [86.31500244, 20.03166962], [86.31555176, 20.03111076], [86.31582642, 20.03111076], [86.3161087, 20.03083038], [86.31555176, 20.03027534], [86.31555176, 20.03000069], [86.31582642, 20.02972031], [86.31583405, 20.02861023], [86.3161087, 20.02833939], [86.3161087, 20.02806091], [86.31667328, 20.02750015], [86.31666565, 20.02722168], [86.31694794, 20.02694321], [86.31694794, 20.0261097], [86.3172226, 20.02583313], [86.3172226, 20.02555466], [86.31777954, 20.02499962], [86.31777954, 20.02472115], [86.31833649, 20.02416611], [86.31833649, 20.02388954], [86.31861115, 20.02361107], [86.3187561, 20.02339172], [86.31902313, 20.02324104], [86.31926727, 20.02301025], [86.31973267, 20.02277946], [86.31973267, 20.0225029], [86.31999969, 20.02220917], [86.32027435, 20.02222252], [86.32055664, 20.02194405], [86.3208313, 20.02194405], [86.32138824, 20.02139091], [86.3216629, 20.02139091], [86.32195282, 20.02111053], [86.32221985, 20.02111053], [86.32305908, 20.02028084], [86.32334137, 20.02028084], [86.32389069, 20.01971817], [86.32389069, 20.01888657], [86.32444763, 20.01832962], [86.32444763, 20.01805496], [86.32472229, 20.0177803], [86.32472229, 20.01721954], [86.32499695, 20.01694679], [86.32499695, 20.01666641], [86.32527924, 20.01639938], [86.32499695, 20.01610947], [86.32499695, 20.01555443], [86.32478333, 20.01503944], [86.32443237, 20.0147171], [86.32401276, 20.01441956], [86.32363129, 20.01400185], [86.32332611, 20.01348686], [86.32305908, 20.01278114], [86.32277679, 20.01250076], [86.32277679, 20.01194191], [86.32221985, 20.01138878], [86.32221985, 20.01111031], [86.32213593, 20.01102448]]], [[[86.3104248, 20.0162468], [86.3105545, 20.01611137], [86.31138611, 20.01611137], [86.31194305, 20.01555443], [86.3125, 20.01555443], [86.31305695, 20.01611137], [86.3133316, 20.01611137], [86.31361389, 20.0158329], [86.31416321, 20.0158329], [86.31472015, 20.01527786], [86.31472015, 20.01499939], [86.31500244, 20.01472092], [86.31500244, 20.01333427], [86.31472015, 20.01305962], [86.31472015, 20.01222038], [86.3144455, 20.01194382], [86.3144455, 20.01138878], [86.31472015, 20.01111031], [86.31472015, 20.01083183], [86.3152771, 20.0102787], [86.3152771, 20.01000023], [86.31555176, 20.00972176], [86.31555176, 20.00916672], [86.31582642, 20.00889015], [86.31582642, 20.00861168], [86.3152771, 20.00805473], [86.3133316, 20.00805473], [86.31305695, 20.00833321], [86.31305695, 20.00861168], [86.31276703, 20.00889015], [86.3133316, 20.00945282], [86.3133316, 20.01000023], [86.31194305, 20.01139069], [86.31140137, 20.01139069], [86.31111145, 20.01111031], [86.31083679, 20.01111031], [86.31054688, 20.01139069], [86.31027985, 20.01139069], [86.30999756, 20.01166725], [86.31027985, 20.01194382], [86.31027985, 20.01222038], [86.31054688, 20.01250076], [86.31054688, 20.01278114], [86.31111145, 20.01334], [86.31111145, 20.01389122], [86.31083679, 20.01416588], [86.31083679, 20.01444054], [86.31027985, 20.01499939], [86.31027985, 20.01527977], [86.30999756, 20.01555443], [86.31003571, 20.01615143], [86.31027985, 20.01639938], [86.3104248, 20.0162468]]], [[[81.75829315, 17.89336014], [81.72631836, 17.87409973], [81.70317078, 17.86112976], [81.69927216, 17.8697319], [81.69787598, 17.87553978], [81.68828583, 17.88479996], [81.6832428, 17.87948036], [81.67774963, 17.87758064], [81.66805267, 17.87842941], [81.66306305, 17.87693024], [81.6569519, 17.8728199], [81.65270233, 17.86819077], [81.64906311, 17.86246872], [81.64601898, 17.85626984], [81.64614105, 17.84687042], [81.64279175, 17.83928108], [81.6365509, 17.83628082], [81.63143921, 17.83044052], [81.62397766, 17.82442284], [81.61569977, 17.82201004], [81.61115265, 17.81536293], [81.59973907, 17.81544113], [81.59395599, 17.81911087], [81.57486725, 17.82734108], [81.56874084, 17.82788086], [81.56459045, 17.82569122], [81.55393982, 17.8163681], [81.52572632, 17.81087112], [81.51130676, 17.80656052], [81.49632263, 17.80647087], [81.48583984, 17.8026104], [81.48117828, 17.80286026], [81.47870636, 17.80470848], [81.47457123, 17.80999947], [81.47271729, 17.81789017], [81.47012329, 17.82318115], [81.46684265, 17.82492065], [81.45942688, 17.82471085], [81.43756866, 17.81529045], [81.43387604, 17.81575966], [81.42592621, 17.82127953], [81.41941833, 17.8205986], [81.41433716, 17.81643105], [81.41445923, 17.81011009], [81.40925598, 17.80483818], [81.40276337, 17.80532074], [81.39431, 17.80812073], [81.38497162, 17.80659294], [81.38310242, 17.81414032], [81.38304901, 17.81695175], [81.38300323, 17.82057953], [81.38378906, 17.82348824], [81.38442993, 17.82579041], [81.39334106, 17.83582115], [81.39736938, 17.84364128], [81.39805603, 17.84678078], [81.38987732, 17.85943031], [81.38954926, 17.8621006], [81.39050293, 17.87429047], [81.39382935, 17.88513947], [81.39585114, 17.88755989], [81.39901733, 17.88849068], [81.40376282, 17.88859177], [81.41166687, 17.88539124], [81.42312622, 17.87742043], [81.4302063, 17.87467957], [81.43450928, 17.87490082], [81.43595886, 17.87544823], [81.43725586, 17.87593842], [81.44026184, 17.87914085], [81.44274902, 17.88516045], [81.4437027, 17.89323044], [81.44827271, 17.90302086], [81.44818115, 17.9050808], [81.44806671, 17.90714073], [81.44621277, 17.91028023], [81.44592285, 17.91717911], [81.44445801, 17.92210007], [81.44510651, 17.92546844], [81.44523621, 17.92617035], [81.45479584, 17.94655991], [81.46695709, 17.95490074], [81.47325897, 17.96532059], [81.47567749, 17.96708107], [81.47644043, 17.96763039], [81.47731018, 17.97002029], [81.47688293, 17.97265053], [81.47666931, 17.97389984], [81.47307587, 17.98328972], [81.47451019, 17.98870277], [81.47767639, 17.9935112], [81.47894287, 18.00370026], [81.47750092, 18.01999283], [81.47389221, 18.02851105], [81.47751617, 18.03872108], [81.48149872, 18.04992294], [81.49465942, 18.05800056], [81.49488068, 18.06266022], [81.49516296, 18.06868935], [81.49600983, 18.07069969], [81.49684906, 18.07271194], [81.50865936, 18.09241104], [81.51072693, 18.10387993], [81.51187897, 18.1292305], [81.51580048, 18.13993073], [81.52173615, 18.14830971], [81.5226059, 18.15727043], [81.51487732, 18.17217064], [81.50892639, 18.17407036], [81.50524902, 18.17778969], [81.504776, 18.18381119], [81.50878906, 18.1925106], [81.51113892, 18.20194054], [81.52287292, 18.22737122], [81.52577209, 18.23652077], [81.52368164, 18.24865913], [81.52796173, 18.25908089], [81.53945923, 18.26210976], [81.54807281, 18.26213074], [81.56759644, 18.27321053], [81.57401276, 18.28116989], [81.58178711, 18.28816032], [81.58624268, 18.29215813], [81.59050751, 18.29333115], [81.59203339, 18.29747963], [81.59340668, 18.30128098], [81.59687042, 18.30211067], [81.60611725, 18.2994194], [81.61588287, 18.30084038], [81.6213913, 18.30372238], [81.62761688, 18.30487061], [81.63214111, 18.3080101], [81.64675903, 18.31150055], [81.65866852, 18.3110981], [81.6603775, 18.31575966], [81.65245819, 18.32478905], [81.64937592, 18.33057976], [81.64916992, 18.33100128], [81.65280914, 18.33667946], [81.65809631, 18.33929062], [81.68078613, 18.34103012], [81.69924164, 18.34357071], [81.71750641, 18.34320068], [81.73707581, 18.34422112], [81.74491119, 18.34535027], [81.74607849, 18.35174179], [81.74675751, 18.35550117], [81.75554657, 18.38624954], [81.76036835, 18.39982986], [81.76210022, 18.4113102], [81.76738739, 18.41477013], [81.79756927, 18.43976021], [81.82892609, 18.46895027], [81.84430695, 18.48154068], [81.84958649, 18.48904991], [81.84896088, 18.50060081], [81.85302734, 18.50732994], [81.85794067, 18.51305962], [81.86296082, 18.51727295], [81.86805725, 18.51748276], [81.8707962, 18.51758957], [81.87361908, 18.51993942], [81.87538147, 18.5214119], [81.87867737, 18.52627945], [81.88259888, 18.52918053], [81.89607239, 18.52843094], [81.8968277, 18.52839279], [81.90029144, 18.53251839], [81.89865112, 18.53615952], [81.89794159, 18.53773117], [81.89763641, 18.54271126], [81.89975739, 18.54904175], [81.90080261, 18.55717087], [81.90859985, 18.56422806], [81.91316986, 18.56118965], [81.91639709, 18.559021], [81.92019653, 18.55730057], [81.92545319, 18.55768013], [81.92984772, 18.55800056], [81.93624115, 18.55770111], [81.94352722, 18.55541992], [81.94625854, 18.55841064], [81.94690704, 18.5591507], [81.94534302, 18.56245041], [81.943573, 18.56615829], [81.94576263, 18.57491112], [81.95452881, 18.58670998], [81.94888306, 18.58954048], [81.93847656, 18.59179115], [81.9330368, 18.59465027], [81.92971802, 18.59638977], [81.92623138, 18.60322952], [81.91303253, 18.6129303], [81.89993286, 18.61960983], [81.8883667, 18.62099075], [81.88729095, 18.62438965], [81.88780212, 18.63162994], [81.88820648, 18.6373806], [81.88931274, 18.64112854], [81.89000702, 18.64347076], [81.88537598, 18.65032959], [81.89317322, 18.65388107], [81.89483643, 18.65196037], [81.9048996, 18.64639282], [81.90914154, 18.6409893], [81.91552734, 18.63582039], [81.93557739, 18.63289833], [81.9474411, 18.62882042], [81.94832611, 18.63278961], [81.94608307, 18.64048958], [81.94592285, 18.64637947], [81.9473877, 18.65571022], [81.95163727, 18.66098022], [81.96063232, 18.66772079], [81.95507813, 18.68022919], [81.95716095, 18.68341064], [81.96386719, 18.68779945], [81.96768188, 18.69061279], [81.97603607, 18.69514847], [81.99186707, 18.69769096], [81.99772644, 18.7004509], [82.00998688, 18.7105999], [82.01561737, 18.71353149], [82.03373718, 18.71879959], [82.03949738, 18.71704102], [82.04943085, 18.7175808], [82.05175781, 18.71183968], [82.05799103, 18.71251106], [82.05912781, 18.71778107], [82.06128693, 18.71800995], [82.06739044, 18.71710968], [82.07398224, 18.7130909], [82.07858276, 18.71208191], [82.08048248, 18.72274017], [82.0848999, 18.73269081], [82.08674622, 18.74693108], [82.08141327, 18.75587082], [82.08470917, 18.75839996], [82.09129333, 18.75617981], [82.10572815, 18.75844955], [82.11392212, 18.76066017], [82.12906647, 18.75765038], [82.1281662, 18.76432037], [82.13066101, 18.77009964], [82.13897705, 18.76954079], [82.14547729, 18.77327919], [82.15001678, 18.77869987], [82.15170288, 18.78380013], [82.15921783, 18.78811073], [82.16114807, 18.79096031], [82.15891266, 18.79507065], [82.15429688, 18.7963028], [82.15611267, 18.79994011], [82.16101074, 18.80356979], [82.16184235, 18.80496025], [82.15867615, 18.80920029], [82.15830994, 18.81147003], [82.16493988, 18.83020973], [82.16175079, 18.83786011], [82.16242218, 18.8451004], [82.15802765, 18.85197067], [82.16126251, 18.8577404], [82.16279602, 18.86551094], [82.15820313, 18.86945915], [82.16310883, 18.87193108], [82.17041016, 18.87757111], [82.17076874, 18.89159012], [82.17272949, 18.89528847], [82.17714691, 18.89690018], [82.18538666, 18.89698029], [82.1987381, 18.90554047], [82.21378326, 18.91213989], [82.22486115, 18.90924835], [82.22767639, 18.9066906], [82.23121643, 18.90522003], [82.23429108, 18.90526962], [82.23956299, 18.91045952], [82.22666168, 18.99398041], [82.22506714, 19.01459122], [82.22248077, 19.02111053], [82.1940918, 19.06022072], [82.19683075, 19.06786919], [82.20855713, 19.07852173], [82.21122742, 19.08575821], [82.21211243, 19.09054947], [82.21058655, 19.09225082], [82.19986725, 19.09217834], [82.1985321, 19.09416962], [82.19948578, 19.09982109], [82.19689941, 19.10115051], [82.20149994, 19.11576271], [82.19975281, 19.11746025], [82.19101715, 19.11631012], [82.17623901, 19.12506104], [82.16982269, 19.11285973], [82.16480255, 19.11469078], [82.15978241, 19.1264801], [82.16117096, 19.12975121], [82.16655731, 19.13214111], [82.1681366, 19.13384056], [82.16471863, 19.13947105], [82.1658783, 19.14314079], [82.16990662, 19.14364052], [82.17198944, 19.14249992], [82.17478943, 19.14523125], [82.17238617, 19.14764977], [82.16500092, 19.15044975], [82.16413879, 19.15463829], [82.16760254, 19.15687943], [82.1714859, 19.15390968], [82.17471313, 19.15275002], [82.17684174, 19.15497971], [82.17878723, 19.15885925], [82.17823792, 19.16147995], [82.17298126, 19.16476059], [82.17112732, 19.16827011], [82.17516327, 19.16963959], [82.17459869, 19.17358017], [82.16940308, 19.17670059], [82.17339325, 19.18431091], [82.16478729, 19.18732071], [82.15804291, 19.19317818], [82.15570831, 19.19652939], [82.16117859, 19.20838928], [82.15376282, 19.21577835], [82.15164948, 19.22356987], [82.15196228, 19.23890114], [82.15099335, 19.25842285], [82.15172577, 19.26546288], [82.15487671, 19.27477837], [82.15836334, 19.28148079], [82.16853333, 19.29066086], [82.1700058, 19.29572105], [82.17008972, 19.3024807], [82.17368317, 19.31630135], [82.1831665, 19.31970024], [82.18025208, 19.33220291], [82.17749023, 19.33237076], [82.17320251, 19.33407974], [82.16895294, 19.33723068], [82.16314697, 19.33780289], [82.15722656, 19.34284019], [82.14955139, 19.34437943], [82.14234924, 19.34817123], [82.14225769, 19.35511017], [82.14083099, 19.3619194], [82.14118195, 19.36578178], [82.14456177, 19.37011909], [82.15080261, 19.37034035], [82.16636658, 19.36593056], [82.17398071, 19.37693977], [82.17777252, 19.40557289], [82.18348694, 19.41246033], [82.18305969, 19.41761017], [82.17925262, 19.41913986], [82.17045593, 19.42949104], [82.1672287, 19.42984962], [82.16069031, 19.42951965], [82.13410187, 19.42482758], [82.11930847, 19.4239006], [82.10679626, 19.44307137], [82.10716248, 19.45261192], [82.09689331, 19.46108055], [82.09986877, 19.46606064], [82.10182953, 19.47365952], [82.09902954, 19.48957062], [82.09101868, 19.49405861], [82.09207916, 19.50984001], [82.08822632, 19.51044273], [82.07084656, 19.51592064], [82.0671463, 19.51102066], [82.05979156, 19.50364113], [82.02239227, 19.50180244], [82.0302124, 19.51420975], [82.03246307, 19.52129173], [82.04102325, 19.52570152], [82.04257202, 19.53156853], [82.04612732, 19.5386219], [82.0430069, 19.5444603], [82.04042053, 19.55220985], [82.0426178, 19.55800056], [82.04413605, 19.56479836], [82.04323578, 19.56767082], [82.0422287, 19.57092094], [82.03779602, 19.5771904], [82.03489685, 19.58327293], [82.03395844, 19.59069061], [82.03727722, 19.59791946], [82.0450592, 19.60165024], [82.04471588, 19.61079025], [82.04847717, 19.61581039], [82.05134583, 19.62444115], [82.05082703, 19.63162041], [82.04728699, 19.63828087], [82.04638672, 19.64402962], [82.04830933, 19.64937019], [82.04603577, 19.65359116], [82.04766846, 19.66268921], [82.04677582, 19.66937065], [82.03848267, 19.69277954], [82.03756714, 19.70391083], [82.04160309, 19.70828819], [82.0437088, 19.71391106], [82.04255676, 19.72313118], [82.04425812, 19.72912979], [82.04400635, 19.73768997], [82.04659271, 19.74302101], [82.05719757, 19.75341034], [82.05541992, 19.7610302], [82.05898285, 19.77507019], [82.05938721, 19.77903938], [82.05982971, 19.78309822], [82.05219269, 19.79134178], [82.04827881, 19.78841019], [82.04444122, 19.78924942], [82.04107666, 19.79219055], [82.03494263, 19.79265976], [82.02906036, 19.79219055], [82.02419281, 19.79297829], [82.00818634, 19.79656982], [82.00305176, 19.79851913], [82.00289154, 19.7985096], [81.99932098, 19.79830933], [81.99237061, 19.79442978], [81.98741913, 19.79174042], [81.98014832, 19.79578018], [81.97020721, 19.81274033], [81.9614563, 19.82443237], [81.95741272, 19.83600998], [81.96037292, 19.85473824], [81.93942261, 19.86484146], [81.92447662, 19.86872292], [81.89805603, 19.87851906], [81.86924744, 19.89281082], [81.85840607, 19.89954948], [81.84963226, 19.90805054], [81.84580994, 19.91486168], [81.84567261, 19.92295265], [81.84883118, 19.938591], [81.84651184, 19.94144058], [81.83895111, 19.94549942], [81.83730316, 19.95008087], [81.84026337, 19.95513916], [81.84689331, 19.9703598], [81.85031891, 19.98260117], [81.85101318, 19.98975182], [81.85161591, 19.99605942], [81.85205078, 19.99715996], [81.85546112, 20.00352097], [81.85762024, 20.00908089], [81.85891724, 20.01637077], [81.86016846, 20.02336121], [81.86458588, 20.02864075], [81.86548615, 20.03388023], [81.86611176, 20.03518105], [81.866539, 20.03603935], [81.87375641, 20.04618073], [81.8762207, 20.04438972], [81.880867, 20.04241943], [81.88504028, 20.04171944], [81.8894577, 20.04327011], [81.8941803, 20.04824829], [81.90142822, 20.05912018], [81.91027069, 20.06705093], [81.91542816, 20.07382965], [81.92188263, 20.08694839], [81.92563629, 20.09011841], [81.93392944, 20.09930992], [81.93696594, 20.10115051], [81.94135284, 20.10225105], [81.94420624, 20.10160255], [81.95477295, 20.09148026], [81.96264648, 20.08556938], [81.97357178, 20.07561111], [81.97849274, 20.06917953], [81.98329926, 20.05702972], [81.98660278, 20.05207253], [81.9927063, 20.04782104], [81.99555206, 20.04753113], [82.00102997, 20.04926109], [82.00689697, 20.04733086], [82.00995636, 20.0447998], [82.01270294, 20.04103088], [82.014328, 20.0364399], [82.01449585, 20.03025055], [82.01551819, 20.02683067], [82.01478577, 20.01951027], [82.02440643, 20.01004028], [82.03070068, 20.01503944], [82.03156281, 20.01666069], [82.03102875, 20.02288055], [82.03875732, 20.02891922], [82.04897308, 20.03524017], [82.05789948, 20.04986954], [82.06980133, 20.04804039], [82.07630157, 20.04404068], [82.08304596, 20.03273964], [82.08943939, 20.03454971], [82.09319305, 20.03267288], [82.0952301, 20.02680016], [82.09773254, 20.02337074], [82.10273743, 20.02082825], [82.10547638, 20.01781273], [82.1160965, 20.01040077], [82.12142181, 20.00979042], [82.12841034, 20.01258087], [82.13169861, 20.01268959], [82.14834595, 20.00300026], [82.15557861, 20.0023098], [82.16583252, 19.99814987], [82.16607666, 19.99584007], [82.17578125, 19.98553085], [82.1784668, 19.97808266], [82.18418121, 19.98116112], [82.19381714, 19.98130989], [82.2042923, 19.98033905], [82.21058655, 19.99081039], [82.21425629, 19.99334145], [82.2194519, 19.9934597], [82.22438049, 19.99587059], [82.23062897, 19.99808121], [82.23335266, 19.99587059], [82.25271606, 19.97647858], [82.25863647, 19.97174072], [82.26169586, 19.97155952], [82.26864624, 19.95792961], [82.26946259, 19.94524956], [82.28333282, 19.91806984], [82.29532623, 19.89895821], [82.29823303, 19.883461], [82.31794739, 19.85915947], [82.32132721, 19.85191917], [82.32511902, 19.84049034], [82.32675171, 19.83833122], [82.33944702, 19.82996178], [82.35624695, 19.84662056], [82.35736084, 19.84950066], [82.35607147, 19.85513115], [82.35845184, 19.85688019], [82.36804962, 19.85448074], [82.37725067, 19.86296844], [82.37798309, 19.86869049], [82.38617706, 19.87684059], [82.38881683, 19.88175964], [82.39700317, 19.88454056], [82.40040588, 19.8888092], [82.41043854, 19.89340019], [82.41388702, 19.89652061], [82.42090607, 19.89833069], [82.42492676, 19.89760971], [82.43225861, 19.89948082], [82.43949127, 19.90291977], [82.44239044, 19.90298271], [82.45835114, 19.89464951], [82.46556091, 19.89657974], [82.46808624, 19.89948082], [82.47569275, 19.90052986], [82.48692322, 19.89653015], [82.49423981, 19.89735985], [82.497612, 19.8950882], [82.49848175, 19.88516998], [82.5022583, 19.88244057], [82.51241302, 19.88412094], [82.51795959, 19.87631035], [82.52305603, 19.87278938], [82.5298996, 19.88212967], [82.53636169, 19.87689018], [82.54428864, 19.86903], [82.54721832, 19.87330055], [82.5508728, 19.8745594], [82.55488586, 19.86950111], [82.56674957, 19.87172127], [82.57758331, 19.86343956], [82.59076691, 19.86621857], [82.59349823, 19.8645401], [82.59738159, 19.86046982], [82.59146881, 19.85243034], [82.58982086, 19.8481884], [82.58573151, 19.8463707], [82.58149719, 19.84049034], [82.58349609, 19.83832169], [82.57894135, 19.83662987], [82.57419586, 19.83197975], [82.57182312, 19.82780838], [82.57126617, 19.82238007], [82.57382965, 19.82370949], [82.57183838, 19.80760956], [82.57303619, 19.80555916], [82.57157898, 19.80200958], [82.57927704, 19.7972126], [82.57779694, 19.79232979], [82.57781219, 19.78780937], [82.5792923, 19.78466034], [82.57791138, 19.77959061], [82.57847595, 19.77581978], [82.5812912, 19.77269173], [82.58506012, 19.7710495], [82.59513855, 19.77306938], [82.59828186, 19.7751503], [82.59900665, 19.78127289], [82.60327911, 19.78355026], [82.60813141, 19.78512955], [82.61886597, 19.78610039], [82.62296295, 19.78931046], [82.62734222, 19.79615021], [82.62890625, 19.80376053], [82.6362915, 19.80799294], [82.64179993, 19.8137207], [82.64573669, 19.82537079], [82.65410614, 19.8255291], [82.66001892, 19.82372093], [82.66913605, 19.82520294], [82.68331909, 19.82372093], [82.6905365, 19.82575989], [82.69844055, 19.82686043], [82.70271301, 19.83103943], [82.70588684, 19.8380909], [82.70471191, 19.84460068], [82.71100616, 19.84856033], [82.71385956, 19.86209106], [82.71750641, 19.87080956], [82.70935059, 19.870121], [82.70636749, 19.87851906], [82.70269012, 19.88584137], [82.70053101, 19.89328957], [82.70147705, 19.90073013], [82.70040894, 19.90661049], [82.70587921, 19.91123009], [82.70426178, 19.91833115], [82.70632172, 19.92685127], [82.70649719, 19.93353081], [82.71061707, 19.93947029], [82.71156311, 19.9444809], [82.70944977, 19.94667053], [82.71092987, 19.98326111], [82.70748901, 19.99021912], [82.70063019, 19.99287033], [82.69802094, 19.99273109], [82.69230652, 19.9924202], [82.68644714, 19.99463081], [82.68102264, 19.99545097], [82.65048218, 19.99940109], [82.64189911, 19.99790955], [82.63625336, 19.99829102], [82.63175964, 20.00008965], [82.62358093, 19.99764061], [82.62088776, 19.99555969], [82.61875916, 19.99156952], [82.61438751, 19.9869709], [82.59836578, 19.98563957], [82.58235931, 19.98994064], [82.57872009, 19.9956398], [82.57594299, 19.99895287], [82.54361725, 20.01213074], [82.53198242, 20.01222992], [82.52424622, 20.01044083], [82.5021286, 20.01353073], [82.49006653, 20.01857185], [82.48159027, 20.02456093], [82.47590637, 20.03005028], [82.47077179, 20.03202057], [82.46409607, 20.03154945], [82.45832825, 20.0338707], [82.45149994, 20.03526115], [82.44142914, 20.03535271], [82.43192291, 20.03897095], [82.4247818, 20.04354095], [82.41713715, 20.04534912], [82.40618896, 20.04631042], [82.39576721, 20.04899979], [82.39086151, 20.05958939], [82.39034271, 20.06423187], [82.39260101, 20.07331085], [82.39466858, 20.08916092], [82.39264679, 20.10824966], [82.39073944, 20.11905098], [82.38775635, 20.12693977], [82.38658142, 20.13338089], [82.38228607, 20.13817024], [82.37892914, 20.14463043], [82.38719177, 20.14885139], [82.38330078, 20.16045952], [82.39048767, 20.16731262], [82.40574646, 20.17898941], [82.40763092, 20.19409943], [82.41359711, 20.20227051], [82.41308594, 20.20795059], [82.41365051, 20.21327972], [82.41277313, 20.21744919], [82.40818787, 20.22063065], [82.40727997, 20.22764015], [82.40432739, 20.23960114], [82.40837097, 20.24166107], [82.41407776, 20.24155045], [82.40537262, 20.25587273], [82.4050827, 20.26353073], [82.412323, 20.26990128], [82.42082214, 20.27260017], [82.42804718, 20.27861023], [82.42922974, 20.2829628], [82.4283371, 20.28986168], [82.42395782, 20.29650116], [82.42243958, 20.30965996], [82.41629791, 20.31695938], [82.40717316, 20.32207108], [82.40045929, 20.32467079], [82.40029907, 20.32925034], [82.39878845, 20.33165169], [82.39377594, 20.3355217], [82.39441681, 20.34013748], [82.39795685, 20.34677124], [82.39794159, 20.35585976], [82.40251923, 20.36133003], [82.40307617, 20.36526108], [82.41040802, 20.37720108], [82.41060638, 20.38247108], [82.41274261, 20.38824272], [82.40989685, 20.40267944], [82.41768646, 20.4056282], [82.42428589, 20.41015053], [82.42295837, 20.41833115], [82.4291687, 20.42575264], [82.427742, 20.43206978], [82.42565155, 20.43631935], [82.41771698, 20.43830109], [82.41940308, 20.44557953], [82.41938782, 20.45728111], [82.41609955, 20.4661808], [82.41007996, 20.47330093], [82.40640259, 20.46614075], [82.39731598, 20.45191956], [82.38809204, 20.45251083], [82.39006805, 20.45939064], [82.38960266, 20.46536064], [82.38513947, 20.4704895], [82.38613129, 20.47552109], [82.38375092, 20.48266029], [82.38123322, 20.50180054], [82.38131714, 20.50777054], [82.38049316, 20.50984955], [82.36994934, 20.51394081], [82.35851288, 20.51623917], [82.34879303, 20.52293015], [82.34224701, 20.53769112], [82.33609009, 20.54323959], [82.32775879, 20.54927063], [82.32401276, 20.55388069], [82.32446289, 20.55664825], [82.32637787, 20.55657959], [82.3274765, 20.55789757], [82.32782745, 20.56196022], [82.33235168, 20.56227112], [82.33715057, 20.56517982], [82.34063721, 20.56973267], [82.3425293, 20.57522011], [82.33766937, 20.58493042], [82.33837128, 20.59082985], [82.33867645, 20.5943203], [82.3454895, 20.59790039], [82.34799957, 20.6016407], [82.35582733, 20.60349083], [82.35785675, 20.60921097], [82.35665894, 20.61136055], [82.35817719, 20.61516953], [82.36633301, 20.6202507], [82.36823273, 20.62405968], [82.36754608, 20.62957001], [82.36380005, 20.6395607], [82.36225128, 20.65047073], [82.36580658, 20.66114998], [82.36522675, 20.66376114], [82.36068726, 20.67191124], [82.35428619, 20.6750412], [82.35131836, 20.67807007], [82.3455658, 20.69491005], [82.34329987, 20.69885254], [82.34426117, 20.7095108], [82.34699249, 20.71423912], [82.33940887, 20.72583008], [82.34586334, 20.72871971], [82.3404007, 20.74671936], [82.33512878, 20.75851822], [82.33692932, 20.77930069], [82.33879089, 20.79017067], [82.33567047, 20.79737282], [82.33310699, 20.8196907], [82.3355484, 20.82783127], [82.33403778, 20.84058952], [82.33687592, 20.8492527], [82.34121704, 20.86806107], [82.34661865, 20.88384819], [82.35917664, 20.8827095], [82.35617828, 20.87635994], [82.35591888, 20.8699398], [82.35903931, 20.86654091], [82.36801147, 20.8640995], [82.37667084, 20.86692047], [82.38279724, 20.8699398], [82.40141296, 20.86243057], [82.40246582, 20.85795975], [82.40225983, 20.85328102], [82.40727997, 20.84802055], [82.40737152, 20.84349823], [82.40563202, 20.8372097], [82.4134903, 20.82956123], [82.41552734, 20.82646942], [82.42294312, 20.82600021], [82.43650055, 20.82953072], [82.43939209, 20.8271904], [82.44108582, 20.82376289], [82.44465637, 20.82406998], [82.44837189, 20.82217979], [82.45350647, 20.8212204], [82.45905304, 20.82384109], [82.46246338, 20.8275795], [82.46231079, 20.83035088], [82.45983124, 20.83564949], [82.46338654, 20.83967018], [82.46826172, 20.84263039], [82.47762299, 20.84671974], [82.48192596, 20.85531044], [82.48136902, 20.86145973], [82.48452759, 20.87289047], [82.48467255, 20.87955093], [82.48313904, 20.8996582], [82.485672, 20.90351105], [82.49363708, 20.90934944], [82.50309753, 20.91389084], [82.51344299, 20.91721916], [82.51924133, 20.92469025], [82.52625275, 20.92770958], [82.53585052, 20.92952156], [82.54573822, 20.93494034], [82.55294037, 20.94148064], [82.56651306, 20.96700096], [82.57813263, 20.97894096], [82.58207703, 20.98677826], [82.59514618, 20.99712944], [82.60444641, 21.00587273], [82.60772705, 21.01216125], [82.60861969, 21.01819992], [82.62230682, 21.0365696], [82.62003326, 21.04439926], [82.60912323, 21.06392097], [82.60938263, 21.07119751], [82.61524963, 21.07517052], [82.62194061, 21.07520103], [82.62587738, 21.07682037], [82.63183594, 21.08695984], [82.63536072, 21.09198952], [82.64299774, 21.09776115], [82.64502716, 21.10187912], [82.63833618, 21.10647011], [82.63710022, 21.11161995], [82.63955688, 21.11700058], [82.64531708, 21.12066841], [82.64775848, 21.12496185], [82.6446228, 21.12881088], [82.6383667, 21.13161278], [82.63408661, 21.13635063], [82.63279724, 21.14266014], [82.63594055, 21.1494503], [82.64582825, 21.15171051], [82.66204834, 21.15075111], [82.68453217, 21.15806007], [82.6919632, 21.15685081], [82.69403839, 21.15280151], [82.70053864, 21.15326118], [82.70553589, 21.15489006], [82.7114563, 21.15576935], [82.72115326, 21.15894127], [82.72724152, 21.15919113], [82.73535156, 21.15787125], [82.75229645, 21.15974045], [82.75752258, 21.1585598], [82.78208923, 21.14101982], [82.78884888, 21.13927269], [82.79176331, 21.14511108], [82.79559326, 21.1505909], [82.80381012, 21.15307045], [82.80684662, 21.15664101], [82.81247711, 21.1585598], [82.83999634, 21.1633606], [82.84712982, 21.16268158], [82.84677124, 21.1581707], [82.85402679, 21.15700912], [82.85949707, 21.15730286], [82.86367035, 21.15538025], [82.86882782, 21.15974998], [82.87285614, 21.1510582], [82.87922668, 21.14908981], [82.88741302, 21.15377235], [82.8951416, 21.15982056], [82.90231323, 21.16296959], [82.90795898, 21.1602726], [82.91442108, 21.16064072], [82.92192841, 21.15821075], [82.9280014, 21.16103172], [82.93739319, 21.16114807], [82.94232941, 21.16304016], [82.9489975, 21.16977119], [82.95606995, 21.17548943], [82.95964813, 21.17385101], [82.96363831, 21.16167068], [82.96514893, 21.15575981], [82.97161102, 21.15631104], [82.97992706, 21.15746117], [82.98342133, 21.14826965], [82.99297333, 21.15427971], [82.99912262, 21.14813995], [83.00554657, 21.14583015], [83.00772858, 21.14653015], [83.01048279, 21.14537048], [83.01589203, 21.13972092], [83.01862335, 21.13817978], [83.02954102, 21.13132286], [83.02908325, 21.12602997], [83.03275299, 21.12436295], [83.03643036, 21.1212101], [83.04058075, 21.11893082], [83.04682922, 21.12021065], [83.05139923, 21.11717033], [83.05976105, 21.11591148], [83.06436157, 21.11110115], [83.07144165, 21.10807037], [83.08156586, 21.1067009], [83.08870697, 21.10745049], [83.09208679, 21.10597038], [83.0951767, 21.1043129], [83.10827637, 21.10770035], [83.11984253, 21.10106087], [83.13400269, 21.10523033], [83.13771057, 21.1098175], [83.14875031, 21.11987114], [83.15339661, 21.12577057], [83.16139221, 21.13145065], [83.16986847, 21.13151932], [83.17662048, 21.13074112], [83.18297577, 21.13204956], [83.19010162, 21.13552856], [83.19274902, 21.13944054], [83.19373322, 21.1576519], [83.1993866, 21.16197014], [83.20007324, 21.16889954], [83.19953156, 21.17404938], [83.20201874, 21.17743111], [83.20520782, 21.18404007], [83.2100296, 21.1880703], [83.21121216, 21.19118118], [83.20757294, 21.20139122], [83.21536255, 21.21549034], [83.21438599, 21.22058105], [83.21520996, 21.22369194], [83.21906281, 21.22371101], [83.21469879, 21.24041939], [83.21414185, 21.25086975], [83.21835327, 21.26012039], [83.22489929, 21.26696968], [83.23187256, 21.26534081], [83.2424469, 21.27643967], [83.24836731, 21.27730179], [83.25730133, 21.27555084], [83.26275635, 21.27260971], [83.26767731, 21.26857758], [83.2713089, 21.28050041], [83.27455902, 21.28567123], [83.27480316, 21.29057121], [83.27268219, 21.29613113], [83.25879669, 21.30212975], [83.25409698, 21.31237984], [83.25421143, 21.31958961], [83.26085663, 21.32674026], [83.25578308, 21.32932281], [83.25495911, 21.33192062], [83.26064301, 21.33717918], [83.26609039, 21.34543037], [83.27078247, 21.35923958], [83.26951599, 21.36721039], [83.27001953, 21.37503815], [83.27614594, 21.37592125], [83.2813797, 21.37514114], [83.2872467, 21.3714695], [83.30164337, 21.36783981], [83.3095932, 21.36456108], [83.31933594, 21.35814285], [83.33460236, 21.35579109], [83.37481689, 21.3399601], [83.37663269, 21.34329987], [83.3879776, 21.33893967], [83.39385986, 21.34208107], [83.40265656, 21.34843063], [83.40444946, 21.35511971], [83.4018631, 21.3583107], [83.39415741, 21.3611412], [83.39317322, 21.36519051], [83.3963089, 21.36927032], [83.39655304, 21.37227058], [83.39308929, 21.38321114], [83.39376068, 21.39944267], [83.38967133, 21.40166283], [83.38140869, 21.40957832], [83.37393951, 21.42222023], [83.37137604, 21.42835999], [83.37014008, 21.43610001], [83.36579132, 21.43984032], [83.36094666, 21.44218063], [83.35028839, 21.44398117], [83.34732819, 21.45514107], [83.34335327, 21.46488953], [83.34197998, 21.47413063], [83.34205627, 21.48533058], [83.33561707, 21.49191093], [83.33463287, 21.49555016], [83.33589935, 21.49963951], [83.3377533, 21.50263023], [83.3458786, 21.50823975], [83.34896851, 21.51596069], [83.35426331, 21.53531837], [83.36577606, 21.54968071], [83.36692047, 21.55302048], [83.36686707, 21.55931282], [83.3633194, 21.56777954], [83.36232758, 21.57252121], [83.36818695, 21.59707069], [83.37725067, 21.60467911], [83.38072205, 21.61275101], [83.38683319, 21.61536026], [83.38981628, 21.62054062], [83.39524078, 21.62419128], [83.40180969, 21.62675095], [83.40518951, 21.63181114], [83.40862274, 21.63420105], [83.41352844, 21.63631058], [83.42405701, 21.63848114], [83.42650604, 21.64353943], [83.44123077, 21.64927292], [83.44757843, 21.64459991], [83.44139099, 21.63246155], [83.44048309, 21.62669945], [83.44142151, 21.62502289], [83.44133759, 21.61809158], [83.44993591, 21.6169796], [83.45001221, 21.61339951], [83.44872284, 21.60822105], [83.45279694, 21.60732269], [83.45275879, 21.60519028], [83.46296692, 21.60551071], [83.46990204, 21.62677002], [83.4765625, 21.62729263], [83.48454285, 21.62556267], [83.48647308, 21.63317108], [83.4833374, 21.6371727], [83.483078, 21.63960075], [83.47477722, 21.64121819], [83.46621704, 21.64412117], [83.44077301, 21.65517044], [83.43535614, 21.66312027], [83.4286499, 21.66889], [83.4197464, 21.67502022], [83.42111206, 21.68654823], [83.42488098, 21.68901062], [83.42796326, 21.69232941], [83.43183136, 21.6939106], [83.4407959, 21.69338989], [83.44970703, 21.69095993], [83.45633698, 21.69432068], [83.45762634, 21.69967079], [83.46160889, 21.70627975], [83.46692657, 21.71056938], [83.47801971, 21.7279911], [83.47986603, 21.7341404], [83.48413086, 21.74155235], [83.47733307, 21.74588966], [83.47390747, 21.7496109], [83.47541809, 21.75341034], [83.47902679, 21.75869942], [83.47789001, 21.76459122], [83.47592163, 21.77379036], [83.46717834, 21.78273964], [83.47429657, 21.78614998], [83.48404694, 21.79434013], [83.48545837, 21.80322075], [83.49133301, 21.80866051], [83.49091339, 21.81454086], [83.49771881, 21.80618095], [83.50614166, 21.80039978], [83.51412201, 21.79780006], [83.52218628, 21.79411125], [83.53656769, 21.79393005], [83.5357666, 21.79896164], [83.53866577, 21.80061913], [83.53478241, 21.80681992], [83.53639984, 21.81834984], [83.52765656, 21.82299042], [83.53124237, 21.83189964], [83.54094696, 21.83465958], [83.54853821, 21.83523178], [83.55745697, 21.83440971], [83.56453705, 21.83036995], [83.5735321, 21.82966042], [83.57489777, 21.83260155], [83.57948303, 21.83712006], [83.58447266, 21.84360123], [83.5859375, 21.84762955], [83.58405304, 21.85279274], [83.57151794, 21.87187004], [83.57330322, 21.87636948], [83.57810974, 21.87978935], [83.57670593, 21.8861599], [83.57988739, 21.88925171], [83.58333588, 21.89096069], [83.58319855, 21.89406967], [83.58151245, 21.89743042], [83.58325195, 21.89856911], [83.59263611, 21.90075111], [83.59931183, 21.90600014], [83.60047913, 21.91084099], [83.58776855, 21.92612076], [83.55335999, 21.9321804], [83.55397034, 21.9362812], [83.55771637, 21.9439106], [83.54949188, 21.95038986], [83.53517151, 21.96350098], [83.53447723, 21.97624969], [83.53544617, 21.9796505], [83.54010773, 21.98533058], [83.54083252, 21.99323273], [83.543396, 21.99436951], [83.54663849, 21.99827957], [83.54496765, 21.99938965], [83.54673767, 22.00335121], [83.5485611, 22.00670242], [83.53885651, 22.01437187], [83.53399658, 22.02227974], [83.5326767, 22.02863121], [83.53244781, 22.03404808], [83.53414917, 22.04343987], [83.53836823, 22.05537987], [83.5430069, 22.05939102], [83.55095673, 22.05564117], [83.56562805, 22.0567894], [83.58351135, 22.05495071], [83.58595276, 22.0555706], [83.59056854, 22.05934143], [83.60031891, 22.0655098], [83.58917999, 22.07635117], [83.58306885, 22.08049011], [83.57369995, 22.08880043], [83.56482697, 22.09397125], [83.55892181, 22.0954895], [83.55726624, 22.0999794], [83.55916595, 22.10386086], [83.56575775, 22.11285019], [83.56730652, 22.1137085], [83.59253693, 22.13998032], [83.60233307, 22.1518383], [83.60594177, 22.15760994], [83.61183929, 22.17714119], [83.61927032, 22.19635963], [83.62628174, 22.20585823], [83.64575195, 22.22458839], [83.65457153, 22.2238903], [83.65744019, 22.22479057], [83.66461945, 22.2319603], [83.67273712, 22.2374382], [83.67904663, 22.2406311], [83.69300079, 22.24550056], [83.70043182, 22.24588013], [83.71898651, 22.2432518], [83.74565125, 22.24122047], [83.75279999, 22.24286079], [83.7568512, 22.25037956], [83.76180267, 22.25415039], [83.76583862, 22.25601959], [83.77131653, 22.25733948], [83.77471924, 22.26733971], [83.77855682, 22.27450943], [83.78862762, 22.28025055], [83.79078674, 22.28464127], [83.79364777, 22.28769112], [83.79751587, 22.28948975], [83.79798889, 22.28996277], [83.80478668, 22.28988075], [83.81598663, 22.29120255], [83.81944275, 22.29245186], [83.82080841, 22.29603958], [83.82010651, 22.30508232], [83.82065582, 22.31025124], [83.82248688, 22.31563759], [83.82520294, 22.31962967], [83.82940674, 22.32394028], [83.84303284, 22.32634926], [83.84757996, 22.33083916], [83.85330963, 22.33880043], [83.86100769, 22.34378052], [83.86414337, 22.34361839], [83.86714935, 22.34102058], [83.87194824, 22.33893013], [83.89697266, 22.33968925], [83.9053421, 22.35261154], [83.9155426, 22.35967064], [83.91929626, 22.35978127], [83.92402649, 22.35749054], [83.92958069, 22.35628128], [83.9432373, 22.35845947], [83.95231628, 22.36120987], [83.95661163, 22.3610611], [83.96698761, 22.35784912], [83.97820282, 22.36510849], [83.98536682, 22.36637115], [83.99297333, 22.36923981], [83.99739838, 22.36853981], [84.00119019, 22.36967087], [84.00421143, 22.36766052], [84.00167847, 22.37585068], [84.00166321, 22.38036919], [84.00898743, 22.39139938], [84.00994873, 22.39608955], [84.01248932, 22.39889908], [84.01444244, 22.40409279], [84.01875305, 22.40678024], [84.02216339, 22.41016006], [84.02599335, 22.41909027], [84.02398682, 22.42218018], [84.03270721, 22.42603111], [84.04000854, 22.43289948], [84.04139709, 22.43792915], [84.03951263, 22.44872284], [84.04155731, 22.46410942], [84.03872681, 22.46888161], [84.03465271, 22.46989822], [84.0238266, 22.47071075], [84.02168274, 22.47205925], [84.01548767, 22.48242188], [84.01302338, 22.48524094], [83.99707794, 22.4907608], [83.99298096, 22.49398041], [83.990448, 22.49439049], [83.98069, 22.49873161], [83.97609711, 22.50221062], [83.97384644, 22.50913811], [83.97445679, 22.51398087], [83.97657013, 22.51839066], [83.98010254, 22.52201271], [83.98584747, 22.52548027], [83.99298096, 22.52737808], [83.99429321, 22.5288105], [84.00250244, 22.52086067], [84.00963593, 22.52029037], [84.01554108, 22.52168083], [84.01914978, 22.52107048], [84.02472687, 22.51621246], [84.0330658, 22.5120697], [84.05065918, 22.51235962], [84.05758667, 22.51015091], [84.06047821, 22.50502014], [84.06668854, 22.50223923], [84.06900024, 22.49954987], [84.0670929, 22.49812126], [84.07164001, 22.49419022], [84.07920837, 22.48885155], [84.0877533, 22.48493004], [84.0998764, 22.48033905], [84.1029129, 22.48129082], [84.10347748, 22.47933006], [84.10211945, 22.47731018], [84.10611725, 22.47384834], [84.117836, 22.47142029], [84.12557983, 22.47359276], [84.12914276, 22.47348976], [84.13069153, 22.47001076], [84.13492584, 22.47094917], [84.13743591, 22.46710014], [84.13751984, 22.45718956], [84.13522339, 22.4490509], [84.13310242, 22.44531059], [84.13587952, 22.42068291], [84.14229584, 22.41539955], [84.15248871, 22.4009304], [84.17516327, 22.38894081], [84.18344116, 22.38368034], [84.19410706, 22.37181091], [84.22612762, 22.37412071], [84.24046326, 22.3744812], [84.24655914, 22.3737011], [84.25141144, 22.37041092], [84.26088715, 22.35370064], [84.26616669, 22.34782982], [84.27324677, 22.34509277], [84.28501892, 22.34211159], [84.28922272, 22.33732033], [84.31461334, 22.33892059], [84.31874847, 22.34049988], [84.32396698, 22.33892059], [84.333992, 22.34291077], [84.33838654, 22.34209824], [84.34496307, 22.34404945], [84.35328674, 22.34510994], [84.35909271, 22.34504128], [84.36171722, 22.34852982], [84.36741638, 22.34956932], [84.37200165, 22.34905052], [84.37758636, 22.34590912], [84.38786316, 22.34642029], [84.3944931, 22.34385109], [84.41911316, 22.35077095], [84.42608643, 22.3488102], [84.42584229, 22.3520298], [84.43144226, 22.36001015], [84.42719269, 22.36198044], [84.42694092, 22.36465073], [84.44207764, 22.37302017], [84.44785309, 22.37907982], [84.45565033, 22.37522125], [84.47280884, 22.38269043], [84.47759247, 22.38368034], [84.48020935, 22.38723946], [84.47572327, 22.39018822], [84.47595978, 22.39353943], [84.47447968, 22.40173149], [84.47666931, 22.40598106], [84.48126984, 22.40569115], [84.50179291, 22.41531944], [84.50582886, 22.41620064], [84.52101135, 22.41489029], [84.52662659, 22.42002106], [84.54065704, 22.42058945], [84.54329681, 22.41719818], [84.57215881, 22.42301178], [84.58907318, 22.42537117], [84.59395599, 22.42884064], [84.5953064, 22.4249382], [84.61364746, 22.42757988], [84.6255188, 22.42758942], [84.63210297, 22.4286499], [84.66160583, 22.41391945], [84.66934967, 22.41629982], [84.67282104, 22.41493034], [84.6815033, 22.41492081], [84.69149017, 22.41251183], [84.7113266, 22.41390038], [84.72614288, 22.41664124], [84.74385071, 22.41475105], [84.75269318, 22.44201279], [84.77805328, 22.44354057], [84.79128265, 22.4428196], [84.80124664, 22.44371033], [84.80779266, 22.44686127], [84.81047058, 22.44125175], [84.81047821, 22.43522835], [84.81269073, 22.43161011], [84.82842255, 22.42917061], [84.83162689, 22.4299202], [84.83254242, 22.42637825], [84.83574677, 22.42755127], [84.83946991, 22.43403053], [84.84136963, 22.43486977], [84.84780121, 22.43441963], [84.85534668, 22.43197823], [84.86371613, 22.43453026], [84.87124634, 22.43822289], [84.87525177, 22.44117928], [84.87652588, 22.44325066], [84.87779999, 22.4425106], [84.87947083, 22.43219948], [84.88150024, 22.42943954], [84.88198853, 22.42624855], [84.88024902, 22.41759109], [84.89379883, 22.41801071], [84.90770721, 22.41963959], [84.91639709, 22.4233799], [84.91986847, 22.42599106], [84.91815186, 22.42856979], [84.91739655, 22.43437958], [84.92533875, 22.43660927], [84.93136597, 22.43964958], [84.94077301, 22.44742966], [84.94728088, 22.45108032], [84.95244598, 22.45277023], [84.95336151, 22.4455204], [84.95243835, 22.43944931], [84.95458221, 22.4389019], [84.95728302, 22.44185829], [84.96024323, 22.44371986], [84.97779083, 22.45092964], [84.994133, 22.45827103], [85.00049591, 22.45836067], [85.02157593, 22.46710968], [85.02810669, 22.46820259], [85.03156281, 22.46978188], [85.03330994, 22.47692108], [85.03544617, 22.47729111], [85.03733063, 22.47508049], [85.04223633, 22.47694016], [85.04672241, 22.47739029], [85.05139923, 22.47941971], [85.06249237, 22.47841072], [85.07319641, 22.47286987], [85.07363892, 22.46668053], [85.07093811, 22.46116066], [85.07110596, 22.45590019], [85.06048584, 22.44951057], [85.05703735, 22.44470978], [85.05815125, 22.4397316], [85.06289673, 22.43608284], [85.06369019, 22.42322159], [85.06809235, 22.41806984], [85.07459259, 22.41345978], [85.07726288, 22.40830994], [85.07720184, 22.4030304], [85.08068085, 22.39546013], [85.08307648, 22.37844086], [85.07788086, 22.3691597], [85.07504272, 22.36096954], [85.07549286, 22.35577965], [85.07405853, 22.34859085], [85.07990265, 22.34439087], [85.08216095, 22.34132957], [85.09295654, 22.34109116], [85.09046173, 22.32487106], [85.08590698, 22.31698036], [85.08795929, 22.31408119], [85.09512329, 22.31239128], [85.10122681, 22.31432915], [85.10772705, 22.31523132], [85.11403656, 22.3142128], [85.11218262, 22.30507088], [85.11483765, 22.30038071], [85.11445618, 22.2904892], [85.10836029, 22.28947258], [85.10529327, 22.2911396], [85.09857178, 22.28792], [85.08235168, 22.27770805], [85.07051086, 22.27215958], [85.06941986, 22.26758194], [85.06990051, 22.26029015], [85.07431793, 22.25094032], [85.07206726, 22.24571991], [85.0681076, 22.24344063], [85.0694809, 22.23064995], [85.06253815, 22.21615982], [85.05879974, 22.20595169], [85.04692078, 22.18579292], [85.04960632, 22.17930984], [85.04779053, 22.17429924], [85.0414505, 22.17066002], [85.03322601, 22.1608429], [85.02802277, 22.15735817], [85.02539825, 22.15400124], [85.02619934, 22.14845085], [85.03031158, 22.14246178], [85.03115082, 22.13735962], [85.02735138, 22.1225605], [85.02429199, 22.11794281], [85.02374268, 22.11199188], [85.0194931, 22.10839081], [84.99362946, 22.09794807], [84.98586273, 22.09256935], [84.9834671, 22.09148979], [84.98049927, 22.09126091], [84.97982025, 22.08468056], [84.98104095, 22.08242035], [84.98742676, 22.07673836], [84.99359894, 22.07720947], [85.00231934, 22.0799427], [85.00720215, 22.08312988], [85.00901794, 22.09065056], [85.0140686, 22.09370995], [85.01995087, 22.10337067], [85.0271225, 22.10113907], [85.03118134, 22.10247993], [85.03513336, 22.1081295], [85.04389954, 22.11070061], [85.06945038, 22.10712814], [85.07623291, 22.10297012], [85.08409882, 22.10043907], [85.0954361, 22.09945107], [85.09900665, 22.09612083], [85.09970856, 22.08453941], [85.10447693, 22.08278084], [85.10897064, 22.0800209], [85.1102829, 22.07586288], [85.11329651, 22.07107925], [85.11888123, 22.0664711], [85.12539673, 22.06912041], [85.13506317, 22.07114029], [85.14083862, 22.07355118], [85.14891052, 22.07263947], [85.1555481, 22.07045937], [85.1578064, 22.06698036], [85.15896606, 22.06192017], [85.16374969, 22.0529995], [85.16720581, 22.0486908], [85.17080688, 22.04819107], [85.16983032, 22.05310059], [85.16436768, 22.06522942], [85.16960907, 22.06609917], [85.17246246, 22.06818962], [85.17675018, 22.06671906], [85.17913055, 22.06479073], [85.18345642, 22.05492973], [85.18699646, 22.05273056], [85.19232178, 22.05115128], [85.21074677, 22.04318047], [85.21460724, 22.03728104], [85.21389771, 22.02716064], [85.21383667, 22.01628113], [85.21488953, 22.01071167], [85.21835327, 22.00667], [85.22212982, 22.00344849], [85.23094177, 22.00027084], [85.24105835, 22.01251984], [85.24652863, 22.0254097], [85.25609589, 22.04245949], [85.25998688, 22.05285263], [85.26545715, 22.06025124], [85.26995087, 22.06896019], [85.27416229, 22.08008957], [85.28089905, 22.08764076], [85.28742218, 22.0931797], [85.30007935, 22.10705948], [85.30970001, 22.11338997], [85.31536865, 22.11584091], [85.32301331, 22.12499046], [85.33850098, 22.12471962], [85.34536743, 22.12699127], [85.35356903, 22.12057114], [85.35813141, 22.1196003], [85.36138153, 22.12144089], [85.36171722, 22.12475967], [85.35865784, 22.13280106], [85.35807037, 22.1379509], [85.36292267, 22.14657974], [85.36242676, 22.15004921], [85.36319733, 22.15456963], [85.36937714, 22.15521049], [85.37217712, 22.15244102], [85.37931824, 22.15168953], [85.38536835, 22.15234184], [85.39035034, 22.15513039], [85.3944397, 22.15859985], [85.40236664, 22.15653038], [85.41028595, 22.15608025], [85.41781616, 22.15335846], [85.43578339, 22.14417076], [85.45700836, 22.1357708], [85.46517944, 22.1312027], [85.47173309, 22.12413979], [85.47940063, 22.12177086], [85.4858017, 22.11648941], [85.50567627, 22.11145973], [85.5148468, 22.10820961], [85.52416992, 22.10305023], [85.52873993, 22.0987606], [85.53350067, 22.09679985], [85.53604889, 22.09440994], [85.53734589, 22.09029961], [85.53954315, 22.08658981], [85.54862213, 22.08855057], [85.55433655, 22.09082031], [85.56022644, 22.08490944], [85.56623077, 22.08703995], [85.57110596, 22.08605957], [85.58223724, 22.08098984], [85.5867691, 22.07681847], [85.59108734, 22.07444], [85.59664917, 22.07472038], [85.60176086, 22.07634163], [85.60359955, 22.0792408], [85.60732269, 22.08179092], [85.6085968, 22.07895088], [85.61110687, 22.07679939], [85.61958313, 22.07784081], [85.62623596, 22.0796299], [85.63124847, 22.08154106], [85.63639069, 22.08576965], [85.6400528, 22.09023285], [85.64460754, 22.09028053], [85.64805603, 22.08681107], [85.65033722, 22.08130074], [85.65532684, 22.07781029], [85.65750885, 22.07427979], [85.66472626, 22.06657028], [85.66757202, 22.06102943], [85.67236328, 22.05972099], [85.67195129, 22.05147171], [85.6815033, 22.04878044], [85.68788147, 22.05607986], [85.69600677, 22.0568409], [85.70465088, 22.05433083], [85.70780182, 22.05628967], [85.71277618, 22.0564003], [85.71755981, 22.05772972], [85.72235107, 22.05813026], [85.73381805, 22.06452942], [85.74606323, 22.06987953], [85.7504425, 22.07439041], [85.75213623, 22.0792408], [85.75782013, 22.08498192], [85.76502228, 22.08820915], [85.77339172, 22.09024048], [85.77903748, 22.09342003], [85.78425598, 22.09898758], [85.79091644, 22.10038948], [85.79397583, 22.10536957], [85.79718018, 22.10630035], [85.80204773, 22.11083031], [85.81474304, 22.10211182], [85.81521606, 22.09902], [85.80870819, 22.09184074], [85.81542206, 22.09282112], [85.8189621, 22.08963013], [85.82491302, 22.08712959], [85.82808685, 22.08266068], [85.83075714, 22.07697105], [85.8143692, 22.07007027], [85.80272675, 22.07176018], [85.79676056, 22.07450104], [85.78794098, 22.0771904], [85.78511047, 22.07191086], [85.77033234, 22.05128288], [85.7712326, 22.04714966], [85.77330017, 22.04330826], [85.77893829, 22.0362606], [85.77559662, 22.02827072], [85.77217102, 22.02470016], [85.76184845, 22.01794052], [85.75869751, 22.01480293], [85.7561264, 22.00839043], [85.76052094, 21.99694061], [85.76074982, 21.98971939], [85.77140045, 21.98371124], [85.78050232, 21.98104095], [85.78218842, 21.9793911], [85.78427887, 21.97859955], [85.80097961, 21.98166084], [85.80515289, 21.98022079], [85.81265259, 21.98096085], [85.81539154, 21.98013115], [85.81606293, 21.9753418], [85.81558228, 21.97130013], [85.81832886, 21.97001076], [85.82227325, 21.97013092], [85.82859802, 21.97294044], [85.84041595, 21.97648048], [85.8469696, 21.97707939], [85.87132263, 21.97475052], [85.88175201, 21.97483063], [85.88613129, 21.97542], [85.89115143, 21.97851944], [85.89417267, 21.97829056], [85.90284729, 21.96659088], [85.90542603, 21.96663094], [85.90599823, 21.96809006], [85.90445709, 21.9726696], [85.90921021, 21.97554016], [85.90966797, 21.97758102], [85.90725708, 21.98130989], [85.90924835, 21.99012947], [85.91306305, 21.9966507], [85.91223907, 22.0048008], [85.91954041, 22.00979042], [85.92340088, 22.01407814], [85.92488861, 22.01735115], [85.92877197, 22.01935959], [85.93309021, 22.0174408], [85.93856049, 22.01662064], [85.94258118, 22.01913071], [85.94470978, 22.02326965], [85.95153809, 22.0316391], [85.95358276, 22.03610039], [85.95797729, 22.04251099], [85.96331024, 22.0544281], [85.96737671, 22.05978012], [85.97122955, 22.06682014], [85.97528839, 22.0717907], [85.97738647, 22.07673836], [85.97731781, 22.08003998], [85.97899628, 22.08336067], [85.98919678, 22.09345055], [85.99259949, 22.10025024], [86.00047302, 22.10897064], [86.00258636, 22.11302185], [85.99608612, 22.12065125], [85.99508667, 22.12356949], [85.99462891, 22.13178062], [85.99909973, 22.13710976], [85.99968719, 22.14240074], [85.99923706, 22.14492989], [86.00385284, 22.15105057], [86.01140594, 22.15765953], [86.01312256, 22.16361046], [86.01257324, 22.16785812], [86.01477814, 22.17264175], [86.02671814, 22.18522263], [86.0255661, 22.18921089], [86.01738739, 22.19876289], [85.992836, 22.21548271], [85.98513031, 22.22384262], [85.97779083, 22.23554993], [85.97135925, 22.23838043], [85.9697876, 22.24340057], [85.98181152, 22.2520504], [85.98544312, 22.25745964], [85.98519135, 22.2672081], [85.99304199, 22.2732811], [85.99752808, 22.27534103], [86.00074005, 22.27933121], [86.00222015, 22.28146172], [86.00023651, 22.28437042], [86.00849915, 22.2926712], [86.01605988, 22.29652977], [86.0197525, 22.29781914], [86.02339172, 22.29767036], [86.02732086, 22.29949951], [86.0293808, 22.30076027], [86.03031921, 22.30298805], [86.03996277, 22.30355072], [86.04328918, 22.30619049], [86.04225922, 22.30824089], [86.03930664, 22.30865097], [86.03407288, 22.30793953], [86.03230286, 22.30523109], [86.02816772, 22.30768967], [86.02471924, 22.30417061], [86.02040863, 22.30554008], [86.01777649, 22.30455017], [86.01139832, 22.30939102], [86.01117706, 22.31056976], [86.00842285, 22.30995941], [86.008461, 22.31324005], [86.00589752, 22.31591034], [86.01328278, 22.32396126], [86.01918793, 22.32713127], [86.02043152, 22.32939911], [86.01399994, 22.33450127], [86.00476074, 22.33564949], [85.99842834, 22.33107948], [85.99582672, 22.33311844], [85.99288177, 22.33815956], [86.0061264, 22.34875107], [86.01686096, 22.3622303], [86.01526642, 22.36600113], [86.01596832, 22.37297058], [86.01841736, 22.37153053], [86.01891327, 22.37475967], [86.02124786, 22.37504005], [86.0196228, 22.37815094], [86.02149963, 22.38176155], [86.02050781, 22.38420105], [86.0175705, 22.38612175], [86.01906586, 22.39066124], [86.01802063, 22.39324188], [86.01574707, 22.39334106], [86.01477814, 22.39705086], [86.01226807, 22.39899063], [86.01365662, 22.40388107], [86.01204681, 22.41473007], [86.00961304, 22.41889], [86.00974274, 22.42165947], [86.00874329, 22.42432022], [86.0059967, 22.42536163], [86.00283813, 22.42506027], [86.00002289, 22.42264748], [85.99685669, 22.4216404], [85.99297333, 22.42214012], [85.98213196, 22.42898941], [85.96697998, 22.44122124], [85.96311188, 22.44512177], [85.96140289, 22.45269966], [85.95350647, 22.45597267], [85.95826721, 22.46590042], [85.9593277, 22.47038078], [85.95813751, 22.47618103], [85.96079254, 22.47861862], [85.9667511, 22.48216057], [85.9670105, 22.48601151], [85.96560669, 22.4901619], [85.96637726, 22.49381065], [85.96924591, 22.49978065], [85.98071289, 22.50974083], [85.98413849, 22.51062012], [85.99297333, 22.50892067], [85.99591827, 22.50896263], [85.9998703, 22.51497269], [86.00179291, 22.51486015], [86.00868225, 22.51855087], [86.01544952, 22.52448082], [86.02202606, 22.52054977], [86.02826691, 22.53433037], [86.01834106, 22.5436306], [86.0384903, 22.5635891], [86.04664612, 22.55788994], [86.0533905, 22.55465126], [86.05813599, 22.55342102], [86.06182861, 22.5485096], [86.06920624, 22.54306984], [86.07834625, 22.53041077], [86.09155273, 22.50915909], [86.09350586, 22.50822067], [86.0981369, 22.49563026], [86.10137939, 22.49015045], [86.10733032, 22.48489761], [86.11192322, 22.48293114], [86.11992645, 22.48555946], [86.1462326, 22.47914124], [86.14514923, 22.47513962], [86.1555481, 22.4790802], [86.16602325, 22.47674751], [86.17370605, 22.47643089], [86.19668579, 22.46774101], [86.20239258, 22.47027969], [86.20913696, 22.46284103], [86.21653748, 22.46504974], [86.2175827, 22.46824837], [86.21820831, 22.46821022], [86.21694946, 22.46403122], [86.21150208, 22.45971107], [86.22038269, 22.44909096], [86.22103119, 22.45059967], [86.22849274, 22.44958115], [86.2425766, 22.44453049], [86.25956726, 22.44127083], [86.2651825, 22.43954086], [86.27137756, 22.44282913], [86.2798233, 22.4455204], [86.28795624, 22.42536163], [86.29292297, 22.42014122], [86.30065155, 22.41531944], [86.30223846, 22.40520287], [86.30979919, 22.39726067], [86.31770325, 22.39059067], [86.31986237, 22.38035965], [86.32534027, 22.37308121], [86.33931732, 22.36605072], [86.34736633, 22.35900116], [86.35266113, 22.35153008], [86.35273743, 22.34542084], [86.36303711, 22.33960915], [86.37552643, 22.33711815], [86.39060974, 22.32528114], [86.40130615, 22.31941032], [86.41137695, 22.31555939], [86.42169189, 22.31389046], [86.42469788, 22.30920982], [86.42437744, 22.3062706], [86.43335724, 22.30154037], [86.4393158, 22.30578041], [86.44019318, 22.3114109], [86.43881226, 22.31645966], [86.43839264, 22.32336807], [86.44181824, 22.32534027], [86.44954681, 22.3230629], [86.45823669, 22.32211113], [86.46026611, 22.32641983], [86.46395874, 22.32699966], [86.4670105, 22.32891083], [86.46842194, 22.33228111], [86.47457886, 22.33422089], [86.47853088, 22.33446121], [86.48171234, 22.34201813], [86.48371887, 22.34441948], [86.49994659, 22.34095192], [86.50125885, 22.33146095], [86.50798798, 22.32402039], [86.51957703, 22.32057953], [86.52365112, 22.31857109], [86.52509308, 22.3123703], [86.52083588, 22.31148911], [86.52320099, 22.30783844], [86.52455139, 22.30285072], [86.53237915, 22.29819107], [86.53988647, 22.30373001], [86.54573822, 22.29892921], [86.55206299, 22.29528999], [86.561203, 22.29701042], [86.56771088, 22.29700279], [86.57068634, 22.29294968], [86.57433319, 22.29393959], [86.5752182, 22.2963295], [86.57846069, 22.29781914], [86.58130646, 22.29491806], [86.58217621, 22.29101944], [86.58560181, 22.29088974], [86.58561707, 22.28663063], [86.58992767, 22.28214073], [86.59092712, 22.27483177], [86.59845734, 22.27437973], [86.60263062, 22.27843285], [86.60851288, 22.27876091], [86.61605835, 22.27600288], [86.62715149, 22.26683044], [86.63025665, 22.26902962], [86.63465881, 22.26914978], [86.63729095, 22.26620293], [86.63761902, 22.26309013], [86.64137268, 22.26419258], [86.64227295, 22.26184273], [86.64557648, 22.26136971], [86.64589691, 22.25728035], [86.64833832, 22.25323105], [86.64729309, 22.24969292], [86.6481781, 22.23569107], [86.65114594, 22.23320007], [86.66034698, 22.2342205], [86.66269684, 22.23748016], [86.66514587, 22.23855972], [86.66989136, 22.2368412], [86.66995239, 22.23010063], [86.67399597, 22.22496986], [86.68216705, 22.21951103], [86.69178772, 22.2173996], [86.71147156, 22.21772003], [86.72097015, 22.21684074], [86.72278595, 22.21524811], [86.71996307, 22.21018982], [86.71766663, 22.19792938], [86.71607208, 22.19379997], [86.71721649, 22.18556976], [86.71335602, 22.18135262], [86.71277618, 22.17828941], [86.71534729, 22.17440987], [86.71689606, 22.16376114], [86.71520996, 22.15872002], [86.71544647, 22.14349174], [86.72280884, 22.14274025], [86.73233795, 22.14491081], [86.73953247, 22.14508247], [86.75222015, 22.14396095], [86.75670624, 22.14519119], [86.77153778, 22.14678001], [86.77694702, 22.1490097], [86.78283691, 22.15014076], [86.78681183, 22.15372276], [86.79032135, 22.1539402], [86.80045319, 22.1459198], [86.799263, 22.13908958], [86.80047607, 22.1304512], [86.79984283, 22.12848091], [86.79709625, 22.12613106], [86.79785919, 22.12528038], [86.80396271, 22.12613106], [86.806633, 22.12536049], [86.80796814, 22.12382126], [86.80438232, 22.11707115], [86.80621338, 22.11416054], [86.81217194, 22.11367035], [86.81484985, 22.11244011], [86.8208313, 22.11362076], [86.82331085, 22.11292076], [86.82540131, 22.10863113], [86.83132935, 22.10069084], [86.83200836, 22.09510994], [86.84169006, 22.09180069], [86.84603119, 22.09514999], [86.84790039, 22.09835052], [86.90876007, 22.08638], [86.92225647, 22.08576012], [86.92901611, 22.08453941], [86.93203735, 22.08584976], [86.94426727, 22.08197975], [86.95197296, 22.08134079], [86.95723724, 22.0833683], [86.96705627, 22.07775116], [86.97046661, 22.07399178], [86.97190857, 22.06627083], [86.98754883, 22.05507278], [86.99048615, 22.04938126], [86.99517822, 22.04579926], [87.00093079, 22.04500008], [87.00470734, 22.04278946], [87.0094223, 22.04148102], [87.01761627, 22.04128075], [87.02469635, 22.03269005], [87.02604675, 22.02874947], [87.02350616, 22.02102089], [87.02226257, 22.0120697], [87.02500916, 22.00395012], [87.02796936, 21.99842262], [87.0319519, 21.99567032], [87.03431702, 21.98919106], [87.03224182, 21.98610115], [87.03085327, 21.97883987], [87.02030945, 21.96836281], [87.01490021, 21.95326042], [87.00554657, 21.94065094], [87.00408173, 21.9354229], [87.0025177, 21.92235947], [86.99939728, 21.91814041], [87.00061035, 21.91438103], [86.99793243, 21.90750122], [87.00125885, 21.90584183], [87.00483704, 21.8955307], [87.01478577, 21.88968277], [87.0167923, 21.88722992], [87.01996613, 21.88574982], [87.02511597, 21.87034988], [87.03024292, 21.86531067], [87.05377197, 21.86094284], [87.06210327, 21.86018944], [87.0777359, 21.85980034], [87.09464264, 21.86034012], [87.0929184, 21.87420273], [87.09626007, 21.88210106], [87.09612274, 21.88624954], [87.09314728, 21.88986969], [87.0894165, 21.89240074], [87.08853912, 21.89507294], [87.08876801, 21.89812088], [87.09101868, 21.89923096], [87.09353638, 21.90789986], [87.09955597, 21.91098022], [87.10180664, 21.91608047], [87.10468292, 21.91781998], [87.10785675, 21.91741943], [87.1103363, 21.91802025], [87.11255646, 21.92115021], [87.11424255, 21.92217064], [87.11618042, 21.92064095], [87.12351227, 21.92024994], [87.13091278, 21.91801071], [87.1367569, 21.91797066], [87.14112854, 21.91969109], [87.14782715, 21.92592812], [87.15168762, 21.9279995], [87.15641785, 21.9289093], [87.15828705, 21.93054962], [87.15989685, 21.93392944], [87.15976715, 21.94908142], [87.16127777, 21.95389938], [87.16056061, 21.96244049], [87.16520691, 21.96751022], [87.16744232, 21.97340965], [87.17085266, 21.97261047], [87.17497253, 21.96619987], [87.18837738, 21.95701027], [87.19510651, 21.95356941], [87.20291138, 21.95643997], [87.20957184, 21.95737076], [87.22119141, 21.95321083], [87.22323608, 21.95323181], [87.22440338, 21.95401955], [87.22561646, 21.9571209], [87.22873688, 21.95607948], [87.23484802, 21.95438004], [87.23500061, 21.95298958], [87.23232269, 21.94646263], [87.23223114, 21.94036102], [87.23542786, 21.93374062], [87.25208282, 21.92097282], [87.25240326, 21.91780281], [87.25054932, 21.91518021], [87.23937225, 21.90682983], [87.23651886, 21.90272141], [87.23480988, 21.89560127], [87.24732971, 21.87172127], [87.24897766, 21.86651993], [87.24900055, 21.86380005], [87.24475098, 21.85637093], [87.24762726, 21.84820747], [87.25527191, 21.8438797], [87.25714874, 21.84137917], [87.25888824, 21.83501053], [87.26169586, 21.83329964], [87.26226044, 21.82982826], [87.26357269, 21.82719994], [87.26346588, 21.82501984], [87.26756287, 21.82149124], [87.26780701, 21.81970978], [87.26326752, 21.81604195], [87.26242065, 21.81385994], [87.26542664, 21.81289101], [87.27147675, 21.81307983], [87.27379608, 21.81171989], [87.27314758, 21.80579948], [87.27165222, 21.80471992], [87.27156067, 21.80340004], [87.27333832, 21.80360031], [87.27350616, 21.8020401], [87.28060913, 21.7991581], [87.2869873, 21.80384827], [87.29281616, 21.80546951], [87.29480743, 21.80389023], [87.294487, 21.79842186], [87.29656982, 21.79533005], [87.29872131, 21.79444122], [87.30605316, 21.79385948], [87.30755615, 21.79268265], [87.30916595, 21.78890991], [87.31796265, 21.79055023], [87.31685638, 21.78854942], [87.31730652, 21.78572083], [87.32286072, 21.78596115], [87.32427216, 21.78537941], [87.32618713, 21.78564072], [87.33011627, 21.78770256], [87.33270264, 21.78720093], [87.33534241, 21.78363037], [87.33573151, 21.78121185], [87.33500671, 21.78013039], [87.33666992, 21.77918053], [87.33922577, 21.7808094], [87.34046173, 21.78395844], [87.34449768, 21.78596115], [87.3520813, 21.78573036], [87.35504913, 21.77927971], [87.35736084, 21.77724075], [87.36779785, 21.77463913], [87.37045288, 21.76802063], [87.36873627, 21.76263046], [87.37011719, 21.76007271], [87.37166595, 21.76039124], [87.37306213, 21.76204109], [87.37348938, 21.76641083], [87.37542725, 21.76799965], [87.38330078, 21.77086067], [87.39096069, 21.77044106], [87.39240265, 21.76898193], [87.38990021, 21.76654053], [87.39315796, 21.76613808], [87.39377594, 21.76377106], [87.39524078, 21.76242256], [87.39993286, 21.76256943], [87.40101624, 21.76486015], [87.40283203, 21.7655201], [87.41208649, 21.76375008], [87.42481995, 21.76565933], [87.43139648, 21.76440048], [87.43930817, 21.76436043], [87.44367218, 21.76088905], [87.44245911, 21.75533104], [87.44330597, 21.74212074], [87.44563293, 21.7379303], [87.45111084, 21.7354126], [87.45137024, 21.73241043], [87.44441986, 21.732481], [87.44293213, 21.72904968], [87.45419312, 21.72943115], [87.46276855, 21.72640038], [87.46517944, 21.72636032], [87.46605682, 21.72519112], [87.46573639, 21.7235775], [87.46231842, 21.72224998], [87.46083069, 21.72050095], [87.46264648, 21.71706009], [87.47083282, 21.70718002], [87.46929169, 21.69845009], [87.4675293, 21.69565964], [87.46969604, 21.6916008], [87.46839142, 21.68378067], [87.46826172, 21.67727089], [87.46520233, 21.67513084], [87.46507263, 21.67110062], [87.46349335, 21.66876984], [87.46491241, 21.65855026], [87.4604187, 21.65712929], [87.45864868, 21.64493942], [87.46090698, 21.64445114], [87.46776581, 21.64565086], [87.47074127, 21.64307022], [87.47751617, 21.63175964], [87.4785614, 21.62794113], [87.48208618, 21.62586975], [87.48265839, 21.61803246], [87.48171234, 21.61383057], [87.48175812, 21.60946274], [87.48203278, 21.60870361], [87.48110962, 21.60777855], [87.48082733, 21.60778046], [87.4799881, 21.60771751], [87.47948456, 21.60771751], [87.47861481, 21.60785294], [87.47833252, 21.60777855], [87.47782898, 21.60750008], [87.4774704, 21.60705757], [87.47695923, 21.60679054], [87.47635651, 21.60679054], [87.47580719, 21.60698128], [87.47466278, 21.60686493], [87.47389984, 21.60678482], [87.47354126, 21.60638046], [87.47270966, 21.60647202], [87.47214508, 21.60612106], [87.47145081, 21.6061058], [87.47071838, 21.60632324], [87.46992493, 21.60650444], [87.46920776, 21.60645103], [87.46852112, 21.60639], [87.46788025, 21.60630989], [87.46722412, 21.60644722], [87.46673584, 21.6065197], [87.46639252, 21.60667038], [87.4658432, 21.60667038], [87.46565247, 21.60648537], [87.46555328, 21.60638618], [87.46389008, 21.60639], [87.46360779, 21.60610962], [87.46333313, 21.60611153], [87.46305847, 21.60583305], [87.46277618, 21.60583305], [87.4624939, 21.60555649], [87.46221924, 21.60527611], [87.46193695, 21.60527992], [87.46166992, 21.60499954], [87.46138763, 21.60499954], [87.46055603, 21.60416985], [87.46028137, 21.60416985], [87.4597168, 21.60361099], [87.4597168, 21.60305977], [87.46055603, 21.60222054], [87.45972443, 21.60179329], [87.45944214, 21.6016674], [87.45889282, 21.60167122], [87.45870209, 21.60148239], [87.45861053, 21.60138893], [87.45833588, 21.60139275], [87.45777893, 21.60083008], [87.45761871, 21.6006794], [87.45707703, 21.60037422], [87.45639038, 21.60000038], [87.45582581, 21.60000038], [87.45500946, 21.59917259], [87.45471954, 21.5988903], [87.45443726, 21.5988903], [87.454216, 21.59865761], [87.45388794, 21.59861183], [87.45361328, 21.59833336], [87.45305634, 21.59833336], [87.45249939, 21.59777832], [87.45276642, 21.59749985], [87.45276642, 21.59693909], [87.45305634, 21.59694481], [87.45333099, 21.59722137], [87.45388794, 21.59721756], [87.45417023, 21.59749985], [87.45500946, 21.59749985], [87.45542908, 21.59707642], [87.45555878, 21.59694481], [87.45500183, 21.59638977], [87.45471954, 21.59638977], [87.45417023, 21.59583282], [87.45388794, 21.59583282], [87.45333099, 21.59527969], [87.45305634, 21.59527969], [87.4522171, 21.59444046], [87.45178986, 21.59422684], [87.45124054, 21.59387016], [87.44972229, 21.5933342], [87.44721985, 21.59083557], [87.4466629, 21.59083557], [87.44638824, 21.59055328], [87.44610596, 21.59057045], [87.44581604, 21.59028053], [87.44555664, 21.59028053], [87.44444275, 21.58917046], [87.44361115, 21.58917046], [87.44194794, 21.58751106], [87.44139099, 21.58751106], [87.44114685, 21.58726311], [87.44083405, 21.58722115], [87.44055176, 21.58694458], [87.4402771, 21.58694458], [87.44000244, 21.58666611], [87.43972015, 21.58667183], [87.43860626, 21.58556175], [87.4383316, 21.58556175], [87.43776703, 21.58499908], [87.4375, 21.58499908], [87.43742371, 21.58492088], [87.43731689, 21.58481216], [87.43694305, 21.58444405], [87.4366684, 21.58444405], [87.43611145, 21.58389091], [87.43583679, 21.58389091], [87.43444824, 21.58250046], [87.43416595, 21.58250046], [87.43332672, 21.58167076], [87.43305206, 21.58167076], [87.4327774, 21.58138084], [87.43250275, 21.58138847], [87.43138885, 21.5802784], [87.43110657, 21.5802803], [87.4306488, 21.579813], [87.43055725, 21.57971954], [87.43055725, 21.57944679], [87.43027496, 21.57916451], [87.43000031, 21.57917023], [87.42944336, 21.57860947], [87.4291687, 21.57861137], [87.42875671, 21.57819557], [87.4283371, 21.57777786], [87.4283371, 21.57749939], [87.42778015, 21.57694054], [87.42694092, 21.57694244], [87.42666626, 21.57666588], [87.42582703, 21.57639122], [87.42415619, 21.57472038], [87.42388916, 21.57472229], [87.4236145, 21.57444382], [87.42333221, 21.57444382], [87.42319489, 21.57430649], [87.42305756, 21.57416725], [87.4227829, 21.57417107], [87.42193604, 21.57333183], [87.42166901, 21.57333374], [87.42138672, 21.57305527], [87.42111206, 21.5730629], [87.42028046, 21.57389069], [87.41971588, 21.57389069], [87.41916656, 21.57333183], [87.41916656, 21.57305527], [87.41887665, 21.57278252], [87.41887665, 21.57250023], [87.41805267, 21.57167244], [87.41805267, 21.57055092], [87.41694641, 21.56944466], [87.41666412, 21.56944466], [87.41576385, 21.5688324], [87.41555023, 21.5684967], [87.41570282, 21.56829262], [87.41619873, 21.56829453], [87.4168396, 21.56816292], [87.4168396, 21.5680294], [87.41677094, 21.56776047], [87.41619873, 21.56709099], [87.41567993, 21.56651115], [87.41503906, 21.56637001], [87.41444397, 21.56583595], [87.41416931, 21.56583023], [87.41333008, 21.56666946], [87.41339874, 21.56701088], [87.41346741, 21.56777954], [87.41352844, 21.56805992], [87.4136734, 21.56916618], [87.41333008, 21.56972313], [87.41278076, 21.56916618], [87.41278076, 21.56861115], [87.41249847, 21.56833076], [87.41249847, 21.56749916], [87.41166687, 21.56666946], [87.41166687, 21.56640053], [87.41139221, 21.56611061], [87.41139221, 21.56555939], [87.41110992, 21.56528091], [87.41110992, 21.56500053], [87.4108429, 21.56472015], [87.41083527, 21.56416512], [87.40970612, 21.56306076], [87.40952301, 21.56285095], [87.40910339, 21.56243324], [87.40916443, 21.56222153], [87.40916443, 21.56194305], [87.40944672, 21.5616703], [87.40952301, 21.56151962], [87.40994263, 21.56131172], [87.41166687, 21.56272125], [87.41207886, 21.56236076], [87.41207886, 21.56215477], [87.4119339, 21.56173134], [87.41007233, 21.56004906], [87.40970612, 21.56011963], [87.40943909, 21.56001663], [87.40937042, 21.55999184], [87.4091568, 21.56005859], [87.40888977, 21.55999947], [87.40860748, 21.55999947], [87.40791321, 21.55977821], [87.40776825, 21.55983734], [87.40727997, 21.55962944], [87.40693665, 21.55888939], [87.40673065, 21.55861092], [87.40611267, 21.55777931], [87.40596771, 21.55750084], [87.40499878, 21.5566597], [87.40444183, 21.55639076], [87.40409851, 21.55631065], [87.40291595, 21.55644989], [87.40222168, 21.55666924], [87.40090179, 21.55686951], [87.40027618, 21.55721092], [87.39923859, 21.55755806], [87.39861298, 21.55777931], [87.39833069, 21.55777931], [87.39805603, 21.5580616], [87.39778137, 21.55805588], [87.39749908, 21.55833244], [87.3972168, 21.55833054], [87.39569092, 21.55918312], [87.39533997, 21.5597229], [87.39520264, 21.55986977], [87.39499664, 21.55999947], [87.39303589, 21.56113052], [87.39261627, 21.56139946], [87.39248657, 21.56167984], [87.39235687, 21.56167984], [87.39193726, 21.56182098], [87.39179993, 21.56208801], [87.3915329, 21.56223106], [87.39111328, 21.5625], [87.39027405, 21.56333542], [87.38967133, 21.56386948], [87.38947296, 21.56417084], [87.38906097, 21.56484032], [87.38863373, 21.56511688], [87.38814545, 21.5652504], [87.38692474, 21.56630898], [87.38638306, 21.56656265], [87.38679504, 21.5662632], [87.38703918, 21.56541443], [87.38676453, 21.564991], [87.38684845, 21.56478119], [87.38663483, 21.56451225], [87.3864975, 21.56423569], [87.38642883, 21.56388855], [87.38643646, 21.56360054], [87.38630676, 21.56333542], [87.3861084, 21.56278038], [87.3861084, 21.5625], [87.38556671, 21.5616703], [87.38527679, 21.56138992], [87.38533783, 21.56110954], [87.3852005, 21.56083107], [87.38492584, 21.5602932], [87.3848877, 21.56021309], [87.38459778, 21.55999184], [87.38406372, 21.55921555], [87.3844223, 21.55796814], [87.38443756, 21.55708122], [87.3842926, 21.55652046], [87.38444519, 21.55611038], [87.38401794, 21.55399704], [87.38340759, 21.55352974], [87.38285065, 21.55346107], [87.38201904, 21.55335045], [87.38276672, 21.55249977], [87.38305664, 21.55249977], [87.3833313, 21.55221939], [87.38388824, 21.5522213], [87.3841629, 21.55194664], [87.38444519, 21.55194664], [87.38471985, 21.5522213], [87.38500214, 21.5522213], [87.38527679, 21.55194664], [87.3861084, 21.55194664], [87.38639069, 21.55166435], [87.38694763, 21.55167007], [87.38722229, 21.55140114], [87.38791656, 21.55104065], [87.38944244, 21.55083084], [87.3895874, 21.55089569], [87.39026642, 21.55120087], [87.39065552, 21.55122375], [87.39083099, 21.55140114], [87.39111328, 21.55140114], [87.39138794, 21.55111122], [87.39138794, 21.55000114], [87.39111328, 21.55000114], [87.39026642, 21.54916954], [87.38999939, 21.54916954], [87.38916779, 21.54833031], [87.3888855, 21.54833221], [87.38833618, 21.54777718], [87.38804626, 21.5477829], [87.38777924, 21.54750061], [87.38749695, 21.54750061], [87.38722229, 21.5477829], [87.38694763, 21.54777718], [87.38639069, 21.54833221], [87.3861084, 21.54833031], [87.38582611, 21.54861069], [87.38527679, 21.54861069], [87.38500214, 21.54889107], [87.38500214, 21.54916573], [87.38471985, 21.54944229], [87.38444519, 21.54944229], [87.3841629, 21.54916573], [87.38388824, 21.54916954], [87.38360596, 21.54889107], [87.3833313, 21.54889107], [87.38276672, 21.54833031], [87.38277435, 21.54805565], [87.38249969, 21.5477829], [87.38249969, 21.54750061], [87.38111115, 21.54611015], [87.38083649, 21.54611015], [87.3805542, 21.54583359], [87.38027954, 21.54583359], [87.37999725, 21.54555511], [87.37944794, 21.54555511], [87.37916565, 21.54583359], [87.37889099, 21.54583359], [87.3786087, 21.54611015], [87.3777771, 21.54611015], [87.37750244, 21.54639053], [87.37722015, 21.54639053], [87.37696075, 21.54611015], [87.37610626, 21.54611015], [87.3758316, 21.54639053], [87.375, 21.54639053], [87.37473297, 21.54667282], [87.3741684, 21.5466671], [87.37388611, 21.54694366], [87.37359619, 21.54694176], [87.37249756, 21.54805565], [87.37249756, 21.54833031], [87.37277985, 21.54861069], [87.3741684, 21.54861069], [87.37444305, 21.54889107], [87.3741684, 21.54916573], [87.3741684, 21.54944038], [87.37359619, 21.55000114], [87.37277985, 21.55000114], [87.3722229, 21.55055428], [87.3722229, 21.55083275], [87.37166595, 21.55083084], [87.3713913, 21.55111122], [87.37110901, 21.55083084], [87.3694458, 21.55083275], [87.36916351, 21.55055428], [87.36860657, 21.55056], [87.36833191, 21.55027962], [87.36776733, 21.55027962], [87.36750031, 21.55000114], [87.36723328, 21.55000114], [87.36694336, 21.55027962], [87.3666687, 21.55027962], [87.36638641, 21.55056], [87.36611176, 21.55056], [87.36528015, 21.55138969], [87.36528015, 21.5522213], [87.36416626, 21.55333328], [87.3638916, 21.55305672], [87.3638916, 21.55277824], [87.36305237, 21.55194092], [87.36222076, 21.55194664], [87.36208344, 21.55180359], [87.36194611, 21.55166435], [87.3602829, 21.55167007], [87.36000061, 21.55140114], [87.35943604, 21.55140114], [87.35916901, 21.55167007], [87.35805511, 21.55166435], [87.35778046, 21.55194664], [87.35749817, 21.55194664], [87.35722351, 21.5522213], [87.35639191, 21.55138969], [87.35582733, 21.55140114], [87.3555603, 21.55167007], [87.35500336, 21.55167007], [87.35472107, 21.55140114], [87.35388947, 21.55140114], [87.35360718, 21.55167007], [87.35221863, 21.55167007], [87.35193634, 21.55140114], [87.35109711, 21.55140114], [87.35083008, 21.55167007], [87.35063171, 21.55166435], [87.34972382, 21.55166435], [87.34916687, 21.5522213], [87.34889221, 21.55194664], [87.34833527, 21.55194664], [87.34805298, 21.55166435], [87.34777832, 21.55194664], [87.34666443, 21.55194664], [87.34638977, 21.5522213], [87.34610748, 21.55221939], [87.34555817, 21.55278015], [87.34416962, 21.55277824], [87.34388733, 21.55305672], [87.34361267, 21.55305672], [87.34336853, 21.55282021], [87.34166718, 21.55277824], [87.34139252, 21.55305672], [87.34083557, 21.55305672], [87.34054565, 21.55327988], [87.34027863, 21.55333328], [87.33999634, 21.55361176], [87.33916473, 21.55361176], [87.33865356, 21.55309868], [87.33833313, 21.55277824], [87.33721924, 21.55277824], [87.33694458, 21.55305672], [87.33666992, 21.55305672], [87.33638763, 21.55333328], [87.33499908, 21.55333328], [87.33374786, 21.55424118], [87.33333588, 21.55446053], [87.33203125, 21.55438042], [87.3312912, 21.55442429], [87.33072662, 21.55450249], [87.33059692, 21.55451965], [87.3299408, 21.5544796], [87.32928467, 21.55446243], [87.32863617, 21.55446053], [87.32795715, 21.55442047], [87.3272171, 21.55446053], [87.32694244, 21.55446053], [87.32666779, 21.55417061], [87.32639313, 21.55446053], [87.32305908, 21.55444527], [87.32277679, 21.55472183], [87.32221985, 21.55472183], [87.32195282, 21.55446053], [87.31890106, 21.55424118], [87.31833649, 21.5541687], [87.31777954, 21.55417061], [87.31742859, 21.55444527], [87.3172226, 21.55451012], [87.31694794, 21.55465508], [87.31555176, 21.55472183], [87.31520844, 21.55466461], [87.31361389, 21.55473137], [87.3133316, 21.55472183], [87.3132019, 21.55472183], [87.31305695, 21.55471992], [87.31138611, 21.55500031], [87.30999756, 21.55500031], [87.3097229, 21.55508041], [87.3077774, 21.55528069], [87.30735779, 21.55523109], [87.30444336, 21.55555534], [87.30392456, 21.55570412], [87.30361176, 21.55555534], [87.3033371, 21.55555916], [87.30304718, 21.55569839], [87.30272675, 21.55565834], [87.30251312, 21.55563164], [87.30136108, 21.55563164], [87.30014801, 21.55542946], [87.29611206, 21.55501938], [87.29528046, 21.5549202], [87.29472351, 21.55472183], [87.29444122, 21.55479813], [87.29277802, 21.55500031], [87.29242706, 21.5549202], [87.29083252, 21.5549202], [87.2902832, 21.55500984], [87.29000092, 21.55500984], [87.2894516, 21.55505943], [87.28923035, 21.55498123], [87.28853607, 21.5546875], [87.28806305, 21.55468941], [87.28749847, 21.55463982], [87.28722382, 21.55456924], [87.28666687, 21.55472183], [87.28639221, 21.55451202], [87.28610992, 21.55472183], [87.28527832, 21.55471992], [87.28472137, 21.55480766], [87.28451538, 21.55487442], [87.28409576, 21.55473137], [87.28388977, 21.55472183], [87.28367615, 21.55456924], [87.2831192, 21.55462074], [87.28291321, 21.55449104], [87.28277588, 21.55449486], [87.28221893, 21.55444527], [87.28193665, 21.55446053], [87.28132629, 21.55439949], [87.28083038, 21.55447006], [87.28041077, 21.55431747], [87.2800827, 21.55433273], [87.27944183, 21.55433273], [87.27861023, 21.55417061], [87.27777863, 21.55417061], [87.27429199, 21.55425072], [87.27271271, 21.55417824], [87.27111053, 21.55360985], [87.26944733, 21.55361176], [87.26773071, 21.55307198], [87.26568604, 21.55329704], [87.26529694, 21.55334091], [87.26465607, 21.55340958], [87.26286316, 21.55321121], [87.2612915, 21.55321121], [87.26051331, 21.55301094], [87.25863647, 21.55266953], [87.25327301, 21.55266953], [87.25269318, 21.55280304], [87.2514801, 21.55273628], [87.24983215, 21.55247116], [87.24846649, 21.55186081], [87.24782562, 21.55179405], [87.24568176, 21.55158997], [87.24446106, 21.55152512], [87.24310303, 21.55158997], [87.24188232, 21.55166054], [87.24082184, 21.55200005], [87.23960876, 21.55120087], [87.23912048, 21.55125237], [87.23851776, 21.55121231], [87.23782349, 21.55107117], [87.23709106, 21.55092812], [87.23638153, 21.55084038], [87.23573303, 21.55079079], [87.23513031, 21.55064011], [87.23456573, 21.55035782], [87.23416901, 21.55000114], [87.23220825, 21.55000114], [87.23194122, 21.54972076], [87.23082733, 21.54972076], [87.22956848, 21.54980087], [87.22720337, 21.54980087], [87.22648621, 21.54957008], [87.22596741, 21.5494709], [87.22538757, 21.54943275], [87.22514343, 21.54947281], [87.224823, 21.54953003], [87.22416687, 21.54944992], [87.22368622, 21.54938316], [87.22333527, 21.54944229], [87.22211456, 21.54931641], [87.22090149, 21.54891014], [87.22025299, 21.5485096], [87.21837616, 21.54824066], [87.21746063, 21.54797173], [87.21723175, 21.54780006], [87.21694183, 21.54770279], [87.21424103, 21.54722977], [87.21322632, 21.54689026], [87.21187592, 21.54675865], [87.21037292, 21.54676056], [87.2099762, 21.54672623], [87.2095871, 21.54668999], [87.20901489, 21.54628754], [87.20835114, 21.54639053], [87.20803833, 21.54639053], [87.20780182, 21.54613876], [87.20749664, 21.54611015], [87.20722198, 21.54639053], [87.20694733, 21.54639053], [87.20666504, 21.5466671], [87.20575714, 21.5471611], [87.20548248, 21.54729843], [87.20492554, 21.54765129], [87.20437622, 21.54784966], [87.20417023, 21.54807091], [87.20361328, 21.5481987], [87.20333099, 21.54834175], [87.20305634, 21.54833031], [87.20276642, 21.54840279], [87.20236206, 21.54841995], [87.20188141, 21.54849052], [87.20139313, 21.54849052], [87.20089722, 21.54849052], [87.20027924, 21.54805946], [87.19999695, 21.54805946], [87.19944763, 21.54750061], [87.19944763, 21.54694176], [87.19984436, 21.54653358], [87.20021057, 21.54618645], [87.20052338, 21.54580116], [87.20069122, 21.54536057], [87.20059204, 21.54493141], [87.20037842, 21.54450035], [87.20005035, 21.54413033], [87.19963837, 21.54379082], [87.19922638, 21.5434494], [87.19877625, 21.54323006], [87.19834137, 21.54305077], [87.19788361, 21.54289436], [87.19741821, 21.54274368], [87.19696045, 21.54255676], [87.19645691, 21.54243279], [87.19602966, 21.54223061], [87.19558716, 21.54203033], [87.19509125, 21.54189873], [87.19461823, 21.5417099], [87.19425201, 21.54157639], [87.1941452, 21.54153824], [87.19365692, 21.54138947], [87.19319153, 21.54123116], [87.19272614, 21.54105186], [87.1922226, 21.54087067], [87.19166565, 21.5408268], [87.19151306, 21.54081154], [87.19110107, 21.54077339], [87.19057465, 21.54060936], [87.19000244, 21.54050064], [87.18942261, 21.54032326], [87.18881226, 21.54021645], [87.18821716, 21.54002953], [87.18761444, 21.53991318], [87.18704987, 21.53970337], [87.18651581, 21.53946114], [87.18598938, 21.53920174], [87.18541718, 21.53902817], [87.18480682, 21.53887939], [87.18421936, 21.53868103], [87.1836319, 21.53849983], [87.18305206, 21.53830147], [87.18251801, 21.5380497], [87.18199921, 21.5377903], [87.18147278, 21.53755188], [87.18090057, 21.5373764], [87.180336, 21.53721046], [87.17980194, 21.53703308], [87.1792984, 21.53680801], [87.17877197, 21.53655815], [87.1782608, 21.5363369], [87.1778717, 21.53627777], [87.17751312, 21.53634071], [87.17707062, 21.53635979], [87.17648315, 21.53619003], [87.17582703, 21.53593063], [87.17537689, 21.53565025], [87.17505646, 21.53536987], [87.17471313, 21.53517342], [87.17433167, 21.53497505], [87.17392731, 21.53475952], [87.17349243, 21.53460121], [87.17304993, 21.5344429], [87.17260742, 21.53427124], [87.17216492, 21.53410149], [87.17172241, 21.53390884], [87.17124939, 21.53373909], [87.17077637, 21.53357506], [87.17032623, 21.53337097], [87.1698761, 21.53320122], [87.16943359, 21.53304863], [87.16899109, 21.53289032], [87.16854095, 21.53273964], [87.16810608, 21.53254128], [87.16765594, 21.53238106], [87.16722107, 21.53222084], [87.16677094, 21.53206825], [87.16630554, 21.5319767], [87.16580963, 21.53193855], [87.16532135, 21.53186989], [87.16487885, 21.53165817], [87.16445923, 21.53140259], [87.16404724, 21.53116035], [87.16362, 21.53095818], [87.16319275, 21.53077507], [87.16279602, 21.5305481], [87.1624527, 21.53032112], [87.16207886, 21.53012085], [87.16165924, 21.53001022], [87.16122437, 21.52992439], [87.16078949, 21.52972984], [87.16033173, 21.52951813], [87.15986633, 21.52930832], [87.15947723, 21.52905273], [87.15911865, 21.52879333], [87.15870667, 21.52859116], [87.15830231, 21.52837944], [87.15785217, 21.52824974], [87.15738678, 21.52808952], [87.15638733, 21.52743912], [87.15473938, 21.52683067], [87.15380859, 21.52602768], [87.15231323, 21.5250206], [87.15087128, 21.52408028], [87.14966583, 21.52361107], [87.1492157, 21.52345657], [87.14853668, 21.52346039], [87.14785004, 21.52310944], [87.14720154, 21.52273941], [87.14658356, 21.52234459], [87.14594269, 21.52199745], [87.14533997, 21.52164078], [87.1446991, 21.52136612], [87.14404297, 21.52109909], [87.14337921, 21.52083015], [87.14277649, 21.52050018], [87.14228058, 21.52011299], [87.14176941, 21.51984024], [87.14128113, 21.51963043], [87.14083099, 21.51944351], [87.13968658, 21.51861572], [87.13896942, 21.51828194], [87.13846588, 21.51781082], [87.13817596, 21.51740074], [87.13796997, 21.51720238], [87.13718414, 21.51700211], [87.1366806, 21.51673317], [87.13648224, 21.51650429], [87.13592529, 21.51619148], [87.13542938, 21.51584625], [87.13498688, 21.51551056], [87.134552, 21.51521111], [87.13414001, 21.51492119], [87.13374329, 21.51499939], [87.13275909, 21.51472092], [87.13194275, 21.51415825], [87.13173676, 21.51403046], [87.1314621, 21.51403236], [87.1305542, 21.51333427], [87.1297226, 21.51292992], [87.1286087, 21.51303291], [87.12832642, 21.5128994], [87.12805176, 21.51303864], [87.12722015, 21.51333046], [87.12722015, 21.51361084], [87.12917328, 21.51555824], [87.12944794, 21.51582527], [87.12957764, 21.51609993], [87.12978363, 21.5161705], [87.13040924, 21.51651955], [87.13069153, 21.51672554], [87.13082123, 21.51679993], [87.13166046, 21.51756859], [87.1313858, 21.51779175], [87.13111115, 21.5177784], [87.13083649, 21.5177784], [87.13054657, 21.51749992], [87.13027954, 21.51749992], [87.1297226, 21.51693916], [87.12944794, 21.51694489], [87.1286087, 21.51611137], [87.12833405, 21.51611137], [87.12805176, 21.5158329], [87.1277771, 21.5158329], [87.12722015, 21.51527977], [87.12693787, 21.51528931], [87.12666321, 21.51499939], [87.12638855, 21.51499939], [87.12610626, 21.51472092], [87.12555695, 21.51472282], [87.12527466, 21.51471329], [87.12472534, 21.51499939], [87.12472534, 21.5158329], [87.12458801, 21.51610947], [87.12472534, 21.51638985], [87.12473297, 21.51721954], [87.125, 21.51749992], [87.125, 21.51833344], [87.12526703, 21.51861191], [87.12527466, 21.51916695], [87.125, 21.5194416], [87.125, 21.52000046], [87.12361145, 21.52139282], [87.12333679, 21.52138901], [87.12277985, 21.52147484], [87.12242889, 21.52147484], [87.12194824, 21.52138901], [87.1213913, 21.52112007], [87.12110901, 21.52109909], [87.12083435, 21.52111053], [87.12055206, 21.52083206], [87.1202774, 21.52083206], [87.12000275, 21.5205555], [87.11972046, 21.52056122], [87.11915588, 21.52028275], [87.11807251, 21.51917267], [87.11778259, 21.51917267], [87.11759186, 21.51898384], [87.11750031, 21.51889038], [87.11723328, 21.51889038], [87.11638641, 21.51806259], [87.1159668, 21.51791954], [87.11562347, 21.51764107], [87.11521149, 21.51737213], [87.11459351, 21.51667595], [87.11416626, 21.51666832], [87.1138916, 21.51638985], [87.11305237, 21.51625061], [87.11277771, 21.51617813], [87.11242676, 21.51625061], [87.11138916, 21.51638985], [87.11110687, 21.51666832], [87.10944366, 21.51666641], [87.10916901, 21.51694489], [87.10888672, 21.51694489], [87.10861206, 21.51722145], [87.10749817, 21.51722145], [87.10694885, 21.51773453], [87.10697174, 21.51732063], [87.10668945, 21.51669121], [87.10643768, 21.51634026], [87.10722351, 21.51555634], [87.10849762, 21.51478004], [87.10928345, 21.51485252], [87.11107635, 21.51458359], [87.11164856, 21.51431465], [87.11229706, 21.51424789], [87.11422729, 21.5137825], [87.11472321, 21.51333046], [87.11472321, 21.51277542], [87.11472321, 21.51250076], [87.1147995, 21.51222992], [87.11473083, 21.51151276], [87.11444092, 21.50972176], [87.11416626, 21.50944328], [87.11416626, 21.50889015], [87.1138916, 21.50860977], [87.1138916, 21.5083313], [87.11360931, 21.50805473], [87.11333466, 21.50805473], [87.11222076, 21.50694466], [87.11222076, 21.50666618], [87.11193848, 21.50638962], [87.11193848, 21.5060997], [87.11166382, 21.50583267], [87.11166382, 21.50555611], [87.11138916, 21.50527954], [87.11138916, 21.50499916], [87.10916901, 21.50278091], [87.10887909, 21.50278091], [87.10861206, 21.50250053], [87.10805511, 21.50250053], [87.10694122, 21.50138855], [87.10666656, 21.50139046], [87.10652924, 21.50125122], [87.10639191, 21.50111198], [87.10618591, 21.50097656], [87.10597229, 21.50077057], [87.10569763, 21.50036049], [87.10398102, 21.4985466], [87.10382843, 21.49833488], [87.10361481, 21.49805641], [87.10305786, 21.49749947], [87.10305786, 21.49722099], [87.10194397, 21.49611092], [87.10193634, 21.49583054], [87.10166931, 21.49555588], [87.10138702, 21.49555969], [87.09967804, 21.4938488], [87.09944153, 21.49361038], [87.0983429, 21.49250031], [87.09812927, 21.49229813], [87.09722137, 21.49160194], [87.09694672, 21.49138832], [87.09664917, 21.49111938], [87.09645844, 21.49098015], [87.09636688, 21.4908886], [87.09625244, 21.49077415], [87.09563446, 21.49027824], [87.09527588, 21.48999977], [87.09443665, 21.48916817], [87.09416962, 21.48916817], [87.09310913, 21.4881115], [87.09194183, 21.4869442], [87.09194183, 21.48666763], [87.09139252, 21.48611069], [87.09083557, 21.48611069], [87.09046936, 21.48574448], [87.09027863, 21.48555756], [87.09027863, 21.48528099], [87.08999634, 21.48499107], [87.08999634, 21.48444557], [87.08944702, 21.48388863], [87.0891571, 21.48389053], [87.08776855, 21.48250008], [87.08750153, 21.48250008], [87.08583069, 21.48083115], [87.08555603, 21.48083115], [87.08499908, 21.48027802], [87.08444214, 21.48028183], [87.08361053, 21.47972107], [87.08333588, 21.4794445], [87.08277893, 21.4794445], [87.08222961, 21.47893333], [87.08166504, 21.4781189], [87.08110046, 21.47758293], [87.08027649, 21.47722054], [87.08027649, 21.47694397], [87.08000183, 21.4766674], [87.07971954, 21.47666931], [87.07943726, 21.47639084], [87.0789032, 21.47639084], [87.07805634, 21.47555923], [87.07776642, 21.47555923], [87.07704163, 21.47482491], [87.07694244, 21.47471809], [87.07694244, 21.4738884], [87.07444763, 21.47138977], [87.07389069, 21.4711895], [87.0736084, 21.47110939], [87.07333374, 21.47105217], [87.07305908, 21.47105026], [87.07276917, 21.47112083], [87.07250214, 21.47110939], [87.07118225, 21.47090912], [87.07105255, 21.47088051], [87.0708313, 21.47083473], [87.07026672, 21.47083092], [87.06929779, 21.47139549], [87.06902313, 21.47146034], [87.06881714, 21.47167778], [87.06861115, 21.47194672], [87.06777954, 21.47205162], [87.0661087, 21.47278023], [87.06583405, 21.47291183], [87.06548309, 21.47324944], [87.06495667, 21.47377968], [87.0644455, 21.47402954], [87.06419373, 21.47439194], [87.06382751, 21.47465134], [87.06359863, 21.47471809], [87.06276703, 21.47555923], [87.06194305, 21.47639084], [87.06138611, 21.47639084], [87.06111145, 21.47666931], [87.0605545, 21.4766674], [87.06027985, 21.47694397], [87.05999756, 21.4766674], [87.05916595, 21.4766674], [87.0588913, 21.47694397], [87.05833435, 21.47694397], [87.05805206, 21.4766674], [87.0577774, 21.47694397], [87.0533371, 21.47694397], [87.05305481, 21.4766674], [87.05249786, 21.47666931], [87.05222321, 21.47639084], [87.0513916, 21.47639084], [87.05110931, 21.47666931], [87.05000305, 21.47666931], [87.04972076, 21.47680855], [87.04924011, 21.47673988], [87.04888916, 21.4766674], [87.04833221, 21.47666931], [87.04805756, 21.47687912], [87.04750061, 21.47687912], [87.04722595, 21.47666931], [87.04666901, 21.47666931], [87.04638672, 21.47639084], [87.04611206, 21.47639084], [87.04582977, 21.4761219], [87.04556274, 21.4761219], [87.04547119, 21.47602463], [87.04528046, 21.47582817], [87.04499817, 21.47583389], [87.04444122, 21.47527885], [87.04416656, 21.47528076], [87.04379272, 21.47490692], [87.04360962, 21.47471809], [87.04360962, 21.47444534], [87.04332733, 21.47417068], [87.04332733, 21.47360992], [87.04360962, 21.47333336], [87.04360962, 21.47305679], [87.04389191, 21.47277832], [87.04389191, 21.47249985], [87.04380798, 21.47221947], [87.04373932, 21.47201157], [87.04360199, 21.47166443], [87.04389191, 21.47056007], [87.04400635, 21.47044182], [87.04416656, 21.47027779], [87.04416656, 21.46972084], [87.04444122, 21.46944237], [87.04464722, 21.46925163], [87.04499817, 21.46918678], [87.04573822, 21.46899033], [87.04581451, 21.46936798], [87.04582977, 21.46998978], [87.04576874, 21.47027969], [87.04576874, 21.47055435], [87.04582977, 21.47083473], [87.04605103, 21.47110939], [87.04611206, 21.47138977], [87.04611206, 21.47166443], [87.04626465, 21.47194672], [87.04633331, 21.4721508], [87.04611206, 21.47249985], [87.04611969, 21.47277832], [87.04605103, 21.47305679], [87.04611206, 21.47333336], [87.04618073, 21.47375107], [87.04722595, 21.47500038], [87.04839325, 21.4754715], [87.04888916, 21.47527885], [87.04944611, 21.47528076], [87.04972076, 21.47500038], [87.05000305, 21.47500038], [87.05027771, 21.47471809], [87.05083466, 21.47472191], [87.05133057, 21.47439957], [87.05194092, 21.47413445], [87.05263519, 21.47371292], [87.05326843, 21.47335815], [87.0538559, 21.4731102], [87.05444336, 21.47305679], [87.05527496, 21.47359467], [87.05555725, 21.47373962], [87.05610657, 21.47417831], [87.0569458, 21.4742012], [87.05750275, 21.4742012], [87.05805206, 21.47417831], [87.05833435, 21.47418404], [87.05860901, 21.47417641], [87.0588913, 21.47417831], [87.05944824, 21.4738903], [87.0597229, 21.47360992], [87.06083679, 21.47361183], [87.06111145, 21.47333336], [87.06138611, 21.47333336], [87.06194305, 21.47277832], [87.06194305, 21.47249985], [87.0616684, 21.47221947], [87.0616684, 21.47166443], [87.06138611, 21.47138977], [87.06138611, 21.47083092], [87.06222534, 21.46999931], [87.06222534, 21.46694374], [87.06305695, 21.46611023], [87.06305695, 21.46583176], [87.0633316, 21.46555519], [87.0633316, 21.46500015], [87.06359863, 21.46472168], [87.06361389, 21.46444511], [87.06416321, 21.46388817], [87.06305695, 21.46277809], [87.06305695, 21.46222115], [87.0625, 21.46166611], [87.0625, 21.46138954], [87.0616684, 21.46055984], [87.06138611, 21.46055984], [87.06053925, 21.45972061], [87.0597229, 21.45972061], [87.05944824, 21.46000099], [87.05944824, 21.46138954], [87.05916595, 21.46166992], [87.05916595, 21.46277809], [87.05944824, 21.46305466], [87.05916595, 21.46333313], [87.05805206, 21.46333313], [87.0577774, 21.4636116], [87.05722046, 21.4636116], [87.0569458, 21.46333313], [87.05638885, 21.46333313], [87.0561142, 21.4636116], [87.05555725, 21.4636116], [87.05548096, 21.46353722], [87.05527496, 21.46333313], [87.05477905, 21.46320152], [87.05435181, 21.46300888], [87.05393219, 21.46275902], [87.05349731, 21.46247101], [87.05309296, 21.46217155], [87.05275726, 21.46185112], [87.0524292, 21.46158028], [87.05212402, 21.46130371], [87.05179596, 21.46101952], [87.05149078, 21.46066284], [87.05114746, 21.46030235], [87.0508194, 21.45993423], [87.05050659, 21.45957565], [87.05039978, 21.45944786], [87.05023956, 21.45924377], [87.05001068, 21.45895576], [87.0497818, 21.45869827], [87.04944611, 21.45842934], [87.04899597, 21.45824051], [87.04854584, 21.45800972], [87.04815674, 21.45769691], [87.04769897, 21.45741272], [87.04722595, 21.4571209], [87.04682159, 21.45679283], [87.04646301, 21.45644188], [87.04615784, 21.45609665], [87.04588318, 21.45576286], [87.04556274, 21.45546913], [87.04521179, 21.4552002], [87.04482269, 21.45492363], [87.04440308, 21.45463371], [87.04397583, 21.45432854], [87.04351807, 21.45401955], [87.04299927, 21.45368195], [87.04251862, 21.45330238], [87.04202271, 21.45285034], [87.04151154, 21.45243263], [87.04103851, 21.45204353], [87.04063416, 21.45158958], [87.0402298, 21.45116806], [87.03975677, 21.45086098], [87.03926086, 21.45054817], [87.03876495, 21.45025253], [87.03829193, 21.44995117], [87.03785706, 21.44964981], [87.03748322, 21.44933128], [87.03710938, 21.44903183], [87.03678894, 21.44870949], [87.03650665, 21.44836044], [87.03620148, 21.44805145], [87.03585815, 21.44776154], [87.03546143, 21.44748878], [87.03504181, 21.44721985], [87.03462219, 21.44695091], [87.03422546, 21.44669533], [87.03388214, 21.44639969], [87.03349304, 21.44610977], [87.03304291, 21.44580269], [87.032547, 21.44547653], [87.03203583, 21.44516945], [87.03157043, 21.44487381], [87.03118134, 21.44451141], [87.03084564, 21.44411469], [87.03048706, 21.44373131], [87.03006744, 21.44339371], [87.02961731, 21.44302368], [87.02915192, 21.4425869], [87.02864838, 21.44209099], [87.02805328, 21.44166946], [87.02805328, 21.4413929], [87.02749634, 21.44083023], [87.02722168, 21.44083214], [87.02694702, 21.44055557], [87.0266571, 21.44055939], [87.02555847, 21.43944168], [87.02527618, 21.43944359], [87.02500153, 21.43916702], [87.02416992, 21.43917274], [87.02361298, 21.43861008], [87.02333069, 21.43861008], [87.02278137, 21.43805504], [87.02249908, 21.43806267], [87.0222168, 21.43778229], [87.02194214, 21.43778229], [87.0211792, 21.43730164], [87.02057648, 21.4369297], [87.02005768, 21.43658638], [87.01957703, 21.4362812], [87.01911163, 21.43602943], [87.01863861, 21.43575096], [87.01815033, 21.43544006], [87.01767731, 21.43511009], [87.01724243, 21.43473053], [87.01681519, 21.43437195], [87.01638031, 21.4340229], [87.01593781, 21.43370628], [87.01552582, 21.43338013], [87.01512909, 21.43307495], [87.01473236, 21.43279076], [87.01434326, 21.43251038], [87.01396179, 21.43223953], [87.01355743, 21.43196106], [87.01313019, 21.43168068], [87.01267242, 21.43139076], [87.0121994, 21.43109131], [87.01174164, 21.43075371], [87.01131439, 21.4303894], [87.01087189, 21.43008995], [87.0104599, 21.4297924], [87.01004791, 21.42954826], [87.0096817, 21.42926979], [87.00930786, 21.42901039], [87.00895691, 21.42869949], [87.00857544, 21.42841148], [87.00812531, 21.42812538], [87.00763702, 21.42780113], [87.00708771, 21.42744064], [87.00653076, 21.42702293], [87.00591278, 21.42664909], [87.00533295, 21.4262867], [87.00484467, 21.42592239], [87.00435638, 21.42571831], [87.00395966, 21.42550278], [87.0036087, 21.42527962], [87.00305176, 21.42472076], [87.0027771, 21.42472267], [87.00250244, 21.4244442], [87.00222015, 21.4244442], [87.0019455, 21.42416573], [87.00166321, 21.42388916], [87.00138855, 21.42388916], [87.00110626, 21.42361069], [87.0008316, 21.42361069], [87.0002594, 21.42277908], [87.0, 21.42250061], [86.99973297, 21.42222023], [86.99861145, 21.4216671], [86.99833679, 21.42139053], [86.99777985, 21.42111015], [86.99610901, 21.42083359], [86.99555206, 21.42055511], [86.99555206, 21.42028046], [86.9952774, 21.42000008], [86.9952774, 21.4197197], [86.99472046, 21.41916656], [86.99415588, 21.41888046], [86.99333191, 21.41861153], [86.9916687, 21.4169426], [86.99111176, 21.41666412], [86.99054718, 21.41611099], [86.98999786, 21.41584015], [86.98972321, 21.41555977], [86.98916626, 21.41527939], [86.9883194, 21.41500282], [86.9883194, 21.41472054], [86.98694611, 21.41333389], [86.98583221, 21.41277695], [86.98554993, 21.41250038], [86.98500061, 21.41222191], [86.98472595, 21.41194534], [86.98472595, 21.41167259], [86.98361206, 21.4113903], [86.98332977, 21.41110992], [86.98278046, 21.41083336], [86.98278046, 21.41055489], [86.98166656, 21.41055489], [86.98166656, 21.41083336], [86.98110962, 21.41083336], [86.98027802, 21.40999985], [86.98027802, 21.40970993], [86.98000336, 21.40944481], [86.98000336, 21.40916634], [86.97972107, 21.40888977], [86.97972107, 21.40833092], [86.97944641, 21.40805626], [86.97944641, 21.40777969], [86.97915649, 21.40750122], [86.97915649, 21.40722084], [86.97888947, 21.40694427], [86.97888947, 21.40666771], [86.97833252, 21.40611076], [86.97833252, 21.40583038], [86.97750092, 21.40500069], [86.97693634, 21.40472031], [86.97638702, 21.40416718], [86.97583008, 21.40390015], [86.97556305, 21.40361023], [86.97555542, 21.40305328], [86.97528076, 21.40278053], [86.97528076, 21.40250015], [86.97389221, 21.4011097], [86.97333527, 21.40083122], [86.97083282, 21.39833069], [86.97083282, 21.39805603], [86.97027588, 21.39749908], [86.96971893, 21.39722061], [86.96916962, 21.39666748], [86.96861267, 21.39639091], [86.96806335, 21.39582825], [86.96805573, 21.3955555], [86.96721649, 21.39471054], [86.96722412, 21.39444351], [86.96694183, 21.39416885], [86.96611023, 21.39389038], [86.96555328, 21.39332962], [86.96555328, 21.39305687], [86.96305847, 21.39056015], [86.96221924, 21.39027977], [86.96138, 21.38944054], [86.96138763, 21.38916588], [86.95944214, 21.38722038], [86.95944214, 21.38694382], [86.95888519, 21.38666725], [86.95833588, 21.38611031], [86.95833588, 21.3855629], [86.95777893, 21.38500023], [86.95777893, 21.38472176], [86.95722198, 21.38416672], [86.95667267, 21.38388824], [86.95610809, 21.38332748], [86.95527649, 21.38305473], [86.95500183, 21.38277817], [86.95500183, 21.38249969], [86.95417023, 21.38166809], [86.95361328, 21.38138962], [86.95305634, 21.38083076], [86.95305634, 21.38055611], [86.95249939, 21.38000107], [86.95194244, 21.37973022], [86.95083618, 21.37861061], [86.95083618, 21.37833023], [86.95055389, 21.37805367], [86.95054626, 21.37778091], [86.94999695, 21.37750053], [86.94889069, 21.37639046], [86.94777679, 21.3758297], [86.94721985, 21.37527847], [86.94721985, 21.375], [86.94695282, 21.37471962], [86.94694519, 21.37444305], [86.9466629, 21.3741703], [86.9466629, 21.37389183], [86.94610596, 21.37333107], [86.94611359, 21.37305641], [86.9458313, 21.37278175], [86.94526672, 21.37249947], [86.94526672, 21.37221909], [86.94472504, 21.37166595], [86.94473267, 21.37138939], [86.94444275, 21.37111092], [86.94444275, 21.37083054], [86.94416809, 21.37055588], [86.94402313, 21.37041092], [86.9438858, 21.37000084], [86.94330597, 21.3698597], [86.94167328, 21.36750031], [86.94138336, 21.36722183], [86.94055176, 21.36611176], [86.94033813, 21.3659687], [86.94000244, 21.36555099], [86.93916321, 21.3647213], [86.93873596, 21.36444092], [86.93784332, 21.36346817], [86.93776703, 21.36313057], [86.93638611, 21.36139107], [86.93638611, 21.36111069], [86.93611145, 21.36055946], [86.93583679, 21.3602829], [86.93554688, 21.3602829], [86.93499756, 21.35972023], [86.93499756, 21.35944366], [86.93360901, 21.35805511], [86.93332672, 21.35806274], [86.93305206, 21.35778236], [86.93305206, 21.35749817], [86.93222046, 21.35666847], [86.93222046, 21.35610962], [86.9291687, 21.35305786], [86.9291687, 21.35279083], [86.92861176, 21.35222054], [86.92861176, 21.3516674], [86.92804718, 21.35111046], [86.92804718, 21.35083008], [86.92472076, 21.34749985], [86.92472076, 21.34721947], [86.9236145, 21.3461113], [86.92333221, 21.3461113], [86.92028046, 21.34305573], [86.91999817, 21.34306145], [86.91971588, 21.34277916], [86.91944122, 21.34277916], [86.91722107, 21.34056091], [86.91638947, 21.34056091], [86.91583252, 21.34000015], [86.91555786, 21.34000015], [86.9152832, 21.33971977], [86.91333008, 21.33972168], [86.91306305, 21.34000015], [86.91278076, 21.34000015], [86.91249847, 21.34028053], [86.91166687, 21.34028053], [86.91139221, 21.34056091], [86.91110992, 21.34056091], [86.91098022, 21.34042168], [86.9108429, 21.34028053], [86.9108429, 21.33971977], [86.91027832, 21.33916664], [86.91028595, 21.33889008], [86.90999603, 21.3386097], [86.91000366, 21.33694649], [86.91055298, 21.33638954], [86.91055298, 21.33611107], [86.91166687, 21.3350029], [86.91166687, 21.33472061], [86.91139221, 21.33444214], [86.91139221, 21.33416748], [86.91110992, 21.33389282], [86.91110992, 21.33333015], [86.91083527, 21.3330555], [86.9108429, 21.33278275], [86.91055298, 21.33250046], [86.91055298, 21.33222008], [86.91000366, 21.33166695], [86.90999603, 21.33139038], [86.90972137, 21.33111191], [86.90972137, 21.33083344], [86.90944672, 21.33055496], [86.90944672, 21.3302784], [86.90888977, 21.32971954], [86.90888977, 21.32944489], [86.90777588, 21.3283329], [86.90777588, 21.32805634], [86.90389252, 21.32417107], [86.90361023, 21.32417107], [86.90277863, 21.32332993], [86.90277863, 21.32305336], [86.90110016, 21.32139015], [86.90083313, 21.32139015], [86.89861298, 21.31917191], [86.89833069, 21.31917191], [86.89694214, 21.31777954], [86.89666748, 21.31777954], [86.89639282, 21.31749916], [86.89528656, 21.31749916], [86.89499664, 21.31777954], [86.89417267, 21.31777954], [86.89360809, 21.31722069], [86.89305878, 21.3172226], [86.89221954, 21.31638908], [86.89222717, 21.31611061], [86.89194489, 21.31583405], [86.89194489, 21.31500053], [86.89167023, 21.31472015], [86.89167023, 21.31138611], [86.89138794, 21.31110954], [86.89138794, 21.31055641], [86.89111328, 21.31027794], [86.89111328, 21.30972099], [86.89083099, 21.30944252], [86.89083099, 21.30916405], [86.89111328, 21.30888939], [86.89055634, 21.30833054], [86.89055634, 21.30750275], [86.89027405, 21.30722427], [86.89027405, 21.30694389], [86.88999939, 21.30666733], [86.88999939, 21.30611038], [86.88944244, 21.30556107], [86.88944244, 21.30528259], [86.88899994, 21.30483437], [86.88889313, 21.30472565], [86.88861084, 21.30444527], [86.88861084, 21.30417252], [86.88809204, 21.30360413], [86.88804626, 21.30332756], [86.88777924, 21.30305481], [86.88777924, 21.30277824], [86.88749695, 21.30249977], [86.88749695, 21.30194092], [86.88722229, 21.30166626], [86.88722229, 21.30111122], [86.88694763, 21.30083084], [86.88694763, 21.30027771], [86.88680267, 21.30013275], [86.8861084, 21.2994442], [86.8861084, 21.29916763], [86.88582611, 21.29889107], [86.88582611, 21.29861069], [86.88555908, 21.29832077], [86.88555908, 21.29805565], [86.88527679, 21.29778099], [86.88527679, 21.29750061], [86.88500214, 21.29722023], [86.88500214, 21.29694557], [86.88444519, 21.29638863], [86.88445282, 21.29611015], [86.8841629, 21.29583549], [86.8841629, 21.29555321], [86.88388824, 21.29527855], [86.88388824, 21.29500008], [86.88360596, 21.2947197], [86.88361359, 21.29444313], [86.88276672, 21.29360962], [86.88277435, 21.29333115], [86.88194275, 21.29249954], [86.88194275, 21.29221916], [86.88027954, 21.29055595], [86.88028717, 21.29027939], [86.8797226, 21.28972054], [86.8797226, 21.28944397], [86.87750244, 21.28722], [86.87750244, 21.28694534], [86.87526703, 21.28471947], [86.87527466, 21.28444672], [86.87472534, 21.28388977], [86.87472534, 21.2836113], [86.8741684, 21.28305626], [86.87416077, 21.28277969], [86.87388611, 21.28250122], [86.87388611, 21.28222084], [86.87361145, 21.28194237], [86.87361145, 21.2816658], [86.87304688, 21.28111076], [86.87304688, 21.28083038], [86.8722229, 21.28000259], [86.87194824, 21.28000259], [86.8713913, 21.27944183], [86.87110901, 21.27944374], [86.87083435, 21.27916718], [86.87082672, 21.27889252], [86.86972046, 21.27778244], [86.86972046, 21.27750969], [86.86833191, 21.2761097], [86.86833191, 21.27583313], [86.86805725, 21.27555466], [86.86805725, 21.27527809], [86.86833191, 21.27499962], [86.86833191, 21.27472115], [86.86750031, 21.27388954], [86.86750031, 21.27361107], [86.86694336, 21.27305984], [86.86694336, 21.27277946], [86.86638641, 21.27222061], [86.86638641, 21.27194595], [86.86611176, 21.27166748], [86.86611176, 21.27083015], [86.86555481, 21.27027512], [86.86528015, 21.27028084], [86.86499023, 21.27000046], [86.86472321, 21.27000046], [86.86444092, 21.26972008], [86.86444092, 21.26916695], [86.86416626, 21.26889038], [86.86416626, 21.26861], [86.86360931, 21.26805305], [86.86360931, 21.2677803], [86.86305237, 21.26721954], [86.86305237, 21.26694489], [86.86166382, 21.26555634], [86.86165619, 21.26528168], [86.86138916, 21.26499939], [86.86138916, 21.2641716], [86.86055756, 21.26333046], [86.86055756, 21.2630558], [86.85943604, 21.2619381], [86.85944366, 21.26166725], [86.85917664, 21.26139069], [86.85917664, 21.26111031], [86.85888672, 21.26083374], [86.85888672, 21.26055527], [86.85832977, 21.26000023], [86.85832977, 21.25971985], [86.85758972, 21.25760841], [86.85694122, 21.25667], [86.85694122, 21.25611115], [86.85666656, 21.25583076], [86.85666656, 21.2555542], [86.85639191, 21.25527954], [86.85639191, 21.25500107], [86.85500336, 21.25361061], [86.85500336, 21.25333977], [86.85444641, 21.25278282], [86.85444641, 21.25250053], [86.85415649, 21.25222015], [86.85416412, 21.25194359], [86.85444641, 21.25166702], [86.85360718, 21.2508297], [86.85361481, 21.25055504], [86.85333252, 21.25027084], [86.85333252, 21.24999809], [86.85305023, 21.24971962], [86.85305786, 21.24944496], [86.85250092, 21.24888992], [86.85250092, 21.24860954], [86.85277557, 21.24833298], [86.85221863, 21.24777794], [86.85221863, 21.24749947], [86.85166931, 21.24694061], [86.85166931, 21.24666786], [86.85111237, 21.24611092], [86.85111237, 21.24555969], [86.85056305, 21.24500084], [86.85055542, 21.24472237], [86.85028076, 21.2444458], [86.85028076, 21.24388885], [86.84999084, 21.24361038], [86.84999084, 21.24333], [86.84944153, 21.24277687], [86.84944153, 21.24250031], [86.84916687, 21.24221992], [86.84916687, 21.24194527], [86.84860992, 21.24139977], [86.84860992, 21.24110985], [86.84833527, 21.24083138], [86.84833527, 21.24027824], [86.84777832, 21.23971939], [86.84777832, 21.23944473], [86.84750366, 21.23916626], [86.84749603, 21.23888969], [86.84722137, 21.23860931], [86.84722137, 21.23833084], [86.84694672, 21.23805618], [86.84694672, 21.23778152], [86.84638977, 21.23722076], [86.84638977, 21.2369442], [86.84610748, 21.23666573], [86.84610748, 21.23611069], [86.84583282, 21.23583031], [86.84583282, 21.23555565], [86.84527588, 21.23500061], [86.84527588, 21.23472023], [86.84500122, 21.23444366], [86.84500122, 21.23388863], [86.84471893, 21.23361015], [86.84471893, 21.23333359], [86.84444427, 21.23305511], [86.84443665, 21.23278046], [86.84471893, 21.23250008], [86.84500122, 21.23250008], [86.84527588, 21.23221016], [86.84583282, 21.2322216], [86.84610748, 21.23194695], [86.84638977, 21.23195076], [86.84675598, 21.23158455], [86.84889221, 21.2294426], [86.84889221, 21.22888947], [86.84916687, 21.2286129], [86.84916687, 21.22805977], [86.84889221, 21.22777939], [86.84889221, 21.22667122], [86.8483429, 21.22611046], [86.84777832, 21.22667122], [86.84750366, 21.2266674], [86.84722137, 21.22694206], [86.84722137, 21.22722054], [86.84694672, 21.22750282], [86.84694672, 21.22805405], [86.84555817, 21.2294426], [86.8454361, 21.2294426], [86.84500122, 21.2294426], [86.84471893, 21.22972488], [86.84444427, 21.22972488], [86.84417725, 21.22999954], [86.84388733, 21.22999954], [86.84361267, 21.23027992], [86.84333038, 21.22999954], [86.84333038, 21.22972107], [86.84278107, 21.22916412], [86.84278107, 21.22888947], [86.84361267, 21.22805977], [86.84361267, 21.22777939], [86.84378815, 21.2276001], [86.84388733, 21.22750282], [86.84388733, 21.22722054], [86.84361267, 21.22694206], [86.84361267, 21.2266674], [86.84333038, 21.22639275], [86.84333038, 21.22583008], [86.84305573, 21.22555542], [86.84306335, 21.22500038], [86.84278107, 21.22472191], [86.84278107, 21.22416687], [86.84249878, 21.2238884], [86.84249878, 21.22360992], [86.84222412, 21.22333336], [86.84222412, 21.22305489], [86.84194183, 21.22277832], [86.84194183, 21.22138977], [86.84139252, 21.22083092], [86.84139252, 21.22055626], [86.84111023, 21.22027016], [86.84111023, 21.21972275], [86.84055328, 21.21916771], [86.84055328, 21.21861076], [86.84027863, 21.21833038], [86.84027863, 21.21722221], [86.83944702, 21.21639061], [86.83944702, 21.21611023], [86.83972168, 21.21582985], [86.83972168, 21.21527863], [86.83944702, 21.21500015], [86.83944702, 21.21471977], [86.83805847, 21.21333122], [86.83805847, 21.21110916], [86.83833313, 21.2108326], [86.83889008, 21.21083069], [86.83944702, 21.21138954], [86.83944702, 21.21166611], [86.83972168, 21.21194458], [86.83972168, 21.21221924], [86.84027863, 21.21277809], [86.84027863, 21.21305466], [86.84055328, 21.21333122], [86.84055328, 21.21389008], [86.84111023, 21.21445084], [86.84111023, 21.21500015], [86.84166718, 21.21555328], [86.84166718, 21.21582985], [86.84222412, 21.2163887], [86.84221649, 21.21693993], [86.84249878, 21.21722984], [86.84249878, 21.21750069], [86.84305573, 21.21805573], [86.84306335, 21.21861076], [86.84333038, 21.21889114], [86.84333038, 21.21916771], [86.84361267, 21.21944427], [86.84361267, 21.21972275], [86.84416962, 21.22027779], [86.84444427, 21.22027779], [86.84471893, 21.21999931], [86.84500122, 21.22000122], [86.84527588, 21.21972084], [86.84527588, 21.21916771], [86.84500122, 21.21889114], [86.84500122, 21.21833038], [86.84471893, 21.21805573], [86.84471893, 21.21778107], [86.84388733, 21.21693993], [86.84388733, 21.2163887], [86.84333038, 21.21582985], [86.84333038, 21.21555328], [86.84306335, 21.21528053], [86.84306335, 21.21500015], [86.84278107, 21.21472359], [86.84278107, 21.21416664], [86.84194183, 21.21333122], [86.84194183, 21.21305466], [86.84166718, 21.21277809], [86.84166718, 21.21249962], [86.84139252, 21.21221924], [86.84139252, 21.21194458], [86.84111023, 21.21166611], [86.84111023, 21.21109962], [86.84083557, 21.2108326], [86.84083557, 21.21055603], [86.84055328, 21.21027946], [86.84055328, 21.20999908], [86.83999634, 21.20943832], [86.83944702, 21.20944405], [86.83889008, 21.2088871], [86.83889008, 21.20806122], [86.83944702, 21.20750046], [86.83944702, 21.20722008], [86.83777618, 21.20555687], [86.83750153, 21.20583344], [86.83666992, 21.20583344], [86.83638763, 21.20555687], [86.83611298, 21.20555687], [86.83555603, 21.20611191], [86.83528137, 21.20611], [86.83500671, 21.20639038], [86.83416748, 21.20639038], [86.83389282, 21.20611], [86.83361053, 21.20611191], [86.83333588, 21.20583344], [86.83305359, 21.20583344], [86.83222198, 21.20499992], [86.83139038, 21.20499992], [86.83110809, 21.20528984], [86.83082581, 21.20499992], [86.83055878, 21.20499992], [86.82971954, 21.20417023], [86.82971954, 21.20306015], [86.82943726, 21.20277977], [86.82943726, 21.20223045], [86.82917023, 21.20194054], [86.82917023, 21.20153999], [86.82917023, 21.20138931], [86.82888031, 21.20111275], [86.82888031, 21.20083046], [86.82971954, 21.20000267], [86.83000183, 21.20000267], [86.83082581, 21.19916153], [86.83083344, 21.19888878], [86.83110809, 21.19861031], [86.83110809, 21.19778252], [86.83000183, 21.19666862], [86.83027649, 21.19638824], [86.83027649, 21.19610023], [86.83083344, 21.19555473], [86.83055878, 21.19527817], [86.83055878, 21.19444084], [86.83000183, 21.19388962], [86.83000183, 21.19361115], [86.82943726, 21.19305992], [86.82917023, 21.19305611], [86.82888794, 21.19333267], [86.82776642, 21.19333076], [86.82749939, 21.19361115], [86.82749939, 21.19388962], [86.82694244, 21.19444466], [86.82694244, 21.19472122], [86.82666779, 21.19499969], [86.82666779, 21.19527817], [86.82678986, 21.19539833], [86.82749939, 21.19611168], [86.82777405, 21.19611168], [86.82796478, 21.1962986], [86.82805634, 21.19638824], [86.82861328, 21.19638824], [86.82888794, 21.19666672], [86.82888031, 21.19721985], [86.82917023, 21.19750023], [86.82861328, 21.1980629], [86.82776642, 21.1980629], [86.82722473, 21.19861031], [86.8263855, 21.19861031], [86.8263855, 21.19833374], [86.82611084, 21.19805527], [86.82611084, 21.19721985], [86.82555389, 21.19666672], [86.82527924, 21.19666672], [86.82472229, 21.19722176], [86.82389069, 21.19638824], [86.82389069, 21.19582748], [86.82416534, 21.19555473], [86.82416534, 21.19527817], [86.82306671, 21.19416809], [86.82277679, 21.19416809], [86.82250214, 21.19388962], [86.82250214, 21.19333076], [86.82277679, 21.19305611], [86.82277679, 21.19277954], [86.82306671, 21.19250107], [86.82306671, 21.19194031], [86.82333374, 21.19166756], [86.82332611, 21.19111061], [86.82306671, 21.19083023], [86.82305908, 21.19055557], [86.82250214, 21.19000053], [86.82250214, 21.18943977], [86.82221985, 21.18916702], [86.82221985, 21.18889046], [86.82195282, 21.18861008], [86.82194519, 21.1883316], [86.8216629, 21.18805313], [86.8216629, 21.1866703], [86.82138824, 21.18639183], [86.82138824, 21.18528175], [86.82110596, 21.18499947], [86.82110596, 21.18471909], [86.8208313, 21.18444443], [86.8208313, 21.18361092], [86.82055664, 21.18333054], [86.82055664, 21.1827774], [86.82026672, 21.18250084], [86.82026672, 21.18193817], [86.81972504, 21.18138885], [86.81973267, 21.18082809], [86.81916809, 21.18027878], [86.81916809, 21.17945099], [86.8188858, 21.17917061], [86.8188858, 21.17860985], [86.81861115, 21.17833328], [86.81861115, 21.17805672], [86.81916809, 21.17749977], [86.81944275, 21.17749977], [86.82027435, 21.17833328], [86.82055664, 21.17833328], [86.8208313, 21.17861176], [86.82108307, 21.17861176], [86.82138824, 21.17860985], [86.8216629, 21.17889023], [86.82194519, 21.17888832], [86.82211304, 21.17906189], [86.82221985, 21.17917061], [86.82250214, 21.17917061], [86.82277679, 21.17945099], [86.82306671, 21.17945099], [86.82332611, 21.17917061], [86.82389069, 21.17917061], [86.82389069, 21.17860985], [86.82305908, 21.17777824], [86.82306671, 21.17749977], [86.82333374, 21.1772213], [86.8236084, 21.1772213], [86.82416534, 21.17666435], [86.82444763, 21.17667007], [86.82583618, 21.17806053], [86.82611084, 21.17806053], [86.8272171, 21.17694092], [86.82833099, 21.17694664], [86.82833099, 21.17638969], [86.82805634, 21.17611122], [86.82805634, 21.17361069], [86.82694244, 21.17250252], [86.82694244, 21.17222023], [86.82722473, 21.17194366], [86.82722473, 21.1716671], [86.82749939, 21.17139244], [86.82749939, 21.17056274], [86.82666779, 21.1697197], [86.82666779, 21.16944504], [86.82694244, 21.16918182], [86.82694244, 21.1680584], [86.8272171, 21.16777992], [86.8272171, 21.16694069], [86.82694244, 21.16666794], [86.82694244, 21.16500092], [86.82666779, 21.16472054], [86.82666779, 21.1641674], [86.82639313, 21.16389084], [86.82639313, 21.16250038], [86.82583618, 21.16194534], [86.82583618, 21.16055107], [86.82611084, 21.16027832], [86.82611084, 21.15806007], [86.82554626, 21.15749931], [86.82527924, 21.15749931], [86.82513428, 21.15735817], [86.82499695, 21.15722275], [86.82499695, 21.15694427], [86.82472229, 21.15667152], [86.82472229, 21.15611076], [86.82554626, 21.15527916], [86.82554626, 21.15221977], [86.82583618, 21.15194511], [86.82583618, 21.15167046], [86.82554626, 21.15139008], [86.82552338, 21.15051842], [86.82527924, 21.15027809], [86.82527924, 21.14972115], [86.82499695, 21.14944458], [86.82499695, 21.14861107], [86.82417297, 21.14777946], [86.82472229, 21.14722061], [86.82472229, 21.14694214], [86.82499695, 21.14666748], [86.82499695, 21.14611053], [86.82472229, 21.14583015], [86.82472229, 21.14500046], [86.82444763, 21.14472008], [86.82444763, 21.14333344], [86.82472229, 21.14305496], [86.82472229, 21.14138985], [86.82417297, 21.14083099], [86.8236084, 21.1408329], [86.8236084, 21.13999939], [86.82389069, 21.13972092], [86.8236084, 21.13944435], [86.8236084, 21.13888931], [86.82332611, 21.13861084], [86.82332611, 21.13833046], [86.82389069, 21.13777733], [86.82417297, 21.13778114], [86.82666779, 21.13528061], [86.82666779, 21.13500023], [86.82694244, 21.13471985], [86.82694244, 21.13361359], [86.82749939, 21.13305473], [86.82749939, 21.13194466], [86.82777405, 21.13166618], [86.82776642, 21.13056183], [86.82805634, 21.13028145], [86.82805634, 21.12805748], [86.82833099, 21.12778091], [86.82833099, 21.12693977], [86.82805634, 21.12666893], [86.82805634, 21.1258297], [86.82833099, 21.12555695], [86.82833099, 21.12528038], [86.82861328, 21.125], [86.82861328, 21.12445068], [86.82888031, 21.1241703], [86.82888031, 21.12388039], [86.82917023, 21.12361145], [86.82917023, 21.12333488], [86.82944489, 21.12305641], [86.82943726, 21.12277985], [86.83000183, 21.1222229], [86.83000183, 21.12194252], [86.83027649, 21.12166405], [86.83027649, 21.12111282], [86.83055878, 21.12082291], [86.83055878, 21.12055588], [86.83082581, 21.12028122], [86.83082581, 21.11944008], [86.83055878, 21.11916733], [86.83082581, 21.11889267], [86.83055878, 21.11861038], [86.83082581, 21.11861038], [86.83082581, 21.11750031], [86.83110809, 21.11721992], [86.83110809, 21.11694527], [86.83139038, 21.11667061], [86.83139038, 21.11610985], [86.83166504, 21.11583328], [86.83166504, 21.11555481], [86.83194733, 21.11527824], [86.83194733, 21.11444092], [86.83222198, 21.11416626], [86.83222198, 21.11333084], [86.83305359, 21.11249924], [86.83304596, 21.11222076], [86.83333588, 21.1119442], [86.83333588, 21.11166763], [86.83361053, 21.11139107], [86.83361053, 21.11083031], [86.83388519, 21.11055565], [86.83389282, 21.11028099], [86.83416748, 21.11000061], [86.83416748, 21.10972023], [86.83444214, 21.10944557], [86.83444214, 21.10888863], [86.83472443, 21.10861206], [86.83472443, 21.10833168], [86.83499908, 21.10805321], [86.83500671, 21.10750008], [86.83472443, 21.10722351], [86.83472443, 21.10666656], [86.83583069, 21.1055603], [86.83583069, 21.10499954], [86.83555603, 21.10471916], [86.83555603, 21.1044445], [86.83583069, 21.10416603], [86.83583069, 21.10333061], [86.83611298, 21.10305595], [86.83611298, 21.10277939], [86.83666992, 21.10222054], [86.83666992, 21.10194397], [86.83694458, 21.1016674], [86.83693695, 21.10056114], [86.83666992, 21.10028076], [86.83666992, 21.09971046], [86.83694458, 21.09944534], [86.83721924, 21.09945107], [86.83750153, 21.09917068], [86.83777618, 21.09917068], [86.8391571, 21.09778023], [86.8391571, 21.09721947], [86.83944702, 21.09694672], [86.83944702, 21.09638977], [86.83972168, 21.09610939], [86.83972168, 21.09583473], [86.83999634, 21.09555626], [86.83999634, 21.09527969], [86.84055328, 21.09472084], [86.84055328, 21.09444237], [86.84083557, 21.0941658], [86.8408432, 21.09390068], [86.84055328, 21.09361267], [86.84055328, 21.09333038], [86.84111023, 21.09277725], [86.84111023, 21.09250259], [86.84166718, 21.09194183], [86.84166718, 21.09166718], [86.84194183, 21.09139252], [86.84194183, 21.09111023], [86.84221649, 21.09083939], [86.84221649, 21.08999825], [86.84249878, 21.08971977], [86.84249878, 21.08916664], [86.84278107, 21.08888817], [86.84278107, 21.08722115], [86.84305573, 21.08694458], [86.84305573, 21.08666611], [86.84333038, 21.08638954], [86.84333038, 21.08611107], [86.84361267, 21.08583069], [86.84361267, 21.08527756], [86.84388733, 21.08500099], [86.84388733, 21.08444023], [86.84361267, 21.08416748], [86.84361267, 21.08389091], [86.84388733, 21.08361053], [86.84388733, 21.08306122], [86.84417725, 21.08278084], [86.84417725, 21.08222008], [86.84388733, 21.08194542], [86.84388733, 21.08166695], [86.84443665, 21.08111], [86.84471893, 21.08111382], [86.84500122, 21.08083153], [86.84527588, 21.08083153], [86.84555817, 21.08055305], [86.84583282, 21.08056068], [86.84805298, 21.07832909], [86.84805298, 21.07805634], [86.84860992, 21.07749939], [86.84860992, 21.07722092], [86.84889221, 21.07694435], [86.84916687, 21.07666588], [86.84916687, 21.07638931], [86.84944153, 21.07611084], [86.84944153, 21.07583046], [86.84972382, 21.0755558], [86.84971619, 21.07527924], [86.85028076, 21.07472038], [86.85028076, 21.07444382], [86.85055542, 21.07416725], [86.85056305, 21.07389069], [86.85083008, 21.07361031], [86.85083008, 21.07332993], [86.85111237, 21.07305527], [86.85111237, 21.07277107], [86.85138702, 21.07250023], [86.85138702, 21.07139015], [86.85221863, 21.07055092], [86.85221863, 21.07027817], [86.8527832, 21.06973076], [86.8527832, 21.06944084], [86.85305786, 21.06916618], [86.85305023, 21.06888962], [86.85333252, 21.06861115], [86.85333252, 21.06833076], [86.85361481, 21.06805611], [86.85360718, 21.06722069], [86.85388947, 21.06694221], [86.85388947, 21.06666756], [86.85444641, 21.06611061], [86.85444641, 21.06555939], [86.85472107, 21.06528282], [86.85472107, 21.06500244], [86.85527802, 21.06444168], [86.85555267, 21.06444359], [86.85583496, 21.06416702], [86.85582733, 21.06360054], [86.85610962, 21.06333351], [86.85610962, 21.06277847], [86.85639191, 21.06249809], [86.85639191, 21.06195068], [86.85666656, 21.0616684], [86.85666656, 21.06138992], [86.85694122, 21.06110954], [86.85694122, 21.06055641], [86.85721588, 21.06027985], [86.85721588, 21.05972099], [86.85694122, 21.05944443], [86.85694122, 21.05888939], [86.85721588, 21.05861092], [86.85721588, 21.05833054], [86.85749817, 21.05805779], [86.85749817, 21.05779076], [86.85778046, 21.05750084], [86.85778046, 21.05694008], [86.85805511, 21.05666733], [86.85806274, 21.05611038], [86.85832977, 21.05611038], [86.85806274, 21.05583], [86.85805511, 21.05555534], [86.85832977, 21.05528069], [86.85832977, 21.05500031], [86.85917664, 21.05417061], [86.85943604, 21.05417061], [86.86055756, 21.0530529], [86.86055756, 21.05277824], [86.86110687, 21.05221939], [86.8611145, 21.05194473], [86.86166382, 21.0513916], [86.86165619, 21.05110931], [86.86222076, 21.0505619], [86.86222076, 21.05028152], [86.86332703, 21.04917145], [86.86360931, 21.04917145], [86.8638916, 21.04888916], [86.86416626, 21.04888916], [86.86611176, 21.04693985], [86.86611176, 21.04638863], [86.86638641, 21.04611015], [86.86638641, 21.04583359], [86.86777496, 21.04444695], [86.86776733, 21.04417038], [86.86833191, 21.04360962], [86.86833191, 21.04305649], [86.86888885, 21.04249954], [86.86888885, 21.04222107], [86.87000275, 21.0411129], [86.87000275, 21.04083061], [86.8702774, 21.04055595], [86.8702774, 21.04027939], [86.87055206, 21.04000282], [86.87055206, 21.03972054], [86.87083435, 21.03944206], [86.87083435, 21.0391674], [86.87111664, 21.03889275], [86.87111664, 21.03861046], [86.8730545, 21.03666687], [86.8730545, 21.0363884], [86.87361145, 21.03582954], [86.87361145, 21.03555489], [86.87388611, 21.03527832], [86.87388611, 21.03499985], [86.87610626, 21.03277969], [86.87610626, 21.03222084], [86.87666321, 21.03166771], [86.87666321, 21.03139114], [86.87722015, 21.03083038], [86.87722015, 21.03027725], [86.87889099, 21.02861023], [86.87917328, 21.02861023], [86.88083649, 21.02694511], [86.88083649, 21.02667046], [86.88111115, 21.02639008], [86.88111115, 21.0261097], [86.8813858, 21.02583122], [86.8813858, 21.02555466], [86.88166809, 21.02527809], [86.88166809, 21.02499962], [86.88249969, 21.02417183], [86.88249969, 21.02388954], [86.88276672, 21.02360916], [86.88276672, 21.02333069], [86.88361359, 21.02249908], [86.88360596, 21.02222061], [86.8841629, 21.02166748], [86.8841629, 21.02139091], [86.88471985, 21.02083015], [86.88471985, 21.0205555], [86.88500214, 21.02028084], [86.88500214, 21.01972008], [86.88527679, 21.01972198], [86.88583374, 21.01916695], [86.88610077, 21.01917076], [86.88889313, 21.01638985], [86.88889313, 21.01610947], [86.88916779, 21.01583481], [86.88916779, 21.01555634], [86.88944244, 21.01527977], [86.88944244, 21.01499939], [86.8897171, 21.01472282], [86.88972473, 21.01416588], [86.89026642, 21.01361275], [86.89026642, 21.01333046], [86.89055634, 21.0130558], [86.89055634, 21.01278114], [86.89083099, 21.01248932], [86.89083099, 21.01194382], [86.89111328, 21.01166725], [86.89111328, 21.01111031], [86.89138794, 21.01083183], [86.89138794, 21.0102787], [86.89167023, 21.00999832], [86.89167023, 21.00945091], [86.89193726, 21.00917053], [86.89193726, 21.00888824], [86.89332581, 21.00749969], [86.89332581, 21.00722122], [86.89360809, 21.00694466], [86.89360809, 21.00666618], [86.89389038, 21.00638962], [86.89389038, 21.00555992], [86.89417267, 21.00527954], [86.89417267, 21.00500107], [86.89444733, 21.00472069], [86.89444733, 21.00444412], [86.89472198, 21.00416756], [86.89472198, 21.00389099], [86.89528656, 21.00333023], [86.89527893, 21.00305557], [86.89554596, 21.00278091], [86.89554596, 21.00250053], [86.89666748, 21.00139046], [86.89666748, 21.00055122], [86.89666748, 21.00027847], [86.89694214, 21.00000191], [86.89749908, 20.99945068], [86.89749908, 20.9991703], [86.89778137, 20.99889183], [86.89778137, 20.99860954], [86.89861298, 20.99777794], [86.89861298, 20.99694061], [86.89888763, 20.99666595], [86.89888763, 20.99611092], [86.89916992, 20.99583054], [86.89916992, 20.99472237], [86.89944458, 20.99444389], [86.89943695, 20.99417114], [86.89971924, 20.99389076], [86.89971924, 20.99333], [86.90000153, 20.99305534], [86.90000153, 20.99278069], [86.90027618, 20.99250031], [86.90027618, 20.99221992], [86.90055847, 20.99194527], [86.90055847, 20.99110985], [86.90067291, 20.99006081], [86.9016571, 20.98890114], [86.90209961, 20.98749733], [86.9023819, 20.98689079], [86.90294647, 20.98669052], [86.90331268, 20.98641968], [86.90331268, 20.9860096], [86.90316772, 20.98486519], [86.90294647, 20.98411942], [86.90345001, 20.98317719], [86.90400696, 20.98311043], [86.90416718, 20.98237038], [86.90416718, 20.97999954], [86.90444183, 20.97972107], [86.90444183, 20.97916794], [86.90499115, 20.97777939], [86.90585327, 20.97662926], [86.90628052, 20.97616005], [86.90663147, 20.97534943], [86.90670776, 20.9743309], [86.90734863, 20.97338867], [86.90734863, 20.97250938], [86.90749359, 20.97122955], [86.90798187, 20.96980286], [86.90847778, 20.96912193], [86.90854645, 20.96858215], [86.90833282, 20.96804237], [86.90805054, 20.96750259], [86.90783691, 20.96696091], [86.90798187, 20.96662521], [86.90904999, 20.96664047], [86.90956116, 20.96628952], [86.90985107, 20.96587944], [86.9101181, 20.96507263], [86.9101181, 20.96345139], [86.9101944, 20.96298027], [86.91026306, 20.96244049], [86.91026306, 20.9617691], [86.9101181, 20.96142769], [86.90985107, 20.96089172], [86.90990448, 20.96035004], [86.91047668, 20.96006966], [86.91104889, 20.95974159], [86.91104889, 20.95927048], [86.9108429, 20.95880127], [86.9108429, 20.95750237], [86.91055298, 20.95722008], [86.91055298, 20.95638847], [86.91028595, 20.95610809], [86.91000366, 20.95611191], [86.91000366, 20.95583344], [86.91055298, 20.9552784], [86.91110992, 20.9552784], [86.91139221, 20.95499992], [86.91166687, 20.95499992], [86.91194153, 20.95471954], [86.91194153, 20.95444489], [86.91249847, 20.95388794], [86.91249847, 20.95360947], [86.91278076, 20.9533329], [86.91278076, 20.95277786], [86.91249847, 20.95249939], [86.91249847, 20.95111084], [86.91361237, 20.95000076], [86.91361237, 20.94972038], [86.91378784, 20.94891739], [86.91378784, 20.94831085], [86.91414642, 20.94750023], [86.91464996, 20.94696236], [86.91514587, 20.94581413], [86.9153595, 20.9448719], [86.91578674, 20.94425964], [86.91657257, 20.94264412], [86.91693115, 20.94129562], [86.91728973, 20.93981171], [86.91779327, 20.93919945], [86.91835785, 20.93893242], [86.9193573, 20.93866348], [86.91999817, 20.93805695], [86.92056274, 20.9375], [86.92055511, 20.93722153], [86.92082977, 20.93694687], [86.92082977, 20.9366703], [86.92056274, 20.93638992], [86.92056274, 20.93583107], [86.92028046, 20.93555641], [86.92028046, 20.93499947], [86.92056274, 20.9347229], [86.92055511, 20.93444443], [86.92082977, 20.93416405], [86.92082977, 20.93388939], [86.92166901, 20.93305969], [86.92166901, 20.93250275], [86.92193604, 20.93222046], [86.92194366, 20.93194389], [86.92222595, 20.93166733], [86.92222595, 20.93111038], [86.92250061, 20.93083191], [86.92250061, 20.93055534], [86.9227829, 20.93028259], [86.9227829, 20.9299984], [86.92305756, 20.92972183], [86.92305756, 20.92861176], [86.92472076, 20.92694473], [86.92472076, 20.92666626], [86.92582703, 20.92555809], [86.92582703, 20.92527008], [86.92610931, 20.92499924], [86.92610931, 20.92472076], [86.9263916, 20.9244442], [86.9263916, 20.92416573], [86.92694092, 20.92361069], [86.92694092, 20.92333031], [86.92722321, 20.92305565], [86.92722321, 20.92278099], [86.92861176, 20.92139053], [86.92861176, 20.92082977], [86.92888641, 20.92055321], [86.92888641, 20.92000008], [86.9291687, 20.9197197], [86.9291687, 20.91944504], [86.93055725, 20.9180603], [86.93055725, 20.91694069], [86.93083191, 20.91666603], [86.93083191, 20.91638947], [86.93110657, 20.91610909], [86.93110657, 20.91556168], [86.93139648, 20.91527748], [86.93139648, 20.91500092], [86.9319458, 20.91444397], [86.9319458, 20.9141674], [86.93250275, 20.91361046], [86.93250275, 20.91333008], [86.9327774, 20.91305542], [86.9327774, 20.91250038], [86.93305206, 20.91222], [86.9327774, 20.91194534], [86.9327774, 20.9113903], [86.93305206, 20.91110992], [86.93305206, 20.91083336], [86.9338913, 20.90999985], [86.9338913, 20.90971947], [86.93416595, 20.90944481], [86.93416595, 20.90916634], [86.93445587, 20.90888977], [86.93444824, 20.9086113], [86.9347229, 20.90833473], [86.93499756, 20.90833473], [86.93499756, 20.9066658], [86.93527985, 20.90639114], [86.93527985, 20.90583038], [86.9355545, 20.90555573], [86.93554688, 20.90528107], [86.93583679, 20.90500259], [86.93583679, 20.90472031], [86.93638611, 20.90416718], [86.93638611, 20.90389252], [86.9366684, 20.90360832], [86.9366684, 20.90332985], [86.93694305, 20.90305519], [86.93694305, 20.90277863], [86.93723297, 20.90249825], [86.93722534, 20.90222168], [86.9375, 20.90194511], [86.9375, 20.90167046], [86.93888855, 20.90027809], [86.93888855, 20.89916992], [86.93860626, 20.89888954], [86.93860626, 20.89861107], [86.93888855, 20.89833069], [86.93888855, 20.89777756], [86.9383316, 20.89722061], [86.9383316, 20.89694595], [86.9394455, 20.89583588], [86.9394455, 20.8955555], [86.93972015, 20.89529037], [86.94082642, 20.89306068], [86.94108582, 20.89232063], [86.94129944, 20.89145088], [86.94165802, 20.89097023], [86.94237518, 20.89016151], [86.9430542, 20.88972282], [86.94416809, 20.88861084], [86.94416809, 20.88833046], [86.94444275, 20.8880558], [86.94444275, 20.88777924], [86.94452667, 20.8868103], [86.94460297, 20.88626862], [86.94474792, 20.8853302], [86.9451828, 20.88479042], [86.94589233, 20.8841095], [86.94645691, 20.88323402], [86.94681549, 20.88242531], [86.94682312, 20.88167953], [86.94689178, 20.88114357], [86.94745636, 20.88040161], [86.94810486, 20.88019753], [86.94860077, 20.87985992], [86.94895935, 20.87925339], [86.94966888, 20.87851143], [86.95002747, 20.87790489], [86.95083618, 20.87722015], [86.95166779, 20.87638855], [86.95166779, 20.87610817], [86.95194244, 20.87583351], [86.95194244, 20.87555504], [86.95276642, 20.87471962], [86.95277405, 20.87444496], [86.95333099, 20.87388992], [86.95305634, 20.87360954], [86.95305634, 20.87305641], [86.95361328, 20.87249947], [86.95361328, 20.87222099], [86.95417023, 20.87166786], [86.95417023, 20.87083054], [86.95583344, 20.86916733], [86.95582581, 20.86833], [86.95777893, 20.86638832], [86.95777893, 20.86610985], [86.95805359, 20.86583138], [86.95805359, 20.86555481], [86.95888519, 20.86471939], [86.95888519, 20.86444473], [86.95916748, 20.86416626], [86.95916748, 20.8638916], [86.95944214, 20.86360931], [86.95944214, 20.86249924], [86.9597168, 20.86222076], [86.95972443, 20.8619442], [86.95999908, 20.86166573], [86.95999908, 20.86111069], [86.96028137, 20.86083031], [86.96028137, 20.86055565], [86.96055603, 20.86027908], [86.96055603, 20.85972023], [86.96083069, 20.85944366], [86.96083069, 20.8591671], [86.96055603, 20.85889053], [86.96138, 20.85806084], [86.96138, 20.85778046], [86.96166992, 20.85750008], [86.96166992, 20.85639], [86.96193695, 20.85612106], [86.96193695, 20.85472107], [86.96221924, 20.8544445], [86.96225739, 20.85354996], [86.96253967, 20.85280609], [86.96253967, 20.85098267], [86.96282196, 20.85031128], [86.96325684, 20.84922981], [86.96339417, 20.84801674], [86.96353912, 20.84707069], [86.96368408, 20.84612656], [86.96396637, 20.84504128], [86.96453857, 20.84390068], [86.9647522, 20.84289169], [86.96517944, 20.84193993], [86.9653244, 20.84079742], [86.96533203, 20.83971977], [86.96553802, 20.83910942], [86.96575165, 20.8379612], [86.96553802, 20.83721924], [86.9659729, 20.83641052], [86.96639252, 20.83539963], [86.96681976, 20.83466148], [86.96695709, 20.83337021], [86.96717834, 20.83256531], [86.96775055, 20.83128166], [86.9681778, 20.83067322], [86.96868134, 20.8300705], [86.96897125, 20.82925987], [86.96944427, 20.82833481], [86.97000122, 20.82777786], [86.97000122, 20.82639122], [86.97027588, 20.82611275], [86.97027588, 20.82332993], [86.97000122, 20.82305527], [86.97000122, 20.82195091], [86.96971893, 20.82167053], [86.96971893, 20.82138824], [86.96943665, 20.82110977], [86.96944427, 20.82027626], [86.96916962, 20.82000923], [86.96916962, 20.81944084], [86.96888733, 20.81916618], [86.96888733, 20.81888962], [86.96861267, 20.81861115], [86.96861267, 20.81805992], [86.96833038, 20.81777954], [86.96833038, 20.81666946], [86.96806335, 20.81639099], [86.96806335, 20.81583023], [86.96778107, 20.81555557], [86.96778107, 20.81472015], [86.96749878, 20.81444168], [86.96749878, 20.81388855], [86.96722412, 20.81361389], [86.96722412, 20.81222343], [86.96694183, 20.81194496], [86.96694183, 20.81081963], [86.96666718, 20.81055641], [86.96666718, 20.80861092], [86.96639252, 20.80833054], [86.96639252, 20.80750084], [86.96611023, 20.80722046], [86.96611023, 20.80500031], [86.9658432, 20.80471992], [86.96583557, 20.80361176], [86.96555328, 20.80333328], [86.96555328, 20.80277824], [86.96527863, 20.80249977], [86.96466827, 20.80175018], [86.96466827, 20.80025864], [86.96472168, 20.79916573], [86.96472168, 20.79805946], [86.96443939, 20.7977829], [86.96472168, 20.79750252], [86.96443939, 20.79722023], [86.96444702, 20.7966671], [86.96414948, 20.79638863], [86.96414948, 20.79527855], [86.96389008, 20.79499817], [86.96389008, 20.7947197], [86.96416473, 20.79444504], [86.96414948, 20.79417038], [86.96389008, 20.79388809], [86.96389008, 20.79360962], [86.96360779, 20.79333305], [86.96360779, 20.79249954], [86.96333313, 20.79222107], [86.96333313, 20.79166794], [86.96305847, 20.79138947], [86.96305847, 20.79111099], [86.96277618, 20.79083061], [86.96277618, 20.79055405], [86.96260834, 20.7903862], [86.96250153, 20.79027748], [86.96250153, 20.79000092], [86.96221924, 20.78971291], [86.96221924, 20.78944588], [86.96111298, 20.7883358], [86.96111298, 20.78805542], [86.95804596, 20.78500175], [86.95777893, 20.78500175], [86.95749664, 20.78471947], [86.95722198, 20.78500175], [86.95639038, 20.78500175], [86.95582581, 20.78443909], [86.95556641, 20.78443909], [86.95471954, 20.78528023], [86.95444489, 20.78527832], [86.95417023, 20.78555489], [86.95388794, 20.78555489], [86.95333099, 20.78611374], [86.95276642, 20.78611183], [86.95249939, 20.7863903], [86.95194244, 20.7863903], [86.95166779, 20.78667068], [86.95111084, 20.78666687], [86.95083618, 20.78694534], [86.95055389, 20.78694534], [86.95027924, 20.78722382], [86.94917297, 20.78722], [86.94889069, 20.78750038], [86.94805908, 20.78750038], [86.94777679, 20.78778076], [86.94721985, 20.78778076], [86.94695282, 20.78806114], [86.9466629, 20.78805542], [86.94638824, 20.7883358], [86.94555664, 20.78833008], [86.94527435, 20.78861046], [86.94473267, 20.78861046], [86.94444275, 20.78889084], [86.9438858, 20.78889084], [86.94361115, 20.78917122], [86.9430542, 20.7891674], [86.94277954, 20.78944588], [86.9422226, 20.78944588], [86.94194794, 20.78972244], [86.94026947, 20.78971291], [86.94000244, 20.79000092], [86.93972015, 20.79000092], [86.93945313, 20.79027939], [86.93527985, 20.79027939], [86.93499756, 20.79055977], [86.93333435, 20.79055405], [86.93305206, 20.79083252], [86.93083191, 20.79083252], [86.93055725, 20.79055405], [86.92973328, 20.79055977], [86.92944336, 20.79027939], [86.9291687, 20.79027939], [86.92888641, 20.79055977], [86.92583466, 20.79055405], [86.92555237, 20.79083252], [86.92527771, 20.79083252], [86.92500305, 20.79055405], [86.92388916, 20.79055405], [86.9236145, 20.79083252], [86.92166901, 20.79083252], [86.92138672, 20.79055405], [86.92111206, 20.79055405], [86.92082977, 20.79083252], [86.91944122, 20.79083061], [86.91916656, 20.79111099], [86.91805267, 20.79111099], [86.91777802, 20.79138947], [86.91694641, 20.79138947], [86.91665649, 20.79166985], [86.91583252, 20.79166794], [86.91555786, 20.7919445], [86.91500092, 20.7919445], [86.91471863, 20.79222298], [86.90999603, 20.79222107], [86.90972137, 20.79249954], [86.90305328, 20.79249954], [86.90277863, 20.79277992], [86.90249634, 20.79277992], [86.90222168, 20.7930603], [86.9016571, 20.7930603], [86.90110016, 20.79249954], [86.90055847, 20.79249954], [86.90027618, 20.79277992], [86.89833069, 20.79277992], [86.89805603, 20.7930603], [86.89666748, 20.79305649], [86.89638519, 20.79333305], [86.89499664, 20.79333305], [86.89472198, 20.79361153], [86.89417267, 20.79360962], [86.89389038, 20.79388809], [86.89332581, 20.79388809], [86.89305878, 20.79417038], [86.89193726, 20.79417038], [86.89167023, 20.79445076], [86.89055634, 20.79445076], [86.89026642, 20.79417038], [86.88944244, 20.79417038], [86.88916016, 20.79445076], [86.88833618, 20.79444504], [86.88805389, 20.7947216], [86.88722229, 20.7947197], [86.88694763, 20.79499817], [86.88639069, 20.79499817], [86.88610077, 20.79527855], [86.88582611, 20.79527855], [86.88555908, 20.79556084], [86.88527679, 20.79556084], [86.88500214, 20.79583931], [86.88471985, 20.79583359], [86.88444519, 20.79611015], [86.8841629, 20.79610825], [86.88388824, 20.79638863], [86.88360596, 20.79638863], [86.8833313, 20.79667282], [86.88305664, 20.7966671], [86.88277435, 20.79694366], [86.88222504, 20.79694366], [86.88194275, 20.79722023], [86.88166809, 20.79722023], [86.8813858, 20.79750252], [86.87944794, 20.79638863], [86.87917328, 20.79638863], [86.87889099, 20.79610825], [86.87808228, 20.79610825], [86.8769455, 20.79611015], [86.87666321, 20.79583359], [86.87638855, 20.79583931], [86.87610626, 20.79556084], [86.8758316, 20.79556084], [86.87555695, 20.79527855], [86.87361145, 20.79527855], [86.87333679, 20.79499817], [86.87277985, 20.79499817], [86.87249756, 20.7947197], [86.87166595, 20.7947216], [86.8713913, 20.79444504], [86.87068176, 20.79445076], [86.87055206, 20.79445076], [86.8702774, 20.79417038], [86.86972046, 20.79417038], [86.8694458, 20.79388809], [86.86860657, 20.79388809], [86.86833191, 20.79360962], [86.86805725, 20.79361153], [86.86798096, 20.79353714], [86.86777496, 20.79333305], [86.86750031, 20.79333305], [86.86722565, 20.79305649], [86.8666687, 20.7930603], [86.86638641, 20.79277992], [86.86611176, 20.79277992], [86.8658371, 20.79249954], [86.86528015, 20.79249954], [86.86499023, 20.79222107], [86.86444092, 20.79222298], [86.86416626, 20.7919445], [86.8638916, 20.7919445], [86.86360931, 20.79166794], [86.86332703, 20.79166985], [86.86277771, 20.79111099], [86.86250305, 20.79111099], [86.86222076, 20.79083061], [86.86194611, 20.79083252], [86.86138916, 20.79027748], [86.86110687, 20.79027939], [86.86083221, 20.79000092], [86.86055756, 20.79000092], [86.8602829, 20.78971291], [86.86000061, 20.78972244], [86.85944366, 20.7891674], [86.85917664, 20.78917122], [86.85806274, 20.78806114], [86.85778046, 20.78806114], [86.85721588, 20.78750038], [86.85694122, 20.78750038], [86.85666656, 20.78722], [86.85610962, 20.78722382], [86.85527802, 20.7863884], [86.85500336, 20.7863903], [86.8548584, 20.78624916], [86.85472107, 20.78611374], [86.85444641, 20.78611374], [86.85434723, 20.78601456], [86.85416412, 20.78583145], [86.85388947, 20.78583145], [86.85361481, 20.78555489], [86.85333252, 20.78555489], [86.85305786, 20.78527832], [86.8527832, 20.78528023], [86.85221863, 20.78471947], [86.85194397, 20.78471947], [86.85138702, 20.78416634], [86.85111237, 20.78417015], [86.85083008, 20.78390121], [86.85056305, 20.78417015], [86.85028076, 20.78390121], [86.84999084, 20.78390121], [86.84916687, 20.78306007], [86.8483429, 20.78306007], [86.84777832, 20.78249931], [86.84749603, 20.78249931], [86.84722137, 20.78222084], [86.84694672, 20.78222275], [86.84684753, 20.78212738], [86.84666443, 20.78194427], [86.84638977, 20.78194427], [86.84625244, 20.78180885], [86.84610748, 20.7816658], [86.84555817, 20.78166771], [86.84527588, 20.78138924], [86.84500122, 20.78138924], [86.84471893, 20.78111076], [86.84416962, 20.78111076], [86.84388733, 20.7808342], [86.84361267, 20.78083992], [86.84333038, 20.78055954], [86.84278107, 20.78055954], [86.84249878, 20.78028107], [86.84221649, 20.78028107], [86.84194183, 20.78000069], [86.84139252, 20.78000069], [86.84111023, 20.77972031], [86.84083557, 20.77972221], [86.84055328, 20.77944374], [86.84027863, 20.77944374], [86.83999634, 20.77916718], [86.83944702, 20.77917099], [86.83889008, 20.77861023], [86.83860779, 20.77861023], [86.83833313, 20.77832985], [86.83805847, 20.77833366], [86.83777618, 20.77805519], [86.83721924, 20.77806091], [86.83693695, 20.777771], [86.83666992, 20.77777863], [86.83638763, 20.77750015], [86.83611298, 20.77750015], [86.83583069, 20.77721977], [86.83555603, 20.77722168], [86.83528137, 20.77694511], [86.83500671, 20.77695084], [86.8347168, 20.77667046], [86.83444214, 20.77667046], [86.83389282, 20.7761116], [86.83333588, 20.77555084], [86.83305359, 20.77555466], [86.83249664, 20.77499962], [86.83222198, 20.77499962], [86.83139038, 20.77416992], [86.83110809, 20.77416992], [86.83082581, 20.77388954], [86.83055878, 20.77388954], [86.83027649, 20.77361107], [86.83027649, 20.77333069], [86.82971954, 20.77277756], [86.82943726, 20.77277946], [86.82917023, 20.7725029], [86.82888031, 20.7725029], [86.82805634, 20.77166939], [86.82776642, 20.77166939], [86.82485962, 20.76874924], [86.82195282, 20.76583099], [86.82194519, 20.76555634], [86.82157135, 20.7651844], [86.8208313, 20.76444435], [86.8208313, 20.76416779], [86.82055664, 20.76389122], [86.82055664, 20.76361084], [86.82000732, 20.76305962], [86.82000732, 20.7627697], [86.8188858, 20.76166725], [86.8188858, 20.76139069], [86.81804657, 20.76056099], [86.81804657, 20.76028061], [86.81777954, 20.76000023], [86.81777954, 20.75972939], [86.81749725, 20.75945091], [86.81749725, 20.75917053], [86.8172226, 20.75889015], [86.8172226, 20.75832939], [86.81694794, 20.75805473], [86.81694794, 20.7575016], [86.81667328, 20.75721931], [86.81666565, 20.75694466], [86.81639099, 20.75666618], [86.81639099, 20.75639153], [86.8161087, 20.75610924], [86.8161087, 20.75444031], [86.81583405, 20.75416756], [86.81582642, 20.75360107], [86.81555176, 20.75333405], [86.81555176, 20.75305557], [86.81532288, 20.75282097], [86.8152771, 20.75250053], [86.81500244, 20.75222015], [86.81500244, 20.75138855], [86.81472015, 20.75111008], [86.81472015, 20.75083351], [86.8133316, 20.74944687], [86.8133316, 20.7491703], [86.81305695, 20.74888992], [86.81305695, 20.74860954], [86.81277466, 20.74833488], [86.81277466, 20.74805641], [86.81356049, 20.7462101], [86.81369781, 20.74588776], [86.81412506, 20.74494362], [86.8146286, 20.74372864], [86.81576538, 20.74420166], [86.81666565, 20.74444389], [86.81694031, 20.74444008], [86.81749725, 20.74500275], [86.81777954, 20.74500275], [86.81861115, 20.74417114], [86.81861115, 20.74389267], [86.81833649, 20.74361038], [86.81861115, 20.74332809], [86.81861115, 20.74027634], [86.81833649, 20.73999977], [86.81833649, 20.73859978], [86.8180542, 20.73833275], [86.81807709, 20.7378006], [86.81778717, 20.73624039], [86.81771088, 20.73496246], [86.81771088, 20.73347664], [86.81742859, 20.73266983], [86.81749725, 20.73110962], [86.81749725, 20.72999954], [86.8172226, 20.72971916], [86.8172226, 20.7294445], [86.81694794, 20.72916603], [86.81694031, 20.72889137], [86.81667328, 20.72860909], [86.81666565, 20.72833252], [86.81639099, 20.72805595], [86.81639099, 20.72722054], [86.8161087, 20.72694397], [86.8161087, 20.72611046], [86.81639099, 20.72583008], [86.8161087, 20.72555542], [86.8161087, 20.72442055], [86.8161087, 20.7238884], [86.81555176, 20.72332954], [86.81555176, 20.72277832], [86.8152771, 20.72249985], [86.8152771, 20.72221947], [86.81500244, 20.72194481], [86.81500244, 20.72166634], [86.81416321, 20.72083282], [86.81388855, 20.72083473], [86.81361389, 20.72055626], [86.8133316, 20.72056007], [86.81305695, 20.72027969], [86.81276703, 20.72027969], [86.80665588, 20.71417046], [86.80665588, 20.71388817], [86.8033371, 20.71055984], [86.80207825, 20.70965958], [86.80136108, 20.70885468], [86.80065155, 20.70777321], [86.80014801, 20.70656013], [86.79972076, 20.7052803], [86.79972076, 20.70471954], [86.79916382, 20.70416641], [86.79915619, 20.70389175], [86.79860687, 20.70332909], [86.7986145, 20.70305634], [86.79805756, 20.70248985], [86.79805756, 20.70222282], [86.79722595, 20.70138741], [86.79722595, 20.70111084], [86.79638672, 20.70028114], [86.79638672, 20.70000076], [86.7958374, 20.69943047], [86.79582977, 20.69916725], [86.79556274, 20.69889069], [86.79556274, 20.69861031], [86.79499817, 20.69805527], [86.79499817, 20.69778061], [86.79444122, 20.69721985], [86.79444122, 20.69666672], [86.79416656, 20.69639015], [86.79416656, 20.69610977], [86.79389191, 20.69583321], [86.79389191, 20.69555473], [86.79360962, 20.69527817], [86.79360962, 20.69499969], [86.79332733, 20.69472122], [86.79333496, 20.69416618], [86.79305267, 20.69388962], [86.79305267, 20.69333076], [86.79277802, 20.69305611], [86.79277802, 20.69277954], [86.79250336, 20.69250107], [86.79250336, 20.69194031], [86.79222107, 20.69166756], [86.79222107, 20.6913929], [86.79194641, 20.69111252], [86.79194641, 20.69055176], [86.79166412, 20.6902771], [86.79165649, 20.69000244], [86.79138947, 20.68971825], [86.79138947, 20.68944359], [86.79111481, 20.68916702], [86.79110718, 20.68860817], [86.79083252, 20.68833351], [86.79083252, 20.68805504], [86.79055786, 20.68778038], [86.79055786, 20.68721962], [86.79027557, 20.68694496], [86.7902832, 20.6866703], [86.79000092, 20.68638992], [86.79000092, 20.68583107], [86.78971863, 20.68555641], [86.789711, 20.68527985], [86.78943634, 20.68499947], [86.78943634, 20.68445015], [86.78916931, 20.68416977], [86.78916931, 20.68388939], [86.78888702, 20.68361092], [86.78888702, 20.68305969], [86.78861237, 20.68278122], [86.78861237, 20.68250084], [86.78833008, 20.68222046], [86.78833008, 20.68138885], [86.78806305, 20.68111038], [86.78805542, 20.68083382], [86.78833008, 20.68055534], [86.78833008, 20.68028069], [86.78861237, 20.68000031], [86.78861237, 20.67861176], [86.78888702, 20.67833138], [86.78888702, 20.67805481], [86.78861237, 20.67777824], [86.78861237, 20.67721939], [86.78833008, 20.67694473], [86.78833008, 20.67666626], [86.78861237, 20.6763916], [86.78861237, 20.67528152], [86.78833008, 20.67499924], [86.78833008, 20.67472076], [86.78805542, 20.6744442], [86.78805542, 20.67416573], [86.78778076, 20.67388916], [86.78778076, 20.67361069], [86.78749847, 20.67333031], [86.78749847, 20.67277718], [86.78721619, 20.67250824], [86.78721619, 20.67222023], [86.78694153, 20.67194366], [86.78694153, 20.67166519], [86.78610992, 20.67082977], [86.78610992, 20.67055511], [86.78555298, 20.67000008], [86.78555298, 20.66945076], [86.78499603, 20.66889], [86.78499603, 20.66860962], [86.78444672, 20.66805649], [86.78444672, 20.66777992], [86.7838974, 20.66722107], [86.78388977, 20.66666603], [86.78360748, 20.66638184], [86.78360748, 20.6661129], [86.78277588, 20.66527939], [86.78277588, 20.66500282], [86.78083801, 20.66306114], [86.78083801, 20.66278076], [86.77971649, 20.66167068], [86.77944183, 20.66167068], [86.77861023, 20.66082954], [86.77833557, 20.66083336], [86.77805328, 20.66055489], [86.77777863, 20.66055489], [86.77500153, 20.65777779], [86.77500153, 20.65751076], [86.77471161, 20.65722084], [86.77471924, 20.65694427], [86.77388763, 20.65611076], [86.77388763, 20.65583038], [86.77278137, 20.65472221], [86.77278137, 20.65444565], [86.77222443, 20.6538887], [86.7722168, 20.65361023], [86.77194214, 20.65332985], [86.77194214, 20.65305519], [86.77166748, 20.65278053], [86.77166748, 20.65250015], [86.77083588, 20.65167046], [86.77083588, 20.65137863], [86.77027893, 20.65083122], [86.77027893, 20.65055466], [86.76999664, 20.65027809], [86.76999664, 20.64971924], [86.76833344, 20.64805603], [86.76832581, 20.64777756], [86.76805878, 20.64749908], [86.76805878, 20.64722061], [86.76777649, 20.64694405], [86.76777649, 20.64666748], [86.76750183, 20.64639091], [86.76750183, 20.64611053], [86.76721954, 20.64583015], [86.76721954, 20.64527512], [86.76693726, 20.64500046], [86.76693726, 20.64472008], [86.76667023, 20.64444351], [86.76667023, 20.63944435], [86.76638794, 20.63916588], [86.76638794, 20.63694191], [86.76618958, 20.63487434], [86.76597595, 20.63224411], [86.76583862, 20.63008499], [86.76541138, 20.62799072], [86.7650528, 20.62650871], [86.76416779, 20.62471962], [86.76416779, 20.62444496], [86.76361084, 20.62389183], [86.76361084, 20.62360954], [86.76249695, 20.62249947], [86.76249695, 20.62221909], [86.76194763, 20.62166595], [86.76194763, 20.62111092], [86.76139069, 20.62055969], [86.76139069, 20.62028122], [86.76055908, 20.61944008], [86.76055908, 20.61916733], [86.75972748, 20.61833], [86.75944519, 20.61833382], [86.75805664, 20.61694527], [86.75776672, 20.61695099], [86.75749969, 20.61667061], [86.75723267, 20.61667061], [86.75694275, 20.61639023], [86.7563858, 20.61639023], [86.75624847, 20.61624908], [86.75611115, 20.61610985], [86.75583649, 20.61611176], [86.75577545, 20.61449242], [86.75569916, 20.61388206], [86.75569916, 20.61334419], [86.75741577, 20.61355019], [86.75805664, 20.61388969], [86.7583313, 20.61417007], [86.75888824, 20.61416626], [86.7591629, 20.61444473], [86.75971985, 20.61444473], [86.76000214, 20.6147213], [86.76027679, 20.61471939], [86.76055908, 20.61499977], [86.76083374, 20.61499977], [86.7611084, 20.61527824], [86.76139069, 20.61527824], [86.76166534, 20.61555481], [86.76194763, 20.61555099], [86.76277161, 20.61639023], [86.76304626, 20.61639023], [86.76333618, 20.61667061], [86.76361084, 20.61667061], [86.76389313, 20.61695099], [86.76416779, 20.61695099], [86.76583099, 20.61861038], [86.76583099, 20.61889076], [86.76750183, 20.62055588], [86.76750183, 20.62083054], [86.76777649, 20.62111092], [86.76777649, 20.62138748], [86.76860809, 20.62221909], [86.76860809, 20.62249947], [86.76889038, 20.62277985], [86.76889038, 20.62333107], [86.76917267, 20.62360954], [86.76917267, 20.6241703], [86.76944733, 20.62444496], [86.76944733, 20.62471962], [86.76999664, 20.62527847], [86.76999664, 20.6258297], [86.77083588, 20.62667084], [86.77083588, 20.62750053], [86.77111053, 20.62778091], [86.77111053, 20.62805557], [86.77138519, 20.62833595], [86.77139282, 20.62972069], [86.77166748, 20.62999916], [86.77166748, 20.63027], [86.77194214, 20.63055992], [86.77194214, 20.63166618], [86.77166748, 20.63194466], [86.77194214, 20.63222122], [86.77194214, 20.63277626], [86.77222443, 20.63305473], [86.7722168, 20.63360977], [86.77194214, 20.63388824], [86.77194214, 20.63444519], [86.77166748, 20.63471985], [86.77166748, 20.63528061], [86.77138519, 20.63555527], [86.77139282, 20.63582993], [86.77111053, 20.6361084], [86.77166748, 20.63666725], [86.77166748, 20.63722038], [86.77139282, 20.63750267], [86.77166748, 20.63778114], [86.77166748, 20.6380558], [86.77139282, 20.63833046], [86.77139282, 20.63889122], [86.77153015, 20.64017105], [86.77138519, 20.64166641], [86.77111053, 20.64194489], [86.77111053, 20.64221001], [86.77194214, 20.64305687], [86.77194214, 20.64361], [86.7722168, 20.64389038], [86.7722168, 20.64417076], [86.77305603, 20.64500046], [86.77333069, 20.64500046], [86.77361298, 20.64528084], [86.77555847, 20.64528084], [86.77583313, 20.64557076], [86.77722168, 20.64557076], [86.77749634, 20.64528084], [86.77916718, 20.64528084], [86.77944183, 20.64500046], [86.77999878, 20.64500046], [86.78056335, 20.6444397], [86.78083038, 20.64444351], [86.78111267, 20.64416695], [86.78138733, 20.64417076], [86.78193665, 20.64361], [86.78194427, 20.64333344], [86.78221893, 20.64305687], [86.78250122, 20.64306068], [86.78277588, 20.6427803], [86.78305817, 20.6427784], [86.78324127, 20.64296341], [86.78360748, 20.64333344], [86.78416443, 20.6427784], [86.78472137, 20.6427803], [86.78499603, 20.64306068], [86.78555298, 20.64305687], [86.78583527, 20.64333344], [86.78833008, 20.64333344], [86.78861237, 20.64361191], [86.79055786, 20.64361], [86.79083252, 20.64389038], [86.79110718, 20.64389038], [86.79138947, 20.64417076], [86.79166412, 20.64416695], [86.79187012, 20.64436913], [86.79194641, 20.64444351], [86.79250336, 20.6444397], [86.79305267, 20.64500046], [86.79416656, 20.64500046], [86.79444122, 20.64528084], [86.79499817, 20.64528084], [86.79528046, 20.64500046], [86.79722595, 20.64500046], [86.79750061, 20.64472008], [86.79777527, 20.64472198], [86.79805756, 20.64444351], [86.7986145, 20.64444351], [86.79916382, 20.64388847], [86.79973602, 20.64394379], [86.79988098, 20.64390755], [86.8001709, 20.64383888], [86.80062866, 20.6437397], [86.80116272, 20.64381027], [86.80171967, 20.64385033], [86.80231476, 20.64386177], [86.80291748, 20.64387131], [86.80350494, 20.64387321], [86.80405426, 20.64384842], [86.80452728, 20.64376068], [86.80497742, 20.64362907], [86.80555725, 20.64361], [86.80583191, 20.64333344], [86.8069458, 20.64333344], [86.80722046, 20.64305687], [86.80750275, 20.64306068], [86.8077774, 20.6427803], [86.80805206, 20.6427803], [86.80860901, 20.64221001], [86.8088913, 20.64222145], [86.80999756, 20.64111137], [86.80999756, 20.64083481], [86.81027985, 20.64055634], [86.81027985, 20.64027977], [86.81083679, 20.63972282], [86.81083679, 20.63944435], [86.81111145, 20.63916588], [86.81134033, 20.63888168], [86.8117218, 20.63856316], [86.81212616, 20.63824654], [86.81254578, 20.6379509], [86.81297302, 20.63764954], [86.81344604, 20.63739586], [86.81396484, 20.63713074], [86.81459808, 20.63686943], [86.81524658, 20.63661194], [86.81552887, 20.6364727], [86.81587219, 20.63640022], [86.81636047, 20.63635445], [86.81687927, 20.63645935], [86.81731415, 20.63668442], [86.81771851, 20.63694191], [86.81816101, 20.63722038], [86.81861115, 20.63754082], [86.81903839, 20.63791084], [86.81945038, 20.63832092], [86.81985474, 20.63874817], [86.82022858, 20.6391716], [86.82055664, 20.63958359], [86.8208313, 20.63997269], [86.82105255, 20.64035034], [86.8212204, 20.64074707], [86.82142639, 20.64112663], [86.82164764, 20.64147949], [86.82187653, 20.64183807], [86.82211304, 20.64217949], [86.82227325, 20.64253044], [86.82242584, 20.64286995], [86.82254791, 20.64322853], [86.82267761, 20.64359283], [86.82279968, 20.64397621], [86.82290649, 20.6443882], [86.82301331, 20.64487839], [86.82306671, 20.64541054], [86.82306671, 20.64597511], [86.82298279, 20.64651108], [86.82283783, 20.64703178], [86.82264709, 20.64749908], [86.82247162, 20.64793587], [86.82229614, 20.64834023], [86.82216644, 20.64874268], [86.822052, 20.64912033], [86.82190704, 20.64946747], [86.82177734, 20.64977837], [86.82162476, 20.6500473], [86.82147217, 20.65030098], [86.82131958, 20.6505661], [86.82115173, 20.6508007], [86.82097626, 20.6510601], [86.82083893, 20.65133286], [86.8207016, 20.65160179], [86.82057953, 20.65190125], [86.82047272, 20.6522007], [86.82034302, 20.65249252], [86.82021332, 20.65278053], [86.82006836, 20.65304947], [86.81991577, 20.65335464], [86.81970215, 20.6536808], [86.81942749, 20.6540699], [86.81909943, 20.65454102], [86.81877136, 20.65510368], [86.81848145, 20.65571976], [86.81819153, 20.65631104], [86.81794739, 20.65683937], [86.81772614, 20.65732956], [86.81751251, 20.65777969], [86.81730652, 20.65824127], [86.81710815, 20.65871429], [86.81694031, 20.65921021], [86.81677246, 20.65975189], [86.81656647, 20.66027641], [86.81630707, 20.6607399], [86.81601715, 20.66114998], [86.81574249, 20.66151047], [86.81547546, 20.66187859], [86.81521606, 20.66224289], [86.81495667, 20.66261101], [86.81468201, 20.66294861], [86.81439972, 20.66331482], [86.81408691, 20.66365814], [86.81373596, 20.66396713], [86.81334686, 20.66422081], [86.81299591, 20.66451263], [86.81265259, 20.66483116], [86.81226349, 20.66513252], [86.81185913, 20.66540146], [86.81147766, 20.66573906], [86.8110733, 20.66609955], [86.81060791, 20.66643524], [86.81013489, 20.66676331], [86.80961609, 20.66703033], [86.80912018, 20.66727066], [86.8086319, 20.66750145], [86.80817413, 20.66774368], [86.80771637, 20.66798019], [86.80724335, 20.66819954], [86.80666351, 20.66833305], [86.80638885, 20.66861153], [86.80610657, 20.66860962], [86.80583191, 20.66889], [86.80500031, 20.66889], [86.80473328, 20.66917038], [86.80361176, 20.66917038], [86.8033371, 20.66889], [86.80194092, 20.66889], [86.80180359, 20.66875076], [86.80166626, 20.66861153], [86.8013916, 20.66861153], [86.80097198, 20.66819572], [86.80055237, 20.66777802], [86.80055237, 20.66749954], [86.79915619, 20.6661129], [86.79915619, 20.66583061], [86.79869843, 20.66535759], [86.79837036, 20.66505051], [86.79802704, 20.6648407], [86.7976532, 20.66476059], [86.79727173, 20.66480064], [86.79695892, 20.66493797], [86.79672241, 20.66519928], [86.79650879, 20.66557121], [86.7963028, 20.66604996], [86.79618073, 20.66666985], [86.79612732, 20.66736984], [86.79613495, 20.66810036], [86.79621124, 20.66883278], [86.79638672, 20.66953087], [86.7966156, 20.67018509], [86.79686737, 20.67074013], [86.79709625, 20.67123985], [86.79733276, 20.67168045], [86.79762268, 20.67208099], [86.79795837, 20.67250633], [86.79831696, 20.67287254], [86.7986908, 20.67311859], [86.79907227, 20.67337036], [86.79946136, 20.6736908], [86.79988861, 20.6740284], [86.80039978, 20.67435455], [86.8010025, 20.67466354], [86.80164337, 20.67494965], [86.80223846, 20.67521095], [86.80285645, 20.67538071], [86.80345917, 20.67547035], [86.80397797, 20.67547035], [86.80444336, 20.67551804], [86.80484772, 20.67555046], [86.8052597, 20.67561913], [86.80568695, 20.6757412], [86.80618286, 20.67578125], [86.80648041, 20.67576218], [86.80665588, 20.67575073], [86.8070755, 20.67566872], [86.80745697, 20.67560005], [86.80782318, 20.67562866], [86.80818939, 20.6757412], [86.80860138, 20.67579079], [86.80905914, 20.67580032], [86.80950928, 20.67579079], [86.80995178, 20.67575073], [86.81040192, 20.67567062], [86.81080627, 20.6757412], [86.81125641, 20.67579079], [86.81171417, 20.67580223], [86.81217194, 20.67579651], [86.81262207, 20.67579079], [86.81304932, 20.67578125], [86.8134613, 20.67572975], [86.81385803, 20.67562675], [86.81427002, 20.6756115], [86.81469727, 20.67569351], [86.81512451, 20.67568207], [86.8155365, 20.6756115], [86.81596375, 20.6756115], [86.81639862, 20.67556763], [86.81685638, 20.67554092], [86.81735229, 20.67551994], [86.81784821, 20.67546082], [86.81830597, 20.67534065], [86.81881714, 20.67528152], [86.81936646, 20.67525101], [86.81993866, 20.67518997], [86.82047272, 20.6750412], [86.82099915, 20.67493057], [86.82150269, 20.67477036], [86.82202148, 20.67464828], [86.82253265, 20.67448997], [86.82308197, 20.67437935], [86.82360077, 20.6742382], [86.82411194, 20.67410851], [86.82457733, 20.67394066], [86.8250885, 20.67381859], [86.82559204, 20.67366028], [86.82611847, 20.6735363], [86.82660675, 20.67332077], [86.82710266, 20.67304993], [86.82758331, 20.67278099], [86.82805634, 20.67252159], [86.82853699, 20.67226982], [86.82897186, 20.67198181], [86.82939911, 20.67169952], [86.82982635, 20.67141914], [86.83024597, 20.67114067], [86.83067322, 20.6708107], [86.83110046, 20.67044258], [86.83153534, 20.67004395], [86.83200836, 20.6696434], [86.83246613, 20.66921043], [86.83291626, 20.66873741], [86.83331299, 20.66822815], [86.83370209, 20.6677475], [86.83409119, 20.66737938], [86.83441162, 20.66703987], [86.83463287, 20.66673279], [86.83474731, 20.6664505], [86.83487701, 20.66621017], [86.83502197, 20.66596031], [86.83518982, 20.66571236], [86.83531952, 20.66542244], [86.83547211, 20.66514778], [86.83560181, 20.66484833], [86.83574677, 20.66456032], [86.83586884, 20.66424942], [86.83600616, 20.66395569], [86.83608246, 20.66365051], [86.83612061, 20.66333771], [86.83615875, 20.66303062], [86.83627319, 20.66275978], [86.83641052, 20.66244125], [86.83659363, 20.66205788], [86.8367691, 20.66152763], [86.8368988, 20.6608696], [86.83699799, 20.66016006], [86.83715057, 20.65949059], [86.83721161, 20.6588707], [86.8372345, 20.65832901], [86.8372879, 20.65785027], [86.83744049, 20.65742111], [86.83753967, 20.65695953], [86.83769989, 20.65650368], [86.83792877, 20.65607643], [86.83817291, 20.65563965], [86.83841705, 20.65523911], [86.83863068, 20.65481949], [86.83882904, 20.65439987], [86.83899689, 20.65390015], [86.83930206, 20.65341949], [86.83969879, 20.65294266], [86.84012604, 20.65242767], [86.84056091, 20.65197945], [86.84100342, 20.65162659], [86.84142303, 20.65134811], [86.84181976, 20.65116119], [86.84217072, 20.65100098], [86.8425293, 20.65088844], [86.84291077, 20.6508007], [86.84332275, 20.65075493], [86.84375763, 20.65073967], [86.84421539, 20.65073776], [86.8446579, 20.65076256], [86.84506226, 20.65081978], [86.84541321, 20.65088081], [86.84572601, 20.65092087], [86.84606171, 20.6510601], [86.84645844, 20.65124321], [86.84692383, 20.65144348], [86.84739685, 20.65166283], [86.8478775, 20.65187263], [86.84835815, 20.65197945], [86.84879303, 20.65209007], [86.8491745, 20.65222359], [86.84955597, 20.65241051], [86.84998322, 20.65269089], [86.8504715, 20.65304947], [86.85099792, 20.65343666], [86.85154724, 20.65377045], [86.85206604, 20.65406036], [86.85253906, 20.65439034], [86.8529892, 20.65471268], [86.85350037, 20.65501976], [86.85399628, 20.65539169], [86.85452271, 20.65578079], [86.85504913, 20.6561203], [86.85553741, 20.65647888], [86.85597992, 20.65682983], [86.85639191, 20.65718079], [86.85681915, 20.65748978], [86.85728455, 20.65776825], [86.85777283, 20.65805054], [86.85822296, 20.65837288], [86.85861206, 20.658741], [86.8589859, 20.65912247], [86.85942841, 20.65942955], [86.85985565, 20.65978432], [86.8602066, 20.66024971], [86.86060333, 20.66069031], [86.86107635, 20.66107559], [86.86164093, 20.66138268], [86.86226654, 20.66166115], [86.86295319, 20.66194916], [86.86362457, 20.66226959], [86.864151, 20.66274071], [86.86464691, 20.66324806], [86.86527252, 20.66357613], [86.86585999, 20.66387939], [86.86641693, 20.66418076], [86.86688232, 20.66451073], [86.86724091, 20.66489983], [86.86753845, 20.66531944], [86.867836, 20.66573906], [86.86821747, 20.6660881], [86.86867523, 20.66638565], [86.86917877, 20.66666031], [86.86969757, 20.66694641], [86.87017822, 20.66725922], [86.87058258, 20.66761017], [86.87098694, 20.66790009], [86.87136078, 20.66819], [86.87169647, 20.66848946], [86.87207794, 20.6687603], [86.87240601, 20.66908073], [86.87272644, 20.66940117], [86.87304688, 20.66971016], [86.87338257, 20.67000008], [86.87371063, 20.67027664], [86.87403107, 20.67054939], [86.87435913, 20.67084122], [86.87468719, 20.67115974], [86.87499237, 20.67152977], [86.8752594, 20.67194939], [86.87548828, 20.67239952], [86.87580109, 20.67274284], [86.87610626, 20.67301178], [86.87639618, 20.67324066], [86.87665558, 20.67343903], [86.87690735, 20.67365074], [86.87716675, 20.67391586], [86.87741852, 20.67422295], [86.87766266, 20.6745739], [86.87800598, 20.67482376], [86.87831879, 20.67511177], [86.87858582, 20.6754303], [86.87883759, 20.67577553], [86.87913513, 20.67606163], [86.87943268, 20.6763401], [86.87970734, 20.67664909], [86.87999725, 20.67695045], [86.88027954, 20.67726326], [86.88054657, 20.67757988], [86.88082886, 20.67790604], [86.88110352, 20.6782341], [86.88135529, 20.67856979], [86.88166046, 20.67885208], [86.88195038, 20.67912102], [86.88223267, 20.67938042], [86.88249969, 20.67962074], [86.88275146, 20.67987061], [86.88305664, 20.68028069], [86.8833313, 20.68056107], [86.88360596, 20.68056107], [86.8841629, 20.68111038], [86.88445282, 20.68111038], [86.88610077, 20.68278122], [86.88639069, 20.68278122], [86.88666534, 20.68305588], [86.88683319, 20.68349838], [86.88712311, 20.68381119], [86.88739014, 20.68414116], [86.8877182, 20.68438911], [86.88804626, 20.68464851], [86.88835907, 20.68494987], [86.88870239, 20.68525124], [86.88909912, 20.68548965], [86.88948822, 20.68571091], [86.88987732, 20.68587112], [86.89016724, 20.68615723], [86.89055634, 20.68645096], [86.89097595, 20.68668175], [86.89134979, 20.68693542], [86.89167023, 20.68721962], [86.89187622, 20.68742943], [86.89250183, 20.68806076], [86.89277649, 20.68805504], [86.89444733, 20.68972015], [86.89472198, 20.68971825], [86.89527893, 20.6902771], [86.89528656, 20.69083023], [86.89778137, 20.69333458], [86.89861298, 20.69417], [86.89888763, 20.69416618], [86.89888763, 20.69444466], [86.90018463, 20.69574165], [86.90083313, 20.69639015], [86.90110016, 20.69639015], [86.90249634, 20.69778061], [86.90305328, 20.6977787], [86.90361023, 20.69833374], [86.90389252, 20.69832993], [86.90416718, 20.69861031], [86.90444183, 20.69861031], [86.90471649, 20.69889069], [86.90499878, 20.69889069], [86.90528107, 20.69917107], [86.90555573, 20.69916725], [86.90583038, 20.69944382], [86.9059906, 20.69944382], [86.90611267, 20.69944382], [86.90638733, 20.69972229], [86.90666962, 20.69972038], [86.90693665, 20.70000076], [86.90721893, 20.70000076], [86.90740967, 20.70018768], [86.90750122, 20.70028114], [86.90777588, 20.70028114], [86.90805817, 20.70055962], [86.90860748, 20.7005558], [86.90888977, 20.70083427], [86.9091568, 20.70083046], [86.90972137, 20.70139122], [86.90999603, 20.70139122], [86.91028595, 20.70166969], [86.91083527, 20.70166588], [86.91110992, 20.70194435], [86.91166687, 20.70194435], [86.91194153, 20.70222282], [86.91249847, 20.70222282], [86.91278076, 20.70249939], [86.91306305, 20.70248985], [86.91333008, 20.70278168], [86.91500092, 20.70278168], [86.9152832, 20.70306015], [86.91583252, 20.70305634], [86.91611481, 20.7033329], [86.91638947, 20.7033329], [86.91666412, 20.70360947], [86.91694641, 20.70360947], [86.91722107, 20.70388794], [86.91765594, 20.7040081], [86.91822052, 20.70420074], [86.91873932, 20.70451546], [86.91936493, 20.70472336], [86.91997528, 20.70498466], [86.92056274, 20.70523071], [86.92112732, 20.70539093], [86.92166901, 20.70557976], [86.92218781, 20.70587921], [86.92271423, 20.70623779], [86.92338562, 20.70626259], [86.92391205, 20.70644951], [86.92432404, 20.7067585], [86.92487335, 20.70683479], [86.925354, 20.70698166], [86.92578125, 20.70722008], [86.92619324, 20.70750046], [86.92664337, 20.70778084], [86.92708588, 20.70802116], [86.92758179, 20.70816612], [86.9280014, 20.70833588], [86.92835999, 20.70849991], [86.92871094, 20.70862961], [86.92900848, 20.70880127], [86.9292984, 20.70901108], [86.92970276, 20.70919991], [86.93014526, 20.70937347], [86.9306488, 20.70946121], [86.93112183, 20.70960808], [86.93157196, 20.70974541], [86.93198395, 20.70990372], [86.93209076, 20.70993614], [86.93239594, 20.71003151], [86.93279266, 20.71026993], [86.93328094, 20.71050072], [86.93393707, 20.71071053], [86.93468475, 20.71088028], [86.93540955, 20.71108055], [86.93612671, 20.71119118], [86.93682098, 20.71125984], [86.93742371, 20.71136665], [86.93802643, 20.71139908], [86.938591, 20.7115097], [86.93916321, 20.71161079], [86.93979645, 20.71146965], [86.94050598, 20.71139908], [86.94123077, 20.71138954], [86.9419632, 20.71138954], [86.94267273, 20.71136665], [86.94335175, 20.71124077], [86.94402313, 20.71112061], [86.94468689, 20.71103096], [86.94535828, 20.71092033], [86.9460144, 20.71083832], [86.94668579, 20.7107811], [86.94734192, 20.71077728], [86.94798279, 20.7107811], [86.94848633, 20.71058083], [86.94898224, 20.71044731], [86.94944, 20.71027946], [86.94986725, 20.71013069], [86.95027161, 20.71001816], [86.95069885, 20.71000099], [86.95115662, 20.71000099], [86.95160675, 20.70996094], [86.95198822, 20.70974922], [86.95231628, 20.7096405], [86.95258331, 20.70947838], [86.95288086, 20.70957375], [86.95321655, 20.70968056], [86.95358276, 20.70972061], [86.95397949, 20.70972061], [86.95440674, 20.70968056], [86.95481873, 20.7094841], [86.9552536, 20.70942879], [86.95565796, 20.70935249], [86.9560318, 20.70922279], [86.95642853, 20.70918083], [86.95684052, 20.70916939], [86.95726776, 20.70916939], [86.95770264, 20.70916939], [86.95812225, 20.70916939], [86.95852661, 20.70916939], [86.95889282, 20.70916939], [86.95916748, 20.70916748], [86.95944214, 20.70944595], [86.95972443, 20.70944595], [86.95999908, 20.70916748], [86.96194458, 20.70916748], [86.96221924, 20.70944595], [86.96305847, 20.70944595], [86.96333313, 20.70916748], [86.9658432, 20.70916939], [86.96611023, 20.70889091], [86.96669006, 20.70889091], [86.9672699, 20.70889091], [86.96787262, 20.70889091], [86.96843719, 20.70887947], [86.96899414, 20.70885658], [86.96952057, 20.7088623], [86.97000885, 20.70883179], [86.97044373, 20.70862961], [86.97088623, 20.70849991], [86.97133636, 20.70840645], [86.97171783, 20.70820427], [86.9720993, 20.70802116], [86.97245789, 20.70779037], [86.97286224, 20.70759964], [86.97336578, 20.7074604], [86.97387695, 20.70722008], [86.97447205, 20.70695114], [86.97614288, 20.70610046], [86.97673035, 20.70566177], [86.97714233, 20.70535469], [86.97821808, 20.70467949], [86.9797287, 20.70421982], [86.98030853, 20.70421028], [86.98091125, 20.70413971], [86.98150635, 20.70396042], [86.98213959, 20.70386124], [86.98274994, 20.7036705], [86.98335266, 20.70359039], [86.98387909, 20.70347404], [86.98442078, 20.70335007], [86.98501587, 20.70331001], [86.98562622, 20.70331955], [86.9861908, 20.70331001], [86.98670197, 20.70318031], [86.98722839, 20.70297813], [86.98777008, 20.70279121], [86.98823547, 20.70263672], [86.98870087, 20.70252037], [86.98924255, 20.7024498], [86.98984528, 20.70226097], [86.99064636, 20.70222282], [86.9911499, 20.70220566], [86.99166107, 20.70219421], [86.99238586, 20.7021122], [86.99311829, 20.70203209], [86.99427795, 20.70196342], [86.99544525, 20.70189667], [87.0, 20.70028114], [87.00305176, 20.70028114], [87.00405884, 20.7003212], [87.00491333, 20.70024109], [87.00519562, 20.7002449], [87.00548553, 20.70010757], [87.00569916, 20.69984055], [87.00569916, 20.69936943], [87.00554657, 20.69875908], [87.00527191, 20.69848824], [87.00454712, 20.6982193], [87.0041275, 20.69795036], [87.00376892, 20.69782066], [87.00327301, 20.69748116], [87.00263214, 20.69728088], [87.00226593, 20.69713974], [87.00177002, 20.69713974], [87.0, 20.69668007], [86.99973297, 20.69695091], [86.99973297, 20.69717026], [86.99960327, 20.69723129], [86.99930573, 20.69722176], [86.99897003, 20.69721413], [86.99859619, 20.69722939], [86.99820709, 20.69729805], [86.99780273, 20.69742966], [86.99734497, 20.6974926], [86.99687958, 20.69754028], [86.99643707, 20.6977005], [86.99595642, 20.69781685], [86.99549103, 20.69799423], [86.99497986, 20.69812393], [86.99449921, 20.69831085], [86.99401093, 20.69848824], [86.99346161, 20.69864273], [86.99295044, 20.69881058], [86.99238586, 20.69888115], [86.99186707, 20.69889641], [86.99138641, 20.69894218], [86.99095917, 20.69906044], [86.99053192, 20.69910812], [86.99009705, 20.6990509], [86.98968506, 20.69891167], [86.98924255, 20.69882011], [86.9888382, 20.69874001], [86.98854065, 20.69861031], [86.98828888, 20.69855499], [86.98812103, 20.69853973], [86.98783875, 20.6984005], [86.98721313, 20.69820023], [86.98750305, 20.69721031], [86.98810577, 20.69742012], [86.9883194, 20.69750023], [86.9888382, 20.69762039], [86.98922729, 20.6976738], [86.98995972, 20.69766235], [86.99044037, 20.69771194], [86.99088287, 20.69767189], [86.9912796, 20.69754028], [86.99171448, 20.69748306], [86.99214935, 20.69741249], [86.99253845, 20.69725227], [86.99295044, 20.69712257], [86.99333954, 20.69697952], [86.99375916, 20.69688606], [86.994133, 20.6967411], [86.99452209, 20.69663429], [86.99491119, 20.69649887], [86.99533081, 20.69635963], [86.9957962, 20.69619942], [86.99633789, 20.69606972], [86.99687958, 20.69592094], [86.99743652, 20.69583321], [86.99803925, 20.69576645], [86.9988327, 20.69569969], [87.0, 20.69528008], [87.0011673, 20.69549942], [87.00159454, 20.69563675], [87.00216675, 20.69577217], [87.00293732, 20.69597054], [87.00359344, 20.69617653], [87.00408936, 20.69624329], [87.00479889, 20.69632149], [87.00522614, 20.69639015], [87.005867, 20.69639015], [87.00644684, 20.69645119], [87.00715637, 20.69664955], [87.00787354, 20.69691849], [87.0085907, 20.69725609], [87.00894165, 20.69739151], [87.00951385, 20.69772911], [87.01029968, 20.69792747], [87.01065826, 20.69799805], [87.01114655, 20.69812012], [87.01151276, 20.69833946], [87.01208496, 20.69853783], [87.01243591, 20.69866943], [87.01287079, 20.69880867], [87.01315308, 20.69894028], [87.01344299, 20.69901085], [87.01358032, 20.69930077], [87.01442719, 20.69963074], [87.01515198, 20.69997025], [87.01571655, 20.70030594], [87.01657867, 20.70064354], [87.01715088, 20.70091057], [87.01772308, 20.70111847], [87.01843262, 20.70165634], [87.0187149, 20.7017231], [87.01900482, 20.7017231], [87.01957703, 20.70165634], [87.01999664, 20.70145035], [87.02043152, 20.7010498], [87.02070618, 20.70084953], [87.02107239, 20.70078278], [87.0213623, 20.7007103], [87.02163696, 20.70064163], [87.02285767, 20.70064163], [87.02313995, 20.7007103], [87.02342987, 20.70084572], [87.02407074, 20.70145226], [87.02428436, 20.7017231], [87.02457428, 20.70199203], [87.02493286, 20.70226097], [87.02513885, 20.70232964], [87.0252533, 20.7023716], [87.02574158, 20.70265007], [87.0265274, 20.70304108], [87.02709961, 20.70345116], [87.02767181, 20.70358086], [87.02831268, 20.70384979], [87.02880859, 20.70412064], [87.0293808, 20.70458984], [87.02967072, 20.70493126], [87.03009796, 20.70540237], [87.03038025, 20.7056675], [87.03067017, 20.70587921], [87.03116608, 20.70587921], [87.03180695, 20.70573807], [87.0326004, 20.70560074], [87.03344727, 20.70560074], [87.03373718, 20.70573807], [87.03423309, 20.70594025], [87.03452301, 20.70607948], [87.03495026, 20.70621109], [87.03530884, 20.70641518], [87.03573608, 20.70648003], [87.03601837, 20.7065506], [87.03637695, 20.70668411], [87.03665924, 20.70675087], [87.03697968, 20.70706177], [87.03733826, 20.7074604], [87.03733826, 20.70800018], [87.03826141, 20.70853996], [87.03875732, 20.70887947], [87.03911591, 20.70907974], [87.03946686, 20.70922279], [87.03990173, 20.70941734], [87.0404129, 20.70955086], [87.04068756, 20.70975494], [87.04090118, 20.70981979], [87.04125977, 20.70996094], [87.04168701, 20.71002579], [87.04219055, 20.71009064], [87.04247284, 20.71022987], [87.04276276, 20.71029472], [87.04325867, 20.71036148], [87.0446167, 20.71036148], [87.04483032, 20.71022987], [87.04489136, 20.71015358], [87.04512024, 20.70988846], [87.0451889, 20.7094841], [87.0446167, 20.70887756], [87.04403687, 20.70845985], [87.04319, 20.70800018], [87.04234314, 20.70759964], [87.04154968, 20.70725822], [87.04067993, 20.70650864], [87.04032135, 20.70624161], [87.03974915, 20.70556641], [87.03846741, 20.70543098], [87.03760529, 20.70468712], [87.03653717, 20.7038784], [87.03568268, 20.70334053], [87.03497314, 20.70280075], [87.03417969, 20.70192337], [87.03318024, 20.70145035], [87.0324707, 20.70083809], [87.03153992, 20.70010376], [87.03070831, 20.69924927], [87.03042603, 20.69898033], [87.02970886, 20.69856071], [87.02921295, 20.69823837], [87.02884674, 20.6977005], [87.02700043, 20.69634819], [87.02635956, 20.69615173], [87.02578735, 20.69581032], [87.02542877, 20.69547272], [87.0241394, 20.69466019], [87.02364349, 20.69445992], [87.02307129, 20.69406128], [87.02258301, 20.6936512], [87.0213623, 20.69277191], [87.02072144, 20.69223213], [87.02028656, 20.69182777], [87.01950073, 20.6914196], [87.01885986, 20.69108772], [87.01821899, 20.69082069], [87.01735687, 20.69033813], [87.01657104, 20.68965912], [87.01635742, 20.68939972], [87.01535797, 20.68844032], [87.01457214, 20.68776894], [87.01364899, 20.68722916], [87.01136017, 20.68601036], [87.01065063, 20.6854744], [87.00993347, 20.6848011], [87.00921631, 20.68419075], [87.00665283, 20.68264198], [87.00565338, 20.68196869], [87.00465393, 20.68142891], [87.00222778, 20.67974091], [87.00144196, 20.67918968], [87.00086975, 20.67866135], [87.0, 20.67721939], [86.99834442, 20.67666245], [86.9972229, 20.67610931], [86.99694824, 20.67610931], [86.99610901, 20.67528152], [86.99582672, 20.67528152], [86.99536896, 20.67481232], [86.9952774, 20.67472267], [86.99500275, 20.67472267], [86.99472046, 20.6744442], [86.9944458, 20.6744442], [86.99416351, 20.67416573], [86.99388885, 20.67416954], [86.99360657, 20.67388916], [86.99333191, 20.67388916], [86.99305725, 20.67361069], [86.99276733, 20.67361069], [86.99194336, 20.67278099], [86.9916687, 20.67278099], [86.99111176, 20.67222023], [86.99055481, 20.67222214], [86.98972321, 20.67138863], [86.98944092, 20.67139053], [86.98860931, 20.67056084], [86.9883194, 20.67056084], [86.98722076, 20.66945076], [86.98722076, 20.66917038], [86.98694611, 20.66889], [86.98694611, 20.66860962], [86.98666382, 20.66833305], [86.98638916, 20.66833305], [86.9861145, 20.66805649], [86.98583221, 20.6680603], [86.98554993, 20.66777992], [86.9852829, 20.66777992], [86.98477173, 20.66727448], [86.98444366, 20.6669445], [86.98332977, 20.6669445], [86.98278046, 20.66638947], [86.98249817, 20.66638947], [86.98194122, 20.66583061], [86.98083496, 20.66583061], [86.98027802, 20.66527748], [86.98000336, 20.66527939], [86.97972107, 20.66500282], [86.97860718, 20.66500282], [86.97833252, 20.66472054], [86.97805786, 20.66472054], [86.97638702, 20.66305542], [86.97611237, 20.66306114], [86.97471619, 20.66167068], [86.97444153, 20.66167068], [86.97407532, 20.66129684], [86.97389221, 20.66111183], [86.97360992, 20.66111183], [86.97305298, 20.66055489], [86.97277832, 20.66055489], [86.97250366, 20.66027832], [86.97222137, 20.66027832], [86.97194672, 20.65999985], [86.9716568, 20.65999985], [86.97138214, 20.65977097], [86.97083282, 20.65972137], [86.97027588, 20.65916634], [86.97000122, 20.65917015], [86.96916962, 20.65833092], [86.96888733, 20.65833282], [86.96833038, 20.65777779], [86.96806335, 20.65777969], [86.96778107, 20.65751076], [86.96750641, 20.65751076], [86.96721649, 20.65722084], [86.96666718, 20.65722275], [86.96648407, 20.65703964], [86.96611023, 20.6566658], [86.9658432, 20.65666962], [86.96527863, 20.65611076], [86.96499634, 20.65611076], [86.96333313, 20.65443993], [86.96250153, 20.65444565], [86.96221924, 20.65416718], [86.96193695, 20.65417099], [86.96166992, 20.65389061], [86.96111298, 20.65389061], [86.96103668, 20.6538105], [86.96092987, 20.65370369], [86.96055603, 20.65333366], [86.96055603, 20.65305519], [86.95999908, 20.65306091], [86.9597168, 20.65278053], [86.95916748, 20.65278053], [86.95833588, 20.65195084], [86.95804596, 20.65195084], [86.95769501, 20.65159035], [86.95749664, 20.65138817], [86.95722198, 20.65138817], [86.95639038, 20.65055466], [86.95639038, 20.65027809], [86.95582581, 20.64971924], [86.95471954, 20.64972115], [86.95444489, 20.64944458], [86.95417023, 20.64944458], [86.95381927, 20.64909554], [86.95277405, 20.64805603], [86.95249939, 20.64805984], [86.95220947, 20.64777756], [86.95139313, 20.64777756], [86.9511795, 20.64756966], [86.95110321, 20.64755249], [86.95083618, 20.64749908], [86.95054626, 20.64722061], [86.95055389, 20.64694405], [86.94944763, 20.64583397], [86.94916534, 20.64583397], [86.94889069, 20.6455555], [86.94832611, 20.64557076], [86.94805908, 20.64528084], [86.94777679, 20.64528084], [86.9466629, 20.64417076], [86.94639587, 20.64417076], [86.94610596, 20.64389038], [86.9458313, 20.64389038], [86.94526672, 20.64332962], [86.94499969, 20.64333344], [86.9430542, 20.64138794], [86.94194794, 20.64138985], [86.94139099, 20.6408329], [86.94083405, 20.64083481], [86.94055176, 20.64111137], [86.94000244, 20.64111137], [86.93972015, 20.64083481], [86.9394455, 20.64083481], [86.93916321, 20.64055634], [86.93860626, 20.64056015], [86.9383316, 20.64027977], [86.93805695, 20.64027977], [86.93638611, 20.63861275], [86.93638611, 20.63833046], [86.9355545, 20.63750267], [86.93527985, 20.63750267], [86.93499756, 20.63722038], [86.9347229, 20.63722038], [86.93453979, 20.63703918], [86.93416595, 20.63666725], [86.9338913, 20.63667107], [86.93360901, 20.63640022], [86.93332672, 20.63640022], [86.93305206, 20.6361084], [86.9327774, 20.6361084], [86.93250275, 20.63582993], [86.93222046, 20.63582993], [86.9319458, 20.6361084], [86.93000031, 20.63417053], [86.92973328, 20.63417053], [86.92944336, 20.63388824], [86.9291687, 20.63388824], [86.92778015, 20.63249969], [86.92722321, 20.63249969], [86.92694092, 20.63222122], [86.92666626, 20.63222313], [86.9263916, 20.63194466], [86.92610931, 20.63194466], [86.92583466, 20.63166618], [86.92555237, 20.63166809], [86.92500305, 20.63111115], [86.92472076, 20.63111115], [86.92444611, 20.63083076], [86.92388916, 20.63083267], [86.92166901, 20.62861061], [86.92138672, 20.62861061], [86.92056274, 20.62778091], [86.92056274, 20.62721062], [86.91999817, 20.62666702], [86.91916656, 20.62667084], [86.91889191, 20.62639046], [86.91832733, 20.62639046], [86.91809845, 20.62615967], [86.91694641, 20.62611389], [86.91684723, 20.62601471], [86.91666412, 20.62583351], [86.91500092, 20.62583351], [86.91416931, 20.62500191], [86.91416931, 20.62446022], [86.91443634, 20.6241703], [86.91416931, 20.62389183], [86.91416931, 20.62332916], [86.91388702, 20.62305641], [86.91278076, 20.62306023], [86.91249847, 20.62278175], [86.91221619, 20.62278175], [86.91166687, 20.62221909], [86.91139221, 20.6222229], [86.91110992, 20.62194443], [86.91083527, 20.62194443], [86.91027832, 20.62138748], [86.90972137, 20.62140274], [86.90944672, 20.62111092], [86.90860748, 20.62111092], [86.90805817, 20.62055969], [86.90777588, 20.62055969], [86.90759277, 20.62037468], [86.90721893, 20.62000084], [86.90693665, 20.62000084], [86.90666962, 20.61972046], [86.90638733, 20.61972237], [86.90555573, 20.61888885], [86.90556335, 20.61861038], [86.90528107, 20.61833382], [86.90416718, 20.61833382], [86.90361023, 20.61777687], [86.9033432, 20.61778069], [86.90139008, 20.61582947], [86.90110779, 20.61583328], [86.90055847, 20.61527824], [86.90083313, 20.61499977], [86.90083313, 20.61471939], [86.90027618, 20.61416626], [86.89916992, 20.61417007], [86.89888763, 20.61388969], [86.8972168, 20.61220932], [86.89694214, 20.61222267], [86.89638519, 20.61166573], [86.89611053, 20.61166954], [86.89583588, 20.61139107], [86.89554596, 20.61139107], [86.89515686, 20.61099434], [86.89499664, 20.61083412], [86.89472198, 20.61083412], [86.89444733, 20.61055565], [86.89389038, 20.61055946], [86.89332581, 20.61000252], [86.89305878, 20.61000252], [86.89277649, 20.60971832], [86.89250183, 20.61000252], [86.89221954, 20.61000252], [86.89194489, 20.60972023], [86.89194489, 20.60944366], [86.89027405, 20.60778046], [86.88999939, 20.60778046], [86.88944244, 20.6072197], [86.8888855, 20.6072216], [86.88805389, 20.60638618], [86.88723755, 20.60606194], [86.8866272, 20.60611725], [86.88641357, 20.60699654], [86.88645172, 20.60822105], [86.88666534, 20.6091671], [86.88694763, 20.60943985], [86.88694763, 20.61000252], [86.88722229, 20.6102829], [86.88722229, 20.61166573], [86.88694763, 20.61194038], [86.88694763, 20.61250114], [86.88722229, 20.61277771], [86.88722229, 20.61333275], [86.88749695, 20.61361122], [86.88749695, 20.61388969], [86.88777924, 20.61416626], [86.88777924, 20.61721992], [86.88722229, 20.61778069], [86.88694763, 20.61778069], [86.88610077, 20.61695099], [86.88610077, 20.61667061], [86.88582611, 20.61639023], [86.88500214, 20.61639023], [86.88388824, 20.61527061], [86.88444519, 20.6147213], [86.88444519, 20.61444473], [86.88471985, 20.61416626], [86.88471985, 20.61361122], [86.88582611, 20.61250114], [86.88582611, 20.60806084], [86.88555908, 20.60749817], [86.8850708, 20.60630989], [86.88500214, 20.60583115], [86.88500214, 20.60527611], [86.88527679, 20.60499954], [86.88527679, 20.60472107], [86.88500214, 20.6044445], [86.88471985, 20.6044445], [86.88444519, 20.60416794], [86.8841629, 20.60416985], [86.88388824, 20.60388947], [86.88360596, 20.60388947], [86.8833313, 20.60361099], [86.88249969, 20.60361099], [86.88194275, 20.60305977], [86.88166809, 20.60305977], [86.8813858, 20.60277939], [86.88028717, 20.60277939], [86.87999725, 20.60250092], [86.8797226, 20.60250092], [86.87832642, 20.60111046], [86.87750244, 20.60111046], [86.87722015, 20.60083008], [86.87527466, 20.5988884], [86.875, 20.5988903], [86.87444305, 20.59832954], [86.87388611, 20.59833336], [86.87361145, 20.59861374], [86.87333679, 20.59833336], [86.87277985, 20.59833336], [86.87249756, 20.59805489], [86.8722229, 20.59805489], [86.87203979, 20.59786987], [86.87194824, 20.59777832], [86.87194824, 20.59750175], [86.87082672, 20.59639168], [86.87055206, 20.59639168], [86.87000275, 20.59583092], [86.8694458, 20.59583282], [86.86888885, 20.59527969], [86.86860657, 20.5952816], [86.86833191, 20.59499931], [86.86805725, 20.59499931], [86.86694336, 20.59389114], [86.8666687, 20.59389114], [86.86554718, 20.59278107], [86.86528015, 20.59278107], [86.86416626, 20.59167099], [86.8638916, 20.59167099], [86.86360931, 20.59139061], [86.86332703, 20.59139061], [86.8631897, 20.59124756], [86.86305237, 20.59110069], [86.86277771, 20.59111023], [86.86250305, 20.59083366], [86.86222076, 20.59083366], [86.86194611, 20.59055519], [86.86165619, 20.59056091], [86.86138916, 20.59028053], [86.86083221, 20.59028053], [86.86055756, 20.59000015], [86.86027527, 20.59000015], [86.86000061, 20.58972168], [86.85972595, 20.58972168], [86.85972595, 20.58944511], [86.85943604, 20.58917046], [86.85943604, 20.58889008], [86.85888672, 20.58833122], [86.85861206, 20.58833313], [86.85778046, 20.58749962], [86.85749817, 20.58749962], [86.85694122, 20.58694077], [86.85666656, 20.58694458], [86.85610962, 20.58638954], [86.85582733, 20.58638954], [86.85555267, 20.58666992], [86.85527802, 20.58666611], [86.85472107, 20.58722115], [86.85472107, 20.58777809], [86.85500336, 20.5880394], [86.85575867, 20.58814812], [86.85668945, 20.5883503], [86.85675812, 20.58862114], [86.85661316, 20.58903122], [86.85611725, 20.58916092], [86.85504913, 20.58909035], [86.85375977, 20.58909225], [86.85305023, 20.5883503], [86.85276794, 20.58794975], [86.85240173, 20.58727074], [86.85231781, 20.58653069], [86.85231781, 20.58579063], [86.85260773, 20.58484077], [86.85333252, 20.58416939], [86.85333252, 20.58389282], [86.8527832, 20.58333015], [86.85250092, 20.58333397], [86.85194397, 20.58277702], [86.85166931, 20.58278084], [86.85056305, 20.58167076], [86.84999084, 20.58167076], [86.84916687, 20.58082962], [86.84889221, 20.58083344], [86.84805298, 20.57999992], [86.84777832, 20.57999992], [86.84694672, 20.57916069], [86.84610748, 20.57916641], [86.84590149, 20.57895851], [86.8458252, 20.57894135], [86.84555817, 20.57888985], [86.84471893, 20.57806015], [86.84443665, 20.57806015], [86.84372711, 20.57733917], [86.84361267, 20.57722282], [86.84361267, 20.57694435], [86.84305573, 20.57638931], [86.84249878, 20.57694435], [86.84166718, 20.57694435], [86.83916473, 20.57444572], [86.83889008, 20.57444572], [86.83860779, 20.57416725], [86.83833313, 20.57417107], [86.83750153, 20.57332993], [86.83721924, 20.57333374], [86.83638763, 20.57250023], [86.83611298, 20.57221985], [86.83583069, 20.57222366], [86.83528137, 20.57166672], [86.83500671, 20.57167053], [86.83416748, 20.57082939], [86.83361053, 20.5708313], [86.83251953, 20.57007599], [86.83101654, 20.56906128], [86.8303833, 20.56865883], [86.82959747, 20.56851959], [86.82917023, 20.56805611], [86.82749939, 20.56638908], [86.8272171, 20.56638908], [86.82499695, 20.56415939], [86.82472229, 20.56416512], [86.82416534, 20.56361198], [86.82389069, 20.56389046], [86.82332611, 20.56389046], [86.82256317, 20.56311798], [86.82195282, 20.5625], [86.8216629, 20.5625], [86.81916809, 20.55999947], [86.81861115, 20.55999947], [86.81833649, 20.5597229], [86.8180542, 20.55972481], [86.81777954, 20.55944443], [86.81639099, 20.55944443], [86.81620026, 20.55925369], [86.81583405, 20.55888939], [86.81555176, 20.55888939], [86.8152771, 20.55861282], [86.81500244, 20.55861282], [86.81472015, 20.55833054], [86.81445313, 20.55833054], [86.81416321, 20.55861282], [86.81388092, 20.55861282], [86.8133316, 20.55805969], [86.81305695, 20.55805969], [86.81276703, 20.55778122], [86.8125, 20.55778122], [86.81240845, 20.55768967], [86.81223297, 20.55750275], [86.81194305, 20.55750275], [86.8116684, 20.55722046], [86.8116684, 20.55694389], [86.81222534, 20.55639076], [86.81194305, 20.55610847], [86.81194305, 20.55582809], [86.81138611, 20.55527687], [86.81111145, 20.55528069], [86.80999756, 20.55417061], [86.8097229, 20.55417061], [86.80860901, 20.55305099], [86.80833435, 20.55305481], [86.80805206, 20.55277634], [86.8077774, 20.55277824], [86.80750275, 20.55249977], [86.80722046, 20.55249977], [86.8069458, 20.55221939], [86.80638885, 20.5522213], [86.8061142, 20.55194473], [86.80583191, 20.55194473], [86.8041687, 20.55027771], [86.80388641, 20.55027962], [86.8033371, 20.54972076], [86.80305481, 20.54972267], [86.80288696, 20.5495491], [86.80278015, 20.5494442], [86.80194092, 20.5494442], [86.79972076, 20.54722214], [86.79944611, 20.54722214], [86.79916382, 20.54694366], [86.79888916, 20.54694366], [86.79833221, 20.54638863], [86.79805756, 20.54639053], [86.79676819, 20.54570007], [86.79634094, 20.5454998], [86.79531097, 20.54516029], [86.79453278, 20.54482079], [86.79387665, 20.54482079], [86.7934494, 20.54475021], [86.7928772, 20.54454994], [86.79216766, 20.5440712], [86.79166412, 20.54333115], [86.79166412, 20.54250145], [86.79110718, 20.54194069], [86.79111481, 20.54166603], [86.79083252, 20.54138756], [86.79083252, 20.54110909], [86.78943634, 20.53972054], [86.78916931, 20.53972244], [86.78694153, 20.53750038], [86.78639221, 20.53750038], [86.7858429, 20.53695107], [86.78555298, 20.53695107], [86.78444672, 20.53582954], [86.78444672, 20.53527832], [86.7841568, 20.53499985], [86.7841568, 20.53417969], [86.78221893, 20.53222275], [86.78221893, 20.53194427], [86.78194427, 20.5316658], [86.78153229, 20.53049278], [86.78055573, 20.52916718], [86.78028107, 20.52889061], [86.78028107, 20.52860832], [86.77999878, 20.52832985], [86.77999878, 20.52805519], [86.77944183, 20.52749825], [86.77944183, 20.52721977], [86.77972412, 20.52694511], [86.77971649, 20.52638817], [86.77889252, 20.52555084], [86.77889252, 20.52527618], [86.77861023, 20.52500916], [86.77861023, 20.52472115], [86.77805328, 20.52416611], [86.77805328, 20.52361107], [86.777771, 20.52333069], [86.77777863, 20.52305412], [86.77694702, 20.52222061], [86.77694702, 20.52083588], [86.77666473, 20.5205555], [86.7766571, 20.52028084], [86.77610779, 20.51972008], [86.77610779, 20.51888847], [86.77583313, 20.51861191], [86.77583313, 20.51805496], [86.77555847, 20.5177803], [86.77555847, 20.51721954], [86.77527618, 20.51694489], [86.77527618, 20.51472282], [86.77555847, 20.51444435], [86.77555847, 20.51389122], [86.77527618, 20.51361084], [86.77527618, 20.51306915], [86.77500153, 20.51278114], [86.77500153, 20.51167107], [86.77471161, 20.51139069], [86.77500153, 20.51111031], [86.77500153, 20.51082993], [86.77471924, 20.51055527], [86.77471161, 20.51028061], [86.77443695, 20.51000977], [86.77443695, 20.50945091], [86.77471161, 20.50917053], [86.77443695, 20.50889015], [86.77443695, 20.50832939], [86.77388763, 20.50777817], [86.77388763, 20.50749969], [86.77278137, 20.50638962], [86.77278137, 20.50611115], [86.77111053, 20.50444031], [86.76866913, 20.50444412], [86.76805878, 20.50444412], [86.76777649, 20.50416756], [86.76667023, 20.50416946], [86.76611328, 20.50361252], [86.7638855, 20.50361252], [86.76361084, 20.50333405], [86.76333618, 20.50333023], [86.76304626, 20.50361252], [86.76222229, 20.50361252], [86.76139069, 20.50444412], [86.76139069, 20.5047226], [86.76055908, 20.50555992], [86.75945282, 20.50555992], [86.75740051, 20.50266075], [86.75640106, 20.50124741], [86.75617981, 20.50064278], [86.75553894, 20.49956322], [86.7555542, 20.49916649], [86.75527954, 20.4991703], [86.75389099, 20.49777985], [86.75360107, 20.49777985], [86.75332642, 20.49749947], [86.75332642, 20.49722099], [86.75305176, 20.49694443], [86.75333405, 20.49666405], [86.75332642, 20.49555969], [86.75235748, 20.49458122], [86.7519455, 20.49416733], [86.75195313, 20.49389076], [86.75166321, 20.49361038], [86.75138855, 20.49155045], [86.75138855, 20.49000168], [86.75110626, 20.48971939], [86.75111389, 20.48944473], [86.7508316, 20.48916626], [86.7508316, 20.48887825], [86.75055695, 20.48860931], [86.75055695, 20.48722076], [86.7508316, 20.4869442], [86.7508316, 20.48611069], [86.75055695, 20.48583984], [86.75055695, 20.48500061], [86.75026703, 20.48472023], [86.75027466, 20.48416519], [86.75, 20.48389053], [86.75, 20.48332977], [86.74972534, 20.48305511], [86.74973297, 20.4822197], [86.74944305, 20.48194313], [86.74944305, 20.48167038], [86.7491684, 20.48139], [86.7491684, 20.48083115], [86.74888611, 20.48055649], [86.74888611, 20.48027992], [86.74861145, 20.47999954], [86.74861145, 20.47970963], [86.74833679, 20.4794445], [86.74833679, 20.4786129], [86.74804688, 20.47833061], [86.7480545, 20.47777748], [86.74778748, 20.47750282], [86.74777985, 20.47694206], [86.74749756, 20.4766674], [86.74749756, 20.47582817], [86.7472229, 20.47555542], [86.7472229, 20.47528076], [86.74666595, 20.47471809], [86.74666595, 20.47416878], [86.7463913, 20.47390175], [86.7463913, 20.47305107], [86.74555206, 20.47222137], [86.74555206, 20.47194481], [86.7452774, 20.47166634], [86.7452774, 20.47110939], [86.74500275, 20.47083282], [86.74500275, 20.47027969], [86.74472809, 20.47000122], [86.74472809, 20.46972084], [86.7436142, 20.46861076], [86.74276733, 20.46861076], [86.74250031, 20.46889114], [86.74222565, 20.46888924], [86.74166107, 20.46944046], [86.74166107, 20.47000122], [86.74138641, 20.47027969], [86.74138641, 20.47056007], [86.74166107, 20.47084045], [86.7416687, 20.47166634], [86.74138641, 20.47194099], [86.74138641, 20.47249985], [86.74111176, 20.47278023], [86.74111176, 20.47390175], [86.74055481, 20.47444534], [86.74054718, 20.47471809], [86.73999786, 20.47528076], [86.73999786, 20.47555923], [86.73916626, 20.47639275], [86.73916626, 20.4766674], [86.7388916, 20.47694206], [86.7388916, 20.47722244], [86.73832703, 20.47777939], [86.73832703, 20.47805977], [86.73777771, 20.4786129], [86.73750305, 20.4786129], [86.73722076, 20.47888947], [86.73665619, 20.47888947], [86.73638916, 20.47916985], [86.7361145, 20.47916603], [86.73583221, 20.4794445], [86.73416901, 20.4794445], [86.73388672, 20.47916603], [86.73388672, 20.4786129], [86.73472595, 20.4786129], [86.73500061, 20.47833061], [86.73583221, 20.47833061], [86.73638916, 20.47777748], [86.73665619, 20.47777939], [86.73777771, 20.47667122], [86.73777771, 20.47639275], [86.73805237, 20.47610855], [86.73805237, 20.47582817], [86.73860931, 20.47527695], [86.73860168, 20.47499847], [86.73832703, 20.47471809], [86.73860931, 20.47444534], [86.73860168, 20.47249985], [86.73832703, 20.47221947], [86.73833466, 20.46888924], [86.73805237, 20.46861076], [86.73803711, 20.46748161], [86.73777771, 20.46722221], [86.73777771, 20.46694374], [86.73750305, 20.46666718], [86.73750305, 20.46639061], [86.73722076, 20.46611023], [86.73722076, 20.46582985], [86.73694611, 20.46555519], [86.73694611, 20.46500015], [86.73665619, 20.46470833], [86.73666382, 20.46388817], [86.73638916, 20.4636116], [86.73638916, 20.46305466], [86.7361145, 20.46277809], [86.73610687, 20.46139145], [86.73583221, 20.46110916], [86.73583221, 20.46027756], [86.73555756, 20.45999908], [86.73555756, 20.45972061], [86.73527527, 20.45944405], [86.73527527, 20.4588871], [86.73500061, 20.45861053], [86.73500061, 20.45806122], [86.73472595, 20.45778084], [86.73472595, 20.45750046], [86.73443604, 20.45722008], [86.73444366, 20.45694351], [86.73388672, 20.45638847], [86.73388672, 20.45611], [86.73361206, 20.45583344], [86.73361206, 20.4552784], [86.73332977, 20.45499992], [86.73332977, 20.4543705], [86.73332977, 20.45388794], [86.73306274, 20.45360947], [86.73361206, 20.45305634], [86.73361206, 20.45249939], [86.73337555, 20.4522171], [86.73336029, 20.45205879], [86.73332977, 20.45166588], [86.73361206, 20.45139122], [86.73361206, 20.44889069], [86.73332977, 20.4486084], [86.73332977, 20.44778061], [86.73361206, 20.44749832], [86.73361206, 20.44696045], [86.73332977, 20.44667053], [86.73332977, 20.44638824], [86.73306274, 20.44610977], [86.73305511, 20.44527626], [86.73278809, 20.44499969], [86.73278046, 20.44444466], [86.73332977, 20.44388962], [86.73306274, 20.4435997], [86.73305511, 20.4430542], [86.73332977, 20.44277954], [86.73332977, 20.44166946], [86.73306274, 20.44139099], [86.73306274, 20.44028091], [86.73278809, 20.44000053], [86.73278046, 20.43972206], [86.73249817, 20.43944359], [86.73249817, 20.43916702], [86.73306274, 20.43861008], [86.73305511, 20.43805504], [86.73249817, 20.43750191], [86.73249817, 20.43639183], [86.73221588, 20.43611145], [86.73222351, 20.43500137], [86.73249817, 20.43473244], [86.73249817, 20.43222046], [86.73278046, 20.43194389], [86.73278046, 20.42666626], [86.73306274, 20.42638969], [86.73305511, 20.42611122], [86.73332977, 20.42583466], [86.73332977, 20.42499924], [86.73306274, 20.42472267], [86.73305511, 20.42361259], [86.73332977, 20.42333412], [86.73332977, 20.42305565], [86.73361206, 20.42279053], [86.73361206, 20.41860962], [86.73388672, 20.41833305], [86.73388672, 20.41777611], [86.73332977, 20.41722107], [86.73332977, 20.4169445], [86.73305511, 20.41666412], [86.73305511, 20.41638947], [86.73361206, 20.41583252], [86.73305511, 20.41527748], [86.73306274, 20.41472054], [86.73332977, 20.41444588], [86.73332977, 20.41388893], [86.73306274, 20.41362], [86.73306274, 20.41333008], [86.73278046, 20.41305542], [86.73278809, 20.41082954], [86.73305511, 20.41055489], [86.73249817, 20.41000175], [86.73278809, 20.40971947], [86.73222351, 20.40916634], [86.73221588, 20.40889168], [86.73194122, 20.40860939], [86.73194122, 20.40833282], [86.73166656, 20.40805626], [86.73166656, 20.40777969], [86.73139191, 20.40750122], [86.73105621, 20.40707016], [86.73000336, 20.40582085], [86.72943115, 20.40488052], [86.73107147, 20.40365982], [86.73171234, 20.40319252], [86.73271179, 20.40251732], [86.73278046, 20.40277863], [86.73332977, 20.40333366], [86.73361206, 20.40332985], [86.73388672, 20.40361023], [86.73416901, 20.40361023], [86.73583221, 20.40389061], [86.73610687, 20.40417099], [86.73638916, 20.40416527], [86.73649597, 20.40427589], [86.73666382, 20.40444374], [86.73750305, 20.40444374], [86.73777771, 20.40472221], [86.73944092, 20.40472031], [86.73972321, 20.40500069], [86.74054718, 20.40500069], [86.7408371, 20.40472031], [86.74111176, 20.40472031], [86.74138641, 20.40500069], [86.74305725, 20.40500069], [86.74333191, 20.40528107], [86.74360657, 20.40528107], [86.74388885, 20.40555954], [86.74416351, 20.40555573], [86.7444458, 20.4058342], [86.74500275, 20.4058342], [86.7452774, 20.40555573], [86.74555206, 20.40555954], [86.74582672, 20.40528107], [86.74666595, 20.40528107], [86.74694824, 20.40500069], [86.74833679, 20.40500069], [86.74888611, 20.40555954], [86.7491684, 20.40555954], [86.74973297, 20.40500069], [86.74972534, 20.40472221], [86.75055695, 20.4038887], [86.75055695, 20.40361023], [86.75195313, 20.40221977], [86.7519455, 20.40166664], [86.75222015, 20.40139008], [86.75222015, 20.40055084], [86.7519455, 20.40027809], [86.75195313, 20.39999962], [86.75027466, 20.3983326], [86.75, 20.3983326], [86.74972534, 20.39805794], [86.74944305, 20.39777756], [86.7491684, 20.39777946], [86.74888611, 20.39749908], [86.74861145, 20.39722252], [86.74833679, 20.39722252], [86.7480545, 20.39694405], [86.7472229, 20.39694405], [86.74694824, 20.39666748], [86.74610901, 20.39666939], [86.74582672, 20.39639282], [86.74472809, 20.39639282], [86.7444458, 20.39610863], [86.74388885, 20.39610863], [86.74360657, 20.39582825], [86.74277496, 20.39583397], [86.74250031, 20.3955555], [86.74194336, 20.39555931], [86.74166107, 20.39528084], [86.74111176, 20.39528084], [86.73999786, 20.39417076], [86.74028015, 20.39389038], [86.74054718, 20.39389038], [86.7408371, 20.39360809], [86.74111176, 20.39360809], [86.74124908, 20.39374733], [86.74138641, 20.39389038], [86.7416687, 20.39389038], [86.74192047, 20.39414024], [86.74222565, 20.39444351], [86.74250031, 20.39444351], [86.74277496, 20.39472008], [86.74388885, 20.39477539], [86.74415588, 20.39499855], [86.74582672, 20.39499855], [86.74610901, 20.39528084], [86.7463913, 20.39528084], [86.74666595, 20.39555931], [86.7472229, 20.3955555], [86.74749756, 20.39583397], [86.74833679, 20.39583397], [86.748703, 20.3962059], [86.74888611, 20.39639282], [86.74944305, 20.39639091], [86.74951935, 20.39646339], [86.74973297, 20.39666939], [86.75, 20.39666748], [86.75027466, 20.39694405], [86.75138855, 20.39694405], [86.75166321, 20.39722252], [86.75195313, 20.39722252], [86.75222015, 20.3975029], [86.75250244, 20.3975029], [86.7527771, 20.39777946], [86.75332642, 20.39777946], [86.75360107, 20.39805984], [86.75444794, 20.39805603], [86.7547226, 20.3983326], [86.75499725, 20.3983326], [86.75527954, 20.39862061], [86.75554657, 20.39862061], [86.75611115, 20.39916992], [86.75666809, 20.39916992], [86.75749969, 20.3983326], [86.75777435, 20.3983326], [86.75805664, 20.39805603], [86.7583313, 20.39805984], [86.75860596, 20.39777946], [86.75860596, 20.39582825], [86.7583313, 20.3955555], [86.7583313, 20.39528084], [86.75805664, 20.39499855], [86.75805664, 20.39360809], [86.75777435, 20.39333344], [86.75777435, 20.39222145], [86.75749969, 20.39194489], [86.75749969, 20.39138794], [86.75723267, 20.39110947], [86.75722504, 20.3908329], [86.75694275, 20.39055634], [86.75694275, 20.39027977], [86.75666809, 20.38999939], [86.75611115, 20.38943291], [86.75611115, 20.38916588], [86.75666809, 20.38861084], [86.75694275, 20.38861084], [86.75722504, 20.38888931], [86.75777435, 20.38944435], [86.75776672, 20.38972092], [86.75805664, 20.38999939], [86.75805664, 20.39027977], [86.7583313, 20.39055634], [86.7583313, 20.39110947], [86.75861359, 20.39138794], [86.75861359, 20.39194489], [86.75888824, 20.39221954], [86.75888824, 20.39305496], [86.7591629, 20.39333344], [86.7591629, 20.39444351], [86.75944519, 20.39472008], [86.75972748, 20.39499855], [86.75971985, 20.39527893], [86.76027679, 20.39582825], [86.76027679, 20.39610863], [86.7611084, 20.39694405], [86.76249695, 20.39694405], [86.76277924, 20.39722252], [86.76304626, 20.39722252], [86.76333618, 20.3975029], [86.76360321, 20.39755249], [86.7636795, 20.39756775], [86.76389313, 20.39777946], [86.76416779, 20.39777946], [86.76444244, 20.3975029], [86.76499939, 20.3975029], [86.76526642, 20.39777946], [86.76555634, 20.39777756], [86.76611328, 20.3983326], [86.76638794, 20.3983326], [86.76667023, 20.39805603], [86.76693726, 20.39805984], [86.76721954, 20.39777946], [86.76805878, 20.39777946], [86.76832581, 20.39805984], [86.76889801, 20.39805984], [86.76917267, 20.39777946], [86.76999664, 20.39777946], [86.77027893, 20.3975029], [86.77054596, 20.3975029], [86.77083588, 20.39722252], [86.77111053, 20.39722252], [86.77138519, 20.39694405], [86.77249908, 20.39694405], [86.77278137, 20.39666748], [86.77305603, 20.39666939], [86.77388763, 20.39582825], [86.77416992, 20.39583397], [86.77444458, 20.3955555], [86.77471161, 20.39555931], [86.77500153, 20.39528084], [86.77527618, 20.39528084], [86.77610779, 20.3944397], [86.77639008, 20.39444351], [86.77666473, 20.39416885], [86.77722168, 20.39417076], [86.77971649, 20.39167023], [86.77971649, 20.39138985], [86.77999878, 20.39110947], [86.77999878, 20.3908329], [86.78083038, 20.38999939], [86.78083038, 20.38972282], [86.78111267, 20.38944435], [86.78111267, 20.38888931], [86.78166962, 20.38833046], [86.78166962, 20.38777733], [86.78193665, 20.38750076], [86.78193665, 20.3866806], [86.78221893, 20.38639069], [86.78221893, 20.38582993], [86.78194427, 20.38555527], [86.78221893, 20.38528061], [86.78221893, 20.38362122], [86.78193665, 20.38332939], [86.78194427, 20.38305473], [86.78166962, 20.38277817], [86.78166962, 20.38221931], [86.78111267, 20.38166618], [86.78111267, 20.38139153], [86.77971649, 20.37999916], [86.77916718, 20.37999916], [86.77889252, 20.37972069], [86.77833557, 20.3797226], [86.77805328, 20.37944412], [86.77639008, 20.37944412], [86.77610779, 20.37916946], [86.77555847, 20.37916946], [86.77527618, 20.37889099], [86.77471924, 20.37888718], [86.77444458, 20.37861061], [86.77388763, 20.37861061], [86.77361298, 20.37833023], [86.77333069, 20.37833405], [86.77305603, 20.37805557], [86.77278137, 20.37805939], [86.77222443, 20.37749863], [86.77166748, 20.37693977], [86.77166748, 20.37666512], [86.76972198, 20.37471962], [86.76972198, 20.37444305], [86.76917267, 20.37388992], [86.76917267, 20.37360954], [86.76889038, 20.37333488], [86.76889038, 20.37305641], [86.76860809, 20.37277985], [86.76860809, 20.3722229], [86.76721954, 20.37083244], [86.76694489, 20.37083244], [86.76611328, 20.37000275], [86.76611328, 20.36972237], [86.76583099, 20.36944389], [86.76583099, 20.36889076], [86.76526642, 20.36832047], [86.76527405, 20.36805534], [86.76499939, 20.36778069], [86.76499939, 20.3674984], [86.7647171, 20.36721992], [86.76472473, 20.36694527], [86.76416779, 20.36638832], [86.76416779, 20.36582947], [86.76472473, 20.36527634], [86.76555634, 20.36610985], [86.76555634, 20.36638832], [86.76583099, 20.36667061], [86.76583099, 20.36694527], [86.76611328, 20.36721992], [86.76611328, 20.3674984], [86.76638794, 20.36778069], [86.76638794, 20.36805916], [86.76693726, 20.36860847], [86.76694489, 20.36889076], [86.76750183, 20.36944389], [86.76750183, 20.36972237], [86.76794434, 20.36998177], [86.76838684, 20.37033272], [86.7688446, 20.37068176], [86.76927948, 20.37105942], [86.76972961, 20.37138939], [86.77017212, 20.37170982], [86.77056122, 20.37207794], [86.77091217, 20.37244034], [86.7712326, 20.37275124], [86.771492, 20.37301826], [86.77172089, 20.37329102], [86.7719574, 20.37360191], [86.77222443, 20.37395668], [86.7725296, 20.37439156], [86.7728653, 20.37487793], [86.77321625, 20.3753624], [86.77379608, 20.37560463], [86.77444458, 20.37583351], [86.77471924, 20.37583351], [86.77500153, 20.37611198], [86.77527618, 20.37611008], [86.77555847, 20.37639046], [86.77583313, 20.37611008], [86.77597046, 20.37611008], [86.77639008, 20.37611198], [86.77666473, 20.37583351], [86.77777863, 20.37583351], [86.77805328, 20.37555695], [86.77861023, 20.37555695], [86.77889252, 20.37583351], [86.77944183, 20.37583351], [86.77955627, 20.37594414], [86.77972412, 20.37611198], [86.78028107, 20.37611008], [86.78056335, 20.37639046], [86.78083801, 20.37639046], [86.78134918, 20.37634087], [86.78188324, 20.37652969], [86.78250122, 20.37661743], [86.78312683, 20.37668037], [86.78376007, 20.37690163], [86.78436279, 20.37742043], [86.78495026, 20.37746239], [86.78552246, 20.37720108], [86.78607941, 20.37691498], [86.78637695, 20.37651253], [86.78623199, 20.3759613], [86.78598022, 20.37540627], [86.78573608, 20.37490082], [86.78553009, 20.37447357], [86.78522491, 20.37412071], [86.78491974, 20.37380028], [86.78464508, 20.37347984], [86.78457642, 20.37301636], [86.78472137, 20.37239075], [86.78465271, 20.37207031], [86.78446198, 20.37183952], [86.78427887, 20.37158585], [86.78410339, 20.37127113], [86.78380585, 20.37092972], [86.78343201, 20.37051964], [86.78301239, 20.37001991], [86.78256989, 20.36947441], [86.78208923, 20.36894035], [86.78166962, 20.36837959], [86.78125763, 20.36786652], [86.78085327, 20.36742973], [86.78056335, 20.36699104], [86.78027344, 20.36655998], [86.78000641, 20.36610985], [86.77971649, 20.36555099], [86.77972412, 20.36527634], [86.77944183, 20.36499977], [86.77944183, 20.36471939], [86.77916718, 20.36444473], [86.77916718, 20.36416626], [86.77889252, 20.36388969], [86.77889252, 20.36361122], [86.77861023, 20.36333084], [86.77861023, 20.36305428], [86.7783432, 20.36277962], [86.7783432, 20.36222076], [86.77805328, 20.3619442], [86.77805328, 20.36166573], [86.77783966, 20.36138344], [86.77777863, 20.36083412], [86.77749634, 20.36055565], [86.77749634, 20.35917091], [86.77722168, 20.35889053], [86.77749634, 20.35861015], [86.77749634, 20.35833359], [86.77757263, 20.3582592], [86.77777863, 20.35805511], [86.777771, 20.3555603], [86.77861023, 20.35471916], [86.77861023, 20.35528183], [86.77889252, 20.35555649], [86.77889252, 20.35611153], [86.77916718, 20.35638046], [86.77916718, 20.35667038], [86.77889252, 20.35695267], [86.77889252, 20.35889053], [86.77916718, 20.35917091], [86.77916718, 20.35944366], [86.77944183, 20.35972023], [86.77944183, 20.36028099], [86.77971649, 20.36055946], [86.77972412, 20.36166573], [86.77999878, 20.3619442], [86.77999878, 20.36222076], [86.78083038, 20.36305428], [86.78083801, 20.36361122], [86.78111267, 20.36388969], [86.78250122, 20.36527634], [86.78250122, 20.36555099], [86.78388977, 20.36694527], [86.7838974, 20.36721992], [86.78444672, 20.36778069], [86.78444672, 20.36805916], [86.78666687, 20.3702774], [86.78666687, 20.37083244], [86.78749847, 20.37166977], [86.78833008, 20.37083244], [86.78833008, 20.37055588], [86.78861237, 20.37028122], [86.78861237, 20.37000275], [86.78888702, 20.36972237], [86.78861237, 20.36944389], [86.78861237, 20.36805534], [86.78916931, 20.3674984], [86.78916931, 20.36721992], [86.78944397, 20.36694527], [86.78943634, 20.36667061], [86.78916931, 20.36638832], [86.78916931, 20.36610985], [86.78861237, 20.36555481], [86.78884125, 20.36532593], [86.78944397, 20.3647213], [86.78916931, 20.36444473], [86.78916931, 20.36361122], [86.79000092, 20.36277962], [86.79000092, 20.36111069], [86.78943634, 20.36055946], [86.78943634, 20.36028099], [86.789711, 20.36000061], [86.78943634, 20.35972023], [86.78971863, 20.35944366], [86.789711, 20.35917091], [86.78916931, 20.35861015], [86.78916931, 20.35833359], [86.78861237, 20.35777855], [86.78833008, 20.35750008], [86.78833008, 20.3572216], [86.78805542, 20.35694504], [86.78806305, 20.35667038], [86.78694153, 20.3555603], [86.78694153, 20.35528183], [86.78666687, 20.35500145], [86.78666687, 20.35471916], [86.78444672, 20.35250092], [86.78444672, 20.35222054], [86.78416443, 20.35194397], [86.78416443, 20.35166931], [86.7838974, 20.35139084], [86.7838974, 20.35111046], [86.78360748, 20.35083389], [86.78360748, 20.35055542], [86.78277588, 20.34972], [86.78277588, 20.34944534], [86.78221893, 20.3488903], [86.78221893, 20.34860992], [86.78194427, 20.34833336], [86.78194427, 20.34805489], [86.78166962, 20.34777832], [86.78166962, 20.34721947], [86.78111267, 20.34666634], [86.78111267, 20.34638977], [86.78083801, 20.34610939], [86.78083038, 20.34583473], [86.77777863, 20.34277725], [86.77749634, 20.34278107], [86.77722168, 20.34250069], [86.77694702, 20.34250069], [86.77610779, 20.34333038], [86.77610779, 20.34361267], [86.77583313, 20.34389114], [86.77610779, 20.3441658], [86.77610779, 20.34472275], [86.77583313, 20.34499931], [86.77583313, 20.34583473], [86.77555847, 20.34610939], [86.77555847, 20.34638977], [86.77527618, 20.34666634], [86.77527618, 20.34694481], [86.77475739, 20.34745979], [86.77443695, 20.34750938], [86.77419281, 20.34724617], [86.77388763, 20.34722137], [86.77361298, 20.34694481], [86.77361298, 20.34666634], [86.77388763, 20.34638977], [86.77388763, 20.34610939], [86.77471924, 20.34527779], [86.77471161, 20.34416962], [86.77443695, 20.34389114], [86.77443695, 20.34305954], [86.77416992, 20.34278107], [86.77416992, 20.3422184], [86.77471924, 20.34166718], [86.77471161, 20.34056091], [86.77500153, 20.34028053], [86.77500153, 20.33971977], [86.77471924, 20.33944511], [86.77471161, 20.33917046], [86.77443695, 20.33888817], [86.77443695, 20.33834076], [86.77471161, 20.33806038], [86.7743988, 20.33777809], [86.77416992, 20.33777809], [86.77249908, 20.33611107], [86.77249908, 20.33583069], [86.77138519, 20.33472252], [86.77138519, 20.33444595], [86.77111053, 20.33416748], [86.77111053, 20.33361053], [86.77054596, 20.33306122], [86.77054596, 20.33250046], [86.76917267, 20.33111191], [86.76889038, 20.33111382], [86.76860809, 20.33083344], [86.76833344, 20.33083344], [86.76805878, 20.33055496], [86.76777649, 20.33056068], [86.76721954, 20.33000183], [86.76693726, 20.33000183], [86.76667023, 20.32971954], [86.76638794, 20.32971954], [86.76611328, 20.32944489], [86.76583099, 20.32944489], [86.76472473, 20.32833481], [86.76416779, 20.32777977], [86.76389313, 20.32778168], [86.76333618, 20.32722092], [86.76305389, 20.32722282], [86.76277924, 20.32694435], [86.76249695, 20.32694435], [86.76222229, 20.32666588], [86.76194763, 20.32666969], [86.76167297, 20.32640076], [86.76139069, 20.32640076], [86.7611084, 20.32611084], [86.76082611, 20.32611084], [86.76027679, 20.32555962], [86.76000214, 20.32555962], [86.7591629, 20.32472038], [86.75888824, 20.32472229], [86.75879669, 20.32462883], [86.75861359, 20.32444382], [86.7583313, 20.32444382], [86.75819397, 20.3243084], [86.75805664, 20.32416534], [86.75776672, 20.32417107], [86.75749969, 20.32389069], [86.75723267, 20.32389069], [86.75694275, 20.32361031], [86.7563858, 20.32361031], [86.75583649, 20.32306099], [86.75554657, 20.32306099], [86.75499725, 20.32250023], [86.75332642, 20.32250023], [86.7527771, 20.32195091], [86.75222015, 20.32195091], [86.75166321, 20.32139015], [86.75138855, 20.32139015], [86.75, 20.31999969], [86.74972534, 20.31999969], [86.7491684, 20.31944466], [86.74888611, 20.31944466], [86.74861145, 20.31916618], [86.74833679, 20.31917], [86.74804688, 20.31888962], [86.74777985, 20.31888962], [86.74694824, 20.31805611], [86.74666595, 20.31805992], [86.74610901, 20.31750107], [86.74582672, 20.31750107], [86.74570465, 20.31737137], [86.74555206, 20.31720924], [86.7452774, 20.3172226], [86.74472046, 20.31666756], [86.74415588, 20.31611252], [86.74388885, 20.31611252], [86.74305725, 20.31528091], [86.74305725, 20.31500053], [86.74223328, 20.31417084], [86.74194336, 20.31417084], [86.74166107, 20.31389046], [86.74166107, 20.31360817], [86.74111176, 20.31305504], [86.74111176, 20.31278038], [86.73805237, 20.30972099], [86.73777771, 20.30944443], [86.73750305, 20.30944443], [86.73694611, 20.30888939], [86.73665619, 20.30888939], [86.73638916, 20.30861092], [86.73610687, 20.30861092], [86.73583221, 20.30833054], [86.73555756, 20.30833244], [86.73500061, 20.3077774], [86.73472595, 20.30778122], [86.73443604, 20.30750084], [86.73361206, 20.30750084], [86.73332977, 20.30722046], [86.73222351, 20.30722237], [86.73205566, 20.30705452], [86.73194122, 20.30694389], [86.72972107, 20.30694389], [86.72958374, 20.30680466], [86.72944641, 20.30666733], [86.72721863, 20.30667114], [86.72693634, 20.30639076], [86.72638702, 20.30638885], [86.72583008, 20.30694389], [86.72555542, 20.30694389], [86.72528076, 20.30722237], [86.72499847, 20.30722237], [86.72472382, 20.30694389], [86.72472382, 20.30666733], [86.72444153, 20.30639076], [86.72389221, 20.30639076], [86.72381592, 20.30631065], [86.72333527, 20.30583382], [86.72249603, 20.30583191], [86.72194672, 20.30639076], [86.7216568, 20.30639076], [86.72138977, 20.30611038], [86.72110748, 20.30611038], [86.72083282, 20.30583191], [86.72055817, 20.30583382], [86.72044373, 20.30572128], [86.72027588, 20.30555534], [86.72000122, 20.30556107], [86.71986389, 20.30541992], [86.71971893, 20.30527687], [86.71944427, 20.30527687], [86.71888733, 20.30472374], [86.71861267, 20.30472374], [86.71833038, 20.30444527], [86.71806335, 20.3044529], [86.71778107, 20.30417061], [86.71749878, 20.30417061], [86.71721649, 20.30389023], [86.71694183, 20.30389023], [86.71675873, 20.30370331], [86.71639252, 20.30333328], [86.71611023, 20.30333328], [86.71583557, 20.30305481], [86.71555328, 20.30305481], [86.71527863, 20.30277824], [86.71499634, 20.30278015], [86.71444702, 20.30220985], [86.71416473, 20.30221939], [86.71360779, 20.30166626], [86.71333313, 20.30167007], [86.71305847, 20.3013916], [86.71277618, 20.3013916], [86.71193695, 20.30055809], [86.71167755, 20.30055809], [86.71056366, 20.29944992], [86.70999908, 20.29888725], [86.7097168, 20.29889107], [86.70833588, 20.29750061], [86.70853424, 20.29389], [86.70861053, 20.29249954], [86.70944214, 20.29249954], [86.7097168, 20.29277992], [86.70999908, 20.29277992], [86.71028137, 20.29249954], [86.71221924, 20.29249954], [86.71250153, 20.29277992], [86.71277618, 20.29249954], [86.71305847, 20.29249954], [86.71333313, 20.29277992], [86.71360779, 20.29277992], [86.7141571, 20.29222107], [86.71444702, 20.29222488], [86.71472168, 20.2919445], [86.71555328, 20.2919426], [86.71639252, 20.29277992], [86.71721649, 20.29277992], [86.71806335, 20.2919426], [86.71805573, 20.29166603], [86.71848297, 20.2912426], [86.71861267, 20.2911129], [86.71888733, 20.2911129], [86.71888733, 20.29029083], [86.71861267, 20.29000282], [86.71861267, 20.28972244], [86.71833038, 20.28944397], [86.71833038, 20.28889084], [86.71806335, 20.28860855], [86.71805573, 20.28777885], [86.71721649, 20.28694916], [86.71694183, 20.28694916], [86.71639252, 20.2863903], [86.7158432, 20.2863903], [86.71527863, 20.28582954], [86.71472168, 20.28583336], [86.71444702, 20.28555489], [86.71416473, 20.28555489], [86.71360779, 20.28499985], [86.71305847, 20.28499985], [86.71277618, 20.28471947], [86.71250153, 20.28472137], [86.71221924, 20.28444481], [86.71194458, 20.28444481], [86.71180725, 20.28430557], [86.71166992, 20.28416634], [86.71138763, 20.28417015], [86.71111298, 20.28388977], [86.71083069, 20.28388977], [86.71028137, 20.28333092], [86.70972443, 20.28333282], [86.70944214, 20.28305435], [86.70889282, 20.28306007], [86.70861816, 20.28277969], [86.70804596, 20.28277969], [86.70777893, 20.28250122], [86.70722198, 20.28250122], [86.70708466, 20.28236008], [86.70694733, 20.28222084], [86.70666504, 20.28222275], [86.70639038, 20.28194427], [86.70610809, 20.28194427], [86.70583344, 20.2816658], [86.70527649, 20.28166962], [86.70500183, 20.28139114], [86.70471954, 20.28139114], [86.70443726, 20.28110123], [86.70388794, 20.28111076], [86.70361328, 20.2808342], [86.70333099, 20.2808342], [86.70277405, 20.28027725], [86.70194244, 20.28028107], [86.70166779, 20.28000069], [86.7013855, 20.28000069], [86.70111084, 20.27972221], [86.70083618, 20.27972221], [86.700737, 20.27962494], [86.70055389, 20.27944374], [86.70027924, 20.27944374], [86.69999695, 20.27916718], [86.69917297, 20.2791729], [86.69889069, 20.27889061], [86.69805908, 20.27889061], [86.69777679, 20.27861023], [86.69721985, 20.27861023], [86.69695282, 20.27833176], [86.69638824, 20.27833366], [86.69611359, 20.27805519], [86.6958313, 20.27806282], [86.69555664, 20.27778053], [86.69526672, 20.27778053], [86.69499969, 20.27750015], [86.69472504, 20.27750015], [86.69444275, 20.27722168], [86.6938858, 20.27722168], [86.69333649, 20.27666664], [86.69304657, 20.27667046], [86.69277954, 20.27639008], [86.69249725, 20.27639008], [86.6922226, 20.2761116], [86.69194794, 20.27583313], [86.69166565, 20.27583313], [86.69139099, 20.27555466], [86.6911087, 20.27555466], [86.6902771, 20.27472305], [86.69000244, 20.27472305], [86.68861389, 20.2733326], [86.68805695, 20.2733326], [86.68777466, 20.27305794], [86.68749237, 20.27305984], [86.68723297, 20.27277946], [86.6866684, 20.27277946], [86.68554688, 20.27166939], [86.68527985, 20.27194405], [86.6847229, 20.27194405], [86.6838913, 20.27111053], [86.68332672, 20.27111053], [86.68305206, 20.27083015], [86.6827774, 20.27083397], [86.68250275, 20.2705555], [86.68222046, 20.27056122], [86.6819458, 20.27028084], [86.68165588, 20.27028084], [86.68138885, 20.27000046], [86.68110657, 20.27000046], [86.68026733, 20.26916122], [86.68027496, 20.26888847], [86.68000031, 20.26861], [86.68000031, 20.26805305], [86.68026733, 20.2677803], [86.68026733, 20.26694107], [86.68000031, 20.26666641], [86.68000031, 20.26610184], [86.68027496, 20.26583481], [86.68027496, 20.26527786], [86.68055725, 20.26499939], [86.68055725, 20.26468086], [86.68055725, 20.26388931], [86.68000031, 20.26333237], [86.67973328, 20.26333237], [86.67888641, 20.26416588], [86.67888641, 20.26444054], [86.67805481, 20.26527786], [86.67804718, 20.26610184], [86.67749786, 20.26666641], [86.67749786, 20.26694489], [86.67722321, 20.26694489], [86.67707825, 20.26680374], [86.67694092, 20.26666641], [86.67666626, 20.26667023], [86.67610931, 20.26610184], [86.67555237, 20.26667023], [86.67527771, 20.26667023], [86.67416382, 20.2677784], [86.67416382, 20.26833344], [86.67388916, 20.26861191], [86.67388916, 20.26916695], [86.67360687, 20.2694397], [86.67360687, 20.27139091], [86.67333221, 20.27166939], [86.67333221, 20.27249908], [86.67305756, 20.27277946], [86.67305756, 20.27305984], [86.67416382, 20.27416611], [86.67415619, 20.27444077], [86.67472076, 20.27500153], [86.67472076, 20.27527809], [86.67500305, 20.27555466], [86.67500305, 20.27582932], [86.67583466, 20.27666664], [86.67582703, 20.27722168], [86.67610931, 20.27750015], [86.67610931, 20.27778053], [86.6763916, 20.27806282], [86.6763916, 20.27861023], [86.67582703, 20.2791729], [86.67555237, 20.2791729], [86.67500305, 20.27861023], [86.67500305, 20.27833176], [86.67444611, 20.27777863], [86.67444611, 20.27722168], [86.67416382, 20.27694511], [86.67415619, 20.27667046], [86.67388916, 20.27639008], [86.67388916, 20.2761116], [86.6736145, 20.27583313], [86.6736145, 20.27555466], [86.67305756, 20.27500153], [86.67305756, 20.27471924], [86.67277527, 20.27444458], [86.67277527, 20.27416611], [86.67250824, 20.27388763], [86.67250061, 20.2733326], [86.67222595, 20.27333069], [86.67193604, 20.27360916], [86.67111206, 20.27360916], [86.67056274, 20.27416992], [86.67028046, 20.27416992], [86.66928864, 20.27515984], [86.66957092, 20.27563286], [86.66999817, 20.27722168], [86.67028046, 20.27750015], [86.67028046, 20.27778053], [86.67055511, 20.27805519], [86.67055511, 20.27833366], [86.67193604, 20.27972031], [86.67193604, 20.28000069], [86.67222595, 20.28027725], [86.67222595, 20.28110123], [86.67194366, 20.28138924], [86.67194366, 20.28194427], [86.67166901, 20.28222275], [86.67111206, 20.28222275], [86.67082977, 20.28194427], [86.67082977, 20.2816658], [86.67056274, 20.28139114], [86.67056274, 20.28110123], [86.67028046, 20.2808342], [86.67028046, 20.28027725], [86.66999817, 20.28000069], [86.66999817, 20.27943993], [86.66972351, 20.27916718], [86.66971588, 20.27861023], [86.66944885, 20.27833176], [86.66944122, 20.27805519], [86.66916656, 20.27778053], [86.66777802, 20.2761116], [86.66666412, 20.27500153], [86.66665649, 20.27444077], [86.66638947, 20.27416611], [86.66638184, 20.27333069], [86.66694641, 20.27277946], [86.66694641, 20.27249908], [86.66722107, 20.27222824], [86.66750336, 20.27222824], [86.66832733, 20.27139091], [86.66832733, 20.27111053], [86.66860962, 20.27083015], [86.66860962, 20.2705555], [86.66889191, 20.27028084], [86.66889191, 20.27000046], [86.66916656, 20.26972008], [86.66944122, 20.26972198], [86.66972351, 20.26944351], [86.67055511, 20.26944351], [86.67082977, 20.26916695], [86.67111206, 20.26916695], [86.67250061, 20.2677784], [86.67250824, 20.26749992], [86.67277527, 20.26722145], [86.67277527, 20.26666641], [86.67360687, 20.2658329], [86.6736145, 20.26555634], [86.67333221, 20.26527977], [86.67333221, 20.26499939], [86.67305756, 20.26472282], [86.67305756, 20.26444435], [86.67277527, 20.26416588], [86.6727829, 20.26250076], [86.6736145, 20.26166725], [86.67388916, 20.26166916], [86.67444611, 20.2611084], [86.67472076, 20.2611084], [86.67500305, 20.26082993], [86.67555237, 20.26083374], [86.67583466, 20.26055527], [86.67610931, 20.26055908], [86.6763916, 20.26029015], [86.67666626, 20.26029015], [86.67694092, 20.25999832], [86.67778015, 20.25999832], [86.67804718, 20.25971985], [86.67972565, 20.25972176], [86.68027496, 20.25916862], [86.68055725, 20.25917053], [86.68055725, 20.25888824], [86.67973328, 20.25805092], [86.6783371, 20.25805473], [86.67805481, 20.25833321], [86.67694092, 20.25832939], [86.67591095, 20.25834274], [86.67539978, 20.25834846], [86.67404938, 20.25788116], [86.67183685, 20.25761032], [86.66932678, 20.25653076], [86.6682663, 20.25630379], [86.66712189, 20.25605392], [86.66388702, 20.2547226], [86.66204071, 20.25406837], [86.66068268, 20.25392914], [86.65860748, 20.25305557], [86.65619659, 20.25259972], [86.65333557, 20.25138855], [86.6516571, 20.25056267], [86.64977264, 20.25002098], [86.64733887, 20.24908066], [86.6446228, 20.24818993], [86.64319611, 20.24745369], [86.64095306, 20.24693871], [86.6388092, 20.24605942], [86.63630676, 20.24552155], [86.6348114, 20.24417114], [86.63210297, 20.2428894], [86.62953186, 20.2422142], [86.62617493, 20.24072838], [86.62333679, 20.23971939], [86.62220001, 20.23877335], [86.61977386, 20.23789978], [86.61776733, 20.23722267], [86.6166687, 20.23611259], [86.61638641, 20.23612022], [86.6158371, 20.23555946], [86.61554718, 20.23555946], [86.61527252, 20.23527908], [86.61472321, 20.23527908], [86.61444092, 20.23500061], [86.6138916, 20.23500061], [86.61360931, 20.23471832], [86.61333466, 20.23472214], [86.61305237, 20.23444366], [86.61277771, 20.23444366], [86.61222076, 20.23389053], [86.61194611, 20.23389053], [86.61165619, 20.23360825], [86.6111145, 20.23361206], [86.61055756, 20.23305511], [86.61027527, 20.23305511], [86.61000061, 20.23277664], [86.60972595, 20.23278046], [86.60943604, 20.23249817], [86.60916901, 20.23249817], [86.60694122, 20.23167038], [86.60639191, 20.23110962], [86.60610962, 20.23111153], [86.60555267, 20.2305584], [86.60527802, 20.2305603], [86.60500336, 20.23027992], [86.60472107, 20.23027992], [86.60444641, 20.22999001], [86.60416412, 20.22999954], [86.60388947, 20.22972298], [86.60361481, 20.22972298], [86.60333252, 20.2294445], [86.60277557, 20.2294445], [86.60227203, 20.22894287], [86.60194397, 20.22861099], [86.60166931, 20.22861099], [86.60111237, 20.22805977], [86.60083008, 20.22805977], [86.59999847, 20.22722054], [86.59972382, 20.22722244], [86.59944153, 20.22694206], [86.59916687, 20.22694969], [86.59860992, 20.22639084], [86.5983429, 20.22639084], [86.59777832, 20.22583008], [86.59750366, 20.22583389], [86.59722137, 20.22555542], [86.59610748, 20.22555542], [86.59583282, 20.22583389], [86.59555817, 20.22583008], [86.59527588, 20.22611046], [86.59500122, 20.22611046], [86.59471893, 20.22639084], [86.59416962, 20.22583008], [86.59388733, 20.22583389], [86.59361267, 20.22555733], [86.59333038, 20.22527695], [86.59306335, 20.22528076], [86.59278107, 20.22500038], [86.59221649, 20.22500038], [86.59199524, 20.22477722], [86.59194183, 20.22472191], [86.59083557, 20.22472382], [86.58963776, 20.22352982], [86.58916473, 20.22305489], [86.58889008, 20.22305489], [86.58750153, 20.22166634], [86.58721924, 20.22167015], [86.58693695, 20.22139168], [86.58666992, 20.22139168], [86.58555603, 20.22027969], [86.585289, 20.22027969], [86.58499908, 20.22000122], [86.5847168, 20.22000122], [86.58448792, 20.21976852], [86.58416748, 20.21972275], [86.58398438, 20.21953964], [86.58361053, 20.2191658], [86.58333588, 20.21916962], [86.58304596, 20.21889114], [86.58304596, 20.21861076], [86.58277893, 20.21833038], [86.58249664, 20.2183342], [86.58222198, 20.21805573], [86.58194733, 20.21805], [86.58139038, 20.21861076], [86.58082581, 20.21861076], [86.58055878, 20.21889114], [86.58055878, 20.21916962], [86.58027649, 20.2191658], [86.58000183, 20.21944427], [86.57971954, 20.21944427], [86.57955933, 20.21928406], [86.57917023, 20.21888733], [86.57861328, 20.21889114], [86.57833099, 20.21861076], [86.5772171, 20.21861076], [86.57694244, 20.21833038], [86.57555389, 20.2183342], [86.57527924, 20.21805573], [86.57499695, 20.21805573], [86.57472229, 20.21777534], [86.57417297, 20.21778107], [86.5736084, 20.21722031], [86.57333374, 20.21722221], [86.57305908, 20.21694374], [86.57277679, 20.21694374], [86.57263947, 20.2168045], [86.57250214, 20.21666527], [86.57221985, 20.21667099], [86.57211304, 20.21656036], [86.57194519, 20.2163887], [86.5716629, 20.21639061], [86.5707016, 20.21542549], [86.56972504, 20.21444321], [86.56944275, 20.21445084], [86.56916809, 20.21417046], [86.5680542, 20.21416664], [86.56749725, 20.21472168], [86.56694794, 20.21472168], [86.56666565, 20.21444321], [86.56639099, 20.21445084], [86.5661087, 20.21417046], [86.56582642, 20.21417046], [86.56535339, 20.2136898], [86.5652771, 20.2136097], [86.56500244, 20.2136116], [86.56472015, 20.21333313], [86.5644455, 20.21333313], [86.56416321, 20.21305466], [86.56388855, 20.21305466], [86.5633316, 20.21249962], [86.56305695, 20.21249962], [86.56194305, 20.21138954], [86.56194305, 20.21111107], [86.56111908, 20.21027946], [86.56111908, 20.2100029], [86.56027985, 20.20916939], [86.55999756, 20.20916939], [86.5597229, 20.20889091], [86.5588913, 20.20889091], [86.55860901, 20.20860863], [86.55832672, 20.20860863], [86.55805969, 20.20832825], [86.5577774, 20.20833397], [86.55750275, 20.2080555], [86.55722046, 20.20805931], [86.5569458, 20.20778084], [86.55638885, 20.20778084], [86.55610657, 20.20805931], [86.55527496, 20.2080555], [86.55473328, 20.20860863], [86.55472565, 20.20916748], [86.55444336, 20.20944405], [86.55444336, 20.20972252], [86.5541687, 20.2100029], [86.55361176, 20.2100029], [86.55347443, 20.20986176], [86.5533371, 20.20972252], [86.55305481, 20.20972252], [86.55249786, 20.20916748], [86.55222321, 20.20916939], [86.55110931, 20.20805931], [86.55110931, 20.20778084], [86.54944611, 20.20610809], [86.54916382, 20.20611191], [86.54777527, 20.20472145], [86.54777527, 20.20444489], [86.54750061, 20.20416641], [86.54750061, 20.20388985], [86.54582977, 20.20222092], [86.54582977, 20.20194435], [86.54611206, 20.20166588], [86.54582977, 20.20139122], [86.54614258, 20.20055008], [86.54564667, 20.19967079], [86.54556274, 20.19833183], [86.54555511, 20.19805527], [86.54471588, 20.19722176], [86.54389191, 20.19722176], [86.54360962, 20.19750023], [86.54277802, 20.19750023], [86.54222107, 20.19805527], [86.54222107, 20.19833183], [86.54194641, 20.19861031], [86.54194641, 20.19889069], [86.54165649, 20.19917107], [86.54165649, 20.20028114], [86.54164886, 20.20119858], [86.541008, 20.20187187], [86.53888702, 20.20111084], [86.53861237, 20.20111084], [86.53833008, 20.20083046], [86.53778076, 20.20083427], [86.53749847, 20.2005558], [86.53721619, 20.20055962], [86.53666687, 20.2000103], [86.53610992, 20.2000103], [86.53472137, 20.19861031], [86.53472137, 20.19833183], [86.53305817, 20.19666672], [86.53277588, 20.19667053], [86.53277588, 20.19639015], [86.53250122, 20.19611168], [86.53250122, 20.19555473], [86.53166962, 20.19472313], [86.53083038, 20.19472313], [86.52972412, 20.19360924], [86.52944183, 20.19360924], [86.52916718, 20.19387817], [86.52916718, 20.19416618], [86.52889252, 20.19444466], [86.52889252, 20.19471931], [86.52861023, 20.1950016], [86.52805328, 20.1950016], [86.52749634, 20.19444084], [86.52749634, 20.19416618], [86.5266571, 20.19333076], [86.52666473, 20.19305611], [86.52583313, 20.19222069], [86.52583313, 20.19138718], [86.52527618, 20.19082069], [86.52471924, 20.19083405], [86.52444458, 20.19055557], [86.52443695, 20.19028091], [86.52388763, 20.18972015], [86.52305603, 20.18972206], [86.52278137, 20.18944359], [86.52249908, 20.18944359], [86.52138519, 20.18833351], [86.52055359, 20.18833351], [86.51810455, 20.18728447], [86.51721954, 20.18638802], [86.51693726, 20.18610954], [86.51694489, 20.18583488], [86.51611328, 20.18499947], [86.51582336, 20.18499947], [86.51499939, 20.18416977], [86.51499939, 20.18388939], [86.51444244, 20.18333244], [86.51444244, 20.18305588], [86.51416779, 20.18278122], [86.51416779, 20.18250275], [86.51361084, 20.18193817], [86.51333618, 20.18194389], [86.51305389, 20.18166733], [86.51277924, 20.18166924], [86.51235962, 20.18125153], [86.51194763, 20.18082809], [86.51166534, 20.18083382], [86.51148224, 20.1806488], [86.51139069, 20.18055534], [86.51139069, 20.18028069], [86.5111084, 20.1799984], [86.5111084, 20.17860985], [86.51139069, 20.17833328], [86.51083374, 20.17777634], [86.51055908, 20.17805481], [86.50971985, 20.1772213], [86.50945282, 20.17721939], [86.5091629, 20.17749977], [86.50888824, 20.17721939], [86.50805664, 20.1772213], [86.50777435, 20.17694473], [86.50723267, 20.17749977], [86.50694275, 20.17749977], [86.5055542, 20.17888641], [86.5047226, 20.17888641], [86.50389099, 20.17972183], [86.5036087, 20.17944527], [86.50332642, 20.17944908], [86.50297546, 20.17908859], [86.5027771, 20.17888641], [86.50195312, 20.17888069], [86.50166321, 20.17917061], [86.50138855, 20.17917061], [86.50110626, 20.17944908], [86.50055695, 20.17944527], [86.50027466, 20.17972183], [86.49861145, 20.17971992], [86.49833679, 20.1799984], [86.49804688, 20.1799984], [86.49749756, 20.18055916], [86.49555206, 20.18055534], [86.4952774, 20.18083382], [86.49500275, 20.18082809], [86.49472046, 20.18110847], [86.4944458, 20.18110847], [86.49415588, 20.18139076], [86.49388885, 20.18139076], [86.49360657, 20.18166924], [86.49360657, 20.18278122], [86.49582672, 20.18499947], [86.49610901, 20.18499947], [86.49666595, 20.18556023], [86.49694824, 20.18555641], [86.4972229, 20.18583488], [86.49749756, 20.18583107], [86.4991684, 20.1875], [86.4991684, 20.18805313], [86.49944305, 20.18833351], [86.49944305, 20.18861198], [86.49973297, 20.18861008], [86.50027466, 20.18916512], [86.5, 20.18944359], [86.49972534, 20.18944359], [86.49944305, 20.18972206], [86.4991684, 20.18972015], [86.49888611, 20.19000053], [86.49861145, 20.19000053], [86.49833679, 20.19028091], [86.49749756, 20.19028091], [86.4972229, 20.19000053], [86.4972229, 20.18972015], [86.49777985, 20.18916512], [86.49804688, 20.18917084], [86.49833679, 20.18889046], [86.4972229, 20.18778038], [86.49694824, 20.18778038], [86.49610901, 20.18695068], [86.49582672, 20.18695068], [86.49555206, 20.1866703], [86.4952774, 20.1866703], [86.49417114, 20.1855545], [86.49305725, 20.18444252], [86.49277496, 20.18444443], [86.49277496, 20.18388939], [86.49223328, 20.18333244], [86.49194336, 20.18333244], [86.49194336, 20.18305588], [86.49223328, 20.18278122], [86.49223328, 20.18221855], [86.49250031, 20.18194389], [86.49250031, 20.18055534], [86.49276733, 20.18028069], [86.49276733, 20.1799984], [86.49333191, 20.17944908], [86.49360657, 20.17944908], [86.49388885, 20.17917061], [86.49415588, 20.17917061], [86.4944458, 20.17888069], [86.49472046, 20.17888641], [86.4952774, 20.17833328], [86.4952774, 20.17777634], [86.49500275, 20.17749977], [86.4952774, 20.17721939], [86.49500275, 20.17694473], [86.49472046, 20.17694473], [86.49388885, 20.17611122], [86.49388885, 20.17556], [86.49415588, 20.17527962], [86.49388885, 20.17500114], [86.49388885, 20.17472076], [86.49250031, 20.17333221], [86.49222565, 20.17333221], [86.49194336, 20.17305565], [86.4916687, 20.17305946], [86.49138641, 20.17278099], [86.49054718, 20.17278099], [86.49028015, 20.17250061], [86.48972321, 20.17250061], [86.48944092, 20.17222023], [86.48833466, 20.17222214], [86.48805237, 20.17194366], [86.48777771, 20.17194366], [86.48750305, 20.1716671], [86.48638916, 20.1716671], [86.48583221, 20.17222214], [86.48416901, 20.17222214], [86.48388672, 20.17194366], [86.48361206, 20.17194366], [86.48347473, 20.17180824], [86.48332977, 20.1716671], [86.48306274, 20.17167282], [86.4828949, 20.1715107], [86.48278046, 20.17138863], [86.48249817, 20.17139053], [86.48055267, 20.16945267], [86.48055267, 20.16861153], [86.47972107, 20.16777992], [86.47970581, 20.16749763], [86.47944641, 20.16721916], [86.47944641, 20.1669445], [86.47861481, 20.16610909], [86.47833252, 20.16610909], [86.47805786, 20.16583061], [86.47777557, 20.16583252], [86.47750092, 20.16555786], [86.47666931, 20.16555786], [86.47528076, 20.16694069], [86.47528076, 20.16889191], [86.47499847, 20.16917038], [86.47444153, 20.16917038], [86.47416687, 20.16889191], [86.47416687, 20.16778183], [86.47389984, 20.16749763], [86.47389221, 20.16638756], [86.47416687, 20.16610909], [86.47416687, 20.16583061], [86.47472382, 20.16527939], [86.47583008, 20.16417122], [86.47528076, 20.16361046], [86.47499847, 20.16361046], [86.47471619, 20.16333008], [86.47444153, 20.16333389], [86.47416687, 20.16305542], [86.47389984, 20.16306114], [86.47362518, 20.16278648], [86.47277832, 20.16194534], [86.47277832, 20.16167068], [86.47249603, 20.1613903], [86.47249603, 20.16110992], [86.47222137, 20.16083336], [86.47222137, 20.16055107], [86.47194672, 20.16027832], [86.47194672, 20.15888977], [86.4716568, 20.15860939], [86.47194672, 20.15833282], [86.47194672, 20.15805626], [86.47222137, 20.15777016], [86.47250366, 20.15777779], [86.47277832, 20.15749931], [86.47277832, 20.15722275], [86.47305298, 20.15694427], [86.47305298, 20.1566658], [86.4733429, 20.15639114], [86.4733429, 20.15500069], [86.47360992, 20.15472221], [86.47360992, 20.15305519], [86.4733429, 20.15278053], [86.4733429, 20.15221977], [86.47277832, 20.15166855], [86.47277832, 20.15138817], [86.47249603, 20.1511097], [86.47250366, 20.15055466], [86.47166443, 20.14972305], [86.47138977, 20.14972305], [86.47083282, 20.1491642], [86.47084045, 20.14890099], [86.47055817, 20.14890099], [86.46943665, 20.14777946], [86.46916962, 20.14777946], [86.46888733, 20.14750099], [86.46861267, 20.14750099], [86.46847534, 20.14736176], [86.46833038, 20.14722061], [86.4658432, 20.14722061], [86.46555328, 20.14750099], [86.46527863, 20.14750099], [86.46499634, 20.14777946], [86.46472168, 20.14777756], [86.46376801, 20.14855194], [86.46305847, 20.1511097], [86.46305847, 20.15138817], [86.46277618, 20.15167046], [86.46277618, 20.15194511], [86.46250153, 20.15221977], [86.46193695, 20.15389061], [86.46194458, 20.15416718], [86.46166992, 20.15443993], [86.46166992, 20.15500069], [86.46045685, 20.15732002], [86.46038055, 20.15812874], [86.46053314, 20.15906906], [86.46083069, 20.16084099], [86.46083069, 20.16194534], [86.46055603, 20.16222191], [86.45999908, 20.16222191], [86.45972443, 20.16194534], [86.4597168, 20.16167068], [86.45944214, 20.1613903], [86.45944214, 20.16084099], [86.45916748, 20.16055107], [86.45916748, 20.15777779], [86.45944214, 20.15749931], [86.45944214, 20.15639114], [86.4597168, 20.15611267], [86.4597168, 20.15527916], [86.45999908, 20.15500069], [86.45999908, 20.15389061], [86.46055603, 20.15332985], [86.46055603, 20.15305519], [86.46111298, 20.15249825], [86.46111298, 20.15221977], [86.46138763, 20.15194511], [86.46138763, 20.1511097], [86.46166992, 20.15083313], [86.46166992, 20.14999962], [86.46277618, 20.14833069], [86.46472168, 20.14638901], [86.46499634, 20.14639091], [86.46604156, 20.14599037], [86.46761322, 20.14603996], [86.46861267, 20.14611053], [86.46888733, 20.14611053], [86.46916962, 20.14639091], [86.46944427, 20.14638901], [86.47027588, 20.14722252], [86.47055817, 20.14722061], [86.47110748, 20.14777946], [86.47138977, 20.14777946], [86.47222137, 20.14861107], [86.47249603, 20.14861107], [86.47305298, 20.1491642], [86.47305298, 20.14944077], [86.47389221, 20.15027618], [86.47389221, 20.15055466], [86.47416687, 20.15083122], [86.47416687, 20.15138817], [86.47444153, 20.15167046], [86.47444153, 20.15194511], [86.47471619, 20.15221977], [86.47472382, 20.15278053], [86.47528076, 20.15332985], [86.47528076, 20.15360832], [86.47499847, 20.15389061], [86.47499847, 20.15416718], [86.47472382, 20.15444374], [86.47471619, 20.15583229], [86.47444153, 20.15611267], [86.47444153, 20.15777016], [86.47416687, 20.15805626], [86.47416687, 20.16110992], [86.47444153, 20.1613903], [86.47444153, 20.16167068], [86.47528076, 20.16250038], [86.47556305, 20.16250038], [86.47583008, 20.16278076], [86.47750092, 20.16278076], [86.4777832, 20.16306114], [86.47805786, 20.16305542], [86.47833252, 20.16333389], [86.47860718, 20.16333008], [86.48027802, 20.16500092], [86.48027802, 20.16527939], [86.48082733, 20.16583061], [86.48083496, 20.16610909], [86.48444366, 20.1697216], [86.48472595, 20.16970825], [86.48500061, 20.17000008], [86.4852829, 20.17000008], [86.48555756, 20.1697216], [86.48833466, 20.1669445], [86.48833466, 20.16638756], [86.48860931, 20.16610909], [86.48860931, 20.16583061], [86.4888916, 20.16555786], [86.48887634, 20.16500092], [86.48916626, 20.16472054], [86.48916626, 20.16361046], [86.48944092, 20.16333008], [86.48944092, 20.16277695], [86.48972321, 20.16250038], [86.48972321, 20.16222], [86.48916626, 20.16166687], [86.48916626, 20.16110992], [86.48944092, 20.16083336], [86.48944092, 20.16028023], [86.48972321, 20.15999985], [86.48972321, 20.15971947], [86.4908371, 20.1586113], [86.4908371, 20.15805626], [86.49111176, 20.15777016], [86.49111176, 20.15749931], [86.4908371, 20.15722275], [86.4908371, 20.1566658], [86.49054718, 20.15639114], [86.49054718, 20.15611267], [86.48972321, 20.15527916], [86.48972321, 20.15500069], [86.48944092, 20.15471077], [86.48944092, 20.15278053], [86.48972321, 20.15249825], [86.48972321, 20.15221977], [86.48944092, 20.15194511], [86.48944092, 20.15167046], [86.48916626, 20.15138817], [86.48916626, 20.1511097], [86.48805237, 20.14999962], [86.48777771, 20.14999962], [86.48750305, 20.14972115], [86.48722076, 20.14972305], [86.4861145, 20.14861107], [86.48610687, 20.14722061], [86.48583221, 20.14694595], [86.48583221, 20.14666748], [86.48555756, 20.14639091], [86.48555756, 20.14556122], [86.48443604, 20.1444397], [86.48361206, 20.14444351], [86.48332977, 20.14472389], [86.48249817, 20.14472389], [86.48240662, 20.14463043], [86.48222351, 20.14444351], [86.48194122, 20.14444351], [86.48180389, 20.14430618], [86.48166656, 20.14416695], [86.48139191, 20.14417076], [86.48110962, 20.14389038], [86.48082733, 20.14389038], [86.48059845, 20.14365959], [86.47972107, 20.14361191], [86.47944641, 20.14333344], [86.47888947, 20.14333344], [86.47861481, 20.14305496], [86.47805786, 20.14306259], [86.47798157, 20.14297867], [86.47777557, 20.1427784], [86.47694397, 20.1427784], [86.47666931, 20.14250183], [86.47611237, 20.14250183], [86.47538757, 20.14188957], [86.47460175, 20.14141846], [86.47445679, 20.14075089], [86.474823, 20.13953018], [86.47553253, 20.13838196], [86.4761734, 20.13791084], [86.47666931, 20.13805771], [86.47666931, 20.13833046], [86.47583008, 20.13916588], [86.47583008, 20.13944054], [86.47556305, 20.13972855], [86.47556305, 20.14055824], [86.47638702, 20.14139175], [86.47721863, 20.14139175], [86.47750092, 20.14167023], [86.47805786, 20.14166641], [86.47833252, 20.14194489], [86.47944641, 20.14194489], [86.47972107, 20.14222145], [86.48166656, 20.14222145], [86.48194122, 20.14250183], [86.48221588, 20.14250183], [86.48249817, 20.14222145], [86.48332977, 20.14222145], [86.48361206, 20.14194489], [86.48388672, 20.14194489], [86.48416901, 20.14166641], [86.48416901, 20.14082909], [86.48444366, 20.14055634], [86.48443604, 20.14027977], [86.48416901, 20.13999748], [86.48388672, 20.13999748], [86.48361206, 20.13972855], [86.48332977, 20.13972855], [86.48221588, 20.13861084], [86.48166656, 20.13861084], [86.48110962, 20.13805962], [86.48055267, 20.13805962], [86.48000336, 20.13750076], [86.48000336, 20.13722038], [86.47888947, 20.13611031], [86.47888947, 20.13582993], [86.47861481, 20.13555527], [86.47860718, 20.13528061], [86.47833252, 20.13500023], [86.47833252, 20.13278008], [86.47888947, 20.13222122], [86.47916412, 20.13222313], [86.48000336, 20.13138962], [86.48000336, 20.1297226], [86.48027802, 20.12944412], [86.48027802, 20.12639046], [86.48000336, 20.12610817], [86.48000336, 20.12583351], [86.47888947, 20.12472153], [86.47666931, 20.12472916], [86.47638702, 20.12445068], [86.47471619, 20.12445068], [86.47444153, 20.12472916], [86.47416687, 20.12472916], [86.47360992, 20.1241703], [86.4733429, 20.1241703], [86.4730072, 20.12383461], [86.47250366, 20.12333298], [86.47222137, 20.12333298], [86.47194672, 20.12305832], [86.4716568, 20.12306023], [86.4716568, 20.12277985], [86.47110748, 20.12222099], [86.47110748, 20.12194443], [86.47083282, 20.12194443], [86.47083282, 20.12166405], [86.47000122, 20.12083244], [86.46971893, 20.12083244], [86.46944427, 20.12055588], [86.46916962, 20.12055969], [86.46888733, 20.12028122], [86.46861267, 20.12028122], [86.46833038, 20.12000084], [86.46805573, 20.12000084], [86.46749878, 20.11944389], [86.46722412, 20.11944389], [86.46694183, 20.11916733], [86.46639252, 20.11916733], [86.46583557, 20.11972237], [86.46555328, 20.11972237], [86.46527863, 20.11944389], [86.46527863, 20.11888885], [86.46499634, 20.11860275], [86.46499634, 20.11777687], [86.46470642, 20.11750031], [86.46470642, 20.11722183], [86.46333313, 20.11583328], [86.46305847, 20.11583328], [86.46277618, 20.11555481], [86.46277618, 20.11528015], [86.46221924, 20.11471939], [86.46221924, 20.11444473], [86.46250153, 20.11416626], [86.46250153, 20.11361122], [86.46277618, 20.11333084], [86.46277618, 20.1119442], [86.46305847, 20.11166573], [86.46305847, 20.11111069], [86.46277618, 20.11083031], [86.46277618, 20.11000061], [86.46250153, 20.10972023], [86.46250153, 20.10916519], [86.46277618, 20.10889053], [86.46277618, 20.10861015], [86.46333313, 20.10805321], [86.46470642, 20.10666084], [86.46472168, 20.10638809], [86.4658432, 20.10527992], [86.4658432, 20.10499954], [86.46611023, 20.10472107], [86.46611023, 20.1044445], [86.46694183, 20.1036129], [86.46721649, 20.10362053], [86.46749878, 20.10333252], [86.46833038, 20.10333252], [86.46861267, 20.10305595], [86.46916962, 20.10305977], [86.46943665, 20.10277939], [86.46971893, 20.10277939], [86.47000122, 20.10250282], [86.47027588, 20.10250282], [86.47084045, 20.10193825], [86.47083282, 20.10083389], [86.47055817, 20.10055542], [86.47055817, 20.10028076], [86.47000122, 20.09971809], [86.47000122, 20.09944534], [86.46943665, 20.0988903], [86.46971893, 20.09860992], [86.46971893, 20.09833336], [86.46944427, 20.09805489], [86.46944427, 20.09777641], [86.46971893, 20.09749985], [86.47138977, 20.09749985], [86.47194672, 20.09805489], [86.47222137, 20.09805107], [86.47333527, 20.09916878], [86.47250366, 20.09972191], [86.47222137, 20.09944534], [86.47138977, 20.09944534], [86.47138977, 20.09971809], [86.4716568, 20.10000038], [86.4716568, 20.10028076], [86.47194672, 20.10055542], [86.47194672, 20.10082817], [86.47222137, 20.10110855], [86.47222137, 20.10139084], [86.47250366, 20.1016674], [86.47250366, 20.10194397], [86.47222137, 20.10221863], [86.47222137, 20.10277748], [86.47166443, 20.10333252], [86.47138977, 20.10333252], [86.47110748, 20.10362053], [86.47083282, 20.1036129], [86.46983337, 20.10461044], [86.46971893, 20.10472107], [86.46944427, 20.1044445], [86.46861267, 20.1044445], [86.46806335, 20.10499954], [86.46749878, 20.10499954], [86.46721649, 20.10527992], [86.46722412, 20.10555649], [86.46694183, 20.10583305], [86.46694183, 20.10610962], [86.46555328, 20.10750008], [86.46555328, 20.10777855], [86.46499634, 20.10833359], [86.46499634, 20.10861015], [86.46470642, 20.10889053], [86.46470642, 20.11000061], [86.46527863, 20.11055565], [86.46499634, 20.11083031], [86.46499634, 20.11111069], [86.46444702, 20.11166954], [86.46444702, 20.11250114], [86.46416473, 20.11277962], [86.4641571, 20.11333084], [86.46389008, 20.11361122], [86.46389008, 20.11471939], [86.46499634, 20.11583328], [86.46527863, 20.11582947], [86.46611023, 20.11666679], [86.46611023, 20.11722183], [86.46694183, 20.11806107], [86.46778107, 20.11805534], [86.46805573, 20.11833382], [86.46888733, 20.11833382], [86.46916962, 20.11861038], [86.46971893, 20.11860275], [86.47000122, 20.11889076], [86.47027588, 20.11889076], [86.47055817, 20.11917114], [86.47084045, 20.11917114], [86.47444153, 20.12277985], [86.47556305, 20.12277985], [86.47583008, 20.12249947], [86.47666931, 20.12249947], [86.47693634, 20.12277985], [86.47805786, 20.12277985], [86.47833252, 20.12306023], [86.47888947, 20.12306023], [86.48139191, 20.12555504], [86.48139191, 20.12583351], [86.48166656, 20.12610817], [86.48166656, 20.13138962], [86.48139191, 20.13166618], [86.48139191, 20.13194466], [86.48110962, 20.13222122], [86.48110962, 20.13249969], [86.48083496, 20.13277817], [86.48083496, 20.13333321], [86.48472595, 20.13722229], [86.48500061, 20.13722229], [86.48518372, 20.1374073], [86.48555756, 20.13778114], [86.48583984, 20.13778114], [86.48665619, 20.13861084], [86.48666382, 20.13888741], [86.48722076, 20.13944054], [86.48722076, 20.14027977], [86.48750305, 20.14055824], [86.48777771, 20.14055824], [86.48832703, 20.13999748], [86.48832703, 20.13972855], [86.48887634, 20.13916969], [86.48887634, 20.13833046], [86.48916626, 20.13805771], [86.48916626, 20.13667107], [86.48944092, 20.13639069], [86.48944092, 20.13556099], [86.48972321, 20.13528061], [86.48972321, 20.13471985], [86.48944092, 20.13444328], [86.48944092, 20.13389015], [86.48999786, 20.13332939], [86.49028015, 20.13333321], [86.49055481, 20.13361168], [86.4908371, 20.13361168], [86.49111176, 20.13333321], [86.49111176, 20.13305473], [86.49028015, 20.13222313], [86.48999786, 20.13222313], [86.4888916, 20.13111115], [86.48887634, 20.13083267], [86.48805237, 20.12999916], [86.48805237, 20.1297226], [86.48777771, 20.12944412], [86.48777771, 20.12861061], [86.48750305, 20.12832832], [86.48750305, 20.12750053], [86.48722076, 20.12721825], [86.48722076, 20.12694359], [86.48750305, 20.12666893], [86.48750305, 20.12556076], [86.48777771, 20.12528038], [86.48777771, 20.12333107], [86.48805237, 20.12305832], [86.48777771, 20.12277985], [86.48777771, 20.12222099], [86.48750305, 20.12194443], [86.48750305, 20.12166405], [86.48833466, 20.12083244], [86.48860931, 20.12083054], [86.48916626, 20.12138939], [86.48916626, 20.12194443], [86.48944092, 20.12222099], [86.48944092, 20.12499809], [86.48916626, 20.12528038], [86.48916626, 20.12555504], [86.48887634, 20.1258297], [86.48887634, 20.12639046], [86.48860931, 20.12666893], [86.48860931, 20.12694359], [86.48832703, 20.12721825], [86.48832703, 20.12750053], [86.48860931, 20.12779045], [86.48887634, 20.12779045], [86.4888916, 20.12805557], [86.48860931, 20.12832832], [86.48860931, 20.12861061], [86.48887634, 20.12888908], [86.4888916, 20.12916756], [86.49055481, 20.13083267], [86.49111176, 20.13083267], [86.4916687, 20.13138962], [86.4916687, 20.13166618], [86.49194336, 20.13194466], [86.49194336, 20.13222313], [86.49222565, 20.13249969], [86.49222565, 20.13333321], [86.49194336, 20.13360023], [86.49194336, 20.13389015], [86.4916687, 20.13417053], [86.4916687, 20.13444328], [86.49138641, 20.13471985], [86.49138641, 20.13500023], [86.49111176, 20.13528061], [86.49111176, 20.13611031], [86.49138641, 20.13639069], [86.49138641, 20.13666534], [86.4916687, 20.13694382], [86.4916687, 20.13722038], [86.49194336, 20.13750076], [86.49194336, 20.13805771], [86.49223328, 20.13833046], [86.49222565, 20.13916588], [86.49250031, 20.13944054], [86.49222565, 20.13972282], [86.49223328, 20.13999748], [86.49194336, 20.14027977], [86.49194336, 20.14055634], [86.49222565, 20.1408329], [86.49223328, 20.14111137], [86.49194336, 20.14139175], [86.49194336, 20.14167023], [86.49111176, 20.14250183], [86.48999786, 20.14250183], [86.48972321, 20.14222145], [86.4888916, 20.14305496], [86.48916626, 20.14333344], [86.48944092, 20.14333344], [86.48972321, 20.14361191], [86.48999786, 20.14361191], [86.49028015, 20.14389038], [86.49194336, 20.14389038], [86.49223328, 20.14417076], [86.49276733, 20.14417076], [86.49500275, 20.14639091], [86.49500275, 20.14666748], [86.4952774, 20.14694023], [86.4952774, 20.14750099], [86.49582672, 20.14805984], [86.49582672, 20.14861107], [86.49555206, 20.14888954], [86.49555206, 20.14972115], [86.4952774, 20.14999962], [86.4952774, 20.15027618], [86.49500275, 20.15055466], [86.49500275, 20.15083313], [86.49472046, 20.1511116], [86.49472046, 20.15221977], [86.4944458, 20.15249825], [86.49472046, 20.15278053], [86.49472046, 20.15332985], [86.49500275, 20.15360832], [86.49500275, 20.15389061], [86.49610901, 20.15500069], [86.49666595, 20.15500069], [86.49694824, 20.15527916], [86.49749756, 20.15527916], [86.49777985, 20.15555954], [86.49804688, 20.15555954], [86.49861145, 20.15611267], [86.49888611, 20.15611267], [86.4991684, 20.15639114], [86.49944305, 20.15638924], [86.5, 20.15694427], [86.50027466, 20.15694427], [86.50111389, 20.15777779], [86.50138855, 20.15777779], [86.50222015, 20.15860939], [86.50222015, 20.15888977], [86.50250244, 20.15916634], [86.50250244, 20.15944481], [86.5027771, 20.15971947], [86.5027771, 20.16028023], [86.50333405, 20.16083336], [86.50332642, 20.16110992], [86.5036087, 20.1613884], [86.5036087, 20.16222], [86.50388336, 20.16250038], [86.50388336, 20.16306114], [86.50332642, 20.16361046], [86.50389099, 20.1641655], [86.50388336, 20.16444016], [86.50554657, 20.16610909], [86.5055542, 20.16638756], [86.50749969, 20.16833305], [86.50776672, 20.16832924], [86.50860596, 20.16917038], [86.50888824, 20.16916656], [86.50944519, 20.1697216], [86.51000977, 20.16970825], [86.51027679, 20.17000008], [86.51055908, 20.17000008], [86.51082611, 20.17028046], [86.5111084, 20.17027855], [86.51304626, 20.17222023], [86.51304626, 20.17250061], [86.51416779, 20.17361069], [86.51416779, 20.17389107], [86.51444244, 20.17416954], [86.51527405, 20.17416573], [86.51555634, 20.1744442], [86.51611328, 20.1744442], [86.51638794, 20.17472267], [86.51667023, 20.17472076], [86.51689148, 20.17494392], [86.51777649, 20.17584038], [86.51805878, 20.17584038], [86.51832581, 20.17611122], [86.51860809, 20.17611122], [86.51888275, 20.17638969], [86.51916504, 20.17638969], [86.51935577, 20.17657661], [86.51944733, 20.17667007], [86.51972198, 20.17666626], [86.51999664, 20.17694473], [86.52027893, 20.17694092], [86.52083588, 20.17749977], [86.52111053, 20.17749977], [86.52139282, 20.17778015], [86.52222443, 20.17777634], [86.52278137, 20.17833328], [86.52305603, 20.17833328], [86.52361298, 20.17888641], [86.52388763, 20.17888069], [86.52416992, 20.17917061], [86.52416992, 20.17944527], [86.52443695, 20.17971992], [86.52444458, 20.1799984], [86.52527618, 20.18083382], [86.52555847, 20.18083382], [86.52694702, 20.18221855], [86.52694702, 20.18250275], [86.52749634, 20.18305588], [86.52749634, 20.18333244], [86.52777863, 20.18361282], [86.52777863, 20.18388939], [86.52861023, 20.1847229], [86.52861023, 20.18499947], [86.52889252, 20.18527985], [86.52889252, 20.18555641], [86.52916718, 20.18583488], [86.53028107, 20.18583488], [86.53055573, 20.18611145], [86.53082275, 20.18610954], [86.53111267, 20.18638992], [86.53166962, 20.18638992], [86.53221893, 20.18695068], [86.53250122, 20.18694305], [86.53277588, 20.18722153], [86.53305817, 20.18721962], [86.53333282, 20.1875], [86.53360748, 20.1875], [86.5341568, 20.1880703], [86.53472137, 20.18805313], [86.53500366, 20.18833351], [86.53500366, 20.18861198], [86.53555298, 20.18861198], [86.53610992, 20.18805313], [86.53666687, 20.18805313], [86.53682709, 20.18821716], [86.53694153, 20.18833351], [86.53722382, 20.18805313], [86.53794098, 20.18864632], [86.53881073, 20.18944359], [86.53902435, 20.18972206], [86.5393219, 20.19041061], [86.54081726, 20.1917305], [86.54059601, 20.19219971], [86.53959656, 20.19226074], [86.53916931, 20.19308281], [86.53939056, 20.1936264], [86.53959656, 20.1937027], [86.53965759, 20.1938324], [86.53986359, 20.19382858], [86.54000092, 20.19388962], [86.54055786, 20.19388962], [86.54083252, 20.19360924], [86.54161072, 20.19333839], [86.54167938, 20.19330406], [86.54201508, 20.19311523], [86.54250336, 20.19333267], [86.54277802, 20.19333076], [86.54305267, 20.19360924], [86.54360962, 20.19360924], [86.54389191, 20.19333076], [86.54416656, 20.19360924], [86.54444122, 20.19360924], [86.54472351, 20.19388962], [86.54499817, 20.19388962], [86.54528046, 20.19360924], [86.54694366, 20.19360924], [86.54722595, 20.19388962], [86.5477829, 20.19387817], [86.54805756, 20.19416809], [86.54833221, 20.19416618], [86.5486145, 20.19444466], [86.54916382, 20.19444466], [86.54944611, 20.19472313], [86.55000305, 20.19472313], [86.55110931, 20.19583321], [86.5513916, 20.19582939], [86.55304718, 20.19750023], [86.55305481, 20.1977787], [86.55361176, 20.19833183], [86.55361176, 20.19861031], [86.55472565, 20.19972229], [86.55499268, 20.19972038], [86.55526733, 20.2000103], [86.55555725, 20.2000103], [86.55722046, 20.20166969], [86.5577774, 20.20166969], [86.5588913, 20.20055962], [86.5588913, 20.20028114], [86.55805969, 20.19944191], [86.5577774, 20.19944382], [86.55750275, 20.19916725], [86.55722046, 20.19917107], [86.55444336, 20.19639015], [86.5541687, 20.19639015], [86.55361176, 20.19582939], [86.5533371, 20.19583321], [86.55278015, 20.19527817], [86.55249786, 20.19528008], [86.55110931, 20.19387817], [86.55083466, 20.19388962], [86.55027771, 20.19333267], [86.55000305, 20.19333267], [86.5499115, 20.19324112], [86.54972076, 20.19305611], [86.54915619, 20.19305992], [86.54888916, 20.19277954], [86.54860687, 20.19277954], [86.5477829, 20.19194031], [86.54750061, 20.19194412], [86.54611206, 20.19055557], [86.54582977, 20.19055939], [86.54471588, 20.18943977], [86.54389191, 20.18944359], [86.54222107, 20.18777847], [86.54110718, 20.18778038], [86.54055786, 20.18721962], [86.54027557, 20.18722153], [86.53944397, 20.18638802], [86.53916931, 20.18638992], [86.53861237, 20.18583107], [86.53833008, 20.18583488], [86.53694153, 20.18444443], [86.53666687, 20.18444443], [86.53444672, 20.18222237], [86.53416443, 20.18222237], [86.53388977, 20.18194389], [86.53360748, 20.18194389], [86.53138733, 20.17972183], [86.53111267, 20.17972183], [86.52722168, 20.17583275], [86.52694702, 20.17584038], [86.52639008, 20.17527962], [86.52610779, 20.17527962], [86.52555847, 20.17472076], [86.52555847, 20.1744442], [86.52249908, 20.17138863], [86.52249908, 20.17111015], [86.52055359, 20.16916656], [86.52054596, 20.16889191], [86.51999664, 20.16832924], [86.51999664, 20.16805649], [86.51917267, 20.16721916], [86.51916504, 20.1669445], [86.51833344, 20.16610909], [86.51832581, 20.16583061], [86.51805878, 20.16555786], [86.51805878, 20.16527939], [86.51777649, 20.16500092], [86.51777649, 20.16472054], [86.51667023, 20.16361046], [86.51667023, 20.16333008], [86.51555634, 20.16222191], [86.51555634, 20.16194534], [86.51526642, 20.16167068], [86.51526642, 20.1613903], [86.51499939, 20.16110992], [86.51499939, 20.16083336], [86.51444244, 20.16028023], [86.51444244, 20.15999985], [86.51389313, 20.1594429], [86.5138855, 20.15888977], [86.51361084, 20.1586113], [86.51361084, 20.15833282], [86.51249695, 20.15722275], [86.51249695, 20.1566658], [86.51222229, 20.15639114], [86.51222229, 20.15611267], [86.51139069, 20.15527916], [86.51139069, 20.15500069], [86.5111084, 20.15471077], [86.5111084, 20.15444374], [86.5091629, 20.15249825], [86.5091629, 20.15195847], [86.50888824, 20.15167046], [86.50888824, 20.15138817], [86.50860596, 20.1511097], [86.50861359, 20.15055466], [86.5083313, 20.15027618], [86.5083313, 20.14972115], [86.50805664, 20.14944458], [86.50805664, 20.1491642], [86.50776672, 20.14890099], [86.50776672, 20.14861107], [86.50723267, 20.14805984], [86.50723267, 20.14777946], [86.50666809, 20.14722061], [86.50666809, 20.14694595], [86.5063858, 20.14666748], [86.5063858, 20.14611053], [86.50611115, 20.14583015], [86.50611115, 20.1455555], [86.50583649, 20.14528084], [86.50583649, 20.14500046], [86.50554657, 20.14472008], [86.5055542, 20.14416695], [86.5047226, 20.14332962], [86.50444794, 20.14333344], [86.50416565, 20.14305496], [86.50388336, 20.14306259], [86.5036087, 20.14277077], [86.5036087, 20.14222145], [86.50416565, 20.14166641], [86.5036087, 20.14111137], [86.50250244, 20.14111137], [86.5022583, 20.14086914], [86.5008316, 20.13944435], [86.50055695, 20.13944435], [86.50048065, 20.13936806], [86.50027466, 20.13916588], [86.5, 20.13916969], [86.49989319, 20.13905907], [86.49972534, 20.13888741], [86.49973297, 20.13861084], [86.50055695, 20.13777542], [86.49973297, 20.13694], [86.49972534, 20.13638878], [86.49944305, 20.13611031], [86.49944305, 20.13582993], [86.49777985, 20.13416672], [86.49777985, 20.13389015], [86.49749756, 20.13360023], [86.49749756, 20.13305473], [86.4972229, 20.13277817], [86.4972229, 20.13249969], [86.49694824, 20.13222122], [86.49694824, 20.13138962], [86.49666595, 20.13111115], [86.49666595, 20.1297226], [86.4963913, 20.12944412], [86.4963913, 20.12916756], [86.49666595, 20.12888908], [86.49666595, 20.12861061], [86.4963913, 20.12832832], [86.49610901, 20.12833405], [86.49583435, 20.12805557], [86.49582672, 20.12779045], [86.4952774, 20.12721825], [86.4952774, 20.12639046], [86.49472046, 20.1258297], [86.49472046, 20.12555504], [86.49415588, 20.12499809], [86.49415588, 20.12472916], [86.49388885, 20.12445068], [86.49388885, 20.12360954], [86.49277496, 20.12249947], [86.49250031, 20.12249947], [86.49223328, 20.12222099], [86.49194336, 20.1222229], [86.4908371, 20.12111092], [86.4908371, 20.12083054], [86.49055481, 20.12055588], [86.49028015, 20.12028122], [86.49028015, 20.12000084], [86.48999786, 20.11972046], [86.48972321, 20.11972237], [86.48944092, 20.11944389], [86.48916626, 20.11944389], [86.48833466, 20.11861038], [86.48777771, 20.11861038], [86.48777771, 20.11777687], [86.48722076, 20.11722183], [86.48694611, 20.11722374], [86.486763, 20.11703873], [86.48638916, 20.11666679], [86.48638916, 20.11639023], [86.48665619, 20.11611176], [86.48666382, 20.11583328], [86.48638916, 20.11555481], [86.48603058, 20.11522293], [86.48574829, 20.11474991], [86.48532104, 20.11421013], [86.48500061, 20.11388969], [86.48332977, 20.11555481], [86.48332977, 20.11611176], [86.48388672, 20.11666679], [86.48388672, 20.11722183], [86.48416901, 20.11750031], [86.48416901, 20.11777687], [86.48472595, 20.11833191], [86.48416901, 20.11889076], [86.48388672, 20.11889076], [86.48332977, 20.11833191], [86.48332977, 20.11805534], [86.48278046, 20.11750031], [86.48278046, 20.11722183], [86.48249817, 20.11694527], [86.48249817, 20.11667061], [86.48110962, 20.11528015], [86.48110962, 20.11500168], [86.48082733, 20.11471939], [86.48083496, 20.11416626], [86.48110962, 20.11388969], [86.48110962, 20.11361122], [86.48221588, 20.11250114], [86.48306274, 20.11250114], [86.48332977, 20.11222076], [86.48332977, 20.1119442], [86.48361206, 20.11166573], [86.48361206, 20.11111069], [86.48388672, 20.11083031], [86.48388672, 20.11027527], [86.48332977, 20.10972023], [86.48278046, 20.11028099], [86.48249817, 20.11028099], [86.48139191, 20.10917091], [86.48139191, 20.10889053], [86.47970581, 20.1072197], [86.47944641, 20.1072197], [86.47915649, 20.10750008], [86.47888947, 20.10750008], [86.47888947, 20.10778046], [86.47916412, 20.10805321], [86.47916412, 20.10833359], [86.47944641, 20.10861015], [86.47944641, 20.10889053], [86.47972107, 20.10916519], [86.47972107, 20.10944366], [86.48000336, 20.10972023], [86.48000336, 20.11000061], [86.48027802, 20.11028099], [86.48055267, 20.11028099], [86.48082733, 20.11055946], [86.48139191, 20.11055946], [86.48194122, 20.11111069], [86.48139191, 20.11166573], [86.48083496, 20.11222267], [86.48055267, 20.11222267], [86.48000336, 20.11166573], [86.47970581, 20.11166954], [86.47915649, 20.11111069], [86.47860718, 20.11111069], [86.47833252, 20.11083031], [86.47777557, 20.11083412], [86.47721863, 20.11027527], [86.47721863, 20.11000061], [86.47693634, 20.10972023], [86.47694397, 20.10944366], [86.47666931, 20.10916519], [86.47666931, 20.10750008], [86.47638702, 20.1072197], [86.47638702, 20.10638809], [86.47611237, 20.10610962], [86.47611237, 20.10583305], [86.47583008, 20.10555649], [86.47583008, 20.10527992], [86.47528076, 20.10472107], [86.47528076, 20.1044445], [86.47499847, 20.10416603], [86.47499847, 20.10388947], [86.47556305, 20.10333252], [86.47583008, 20.10333252], [86.47611237, 20.10305595], [86.47638702, 20.10305977], [86.47666931, 20.10277939], [86.47666931, 20.10221863], [86.47638702, 20.10194397], [86.47638702, 20.1016674], [86.47611237, 20.10139084], [86.47611237, 20.10110855], [86.47583008, 20.10082817], [86.47583008, 20.10055542], [86.47471619, 20.09944916], [86.4716568, 20.09638977], [86.47138977, 20.09638977], [86.47138977, 20.09610939], [86.47110748, 20.09583282], [86.47110748, 20.09555435], [86.47055817, 20.09500122], [86.47027588, 20.09500122], [86.47027588, 20.09472084], [86.46250153, 20.08694458], [86.46250153, 20.08666611], [86.46138763, 20.08555984], [86.46083069, 20.08555984], [86.45999908, 20.08472061], [86.45972443, 20.08472252], [86.45916748, 20.08416557], [86.45861053, 20.08416939], [86.45777893, 20.08333015], [86.45777893, 20.0830555], [86.45749664, 20.08278084], [86.45749664, 20.08249092], [86.45694733, 20.08194351], [86.45694733, 20.08111191], [86.45500183, 20.07916641], [86.45471954, 20.07917023], [86.45443726, 20.07888985], [86.45417023, 20.07888985], [86.45388794, 20.07860947], [86.45388794, 20.07805634], [86.45333099, 20.07749939], [86.4522171, 20.07749939], [86.45166779, 20.07694244], [86.45121765, 20.07666969], [86.45072937, 20.07636833], [86.4502182, 20.07605553], [86.44970703, 20.07563972], [86.4493866, 20.07496071], [86.44908142, 20.07432938], [86.44863892, 20.07389069], [86.44819641, 20.07354927], [86.44783783, 20.0732708], [86.44754028, 20.07299232], [86.44728088, 20.07270622], [86.44700623, 20.07242966], [86.44673157, 20.07215309], [86.44642639, 20.0718174], [86.4460907, 20.07143974], [86.44564819, 20.07113075], [86.44439697, 20.0706234], [86.44368744, 20.0699482], [86.44288635, 20.06867027], [86.44248962, 20.06837845], [86.44207001, 20.06805992], [86.44164276, 20.06772995], [86.44124603, 20.06735992], [86.44082642, 20.06694984], [86.4404068, 20.06653023], [86.43990326, 20.06610107], [86.43937683, 20.06565857], [86.43898773, 20.06508064], [86.43869781, 20.06443024], [86.43849182, 20.0638504], [86.43818665, 20.06339073], [86.43785858, 20.06301117], [86.43754578, 20.06255913], [86.43730164, 20.06196213], [86.43708038, 20.06139946], [86.43678284, 20.0609684], [86.43641663, 20.06067085], [86.43601227, 20.06049538], [86.43559265, 20.06032944], [86.43512726, 20.06018066], [86.43466949, 20.05999756], [86.43412018, 20.05985069], [86.43344116, 20.05983353], [86.43273163, 20.05989456], [86.43224335, 20.05978012], [86.43179321, 20.05955124], [86.4312973, 20.05919266], [86.43078613, 20.05879021], [86.43032837, 20.05827332], [86.43000031, 20.05768776], [86.42973328, 20.05711174], [86.42951202, 20.05656433], [86.42945099, 20.05602455], [86.42944336, 20.0555191], [86.42942047, 20.05507088], [86.42935181, 20.05467987], [86.42919159, 20.05438232], [86.4283371, 20.05361176], [86.42805481, 20.05361176], [86.42694092, 20.05471992], [86.42694092, 20.05500031], [86.42583466, 20.05611038], [86.42555237, 20.05611038], [86.42472076, 20.05694389], [86.42444611, 20.05694389], [86.42416382, 20.05722237], [86.42388916, 20.05722046], [86.42360687, 20.05750084], [86.42193604, 20.05750084], [86.42166901, 20.05778122], [86.41971588, 20.05778122], [86.41944122, 20.05750084], [86.41889191, 20.05750084], [86.41860962, 20.05722046], [86.41805267, 20.05722237], [86.41777802, 20.05694389], [86.41722107, 20.05694389], [86.41708374, 20.05680466], [86.41694641, 20.05666542], [86.41638947, 20.05667114], [86.41610718, 20.05639076], [86.41500092, 20.05639076], [86.41471863, 20.05611038], [86.41388702, 20.05611038], [86.41362, 20.05583], [86.41176605, 20.05554008], [86.41176605, 20.05513954], [86.41311646, 20.05500031], [86.41610718, 20.05500031], [86.41638947, 20.05528069], [86.41722107, 20.05527687], [86.41733551, 20.0553894], [86.41750336, 20.05555534], [86.41916656, 20.05555534], [86.41944122, 20.05583382], [86.42028046, 20.05583382], [86.42055511, 20.05611038], [86.42166901, 20.05611038], [86.42193604, 20.05639076], [86.42250061, 20.05639076], [86.42279053, 20.05611038], [86.42388916, 20.05611038], [86.42556, 20.05445099], [86.42556, 20.05332947], [86.42583466, 20.05305481], [86.42610931, 20.05305481], [86.4263916, 20.05277824], [86.4263916, 20.05251122], [86.42722321, 20.05167007], [86.42694092, 20.05138969], [86.42694092, 20.05027962], [86.42722321, 20.05000114], [86.42722321, 20.04972267], [86.42694092, 20.0494442], [86.42694092, 20.04889107], [86.4263916, 20.0483284], [86.4263916, 20.04750061], [86.42610931, 20.04721832], [86.42556, 20.04721832], [86.42527771, 20.04750061], [86.42527771, 20.04777908], [86.42500305, 20.04805565], [86.42500305, 20.0483284], [86.42388916, 20.04945183], [86.42360687, 20.04945183], [86.42360687, 20.04916954], [86.42166901, 20.04721832], [86.42138672, 20.04722214], [86.42111206, 20.04694366], [86.42056274, 20.04693985], [86.41971588, 20.04777908], [86.41972351, 20.04805565], [86.41944122, 20.0483284], [86.41944122, 20.04861069], [86.41916656, 20.04889107], [86.41898346, 20.04870415], [86.41860962, 20.04833412], [86.41860962, 20.04611206], [86.41833496, 20.04583359], [86.41833496, 20.04555511], [86.41805267, 20.04528046], [86.41718292, 20.04488182], [86.41660309, 20.04447746], [86.41574097, 20.04346085], [86.4153595, 20.04224396], [86.41511536, 20.04189873], [86.41488647, 20.04152107], [86.41471863, 20.04111099], [86.41443634, 20.04083061], [86.41444397, 20.04055405], [86.41471863, 20.04027939], [86.41471863, 20.03833008], [86.41444397, 20.03805542], [86.41443634, 20.03722191], [86.41471863, 20.03694534], [86.41471863, 20.03667068], [86.41500092, 20.0363903], [86.4152832, 20.0363903], [86.41610718, 20.03554916], [86.41611481, 20.03500175], [86.41638947, 20.03472137], [86.41638947, 20.03416634], [86.41610718, 20.03388977], [86.41610718, 20.03305817], [86.41583252, 20.03277969], [86.41583252, 20.03222084], [86.41555786, 20.03194427], [86.41583252, 20.0316658], [86.41583252, 20.03111076], [86.41500092, 20.03028107], [86.41361237, 20.0316658], [86.41361237, 20.03194427], [86.41333008, 20.03222084], [86.41333008, 20.03388977], [86.41361237, 20.03416634], [86.41361237, 20.03444481], [86.41305542, 20.03500175], [86.41305542, 20.03555489], [86.41278076, 20.03583336], [86.41278076, 20.03611183], [86.41249847, 20.0363903], [86.41249847, 20.03667068], [86.41221619, 20.03695107], [86.41166687, 20.0363903], [86.41166687, 20.03554916], [86.41156769, 20.03492165], [86.41152954, 20.03435707], [86.41160583, 20.03380966], [86.41158295, 20.03329277], [86.41143799, 20.03277016], [86.41133881, 20.03221893], [86.41114807, 20.0316925], [86.41101837, 20.03117943], [86.41086578, 20.03070068], [86.41078186, 20.03024864], [86.41065216, 20.02981949], [86.41065979, 20.02938461], [86.41077423, 20.02890968], [86.41078186, 20.02837944], [86.41069031, 20.02779007], [86.41059113, 20.02715492], [86.41054535, 20.0264473], [86.41046143, 20.02572823], [86.4101944, 20.02513695], [86.40983582, 20.02472115], [86.40950012, 20.02436066], [86.40923309, 20.02399063], [86.4090271, 20.02358627], [86.40888214, 20.0231781], [86.40872955, 20.02279282], [86.40857697, 20.02240944], [86.40840912, 20.02202988], [86.40827179, 20.02158737], [86.4080658, 20.02116013], [86.40782928, 20.02073097], [86.40750122, 20.02028084], [86.40750122, 20.02000046], [86.40721893, 20.01971817], [86.40721893, 20.01861191], [86.40777588, 20.01805496], [86.40777588, 20.01749992], [86.40805817, 20.01721954], [86.40805817, 20.01694679], [86.40833282, 20.01666641], [86.40860748, 20.01667023], [86.4091568, 20.01610947], [86.40972137, 20.01611137], [86.41027832, 20.01555443], [86.41027832, 20.01527977], [86.41085052, 20.01472092], [86.41083527, 20.01444435], [86.41139221, 20.01388931], [86.41110992, 20.01361084], [86.41110992, 20.01305962], [86.41139221, 20.01278114], [86.41194153, 20.01278114], [86.41221619, 20.01305962], [86.41249847, 20.01278114], [86.41249847, 20.01250076], [86.41278076, 20.01222038], [86.41278076, 20.01083374], [86.41249847, 20.01055527], [86.41249847, 20.01000023], [86.41221619, 20.00972176], [86.41222382, 20.00916672], [86.41194153, 20.00861168], [86.41194153, 20.00805473], [86.41166687, 20.00777817], [86.41166687, 20.0075016], [86.41194153, 20.00720978], [86.41194153, 20.00694466], [86.41166687, 20.00666618], [86.41194153, 20.00638962], [86.41194153, 20.00555992], [86.41166687, 20.00527954], [86.41166687, 20.00361061], [86.41139221, 20.00333023], [86.41139221, 20.00222206], [86.41110992, 20.00194359], [86.41110992, 20.0], [86.40999603, 19.99945068], [86.40833282, 19.99777985], [86.40833282, 19.99749947], [86.40805817, 19.9972229], [86.40805817, 19.99583244], [86.40750122, 19.9952774], [86.40721893, 19.9952774], [86.40638733, 19.99444389], [86.40611267, 19.99444389], [86.40583038, 19.99416733], [86.40556335, 19.99416924], [86.40537262, 19.99398232], [86.40528107, 19.99389076], [86.40499878, 19.99389076], [86.40442657, 19.99332809], [86.40416718, 19.99333382], [86.40361023, 19.99277878], [86.4033432, 19.99278069], [86.40110779, 19.99055099], [86.40083313, 19.99055481], [86.39916992, 19.98888969], [86.39916992, 19.98861122], [86.39749908, 19.98694038], [86.39749908, 19.98666573], [86.3972168, 19.98666954], [86.39694214, 19.98639107], [86.39666748, 19.98639107], [86.39601898, 19.98574066], [86.39472198, 19.98444176], [86.39444733, 19.9841671], [86.39417267, 19.98417282], [86.39398193, 19.98398209], [86.39389038, 19.98389053], [86.39360809, 19.98389053], [86.39305878, 19.98333168], [86.39305878, 19.98277855], [86.39221954, 19.98195267], [86.39167023, 19.98195267], [86.39167023, 19.98167038], [86.39055634, 19.9805603], [86.39055634, 19.98028946], [86.38999939, 19.97971916], [86.38999939, 19.97888947], [86.3897171, 19.97860909], [86.38970184, 19.97832108], [86.38916779, 19.97777939], [86.38916779, 19.97750092], [86.38889313, 19.97722816], [86.38861084, 19.97722816], [86.38833618, 19.97694016], [86.38805389, 19.97694397], [86.38749695, 19.97638893], [86.38722229, 19.97639084], [86.38694763, 19.97611046], [86.38640594, 19.97611046], [86.38360596, 19.97611046], [86.3833313, 19.97639084], [86.38223267, 19.97639084], [86.38194275, 19.97667122], [86.3813858, 19.97667122], [86.38083649, 19.97722816], [86.38054657, 19.97722816], [86.38027954, 19.97750092], [86.3797226, 19.97750092], [86.37917328, 19.97805977], [86.37889099, 19.97805977], [86.37832642, 19.97860909], [86.37805176, 19.97860909], [86.3777771, 19.97888947], [86.3777771, 19.9794445], [86.37805176, 19.97971916], [86.37805176, 19.97999763], [86.37833405, 19.98027992], [86.37833405, 19.98083305], [86.3786087, 19.98111153], [86.3786087, 19.98139191], [86.37889099, 19.98166656], [86.37889099, 19.9822216], [86.37917328, 19.98250008], [86.37916565, 19.98277855], [86.3797226, 19.98333359], [86.3797226, 19.98361206], [86.38083649, 19.98472023], [86.38083649, 19.98611069], [86.38111115, 19.98639107], [86.38083649, 19.98666954], [86.38083649, 19.98750114], [86.38054657, 19.98777962], [86.3805542, 19.98916435], [86.38083649, 19.98944092], [86.38083649, 19.98999977], [86.3813858, 19.99055481], [86.38166809, 19.99055481], [86.38283539, 19.99083328], [86.3833313, 19.99083328], [86.38360596, 19.99110985], [86.38384247, 19.99115753], [86.38500214, 19.99139023], [86.38582611, 19.99139023], [86.3861084, 19.99167061], [86.38639069, 19.99167061], [86.3866806, 19.99194908], [86.38694763, 19.99194527], [86.38722229, 19.99221039], [86.38722229, 19.99250031], [86.38694763, 19.99278069], [86.38581085, 19.99250031], [86.38424683, 19.99229813], [86.38276672, 19.99250031], [86.38249969, 19.99305534], [86.38243103, 19.99526978], [86.38223267, 19.99555969], [86.38166809, 19.99555969], [86.3813858, 19.99526978], [86.3813858, 19.99500084], [86.38111115, 19.99471855], [86.38111115, 19.99333382], [86.3805542, 19.99277878], [86.38054657, 19.99250031], [86.37982178, 19.99176979], [86.37895203, 19.99115944], [86.37853241, 19.99048424], [86.37838745, 19.98892784], [86.37853241, 19.98805046], [86.37889099, 19.98690033], [86.37889099, 19.98500061], [86.37832642, 19.98444176], [86.37805176, 19.98444366], [86.3777771, 19.9841671], [86.3777771, 19.98389053], [86.37748718, 19.98361015], [86.37750244, 19.98333359], [86.37666321, 19.98250008], [86.37666321, 19.9822216], [86.37611389, 19.98166656], [86.37610626, 19.98139191], [86.37526703, 19.9805603], [86.375, 19.9805603], [86.3747406, 19.98028946], [86.3741684, 19.98028946], [86.37384796, 19.97999763], [86.37249756, 19.97999763], [86.3722229, 19.97971916], [86.37166595, 19.97971916], [86.3713913, 19.97999763], [86.3702774, 19.97999763], [86.37000275, 19.98028946], [86.36915588, 19.98028946], [86.36915588, 19.97999763], [86.36888885, 19.97971916], [86.3686142, 19.97972298], [86.36833191, 19.9794445], [86.36777496, 19.9794445], [86.36750031, 19.97972298], [86.36723328, 19.97971916], [86.36694336, 19.97999763], [86.36360931, 19.97999763], [86.36332703, 19.98028946], [86.36222076, 19.98028946], [86.36194611, 19.9805603], [86.36165619, 19.98028946], [86.36055756, 19.98028946], [86.3602829, 19.97999763], [86.35972595, 19.97999763], [86.35945129, 19.98028946], [86.35888672, 19.98028946], [86.35861206, 19.9805603], [86.35832977, 19.98055649], [86.35805511, 19.98083305], [86.35527802, 19.98083305], [86.35500336, 19.98055649], [86.35444641, 19.98111153], [86.35360718, 19.98111153], [86.35331726, 19.98139191], [86.35256958, 19.98139191], [86.35221863, 19.98139191], [86.35193634, 19.98167038], [86.35166931, 19.98167038], [86.35138702, 19.98195267], [86.35111237, 19.98194504], [86.35057068, 19.98250008], [86.35055542, 19.98277855], [86.34999847, 19.98333359], [86.34999847, 19.98360062], [86.34999847, 19.98444366], [86.34971619, 19.98472023], [86.34971619, 19.98500061], [86.34999847, 19.9852829], [86.34999847, 19.98611069], [86.35028076, 19.98639107], [86.35028076, 19.98666573], [86.35012054, 19.98682785], [86.34972382, 19.98722267], [86.34944153, 19.9869442], [86.34916687, 19.98666573], [86.34916687, 19.98639107], [86.34889221, 19.98611069], [86.34889221, 19.98583031], [86.34833527, 19.98527718], [86.3483429, 19.98472023], [86.34860992, 19.98444366], [86.34860992, 19.98388863], [86.34889221, 19.98361015], [86.34889221, 19.98277855], [86.34944153, 19.9822216], [86.34944153, 19.98166656], [86.34916687, 19.98139191], [86.34860992, 19.98195267], [86.34805298, 19.98194504], [86.34777832, 19.9822216], [86.34751129, 19.9822216], [86.34722137, 19.98250008], [86.34722137, 19.98278046], [86.34583282, 19.98417282], [86.34555817, 19.9841671], [86.34500122, 19.98472214], [86.34471893, 19.98472214], [86.34455872, 19.98488235], [86.34333038, 19.98611069], [86.34306335, 19.98611069], [86.34278107, 19.98639107], [86.34221649, 19.98639107], [86.34127045, 19.98746872], [86.340271, 19.98888969], [86.33999634, 19.98916435], [86.33999634, 19.98944473], [86.33972168, 19.98971939], [86.33972168, 19.98999977], [86.33944702, 19.99027634], [86.33944702, 19.99110985], [86.33946991, 19.99309921], [86.33961487, 19.99472427], [86.33996582, 19.99567223], [86.34017944, 19.99682236], [86.34011078, 19.99763107], [86.33994293, 19.99830055], [86.3391571, 20.0], [86.33889008, 20.00036049], [86.33883667, 20.00071716], [86.33866119, 20.00106049], [86.33863068, 20.00144958], [86.33860779, 20.0018425], [86.33860779, 20.00218582], [86.33857727, 20.00251961], [86.33843994, 20.00283051], [86.33831787, 20.00317955], [86.33812714, 20.00354004], [86.33770752, 20.00486755], [86.33728027, 20.00608063], [86.33692169, 20.00777054], [86.33656311, 20.00898552], [86.33621216, 20.01066971], [86.33528137, 20.01250076], [86.33499908, 20.01278114], [86.33499908, 20.01305962], [86.33444214, 20.01361084], [86.33444214, 20.01444435], [86.33389282, 20.01499939], [86.33389282, 20.01527977], [86.33361053, 20.01555443], [86.33361053, 20.01583099], [86.33277893, 20.01667023], [86.33241272, 20.01703644], [86.33207703, 20.01736069], [86.3316803, 20.01768112], [86.33129883, 20.01802444], [86.3309021, 20.01832199], [86.33048248, 20.01857185], [86.3300705, 20.01881981], [86.3298111, 20.0191803], [86.32956696, 20.01958084], [86.3292923, 20.01998711], [86.32900238, 20.02042961], [86.32888031, 20.02102089], [86.32874298, 20.02160263], [86.32849121, 20.02207947], [86.32832336, 20.02256966], [86.32832336, 20.02312279], [86.32833862, 20.02370071], [86.32833099, 20.02416611], [86.32861328, 20.02444267], [86.32861328, 20.02499962], [86.32888794, 20.02527809], [86.32888794, 20.02583313], [86.32861328, 20.0261097], [86.32861328, 20.02695084], [86.32853699, 20.02816963], [86.32818604, 20.02952003], [86.32740021, 20.03067017], [86.32640076, 20.03180885], [86.32575226, 20.03275108], [86.3248291, 20.03369904], [86.32418823, 20.03437042], [86.32290649, 20.03469086], [86.32242584, 20.03500175], [86.32195282, 20.03524971], [86.3214798, 20.03540993], [86.32111359, 20.03569603], [86.32076263, 20.03604126], [86.32034302, 20.03637123], [86.31986237, 20.03666496], [86.3194046, 20.03692818], [86.31897736, 20.03715134], [86.31863403, 20.03741264], [86.31838226, 20.03772354], [86.3181076, 20.03800964], [86.31787109, 20.03832245], [86.31759644, 20.03860283], [86.31726074, 20.03885841], [86.31695557, 20.03917122], [86.31667328, 20.03955078], [86.31638336, 20.03993034], [86.31600189, 20.04017067], [86.31556702, 20.04031944], [86.31517029, 20.04050064], [86.31475067, 20.04061127], [86.31437683, 20.04079056], [86.31391907, 20.04092979], [86.31343842, 20.04109192], [86.31292725, 20.04124069], [86.31238556, 20.04137611], [86.31183624, 20.04150963], [86.31136322, 20.04171181], [86.31095886, 20.04195786], [86.31059265, 20.04222107], [86.31021881, 20.04248047], [86.30983734, 20.04265022], [86.3094101, 20.04278946], [86.30898285, 20.04294968], [86.30857086, 20.04311562], [86.30819702, 20.0433197], [86.30784607, 20.04354095], [86.30749512, 20.04372787], [86.30715942, 20.04390335], [86.3068161, 20.04408073], [86.30641174, 20.04421043], [86.30600739, 20.0443573], [86.30552673, 20.04447365], [86.30503845, 20.04467964], [86.30451965, 20.04491043], [86.30400085, 20.04510117], [86.30356598, 20.0453968], [86.30310059, 20.04561806], [86.30265045, 20.04585075], [86.30223846, 20.04611206], [86.30183411, 20.04639053], [86.30145264, 20.04667091], [86.30108643, 20.04700089], [86.30081177, 20.04738998], [86.30053711, 20.04777908], [86.30027771, 20.04817963], [86.30002594, 20.04862022], [86.29985809, 20.0491066], [86.29960632, 20.04951477], [86.29930878, 20.04975319], [86.29905701, 20.04999161], [86.29884338, 20.05022049], [86.2986145, 20.05055618], [86.29694366, 20.0522213], [86.29666901, 20.05221939], [86.29611206, 20.05278015], [86.29564667, 20.05308723], [86.29528809, 20.05328178], [86.29483795, 20.05336761], [86.29445648, 20.05360985], [86.29409027, 20.05391502], [86.29373932, 20.05433846], [86.293396, 20.05489922], [86.29305267, 20.05539894], [86.29270935, 20.05589485], [86.29244232, 20.05639076], [86.29213715, 20.05677795], [86.29189301, 20.05714035], [86.29164886, 20.05743027], [86.29147339, 20.05767822], [86.29139709, 20.05797958], [86.29138184, 20.05830002], [86.29133606, 20.05861092], [86.29122925, 20.05891991], [86.29113007, 20.05925941], [86.2910614, 20.05965042], [86.29099274, 20.06007957], [86.29087067, 20.06043053], [86.2906723, 20.06072044], [86.29046631, 20.06098175], [86.29007721, 20.06113052], [86.28987122, 20.06081009], [86.28978729, 20.06034851], [86.28983307, 20.05991554], [86.28991699, 20.05952072], [86.28990936, 20.05920219], [86.28981781, 20.05895233], [86.289711, 20.05872154], [86.28951263, 20.05859756], [86.28922272, 20.05855942], [86.2888031, 20.05854416], [86.28826141, 20.05852127], [86.28749847, 20.05861092], [86.28749847, 20.05750084], [86.28778076, 20.05722046], [86.28944397, 20.05722237], [86.29194641, 20.05472183], [86.29194641, 20.05416679], [86.29222107, 20.05389023], [86.29165649, 20.05332947], [86.29138947, 20.05333328], [86.29083252, 20.05277824], [86.29110718, 20.05251122], [86.29055786, 20.05194283], [86.29027557, 20.05194473], [86.29000092, 20.05166626], [86.29000092, 20.05138969], [86.28971863, 20.05111122], [86.28916931, 20.05111122], [86.28861237, 20.0505619], [86.28833008, 20.0505619], [86.28806305, 20.05027962], [86.28778076, 20.05027962], [86.28768921, 20.05018616], [86.28722382, 20.04972267], [86.28610992, 20.04972267], [86.2858429, 20.05000114], [86.28527832, 20.05000114], [86.28499603, 20.05027962], [86.28417206, 20.05027962], [86.28333282, 20.05111122], [86.28333282, 20.05166626], [86.28388977, 20.05221939], [86.28388977, 20.05249977], [86.28305817, 20.05333328], [86.28221893, 20.05332947], [86.28166962, 20.05389023], [86.28138733, 20.05389023], [86.28109741, 20.05417061], [86.28083038, 20.05417061], [86.28055573, 20.05388832], [86.27889252, 20.05555534], [86.27861023, 20.05554962], [86.2766571, 20.05750084], [86.27666473, 20.05777931], [86.27630615, 20.05930328], [86.27581024, 20.06011009], [86.27445221, 20.06160164], [86.27381134, 20.0617981], [86.27194214, 20.06195259], [86.27083588, 20.06194496], [86.27055359, 20.06222153], [86.26999664, 20.06222153], [86.26972198, 20.06250191], [86.26944733, 20.06250191], [86.26915741, 20.06278038], [86.26805878, 20.06278038], [86.26777649, 20.06250191], [86.26721954, 20.06250191], [86.26693726, 20.06278038], [86.26609802, 20.06278038], [86.26583099, 20.06250191], [86.26444244, 20.06250191], [86.26416779, 20.06222153], [86.26361084, 20.06222153], [86.26333618, 20.06194496], [86.26249695, 20.06195259], [86.26222229, 20.0616703], [86.26194763, 20.0616703], [86.26167297, 20.06139183], [86.26139069, 20.06139183], [86.2611084, 20.06111145], [86.26077271, 20.06113243], [86.26042938, 20.06096268], [86.26006317, 20.06063652], [86.25959778, 20.06031036], [86.25905609, 20.05999756], [86.25850677, 20.05971909], [86.25797272, 20.05944061], [86.25746918, 20.05916977], [86.25699615, 20.05892944], [86.25649261, 20.05879974], [86.25602722, 20.05859947], [86.25562286, 20.05837631], [86.25528717, 20.05811119], [86.25499725, 20.05784035], [86.25469208, 20.05760956], [86.25435638, 20.05741119], [86.2539978, 20.05719948], [86.25358582, 20.05698586], [86.25309753, 20.05682945], [86.25259399, 20.05665779], [86.25211334, 20.05647087], [86.2516098, 20.05633926], [86.25121307, 20.05611992], [86.2508316, 20.05592537], [86.25047302, 20.05574036], [86.25016785, 20.05553627], [86.24989319, 20.05528069], [86.24961853, 20.05500031], [86.24932098, 20.0547142], [86.24900055, 20.05439949], [86.248703, 20.0539875], [86.24829865, 20.05359268], [86.24785614, 20.05318832], [86.24752045, 20.05264091], [86.24726868, 20.05207253], [86.24716949, 20.05151176], [86.24698639, 20.05101967], [86.24687958, 20.05046844], [86.24677277, 20.04986191], [86.24689484, 20.0492897], [86.24685669, 20.04873085], [86.24669647, 20.04823112], [86.24666595, 20.04772949], [86.24668884, 20.04725075], [86.24675751, 20.04679871], [86.24668884, 20.04636002], [86.24666595, 20.04590034], [86.24666595, 20.0454464], [86.24664307, 20.04499817], [86.24650574, 20.04456902], [86.24636841, 20.04409981], [86.24632263, 20.04360008], [86.24623108, 20.0431881], [86.24610901, 20.04284096], [86.24598694, 20.0425396], [86.24585724, 20.04228973], [86.24582672, 20.04199982], [86.24580383, 20.04173088], [86.24568176, 20.04150963], [86.24555206, 20.04138947], [86.24555206, 20.04083061], [86.24500275, 20.04027748], [86.24472046, 20.04027939], [86.2444458, 20.04000092], [86.24388885, 20.04000092], [86.24333191, 20.03944016], [86.24305725, 20.03944206], [86.24277496, 20.0391674], [86.24250031, 20.03917122], [86.2419281, 20.03861046], [86.2408371, 20.03861046], [86.24054718, 20.03833008], [86.24028015, 20.03833389], [86.23916626, 20.03722382], [86.23916626, 20.03694534], [86.23972321, 20.0363903], [86.24028015, 20.0363903], [86.24111176, 20.03554916], [86.24138641, 20.03555489], [86.24194336, 20.03500175], [86.24250031, 20.03500175], [86.24276733, 20.03472137], [86.24333191, 20.03472137], [86.24333191, 20.03444481], [86.2436142, 20.03416634], [86.24360657, 20.03360748], [86.24305725, 20.03305626], [86.24305725, 20.03277969], [86.24250031, 20.03222084], [86.24250031, 20.03194427], [86.24222565, 20.0316658], [86.24221802, 20.0313797], [86.2419281, 20.03108025], [86.24194336, 20.0308342], [86.24055481, 20.02944374], [86.23999786, 20.03000069], [86.23944092, 20.03000069], [86.23918152, 20.02972031], [86.2388916, 20.02972221], [86.23860931, 20.02944374], [86.23833466, 20.02944374], [86.23805237, 20.02916527], [86.23777771, 20.02917099], [86.23750305, 20.02889061], [86.23694611, 20.02889061], [86.23665619, 20.02861023], [86.23665619, 20.02695084], [86.23972321, 20.02695084], [86.23999786, 20.02667046], [86.2419281, 20.02667046], [86.24221802, 20.02639008], [86.24254608, 20.02637291], [86.24291229, 20.02625084], [86.24323273, 20.02607918], [86.24352264, 20.02583122], [86.2437973, 20.02555275], [86.244133, 20.02526283], [86.24449921, 20.02495766], [86.24489594, 20.02465057], [86.24519348, 20.02425766], [86.24549866, 20.02388954], [86.24581909, 20.02353859], [86.24614716, 20.0231781], [86.24655914, 20.02287865], [86.24698639, 20.02254105], [86.24742126, 20.02219963], [86.24780273, 20.02177048], [86.24819946, 20.0214138], [86.24861145, 20.02115631], [86.24907684, 20.02114105], [86.24954987, 20.02130127], [86.25003815, 20.02133179], [86.25058746, 20.02116013], [86.25120544, 20.02108765], [86.2518158, 20.0209198], [86.25233459, 20.02060127], [86.25283051, 20.02033806], [86.25328827, 20.02013969], [86.25369263, 20.01991272], [86.25400543, 20.01964951], [86.25424194, 20.01927376], [86.25455475, 20.01893044], [86.25495911, 20.01863289], [86.25543976, 20.01839066], [86.25598145, 20.01833534], [86.25649261, 20.01832962], [86.25691986, 20.01833344], [86.25732422, 20.01833344], [86.25772858, 20.01832008], [86.25813293, 20.01823997], [86.25852966, 20.01813126], [86.2589798, 20.01828957], [86.25942993, 20.01828957], [86.25992584, 20.01810074], [86.26049805, 20.01805878], [86.26107788, 20.01806068], [86.2616272, 20.01806068], [86.26212311, 20.01805115], [86.26254272, 20.01799965], [86.26287079, 20.01781273], [86.26317596, 20.01775551], [86.26335144, 20.0177803], [86.26361084, 20.01749992], [86.26416779, 20.01749992], [86.26444244, 20.01721954], [86.26472473, 20.01722145], [86.26499939, 20.01694679], [86.26555634, 20.01694679], [86.26583099, 20.01722145], [86.26667023, 20.01721954], [86.26693726, 20.01749992], [86.26721954, 20.01749992], [86.26750183, 20.0177803], [86.26889038, 20.0177803], [86.26915741, 20.01749992], [86.26999664, 20.01749992], [86.27027893, 20.0177803], [86.27223206, 20.0177803], [86.27259064, 20.0177803], [86.27303314, 20.0177803], [86.27349091, 20.01777077], [86.27394867, 20.01772499], [86.27435303, 20.01754951], [86.27471924, 20.01753426], [86.27507019, 20.0176506], [86.27542114, 20.01776123], [86.27581024, 20.0178299], [86.27615356, 20.01800537], [86.27659607, 20.01805305], [86.27706146, 20.01808167], [86.27749634, 20.01819992], [86.27790833, 20.01834869], [86.27826691, 20.01852417], [86.27863312, 20.01866341], [86.27894592, 20.01885986], [86.27932739, 20.01903915], [86.27973175, 20.01920128], [86.28011322, 20.01942062], [86.28050232, 20.01960182], [86.2808609, 20.01986122], [86.28125763, 20.02013016], [86.28172302, 20.02038002], [86.28222656, 20.02060127], [86.28268433, 20.02090263], [86.28304291, 20.02127075], [86.28333282, 20.02164078], [86.28361511, 20.02193642], [86.28388214, 20.02219009], [86.28411865, 20.02243042], [86.28436279, 20.02260971], [86.28453827, 20.02287102], [86.28471375, 20.02317047], [86.28494263, 20.02351952], [86.28530121, 20.02388954], [86.28582764, 20.02416992], [86.28636932, 20.02434921], [86.28687286, 20.02420807], [86.287323, 20.0241909], [86.28774261, 20.02433968], [86.28818512, 20.02456856], [86.28868103, 20.02461243], [86.28920746, 20.02451515], [86.28967285, 20.02452087], [86.29006958, 20.02466965], [86.29049683, 20.02472115], [86.2909317, 20.02472687], [86.29133606, 20.02477074], [86.29171753, 20.02495003], [86.29211426, 20.02500534], [86.29234314, 20.02503014], [86.29252625, 20.02504921], [86.29296875, 20.02510834], [86.29344177, 20.02499008], [86.29393005, 20.02478981], [86.29444885, 20.02461243], [86.29494476, 20.02441978], [86.29532623, 20.02407837], [86.2954483, 20.02331352], [86.29568481, 20.02288055], [86.29576111, 20.0227356], [86.29608154, 20.02220917], [86.29640198, 20.0217495], [86.29670715, 20.02135086], [86.29693604, 20.02095985], [86.29689026, 20.02046013], [86.29699707, 20.02008438], [86.29720306, 20.01973152], [86.29738617, 20.01930809], [86.29766846, 20.01876068], [86.29798126, 20.01809311], [86.29836273, 20.01753044], [86.29884338, 20.01703072], [86.29940796, 20.0166893], [86.29992676, 20.01638031], [86.30036926, 20.01605988], [86.30072021, 20.01567841], [86.30104828, 20.01534081], [86.30139923, 20.0150528], [86.30178833, 20.01486969], [86.30217743, 20.01470184], [86.3025589, 20.01451111], [86.30297852, 20.01445198], [86.30343628, 20.01442337], [86.30396271, 20.01435471], [86.30454254, 20.01424026], [86.30516052, 20.01416206], [86.30540466, 20.01388931], [86.30561066, 20.01357841], [86.30587769, 20.01327133], [86.30612946, 20.01289177], [86.30639648, 20.01250076], [86.30661774, 20.01210976], [86.30665588, 20.01167107], [86.3069458, 20.01139069], [86.3069458, 20.01083183], [86.30722046, 20.01055527], [86.30722046, 20.01026917], [86.30833435, 20.00916672], [86.30832672, 20.00889015], [86.3088913, 20.00832939], [86.3088913, 20.00805473], [86.30916595, 20.00777817], [86.30916595, 20.0075016], [86.30944824, 20.00720978], [86.3105545, 20.00611115], [86.31054688, 20.00599289], [86.31079865, 20.00571632], [86.31098175, 20.00539017], [86.31114197, 20.00501251], [86.31141663, 20.00467491], [86.31178284, 20.00438118], [86.31195831, 20.00396919], [86.31175232, 20.00333977], [86.31170654, 20.00285339], [86.31179047, 20.00245857], [86.31172943, 20.00196838], [86.31171417, 20.0014267], [86.31181335, 20.00085068], [86.3122406, 20.0003891], [86.3125, 20.0], [86.31333923, 19.99916077], [86.31383514, 19.99882317], [86.31399536, 19.9985466], [86.3144455, 19.99777794], [86.31446075, 19.99749947], [86.3152771, 19.99666595], [86.3152771, 19.99638939], [86.31582642, 19.99583244], [86.31583405, 19.9952774], [86.3161087, 19.99500084], [86.3161087, 19.99471855], [86.31639099, 19.99444389], [86.31639099, 19.99416733], [86.31777954, 19.99278069], [86.31777954, 19.99250031], [86.31804657, 19.99221039], [86.3180542, 19.99194527], [86.31833649, 19.99167061], [86.31833649, 19.99028015], [86.31861115, 19.98999977], [86.31861115, 19.98944092], [86.31916809, 19.98888969], [86.31916809, 19.98861122], [86.31973267, 19.98806], [86.31973267, 19.98777962], [86.31999969, 19.98750114], [86.31999969, 19.98722076], [86.3216629, 19.98555565], [86.3216629, 19.98472023], [86.32194519, 19.98444366], [86.32194519, 19.98388863], [86.32138824, 19.98333168], [86.32138824, 19.98305511], [86.32013702, 19.98180962], [86.31906891, 19.98101044], [86.31715393, 19.98060417], [86.31646729, 19.98069954], [86.31518555, 19.98070526], [86.31414795, 19.98111153], [86.31181335, 19.98180962], [86.31130981, 19.9820652], [86.30995178, 19.9824028], [86.30887604, 19.98294067], [86.30802917, 19.98314857], [86.30690002, 19.98351097], [86.30487061, 19.9838829], [86.30390167, 19.98400116], [86.30323792, 19.98408318], [86.30266571, 19.98408318], [86.30252075, 19.98401642], [86.30252075, 19.98381042], [86.30266571, 19.9835434], [86.30308533, 19.9832592], [86.30349731, 19.98329544], [86.30388641, 19.98333359], [86.3041687, 19.98305511], [86.30473328, 19.98306274], [86.30500031, 19.98278046], [86.3069458, 19.98278046], [86.30722046, 19.98250008], [86.3077774, 19.98250008], [86.30860901, 19.98167038], [86.30916595, 19.98167038], [86.30944824, 19.98139191], [86.31027985, 19.98139191], [86.31054688, 19.98111153], [86.31138611, 19.98111153], [86.31359863, 19.98013496], [86.3157959, 19.9798584], [86.31711578, 19.97971916], [86.31789398, 19.97991562], [86.31839752, 19.97998047], [86.31907654, 19.98023033], [86.31999969, 19.9805603], [86.32097626, 19.98103905], [86.32168579, 19.98171616], [86.32195282, 19.9822216], [86.32277679, 19.98305511], [86.32315063, 19.98347282], [86.32327271, 19.98361206], [86.32389069, 19.98361206], [86.32472229, 19.98277855], [86.32472229, 19.98250008], [86.32640076, 19.98082924], [86.3263855, 19.98055649], [86.32694244, 19.97999763], [86.3272171, 19.97999763], [86.32861328, 19.97860909], [86.32888794, 19.97860909], [86.32917023, 19.97833061], [86.32944489, 19.97833252], [86.32971954, 19.97805786], [86.33055878, 19.97805977], [86.33082581, 19.97777939], [86.33110809, 19.97777939], [86.33139038, 19.97750092], [86.33167267, 19.97750092], [86.33194733, 19.97722244], [86.33304596, 19.97722816], [86.33333588, 19.97694016], [86.33444214, 19.97694397], [86.33472443, 19.9766655], [86.33528137, 19.97667122], [86.33557129, 19.97639084], [86.33583069, 19.97639084], [86.33611298, 19.97611046], [86.33638763, 19.97611046], [86.33666992, 19.97583008], [86.33721924, 19.9758358], [86.33750153, 19.97555542], [86.33777618, 19.97556114], [86.33805847, 19.97528076], [86.33834076, 19.97528076], [86.33917999, 19.97454071], [86.3397522, 19.97393036], [86.34060669, 19.97284889], [86.34102631, 19.97237968], [86.34137726, 19.97116089], [86.34137726, 19.97056007], [86.34027863, 19.96944237], [86.33999634, 19.96944427], [86.33972168, 19.9691658], [86.33944702, 19.96916962], [86.3391571, 19.96889114], [86.33889008, 19.96889114], [86.33834076, 19.96832848], [86.33805847, 19.9683342], [86.33792114, 19.96819687], [86.33777618, 19.96805573], [86.33777618, 19.96777916], [86.33583069, 19.96582985], [86.33472443, 19.96388626], [86.3347168, 19.9636097], [86.33305359, 19.96194458], [86.33277893, 19.96194458], [86.33073425, 19.95990181], [86.32944489, 19.95861053], [86.32943726, 19.95778084], [86.32953644, 19.95768166], [86.32971954, 19.95750046], [86.3290329, 19.95681381], [86.32888794, 19.95666695], [86.32888794, 19.95656013], [86.32888794, 19.95638847], [86.32863617, 19.9561367], [86.32805634, 19.95555496], [86.32776642, 19.95556259], [86.32749939, 19.9552803], [86.32694244, 19.9552803], [86.32666779, 19.95500183], [86.3263855, 19.95500183], [86.32583618, 19.95444489], [86.32555389, 19.95444489], [86.32499695, 19.95388985], [86.32472229, 19.95389175], [86.32463074, 19.95379448], [86.32417297, 19.95332909], [86.32389069, 19.9533329], [86.3236084, 19.95305634], [86.32305908, 19.95305824], [86.32277679, 19.95277977], [86.32250214, 19.95277977], [86.32221985, 19.95249748], [86.3216629, 19.95249748], [86.32138824, 19.95222092], [86.32111359, 19.95222282], [86.3208313, 19.95194435], [86.32027435, 19.95194435], [86.31999969, 19.95166779], [86.31944275, 19.95166969], [86.31916809, 19.95139122], [86.3188858, 19.95139122], [86.31861115, 19.95111084], [86.31833649, 19.95111084], [86.31720734, 19.95000076], [86.31694794, 19.94972038], [86.31749725, 19.94916534], [86.31833649, 19.94916534], [86.31847382, 19.94930458], [86.31861115, 19.94944382], [86.3188858, 19.94944382], [86.31916809, 19.94972229], [86.31944275, 19.94972038], [86.31999969, 19.95029068], [86.32027435, 19.95027542], [86.3208313, 19.95083427], [86.32110596, 19.95083046], [86.32138824, 19.95111084], [86.3216629, 19.95111084], [86.32195282, 19.95139122], [86.32221985, 19.95139122], [86.32250214, 19.95166969], [86.32305908, 19.95166779], [86.32333374, 19.95194435], [86.32389069, 19.95194435], [86.32416534, 19.95222282], [86.32444763, 19.95222092], [86.32499695, 19.95277977], [86.32527924, 19.95277977], [86.32554626, 19.95305824], [86.32611084, 19.95305824], [86.32694244, 19.95389175], [86.32722473, 19.95388985], [86.32749939, 19.95416641], [86.32777405, 19.95416641], [86.32805634, 19.95444489], [86.32833099, 19.95444489], [86.33110809, 19.95722008], [86.33416748, 19.96055984], [86.33444214, 19.96055412], [86.33472443, 19.9608326], [86.33499908, 19.96083069], [86.33666992, 19.96249962], [86.33777618, 19.96499825], [86.33777618, 19.96528816], [86.33805847, 19.96555519], [86.33805847, 19.96583366], [86.33834076, 19.96610832], [86.33834076, 19.96639061], [86.33944702, 19.96750069], [86.33972168, 19.96750069], [86.33999634, 19.96777916], [86.34027863, 19.96777725], [86.34135437, 19.96863747], [86.34243774, 19.9695034], [86.34331512, 19.96925926], [86.34381104, 19.9691906], [86.34467316, 19.96865082], [86.3451767, 19.96858025], [86.34554291, 19.96813583], [86.34632111, 19.96759033], [86.34696198, 19.96711922], [86.34767151, 19.96651077], [86.34806824, 19.96610832], [86.34913635, 19.96547127], [86.3500061, 19.96467972], [86.35086823, 19.9642086], [86.3514328, 19.96393967], [86.35164642, 19.96372986], [86.35165405, 19.96339417], [86.35111237, 19.96333122], [86.35083008, 19.96333313], [86.34899902, 19.96389961], [86.34814453, 19.96430969], [86.34714508, 19.96485138], [86.34671783, 19.96512032], [86.34622192, 19.96533012], [86.34593964, 19.96533012], [86.34586334, 19.96512032], [86.34593964, 19.96478462], [86.34650421, 19.96437645], [86.34694672, 19.96417046], [86.34751129, 19.9636097], [86.34777832, 19.9636116], [86.34833527, 19.96305466], [86.34860992, 19.96305466], [86.34889221, 19.96277618], [86.34971619, 19.96278], [86.34999847, 19.96249962], [86.35083008, 19.96249962], [86.35111237, 19.96223068], [86.35250092, 19.96223068], [86.3527832, 19.96194077], [86.35361481, 19.96194458], [86.35388947, 19.9616642], [86.35500336, 19.96166992], [86.35527802, 19.96138954], [86.35584259, 19.96138954], [86.35610962, 19.96111107], [86.35666656, 19.96111107], [86.35694122, 19.96083069], [86.35749817, 19.9608326], [86.35778046, 19.96055412], [86.35832977, 19.96055984], [86.35861206, 19.96027946], [86.35888672, 19.96027946], [86.35945129, 19.95972061], [86.35972595, 19.95972252], [86.36000061, 19.95944214], [86.36027527, 19.95944214], [86.36055756, 19.95916748], [86.3611145, 19.95916748], [86.36138916, 19.95888901], [86.36222076, 19.95889091], [86.36251068, 19.95861053], [86.36277771, 19.95861053], [86.36305237, 19.95833015], [86.3638916, 19.95833206], [86.36416626, 19.9580555], [86.36472321, 19.95806122], [86.36499786, 19.95778084], [86.36554718, 19.95778084], [86.3658371, 19.95750046], [86.3658371, 19.95583153], [86.3655777, 19.9551506], [86.36422729, 19.95372963], [86.36266327, 19.95277977], [86.36065674, 19.9522419], [86.35788727, 19.95156288], [86.35634613, 19.95125961], [86.35546875, 19.95108795], [86.35169983, 19.95055008], [86.34992218, 19.95013046], [86.34664917, 19.94966888], [86.34500885, 19.94872284], [86.34395599, 19.94819069], [86.34261322, 19.94819069], [86.34131622, 19.94765091], [86.3395462, 19.9474411], [86.33691406, 19.94683456], [86.33413696, 19.94636154], [86.33200073, 19.94602013], [86.33113861, 19.94584656], [86.32971954, 19.94555473], [86.32746887, 19.94473839], [86.32462311, 19.94412994], [86.32398224, 19.94406128], [86.32319641, 19.94392395], [86.32205963, 19.94372368], [86.32149506, 19.94350624], [86.32042694, 19.94299126], [86.31977844, 19.94279289], [86.318573, 19.94218063], [86.31742859, 19.94197083], [86.31593323, 19.94190025], [86.31443787, 19.94123077], [86.31279755, 19.94067955], [86.31180573, 19.94047737], [86.31059265, 19.93988991], [86.30912781, 19.93950081], [86.30713654, 19.93917084], [86.30535889, 19.93856239], [86.30420685, 19.93802071], [86.30172729, 19.93721008], [86.3003006, 19.93659019], [86.29880524, 19.93585396], [86.29766846, 19.93564987], [86.29611206, 19.93551064], [86.29475403, 19.93497276], [86.29375458, 19.93463516], [86.2926178, 19.93367958], [86.29192352, 19.93335724], [86.2903595, 19.9327507], [86.28956604, 19.93227005], [86.28843689, 19.93193626], [86.28730011, 19.93112564], [86.28565979, 19.93085289], [86.28424072, 19.9303112], [86.28309631, 19.92963982], [86.28217316, 19.92923164], [86.2806778, 19.92821884], [86.27867889, 19.92733955], [86.2770462, 19.92658806], [86.2736969, 19.92496872], [86.27220917, 19.92436028], [86.26999664, 19.92307091], [86.26717377, 19.9215641], [86.26574707, 19.92068481], [86.26475525, 19.92020988], [86.26347351, 19.91926193], [86.26183319, 19.91892242], [86.25930023, 19.91778755], [86.25666809, 19.91642952], [86.25421143, 19.91516685], [86.25258636, 19.91434097], [86.25016785, 19.91270828], [86.24867249, 19.91183662], [86.24739075, 19.91123009], [86.24617767, 19.91115952], [86.24524689, 19.91115952], [86.2444458, 19.91194534], [86.24278259, 19.91250038], [86.24138641, 19.91389084], [86.24138641, 19.9141674], [86.2408371, 19.91471863], [86.2408371, 19.91500092], [86.24028015, 19.91555977], [86.24028015, 19.9161129], [86.2416687, 19.91749954], [86.2419281, 19.91749954], [86.24221802, 19.91777992], [86.24250031, 19.91777802], [86.24333191, 19.91860962], [86.24305725, 19.91889], [86.24305725, 19.91944313], [86.24278259, 19.9197197], [86.24278259, 19.92028046], [86.24250031, 19.92055321], [86.24250031, 19.92083359], [86.24222565, 19.92111206], [86.24175262, 19.92205048], [86.24160004, 19.92205048], [86.24138641, 19.92192268], [86.24138641, 19.92099762], [86.24173737, 19.92004967], [86.24173737, 19.91917038], [86.24102783, 19.91822052], [86.24010468, 19.91727448], [86.2388916, 19.91638947], [86.2388916, 19.9159584], [86.2388916, 19.91583252], [86.23944092, 19.91527748], [86.23944092, 19.91500092], [86.23972321, 19.91471863], [86.23972321, 19.9141674], [86.23999786, 19.91389084], [86.23999786, 19.91361046], [86.24028015, 19.91332817], [86.23999786, 19.91305542], [86.23999786, 19.91278076], [86.23972321, 19.91250038], [86.23832703, 19.91389084], [86.23805237, 19.91389084], [86.23750305, 19.91332817], [86.23750305, 19.91222191], [86.23722076, 19.91194534], [86.23722076, 19.91167068], [86.23694611, 19.9113903], [86.23694611, 19.91082954], [86.23583221, 19.90972137], [86.23583221, 19.90916443], [86.23443604, 19.90777969], [86.23388672, 19.90777969], [86.23332977, 19.90722084], [86.23305511, 19.90722275], [86.23278046, 19.90694427], [86.23222351, 19.90694427], [86.23194122, 19.9066658], [86.23166656, 19.90666962], [86.23139191, 19.90639114], [86.23110962, 19.90639114], [86.22972107, 19.90501022], [86.22944641, 19.90501022], [86.22833252, 19.90389061], [86.2277832, 19.90361023], [86.22666931, 19.90361023], [86.22638702, 19.90389061], [86.22583008, 19.9038887], [86.22499847, 19.90472031], [86.22499847, 19.90501022], [86.22360992, 19.90639114], [86.22360992, 19.9066658], [86.22333527, 19.90694427], [86.22333527, 19.90722275], [86.22250366, 19.90805435], [86.22249603, 19.90833092], [86.22166443, 19.90916443], [86.22166443, 19.90944672], [86.22138977, 19.90972137], [86.22138977, 19.91055489], [86.22110748, 19.91082954], [86.22110748, 19.91138649], [86.22305298, 19.91332817], [86.22305298, 19.91361046], [86.22389221, 19.91444397], [86.22389221, 19.91471863], [86.22528076, 19.9161129], [86.22556305, 19.9161129], [86.22606659, 19.91662025], [86.22634125, 19.91731071], [86.22657013, 19.91855049], [86.22657013, 19.91949844], [86.22632599, 19.92052078], [86.22606659, 19.92087936], [86.22583008, 19.92111015], [86.22551727, 19.9217701], [86.22480774, 19.92251015], [86.22431183, 19.92332268], [86.2237854, 19.9246521], [86.22354126, 19.92498016], [86.22328186, 19.92533112], [86.22289276, 19.92562103], [86.22252655, 19.92562103], [86.22249603, 19.92547607], [86.22246552, 19.92534447], [86.2227478, 19.92480278], [86.22305298, 19.92416954], [86.22354889, 19.9229393], [86.22397614, 19.92213058], [86.22421265, 19.9218998], [86.22505951, 19.92095184], [86.22556305, 19.92033958], [86.22576904, 19.91966438], [86.22555542, 19.91861153], [86.22528076, 19.91833305], [86.22528076, 19.91805649], [86.22499847, 19.91777992], [86.22499847, 19.91749954], [86.22389221, 19.91638947], [86.22389221, 19.9161129], [86.22081757, 19.91305923], [86.22081757, 19.91278076], [86.22055817, 19.91250038], [86.22055817, 19.91221809], [86.22027588, 19.91194534], [86.22027588, 19.91167068], [86.22000122, 19.9113903], [86.21943665, 19.91194916], [86.21888733, 19.91194916], [86.21868134, 19.91214943], [86.21775818, 19.91290092], [86.21720123, 19.91323662], [86.21689606, 19.91332054], [86.21671295, 19.91337013], [86.21656036, 19.9134407], [86.21627808, 19.913311], [86.21613312, 19.9131012], [86.21606445, 19.91269875], [86.21556091, 19.91242027], [86.21472168, 19.91222191], [86.21416473, 19.91222191], [86.21389008, 19.91194534], [86.21360779, 19.91194916], [86.21298218, 19.91131973], [86.21277618, 19.91110992], [86.21250153, 19.91111183], [86.21250153, 19.91083336], [86.21221924, 19.91055489], [86.21221924, 19.90916443], [86.21250153, 19.90888977], [86.21221924, 19.90833092], [86.21250153, 19.90805435], [86.21250153, 19.90611076], [86.21221924, 19.90583038], [86.21221924, 19.90555573], [86.21138763, 19.90472031], [86.20944214, 19.90472031], [86.20887756, 19.90528107], [86.20887756, 19.90555954], [86.20848083, 19.90600014], [86.20812988, 19.90607071], [86.20791626, 19.90607071], [86.20791626, 19.90553093], [86.20804596, 19.90472031], [86.20944214, 19.90333366], [86.21111298, 19.90333176], [86.21138763, 19.90361023], [86.21194458, 19.90361023], [86.21305847, 19.90472031], [86.21305847, 19.90501022], [86.21360779, 19.90555573], [86.21360779, 19.90583038], [86.21389008, 19.90611076], [86.21389008, 19.90639114], [86.21416473, 19.9066658], [86.21416473, 19.90694427], [86.21389008, 19.90722275], [86.21389008, 19.90833282], [86.21360779, 19.90860939], [86.21360779, 19.90888977], [86.21389008, 19.90916443], [86.21389008, 19.90971947], [86.2141571, 19.90999985], [86.21416473, 19.91027641], [86.21444702, 19.91055489], [86.21444702, 19.91082954], [86.2150116, 19.9113903], [86.21555328, 19.91138649], [86.21565247, 19.91148567], [86.2158432, 19.91167068], [86.21678925, 19.91166878], [86.21721649, 19.91167068], [86.21749878, 19.9113903], [86.21778107, 19.9113903], [86.21833038, 19.91082954], [86.21888733, 19.91083336], [86.21916962, 19.91055489], [86.21916962, 19.91027641], [86.21971893, 19.90971947], [86.21971893, 19.90888977], [86.22000122, 19.90860939], [86.22000122, 19.90805435], [86.22027588, 19.90777779], [86.22027588, 19.90722084], [86.22110748, 19.90638924], [86.22138977, 19.90639114], [86.22194672, 19.90583038], [86.22194672, 19.90527725], [86.22305298, 19.9041729], [86.22305298, 19.90389061], [86.22471619, 19.90222168], [86.22558594, 19.9016819], [86.22657776, 19.90160942], [86.22735596, 19.90175056], [86.22807312, 19.90184021], [86.22838593, 19.90184021], [86.22867584, 19.90157127], [86.22796631, 19.90088081], [86.22753143, 19.90075493], [86.2247467, 19.89953995], [86.22238922, 19.89898109], [86.2199707, 19.89810562], [86.21837616, 19.89743614], [86.21705627, 19.89688492], [86.21613312, 19.89689064], [86.21440887, 19.89621162], [86.21250153, 19.89546013], [86.20986938, 19.89458275], [86.20710754, 19.89394379], [86.20603943, 19.89347076], [86.20461273, 19.89286041], [86.20226288, 19.89204979], [86.19906616, 19.8908329], [86.19629669, 19.89007187], [86.19473267, 19.88966751], [86.19210052, 19.88879013], [86.19061279, 19.88796806], [86.18804932, 19.8872261], [86.18527985, 19.88628006], [86.18392181, 19.88594055], [86.18171692, 19.88525963], [86.17887115, 19.88438225], [86.17778015, 19.88388634], [86.1763916, 19.88376617], [86.17575073, 19.88343239], [86.17489624, 19.88295174], [86.17440033, 19.88288498], [86.1727829, 19.88278008], [86.17082977, 19.88217926], [86.16696167, 19.88101006], [86.1651001, 19.88030052], [86.16268158, 19.8796196], [86.1607666, 19.87887955], [86.15888977, 19.87833023], [86.15833282, 19.87833214], [86.15777588, 19.8777771], [86.1550827, 19.87730026], [86.15399933, 19.87686729], [86.15248871, 19.87615013], [86.15019989, 19.87568092], [86.14985657, 19.87568092], [86.14885712, 19.87528992], [86.14705658, 19.87456322], [86.14585114, 19.87415886], [86.14408112, 19.87401962], [86.14266968, 19.87341499], [86.14111328, 19.87267113], [86.14017487, 19.87246704], [86.13939667, 19.87220001], [86.13752747, 19.87181091], [86.1366806, 19.87140656], [86.13553619, 19.87141037], [86.13446808, 19.87072945], [86.13340759, 19.87053108], [86.13247681, 19.87005997], [86.13166809, 19.86972046], [86.1305542, 19.86972237], [86.12809753, 19.8693161], [86.12696075, 19.86890984], [86.12539673, 19.86844254], [86.12412262, 19.86796188], [86.12247467, 19.86750031], [86.1222229, 19.86750031], [86.12076569, 19.86750412], [86.12032318, 19.8674736], [86.11977386, 19.86743736], [86.1182785, 19.86668968], [86.11685181, 19.86655617], [86.1155014, 19.8658123], [86.11351776, 19.86547279], [86.11138916, 19.8647213], [86.11055756, 19.86444473], [86.11000061, 19.86416626], [86.10961151, 19.86404037], [86.10845947, 19.86347961], [86.10726166, 19.86347961], [86.10610962, 19.86361122], [86.10584259, 19.86333275], [86.10444641, 19.86333275], [86.10416412, 19.86305618], [86.10305786, 19.8630619], [86.1027832, 19.86277962], [86.10250092, 19.86277962], [86.10221863, 19.86250114], [86.10138702, 19.86250114], [86.10124969, 19.86236191], [86.10111237, 19.86222267], [86.10083008, 19.86222267], [86.10055542, 19.8619442], [86.09999847, 19.8619442], [86.09972382, 19.86166573], [86.09916687, 19.86166954], [86.09770966, 19.86129951], [86.0966568, 19.86055946], [86.09514618, 19.85991096], [86.09465027, 19.85984612], [86.09278107, 19.85971069], [86.09194183, 19.85972214], [86.09166718, 19.85944366], [86.09083557, 19.85944366], [86.09055328, 19.8591671], [86.09027863, 19.85917091], [86.08999634, 19.85889053], [86.08947754, 19.85889053], [86.08777618, 19.85847092], [86.08586121, 19.85819817], [86.08436584, 19.85773277], [86.08296967, 19.85741043], [86.08062744, 19.85713959], [86.07920074, 19.85674095], [86.07861328, 19.85667038], [86.07805634, 19.85666847], [86.07777405, 19.85694695], [86.07722473, 19.85694695], [86.07694244, 19.8572216], [86.0763855, 19.8572216], [86.07611084, 19.85694695], [86.07583618, 19.85694695], [86.07555389, 19.85666847], [86.07333374, 19.85666847], [86.07305908, 19.85694695], [86.07250214, 19.85694695], [86.07221985, 19.85666847], [86.0716629, 19.85667038], [86.07138824, 19.85639], [86.07054901, 19.85639], [86.06999969, 19.85583115], [86.06972504, 19.85611153], [86.06833649, 19.85611153], [86.0680542, 19.85583305], [86.0661087, 19.85583305], [86.06583405, 19.85555458], [86.0652771, 19.8555603], [86.06500244, 19.85527992], [86.06472015, 19.85527992], [86.06445313, 19.85499954], [86.0633316, 19.85499954], [86.06305695, 19.85472107], [86.06222534, 19.85472488], [86.06138611, 19.85388947], [86.06111145, 19.85390091], [86.06083679, 19.85416985], [86.05999756, 19.85416985], [86.0597229, 19.85390091], [86.05916595, 19.85390091], [86.0588913, 19.85416985], [86.05665588, 19.85416985], [86.05464172, 19.85373116], [86.05349731, 19.85338974], [86.05193329, 19.8531208], [86.05076599, 19.8526783], [86.04865265, 19.85222054], [86.04833221, 19.85222244], [86.04805756, 19.85194206], [86.04777527, 19.85194206], [86.04750061, 19.8516674], [86.04360962, 19.8516674], [86.04333496, 19.85194206], [86.04222107, 19.85194206], [86.04194641, 19.85222244], [86.04138947, 19.85222054], [86.04110718, 19.85250092], [86.04083252, 19.85250092], [86.0402832, 19.85305977], [86.03971863, 19.85305977], [86.03916931, 19.85361099], [86.03888702, 19.85361099], [86.03805542, 19.8544445], [86.03778076, 19.8544445], [86.03749847, 19.85472488], [86.03721619, 19.85472107], [86.03694153, 19.85499954], [86.03666687, 19.85499954], [86.03639221, 19.85527992], [86.03610992, 19.85527992], [86.0358429, 19.85499954], [86.03555298, 19.85499954], [86.03527832, 19.85527992], [86.03499603, 19.85527992], [86.03472137, 19.85499954], [86.03414917, 19.85499954], [86.03392029, 19.85475159], [86.03333282, 19.85472488], [86.03305817, 19.8544445], [86.03250122, 19.8544445], [86.03236389, 19.85430527], [86.03221893, 19.85416412], [86.03193665, 19.85416985], [86.03098297, 19.85288048], [86.03044128, 19.85232353], [86.03044128, 19.85198402], [86.03083801, 19.85174561], [86.03091431, 19.85153961], [86.03090668, 19.8512001], [86.03055573, 19.85059357], [86.03055573, 19.85027695], [86.03028107, 19.85000038], [86.03028107, 19.84972191], [86.02999878, 19.84944534], [86.02999878, 19.84917259], [86.02916718, 19.84833145], [86.02889252, 19.84833336], [86.02805328, 19.84750175], [86.02805328, 19.84722137], [86.02777863, 19.84694481], [86.02777863, 19.84666634], [86.02668762, 19.84560013], [86.02611542, 19.84519768], [86.02526093, 19.84513092], [86.02481842, 19.84500122], [86.02353668, 19.84487724], [86.02353668, 19.84453964], [86.02371216, 19.84424973], [86.02464294, 19.84408951], [86.02527618, 19.84416962], [86.02583313, 19.84416771], [86.02607727, 19.84428787], [86.02694702, 19.84472275], [86.02722168, 19.8447094], [86.02777863, 19.84527969], [86.02805328, 19.84527969], [86.02833557, 19.84555626], [86.0283432, 19.84583092], [86.02889252, 19.84638977], [86.02916718, 19.84638977], [86.03083038, 19.84805489], [86.03083038, 19.84833336], [86.03111267, 19.84861183], [86.03111267, 19.8488903], [86.03166962, 19.84944534], [86.03166962, 19.84972191], [86.03193665, 19.85000038], [86.03193665, 19.85056114], [86.03221893, 19.85083961], [86.03221893, 19.85111046], [86.03250122, 19.85138893], [86.03250122, 19.85194206], [86.03277588, 19.85222054], [86.03277588, 19.85250092], [86.03414917, 19.85390091], [86.03666687, 19.85390091], [86.03694153, 19.85361099], [86.0375061, 19.85361099], [86.03778076, 19.85333252], [86.03805542, 19.85333252], [86.03861237, 19.85277748], [86.03888702, 19.85277939], [86.04057312, 19.85111046], [86.04111481, 19.85111046], [86.04334259, 19.8488903], [86.04416656, 19.84804916], [86.04499054, 19.84777832], [86.04548645, 19.84757614], [86.04563141, 19.84737015], [86.04563141, 19.84723663], [86.04556274, 19.84710121], [86.0450592, 19.84691048], [86.04432678, 19.84682274], [86.04403687, 19.84674072], [86.04302216, 19.84657097], [86.04189301, 19.84622955], [86.04142761, 19.84614944], [86.04029846, 19.84601784], [86.03845215, 19.84534073], [86.0378418, 19.84528923], [86.03620148, 19.84507942], [86.03499603, 19.84454346], [86.03356934, 19.84427071], [86.03214264, 19.84406853], [86.03050995, 19.8439312], [86.02980804, 19.84362602], [86.02752686, 19.84329033], [86.02632904, 19.84282112], [86.02490234, 19.84262085], [86.02348328, 19.84249115], [86.02134705, 19.84227943], [86.02068329, 19.84214592], [86.01847839, 19.84160614], [86.01641083, 19.84086037], [86.01486969, 19.84062576], [86.01394653, 19.84049034], [86.01251984, 19.8402195], [86.01145935, 19.84008026], [86.00999451, 19.83998108], [86.00914001, 19.83991432], [86.00821686, 19.83984947], [86.00737, 19.83937073], [86.00658417, 19.83910179], [86.00543976, 19.83910179], [86.00479889, 19.83883286], [86.0031662, 19.83835793], [86.0017395, 19.83829117], [86.0, 19.83805275], [85.99822998, 19.83774948], [85.99749756, 19.83778], [85.99555206, 19.83778], [85.99500275, 19.83749962], [85.99472046, 19.83749962], [85.9944458, 19.83722115], [85.99416351, 19.83722115], [85.99388885, 19.83694458], [85.99111176, 19.83694458], [85.99055481, 19.83638954], [85.9888916, 19.83638954], [85.98860931, 19.83611107], [85.98583221, 19.83611107], [85.98555756, 19.8358326], [85.98500061, 19.8358326], [85.98472595, 19.83555603], [85.98361206, 19.83556175], [85.98332977, 19.83527946], [85.98278046, 19.83527946], [85.98249817, 19.83499908], [85.98110962, 19.83499908], [85.98084259, 19.83472061], [85.97915649, 19.83472061], [85.97888947, 19.83499908], [85.97860718, 19.83499908], [85.9783783, 19.83476639], [85.97805786, 19.83472252], [85.97750092, 19.83416748], [85.97638702, 19.83416939], [85.97611237, 19.83389091], [85.97583008, 19.83389091], [85.97556305, 19.83361053], [85.97499847, 19.83361053], [85.97471619, 19.83389091], [85.97444153, 19.83389091], [85.97416687, 19.83361053], [85.97360992, 19.83361053], [85.9733429, 19.83332825], [85.97305298, 19.83361053], [85.97277832, 19.83361053], [85.97249603, 19.83332825], [85.97166443, 19.83333397], [85.97138977, 19.8330555], [85.97055817, 19.83305931], [85.97027588, 19.83276939], [85.96861267, 19.83277893], [85.96833038, 19.83250046], [85.96749878, 19.83250046], [85.96721649, 19.83221817], [85.96694183, 19.83222198], [85.96666718, 19.83194351], [85.96444702, 19.83194351], [85.96416473, 19.83166885], [85.96193695, 19.83167076], [85.96166992, 19.83139038], [85.96028137, 19.83139038], [85.96014404, 19.83124733], [85.95999908, 19.83110809], [85.95916748, 19.83111191], [85.95888519, 19.83083344], [85.95833588, 19.83083344], [85.95805359, 19.83055687], [85.95749664, 19.83056068], [85.95722198, 19.8302803], [85.95527649, 19.8302803], [85.95500183, 19.82999992], [85.95333099, 19.82999992], [85.95305634, 19.82973099], [85.95276642, 19.82973099], [85.95249939, 19.82944107], [85.9513855, 19.82944679], [85.95111084, 19.82916451], [85.94999695, 19.82917023], [85.94972229, 19.82888985], [85.9486084, 19.82888985], [85.94832611, 19.82860947], [85.94777679, 19.82861137], [85.94750214, 19.8283329], [85.9466629, 19.8283329], [85.94657135, 19.82824135], [85.94638824, 19.82805443], [85.94499969, 19.82806015], [85.94489288, 19.82795143], [85.94473267, 19.82777977], [85.94444275, 19.82777977], [85.94416046, 19.82749939], [85.94277954, 19.82749939], [85.94249725, 19.82722092], [85.9422226, 19.82722282], [85.94194794, 19.82694435], [85.94083405, 19.82694435], [85.94055176, 19.82666588], [85.93888855, 19.82666969], [85.93860626, 19.82639122], [85.93776703, 19.82639122], [85.9375, 19.82611084], [85.93583679, 19.82611084], [85.93554688, 19.82583046], [85.93527985, 19.82583237], [85.93499756, 19.8255558], [85.93444824, 19.82555962], [85.9338913, 19.82500076], [85.93110657, 19.82444191], [85.92972565, 19.82444382], [85.9291687, 19.82388878], [85.92749786, 19.82389069], [85.92722321, 19.82360077], [85.92694092, 19.82361031], [85.92666626, 19.82333374], [85.92610931, 19.82333374], [85.92597961, 19.82320213], [85.92583466, 19.82305527], [85.92472076, 19.82305527], [85.92455292, 19.82322693], [85.92444611, 19.82333374], [85.92416382, 19.82305527], [85.9236145, 19.82305527], [85.92333221, 19.82333374], [85.92138672, 19.82333374], [85.92082977, 19.8227787], [85.92028046, 19.82278061], [85.91999054, 19.82250023], [85.91971588, 19.82250023], [85.91944122, 19.82222176], [85.91750336, 19.82222176], [85.91722107, 19.82250023], [85.91694641, 19.82222176], [85.91638947, 19.82222176], [85.91611481, 19.82250023], [85.91416931, 19.82250023], [85.91361237, 19.82194519], [85.91333008, 19.82195282], [85.91306305, 19.82167053], [85.91278076, 19.82167053], [85.91221619, 19.82111168], [85.91083527, 19.82111168], [85.91027832, 19.82055473], [85.90972137, 19.82111168], [85.90972137, 19.82139015], [85.90860748, 19.82250023], [85.90860748, 19.82360077], [85.90833282, 19.82388878], [85.90833282, 19.82472038], [85.90805817, 19.82500076], [85.90805054, 19.82583046], [85.90777588, 19.82611084], [85.90777588, 19.82694435], [85.90750122, 19.82722092], [85.90750122, 19.82777977], [85.90721893, 19.82805443], [85.90721893, 19.82860947], [85.90694427, 19.82888794], [85.90693665, 19.82944107], [85.90666962, 19.82973099], [85.90666962, 19.82999992], [85.90694427, 19.8302784], [85.90638733, 19.83083344], [85.90638733, 19.83110809], [85.90583038, 19.83166885], [85.90583038, 19.83194351], [85.90555573, 19.83222198], [85.90499878, 19.83222198], [85.90460205, 19.83182716], [85.90444183, 19.83166885], [85.90416718, 19.83167076], [85.90416718, 19.82973099], [85.90471649, 19.82917023], [85.90471649, 19.82888985], [85.90500641, 19.82860947], [85.90499878, 19.82805443], [85.90528107, 19.82777977], [85.90528107, 19.82500076], [85.90556335, 19.82472038], [85.90555573, 19.82305527], [85.90583038, 19.82278061], [85.90583038, 19.82222176], [85.90611267, 19.82194519], [85.90611267, 19.82111168], [85.90638733, 19.82083321], [85.90638733, 19.82055473], [85.90777588, 19.81916618], [85.90834045, 19.81858063], [85.9080658, 19.8178997], [85.90721893, 19.81777954], [85.90596771, 19.81768036], [85.90338898, 19.81699944], [85.90084076, 19.81604958], [85.89813995, 19.81524086], [85.89514923, 19.81456184], [85.893013, 19.81402016], [85.8897171, 19.81278038], [85.88861084, 19.81278038], [85.88833618, 19.8125], [85.88639069, 19.8125], [85.8861084, 19.81221962], [85.88555908, 19.81222153], [85.88527679, 19.81194305], [85.88500214, 19.81195068], [85.88471985, 19.81166267], [85.8841629, 19.81166649], [85.88388824, 19.81138802], [85.88360596, 19.81138992], [85.8833313, 19.81110954], [85.88249969, 19.81111145], [85.88222504, 19.81083107], [85.88083649, 19.81083107], [85.8805542, 19.81055641], [85.87944794, 19.81056023], [85.8793335, 19.81044769], [85.87917328, 19.81027985], [85.87889099, 19.81027985], [85.8786087, 19.80999947], [85.8769455, 19.80999947], [85.87666321, 19.8097229], [85.87611389, 19.8097229], [85.8758316, 19.80944443], [85.87472534, 19.80944443], [85.87444305, 19.80916595], [85.8741684, 19.80916977], [85.87388611, 19.80888939], [85.87277985, 19.80888939], [85.87249756, 19.80859756], [85.8722229, 19.80861282], [85.87194824, 19.80833244], [85.8713913, 19.80833244], [85.87110901, 19.80805588], [85.8702774, 19.80805969], [85.87000275, 19.80777931], [85.86972046, 19.80777931], [85.8694458, 19.80750084], [85.86805725, 19.80750084], [85.86778259, 19.80721855], [85.8666687, 19.80722237], [85.86638641, 19.80694389], [85.86555481, 19.80694389], [85.86528015, 19.80666733], [85.86499786, 19.80666924], [85.86472321, 19.80639076], [85.86444092, 19.80639076], [85.86416626, 19.80611038], [85.86360931, 19.80611038], [85.86305237, 19.80555916], [85.86194611, 19.80555916], [85.86165619, 19.80528069], [85.86055756, 19.80528069], [85.85943604, 19.80417061], [85.85888672, 19.80389023], [85.85861206, 19.80360985], [85.85749817, 19.80361176], [85.85562897, 19.80340576], [85.85475922, 19.80258751], [85.85391998, 19.80273056], [85.8527832, 19.80273056], [85.85106659, 19.80165291], [85.84951019, 19.80165291], [85.84908295, 19.80111122], [85.84751129, 19.80070114], [85.8466568, 19.80124092], [85.84552002, 19.80124092], [85.8445282, 19.80056], [85.8431015, 19.80042839], [85.84139252, 19.79948044], [85.8395462, 19.7992115], [85.83798218, 19.79879951], [85.83750153, 19.79805565], [85.83444214, 19.79722023], [85.83346558, 19.79723167], [85.83190918, 19.79684448], [85.83112335, 19.79664993], [85.82900238, 19.79570007], [85.82685089, 19.79556465], [85.82492828, 19.79479408], [85.82234955, 19.7940731], [85.82006836, 19.79312515], [85.81838226, 19.79236031], [85.8169632, 19.79236031], [85.81321716, 19.79145813], [85.81027985, 19.79027557], [85.80999756, 19.79055977], [85.80916595, 19.79055977], [85.8088913, 19.79027939], [85.80832672, 19.79027939], [85.80722046, 19.78917122], [85.8069458, 19.78917122], [85.80665588, 19.78889084], [85.80528259, 19.78889084], [85.80375671, 19.78812027], [85.80119324, 19.78730965], [85.79934692, 19.78689957], [85.7977829, 19.7863903], [85.79750061, 19.78610992], [85.79524231, 19.78536606], [85.79296112, 19.78428078], [85.79138947, 19.7836113], [85.78900909, 19.78355408], [85.78843689, 19.78288078], [85.78701019, 19.7824707], [85.78527832, 19.78277969], [85.7841568, 19.78277969], [85.78388977, 19.78250122], [85.78333282, 19.78250122], [85.7831955, 19.78236008], [85.78305817, 19.78222275], [85.78250122, 19.78222275], [85.78221893, 19.78194427], [85.78193665, 19.78194237], [85.78138733, 19.78250122], [85.78138733, 19.78277779], [85.78083038, 19.78333282], [85.78083038, 19.7836113], [85.78055573, 19.78388977], [85.78083038, 19.78444481], [85.78083038, 19.78472137], [85.78055573, 19.78499985], [85.77993011, 19.78504181], [85.77983856, 19.78499794], [85.77964783, 19.78490639], [85.77964783, 19.78403282], [85.77971649, 19.78360939], [85.77972412, 19.78333282], [85.77999878, 19.78305626], [85.77999878, 19.78055954], [85.77971649, 19.78027916], [85.77971649, 19.7797184], [85.77944183, 19.77944374], [85.77916718, 19.77944374], [85.77889252, 19.77916718], [85.77861786, 19.77916908], [85.7783432, 19.77889061], [85.77805328, 19.77889061], [85.77722168, 19.77806091], [85.77694702, 19.77806091], [85.77639008, 19.77750015], [85.77555847, 19.77750015], [85.77527618, 19.77721977], [85.77500153, 19.77722168], [85.77471924, 19.77694511], [85.77444458, 19.77722168], [85.77388763, 19.77722168], [85.77333069, 19.77666855], [85.77305603, 19.77667046], [85.77249146, 19.7761097], [85.77222443, 19.7761116], [85.77194214, 19.77589989], [85.77027893, 19.77583313], [85.76999664, 19.77555466], [85.76972198, 19.77556038], [85.76944733, 19.77528], [85.76917267, 19.77528], [85.76889038, 19.77499962], [85.76721954, 19.77499962], [85.76693726, 19.77472115], [85.76667023, 19.77472305], [85.76638794, 19.77444649], [85.76611328, 19.77472305], [85.76438141, 19.77413177], [85.76281738, 19.77359009], [85.76027679, 19.77277946], [85.76000214, 19.77248955], [85.75971985, 19.77249908], [85.75944519, 19.77222252], [85.75861359, 19.77222252], [85.7583313, 19.77194214], [85.75805664, 19.77194214], [85.75777435, 19.77166748], [85.75749207, 19.77166939], [85.75694275, 19.77111053], [85.75554657, 19.77111053], [85.75527954, 19.77083015], [85.75499725, 19.7705555], [85.75444794, 19.77056122], [85.75258636, 19.76982117], [85.75131226, 19.76928139], [85.74833679, 19.76861191], [85.7480545, 19.76833344], [85.74749756, 19.76833344], [85.74739075, 19.76822662], [85.7472229, 19.76805496], [85.74666595, 19.76806259], [85.7463913, 19.7677803], [85.74610901, 19.7677803], [85.74582672, 19.76750183], [85.74555206, 19.76750183], [85.7452774, 19.76722145], [85.74472046, 19.76722145], [85.7444458, 19.76694489], [85.74305725, 19.76694489], [85.74250031, 19.76638985], [85.7416687, 19.76638985], [85.7408371, 19.76555824], [85.74054718, 19.76555824], [85.74028015, 19.76527977], [85.73860931, 19.76527977], [85.7360611, 19.76436806], [85.73420715, 19.76355934], [85.73264313, 19.76275063], [85.73065186, 19.7620697], [85.72805786, 19.76166534], [85.7277832, 19.76139069], [85.72750854, 19.76139069], [85.72721863, 19.76111031], [85.72638702, 19.76111031], [85.72583008, 19.76054955], [85.72555542, 19.76055336], [85.72528076, 19.7602787], [85.72444153, 19.76028061], [85.72055817, 19.75889015], [85.71611023, 19.75749016], [85.71555328, 19.75749969], [85.71527863, 19.75722122], [85.71499634, 19.75722122], [85.71472168, 19.75694466], [85.71444702, 19.75694466], [85.71416473, 19.75666618], [85.71389008, 19.75667191], [85.71305847, 19.75583267], [85.71069336, 19.75563812], [85.70897675, 19.75510025], [85.70767975, 19.75472069], [85.70639801, 19.75445175], [85.70582581, 19.75445175], [85.70555878, 19.75416946], [85.70527649, 19.75416946], [85.70500183, 19.75388908], [85.70443726, 19.75388908], [85.70313263, 19.75331116], [85.70198822, 19.75275993], [85.70027924, 19.75222206], [85.69999695, 19.75194359], [85.69972229, 19.75194359], [85.69889069, 19.75111198], [85.6986084, 19.75111198], [85.69851685, 19.75101852], [85.69833374, 19.75083351], [85.69721985, 19.75083351], [85.69704437, 19.75065422], [85.69694519, 19.75055695], [85.69610596, 19.75056076], [85.6958313, 19.75028038], [85.69526672, 19.75028038], [85.69499969, 19.75], [85.69444275, 19.75], [85.6938858, 19.74945068], [85.69304657, 19.74945068], [85.69277954, 19.7491703], [85.69249725, 19.7491703], [85.6922226, 19.74888992], [85.69194794, 19.74888992], [85.69167328, 19.74860954], [85.6911087, 19.74861145], [85.69083405, 19.74833298], [85.6902771, 19.74833298], [85.68999481, 19.74811172], [85.68945313, 19.74806023], [85.68926239, 19.74787521], [85.68916321, 19.74777794], [85.68860626, 19.74777985], [85.6883316, 19.74749947], [85.6875, 19.74749947], [85.68723297, 19.74722099], [85.68694305, 19.74722481], [85.6866684, 19.74694443], [85.68611145, 19.74694443], [85.68583679, 19.74666405], [85.68499756, 19.74666977], [85.6847229, 19.74638939], [85.68444824, 19.74638939], [85.68248749, 19.74596977], [85.68049622, 19.74570084], [85.67888641, 19.74472046], [85.6783371, 19.74416733], [85.67804718, 19.74417114], [85.67778015, 19.74389076], [85.67694092, 19.74389076], [85.67582703, 19.74278069], [85.67527771, 19.74278069], [85.67500305, 19.74250984], [85.67388916, 19.74250984], [85.67360687, 19.74222183], [85.67277527, 19.74222183], [85.67250061, 19.74194527], [85.67193604, 19.7419529], [85.67166901, 19.74167252], [85.67138672, 19.74167252], [85.67111206, 19.74139023], [85.67082977, 19.74139023], [85.67056274, 19.74111176], [85.67028046, 19.74111176], [85.66999817, 19.74083328], [85.66916656, 19.74083328], [85.66889191, 19.74055481], [85.66860962, 19.74055481], [85.66833496, 19.74027824], [85.66777802, 19.74028015], [85.66768646, 19.7401886], [85.66722107, 19.7397213], [85.66666412, 19.7397213], [85.66638947, 19.73944473], [85.66471863, 19.73944855], [85.66443634, 19.73916817], [85.66361237, 19.73916817], [85.66305542, 19.73860741], [85.66278076, 19.73833275], [85.66278076, 19.73805618], [85.66249847, 19.73777962], [85.66249847, 19.73666954], [85.66221619, 19.73637962], [85.66222382, 19.73555756], [85.66249847, 19.73528099], [85.66221619, 19.73500061], [85.66221619, 19.73472023], [85.66194153, 19.73444366], [85.66194153, 19.73388863], [85.66166687, 19.73361015], [85.66166687, 19.73333359], [85.66027832, 19.73194313], [85.65999603, 19.73195076], [85.65972137, 19.73167038], [85.65944672, 19.73195076], [85.65888977, 19.73195076], [85.65805817, 19.73110962], [85.65750122, 19.73110962], [85.65666962, 19.73195076], [85.65555573, 19.73194313], [85.65528107, 19.7322216], [85.65472412, 19.7322216], [85.65444183, 19.73195076], [85.65361023, 19.73195076], [85.6533432, 19.73167038], [85.65277863, 19.73167038], [85.65194702, 19.73083115], [85.65166473, 19.73083115], [85.65110779, 19.73027802], [85.65083313, 19.73027992], [85.65055847, 19.73000145], [85.65000153, 19.7294445], [85.64971924, 19.7294445], [85.64944458, 19.72972107], [85.64888763, 19.72972107], [85.64861298, 19.7294445], [85.64749908, 19.7294445], [85.64722443, 19.72916603], [85.64694214, 19.72916985], [85.64666748, 19.72888947], [85.64638519, 19.72888947], [85.64611053, 19.7286129], [85.64554596, 19.7286129], [85.64527893, 19.7283287], [85.64472198, 19.72833252], [85.64444733, 19.72805595], [85.64417267, 19.72806168], [85.64398193, 19.72787094], [85.64389038, 19.72777748], [85.64360809, 19.72777939], [85.64332581, 19.72751045], [85.64305878, 19.72751045], [85.64266205, 19.72710228], [85.64250183, 19.72694397], [85.64221954, 19.72694397], [85.64111328, 19.72583389], [85.64055634, 19.72583389], [85.64027405, 19.72555542], [85.6397171, 19.72555923], [85.63944244, 19.72528076], [85.63916779, 19.72528076], [85.63833618, 19.72500038], [85.63777924, 19.72500038], [85.63722229, 19.72443962], [85.63694763, 19.72444534], [85.63666534, 19.72416878], [85.63639069, 19.72417068], [85.63582611, 19.72360992], [85.63527679, 19.72361183], [85.63500214, 19.72333336], [85.63444519, 19.72333336], [85.6341629, 19.72305679], [85.63388824, 19.72333336], [85.63305664, 19.72249985], [85.63166809, 19.72249985], [85.6313858, 19.72221947], [85.63083649, 19.72222137], [85.62944794, 19.72083282], [85.62916565, 19.72083282], [85.62897491, 19.72063637], [85.62889099, 19.72055435], [85.6277771, 19.72056007], [85.62750244, 19.72027969], [85.62722015, 19.72027969], [85.62695313, 19.72000122], [85.62666321, 19.72000122], [85.62638855, 19.71972084], [85.62611389, 19.71972275], [85.6258316, 19.71944427], [85.62555695, 19.71944427], [85.62527466, 19.7191658], [85.62499237, 19.71916962], [85.62481689, 19.7189846], [85.62473297, 19.71889114], [85.62444305, 19.71889114], [85.6241684, 19.71861076], [85.62388611, 19.71861076], [85.62277985, 19.71750069], [85.62249756, 19.71750069], [85.6222229, 19.71722031], [85.61937714, 19.71676636], [85.6186676, 19.71635818], [85.61781311, 19.71581841], [85.61638641, 19.71528053], [85.61532593, 19.7148304], [85.61434174, 19.71442032], [85.61333466, 19.7136116], [85.61305237, 19.71333313], [85.61250305, 19.71333313], [85.61222076, 19.71305466], [85.61194611, 19.71305466], [85.6111145, 19.71222305], [85.60892487, 19.71161652], [85.60769653, 19.71083832], [85.60749817, 19.71055984], [85.60721588, 19.71027946], [85.60666656, 19.71027946], [85.60639191, 19.71000099], [85.60610962, 19.71000099], [85.60582733, 19.70972061], [85.60500336, 19.70972252], [85.60472107, 19.70944595], [85.60444641, 19.70944595], [85.60388947, 19.7088871], [85.60360718, 19.70889091], [85.60321808, 19.70849419], [85.60305786, 19.70833588], [85.60277557, 19.70833588], [85.60227203, 19.70783043], [85.60194397, 19.70750046], [85.60111237, 19.70750046], [85.60082245, 19.70722008], [85.60055542, 19.70722198], [85.60015869, 19.70682716], [85.59999847, 19.70666695], [85.59944153, 19.70667076], [85.59916687, 19.70639992], [85.59889221, 19.70639992], [85.59864807, 19.70615005], [85.59805298, 19.70611191], [85.59727478, 19.70558739], [85.59649658, 19.70506859], [85.59616089, 19.70471954], [85.59604645, 19.7044239], [85.59541321, 19.70441628], [85.5949173, 19.70428085], [85.59401703, 19.70407867], [85.59361267, 19.70360947], [85.59333038, 19.70361137], [85.59305573, 19.7033329], [85.59278107, 19.70334053], [85.59249878, 19.70306015], [85.59194946, 19.70306015], [85.59175873, 19.70286942], [85.59166718, 19.70277786], [85.59139252, 19.70277977], [85.5908432, 19.70222282], [85.59055328, 19.70222282], [85.59027863, 19.70194435], [85.58999634, 19.70194435], [85.58916473, 19.70111084], [85.58888245, 19.70111084], [85.58869934, 19.70092583], [85.58860779, 19.70083427], [85.58833313, 19.70083427], [85.5881958, 19.70069504], [85.58805847, 19.7005558], [85.58721924, 19.70055962], [85.58693695, 19.7002697], [85.58666992, 19.70027733], [85.58638763, 19.70000076], [85.58611298, 19.70000076], [85.58582306, 19.69971848], [85.58555603, 19.69972229], [85.58528137, 19.69944382], [85.58499908, 19.69944382], [85.58472443, 19.69916725], [85.58444214, 19.69916916], [85.58389282, 19.69861031], [85.58361053, 19.69861031], [85.58333588, 19.69832993], [85.58305359, 19.69833374], [85.58277893, 19.69805527], [85.58249664, 19.69805908], [85.58194733, 19.69750023], [85.58166504, 19.69750023], [85.58118439, 19.69728279], [85.58062744, 19.69742012], [85.57943726, 19.6972599], [85.57830048, 19.69671059], [85.57688141, 19.69617271], [85.57545471, 19.69536018], [85.57460022, 19.69536018], [85.57250214, 19.69444084], [85.57221985, 19.69416428], [85.57195282, 19.69417], [85.5716629, 19.69388962], [85.57138824, 19.69388962], [85.57110596, 19.69361115], [85.57081604, 19.69361115], [85.56999969, 19.69277954], [85.56916809, 19.69277954], [85.5688858, 19.69250107], [85.56861115, 19.69250107], [85.56833649, 19.69222069], [85.56804657, 19.69250107], [85.56667328, 19.69111061], [85.56639099, 19.69111061], [85.56582642, 19.69055939], [85.5652771, 19.69000053], [85.56500244, 19.69000053], [85.56472015, 19.68972015], [85.5644455, 19.68972015], [85.56416321, 19.68944359], [85.56388855, 19.68944359], [85.56361389, 19.68916702], [85.5633316, 19.68917274], [85.56305695, 19.68889046], [85.56276703, 19.68889046], [85.56252289, 19.68863487], [85.56223297, 19.6883316], [85.5616684, 19.68833351], [85.56111145, 19.68777847], [85.56054688, 19.68778038], [85.56027985, 19.68750191], [85.5597229, 19.68750191], [85.55944824, 19.68722153], [85.5588913, 19.68722153], [85.55833435, 19.68666649], [85.55805206, 19.6866684], [85.55750275, 19.68610764], [85.5569458, 19.68611145], [85.55666351, 19.68583298], [85.55638885, 19.68583298], [85.55583191, 19.68527985], [85.55555725, 19.68527985], [85.55527496, 19.68499947], [85.55500031, 19.68499947], [85.55473328, 19.68472099], [85.55388641, 19.6847229], [85.55361176, 19.68444443], [85.5533371, 19.68444443], [85.55278015, 19.68388939], [85.55249786, 19.68388939], [85.55222321, 19.68361092], [85.55194092, 19.68361092], [85.54971313, 19.68250084], [85.54944611, 19.68250084], [85.54888916, 19.68194008], [85.5486145, 19.6819458], [85.54833221, 19.68166542], [85.54805756, 19.68167114], [85.5477829, 19.68139076], [85.54722595, 19.68139076], [85.54693604, 19.68111038], [85.54252625, 19.67981911], [85.53954315, 19.67819023], [85.53639221, 19.67638969], [85.53362274, 19.67556953], [85.53092194, 19.6746254], [85.52892303, 19.67272949], [85.52536774, 19.6715107], [85.52279663, 19.66988945], [85.51893616, 19.66802979], [85.51638031, 19.66723061], [85.51352692, 19.66546059], [85.51139832, 19.66423988], [85.50926208, 19.66316032], [85.50694275, 19.66167259], [85.5027771, 19.65916824], [85.50138855, 19.65888977], [85.50110626, 19.65888977], [85.50026703, 19.65805817], [85.49944305, 19.65805817], [85.4991684, 19.65777969], [85.49888611, 19.65777969], [85.49859619, 19.65750122], [85.49833679, 19.65750122], [85.49804688, 19.65722084], [85.49777985, 19.65722275], [85.49749756, 19.65694427], [85.4972229, 19.65694427], [85.49694824, 19.65666771], [85.4963913, 19.65666962], [85.49610901, 19.65639114], [85.49582672, 19.65639114], [85.49555969, 19.65611076], [85.4952774, 19.65611076], [85.49472046, 19.65555954], [85.4944458, 19.65555954], [85.49388885, 19.65500069], [85.49360657, 19.65500069], [85.49276733, 19.65417099], [85.49250031, 19.65417099], [85.49239349, 19.65405846], [85.49222565, 19.6538887], [85.4916687, 19.65389061], [85.49138641, 19.65361023], [85.49111176, 19.65361023], [85.49054718, 19.65306091], [85.49028015, 19.65306091], [85.48999786, 19.65278053], [85.48916626, 19.65278053], [85.4888916, 19.65250015], [85.48860931, 19.65250015], [85.48832703, 19.65223122], [85.48805237, 19.65223122], [85.48777771, 19.65195084], [85.48694611, 19.65195084], [85.48665619, 19.65167046], [85.48555756, 19.65167046], [85.4852829, 19.65139008], [85.48500061, 19.65139008], [85.48486328, 19.65124893], [85.48472595, 19.6511116], [85.48416901, 19.6511116], [85.48388672, 19.65083122], [85.48332977, 19.65083122], [85.48305511, 19.65055466], [85.48278046, 19.65055466], [85.48249817, 19.65027809], [85.48221588, 19.65028], [85.48194122, 19.64999962], [85.48166656, 19.64999962], [85.48139191, 19.64972115], [85.48110962, 19.64972115], [85.48055267, 19.64916611], [85.48027802, 19.64916611], [85.48000336, 19.64888954], [85.47972107, 19.64888954], [85.47944641, 19.64861107], [85.47888947, 19.64861107], [85.47860718, 19.6483326], [85.47833252, 19.6483326], [85.47805786, 19.64805603], [85.4777832, 19.64806175], [85.47744751, 19.64772224], [85.47693634, 19.64722061], [85.47638702, 19.64722252], [85.47611237, 19.64694405], [85.47499847, 19.64694405], [85.47444153, 19.64639091], [85.47389221, 19.64639091], [85.47360992, 19.646101], [85.47333527, 19.64611053], [85.47305298, 19.64583397], [85.47277832, 19.64583397], [85.47250366, 19.6455555], [85.47222137, 19.64555931], [85.47194672, 19.64528084], [85.47138977, 19.64528084], [85.47101593, 19.64490509], [85.47083282, 19.64471817], [85.47027588, 19.64472198], [85.46971893, 19.64416885], [85.46943665, 19.64417076], [85.46888733, 19.64360809], [85.46749878, 19.64361191], [85.46722412, 19.64333344], [85.46694183, 19.64333344], [85.46683502, 19.64322472], [85.46666718, 19.64305687], [85.46639252, 19.64306068], [85.46615601, 19.64282036], [85.4658432, 19.64249992], [85.46555328, 19.64249992], [85.46527863, 19.64222145], [85.46472168, 19.64222145], [85.46444702, 19.64194679], [85.46416473, 19.64194679], [85.46389008, 19.64166451], [85.46360779, 19.64167023], [85.46333313, 19.64138985], [85.46277618, 19.64138985], [85.46248627, 19.64110947], [85.46221924, 19.64111137], [85.46166992, 19.64055443], [85.46111298, 19.64056015], [85.46083069, 19.64029121], [85.4597168, 19.64029121], [85.45942688, 19.63999939], [85.45888519, 19.63999939], [85.45833588, 19.63944435], [85.45805359, 19.63944435], [85.45749664, 19.63888931], [85.45722198, 19.63889122], [85.45694733, 19.63861084], [85.4566803, 19.63889122], [85.45582581, 19.63889122], [85.45500183, 19.63805962], [85.45471954, 19.63805962], [85.45443726, 19.63778114], [85.45417023, 19.63778114], [85.45388794, 19.63750076], [85.45361328, 19.63750076], [85.45333099, 19.63722038], [85.45305634, 19.63722229], [85.45277405, 19.63694382], [85.45249939, 19.63694382], [85.45222473, 19.63666725], [85.45111084, 19.63667107], [85.45083618, 19.63639069], [85.44972229, 19.63639069], [85.44944763, 19.63611031], [85.44796753, 19.63562012], [85.4478302, 19.63563156], [85.44647217, 19.63495636], [85.44576263, 19.63475227], [85.44497681, 19.63455009], [85.4438858, 19.63389015], [85.44361115, 19.63416672], [85.44333649, 19.63416672], [85.44166565, 19.63249969], [85.44139099, 19.63249969], [85.4411087, 19.63222122], [85.44055176, 19.63222313], [85.4402771, 19.63194466], [85.43916321, 19.63194466], [85.43888855, 19.63166618], [85.43860626, 19.63166809], [85.43805695, 19.63112068], [85.43776703, 19.63112068], [85.4375, 19.63083076], [85.43722534, 19.63083267], [85.43275452, 19.62917519], [85.4310379, 19.62823105], [85.42904663, 19.62742043], [85.42549896, 19.62552071], [85.42378998, 19.62457275], [85.42222595, 19.62416649], [85.41919708, 19.62306976], [85.41777802, 19.62198639], [85.41635132, 19.62117958], [85.41471863, 19.62027931], [85.41443634, 19.62027931], [85.41416931, 19.62000084], [85.41388702, 19.62000084], [85.41361237, 19.61972046], [85.41305542, 19.61972237], [85.41047668, 19.6183548], [85.40919495, 19.61767769], [85.40721893, 19.61667061], [85.40486908, 19.61561012], [85.40344238, 19.61466789], [85.40159607, 19.61384964], [85.40045166, 19.61317635], [85.39888763, 19.61250114], [85.39787292, 19.61166191], [85.39743805, 19.61125565], [85.39573669, 19.61071014], [85.39431, 19.61017227], [85.39260101, 19.60909081], [85.39103699, 19.60855293], [85.38976288, 19.60801125], [85.3887558, 19.60705948], [85.38719177, 19.60638046], [85.38555908, 19.60611153], [85.38471985, 19.60527992], [85.38446045, 19.60527992], [85.38431549, 19.60514832], [85.3841629, 19.60499954], [85.38414764, 19.60472107], [85.38249969, 19.60305786], [85.38140106, 19.60305977], [85.38083649, 19.60250092], [85.38054657, 19.60250092], [85.37999725, 19.60194016], [85.37944794, 19.60194588], [85.37916565, 19.6016674], [85.3786087, 19.60167122], [85.3777771, 19.60083008], [85.37750244, 19.6008358], [85.37722015, 19.60055351], [85.37666321, 19.60056114], [85.37638855, 19.60028076], [85.37610626, 19.60028076], [85.37563324, 19.59980011], [85.37555695, 19.59972191], [85.375, 19.59972191], [85.37472534, 19.59944344], [85.3741684, 19.59945107], [85.37388611, 19.59917068], [85.37361145, 19.59917068], [85.3730545, 19.59860992], [85.37249756, 19.59805107], [85.37194824, 19.59805489], [85.37166595, 19.59777832], [85.37110901, 19.59778023], [85.37082672, 19.59749985], [85.3702774, 19.59749985], [85.36794281, 19.59664917], [85.36672211, 19.59576988], [85.36553192, 19.59543037], [85.3640976, 19.59461975], [85.36267853, 19.59338951], [85.36011505, 19.59231949], [85.35868835, 19.59123611], [85.35639191, 19.59000015], [85.35582733, 19.58945084], [85.35555267, 19.58945084], [85.35527802, 19.58917046], [85.35500336, 19.58917046], [85.3549118, 19.589077], [85.35472107, 19.58888626], [85.35444641, 19.58888626], [85.35416412, 19.5886116], [85.35388947, 19.5886116], [85.35333252, 19.58805656], [85.35305786, 19.58805656], [85.35277557, 19.58777618], [85.35250092, 19.58778], [85.35193634, 19.58722115], [85.35166931, 19.58722305], [85.35138702, 19.58694649], [85.35111237, 19.58694649], [85.35083008, 19.5866642], [85.35056305, 19.58666992], [85.35028076, 19.58638954], [85.34999847, 19.58638954], [85.34971619, 19.58666992], [85.34944153, 19.58666992], [85.34889221, 19.58611107], [85.34860992, 19.58611107], [85.34749603, 19.58500099], [85.34749603, 19.58472061], [85.34722137, 19.58472252], [85.34694672, 19.58444214], [85.34666443, 19.58444214], [85.34555817, 19.58333206], [85.34527588, 19.58333206], [85.34471893, 19.58277702], [85.3422699, 19.58205032], [85.34085083, 19.58135986], [85.33860779, 19.5802803], [85.33805847, 19.57971764], [85.33750153, 19.57972145], [85.33666992, 19.57888985], [85.33638763, 19.57888985], [85.33583069, 19.57832909], [85.33555603, 19.5783329], [85.33528137, 19.57805824], [85.33499908, 19.57777977], [85.3347168, 19.57777977], [85.33444214, 19.57749939], [85.33222198, 19.57528114], [85.33167267, 19.57528114], [85.33139038, 19.57500076], [85.33110809, 19.57500076], [85.33082581, 19.57472038], [85.33027649, 19.57472229], [85.33000183, 19.57444572], [85.32971954, 19.57444572], [85.32888794, 19.57361031], [85.32861328, 19.57361031], [85.32749939, 19.57250023], [85.3272171, 19.57250023], [85.32666779, 19.57195091], [85.32639313, 19.57195091], [85.32554626, 19.57110977], [85.32499695, 19.57111168], [85.32472229, 19.5708313], [85.32416534, 19.5708313], [85.3236084, 19.57027817], [85.32277679, 19.57028008], [85.32249451, 19.56999969], [85.32221985, 19.56972122], [85.32221985, 19.56944466], [85.3208313, 19.56805611], [85.32055664, 19.56806946], [85.32026672, 19.56777954], [85.31999969, 19.56777954], [85.31944275, 19.56722069], [85.3188858, 19.5672226], [85.31861115, 19.56694412], [85.31773376, 19.56694221], [85.31658936, 19.56653595], [85.31555176, 19.56528091], [85.31555176, 19.56500053], [85.3152771, 19.56471825], [85.3152771, 19.56444359], [85.31500244, 19.56416893], [85.31388855, 19.56417084], [85.3133316, 19.56361008], [85.31305695, 19.56361198], [85.31277466, 19.56333351], [85.3125, 19.56333351], [85.31194305, 19.56277847], [85.3116684, 19.56278038], [85.31138611, 19.5625], [85.30944824, 19.5625], [85.3088913, 19.56194115], [85.30860901, 19.56194687], [85.3077774, 19.56111145], [85.3077774, 19.56083488], [85.30716705, 19.56039047], [85.30666351, 19.55944633], [85.3061142, 19.55944633], [85.30583191, 19.55916405], [85.30526733, 19.55916977], [85.30446625, 19.55900955], [85.30361176, 19.55833054], [85.30194092, 19.55666733], [85.3013916, 19.55667114], [85.30110931, 19.55639076], [85.30082703, 19.55639076], [85.30055237, 19.55611038], [85.30027771, 19.55611038], [85.29998779, 19.55583954], [85.29943848, 19.55583954], [85.29753113, 19.55472183], [85.29528809, 19.55361176], [85.29244232, 19.55159569], [85.29045105, 19.55051041], [85.28902435, 19.54970169], [85.28778076, 19.54888916], [85.28721619, 19.54833031], [85.28694153, 19.54833412], [85.28666687, 19.54805756], [85.28639221, 19.54805946], [85.28639221, 19.54778099], [85.28527832, 19.54667091], [85.28501129, 19.54667091], [85.28444672, 19.54611015], [85.28416443, 19.54611206], [85.28360748, 19.54555321], [85.28333282, 19.54556084], [85.28305817, 19.54528046], [85.28277588, 19.54528046], [85.28166962, 19.54417038], [85.28111267, 19.54417038], [85.28095245, 19.54400826], [85.28055573, 19.54361153], [85.28028107, 19.54361153], [85.27916718, 19.54249954], [85.27887726, 19.54249954], [85.27861023, 19.54222107], [85.27805328, 19.54222107], [85.27666473, 19.54083252], [85.27639008, 19.54084015], [85.27610779, 19.54056168], [85.27456665, 19.53973961], [85.27222443, 19.53777885], [85.27194214, 19.53777885], [85.27141571, 19.53725052], [85.27055359, 19.5363884], [85.27027893, 19.5363903], [85.26917267, 19.53528023], [85.26917267, 19.53499985], [85.26889038, 19.53499985], [85.26860809, 19.53470993], [85.26833344, 19.53472137], [85.26694489, 19.53333282], [85.26667023, 19.53333282], [85.26499939, 19.5316658], [85.26444244, 19.53166962], [85.26416779, 19.53139114], [85.26333618, 19.53139114], [85.26304626, 19.53111076], [85.26277924, 19.53111076], [85.2611084, 19.52944183], [85.26083374, 19.52944374], [85.25777435, 19.52638817], [85.25694275, 19.52638817], [85.2568512, 19.52629662], [85.25666809, 19.5261116], [85.2563858, 19.5261116], [85.25611115, 19.52583313], [85.25583649, 19.52583313], [85.2555542, 19.52555275], [85.25527954, 19.52527809], [85.25499725, 19.52527809], [85.25332642, 19.52361107], [85.25305176, 19.52361107], [85.25222015, 19.52276993], [85.25166321, 19.52277756], [85.25138855, 19.52249718], [85.25110626, 19.52250099], [85.25087738, 19.5222683], [85.25055695, 19.52222252], [85.25, 19.52166748], [85.24973297, 19.52166939], [85.24822998, 19.5201683], [85.2472229, 19.51917076], [85.24694824, 19.51917076], [85.2465744, 19.51879692], [85.2463913, 19.51861382], [85.24610901, 19.51861382], [85.24583435, 19.51833344], [85.24555206, 19.51833344], [85.24500275, 19.5177784], [85.24472046, 19.5177803], [85.24360657, 19.51667023], [85.24333191, 19.51667023], [85.24305725, 19.51638985], [85.24278259, 19.51638985], [85.24111176, 19.51472282], [85.23999786, 19.51472282], [85.23972321, 19.51444435], [85.23944092, 19.51444435], [85.23916626, 19.51416588], [85.2388916, 19.5141716], [85.23860931, 19.51388931], [85.23832703, 19.51388931], [85.23777771, 19.51333046], [85.23777771, 19.5130558], [85.23722076, 19.51250076], [85.23694611, 19.51250076], [85.23638916, 19.51194382], [85.2361145, 19.51194382], [85.23555756, 19.51138878], [85.2352829, 19.51139069], [85.23472595, 19.51082993], [85.23444366, 19.51083374], [85.23352051, 19.50991058], [85.23305511, 19.50944519], [85.23278046, 19.50945091], [85.23194122, 19.50860977], [85.23166656, 19.50861168], [85.23139191, 19.50833321], [85.23110962, 19.50833321], [85.23027802, 19.50749969], [85.23000336, 19.50749969], [85.22972107, 19.50722122], [85.22944641, 19.50722313], [85.22916412, 19.50694656], [85.22888947, 19.50694656], [85.22833252, 19.50638962], [85.22776794, 19.50638962], [85.22732544, 19.50594139], [85.22721863, 19.50583267], [85.22694397, 19.50583267], [85.22583008, 19.5047226], [85.22556305, 19.50473022], [85.22470856, 19.5038929], [85.22470856, 19.50361061], [85.22444153, 19.50333023], [85.22416687, 19.50333214], [85.22333527, 19.50250053], [85.22277832, 19.50250053], [85.22222137, 19.50194168], [85.22194672, 19.50194359], [85.22083282, 19.50083351], [85.22083282, 19.50055504], [85.22055817, 19.50028038], [85.22027588, 19.50028038], [85.22000122, 19.50000191], [85.21971893, 19.50000191], [85.21943665, 19.49971962], [85.21916962, 19.49972153], [85.21888733, 19.49944496], [85.21861267, 19.49945068], [85.21806335, 19.49888992], [85.21778107, 19.49888992], [85.21611023, 19.49722099], [85.21583557, 19.4972229], [85.21527863, 19.49666786], [85.21499634, 19.49666977], [85.2141571, 19.49583054], [85.21389008, 19.49583244], [85.21360779, 19.49555779], [85.21333313, 19.49555969], [85.21276855, 19.49500084], [85.21250153, 19.49500084], [85.21193695, 19.49444008], [85.21166992, 19.4944458], [85.21153259, 19.49430656], [85.21138763, 19.49416733], [85.21111298, 19.49417114], [85.21055603, 19.49361038], [85.21028137, 19.49361038], [85.20833588, 19.49167061], [85.20804596, 19.49167061], [85.20777893, 19.49139023], [85.20749664, 19.49139023], [85.20667267, 19.4905529], [85.20639038, 19.49055481], [85.20527649, 19.48999977], [85.20359802, 19.48833275], [85.20333099, 19.48833275], [85.20277405, 19.48777771], [85.20249939, 19.48777962], [85.2022171, 19.48749924], [85.20194244, 19.48749924], [85.20139313, 19.48693848], [85.20111084, 19.4869442], [85.20083618, 19.48666573], [85.20055389, 19.48666573], [85.20027924, 19.48638916], [85.19999695, 19.48638916], [85.19832611, 19.48472023], [85.19805908, 19.48472214], [85.19777679, 19.48444366], [85.19721985, 19.48444366], [85.19611359, 19.48333359], [85.1958313, 19.48333359], [85.19472504, 19.4822216], [85.19416809, 19.4822216], [85.1938858, 19.48194695], [85.19361115, 19.48195076], [85.19277954, 19.48110962], [85.19249725, 19.48111153], [85.1911087, 19.47972488], [85.19083405, 19.47972488], [85.18972015, 19.47861099], [85.1894455, 19.47861099], [85.18916321, 19.47833252], [85.18888855, 19.47833252], [85.18861389, 19.47805405], [85.1883316, 19.47805977], [85.18776703, 19.47750092], [85.1875, 19.47750092], [85.18723297, 19.47722054], [85.18694305, 19.47722244], [85.18638611, 19.4766674], [85.18611145, 19.47667122], [85.18583679, 19.47638893], [85.18556213, 19.47639275], [85.18527985, 19.47611046], [85.18499756, 19.47611046], [85.18444824, 19.47556114], [85.18416595, 19.47556114], [85.18360901, 19.47500038], [85.18302155, 19.47435951], [85.18131256, 19.4735527], [85.17722321, 19.47000122], [85.17694092, 19.47000122], [85.17665863, 19.46972084], [85.1763916, 19.46972275], [85.17610931, 19.46944427], [85.17555237, 19.46944427], [85.17500305, 19.46888924], [85.17472076, 19.46889114], [85.17415619, 19.46833038], [85.17388916, 19.4683342], [85.17333221, 19.46777534], [85.17305756, 19.46778107], [85.17166901, 19.46639061], [85.17138672, 19.46639061], [85.16971588, 19.46471977], [85.16944122, 19.46472168], [85.16916656, 19.46444321], [85.16889191, 19.46445084], [85.16860962, 19.46417046], [85.16832733, 19.46417046], [85.16722107, 19.46305275], [85.16694641, 19.46305466], [85.16661072, 19.46271896], [85.16611481, 19.46222115], [85.16555786, 19.46222115], [85.16499329, 19.46171761], [85.16471863, 19.46167183], [85.16442871, 19.46138954], [85.16416931, 19.46138954], [85.16388702, 19.46110916], [85.16361237, 19.46110916], [85.16306305, 19.46056175], [85.16278076, 19.46056175], [85.16221619, 19.45999908], [85.16179657, 19.45946121], [85.15849304, 19.45721054], [85.15499878, 19.45416451], [85.15471649, 19.45417023], [85.15444183, 19.45388985], [85.15416718, 19.45388985], [85.15277863, 19.45249939], [85.15248871, 19.45249939], [85.15221405, 19.45227051], [85.15194702, 19.45222473], [85.14638519, 19.44833374], [85.14611053, 19.44805527], [85.14583588, 19.4480629], [85.14221954, 19.44527817], [85.14167023, 19.44472122], [85.14138794, 19.44472313], [85.14083099, 19.44416618], [85.14025879, 19.44416809], [85.13944244, 19.44333076], [85.13555908, 19.44000053], [85.13388824, 19.43832016], [85.13201141, 19.43688393], [85.12916565, 19.43444443], [85.12805176, 19.43333244], [85.1277771, 19.43333244], [85.12638855, 19.43194389], [85.12611389, 19.43194389], [85.1258316, 19.43166733], [85.12554932, 19.43166924], [85.12296295, 19.4300499], [85.12182617, 19.42922974], [85.12068939, 19.42814827], [85.11869812, 19.42654037], [85.11727142, 19.42543983], [85.11585236, 19.42381859], [85.11443329, 19.42246056], [85.11250305, 19.42111015], [85.11166382, 19.42027855], [85.11165619, 19.42000008], [85.11083221, 19.41916847], [85.10785675, 19.41669273], [85.10558319, 19.41480064], [85.1047287, 19.41377068], [85.10430145, 19.4132328], [85.10380554, 19.41255569], [85.10324097, 19.41188049], [85.10280609, 19.41134071], [85.10231018, 19.41073036], [85.10195923, 19.41018867], [85.10131836, 19.40950966], [85.10108948, 19.40917015], [85.1006012, 19.40842438], [85.10045624, 19.40794945], [85.09989166, 19.4075489], [85.09954071, 19.40700912], [85.09916687, 19.40638924], [85.0983429, 19.40557289], [85.0983429, 19.40527916], [85.09805298, 19.40500069], [85.09805298, 19.40472031], [85.09722137, 19.4038887], [85.09722137, 19.40361023], [85.09694672, 19.40332985], [85.09694672, 19.40305519], [85.09638977, 19.40250015], [85.09638977, 19.40195084], [85.09610748, 19.40167046], [85.09610748, 19.40139008], [85.09388733, 19.39916992], [85.09361267, 19.39916992], [85.09361267, 19.39888954], [85.09278107, 19.39805984], [85.09278107, 19.39777946], [85.09220886, 19.39722061], [85.09222412, 19.39666748], [85.09166718, 19.39611053], [85.09166718, 19.39556122], [85.09139252, 19.39528275], [85.09139252, 19.39500046], [85.09111023, 19.39472008], [85.09083557, 19.39472008], [85.09023285, 19.39265442], [85.08740997, 19.38991737], [85.08612823, 19.38775063], [85.08526611, 19.38585091], [85.0851059, 19.38446426], [85.08389282, 19.38276672], [85.08304596, 19.38195038], [85.08175659, 19.38100433], [85.08055878, 19.38027954], [85.07971954, 19.3794384], [85.07971954, 19.37916756], [85.07776642, 19.37722015], [85.07611084, 19.37888908], [85.07554626, 19.37888908], [85.07446289, 19.37778091], [85.07417297, 19.37778091], [85.07389069, 19.37750053], [85.0736084, 19.37750053], [85.07332611, 19.37722015], [85.07305908, 19.37722206], [85.07277679, 19.37694359], [85.07250214, 19.37694359], [85.0716629, 19.37611198], [85.0716629, 19.37583351], [85.0688858, 19.37305641], [85.06861115, 19.37306023], [85.06804657, 19.37249947], [85.06777954, 19.37249947], [85.06749725, 19.37220955], [85.0663681, 19.37176132], [85.066185, 19.37166214], [85.06562042, 19.36904335], [85.06506348, 19.36691666], [85.06516266, 19.36689758], [85.06594086, 19.36675453], [85.06622314, 19.36648369], [85.06622314, 19.36580658], [85.06600952, 19.36553383], [85.06536865, 19.36499214], [85.06472015, 19.36444473], [85.06415558, 19.36414528], [85.063797, 19.36380959], [85.06310272, 19.36367035], [85.0625, 19.36333275], [85.0616684, 19.36333275], [85.06157684, 19.3632412], [85.06138611, 19.36305618], [85.06083679, 19.36305809], [85.06054688, 19.36277962], [85.06027985, 19.36277962], [85.05999756, 19.36250114], [85.0597229, 19.36250114], [85.05945587, 19.36222076], [85.05916595, 19.36222267], [85.05860901, 19.36166763], [85.05832672, 19.36166954], [85.05805206, 19.36139107], [85.05750275, 19.36139107], [85.05722046, 19.36111069], [85.0569458, 19.36111069], [85.05665588, 19.36083031], [85.05638885, 19.36083412], [85.05583191, 19.36027527], [85.05555725, 19.36000061], [85.05555725, 19.35972023], [85.05527496, 19.35944557], [85.05500031, 19.35944557], [85.05472565, 19.35916519], [85.05332947, 19.35917091], [85.05303955, 19.35889053], [85.05278015, 19.35889053], [85.05249786, 19.35861015], [85.05222321, 19.35861206], [85.05166626, 19.35805321], [85.0513916, 19.35806084], [85.05082703, 19.35750008], [85.05027771, 19.35750008], [85.05000305, 19.3572216], [85.04944611, 19.35723114], [85.04915619, 19.35695076], [85.04860687, 19.35695076], [85.04833221, 19.35667038], [85.04805756, 19.35667038], [85.04768372, 19.35629654], [85.04750061, 19.35610962], [85.04722595, 19.35611153], [85.04694366, 19.35583115], [85.04666901, 19.35583115], [85.04657745, 19.3557415], [85.04638672, 19.35555649], [85.04611206, 19.3555603], [85.04582977, 19.35528183], [85.04556274, 19.35528183], [85.04499817, 19.35472107], [85.04472351, 19.35472107], [85.04389191, 19.35388947], [85.04360962, 19.35388947], [85.04305267, 19.35333061], [85.04277802, 19.35333252], [85.04222107, 19.35277748], [85.04194641, 19.35277939], [85.04109955, 19.35193825], [85.04027557, 19.35194397], [85.03971863, 19.35138893], [85.03943634, 19.35139084], [85.03929901, 19.35124397], [85.03916931, 19.35111046], [85.03888702, 19.35111046], [85.03853607, 19.35076141], [85.03833008, 19.35055542], [85.03806305, 19.35055923], [85.03796387, 19.35046577], [85.03778076, 19.35028076], [85.03749847, 19.35028076], [85.03721619, 19.35000038], [85.03639221, 19.35000038], [85.03610992, 19.34971809], [85.03555298, 19.34972191], [85.03500366, 19.34916878], [85.03444672, 19.34860992], [85.03416443, 19.34861183], [85.03360748, 19.34805679], [85.03333282, 19.34805679], [85.03305817, 19.34777832], [85.03250122, 19.34778023], [85.03222656, 19.34749985], [85.03166962, 19.34749985], [85.03138733, 19.34721947], [85.03111267, 19.34722137], [85.03055573, 19.34666443], [85.03028107, 19.34667015], [85.02915955, 19.34556007], [85.02889252, 19.34556007], [85.0283432, 19.34500122], [85.02805328, 19.34500122], [85.02777863, 19.34472084], [85.02749634, 19.34472466], [85.02722168, 19.34444237], [85.02666473, 19.34444237], [85.02639008, 19.3441658], [85.02610016, 19.34416962], [85.02583313, 19.34389114], [85.02555847, 19.34389114], [85.02443695, 19.34278107], [85.02416992, 19.34278107], [85.02388763, 19.34250069], [85.02361298, 19.34250069], [85.02305603, 19.34194183], [85.02278137, 19.34194374], [85.02264404, 19.34180641], [85.02249908, 19.34166718], [85.0222168, 19.3416729], [85.02166748, 19.34111023], [85.02138519, 19.34111023], [85.02083588, 19.34055519], [85.02054596, 19.34056282], [85.01999664, 19.34000015], [85.01944733, 19.34000015], [85.01917267, 19.33972168], [85.01889038, 19.33972168], [85.01833344, 19.33916664], [85.01805878, 19.33916664], [85.01784515, 19.33895683], [85.01776886, 19.33894157], [85.01750183, 19.33888817], [85.01692963, 19.33833122], [85.01667023, 19.33833313], [85.01638794, 19.33805275], [85.01611328, 19.33777809], [85.01583099, 19.33777809], [85.01555634, 19.33749962], [85.01526642, 19.33749962], [85.0150528, 19.33727455], [85.01499939, 19.33722115], [85.01472473, 19.33722305], [85.01416779, 19.33666611], [85.01389313, 19.33666992], [85.01361084, 19.33638954], [85.01333618, 19.33638954], [85.01167297, 19.33472061], [85.01139069, 19.33472252], [85.01129913, 19.33463287], [85.01083374, 19.33416748], [85.01055908, 19.33416939], [85.01027679, 19.33389091], [85.01000214, 19.33389091], [85.00971985, 19.33361053], [85.0091629, 19.33361053], [85.00888824, 19.33333015], [85.00861359, 19.33333588], [85.0083313, 19.33305359], [85.00805664, 19.33306122], [85.00694275, 19.3319397], [85.00666809, 19.33194351], [85.0063858, 19.33166695], [85.00583649, 19.33167076], [85.00554657, 19.33139038], [85.00527954, 19.33139038], [85.0047226, 19.33082962], [85.00444794, 19.33083534], [85.0036087, 19.32999992], [85.00332642, 19.32999992], [85.00013733, 19.32866859], [85.00013733, 19.32875061], [84.99986267, 19.32875061], [84.99986267, 19.32847023], [84.99958038, 19.32847023], [84.99958038, 19.32819366], [84.99903107, 19.32819366], [84.99903107, 19.3279171], [84.99846649, 19.32792282], [84.99846649, 19.32764053], [84.99764252, 19.32764053], [84.99764252, 19.32709122], [84.99736023, 19.32709122], [84.99736023, 19.32681274], [84.9970932, 19.32681274], [84.9970932, 19.32625008], [84.99652863, 19.32625008], [84.99652863, 19.3259697], [84.99597168, 19.3259716], [84.99597168, 19.32569504], [84.99569702, 19.32570076], [84.99569702, 19.32541847], [84.99514008, 19.32541847], [84.99514008, 19.32513809], [84.99485779, 19.32513809], [84.99485779, 19.32485962], [84.99430847, 19.32486153], [84.99430847, 19.32402992], [84.99375153, 19.32402992], [84.99375153, 19.32374954], [84.99346924, 19.32374954], [84.99346924, 19.32347107], [84.99263763, 19.32347298], [84.99263763, 19.3231945], [84.99236298, 19.3231945], [84.99236298, 19.32291794], [84.99153137, 19.32291985], [84.99153137, 19.32263947], [84.99124908, 19.32263947], [84.99124908, 19.32208061], [84.99069214, 19.32208252], [84.99069214, 19.32180786], [84.99041748, 19.32180977], [84.99041748, 19.32152939], [84.99015045, 19.32152939], [84.99015045, 19.320961], [84.98958588, 19.32097244], [84.98958588, 19.3204174], [84.98847198, 19.32042122], [84.98847198, 19.32014084], [84.98735809, 19.32014084], [84.98735809, 19.31986046], [84.98680878, 19.31986046], [84.98680878, 19.31958008], [84.98625183, 19.3195858], [84.98625183, 19.31930351], [84.98568726, 19.31931114], [84.98568726, 19.31903076], [84.98513794, 19.31903076], [84.98513794, 19.31847], [84.98486328, 19.31847382], [84.98486328, 19.31819344], [84.98430634, 19.31819344], [84.98430634, 19.3176384], [84.98401642, 19.3176403], [84.98401642, 19.31735992], [84.98374939, 19.31736374], [84.98374939, 19.31708145], [84.98347473, 19.31708145], [84.98347473, 19.31680489], [84.98291779, 19.31680489], [84.98291779, 19.31652832], [84.98236084, 19.31653023], [84.98236084, 19.31624985], [84.98152924, 19.31624985], [84.98152924, 19.31596947], [84.98097229, 19.31597137], [84.98097229, 19.31569481], [84.98041534, 19.31569481], [84.98041534, 19.31541634], [84.98014069, 19.31542015], [84.98014069, 19.31458282], [84.97958374, 19.31458282], [84.97958374, 19.31402779], [84.97875214, 19.31402969], [84.97875214, 19.31347084], [84.97819519, 19.31347275], [84.97819519, 19.31319427], [84.97763824, 19.31319427], [84.97763824, 19.3129158], [84.97735596, 19.31292152], [84.97735596, 19.31263924], [84.97680664, 19.31263924], [84.97680664, 19.31209183], [84.97598267, 19.31209183], [84.97598267, 19.31181145], [84.97569275, 19.31181145], [84.97569275, 19.31152916], [84.9751358, 19.31152916], [84.9751358, 19.31097031], [84.97486115, 19.31097221], [84.97486115, 19.31041718], [84.97458649, 19.31041908], [84.97458649, 19.31014061], [84.97429657, 19.31014061], [84.97429657, 19.30986023], [84.97402954, 19.30986023], [84.97402954, 19.30957985], [84.97319794, 19.30958366], [84.97319794, 19.30930519], [84.97292328, 19.30931091], [84.97292328, 19.309021], [84.97264099, 19.30902863], [84.97264099, 19.30875015], [84.97207642, 19.30875015], [84.97207642, 19.30846977], [84.9715271, 19.30847168], [84.9715271, 19.30819511], [84.97125244, 19.30820084], [84.97125244, 19.30792046], [84.97041321, 19.30792046], [84.97041321, 19.30764008], [84.97013855, 19.30764008], [84.97013855, 19.3073597], [84.96986389, 19.3073616], [84.96986389, 19.30708313], [84.9695816, 19.30708313], [84.9695816, 19.30652809], [84.96930695, 19.30653], [84.96930695, 19.30624962], [84.96875, 19.30624962], [84.96875, 19.3059597], [84.96847534, 19.30597305], [84.96847534, 19.30569649], [84.9679184, 19.30569649], [84.9679184, 19.3054142], [84.96763611, 19.30541992], [84.96763611, 19.30486107], [84.96736145, 19.30486107], [84.96736145, 19.30430984], [84.96708679, 19.30430984], [84.96708679, 19.30402946], [84.96679688, 19.30402946], [84.96679688, 19.3037529], [84.96652985, 19.3037529], [84.96652985, 19.30347061], [84.9668045, 19.30347443], [84.9668045, 19.30291748], [84.96708679, 19.30291939], [84.96708679, 19.30236053], [84.96736145, 19.30236053], [84.96736145, 19.30208015], [84.96763611, 19.30208206], [84.96763611, 19.30152702], [84.9679184, 19.30153275], [84.9679184, 19.30125046], [84.96652985, 19.30125046], [84.96652985, 19.30097008], [84.9668045, 19.30097008], [84.9668045, 19.30069351], [84.96708679, 19.30069351], [84.96708679, 19.30041695], [84.96736145, 19.30042267], [84.96736145, 19.30015182], [84.96763611, 19.30015182], [84.96763611, 19.29957771], [84.9679184, 19.29958344], [84.9679184, 19.29930496], [84.96848297, 19.29931068], [84.96848297, 19.2990284], [84.96901703, 19.2990284], [84.96901703, 19.29846954], [84.96736145, 19.29846954], [84.96736145, 19.29874992], [84.96708679, 19.29874992], [84.96708679, 19.2991581], [84.96708679, 19.29931068], [84.9668045, 19.29930496], [84.9668045, 19.29958344], [84.96624756, 19.29958344], [84.96624756, 19.29986191], [84.96598053, 19.29986191], [84.96598053, 19.30015182], [84.96569824, 19.30015182], [84.96569824, 19.30042267], [84.96541595, 19.30041695], [84.96541595, 19.30097008], [84.9651413, 19.30097008], [84.9651413, 19.30125046], [84.96485901, 19.30125046], [84.96485901, 19.30153275], [84.96457672, 19.30153275], [84.96457672, 19.30125046], [84.96430206, 19.30125046], [84.96430206, 19.30097008], [84.9640274, 19.30097008], [84.9640274, 19.30069542], [84.96375275, 19.3006916], [84.96375275, 19.30041695], [84.96347046, 19.30042267], [84.96347046, 19.30015182], [84.9631958, 19.30015182], [84.9631958, 19.29986191], [84.96291351, 19.29986191], [84.96291351, 19.29958344], [84.96263885, 19.29958344], [84.96263885, 19.29930496], [84.96235657, 19.29931068], [84.96235657, 19.2990284], [84.96180725, 19.2990284], [84.96180725, 19.29874992], [84.96151733, 19.29874992], [84.96151733, 19.29846954], [84.96125031, 19.29847145], [84.96125031, 19.29819489], [84.96097565, 19.29819489], [84.96097565, 19.29791641], [84.9604187, 19.29791832], [84.9604187, 19.29763985], [84.96013641, 19.29763985], [84.96013641, 19.29735947], [84.95986176, 19.29736137], [84.95986176, 19.2970829], [84.95903015, 19.2970829], [84.95903015, 19.29680634], [84.95847321, 19.29680824], [84.95847321, 19.29652977], [84.95819092, 19.29652977], [84.95819092, 19.29624939], [84.9576416, 19.29624939], [84.9576416, 19.29597092], [84.95652771, 19.29597282], [84.95652771, 19.29569435], [84.95569611, 19.29569435], [84.95569611, 19.29541779], [84.95540619, 19.29541969], [84.95540619, 19.29514122], [84.95485687, 19.29514122], [84.95485687, 19.29458046], [84.95458221, 19.29458427], [84.95458221, 19.29430771], [84.95404053, 19.29430962], [84.95404053, 19.2940197], [84.95375061, 19.29402733], [84.95375061, 19.29375076], [84.95347595, 19.29375076], [84.95347595, 19.29347038], [84.95319366, 19.29347229], [84.95319366, 19.29291725], [84.95291901, 19.29292107], [84.95291901, 19.29264069], [84.95207977, 19.29264069], [84.95207977, 19.29236031], [84.95180511, 19.29236031], [84.95180511, 19.29208565], [84.95124817, 19.29208565], [84.95124817, 19.29180336], [84.95096588, 19.29181099], [84.95096588, 19.29153061], [84.95041656, 19.29153061], [84.95041656, 19.29125023], [84.94985962, 19.29125023], [84.94985962, 19.29097939], [84.94930267, 19.29097939], [84.94930267, 19.29070091], [84.94902802, 19.29070091], [84.94902802, 19.29042053], [84.94875336, 19.29042053], [84.94875336, 19.29014015], [84.94847107, 19.29014015], [84.94847107, 19.28985977], [84.94791412, 19.28986359], [84.94791412, 19.28902817], [84.94763947, 19.28903008], [84.94763947, 19.28874969], [84.94708252, 19.28874969], [84.94708252, 19.28847122], [84.94625092, 19.28847122], [84.94625092, 19.28791618], [84.94568634, 19.28792191], [84.94568634, 19.28763962], [84.94513702, 19.28763962], [84.94513702, 19.28735924], [84.94458008, 19.28735924], [84.94458008, 19.28708076], [84.94430542, 19.28708267], [84.94430542, 19.28652763], [84.94403076, 19.28652954], [84.94403076, 19.28624916], [84.94374847, 19.28624916], [84.94374847, 19.28597069], [84.94319153, 19.2859726], [84.94319153, 19.28569412], [84.94291687, 19.28569412], [84.94291687, 19.28541756], [84.94210052, 19.28541946], [84.94210052, 19.28513908], [84.94181061, 19.28513908], [84.94181061, 19.28486061], [84.94152832, 19.28486061], [84.94152832, 19.28457832], [84.94097137, 19.28458405], [84.94097137, 19.28430557], [84.94069672, 19.28430748], [84.94069672, 19.28403091], [84.94013977, 19.28403091], [84.94013977, 19.28375053], [84.93985748, 19.28375053], [84.93985748, 19.28347015], [84.93958282, 19.28347206], [84.93958282, 19.28319359], [84.93930817, 19.28319359], [84.93930817, 19.28291893], [84.93902588, 19.28292084], [84.93902588, 19.28264046], [84.93846893, 19.28264046], [84.93846893, 19.28236008], [84.93819427, 19.28236198], [84.93819427, 19.28208351], [84.93791962, 19.28208351], [84.93791962, 19.28180695], [84.93763733, 19.28181076], [84.93763733, 19.28153038], [84.93736267, 19.28153038], [84.93736267, 19.28125], [84.93680573, 19.28125], [84.93680573, 19.28097153], [84.93624878, 19.28097153], [84.93624878, 19.28069687], [84.93596649, 19.28070068], [84.93596649, 19.2804203], [84.93567657, 19.2804203], [84.93567657, 19.28013992], [84.93541718, 19.28013992], [84.93541718, 19.27985954], [84.93514252, 19.27986145], [84.93514252, 19.27958488], [84.93486023, 19.27958488], [84.93486023, 19.27930641], [84.93430328, 19.27931023], [84.93430328, 19.27903938], [84.93402863, 19.27903938], [84.93402863, 19.27874947], [84.93374634, 19.27874947], [84.93374634, 19.27847099], [84.93347168, 19.27847481], [84.93347168, 19.27819252], [84.93291473, 19.27819252], [84.93291473, 19.27791405], [84.93235779, 19.27791977], [84.93235779, 19.27763939], [84.93208313, 19.27763939], [84.93208313, 19.27736092], [84.93152618, 19.27736092], [84.93152618, 19.27708054], [84.93125153, 19.27708244], [84.93125153, 19.27680588], [84.93096924, 19.27680969], [84.93096924, 19.27653122], [84.93068695, 19.27653122], [84.93068695, 19.27625275], [84.93041992, 19.27625275], [84.93041992, 19.27598], [84.93013763, 19.27598], [84.93013763, 19.27569008], [84.92986298, 19.27569389], [84.92986298, 19.27541733], [84.92958069, 19.27542114], [84.92958069, 19.27458191], [84.92930603, 19.27458382], [84.92930603, 19.27430534], [84.92903137, 19.27431107], [84.92903137, 19.27403259], [84.92874908, 19.27403259], [84.92874908, 19.27375031], [84.9284668, 19.27375031], [84.9284668, 19.27347183], [84.92819214, 19.27347183], [84.92819214, 19.27319527], [84.92791748, 19.2732029], [84.92791748, 19.27290916], [84.92763519, 19.27291679], [84.92763519, 19.27263832], [84.92736053, 19.27263832], [84.92736053, 19.27235985], [84.92708588, 19.27236176], [84.92708588, 19.27208328], [84.92652893, 19.27208328], [84.92652893, 19.27180481], [84.92597198, 19.27180481], [84.92597198, 19.27152824], [84.92542267, 19.27152824], [84.92542267, 19.27124977], [84.92485809, 19.27124977], [84.92485809, 19.27096748], [84.92458344, 19.2709713], [84.92458344, 19.27069473], [84.92430878, 19.27069473], [84.92430878, 19.27041626], [84.92373657, 19.27041817], [84.92373657, 19.27013969], [84.92346954, 19.27013969], [84.92346954, 19.26984978], [84.92319489, 19.26986122], [84.92319489, 19.26958275], [84.92292023, 19.26958275], [84.92292023, 19.26930618], [84.92263794, 19.26930809], [84.92263794, 19.26875114], [84.92236328, 19.26875114], [84.92236328, 19.26847076], [84.92208099, 19.26847267], [84.92208099, 19.2681942], [84.92180634, 19.2681942], [84.92180634, 19.26791763], [84.92124939, 19.26791954], [84.92124939, 19.26764107], [84.9209671, 19.26764107], [84.9209671, 19.26708031], [84.92069244, 19.26708412], [84.92069244, 19.26647949], [84.92069244, 19.26597214], [84.92041779, 19.26597214], [84.92041779, 19.26569557], [84.91986084, 19.26569557], [84.91986084, 19.2654171], [84.91958618, 19.26542091], [84.91958618, 19.26514053], [84.91905212, 19.2651329], [84.91902924, 19.26486206], [84.91874695, 19.26486206], [84.91874695, 19.26458549], [84.91832733, 19.26458549], [84.91819763, 19.26458549], [84.91819763, 19.26430321], [84.91794586, 19.26430321], [84.91570282, 19.26431084], [84.91570282, 19.26403999], [84.9154129, 19.26403999], [84.9154129, 19.26375008], [84.91401672, 19.26375008], [84.91401672, 19.2634697], [84.91347504, 19.2634716], [84.91347504, 19.26319313], [84.91319275, 19.26320076], [84.91319275, 19.26292038], [84.91291809, 19.26292038], [84.91291809, 19.26264191], [84.9126358, 19.26264191], [84.9126358, 19.26235962], [84.91236115, 19.26236153], [84.91236115, 19.26208115], [84.91124725, 19.26208115], [84.91124725, 19.26236153], [84.91042328, 19.26235962], [84.91042328, 19.26264191], [84.9098587, 19.26264191], [84.9098587, 19.26292038], [84.9090271, 19.26292038], [84.9090271, 19.26320076], [84.90847015, 19.26319313], [84.90847015, 19.2634716], [84.90820313, 19.2634697], [84.90820313, 19.26431084], [84.90791321, 19.26430321], [84.90791321, 19.26708412], [84.90763855, 19.26708031], [84.90763855, 19.26930809], [84.90736389, 19.26930618], [84.90736389, 19.26986122], [84.90625, 19.26986122], [84.90625, 19.26958275], [84.90569305, 19.26958275], [84.90569305, 19.26930618], [84.9054184, 19.26930809], [84.9054184, 19.26847076], [84.90513611, 19.26847267], [84.90513611, 19.2681942], [84.90486145, 19.2681942], [84.90486145, 19.26791763], [84.90458679, 19.26791954], [84.90458679, 19.26708031], [84.90486145, 19.26708412], [84.90486145, 19.26680565], [84.90513611, 19.26680946], [84.90513611, 19.26653099], [84.9054184, 19.26653099], [84.9054184, 19.26625061], [84.90570068, 19.26625061], [84.90569305, 19.2634716], [84.90597534, 19.2634716], [84.90597534, 19.26319313], [84.90625, 19.26320076], [84.90625, 19.26264191], [84.90735626, 19.26264191], [84.90735626, 19.26235962], [84.90763855, 19.26236153], [84.90763855, 19.26208115], [84.9081955, 19.26208115], [84.9081955, 19.26152802], [84.90847015, 19.26153183], [84.90847015, 19.26124954], [84.90957642, 19.26124954], [84.90957642, 19.26097107], [84.91041565, 19.26097107], [84.91041565, 19.2606945], [84.91152954, 19.2606945], [84.91152954, 19.26041603], [84.91236115, 19.26042175], [84.91236877, 19.26013947], [84.9126358, 19.26013947], [84.9126358, 19.25958061], [84.91236115, 19.25958252], [84.91236115, 19.25930595], [84.91179657, 19.25931168], [84.91179657, 19.25902939], [84.91152954, 19.25902939], [84.91152954, 19.25875092], [84.91124725, 19.25875092], [84.91124725, 19.25847054], [84.9109726, 19.25847244], [84.9109726, 19.25819397], [84.91041565, 19.25819397], [84.91041565, 19.2579174], [84.91014099, 19.2579174], [84.91014099, 19.25763893], [84.9098587, 19.25764084], [84.9098587, 19.25736046], [84.90957642, 19.25736046], [84.90957642, 19.25707817], [84.90930176, 19.25708389], [84.90930176, 19.25680542], [84.9090271, 19.25681114], [84.9090271, 19.25653076], [84.90873718, 19.25653076], [84.90873718, 19.25625038], [84.90847015, 19.25625038], [84.90847015, 19.25597], [84.9081955, 19.25597191], [84.9081955, 19.25569534], [84.90791321, 19.25570107], [84.90791321, 19.25542068], [84.90763855, 19.25542068], [84.90763855, 19.2551403], [84.90735626, 19.2551403], [84.90735626, 19.25457954], [84.90680695, 19.25458336], [84.90680695, 19.25430679], [84.90652466, 19.25430679], [84.90652466, 19.25402832], [84.90625, 19.25403023], [84.90625, 19.25374985], [84.90597534, 19.25374985], [84.90597534, 19.25319672], [84.90569305, 19.25319672], [84.90569305, 19.25291443], [84.9054184, 19.25292015], [84.9054184, 19.25263977], [84.90486145, 19.25263977], [84.90486145, 19.25235939], [84.90374756, 19.2523613], [84.90374756, 19.25208473], [84.90319824, 19.25208473], [84.90319061, 19.25152779], [84.90293121, 19.25152969], [84.90293121, 19.25125122], [84.9026413, 19.25125122], [84.9026413, 19.25069046], [84.90235901, 19.25069237], [84.90235901, 19.2504158], [84.90207672, 19.25041962], [84.90207672, 19.25014114], [84.9015274, 19.25014114], [84.9015274, 19.24986076], [84.90125275, 19.24986076], [84.90125275, 19.24958038], [84.90097046, 19.24958229], [84.90097046, 19.24930573], [84.9006958, 19.24930954], [84.9006958, 19.24903107], [84.90040588, 19.24903107], [84.90040588, 19.24847031], [84.89958191, 19.24847031], [84.89958191, 19.24819374], [84.89875031, 19.24819374], [84.89875031, 19.24791718], [84.89848328, 19.2479229], [84.89848328, 19.24764252], [84.89816284, 19.24764252], [84.8979187, 19.24764252], [84.8979187, 19.24736023], [84.89783478, 19.24736023], [84.89736176, 19.24736023], [84.89736176, 19.24708176], [84.8970871, 19.24708366], [84.8970871, 19.24680519], [84.89653015, 19.24681282], [84.89653015, 19.24653244], [84.89624786, 19.24653244], [84.89624786, 19.24625015], [84.89597321, 19.24625015], [84.89597321, 19.24596977], [84.89569092, 19.24597168], [84.89569092, 19.24569511], [84.89541626, 19.24570084], [84.89541626, 19.24541855], [84.8951416, 19.24541855], [84.8951416, 19.24513817], [84.89457703, 19.24513817], [84.89457703, 19.24458122], [84.89430237, 19.24458313], [84.89430237, 19.24430466], [84.89402771, 19.24430466], [84.89402771, 19.24402809], [84.89376068, 19.24402809], [84.89376068, 19.24377251], [84.89347076, 19.24374962], [84.89342499, 19.24352837], [84.89335632, 19.24347305], [84.89319611, 19.24347305], [84.89319611, 19.24332047], [84.89319611, 19.24319458], [84.89305115, 19.24319458], [84.89263916, 19.24319458], [84.89263916, 19.24291611], [84.89208221, 19.24291611], [84.89208221, 19.24263954], [84.89180756, 19.24263954], [84.89180756, 19.24236107], [84.89152527, 19.24236107], [84.89152527, 19.2420826], [84.89125061, 19.2420826], [84.89125061, 19.24180794], [84.89070129, 19.24180984], [84.89070129, 19.24152946], [84.89041901, 19.24152946], [84.89041901, 19.24097061], [84.89013672, 19.24097252], [84.89013672, 19.24069595], [84.88986206, 19.24069595], [84.88986206, 19.24041748], [84.88957977, 19.24041939], [84.88954926, 19.24014091], [84.88903046, 19.24014091], [84.88903046, 19.23987007], [84.88874817, 19.23987007], [84.88874817, 19.23958015], [84.88847351, 19.23958588], [84.88847351, 19.23930359], [84.88819122, 19.23931122], [84.88819122, 19.23903084], [84.88791656, 19.23903084], [84.88791656, 19.23875046], [84.88762665, 19.23875046], [84.88762665, 19.23847961], [84.88709259, 19.23847008], [84.88708496, 19.23819542], [84.88680267, 19.2381897], [84.88680267, 19.23791695], [84.88625336, 19.23792076], [84.88625336, 19.23764038], [84.88597107, 19.23764038], [84.88597107, 19.23736], [84.88569641, 19.23736382], [84.88569641, 19.23708153], [84.88541412, 19.23708153], [84.88541412, 19.23680305], [84.88513947, 19.23681068], [84.88513947, 19.2365303], [84.88485718, 19.2365303], [84.88485718, 19.23624992], [84.88456726, 19.23624992], [84.88458252, 19.23583031], [84.88458252, 19.23569489], [84.8844223, 19.23569489], [84.88430786, 19.23569489], [84.88430786, 19.23541641], [84.88402557, 19.23541641], [84.88402557, 19.23533058], [84.88402557, 19.23513985], [84.88375092, 19.23513985], [84.88375092, 19.23485947], [84.88346863, 19.23486137], [84.88346863, 19.2345829], [84.88319397, 19.2345829], [84.88319397, 19.23430634], [84.88291931, 19.23431015], [84.88291931, 19.23373985], [84.88263702, 19.23374939], [84.88263702, 19.23347282], [84.88208008, 19.23347282], [84.88208008, 19.23319435], [84.88192749, 19.23319435], [84.88180542, 19.23319435], [84.88180542, 19.23291588], [84.88172913, 19.23291588], [84.88153076, 19.2329216], [84.88153076, 19.23263931], [84.88124847, 19.23263931], [84.88124847, 19.2322197], [84.88124847, 19.23208427], [84.88041687, 19.23208427], [84.88041687, 19.23152733], [84.88014221, 19.23152924], [84.88014221, 19.23125076], [84.87985992, 19.23125076], [84.87985992, 19.23097038], [84.87958527, 19.23097229], [84.87958527, 19.23069382], [84.87902832, 19.23069382], [84.87902832, 19.23041725], [84.87876129, 19.23041916], [84.87876129, 19.23014069], [84.87847137, 19.23014069], [84.87847137, 19.22957993], [84.87791443, 19.22958374], [84.87791443, 19.2290287], [84.87763977, 19.22903061], [84.87763977, 19.22875023], [84.87708282, 19.22875023], [84.87708282, 19.22846985], [84.87680817, 19.22847176], [84.87680817, 19.22819519], [84.87652588, 19.22820091], [84.87652588, 19.22792816], [84.87625122, 19.22792816], [84.87625122, 19.22764015], [84.87596893, 19.22764015], [84.87596893, 19.22707939], [84.87569427, 19.22708321], [84.87569427, 19.22680664], [84.87513733, 19.22680664], [84.87513733, 19.22652817], [84.87458038, 19.22653008], [84.87458038, 19.22597122], [84.87430573, 19.22597313], [84.87430573, 19.22569656], [84.87403107, 19.22569656], [84.87403107, 19.22541428], [84.87346649, 19.22542], [84.87346649, 19.22513962], [84.87291718, 19.22513962], [84.87291718, 19.22487068], [84.87262726, 19.22487068], [84.87262726, 19.22430992], [84.87236023, 19.22430992], [84.87236023, 19.22402954], [84.8720932, 19.22402954], [84.8720932, 19.22375107], [84.87152863, 19.22375107], [84.87152863, 19.22319031], [84.87124634, 19.22319221], [84.87124634, 19.22291756], [84.87097168, 19.22291946], [84.87097168, 19.2226429], [84.87069702, 19.2226429], [84.87069702, 19.22236061], [84.8704071, 19.22236061], [84.8704071, 19.22208023], [84.87014008, 19.22208214], [84.87014008, 19.22180557], [84.86985779, 19.22180557], [84.86985779, 19.2215271], [84.86902618, 19.22153282], [84.86902618, 19.22125053], [84.86875153, 19.22125053], [84.86875153, 19.22097015], [84.86846924, 19.22097015], [84.86846924, 19.22069359], [84.86791992, 19.22069359], [84.86791992, 19.22041702], [84.86763763, 19.22042274], [84.86763763, 19.22014046], [84.86736298, 19.22014046], [84.86736298, 19.2195816], [84.86680603, 19.21958351], [84.86680603, 19.21902847], [84.86653137, 19.21902847], [84.86653137, 19.21874046], [84.86624908, 19.21874809], [84.86624908, 19.21847153], [84.86597443, 19.21847153], [84.86597443, 19.21819496], [84.86569214, 19.21820068], [84.86569214, 19.2179184], [84.86541748, 19.2179184], [84.86541748, 19.21763992], [84.86514282, 19.21763992], [84.86514282, 19.21708107], [84.86486053, 19.21708298], [84.86486053, 19.21652985], [84.86458588, 19.21652985], [84.86458588, 19.21624947], [84.86429596, 19.21624947], [84.86429596, 19.21597099], [84.86402893, 19.2159729], [84.86402893, 19.21569443], [84.86374664, 19.21569824], [84.86374664, 19.21541977], [84.86347198, 19.21541977], [84.86347198, 19.21513939], [84.86319733, 19.21513939], [84.86319733, 19.21486092], [84.86291504, 19.21486092], [84.86291504, 19.21430779], [84.86264038, 19.21430969], [84.86264038, 19.21403122], [84.86207581, 19.21403122], [84.86207581, 19.21375084], [84.86152649, 19.21375084], [84.86152649, 19.21347046], [84.86125183, 19.21347237], [84.86125183, 19.2131958], [84.86096954, 19.2131958], [84.86096954, 19.21291733], [84.86068726, 19.21293068], [84.86068726, 19.21264076], [84.86042023, 19.21264076], [84.86042023, 19.21236038], [84.86013794, 19.21236038], [84.86013794, 19.21208], [84.85986328, 19.21208572], [84.85986328, 19.21180344], [84.85930634, 19.21181107], [84.85930634, 19.21153069], [84.85901642, 19.21153069], [84.85901642, 19.21125031], [84.85874939, 19.21125031], [84.85874939, 19.21070099], [84.8584671, 19.21070099], [84.8584671, 19.21042061], [84.85819244, 19.21042061], [84.85819244, 19.20985985], [84.85791779, 19.20986366], [84.85791779, 19.20958138], [84.8576355, 19.20958138], [84.8576355, 19.20930481], [84.85708618, 19.20930481], [84.85708618, 19.20874977], [84.85679626, 19.20874977], [84.85679626, 19.20846939], [84.85652924, 19.2084713], [84.85652924, 19.20819473], [84.85624695, 19.20819473], [84.85624695, 19.20791626], [84.85597229, 19.20792007], [84.85597229, 19.20763969], [84.85569763, 19.20763969], [84.85569763, 19.20735931], [84.85541534, 19.20735931], [84.85541534, 19.20708275], [84.85514069, 19.20708275], [84.85514069, 19.20680618], [84.8548584, 19.20680618], [84.8548584, 19.20652771], [84.85459137, 19.20652962], [84.85459137, 19.20624924], [84.85430908, 19.20624924], [84.85430908, 19.20597076], [84.85375214, 19.20597267], [84.85375214, 19.2056942], [84.85346985, 19.2056942], [84.85346985, 19.20541763], [84.85320282, 19.20542145], [84.85320282, 19.20513916], [84.8529129, 19.20513916], [84.8529129, 19.20486069], [84.85263824, 19.20486069], [84.85263824, 19.20458031], [84.85236359, 19.20458412], [84.85236359, 19.20402718], [84.8520813, 19.20402908], [84.8520813, 19.20375824], [84.85153198, 19.20375824], [84.85153198, 19.20318985], [84.85124969, 19.20319366], [84.85124969, 19.2029171], [84.85098267, 19.20292091], [84.85098267, 19.20264053], [84.85069275, 19.20264053], [84.85069275, 19.20207977], [84.85041809, 19.20208359], [84.85041809, 19.20180511], [84.84958649, 19.20181084], [84.84958649, 19.20153046], [84.84929657, 19.20153046], [84.84929657, 19.20125008], [84.84902954, 19.20125008], [84.84902954, 19.2009697], [84.84874725, 19.2009716], [84.84874725, 19.20069695], [84.84845734, 19.20070076], [84.84845734, 19.20042038], [84.84819794, 19.20042038], [84.84819794, 19.19985962], [84.84791565, 19.19986153], [84.84791565, 19.19958305], [84.84764099, 19.19958305], [84.84764099, 19.19930649], [84.8473587, 19.1993103], [84.8473587, 19.19902992], [84.84707642, 19.19902992], [84.84707642, 19.19847107], [84.84680176, 19.19847488], [84.84680176, 19.1981926], [84.8465271, 19.1981926], [84.8465271, 19.19763947], [84.84625244, 19.19763947], [84.84625244, 19.1973629], [84.84617615, 19.1973629], [84.84597015, 19.1973629], [84.84597015, 19.19715118], [84.84541321, 19.19708252], [84.84541321, 19.19680405], [84.84485626, 19.19680977], [84.84485626, 19.19652939], [84.8445816, 19.19652939], [84.8445816, 19.19625282], [84.84430695, 19.19625282], [84.84430695, 19.19569016], [84.84402466, 19.19569206], [84.84402466, 19.19513893], [84.84348297, 19.19514275], [84.84346771, 19.19458961], [84.8429184, 19.19457054], [84.8429184, 19.19430542], [84.84265137, 19.19431114], [84.84265137, 19.19403267], [84.84236145, 19.19403267], [84.84236145, 19.19375038], [84.84208679, 19.19375038], [84.84208679, 19.19347191], [84.8418045, 19.19347191], [84.8418045, 19.19319534], [84.84152985, 19.19320107], [84.84152985, 19.19235992], [84.84124756, 19.19236183], [84.84124756, 19.19192123], [84.84124756, 19.19180489], [84.8409729, 19.19180489], [84.8409729, 19.19152832], [84.84069824, 19.19152832], [84.84066772, 19.19125938], [84.8401413, 19.19124985], [84.8401413, 19.19096947], [84.83985901, 19.19097137], [84.83985901, 19.19069481], [84.83958435, 19.19069481], [84.83958435, 19.19041634], [84.83930206, 19.19041824], [84.83930206, 19.19013977], [84.8390274, 19.19013977], [84.8390274, 19.18985939], [84.83875275, 19.1898613], [84.83875275, 19.18958282], [84.83847046, 19.18958282], [84.83847046, 19.18902779], [84.8381958, 19.18902969], [84.8381958, 19.18876076], [84.83790588, 19.18876076], [84.83791351, 19.18836021], [84.83791351, 19.18819427], [84.8377533, 19.18819427], [84.83763885, 19.18819427], [84.83763885, 19.18806839], [84.83763885, 19.18763924], [84.83735657, 19.18764114], [84.83735657, 19.18708038], [84.83708191, 19.1870842], [84.83708191, 19.18652725], [84.83680725, 19.18653107], [84.83680725, 19.18625069], [84.83651733, 19.18625069], [84.83651733, 19.18597031], [84.83569336, 19.18597221], [84.83569336, 19.18569565], [84.83538055, 19.18569565], [84.83513641, 19.18569565], [84.83513641, 19.18543053], [84.83513641, 19.18486023], [84.83486176, 19.18486023], [84.83486176, 19.18457985], [84.8345871, 19.18458557], [84.8345871, 19.18430328], [84.83429718, 19.18431091], [84.83429718, 19.18375015], [84.83403015, 19.18375015], [84.83403015, 19.18320084], [84.83374786, 19.18320084], [84.83374786, 19.18292046], [84.83345795, 19.18292046], [84.83345795, 19.18263054], [84.83319092, 19.18263817], [84.83319092, 19.18236351], [84.83291626, 19.18236351], [84.83291626, 19.18208122], [84.8326416, 19.18208122], [84.8326416, 19.18180466], [84.83208466, 19.18180466], [84.83208466, 19.18152809], [84.83180237, 19.18153191], [84.83180237, 19.18124962], [84.83152771, 19.18124962], [84.83152771, 19.18069077], [84.83125305, 19.18069458], [84.83125305, 19.18041611], [84.83097076, 19.18042183], [84.83097076, 19.18013954], [84.83069611, 19.18013954], [84.83069611, 19.18000984], [84.83069611, 19.17985916], [84.83041382, 19.17985916], [84.83041382, 19.1795826], [84.83013916, 19.17959023], [84.83013916, 19.17931175], [84.82985687, 19.17931175], [84.82985687, 19.17902946], [84.82958221, 19.17902946], [84.82958221, 19.17874908], [84.82930756, 19.17874908], [84.82930756, 19.17847061], [84.82902527, 19.17847252], [84.82902527, 19.17791748], [84.82875061, 19.1779213], [84.82875061, 19.17708015], [84.82819366, 19.17708397], [84.82819366, 19.17652893], [84.82791901, 19.17653084], [84.82791138, 19.17625809], [84.82736206, 19.17625046], [84.82736206, 19.17597008], [84.82653046, 19.17597198], [84.82653046, 19.17541885], [84.82624817, 19.17542076], [84.82624817, 19.17515945], [84.82596588, 19.17514038], [84.82595825, 19.17487907], [84.82569122, 19.17486], [84.82569122, 19.17458344], [84.82541656, 19.17458344], [84.82541656, 19.17427254], [84.82541656, 19.1740284], [84.82521057, 19.1740303], [84.82514191, 19.17374992], [84.82496643, 19.17374992], [84.82457733, 19.17374992], [84.82457733, 19.17346954], [84.82375336, 19.17347145], [84.82375336, 19.17291641], [84.82347107, 19.17292023], [84.82347107, 19.17235947], [84.82319641, 19.17236137], [84.82319641, 19.17180634], [84.82290649, 19.17181015], [84.82290649, 19.17152977], [84.82263947, 19.17152977], [84.82260895, 19.17098045], [84.82236481, 19.17097473], [84.82236481, 19.17069244], [84.82180786, 19.17069244], [84.82180786, 19.17041588], [84.82151794, 19.17041969], [84.82151794, 19.17014122], [84.82125092, 19.17014122], [84.82125092, 19.16986084], [84.82096863, 19.16986084], [84.82096863, 19.16958046], [84.82069397, 19.16958237], [84.82069397, 19.16902733], [84.82041931, 19.16903114], [84.82041931, 19.16847038], [84.82013702, 19.16847038], [84.82013702, 19.16819382], [84.81986237, 19.16819382], [84.81986237, 19.1678009], [84.81986237, 19.16763878], [84.81973267, 19.16763878], [84.81958008, 19.16765022], [84.81958008, 19.16747093], [84.81958008, 19.16708374], [84.81930542, 19.16708374], [84.81930542, 19.16680527], [84.81903076, 19.1668129], [84.81903076, 19.16653252], [84.81874847, 19.16651917], [84.81874847, 19.16597176], [84.81847382, 19.16597176], [84.81847382, 19.16569519], [84.81819153, 19.16570091], [84.81819153, 19.16513824], [84.81791687, 19.16513824], [84.81791687, 19.16459084], [84.81764221, 19.16459084], [84.81764221, 19.16430092], [84.81735992, 19.16430473], [84.81735992, 19.16374969], [84.81708527, 19.16374969], [84.81708527, 19.16347313], [84.81680298, 19.16347313], [84.81680298, 19.16319466], [84.81652832, 19.16319466], [84.81652832, 19.16291618], [84.81614685, 19.16291618], [84.81597137, 19.16291809], [84.81597137, 19.16264915], [84.81569672, 19.16263962], [84.81569672, 19.16236115], [84.81541443, 19.16236115], [84.81541443, 19.16208267], [84.81513977, 19.16208267], [84.81513977, 19.16152763], [84.81485748, 19.16152954], [84.81485748, 19.16125107], [84.81458282, 19.16125107], [84.81458282, 19.16097069], [84.81430817, 19.1609726], [84.81430817, 19.16041756], [84.81402588, 19.16041946], [84.81402588, 19.16014099], [84.81375122, 19.16014099], [84.81375122, 19.15986061], [84.81346893, 19.15986061], [84.81346893, 19.15930939], [84.81291962, 19.15930939], [84.81291962, 19.15875053], [84.81263733, 19.15875053], [84.81263733, 19.15846062], [84.81236267, 19.15847206], [84.81236267, 19.1581955], [84.81208038, 19.1581955], [84.81208038, 19.15763855], [84.81181335, 19.15764046], [84.81181335, 19.15736008], [84.81124878, 19.15736389], [84.81124878, 19.15708542], [84.81097412, 19.15708542], [84.81097412, 19.15680313], [84.81069183, 19.15681076], [84.81069183, 19.15653038], [84.81041718, 19.15653038], [84.81041718, 19.15625], [84.81014252, 19.15625], [84.81014252, 19.15596962], [84.80986023, 19.15597153], [84.80986023, 19.15569305], [84.80957794, 19.15571022], [84.80957794, 19.1554203], [84.80928802, 19.1554203], [84.80928802, 19.15514183], [84.80902863, 19.15514183], [84.80902863, 19.15485954], [84.80874634, 19.15486145], [84.80874634, 19.15402794], [84.80847168, 19.15403175], [84.80847168, 19.15236092], [84.80819702, 19.15236092], [84.80819702, 19.15152931], [84.8079071, 19.15152931], [84.80791473, 19.15117836], [84.80791473, 19.15097237], [84.80764008, 19.15097237], [84.80764008, 19.15041733], [84.80735779, 19.15041924], [84.80735779, 19.15014076], [84.80696106, 19.15014076], [84.80680847, 19.15014076], [84.80680847, 19.14997101], [84.80680847, 19.14958382], [84.80654144, 19.14958954], [84.80654144, 19.14931107], [84.80619812, 19.14931107], [84.80596924, 19.14931107], [84.80596161, 19.14903831], [84.80568695, 19.14903069], [84.80568695, 19.14875031], [84.80541992, 19.14875031], [84.80541992, 19.14845085], [84.80541992, 19.14819527], [84.80516052, 19.14820099], [84.80513763, 19.14792061], [84.80486298, 19.14791679], [84.80486298, 19.14782715], [84.80486298, 19.14652824], [84.80458069, 19.14652824], [84.80458069, 19.14569664], [84.80430603, 19.14569664], [84.80430603, 19.14513969], [84.80403137, 19.14513969], [84.80403137, 19.14486122], [84.80374908, 19.14486122], [84.80374908, 19.14458084], [84.80319214, 19.14458466], [84.80319214, 19.14402771], [84.80291748, 19.14402962], [84.80291748, 19.14346123], [84.80263519, 19.14347458], [84.80263519, 19.14291763], [84.80236053, 19.14291954], [84.80236053, 19.14208031], [84.80208588, 19.14208221], [84.80208588, 19.14152718], [84.80179596, 19.1415329], [84.80179596, 19.14097023], [84.80152893, 19.14097023], [84.80152893, 19.1404171], [84.80124664, 19.14042282], [84.80124664, 19.14014244], [84.80097198, 19.14014244], [84.80097198, 19.13958168], [84.80069733, 19.13958359], [84.80069733, 19.13930511], [84.80040741, 19.13931274], [84.80040741, 19.13874817], [84.79985809, 19.13874817], [84.79985809, 19.1384697], [84.79958344, 19.1384716], [84.79958344, 19.13763809], [84.79930878, 19.13763809], [84.79930878, 19.1368084], [84.79902649, 19.1368084], [84.79902649, 19.13624954], [84.79875183, 19.13624954], [84.79875183, 19.13569069], [84.79846954, 19.1356945], [84.79846954, 19.13513947], [84.79792023, 19.13513947], [84.79792023, 19.13375092], [84.79763794, 19.13375092], [84.79763794, 19.13347054], [84.79736328, 19.13347244], [84.79736328, 19.13319588], [84.79708099, 19.13319588], [84.79708099, 19.13125038], [84.79680634, 19.13125038], [84.79680634, 19.13042068], [84.79651642, 19.13042068], [84.79651642, 19.12930107], [84.79624939, 19.12930489], [84.79624939, 19.12874985], [84.7959671, 19.12874985], [84.7959671, 19.12848091], [84.79569244, 19.12848091], [84.79569244, 19.1281929], [84.7951355, 19.12819481], [84.7951355, 19.12791634], [84.79486084, 19.12792015], [84.79486084, 19.12763977], [84.79402924, 19.12763977], [84.79402924, 19.12708092], [84.79374695, 19.12708282], [84.79374695, 19.12680626], [84.79319763, 19.12681007], [84.79319763, 19.1265316], [84.79264069, 19.1265316], [84.79264069, 19.12624931], [84.79207611, 19.12624931], [84.79207611, 19.12597084], [84.79180908, 19.12597275], [84.79180908, 19.12569427], [84.79152679, 19.12569427], [84.79152679, 19.1254158], [84.79103851, 19.12542152], [84.79099274, 19.12524414], [84.79096985, 19.12513924], [84.78985596, 19.12513924], [84.78985596, 19.12458038], [84.7895813, 19.1245842], [84.7895813, 19.12402725], [84.78930664, 19.12402916], [84.78930664, 19.12375069], [84.78901672, 19.12375069], [84.78901672, 19.12318993], [84.78874969, 19.12319374], [84.78874969, 19.12291718], [84.78846741, 19.12291908], [84.78846741, 19.12264061], [84.78817749, 19.12264061], [84.78817749, 19.12207985], [84.78791809, 19.12208366], [84.78791809, 19.12180519], [84.7876358, 19.12181091], [84.7876358, 19.12153053], [84.78708649, 19.12153053], [84.78708649, 19.12125015], [84.78624725, 19.12125015], [84.78624725, 19.12096977], [84.7859726, 19.12097168], [84.7859726, 19.12069511], [84.78569794, 19.12070084], [84.78569794, 19.12042046], [84.78540802, 19.12042046], [84.78540802, 19.12014008], [84.78514099, 19.12014008], [84.78514099, 19.1198597], [84.7848587, 19.1198616], [84.7848587, 19.11930656], [84.78458405, 19.11930656], [84.78458405, 19.11902809], [84.78430176, 19.11903], [84.78430176, 19.11874962], [84.7840271, 19.11874962], [84.7840271, 19.11819077], [84.78375244, 19.11819267], [84.78375244, 19.1179142], [84.78347015, 19.11791992], [84.78347015, 19.11736107], [84.7831955, 19.11736107], [84.7831955, 19.1170845], [84.78291321, 19.1170845], [84.78291321, 19.11680412], [84.78263855, 19.11680984], [84.78263855, 19.1162529], [84.78237152, 19.1162529], [84.78237152, 19.11597061], [84.7820816, 19.11597443], [84.7820816, 19.11541748], [84.78291321, 19.11541939], [84.78291321, 19.11514282], [84.78320313, 19.11514282], [84.78320313, 19.11403275], [84.78291321, 19.11403275], [84.78291321, 19.11375046], [84.78263855, 19.11375046], [84.78263855, 19.11347961], [84.78237152, 19.11347961], [84.78237152, 19.11320114], [84.7804184, 19.1131916], [84.7804184, 19.11291695], [84.78013611, 19.11292267], [84.78013611, 19.11235809], [84.77986145, 19.11236191], [84.77986145, 19.11208344], [84.77958679, 19.11208344], [84.77958679, 19.11180496], [84.77931213, 19.11181068], [84.77931213, 19.1115284], [84.77874756, 19.1115284], [84.77874756, 19.11124992], [84.7784729, 19.11124992], [84.7784729, 19.11069107], [84.77819824, 19.11069489], [84.77819061, 19.11041641], [84.77791595, 19.11041641], [84.77791595, 19.11013985], [84.77735901, 19.11013985], [84.77735901, 19.10985947], [84.7765274, 19.10986137], [84.7765274, 19.1095829], [84.77597046, 19.1095829], [84.77597046, 19.10986137], [84.77541351, 19.10986137], [84.77541351, 19.1095829], [84.77402496, 19.1095829], [84.77402496, 19.10986137], [84.77375031, 19.10986137], [84.77375031, 19.1095829], [84.77263641, 19.1095829], [84.77263641, 19.10930634], [84.76930237, 19.10930634], [84.76930237, 19.1095829], [84.76902771, 19.1095829], [84.76902771, 19.10930634], [84.76819611, 19.10930634], [84.76819611, 19.1095829], [84.76763916, 19.1095829], [84.76763916, 19.10986137], [84.76737213, 19.10985947], [84.76737213, 19.11013985], [84.76708221, 19.11013985], [84.76708221, 19.10985947], [84.76680756, 19.10985947], [84.76680756, 19.11013985], [84.76569366, 19.11013985], [84.76569366, 19.11041641], [84.76541901, 19.11041641], [84.76541901, 19.11069489], [84.76457977, 19.11069107], [84.76457977, 19.1115284], [84.76264191, 19.1115284], [84.76264191, 19.11181068], [84.76208496, 19.11180496], [84.76208496, 19.11208344], [84.76180267, 19.11208344], [84.76180267, 19.11236191], [84.76152802, 19.11235809], [84.76152802, 19.11264038], [84.76097107, 19.11264038], [84.76097107, 19.11292267], [84.76069641, 19.11291695], [84.76069641, 19.1131916], [84.75985718, 19.11320114], [84.75985718, 19.11347961], [84.75930786, 19.11347961], [84.75930786, 19.11375046], [84.75902557, 19.11375046], [84.75902557, 19.11347008], [84.75875092, 19.11347961], [84.75875092, 19.11320114], [84.7582016, 19.11320114], [84.7582016, 19.11347961], [84.75763702, 19.11347961], [84.75763702, 19.11375046], [84.75736237, 19.11375046], [84.75736237, 19.11403275], [84.75763702, 19.11403275], [84.75763702, 19.11486053], [84.75736237, 19.11486053], [84.75736237, 19.11514282], [84.75708008, 19.11514282], [84.75708008, 19.11541939], [84.75653076, 19.11541939], [84.75653076, 19.11514282], [84.75596619, 19.11514282], [84.75596619, 19.11486053], [84.75569153, 19.11486053], [84.75569153, 19.11458015], [84.75541687, 19.11458206], [84.75541687, 19.1143055], [84.75569153, 19.11431122], [84.75569153, 19.11375046], [84.75596619, 19.11375046], [84.75596619, 19.11264038], [84.75569153, 19.11264038], [84.75569153, 19.11207962], [84.75541687, 19.11208344], [84.75541687, 19.11180496], [84.75485992, 19.11181068], [84.75485992, 19.11124992], [84.75430298, 19.11124992], [84.75430298, 19.1115284], [84.75374603, 19.1115284], [84.75374603, 19.11124992], [84.75347137, 19.11124992], [84.75347137, 19.1115284], [84.75319672, 19.1115284], [84.75319672, 19.11292267], [84.75430298, 19.11292267], [84.75430298, 19.11375046], [84.75402832, 19.11375046], [84.75402832, 19.11431122], [84.75347137, 19.1143055], [84.75347137, 19.11458206], [84.7529068, 19.11458015], [84.7529068, 19.11514282], [84.75263977, 19.11513901], [84.75263977, 19.11569214], [84.75208282, 19.11569214], [84.75208282, 19.11597443], [84.75096893, 19.11597061], [84.75096893, 19.1162529], [84.74986267, 19.1162529], [84.74986267, 19.11654091], [84.74958038, 19.11654091], [84.74958038, 19.11680984], [84.74930573, 19.11680412], [84.74930573, 19.1170845], [84.74764252, 19.11708069], [84.74764252, 19.11736107], [84.74708557, 19.11736107], [84.7470932, 19.11763954], [84.74569702, 19.11763954], [84.74569702, 19.11736107], [84.7454071, 19.11736107], [84.7454071, 19.11708069], [84.74514008, 19.1170845], [84.74514008, 19.11680412], [84.74485779, 19.11680984], [84.74485779, 19.11654091], [84.74430847, 19.11654091], [84.74430847, 19.1162529], [84.74402618, 19.1162529], [84.74402618, 19.11597061], [84.74375153, 19.11597443], [84.74375153, 19.11569214], [84.74346924, 19.11569214], [84.74346924, 19.11541748], [84.74291992, 19.11541939], [84.74291992, 19.11514282], [84.74263763, 19.11514282], [84.74263763, 19.11486053], [84.74208069, 19.11486053], [84.74208069, 19.11458015], [84.74124908, 19.11458206], [84.74124908, 19.1143055], [84.7409668, 19.11431122], [84.7409668, 19.11403275], [84.74069214, 19.11403275], [84.74069214, 19.11375046], [84.74041748, 19.11375046], [84.74041748, 19.11320114], [84.74014282, 19.1131916], [84.74013519, 19.11291695], [84.73986053, 19.11292267], [84.73986053, 19.11264038], [84.73958588, 19.11264038], [84.73958588, 19.11235809], [84.73847198, 19.11236191], [84.73847198, 19.11180496], [84.73819733, 19.11181068], [84.73819733, 19.11096954], [84.73791504, 19.11097145], [84.73791504, 19.11069489], [84.73708344, 19.11069489], [84.73708344, 19.11041641], [84.73680878, 19.11041641], [84.73680878, 19.11013985], [84.73652649, 19.11013985], [84.73652649, 19.10930824], [84.73625183, 19.10930824], [84.73625183, 19.10874939], [84.73652649, 19.10874939], [84.73652649, 19.1073494], [84.73625183, 19.10736084], [84.73625183, 19.10680771], [84.73596954, 19.10680962], [84.73596954, 19.10653114], [84.73568726, 19.10653114], [84.73568726, 19.10625076], [84.73542023, 19.10625076], [84.73542023, 19.10597038], [84.73513794, 19.10597229], [84.73513794, 19.10569572], [84.73486328, 19.10569572], [84.73486328, 19.10347366], [84.73458099, 19.10347366], [84.73458099, 19.10319328], [84.73486328, 19.10320091], [84.73486328, 19.10235977], [84.73513794, 19.10236359], [84.73513794, 19.10124969], [84.73486328, 19.10124969], [84.73486328, 19.10097122], [84.73458099, 19.10097122], [84.73458099, 19.10069466], [84.73374939, 19.10069466], [84.73374939, 19.10013962], [84.7334671, 19.10013962], [84.7334671, 19.09985924], [84.73319244, 19.09985924], [84.73319244, 19.09958076], [84.73291779, 19.09958267], [84.73291779, 19.09902763], [84.73264313, 19.09903145], [84.73264313, 19.09818077], [84.73236084, 19.09819412], [84.73236084, 19.09791756], [84.73208618, 19.09792137], [84.73208618, 19.09763908], [84.73152924, 19.09763908], [84.73152924, 19.09736061], [84.73124695, 19.09736061], [84.73124695, 19.09708405], [84.73097229, 19.09708405], [84.73097229, 19.09680557], [84.73042297, 19.09680748], [84.73042297, 19.09653091], [84.72875214, 19.09653091], [84.72875214, 19.09625053], [84.72846985, 19.09625053], [84.72846985, 19.09597015], [84.7279129, 19.09597206], [84.7279129, 19.09569359], [84.72736359, 19.09569359], [84.72736359, 19.09597206], [84.72680664, 19.09597015], [84.72680664, 19.09625053], [84.72624969, 19.09625053], [84.72624969, 19.09653091], [84.72541809, 19.09653091], [84.72541809, 19.09736061], [84.72512817, 19.09736061], [84.72512817, 19.09792137], [84.72569275, 19.09791756], [84.72569275, 19.0984726], [84.72597504, 19.0984726], [84.72598267, 19.10013962], [84.72569275, 19.10013962], [84.72569275, 19.10264015], [84.72598267, 19.10264015], [84.72598267, 19.10320091], [84.72624969, 19.10320091], [84.72624969, 19.10375023], [84.72651672, 19.10375023], [84.72651672, 19.10403061], [84.72680664, 19.10403061], [84.72680664, 19.10431099], [84.7270813, 19.10430336], [84.7270813, 19.10458565], [84.72763824, 19.10457993], [84.72763824, 19.10486031], [84.7279129, 19.10486031], [84.7279129, 19.10542107], [84.72819519, 19.10541725], [84.72819519, 19.10569572], [84.72930908, 19.10569], [84.72930908, 19.10653114], [84.72958374, 19.10652733], [84.72958374, 19.10708237], [84.7298584, 19.10708427], [84.7298584, 19.10736084], [84.73014069, 19.1073494], [84.73014069, 19.10764122], [84.73042297, 19.10764122], [84.73042297, 19.10791969], [84.73069763, 19.10791779], [84.73069763, 19.10819435], [84.73097229, 19.10819435], [84.73097229, 19.10847282], [84.73152924, 19.10847092], [84.73152924, 19.10930824], [84.73180389, 19.10930634], [84.73180389, 19.1095829], [84.73208618, 19.10958099], [84.73208618, 19.11013985], [84.73236084, 19.11013985], [84.73236084, 19.11041641], [84.7326355, 19.11041641], [84.7326355, 19.11097145], [84.73291779, 19.11096954], [84.73291779, 19.11181068], [84.73264313, 19.11181068], [84.73264313, 19.11264038], [84.73291779, 19.11264038], [84.73291779, 19.11292267], [84.73400879, 19.11292267], [84.73400879, 19.11264038], [84.73432159, 19.11264038], [84.73432159, 19.11235809], [84.73458099, 19.11236191], [84.73458099, 19.11208344], [84.73513794, 19.11208344], [84.73513794, 19.11180496], [84.73542023, 19.11181068], [84.73542023, 19.1115284], [84.73568726, 19.1115284], [84.73568726, 19.11096954], [84.73652649, 19.11097145], [84.73652649, 19.11208344], [84.73708344, 19.11208344], [84.73708344, 19.11236191], [84.73792267, 19.11235809], [84.73792267, 19.11264038], [84.73819733, 19.11263847], [84.73819733, 19.1131916], [84.73706818, 19.11320114], [84.73706818, 19.11347961], [84.73680878, 19.11347008], [84.73680878, 19.11458206], [84.73652649, 19.11458206], [84.73652649, 19.1143055], [84.73625183, 19.11431122], [84.73625183, 19.11403275], [84.73596954, 19.11402702], [84.73596954, 19.11569214], [84.73568726, 19.11569023], [84.73568726, 19.1162529], [84.73542023, 19.1162529], [84.73542023, 19.11654091], [84.73513794, 19.11654091], [84.73513794, 19.11680984], [84.73486328, 19.11680984], [84.73486328, 19.11736107], [84.73513794, 19.11736107], [84.73513794, 19.11791992], [84.73542023, 19.11791992], [84.73542023, 19.11763954], [84.73596954, 19.11763954], [84.73596954, 19.11791992], [84.73625183, 19.1179142], [84.73625183, 19.11958313], [84.73596954, 19.11958313], [84.73596954, 19.1198616], [84.73568726, 19.1198597], [84.73568726, 19.12014008], [84.73486328, 19.12014008], [84.73486328, 19.12042046], [84.73432159, 19.12042046], [84.73432159, 19.12014008], [84.73374939, 19.12014008], [84.73374939, 19.12070084], [84.73347473, 19.12069511], [84.73347473, 19.12208366], [84.73374939, 19.12208366], [84.73374939, 19.12236023], [84.73542023, 19.12236023], [84.73542023, 19.12208366], [84.73569489, 19.12208366], [84.73569489, 19.12180519], [84.73708344, 19.12180519], [84.73708344, 19.12208366], [84.73735809, 19.12207985], [84.73735809, 19.12291908], [84.73708344, 19.12291718], [84.73708344, 19.12319374], [84.73680878, 19.12319374], [84.73680878, 19.12347221], [84.73596954, 19.12347031], [84.73596954, 19.12375069], [84.73568726, 19.12375069], [84.73568726, 19.12402916], [84.73542023, 19.12402916], [84.73542023, 19.12486076], [84.73596954, 19.12486076], [84.73596954, 19.12458038], [84.73847198, 19.1245842], [84.73847198, 19.12402725], [84.73874664, 19.12402916], [84.73874664, 19.12375069], [84.73929596, 19.12375069], [84.73929596, 19.12347031], [84.74013519, 19.12347221], [84.74013519, 19.12319374], [84.74097443, 19.12319374], [84.74097443, 19.12291718], [84.74153137, 19.12291908], [84.74153137, 19.12264061], [84.74180603, 19.12264061], [84.74180603, 19.12235069], [84.74236298, 19.12235069], [84.74236298, 19.12264061], [84.74346924, 19.12264061], [84.74346924, 19.12235069], [84.74375153, 19.12236023], [84.74375153, 19.12208366], [84.74402618, 19.12208366], [84.74402618, 19.12152863], [84.74458313, 19.12153053], [84.74458313, 19.12096977], [84.74541473, 19.12097168], [84.74541473, 19.12069511], [84.74569702, 19.12069511], [84.74569702, 19.12097168], [84.74597168, 19.12096977], [84.74597168, 19.12125015], [84.7462616, 19.12125015], [84.7462616, 19.12153053], [84.74652863, 19.12152863], [84.74652863, 19.12319374], [84.74624634, 19.12319374], [84.7462616, 19.12375069], [84.74597168, 19.12375069], [84.74597168, 19.12431145], [84.7454071, 19.12431145], [84.7454071, 19.12486076], [84.74514008, 19.12486076], [84.74514008, 19.12513924], [84.74430847, 19.12513924], [84.74430847, 19.12624931], [84.74402618, 19.12624931], [84.74402618, 19.12708282], [84.74430847, 19.12708092], [84.74430847, 19.12792015], [84.74458313, 19.12791634], [84.74458313, 19.12819481], [84.74485779, 19.1281929], [84.74485779, 19.12848091], [84.74569702, 19.12848091], [84.74569702, 19.12874985], [84.7462616, 19.12874985], [84.7462616, 19.12903023], [84.74652863, 19.12902832], [84.74652863, 19.12930489], [84.74680328, 19.12930489], [84.74680328, 19.12958145], [84.74652863, 19.12958145], [84.74652863, 19.12986374], [84.7462616, 19.12985992], [84.7462616, 19.13070107], [84.74652863, 19.13069534], [84.74652863, 19.13097382], [84.74680328, 19.13097], [84.74680328, 19.13181114], [84.74541473, 19.13180351], [84.74541473, 19.1320858], [84.74485779, 19.13208008], [84.74485779, 19.13236046], [84.74458313, 19.13236046], [84.74458313, 19.13292122], [84.74485779, 19.1329174], [84.74485779, 19.13319588], [84.74514008, 19.13319588], [84.74514008, 19.13347244], [84.7454071, 19.13347054], [84.7454071, 19.13402939], [84.7470932, 19.13402939], [84.7470932, 19.13430977], [84.74764252, 19.13430786], [84.74764252, 19.13458252], [84.74791718, 19.13458061], [84.74791718, 19.13486099], [84.74819183, 19.13486099], [84.74819183, 19.13513947], [84.74847412, 19.13513947], [84.74847412, 19.1356945], [84.74874878, 19.1356945], [84.74874878, 19.13597298], [84.75041962, 19.13597107], [84.75041962, 19.13652992], [84.75013733, 19.13652992], [84.75013733, 19.13708305], [84.74986267, 19.13708115], [84.74986267, 19.14042282], [84.74958038, 19.14042282], [84.74958038, 19.14125061], [84.7492981, 19.14125061], [84.7492981, 19.14180946], [84.74903107, 19.14180565], [84.74903107, 19.14208221], [84.74874878, 19.14208031], [84.74874878, 19.14236069], [84.74819183, 19.14236069], [84.74819183, 19.14264107], [84.74736023, 19.14263916], [84.74736023, 19.14319229], [84.74708557, 19.14319229], [84.74708557, 19.14347458], [84.74514008, 19.14346123], [84.74514008, 19.14375114], [84.74485779, 19.14375114], [84.74485779, 19.14402962], [84.74458313, 19.14402771], [84.74458313, 19.14458466], [84.74375153, 19.14458466], [84.74375153, 19.14430618], [84.74346924, 19.14431], [84.74346924, 19.14402962], [84.74014282, 19.14402962], [84.74014282, 19.14375114], [84.73986053, 19.14375114], [84.73986053, 19.14346123], [84.73958588, 19.14347458], [84.73958588, 19.14291763], [84.73929596, 19.14291954], [84.73929596, 19.14236069], [84.73819733, 19.14236069], [84.73819733, 19.14264107], [84.73792267, 19.14264107], [84.73792267, 19.14291954], [84.73764038, 19.14291763], [84.73764038, 19.14319229], [84.73708344, 19.14319229], [84.73708344, 19.14347458], [84.73680878, 19.14346123], [84.73680878, 19.14375114], [84.73542023, 19.14375114], [84.73542023, 19.14346123], [84.73458099, 19.14347458], [84.73458099, 19.14319229], [84.73430634, 19.14319229], [84.73430634, 19.14291763], [84.7334671, 19.14291954], [84.7334671, 19.14264107], [84.73291779, 19.14264107], [84.73291779, 19.14208031], [84.73236084, 19.14208221], [84.73236084, 19.14180565], [84.73097229, 19.14180946], [84.73097229, 19.1415329], [84.7298584, 19.1415329], [84.7298584, 19.14125061], [84.72957611, 19.14125061], [84.72957611, 19.14097023], [84.72902679, 19.14097023], [84.72902679, 19.14069366], [84.72875214, 19.14069366], [84.72875214, 19.1404171], [84.72846985, 19.14042282], [84.72846985, 19.14014244], [84.72820282, 19.14014244], [84.72820282, 19.13986015], [84.72736359, 19.13986015], [84.72736359, 19.13958359], [84.72680664, 19.13958359], [84.72680664, 19.13986015], [84.72624969, 19.13986015], [84.72624969, 19.14014244], [84.72486115, 19.14014244], [84.72486115, 19.14042282], [84.72374725, 19.14042282], [84.72374725, 19.14014244], [84.7234726, 19.14014244], [84.7234726, 19.13986015], [84.72264099, 19.13986015], [84.72264099, 19.13958359], [84.7223587, 19.13958359], [84.7223587, 19.13930511], [84.72206879, 19.13931274], [84.72206879, 19.1384697], [84.72180176, 19.1384716], [84.72180176, 19.13819504], [84.7215271, 19.13820076], [84.7215271, 19.13791847], [84.72125244, 19.13791847], [84.72125244, 19.13763809], [84.72097015, 19.13763809], [84.72097015, 19.13735962], [84.7206955, 19.13736153], [84.7206955, 19.13680649], [84.72097015, 19.13680077], [84.72097015, 19.13652992], [84.72125244, 19.13652992], [84.72125244, 19.13597107], [84.7215271, 19.13597298], [84.7215271, 19.13513947], [84.72125244, 19.13513947], [84.72125244, 19.13458061], [84.7215271, 19.13458252], [84.7215271, 19.13402748], [84.72180176, 19.13402939], [84.72180176, 19.13347054], [84.72125244, 19.13347244], [84.72125244, 19.13319588], [84.72097015, 19.13319588], [84.72097015, 19.1329174], [84.72041321, 19.13292122], [84.72041321, 19.13264084], [84.72013855, 19.13264084], [84.72013855, 19.13236046], [84.71985626, 19.13236046], [84.71985626, 19.13181114], [84.7195816, 19.13181114], [84.7195816, 19.13125038], [84.71985626, 19.13125038], [84.71985626, 19.13097], [84.7195816, 19.13097382], [84.7195816, 19.13069534], [84.7193222, 19.13070107], [84.7193222, 19.1301403], [84.71903229, 19.1301403], [84.71903229, 19.12985992], [84.7179184, 19.12986374], [84.7179184, 19.12958145], [84.71736145, 19.12958145], [84.71736145, 19.12930489], [84.71708679, 19.12930489], [84.71708679, 19.12902832], [84.71679688, 19.12903023], [84.71679688, 19.12874985], [84.71624756, 19.12874985], [84.71624756, 19.12847137], [84.71569824, 19.12848091], [84.71569061, 19.1281929], [84.71541595, 19.12819481], [84.71541595, 19.12791634], [84.7140274, 19.12792015], [84.7140274, 19.12763977], [84.71375275, 19.12763977], [84.71375275, 19.12735939], [84.71347046, 19.1273613], [84.71347046, 19.12708282], [84.7131958, 19.12708282], [84.7131958, 19.12652779], [84.71289825, 19.1265316], [84.71289825, 19.12624931], [84.71263885, 19.12624931], [84.71263885, 19.12597084], [84.7123642, 19.12597275], [84.7123642, 19.1254158], [84.71208191, 19.12542152], [84.71208191, 19.12486076], [84.71180725, 19.12486076], [84.71180725, 19.12458038], [84.71152496, 19.1245842], [84.71152496, 19.12347221], [84.71097565, 19.12347221], [84.71097565, 19.12319374], [84.71069336, 19.12319374], [84.71069336, 19.12291718], [84.7104187, 19.12291908], [84.7104187, 19.12235069], [84.70847321, 19.12236023], [84.70847321, 19.12208366], [84.70680237, 19.12208366], [84.70680237, 19.12180519], [84.70652771, 19.12181091], [84.70652771, 19.12153053], [84.70569611, 19.12153053], [84.70569611, 19.12096977], [84.70541382, 19.12097168], [84.70541382, 19.12041664], [84.70402527, 19.12041664], [84.70402527, 19.12097168], [84.70347595, 19.12097168], [84.70347595, 19.12069511], [84.70318604, 19.12070084], [84.70318604, 19.1198597], [84.70291901, 19.1198616], [84.70291901, 19.11874962], [84.70318604, 19.11874962], [84.70318604, 19.11763954], [84.70347595, 19.11763954], [84.70347595, 19.11680984], [84.70375061, 19.11680984], [84.70375061, 19.1162529], [84.7040329, 19.1162529], [84.7040329, 19.11597061], [84.70430756, 19.11597443], [84.70430756, 19.11458206], [84.7048645, 19.11458206], [84.7048645, 19.1143055], [84.70540619, 19.11431122], [84.70540619, 19.11403275], [84.70569611, 19.11403275], [84.70569611, 19.11375046], [84.70652771, 19.11375046], [84.70652771, 19.11320114], [84.70597076, 19.1131916], [84.70597076, 19.11124992], [84.70625305, 19.11124992], [84.70625305, 19.11096954], [84.70652771, 19.11097145], [84.70652771, 19.11069489], [84.70680237, 19.11069489], [84.70680237, 19.11013985], [84.70709229, 19.11013985], [84.70709229, 19.10902977], [84.70680237, 19.10902977], [84.70680237, 19.10874939], [84.70652771, 19.10874939], [84.70652771, 19.10847092], [84.70680237, 19.10847282], [84.70680237, 19.10819435], [84.70708466, 19.10819435], [84.70708466, 19.10791779], [84.70791626, 19.10791779], [84.70791626, 19.10819435], [84.71013641, 19.10819435], [84.71013641, 19.10847282], [84.7104187, 19.10847282], [84.7104187, 19.10819435], [84.71097565, 19.10819435], [84.71097565, 19.10763931], [84.71125031, 19.10764122], [84.71125031, 19.1073494], [84.71152496, 19.10736084], [84.71152496, 19.10708427], [84.71125031, 19.10708427], [84.71125031, 19.10652733], [84.71153259, 19.10653114], [84.71153259, 19.10625076], [84.71180725, 19.10625076], [84.71180725, 19.10514069], [84.71208191, 19.10514069], [84.71208191, 19.10486031], [84.71235657, 19.10486031], [84.71235657, 19.10457993], [84.71291351, 19.10458565], [84.71291351, 19.10375023], [84.71318817, 19.10375023], [84.71318817, 19.10320091], [84.71347046, 19.10320091], [84.71347046, 19.10292053], [84.71375275, 19.10292053], [84.71375275, 19.10042191], [84.7140274, 19.10042191], [84.7140274, 19.09958076], [84.71430206, 19.09958267], [84.71430206, 19.09930611], [84.71457672, 19.09931183], [84.71457672, 19.09903145], [84.71626282, 19.09903145], [84.71626282, 19.09874916], [84.71652985, 19.09874916], [84.71652985, 19.09792137], [84.71679688, 19.09792137], [84.71679688, 19.09763908], [84.71708679, 19.09763908], [84.71708679, 19.09736061], [84.71763611, 19.09736061], [84.71763611, 19.09708023], [84.71875, 19.09708405], [84.71875, 19.09680557], [84.71903229, 19.09680748], [84.71903229, 19.09653091], [84.71875, 19.09653091], [84.71875, 19.09625053], [84.71903229, 19.09625053], [84.71903229, 19.09584427], [84.71185303, 19.1000309], [84.69754791, 19.10881805], [84.69832611, 19.1103096], [84.69776917, 19.1156311], [84.69381714, 19.11952019], [84.69391632, 19.12155151], [84.69731903, 19.1251297], [84.70648193, 19.14356041], [84.70522308, 19.1490097], [84.7020874, 19.15114975], [84.69756317, 19.15029144], [84.69213867, 19.15170097], [84.68141174, 19.14974976], [84.67807007, 19.15346909], [84.67333221, 19.15689087], [84.66929626, 19.15568161], [84.66501617, 19.15673065], [84.66326904, 19.14748001], [84.6654129, 19.14470291], [84.66590118, 19.13527107], [84.66451263, 19.12815094], [84.66117096, 19.1218605], [84.65731812, 19.12138939], [84.65342712, 19.12290955], [84.64729309, 19.12037086], [84.64170837, 19.12478828], [84.64037323, 19.12223816], [84.62931824, 19.12070084], [84.62554932, 19.11827087], [84.60939789, 19.11745071], [84.59464264, 19.12354851], [84.59184265, 19.12384033], [84.59168243, 19.12112045], [84.59577179, 19.11520958], [84.60293579, 19.09657097], [84.6055603, 19.09263039], [84.60962677, 19.09089279], [84.6144104, 19.09231758], [84.61678314, 19.09000015], [84.61656952, 19.08520126], [84.61982727, 19.07650948], [84.62444305, 19.07442093], [84.63144684, 19.07262039], [84.63360596, 19.07463837], [84.63474274, 19.07868958], [84.64460754, 19.08445168], [84.64871216, 19.08419991], [84.65416718, 19.08101273], [84.65962219, 19.07093048], [84.66458893, 19.06629181], [84.66320038, 19.06445122], [84.65901184, 19.06364822], [84.65453339, 19.05231094], [84.64772797, 19.0560894], [84.63683319, 19.05714989], [84.63437653, 19.05554008], [84.63005829, 19.04959106], [84.62608337, 19.05029106], [84.62541199, 19.05278015], [84.62329102, 19.05566025], [84.61271667, 19.05483055], [84.61152649, 19.05373001], [84.61235809, 19.04973984], [84.61418915, 19.0467205], [84.60946655, 19.04673958], [84.60756683, 19.04540825], [84.60048676, 19.03293037], [84.59697723, 19.01974106], [84.59011841, 19.01338005], [84.58769226, 19.01299095], [84.57813263, 19.01890182], [84.57531738, 19.02719116], [84.57364655, 19.03511047], [84.57509613, 19.03753853], [84.57811737, 19.06212807], [84.57644653, 19.06456184], [84.57060242, 19.06041145], [84.56852722, 19.06064034], [84.56797028, 19.06347084], [84.56613922, 19.06503868], [84.5597229, 19.05956078], [84.5535965, 19.04740906], [84.54772186, 19.04609108], [84.53481293, 19.04536057], [84.53147125, 19.0441494], [84.52715302, 19.03871918], [84.50991821, 19.03746033], [84.5071106, 19.03544807], [84.5030899, 19.02926254], [84.49777985, 19.02487946], [84.48938751, 19.02095032], [84.48206329, 19.00990868], [84.47782898, 19.0078907], [84.47551727, 18.99603271], [84.47569275, 18.99173927], [84.47306061, 18.98264122], [84.4716568, 18.98122025], [84.46282959, 18.98328972], [84.45218658, 18.98833084], [84.44815063, 18.99173927], [84.44406128, 18.99455833], [84.43739319, 18.99745941], [84.43297577, 19.00185966], [84.42980194, 19.00118065], [84.42218781, 19.00853157], [84.42002106, 19.01251984], [84.41513062, 19.0138607], [84.41464996, 19.01235962], [84.4154129, 19.00813293], [84.41803741, 19.00498962], [84.42003632, 19.00084114], [84.42526245, 18.99534035], [84.42610931, 18.99176979], [84.42555237, 18.989151], [84.42640686, 18.98397064], [84.42796326, 18.98264122], [84.4347229, 18.97682953], [84.44064331, 18.96693039], [84.43772888, 18.96570969], [84.43454742, 18.96315956], [84.42030334, 18.94935989], [84.41559601, 18.93803978], [84.41713715, 18.93330193], [84.41998291, 18.92971039], [84.42938995, 18.91368294], [84.42032623, 18.90487099], [84.41796875, 18.90065956], [84.40956879, 18.90810013], [84.40615082, 18.9061203], [84.40769958, 18.90112114], [84.41072083, 18.89825821], [84.41208649, 18.89393997], [84.40981293, 18.89063072], [84.39782715, 18.88611984], [84.39396667, 18.88586998], [84.38687134, 18.88986969], [84.37845612, 18.89324188], [84.37406921, 18.89402962], [84.36976624, 18.89581108], [84.3653183, 18.89625931], [84.36490631, 18.8932209], [84.36767578, 18.88932991], [84.37422943, 18.8888607], [84.37903595, 18.88546944], [84.38609314, 18.88302994], [84.38762665, 18.87766838], [84.38622284, 18.87170982], [84.38323212, 18.86927986], [84.37808228, 18.87409973], [84.37406921, 18.87649918], [84.37135315, 18.8754406], [84.35473633, 18.88293076], [84.35144806, 18.88319969], [84.35183716, 18.87779045], [84.35382843, 18.87506294], [84.35962677, 18.87190056], [84.3613205, 18.87268066], [84.36624908, 18.87170982], [84.37156677, 18.86721992], [84.37146759, 18.86338234], [84.36933899, 18.85897064], [84.3624115, 18.85106087], [84.3583374, 18.85134125], [84.35521698, 18.85264015], [84.35411835, 18.85149956], [84.35146332, 18.85090065], [84.3469696, 18.85997963], [84.34438324, 18.86276245], [84.33979034, 18.86592102], [84.33602142, 18.86671066], [84.33442688, 18.86384964], [84.33413696, 18.85799026], [84.33413696, 18.85156059], [84.33598328, 18.84142113], [84.3380661, 18.83621979], [84.34435272, 18.8327198], [84.34516907, 18.82678032], [84.3442688, 18.8227005], [84.34243011, 18.82150841], [84.34075928, 18.81825066], [84.34410095, 18.81194115], [84.32932281, 18.80899811], [84.32952881, 18.8045311], [84.33358765, 18.79505157], [84.33222198, 18.79202271], [84.3269577, 18.78967285], [84.3157196, 18.78617096], [84.31292725, 18.78218079], [84.31249237, 18.77919006], [84.30885315, 18.77841949], [84.30716705, 18.78166008], [84.30432129, 18.78071976], [84.30036926, 18.78174019], [84.28392029, 18.79082108], [84.27854919, 18.78968048], [84.27533722, 18.78718185], [84.27321625, 18.78248978], [84.26818848, 18.78030968], [84.26422119, 18.78051949], [84.25888824, 18.77482986], [84.25218964, 18.77248192], [84.24603271, 18.7734108], [84.23116302, 18.78012085], [84.23069, 18.78564072], [84.22698975, 18.78716087], [84.22429657, 18.78426933], [84.22145844, 18.78647995], [84.21671295, 18.78728104], [84.2038269, 18.78264046], [84.19033813, 18.77673912], [84.18651581, 18.77960014], [84.18151093, 18.77752113], [84.1798172, 18.76897049], [84.16703033, 18.77013969], [84.16262817, 18.76856995], [84.15818787, 18.76918983], [84.16027069, 18.77231979], [84.15934753, 18.77503967], [84.15493011, 18.77601051], [84.15136719, 18.77576065], [84.14811707, 18.77176094], [84.14042664, 18.76769066], [84.13497925, 18.76678848], [84.13136292, 18.76480293], [84.12793732, 18.76126862], [84.12948608, 18.75286293], [84.12294006, 18.74826813], [84.118927, 18.75303078], [84.11406708, 18.7551403], [84.10758972, 18.7548008], [84.10072327, 18.75267982], [84.09163666, 18.74523926], [84.08878326, 18.74711037], [84.08557892, 18.74518013], [84.08177948, 18.74464035], [84.07933044, 18.74611092], [84.07788086, 18.74888039], [84.06989288, 18.74975967], [84.06577301, 18.75169945], [84.06046295, 18.76267052], [84.05860901, 18.76810074], [84.05355835, 18.76836967], [84.04920197, 18.77065086], [84.04804993, 18.77440262], [84.04972076, 18.77730942], [84.04760742, 18.77987289], [84.04794312, 18.78347969], [84.03871918, 18.78742981], [84.0342865, 18.79012108], [84.03077698, 18.79544067], [84.03071594, 18.80027962], [84.02706146, 18.80220032], [84.02372742, 18.80115128], [84.02231598, 18.79862976], [84.01966095, 18.79762268], [84.01586914, 18.80141068], [84.01249695, 18.80063057], [84.00739288, 18.80421066], [83.99997711, 18.8047905], [83.991539, 18.8046627], [83.98232269, 18.80001068], [83.96938324, 18.80382919], [83.9640274, 18.80410957], [83.95561218, 18.80306053], [83.95121002, 18.8000412], [83.94902039, 18.79704094], [83.94368744, 18.79628754], [83.93978882, 18.79660034], [83.93657684, 18.79920006], [83.93572235, 18.8031292], [83.93358612, 18.80685806], [83.9263916, 18.80656052], [83.9226532, 18.80853271], [83.92059326, 18.81157112], [83.90775299, 18.81638908], [83.90197754, 18.81692123], [83.89855194, 18.81644058], [83.89547729, 18.81487846], [83.89064026, 18.80686951], [83.88687897, 18.80540848], [83.88535309, 18.81004143], [83.88463593, 18.8178196], [83.88323975, 18.8196907], [83.87391663, 18.8177681], [83.87017822, 18.81842995], [83.86686707, 18.82345009], [83.86434174, 18.83904076], [83.85906982, 18.84301186], [83.84797668, 18.8476181], [83.84366608, 18.85140038], [83.83709717, 18.86470985], [83.83600616, 18.8691082], [83.83669281, 18.87272072], [83.8423233, 18.88824081], [83.84163666, 18.89763069], [83.840271, 18.90406036], [83.83772278, 18.90860939], [83.83487701, 18.90929985], [83.82305145, 18.90546036], [83.81845093, 18.90711975], [83.81693268, 18.90940285], [83.82116699, 18.92196083], [83.81890106, 18.92609978], [83.814888, 18.93003845], [83.8134079, 18.9335804], [83.81606293, 18.9486599], [83.81476593, 18.95317841], [83.81063843, 18.9648304], [83.80809021, 18.96840286], [83.80253601, 18.98180962], [83.79116821, 18.99235916], [83.78894806, 18.99833107], [83.78830719, 19.00781059], [83.78704071, 19.00836945], [83.7859726, 19.00878906], [83.78486633, 19.00909042], [83.78375244, 19.00933075], [83.78263855, 19.00957108], [83.78148651, 19.00979042], [83.78037262, 19.0099411], [83.77887726, 19.01000977], [83.77774048, 19.00988007], [83.77664948, 19.00951958], [83.77565002, 19.00896072], [83.77474213, 19.00824928], [83.77392578, 19.00745964], [83.77320099, 19.00658989], [83.77259827, 19.00566101], [83.77204895, 19.0046711], [83.7715683, 19.00366974], [83.77111816, 19.00263977], [83.7706604, 19.0016098], [83.77021027, 19.00059128], [83.76941681, 18.99977112], [83.76850128, 18.99908066], [83.76747894, 18.99842834], [83.7664032, 18.99795914], [83.7652359, 18.99760056], [83.76405334, 18.99731064], [83.76288605, 18.99705124], [83.76171112, 18.99677849], [83.76056671, 18.9964695], [83.75946808, 18.99605942], [83.75845337, 18.99547005], [83.75778961, 18.99455833], [83.75695801, 18.99390984], [83.75582886, 18.99361038], [83.75469208, 18.99337006], [83.75354767, 18.99316978], [83.75242615, 18.99333191], [83.75128174, 18.99328041], [83.75061798, 18.99241829], [83.74923706, 18.99067116], [83.74108124, 18.98389053], [83.73956299, 18.97844124], [83.74172211, 18.96705818], [83.74597168, 18.9632206], [83.74900055, 18.95844078], [83.74836731, 18.95137024], [83.75036621, 18.94437027], [83.75520325, 18.94202995], [83.76148224, 18.94460106], [83.76525116, 18.93642044], [83.76986694, 18.93297005], [83.77715302, 18.9190712], [83.78006744, 18.90772057], [83.77739716, 18.90439987], [83.77127075, 18.90130043], [83.77050018, 18.90159035], [83.76750183, 18.90236282], [83.7628479, 18.90653992], [83.75614929, 18.91669083], [83.74582672, 18.91817284], [83.74214935, 18.92313957], [83.74140167, 18.93029022], [83.73992157, 18.93406105], [83.73649597, 18.93897057], [83.73002625, 18.9601593], [83.72746277, 18.96607971], [83.7263031, 18.97556114], [83.71689606, 18.98253822], [83.71140289, 18.98495102], [83.70880127, 18.9838028], [83.70574188, 18.98524094], [83.70484924, 18.99200821], [83.70469666, 18.99248123], [83.70436096, 18.99530983], [83.70500183, 18.99946976], [83.70941925, 19.00195122], [83.71478271, 19.00213051], [83.71984863, 19.00428963], [83.72325134, 19.01189995], [83.72128296, 19.0134182], [83.71682739, 19.01444817], [83.69983673, 19.01503181], [83.69702148, 19.01647949], [83.69415283, 19.02114105], [83.68438721, 19.04393005], [83.67637634, 19.05245018], [83.66673279, 19.06446075], [83.66261292, 19.06649017], [83.65969849, 19.0697403], [83.65685272, 19.07493973], [83.65809631, 19.08210945], [83.65748596, 19.08777237], [83.65026855, 19.10009956], [83.6479187, 19.10225105], [83.647789, 19.10594177], [83.64588165, 19.10873032], [83.64472961, 19.11329079], [83.64627075, 19.11449814], [83.64974976, 19.11482048], [83.65072632, 19.11840057], [83.64943695, 19.12187958], [83.64556122, 19.12310028], [83.63331604, 19.1244297], [83.62983704, 19.12699127], [83.62844086, 19.13150024], [83.63018799, 19.14479065], [83.62850952, 19.14974022], [83.62328339, 19.15363121], [83.62116241, 19.15192032], [83.62023926, 19.14862823], [83.62271881, 19.14468765], [83.619133, 19.14188194], [83.61408997, 19.13381958], [83.61060333, 19.13093758], [83.60521698, 19.13103294], [83.60051727, 19.12770081], [83.59429932, 19.12033081], [83.59365082, 19.11548996], [83.59429932, 19.11058044], [83.59677887, 19.10519981], [83.60440063, 19.09287071], [83.60441589, 19.08818054], [83.59986115, 19.08480263], [83.59320831, 19.08489037], [83.58763123, 19.08307076], [83.58444977, 19.07973099], [83.5821991, 19.07563972], [83.58178711, 19.06277275], [83.58078003, 19.05514908], [83.57876587, 19.04978943], [83.56735992, 19.05225945], [83.56105042, 19.05038834], [83.55766296, 19.05138016], [83.556427, 19.05583954], [83.55710602, 19.05998993], [83.56038666, 19.06396103], [83.56067657, 19.06622124], [83.55497742, 19.07813072], [83.55149078, 19.07785034], [83.5464325, 19.07382965], [83.54485321, 19.06940269], [83.54486847, 19.06208038], [83.55148315, 19.05038071], [83.5522995, 19.04718971], [83.54772949, 19.04496956], [83.54277802, 19.03684044], [83.53578949, 19.03034973], [83.53482819, 19.02861977], [83.53309631, 19.01938248], [83.53311157, 19.01246071], [83.53138733, 19.00542068], [83.51529694, 19.00490952], [83.50460052, 19.01009941], [83.49539948, 19.01109123], [83.49292755, 19.01803017], [83.49263, 19.02398109], [83.49355316, 19.02680016], [83.49931335, 19.02708054], [83.50392914, 19.02620125], [83.50817871, 19.02197075], [83.51367188, 19.02478027], [83.51322937, 19.03032112], [83.51008606, 19.03617287], [83.50979614, 19.04008102], [83.51074982, 19.04800034], [83.50847626, 19.0499115], [83.50617981, 19.05430984], [83.50538635, 19.06477165], [83.50287628, 19.06466103], [83.50036621, 19.06208038], [83.49633026, 19.05550957], [83.49362946, 19.05308914], [83.49249268, 19.05495071], [83.48043823, 19.06648064], [83.47817993, 19.07022095], [83.47698975, 19.07533073], [83.47323608, 19.0777626], [83.47202301, 19.07274055], [83.47027588, 19.07032013], [83.46746826, 19.06987953], [83.46382904, 19.0714016], [83.45939636, 19.06967163], [83.45826721, 19.06713295], [83.45913696, 19.06348991], [83.45736694, 19.0598011], [83.45670319, 19.05611038], [83.46327209, 19.05260086], [83.46279907, 19.04395103], [83.46543884, 19.03619003], [83.47735596, 19.02551842], [83.47796631, 19.02119064], [83.47511292, 19.01152992], [83.47663879, 19.00407028], [83.47460175, 19.00031281], [83.4718399, 18.99897957], [83.46750641, 18.99891853], [83.45848083, 19.00209808], [83.45327759, 19.00246048], [83.45017242, 19.00188828], [83.44851685, 18.99963188], [83.44822693, 18.99594116], [83.44908905, 18.99261093], [83.45022583, 18.98242188], [83.4577179, 18.98250008], [83.46029663, 18.98077965], [83.45831299, 18.97247124], [83.45894623, 18.97044945], [83.46147156, 18.9679203], [83.46224213, 18.96359062], [83.46227264, 18.95922089], [83.45548248, 18.94557953], [83.45120239, 18.94445992], [83.44684601, 18.94564819], [83.44267273, 18.94774055], [83.44001007, 18.95022011], [83.43647766, 18.95787811], [83.43292236, 18.96139908], [83.4148407, 18.97787285], [83.40878296, 18.97989082], [83.41142273, 18.98871994], [83.41057587, 18.99261093], [83.40885162, 18.99619102], [83.4068985, 18.99508095], [83.4046402, 18.99320984], [83.40231323, 18.99516106], [83.40142059, 18.99638176], [83.39605713, 18.99583054], [83.39295959, 18.99912834], [83.3887558, 19.00001907], [83.38471985, 18.99727249], [83.37719727, 18.99472046], [83.36747742, 18.99361992], [83.36232758, 18.99473], [83.35800934, 19.00613976], [83.35498047, 19.00938988], [83.34633636, 19.0098896], [83.34091187, 19.0091629], [83.3349762, 19.00671959], [83.33271027, 18.99983978], [83.33067322, 18.99842834], [83.33010101, 18.99695969], [83.33075714, 18.99257088], [83.33120728, 18.99007034], [83.32917786, 18.98818016], [83.32537842, 18.98880959], [83.31643677, 18.99040031], [83.30783844, 18.99094963], [83.30526733, 18.98968124], [83.30432892, 18.98698997], [83.30774689, 18.98324966], [83.30914307, 18.98035049], [83.30961609, 18.9768219], [83.31334686, 18.96663094], [83.31980896, 18.96133041], [83.32055664, 18.96103096], [83.32556152, 18.95897102], [83.32691956, 18.95734024], [83.32565308, 18.95292282], [83.32601166, 18.95016289], [83.32704163, 18.94790077], [83.32888794, 18.94682121], [83.33104706, 18.94581032], [83.3324585, 18.94337082], [83.33302307, 18.93931961], [83.33113098, 18.93763924], [83.32119751, 18.93602943], [83.3184967, 18.93362045], [83.31887817, 18.92843819], [83.31991577, 18.92581749], [83.32202911, 18.9232502], [83.32901001, 18.91690826], [83.33454132, 18.91582108], [83.33905792, 18.91620064], [83.34136963, 18.91839981], [83.33957672, 18.92620087], [83.33953857, 18.9294796], [83.33952332, 18.93191147], [83.33972931, 18.93275261], [83.33983612, 18.93321991], [83.34326172, 18.93516159], [83.34480286, 18.94524956], [83.34501648, 18.95630074], [83.34575653, 18.95709991], [83.34903717, 18.95609093], [83.35440826, 18.95445061], [83.35890198, 18.95471191], [83.36022949, 18.95389938], [83.36106873, 18.95340157], [83.36084747, 18.94811058], [83.36389923, 18.93793106], [83.36741638, 18.93349075], [83.38022614, 18.92328262], [83.37966156, 18.92152023], [83.37634277, 18.91777039], [83.37384033, 18.91679192], [83.3710022, 18.91708946], [83.36406708, 18.92278862], [83.36276245, 18.93007088], [83.35523987, 18.93303108], [83.34902954, 18.9338398], [83.34792328, 18.93214035], [83.34661102, 18.92687035], [83.34768677, 18.92098808], [83.35016632, 18.91592979], [83.35649872, 18.90480995], [83.35777283, 18.9036808], [83.36052704, 18.90117073], [83.36631012, 18.9004612], [83.36715698, 18.90036011], [83.37684631, 18.90246964], [83.3809967, 18.90182114], [83.38391113, 18.89969063], [83.38326263, 18.89723969], [83.37444305, 18.89194107], [83.37248993, 18.88983917], [83.37390137, 18.88591194], [83.37890625, 18.88027954], [83.38568115, 18.87549019], [83.38539124, 18.87326241], [83.38780975, 18.87103081], [83.39425659, 18.8682003], [83.40177917, 18.86707115], [83.40432739, 18.86598015], [83.40585327, 18.86532974], [83.41133881, 18.85934067], [83.41073608, 18.85676193], [83.40875244, 18.85445023], [83.40680695, 18.85367966], [83.39985657, 18.85365105], [83.39787292, 18.85259056], [83.39694214, 18.84921074], [83.39871216, 18.83352852], [83.39630127, 18.83070946], [83.38648987, 18.82576942], [83.38313293, 18.82607079], [83.3763504, 18.82195091], [83.37283325, 18.82121086], [83.36226654, 18.83210945], [83.36032104, 18.83204079], [83.35887909, 18.83200073], [83.35349274, 18.82748985], [83.35011292, 18.82163811], [83.35999298, 18.80735016], [83.36022949, 18.80447006], [83.35848236, 18.80179977], [83.35629272, 18.8001194], [83.3524704, 18.80018997], [83.34780884, 18.80125809], [83.34429169, 18.80293083], [83.34073639, 18.8035202], [83.33927917, 18.80309105], [83.33812714, 18.80035019], [83.33761597, 18.79570007], [83.33687592, 18.79465294], [83.33587646, 18.79321289], [83.33333588, 18.7926712], [83.32978821, 18.79372978], [83.32614136, 18.79482079], [83.32302094, 18.79828072], [83.31826019, 18.79584122], [83.31404114, 18.79580116], [83.30422211, 18.79887009], [83.30036926, 18.79791069], [83.29210663, 18.79253006], [83.27950287, 18.78960037], [83.2752533, 18.78536987], [83.26992035, 18.77528763], [83.26914978, 18.77075958], [83.27124786, 18.76732063], [83.27171326, 18.76317978], [83.26991272, 18.75980949], [83.26609802, 18.75700951], [83.2593689, 18.75760078], [83.25541687, 18.75881958], [83.24508667, 18.75808907], [83.23956299, 18.75878143], [83.22931671, 18.76414108], [83.22651672, 18.76490021], [83.22271729, 18.76593018], [83.22103119, 18.76587105], [83.21939087, 18.76581955], [83.21707916, 18.76356125], [83.21733093, 18.75895119], [83.22189331, 18.75202179], [83.22268677, 18.74861908], [83.2230072, 18.74798012], [83.22235107, 18.74505043], [83.22033691, 18.74204826], [83.21446228, 18.73719978], [83.21363831, 18.73602104], [83.2125473, 18.7344799], [83.20918274, 18.72454071], [83.20677948, 18.71749115], [83.20506287, 18.71586037], [83.20332336, 18.7195797], [83.20366669, 18.72350121], [83.20641327, 18.72742081], [83.20633698, 18.72803116], [83.20626068, 18.7287426], [83.2024231, 18.73254967], [83.20188904, 18.73613167], [83.20342255, 18.74035263], [83.20170593, 18.74222946], [83.19181824, 18.74178123], [83.1853714, 18.74414253], [83.18080139, 18.74825096], [83.17701721, 18.75440979], [83.17394257, 18.75676918], [83.16854858, 18.75906944], [83.15622711, 18.75731087], [83.15083313, 18.75868988], [83.14686584, 18.76317978], [83.14491272, 18.76690102], [83.13884735, 18.77113914], [83.13295746, 18.77244949], [83.11580658, 18.76208115], [83.11219025, 18.7582798], [83.11752319, 18.75048065], [83.11650085, 18.74797058], [83.10600281, 18.73849106], [83.09921265, 18.72689056], [83.09546661, 18.72309113], [83.09259033, 18.7217617], [83.09079742, 18.71925926], [83.08960724, 18.71627045], [83.0880661, 18.71240044], [83.08574677, 18.70998001], [83.07788086, 18.70533943], [83.07073212, 18.69719124], [83.0690918, 18.69405174], [83.06987762, 18.69188118], [83.07080841, 18.68930054], [83.05584717, 18.66714096], [83.05146027, 18.6632309], [83.05097198, 18.65415955], [83.03616333, 18.64768982], [83.0226059, 18.64435959], [83.01154327, 18.63903046], [83.0096817, 18.63652992], [83.00948334, 18.63354111], [83.00934601, 18.63148117], [83.01132202, 18.62771034], [83.01461029, 18.62626076], [83.01737976, 18.62339973], [83.02126312, 18.61045074], [83.02030182, 18.60541153], [83.00948334, 18.5914402], [83.00804138, 18.58842087], [83.01586914, 18.58477974], [83.02770233, 18.58227158], [83.03114319, 18.58358955], [83.03781891, 18.58871269], [83.03970337, 18.59207916], [83.04065704, 18.59526253], [83.04110718, 18.59673119], [83.04891968, 18.59526253], [83.04946899, 18.59486961], [83.05208588, 18.59305954], [83.05297852, 18.58993912], [83.05394745, 18.58646965], [83.0511322, 18.58307076], [83.0447464, 18.57817078], [83.04203796, 18.57730293], [83.04171753, 18.5773201], [83.03650665, 18.57757187], [83.03376007, 18.57571983], [83.03114319, 18.5717907], [83.0268631, 18.56796074], [83.02545929, 18.56430054], [83.03370667, 18.55829048], [83.03247833, 18.54788971], [83.04023743, 18.54489136], [83.04509735, 18.53932953], [83.05117798, 18.5349102], [83.05414581, 18.53479958], [83.05735779, 18.53469086], [83.0714798, 18.54249191], [83.08705139, 18.54105949], [83.08933258, 18.53791046], [83.08850861, 18.53276062], [83.08230591, 18.52717018], [83.07315826, 18.51473999], [83.06881714, 18.50202942], [83.06511688, 18.4975605], [83.06035614, 18.49442101], [83.05517578, 18.48812294], [83.05179596, 18.47748947], [83.04384613, 18.47211075], [83.03701782, 18.46313095], [83.03414917, 18.46076965], [83.02672577, 18.45692062], [83.02455902, 18.45369911], [83.01644897, 18.44767952], [83.01541138, 18.4444294], [83.01803589, 18.44040108], [83.02484131, 18.43666077], [83.032341, 18.43618965], [83.037323, 18.43482971], [83.03900909, 18.43204117], [83.03819275, 18.42671013], [83.03330231, 18.42333984], [83.03555298, 18.42007065], [83.03743744, 18.41894913], [83.04261017, 18.41829109], [83.0485611, 18.42486], [83.05825806, 18.42905998], [83.05982971, 18.42863274], [83.061203, 18.42394066], [83.06208801, 18.42088127], [83.06062317, 18.41924286], [83.06046295, 18.41348839], [83.06035614, 18.41337967], [83.05531311, 18.40811157], [83.05581665, 18.40436935], [83.05903625, 18.3990097], [83.06373596, 18.39570999], [83.06582642, 18.39315987], [83.0664978, 18.3922596], [83.06582642, 18.38940048], [83.05619812, 18.37726021], [83.0533905, 18.37529945], [83.03952026, 18.37008095], [83.03697968, 18.36984253], [83.03188324, 18.3732605], [83.02375793, 18.37644958], [83.02005005, 18.38348007], [83.0171814, 18.3845005], [83.01161194, 18.37821007], [83.00348663, 18.3769207], [82.99711609, 18.37486076], [82.99286652, 18.37482071], [82.99196625, 18.37499809], [82.98761749, 18.36950111], [82.98610687, 18.36590195], [82.9812088, 18.36581993], [82.9784317, 18.36098862], [82.97644806, 18.3549118], [82.96878052, 18.35758018], [82.95979309, 18.35724068], [82.95597076, 18.35581017], [82.95204926, 18.35434914], [82.94816589, 18.35206032], [82.94550323, 18.35046959], [82.93268585, 18.35136986], [82.9276123, 18.36098862], [82.9200592, 18.3597393], [82.91513062, 18.35639954], [82.91166687, 18.35737991], [82.90838623, 18.35943031], [82.90274811, 18.35591125], [82.89852142, 18.35930061], [82.89186096, 18.36688042], [82.88490295, 18.37862015], [82.89095306, 18.39221954], [82.89077759, 18.39859962], [82.88835907, 18.40625954], [82.88461304, 18.41275978], [82.87935638, 18.41464043], [82.87706757, 18.4118309], [82.87001038, 18.40620041], [82.86296844, 18.40792084], [82.85597992, 18.41080093], [82.84863281, 18.41500854], [82.84490967, 18.40977287], [82.83978271, 18.41177177], [82.83698273, 18.4142704], [82.83634186, 18.41954041], [82.83576965, 18.42423058], [82.83014679, 18.42612076], [82.82417297, 18.4299202], [82.81874847, 18.43337059], [82.81835938, 18.43852997], [82.79917145, 18.43940163], [82.79197693, 18.4331398], [82.78710938, 18.42674065], [82.77622223, 18.41969109], [82.77620697, 18.41551971], [82.77845764, 18.40947914], [82.78160858, 18.4042511], [82.78118134, 18.3994503], [82.78739166, 18.39982033], [82.79329681, 18.39496994], [82.78748322, 18.3902092], [82.78675842, 18.38458061], [82.78761292, 18.37816048], [82.78096771, 18.37252045], [82.77790833, 18.37092018], [82.78421783, 18.35415077], [82.7714386, 18.33967972], [82.7670517, 18.33107948], [82.76184845, 18.32781029], [82.75849915, 18.32718086], [82.7544632, 18.32982063], [82.7510376, 18.3283329], [82.7506485, 18.32329941], [82.74642944, 18.31985092], [82.73781586, 18.31990051], [82.73280334, 18.3178997], [82.73432922, 18.3132515], [82.72531128, 18.31157112], [82.71726227, 18.31482124], [82.71090698, 18.31282043], [82.70670319, 18.31063271], [82.7025528, 18.30846977], [82.70169067, 18.30484009], [82.70050049, 18.29978943], [82.69809723, 18.29627037], [82.69374084, 18.29733086], [82.69032288, 18.29706955], [82.68177795, 18.29277992], [82.67539978, 18.29236984], [82.6725769, 18.29220009], [82.66493988, 18.2906208], [82.65883636, 18.28660965], [82.65648651, 18.27880096], [82.65222931, 18.2721405], [82.64910889, 18.26383972], [82.64485931, 18.25707817], [82.64758301, 18.2447319], [82.64530945, 18.24044991], [82.63716888, 18.23493004], [82.63165283, 18.22853088], [82.6288681, 18.22866058], [82.62687683, 18.22874069], [82.62039185, 18.23637009], [82.6164093, 18.23812103], [82.61341858, 18.23942947], [82.61103058, 18.24384117], [82.61181641, 18.24651146], [82.60948181, 18.24925041], [82.60076904, 18.25201988], [82.5982666, 18.25447273], [82.58920288, 18.25672913], [82.58866882, 18.26211929], [82.58724976, 18.2657795], [82.58547211, 18.26612091], [82.58318329, 18.26655006], [82.58074188, 18.27009964], [82.58428192, 18.27322006], [82.58846283, 18.27504921], [82.58840179, 18.27833939], [82.58722687, 18.27943993], [82.58558655, 18.28096008], [82.58757782, 18.2847805], [82.59031677, 18.28778076], [82.59095001, 18.29195976], [82.58783722, 18.3020401], [82.58270264, 18.30080032], [82.58107758, 18.30093956], [82.57978058, 18.30104065], [82.5764389, 18.30681038], [82.57805634, 18.30935097], [82.58325195, 18.3114109], [82.58596039, 18.3159008], [82.58863831, 18.31847954], [82.58966827, 18.3194828], [82.59229279, 18.31792068], [82.59568787, 18.3159008], [82.60214233, 18.31726074], [82.60382843, 18.32037163], [82.60031891, 18.33076096], [82.59757996, 18.33361816], [82.59651184, 18.3408699], [82.59783173, 18.34164047], [82.59915161, 18.34242058], [82.60787964, 18.34167099], [82.61128235, 18.34646034], [82.60865784, 18.35123062], [82.60566711, 18.35280991], [82.59857941, 18.35401154], [82.5976181, 18.35621834], [82.59931183, 18.35997009], [82.59768677, 18.3625927], [82.60087585, 18.36605072], [82.60050964, 18.36870956], [82.59902191, 18.37161827], [82.59364319, 18.37049103], [82.58917236, 18.37713814], [82.58080292, 18.37885094], [82.57733154, 18.37732124], [82.57556152, 18.37986946], [82.57060242, 18.38418961], [82.56521606, 18.38398933], [82.55603027, 18.38850975], [82.55172729, 18.38708115], [82.54944611, 18.38351059], [82.54234314, 18.38904953], [82.53515625, 18.3895607], [82.53230286, 18.39344978], [82.5326004, 18.39682007], [82.54032135, 18.40187073], [82.54057312, 18.40343094], [82.53968811, 18.40362167], [82.53697968, 18.4041996], [82.53591156, 18.40831947], [82.5376358, 18.41222954], [82.53968048, 18.41686821], [82.54512024, 18.41724968], [82.54605865, 18.42414284], [82.55021667, 18.42650032], [82.55107117, 18.43390083], [82.55377197, 18.43765068], [82.55011749, 18.43889046], [82.54772949, 18.44178963], [82.54421234, 18.44129944], [82.5383606, 18.44318008], [82.53900909, 18.43808937], [82.53560638, 18.43665123], [82.53308105, 18.43406105], [82.53015137, 18.43431091], [82.52879333, 18.44034004], [82.5293808, 18.44293976], [82.52670288, 18.44730949], [82.52316284, 18.44577026], [82.52120209, 18.44711113], [82.52043915, 18.45053291], [82.52319336, 18.45277977], [82.51613617, 18.45588112], [82.51676178, 18.45721054], [82.51774597, 18.45928955], [82.52176666, 18.46175957], [82.5275116, 18.46821976], [82.52572632, 18.470541], [82.52101135, 18.47237015], [82.52752686, 18.47772026], [82.52448273, 18.48284912], [82.51951599, 18.48251152], [82.51979065, 18.48488998], [82.52005768, 18.48726082], [82.52449799, 18.48978043], [82.52321625, 18.4935112], [82.52202606, 18.4969902], [82.52390289, 18.49929047], [82.52313232, 18.50392914], [82.51751709, 18.50563812], [82.51426697, 18.50363922], [82.50740814, 18.50807953], [82.50418091, 18.50549126], [82.50202179, 18.50173187], [82.49915314, 18.50175095], [82.49880981, 18.5032711], [82.49820709, 18.50604057], [82.48145294, 18.51506042], [82.47573853, 18.5294075], [82.47783661, 18.53153038], [82.48191833, 18.53271103], [82.48532104, 18.53370094], [82.48161316, 18.53845978], [82.47400665, 18.53683281], [82.45342255, 18.51702118], [82.44993591, 18.5114212], [82.43712616, 18.4973011], [82.42913818, 18.48514175], [82.42687225, 18.47699165], [82.42032623, 18.46988106], [82.41220093, 18.46467018], [82.39737701, 18.45160103], [82.38227081, 18.43169975], [82.38065338, 18.42642975], [82.37760162, 18.42198944], [82.37174225, 18.42016983], [82.36702728, 18.41716957], [82.36599731, 18.41301155], [82.36128998, 18.4099102], [82.36599731, 18.40335274], [82.37251282, 18.39809036], [82.37490845, 18.39281082], [82.37523651, 18.38306046], [82.37841034, 18.37813187], [82.38443756, 18.37240982], [82.38442993, 18.36911011], [82.38109589, 18.36668968], [82.37879944, 18.3616581], [82.37970734, 18.3574295], [82.3763504, 18.35326958], [82.36947632, 18.35036278], [82.36013794, 18.34370041], [82.35656738, 18.33357048], [82.35021973, 18.32891083], [82.34542084, 18.32181931], [82.33641815, 18.32011986], [82.33444214, 18.31713295], [82.34101105, 18.31065941], [82.34290314, 18.30734062], [82.34874725, 18.30615044], [82.35456085, 18.309021], [82.35797119, 18.30824089], [82.36524963, 18.31642914], [82.3691864, 18.31775284], [82.37510681, 18.31800079], [82.38049316, 18.31931114], [82.3843689, 18.31870079], [82.38842773, 18.3112011], [82.393013, 18.30644035], [82.38735199, 18.30062294], [82.38540649, 18.28909111], [82.3822403, 18.28429031], [82.37187958, 18.27410126], [82.3670578, 18.27094078], [82.34365082, 18.27165031], [82.3368988, 18.26624107], [82.33390045, 18.25229073], [82.33180237, 18.24679184], [82.33203888, 18.24012947], [82.33100891, 18.23336029], [82.33022308, 18.23134041], [82.32253265, 18.22812843], [82.32131958, 18.22245979], [82.32673645, 18.21623039], [82.33281708, 18.21578979], [82.31973267, 18.20104027], [82.30609894, 18.19565964], [82.30943298, 18.18938065], [82.30821991, 18.18128014], [82.31030273, 18.17460251], [82.31931305, 18.17143059], [82.32479095, 18.16641998], [82.33302307, 18.16341972], [82.34160614, 18.16343117], [82.34873199, 18.16183281], [82.35897827, 18.1491394], [82.36515808, 18.13966942], [82.36429596, 18.13485909], [82.361763, 18.12919807], [82.35756683, 18.12510109], [82.34487152, 18.13462067], [82.33825684, 18.13796043], [82.33336639, 18.14237976], [82.33535767, 18.1272583], [82.33030701, 18.11899948], [82.33248901, 18.10704994], [82.33216095, 18.09412193], [82.33466339, 18.08988762], [82.34055328, 18.08708954], [82.34316254, 18.08247948], [82.34362793, 18.07499123], [82.34194183, 18.07130051], [82.3431778, 18.0678196], [82.33692932, 18.04910088], [82.33634949, 18.04726028], [82.32977295, 18.040411], [82.32491302, 18.04269028], [82.3261795, 18.0465107], [82.32182312, 18.05018044], [82.31964874, 18.04857063], [82.31730652, 18.04853058], [82.31572723, 18.04668045], [82.31299591, 18.04519081], [82.3169632, 18.03602028], [82.31320953, 18.03475761], [82.30961609, 18.03842926], [82.30552673, 18.03780937], [82.30441284, 18.03961945], [82.30634308, 18.04499054], [82.30105591, 18.04404068], [82.2964859, 18.04614067], [82.29280853, 18.05433273], [82.29640198, 18.05755806], [82.29789734, 18.06196022], [82.28777313, 18.06056023], [82.28505707, 18.0594101], [82.28302765, 18.05577087], [82.27894592, 18.05492973], [82.26695251, 18.04827118], [82.2651062, 18.0430603], [82.26460266, 18.039011], [82.26220703, 18.03630066], [82.25815582, 18.03487015], [82.26624298, 18.02569008], [82.26893616, 18.01993942], [82.27081299, 18.01066971], [82.27052307, 17.9977417], [82.26885223, 17.99198914], [82.26725006, 17.98644066], [82.26107788, 17.98240089], [82.25318909, 17.98019028], [82.24170685, 17.97976112], [82.2383194, 17.98390007], [82.23699188, 17.99201012], [82.23079681, 17.99370956], [82.22297668, 17.99287987], [82.2181778, 17.99419022], [82.20775604, 18.00070953], [82.1969223, 18.00868988], [82.19101715, 18.00895119], [82.18508911, 18.00735283], [82.17740631, 18.01057053], [82.17424774, 18.01550293], [82.17694092, 18.02089119], [82.17314911, 18.0255928], [82.16374969, 18.04162025], [82.16034698, 18.04359818], [82.14730835, 18.04042053], [82.14229584, 18.04356956], [82.13237, 18.03561974], [82.13041687, 18.04090118], [82.12924194, 18.04866982], [82.12708282, 18.0510006], [82.1193161, 18.05120087], [82.11326599, 18.05782127], [82.11058807, 18.05766106], [82.10797882, 18.05401993], [82.09236145, 18.05276108], [82.0891571, 18.05741119], [82.08006287, 18.0604496], [82.07221222, 18.06563759], [82.06989288, 18.06043053], [82.06440735, 18.05837059], [82.05898285, 18.0584507], [82.06098938, 18.05398178], [82.06546783, 18.05130005], [82.06564331, 18.04891968], [82.0597229, 18.04511833], [82.05085754, 18.0444603], [82.04516602, 18.04558945], [82.03263855, 18.05171013], [82.02986145, 18.05653191], [82.0246582, 18.0578804], [82.01677704, 18.0551281], [82.00663757, 18.04919815], [82.00157928, 18.04481125], [82.00473022, 18.03430939], [82.00211334, 18.0282402], [82.0016861, 18.02366066], [81.99147797, 18.02182007], [81.98886108, 18.02034187], [81.98587799, 18.01427078], [81.98046112, 18.01128006], [81.97305298, 18.00567055], [81.96404266, 17.99986839], [81.95713043, 17.99707031], [81.95176697, 17.99209976], [81.93609619, 17.98409081], [81.92471313, 17.98088074], [81.91369629, 17.97989082], [81.90454865, 17.97347069], [81.89927673, 17.96854973], [81.88507843, 17.96583939], [81.87413788, 17.95984077], [81.84681702, 17.95079994], [81.83969879, 17.95006943], [81.83333588, 17.95103073], [81.81980133, 17.94546127], [81.80104065, 17.93608093], [81.79405212, 17.9296608], [81.7893219, 17.92136955], [81.78601074, 17.91361046], [81.7824173, 17.90974045], [81.77574921, 17.9047699], [81.76222229, 17.89658928], [81.75829315, 17.89336014]]], [[[86.26335144, 20.05805969], [86.26167297, 20.05639076], [86.26139069, 20.05639076], [86.26029205, 20.05528069], [86.26000214, 20.05528069], [86.25971985, 20.05500031], [86.2591629, 20.05500031], [86.25860596, 20.05445099], [86.2583313, 20.05445099], [86.25805664, 20.05417061], [86.25776672, 20.05417061], [86.25749969, 20.05389023], [86.25721741, 20.05389023], [86.25692749, 20.05360985], [86.25666809, 20.05361176], [86.2563858, 20.05333328], [86.25611115, 20.05333328], [86.25590515, 20.05312538], [86.25527954, 20.05249977], [86.25444794, 20.05251122], [86.25415802, 20.05221939], [86.25389099, 20.05251122], [86.25332642, 20.05251122], [86.25307465, 20.05224609], [86.2527771, 20.0522213], [86.25250244, 20.05194473], [86.25222015, 20.05194473], [86.2519455, 20.05166626], [86.25166321, 20.05167007], [86.25138855, 20.05138969], [86.2508316, 20.05138969], [86.25055695, 20.05166626], [86.25055695, 20.05221939], [86.25026703, 20.05251122], [86.25055695, 20.05277824], [86.25055695, 20.0530529], [86.25195313, 20.05445099], [86.25222015, 20.05444336], [86.25333405, 20.05555534], [86.2536087, 20.05555534], [86.25389099, 20.05583382], [86.25415802, 20.05583], [86.25444794, 20.05611038], [86.2547226, 20.05611038], [86.25499725, 20.05639076], [86.25527954, 20.05638885], [86.25583649, 20.05694389], [86.25611115, 20.05694389], [86.2563858, 20.05722237], [86.25669861, 20.05725288], [86.25692749, 20.05750084], [86.25721741, 20.05750084], [86.25749969, 20.05778122], [86.2583313, 20.05778122], [86.25860596, 20.05805969], [86.2591629, 20.05805779], [86.25944519, 20.05833244], [86.2611084, 20.05833244], [86.26166534, 20.05888748], [86.26249695, 20.05888748], [86.26335144, 20.05805969]]], [[[86.25305176, 20.02528], [86.25332642, 20.02499962], [86.25444794, 20.02499962], [86.2547226, 20.02472115], [86.25527954, 20.02472115], [86.25583649, 20.02416611], [86.25611115, 20.02416992], [86.2583313, 20.02193832], [86.25749969, 20.02111053], [86.25721741, 20.02139091], [86.25692749, 20.02139091], [86.25666809, 20.02166939], [86.2563858, 20.02166748], [86.25611115, 20.02194405], [86.2547226, 20.02194405], [86.25444794, 20.02222252], [86.25415802, 20.02220917], [86.2536087, 20.02277946], [86.25333405, 20.02277756], [86.25166321, 20.02444458], [86.25166321, 20.02472115], [86.25195313, 20.02472115], [86.25250244, 20.02528], [86.25305176, 20.02528]]], [[[86.30999756, 20.04083252], [86.31027985, 20.04055405], [86.31083679, 20.04057121], [86.31111145, 20.04027939], [86.3125, 20.04027939], [86.31276703, 20.04000092], [86.3133316, 20.04000092], [86.31360626, 20.03861046], [86.3133316, 20.03833008], [86.31083679, 20.03833008], [86.31054688, 20.03861046], [86.31027985, 20.03861046], [86.30999756, 20.03889084], [86.30916595, 20.03889084], [86.3088913, 20.0391674], [86.3088913, 20.03972054], [86.30944824, 20.04027939], [86.30944824, 20.04055405], [86.3097229, 20.04083252], [86.30999756, 20.04083252]]], [[[86.32027435, 20.02944374], [86.32055664, 20.02916527], [86.32098389, 20.0291729], [86.32130432, 20.02913666], [86.32160187, 20.02897835], [86.32196045, 20.02890015], [86.32235718, 20.02882957], [86.32271576, 20.02861786], [86.32305908, 20.02833939], [86.32417297, 20.02721977], [86.32416534, 20.02694321], [86.32444763, 20.02667046], [86.32444763, 20.02639008], [86.32554626, 20.02528], [86.32583618, 20.02528], [86.32666779, 20.02444267], [86.32666779, 20.02416611], [86.32640076, 20.02388954], [86.3263855, 20.02361107], [86.32583618, 20.02305603], [86.32527924, 20.02305984], [86.32417297, 20.02193832], [86.32334137, 20.02193832], [86.32221985, 20.02305603], [86.32213593, 20.02330017], [86.32190704, 20.02361107], [86.32157898, 20.02390099], [86.32125854, 20.0241909], [86.32095337, 20.02449989], [86.3207016, 20.02482986], [86.32055664, 20.02524567], [86.32042694, 20.02565956], [86.3203125, 20.02607918], [86.32026672, 20.02650642], [86.32022095, 20.02695656], [86.32021332, 20.02742958], [86.32019043, 20.0279007], [86.31999969, 20.02833366], [86.31973267, 20.02861023], [86.31972504, 20.02916527], [86.31999969, 20.02944374], [86.32027435, 20.02944374]]], [[[86.26583099, 20.0336113], [86.26611328, 20.03333282], [86.26638794, 20.03333282], [86.26667023, 20.03305626], [86.26693726, 20.03305817], [86.26721954, 20.03277969], [86.26750183, 20.03277969], [86.26777649, 20.03250122], [86.26832581, 20.03250122], [86.26832581, 20.0313797], [86.26777649, 20.0308342], [86.26750183, 20.0308342], [86.26721954, 20.03055763], [86.26694489, 20.03055763], [86.26667023, 20.0308342], [86.26638794, 20.03083038], [86.26609802, 20.03111076], [86.26555634, 20.03111076], [86.26527405, 20.03138733], [86.26416779, 20.0313797], [86.26389313, 20.03166962], [86.26333618, 20.0316658], [86.26305389, 20.03194427], [86.26277924, 20.03194427], [86.26249695, 20.03222084], [86.26333618, 20.03305626], [86.26305389, 20.03333282], [86.26333618, 20.0336113], [86.26583099, 20.0336113]]], [[[86.27249908, 20.02444458], [86.27194214, 20.02388954], [86.27166748, 20.02388954], [86.26972198, 20.02193832], [86.26944733, 20.02222252], [86.26833344, 20.02111053], [86.26805878, 20.02111053], [86.26777649, 20.02082825], [86.26667023, 20.02082825], [86.26583099, 20.02166939], [86.26527405, 20.02166748], [86.2647171, 20.02220917], [86.2647171, 20.02277946], [86.26555634, 20.02361107], [86.26583099, 20.02361107], [86.26609802, 20.02388954], [86.26638794, 20.02388954], [86.26667023, 20.02416992], [86.26694489, 20.02416611], [86.26721954, 20.02444458], [86.26805878, 20.02444458], [86.26833344, 20.02472115], [86.26860809, 20.02472115], [86.26944733, 20.02555466], [86.26944733, 20.02583313], [86.27083588, 20.02722168], [86.27138519, 20.02722168], [86.27194214, 20.02666664], [86.27194214, 20.02639008], [86.27249908, 20.02583122], [86.27249908, 20.02527809], [86.27278137, 20.02499962], [86.27249908, 20.02472115], [86.27249908, 20.02444458]]], [[[86.28814697, 20.02861023], [86.28749847, 20.02861023], [86.28723145, 20.02833939], [86.28666687, 20.02833939], [86.28639221, 20.02861023], [86.28555298, 20.02861023], [86.28527832, 20.02833939], [86.28472137, 20.02833939], [86.28444672, 20.02806091], [86.28417206, 20.02806091], [86.2840271, 20.02791786], [86.28388977, 20.02778053], [86.28333282, 20.02778053], [86.28305817, 20.02750015], [86.28221893, 20.02750015], [86.28193665, 20.02721977], [86.28055573, 20.02722168], [86.28028107, 20.02694321], [86.27999878, 20.02695084], [86.27971649, 20.02667046], [86.27889252, 20.02667046], [86.27861023, 20.02695084], [86.27833557, 20.02694321], [86.27803802, 20.02721977], [86.27803802, 20.02806091], [86.27835083, 20.02833939], [86.27803802, 20.02861023], [86.27803802, 20.02889061], [86.27777863, 20.02916527], [86.27777863, 20.02943993], [86.27722168, 20.03000069], [86.27610779, 20.03000069], [86.27583313, 20.02972031], [86.27443695, 20.02972031], [86.27416992, 20.03000069], [86.27388763, 20.03000069], [86.27361298, 20.03028107], [86.27333069, 20.03028107], [86.27249908, 20.03111076], [86.27249908, 20.0313797], [86.27222443, 20.0316658], [86.27222443, 20.03194427], [86.27194214, 20.03222084], [86.27194214, 20.03250122], [86.27138519, 20.03305626], [86.27111053, 20.03333282], [86.26999664, 20.03333092], [86.26944733, 20.03388977], [86.26915741, 20.03388977], [86.26889038, 20.03417015], [86.26860809, 20.03416634], [86.26805878, 20.03472137], [86.26777649, 20.03472137], [86.26750183, 20.03500175], [86.26721954, 20.03500175], [86.26693726, 20.03528023], [86.26638794, 20.03528023], [86.26609802, 20.03500175], [86.26555634, 20.03500175], [86.26526642, 20.03472137], [86.26444244, 20.03472137], [86.26416779, 20.03500175], [86.26305389, 20.03500175], [86.26277924, 20.03472137], [86.26249695, 20.03472137], [86.26222229, 20.03444481], [86.26083374, 20.03444481], [86.26008606, 20.03369904], [86.25971985, 20.03333282], [86.25944519, 20.03333282], [86.2591629, 20.03305626], [86.25888824, 20.03305817], [86.2583313, 20.03250122], [86.25805664, 20.03250122], [86.25776672, 20.03222084], [86.25749969, 20.03222275], [86.25694275, 20.0316658], [86.2563858, 20.03166962], [86.25630951, 20.0315876], [86.25611115, 20.0313797], [86.25583649, 20.03138733], [86.2555542, 20.03111076], [86.25527954, 20.03111076], [86.25499725, 20.03083038], [86.2547226, 20.0308342], [86.25389099, 20.03000069], [86.25389099, 20.02972031], [86.25222015, 20.02972221], [86.25195313, 20.03000069], [86.25138855, 20.03000069], [86.25112152, 20.02972031], [86.2508316, 20.02972031], [86.25026703, 20.03028107], [86.25, 20.03028107], [86.24964905, 20.03026962], [86.24923706, 20.03027153], [86.24887085, 20.03023148], [86.24854279, 20.03004074], [86.24819946, 20.02980042], [86.24781799, 20.02927017], [86.24740601, 20.02885818], [86.2470932, 20.02891922], [86.24677277, 20.02907181], [86.24637604, 20.02907181], [86.24591064, 20.02891922], [86.24568176, 20.02902985], [86.24546051, 20.02917099], [86.24523163, 20.02935982], [86.24499512, 20.02956963], [86.24476624, 20.02981949], [86.24459076, 20.03013611], [86.24446869, 20.03046989], [86.24447632, 20.03079987], [86.24465942, 20.03108025], [86.24472046, 20.0313797], [86.24472046, 20.03170967], [86.24472046, 20.03208923], [86.24472046, 20.03255844], [86.24472046, 20.03310204], [86.24472046, 20.03368378], [86.24475861, 20.03425217], [86.24488068, 20.03473282], [86.24498749, 20.0352211], [86.24505615, 20.03570175], [86.24524689, 20.03616905], [86.24541473, 20.03666496], [86.24556732, 20.03713036], [86.24578857, 20.03750992], [86.2459259, 20.03784943], [86.24610901, 20.03812027], [86.24629211, 20.03839111], [86.24645996, 20.03868294], [86.24665833, 20.03897095], [86.24684143, 20.03926086], [86.24697113, 20.03963089], [86.24716949, 20.03993607], [86.24742126, 20.04024124], [86.24767303, 20.04057121], [86.24787903, 20.04088974], [86.24806976, 20.04122162], [86.24828339, 20.04150963], [86.24846649, 20.04181099], [86.2486496, 20.04210854], [86.24886322, 20.04236794], [86.24903107, 20.04269028], [86.24919891, 20.04306984], [86.24947357, 20.04341125], [86.24987793, 20.04373169], [86.25028992, 20.0440712], [86.25076294, 20.04440498], [86.25123596, 20.0447197], [86.25170135, 20.04502678], [86.25215912, 20.04529953], [86.25250244, 20.04556084], [86.25305176, 20.04555511], [86.2538681, 20.04636955], [86.25416565, 20.0466671], [86.25415802, 20.04721832], [86.25444794, 20.04750061], [86.25444794, 20.04861069], [86.2547226, 20.04888916], [86.25485229, 20.04929924], [86.25502014, 20.04965973], [86.25525665, 20.04999161], [86.25550079, 20.05034256], [86.25575256, 20.05072975], [86.25610352, 20.05112076], [86.25653839, 20.05153084], [86.25704193, 20.05195999], [86.25754547, 20.05238533], [86.2580719, 20.05276108], [86.25862122, 20.0530529], [86.25915527, 20.05331802], [86.25971985, 20.05360985], [86.25971985, 20.05389023], [86.26000214, 20.05417061], [86.26029205, 20.05417061], [86.26055908, 20.05445099], [86.26082611, 20.05445099], [86.26148224, 20.05509567], [86.26167297, 20.05528069], [86.26194763, 20.05528069], [86.26249695, 20.05471992], [86.26277924, 20.05472183], [86.26305389, 20.05444336], [86.26335144, 20.05445099], [86.26361084, 20.05417061], [86.26389313, 20.05417061], [86.26444244, 20.05360985], [86.26499939, 20.05416679], [86.26555634, 20.05471992], [86.26555634, 20.05500031], [86.26499939, 20.05554962], [86.26499939, 20.05611038], [86.26526642, 20.05639076], [86.26526642, 20.05667114], [86.26638794, 20.05778122], [86.26667023, 20.05778122], [86.26693726, 20.05805969], [86.26833344, 20.05805779], [86.26860809, 20.05833244], [86.26999664, 20.05833244], [86.27027893, 20.05805779], [86.26999664, 20.05778122], [86.26999664, 20.05722046], [86.27027893, 20.05694389], [86.27027893, 20.05638885], [86.26915741, 20.05528069], [86.26889038, 20.05528069], [86.26832581, 20.05471992], [86.26805878, 20.05472183], [86.26777649, 20.05444336], [86.26750183, 20.05445099], [86.26721954, 20.05417061], [86.26721954, 20.05332947], [86.26750183, 20.05305481], [86.26777649, 20.05305481], [86.26805878, 20.05333328], [86.26833344, 20.05333328], [86.26860809, 20.05361176], [86.26916504, 20.05305481], [86.26972198, 20.05277824], [86.27054596, 20.05194283], [86.27083588, 20.05194283], [86.27166748, 20.05277824], [86.27166748, 20.05305481], [86.27194214, 20.05332947], [86.27194214, 20.05389023], [86.27223206, 20.05417061], [86.27223206, 20.05445099], [86.27278137, 20.05500031], [86.27305603, 20.05500031], [86.27333069, 20.05528069], [86.27361298, 20.05500031], [86.27388763, 20.05500031], [86.27500153, 20.05389023], [86.27500153, 20.05360985], [86.27444458, 20.05305481], [86.27444458, 20.05277824], [86.27471924, 20.05251122], [86.27480316, 20.05246735], [86.2750473, 20.05234146], [86.27539063, 20.05221367], [86.27577972, 20.05204964], [86.27620697, 20.05185127], [86.27679443, 20.05198479], [86.27719116, 20.05185699], [86.27749634, 20.05164909], [86.277771, 20.05138969], [86.27800751, 20.05115128], [86.27828217, 20.05101967], [86.27854919, 20.0508709], [86.27892303, 20.05078888], [86.27929688, 20.0505619], [86.27973175, 20.05030251], [86.28016663, 20.0500164], [86.28058624, 20.0497303], [86.28096008, 20.04946327], [86.28128052, 20.04923058], [86.2816391, 20.04912949], [86.28192902, 20.04894066], [86.28232574, 20.04886246], [86.28276062, 20.04875183], [86.28320313, 20.04857826], [86.28363037, 20.04834175], [86.28410339, 20.04809952], [86.28465271, 20.04792976], [86.28514099, 20.04764938], [86.2856369, 20.04740524], [86.28605652, 20.04710388], [86.28630829, 20.04659843], [86.28675079, 20.04648972], [86.28723145, 20.046381], [86.28749847, 20.04611206], [86.28749847, 20.04527664], [86.28723145, 20.04499817], [86.28749847, 20.0447216], [86.28778076, 20.0447216], [86.28805542, 20.04444695], [86.28916931, 20.04445076], [86.28943634, 20.04417038], [86.28971863, 20.04417038], [86.29000092, 20.04388809], [86.29000092, 20.0433197], [86.29055786, 20.04277611], [86.29083252, 20.0430603], [86.29111481, 20.0430584], [86.29138947, 20.0433197], [86.29138947, 20.04445076], [86.29250336, 20.04556084], [86.29277802, 20.04556084], [86.29303741, 20.04528046], [86.29332733, 20.04528046], [86.29360962, 20.04499817], [86.29389191, 20.04499817], [86.29444122, 20.04445076], [86.29471588, 20.04445076], [86.29611206, 20.0430603], [86.29638672, 20.0430603], [86.29666901, 20.04277992], [86.29666901, 20.04249954], [86.29750061, 20.04166985], [86.29750061, 20.04111099], [86.29722595, 20.04083061], [86.29722595, 20.04055405], [86.29693604, 20.04027939], [86.29693604, 20.04000092], [86.29666901, 20.03972054], [86.29777527, 20.03861046], [86.29888916, 20.03861046], [86.29917145, 20.03833008], [86.30000305, 20.03833389], [86.30027771, 20.03805542], [86.30082703, 20.03806114], [86.30110931, 20.03778076], [86.30194092, 20.03778076], [86.30223083, 20.03750992], [86.30249786, 20.03750992], [86.30304718, 20.03695107], [86.3033371, 20.03695107], [86.30361176, 20.03667068], [86.30388641, 20.03667068], [86.3041687, 20.0363903], [86.30500031, 20.0363903], [86.30526733, 20.03611183], [86.30555725, 20.03611183], [86.3061142, 20.03555489], [86.30638885, 20.03555489], [86.30666351, 20.03527832], [86.30722046, 20.03528023], [86.3077774, 20.03472137], [86.30805206, 20.03472137], [86.30805206, 20.03444481], [86.30722046, 20.0336113], [86.3069458, 20.0336113], [86.3067627, 20.03342819], [86.30638885, 20.03305626], [86.30583191, 20.03305817], [86.30526733, 20.03250122], [86.30444336, 20.03250122], [86.30388641, 20.03305817], [86.30361176, 20.03277969], [86.3033371, 20.03277969], [86.30304718, 20.03250122], [86.30278015, 20.03250122], [86.30166626, 20.0313797], [86.30110931, 20.03194427], [86.30055237, 20.03194427], [86.29944611, 20.0308342], [86.29916382, 20.0308342], [86.29805756, 20.02972221], [86.29805756, 20.02944374], [86.29777527, 20.02916527], [86.29722595, 20.02916527], [86.29666901, 20.02972031], [86.29666901, 20.03000069], [86.29638672, 20.03028107], [86.29582977, 20.03028107], [86.29528046, 20.02972031], [86.29499817, 20.02972221], [86.29490662, 20.02962875], [86.29472351, 20.02944374], [86.29166412, 20.02944374], [86.29138947, 20.02916527], [86.29055786, 20.02917099], [86.29029083, 20.02889061], [86.29000092, 20.02889061], [86.28971863, 20.02861023], [86.28916931, 20.02861023], [86.28888702, 20.02889061], [86.28861237, 20.02861023], [86.28814697, 20.02861023]]], [[[86.30055237, 20.04249954], [86.30082703, 20.04222107], [86.30110931, 20.04222298], [86.30305481, 20.04027748], [86.3033371, 20.04027939], [86.30388641, 20.03972054], [86.3033371, 20.0391674], [86.3033371, 20.03889084], [86.30304718, 20.03861046], [86.30249786, 20.03861046], [86.30223083, 20.03889084], [86.3013916, 20.03889084], [86.30110931, 20.03917122], [86.30083466, 20.0391674], [86.30055237, 20.03944206], [86.30027771, 20.03944206], [86.30000305, 20.03972244], [86.29972076, 20.03972054], [86.29917145, 20.04027939], [86.29916382, 20.04055405], [86.29888916, 20.04083061], [86.29888916, 20.04111099], [86.29860687, 20.04138947], [86.2986145, 20.04166412], [86.29891205, 20.04196739], [86.29916382, 20.04222298], [86.29946136, 20.04222107], [86.29972076, 20.04249954], [86.30055237, 20.04249954]]], [[[86.29499817, 20.04972267], [86.29555511, 20.04916573], [86.29582977, 20.04916573], [86.29638672, 20.04972267], [86.29694366, 20.04972267], [86.29833221, 20.04833412], [86.29833221, 20.04805565], [86.29860687, 20.04777908], [86.29860687, 20.04750061], [86.29888916, 20.04721832], [86.29888916, 20.04694366], [86.29916382, 20.0466671], [86.29917145, 20.046381], [86.29944611, 20.04611206], [86.29944611, 20.04583359], [86.29972076, 20.04555511], [86.29972076, 20.04528046], [86.30027771, 20.0447197], [86.30027771, 20.04444695], [86.29972076, 20.04388809], [86.29888916, 20.04388809], [86.29833221, 20.04445076], [86.29805756, 20.04445076], [86.29750061, 20.04499817], [86.29722595, 20.04499817], [86.29693604, 20.04528046], [86.29638672, 20.04528046], [86.29611206, 20.04556084], [86.29582977, 20.04555511], [86.29555511, 20.04583359], [86.29528046, 20.04583359], [86.29499817, 20.04611206], [86.29472351, 20.04611206], [86.29444122, 20.04639053], [86.29416656, 20.046381], [86.29389191, 20.04667091], [86.29333496, 20.0466671], [86.29305267, 20.04694366], [86.29222107, 20.04694366], [86.29194641, 20.04722214], [86.29165649, 20.04721832], [86.29110718, 20.04777908], [86.29110718, 20.04861069], [86.29083252, 20.04889107], [86.29111481, 20.04916573], [86.29110718, 20.04972267], [86.29165649, 20.05027962], [86.29250336, 20.05027962], [86.29277802, 20.05055618], [86.29277802, 20.05083275], [86.29389191, 20.05083275], [86.29499817, 20.04972267]]], [[[86.78972626, 20.38760948], [86.78939819, 20.38754082], [86.78897858, 20.3877697], [86.78904724, 20.38815117], [86.7891922, 20.38869095], [86.7891922, 20.38923073], [86.78904724, 20.38997269], [86.78911591, 20.39059258], [86.78916168, 20.39103127], [86.78910828, 20.39144516], [86.78897858, 20.39182091], [86.78890228, 20.39217758], [86.78888702, 20.39252281], [86.78888702, 20.39285851], [86.78894043, 20.39317894], [86.78910065, 20.39346123], [86.78917694, 20.3937912], [86.78927612, 20.39413261], [86.78942108, 20.39447975], [86.78951263, 20.39485931], [86.78967285, 20.39520836], [86.78971863, 20.39558411], [86.78972626, 20.39596939], [86.78972626, 20.39638519], [86.78972626, 20.39682961], [86.78972626, 20.39731979], [86.78972626, 20.39782906], [86.78972626, 20.39836121], [86.78972626, 20.39888954], [86.79000092, 20.40018082], [86.78979492, 20.40098953], [86.78929138, 20.40200043], [86.78879547, 20.40301514], [86.78858185, 20.40389252], [86.78779602, 20.4050808], [86.78788757, 20.4056263], [86.78806305, 20.40611076], [86.78833008, 20.40639114], [86.78833008, 20.4066658], [86.78861237, 20.40694046], [86.78861237, 20.40777969], [86.78943634, 20.40860939], [86.78943634, 20.40889168], [86.78971863, 20.40916634], [86.78971863, 20.40944481], [86.79000092, 20.40971947], [86.79000092, 20.41055489], [86.7902832, 20.41082954], [86.7902832, 20.41167068], [86.79055786, 20.41195107], [86.79055786, 20.41278076], [86.7902832, 20.41306114], [86.7902832, 20.41389084], [86.79000092, 20.41417122], [86.79000092, 20.41527939], [86.789711, 20.41555977], [86.78971863, 20.41611099], [86.79027557, 20.41666412], [86.79000092, 20.41694069], [86.79000092, 20.41749954], [86.78971863, 20.41777611], [86.789711, 20.4197197], [86.79000092, 20.41999817], [86.79000092, 20.42110825], [86.7902832, 20.42139053], [86.79027557, 20.4216671], [86.79000092, 20.42193985], [86.79000092, 20.42416573], [86.7902832, 20.42444038], [86.7902832, 20.42500114], [86.79000092, 20.42527771], [86.79000092, 20.42583466], [86.79027557, 20.42611122], [86.7902832, 20.42638969], [86.7904129, 20.42679977], [86.79057312, 20.42728043], [86.79083252, 20.42777824], [86.79055786, 20.42805481], [86.79055786, 20.42860031], [86.79083252, 20.42888641], [86.79110718, 20.42917061], [86.79138947, 20.42917061], [86.79151154, 20.42904663], [86.79194641, 20.42861176], [86.79194641, 20.42833328], [86.79222107, 20.42805481], [86.79222107, 20.42777824], [86.79250336, 20.42749977], [86.79250336, 20.42721939], [86.79277802, 20.42694473], [86.79277802, 20.42666626], [86.79305267, 20.42638969], [86.79305267, 20.42611122], [86.79332733, 20.42583275], [86.79332733, 20.42534637], [86.79332733, 20.42494011], [86.79335785, 20.42450333], [86.79345703, 20.42404556], [86.79358673, 20.4235611], [86.79360962, 20.42305756], [86.79360962, 20.42255974], [86.79361725, 20.42210007], [86.79366302, 20.42168045], [86.79380035, 20.42128944], [86.79383087, 20.42088127], [86.79366302, 20.42042923], [86.7935791, 20.41996765], [86.79344177, 20.41953087], [86.79335022, 20.41909981], [86.79332733, 20.41868019], [86.79333496, 20.41829872], [86.79332733, 20.4179306], [86.79338074, 20.41757011], [86.79354095, 20.41726112], [86.79366302, 20.41692734], [86.79386902, 20.41661835], [86.79402161, 20.41625023], [86.79413605, 20.41584778], [86.79416656, 20.41537094], [86.79416656, 20.41484261], [86.79421997, 20.41428947], [86.79440308, 20.41380119], [86.79444122, 20.4133091], [86.79445648, 20.41286087], [86.79454041, 20.41242981], [86.79467773, 20.41201973], [86.79467773, 20.41156006], [86.7946167, 20.41106987], [86.79476929, 20.41048241], [86.79454803, 20.41004944], [86.79415894, 20.40966034], [86.79389954, 20.40917015], [86.79370117, 20.40864754], [86.79344177, 20.40813065], [86.79329681, 20.40752029], [86.79309845, 20.40691185], [86.79305267, 20.40626144], [86.79302216, 20.40561104], [86.79289246, 20.40496254], [86.79283905, 20.40431976], [86.79297638, 20.40367126], [86.79305267, 20.40303993], [86.79305267, 20.40245438], [86.7930603, 20.40193367], [86.79310608, 20.40147781], [86.79328156, 20.40107918], [86.79332733, 20.40065956], [86.79332733, 20.40023994], [86.79332733, 20.3998394], [86.79338074, 20.39947128], [86.79354095, 20.3991375], [86.79354095, 20.39874268], [86.7935791, 20.39835739], [86.79358673, 20.39817047], [86.79360199, 20.39796829], [86.79360962, 20.39760017], [86.79361725, 20.39723969], [86.79368591, 20.39690971], [86.79384613, 20.39658928], [86.79396057, 20.3962307], [86.79412079, 20.39587593], [86.79418945, 20.39549446], [86.79436493, 20.39511299], [86.79473114, 20.39473343], [86.7951889, 20.39431763], [86.79535675, 20.39381981], [86.79534149, 20.39335251], [86.79470825, 20.39292145], [86.79428864, 20.39253044], [86.79412079, 20.39211273], [86.79395294, 20.3916893], [86.7938385, 20.39120865], [86.79360962, 20.39076805], [86.79334259, 20.39033127], [86.79308319, 20.38990021], [86.79281616, 20.38952065], [86.79251099, 20.38927078], [86.79220581, 20.38904953], [86.79193115, 20.38886261], [86.79168701, 20.38865089], [86.79141998, 20.38849068], [86.79116821, 20.38829613], [86.79087067, 20.38805008], [86.7904129, 20.3877964], [86.78972626, 20.38760948]]], [[[86.79805756, 20.69194221], [86.79784393, 20.69030571], [86.79763031, 20.68982124], [86.79763031, 20.68922615], [86.79727936, 20.68862152], [86.79656982, 20.6878109], [86.79577637, 20.68558121], [86.79528046, 20.68416786], [86.79528046, 20.68388939], [86.79499817, 20.68361092], [86.79499817, 20.68333054], [86.79472351, 20.68305588], [86.79471588, 20.68278122], [86.79444122, 20.68250084], [86.79444122, 20.68222046], [86.79416656, 20.6819458], [86.79416656, 20.68166733], [86.79389191, 20.68139076], [86.79389191, 20.68083], [86.79360962, 20.68055534], [86.79360962, 20.68028069], [86.79332733, 20.68000031], [86.79332733, 20.67971992], [86.79305267, 20.67944527], [86.79305267, 20.67917061], [86.79250336, 20.67861176], [86.79250336, 20.67833138], [86.79222107, 20.67805481], [86.79222107, 20.67777824], [86.79110718, 20.67667007], [86.79110718, 20.6763916], [86.79083252, 20.67610931], [86.79055786, 20.67583084], [86.79016876, 20.67534065], [86.78967285, 20.67493057], [86.78924561, 20.67513847], [86.78924561, 20.67689133], [86.78931427, 20.67824173], [86.78931427, 20.67925262], [86.78943634, 20.68083], [86.789711, 20.68111038], [86.789711, 20.68278122], [86.79000092, 20.68305588], [86.79000092, 20.68333244], [86.79027557, 20.68361092], [86.7902832, 20.68388939], [86.79055786, 20.68416977], [86.79055786, 20.68499947], [86.79083252, 20.68527985], [86.79083252, 20.68555641], [86.79111481, 20.68583298], [86.79110718, 20.68610954], [86.79138947, 20.68638992], [86.79138947, 20.68694496], [86.79166412, 20.68722153], [86.79165649, 20.68749046], [86.79194641, 20.68778038], [86.79194641, 20.68805504], [86.79222107, 20.68833351], [86.79222107, 20.68860817], [86.79277802, 20.68916702], [86.79277802, 20.68971825], [86.79305267, 20.69000244], [86.79305267, 20.69055557], [86.79332733, 20.69083023], [86.79332733, 20.69111252], [86.79360962, 20.6913929], [86.79389191, 20.69138908], [86.79389191, 20.69194221], [86.79416656, 20.6922226], [86.79416656, 20.69277763], [86.79471588, 20.69333076], [86.79471588, 20.69388962], [86.79499817, 20.69416618], [86.79499817, 20.69444466], [86.79528046, 20.69472313], [86.79528046, 20.69582939], [86.79582977, 20.69638824], [86.7958374, 20.69721985], [86.79638672, 20.69778061], [86.79638672, 20.69806099], [86.79693604, 20.69861031], [86.79694366, 20.69888878], [86.79750061, 20.69944382], [86.79750061, 20.69972038], [86.79833221, 20.70055962], [86.79860687, 20.70055962], [86.79915619, 20.70000076], [86.79915619, 20.69972038], [86.79888916, 20.69944382], [86.79854584, 20.69907761], [86.79847717, 20.69861031], [86.79847717, 20.69684982], [86.79854584, 20.69617653], [86.79840851, 20.69495964], [86.79833221, 20.69416618], [86.79833221, 20.6922226], [86.79805756, 20.69194221]]], [[[86.80426788, 20.67662048], [86.80347443, 20.67656708], [86.80271149, 20.67645073], [86.80207825, 20.67624092], [86.80153656, 20.67603111], [86.80103302, 20.67583275], [86.80051422, 20.67566872], [86.80008698, 20.67547035], [86.79971313, 20.67526627], [86.79932404, 20.67507362], [86.7990036, 20.67481995], [86.7986908, 20.67455101], [86.79833984, 20.6742897], [86.79805756, 20.67416954], [86.79805756, 20.67388916], [86.79666901, 20.67250824], [86.79666901, 20.67222023], [86.79638672, 20.67194366], [86.79638672, 20.67166519], [86.7958374, 20.67111015], [86.79582977, 20.67083359], [86.79555511, 20.67055511], [86.79556274, 20.67000008], [86.79528046, 20.6697216], [86.79528046, 20.66916656], [86.79499817, 20.66889], [86.79499817, 20.66860962], [86.79528046, 20.66833305], [86.79528046, 20.66749954], [86.79499817, 20.66722107], [86.79528046, 20.6669445], [86.79528046, 20.66638947], [86.79541016, 20.66562271], [86.79575348, 20.66504669], [86.7961731, 20.6645298], [86.79666138, 20.66414833], [86.79712677, 20.6638298], [86.79750824, 20.6635704], [86.79788971, 20.66345978], [86.79823303, 20.66348267], [86.79852295, 20.66362953], [86.79876709, 20.66389275], [86.79904938, 20.66423798], [86.7993927, 20.66460419], [86.79981232, 20.66493988], [86.80021667, 20.66529846], [86.80056763, 20.66570282], [86.80088043, 20.6661396], [86.8012085, 20.66655731], [86.80156708, 20.6668911], [86.80197144, 20.66716957], [86.80243683, 20.66739082], [86.80304718, 20.66754723], [86.80374908, 20.66757393], [86.80437469, 20.6674881], [86.80491638, 20.66739082], [86.80545044, 20.66732025], [86.80593109, 20.66732979], [86.80609894, 20.66729736], [86.806427, 20.66723061], [86.80691528, 20.66712379], [86.80737305, 20.66693687], [86.80784607, 20.66673279], [86.8083725, 20.66652107], [86.80885315, 20.66620064], [86.80931854, 20.66584015], [86.80982208, 20.66546822], [86.81030273, 20.66508484], [86.81079102, 20.66470909], [86.81124115, 20.66431046], [86.81167603, 20.66390038], [86.81213379, 20.66351891], [86.81253815, 20.66311073], [86.81295013, 20.66275024], [86.81335449, 20.66238976], [86.81363678, 20.66194916], [86.81391144, 20.66150093], [86.8141861, 20.66106033], [86.81443787, 20.66059113], [86.81469727, 20.66012955], [86.81494141, 20.65971184], [86.81512451, 20.65933037], [86.81526947, 20.65901947], [86.81539917, 20.65875816], [86.81550598, 20.65853119], [86.81562042, 20.65826988], [86.81573486, 20.65799713], [86.81582642, 20.65768051], [86.81597137, 20.65737915], [86.8161087, 20.6570797], [86.81628418, 20.65678215], [86.8164444, 20.65642357], [86.81664276, 20.65605164], [86.81684113, 20.65566063], [86.81698608, 20.65526009], [86.81717682, 20.65488815], [86.81741333, 20.65450287], [86.81768036, 20.65407944], [86.81793976, 20.65364647], [86.81817627, 20.65316963], [86.81841278, 20.65270996], [86.8186264, 20.65229988], [86.81884766, 20.65193176], [86.81912231, 20.65155983], [86.81945801, 20.65113068], [86.81984711, 20.65065956], [86.82021332, 20.65014267], [86.82052612, 20.64965057], [86.82080841, 20.6491909], [86.82106018, 20.64877701], [86.82129669, 20.64836121], [86.8215332, 20.64795494], [86.82171631, 20.64752007], [86.82186127, 20.64706993], [86.8219223, 20.64660835], [86.82195282, 20.64614105], [86.82194519, 20.64571381], [86.8219223, 20.64530182], [86.82186127, 20.64492035], [86.82176208, 20.64455032], [86.82157898, 20.64413261], [86.82139587, 20.6436615], [86.82115936, 20.64320374], [86.82089233, 20.64274597], [86.82063293, 20.64228058], [86.82039642, 20.64183044], [86.82022095, 20.64142036], [86.82003784, 20.64105988], [86.81984711, 20.64068985], [86.81968689, 20.64031792], [86.81954193, 20.63992119], [86.81935883, 20.6395607], [86.81912231, 20.63924217], [86.81880188, 20.63892555], [86.81842804, 20.63858032], [86.81800842, 20.63826942], [86.81755066, 20.63803101], [86.81707001, 20.63788033], [86.8165741, 20.6378727], [86.81616974, 20.63780022], [86.81581879, 20.63775826], [86.81547546, 20.63776779], [86.81510925, 20.63784027], [86.81472778, 20.63803101], [86.81428528, 20.63824844], [86.81376648, 20.63848305], [86.81324768, 20.63878059], [86.81280518, 20.63917923], [86.81241608, 20.63961029], [86.81204987, 20.64003754], [86.8117218, 20.64045906], [86.81140137, 20.6408577], [86.81109619, 20.64125061], [86.81079102, 20.64165306], [86.81045532, 20.64203262], [86.810112, 20.64237022], [86.80969238, 20.64268494], [86.80921936, 20.64300156], [86.80874634, 20.64335442], [86.8082962, 20.64373016], [86.80786896, 20.64409065], [86.80745697, 20.64443588], [86.80700684, 20.64471245], [86.80652618, 20.64493942], [86.80610657, 20.64500046], [86.80583191, 20.64528084], [86.80500031, 20.64528084], [86.80371094, 20.64500046], [86.8024292, 20.64487076], [86.80082703, 20.64500046], [86.80027771, 20.6455555], [86.80027771, 20.64583015], [86.80000305, 20.64611053], [86.79611206, 20.64611053], [86.79437256, 20.64603806], [86.79401398, 20.64583397], [86.79305267, 20.64583015], [86.79277802, 20.64611053], [86.79250336, 20.64611053], [86.79222107, 20.64583015], [86.79111481, 20.64583397], [86.79083252, 20.6455555], [86.79055786, 20.64557076], [86.7902832, 20.64528084], [86.789711, 20.64528084], [86.78943634, 20.64500046], [86.78888702, 20.64500046], [86.78861237, 20.64472008], [86.78694153, 20.64472198], [86.78666687, 20.64444351], [86.78583527, 20.64444351], [86.78562927, 20.64424133], [86.78555298, 20.64416695], [86.78472137, 20.64416695], [86.78444672, 20.64444351], [86.78360748, 20.64444351], [86.78333282, 20.64472198], [86.78305817, 20.64472008], [86.78277588, 20.64500046], [86.78277588, 20.64528084], [86.78250122, 20.64557076], [86.78166962, 20.6455555], [86.78138733, 20.64583397], [86.78056335, 20.64583015], [86.78028107, 20.64611053], [86.77971649, 20.64611053], [86.77944183, 20.64639091], [86.77889252, 20.64639091], [86.77861023, 20.64666748], [86.77805328, 20.64666748], [86.77777863, 20.64694405], [86.77749634, 20.64694405], [86.77722168, 20.64666748], [86.77694702, 20.64666748], [86.7766571, 20.64639091], [86.77602386, 20.64639473], [86.77523804, 20.64618874], [86.77459717, 20.64639091], [86.77379608, 20.6463871], [86.77394104, 20.64672279], [86.77429962, 20.64744949], [86.77416992, 20.64805984], [86.77416992, 20.64834023], [86.77471161, 20.64889145], [86.77471924, 20.64916611], [86.77527618, 20.64971924], [86.77527618, 20.65000153], [86.77555847, 20.65027809], [86.77555847, 20.65082932], [86.77639008, 20.65167046], [86.77639008, 20.65195084], [86.77805328, 20.65361023], [86.77805328, 20.65389061], [86.77833557, 20.65416718], [86.7783432, 20.65443993], [86.77889252, 20.65500069], [86.77889252, 20.65528107], [86.77916718, 20.65555573], [86.77916718, 20.65583038], [86.78111267, 20.65777969], [86.78138733, 20.65777779], [86.78194427, 20.65833282], [86.78250122, 20.65833092], [86.78916931, 20.66500282], [86.78916931, 20.66527748], [86.789711, 20.66583061], [86.789711, 20.6661129], [86.79000092, 20.6661129], [86.79000092, 20.66638947], [86.79055786, 20.66694069], [86.79055786, 20.66749954], [86.79194641, 20.66889], [86.79194641, 20.66916656], [86.79250336, 20.6697197], [86.79250336, 20.67000008], [86.79277802, 20.67028046], [86.79277802, 20.67055511], [86.79305267, 20.67083359], [86.79305267, 20.67111015], [86.79499817, 20.67305565], [86.79499817, 20.67333031], [86.79556274, 20.67388916], [86.79555511, 20.67416573], [86.7958374, 20.67444038], [86.7958374, 20.67499924], [86.79611206, 20.67527771], [86.79611206, 20.67555618], [86.7977829, 20.67721939], [86.79750061, 20.67750168], [86.79750061, 20.67777824], [86.79777527, 20.67805481], [86.7977829, 20.67831993], [86.79860687, 20.67917061], [86.7986145, 20.67944527], [86.79888153, 20.67971992], [86.79888153, 20.68000031], [86.79944611, 20.68055534], [86.79944611, 20.68083], [86.79972076, 20.68111038], [86.80072021, 20.6822567], [86.80150604, 20.68340492], [86.80214691, 20.68522072], [86.80207825, 20.68657494], [86.80251312, 20.68798828], [86.80361176, 20.69111252], [86.80361176, 20.69305611], [86.80388641, 20.69333458], [86.80388641, 20.69444466], [86.8041687, 20.69472122], [86.8041687, 20.69527817], [86.80444336, 20.69555473], [86.80444336, 20.69833374], [86.80473328, 20.69861031], [86.80444336, 20.69889069], [86.80472565, 20.69916725], [86.80473328, 20.70248985], [86.80500031, 20.70277786], [86.80500031, 20.70360947], [86.80527496, 20.70388794], [86.80526733, 20.70471954], [86.80555725, 20.70500183], [86.80555725, 20.7052784], [86.80750275, 20.70722008], [86.80750275, 20.70750046], [86.80832672, 20.70833015], [86.80832672, 20.70862007], [86.80860901, 20.70889091], [86.80916595, 20.70889091], [86.80944824, 20.70916939], [86.8097229, 20.70916748], [86.81027985, 20.70972252], [86.81054688, 20.70944023], [86.8116684, 20.71055412], [86.8116684, 20.71083069], [86.81194305, 20.71111107], [86.81194305, 20.71138954], [86.81277466, 20.71222305], [86.81305695, 20.71194458], [86.81472015, 20.7136097], [86.81472015, 20.71388817], [86.81555176, 20.71471977], [86.81555176, 20.71499825], [86.81667328, 20.71610832], [86.81666565, 20.7163887], [86.8172226, 20.71694374], [86.8172226, 20.71722031], [86.81777954, 20.71778107], [86.81777954, 20.71805573], [86.81804657, 20.71833038], [86.81804657, 20.71861267], [86.81833649, 20.71889114], [86.81833649, 20.7191658], [86.81861115, 20.71944046], [86.81861115, 20.72000122], [86.8188858, 20.72027779], [86.8188858, 20.72083473], [86.81916809, 20.72110939], [86.81916809, 20.72138977], [86.81944275, 20.72166634], [86.81944275, 20.72222137], [86.81972504, 20.72249985], [86.81973267, 20.72332954], [86.81944275, 20.72361946], [86.81944275, 20.7238903], [86.81973267, 20.72417068], [86.81972504, 20.72444534], [86.81999969, 20.72472191], [86.82000732, 20.72500038], [86.82026672, 20.72528076], [86.82027435, 20.72555542], [86.82055664, 20.72583389], [86.82055664, 20.7266674], [86.8208313, 20.72694016], [86.8208313, 20.72777748], [86.82111359, 20.72805595], [86.82111359, 20.7294445], [86.82138824, 20.72971916], [86.82138824, 20.73028183], [86.8216629, 20.7305603], [86.8216629, 20.73250008], [86.82195282, 20.73278999], [86.82195282, 20.73528099], [86.82221985, 20.73555946], [86.82221985, 20.73611069], [86.82250214, 20.73639107], [86.82250214, 20.73750114], [86.82277679, 20.73777771], [86.82277679, 20.73944473], [86.82306671, 20.73971939], [86.82305908, 20.74027634], [86.82332611, 20.74055099], [86.82382965, 20.74240112], [86.82411957, 20.74360085], [86.82444763, 20.74528122], [86.82444763, 20.74555588], [86.82472229, 20.74583054], [86.82472229, 20.74611282], [86.82499695, 20.74638939], [86.82499695, 20.74666595], [86.82527924, 20.74694443], [86.82527924, 20.74728966], [86.82527924, 20.74749947], [86.82554626, 20.74778938], [86.82554626, 20.74888992], [86.82583618, 20.7491703], [86.82583618, 20.74944687], [86.82611084, 20.74971962], [86.82611084, 20.75028038], [86.8263855, 20.75055695], [86.8263855, 20.75083351], [86.82666779, 20.75111008], [86.82666779, 20.75166512], [86.8272171, 20.75222015], [86.8272171, 20.75250053], [86.82777405, 20.75305557], [86.82776642, 20.75360107], [86.82805634, 20.75388718], [86.82805634, 20.75444412], [86.82833099, 20.75472069], [86.82833099, 20.75528145], [86.82861328, 20.75556183], [86.82861328, 20.75610924], [86.82917023, 20.75667191], [86.82917023, 20.7575016], [86.82944489, 20.75777817], [86.82944489, 20.75805473], [86.82971954, 20.7583313], [86.82971954, 20.75860977], [86.83000183, 20.75889015], [86.83000183, 20.76000023], [86.83583069, 20.7658329], [86.83611298, 20.7658329], [86.83622742, 20.76594925], [86.83693695, 20.76667023], [86.83721924, 20.76667023], [86.83805084, 20.76749992], [86.83833313, 20.76749992], [86.83860779, 20.7677784], [86.83889008, 20.7677784], [86.8391571, 20.76806068], [86.83944702, 20.76805496], [86.83972168, 20.76833344], [86.83999634, 20.76833344], [86.84013367, 20.76847267], [86.84055328, 20.76890182], [86.8408432, 20.76890182], [86.84111023, 20.76917076], [86.84139252, 20.76916695], [86.84152985, 20.76930618], [86.84166718, 20.76944351], [86.84194183, 20.7694397], [86.84249878, 20.76999855], [86.84278107, 20.76999855], [86.84417725, 20.77139282], [86.84443665, 20.77139282], [86.84751129, 20.77308083], [86.84951019, 20.77429008], [86.85101318, 20.77482986], [86.85416412, 20.77583313], [86.85527802, 20.77583313], [86.85891724, 20.77569771], [86.86110687, 20.77555084], [86.86301422, 20.77508354], [86.86457825, 20.77454376], [86.86657715, 20.77393532], [86.86808014, 20.77313042], [86.86929321, 20.77259064], [86.87065125, 20.77177811], [86.87185669, 20.77164078], [86.87277985, 20.77166939], [86.87416077, 20.77166939], [86.87444305, 20.77139282], [86.87608337, 20.77071953], [86.87728882, 20.77031517], [86.87843323, 20.76997948], [86.881073, 20.76903534], [86.88299561, 20.76856041], [86.88484955, 20.76822472], [86.88713837, 20.76788902], [86.88906097, 20.76754951], [86.89056396, 20.76734924], [86.89305878, 20.76721954], [86.89555359, 20.76722145], [86.89583588, 20.76694489], [86.89694214, 20.76694489], [86.89722443, 20.76722145], [86.89916992, 20.76722145], [86.89944458, 20.76694489], [86.89971924, 20.76694489], [86.90000153, 20.76722145], [86.90305328, 20.76722145], [86.90333557, 20.76749992], [86.90416718, 20.76749992], [86.90444183, 20.7677784], [86.90499878, 20.7677784], [86.90528107, 20.76806068], [86.90721893, 20.76805496], [86.90750122, 20.76833344], [86.91004944, 20.76832962], [86.91140747, 20.76847076], [86.91340637, 20.76867104], [86.91454315, 20.76867104], [86.9155426, 20.7687397], [86.91796875, 20.76860809], [86.91883087, 20.76853752], [86.91999054, 20.76849365], [86.92053986, 20.76846886], [86.92189789, 20.76832962], [86.92325592, 20.76819992], [86.92524719, 20.76792908], [86.92669678, 20.76781464], [86.92696381, 20.76779366], [86.92711639, 20.76784134], [86.9278183, 20.76806068], [86.9283371, 20.76805496], [86.92861176, 20.76833344], [86.92888641, 20.76805496], [86.93032074, 20.76805496], [86.93055725, 20.76806068], [86.93083191, 20.7677784], [86.93139648, 20.7677784], [86.93165588, 20.76806068], [86.93222046, 20.76749992], [86.93250275, 20.7677784], [86.9327774, 20.7677784], [86.93305206, 20.76749992], [86.9338913, 20.76749992], [86.93509674, 20.76729965], [86.93659973, 20.76689148], [86.93838501, 20.76655579], [86.93952942, 20.76657295], [86.94110107, 20.76649284], [86.94210052, 20.76657295], [86.94361115, 20.76667023], [86.94611359, 20.76666641], [86.94625092, 20.76680565], [86.94638824, 20.76694489], [86.9466629, 20.76694489], [86.94721985, 20.76638794], [86.94777679, 20.76638985], [86.94805908, 20.76667023], [86.9486084, 20.76666641], [86.94874573, 20.76680374], [86.94889069, 20.76694489], [86.94972229, 20.76694489], [86.94999695, 20.76666641], [86.95166779, 20.76666641], [86.95194244, 20.76694489], [86.95220947, 20.76694107], [86.95249939, 20.76722145], [86.95305634, 20.76722145], [86.95333099, 20.76694489], [86.95722198, 20.76694489], [86.95749664, 20.76666641], [86.96089935, 20.76667023], [86.96296692, 20.7667408], [86.96496582, 20.76713943], [86.96639252, 20.76753998], [86.96846771, 20.76828575], [86.9701767, 20.76920319], [86.97167206, 20.76974487], [86.97303009, 20.77028275], [86.97453308, 20.77102089], [86.97538757, 20.77130127], [86.97731018, 20.77130127], [86.97805786, 20.77166748], [86.97833252, 20.77194214], [86.98055267, 20.77194214], [86.98249817, 20.77222061], [86.98278046, 20.77222061], [86.98305511, 20.77194214], [86.98317719, 20.77194214], [86.98332977, 20.77194214], [86.98447418, 20.77174377], [86.98668671, 20.77180862], [86.98770142, 20.77180862], [86.98804474, 20.77180862], [86.98916626, 20.77166748], [86.99054718, 20.77166939], [86.9908371, 20.77139282], [86.99111176, 20.77139282], [86.99138641, 20.77111244], [86.99194336, 20.77111244], [86.99223328, 20.77083015], [86.99250031, 20.77083206], [86.99277496, 20.7705555], [86.99305725, 20.77056122], [86.99415588, 20.7694397], [86.99416351, 20.76916695], [86.99472046, 20.76860809], [86.99472046, 20.76833344], [86.99500275, 20.76805496], [86.99500275, 20.7677784], [86.9952774, 20.76749992], [86.9952774, 20.76667023], [86.99555206, 20.76638985], [86.99555206, 20.76583099], [86.99583435, 20.76555634], [86.99582672, 20.76527977], [86.9963913, 20.76472092], [86.9963913, 20.76444435], [86.99666595, 20.76416779], [86.99666595, 20.76361084], [86.99694824, 20.76333046], [86.99694824, 20.7630558], [86.9972229, 20.7627697], [86.9972229, 20.76250076], [86.99748993, 20.76222038], [86.99749756, 20.76194572], [86.99777985, 20.76166725], [86.99777985, 20.76111031], [86.99833679, 20.76056099], [86.99833679, 20.76000023], [86.99861145, 20.75972939], [86.99861145, 20.75860977], [86.99888611, 20.7583313], [86.99888611, 20.75583267], [86.9991684, 20.75555611], [86.9991684, 20.75499916], [86.99944305, 20.75472069], [86.99944305, 20.75444412], [86.99972534, 20.75305557], [87.0, 20.75333405], [87.00027466, 20.75305557], [87.00054932, 20.75305939], [87.00054932, 20.75278091], [87.0008316, 20.75250053], [87.0008316, 20.75167084], [87.00138855, 20.75111008], [87.00138855, 20.75027847], [87.00195313, 20.75], [87.0019455, 20.74972153], [87.00305176, 20.74861145], [87.0036087, 20.74833488], [87.00389099, 20.74805641], [87.00389099, 20.74749947], [87.00332642, 20.74694061], [87.0036087, 20.74666595], [87.0036087, 20.74638939], [87.00444794, 20.74611282], [87.00444794, 20.74583054], [87.00499725, 20.74555588], [87.0047226, 20.74528122], [87.00499725, 20.74500275], [87.00583649, 20.7447319], [87.00583649, 20.74417114], [87.00694275, 20.74305916], [87.00694275, 20.74138832], [87.00723267, 20.74110985], [87.00694275, 20.74083328], [87.00694275, 20.73944473], [87.0063858, 20.73916626], [87.00668335, 20.73888969], [87.0063858, 20.73861122], [87.0063858, 20.73777771], [87.00611115, 20.73750114], [87.00611115, 20.73611069], [87.00583649, 20.73583031], [87.00583649, 20.73472214], [87.0055542, 20.73444366], [87.0055542, 20.73277855], [87.00527954, 20.73250008], [87.00527954, 20.73139191], [87.00499725, 20.73110962], [87.00499725, 20.7294445], [87.0047226, 20.72916603], [87.0047226, 20.72833061], [87.00416565, 20.72777748], [87.00417328, 20.72639084], [87.00389099, 20.72611046], [87.00389099, 20.72500038], [87.00372314, 20.72483635], [87.0036087, 20.72472191], [87.0036087, 20.72305679], [87.00333405, 20.72277832], [87.00332642, 20.72167015], [87.0027771, 20.72110939], [87.0027771, 20.71999931], [87.00222015, 20.71944046], [87.00222015, 20.7183342], [87.00166321, 20.71777725], [87.00166321, 20.71694183], [87.00138855, 20.71666718], [87.00138855, 20.71582985], [87.00111389, 20.71555519], [87.00110626, 20.71528053], [87.0008316, 20.71499825], [87.0008316, 20.71471977], [87.00055695, 20.71444511], [87.00054932, 20.71417046], [87.0, 20.71388817], [86.99973297, 20.71340752], [86.9994278, 20.71280861], [86.99899292, 20.71223831], [86.99855804, 20.71174049], [86.99811554, 20.71137428], [86.99773407, 20.71105957], [86.99740601, 20.71076012], [86.99700165, 20.71053123], [86.99658966, 20.71027946], [86.9961319, 20.71004295], [86.99559021, 20.70981026], [86.99500275, 20.70951271], [86.99429321, 20.70946121], [86.99356079, 20.70952034], [86.99285126, 20.70968628], [86.99214172, 20.70972061], [86.99146271, 20.70975876], [86.99088287, 20.70994949], [86.99040222, 20.71014786], [86.9899826, 20.71027946], [86.98957062, 20.71042061], [86.98912048, 20.71058083], [86.98860931, 20.71080971], [86.98808289, 20.71101189], [86.9875412, 20.71120071], [86.98701477, 20.71135521], [86.98641968, 20.71138954], [86.98581696, 20.71145058], [86.98583221, 20.71167946], [86.98555756, 20.71166611], [86.98527527, 20.71194458], [86.98500061, 20.71194458], [86.98472595, 20.71222305], [86.98443604, 20.71222115], [86.98416901, 20.71249962], [86.98306274, 20.71249962], [86.98278046, 20.71277809], [86.98222351, 20.71277618], [86.98194122, 20.71305466], [86.98166656, 20.71305466], [86.98139191, 20.71333313], [86.98083496, 20.71333313], [86.98055267, 20.7136116], [86.98007202, 20.71364975], [86.97962952, 20.71374512], [86.9792099, 20.71385956], [86.97873688, 20.71390152], [86.9782486, 20.71393776], [86.97780609, 20.71409988], [86.97734833, 20.71416092], [86.97688293, 20.71417046], [86.97641754, 20.71418953], [86.97598267, 20.71430969], [86.97553253, 20.71442032], [86.97506714, 20.71445084], [86.97460938, 20.71450806], [86.97416687, 20.71471024], [86.97370148, 20.71488762], [86.97318268, 20.7149868], [86.97277832, 20.71499443], [86.97261047, 20.71499825], [86.97197723, 20.71495056], [86.97130585, 20.71477127], [86.97059631, 20.71478081], [86.96985626, 20.71495056], [86.96910095, 20.71493912], [86.96766663, 20.7151413], [86.96639252, 20.71499825], [86.96577454, 20.71499825], [86.96531677, 20.71500015], [86.96486664, 20.71499825], [86.96440887, 20.71500015], [86.96394348, 20.71499443], [86.9634552, 20.7149334], [86.96292877, 20.71475983], [86.96232605, 20.71471977], [86.9617157, 20.71468163], [86.96115875, 20.71452522], [86.96060181, 20.71449089], [86.96009064, 20.71446991], [86.95962524, 20.71445084], [86.95921326, 20.71445084], [86.9588089, 20.71442986], [86.95838928, 20.71444321], [86.95793152, 20.71444321], [86.95742035, 20.71446037], [86.95690155, 20.714571], [86.95635986, 20.71466064], [86.95580292, 20.71471405], [86.95523071, 20.71472168], [86.95466614, 20.71474266], [86.95419312, 20.71486092], [86.95375061, 20.71498108], [86.95333099, 20.71499825], [86.95294952, 20.71499825], [86.9525528, 20.71499825], [86.95214844, 20.71499825], [86.95174408, 20.71504211], [86.95139313, 20.71522331], [86.9512558, 20.71520805], [86.95104218, 20.71518517], [86.95065308, 20.71503067], [86.95024109, 20.71499825], [86.94980621, 20.7150383], [86.94934082, 20.71515274], [86.94886017, 20.71529961], [86.94838715, 20.71550179], [86.94786835, 20.71557045], [86.9473877, 20.71568108], [86.94698334, 20.71583939], [86.94658661, 20.71602631], [86.9461441, 20.7161026], [86.94563293, 20.71615028], [86.94509125, 20.71635056], [86.94444275, 20.7163887], [86.94368744, 20.71640015], [86.94288635, 20.71645927], [86.94211578, 20.71663094], [86.94130707, 20.71664429], [86.94078064, 20.71656418], [86.94052124, 20.71652985], [86.93978882, 20.71640968], [86.93911743, 20.7163887], [86.93850708, 20.71640015], [86.93797302, 20.71648979], [86.93746185, 20.71664047], [86.93694305, 20.7166729], [86.93641663, 20.7166729], [86.93615723, 20.71666527], [86.93589783, 20.71665764], [86.93539429, 20.71660042], [86.93492126, 20.71643066], [86.9344101, 20.71635056], [86.93393707, 20.71615982], [86.93344116, 20.71609116], [86.93292236, 20.71597672], [86.93239594, 20.71585274], [86.93187714, 20.7157402], [86.93141174, 20.71556664], [86.93096924, 20.71540833], [86.93054199, 20.71525192], [86.93015289, 20.71503067], [86.92970276, 20.7148819], [86.92919922, 20.71474266], [86.92871094, 20.71465111], [86.92825317, 20.71446991], [86.92777252, 20.71430016], [86.92733002, 20.71414566], [86.92690277, 20.71390915], [86.92642975, 20.71366119], [86.92592621, 20.71340752], [86.92547607, 20.71311951], [86.92500305, 20.7129097], [86.92450714, 20.71272087], [86.92407227, 20.71249008], [86.92363739, 20.71223068], [86.92314911, 20.7120266], [86.92260742, 20.71186066], [86.92212677, 20.71157074], [86.92167664, 20.71121979], [86.9212265, 20.71084976], [86.92077637, 20.71055031], [86.92037201, 20.71027756], [86.91998291, 20.71003151], [86.91951752, 20.70991135], [86.9190979, 20.70970917], [86.91871643, 20.70946121], [86.91828918, 20.70926857], [86.9178009, 20.70914268], [86.91736603, 20.70890808], [86.91689301, 20.70870018], [86.91638184, 20.7085743], [86.916008, 20.70833588], [86.91567993, 20.70809746], [86.91545868, 20.70801353], [86.91529083, 20.70795059], [86.91487885, 20.70776939], [86.91441345, 20.70755005], [86.91390991, 20.70732117], [86.91343689, 20.70704079], [86.91303253, 20.70675278], [86.91261292, 20.70651436], [86.91216278, 20.70632362], [86.91173553, 20.70610046], [86.91131592, 20.70583916], [86.91086578, 20.70560074], [86.91039276, 20.70536995], [86.90994263, 20.70507813], [86.90946198, 20.70482063], [86.90901184, 20.70455742], [86.90862274, 20.70425034], [86.90822601, 20.70392036], [86.9078064, 20.70363426], [86.90737915, 20.70334053], [86.90692902, 20.70305634], [86.90647888, 20.70278168], [86.90602875, 20.70248985], [86.9056015, 20.70222282], [86.90516663, 20.70194435], [86.90470886, 20.70166969], [86.90419006, 20.70143127], [86.90361023, 20.70124054], [86.90302277, 20.70106697], [86.9025116, 20.70083046], [86.90203094, 20.70054817], [86.90157318, 20.70027733], [86.90110016, 20.70003128], [86.90058136, 20.69985962], [86.90011597, 20.69965172], [86.89978027, 20.69932365], [86.89949799, 20.69896317], [86.89919281, 20.69864655], [86.8988266, 20.69839096], [86.89832306, 20.69829178], [86.8979187, 20.69804001], [86.89752197, 20.6977787], [86.89711761, 20.69754028], [86.89666748, 20.69736099], [86.8962326, 20.69718361], [86.89585114, 20.69692802], [86.89550018, 20.69664955], [86.89520264, 20.69634056], [86.89482117, 20.69615173], [86.89437866, 20.69602966], [86.8939209, 20.69581032], [86.89341736, 20.69549942], [86.89289093, 20.69512177], [86.89231873, 20.69468117], [86.89175415, 20.69419861], [86.89116669, 20.69377708], [86.89067841, 20.69334984], [86.89022064, 20.69299126], [86.88981628, 20.69259071], [86.8894043, 20.69226074], [86.88897705, 20.69194984], [86.88854218, 20.69166183], [86.88813782, 20.6913681], [86.88777924, 20.69106102], [86.88743591, 20.69077873], [86.88704681, 20.69054031], [86.88667297, 20.69028282], [86.88626862, 20.69000244], [86.88585663, 20.68971825], [86.88546753, 20.68943977], [86.88513947, 20.68913078], [86.88487244, 20.6887722], [86.88455963, 20.68844795], [86.88420105, 20.68810081], [86.88375092, 20.68774033], [86.88331604, 20.68731499], [86.88286591, 20.68686104], [86.88247681, 20.68634415], [86.88201141, 20.68590164], [86.88148499, 20.6855278], [86.88098145, 20.68514061], [86.88056946, 20.68469048], [86.88020325, 20.68424988], [86.87976074, 20.68392181], [86.87937927, 20.68359947], [86.87908173, 20.6832695], [86.8787384, 20.68303108], [86.87843323, 20.68276024], [86.87812042, 20.68243027], [86.87782288, 20.68197823], [86.87746429, 20.68152618], [86.87708282, 20.68118858], [86.8767395, 20.68089294], [86.87644196, 20.68060684], [86.87615204, 20.68032074], [86.87583923, 20.68003273], [86.8755188, 20.67969131], [86.87517548, 20.67934036], [86.87482452, 20.67898941], [86.8744812, 20.6786499], [86.87412262, 20.67835045], [86.87374115, 20.67806053], [86.87335205, 20.67778778], [86.87301636, 20.67745972], [86.87275696, 20.67707062], [86.87245178, 20.67671013], [86.87210083, 20.67639923], [86.87172699, 20.67610931], [86.87135315, 20.67583084], [86.87097931, 20.67555046], [86.87062836, 20.67525101], [86.87032318, 20.67490959], [86.87008667, 20.67454529], [86.86988831, 20.67420006], [86.86966705, 20.67391968], [86.86943817, 20.6736908], [86.8691864, 20.67345047], [86.86897278, 20.67314529], [86.86868286, 20.67283058], [86.86843109, 20.67236519], [86.8682785, 20.67171288], [86.86794281, 20.67116547], [86.86750031, 20.67071915], [86.86705017, 20.67030907], [86.86663818, 20.66994858], [86.8663559, 20.66954041], [86.86608887, 20.66921043], [86.8658371, 20.66892052], [86.86560059, 20.66862106], [86.86532593, 20.66831207], [86.86502075, 20.6679821], [86.86470032, 20.66760826], [86.86433411, 20.66723442], [86.86392975, 20.66685867], [86.86351776, 20.6664505], [86.86302948, 20.6661377], [86.86252594, 20.66584969], [86.86199188, 20.66550255], [86.86138916, 20.66500282], [86.86110687, 20.66500282], [86.86083221, 20.66477394], [86.85917664, 20.66472054], [86.85888672, 20.66500282], [86.85832977, 20.66500282], [86.85722351, 20.6661129], [86.85721588, 20.66722107], [86.85749817, 20.66749954], [86.85749817, 20.66833305], [86.85778046, 20.66860962], [86.85778046, 20.66916656], [86.85832977, 20.6697197], [86.85832977, 20.67000008], [86.86027527, 20.67194366], [86.8602829, 20.67222023], [86.86083221, 20.67278099], [86.86083221, 20.67305946], [86.86138916, 20.67361069], [86.86444092, 20.67666626], [86.86444092, 20.67694092], [86.86499023, 20.67750168], [86.86499786, 20.67777824], [86.86528015, 20.67804909], [86.86528015, 20.67889023], [86.86499023, 20.67917061], [86.86499786, 20.67944527], [86.86472321, 20.67971992], [86.86472321, 20.68000031], [86.86444092, 20.68028069], [86.86444092, 20.68056107], [86.86332703, 20.68167114], [86.86277771, 20.68166733], [86.86250305, 20.6819458], [86.86222076, 20.6819458], [86.86194611, 20.68222237], [86.86055756, 20.68222237], [86.8602829, 20.68250084], [86.85832977, 20.68250084], [86.85806274, 20.68278122], [86.85778046, 20.68278122], [86.85749817, 20.68305969], [86.85722351, 20.68305588], [86.85694122, 20.68333054], [86.85694122, 20.68416977], [86.85806274, 20.68527985], [86.85806274, 20.68556023], [86.85944366, 20.68694496], [86.85944366, 20.68722153], [86.85972595, 20.68749046], [86.85972595, 20.68778038], [86.86027527, 20.68833351], [86.86027527, 20.68861008], [86.86250305, 20.69083405], [86.86305237, 20.69083023], [86.86332703, 20.69111252], [86.86360931, 20.69111252], [86.8638916, 20.6913929], [86.86694336, 20.6913929], [86.86723328, 20.69166946], [86.86805725, 20.69166756], [86.8681488, 20.69175911], [86.86833191, 20.69194221], [86.86888885, 20.69194221], [86.86916351, 20.6922226], [86.8694458, 20.6922226], [86.87000275, 20.69277954], [86.8702774, 20.69277954], [86.87110901, 20.69361115], [86.87110901, 20.69388962], [86.87166595, 20.69444466], [86.87166595, 20.69472122], [86.87194824, 20.69499969], [86.87194824, 20.69528008], [86.87416077, 20.69750023], [86.87416077, 20.69778061], [86.875, 20.69861031], [86.87526703, 20.69861031], [86.87555695, 20.69889069], [86.87582397, 20.69894218], [86.87590027, 20.69895554], [86.87638855, 20.69944382], [86.87666321, 20.69944382], [86.8769455, 20.69972229], [86.87722015, 20.69972038], [86.8777771, 20.70028114], [86.87805176, 20.70028114], [86.87832642, 20.70055962], [86.8786087, 20.70055962], [86.87944794, 20.70139122], [86.8797226, 20.70139122], [86.87999725, 20.70166969], [86.8805542, 20.70166588], [86.88083649, 20.70194435], [86.88111115, 20.70194435], [86.88388824, 20.70471954], [86.88388824, 20.70500183], [86.8841629, 20.7052803], [86.8841629, 20.70555305], [86.88444519, 20.70583344], [86.88445282, 20.70611191], [86.88471985, 20.70639038], [86.88471985, 20.70666695], [86.88527679, 20.70722008], [86.88527679, 20.7080555], [86.88500214, 20.70833015], [86.88500214, 20.70862007], [86.88471985, 20.70889091], [86.88471985, 20.70916748], [86.88444519, 20.70944595], [86.88445282, 20.70972061], [86.8841629, 20.71000099], [86.8841629, 20.71027756], [86.88360596, 20.71083069], [86.88360596, 20.71111107], [86.88194275, 20.71277809], [86.88166809, 20.71277618], [86.8813858, 20.71305466], [86.88111115, 20.71305466], [86.8805542, 20.7136116], [86.88028717, 20.7136097], [86.87999725, 20.71388817], [86.8797226, 20.71388817], [86.87944794, 20.71417046], [86.87917328, 20.71417046], [86.87889099, 20.71445084], [86.8786087, 20.71444511], [86.87833405, 20.71472168], [86.87805176, 20.71471977], [86.87805176, 20.71499825], [86.8777771, 20.71528053], [86.8777771, 20.71555519], [86.87750244, 20.71582985], [86.87750244, 20.71610832], [86.87722015, 20.7163887], [86.87722015, 20.71944427], [86.87750244, 20.71972466], [86.87750244, 20.72083473], [86.8777771, 20.72110939], [86.8777771, 20.72138977], [86.87805176, 20.72166634], [86.87805176, 20.72194481], [86.87832642, 20.72221947], [86.87833405, 20.72277832], [86.8786087, 20.72305107], [86.8786087, 20.7238903], [86.87889099, 20.72416687], [86.87889099, 20.72472191], [86.87916565, 20.72500038], [86.87917328, 20.72583008], [86.87944794, 20.72611046], [86.87944794, 20.72694397], [86.8797226, 20.72722054], [86.8797226, 20.72750092], [86.87944794, 20.72777748], [86.87944794, 20.72805977], [86.87889099, 20.72860909], [86.87889099, 20.73250008], [86.87832642, 20.73306084], [86.87805176, 20.73278999], [86.87805176, 20.73250008], [86.8777771, 20.7322197], [86.8777771, 20.73027992], [86.87750244, 20.72999954], [86.87750244, 20.72944069], [86.8777771, 20.72916603], [86.8777771, 20.72833061], [86.87805176, 20.72805595], [86.87805176, 20.72611046], [86.8777771, 20.72583008], [86.8777771, 20.72527695], [86.87750244, 20.72500038], [86.87750244, 20.72472], [86.87722015, 20.72444534], [86.87722015, 20.72417068], [86.87695313, 20.7238903], [86.87695313, 20.72361946], [86.87666321, 20.72332954], [86.87666321, 20.72277832], [86.87638855, 20.72249985], [86.87638855, 20.72194099], [86.87611389, 20.72166634], [86.87610626, 20.72027969], [86.8758316, 20.72000122], [86.8758316, 20.71889114], [86.87555695, 20.71861267], [86.87555695, 20.71833038], [86.8758316, 20.71805573], [86.8758316, 20.71722031], [86.87611389, 20.71694374], [86.87611389, 20.71610832], [86.87638855, 20.71582985], [86.87638855, 20.71528053], [86.87750244, 20.71417046], [86.87750244, 20.71388817], [86.87805176, 20.71333122], [86.87833405, 20.71333313], [86.8786087, 20.71305466], [86.87889099, 20.71305466], [86.87916565, 20.71277618], [86.87944794, 20.71277809], [86.87999725, 20.71222115], [86.88027954, 20.71222305], [86.88083649, 20.71166611], [86.88111115, 20.71167946], [86.88223267, 20.71055984], [86.88249969, 20.71055984], [86.8833313, 20.70972061], [86.8833313, 20.70916748], [86.88388824, 20.70862007], [86.88388824, 20.70722008], [86.88361359, 20.7069416], [86.88361359, 20.70666695], [86.88305664, 20.70611191], [86.88305664, 20.70583344], [86.88277435, 20.70583344], [86.8805542, 20.70360947], [86.88027954, 20.70360947], [86.8797226, 20.70305634], [86.87944794, 20.70306015], [86.8786087, 20.70222092], [86.87833405, 20.70222282], [86.8777771, 20.70166588], [86.87750244, 20.70166969], [86.87666321, 20.70083046], [86.87638855, 20.70083427], [86.87611389, 20.7005558], [86.8758316, 20.70055962], [86.87526703, 20.70000076], [86.875, 20.70000076], [86.87473297, 20.69972038], [86.87444305, 20.69972229], [86.87402344, 20.69930458], [86.87361145, 20.69888878], [86.87333679, 20.69889069], [86.8713913, 20.69695091], [86.8713913, 20.69668007], [86.87111664, 20.69639015], [86.87111664, 20.69610977], [86.87083435, 20.69583321], [86.87083435, 20.69555473], [86.87055206, 20.69527817], [86.87055206, 20.69499969], [86.8702774, 20.69472122], [86.8702774, 20.69444466], [86.86916351, 20.69333458], [86.86888885, 20.69333458], [86.8686142, 20.69305611], [86.86833191, 20.69305992], [86.86805725, 20.69277954], [86.86750031, 20.69277954], [86.86723328, 20.69305992], [86.86694336, 20.69305992], [86.8666687, 20.69277954], [86.8638916, 20.69277954], [86.86332703, 20.6922226], [86.86277771, 20.6922226], [86.86250305, 20.69194221], [86.86222076, 20.69194221], [86.86206055, 20.69178391], [86.86166382, 20.69138908], [86.86138916, 20.6913929], [86.85832977, 20.6883297], [86.85832977, 20.68805504], [86.85639191, 20.68610954], [86.85639191, 20.68583298], [86.85610962, 20.68555641], [86.85611725, 20.68527985], [86.85582733, 20.68499947], [86.85582733, 20.68472099], [86.85555267, 20.68444443], [86.85555267, 20.68305969], [86.85694122, 20.68167114], [86.85721588, 20.68167114], [86.85749817, 20.68139076], [86.85778046, 20.68139076], [86.85806274, 20.68111038], [86.85832977, 20.68111038], [86.85861206, 20.68083], [86.85944366, 20.68083382], [86.85972595, 20.68055534], [86.86000061, 20.68056107], [86.8602829, 20.68028069], [86.86083221, 20.68028069], [86.86110687, 20.68000031], [86.86194611, 20.68000031], [86.86222076, 20.67971992], [86.86277771, 20.67972374], [86.86360931, 20.67888832], [86.86360931, 20.67831993], [86.86166382, 20.6763916], [86.86138916, 20.6763916], [86.8602829, 20.67528152], [86.86000061, 20.67528152], [86.86000061, 20.67499924], [86.85861206, 20.67361069], [86.85861206, 20.67333031], [86.85832977, 20.67305565], [86.85832977, 20.67278099], [86.85806274, 20.67250824], [86.85806274, 20.67222023], [86.85666656, 20.67083359], [86.85666656, 20.67055511], [86.85639191, 20.67028046], [86.85639191, 20.66945076], [86.85611725, 20.66917038], [86.85611725, 20.66833115], [86.85583496, 20.66805649], [86.85582733, 20.66777992], [86.85555267, 20.66749954], [86.85555267, 20.66638184], [86.85583496, 20.6661129], [86.85582733, 20.66555977], [86.85694122, 20.66444016], [86.85722351, 20.66444206], [86.85778046, 20.66389084], [86.85806274, 20.66389275], [86.85832977, 20.66361237], [86.85888672, 20.66361237], [86.85972595, 20.66278076], [86.85917664, 20.66221809], [86.85916901, 20.66194534], [86.85871887, 20.66163063], [86.85832214, 20.66127968], [86.85791779, 20.66097641], [86.85752869, 20.66067123], [86.85721588, 20.66033554], [86.85692596, 20.66003036], [86.85665131, 20.65977097], [86.85637665, 20.65954971], [86.85611725, 20.6593399], [86.85582733, 20.65909004], [86.85555267, 20.65878105], [86.85523224, 20.65845108], [86.85484314, 20.65815163], [86.85449219, 20.65781784], [86.85415649, 20.65747261], [86.85385895, 20.65706062], [86.85352325, 20.65672493], [86.85312653, 20.65644073], [86.85276031, 20.65615463], [86.85237885, 20.65585709], [86.8519516, 20.65555954], [86.85150909, 20.65526772], [86.85106659, 20.65496826], [86.85058594, 20.65471268], [86.85012054, 20.65443993], [86.84964752, 20.65416718], [86.84915161, 20.65388107], [86.8486557, 20.65361595], [86.84815979, 20.6533699], [86.84765625, 20.65315819], [86.84716797, 20.65300941], [86.84668732, 20.65281105], [86.84623718, 20.65261078], [86.84578705, 20.65237999], [86.84532166, 20.65217972], [86.84487152, 20.65199852], [86.84436035, 20.65191078], [86.84383392, 20.65188789], [86.84332275, 20.65190125], [86.84287262, 20.65197945], [86.842453, 20.65211105], [86.84200287, 20.65223885], [86.84155273, 20.65244293], [86.84115601, 20.6527729], [86.84083557, 20.65315628], [86.84055328, 20.65350914], [86.84030151, 20.6538105], [86.84011078, 20.65409279], [86.83999634, 20.65439987], [86.8398819, 20.65469933], [86.83975983, 20.65498924], [86.8396759, 20.65530968], [86.83955383, 20.65563774], [86.83944702, 20.65603065], [86.83933258, 20.6565094], [86.83921051, 20.65703964], [86.83912659, 20.65759087], [86.83900452, 20.65811729], [86.83892059, 20.6586113], [86.83888245, 20.65906143], [86.83882141, 20.65945435], [86.83868408, 20.65979195], [86.83862305, 20.6601696], [86.83853912, 20.66057777], [86.83838654, 20.66096306], [86.83827209, 20.66140175], [86.83809662, 20.66183853], [86.83795166, 20.66230011], [86.83777618, 20.66274071], [86.83760071, 20.66319084], [86.83744812, 20.66365814], [86.8372345, 20.66414833], [86.83699036, 20.66469955], [86.83673859, 20.66533089], [86.83644867, 20.66597939], [86.83609009, 20.66654968], [86.83570099, 20.66707039], [86.83534241, 20.66752815], [86.8350296, 20.66794586], [86.83474731, 20.66834068], [86.83451843, 20.6687603], [86.83421326, 20.66912842], [86.83387756, 20.6695118], [86.83351898, 20.6699028], [86.83313751, 20.67028618], [86.83274841, 20.67066956], [86.83235931, 20.67103958], [86.83193207, 20.67136955], [86.83149719, 20.67167091], [86.83107758, 20.67196083], [86.8306427, 20.67222977], [86.83022308, 20.67250824], [86.82978821, 20.67277527], [86.82936096, 20.67304039], [86.82892609, 20.67331123], [86.82847595, 20.67359543], [86.82800293, 20.67387009], [86.82745361, 20.67412949], [86.82686615, 20.67436028], [86.82624054, 20.67455101], [86.82563782, 20.67475128], [86.82508087, 20.67497063], [86.82454681, 20.67515945], [86.82404327, 20.67531967], [86.82357025, 20.67547607], [86.82309723, 20.67560005], [86.82266998, 20.67575645], [86.8221817, 20.6758709], [86.82171631, 20.67601967], [86.82124329, 20.67613029], [86.82077026, 20.67624092], [86.8203125, 20.67633057], [86.81985474, 20.67640114], [86.81939697, 20.67649078], [86.81890869, 20.6765995], [86.81838989, 20.67667961], [86.81785583, 20.67679024], [86.81729889, 20.67687798], [86.81672668, 20.67699432], [86.8161087, 20.67706108], [86.81552887, 20.67707062], [86.81505585, 20.67699814], [86.81459045, 20.67701149], [86.81408691, 20.67703819], [86.81350708, 20.67704964], [86.81291962, 20.67713737], [86.81229401, 20.67717171], [86.81202698, 20.67711067], [86.81172943, 20.67704201], [86.811203, 20.67695045], [86.81069183, 20.6769104], [86.81015015, 20.67690659], [86.80955505, 20.67694473], [86.80885315, 20.67694092], [86.80815125, 20.67688942], [86.80741882, 20.67686081], [86.80665588, 20.67679024], [86.80587769, 20.67671776], [86.80506897, 20.67667961], [86.80426788, 20.67662048]]]]}}, {\\\"id\\\": \\\"24\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.27_1\\\", \\\"HASC_1\\\": \\\"IN.PY\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Puducherry\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": \\\"Pondicherry|Puduchcheri|Pondich\\\\u00e9ry\\\", \\\"apm25_popweighted\\\": -5.1, \\\"dalys_apm25_rate_6cod_mean_total\\\": 954.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1686.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -731.0, \\\"geo-id\\\": 24, \\\"hpm25_child_popweighted\\\": -260.0, \\\"hpm25_female_popweighted\\\": -299.0, \\\"hpm25_male_popweighted\\\": -215.0, \\\"location\\\": \\\"Puducherry\\\", \\\"mort_apm25_6cod_mean_total\\\": 182.0, \\\"mort_hpm25_6cod_mean_total\\\": -327.0, \\\"mort_tpm25_6cod_mean_total\\\": -145.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[79.84485626, 10.82653236], [79.84485626, 10.82625103], [79.84541321, 10.82625103], [79.84541321, 10.82569122], [79.84486389, 10.82569504], [79.84486389, 10.82541656], [79.84401703, 10.82541943], [79.84401703, 10.82514095], [79.84348297, 10.82514095], [79.84348297, 10.82486057], [79.8429184, 10.82486057], [79.8429184, 10.82458305], [79.84208679, 10.82458305], [79.84208679, 10.82430458], [79.84152985, 10.82430935], [79.84152985, 10.82403088], [79.84040833, 10.82403088], [79.84040833, 10.82375145], [79.8401413, 10.82375145], [79.8401413, 10.82430935], [79.84041595, 10.82430458], [79.84041595, 10.82458305], [79.8409729, 10.82458305], [79.8409729, 10.82486057], [79.84124756, 10.82486057], [79.84124756, 10.82514095], [79.84179688, 10.82514095], [79.84179688, 10.82541943], [79.84236145, 10.82541656], [79.84236145, 10.82569504], [79.8429184, 10.82569504], [79.8429184, 10.82597256], [79.84348297, 10.82597065], [79.84348297, 10.82625103], [79.84401703, 10.82625103], [79.84401703, 10.82653236], [79.84485626, 10.82653236]]], [[[79.85124969, 10.81377125], [79.84329224, 10.81225109], [79.83571625, 10.8117218], [79.8319931, 10.81137085], [79.81976318, 10.81110191], [79.81333923, 10.81408119], [79.81167603, 10.8157692], [79.81368256, 10.81837177], [79.81326294, 10.82874012], [79.81204224, 10.83282185], [79.80819702, 10.8313818], [79.80589294, 10.82804012], [79.80307007, 10.83368969], [79.79667664, 10.83589172], [79.7931366, 10.83949089], [79.79113007, 10.84570122], [79.7922821, 10.84883118], [79.79563141, 10.84381199], [79.79940796, 10.84468269], [79.80338287, 10.84731007], [79.80815887, 10.8488903], [79.80745697, 10.8526907], [79.80345917, 10.85748005], [79.79727173, 10.85809135], [79.78956604, 10.8617506], [79.79178619, 10.86394978], [79.80558014, 10.86365032], [79.81138611, 10.86443138], [79.80898285, 10.86744022], [79.80278778, 10.8711319], [79.79245758, 10.87000179], [79.78833008, 10.87292957], [79.78486633, 10.87355042], [79.78026581, 10.87131023], [79.77562714, 10.87578106], [79.7724762, 10.87325191], [79.76698303, 10.87276173], [79.76735687, 10.87555122], [79.77005768, 10.87798119], [79.77493286, 10.87890244], [79.77635956, 10.88167953], [79.77317047, 10.8895607], [79.76122284, 10.8914299], [79.76045227, 10.88315201], [79.75694275, 10.88010025], [79.75186157, 10.88085938], [79.75415802, 10.88665962], [79.74919891, 10.88941956], [79.74794769, 10.8952198], [79.74532318, 10.89307976], [79.74578094, 10.88724136], [79.74302673, 10.8819418], [79.7414093, 10.88329124], [79.74220276, 10.89054966], [79.74180603, 10.89444065], [79.74485016, 10.89674854], [79.74298096, 10.89936066], [79.72688293, 10.8974514], [79.72838593, 10.90229034], [79.72557068, 10.90358925], [79.72590637, 10.90690136], [79.72389984, 10.90802193], [79.72119141, 10.9052], [79.71958923, 10.90579128], [79.72083282, 10.91070175], [79.70922852, 10.91320038], [79.70863342, 10.91415501], [79.70803833, 10.91510105], [79.71034241, 10.9174099], [79.71042633, 10.91913986], [79.70423126, 10.91887093], [79.70437622, 10.92103958], [79.70848083, 10.9211607], [79.70767212, 10.92341137], [79.70847321, 10.92671108], [79.71299744, 10.9279213], [79.71585083, 10.93050957], [79.72022247, 10.93222046], [79.72122955, 10.93531036], [79.7191925, 10.94054127], [79.71555328, 10.9382906], [79.71481323, 10.93412971], [79.70934296, 10.93558121], [79.70435333, 10.93518925], [79.70323944, 10.9382906], [79.70287323, 10.94562054], [79.70391846, 10.94761086], [79.70365143, 10.95186138], [79.71150208, 10.95227146], [79.71546173, 10.95328999], [79.72093201, 10.95060062], [79.7266922, 10.95235062], [79.73169708, 10.94816017], [79.73265076, 10.94116116], [79.74009705, 10.94365025], [79.7455368, 10.9433403], [79.74572754, 10.94929028], [79.74456024, 10.95447063], [79.73992157, 10.95578098], [79.73813629, 10.95860958], [79.73914337, 10.96146107], [79.74131012, 10.96326065], [79.74381256, 10.96701145], [79.73951721, 10.9660902], [79.7381897, 10.96931934], [79.73015594, 10.97101116], [79.73163605, 10.97529125], [79.72986603, 10.9813509], [79.73017883, 10.98510933], [79.73190308, 10.98703957], [79.73721313, 10.98910046], [79.74305725, 10.98506069], [79.74823761, 10.98153114], [79.75260162, 10.97989178], [79.76051331, 10.98058128], [79.76521301, 10.97919941], [79.77227783, 10.97956181], [79.77435303, 10.97724247], [79.77392578, 10.97101116], [79.77723694, 10.96793079], [79.78341675, 10.96733189], [79.78705597, 10.9698], [79.78962708, 10.97338104], [79.79036713, 10.97853184], [79.79191589, 10.98092937], [79.79644775, 10.98306942], [79.79741669, 10.98490047], [79.80145264, 10.98621178], [79.80256653, 10.9848814], [79.80454254, 10.98287964], [79.80979919, 10.9820509], [79.81202698, 10.98295975], [79.81302643, 10.98485184], [79.81389618, 10.98714924], [79.82478333, 10.98662853], [79.82491302, 10.98479939], [79.82441711, 10.97949123], [79.8344574, 10.97681999], [79.83448029, 10.97671127], [79.83537292, 10.97662163], [79.83763885, 10.97643948], [79.84440613, 10.97597027], [79.85058594, 10.97579002], [79.85457611, 10.97602177], [79.85457611, 10.97431087], [79.85430908, 10.97431087], [79.85430908, 10.97264004], [79.85402679, 10.97264004], [79.85402679, 10.97097015], [79.85375214, 10.97097206], [79.85375214, 10.96930599], [79.85346985, 10.96931934], [79.85346985, 10.96403027], [79.85320282, 10.96403027], [79.85320282, 10.96208096], [79.8529129, 10.96208286], [79.8529129, 10.96152687], [79.85320282, 10.96153164], [79.85320282, 10.96097088], [79.85346985, 10.96097088], [79.85346985, 10.9598608], [79.85319519, 10.9598608], [79.85319519, 10.95958328], [79.8529129, 10.95958328], [79.8529129, 10.95930481], [79.85320282, 10.95930862], [79.85320282, 10.95514107], [79.8529129, 10.95514107], [79.8529129, 10.95347023], [79.85319519, 10.95347309], [79.85319519, 10.95291615], [79.85346985, 10.95292091], [79.85346985, 10.95153141], [79.85320282, 10.95153141], [79.85320282, 10.95069027], [79.8529129, 10.95069408], [79.8529129, 10.94847202], [79.85319519, 10.94847202], [79.85319519, 10.94569397], [79.8529129, 10.94569397], [79.8529129, 10.94513988], [79.85320282, 10.94515133], [79.85320282, 10.94347191], [79.8529129, 10.94347191], [79.8529129, 10.94180584], [79.85320282, 10.94180965], [79.85320282, 10.94153023], [79.85346985, 10.94153023], [79.85346985, 10.93931007], [79.85375214, 10.93931007], [79.85375214, 10.93236065], [79.85402679, 10.93236065], [79.85402679, 10.92319393], [79.85430908, 10.92319393], [79.85430908, 10.9179163], [79.85402679, 10.91792011], [79.85402679, 10.91652966], [79.85375214, 10.91652966], [79.85375214, 10.91514015], [79.85346985, 10.91514015], [79.85346985, 10.91374969], [79.85320282, 10.91374969], [79.85320282, 10.91346931], [79.85097504, 10.91347122], [79.85097504, 10.91319561], [79.85041809, 10.91319561], [79.85041809, 10.91291809], [79.84764099, 10.91292], [79.84764099, 10.91235924], [79.84819794, 10.9123621], [79.84819794, 10.91208267], [79.84874725, 10.91208267], [79.84874725, 10.91180515], [79.84928894, 10.91180992], [79.84928894, 10.91125202], [79.85098267, 10.91125202], [79.85098267, 10.91152954], [79.85124969, 10.91152668], [79.85124969, 10.91208267], [79.85152435, 10.91208267], [79.85152435, 10.9123621], [79.85263824, 10.9123621], [79.85263824, 10.91208267], [79.8529129, 10.91208267], [79.8529129, 10.91069317], [79.85263824, 10.91069317], [79.85263824, 10.9090271], [79.85234833, 10.9090414], [79.85234833, 10.90819073], [79.8520813, 10.90819454], [79.8520813, 10.90736103], [79.85236359, 10.90736103], [79.85234833, 10.90486145], [79.85263824, 10.90486145], [79.85263824, 10.90236092], [79.85234833, 10.90236092], [79.85234833, 10.89513969], [79.8520813, 10.89513969], [79.8520813, 10.89264011], [79.85234833, 10.89264011], [79.85234833, 10.89235973], [79.85263824, 10.89235973], [79.85263824, 10.89013767], [79.8529129, 10.89013958], [79.8529129, 10.88986015], [79.85236359, 10.88986206], [79.85236359, 10.88958359], [79.8520813, 10.88958359], [79.8520813, 10.88930607], [79.85180664, 10.88931274], [79.85180664, 10.88903046], [79.85151672, 10.88903046], [79.85151672, 10.88875198], [79.85124969, 10.88875198], [79.85124969, 10.88791084], [79.85097504, 10.88791561], [79.85097504, 10.88652802], [79.85069275, 10.88652992], [79.85069275, 10.88569069], [79.84986115, 10.8856926], [79.84986115, 10.88541794], [79.84874725, 10.88541985], [79.84874725, 10.88487053], [79.8484726, 10.88487053], [79.8484726, 10.88430977], [79.84819794, 10.88430977], [79.84819794, 10.88403034], [79.84874725, 10.88403034], [79.84874725, 10.88375187], [79.85041809, 10.88375187], [79.85041809, 10.88403034], [79.85098267, 10.88403034], [79.85098267, 10.88430977], [79.85151672, 10.88430977], [79.85151672, 10.88375187], [79.85124969, 10.88375187], [79.85124969, 10.88264179], [79.85098267, 10.88264179], [79.85098267, 10.88153172], [79.85124969, 10.88153172], [79.85124969, 10.88069057], [79.85152435, 10.88069534], [79.85152435, 10.88013935], [79.85180664, 10.88014126], [79.85180664, 10.87958145], [79.8520813, 10.87958336], [79.8520813, 10.87930489], [79.85234833, 10.87930965], [79.85234833, 10.87874889], [79.85263824, 10.87874889], [79.85263824, 10.87847328], [79.8529129, 10.87847328], [79.8529129, 10.87458324], [79.85263824, 10.87458324], [79.85263824, 10.8698616], [79.85234833, 10.86986923], [79.85234833, 10.86847019], [79.8520813, 10.8684721], [79.8520813, 10.86708355], [79.85180664, 10.86708355], [79.85180664, 10.86541557], [79.85151672, 10.86542034], [79.85151672, 10.86485958], [79.85180664, 10.86486244], [79.85180664, 10.86402798], [79.8520813, 10.86403179], [79.8520813, 10.85902977], [79.85234833, 10.85902977], [79.85234833, 10.85403156], [79.85263824, 10.85403156], [79.85263824, 10.839571], [79.85236359, 10.83958435], [79.85236359, 10.83874989], [79.85263824, 10.83875179], [79.85263824, 10.8376379], [79.8529129, 10.8376379], [79.8529129, 10.83708382], [79.85263824, 10.83708382], [79.85263824, 10.8368063], [79.85236359, 10.8368063], [79.85236359, 10.83652782], [79.85263824, 10.83652973], [79.85263824, 10.83096886], [79.85236359, 10.83097363], [79.85236359, 10.8293047], [79.8520813, 10.82931042], [79.8520813, 10.82763004], [79.85180664, 10.82763863], [79.85180664, 10.82680511], [79.8473587, 10.82681179], [79.8473587, 10.82653236], [79.84625244, 10.82653236], [79.84625244, 10.82681179], [79.84541321, 10.82680511], [79.84541321, 10.82708263], [79.84486389, 10.82708263], [79.84486389, 10.82736111], [79.84402466, 10.82736111], [79.84402466, 10.82708263], [79.84347534, 10.82708263], [79.84347534, 10.82680511], [79.8429184, 10.82681179], [79.8429184, 10.82653236], [79.84236145, 10.82653236], [79.84236145, 10.82625103], [79.84179688, 10.82625103], [79.84179688, 10.82597065], [79.84124756, 10.82597256], [79.84124756, 10.82569504], [79.8409729, 10.82569504], [79.8409729, 10.82541656], [79.84040833, 10.82541943], [79.84040833, 10.82514095], [79.83985901, 10.82514095], [79.83985901, 10.82541943], [79.83957672, 10.82541943], [79.83957672, 10.82514095], [79.83930206, 10.82514095], [79.83930206, 10.82457161], [79.8390274, 10.82458305], [79.8390274, 10.82374859], [79.83930206, 10.82375145], [79.83930206, 10.82347107], [79.8381958, 10.82347298], [79.8381958, 10.82319546], [79.8373642, 10.82319546], [79.8373642, 10.82291698], [79.83680725, 10.82291889], [79.83680725, 10.82264137], [79.83625031, 10.82264137], [79.83625031, 10.82236099], [79.83597565, 10.82236099], [79.83597565, 10.82208347], [79.8354187, 10.82208347], [79.8354187, 10.82180691], [79.83513641, 10.82182121], [79.83513641, 10.8215313], [79.83460236, 10.8215313], [79.83460236, 10.82125092], [79.83403015, 10.82125092], [79.83403015, 10.82096958], [79.83374786, 10.8209734], [79.83374786, 10.82069492], [79.83319092, 10.82069492], [79.83319092, 10.8204174], [79.8326416, 10.82042122], [79.8326416, 10.82014084], [79.83207703, 10.82014084], [79.83207703, 10.81986141], [79.83149719, 10.81986141], [79.83097076, 10.81986141], [79.83097076, 10.81958199], [79.83013916, 10.81958199], [79.83013916, 10.81930447], [79.8290329, 10.81931114], [79.8290329, 10.81902885], [79.82817841, 10.81902885], [79.82817841, 10.81876183], [79.82707977, 10.81876183], [79.82707977, 10.81847], [79.82541656, 10.81847286], [79.82541656, 10.81819439], [79.82402802, 10.81819439], [79.82402802, 10.81791592], [79.82375336, 10.81792068], [79.82375336, 10.81764126], [79.82402802, 10.81764126], [79.82402802, 10.81735992], [79.82540894, 10.81735992], [79.82540894, 10.81764126], [79.82707977, 10.81764126], [79.82707977, 10.81792068], [79.82819366, 10.81791592], [79.82819366, 10.81819439], [79.82902527, 10.81819439], [79.82902527, 10.81847286], [79.83013916, 10.81847], [79.83013916, 10.81876183], [79.83097076, 10.81876183], [79.83097076, 10.81902885], [79.83149719, 10.81902885], [79.83207703, 10.81902885], [79.83207703, 10.81931114], [79.8326416, 10.81930447], [79.8326416, 10.81958199], [79.83319092, 10.81958199], [79.83319092, 10.81986141], [79.83374786, 10.81986141], [79.83374786, 10.82014084], [79.83403015, 10.82014084], [79.83403015, 10.82042122], [79.8345871, 10.8204174], [79.8345871, 10.82069492], [79.83513641, 10.82069492], [79.83513641, 10.8209734], [79.8354187, 10.82096958], [79.8354187, 10.82125092], [79.83598328, 10.82125092], [79.83598328, 10.8215313], [79.83625031, 10.8215313], [79.83625031, 10.82182121], [79.83680725, 10.82180691], [79.83680725, 10.82208347], [79.83734894, 10.82207966], [79.83734894, 10.82236099], [79.8381958, 10.82236099], [79.8381958, 10.82264137], [79.83930206, 10.82264137], [79.83930206, 10.82291889], [79.84041595, 10.82291698], [79.84041595, 10.82319546], [79.84152985, 10.82319546], [79.84152985, 10.82347298], [79.84208679, 10.82347107], [79.84208679, 10.82375145], [79.8429184, 10.82375145], [79.8429184, 10.82403088], [79.84348297, 10.82403088], [79.84348297, 10.82430935], [79.84402466, 10.82430458], [79.84402466, 10.82458305], [79.84486389, 10.82458305], [79.84486389, 10.82486057], [79.84541321, 10.82486057], [79.84541321, 10.82514095], [79.84625244, 10.82514095], [79.84625244, 10.82541943], [79.84680176, 10.82541656], [79.84680939, 10.8255558], [79.84680939, 10.82569504], [79.8473587, 10.82569504], [79.8473587, 10.82597256], [79.85152435, 10.82597256], [79.85152435, 10.82375145], [79.85124969, 10.82375145], [79.85124969, 10.82236099], [79.85097504, 10.82236099], [79.85097504, 10.81986141], [79.85124969, 10.81986141], [79.85124969, 10.81930447], [79.85098267, 10.81931114], [79.85098267, 10.81902885], [79.85069275, 10.81902885], [79.85069275, 10.81792068], [79.85098267, 10.81792068], [79.85098267, 10.81764126], [79.85124969, 10.81764126], [79.85124969, 10.81735992], [79.85097504, 10.81735992], [79.85097504, 10.81708241], [79.85124969, 10.81708241], [79.85124969, 10.81486225], [79.85097504, 10.81486225], [79.85097504, 10.81402779], [79.85124969, 10.81403065], [79.85124969, 10.81377125]]], [[[75.28013611, 11.98874855], [75.2804184, 11.98874855], [75.2804184, 11.98819065], [75.28069305, 11.98819256], [75.28069305, 11.9879179], [75.28098297, 11.98791981], [75.28098297, 11.98764038], [75.28125, 11.98764038], [75.28125, 11.98736095], [75.28151703, 11.98736095], [75.28151703, 11.98708057], [75.28180695, 11.98708344], [75.28180695, 11.98680496], [75.2820816, 11.98680973], [75.2820816, 11.98625183], [75.28235626, 11.98625183], [75.28235626, 11.98569107], [75.28263855, 11.98569489], [75.28263855, 11.98541737], [75.28291321, 11.98542023], [75.28291321, 11.98513889], [75.28320313, 11.98513889], [75.28320313, 11.98403168], [75.28347015, 11.98403168], [75.28347015, 11.98348045], [75.28376007, 11.98348045], [75.28376007, 11.98319054], [75.2840271, 11.9831953], [75.2840271, 11.98263931], [75.28430176, 11.98264122], [75.28430176, 11.98208141], [75.28458405, 11.98208332], [75.28458405, 11.98180485], [75.28430176, 11.98180866], [75.28430176, 11.98152924], [75.28457642, 11.98152924], [75.28457642, 11.98097134], [75.2848587, 11.98097324], [75.2848587, 11.98041725], [75.28514099, 11.98041725], [75.28514099, 11.97958279], [75.28541565, 11.97958279], [75.28541565, 11.97875118], [75.28569794, 11.97875118], [75.28569794, 11.97792053], [75.2859726, 11.97792053], [75.2859726, 11.97708035], [75.28614807, 11.97708035], [75.28652954, 11.97708321], [75.28652954, 11.97625065], [75.28679657, 11.97625065], [75.28679657, 11.97597027], [75.28708649, 11.97597313], [75.28708649, 11.97569466], [75.28736115, 11.97569466], [75.28736115, 11.97513771], [75.2876358, 11.97514057], [75.2876358, 11.97486019], [75.28791809, 11.97486019], [75.28791809, 11.97402859], [75.28848267, 11.97403145], [75.28848267, 11.97346973], [75.28874969, 11.97347164], [75.28874969, 11.97319412], [75.28847504, 11.97319412], [75.28847504, 11.97263813], [75.28874969, 11.97264099], [75.28874969, 11.97235966], [75.28902435, 11.97235966], [75.28901672, 11.97124958], [75.28930664, 11.97124958], [75.28930664, 11.97097015], [75.2895813, 11.97097206], [75.2895813, 11.97041607], [75.28985596, 11.97042274], [75.28985596, 11.96986008], [75.29013824, 11.96986008], [75.29013824, 11.96931076], [75.2904129, 11.96931076], [75.2904129, 11.96903038], [75.29070282, 11.96903038], [75.29070282, 11.9681797], [75.29096985, 11.96819401], [75.29096985, 11.96791553], [75.29125214, 11.9679203], [75.29125214, 11.96708202], [75.29180908, 11.96708393], [75.29180908, 11.96652794], [75.29207611, 11.96652985], [75.29207611, 11.96625042], [75.2923584, 11.96625042], [75.2923584, 11.96569061], [75.29264069, 11.96569443], [75.29264069, 11.96541786], [75.29291534, 11.96541786], [75.29291534, 11.96513844], [75.29319763, 11.96514034], [75.29319763, 11.96486187], [75.29374695, 11.96486187], [75.29374695, 11.96430969], [75.29402924, 11.96430969], [75.29402924, 11.96375179], [75.29429626, 11.96375179], [75.29429626, 11.96347237], [75.29486084, 11.96347237], [75.29486084, 11.9631958], [75.2951355, 11.9631958], [75.2951355, 11.96291542], [75.29541779, 11.96292019], [75.29541779, 11.96263981], [75.29570007, 11.96263981], [75.29569244, 11.96236229], [75.2959671, 11.96237087], [75.2959671, 11.96208096], [75.29624939, 11.96208382], [75.29624939, 11.96152687], [75.29651642, 11.96152973], [75.29651642, 11.96097088], [75.29708099, 11.96097088], [75.29708099, 11.96069336], [75.29736328, 11.96069336], [75.29736328, 11.96041775], [75.29763794, 11.96041965], [75.29763794, 11.96013927], [75.29792023, 11.96013927], [75.29792023, 11.95985889], [75.29846954, 11.9598608], [75.29846954, 11.95958328], [75.29875183, 11.95958328], [75.29875183, 11.95930481], [75.29902649, 11.95930958], [75.29902649, 11.95903015], [75.29957581, 11.95903015], [75.29957581, 11.9584713], [75.29985809, 11.9584713], [75.29985809, 11.95819473], [75.30014038, 11.95819473], [75.30014038, 11.95791721], [75.30042267, 11.95792198], [75.30042267, 11.9576416], [75.30069733, 11.9576416], [75.30069733, 11.95736122], [75.30097198, 11.95736122], [75.30097198, 11.95708275], [75.30124664, 11.95708275], [75.30124664, 11.95680523], [75.30152893, 11.9568119], [75.30152893, 11.95653152], [75.30179596, 11.95653152], [75.30179596, 11.9562397], [75.30208588, 11.95625114], [75.30208588, 11.95569515], [75.30236053, 11.95569515], [75.30236053, 11.95541668], [75.30264282, 11.95541859], [75.30264282, 11.95486069], [75.30291748, 11.95486069], [75.30291748, 11.95430946], [75.30319214, 11.95430946], [75.30319214, 11.95403099], [75.3034668, 11.95403099], [75.3034668, 11.95347118], [75.30374908, 11.95347309], [75.30374908, 11.95319462], [75.30403137, 11.95319462], [75.30403137, 11.95263863], [75.30430603, 11.95264053], [75.30430603, 11.95236111], [75.30458069, 11.95236111], [75.30458069, 11.95180511], [75.30486298, 11.95181084], [75.30486298, 11.95125103], [75.30458069, 11.95125103], [75.30458069, 11.95069027], [75.30430603, 11.95069504], [75.30430603, 11.95041656], [75.30403137, 11.95042992], [75.30403137, 11.94986057], [75.30374908, 11.94986057], [75.30374908, 11.94958305], [75.30319214, 11.94958305], [75.30319214, 11.94930363], [75.30291748, 11.94931126], [75.30291748, 11.94903088], [75.30236053, 11.94903088], [75.30236053, 11.94875145], [75.30208588, 11.94875145], [75.30208588, 11.94847012], [75.30097198, 11.94847298], [75.30097198, 11.94819546], [75.29985809, 11.94819546], [75.29985809, 11.94791603], [75.29886627, 11.94791603], [75.29875183, 11.94791603], [75.29875183, 11.94819546], [75.29846954, 11.94819546], [75.29846954, 11.94847298], [75.29818726, 11.94847012], [75.29818726, 11.94903088], [75.29736328, 11.94903088], [75.29736328, 11.94875145], [75.29708099, 11.94875145], [75.29708099, 11.94847012], [75.29680634, 11.94847298], [75.29680634, 11.94819546], [75.29624939, 11.94819546], [75.29624939, 11.94791603], [75.29597473, 11.94791603], [75.29597473, 11.94819546], [75.29569244, 11.94819546], [75.29569244, 11.94847298], [75.29541779, 11.94847012], [75.29541779, 11.94875145], [75.29514313, 11.94875145], [75.29514313, 11.94931126], [75.29486084, 11.94930363], [75.29486084, 11.94958305], [75.29458618, 11.94958305], [75.29458618, 11.94986057], [75.29430389, 11.94986057], [75.29430389, 11.95069504], [75.29374695, 11.95069504], [75.29374695, 11.95097256], [75.29347229, 11.9509697], [75.29347229, 11.95125103], [75.29292297, 11.95125103], [75.29292297, 11.95153141], [75.29264069, 11.95153141], [75.29264069, 11.95181084], [75.2923584, 11.95180511], [75.2923584, 11.95208263], [75.29208374, 11.95208263], [75.29208374, 11.95236111], [75.29180908, 11.95236111], [75.29180908, 11.95292091], [75.29125214, 11.9529171], [75.29125214, 11.95319462], [75.29096985, 11.95319462], [75.29096985, 11.95347309], [75.29070282, 11.95347118], [75.29070282, 11.95375061], [75.29013824, 11.95375061], [75.29013824, 11.95403099], [75.28956604, 11.95403099], [75.28956604, 11.95430946], [75.28930664, 11.95430946], [75.28930664, 11.95486069], [75.28901672, 11.95486069], [75.28901672, 11.95514107], [75.28874969, 11.95514107], [75.28874969, 11.95541859], [75.28847504, 11.95541668], [75.28847504, 11.95569515], [75.28819275, 11.95569515], [75.28819275, 11.95597267], [75.28791809, 11.95597267], [75.28791809, 11.95625114], [75.2876358, 11.9562397], [75.2876358, 11.9568119], [75.28736115, 11.95680523], [75.28736115, 11.95736122], [75.28708649, 11.95736122], [75.28708649, 11.9576416], [75.2868042, 11.95763874], [75.2868042, 11.95819473], [75.28652954, 11.95819473], [75.28652954, 11.9584713], [75.28624725, 11.9584713], [75.28624725, 11.95903015], [75.2859726, 11.95902729], [75.2859726, 11.95958328], [75.28569794, 11.95958328], [75.28569794, 11.9598608], [75.28542328, 11.95985889], [75.28542328, 11.96013927], [75.28514099, 11.96013927], [75.28514099, 11.96069336], [75.28457642, 11.96069145], [75.28457642, 11.96124935], [75.28430939, 11.96124935], [75.28430176, 11.96181011], [75.2840271, 11.96181011], [75.2840271, 11.96237087], [75.28375244, 11.96236229], [75.28376007, 11.96263981], [75.28347015, 11.96263981], [75.28347015, 11.96292019], [75.2831955, 11.96291542], [75.2831955, 11.96347237], [75.28291321, 11.96347237], [75.28291321, 11.96375179], [75.28263855, 11.96375179], [75.28263855, 11.96403027], [75.28236389, 11.96402836], [75.28236389, 11.96458435], [75.2820816, 11.96458054], [75.2820816, 11.96514034], [75.28152466, 11.96514034], [75.28152466, 11.96597195], [75.28098297, 11.96597195], [75.28098297, 11.96652985], [75.28070068, 11.96652985], [75.28070068, 11.96681023], [75.2804184, 11.96680641], [75.2804184, 11.9673624], [75.28013611, 11.96735954], [75.28013611, 11.9679203], [75.27986145, 11.9679203], [75.27986145, 11.96903038], [75.27958679, 11.96902847], [75.27958679, 11.96958447], [75.27902985, 11.9695797], [75.27902985, 11.96986008], [75.27874756, 11.96986008], [75.27874756, 11.97014046], [75.27819824, 11.9701376], [75.27819824, 11.97069359], [75.27791595, 11.97069359], [75.27791595, 11.97097206], [75.27762604, 11.97097015], [75.27762604, 11.97154045], [75.27735901, 11.97152805], [75.27735901, 11.97208214], [75.27708435, 11.97208214], [75.27708435, 11.97236156], [75.27680206, 11.97235966], [75.27680206, 11.97292137], [75.27625275, 11.97291565], [75.27625275, 11.97319412], [75.27597046, 11.97319031], [75.27597046, 11.97375011], [75.2756958, 11.97375011], [75.2756958, 11.97431087], [75.27541351, 11.9743042], [75.27541351, 11.97486019], [75.27513885, 11.97486019], [75.27513885, 11.97514057], [75.27485657, 11.97514057], [75.27485657, 11.97542095], [75.27458191, 11.97541714], [75.27458191, 11.97569466], [75.27430725, 11.9756918], [75.27430725, 11.97625065], [75.27401733, 11.97625065], [75.27401733, 11.97653103], [75.27375031, 11.97652912], [75.27375031, 11.97708321], [75.27348328, 11.97708035], [75.27348328, 11.97764111], [75.27319336, 11.97764111], [75.27319336, 11.97792053], [75.27263641, 11.97791672], [75.27263641, 11.97847271], [75.27236176, 11.9784708], [75.27236176, 11.97903061], [75.27180481, 11.97902679], [75.27180481, 11.97958279], [75.27153015, 11.97958279], [75.27153015, 11.97986126], [75.27124786, 11.97986126], [75.27124786, 11.98041725], [75.27097321, 11.98041725], [75.27097321, 11.98097324], [75.27069092, 11.98097324], [75.27069092, 11.98124886], [75.27041626, 11.98124886], [75.27041626, 11.98180866], [75.2701416, 11.98180485], [75.2701416, 11.98208332], [75.26985931, 11.98208141], [75.26985931, 11.98236084], [75.26930237, 11.98236084], [75.26930237, 11.98264122], [75.26902771, 11.98263931], [75.26902771, 11.9831953], [75.26875305, 11.9831953], [75.26876068, 11.9837513], [75.26847076, 11.9837513], [75.26847076, 11.98431015], [75.26819611, 11.98430538], [75.26819611, 11.9845829], [75.26763916, 11.98458099], [75.26763916, 11.98513889], [75.26735687, 11.98513889], [75.26735687, 11.98542023], [75.26708221, 11.98541737], [75.26708221, 11.98597336], [75.26680756, 11.98597145], [75.26680756, 11.98625183], [75.2665329, 11.98625183], [75.2665329, 11.98654079], [75.26625061, 11.98654079], [75.26625061, 11.98680973], [75.26597595, 11.98680496], [75.26597595, 11.98708344], [75.26568604, 11.98708057], [75.26568604, 11.98736095], [75.26513672, 11.98736095], [75.26513672, 11.98791981], [75.26486206, 11.9879179], [75.26486206, 11.98847103], [75.26430511, 11.98847103], [75.26431274, 11.98874855], [75.26403046, 11.98874855], [75.26403046, 11.98931026], [75.26374817, 11.98930645], [75.26374817, 11.98986244], [75.26346588, 11.98986244], [75.26346588, 11.99014187], [75.26291656, 11.99013996], [75.26291656, 11.99069405], [75.26235962, 11.99069118], [75.26235962, 11.99125195], [75.26207733, 11.99125195], [75.26207733, 11.99180984], [75.26180267, 11.99180603], [75.26180267, 11.99208355], [75.26152802, 11.99208164], [75.26152802, 11.99263954], [75.26125336, 11.99263954], [75.26125336, 11.99291992], [75.26097107, 11.99291801], [75.26097107, 11.99319363], [75.26069641, 11.99319363], [75.26069641, 11.9934721], [75.26040649, 11.99347019], [75.26040649, 11.99374962], [75.26013947, 11.99374962], [75.26013947, 11.99431133], [75.25959015, 11.99431133], [75.25959015, 11.99514008], [75.25930786, 11.99514008], [75.25930786, 11.99542046], [75.25902557, 11.99541569], [75.25902557, 11.99569416], [75.25875092, 11.99568939], [75.25875092, 11.99625015], [75.25846863, 11.99625015], [75.25846863, 11.99652958], [75.25819397, 11.99652767], [75.25819397, 11.99708366], [75.25763702, 11.99707985], [75.25763702, 11.99763966], [75.25736237, 11.99763966], [75.25736237, 11.99792099], [75.25708008, 11.99792099], [75.25708008, 11.9984808], [75.25682068, 11.9984808], [75.25682068, 11.99874973], [75.25653076, 11.99874973], [75.25653076, 11.99931145], [75.25624847, 11.99930573], [75.25624847, 11.99958229], [75.25596619, 11.99958038], [75.25596619, 12.00014114], [75.25541687, 12.00014114], [75.25541687, 12.00042057], [75.25514221, 12.0004158], [75.25514221, 12.00069427], [75.25485992, 12.00069046], [75.25485992, 12.00125122], [75.25430298, 12.00125122], [75.25430298, 12.00181103], [75.25402832, 12.00180435], [75.25402832, 12.00208473], [75.25374603, 12.00207996], [75.25374603, 12.00264072], [75.25319672, 12.00264072], [75.25319672, 12.0029211], [75.25291443, 12.00291729], [75.25291443, 12.00347328], [75.25263977, 12.00347042], [75.25263977, 12.00403118], [75.25208282, 12.00402641], [75.25208282, 12.00458336], [75.25180817, 12.00457954], [75.25180817, 12.00486088], [75.25152588, 12.00486088], [75.25152588, 12.00514126], [75.25125122, 12.00513935], [75.25125122, 12.00569534], [75.25096893, 12.00568962], [75.25096893, 12.00625134], [75.25041962, 12.00625134], [75.25041962, 12.00653076], [75.24986267, 12.00652885], [75.24986267, 12.00708294], [75.24958038, 12.00708294], [75.24958038, 12.00736141], [75.24946594, 12.00736141], [75.24931335, 12.00736141], [75.24931335, 12.00791931], [75.24874878, 12.0079174], [75.24874878, 12.00819016], [75.24846649, 12.00819969], [75.24846649, 12.00875092], [75.24819183, 12.00875092], [75.24819183, 12.0090313], [75.24765015, 12.0090313], [75.24765015, 12.00931168], [75.24736023, 12.00931168], [75.24736023, 12.00986099], [75.2470932, 12.00986099], [75.2470932, 12.01041889], [75.24680328, 12.01041698], [75.24680328, 12.01069546], [75.24624634, 12.01069546], [75.24624634, 12.01097107], [75.24569702, 12.01097107], [75.24569702, 12.01153183], [75.2454071, 12.01153183], [75.2454071, 12.0118103], [75.24485779, 12.01180458], [75.24485779, 12.01236057], [75.24430847, 12.01236057], [75.24430847, 12.01264191], [75.24402618, 12.01264191], [75.24402618, 12.01292038], [75.24375153, 12.01291656], [75.24375153, 12.01319313], [75.24346924, 12.01319313], [75.24346924, 12.01347446], [75.24318695, 12.01346016], [75.24318695, 12.01375198], [75.24291992, 12.01375198], [75.24291992, 12.01431179], [75.24236298, 12.01430511], [75.24236298, 12.01458263], [75.24180603, 12.01458263], [75.24180603, 12.01486206], [75.24124908, 12.0148592], [75.24124908, 12.01541996], [75.24069214, 12.01541805], [75.24069214, 12.01569557], [75.24041748, 12.01569557], [75.24041748, 12.01597118], [75.23986053, 12.01596928], [75.23986053, 12.0162487], [75.23958588, 12.0162487], [75.23958588, 12.01652813], [75.23929596, 12.01652145], [75.23929596, 12.01681042], [75.23874664, 12.01680565], [75.23874664, 12.01708412], [75.23851013, 12.01708412], [75.23819733, 12.01708412], [75.23819733, 12.01719093], [75.23819733, 12.01736164], [75.23792267, 12.01736164], [75.23792267, 12.01764202], [75.23735809, 12.01764202], [75.23735809, 12.01791954], [75.23680878, 12.01791573], [75.23680878, 12.0181942], [75.23652649, 12.0181942], [75.23652649, 12.01847172], [75.23596954, 12.01846886], [75.23596954, 12.01875019], [75.23568726, 12.01875019], [75.23568726, 12.01902962], [75.23513794, 12.01902962], [75.23513794, 12.01931], [75.23430634, 12.01930618], [75.23430634, 12.0195837], [75.23374939, 12.0195837], [75.23374939, 12.01986217], [75.2334671, 12.01986027], [75.2334671, 12.02013969], [75.23319244, 12.02013969], [75.23319244, 12.02042007], [75.23291779, 12.02041626], [75.23291779, 12.02069378], [75.2326355, 12.02069378], [75.2326355, 12.02097225], [75.23236084, 12.02097034], [75.23236084, 12.02265167], [75.23208618, 12.02265167], [75.23208618, 12.02292061], [75.23236084, 12.02291584], [75.23236084, 12.02347183], [75.23208618, 12.02346992], [75.23208618, 12.02375031], [75.23179626, 12.02375031], [75.23179626, 12.02402973], [75.23069763, 12.02402782], [75.23069763, 12.02414036], [75.23105621, 12.02456188], [75.22492218, 12.03195], [75.22735596, 12.04430103], [75.22367096, 12.05447102], [75.2231369, 12.06444168], [75.22424316, 12.07438087], [75.22225952, 12.07815075], [75.22245789, 12.08556938], [75.22113037, 12.10095119], [75.22306061, 12.10484028], [75.23660278, 12.11023045], [75.24053192, 12.10926056], [75.24344635, 12.10467052], [75.24739075, 12.1036911], [75.25588989, 12.10857964], [75.25985718, 12.10893059], [75.26602173, 12.10366058], [75.2745285, 12.10026073], [75.27781677, 12.1017704], [75.28198242, 12.1091404], [75.28392792, 12.11498165], [75.29277039, 12.11613274], [75.31067657, 12.12473202], [75.3098526, 12.13204956], [75.31115723, 12.1364603], [75.31429291, 12.14009953], [75.32064056, 12.14352131], [75.32515717, 12.14489079], [75.33112335, 12.14515114], [75.33522797, 12.14400196], [75.34194946, 12.13718033], [75.34616089, 12.13861179], [75.34784698, 12.13530922], [75.36360931, 12.13496971], [75.36669159, 12.13537979], [75.36826324, 12.14007854], [75.37149048, 12.14262962], [75.37201691, 12.14647007], [75.37460327, 12.14908028], [75.37838745, 12.14603043], [75.38852692, 12.14629173], [75.39392853, 12.14548111], [75.39982605, 12.14050102], [75.40251923, 12.13684082], [75.4021759, 12.13414001], [75.39823914, 12.12987137], [75.39215088, 12.12634087], [75.38308716, 12.12397957], [75.38228607, 12.12912083], [75.37993622, 12.12639141], [75.37930298, 12.12213993], [75.37548065, 12.12341022], [75.3685379, 12.12126064], [75.36592102, 12.11693001], [75.36267853, 12.11610985], [75.35790253, 12.11290073], [75.3553009, 12.10936069], [75.35193634, 12.10885143], [75.3398819, 12.09825134], [75.33598328, 12.09864044], [75.32998657, 12.10258961], [75.32817841, 12.10727978], [75.31962585, 12.10665131], [75.31288147, 12.10531139], [75.30906677, 12.10266113], [75.30964661, 12.09063053], [75.3147583, 12.08760929], [75.30916595, 12.07843971], [75.29917145, 12.06679153], [75.29737091, 12.06365108], [75.2961731, 12.05924129], [75.30066681, 12.05802059], [75.30480957, 12.0529213], [75.30879211, 12.05379105], [75.3116684, 12.04930592], [75.31014252, 12.04931068], [75.31014252, 12.0490303], [75.30986023, 12.0490303], [75.30986023, 12.04931068], [75.30847168, 12.04931068], [75.30847168, 12.0490303], [75.30819702, 12.0490303], [75.30819702, 12.04874992], [75.3079071, 12.04874992], [75.3079071, 12.04846954], [75.30764008, 12.0484724], [75.30764008, 12.04819393], [75.30735779, 12.04819393], [75.30735779, 12.04708385], [75.30764008, 12.04708385], [75.30764008, 12.04680634], [75.30735779, 12.04681969], [75.30735779, 12.04597187], [75.30708313, 12.04597187], [75.30708313, 12.04514027], [75.30680847, 12.04514027], [75.30680847, 12.04486179], [75.30652618, 12.04486179], [75.30652618, 12.04458141], [75.30625153, 12.04458427], [75.30625153, 12.04402828], [75.30596924, 12.04403019], [75.30596924, 12.04319096], [75.30569458, 12.04319572], [75.30569458, 12.04263973], [75.30541992, 12.04263973], [75.30541992, 12.04208088], [75.30513763, 12.04208374], [75.30513763, 12.04152679], [75.30486298, 12.04152966], [75.30486298, 12.04124928], [75.30458069, 12.04124928], [75.30458069, 12.0401392], [75.30430603, 12.0401392], [75.30430603, 12.03903198], [75.30458069, 12.03903198], [75.30458069, 12.03792191], [75.30486298, 12.03792191], [75.30486298, 12.03736115], [75.30513763, 12.03736115], [75.30513763, 12.03708267], [75.30486298, 12.03708267], [75.30486298, 12.03680515], [75.30458069, 12.03680515], [75.30458069, 12.03708267], [75.30403137, 12.03708267], [75.30403137, 12.03736115], [75.30347443, 12.03736115], [75.30347443, 12.03708267], [75.30319214, 12.03708267], [75.30319214, 12.03680515], [75.30291748, 12.03681183], [75.30291748, 12.0365324], [75.30264282, 12.0365324], [75.30264282, 12.03625107], [75.30291748, 12.03625107], [75.30291748, 12.03569126], [75.30319214, 12.03569508], [75.30319214, 12.0354166], [75.3034668, 12.03541946], [75.3034668, 12.03514099], [75.30374908, 12.03514099], [75.30374908, 12.03403091], [75.3034668, 12.03403091], [75.3034668, 12.03375053], [75.30319214, 12.03375053], [75.30319214, 12.03347111], [75.30291748, 12.03347301], [75.30291748, 12.03319454], [75.30180359, 12.03319454], [75.30180359, 12.03347301], [75.30152893, 12.03347111], [75.30152893, 12.03375053], [75.30097198, 12.03375053], [75.30097198, 12.03347111], [75.30069733, 12.03347301], [75.30069733, 12.03319454], [75.30041504, 12.03319454], [75.30041504, 12.03263855], [75.30014038, 12.03264141], [75.30014038, 12.03151989], [75.29985809, 12.03152657], [75.29985809, 12.03041744], [75.29957581, 12.03042126], [75.29957581, 12.02931118], [75.29930878, 12.02931118], [75.29930878, 12.02818966], [75.29958344, 12.02819443], [75.29958344, 12.02791595], [75.29985809, 12.02792072], [75.29985809, 12.02735996], [75.30014038, 12.02735996], [75.30014038, 12.02707958], [75.30041504, 12.0270853], [75.30041504, 12.02680588], [75.30069733, 12.02681065], [75.30069733, 12.02653122], [75.30097198, 12.02653122], [75.30097198, 12.02597046], [75.30124664, 12.02597237], [75.30124664, 12.02541637], [75.30152893, 12.02542114], [75.30152893, 12.02460003], [75.30097198, 12.02458382], [75.30097198, 12.02486229], [75.29985809, 12.02486038], [75.29985809, 12.02514267], [75.29902649, 12.0251379], [75.29902649, 12.02569389], [75.29930878, 12.02569199], [75.29930878, 12.02625275], [75.29902649, 12.02625275], [75.29902649, 12.02681065], [75.29875183, 12.02680588], [75.29875183, 12.0270853], [75.29846954, 12.02707958], [75.29846954, 12.0276413], [75.29819489, 12.02763844], [75.29819489, 12.02819443], [75.29792023, 12.02819443], [75.29792023, 12.0284729], [75.29736328, 12.02846146], [75.29736328, 12.02875137], [75.29708099, 12.02875137], [75.29708099, 12.0290308], [75.29651642, 12.0290308], [75.29651642, 12.02931118], [75.29624939, 12.02930355], [75.29624939, 12.02985954], [75.2959671, 12.02985954], [75.2959671, 12.03042126], [75.29569244, 12.03041744], [75.29569244, 12.03069496], [75.2951355, 12.03069496], [75.2951355, 12.03097343], [75.29486084, 12.03097343], [75.29486084, 12.03152657], [75.29458618, 12.03151989], [75.29458618, 12.03181076], [75.29319763, 12.03181076], [75.29319763, 12.03151989], [75.29292297, 12.03151989], [75.29292297, 12.03181076], [75.29207611, 12.03181076], [75.29207611, 12.03151989], [75.29180908, 12.03152657], [75.29180908, 12.03069496], [75.29152679, 12.03069496], [75.29152679, 12.03041744], [75.29180908, 12.03042126], [75.29180908, 12.02985954], [75.29208374, 12.02985954], [75.29208374, 12.02958202], [75.2923584, 12.02958202], [75.2923584, 12.02930355], [75.29264069, 12.02931118], [75.29264069, 12.0290308], [75.29292297, 12.0290308], [75.29292297, 12.02846146], [75.29319763, 12.0284729], [75.29319763, 12.02791595], [75.29347229, 12.02792072], [75.29347229, 12.0276413], [75.29402924, 12.0276413], [75.29402924, 12.02792072], [75.29541779, 12.02792072], [75.29541779, 12.0276413], [75.29570007, 12.0276413], [75.29570007, 12.02735996], [75.29624939, 12.02735996], [75.29624939, 12.02707958], [75.29680634, 12.0270853], [75.29680634, 12.02680588], [75.29736328, 12.02681065], [75.29736328, 12.02653122], [75.29763794, 12.02653122], [75.29763794, 12.02597046], [75.29736328, 12.02597237], [75.29736328, 12.02569389], [75.29652405, 12.02569389], [75.29652405, 12.02541637], [75.29541779, 12.02542114], [75.29541779, 12.02514267], [75.29486084, 12.02514267], [75.29486084, 12.02486038], [75.29458618, 12.02486229], [75.29458618, 12.02458382], [75.29430389, 12.02458191], [75.29430389, 12.02375031], [75.29402924, 12.02375031], [75.29402924, 12.02292061], [75.29374695, 12.02292061], [75.29374695, 12.02181053], [75.29402924, 12.02181053], [75.29402924, 12.02125168], [75.29458618, 12.02125168], [75.29458618, 12.02097034], [75.29486084, 12.02097225], [75.29486084, 12.02069378], [75.2951355, 12.02069378], [75.2951355, 12.02041626], [75.29541779, 12.02042007], [75.29541779, 12.02013969], [75.29570007, 12.02013969], [75.29570007, 12.01958179], [75.29597473, 12.0195837], [75.29597473, 12.01902771], [75.29624939, 12.01902962], [75.29624939, 12.01791954], [75.2959671, 12.01791954], [75.2959671, 12.01764202], [75.29458618, 12.01764202], [75.29458618, 12.01791954], [75.29402924, 12.01791954], [75.29402924, 12.01764202], [75.29319763, 12.01764202], [75.29319763, 12.01791954], [75.29291534, 12.01791573], [75.29291534, 12.01847172], [75.29264069, 12.01846886], [75.29264069, 12.01902962], [75.2923584, 12.01902962], [75.2923584, 12.01931], [75.29180908, 12.01930618], [75.29180908, 12.0195837], [75.29125214, 12.01958179], [75.29125214, 12.02013969], [75.29096985, 12.02013779], [75.29096985, 12.02069378], [75.29125214, 12.02069187], [75.29125214, 12.02125168], [75.29152679, 12.02124977], [75.29152679, 12.02208424], [75.29096985, 12.02208424], [75.29096985, 12.02235985], [75.29070282, 12.02235985], [75.29070282, 12.02265167], [75.2904129, 12.02264023], [75.2904129, 12.02319431], [75.29069519, 12.02319431], [75.29069519, 12.02375031], [75.29096985, 12.02375031], [75.29096985, 12.02402973], [75.29125214, 12.02402973], [75.29125214, 12.02431107], [75.29180908, 12.02431107], [75.29180908, 12.02542114], [75.29152679, 12.02541637], [75.29152679, 12.02597237], [75.29125214, 12.02597046], [75.29125214, 12.02681065], [75.29152679, 12.02681065], [75.29152679, 12.02735996], [75.29125214, 12.02735996], [75.29125214, 12.0276413], [75.29096985, 12.0276413], [75.29096985, 12.02792072], [75.28986359, 12.02791595], [75.28986359, 12.02819443], [75.28930664, 12.02819443], [75.28930664, 12.0284729], [75.28901672, 12.02846146], [75.28902435, 12.02875137], [75.28848267, 12.02875137], [75.28848267, 12.0290308], [75.28708649, 12.0290308], [75.28708649, 12.02931118], [75.2868042, 12.02930355], [75.2868042, 12.02958202], [75.28652954, 12.02958202], [75.28652954, 12.02985954], [75.2859726, 12.02985954], [75.2859726, 12.02958202], [75.28569794, 12.02958202], [75.28569794, 12.02930355], [75.28542328, 12.02931118], [75.28542328, 12.02875137], [75.28514099, 12.02875137], [75.28514099, 12.02818966], [75.2848587, 12.02819443], [75.2848587, 12.02791595], [75.28430176, 12.02792072], [75.28430176, 12.0276413], [75.28376007, 12.0276413], [75.28376007, 12.02681065], [75.2840271, 12.02681065], [75.2840271, 12.02653122], [75.2848587, 12.02653122], [75.2848587, 12.02625275], [75.28542328, 12.02625275], [75.28542328, 12.02597046], [75.28569794, 12.02597237], [75.28569794, 12.02569389], [75.2859726, 12.02569389], [75.2859726, 12.02541637], [75.28624725, 12.02542114], [75.28624725, 12.02486038], [75.28652954, 12.02486229], [75.28652954, 12.0243063], [75.28624725, 12.02431107], [75.28624725, 12.02375031], [75.2859726, 12.02375031], [75.2859726, 12.02402973], [75.28542328, 12.02402973], [75.28542328, 12.02431107], [75.28514099, 12.0243063], [75.28514099, 12.02458191], [75.2848587, 12.02458382], [75.2848587, 12.02486229], [75.28430939, 12.02486038], [75.28430176, 12.02514267], [75.2840271, 12.02514267], [75.2840271, 12.02542114], [75.28347015, 12.02541637], [75.28347015, 12.02569389], [75.2804184, 12.02569389], [75.2804184, 12.02541637], [75.27986145, 12.02542114], [75.27986145, 12.02514267], [75.27929688, 12.02514267], [75.27929688, 12.02486038], [75.27791595, 12.02486038], [75.27791595, 12.02514267], [75.27707672, 12.02514267], [75.27707672, 12.02542114], [75.27625275, 12.02541637], [75.27625275, 12.02569389], [75.2748642, 12.02569389], [75.2748642, 12.02597237], [75.27401733, 12.02597046], [75.27401733, 12.02653122], [75.27348328, 12.02653122], [75.27348328, 12.02681065], [75.27319336, 12.02681065], [75.27319336, 12.02735996], [75.2729187, 12.02735996], [75.2729187, 12.0276413], [75.27263641, 12.02763844], [75.27263641, 12.02819443], [75.2729187, 12.02818966], [75.2729187, 12.02875137], [75.27263641, 12.02875137], [75.27263641, 12.02931118], [75.27236176, 12.02930355], [75.27236176, 12.02958202], [75.27097321, 12.02958202], [75.27097321, 12.02930355], [75.27069092, 12.02931118], [75.27069092, 12.0290308], [75.27041626, 12.0290308], [75.27041626, 12.02875137], [75.2701416, 12.02875137], [75.2701416, 12.02846146], [75.27041626, 12.0284729], [75.27041626, 12.02819443], [75.27069092, 12.02819443], [75.27069092, 12.02791595], [75.27097321, 12.02792072], [75.27097321, 12.02681065], [75.2701416, 12.02681065], [75.2701416, 12.02653122], [75.26985931, 12.02653122], [75.26985931, 12.02625275], [75.26930237, 12.02625275], [75.26930237, 12.02569199], [75.26847076, 12.02569389], [75.26847076, 12.02541637], [75.26763916, 12.02542114], [75.26763916, 12.02486038], [75.2673645, 12.02486229], [75.2673645, 12.02402782], [75.26708221, 12.02402973], [75.26708221, 12.02318859], [75.26652527, 12.02319431], [75.26652527, 12.02264023], [75.26625061, 12.02265167], [75.26625061, 12.02208042], [75.26597595, 12.02208424], [75.26597595, 12.02152824], [75.26568604, 12.02153015], [75.26568604, 12.02097034], [75.26541901, 12.02097225], [75.26541901, 12.02041626], [75.26513672, 12.02042007], [75.26513672, 12.01986027], [75.26486206, 12.01986217], [75.26486206, 12.01930618], [75.26457977, 12.01931], [75.26457977, 12.01846886], [75.26430511, 12.01847172], [75.26430511, 12.01764011], [75.26403046, 12.01764202], [75.26403046, 12.01708126], [75.26374817, 12.01708412], [75.26374817, 12.01597118], [75.26347351, 12.01597118], [75.26347351, 12.01458263], [75.26319122, 12.01458263], [75.26319122, 12.01347446], [75.26291656, 12.01347446], [75.26291656, 12.01208305], [75.26264191, 12.01208305], [75.26264191, 12.00902653], [75.26235962, 12.0090313], [75.26235962, 12.00625134], [75.26262665, 12.00625134], [75.26262665, 12.00542068], [75.26291656, 12.00542068], [75.26291656, 12.00431061], [75.26319122, 12.00431061], [75.26319122, 12.00347042], [75.26347351, 12.00347328], [75.26347351, 12.00291729], [75.26374817, 12.0029211], [75.26374817, 12.00264072], [75.26403046, 12.00264072], [75.26403046, 12.00236034], [75.26430511, 12.00236034], [75.26430511, 12.00208473], [75.26457977, 12.00208473], [75.26457977, 12.00180435], [75.26486206, 12.00181103], [75.26486206, 12.0015192], [75.26513672, 12.00152874], [75.26513672, 12.00125122], [75.26568604, 12.00125122], [75.26568604, 12.00097179], [75.26597595, 12.00097179], [75.26597595, 12.00069046], [75.26652527, 12.00069427], [75.26652527, 12.0004158], [75.26819611, 12.00042057], [75.26819611, 12.00014114], [75.26876068, 12.00014114], [75.26876068, 11.99986267], [75.26930237, 11.99986267], [75.26930237, 11.99958038], [75.2701416, 11.99958229], [75.2701416, 11.99930573], [75.27069092, 11.99931145], [75.27069092, 11.99874973], [75.27097321, 11.99874973], [75.27097321, 11.9984808], [75.27153015, 11.9984808], [75.27153015, 11.99819183], [75.2720871, 11.99819374], [75.2720871, 11.99791622], [75.27236176, 11.99792099], [75.27236176, 11.99736023], [75.2729187, 11.99736214], [75.2729187, 11.99680614], [75.27319336, 11.99681091], [75.27319336, 11.99625015], [75.27375031, 11.99625015], [75.27375031, 11.99597168], [75.27430725, 11.99597168], [75.27430725, 11.99569416], [75.27458191, 11.99569416], [75.27458191, 11.99514008], [75.27485657, 11.99514008], [75.27485657, 11.9948597], [75.27513885, 11.9948597], [75.27513885, 11.99457932], [75.2756958, 11.99458408], [75.2756958, 11.99374962], [75.27597046, 11.99374962], [75.27597046, 11.99347019], [75.27625275, 11.9934721], [75.27625275, 11.99319363], [75.2765274, 11.99319363], [75.2765274, 11.99291801], [75.27680206, 11.99291992], [75.27680206, 11.99234962], [75.27735901, 11.99236202], [75.27735901, 11.99180603], [75.27762604, 11.99180984], [75.27762604, 11.99153042], [75.27791595, 11.99153042], [75.27791595, 11.99125195], [75.27819061, 11.99125195], [75.27819824, 11.99069118], [75.2784729, 11.99069405], [75.2784729, 11.99041462], [75.27874756, 11.99042034], [75.27874756, 11.99014187], [75.27902985, 11.99014187], [75.27902985, 11.98986244], [75.2793045, 11.98986244], [75.2793045, 11.98930645], [75.27958679, 11.98931026], [75.27958679, 11.98903179], [75.28013611, 11.98903179], [75.28013611, 11.98874855]]], [[[82.25875092, 16.69011116], [82.25875092, 16.69069481], [82.25846863, 16.69069481], [82.25846863, 16.69180489], [82.25819397, 16.69180489], [82.25819397, 16.69208336], [82.25791931, 16.69207954], [82.25791931, 16.69292068], [82.25763702, 16.69292068], [82.25763702, 16.6973629], [82.25736237, 16.6973629], [82.25736237, 16.69791985], [82.25763702, 16.69791603], [82.25763702, 16.6981945], [82.25791931, 16.69819069], [82.25791931, 16.70181084], [82.25930786, 16.70180511], [82.25930786, 16.70208359], [82.26069641, 16.70208359], [82.26069641, 16.70236206], [82.26235962, 16.70236206], [82.26235962, 16.70263863], [82.26291656, 16.702631], [82.26291656, 16.70292091], [82.26568604, 16.70292091], [82.26568604, 16.702631], [82.26791382, 16.70263863], [82.26791382, 16.70236206], [82.2701416, 16.70236206], [82.2701416, 16.70208359], [82.27069092, 16.70208359], [82.27069092, 16.70180511], [82.27179718, 16.70181084], [82.27179718, 16.70153046], [82.27319336, 16.70153046], [82.27319336, 16.70125008], [82.27401733, 16.70125008], [82.27401733, 16.7009697], [82.27513885, 16.7009716], [82.27513885, 16.70069695], [82.27597046, 16.70070076], [82.27597046, 16.70042038], [82.27707672, 16.70042038], [82.27707672, 16.70014], [82.27791595, 16.70014], [82.27791595, 16.69985962], [82.27874756, 16.69986153], [82.27874756, 16.69958305], [82.27929688, 16.69959068], [82.27929688, 16.6993103], [82.2804184, 16.6993103], [82.2804184, 16.69902992], [82.28124237, 16.69902992], [82.28124237, 16.69874954], [82.28235626, 16.69874954], [82.28235626, 16.69847107], [82.2831955, 16.69847488], [82.2831955, 16.6981945], [82.28458405, 16.6981945], [82.28458405, 16.69791603], [82.28514099, 16.69791985], [82.28514099, 16.69763947], [82.28539276, 16.69763947], [82.28515625, 16.6974411], [82.27633667, 16.69310951], [82.26467133, 16.69053078], [82.25875092, 16.69011116]]], [[[82.29938507, 16.71402931], [82.29930878, 16.71388054], [82.29930878, 16.71375084], [82.29902649, 16.71375084], [82.29902649, 16.71347046], [82.29846954, 16.71347237], [82.29846954, 16.71291733], [82.29818726, 16.71292114], [82.29818726, 16.71236038], [82.29763794, 16.71236038], [82.29763794, 16.7118206], [82.29736328, 16.7118206], [82.29736328, 16.71153069], [82.29708099, 16.71153069], [82.29708099, 16.71125031], [82.29680634, 16.71125031], [82.29680634, 16.71096992], [82.29652405, 16.71097374], [82.29652405, 16.71041679], [82.29624176, 16.71042061], [82.29624176, 16.71014023], [82.2959671, 16.71014023], [82.2959671, 16.70985985], [82.29541779, 16.70986366], [82.29541779, 16.70958138], [82.2951355, 16.70958138], [82.2951355, 16.70930481], [82.29486084, 16.70930481], [82.29486084, 16.70902824], [82.29458618, 16.70903015], [82.29458618, 16.70876122], [82.29429626, 16.70876122], [82.29429626, 16.70846939], [82.29402924, 16.70846939], [82.29402924, 16.70819473], [82.29347229, 16.70819473], [82.29347229, 16.70791626], [82.29207611, 16.70792007], [82.29207611, 16.7076416], [82.29125214, 16.7076416], [82.29125214, 16.70735931], [82.28847504, 16.70735931], [82.28847504, 16.70708275], [82.28791809, 16.70708084], [82.28791809, 16.70735931], [82.28708649, 16.70735931], [82.28708649, 16.70708084], [82.28624725, 16.70708084], [82.28624725, 16.70735931], [82.28569794, 16.70735931], [82.28569794, 16.7076416], [82.28069305, 16.7076416], [82.28069305, 16.70792007], [82.2793045, 16.70791626], [82.2793045, 16.70819473], [82.27180481, 16.70819473], [82.27180481, 16.70846939], [82.27069092, 16.70846939], [82.27069092, 16.70903015], [82.2701416, 16.70902824], [82.2701416, 16.70930481], [82.26958466, 16.70930481], [82.26958466, 16.70958138], [82.26930237, 16.70958138], [82.26930237, 16.70986366], [82.26902771, 16.70985985], [82.26902771, 16.71014023], [82.26875305, 16.71014023], [82.26875305, 16.71042061], [82.26847076, 16.71042061], [82.26847076, 16.71070099], [82.26790619, 16.71070099], [82.26790619, 16.71125031], [82.26735687, 16.71125031], [82.26735687, 16.71153069], [82.2665329, 16.71153069], [82.2665329, 16.7118206], [82.26625061, 16.71180534], [82.26625061, 16.71208572], [82.26541901, 16.71208], [82.26541901, 16.71236038], [82.26513672, 16.71236038], [82.26513672, 16.71264076], [82.26486206, 16.71264076], [82.26486206, 16.71292114], [82.26457977, 16.71291733], [82.26457977, 16.7131958], [82.26430511, 16.7131958], [82.26430511, 16.71347237], [82.26374817, 16.71347046], [82.26374817, 16.71375084], [82.26319885, 16.71375084], [82.26319885, 16.71403122], [82.26264191, 16.71403122], [82.26264191, 16.71430969], [82.26208496, 16.71430588], [82.26208496, 16.71458244], [82.26152802, 16.714571], [82.26152802, 16.71486092], [82.26125336, 16.71486092], [82.26125336, 16.71513939], [82.26040649, 16.71513939], [82.26040649, 16.71541977], [82.25958252, 16.71541786], [82.25958252, 16.71569443], [82.25875092, 16.71569443], [82.25875092, 16.7159729], [82.25818634, 16.71597099], [82.25818634, 16.71624947], [82.25763702, 16.71624947], [82.25763702, 16.71652985], [82.25707245, 16.71652985], [82.25707245, 16.71681023], [82.25597382, 16.71680641], [82.25597382, 16.71708298], [82.25458527, 16.71708298], [82.25458527, 16.71736145], [82.25347137, 16.71736145], [82.25347137, 16.71763992], [82.25125885, 16.71763039], [82.25125885, 16.7179184], [82.25068665, 16.7179184], [82.25068665, 16.71763039], [82.24903107, 16.71763992], [82.24903107, 16.71736145], [82.24847412, 16.71736145], [82.24847412, 16.71708298], [82.24624634, 16.71708298], [82.24624634, 16.71680641], [82.24569702, 16.71681023], [82.24569702, 16.71597099], [82.24541473, 16.7159729], [82.24541473, 16.71513939], [82.24513245, 16.71513939], [82.24513245, 16.71403122], [82.24485779, 16.71403122], [82.24485779, 16.71319008], [82.24458313, 16.7131958], [82.24458313, 16.71236038], [82.24430847, 16.71236038], [82.24430847, 16.71125031], [82.24402618, 16.71125031], [82.24402618, 16.71042061], [82.24375153, 16.71042061], [82.24375153, 16.7093029], [82.24346924, 16.70930481], [82.24346924, 16.70875168], [82.24318695, 16.70876122], [82.24318695, 16.70846939], [82.24291992, 16.70846939], [82.24291992, 16.70819473], [82.24263763, 16.70819473], [82.24263763, 16.7076416], [82.24291992, 16.7076416], [82.24291992, 16.70792007], [82.24346924, 16.70792007], [82.24346924, 16.7076416], [82.24402618, 16.7076416], [82.24402618, 16.70735931], [82.24430847, 16.70735931], [82.24430847, 16.70708084], [82.24458313, 16.70708275], [82.24458313, 16.70680618], [82.24485779, 16.7068119], [82.24485779, 16.70653152], [82.24597168, 16.70653152], [82.24597168, 16.70624924], [82.24624634, 16.70624924], [82.24624634, 16.70597076], [82.24652863, 16.70597267], [82.24652863, 16.7056942], [82.24736023, 16.7056942], [82.24736023, 16.70541573], [82.24764252, 16.70541763], [82.24764252, 16.70513916], [82.24791718, 16.70513916], [82.24791718, 16.70486069], [82.24819946, 16.70486069], [82.24819183, 16.70430565], [82.24846649, 16.70430756], [82.24846649, 16.70402908], [82.24874878, 16.70402908], [82.24874878, 16.70375061], [82.24903107, 16.70375061], [82.24903107, 16.70347023], [82.24930573, 16.70347214], [82.24930573, 16.7029171], [82.24958038, 16.70292091], [82.24958038, 16.702631], [82.24986267, 16.70263863], [82.24986267, 16.70208359], [82.25013733, 16.70208359], [82.25013733, 16.70180511], [82.25041962, 16.70181084], [82.25041962, 16.70153046], [82.25068665, 16.70153046], [82.25068665, 16.70125008], [82.25096893, 16.70125008], [82.25096893, 16.7009697], [82.25125122, 16.7009716], [82.25125122, 16.70069695], [82.25152588, 16.70070076], [82.25152588, 16.70042038], [82.25180817, 16.70042038], [82.25180817, 16.70014], [82.25208282, 16.70014], [82.25208282, 16.69985962], [82.25235748, 16.69986153], [82.25235748, 16.69958305], [82.25263977, 16.69959068], [82.25263977, 16.69902992], [82.25319672, 16.69902992], [82.25319672, 16.69874954], [82.25374603, 16.69874954], [82.25374603, 16.69847107], [82.25402832, 16.69847488], [82.25402832, 16.69791603], [82.25430298, 16.69791985], [82.25430298, 16.6973629], [82.2545929, 16.6973629], [82.25458527, 16.69708443], [82.25485992, 16.69708443], [82.25485992, 16.69652748], [82.25514221, 16.69652939], [82.25514221, 16.69597054], [82.25541687, 16.69597054], [82.25541687, 16.69569206], [82.25569153, 16.69569206], [82.25569153, 16.6954174], [82.25596619, 16.69542122], [82.25596619, 16.69514275], [82.25624847, 16.69514275], [82.25624847, 16.69486046], [82.25653076, 16.69486046], [82.25653076, 16.69458008], [82.25680542, 16.69458389], [82.25680542, 16.69430542], [82.25653076, 16.69431114], [82.25653076, 16.69346809], [82.25708008, 16.69347191], [82.25708008, 16.69236183], [82.25736237, 16.69236183], [82.25736237, 16.69152832], [82.25763702, 16.69152832], [82.25763702, 16.69011307], [82.25344849, 16.68972015], [82.24653625, 16.69144058], [82.22740936, 16.70465088], [82.21543884, 16.70976067], [82.20252991, 16.70769119], [82.19358063, 16.70845032], [82.17907715, 16.71630096], [82.17463684, 16.7251091], [82.18032074, 16.72809982], [82.18875122, 16.72721291], [82.19677734, 16.73647118], [82.20722961, 16.74370956], [82.21113586, 16.74822044], [82.21768188, 16.75168991], [82.22181702, 16.75035286], [82.2197876, 16.74486923], [82.2100296, 16.73127174], [82.21096802, 16.72793961], [82.21478271, 16.72520065], [82.22042084, 16.7183094], [82.22704315, 16.71718025], [82.24494934, 16.71895981], [82.26370239, 16.71936989], [82.28070068, 16.72274971], [82.28507996, 16.73450851], [82.28909302, 16.74098969], [82.29370117, 16.74304008], [82.29773712, 16.74037933], [82.30105591, 16.73333931], [82.30282593, 16.72283936], [82.29951477, 16.71433258], [82.29943848, 16.71412849], [82.29938507, 16.71402931]]], [[[79.81014252, 11.87486076], [79.81014252, 11.87514973], [79.80930328, 11.87514973], [79.80930328, 11.87542152], [79.80874634, 11.87541676], [79.80874634, 11.87569523], [79.80764008, 11.87569523], [79.80764008, 11.87541676], [79.80680847, 11.87542152], [79.80680847, 11.87514973], [79.80625153, 11.87514973], [79.80625153, 11.87486076], [79.80581665, 11.87486076], [79.80541992, 11.87486076], [79.80541992, 11.87458134], [79.80458069, 11.87458324], [79.80458069, 11.87430477], [79.80513763, 11.87430859], [79.80513763, 11.87403107], [79.80541992, 11.87403107], [79.80541992, 11.87430859], [79.80568695, 11.87430859], [79.80652618, 11.87430477], [79.80652618, 11.87458324], [79.80737305, 11.87458134], [79.80737305, 11.87486076], [79.8079071, 11.87486076], [79.8079071, 11.87458134], [79.80958557, 11.87458324], [79.80958557, 11.87430477], [79.81014252, 11.87430859], [79.81014252, 11.87403107], [79.81043243, 11.87403107], [79.81043243, 11.87347126], [79.81069183, 11.87347317], [79.81069183, 11.87319469], [79.81097412, 11.87319469], [79.81097412, 11.87291718], [79.81153107, 11.87292099], [79.81153107, 11.87264061], [79.81208038, 11.87264061], [79.81208038, 11.87236118], [79.81291962, 11.87236118], [79.81291962, 11.87208271], [79.81430817, 11.87209034], [79.81430817, 11.87181187], [79.81458282, 11.87181187], [79.81458282, 11.87209034], [79.81485748, 11.87209034], [79.81485748, 11.87181187], [79.81597137, 11.87181187], [79.81597137, 11.87153053], [79.8162384, 11.87153053], [79.8162384, 11.87125111], [79.81652832, 11.87125111], [79.81652832, 11.87097073], [79.81764221, 11.87097073], [79.81764221, 11.87125111], [79.81846619, 11.87125111], [79.81846619, 11.87097073], [79.81874847, 11.87097263], [79.81874847, 11.87069511], [79.81903076, 11.87069511], [79.81903076, 11.87013912], [79.81931305, 11.87014103], [79.81931305, 11.86986065], [79.81958008, 11.86986065], [79.81958008, 11.86958027], [79.81986237, 11.86958313], [79.81986237, 11.86930466], [79.81958008, 11.86931133], [79.81958008, 11.8681879], [79.81930542, 11.86819458], [79.81930542, 11.86736012], [79.81903076, 11.86736012], [79.81903076, 11.8668108], [79.81874847, 11.8668108], [79.81874847, 11.86625004], [79.81846619, 11.86625004], [79.81846619, 11.86569023], [79.81819153, 11.86569405], [79.81819153, 11.86402798], [79.81764221, 11.86403275], [79.81764221, 11.86347008], [79.81735992, 11.86347198], [79.81735992, 11.86319447], [79.81708527, 11.86319447], [79.81708527, 11.86263847], [79.81680298, 11.86264038], [79.81680298, 11.86181068], [79.81652832, 11.86181068], [79.81652832, 11.86124992], [79.8162384, 11.86124992], [79.8162384, 11.86042023], [79.81597137, 11.86042023], [79.81597137, 11.85958195], [79.81625366, 11.85958385], [79.81625366, 11.85930634], [79.81597137, 11.85931015], [79.81597137, 11.85875034], [79.81569672, 11.85875034], [79.81569672, 11.85819054], [79.81541443, 11.85819435], [79.81541443, 11.85736179], [79.81513977, 11.85736179], [79.81513977, 11.85653019], [79.81485748, 11.85653019], [79.81485748, 11.85569096], [79.81458282, 11.85569572], [79.81458282, 11.85541534], [79.81430817, 11.85542011], [79.81430817, 11.85513973], [79.81402588, 11.85513973], [79.81402588, 11.85458088], [79.81375122, 11.85458374], [79.81375122, 11.85430622], [79.81346893, 11.85431004], [79.81346893, 11.85346889], [79.81291962, 11.8534708], [79.81291962, 11.85319328], [79.81263733, 11.85319328], [79.81263733, 11.8526392], [79.81236267, 11.8526392], [79.81236267, 11.85181046], [79.81208038, 11.85181046], [79.81208038, 11.8509798], [79.81181335, 11.8509798], [79.81181335, 11.85042191], [79.81153107, 11.85042191], [79.81153107, 11.84958076], [79.81124878, 11.84958267], [79.81124878, 11.84874916], [79.81096649, 11.84875107], [79.81096649, 11.84819126], [79.81069183, 11.84819508], [79.81069183, 11.84736061], [79.81041718, 11.84736061], [79.81041718, 11.84652901], [79.81014252, 11.84653091], [79.81014252, 11.84514141], [79.81043243, 11.84514141], [79.81043243, 11.84431171], [79.81014252, 11.84431171], [79.81014252, 11.84403133], [79.80986023, 11.84403133], [79.80986023, 11.84375095], [79.8095932, 11.84375095], [79.8095932, 11.84347057], [79.80902863, 11.84347343], [79.80902863, 11.84319496], [79.80930328, 11.84319496], [79.80930328, 11.84208298], [79.80902863, 11.84208298], [79.80902863, 11.84180355], [79.80874634, 11.84181118], [79.80874634, 11.83985996], [79.80847168, 11.83985996], [79.80847168, 11.83931065], [79.80819702, 11.83931065], [79.80819702, 11.8390398], [79.8079071, 11.8390398], [79.8079071, 11.83875275], [79.80764008, 11.83875275], [79.80764008, 11.83819199], [79.80735779, 11.83819389], [79.80735779, 11.8376379], [79.80764008, 11.83764267], [79.80764008, 11.83653069], [79.80708313, 11.83653069], [79.80708313, 11.83681107], [79.80625153, 11.83681107], [79.80625153, 11.83764267], [79.80652618, 11.83764267], [79.80652618, 11.83792114], [79.80680847, 11.83791637], [79.80680847, 11.83847237], [79.80652618, 11.83847046], [79.80652618, 11.8390398], [79.80625153, 11.83902836], [79.80625153, 11.83958244], [79.80569458, 11.83958244], [79.80569458, 11.83930683], [79.80179596, 11.83931065], [79.80179596, 11.84181118], [79.80123901, 11.84181118], [79.80123901, 11.8415308], [79.80097198, 11.8415308], [79.80097198, 11.84097004], [79.80069733, 11.8409729], [79.80069733, 11.84069538], [79.80041504, 11.84069538], [79.80041504, 11.84041595], [79.79985809, 11.84042072], [79.79985809, 11.8401413], [79.79957581, 11.8401413], [79.79957581, 11.83931065], [79.80042267, 11.83931065], [79.80042267, 11.8390398], [79.80097198, 11.8390398], [79.80097198, 11.83875275], [79.80123901, 11.83875275], [79.80123901, 11.83819199], [79.80152893, 11.83819389], [79.80152893, 11.83736229], [79.80180359, 11.83736229], [79.80180359, 11.83625031], [79.80208588, 11.83625031], [79.80208588, 11.83514023], [79.80236053, 11.83514023], [79.80236053, 11.83458042], [79.80291748, 11.83458424], [79.80291748, 11.83430576], [79.80319214, 11.83431053], [79.80319214, 11.83403015], [79.80403137, 11.83403015], [79.80403137, 11.83375168], [79.80513763, 11.83375168], [79.80513763, 11.83347034], [79.80541992, 11.83347225], [79.80541992, 11.83291626], [79.80569458, 11.83291626], [79.80569458, 11.83236217], [79.80596924, 11.83236217], [79.80596924, 11.82819557], [79.80569458, 11.82819557], [79.80569458, 11.82791805], [79.80541992, 11.82791996], [79.80541992, 11.82763958], [79.80568695, 11.82763958], [79.80568695, 11.8273592], [79.80541992, 11.82736206], [79.80541992, 11.82680511], [79.80513763, 11.82681179], [79.80513763, 11.82458115], [79.80458069, 11.82458305], [79.80458069, 11.82402706], [79.8042984, 11.82404137], [79.8042984, 11.82347107], [79.80403137, 11.82347107], [79.80403137, 11.82208347], [79.80374908, 11.82208347], [79.80374908, 11.821805], [79.80403137, 11.82180977], [79.80403137, 11.82097054], [79.80347443, 11.8209734], [79.80347443, 11.8204174], [79.80319214, 11.82041931], [79.80319214, 11.81986141], [79.80291748, 11.81986141], [79.80291748, 11.81902695], [79.80264282, 11.81903076], [79.80264282, 11.81681061], [79.80236053, 11.81681061], [79.80236053, 11.81653118], [79.80208588, 11.81653118], [79.80208588, 11.81597042], [79.80236053, 11.81597328], [79.80236053, 11.8148613], [79.80208588, 11.81487179], [79.80208588, 11.81403065], [79.80179596, 11.81403065], [79.80179596, 11.81236267], [79.80152893, 11.81236267], [79.80152893, 11.81208038], [79.80124664, 11.81208229], [79.80124664, 11.81124973], [79.80097198, 11.81124973], [79.80097198, 11.81042099], [79.80069733, 11.81042099], [79.80069733, 11.81013966], [79.80042267, 11.81013966], [79.80041504, 11.8083992], [79.79682159, 11.81153965], [79.79397583, 11.81564045], [79.79296875, 11.81764984], [79.79281616, 11.81945992], [79.79176331, 11.82697201], [79.79402161, 11.83020973], [79.79097748, 11.83181], [79.78787231, 11.83508968], [79.78616333, 11.83840179], [79.78176117, 11.840271], [79.77849579, 11.83882999], [79.76712036, 11.84047985], [79.76539612, 11.83333111], [79.76360321, 11.83250999], [79.76043701, 11.82303143], [79.75811005, 11.82210064], [79.75213623, 11.82445145], [79.74730682, 11.83270168], [79.74871063, 11.83584023], [79.75028229, 11.83598137], [79.7515564, 11.84166145], [79.75393677, 11.84224033], [79.7557373, 11.85046959], [79.75495148, 11.85783958], [79.75099945, 11.85894966], [79.74980927, 11.8605299], [79.74363708, 11.85972118], [79.74339294, 11.85363102], [79.73944855, 11.84986115], [79.73840332, 11.83500099], [79.72776031, 11.83233929], [79.73034668, 11.84687996], [79.71817017, 11.84836197], [79.71798706, 11.84762955], [79.70668793, 11.84708977], [79.70379639, 11.83829021], [79.69766998, 11.85242081], [79.69345093, 11.85389137], [79.69573212, 11.87337971], [79.69050598, 11.87406063], [79.68205261, 11.87335014], [79.68036652, 11.87062168], [79.67838287, 11.86957073], [79.67315674, 11.86995029], [79.67090607, 11.86983109], [79.67118073, 11.86660099], [79.65907288, 11.86566925], [79.65907288, 11.87212181], [79.66036987, 11.87732029], [79.66821289, 11.87625122], [79.6687088, 11.87463093], [79.67591095, 11.87932968], [79.67987061, 11.87926197], [79.68065643, 11.8819418], [79.6799469, 11.88615036], [79.68382263, 11.88745975], [79.68229675, 11.89185047], [79.67983246, 11.89344978], [79.68286133, 11.90470886], [79.70258331, 11.90250015], [79.70250702, 11.89843178], [79.69168854, 11.89777088], [79.69153595, 11.8784008], [79.70173645, 11.87654972], [79.70437622, 11.87460136], [79.70831299, 11.87395191], [79.71537018, 11.87497044], [79.71692657, 11.87684155], [79.71601868, 11.8866806], [79.71750641, 11.88924026], [79.72489929, 11.89151001], [79.70407867, 11.91299057], [79.7060318, 11.92870998], [79.6964798, 11.93245029], [79.6946106, 11.93133068], [79.69451141, 11.92593193], [79.69608307, 11.92010021], [79.69782257, 11.91668129], [79.69277954, 11.9211998], [79.69200134, 11.92448044], [79.69023895, 11.92618275], [79.68414307, 11.92722034], [79.67819977, 11.93653202], [79.6776886, 11.93935108], [79.68148041, 11.94336033], [79.68312836, 11.94650078], [79.68543243, 11.9451704], [79.68667603, 11.94728088], [79.69315338, 11.95079041], [79.70155334, 11.95218086], [79.70192719, 11.95643139], [79.69525909, 11.96103096], [79.69921875, 11.97003078], [79.6990509, 11.97205925], [79.69480133, 11.97511101], [79.68997955, 11.9756403], [79.68689728, 11.9739809], [79.68416595, 11.97472954], [79.68113708, 11.97284126], [79.67749786, 11.97399044], [79.67344666, 11.97236919], [79.67114258, 11.97476006], [79.6653595, 11.96752167], [79.66143036, 11.97285938], [79.65960693, 11.97705078], [79.65122223, 11.97201061], [79.64420319, 11.97321033], [79.64234161, 11.975811], [79.64428711, 11.98627186], [79.64441681, 11.98627186], [79.64434052, 11.99267197], [79.6470108, 11.99332142], [79.64731598, 11.99722958], [79.65236664, 11.99830055], [79.65930939, 11.99689102], [79.66326141, 12.00638103], [79.66890717, 12.00729179], [79.67151642, 12.01162148], [79.67645264, 12.0128603], [79.679039, 12.01926041], [79.69155884, 12.0174408], [79.69242096, 12.01107121], [79.69048309, 12.00112057], [79.69075775, 11.99627972], [79.69539642, 11.99268055], [79.7016983, 11.98608971], [79.70359039, 11.98005009], [79.70584869, 11.97737026], [79.7098999, 11.97622108], [79.71259308, 11.97563076], [79.71695709, 11.97544193], [79.71985626, 11.97646046], [79.72493744, 11.97790146], [79.72711182, 11.97996998], [79.72885895, 11.98602104], [79.72899628, 11.98602104], [79.73468018, 11.99431133], [79.74964905, 11.98613071], [79.75260925, 11.97945976], [79.75244141, 11.97612953], [79.74906921, 11.97236919], [79.74513245, 11.97085094], [79.74240875, 11.96704102], [79.73816681, 11.9670496], [79.73544312, 11.96361065], [79.72692108, 11.96249199], [79.72209167, 11.96743965], [79.71790314, 11.96887112], [79.71570587, 11.9674511], [79.7144928, 11.95525074], [79.73361206, 11.94721031], [79.73356628, 11.93729973], [79.73690033, 11.92739105], [79.73658752, 11.91020966], [79.73690033, 11.9071703], [79.74053955, 11.90716076], [79.7408371, 11.90945053], [79.74751282, 11.91516113], [79.7472229, 11.91783047], [79.74784088, 11.92890167], [79.75814056, 11.93040085], [79.76420593, 11.93459034], [79.76544952, 11.93916035], [79.76937866, 11.94145107], [79.77181244, 11.94640064], [79.77272034, 11.9467907], [79.77575684, 11.94601059], [79.77879333, 11.94640064], [79.78333282, 11.94373035], [79.78756714, 11.9383707], [79.79030609, 11.94255066], [79.79165649, 11.94774055], [79.79242706, 11.95705128], [79.79527283, 11.96189022], [79.7979126, 11.96352196], [79.79972839, 11.96428967], [79.80458832, 11.96314144], [79.80602264, 11.95922089], [79.80632782, 11.95526886], [79.8081131, 11.94651031], [79.8110199, 11.94250965], [79.81420135, 11.94062138], [79.81800079, 11.94039059], [79.82540131, 11.94001007], [79.82540131, 11.94014931], [79.83069611, 11.94024944], [79.83763885, 11.94054985], [79.83763885, 11.93986225], [79.8373642, 11.93986225], [79.8373642, 11.93875027], [79.83708191, 11.93875027], [79.83708191, 11.93624973], [79.83680725, 11.93624973], [79.83680725, 11.93543053], [79.83653259, 11.93543053], [79.83653259, 11.93347073], [79.83625031, 11.93347359], [79.83625031, 11.93319321], [79.83652496, 11.93319321], [79.83652496, 11.93291664], [79.83625031, 11.93292046], [79.83625031, 11.93125057], [79.83598328, 11.93125057], [79.83598328, 11.92958069], [79.83625031, 11.9295826], [79.83625031, 11.92930508], [79.83597565, 11.92930508], [79.83597565, 11.9290266], [79.83569336, 11.92903233], [79.83569336, 11.92819118], [79.8354187, 11.928195], [79.8354187, 11.92791653], [79.83513641, 11.92791939], [79.83513641, 11.92764091], [79.8354187, 11.92764091], [79.8354187, 11.92736053], [79.83513641, 11.92736053], [79.83513641, 11.92625141], [79.83486176, 11.92625999], [79.83486176, 11.92457962], [79.8345871, 11.92458344], [79.8345871, 11.92375088], [79.83431244, 11.92375088], [79.83431244, 11.92292118], [79.83403015, 11.92292118], [79.83403015, 11.9226408], [79.83374786, 11.9226408], [79.83374786, 11.9218111], [79.83347321, 11.9218111], [79.83347321, 11.91986275], [79.83319092, 11.91986275], [79.83319092, 11.91958046], [79.83291626, 11.91958237], [79.83291626, 11.91874981], [79.8326416, 11.91875267], [79.8326416, 11.91763973], [79.83235931, 11.91763973], [79.83235931, 11.91681099], [79.83207703, 11.91681099], [79.83207703, 11.91625023], [79.83180237, 11.91625023], [79.83180237, 11.91596985], [79.83152771, 11.91597176], [79.83152771, 11.91569424], [79.83125305, 11.91569424], [79.83125305, 11.91541576], [79.83097076, 11.91542053], [79.83097076, 11.91347027], [79.83069611, 11.91347218], [79.83069611, 11.9131937], [79.83041382, 11.9131937], [79.83041382, 11.91263771], [79.83013916, 11.91263962], [79.83013916, 11.91180992], [79.82985687, 11.91180992], [79.82985687, 11.91069126], [79.82958221, 11.91069412], [79.82958221, 11.91041565], [79.82985687, 11.91042042], [79.82985687, 11.90957928], [79.83013916, 11.90958405], [79.83013916, 11.90791798], [79.83069611, 11.90792179], [79.83069611, 11.90764046], [79.83097076, 11.90764046], [79.83097076, 11.90708065], [79.83069611, 11.90708256], [79.83069611, 11.90680504], [79.82985687, 11.90680981], [79.82985687, 11.90653038], [79.82875061, 11.90653038], [79.82875061, 11.90680981], [79.82819366, 11.90680504], [79.82819366, 11.90708256], [79.82791901, 11.90708065], [79.82791901, 11.90736198], [79.82763672, 11.90736198], [79.82763672, 11.90792179], [79.82736206, 11.90791798], [79.82736206, 11.90847111], [79.82707977, 11.9084692], [79.82707977, 11.90902996], [79.82736206, 11.90902996], [79.82736206, 11.91042042], [79.82763672, 11.91042042], [79.82763672, 11.9143219], [79.82736206, 11.9143219], [79.82736206, 11.91486168], [79.82707977, 11.91486168], [79.82707977, 11.91514015], [79.82681274, 11.91514015], [79.82681274, 11.91542053], [79.82653046, 11.91541576], [79.82653046, 11.91569424], [79.82624817, 11.91569424], [79.82624817, 11.91597176], [79.82569122, 11.91596985], [79.82569122, 11.91625023], [79.82540894, 11.91625023], [79.82540894, 11.91652966], [79.82430267, 11.91652966], [79.82430267, 11.91596985], [79.82458496, 11.91597176], [79.82458496, 11.91541576], [79.82485962, 11.91542053], [79.82485962, 11.91486168], [79.82514191, 11.91486168], [79.82514191, 11.91458035], [79.82569122, 11.91458416], [79.82569122, 11.91430569], [79.82596588, 11.9143219], [79.82596588, 11.91403008], [79.82624817, 11.91403008], [79.82624817, 11.91347027], [79.82653046, 11.91347218], [79.82653046, 11.91263771], [79.82624817, 11.91263962], [79.82624817, 11.91207886], [79.82653046, 11.91208363], [79.82653046, 11.90958405], [79.82624817, 11.90958405], [79.82624817, 11.90902805], [79.82596588, 11.90902996], [79.82596588, 11.90792179], [79.82569122, 11.90792179], [79.82569122, 11.90764046], [79.82514191, 11.90764046], [79.82514191, 11.90902996], [79.82485962, 11.90902996], [79.82485962, 11.90931034], [79.82459259, 11.90931034], [79.82459259, 11.90874958], [79.82290649, 11.90874958], [79.82290649, 11.90902996], [79.82263947, 11.90902996], [79.82263947, 11.90931034], [79.82237244, 11.90931034], [79.82237244, 11.90902996], [79.82180786, 11.90902996], [79.82180786, 11.90874958], [79.8215332, 11.90874958], [79.8215332, 11.9084692], [79.82125092, 11.90847111], [79.82125092, 11.90819645], [79.82013702, 11.90819645], [79.82013702, 11.90791798], [79.81986237, 11.90792179], [79.81986237, 11.90764046], [79.81958008, 11.90764046], [79.81958008, 11.90736198], [79.81930542, 11.90736198], [79.81930542, 11.90708256], [79.81903076, 11.90708256], [79.81903076, 11.90680504], [79.81874847, 11.90680981], [79.81874847, 11.90625191], [79.81846619, 11.90625191], [79.81846619, 11.90431023], [79.81819153, 11.90431023], [79.81819153, 11.90207195], [79.81791687, 11.9020834], [79.81791687, 11.9015274], [79.81819153, 11.90152931], [79.81819153, 11.90180969], [79.81874847, 11.90180969], [79.81874847, 11.90236092], [79.81903076, 11.90236092], [79.81903076, 11.9026413], [79.81930542, 11.90263939], [79.81930542, 11.90375137], [79.81958008, 11.90375137], [79.81958008, 11.90513897], [79.81986237, 11.90513897], [79.81986237, 11.90569305], [79.82013702, 11.90569115], [79.82013702, 11.90625191], [79.82041931, 11.90625191], [79.82041931, 11.90653038], [79.82068634, 11.90653038], [79.82068634, 11.90680981], [79.82125092, 11.90680504], [79.82125092, 11.90708256], [79.82152557, 11.90708256], [79.82152557, 11.90736198], [79.82375336, 11.90736198], [79.82375336, 11.90708065], [79.82402802, 11.90708256], [79.82402802, 11.90680504], [79.82459259, 11.90680981], [79.82459259, 11.90625191], [79.82653046, 11.90625191], [79.82653046, 11.90597057], [79.82736206, 11.90597439], [79.82736206, 11.90569305], [79.82930756, 11.90569305], [79.82930756, 11.90541744], [79.82958221, 11.9054203], [79.82958221, 11.90486145], [79.8298645, 11.90486145], [79.8298645, 11.90458298], [79.83041382, 11.90458298], [79.83041382, 11.90402699], [79.83097076, 11.90402699], [79.83097076, 11.90486145], [79.83125305, 11.90486145], [79.83125305, 11.90513897], [79.83154297, 11.90513039], [79.83154297, 11.9054203], [79.83207703, 11.9054203], [79.83207703, 11.90402889], [79.83180237, 11.90402889], [79.83180237, 11.90375137], [79.83125305, 11.90375137], [79.83125305, 11.90347099], [79.82847595, 11.90347099], [79.82847595, 11.90291691], [79.82817841, 11.90292168], [79.82817841, 11.90207195], [79.82791901, 11.9020834], [79.82791901, 11.90097332], [79.82763672, 11.90097332], [79.82763672, 11.90041733], [79.82736206, 11.90041924], [79.82736206, 11.89847088], [79.82791901, 11.89847279], [79.82791901, 11.89680672], [79.82763672, 11.89681053], [79.82763672, 11.89625072], [79.82736206, 11.89625072], [79.82736206, 11.89597034], [79.82707977, 11.89597321], [79.82707977, 11.89486027], [79.82736206, 11.89486027], [79.82736206, 11.89458466], [79.82707977, 11.89458466], [79.82707977, 11.89430428], [79.82681274, 11.89431095], [79.82681274, 11.89403057], [79.82653046, 11.89403057], [79.82653046, 11.89375114], [79.82624817, 11.89375114], [79.82624817, 11.89097023], [79.82653046, 11.89097214], [79.82653046, 11.89069366], [79.82624817, 11.89069366], [79.82624817, 11.88958359], [79.82597351, 11.88958359], [79.82597351, 11.88930607], [79.82569122, 11.88931084], [79.82569122, 11.88875008], [79.82540894, 11.88875008], [79.82540894, 11.88818932], [79.82514191, 11.88819408], [79.82514191, 11.88680553], [79.82485962, 11.88681126], [79.82485962, 11.88624954], [79.82459259, 11.88624954], [79.82459259, 11.88569069], [79.82430267, 11.88569355], [79.82430267, 11.88486195], [79.82459259, 11.88486195], [79.82458496, 11.88374996], [79.82430267, 11.88375187], [79.82430267, 11.88319969], [79.82402802, 11.88319111], [79.82402802, 11.88291645], [79.82375336, 11.88292027], [79.82375336, 11.88181019], [79.82290649, 11.88181019], [79.82290649, 11.88152981], [79.82208252, 11.88152981], [79.82208252, 11.88124943], [79.82180786, 11.88124943], [79.82180786, 11.88096046], [79.82125092, 11.88097095], [79.82125092, 11.88069344], [79.82013702, 11.88069344], [79.82013702, 11.88041782], [79.81958008, 11.88041973], [79.81958008, 11.8801403], [79.81931305, 11.8801403], [79.81931305, 11.87986088], [79.81903076, 11.87986088], [79.81903076, 11.87958145], [79.81846619, 11.87958145], [79.81846619, 11.87986088], [79.81791687, 11.87986088], [79.81791687, 11.8801403], [79.8162384, 11.8801403], [79.8162384, 11.88041973], [79.81513977, 11.88041782], [79.81513977, 11.88069344], [79.81485748, 11.88069344], [79.81485748, 11.88041782], [79.81430817, 11.88041782], [79.81430817, 11.88069344], [79.81402588, 11.88069344], [79.81402588, 11.88097095], [79.81346893, 11.88096046], [79.81346893, 11.88124943], [79.81317902, 11.88124943], [79.81317902, 11.88152981], [79.81208038, 11.88152981], [79.81208038, 11.88181019], [79.81097412, 11.88180637], [79.81097412, 11.88208389], [79.81041718, 11.88208389], [79.81041718, 11.88236237], [79.8079071, 11.88235855], [79.8079071, 11.88264179], [79.80761719, 11.88263988], [79.80737305, 11.88264179], [79.80737305, 11.88292027], [79.80652618, 11.88292027], [79.80652618, 11.88264179], [79.80625153, 11.88264179], [79.80625153, 11.88292027], [79.80486298, 11.88291645], [79.80486298, 11.88319111], [79.80347443, 11.88319588], [79.80347443, 11.88347244], [79.80208588, 11.88347244], [79.80208588, 11.88375187], [79.80097198, 11.88375187], [79.80097198, 11.88347244], [79.80041504, 11.88347244], [79.80041504, 11.88319588], [79.80014038, 11.88319111], [79.80014038, 11.88291645], [79.79957581, 11.88292027], [79.79957581, 11.88264179], [79.79792023, 11.88264179], [79.79792023, 11.88235855], [79.79736328, 11.88236237], [79.79736328, 11.88208389], [79.79680634, 11.88208389], [79.79680634, 11.88180637], [79.79624939, 11.88181019], [79.79624939, 11.88152981], [79.79569244, 11.88152981], [79.79569244, 11.88124943], [79.79541779, 11.88124943], [79.79541779, 11.88097095], [79.79374695, 11.88097095], [79.79374695, 11.88069344], [79.79347229, 11.88069344], [79.79347229, 11.8801403], [79.79319763, 11.8801403], [79.79319763, 11.87986088], [79.79347229, 11.87986088], [79.79347229, 11.87958145], [79.79319763, 11.87958336], [79.79319763, 11.87902737], [79.79207611, 11.87903023], [79.79207611, 11.87874889], [79.79069519, 11.87874889], [79.79069519, 11.87847137], [79.79152679, 11.87847137], [79.79152679, 11.87819481], [79.79180908, 11.87819481], [79.79180908, 11.87791729], [79.79374695, 11.87792015], [79.79374695, 11.87764168], [79.79458618, 11.87764168], [79.79458618, 11.87792015], [79.79486084, 11.87791729], [79.79486084, 11.87819481], [79.79541779, 11.87819481], [79.79541779, 11.87847137], [79.79569244, 11.87847137], [79.79569244, 11.87903023], [79.79624939, 11.87903023], [79.79624939, 11.87930965], [79.79651642, 11.87930965], [79.79651642, 11.87986088], [79.79680634, 11.87986088], [79.79680634, 11.8801403], [79.79736328, 11.8801403], [79.79736328, 11.88041973], [79.79763794, 11.88041782], [79.79763794, 11.88069344], [79.79846954, 11.88069344], [79.79846954, 11.88097095], [79.79875183, 11.88096046], [79.79875183, 11.88124943], [79.79902649, 11.88124943], [79.79902649, 11.88152981], [79.79930878, 11.88152981], [79.79930878, 11.88181019], [79.79957581, 11.88181019], [79.79957581, 11.88152981], [79.80069733, 11.88152981], [79.80069733, 11.88096046], [79.80041504, 11.88097095], [79.80041504, 11.88069344], [79.80097198, 11.88069344], [79.80097198, 11.88041782], [79.80180359, 11.88041782], [79.80180359, 11.88069344], [79.80263519, 11.88069344], [79.80263519, 11.88041782], [79.80347443, 11.88041782], [79.80347443, 11.88069344], [79.80374908, 11.88069057], [79.80374908, 11.88152981], [79.80403137, 11.88152981], [79.80403137, 11.88181019], [79.80458069, 11.88180637], [79.80458069, 11.88208389], [79.80486298, 11.88208389], [79.80486298, 11.88180637], [79.80513763, 11.88180637], [79.80513763, 11.88208389], [79.80569458, 11.88208389], [79.80569458, 11.88180637], [79.80652618, 11.88181019], [79.80652618, 11.88152981], [79.80680847, 11.88152981], [79.80680847, 11.88124943], [79.80708313, 11.88124943], [79.80708313, 11.88096046], [79.80724335, 11.88096714], [79.80735779, 11.88097095], [79.80735779, 11.88069344], [79.80847168, 11.88069344], [79.80847168, 11.88041782], [79.8095932, 11.88041973], [79.8095932, 11.8801403], [79.80986023, 11.8801403], [79.80986023, 11.87986088], [79.81043243, 11.87986088], [79.81041718, 11.87958336], [79.81097412, 11.87958336], [79.81097412, 11.87930489], [79.81153107, 11.87930965], [79.81153107, 11.87903023], [79.81208038, 11.87903023], [79.81208038, 11.87847137], [79.81236267, 11.87847137], [79.81236267, 11.87819481], [79.81291962, 11.87819481], [79.81291962, 11.87791729], [79.81317902, 11.87792015], [79.81317902, 11.87764168], [79.81485748, 11.87764168], [79.81485748, 11.8773613], [79.81513977, 11.8773613], [79.81513977, 11.87708282], [79.81541443, 11.87708282], [79.81541443, 11.87680531], [79.81597137, 11.87681198], [79.81597137, 11.8765316], [79.81652832, 11.8765316], [79.81652832, 11.87625122], [79.81680298, 11.87625122], [79.81680298, 11.87597084], [79.81735992, 11.87597084], [79.81735992, 11.87542152], [79.81764221, 11.87542152], [79.81764221, 11.87514973], [79.81819153, 11.87514973], [79.81819153, 11.87458134], [79.81903076, 11.87458324], [79.81903076, 11.87430477], [79.81958008, 11.87430859], [79.81958008, 11.87347126], [79.81930542, 11.87347317], [79.81930542, 11.87319469], [79.81847382, 11.87319469], [79.81847382, 11.87347317], [79.81791687, 11.87347126], [79.81791687, 11.87375069], [79.81680298, 11.87375069], [79.81680298, 11.87347126], [79.81485748, 11.87347126], [79.81485748, 11.87375069], [79.81375122, 11.87375069], [79.81375122, 11.87403107], [79.81263733, 11.87403107], [79.81263733, 11.87430859], [79.81236267, 11.87430477], [79.81236267, 11.87458324], [79.81096649, 11.87458134], [79.81096649, 11.87486076], [79.81014252, 11.87486076]]]]}}, {\\\"id\\\": \\\"25\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.28_1\\\", \\\"HASC_1\\\": \\\"IN.PB\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Punjab\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -8.8, \\\"dalys_apm25_rate_6cod_mean_total\\\": 470.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -940.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -470.0, \\\"geo-id\\\": 25, \\\"hpm25_child_popweighted\\\": -164.2, \\\"hpm25_female_popweighted\\\": -188.8, \\\"hpm25_male_popweighted\\\": -135.9, \\\"location\\\": \\\"Punjab\\\", \\\"mort_apm25_6cod_mean_total\\\": 4840.0, \\\"mort_hpm25_6cod_mean_total\\\": -9834.0, \\\"mort_tpm25_6cod_mean_total\\\": -4994.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[74.27902985, 29.95508957], [74.26030731, 29.9556694], [74.25190735, 29.95525932], [74.24067688, 29.95628929], [74.22380066, 29.95971107], [74.21276093, 29.96039009], [74.18596649, 29.96038055], [74.15444946, 29.96329117], [74.08332825, 29.96737289], [74.06919861, 29.96887016], [74.00274658, 29.97006035], [73.9960022, 29.97089005], [73.99092102, 29.97122955], [73.97646332, 29.96911049], [73.9569397, 29.96951294], [73.93295288, 29.97074127], [73.89118195, 29.97006989], [73.88944244, 29.97760963], [73.8884964, 29.9817791], [73.88302612, 29.99129105], [73.8811264, 29.99628067], [73.88186646, 30.01124001], [73.88551331, 30.01742935], [73.89261627, 30.03853035], [73.89480591, 30.0468502], [73.89840698, 30.0536499], [73.90854645, 30.06011009], [73.91821289, 30.06814957], [73.93152618, 30.08381081], [73.94291687, 30.09909058], [73.94410706, 30.10423088], [73.94998932, 30.1097908], [73.95794678, 30.11956024], [73.96665192, 30.12118912], [73.96393585, 30.12438011], [73.96247101, 30.12750053], [73.96118164, 30.13422966], [73.96082306, 30.14323044], [73.96337128, 30.17182922], [73.96643829, 30.17703056], [73.96810913, 30.18429947], [73.96640778, 30.19449425], [73.96631622, 30.19504929], [73.96459961, 30.2244606], [73.96391296, 30.23080063], [73.96383667, 30.23130035], [73.96115875, 30.24121284], [73.9598465, 30.25517273], [73.95909119, 30.25562096], [73.9578476, 30.26169014], [73.95574951, 30.2630291], [73.954422, 30.26619911], [73.95205688, 30.26798058], [73.95155334, 30.26999092], [73.95072174, 30.27054977], [73.94944, 30.27135086], [73.94872284, 30.27382278], [73.94795227, 30.27425003], [73.94734192, 30.27471161], [73.94448853, 30.28183174], [73.94394684, 30.28207016], [73.94329834, 30.28495979], [73.94229126, 30.28619957], [73.94126129, 30.2868309], [73.94124603, 30.28751945], [73.94045258, 30.28795052], [73.93699646, 30.29634285], [73.9363327, 30.2968998], [73.93432617, 30.30302048], [73.93308258, 30.30375099], [73.93209839, 30.30533028], [73.93138123, 30.30653954], [73.92685699, 30.30931854], [73.92662048, 30.30995941], [73.92608643, 30.31018066], [73.9254303, 30.31064034], [73.9241333, 30.31402969], [73.92305756, 30.31491089], [73.92253113, 30.31511116], [73.92015839, 30.32006073], [73.91963959, 30.32029915], [73.9190979, 30.32051086], [73.91828156, 30.32322121], [73.91620636, 30.3250103], [73.91590118, 30.32726097], [73.91436005, 30.32816124], [73.91422272, 30.32862091], [73.91304779, 30.3308506], [73.9122467, 30.33128929], [73.91118622, 30.33196831], [73.90854645, 30.33669281], [73.90750885, 30.33711052], [73.90647125, 30.33756828], [73.90647125, 30.33823013], [73.90569305, 30.33980942], [73.9048996, 30.34025955], [73.90461731, 30.34091949], [73.90329742, 30.34136963], [73.90096283, 30.3429203], [73.89980316, 30.34492111], [73.89952087, 30.34581184], [73.89875031, 30.34626961], [73.897789, 30.34695816], [73.89727783, 30.34900093], [73.89392853, 30.35056496], [73.88564301, 30.3544426], [73.88069153, 30.35715294], [73.88043213, 30.35775185], [73.87874603, 30.35897827], [73.87555695, 30.36079025], [73.87554932, 30.36130333], [73.87530518, 30.36138535], [73.87125397, 30.36857224], [73.87088776, 30.37499619], [73.87321472, 30.38343811], [73.87975311, 30.39111137], [73.88179016, 30.39276886], [73.89352417, 30.40231323], [73.90119934, 30.41271591], [73.90341949, 30.41679764], [73.92016602, 30.42014122], [73.92785645, 30.4209137], [73.93034363, 30.4249897], [73.93161011, 30.43322182], [73.93309021, 30.43609619], [73.93663025, 30.44298363], [73.93226624, 30.45843124], [73.93528748, 30.46295738], [73.93974304, 30.46269417], [73.94450378, 30.46241379], [73.94691467, 30.46227264], [73.95307922, 30.45910835], [73.95527649, 30.45798111], [73.962677, 30.45760727], [73.96652985, 30.46349144], [73.96828461, 30.47631454], [73.96881866, 30.48018646], [73.97273254, 30.48813248], [73.98365021, 30.50053024], [73.98851776, 30.50456047], [73.99977875, 30.51087952], [74.00652313, 30.5146637], [74.01862335, 30.52145195], [74.02561188, 30.52537537], [74.02948761, 30.53172112], [74.03060913, 30.53228951], [74.0329361, 30.53466988], [74.03401184, 30.5362606], [74.04023743, 30.53768539], [74.04071808, 30.53710365], [74.04767609, 30.52859497], [74.05570221, 30.5220108], [74.06085205, 30.52114105], [74.06651306, 30.52018738], [74.07761383, 30.52936172], [74.07996368, 30.53305054], [74.08480835, 30.54067993], [74.08439636, 30.54504013], [74.08226776, 30.54645157], [74.07642365, 30.55031776], [74.07213593, 30.54927063], [74.06817627, 30.5508194], [74.06777191, 30.5535202], [74.06790161, 30.55487061], [74.06932831, 30.5560112], [74.07087708, 30.55714035], [74.07138824, 30.55761147], [74.07594299, 30.56102943], [74.08409882, 30.56619263], [74.08512115, 30.56740952], [74.08999634, 30.57172012], [74.0904007, 30.57204819], [74.09120941, 30.57285118], [74.09262848, 30.57534981], [74.09307098, 30.57987976], [74.09323883, 30.58144951], [74.09213257, 30.5884304], [74.09204865, 30.59813118], [74.09445953, 30.60468292], [74.0944519, 30.60580063], [74.09430695, 30.6062603], [74.09015656, 30.60849953], [74.09001923, 30.61028099], [74.09099579, 30.61279106], [74.09583282, 30.61507988], [74.09841919, 30.61552048], [74.09922028, 30.61486053], [74.0994873, 30.61351013], [74.10056305, 30.61150169], [74.10108185, 30.6112709], [74.10205841, 30.6100235], [74.10212708, 30.60993004], [74.10212708, 30.60926056], [74.1047287, 30.60744286], [74.10473633, 30.60655975], [74.10891724, 30.60568047], [74.10945892, 30.60593033], [74.11048889, 30.60704994], [74.11148834, 30.61498833], [74.11171722, 30.61678123], [74.11686707, 30.62330818], [74.11691284, 30.62433052], [74.1174469, 30.62433052], [74.11837006, 30.63216019], [74.12095642, 30.63239098], [74.12177277, 30.63241005], [74.12359619, 30.62902069], [74.12986755, 30.62792015], [74.13122559, 30.62864876], [74.13491058, 30.62880135], [74.14394379, 30.6291008], [74.15077209, 30.63254166], [74.15093231, 30.63262177], [74.17874146, 30.65572166], [74.18323517, 30.65945244], [74.18336487, 30.65944862], [74.18569946, 30.65940094], [74.1861496, 30.6593914], [74.19683838, 30.67177582], [74.20818329, 30.68826866], [74.22200775, 30.70814705], [74.22724915, 30.71407318], [74.23215485, 30.71962166], [74.23305511, 30.71988106], [74.24098206, 30.72217941], [74.25400543, 30.72304535], [74.26831055, 30.73144531], [74.27966309, 30.7293644], [74.28180695, 30.73023415], [74.28246307, 30.73457336], [74.2736969, 30.7432518], [74.27322388, 30.74447441], [74.26628876, 30.76243973], [74.26220703, 30.76803017], [74.26499939, 30.77278328], [74.26647949, 30.77278137], [74.27372742, 30.77276993], [74.27910614, 30.77612114], [74.2840271, 30.77703094], [74.2848053, 30.77697945], [74.28555298, 30.77692986], [74.29113007, 30.77841187], [74.29631805, 30.78157806], [74.29737854, 30.7827301], [74.29914093, 30.78596115], [74.2990799, 30.78732681], [74.29901123, 30.78883934], [74.29810333, 30.78996277], [74.29759216, 30.79018021], [74.29677582, 30.79243088], [74.2962265, 30.79286957], [74.29537964, 30.79306793], [74.2906189, 30.79418945], [74.28684998, 30.79578018], [74.286026, 30.79667091], [74.28575897, 30.79959106], [74.29225922, 30.80233192], [74.29331207, 30.80323029], [74.29458618, 30.81022072], [74.29532623, 30.81158257], [74.29833221, 30.81431961], [74.30237579, 30.81637955], [74.30760193, 30.82114029], [74.30845642, 30.82384109], [74.31047821, 30.83468056], [74.31162262, 30.84053993], [74.3140564, 30.84370041], [74.31614685, 30.84758186], [74.31997681, 30.84962082], [74.32048035, 30.84985161], [74.32334137, 30.85033035], [74.32935333, 30.84877968], [74.33114624, 30.84898949], [74.33122253, 30.85027122], [74.3312912, 30.85079002], [74.33139801, 30.85239029], [74.3324585, 30.85307121], [74.33461761, 30.85352516], [74.33743286, 30.85411835], [74.34089661, 30.85402107], [74.342659, 30.8544693], [74.34604645, 30.85425758], [74.34604645, 30.85357094], [74.34658813, 30.85335922], [74.34733582, 30.85289955], [74.3473587, 30.85128975], [74.35118103, 30.84996986], [74.3536377, 30.84865189], [74.35875702, 30.8459034], [74.36300659, 30.84580612], [74.37198639, 30.85294151], [74.37114716, 30.86029625], [74.36532593, 30.86818886], [74.36494446, 30.86870384], [74.36221313, 30.87241936], [74.36188507, 30.87930107], [74.36552429, 30.88540649], [74.36618042, 30.88565826], [74.37627411, 30.88952255], [74.38272095, 30.89166832], [74.39503479, 30.90353775], [74.41292572, 30.90634155], [74.41610718, 30.90604019], [74.41920471, 30.9116993], [74.42031097, 30.92218399], [74.42070007, 30.92587662], [74.42761993, 30.93327713], [74.42867279, 30.93440628], [74.44639587, 30.94889641], [74.46434021, 30.96154976], [74.46782684, 30.96261215], [74.47058868, 30.96598816], [74.48509216, 30.97046471], [74.48963165, 30.96970367], [74.49143982, 30.96940041], [74.49661255, 30.96718407], [74.49698639, 30.96756935], [74.4997406, 30.96902084], [74.50444794, 30.97784805], [74.50888062, 30.98003006], [74.50966644, 30.9803524], [74.51435089, 30.98487091], [74.52272034, 30.98897934], [74.53263855, 30.99056816], [74.53658295, 30.99217033], [74.53811646, 30.99354172], [74.53851318, 30.9973526], [74.53800201, 30.99757004], [74.53704071, 31.00029945], [74.53618622, 31.00089073], [74.53504944, 31.00213051], [74.53360748, 31.00505066], [74.53231812, 31.00806999], [74.53179932, 31.0092907], [74.53179169, 31.01268959], [74.53469086, 31.01569176], [74.53572083, 31.01676178], [74.53800201, 31.03166962], [74.54058838, 31.03481293], [74.54611206, 31.03868103], [74.54967499, 31.04321861], [74.55310822, 31.0608902], [74.55344391, 31.06260109], [74.55839539, 31.06752586], [74.57170105, 31.06743622], [74.57330322, 31.06625366], [74.59249878, 31.05204201], [74.59736633, 31.04619598], [74.60018158, 31.04354668], [74.60262299, 31.04470062], [74.6054306, 31.04528046], [74.61441803, 31.04618073], [74.62251282, 31.04702187], [74.63350677, 31.05291939], [74.64240265, 31.05316162], [74.64605713, 31.05294037], [74.64892578, 31.05318069], [74.65600586, 31.05451012], [74.66660309, 31.05881119], [74.67221832, 31.06157112], [74.67378998, 31.0635891], [74.67823792, 31.06675911], [74.68319702, 31.07217979], [74.6840744, 31.07422066], [74.68504333, 31.07646942], [74.68492889, 31.07996941], [74.68418884, 31.08136177], [74.68422699, 31.08641052], [74.68628693, 31.08956909], [74.69101715, 31.09205055], [74.69442749, 31.09543991], [74.69441986, 31.09815025], [74.69075012, 31.10399818], [74.6906662, 31.11013222], [74.69061279, 31.11448097], [74.69059753, 31.11503029], [74.69059753, 31.11551094], [74.68991089, 31.11709023], [74.68624115, 31.11935234], [74.68206024, 31.12023926], [74.68060303, 31.12545967], [74.67913055, 31.12903023], [74.67809296, 31.1294899], [74.67730713, 31.1297226], [74.67732239, 31.13060951], [74.67655182, 31.13104057], [74.66892242, 31.13038826], [74.66368866, 31.12676048], [74.65898895, 31.1274395], [74.65738678, 31.13260078], [74.65634918, 31.13350868], [74.65267944, 31.13508034], [74.65109253, 31.13484955], [74.64980316, 31.1337204], [74.63983917, 31.13010025], [74.63774109, 31.12849045], [74.63566589, 31.12421989], [74.6312027, 31.12128067], [74.62490845, 31.12258911], [74.62465668, 31.12733078], [74.62596893, 31.13236046], [74.62631989, 31.13569069], [74.6261673, 31.13636971], [74.62515259, 31.13726044], [74.62410736, 31.13680077], [74.62306213, 31.13656998], [74.62252045, 31.13680077], [74.62145996, 31.13703156], [74.61474609, 31.13600159], [74.61414337, 31.13568115], [74.61089325, 31.13376808], [74.6102066, 31.13339996], [74.60782623, 31.13273048], [74.60653687, 31.13294983], [74.60128021, 31.13541985], [74.59500885, 31.13495064], [74.59236908, 31.13335037], [74.59187317, 31.13196945], [74.59176636, 31.12833023], [74.59214783, 31.12725067], [74.59329224, 31.12677956], [74.59422302, 31.12659836], [74.59578705, 31.12479019], [74.59659576, 31.12433052], [74.59726715, 31.12251091], [74.59796906, 31.11541939], [74.59820557, 31.11484718], [74.59926605, 31.11224174], [74.60031891, 31.11149979], [74.6006012, 31.10880089], [74.6000824, 31.10337067], [74.59815979, 31.09980965], [74.59642792, 31.09749031], [74.59648895, 31.09094048], [74.59279633, 31.08740807], [74.59140778, 31.0891304], [74.58937836, 31.08958054], [74.58907318, 31.09064102], [74.58886719, 31.09140015], [74.58802795, 31.09320068], [74.58542633, 31.09521103], [74.58270264, 31.09475136], [74.58165741, 31.09292984], [74.58126831, 31.09180069], [74.57814026, 31.09020996], [74.57602692, 31.09000015], [74.5746994, 31.09020996], [74.57289886, 31.08949852], [74.57145691, 31.08870125], [74.57051849, 31.08838081], [74.56581879, 31.08434105], [74.55768585, 31.08702278], [74.55323029, 31.08617973], [74.55193329, 31.08562088], [74.54721069, 31.08742905], [74.54693604, 31.08834267], [74.54640198, 31.08856964], [74.54585266, 31.09850121], [74.54519653, 31.0991497], [74.54387665, 31.10345078], [74.54347229, 31.1052494], [74.54380035, 31.11100006], [74.54432678, 31.11235809], [74.544487, 31.11562157], [74.544487, 31.11696053], [74.54382324, 31.12035942], [74.54341125, 31.12170982], [74.54264069, 31.12214088], [74.54236603, 31.12282944], [74.53634644, 31.12506104], [74.53437805, 31.12457085], [74.53015137, 31.12309265], [74.52832031, 31.12194061], [74.52648163, 31.12240028], [74.525177, 31.12529945], [74.52465057, 31.12553024], [74.52424622, 31.1271801], [74.52371216, 31.12739944], [74.52319336, 31.12956047], [74.51761627, 31.1320591], [74.51584625, 31.13223076], [74.50615692, 31.13579941], [74.50538635, 31.1364994], [74.5045929, 31.13850975], [74.50556946, 31.14954948], [74.50543976, 31.15068054], [74.50491333, 31.15089989], [74.50396729, 31.15854073], [74.50382996, 31.16500092], [74.5045929, 31.16739082], [74.50377655, 31.17098045], [74.50325775, 31.17121124], [74.50128937, 31.1799202], [74.50128937, 31.18104172], [74.50126648, 31.18157959], [74.50228882, 31.18429947], [74.50242615, 31.18497086], [74.5043869, 31.1856575], [74.50752258, 31.18523026], [74.50882721, 31.18567085], [74.50948334, 31.18703079], [74.50945282, 31.18861008], [74.50776672, 31.19289017], [74.50826263, 31.19740105], [74.51088715, 31.20057106], [74.51184845, 31.20296288], [74.51341248, 31.20672226], [74.51451874, 31.2093811], [74.51428223, 31.21214294], [74.51381683, 31.21750069], [74.51299286, 31.21829033], [74.51080322, 31.22293091], [74.51127625, 31.23127174], [74.51374817, 31.23670006], [74.5196228, 31.24167061], [74.52181244, 31.24666023], [74.52220154, 31.24753952], [74.52207184, 31.24867058], [74.52193451, 31.24908066], [74.52115631, 31.25136948], [74.52065277, 31.25159264], [74.52062988, 31.25228119], [74.51876831, 31.25360107], [74.51760864, 31.25666809], [74.51586914, 31.26330948], [74.51534271, 31.2635498], [74.51455688, 31.26624107], [74.51164246, 31.26805115], [74.51111603, 31.27233124], [74.51277924, 31.27549171], [74.5163269, 31.27752113], [74.51686096, 31.27799034], [74.51840973, 31.28386116], [74.51917267, 31.28547096], [74.52179718, 31.28987885], [74.52466583, 31.29470062], [74.53023529, 31.29867554], [74.55187225, 31.29845428], [74.56752014, 31.33480644], [74.56808472, 31.33723831], [74.56964111, 31.34082031], [74.57212067, 31.34653854], [74.59457397, 31.39709473], [74.60120392, 31.40403748], [74.62431335, 31.42268944], [74.62534332, 31.42361832], [74.63199615, 31.44094467], [74.63632965, 31.45223808], [74.64079285, 31.45590973], [74.64206696, 31.45996094], [74.64206696, 31.46154976], [74.64072418, 31.4636898], [74.64022827, 31.46447945], [74.63378906, 31.46868134], [74.63231659, 31.46964073], [74.63204193, 31.47122002], [74.63072968, 31.47235107], [74.62837982, 31.47356987], [74.6207428, 31.47797966], [74.62084961, 31.4786396], [74.62032318, 31.47887039], [74.62071228, 31.47999191], [74.62380981, 31.48241043], [74.62574005, 31.48553276], [74.62645721, 31.48669052], [74.62394714, 31.4869175], [74.62203217, 31.48708916], [74.61412811, 31.48583984], [74.61309052, 31.48613167], [74.60912323, 31.48718071], [74.60439301, 31.48965263], [74.60279083, 31.49482918], [74.60175323, 31.4957428], [74.5973587, 31.49810982], [74.59707642, 31.49875069], [74.5956955, 31.49979019], [74.59510803, 31.5002327], [74.59303284, 31.49999809], [74.59012604, 31.49841118], [74.58831787, 31.49863243], [74.58616638, 31.49885941], [74.5825119, 31.4983902], [74.57964325, 31.49567032], [74.57512665, 31.49658966], [74.56620026, 31.50083923], [74.5657959, 31.50172806], [74.56593323, 31.50287056], [74.56765747, 31.50317764], [74.568573, 31.50332069], [74.57171631, 31.50534058], [74.57247925, 31.50581169], [74.5734024, 31.50919914], [74.57328033, 31.50987053], [74.57247925, 31.51032066], [74.57139587, 31.51144981], [74.57139587, 31.51448631], [74.57139587, 31.51593971], [74.57298279, 31.51956177], [74.57467651, 31.52069092], [74.57480621, 31.5211525], [74.57937622, 31.52382088], [74.58241272, 31.52478981], [74.58822632, 31.52519989], [74.59348297, 31.5255127], [74.59897614, 31.52754021], [74.60106659, 31.52960014], [74.60269165, 31.53326988], [74.60385132, 31.53411102], [74.60434723, 31.53590965], [74.60478973, 31.54018974], [74.60523224, 31.54100418], [74.6023407, 31.55893135], [74.60028076, 31.55977249], [74.60011292, 31.56285095], [74.60167694, 31.56306648], [74.60090637, 31.56783867], [74.60030365, 31.5696106], [74.59260559, 31.59231186], [74.58634949, 31.60643578], [74.57849884, 31.62340546], [74.57181549, 31.63394737], [74.56254578, 31.64857483], [74.55711365, 31.65713692], [74.54148865, 31.68072891], [74.53022766, 31.69808578], [74.51978302, 31.71768761], [74.51728058, 31.72291183], [74.51810455, 31.74057579], [74.51815796, 31.74164772], [74.51804352, 31.74520111], [74.52886963, 31.74974823], [74.53646851, 31.7511425], [74.54205322, 31.75071907], [74.54545593, 31.75049019], [74.55098724, 31.75255013], [74.55179596, 31.7532196], [74.55219269, 31.75434113], [74.5520401, 31.75749969], [74.54940796, 31.75930023], [74.54750824, 31.76335907], [74.5448761, 31.7653904], [74.54402924, 31.77643013], [74.54428101, 31.77781105], [74.54717255, 31.78432083], [74.55454254, 31.79021072], [74.55493927, 31.79157066], [74.55478668, 31.79449081], [74.5534668, 31.79540062], [74.54953003, 31.79653168], [74.5493927, 31.79833031], [74.54949188, 31.79902267], [74.55763245, 31.80782127], [74.56022644, 31.81528091], [74.55960846, 31.81869125], [74.55625153, 31.82156944], [74.55615997, 31.82177925], [74.55584717, 31.82249069], [74.55574036, 31.82766914], [74.55638123, 31.82882118], [74.56466675, 31.83243752], [74.57256317, 31.84171295], [74.58046722, 31.84354019], [74.58065033, 31.84477997], [74.58119965, 31.8452301], [74.58229065, 31.85505295], [74.58329773, 31.85686111], [74.5855484, 31.85881805], [74.58811188, 31.86028481], [74.59599304, 31.86479187], [74.59632111, 31.86750031], [74.59593201, 31.8771801], [74.59642792, 31.8792305], [74.59803009, 31.8835125], [74.59910583, 31.88511086], [74.60028076, 31.88602066], [74.60250092, 31.88648987], [74.60383606, 31.88535118], [74.60437775, 31.88400269], [74.61178589, 31.88128853], [74.61521912, 31.8808918], [74.62261963, 31.88134956], [74.6265564, 31.88293076], [74.629776, 31.88543129], [74.63091278, 31.88705063], [74.63368988, 31.88970757], [74.63552856, 31.89447021], [74.63788605, 31.89672089], [74.6389389, 31.89694977], [74.64424896, 31.89696121], [74.64715576, 31.89585114], [74.64846802, 31.89629173], [74.65081024, 31.8980999], [74.65161896, 31.90081024], [74.65133667, 31.90464973], [74.65158844, 31.90917969], [74.6519928, 31.90986061], [74.65637207, 31.91143036], [74.65899658, 31.91348076], [74.65986633, 31.91823006], [74.66187286, 31.91867256], [74.66662598, 31.91687012], [74.66794586, 31.91664124], [74.66927338, 31.91687965], [74.67019653, 31.91805077], [74.670578, 31.91868973], [74.67404175, 31.92097092], [74.67614746, 31.9216404], [74.68470764, 31.92309952], [74.6872406, 31.92290115], [74.68959808, 31.92255974], [74.69303894, 31.92098999], [74.69436646, 31.92010117], [74.69477081, 31.9194355], [74.70326233, 31.92489815], [74.70506287, 31.93057632], [74.709198, 31.95794868], [74.7177887, 31.95773506], [74.72665405, 31.94217873], [74.73591614, 31.93738937], [74.73963928, 31.93853951], [74.74578094, 31.9416008], [74.74577332, 31.94565964], [74.74517822, 31.94922066], [74.74595642, 31.95177269], [74.74772644, 31.95228004], [74.75013733, 31.95009041], [74.75174713, 31.94753838], [74.75509644, 31.94703102], [74.75948334, 31.94619942], [74.76294708, 31.94824982], [74.76461029, 31.94971085], [74.76521301, 31.95021057], [74.76596069, 31.95069122], [74.76860046, 31.95181847], [74.78365326, 31.95545959], [74.78829193, 31.95724106], [74.79364014, 31.95934105], [74.80137634, 31.96179008], [74.80269623, 31.96066856], [74.80297089, 31.95750999], [74.80631256, 31.95543289], [74.80671692, 31.9539299], [74.80914307, 31.95513916], [74.81038666, 31.95616913], [74.81217957, 31.96216965], [74.81510162, 31.97174072], [74.81987762, 31.97649193], [74.81990051, 31.9781208], [74.82012939, 31.98438072], [74.81774139, 31.99385071], [74.81835175, 31.99744987], [74.81904602, 31.9979229], [74.82012939, 31.9979229], [74.82048798, 32.00016022], [74.82141113, 32.00083923], [74.82778168, 32.00513077], [74.83840942, 32.00696945], [74.84416962, 32.00831223], [74.84496307, 32.00875854], [74.84574127, 32.00923157], [74.84615326, 32.01079941], [74.84548187, 32.01327896], [74.84069824, 32.01736069], [74.84020233, 32.01826096], [74.84033966, 32.02025986], [74.85234833, 32.02188873], [74.85501099, 32.02320862], [74.8564682, 32.02592087], [74.85949707, 32.02661133], [74.86058044, 32.02614975], [74.86107635, 32.0259285], [74.86160278, 32.02479935], [74.86427307, 32.02368927], [74.86508179, 32.02391052], [74.86750793, 32.03115082], [74.86769104, 32.0333786], [74.8673172, 32.03450012], [74.86477661, 32.03699112], [74.86212158, 32.04330063], [74.86199188, 32.04463959], [74.86225128, 32.0451088], [74.86873627, 32.04782104], [74.87242889, 32.05052948], [74.87934113, 32.05187988], [74.89730072, 32.0494194], [74.89803314, 32.04964066], [74.89894867, 32.04988098], [74.89971924, 32.05031204], [74.90312195, 32.0571022], [74.90421295, 32.05778885], [74.90529633, 32.06035995], [74.90686035, 32.06251144], [74.91337585, 32.06492996], [74.91426086, 32.06521988], [74.92592621, 32.06565094], [74.93874359, 32.06197357], [74.93914032, 32.06185913], [74.94335175, 32.05958557], [74.94629669, 32.05938721], [74.96031952, 32.05503082], [74.96463776, 32.0517807], [74.96614075, 32.05101013], [74.96620178, 32.05060577], [74.96666718, 32.04738998], [74.96614075, 32.04703903], [74.96404266, 32.04492188], [74.96364594, 32.04402924], [74.96378326, 32.04312897], [74.96826172, 32.04201889], [74.97039032, 32.04177094], [74.97072601, 32.04217148], [74.97223663, 32.04222107], [74.97331238, 32.04198074], [74.977211, 32.04232788], [74.98691559, 32.03502655], [74.98741913, 32.0346489], [74.99841309, 32.02866745], [75.0, 32.02869034], [75.00344849, 32.02873611], [75.00492859, 32.02875519], [75.01061249, 32.03039932], [75.02302551, 32.03904724], [75.0309906, 32.04058075], [75.04588318, 32.03923416], [75.05084991, 32.04130936], [75.06893158, 32.05837631], [75.06902313, 32.05846405], [75.07258606, 32.05958939], [75.07446289, 32.05978012], [75.07524872, 32.06047058], [75.07603455, 32.06072235], [75.08119202, 32.05624008], [75.0774231, 32.06116867], [75.07866669, 32.06158066], [75.07919312, 32.06203079], [75.08583069, 32.0628891], [75.08624268, 32.06208038], [75.09005737, 32.05995941], [75.09216309, 32.0594902], [75.09427643, 32.06087112], [75.09483337, 32.06132889], [75.0953598, 32.06650925], [75.09747314, 32.0703392], [75.09866333, 32.0712204], [75.10806274, 32.07485962], [75.10941315, 32.07600021], [75.11048889, 32.07664108], [75.11353302, 32.08119202], [75.11625671, 32.08280945], [75.11785126, 32.0830307], [75.12001038, 32.08317184], [75.12320709, 32.08203888], [75.12982941, 32.08068085], [75.13141632, 32.08135986], [75.13828278, 32.08293915], [75.14180756, 32.08330154], [75.14438629, 32.082901], [75.1519165, 32.08045959], [75.15270996, 32.07910919], [75.15338135, 32.07883072], [75.15419769, 32.07593918], [75.15480804, 32.07548904], [75.15705872, 32.07229996], [75.15757751, 32.07205963], [75.15836334, 32.06845856], [75.16284943, 32.06777191], [75.1644516, 32.06797028], [75.1667099, 32.07025909], [75.16816711, 32.07138062], [75.17163849, 32.07902908], [75.17479706, 32.08129883], [75.18091583, 32.08218002], [75.18147278, 32.08197021], [75.18358612, 32.08263016], [75.18437195, 32.08306885], [75.18514252, 32.08375168], [75.18550873, 32.08716202], [75.18517303, 32.09526062], [75.18769073, 32.09931183], [75.18917084, 32.10020065], [75.19156647, 32.10065079], [75.19315338, 32.10020065], [75.1937027, 32.10065079], [75.19320679, 32.11463928], [75.19333649, 32.11529922], [75.19532013, 32.11664963], [75.1989975, 32.11732864], [75.20459747, 32.11598969], [75.20503235, 32.11560822], [75.21128082, 32.11875534], [75.21204376, 32.11914063], [75.22270966, 32.11252975], [75.22496033, 32.10689926], [75.22360229, 32.09107208], [75.22776031, 32.08455658], [75.23342896, 32.08436203], [75.23916626, 32.08715057], [75.27197266, 32.11275101], [75.27481079, 32.11884689], [75.2772522, 32.13524246], [75.28326416, 32.14216995], [75.2880249, 32.14443207], [75.30940247, 32.15460968], [75.31423187, 32.15918732], [75.3177948, 32.17081833], [75.31719208, 32.19280624], [75.32284546, 32.20132065], [75.33328247, 32.20471954], [75.33307648, 32.20486069], [75.31964111, 32.20824051], [75.31358337, 32.21239853], [75.31420135, 32.2149086], [75.31494141, 32.21567917], [75.31629944, 32.21707916], [75.31774139, 32.21813202], [75.3232193, 32.21889114], [75.33004761, 32.21875], [75.33341217, 32.21910858], [75.34015656, 32.21760178], [75.34333038, 32.21850204], [75.34438324, 32.21828079], [75.34623718, 32.21804047], [75.3496933, 32.21958923], [75.35263062, 32.22275162], [75.35794067, 32.22589111], [75.35927582, 32.22703934], [75.36048126, 32.23175049], [75.36128998, 32.23221207], [75.36277771, 32.23377991], [75.36315155, 32.23468018], [75.36370087, 32.23828125], [75.36354065, 32.23918915], [75.36251068, 32.23986053], [75.36173248, 32.24032974], [75.3604126, 32.2441597], [75.35933685, 32.24485016], [75.35830688, 32.2457695], [75.35695648, 32.24895096], [75.35700226, 32.25186157], [75.35864258, 32.25860214], [75.35957336, 32.25951004], [75.36315155, 32.26177979], [75.36502075, 32.26243973], [75.36598206, 32.26401901], [75.36620331, 32.26501846], [75.36699677, 32.26874924], [75.36415863, 32.27180862], [75.36161804, 32.27393341], [75.36107635, 32.27439117], [75.36107635, 32.27484894], [75.35632324, 32.27848053], [75.35326385, 32.27816391], [75.34938812, 32.28395081], [75.33992004, 32.28856659], [75.33622742, 32.29573822], [75.33512115, 32.30076218], [75.3343277, 32.30436707], [75.33666992, 32.32259369], [75.33042145, 32.33171082], [75.32232666, 32.33732605], [75.32440186, 32.34165955], [75.32530212, 32.3428421], [75.33177948, 32.34469986], [75.3440094, 32.34020996], [75.34526825, 32.33916092], [75.35919189, 32.33491898], [75.37346649, 32.33057022], [75.37853241, 32.3288002], [75.38595581, 32.32769012], [75.39745331, 32.32625198], [75.41499329, 32.32427216], [75.43107605, 32.32648849], [75.43257904, 32.32669067], [75.44859314, 32.33132172], [75.45178986, 32.33176041], [75.45635223, 32.33351898], [75.46660614, 32.33885193], [75.47223663, 32.34004974], [75.473526, 32.33919907], [75.46775818, 32.3175621], [75.47142029, 32.31465149], [75.47992706, 32.31034851], [75.48475647, 32.31029129], [75.49022675, 32.31021118], [75.49111938, 32.30672073], [75.49212646, 32.30279922], [75.49002075, 32.28797913], [75.49472046, 32.27690887], [75.49894714, 32.27532959], [75.50123596, 32.27605057], [75.50450134, 32.27952957], [75.50559998, 32.28134155], [75.51582336, 32.29798889], [75.5242691, 32.34004974], [75.52921295, 32.34888077], [75.54515076, 32.36082077], [75.55731964, 32.36695862], [75.56700134, 32.37184143], [75.59263611, 32.38169861], [75.63697815, 32.38737869], [75.64807129, 32.3888092], [75.66274261, 32.39350891], [75.68495941, 32.40061951], [75.69822693, 32.40953064], [75.71153259, 32.41815948], [75.71534729, 32.42383194], [75.71974945, 32.43032074], [75.72515106, 32.43832016], [75.72970581, 32.44506073], [75.73532104, 32.45468903], [75.74373627, 32.46910858], [75.74505615, 32.47426224], [75.7459259, 32.47634888], [75.75296021, 32.4752388], [75.77246857, 32.47510147], [75.77886963, 32.47504044], [75.79014587, 32.47879028], [75.80433655, 32.48706055], [75.81569672, 32.4992218], [75.82357788, 32.50764084], [75.82504272, 32.50922012], [75.82892609, 32.51996994], [75.83055115, 32.52450943], [75.83783722, 32.5376091], [75.85653687, 32.55842209], [75.87177277, 32.57529068], [75.87254333, 32.57619095], [75.87545013, 32.57086182], [75.87030029, 32.55876923], [75.85636902, 32.53768921], [75.85138702, 32.5213089], [75.85096741, 32.50786972], [75.85527802, 32.49958038], [75.86876678, 32.48868179], [75.88712311, 32.47203064], [75.89541626, 32.46186066], [75.91549683, 32.44869995], [75.92443848, 32.4389801], [75.93141174, 32.43078995], [75.93463135, 32.42475891], [75.93216705, 32.41682053], [75.92592621, 32.41178131], [75.91542053, 32.41025925], [75.91110992, 32.40919113], [75.87193298, 32.39844894], [75.86631012, 32.39456177], [75.8438797, 32.37931061], [75.83740234, 32.37302017], [75.81887054, 32.35503006], [75.81391907, 32.35055923], [75.79927826, 32.33737183], [75.79371643, 32.3323822], [75.78549194, 32.3237915], [75.78314209, 32.32220078], [75.7633667, 32.30215073], [75.76185608, 32.29611206], [75.75467682, 32.28607941], [75.75183868, 32.28417206], [75.73639679, 32.27376175], [75.70487976, 32.26723862], [75.68489075, 32.26501846], [75.67584229, 32.26401901], [75.65487671, 32.25585175], [75.65244293, 32.25543976], [75.64092255, 32.2473793], [75.63407898, 32.24473953], [75.62254333, 32.23468018], [75.62177277, 32.23003006], [75.62011719, 32.22021103], [75.61833191, 32.19702148], [75.6194458, 32.18984985], [75.62021637, 32.18516922], [75.64958954, 32.17969131], [75.65615845, 32.17662048], [75.66182709, 32.16466904], [75.65547943, 32.14606094], [75.64787292, 32.13766098], [75.6312027, 32.11949921], [75.61055756, 32.09960937], [75.57875824, 32.0816803], [75.598526, 32.06600952], [75.60955811, 32.06946945], [75.62532043, 32.07266998], [75.6400528, 32.07674026], [75.64936066, 32.07717133], [75.67310333, 32.06692123], [75.68981934, 32.06153107], [75.692276, 32.05945206], [75.70040894, 32.04359055], [75.71048737, 32.03602219], [75.72322845, 32.03617096], [75.73397827, 32.03733063], [75.73800659, 32.03580093], [75.74003601, 32.03448105], [75.74836731, 32.02716064], [75.75380707, 32.0198822], [75.76154327, 32.01390076], [75.76644897, 32.00764084], [75.77429962, 32.00078964], [75.7842865, 31.99432945], [75.79512024, 31.9885807], [75.80560303, 31.98501968], [75.81404877, 31.98340034], [75.83637238, 31.9816494], [75.84162903, 31.97361946], [75.8513031, 31.97253036], [75.85679626, 31.96945953], [75.86617279, 31.96882057], [75.8685379, 31.96690941], [75.86972046, 31.96597099], [75.87771606, 31.96198082], [75.89454651, 31.94980049], [75.89595795, 31.94025993], [75.90276337, 31.92791939], [75.91268921, 31.91657829], [75.92617035, 31.88979149], [75.93144226, 31.88383102], [75.93840027, 31.8678894], [75.94425201, 31.85751915], [75.94972992, 31.84810066], [75.95358276, 31.83995056], [75.95575714, 31.83237076], [75.96762848, 31.82351112], [75.97091675, 31.81921005], [75.97146606, 31.81454849], [75.96697998, 31.81488991], [75.96031189, 31.81847954], [75.95289612, 31.82396126], [75.94877625, 31.8231411], [75.9360733, 31.81826019], [75.93325043, 31.81501961], [75.92932892, 31.81524086], [75.92675018, 31.81644058], [75.92182922, 31.81718063], [75.92722321, 31.80514908], [75.93300629, 31.7971096], [75.93582153, 31.78974915], [75.93644714, 31.78434944], [75.94506073, 31.78128052], [75.95189667, 31.76301956], [75.9595108, 31.74953842], [75.95974731, 31.74430275], [75.95755005, 31.7404995], [75.96100616, 31.73677254], [75.96602631, 31.73345947], [75.96936798, 31.71967125], [75.97257996, 31.71515274], [75.97737122, 31.70499992], [75.97579193, 31.69532967], [75.98562622, 31.68539047], [75.99066162, 31.6847496], [75.99098969, 31.68575096], [75.99214935, 31.68452072], [75.99469757, 31.68154907], [75.99742126, 31.6760006], [75.99736023, 31.66888046], [76.00473022, 31.66303062], [76.00392151, 31.65689087], [76.00624847, 31.65142822], [76.00274658, 31.64657021], [76.01760101, 31.62167168], [76.02319336, 31.61547089], [76.03140259, 31.60946083], [76.03671265, 31.60679817], [76.03997803, 31.60845947], [76.04402924, 31.60303116], [76.04268646, 31.59588051], [76.04315948, 31.59197044], [76.05150604, 31.58179092], [76.06490326, 31.56179047], [76.06601715, 31.56051826], [76.07158661, 31.55414963], [76.07681274, 31.54595947], [76.08399963, 31.53718185], [76.08895874, 31.52763939], [76.09062195, 31.51898956], [76.09455109, 31.51420975], [76.10410309, 31.5023098], [76.10816193, 31.49510956], [76.10795593, 31.48221016], [76.11472321, 31.47354126], [76.11551666, 31.46544075], [76.12127686, 31.46097946], [76.122612, 31.45372963], [76.12824249, 31.44375992], [76.13507843, 31.43750954], [76.14346313, 31.43229103], [76.14713287, 31.42560959], [76.14707184, 31.41884041], [76.15349579, 31.41401291], [76.15674591, 31.4045105], [76.15303802, 31.39725113], [76.14713287, 31.39190292], [76.1386261, 31.38685989], [76.13408661, 31.38264275], [76.13503265, 31.36175919], [76.13961029, 31.3531208], [76.14774323, 31.34814835], [76.1580658, 31.34694099], [76.1663208, 31.34145927], [76.16607666, 31.3261795], [76.16845703, 31.31412125], [76.17282867, 31.30673981], [76.18569946, 31.3046608], [76.20639801, 31.30526161], [76.21495819, 31.30764008], [76.22319031, 31.31306076], [76.24414063, 31.31371117], [76.25562286, 31.31495094], [76.26116943, 31.30583], [76.26840973, 31.30660057], [76.27735901, 31.3099308], [76.28439331, 31.31356049], [76.29039001, 31.31563187], [76.2960968, 31.31920052], [76.30226898, 31.3263607], [76.2959671, 31.34222984], [76.29991913, 31.34383011], [76.3157959, 31.34749985], [76.31783295, 31.35222054], [76.32446289, 31.34711075], [76.33007813, 31.34527969], [76.33666229, 31.35301971], [76.33129883, 31.35909271], [76.33001709, 31.36771011], [76.32958221, 31.37951851], [76.3182373, 31.3810997], [76.31877136, 31.38817978], [76.31584167, 31.40237808], [76.32952118, 31.40113831], [76.33460236, 31.40373993], [76.34689331, 31.40571022], [76.35312653, 31.41246033], [76.35914612, 31.41563034], [76.35677338, 31.4296093], [76.36313629, 31.44135094], [76.36917114, 31.42814064], [76.37526703, 31.4221611], [76.37303162, 31.41364861], [76.38162994, 31.41061974], [76.39039612, 31.39733124], [76.37924957, 31.3911705], [76.39105225, 31.37863159], [76.39924622, 31.36547089], [76.40883636, 31.35374832], [76.41284943, 31.34765816], [76.41816711, 31.33731079], [76.42801666, 31.32518005], [76.43744659, 31.31742287], [76.44827271, 31.30599022], [76.44558716, 31.30041122], [76.43580627, 31.29463959], [76.42849731, 31.28923035], [76.43113708, 31.28284073], [76.44577789, 31.28970909], [76.45101166, 31.29620934], [76.46208954, 31.30681038], [76.46671295, 31.31021118], [76.47245026, 31.30669975], [76.47505951, 31.29899979], [76.47564697, 31.29220009], [76.4797287, 31.28910255], [76.4832077, 31.28427124], [76.48858643, 31.27340126], [76.49823761, 31.27329063], [76.50340271, 31.27788925], [76.51091003, 31.28261948], [76.51426697, 31.28307915], [76.5165863, 31.27738953], [76.51428223, 31.26450157], [76.51811218, 31.26231003], [76.52789307, 31.2699604], [76.53122711, 31.28354073], [76.53717041, 31.28395081], [76.53481293, 31.27233124], [76.53264618, 31.26651192], [76.53495026, 31.25535011], [76.54592133, 31.25588036], [76.55224609, 31.26485252], [76.57050323, 31.28014946], [76.60161591, 31.25090981], [76.59268188, 31.24615097], [76.58470917, 31.23964119], [76.58252716, 31.2309494], [76.57596588, 31.22578812], [76.57935333, 31.2204895], [76.58061218, 31.21635246], [76.5867691, 31.21606064], [76.61625671, 31.22944069], [76.62594604, 31.22709084], [76.62452698, 31.22104073], [76.63414764, 31.21533966], [76.63542175, 31.21298027], [76.62011719, 31.20666122], [76.61869812, 31.20390129], [76.61221313, 31.20264053], [76.6057663, 31.19712067], [76.60066223, 31.1910305], [76.59831238, 31.18647957], [76.59039307, 31.18285942], [76.59246826, 31.1722908], [76.58943939, 31.16476059], [76.5914917, 31.16032028], [76.59007263, 31.15726852], [76.59467316, 31.15134048], [76.59874725, 31.15117073], [76.59395599, 31.1364994], [76.58931732, 31.12770081], [76.59744263, 31.12619972], [76.60727692, 31.11964035], [76.61559296, 31.12158012], [76.62371063, 31.11800957], [76.62573242, 31.11024284], [76.61184692, 31.09638977], [76.60782623, 31.08350182], [76.60489655, 31.07837868], [76.60952759, 31.06067085], [76.59896851, 31.05355072], [76.60151672, 31.04356194], [76.60518646, 31.03351974], [76.61360168, 31.02198982], [76.61006927, 31.0042305], [76.61241913, 31.0020504], [76.62094879, 30.99830055], [76.62592316, 30.9924984], [76.63334656, 30.99072266], [76.65306091, 30.98180962], [76.6626358, 30.97113037], [76.66819, 30.96988106], [76.69423676, 30.97249031], [76.69615936, 30.97179031], [76.69837952, 30.96889114], [76.70507813, 30.9633007], [76.71260071, 30.96342087], [76.72413635, 30.9505825], [76.72547913, 30.9425106], [76.72602081, 30.93933105], [76.7383728, 30.93005943], [76.74382019, 30.92904091], [76.74862671, 30.92916107], [76.74868774, 30.92379951], [76.75411987, 30.92295265], [76.75383759, 30.91781807], [76.76985931, 30.90639114], [76.76254272, 30.89340973], [76.76904297, 30.87652969], [76.77333832, 30.87115097], [76.78494263, 30.8612709], [76.80121613, 30.84252167], [76.8065567, 30.84025192], [76.81894684, 30.83710098], [76.82775116, 30.83256912], [76.83209991, 30.82542038], [76.83335876, 30.81589127], [76.83351135, 30.80457115], [76.84134674, 30.79908943], [76.8467865, 30.79252052], [76.83081818, 30.76793289], [76.82818604, 30.76379013], [76.81198883, 30.76663971], [76.80145264, 30.7627697], [76.7931366, 30.76651955], [76.79136658, 30.76950073], [76.80345154, 30.77760124], [76.80387878, 30.77902031], [76.8021698, 30.78182983], [76.79776764, 30.78527069], [76.79612732, 30.78577042], [76.78872681, 30.78097153], [76.78093719, 30.77387047], [76.7755661, 30.77605057], [76.76930237, 30.77697945], [76.77266693, 30.78308105], [76.77629089, 30.78404045], [76.77732849, 30.78545952], [76.77334595, 30.78790092], [76.76760101, 30.79511833], [76.75933838, 30.79903984], [76.75092316, 30.7968483], [76.74575043, 30.79463768], [76.74298859, 30.79148293], [76.73999023, 30.79108047], [76.73822021, 30.78985023], [76.73922729, 30.78607941], [76.7351532, 30.78300095], [76.7305069, 30.78100967], [76.73123169, 30.77701759], [76.72924042, 30.77625084], [76.7227478, 30.77071953], [76.71832275, 30.76909256], [76.70786285, 30.77010918], [76.69062805, 30.76008034], [76.69293213, 30.75739098], [76.69332123, 30.75266075], [76.69068146, 30.74666023], [76.69267273, 30.74471283], [76.69545746, 30.74409294], [76.70127106, 30.74529076], [76.70992279, 30.73548126], [76.71115875, 30.73229027], [76.71614075, 30.72863007], [76.71795654, 30.72063065], [76.71759796, 30.71746826], [76.71533966, 30.71497917], [76.71520233, 30.7133007], [76.72154999, 30.71208954], [76.72545624, 30.70998955], [76.72690582, 30.70755005], [76.72609711, 30.70491982], [76.72458649, 30.70379066], [76.7263031, 30.6959095], [76.72749329, 30.69565964], [76.73044586, 30.69749832], [76.73288727, 30.69716072], [76.73847961, 30.68915176], [76.74503326, 30.6904583], [76.77069092, 30.67794037], [76.78930664, 30.67058182], [76.79437256, 30.66931915], [76.80293274, 30.6754818], [76.80591583, 30.6802597], [76.81050873, 30.68495178], [76.81980896, 30.68582916], [76.818367, 30.67296028], [76.81881714, 30.66059113], [76.82409668, 30.66007042], [76.82694244, 30.66333008], [76.83006287, 30.66493034], [76.83499908, 30.66411018], [76.83479309, 30.65582085], [76.83985901, 30.65678024], [76.84983826, 30.66485977], [76.85540771, 30.67320251], [76.86222839, 30.6792717], [76.86310577, 30.6715107], [76.86186218, 30.65971947], [76.85897064, 30.65155983], [76.85858154, 30.64063072], [76.86194611, 30.64027023], [76.86795807, 30.64163971], [76.87267303, 30.64002037], [76.87709045, 30.63702011], [76.88063049, 30.6330719], [76.88360596, 30.62709045], [76.89453888, 30.62333107], [76.89959717, 30.62002945], [76.90154266, 30.60840988], [76.91060638, 30.60582924], [76.91342926, 30.59970284], [76.9072113, 30.59140968], [76.89855957, 30.5884304], [76.90453339, 30.58057022], [76.90390778, 30.57518005], [76.89888763, 30.56671906], [76.89888763, 30.56402969], [76.90384674, 30.56171989], [76.90592957, 30.55838966], [76.90223694, 30.55104065], [76.89218903, 30.54444122], [76.88504028, 30.54042053], [76.88775635, 30.53815079], [76.89821625, 30.53470039], [76.90724945, 30.5298996], [76.91429901, 30.52655029], [76.92006683, 30.52469063], [76.92032623, 30.51802063], [76.91828918, 30.50723076], [76.91590881, 30.49942017], [76.91236877, 30.49365997], [76.9078064, 30.49078941], [76.90114594, 30.48884964], [76.89385986, 30.48964119], [76.88891602, 30.48458862], [76.8898468, 30.47932816], [76.89663696, 30.47537994], [76.8980484, 30.46778107], [76.89518738, 30.45556831], [76.89071655, 30.45106125], [76.88884735, 30.44111061], [76.88993073, 30.43669128], [76.90167999, 30.42832947], [76.90370941, 30.42488098], [76.90370178, 30.41823006], [76.90524292, 30.41319084], [76.90392303, 30.40995026], [76.90384674, 30.40670967], [76.90518188, 30.40468979], [76.90925598, 30.40327072], [76.91947174, 30.4030304], [76.92579651, 30.40159035], [76.92904663, 30.3998909], [76.93139648, 30.39707184], [76.93026733, 30.39258957], [76.9272995, 30.38863945], [76.92077637, 30.38478279], [76.91699219, 30.38275909], [76.90348816, 30.36750984], [76.89776611, 30.36260033], [76.89227295, 30.35967827], [76.88722229, 30.35838127], [76.88022614, 30.35970116], [76.87644196, 30.36333847], [76.87571716, 30.36954117], [76.88043213, 30.38298988], [76.88022614, 30.38622284], [76.87441254, 30.39128113], [76.86624146, 30.3948307], [76.86756134, 30.40151978], [76.86473083, 30.40879059], [76.84726715, 30.41489983], [76.83972931, 30.42074966], [76.8324585, 30.43388176], [76.82789612, 30.43033028], [76.82314301, 30.42254829], [76.80845642, 30.41185951], [76.79728699, 30.41512108], [76.78069305, 30.4150219], [76.77082062, 30.41830063], [76.764328, 30.42501068], [76.76674652, 30.43600082], [76.76332855, 30.43972969], [76.75786591, 30.43889046], [76.7543869, 30.43280983], [76.74887085, 30.42663193], [76.73786163, 30.42486954], [76.72516632, 30.42041969], [76.72654724, 30.40500069], [76.71289063, 30.39824295], [76.70014954, 30.39361191], [76.70168304, 30.38482857], [76.70487976, 30.38083267], [76.71572113, 30.38026047], [76.71808624, 30.37710953], [76.7089386, 30.36816978], [76.71135712, 30.36512947], [76.73039246, 30.36744118], [76.73501587, 30.36491013], [76.73853302, 30.35964966], [76.73462677, 30.35393906], [76.72901154, 30.34843254], [76.72392273, 30.34436989], [76.71515656, 30.33990097], [76.71515656, 30.33291054], [76.71096039, 30.32987022], [76.70475006, 30.33168983], [76.70025635, 30.32985115], [76.69767761, 30.32485771], [76.68846893, 30.32598114], [76.67949677, 30.32137108], [76.67462921, 30.32595062], [76.67088318, 30.31917], [76.67307281, 30.31277084], [76.66242981, 30.29955101], [76.65128326, 30.2993412], [76.626297, 30.28392982], [76.62283325, 30.29138947], [76.61969757, 30.28784943], [76.61437988, 30.27527046], [76.6098175, 30.27061081], [76.60449982, 30.27226067], [76.58094025, 30.26987076], [76.55792999, 30.26426125], [76.54763794, 30.26492119], [76.54582214, 30.25863075], [76.54692841, 30.24953079], [76.5459671, 30.24353981], [76.54219818, 30.23637962], [76.53292084, 30.23207855], [76.53253174, 30.22713089], [76.54438019, 30.23085976], [76.54766846, 30.23444176], [76.56904602, 30.2513504], [76.57588959, 30.25586128], [76.58399963, 30.25653076], [76.59031677, 30.25412178], [76.59590912, 30.24394035], [76.59942627, 30.24032974], [76.60930634, 30.23488045], [76.61199951, 30.23096848], [76.61186981, 30.22562981], [76.60627747, 30.22001076], [76.60427856, 30.21517181], [76.60941315, 30.21277046], [76.61675262, 30.21105957], [76.63282013, 30.21001053], [76.63891602, 30.20594025], [76.63716888, 30.19695091], [76.64198303, 30.19366837], [76.641716, 30.18925095], [76.63925171, 30.18521118], [76.6227417, 30.17029953], [76.62763977, 30.1551075], [76.62326813, 30.14940262], [76.62309265, 30.14466095], [76.62940216, 30.13476944], [76.62872314, 30.13019943], [76.62520599, 30.12103081], [76.62474823, 30.11688995], [76.62663269, 30.11396027], [76.62755585, 30.11048126], [76.62667084, 30.10564995], [76.62515259, 30.10184097], [76.61947632, 30.09536171], [76.61769867, 30.09406281], [76.6158905, 30.09278107], [76.61411285, 30.09150124], [76.61235046, 30.09020996], [76.61061096, 30.08886909], [76.60896301, 30.08745956], [76.60742188, 30.08589935], [76.60595703, 30.08428955], [76.6044693, 30.08272171], [76.60286713, 30.08131981], [76.60105133, 30.08023071], [76.59877777, 30.07970047], [76.59642029, 30.07947159], [76.59406281, 30.0795517], [76.59168243, 30.07974052], [76.58953094, 30.07929993], [76.58763885, 30.07814026], [76.58583069, 30.07674026], [76.58399963, 30.07543945], [76.58194733, 30.07467079], [76.57917023, 30.07459068], [76.57676697, 30.07509995], [76.57637787, 30.07611084], [76.57787323, 30.07771111], [76.57977295, 30.07953072], [76.58104706, 30.08127975], [76.58194733, 30.08312988], [76.5819397, 30.08521271], [76.58080292, 30.08685112], [76.57879639, 30.08784294], [76.57663727, 30.08876038], [76.57478333, 30.08995819], [76.57301331, 30.09123993], [76.57124329, 30.09255981], [76.5694809, 30.0938797], [76.56767273, 30.09511948], [76.56575012, 30.09626007], [76.56363678, 30.09711075], [76.56143951, 30.09763908], [76.55916595, 30.09804916], [76.55487061, 30.0987606], [76.533638, 30.08278084], [76.52554321, 30.0808506], [76.50894165, 30.07953072], [76.50112152, 30.07662964], [76.49713898, 30.08156967], [76.49501038, 30.08708191], [76.49517059, 30.09238815], [76.49082947, 30.0971508], [76.48348999, 30.09955978], [76.46157074, 30.09900093], [76.4520874, 30.10070992], [76.44909668, 30.10480118], [76.44664001, 30.11123085], [76.4444809, 30.12288094], [76.44618988, 30.12895966], [76.44645691, 30.1371212], [76.44104004, 30.13595963], [76.43631744, 30.13702965], [76.43135071, 30.14071083], [76.42604065, 30.14756012], [76.42488861, 30.15462112], [76.42227173, 30.15870094], [76.42243195, 30.16357994], [76.42642975, 30.16757965], [76.42900848, 30.1729908], [76.42858124, 30.1797924], [76.4200058, 30.19787979], [76.41020203, 30.20228958], [76.39884186, 30.1989994], [76.39100647, 30.19225121], [76.38674164, 30.18699074], [76.3809967, 30.18324089], [76.38304138, 30.17902946], [76.38861847, 30.17410088], [76.40164185, 30.1577282], [76.39951324, 30.15517044], [76.39251709, 30.15026093], [76.3861618, 30.14824104], [76.38456726, 30.14581108], [76.38832855, 30.13832855], [76.38845062, 30.13396835], [76.39000702, 30.12754059], [76.3843689, 30.1238327], [76.37471771, 30.12372971], [76.36374664, 30.12754059], [76.35816193, 30.13330269], [76.3483429, 30.15052032], [76.34306335, 30.1534481], [76.32588196, 30.14924049], [76.3286972, 30.14476967], [76.33570862, 30.13926125], [76.34829712, 30.13166046], [76.34892273, 30.12766075], [76.33790588, 30.11585045], [76.32837677, 30.10951042], [76.32289886, 30.10822105], [76.31275177, 30.10851288], [76.29308319, 30.11862946], [76.28636169, 30.11682129], [76.27984619, 30.11365128], [76.27202606, 30.11433983], [76.26551056, 30.11769295], [76.25115967, 30.11899948], [76.24458313, 30.1218605], [76.24299622, 30.12746811], [76.24095917, 30.12865829], [76.23816681, 30.13091087], [76.23680115, 30.13255119], [76.23539734, 30.13414955], [76.23375702, 30.13556862], [76.23191833, 30.13677979], [76.22997284, 30.1378994], [76.2280426, 30.1390419], [76.22628784, 30.14031029], [76.2247467, 30.14180946], [76.22336578, 30.14343834], [76.22202301, 30.14509964], [76.2205658, 30.14668083], [76.21897888, 30.14817047], [76.2173233, 30.1497612], [76.21565247, 30.15139008], [76.21395111, 30.1530304], [76.21224976, 30.15460968], [76.21053314, 30.15607834], [76.20884705, 30.15739059], [76.20720673, 30.15851021], [76.20558929, 30.15934944], [76.20387268, 30.15890121], [76.20236206, 30.15671158], [76.20195007, 30.15457153], [76.20259857, 30.15281105], [76.20375824, 30.15103912], [76.20511627, 30.14924049], [76.20632172, 30.14740944], [76.20706177, 30.14550018], [76.20744324, 30.14348984], [76.20851898, 30.14172173], [76.2100296, 30.1400795], [76.21156311, 30.1384716], [76.21266174, 30.13683128], [76.21192932, 30.13506126], [76.21008301, 30.13360977], [76.20794678, 30.13314819], [76.20580292, 30.13376045], [76.20365143, 30.13473129], [76.20162964, 30.13582993], [76.19969177, 30.13721085], [76.19777679, 30.13870049], [76.19590759, 30.13999176], [76.19410706, 30.1407795], [76.19230652, 30.14045906], [76.19055176, 30.13862991], [76.18962097, 30.13669014], [76.19061279, 30.13496017], [76.19249725, 30.13351059], [76.1943512, 30.13235092], [76.19632721, 30.13126945], [76.19837189, 30.13025093], [76.20038605, 30.12930107], [76.20262909, 30.12865829], [76.20471191, 30.12786102], [76.20639801, 30.12648964], [76.20791626, 30.12495995], [76.20928955, 30.12330055], [76.21058655, 30.12161064], [76.21193695, 30.11996269], [76.21343994, 30.11845016], [76.21518707, 30.11717987], [76.2171402, 30.11610985], [76.21920013, 30.11512184], [76.22123718, 30.11412048], [76.22316742, 30.11301994], [76.2248764, 30.11165047], [76.22667694, 30.11040115], [76.2286911, 30.10933113], [76.23082733, 30.10852051], [76.233078, 30.10822105], [76.23539734, 30.108181], [76.23771667, 30.10823059], [76.24006653, 30.10827827], [76.24238586, 30.10819054], [76.24469757, 30.10792923], [76.2470932, 30.10762024], [76.2494812, 30.1072197], [76.2517395, 30.1067028], [76.25377655, 30.10602951], [76.25499725, 30.10457993], [76.2545929, 30.10239983], [76.25358582, 30.10053062], [76.25237274, 30.0986824], [76.25093079, 30.09706116], [76.2492218, 30.09603119], [76.24672699, 30.09638977], [76.24455261, 30.09614944], [76.242836, 30.09490967], [76.24120331, 30.09353065], [76.23963165, 30.09203911], [76.23808289, 30.09046173], [76.23660278, 30.08884811], [76.2351532, 30.08719826], [76.23381042, 30.08558083], [76.23246002, 30.08394051], [76.23116302, 30.08226013], [76.22991943, 30.08056831], [76.22869873, 30.07886124], [76.22749329, 30.07713127], [76.22632599, 30.0753994], [76.22509766, 30.07366943], [76.22395325, 30.07194138], [76.22273254, 30.0702076], [76.2215271, 30.06848907], [76.22035217, 30.06674957], [76.21916199, 30.06502914], [76.21798706, 30.06329918], [76.21681976, 30.06155014], [76.21566772, 30.05981064], [76.2144928, 30.05808067], [76.21330261, 30.05633163], [76.2121582, 30.05458832], [76.21102905, 30.05282021], [76.20987701, 30.05106926], [76.20864105, 30.04939079], [76.20723724, 30.04779053], [76.2056427, 30.04628944], [76.20404053, 30.04483986], [76.20252991, 30.04331017], [76.20111084, 30.04164124], [76.19962311, 30.03977966], [76.19838715, 30.03792953], [76.19793701, 30.03625107], [76.19890594, 30.03482819], [76.20111847, 30.03367233], [76.20345306, 30.03273964], [76.20580292, 30.03203011], [76.20838928, 30.03144836], [76.21098328, 30.03092957], [76.21333313, 30.03035164], [76.21514893, 30.0296402], [76.21613312, 30.0286808], [76.21543884, 30.02713013], [76.21354675, 30.02530861], [76.21140289, 30.02373123], [76.20947266, 30.02272987], [76.20720673, 30.02211952], [76.20490265, 30.02166939], [76.20263672, 30.02120018], [76.2003479, 30.02085114], [76.19803619, 30.02052116], [76.19581604, 30.02006149], [76.19346619, 30.01938057], [76.19156647, 30.01823044], [76.19091797, 30.01641273], [76.19050598, 30.01449013], [76.19020844, 30.01249123], [76.18998718, 30.01044846], [76.18981171, 30.00838089], [76.1896286, 30.00632286], [76.18937683, 30.00419044], [76.19303131, 29.99662018], [76.19577789, 29.9904995], [76.19713593, 29.98511124], [76.19748688, 29.97981071], [76.19901276, 29.97317123], [76.19473267, 29.96567917], [76.20345306, 29.95206833], [76.2050705, 29.94750023], [76.20387268, 29.94412041], [76.19087219, 29.94445992], [76.18480682, 29.94627953], [76.1789093, 29.94626808], [76.1696167, 29.93655968], [76.16629028, 29.92865944], [76.1714859, 29.92323112], [76.18199158, 29.92324066], [76.18358612, 29.91571808], [76.18270874, 29.89388084], [76.18463898, 29.88858032], [76.19740295, 29.88401985], [76.20812988, 29.88651085], [76.21694946, 29.88385963], [76.22529602, 29.88506126], [76.23245239, 29.88132095], [76.23869324, 29.87590027], [76.24201202, 29.86902809], [76.23795319, 29.86545944], [76.23522949, 29.85980988], [76.2318573, 29.85637093], [76.22852325, 29.85452843], [76.22290039, 29.85559082], [76.21582794, 29.85470963], [76.21176147, 29.85314941], [76.20965576, 29.8501606], [76.21111298, 29.8432312], [76.20964813, 29.84274292], [76.2022171, 29.84530067], [76.19418335, 29.8449707], [76.18936157, 29.84047127], [76.18582153, 29.83123016], [76.16665649, 29.81832123], [76.15312958, 29.81627274], [76.13926697, 29.81676292], [76.13210297, 29.81205177], [76.12718201, 29.80542946], [76.12140656, 29.7994709], [76.11638641, 29.79640007], [76.11026764, 29.80331993], [76.10321045, 29.80841064], [76.09438324, 29.81156158], [76.09056091, 29.81083107], [76.08605957, 29.80989838], [76.07766724, 29.80577278], [76.07557678, 29.79704857], [76.07543945, 29.78790092], [76.07434082, 29.78124046], [76.06990051, 29.77602005], [76.0632019, 29.7774601], [76.0584259, 29.77314949], [76.04148102, 29.7487812], [76.03565216, 29.74668121], [76.03292084, 29.74959946], [76.03170776, 29.7508812], [76.02424622, 29.75560188], [76.01759338, 29.75607109], [76.01127625, 29.75282097], [76.00382996, 29.75093079], [75.98927307, 29.74230957], [75.98000336, 29.73616982], [75.97254944, 29.73237038], [75.97045898, 29.73210907], [75.96485901, 29.73138046], [75.95748901, 29.73212051], [75.9500885, 29.73391151], [75.94235229, 29.73427963], [75.9386673, 29.73351288], [75.93662262, 29.73308182], [75.93401337, 29.7325325], [75.9289093, 29.73365021], [75.92314911, 29.73491096], [75.91394806, 29.73876953], [75.90313721, 29.74628258], [75.89723206, 29.7555294], [75.89068604, 29.75321007], [75.87928009, 29.74707031], [75.87201691, 29.75012016], [75.86377716, 29.75233078], [75.85459137, 29.76966095], [75.84362793, 29.77596092], [75.84124756, 29.78083992], [75.83338928, 29.79066086], [75.82927704, 29.80070114], [75.82901764, 29.81232071], [75.81997681, 29.8153801], [75.79605103, 29.80712128], [75.78320313, 29.81532097], [75.77243805, 29.82467079], [75.7716217, 29.82538986], [75.76698303, 29.82345009], [75.76342773, 29.82196045], [75.76059723, 29.81866074], [75.74839783, 29.81212044], [75.73272705, 29.81126022], [75.7259903, 29.81151962], [75.70987701, 29.81225967], [75.70593262, 29.80862045], [75.69744873, 29.75521088], [75.68743134, 29.75177956], [75.67830658, 29.75706291], [75.66616821, 29.77270126], [75.65638733, 29.7760601], [75.6496582, 29.77456093], [75.64087677, 29.77111053], [75.62535858, 29.7732296], [75.6235199, 29.76688957], [75.62261963, 29.75362015], [75.61322784, 29.74645805], [75.60048676, 29.74740028], [75.59274292, 29.74915123], [75.56878662, 29.74262047], [75.56308746, 29.74423981], [75.55639648, 29.7658329], [75.54418182, 29.77176094], [75.53019714, 29.7727108], [75.52397919, 29.76724052], [75.51171112, 29.76004982], [75.5063324, 29.77407074], [75.4983902, 29.77775002], [75.44426727, 29.80784988], [75.43547058, 29.79884911], [75.44315338, 29.79417038], [75.44378662, 29.7861805], [75.43463898, 29.78028107], [75.42720795, 29.77794075], [75.41976929, 29.77437973], [75.40999603, 29.77532005], [75.39723206, 29.76102066], [75.39679718, 29.74867058], [75.39087677, 29.73859978], [75.3837204, 29.7340107], [75.38218689, 29.72705841], [75.3835907, 29.72030258], [75.37877655, 29.7112999], [75.37003326, 29.71306038], [75.36194611, 29.71289063], [75.35855865, 29.70576096], [75.35269165, 29.70449066], [75.34121704, 29.69524002], [75.33535004, 29.69384956], [75.33384705, 29.68805122], [75.34603882, 29.67142105], [75.34932709, 29.66563988], [75.35044861, 29.65928078], [75.34850311, 29.65907097], [75.34680939, 29.65888977], [75.3414917, 29.66213036], [75.33014679, 29.67227936], [75.32260895, 29.67240906], [75.31772614, 29.67070007], [75.31623077, 29.66082191], [75.31169891, 29.64875984], [75.30753326, 29.63256073], [75.30105591, 29.62709045], [75.28785706, 29.61976814], [75.28056335, 29.61010933], [75.28034973, 29.6032505], [75.29361725, 29.59767151], [75.30203247, 29.59198952], [75.30451202, 29.58847809], [75.30486298, 29.58361053], [75.30304718, 29.57905006], [75.29606628, 29.5680809], [75.29064941, 29.56176186], [75.27503204, 29.56110954], [75.26748657, 29.55928993], [75.25453949, 29.55418015], [75.23806763, 29.55154037], [75.22348022, 29.54617119], [75.22432709, 29.55002975], [75.2281723, 29.55855751], [75.2217865, 29.57028008], [75.21788788, 29.57846069], [75.21118927, 29.58239937], [75.21936798, 29.59250259], [75.2232132, 29.5988903], [75.22123718, 29.60655022], [75.19937134, 29.6226902], [75.18473053, 29.62254143], [75.17333984, 29.63008118], [75.1724472, 29.63862991], [75.1733017, 29.64948082], [75.16854858, 29.65423012], [75.16275787, 29.65802956], [75.15783691, 29.66271019], [75.15892029, 29.66936111], [75.16783905, 29.67327118], [75.17531586, 29.67805099], [75.17986298, 29.67830276], [75.18888855, 29.68082809], [75.19528198, 29.6877594], [75.19766998, 29.69647026], [75.19243622, 29.69952965], [75.1884079, 29.70374107], [75.18724823, 29.71191978], [75.19368744, 29.72520065], [75.19809723, 29.73080063], [75.2061615, 29.73525047], [75.21067047, 29.73089027], [75.21660614, 29.72999001], [75.22136688, 29.73307037], [75.23097992, 29.75206757], [75.22733307, 29.75612068], [75.22328186, 29.76353836], [75.21673584, 29.77149963], [75.21617889, 29.7798996], [75.21238708, 29.78652], [75.20536041, 29.79000092], [75.1979599, 29.79622078], [75.19645691, 29.80511093], [75.19777679, 29.81344032], [75.20250702, 29.8213501], [75.20091248, 29.82999992], [75.18860626, 29.83457947], [75.18234253, 29.83870125], [75.17855835, 29.83690834], [75.17603302, 29.83506966], [75.1751709, 29.82951927], [75.16699982, 29.82495117], [75.15995789, 29.82364082], [75.15542603, 29.81981087], [75.15130615, 29.80183983], [75.14894867, 29.79611969], [75.14951324, 29.79164124], [75.15486145, 29.78910065], [75.15918732, 29.78421974], [75.15405273, 29.78101921], [75.141716, 29.77700806], [75.1354599, 29.78038025], [75.13141632, 29.78486061], [75.12491608, 29.80562019], [75.10228729, 29.80255127], [75.09552765, 29.8043499], [75.09017944, 29.80666161], [75.08905029, 29.81282997], [75.09333801, 29.81931114], [75.1071167, 29.82653046], [75.10408783, 29.83801079], [75.09895325, 29.84142113], [75.08574677, 29.84481049], [75.08125305, 29.84937286], [75.08098602, 29.85414124], [75.08468628, 29.85859108], [75.10058594, 29.8678894], [75.1042099, 29.87319183], [75.10309601, 29.87677956], [75.10267639, 29.89702034], [75.09475708, 29.90507126], [75.08978271, 29.91171074], [75.08480072, 29.91514015], [75.0777359, 29.91230965], [75.07000732, 29.8933506], [75.06548309, 29.87903976], [75.06040192, 29.87611961], [75.05175781, 29.87486076], [75.03749847, 29.88178062], [75.02348328, 29.87286949], [75.01412964, 29.86462975], [75.00566101, 29.86757088], [74.99411011, 29.86320114], [74.9899292, 29.85646057], [74.96946716, 29.88067055], [74.96988678, 29.88992119], [74.95786285, 29.89773941], [74.94317627, 29.9025383], [74.93566895, 29.9154129], [74.93192291, 29.92277908], [74.9285965, 29.92916107], [74.92408752, 29.94153023], [74.91573334, 29.94915962], [74.89437866, 29.93944168], [74.88523865, 29.9391098], [74.88960266, 29.94501114], [74.89309692, 29.9472599], [74.89435577, 29.95293999], [74.88976288, 29.95903015], [74.88543701, 29.9623394], [74.88149261, 29.96834946], [74.87741089, 29.96256828], [74.87195587, 29.95912933], [74.86566162, 29.95889091], [74.85935974, 29.9611702], [74.84963226, 29.95912933], [74.83660889, 29.96416092], [74.82898712, 29.96947098], [74.82138824, 29.97305107], [74.81968689, 29.97945976], [74.81668091, 29.98451996], [74.80902863, 29.99047089], [74.80117798, 29.99257278], [74.79440308, 29.98961067], [74.78421783, 29.98042107], [74.77599335, 29.97439957], [74.76737213, 29.9727211], [74.75868225, 29.97363091], [74.75071716, 29.97122955], [74.73723602, 29.96904945], [74.72400665, 29.96186066], [74.70613861, 29.96887016], [74.69737244, 29.97114944], [74.69550323, 29.97153091], [74.69078827, 29.96927071], [74.68319702, 29.96107292], [74.68096161, 29.94919014], [74.66570282, 29.94169044], [74.64892578, 29.93092918], [74.63986206, 29.92249107], [74.63886261, 29.91444969], [74.64697266, 29.90467072], [74.63963318, 29.90394974], [74.63263702, 29.90566254], [74.62638855, 29.90600967], [74.62201691, 29.90777969], [74.58580017, 29.91476059], [74.58084869, 29.91830254], [74.57295227, 29.92588806], [74.56183624, 29.92930984], [74.55200195, 29.92922974], [74.54901886, 29.93316269], [74.53024292, 29.94497108], [74.52464294, 29.95156097], [74.51906586, 29.94334984], [74.46660614, 29.94467926], [74.44403839, 29.94672012], [74.44197845, 29.94708824], [74.42807007, 29.94954109], [74.40379333, 29.94734001], [74.37245178, 29.95001984], [74.35585022, 29.95033073], [74.32151031, 29.95396042], [74.2899704, 29.95626068], [74.27902985, 29.95508957]]]}}, {\\\"id\\\": \\\"26\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.29_1\\\", \\\"HASC_1\\\": \\\"IN.RJ\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Rajasthan\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Greater Rajasthan|Rajputana\\\", \\\"apm25_popweighted\\\": -10.7, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1089.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1724.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -635.0, \\\"geo-id\\\": 26, \\\"hpm25_child_popweighted\\\": -213.3, \\\"hpm25_female_popweighted\\\": -245.2, \\\"hpm25_male_popweighted\\\": -176.5, \\\"location\\\": \\\"Rajasthan\\\", \\\"mort_apm25_6cod_mean_total\\\": 24350.0, \\\"mort_hpm25_6cod_mean_total\\\": -40456.0, \\\"mort_tpm25_6cod_mean_total\\\": -16106.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[75.68447876, 23.76056862], [75.67906952, 23.76954842], [75.67605591, 23.78212929], [75.67440796, 23.7844677], [75.6712265, 23.78680038], [75.66747284, 23.78819847], [75.6626358, 23.78816032], [75.65908813, 23.78894043], [75.65680695, 23.7917881], [75.65183258, 23.80194855], [75.64930725, 23.79935074], [75.64367676, 23.80183029], [75.64108276, 23.80225945], [75.63703918, 23.80236053], [75.62594604, 23.80026054], [75.6239624, 23.80051994], [75.61662292, 23.80597115], [75.61213684, 23.80661964], [75.60797882, 23.80550003], [75.60608673, 23.80364037], [75.59168243, 23.80239105], [75.58252716, 23.80035973], [75.58294678, 23.80380058], [75.5848999, 23.80881119], [75.5844574, 23.81402016], [75.58331299, 23.81520844], [75.57279205, 23.81685066], [75.56603241, 23.81568909], [75.56253052, 23.81693077], [75.5585022, 23.82015991], [75.55606079, 23.82593155], [75.556633, 23.83160973], [75.56008148, 23.83685112], [75.56150818, 23.83698082], [75.56931305, 23.8346405], [75.57229614, 23.83483124], [75.57485962, 23.83801079], [75.5761795, 23.84151077], [75.57640076, 23.84329033], [75.57306671, 23.84647942], [75.56720734, 23.84762955], [75.56536865, 23.84986115], [75.56246185, 23.85814285], [75.56062317, 23.85995102], [75.55715942, 23.86279106], [75.55252838, 23.86515808], [75.53787994, 23.87672997], [75.52876282, 23.88026047], [75.51674652, 23.88875008], [75.50734711, 23.89062119], [75.50409698, 23.89191055], [75.49993134, 23.89690971], [75.49957275, 23.90052032], [75.48742676, 23.9108429], [75.47683716, 23.91473961], [75.46089935, 23.91728973], [75.45649719, 23.92074013], [75.45593262, 23.92543983], [75.45636749, 23.93214989], [75.45722961, 23.93818092], [75.46058655, 23.94762039], [75.46170044, 23.95342064], [75.46237946, 23.9681015], [75.46476746, 23.98072815], [75.46720886, 23.9845295], [75.47055817, 23.98719978], [75.48058319, 23.99233055], [75.48597717, 23.99833107], [75.48919678, 24.00031281], [75.49176788, 24.00455093], [75.51438141, 24.04873276], [75.53192139, 24.03148079], [75.54264832, 24.02556038], [75.55264282, 24.0227108], [75.56111908, 24.02357864], [75.56693268, 24.0227108], [75.57171631, 24.01740074], [75.56881714, 24.00461006], [75.568367, 24.00114059], [75.56932068, 23.99937057], [75.57376862, 23.99847984], [75.57596588, 24.00062943], [75.57779694, 23.99962044], [75.58036804, 23.99430275], [75.58383942, 23.99192047], [75.58693695, 23.99563026], [75.59004974, 23.9963398], [75.59262848, 23.9948597], [75.59742737, 23.99864006], [75.60412598, 23.99628067], [75.60678864, 23.99625015], [75.61174774, 23.99876022], [75.62471771, 23.99882126], [75.63051605, 23.99966812], [75.6312027, 24.00031281], [75.63474274, 23.99983025], [75.63846588, 24.00283051], [75.63922119, 24.00463104], [75.64147186, 24.01836967], [75.64591217, 24.01746941], [75.64814758, 24.02073097], [75.64766693, 24.02320099], [75.65313721, 24.02757835], [75.65936279, 24.03149986], [75.66919708, 24.03354263], [75.67269135, 24.03089905], [75.67703247, 24.02011108], [75.68228912, 24.01695251], [75.68580627, 24.01794052], [75.68431091, 24.00463104], [75.68533325, 24.00234985], [75.68354034, 23.99821091], [75.68406677, 23.99311066], [75.68638611, 23.99054909], [75.69065094, 23.98948097], [75.6931076, 23.98921013], [75.69613647, 23.99039078], [75.6964798, 23.98751068], [75.69544983, 23.98590088], [75.69789886, 23.97208023], [75.69845581, 23.97007942], [75.70040894, 23.9690609], [75.71382141, 23.97208023], [75.72331238, 23.97313118], [75.72515869, 23.97451973], [75.72647858, 23.97877121], [75.72776794, 23.9795208], [75.73309326, 23.97892952], [75.73551178, 23.9805603], [75.73626709, 23.9823494], [75.73602295, 23.98475075], [75.73815155, 23.98816109], [75.73738098, 23.99406052], [75.73784637, 23.99533272], [75.74756622, 23.99347115], [75.74957275, 23.99509048], [75.75533295, 23.99492264], [75.76203918, 23.99795151], [75.76431274, 24.00242805], [75.76405334, 24.00458145], [75.76415253, 24.00530052], [75.76008606, 24.00843048], [75.76088715, 24.01291084], [75.76319885, 24.01396751], [75.76782227, 24.0116806], [75.77127075, 24.01221085], [75.77377319, 24.01910973], [75.77778625, 24.02751923], [75.78024292, 24.0362606], [75.77771759, 24.05714035], [75.77961731, 24.06208038], [75.78901672, 24.06329918], [75.80726624, 24.06760025], [75.81334686, 24.07162094], [75.82073975, 24.07060051], [75.82950592, 24.07195282], [75.83376312, 24.07542992], [75.83139038, 24.07712173], [75.83055115, 24.08159065], [75.83267212, 24.09574127], [75.83586121, 24.10400009], [75.83579254, 24.11135101], [75.8306427, 24.10792923], [75.81218719, 24.10287094], [75.80834961, 24.11335945], [75.80239868, 24.11833], [75.78961182, 24.10980034], [75.78478241, 24.11834908], [75.78317261, 24.12268066], [75.77902985, 24.12462044], [75.77868652, 24.13467026], [75.77629852, 24.13896179], [75.77316284, 24.13944244], [75.7651062, 24.13663101], [75.76213837, 24.14101028], [75.75942993, 24.14035034], [75.74349213, 24.13960075], [75.75065613, 24.1616497], [75.75331879, 24.16434097], [75.75827789, 24.17455292], [75.75891113, 24.17961121], [75.76365662, 24.18978119], [75.76862335, 24.19330025], [75.76967621, 24.19774055], [75.76782227, 24.20754814], [75.77350616, 24.22089195], [75.77883911, 24.2244091], [75.79189301, 24.22324181], [75.79534912, 24.22686958], [75.79953003, 24.22923088], [75.805336, 24.22971916], [75.80776215, 24.24067116], [75.81060791, 24.2419796], [75.81424713, 24.23959923], [75.81659698, 24.24194908], [75.82129669, 24.24102974], [75.82636261, 24.24257088], [75.82688141, 24.24641037], [75.82250977, 24.24733925], [75.81806183, 24.24995995], [75.81269073, 24.25688171], [75.81253052, 24.26065063], [75.81852722, 24.26822281], [75.81178284, 24.27042961], [75.81289673, 24.27709007], [75.81143188, 24.28472137], [75.81682587, 24.2907505], [75.81095123, 24.29804039], [75.81299591, 24.30067825], [75.811203, 24.30344963], [75.8030014, 24.31233025], [75.79741669, 24.31434822], [75.79001617, 24.3110981], [75.78103638, 24.30863953], [75.77085114, 24.30877113], [75.76509094, 24.31065941], [75.7562561, 24.32722282], [75.73792267, 24.34797096], [75.74051666, 24.34974289], [75.74180603, 24.35296822], [75.74178314, 24.36107254], [75.73869324, 24.36125755], [75.73829651, 24.36618996], [75.73957825, 24.38893127], [75.73857117, 24.39529991], [75.7353363, 24.39439964], [75.72968292, 24.38949966], [75.72688293, 24.40527916], [75.728302, 24.40749168], [75.72979736, 24.40360832], [75.73581696, 24.40343285], [75.7432785, 24.40501022], [75.74500275, 24.4070797], [75.75527954, 24.40930939], [75.75583649, 24.42105293], [75.75640869, 24.42766953], [75.74872589, 24.42840958], [75.75241852, 24.43157005], [75.76824188, 24.44034958], [75.77567291, 24.44826126], [75.77617645, 24.45388031], [75.78128052, 24.45391083], [75.78357697, 24.45182991], [75.78575134, 24.45508957], [75.78608704, 24.4584198], [75.78409576, 24.46473122], [75.78675842, 24.47183037], [75.79113007, 24.47520256], [75.79564667, 24.47312164], [75.80502319, 24.47277069], [75.81510925, 24.46511269], [75.81646729, 24.45852089], [75.81417084, 24.4480896], [75.80964661, 24.44123077], [75.81254578, 24.43678093], [75.8241272, 24.43078995], [75.82900238, 24.42251968], [75.84725189, 24.41897011], [75.86120605, 24.42333031], [75.87522888, 24.43028069], [75.88648987, 24.4369297], [75.89862061, 24.44159126], [75.90338898, 24.44613075], [75.90335083, 24.45393944], [75.90899658, 24.45614052], [75.90943909, 24.46363068], [75.9072876, 24.46951103], [75.90811157, 24.47813034], [75.9124527, 24.48558044], [75.91181946, 24.4924202], [75.90674591, 24.49804115], [75.9054718, 24.50530815], [75.89105225, 24.50958824], [75.89256287, 24.52153015], [75.89694977, 24.52226067], [75.90216064, 24.52202034], [75.90289307, 24.51972008], [75.90934753, 24.51488113], [75.92204285, 24.52728081], [75.9250412, 24.53339958], [75.92501831, 24.53829956], [75.92051697, 24.54380989], [75.91671753, 24.54668808], [75.90703583, 24.55046082], [75.90661621, 24.55220032], [75.90570831, 24.56059265], [75.90782166, 24.56536293], [75.90956116, 24.56450844], [75.91320801, 24.56529045], [75.91584778, 24.56736946], [75.91739655, 24.5714798], [75.91512299, 24.57459068], [75.91107178, 24.57705116], [75.90287018, 24.57681084], [75.89771271, 24.58045006], [75.89372253, 24.58167076], [75.88436127, 24.58173943], [75.87581635, 24.59078026], [75.8766861, 24.59964943], [75.87407684, 24.60711098], [75.86566162, 24.60733986], [75.86345673, 24.61292076], [75.85254669, 24.61432076], [75.84816742, 24.61116028], [75.84501648, 24.6103611], [75.84233093, 24.60024261], [75.83835602, 24.59568977], [75.83544159, 24.59756279], [75.83920288, 24.60874939], [75.82814789, 24.61334991], [75.83036041, 24.61995125], [75.83428955, 24.62375069], [75.83812714, 24.62360191], [75.84287262, 24.62611961], [75.84620667, 24.63140106], [75.84411621, 24.63472176], [75.84393311, 24.63927078], [75.84880829, 24.65306091], [75.84864807, 24.66455078], [75.84390259, 24.66934967], [75.83706665, 24.66999817], [75.82818604, 24.66822243], [75.82714081, 24.67150116], [75.83154297, 24.67974091], [75.83368683, 24.68595123], [75.84202576, 24.71746063], [75.83875275, 24.72986984], [75.82781219, 24.73635292], [75.80545807, 24.75626945], [75.78618622, 24.76552963], [75.78064728, 24.76316071], [75.77259827, 24.76204109], [75.7596817, 24.76479912], [75.74180603, 24.76036072], [75.73075867, 24.75555038], [75.72306824, 24.7501297], [75.71177673, 24.74542999], [75.68004608, 24.72783089], [75.65918732, 24.70170021], [75.63400269, 24.69115067], [75.61332703, 24.68842125], [75.60943604, 24.6899929], [75.6026001, 24.70127106], [75.58190155, 24.72270012], [75.56899261, 24.71990013], [75.55210114, 24.71376991], [75.54854584, 24.71556091], [75.54122162, 24.71669006], [75.53507996, 24.72001839], [75.52748108, 24.71791077], [75.505867, 24.70942116], [75.4834671, 24.69762039], [75.45189667, 24.69321823], [75.43753815, 24.69552994], [75.41970062, 24.69996071], [75.3964386, 24.70455933], [75.37814331, 24.7063694], [75.36389923, 24.70951843], [75.35086823, 24.71710014], [75.30436707, 24.72074127], [75.2858429, 24.72590065], [75.26724243, 24.73271942], [75.26200104, 24.73306084], [75.24954224, 24.72914124], [75.24246979, 24.73048019], [75.22840881, 24.7351017], [75.22406006, 24.73546028], [75.22141266, 24.73345947], [75.21936798, 24.72305107], [75.21694946, 24.7224102], [75.20191193, 24.74614143], [75.19818878, 24.75690079], [75.19561768, 24.76000977], [75.1868515, 24.76032066], [75.18559265, 24.76304054], [75.18551636, 24.76805115], [75.18768311, 24.77007294], [75.18950653, 24.77464104], [75.19229889, 24.78874969], [75.19532776, 24.789711], [75.20271301, 24.78880119], [75.20358276, 24.79247093], [75.20269775, 24.79628754], [75.2035675, 24.80168915], [75.2064209, 24.8099308], [75.21737671, 24.82046127], [75.22247314, 24.81896019], [75.23661041, 24.82024002], [75.24134064, 24.8194294], [75.24671173, 24.82184029], [75.2494812, 24.82639122], [75.25154877, 24.83221817], [75.25192261, 24.83716965], [75.24968719, 24.84081078], [75.24616241, 24.84416962], [75.24104309, 24.84686089], [75.23378754, 24.84662056], [75.22773743, 24.84775925], [75.22550201, 24.85103989], [75.22601318, 24.85485077], [75.22170258, 24.85819054], [75.21848297, 24.8594799], [75.21038055, 24.87142944], [75.20670319, 24.8791008], [75.20131683, 24.88420105], [75.20288086, 24.88809967], [75.20609283, 24.8916111], [75.20820618, 24.89775085], [75.20742798, 24.90464973], [75.20819092, 24.90999985], [75.21264648, 24.91007042], [75.21920013, 24.90648842], [75.22135162, 24.90279961], [75.21969604, 24.89220047], [75.22341919, 24.89002991], [75.23059845, 24.89442062], [75.23612976, 24.89929962], [75.24124146, 24.90263176], [75.24437714, 24.90204048], [75.24774933, 24.8999176], [75.24994659, 24.89569092], [75.24797058, 24.88088989], [75.23667145, 24.87088966], [75.22738647, 24.85914993], [75.22953033, 24.857481], [75.23406982, 24.8583107], [75.24169159, 24.86094093], [75.24769592, 24.85950851], [75.25234985, 24.85950851], [75.25979614, 24.85752106], [75.27121735, 24.85635948], [75.27893829, 24.85349083], [75.28382111, 24.85001945], [75.29042053, 24.84091949], [75.29421997, 24.83037949], [75.29769897, 24.82637024], [75.29841614, 24.81990814], [75.30049133, 24.81524277], [75.30573273, 24.8133297], [75.31301117, 24.81353951], [75.31981659, 24.81779289], [75.32361603, 24.82396126], [75.33023071, 24.83172989], [75.33744049, 24.83370972], [75.34407806, 24.83279037], [75.35505676, 24.83743095], [75.36396027, 24.84252167], [75.39965057, 24.8549099], [75.4105072, 24.86123848], [75.417099, 24.86390114], [75.4172821, 24.86861038], [75.42063141, 24.87733078], [75.42059326, 24.88163185], [75.42421722, 24.89275169], [75.41416931, 24.89300919], [75.40753937, 24.89191055], [75.3986969, 24.88834953], [75.37197113, 24.87798119], [75.35006714, 24.88496971], [75.33534241, 24.88667107], [75.32596588, 24.88700867], [75.32124329, 24.88266182], [75.31765747, 24.87515068], [75.31130219, 24.86945915], [75.29904938, 24.87026024], [75.29411316, 24.87137985], [75.28807831, 24.87968063], [75.27928162, 24.88455009], [75.27265167, 24.88693047], [75.26508331, 24.88817024], [75.26145172, 24.88965988], [75.25965881, 24.89982033], [75.26077271, 24.90534019], [75.26425171, 24.90731049], [75.26702881, 24.91421127], [75.27171326, 24.91786957], [75.274086, 24.9170475], [75.27485657, 24.91432953], [75.27796936, 24.91308022], [75.27867889, 24.91749191], [75.28237152, 24.92254066], [75.28482819, 24.92280006], [75.28793335, 24.92053032], [75.29190063, 24.92091751], [75.29308319, 24.92317963], [75.29116821, 24.92496109], [75.28790283, 24.9262619], [75.28488159, 24.93712044], [75.27580261, 24.94027138], [75.27722168, 24.94790077], [75.27165222, 24.94942093], [75.26999664, 24.95627022], [75.26631165, 24.96191978], [75.26844788, 24.9655304], [75.271492, 24.96821976], [75.27590179, 24.97673035], [75.28536224, 24.97669029], [75.28556061, 24.96412277], [75.28814697, 24.96263123], [75.28778076, 24.95963287], [75.28980255, 24.95611191], [75.29045868, 24.95202065], [75.29429626, 24.94870949], [75.30018616, 24.94682121], [75.30267334, 24.94316101], [75.30351257, 24.94017982], [75.30229187, 24.9348793], [75.30316162, 24.93061256], [75.30610657, 24.92897987], [75.30832672, 24.92629051], [75.31217194, 24.91106033], [75.31210327, 24.8999176], [75.31387329, 24.90044022], [75.31754303, 24.90722084], [75.32540894, 24.93809128], [75.32875061, 24.94563103], [75.33426666, 24.95061111], [75.33748627, 24.96310043], [75.33541107, 24.96471024], [75.3337326, 24.9674511], [75.33127594, 24.9760704], [75.32636261, 24.97616005], [75.32312012, 24.98224068], [75.32208252, 24.98961258], [75.32203674, 24.99612999], [75.32311249, 25.00090981], [75.31894684, 25.00650978], [75.32248688, 25.01338959], [75.32949066, 25.01762962], [75.3431015, 25.02230072], [75.35061646, 25.0248394], [75.35154724, 25.02515984], [75.35362244, 25.02873039], [75.35005188, 25.03327179], [75.35424042, 25.03737068], [75.349617, 25.04173088], [75.34558868, 25.0428009], [75.33615875, 25.04488945], [75.32266998, 25.0442524], [75.31048584, 25.04607964], [75.30016327, 25.0440197], [75.29255676, 25.04288292], [75.27826691, 25.04470062], [75.26597595, 25.04306984], [75.25562286, 25.04004288], [75.24459076, 25.03993034], [75.2375412, 25.04191971], [75.2270813, 25.03853035], [75.21821594, 25.04144096], [75.20548248, 25.0424099], [75.20355225, 25.0388298], [75.20056152, 25.03449821], [75.19509125, 25.03751945], [75.19441986, 25.03770065], [75.1917572, 25.03836823], [75.18531036, 25.04253006], [75.18209076, 25.04758072], [75.17378235, 25.05379295], [75.16696167, 25.0442009], [75.15912628, 25.04547119], [75.15628052, 25.03544044], [75.15470886, 25.02886963], [75.15921021, 25.02407074], [75.16525269, 25.02231979], [75.16860199, 25.01319122], [75.16924286, 25.00996971], [75.16676331, 25.00610924], [75.16439819, 24.99166107], [75.16256714, 24.99170113], [75.16131592, 24.99008942], [75.1608963, 24.98761177], [75.15215302, 24.98868942], [75.14582825, 24.98643112], [75.14385986, 24.98705292], [75.14037323, 24.98713112], [75.13802338, 24.98636246], [75.13432312, 24.98266029], [75.14775848, 24.98163986], [75.149086, 24.98122025], [75.14685059, 24.97957993], [75.13656616, 24.97874069], [75.13471985, 24.97772026], [75.13352966, 24.97524261], [75.11982727, 24.97575951], [75.1190567, 24.97475243], [75.1157074, 24.96539116], [75.11534882, 24.96112823], [75.11569214, 24.95364952], [75.11772919, 24.94634056], [75.11942291, 24.91814041], [75.11493683, 24.91184044], [75.1177063, 24.9051609], [75.11943054, 24.89583015], [75.11886597, 24.88903999], [75.1149826, 24.88713837], [75.09011078, 24.87973022], [75.08834076, 24.8810997], [75.0870285, 24.88347054], [75.0866394, 24.88657951], [75.08532715, 24.88889122], [75.08167267, 24.88913918], [75.07685089, 24.88883972], [75.0735321, 24.88731003], [75.06620026, 24.87839127], [75.0631485, 24.87746811], [75.0592804, 24.88129997], [75.05634308, 24.88194084], [75.05626678, 24.88091087], [75.05877686, 24.87771034], [75.0598526, 24.87473106], [75.05713654, 24.87105179], [75.05108643, 24.86488914], [75.04338837, 24.85922813], [75.03411102, 24.85860062], [75.02974701, 24.86054039], [75.0229187, 24.86561966], [75.0194931, 24.86693001], [75.01508331, 24.87020111], [75.01261139, 24.87408066], [74.99767303, 24.8766098], [74.99104309, 24.87500191], [74.98751068, 24.87597275], [74.98416901, 24.87763023], [74.97733307, 24.87747955], [74.97173309, 24.8753891], [74.96353912, 24.87408066], [74.95633698, 24.87495995], [74.94883728, 24.87812042], [74.94480896, 24.87791061], [74.95043182, 24.88997078], [74.95020294, 24.89295006], [74.9487381, 24.89480019], [74.9462204, 24.8939209], [74.93969727, 24.8934803], [74.93547058, 24.8952198], [74.9307785, 24.89397049], [74.92951202, 24.88788986], [74.92695618, 24.89036942], [74.92368317, 24.89207077], [74.92008209, 24.89184952], [74.91951752, 24.8948307], [74.91615295, 24.89944077], [74.91252136, 24.89909935], [74.90688324, 24.90715981], [74.91174316, 24.91887283], [74.91100311, 24.92328072], [74.91293335, 24.9283886], [74.90735626, 24.92867088], [74.90428925, 24.93011093], [74.90265656, 24.93468094], [74.90260315, 24.93727112], [74.90054321, 24.93974113], [74.8899231, 24.94145012], [74.88469696, 24.94976044], [74.87911987, 24.9487896], [74.87728119, 24.93939018], [74.87085724, 24.93720055], [74.86720276, 24.93694115], [74.86572266, 24.94326973], [74.86387634, 24.9475708], [74.86351776, 24.95729065], [74.86203766, 24.96282959], [74.86209869, 24.96583939], [74.85320282, 24.97472], [74.84635162, 24.97429085], [74.83271027, 24.9674511], [74.83061218, 24.96191025], [74.83114624, 24.95730972], [74.82627106, 24.95220947], [74.82498932, 24.94589043], [74.82534027, 24.94045067], [74.82421875, 24.94009972], [74.8236084, 24.92850113], [74.82411194, 24.91481018], [74.82713318, 24.89912987], [74.83161926, 24.89892006], [74.83512115, 24.89703941], [74.83783722, 24.89721107], [74.8394165, 24.89286995], [74.84015656, 24.88055038], [74.84237671, 24.87496948], [74.84565735, 24.87210274], [74.8529129, 24.86033058], [74.85588837, 24.85320091], [74.85604858, 24.84716988], [74.85748291, 24.8429985], [74.85903168, 24.82901001], [74.85903931, 24.82015991], [74.85746002, 24.81784821], [74.85296631, 24.81553078], [74.84597778, 24.81484032], [74.83751678, 24.80846024], [74.84078217, 24.80341911], [74.84889221, 24.79265976], [74.85144806, 24.79265976], [74.85794067, 24.79462051], [74.85946655, 24.7995491], [74.85856628, 24.81306076], [74.86785126, 24.81311989], [74.87023163, 24.81205177], [74.87805176, 24.81318092], [74.88014984, 24.8105011], [74.88053894, 24.80796814], [74.8846817, 24.80243111], [74.89195251, 24.79911041], [74.89743805, 24.79920959], [74.90518188, 24.79746056], [74.90997314, 24.78821945], [74.91694641, 24.78718185], [74.92207336, 24.7884407], [74.92941284, 24.79548264], [74.93855286, 24.79479027], [74.94595337, 24.79171944], [74.95542145, 24.79244041], [74.96157837, 24.79117012], [74.97038269, 24.79086113], [74.99001312, 24.79381943], [74.99832916, 24.79771042], [75.00705719, 24.79606056], [75.01293182, 24.79380989], [75.01629639, 24.78594971], [75.01795959, 24.7807312], [75.02005005, 24.7744503], [75.02137756, 24.77285957], [75.02133942, 24.77026939], [75.02131653, 24.76716042], [75.02023315, 24.75276756], [74.9970932, 24.75420952], [74.99343109, 24.75272942], [74.99202728, 24.74381065], [74.99075317, 24.73376846], [74.99211884, 24.72826195], [74.99521637, 24.71614075], [74.99664307, 24.71599007], [74.99941254, 24.71379089], [75.00035095, 24.71056938], [74.99989319, 24.70848846], [74.99655914, 24.70684242], [74.99371338, 24.70578957], [74.99043274, 24.70634842], [74.96411133, 24.70046806], [74.96216583, 24.7008419], [74.96485901, 24.69454193], [74.9598999, 24.68875122], [74.95990753, 24.68671989], [74.96102905, 24.68609047], [74.96182251, 24.68370056], [74.96198273, 24.67958069], [74.96116638, 24.67889023], [74.95923615, 24.67990112], [74.95728302, 24.68268967], [74.95197296, 24.67646027], [74.95265961, 24.67385101], [74.95202637, 24.67031288], [74.94300842, 24.66889763], [74.94181824, 24.66682053], [74.94387817, 24.66228294], [74.94285583, 24.66039085], [74.93917847, 24.66171074], [74.93718719, 24.66015053], [74.93476105, 24.66184807], [74.92945099, 24.65917015], [74.91986847, 24.65842056], [74.91478729, 24.65942001], [74.91300964, 24.66041183], [74.90965271, 24.66043091], [74.90854645, 24.66157913], [74.90563965, 24.66033936], [74.90246582, 24.65631104], [74.89700317, 24.66555977], [74.8935318, 24.66385841], [74.8935318, 24.66098022], [74.89450836, 24.65814972], [74.89285278, 24.65534973], [74.88791656, 24.65772247], [74.88018036, 24.66801071], [74.87767029, 24.66578102], [74.87502289, 24.66748047], [74.87343597, 24.66948128], [74.87268829, 24.67592049], [74.86975861, 24.67878914], [74.86691284, 24.69052124], [74.86521149, 24.69207001], [74.86245728, 24.69234276], [74.85983276, 24.69388962], [74.85853577, 24.70218086], [74.85636139, 24.70517921], [74.85396576, 24.70412064], [74.85531616, 24.69922066], [74.85431671, 24.69671059], [74.85182953, 24.69659042], [74.84984589, 24.69865036], [74.84970856, 24.70633125], [74.84884644, 24.70872116], [74.83487701, 24.73200035], [74.8292923, 24.74590111], [74.81854248, 24.76534081], [74.81495667, 24.78145027], [74.80980682, 24.79640007], [74.79931641, 24.79564095], [74.79847717, 24.7905407], [74.80114746, 24.78668976], [74.80191803, 24.76654053], [74.80314636, 24.75485229], [74.79978943, 24.75171089], [74.79254913, 24.7501812], [74.78607941, 24.74691963], [74.78005219, 24.74274826], [74.78137207, 24.74085045], [74.78386688, 24.73035049], [74.78837585, 24.72803116], [74.78965759, 24.72663116], [74.78753662, 24.72192955], [74.78315735, 24.71821976], [74.7844162, 24.71264076], [74.78385925, 24.7095108], [74.78089142, 24.70508957], [74.77964783, 24.70066071], [74.77731323, 24.69668961], [74.77786255, 24.69321823], [74.77527618, 24.68773079], [74.77606201, 24.68605995], [74.7857132, 24.67994118], [74.78946686, 24.67893982], [74.79197693, 24.68157959], [74.79234314, 24.68432045], [74.80966949, 24.68653107], [74.81333923, 24.6861496], [74.81775665, 24.6799202], [74.81774902, 24.6764698], [74.81710815, 24.67167091], [74.81482697, 24.66977119], [74.81137848, 24.6716404], [74.80873871, 24.66996193], [74.8049469, 24.65956116], [74.80237579, 24.65691948], [74.79934692, 24.65657043], [74.79493713, 24.65470123], [74.79302216, 24.65155983], [74.79350281, 24.64944077], [74.79138947, 24.64542961], [74.78344727, 24.63676071], [74.78483582, 24.62928963], [74.78781891, 24.62078094], [74.7873764, 24.61759186], [74.79055023, 24.61740112], [74.79012299, 24.61075974], [74.78633118, 24.61010933], [74.78176117, 24.6071701], [74.77723694, 24.60539055], [74.77065277, 24.60584259], [74.76017761, 24.60139084], [74.75595093, 24.6006794], [74.74797058, 24.59680939], [74.74668884, 24.59299278], [74.75031281, 24.58866119], [74.75154114, 24.58611107], [74.75377655, 24.57838058], [74.75547791, 24.57098961], [74.7569809, 24.56365013], [74.75634766, 24.55989075], [74.75746155, 24.55681992], [74.75675201, 24.55462074], [74.75234222, 24.55237007], [74.74854279, 24.5517292], [74.74759674, 24.5476799], [74.74961853, 24.5425396], [74.74771118, 24.53623962], [74.7285614, 24.53479004], [74.72342682, 24.53115082], [74.71570587, 24.52283096], [74.71193695, 24.51094055], [74.71290588, 24.50922012], [74.71555328, 24.50823975], [74.72370911, 24.51040077], [74.72718811, 24.5107708], [74.73082733, 24.51003075], [74.73504639, 24.50362015], [74.75065613, 24.49200058], [74.75731659, 24.48882294], [74.76081848, 24.48857117], [74.7661972, 24.49065018], [74.77330017, 24.48509979], [74.77899933, 24.48338127], [74.78153229, 24.48486137], [74.78495789, 24.48989105], [74.79187775, 24.49327087], [74.79595184, 24.49324989], [74.801651, 24.49208069], [74.80800629, 24.49304008], [74.81083679, 24.49200058], [74.81450653, 24.49221039], [74.81684113, 24.49117088], [74.82238007, 24.4878006], [74.82419586, 24.48354912], [74.8246994, 24.47923088], [74.82010651, 24.47290039], [74.81826782, 24.4619503], [74.83378601, 24.46042061], [74.8365097, 24.46539116], [74.84085083, 24.46722031], [74.84455109, 24.46590996], [74.8493576, 24.46664047], [74.85066986, 24.4688282], [74.85411072, 24.47020912], [74.85813141, 24.46733284], [74.85695648, 24.46327972], [74.85817719, 24.4555397], [74.85749817, 24.45150185], [74.85389709, 24.44950294], [74.8477478, 24.44355965], [74.84586334, 24.44073105], [74.8351593, 24.42951965], [74.82701111, 24.42360115], [74.82723236, 24.41680908], [74.82639313, 24.41069031], [74.82524109, 24.40833282], [74.81479645, 24.41069031], [74.81231689, 24.40915108], [74.80541229, 24.39545059], [74.80227661, 24.38734055], [74.79833221, 24.384161], [74.79315948, 24.37614059], [74.78835297, 24.37177086], [74.7869873, 24.3716507], [74.78462219, 24.36736107], [74.78167725, 24.35835075], [74.78276062, 24.35466003], [74.78621674, 24.34880066], [74.78633881, 24.34386063], [74.78379059, 24.33609962], [74.78317261, 24.3194294], [74.78482056, 24.32113075], [74.78363037, 24.31680107], [74.7670517, 24.30446053], [74.75746155, 24.29622078], [74.75302124, 24.28939056], [74.75280762, 24.28265953], [74.75479126, 24.27897072], [74.76647949, 24.27342033], [74.77253723, 24.27198029], [74.77968597, 24.27260971], [74.79029846, 24.27187157], [74.81516266, 24.27700996], [74.81964874, 24.27626038], [74.82578278, 24.27330017], [74.83264923, 24.27157021], [74.83891296, 24.27123833], [74.84390259, 24.27016068], [74.85331726, 24.26997948], [74.85659027, 24.27219963], [74.85975647, 24.27299118], [74.86255646, 24.27370071], [74.86403656, 24.27396011], [74.86972046, 24.28070831], [74.87542725, 24.27802086], [74.88530731, 24.2687397], [74.88905334, 24.26684952], [74.89428711, 24.2616806], [74.89700317, 24.24917984], [74.90405273, 24.24587822], [74.90544128, 24.24530983], [74.90725708, 24.24081039], [74.90585327, 24.23372078], [74.90271759, 24.23101044], [74.89821625, 24.22907066], [74.88970947, 24.22689056], [74.88671112, 24.22492027], [74.88017273, 24.21648026], [74.8811264, 24.21350288], [74.89729309, 24.18704033], [74.8976593, 24.18237114], [74.89948273, 24.17844009], [74.90033722, 24.17430115], [74.9201889, 24.16284752], [74.92146301, 24.16024971], [74.92751312, 24.15715027], [74.92350769, 24.14928055], [74.92469025, 24.14523125], [74.93665314, 24.13898087], [74.9389801, 24.12788963], [74.93618011, 24.12376976], [74.93914032, 24.12111092], [74.95487213, 24.11203957], [74.95951843, 24.11009026], [74.96089172, 24.10550117], [74.96074677, 24.09416008], [74.96186066, 24.08963013], [74.96517181, 24.08272171], [74.97155762, 24.07785988], [74.97625732, 24.07600975], [74.97940826, 24.07201195], [74.98121643, 24.04104042], [74.99038696, 24.03343964], [74.99298859, 24.02970123], [74.99236298, 24.02323151], [74.98779297, 24.01433182], [74.97981262, 24.00989914], [74.972229, 24.00362968], [74.97292328, 23.99105263], [74.96869659, 23.97973061], [74.96334839, 23.97367096], [74.94145966, 23.96051979], [74.93760681, 23.95608139], [74.93151855, 23.94681931], [74.93112183, 23.94491005], [74.92984772, 23.94096184], [74.92431641, 23.93861008], [74.92131042, 23.93571281], [74.92360687, 23.92926979], [74.92337799, 23.92490959], [74.91742706, 23.91757011], [74.91461945, 23.91246986], [74.91385651, 23.90336037], [74.91049957, 23.88850975], [74.90724182, 23.87675095], [74.9056778, 23.8739109], [74.90518951, 23.86811066], [74.90688324, 23.85638046], [74.91024017, 23.85213089], [74.91313934, 23.84986115], [74.91581726, 23.8456707], [74.91326141, 23.83662987], [74.91191864, 23.81261063], [74.91033936, 23.80084038], [74.91500854, 23.79918861], [74.92761993, 23.79833031], [74.92993164, 23.79420853], [74.93785095, 23.77671051], [74.93947601, 23.77067184], [74.93992615, 23.76585007], [74.93187714, 23.75811005], [74.93192291, 23.75641823], [74.93810272, 23.74287987], [74.94056702, 23.73487091], [74.93199158, 23.72834015], [74.92424011, 23.71915054], [74.92289734, 23.71386909], [74.92304993, 23.69658089], [74.91745758, 23.6921196], [74.91043854, 23.68798065], [74.90762329, 23.68283081], [74.90991211, 23.67690086], [74.92421722, 23.6685009], [74.92838287, 23.6531601], [74.93061066, 23.64821815], [74.9389801, 23.64318848], [74.94034576, 23.63692284], [74.93972015, 23.63037109], [74.92787933, 23.62438011], [74.92193604, 23.62231064], [74.90956879, 23.62416077], [74.90602875, 23.62295151], [74.89803314, 23.61218262], [74.88609314, 23.60642815], [74.8849411, 23.60330963], [74.87937927, 23.59596062], [74.87732697, 23.59439087], [74.87457275, 23.59011078], [74.87502289, 23.5835495], [74.87265015, 23.57822037], [74.86933136, 23.57479858], [74.86171722, 23.57234001], [74.8589859, 23.56949997], [74.85147858, 23.55739975], [74.84542084, 23.55417061], [74.83757782, 23.55321121], [74.83009338, 23.54952049], [74.81923676, 23.54079819], [74.81575775, 23.53961945], [74.81230927, 23.53843117], [74.80288696, 23.5340519], [74.79875946, 23.54043961], [74.79633331, 23.54626083], [74.792099, 23.5486412], [74.78501129, 23.54803085], [74.77406311, 23.54330254], [74.77072906, 23.53577042], [74.7639389, 23.52471161], [74.75707245, 23.52217293], [74.74237061, 23.51947975], [74.73777771, 23.50678062], [74.73365784, 23.50052071], [74.72589111, 23.49846077], [74.71877289, 23.50358009], [74.71089935, 23.50563049], [74.70066071, 23.50368118], [74.68740845, 23.49580956], [74.68776703, 23.49220085], [74.68371582, 23.48658943], [74.68093872, 23.48509026], [74.67446136, 23.48568153], [74.66932678, 23.48389244], [74.66409302, 23.47334099], [74.65894318, 23.46680069], [74.65473175, 23.46442032], [74.65223694, 23.46339035], [74.63642883, 23.46406174], [74.62699127, 23.46198082], [74.61338043, 23.46136093], [74.61312103, 23.45155144], [74.59845734, 23.42975998], [74.59146881, 23.42513084], [74.57966614, 23.4224205], [74.57402039, 23.42254257], [74.57314301, 23.41924286], [74.57241058, 23.38332939], [74.57071686, 23.3777504], [74.56521606, 23.37522125], [74.56022644, 23.36449051], [74.55580902, 23.36297989], [74.54582977, 23.36379814], [74.5437088, 23.35898972], [74.54271698, 23.3386898], [74.53839874, 23.33399963], [74.52028656, 23.33169174], [74.51830292, 23.32872963], [74.51924896, 23.32193756], [74.52085114, 23.32160187], [74.53032684, 23.32414055], [74.53366089, 23.32303047], [74.53450775, 23.32036972], [74.53421021, 23.31398964], [74.53568268, 23.30952263], [74.54062653, 23.30511284], [74.54390717, 23.30005264], [74.54856873, 23.28676033], [74.5534668, 23.28252029], [74.55822754, 23.28531075], [74.56210327, 23.29208946], [74.56735229, 23.29846191], [74.5719223, 23.30089188], [74.57728577, 23.29734993], [74.58676147, 23.28446007], [74.592659, 23.28358078], [74.59905243, 23.28363037], [74.60669708, 23.28536034], [74.61530304, 23.28460121], [74.62229156, 23.28133965], [74.6265564, 23.27599907], [74.62956238, 23.26584053], [74.63214111, 23.26340103], [74.64624786, 23.25971985], [74.65222168, 23.26081276], [74.66649628, 23.27111053], [74.67312622, 23.27486992], [74.68048859, 23.27526283], [74.70114899, 23.27214241], [74.70162201, 23.26675034], [74.70334625, 23.26164246], [74.71026611, 23.25814056], [74.71489716, 23.25296021], [74.71853638, 23.24600983], [74.72215271, 23.24251175], [74.71324921, 23.2363205], [74.70381165, 23.23315048], [74.69554138, 23.22859001], [74.69500732, 23.22307968], [74.69960785, 23.22034073], [74.7026062, 23.21970177], [74.712883, 23.22135925], [74.71895599, 23.21943283], [74.72431946, 23.22011948], [74.7329483, 23.22375107], [74.73995972, 23.22863007], [74.74053955, 23.22904015], [74.74098206, 23.2293396], [74.7457962, 23.23270988], [74.75083923, 23.23038101], [74.74603271, 23.21536064], [74.74569702, 23.21211052], [74.73477936, 23.20639992], [74.721138, 23.19697952], [74.71552277, 23.19466972], [74.68756866, 23.19670105], [74.66915894, 23.2014904], [74.66532135, 23.19824982], [74.65983582, 23.18789101], [74.65474701, 23.18202972], [74.64198303, 23.17266273], [74.62567902, 23.16294098], [74.61782837, 23.15193176], [74.61415863, 23.14833069], [74.60806274, 23.14482117], [74.59723663, 23.14199257], [74.58863068, 23.14146996], [74.58007812, 23.13997078], [74.57363129, 23.1371994], [74.56604004, 23.13523293], [74.54570007, 23.13207054], [74.54751587, 23.11849022], [74.54650116, 23.11280823], [74.54265594, 23.10690117], [74.53543854, 23.10151291], [74.52327728, 23.09891129], [74.51360321, 23.09590149], [74.51228333, 23.08883095], [74.49140167, 23.08838272], [74.46724701, 23.08525848], [74.45823669, 23.08706093], [74.4454422, 23.09293175], [74.4393158, 23.09807968], [74.4331665, 23.10568047], [74.42610168, 23.10602951], [74.41884613, 23.10847092], [74.41409302, 23.11096191], [74.40683746, 23.11177063], [74.39118958, 23.11199951], [74.38767242, 23.11044121], [74.36696625, 23.09552002], [74.36112213, 23.09031105], [74.35954285, 23.08049965], [74.35510254, 23.07580185], [74.3478775, 23.07080078], [74.33927917, 23.06697083], [74.32277679, 23.06269073], [74.31829071, 23.06725121], [74.31552124, 23.07212067], [74.31017303, 23.07954025], [74.30391693, 23.08389282], [74.28678131, 23.0916996], [74.28253937, 23.09501266], [74.28077698, 23.10098076], [74.2820282, 23.10643005], [74.28814697, 23.11873055], [74.28491211, 23.12458038], [74.27954102, 23.12997055], [74.27762604, 23.13397026], [74.27661896, 23.13977242], [74.2718277, 23.15600967], [74.26706696, 23.16596985], [74.26185608, 23.17160034], [74.25701904, 23.17472076], [74.25242615, 23.17616844], [74.24977875, 23.17843056], [74.24603271, 23.18825912], [74.2370224, 23.18270111], [74.2293396, 23.184021], [74.20754242, 23.19205093], [74.2041626, 23.18909073], [74.20008087, 23.18374062], [74.19412231, 23.17856026], [74.18953705, 23.17184067], [74.18914795, 23.15790939], [74.18660736, 23.15252113], [74.18299103, 23.15221977], [74.16493988, 23.15648079], [74.16069031, 23.15554047], [74.15516663, 23.15775108], [74.14845276, 23.17205048], [74.14569092, 23.17523003], [74.13617706, 23.17770958], [74.13051605, 23.17764282], [74.12702179, 23.17885017], [74.1244812, 23.18799973], [74.12452698, 23.19044113], [74.12252045, 23.19157028], [74.12349701, 23.20170021], [74.12470245, 23.20656967], [74.13391113, 23.21517944], [74.13510132, 23.22006989], [74.13948059, 23.2268219], [74.13865662, 23.23092079], [74.1388092, 23.23637962], [74.13652039, 23.24480057], [74.1361084, 23.26472092], [74.13378143, 23.26945114], [74.12989044, 23.27272034], [74.11856079, 23.27536964], [74.11387634, 23.27734947], [74.11106873, 23.28572083], [74.10658264, 23.2941227], [74.10166168, 23.29574966], [74.08973694, 23.29799271], [74.07652283, 23.29819107], [74.04873657, 23.29506111], [74.04447174, 23.29609108], [74.04968262, 23.30709076], [74.04769897, 23.31093979], [74.04138184, 23.30700111], [74.03759766, 23.30574036], [74.03592682, 23.31261063], [74.03006744, 23.31994057], [74.03266144, 23.33234978], [74.02361298, 23.33288193], [74.00380707, 23.33620071], [73.99077606, 23.33762932], [73.98696899, 23.34123993], [73.98446655, 23.34945107], [73.98348999, 23.35984039], [73.97889709, 23.36783981], [73.97103119, 23.37713814], [73.96247101, 23.38138962], [73.95691681, 23.37763977], [73.94729614, 23.3735199], [73.94371033, 23.36634064], [73.9438324, 23.35359955], [73.94262695, 23.34593964], [73.93889618, 23.34141922], [73.92784119, 23.33788109], [73.91398621, 23.33597946], [73.90122986, 23.3359127], [73.89427185, 23.33713913], [73.89492798, 23.35258102], [73.89118195, 23.35860062], [73.87944031, 23.36811066], [73.87708282, 23.37833023], [73.86676025, 23.39577103], [73.85743713, 23.40479279], [73.8364563, 23.43069077], [73.83679962, 23.44013977], [73.83213043, 23.44675064], [73.82688904, 23.44684029], [73.79416656, 23.43556976], [73.7830658, 23.43461037], [73.77784729, 23.44231987], [73.7739563, 23.44586945], [73.77099609, 23.45257759], [73.7647171, 23.45857811], [73.76065063, 23.4568119], [73.7565918, 23.4495697], [73.7513504, 23.44246101], [73.7339859, 23.42489243], [73.72881317, 23.41829109], [73.72614288, 23.41266251], [73.7203064, 23.4148407], [73.71721649, 23.41884041], [73.71356201, 23.43367958], [73.70960236, 23.44449043], [73.704216, 23.45578194], [73.69394684, 23.45890045], [73.68190765, 23.45708084], [73.6687088, 23.451931], [73.66081238, 23.44725037], [73.65320587, 23.44049072], [73.63806915, 23.45034027], [73.63275146, 23.45239258], [73.64064789, 23.47304153], [73.64382172, 23.4967804], [73.64491272, 23.49873924], [73.65258789, 23.50093079], [73.65841675, 23.50411987], [73.65844727, 23.51415253], [73.65733337, 23.51618004], [73.65219879, 23.52140236], [73.63700104, 23.53112984], [73.63713074, 23.54801941], [73.63825989, 23.56254959], [73.64286804, 23.56962013], [73.6497879, 23.57534027], [73.65120697, 23.58086967], [73.64872742, 23.59067917], [73.64804077, 23.59864044], [73.64998627, 23.60769272], [73.66073608, 23.62290192], [73.65039825, 23.62688065], [73.64225769, 23.63126945], [73.63295746, 23.63853073], [73.61901855, 23.6514225], [73.60853577, 23.65430832], [73.57727051, 23.65536118], [73.57074738, 23.65351105], [73.55297852, 23.63134956], [73.54141998, 23.62265015], [73.53224182, 23.61354065], [73.52672577, 23.6106205], [73.51348877, 23.61681175], [73.51024628, 23.62068939], [73.50569153, 23.62885094], [73.50109863, 23.63383102], [73.50137329, 23.63544083], [73.50845337, 23.63939095], [73.5116272, 23.64508057], [73.50052643, 23.65073013], [73.50720978, 23.6577301], [73.50779724, 23.66263008], [73.51094055, 23.67338943], [73.51122284, 23.68008041], [73.51035309, 23.69697952], [73.50853729, 23.70333099], [73.50192261, 23.70664978], [73.48561096, 23.70500946], [73.47927094, 23.70897293], [73.47661591, 23.72103119], [73.47289276, 23.72578049], [73.46276855, 23.73430824], [73.45493317, 23.73971939], [73.45128632, 23.74884033], [73.45082092, 23.75259018], [73.43218994, 23.76208115], [73.42765808, 23.7664299], [73.42048645, 23.77933121], [73.41349792, 23.78110123], [73.408638, 23.78359032], [73.40000916, 23.78397751], [73.39391327, 23.77846146], [73.3898468, 23.76926041], [73.37590027, 23.76667023], [73.37133789, 23.77787018], [73.36769867, 23.78364944], [73.36264801, 23.78742981], [73.36112976, 23.79165077], [73.36283112, 23.79775047], [73.37042236, 23.81438065], [73.37267303, 23.8219223], [73.3719101, 23.83208275], [73.36952209, 23.83855057], [73.35984802, 23.85462952], [73.36207581, 23.86186981], [73.36606598, 23.86907005], [73.37124634, 23.87585068], [73.37695313, 23.88879967], [73.38237762, 23.89500046], [73.3864975, 23.90577126], [73.39611053, 23.91679192], [73.40225983, 23.91822052], [73.40775299, 23.91612053], [73.42012024, 23.92340088], [73.42346954, 23.92760086], [73.42468262, 23.93106079], [73.42038727, 23.93644905], [73.41912842, 23.95379829], [73.42146301, 23.97467041], [73.41957855, 23.98266029], [73.41396332, 23.98843193], [73.40505981, 23.99054909], [73.41060638, 23.99833107], [73.41081238, 24.00255013], [73.40925598, 24.01585007], [73.41146851, 24.02518272], [73.41140747, 24.03484154], [73.41375732, 24.05106926], [73.40419006, 24.06520081], [73.39659119, 24.07253075], [73.38526917, 24.07958031], [73.37979126, 24.08415031], [73.37475586, 24.08708191], [73.36962891, 24.08798027], [73.36962128, 24.11249161], [73.37346649, 24.1281395], [73.36081696, 24.11409187], [73.34276581, 24.11582947], [73.33518219, 24.1151104], [73.33188629, 24.10400963], [73.33451843, 24.08256912], [73.33249664, 24.07368279], [73.32656097, 24.0625], [73.31845856, 24.0567894], [73.31140137, 24.05461121], [73.3068161, 24.05145073], [73.2979126, 24.03676987], [73.29103088, 24.02740288], [73.28275299, 24.02881813], [73.2753067, 24.02802086], [73.26390839, 24.02009964], [73.25637817, 24.01317978], [73.25254059, 24.01111984], [73.24582672, 24.01070976], [73.2425766, 24.01279831], [73.24032593, 24.01831818], [73.23513794, 24.02011108], [73.22940063, 24.02403069], [73.22933197, 24.02811813], [73.2232666, 24.03239059], [73.20812225, 24.03948021], [73.20063782, 24.0452404], [73.19893646, 24.05146027], [73.20108795, 24.05739021], [73.20910645, 24.06664085], [73.21366882, 24.07578087], [73.21438599, 24.08019066], [73.21672058, 24.08526039], [73.22041321, 24.08930016], [73.22264862, 24.09350967], [73.22381592, 24.09822083], [73.21578979, 24.10169983], [73.21227264, 24.10414124], [73.19999695, 24.10839081], [73.19760132, 24.11079025], [73.19386292, 24.10518265], [73.19190216, 24.10654831], [73.18686676, 24.10770035], [73.17173004, 24.1113224], [73.16755676, 24.11628914], [73.16114807, 24.12005997], [73.1554718, 24.12186813], [73.14715576, 24.12255096], [73.13846588, 24.12807083], [73.12339783, 24.14030075], [73.11416626, 24.13858986], [73.11650848, 24.15286064], [73.11303711, 24.15779114], [73.10243988, 24.16519928], [73.09095001, 24.17527962], [73.08268738, 24.18498039], [73.08130646, 24.19185829], [73.08196259, 24.19664955], [73.08722687, 24.20079994], [73.09172821, 24.22088051], [73.10119629, 24.22327042], [73.10600281, 24.22615051], [73.11120605, 24.23111153], [73.10617065, 24.23238945], [73.10193634, 24.23485184], [73.10090637, 24.23771095], [73.10575867, 24.24431038], [73.10690308, 24.24895287], [73.10987854, 24.25399017], [73.11606598, 24.26259041], [73.13894653, 24.28005028], [73.14385223, 24.29948044], [73.1449585, 24.30785751], [73.15123749, 24.31079292], [73.1733017, 24.30105019], [73.18062592, 24.30149078], [73.18479919, 24.30911064], [73.18643951, 24.3201828], [73.18612671, 24.32697105], [73.18701172, 24.33494949], [73.19294739, 24.34357071], [73.19792938, 24.33977127], [73.20140076, 24.33409119], [73.21105957, 24.33423042], [73.21644592, 24.35046959], [73.22561646, 24.35647964], [73.23147583, 24.36466026], [73.21098328, 24.37541962], [73.20072937, 24.36679077], [73.19039154, 24.35577011], [73.18017578, 24.35066986], [73.16996765, 24.35066986], [73.16200256, 24.35268021], [73.15455627, 24.35642815], [73.14531708, 24.36305046], [73.13730621, 24.36444092], [73.127388, 24.36882973], [73.11863708, 24.37574005], [73.11119843, 24.38680077], [73.10865021, 24.38746262], [73.09825897, 24.38552094], [73.08496094, 24.39447021], [73.08442688, 24.39764977], [73.08862305, 24.40008926], [73.09072113, 24.40878105], [73.0930481, 24.41312981], [73.09673309, 24.41720963], [73.10624695, 24.42032051], [73.10832977, 24.42632103], [73.10883331, 24.43241119], [73.1065979, 24.44536972], [73.10762787, 24.45181084], [73.10719299, 24.45681953], [73.098526, 24.47261047], [73.09892273, 24.49149132], [73.09438324, 24.49472809], [73.08381653, 24.49020958], [73.07485962, 24.48269081], [73.07006073, 24.48088074], [73.06713867, 24.47458267], [73.05728149, 24.4726181], [73.0533905, 24.4664917], [73.05104065, 24.46525955], [73.03320313, 24.46371078], [73.02719879, 24.46511269], [73.02185059, 24.46511269], [73.01278687, 24.48240089], [73.00676727, 24.47628021], [73.00034332, 24.47063065], [72.9980011, 24.46804047], [72.98912048, 24.45700073], [72.98100281, 24.4510498], [72.98324585, 24.44029808], [72.98931122, 24.43272972], [72.99061584, 24.42089081], [72.97939301, 24.40563965], [72.97245026, 24.40192986], [72.96418762, 24.39222145], [72.96327972, 24.38373947], [72.9661026, 24.38303185], [72.974617, 24.38343048], [72.98127747, 24.38005066], [72.98748016, 24.37511063], [72.99201202, 24.3682003], [72.99146271, 24.36397171], [72.97749329, 24.35884094], [72.96537018, 24.35110855], [72.96177673, 24.34877014], [72.94602203, 24.33928108], [72.9337616, 24.33618927], [72.92903137, 24.33265114], [72.92391205, 24.32632256], [72.9210968, 24.32723999], [72.91557312, 24.33280945], [72.91002655, 24.34049988], [72.90055847, 24.35144806], [72.8842926, 24.36084938], [72.86811829, 24.36581039], [72.85367584, 24.36601067], [72.83905029, 24.36478043], [72.82924652, 24.36498833], [72.81534576, 24.35819054], [72.79325104, 24.36016083], [72.77282715, 24.36074066], [72.74871826, 24.35752106], [72.73928833, 24.35884094], [72.73253632, 24.3612709], [72.71747589, 24.37555122], [72.70664215, 24.39133263], [72.69346619, 24.41928101], [72.69264221, 24.4414196], [72.69753265, 24.452631], [72.69725037, 24.45721054], [72.69301605, 24.46016121], [72.68460846, 24.45919991], [72.67443085, 24.45696259], [72.658638, 24.45643044], [72.63932037, 24.46146011], [72.60412598, 24.46910858], [72.58850098, 24.47250175], [72.5823822, 24.47746086], [72.57422638, 24.48814011], [72.55914307, 24.49464035], [72.55181122, 24.50032806], [72.54772186, 24.50559235], [72.54457855, 24.5068512], [72.54213715, 24.50486946], [72.51877594, 24.47299194], [72.51387787, 24.46455956], [72.51174164, 24.4473896], [72.50055695, 24.45029068], [72.50441742, 24.43089104], [72.51000214, 24.41834259], [72.50771332, 24.40993118], [72.50099945, 24.4073391], [72.48744202, 24.4054203], [72.4646759, 24.40711975], [72.46375275, 24.42094994], [72.46127319, 24.42685127], [72.45761871, 24.43285179], [72.45623779, 24.43812943], [72.44616699, 24.44826126], [72.43667603, 24.46051025], [72.43863678, 24.47907257], [72.44558716, 24.4877491], [72.44815063, 24.49332047], [72.44561005, 24.49962044], [72.44248962, 24.50424957], [72.4360199, 24.50536919], [72.4260025, 24.50832939], [72.42111206, 24.50806808], [72.39772034, 24.50028038], [72.39052582, 24.49884987], [72.38632202, 24.50051117], [72.37088013, 24.52876091], [72.37486267, 24.5299511], [72.37523651, 24.53164291], [72.37419891, 24.53354073], [72.373909, 24.53735924], [72.36860657, 24.5365181], [72.36546326, 24.53934097], [72.3615799, 24.54331017], [72.35793304, 24.55251122], [72.34860992, 24.55348969], [72.34327698, 24.55496979], [72.34057617, 24.55751038], [72.3348999, 24.55867958], [72.33362579, 24.55583954], [72.33701324, 24.5441494], [72.33241272, 24.54244041], [72.30182648, 24.54055977], [72.29512024, 24.5384407], [72.29338837, 24.53999138], [72.29393005, 24.54491043], [72.29191589, 24.55046082], [72.29170227, 24.55528069], [72.29003906, 24.55828094], [72.28508759, 24.55743027], [72.27168274, 24.55015945], [72.25099945, 24.58016014], [72.27671051, 24.59918022], [72.27925873, 24.60000038], [72.29305267, 24.59708977], [72.30033112, 24.60015106], [72.30458069, 24.59727287], [72.30890656, 24.5908699], [72.31402588, 24.58539009], [72.31784821, 24.58496094], [72.3259964, 24.58686066], [72.34221649, 24.59352112], [72.34546661, 24.59945107], [72.34915161, 24.60231018], [72.34896851, 24.61199188], [72.35011292, 24.6146698], [72.35309601, 24.61624908], [72.35378265, 24.61810112], [72.34797668, 24.62132263], [72.34020233, 24.62298965], [72.33100891, 24.61188126], [72.3237381, 24.60894012], [72.31505585, 24.60887146], [72.30932617, 24.6119709], [72.30619812, 24.61497116], [72.29969788, 24.61619949], [72.29366302, 24.61320114], [72.27474976, 24.62223053], [72.27414703, 24.62214279], [72.26059723, 24.62074089], [72.25421906, 24.62138939], [72.24893188, 24.62078094], [72.24202728, 24.62334061], [72.23362732, 24.63080978], [72.2299881, 24.63288116], [72.21637726, 24.62021255], [72.21096802, 24.61901093], [72.20828247, 24.61725044], [72.21063995, 24.61256981], [72.20697021, 24.61207008], [72.20144653, 24.6161499], [72.18589783, 24.60943031], [72.17559052, 24.61271095], [72.16539764, 24.61450005], [72.16166687, 24.61581039], [72.16101074, 24.61944962], [72.15357971, 24.63110924], [72.15072632, 24.63410187], [72.14595032, 24.63487053], [72.13475037, 24.63380051], [72.12529755, 24.63163948], [72.12100983, 24.63196182], [72.11654663, 24.63336945], [72.10186005, 24.64333916], [72.09091187, 24.64869118], [72.0848999, 24.65275192], [72.08547974, 24.65872002], [72.08239746, 24.66847038], [72.0923233, 24.67476082], [72.08525085, 24.69700813], [72.07958221, 24.70033836], [72.05249023, 24.70578957], [72.04087067, 24.69547081], [72.03161621, 24.69181061], [72.00730896, 24.68598175], [72.001091, 24.68297005], [71.99407959, 24.67755127], [71.98987579, 24.66704941], [71.99339294, 24.65670967], [71.99324799, 24.65312958], [71.99077606, 24.65139961], [71.98282623, 24.65085983], [71.97914886, 24.64696121], [71.96740723, 24.63793945], [71.96218109, 24.63845062], [71.95079041, 24.6325798], [71.94744873, 24.62758064], [71.94419098, 24.62677956], [71.93952179, 24.62760162], [71.93450928, 24.62685013], [71.92800903, 24.63381195], [71.91879272, 24.64620018], [71.91723633, 24.65089035], [71.92137909, 24.65223122], [71.92405701, 24.65448189], [71.92597961, 24.65871048], [71.92592621, 24.66208267], [71.92008209, 24.66735077], [71.91210175, 24.66959953], [71.90416718, 24.66904068], [71.89379883, 24.6657505], [71.89095306, 24.67008972], [71.8813324, 24.67567062], [71.87647247, 24.67515945], [71.87110138, 24.67221832], [71.86495972, 24.66291046], [71.86276245, 24.65475273], [71.86255646, 24.64948082], [71.867836, 24.63002014], [71.86868286, 24.62347984], [71.86470032, 24.6195507], [71.8609314, 24.61405945], [71.85839081, 24.60416985], [71.85553741, 24.60609055], [71.84657288, 24.61486053], [71.83860779, 24.61638069], [71.82141113, 24.61658096], [71.8155365, 24.61832809], [71.81176758, 24.62182045], [71.81153107, 24.62593079], [71.81259155, 24.63252068], [71.81738281, 24.64587975], [71.81508636, 24.65468025], [71.81292725, 24.66087914], [71.80912781, 24.66592026], [71.80459595, 24.66905975], [71.79898834, 24.67052078], [71.79094696, 24.67012024], [71.78450775, 24.66885948], [71.75830841, 24.66027069], [71.74577332, 24.65427971], [71.73734283, 24.65344048], [71.71631622, 24.6543293], [71.68599701, 24.63984108], [71.66977692, 24.6365509], [71.66156006, 24.63326073], [71.65027618, 24.63993073], [71.65122223, 24.64315987], [71.64836121, 24.64640999], [71.64494324, 24.65254021], [71.64057159, 24.65608025], [71.6341629, 24.65805054], [71.6307373, 24.66255951], [71.62711334, 24.66193008], [71.62338257, 24.66424942], [71.62081909, 24.66698265], [71.61833191, 24.66836166], [71.61659241, 24.670681], [71.61003876, 24.66854095], [71.60486603, 24.66553116], [71.59783173, 24.66385078], [71.592453, 24.66558838], [71.58965302, 24.67016983], [71.58309937, 24.67653084], [71.57717896, 24.67740059], [71.5684433, 24.67352104], [71.55142212, 24.67063141], [71.54364014, 24.67358017], [71.53697205, 24.67892075], [71.52731323, 24.67716026], [71.52275085, 24.67526054], [71.52092743, 24.67548943], [71.51618958, 24.67634964], [71.50353241, 24.67380905], [71.4883194, 24.67385101], [71.47424316, 24.66320038], [71.4668808, 24.66076279], [71.45889282, 24.66127968], [71.45146942, 24.65884018], [71.4453125, 24.65397072], [71.43241882, 24.64616013], [71.42897034, 24.64256096], [71.42230988, 24.63810158], [71.41295624, 24.63531113], [71.40703583, 24.63467026], [71.40280151, 24.63153076], [71.39962769, 24.62696075], [71.39451599, 24.62701035], [71.38977051, 24.6282196], [71.38835144, 24.62393951], [71.38305664, 24.62168121], [71.3807373, 24.62138176], [71.37518311, 24.62305069], [71.37269592, 24.62576103], [71.36765289, 24.62726021], [71.36702728, 24.63190079], [71.36196899, 24.64160919], [71.35671234, 24.65405083], [71.35103607, 24.65321922], [71.34276581, 24.6482296], [71.32649231, 24.64292908], [71.32164001, 24.64031982], [71.31777191, 24.63591957], [71.31006622, 24.62108994], [71.30745697, 24.61987114], [71.29773712, 24.60764122], [71.28714752, 24.61271095], [71.26095581, 24.62053108], [71.25298309, 24.62363052], [71.24154663, 24.6266098], [71.23789215, 24.62850952], [71.2073288, 24.63954926], [71.19709778, 24.64292908], [71.17164612, 24.64886093], [71.14673615, 24.65801048], [71.11927795, 24.66864967], [71.11334229, 24.67362976], [71.10713959, 24.68065071], [71.10040283, 24.68333817], [71.08651733, 24.6978302], [71.077034, 24.70766068], [71.07285309, 24.71199989], [71.07177734, 24.71487427], [71.06276703, 24.73892975], [71.06231689, 24.73971939], [71.06095123, 24.74217987], [71.05381012, 24.75551033], [71.05029297, 24.7606411], [71.03530884, 24.7987709], [71.0235672, 24.82118034], [71.01243591, 24.83587074], [71.01111603, 24.83854103], [71.00955963, 24.84165001], [71.0039978, 24.85289192], [70.98957062, 24.87247086], [70.98532104, 24.87718964], [70.97865295, 24.88972282], [70.96190643, 24.90824127], [70.95625305, 24.91440964], [70.94548798, 24.9345417], [70.93260956, 24.97347069], [70.92560577, 24.99471092], [70.91467285, 25.04155159], [70.91372681, 25.04552078], [70.91203308, 25.05788994], [70.90538025, 25.09503174], [70.90013123, 25.11969185], [70.89431, 25.14405823], [70.88456726, 25.15357971], [70.87477875, 25.16321945], [70.8608017, 25.17575073], [70.85597229, 25.18218994], [70.85423279, 25.18377113], [70.80934906, 25.2237606], [70.79618835, 25.2397728], [70.79560089, 25.24027061], [70.79353333, 25.24205971], [70.76644897, 25.2649498], [70.75905609, 25.27495956], [70.75354767, 25.29630089], [70.7442627, 25.320961], [70.73226929, 25.33476257], [70.72315216, 25.34514999], [70.7059021, 25.36009026], [70.70194244, 25.3640995], [70.68704987, 25.37829018], [70.67871094, 25.38535118], [70.67668152, 25.38710022], [70.67572021, 25.38711357], [70.67562866, 25.38719368], [70.67417145, 25.38932037], [70.67366028, 25.39495087], [70.6762619, 25.40108109], [70.67899323, 25.41175079], [70.67974091, 25.41650963], [70.67957306, 25.44745064], [70.6829071, 25.47352028], [70.68499756, 25.48952293], [70.68521118, 25.50340271], [70.68596649, 25.51066017], [70.68553925, 25.51120186], [70.68786621, 25.51734924], [70.68773651, 25.51823044], [70.68551636, 25.51921082], [70.67621613, 25.52387047], [70.6765213, 25.53107071], [70.67662048, 25.53256035], [70.67585754, 25.53309059], [70.67685699, 25.53334999], [70.67693329, 25.53518295], [70.67694092, 25.53614616], [70.67727661, 25.5886898], [70.67735291, 25.59049034], [70.67935181, 25.61403084], [70.67986298, 25.6198101], [70.6799469, 25.62203789], [70.68035889, 25.6325531], [70.68090057, 25.64641953], [70.68110657, 25.65213966], [70.68113708, 25.66076088], [70.67613983, 25.68029022], [70.67328644, 25.68535614], [70.67292786, 25.68600082], [70.66596222, 25.69722939], [70.66079712, 25.70112038], [70.65921783, 25.7017498], [70.65891266, 25.70191765], [70.65542603, 25.70378113], [70.64885712, 25.70590019], [70.64686584, 25.70654106], [70.64395905, 25.70658112], [70.64247894, 25.70587921], [70.63842773, 25.70675087], [70.63085938, 25.70672035], [70.61705017, 25.70663071], [70.60170746, 25.70325089], [70.57470703, 25.69058037], [70.5657959, 25.68638992], [70.53705597, 25.67700958], [70.53623199, 25.67673111], [70.53277588, 25.67618942], [70.49030304, 25.67596054], [70.47035217, 25.67436981], [70.4597702, 25.67346954], [70.42533875, 25.66957092], [70.40879822, 25.66627121], [70.3996582, 25.66379929], [70.39443207, 25.6641407], [70.39229584, 25.66460037], [70.37520599, 25.66846085], [70.36567688, 25.67169952], [70.28526306, 25.69893074], [70.27961731, 25.70125961], [70.27594757, 25.70342064], [70.27231598, 25.7087307], [70.26964569, 25.71651649], [70.26726532, 25.72345352], [70.26078796, 25.74230957], [70.24639893, 25.76348877], [70.24450684, 25.76626968], [70.244133, 25.76666832], [70.24249268, 25.76838112], [70.23620605, 25.77494621], [70.22379303, 25.78791046], [70.20671844, 25.80229187], [70.20321655, 25.80524063], [70.17796326, 25.81949997], [70.17144775, 25.83228874], [70.1663208, 25.84235954], [70.16536713, 25.84423065], [70.16150665, 25.84887123], [70.15473938, 25.85874939], [70.15392303, 25.86027527], [70.14501953, 25.86852264], [70.1416626, 25.87537956], [70.10668182, 25.92420959], [70.09737396, 25.94186592], [70.09607697, 25.94431686], [70.09130096, 25.96515846], [70.09111023, 25.98373795], [70.09098053, 25.99682236], [70.08656311, 26.03120804], [70.08045197, 26.05823708], [70.08257294, 26.07385826], [70.08604431, 26.08214951], [70.09427643, 26.09736252], [70.12638855, 26.13938522], [70.13728333, 26.15489769], [70.14519501, 26.16615486], [70.1594162, 26.19448853], [70.16163635, 26.20185089], [70.16725922, 26.22387505], [70.17266846, 26.24507713], [70.17222595, 26.24832916], [70.17076111, 26.25906372], [70.16681671, 26.27257347], [70.16524506, 26.2771492], [70.16460419, 26.29091644], [70.16674042, 26.3069973], [70.17830658, 26.3497715], [70.17790222, 26.36583519], [70.17933655, 26.37525558], [70.17848969, 26.38442993], [70.17804718, 26.40416336], [70.17599487, 26.4332962], [70.18099976, 26.46959877], [70.18389893, 26.48683357], [70.18225861, 26.49852562], [70.17854309, 26.51410294], [70.17273712, 26.53494453], [70.1678009, 26.55056], [70.16773987, 26.5507431], [70.16051483, 26.55895424], [70.15022278, 26.56828499], [70.13893127, 26.57439613], [70.10688019, 26.58952141], [70.08843994, 26.59556961], [70.06619263, 26.59929085], [70.04782104, 26.59913635], [70.0404129, 26.59953308], [70.02484894, 26.59871101], [70.0, 26.59449768], [69.996315, 26.59387207], [69.95478058, 26.58730316], [69.91834259, 26.58260345], [69.91094208, 26.58230591], [69.87931061, 26.58108521], [69.85555267, 26.58292007], [69.83175659, 26.58773422], [69.81536102, 26.59215736], [69.79483795, 26.59998322], [69.77194214, 26.61374664], [69.74327087, 26.63846397], [69.72187042, 26.65384293], [69.69898224, 26.66506958], [69.68975067, 26.66795158], [69.67665863, 26.6726265], [69.60830688, 26.70030975], [69.60184479, 26.70505524], [69.59210205, 26.70723724], [69.58053589, 26.71191978], [69.57460785, 26.71552467], [69.55044556, 26.72464561], [69.52241516, 26.73601151], [69.51544952, 26.74005508], [69.51135254, 26.74446678], [69.50765228, 26.74845123], [69.48751068, 26.7936554], [69.48443604, 26.80388832], [69.48373413, 26.80623055], [69.48387909, 26.80763817], [69.48551178, 26.82346916], [69.4957428, 26.87249184], [69.50093842, 26.9003315], [69.50359344, 26.94329071], [69.51287842, 27.01438141], [69.51320648, 27.01686859], [69.53726196, 27.06927299], [69.54020691, 27.07757187], [69.5426178, 27.08334923], [69.55678558, 27.11725426], [69.56483459, 27.1375885], [69.56518555, 27.13847542], [69.578125, 27.1654892], [69.58666229, 27.17798424], [69.60060883, 27.18939781], [69.60363007, 27.1931057], [69.66594696, 27.25143623], [69.69870758, 27.27773857], [69.70013428, 27.27867126], [69.72467804, 27.29477692], [69.79387665, 27.34646225], [69.81254578, 27.35961151], [69.83253479, 27.3787632], [69.84881592, 27.39292717], [69.86196899, 27.40277863], [69.90762329, 27.45957756], [69.92113495, 27.47939873], [69.93624878, 27.50210762], [70.0, 27.54504204], [70.01626587, 27.55599594], [70.02456665, 27.5696907], [70.05142212, 27.63533974], [70.08312988, 27.70836639], [70.10781097, 27.76687241], [70.1569519, 27.83404922], [70.18078613, 27.8551445], [70.18127441, 27.85557938], [70.20716858, 27.88489914], [70.20759583, 27.88538361], [70.28133392, 27.93042374], [70.30290985, 27.94617271], [70.32187653, 27.96488953], [70.33289337, 27.97712326], [70.33646393, 27.98311424], [70.36616516, 28.00824928], [70.40859985, 28.0172863], [70.43235779, 28.02154922], [70.4597168, 28.02950287], [70.47908783, 28.03373718], [70.48375702, 28.03401184], [70.50983429, 28.03554344], [70.53033447, 28.03248787], [70.5626297, 28.01980209], [70.58232117, 28.00265884], [70.59876251, 27.98834229], [70.60411072, 27.98344994], [70.61162567, 27.97656822], [70.61174774, 27.97646141], [70.61607361, 27.97250175], [70.62825775, 27.96135521], [70.65086365, 27.93985558], [70.66069794, 27.93050194], [70.67210388, 27.91431808], [70.67284393, 27.86979294], [70.67577362, 27.85098076], [70.67841339, 27.8390522], [70.6879425, 27.82188988], [70.68935394, 27.8193512], [70.69818115, 27.80767822], [70.70311737, 27.80035019], [70.70438385, 27.79647827], [70.70521545, 27.79393387], [70.71431732, 27.77950287], [70.71484375, 27.77628708], [70.72158813, 27.76896667], [70.72575378, 27.76025963], [70.73795319, 27.74216652], [70.74073792, 27.73894882], [70.74080658, 27.73886871], [70.75143433, 27.72660065], [70.75766754, 27.71720886], [70.76721191, 27.71494293], [70.76904297, 27.71483231], [70.76967621, 27.71449089], [70.78881836, 27.71001053], [70.8013382, 27.70812035], [70.81899261, 27.70426941], [70.84137726, 27.70333099], [70.85793304, 27.70220947], [70.86958313, 27.70070076], [70.87137604, 27.70020103], [70.88345337, 27.69850159], [70.88417053, 27.6984005], [70.89795685, 27.70022964], [70.90686035, 27.70063972], [70.94995117, 27.71883965], [70.95175171, 27.71959114], [70.96156311, 27.7227211], [70.96969604, 27.72654915], [70.98433685, 27.7342205], [71.03398895, 27.75726128], [71.05593109, 27.76391029], [71.07047272, 27.76834106], [71.08701324, 27.77679253], [71.12506104, 27.79225159], [71.13994598, 27.79829979], [71.1736908, 27.81199074], [71.18379211, 27.81441116], [71.20865631, 27.82435036], [71.23013306, 27.82878113], [71.23379517, 27.83000374], [71.24267578, 27.83296967], [71.25521851, 27.83704948], [71.27295685, 27.84192848], [71.32578278, 27.85174942], [71.34189606, 27.85472107], [71.38105011, 27.86193085], [71.409729, 27.86578941], [71.4126358, 27.86520767], [71.41876221, 27.86398125], [71.44787598, 27.86605263], [71.49971008, 27.86557007], [71.52362823, 27.86535072], [71.53079987, 27.86530113], [71.54905701, 27.86623001], [71.58657837, 27.87030029], [71.6044693, 27.86815071], [71.62077332, 27.86838913], [71.64443207, 27.86873055], [71.65828705, 27.86893082], [71.66394043, 27.87265015], [71.68099213, 27.87723923], [71.69803619, 27.88256264], [71.7199173, 27.89157104], [71.74344635, 27.90061951], [71.7596283, 27.90730286], [71.76560974, 27.90994072], [71.82628632, 27.93048096], [71.85851288, 27.94140053], [71.89311218, 27.95511055], [71.89630127, 27.95684052], [71.89737701, 27.95742035], [71.90154266, 27.96899033], [71.90361023, 27.98343277], [71.90547943, 27.99745178], [71.90867615, 28.01393127], [71.91194916, 28.02614975], [71.91253662, 28.03467941], [71.91316223, 28.03832817], [71.91236115, 28.04807091], [71.91569519, 28.0589447], [71.91760254, 28.06517029], [71.92021942, 28.07555008], [71.92207336, 28.09140015], [71.92530823, 28.10544968], [71.92790985, 28.11462021], [71.93057251, 28.12195015], [71.93325806, 28.12685966], [71.94265747, 28.13973808], [71.95347595, 28.15266991], [71.96604156, 28.16526031], [71.97484589, 28.17822075], [71.99588013, 28.20695686], [72.00543976, 28.2154007], [72.01911163, 28.22663116], [72.02536011, 28.23110962], [72.04427338, 28.24346161], [72.06626129, 28.26082993], [72.09078979, 28.2784996], [72.09253693, 28.27954292], [72.09375763, 28.28026962], [72.0981369, 28.28285027], [72.10856628, 28.28989029], [72.12612915, 28.30350113], [72.13633728, 28.31485939], [72.15092468, 28.33109283], [72.15612793, 28.33688164], [72.18442535, 28.35800552], [72.19802856, 28.3813858], [72.20228577, 28.38525963], [72.20358276, 28.38845062], [72.20710754, 28.3969841], [72.20884705, 28.39998245], [72.23577118, 28.47483635], [72.24324799, 28.49635506], [72.24437714, 28.50575638], [72.24935913, 28.51076698], [72.25341797, 28.52703285], [72.27961731, 28.60142136], [72.2855072, 28.61881828], [72.30195618, 28.6648159], [72.32628632, 28.69889259], [72.34435272, 28.71603966], [72.34638977, 28.72047806], [72.36579132, 28.74187088], [72.37506104, 28.75210762], [72.3783493, 28.75574112], [72.38469696, 28.76394081], [72.38996887, 28.76801491], [72.40273285, 28.77787971], [72.40957642, 28.78084946], [72.43093109, 28.7885704], [72.44657135, 28.79315948], [72.45922089, 28.79922104], [72.46811676, 28.80252075], [72.48480988, 28.81042099], [72.50382996, 28.82028961], [72.51985168, 28.82860947], [72.54417419, 28.84358025], [72.5515976, 28.84815025], [72.58792877, 28.86601067], [72.59012604, 28.86734962], [72.59153748, 28.86804962], [72.64351654, 28.89910126], [72.65065002, 28.90335083], [72.65841675, 28.90690041], [72.6665802, 28.91192055], [72.66838837, 28.91282082], [72.67177582, 28.91378975], [72.6745224, 28.91629982], [72.71129608, 28.93502998], [72.74143982, 28.94829941], [72.78582001, 28.96537018], [72.78970337, 28.96686172], [72.84401703, 28.9877224], [72.8454361, 28.9883194], [72.84599304, 28.98855972], [72.84880829, 28.98990059], [72.86197662, 28.99623108], [72.88774109, 29.00370026], [72.89898682, 29.00938988], [72.91279602, 29.01438141], [72.9282074, 29.01993942], [72.93551636, 29.02294922], [72.93943787, 29.02524185], [72.94069672, 29.02627945], [72.94171906, 29.0272007], [72.9437561, 29.02991104], [72.95053864, 29.04591942], [72.95361328, 29.05317116], [72.95806885, 29.06110954], [72.96061707, 29.06810951], [72.97570801, 29.09918022], [72.97878265, 29.10707092], [72.98335266, 29.11388969], [72.98397827, 29.11478233], [72.9850769, 29.11634827], [72.98565674, 29.11764908], [72.98587036, 29.11857033], [72.99981689, 29.14652252], [73.00003052, 29.14736557], [73.01570892, 29.16432953], [73.02033997, 29.16818047], [73.02416229, 29.17402077], [73.03180695, 29.18342209], [73.03553772, 29.18801117], [73.03664398, 29.18886757], [73.04013824, 29.19157028], [73.05516815, 29.20714188], [73.05636597, 29.20850945], [73.07846069, 29.23340034], [73.07946777, 29.23483086], [73.08434296, 29.24192429], [73.08927155, 29.24909019], [73.09229279, 29.25377274], [73.09844208, 29.26575089], [73.10153198, 29.2725296], [73.10943604, 29.28273964], [73.10991669, 29.28466988], [73.11221313, 29.28932953], [73.11392212, 29.29212952], [73.11470032, 29.29269028], [73.11524963, 29.29356194], [73.11524963, 29.29467964], [73.1370163, 29.32930946], [73.13957214, 29.33542061], [73.14686584, 29.34988976], [73.15101624, 29.35724831], [73.15735626, 29.3678112], [73.16900635, 29.38599968], [73.16982269, 29.38755035], [73.17103577, 29.389431], [73.19129181, 29.42856979], [73.20236206, 29.44190979], [73.22164154, 29.47943115], [73.22315979, 29.48034096], [73.22381592, 29.48200035], [73.22751617, 29.48661995], [73.22815704, 29.48834038], [73.2324295, 29.49299812], [73.23810577, 29.50611115], [73.24295807, 29.51247978], [73.24759674, 29.52086067], [73.26213837, 29.54120064], [73.26341248, 29.54316139], [73.27131653, 29.55696106], [73.27488708, 29.56666946], [73.28392029, 29.59768295], [73.2859726, 29.60463905], [73.29760742, 29.63355064], [73.31202698, 29.68622017], [73.31257629, 29.68761063], [73.31478882, 29.69145012], [73.31523132, 29.69299126], [73.31607819, 29.6944809], [73.31732941, 29.69895172], [73.32546234, 29.72772026], [73.32669067, 29.73106766], [73.32772827, 29.73220062], [73.3336792, 29.74969101], [73.33571625, 29.75759125], [73.34030914, 29.76885033], [73.34568787, 29.79204941], [73.34957123, 29.80516052], [73.35430908, 29.81760979], [73.35869598, 29.83613968], [73.36582184, 29.85284042], [73.37146759, 29.87400055], [73.38539886, 29.92601967], [73.39137268, 29.93787003], [73.39924622, 29.94341087], [73.40738678, 29.94688606], [73.41280365, 29.94919968], [73.46694183, 29.96907806], [73.53329468, 29.99363518], [73.53985596, 29.9953804], [73.54685211, 29.99865341], [73.56176758, 30.00563049], [73.57958221, 30.01172066], [73.5994873, 30.01853943], [73.61118317, 30.02240944], [73.65339661, 30.03120041], [73.67189026, 30.03693008], [73.67843628, 30.0389595], [73.70915985, 30.04712105], [73.75398254, 30.05653954], [73.78721619, 30.06640053], [73.79408264, 30.06965828], [73.80046082, 30.07639122], [73.80632019, 30.08250046], [73.83770752, 30.10870171], [73.84842682, 30.11609077], [73.85430145, 30.12026024], [73.87255859, 30.13231087], [73.88349152, 30.13885117], [73.89550018, 30.14941025], [73.90392303, 30.15500069], [73.92346954, 30.16789818], [73.95796204, 30.18574715], [73.96631622, 30.19504929], [73.96640778, 30.19449425], [73.96810913, 30.18429947], [73.96643829, 30.17703056], [73.96337128, 30.17182922], [73.96082306, 30.14323044], [73.96118164, 30.13422966], [73.96247101, 30.12750053], [73.96393585, 30.12438011], [73.96665192, 30.12118912], [73.95794678, 30.11956024], [73.94998932, 30.1097908], [73.94410706, 30.10423088], [73.94291687, 30.09909058], [73.93152618, 30.08381081], [73.91821289, 30.06814957], [73.90854645, 30.06011009], [73.89840698, 30.0536499], [73.89480591, 30.0468502], [73.89261627, 30.03853035], [73.88551331, 30.01742935], [73.88186646, 30.01124001], [73.8811264, 29.99628067], [73.88302612, 29.99129105], [73.8884964, 29.9817791], [73.88944244, 29.97760963], [73.89118195, 29.97006989], [73.93295288, 29.97074127], [73.9569397, 29.96951294], [73.97646332, 29.96911049], [73.99092102, 29.97122955], [73.9960022, 29.97089005], [74.00274658, 29.97006035], [74.06919861, 29.96887016], [74.08332825, 29.96737289], [74.15444946, 29.96329117], [74.18596649, 29.96038055], [74.21276093, 29.96039009], [74.22380066, 29.95971107], [74.24067688, 29.95628929], [74.25190735, 29.95525932], [74.26030731, 29.9556694], [74.27902985, 29.95508957], [74.2899704, 29.95626068], [74.32151031, 29.95396042], [74.35585022, 29.95033073], [74.37245178, 29.95001984], [74.40379333, 29.94734001], [74.42807007, 29.94954109], [74.44197845, 29.94708824], [74.44403839, 29.94672012], [74.46660614, 29.94467926], [74.51906586, 29.94334984], [74.51278687, 29.93003845], [74.50502777, 29.90776062], [74.51091003, 29.90429115], [74.5255127, 29.90256119], [74.53369141, 29.90262032], [74.54345703, 29.88871956], [74.54521942, 29.88072968], [74.55179596, 29.8735199], [74.55356598, 29.86564064], [74.54747009, 29.85692024], [74.53253174, 29.83928108], [74.50588989, 29.83258057], [74.4916687, 29.82650948], [74.48060608, 29.8152504], [74.4705658, 29.80200005], [74.46526337, 29.78754997], [74.46911621, 29.75823975], [74.47200012, 29.74403], [74.48319244, 29.74403], [74.49680328, 29.74182129], [74.51155853, 29.7406826], [74.52583313, 29.74136925], [74.53185272, 29.74934959], [74.53778839, 29.75386047], [74.54933167, 29.7548008], [74.56402588, 29.75461006], [74.57139587, 29.75324821], [74.57816315, 29.76696014], [74.5866394, 29.76851082], [74.59253693, 29.76671982], [74.59751129, 29.75797081], [74.60540009, 29.7528801], [74.60598755, 29.7466507], [74.60161591, 29.74066925], [74.60347748, 29.72142982], [74.60037994, 29.71310806], [74.59902954, 29.70621109], [74.59287262, 29.70071983], [74.59387207, 29.69143295], [74.59085083, 29.68272018], [74.58513641, 29.67502975], [74.57852173, 29.65475273], [74.58203888, 29.64406967], [74.58603668, 29.63525963], [74.58127594, 29.63054085], [74.57536316, 29.62732124], [74.57699585, 29.62082291], [74.57467651, 29.6144104], [74.57028198, 29.58591843], [74.57060242, 29.56854057], [74.56653595, 29.56349945], [74.57174683, 29.55558014], [74.58178711, 29.54768944], [74.59117889, 29.54342079], [74.5994873, 29.53686905], [74.61142731, 29.53149986], [74.61440277, 29.52711105], [74.61168671, 29.52000809], [74.60452271, 29.51044083], [74.60074615, 29.50354958], [74.592659, 29.49212265], [74.59030914, 29.48612976], [74.59156036, 29.47985077], [74.58553314, 29.4689827], [74.58042145, 29.46349907], [74.57891083, 29.45862007], [74.57170868, 29.46230125], [74.55947113, 29.46437073], [74.55037689, 29.46447945], [74.54280853, 29.4665699], [74.53462982, 29.46503258], [74.53074646, 29.45754814], [74.52910614, 29.44953918], [74.52955627, 29.43499947], [74.53129578, 29.42498016], [74.5411377, 29.42314911], [74.5521698, 29.42240143], [74.55780792, 29.4186306], [74.56439972, 29.41077995], [74.57003021, 29.40615845], [74.56909943, 29.39730072], [74.57289886, 29.38644981], [74.57978058, 29.37873077], [74.59053802, 29.37067032], [74.59671783, 29.36219025], [74.60003662, 29.35433006], [74.59577942, 29.32831192], [74.60603333, 29.3275795], [74.64182281, 29.33119965], [74.64412689, 29.33534813], [74.64370728, 29.35440063], [74.650177, 29.37236977], [74.65851593, 29.36997986], [74.67601776, 29.36817169], [74.68868256, 29.36515999], [74.71124268, 29.36890984], [74.71688843, 29.36635971], [74.72255707, 29.36084938], [74.73169708, 29.35378838], [74.75663757, 29.35596085], [74.77591705, 29.36015129], [74.78578186, 29.37054062], [74.79878235, 29.38465118], [74.80954742, 29.39847946], [74.8351059, 29.40147972], [74.84113312, 29.4040699], [74.84951782, 29.40279007], [74.85719299, 29.39937019], [74.86393738, 29.39635086], [74.86656952, 29.38846016], [74.87058258, 29.38511276], [74.88848114, 29.38667107], [74.89530945, 29.3841095], [74.89907074, 29.3782196], [74.91021729, 29.37115288], [74.92196655, 29.36603165], [74.92714691, 29.36463928], [74.93592072, 29.33794975], [74.94608307, 29.33280945], [74.95096588, 29.32607079], [74.95056915, 29.31851006], [74.94584656, 29.31102753], [74.94010925, 29.30481911], [74.94256592, 29.29518127], [74.94753265, 29.28815842], [74.95310974, 29.28194046], [74.95996094, 29.28015137], [74.96806335, 29.28244019], [74.97690582, 29.28111839], [74.98291779, 29.27826118], [74.99104309, 29.2717495], [75.005867, 29.28380966], [75.02385712, 29.29153061], [75.03991699, 29.28714943], [75.05047607, 29.2723999], [75.05066681, 29.26888084], [75.05094147, 29.26371193], [75.06062317, 29.25331116], [75.06532288, 29.24661064], [75.06270599, 29.23892021], [75.07807922, 29.23245049], [75.09250641, 29.22911263], [75.10817719, 29.2267704], [75.11374664, 29.24290085], [75.12467194, 29.24496078], [75.1474762, 29.24584961], [75.16082001, 29.25374985], [75.16401672, 29.2643795], [75.17999268, 29.26861954], [75.18850708, 29.25863075], [75.1953125, 29.24422073], [75.21195984, 29.2345295], [75.22345734, 29.23495102], [75.23522949, 29.25193977], [75.24946594, 29.25646019], [75.27172852, 29.25436974], [75.27671814, 29.27345085], [75.27937317, 29.27682114], [75.28968811, 29.27770042], [75.29969025, 29.28198051], [75.30857849, 29.28891754], [75.31926727, 29.29343987], [75.32424927, 29.29018974], [75.32537079, 29.27831078], [75.32318115, 29.25175095], [75.31492615, 29.23596001], [75.33454132, 29.22883034], [75.3453064, 29.22616005], [75.34719849, 29.23011971], [75.35016632, 29.24738121], [75.35797882, 29.25461006], [75.37246704, 29.26003075], [75.37954712, 29.26393127], [75.3879776, 29.2643528], [75.39570618, 29.26194], [75.39868927, 29.25498962], [75.39968109, 29.24677849], [75.39936829, 29.24027061], [75.3936615, 29.23423958], [75.38729858, 29.22904015], [75.38611603, 29.2212429], [75.39229584, 29.21807098], [75.39646149, 29.21342087], [75.39985657, 29.20148277], [75.40065002, 29.18890953], [75.39438629, 29.17427063], [75.38857269, 29.17070007], [75.37845612, 29.17152023], [75.36895752, 29.16995811], [75.36763, 29.15042114], [75.36115265, 29.14262009], [75.37380981, 29.13706017], [75.38508606, 29.134161], [75.39620972, 29.12844086], [75.39134216, 29.11931992], [75.38069916, 29.11071968], [75.38130188, 29.10256958], [75.38315582, 29.09537125], [75.3813858, 29.08967018], [75.38218689, 29.08359909], [75.38065338, 29.07032013], [75.39025116, 29.06822968], [75.4302597, 29.06472015], [75.42975616, 29.05617905], [75.4375, 29.05047989], [75.44055939, 29.04152107], [75.43264008, 29.02206993], [75.43473816, 29.01654053], [75.4586792, 29.02015114], [75.47342682, 29.02020073], [75.48362732, 29.01885033], [75.50511932, 29.01515007], [75.51110077, 29.01082993], [75.51107025, 29.00414085], [75.51113892, 29.00332069], [75.51525116, 28.99105072], [75.51651764, 28.97538948], [75.50891876, 28.9657383], [75.50293732, 28.96148109], [75.50354767, 28.95182037], [75.49756622, 28.94148827], [75.46888733, 28.93799019], [75.46707916, 28.92625046], [75.48462677, 28.90166092], [75.48842621, 28.89831924], [75.48799133, 28.85964966], [75.49771881, 28.85618973], [75.49915314, 28.85036087], [75.50267792, 28.84597969], [75.51049805, 28.84342003], [75.5133667, 28.83658981], [75.50878906, 28.81529045], [75.50312042, 28.80928993], [75.50392151, 28.79673958], [75.49854279, 28.7876606], [75.50502777, 28.78279114], [75.51608276, 28.77222824], [75.5219574, 28.7561512], [75.52892303, 28.75028038], [75.52603149, 28.74291992], [75.53093719, 28.73282051], [75.53148651, 28.71729088], [75.53547668, 28.68839073], [75.53663635, 28.68217087], [75.53980255, 28.67601967], [75.53793335, 28.66128922], [75.54071808, 28.65527916], [75.53956604, 28.64887047], [75.54901123, 28.64312172], [75.55570984, 28.6145916], [75.57699585, 28.61667061], [75.58495331, 28.60638046], [75.60933685, 28.60588074], [75.61804962, 28.60220909], [75.62001801, 28.59922981], [75.61904907, 28.58872986], [75.6252594, 28.55850983], [75.62909698, 28.54597092], [75.63665009, 28.54751015], [75.64351654, 28.54290962], [75.65355682, 28.54057121], [75.66333008, 28.53611183], [75.6654892, 28.53327942], [75.6639328, 28.52086067], [75.6710968, 28.51692963], [75.69007874, 28.49909973], [75.70069122, 28.49533081], [75.72395325, 28.49129295], [75.73654938, 28.48720169], [75.73500061, 28.47264099], [75.74713898, 28.46937943], [75.77822876, 28.45761108], [75.78515625, 28.45074081], [75.78513336, 28.43921089], [75.77683258, 28.43047142], [75.76544952, 28.42078018], [75.77031708, 28.40761948], [75.78256226, 28.40723038], [75.78759003, 28.40444183], [75.79405212, 28.40987968], [75.80258942, 28.41422844], [75.81671143, 28.41150093], [75.81813812, 28.40588951], [75.82823944, 28.40907288], [75.83508301, 28.39770126], [75.84120178, 28.39727974], [75.87213135, 28.39085007], [75.88315582, 28.38669968], [75.88353729, 28.39199066], [75.88922882, 28.39365959], [75.89686584, 28.38999939], [75.89713287, 28.38008118], [75.90467072, 28.37606049], [75.92237854, 28.36890984], [75.92498016, 28.36469841], [75.92840576, 28.35601997], [75.92740631, 28.3451004], [75.95630646, 28.33837128], [75.95659637, 28.33558083], [75.95143127, 28.33349991], [75.95449066, 28.32870865], [75.95466614, 28.31853104], [75.96762848, 28.32409286], [75.97470856, 28.31586075], [75.97933197, 28.30633163], [75.98657227, 28.29589081], [75.99124146, 28.29519081], [76.01872253, 28.28095818], [76.00740051, 28.25315285], [76.01119232, 28.24175072], [76.02577972, 28.23591995], [76.03634644, 28.22710991], [76.05300903, 28.22422981], [76.05227661, 28.21443939], [76.04975128, 28.20983124], [76.04382324, 28.20549011], [76.04506683, 28.20293045], [76.05665588, 28.201231], [76.06561279, 28.19894981], [76.06929779, 28.19425011], [76.07157135, 28.17922974], [76.07480621, 28.17242813], [76.08042908, 28.16810989], [76.09288788, 28.15521812], [76.09287262, 28.15162086], [76.09179688, 28.14641953], [76.0879364, 28.14353943], [76.08319855, 28.14225006], [76.07491302, 28.14195061], [76.06505585, 28.14447021], [76.0636673, 28.1498909], [76.0654068, 28.15564919], [76.06635284, 28.16777039], [76.06072998, 28.169981], [76.02774811, 28.17272186], [76.0161972, 28.16107941], [76.01119995, 28.15767288], [76.00602722, 28.15656281], [75.99975586, 28.15644073], [75.99466705, 28.15060043], [75.99571991, 28.13532066], [75.99429321, 28.13111115], [75.99111176, 28.12817955], [75.97706604, 28.12720108], [75.96761322, 28.11939049], [75.95749664, 28.11555099], [75.94740295, 28.10968971], [75.94249725, 28.10563087], [75.93608856, 28.09353065], [75.95896912, 28.08406067], [75.97706604, 28.08418083], [75.98206329, 28.08022118], [75.98763275, 28.07058907], [75.97640991, 28.0589447], [75.97458649, 28.0570507], [75.97740936, 28.05220032], [75.98455048, 28.0507412], [75.99106598, 28.0564518], [75.99762726, 28.05746841], [75.99957275, 28.0589447], [76.00192261, 28.06073189], [76.01242828, 28.07635117], [76.01486206, 28.08107948], [76.01564789, 28.08885193], [76.03121185, 28.08389282], [76.03420258, 28.07995033], [76.03562927, 28.07398033], [76.0331192, 28.0686512], [76.02229309, 28.06230927], [76.01924133, 28.0589447], [76.01667023, 28.05611038], [76.00535583, 28.0545311], [76.00995636, 28.04990959], [76.01088715, 28.04704094], [76.01007843, 28.03671074], [75.99105072, 28.03991127], [75.9805069, 28.03870964], [75.9743576, 28.03693962], [75.96998596, 28.03094864], [75.97083282, 28.02375031], [75.97267914, 28.01814079], [75.97915649, 28.01545906], [75.98581696, 28.01474953], [75.99053955, 28.01017189], [75.98911285, 28.00432968], [75.97988892, 28.00145149], [75.97226715, 28.00134087], [75.96687317, 28.00222969], [75.96452332, 28.00266075], [75.96051788, 28.00209999], [75.95639801, 28.00102043], [75.95527649, 27.99418068], [75.95546722, 27.98863983], [75.9656601, 27.98657036], [75.97316742, 27.98396111], [75.98207855, 27.98698044], [75.98690796, 27.98463058], [75.98647308, 27.98110962], [75.98182678, 27.97831154], [75.97384644, 27.96993828], [75.96833038, 27.96231079], [75.97319794, 27.95800018], [75.96317291, 27.93695068], [75.95394897, 27.93943977], [75.9446106, 27.94008827], [75.94169617, 27.94634056], [75.93850708, 27.95109177], [75.92858887, 27.94174957], [75.92362213, 27.93309021], [75.9287796, 27.92648125], [75.92883301, 27.91680908], [75.94174957, 27.91908073], [75.95588684, 27.91954994], [75.96753693, 27.91537094], [75.97738647, 27.9092598], [75.96724701, 27.89931107], [75.97518921, 27.8930912], [75.97280121, 27.88537979], [75.97345734, 27.87745285], [75.96425629, 27.87150955], [75.96308136, 27.86473083], [75.97544861, 27.86462975], [75.98427582, 27.86286926], [75.99447632, 27.86091995], [75.99662018, 27.86016846], [76.00524902, 27.85744095], [76.00930786, 27.86260986], [76.0207901, 27.85752106], [76.02961731, 27.85388947], [76.03383636, 27.85418129], [76.03839874, 27.85250092], [76.04368591, 27.84885025], [76.04962921, 27.84786034], [76.05478668, 27.8518219], [76.06002808, 27.85717964], [76.08009338, 27.8510704], [76.08476257, 27.85639], [76.08563995, 27.86522293], [76.0880661, 27.86844826], [76.09577179, 27.8647995], [76.10334778, 27.86237907], [76.11258698, 27.85858154], [76.12213898, 27.85440063], [76.12845612, 27.84692192], [76.12822723, 27.83784103], [76.12776947, 27.83320045], [76.14267731, 27.82783127], [76.15319061, 27.82129288], [76.1628418, 27.81484032], [76.16734314, 27.80914116], [76.17292023, 27.80746078], [76.18041992, 27.81241035], [76.18624115, 27.81904984], [76.1904068, 27.82676125], [76.19412994, 27.83121109], [76.20054626, 27.82891083], [76.20773315, 27.82849121], [76.21380615, 27.8325882], [76.22328186, 27.84093094], [76.21063232, 27.84481812], [76.20594788, 27.84799004], [76.2050705, 27.85552025], [76.19895172, 27.85967064], [76.1931076, 27.86391258], [76.19135284, 27.86942863], [76.18901062, 27.87636948], [76.19032288, 27.88157845], [76.19444275, 27.88394165], [76.19975281, 27.88809967], [76.20012665, 27.8923111], [76.19863892, 27.89899063], [76.19095612, 27.90269089], [76.18261719, 27.90507126], [76.17516327, 27.90710068], [76.1697464, 27.90974998], [76.16645813, 27.91506958], [76.16607666, 27.92098999], [76.16765594, 27.92835045], [76.17037201, 27.93329048], [76.17476654, 27.94124985], [76.17636871, 27.94831085], [76.17693329, 27.95506096], [76.17629242, 27.96105957], [76.17817688, 27.96747017], [76.17946625, 27.97284126], [76.17421722, 27.97521019], [76.16703796, 27.97915268], [76.16098022, 27.98010063], [76.16246796, 27.98830986], [76.15386963, 27.99253082], [76.15493774, 27.99899101], [76.15872192, 28.00455093], [76.16938782, 28.01685905], [76.174263, 28.02190971], [76.1795578, 28.02329254], [76.1838913, 28.0235405], [76.19068146, 28.02141953], [76.19587708, 28.02173805], [76.20038605, 28.02567101], [76.20346069, 28.03036118], [76.21382904, 28.03168106], [76.21356201, 28.04018021], [76.2041626, 28.04224968], [76.19818115, 28.03494835], [76.19342804, 28.03523064], [76.18318176, 28.04302025], [76.17688751, 28.04895973], [76.17545319, 28.05425072], [76.17722321, 28.0589447], [76.17733765, 28.05925941], [76.19284821, 28.05981064], [76.19991302, 28.06075096], [76.20363617, 28.05952072], [76.20431519, 28.0589447], [76.20833588, 28.05556107], [76.22593689, 28.05518913], [76.23336792, 28.05642128], [76.23542786, 28.0589447], [76.24356842, 28.06893921], [76.25109863, 28.07092094], [76.2649231, 28.06874084], [76.27178955, 28.06638908], [76.28200531, 28.0589447], [76.29007721, 28.04911041], [76.28811646, 28.04204941], [76.29012299, 28.0298996], [76.29715729, 28.02596092], [76.31659698, 28.02099037], [76.32367706, 28.02384186], [76.32995605, 28.02487946], [76.33679962, 28.02966118], [76.34126282, 28.0360508], [76.34591675, 28.04578972], [76.35081482, 28.0589447], [76.35328674, 28.06557274], [76.354599, 28.07420158], [76.35048676, 28.07578087], [76.34436798, 28.07386971], [76.33734894, 28.07306099], [76.33213806, 28.07678986], [76.33126831, 28.08164978], [76.32879639, 28.08776093], [76.32488251, 28.09215927], [76.32054901, 28.09431267], [76.31344604, 28.09467125], [76.30716705, 28.09645271], [76.29740143, 28.10104942], [76.30132294, 28.10620117], [76.30802917, 28.11128044], [76.31417847, 28.11212921], [76.33188629, 28.10671806], [76.3395462, 28.10969925], [76.34350586, 28.11321831], [76.35560608, 28.12845039], [76.34934235, 28.13215065], [76.34321594, 28.13277054], [76.33759308, 28.13484764], [76.33100891, 28.13896942], [76.32274628, 28.14921761], [76.31732941, 28.15306091], [76.31111908, 28.15467072], [76.30821228, 28.15088081], [76.30155945, 28.15100098], [76.29590607, 28.15467072], [76.29506683, 28.15705109], [76.29846954, 28.15944862], [76.29852295, 28.16254807], [76.2930069, 28.16527939], [76.27818298, 28.16857147], [76.2767868, 28.17276001], [76.27906799, 28.17872047], [76.28885651, 28.1826725], [76.29802704, 28.18287086], [76.30496216, 28.18386078], [76.30871582, 28.18336105], [76.32595825, 28.17743111], [76.33590698, 28.17734146], [76.34259796, 28.17393112], [76.3532486, 28.1661911], [76.35597229, 28.1597805], [76.35740662, 28.14785194], [76.35983276, 28.14338112], [76.37677002, 28.13807106], [76.3840332, 28.13986015], [76.38851166, 28.13952065], [76.39302826, 28.14105034], [76.39704132, 28.14779282], [76.4122467, 28.1474781], [76.42729187, 28.14594078], [76.43135834, 28.14757156], [76.43712616, 28.15215111], [76.45604706, 28.15142822], [76.46109009, 28.15237045], [76.46517944, 28.15561104], [76.47099304, 28.15474129], [76.47233582, 28.14960098], [76.46996307, 28.13850021], [76.47319031, 28.13573074], [76.47722626, 28.13467026], [76.48329163, 28.13484764], [76.48509216, 28.13490105], [76.48972321, 28.13367844], [76.48574066, 28.12812042], [76.4868927, 28.12281036], [76.49809265, 28.12253952], [76.49729156, 28.11597824], [76.49780273, 28.10662079], [76.48874664, 28.10473061], [76.47728729, 28.10598946], [76.47254181, 28.11271095], [76.4662323, 28.11297035], [76.46092987, 28.11190033], [76.45688629, 28.11038971], [76.4539032, 28.10589027], [76.45121765, 28.09766006], [76.44857025, 28.09317017], [76.45343018, 28.08778954], [76.45881653, 28.08500099], [76.46360779, 28.0840683], [76.46988678, 28.08632088], [76.48590088, 28.07512093], [76.49537659, 28.0676403], [76.49765778, 28.0647316], [76.49453735, 28.0610714], [76.48957825, 28.05924034], [76.48780823, 28.0589447], [76.48381805, 28.05828094], [76.48087311, 28.0589447], [76.47129822, 28.06110954], [76.45797729, 28.06197166], [76.45624542, 28.0589447], [76.4540329, 28.05507278], [76.45372772, 28.04966927], [76.45574188, 28.04648018], [76.46170044, 28.04457283], [76.47570801, 28.04405975], [76.48307037, 28.0463295], [76.49221802, 28.04709816], [76.49604797, 28.04364014], [76.49848938, 28.04018021], [76.49949646, 28.03635979], [76.50522614, 28.03503036], [76.51140594, 28.03536034], [76.51859283, 28.03896141], [76.52585602, 28.0454483], [76.53124237, 28.0431118], [76.53852081, 28.03911972], [76.53553009, 28.02571106], [76.53855133, 28.01670074], [76.53862, 28.01206017], [76.53774261, 28.00751114], [76.53845215, 28.00537109], [76.53640747, 28.00473022], [76.53553772, 27.99306107], [76.53193665, 27.98570061], [76.53103638, 27.97932816], [76.53350067, 27.97372818], [76.53819275, 27.970541], [76.54659271, 27.9713707], [76.55343628, 27.9750309], [76.55979156, 27.98178291], [76.56749725, 27.98357964], [76.57382965, 27.98901939], [76.57727051, 27.99487114], [76.58381653, 28.0003109], [76.59175873, 28.00365829], [76.59523773, 28.00614929], [76.59896851, 28.00984001], [76.60389709, 28.01079178], [76.6159668, 28.0112896], [76.62534332, 28.01046944], [76.63687897, 28.01066017], [76.64671326, 28.01262093], [76.65455627, 28.01556969], [76.66007233, 28.0190506], [76.66240692, 28.02294159], [76.66146088, 28.0293026], [76.65962219, 28.03367043], [76.65341949, 28.03992081], [76.65099335, 28.0444603], [76.65162659, 28.05548286], [76.6501236, 28.0589447], [76.64892578, 28.06171036], [76.64792633, 28.06767082], [76.64804077, 28.07908058], [76.64697266, 28.08510971], [76.64785004, 28.09221077], [76.65122986, 28.0967598], [76.6579895, 28.0990715], [76.6639328, 28.0978508], [76.67790985, 28.09781075], [76.68218231, 28.09777069], [76.68564606, 28.10688019], [76.6894989, 28.1135006], [76.69024658, 28.11478996], [76.69494629, 28.11529922], [76.69876099, 28.11571121], [76.70543671, 28.12772751], [76.708992, 28.13138008], [76.70996094, 28.13236046], [76.720047, 28.13153076], [76.7315979, 28.12845039], [76.73295593, 28.12857246], [76.73912811, 28.12903976], [76.75508118, 28.14661026], [76.76216888, 28.1500206], [76.77294159, 28.15142059], [76.7830658, 28.1556797], [76.79148865, 28.15724182], [76.79614258, 28.17048073], [76.79228973, 28.17566109], [76.79225922, 28.18292046], [76.79025269, 28.19375992], [76.79309845, 28.19832993], [76.79384613, 28.19955063], [76.79788971, 28.19437981], [76.8026123, 28.19607162], [76.80560303, 28.20038033], [76.80246735, 28.20463181], [76.80136871, 28.21160126], [76.80580902, 28.21589088], [76.81323242, 28.21631241], [76.8189621, 28.21469116], [76.82382965, 28.2147007], [76.82724762, 28.21749115], [76.83342743, 28.2248497], [76.85048676, 28.22666931], [76.8543396, 28.22524071], [76.85772705, 28.22317123], [76.8636322, 28.22463989], [76.86580658, 28.21795845], [76.86618042, 28.21152115], [76.8792572, 28.21038055], [76.88668823, 28.21049118], [76.89668274, 28.20763016], [76.89984894, 28.20476913], [76.88574219, 28.1967411], [76.88387299, 28.19473076], [76.88404846, 28.19165993], [76.89009094, 28.18782806], [76.8991394, 28.17932129], [76.91204834, 28.17185974], [76.92105103, 28.16225052], [76.92753601, 28.15891266], [76.93781281, 28.15534973], [76.94156647, 28.15517044], [76.94052887, 28.15092087], [76.94174194, 28.14870071], [76.95654297, 28.14600945], [76.96176147, 28.14401054], [76.95582581, 28.12371826], [76.955513, 28.11174965], [76.95107269, 28.09608841], [76.94806671, 28.0786705], [76.94655609, 28.07134056], [76.94252777, 28.06682014], [76.93802643, 28.05961037], [76.93777466, 28.0589447], [76.93364716, 28.04813004], [76.93186188, 28.04202271], [76.93074036, 28.03050041], [76.92658234, 28.01250076], [76.92163086, 28.00568962], [76.91864777, 27.99761009], [76.9223175, 27.9858284], [76.92492676, 27.97836113], [76.92276764, 27.96577072], [76.91954041, 27.95283127], [76.91909027, 27.94082069], [76.9190979, 27.92486], [76.92127991, 27.92105293], [76.92993927, 27.92136002], [76.93881989, 27.91902924], [76.93673706, 27.90754128], [76.93817902, 27.89599037], [76.92608643, 27.89442062], [76.92610931, 27.88837051], [76.9247818, 27.876791], [76.92829895, 27.86713028], [76.92990875, 27.85523033], [76.92809296, 27.84398079], [76.92664337, 27.83422089], [76.92193604, 27.83183098], [76.91499329, 27.83461952], [76.90788269, 27.83591843], [76.90377808, 27.83266068], [76.90106964, 27.82541847], [76.900383, 27.82114983], [76.90524292, 27.81255913], [76.90660095, 27.80765915], [76.90280151, 27.80128098], [76.90392303, 27.79488945], [76.89865112, 27.79108047], [76.89560699, 27.78614044], [76.89363861, 27.7792511], [76.89232635, 27.77203178], [76.8914032, 27.76119041], [76.89060974, 27.74201965], [76.88786316, 27.73721123], [76.88407898, 27.73090935], [76.88334656, 27.72442245], [76.88854218, 27.71955109], [76.89539337, 27.71850967], [76.90278625, 27.7164402], [76.90830994, 27.71208954], [76.91220093, 27.70610046], [76.91456604, 27.70082092], [76.91036224, 27.69664955], [76.90600586, 27.69584084], [76.9003067, 27.69462967], [76.89350891, 27.69826126], [76.88802338, 27.70167923], [76.88284302, 27.70337105], [76.88092041, 27.69936943], [76.88311768, 27.69549942], [76.8886261, 27.69284058], [76.89473724, 27.68965912], [76.89673615, 27.68596077], [76.89401245, 27.68333054], [76.89164734, 27.67988968], [76.89322662, 27.67687988], [76.89715576, 27.67243004], [76.90009308, 27.66803932], [76.90052795, 27.6634407], [76.90262604, 27.65851974], [76.90540314, 27.65596962], [76.90947723, 27.65680122], [76.91382599, 27.65960121], [76.91899109, 27.66148186], [76.92385101, 27.66073036], [76.92684174, 27.66543007], [76.93028259, 27.67170906], [76.93419647, 27.67510033], [76.93844604, 27.67366982], [76.94478607, 27.67057037], [76.95153809, 27.66625023], [76.96022797, 27.66242027], [76.97049713, 27.65714264], [76.97033691, 27.66545105], [76.97229767, 27.67287064], [76.97312927, 27.68042183], [76.97608185, 27.69285011], [76.97910309, 27.70615959], [76.98277283, 27.71850014], [76.98744965, 27.72928047], [76.98912811, 27.73377991], [76.9913559, 27.73642921], [76.9935379, 27.74170113], [76.99437714, 27.74204254], [77.00099182, 27.73851967], [77.00337219, 27.73855019], [77.00502014, 27.73913956], [77.01140594, 27.74651909], [77.01680756, 27.74776077], [77.02485657, 27.74712944], [77.02894592, 27.74937057], [77.03196716, 27.74841118], [77.03649902, 27.74462128], [77.0393219, 27.7415905], [77.0402832, 27.73835945], [77.04271698, 27.73590279], [77.04427338, 27.73224068], [77.05065918, 27.72811127], [77.0532074, 27.7278595], [77.05944824, 27.73135948], [77.06572723, 27.73241043], [77.07113647, 27.73574066], [77.07797241, 27.73734093], [77.079216, 27.73841095], [77.07943726, 27.74019051], [77.07840729, 27.74287987], [77.07253265, 27.74909973], [77.07118988, 27.75192261], [77.0707016, 27.75884056], [77.06733704, 27.76375961], [77.06181335, 27.76568985], [77.05603027, 27.7643795], [77.05422974, 27.76189995], [77.05010223, 27.76104164], [77.04692841, 27.76798058], [77.03943634, 27.77490044], [77.02841187, 27.78029823], [77.02672577, 27.77791023], [77.024086, 27.77700996], [77.02276611, 27.77794838], [77.02066803, 27.77812004], [77.0197525, 27.78032112], [77.0230484, 27.78718948], [77.02398682, 27.79817009], [77.03038025, 27.81142998], [77.03457642, 27.81252289], [77.03539276, 27.81410027], [77.03504944, 27.81666183], [77.03827667, 27.82004166], [77.04514313, 27.81698036], [77.04682159, 27.81809044], [77.05182648, 27.81516075], [77.05625153, 27.81146049], [77.06529236, 27.81258011], [77.06848145, 27.81157112], [77.07241058, 27.80952072], [77.07427216, 27.80435181], [77.07663727, 27.8014698], [77.08023071, 27.80039024], [77.09362793, 27.78970146], [77.10116577, 27.78549194], [77.10263062, 27.78518105], [77.10748291, 27.78665924], [77.11476898, 27.78988075], [77.11741638, 27.79019165], [77.11997223, 27.78947067], [77.12210846, 27.7883091], [77.12467194, 27.78483963], [77.12520599, 27.77693176], [77.12652588, 27.77646065], [77.13535309, 27.78395081], [77.14142609, 27.78623009], [77.14727783, 27.78665924], [77.15142822, 27.79181099], [77.15329742, 27.79785919], [77.15354156, 27.80243111], [77.14972687, 27.81243134], [77.15061951, 27.81555939], [77.15209961, 27.8157711], [77.15666199, 27.81360054], [77.16108704, 27.81318855], [77.17237854, 27.81632042], [77.1758728, 27.81445122], [77.18065643, 27.80865288], [77.18044281, 27.80443192], [77.17814636, 27.80252075], [77.16924286, 27.80056953], [77.16660309, 27.79591942], [77.16216278, 27.79059029], [77.16400909, 27.78691101], [77.16870117, 27.78490067], [77.17556, 27.78722191], [77.18894196, 27.79842949], [77.18659973, 27.81048012], [77.18747711, 27.81504822], [77.19384766, 27.82193947], [77.19676208, 27.81944084], [77.20210266, 27.81257057], [77.20571136, 27.80548096], [77.20677185, 27.80105972], [77.21684265, 27.7954998], [77.22215271, 27.79764938], [77.22685242, 27.79610062], [77.22870636, 27.79310036], [77.22724915, 27.78865814], [77.23174286, 27.78580093], [77.23455811, 27.78581047], [77.24088287, 27.7903595], [77.24794769, 27.79375076], [77.25284576, 27.79763985], [77.25699615, 27.80525017], [77.25805664, 27.80929947], [77.26249695, 27.81611061], [77.26748657, 27.81196022], [77.27577972, 27.80654907], [77.27932739, 27.80280113], [77.29064178, 27.80170059], [77.29538727, 27.79984093], [77.29794312, 27.79785919], [77.30110931, 27.79368019], [77.30414581, 27.78800964], [77.30368805, 27.77598], [77.3014679, 27.77170944], [77.30152893, 27.76896095], [77.30296326, 27.76465034], [77.30280304, 27.76119041], [77.30169678, 27.76006126], [77.30134583, 27.75645828], [77.305336, 27.74922943], [77.30599976, 27.74469948], [77.30966949, 27.74278831], [77.31210327, 27.74017143], [77.31233215, 27.73867989], [77.31067657, 27.73686981], [77.29634094, 27.72982979], [77.29760742, 27.71868134], [77.30235291, 27.71321106], [77.30845642, 27.71390915], [77.31725311, 27.71124077], [77.32034302, 27.71268272], [77.32447815, 27.71319008], [77.33053589, 27.71113968], [77.3339386, 27.70792007], [77.33444214, 27.69948959], [77.33654785, 27.69618034], [77.33679199, 27.68546295], [77.33500671, 27.68142128], [77.33746338, 27.67580986], [77.33716583, 27.6696701], [77.33934784, 27.66242027], [77.34276581, 27.65720177], [77.3423233, 27.6530304], [77.33233643, 27.6377697], [77.31321716, 27.61732101], [77.31121063, 27.61169052], [77.32578278, 27.59687805], [77.32811737, 27.59604073], [77.33516693, 27.60153008], [77.35011292, 27.59340096], [77.3483963, 27.59012032], [77.3434906, 27.58550262], [77.33838654, 27.57660294], [77.33306122, 27.57604027], [77.33109283, 27.57344055], [77.33039856, 27.57110977], [77.33120728, 27.56862831], [77.33067322, 27.56375122], [77.33357239, 27.55459023], [77.33843994, 27.54964256], [77.34015656, 27.54673958], [77.33545685, 27.54170036], [77.33252716, 27.53854942], [77.33513641, 27.53002167], [77.34026337, 27.52477264], [77.35222626, 27.51997948], [77.35816956, 27.51947975], [77.36122894, 27.51851082], [77.37619019, 27.51860046], [77.38241577, 27.51655006], [77.38326263, 27.51148987], [77.38955688, 27.50542259], [77.39202881, 27.50204277], [77.39155579, 27.49356079], [77.39234924, 27.48610115], [77.39359283, 27.48194122], [77.39642334, 27.47780991], [77.40738678, 27.47636986], [77.41136932, 27.47269058], [77.41545105, 27.46614075], [77.42543793, 27.46480942], [77.42959595, 27.46204948], [77.42878723, 27.45545959], [77.42727661, 27.45100975], [77.42295074, 27.44943047], [77.42073059, 27.44729042], [77.41828156, 27.4421711], [77.41703033, 27.43824005], [77.41517639, 27.42537117], [77.42508698, 27.41887283], [77.42677307, 27.41661072], [77.42999268, 27.4050293], [77.4295578, 27.4043808], [77.4318924, 27.39915848], [77.43578339, 27.39678955], [77.44326019, 27.39332962], [77.461586, 27.38759041], [77.46660614, 27.3842907], [77.47586823, 27.38772964], [77.48696136, 27.38562965], [77.49724579, 27.38136292], [77.50219727, 27.37735939], [77.50385284, 27.37405968], [77.50802612, 27.37278175], [77.50936127, 27.36782074], [77.51567841, 27.36273003], [77.52200317, 27.35763931], [77.53074646, 27.35276985], [77.53539276, 27.35293961], [77.53909302, 27.35307121], [77.5404129, 27.34758949], [77.5427475, 27.34242821], [77.56173706, 27.33543968], [77.56671906, 27.33361053], [77.56777191, 27.33323097], [77.57273865, 27.33008957], [77.57454681, 27.32673073], [77.58043671, 27.32845116], [77.58229828, 27.33163071], [77.58661652, 27.33527184], [77.5929718, 27.3379612], [77.60481262, 27.33794975], [77.60753632, 27.34215927], [77.61036682, 27.34439278], [77.61411285, 27.34338951], [77.61634064, 27.33831024], [77.61559296, 27.33453941], [77.61553192, 27.32541084], [77.6135025, 27.31476021], [77.60887909, 27.3119297], [77.603302, 27.30992126], [77.6000824, 27.30470085], [77.59702301, 27.30470085], [77.59172821, 27.30273056], [77.59166718, 27.30055809], [77.59832764, 27.29635048], [77.60307312, 27.29487991], [77.60909271, 27.28799057], [77.60935211, 27.28166962], [77.61414337, 27.27916145], [77.61125183, 27.27433968], [77.60661316, 27.2727108], [77.60900116, 27.2650795], [77.61284637, 27.26030159], [77.62329865, 27.26382065], [77.62581635, 27.26234055], [77.62957764, 27.25549126], [77.6342392, 27.25368118], [77.63890839, 27.24714088], [77.63913727, 27.24712944], [77.63800812, 27.24253845], [77.63839722, 27.24065018], [77.64420319, 27.23887825], [77.64318085, 27.23180962], [77.6394577, 27.22323036], [77.63951874, 27.2172718], [77.64202881, 27.21476936], [77.64778137, 27.21454811], [77.65500641, 27.21178055], [77.65664673, 27.21302032], [77.66719055, 27.20709991], [77.67299652, 27.20036125], [77.67199707, 27.19506073], [77.6654129, 27.1861496], [77.66124725, 27.18278122], [77.65461731, 27.17558098], [77.64334106, 27.17440033], [77.63591766, 27.17012978], [77.63079834, 27.17020988], [77.6282959, 27.17312241], [77.6254425, 27.17436028], [77.62252045, 27.1749897], [77.61480713, 27.17478943], [77.6051178, 27.16847992], [77.60407257, 27.16431999], [77.6059494, 27.15890121], [77.60653687, 27.15414047], [77.59807587, 27.14800072], [77.59365845, 27.14795113], [77.59210968, 27.14476967], [77.59239197, 27.14011955], [77.59591675, 27.13721085], [77.59455109, 27.13368034], [77.59726715, 27.12905121], [77.59567261, 27.12615967], [77.59078217, 27.12308121], [77.58587646, 27.12424088], [77.58342743, 27.12068176], [77.57466888, 27.1221199], [77.55612183, 27.11581993], [77.54576874, 27.11512947], [77.54444885, 27.11560059], [77.53948212, 27.11125946], [77.53209686, 27.10968971], [77.52937317, 27.10414124], [77.52082062, 27.1058197], [77.51383972, 27.10808945], [77.50821686, 27.1028595], [77.50231934, 27.09922028], [77.49903107, 27.09584045], [77.49841309, 27.09519005], [77.49938965, 27.09398079], [77.51100159, 27.09391975], [77.51474762, 27.09189987], [77.51377869, 27.09137917], [77.51738739, 27.08949089], [77.51822662, 27.0880928], [77.51773834, 27.0797596], [77.51468658, 27.07406044], [77.51429749, 27.07042122], [77.52136993, 27.0672226], [77.52654266, 27.06650925], [77.52915955, 27.06711006], [77.53366089, 27.06981087], [77.54139709, 27.07739067], [77.54631805, 27.08073044], [77.55422974, 27.07722092], [77.56324005, 27.07862282], [77.56568146, 27.07801056], [77.5684433, 27.07248116], [77.56572723, 27.06903076], [77.56694031, 27.06632042], [77.56680298, 27.06026077], [77.56523895, 27.05397987], [77.56112671, 27.05157089], [77.55893707, 27.04878998], [77.55739594, 27.03689957], [77.56067657, 27.03565025], [77.56820679, 27.03932953], [77.57509613, 27.04157066], [77.58392334, 27.03931999], [77.58875275, 27.03705978], [77.59059143, 27.03166008], [77.5943222, 27.03119087], [77.59881592, 27.02882957], [77.6034317, 27.02909279], [77.61559296, 27.02739906], [77.61949921, 27.02490807], [77.62201691, 27.02186966], [77.62425232, 27.01689911], [77.62740326, 27.01550102], [77.63092041, 27.0234108], [77.63426208, 27.02701187], [77.64334106, 27.02719116], [77.65196991, 27.02257919], [77.6570282, 27.02273178], [77.6598587, 27.02503967], [77.66329956, 27.03030968], [77.67076874, 27.0489006], [77.67331696, 27.05155945], [77.67816925, 27.05052948], [77.68430328, 27.04491997], [77.68486023, 27.0398407], [77.68202209, 27.03294182], [77.69374084, 27.01951981], [77.69567108, 27.01605034], [77.69661713, 27.00695038], [77.69896698, 27.0057106], [77.70358276, 27.0003109], [77.70858002, 27.00110245], [77.71392059, 26.99796104], [77.71761322, 27.00002098], [77.72231293, 27.00033951], [77.72336578, 27.00390816], [77.72104645, 27.00570107], [77.7201767, 27.01404953], [77.72216034, 27.02614021], [77.72648621, 27.03153992], [77.7355423, 27.033741], [77.73840332, 27.03268051], [77.73935699, 27.0275898], [77.74085236, 27.02552032], [77.74389648, 27.02374077], [77.75311279, 27.02363014], [77.75501251, 27.02276039], [77.74768066, 27.01762962], [77.74529266, 27.01336098], [77.74616241, 27.01086044], [77.74546051, 27.00868988], [77.74254608, 27.00634956], [77.74246216, 27.00570107], [77.74607849, 27.00294113], [77.74771118, 26.99850082], [77.74336243, 26.99765968], [77.73969269, 26.9979496], [77.73900604, 26.99106026], [77.73634338, 26.98822021], [77.72328186, 26.98823929], [77.71459198, 26.99166107], [77.70992279, 26.98769951], [77.70123291, 26.98431969], [77.69191742, 26.97899246], [77.67028046, 26.97710991], [77.66861725, 26.96917915], [77.66529846, 26.96692085], [77.65960693, 26.96808052], [77.65660858, 26.97406006], [77.65260315, 26.97494125], [77.64894104, 26.9738102], [77.64227295, 26.96730042], [77.60482788, 26.94595909], [77.59812927, 26.94026947], [77.59379578, 26.93770981], [77.59176636, 26.94398117], [77.58744812, 26.94454956], [77.5847702, 26.94227028], [77.57975006, 26.93087006], [77.55735779, 26.92603111], [77.5453186, 26.92204094], [77.51856995, 26.91547966], [77.49584198, 26.90578079], [77.48246765, 26.90377998], [77.47377777, 26.89978981], [77.46478271, 26.89266014], [77.45517731, 26.8895607], [77.455513, 26.88043976], [77.45417786, 26.8767395], [77.45052338, 26.87501144], [77.44182587, 26.87759018], [77.43650818, 26.8678875], [77.4318161, 26.8658905], [77.42648315, 26.8670311], [77.42247009, 26.86701965], [77.42347717, 26.85762024], [77.42616272, 26.85305977], [77.4214859, 26.84877968], [77.4174881, 26.8427906], [77.4228363, 26.83680916], [77.42584991, 26.83567047], [77.42719269, 26.8316803], [77.43421173, 26.82541084], [77.43921661, 26.81915092], [77.43824005, 26.80887985], [77.43192291, 26.79235077], [77.42858887, 26.78578949], [77.42726898, 26.77609253], [77.4285965, 26.77011108], [77.43428802, 26.77239037], [77.43894196, 26.77581024], [77.44528198, 26.77753067], [77.45095062, 26.78067017], [77.45597076, 26.78038025], [77.46431732, 26.76955032], [77.46166992, 26.76584816], [77.45730591, 26.76214027], [77.44831085, 26.74674988], [77.48036194, 26.75387955], [77.48635864, 26.76101112], [77.49334717, 26.76699066], [77.49668884, 26.77411079], [77.48932648, 26.77724838], [77.48432159, 26.78239059], [77.48098755, 26.78779984], [77.48232269, 26.7940712], [77.48664856, 26.80120087], [77.48932648, 26.80861092], [77.49698639, 26.83797073], [77.49797821, 26.84794998], [77.50197601, 26.84653091], [77.50666809, 26.84738159], [77.51367188, 26.84510231], [77.51535034, 26.84140015], [77.51233673, 26.83826065], [77.5120163, 26.82798958], [77.51435852, 26.8245697], [77.52069092, 26.82200813], [77.52838135, 26.8245697], [77.5357132, 26.82542992], [77.54740906, 26.82172012], [77.55641937, 26.82199097], [77.56476593, 26.82456017], [77.5687561, 26.82741165], [77.57211304, 26.83196068], [77.57746887, 26.83310127], [77.5881424, 26.83337975], [77.59615326, 26.84165192], [77.60016632, 26.84250069], [77.60083771, 26.83423042], [77.60450745, 26.83280182], [77.60853577, 26.8345108], [77.61186218, 26.83964157], [77.61319733, 26.84446907], [77.61620331, 26.84847069], [77.62487793, 26.84674835], [77.65730286, 26.85641098], [77.66462708, 26.85984039], [77.66697693, 26.86238289], [77.67166901, 26.87407112], [77.67468262, 26.87462997], [77.67835236, 26.87832069], [77.68235016, 26.87916946], [77.68636322, 26.87832069], [77.68937683, 26.87347031], [77.69371796, 26.87289047], [77.69637299, 26.87659073], [77.69773102, 26.8800106], [77.70540619, 26.88027954], [77.7158432, 26.88133049], [77.719841, 26.88673973], [77.72054291, 26.89301109], [77.71987915, 26.89673042], [77.71788025, 26.89958954], [77.71083832, 26.90302086], [77.71891022, 26.91641045], [77.72392273, 26.92295074], [77.72895813, 26.92580032], [77.74064636, 26.92691994], [77.74433136, 26.92321014], [77.748703, 26.9269104], [77.75337982, 26.93773842], [77.76509857, 26.93799019], [77.77348328, 26.93626976], [77.77313995, 26.9325695], [77.78148651, 26.92770958], [77.78885651, 26.92228127], [77.79588318, 26.92340088], [77.79923248, 26.92825127], [77.8052597, 26.9285202], [77.80860901, 26.92566109], [77.8146286, 26.92279053], [77.82132721, 26.92620087], [77.82633209, 26.92103958], [77.83637238, 26.9195919], [77.84104156, 26.91644096], [77.84940338, 26.91242027], [77.87146759, 26.90550041], [77.87677765, 26.89920998], [77.88214111, 26.89603996], [77.88479614, 26.89232063], [77.8901062, 26.88945961], [77.89612579, 26.88972092], [77.90083313, 26.89513969], [77.90284729, 26.90114021], [77.90090179, 26.91171265], [77.89858246, 26.91542053], [77.89692688, 26.92000008], [77.89994049, 26.9245491], [77.90661621, 26.92395973], [77.90925598, 26.92082977], [77.9082489, 26.91683006], [77.90956879, 26.9142704], [77.92189026, 26.91455078], [77.92884064, 26.91283989], [77.93212891, 26.90999985], [77.93474579, 26.9051609], [77.93769836, 26.90205002], [77.94197083, 26.89978981], [77.96295929, 26.91257095], [77.96579742, 26.91098022], [77.96481323, 26.90724945], [77.96675873, 26.90302086], [77.97062683, 26.89970016], [77.9751358, 26.89752769], [77.98027802, 26.89770126], [77.98501587, 26.90138054], [77.99188995, 26.91090012], [77.99838257, 26.90985107], [78.00666046, 26.9106617], [78.01406097, 26.90839195], [78.01629639, 26.90497971], [78.01911926, 26.89743996], [78.02171326, 26.89479065], [78.02207184, 26.89019012], [78.01756287, 26.88203049], [78.02009583, 26.87961006], [78.02793121, 26.87615013], [78.02731323, 26.87347984], [78.01635742, 26.86381912], [78.01761627, 26.86164093], [78.02202606, 26.86087036], [78.02722168, 26.86218071], [78.03114319, 26.86548233], [78.03540039, 26.8745594], [78.03755951, 26.87696266], [78.03965759, 26.87734985], [78.04589081, 26.87488174], [78.04780579, 26.87480927], [78.04772949, 26.8777504], [78.04482269, 26.88211823], [78.04429626, 26.88453102], [78.04522705, 26.90286255], [78.04223633, 26.91542053], [78.04862976, 26.91377068], [78.0524826, 26.91488266], [78.05712128, 26.91329956], [78.06053925, 26.91590118], [78.06291962, 26.91485023], [78.06788635, 26.91028023], [78.07280731, 26.90755081], [78.08682251, 26.90200806], [78.0894165, 26.90286255], [78.08992004, 26.90574837], [78.08830261, 26.90993118], [78.09104919, 26.9116497], [78.09346008, 26.91008949], [78.09861755, 26.90397263], [78.10147095, 26.90498924], [78.10276031, 26.90993118], [78.09908295, 26.92061234], [78.09662628, 26.92304039], [78.09535217, 26.92905045], [78.09866333, 26.93061066], [78.10214233, 26.93085289], [78.10630798, 26.93001175], [78.11270905, 26.92749023], [78.11431122, 26.93058014], [78.11522675, 26.93819046], [78.11305237, 26.94194984], [78.10943604, 26.94487953], [78.1079483, 26.94831085], [78.10804749, 26.9500103], [78.11134338, 26.95323181], [78.11489868, 26.95486069], [78.12706757, 26.9554882], [78.13407135, 26.95700836], [78.13947296, 26.95713043], [78.14608002, 26.95305061], [78.15265656, 26.95214081], [78.16314697, 26.95269012], [78.17373657, 26.94869041], [78.19049835, 26.94676971], [78.2012558, 26.94032288], [78.20524597, 26.93889046], [78.20826721, 26.93975258], [78.21219635, 26.94961929], [78.21589661, 26.95395088], [78.22052765, 26.94767952], [78.2233963, 26.9450798], [78.22731781, 26.94358063], [78.22940063, 26.94131088], [78.23060608, 26.93678284], [78.23274231, 26.93369293], [78.24024963, 26.93363953], [78.24733734, 26.93074989], [78.25219727, 26.9349823], [78.25831604, 26.9340229], [78.26122284, 26.93177986], [78.2617569, 26.93017006], [78.26223755, 26.92351151], [78.25953674, 26.91621971], [78.25432587, 26.90974808], [78.25267029, 26.90460968], [78.24817657, 26.90063095], [78.23249817, 26.89545822], [78.22978973, 26.89389992], [78.22657013, 26.88262939], [78.20485687, 26.87738991], [78.20053864, 26.87858009], [78.19352722, 26.88952065], [78.19113922, 26.88861084], [78.19017792, 26.88346291], [78.19689178, 26.87212181], [78.20075226, 26.86240005], [78.20448303, 26.85555077], [78.20755768, 26.85233116], [78.21395111, 26.84852028], [78.21164703, 26.83846092], [78.20979309, 26.83609009], [78.20278931, 26.83231926], [78.19210052, 26.8298111], [78.1795578, 26.83102036], [78.17327881, 26.83257103], [78.16757202, 26.83195114], [78.16355133, 26.82985115], [78.16094971, 26.82703972], [78.16340637, 26.81993103], [78.17936707, 26.80116081], [78.18044281, 26.79704094], [78.17975616, 26.79356956], [78.17611694, 26.79149246], [78.15978241, 26.79112053], [78.14581299, 26.79173088], [78.14048004, 26.79364014], [78.13131714, 26.79916954], [78.11902618, 26.80256081], [78.1129303, 26.80256081], [78.10552216, 26.80075264], [78.09983063, 26.79700851], [78.09538269, 26.78943062], [78.09442139, 26.7834301], [78.09568024, 26.77179909], [78.09709167, 26.76942062], [78.10051727, 26.76637077], [78.11104584, 26.76214027], [78.11482239, 26.75881195], [78.11605835, 26.7546196], [78.11167908, 26.74965096], [78.09600067, 26.74376106], [78.08914948, 26.73810959], [78.08676147, 26.73176956], [78.0865097, 26.72445107], [78.08898926, 26.70072174], [78.08805847, 26.68666077], [78.08573914, 26.68305016], [78.07863617, 26.68032074], [78.07537079, 26.67819023], [78.06938934, 26.67851067], [78.06511688, 26.67964172], [78.06092834, 26.68184853], [78.05622101, 26.68589973], [78.04911041, 26.68980026], [78.04312134, 26.69106293], [78.03156281, 26.69133949], [78.01920319, 26.69762039], [78.01190186, 26.70014763], [77.99221802, 26.70264053], [77.98855591, 26.69999123], [77.97572327, 26.68330193], [77.96879578, 26.67663956], [77.96053314, 26.67152977], [77.95355988, 26.66942024], [77.94789124, 26.66504097], [77.93990326, 26.66270828], [77.92391205, 26.66499138], [77.9036026, 26.66617966], [77.89457703, 26.66221046], [77.89087677, 26.65450287], [77.89015198, 26.64051819], [77.88877869, 26.63281059], [77.8793869, 26.62029076], [77.87037659, 26.61861992], [77.85144043, 26.61601067], [77.84243774, 26.61517906], [77.83409882, 26.61178017], [77.82543182, 26.60524178], [77.82041168, 26.59983826], [77.81842041, 26.59385109], [77.8243866, 26.58443069], [77.82467651, 26.57274055], [77.81765747, 26.56021118], [77.81299591, 26.55480957], [77.80430603, 26.55140114], [77.7976532, 26.55027962], [77.78299713, 26.55258942], [77.76700592, 26.55347824], [77.75801849, 26.55064964], [77.75, 26.54667091], [77.74434662, 26.54524994], [77.73935699, 26.54269028], [77.73066711, 26.52988052], [77.72698212, 26.51536179], [77.72099304, 26.50852013], [77.71398163, 26.50424957], [77.69503021, 26.50086975], [77.68598938, 26.50259018], [77.67800903, 26.5054512], [77.67102814, 26.50972939], [77.66768646, 26.50831032], [77.65470123, 26.49722099], [77.64636993, 26.49379921], [77.63938141, 26.48924065], [77.62671661, 26.48299026], [77.62007141, 26.47700119], [77.61673737, 26.47187042], [77.61538696, 26.46646118], [77.60874176, 26.45934105], [77.59908295, 26.45422173], [77.57910156, 26.45108986], [77.56912994, 26.44310951], [77.55914307, 26.44083977], [77.55148315, 26.44055939], [77.54715729, 26.4362812], [77.54250336, 26.42945099], [77.53717804, 26.4234581], [77.52986908, 26.41804123], [77.52288055, 26.41491127], [77.50591278, 26.41291046], [77.493927, 26.41357994], [77.47496796, 26.41463089], [77.45899963, 26.41119957], [77.43405151, 26.40920067], [77.42771912, 26.40690994], [77.42542267, 26.40205956], [77.42640686, 26.39550972], [77.43373871, 26.38753128], [77.43972778, 26.37869072], [77.43942261, 26.37298965], [77.43676758, 26.36814117], [77.43242645, 26.36499977], [77.41546631, 26.36811829], [77.40782166, 26.36898041], [77.40184021, 26.3686924], [77.39451599, 26.36670113], [77.38585663, 26.36242294], [77.38288879, 26.36240959], [77.37889862, 26.3638382], [77.36624908, 26.37151909], [77.36025238, 26.36952019], [77.3466568, 26.36038017], [77.33467102, 26.35723114], [77.32937622, 26.34810257], [77.32704163, 26.34724045], [77.32405853, 26.34810257], [77.31804657, 26.34638023], [77.31179047, 26.33382988], [77.30847931, 26.32155991], [77.3081665, 26.31500053], [77.28994751, 26.29559135], [77.26703644, 26.27617073], [77.25144958, 26.26703072], [77.23784637, 26.26272011], [77.20838928, 26.24423981], [77.20310974, 26.23740005], [77.19447327, 26.23597145], [77.18453217, 26.23682022], [77.17753601, 26.2390995], [77.17022705, 26.24451065], [77.16493988, 26.24450111], [77.16130066, 26.24222946], [77.15804291, 26.23852921], [77.15276337, 26.23795128], [77.1432724, 26.2382412], [77.12954712, 26.23965073], [77.12403107, 26.23795128], [77.11364746, 26.23135948], [77.10938263, 26.22507286], [77.10587311, 26.21936035], [77.10508728, 26.2091198], [77.09822083, 26.20225906], [77.09644318, 26.19544029], [77.09168243, 26.19087982], [77.0846405, 26.18717003], [77.06893921, 26.18540955], [77.05893707, 26.18535042], [77.05264282, 26.18617058], [77.04499054, 26.18494987], [77.03473663, 26.18193054], [77.02388, 26.17617035], [77.01123047, 26.16530037], [77.00773621, 26.16057968], [77.00480652, 26.15924072], [76.99968719, 26.15262985], [76.99646759, 26.14772034], [76.99447632, 26.13778114], [76.98603821, 26.13235283], [76.96856689, 26.1240406], [76.95352173, 26.11531067], [76.9418869, 26.10811043], [76.93871307, 26.1060791], [76.92897034, 26.10268021], [76.91834259, 26.10264969], [76.90631866, 26.10110092], [76.89531708, 26.09802055], [76.88777924, 26.09332275], [76.88288116, 26.0864296], [76.88223267, 26.07860947], [76.87696838, 26.07205009], [76.87255859, 26.06414986], [76.87042236, 26.05644989], [76.86392975, 26.05167961], [76.85774231, 26.0485611], [76.85176849, 26.04351044], [76.84572601, 26.04027939], [76.83809662, 26.0363903], [76.83040619, 26.02959061], [76.84024048, 26.0112896], [76.83705139, 26.00204086], [76.82962799, 25.99592972], [76.82328033, 25.99272156], [76.81984711, 25.98867989], [76.81804657, 25.98427963], [76.8188858, 25.97125053], [76.81624603, 25.96713066], [76.80631256, 25.95297813], [76.7947998, 25.9442215], [76.78591156, 25.94046974], [76.7767868, 25.93938065], [76.76065063, 25.94252968], [76.75591278, 25.94169044], [76.75356293, 25.93963051], [76.75283051, 25.93581009], [76.75344849, 25.93223953], [76.75676727, 25.92835045], [76.76278687, 25.92531013], [76.76241302, 25.92206955], [76.75563049, 25.91623116], [76.74546814, 25.90923119], [76.73332977, 25.90254974], [76.72220612, 25.90031052], [76.71452332, 25.90098953], [76.70548248, 25.9034729], [76.69645691, 25.90711021], [76.68405914, 25.91020966], [76.67436218, 25.91180038], [76.65656281, 25.91081047], [76.64612579, 25.90885162], [76.64141846, 25.90625], [76.63833618, 25.90151978], [76.6355896, 25.89592934], [76.63168335, 25.87524033], [76.62660217, 25.87087059], [76.61653137, 25.87125015], [76.59747314, 25.8764801], [76.59272766, 25.8741684], [76.58528137, 25.86771965], [76.56678009, 25.83967018], [76.54946136, 25.82504082], [76.54164886, 25.81740189], [76.53549194, 25.80917168], [76.52931213, 25.79797173], [76.5226593, 25.77434158], [76.52223969, 25.76634026], [76.53040314, 25.74374008], [76.53061676, 25.73397064], [76.52655029, 25.73104286], [76.51075745, 25.73001289], [76.50299835, 25.72860909], [76.48239136, 25.71813011], [76.4779129, 25.70603943], [76.4777832, 25.69506073], [76.48175812, 25.68939972], [76.48906708, 25.68340111], [76.50779724, 25.67612076], [76.51080322, 25.67283821], [76.4994278, 25.64834023], [76.50076294, 25.64330292], [76.50538635, 25.63821983], [76.51077271, 25.63816833], [76.51473236, 25.63367844], [76.51579285, 25.60700989], [76.50985718, 25.5872097], [76.50978088, 25.57982063], [76.51239777, 25.5717926], [76.51634216, 25.56553078], [76.52027893, 25.55690002], [76.52220917, 25.55035973], [76.52246094, 25.54146957], [76.52030945, 25.52993011], [76.52259827, 25.52429008], [76.52854919, 25.51770973], [76.53456879, 25.51350021], [76.53787231, 25.51020813], [76.54016876, 25.50573921], [76.54210663, 25.4974308], [76.54669189, 25.48968124], [76.55066681, 25.48430824], [76.55632019, 25.47981071], [76.5595932, 25.47326088], [76.56066895, 25.44985008], [76.56427765, 25.44240189], [76.5742569, 25.4366703], [76.58297729, 25.43569183], [76.58896637, 25.43148994], [76.59905243, 25.40530014], [76.60254669, 25.38898087], [76.60585022, 25.38866997], [76.60957336, 25.38830948], [76.61487579, 25.3841095], [76.61686707, 25.38161278], [76.61915588, 25.37873077], [76.62262726, 25.37675095], [76.62549591, 25.37511063], [76.6362915, 25.38033104], [76.64360046, 25.37639809], [76.65750122, 25.36144066], [76.66483307, 25.35750961], [76.6727829, 25.35003281], [76.68107605, 25.34547997], [76.70321655, 25.34761047], [76.7145462, 25.34243965], [76.72229767, 25.34592056], [76.73204803, 25.34787941], [76.74040222, 25.34778976], [76.75372314, 25.33934021], [76.7587204, 25.33869171], [76.76673126, 25.33623123], [76.76669312, 25.33296967], [76.76584625, 25.33204079], [76.76225281, 25.32798958], [76.75984192, 25.32267952], [76.77009583, 25.31219101], [76.77282715, 25.31591034], [76.79527283, 25.32182121], [76.82174683, 25.3270607], [76.82614899, 25.32698059], [76.83348083, 25.32685089], [76.83976746, 25.32928848], [76.84297943, 25.33054161], [76.85373688, 25.32971191], [76.86699677, 25.32516289], [76.87258911, 25.32427979], [76.88156891, 25.32286072], [76.89322662, 25.32240105], [76.90463257, 25.31785965], [76.91535187, 25.30898094], [76.92295837, 25.30137825], [76.92920685, 25.29729843], [76.93260956, 25.28746986], [76.92870331, 25.27915192], [76.93393707, 25.27590179], [76.94182587, 25.27536011], [76.94838715, 25.27652168], [76.95272064, 25.2785511], [76.95526886, 25.2845993], [76.9566803, 25.29142761], [76.95874023, 25.29718018], [76.99266815, 25.30183029], [77.00337219, 25.30183029], [77.01010132, 25.30154037], [77.01760101, 25.30155945], [77.02419281, 25.30109024], [77.03412628, 25.3118782], [77.03804779, 25.31936073], [77.03936005, 25.32505035], [77.04479218, 25.32245064], [77.04817963, 25.3210907], [77.0530014, 25.32069016], [77.05825806, 25.32191277], [77.0634613, 25.32415009], [77.06785583, 25.32966995], [77.07142639, 25.33584023], [77.07546997, 25.33969116], [77.08306122, 25.33980179], [77.09262848, 25.33727074], [77.10176849, 25.33512115], [77.10811615, 25.33527946], [77.11576843, 25.33506012], [77.12142181, 25.33125114], [77.12890625, 25.32541847], [77.13630676, 25.32413292], [77.14900208, 25.31536293], [77.15355682, 25.31324959], [77.16159058, 25.31365013], [77.16776276, 25.31552124], [77.17340851, 25.31517029], [77.18210602, 25.31331062], [77.19055176, 25.31166077], [77.1973877, 25.31097984], [77.20514679, 25.31142998], [77.2003479, 25.3187294], [77.19860077, 25.32464981], [77.19815826, 25.33052063], [77.20526123, 25.33304977], [77.21070099, 25.33369064], [77.2131958, 25.33175087], [77.20942688, 25.32864952], [77.21039581, 25.32447052], [77.21502686, 25.32450104], [77.21803284, 25.33131027], [77.2173996, 25.33724976], [77.21701813, 25.34925079], [77.22113037, 25.36108017], [77.22026062, 25.37342834], [77.22564697, 25.37924957], [77.23467255, 25.38506126], [77.24415588, 25.38961029], [77.24964142, 25.39491081], [77.25995636, 25.39945984], [77.27295685, 25.41200256], [77.28298187, 25.42358971], [77.29556274, 25.43169022], [77.30529785, 25.4364109], [77.31690979, 25.43284035], [77.32923126, 25.4285717], [77.33706665, 25.42475128], [77.34371185, 25.42243195], [77.35434723, 25.42402267], [77.36134338, 25.41296005], [77.35764313, 25.40928841], [77.35395813, 25.4036293], [77.3497467, 25.39838028], [77.34610748, 25.39249992], [77.34426117, 25.38792992], [77.34467316, 25.38334084], [77.34474945, 25.3798027], [77.34841919, 25.37555122], [77.3516922, 25.37235069], [77.3538208, 25.36954117], [77.35604095, 25.3678894], [77.35511017, 25.36437988], [77.34391785, 25.33736038], [77.33641815, 25.3255806], [77.34934235, 25.32413292], [77.35317993, 25.33234978], [77.3637619, 25.33300018], [77.36580658, 25.32850075], [77.36894989, 25.32464981], [77.37178802, 25.32022095], [77.37364197, 25.31549263], [77.37462616, 25.31057167], [77.37480164, 25.30585098], [77.37377167, 25.30018044], [77.37336731, 25.29936981], [77.37258911, 25.29429054], [77.36946869, 25.28852844], [77.36672211, 25.28540039], [77.36302948, 25.28375816], [77.36000061, 25.28022003], [77.34966278, 25.27177048], [77.35668182, 25.26579094], [77.3602829, 25.26085281], [77.36203766, 25.25593185], [77.36271667, 25.25007057], [77.37046814, 25.2509594], [77.3755722, 25.24902153], [77.38004303, 25.24542046], [77.39164734, 25.23114967], [77.40081787, 25.22770119], [77.40640259, 25.22629166], [77.40952301, 25.21243095], [77.41133881, 25.20659065], [77.41372681, 25.19952965], [77.41799164, 25.1930294], [77.41475677, 25.18943024], [77.4076767, 25.19005966], [77.40306091, 25.1865406], [77.39070892, 25.18819046], [77.3913269, 25.17964935], [77.39129639, 25.17469978], [77.38961029, 25.16838837], [77.38918304, 25.15994072], [77.38931274, 25.15103912], [77.38739014, 25.13809013], [77.38694, 25.13296127], [77.38861084, 25.12725067], [77.39388275, 25.12330055], [77.39810944, 25.11641121], [77.39852905, 25.11327171], [77.39554596, 25.11199951], [77.39318848, 25.11528015], [77.39227295, 25.11741066], [77.38667297, 25.12195969], [77.37516022, 25.11681938], [77.36839294, 25.11413002], [77.36850739, 25.10849953], [77.36078644, 25.10434914], [77.35714722, 25.10155106], [77.34867859, 25.09779167], [77.33244324, 25.09657097], [77.32801819, 25.09340096], [77.32038116, 25.09070969], [77.31389618, 25.08756065], [77.3098526, 25.08639145], [77.30700684, 25.08575058], [77.30285645, 25.08386993], [77.29593658, 25.08710289], [77.29133606, 25.09411049], [77.28443146, 25.10421944], [77.2755661, 25.11213112], [77.26226044, 25.11926079], [77.24164581, 25.11272049], [77.22083282, 25.11024284], [77.20581055, 25.11242104], [77.1973877, 25.11667061], [77.18876648, 25.11180115], [77.18305969, 25.11180115], [77.16957855, 25.11371994], [77.1628418, 25.10972023], [77.1645813, 25.09856987], [77.15770721, 25.08827972], [77.14045715, 25.09090042], [77.14016724, 25.09620094], [77.12827301, 25.08905029], [77.11445618, 25.06908989], [77.10249329, 25.06924057], [77.09041595, 25.06636047], [77.08426666, 25.06264114], [77.07723236, 25.05798912], [77.06801605, 25.05969048], [77.0613327, 25.06139183], [77.0549469, 25.06326294], [77.04432678, 25.0657711], [77.03929901, 25.06810951], [77.02934265, 25.07189941], [77.02472687, 25.07180023], [77.02039337, 25.07143974], [77.01764679, 25.07217026], [77.01235199, 25.07491112], [77.00595093, 25.07856941], [77.00029755, 25.07973099], [76.99372864, 25.07995033], [76.9836731, 25.07756042], [76.97466278, 25.07067108], [76.97183228, 25.06683922], [76.97126007, 25.06058121], [76.96866608, 25.05594063], [76.96131134, 25.05398941], [76.95349884, 25.0484581], [76.92987823, 25.0415802], [76.91767883, 25.04003143], [76.90976715, 25.03567123], [76.90106201, 25.03404045], [76.88202667, 25.03409958], [76.87828064, 25.02583122], [76.87671661, 25.01993942], [76.87676239, 25.01801109], [76.87680817, 25.01606178], [76.87448883, 25.01311111], [76.8693161, 25.01110268], [76.86055756, 25.01038933], [76.85434723, 25.01031113], [76.85952759, 25.00691032], [76.86805725, 25.00136948], [76.86871338, 24.99751091], [76.86965942, 24.99189186], [76.86643982, 24.97179031], [76.86727905, 24.96544075], [76.87156677, 24.96130943], [76.87336731, 24.95757294], [76.87206268, 24.95460129], [76.87520599, 24.9509697], [76.87970734, 24.94576073], [76.89322662, 24.93542099], [76.89247131, 24.9290905], [76.89015961, 24.92305946], [76.89122772, 24.91967964], [76.9074173, 24.92325974], [76.92086792, 24.91678047], [76.92353058, 24.91426086], [76.92463684, 24.91037178], [76.92032623, 24.90488052], [76.91575623, 24.90118027], [76.91269684, 24.89724159], [76.91216278, 24.89313126], [76.91385651, 24.88788033], [76.91751862, 24.88479042], [76.92176819, 24.8837204], [76.93398285, 24.88428116], [76.93572998, 24.87868118], [76.94185638, 24.87470818], [76.9432373, 24.8745594], [76.94671631, 24.87419128], [76.9489212, 24.87286949], [76.94664001, 24.86825943], [76.94425964, 24.86547279], [76.94312286, 24.86005974], [76.9332428, 24.85394096], [76.9265213, 24.84978294], [76.91506195, 24.84869957], [76.91153717, 24.84760094], [76.90843201, 24.84509277], [76.89504242, 24.83950996], [76.8780899, 24.83955193], [76.86332703, 24.84169006], [76.85748291, 24.84098053], [76.85131073, 24.84023094], [76.84217834, 24.84011269], [76.83750153, 24.84106064], [76.83164978, 24.84024239], [76.82714081, 24.83835983], [76.82308197, 24.83485031], [76.81672668, 24.83249855], [76.81118774, 24.82823944], [76.80229187, 24.82657051], [76.80066681, 24.82456017], [76.80158234, 24.81983948], [76.80410767, 24.8166008], [76.80869293, 24.81497955], [76.8157196, 24.80367088], [76.82579041, 24.79338074], [76.83587646, 24.78507042], [76.84674072, 24.76999283], [76.84702301, 24.76505089], [76.84501648, 24.75213814], [76.84729767, 24.75040054], [76.86084747, 24.74869919], [76.86812592, 24.74958038], [76.88668823, 24.75415039], [76.89692688, 24.75060081], [76.8983078, 24.74777031], [76.90325928, 24.74604988], [76.90939331, 24.74681091], [76.92169189, 24.7488308], [76.94577789, 24.76404953], [76.95173645, 24.76546097], [76.95632172, 24.76431084], [76.96330261, 24.75955009], [76.96383667, 24.75045967], [76.96533203, 24.74410057], [76.96848297, 24.73608971], [76.97197723, 24.73167038], [76.98230743, 24.72487259], [76.99214172, 24.71739769], [77.00422668, 24.71366119], [77.01407623, 24.71541977], [77.01924896, 24.71495056], [77.02265167, 24.71372032], [77.0266571, 24.71092033], [77.03346252, 24.70294952], [77.03450012, 24.69846916], [77.03491974, 24.68856049], [77.03701019, 24.6827507], [77.04894257, 24.6613102], [77.05414581, 24.65410805], [77.05945587, 24.64241982], [77.06028748, 24.63770294], [77.06112671, 24.62458992], [77.06111908, 24.61050987], [77.06034851, 24.60609055], [77.05832672, 24.6011982], [77.05845642, 24.59481049], [77.06355286, 24.5853405], [77.06469727, 24.56991005], [77.06433868, 24.56412125], [77.06153107, 24.55477905], [77.05338287, 24.54417038], [77.05195618, 24.54125023], [77.05092621, 24.53714752], [77.05030823, 24.52653122], [77.03904724, 24.5266304], [77.0319519, 24.52879906], [77.02997589, 24.52705956], [77.02910614, 24.52376175], [77.02670288, 24.5214119], [77.02478027, 24.51704979], [77.02407074, 24.50132942], [77.0206604, 24.49793053], [77.01589203, 24.49489975], [77.01233673, 24.49436951], [77.00866699, 24.4949398], [77.0059967, 24.49394989], [77.00473022, 24.49196053], [77.00496674, 24.48938942], [77.00688934, 24.48755074], [77.00255585, 24.48349953], [77.00152588, 24.47789955], [76.99819946, 24.47548294], [76.99252319, 24.47344971], [76.97966003, 24.47462845], [76.97753906, 24.47198105], [76.9749527, 24.46492958], [76.96531677, 24.46086121], [76.96016693, 24.46022987], [76.95287323, 24.46393013], [76.94108582, 24.46735001], [76.93708801, 24.47239113], [76.93083954, 24.47669983], [76.92288208, 24.48065186], [76.91464996, 24.48765945], [76.91526031, 24.51140022], [76.91734314, 24.51696968], [76.91890717, 24.52439117], [76.91877747, 24.52998161], [76.91838074, 24.53560066], [76.91568756, 24.54038048], [76.91287231, 24.54356956], [76.90238953, 24.54752159], [76.89982605, 24.5478096], [76.89776611, 24.54370117], [76.8928833, 24.53969002], [76.89359283, 24.53545952], [76.88896942, 24.5267601], [76.87954712, 24.52531052], [76.87573242, 24.52618027], [76.87290192, 24.53203964], [76.87475586, 24.54045105], [76.87413025, 24.54305077], [76.87195587, 24.54589081], [76.86620331, 24.54936028], [76.85282135, 24.55101967], [76.84604645, 24.55101967], [76.8381958, 24.54846954], [76.83114624, 24.54319], [76.82675171, 24.53878021], [76.81902313, 24.53656006], [76.81459045, 24.53437042], [76.81416321, 24.53227997], [76.81442261, 24.52964973], [76.8192215, 24.52462006], [76.82810974, 24.51036263], [76.83454895, 24.49830055], [76.83532715, 24.49438095], [76.8423233, 24.49374008], [76.84527588, 24.49090004], [76.8467865, 24.48755074], [76.84629822, 24.47545815], [76.85057831, 24.47394943], [76.85132599, 24.46910858], [76.84897614, 24.46438026], [76.84844971, 24.45876122], [76.84591675, 24.4532795], [76.83862305, 24.45416069], [76.837883, 24.45058823], [76.84117126, 24.4428196], [76.85066223, 24.43736076], [76.85109711, 24.43539047], [76.84926605, 24.42525291], [76.84603119, 24.41934013], [76.84226227, 24.4181881], [76.83769226, 24.41808128], [76.83587646, 24.41657066], [76.8423996, 24.4085083], [76.8483429, 24.39627075], [76.8501358, 24.38896942], [76.84799957, 24.37883186], [76.85231781, 24.37486839], [76.85167694, 24.37024117], [76.84906006, 24.36820984], [76.83883667, 24.36470032], [76.83696747, 24.36070824], [76.83821106, 24.35495949], [76.83888245, 24.34262276], [76.84017944, 24.33872032], [76.84490967, 24.32798195], [76.85878754, 24.31231117], [76.85980225, 24.30529022], [76.86264038, 24.29883194], [76.86380005, 24.29381943], [76.86360931, 24.28976059], [76.86705017, 24.28085136], [76.86994171, 24.27658272], [76.87419891, 24.27108955], [76.89736176, 24.24708939], [76.90389252, 24.24167824], [76.91117096, 24.23761177], [76.9164505, 24.23196983], [76.91855621, 24.22640038], [76.91928864, 24.22068977], [76.9225769, 24.21679115], [76.9282608, 24.21354103], [76.93165588, 24.20953941], [76.9368515, 24.20979118], [76.94254303, 24.20835114], [76.94444275, 24.2062912], [76.94483185, 24.20330048], [76.94386292, 24.19885063], [76.9331665, 24.18687057], [76.92723846, 24.18666077], [76.9161377, 24.1887207], [76.91487122, 24.18337059], [76.91118622, 24.17690086], [76.90579987, 24.15319252], [76.89994049, 24.13111115], [76.88625336, 24.1317482], [76.87758636, 24.13492966], [76.87657166, 24.13837814], [76.87332916, 24.13978958], [76.86628723, 24.13883018], [76.85600281, 24.13894081], [76.84607697, 24.13614082], [76.84233093, 24.13227081], [76.83547211, 24.13125038], [76.82772827, 24.12559128], [76.82183075, 24.12667274], [76.81466675, 24.12651062], [76.80111694, 24.12034035], [76.79721832, 24.12181091], [76.7909317, 24.12575912], [76.77562714, 24.15307999], [76.77308655, 24.15877914], [76.76885986, 24.16468048], [76.76261902, 24.16421127], [76.7594986, 24.16586113], [76.75733948, 24.16970253], [76.75499725, 24.17209053], [76.74938202, 24.17254066], [76.73589325, 24.17184258], [76.72939301, 24.17056084], [76.72683716, 24.16508293], [76.72071075, 24.16172028], [76.71470642, 24.16418266], [76.71247864, 24.16662979], [76.70114136, 24.17144012], [76.69519043, 24.1760006], [76.6893692, 24.18370819], [76.68438721, 24.18864059], [76.67420959, 24.19342995], [76.6767807, 24.21054077], [76.68488312, 24.22483253], [76.68778229, 24.23245049], [76.69523621, 24.24207115], [76.69876099, 24.245121], [76.70249939, 24.24880028], [76.70137024, 24.2543602], [76.69967651, 24.2578392], [76.69664764, 24.26119995], [76.69480896, 24.26781273], [76.69330597, 24.27404976], [76.69491577, 24.28231049], [76.69296265, 24.28504944], [76.68476868, 24.28269005], [76.67874908, 24.27063942], [76.67082977, 24.27100945], [76.66829681, 24.26738167], [76.65821075, 24.26781273], [76.64724731, 24.27240944], [76.64245605, 24.27011108], [76.64222717, 24.26624107], [76.64006042, 24.26231956], [76.63482666, 24.26405907], [76.63008118, 24.26470947], [76.62336731, 24.26460838], [76.61634827, 24.26284027], [76.61395264, 24.24217987], [76.610466, 24.24148941], [76.60047913, 24.24497986], [76.59324646, 24.25089073], [76.58802032, 24.2495594], [76.58747864, 24.24604988], [76.5966568, 24.2352829], [76.59738922, 24.22991943], [76.59255981, 24.22387123], [76.58586121, 24.21956062], [76.57148743, 24.21347809], [76.567276, 24.20691109], [76.56577301, 24.20079994], [76.5669632, 24.19715118], [76.56980896, 24.19628906], [76.57698822, 24.19131088], [76.57972717, 24.18067932], [76.57266998, 24.1772995], [76.56632996, 24.17645073], [76.5625, 24.1724205], [76.55475616, 24.16822052], [76.5459671, 24.16801071], [76.53985596, 24.16674995], [76.53578186, 24.16421127], [76.53143311, 24.16346931], [76.52319336, 24.1631794], [76.51737976, 24.16657829], [76.51333618, 24.1728611], [76.51048279, 24.17902946], [76.50836945, 24.20023155], [76.50538635, 24.20546913], [76.50180054, 24.20903015], [76.49693298, 24.21203995], [76.48442078, 24.21504021], [76.47941589, 24.21751022], [76.47457123, 24.22870255], [76.46994781, 24.23139954], [76.46343231, 24.22891998], [76.46102142, 24.22541046], [76.45862579, 24.22085953], [76.45324707, 24.21682167], [76.44742584, 24.21774101], [76.44184113, 24.2218895], [76.43601227, 24.22500038], [76.42945099, 24.22706032], [76.42360687, 24.22694969], [76.4181366, 24.22435951], [76.42172241, 24.2206707], [76.42253113, 24.21422005], [76.41873169, 24.20833969], [76.41443634, 24.20742035], [76.41179657, 24.20955086], [76.40009308, 24.22278976], [76.39124298, 24.22561073], [76.3735199, 24.23769951], [76.3651886, 24.24131012], [76.36120605, 24.24448967], [76.35829926, 24.24607086], [76.35299683, 24.2489109], [76.34417725, 24.25189972], [76.33499146, 24.25396919], [76.32689667, 24.25361824], [76.31787872, 24.25113106], [76.31012726, 24.24638939], [76.3028717, 24.24443054], [76.29392242, 24.24067116], [76.28964996, 24.23703003], [76.28884125, 24.22557068], [76.28716278, 24.21825027], [76.28277588, 24.21571159], [76.27639771, 24.21651077], [76.26538086, 24.22154999], [76.25180817, 24.22481918], [76.24767303, 24.22792053], [76.24046326, 24.22618103], [76.23612213, 24.22388077], [76.22335052, 24.22327042], [76.21821594, 24.21738052], [76.21556854, 24.21680832], [76.21057129, 24.22284126], [76.20622253, 24.23274994], [76.205513, 24.2418499], [76.20363617, 24.25058937], [76.20437622, 24.26902008], [76.20218658, 24.27675056], [76.19465637, 24.28479958], [76.19560242, 24.29009819], [76.19908905, 24.29730034], [76.20498657, 24.30570984], [76.20623016, 24.31092072], [76.20252228, 24.31315994], [76.19402313, 24.32086945], [76.19004822, 24.32995033], [76.18548584, 24.33151054], [76.18112946, 24.3248806], [76.17212677, 24.31558037], [76.1713562, 24.31032944], [76.1725769, 24.30722046], [76.17002106, 24.30340958], [76.1692276, 24.29609108], [76.1627121, 24.29336166], [76.14952087, 24.29223061], [76.14666748, 24.29031944], [76.143013, 24.28528976], [76.14222717, 24.28115082], [76.1455307, 24.26576042], [76.14836121, 24.26403046], [76.14977264, 24.26098061], [76.15445709, 24.24376106], [76.15236664, 24.23545837], [76.14704895, 24.22776985], [76.14180756, 24.22384071], [76.13156891, 24.21244812], [76.12335968, 24.20540047], [76.12132263, 24.19639015], [76.12085724, 24.18359947], [76.11995697, 24.18013954], [76.12059784, 24.17823982], [76.1254425, 24.17814064], [76.12889099, 24.17485809], [76.13088989, 24.16905022], [76.13047028, 24.15366936], [76.13173676, 24.14394188], [76.13442993, 24.13933945], [76.1368866, 24.13133812], [76.1307373, 24.12290955], [76.12922668, 24.11893272], [76.13005066, 24.11214066], [76.13128662, 24.10662079], [76.13469696, 24.09972954], [76.13469696, 24.09528923], [76.12327576, 24.09233284], [76.11244965, 24.09650993], [76.1085968, 24.09712982], [76.10515594, 24.09590912], [76.09899902, 24.08918953], [76.09082794, 24.08574104], [76.08454132, 24.08214951], [76.08024597, 24.0839901], [76.06372833, 24.07790947], [76.05748749, 24.07785034], [76.04695892, 24.07567024], [76.04335022, 24.07396126], [76.0399704, 24.06690979], [76.03299713, 24.0642128], [76.02672577, 24.05046272], [76.01793671, 24.04455948], [76.00894165, 24.04030037], [76.00213623, 24.03523064], [76.00028229, 24.0354805], [75.99450684, 24.03190041], [75.99008942, 24.03006935], [75.97975159, 24.03104973], [75.97962189, 24.03209114], [75.97336578, 24.03144073], [75.96018219, 24.02536964], [75.95910645, 24.00997162], [75.96092987, 24.00427055], [75.96024323, 23.99746132], [75.96131897, 23.99484062], [75.96353149, 23.99165916], [75.97675323, 23.98195076], [75.97823334, 23.98007011], [75.98018646, 23.97438049], [75.98018646, 23.96875954], [75.98123169, 23.96241951], [75.97981262, 23.95215988], [75.98092651, 23.94301987], [75.9759903, 23.93898964], [75.97582245, 23.93293953], [75.97409058, 23.93153], [75.96652222, 23.92987061], [75.94822693, 23.92226028], [75.94658661, 23.92071152], [75.94433594, 23.91620827], [75.93808746, 23.91220856], [75.93180847, 23.90193939], [75.92695618, 23.9018898], [75.9212265, 23.90417099], [75.9054718, 23.89606285], [75.90126038, 23.89501953], [75.89655304, 23.8927002], [75.89393616, 23.89308167], [75.88878632, 23.89171982], [75.88633728, 23.8885994], [75.87861633, 23.88455963], [75.87236786, 23.88818169], [75.86709595, 23.89398956], [75.86351776, 23.895401], [75.86065674, 23.89558983], [75.85661316, 23.89400101], [75.85341644, 23.89420128], [75.84142303, 23.88843918], [75.83973694, 23.88256073], [75.83703613, 23.88132858], [75.83040619, 23.8847599], [75.81785583, 23.8793602], [75.81394196, 23.87426949], [75.80265808, 23.87111092], [75.79421997, 23.87430954], [75.79102325, 23.87215042], [75.78514862, 23.8653698], [75.78505707, 23.85980988], [75.78385162, 23.85773087], [75.77992249, 23.85470009], [75.77706146, 23.85387039], [75.7696228, 23.85444069], [75.7616272, 23.85688972], [75.75994873, 23.86199188], [75.75917053, 23.88132858], [75.75712585, 23.88418961], [75.74974823, 23.89002037], [75.7400589, 23.89422035], [75.73647308, 23.89409065], [75.73420715, 23.89952278], [75.73132324, 23.9015007], [75.72821808, 23.90209961], [75.72281647, 23.90061951], [75.71549225, 23.90151978], [75.71299744, 23.89995956], [75.71057892, 23.90040016], [75.70707703, 23.90288925], [75.70233154, 23.90405083], [75.7008667, 23.90127945], [75.70094299, 23.89491081], [75.69863892, 23.89122963], [75.69773865, 23.88772011], [75.69812775, 23.87710762], [75.70131683, 23.87495995], [75.70355225, 23.87543106], [75.70474243, 23.87475967], [75.70656586, 23.86818123], [75.71753693, 23.8647728], [75.72754669, 23.86450958], [75.72911072, 23.85820961], [75.72815704, 23.85505104], [75.72637177, 23.8534317], [75.72396088, 23.84801102], [75.72067261, 23.84678078], [75.71787262, 23.84698105], [75.71572113, 23.84559059], [75.71794891, 23.84004021], [75.71872711, 23.83236122], [75.72216797, 23.82691193], [75.72083282, 23.82364082], [75.7167511, 23.82212067], [75.71588135, 23.82102013], [75.71784973, 23.81903267], [75.71569061, 23.81705093], [75.71321869, 23.8164711], [75.70878601, 23.81809807], [75.70259094, 23.81713104], [75.69024658, 23.8196106], [75.68740082, 23.81925011], [75.68692017, 23.8176899], [75.68826294, 23.81408119], [75.69403839, 23.80455017], [75.69451904, 23.79754257], [75.69866943, 23.7918396], [75.69828796, 23.78800011], [75.69671631, 23.78528976], [75.69007874, 23.7759819], [75.68734741, 23.77333069], [75.68515015, 23.76664925], [75.68447876, 23.76056862]]]}}, {\\\"id\\\": \\\"27\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.30_1\\\", \\\"HASC_1\\\": \\\"IN.SK\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Sikkim\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -1.2, \\\"dalys_apm25_rate_6cod_mean_total\\\": 388.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1466.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1079.0, \\\"geo-id\\\": 27, \\\"hpm25_child_popweighted\\\": -117.4, \\\"hpm25_female_popweighted\\\": -135.0, \\\"hpm25_male_popweighted\\\": -97.2, \\\"location\\\": \\\"Sikkim\\\", \\\"mort_apm25_6cod_mean_total\\\": 161.0, \\\"mort_hpm25_6cod_mean_total\\\": -565.0, \\\"mort_tpm25_6cod_mean_total\\\": -404.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[88.80600739, 27.41423988], [88.80712128, 27.41119957], [88.80805969, 27.40864182], [88.80932617, 27.40518951], [88.81009674, 27.40475845], [88.81009674, 27.40430069], [88.81136322, 27.40318108], [88.81175995, 27.40302086], [88.81175995, 27.40256119], [88.81745148, 27.40071106], [88.81920624, 27.39932251], [88.81925964, 27.39925575], [88.81932068, 27.39918327], [88.82083893, 27.39736938], [88.82170105, 27.39571953], [88.82238007, 27.39408112], [88.82536316, 27.39143944], [88.82536316, 27.39099121], [88.82536316, 27.39056015], [88.83119965, 27.38875008], [88.8327179, 27.38651085], [88.83316803, 27.38651085], [88.83349609, 27.38651085], [88.83348846, 27.38605118], [88.83423615, 27.38583946], [88.83444214, 27.38460732], [88.83473206, 27.38290024], [88.83551788, 27.38244057], [88.83831024, 27.37882996], [88.83982849, 27.37815857], [88.84134674, 27.37770081], [88.84234619, 27.37794113], [88.84411621, 27.37907982], [88.84451294, 27.37973022], [88.84718323, 27.38085938], [88.84829712, 27.38268089], [88.84835815, 27.38276863], [88.84895325, 27.38360023], [88.85270691, 27.38632965], [88.85653687, 27.38677979], [88.85883331, 27.38586998], [88.8616333, 27.38361931], [88.86213684, 27.38250923], [88.86313629, 27.38068008], [88.86466217, 27.37977028], [88.86721802, 27.36824989], [88.86875153, 27.36736107], [88.86942291, 27.36718178], [88.87046814, 27.36688614], [88.87915039, 27.36444092], [88.87924957, 27.36437416], [88.88098907, 27.3631897], [88.88320923, 27.35766029], [88.88506317, 27.34680939], [88.88561249, 27.34550858], [88.88861084, 27.33844185], [88.88910675, 27.3382206], [88.88986206, 27.33640099], [88.89393616, 27.33394051], [88.89395142, 27.33346939], [88.89599609, 27.33305168], [88.89714813, 27.333395], [88.90054321, 27.33440971], [88.90693665, 27.33067322], [88.90786743, 27.33012962], [88.90916443, 27.33041573], [88.91194916, 27.33102989], [88.91416168, 27.3302002], [88.9153595, 27.32963371], [88.91945648, 27.32769966], [88.91963196, 27.3269043], [88.91938019, 27.3246212], [88.91956329, 27.32340431], [88.91962433, 27.32299614], [88.91965485, 27.32242203], [88.91973114, 27.32100105], [88.91811371, 27.31842422], [88.91690826, 27.31633759], [88.91537476, 27.314291], [88.91402435, 27.31240845], [88.91353607, 27.31085777], [88.91268921, 27.30901909], [88.91215515, 27.30811882], [88.91016388, 27.30631447], [88.90944672, 27.30516815], [88.90939331, 27.30491829], [88.90914154, 27.30382156], [88.9091568, 27.30219269], [88.90916443, 27.30173302], [88.90917206, 27.3004837], [88.90916443, 27.30033302], [88.90913391, 27.29909897], [88.91040802, 27.29741096], [88.91077423, 27.29692841], [88.9111557, 27.29570007], [88.91218567, 27.29349518], [88.91339111, 27.2918644], [88.91441345, 27.29006958], [88.91387939, 27.28891754], [88.91123962, 27.28643799], [88.91043091, 27.28421974], [88.90834808, 27.28149796], [88.90791321, 27.27911758], [88.90785217, 27.27667809], [88.90583801, 27.27516747], [88.90428925, 27.27384377], [88.90058899, 27.27396393], [88.89971924, 27.27266312], [88.89579773, 27.27017403], [88.89333344, 27.26908875], [88.89031219, 27.26808167], [88.88747406, 27.2675705], [88.88609314, 27.26764107], [88.88398743, 27.26713371], [88.87896729, 27.26123619], [88.87776184, 27.26146698], [88.87693024, 27.26171684], [88.87621307, 27.26193237], [88.87521362, 27.26222229], [88.87413788, 27.26251411], [88.87283325, 27.26281929], [88.87123108, 27.26330757], [88.86985779, 27.26379776], [88.86728668, 27.2646389], [88.86647797, 27.26477623], [88.8631134, 27.26467705], [88.86006927, 27.26465416], [88.85734558, 27.2645607], [88.85349274, 27.26403046], [88.84916687, 27.26385307], [88.84468079, 27.26345825], [88.84211731, 27.26322365], [88.83631134, 27.26281357], [88.83410645, 27.26265717], [88.83300781, 27.26269722], [88.83245087, 27.26261711], [88.83132172, 27.26245308], [88.82805634, 27.2574482], [88.82294464, 27.25533104], [88.81911469, 27.25393677], [88.81535339, 27.25261688], [88.81048584, 27.25099945], [88.8032074, 27.2479744], [88.80292511, 27.24640656], [88.80345154, 27.24470711], [88.80401611, 27.24323273], [88.80449677, 27.24126434], [88.80438995, 27.24005318], [88.80400085, 27.23856544], [88.80310059, 27.23582649], [88.80265045, 27.2329464], [88.80266571, 27.23155022], [88.80268097, 27.23015213], [88.8026886, 27.22933006], [88.80265808, 27.22830582], [88.80266571, 27.22744942], [88.80261993, 27.22621346], [88.80270386, 27.2238369], [88.8028717, 27.22298241], [88.80325317, 27.22151184], [88.80285645, 27.22037888], [88.80241394, 27.21853447], [88.80155945, 27.21757698], [88.80130768, 27.21662331], [88.80078888, 27.2151947], [88.80013275, 27.21382332], [88.79981995, 27.21221733], [88.7995224, 27.20853233], [88.79883575, 27.20664024], [88.79767609, 27.20572853], [88.79689026, 27.20453262], [88.795578, 27.20295334], [88.79495239, 27.20142555], [88.79154205, 27.19683266], [88.78980255, 27.19638634], [88.78900909, 27.19558144], [88.78875732, 27.19532776], [88.7888031, 27.19466209], [88.78877258, 27.19392776], [88.78890228, 27.19270325], [88.78915405, 27.19135666], [88.7891922, 27.19113159], [88.78916931, 27.19073486], [88.78910828, 27.18955994], [88.78909302, 27.18925858], [88.78890228, 27.18866348], [88.78878021, 27.18771172], [88.78839111, 27.18651962], [88.78807831, 27.18467522], [88.78684998, 27.18199348], [88.78470612, 27.18201637], [88.78379059, 27.18202591], [88.7828598, 27.18231583], [88.78179169, 27.18266296], [88.78079224, 27.18307114], [88.77979279, 27.18341827], [88.77872467, 27.18370628], [88.77706146, 27.18357468], [88.77488708, 27.18266487], [88.77322388, 27.18235397], [88.77176666, 27.18216324], [88.76965332, 27.18119621], [88.76851654, 27.18031693], [88.76675415, 27.17903328], [88.76622772, 27.17858315], [88.76556396, 27.17801476], [88.76431274, 27.17723083], [88.76301575, 27.17440605], [88.76229858, 27.17281723], [88.7615509, 27.17196274], [88.76072693, 27.17102242], [88.7600708, 27.17048264], [88.75902557, 27.16875076], [88.75852966, 27.16798019], [88.75752258, 27.16641998], [88.75693512, 27.1654644], [88.75701141, 27.1642189], [88.75756073, 27.16279793], [88.75797272, 27.16119766], [88.75693512, 27.15881157], [88.75747681, 27.15798569], [88.75844574, 27.15692139], [88.75935364, 27.15621948], [88.75958252, 27.15492439], [88.75963593, 27.15461731], [88.76019287, 27.15283966], [88.75839996, 27.15139771], [88.75678253, 27.14823723], [88.75163269, 27.14818192], [88.75152588, 27.14815331], [88.75138092, 27.14811707], [88.74920654, 27.14765358], [88.74711609, 27.14557457], [88.74694061, 27.14536476], [88.73718262, 27.13952065], [88.73253632, 27.13735008], [88.72454071, 27.13852119], [88.71779633, 27.14397049], [88.71496582, 27.15023994], [88.71180725, 27.16514969], [88.70197296, 27.17411041], [88.6914978, 27.17869949], [88.6844101, 27.18022919], [88.68036652, 27.17951012], [88.67350006, 27.17661095], [88.66806793, 27.17198944], [88.6595993, 27.16221046], [88.65645599, 27.1624012], [88.64248657, 27.16715813], [88.6387558, 27.16772079], [88.63327789, 27.17453003], [88.61901855, 27.18785286], [88.60678864, 27.18966103], [88.60352325, 27.19115257], [88.59810638, 27.19137192], [88.59751892, 27.19271088], [88.59400177, 27.19118118], [88.59147644, 27.19445992], [88.58702087, 27.19053268], [88.58509064, 27.19283295], [88.56629181, 27.18786049], [88.55899048, 27.18875122], [88.54084015, 27.1837101], [88.52899933, 27.17776108], [88.52075195, 27.17818069], [88.52047729, 27.17502975], [88.52980804, 27.16579056], [88.52672577, 27.1602726], [88.5320282, 27.1543293], [88.52993011, 27.1501503], [88.52674103, 27.14977264], [88.52171326, 27.15034294], [88.51870728, 27.14780045], [88.51596069, 27.1437397], [88.51222992, 27.14103127], [88.50750732, 27.13599014], [88.50295258, 27.13405037], [88.49890137, 27.13121986], [88.49640656, 27.12815285], [88.4956131, 27.12536049], [88.49185181, 27.1248703], [88.48668671, 27.12677956], [88.48127747, 27.12285042], [88.47377777, 27.12070084], [88.46907806, 27.11730194], [88.46672058, 27.11394119], [88.46479797, 27.10479164], [88.46018219, 27.09584999], [88.45449829, 27.0896492], [88.44628143, 27.08539963], [88.43962097, 27.08416939], [88.4319458, 27.08160973], [88.42914581, 27.08362007], [88.41100311, 27.09070015], [88.3976593, 27.09443092], [88.38751984, 27.09840965], [88.37065125, 27.09941292], [88.36387634, 27.0984211], [88.35230255, 27.1010704], [88.34793854, 27.10332108], [88.34516144, 27.10690117], [88.34079742, 27.11067009], [88.33174133, 27.10816765], [88.32383728, 27.10490036], [88.32007599, 27.10732079], [88.32048798, 27.11664009], [88.31881714, 27.1193409], [88.31127167, 27.12535095], [88.30449677, 27.12860107], [88.29988861, 27.12799835], [88.29490662, 27.12477112], [88.27813721, 27.13083076], [88.27735138, 27.13119125], [88.27088928, 27.13013077], [88.26345825, 27.12737083], [88.25154877, 27.12536049], [88.24006653, 27.12037086], [88.2325058, 27.11976814], [88.22690582, 27.12138939], [88.22151184, 27.12527084], [88.21383667, 27.1351223], [88.20986938, 27.13340187], [88.19561768, 27.13623047], [88.18850708, 27.13442039], [88.18367767, 27.1352005], [88.17899323, 27.13471031], [88.17260742, 27.1303196], [88.15843964, 27.11435127], [88.15544128, 27.1121006], [88.15231323, 27.11170959], [88.14377594, 27.11707115], [88.1366272, 27.11687851], [88.12690735, 27.12308121], [88.12329102, 27.12379074], [88.09593964, 27.13550949], [88.09266663, 27.13627815], [88.08863831, 27.13875008], [88.08584595, 27.14151001], [88.08383179, 27.14501953], [88.08299255, 27.14893913], [88.08390808, 27.16106987], [88.08325958, 27.16504288], [88.0786972, 27.16792107], [88.07309723, 27.1744175], [88.07232666, 27.17934036], [88.06926727, 27.18494987], [88.06745148, 27.19026947], [88.0688324, 27.1943512], [88.07540894, 27.19880104], [88.07495117, 27.20084], [88.0682373, 27.20473099], [88.06433868, 27.20783043], [88.06173706, 27.2112999], [88.05819702, 27.21389008], [88.04676056, 27.21611023], [88.03292847, 27.22103119], [88.02398682, 27.22066116], [88.01696777, 27.21887207], [88.021492, 27.22472954], [88.02162933, 27.22888565], [88.02185822, 27.23554611], [88.02431488, 27.23741531], [88.02745819, 27.23690796], [88.02684021, 27.24175644], [88.03031921, 27.24911499], [88.03341675, 27.24971581], [88.03338623, 27.25157928], [88.03321838, 27.26301575], [88.0344162, 27.26561546], [88.03291321, 27.27171516], [88.03561401, 27.28141594], [88.03429413, 27.28599548], [88.04076385, 27.29143524], [88.04650879, 27.29244232], [88.04364014, 27.30112648], [88.04411316, 27.30401611], [88.04771423, 27.30985641], [88.05111694, 27.31231499], [88.05203247, 27.31844711], [88.05522156, 27.32430077], [88.06273651, 27.32825661], [88.06611633, 27.33411598], [88.06921387, 27.33558083], [88.06885529, 27.33664131], [88.06731415, 27.34101486], [88.06563568, 27.34269524], [88.06441498, 27.34391594], [88.06243896, 27.34927559], [88.06026459, 27.35534096], [88.0528183, 27.35831451], [88.04441833, 27.37071609], [88.04761505, 27.37971497], [88.04672241, 27.38429642], [88.0473175, 27.38961601], [88.04846191, 27.39548111], [88.05111694, 27.40061569], [88.04941559, 27.40521622], [88.05219269, 27.40691376], [88.05321503, 27.41261482], [88.0594635, 27.41804504], [88.0607605, 27.41822243], [88.06912994, 27.42461395], [88.06971741, 27.4250145], [88.08261871, 27.42641449], [88.08288574, 27.429533], [88.08213043, 27.43057823], [88.08211517, 27.43071556], [88.0819931, 27.43076897], [88.08126831, 27.43176842], [88.07541656, 27.43361473], [88.07525635, 27.43377876], [88.07086945, 27.43816185], [88.07048035, 27.43853188], [88.07410431, 27.44385338], [88.07501984, 27.44521904], [88.06981659, 27.44931602], [88.06896973, 27.45215034], [88.06812286, 27.4527359], [88.06970978, 27.45761871], [88.06300354, 27.46084785], [88.06274414, 27.46129227], [88.05931854, 27.46721458], [88.05873108, 27.46761513], [88.05380249, 27.47153664], [88.05251312, 27.4718895], [88.0466156, 27.47841454], [88.04780579, 27.48134232], [88.04660034, 27.48470879], [88.04720306, 27.49265862], [88.04633331, 27.49576569], [88.04921722, 27.50121498], [88.05342865, 27.50409698], [88.05741882, 27.50431442], [88.06011963, 27.5092144], [88.06411743, 27.51181602], [88.06002045, 27.516716], [88.06401825, 27.52511597], [88.06983948, 27.52609253], [88.06781769, 27.52931595], [88.06613159, 27.52990913], [88.06241608, 27.53121567], [88.0620575, 27.53271866], [88.06166077, 27.53463364], [88.06163025, 27.53479195], [88.06350708, 27.53975487], [88.06771851, 27.54451561], [88.07120514, 27.54610062], [88.07182312, 27.55554581], [88.0786438, 27.55841637], [88.08361816, 27.56461525], [88.08201599, 27.56809807], [88.07781982, 27.57181549], [88.08713531, 27.5890007], [88.09541321, 27.59731483], [88.10821533, 27.6023159], [88.11631775, 27.61034966], [88.11688232, 27.61403847], [88.11791992, 27.62081528], [88.12213135, 27.62702942], [88.11991882, 27.62951469], [88.12329102, 27.63921356], [88.12262726, 27.64526749], [88.13381958, 27.65511513], [88.13981628, 27.65721512], [88.14026642, 27.65771103], [88.14725494, 27.66540337], [88.14822388, 27.67155266], [88.14941406, 27.67881584], [88.15032959, 27.68122292], [88.15135956, 27.68379593], [88.15742493, 27.69042015], [88.15099335, 27.70168114], [88.15090942, 27.70166016], [88.15071106, 27.70200729], [88.15197754, 27.70790482], [88.1581192, 27.71721458], [88.15733337, 27.72915459], [88.16104889, 27.74061775], [88.17235565, 27.74134064], [88.18121338, 27.74681473], [88.17931366, 27.75811577], [88.18344116, 27.76150322], [88.18603516, 27.7660656], [88.1852417, 27.76721954], [88.18421936, 27.76881599], [88.18423462, 27.76921272], [88.18441772, 27.77451515], [88.18789673, 27.77700043], [88.19075012, 27.78123665], [88.19794464, 27.78632927], [88.19992065, 27.79052925], [88.19649506, 27.79600334], [88.19252014, 27.79791451], [88.18951416, 27.80121613], [88.18789673, 27.81030655], [88.18152618, 27.8155365], [88.17998505, 27.81602859], [88.17611694, 27.81731606], [88.17572021, 27.82021523], [88.19013214, 27.82509613], [88.19721985, 27.83551598], [88.1993866, 27.83609581], [88.20392609, 27.83731461], [88.20401001, 27.84240532], [88.20069122, 27.84551048], [88.20016479, 27.84796906], [88.19891357, 27.85351563], [88.19552612, 27.85453224], [88.19101715, 27.8537159], [88.18789673, 27.85653687], [88.1834259, 27.85645676], [88.18093872, 27.85641289], [88.17705536, 27.86096954], [88.17521667, 27.86312294], [88.17462158, 27.86336708], [88.16975403, 27.86536026], [88.16856384, 27.86655235], [88.16689301, 27.86821747], [88.15657806, 27.8704567], [88.15634918, 27.87072182], [88.15131378, 27.87651443], [88.14561462, 27.8781147], [88.14191437, 27.8774147], [88.13754272, 27.88149261], [88.12998199, 27.8815155], [88.13020325, 27.88191986], [88.12992859, 27.88593864], [88.12738037, 27.89129066], [88.12628174, 27.8950901], [88.12576294, 27.89532089], [88.12522888, 27.8964386], [88.12294769, 27.89759064], [88.12245941, 27.89883041], [88.1216507, 27.90027046], [88.11959076, 27.902071], [88.1187973, 27.90250969], [88.11750793, 27.90559959], [88.11675262, 27.90602112], [88.11660004, 27.90718079], [88.1138916, 27.91219139], [88.11366272, 27.91583824], [88.1135788, 27.91761017], [88.11680603, 27.92578125], [88.12586975, 27.93442917], [88.1288681, 27.93829918], [88.12895203, 27.93984985], [88.12880707, 27.94552994], [88.123703, 27.94798088], [88.12365723, 27.95024109], [88.123909, 27.9509201], [88.12998199, 27.95594025], [88.13308716, 27.96161079], [88.13474274, 27.96298027], [88.13906097, 27.96348], [88.13981628, 27.96326065], [88.14000702, 27.96318245], [88.14676666, 27.96051407], [88.14720154, 27.96034241], [88.15368652, 27.95778084], [88.1672287, 27.94827271], [88.17362213, 27.94470978], [88.17566681, 27.94427109], [88.18276215, 27.94356155], [88.18865967, 27.94367981], [88.19293213, 27.94545174], [88.19476318, 27.94621086], [88.19554901, 27.94691849], [88.19576263, 27.94711113], [88.19713593, 27.95050049], [88.19922638, 27.95796967], [88.19970703, 27.96047974], [88.20028687, 27.96148491], [88.20259094, 27.9654808], [88.20349121, 27.96615028], [88.20347595, 27.96661949], [88.20980835, 27.96778107], [88.21130371, 27.96715927], [88.21411896, 27.96599007], [88.215271, 27.96557045], [88.2158432, 27.96536064], [88.21663666, 27.96496773], [88.21801758, 27.96446037], [88.22157288, 27.96401978], [88.22233582, 27.9642601], [88.22312927, 27.96447754], [88.22615051, 27.96722031], [88.22969818, 27.9679203], [88.23018646, 27.96777344], [88.23046875, 27.96768951], [88.23097992, 27.96722031], [88.23277283, 27.96587944], [88.23297119, 27.96492195], [88.23517609, 27.95413971], [88.23747253, 27.95259094], [88.23771667, 27.95146942], [88.23773193, 27.95055008], [88.23825073, 27.95034981], [88.23825836, 27.94989014], [88.24388885, 27.94853973], [88.24793243, 27.95010185], [88.24817657, 27.95019531], [88.24824524, 27.95028305], [88.24843597, 27.95083046], [88.25882721, 27.95631981], [88.26085663, 27.95656967], [88.2616272, 27.95634079], [88.26519775, 27.95659065], [88.27052307, 27.95831108], [88.27102661, 27.95808029], [88.2712326, 27.95817184], [88.27153778, 27.95831108], [88.27204895, 27.95844078], [88.27482605, 27.96051025], [88.27561188, 27.96123505], [88.27671051, 27.96436119], [88.27681732, 27.9654808], [88.27948761, 27.9673214], [88.28005981, 27.96761131], [88.28038025, 27.96778107], [88.28607178, 27.96846199], [88.29007721, 27.96894073], [88.29386139, 27.96806908], [88.30478668, 27.96996117], [88.3088913, 27.97268105], [88.31005096, 27.97398949], [88.31391907, 27.97836113], [88.31619263, 27.97972107], [88.32290649, 27.98131943], [88.3239212, 27.98110008], [88.32749939, 27.98192024], [88.32914734, 27.98250008], [88.33183289, 27.98475075], [88.33242798, 27.98590088], [88.33502197, 27.98702049], [88.33776093, 27.98798943], [88.34519196, 27.98948097], [88.3502121, 27.98962975], [88.35098267, 27.98985291], [88.3542099, 27.98941994], [88.3637619, 27.98814011], [88.37474823, 27.98367119], [88.38166046, 27.97986984], [88.38166046, 27.97940826], [88.38880157, 27.97784042], [88.38980103, 27.97808075], [88.39402008, 27.97973061], [88.39605713, 27.98110008], [88.40071869, 27.98334122], [88.40200043, 27.98359108], [88.40428925, 27.98674011], [88.40656281, 27.98789978], [88.40879822, 27.99244118], [88.40994263, 27.99356842], [88.41172791, 27.99562073], [88.41233063, 27.99698067], [88.42350006, 28.00563049], [88.42347717, 28.00606918], [88.42475891, 28.00653076], [88.42653656, 28.00811958], [88.42707062, 28.00832939], [88.43258667, 28.01040077], [88.45094299, 28.01501083], [88.45585632, 28.01719856], [88.46160126, 28.01980972], [88.4646225, 28.02319908], [88.46917725, 28.0328598], [88.4716568, 28.03680992], [88.47798157, 28.04257965], [88.4818573, 28.04500961], [88.48311615, 28.04558754], [88.4896698, 28.04807854], [88.50113678, 28.04893112], [88.50167084, 28.04869843], [88.50166321, 28.0482502], [88.50167847, 28.04779053], [88.50292969, 28.04713058], [88.50699615, 28.04648018], [88.516716, 28.0440197], [88.52083588, 28.0410881], [88.52110291, 28.04018021], [88.52108002, 28.03973961], [88.52236938, 28.03905106], [88.52236176, 28.03858948], [88.52776337, 28.03682137], [88.53154755, 28.03638077], [88.53334045, 28.03661919], [88.53801727, 28.03848076], [88.53824615, 28.0385704], [88.53894806, 28.03889084], [88.54097748, 28.04047966], [88.54273987, 28.04412079], [88.5428772, 28.04968262], [88.5429306, 28.05046082], [88.54367828, 28.05252075], [88.54505157, 28.05387115], [88.54881287, 28.0589447], [88.55042267, 28.06112099], [88.55177307, 28.06381035], [88.55227661, 28.06540108], [88.55246735, 28.07761955], [88.55445099, 28.08483124], [88.55828094, 28.08756065], [88.56691742, 28.08898163], [88.56774902, 28.08846092], [88.57076263, 28.0865097], [88.57483673, 28.08560944], [88.57657623, 28.08628082], [88.58551025, 28.09017181], [88.58756256, 28.09130096], [88.58908081, 28.09153938], [88.59037018, 28.09131813], [88.59516907, 28.09563065], [88.59604645, 28.09692955], [88.60279083, 28.0983696], [88.60540771, 28.09966087], [88.6134491, 28.10256004], [88.61646271, 28.10367966], [88.6135788, 28.10869026], [88.61215973, 28.10993195], [88.61155701, 28.11577988], [88.61083221, 28.11874008], [88.610466, 28.11963081], [88.60688782, 28.12281036], [88.6067276, 28.12618065], [88.60746765, 28.12755013], [88.61181641, 28.12961006], [88.62123871, 28.13096809], [88.62523651, 28.12826157], [88.62687683, 28.12714958], [88.62687683, 28.12668991], [88.62689209, 28.12626076], [88.62895203, 28.1246891], [88.62969971, 28.12446976], [88.62970734, 28.12401962], [88.63049316, 28.12379837], [88.63173676, 28.12109756], [88.63226318, 28.12086105], [88.63276672, 28.12063026], [88.63506317, 28.1130619], [88.63639069, 28.10868263], [88.63768768, 28.10437012], [88.63935852, 28.10311127], [88.64124298, 28.10172081], [88.64525604, 28.09912109], [88.65410614, 28.08983994], [88.66110229, 28.07963943], [88.66677094, 28.07407951], [88.67280579, 28.07283974], [88.67331696, 28.07307053], [88.67363739, 28.07327271], [88.67510986, 28.07420158], [88.67711639, 28.07737923], [88.68579865, 28.07897949], [88.69522095, 28.07698059], [88.69785309, 28.07736969], [88.70388794, 28.07813072], [88.71434021, 28.07569122], [88.71943665, 28.07637024], [88.72914124, 28.07528114], [88.74034882, 28.07599068], [88.7480545, 28.07406616], [88.75108337, 28.07331276], [88.75361633, 28.07193947], [88.75363922, 28.07150078], [88.75614929, 28.06971169], [88.76803589, 28.06124115], [88.7682724, 28.0606308], [88.76880646, 28.0606308], [88.76912689, 28.06040001], [88.77075195, 28.05912018], [88.77074432, 28.0589447], [88.77073669, 28.05866051], [88.77076721, 28.05820084], [88.77332306, 28.05686188], [88.7822876, 28.05076981], [88.782547, 28.04961967], [88.7828064, 28.04849052], [88.78356171, 28.04803276], [88.78431702, 28.0476017], [88.78562164, 28.04424095], [88.78663635, 28.04355049], [88.78663635, 28.04310036], [88.79471588, 28.03704262], [88.79473114, 28.03659821], [88.79498291, 28.0363903], [88.7960968, 28.03590012], [88.79749298, 28.03277969], [88.79766083, 28.0324707], [88.79943085, 28.0311203], [88.79944611, 28.03069115], [88.80226898, 28.02877426], [88.80532837, 28.02670097], [88.80532837, 28.02625084], [88.80560303, 28.02609062], [88.80786896, 28.02527046], [88.8167038, 28.02098083], [88.81925964, 28.01974106], [88.82070923, 28.01897812], [88.8253479, 28.01705933], [88.82905579, 28.01515961], [88.832901, 28.01153946], [88.83463287, 28.00040817], [88.83564758, 27.99949074], [88.83571625, 27.99912071], [88.83625031, 27.99889946], [88.83625031, 27.99821281], [88.83677673, 27.99685097], [88.83905792, 27.99505997], [88.84088135, 27.99100113], [88.84029388, 27.97680283], [88.83981323, 27.96523094], [88.83995819, 27.96410942], [88.84300995, 27.96161079], [88.84407043, 27.95642281], [88.83972931, 27.95279121], [88.83644867, 27.94735909], [88.83641815, 27.94491959], [88.83625031, 27.93200111], [88.8395462, 27.93041992], [88.84178162, 27.92983055], [88.85353088, 27.92673111], [88.85443878, 27.92648888], [88.85894775, 27.92527008], [88.86123657, 27.92346191], [88.86480713, 27.91306114], [88.86682892, 27.90909958], [88.87023163, 27.90242958], [88.87071991, 27.90243912], [88.8707428, 27.90197945], [88.87146759, 27.90181923], [88.87725067, 27.89749146], [88.87967682, 27.89567947], [88.87966156, 27.89525986], [88.88018799, 27.89524078], [88.88046265, 27.89365959], [88.88050079, 27.89320946], [88.88101196, 27.89320946], [88.8813858, 27.89253044], [88.88136292, 27.88904953], [88.88093567, 27.88638306], [88.87996674, 27.88031006], [88.88076782, 27.87014008], [88.88089752, 27.86984062], [88.88176727, 27.86787033], [88.88456726, 27.86539078], [88.88574219, 27.86133766], [88.88564301, 27.85905838], [88.88539886, 27.85891724], [88.88297272, 27.85749054], [88.88286591, 27.85703087], [88.88209534, 27.85544205], [88.88208771, 27.85530853], [88.8809967, 27.83896065], [88.88038635, 27.83760071], [88.87896729, 27.83714104], [88.87782288, 27.83624077], [88.87709045, 27.83397102], [88.87666321, 27.83337975], [88.87623596, 27.83263016], [88.87528229, 27.83106995], [88.87303162, 27.82739067], [88.86830139, 27.82454109], [88.86752319, 27.82460022], [88.86553955, 27.82368088], [88.86234283, 27.82175064], [88.85573578, 27.81812286], [88.8553772, 27.81788826], [88.85426331, 27.8165226], [88.85412598, 27.81495094], [88.85463715, 27.81474113], [88.85476685, 27.81360054], [88.85527039, 27.81245041], [88.85732269, 27.81134033], [88.85745239, 27.80816269], [88.85682678, 27.79887962], [88.85233307, 27.77832031], [88.85260773, 27.7683506], [88.85431671, 27.76037025], [88.85457611, 27.75933075], [88.85592651, 27.75694084], [88.85694885, 27.75601959], [88.85752869, 27.75459099], [88.85852814, 27.75369072], [88.85952759, 27.7530098], [88.86136627, 27.74894142], [88.86238098, 27.73900032], [88.86107635, 27.73583031], [88.85428619, 27.7301712], [88.85372925, 27.72914505], [88.85151672, 27.72405052], [88.85051727, 27.71820068], [88.8500061, 27.7175312], [88.84127808, 27.71206284], [88.83888245, 27.71116257], [88.83862305, 27.7104702], [88.83863831, 27.70821953], [88.83940125, 27.7057209], [88.83988953, 27.70551109], [88.84040833, 27.7052784], [88.84117889, 27.70281029], [88.84552765, 27.70031166], [88.84552002, 27.6944313], [88.84416962, 27.68892288], [88.84449768, 27.6859417], [88.84500885, 27.68161964], [88.84526062, 27.6807003], [88.84545898, 27.68008041], [88.84673309, 27.67558289], [88.84661102, 27.66904068], [88.84661102, 27.66889954], [88.84562683, 27.66723824], [88.84310913, 27.6629982], [88.83843994, 27.65871048], [88.83679199, 27.65756989], [88.8341217, 27.65332222], [88.83223724, 27.65032959], [88.82601929, 27.64546967], [88.82232666, 27.64283943], [88.82073212, 27.64229012], [88.81981659, 27.64194107], [88.81552887, 27.64266968], [88.81375122, 27.64332008], [88.8132019, 27.64352036], [88.81067657, 27.64282036], [88.80990601, 27.64191818], [88.80713654, 27.63625908], [88.80639648, 27.6321907], [88.8082428, 27.61912918], [88.8085022, 27.61433029], [88.80797577, 27.61363983], [88.80548859, 27.6032505], [88.80195618, 27.59984016], [88.80095673, 27.59961128], [88.80098724, 27.59918022], [88.80046082, 27.59917259], [88.80046082, 27.59871101], [88.79789734, 27.59646034], [88.79740906, 27.59646034], [88.79741669, 27.59600258], [88.79457092, 27.59399986], [88.79406738, 27.59399986], [88.79280853, 27.59198952], [88.79177856, 27.5906105], [88.78853607, 27.58806992], [88.78726959, 27.58557129], [88.78557587, 27.57628059], [88.78481293, 27.57538033], [88.78368378, 27.57448006], [88.78227997, 27.57336044], [88.76847839, 27.56799889], [88.76822662, 27.5678997], [88.76822662, 27.56743813], [88.76732635, 27.56677246], [88.76706696, 27.56496048], [88.76786804, 27.55997086], [88.7684021, 27.5597496], [88.76891327, 27.55952263], [88.77311707, 27.54450989], [88.77510071, 27.53759956], [88.77554321, 27.53728294], [88.77635956, 27.53672028], [88.77913666, 27.53400993], [88.77990723, 27.5326519], [88.77987671, 27.53222084], [88.78424835, 27.52951813], [88.78601837, 27.52906036], [88.78703308, 27.52930069], [88.78806305, 27.5290699], [88.78856659, 27.52860069], [88.78894806, 27.52613068], [88.78882599, 27.52501106], [88.78768921, 27.52453041], [88.7869873, 27.52083969], [88.78666687, 27.51917267], [88.78617096, 27.51510048], [88.78613281, 27.51362991], [88.786026, 27.51148987], [88.78517151, 27.50646019], [88.78322601, 27.49648094], [88.78333282, 27.49452972], [88.7842865, 27.49373055], [88.78501129, 27.49297905], [88.78555298, 27.49241829], [88.78543091, 27.48767281], [88.78524017, 27.48725319], [88.78474426, 27.48616409], [88.78390503, 27.48432732], [88.78315735, 27.48270035], [88.78259277, 27.47958374], [88.78231812, 27.47806549], [88.78144073, 27.47319031], [88.78144073, 27.47253227], [88.78145599, 27.46775818], [88.78216553, 27.46325684], [88.78338623, 27.45555115], [88.7842865, 27.45399094], [88.78733826, 27.45242119], [88.78736877, 27.45129967], [88.78759766, 27.45017052], [88.79243469, 27.44802666], [88.79473114, 27.44701004], [88.79459381, 27.4449501], [88.79402161, 27.43660927], [88.79490662, 27.43276978], [88.7950058, 27.43264961], [88.79653168, 27.43078041], [88.80032349, 27.4287014], [88.80316925, 27.42713928], [88.80406952, 27.42533112], [88.80407715, 27.42509079], [88.80600739, 27.41423988]]]}}, {\\\"id\\\": \\\"28\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.31_1\\\", \\\"HASC_1\\\": \\\"IN.TN\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Tamil Nadu\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Madras|Tamilnad\\\", \\\"apm25_popweighted\\\": -6.3, \\\"dalys_apm25_rate_6cod_mean_total\\\": 369.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -857.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -488.0, \\\"geo-id\\\": 28, \\\"hpm25_child_popweighted\\\": -100.5, \\\"hpm25_female_popweighted\\\": -115.5, \\\"hpm25_male_popweighted\\\": -83.2, \\\"location\\\": \\\"Tamil Nadu\\\", \\\"mort_apm25_6cod_mean_total\\\": 8477.0, \\\"mort_hpm25_6cod_mean_total\\\": -18950.0, \\\"mort_tpm25_6cod_mean_total\\\": -10472.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[77.55596161, 8.07903099], [77.55596161, 8.07875061], [77.55625153, 8.07875061], [77.55625153, 8.07847118], [77.55652618, 8.07847309], [77.55652618, 8.07736111], [77.55625153, 8.07736111], [77.55625153, 8.07708263], [77.55596924, 8.07708263], [77.55596924, 8.07680511], [77.55513763, 8.07680511], [77.55513763, 8.07652569], [77.55458069, 8.07652569], [77.55458069, 8.07680511], [77.55374908, 8.07680511], [77.55374908, 8.07708263], [77.55347443, 8.07708263], [77.55347443, 8.07736111], [77.55319214, 8.07736111], [77.55319214, 8.07847309], [77.5534668, 8.07847118], [77.5534668, 8.07875061], [77.55486298, 8.07875061], [77.55486298, 8.07903099], [77.55596161, 8.07903099]]], [[[78.22486115, 8.87374973], [78.22486115, 8.87319183], [78.22541809, 8.87319374], [78.22541809, 8.87291622], [78.22598267, 8.87292004], [78.22598267, 8.87263966], [78.22624969, 8.87263966], [78.22624969, 8.87236023], [78.22652435, 8.87236214], [78.22652435, 8.87152767], [78.22680664, 8.87154102], [78.22680664, 8.87125015], [78.2270813, 8.87125015], [78.22706604, 8.86958122], [78.22736359, 8.86958408], [78.22736359, 8.86902809], [78.22763824, 8.86903191], [78.22763824, 8.86874866], [78.22706604, 8.86874866], [78.22706604, 8.86791992], [78.22735596, 8.86791992], [78.22735596, 8.86736107], [78.22569275, 8.86736107], [78.22569275, 8.86763954], [78.22597504, 8.86763954], [78.22597504, 8.86819553], [78.22569275, 8.86819553], [78.22569275, 8.86847115], [78.22541809, 8.86846924], [78.22541809, 8.86903191], [78.22486115, 8.86902809], [78.22486115, 8.86958408], [78.22458649, 8.86958122], [78.22458649, 8.87014198], [78.22429657, 8.87014198], [78.22429657, 8.87042046], [78.22402954, 8.87041569], [78.22402954, 8.87097168], [78.22429657, 8.87097168], [78.22429657, 8.87154102], [78.22402954, 8.87152767], [78.22402954, 8.87208366], [78.2234726, 8.87208366], [78.2234726, 8.87236214], [78.22291565, 8.87236214], [78.22291565, 8.87319374], [78.22319794, 8.87319374], [78.22319794, 8.87347221], [78.22374725, 8.87347031], [78.22374725, 8.87374973], [78.22486115, 8.87374973]]], [[[78.20847321, 8.84097099], [78.20847321, 8.84069347], [78.20903015, 8.84069347], [78.20903015, 8.84041786], [78.2095871, 8.84041977], [78.2095871, 8.84013939], [78.21013641, 8.84013939], [78.21013641, 8.83986092], [78.2104187, 8.83986092], [78.2104187, 8.83930492], [78.21098328, 8.83930969], [78.21098328, 8.83903027], [78.21206665, 8.83903027], [78.21206665, 8.83847141], [78.2123642, 8.83847332], [78.2123642, 8.83791733], [78.21263885, 8.83792019], [78.21263885, 8.83708096], [78.21291351, 8.83708286], [78.21291351, 8.83652687], [78.21263885, 8.83653164], [78.21263885, 8.83625126], [78.21180725, 8.83625126], [78.21180725, 8.83597088], [78.21152496, 8.83597088], [78.21152496, 8.83541679], [78.21013641, 8.83541679], [78.21013641, 8.83569527], [78.2104187, 8.83569527], [78.2104187, 8.83625126], [78.20986176, 8.83625126], [78.20986176, 8.83653164], [78.2095871, 8.83652687], [78.2095871, 8.83708286], [78.20929718, 8.83708096], [78.20929718, 8.83930969], [78.20903015, 8.83930492], [78.20903015, 8.83986092], [78.20874786, 8.83986092], [78.20874786, 8.84041977], [78.20819092, 8.84041786], [78.20819092, 8.84069347], [78.2076416, 8.84069347], [78.2076416, 8.84097099], [78.20847321, 8.84097099]]], [[[78.12763977, 8.64792156], [78.12763977, 8.64514065], [78.1279068, 8.64514065], [78.1279068, 8.6434679], [78.12819672, 8.64347267], [78.12819672, 8.64291668], [78.12791443, 8.64291668], [78.12791443, 8.64319515], [78.12596893, 8.64319515], [78.12596893, 8.64347267], [78.12625122, 8.6434679], [78.12625122, 8.64403057], [78.12652588, 8.64403057], [78.12652588, 8.6465292], [78.12625122, 8.6465292], [78.12625122, 8.6473608], [78.12735748, 8.64735889], [78.12735748, 8.64792156], [78.12763977, 8.64792156]]], [[[78.11541748, 8.61680889], [78.11541748, 8.61597061], [78.11569214, 8.61597347], [78.11569214, 8.615695], [78.11597443, 8.615695], [78.11597443, 8.61541653], [78.11624908, 8.6154213], [78.11624908, 8.61514091], [78.11653137, 8.61514091], [78.11653137, 8.61486053], [78.11680603, 8.61486053], [78.11680603, 8.61458302], [78.11763763, 8.61458302], [78.11763763, 8.61486053], [78.11791992, 8.61486053], [78.11791992, 8.61514091], [78.11818695, 8.61514091], [78.11818695, 8.6154213], [78.11875153, 8.6154213], [78.11875153, 8.61514091], [78.11902618, 8.61514091], [78.11902618, 8.61486053], [78.11930847, 8.61486053], [78.11930847, 8.61458302], [78.12014008, 8.61458302], [78.12014008, 8.61430359], [78.12069702, 8.61431122], [78.12069702, 8.61375141], [78.1204071, 8.61375141], [78.1204071, 8.61347008], [78.12014008, 8.61347294], [78.12014008, 8.61319542], [78.11875153, 8.61319542], [78.11875153, 8.61263847], [78.11846924, 8.61264992], [78.11846924, 8.61207962], [78.11819458, 8.61208153], [78.11819458, 8.61124992], [78.11846924, 8.61124992], [78.11846924, 8.61069202], [78.11791992, 8.61069393], [78.11791992, 8.61041641], [78.11736298, 8.61042118], [78.11736298, 8.6101408], [78.1159668, 8.6101408], [78.1159668, 8.61042118], [78.11569214, 8.61041641], [78.11569214, 8.61069393], [78.11513519, 8.61069393], [78.11513519, 8.6109724], [78.11541748, 8.6109724], [78.11541748, 8.61208153], [78.11569214, 8.61208153], [78.11569214, 8.61347294], [78.11486053, 8.61347008], [78.11486053, 8.6137476], [78.11458588, 8.61375141], [78.11458588, 8.61458302], [78.11430359, 8.61458302], [78.11430359, 8.61486053], [78.11402893, 8.61486053], [78.11402893, 8.61514091], [78.11207581, 8.61514091], [78.11207581, 8.61486053], [78.11042023, 8.61486053], [78.11042023, 8.61458302], [78.10986328, 8.61458302], [78.10986328, 8.61597347], [78.11013794, 8.61597061], [78.11013794, 8.61625099], [78.11042023, 8.61625099], [78.11042023, 8.61653137], [78.11319733, 8.61653137], [78.11319733, 8.61680889], [78.11541748, 8.61680889]]], [[[78.12124634, 8.61736107], [78.12124634, 8.61680698], [78.12097168, 8.61680889], [78.12097168, 8.61653137], [78.12069702, 8.61653137], [78.12069702, 8.61625099], [78.1204071, 8.61625099], [78.1204071, 8.61569023], [78.12014008, 8.615695], [78.12014008, 8.61541653], [78.11985779, 8.6154213], [78.11985779, 8.61514091], [78.11958313, 8.61514091], [78.11958313, 8.6154213], [78.11902618, 8.61541653], [78.11902618, 8.615695], [78.11930847, 8.61569023], [78.11930847, 8.61625099], [78.11958313, 8.61625099], [78.11958313, 8.61653137], [78.11985779, 8.6165266], [78.11985779, 8.6170826], [78.12014008, 8.61707973], [78.12014008, 8.61764145], [78.1204071, 8.61764145], [78.1204071, 8.61792088], [78.12152863, 8.61792088], [78.12152863, 8.61736107], [78.12124634, 8.61736107]]], [[[78.12014008, 8.63792133], [78.12014008, 8.63764095], [78.1204071, 8.63764095], [78.1204071, 8.63735962], [78.12097168, 8.63736343], [78.12097168, 8.6370821], [78.12124634, 8.6370821], [78.12124634, 8.63680553], [78.12152863, 8.63681984], [78.12152863, 8.63653088], [78.12210083, 8.63653088], [78.12210083, 8.63597012], [78.12236023, 8.63597202], [78.12236023, 8.63541603], [78.12097168, 8.6354208], [78.12097168, 8.63514042], [78.12069702, 8.63514042], [78.12069702, 8.63457966], [78.12041473, 8.63458443], [78.12041473, 8.63430595], [78.12014008, 8.63431072], [78.12014008, 8.63374996], [78.11985779, 8.63374996], [78.11985779, 8.633461], [78.11958313, 8.63347244], [78.11958313, 8.63319397], [78.11930847, 8.63319397], [78.11930847, 8.63291645], [78.11875153, 8.63292027], [78.11875153, 8.63236046], [78.11846924, 8.63236237], [78.11846924, 8.63180637], [78.11818695, 8.63181114], [78.11818695, 8.63125038], [78.11680603, 8.63125038], [78.11680603, 8.63153172], [78.11567688, 8.63153172], [78.11567688, 8.62846947], [78.11597443, 8.62847233], [78.11597443, 8.62763977], [78.11680603, 8.62765121], [78.11680603, 8.62735939], [78.11846924, 8.62735939], [78.11846924, 8.62792015], [78.12180328, 8.62791538], [78.12180328, 8.62819576], [78.12069702, 8.62819576], [78.12069702, 8.62847233], [78.11958313, 8.62847233], [78.11958313, 8.62874985], [78.12014008, 8.62874985], [78.12014008, 8.62903023], [78.12069702, 8.62903023], [78.12069702, 8.62930965], [78.12124634, 8.62930584], [78.12124634, 8.62958431], [78.12181091, 8.62958241], [78.12181091, 8.6301403], [78.12069702, 8.6301403], [78.12069702, 8.63069439], [78.12097168, 8.63069439], [78.12097168, 8.6331892], [78.12124634, 8.63320065], [78.12124634, 8.63374996], [78.12210083, 8.63374996], [78.12210083, 8.63403034], [78.12264252, 8.63403034], [78.12264252, 8.63208199], [78.12236023, 8.63208389], [78.12236023, 8.63041782], [78.12264252, 8.63041973], [78.12264252, 8.62986183], [78.12291718, 8.62986183], [78.12291718, 8.62930584], [78.12264252, 8.62930965], [78.12264252, 8.62874985], [78.12236023, 8.62874985], [78.12236023, 8.62819576], [78.12208557, 8.62819576], [78.12208557, 8.62763977], [78.12181091, 8.62765121], [78.12181091, 8.62708092], [78.12152863, 8.62708378], [78.12152863, 8.62680626], [78.12124634, 8.62681007], [78.12124634, 8.62652969], [78.12097168, 8.62652969], [78.12097168, 8.62597084], [78.12069702, 8.62597084], [78.12069702, 8.62569332], [78.12041473, 8.62569332], [78.12041473, 8.62514019], [78.12014008, 8.62514019], [78.12014008, 8.62430954], [78.11985779, 8.62430954], [78.11985779, 8.62319088], [78.11958313, 8.62319469], [78.11958313, 8.62236118], [78.11930847, 8.62236118], [78.11930847, 8.62180519], [78.11958313, 8.62181187], [78.11958313, 8.62152004], [78.11930847, 8.62152672], [78.11930847, 8.62097263], [78.11958313, 8.62097263], [78.11958313, 8.61958313], [78.11930847, 8.61958313], [78.11930847, 8.61874866], [78.11902618, 8.61875057], [78.11902618, 8.61846161], [78.11875153, 8.61847305], [78.11875153, 8.61791706], [78.11846924, 8.61792088], [78.11846924, 8.61764145], [78.11818695, 8.61764145], [78.11818695, 8.61736107], [78.11791992, 8.61736107], [78.11791992, 8.61875057], [78.11818695, 8.61875057], [78.11819458, 8.61986065], [78.11791992, 8.61986065], [78.11791992, 8.62041855], [78.11763763, 8.62041664], [78.11763763, 8.62097263], [78.11736298, 8.62097263], [78.11736298, 8.6212492], [78.11708069, 8.6212492], [78.11708069, 8.62181187], [78.11680603, 8.62180519], [78.11680603, 8.62208271], [78.11708069, 8.62208271], [78.11708069, 8.62236118], [78.11846924, 8.62236118], [78.11846924, 8.62375164], [78.11819458, 8.62374878], [78.11819458, 8.62486076], [78.11846924, 8.62485886], [78.11846924, 8.62514019], [78.11875153, 8.62514019], [78.11875153, 8.62541962], [78.11902618, 8.62541771], [78.11902618, 8.62569332], [78.11958313, 8.62569332], [78.11958313, 8.62597084], [78.11985779, 8.62597084], [78.11985779, 8.62736225], [78.11902618, 8.62736225], [78.11902618, 8.62708378], [78.11708069, 8.62708378], [78.11708069, 8.62680626], [78.11680603, 8.62681007], [78.11680603, 8.62652969], [78.11653137, 8.62652969], [78.11653137, 8.62597084], [78.11624908, 8.62597084], [78.11624908, 8.62569332], [78.11569214, 8.62569332], [78.11569214, 8.62597084], [78.11514282, 8.62597084], [78.11514282, 8.62792015], [78.11486053, 8.62791538], [78.11486053, 8.62986183], [78.11458588, 8.62986183], [78.11458588, 8.6301403], [78.11402893, 8.6301403], [78.11402893, 8.63041973], [78.11374664, 8.63041782], [78.11374664, 8.63069439], [78.11319733, 8.63069439], [78.11319733, 8.63097191], [78.11235809, 8.63097191], [78.11235809, 8.63125038], [78.11180878, 8.63125038], [78.11180878, 8.63153172], [78.11125183, 8.6315279], [78.11125183, 8.63236237], [78.11152649, 8.63236046], [78.11152649, 8.63292027], [78.11180878, 8.63291645], [78.11180878, 8.63347244], [78.11207581, 8.633461], [78.11207581, 8.63374996], [78.11235809, 8.63374996], [78.11235809, 8.63403034], [78.11264038, 8.63403034], [78.11264038, 8.63431072], [78.11291504, 8.63430595], [78.11291504, 8.63458443], [78.11319733, 8.63458443], [78.11319733, 8.63486004], [78.11374664, 8.63486004], [78.11374664, 8.63514042], [78.11429596, 8.63514042], [78.11429596, 8.6354208], [78.11486053, 8.63541603], [78.11486053, 8.63569355], [78.11541748, 8.63569355], [78.11541748, 8.63597202], [78.1159668, 8.63597012], [78.1159668, 8.63624954], [78.11624908, 8.63624954], [78.11624908, 8.63653088], [78.11680603, 8.63653088], [78.11680603, 8.63681984], [78.11736298, 8.63680553], [78.11736298, 8.6370821], [78.11791992, 8.6370821], [78.11791992, 8.63736343], [78.11875153, 8.63735962], [78.11875153, 8.63764095], [78.11930847, 8.63764095], [78.11930847, 8.63792133], [78.12014008, 8.63792133]]], [[[78.11708069, 8.65653038], [78.11708069, 8.6554203], [78.11736298, 8.6554203], [78.11736298, 8.65485859], [78.11763763, 8.6548624], [78.11763763, 8.65458393], [78.11791992, 8.65458393], [78.11791992, 8.65430641], [78.11846924, 8.65431023], [78.11846924, 8.65402985], [78.11875153, 8.65402985], [78.11875153, 8.65374947], [78.11930847, 8.65374947], [78.11930847, 8.65347099], [78.11985779, 8.65347099], [78.11985779, 8.65180492], [78.12014008, 8.65181923], [78.12014008, 8.65125179], [78.1204071, 8.65125179], [78.1204071, 8.65097141], [78.12208557, 8.65097141], [78.12208557, 8.65069485], [78.12291718, 8.65069485], [78.12291718, 8.65041733], [78.12374878, 8.65042019], [78.12374878, 8.65014172], [78.12403107, 8.65014172], [78.12403107, 8.64986134], [78.12430573, 8.64986134], [78.12430573, 8.64958286], [78.12458038, 8.64958286], [78.12458038, 8.64624882], [78.1248703, 8.64625072], [78.1248703, 8.64568996], [78.12513733, 8.64569473], [78.12513733, 8.64236069], [78.12541962, 8.64236069], [78.12541962, 8.64208317], [78.12486267, 8.64208317], [78.12486267, 8.6418047], [78.12403107, 8.64181137], [78.12403107, 8.64125061], [78.12431335, 8.64125061], [78.12431335, 8.64014053], [78.12458038, 8.64014053], [78.12458038, 8.63931084], [78.12541962, 8.63931084], [78.12541962, 8.63903141], [78.12513733, 8.63903141], [78.12513733, 8.63875103], [78.12458038, 8.63875103], [78.12458038, 8.6384697], [78.12403107, 8.6384716], [78.12403107, 8.63819408], [78.12319183, 8.63819027], [78.12319183, 8.63875103], [78.12264252, 8.63875103], [78.12264252, 8.63903141], [78.12236023, 8.63903141], [78.12236023, 8.63931084], [78.12264252, 8.63930416], [78.12264252, 8.63986015], [78.12291718, 8.63986015], [78.12291718, 8.64042091], [78.12319183, 8.6404171], [78.12319183, 8.64097309], [78.12152863, 8.64097023], [78.12152863, 8.64125061], [78.11985779, 8.64125061], [78.11985779, 8.64181137], [78.12014008, 8.6418047], [78.12014008, 8.64208317], [78.1204071, 8.64208031], [78.1204071, 8.64236069], [78.12097168, 8.64236069], [78.12097168, 8.64263916], [78.12124634, 8.64262962], [78.12124634, 8.64292145], [78.12152863, 8.64291668], [78.12152863, 8.64319515], [78.12180328, 8.64319515], [78.12180328, 8.64347267], [78.12210083, 8.6434679], [78.12210083, 8.64403057], [78.12236023, 8.64403057], [78.12236023, 8.6443119], [78.12152863, 8.64430523], [78.12152863, 8.64458275], [78.12014008, 8.64458275], [78.12014008, 8.64402676], [78.11985779, 8.64403057], [78.11985779, 8.64375114], [78.11958313, 8.64375114], [78.11958313, 8.64319515], [78.11930847, 8.64319515], [78.11930847, 8.64291668], [78.11902618, 8.64292145], [78.11902618, 8.64262962], [78.11875153, 8.64263916], [78.11875153, 8.64208317], [78.11846924, 8.64208317], [78.11846924, 8.6418047], [78.11736298, 8.6418047], [78.11736298, 8.64236069], [78.11708069, 8.64236069], [78.11708069, 8.64403057], [78.11680603, 8.64402676], [78.11680603, 8.64486122], [78.11708069, 8.64486122], [78.11708069, 8.64514065], [78.11763763, 8.64514065], [78.11763763, 8.64542198], [78.11791992, 8.64541721], [78.11791992, 8.64569473], [78.11846924, 8.64569473], [78.11846924, 8.64597321], [78.11875153, 8.64597321], [78.11875153, 8.64958286], [78.11846924, 8.64958286], [78.11846924, 8.64986134], [78.11791992, 8.64986134], [78.11791992, 8.65014172], [78.11763763, 8.65013885], [78.11763763, 8.65069485], [78.11791992, 8.65069103], [78.11791992, 8.65181923], [78.11763763, 8.65181923], [78.11763763, 8.65264034], [78.11736298, 8.65264034], [78.11736298, 8.65319347], [78.11708069, 8.65319347], [78.11708069, 8.65374947], [78.11680603, 8.65374947], [78.11680603, 8.65458393], [78.11653137, 8.65456963], [78.11653137, 8.6554203], [78.11680603, 8.6554203], [78.11680603, 8.65653038], [78.11708069, 8.65653038]]], [[[78.69458008, 9.15486145], [78.69458008, 9.15514088], [78.69625092, 9.15514088], [78.69625092, 9.15375137], [78.69652557, 9.15375137], [78.69652557, 9.15125084], [78.69596863, 9.15125084], [78.69596863, 9.15097332], [78.69374847, 9.15097332], [78.69374847, 9.15125084], [78.69319153, 9.1512394], [78.69319153, 9.15153122], [78.69291687, 9.15152645], [78.69291687, 9.1520834], [78.69319153, 9.15207958], [78.69319153, 9.1526413], [78.69347382, 9.15263939], [78.69347382, 9.1534729], [78.6937561, 9.15347099], [78.6937561, 9.15402889], [78.69403076, 9.15402889], [78.69403076, 9.15430546], [78.69430542, 9.15430546], [78.69430542, 9.15486145], [78.69458008, 9.15486145]]], [[[78.72986603, 9.15569019], [78.72986603, 9.15625095], [78.73069763, 9.15625095], [78.73069763, 9.15597057], [78.73097229, 9.15597343], [78.73097229, 9.15569496], [78.73152924, 9.15569496], [78.73152924, 9.15541744], [78.73208618, 9.15542126], [78.73208618, 9.15318966], [78.73180389, 9.15319538], [78.73180389, 9.15125084], [78.73042297, 9.1512394], [78.73042297, 9.15153122], [78.72986603, 9.15153122], [78.72986603, 9.15181065], [78.72958374, 9.15180683], [78.72958374, 9.1520834], [78.72902679, 9.1520834], [78.72902679, 9.15236092], [78.72875214, 9.15236092], [78.72875214, 9.1526413], [78.72902679, 9.1526413], [78.72902679, 9.15292072], [78.72930908, 9.15291691], [78.72930908, 9.15319538], [78.72957611, 9.15318966], [78.72957611, 9.15375137], [78.7298584, 9.15375137], [78.7298584, 9.15486145], [78.73014069, 9.15486145], [78.73014069, 9.15569496], [78.72986603, 9.15569019]]], [[[78.49097443, 9.09291553], [78.49097443, 9.09319401], [78.49180603, 9.09319401], [78.49180603, 9.09291553], [78.49208832, 9.09292126], [78.49208832, 9.09235954], [78.49236298, 9.0923624], [78.49236298, 9.09208202], [78.49263763, 9.09208202], [78.49263763, 9.09180641], [78.49318695, 9.09181118], [78.49318695, 9.09152985], [78.49375153, 9.09152985], [78.49375153, 9.09125042], [78.49430847, 9.09125042], [78.49430847, 9.09097195], [78.49485779, 9.09097195], [78.49485779, 9.09069443], [78.49514008, 9.09069443], [78.49514008, 9.09013844], [78.49485779, 9.09014034], [78.49485779, 9.08931065], [78.49458313, 9.08931065], [78.49458313, 9.08847046], [78.49430847, 9.08847237], [78.49430847, 9.08791637], [78.49402618, 9.08792019], [78.49402618, 9.08736038], [78.49375153, 9.08736229], [78.49375153, 9.0868063], [78.49346924, 9.08681011], [78.49346924, 9.08597183], [78.49319458, 9.08597183], [78.49319458, 9.08569431], [78.49263763, 9.08569431], [78.49263763, 9.08597183], [78.49236298, 9.08597183], [78.49236298, 9.08652973], [78.49208069, 9.08652782], [78.49208069, 9.08708382], [78.49180603, 9.08708382], [78.49180603, 9.08763981], [78.49124908, 9.08763981], [78.49124908, 9.08792019], [78.49069214, 9.08791637], [78.49069214, 9.08819389], [78.49013519, 9.08819389], [78.49013519, 9.08847237], [78.48958588, 9.08847046], [78.48958588, 9.08875179], [78.4890213, 9.08875179], [78.4890213, 9.08903027], [78.48874664, 9.08903027], [78.48874664, 9.08931065], [78.48847198, 9.08930588], [78.48847198, 9.08985996], [78.48819733, 9.08985996], [78.48819733, 9.09014034], [78.48792267, 9.09014034], [78.48792267, 9.09041977], [78.48847198, 9.09041595], [78.48847198, 9.09069443], [78.48930359, 9.09069443], [78.48930359, 9.09097195], [78.48986053, 9.09097195], [78.48986053, 9.09125042], [78.49014282, 9.09125042], [78.49014282, 9.09181118], [78.49041748, 9.09180641], [78.49041748, 9.0923624], [78.49069214, 9.09235954], [78.49069214, 9.09292126], [78.49097443, 9.09291553]]], [[[78.57902527, 9.11208439], [78.57902527, 9.11236191], [78.58041382, 9.11236191], [78.58041382, 9.11208439], [78.58097076, 9.11208439], [78.58097076, 9.11180592], [78.58180237, 9.11180973], [78.58180237, 9.1115303], [78.58319092, 9.1115303], [78.58319092, 9.11125183], [78.5845871, 9.11125183], [78.5845871, 9.11097145], [78.58486176, 9.11097145], [78.58486176, 9.11069584], [78.58513641, 9.11069584], [78.58513641, 9.11041546], [78.58541107, 9.11042023], [78.58541107, 9.11013985], [78.58569336, 9.11013985], [78.58569336, 9.10986233], [78.58625031, 9.10986233], [78.58625031, 9.1095829], [78.58652496, 9.1095829], [78.58652496, 9.10930538], [78.58625031, 9.10932064], [78.58625031, 9.10874939], [78.58597565, 9.10874939], [78.58597565, 9.10847092], [78.58569336, 9.10847092], [78.58569336, 9.1081953], [78.58513641, 9.1081953], [78.58513641, 9.10791683], [78.58347321, 9.10791969], [78.58347321, 9.10763931], [78.58319092, 9.10763931], [78.58319092, 9.10736084], [78.58291626, 9.10736084], [78.58291626, 9.10680962], [78.5826416, 9.10680962], [78.5826416, 9.10652924], [78.58236694, 9.10652924], [78.58236694, 9.10625076], [78.58207703, 9.10625076], [78.58207703, 9.10597134], [78.58180237, 9.10597324], [78.58180237, 9.10541725], [78.58152771, 9.10542202], [78.58152771, 9.10514069], [78.58125305, 9.10514069], [78.58125305, 9.10486126], [78.58097076, 9.10486126], [78.58097076, 9.10458279], [78.58069611, 9.10458279], [78.58069611, 9.10402679], [78.58040619, 9.10403061], [78.58040619, 9.10375118], [78.58013916, 9.10375118], [78.58013916, 9.1034708], [78.57902527, 9.1034708], [78.57902527, 9.10319519], [78.57791901, 9.10319519], [78.57791901, 9.10291672], [78.57347107, 9.10292244], [78.57347107, 9.10264111], [78.57319641, 9.10264111], [78.57319641, 9.1020813], [78.57180786, 9.1020813], [78.57180786, 9.10292244], [78.57208252, 9.10292244], [78.57208252, 9.10403061], [78.57180786, 9.10402679], [78.57180786, 9.10458279], [78.57208252, 9.10458279], [78.57208252, 9.10486126], [78.57263947, 9.10486126], [78.57263947, 9.10514069], [78.57290649, 9.10514069], [78.57290649, 9.10542202], [78.57319641, 9.10541725], [78.57319641, 9.10569477], [78.57347107, 9.10569477], [78.57347107, 9.10597324], [78.57402802, 9.10597134], [78.57402802, 9.10625076], [78.57430267, 9.10625076], [78.57430267, 9.10652924], [78.57457733, 9.10652924], [78.57457733, 9.10680962], [78.57485962, 9.10680485], [78.57485962, 9.10708332], [78.57541656, 9.10708141], [78.57541656, 9.10736084], [78.57569122, 9.10736084], [78.57569122, 9.10763931], [78.57597351, 9.10763931], [78.57597351, 9.10847092], [78.57624817, 9.10847092], [78.57624817, 9.1095829], [78.57653046, 9.10958099], [78.57653046, 9.11042023], [78.57680511, 9.11041546], [78.57680511, 9.11069584], [78.57736206, 9.11069584], [78.57736206, 9.11097145], [78.57763672, 9.11097145], [78.57763672, 9.11125183], [78.57791901, 9.11125183], [78.57791901, 9.1115303], [78.57818604, 9.1115303], [78.57818604, 9.11180973], [78.57875061, 9.11180592], [78.57875061, 9.11208439], [78.57902527, 9.11208439]]], [[[78.48735809, 9.13458347], [78.48735809, 9.13486099], [78.48791504, 9.13486099], [78.48791504, 9.134305], [78.48764038, 9.13430977], [78.48764038, 9.13319969], [78.48735809, 9.13319969], [78.48735809, 9.13236141], [78.48708344, 9.13236141], [78.48708344, 9.13208294], [78.48680878, 9.13208294], [78.48680878, 9.13097095], [78.48652649, 9.13097095], [78.48652649, 9.13069534], [78.48542023, 9.13069534], [78.48542023, 9.13097095], [78.48513794, 9.13097095], [78.48513794, 9.13125134], [78.48458099, 9.13125134], [78.48458099, 9.13181019], [78.48486328, 9.13180542], [78.48486328, 9.13236141], [78.48513794, 9.13236141], [78.48513794, 9.13264084], [78.48486328, 9.13263893], [78.48486328, 9.1334734], [78.48513794, 9.13347054], [78.48513794, 9.13375092], [78.48542023, 9.13375092], [78.48542023, 9.13402939], [78.48625183, 9.13402939], [78.48625183, 9.13430977], [78.48708344, 9.134305], [78.48708344, 9.13458347], [78.48735809, 9.13458347]]], [[[78.53819275, 9.10569477], [78.53819275, 9.10597324], [78.53930664, 9.10597324], [78.53930664, 9.10569477], [78.5395813, 9.10569477], [78.5395813, 9.10541725], [78.53930664, 9.10542202], [78.53930664, 9.10514069], [78.53901672, 9.10514069], [78.53901672, 9.10458088], [78.53874969, 9.10458279], [78.53874969, 9.10430527], [78.53848267, 9.10431194], [78.53848267, 9.1034708], [78.53819275, 9.1034708], [78.53819275, 9.10291672], [78.5376358, 9.10292244], [78.5376358, 9.10264111], [78.53708649, 9.10264111], [78.53708649, 9.10236073], [78.53624725, 9.10236073], [78.53624725, 9.1020813], [78.53514099, 9.1020813], [78.53514099, 9.10236073], [78.5348587, 9.10236073], [78.5348587, 9.10292244], [78.53514099, 9.10291672], [78.53514099, 9.10319519], [78.53541565, 9.10319519], [78.53541565, 9.1034708], [78.5359726, 9.10347271], [78.5359726, 9.10375118], [78.53624725, 9.10375118], [78.53624725, 9.10403061], [78.53652954, 9.10403061], [78.53652954, 9.10431194], [78.5368042, 9.10430527], [78.5368042, 9.10458279], [78.53736115, 9.10458279], [78.53736115, 9.10486126], [78.5376358, 9.10486126], [78.5376358, 9.10514069], [78.53791809, 9.10513878], [78.53791809, 9.10569477], [78.53819275, 9.10569477]]], [[[78.82819366, 9.17125034], [78.82818604, 9.17097187], [78.82847595, 9.17097187], [78.82847595, 9.17041588], [78.82875061, 9.17041969], [78.82875061, 9.16903019], [78.8290329, 9.16903019], [78.8290329, 9.16708088], [78.82875061, 9.16708374], [78.82875061, 9.16597176], [78.82847595, 9.16597176], [78.82847595, 9.16541767], [78.82818604, 9.16541958], [78.82818604, 9.16514015], [78.82791901, 9.16514015], [78.82791901, 9.16486168], [78.82541656, 9.16486168], [78.82541656, 9.16458416], [78.82485962, 9.16458416], [78.82485962, 9.16430569], [78.82430267, 9.16431046], [78.82430267, 9.16403198], [78.82375336, 9.16403198], [78.82375336, 9.1637516], [78.82289886, 9.1637516], [78.82289886, 9.16347122], [78.82236481, 9.16347122], [78.82236481, 9.16124916], [78.82125092, 9.16125107], [78.82125092, 9.16097069], [78.82096863, 9.1609726], [78.82096863, 9.1604166], [78.82068634, 9.16043091], [78.82068634, 9.15958118], [78.82041931, 9.15958309], [78.82041931, 9.15847111], [78.82013702, 9.15847111], [78.82013702, 9.15763855], [78.81931305, 9.15764141], [78.81931305, 9.15792179], [78.81485748, 9.15792179], [78.81485748, 9.15875053], [78.8170929, 9.15875053], [78.8170929, 9.15903187], [78.81735992, 9.15903187], [78.81735992, 9.15931034], [78.81764221, 9.15930462], [78.81764221, 9.15958309], [78.81791687, 9.15958309], [78.81791687, 9.15986061], [78.81819153, 9.15986061], [78.81819153, 9.16014194], [78.81847382, 9.16013908], [78.81847382, 9.16069317], [78.81874847, 9.16069126], [78.81874847, 9.16152954], [78.81903076, 9.16152668], [78.81903076, 9.16208267], [78.81930542, 9.16208267], [78.81930542, 9.16236115], [78.81958008, 9.16235924], [78.81958008, 9.16263866], [78.81986237, 9.16263866], [78.81986237, 9.16292191], [78.82013702, 9.16291809], [78.82013702, 9.16319561], [78.82041931, 9.16319561], [78.82041931, 9.16347122], [78.82068634, 9.16347122], [78.82068634, 9.1637516], [78.82096863, 9.1637516], [78.82096863, 9.16403198], [78.82208252, 9.16403198], [78.82208252, 9.16431046], [78.82263947, 9.16430569], [78.82263947, 9.16458416], [78.82318878, 9.1645813], [78.82318878, 9.16486168], [78.82347107, 9.16486168], [78.82347107, 9.16514015], [78.82402802, 9.16514015], [78.82402802, 9.16541958], [78.82458496, 9.16541767], [78.82458496, 9.16569424], [78.82485962, 9.16569424], [78.82485962, 9.16597176], [78.82514191, 9.16597366], [78.82514191, 9.16625023], [78.82541656, 9.16623974], [78.82541656, 9.16681004], [78.82569122, 9.16680622], [78.82569122, 9.16708374], [78.82596588, 9.16708088], [78.82596588, 9.16763973], [78.82624817, 9.16763973], [78.82624817, 9.16847229], [78.82653046, 9.16846943], [78.82653046, 9.16903019], [78.82681274, 9.16903019], [78.82681274, 9.16986179], [78.82707977, 9.16985989], [78.82707977, 9.17069435], [78.82736206, 9.17069435], [78.82736206, 9.17125034], [78.82819366, 9.17125034]]], [[[78.94069672, 9.18458271], [78.94069672, 9.18430519], [78.94042206, 9.18431187], [78.94042206, 9.18403053], [78.94013977, 9.18403053], [78.94013977, 9.18375111], [78.93958282, 9.18375111], [78.93958282, 9.18347263], [78.93930817, 9.18347263], [78.93930817, 9.18319511], [78.93875122, 9.18319511], [78.93875122, 9.18263912], [78.93763733, 9.18264103], [78.93763733, 9.18292141], [78.93680573, 9.18291664], [78.93680573, 9.18319511], [78.93514252, 9.18319511], [78.93514252, 9.18291664], [78.93347168, 9.18292141], [78.93347168, 9.18264103], [78.9329071, 9.18264103], [78.9329071, 9.18236065], [78.93235779, 9.18236065], [78.93235779, 9.18208313], [78.93208313, 9.18208313], [78.93208313, 9.18180466], [78.93154144, 9.18180943], [78.93154144, 9.18153954], [78.92958069, 9.18153954], [78.92958069, 9.18180943], [78.92847443, 9.18180466], [78.92847443, 9.18208313], [78.92736053, 9.18208313], [78.92736053, 9.18236065], [78.92624664, 9.18236065], [78.92624664, 9.18264103], [78.91902924, 9.18264103], [78.91902924, 9.18236065], [78.91791534, 9.18236065], [78.91791534, 9.18208313], [78.91652679, 9.18208313], [78.91652679, 9.18180466], [78.9154129, 9.18180943], [78.9154129, 9.18153954], [78.9145813, 9.18153954], [78.9145813, 9.18125057], [78.91348267, 9.18125057], [78.91348267, 9.18097115], [78.9126358, 9.18097305], [78.9126358, 9.18069458], [78.91152954, 9.18069458], [78.91152954, 9.18041706], [78.91069794, 9.18042088], [78.91069794, 9.18014145], [78.90875244, 9.18014145], [78.90875244, 9.18042088], [78.90847015, 9.18041706], [78.90847015, 9.18069458], [78.9070816, 9.18069458], [78.9070816, 9.18041706], [78.90569305, 9.18042088], [78.90569305, 9.18014145], [78.9054184, 9.18014145], [78.9054184, 9.17986107], [78.90486145, 9.17986107], [78.90486145, 9.1795826], [78.90458679, 9.1795826], [78.90458679, 9.17930698], [78.90431213, 9.17930889], [78.90431213, 9.17903137], [78.90374756, 9.17903137], [78.90374756, 9.17875099], [78.9034729, 9.17875099], [78.9034729, 9.17846966], [78.90319824, 9.17847347], [78.90319824, 9.178195], [78.9026413, 9.178195], [78.9026413, 9.17791653], [78.90125275, 9.17791653], [78.90125275, 9.178195], [78.90013885, 9.178195], [78.90013885, 9.17847347], [78.89930725, 9.17846966], [78.89930725, 9.17875099], [78.89901733, 9.17875099], [78.89901733, 9.17903137], [78.89875031, 9.17903137], [78.89875031, 9.17930889], [78.89847565, 9.17930698], [78.89847565, 9.1795826], [78.89875031, 9.1795826], [78.89875031, 9.17986107], [78.89930725, 9.17986107], [78.89930725, 9.18014145], [78.89958191, 9.18014145], [78.89958191, 9.18042088], [78.8998642, 9.18041706], [78.8998642, 9.18069458], [78.90041351, 9.18069458], [78.90041351, 9.18097305], [78.9006958, 9.18097115], [78.9006958, 9.18125057], [78.90097046, 9.18125057], [78.90097046, 9.18153954], [78.90154266, 9.18153954], [78.90154266, 9.18180943], [78.90180206, 9.18180466], [78.90180206, 9.18208313], [78.90235901, 9.18208313], [78.90235901, 9.18236065], [78.90291595, 9.18236065], [78.90291595, 9.18264103], [78.90374756, 9.18264103], [78.90374756, 9.18292141], [78.9043045, 9.18291664], [78.9043045, 9.18319511], [78.90486145, 9.18319511], [78.90486145, 9.18347263], [78.90597534, 9.18347263], [78.90597534, 9.18319511], [78.90625, 9.18319511], [78.90625, 9.18291664], [78.90680695, 9.18292141], [78.90680695, 9.18264103], [78.90734863, 9.18264103], [78.90734863, 9.18180943], [78.90820313, 9.18180943], [78.90820313, 9.18153954], [78.90875244, 9.18153954], [78.90875244, 9.18125057], [78.91040802, 9.18125057], [78.91040802, 9.18153954], [78.91179657, 9.18153954], [78.91179657, 9.18180943], [78.91291809, 9.18180466], [78.91291809, 9.18236065], [78.91401672, 9.18236065], [78.91401672, 9.18264103], [78.9154129, 9.18264103], [78.9154129, 9.18292141], [78.91652679, 9.18291664], [78.91652679, 9.18319511], [78.91791534, 9.18319511], [78.91791534, 9.18347263], [78.91902924, 9.18347263], [78.91902924, 9.18375111], [78.92041779, 9.18375111], [78.92041779, 9.18403053], [78.92542267, 9.18403053], [78.92542267, 9.18375111], [78.92597198, 9.18375111], [78.92597198, 9.18403053], [78.92652893, 9.18403053], [78.92652893, 9.18431187], [78.92874908, 9.18431187], [78.92874908, 9.18403053], [78.93041992, 9.18403053], [78.93041992, 9.18375111], [78.93069458, 9.18375111], [78.93068695, 9.18347073], [78.93514252, 9.18347263], [78.93514252, 9.18375111], [78.93681335, 9.18375111], [78.93681335, 9.18403053], [78.93736267, 9.18403053], [78.93736267, 9.18431187], [78.93763733, 9.18430519], [78.93763733, 9.18458271], [78.93819427, 9.18458271], [78.93819427, 9.18486118], [78.93875122, 9.18486118], [78.93875122, 9.18514061], [78.93902588, 9.18514061], [78.93902588, 9.18542194], [78.94152832, 9.18542194], [78.94152832, 9.18514061], [78.94124603, 9.18514061], [78.94124603, 9.18486118], [78.94097137, 9.18486118], [78.94097137, 9.18458271], [78.94069672, 9.18458271]]], [[[78.96765137, 9.18931007], [78.96765137, 9.18902969], [78.96819305, 9.18902969], [78.96819305, 9.18847084], [78.96847534, 9.18847084], [78.96847534, 9.18791676], [78.96875, 9.18791962], [78.96875, 9.18735027], [78.96902466, 9.18736076], [78.96902466, 9.18708324], [78.9695816, 9.18708324], [78.9695816, 9.18680477], [78.97039795, 9.18680954], [78.97039795, 9.18625069], [78.97068787, 9.18625069], [78.97068787, 9.18597126], [78.97097015, 9.18597317], [78.97097015, 9.18569469], [78.97013855, 9.18569469], [78.97013855, 9.18541718], [78.96985626, 9.18542194], [78.96985626, 9.18514061], [78.9695816, 9.18514061], [78.9695816, 9.18486118], [78.96902466, 9.18486118], [78.96902466, 9.18458271], [78.96875, 9.18458271], [78.96875, 9.18430519], [78.96848297, 9.18431187], [78.96848297, 9.18403053], [78.96736145, 9.18402672], [78.96736145, 9.18486118], [78.96708679, 9.18486118], [78.96708679, 9.18569469], [78.96679688, 9.18569088], [78.96679688, 9.18653202], [78.96652985, 9.18652725], [78.96652985, 9.18708324], [78.96624756, 9.18708324], [78.96624756, 9.18736076], [78.9659729, 9.18735027], [78.9659729, 9.18763924], [78.96569824, 9.18763924], [78.96569061, 9.18847084], [78.96541595, 9.18847084], [78.96541595, 9.18874931], [78.96624756, 9.18874931], [78.96624756, 9.18902969], [78.96679688, 9.18902969], [78.96679688, 9.18931007], [78.96765137, 9.18931007]]], [[[79.07013702, 9.20819473], [79.07013702, 9.20708275], [79.06986237, 9.20708275], [79.06986237, 9.20680523], [79.06958008, 9.20681095], [79.06958008, 9.20653057], [79.06931305, 9.20653057], [79.06931305, 9.20625114], [79.06903076, 9.20625114], [79.06903076, 9.20597267], [79.06874847, 9.20597267], [79.06874847, 9.20541668], [79.06958008, 9.20542145], [79.06958008, 9.20514107], [79.06984711, 9.20514107], [79.06984711, 9.20485973], [79.07041931, 9.20485973], [79.07041931, 9.20458221], [79.07069397, 9.20458221], [79.07069397, 9.20375061], [79.07096863, 9.20375061], [79.07096863, 9.20347023], [79.07208252, 9.20347214], [79.07208252, 9.20236015], [79.07263947, 9.20236015], [79.07263947, 9.20208359], [79.07319641, 9.20208359], [79.07319641, 9.20180416], [79.07375336, 9.20181084], [79.07375336, 9.20153141], [79.07430267, 9.20153141], [79.07430267, 9.20125008], [79.07459259, 9.20125008], [79.07459259, 9.2009697], [79.07514191, 9.2009716], [79.07514191, 9.20069408], [79.07541656, 9.20069408], [79.07541656, 9.20041561], [79.07598114, 9.20042133], [79.07598114, 9.20014], [79.07681274, 9.20014], [79.07681274, 9.19985962], [79.08040619, 9.19985962], [79.08040619, 9.20042133], [79.08069611, 9.20041561], [79.08069611, 9.20069408], [79.08152771, 9.20069408], [79.08152771, 9.20041561], [79.08178711, 9.20042133], [79.08178711, 9.20014], [79.08235931, 9.20014], [79.08235931, 9.19958019], [79.0826416, 9.1995821], [79.0826416, 9.19902802], [79.08291626, 9.19902992], [79.08291626, 9.19847202], [79.08347321, 9.19847202], [79.08347321, 9.19819355], [79.08430481, 9.19819355], [79.08430481, 9.19791603], [79.0848465, 9.19791985], [79.0848465, 9.19764042], [79.08513641, 9.19764042], [79.08513641, 9.19736195], [79.08569336, 9.19736195], [79.08569336, 9.19708443], [79.08680725, 9.19708443], [79.08680725, 9.19652843], [79.08653259, 9.19654179], [79.08653259, 9.19624996], [79.08680725, 9.19624996], [79.08680725, 9.19596958], [79.08708191, 9.19597244], [79.08708191, 9.19486237], [79.08680725, 9.19486237], [79.08680725, 9.19458389], [79.08597565, 9.19458389], [79.08597565, 9.19430637], [79.08625031, 9.19431019], [79.08625031, 9.19375038], [79.08653259, 9.19375038], [79.08653259, 9.19431019], [79.08708191, 9.19430637], [79.08708191, 9.19458389], [79.08792114, 9.19458199], [79.08792114, 9.19514179], [79.0881958, 9.19513988], [79.0881958, 9.19597244], [79.08847046, 9.19596958], [79.08847046, 9.19681072], [79.08821106, 9.19681072], [79.08821106, 9.19791985], [79.08875275, 9.19791603], [79.08875275, 9.19819355], [79.0890274, 9.19819164], [79.0890274, 9.19874954], [79.08930206, 9.19874954], [79.08930206, 9.19986153], [79.09041595, 9.19985962], [79.09041595, 9.20014], [79.09098053, 9.20014], [79.09098053, 9.19958019], [79.09124756, 9.1995821], [79.09124756, 9.19902802], [79.09152985, 9.19902992], [79.09152985, 9.19596958], [79.09124756, 9.19597244], [79.09124756, 9.19569397], [79.0909729, 9.19569397], [79.0909729, 9.19541645], [79.09069824, 9.19542027], [79.09069824, 9.19486046], [79.09041595, 9.19486237], [79.09041595, 9.19458389], [79.0901413, 9.19458389], [79.0901413, 9.19430637], [79.08985901, 9.19431019], [79.08985901, 9.1940279], [79.08930206, 9.1940279], [79.08930206, 9.19348145], [79.0890274, 9.19348145], [79.0890274, 9.19291973], [79.08847046, 9.19291973], [79.08847046, 9.1926403], [79.08792114, 9.1926403], [79.08792114, 9.19236183], [79.08763885, 9.19236183], [79.08763885, 9.19208431], [79.08708191, 9.19208431], [79.08708191, 9.19180584], [79.08513641, 9.19180584], [79.08513641, 9.19208431], [79.0845871, 9.19208431], [79.0845871, 9.19236183], [79.08429718, 9.19236183], [79.08429718, 9.1926403], [79.08374786, 9.1926403], [79.08374786, 9.19291973], [79.08347321, 9.19291782], [79.08347321, 9.19319439], [79.08291626, 9.19319057], [79.08291626, 9.19348145], [79.0826416, 9.19347191], [79.0826416, 9.19375038], [79.08207703, 9.19375038], [79.08207703, 9.1940279], [79.08180237, 9.1940279], [79.08180237, 9.19458389], [79.08152771, 9.19458389], [79.08152771, 9.19486237], [79.08125305, 9.19486046], [79.08125305, 9.19514179], [79.08097076, 9.19514179], [79.08097076, 9.19542027], [79.08041382, 9.19541645], [79.08041382, 9.19569397], [79.08013916, 9.19569397], [79.08013916, 9.19597244], [79.07904053, 9.19596958], [79.07904053, 9.19624996], [79.07818604, 9.19624996], [79.07818604, 9.19654179], [79.07791901, 9.19654179], [79.07791901, 9.19681072], [79.07707977, 9.19680595], [79.07707977, 9.19708443], [79.07624817, 9.19708443], [79.07624817, 9.19736195], [79.07569122, 9.19736195], [79.07569122, 9.19764042], [79.07485962, 9.19764042], [79.07485962, 9.19791985], [79.07430267, 9.19791603], [79.07430267, 9.19819355], [79.07347107, 9.19819355], [79.07347107, 9.19847202], [79.07290649, 9.19847202], [79.07290649, 9.19874954], [79.07180786, 9.19874954], [79.07180786, 9.19902992], [79.07068634, 9.19902992], [79.07068634, 9.19931126], [79.06930542, 9.19930553], [79.06930542, 9.1995821], [79.06791687, 9.1995821], [79.06791687, 9.19986153], [79.06513977, 9.19986153], [79.06513977, 9.1995821], [79.06458282, 9.1995821], [79.06458282, 9.19986153], [79.06430817, 9.19986153], [79.06430817, 9.1995821], [79.06402588, 9.1995821], [79.06402588, 9.19930553], [79.06346893, 9.19931126], [79.06346893, 9.19902992], [79.06318665, 9.19902992], [79.06318665, 9.19874954], [79.06263733, 9.19874954], [79.06263733, 9.19847202], [79.06236267, 9.19847202], [79.06236267, 9.19819355], [79.06208038, 9.19819355], [79.06208038, 9.19791603], [79.06153107, 9.19791985], [79.06153107, 9.19736195], [79.06124878, 9.19736195], [79.06124878, 9.19708443], [79.06097412, 9.19708443], [79.06097412, 9.19680595], [79.06041718, 9.19681072], [79.06041718, 9.19654179], [79.05902863, 9.19654179], [79.05902863, 9.19681072], [79.05847168, 9.19680595], [79.05847168, 9.19708443], [79.05819702, 9.1970787], [79.05819702, 9.19764042], [79.05847168, 9.19764042], [79.05847168, 9.19791985], [79.05874634, 9.19791603], [79.05874634, 9.19847202], [79.05902863, 9.19847202], [79.05902863, 9.19902992], [79.05930328, 9.19902802], [79.05930328, 9.1995821], [79.0595932, 9.19958019], [79.0595932, 9.20014], [79.05986023, 9.20014], [79.05986023, 9.20042133], [79.06014252, 9.20041561], [79.06014252, 9.2009716], [79.05986023, 9.2009716], [79.05986023, 9.20236015], [79.06014252, 9.20235062], [79.06014252, 9.20264053], [79.06069183, 9.20264053], [79.06069183, 9.20292091], [79.06124878, 9.20291615], [79.06124878, 9.20319366], [79.06153107, 9.20319366], [79.06153107, 9.20347214], [79.06181335, 9.20347023], [79.06181335, 9.20375061], [79.06208038, 9.20375061], [79.06208038, 9.20403099], [79.06236267, 9.20403099], [79.06236267, 9.20431137], [79.06263733, 9.2043066], [79.06263733, 9.20458221], [79.06291962, 9.20458221], [79.06291962, 9.20485973], [79.06318665, 9.20485973], [79.06318665, 9.20514107], [79.06346893, 9.20514107], [79.06346893, 9.20542145], [79.06402588, 9.20541668], [79.06402588, 9.20569515], [79.06458282, 9.20569515], [79.06458282, 9.20597267], [79.06485748, 9.20597267], [79.06485748, 9.20625114], [79.0654068, 9.20625114], [79.0654068, 9.20653057], [79.06597137, 9.20653057], [79.06597137, 9.20681095], [79.06625366, 9.20680523], [79.06625366, 9.20708275], [79.06652832, 9.20707989], [79.06652832, 9.20764065], [79.06681061, 9.20764065], [79.06681061, 9.20792103], [79.06874847, 9.20791721], [79.06874847, 9.20819473], [79.07013702, 9.20819473]]], [[[79.14206696, 9.21486092], [79.14206696, 9.21402931], [79.14180756, 9.21402931], [79.14180756, 9.21347141], [79.14152527, 9.21347332], [79.14152527, 9.21319485], [79.14125061, 9.21319485], [79.14125061, 9.21291733], [79.14041901, 9.21291924], [79.14041901, 9.21264076], [79.14013672, 9.21264076], [79.14013672, 9.21236134], [79.13957977, 9.21236134], [79.13957977, 9.21208286], [79.13903046, 9.21208286], [79.13903046, 9.21236134], [79.13846588, 9.21236134], [79.13846588, 9.21375084], [79.13874817, 9.21375084], [79.13874817, 9.21402931], [79.13932037, 9.21402931], [79.13932037, 9.21430969], [79.14013672, 9.21430492], [79.14013672, 9.2145834], [79.14068604, 9.21458054], [79.14068604, 9.21486092], [79.14206696, 9.21486092]]], [[[79.12568665, 9.2179203], [79.12568665, 9.21764183], [79.12819672, 9.21764183], [79.12819672, 9.2173624], [79.12875366, 9.2173624], [79.12875366, 9.21708298], [79.12930298, 9.21708298], [79.12930298, 9.21680546], [79.1295929, 9.21681023], [79.1295929, 9.21652985], [79.13485718, 9.21652985], [79.13485718, 9.21624947], [79.13513947, 9.21624947], [79.13513947, 9.21597099], [79.13541412, 9.21597099], [79.13541412, 9.21569538], [79.13569641, 9.21569538], [79.13569641, 9.21541691], [79.13597107, 9.21541977], [79.13597107, 9.21486092], [79.13513947, 9.21486092], [79.13513947, 9.2145834], [79.13430786, 9.2145834], [79.13430786, 9.21430492], [79.13375092, 9.21430969], [79.13375092, 9.21402931], [79.13208008, 9.21402931], [79.13208008, 9.21375084], [79.13153076, 9.21375084], [79.13153076, 9.21347141], [79.13097382, 9.21347332], [79.13097382, 9.21319485], [79.13041687, 9.21319485], [79.13041687, 9.21291733], [79.12985992, 9.21291733], [79.12985992, 9.21319485], [79.12847137, 9.21319485], [79.12847137, 9.21347332], [79.12763977, 9.21347141], [79.12763977, 9.21375084], [79.12625122, 9.21375084], [79.12625122, 9.21402931], [79.12568665, 9.21402931], [79.12568665, 9.21430969], [79.12513733, 9.21430492], [79.12513733, 9.2145834], [79.12403107, 9.2145834], [79.12403107, 9.21486092], [79.12319183, 9.21486092], [79.12319183, 9.21513939], [79.12236023, 9.21513939], [79.12236023, 9.21541977], [79.12124634, 9.21541691], [79.12124634, 9.21597099], [79.12095642, 9.21597099], [79.12095642, 9.21624947], [79.12152863, 9.21624947], [79.12152863, 9.21652985], [79.12291718, 9.21652985], [79.12291718, 9.21624947], [79.12431335, 9.21624947], [79.12431335, 9.21681023], [79.12403107, 9.21680546], [79.12403107, 9.2173624], [79.12431335, 9.2173624], [79.12431335, 9.2179203], [79.12568665, 9.2179203]]], [[[79.18235779, 9.24874973], [79.18235779, 9.24903011], [79.18402863, 9.24903011], [79.18402863, 9.24874973], [79.18430328, 9.24874973], [79.18430328, 9.24819088], [79.18458557, 9.24819374], [79.18458557, 9.24625015], [79.18374634, 9.24625015], [79.18374634, 9.24652958], [79.18208313, 9.24652958], [79.18208313, 9.2456913], [79.18180847, 9.24569321], [79.18180847, 9.24541759], [79.18096924, 9.24542046], [79.18096924, 9.24458981], [79.18068695, 9.24458981], [79.18068695, 9.24403191], [79.18096924, 9.24403191], [79.18096924, 9.24375153], [79.18123627, 9.24375153], [79.18123627, 9.24431038], [79.18208313, 9.24431038], [79.18208313, 9.24403191], [79.18235779, 9.24403191], [79.18235779, 9.24375153], [79.18264008, 9.24375153], [79.18264008, 9.24347115], [79.18291473, 9.24347115], [79.18291473, 9.24263859], [79.18264008, 9.24263859], [79.18264008, 9.24208069], [79.18291473, 9.2420826], [79.18291473, 9.24180508], [79.18319702, 9.24180984], [79.18319702, 9.24151993], [79.18347168, 9.24151993], [79.18347168, 9.24180984], [79.18596649, 9.24180984], [79.18596649, 9.24151993], [79.18624878, 9.24151993], [79.18624878, 9.24180984], [79.1873703, 9.24180984], [79.1873703, 9.24151993], [79.18763733, 9.2415266], [79.18763733, 9.24124908], [79.18818665, 9.24125099], [79.18818665, 9.24097061], [79.18846893, 9.24097347], [79.18846893, 9.24069309], [79.18958282, 9.24069309], [79.18958282, 9.24041653], [79.18985748, 9.24042034], [79.18985748, 9.23986053], [79.19013977, 9.23986053], [79.19013977, 9.23958302], [79.19041443, 9.23958302], [79.19041443, 9.23875141], [79.19013977, 9.23875141], [79.19013977, 9.23819065], [79.18985748, 9.23819542], [79.18985748, 9.23791695], [79.1904068, 9.23792171], [79.1904068, 9.23764133], [79.19069672, 9.23764133], [79.19069672, 9.23736095], [79.19430542, 9.23736095], [79.19430542, 9.23625088], [79.19458008, 9.23625088], [79.19458008, 9.23597145], [79.19513702, 9.23597336], [79.19513702, 9.23569489], [79.19569397, 9.23569489], [79.19569397, 9.23541737], [79.19624329, 9.23541927], [79.19624329, 9.23513889], [79.19708252, 9.23513889], [79.19708252, 9.23458004], [79.19791412, 9.2345829], [79.19791412, 9.23402882], [79.19819641, 9.23403072], [79.19819641, 9.23346996], [79.19847107, 9.23346996], [79.19847107, 9.23403072], [79.19875336, 9.23402882], [79.19875336, 9.2345829], [79.19957733, 9.23458004], [79.19957733, 9.23513889], [79.19930267, 9.23513889], [79.19930267, 9.23708344], [79.19957733, 9.23708057], [79.19957733, 9.23792171], [79.19985962, 9.23791695], [79.19985962, 9.23847103], [79.20014191, 9.23845863], [79.20014191, 9.23903179], [79.20041656, 9.23903179], [79.20041656, 9.23931026], [79.20069122, 9.23930454], [79.20069122, 9.23958302], [79.20041656, 9.23958111], [79.20041656, 9.24042034], [79.20069122, 9.24041653], [79.20069122, 9.24069309], [79.20124817, 9.24069309], [79.20124817, 9.24041653], [79.20153046, 9.24042034], [79.20153046, 9.24014091], [79.20181274, 9.24014091], [79.20181274, 9.23792171], [79.20153046, 9.23792171], [79.20153046, 9.23764133], [79.20124817, 9.23764133], [79.20124817, 9.23681164], [79.20096588, 9.23681164], [79.20096588, 9.23625088], [79.20124817, 9.23625088], [79.20124817, 9.23541927], [79.20153046, 9.23541927], [79.20153046, 9.23403072], [79.20124817, 9.23403072], [79.20124817, 9.2337513], [79.20069122, 9.2337513], [79.20069122, 9.23347282], [79.20041656, 9.23347282], [79.20041656, 9.2331953], [79.20014191, 9.2331953], [79.20014191, 9.23291683], [79.19985962, 9.23292065], [79.19985962, 9.2326498], [79.19957733, 9.2326498], [79.19957733, 9.23236275], [79.19790649, 9.23236275], [79.19790649, 9.2326498], [79.19740295, 9.23264503], [79.19708252, 9.2326498], [79.19708252, 9.23292065], [79.19625092, 9.23291683], [79.19625092, 9.2331953], [79.19596863, 9.2331953], [79.19596863, 9.23347282], [79.19513702, 9.23347282], [79.19513702, 9.2337513], [79.19486237, 9.2337513], [79.19486237, 9.23403072], [79.19374847, 9.23403072], [79.19374847, 9.2343092], [79.19347382, 9.23430538], [79.19347382, 9.2345829], [79.19208527, 9.2345829], [79.19208527, 9.23486137], [79.19180298, 9.23486137], [79.19180298, 9.23513889], [79.19152832, 9.23513889], [79.19152832, 9.23541927], [79.19069672, 9.23541737], [79.19069672, 9.23597336], [79.1904068, 9.23597145], [79.1904068, 9.23625088], [79.18958282, 9.23625088], [79.18958282, 9.23653126], [79.18875122, 9.23653126], [79.18875122, 9.23681164], [79.18819427, 9.23680496], [79.18819427, 9.23708344], [79.18736267, 9.23708344], [79.18736267, 9.23736095], [79.18681335, 9.23736095], [79.18681335, 9.23792171], [79.18653107, 9.23791695], [79.18653107, 9.23819542], [79.18597412, 9.23819542], [79.18597412, 9.23847103], [79.18569183, 9.23845863], [79.18569183, 9.23874855], [79.18430328, 9.23875141], [79.18430328, 9.23903179], [79.18264008, 9.23903179], [79.18264008, 9.23931026], [79.18208313, 9.23930454], [79.18208313, 9.23958302], [79.18180847, 9.23958302], [79.18180847, 9.23986053], [79.18152618, 9.23986053], [79.18152618, 9.24014091], [79.18096924, 9.24014091], [79.18096924, 9.24042034], [79.18069458, 9.24041653], [79.18069458, 9.24069309], [79.18041992, 9.24069118], [79.18041992, 9.24125099], [79.18013763, 9.24124908], [79.18013763, 9.2415266], [79.17986298, 9.2415266], [79.17986298, 9.2420826], [79.17958069, 9.24208069], [79.17958069, 9.24263859], [79.17930603, 9.24263859], [79.17930603, 9.24291992], [79.17903137, 9.24291706], [79.17903137, 9.24347115], [79.17874908, 9.24347115], [79.17874908, 9.24431038], [79.17903137, 9.24431038], [79.17903137, 9.24542046], [79.17930603, 9.24542046], [79.17930603, 9.24652958], [79.17958069, 9.24652767], [79.17958069, 9.24708366], [79.17986298, 9.2470789], [79.17986298, 9.2476511], [79.18013763, 9.24763966], [79.18013763, 9.24819374], [79.18041992, 9.24819374], [79.18041992, 9.24847221], [79.18152618, 9.24846935], [79.18152618, 9.24874973], [79.18235779, 9.24874973]]], [[[79.23152924, 9.24403191], [79.23152924, 9.24458981], [79.23235321, 9.24458981], [79.23235321, 9.24431038], [79.23264313, 9.24431038], [79.23264313, 9.24403191], [79.23291779, 9.24403191], [79.23291779, 9.24375153], [79.23374939, 9.24375153], [79.23374939, 9.24347115], [79.23625183, 9.24347115], [79.23625183, 9.24319553], [79.23652649, 9.24319553], [79.23652649, 9.24347115], [79.23680878, 9.24347115], [79.23680878, 9.24375153], [79.23707581, 9.24375153], [79.23707581, 9.24403191], [79.23735809, 9.24403191], [79.23735809, 9.24431038], [79.23819733, 9.24431038], [79.23819733, 9.24375153], [79.23847961, 9.24375153], [79.23847961, 9.24319077], [79.23874664, 9.24319553], [79.23874664, 9.2420826], [79.23930359, 9.2420826], [79.23930359, 9.24097347], [79.23874664, 9.24097347], [79.23874664, 9.24069309], [79.23791504, 9.24069309], [79.23791504, 9.24041653], [79.23735809, 9.24042034], [79.23735809, 9.24014091], [79.23652649, 9.24014091], [79.23652649, 9.23986053], [79.23625183, 9.23986053], [79.23625183, 9.23958302], [79.23458099, 9.23958111], [79.23458099, 9.24014091], [79.23430634, 9.24013901], [79.23430634, 9.24069309], [79.23402405, 9.24069309], [79.23402405, 9.24097347], [79.23374939, 9.24097061], [79.23374939, 9.24125099], [79.23347473, 9.24124908], [79.23347473, 9.2415266], [79.23319244, 9.2415266], [79.23319244, 9.2420826], [79.23291779, 9.2420826], [79.23291779, 9.24236107], [79.23264313, 9.24236107], [79.23264313, 9.24263859], [79.23235321, 9.24263859], [79.23235321, 9.24291992], [79.23208618, 9.24291706], [79.23208618, 9.24319553], [79.23180389, 9.24319553], [79.23180389, 9.24347115], [79.23152924, 9.24347115], [79.23152924, 9.24375153], [79.23124695, 9.24375153], [79.23124695, 9.24403191], [79.23152924, 9.24403191]]], [[[78.2529068, 8.95792103], [78.2529068, 8.95736027], [78.25319672, 8.95736217], [78.25319672, 8.9570837], [78.25347137, 8.9570837], [78.25347137, 8.95680618], [78.25374603, 8.95681095], [78.25374603, 8.95652962], [78.25402832, 8.95652962], [78.25402832, 8.95597172], [78.25458527, 8.95597172], [78.25458527, 8.9556942], [78.25485992, 8.9556942], [78.25485992, 8.95541573], [78.25541687, 8.95541954], [78.25541687, 8.95431137], [78.25514221, 8.95431137], [78.25514221, 8.95403004], [78.25485992, 8.95403004], [78.25485992, 8.95347023], [78.25458527, 8.95347214], [78.25458527, 8.95291805], [78.25402832, 8.95291805], [78.25402832, 8.95319366], [78.25291443, 8.95319366], [78.25291443, 8.95291805], [78.25235748, 8.95291805], [78.25235748, 8.95319366], [78.25180817, 8.95319366], [78.25180817, 8.95485973], [78.25152588, 8.95485973], [78.25152588, 8.95763969], [78.25123596, 8.95763969], [78.25123596, 8.95792103], [78.2529068, 8.95792103]]], [[[79.5293045, 9.38419724], [79.5293045, 9.38402843], [79.52913666, 9.38402843], [79.5293045, 9.38419724]]], [[[79.53009033, 9.38595772], [79.53013611, 9.38569355], [79.52998352, 9.38569355], [79.53009033, 9.38595772]]], [[[79.53009033, 9.38595772], [79.5300827, 9.38611794], [79.53006744, 9.3863802], [79.53012085, 9.38658524], [79.53020477, 9.38689518], [79.53013611, 9.38708401], [79.5304184, 9.38708401], [79.5304184, 9.38597202], [79.53009033, 9.38595772]]], [[[79.53013611, 9.38831711], [79.52993011, 9.38863564], [79.52986145, 9.38875008], [79.53013611, 9.38875008], [79.53013611, 9.38831711]]], [[[79.52986145, 9.38875008], [79.52970886, 9.38895512], [79.52967834, 9.38911533], [79.52986145, 9.38902092], [79.52986145, 9.38875008]]], [[[79.52958679, 9.38916016], [79.5293045, 9.38930416], [79.52958679, 9.38931084], [79.52958679, 9.38916016]]], [[[79.37374878, 9.21958447], [79.37403107, 9.21958447], [79.37403107, 9.21930599], [79.37431335, 9.2193079], [79.37431335, 9.21903038], [79.37458038, 9.21903038], [79.37458038, 9.21875191], [79.37486267, 9.21875191], [79.37486267, 9.21847057], [79.37541962, 9.21847057], [79.37541962, 9.21819305], [79.37569427, 9.21819305], [79.37569427, 9.2179184], [79.37596893, 9.2179203], [79.37596893, 9.21764183], [79.37625122, 9.21764183], [79.37625122, 9.2173624], [79.37652588, 9.2173624], [79.37652588, 9.21708298], [79.37708282, 9.21708298], [79.37708282, 9.21680546], [79.37735748, 9.21681023], [79.37735748, 9.21652985], [79.37763977, 9.21652985], [79.37763977, 9.21624947], [79.37791443, 9.21624947], [79.3779068, 9.21597099], [79.37847137, 9.21597099], [79.37847137, 9.21569538], [79.37875366, 9.21569538], [79.37875366, 9.21541691], [79.37930298, 9.21541977], [79.37930298, 9.21513939], [79.3795929, 9.21513939], [79.3795929, 9.21486092], [79.37985992, 9.21486092], [79.37985992, 9.2145834], [79.38041687, 9.2145834], [79.38041687, 9.21430492], [79.38069153, 9.21430969], [79.38069153, 9.21402931], [79.38124847, 9.21402931], [79.38124847, 9.21375084], [79.38153076, 9.21375084], [79.38153076, 9.21347141], [79.38208008, 9.21347332], [79.38208008, 9.21319485], [79.38236237, 9.21319485], [79.38236237, 9.21291733], [79.38291168, 9.21291924], [79.38291168, 9.21264076], [79.38346863, 9.21264076], [79.38346863, 9.21236134], [79.38430786, 9.21236134], [79.38430786, 9.21208286], [79.38486481, 9.21208286], [79.38486481, 9.21180534], [79.38513947, 9.21181202], [79.38513947, 9.21125126], [79.38541412, 9.21125126], [79.38540649, 9.21097088], [79.38569641, 9.21097088], [79.38569641, 9.21069527], [79.38652802, 9.21069527], [79.38652802, 9.21041679], [79.38680267, 9.21042156], [79.38680267, 9.21014118], [79.38764191, 9.21014118], [79.38764191, 9.2098608], [79.38791656, 9.2098608], [79.38791656, 9.20958328], [79.38819122, 9.20958328], [79.38819122, 9.20930481], [79.38846588, 9.20931244], [79.38846588, 9.20903111], [79.38903809, 9.20903111], [79.38903809, 9.20875072], [79.38957977, 9.20875072], [79.38957977, 9.20818996], [79.38986206, 9.20819473], [79.38986206, 9.20791721], [79.39041901, 9.20792103], [79.39041901, 9.20764065], [79.39068604, 9.20764065], [79.39068604, 9.20736122], [79.39097595, 9.20736122], [79.39097595, 9.20680523], [79.39125061, 9.20681095], [79.39125061, 9.20653057], [79.39180756, 9.20653057], [79.39180756, 9.20625114], [79.3923645, 9.20625114], [79.39235687, 9.20569038], [79.39263916, 9.20569515], [79.39263916, 9.20541668], [79.39319611, 9.20542145], [79.39319611, 9.20514107], [79.39375305, 9.20514107], [79.39375305, 9.20458031], [79.39430237, 9.20458221], [79.39430237, 9.2043066], [79.39457703, 9.20431137], [79.39457703, 9.20403099], [79.39485168, 9.20403099], [79.39485168, 9.20347023], [79.39541626, 9.20347214], [79.39541626, 9.20319366], [79.39569092, 9.20319366], [79.39569092, 9.20291615], [79.39624786, 9.20292091], [79.39624786, 9.20235062], [79.39680481, 9.20236015], [79.39680481, 9.20208359], [79.39736176, 9.20208359], [79.39736176, 9.20180416], [79.39763641, 9.20181084], [79.39763641, 9.20153141], [79.3979187, 9.20153141], [79.3979187, 9.20125008], [79.39819336, 9.20125008], [79.39819336, 9.2009697], [79.39875031, 9.2009716], [79.39875031, 9.20069408], [79.39902496, 9.20069408], [79.39902496, 9.20013809], [79.39930725, 9.20014], [79.39930725, 9.19985962], [79.3998642, 9.19986153], [79.3998642, 9.1995821], [79.40013885, 9.1995821], [79.40013885, 9.19930553], [79.40040588, 9.19931126], [79.40040588, 9.19902992], [79.4006958, 9.19902992], [79.4006958, 9.19874954], [79.40097046, 9.19874954], [79.40097809, 9.19847202], [79.4015274, 9.19847202], [79.4015274, 9.19819355], [79.40180206, 9.19819355], [79.40180206, 9.19791603], [79.40207672, 9.19791985], [79.40207672, 9.19764042], [79.4026413, 9.19764042], [79.4026413, 9.19736195], [79.40291595, 9.19736195], [79.40291595, 9.19652843], [79.4034729, 9.19654179], [79.4034729, 9.19624996], [79.40402222, 9.19624996], [79.40402222, 9.19596958], [79.4043045, 9.19597244], [79.4043045, 9.19541645], [79.40486145, 9.19542027], [79.40486145, 9.19514179], [79.4054184, 9.19514179], [79.4054184, 9.19486046], [79.40569305, 9.19486237], [79.40569305, 9.19458389], [79.40597534, 9.19458389], [79.40597534, 9.19430637], [79.40625, 9.19431019], [79.40625, 9.1940279], [79.40680695, 9.1940279], [79.40680695, 9.19375038], [79.4070816, 9.19375038], [79.4070816, 9.19347191], [79.40735626, 9.19348145], [79.40735626, 9.19319057], [79.40763855, 9.19319439], [79.40763855, 9.1926403], [79.40820313, 9.1926403], [79.40820313, 9.19208145], [79.40875244, 9.19208431], [79.40875244, 9.19180584], [79.40930176, 9.19180965], [79.40930939, 9.19153023], [79.4098587, 9.19153023], [79.4098587, 9.19124889], [79.41014099, 9.19124889], [79.41014099, 9.19069576], [79.41069794, 9.19069576], [79.41069794, 9.19041538], [79.4109726, 9.19041538], [79.4109726, 9.19013977], [79.41124725, 9.19014168], [79.41124725, 9.1898613], [79.41152954, 9.1898613], [79.41152954, 9.18958282], [79.41208649, 9.18958282], [79.41208649, 9.18930531], [79.41179657, 9.18931007], [79.41179657, 9.18874931], [79.41236115, 9.18874931], [79.41236115, 9.18847084], [79.4126358, 9.18847084], [79.4126358, 9.18819523], [79.41291809, 9.18819523], [79.41291809, 9.18791676], [79.41374969, 9.18791962], [79.41374969, 9.18735027], [79.41402435, 9.18736076], [79.41402435, 9.18708324], [79.41430664, 9.18708324], [79.41430664, 9.18652725], [79.41485596, 9.18653202], [79.41485596, 9.18625069], [79.4145813, 9.18625069], [79.4145813, 9.18597126], [79.4154129, 9.18597126], [79.4154129, 9.18625069], [79.41596222, 9.18625069], [79.41596222, 9.18569088], [79.41625214, 9.18569469], [79.41625214, 9.18541718], [79.41652679, 9.18542194], [79.41652679, 9.18514061], [79.41680908, 9.18514061], [79.41680908, 9.1845808], [79.41708374, 9.18458271], [79.41708374, 9.18430519], [79.4173584, 9.18431187], [79.4173584, 9.18403053], [79.41764069, 9.18403053], [79.41764069, 9.18375111], [79.41791534, 9.18375111], [79.41791534, 9.18347263], [79.41819763, 9.18347263], [79.41819763, 9.18319511], [79.41874695, 9.18319511], [79.41874695, 9.18291664], [79.41902161, 9.18292141], [79.41902161, 9.18264103], [79.41929626, 9.18264103], [79.41929626, 9.18236065], [79.41958618, 9.18236065], [79.41958618, 9.18208313], [79.41986084, 9.18208313], [79.41986084, 9.18180466], [79.42041779, 9.18180943], [79.42041779, 9.18153954], [79.4209671, 9.18153954], [79.4209671, 9.18097115], [79.42124939, 9.18097305], [79.42124939, 9.18041706], [79.42208862, 9.18042088], [79.42208862, 9.18014145], [79.42236328, 9.18014145], [79.42236328, 9.17986107], [79.42263794, 9.17986107], [79.42263794, 9.1795826], [79.42319489, 9.1795826], [79.42319489, 9.17930698], [79.42346954, 9.17930889], [79.42346954, 9.17903137], [79.42375183, 9.17903137], [79.42375183, 9.17875099], [79.42402649, 9.17875099], [79.42402649, 9.17846966], [79.42458344, 9.17847347], [79.42458344, 9.178195], [79.42485809, 9.178195], [79.42485809, 9.17791653], [79.42514801, 9.1779213], [79.42514801, 9.17764091], [79.42542267, 9.17764091], [79.42542267, 9.17708015], [79.42569733, 9.17708206], [79.42569733, 9.17652893], [79.42597198, 9.17653084], [79.42597198, 9.17625046], [79.42652893, 9.17625046], [79.42652893, 9.17597198], [79.42708588, 9.17597198], [79.42708588, 9.17569447], [79.42736053, 9.17569447], [79.42736053, 9.17513847], [79.42764282, 9.17514133], [79.42764282, 9.17486], [79.42847443, 9.17486], [79.42847443, 9.17458439], [79.42874908, 9.17458439], [79.42874908, 9.17430592], [79.42903137, 9.17431068], [79.42903137, 9.17403126], [79.42930603, 9.17403126], [79.42930603, 9.17374992], [79.42986298, 9.17374992], [79.42986298, 9.17346954], [79.43013763, 9.1734724], [79.43013763, 9.17291641], [79.43041992, 9.17292118], [79.43041992, 9.17263985], [79.43068695, 9.17263985], [79.43068695, 9.17208195], [79.43096924, 9.17208195], [79.43096924, 9.17180634], [79.43125153, 9.1718111], [79.43125153, 9.17152977], [79.43152618, 9.17152977], [79.43152618, 9.17125034], [79.43180847, 9.17125034], [79.43180847, 9.17069435], [79.43208313, 9.17069435], [79.43208313, 9.17041588], [79.43235779, 9.17041969], [79.43235779, 9.17014027], [79.43264008, 9.17014027], [79.43264008, 9.16986179], [79.4329071, 9.16986179], [79.4329071, 9.16957855], [79.43319702, 9.16958427], [79.43319702, 9.1693058], [79.43347168, 9.16930962], [79.43347168, 9.16903019], [79.43374634, 9.16903019], [79.43374634, 9.16874981], [79.43402863, 9.16874981], [79.43402863, 9.16847229], [79.43430328, 9.16847229], [79.43430328, 9.16819382], [79.43458557, 9.16819382], [79.43458557, 9.1679163], [79.43486023, 9.16792011], [79.43486023, 9.16763973], [79.43514252, 9.16763973], [79.43514252, 9.16708088], [79.43541718, 9.16708374], [79.43541718, 9.16680622], [79.43569183, 9.16681004], [79.43569183, 9.16623974], [79.43597412, 9.16625023], [79.43597412, 9.16597366], [79.43624878, 9.16597176], [79.43624878, 9.16569424], [79.43653107, 9.16569424], [79.43653107, 9.16514015], [79.43681335, 9.16514015], [79.43681335, 9.16486168], [79.43708038, 9.16486168], [79.43708038, 9.16458416], [79.43763733, 9.16458416], [79.43763733, 9.16430569], [79.43791962, 9.16431046], [79.43791962, 9.16403198], [79.43846893, 9.16403198], [79.43846893, 9.1637516], [79.43875122, 9.1637516], [79.43875122, 9.16347122], [79.43902588, 9.16347122], [79.43902588, 9.16319561], [79.43930817, 9.16319561], [79.43930817, 9.16291809], [79.43958282, 9.16292191], [79.43958282, 9.16263866], [79.43985748, 9.16263866], [79.43985748, 9.16208076], [79.44013977, 9.16208267], [79.44013977, 9.16152668], [79.43930817, 9.16152668], [79.43930817, 9.16208267], [79.43902588, 9.16208267], [79.43902588, 9.16236115], [79.43875122, 9.16235924], [79.43875122, 9.16263866], [79.43846893, 9.16263866], [79.43846893, 9.16292191], [79.43791962, 9.16291809], [79.43791962, 9.16319561], [79.43763733, 9.16319561], [79.43763733, 9.16347122], [79.43708801, 9.16347122], [79.43708801, 9.1637516], [79.43681335, 9.1637516], [79.43681335, 9.16403198], [79.43653107, 9.16403198], [79.43653107, 9.16431046], [79.43624878, 9.16430569], [79.43624878, 9.16458416], [79.43596649, 9.1645813], [79.43597412, 9.16486168], [79.43569183, 9.16486168], [79.43569183, 9.16514015], [79.43541718, 9.16514015], [79.43541718, 9.16541958], [79.43514252, 9.16541767], [79.43514252, 9.16569424], [79.43486023, 9.16569424], [79.43486023, 9.16597176], [79.4345932, 9.16596889], [79.4345932, 9.16652966], [79.43430328, 9.16652966], [79.43430328, 9.16681004], [79.43402863, 9.16680622], [79.43402863, 9.16708374], [79.43374634, 9.16708374], [79.43374634, 9.16736221], [79.43347168, 9.16736031], [79.43347168, 9.16763973], [79.43319702, 9.16763973], [79.43319702, 9.16819382], [79.43291473, 9.16819382], [79.43291473, 9.16847229], [79.43264008, 9.16847229], [79.43264008, 9.16874981], [79.43235779, 9.16874981], [79.43235779, 9.16930962], [79.43208313, 9.1693058], [79.43208313, 9.16958427], [79.43125153, 9.16957855], [79.43125153, 9.16986179], [79.43068695, 9.16986179], [79.43068695, 9.17014027], [79.43041992, 9.17014027], [79.43041992, 9.17041969], [79.43013763, 9.17041588], [79.43013763, 9.17069435], [79.42986298, 9.17069435], [79.42986298, 9.17125034], [79.42958069, 9.17125034], [79.42958069, 9.17152977], [79.42930603, 9.17152977], [79.42930603, 9.1718111], [79.42903137, 9.17180634], [79.42903137, 9.17208195], [79.42874908, 9.17208195], [79.42874908, 9.17237091], [79.4284668, 9.17237091], [79.4284668, 9.17263985], [79.42819214, 9.17263985], [79.42819214, 9.17292118], [79.42791748, 9.17291641], [79.42791748, 9.1734724], [79.42764282, 9.17346954], [79.42764282, 9.17374992], [79.42736053, 9.17374992], [79.42736053, 9.17403126], [79.42708588, 9.17403126], [79.42708588, 9.17431068], [79.42680359, 9.17430592], [79.42680359, 9.17458439], [79.42652893, 9.17458439], [79.42652893, 9.17486], [79.42624664, 9.17486], [79.42624664, 9.17514133], [79.42597198, 9.17513847], [79.42597198, 9.17541599], [79.42569733, 9.17541599], [79.42569733, 9.17569447], [79.42541504, 9.17569447], [79.42541504, 9.17597198], [79.42514801, 9.17597008], [79.42514038, 9.17625046], [79.42485809, 9.17625046], [79.42485809, 9.17653084], [79.42457581, 9.17653084], [79.42457581, 9.17681122], [79.42430878, 9.1768074], [79.42430878, 9.17708206], [79.42292023, 9.17708206], [79.42292023, 9.17735958], [79.42263794, 9.17735958], [79.42263794, 9.1779213], [79.42208099, 9.17791653], [79.42208099, 9.178195], [79.42152405, 9.178195], [79.42152405, 9.17847347], [79.42124939, 9.17846966], [79.42124939, 9.17903137], [79.42097473, 9.17902565], [79.42097473, 9.1795826], [79.42069244, 9.1795826], [79.42069244, 9.17986107], [79.42041779, 9.17986107], [79.42041779, 9.18014145], [79.41986084, 9.18014145], [79.41986084, 9.18042088], [79.41958618, 9.18041706], [79.41958618, 9.18069458], [79.41929626, 9.1806879], [79.41929626, 9.18125057], [79.41902161, 9.18125057], [79.41902161, 9.18153954], [79.41847229, 9.18153954], [79.41847229, 9.18180943], [79.41819763, 9.18180466], [79.41819763, 9.18208313], [79.41791534, 9.18208313], [79.41791534, 9.18236065], [79.41764069, 9.18236065], [79.41764069, 9.18264103], [79.4173584, 9.18264103], [79.4173584, 9.18292141], [79.41708374, 9.18291664], [79.41708374, 9.18319511], [79.41680908, 9.18319511], [79.41680908, 9.18347263], [79.41652679, 9.18347263], [79.41652679, 9.18375111], [79.41625214, 9.18375111], [79.41625214, 9.18347263], [79.41486359, 9.18347263], [79.41486359, 9.18263912], [79.4145813, 9.18264103], [79.4145813, 9.18208027], [79.41486359, 9.18208313], [79.41486359, 9.18097305], [79.4154129, 9.18097305], [79.4154129, 9.18069458], [79.41569519, 9.18069458], [79.41569519, 9.18013859], [79.41596222, 9.18014145], [79.41596222, 9.17986107], [79.41652679, 9.17986107], [79.41652679, 9.1795826], [79.41680908, 9.1795826], [79.41680908, 9.17930698], [79.41707611, 9.17930889], [79.41707611, 9.17903137], [79.41792297, 9.17903137], [79.41792297, 9.17875099], [79.41986084, 9.17875099], [79.41986084, 9.17764091], [79.42014313, 9.17764091], [79.42014313, 9.17735958], [79.42041779, 9.17735958], [79.42041779, 9.1779213], [79.42151642, 9.1779213], [79.42151642, 9.17764091], [79.42208862, 9.17764091], [79.42208862, 9.17597008], [79.42236328, 9.17597198], [79.42236328, 9.17541599], [79.42263794, 9.17541599], [79.42263794, 9.17486], [79.42292023, 9.17486], [79.42292023, 9.17430592], [79.42318726, 9.17431068], [79.42318726, 9.17403126], [79.42375183, 9.17403126], [79.42375183, 9.17374992], [79.42402649, 9.17374992], [79.42402649, 9.17346954], [79.42458344, 9.1734724], [79.42458344, 9.17319393], [79.42485809, 9.17319393], [79.42485809, 9.17291641], [79.42542267, 9.17292118], [79.42542267, 9.17263985], [79.42569733, 9.17263985], [79.42569733, 9.17208195], [79.42597198, 9.17208195], [79.42597198, 9.17180634], [79.42624664, 9.1718111], [79.42624664, 9.17152977], [79.42652893, 9.17152977], [79.42652893, 9.17125034], [79.42680359, 9.17125034], [79.42679596, 9.17097187], [79.42708588, 9.17097187], [79.42708588, 9.17041588], [79.42736053, 9.17041969], [79.42736053, 9.17014027], [79.42764282, 9.17014027], [79.42764282, 9.16986179], [79.42791748, 9.16986179], [79.42791748, 9.16957855], [79.42819214, 9.16958427], [79.42819214, 9.1693058], [79.4284668, 9.16930962], [79.4284668, 9.16903019], [79.42874908, 9.16903019], [79.42874908, 9.16874981], [79.42903137, 9.16874981], [79.42903137, 9.16819382], [79.42930603, 9.16819382], [79.42930603, 9.16763973], [79.42958069, 9.16763973], [79.42958069, 9.16736031], [79.43041992, 9.16736221], [79.43041992, 9.16708374], [79.43152618, 9.16708374], [79.43152618, 9.16680622], [79.43180847, 9.16681004], [79.43180847, 9.16623974], [79.43208313, 9.16625023], [79.43208313, 9.16597366], [79.43235779, 9.16597176], [79.43235779, 9.16569424], [79.43264008, 9.16569424], [79.43264008, 9.16514015], [79.4329071, 9.16514015], [79.4329071, 9.16486168], [79.43319702, 9.16486168], [79.43319702, 9.16458416], [79.43347168, 9.16458416], [79.43347168, 9.16430569], [79.43374634, 9.16431046], [79.43374634, 9.16403198], [79.43402863, 9.16403198], [79.43402863, 9.1637516], [79.43430328, 9.1637516], [79.43430328, 9.16347122], [79.43458557, 9.16347122], [79.43458557, 9.16319561], [79.43486023, 9.16319561], [79.43486023, 9.16291809], [79.43514252, 9.16292191], [79.43514252, 9.16263866], [79.43541718, 9.16263866], [79.43541718, 9.16235924], [79.43569183, 9.16236115], [79.43569183, 9.16208267], [79.43597412, 9.16208267], [79.43597412, 9.16180515], [79.43624878, 9.16180992], [79.43624878, 9.16152954], [79.43653107, 9.16152954], [79.43653107, 9.16125107], [79.43681335, 9.16125107], [79.43681335, 9.16097069], [79.43736267, 9.1609726], [79.43736267, 9.16069317], [79.43763733, 9.16069317], [79.43763733, 9.1604166], [79.43791962, 9.16043091], [79.43791962, 9.16014194], [79.43818665, 9.16014194], [79.43818665, 9.15986061], [79.43846893, 9.15986061], [79.43846893, 9.15958309], [79.43875122, 9.15958309], [79.43875122, 9.15930462], [79.43902588, 9.15931034], [79.43902588, 9.15903187], [79.43930817, 9.15903187], [79.43930817, 9.15875053], [79.43958282, 9.15875053], [79.43958282, 9.15847111], [79.43985748, 9.15847111], [79.43985748, 9.15819454], [79.43902588, 9.15819454], [79.43902588, 9.15847111], [79.43875122, 9.15847111], [79.43875122, 9.15875053], [79.43846893, 9.15875053], [79.43846893, 9.15903187], [79.43818665, 9.15903187], [79.43818665, 9.15931034], [79.43791962, 9.15930462], [79.43791962, 9.15958309], [79.43763733, 9.15958309], [79.43763733, 9.15986061], [79.43736267, 9.15986061], [79.43736267, 9.16014194], [79.43681335, 9.16014194], [79.43681335, 9.16043091], [79.43653107, 9.1604166], [79.43653107, 9.16069317], [79.43597412, 9.16069317], [79.43597412, 9.1609726], [79.43569183, 9.16097069], [79.43569183, 9.16125107], [79.43541718, 9.16125107], [79.43541718, 9.16152954], [79.43486023, 9.16152954], [79.43486023, 9.16180992], [79.43458557, 9.16180515], [79.43458557, 9.16208267], [79.43430328, 9.16208267], [79.43430328, 9.16236115], [79.43402863, 9.16235924], [79.43402863, 9.16263866], [79.43374634, 9.16263866], [79.43374634, 9.16292191], [79.43347168, 9.16291809], [79.43347168, 9.16319561], [79.43319702, 9.16319561], [79.43319702, 9.16347122], [79.43264008, 9.16347122], [79.43264008, 9.1637516], [79.43235779, 9.1637516], [79.43235779, 9.16403198], [79.43208313, 9.16403198], [79.43208313, 9.16431046], [79.43180847, 9.16430569], [79.43180847, 9.16458416], [79.43152618, 9.16458416], [79.43152618, 9.16486168], [79.43125153, 9.16486168], [79.43125153, 9.16514015], [79.43096924, 9.16514015], [79.43096924, 9.16569424], [79.43069458, 9.16569424], [79.43069458, 9.16597176], [79.43041992, 9.16597176], [79.43041992, 9.16625023], [79.43013763, 9.16623974], [79.43013763, 9.16652966], [79.42958069, 9.16652966], [79.42958069, 9.16681004], [79.42930603, 9.16680622], [79.42930603, 9.16708374], [79.42903137, 9.16708374], [79.42903137, 9.16736221], [79.42874908, 9.16736031], [79.42874908, 9.16763973], [79.42819214, 9.16763973], [79.42819214, 9.16792011], [79.42791748, 9.1679163], [79.42791748, 9.16819382], [79.42763519, 9.16819382], [79.42763519, 9.16847229], [79.42736053, 9.16847229], [79.42736053, 9.16874981], [79.42708588, 9.16874981], [79.42708588, 9.16903019], [79.42679596, 9.16903019], [79.42679596, 9.16930962], [79.42652893, 9.16930962], [79.42652893, 9.16986179], [79.42624664, 9.16986179], [79.42624664, 9.17041969], [79.42541504, 9.17041588], [79.42541504, 9.17069435], [79.42458344, 9.17069435], [79.42458344, 9.17097187], [79.42318726, 9.17097187], [79.42319489, 9.17125034], [79.42292023, 9.17125034], [79.42292023, 9.1718111], [79.42236328, 9.1718111], [79.42236328, 9.17237091], [79.42208862, 9.17237091], [79.42208862, 9.17374992], [79.42180634, 9.17374992], [79.42180634, 9.17403126], [79.42124939, 9.17403126], [79.42124939, 9.17431068], [79.42097473, 9.17430592], [79.42097473, 9.17458439], [79.42069244, 9.17458439], [79.42069244, 9.17486], [79.42014313, 9.17486], [79.42014313, 9.17514133], [79.41986084, 9.17513847], [79.41986084, 9.17541599], [79.41930389, 9.17541599], [79.41930389, 9.17569447], [79.41902924, 9.17569447], [79.41902924, 9.17597198], [79.41764069, 9.17597008], [79.41764069, 9.17625046], [79.4173584, 9.17625046], [79.4173584, 9.17653084], [79.41680908, 9.17653084], [79.41680908, 9.17681122], [79.41652679, 9.1768074], [79.41652679, 9.17708206], [79.41596985, 9.17708206], [79.41596985, 9.17735958], [79.41570282, 9.17735958], [79.41570282, 9.17764091], [79.41513824, 9.17764091], [79.41513824, 9.1779213], [79.41486359, 9.17791653], [79.41486359, 9.178195], [79.41430664, 9.178195], [79.41430664, 9.17847347], [79.41348267, 9.17846966], [79.41348267, 9.17875099], [79.41319275, 9.17875099], [79.41319275, 9.17930889], [79.41208649, 9.17930698], [79.41208649, 9.1795826], [79.41179657, 9.17957973], [79.4118042, 9.17986107], [79.41152954, 9.17986107], [79.41152954, 9.18014145], [79.4109726, 9.18014145], [79.4109726, 9.18042088], [79.41069794, 9.18041706], [79.41069794, 9.18069458], [79.41041565, 9.18069458], [79.41041565, 9.18097305], [79.4090271, 9.18097115], [79.4090271, 9.18125057], [79.40875244, 9.18125057], [79.40875244, 9.18153954], [79.40820313, 9.18153954], [79.40820313, 9.18180943], [79.40791321, 9.18180466], [79.40791321, 9.18208313], [79.40763855, 9.18208313], [79.40763855, 9.18236065], [79.4070816, 9.18236065], [79.4070816, 9.18264103], [79.40680695, 9.18264103], [79.40680695, 9.18292141], [79.40652466, 9.18291664], [79.40652466, 9.18347263], [79.40625, 9.18347263], [79.40625, 9.18375111], [79.40513611, 9.18375111], [79.40513611, 9.18403053], [79.40486145, 9.18403053], [79.40486145, 9.18431187], [79.4043045, 9.18430519], [79.4043045, 9.18458271], [79.40402985, 9.18458271], [79.40402985, 9.18486118], [79.4034729, 9.18486118], [79.4034729, 9.18542194], [79.40291595, 9.18541718], [79.40291595, 9.18569469], [79.40235901, 9.18569469], [79.40235901, 9.18597317], [79.40207672, 9.18597126], [79.40207672, 9.18653202], [79.40097809, 9.18653202], [79.40097809, 9.18680954], [79.4006958, 9.18680477], [79.4006958, 9.18708324], [79.39958191, 9.18708324], [79.39958191, 9.18736076], [79.39930725, 9.18735027], [79.39930725, 9.18763924], [79.39901733, 9.18763924], [79.39901733, 9.18791962], [79.39875031, 9.18791676], [79.39875031, 9.18819523], [79.39819336, 9.18819523], [79.39819336, 9.18847084], [79.39763641, 9.18847084], [79.39763641, 9.18874931], [79.39736176, 9.18874931], [79.39736176, 9.18902969], [79.39653015, 9.18902683], [79.39653015, 9.19041538], [79.39541626, 9.19041538], [79.39541626, 9.19069576], [79.39485931, 9.19069576], [79.39485931, 9.19097137], [79.39457703, 9.19097137], [79.39458466, 9.19124889], [79.39402771, 9.19124889], [79.39402771, 9.19153023], [79.39375305, 9.19153023], [79.39375305, 9.19180965], [79.39319611, 9.19180584], [79.39319611, 9.19208431], [79.39235687, 9.19208145], [79.3923645, 9.19236183], [79.39180756, 9.19236183], [79.39180756, 9.1926403], [79.3915329, 9.1926403], [79.3915329, 9.19291973], [79.39125061, 9.19291782], [79.39125061, 9.19319439], [79.39068604, 9.19319057], [79.39068604, 9.19348145], [79.39013672, 9.19347191], [79.39013672, 9.19375038], [79.38986206, 9.19375038], [79.38986206, 9.1940279], [79.38931274, 9.1940279], [79.38931274, 9.19431019], [79.38874817, 9.19430637], [79.38874817, 9.19458389], [79.38819122, 9.19458389], [79.38819122, 9.19486237], [79.38764191, 9.19486046], [79.38764191, 9.19514179], [79.38707733, 9.19514179], [79.38707733, 9.19542027], [79.38680267, 9.19541645], [79.38680267, 9.19569397], [79.38625336, 9.19569397], [79.38625336, 9.19597244], [79.38569641, 9.19596958], [79.38569641, 9.19624996], [79.38513947, 9.19624996], [79.38513947, 9.19654179], [79.38485718, 9.19654179], [79.38485718, 9.19681072], [79.38458252, 9.19680595], [79.38458252, 9.19708443], [79.38430786, 9.19708443], [79.38430786, 9.19736195], [79.38375092, 9.19736195], [79.38375092, 9.19764042], [79.38346863, 9.19764042], [79.38346863, 9.19791985], [79.38291931, 9.19791603], [79.38291931, 9.19819355], [79.38263702, 9.19819355], [79.38263702, 9.19847202], [79.38153076, 9.19847202], [79.38153076, 9.19874954], [79.38124847, 9.19874954], [79.38124847, 9.19902992], [79.38069153, 9.19902992], [79.38069153, 9.19931126], [79.38041687, 9.19930553], [79.38041687, 9.1995821], [79.37985992, 9.1995821], [79.37985992, 9.19986153], [79.3795929, 9.19985962], [79.3795929, 9.20014], [79.37902832, 9.20014], [79.37902832, 9.20042133], [79.37847137, 9.20041561], [79.37847137, 9.20069408], [79.37791443, 9.20069408], [79.37791443, 9.2009716], [79.37763977, 9.2009697], [79.37763977, 9.20125008], [79.37708282, 9.20125008], [79.37708282, 9.20153141], [79.37652588, 9.20153141], [79.37652588, 9.20181084], [79.37625122, 9.20180416], [79.37625122, 9.20208359], [79.37569427, 9.20208359], [79.37569427, 9.20236015], [79.37541962, 9.20235062], [79.37541962, 9.20264053], [79.37486267, 9.20264053], [79.37486267, 9.20292091], [79.37458038, 9.20291615], [79.37458038, 9.20319366], [79.37431335, 9.20318985], [79.37431335, 9.20375061], [79.37346649, 9.20375061], [79.37346649, 9.20403099], [79.37264252, 9.20403099], [79.37264252, 9.20431137], [79.37208557, 9.2043066], [79.37208557, 9.20458221], [79.37180328, 9.20458221], [79.37180328, 9.20485973], [79.37152863, 9.20485973], [79.37152863, 9.20514107], [79.37124634, 9.20514107], [79.37124634, 9.20542145], [79.37041473, 9.20541668], [79.37041473, 9.20569515], [79.37014008, 9.20569515], [79.37014008, 9.20597267], [79.36958313, 9.20597267], [79.36958313, 9.20625114], [79.36930847, 9.20625114], [79.36930847, 9.20653057], [79.36875153, 9.20653057], [79.36875153, 9.20681095], [79.36846924, 9.20680523], [79.36846924, 9.20708275], [79.36819458, 9.20708275], [79.36819458, 9.20736122], [79.36763763, 9.20736122], [79.36763763, 9.20764065], [79.36708069, 9.20764065], [79.36708069, 9.20792103], [79.36653137, 9.20791721], [79.36653137, 9.20819473], [79.36624908, 9.20818996], [79.36624908, 9.20848179], [79.36569214, 9.20848179], [79.36569214, 9.20875072], [79.36541748, 9.20875072], [79.36541748, 9.20903111], [79.36486816, 9.20903111], [79.36486816, 9.20931244], [79.36458588, 9.20930481], [79.36458588, 9.20958328], [79.36402893, 9.20958328], [79.36402893, 9.2098608], [79.36374664, 9.2098608], [79.36374664, 9.21014118], [79.36347198, 9.21013927], [79.36347198, 9.21069527], [79.36319733, 9.21069527], [79.36319733, 9.21097088], [79.36264038, 9.21097088], [79.36264038, 9.21125126], [79.36235809, 9.21125126], [79.36235809, 9.21154118], [79.36180878, 9.21154118], [79.36180878, 9.21181202], [79.36152649, 9.21180534], [79.36152649, 9.21208286], [79.36096954, 9.21208286], [79.36096954, 9.21236134], [79.36068726, 9.21236134], [79.36068726, 9.21264076], [79.36042023, 9.21264076], [79.36042023, 9.21291924], [79.36013794, 9.21291733], [79.36013794, 9.21319485], [79.35958099, 9.21319485], [79.35958099, 9.21347332], [79.35930634, 9.21347141], [79.35930634, 9.21402931], [79.35819244, 9.21402931], [79.35819244, 9.21430969], [79.3576355, 9.21430492], [79.3576355, 9.2145834], [79.35708618, 9.2145834], [79.35708618, 9.21486092], [79.35679626, 9.21486092], [79.35679626, 9.21541977], [79.35652924, 9.21541691], [79.35652924, 9.21569538], [79.35569763, 9.21569538], [79.35569763, 9.21597099], [79.35514069, 9.21597099], [79.35514069, 9.21624947], [79.35430908, 9.21624947], [79.35430908, 9.21652985], [79.35375214, 9.21652985], [79.35375214, 9.21681023], [79.35319519, 9.21680546], [79.35319519, 9.21708298], [79.3529129, 9.21708298], [79.3529129, 9.2173624], [79.35235596, 9.2173624], [79.35235596, 9.21764183], [79.3520813, 9.21764183], [79.3520813, 9.2179203], [79.35152435, 9.2179184], [79.35152435, 9.21819305], [79.35098267, 9.21819115], [79.35098267, 9.21903038], [79.3501358, 9.21903038], [79.3501358, 9.2193079], [79.3493042, 9.21930599], [79.3493042, 9.21958447], [79.34902954, 9.21958447], [79.34902954, 9.21986198], [79.34874725, 9.21986198], [79.34874725, 9.22014046], [79.3484726, 9.22014046], [79.3484726, 9.22042179], [79.34819794, 9.22041798], [79.34819794, 9.22069359], [79.3473587, 9.22069359], [79.3473587, 9.22097206], [79.34680939, 9.2209692], [79.34680939, 9.22124958], [79.3465271, 9.22124958], [79.3465271, 9.22152996], [79.34597015, 9.22152996], [79.34597015, 9.22181034], [79.34541321, 9.22180557], [79.34541321, 9.22208405], [79.34513855, 9.22208405], [79.34513855, 9.22235966], [79.3445816, 9.22235966], [79.3445816, 9.22264004], [79.34430695, 9.22264004], [79.34430695, 9.22292042], [79.34374237, 9.22292042], [79.34374237, 9.22348118], [79.34348297, 9.22348118], [79.34348297, 9.22402954], [79.34208679, 9.22402954], [79.34208679, 9.22431087], [79.3418045, 9.22430611], [79.3418045, 9.22458363], [79.34124756, 9.22458363], [79.34124756, 9.2248621], [79.3409729, 9.22486019], [79.3409729, 9.22513962], [79.34069824, 9.22513962], [79.34068298, 9.22542095], [79.33958435, 9.22541809], [79.33958435, 9.2256937], [79.33930206, 9.2256937], [79.33930206, 9.22597218], [79.33847046, 9.22597027], [79.33847046, 9.22624969], [79.33791351, 9.22624969], [79.33791351, 9.22652817], [79.33763885, 9.22652054], [79.33763885, 9.22681141], [79.3373642, 9.22680569], [79.3373642, 9.22708416], [79.33708191, 9.22708416], [79.33708191, 9.22735977], [79.33680725, 9.22735977], [79.33680725, 9.22764015], [79.33625031, 9.22764015], [79.33625031, 9.22792053], [79.33597565, 9.22791576], [79.33597565, 9.22819424], [79.33569336, 9.22819424], [79.33569336, 9.22847176], [79.3354187, 9.22847176], [79.3354187, 9.22875023], [79.33486938, 9.22875023], [79.33486938, 9.22903061], [79.3345871, 9.22903061], [79.3345871, 9.22931099], [79.33291626, 9.22930431], [79.33291626, 9.22958469], [79.3326416, 9.22958469], [79.3326416, 9.22986031], [79.33207703, 9.22986031], [79.33207703, 9.23014069], [79.33180237, 9.23014069], [79.33180237, 9.23042107], [79.33125305, 9.2304163], [79.33125305, 9.23069382], [79.33069611, 9.23069382], [79.33069611, 9.23097324], [79.33013916, 9.23097324], [79.33013916, 9.23125076], [79.32985687, 9.2312479], [79.32985687, 9.23153114], [79.32930756, 9.23153114], [79.32930756, 9.23181057], [79.32875061, 9.23180676], [79.32875061, 9.23208237], [79.32818604, 9.23208046], [79.32818604, 9.23236275], [79.32681274, 9.23236275], [79.32681274, 9.2326498], [79.32624817, 9.2326498], [79.32624817, 9.23292065], [79.32597351, 9.23291683], [79.32597351, 9.2331953], [79.32569122, 9.2331953], [79.32569122, 9.23347282], [79.32541656, 9.23347282], [79.32541656, 9.2337513], [79.32457733, 9.2337513], [79.32457733, 9.23403072], [79.32430267, 9.23403072], [79.32430267, 9.2343092], [79.32402802, 9.23430538], [79.32402802, 9.23486137], [79.32375336, 9.23486137], [79.32375336, 9.23513889], [79.32347107, 9.23513889], [79.32347107, 9.23541927], [79.32236481, 9.23541737], [79.32236481, 9.23569489], [79.32208252, 9.23569012], [79.32208252, 9.23625088], [79.32180786, 9.23625088], [79.32180786, 9.23653126], [79.3215332, 9.23653126], [79.3215332, 9.23681164], [79.32068634, 9.23681164], [79.32068634, 9.23653126], [79.32041931, 9.23653126], [79.32041931, 9.23625088], [79.32013702, 9.23625088], [79.32013702, 9.23653126], [79.31986237, 9.23653126], [79.31986237, 9.23681164], [79.31930542, 9.23680496], [79.31930542, 9.23708344], [79.31903076, 9.23708344], [79.31903076, 9.23736095], [79.31791687, 9.23736095], [79.31791687, 9.23764133], [79.31735992, 9.23763943], [79.31735992, 9.23819542], [79.31680298, 9.23819542], [79.31680298, 9.23847103], [79.31624603, 9.23845863], [79.31624603, 9.23875141], [79.3154068, 9.23875141], [79.3154068, 9.23903179], [79.31485748, 9.23903179], [79.31485748, 9.23931026], [79.31402588, 9.23930454], [79.31402588, 9.23958302], [79.31319427, 9.23958302], [79.31319427, 9.23986053], [79.31291962, 9.23986053], [79.31291962, 9.24014091], [79.31263733, 9.24014091], [79.31263733, 9.24042034], [79.31180573, 9.24041653], [79.31180573, 9.24069309], [79.31153107, 9.24069309], [79.31153107, 9.24097347], [79.31109619, 9.24097347], [79.31097412, 9.24097347], [79.31096649, 9.24114037], [79.31096649, 9.24125099], [79.31014252, 9.24124908], [79.31014252, 9.2415266], [79.30930328, 9.24151993], [79.30930328, 9.24180984], [79.30902863, 9.24180508], [79.30902863, 9.2420826], [79.30874634, 9.2420826], [79.30874634, 9.24236107], [79.30847168, 9.24236107], [79.30847168, 9.24263859], [79.30735779, 9.24263859], [79.30735779, 9.24291992], [79.30652618, 9.24291706], [79.30652618, 9.24319553], [79.30596924, 9.24319553], [79.30596924, 9.24347115], [79.30568695, 9.24347115], [79.30568695, 9.24375153], [79.30486298, 9.24375153], [79.30486298, 9.24403191], [79.30403137, 9.24403191], [79.30403137, 9.24431038], [79.30319214, 9.24431038], [79.30319214, 9.24458981], [79.30263519, 9.24458408], [79.30263519, 9.2448616], [79.30236053, 9.2448616], [79.30236053, 9.24514198], [79.30152893, 9.24514198], [79.30152893, 9.24542046], [79.30097198, 9.24541759], [79.30097198, 9.24569321], [79.30041504, 9.24569321], [79.30041504, 9.24597168], [79.29985809, 9.24597168], [79.29985809, 9.24625015], [79.29930878, 9.24625015], [79.29930878, 9.24652958], [79.29875946, 9.24652958], [79.29875946, 9.24680996], [79.29792023, 9.24680614], [79.29792023, 9.24708366], [79.29736328, 9.24708366], [79.29736328, 9.24736214], [79.29651642, 9.24735928], [79.29651642, 9.2476511], [79.29569244, 9.2476511], [79.29569244, 9.24792004], [79.29486084, 9.24791622], [79.29486084, 9.24819374], [79.29430389, 9.24819374], [79.29430389, 9.24847221], [79.29347229, 9.24846935], [79.29347229, 9.24874973], [79.29263306, 9.24874973], [79.29263306, 9.24903011], [79.29207611, 9.24903011], [79.29207611, 9.24930954], [79.29125214, 9.24930573], [79.29125214, 9.2495842], [79.29069519, 9.2495842], [79.29069519, 9.24985981], [79.28985596, 9.24985981], [79.28985596, 9.25014019], [79.28930664, 9.25014019], [79.28930664, 9.25041962], [79.28847504, 9.2504158], [79.28847504, 9.25069427], [79.28791809, 9.25069427], [79.28791809, 9.25097179], [79.28708649, 9.25097179], [79.28708649, 9.25125027], [79.28652954, 9.25125027], [79.28652954, 9.25152969], [79.2859726, 9.25152969], [79.2859726, 9.25181103], [79.2848587, 9.25180626], [79.2848587, 9.25208378], [79.2840271, 9.25208378], [79.2840271, 9.25236225], [79.28320313, 9.25236034], [79.28320313, 9.25263977], [79.28263855, 9.25263786], [79.28263855, 9.25319386], [79.28180695, 9.25319386], [79.28180695, 9.25347233], [79.28069305, 9.25347233], [79.28069305, 9.25374985], [79.27958679, 9.25374985], [79.27958679, 9.25347233], [79.27874756, 9.25347233], [79.27874756, 9.25374985], [79.27819824, 9.25374985], [79.27819061, 9.25403118], [79.27764893, 9.25403118], [79.27764893, 9.25431061], [79.27708435, 9.25430584], [79.27708435, 9.25458431], [79.27485657, 9.25457954], [79.27485657, 9.25485992], [79.27401733, 9.25485992], [79.27401733, 9.2551403], [79.27319336, 9.2551403], [79.27319336, 9.25542068], [79.27180481, 9.25541592], [79.27180481, 9.25569439], [79.27124786, 9.25569439], [79.27124786, 9.25597191], [79.26846313, 9.25597], [79.26847076, 9.25625038], [79.26763916, 9.25625038], [79.26763916, 9.2565279], [79.26708221, 9.2565279], [79.26708221, 9.25681973], [79.26625061, 9.25680733], [79.26625061, 9.25708199], [79.26457977, 9.25708199], [79.26457977, 9.25736046], [79.26374817, 9.25736046], [79.26374817, 9.25708199], [79.26152802, 9.25708199], [79.26152802, 9.25736046], [79.26125336, 9.25736046], [79.26125336, 9.25764084], [79.26097107, 9.25764084], [79.26097107, 9.25792122], [79.25930786, 9.25791645], [79.25930786, 9.25819492], [79.25846863, 9.25819492], [79.25846863, 9.2584734], [79.25736237, 9.25846958], [79.25736237, 9.25875092], [79.25541687, 9.25875092], [79.25541687, 9.2590313], [79.25514221, 9.2590313], [79.25514221, 9.25931072], [79.25345612, 9.25931072], [79.25345612, 9.2595892], [79.25096893, 9.2595892], [79.25096893, 9.25931072], [79.24931335, 9.25931072], [79.24931335, 9.2595892], [79.24874878, 9.25958157], [79.24874878, 9.25986099], [79.24819183, 9.25986099], [79.24819183, 9.26014137], [79.24624634, 9.26014137], [79.24624634, 9.25986099], [79.24597168, 9.25986099], [79.24597168, 9.25958157], [79.2454071, 9.2595892], [79.2454071, 9.25931072], [79.24402618, 9.25931072], [79.24402618, 9.2595892], [79.23902893, 9.2595892], [79.23902893, 9.25931072], [79.23764038, 9.25931072], [79.23764038, 9.2590313], [79.23458099, 9.2590313], [79.23458099, 9.25931072], [79.23319244, 9.25931072], [79.23319244, 9.2595892], [79.23124695, 9.2595892], [79.23124695, 9.25931072], [79.23097229, 9.25931072], [79.23097229, 9.2595892], [79.22680664, 9.2595892], [79.22680664, 9.25931072], [79.22402954, 9.25931072], [79.22402954, 9.2590313], [79.22348022, 9.2590313], [79.22348022, 9.25875092], [79.22292328, 9.25875092], [79.22292328, 9.25846958], [79.2223587, 9.2584734], [79.2223587, 9.25819492], [79.22208405, 9.25819492], [79.22208405, 9.25791645], [79.2215271, 9.25792122], [79.2215271, 9.25764084], [79.22125244, 9.25764084], [79.22125244, 9.25736046], [79.21930695, 9.25736046], [79.21930695, 9.25708199], [79.21902466, 9.25708199], [79.21902466, 9.25680733], [79.21875, 9.25681973], [79.21875, 9.25625038], [79.21847534, 9.25625038], [79.21847534, 9.25597191], [79.21819305, 9.25597191], [79.21819305, 9.25569439], [79.21736145, 9.25569439], [79.21736145, 9.2551403], [79.21708679, 9.2551403], [79.21708679, 9.25319195], [79.2168045, 9.25319386], [79.2168045, 9.25263786], [79.2159729, 9.25263977], [79.2159729, 9.2529211], [79.21569824, 9.25291634], [79.21569061, 9.25319386], [79.21541595, 9.25319386], [79.21541595, 9.25347233], [79.2151413, 9.25347233], [79.2151413, 9.25374985], [79.21485901, 9.25374985], [79.21485901, 9.25403118], [79.21458435, 9.25402832], [79.21458435, 9.25458431], [79.21430206, 9.25458431], [79.21430206, 9.25597191], [79.21457672, 9.25597], [79.21457672, 9.2565279], [79.21485901, 9.2565279], [79.21485901, 9.25681973], [79.2151413, 9.25680733], [79.2151413, 9.25708199], [79.21541595, 9.25708199], [79.21541595, 9.25736046], [79.21569061, 9.25736046], [79.21569824, 9.25764084], [79.2159729, 9.25764084], [79.2159729, 9.25792122], [79.21624756, 9.25791645], [79.21624756, 9.2584734], [79.21679688, 9.25846958], [79.21679688, 9.25875092], [79.21708679, 9.25875092], [79.21708679, 9.25931072], [79.21734619, 9.25931072], [79.21734619, 9.25986099], [79.21763611, 9.25986099], [79.21763611, 9.26041889], [79.2179184, 9.26041889], [79.2179184, 9.26153088], [79.21819305, 9.26153088], [79.21819305, 9.26180935], [79.21847534, 9.26180458], [79.21847534, 9.26236057], [79.21875, 9.26236057], [79.21875, 9.26263905], [79.2195816, 9.26263046], [79.2195816, 9.26292133], [79.22097015, 9.26292133], [79.22097015, 9.26403141], [79.22070313, 9.26403141], [79.22070313, 9.26431179], [79.22097015, 9.26430511], [79.22097015, 9.26458263], [79.2206955, 9.26458263], [79.2206955, 9.26486111], [79.22097015, 9.26486111], [79.22097015, 9.26542187], [79.2206955, 9.2654171], [79.2206955, 9.26597309], [79.22097015, 9.26597118], [79.22097015, 9.26625061], [79.22125244, 9.2662487], [79.22125244, 9.26708317], [79.22097015, 9.26708126], [79.22097015, 9.26764202], [79.22041321, 9.26764202], [79.22041321, 9.26791954], [79.22013855, 9.26791668], [79.22013855, 9.26819324], [79.21986389, 9.26819324], [79.21986389, 9.26847076], [79.2195816, 9.26847076], [79.2195816, 9.26902962], [79.21902466, 9.26902676], [79.21902466, 9.26958275], [79.21875, 9.26958275], [79.21875, 9.26986122], [79.21901703, 9.26986122], [79.21901703, 9.2701416], [79.21930695, 9.2701416], [79.21930695, 9.27042198], [79.21902466, 9.27041531], [79.21902466, 9.27069569], [79.21763611, 9.27069569], [79.21763611, 9.2709713], [79.21679688, 9.2709713], [79.21679688, 9.27125168], [79.2159729, 9.27125168], [79.2159729, 9.27153015], [79.21569824, 9.27153015], [79.21569061, 9.27182102], [79.21541595, 9.27180576], [79.21541595, 9.27208424], [79.21485901, 9.27208424], [79.21485901, 9.27236176], [79.21430969, 9.27235889], [79.21430969, 9.27264023], [79.21375275, 9.27264023], [79.21375275, 9.27291965], [79.21347046, 9.27291775], [79.21347046, 9.27319336], [79.2131958, 9.27319336], [79.2131958, 9.27347183], [79.21180725, 9.27347183], [79.21180725, 9.27375031], [79.20986176, 9.27375031], [79.20986176, 9.27402973], [79.20929718, 9.27402973], [79.20929718, 9.27431011], [79.20847321, 9.2743063], [79.20847321, 9.27458382], [79.20791626, 9.27458382], [79.20791626, 9.27486229], [79.20652771, 9.27486229], [79.20652771, 9.2743063], [79.20680237, 9.27431011], [79.20680237, 9.27402973], [79.20707703, 9.27402973], [79.20707703, 9.27375031], [79.20735931, 9.27375031], [79.20735931, 9.27347183], [79.20708466, 9.27347183], [79.20708466, 9.27319336], [79.20680237, 9.27319336], [79.20680237, 9.27291775], [79.20625305, 9.27291965], [79.20625305, 9.27264023], [79.20569611, 9.27264023], [79.20569611, 9.27291965], [79.20541382, 9.27291775], [79.20541382, 9.27319336], [79.20513916, 9.27319336], [79.20513916, 9.27347183], [79.20485687, 9.27347183], [79.20485687, 9.27431011], [79.20458221, 9.2743063], [79.20458221, 9.27458382], [79.20430756, 9.27458382], [79.20430756, 9.27736187], [79.20458221, 9.27736187], [79.20458221, 9.27791977], [79.2048645, 9.27791595], [79.2048645, 9.27871132], [79.2048645, 9.27958202], [79.20513916, 9.27958202], [79.20513916, 9.28042126], [79.20680237, 9.28041553], [79.20680237, 9.28097153], [79.20707703, 9.28096962], [79.20707703, 9.28125], [79.2076416, 9.28125], [79.2076416, 9.28153133], [79.20818329, 9.28153133], [79.20818329, 9.28180885], [79.20847321, 9.28180599], [79.20847321, 9.28208447], [79.20874786, 9.28208447], [79.20874786, 9.28236008], [79.20929718, 9.28236008], [79.20929718, 9.28264141], [79.2095871, 9.28264141], [79.2095871, 9.28292084], [79.2104187, 9.28291607], [79.2104187, 9.28319359], [79.2123642, 9.28319359], [79.2123642, 9.28347206], [79.21290588, 9.28347015], [79.21290588, 9.28376198], [79.2131958, 9.28376198], [79.2131958, 9.28403091], [79.21347046, 9.28403091], [79.21347046, 9.28431129], [79.21375275, 9.28430653], [79.21375275, 9.28458214], [79.21430206, 9.28458214], [79.21430206, 9.28486347], [79.21457672, 9.28485966], [79.21457672, 9.28514099], [79.2151413, 9.28514099], [79.2151413, 9.28542137], [79.21541595, 9.2854166], [79.21541595, 9.28569508], [79.2159729, 9.28569508], [79.2159729, 9.2859726], [79.21624756, 9.28596973], [79.21624756, 9.28625107], [79.21652985, 9.28625107], [79.21652985, 9.2868042], [79.2168045, 9.2868042], [79.2168045, 9.28736115], [79.21708679, 9.28736115], [79.21708679, 9.28792095], [79.21736145, 9.28791714], [79.21736145, 9.28819466], [79.21763611, 9.28818989], [79.21763611, 9.28875065], [79.2179184, 9.28875065], [79.2179184, 9.28931236], [79.21819305, 9.28930473], [79.21819305, 9.28986073], [79.21848297, 9.28986073], [79.21848297, 9.29042053], [79.21875, 9.29041672], [79.21875, 9.29069519], [79.21902466, 9.29069519], [79.21902466, 9.2909708], [79.2195816, 9.29097271], [79.2195816, 9.29125118], [79.21985626, 9.29125118], [79.21985626, 9.29153061], [79.22013855, 9.29153061], [79.22013855, 9.29181194], [79.22041321, 9.29180527], [79.22041321, 9.29208279], [79.2223587, 9.29208279], [79.2223587, 9.29180527], [79.22569275, 9.29181194], [79.22569275, 9.29153061], [79.22624969, 9.29153061], [79.22624969, 9.29181194], [79.22846985, 9.29180527], [79.22846985, 9.29208279], [79.2298584, 9.29208279], [79.2298584, 9.29236126], [79.23042297, 9.29236126], [79.23042297, 9.29264069], [79.23152924, 9.29264069], [79.23152924, 9.29236126], [79.23430634, 9.29236126], [79.23430634, 9.29208279], [79.23652649, 9.29208279], [79.23652649, 9.29180527], [79.23764038, 9.29180527], [79.23764038, 9.29208279], [79.23930359, 9.29208279], [79.23930359, 9.29180527], [79.23986053, 9.29180527], [79.23986053, 9.29208279], [79.24180603, 9.29208279], [79.24180603, 9.29236126], [79.24236298, 9.29236126], [79.24236298, 9.29264069], [79.24263763, 9.29264069], [79.24263763, 9.29236126], [79.24346924, 9.29236126], [79.24346924, 9.29208279], [79.24624634, 9.29208279], [79.24624634, 9.29180527], [79.24931335, 9.29181194], [79.24931335, 9.29153061], [79.25345612, 9.29153061], [79.25345612, 9.29181194], [79.25485992, 9.29181194], [79.25485992, 9.29153061], [79.25541687, 9.29153061], [79.25541687, 9.29181194], [79.25569153, 9.29180527], [79.25569153, 9.29208279], [79.25680542, 9.29208279], [79.25680542, 9.29236126], [79.25875092, 9.29236126], [79.25875092, 9.29208279], [79.26168823, 9.29208279], [79.26235962, 9.29208279], [79.26235962, 9.29236126], [79.26403046, 9.29236126], [79.26403046, 9.29264069], [79.26513672, 9.29264069], [79.26513672, 9.29292202], [79.26569366, 9.29291725], [79.26569366, 9.29319477], [79.26763916, 9.29319477], [79.26763916, 9.29347324], [79.26790619, 9.29347134], [79.26790619, 9.29375076], [79.26819611, 9.29375076], [79.26819611, 9.29402924], [79.26875305, 9.29402924], [79.26875305, 9.29430962], [79.26930237, 9.29430485], [79.26930237, 9.29458332], [79.26985931, 9.29458141], [79.26985931, 9.29486084], [79.2701416, 9.29486084], [79.2701416, 9.29513931], [79.27041626, 9.29513931], [79.27041626, 9.29541969], [79.27069092, 9.29541969], [79.27069092, 9.29570007], [79.27097321, 9.2956953], [79.27097321, 9.29624939], [79.27124786, 9.29624939], [79.27124786, 9.29653168], [79.27152252, 9.29653168], [79.27152252, 9.29763985], [79.27180481, 9.29763985], [79.27180481, 9.29847145], [79.27236176, 9.29847145], [79.27236176, 9.2990303], [79.27263641, 9.2990303], [79.27263641, 9.29930973], [79.27236176, 9.29930973], [79.27236176, 9.3004179], [79.27263641, 9.3004179], [79.27263641, 9.30097198], [79.2729187, 9.30097198], [79.2729187, 9.30180645], [79.27263641, 9.30180073], [79.27263641, 9.30263996], [79.2729187, 9.30263996], [79.2729187, 9.30292034], [79.27319336, 9.30291557], [79.27319336, 9.30319405], [79.27347565, 9.30319405], [79.27347565, 9.30347157], [79.27375031, 9.30346966], [79.27375031, 9.30375004], [79.27402496, 9.30375004], [79.27402496, 9.30387974], [79.27401733, 9.30403042], [79.27430725, 9.30402756], [79.27430725, 9.30458355], [79.27458954, 9.30458164], [79.27458954, 9.30513954], [79.2748642, 9.30513763], [79.2748642, 9.30569363], [79.27513885, 9.30568886], [79.27513885, 9.30624962], [79.27540588, 9.30624962], [79.27540588, 9.30653], [79.2756958, 9.30653], [79.2756958, 9.30681133], [79.27597046, 9.30680561], [79.27597046, 9.30708408], [79.27625275, 9.30708408], [79.27625275, 9.3073597], [79.2765274, 9.3073597], [79.2765274, 9.3079319], [79.27680206, 9.30791569], [79.27680206, 9.30847168], [79.27707672, 9.30846977], [79.27707672, 9.30903053], [79.27735901, 9.30903053], [79.27735901, 9.30931091], [79.2776413, 9.30930424], [79.2776413, 9.30986023], [79.27791595, 9.30986023], [79.27791595, 9.31014061], [79.27819061, 9.31014061], [79.27819824, 9.31042099], [79.2784729, 9.31041622], [79.2784729, 9.31069374], [79.27874756, 9.31069374], [79.27874756, 9.31097221], [79.27902985, 9.31097031], [79.27902985, 9.31125069], [79.2793045, 9.31125069], [79.2793045, 9.31208229], [79.27986145, 9.31208229], [79.27986145, 9.31180668], [79.28013611, 9.31180668], [79.28013611, 9.31235981], [79.2804184, 9.3123579], [79.2804184, 9.31264114], [79.28069305, 9.31264114], [79.28069305, 9.31292057], [79.28236389, 9.31291676], [79.28236389, 9.31375122], [79.28291321, 9.31374168], [79.28291321, 9.31403065], [79.28346252, 9.31403065], [79.28346252, 9.31431103], [79.2840271, 9.31430531], [79.2840271, 9.31458473], [79.28430176, 9.31458473], [79.28430176, 9.3148613], [79.2848587, 9.3148613], [79.2848587, 9.3154192], [79.28514099, 9.31541729], [79.28514099, 9.31569481], [79.28541565, 9.31569481], [79.28541565, 9.31597328], [79.28569794, 9.31597328], [79.28569794, 9.3162508], [79.2859726, 9.3162508], [79.2859726, 9.31681156], [79.28624725, 9.31680489], [79.28624725, 9.31708336], [79.28652954, 9.31708336], [79.28652954, 9.31736088], [79.2876358, 9.31736088], [79.2876358, 9.31764126], [79.28848267, 9.31764126], [79.28848267, 9.31792164], [79.28902435, 9.31791687], [79.28902435, 9.31847095], [79.28930664, 9.31847095], [79.28930664, 9.31987], [79.29013824, 9.31987], [79.29013824, 9.32014084], [79.29070282, 9.32014084], [79.29070282, 9.32041931], [79.29152679, 9.3204174], [79.29152679, 9.32069302], [79.29319763, 9.32069492], [79.29319763, 9.3209734], [79.29347229, 9.32097054], [79.29347229, 9.32125092], [79.29402924, 9.32125092], [79.29402924, 9.32152939], [79.29429626, 9.32152939], [79.29429626, 9.32180977], [79.29624939, 9.321805], [79.29624939, 9.32208347], [79.29680634, 9.32208347], [79.29680634, 9.32236099], [79.29819489, 9.32236099], [79.29818726, 9.32208061], [79.29846954, 9.32208347], [79.29846954, 9.32236099], [79.29930878, 9.32236099], [79.29930878, 9.32263947], [79.30042267, 9.32263947], [79.30042267, 9.32293129], [79.30069733, 9.32291698], [79.30069733, 9.32347107], [79.30097198, 9.32347107], [79.30097198, 9.3237524], [79.30124664, 9.3237524], [79.30124664, 9.3243103], [79.30152893, 9.32430458], [79.30152893, 9.32458305], [79.30236053, 9.32458305], [79.30236053, 9.32486153], [79.30264282, 9.32486153], [79.30264282, 9.32514191], [79.30291748, 9.32514191], [79.30291748, 9.32542038], [79.30347443, 9.32541847], [79.30347443, 9.32569313], [79.30403137, 9.32569313], [79.30403137, 9.32597065], [79.30596924, 9.32597065], [79.30596924, 9.32625198], [79.30652618, 9.32625198], [79.30652618, 9.32653046], [79.30680847, 9.32653046], [79.30680847, 9.32681179], [79.30735779, 9.32680607], [79.30735779, 9.32708359], [79.30791473, 9.32708359], [79.30791473, 9.32736206], [79.30847168, 9.3273592], [79.30847168, 9.32763958], [79.30902863, 9.32763958], [79.30902863, 9.32791996], [79.30958557, 9.32791805], [79.30958557, 9.32819366], [79.31014252, 9.32819366], [79.31014252, 9.32847214], [79.31236267, 9.32847214], [79.31236267, 9.32819366], [79.31291962, 9.32819366], [79.31291962, 9.32791805], [79.31458282, 9.32791996], [79.31458282, 9.32763958], [79.31485748, 9.32763958], [79.31485748, 9.3273592], [79.31569672, 9.32736206], [79.31569672, 9.32708359], [79.31652832, 9.32708359], [79.31652832, 9.32680607], [79.31680298, 9.32681179], [79.31680298, 9.32653046], [79.31764221, 9.32653046], [79.31764221, 9.32625198], [79.31819153, 9.32625198], [79.31819153, 9.32597065], [79.31874847, 9.32597065], [79.31874847, 9.32569313], [79.31930542, 9.32569313], [79.31930542, 9.32541847], [79.32013702, 9.32542038], [79.32013702, 9.32514191], [79.32068634, 9.32514191], [79.32068634, 9.32486153], [79.32125092, 9.32486153], [79.32125092, 9.32430458], [79.3215332, 9.3243103], [79.3215332, 9.32403183], [79.32208252, 9.32403183], [79.32208252, 9.3237524], [79.32263947, 9.32374859], [79.32263947, 9.32347107], [79.32347107, 9.32347107], [79.32347107, 9.32319546], [79.32402802, 9.32319546], [79.32402802, 9.32291698], [79.32430267, 9.32293129], [79.32430267, 9.32263947], [79.32457733, 9.32263947], [79.32457733, 9.32236099], [79.32514191, 9.32236099], [79.32514191, 9.32208347], [79.32541656, 9.32208347], [79.32541656, 9.321805], [79.32624817, 9.32180977], [79.32624817, 9.32152939], [79.32681274, 9.32152939], [79.32681274, 9.32125092], [79.32707977, 9.32125092], [79.32707977, 9.32097054], [79.32736206, 9.3209734], [79.32736206, 9.32069492], [79.32791901, 9.32069302], [79.32791901, 9.3204174], [79.32847595, 9.32041931], [79.32847595, 9.32014084], [79.3290329, 9.32014084], [79.3290329, 9.31987], [79.32930756, 9.31987], [79.32930756, 9.31958103], [79.3298645, 9.31958294], [79.3298645, 9.31930542], [79.33040619, 9.31931019], [79.33040619, 9.31903076], [79.33069611, 9.31903076], [79.33069611, 9.31875134], [79.33097076, 9.31875134], [79.33097076, 9.31847095], [79.33125305, 9.31847095], [79.33125305, 9.31763935], [79.33152771, 9.31764126], [79.33152771, 9.31708145], [79.33208466, 9.31708336], [79.33208466, 9.31597328], [79.33235931, 9.31597328], [79.33235931, 9.31569481], [79.33319092, 9.31569481], [79.33319092, 9.31513882], [79.33347321, 9.31514072], [79.33347321, 9.3148613], [79.33374786, 9.3148613], [79.33374786, 9.31430531], [79.33403015, 9.31431103], [79.33403015, 9.31403065], [79.33429718, 9.31403065], [79.33429718, 9.31346989], [79.3345871, 9.31347275], [79.3345871, 9.31263828], [79.33486938, 9.31264114], [79.33486938, 9.31153107], [79.33513641, 9.31153107], [79.33513641, 9.30986023], [79.33486176, 9.30986023], [79.33486176, 9.30847168], [79.3345871, 9.30847168], [79.3345871, 9.30791569], [79.33403015, 9.3079319], [79.33403015, 9.3073597], [79.33374786, 9.3073597], [79.33374786, 9.30680561], [79.33319092, 9.30681133], [79.33319092, 9.30597019], [79.33291626, 9.3059721], [79.33291626, 9.30402756], [79.3326416, 9.30403042], [79.3326416, 9.30346966], [79.33235931, 9.30347157], [79.33235931, 9.30319405], [79.33208466, 9.30319405], [79.33208466, 9.30291557], [79.33152771, 9.30292034], [79.33152771, 9.30263996], [79.33069611, 9.30263996], [79.33069611, 9.3020792], [79.33041382, 9.30208397], [79.33041382, 9.30152798], [79.32985687, 9.30153179], [79.32985687, 9.30125046], [79.32930756, 9.30125046], [79.32930756, 9.30097198], [79.32902527, 9.30097198], [79.32902527, 9.30069447], [79.32875061, 9.30069447], [79.32875061, 9.3004179], [79.32847595, 9.3004179], [79.32847595, 9.30014038], [79.32818604, 9.30014038], [79.32818604, 9.29958057], [79.32791901, 9.29958439], [79.32791901, 9.29930592], [79.32763672, 9.29930973], [79.32763672, 9.2990303], [79.32736206, 9.2990303], [79.32736206, 9.29874039], [79.32707977, 9.29874897], [79.32707977, 9.29791546], [79.32736206, 9.29792023], [79.32736206, 9.29486084], [79.32791901, 9.29486084], [79.32791901, 9.29430962], [79.32707977, 9.29430962], [79.32707977, 9.29402924], [79.32653046, 9.29402924], [79.32653046, 9.29264069], [79.32514191, 9.29264069], [79.32514191, 9.29236126], [79.32485962, 9.29236126], [79.32485962, 9.29208279], [79.32458496, 9.29208279], [79.32458496, 9.29180527], [79.32402802, 9.29181194], [79.32402802, 9.29153061], [79.32375336, 9.29153061], [79.32375336, 9.29125118], [79.32347107, 9.29125118], [79.32347107, 9.29069519], [79.32319641, 9.29069519], [79.32319641, 9.29041672], [79.32235718, 9.29042053], [79.32235718, 9.28986073], [79.32180786, 9.28986073], [79.32180786, 9.28958321], [79.32152557, 9.28958321], [79.32152557, 9.28930473], [79.32125092, 9.28931236], [79.32125092, 9.28903103], [79.32096863, 9.28903103], [79.32096863, 9.28764057], [79.32013702, 9.28764057], [79.32013702, 9.28736115], [79.31958008, 9.28736115], [79.31958008, 9.2868042], [79.31930542, 9.2868042], [79.31930542, 9.28625107], [79.31819153, 9.28625107], [79.31819153, 9.28596973], [79.31764221, 9.2859726], [79.31764221, 9.28569508], [79.31708527, 9.28569508], [79.31708527, 9.2854166], [79.31652832, 9.28542137], [79.31652832, 9.28514099], [79.31624603, 9.28514099], [79.31624603, 9.28485966], [79.31597137, 9.28485966], [79.31597137, 9.28347206], [79.31569672, 9.28347206], [79.31569672, 9.2826376], [79.31513977, 9.28264141], [79.31513977, 9.28236008], [79.31458282, 9.28236008], [79.31458282, 9.28180599], [79.31541443, 9.28180599], [79.31541443, 9.28208447], [79.31569672, 9.28208447], [79.31569672, 9.28236008], [79.31708527, 9.28236008], [79.31708527, 9.28208447], [79.31735992, 9.28208447], [79.31735992, 9.28152847], [79.31764221, 9.28153133], [79.31764221, 9.28125], [79.31791687, 9.28125], [79.31791687, 9.28070068], [79.31764221, 9.28070068], [79.31764221, 9.27985954], [79.31735992, 9.2798624], [79.31735992, 9.27875042], [79.31764221, 9.27875042], [79.31764221, 9.27819443], [79.31791687, 9.27819443], [79.31791687, 9.27763844], [79.31764221, 9.27763844], [79.31764221, 9.27569389], [79.31791687, 9.27569389], [79.31791687, 9.27541637], [79.31846619, 9.27542019], [79.31846619, 9.27486038], [79.31819153, 9.27486229], [79.31819153, 9.27375031], [79.31847382, 9.27375031], [79.31846619, 9.27319145], [79.31874847, 9.27319336], [79.31874847, 9.27264023], [79.31903076, 9.27264023], [79.31903076, 9.27235889], [79.31930542, 9.27236176], [79.31930542, 9.27180576], [79.31957245, 9.27182102], [79.31957245, 9.27153015], [79.31986237, 9.27153015], [79.31986237, 9.2709713], [79.32013702, 9.2709713], [79.32013702, 9.27041531], [79.32041931, 9.27042198], [79.32041931, 9.26986122], [79.32069397, 9.26986122], [79.32069397, 9.26930523], [79.32096863, 9.26931], [79.32096863, 9.26902962], [79.32125092, 9.26902962], [79.32125092, 9.26876068], [79.3215332, 9.26876068], [79.3215332, 9.26819134], [79.32208252, 9.26819324], [79.32208252, 9.26791668], [79.32235718, 9.26791954], [79.32235718, 9.26736069], [79.32263947, 9.26736069], [79.32263947, 9.2668047], [79.32290649, 9.26681042], [79.32290649, 9.26653194], [79.32319641, 9.26653194], [79.32319641, 9.26597118], [79.32347107, 9.26597309], [79.32347107, 9.26569462], [79.32375336, 9.26569462], [79.32375336, 9.26513863], [79.32402802, 9.26514053], [79.32402802, 9.26458073], [79.32430267, 9.26458263], [79.32430267, 9.26430511], [79.32457733, 9.26431179], [79.32457733, 9.26375103], [79.32485962, 9.26375103], [79.32485962, 9.26347065], [79.32514191, 9.26347256], [79.32514191, 9.26319504], [79.32541656, 9.26319504], [79.32541656, 9.26263905], [79.32569122, 9.26263905], [79.32569122, 9.26236057], [79.32597351, 9.26236057], [79.32597351, 9.26180458], [79.32624817, 9.26180935], [79.32624817, 9.26153088], [79.32653046, 9.26153088], [79.32653046, 9.26125145], [79.32680511, 9.26124859], [79.32681274, 9.26097012], [79.32707977, 9.26097298], [79.32707977, 9.26069546], [79.32736206, 9.26069546], [79.32736206, 9.26041698], [79.32763672, 9.26041889], [79.32763672, 9.25986099], [79.32791901, 9.25986099], [79.32791901, 9.25958157], [79.32818604, 9.2595892], [79.32818604, 9.25931072], [79.32847595, 9.25931072], [79.32847595, 9.2590313], [79.32874298, 9.2590313], [79.32874298, 9.25875092], [79.3290329, 9.25875092], [79.3290329, 9.25820065], [79.32930756, 9.25819016], [79.32930756, 9.25791645], [79.32958221, 9.25792122], [79.32958221, 9.25764084], [79.32985687, 9.25764084], [79.32985687, 9.25736046], [79.33041382, 9.25736046], [79.33041382, 9.25708199], [79.33069611, 9.25708199], [79.33069611, 9.2565279], [79.33097076, 9.2565279], [79.33097076, 9.25625038], [79.33125305, 9.25625038], [79.33125305, 9.25597191], [79.33152771, 9.25597191], [79.33152771, 9.25569439], [79.33180237, 9.25569439], [79.33180237, 9.25541592], [79.33207703, 9.25542068], [79.33207703, 9.2551403], [79.33235931, 9.2551403], [79.33235931, 9.25485992], [79.3326416, 9.25485992], [79.3326416, 9.25458431], [79.33291626, 9.25458431], [79.33291626, 9.25430584], [79.33319092, 9.25431061], [79.33319092, 9.25403118], [79.33347321, 9.25403118], [79.33347321, 9.25374985], [79.33374786, 9.25374985], [79.33374786, 9.25347233], [79.33403015, 9.25347233], [79.33403015, 9.25319386], [79.33430481, 9.25319386], [79.33430481, 9.25291634], [79.3345871, 9.2529211], [79.3345871, 9.25263977], [79.33486938, 9.25263977], [79.33486938, 9.25236034], [79.3354187, 9.25236225], [79.3354187, 9.25208378], [79.33569336, 9.25208378], [79.33569336, 9.25180626], [79.33598328, 9.25181103], [79.33598328, 9.25152969], [79.33625031, 9.25152969], [79.33625031, 9.25125027], [79.33652496, 9.25125027], [79.33651733, 9.25097179], [79.33680725, 9.25097179], [79.33680725, 9.25069427], [79.33708191, 9.25069427], [79.33708191, 9.2504158], [79.33735657, 9.25041962], [79.33735657, 9.25014019], [79.33763885, 9.25014019], [79.33763885, 9.24985981], [79.3381958, 9.24985981], [79.3381958, 9.2495842], [79.33847046, 9.2495842], [79.33847046, 9.24930573], [79.33875275, 9.24930954], [79.33875275, 9.24903011], [79.3390274, 9.24903011], [79.3390274, 9.24874973], [79.33930206, 9.24874973], [79.33930206, 9.24846935], [79.33958435, 9.24847221], [79.33958435, 9.24819374], [79.33985901, 9.24819374], [79.33985901, 9.24791622], [79.34041595, 9.24792004], [79.34041595, 9.2476511], [79.34069824, 9.2476511], [79.34069824, 9.24735928], [79.3409729, 9.24736214], [79.3409729, 9.24708366], [79.34124756, 9.24708366], [79.34124756, 9.24680614], [79.34152985, 9.24680996], [79.34152985, 9.24652958], [79.34179688, 9.24652958], [79.34179688, 9.24625015], [79.34236145, 9.24625015], [79.34236145, 9.24597168], [79.34263611, 9.24597168], [79.34263611, 9.24569321], [79.34319305, 9.24569321], [79.34319305, 9.24541759], [79.34348297, 9.24542046], [79.34348297, 9.24514198], [79.34374237, 9.24514198], [79.34374237, 9.2448616], [79.34430695, 9.2448616], [79.34430695, 9.24458408], [79.3445816, 9.24458981], [79.3445816, 9.24431038], [79.34485626, 9.24431038], [79.34485626, 9.24403191], [79.34541321, 9.24403191], [79.34541321, 9.24375153], [79.34570313, 9.24375153], [79.34570313, 9.24347115], [79.34597015, 9.24347115], [79.34597015, 9.24319553], [79.3465271, 9.24319553], [79.3465271, 9.24291706], [79.34680939, 9.24291992], [79.34680939, 9.24263859], [79.34707642, 9.24263859], [79.34707642, 9.24236107], [79.34764099, 9.24236107], [79.34764099, 9.2420826], [79.34791565, 9.2420826], [79.34791565, 9.24180508], [79.34819794, 9.24180984], [79.34819794, 9.24151993], [79.34874725, 9.2415266], [79.34874725, 9.24124908], [79.34902954, 9.24125099], [79.34902954, 9.24097061], [79.3493042, 9.24097347], [79.3493042, 9.24069309], [79.34958649, 9.24069309], [79.34958649, 9.24041653], [79.34986877, 9.24042034], [79.34986877, 9.24014091], [79.35041809, 9.24014091], [79.35041809, 9.23986053], [79.35069275, 9.23986053], [79.35069275, 9.23958302], [79.35097504, 9.23958302], [79.35097504, 9.23930454], [79.35124969, 9.23931026], [79.35124969, 9.23903179], [79.35151672, 9.23903179], [79.35151672, 9.23875141], [79.35180664, 9.23875141], [79.35180664, 9.23847103], [79.35236359, 9.23847103], [79.35236359, 9.23819542], [79.35263824, 9.23819542], [79.35263824, 9.23791695], [79.3529129, 9.23792171], [79.3529129, 9.23764133], [79.35320282, 9.23764133], [79.35320282, 9.23736095], [79.35346985, 9.23736095], [79.35346985, 9.23708344], [79.35402679, 9.23708344], [79.35402679, 9.23680496], [79.35430908, 9.23681164], [79.35430908, 9.23653126], [79.35457611, 9.23653126], [79.35457611, 9.23625088], [79.3548584, 9.23625088], [79.3548584, 9.23597145], [79.35514069, 9.23597336], [79.35514069, 9.23569489], [79.35569763, 9.23569489], [79.35569763, 9.23541737], [79.35597229, 9.23541927], [79.35597229, 9.23513889], [79.35624695, 9.23513889], [79.35624695, 9.23486137], [79.35652924, 9.23486137], [79.35652924, 9.2345829], [79.35680389, 9.2345829], [79.35680389, 9.23430538], [79.35736084, 9.2343092], [79.35736084, 9.23403072], [79.35764313, 9.23403072], [79.35764313, 9.2337513], [79.35791779, 9.2337513], [79.35791779, 9.23347282], [79.35819244, 9.23347282], [79.35819244, 9.2331953], [79.35847473, 9.2331953], [79.35847473, 9.23291683], [79.35901642, 9.23292065], [79.35901642, 9.2326498], [79.35930634, 9.2326498], [79.35930634, 9.23236275], [79.35958099, 9.23236275], [79.35958099, 9.23208046], [79.35986328, 9.23208237], [79.35986328, 9.23180676], [79.36013794, 9.23181057], [79.36013794, 9.23153114], [79.36068726, 9.23153114], [79.36068726, 9.2312479], [79.36096954, 9.23125076], [79.36096954, 9.23097324], [79.36125183, 9.23097324], [79.36125183, 9.23069382], [79.36152649, 9.23069382], [79.36152649, 9.2304163], [79.36207581, 9.23042107], [79.36207581, 9.23014069], [79.36235809, 9.23014069], [79.36235809, 9.22986031], [79.36264038, 9.22986031], [79.36264038, 9.22930431], [79.36292267, 9.22931099], [79.36292267, 9.22903061], [79.36319733, 9.22903061], [79.36319733, 9.22875023], [79.36347198, 9.22875023], [79.36347198, 9.22847176], [79.36374664, 9.22847176], [79.36374664, 9.22819424], [79.36402893, 9.22819424], [79.36402893, 9.22791576], [79.36429596, 9.22792053], [79.36429596, 9.22764015], [79.36458588, 9.22764015], [79.36458588, 9.22735977], [79.36486053, 9.22735977], [79.36486053, 9.22708416], [79.36513519, 9.22708416], [79.36513519, 9.22680569], [79.36541748, 9.22681141], [79.36541748, 9.22652054], [79.36597443, 9.22652817], [79.36597443, 9.22624969], [79.36624908, 9.22624969], [79.36624908, 9.22597027], [79.36680603, 9.22597218], [79.36680603, 9.2256937], [79.36708069, 9.2256937], [79.36708069, 9.22541809], [79.36763763, 9.22542095], [79.36763763, 9.22513962], [79.36791229, 9.22513962], [79.36791229, 9.22486019], [79.36819458, 9.2248621], [79.36819458, 9.22458363], [79.36846924, 9.22458363], [79.36846924, 9.22430611], [79.36875153, 9.22431087], [79.36875153, 9.22402954], [79.36902618, 9.22402954], [79.36902618, 9.22375202], [79.36930847, 9.22375202], [79.36930847, 9.22348118], [79.36958313, 9.22348118], [79.36958313, 9.22318935], [79.36985779, 9.22319412], [79.36985779, 9.22291565], [79.37014008, 9.22292042], [79.37014008, 9.22264004], [79.3704071, 9.22264004], [79.3704071, 9.22235966], [79.37069702, 9.22236156], [79.37069702, 9.22208405], [79.37097168, 9.22208405], [79.37097168, 9.22180557], [79.37124634, 9.22181034], [79.37124634, 9.22152996], [79.37152863, 9.22152996], [79.37152863, 9.22124958], [79.3720932, 9.22124958], [79.3720932, 9.2209692], [79.37236023, 9.22097206], [79.37236023, 9.22069359], [79.37264252, 9.22069359], [79.37264252, 9.22041798], [79.37291718, 9.22042179], [79.37291718, 9.22014046], [79.37319183, 9.22014046], [79.37319183, 9.21986198], [79.37374878, 9.21986198], [79.37374878, 9.21958447]]], [[[79.21485901, 9.25069427], [79.21485901, 9.25097179], [79.21902466, 9.25097179], [79.21902466, 9.25069427], [79.21930695, 9.25069427], [79.21930695, 9.2504158], [79.2195816, 9.25041962], [79.2195816, 9.25014019], [79.21985626, 9.25014019], [79.21985626, 9.24985981], [79.22013855, 9.24985981], [79.22013855, 9.24930573], [79.22041321, 9.24930954], [79.22041321, 9.24903011], [79.22097015, 9.24903011], [79.22097015, 9.24874973], [79.2215271, 9.24874973], [79.2215271, 9.24846935], [79.22208405, 9.24847221], [79.22208405, 9.24819374], [79.2223587, 9.24819374], [79.2223587, 9.24763966], [79.22207642, 9.2476511], [79.22207642, 9.2470789], [79.2215271, 9.24708366], [79.2215271, 9.24680614], [79.22013855, 9.24680614], [79.22013855, 9.24708366], [79.21930695, 9.24708366], [79.21930695, 9.24680614], [79.2179184, 9.24680614], [79.2179184, 9.24708366], [79.2168045, 9.24708366], [79.2168045, 9.24680614], [79.21624756, 9.24680996], [79.21624756, 9.24652958], [79.21604156, 9.24652958], [79.21456909, 9.24652767], [79.21430969, 9.24652958], [79.21430969, 9.24640179], [79.21430206, 9.24625015], [79.21401978, 9.24625015], [79.21290588, 9.24625015], [79.21290588, 9.24597168], [79.21208191, 9.24597168], [79.21208191, 9.24569321], [79.21152496, 9.24569321], [79.21152496, 9.24541759], [79.21069336, 9.24542046], [79.21069336, 9.24514198], [79.2104187, 9.24514198], [79.2104187, 9.2448616], [79.20986176, 9.2448616], [79.20986176, 9.24458408], [79.2095871, 9.24458981], [79.2095871, 9.24431038], [79.20903015, 9.24431038], [79.20903015, 9.24403191], [79.20791626, 9.24403191], [79.20791626, 9.24375153], [79.20735931, 9.24375153], [79.20735931, 9.24347115], [79.20680237, 9.24347115], [79.20680237, 9.24319553], [79.20652771, 9.24319553], [79.20652771, 9.24291706], [79.20625305, 9.24291992], [79.20623779, 9.24270821], [79.20597076, 9.24263859], [79.20597076, 9.24236107], [79.20485687, 9.24236107], [79.20485687, 9.24208069], [79.20458221, 9.2420826], [79.20458221, 9.24180508], [79.20347595, 9.24180984], [79.20347595, 9.24151993], [79.20319366, 9.2415266], [79.20319366, 9.24124908], [79.20096588, 9.24125099], [79.20096588, 9.24180984], [79.20124817, 9.24180508], [79.20124817, 9.24319553], [79.20153046, 9.24319553], [79.20153046, 9.24373055], [79.20181274, 9.24375153], [79.20181274, 9.24431038], [79.20207977, 9.24431038], [79.20207977, 9.24458981], [79.20291901, 9.24458981], [79.20291901, 9.24542046], [79.20319366, 9.24541759], [79.20319366, 9.24597168], [79.20347595, 9.24597168], [79.20347595, 9.24625015], [79.20625305, 9.24625015], [79.20625305, 9.24736214], [79.20791626, 9.24736214], [79.20791626, 9.24819374], [79.2076416, 9.24819088], [79.2076416, 9.24930954], [79.20847321, 9.24930573], [79.20847321, 9.2495842], [79.21097565, 9.2495842], [79.21097565, 9.24985981], [79.2131958, 9.24985981], [79.2131958, 9.25014019], [79.21430969, 9.25014019], [79.21430969, 9.25041962], [79.21458435, 9.2504158], [79.21458435, 9.25069427], [79.21485901, 9.25069427]]], [[[79.5293045, 9.38930416], [79.52894592, 9.38960266], [79.52864838, 9.38985252], [79.5293045, 9.38986015], [79.5293045, 9.38930416]]], [[[79.52864838, 9.38985252], [79.52835846, 9.39013767], [79.52874756, 9.39014053], [79.52864838, 9.38985252]]], [[[79.8390274, 11.2365303], [79.8390274, 11.23625183], [79.83985901, 11.23625183], [79.83985901, 11.23597145], [79.8401413, 11.23597145], [79.8401413, 11.23569584], [79.84041595, 11.23569584], [79.84041595, 11.23513985], [79.84152985, 11.23513985], [79.84152985, 11.23486233], [79.8418045, 11.23486233], [79.8418045, 11.23430538], [79.84208679, 11.23431015], [79.84208679, 11.23402119], [79.8418045, 11.23402691], [79.8418045, 11.23374939], [79.84152985, 11.23374939], [79.84152985, 11.23347092], [79.84069824, 11.23347092], [79.84069824, 11.2331953], [79.8390274, 11.2331953], [79.8390274, 11.23347092], [79.83791351, 11.23347092], [79.83791351, 11.2331953], [79.83734894, 11.23319054], [79.83734894, 11.23513985], [79.83708191, 11.23513985], [79.83708191, 11.23542023], [79.8373642, 11.23541546], [79.8373642, 11.23569584], [79.83763885, 11.23569584], [79.83763885, 11.23597145], [79.83790588, 11.23597145], [79.83790588, 11.23625183], [79.83875275, 11.23625183], [79.83875275, 11.2365303], [79.8390274, 11.2365303]]], [[[79.82707977, 11.23736191], [79.82707977, 11.23708057], [79.82819366, 11.23708439], [79.82819366, 11.23680592], [79.82846832, 11.23680973], [79.82846832, 11.23625183], [79.82817841, 11.23625183], [79.82817841, 11.23597145], [79.82791901, 11.23597145], [79.82791901, 11.23569584], [79.82736206, 11.23569584], [79.82736206, 11.23597145], [79.82680511, 11.23597145], [79.82680511, 11.23569584], [79.82624817, 11.23569584], [79.82624817, 11.23541546], [79.82540894, 11.23542023], [79.82540894, 11.23513985], [79.82514191, 11.23513985], [79.82514191, 11.23486233], [79.82430267, 11.23486233], [79.82430267, 11.2345829], [79.82375336, 11.2345829], [79.82375336, 11.23569584], [79.82402802, 11.23569107], [79.82402802, 11.23625183], [79.82430267, 11.23625183], [79.82430267, 11.2365303], [79.82457733, 11.2365303], [79.82457733, 11.23680973], [79.82624817, 11.23680973], [79.82624817, 11.23736191], [79.82707977, 11.23736191]]], [[[79.98902893, 12.25097084], [79.98902893, 12.25125122], [79.99124908, 12.25125122], [79.99124908, 12.25097084], [79.99153137, 12.25097084], [79.99153137, 12.25069141], [79.99180603, 12.25069523], [79.99180603, 12.25041676], [79.99153137, 12.25042152], [79.99153137, 12.24958134], [79.99124908, 12.24958324], [79.99124908, 12.24930477], [79.9909668, 12.2493124], [79.9909668, 12.24903107], [79.99069214, 12.24903107], [79.99069214, 12.24875069], [79.99014282, 12.24875069], [79.99014282, 12.24847126], [79.98986053, 12.24847317], [79.98986053, 12.24819469], [79.98929596, 12.24819946], [79.98929596, 12.24792099], [79.98902893, 12.24792099], [79.98902893, 12.24764061], [79.98874664, 12.24764061], [79.98874664, 12.24736118], [79.98847198, 12.24736118], [79.98847198, 12.24708271], [79.98791504, 12.24708271], [79.98791504, 12.24652863], [79.98735809, 12.24653053], [79.98735809, 12.24625111], [79.98707581, 12.24625111], [79.98707581, 12.24596977], [79.98680878, 12.24597263], [79.98680878, 12.24569511], [79.98652649, 12.24569511], [79.98652649, 12.24541664], [79.98625183, 12.24542999], [79.98625183, 12.24514103], [79.98513794, 12.24514103], [79.98513794, 12.24542999], [79.98542023, 12.24541664], [79.98542023, 12.24597263], [79.98568726, 12.24596977], [79.98568726, 12.24681091], [79.98596954, 12.24680519], [79.98596954, 12.24736118], [79.98625183, 12.24736118], [79.98625183, 12.24792099], [79.98652649, 12.24791718], [79.98652649, 12.24847317], [79.98680878, 12.24847126], [79.98680878, 12.24903107], [79.98708344, 12.24902916], [79.98708344, 12.24958324], [79.98735809, 12.24958134], [79.98735809, 12.25014114], [79.98790741, 12.25014114], [79.98790741, 12.25042152], [79.98847198, 12.25042152], [79.98847198, 12.25097084], [79.98902893, 12.25097084]]], [[[80.32290649, 13.43847084], [80.32290649, 13.43791962], [80.32347107, 13.43791962], [80.32347107, 13.43763924], [80.32375336, 13.43763924], [80.32375336, 13.43736076], [80.32430267, 13.43736076], [80.32430267, 13.43708992], [80.32457733, 13.43708992], [80.32457733, 13.43653202], [80.32485199, 13.43653202], [80.32485199, 13.43597126], [80.32514191, 13.43597317], [80.32514191, 13.4351387], [80.32485199, 13.43514061], [80.32485199, 13.43431187], [80.32347107, 13.43431187], [80.32347107, 13.43403053], [80.32290649, 13.43403053], [80.32290649, 13.43431187], [80.32208252, 13.43430519], [80.32208252, 13.43458271], [80.32152557, 13.43458271], [80.32152557, 13.43486118], [80.32125092, 13.43486118], [80.32125092, 13.43680954], [80.32152557, 13.43680477], [80.32152557, 13.43819523], [80.32208252, 13.43819141], [80.32208252, 13.43847084], [80.32290649, 13.43847084]]], [[[80.22735596, 13.49403191], [80.22735596, 13.49347115], [80.22763824, 13.49347115], [80.22763824, 13.49291706], [80.2279129, 13.49292183], [80.2279129, 13.49236107], [80.22763824, 13.49236107], [80.22763824, 13.49181175], [80.22735596, 13.49181175], [80.22735596, 13.49123955], [80.2270813, 13.49124908], [80.2270813, 13.49069309], [80.2251358, 13.49069309], [80.2251358, 13.49041653], [80.22486115, 13.49042034], [80.22486115, 13.49014091], [80.22402954, 13.49014091], [80.22402954, 13.49181175], [80.22458649, 13.49180508], [80.22458649, 13.4920826], [80.22486115, 13.49208069], [80.22486115, 13.49236107], [80.22541809, 13.49236107], [80.22541809, 13.49263859], [80.22598267, 13.49263859], [80.22598267, 13.49292183], [80.22624969, 13.49291706], [80.22624969, 13.49319553], [80.22680664, 13.49319077], [80.22680664, 13.49403191], [80.22735596, 13.49403191]]], [[[80.27458191, 13.45958328], [80.27458191, 13.4590292], [80.27485657, 13.45903111], [80.27485657, 13.45875072], [80.27513885, 13.45875072], [80.27513885, 13.45819855], [80.27540588, 13.45819855], [80.27540588, 13.45792103], [80.2756958, 13.45792103], [80.2756958, 13.45764065], [80.27597046, 13.45764065], [80.27597046, 13.45708275], [80.27625275, 13.45708275], [80.27625275, 13.45680523], [80.2765274, 13.45681095], [80.2765274, 13.45625114], [80.27680969, 13.45625114], [80.27680206, 13.45597267], [80.27708435, 13.45597267], [80.27708435, 13.45569515], [80.2776413, 13.45569515], [80.2776413, 13.45541668], [80.27791595, 13.45542145], [80.27791595, 13.45513153], [80.2784729, 13.45513821], [80.2784729, 13.45485973], [80.27874756, 13.45485973], [80.27874756, 13.45458031], [80.2793045, 13.45458221], [80.2793045, 13.4543066], [80.27958679, 13.45431137], [80.27958679, 13.45403099], [80.2804184, 13.45403099], [80.2804184, 13.45374966], [80.28125, 13.45374966], [80.28125, 13.45347023], [80.2820816, 13.45347214], [80.2820816, 13.45319366], [80.2831955, 13.45319366], [80.2831955, 13.45291615], [80.2840271, 13.45292091], [80.2840271, 13.45264053], [80.2848587, 13.45264053], [80.2848587, 13.45236015], [80.28514099, 13.45236015], [80.28514099, 13.45180416], [80.28542328, 13.45181084], [80.28542328, 13.45125008], [80.28569794, 13.45125008], [80.28569794, 13.4509697], [80.2859726, 13.4509716], [80.2859726, 13.45041561], [80.28624725, 13.45042133], [80.28624725, 13.44985962], [80.28652954, 13.44986153], [80.28652954, 13.44902802], [80.28624725, 13.44902992], [80.28624725, 13.44847202], [80.28569794, 13.44847202], [80.28569794, 13.44874954], [80.28542328, 13.44874954], [80.28542328, 13.44932175], [80.28514099, 13.44930553], [80.28514099, 13.4495821], [80.2848587, 13.4495821], [80.2848587, 13.44986153], [80.28457642, 13.44985962], [80.28457642, 13.45014], [80.28430176, 13.45013809], [80.28430176, 13.45069408], [80.2840271, 13.45069408], [80.2840271, 13.4509716], [80.28375244, 13.4509697], [80.28375244, 13.45125008], [80.28291321, 13.45125008], [80.28291321, 13.45153141], [80.2820816, 13.45153141], [80.2820816, 13.45181084], [80.28152466, 13.45180416], [80.28152466, 13.45208359], [80.28069305, 13.45208359], [80.28069305, 13.45236015], [80.28013611, 13.45236015], [80.28013611, 13.45264053], [80.27986908, 13.45264053], [80.27986908, 13.45292091], [80.2793045, 13.45291615], [80.2793045, 13.45319366], [80.27874756, 13.45319366], [80.27874756, 13.45347214], [80.27819824, 13.45347023], [80.27819061, 13.45374966], [80.27791595, 13.45374966], [80.27791595, 13.45403099], [80.27735901, 13.45403099], [80.27735901, 13.45431137], [80.27708435, 13.4543066], [80.27708435, 13.45458221], [80.2765274, 13.45458031], [80.2765274, 13.45485973], [80.27625275, 13.45485973], [80.27625275, 13.45513821], [80.2756958, 13.45513153], [80.2756958, 13.45542145], [80.27541351, 13.45541668], [80.27541351, 13.45569515], [80.27513885, 13.45569038], [80.27513885, 13.45625114], [80.27485657, 13.45625114], [80.27485657, 13.45681095], [80.27458191, 13.45680523], [80.27458191, 13.45736122], [80.27430725, 13.45736122], [80.27430725, 13.45792103], [80.27402496, 13.45791721], [80.27402496, 13.45847321], [80.27374268, 13.4584713], [80.27374268, 13.45931244], [80.27402496, 13.45930481], [80.27402496, 13.45958328], [80.27458191, 13.45958328]]], [[[80.23236084, 13.49458313], [80.23236084, 13.49430466], [80.23291779, 13.49430466], [80.23291779, 13.49402714], [80.23319244, 13.49403191], [80.23319244, 13.49375153], [80.23374939, 13.49375153], [80.23374939, 13.49347115], [80.23430634, 13.49347115], [80.23430634, 13.49291706], [80.23457336, 13.49292183], [80.23457336, 13.49236107], [80.23486328, 13.49236107], [80.23486328, 13.49208069], [80.23458099, 13.4920826], [80.23458099, 13.49180508], [80.23430634, 13.49181175], [80.23430634, 13.49123955], [80.23402405, 13.49124908], [80.23402405, 13.49097347], [80.23374939, 13.49097347], [80.23374939, 13.49069309], [80.23041534, 13.49069309], [80.23041534, 13.49124908], [80.23014069, 13.49123955], [80.23014069, 13.49152946], [80.2298584, 13.4915266], [80.2298584, 13.4920826], [80.22957611, 13.49208069], [80.22957611, 13.49263859], [80.22930908, 13.49263859], [80.22930908, 13.49292183], [80.22958374, 13.49291706], [80.22958374, 13.49347115], [80.2298584, 13.49347115], [80.2298584, 13.49375153], [80.23042297, 13.49375153], [80.23042297, 13.49403191], [80.23069763, 13.49402714], [80.23069763, 13.49430466], [80.23124695, 13.49430466], [80.23124695, 13.49458313], [80.23236084, 13.49458313]]], [[[80.26875305, 13.56245422], [80.26875305, 13.56208038], [80.26902771, 13.56208229], [80.26902771, 13.56152916], [80.26930237, 13.56153107], [80.26930237, 13.56097031], [80.26958466, 13.56097221], [80.26958466, 13.56013775], [80.26985931, 13.56014061], [80.26985931, 13.55957985], [80.2701416, 13.55958366], [80.2701416, 13.55902767], [80.27041626, 13.55903053], [80.27041626, 13.55846977], [80.27069092, 13.55847168], [80.27069092, 13.55791569], [80.27097321, 13.55792141], [80.27097321, 13.5573597], [80.27124786, 13.5573597], [80.27124786, 13.55653], [80.27153015, 13.55653], [80.27153015, 13.55597019], [80.27180481, 13.5559721], [80.27180481, 13.55513763], [80.2720871, 13.55513954], [80.2720871, 13.55458164], [80.27236176, 13.55458355], [80.27236176, 13.55375004], [80.27263641, 13.55375004], [80.27263641, 13.55292034], [80.2729187, 13.55292034], [80.2729187, 13.55235958], [80.27319336, 13.55236244], [80.27319336, 13.55152798], [80.27347565, 13.55152798], [80.27347565, 13.55097198], [80.27375031, 13.55097198], [80.27375031, 13.55013657], [80.27401733, 13.55014038], [80.27401733, 13.54958057], [80.27430725, 13.54958439], [80.27430725, 13.54874897], [80.27458191, 13.54875183], [80.27458191, 13.54792023], [80.27485657, 13.54792023], [80.27485657, 13.54736137], [80.27513885, 13.54736137], [80.27513885, 13.54652691], [80.27540588, 13.54653168], [80.27540588, 13.54597092], [80.2756958, 13.54597092], [80.2756958, 13.54513931], [80.27597046, 13.54513931], [80.27597046, 13.54458141], [80.27625275, 13.54458332], [80.27625275, 13.54374886], [80.2765274, 13.54375076], [80.2765274, 13.54292202], [80.27680969, 13.54292202], [80.27680969, 13.54234982], [80.27708435, 13.54236126], [80.27708435, 13.54152679], [80.27735901, 13.54153061], [80.27735901, 13.5409708], [80.2776413, 13.5409708], [80.2776413, 13.5401392], [80.27791595, 13.54014111], [80.27791595, 13.53958035], [80.27819061, 13.53958321], [80.27819824, 13.53874874], [80.2784729, 13.53875065], [80.2784729, 13.53792095], [80.27874756, 13.53792095], [80.27874756, 13.53736115], [80.27902985, 13.53736115], [80.27902985, 13.53652859], [80.27929688, 13.53654003], [80.27929688, 13.53596973], [80.27958679, 13.5359726], [80.27958679, 13.53513813], [80.27986908, 13.53514099], [80.27986908, 13.53458023], [80.28013611, 13.53458214], [80.28013611, 13.53374958], [80.2804184, 13.53374958], [80.2804184, 13.53292084], [80.28069305, 13.53292084], [80.28069305, 13.53236008], [80.28098297, 13.53236008], [80.28097534, 13.53152847], [80.28125, 13.53153133], [80.28125, 13.53096962], [80.28152466, 13.53097153], [80.28152466, 13.53041553], [80.28180695, 13.53041553], [80.28180695, 13.52958202], [80.2820816, 13.52958202], [80.2820816, 13.52902794], [80.28235626, 13.52902985], [80.28235626, 13.52847195], [80.28263855, 13.52847195], [80.28263855, 13.52763844], [80.28291321, 13.52764034], [80.28291321, 13.52707863], [80.2831955, 13.52708435], [80.2831955, 13.52652836], [80.28347015, 13.52653027], [80.28347015, 13.52569103], [80.28375244, 13.5256958], [80.28375244, 13.52486229], [80.2840271, 13.52486229], [80.2840271, 13.52402782], [80.28430176, 13.52402973], [80.28430176, 13.52347183], [80.28458405, 13.52347183], [80.28458405, 13.52264023], [80.2848587, 13.52264023], [80.2848587, 13.52180958], [80.28514099, 13.52180958], [80.28514099, 13.5209713], [80.28541565, 13.5209713], [80.28541565, 13.52013874], [80.28569794, 13.5201416], [80.28569794, 13.51958084], [80.2859726, 13.51958275], [80.2859726, 13.51874924], [80.28624725, 13.51874924], [80.28624725, 13.51791954], [80.28652954, 13.51791954], [80.28652954, 13.51708126], [80.2868042, 13.51708317], [80.2868042, 13.5162487], [80.28708649, 13.51625061], [80.28708649, 13.51541042], [80.28736115, 13.5154171], [80.28736115, 13.51458263], [80.2876358, 13.51458263], [80.2876358, 13.51347256], [80.28791809, 13.51347256], [80.28791809, 13.51263905], [80.28819275, 13.51264095], [80.28819275, 13.51180935], [80.28848267, 13.51180935], [80.28848267, 13.51097012], [80.28874969, 13.51097298], [80.28874969, 13.51013947], [80.28901672, 13.51014137], [80.28901672, 13.50931072], [80.28930664, 13.50931072], [80.28930664, 13.50846958], [80.2895813, 13.5084734], [80.2895813, 13.50763798], [80.28985596, 13.50764084], [80.28985596, 13.50681114], [80.29013824, 13.50681114], [80.29013824, 13.50568962], [80.2904129, 13.50569439], [80.2904129, 13.50485992], [80.29070282, 13.50485992], [80.29069519, 13.50402832], [80.29096985, 13.50403118], [80.29096985, 13.50317955], [80.29125214, 13.50319386], [80.29125214, 13.50236225], [80.29152679, 13.50236225], [80.29152679, 13.50125027], [80.29180908, 13.50125027], [80.29180908, 13.50014019], [80.29207611, 13.50014019], [80.29207611, 13.49903011], [80.2923584, 13.49903011], [80.2923584, 13.49792004], [80.29264069, 13.49792004], [80.29264069, 13.49763966], [80.29292297, 13.49763966], [80.29292297, 13.4970789], [80.29319763, 13.49708366], [80.29319763, 13.49652767], [80.29347229, 13.49652958], [80.29347229, 13.4956913], [80.29374695, 13.49569321], [80.29374695, 13.4948616], [80.29402924, 13.4948616], [80.29402924, 13.49403191], [80.29429626, 13.49403191], [80.29429626, 13.49292183], [80.29458618, 13.49292183], [80.29458618, 13.49181175], [80.29486847, 13.49181175], [80.29486847, 13.49069118], [80.2951355, 13.49069309], [80.2951355, 13.48958302], [80.29541779, 13.48958302], [80.29541779, 13.48847103], [80.29569244, 13.48847103], [80.29569244, 13.48763943], [80.2959671, 13.48764133], [80.2959671, 13.48653126], [80.29624939, 13.48653126], [80.29624939, 13.48569012], [80.29652405, 13.48569489], [80.29652405, 13.48513889], [80.29680634, 13.48513889], [80.29680634, 13.48458004], [80.29708099, 13.4845829], [80.29708099, 13.4837513], [80.29736328, 13.4837513], [80.29736328, 13.48318958], [80.29763794, 13.4831953], [80.29763794, 13.48235989], [80.2979126, 13.48236275], [80.2979126, 13.48181057], [80.29818726, 13.48181057], [80.29818726, 13.48125076], [80.29846954, 13.48125076], [80.29846954, 13.48042107], [80.29875183, 13.48042107], [80.29875183, 13.47986031], [80.29902649, 13.47986031], [80.29902649, 13.47930431], [80.29930878, 13.47930431], [80.29930878, 13.47875023], [80.29957581, 13.47875023], [80.29957581, 13.47819042], [80.29985809, 13.47819424], [80.29985809, 13.47791576], [80.30014038, 13.47792053], [80.30014038, 13.47735977], [80.30042267, 13.47735977], [80.30041504, 13.47680569], [80.30069733, 13.47681141], [80.30069733, 13.47653008], [80.30097198, 13.47653008], [80.30097198, 13.47597027], [80.30124664, 13.47597218], [80.30124664, 13.4756937], [80.30152893, 13.4756937], [80.30152893, 13.47513771], [80.30179596, 13.47513962], [80.30179596, 13.47457981], [80.30152893, 13.47458363], [80.30152893, 13.47375011], [80.30124664, 13.47375202], [80.30124664, 13.4732008], [80.30097198, 13.4732008], [80.30097198, 13.47264004], [80.30124664, 13.47264004], [80.30124664, 13.47235966], [80.30152893, 13.47235966], [80.30152893, 13.47207928], [80.30180359, 13.47208405], [80.30180359, 13.47180557], [80.30208588, 13.47181034], [80.30208588, 13.47152996], [80.30236053, 13.47152996], [80.30236053, 13.47124958], [80.30264282, 13.47124958], [80.30264282, 13.4709692], [80.30319214, 13.47097206], [80.30319214, 13.47069359], [80.30403137, 13.47069359], [80.30403137, 13.47041798], [80.30430603, 13.47042179], [80.30430603, 13.47014046], [80.30458069, 13.47014046], [80.30458069, 13.46986198], [80.30486298, 13.46986198], [80.30486298, 13.46958065], [80.30513763, 13.46958447], [80.30513763, 13.46930599], [80.30541992, 13.46930981], [80.30541992, 13.46903038], [80.30568695, 13.46903038], [80.30568695, 13.46875191], [80.30596924, 13.46875191], [80.30596924, 13.46847057], [80.30625153, 13.46847057], [80.30625153, 13.46819305], [80.30652618, 13.46819305], [80.30652618, 13.4679184], [80.30680847, 13.4679203], [80.30680847, 13.46764183], [80.30708313, 13.46764183], [80.30708313, 13.46736145], [80.30735779, 13.46736145], [80.30735779, 13.46708298], [80.30764008, 13.46708298], [80.30764008, 13.46652699], [80.3079071, 13.46653175], [80.3079071, 13.46597099], [80.30819702, 13.46597099], [80.30819702, 13.46541691], [80.30847168, 13.46541977], [80.30847168, 13.46486092], [80.30874634, 13.46486092], [80.30874634, 13.46402931], [80.30902863, 13.46402931], [80.30902863, 13.46319103], [80.30930328, 13.46319485], [80.30930328, 13.46263885], [80.3095932, 13.46264076], [80.3095932, 13.46181202], [80.3098526, 13.46181202], [80.3098526, 13.4612627], [80.31014252, 13.4612627], [80.31014252, 13.46042156], [80.31041718, 13.46042156], [80.31041718, 13.45958138], [80.31069183, 13.45958328], [80.31069183, 13.4590292], [80.31096649, 13.45903111], [80.31096649, 13.45792103], [80.31124878, 13.45792103], [80.31124878, 13.45653057], [80.31153107, 13.45653057], [80.31153107, 13.45513153], [80.31180573, 13.45513821], [80.31180573, 13.45402908], [80.31208038, 13.45403099], [80.31208038, 13.45292091], [80.31181335, 13.45292091], [80.31181335, 13.45207119], [80.31153107, 13.45208359], [80.31153107, 13.4515276], [80.31124878, 13.45153141], [80.31124878, 13.4509697], [80.31236267, 13.4509716], [80.31236267, 13.45069408], [80.31291962, 13.45069408], [80.31291962, 13.45041561], [80.31346893, 13.45042133], [80.31346893, 13.44985962], [80.31375122, 13.44986153], [80.31375122, 13.44680595], [80.31402588, 13.44681263], [80.31402588, 13.44624996], [80.31430817, 13.44624996], [80.31430817, 13.4456892], [80.31458282, 13.44569397], [80.31458282, 13.44513988], [80.31485748, 13.44514179], [80.31485748, 13.44458199], [80.31513977, 13.44458389], [80.31513977, 13.44375038], [80.31485748, 13.44375038], [80.31485748, 13.44347191], [80.31513977, 13.44347191], [80.31513977, 13.4426403], [80.3154068, 13.4426403], [80.3154068, 13.44180965], [80.31513977, 13.44180965], [80.31513977, 13.44042015], [80.3154068, 13.44042015], [80.3154068, 13.43736076], [80.31569672, 13.43736076], [80.31569672, 13.43708992], [80.315979, 13.43708992], [80.315979, 13.43597126], [80.31541443, 13.43597317], [80.31541443, 13.43569469], [80.31513977, 13.43569469], [80.31513977, 13.43541718], [80.3154068, 13.43542194], [80.3154068, 13.4345808], [80.31513977, 13.43458271], [80.31513977, 13.43375111], [80.31485748, 13.43375111], [80.31485748, 13.43347073], [80.31291962, 13.43347263], [80.31291962, 13.43319511], [80.31208038, 13.43319511], [80.31208038, 13.43291664], [80.31153107, 13.43292141], [80.31153107, 13.43264103], [80.31069183, 13.43264103], [80.31069183, 13.43292141], [80.31041718, 13.43292141], [80.31041718, 13.43264103], [80.3098526, 13.43264103], [80.3098526, 13.43292141], [80.30819702, 13.43291664], [80.30819702, 13.43319511], [80.30764008, 13.43319511], [80.30764008, 13.43347263], [80.30735779, 13.43347073], [80.30735779, 13.43375111], [80.30680847, 13.43375111], [80.30680847, 13.43403053], [80.30652618, 13.43403053], [80.30652618, 13.43431187], [80.30596924, 13.43430519], [80.30596924, 13.43458271], [80.30569458, 13.43458271], [80.30569458, 13.43486118], [80.30541992, 13.43486118], [80.30541992, 13.43542194], [80.30513763, 13.43541718], [80.30513763, 13.43569469], [80.30486298, 13.43569469], [80.30486298, 13.43597317], [80.30458069, 13.43597126], [80.30457306, 13.43653202], [80.30430603, 13.43653202], [80.30430603, 13.43680954], [80.304039, 13.43680954], [80.304039, 13.43708992], [80.30374908, 13.43708992], [80.30374908, 13.43763924], [80.3034668, 13.43763924], [80.3034668, 13.43791962], [80.30319214, 13.43791676], [80.30319214, 13.43819523], [80.30291748, 13.43819141], [80.30291748, 13.43874931], [80.30264282, 13.43874931], [80.30264282, 13.43902969], [80.30236053, 13.43902969], [80.30236053, 13.43931007], [80.30208588, 13.43930531], [80.30208588, 13.4398613], [80.30180359, 13.4398613], [80.30180359, 13.44013977], [80.30152893, 13.44013023], [80.30152893, 13.44042015], [80.30097198, 13.44041538], [80.30097198, 13.44069576], [80.30069733, 13.44069576], [80.30069733, 13.44097137], [80.30014038, 13.44097137], [80.30014038, 13.44124889], [80.29985809, 13.44124889], [80.29985809, 13.44153023], [80.29957581, 13.44153023], [80.29957581, 13.44180965], [80.29902649, 13.44180584], [80.29902649, 13.44208431], [80.29875183, 13.44208145], [80.29875183, 13.44236183], [80.29846954, 13.44236183], [80.29846954, 13.4426403], [80.2979126, 13.4426403], [80.2979126, 13.44291973], [80.29763794, 13.44291782], [80.29763794, 13.44319439], [80.29680634, 13.44319439], [80.29680634, 13.44347191], [80.29651642, 13.44347191], [80.29651642, 13.44375038], [80.29624939, 13.44375038], [80.29624939, 13.44402981], [80.2959671, 13.44402981], [80.2959671, 13.44431019], [80.29569244, 13.44430637], [80.29569244, 13.44458389], [80.29541779, 13.44458389], [80.29541779, 13.44486237], [80.29514313, 13.44486046], [80.29514313, 13.44514179], [80.29486847, 13.44514179], [80.29486847, 13.44542027], [80.29458618, 13.44541645], [80.29458618, 13.4456892], [80.29430389, 13.44569588], [80.29430389, 13.44597244], [80.29402924, 13.44596958], [80.29402924, 13.44624996], [80.29374695, 13.44624996], [80.29374695, 13.44653034], [80.29347229, 13.44653034], [80.29347229, 13.44681263], [80.29319763, 13.44680595], [80.29319763, 13.44708443], [80.29292297, 13.44708157], [80.29292297, 13.44764042], [80.29264069, 13.44763756], [80.29264069, 13.44847202], [80.2923584, 13.44847202], [80.2923584, 13.44932175], [80.29207611, 13.44932175], [80.29207611, 13.45042133], [80.29180908, 13.45042133], [80.29180908, 13.45125008], [80.29152679, 13.45125008], [80.29152679, 13.45208359], [80.29125214, 13.45207119], [80.29125214, 13.45264053], [80.29096985, 13.45263767], [80.29096985, 13.45319366], [80.29070282, 13.45318985], [80.29070282, 13.45374966], [80.2904129, 13.45374966], [80.2904129, 13.45458221], [80.29013824, 13.45458221], [80.29013824, 13.45513821], [80.28986359, 13.45513821], [80.28986359, 13.45569515], [80.2895813, 13.45569038], [80.2895813, 13.45625114], [80.28930664, 13.45625114], [80.28930664, 13.45681095], [80.28902435, 13.45680523], [80.28902435, 13.45736122], [80.28874969, 13.45736122], [80.28874969, 13.45764065], [80.28848267, 13.45764065], [80.28848267, 13.45819855], [80.28819275, 13.45819855], [80.28819275, 13.45875072], [80.28791809, 13.45875072], [80.28791809, 13.45931244], [80.2876358, 13.45931244], [80.2876358, 13.46014118], [80.28736115, 13.46013927], [80.28736115, 13.46097088], [80.28708649, 13.46097088], [80.28708649, 13.46208286], [80.28679657, 13.46208096], [80.28679657, 13.46291924], [80.28652954, 13.46291733], [80.28652954, 13.46347332], [80.28624725, 13.46347141], [80.28624725, 13.46375084], [80.2859726, 13.46375084], [80.2859726, 13.46486092], [80.28569794, 13.46486092], [80.28569794, 13.46625233], [80.28541565, 13.46625233], [80.28541565, 13.46708298], [80.28624725, 13.46708298], [80.28624725, 13.46652699], [80.28652954, 13.46653175], [80.28652954, 13.46625233], [80.28679657, 13.46625233], [80.28679657, 13.46513939], [80.28708649, 13.46513939], [80.28708649, 13.46541977], [80.28736115, 13.46541691], [80.28736115, 13.46597099], [80.2876358, 13.46597099], [80.2876358, 13.46736145], [80.28736115, 13.46736145], [80.28736115, 13.46903038], [80.2876358, 13.46903038], [80.2876358, 13.46930981], [80.28791809, 13.46930599], [80.28791809, 13.47069359], [80.28819275, 13.47069073], [80.28819275, 13.47124958], [80.28791809, 13.47124958], [80.28791809, 13.47152996], [80.28819275, 13.47152996], [80.28819275, 13.4732008], [80.28791809, 13.47319412], [80.28791809, 13.47347164], [80.28819275, 13.47346973], [80.28819275, 13.47431087], [80.28791809, 13.47430611], [80.28791809, 13.47458363], [80.2876358, 13.47458363], [80.2876358, 13.4748621], [80.28736115, 13.47486019], [80.28736115, 13.47513962], [80.28708649, 13.47513771], [80.28708649, 13.4756937], [80.28736115, 13.4756918], [80.28736115, 13.47625923], [80.28708649, 13.47625923], [80.28708649, 13.47681141], [80.2868042, 13.47680569], [80.2868042, 13.47708416], [80.28652954, 13.47708416], [80.28652954, 13.47680569], [80.2859726, 13.47681141], [80.2859726, 13.47653008], [80.28569794, 13.47653008], [80.28569794, 13.47625923], [80.2848587, 13.47625923], [80.2848587, 13.47681141], [80.28457642, 13.47681141], [80.28457642, 13.47735977], [80.2848587, 13.47735977], [80.2848587, 13.47847176], [80.28514099, 13.47847176], [80.28514099, 13.47958469], [80.2848587, 13.47958469], [80.2848587, 13.47986031], [80.28458405, 13.47986031], [80.28458405, 13.48069382], [80.28430939, 13.48069382], [80.28430176, 13.48097229], [80.2840271, 13.48097038], [80.2840271, 13.48181057], [80.28375244, 13.48181057], [80.28375244, 13.48236275], [80.28347015, 13.48236275], [80.28347015, 13.48292065], [80.28375244, 13.48291683], [80.28375244, 13.4831953], [80.2840271, 13.48318958], [80.2840271, 13.4837513], [80.28430176, 13.4837513], [80.28430176, 13.48403072], [80.2840271, 13.48403072], [80.2840271, 13.4843092], [80.28347015, 13.48430538], [80.28347015, 13.4845829], [80.2831955, 13.4845829], [80.2831955, 13.48486137], [80.28291321, 13.48486137], [80.28291321, 13.48513889], [80.28263855, 13.48513889], [80.28263855, 13.48542976], [80.28236389, 13.48541737], [80.28236389, 13.48597336], [80.2820816, 13.48597145], [80.2820816, 13.48653126], [80.28180695, 13.48652744], [80.28180695, 13.48708344], [80.28151703, 13.48708057], [80.28151703, 13.48764133], [80.28180695, 13.48763943], [80.28180695, 13.48847103], [80.28151703, 13.48847103], [80.28151703, 13.48903179], [80.28125, 13.48902702], [80.28125, 13.49124908], [80.28151703, 13.49123955], [80.28151703, 13.49181175], [80.28180695, 13.49180508], [80.28180695, 13.49985981], [80.28152466, 13.49985981], [80.28152466, 13.50069427], [80.28125, 13.50069237], [80.28125, 13.50125027], [80.28097534, 13.50125027], [80.28097534, 13.50208378], [80.28069305, 13.50208378], [80.28069305, 13.50236225], [80.2804184, 13.50236034], [80.2804184, 13.5029211], [80.28013611, 13.50291634], [80.28013611, 13.50319386], [80.27986145, 13.50319386], [80.27986908, 13.50374985], [80.27958679, 13.50374985], [80.27958679, 13.50431061], [80.27929688, 13.50431061], [80.27929688, 13.50485992], [80.27902985, 13.50485992], [80.27902985, 13.50625038], [80.27874756, 13.50625038], [80.27874756, 13.50708199], [80.2784729, 13.50708199], [80.2784729, 13.50819016], [80.27819824, 13.50820065], [80.27819824, 13.50931072], [80.27791595, 13.50931072], [80.27791595, 13.51237202], [80.2776413, 13.51237202], [80.2776413, 13.51264095], [80.27735901, 13.51264095], [80.27735901, 13.51292133], [80.2776413, 13.51292133], [80.2776413, 13.51764202], [80.27791595, 13.51763916], [80.27791595, 13.52069569], [80.2776413, 13.52069092], [80.2776413, 13.52125168], [80.27735901, 13.52124882], [80.27735901, 13.52208424], [80.27707672, 13.52208138], [80.27707672, 13.52291965], [80.27680206, 13.52291775], [80.27680206, 13.52347183], [80.2765274, 13.52347183], [80.2765274, 13.52431011], [80.27625275, 13.5243063], [80.27625275, 13.52486229], [80.27597046, 13.52486038], [80.27597046, 13.52513981], [80.27540588, 13.52513981], [80.27540588, 13.52486038], [80.27513885, 13.52486229], [80.27513885, 13.52402782], [80.27540588, 13.52402973], [80.27540588, 13.52291965], [80.2756958, 13.52291965], [80.2756958, 13.52125168], [80.27597046, 13.52125168], [80.27597046, 13.51902962], [80.27625275, 13.51902962], [80.27625275, 13.51708126], [80.27597046, 13.51708317], [80.27597046, 13.51569462], [80.2756958, 13.51569462], [80.2756958, 13.51513863], [80.27540588, 13.51514053], [80.27540588, 13.51458073], [80.2748642, 13.51458263], [80.2748642, 13.51430511], [80.27430725, 13.51430511], [80.27430725, 13.51458263], [80.27374268, 13.51458073], [80.27374268, 13.51653194], [80.27263641, 13.51653194], [80.27263641, 13.51874924], [80.27236176, 13.51874924], [80.27236176, 13.52042198], [80.2720871, 13.52041531], [80.2720871, 13.52236176], [80.27180481, 13.52236176], [80.27180481, 13.52347183], [80.27124786, 13.52347183], [80.27124786, 13.52375031], [80.27068329, 13.52375031], [80.27068329, 13.52402973], [80.2701416, 13.52402973], [80.2701416, 13.52431011], [80.26985931, 13.52431011], [80.26985931, 13.52402973], [80.26957703, 13.52402973], [80.26957703, 13.52375031], [80.26902771, 13.52375031], [80.26902771, 13.52347183], [80.26875305, 13.52347183], [80.26875305, 13.52319336], [80.26847076, 13.52319336], [80.26847076, 13.52291775], [80.26819611, 13.52291965], [80.26819611, 13.52264023], [80.26790619, 13.52264023], [80.26790619, 13.52235889], [80.26763916, 13.52236176], [80.26763916, 13.52208424], [80.2673645, 13.52208424], [80.2673645, 13.52180481], [80.26597595, 13.52180481], [80.26597595, 13.52208424], [80.26569366, 13.52208424], [80.26569366, 13.52236176], [80.26541901, 13.52235889], [80.26541901, 13.52264023], [80.26513672, 13.52264023], [80.26513672, 13.52291965], [80.26486206, 13.52291775], [80.26486206, 13.52319336], [80.26457977, 13.52319336], [80.26457977, 13.52347183], [80.26431274, 13.52347183], [80.26431274, 13.52431011], [80.26457977, 13.5243063], [80.26457977, 13.52458382], [80.26513672, 13.52458382], [80.26513672, 13.52486229], [80.26568604, 13.52486038], [80.26568604, 13.52513981], [80.26625061, 13.52513981], [80.26625061, 13.52542019], [80.26680756, 13.52541637], [80.26680756, 13.5256958], [80.2673645, 13.5256958], [80.2673645, 13.52597237], [80.26763916, 13.52596855], [80.26763916, 13.52625179], [80.26819611, 13.52625179], [80.26819611, 13.52653027], [80.26847076, 13.52653027], [80.26848602, 13.52680969], [80.26902771, 13.52680588], [80.26902771, 13.52708435], [80.26930237, 13.52708435], [80.26930237, 13.52819443], [80.2701416, 13.52819443], [80.2701416, 13.52847195], [80.27041626, 13.52847195], [80.27041626, 13.52902985], [80.2701416, 13.52902794], [80.2701416, 13.5298624], [80.26985931, 13.5298624], [80.26985931, 13.53041553], [80.26957703, 13.53040886], [80.26957703, 13.53125], [80.26930237, 13.53125], [80.26930237, 13.53181076], [80.26902771, 13.53181076], [80.26902771, 13.53236008], [80.26875305, 13.53236008], [80.26875305, 13.53292084], [80.26847076, 13.53292084], [80.26847076, 13.5334816], [80.26819611, 13.5334816], [80.26819611, 13.53403091], [80.26791382, 13.53402805], [80.26791382, 13.53458214], [80.26763916, 13.53458023], [80.26763916, 13.53542137], [80.26735687, 13.53542137], [80.26735687, 13.53654003], [80.26708221, 13.53654003], [80.26708221, 13.53764057], [80.2673645, 13.53763866], [80.2673645, 13.53819466], [80.26763916, 13.5381918], [80.26763916, 13.53875065], [80.26790619, 13.53875065], [80.26790619, 13.53986073], [80.26763916, 13.53986073], [80.26763916, 13.54125118], [80.26735687, 13.54125118], [80.26735687, 13.54264069], [80.26708221, 13.54264069], [80.26708221, 13.54402924], [80.26680756, 13.54402924], [80.26680756, 13.54486084], [80.2665329, 13.54486084], [80.2665329, 13.54541969], [80.26625061, 13.54541683], [80.26625061, 13.54597092], [80.26597595, 13.54597092], [80.26597595, 13.54653168], [80.26569366, 13.54652691], [80.26569366, 13.5470829], [80.26541901, 13.54708099], [80.26541901, 13.54764175], [80.26513672, 13.54763889], [80.26513672, 13.54819584], [80.26486969, 13.54819107], [80.26486969, 13.54875183], [80.26457977, 13.54874897], [80.26457977, 13.55152798], [80.26486969, 13.5515213], [80.26486969, 13.55263996], [80.26513672, 13.55263996], [80.26513672, 13.55541992], [80.26486206, 13.55541801], [80.26486206, 13.55847168], [80.26457977, 13.55846977], [80.26457977, 13.56014061], [80.26431274, 13.56014061], [80.26875305, 13.56245422]]], [[[80.26541901, 13.51958275], [80.26541901, 13.51930523], [80.26568604, 13.51931], [80.26568604, 13.51902962], [80.26597595, 13.51902962], [80.26597595, 13.51874924], [80.2665329, 13.51874924], [80.26652527, 13.51819324], [80.26680756, 13.51819324], [80.26680756, 13.51763916], [80.26708221, 13.51764202], [80.26708221, 13.51708126], [80.26680756, 13.51708317], [80.26680756, 13.51652718], [80.2665329, 13.51653194], [80.2665329, 13.5156908], [80.26625061, 13.51569462], [80.26625061, 13.51458263], [80.26652527, 13.51458263], [80.26652527, 13.51347256], [80.26680756, 13.51347256], [80.26680756, 13.51236057], [80.26708221, 13.51237202], [80.26708221, 13.51180935], [80.26735687, 13.51180935], [80.26735687, 13.51097012], [80.26763916, 13.51097298], [80.26763916, 13.51041698], [80.26790619, 13.51041889], [80.26790619, 13.50931072], [80.26763916, 13.50931072], [80.26763916, 13.50792122], [80.26735687, 13.50792122], [80.26735687, 13.50653076], [80.26708221, 13.50653076], [80.26708221, 13.50485992], [80.26680756, 13.50485992], [80.26680756, 13.50317955], [80.26652527, 13.50319386], [80.26652527, 13.50152779], [80.26625061, 13.50152969], [80.26625061, 13.50014019], [80.26597595, 13.50014019], [80.26597595, 13.49957943], [80.26541901, 13.4995842], [80.26541901, 13.49985981], [80.26513672, 13.49985981], [80.26513672, 13.50125027], [80.26486206, 13.50125027], [80.26486206, 13.50319386], [80.26513672, 13.50317955], [80.26513672, 13.5051403], [80.26541901, 13.5051403], [80.26541901, 13.50597191], [80.26569366, 13.50597191], [80.26569366, 13.50708199], [80.26597595, 13.50708199], [80.26597595, 13.50819016], [80.26625061, 13.50820065], [80.26625061, 13.50931072], [80.2665329, 13.50931072], [80.2665329, 13.51041889], [80.26625061, 13.51041889], [80.26625061, 13.51125145], [80.26597595, 13.51124859], [80.26597595, 13.51208305], [80.26569366, 13.51208305], [80.26569366, 13.51319504], [80.26541901, 13.51319027], [80.26541901, 13.51403141], [80.26513672, 13.51402664], [80.26513672, 13.51486111], [80.26486206, 13.51486111], [80.26486206, 13.5154171], [80.26457977, 13.51541042], [80.26457977, 13.51625061], [80.26430511, 13.5162487], [80.26430511, 13.51736069], [80.26457977, 13.51736069], [80.26457977, 13.51902962], [80.26486206, 13.51902676], [80.26486206, 13.51958275], [80.26541901, 13.51958275]]], [[[79.70680237, 10.28819466], [79.70680237, 10.28791714], [79.70707703, 10.28792191], [79.70707703, 10.28764057], [79.70735931, 10.28764057], [79.70735931, 10.2870779], [79.7076416, 10.28708267], [79.7076416, 10.28680515], [79.70791626, 10.28681183], [79.70791626, 10.28625107], [79.7076416, 10.28625107], [79.7076416, 10.28569031], [79.70708466, 10.28569508], [79.70708466, 10.2854166], [79.70680237, 10.28542137], [79.70680237, 10.28514099], [79.70540619, 10.28514099], [79.70540619, 10.28542137], [79.7048645, 10.2854166], [79.7048645, 10.28569508], [79.70458221, 10.28569031], [79.70458221, 10.28598022], [79.7040329, 10.28598022], [79.7040329, 10.28625107], [79.70375061, 10.28625107], [79.70375061, 10.28653145], [79.70318604, 10.28653145], [79.70318604, 10.28681183], [79.70291901, 10.28680515], [79.70291901, 10.28708267], [79.70236206, 10.28708267], [79.70236206, 10.28736115], [79.70263672, 10.28736115], [79.70263672, 10.28792191], [79.70291901, 10.28791714], [79.70291901, 10.28819466], [79.70680237, 10.28819466]]], [[[79.69790649, 10.2901392], [79.69790649, 10.28986073], [79.69904327, 10.28986073], [79.69902802, 10.28958321], [79.70041656, 10.28958321], [79.70041656, 10.28930473], [79.70096588, 10.28931046], [79.70096588, 10.28875065], [79.70069122, 10.28875065], [79.70069122, 10.28819084], [79.69847107, 10.28819466], [79.69847107, 10.28847313], [79.69763947, 10.28847122], [79.69763947, 10.28875065], [79.69708252, 10.28875065], [79.69708252, 10.2901392], [79.69790649, 10.2901392]]], [[[79.69569397, 10.2909708], [79.69569397, 10.29041672], [79.69597626, 10.29041958], [79.69597626, 10.2901392], [79.6965332, 10.2901392], [79.6965332, 10.28986073], [79.69625092, 10.28986073], [79.69625092, 10.28958321], [79.69569397, 10.28958321], [79.69569397, 10.28930473], [79.69430542, 10.28930473], [79.69430542, 10.28958321], [79.69346619, 10.2895813], [79.69346619, 10.29124928], [79.69486237, 10.29124928], [79.69486237, 10.29097271], [79.69569397, 10.2909708]]], [[[79.69124603, 10.29792023], [79.69124603, 10.29763985], [79.69152832, 10.29763985], [79.69152832, 10.29736042], [79.69180298, 10.29736233], [79.69180298, 10.29708385], [79.69235992, 10.29708385], [79.69235992, 10.29680634], [79.69264221, 10.29681015], [79.69264221, 10.29652977], [79.69290924, 10.29652977], [79.69291687, 10.29596043], [79.69291687, 10.29541779], [79.69264221, 10.29541969], [79.69264221, 10.29458141], [79.69235992, 10.29458427], [79.69235992, 10.29402733], [79.6920929, 10.29403019], [79.6920929, 10.29374886], [79.69152832, 10.29374886], [79.69152832, 10.29347134], [79.69041443, 10.29347134], [79.69041443, 10.29374886], [79.69013977, 10.29374886], [79.69013977, 10.29403019], [79.68958282, 10.29403019], [79.68958282, 10.29430962], [79.68930817, 10.2943058], [79.68930817, 10.29458427], [79.68902588, 10.29458141], [79.68902588, 10.29514027], [79.68875122, 10.29514027], [79.68875122, 10.29569435], [79.68902588, 10.29569435], [79.68902588, 10.29625034], [79.68930817, 10.29625034], [79.68930817, 10.29636097], [79.68930817, 10.29681015], [79.68958282, 10.29680634], [79.68958282, 10.29708385], [79.68985748, 10.29708385], [79.68985748, 10.29736233], [79.69013977, 10.29736042], [79.69013977, 10.29763985], [79.6904068, 10.29763985], [79.6904068, 10.29792023], [79.69124603, 10.29792023]]], [[[79.68597412, 10.2984724], [79.68597412, 10.29819584], [79.68624878, 10.29819584], [79.68624878, 10.29763985], [79.68653107, 10.29763985], [79.68653107, 10.29736042], [79.68680573, 10.29736233], [79.68680573, 10.29708385], [79.68653107, 10.29708385], [79.68653107, 10.29690075], [79.68653107, 10.29652786], [79.68624878, 10.29652977], [79.68624878, 10.29597187], [79.68597412, 10.29597187], [79.68597412, 10.29541779], [79.68486023, 10.29541779], [79.68486023, 10.29569435], [79.68430328, 10.29569435], [79.68430328, 10.29597187], [79.68402863, 10.29597187], [79.68402863, 10.29625034], [79.68374634, 10.29625034], [79.68374634, 10.29681015], [79.68347168, 10.29680634], [79.68347168, 10.29776096], [79.68347168, 10.29819584], [79.68514252, 10.29819584], [79.68514252, 10.2984724], [79.68597412, 10.2984724]]], [[[79.62264252, 10.29986191], [79.62264252, 10.29958439], [79.62458038, 10.29958439], [79.62458038, 10.29930592], [79.62652588, 10.29931068], [79.62652588, 10.2990303], [79.62930298, 10.2990303], [79.62930298, 10.29819107], [79.62902832, 10.29819584], [79.62902832, 10.29791641], [79.62874603, 10.29792023], [79.62874603, 10.29763985], [79.62819672, 10.29763985], [79.62819672, 10.29736042], [79.62236023, 10.29736042], [79.62236023, 10.29763985], [79.6220932, 10.29763985], [79.6220932, 10.29792023], [79.62152863, 10.29791641], [79.62152863, 10.29819584], [79.62124634, 10.29819584], [79.62124634, 10.2984724], [79.62069702, 10.29846954], [79.62069702, 10.29874992], [79.6204071, 10.29874992], [79.6204071, 10.2990303], [79.62014008, 10.2990303], [79.62014008, 10.29931068], [79.62041473, 10.29930592], [79.62041473, 10.29958439], [79.62069702, 10.29958439], [79.62069702, 10.29986191], [79.62264252, 10.29986191]]], [[[79.60819244, 10.30263996], [79.60819244, 10.30235958], [79.60847473, 10.30236244], [79.60847473, 10.30208206], [79.60902405, 10.30208206], [79.60902405, 10.30097198], [79.60652924, 10.30098057], [79.60652924, 10.30125046], [79.60597229, 10.30125046], [79.60597229, 10.30140018], [79.60597229, 10.30153275], [79.60569763, 10.30152798], [79.60569763, 10.30236244], [79.60597229, 10.30235958], [79.60597229, 10.30263996], [79.60819244, 10.30263996]]], [[[79.69985962, 10.30958271], [79.69985962, 10.30930519], [79.70041656, 10.30931091], [79.70041656, 10.30903053], [79.70096588, 10.30903053], [79.70096588, 10.30875111], [79.70153046, 10.30875111], [79.70153046, 10.30847263], [79.70180511, 10.30847263], [79.70180511, 10.30819511], [79.70236206, 10.30819511], [79.70236206, 10.30791664], [79.70291901, 10.30792141], [79.70291901, 10.30764103], [79.70347595, 10.30764103], [79.70347595, 10.3073597], [79.70375061, 10.3073597], [79.70375061, 10.30708218], [79.70430756, 10.30708218], [79.70430756, 10.30680656], [79.70484924, 10.30681133], [79.70484924, 10.30653095], [79.70540619, 10.30653095], [79.70540619, 10.30681133], [79.70735931, 10.30680656], [79.70735931, 10.30708218], [79.70903015, 10.30708218], [79.70903015, 10.3073597], [79.70986176, 10.3073597], [79.70986176, 10.30764103], [79.71069336, 10.30764103], [79.71069336, 10.3073597], [79.7104187, 10.3073597], [79.7104187, 10.30708218], [79.71013641, 10.30708218], [79.71013641, 10.30680656], [79.70986176, 10.30681133], [79.70986176, 10.30597019], [79.7095871, 10.3059721], [79.7095871, 10.30541611], [79.70929718, 10.30542088], [79.70929718, 10.30514145], [79.70874786, 10.30514145], [79.70874786, 10.30486012], [79.70847321, 10.30486012], [79.70847321, 10.30458355], [79.70791626, 10.30458355], [79.70791626, 10.30430603], [79.7076416, 10.3043108], [79.7076416, 10.30402088], [79.70708466, 10.30402756], [79.70708466, 10.30375004], [79.70375061, 10.30375004], [79.70375061, 10.30458355], [79.70347595, 10.30457973], [79.70347595, 10.30542088], [79.70319366, 10.30541611], [79.70319366, 10.3059721], [79.70263672, 10.30597019], [79.70263672, 10.30624962], [79.70236206, 10.30624962], [79.70236206, 10.30653095], [79.70181274, 10.30653095], [79.70181274, 10.30681133], [79.70124817, 10.30680656], [79.70124817, 10.30708218], [79.70096588, 10.30708027], [79.70097351, 10.3073597], [79.70041656, 10.3073597], [79.70041656, 10.30764103], [79.69985962, 10.30764103], [79.69985962, 10.30792141], [79.69958496, 10.30791664], [79.69958496, 10.30819511], [79.69902802, 10.30819511], [79.69902802, 10.30958271], [79.69985962, 10.30958271]]], [[[79.62403107, 10.30875111], [79.62403107, 10.30791664], [79.62375641, 10.30792141], [79.62375641, 10.30708027], [79.62347412, 10.30708218], [79.62347412, 10.30652905], [79.62319183, 10.30653095], [79.62319183, 10.30624962], [79.62264252, 10.30624962], [79.62264252, 10.30597019], [79.62236023, 10.3059721], [79.62236023, 10.30569363], [79.62180328, 10.30569363], [79.62180328, 10.30541611], [79.62124634, 10.30541611], [79.62124634, 10.30569363], [79.62097168, 10.30569172], [79.62097168, 10.30624962], [79.62152863, 10.30624962], [79.62152863, 10.30653095], [79.6220932, 10.30653095], [79.6220932, 10.30792141], [79.62264252, 10.30791664], [79.62264252, 10.30819511], [79.62291718, 10.30819511], [79.62291718, 10.30847263], [79.62346649, 10.30846977], [79.62346649, 10.30875111], [79.62403107, 10.30875111]]], [[[79.67736053, 10.30986118], [79.67736053, 10.30958271], [79.67791748, 10.30958271], [79.67791748, 10.30930519], [79.6784668, 10.30931091], [79.6784668, 10.30903053], [79.67903137, 10.30903053], [79.67903137, 10.30875111], [79.68180847, 10.30875111], [79.68180847, 10.30847263], [79.68208313, 10.30847263], [79.68208313, 10.30819511], [79.68264008, 10.30819511], [79.68264008, 10.30791664], [79.6829071, 10.30792141], [79.6829071, 10.30764103], [79.68347168, 10.30764103], [79.68347168, 10.30708027], [79.68319702, 10.30708218], [79.68319702, 10.30652905], [79.6829071, 10.30653095], [79.6829071, 10.30597019], [79.68264008, 10.3059721], [79.68264008, 10.30541611], [79.68096924, 10.30542088], [79.68096924, 10.30514145], [79.67903137, 10.30514145], [79.67903137, 10.30486012], [79.67652893, 10.30486012], [79.67652893, 10.30514145], [79.67263794, 10.30514145], [79.67263794, 10.30542088], [79.67208099, 10.30541611], [79.67208099, 10.30569363], [79.67152405, 10.30569363], [79.67152405, 10.3059721], [79.67069244, 10.30597019], [79.67069244, 10.30624962], [79.67014313, 10.30624962], [79.67014313, 10.30653095], [79.66958618, 10.30653095], [79.66958618, 10.30681133], [79.66986084, 10.30680656], [79.66986084, 10.3073597], [79.67236328, 10.3073597], [79.67236328, 10.30764103], [79.67263794, 10.30764103], [79.67263794, 10.30792141], [79.67319489, 10.30791664], [79.67319489, 10.30819511], [79.67375183, 10.30819511], [79.67375183, 10.30847263], [79.67402649, 10.30847263], [79.67402649, 10.30875111], [79.67457581, 10.30875111], [79.67457581, 10.30903053], [79.67514038, 10.30903053], [79.67514038, 10.30931091], [79.67541504, 10.30930519], [79.67541504, 10.30958271], [79.67597198, 10.30958271], [79.67597198, 10.30986118], [79.67736053, 10.30986118]]], [[[79.68984985, 10.31042099], [79.68984985, 10.31015015], [79.6904068, 10.31015015], [79.6904068, 10.30986118], [79.69069672, 10.30986118], [79.69069672, 10.30930519], [79.69097137, 10.30931091], [79.69097137, 10.30903053], [79.69180298, 10.30903053], [79.69180298, 10.30846977], [79.69208527, 10.30847263], [79.69208527, 10.30819511], [79.69235992, 10.30819511], [79.69235992, 10.30791664], [79.69264221, 10.30791664], [79.69264221, 10.30819511], [79.69319153, 10.30819511], [79.69319153, 10.30847263], [79.69374847, 10.30847263], [79.69374847, 10.30819511], [79.69403076, 10.30819511], [79.69403076, 10.30763817], [79.69374847, 10.30764103], [79.69374847, 10.30708027], [79.69347382, 10.30708218], [79.69347382, 10.30680656], [79.69319153, 10.30681133], [79.69319153, 10.30644035], [79.69319153, 10.30569363], [79.69291687, 10.30569363], [79.69291687, 10.30513763], [79.69264221, 10.30514145], [79.69264221, 10.30457973], [79.69235992, 10.30458355], [79.69235992, 10.30430603], [79.69152832, 10.30430603], [79.69152832, 10.30458355], [79.69124603, 10.30457973], [79.69125366, 10.30486012], [79.69069672, 10.30486012], [79.69069672, 10.30514145], [79.6904068, 10.30514145], [79.6904068, 10.30542088], [79.69013977, 10.30541611], [79.69013977, 10.30569363], [79.68984985, 10.30569172], [79.68984985, 10.30624962], [79.68958282, 10.30624962], [79.68958282, 10.30681133], [79.68930817, 10.30680656], [79.68930817, 10.30828953], [79.68930817, 10.30875111], [79.68902588, 10.30875111], [79.68902588, 10.30931091], [79.68875122, 10.30931091], [79.68875122, 10.31042099], [79.68984985, 10.31042099]]], [[[79.60875702, 10.31125069], [79.60875702, 10.31097126], [79.60930634, 10.31097317], [79.60930634, 10.31069469], [79.60958099, 10.31069469], [79.60958099, 10.30986118], [79.60986328, 10.30986118], [79.60986328, 10.30930519], [79.60930634, 10.30931091], [79.60930634, 10.30903053], [79.60875702, 10.30903053], [79.60875702, 10.30875111], [79.6084671, 10.30875111], [79.6084671, 10.30846977], [79.60819244, 10.30847263], [79.60819244, 10.30819511], [79.60791779, 10.30819511], [79.60791779, 10.30791664], [79.60764313, 10.30792141], [79.60764313, 10.30764103], [79.60736084, 10.30764103], [79.60736084, 10.3073597], [79.60708618, 10.3073597], [79.60708618, 10.30708218], [79.60680389, 10.30708218], [79.60680389, 10.30680656], [79.60652924, 10.30681133], [79.60652924, 10.30653095], [79.60569, 10.30653095], [79.60569, 10.30624962], [79.60514069, 10.30624962], [79.60514069, 10.30653095], [79.6048584, 10.30652905], [79.6048584, 10.30847263], [79.60514069, 10.30846977], [79.60514069, 10.30931091], [79.60542297, 10.30931091], [79.60542297, 10.31015015], [79.60569, 10.31015015], [79.60569, 10.31042099], [79.60624695, 10.31041718], [79.60624695, 10.31069469], [79.60736084, 10.31069469], [79.60736084, 10.31097317], [79.60764313, 10.31097126], [79.60764313, 10.31125069], [79.60875702, 10.31125069]]], [[[79.61875153, 10.30875111], [79.61875153, 10.30847263], [79.62041473, 10.30847263], [79.62041473, 10.30819511], [79.62097168, 10.30819511], [79.62097168, 10.30791664], [79.62124634, 10.30792141], [79.62124634, 10.3073597], [79.62097168, 10.3073597], [79.62097168, 10.30680656], [79.62069702, 10.30681133], [79.62069702, 10.30653095], [79.62014008, 10.30653095], [79.62014008, 10.30624962], [79.61930847, 10.30624962], [79.61930847, 10.30764103], [79.61875153, 10.30764103], [79.61875153, 10.3073597], [79.61846924, 10.3073597], [79.61846924, 10.30708218], [79.61819458, 10.30708218], [79.61819458, 10.30680656], [79.61791992, 10.30681133], [79.61791992, 10.30653095], [79.61624908, 10.30653095], [79.61624908, 10.30792141], [79.61597443, 10.30791664], [79.61597443, 10.30819511], [79.61680603, 10.30819511], [79.61680603, 10.30847263], [79.61736298, 10.30847263], [79.61736298, 10.30875111], [79.61875153, 10.30875111]]], [[[79.63153076, 10.30875111], [79.63153076, 10.30819511], [79.63180542, 10.30819511], [79.63180542, 10.3073597], [79.63153076, 10.3073597], [79.63153076, 10.30680656], [79.63069153, 10.30681133], [79.63069153, 10.30653095], [79.62902832, 10.30653095], [79.62902832, 10.30681133], [79.62791443, 10.30680656], [79.62791443, 10.30819511], [79.62847137, 10.30819511], [79.62847137, 10.30847263], [79.62930298, 10.30847263], [79.62930298, 10.30875111], [79.63153076, 10.30875111]]], [[[79.69597626, 10.32125187], [79.69597626, 10.32097054], [79.69652557, 10.32097054], [79.69652557, 10.32069588], [79.69680786, 10.32069302], [79.69680786, 10.32041836], [79.69735718, 10.32042027], [79.69735718, 10.32014179], [79.69790649, 10.32014179], [79.69790649, 10.31986141], [79.69819641, 10.31986141], [79.69819641, 10.31958294], [79.69875336, 10.31958294], [79.69875336, 10.31930542], [79.69930267, 10.31931019], [79.69930267, 10.31902027], [79.69985962, 10.31902695], [79.69985962, 10.31874943], [79.70014191, 10.31874943], [79.70014191, 10.31847095], [79.70069122, 10.31847095], [79.70069122, 10.31819534], [79.70097351, 10.31819534], [79.70097351, 10.31791687], [79.70124817, 10.31791973], [79.70124817, 10.31736088], [79.70153046, 10.31736088], [79.70153046, 10.31708336], [79.70180511, 10.31708336], [79.70180511, 10.31680489], [79.70207977, 10.31680965], [79.70207977, 10.31624889], [79.70236206, 10.31624889], [79.70236206, 10.31597328], [79.70263672, 10.31597328], [79.70263672, 10.31569481], [79.70847321, 10.31569481], [79.70847321, 10.31597328], [79.71013641, 10.31597328], [79.71013641, 10.31624889], [79.7123642, 10.31624889], [79.71235657, 10.31596184], [79.71291351, 10.31597328], [79.71291351, 10.31569481], [79.7131958, 10.31569481], [79.7131958, 10.31541729], [79.71375275, 10.3154192], [79.71375275, 10.31514072], [79.71652985, 10.31514072], [79.71652985, 10.31431198], [79.71624756, 10.31431198], [79.71624756, 10.31264114], [79.7159729, 10.31264114], [79.7159729, 10.31153107], [79.71569824, 10.31153107], [79.71569824, 10.31125069], [79.71541595, 10.31125069], [79.71541595, 10.31097126], [79.71485901, 10.31097317], [79.71485901, 10.31069469], [79.71404266, 10.31069469], [79.71375275, 10.31069469], [79.71375275, 10.31097317], [79.7131958, 10.31097317], [79.7131958, 10.31152916], [79.71291351, 10.31152916], [79.71291351, 10.31174088], [79.71291351, 10.31236076], [79.71263885, 10.31236076], [79.71263885, 10.31347084], [79.71235657, 10.31347084], [79.71235657, 10.31403065], [79.71180725, 10.31403065], [79.71180725, 10.31431198], [79.71125031, 10.31430531], [79.71125031, 10.31458282], [79.71097565, 10.31458282], [79.71097565, 10.31430531], [79.71069336, 10.31431198], [79.71069336, 10.31379032], [79.71069336, 10.31347084], [79.7104187, 10.31347084], [79.7104187, 10.31291676], [79.71013641, 10.31292152], [79.71013641, 10.31264114], [79.7095871, 10.31263924], [79.7095871, 10.31319523], [79.70929718, 10.31319046], [79.70930481, 10.31347084], [79.70903015, 10.31347084], [79.70903015, 10.31402016], [79.7076416, 10.31403065], [79.7076416, 10.31375122], [79.70735931, 10.31375122], [79.70735931, 10.31357098], [79.70735931, 10.31347084], [79.70697021, 10.31347084], [79.70680237, 10.31347084], [79.70680237, 10.31319523], [79.70652771, 10.31319523], [79.70652771, 10.31291676], [79.70318604, 10.31292152], [79.70318604, 10.31264114], [79.70207977, 10.31264114], [79.70207977, 10.31235886], [79.70069122, 10.31236076], [79.70069122, 10.31208324], [79.69736481, 10.31208324], [79.69736481, 10.31236076], [79.69680786, 10.31235886], [79.69680786, 10.31264114], [79.6965332, 10.31264114], [79.6965332, 10.31292152], [79.69596863, 10.31291676], [79.69596863, 10.31319523], [79.69568634, 10.31319046], [79.69569397, 10.31347084], [79.69513702, 10.31347084], [79.69513702, 10.31375122], [79.69290924, 10.31375122], [79.69290924, 10.31403065], [79.69264221, 10.31403065], [79.69264221, 10.31431198], [79.69208527, 10.31430531], [79.69208527, 10.31458282], [79.69152832, 10.31458282], [79.69152832, 10.3148613], [79.69124603, 10.3148613], [79.69124603, 10.31514072], [79.69069672, 10.31514072], [79.69069672, 10.3154192], [79.69041443, 10.31541729], [79.69041443, 10.31574059], [79.69041443, 10.31597328], [79.69013977, 10.31596184], [79.69013977, 10.31652927], [79.68984985, 10.31652927], [79.68984985, 10.31680965], [79.68958282, 10.31680489], [79.68958282, 10.31736088], [79.68930817, 10.31736088], [79.68930817, 10.31791973], [79.68902588, 10.31791687], [79.68902588, 10.31847095], [79.68875122, 10.31847095], [79.68875122, 10.31874943], [79.69069672, 10.31874943], [79.69069672, 10.31902695], [79.69264221, 10.31902027], [79.69264221, 10.31931019], [79.69291687, 10.31930542], [79.69291687, 10.31958294], [79.69347382, 10.31958294], [79.69347382, 10.31986141], [79.69374847, 10.31986141], [79.69374847, 10.32014179], [79.69431305, 10.32014179], [79.69431305, 10.32042027], [79.69458008, 10.32041836], [79.69458008, 10.32069302], [79.69513702, 10.32069588], [79.69513702, 10.32097054], [79.69541931, 10.32097054], [79.69541931, 10.32125187], [79.69597626, 10.32125187]]], [[[79.62568665, 10.34375095], [79.62568665, 10.34347057], [79.62680817, 10.34347343], [79.62680817, 10.34319305], [79.62708282, 10.34319305], [79.62708282, 10.34291744], [79.62763977, 10.34291935], [79.62763977, 10.34264088], [79.6279068, 10.34264088], [79.6279068, 10.34236145], [79.62847137, 10.34236145], [79.62847137, 10.34208298], [79.62875366, 10.34208298], [79.62875366, 10.34125137], [79.62847137, 10.34125137], [79.62847137, 10.34013939], [79.62819672, 10.34013939], [79.62819672, 10.33875084], [79.62847137, 10.33875084], [79.62847137, 10.33819008], [79.62875366, 10.33819485], [79.62875366, 10.33791733], [79.62902832, 10.33791924], [79.62902832, 10.33736134], [79.62875366, 10.33736134], [79.62875366, 10.33708286], [79.62819672, 10.33708858], [79.62819672, 10.33681107], [79.62708282, 10.33680534], [79.62708282, 10.33736134], [79.62680054, 10.33736134], [79.62680054, 10.33791924], [79.62625122, 10.33791733], [79.62625122, 10.33819485], [79.62569427, 10.33819485], [79.62569427, 10.33847332], [79.62541962, 10.33847141], [79.62541962, 10.33875084], [79.62486267, 10.33875084], [79.62486267, 10.34069538], [79.62513733, 10.34069538], [79.62513733, 10.34125137], [79.62486267, 10.34125137], [79.62486267, 10.34236145], [79.62513733, 10.34236145], [79.62513733, 10.34319305], [79.62541962, 10.34319305], [79.62541962, 10.34347343], [79.62513733, 10.34347057], [79.62513733, 10.34375095], [79.62568665, 10.34375095]]], [[[79.63208008, 10.33319378], [79.63208008, 10.33291626], [79.63236237, 10.33292103], [79.63236237, 10.33264065], [79.63263702, 10.33264065], [79.63263702, 10.33236027], [79.63375092, 10.33236027], [79.63375092, 10.33180428], [79.63346863, 10.33181095], [79.63346863, 10.33096123], [79.63319397, 10.33097172], [79.63319397, 10.33041573], [79.63291931, 10.33042145], [79.63291931, 10.32985973], [79.63263702, 10.32985973], [79.63263702, 10.32958412], [79.63236237, 10.32958412], [79.63236237, 10.32902813], [79.63208008, 10.32903004], [79.63208008, 10.32874966], [79.63181305, 10.32874966], [79.63181305, 10.32847023], [79.63153076, 10.32847214], [79.63153076, 10.32791805], [79.63124847, 10.32792091], [79.63124847, 10.32736015], [79.63069153, 10.32736206], [79.63069153, 10.32708359], [79.62930298, 10.32708359], [79.62930298, 10.32680607], [79.62902832, 10.32681274], [79.62902832, 10.32653046], [79.62874603, 10.32653046], [79.62874603, 10.32625008], [79.62847137, 10.32625008], [79.62847137, 10.3259697], [79.62763977, 10.3259697], [79.62763977, 10.32625008], [79.62735748, 10.32625008], [79.62735748, 10.32708359], [79.62763977, 10.32708359], [79.62763977, 10.32736206], [79.6279068, 10.32736015], [79.6279068, 10.32763958], [79.62819672, 10.32763958], [79.62819672, 10.32792091], [79.62735748, 10.32791805], [79.62735748, 10.32847214], [79.62763977, 10.32847023], [79.62763977, 10.32903004], [79.6279068, 10.32903004], [79.6279068, 10.33042145], [79.62819672, 10.33041573], [79.62819672, 10.3306942], [79.62902832, 10.3306942], [79.62902832, 10.33041573], [79.62958527, 10.33041573], [79.62958527, 10.3306942], [79.62985992, 10.3306942], [79.62985992, 10.33097172], [79.63041687, 10.33097172], [79.63041687, 10.33125019], [79.63069153, 10.33125019], [79.63069153, 10.33153057], [79.63097382, 10.33152771], [79.63097382, 10.3320837], [79.63124847, 10.33208179], [79.63124847, 10.33264065], [79.63153076, 10.33263779], [79.63153076, 10.33319378], [79.63208008, 10.33319378]]], [[[79.74597168, 10.27735996], [79.7454071, 10.27735996], [79.7454071, 10.27764034], [79.74514008, 10.27764034], [79.74514008, 10.27792072], [79.74541473, 10.27791595], [79.74541473, 10.27819443], [79.74569702, 10.27819443], [79.74569702, 10.27847195], [79.74597168, 10.27847004], [79.74597168, 10.2790308], [79.74624634, 10.2790308], [79.74624634, 10.27931118], [79.74652863, 10.27930737], [79.74652863, 10.27958202], [79.74764252, 10.27958202], [79.74764252, 10.27930737], [79.74791718, 10.27931118], [79.74791718, 10.2790308], [79.74846649, 10.2790308], [79.74846649, 10.27875042], [79.74903107, 10.27875042], [79.74903107, 10.27847195], [79.74958038, 10.27847195], [79.74958038, 10.27819443], [79.74986267, 10.27819443], [79.74986267, 10.27791595], [79.75041962, 10.27792072], [79.75041962, 10.27625179], [79.75096893, 10.27625179], [79.75096893, 10.27597046], [79.75180817, 10.27597237], [79.75180817, 10.27569389], [79.75235748, 10.27569389], [79.75235748, 10.27541637], [79.75569153, 10.27541637], [79.75569153, 10.27597237], [79.75541687, 10.27597237], [79.75541687, 10.27708435], [79.75514221, 10.27707958], [79.75514221, 10.27764034], [79.75235748, 10.27764034], [79.75235748, 10.27792072], [79.75208282, 10.27791595], [79.75208282, 10.27819443], [79.75152588, 10.27819443], [79.75152588, 10.27847195], [79.75125122, 10.27847195], [79.75125122, 10.27875042], [79.75096893, 10.27875042], [79.75096893, 10.2790308], [79.75068665, 10.2790308], [79.75068665, 10.27931118], [79.75013733, 10.27930737], [79.75013733, 10.27958202], [79.74986267, 10.27958202], [79.74986267, 10.27985954], [79.74931335, 10.27985096], [79.74931335, 10.28014088], [79.74903107, 10.28014088], [79.74903107, 10.28042126], [79.74847412, 10.28041553], [79.74847412, 10.28069496], [79.74819183, 10.28069496], [79.74819183, 10.28097343], [79.74764252, 10.28096962], [79.74764252, 10.28153133], [79.74736023, 10.28152561], [79.74736023, 10.28236103], [79.74708557, 10.28236103], [79.74708557, 10.28291702], [79.74736023, 10.28291702], [79.74736023, 10.28319454], [79.74791718, 10.28319454], [79.74791718, 10.28347301], [79.74819183, 10.28347111], [79.74819183, 10.28375053], [79.74874878, 10.28375053], [79.74874878, 10.28403091], [79.74958038, 10.28403091], [79.74958038, 10.28347111], [79.74986267, 10.28347301], [79.74986267, 10.28319454], [79.7501297, 10.28318977], [79.7501297, 10.28375053], [79.75041962, 10.28375053], [79.75041962, 10.28430939], [79.75069427, 10.28430462], [79.75069427, 10.28486061], [79.75096893, 10.28486061], [79.75096893, 10.28542137], [79.75125122, 10.28543091], [79.75125122, 10.28598022], [79.75096893, 10.28598022], [79.75096893, 10.28653145], [79.75068665, 10.28653145], [79.75068665, 10.28681183], [79.75041962, 10.28680515], [79.75041962, 10.28708267], [79.7501297, 10.2870779], [79.7501297, 10.28764057], [79.74986267, 10.28764057], [79.74986267, 10.28792191], [79.74958038, 10.28791714], [79.74958038, 10.28819466], [79.74931335, 10.28819084], [79.74931335, 10.28875065], [79.74903107, 10.28875065], [79.74903107, 10.28904057], [79.74958038, 10.28904057], [79.74958038, 10.28931046], [79.75013733, 10.28930473], [79.75013733, 10.28958321], [79.75041962, 10.28958321], [79.75041962, 10.28986073], [79.75096893, 10.28986073], [79.75096893, 10.2901392], [79.75208282, 10.2901392], [79.75208282, 10.28986073], [79.75235748, 10.28986073], [79.75235748, 10.28958321], [79.75263977, 10.28958321], [79.75263977, 10.28902721], [79.75289917, 10.28904057], [79.75289917, 10.28875065], [79.75318909, 10.28875065], [79.75318909, 10.28847122], [79.75374603, 10.28847122], [79.75374603, 10.28904057], [79.75402832, 10.28902721], [79.75402832, 10.28958321], [79.75430298, 10.2895813], [79.75430298, 10.2901392], [79.75875092, 10.2901392], [79.75875092, 10.2895813], [79.75902557, 10.28958321], [79.75902557, 10.28902721], [79.75932312, 10.28904057], [79.75932312, 10.28875065], [79.75958252, 10.28875065], [79.75958252, 10.28819084], [79.75986481, 10.28819466], [79.75986481, 10.28791714], [79.76013947, 10.28792191], [79.76013947, 10.28736115], [79.76041412, 10.28736115], [79.76041412, 10.28680515], [79.76069641, 10.28681183], [79.76069641, 10.28653145], [79.76040649, 10.28653145], [79.76040649, 10.28625107], [79.76013947, 10.28625107], [79.76013947, 10.28598022], [79.75985718, 10.28598022], [79.75985718, 10.28569031], [79.75958252, 10.28569508], [79.75958252, 10.2854166], [79.75932312, 10.28542137], [79.75932312, 10.28514099], [79.7590332, 10.28514099], [79.7590332, 10.28486061], [79.75875092, 10.28486061], [79.75875092, 10.28458309], [79.75819397, 10.28458309], [79.75819397, 10.28430462], [79.75791931, 10.28430939], [79.75791931, 10.28403091], [79.75958252, 10.28403091], [79.75958252, 10.28375053], [79.75985718, 10.28375053], [79.75985718, 10.28318977], [79.76013947, 10.28319454], [79.76013947, 10.28291702], [79.76041412, 10.28291702], [79.76041412, 10.28236103], [79.76069641, 10.28236103], [79.76069641, 10.28291702], [79.76097107, 10.28291702], [79.76097107, 10.28347301], [79.76125336, 10.28347111], [79.76125336, 10.28375053], [79.76152802, 10.28375053], [79.76152802, 10.28430939], [79.76180267, 10.28430462], [79.76180267, 10.28458309], [79.7620697, 10.28458023], [79.7620697, 10.28514099], [79.76235962, 10.28513908], [79.76235962, 10.28569508], [79.76264191, 10.28569031], [79.76264191, 10.28598022], [79.76291656, 10.28598022], [79.76291656, 10.28653145], [79.76319122, 10.28652668], [79.76319122, 10.28708267], [79.76680756, 10.28708267], [79.76680756, 10.28736115], [79.76763916, 10.28736115], [79.76763916, 10.28764057], [79.76847076, 10.28764057], [79.76847076, 10.28792191], [79.76985931, 10.28792191], [79.76985931, 10.28764057], [79.77041626, 10.28764057], [79.77041626, 10.28736115], [79.77069092, 10.28736115], [79.77069092, 10.28708267], [79.77124786, 10.28708267], [79.77124786, 10.28569508], [79.77153015, 10.28569508], [79.77153015, 10.28430462], [79.77347565, 10.28430462], [79.77347565, 10.28486061], [79.77375031, 10.28486061], [79.77375031, 10.28569508], [79.77625275, 10.28569508], [79.77625275, 10.2854166], [79.7765274, 10.28542137], [79.7765274, 10.28514099], [79.77680206, 10.28514099], [79.77680206, 10.28486061], [79.77708435, 10.28486061], [79.77708435, 10.28458309], [79.77735901, 10.28458309], [79.77735901, 10.28430462], [79.7776413, 10.28430939], [79.7776413, 10.28403091], [79.77791595, 10.28403091], [79.77791595, 10.28375053], [79.77819061, 10.28375053], [79.77819824, 10.28347111], [79.7784729, 10.28347301], [79.7784729, 10.28291702], [79.77874756, 10.28291702], [79.77874756, 10.28180695], [79.77902985, 10.28181076], [79.77902985, 10.28153133], [79.78098297, 10.28153133], [79.78098297, 10.28181076], [79.78347015, 10.28181076], [79.78347015, 10.28069019], [79.7848587, 10.28069496], [79.7848587, 10.28097343], [79.78514099, 10.28096962], [79.78514099, 10.28153133], [79.78542328, 10.28153133], [79.78542328, 10.28181076], [79.78569794, 10.28180695], [79.78569794, 10.28208256], [79.7859726, 10.2820797], [79.7859726, 10.28264141], [79.78624725, 10.28263855], [79.78624725, 10.28291702], [79.78652954, 10.28291702], [79.78652954, 10.28347301], [79.78679657, 10.28347111], [79.78679657, 10.28403091], [79.78652954, 10.28402901], [79.78652954, 10.28458309], [79.78626251, 10.28458023], [79.78626251, 10.28514099], [79.7859726, 10.28513908], [79.7859726, 10.28569508], [79.78569794, 10.28569031], [79.78569794, 10.28625107], [79.78542328, 10.28625107], [79.78542328, 10.28681183], [79.78514099, 10.28680515], [79.78514099, 10.28708267], [79.7848587, 10.28708267], [79.7848587, 10.28736115], [79.78457642, 10.28736115], [79.78457642, 10.28764057], [79.78430939, 10.28764057], [79.78430176, 10.28792191], [79.7840271, 10.28791714], [79.7840271, 10.28819466], [79.78347015, 10.28819466], [79.78347015, 10.28847313], [79.78320313, 10.28847122], [79.78320313, 10.28875065], [79.78291321, 10.28875065], [79.78291321, 10.28904057], [79.78263855, 10.28904057], [79.78263855, 10.28931046], [79.78236389, 10.28930473], [79.78236389, 10.28958321], [79.7820816, 10.28958321], [79.7820816, 10.28986073], [79.78180695, 10.28986073], [79.78180695, 10.2901392], [79.78151703, 10.2901392], [79.78151703, 10.29041958], [79.78125, 10.29041672], [79.78125, 10.29069328], [79.78097534, 10.29069328], [79.78097534, 10.2909708], [79.7804184, 10.29097271], [79.7804184, 10.29124928], [79.78012848, 10.29124928], [79.78012848, 10.29152966], [79.77986145, 10.29152966], [79.77986145, 10.29181004], [79.77958679, 10.29180527], [79.77958679, 10.29208279], [79.77902985, 10.29208279], [79.77902985, 10.29236126], [79.7784729, 10.29236126], [79.7784729, 10.29264164], [79.77791595, 10.29264164], [79.77791595, 10.29292202], [79.77735901, 10.29291534], [79.77735901, 10.29319572], [79.77708435, 10.29319572], [79.77708435, 10.29347134], [79.7765274, 10.29347134], [79.7765274, 10.29374886], [79.77597046, 10.29374886], [79.77597046, 10.29403019], [79.77540588, 10.29403019], [79.77540588, 10.29430962], [79.7748642, 10.2943058], [79.7748642, 10.29458427], [79.77430725, 10.29458427], [79.77430725, 10.29486179], [79.7740097, 10.29485035], [79.7740097, 10.29514027], [79.77348328, 10.29514027], [79.77348328, 10.29541969], [79.77319336, 10.29541779], [79.77319336, 10.29569435], [79.77263641, 10.29569435], [79.77263641, 10.29597187], [79.7720871, 10.29597187], [79.7720871, 10.29625034], [79.77179718, 10.29625034], [79.77179718, 10.29652977], [79.77126312, 10.29652977], [79.77126312, 10.29681015], [79.77069092, 10.29680634], [79.77069092, 10.29708385], [79.77041626, 10.29708385], [79.77041626, 10.29736233], [79.76985931, 10.29736042], [79.76985931, 10.29763985], [79.76930237, 10.29763985], [79.76930237, 10.29792023], [79.76875305, 10.29791641], [79.76875305, 10.29819584], [79.76847076, 10.29819584], [79.76847076, 10.2984724], [79.76790619, 10.29846954], [79.76790619, 10.29874992], [79.76735687, 10.29874992], [79.76735687, 10.2990303], [79.76708221, 10.2990303], [79.76708221, 10.29931068], [79.76652527, 10.29930592], [79.76652527, 10.29958439], [79.76597595, 10.29958439], [79.76597595, 10.29986191], [79.76568604, 10.29986191], [79.76568604, 10.30014038], [79.76512909, 10.30014038], [79.76512909, 10.30042267], [79.76457977, 10.30041599], [79.76457977, 10.30069447], [79.76431274, 10.3006916], [79.76431274, 10.30098057], [79.76374817, 10.30097198], [79.76374817, 10.30125046], [79.76346588, 10.30125046], [79.76346588, 10.30153275], [79.76319122, 10.30153275], [79.76319122, 10.30181122], [79.76291656, 10.30180645], [79.76291656, 10.30208206], [79.76264191, 10.30208015], [79.76264191, 10.30263996], [79.76235962, 10.30263996], [79.76235962, 10.3029213], [79.76208496, 10.30291557], [79.76208496, 10.30319405], [79.76180267, 10.30319405], [79.76180267, 10.30347157], [79.76152802, 10.30346966], [79.76152802, 10.30375004], [79.76125336, 10.30375004], [79.76125336, 10.30402756], [79.76097107, 10.30402088], [79.76097107, 10.3043108], [79.76069641, 10.30430603], [79.76069641, 10.30458355], [79.76040649, 10.30457973], [79.76040649, 10.30514145], [79.76013947, 10.30514145], [79.76013947, 10.30542088], [79.75986481, 10.30541611], [79.75986481, 10.30569363], [79.75958252, 10.30569363], [79.75958252, 10.3059721], [79.75932312, 10.30597019], [79.75932312, 10.30624962], [79.7590332, 10.30624962], [79.7590332, 10.30653095], [79.75875092, 10.30652905], [79.75875092, 10.30708218], [79.75846863, 10.30708027], [79.75846863, 10.30764103], [79.75818634, 10.30764103], [79.75818634, 10.30792141], [79.75791931, 10.30791664], [79.75791931, 10.30847263], [79.75763702, 10.30846977], [79.75763702, 10.30903053], [79.75736237, 10.30903053], [79.75736237, 10.30931091], [79.75763702, 10.30930519], [79.75763702, 10.30958271], [79.75819397, 10.30958271], [79.75819397, 10.30986118], [79.75846863, 10.30986118], [79.75846863, 10.31015015], [79.75819397, 10.3101387], [79.75819397, 10.31069469], [79.75791931, 10.31069469], [79.75791931, 10.31097317], [79.75763702, 10.31097126], [79.75763702, 10.31125069], [79.75736237, 10.31125069], [79.75736237, 10.3118124], [79.75708008, 10.31180477], [79.75708008, 10.31208324], [79.75986481, 10.31208324], [79.75986481, 10.31180477], [79.76013947, 10.3118124], [79.76013947, 10.31125069], [79.76040649, 10.31125069], [79.76040649, 10.31097126], [79.76125336, 10.31097317], [79.76125336, 10.31069469], [79.76208496, 10.31069469], [79.76208496, 10.31041718], [79.76264191, 10.31042099], [79.76264191, 10.31015015], [79.76291656, 10.31015015], [79.76291656, 10.30957985], [79.76319122, 10.30958271], [79.76319122, 10.30930519], [79.76346588, 10.30931091], [79.76346588, 10.30875111], [79.76374817, 10.30875111], [79.76374817, 10.30847263], [79.76403046, 10.30847263], [79.76403046, 10.30819511], [79.76430511, 10.30819511], [79.76430511, 10.30763817], [79.76457977, 10.30764103], [79.76457977, 10.3073597], [79.76486206, 10.3073597], [79.76486206, 10.30680656], [79.76512909, 10.30681133], [79.76512909, 10.30653095], [79.76568604, 10.30653095], [79.76568604, 10.30624962], [79.76597595, 10.30624962], [79.76597595, 10.30597019], [79.76652527, 10.3059721], [79.76652527, 10.30569363], [79.76708221, 10.30569363], [79.76708221, 10.30541611], [79.76735687, 10.30542088], [79.76735687, 10.30514145], [79.76763916, 10.30514145], [79.76763916, 10.30486012], [79.76791382, 10.30486012], [79.76790619, 10.30457973], [79.76819611, 10.30458355], [79.76819611, 10.30430603], [79.76847076, 10.3043108], [79.76847076, 10.30402088], [79.76875305, 10.30402756], [79.76875305, 10.30375004], [79.76930237, 10.30375004], [79.76930237, 10.30346966], [79.76985931, 10.30347157], [79.76985931, 10.30319405], [79.77069092, 10.30319405], [79.77069092, 10.30291557], [79.77126312, 10.3029213], [79.77126312, 10.30263996], [79.77179718, 10.30263996], [79.77179718, 10.30235958], [79.77236176, 10.30236244], [79.77236176, 10.30208206], [79.77319336, 10.30208206], [79.77319336, 10.30180645], [79.7756958, 10.30181122], [79.7756958, 10.30153275], [79.77735901, 10.30153275], [79.77735901, 10.30181122], [79.7784729, 10.30180645], [79.7784729, 10.30236244], [79.77819824, 10.30235958], [79.77819824, 10.30263996], [79.77513885, 10.30263996], [79.77513885, 10.3029213], [79.77458191, 10.30291557], [79.77458191, 10.30319405], [79.77430725, 10.30319405], [79.77430725, 10.30347157], [79.7740097, 10.30346966], [79.7740097, 10.30375004], [79.77347565, 10.30375004], [79.77347565, 10.30402756], [79.7729187, 10.30402088], [79.7729187, 10.3043108], [79.77236176, 10.30430603], [79.77236176, 10.30458355], [79.77180481, 10.30458355], [79.77180481, 10.30486012], [79.77126312, 10.30486012], [79.77126312, 10.30514145], [79.77041626, 10.30514145], [79.77041626, 10.30542088], [79.76985931, 10.30541611], [79.76985931, 10.30569363], [79.76930237, 10.30569363], [79.76930237, 10.3059721], [79.76875305, 10.30597019], [79.76875305, 10.30624962], [79.76818848, 10.30624962], [79.76818848, 10.30653095], [79.76763916, 10.30653095], [79.76763916, 10.30681133], [79.76625061, 10.30680656], [79.76625061, 10.30708218], [79.76597595, 10.30708027], [79.76597595, 10.30764103], [79.76568604, 10.30764103], [79.76568604, 10.30792141], [79.76541901, 10.30791664], [79.76541901, 10.30819511], [79.76513672, 10.30819511], [79.76513672, 10.30847263], [79.76486206, 10.30847263], [79.76486206, 10.30875111], [79.76457977, 10.30875111], [79.76457977, 10.30931091], [79.76430511, 10.30930519], [79.76430511, 10.30958271], [79.76403046, 10.30958271], [79.76403046, 10.30986118], [79.76374817, 10.30986118], [79.76374817, 10.31015015], [79.76346588, 10.31015015], [79.76346588, 10.31042099], [79.76319122, 10.31041718], [79.76319122, 10.31097317], [79.76291656, 10.31097126], [79.76291656, 10.31125069], [79.76264191, 10.31125069], [79.76264191, 10.31153107], [79.76235962, 10.31153107], [79.76235962, 10.3118124], [79.76208496, 10.31180477], [79.76208496, 10.31208324], [79.76180267, 10.31208134], [79.76180267, 10.31264114], [79.76152802, 10.31264114], [79.76152802, 10.31292152], [79.76125336, 10.31291676], [79.76125336, 10.31319523], [79.75930786, 10.31319523], [79.75930786, 10.31347084], [79.75763702, 10.31347084], [79.75763702, 10.31375122], [79.74986267, 10.31375122], [79.74986267, 10.31347084], [79.74375153, 10.31347084], [79.74375153, 10.31319523], [79.74319458, 10.31319523], [79.74319458, 10.31291676], [79.74291992, 10.31292152], [79.74291992, 10.31264114], [79.74236298, 10.31264114], [79.74236298, 10.31235886], [79.74180603, 10.31236076], [79.74180603, 10.31208324], [79.74097443, 10.31208324], [79.74097443, 10.31180477], [79.74041748, 10.3118124], [79.74041748, 10.31153107], [79.73958588, 10.31153107], [79.73958588, 10.31125069], [79.73902893, 10.31125069], [79.73902893, 10.31097126], [79.73819733, 10.31097317], [79.73819733, 10.31069469], [79.73764038, 10.31069469], [79.73764038, 10.31041718], [79.73430634, 10.31041718], [79.73430634, 10.31069469], [79.73236084, 10.31069469], [79.73236084, 10.31097317], [79.73014069, 10.31097126], [79.73014069, 10.31125069], [79.7298584, 10.31125069], [79.7298584, 10.31153107], [79.72957611, 10.31153107], [79.72957611, 10.3118124], [79.72902679, 10.31180477], [79.72902679, 10.31208324], [79.72875214, 10.31208324], [79.72875214, 10.31236076], [79.72846985, 10.31235886], [79.72846985, 10.31264114], [79.72820282, 10.31264114], [79.72820282, 10.31292152], [79.7279129, 10.31291676], [79.7279129, 10.31319523], [79.72763824, 10.31319523], [79.72763824, 10.31347084], [79.7270813, 10.31347084], [79.7270813, 10.31375122], [79.72680664, 10.31375122], [79.72680664, 10.31403065], [79.72651672, 10.31403065], [79.72651672, 10.31431198], [79.72624969, 10.31430531], [79.72624969, 10.31458282], [79.72597504, 10.31458282], [79.72597504, 10.3148613], [79.72541809, 10.3148613], [79.72541809, 10.31514072], [79.7251358, 10.31514072], [79.7251358, 10.3154192], [79.72486115, 10.31541729], [79.72486115, 10.31569481], [79.72458649, 10.31569481], [79.72458649, 10.31597328], [79.72429657, 10.31596184], [79.7243042, 10.31624889], [79.72374725, 10.31624889], [79.72374725, 10.31652927], [79.7234726, 10.31652927], [79.7234726, 10.31680965], [79.72319794, 10.31680489], [79.72319794, 10.31708336], [79.72291565, 10.31708336], [79.72291565, 10.31736088], [79.72264099, 10.31736088], [79.72264099, 10.31763935], [79.7223587, 10.31763935], [79.7223587, 10.31791973], [79.72180939, 10.31791687], [79.72180176, 10.31819534], [79.7215271, 10.31819534], [79.7215271, 10.31847095], [79.72125244, 10.31847095], [79.72125244, 10.31874943], [79.7206955, 10.31874943], [79.7206955, 10.31902695], [79.72014618, 10.31902027], [79.72014618, 10.31931019], [79.71930695, 10.31930542], [79.71930695, 10.31958294], [79.71875, 10.31958294], [79.71875, 10.31986141], [79.71819305, 10.31986141], [79.71819305, 10.32014179], [79.71707916, 10.32014179], [79.71707916, 10.32042027], [79.71624756, 10.32041836], [79.71624756, 10.32069302], [79.7151413, 10.32069588], [79.7151413, 10.32097054], [79.71430206, 10.32097054], [79.71430206, 10.32125187], [79.7131958, 10.32125187], [79.7131958, 10.32153034], [79.71263885, 10.32153034], [79.71263885, 10.32180977], [79.71208191, 10.32180977], [79.71208191, 10.32209015], [79.71151733, 10.32209015], [79.71152496, 10.32236195], [79.71069336, 10.32236195], [79.71069336, 10.32264042], [79.71013641, 10.32264042], [79.71013641, 10.32291985], [79.7095871, 10.32291794], [79.7095871, 10.32319355], [79.70903015, 10.32319355], [79.70903015, 10.32347202], [79.70847321, 10.32347202], [79.70847321, 10.32374954], [79.71151733, 10.32374954], [79.71151733, 10.32402992], [79.71180725, 10.32402802], [79.71180725, 10.32486153], [79.7104187, 10.32485962], [79.7104187, 10.32515144], [79.70874786, 10.32515144], [79.70874786, 10.32485962], [79.70819092, 10.32486153], [79.70819092, 10.32458401], [79.7076416, 10.32458401], [79.7076416, 10.32430553], [79.70707703, 10.3243103], [79.70707703, 10.32402992], [79.70652771, 10.32402992], [79.70652771, 10.32374954], [79.70597076, 10.32374954], [79.70597076, 10.32347202], [79.7040329, 10.32347202], [79.70402527, 10.32374954], [79.70291901, 10.32374954], [79.70291901, 10.32402992], [79.70181274, 10.32402992], [79.70181274, 10.3243103], [79.69985962, 10.32430553], [79.69985962, 10.32458401], [79.69763947, 10.32458401], [79.69763947, 10.32486153], [79.69568634, 10.32485962], [79.69568634, 10.32515144], [79.69374847, 10.32515144], [79.69374847, 10.32542038], [79.68708038, 10.32542038], [79.68708038, 10.32515144], [79.68653107, 10.32515144], [79.68653107, 10.32485962], [79.68569183, 10.32486153], [79.68569183, 10.32458401], [79.68514252, 10.32458401], [79.68514252, 10.32430553], [79.68430328, 10.3243103], [79.68430328, 10.32402992], [79.68374634, 10.32402992], [79.68374634, 10.32374954], [79.68264008, 10.32374954], [79.68264008, 10.32347202], [79.68152618, 10.32347202], [79.68152618, 10.32319355], [79.68041992, 10.32319355], [79.68041992, 10.32291794], [79.67930603, 10.32291985], [79.67930603, 10.32264042], [79.67903137, 10.32264042], [79.67903137, 10.32236195], [79.67874908, 10.32236195], [79.67874908, 10.32180595], [79.6784668, 10.32180977], [79.6784668, 10.32153034], [79.67819214, 10.32153034], [79.67819214, 10.32125187], [79.67790985, 10.32125187], [79.67790985, 10.32097054], [79.67680359, 10.32097054], [79.67680359, 10.32069588], [79.67597198, 10.32069302], [79.67597198, 10.32041836], [79.67487335, 10.32042027], [79.67487335, 10.32014179], [79.67402649, 10.32014179], [79.67402649, 10.31986141], [79.67292023, 10.31986141], [79.67292023, 10.31958294], [79.67208099, 10.31958294], [79.67208099, 10.31930542], [79.66041565, 10.31930542], [79.66041565, 10.31958294], [79.65875244, 10.31958294], [79.65875244, 10.31930542], [79.65820312, 10.31931019], [79.65820312, 10.31902027], [79.65791321, 10.31902695], [79.65791321, 10.31874943], [79.65652466, 10.31874943], [79.65652466, 10.31902695], [79.65569305, 10.31902027], [79.65569305, 10.31931019], [79.65513611, 10.31930542], [79.65513611, 10.31958294], [79.65125275, 10.31958294], [79.65125275, 10.31986141], [79.65040588, 10.31986141], [79.65040588, 10.32014179], [79.6470871, 10.32014179], [79.6470871, 10.31986141], [79.64653015, 10.31986141], [79.64653015, 10.31958294], [79.64597321, 10.31958294], [79.64597321, 10.31930542], [79.64541626, 10.31931019], [79.64541626, 10.31902027], [79.63930511, 10.31902695], [79.63930511, 10.31874943], [79.63903046, 10.31874943], [79.63903046, 10.31791687], [79.63764191, 10.31791687], [79.63764191, 10.31819534], [79.63699341, 10.31819344], [79.63652802, 10.31819057], [79.63652802, 10.32264042], [79.63625336, 10.32264042], [79.63625336, 10.32374954], [79.63652802, 10.32374954], [79.63652802, 10.32486153], [79.63680267, 10.32486153], [79.63680267, 10.3259716], [79.63708496, 10.3259716], [79.63708496, 10.32708359], [79.63735962, 10.32708168], [79.63735962, 10.32792091], [79.63708496, 10.32791805], [79.63708496, 10.32847214], [79.63680267, 10.32847023], [79.63680267, 10.32903004], [79.63652802, 10.32902813], [79.63652802, 10.32958412], [79.63625336, 10.32958031], [79.63625336, 10.33181095], [79.63597107, 10.33180428], [79.63597107, 10.33236027], [79.63569641, 10.33236027], [79.63569641, 10.33292103], [79.63540649, 10.33292103], [79.63540649, 10.33375072], [79.63513947, 10.33375072], [79.63513947, 10.33542061], [79.63485718, 10.33542061], [79.63485718, 10.33485985], [79.63458252, 10.33485985], [79.63458252, 10.3340292], [79.63430786, 10.33403111], [79.63430786, 10.33375072], [79.63375092, 10.33375072], [79.63375092, 10.33403111], [79.63346863, 10.33403111], [79.63346863, 10.33431053], [79.63319397, 10.33430672], [79.63319397, 10.33458233], [79.63291931, 10.33458233], [79.63291931, 10.33485985], [79.63236237, 10.33485985], [79.63236237, 10.33514118], [79.63208008, 10.33514118], [79.63208008, 10.33542061], [79.63180542, 10.33541679], [79.63180542, 10.33569527], [79.63153076, 10.33569527], [79.63153076, 10.33597279], [79.63124847, 10.33596992], [79.63124847, 10.33791924], [79.63096619, 10.33791924], [79.63097382, 10.33986092], [79.63069153, 10.33986092], [79.63069153, 10.34013939], [79.63041687, 10.34013939], [79.63041687, 10.34069538], [79.63014221, 10.34069538], [79.63014221, 10.34097099], [79.62985992, 10.34097099], [79.62985992, 10.34125137], [79.6295929, 10.34125137], [79.6295929, 10.34152889], [79.62930298, 10.34152699], [79.62930298, 10.34208298], [79.62902832, 10.34208298], [79.62902832, 10.34236145], [79.62874603, 10.34236145], [79.62874603, 10.34291935], [79.62847137, 10.34291744], [79.62847137, 10.34347343], [79.62819672, 10.34347057], [79.62819672, 10.34402943], [79.6279068, 10.34402943], [79.62791443, 10.34486103], [79.62763977, 10.34486103], [79.62763977, 10.34542179], [79.62735748, 10.34542179], [79.62735748, 10.34764194], [79.62708282, 10.34764004], [79.62708282, 10.3498621], [79.62735748, 10.34985924], [79.62735748, 10.35013962], [79.62763977, 10.35013962], [79.62763977, 10.3506937], [79.62791443, 10.3506937], [79.62791443, 10.35097218], [79.62819672, 10.35096931], [79.62819672, 10.35124969], [79.62847137, 10.35124969], [79.62847137, 10.35181046], [79.62875366, 10.35180569], [79.62875366, 10.35208416], [79.62902832, 10.35208416], [79.62902832, 10.35235977], [79.62930298, 10.35235977], [79.62930298, 10.35291958], [79.62958527, 10.35291576], [79.62958527, 10.35319424], [79.62930298, 10.35319424], [79.62930298, 10.35347176], [79.62902832, 10.35347176], [79.62902832, 10.35375023], [79.62874603, 10.35375023], [79.62874603, 10.35402966], [79.62847137, 10.35402966], [79.62847137, 10.35431099], [79.62819672, 10.35430622], [79.62819672, 10.35486221], [79.6279068, 10.35486031], [79.6279068, 10.35542107], [79.62763977, 10.35542107], [79.62763977, 10.35653019], [79.62735748, 10.35652828], [79.62735748, 10.35708427], [79.62763977, 10.35708046], [79.62763977, 10.35764027], [79.6279068, 10.35764027], [79.6279068, 10.35792065], [79.62819672, 10.35791588], [79.62819672, 10.35847187], [79.62847137, 10.35846996], [79.62847137, 10.35903072], [79.62874603, 10.35903072], [79.62874603, 10.3593111], [79.62902832, 10.35930634], [79.62902832, 10.35958195], [79.62930298, 10.35958195], [79.62930298, 10.35986042], [79.6295929, 10.35986042], [79.6295929, 10.3601408], [79.62985992, 10.3601408], [79.62985992, 10.36042118], [79.63014221, 10.36041641], [79.63014221, 10.36097336], [79.63041687, 10.36096954], [79.63041687, 10.36126041], [79.63069153, 10.36126041], [79.63069153, 10.36153126], [79.63096619, 10.36153126], [79.63096619, 10.36181068], [79.63124847, 10.36180687], [79.63124847, 10.36208153], [79.63153076, 10.36208153], [79.63153076, 10.36236095], [79.63096619, 10.36236095], [79.63096619, 10.36264133], [79.63041687, 10.36264133], [79.63041687, 10.36291885], [79.63014221, 10.36291695], [79.63014221, 10.36319542], [79.62985992, 10.36319542], [79.62985992, 10.36208153], [79.62930298, 10.36208153], [79.62930298, 10.36236095], [79.62847137, 10.36236095], [79.62847137, 10.36291885], [79.62763977, 10.36291885], [79.62763977, 10.36264133], [79.62708282, 10.36264133], [79.62708282, 10.36236095], [79.62680054, 10.36236095], [79.62680054, 10.36207962], [79.62625122, 10.36208153], [79.62625122, 10.36180687], [79.62596893, 10.36181068], [79.62596893, 10.36153126], [79.62568665, 10.36153126], [79.62568665, 10.36126041], [79.62541962, 10.36126041], [79.62541962, 10.36096954], [79.62513733, 10.36097336], [79.62513733, 10.36041641], [79.62486267, 10.36042118], [79.62486267, 10.35986042], [79.62458038, 10.35986042], [79.62458038, 10.35930634], [79.62431335, 10.3593111], [79.62431335, 10.35875034], [79.62403107, 10.35875034], [79.62403107, 10.35791588], [79.62431335, 10.35792065], [79.62431335, 10.35625172], [79.62458038, 10.35625172], [79.62458038, 10.35458183], [79.62486267, 10.35458374], [79.62486267, 10.35291576], [79.62513733, 10.35291958], [79.62513733, 10.35153008], [79.62486267, 10.35153008], [79.62486267, 10.35042], [79.62458038, 10.35042], [79.62458038, 10.35013962], [79.62403107, 10.35013962], [79.62403107, 10.34985924], [79.62374878, 10.3498621], [79.62374878, 10.34958363], [79.62347412, 10.34958363], [79.62347412, 10.34930611], [79.62291718, 10.34931946], [79.62291718, 10.34902954], [79.62264252, 10.34902954], [79.62264252, 10.34875202], [79.6220932, 10.34875202], [79.6220932, 10.34847069], [79.62124634, 10.34847069], [79.62124634, 10.34819317], [79.62180328, 10.34819317], [79.62180328, 10.34791756], [79.62236023, 10.34792042], [79.62236023, 10.34736156], [79.62208557, 10.34736156], [79.62208557, 10.34680462], [79.62180328, 10.34681034], [79.62180328, 10.34653187], [79.62152863, 10.34653187], [79.62152863, 10.34625244], [79.62180328, 10.34625244], [79.62180328, 10.34569073], [79.62124634, 10.34569454], [79.62124634, 10.34513855], [79.62097168, 10.34513855], [79.62097168, 10.34486103], [79.62069702, 10.34486103], [79.62069702, 10.34430504], [79.6204071, 10.34430981], [79.6204071, 10.34375095], [79.61985779, 10.34375095], [79.61985779, 10.34347057], [79.61930847, 10.34347343], [79.61930847, 10.34319305], [79.61569214, 10.34319305], [79.61569214, 10.34291744], [79.61486053, 10.34291935], [79.61486053, 10.34264088], [79.61402893, 10.34264088], [79.61402893, 10.34236145], [79.61319733, 10.34236145], [79.61319733, 10.34208298], [79.61235809, 10.34208298], [79.61235809, 10.34180546], [79.61152649, 10.34181023], [79.61152649, 10.34152889], [79.61042023, 10.34152889], [79.61042023, 10.34068966], [79.61069489, 10.34069538], [79.61069489, 10.34013939], [79.61235809, 10.34013939], [79.61235809, 10.33986092], [79.61264038, 10.33986092], [79.61264038, 10.3395834], [79.61374664, 10.3395834], [79.61374664, 10.34013939], [79.61402893, 10.34013939], [79.61402893, 10.34069538], [79.61430359, 10.34069538], [79.61430359, 10.34097099], [79.61486053, 10.34097099], [79.61486053, 10.34069538], [79.61597443, 10.34069538], [79.61597443, 10.33986092], [79.61624908, 10.33986092], [79.61624908, 10.33875084], [79.61653137, 10.33875084], [79.61653137, 10.33819008], [79.61708069, 10.33819485], [79.61708069, 10.33847332], [79.61736298, 10.33847141], [79.61736298, 10.33875084], [79.61763, 10.33875084], [79.61763, 10.3393116], [79.61791992, 10.33930492], [79.61791992, 10.33986092], [79.61819458, 10.33986092], [79.61819458, 10.34013939], [79.61846924, 10.34013939], [79.61846924, 10.34069538], [79.61875153, 10.34069538], [79.61875153, 10.34097099], [79.61930847, 10.34097099], [79.61930847, 10.34069538], [79.62069702, 10.34069538], [79.62069702, 10.33930492], [79.6204071, 10.3393116], [79.6204071, 10.33763885], [79.62069702, 10.33763885], [79.62069702, 10.33708286], [79.62097168, 10.33708858], [79.62097168, 10.33653069], [79.62124634, 10.33653069], [79.62124634, 10.33596992], [79.62152863, 10.33597279], [79.62152863, 10.33485985], [79.62180328, 10.33485985], [79.62180328, 10.3340292], [79.6220932, 10.33403111], [79.6220932, 10.33318996], [79.62180328, 10.33319378], [79.62180328, 10.3320837], [79.62152863, 10.3320837], [79.62152863, 10.33097172], [79.62124634, 10.33097172], [79.62124634, 10.33041573], [79.62097168, 10.33042145], [79.62097168, 10.33014011], [79.62069702, 10.33014011], [79.62069702, 10.32958031], [79.62041473, 10.32958412], [79.62041473, 10.32930565], [79.62014008, 10.32931137], [79.62014008, 10.32903004], [79.61985779, 10.32903004], [79.61985779, 10.32874966], [79.61958313, 10.32874966], [79.61958313, 10.32847023], [79.61930847, 10.32847214], [79.61930847, 10.32791805], [79.61902618, 10.32792091], [79.61902618, 10.32763958], [79.61875153, 10.32763958], [79.61875153, 10.32736015], [79.61846924, 10.32736206], [79.61846924, 10.32708359], [79.61819458, 10.32708359], [79.61819458, 10.32680607], [79.61791992, 10.32681274], [79.61791992, 10.32625008], [79.61763, 10.32625008], [79.61763, 10.3259697], [79.61736298, 10.3259716], [79.61736298, 10.32569408], [79.61708069, 10.32569408], [79.61708069, 10.32514], [79.61680603, 10.32515144], [79.61680603, 10.32457924], [79.61653137, 10.32458401], [79.61653137, 10.32374954], [79.61624908, 10.32374954], [79.61624908, 10.32291985], [79.61569214, 10.32291985], [79.61569214, 10.32264042], [79.61541748, 10.32264042], [79.61541748, 10.32209015], [79.61514282, 10.32209015], [79.61514282, 10.32153034], [79.61486053, 10.32153034], [79.61486053, 10.32069969], [79.61458588, 10.32069111], [79.61458588, 10.3201189], [79.61458588, 10.31986141], [79.61430359, 10.31986141], [79.61430359, 10.31930542], [79.61402893, 10.31931019], [79.61402893, 10.31874943], [79.61374664, 10.31874943], [79.61374664, 10.31791687], [79.61347198, 10.31791973], [79.61347198, 10.31736088], [79.61235809, 10.31736088], [79.61235809, 10.31708336], [79.61125183, 10.31708336], [79.61125183, 10.31680489], [79.61023712, 10.31680489], [79.60986328, 10.31680965], [79.60986328, 10.31652927], [79.60875702, 10.31652927], [79.60875702, 10.31624889], [79.6076355, 10.31624889], [79.6076355, 10.31597328], [79.60680389, 10.31597328], [79.60680389, 10.31569481], [79.60624695, 10.31569481], [79.60624695, 10.31541729], [79.60597229, 10.3154192], [79.60597229, 10.31514072], [79.60542297, 10.31514072], [79.60542297, 10.3148613], [79.60514069, 10.3148613], [79.60514069, 10.31458282], [79.6048584, 10.31458282], [79.6048584, 10.31430531], [79.60457611, 10.31431198], [79.60457611, 10.31403065], [79.60430908, 10.31403065], [79.60430908, 10.31375122], [79.60375214, 10.31375122], [79.60375214, 10.31347084], [79.60346985, 10.31347084], [79.60346985, 10.31319523], [79.60319519, 10.31319523], [79.60319519, 10.31291676], [79.6029129, 10.31292152], [79.6029129, 10.31264114], [79.60263062, 10.31264114], [79.60263062, 10.31235886], [79.6020813, 10.31236076], [79.6020813, 10.31208324], [79.60180664, 10.31208324], [79.60180664, 10.31180477], [79.60151672, 10.3118124], [79.60151672, 10.31153107], [79.60124969, 10.31153107], [79.60124969, 10.31125069], [79.60098267, 10.31125069], [79.60098267, 10.31097126], [79.60041809, 10.31097317], [79.60041809, 10.31069469], [79.6001358, 10.31069469], [79.6001358, 10.31041718], [79.59958649, 10.31042099], [79.59958649, 10.31015015], [79.59929657, 10.31015015], [79.59929657, 10.30986118], [79.59958649, 10.30986118], [79.59958649, 10.30958271], [79.59874725, 10.30958271], [79.59874725, 10.30930519], [79.59792328, 10.30931091], [79.59792328, 10.30903053], [79.59680176, 10.30903053], [79.59680176, 10.30875111], [79.59625244, 10.30875111], [79.59625244, 10.30931091], [79.59430695, 10.30931091], [79.59430695, 10.30903053], [79.59401703, 10.30903053], [79.59401703, 10.30875111], [79.58930206, 10.30875111], [79.58930206, 10.30903053], [79.5881958, 10.30903053], [79.5881958, 10.30931091], [79.58625031, 10.30930519], [79.58625031, 10.30958271], [79.5854187, 10.30958271], [79.5854187, 10.30986118], [79.58486176, 10.30986118], [79.58486176, 10.31015015], [79.58513641, 10.3101387], [79.58513641, 10.31069469], [79.5854187, 10.31068993], [79.5854187, 10.31125069], [79.58569336, 10.31125069], [79.58569336, 10.31153107], [79.58513641, 10.31153107], [79.58513641, 10.31125069], [79.58486176, 10.31125069], [79.58486176, 10.31097126], [79.5845871, 10.31097317], [79.5845871, 10.31069469], [79.58403015, 10.31069469], [79.58403015, 10.31041718], [79.58374786, 10.31042099], [79.58374786, 10.31015015], [79.58319092, 10.31015015], [79.58319092, 10.30986118], [79.58291626, 10.30986118], [79.58291626, 10.30958271], [79.5826416, 10.30958271], [79.5826416, 10.30930519], [79.58152008, 10.30931091], [79.58152008, 10.30903053], [79.58097076, 10.30903053], [79.58097076, 10.30875111], [79.57653046, 10.30875111], [79.57653046, 10.30903053], [79.57514191, 10.30903053], [79.57514191, 10.30931091], [79.57402802, 10.30930519], [79.57402802, 10.30958271], [79.57347107, 10.30958271], [79.57347107, 10.30986118], [79.57290649, 10.30986118], [79.57290649, 10.31015015], [79.57264709, 10.31015015], [79.57264709, 10.31042099], [79.57208252, 10.31041718], [79.57208252, 10.31069469], [79.57152557, 10.31069469], [79.57152557, 10.31041718], [79.56624603, 10.31042099], [79.56624603, 10.31015015], [79.56402588, 10.31015015], [79.56402588, 10.31042099], [79.56319427, 10.31041718], [79.56319427, 10.31069469], [79.56208038, 10.31069469], [79.56208038, 10.31097317], [79.56153107, 10.31097126], [79.56153107, 10.31125069], [79.56069183, 10.31125069], [79.56069183, 10.31153107], [79.56014252, 10.31153107], [79.56014252, 10.3118124], [79.55958557, 10.31180477], [79.55958557, 10.31208324], [79.55486298, 10.31208324], [79.55486298, 10.31236076], [79.55403137, 10.31235886], [79.55403137, 10.31264114], [79.5534668, 10.31264114], [79.5534668, 10.31292152], [79.55263519, 10.31291676], [79.55263519, 10.31319523], [79.55208588, 10.31319523], [79.55208588, 10.31347084], [79.55124664, 10.31347084], [79.55124664, 10.31375122], [79.55069733, 10.31375122], [79.55069733, 10.31347084], [79.55097198, 10.31347084], [79.55097198, 10.31291676], [79.55124664, 10.31292152], [79.55124664, 10.31235886], [79.55152893, 10.31236076], [79.55152893, 10.31208324], [79.55180359, 10.31208324], [79.55180359, 10.31180477], [79.55208588, 10.3118124], [79.55208588, 10.31153107], [79.55236053, 10.31153107], [79.55236053, 10.31125069], [79.55264282, 10.31125069], [79.55264282, 10.31097126], [79.55291748, 10.31097317], [79.55291748, 10.31069469], [79.55319214, 10.31069469], [79.55319214, 10.31041718], [79.55374908, 10.31042099], [79.55374908, 10.31015015], [79.55403137, 10.31015015], [79.55403137, 10.30986118], [79.55430603, 10.30986118], [79.55430603, 10.30958271], [79.55458069, 10.30958271], [79.55458069, 10.30930519], [79.55486298, 10.30931091], [79.55486298, 10.30903053], [79.55513763, 10.30903053], [79.55513763, 10.30875111], [79.55541992, 10.30875111], [79.55541992, 10.30847263], [79.55708313, 10.30847263], [79.55708313, 10.30819511], [79.55874634, 10.30819511], [79.55874634, 10.30791664], [79.56041718, 10.30792141], [79.56041718, 10.30764103], [79.56236267, 10.30764103], [79.56236267, 10.3073597], [79.56402588, 10.3073597], [79.56402588, 10.30708218], [79.56680298, 10.30708218], [79.56680298, 10.3073597], [79.56930542, 10.3073597], [79.56930542, 10.30708218], [79.57041931, 10.30708218], [79.57041931, 10.30680656], [79.57125092, 10.30681133], [79.57125092, 10.30653095], [79.57235718, 10.30653095], [79.57235718, 10.30624962], [79.57319641, 10.30624962], [79.57319641, 10.30514145], [79.57402802, 10.30514145], [79.57402802, 10.30486012], [79.57958221, 10.30486012], [79.57958221, 10.30458355], [79.5798645, 10.30458355], [79.5798645, 10.30430603], [79.58013916, 10.3043108], [79.58013916, 10.30402088], [79.58041382, 10.30402756], [79.58041382, 10.30375004], [79.58097076, 10.30375004], [79.58097076, 10.30346966], [79.58180237, 10.30347157], [79.58180237, 10.30319405], [79.58235931, 10.30319405], [79.58235931, 10.30291557], [79.58486176, 10.30291557], [79.58486176, 10.30319405], [79.58513641, 10.30319405], [79.58513641, 10.30347157], [79.5854187, 10.30346966], [79.5854187, 10.30375004], [79.58597565, 10.30375004], [79.58597565, 10.30402756], [79.58625031, 10.30402088], [79.58625031, 10.3043108], [79.58652496, 10.30430603], [79.58652496, 10.30458355], [79.58680725, 10.30458355], [79.58680725, 10.30486012], [79.58763885, 10.30486012], [79.58763885, 10.30402756], [79.58791351, 10.30402756], [79.58791351, 10.30291557], [79.5881958, 10.3029213], [79.5881958, 10.30235958], [79.58847046, 10.30236244], [79.58847046, 10.30208206], [79.58958435, 10.30208206], [79.58958435, 10.30236244], [79.58930206, 10.30235958], [79.58930206, 10.3029213], [79.5890274, 10.30291557], [79.5890274, 10.30319405], [79.59124756, 10.30319405], [79.59124756, 10.30291557], [79.59348297, 10.3029213], [79.59348297, 10.30235958], [79.59319305, 10.30236244], [79.59319305, 10.30180645], [79.5929184, 10.30181122], [79.5929184, 10.30125046], [79.59401703, 10.30125046], [79.59401703, 10.30263996], [79.59570313, 10.30263996], [79.59570313, 10.30235958], [79.59708405, 10.30236244], [79.59708405, 10.30208206], [79.59819794, 10.30208206], [79.59819794, 10.30180645], [79.59958649, 10.30181122], [79.59958649, 10.30153275], [79.60069275, 10.30153275], [79.60069275, 10.30125046], [79.6020813, 10.30125046], [79.6020813, 10.30098057], [79.60320282, 10.30098057], [79.60320282, 10.3006916], [79.6029129, 10.30069447], [79.6029129, 10.30013847], [79.60263062, 10.30014038], [79.60263062, 10.29986191], [79.60430908, 10.29986191], [79.60430908, 10.29958439], [79.60597229, 10.29958439], [79.60597229, 10.29930592], [79.60736084, 10.29930592], [79.60736084, 10.29986191], [79.60847473, 10.29986191], [79.6084671, 10.29957867], [79.60902405, 10.29958439], [79.60902405, 10.29930592], [79.60986328, 10.29931068], [79.60986328, 10.2990303], [79.61624908, 10.2990303], [79.61624908, 10.29874992], [79.6159668, 10.29874992], [79.6159668, 10.29846954], [79.61569214, 10.2984724], [79.61569214, 10.29819584], [79.61541748, 10.29819584], [79.61541748, 10.29791641], [79.61514282, 10.29792023], [79.61514282, 10.29763985], [79.61486053, 10.29763985], [79.61486053, 10.29736042], [79.61624908, 10.29736042], [79.61624908, 10.29763985], [79.61653137, 10.29763985], [79.61653137, 10.29819584], [79.61680603, 10.29819107], [79.61680603, 10.29874992], [79.61985779, 10.29874992], [79.61985779, 10.29846954], [79.61958313, 10.2984724], [79.61958313, 10.29791641], [79.61930847, 10.29792023], [79.61930847, 10.29763985], [79.62014008, 10.29763985], [79.62014008, 10.29736042], [79.62124634, 10.29736233], [79.62124634, 10.29708385], [79.62180328, 10.29708385], [79.62180328, 10.29680634], [79.62264252, 10.29681015], [79.62264252, 10.29652977], [79.62319183, 10.29652977], [79.62319183, 10.29625034], [79.62403107, 10.29625034], [79.62403107, 10.29597187], [79.62458038, 10.29597187], [79.62458038, 10.29569435], [79.62541962, 10.29569435], [79.62541962, 10.29541779], [79.62763977, 10.29541969], [79.62763977, 10.29514027], [79.62985992, 10.29514027], [79.62985992, 10.29485035], [79.63208008, 10.29485035], [79.63208008, 10.29514027], [79.63236237, 10.29514027], [79.63236237, 10.29541969], [79.63263702, 10.29541779], [79.63263702, 10.29569435], [79.63375092, 10.29569435], [79.63375092, 10.29541779], [79.63430786, 10.29541969], [79.63430786, 10.29514027], [79.63485718, 10.29514027], [79.63485718, 10.29485035], [79.63569641, 10.29486179], [79.63569641, 10.29458427], [79.63625336, 10.29458427], [79.63625336, 10.2943058], [79.63708496, 10.2943058], [79.63708496, 10.29458427], [79.63764191, 10.29458427], [79.63764191, 10.29486179], [79.63874817, 10.29486179], [79.63874817, 10.29458427], [79.63903046, 10.29458427], [79.63903046, 10.2943058], [79.63931274, 10.29430962], [79.63931274, 10.29403019], [79.64457703, 10.29403019], [79.64457703, 10.29374886], [79.64485931, 10.29374886], [79.64485931, 10.29319572], [79.6451416, 10.29319572], [79.6451416, 10.29263878], [79.64569092, 10.29264164], [79.64569092, 10.29236126], [79.65180206, 10.29236126], [79.65180206, 10.29264164], [79.65429688, 10.29264164], [79.65429688, 10.29236126], [79.65625, 10.29236126], [79.65625, 10.29208279], [79.65680695, 10.29208279], [79.65680695, 10.29180527], [79.65735626, 10.29181004], [79.65735626, 10.29152966], [79.65791321, 10.29152966], [79.65791321, 10.29124928], [79.65847015, 10.29124928], [79.65847015, 10.2909708], [79.6590271, 10.2909708], [79.6590271, 10.29069328], [79.65958405, 10.29069328], [79.65958405, 10.29041672], [79.66014099, 10.29041958], [79.66014099, 10.2901392], [79.66069794, 10.2901392], [79.66069794, 10.28986073], [79.66124725, 10.28986073], [79.66124725, 10.28958321], [79.6618042, 10.28958321], [79.6618042, 10.28930473], [79.66236115, 10.28931046], [79.66236115, 10.28904057], [79.66319275, 10.28904057], [79.66319275, 10.28931046], [79.66430664, 10.28931046], [79.66430664, 10.28904057], [79.66513824, 10.28902721], [79.66513824, 10.28958321], [79.6654129, 10.28958321], [79.6654129, 10.28988171], [79.6654129, 10.29124928], [79.66569519, 10.29124928], [79.66569519, 10.29208279], [79.6654129, 10.29208088], [79.6654129, 10.29264164], [79.66513824, 10.29264164], [79.66513824, 10.29292202], [79.66486359, 10.29291534], [79.66486359, 10.29347134], [79.6645813, 10.29347134], [79.6645813, 10.29403019], [79.66430664, 10.29403019], [79.66430664, 10.29430962], [79.66402435, 10.2943058], [79.66402435, 10.29486179], [79.66374969, 10.29485035], [79.66374969, 10.29514027], [79.66347504, 10.29514027], [79.66347504, 10.29569435], [79.66319275, 10.29569435], [79.66319275, 10.29625034], [79.66293335, 10.29625034], [79.66293335, 10.29681015], [79.6626358, 10.29680634], [79.6626358, 10.29736233], [79.66236115, 10.29736042], [79.66236115, 10.29763985], [79.6626358, 10.29763985], [79.6626358, 10.29819584], [79.66291809, 10.29819584], [79.66291809, 10.2984724], [79.66348267, 10.29846954], [79.66348267, 10.29874992], [79.66374969, 10.29874992], [79.66374969, 10.2990303], [79.66401672, 10.2990303], [79.66401672, 10.29931068], [79.6645813, 10.29930592], [79.6645813, 10.29958439], [79.66485596, 10.29957867], [79.66485596, 10.29986191], [79.66513824, 10.29986191], [79.66513824, 10.30042267], [79.6654129, 10.30041599], [79.6654129, 10.30069447], [79.66570282, 10.3006916], [79.66570282, 10.30125046], [79.66596985, 10.30125046], [79.66596985, 10.30153275], [79.6673584, 10.30153275], [79.6673584, 10.30181122], [79.66874695, 10.30181122], [79.66874695, 10.30098057], [79.66847229, 10.30098057], [79.66847229, 10.3006916], [79.66819763, 10.30069447], [79.66819763, 10.30041599], [79.66764069, 10.30042267], [79.66764069, 10.30014038], [79.6673584, 10.30014038], [79.6673584, 10.29986191], [79.66707611, 10.29986191], [79.66707611, 10.29957867], [79.66680908, 10.29958439], [79.66680908, 10.29930592], [79.66652679, 10.29931068], [79.66652679, 10.2990303], [79.66596985, 10.2990303], [79.66596985, 10.29874992], [79.66570282, 10.29874992], [79.66570282, 10.29846954], [79.66513824, 10.2984724], [79.66513824, 10.29819584], [79.66486359, 10.29819584], [79.66486359, 10.29791641], [79.6645813, 10.29792023], [79.6645813, 10.29763985], [79.66430664, 10.29763985], [79.66430664, 10.29708195], [79.66402435, 10.29708385], [79.66402435, 10.29680634], [79.66374969, 10.29681015], [79.66374969, 10.29652977], [79.66430664, 10.29652977], [79.66430664, 10.29625034], [79.6645813, 10.29625034], [79.6645813, 10.29597187], [79.66513824, 10.29597187], [79.66513824, 10.29569435], [79.6654129, 10.29569435], [79.6654129, 10.29541779], [79.66625214, 10.29541779], [79.66625214, 10.29569435], [79.66652679, 10.29569435], [79.66652679, 10.29625034], [79.66680908, 10.29625034], [79.66680908, 10.29681015], [79.66707611, 10.29681015], [79.66707611, 10.29763985], [79.6673584, 10.29763985], [79.6673584, 10.29819584], [79.66764069, 10.29819107], [79.66764069, 10.29874992], [79.66792297, 10.29874992], [79.66792297, 10.29931068], [79.66819763, 10.29930592], [79.66819763, 10.29958439], [79.66847229, 10.29958439], [79.66847229, 10.29986191], [79.66874695, 10.29986191], [79.66874695, 10.30014038], [79.66929626, 10.30014038], [79.66929626, 10.30042267], [79.66986084, 10.30041599], [79.66986084, 10.30069447], [79.67041779, 10.3006916], [79.67041779, 10.30098057], [79.6709671, 10.30098057], [79.6709671, 10.30125046], [79.67151642, 10.30125046], [79.67151642, 10.30153275], [79.67346954, 10.30153275], [79.67346954, 10.30125046], [79.67430878, 10.30125046], [79.67430878, 10.30098057], [79.67494202, 10.30097675], [79.67542267, 10.30098057], [79.67544556, 10.30075836], [79.67559052, 10.30069447], [79.67652893, 10.30069447], [79.67652893, 10.30041599], [79.67679596, 10.30042267], [79.67679596, 10.30015182], [79.67708588, 10.30014038], [79.67708588, 10.30004025], [79.67708588, 10.29986191], [79.67736053, 10.29986191], [79.67736053, 10.29958439], [79.67763519, 10.29958439], [79.67763519, 10.29930592], [79.67790985, 10.29931068], [79.67790985, 10.29874992], [79.67819214, 10.29874992], [79.67819214, 10.29846954], [79.67847443, 10.2984724], [79.67847443, 10.29819584], [79.67874908, 10.29819584], [79.67874908, 10.29791641], [79.67903137, 10.29792023], [79.67903137, 10.29763985], [79.67930603, 10.29763985], [79.67930603, 10.29736042], [79.67986298, 10.29736233], [79.67986298, 10.29708385], [79.68013763, 10.29708385], [79.68013763, 10.29680634], [79.68068695, 10.29681015], [79.68068695, 10.29652977], [79.68125153, 10.29652977], [79.68125153, 10.29625034], [79.68152618, 10.29625034], [79.68152618, 10.29597187], [79.68208313, 10.29597187], [79.68208313, 10.29569435], [79.68264008, 10.29569435], [79.68264008, 10.29541779], [79.6829071, 10.29541969], [79.6829071, 10.29514027], [79.68347168, 10.29514027], [79.68347168, 10.29485035], [79.68430328, 10.29486179], [79.68430328, 10.29458427], [79.68514252, 10.29458427], [79.68514252, 10.2943058], [79.68596649, 10.29430962], [79.68596649, 10.29403019], [79.68681335, 10.29403019], [79.68681335, 10.29374886], [79.68791962, 10.29374886], [79.68791962, 10.29347134], [79.68875122, 10.29347134], [79.68875122, 10.29319572], [79.68958282, 10.29319572], [79.68958282, 10.29291534], [79.6904068, 10.29292202], [79.6904068, 10.29208088], [79.69069672, 10.29208279], [79.69069672, 10.29124928], [79.68930817, 10.29124928], [79.68930817, 10.29097271], [79.68624878, 10.29097271], [79.68624878, 10.29124928], [79.68514252, 10.29124928], [79.68514252, 10.29152966], [79.68403625, 10.29152966], [79.68403625, 10.29181004], [79.68319702, 10.29180527], [79.68319702, 10.29208279], [79.68208313, 10.29208279], [79.68208313, 10.29236126], [79.68013763, 10.29236126], [79.68013763, 10.29208279], [79.68041992, 10.29208279], [79.68041992, 10.29180527], [79.68068695, 10.29181004], [79.68068695, 10.29152966], [79.68096924, 10.29152966], [79.68096924, 10.29096889], [79.68125153, 10.2909708], [79.68125153, 10.29069328], [79.68152618, 10.29069328], [79.68152618, 10.29041672], [79.68180847, 10.29041958], [79.68180847, 10.2901392], [79.68319702, 10.2901392], [79.68319702, 10.28986073], [79.68430328, 10.28986073], [79.68430328, 10.28958321], [79.68569183, 10.28958321], [79.68569183, 10.28930473], [79.68681335, 10.28931046], [79.68681335, 10.28904057], [79.68818665, 10.28904057], [79.68818665, 10.28875065], [79.68930817, 10.28875065], [79.68930817, 10.28847122], [79.69041443, 10.28847313], [79.69041443, 10.28819466], [79.69125366, 10.28819466], [79.69125366, 10.28791714], [79.69235992, 10.28792191], [79.69235992, 10.28764057], [79.69346619, 10.28764057], [79.69346619, 10.28736115], [79.69458008, 10.28736115], [79.69458008, 10.28708267], [79.69569397, 10.28708267], [79.69569397, 10.28680515], [79.69680786, 10.28681183], [79.69680786, 10.28653145], [79.69763947, 10.28653145], [79.69763947, 10.28625107], [79.69875336, 10.28625107], [79.69875336, 10.28598022], [79.69985962, 10.28598022], [79.69985962, 10.28569031], [79.70124817, 10.28569031], [79.70124817, 10.28598022], [79.70236206, 10.28598022], [79.70236206, 10.28569031], [79.70319366, 10.28569508], [79.70319366, 10.2854166], [79.70375061, 10.28542137], [79.70375061, 10.28514099], [79.70458221, 10.28514099], [79.70458221, 10.28486061], [79.70513916, 10.28486061], [79.70513916, 10.28458309], [79.70597076, 10.28458309], [79.70597076, 10.28430462], [79.70652771, 10.28430939], [79.70652771, 10.28403091], [79.70735931, 10.28403091], [79.70735931, 10.28375053], [79.70791626, 10.28375053], [79.70791626, 10.28347111], [79.70874786, 10.28347301], [79.70874786, 10.28319454], [79.70903015, 10.28318977], [79.70903015, 10.28403091], [79.70874786, 10.28402901], [79.70874786, 10.28569508], [79.70847321, 10.28569031], [79.70847321, 10.28681183], [79.71375275, 10.28681183], [79.71375275, 10.28625107], [79.71401978, 10.28625107], [79.71401978, 10.28598022], [79.71430206, 10.28598022], [79.71430206, 10.28542137], [79.71457672, 10.28542137], [79.71457672, 10.28486061], [79.71485901, 10.28486061], [79.71485901, 10.28458309], [79.7151413, 10.28458309], [79.7151413, 10.28402901], [79.71541595, 10.28403091], [79.71541595, 10.28375053], [79.71678925, 10.28375053], [79.71678925, 10.28347111], [79.7179184, 10.28347301], [79.7179184, 10.28319454], [79.71930695, 10.28319454], [79.71930695, 10.28291702], [79.72041321, 10.28291702], [79.72041321, 10.28263855], [79.72099304, 10.28263855], [79.72180176, 10.28264141], [79.72180176, 10.28236103], [79.72291565, 10.28236103], [79.72291565, 10.28208256], [79.7243042, 10.28208256], [79.7243042, 10.28180695], [79.72541809, 10.28181076], [79.72541809, 10.28153133], [79.72680664, 10.28153133], [79.72680664, 10.28125095], [79.7279129, 10.28125095], [79.7279129, 10.28096962], [79.72930908, 10.28097343], [79.72930908, 10.28069496], [79.73041534, 10.28069496], [79.73041534, 10.28041553], [79.73052979, 10.28041553], [79.73179626, 10.28042126], [79.73179626, 10.28014088], [79.73208618, 10.28014088], [79.73208618, 10.27985096], [79.7326355, 10.27985954], [79.7326355, 10.27958202], [79.73291779, 10.27958202], [79.73291779, 10.27930737], [79.7334671, 10.27931118], [79.7334671, 10.2790308], [79.73374939, 10.2790308], [79.73374939, 10.27875042], [79.73402405, 10.27875042], [79.73401642, 10.27847004], [79.73458099, 10.27847195], [79.73458099, 10.27819443], [79.73486328, 10.27819443], [79.73486328, 10.27791595], [79.73596954, 10.27791595], [79.73596954, 10.27819443], [79.73764038, 10.27819443], [79.73764038, 10.27847195], [79.73792267, 10.27847004], [79.73792267, 10.2790308], [79.7381897, 10.2790308], [79.7381897, 10.27931118], [79.73958588, 10.27931118], [79.73958588, 10.27847004], [79.73930359, 10.27847195], [79.73930359, 10.27791595], [79.73902893, 10.27792072], [79.73902893, 10.27735996], [79.73764038, 10.27735996], [79.73764038, 10.27708435], [79.73458099, 10.27708435], [79.73458099, 10.27680588], [79.73430634, 10.27681065], [79.73430634, 10.27653122], [79.73374939, 10.27653122], [79.73374939, 10.27625179], [79.7334671, 10.27625179], [79.7334671, 10.27569199], [79.73319244, 10.27569389], [79.73319244, 10.2751379], [79.73264313, 10.27514267], [79.73264313, 10.27486038], [79.73239136, 10.27486038], [79.73180389, 10.27486229], [79.73180389, 10.27458382], [79.73124695, 10.27458191], [79.73124695, 10.2743063], [79.73042297, 10.27431107], [79.73042297, 10.27403927], [79.7270813, 10.27403927], [79.7270813, 10.27431107], [79.72486115, 10.2743063], [79.72486115, 10.27458191], [79.72291565, 10.27458382], [79.72291565, 10.27486229], [79.72125244, 10.27486038], [79.72125244, 10.27514267], [79.71930695, 10.27514267], [79.71930695, 10.27542114], [79.71763611, 10.27541637], [79.71763611, 10.27569389], [79.71569824, 10.27569389], [79.71569824, 10.27597237], [79.71401978, 10.27597046], [79.71401978, 10.27625179], [79.71208191, 10.27625179], [79.71208191, 10.27653122], [79.71013641, 10.27653122], [79.71013641, 10.27681065], [79.70819092, 10.27680588], [79.70819092, 10.27708435], [79.70652771, 10.27708435], [79.70652771, 10.27735996], [79.70458221, 10.27735996], [79.70458221, 10.27764034], [79.70263672, 10.27764034], [79.70263672, 10.27792072], [79.70069122, 10.27791595], [79.70069122, 10.27819443], [79.69875336, 10.27819443], [79.69875336, 10.27847195], [79.69708252, 10.27847195], [79.69708252, 10.27875042], [79.69513702, 10.27875042], [79.69513702, 10.2790308], [79.69319153, 10.2790308], [79.69319153, 10.27931118], [79.69125366, 10.27930737], [79.69125366, 10.27958202], [79.68958282, 10.27958202], [79.68958282, 10.27985954], [79.68763733, 10.27985096], [79.68763733, 10.28014088], [79.68569183, 10.28014088], [79.68569183, 10.28042126], [79.68180847, 10.28041553], [79.68180847, 10.28069496], [79.67970276, 10.28069496], [79.67791748, 10.28069496], [79.67791748, 10.28097343], [79.67402649, 10.28096962], [79.67402649, 10.28125095], [79.67292023, 10.28125095], [79.67292023, 10.28153133], [79.67151642, 10.28153133], [79.67151642, 10.28181076], [79.67041779, 10.28180695], [79.67041779, 10.28208256], [79.66929626, 10.2820797], [79.66930389, 10.28236103], [79.66819763, 10.28236103], [79.66819763, 10.28264141], [79.66680908, 10.28263855], [79.66680908, 10.28291702], [79.66569519, 10.28291702], [79.66569519, 10.28319454], [79.6645813, 10.28319454], [79.6645813, 10.28347301], [79.66319275, 10.28347111], [79.66319275, 10.28375053], [79.66208649, 10.28375053], [79.66208649, 10.28403091], [79.6609726, 10.28403091], [79.6609726, 10.28430939], [79.6598587, 10.28430462], [79.6598587, 10.28458309], [79.65847015, 10.28458309], [79.65847015, 10.28486061], [79.65735626, 10.28486061], [79.65735626, 10.28514099], [79.6554184, 10.28514099], [79.6554184, 10.28542137], [79.65374756, 10.2854166], [79.65374756, 10.28569508], [79.65207672, 10.28569031], [79.65207672, 10.28598022], [79.65040588, 10.28598022], [79.65040588, 10.28625107], [79.64848328, 10.28625107], [79.64848328, 10.28653145], [79.64679718, 10.28653145], [79.64679718, 10.28681183], [79.64541626, 10.28680515], [79.64541626, 10.28708267], [79.64402771, 10.28708267], [79.64402771, 10.28736115], [79.64263916, 10.28736115], [79.64263916, 10.28764057], [79.64125061, 10.28764057], [79.64125061, 10.28792191], [79.63957977, 10.28791714], [79.63957977, 10.28819466], [79.63819122, 10.28819466], [79.63819122, 10.28847313], [79.63680267, 10.28847122], [79.63680267, 10.28875065], [79.63540649, 10.28875065], [79.63540649, 10.28904057], [79.6340332, 10.28904057], [79.6340332, 10.28931046], [79.62930298, 10.28930473], [79.62930298, 10.28958321], [79.62763977, 10.28958321], [79.62763977, 10.28986073], [79.62596893, 10.28986073], [79.62596893, 10.2901392], [79.62431335, 10.2901392], [79.62431335, 10.29041958], [79.62291718, 10.29041672], [79.62291718, 10.29069328], [79.62124634, 10.29069328], [79.62124634, 10.2909708], [79.61958313, 10.29097271], [79.61958313, 10.29124928], [79.61791992, 10.29124928], [79.61791992, 10.29152966], [79.61624908, 10.29152966], [79.61624908, 10.29181004], [79.61458588, 10.29180527], [79.61458588, 10.29208279], [79.61291504, 10.29208279], [79.61291504, 10.29236126], [79.61152649, 10.29236126], [79.61152649, 10.29264164], [79.60986328, 10.29264164], [79.60986328, 10.29292202], [79.60819244, 10.29291534], [79.60819244, 10.29319572], [79.60652924, 10.29319572], [79.60652924, 10.29347134], [79.6048584, 10.29347134], [79.6048584, 10.29374886], [79.6029129, 10.29374886], [79.6029129, 10.29403019], [79.60124969, 10.29403019], [79.60124969, 10.29430962], [79.59958649, 10.2943058], [79.59958649, 10.29458427], [79.59764099, 10.29458427], [79.59764099, 10.29486179], [79.59597015, 10.29485035], [79.59597015, 10.29514027], [79.59430695, 10.29514027], [79.59430695, 10.29541969], [79.59236145, 10.29541779], [79.59236145, 10.29569435], [79.59069824, 10.29569435], [79.59069824, 10.29597187], [79.5890274, 10.29597187], [79.5890274, 10.29625034], [79.58708191, 10.29625034], [79.58708191, 10.29652977], [79.5854187, 10.29652977], [79.5854187, 10.29681015], [79.5826416, 10.29680634], [79.5826416, 10.29708385], [79.58180237, 10.29708385], [79.58180237, 10.29736233], [79.57847595, 10.29736233], [79.57847595, 10.29708385], [79.57736206, 10.29708385], [79.57736206, 10.29680634], [79.57707977, 10.29680634], [79.57707977, 10.29708385], [79.57653046, 10.29708385], [79.57653046, 10.29736233], [79.57624817, 10.29736042], [79.57624817, 10.29763985], [79.57541656, 10.29763985], [79.57541656, 10.29792023], [79.57347107, 10.29791641], [79.57347107, 10.2984724], [79.57319641, 10.29846954], [79.57319641, 10.29874992], [79.57235718, 10.29874992], [79.57235718, 10.29846954], [79.57125092, 10.29846954], [79.57125092, 10.29874992], [79.57068634, 10.29874992], [79.57068634, 10.2990303], [79.56958008, 10.2990303], [79.56958008, 10.29931068], [79.56708527, 10.29930592], [79.56708527, 10.29958439], [79.56624603, 10.29957867], [79.56625366, 10.29986191], [79.56402588, 10.29986191], [79.56402588, 10.30014038], [79.56181335, 10.30014038], [79.56181335, 10.30042267], [79.56124878, 10.30042267], [79.56124878, 10.30014038], [79.55902863, 10.30014038], [79.55902863, 10.30042267], [79.55791473, 10.30041599], [79.55791473, 10.30069447], [79.55513763, 10.3006916], [79.55513763, 10.30098057], [79.55263519, 10.30097198], [79.55263519, 10.30125046], [79.55069733, 10.30125046], [79.55069733, 10.30097198], [79.55041504, 10.30097198], [79.55042267, 10.30125046], [79.54957581, 10.30125046], [79.54957581, 10.30153275], [79.54847717, 10.30153275], [79.54847717, 10.30181122], [79.54763794, 10.30180645], [79.54763794, 10.30208206], [79.54569244, 10.30208206], [79.54569244, 10.30236244], [79.54541779, 10.30235958], [79.54541779, 10.30263996], [79.54402924, 10.30263996], [79.54402924, 10.3029213], [79.5423584, 10.30291557], [79.5423584, 10.30319405], [79.54096985, 10.30319405], [79.54096985, 10.30347157], [79.54013824, 10.30347157], [79.54013824, 10.30319405], [79.53986359, 10.30319405], [79.53986359, 10.30347157], [79.53901672, 10.30346966], [79.53901672, 10.30375004], [79.53791809, 10.30375004], [79.53791809, 10.30346966], [79.53679657, 10.30346966], [79.53679657, 10.30375004], [79.53652954, 10.30375004], [79.53652954, 10.30402756], [79.53542328, 10.30402088], [79.53542328, 10.3043108], [79.53375244, 10.30430603], [79.53375244, 10.30458355], [79.5333786, 10.30458355], [79.5320816, 10.30458355], [79.5320816, 10.30486012], [79.52986145, 10.30486012], [79.52986145, 10.30514145], [79.5284729, 10.30514145], [79.5284729, 10.30542088], [79.5265274, 10.30541611], [79.5265274, 10.30569363], [79.52625275, 10.30569363], [79.52625275, 10.3059721], [79.5256958, 10.30597019], [79.5256958, 10.30624962], [79.52540588, 10.30624962], [79.52540588, 10.30653095], [79.52513885, 10.30653095], [79.52513885, 10.30681133], [79.52458191, 10.30680656], [79.52458191, 10.30708218], [79.52430725, 10.30708218], [79.52430725, 10.3073597], [79.52401733, 10.3073597], [79.52401733, 10.30764103], [79.52348328, 10.30764103], [79.52348328, 10.30792141], [79.52319336, 10.30792141], [79.52319336, 10.31125069], [79.52348328, 10.31125069], [79.52348328, 10.3118124], [79.52375031, 10.31180477], [79.52375031, 10.31236076], [79.52401733, 10.31235886], [79.52401733, 10.31292152], [79.52430725, 10.31291676], [79.52430725, 10.31375122], [79.52458191, 10.31375122], [79.52458191, 10.31431198], [79.5248642, 10.31430531], [79.5248642, 10.3148613], [79.52513885, 10.3148613], [79.52513885, 10.3154192], [79.5256958, 10.31541729], [79.5256958, 10.31569481], [79.52625275, 10.31569481], [79.52625275, 10.31597328], [79.52680206, 10.31597328], [79.52680206, 10.31624889], [79.52707672, 10.31624889], [79.52707672, 10.31652927], [79.5276413, 10.31652927], [79.5276413, 10.31680965], [79.53151703, 10.31680965], [79.53151703, 10.31652927], [79.53180695, 10.31652927], [79.53180695, 10.31624889], [79.53236389, 10.31624889], [79.53235626, 10.31596184], [79.53263855, 10.31597328], [79.53263855, 10.31569481], [79.53291321, 10.31569481], [79.53291321, 10.31541729], [79.53320313, 10.3154192], [79.53320313, 10.31514072], [79.53347778, 10.31514072], [79.53347778, 10.3148613], [79.53375244, 10.3148613], [79.53375244, 10.31458282], [79.5340271, 10.31458282], [79.5340271, 10.31430531], [79.53430176, 10.31431198], [79.53430176, 10.31403065], [79.53457642, 10.31403065], [79.53457642, 10.31375122], [79.53514099, 10.31375122], [79.53514099, 10.31347084], [79.53541565, 10.31347084], [79.53541565, 10.31319523], [79.5359726, 10.31319523], [79.5359726, 10.31291676], [79.53624725, 10.31292152], [79.53624725, 10.31272984], [79.53624725, 10.31263924], [79.53679657, 10.31264114], [79.53679657, 10.31235886], [79.53708649, 10.31236076], [79.53708649, 10.31208324], [79.53791809, 10.31208324], [79.53791809, 10.31236076], [79.53848267, 10.31235886], [79.53848267, 10.31264114], [79.53901672, 10.31264114], [79.53901672, 10.31292152], [79.53930664, 10.31291676], [79.53930664, 10.31319523], [79.53985596, 10.31319046], [79.53985596, 10.31347084], [79.5404129, 10.31347084], [79.5404129, 10.31375122], [79.54096985, 10.31375122], [79.54096985, 10.31403065], [79.54207611, 10.31403065], [79.54207611, 10.31431198], [79.54264069, 10.31430531], [79.54264069, 10.31458282], [79.54347229, 10.31458282], [79.54347229, 10.3148613], [79.54429626, 10.3148613], [79.54429626, 10.31514072], [79.54514313, 10.31514072], [79.54514313, 10.3154192], [79.54569244, 10.31541729], [79.54569244, 10.31569481], [79.54652405, 10.31569481], [79.54652405, 10.31597328], [79.54736328, 10.31597328], [79.54736328, 10.31624889], [79.54818726, 10.31624889], [79.54818726, 10.31652927], [79.54875183, 10.31652927], [79.54875183, 10.31680965], [79.54958344, 10.31680489], [79.54958344, 10.31708336], [79.54985809, 10.31708145], [79.54985809, 10.31763935], [79.55014038, 10.31763935], [79.55014038, 10.31791973], [79.55041504, 10.31791687], [79.55041504, 10.31847095], [79.55069733, 10.31847095], [79.55069733, 10.31874943], [79.55097198, 10.31874943], [79.55097198, 10.31931019], [79.55124664, 10.31930542], [79.55124664, 10.31958294], [79.55153656, 10.31958103], [79.55153656, 10.32014179], [79.55180359, 10.32013988], [79.55180359, 10.32236195], [79.55153656, 10.32236195], [79.55153656, 10.32515144], [79.55180359, 10.32514], [79.55180359, 10.32569408], [79.55208588, 10.32568932], [79.55208588, 10.32653046], [79.55236053, 10.3265276], [79.55236053, 10.32708359], [79.55264282, 10.32708168], [79.55264282, 10.32792091], [79.55291748, 10.32791805], [79.55291748, 10.32847214], [79.55319214, 10.32847023], [79.55319214, 10.32903004], [79.55374908, 10.32903004], [79.55374908, 10.32931137], [79.55401611, 10.32930756], [79.55430603, 10.32930565], [79.55430603, 10.32958412], [79.55486298, 10.32958412], [79.55486298, 10.32985973], [79.55541992, 10.32985973], [79.55541992, 10.33014011], [79.55568695, 10.33014011], [79.55568695, 10.33042145], [79.55625153, 10.33041573], [79.55625153, 10.3306942], [79.55680847, 10.3306942], [79.55680847, 10.33097172], [79.55735779, 10.33097172], [79.55735779, 10.33125019], [79.5579071, 10.33125019], [79.5579071, 10.33153057], [79.55819702, 10.33153057], [79.55819702, 10.33181095], [79.55874634, 10.33180428], [79.55874634, 10.3320837], [79.55930328, 10.3320837], [79.55930328, 10.33236027], [79.55986023, 10.33236027], [79.55986023, 10.33264065], [79.56153107, 10.33264065], [79.56153107, 10.33292103], [79.56208038, 10.33292103], [79.56208038, 10.33264065], [79.56263733, 10.33264065], [79.56263733, 10.33236027], [79.56291962, 10.33236027], [79.56291962, 10.3320837], [79.56346893, 10.3320837], [79.56346893, 10.33236027], [79.56430817, 10.33236027], [79.56430817, 10.3320837], [79.56485748, 10.3320837], [79.56485748, 10.33180428], [79.56624603, 10.33181095], [79.56624603, 10.33153057], [79.56764221, 10.33153057], [79.56764221, 10.33125019], [79.56903076, 10.33125019], [79.56903076, 10.33097172], [79.57041931, 10.33097172], [79.57041931, 10.3306942], [79.57180786, 10.3306942], [79.57180786, 10.33041573], [79.57319641, 10.33042145], [79.57319641, 10.33014011], [79.57430267, 10.33014011], [79.57430267, 10.32985973], [79.57489014, 10.32985973], [79.57541656, 10.32985973], [79.57541656, 10.32958412], [79.57653046, 10.32958412], [79.57653046, 10.32930565], [79.57763672, 10.32931137], [79.57763672, 10.32903004], [79.5790329, 10.32903004], [79.5790329, 10.32874966], [79.58013916, 10.32874966], [79.58013916, 10.32847023], [79.58125305, 10.32847214], [79.58125305, 10.32819366], [79.58235931, 10.32819366], [79.58235931, 10.32791805], [79.58652496, 10.32791805], [79.58652496, 10.32847214], [79.58680725, 10.32847023], [79.58680725, 10.32903004], [79.58708191, 10.32902813], [79.58708191, 10.32958412], [79.58735657, 10.32958031], [79.58735657, 10.33042145], [79.58763885, 10.33041573], [79.58763885, 10.33125019], [79.58791351, 10.33125019], [79.58791351, 10.3320837], [79.5881958, 10.33208179], [79.5881958, 10.33264065], [79.58875275, 10.33263779], [79.58875275, 10.33319378], [79.58847046, 10.33318996], [79.58847046, 10.33403111], [79.58875275, 10.3340292], [79.58875275, 10.33485985], [79.5890274, 10.33485985], [79.5890274, 10.33597279], [79.58930206, 10.33596992], [79.58930206, 10.33708858], [79.58958435, 10.33708286], [79.58958435, 10.33819485], [79.58985901, 10.33819008], [79.58985901, 10.3393116], [79.5901413, 10.33930492], [79.5901413, 10.34013939], [79.58985901, 10.34012985], [79.58985901, 10.34042168], [79.58958435, 10.34041691], [79.58958435, 10.34097099], [79.58930206, 10.34097099], [79.58930206, 10.34125137], [79.5890274, 10.34125137], [79.5890274, 10.34152889], [79.5881958, 10.34152889], [79.5881958, 10.34181023], [79.58791351, 10.34180546], [79.58791351, 10.34208298], [79.5873642, 10.34208298], [79.5873642, 10.34319305], [79.58708191, 10.34319305], [79.58708191, 10.34347343], [79.58625031, 10.34347343], [79.58625031, 10.34291744], [79.58598328, 10.34291935], [79.58598328, 10.34236145], [79.58569336, 10.34236145], [79.58569336, 10.34208298], [79.58430481, 10.34208298], [79.58430481, 10.34180546], [79.58403015, 10.34181023], [79.58403015, 10.34152889], [79.58347321, 10.34152889], [79.58347321, 10.34125137], [79.58207703, 10.34125137], [79.58207703, 10.34152889], [79.58180237, 10.34152889], [79.58180237, 10.34125137], [79.58152008, 10.34125137], [79.58152008, 10.34097099], [79.58097076, 10.34097099], [79.58097076, 10.34125137], [79.57818604, 10.34125137], [79.57818604, 10.34097099], [79.57707977, 10.34097099], [79.57707977, 10.34069538], [79.57624817, 10.34069538], [79.57624817, 10.34097099], [79.57457733, 10.34097099], [79.57458496, 10.34125137], [79.57375336, 10.34125137], [79.57375336, 10.34152889], [79.57319641, 10.34152889], [79.57319641, 10.34181023], [79.57208252, 10.34180546], [79.57208252, 10.34208298], [79.57096863, 10.34208298], [79.57096863, 10.34236145], [79.56986237, 10.34236145], [79.56986237, 10.34264088], [79.56846619, 10.34264088], [79.56846619, 10.34236145], [79.56819153, 10.34236145], [79.56819153, 10.34264088], [79.56764221, 10.34264088], [79.56764221, 10.34291935], [79.56680298, 10.34291744], [79.56680298, 10.34319305], [79.56541443, 10.34319305], [79.56541443, 10.34347343], [79.56430817, 10.34347057], [79.56430817, 10.34375095], [79.56402588, 10.34375095], [79.56402588, 10.34402943], [79.5634613, 10.34402943], [79.5634613, 10.34430981], [79.56291962, 10.34430504], [79.56291962, 10.34458256], [79.56263733, 10.34458256], [79.56263733, 10.34430504], [79.56124878, 10.34430504], [79.56124878, 10.34458256], [79.56014252, 10.34458256], [79.56014252, 10.34486103], [79.55902863, 10.34486103], [79.55902863, 10.34513855], [79.55819702, 10.34513855], [79.55819702, 10.34542179], [79.55708313, 10.34541702], [79.55708313, 10.34569454], [79.55596924, 10.34569454], [79.55596924, 10.34597111], [79.55486298, 10.34597111], [79.55486298, 10.34625244], [79.55374908, 10.34625244], [79.55374908, 10.34653187], [79.55264282, 10.34653187], [79.55264282, 10.34681034], [79.55180359, 10.34680462], [79.55180359, 10.34708309], [79.55014038, 10.34708309], [79.55014038, 10.34736156], [79.54847717, 10.34736156], [79.54847717, 10.34764194], [79.54708099, 10.34764194], [79.54708099, 10.34792042], [79.54514313, 10.34792042], [79.54514313, 10.34764194], [79.54347229, 10.34764194], [79.54347229, 10.34708118], [79.54319763, 10.34708309], [79.54319763, 10.34680462], [79.54292297, 10.34681034], [79.54292297, 10.34625244], [79.54264069, 10.34625244], [79.54264069, 10.34597111], [79.5423584, 10.34597111], [79.5423584, 10.34513855], [79.54264069, 10.34513855], [79.54264069, 10.34402943], [79.54292297, 10.34402943], [79.54292297, 10.34375095], [79.54319763, 10.34375095], [79.54319763, 10.34347057], [79.54347229, 10.34347343], [79.54347229, 10.34208298], [79.54319763, 10.34208298], [79.54319763, 10.34125137], [79.54291534, 10.34125137], [79.54291534, 10.33986092], [79.54319763, 10.33986092], [79.54319763, 10.3395834], [79.54347229, 10.3395834], [79.54347229, 10.33930492], [79.54292297, 10.3393116], [79.54292297, 10.33903122], [79.54264069, 10.33903122], [79.54264069, 10.3393116], [79.54208374, 10.33930492], [79.54208374, 10.3395834], [79.54180908, 10.3395834], [79.54180908, 10.33986092], [79.54152679, 10.33986092], [79.54152679, 10.34042168], [79.54125214, 10.34041691], [79.54125214, 10.34097099], [79.54096985, 10.34097099], [79.54096985, 10.34152889], [79.54069519, 10.34152699], [79.54069519, 10.34208298], [79.5404129, 10.34208298], [79.5404129, 10.34319305], [79.54069519, 10.34319305], [79.54069519, 10.34347343], [79.54096985, 10.34347057], [79.54096985, 10.34402943], [79.54069519, 10.34402657], [79.54069519, 10.34458256], [79.5404129, 10.34458256], [79.5404129, 10.34486103], [79.53985596, 10.34486103], [79.53985596, 10.34513855], [79.5395813, 10.34513855], [79.5395813, 10.34569454], [79.53930664, 10.34569073], [79.53930664, 10.34653187], [79.53902435, 10.3465271], [79.53902435, 10.34708309], [79.53819275, 10.34708309], [79.53819275, 10.34569454], [79.53847504, 10.34569454], [79.53847504, 10.34458256], [79.53874969, 10.34458256], [79.53874969, 10.34430504], [79.53901672, 10.34430981], [79.53901672, 10.34402943], [79.53930664, 10.34402943], [79.53930664, 10.34291935], [79.53874969, 10.34291935], [79.53874969, 10.34236145], [79.53902435, 10.34236145], [79.53902435, 10.34180546], [79.53930664, 10.34181023], [79.53930664, 10.34125137], [79.5395813, 10.34125137], [79.5395813, 10.34069538], [79.53986359, 10.34069538], [79.53986359, 10.3395834], [79.54013824, 10.3395834], [79.54013824, 10.33847332], [79.54096985, 10.33847141], [79.54096985, 10.33903122], [79.54152679, 10.33903122], [79.54152679, 10.33847141], [79.54235077, 10.33847141], [79.54235077, 10.33875084], [79.54347229, 10.33875084], [79.54347229, 10.33847141], [79.54374695, 10.33847332], [79.54374695, 10.33819485], [79.54347229, 10.33819485], [79.54347229, 10.33763885], [79.54291534, 10.33763885], [79.54291534, 10.33736134], [79.5423584, 10.33736134], [79.5423584, 10.33708477], [79.54207611, 10.33708858], [79.54207611, 10.33681107], [79.54152679, 10.33681107], [79.54152679, 10.33653069], [79.5404129, 10.33653069], [79.5404129, 10.33681107], [79.54013824, 10.33681107], [79.54013824, 10.33708858], [79.53986359, 10.33708477], [79.53986359, 10.33736134], [79.5395813, 10.33736134], [79.5395813, 10.33763885], [79.53930664, 10.33763885], [79.53930664, 10.33791924], [79.53653717, 10.33791924], [79.53653717, 10.33763885], [79.53624725, 10.33763885], [79.53624725, 10.33736134], [79.53514099, 10.33736134], [79.53514099, 10.33708477], [79.5348587, 10.33708858], [79.5348587, 10.33681107], [79.53457642, 10.33681107], [79.53457642, 10.33596992], [79.53430176, 10.33597279], [79.53430176, 10.33569527], [79.53458405, 10.33569527], [79.53458405, 10.33541679], [79.5348587, 10.33542061], [79.5348587, 10.33514118], [79.53514099, 10.33514118], [79.53514099, 10.33458042], [79.53541565, 10.33458233], [79.53541565, 10.3340292], [79.53569794, 10.33403111], [79.53569794, 10.33375072], [79.53624725, 10.33375072], [79.53624725, 10.33318996], [79.53652954, 10.33319378], [79.53652954, 10.33291626], [79.53679657, 10.33292103], [79.53679657, 10.33264065], [79.53708649, 10.33264065], [79.53708649, 10.33236027], [79.53736115, 10.33236027], [79.53736115, 10.3320837], [79.53791809, 10.3320837], [79.53791809, 10.33180428], [79.53819275, 10.33181095], [79.53819275, 10.33153057], [79.53874969, 10.33153057], [79.53874969, 10.33125019], [79.53902435, 10.33125019], [79.53901672, 10.33096123], [79.53930664, 10.33097172], [79.53930664, 10.3306942], [79.5395813, 10.3306942], [79.5395813, 10.33041573], [79.53985596, 10.33042145], [79.53985596, 10.33014011], [79.54013824, 10.33014011], [79.54013824, 10.32958031], [79.5404129, 10.32958412], [79.5404129, 10.32930565], [79.54070282, 10.32931137], [79.54070282, 10.32903004], [79.54096985, 10.32903004], [79.54096985, 10.32874966], [79.54125214, 10.32874966], [79.54125214, 10.32847023], [79.54152679, 10.32847214], [79.54152679, 10.32791805], [79.54180908, 10.32792091], [79.54180908, 10.32708168], [79.54208374, 10.32708359], [79.54208374, 10.3265276], [79.54235077, 10.32653046], [79.54235077, 10.3259697], [79.54264069, 10.3259716], [79.54264069, 10.32569408], [79.54291534, 10.32569408], [79.54291534, 10.32541561], [79.54319763, 10.32542038], [79.54319763, 10.32515144], [79.54347229, 10.32515144], [79.54347229, 10.3243103], [79.54070282, 10.3243103], [79.54070282, 10.32264042], [79.53874969, 10.32264042], [79.53874969, 10.32236195], [79.53791809, 10.32236195], [79.53791809, 10.32208443], [79.53736115, 10.32209015], [79.53736115, 10.32180977], [79.53542328, 10.32180977], [79.53542328, 10.32209015], [79.5348587, 10.32208443], [79.5348587, 10.32236195], [79.53235626, 10.32236195], [79.53235626, 10.32209015], [79.53125, 10.32209015], [79.53125, 10.32180977], [79.52986145, 10.32180977], [79.52986145, 10.32153034], [79.52874756, 10.32153034], [79.52874756, 10.32125187], [79.5284729, 10.32125187], [79.5284729, 10.32097054], [79.52819824, 10.32097054], [79.52819061, 10.32069588], [79.5276413, 10.32069302], [79.5276413, 10.32041836], [79.52735138, 10.32042027], [79.52735138, 10.32014179], [79.52680206, 10.32014179], [79.52680206, 10.31986141], [79.52625275, 10.31986141], [79.52625275, 10.31930542], [79.52597046, 10.31931019], [79.52597046, 10.31874943], [79.5256958, 10.31874943], [79.5256958, 10.31847095], [79.52347565, 10.31847095], [79.52347565, 10.31874943], [79.52319336, 10.31874943], [79.52319336, 10.31902695], [79.5229187, 10.31902027], [79.5229187, 10.31931019], [79.52263641, 10.31930542], [79.52263641, 10.31958294], [79.52236176, 10.31958294], [79.52236176, 10.31986141], [79.5220871, 10.31986141], [79.5220871, 10.32014179], [79.52097321, 10.32014179], [79.52097321, 10.32042027], [79.52041626, 10.32041836], [79.52041626, 10.32069302], [79.51930237, 10.32069302], [79.51930237, 10.32041836], [79.51597595, 10.32041836], [79.51597595, 10.32069302], [79.51541901, 10.32069588], [79.51541901, 10.32097054], [79.51509857, 10.32097054], [79.51486206, 10.32097054], [79.51486206, 10.32114029], [79.51486206, 10.32125187], [79.51467896, 10.32124901], [79.51457977, 10.32124901], [79.51457977, 10.32153034], [79.5141449, 10.32157803], [79.51403046, 10.32159138], [79.51403046, 10.32180977], [79.51361847, 10.32180595], [79.51350403, 10.32186508], [79.51346588, 10.32209015], [79.51308441, 10.32208443], [79.51291656, 10.32208443], [79.51291656, 10.32217026], [79.51291656, 10.32236195], [79.51255035, 10.32236195], [79.51238251, 10.32242584], [79.51236725, 10.32264042], [79.5120163, 10.3226366], [79.51180267, 10.3226366], [79.51180267, 10.32272625], [79.51180267, 10.32291985], [79.51147461, 10.32291794], [79.51125336, 10.32291794], [79.51125336, 10.32300663], [79.51125336, 10.32319355], [79.51097107, 10.32319355], [79.51097107, 10.32347202], [79.51040649, 10.32347202], [79.51040649, 10.32374954], [79.50985718, 10.32376099], [79.50985718, 10.32402992], [79.50933075, 10.32402992], [79.50930786, 10.3243103], [79.50872803, 10.32430553], [79.50819397, 10.32430553], [79.50819397, 10.32458401], [79.50808716, 10.32458401], [79.50763702, 10.32458401], [79.50763702, 10.32486153], [79.50744629, 10.32486153], [79.50736237, 10.32486153], [79.50736237, 10.32515144], [79.50708008, 10.32514], [79.50708008, 10.32569408], [79.50736237, 10.32568932], [79.50736237, 10.32653046], [79.50763702, 10.3265276], [79.50763702, 10.32736206], [79.50818634, 10.32736015], [79.50818634, 10.32763958], [79.5090332, 10.32763958], [79.5090332, 10.32792091], [79.51013947, 10.32792091], [79.51013947, 10.32763958], [79.51040649, 10.32763958], [79.51040649, 10.32736015], [79.51069641, 10.32736206], [79.51069641, 10.32708359], [79.51097107, 10.32708359], [79.51097107, 10.32680607], [79.51152802, 10.32681274], [79.51152802, 10.32653046], [79.51180267, 10.32653046], [79.51180267, 10.32625008], [79.51486206, 10.32625008], [79.51486206, 10.3259697], [79.51625061, 10.3259716], [79.51625061, 10.32569408], [79.51763916, 10.32569408], [79.51763916, 10.32541561], [79.51902771, 10.32542038], [79.51902771, 10.32515144], [79.52041626, 10.32515144], [79.52041626, 10.32542038], [79.52097321, 10.32542038], [79.52097321, 10.32515144], [79.52153778, 10.32515144], [79.52153778, 10.32542038], [79.5220871, 10.32542038], [79.5220871, 10.32515144], [79.52236176, 10.32515144], [79.52236176, 10.32542038], [79.52319336, 10.32541561], [79.52319336, 10.3259716], [79.5229187, 10.3259697], [79.5229187, 10.32625008], [79.52263641, 10.32625008], [79.52263641, 10.32681274], [79.52236176, 10.32680607], [79.52236176, 10.32708359], [79.52263641, 10.32708359], [79.52263641, 10.32736206], [79.5229187, 10.32736015], [79.5229187, 10.32763958], [79.52319336, 10.32763958], [79.52319336, 10.32792091], [79.52401733, 10.32792091], [79.52401733, 10.32763958], [79.52458191, 10.32763958], [79.52458191, 10.32736015], [79.52513885, 10.32736206], [79.52513885, 10.32514], [79.52540588, 10.32515144], [79.52540588, 10.32485962], [79.5256958, 10.32486153], [79.5256958, 10.32458401], [79.5284729, 10.32457924], [79.5284729, 10.32625008], [79.52874756, 10.32625008], [79.52874756, 10.32708359], [79.52902985, 10.32708168], [79.52902985, 10.32763958], [79.52958679, 10.32763767], [79.52958679, 10.32819366], [79.5293045, 10.32819366], [79.5293045, 10.32847214], [79.52902985, 10.32847023], [79.52902985, 10.32931137], [79.5284729, 10.32930565], [79.5284729, 10.32958412], [79.52819824, 10.32958412], [79.52819824, 10.32985973], [79.5276413, 10.32985973], [79.5276413, 10.33014011], [79.52735138, 10.33014011], [79.52735138, 10.33042145], [79.5265274, 10.33042145], [79.5265274, 10.33014011], [79.52540588, 10.33014011], [79.52540588, 10.33042145], [79.5248642, 10.33041573], [79.5248642, 10.3306942], [79.52180481, 10.3306942], [79.52180481, 10.33041573], [79.52124786, 10.33042145], [79.52124786, 10.33014011], [79.52097321, 10.33014011], [79.52097321, 10.32985973], [79.52041626, 10.32985973], [79.52041626, 10.32958412], [79.5201416, 10.32958412], [79.5201416, 10.32930565], [79.51985931, 10.32931137], [79.51985931, 10.32874966], [79.51957703, 10.32874966], [79.51957703, 10.32903004], [79.51930237, 10.32903004], [79.51930237, 10.32874966], [79.51902771, 10.32874966], [79.51902771, 10.32847023], [79.51875305, 10.32847214], [79.51875305, 10.32819366], [79.51819611, 10.32819366], [79.51819611, 10.32791805], [79.51790619, 10.32792091], [79.51790619, 10.32763958], [79.51735687, 10.32763958], [79.51735687, 10.32736015], [79.51600647, 10.32736015], [79.51568604, 10.32736015], [79.51568604, 10.32763958], [79.5150528, 10.32763767], [79.51457977, 10.32763767], [79.51457977, 10.32778072], [79.51457977, 10.32792091], [79.51430511, 10.32791805], [79.51430511, 10.32819366], [79.51319122, 10.32819366], [79.51319122, 10.32847214], [79.51264191, 10.32847023], [79.51264191, 10.32874966], [79.51236725, 10.32874966], [79.51236725, 10.32903004], [79.51207733, 10.32903004], [79.51207733, 10.32931137], [79.51152802, 10.32930565], [79.51152802, 10.32958412], [79.51097107, 10.32958412], [79.51097107, 10.32985973], [79.51040649, 10.32985973], [79.51040649, 10.33042145], [79.50985718, 10.33042145], [79.50985718, 10.33153057], [79.51180267, 10.33152771], [79.51180267, 10.3320837], [79.51235962, 10.3320837], [79.51235962, 10.33236027], [79.51291656, 10.33236027], [79.51291656, 10.33264065], [79.51346588, 10.33264065], [79.51346588, 10.33292103], [79.51374817, 10.33291626], [79.51374817, 10.33319378], [79.51403046, 10.33318996], [79.51403046, 10.33375072], [79.51430511, 10.33375072], [79.51430511, 10.33458233], [79.51403046, 10.33458233], [79.51403046, 10.33485985], [79.51374817, 10.33485985], [79.51374817, 10.33542061], [79.51346588, 10.33542061], [79.51347351, 10.33625126], [79.51319122, 10.33625126], [79.51319122, 10.33653069], [79.51291656, 10.33653069], [79.51291656, 10.33708858], [79.51264191, 10.33708477], [79.51264191, 10.33736134], [79.51235962, 10.33736134], [79.51235962, 10.33763885], [79.51180267, 10.33763885], [79.51180267, 10.33736134], [79.51069641, 10.33736134], [79.51069641, 10.33763885], [79.51040649, 10.33763885], [79.51040649, 10.33791924], [79.51013947, 10.33791733], [79.51013947, 10.33819485], [79.50977325, 10.33819485], [79.50958252, 10.33819485], [79.50958252, 10.33847332], [79.50819397, 10.33847332], [79.50819397, 10.33819485], [79.50763702, 10.33819485], [79.50763702, 10.33791733], [79.50708008, 10.33791924], [79.50708008, 10.33763885], [79.50653076, 10.33763885], [79.50653076, 10.33736134], [79.50624847, 10.33736134], [79.50624847, 10.33652878], [79.50541687, 10.33653069], [79.50541687, 10.33625126], [79.50514221, 10.33625126], [79.50514221, 10.33569527], [79.50430298, 10.33569527], [79.50430298, 10.33541679], [79.50402832, 10.33541679], [79.50402832, 10.33569527], [79.50375366, 10.33569527], [79.50375366, 10.33541679], [79.50347137, 10.33542061], [79.50347137, 10.33485985], [79.50319672, 10.33485985], [79.50319672, 10.33458233], [79.50291443, 10.33458233], [79.50291443, 10.3340292], [79.50235748, 10.33403111], [79.50235748, 10.33375072], [79.50180817, 10.33375072], [79.50180817, 10.33318996], [79.50152588, 10.33319378], [79.50152588, 10.33263779], [79.50180817, 10.33264065], [79.50180817, 10.33208179], [79.50180817, 10.33152771], [79.50208282, 10.33153057], [79.50208282, 10.32985973], [79.50235748, 10.32985973], [79.50235748, 10.32958412], [79.50263977, 10.32958412], [79.50263977, 10.32930565], [79.50514221, 10.32931137], [79.50514221, 10.32903004], [79.50541687, 10.32903004], [79.50541687, 10.3281889], [79.50514221, 10.32819366], [79.50514221, 10.32586002], [79.50514221, 10.32319355], [79.50485992, 10.32319355], [79.50485992, 10.3226366], [79.5045929, 10.32264042], [79.5045929, 10.32209015], [79.50402832, 10.32209015], [79.50402832, 10.32180977], [79.50374603, 10.32180977], [79.50374603, 10.32153034], [79.50319672, 10.32153034], [79.50319672, 10.32125187], [79.50263977, 10.32125187], [79.50263977, 10.32097054], [79.50208282, 10.32097054], [79.50208282, 10.32069588], [79.50180817, 10.32069302], [79.50180817, 10.32041836], [79.50125122, 10.32042027], [79.50125122, 10.32014179], [79.49931335, 10.32014179], [79.49931335, 10.32042027], [79.49847412, 10.32041836], [79.49847412, 10.32069302], [79.49736023, 10.32069588], [79.49736023, 10.32097054], [79.49652863, 10.32097054], [79.49652863, 10.32125187], [79.49569702, 10.32125187], [79.49569702, 10.32153034], [79.49514008, 10.32153034], [79.49514008, 10.32209015], [79.4954071, 10.32209015], [79.4954071, 10.32264042], [79.49569702, 10.3226366], [79.49569702, 10.32347202], [79.49597168, 10.32347202], [79.49597168, 10.32486153], [79.49624634, 10.32485962], [79.49624634, 10.32542038], [79.49652863, 10.32541561], [79.49652863, 10.32736206], [79.49680328, 10.32736206], [79.49680328, 10.32819366], [79.49652863, 10.32819366], [79.49652863, 10.32791805], [79.49624634, 10.32792091], [79.49624634, 10.32763958], [79.49597168, 10.32763958], [79.49597168, 10.32708168], [79.49569702, 10.32708359], [79.49569702, 10.32680607], [79.4954071, 10.32681274], [79.4954071, 10.32653046], [79.49514008, 10.32653046], [79.49514008, 10.32625008], [79.49485779, 10.32625008], [79.49485779, 10.3259697], [79.49458313, 10.3259716], [79.49458313, 10.32541561], [79.49430084, 10.32542038], [79.49430084, 10.32515144], [79.49402618, 10.32515144], [79.49402618, 10.32347202], [79.49375153, 10.32347202], [79.49375153, 10.32236195], [79.49402618, 10.32236195], [79.49402618, 10.32208443], [79.49430084, 10.32209015], [79.49430084, 10.32153034], [79.49458313, 10.32153034], [79.49458313, 10.32097054], [79.49485779, 10.32097054], [79.49485779, 10.32013988], [79.49514008, 10.32014179], [79.49514008, 10.31986141], [79.49541473, 10.31986141], [79.49541473, 10.31958294], [79.49569702, 10.31958294], [79.49569702, 10.31902695], [79.49597168, 10.31902695], [79.49597168, 10.31874943], [79.49541473, 10.31874943], [79.49541473, 10.31902695], [79.49485779, 10.31902027], [79.49485779, 10.31931019], [79.49458313, 10.31930542], [79.49458313, 10.31958294], [79.49402618, 10.31958294], [79.49402618, 10.31986141], [79.49346924, 10.31986141], [79.49346924, 10.32014179], [79.49291992, 10.32014179], [79.49291992, 10.32042027], [79.49263763, 10.32041836], [79.49263763, 10.32069111], [79.49236298, 10.32069969], [79.49236298, 10.32125187], [79.49208069, 10.32125187], [79.49208069, 10.32209015], [79.49236298, 10.32208443], [79.49236298, 10.32236195], [79.49263763, 10.32236195], [79.49263763, 10.32264042], [79.49291992, 10.32264042], [79.49291992, 10.32374954], [79.49208069, 10.32374954], [79.49208069, 10.32402992], [79.49180603, 10.32402992], [79.49180603, 10.3243103], [79.49013519, 10.32430553], [79.49013519, 10.32458401], [79.48958588, 10.32458401], [79.48958588, 10.32486153], [79.48874664, 10.32485962], [79.48874664, 10.32515144], [79.48764038, 10.32514], [79.48764038, 10.32569408], [79.48791504, 10.32569408], [79.48791504, 10.3259716], [79.48819733, 10.3259697], [79.48819733, 10.32625008], [79.48847198, 10.32625008], [79.48847198, 10.32736206], [79.48819733, 10.32736015], [79.48819733, 10.32763958], [79.48764038, 10.32763958], [79.48764038, 10.32792091], [79.48735809, 10.32791805], [79.48735809, 10.32847214], [79.48764038, 10.32847023], [79.48764038, 10.32874966], [79.48902893, 10.32874966], [79.48902893, 10.32847023], [79.48958588, 10.32847214], [79.48958588, 10.32819366], [79.49013519, 10.32819366], [79.49013519, 10.32847214], [79.49124908, 10.32847214], [79.49124908, 10.32819366], [79.49236298, 10.32819366], [79.49236298, 10.32791805], [79.49318695, 10.32792091], [79.49318695, 10.32763958], [79.49430084, 10.32763958], [79.49430084, 10.32792091], [79.49458313, 10.32791805], [79.49458313, 10.32847214], [79.49485779, 10.32847214], [79.49485779, 10.3303318], [79.49485779, 10.3306942], [79.49402618, 10.3306942], [79.49402618, 10.33097172], [79.49337006, 10.33097172], [79.49319458, 10.33097172], [79.49319458, 10.3306942], [79.49263763, 10.3306942], [79.49263763, 10.33041573], [79.49236298, 10.33042145], [79.49236298, 10.33014011], [79.49208069, 10.33014011], [79.49208069, 10.32985973], [79.49124146, 10.32985973], [79.49124146, 10.32931137], [79.48930359, 10.32930565], [79.48930359, 10.32958412], [79.48874664, 10.32958412], [79.48874664, 10.32985973], [79.48792267, 10.32985973], [79.48792267, 10.33014011], [79.48735809, 10.33013821], [79.48735809, 10.3306942], [79.48707581, 10.33069038], [79.48708344, 10.33125019], [79.48680878, 10.33125019], [79.48680878, 10.33181095], [79.48652649, 10.33180428], [79.48652649, 10.33236027], [79.48680878, 10.33236027], [79.48680878, 10.33264065], [79.48625183, 10.33264065], [79.48625183, 10.33375072], [79.48596954, 10.33375072], [79.48596954, 10.33403111], [79.48652649, 10.3340292], [79.48652649, 10.3353796], [79.48652649, 10.33569527], [79.48603058, 10.33569527], [79.48569489, 10.33569527], [79.48561859, 10.33591557], [79.48208618, 10.33597279], [79.48208618, 10.33625126], [79.48179626, 10.33625126], [79.48179626, 10.33653069], [79.48014069, 10.33653069], [79.48014069, 10.33625126], [79.4798584, 10.33625126], [79.4798584, 10.33597279], [79.47958374, 10.33597279], [79.47958374, 10.33569527], [79.47930908, 10.33569527], [79.47930908, 10.33541679], [79.47902679, 10.33542061], [79.47902679, 10.33514118], [79.47763824, 10.33513927], [79.47763824, 10.33569527], [79.47736359, 10.33569527], [79.47736359, 10.33597279], [79.47680664, 10.33597279], [79.47680664, 10.33625126], [79.47625732, 10.33625126], [79.47625732, 10.33653069], [79.4751358, 10.33653069], [79.4751358, 10.33681107], [79.47402954, 10.33681107], [79.47402954, 10.33653069], [79.4715271, 10.33653069], [79.4715271, 10.33681107], [79.47097015, 10.33680534], [79.47097015, 10.33736134], [79.4706955, 10.33736134], [79.4706955, 10.33763885], [79.47041321, 10.33763885], [79.47041321, 10.33819485], [79.47013855, 10.33819485], [79.47013855, 10.33847332], [79.46985626, 10.33847141], [79.46985626, 10.33903122], [79.4695816, 10.33903122], [79.4695816, 10.3393116], [79.46902466, 10.33930492], [79.46902466, 10.3395834], [79.46847534, 10.3395834], [79.46847534, 10.33986092], [79.4679184, 10.33986092], [79.4679184, 10.34013939], [79.46569824, 10.34013939], [79.46569061, 10.33986092], [79.46541595, 10.33986092], [79.46541595, 10.3395834], [79.4651413, 10.3395834], [79.4651413, 10.33930492], [79.46235657, 10.3393116], [79.46235657, 10.33903122], [79.46208191, 10.33903122], [79.46208191, 10.33875084], [79.46180725, 10.33875084], [79.46180725, 10.33847141], [79.46152496, 10.33847332], [79.46152496, 10.33819485], [79.46125031, 10.33819485], [79.46125031, 10.33791733], [79.4576416, 10.33791924], [79.4576416, 10.33875084], [79.45735931, 10.33875084], [79.45735931, 10.34013939], [79.45708466, 10.34013939], [79.45708466, 10.34069538], [79.45680237, 10.34069538], [79.45680237, 10.34097099], [79.45652771, 10.34097099], [79.45652771, 10.34152889], [79.45625305, 10.34152699], [79.45625305, 10.34208298], [79.45597076, 10.34208298], [79.45597076, 10.34152699], [79.45569611, 10.34152889], [79.45569611, 10.33986092], [79.45540619, 10.33986092], [79.45540619, 10.33875084], [79.45513153, 10.33875084], [79.45513153, 10.33791924], [79.45485687, 10.33791924], [79.45485687, 10.33653069], [79.45513153, 10.33653069], [79.45513153, 10.33625126], [79.45569611, 10.33625126], [79.45569611, 10.33653069], [79.45847321, 10.33653069], [79.45847321, 10.33596992], [79.45874786, 10.33597279], [79.45874786, 10.33513927], [79.45903015, 10.33514118], [79.45903015, 10.33542061], [79.45930481, 10.33541679], [79.45930481, 10.33597279], [79.4595871, 10.33597279], [79.4595871, 10.33625126], [79.45986176, 10.33625126], [79.45986176, 10.33653069], [79.46013641, 10.33653069], [79.46013641, 10.33681107], [79.4604187, 10.33681107], [79.4604187, 10.33708858], [79.46153259, 10.33708858], [79.46153259, 10.33681107], [79.46180725, 10.33681107], [79.46180725, 10.33653069], [79.46235657, 10.33653069], [79.46235657, 10.33625126], [79.46263885, 10.33625126], [79.46263885, 10.33763885], [79.4631958, 10.33763885], [79.4631958, 10.33791924], [79.46375275, 10.33791733], [79.46375275, 10.33819485], [79.46430206, 10.33819485], [79.46430206, 10.33847332], [79.46485901, 10.33847141], [79.46485901, 10.33875084], [79.46541595, 10.33875084], [79.46541595, 10.33903122], [79.46652985, 10.33903122], [79.46652985, 10.33875084], [79.46679688, 10.33875084], [79.46679688, 10.33819008], [79.46708679, 10.33819485], [79.46708679, 10.33791733], [79.46736145, 10.33791924], [79.46736145, 10.33763885], [79.46763611, 10.33763885], [79.46763611, 10.33708286], [79.4679184, 10.33708858], [79.4679184, 10.33653069], [79.46848297, 10.33653069], [79.46848297, 10.33596992], [79.46875, 10.33597279], [79.46875, 10.33569527], [79.47597504, 10.33569527], [79.47597504, 10.33541679], [79.47625732, 10.33542061], [79.47625732, 10.33514118], [79.47680664, 10.33514118], [79.47680664, 10.33485985], [79.4770813, 10.33485985], [79.4770813, 10.33458233], [79.47763824, 10.33458233], [79.47763824, 10.33430672], [79.4779129, 10.33431053], [79.4779129, 10.33403111], [79.48069763, 10.33403111], [79.48069763, 10.33375072], [79.48097229, 10.33375072], [79.48097229, 10.33347034], [79.48124695, 10.33347225], [79.48124695, 10.33319378], [79.48152924, 10.33319378], [79.48152924, 10.33263779], [79.48179626, 10.33264065], [79.48179626, 10.33181095], [79.48208618, 10.33181095], [79.48208618, 10.33125019], [79.48236084, 10.33125019], [79.48236084, 10.3306942], [79.4826355, 10.3306942], [79.4826355, 10.33013821], [79.48291779, 10.33014011], [79.48291779, 10.32985973], [79.48319244, 10.32985973], [79.48319244, 10.32958412], [79.48347473, 10.32958412], [79.48347473, 10.32902813], [79.48374939, 10.32903004], [79.48374939, 10.32874966], [79.48401642, 10.32874966], [79.48401642, 10.32847023], [79.48430634, 10.32847214], [79.48430634, 10.32819366], [79.48458099, 10.32819366], [79.48458099, 10.32791805], [79.48486328, 10.32792091], [79.48486328, 10.32763958], [79.48513794, 10.32763958], [79.48513794, 10.32736015], [79.48542023, 10.32736206], [79.48542023, 10.32708359], [79.48569489, 10.32708359], [79.48569489, 10.32680607], [79.48596954, 10.32681274], [79.48596954, 10.32653046], [79.48625183, 10.32653046], [79.48625183, 10.32625008], [79.48652649, 10.32625008], [79.48652649, 10.3259697], [79.48625183, 10.3259716], [79.48625183, 10.32541561], [79.48596954, 10.32542038], [79.48596954, 10.32485962], [79.48402405, 10.32486153], [79.48402405, 10.32458401], [79.48319244, 10.32458401], [79.48319244, 10.32430553], [79.48097229, 10.3243103], [79.48097229, 10.32402992], [79.47875214, 10.32402992], [79.47875214, 10.3243103], [79.47846985, 10.32430553], [79.47846985, 10.32458401], [79.47680664, 10.32458401], [79.47680664, 10.32486153], [79.47625732, 10.32485962], [79.47625732, 10.32515144], [79.47569275, 10.32515144], [79.47569275, 10.32542038], [79.47541809, 10.32541561], [79.47541809, 10.32569408], [79.4751358, 10.32569408], [79.4751358, 10.3259716], [79.47291565, 10.3259716], [79.47291565, 10.32569408], [79.47125244, 10.32569408], [79.47125244, 10.32541561], [79.47097015, 10.32542038], [79.47097015, 10.32485962], [79.4679184, 10.32485962], [79.4679184, 10.32515144], [79.46624756, 10.32515144], [79.46624756, 10.32542038], [79.46290588, 10.32542038], [79.46290588, 10.32515144], [79.46069336, 10.32515144], [79.46069336, 10.32542038], [79.4604187, 10.32541561], [79.4604187, 10.3259716], [79.46013641, 10.3259697], [79.46013641, 10.32653046], [79.45986176, 10.3265276], [79.45986176, 10.32708359], [79.45819092, 10.32708359], [79.45819092, 10.32625008], [79.45791626, 10.32625008], [79.45791626, 10.32515144], [79.45735931, 10.32515144], [79.45735931, 10.3243103], [79.4576416, 10.3243103], [79.4576416, 10.32153034], [79.45707703, 10.32153034], [79.45707703, 10.32097054], [79.45680237, 10.32097054], [79.45680237, 10.32069302], [79.45708466, 10.32069302], [79.45708466, 10.32041836], [79.46069336, 10.32042027], [79.46069336, 10.32014179], [79.46153259, 10.32014179], [79.46153259, 10.31986141], [79.46263885, 10.31986141], [79.46263885, 10.31958294], [79.46347046, 10.31958294], [79.46347046, 10.31930542], [79.4679184, 10.31931019], [79.4679184, 10.31902027], [79.47041321, 10.31902695], [79.47041321, 10.31874943], [79.4723587, 10.31874943], [79.4723587, 10.31847095], [79.47374725, 10.31847095], [79.47374725, 10.31819534], [79.48097229, 10.31819534], [79.48097229, 10.31791687], [79.48430634, 10.31791973], [79.48430634, 10.31763935], [79.48542786, 10.31763935], [79.48542786, 10.31736088], [79.48652649, 10.31736088], [79.48652649, 10.31708336], [79.49291992, 10.31708336], [79.49291992, 10.31680489], [79.49764252, 10.31680489], [79.49764252, 10.31708336], [79.49819183, 10.31708336], [79.49819183, 10.31736088], [79.49846649, 10.31736088], [79.49846649, 10.31763935], [79.49931335, 10.31763935], [79.49931335, 10.31624889], [79.50125122, 10.31624889], [79.50125122, 10.31597328], [79.50347137, 10.31597328], [79.50347137, 10.31569481], [79.50541687, 10.31569481], [79.50541687, 10.31541729], [79.50763702, 10.3154192], [79.50763702, 10.31514072], [79.51374817, 10.31514072], [79.51374817, 10.3154192], [79.51430511, 10.31541729], [79.51430511, 10.31569481], [79.51541901, 10.31569481], [79.51541901, 10.31597328], [79.51597595, 10.31597328], [79.51597595, 10.31624889], [79.51763916, 10.31624889], [79.51763916, 10.31597328], [79.51791382, 10.31597328], [79.51791382, 10.31541729], [79.51819611, 10.3154192], [79.51819611, 10.31514072], [79.51790619, 10.31514072], [79.51790619, 10.3148613], [79.51763916, 10.3148613], [79.51763916, 10.31458282], [79.51708221, 10.31458282], [79.51708221, 10.31430531], [79.51680756, 10.31431198], [79.51680756, 10.31403065], [79.5165329, 10.31403065], [79.5165329, 10.31375122], [79.51625061, 10.31375122], [79.51625061, 10.31347084], [79.51568604, 10.31347084], [79.51568604, 10.31319046], [79.51541901, 10.31319523], [79.51541901, 10.31291676], [79.51513672, 10.31292152], [79.51513672, 10.31264114], [79.51486206, 10.31264114], [79.51486206, 10.31235886], [79.51457977, 10.31236076], [79.51457977, 10.31180477], [79.51431274, 10.3118124], [79.51431274, 10.31153107], [79.51403046, 10.31153107], [79.51403046, 10.31125069], [79.51374817, 10.31125069], [79.51374817, 10.31068993], [79.51347351, 10.31069469], [79.51347351, 10.31041718], [79.51319122, 10.31042099], [79.51319122, 10.31015015], [79.51291656, 10.31015015], [79.51291656, 10.30957985], [79.51264191, 10.30958271], [79.51264191, 10.30930519], [79.51236725, 10.30931091], [79.51236725, 10.30903053], [79.51097107, 10.30903053], [79.51097107, 10.30875111], [79.51013947, 10.30875111], [79.51013947, 10.30847263], [79.50985718, 10.30846977], [79.50986481, 10.30875111], [79.50958252, 10.30875111], [79.50958252, 10.30847263], [79.50680542, 10.30847263], [79.50680542, 10.30875111], [79.50514221, 10.30875111], [79.50514221, 10.30903053], [79.5045929, 10.30903053], [79.5045929, 10.30931091], [79.50402832, 10.30930519], [79.50402832, 10.30958271], [79.50263977, 10.30958271], [79.50263977, 10.30986118], [79.50180817, 10.30986118], [79.50180817, 10.30930519], [79.50125122, 10.30930519], [79.50125122, 10.30958271], [79.50096893, 10.30958271], [79.50096893, 10.30930519], [79.50069427, 10.30930519], [79.50069427, 10.30958271], [79.49986267, 10.30958271], [79.49986267, 10.30986118], [79.49931335, 10.30986118], [79.49931335, 10.31015015], [79.49819183, 10.31015015], [79.49819183, 10.30986118], [79.49791718, 10.30986118], [79.49791718, 10.31015015], [79.49652863, 10.31015015], [79.49652863, 10.30986118], [79.49569702, 10.30986118], [79.49569702, 10.31015015], [79.49263763, 10.31015015], [79.49263763, 10.30986118], [79.49208069, 10.30986118], [79.49208069, 10.31015015], [79.49153137, 10.31015015], [79.49153137, 10.30986118], [79.49069214, 10.30986118], [79.49069214, 10.31015015], [79.48986053, 10.31015015], [79.48986053, 10.31042099], [79.48680878, 10.31041718], [79.48680878, 10.31069469], [79.48097229, 10.31069469], [79.48097229, 10.31097317], [79.4770813, 10.31097126], [79.4770813, 10.31125069], [79.4751358, 10.31125069], [79.4751358, 10.31153107], [79.47319794, 10.31153107], [79.47319794, 10.3118124], [79.4723587, 10.3118124], [79.4723587, 10.31153107], [79.47207642, 10.31153107], [79.47207642, 10.3118124], [79.4706955, 10.31180477], [79.4706955, 10.31208324], [79.46819305, 10.31208324], [79.46819305, 10.31236076], [79.4659729, 10.31235886], [79.4659729, 10.31264114], [79.4651413, 10.31264114], [79.4651413, 10.31235886], [79.46485901, 10.31235886], [79.46485901, 10.31264114], [79.4631958, 10.31264114], [79.4631958, 10.31292152], [79.46180725, 10.31292152], [79.46180725, 10.31264114], [79.46153259, 10.31264114], [79.46153259, 10.31292152], [79.45986176, 10.31291676], [79.45986176, 10.31319523], [79.45707703, 10.31319046], [79.45707703, 10.31347084], [79.45540619, 10.31347084], [79.45540619, 10.31375122], [79.45485687, 10.31375122], [79.45485687, 10.31347084], [79.45458221, 10.31347084], [79.45458221, 10.31375122], [79.45263672, 10.31375122], [79.45263672, 10.31403065], [79.45124817, 10.31403065], [79.45124817, 10.31431198], [79.45041656, 10.31430531], [79.45041656, 10.31458282], [79.44985962, 10.31458282], [79.44985962, 10.31430531], [79.44625092, 10.31431198], [79.44625092, 10.31403065], [79.44541931, 10.31403065], [79.44541931, 10.31375122], [79.44403076, 10.31375122], [79.44403076, 10.31403065], [79.44069672, 10.31403065], [79.44069672, 10.31431198], [79.44041443, 10.31430531], [79.44041443, 10.31458282], [79.44013977, 10.31458282], [79.44013977, 10.3148613], [79.43958282, 10.3148613], [79.43958282, 10.31458282], [79.43930817, 10.31458282], [79.43930817, 10.3148613], [79.43902588, 10.3148613], [79.43902588, 10.31514072], [79.43875122, 10.31514072], [79.43875122, 10.3154192], [79.43708038, 10.31541729], [79.43708038, 10.31569481], [79.43680573, 10.31569481], [79.43680573, 10.31541729], [79.43402863, 10.3154192], [79.43402863, 10.31514072], [79.43319702, 10.31514072], [79.43319702, 10.3148613], [79.4329071, 10.3148613], [79.4329071, 10.31514072], [79.43235779, 10.31514072], [79.43235779, 10.3154192], [79.43041992, 10.3154192], [79.43041992, 10.31514072], [79.43013763, 10.31514072], [79.43013763, 10.3154192], [79.42930603, 10.3154192], [79.42930603, 10.31514072], [79.42791748, 10.31514072], [79.42791748, 10.3154192], [79.42764282, 10.3154192], [79.42764282, 10.31514072], [79.42708588, 10.31514072], [79.42708588, 10.3154192], [79.42652893, 10.31541729], [79.42652893, 10.31569481], [79.42541504, 10.31569481], [79.42541504, 10.31597328], [79.42514038, 10.31597328], [79.42514038, 10.31569481], [79.42485809, 10.31569481], [79.42485809, 10.31597328], [79.42430878, 10.31597328], [79.42430878, 10.31569481], [79.42402649, 10.31569481], [79.42402649, 10.31597328], [79.42346954, 10.31597328], [79.42346954, 10.31624889], [79.42263794, 10.31624889], [79.42263794, 10.31597328], [79.42208099, 10.31597328], [79.42208099, 10.31624889], [79.41819763, 10.31624889], [79.41819763, 10.31652927], [79.41680908, 10.31652927], [79.41680908, 10.31680965], [79.41402435, 10.31680489], [79.41402435, 10.31708336], [79.41347504, 10.31708336], [79.41347504, 10.31680489], [79.4126358, 10.31680489], [79.4126358, 10.31708336], [79.40875244, 10.31708336], [79.40875244, 10.31736088], [79.40847015, 10.31736088], [79.40847015, 10.31680489], [79.4081955, 10.31680489], [79.4081955, 10.31736088], [79.40763855, 10.31736088], [79.40763855, 10.31708336], [79.4070816, 10.31708336], [79.4070816, 10.31736088], [79.40486145, 10.31736088], [79.40486145, 10.31763935], [79.40458679, 10.31763935], [79.40458679, 10.31736088], [79.40291595, 10.31736088], [79.40291595, 10.31763935], [79.4015274, 10.31763935], [79.4015274, 10.31736088], [79.40125275, 10.31736088], [79.40125275, 10.31763935], [79.39903259, 10.31763935], [79.39903259, 10.31736088], [79.39736176, 10.31736088], [79.39736176, 10.31763935], [79.39679718, 10.31763935], [79.39679718, 10.31791973], [79.39485168, 10.31791973], [79.39485168, 10.31763935], [79.39347076, 10.31763935], [79.39347076, 10.31736088], [79.39235687, 10.31736088], [79.39235687, 10.31763935], [79.3915329, 10.31763935], [79.3915329, 10.31736088], [79.39068604, 10.31736088], [79.39068604, 10.31708145], [79.38819122, 10.31708336], [79.38819122, 10.31680489], [79.38709259, 10.31680965], [79.38709259, 10.31652927], [79.38625336, 10.31652927], [79.38625336, 10.31680965], [79.38569641, 10.31680965], [79.38569641, 10.31652927], [79.38513947, 10.31652927], [79.38513947, 10.31624889], [79.38430786, 10.31624889], [79.38430786, 10.31597328], [79.38291931, 10.31597328], [79.38291931, 10.31569481], [79.38236237, 10.31569481], [79.38236237, 10.31541729], [79.38208008, 10.3154192], [79.38208008, 10.31458092], [79.38180542, 10.31458282], [79.38180542, 10.31430531], [79.38153076, 10.31431198], [79.38153076, 10.31375122], [79.38124847, 10.31375122], [79.38124847, 10.31347084], [79.38096619, 10.31347084], [79.38096619, 10.31319046], [79.38069153, 10.31319523], [79.38069153, 10.31291676], [79.38041687, 10.31292152], [79.38041687, 10.31264114], [79.38014221, 10.31264114], [79.38014221, 10.31235886], [79.37985992, 10.31236076], [79.37985992, 10.31180477], [79.3795929, 10.3118124], [79.3795929, 10.31125069], [79.37930298, 10.31125069], [79.37930298, 10.31068993], [79.37902832, 10.31069469], [79.37902832, 10.30986118], [79.37875366, 10.30986118], [79.37875366, 10.3092289], [79.37875366, 10.30875111], [79.37847137, 10.30875111], [79.37847137, 10.30791664], [79.37819672, 10.30792141], [79.37819672, 10.30708027], [79.37791443, 10.30708218], [79.37791443, 10.30680656], [79.37763977, 10.30681133], [79.37763977, 10.30597019], [79.37735748, 10.3059721], [79.37735748, 10.30569363], [79.37763977, 10.30569363], [79.37763977, 10.30513763], [79.37735748, 10.30514145], [79.37735748, 10.30457973], [79.37708282, 10.30458355], [79.37708282, 10.30402756], [79.37680817, 10.30402756], [79.37680817, 10.30347157], [79.37652588, 10.30347157], [79.37652588, 10.30291557], [79.37625122, 10.3029213], [79.37625122, 10.30235958], [79.37596893, 10.30236244], [79.37596893, 10.30208206], [79.37569427, 10.30208206], [79.37569427, 10.30152798], [79.37541962, 10.30153275], [79.37541962, 10.30125046], [79.37513733, 10.30125046], [79.37513733, 10.30069447], [79.37486267, 10.30069447], [79.37486267, 10.30041599], [79.37458038, 10.30042267], [79.37458038, 10.30014038], [79.37431335, 10.30014038], [79.37431335, 10.29957867], [79.37403107, 10.29958439], [79.37403107, 10.29930592], [79.37374878, 10.29931068], [79.37374878, 10.29874992], [79.37346649, 10.29874992], [79.37346649, 10.29846954], [79.37319183, 10.2984724], [79.37319183, 10.29819584], [79.37291718, 10.29819584], [79.37291718, 10.29791641], [79.37264252, 10.29792023], [79.37264252, 10.29763985], [79.37236023, 10.29763985], [79.37236023, 10.29736042], [79.37208557, 10.29736233], [79.37208557, 10.29708385], [79.37180328, 10.29708385], [79.37180328, 10.29680634], [79.37152863, 10.29681015], [79.37152863, 10.29652977], [79.37124634, 10.29652977], [79.37124634, 10.29625034], [79.37097168, 10.29625034], [79.37097168, 10.29597187], [79.37069702, 10.29597187], [79.37069702, 10.29569435], [79.37014008, 10.29569435], [79.37014008, 10.29541779], [79.36985779, 10.29541969], [79.36985779, 10.29514027], [79.36958313, 10.29514027], [79.36958313, 10.29485035], [79.36875153, 10.29485035], [79.36875153, 10.29514027], [79.36846924, 10.29514027], [79.36846924, 10.29569435], [79.36819458, 10.29569435], [79.36819458, 10.29597187], [79.36791229, 10.29597187], [79.36791992, 10.29625034], [79.36763763, 10.29625034], [79.36763763, 10.29681015], [79.36708069, 10.29680634], [79.36708069, 10.29708385], [79.36653137, 10.29708385], [79.36653137, 10.29736233], [79.36624908, 10.29736042], [79.36624908, 10.29763985], [79.3659668, 10.29763985], [79.3659668, 10.29792023], [79.36569214, 10.29791641], [79.36569214, 10.29819584], [79.36541748, 10.29819584], [79.36541748, 10.2984724], [79.36486816, 10.29846954], [79.36486816, 10.29874992], [79.36429596, 10.29874992], [79.36429596, 10.2990303], [79.36402893, 10.2990303], [79.36402893, 10.29931068], [79.36374664, 10.29930592], [79.36374664, 10.29958439], [79.36347198, 10.29958439], [79.36347198, 10.29986191], [79.36319733, 10.29986191], [79.36319733, 10.30014038], [79.36264038, 10.30014038], [79.36264038, 10.30042267], [79.36208344, 10.30041599], [79.36208344, 10.30069447], [79.36125183, 10.3006916], [79.36123657, 10.30098057], [79.36042023, 10.30097198], [79.36042023, 10.30125046], [79.35986328, 10.30125046], [79.35986328, 10.30153275], [79.35930634, 10.30153275], [79.35930634, 10.30181122], [79.35902405, 10.30180645], [79.35902405, 10.30208206], [79.35847473, 10.30208206], [79.35847473, 10.30069447], [79.35902405, 10.30069447], [79.35902405, 10.30041599], [79.35958099, 10.30042267], [79.35958099, 10.30014038], [79.36013794, 10.30014038], [79.36013794, 10.30000973], [79.36013794, 10.29986191], [79.36069489, 10.29986191], [79.36068726, 10.29957867], [79.36096954, 10.29958439], [79.36096954, 10.29930592], [79.36152649, 10.29931068], [79.36152649, 10.2990303], [79.36207581, 10.2990303], [79.36207581, 10.29874992], [79.36264038, 10.29874992], [79.36264038, 10.29846954], [79.36291504, 10.2984724], [79.36291504, 10.29819584], [79.36319733, 10.29819584], [79.36319733, 10.29791641], [79.36347198, 10.29792023], [79.36347198, 10.29763985], [79.36374664, 10.29763985], [79.36374664, 10.29736042], [79.36402893, 10.29736233], [79.36402893, 10.29708385], [79.36430359, 10.29708385], [79.36430359, 10.29680634], [79.36458588, 10.29681015], [79.36458588, 10.29652977], [79.36486816, 10.29652977], [79.36486816, 10.29625034], [79.36513519, 10.29625034], [79.36513519, 10.29569435], [79.36541748, 10.29569435], [79.36541748, 10.29541779], [79.36569214, 10.29541969], [79.36569214, 10.29514027], [79.3659668, 10.29514027], [79.3659668, 10.29458141], [79.36624908, 10.29458427], [79.36624908, 10.2943058], [79.36653137, 10.29430962], [79.36653137, 10.29319096], [79.36624908, 10.29319572], [79.36624908, 10.29263878], [79.3659668, 10.29264164], [79.3659668, 10.29208088], [79.36430359, 10.29208279], [79.36430359, 10.29236126], [79.36291504, 10.29236126], [79.36291504, 10.29208279], [79.36235809, 10.29208279], [79.36235809, 10.29180527], [79.36180878, 10.29181004], [79.36180878, 10.29152966], [79.36125183, 10.29152966], [79.36125183, 10.29124928], [79.36068726, 10.29124928], [79.36068726, 10.29096889], [79.36013794, 10.2909708], [79.36013794, 10.29069328], [79.35958099, 10.29069328], [79.35958099, 10.29041672], [79.35901642, 10.29041958], [79.35901642, 10.2901392], [79.3584671, 10.2901392], [79.3584671, 10.28986073], [79.35791779, 10.28986073], [79.35791779, 10.28958321], [79.35708618, 10.28958321], [79.35708618, 10.28930473], [79.35597229, 10.28931046], [79.35597229, 10.28904057], [79.35514069, 10.28904057], [79.35514069, 10.28875065], [79.35402679, 10.28875065], [79.35402679, 10.28847122], [79.35319519, 10.28847313], [79.35319519, 10.28791714], [79.3529129, 10.28792191], [79.3529129, 10.28764057], [79.35263824, 10.28764057], [79.35263824, 10.28736115], [79.35236359, 10.28736115], [79.35236359, 10.28708267], [79.3520813, 10.28708267], [79.3520813, 10.28652668], [79.35180664, 10.28653145], [79.35180664, 10.28625107], [79.35151672, 10.28625107], [79.35151672, 10.28598022], [79.35098267, 10.28598022], [79.35098267, 10.28625107], [79.35069275, 10.28625107], [79.35069275, 10.28736115], [79.35041809, 10.28736115], [79.35041809, 10.28847313], [79.3501358, 10.28847313], [79.3501358, 10.28958321], [79.34986877, 10.2895813], [79.34986877, 10.2901392], [79.3484726, 10.2901392], [79.3484726, 10.29208279], [79.34874725, 10.29208279], [79.34874725, 10.29319572], [79.34902954, 10.29319572], [79.34902954, 10.29374886], [79.34874725, 10.29374886], [79.34874725, 10.29403019], [79.3484726, 10.29403019], [79.3484726, 10.29430962], [79.34819794, 10.2943058], [79.34819794, 10.29486179], [79.34791565, 10.29486179], [79.34791565, 10.29597187], [79.34764099, 10.29597187], [79.34764099, 10.29541779], [79.3473587, 10.29541969], [79.3473587, 10.29514027], [79.34707642, 10.29514027], [79.34707642, 10.29458141], [79.3473587, 10.29458427], [79.3473587, 10.29180527], [79.34764099, 10.29181004], [79.34764099, 10.29096889], [79.34791565, 10.2909708], [79.34791565, 10.29041672], [79.34764099, 10.29041958], [79.34764099, 10.2901392], [79.3473587, 10.2901392], [79.3473587, 10.2895813], [79.34708405, 10.28958321], [79.34708405, 10.28847313], [79.3473587, 10.28847313], [79.3473587, 10.28819466], [79.34764099, 10.28819466], [79.34764099, 10.28791714], [79.34792328, 10.28792191], [79.34792328, 10.28736115], [79.34764099, 10.28736115], [79.34764099, 10.28708267], [79.3473587, 10.28708267], [79.3473587, 10.28680515], [79.3465271, 10.28681183], [79.3465271, 10.28653145], [79.34541321, 10.28653145], [79.34541321, 10.28681183], [79.34263611, 10.28680515], [79.34263611, 10.28708267], [79.34124756, 10.28708267], [79.34124756, 10.28680515], [79.3401413, 10.28681183], [79.3401413, 10.28653145], [79.33875275, 10.28653145], [79.33875275, 10.28625107], [79.33763885, 10.28625107], [79.33763885, 10.28598022], [79.33680725, 10.28598022], [79.33680725, 10.28569031], [79.33625031, 10.28569508], [79.33625031, 10.2854166], [79.33374786, 10.28542137], [79.33374786, 10.28514099], [79.33319092, 10.28514099], [79.33319092, 10.28486061], [79.33235931, 10.28486061], [79.33235931, 10.28458309], [79.33180237, 10.28458309], [79.33180237, 10.28430462], [79.33097076, 10.28430939], [79.33097076, 10.28403091], [79.33040619, 10.28403091], [79.33040619, 10.28375053], [79.32985687, 10.28375053], [79.32985687, 10.28347111], [79.32930756, 10.28347301], [79.32930756, 10.28319454], [79.32875061, 10.28319454], [79.32875061, 10.28291702], [79.32819366, 10.28291702], [79.32819366, 10.28263855], [79.32763672, 10.28264141], [79.32763672, 10.28236103], [79.32707977, 10.28236103], [79.32707977, 10.28208256], [79.32653046, 10.28208256], [79.32653046, 10.28180695], [79.32596588, 10.28181076], [79.32596588, 10.28153133], [79.32569885, 10.28153133], [79.32569885, 10.28125095], [79.32514191, 10.28125095], [79.32514191, 10.28096962], [79.32485962, 10.28097343], [79.32485962, 10.28069496], [79.32430267, 10.28069496], [79.32430267, 10.28041553], [79.32375336, 10.28042126], [79.32375336, 10.28014088], [79.32347107, 10.28014088], [79.32347107, 10.27985096], [79.32291412, 10.27985954], [79.32291412, 10.27958202], [79.32263947, 10.27958202], [79.32263947, 10.27930737], [79.32208252, 10.27931118], [79.32208252, 10.2790308], [79.3215332, 10.2790308], [79.3215332, 10.27875042], [79.32125092, 10.27875042], [79.32125092, 10.27847195], [79.32096863, 10.27847195], [79.32096863, 10.27819443], [79.32041931, 10.27819443], [79.32041931, 10.27791595], [79.31986237, 10.27792072], [79.31986237, 10.27707958], [79.31958008, 10.27708435], [79.31958008, 10.27652836], [79.31931305, 10.27653122], [79.31931305, 10.27625179], [79.31903076, 10.27625179], [79.31903076, 10.27597046], [79.31819153, 10.27597046], [79.31819153, 10.27625179], [79.31791687, 10.27625179], [79.31791687, 10.27569199], [79.31764221, 10.27569389], [79.31764221, 10.27541637], [79.31735992, 10.27542114], [79.31735992, 10.27514267], [79.31680298, 10.27514267], [79.31680298, 10.27486038], [79.31597137, 10.27486229], [79.31597137, 10.27458382], [79.31569672, 10.27458191], [79.31569672, 10.2743063], [79.3154068, 10.27431107], [79.3154068, 10.27403927], [79.31513977, 10.27403927], [79.31513977, 10.27375031], [79.31485748, 10.27375031], [79.31485748, 10.27347183], [79.31458282, 10.27347183], [79.31458282, 10.27291584], [79.31430817, 10.27291965], [79.31430817, 10.27264023], [79.31402588, 10.27264023], [79.31402588, 10.27235985], [79.31375122, 10.27235985], [79.31375122, 10.27224064], [79.31375122, 10.27208424], [79.31346893, 10.27208424], [79.31346893, 10.27180576], [79.31318665, 10.27180958], [79.31318665, 10.27153015], [79.31291962, 10.27153015], [79.31291962, 10.27124977], [79.31263733, 10.27124977], [79.31263733, 10.27096939], [79.31236267, 10.27097225], [79.31236267, 10.27069378], [79.31208038, 10.27069378], [79.31208038, 10.27041626], [79.31181335, 10.27042007], [79.31181335, 10.27013969], [79.31153107, 10.27013969], [79.31153107, 10.26958084], [79.31124878, 10.2695837], [79.31124878, 10.26902771], [79.31096649, 10.26902962], [79.31096649, 10.26875019], [79.31069183, 10.26875019], [79.31069183, 10.26819324], [79.31041718, 10.26819324], [79.31041718, 10.26764011], [79.31014252, 10.26764202], [79.31014252, 10.26736164], [79.30986023, 10.26736164], [79.30986023, 10.2668047], [79.3095932, 10.26681042], [79.3095932, 10.26625156], [79.30930328, 10.26625156], [79.30930328, 10.2656908], [79.30902863, 10.26569557], [79.30902863, 10.2654171], [79.30874634, 10.26542187], [79.30874634, 10.26486969], [79.30847168, 10.26486969], [79.30847168, 10.26431179], [79.30735779, 10.26430511], [79.30735779, 10.26458263], [79.30680847, 10.26458073], [79.30680847, 10.26486969], [79.30625153, 10.26486969], [79.30625153, 10.26513863], [79.30522156, 10.26513863], [79.30457306, 10.26513863], [79.30457306, 10.26486969], [79.30208588, 10.26486969], [79.30208588, 10.26513863], [79.30179596, 10.26513863], [79.30179596, 10.26486969], [79.30124664, 10.26486969], [79.30124664, 10.26458073], [79.30069733, 10.26458263], [79.30069733, 10.26430511], [79.30042267, 10.26431179], [79.30042267, 10.26402855], [79.30014038, 10.26402855], [79.30014038, 10.26375103], [79.29985809, 10.26375103], [79.29985809, 10.26347065], [79.29930878, 10.26347256], [79.29930878, 10.26319313], [79.29902649, 10.26319313], [79.29902649, 10.26291656], [79.29846954, 10.26292038], [79.29846954, 10.26264095], [79.29792023, 10.26264095], [79.29792023, 10.26236057], [79.29763794, 10.26236057], [79.29763794, 10.26208305], [79.29708099, 10.26208305], [79.29708099, 10.26180458], [79.29680634, 10.2618103], [79.29680634, 10.26153183], [79.29624939, 10.26153183], [79.29624939, 10.26125145], [79.29569244, 10.26125145], [79.29569244, 10.26097107], [79.29541779, 10.26097107], [79.29541779, 10.26069546], [79.29486084, 10.26069546], [79.29486084, 10.26041698], [79.29458618, 10.26041889], [79.29458618, 10.26014137], [79.29429626, 10.26014137], [79.29429626, 10.25986099], [79.29402924, 10.25986099], [79.29402924, 10.259305], [79.29374695, 10.25931168], [79.29374695, 10.2590313], [79.29347229, 10.2590313], [79.29347229, 10.25875092], [79.29319763, 10.25875092], [79.29319763, 10.25847054], [79.29291534, 10.2584734], [79.29291534, 10.25819492], [79.29264069, 10.25819492], [79.29264069, 10.2579174], [79.2923584, 10.25791931], [79.2923584, 10.25736141], [79.29180908, 10.25736141], [79.29180908, 10.25708294], [79.29152679, 10.25708294], [79.29152679, 10.25680542], [79.29125214, 10.25680923], [79.29125214, 10.25652885], [79.29096985, 10.25652885], [79.29096985, 10.25625134], [79.29069519, 10.25625134], [79.29069519, 10.25597286], [79.2904129, 10.25597286], [79.2904129, 10.25541687], [79.28958893, 10.25542068], [79.28958893, 10.25486088], [79.28930664, 10.25486088], [79.28930664, 10.25458241], [79.28902435, 10.25458241], [79.28902435, 10.25430679], [79.28874969, 10.25431061], [79.28874969, 10.25418091], [79.28874969, 10.25402641], [79.28840637, 10.25402927], [79.2876358, 10.25403118], [79.2876358, 10.2537508], [79.28708649, 10.2537508], [79.28708649, 10.25347328], [79.2868042, 10.25347328], [79.2868042, 10.25302982], [79.2868042, 10.25291634], [79.28668976, 10.25291634], [79.28652954, 10.25292969], [79.28652954, 10.2527504], [79.28652954, 10.25236034], [79.28624725, 10.25236034], [79.28624725, 10.25208473], [79.2859726, 10.25208473], [79.2859726, 10.25152779], [79.28569794, 10.25153065], [79.28569794, 10.25069046], [79.28541565, 10.25069427], [79.28541565, 10.2504158], [79.28514099, 10.25042057], [79.28514099, 10.25014019], [79.28430176, 10.25014019], [79.28430176, 10.24986935], [79.2840271, 10.24986935], [79.2840271, 10.24931145], [79.28320313, 10.24931145], [79.28320313, 10.24903011], [79.28291321, 10.24903011], [79.28291321, 10.24874973], [79.28263855, 10.24874973], [79.28263855, 10.24847031], [79.28236389, 10.24847221], [79.28236389, 10.24819374], [79.2820816, 10.24819374], [79.2820816, 10.24791622], [79.28180695, 10.24792099], [79.28180695, 10.24763966], [79.28151703, 10.24763966], [79.28151703, 10.24736023], [79.28097534, 10.24736214], [79.28097534, 10.24680614], [79.28069305, 10.24681091], [79.28069305, 10.24652958], [79.2804184, 10.24652958], [79.2804184, 10.24596977], [79.28013611, 10.24597168], [79.28013611, 10.24569416], [79.27980042, 10.24572563], [79.27986145, 10.24542046], [79.27960205, 10.24539089], [79.27958679, 10.2448616], [79.27928162, 10.2448597], [79.27902985, 10.2448597], [79.27902985, 10.24443054], [79.27902985, 10.24430561], [79.2784729, 10.24431038], [79.2784729, 10.24374104], [79.27819824, 10.24374962], [79.27819061, 10.2434721], [79.2776413, 10.2434721], [79.2776413, 10.24319363], [79.27735901, 10.24319363], [79.27735901, 10.24291801], [79.27707672, 10.24291992], [79.27707672, 10.24263954], [79.27680206, 10.24263954], [79.27680206, 10.24236202], [79.2765274, 10.24236202], [79.2765274, 10.24180603], [79.2756958, 10.24180984], [79.2756958, 10.24153042], [79.27513885, 10.24153042], [79.27513885, 10.24125195], [79.27485657, 10.24125195], [79.27485657, 10.24097061], [79.27458191, 10.24097061], [79.27458191, 10.24069309], [79.27402496, 10.24069309], [79.27402496, 10.24041843], [79.27375031, 10.24042034], [79.27375031, 10.24014187], [79.27348328, 10.24014187], [79.27348328, 10.23958111], [79.27319336, 10.23958302], [79.27319336, 10.23930454], [79.2729187, 10.23931026], [79.2729187, 10.23874855], [79.27263641, 10.23874855], [79.27263641, 10.23819542], [79.27236176, 10.23819542], [79.27236176, 10.23763943], [79.27179718, 10.23763943], [79.27179718, 10.23736095], [79.27152252, 10.23736095], [79.27152252, 10.23680973], [79.27124786, 10.23680973], [79.27124786, 10.23652935], [79.27097321, 10.23652935], [79.27097321, 10.23604202], [79.27087402, 10.23601723], [79.27069092, 10.23597336], [79.27069092, 10.23583031], [79.27069092, 10.23541737], [79.27041626, 10.23542023], [79.27041626, 10.23513889], [79.2701416, 10.23513889], [79.2701416, 10.23458099], [79.26958466, 10.2345829], [79.26958466, 10.23402691], [79.26930237, 10.23403168], [79.26930237, 10.2337513], [79.26902771, 10.2337513], [79.26902771, 10.2331953], [79.26875305, 10.2331953], [79.26875305, 10.23263931], [79.26846313, 10.23264122], [79.26846313, 10.23236084], [79.26790619, 10.23236084], [79.26790619, 10.23124886], [79.26763916, 10.23124886], [79.26763916, 10.22986126], [79.26791382, 10.22986126], [79.26791382, 10.2290287], [79.26819611, 10.22903061], [79.26819611, 10.22819042], [79.26875305, 10.22819519], [79.26875305, 10.22791672], [79.26902771, 10.22792053], [79.26902771, 10.22764111], [79.26930237, 10.22764111], [79.26930237, 10.22681141], [79.26957703, 10.22681141], [79.26957703, 10.22625065], [79.26985931, 10.22625065], [79.26985931, 10.22570133], [79.2701416, 10.22570133], [79.2701416, 10.22514057], [79.27041626, 10.22514057], [79.27041626, 10.22486019], [79.27124786, 10.22486019], [79.27124786, 10.22458363], [79.27153015, 10.22458363], [79.27153015, 10.2243042], [79.2720871, 10.22431087], [79.2720871, 10.22403145], [79.27263641, 10.22403145], [79.27263641, 10.22375011], [79.27319336, 10.22375011], [79.27319336, 10.22346973], [79.27375031, 10.22347164], [79.27375031, 10.22319412], [79.27458191, 10.22319412], [79.27458191, 10.22291565], [79.27540588, 10.22292137], [79.27540588, 10.22264004], [79.2756958, 10.22264004], [79.2756958, 10.22235966], [79.27597046, 10.22235966], [79.27597046, 10.22180557], [79.27625275, 10.22181129], [79.27625275, 10.22152996], [79.27680206, 10.22152996], [79.27680206, 10.22124958], [79.27707672, 10.22124958], [79.27707672, 10.22097015], [79.2784729, 10.22097206], [79.2784729, 10.22069359], [79.28013611, 10.22069359], [79.28013611, 10.21958447], [79.2804184, 10.21958447], [79.2804184, 10.21847153], [79.28069305, 10.21847153], [79.28069305, 10.21763992], [79.28098297, 10.21763992], [79.28098297, 10.21680069], [79.28125, 10.21680641], [79.28125, 10.21374893], [79.28098297, 10.21376133], [79.28098297, 10.21347141], [79.28069305, 10.21347141], [79.28069305, 10.21291542], [79.2804184, 10.21292019], [79.2804184, 10.21263981], [79.28013611, 10.21263981], [79.28013611, 10.21236134], [79.27986145, 10.21236134], [79.27986145, 10.21208286], [79.27958679, 10.21208286], [79.27958679, 10.21180534], [79.27902985, 10.21181011], [79.27902985, 10.21152973], [79.27874756, 10.21152973], [79.27874756, 10.21124935], [79.2784729, 10.21124935], [79.2784729, 10.21097088], [79.27791595, 10.21097088], [79.27791595, 10.21069527], [79.27764893, 10.21070004], [79.27764893, 10.21041965], [79.27735901, 10.21041965], [79.27735901, 10.21013927], [79.27680206, 10.21013927], [79.27680206, 10.20985889], [79.2765274, 10.2098608], [79.2765274, 10.20958328], [79.27597046, 10.20958328], [79.27597046, 10.20930481], [79.2756958, 10.20930958], [79.2756958, 10.2090292], [79.27540588, 10.2090292], [79.27540588, 10.20875072], [79.27485657, 10.20875072], [79.27485657, 10.2084713], [79.27458191, 10.20847321], [79.27458191, 10.20819473], [79.27430725, 10.20819473], [79.27430725, 10.20791721], [79.27375031, 10.20792198], [79.27375031, 10.20763016], [79.27347565, 10.20763874], [79.27347565, 10.20736122], [79.27319336, 10.20736122], [79.27319336, 10.20708275], [79.27263641, 10.20708275], [79.27263641, 10.20680523], [79.27236176, 10.2068119], [79.27236176, 10.20653057], [79.27179718, 10.20653057], [79.27179718, 10.20625114], [79.27152252, 10.20625114], [79.27152252, 10.20596886], [79.27097321, 10.20597267], [79.27097321, 10.20569515], [79.27069092, 10.20569515], [79.27069092, 10.20541668], [79.2701416, 10.2054224], [79.2701416, 10.20514107], [79.26985931, 10.20514107], [79.26985931, 10.20486069], [79.26930237, 10.20486069], [79.26930237, 10.20458317], [79.26902771, 10.20458317], [79.26902771, 10.2043047], [79.26875305, 10.20430946], [79.26875305, 10.20375061], [79.26846313, 10.20375061], [79.26846313, 10.20318985], [79.26819611, 10.20319462], [79.26819611, 10.20263863], [79.26790619, 10.20264053], [79.26790619, 10.20236111], [79.26763916, 10.20236111], [79.26763916, 10.20180511], [79.26735687, 10.20182037], [79.26735687, 10.20125103], [79.26708221, 10.20125103], [79.26708221, 10.20069027], [79.26680756, 10.20069504], [79.26680756, 10.20013809], [79.2665329, 10.20014095], [79.2665329, 10.19985962], [79.26625061, 10.19985962], [79.26625061, 10.19930744], [79.26597595, 10.19931126], [79.26597595, 10.19876194], [79.26568604, 10.19876194], [79.26568604, 10.19818974], [79.26541901, 10.19819355], [79.26541901, 10.19791603], [79.26513672, 10.1979208], [79.26513672, 10.19764137], [79.26486206, 10.19764137], [79.26486206, 10.19736004], [79.26457977, 10.19736004], [79.26457977, 10.19708443], [79.26430511, 10.19708443], [79.26430511, 10.19680595], [79.26374817, 10.19681072], [79.26374817, 10.1965313], [79.26346588, 10.1965313], [79.26346588, 10.19624996], [79.26319122, 10.19624996], [79.26319122, 10.19596958], [79.26291656, 10.19597244], [79.26291656, 10.19569397], [79.26264191, 10.19569397], [79.26264191, 10.19541645], [79.26235962, 10.19542122], [79.26235962, 10.19514275], [79.26209259, 10.19514275], [79.26209259, 10.19486046], [79.26180267, 10.19486237], [79.26180267, 10.19458199], [79.26125336, 10.19458199], [79.26125336, 10.19430637], [79.26097107, 10.19431114], [79.26097107, 10.19403267], [79.26069641, 10.19403267], [79.26069641, 10.19375038], [79.26040649, 10.19375038], [79.26040649, 10.19347191], [79.26013947, 10.19347191], [79.26013947, 10.19319439], [79.25958252, 10.19319439], [79.25958252, 10.19291592], [79.25930786, 10.19291973], [79.25930786, 10.19262886], [79.25902557, 10.1926403], [79.25902557, 10.19235992], [79.25846863, 10.19235992], [79.25846863, 10.19208431], [79.25819397, 10.19208431], [79.25819397, 10.19180584], [79.25791931, 10.19181061], [79.25791931, 10.19153023], [79.25736237, 10.19153023], [79.25736237, 10.19124985], [79.25708008, 10.19124985], [79.25708008, 10.19097233], [79.25653076, 10.19097233], [79.25653076, 10.19069386], [79.25624847, 10.19069386], [79.25624847, 10.19041634], [79.25596619, 10.19042015], [79.25596619, 10.19013977], [79.25541687, 10.19013977], [79.25541687, 10.18986034], [79.25514221, 10.18986225], [79.25514221, 10.18958378], [79.25485992, 10.18959141], [79.25485992, 10.18931007], [79.25430298, 10.18931007], [79.25430298, 10.18902969], [79.25402832, 10.18902969], [79.25402832, 10.18875027], [79.25319672, 10.18875027], [79.25319672, 10.18847179], [79.2529068, 10.18847179], [79.2529068, 10.18791962], [79.25235748, 10.18791962], [79.25235748, 10.18764019], [79.25208282, 10.18764019], [79.25208282, 10.18791962], [79.25125122, 10.18791962], [79.25125122, 10.18764019], [79.25068665, 10.18764019], [79.25068665, 10.18735886], [79.25041962, 10.18736172], [79.25041962, 10.18723202], [79.25041962, 10.1870842], [79.25013733, 10.1870842], [79.25013733, 10.18680573], [79.24958038, 10.18682098], [79.24958038, 10.18653202], [79.24931335, 10.18653202], [79.24931335, 10.18625164], [79.24846649, 10.18625164], [79.24846649, 10.18597126], [79.24736023, 10.18597126], [79.24736023, 10.18569565], [79.24652863, 10.18569565], [79.24652863, 10.18541527], [79.2454071, 10.18542194], [79.2454071, 10.1851387], [79.24514008, 10.1851387], [79.24514008, 10.18485928], [79.24485779, 10.18486118], [79.24485779, 10.18458271], [79.24430847, 10.18458271], [79.24430847, 10.18430519], [79.24402618, 10.18430996], [79.24402618, 10.18402958], [79.24375153, 10.18402958], [79.24375153, 10.1837492], [79.24346924, 10.1837492], [79.24346924, 10.18347263], [79.24291992, 10.18347263], [79.24291992, 10.18319321], [79.24263763, 10.18319321], [79.24263763, 10.18291664], [79.24236298, 10.18292046], [79.24236298, 10.18236065], [79.24208069, 10.18236065], [79.24208069, 10.18208313], [79.24180603, 10.18208313], [79.24180603, 10.18124866], [79.241539, 10.18125057], [79.241539, 10.18069077], [79.24124908, 10.18069458], [79.24124908, 10.1782999], [79.24124908, 10.17736053], [79.24153137, 10.17736053], [79.24153137, 10.17430687], [79.24124908, 10.17431068], [79.24124908, 10.17375088], [79.2409668, 10.17375088], [79.2409668, 10.17319012], [79.24069214, 10.17319489], [79.24069214, 10.17263794], [79.24041748, 10.1726408], [79.24041748, 10.1718111], [79.23986053, 10.1718111], [79.23986053, 10.17125034], [79.23958588, 10.17125034], [79.23958588, 10.17097187], [79.23930359, 10.17097187], [79.23930359, 10.17069435], [79.23902893, 10.17069435], [79.23902893, 10.17041588], [79.23874664, 10.17042065], [79.23874664, 10.16986179], [79.23847961, 10.16986179], [79.23847961, 10.16958046], [79.23819733, 10.16958427], [79.23819733, 10.1693058], [79.23792267, 10.16931057], [79.23792267, 10.16875267], [79.23819733, 10.16875267], [79.23819733, 10.16819191], [79.23847198, 10.16819382], [79.23847198, 10.16763783], [79.23874664, 10.16763973], [79.23874664, 10.16708183], [79.23902893, 10.16708374], [79.23902893, 10.16652775], [79.23929596, 10.16652966], [79.23929596, 10.16596985], [79.23958588, 10.16597176], [79.23958588, 10.16569424], [79.23930359, 10.16569424], [79.23930359, 10.16541576], [79.23958588, 10.16541958], [79.23958588, 10.16514015], [79.23986053, 10.16514015], [79.23986053, 10.16431046], [79.24014282, 10.16431046], [79.24014282, 10.16403008], [79.24041748, 10.16403008], [79.24041748, 10.16346931], [79.24069214, 10.16347218], [79.24069214, 10.1631937], [79.24097443, 10.1631937], [79.24097443, 10.1623621], [79.24041748, 10.1623621], [79.24041748, 10.16208363], [79.24013519, 10.16208363], [79.24013519, 10.15736103], [79.23986053, 10.15736103], [79.23986053, 10.15430546], [79.23958588, 10.15431023], [79.23958588, 10.15375137], [79.23929596, 10.15375137], [79.23929596, 10.15347958], [79.23847961, 10.15347958], [79.23847961, 10.15319061], [79.23791504, 10.15319538], [79.23791504, 10.15291691], [79.23764038, 10.15292168], [79.23764038, 10.1526413], [79.23735809, 10.1526413], [79.23735809, 10.15236092], [79.23707581, 10.15236092], [79.23707581, 10.15208054], [79.23568726, 10.15208054], [79.23569489, 10.15236092], [79.23513794, 10.15236092], [79.23513794, 10.15180492], [79.23486328, 10.1518116], [79.23486328, 10.15153122], [79.2334671, 10.15153122], [79.2334671, 10.15125084], [79.23319244, 10.15125084], [79.23319244, 10.15097141], [79.2326355, 10.15097332], [79.2326355, 10.15069485], [79.23124695, 10.15069485], [79.23124695, 10.15041733], [79.23069763, 10.15041924], [79.23069763, 10.15013885], [79.23041534, 10.15013885], [79.23041534, 10.14986134], [79.23014069, 10.14986134], [79.23014069, 10.14847279], [79.2298584, 10.14847279], [79.2298584, 10.14680672], [79.22957611, 10.14681053], [79.22957611, 10.14486027], [79.22930908, 10.14486027], [79.22930908, 10.14430428], [79.22902679, 10.14431095], [79.22902679, 10.14347172], [79.22930908, 10.14347172], [79.22930908, 10.1431942], [79.22958374, 10.1431942], [79.22958374, 10.14291573], [79.2298584, 10.14292145], [79.2298584, 10.14264011], [79.23014069, 10.14264011], [79.23014069, 10.14235973], [79.23041534, 10.14235973], [79.23041534, 10.14152813], [79.23014069, 10.14153957], [79.23014069, 10.14068985], [79.2298584, 10.14069366], [79.2298584, 10.14041615], [79.23014069, 10.14042091], [79.23014069, 10.13986015], [79.23041534, 10.13986206], [79.23041534, 10.13958359], [79.23069763, 10.13958359], [79.23069763, 10.13875008], [79.23042297, 10.13875008], [79.23042297, 10.13848114], [79.23014069, 10.13848114], [79.23014069, 10.13818932], [79.22930908, 10.13819408], [79.22930908, 10.13791561], [79.22875214, 10.13792038], [79.22875214, 10.13514042], [79.22930908, 10.13514042], [79.22930908, 10.13430977], [79.22957611, 10.13430977], [79.22957611, 10.13347054], [79.2298584, 10.13347054], [79.2298584, 10.13236237], [79.23014069, 10.13236237], [79.23014069, 10.13185978], [79.23014069, 10.13097095], [79.23041534, 10.13097095], [79.23041534, 10.13069534], [79.23069763, 10.13069534], [79.23069763, 10.13041687], [79.23152924, 10.13041973], [79.23152924, 10.13013935], [79.23208618, 10.13013935], [79.23208618, 10.12986088], [79.2326355, 10.12986088], [79.2326355, 10.12930489], [79.23291779, 10.12930965], [79.23291779, 10.12902927], [79.2334671, 10.12902927], [79.2334671, 10.12874889], [79.23707581, 10.12874889], [79.23707581, 10.12847137], [79.23680878, 10.12847328], [79.23680878, 10.12791729], [79.23652649, 10.12792015], [79.23652649, 10.12764072], [79.23596954, 10.12764072], [79.23596954, 10.1273613], [79.23569489, 10.1273613], [79.23569489, 10.12708282], [79.23542023, 10.12708282], [79.23542023, 10.12680531], [79.23513794, 10.12681198], [79.23513794, 10.12654114], [79.23486328, 10.12654114], [79.23486328, 10.12625122], [79.23430634, 10.12625122], [79.23430634, 10.12597084], [79.23401642, 10.12597084], [79.23401642, 10.12569141], [79.23374939, 10.12569523], [79.23374939, 10.12513924], [79.2334671, 10.12514114], [79.2334671, 10.12485886], [79.23319244, 10.12486076], [79.23319244, 10.12458324], [79.23291779, 10.12458324], [79.23291779, 10.12430477], [79.23235321, 10.12430859], [79.23235321, 10.12375069], [79.23208618, 10.12375069], [79.23208618, 10.12264061], [79.23179626, 10.12264061], [79.23179626, 10.12153053], [79.23152924, 10.12153053], [79.23152924, 10.12096977], [79.23124695, 10.12097263], [79.23124695, 10.1198597], [79.23097229, 10.1198597], [79.23097229, 10.11902905], [79.23069763, 10.11903095], [79.23069763, 10.11847019], [79.23041534, 10.1184721], [79.23041534, 10.11763763], [79.23014069, 10.11764145], [79.23014069, 10.11707973], [79.2298584, 10.11708355], [79.2298584, 10.11569405], [79.22930908, 10.11569405], [79.22930908, 10.11513805], [79.22902679, 10.11513996], [79.22902679, 10.11431122], [79.22875214, 10.11431122], [79.22875214, 10.11375046], [79.22846985, 10.11375046], [79.22846985, 10.11319447], [79.22819519, 10.11319447], [79.22819519, 10.11180592], [79.22846985, 10.11181068], [79.22846985, 10.11013985], [79.22875214, 10.11013985], [79.22875214, 10.10847187], [79.22902679, 10.10847187], [79.22902679, 10.1068058], [79.22930908, 10.10680962], [79.22930908, 10.10513973], [79.22957611, 10.10513973], [79.22957611, 10.10346889], [79.22930908, 10.1034708], [79.22930908, 10.10291672], [79.22875214, 10.10291958], [79.22875214, 10.1026392], [79.22820282, 10.1026392], [79.22820282, 10.10237026], [79.2279129, 10.10237026], [79.2279129, 10.1020813], [79.22763824, 10.10208321], [79.22763824, 10.10180473], [79.22735596, 10.10181046], [79.22735596, 10.10153198], [79.22680664, 10.10153198], [79.22680664, 10.10125065], [79.22651672, 10.10125065], [79.22651672, 10.09847069], [79.22680664, 10.0984726], [79.22680664, 10.09819508], [79.2270813, 10.09819508], [79.2270813, 10.09680462], [79.22735596, 10.09680939], [79.22735596, 10.09624195], [79.22763824, 10.09624863], [79.22763824, 10.09569454], [79.2279129, 10.09569454], [79.2279129, 10.09458256], [79.22819519, 10.09458256], [79.22819519, 10.09402561], [79.2279129, 10.09403133], [79.2279129, 10.09375095], [79.22820282, 10.09375095], [79.22820282, 10.09318066], [79.22846985, 10.09319496], [79.22846985, 10.09208202], [79.22875214, 10.09208202], [79.22875214, 10.09152889], [79.22902679, 10.0915308], [79.22902679, 10.09068966], [79.22930908, 10.09069443], [79.22930908, 10.09013844], [79.22957611, 10.0901413], [79.22957611, 10.08957958], [79.2298584, 10.08958435], [79.2298584, 10.08874989], [79.23014069, 10.08875275], [79.23014069, 10.08819199], [79.23041534, 10.08819389], [79.23041534, 10.08736229], [79.23069763, 10.08737087], [79.23069763, 10.08681107], [79.23097229, 10.08681107], [79.23097229, 10.08625031], [79.23124695, 10.08625031], [79.23124695, 10.08541584], [79.23152924, 10.08541965], [79.23152924, 10.08485985], [79.23180389, 10.08485985], [79.23180389, 10.08458424], [79.23208618, 10.08458424], [79.23208618, 10.08430576], [79.2326355, 10.08430576], [79.2326355, 10.08402824], [79.23319244, 10.08403015], [79.23319244, 10.08374977], [79.23264313, 10.08374977], [79.23264313, 10.08347034], [79.23291779, 10.08347225], [79.23291779, 10.08319378], [79.2326355, 10.08319378], [79.2326355, 10.08236217], [79.23291779, 10.08236217], [79.23291779, 10.08180618], [79.23319244, 10.08181], [79.23319244, 10.08152962], [79.2334671, 10.08152962], [79.2334671, 10.08069134], [79.23374939, 10.0806942], [79.23374939, 10.07986164], [79.23402405, 10.07986164], [79.23401642, 10.07846928], [79.23430634, 10.07847118], [79.23430634, 10.07819557], [79.23486328, 10.07820034], [79.23486328, 10.07791996], [79.23513794, 10.07791996], [79.23513794, 10.07708073], [79.23542023, 10.07708263], [79.23542023, 10.07624912], [79.23568726, 10.07625198], [79.23568726, 10.07543087], [79.23596954, 10.07543087], [79.23596954, 10.07486057], [79.23625183, 10.07486057], [79.23625183, 10.07458305], [79.23652649, 10.07458305], [79.23652649, 10.07402706], [79.23680878, 10.07403183], [79.23680878, 10.07375145], [79.23902893, 10.07375145], [79.23902893, 10.07347107], [79.23958588, 10.07347107], [79.23958588, 10.07319546], [79.24041748, 10.07319546], [79.24041748, 10.07347107], [79.2409668, 10.07347107], [79.2409668, 10.07375145], [79.24180603, 10.07375145], [79.24180603, 10.07319069], [79.24236298, 10.07319546], [79.24236298, 10.07347107], [79.24346924, 10.07347107], [79.24346924, 10.07319546], [79.24402618, 10.07319546], [79.24402618, 10.07291698], [79.24430847, 10.07291889], [79.24430847, 10.07264137], [79.24375153, 10.07264137], [79.24375153, 10.07291889], [79.24263763, 10.07291889], [79.24263763, 10.07264137], [79.24236298, 10.07264137], [79.24236298, 10.07236099], [79.24346924, 10.07236099], [79.24346924, 10.07208347], [79.24458313, 10.07208347], [79.24458313, 10.071805], [79.24485779, 10.07181168], [79.24485779, 10.0715313], [79.2454071, 10.0715313], [79.2454071, 10.07125092], [79.24652863, 10.07125092], [79.24652863, 10.07097054], [79.24708557, 10.0709734], [79.24708557, 10.0704174], [79.24736023, 10.07041931], [79.24736023, 10.07014084], [79.24764252, 10.07014084], [79.24764252, 10.06986141], [79.24819183, 10.06986141], [79.24819183, 10.06958294], [79.24874878, 10.06958294], [79.24874878, 10.06930542], [79.24903107, 10.06930542], [79.24903107, 10.06902885], [79.24931335, 10.06902885], [79.24931335, 10.06847095], [79.24958038, 10.06847286], [79.24958038, 10.06819534], [79.25041962, 10.06819534], [79.25041962, 10.06791687], [79.25068665, 10.06792068], [79.25068665, 10.06764126], [79.25096893, 10.06764126], [79.25096893, 10.06736088], [79.25125122, 10.06736088], [79.25125122, 10.06708336], [79.25180817, 10.06708336], [79.25180817, 10.06680679], [79.25208282, 10.06681061], [79.25208282, 10.06653118], [79.25235748, 10.06653118], [79.25235748, 10.0654211], [79.25263977, 10.0654211], [79.25263977, 10.06486034], [79.25291443, 10.06486034], [79.25291443, 10.06458473], [79.25319672, 10.06458473], [79.25319672, 10.06430435], [79.25345612, 10.06431103], [79.25345612, 10.06320095], [79.25374603, 10.06320095], [79.25374603, 10.06124973], [79.25345612, 10.06124973], [79.25345612, 10.06069183], [79.25375366, 10.06069374], [79.25375366, 10.05902767], [79.25345612, 10.05902958], [79.25345612, 10.05875015], [79.25319672, 10.05875015], [79.25319672, 10.05819416], [79.25291443, 10.05819416], [79.25291443, 10.05708408], [79.25263977, 10.05708408], [79.25263977, 10.0559721], [79.25291443, 10.0559721], [79.25291443, 10.05569363], [79.25319672, 10.05569363], [79.25319672, 10.05486202], [79.25263977, 10.05486202], [79.25263977, 10.05458355], [79.25235748, 10.05458355], [79.25235748, 10.05402756], [79.25208282, 10.05403042], [79.25208282, 10.05264187], [79.25180817, 10.05264187], [79.25180817, 10.05236244], [79.25235748, 10.05236244], [79.25235748, 10.05208397], [79.25263977, 10.05208397], [79.25263977, 10.05180454], [79.2529068, 10.05181026], [79.2529068, 10.05069065], [79.25263977, 10.05069637], [79.25263977, 10.05013943], [79.25235748, 10.05013943], [79.25235748, 10.0490303], [79.25263977, 10.0490303], [79.25263977, 10.04847145], [79.25291443, 10.04847336], [79.25291443, 10.04819489], [79.25347137, 10.04819489], [79.25347137, 10.04791737], [79.25374603, 10.04792023], [79.25374603, 10.04763889], [79.25402832, 10.04763889], [79.25402832, 10.04736137], [79.25430298, 10.04736137], [79.25430298, 10.04680538], [79.2545929, 10.04681015], [79.2545929, 10.04653168], [79.25485992, 10.04653168], [79.25485992, 10.0462513], [79.25514221, 10.0462513], [79.25514221, 10.0456953], [79.25569153, 10.0456953], [79.25569153, 10.04541683], [79.25596619, 10.0454216], [79.25596619, 10.04512978], [79.25624847, 10.04513931], [79.25624847, 10.04486084], [79.25652313, 10.04486084], [79.25652313, 10.04458141], [79.25708008, 10.04458332], [79.25708008, 10.04430485], [79.25736237, 10.04431152], [79.25736237, 10.04402924], [79.25791931, 10.04402924], [79.25791931, 10.04374886], [79.25819397, 10.04374886], [79.25819397, 10.04347324], [79.25846863, 10.04347324], [79.25846863, 10.04319477], [79.25902557, 10.04319477], [79.25902557, 10.04291725], [79.25930786, 10.04292107], [79.25930786, 10.04264069], [79.25985718, 10.04264069], [79.25985718, 10.04236126], [79.26013947, 10.04236126], [79.26013947, 10.04208279], [79.26041412, 10.04208279], [79.26041412, 10.04180527], [79.26097107, 10.04181099], [79.26097107, 10.04153061], [79.26125336, 10.04153061], [79.26125336, 10.04125118], [79.26180267, 10.04125118], [79.26180267, 10.04097271], [79.26208496, 10.04097271], [79.26208496, 10.04069519], [79.26264191, 10.04069519], [79.26264191, 10.04041672], [79.26319122, 10.04042053], [79.26319122, 10.04014111], [79.26374817, 10.04014111], [79.26374817, 10.03986073], [79.26430511, 10.03986073], [79.26430511, 10.03958225], [79.26513672, 10.03958225], [79.26513672, 10.03930664], [79.26568604, 10.03931999], [79.26568604, 10.03903103], [79.26625061, 10.03903103], [79.26625061, 10.03875065], [79.26680756, 10.03875065], [79.26680756, 10.03847027], [79.2673645, 10.03847313], [79.2673645, 10.03791618], [79.26625061, 10.03792095], [79.26625061, 10.03764057], [79.26541901, 10.03764057], [79.26541901, 10.03736019], [79.26430511, 10.03736019], [79.26430511, 10.03708458], [79.26347351, 10.03708458], [79.26347351, 10.0368042], [79.26235962, 10.03681087], [79.26235962, 10.03653145], [79.26209259, 10.03653145], [79.26209259, 10.03625011], [79.26152802, 10.03625011], [79.26152802, 10.03596973], [79.26097107, 10.03597164], [79.26097107, 10.03569412], [79.26041412, 10.03569412], [79.26041412, 10.03541565], [79.25985718, 10.03542137], [79.25985718, 10.03514004], [79.25930786, 10.03514004], [79.25930786, 10.03485966], [79.25902557, 10.03486156], [79.25902557, 10.03458214], [79.25846863, 10.03458214], [79.25846863, 10.03430557], [79.25736237, 10.03431129], [79.25736237, 10.03403091], [79.25681305, 10.03403091], [79.25681305, 10.03374958], [79.25652313, 10.03374958], [79.25652313, 10.03347015], [79.25624847, 10.03347206], [79.25624847, 10.03319359], [79.25569153, 10.03319359], [79.25569153, 10.03291607], [79.25485992, 10.03292274], [79.25485992, 10.03264046], [79.25430298, 10.03264046], [79.25430298, 10.03236008], [79.25374603, 10.03236008], [79.25374603, 10.0320797], [79.25319672, 10.03208447], [79.25319672, 10.03180599], [79.25263977, 10.03181076], [79.25263977, 10.03153038], [79.25180817, 10.03153038], [79.25180817, 10.03125], [79.25152588, 10.03125], [79.25152588, 10.03096962], [79.25125122, 10.03097153], [79.25125122, 10.03069401], [79.25096893, 10.03069401], [79.25096893, 10.03041553], [79.25068665, 10.0304203], [79.25068665, 10.03013134], [79.24986267, 10.03013992], [79.24986267, 10.0298624], [79.24930573, 10.0298624], [79.24930573, 10.02958393], [79.24903107, 10.02958393], [79.24903107, 10.02930641], [79.24846649, 10.02931023], [79.24846649, 10.02902985], [79.24791718, 10.02902985], [79.24791718, 10.02875042], [79.24736023, 10.02875042], [79.24736023, 10.02847195], [79.24680328, 10.02847195], [79.24680328, 10.02764034], [79.24652863, 10.02764034], [79.24652863, 10.02736187], [79.24597168, 10.02736187], [79.24597168, 10.02708435], [79.24569702, 10.02709103], [79.24569702, 10.02680969], [79.24514008, 10.02680969], [79.24514008, 10.02653027], [79.24485779, 10.02653027], [79.24485779, 10.02625179], [79.24430847, 10.02625179], [79.24430847, 10.02597141], [79.24402618, 10.02597141], [79.24402618, 10.02541542], [79.24318695, 10.02542019], [79.24318695, 10.02513981], [79.24263763, 10.02513981], [79.24263763, 10.02486229], [79.24236298, 10.02486229], [79.24236298, 10.02402687], [79.24208069, 10.02402973], [79.24208069, 10.02347088], [79.24153137, 10.02347088], [79.24153137, 10.02319336], [79.24124908, 10.02319336], [79.24124908, 10.02263927], [79.24069214, 10.02263927], [79.24069214, 10.02235889], [79.24041748, 10.0223608], [79.24041748, 10.02124882], [79.24014282, 10.02125072], [79.24014282, 10.02095985], [79.23986053, 10.02097321], [79.23986053, 10.02069473], [79.23958588, 10.02069473], [79.23958588, 10.02041721], [79.23929596, 10.02042198], [79.23929596, 10.02014065], [79.23874664, 10.02014065], [79.23874664, 10.01986122], [79.23819733, 10.01986122], [79.23819733, 10.01958275], [79.23791504, 10.01958275], [79.23791504, 10.01930523], [79.23764038, 10.0193119], [79.23764038, 10.01875114], [79.23735809, 10.01875114], [79.23735809, 10.01847267], [79.23708344, 10.01847267], [79.23708344, 10.01819515], [79.23680878, 10.01819515], [79.23680878, 10.01791668], [79.23625183, 10.0179224], [79.23625183, 10.01764107], [79.23596954, 10.01764107], [79.23596954, 10.01736069], [79.23568726, 10.01736069], [79.23568726, 10.01680946], [79.23513794, 10.01680946], [79.23513794, 10.01625061], [79.23486328, 10.01625061], [79.23484039, 10.01597118], [79.23430634, 10.01597309], [79.23430634, 10.01569462], [79.23374939, 10.01569462], [79.23374939, 10.0154171], [79.2334671, 10.01542091], [79.23347473, 10.01525021], [79.23347473, 10.01513863], [79.23326874, 10.01513863], [79.23319244, 10.01513863], [79.23319244, 10.01457977], [79.23291779, 10.01458263], [79.23291779, 10.01375103], [79.23264313, 10.01375103], [79.23264313, 10.0134697], [79.23208618, 10.01347256], [79.23208618, 10.01291656], [79.23152924, 10.01292133], [79.23152924, 10.01264095], [79.23124695, 10.01264095], [79.23124695, 10.01209164], [79.23069763, 10.01209164], [79.23069763, 10.01181126], [79.23042297, 10.01181126], [79.23042297, 10.01153088], [79.22957611, 10.01153088], [79.22957611, 10.01125145], [79.22930908, 10.01125145], [79.22930908, 10.01068974], [79.22902679, 10.01069355], [79.22902679, 10.01013756], [79.22875214, 10.01014137], [79.22875214, 10.00957966], [79.22846985, 10.00958538], [79.22846985, 10.00930595], [79.22820282, 10.00931072], [79.22820282, 10.00874996], [79.2279129, 10.00874996], [79.2279129, 10.00846958], [79.22763824, 10.00847244], [79.22763824, 10.00791645], [79.22735596, 10.00792122], [79.22735596, 10.00764275], [79.22680664, 10.00764275], [79.22680664, 10.00736046], [79.22651672, 10.00736046], [79.22651672, 10.00764275], [79.22597504, 10.00763798], [79.22597504, 10.00819397], [79.22569275, 10.00819397], [79.22569275, 10.00847244], [79.2251358, 10.00847244], [79.2251358, 10.00819397], [79.22486115, 10.00819397], [79.22486115, 10.00736237], [79.2251358, 10.00736237], [79.2251358, 10.00625038], [79.22486115, 10.00625038], [79.22486115, 10.00597191], [79.22458649, 10.00597191], [79.22458649, 10.00541592], [79.22429657, 10.00542068], [79.22429657, 10.0051403], [79.22402954, 10.0051403], [79.22402954, 10.00485992], [79.22374725, 10.00485992], [79.22374725, 10.00458431], [79.2234726, 10.00458431], [79.2234726, 10.00430584], [79.22319794, 10.00431061], [79.22319794, 10.00403023], [79.22292328, 10.00403023], [79.22292328, 10.00374985], [79.22264099, 10.00374985], [79.22264099, 10.00319386], [79.2223587, 10.00319386], [79.2223587, 10.00291634], [79.22180176, 10.00292015], [79.22180176, 10.00181007], [79.2215271, 10.00181007], [79.2215271, 10.00152969], [79.22125244, 10.00152969], [79.22125244, 10.00125027], [79.2206955, 10.00125027], [79.2206955, 10.00097179], [79.22041321, 10.00097179], [79.22041321, 10.00069427], [79.22013855, 10.00069427], [79.22013855, 10.00014019], [79.22013855, 9.99986172], [79.22013855, 9.9995842], [79.21986389, 9.9995842], [79.21986389, 9.99930573], [79.2195816, 9.99930954], [79.2195816, 9.99903202], [79.21930695, 9.99903202], [79.21930695, 9.99875164], [79.21901703, 9.99875164], [79.21901703, 9.99847126], [79.21875, 9.99847126], [79.21875, 9.99819565], [79.21847534, 9.99819565], [79.21847534, 9.99763966], [79.2179184, 9.99763966], [79.2179184, 9.9970789], [79.21763611, 9.99708271], [79.21763611, 9.99680519], [79.21734619, 9.99680996], [79.21734619, 9.99652958], [79.21708679, 9.99652958], [79.21708679, 9.9962492], [79.21679688, 9.9962492], [79.21679688, 9.99597073], [79.21652985, 9.99597359], [79.21652985, 9.99569321], [79.21624756, 9.99569321], [79.21624756, 9.99541664], [79.21569824, 9.99542046], [79.21569061, 9.99514198], [79.21541595, 9.99514198], [79.21541595, 9.99458122], [79.2151413, 9.99458313], [79.2151413, 9.99430466], [79.21485901, 9.99431038], [79.21485901, 9.99402046], [79.21458435, 9.99402714], [79.21458435, 9.99374866], [79.21430969, 9.99375057], [79.21430969, 9.99347115], [79.2140274, 9.99347115], [79.2140274, 9.99319458], [79.21375275, 9.99319458], [79.21375275, 9.99263859], [79.2131958, 9.99264145], [79.2131958, 9.99236107], [79.21290588, 9.99236107], [79.21290588, 9.99208069], [79.21263885, 9.9920826], [79.21263885, 9.99180508], [79.21208191, 9.99180984], [79.21208191, 9.99153137], [79.21180725, 9.99153137], [79.21180725, 9.99125099], [79.21154022, 9.99125099], [79.21154022, 9.99098015], [79.21125031, 9.99098015], [79.21125031, 9.99069023], [79.21097565, 9.990695], [79.21097565, 9.99041653], [79.21069336, 9.99041939], [79.21069336, 9.98958111], [79.2104187, 9.98958302], [79.2104187, 9.98930454], [79.21013641, 9.98930931], [79.21013641, 9.98875141], [79.20986176, 9.98875141], [79.20986176, 9.98847294], [79.20930481, 9.98847294], [79.20930481, 9.98819542], [79.20874786, 9.98819542], [79.20874786, 9.98763943], [79.20847321, 9.98764133], [79.20847321, 9.98681068], [79.20818329, 9.98681068], [79.20818329, 9.98653126], [79.2076416, 9.98653126], [79.2076416, 9.98625088], [79.20707703, 9.98625088], [79.20707703, 9.98596954], [79.20680237, 9.98597336], [79.20680237, 9.98541737], [79.20652771, 9.98542118], [79.20652771, 9.9851408], [79.20625305, 9.9851408], [79.20625305, 9.98458004], [79.20597076, 9.98458195], [79.20597076, 9.98430443], [79.20569611, 9.9843111], [79.20569611, 9.98403072], [79.20540619, 9.98403072], [79.20540619, 9.9837513], [79.20513916, 9.9837513], [79.20513916, 9.98319435], [79.20430756, 9.98319435], [79.20430756, 9.98263836], [79.2040329, 9.98264122], [79.2040329, 9.98236275], [79.20375061, 9.98236275], [79.20375061, 9.98153114], [79.20347595, 9.98153114], [79.20347595, 9.98069191], [79.20263672, 9.98069382], [79.20263672, 9.98013783], [79.20236969, 9.98013973], [79.20236969, 9.97986031], [79.20207977, 9.97986221], [79.20207977, 9.97930622], [79.20181274, 9.97931099], [79.20181274, 9.97875023], [79.20153046, 9.97875023], [79.20153046, 9.97819424], [79.20124817, 9.97819424], [79.20124817, 9.97764015], [79.20096588, 9.97764015], [79.20096588, 9.97707939], [79.20069122, 9.97708416], [79.20069122, 9.97652817], [79.20041656, 9.97653008], [79.20041656, 9.97569084], [79.20014191, 9.9756937], [79.20014191, 9.9748621], [79.19985962, 9.9748621], [79.19985962, 9.97430611], [79.19960022, 9.97430992], [79.19960022, 9.97347164], [79.19930267, 9.97347164], [79.19930267, 9.97124863], [79.19847107, 9.97124863], [79.19847107, 9.9709692], [79.19763947, 9.97097111], [79.19763947, 9.97069645], [79.19736481, 9.97069645], [79.19736481, 9.97041798], [79.19708252, 9.97042179], [79.19708252, 9.97014046], [79.1965332, 9.97014046], [79.1965332, 9.96984959], [79.19625092, 9.96986103], [79.19625092, 9.96958256], [79.19513702, 9.96958256], [79.19513702, 9.96930504], [79.19486237, 9.96930981], [79.19486237, 9.96903038], [79.19374847, 9.96903038], [79.19374847, 9.96847057], [79.19291687, 9.96847343], [79.19291687, 9.96819305], [79.19235992, 9.96819305], [79.19235992, 9.96763897], [79.1920929, 9.96764183], [79.1920929, 9.96736145], [79.19180298, 9.96736145], [79.19180298, 9.96708298], [79.19152832, 9.96708298], [79.19152832, 9.96680546], [79.19124603, 9.96681023], [79.19124603, 9.96652889], [79.19097137, 9.96652889], [79.19097137, 9.96625137], [79.19069672, 9.96625137], [79.19069672, 9.96597099], [79.19041443, 9.96597099], [79.19041443, 9.96569538], [79.19013977, 9.96569538], [79.19013977, 9.96541691], [79.18985748, 9.96542168], [79.18985748, 9.9651413], [79.18958282, 9.9651413], [79.18958282, 9.96486092], [79.18930817, 9.96486092], [79.18930817, 9.9645834], [79.18902588, 9.9645834], [79.18902588, 9.96430492], [79.18875122, 9.9643116], [79.18875122, 9.96404266], [79.18846893, 9.96404266], [79.18846893, 9.96375084], [79.18818665, 9.96375084], [79.18818665, 9.96347141], [79.18791962, 9.96347332], [79.18791962, 9.96319485], [79.18763733, 9.96319485], [79.18763733, 9.96291733], [79.1873703, 9.96291924], [79.1873703, 9.96263885], [79.18708038, 9.96263885], [79.18708038, 9.96236134], [79.18680573, 9.96236134], [79.18680573, 9.96208286], [79.18653107, 9.96208286], [79.18653107, 9.96180534], [79.18624878, 9.96181202], [79.18624878, 9.96153069], [79.18596649, 9.96153069], [79.18596649, 9.96125126], [79.18569183, 9.96125126], [79.18569183, 9.96097279], [79.18541718, 9.96097279], [79.18541718, 9.96069527], [79.18514252, 9.96069527], [79.18514252, 9.96041679], [79.18486023, 9.96042061], [79.18486023, 9.96014118], [79.1845932, 9.96014118], [79.1845932, 9.9598608], [79.18430328, 9.9598608], [79.18430328, 9.95958328], [79.18402863, 9.95958328], [79.18402863, 9.95930672], [79.18347168, 9.95931053], [79.18347168, 9.95903111], [79.18319702, 9.95903111], [79.18319702, 9.95875072], [79.1829071, 9.95875072], [79.1829071, 9.95847034], [79.18264008, 9.95847321], [79.18264008, 9.95819473], [79.18235779, 9.95819473], [79.18235779, 9.95807076], [79.18235779, 9.95791721], [79.18208313, 9.95791721], [79.18208313, 9.95763779], [79.18180847, 9.95764065], [79.18180847, 9.95736027], [79.18152618, 9.95736027], [79.18152618, 9.95708466], [79.18125153, 9.95708466], [79.18125153, 9.95680428], [79.18096924, 9.95681095], [79.18096924, 9.95653057], [79.18068695, 9.95653057], [79.18068695, 9.95625019], [79.18041992, 9.95625019], [79.18041992, 9.9556942], [79.18013763, 9.9556942], [79.18013763, 9.95541573], [79.17986298, 9.95542145], [79.17986298, 9.95514107], [79.17958069, 9.95514107], [79.17958069, 9.95486927], [79.17930603, 9.95486927], [79.17930603, 9.95458031], [79.17903137, 9.95458221], [79.17903137, 9.95430565], [79.17874908, 9.95431137], [79.17874908, 9.95403099], [79.17819977, 9.95403099], [79.17819977, 9.95374966], [79.17791748, 9.95374966], [79.17791748, 9.95347023], [79.17763519, 9.95347214], [79.17763519, 9.95319366], [79.17736053, 9.95319366], [79.17736053, 9.95291615], [79.17679596, 9.95292091], [79.17679596, 9.95263958], [79.17652893, 9.95263958], [79.17652893, 9.95236015], [79.17624664, 9.95236015], [79.17624664, 9.95208359], [79.17597198, 9.95208359], [79.17597198, 9.95180607], [79.1754303, 9.95181084], [79.1754303, 9.95153046], [79.17514038, 9.95153046], [79.17514038, 9.95125008], [79.17485809, 9.95125008], [79.17485809, 9.9509697], [79.17458344, 9.9509716], [79.17458344, 9.95069408], [79.17430878, 9.95069408], [79.17430878, 9.95041561], [79.17402649, 9.95042038], [79.17402649, 9.94985962], [79.17375183, 9.94986153], [79.17375183, 9.94958401], [79.17346954, 9.94958401], [79.17346954, 9.94930553], [79.17318726, 9.9493103], [79.17318726, 9.94902992], [79.17292023, 9.94902992], [79.17292023, 9.94874954], [79.17263794, 9.94874954], [79.17263794, 9.94819069], [79.17236328, 9.94819355], [79.17236328, 9.94791794], [79.17208099, 9.94791985], [79.17208099, 9.94736195], [79.17180634, 9.94736195], [79.17180634, 9.94708443], [79.17124939, 9.94708443], [79.17124939, 9.94680595], [79.1709671, 9.94680977], [79.1709671, 9.94625187], [79.17069244, 9.94625187], [79.17069244, 9.94567966], [79.17097473, 9.94569302], [79.17097473, 9.94541454], [79.17069244, 9.94542027], [79.17069244, 9.94514179], [79.17041779, 9.94514179], [79.17041779, 9.94485855], [79.16986084, 9.94486237], [79.16986084, 9.94458389], [79.16958618, 9.94458389], [79.16958618, 9.94430637], [79.16929626, 9.94431019], [79.16929626, 9.94402981], [79.16902924, 9.94402981], [79.16902924, 9.94374943], [79.16874695, 9.94374943], [79.16874695, 9.94347095], [79.16819763, 9.94347095], [79.16819763, 9.94319344], [79.16791534, 9.94319344], [79.16791534, 9.94291782], [79.16764069, 9.94293118], [79.16764069, 9.94263935], [79.1673584, 9.94263935], [79.1673584, 9.94250011], [79.1673584, 9.94236088], [79.167099, 9.94236088], [79.16680908, 9.94236088], [79.16680908, 9.94221115], [79.16680908, 9.94208336], [79.16652679, 9.94208336], [79.16652679, 9.94180489], [79.16625977, 9.94180965], [79.16625977, 9.94153023], [79.16596985, 9.94153023], [79.16596985, 9.94124889], [79.16569519, 9.94124889], [79.16569519, 9.94097328], [79.1654129, 9.94097328], [79.1654129, 9.94041729], [79.16513824, 9.94042015], [79.16513824, 9.94014168], [79.16485596, 9.94014168], [79.16485596, 9.93987274], [79.1645813, 9.93987274], [79.1645813, 9.93958092], [79.16430664, 9.93958282], [79.16430664, 9.93930531], [79.16401672, 9.93931198], [79.16401672, 9.9390316], [79.16374969, 9.9390316], [79.16374969, 9.93847084], [79.16347504, 9.93847084], [79.16347504, 9.93819523], [79.16319275, 9.93819523], [79.16319275, 9.93791676], [79.16291809, 9.93792152], [79.16291809, 9.93764114], [79.16236115, 9.93764114], [79.16236115, 9.93735886], [79.1618042, 9.93736076], [79.1618042, 9.93708324], [79.16124725, 9.93708324], [79.16124725, 9.93680477], [79.16042328, 9.93680859], [79.16042328, 9.93653107], [79.16013336, 9.93653107], [79.16013336, 9.93625069], [79.15957642, 9.93625069], [79.15957642, 9.93597126], [79.15930176, 9.93597317], [79.15930176, 9.93569469], [79.1590271, 9.93569469], [79.1590271, 9.93541718], [79.15875244, 9.93542099], [79.15875244, 9.93514061], [79.15847015, 9.93514061], [79.15847015, 9.93486118], [79.15791321, 9.93486118], [79.15791321, 9.93458271], [79.15763855, 9.93458271], [79.15763855, 9.93430519], [79.15735626, 9.93431091], [79.15735626, 9.93403053], [79.15706635, 9.93403053], [79.15706635, 9.93374157], [79.15680695, 9.93375111], [79.15680695, 9.93347263], [79.15652466, 9.93347263], [79.15652466, 9.93319511], [79.15597534, 9.93319511], [79.15597534, 9.93291664], [79.15569305, 9.93292141], [79.15569305, 9.93264103], [79.1554184, 9.93264103], [79.1554184, 9.93236065], [79.15513611, 9.93236065], [79.15513611, 9.93180656], [79.15486145, 9.93181133], [79.15486145, 9.93125057], [79.15458679, 9.93125057], [79.15458679, 9.93068123], [79.1543045, 9.93069458], [79.1543045, 9.93041611], [79.15402985, 9.93042088], [79.15402985, 9.92986012], [79.15374756, 9.92986012], [79.15374756, 9.92930698], [79.15319824, 9.92930889], [79.15319061, 9.92793179], [79.15291595, 9.92793179], [79.15291595, 9.92681122], [79.1526413, 9.92681122], [79.1526413, 9.92514038], [79.15291595, 9.92514038], [79.15291595, 9.92486], [79.15319061, 9.92486], [79.15319824, 9.9240284], [79.1534729, 9.9240303], [79.1534729, 9.92236042], [79.15374756, 9.92236233], [79.15374756, 9.92041779], [79.1534729, 9.92041969], [79.1534729, 9.91986179], [79.15319824, 9.91986179], [79.15319061, 9.91930962], [79.15291595, 9.91930962], [79.15291595, 9.91874027], [79.1526413, 9.91874981], [79.1526413, 9.91847229], [79.15235901, 9.91847229], [79.15235901, 9.91791534], [79.15207672, 9.91792011], [79.15207672, 9.91735935], [79.15180206, 9.91736221], [79.15180206, 9.91708374], [79.1515274, 9.91708374], [79.1515274, 9.91652679], [79.15126038, 9.91652966], [79.15126038, 9.91624928], [79.15097046, 9.91624928], [79.15097046, 9.91597366], [79.1506958, 9.9159708], [79.1506958, 9.91541672], [79.15040588, 9.91541958], [79.15040588, 9.9151392], [79.15013885, 9.9151392], [79.15013885, 9.91486073], [79.14985657, 9.91486073], [79.14985657, 9.91431046], [79.14958191, 9.91431046], [79.14958191, 9.91375065], [79.14930725, 9.91375065], [79.14930725, 9.91319084], [79.14902496, 9.91319466], [79.14902496, 9.91263866], [79.14875031, 9.91264057], [79.14875031, 9.91236115], [79.14847565, 9.91236115], [79.14847565, 9.91208267], [79.1479187, 9.91208267], [79.1479187, 9.91180515], [79.14763641, 9.91181183], [79.14763641, 9.9115324], [79.14653015, 9.9115324], [79.14653015, 9.91125107], [79.14624786, 9.91125107], [79.14624786, 9.91097069], [79.14653015, 9.9109726], [79.14653015, 9.9104166], [79.14679718, 9.91041946], [79.14679718, 9.91014099], [79.1470871, 9.91014099], [79.1470871, 9.90957069], [79.14430237, 9.90958309], [79.14430237, 9.90930462], [79.14402771, 9.90930939], [79.14402771, 9.90903091], [79.14375305, 9.90903091], [79.14375305, 9.90875053], [79.14347076, 9.90875053], [79.14347076, 9.90847111], [79.14319611, 9.90847301], [79.14319611, 9.90791702], [79.14263916, 9.90792084], [79.14263916, 9.90736103], [79.14235687, 9.90736103], [79.14235687, 9.9070797], [79.14208221, 9.90708256], [79.14208221, 9.90680695], [79.14180756, 9.90680695], [79.14180756, 9.90652657], [79.1415329, 9.90653133], [79.1415329, 9.90625095], [79.14125061, 9.90625095], [79.14125061, 9.90569019], [79.14097595, 9.90569496], [79.14097595, 9.90541744], [79.14068604, 9.90542126], [79.14068604, 9.90514088], [79.14041901, 9.90514088], [79.14041901, 9.90486145], [79.14013672, 9.90486145], [79.14013672, 9.90458202], [79.13986206, 9.90458202], [79.13986206, 9.90430355], [79.13957977, 9.90431118], [79.13957977, 9.9040308], [79.13932037, 9.9040308], [79.13932037, 9.90347004], [79.13903046, 9.9034729], [79.13903046, 9.90319443], [79.13874817, 9.90319443], [79.13874817, 9.90291595], [79.13846588, 9.90292072], [79.13846588, 9.9026413], [79.13819122, 9.9026413], [79.13819122, 9.90235996], [79.13791656, 9.90235996], [79.13791656, 9.9020853], [79.13764191, 9.9020853], [79.13764191, 9.90180588], [79.13735962, 9.90181065], [79.13735962, 9.90153122], [79.13709259, 9.90153122], [79.13709259, 9.90125275], [79.13680267, 9.90125275], [79.13680267, 9.90097046], [79.13652802, 9.90097237], [79.13652802, 9.90041637], [79.13625336, 9.90042114], [79.13625336, 9.90014267], [79.13597107, 9.90014267], [79.13597107, 9.89986038], [79.13569641, 9.89986229], [79.13569641, 9.89958382], [79.13541412, 9.89958191], [79.13541412, 9.8993063], [79.13513947, 9.89931107], [79.13513947, 9.89902973], [79.13430786, 9.89902973], [79.13430786, 9.89875031], [79.13346863, 9.89875031], [79.13346863, 9.89847183], [79.13319397, 9.89847183], [79.13319397, 9.89791584], [79.13291931, 9.89792061], [79.13291931, 9.89735985], [79.13263702, 9.89735985], [79.13263702, 9.89708424], [79.13223267, 9.89708424], [79.13153076, 9.89708424], [79.13153076, 9.89652824], [79.13069153, 9.89653015], [79.13069153, 9.89625168], [79.13041687, 9.89625168], [79.13041687, 9.89597034], [79.13014221, 9.89597225], [79.13014221, 9.89569378], [79.12985992, 9.89569378], [79.12985992, 9.89541626], [79.1295929, 9.89542007], [79.1295929, 9.89513969], [79.12930298, 9.89513969], [79.12930298, 9.89486027], [79.12902832, 9.89486217], [79.12902832, 9.8945837], [79.12847137, 9.8945837], [79.12847137, 9.89430618], [79.12819672, 9.89431], [79.12819672, 9.89402962], [79.1279068, 9.89402962], [79.1279068, 9.89346886], [79.12763977, 9.89347172], [79.12763977, 9.8931942], [79.12735748, 9.8931942], [79.12735748, 9.89264011], [79.12709045, 9.89264202], [79.12709045, 9.89236164], [79.12680817, 9.89236164], [79.12680817, 9.89208412], [79.12652588, 9.89208412], [79.12652588, 9.89106274], [79.12652588, 9.89069557], [79.12625122, 9.89069557], [79.12625122, 9.89041805], [79.12596893, 9.89041996], [79.12596893, 9.88958073], [79.12569427, 9.88958263], [79.12569427, 9.88930511], [79.12541962, 9.88931179], [79.12541962, 9.88653183], [79.12513733, 9.88653183], [79.12513733, 9.88541889], [79.12486267, 9.88541889], [79.12486267, 9.88431168], [79.12458038, 9.88431168], [79.12458038, 9.88402939], [79.12403107, 9.88402939], [79.12403107, 9.88375092], [79.12374878, 9.88375092], [79.12374878, 9.88291931], [79.12346649, 9.88291931], [79.12346649, 9.88263035], [79.12319183, 9.88263893], [79.12319183, 9.88236141], [79.12291718, 9.88236141], [79.12291718, 9.88180542], [79.12264252, 9.88180923], [79.12264252, 9.88125134], [79.12236023, 9.88125134], [79.12236023, 9.88097286], [79.12208557, 9.88097286], [79.12208557, 9.88041687], [79.12180328, 9.88042068], [79.12180328, 9.88014126], [79.12152863, 9.88014126], [79.12152863, 9.87986088], [79.12124634, 9.87986088], [79.12124634, 9.87958336], [79.12095642, 9.87959194], [79.12095642, 9.87903118], [79.12069702, 9.87903118], [79.12069702, 9.8787508], [79.1204071, 9.8787508], [79.1204071, 9.87764072], [79.11985779, 9.87764072], [79.11985779, 9.87681961], [79.11958313, 9.87681961], [79.11958313, 9.87625122], [79.11930847, 9.87625122], [79.11930847, 9.87569427], [79.11902618, 9.87569427], [79.11902618, 9.87458229], [79.11875153, 9.87458229], [79.11875153, 9.87374973], [79.11902618, 9.87374973], [79.11902618, 9.87345886], [79.11930847, 9.87347221], [79.11930847, 9.87263775], [79.11958313, 9.87263966], [79.11958313, 9.87207985], [79.11985779, 9.87208366], [79.11985779, 9.87097168], [79.11958313, 9.87097168], [79.11958313, 9.87014008], [79.11985779, 9.87014008], [79.11985779, 9.86957932], [79.12014008, 9.86958408], [79.12014008, 9.86902809], [79.1204071, 9.86903], [79.1204071, 9.86874962], [79.12095642, 9.86874962], [79.12095642, 9.86847019], [79.12152863, 9.8684721], [79.12152863, 9.86819363], [79.12180328, 9.86819363], [79.12180328, 9.86791801], [79.12236023, 9.86791992], [79.12236023, 9.86765099], [79.12291718, 9.86765099], [79.12291718, 9.86708164], [79.12319183, 9.86708355], [79.12319183, 9.86652756], [79.12346649, 9.86653042], [79.12346649, 9.86597157], [79.12374878, 9.86597157], [79.12374878, 9.86541557], [79.12403107, 9.86542034], [79.12403107, 9.86458969], [79.12431335, 9.86458969], [79.12431335, 9.86347103], [79.12458038, 9.86347103], [79.12458038, 9.8629179], [79.12486267, 9.86291981], [79.12486267, 9.86236095], [79.12458038, 9.86236095], [79.12458038, 9.86208344], [79.12430573, 9.86208344], [79.12430573, 9.86152744], [79.12403107, 9.86152744], [79.12403107, 9.86124897], [79.12431335, 9.86125183], [79.12431335, 9.86097145], [79.12374878, 9.86097336], [79.12374878, 9.86041737], [79.12403107, 9.86042023], [79.12403107, 9.85958099], [79.12430573, 9.8595829], [79.12430573, 9.85902691], [79.12403107, 9.85903168], [79.12403107, 9.8587513], [79.12374878, 9.8587513], [79.12374878, 9.85847092], [79.12347412, 9.85847092], [79.12347412, 9.8581953], [79.12319183, 9.8581953], [79.12319183, 9.85763931], [79.12291718, 9.85764122], [79.12291718, 9.85680866], [79.12264252, 9.85680866], [79.12264252, 9.85624886], [79.12236023, 9.85624886], [79.12236023, 9.85569477], [79.12208557, 9.85569477], [79.12208557, 9.85513878], [79.12180328, 9.85514069], [79.12180328, 9.85457993], [79.12152863, 9.85458279], [79.12152863, 9.85430527], [79.12095642, 9.85431194], [79.12095642, 9.85375118], [79.12069702, 9.85375118], [79.12069702, 9.85319519], [79.12041473, 9.85319519], [79.12041473, 9.85291672], [79.11985779, 9.85292053], [79.11985779, 9.85236073], [79.11958313, 9.85236073], [79.11958313, 9.85180664], [79.11930847, 9.85181141], [79.11930847, 9.85153103], [79.11875153, 9.85153103], [79.11875153, 9.85125065], [79.11846924, 9.85125065], [79.11846924, 9.85097027], [79.11819458, 9.85097313], [79.11819458, 9.85069466], [79.11791992, 9.85069466], [79.11791992, 9.85041714], [79.11736298, 9.85042095], [79.11736298, 9.85014057], [79.11708069, 9.85014057], [79.11708069, 9.8495779], [79.11680603, 9.84958458], [79.11680603, 9.8493042], [79.11653137, 9.84931087], [79.11653137, 9.84903145], [79.11624908, 9.84903145], [79.11624908, 9.84875011], [79.1159668, 9.84875011], [79.1159668, 9.84846973], [79.11569214, 9.84847164], [79.11569214, 9.84819412], [79.11541748, 9.84819412], [79.11541748, 9.84791565], [79.11515045, 9.84792137], [79.11515045, 9.84764099], [79.11486053, 9.84764099], [79.11486053, 9.84735966], [79.11458588, 9.84736156], [79.11458588, 9.84708214], [79.11430359, 9.84708214], [79.11430359, 9.84680557], [79.11374664, 9.84681129], [79.11374664, 9.84652138], [79.11347198, 9.84652805], [79.11347198, 9.84624958], [79.11319733, 9.84624958], [79.11319733, 9.84597015], [79.11291504, 9.84597206], [79.11291504, 9.84569359], [79.11235809, 9.84569359], [79.11235809, 9.84541607], [79.11209106, 9.84542274], [79.11209106, 9.84514046], [79.11180878, 9.84514046], [79.11180878, 9.84486008], [79.11152649, 9.84486008], [79.11152649, 9.84458447], [79.11125183, 9.84458447], [79.11125183, 9.84430599], [79.11068726, 9.84431076], [79.11068726, 9.84403038], [79.11042023, 9.84403038], [79.11042023, 9.84375], [79.11013794, 9.84375], [79.11013794, 9.84348106], [79.10986328, 9.84348106], [79.10986328, 9.84318924], [79.10958099, 9.84319401], [79.10958099, 9.84291553], [79.10930634, 9.8429203], [79.10930634, 9.84263992], [79.10901642, 9.84263992], [79.10901642, 9.84208202], [79.10874939, 9.84208393], [79.10874939, 9.84180641], [79.1084671, 9.84181023], [79.1084671, 9.84069061], [79.10819244, 9.84069443], [79.10819244, 9.84014034], [79.10791779, 9.84014034], [79.10791779, 9.83986187], [79.1076355, 9.83986187], [79.1076355, 9.83902836], [79.10791779, 9.83903027], [79.10791779, 9.83847237], [79.1076355, 9.83847237], [79.1076355, 9.83791542], [79.10736084, 9.83792019], [79.10736084, 9.83763981], [79.10679626, 9.83763981], [79.10679626, 9.83708096], [79.10624695, 9.83708382], [79.10624695, 9.8368063], [79.10595703, 9.83681011], [79.10595703, 9.83652973], [79.10542297, 9.83652973], [79.10542297, 9.83624935], [79.1048584, 9.83624935], [79.1048584, 9.83597088], [79.10430908, 9.83597088], [79.10430908, 9.83569336], [79.10402679, 9.83569336], [79.10402679, 9.83541775], [79.10346985, 9.83541965], [79.10346985, 9.83513927], [79.10321045, 9.83513927], [79.10321045, 9.83541965], [79.10263824, 9.83541965], [79.10263824, 9.83513927], [79.10235596, 9.83513927], [79.10235596, 9.83485889], [79.10097504, 9.8348608], [79.10097504, 9.83430481], [79.10041809, 9.83430958], [79.10041809, 9.83403015], [79.10015106, 9.83403015], [79.10015106, 9.83375072], [79.09958649, 9.83375072], [79.09958649, 9.8334713], [79.0993042, 9.8334713], [79.0993042, 9.83319473], [79.09874725, 9.83319473], [79.09874725, 9.83291721], [79.0984726, 9.83292198], [79.0984726, 9.8326416], [79.09792328, 9.8326416], [79.09792328, 9.83236122], [79.09764099, 9.83236122], [79.09764099, 9.83208275], [79.09708405, 9.83208275], [79.09708405, 9.83180523], [79.0967865, 9.8318119], [79.0967865, 9.83154106], [79.09625244, 9.83154106], [79.09622955, 9.83125114], [79.0956955, 9.83125114], [79.0956955, 9.83097267], [79.09541321, 9.83097267], [79.09541321, 9.83069515], [79.09486389, 9.83069515], [79.09486389, 9.83041668], [79.0945816, 9.83041859], [79.0945816, 9.83014107], [79.09401703, 9.83014107], [79.09401703, 9.82986069], [79.09375, 9.82986069], [79.09375, 9.82958317], [79.09347534, 9.82958317], [79.09347534, 9.8293047], [79.09319305, 9.82930946], [79.09319305, 9.82903099], [79.0929184, 9.82903099], [79.0929184, 9.82875061], [79.09263611, 9.82875061], [79.09263611, 9.82847977], [79.09208679, 9.82847977], [79.09208679, 9.82818985], [79.0918045, 9.82819462], [79.0918045, 9.8279171], [79.09152985, 9.82792091], [79.09152985, 9.82764053], [79.09124756, 9.82764053], [79.09124756, 9.82707977], [79.0909729, 9.82708263], [79.0909729, 9.82680511], [79.09069824, 9.82681179], [79.09069061, 9.82653141], [79.09041595, 9.82653141], [79.09041595, 9.82625103], [79.0901413, 9.82625103], [79.0901413, 9.82569027], [79.08985901, 9.82569504], [79.08985901, 9.82541656], [79.08957672, 9.82542133], [79.08957672, 9.82514095], [79.08930206, 9.82514095], [79.08930206, 9.82486057], [79.0890274, 9.82486057], [79.0890274, 9.82458305], [79.08875275, 9.82458305], [79.08875275, 9.82375145], [79.08847046, 9.82375145], [79.08847046, 9.82347012], [79.0881958, 9.82347298], [79.0881958, 9.82319546], [79.08791351, 9.82319546], [79.08791351, 9.82291603], [79.08763885, 9.82291889], [79.08763885, 9.82264137], [79.08735657, 9.82264137], [79.08735657, 9.82207966], [79.08708191, 9.82208538], [79.08708191, 9.82180691], [79.08680725, 9.82181072], [79.08680725, 9.8215313], [79.08653259, 9.8215313], [79.08653259, 9.82070065], [79.08625031, 9.82069016], [79.08625031, 9.82013798], [79.08598328, 9.82014275], [79.08598328, 9.81986046], [79.08569336, 9.81986237], [79.08569336, 9.81958199], [79.0854187, 9.81958199], [79.0854187, 9.8190279], [79.08513641, 9.81903267], [79.08513641, 9.81847], [79.08486176, 9.81847191], [79.08486176, 9.81791592], [79.0845871, 9.81792068], [79.0845871, 9.81735992], [79.08429718, 9.81735992], [79.08429718, 9.81681061], [79.08403015, 9.81681061], [79.08403015, 9.81624985], [79.08374786, 9.81624985], [79.08374786, 9.81569386], [79.08347321, 9.81569386], [79.08347321, 9.81513786], [79.08319092, 9.81514168], [79.08319092, 9.81486034], [79.08291626, 9.81486225], [79.08291626, 9.81430626], [79.0826416, 9.81431007], [79.0826416, 9.81375027], [79.08235931, 9.81375027], [79.08235931, 9.81319427], [79.08208466, 9.81319427], [79.08208466, 9.8120842], [79.08180237, 9.8120842], [79.08180237, 9.81152821], [79.08152771, 9.81153202], [79.08152771, 9.81124973], [79.08097076, 9.81124973], [79.08097076, 9.81013966], [79.08069611, 9.81013966], [79.08069611, 9.80985928], [79.08041382, 9.80986214], [79.08041382, 9.80847359], [79.08013916, 9.80847359], [79.08013916, 9.80708313], [79.0798645, 9.80708313], [79.0798645, 9.80541706], [79.07958221, 9.80542183], [79.07958221, 9.80375099], [79.07985687, 9.80375099], [79.07985687, 9.80264091], [79.07958221, 9.80264091], [79.07958221, 9.80180931], [79.07930756, 9.80180931], [79.07930756, 9.80125141], [79.07902527, 9.80125141], [79.07902527, 9.80069542], [79.07875061, 9.80069542], [79.07875061, 9.80041695], [79.07847595, 9.80041885], [79.07847595, 9.80014133], [79.07818604, 9.80014133], [79.07818604, 9.79957962], [79.07791901, 9.79958344], [79.07791901, 9.79902744], [79.07763672, 9.79903126], [79.07763672, 9.79875088], [79.07707977, 9.79875088], [79.07707977, 9.79846954], [79.07680511, 9.79847336], [79.07680511, 9.79819489], [79.07624817, 9.79819489], [79.07624817, 9.79791737], [79.07598114, 9.79792118], [79.07598114, 9.7976408], [79.07541656, 9.7976408], [79.07541656, 9.79736137], [79.07514191, 9.79736137], [79.07514191, 9.79708195], [79.07458496, 9.79708195], [79.07458496, 9.79680443], [79.07430267, 9.7968111], [79.07430267, 9.79653072], [79.07402802, 9.79653072], [79.07402802, 9.7962513], [79.07347107, 9.7962513], [79.07347107, 9.79597282], [79.07319641, 9.79597282], [79.07319641, 9.79569435], [79.07291412, 9.79569435], [79.07291412, 9.79541588], [79.07263947, 9.79541588], [79.07263947, 9.79513836], [79.07235718, 9.79514122], [79.07235718, 9.79486275], [79.07208252, 9.79486275], [79.07208252, 9.79458046], [79.07180786, 9.79458237], [79.07180786, 9.7943058], [79.0715332, 9.79431057], [79.0715332, 9.79403114], [79.07125092, 9.79403114], [79.07125092, 9.79375267], [79.07096863, 9.79375267], [79.07096863, 9.79347038], [79.07041931, 9.79347229], [79.07041931, 9.79319382], [79.07013702, 9.79319382], [79.07013702, 9.7929163], [79.06984711, 9.79292107], [79.06984711, 9.79263973], [79.06958008, 9.79263973], [79.06958008, 9.7923708], [79.06931305, 9.7923708], [79.06931305, 9.79207993], [79.06903076, 9.79208374], [79.06903076, 9.79152775], [79.06874847, 9.79152966], [79.06874847, 9.79125023], [79.06846619, 9.79125023], [79.06846619, 9.79068947], [79.06819153, 9.79069424], [79.06819153, 9.78985977], [79.06791687, 9.78986168], [79.06791687, 9.78958035], [79.06764221, 9.78958416], [79.06764221, 9.78902817], [79.06735992, 9.78903008], [79.06735992, 9.78847027], [79.06708527, 9.78847218], [79.06708527, 9.78791809], [79.06681061, 9.78792], [79.06681061, 9.78736019], [79.06652832, 9.7873621], [79.06652832, 9.78680611], [79.06624603, 9.78680992], [79.06624603, 9.78624058], [79.06597137, 9.78625011], [79.06597137, 9.78597164], [79.06541443, 9.78597164], [79.06541443, 9.78569412], [79.06513977, 9.78569412], [79.06513977, 9.78541565], [79.06485748, 9.78542042], [79.06485748, 9.78486156], [79.06458282, 9.78486156], [79.06458282, 9.78458405], [79.06430817, 9.78458405], [79.06430817, 9.78430557], [79.06404114, 9.78431034], [79.06404114, 9.78402996], [79.06375122, 9.78402996], [79.06375122, 9.78374958], [79.06346893, 9.78374958], [79.06346893, 9.7834692], [79.06319427, 9.78347111], [79.06319427, 9.78319263], [79.06291962, 9.78319263], [79.06291962, 9.78291798], [79.06263733, 9.78292179], [79.06263733, 9.78236198], [79.06236267, 9.78236198], [79.06236267, 9.78180504], [79.06208038, 9.78180981], [79.06208038, 9.78125191], [79.06181335, 9.78125191], [79.06181335, 9.78043079], [79.06153107, 9.78043079], [79.06153107, 9.77958107], [79.06124878, 9.77958298], [79.06124878, 9.77875137], [79.06096649, 9.77875137], [79.06096649, 9.7776413], [79.06069183, 9.7776413], [79.06069183, 9.77737045], [79.06041718, 9.77737045], [79.06041718, 9.77680969], [79.06014252, 9.77680969], [79.06014252, 9.77652931], [79.05986023, 9.77652931], [79.05986023, 9.77541924], [79.0595932, 9.77541924], [79.0595932, 9.77486134], [79.05930328, 9.77486134], [79.05930328, 9.77458286], [79.05902863, 9.77458286], [79.05902863, 9.77430534], [79.05874634, 9.77430534], [79.05874634, 9.77375126], [79.05847168, 9.77375126], [79.05847168, 9.77347279], [79.05819702, 9.77347279], [79.05819702, 9.77319527], [79.05791473, 9.77319527], [79.05791473, 9.77263927], [79.05764008, 9.77264118], [79.05764008, 9.7723608], [79.05735779, 9.7723608], [79.05735779, 9.77208328], [79.05680847, 9.77208328], [79.05680847, 9.77180672], [79.05596924, 9.77181053], [79.05596924, 9.77153111], [79.05487061, 9.77153111], [79.05487061, 9.77123928], [79.05403137, 9.77125072], [79.05403137, 9.77097321], [79.05347443, 9.77097321], [79.05347443, 9.77069473], [79.05291748, 9.77069473], [79.05291748, 9.77041721], [79.05264282, 9.77042103], [79.05264282, 9.77014065], [79.05210114, 9.77014065], [79.05210114, 9.76986027], [79.05180359, 9.76986027], [79.05180359, 9.76958466], [79.05124664, 9.76958466], [79.05124664, 9.76930428], [79.05097198, 9.76931095], [79.05097198, 9.76875114], [79.04957581, 9.76875114], [79.04957581, 9.76820087], [79.04875183, 9.76820087], [79.04875183, 9.76792145], [79.04680634, 9.76792145], [79.04680634, 9.76764107], [79.0459671, 9.76764107], [79.0459671, 9.76735973], [79.04541779, 9.76735973], [79.04541779, 9.76708221], [79.04528809, 9.76708221], [79.04486084, 9.76708221], [79.04486084, 9.76680565], [79.04429626, 9.76681137], [79.04429626, 9.76653099], [79.04347229, 9.76653099], [79.04347229, 9.76624966], [79.0429306, 9.76624966], [79.0429306, 9.76597023], [79.04180908, 9.76597023], [79.04180908, 9.76624966], [79.04152679, 9.76624966], [79.04152679, 9.76597023], [79.04125214, 9.76597214], [79.04125214, 9.76513767], [79.04096985, 9.76513958], [79.04096985, 9.76486015], [79.0404129, 9.76486015], [79.0404129, 9.76458359], [79.04013824, 9.76458359], [79.04013824, 9.76430607], [79.03987122, 9.76431084], [79.03987122, 9.76403046], [79.03930664, 9.76403046], [79.03930664, 9.76375008], [79.03901672, 9.76375008], [79.03901672, 9.7634697], [79.03874969, 9.7634716], [79.03874969, 9.76319408], [79.03847504, 9.76319408], [79.03847504, 9.76291561], [79.03819275, 9.76292038], [79.03819275, 9.76264], [79.0376358, 9.76264], [79.0376358, 9.76235962], [79.03736115, 9.76236153], [79.03736115, 9.76208401], [79.03708649, 9.76208401], [79.03708649, 9.76180553], [79.03681183, 9.76181126], [79.03681183, 9.76124954], [79.03652954, 9.76124954], [79.03652954, 9.76097202], [79.03624725, 9.76097202], [79.03624725, 9.76069355], [79.0359726, 9.76069355], [79.0359726, 9.76013756], [79.03569794, 9.76014042], [79.03569794, 9.75986195], [79.03541565, 9.75986195], [79.03541565, 9.75958443], [79.03514099, 9.75958443], [79.03514099, 9.75902843], [79.0348587, 9.75903034], [79.0348587, 9.75847244], [79.03458405, 9.75847244], [79.03458405, 9.75791645], [79.03430176, 9.75792027], [79.03430176, 9.75735855], [79.0340271, 9.75736237], [79.0340271, 9.75708389], [79.03375244, 9.75708389], [79.03375244, 9.75680637], [79.03347015, 9.75681019], [79.03347015, 9.75626087], [79.03320313, 9.75626087], [79.03320313, 9.75597095], [79.03291321, 9.75597095], [79.03291321, 9.75564957], [79.03291321, 9.75541782], [79.03263855, 9.75541973], [79.03263855, 9.7551403], [79.03235626, 9.7551403], [79.03235626, 9.75458145], [79.0320816, 9.75458336], [79.0320816, 9.75430489], [79.03180695, 9.75430965], [79.03180695, 9.75374889], [79.03151703, 9.75374889], [79.03151703, 9.75347137], [79.03125, 9.75347137], [79.03125, 9.75319481], [79.0309906, 9.75319958], [79.0309906, 9.75292015], [79.0304184, 9.75292015], [79.0304184, 9.75264168], [79.03013611, 9.75264168], [79.03013611, 9.7523613], [79.02986145, 9.7523613], [79.02986145, 9.75208282], [79.02958679, 9.75208282], [79.02958679, 9.75152683], [79.02929688, 9.7515316], [79.02929688, 9.75125122], [79.02902985, 9.75125122], [79.02902985, 9.75069523], [79.02874756, 9.75069523], [79.02874756, 9.75013924], [79.0284729, 9.75013924], [79.0284729, 9.74958324], [79.02819824, 9.74958324], [79.02819061, 9.74874878], [79.02793121, 9.74875069], [79.02793121, 9.74818993], [79.0276413, 9.74819469], [79.0276413, 9.7476387], [79.02735901, 9.74764061], [79.02735901, 9.74707127], [79.02708435, 9.74708271], [79.02708435, 9.74680519], [79.02680206, 9.74681187], [79.02680206, 9.74653053], [79.0265274, 9.74653053], [79.0265274, 9.74597073], [79.02625275, 9.74597263], [79.02625275, 9.74569511], [79.02597046, 9.74569511], [79.02597046, 9.74541664], [79.0256958, 9.74542141], [79.0256958, 9.74514103], [79.02540588, 9.74514103], [79.02540588, 9.74486065], [79.02513885, 9.74486065], [79.02513885, 9.74458313], [79.0248642, 9.74458313], [79.0248642, 9.74430466], [79.02430725, 9.74431992], [79.02430725, 9.74403095], [79.02403259, 9.74403095], [79.02403259, 9.74347019], [79.02375031, 9.74347305], [79.02375031, 9.74319458], [79.02347565, 9.74319458], [79.02347565, 9.74291706], [79.0229187, 9.74292088], [79.0229187, 9.74264145], [79.02263641, 9.74264145], [79.02263641, 9.74236012], [79.02236176, 9.74236012], [79.02236176, 9.74208546], [79.0220871, 9.74208546], [79.0220871, 9.74180698], [79.02179718, 9.74180889], [79.02179718, 9.74153137], [79.02124786, 9.74153137], [79.02124786, 9.74125957], [79.02097321, 9.74125957], [79.02097321, 9.74096966], [79.02069092, 9.74097157], [79.02069092, 9.74069405], [79.02041626, 9.74069405], [79.02041626, 9.74013805], [79.0201416, 9.74014091], [79.0201416, 9.73985958], [79.01985931, 9.73986244], [79.01985931, 9.73930645], [79.01957703, 9.73931122], [79.01957703, 9.73875046], [79.01930237, 9.73875046], [79.01930237, 9.73819447], [79.01902771, 9.73819447], [79.01902771, 9.73763847], [79.01873779, 9.73764038], [79.01873779, 9.73681068], [79.01847076, 9.73681068], [79.01847076, 9.73596954], [79.01819611, 9.7359724], [79.01819611, 9.73513794], [79.01791382, 9.73513794], [79.01791382, 9.73430634], [79.01763916, 9.7343111], [79.01763916, 9.73375034], [79.01735687, 9.73375034], [79.01735687, 9.73319054], [79.01763916, 9.73319435], [79.01763916, 9.73264027], [79.01735687, 9.73264027], [79.01735687, 9.73236179], [79.01708221, 9.73236179], [79.01708221, 9.73206997], [79.01680756, 9.73208427], [79.01680756, 9.7318058], [79.0165329, 9.73180962], [79.0165329, 9.73153019], [79.01625061, 9.73153019], [79.01625061, 9.73124981], [79.01597595, 9.73124981], [79.01597595, 9.73097229], [79.01569366, 9.73097229], [79.01569366, 9.73041534], [79.01541901, 9.73042011], [79.01541901, 9.73013973], [79.01513672, 9.73013973], [79.01513672, 9.72985935], [79.01486206, 9.72986221], [79.01486206, 9.72958374], [79.01457977, 9.72958374], [79.01457977, 9.72930622], [79.01431274, 9.72932053], [79.01431274, 9.72902966], [79.01403046, 9.72902966], [79.01403046, 9.72874928], [79.01374817, 9.72874928], [79.01374817, 9.72847366], [79.01347351, 9.7284708], [79.01347351, 9.72819328], [79.01319122, 9.72819328], [79.01319122, 9.72791767], [79.01291656, 9.72791958], [79.01291656, 9.7276392], [79.01235962, 9.7276392], [79.01235962, 9.72736073], [79.01208496, 9.72736073], [79.01208496, 9.72708321], [79.01180267, 9.72708321], [79.01180267, 9.72680473], [79.01152802, 9.72681046], [79.01152802, 9.72653198], [79.01125336, 9.72653198], [79.01125336, 9.72625065], [79.00985718, 9.72625065], [79.00985718, 9.72597122], [79.00958252, 9.72597122], [79.00958252, 9.72569466], [79.00930786, 9.72569466], [79.00930786, 9.72541714], [79.0090332, 9.72542191], [79.0090332, 9.72514153], [79.00875092, 9.72514153], [79.00875092, 9.72458076], [79.00846863, 9.72458267], [79.00846863, 9.7234726], [79.00819397, 9.7234726], [79.00819397, 9.72319508], [79.00791931, 9.72319508], [79.00791931, 9.72263908], [79.00763702, 9.72264099], [79.00763702, 9.72180939], [79.00736237, 9.72180939], [79.00736237, 9.72125053], [79.00708008, 9.72125053], [79.00708008, 9.72013187], [79.00680542, 9.72013855], [79.00680542, 9.71986103], [79.00596619, 9.71986103], [79.00596619, 9.7195797], [79.00569153, 9.71958256], [79.00569153, 9.71902657], [79.00541687, 9.71903133], [79.00541687, 9.71847057], [79.00514221, 9.71847343], [79.00514221, 9.71819496], [79.00485992, 9.71819496], [79.00485992, 9.71763897], [79.0045929, 9.71764088], [79.0045929, 9.71709156], [79.00430298, 9.71709156], [79.00430298, 9.71681118], [79.00402832, 9.71681118], [79.00402832, 9.7165308], [79.00347137, 9.7165308], [79.00347137, 9.71625137], [79.00319672, 9.71625137], [79.00319672, 9.7159729], [79.00291443, 9.7159729], [79.00291443, 9.71569538], [79.00263977, 9.71569538], [79.00263977, 9.71541595], [79.00180817, 9.71542072], [79.00180817, 9.7151413], [79.00152588, 9.7151413], [79.00152588, 9.71457958], [79.00125122, 9.71458244], [79.00125122, 9.71430683], [79.00096893, 9.71431065], [79.00096893, 9.71403122], [79.0007019, 9.71403122], [79.0007019, 9.71375275], [78.99986267, 9.71375275], [78.99986267, 9.71347046], [78.99930573, 9.71347237], [78.99930573, 9.71319389], [78.99874878, 9.71319389], [78.99874878, 9.71291637], [78.99819183, 9.71292114], [78.99819183, 9.71264267], [78.99791718, 9.71264267], [78.99791718, 9.71236038], [78.99764252, 9.71236229], [78.99764252, 9.71208382], [78.99736023, 9.71208191], [78.99736023, 9.71152782], [78.9970932, 9.71153069], [78.9970932, 9.71125031], [78.99680328, 9.71125031], [78.99680328, 9.71097183], [78.99652863, 9.71097183], [78.99652863, 9.71069431], [78.99624634, 9.71069431], [78.99624634, 9.71041584], [78.99597168, 9.71042061], [78.99597168, 9.71014023], [78.99569702, 9.71014023], [78.99569702, 9.70958042], [78.99514008, 9.70958424], [78.99514008, 9.70930576], [78.99485779, 9.70931053], [78.99485779, 9.70903015], [78.99456787, 9.70903015], [78.99456787, 9.70875168], [78.99430847, 9.70875168], [78.99430847, 9.70847034], [78.99402618, 9.70847225], [78.99402618, 9.70791626], [78.99375153, 9.70792007], [78.99375153, 9.70736027], [78.99346924, 9.70736217], [78.99346924, 9.7070837], [78.99319458, 9.7070837], [78.99319458, 9.70680618], [78.99291992, 9.70681], [78.99291992, 9.70625019], [78.99263763, 9.70625019], [78.99263763, 9.7056942], [78.99236298, 9.7056942], [78.99236298, 9.70514011], [78.99208069, 9.7051506], [78.99208069, 9.70486164], [78.99180603, 9.70486164], [78.99180603, 9.70430565], [78.99153137, 9.70431042], [78.99153137, 9.70403004], [78.99124908, 9.70403004], [78.99124908, 9.70374966], [78.9909668, 9.70374966], [78.9909668, 9.70346928], [78.99069214, 9.70347214], [78.99069214, 9.70291805], [78.99041748, 9.70291996], [78.99041748, 9.70097065], [78.99013519, 9.70097446], [78.99013519, 9.70013905], [78.98986053, 9.70014191], [78.98986053, 9.69958115], [78.98958588, 9.69958305], [78.98958588, 9.69930458], [78.98929596, 9.6993103], [78.98929596, 9.69875145], [78.98902893, 9.69875145], [78.98902893, 9.69847107], [78.98874664, 9.69847107], [78.98874664, 9.69791698], [78.98847198, 9.69791985], [78.98847198, 9.69736099], [78.98819733, 9.69736099], [78.98819733, 9.696805], [78.98792267, 9.69680977], [78.98792267, 9.69652939], [78.98764038, 9.69652939], [78.98764038, 9.69625092], [78.98735809, 9.69625092], [78.98735809, 9.69596195], [78.98708344, 9.6959734], [78.98708344, 9.69569492], [78.98680878, 9.69569492], [78.98680878, 9.6954174], [78.98652649, 9.69541931], [78.98652649, 9.69514084], [78.98596954, 9.69514084], [78.98596954, 9.69486141], [78.98569489, 9.69486141], [78.98569489, 9.69458294], [78.98542023, 9.69458294], [78.98542023, 9.69430542], [78.98513794, 9.69430923], [78.98513794, 9.69402885], [78.98458099, 9.69402885], [78.98458099, 9.69375134], [78.98430634, 9.69375134], [78.98430634, 9.69319534], [78.98402405, 9.69319534], [78.98402405, 9.69291687], [78.98374939, 9.69292068], [78.98374939, 9.69264126], [78.9834671, 9.69264126], [78.9834671, 9.69236088], [78.98319244, 9.69236088], [78.98319244, 9.69208336], [78.98291779, 9.69208336], [78.98291779, 9.69180679], [78.98262787, 9.69181061], [78.98262787, 9.69153118], [78.98236084, 9.69153118], [78.98236084, 9.69097042], [78.98208618, 9.69097328], [78.98208618, 9.69069481], [78.98180389, 9.69069481], [78.98180389, 9.69041729], [78.98152924, 9.6904211], [78.98152924, 9.6898613], [78.98124695, 9.6898613], [78.98124695, 9.68930435], [78.98097229, 9.68931103], [78.98097229, 9.68903065], [78.98069763, 9.68903065], [78.98069763, 9.68847275], [78.98041534, 9.68847275], [78.98041534, 9.68735981], [78.9798584, 9.68735981], [78.9798584, 9.68680573], [78.97959137, 9.68681145], [78.97959137, 9.68597031], [78.97930908, 9.68597221], [78.97930908, 9.68513775], [78.97902679, 9.68513966], [78.97902679, 9.68431091], [78.97875214, 9.68431091], [78.97875214, 9.68375015], [78.97846985, 9.68375015], [78.97846985, 9.68291569], [78.97820282, 9.68292141], [78.97820282, 9.68264008], [78.9779129, 9.68264008], [78.9779129, 9.68208027], [78.97763824, 9.68208408], [78.97763824, 9.68152809], [78.97735596, 9.68153], [78.97735596, 9.68124962], [78.9770813, 9.68124962], [78.9770813, 9.68068886], [78.97680664, 9.68069363], [78.97680664, 9.68013763], [78.97653198, 9.68013954], [78.97653198, 9.67958164], [78.97624969, 9.67958355], [78.97624969, 9.67902756], [78.97598267, 9.67903042], [78.97598267, 9.67847157], [78.97569275, 9.67847157], [78.97569275, 9.67763996], [78.97541809, 9.67763996], [78.97541809, 9.6770792], [78.9751358, 9.67708397], [78.9751358, 9.6754179], [78.97486115, 9.67541981], [78.97486115, 9.67458057], [78.97458649, 9.67458344], [78.97458649, 9.67319489], [78.9743042, 9.67319489], [78.9743042, 9.67263889], [78.97402954, 9.67263889], [78.97402954, 9.67208099], [78.97374725, 9.6720829], [78.97374725, 9.67180538], [78.97345734, 9.67181015], [78.97345734, 9.6712513], [78.97319794, 9.6712513], [78.97319794, 9.67041683], [78.97292328, 9.6704216], [78.97292328, 9.66958141], [78.97264099, 9.66958332], [78.97264099, 9.66930485], [78.9723587, 9.66930962], [78.9723587, 9.66875076], [78.97207642, 9.66875076], [78.97207642, 9.66847134], [78.97180176, 9.66847324], [78.97180176, 9.66763878], [78.9715271, 9.66764069], [78.9715271, 9.66653061], [78.97180176, 9.66653061], [78.97180176, 9.66625118], [78.9715271, 9.66625118], [78.9715271, 9.66486073], [78.97125244, 9.66486073], [78.97125244, 9.66402912], [78.97097015, 9.66403103], [78.97097015, 9.66291046], [78.9706955, 9.66291714], [78.9706955, 9.66152859], [78.97097015, 9.66153145], [78.97097015, 9.66069031], [78.97125244, 9.66069412], [78.97125244, 9.65902805], [78.97097015, 9.65903091], [78.97097015, 9.65847015], [78.97125244, 9.65847206], [78.97125244, 9.65597153], [78.97097015, 9.65597153], [78.97097015, 9.65541553], [78.97068787, 9.65542126], [78.97068787, 9.65513992], [78.97039795, 9.65513992], [78.97039795, 9.65431118], [78.97013855, 9.65431118], [78.97013855, 9.65319157], [78.96986389, 9.65319443], [78.96986389, 9.65236187], [78.9695816, 9.65236187], [78.9695816, 9.65208435], [78.96930695, 9.65208435], [78.96930695, 9.65152836], [78.96901703, 9.65153027], [78.96901703, 9.65125179], [78.96875, 9.65125179], [78.96875, 9.65069103], [78.96847534, 9.6506958], [78.96847534, 9.65041637], [78.96819305, 9.65042019], [78.96819305, 9.65013981], [78.9679184, 9.65013981], [78.9679184, 9.64958382], [78.96763611, 9.64958382], [78.96763611, 9.6493063], [78.96736145, 9.64931011], [78.96736145, 9.64902973], [78.96708679, 9.64902973], [78.96708679, 9.64874935], [78.96679688, 9.64874935], [78.96679688, 9.64791107], [78.96652985, 9.64791775], [78.96652985, 9.64708328], [78.96624756, 9.64708328], [78.96624756, 9.64624882], [78.9659729, 9.64625168], [78.9659729, 9.6459713], [78.96541595, 9.6459713], [78.96541595, 9.64541721], [78.96485901, 9.64542198], [78.96485901, 9.6451416], [78.96459198, 9.6451416], [78.96459198, 9.64291859], [78.96430206, 9.64291859], [78.96430206, 9.64181042], [78.9640274, 9.64181042], [78.9640274, 9.64153099], [78.96375275, 9.64153099], [78.96375275, 9.64097118], [78.96347046, 9.64097309], [78.96347046, 9.64069462], [78.9631958, 9.64069462], [78.9631958, 9.6404171], [78.96290588, 9.64042187], [78.96290588, 9.64014053], [78.96263885, 9.64014053], [78.96263885, 9.64042187], [78.9623642, 9.6404171], [78.9623642, 9.64069462], [78.96263885, 9.64068985], [78.96263885, 9.64125061], [78.96235657, 9.64125061], [78.96235657, 9.64181042], [78.96208191, 9.6418047], [78.96208191, 9.64236069], [78.96125031, 9.64236069], [78.96125031, 9.64152908], [78.96151733, 9.64153099], [78.96151733, 9.64042187], [78.96125031, 9.64042187], [78.96125031, 9.63958073], [78.96152496, 9.63958263], [78.96152496, 9.63902664], [78.96180725, 9.63903141], [78.96180725, 9.63819027], [78.96208191, 9.63819504], [78.96208191, 9.63791656], [78.96180725, 9.63792133], [78.96180725, 9.63708019], [78.96152496, 9.63708305], [78.96152496, 9.63652897], [78.96125031, 9.63653088], [78.96125031, 9.63541889], [78.96098328, 9.63541889], [78.96098328, 9.6340313], [78.96069336, 9.6340313], [78.96069336, 9.63346958], [78.9604187, 9.63347244], [78.9604187, 9.63291645], [78.96013641, 9.6329298], [78.96013641, 9.63208199], [78.95986176, 9.63208199], [78.95986176, 9.63041592], [78.9595871, 9.63042068], [78.9595871, 9.62987137], [78.95929718, 9.62987137], [78.95929718, 9.62957954], [78.95903015, 9.62958431], [78.95903015, 9.62902832], [78.95874786, 9.62903023], [78.95874786, 9.62874985], [78.95845795, 9.62874985], [78.95845795, 9.62847042], [78.95819092, 9.62847233], [78.95819092, 9.62819386], [78.95791626, 9.62819386], [78.95791626, 9.62791634], [78.95735931, 9.62792015], [78.95735931, 9.62764168], [78.95707703, 9.62764168], [78.95707703, 9.62736034], [78.95680237, 9.62736225], [78.95680237, 9.62680626], [78.95652771, 9.62681103], [78.95652771, 9.62652969], [78.95625305, 9.62652969], [78.95625305, 9.62597179], [78.95597076, 9.62597179], [78.95597076, 9.6254158], [78.95571136, 9.62541962], [78.95571136, 9.62514019], [78.95539856, 9.62514019], [78.95539856, 9.62485981], [78.9548645, 9.62486172], [78.9548645, 9.6245842], [78.95458221, 9.6245842], [78.95458221, 9.62430573], [78.9540329, 9.62430954], [78.9540329, 9.62374115], [78.95319366, 9.62374973], [78.95319366, 9.62347221], [78.95263672, 9.62347221], [78.95263672, 9.62319565], [78.95236206, 9.62319565], [78.95236206, 9.62291527], [78.95207977, 9.62292004], [78.95207977, 9.62263966], [78.95181274, 9.62263966], [78.95181274, 9.62235928], [78.95153046, 9.62236214], [78.95153046, 9.62208366], [78.95097351, 9.62208366], [78.95097351, 9.62180614], [78.95014191, 9.62180996], [78.95014191, 9.62152958], [78.94957733, 9.62152958], [78.94957733, 9.6212492], [78.94930267, 9.6212492], [78.94930267, 9.62097359], [78.94902802, 9.62097359], [78.94902802, 9.62069321], [78.94875336, 9.62069321], [78.94875336, 9.62041759], [78.94790649, 9.62042046], [78.94790649, 9.62014198], [78.94735718, 9.62014198], [78.94735718, 9.61986065], [78.94708252, 9.61986065], [78.94708252, 9.61958313], [78.94625092, 9.61958313], [78.94625092, 9.61902714], [78.94568634, 9.61903191], [78.94568634, 9.61875057], [78.94541931, 9.61875057], [78.94541931, 9.61847115], [78.94513702, 9.61847115], [78.94513702, 9.61819458], [78.94458008, 9.61819458], [78.94458008, 9.61791706], [78.94431305, 9.61793137], [78.94431305, 9.6176424], [78.94403076, 9.6176424], [78.94403076, 9.61736107], [78.94374847, 9.61736107], [78.94374847, 9.61680508], [78.94345856, 9.61680984], [78.94345856, 9.61652946], [78.94319153, 9.61652946], [78.94319153, 9.61597061], [78.94235992, 9.61597347], [78.94235992, 9.61541653], [78.9420929, 9.61541939], [78.9420929, 9.61514091], [78.94180298, 9.61514091], [78.94180298, 9.61486053], [78.94152832, 9.61486053], [78.94152832, 9.61458302], [78.94125366, 9.61458302], [78.94125366, 9.61430454], [78.94097137, 9.61430931], [78.94097137, 9.61403084], [78.94071198, 9.61403084], [78.94071198, 9.61375141], [78.94041443, 9.61375141], [78.94041443, 9.61347294], [78.94013977, 9.61347294], [78.94013977, 9.61319542], [78.93985748, 9.61319542], [78.93985748, 9.61263943], [78.93958282, 9.61264133], [78.93958282, 9.61236095], [78.93930817, 9.61236095], [78.93930817, 9.61180687], [78.93902588, 9.61180687], [78.93902588, 9.61152744], [78.93875122, 9.61153126], [78.93875122, 9.61097145], [78.93846893, 9.61097336], [78.93846893, 9.61069489], [78.93791962, 9.61069489], [78.93791962, 9.61041737], [78.93763733, 9.61042118], [78.93763733, 9.6101408], [78.93708038, 9.6101408], [78.93708038, 9.60986137], [78.93653107, 9.60986137], [78.93653107, 9.6095829], [78.93624878, 9.6095829], [78.93624878, 9.60930443], [78.93596649, 9.6093092], [78.93596649, 9.60903072], [78.93569183, 9.60903072], [78.93569183, 9.6087389], [78.93541718, 9.6087513], [78.93541718, 9.60847282], [78.93514252, 9.60847282], [78.93514252, 9.6081953], [78.93486023, 9.6081953], [78.93486023, 9.60763836], [78.93457794, 9.60764122], [78.93457794, 9.60681057], [78.93428802, 9.60681057], [78.93428802, 9.60292053], [78.93402863, 9.60292053], [78.93402863, 9.60208035], [78.93374634, 9.60208416], [78.93374634, 9.60152817], [78.93347168, 9.60153008], [78.93347168, 9.60097027], [78.93319702, 9.60097218], [78.93319702, 9.60041809], [78.9329071, 9.60042], [78.9329071, 9.59986019], [78.93264008, 9.5998621], [78.93264008, 9.59930611], [78.93235779, 9.59930992], [78.93235779, 9.59902954], [78.93208313, 9.59902954], [78.93208313, 9.59847164], [78.93180847, 9.59847164], [78.93180847, 9.59819412], [78.93152618, 9.59819412], [78.93152618, 9.59764004], [78.93125153, 9.59764004], [78.93125153, 9.59707928], [78.93096924, 9.59708405], [78.93096924, 9.59652805], [78.93068695, 9.59652996], [78.93068695, 9.5959692], [78.93041992, 9.59597206], [78.93041992, 9.59541798], [78.93013763, 9.59542179], [78.93013763, 9.59514046], [78.92986298, 9.59514046], [78.92986298, 9.59458065], [78.92958069, 9.59458447], [78.92958069, 9.59402657], [78.92930603, 9.59403038], [78.92930603, 9.59264183], [78.92903137, 9.59264183], [78.92903137, 9.59181023], [78.92930603, 9.59181023], [78.92930603, 9.59013939], [78.92903137, 9.59013939], [78.92903137, 9.58958054], [78.92874908, 9.5895834], [78.92874908, 9.5890274], [78.92848206, 9.58902931], [78.92848206, 9.58847141], [78.92819214, 9.58847332], [78.92819214, 9.58791733], [78.92791748, 9.58791924], [78.92791748, 9.58708096], [78.92763519, 9.58708286], [78.92763519, 9.58625126], [78.92736053, 9.58625126], [78.92736053, 9.58319473], [78.92763519, 9.58319473], [78.92763519, 9.58152866], [78.92791748, 9.58153057], [78.92791748, 9.5809679], [78.92819214, 9.58097267], [78.92819214, 9.58041573], [78.92764282, 9.58042145], [78.92764282, 9.57958031], [78.92736053, 9.57958221], [78.92736053, 9.57930565], [78.92764282, 9.57931137], [78.92764282, 9.57903099], [78.92736053, 9.57903099], [78.92736053, 9.57875919], [78.92708588, 9.57875919], [78.92708588, 9.57847023], [78.92680359, 9.57847214], [78.92680359, 9.57791615], [78.92652893, 9.57792091], [78.92652893, 9.57681084], [78.92624664, 9.57681084], [78.92624664, 9.57625008], [78.92597198, 9.57625008], [78.92597198, 9.57514], [78.92569733, 9.57514], [78.92569733, 9.57431126], [78.92542267, 9.57431126], [78.92542267, 9.57402992], [78.92514038, 9.57402992], [78.92514038, 9.57374954], [78.92485809, 9.57374954], [78.92485809, 9.57347202], [78.92458344, 9.57347202], [78.92458344, 9.57291794], [78.92430878, 9.57291985], [78.92430878, 9.57236195], [78.92402649, 9.57236195], [78.92402649, 9.57013988], [78.92375183, 9.57014179], [78.92375183, 9.56902981], [78.92402649, 9.56902981], [78.92402649, 9.56847095], [78.92430878, 9.56847095], [78.92430878, 9.56819344], [78.92402649, 9.56819344], [78.92402649, 9.56791782], [78.92375183, 9.56791973], [78.92375183, 9.56708145], [78.92346954, 9.56708336], [78.92346954, 9.56680489], [78.92318726, 9.56681919], [78.92318726, 9.56597137], [78.92292023, 9.56597137], [78.92292023, 9.56541729], [78.92263794, 9.56542015], [78.92263794, 9.56514168], [78.92234802, 9.56514168], [78.92234802, 9.56431198], [78.92208099, 9.56431198], [78.92208099, 9.56346035], [78.92236328, 9.56347084], [78.92236328, 9.56236076], [78.92263794, 9.56236076], [78.92263794, 9.56097126], [78.92236328, 9.56097317], [78.92236328, 9.55986118], [78.92263794, 9.55986118], [78.92263794, 9.55958271], [78.92236328, 9.55958271], [78.92236328, 9.55875111], [78.92263794, 9.55875111], [78.92263794, 9.55847263], [78.92236328, 9.55847263], [78.92236328, 9.55819511], [78.92208099, 9.55819511], [78.92208099, 9.55708313], [78.92180634, 9.55708313], [78.92180634, 9.55652905], [78.92151642, 9.55653095], [78.92151642, 9.5556879], [78.92124939, 9.55569458], [78.92124939, 9.55513859], [78.92151642, 9.55514145], [78.92151642, 9.55486012], [78.92124939, 9.55486012], [78.92124939, 9.55347157], [78.92097473, 9.55347157], [78.92097473, 9.55291557], [78.92069244, 9.5529213], [78.92069244, 9.5506897], [78.92041779, 9.55069447], [78.92041779, 9.55013847], [78.92014313, 9.55014038], [78.92014313, 9.54846096], [78.91986084, 9.5484724], [78.91986084, 9.54597187], [78.91958618, 9.54597187], [78.91958618, 9.54514027], [78.91928864, 9.54514027], [78.91928864, 9.54430962], [78.91902924, 9.54430962], [78.91902924, 9.54292011], [78.91874695, 9.54292011], [78.91874695, 9.54069138], [78.91902924, 9.54069328], [78.91902924, 9.53986073], [78.91874695, 9.53986073], [78.91874695, 9.53958321], [78.91847229, 9.53958321], [78.91847229, 9.53652668], [78.91874695, 9.53652668], [78.91874695, 9.5359726], [78.91902924, 9.5359726], [78.91902924, 9.53569508], [78.91930389, 9.53569508], [78.91930389, 9.53486061], [78.91986084, 9.53486061], [78.91986084, 9.53458309], [78.9201355, 9.53458309], [78.9201355, 9.53430462], [78.92041779, 9.53431034], [78.92041779, 9.53403091], [78.92069244, 9.53403091], [78.92069244, 9.53347969], [78.92124939, 9.53347969], [78.92124939, 9.53318977], [78.92152405, 9.53319454], [78.92152405, 9.53263855], [78.92180634, 9.53264141], [78.92180634, 9.53236103], [78.92208099, 9.53236103], [78.92208099, 9.53208256], [78.92236328, 9.53208256], [78.92236328, 9.53097343], [78.92263794, 9.53097343], [78.92263794, 9.52986145], [78.92236328, 9.52986145], [78.92236328, 9.52958298], [78.92208099, 9.52958298], [78.92208099, 9.52930546], [78.92180634, 9.52930927], [78.92180634, 9.52902889], [78.92208099, 9.52902889], [78.92208099, 9.52847004], [78.92236328, 9.5284729], [78.92236328, 9.52735996], [78.92208099, 9.52735996], [78.92208099, 9.52680683], [78.92180634, 9.52681065], [78.92180634, 9.52597046], [78.92152405, 9.52597237], [78.92152405, 9.5243063], [78.92124939, 9.52431107], [78.92124939, 9.52403069], [78.9209671, 9.52403069], [78.9209671, 9.52375031], [78.92069244, 9.52375031], [78.92069244, 9.52291584], [78.92041779, 9.52292061], [78.92041779, 9.52264023], [78.92014313, 9.52264023], [78.92014313, 9.52235985], [78.91986084, 9.52235985], [78.91986084, 9.52180576], [78.91960144, 9.52181053], [78.91960144, 9.52153969], [78.91928864, 9.52153969], [78.91928864, 9.52097034], [78.91902924, 9.52097225], [78.91902924, 9.51902771], [78.91874695, 9.51902962], [78.91874695, 9.51848125], [78.91847229, 9.51848125], [78.91847229, 9.51819134], [78.91819763, 9.5181942], [78.91819763, 9.51791573], [78.91707611, 9.51791954], [78.91707611, 9.51764202], [78.91680908, 9.51764202], [78.91680908, 9.51681042], [78.91707611, 9.51681042], [78.91707611, 9.51653004], [78.9173584, 9.51653004], [78.9173584, 9.5156889], [78.91708374, 9.51569366], [78.91708374, 9.51458359], [78.91680908, 9.51458359], [78.91680908, 9.51430607], [78.91654205, 9.51428986], [78.91652679, 9.51347446], [78.91625214, 9.51347446], [78.91625214, 9.51236057], [78.91596985, 9.51236057], [78.91596985, 9.51013947], [78.91570282, 9.51014233], [78.91570282, 9.50958061], [78.9154129, 9.50958347], [78.9154129, 9.509305], [78.91513824, 9.50930977], [78.91513824, 9.50875092], [78.91485596, 9.50875092], [78.91485596, 9.50542068], [78.91513824, 9.50542068], [78.91513824, 9.50514126], [78.91570282, 9.50514126], [78.91570282, 9.50457954], [78.9154129, 9.50458336], [78.9154129, 9.50430679], [78.91485596, 9.50431156], [78.91485596, 9.50264072], [78.9145813, 9.50264072], [78.9145813, 9.50153065], [78.91430664, 9.50153065], [78.91430664, 9.50069046], [78.9145813, 9.50069523], [78.9145813, 9.5004158], [78.91486359, 9.5004158], [78.91486359, 9.50013828], [78.91513824, 9.50014114], [78.91513824, 9.49874973], [78.91485596, 9.49874973], [78.91485596, 9.49625015], [78.9145813, 9.49625015], [78.9145813, 9.49569416], [78.91486359, 9.49569416], [78.91486359, 9.49402809], [78.9145813, 9.49403], [78.9145813, 9.49347019], [78.91430664, 9.4934721], [78.91430664, 9.49319363], [78.91402435, 9.49319363], [78.91402435, 9.49263763], [78.91374969, 9.49263954], [78.91374969, 9.49208164], [78.91347504, 9.49208355], [78.91347504, 9.49152756], [78.91179657, 9.49154186], [78.91179657, 9.49125195], [78.91124725, 9.49125195], [78.91124725, 9.49097157], [78.90847015, 9.49097157], [78.90847015, 9.49125195], [78.90763855, 9.49125195], [78.90763855, 9.49154186], [78.90680695, 9.49154186], [78.90680695, 9.49180984], [78.90625, 9.49180603], [78.90625, 9.49208355], [78.90569305, 9.49208355], [78.90569305, 9.49236202], [78.9054184, 9.49236202], [78.9054184, 9.49263954], [78.90513611, 9.49263954], [78.90513611, 9.49291992], [78.90486145, 9.49291801], [78.90486145, 9.49319363], [78.9034729, 9.49319363], [78.9034729, 9.49291801], [78.90291595, 9.49291992], [78.90291595, 9.49263954], [78.90207672, 9.49263954], [78.90207672, 9.49236202], [78.9015274, 9.49236202], [78.9015274, 9.49208355], [78.9006958, 9.49208355], [78.9006958, 9.49152756], [78.90040588, 9.49154186], [78.90040588, 9.49097157], [78.90013885, 9.49097157], [78.90013885, 9.49041557], [78.89958191, 9.49042034], [78.89958191, 9.49013996], [78.89846802, 9.49013996], [78.89846802, 9.48903179], [78.8981781, 9.48903179], [78.8981781, 9.48014069], [78.89846802, 9.48014069], [78.89846802, 9.47819042], [78.89875031, 9.47819519], [78.89875031, 9.47680473], [78.89901733, 9.47681141], [78.89901733, 9.47514057], [78.89930725, 9.47514057], [78.89930725, 9.47375107], [78.89958191, 9.47375107], [78.89958191, 9.47235966], [78.8998642, 9.47235966], [78.8998642, 9.47124958], [78.90013885, 9.47124958], [78.90013885, 9.47043037], [78.90040588, 9.47043037], [78.90040588, 9.46986008], [78.9006958, 9.46986008], [78.9006958, 9.46902847], [78.90097046, 9.46903133], [78.90097046, 9.46819019], [78.90125275, 9.46819401], [78.90125275, 9.46763802], [78.90154266, 9.46763992], [78.90154266, 9.46681118], [78.90180206, 9.46681118], [78.90180206, 9.46625042], [78.90208435, 9.46625042], [78.90207672, 9.46569157], [78.90235901, 9.46569443], [78.90235901, 9.46513844], [78.9026413, 9.46514034], [78.9026413, 9.46458244], [78.90291595, 9.46458435], [78.90291595, 9.46402836], [78.90319061, 9.46403027], [78.90319824, 9.46346855], [78.9034729, 9.46347237], [78.9034729, 9.4631958], [78.90374756, 9.4631958], [78.90374756, 9.46263981], [78.90402985, 9.46263981], [78.90402985, 9.46208382], [78.9043045, 9.46208382], [78.9043045, 9.46152782], [78.90460205, 9.46152973], [78.90460205, 9.46097088], [78.90486145, 9.46097088], [78.90486145, 9.46041775], [78.90513611, 9.46041965], [78.90513611, 9.45985889], [78.9054184, 9.45986176], [78.9054184, 9.45930481], [78.90569305, 9.45930958], [78.90569305, 9.45903015], [78.90598297, 9.45903015], [78.90598297, 9.4584713], [78.90625, 9.4584713], [78.90625, 9.45791531], [78.90651703, 9.45792198], [78.90651703, 9.45736122], [78.90680695, 9.45736122], [78.90680695, 9.45680523], [78.9070816, 9.4568119], [78.9070816, 9.45624924], [78.90736389, 9.45624924], [78.90734863, 9.45569134], [78.90763855, 9.45569515], [78.90763855, 9.45513916], [78.90791321, 9.45514107], [78.90791321, 9.45458126], [78.9081955, 9.45458317], [78.9081955, 9.4543047], [78.90847015, 9.45431042], [78.90847015, 9.45375061], [78.90875244, 9.45375061], [78.90875244, 9.4531908], [78.9090271, 9.45319462], [78.9090271, 9.45263863], [78.90930176, 9.45264053], [78.90930176, 9.45206928], [78.90958405, 9.45208263], [78.90958405, 9.45152664], [78.9098587, 9.45153141], [78.9098587, 9.45097065], [78.91014099, 9.45097256], [78.91014099, 9.45041656], [78.91040802, 9.45042133], [78.91040802, 9.45014095], [78.91069794, 9.45014095], [78.91069794, 9.44958019], [78.9109726, 9.44958305], [78.9109726, 9.44930458], [78.91124725, 9.44930458], [78.91124725, 9.44874763], [78.91152954, 9.44875145], [78.91152954, 9.44818974], [78.9118042, 9.44819546], [78.9118042, 9.44791698], [78.91208649, 9.44791889], [78.91208649, 9.44736004], [78.91236115, 9.44736004], [78.91236115, 9.44680691], [78.9126358, 9.44681072], [78.9126358, 9.44626045], [78.91291809, 9.44626045], [78.91291809, 9.44569016], [78.91319275, 9.44569397], [78.91319275, 9.44513798], [78.91348267, 9.44514275], [78.91348267, 9.44458008], [78.91374969, 9.44458199], [78.91374969, 9.44430637], [78.91401672, 9.44431114], [78.91401672, 9.44375038], [78.91430664, 9.44375038], [78.91430664, 9.44319439], [78.9145813, 9.44320107], [78.9145813, 9.44292068], [78.91485596, 9.44292068], [78.91485596, 9.44235992], [78.91513824, 9.44235992], [78.91513824, 9.44180584], [78.9154129, 9.44181061], [78.9154129, 9.44153023], [78.91570282, 9.44153023], [78.91570282, 9.44097042], [78.91596985, 9.44097233], [78.91596985, 9.44041634], [78.91625214, 9.4404211], [78.91625214, 9.44013119], [78.91652679, 9.44013786], [78.91652679, 9.43958378], [78.91680908, 9.43958378], [78.91680908, 9.43902779], [78.91707611, 9.43902969], [78.91707611, 9.43875027], [78.9173584, 9.43875027], [78.9173584, 9.43819427], [78.91764069, 9.43819427], [78.91764069, 9.4379158], [78.91792297, 9.43791962], [78.91792297, 9.43735981], [78.91819763, 9.43735981], [78.91819763, 9.43680573], [78.91847229, 9.43680954], [78.91847229, 9.43653011], [78.91874695, 9.43653011], [78.91874695, 9.43596935], [78.91902924, 9.43597221], [78.91902924, 9.43541622], [78.91928864, 9.43542004], [78.91928864, 9.43513966], [78.91960144, 9.43513966], [78.91960144, 9.4345789], [78.91986084, 9.43458366], [78.91986084, 9.43402767], [78.92014313, 9.43402958], [78.92014313, 9.4337492], [78.92041779, 9.4337492], [78.92041779, 9.43319321], [78.92069244, 9.43319321], [78.92069244, 9.43236065], [78.92124939, 9.43236065], [78.92124939, 9.43180466], [78.92151642, 9.43181038], [78.92151642, 9.43153191], [78.92180634, 9.43153191], [78.92180634, 9.43097115], [78.92208099, 9.43097115], [78.92208099, 9.43069458], [78.92236328, 9.43069458], [78.92236328, 9.43013859], [78.92263794, 9.4301424], [78.92263794, 9.42986107], [78.92292023, 9.42986107], [78.92292023, 9.42930508], [78.92318726, 9.42930984], [78.92318726, 9.42875099], [78.92346954, 9.42875099], [78.92346954, 9.42847061], [78.92375183, 9.42847347], [78.92375183, 9.42791653], [78.92402649, 9.42791939], [78.92402649, 9.42764091], [78.92430878, 9.42764091], [78.92430878, 9.42708111], [78.92458344, 9.42708302], [78.92458344, 9.42680454], [78.92485809, 9.42681026], [78.92485809, 9.42625141], [78.92514038, 9.42624855], [78.92514038, 9.4256897], [78.92541504, 9.42569542], [78.92541504, 9.42541695], [78.92569733, 9.42542171], [78.92569733, 9.42486095], [78.92597198, 9.42486095], [78.92597198, 9.42458344], [78.92624664, 9.42458344], [78.92624664, 9.42402744], [78.92652893, 9.42403126], [78.92652893, 9.42375088], [78.92679596, 9.42375088], [78.92679596, 9.42319012], [78.92708588, 9.42319489], [78.92708588, 9.42263889], [78.92736053, 9.4226408], [78.92736053, 9.42236137], [78.92763519, 9.42236137], [78.92763519, 9.42180538], [78.92791748, 9.4218092], [78.92791748, 9.42153072], [78.92819214, 9.42153072], [78.92819214, 9.42096996], [78.92847443, 9.42097282], [78.92847443, 9.4206953], [78.92874908, 9.4206953], [78.92874908, 9.42041683], [78.92903137, 9.42042065], [78.92903137, 9.41986275], [78.92930603, 9.41986275], [78.92930603, 9.41958046], [78.92958069, 9.41958237], [78.92958069, 9.41930676], [78.92986298, 9.41932011], [78.92986298, 9.4187479], [78.93013763, 9.41874981], [78.93013763, 9.41847229], [78.93041992, 9.41847229], [78.93041992, 9.41819382], [78.93069458, 9.41819382], [78.93069458, 9.41763783], [78.93096924, 9.41764069], [78.93096924, 9.41736031], [78.93125153, 9.41736031], [78.93125153, 9.41708374], [78.93152618, 9.41708374], [78.93152618, 9.41652775], [78.93180847, 9.41653061], [78.93180847, 9.41625023], [78.93208313, 9.41625023], [78.93208313, 9.41597176], [78.93235779, 9.41597176], [78.93235779, 9.41541576], [78.93264008, 9.41542053], [78.93264008, 9.41514015], [78.9329071, 9.41514015], [78.9329071, 9.41485977], [78.93319702, 9.41485977], [78.93319702, 9.41430569], [78.93347168, 9.41431141], [78.93347168, 9.41403008], [78.93374634, 9.41403008], [78.93374634, 9.41374969], [78.93402863, 9.41374969], [78.93402863, 9.4131918], [78.93430328, 9.4131937], [78.93430328, 9.41291809], [78.93457794, 9.41292], [78.93457794, 9.41263962], [78.93486023, 9.41263962], [78.93486023, 9.41207886], [78.93514252, 9.41208363], [78.93514252, 9.41180611], [78.93541718, 9.41181087], [78.93541718, 9.41125202], [78.93569183, 9.41125202], [78.93569183, 9.41097164], [78.93597412, 9.41097164], [78.93597412, 9.41069412], [78.93624878, 9.41069412], [78.93624878, 9.41041565], [78.93653107, 9.41042042], [78.93653107, 9.40985966], [78.93680573, 9.40985966], [78.93680573, 9.40958405], [78.93708038, 9.40958405], [78.93708038, 9.40930557], [78.93736267, 9.40931034], [78.93736267, 9.40902996], [78.93763733, 9.40902996], [78.93763733, 9.4084692], [78.93791962, 9.40847206], [78.93791962, 9.40819359], [78.93819427, 9.40819359], [78.93819427, 9.40791798], [78.93846893, 9.40792179], [78.93846893, 9.40736198], [78.93875122, 9.40736198], [78.93875122, 9.40708447], [78.93902588, 9.40709019], [78.93902588, 9.4068079], [78.93930817, 9.4068079], [78.93930817, 9.40625191], [78.93958282, 9.40625191], [78.93958282, 9.40597057], [78.93985748, 9.40597057], [78.93985748, 9.40569305], [78.94041443, 9.40569305], [78.94041443, 9.4054184], [78.94071198, 9.4054203], [78.94071198, 9.40514183], [78.94124603, 9.40514183], [78.94124603, 9.40486145], [78.94180298, 9.40486145], [78.94180298, 9.40458298], [78.94208527, 9.40458298], [78.94208527, 9.40402699], [78.94235992, 9.40402985], [78.94235992, 9.40347099], [78.94264221, 9.40347099], [78.94264221, 9.40291691], [78.94291687, 9.40291977], [78.94291687, 9.40236092], [78.94319153, 9.40236092], [78.94319153, 9.40180492], [78.94345856, 9.40180969], [78.94345856, 9.40152931], [78.94374847, 9.40152931], [78.94374847, 9.40125084], [78.94403076, 9.40125084], [78.94403076, 9.40096188], [78.94430542, 9.40097332], [78.94430542, 9.40069485], [78.94458008, 9.40069485], [78.94458008, 9.40041733], [78.94486237, 9.40041924], [78.94486237, 9.40014076], [78.94513702, 9.40014076], [78.94513702, 9.39986134], [78.94541931, 9.39986134], [78.94541931, 9.39958286], [78.94569397, 9.39958286], [78.94569397, 9.39902687], [78.94596863, 9.39903069], [78.94596863, 9.39875126], [78.94625092, 9.39875126], [78.94625092, 9.39847088], [78.94652557, 9.39847088], [78.94652557, 9.39819527], [78.94680786, 9.39819527], [78.94680786, 9.39791679], [78.94708252, 9.39792061], [78.94708252, 9.39764118], [78.94735718, 9.39764118], [78.94735718, 9.3973608], [78.94763947, 9.3973608], [78.94763947, 9.39708328], [78.94791412, 9.39708328], [78.94791412, 9.39680481], [78.94819641, 9.39681244], [78.94819641, 9.39653111], [78.94847107, 9.39653111], [78.94847107, 9.39625072], [78.94875336, 9.39625072], [78.94875336, 9.3959713], [78.94902802, 9.39597321], [78.94902802, 9.39569473], [78.94930267, 9.39569473], [78.94930267, 9.39541721], [78.94957733, 9.39542103], [78.94957733, 9.39515018], [78.94985962, 9.39515018], [78.94985962, 9.39457989], [78.95014191, 9.39458466], [78.95014191, 9.39430428], [78.95041656, 9.39431095], [78.95041656, 9.39403057], [78.95069122, 9.39403057], [78.95069122, 9.39375114], [78.95097351, 9.39375114], [78.95096588, 9.3934679], [78.95124817, 9.39347267], [78.95124817, 9.39319515], [78.95153046, 9.39319515], [78.95153046, 9.39291573], [78.95181274, 9.39292145], [78.95181274, 9.39264107], [78.95207977, 9.39264107], [78.95207977, 9.39235973], [78.95236206, 9.39235973], [78.95236206, 9.39208221], [78.95265198, 9.39208889], [78.95265198, 9.39181137], [78.95291901, 9.39181137], [78.95291901, 9.39153099], [78.95318604, 9.39153099], [78.95318604, 9.39124966], [78.95347595, 9.39124966], [78.95347595, 9.39097023], [78.95375061, 9.39097214], [78.95375061, 9.39069366], [78.95402527, 9.39069366], [78.95402527, 9.39013767], [78.95430756, 9.39014053], [78.95430756, 9.38986015], [78.95458221, 9.38986015], [78.95458221, 9.38958359], [78.9548645, 9.38958359], [78.9548645, 9.38930416], [78.95513916, 9.38931084], [78.95513916, 9.38902092], [78.95541382, 9.3890276], [78.95541382, 9.38875008], [78.95571136, 9.38875008], [78.95571136, 9.3884697], [78.95597076, 9.3884716], [78.95597076, 9.38819408], [78.95625305, 9.38819408], [78.95625305, 9.38791561], [78.95652771, 9.38792133], [78.95652771, 9.38764], [78.95680237, 9.38764], [78.95680237, 9.38735962], [78.95708466, 9.38736153], [78.95708466, 9.38708401], [78.95735931, 9.38708401], [78.95735931, 9.38680553], [78.9576416, 9.38681126], [78.9576416, 9.38652992], [78.95791626, 9.38652992], [78.95791626, 9.38624954], [78.95819092, 9.38624954], [78.95819092, 9.38596058], [78.95847321, 9.38597202], [78.95847321, 9.38569355], [78.95874786, 9.38569355], [78.95874786, 9.38541603], [78.95903015, 9.38541985], [78.95903015, 9.38514042], [78.95929718, 9.38514042], [78.95929718, 9.38486195], [78.9595871, 9.38486195], [78.9595871, 9.38458443], [78.95986176, 9.38458443], [78.95986176, 9.38430595], [78.96013641, 9.38431263], [78.96013641, 9.38403034], [78.9604187, 9.38403034], [78.9604187, 9.38346863], [78.96069336, 9.38347244], [78.96069336, 9.38319397], [78.96097565, 9.38319397], [78.96097565, 9.38291645], [78.96125031, 9.38292027], [78.96125031, 9.38264179], [78.96151733, 9.38264179], [78.96151733, 9.38236046], [78.96180725, 9.38236237], [78.96180725, 9.38208389], [78.96208191, 9.38208389], [78.96208191, 9.38180637], [78.96235657, 9.38181019], [78.96235657, 9.38152981], [78.96263885, 9.38152981], [78.96263885, 9.38125038], [78.96291351, 9.38125038], [78.96290588, 9.38097191], [78.9631958, 9.38097191], [78.9631958, 9.38069344], [78.96347046, 9.38069344], [78.96347046, 9.38041782], [78.96375275, 9.38041973], [78.96375275, 9.38014889], [78.9640274, 9.38014889], [78.9640274, 9.37986183], [78.96430206, 9.37986183], [78.96430206, 9.37958431], [78.96458435, 9.37958431], [78.96458435, 9.37930489], [78.96485901, 9.37930965], [78.96485901, 9.37903023], [78.9651413, 9.37903023], [78.9651413, 9.37874889], [78.96541595, 9.37874889], [78.96541595, 9.37819576], [78.96569061, 9.37819576], [78.96569824, 9.37791538], [78.9659729, 9.37792015], [78.9659729, 9.37764168], [78.96624756, 9.37764168], [78.96624756, 9.37708092], [78.96652985, 9.37708282], [78.96652985, 9.37680531], [78.96679688, 9.37681198], [78.96679688, 9.3765316], [78.96708679, 9.3765316], [78.96708679, 9.37597084], [78.96736145, 9.37597084], [78.96736145, 9.37569523], [78.96763611, 9.37569523], [78.96763611, 9.37541676], [78.9679184, 9.37541962], [78.9679184, 9.37486076], [78.96819305, 9.37486076], [78.96819305, 9.37458134], [78.96847534, 9.37458324], [78.96847534, 9.37430477], [78.96875, 9.37430954], [78.96875, 9.37401962], [78.96902466, 9.37402916], [78.96902466, 9.37374878], [78.96930695, 9.37375069], [78.96930695, 9.37347126], [78.9695816, 9.37347317], [78.9695816, 9.37319469], [78.96986389, 9.37319469], [78.96986389, 9.37291718], [78.97013855, 9.37292194], [78.97013855, 9.37264061], [78.97039795, 9.37264061], [78.97039795, 9.37236118], [78.9706955, 9.37236118], [78.9706955, 9.37208271], [78.97097015, 9.37208271], [78.97097015, 9.37180519], [78.97125244, 9.37181187], [78.97125244, 9.37153053], [78.9715271, 9.37153053], [78.9715271, 9.37125111], [78.97180176, 9.37125111], [78.97180176, 9.37097263], [78.97207642, 9.37098026], [78.97207642, 9.37069035], [78.9723587, 9.37069511], [78.9723587, 9.37041664], [78.97264099, 9.37042141], [78.97264099, 9.37014103], [78.97292328, 9.37014103], [78.97292328, 9.36986065], [78.97319794, 9.36986065], [78.97319794, 9.36958313], [78.9734726, 9.36958313], [78.9734726, 9.36930466], [78.97374725, 9.36931133], [78.97374725, 9.36903095], [78.97402954, 9.36903095], [78.97402954, 9.36875057], [78.97429657, 9.36875057], [78.97429657, 9.36847019], [78.97458649, 9.36847305], [78.97458649, 9.36819458], [78.97486115, 9.36819458], [78.97486115, 9.36791706], [78.9751358, 9.36792088], [78.9751358, 9.36764145], [78.97541809, 9.36764145], [78.97541809, 9.36736107], [78.97569275, 9.36736107], [78.97569275, 9.36708164], [78.97597504, 9.36708164], [78.97597504, 9.36680698], [78.97624969, 9.36680889], [78.97624969, 9.36653137], [78.97653198, 9.36653137], [78.97653198, 9.36625099], [78.9768219, 9.36625099], [78.9768219, 9.36596966], [78.9770813, 9.36597347], [78.9770813, 9.36569405], [78.97736359, 9.36569405], [78.97736359, 9.36541557], [78.97763824, 9.3654213], [78.97763824, 9.36514091], [78.97820282, 9.36514091], [78.97820282, 9.364851], [78.97846985, 9.3648634], [78.97846985, 9.36458206], [78.97875214, 9.36458206], [78.97875214, 9.3643074], [78.97902679, 9.36431122], [78.97902679, 9.36403084], [78.97930908, 9.36403084], [78.97930908, 9.36375046], [78.97958374, 9.36375046], [78.97959137, 9.36347008], [78.9798584, 9.36347198], [78.9798584, 9.36319447], [78.98014069, 9.36319447], [78.98014069, 9.36291599], [78.98069763, 9.36291885], [78.98069763, 9.36264038], [78.98097229, 9.36264038], [78.98097229, 9.36236], [78.98124695, 9.36236], [78.98124695, 9.36208439], [78.98152924, 9.36208439], [78.98152924, 9.36180592], [78.98179626, 9.36181068], [78.98179626, 9.36153126], [78.98208618, 9.36153126], [78.98208618, 9.36124992], [78.98236084, 9.36124992], [78.98236084, 9.36096954], [78.9826355, 9.3609724], [78.9826355, 9.36069393], [78.98319244, 9.36069393], [78.98319244, 9.36041641], [78.9834671, 9.36042118], [78.9834671, 9.36013985], [78.98374939, 9.36013985], [78.98374939, 9.35986042], [78.98402405, 9.35986233], [78.98402405, 9.35958195], [78.98430634, 9.35958195], [78.98430634, 9.35930634], [78.98458099, 9.3593111], [78.98458099, 9.35903931], [78.98486328, 9.35903931], [78.98486328, 9.35875034], [78.98513794, 9.35875034], [78.98513794, 9.35819435], [78.98542023, 9.35819435], [78.98542023, 9.35791588], [78.98568726, 9.35791969], [78.98568726, 9.35764027], [78.98596954, 9.35764027], [78.98596954, 9.35736179], [78.98625183, 9.35736179], [78.98625183, 9.35707855], [78.98652649, 9.35708427], [78.98652649, 9.3568058], [78.98680878, 9.35680962], [78.98680878, 9.35653019], [78.98707581, 9.35653019], [78.98707581, 9.35624981], [78.98735809, 9.35624981], [78.98735809, 9.35597229], [78.98764038, 9.35598087], [78.98764038, 9.35542011], [78.98792267, 9.35542011], [78.98792267, 9.35513973], [78.98819733, 9.35513973], [78.98819733, 9.35485935], [78.98847198, 9.35486221], [78.98847198, 9.35458374], [78.98874664, 9.35458374], [78.98874664, 9.35430622], [78.98902893, 9.35431004], [78.98902893, 9.35402966], [78.98929596, 9.35402966], [78.98929596, 9.35375023], [78.98986053, 9.35375023], [78.98986053, 9.3534708], [78.99013519, 9.3534708], [78.99013519, 9.35319328], [78.99041748, 9.35319328], [78.99041748, 9.35291767], [78.99069214, 9.35291767], [78.99069214, 9.35264015], [78.99124908, 9.35264015], [78.99124908, 9.35236168], [78.99153137, 9.35236168], [78.99153137, 9.35208321], [78.99180603, 9.35208321], [78.99180603, 9.35180473], [78.99208069, 9.35181046], [78.99208069, 9.35153198], [78.99263763, 9.35153198], [78.99263763, 9.3512516], [78.99291992, 9.3512516], [78.99291992, 9.35097122], [78.99319458, 9.35097122], [78.99319458, 9.35069561], [78.99346924, 9.35069561], [78.99346924, 9.35041714], [78.99402618, 9.35042191], [78.99402618, 9.35014153], [78.99430847, 9.35014153], [78.99430847, 9.3498497], [78.99458313, 9.34986115], [78.99458313, 9.34958267], [78.99485779, 9.34958267], [78.99485779, 9.34930515], [78.9954071, 9.34930992], [78.9954071, 9.34902859], [78.99597168, 9.34902859], [78.99597168, 9.34875107], [78.99624634, 9.34875107], [78.99624634, 9.34847069], [78.99652863, 9.3484726], [78.99652863, 9.3479166], [78.99680328, 9.34792042], [78.99680328, 9.34764099], [78.99736023, 9.34764099], [78.99736023, 9.34736061], [78.99764252, 9.34736061], [78.99764252, 9.34708309], [78.99791718, 9.34708309], [78.99791718, 9.34680462], [78.99819183, 9.34681034], [78.99819183, 9.34653187], [78.99846649, 9.34653187], [78.99846649, 9.34625053], [78.99874878, 9.34625053], [78.99874878, 9.34597111], [78.99930573, 9.34597301], [78.99930573, 9.34569454], [78.99958038, 9.34569454], [78.99958038, 9.34541702], [78.99986267, 9.34542179], [78.99986267, 9.34514141], [79.00125122, 9.34514141], [79.00125122, 9.34486103], [79.00152588, 9.34486103], [79.00152588, 9.34458256], [79.00180817, 9.34458256], [79.00180817, 9.34430695], [79.00208282, 9.34431171], [79.00208282, 9.34403992], [79.00263977, 9.34403992], [79.00263977, 9.34347057], [79.00291443, 9.34347343], [79.00291443, 9.34319496], [79.00319672, 9.34319496], [79.00319672, 9.34291744], [79.00347137, 9.34292126], [79.00347137, 9.34264088], [79.00376129, 9.34264088], [79.00376129, 9.34236145], [79.00402832, 9.34236145], [79.00402832, 9.34208298], [79.00430298, 9.34208298], [79.00430298, 9.34180546], [79.0045929, 9.34180927], [79.0045929, 9.34152889], [79.00514221, 9.34152889], [79.00514221, 9.34125137], [79.00541687, 9.34125137], [79.00541687, 9.3409729], [79.00597382, 9.3409729], [79.00597382, 9.34069538], [79.00624847, 9.34069538], [79.00624847, 9.34041691], [79.00708008, 9.34042072], [79.00708008, 9.3401413], [79.00736237, 9.3401413], [79.00736237, 9.33985996], [79.00763702, 9.33985996], [79.00763702, 9.33930683], [79.00818634, 9.33931065], [79.00818634, 9.33903122], [79.00846863, 9.33903122], [79.00846863, 9.33875275], [79.0090332, 9.33875275], [79.0090332, 9.33847046], [79.00930786, 9.33847332], [79.00930786, 9.33819389], [79.00958252, 9.33819389], [79.00958252, 9.33791637], [79.00986481, 9.33791637], [79.00986481, 9.3376379], [79.01041412, 9.3376379], [79.01040649, 9.33736038], [79.01069641, 9.33736038], [79.01069641, 9.33708191], [79.01097107, 9.33708191], [79.01097107, 9.3368063], [79.01152802, 9.33681107], [79.01152802, 9.33653069], [79.01180267, 9.33653069], [79.01180267, 9.33625031], [79.01235962, 9.33625031], [79.01235962, 9.33597183], [79.01264191, 9.33597183], [79.01264191, 9.33569431], [79.01291656, 9.33569431], [79.01291656, 9.33541584], [79.01319122, 9.33542061], [79.01319122, 9.33514023], [79.01346588, 9.33514023], [79.01346588, 9.33487129], [79.01374817, 9.33487129], [79.01374817, 9.33458042], [79.01403046, 9.33458424], [79.01403046, 9.33430576], [79.01431274, 9.33431053], [79.01431274, 9.33403015], [79.01457977, 9.33403015], [79.01457977, 9.33374977], [79.01486206, 9.33374977], [79.01486206, 9.33347034], [79.01513672, 9.33347225], [79.01513672, 9.33319378], [79.01541901, 9.33319378], [79.01541901, 9.33291626], [79.01599121, 9.33292103], [79.01599121, 9.33263969], [79.01625061, 9.33263969], [79.01625061, 9.33236027], [79.01652527, 9.33236217], [79.01652527, 9.3320837], [79.01680756, 9.3320837], [79.01680756, 9.33180618], [79.01735687, 9.33181095], [79.01735687, 9.33152962], [79.01763916, 9.33152962], [79.01763916, 9.33125019], [79.01791382, 9.33125019], [79.01790619, 9.33096981], [79.01847076, 9.33097172], [79.01847076, 9.3306942], [79.01875305, 9.3306942], [79.01875305, 9.33041573], [79.01902771, 9.33041954], [79.01902771, 9.33014011], [79.01957703, 9.33014011], [79.01957703, 9.32985973], [79.01930237, 9.32985973], [79.01930237, 9.32958412], [79.01902771, 9.32958412], [79.01902771, 9.32930565], [79.02041626, 9.32930565], [79.02041626, 9.32958412], [79.02097321, 9.32958412], [79.02097321, 9.32930565], [79.02124786, 9.32931042], [79.02124786, 9.32846928], [79.02153015, 9.32847214], [79.02153015, 9.32763672], [79.02179718, 9.32763958], [79.02179718, 9.3273592], [79.02236176, 9.32736206], [79.02236176, 9.32708359], [79.02263641, 9.32708359], [79.02263641, 9.32680607], [79.02319336, 9.32681179], [79.02319336, 9.32653046], [79.02348328, 9.32653046], [79.02348328, 9.32625198], [79.02401733, 9.32625198], [79.02401733, 9.32597065], [79.02430725, 9.32597065], [79.02430725, 9.32569313], [79.0248642, 9.32569313], [79.0248642, 9.32541847], [79.02513885, 9.32542038], [79.02513885, 9.32514191], [79.0256958, 9.32514191], [79.0256958, 9.32486153], [79.02597046, 9.32486153], [79.02597046, 9.32458305], [79.02625275, 9.32458305], [79.02625275, 9.32430458], [79.02680206, 9.3243103], [79.02680206, 9.32403183], [79.02707672, 9.32403183], [79.02707672, 9.3237524], [79.0276413, 9.3237524], [79.0276413, 9.32347107], [79.02791595, 9.32347107], [79.02791595, 9.32319546], [79.0284729, 9.32319546], [79.0284729, 9.32291698], [79.02874756, 9.32293129], [79.02874756, 9.32263947], [79.02929688, 9.32263947], [79.02929688, 9.32236099], [79.02958679, 9.32236099], [79.02958679, 9.32208347], [79.03013611, 9.32208347], [79.03013611, 9.321805], [79.0304184, 9.32180977], [79.0304184, 9.32152939], [79.0306778, 9.32152939], [79.0306778, 9.32125092], [79.03125, 9.32125092], [79.03125, 9.32097054], [79.03152466, 9.3209734], [79.03152466, 9.32069302], [79.03180695, 9.32069302], [79.03180695, 9.3204174], [79.0320816, 9.32041931], [79.0320816, 9.32014084], [79.03263855, 9.32014084], [79.03263855, 9.31987], [79.03291321, 9.31987], [79.03291321, 9.31958103], [79.0331955, 9.31958294], [79.0331955, 9.31930542], [79.03373718, 9.31931019], [79.03373718, 9.31903076], [79.0340271, 9.31903076], [79.0340271, 9.31875134], [79.03430176, 9.31875134], [79.03430176, 9.31847095], [79.0348587, 9.31847095], [79.0348587, 9.31819534], [79.03514099, 9.31819534], [79.03514099, 9.31791687], [79.03569794, 9.31792164], [79.03569794, 9.31764126], [79.0359726, 9.31764126], [79.0359726, 9.31736088], [79.03652954, 9.31736088], [79.03652954, 9.31708336], [79.0368042, 9.31708336], [79.0368042, 9.31680489], [79.03736115, 9.31681156], [79.03736115, 9.31653118], [79.0376358, 9.31653118], [79.0376358, 9.3162508], [79.03819275, 9.3162508], [79.03819275, 9.31597328], [79.03847504, 9.31597328], [79.03847504, 9.31569481], [79.03902435, 9.31569481], [79.03902435, 9.31541729], [79.03930664, 9.3154192], [79.03930664, 9.31514072], [79.03987122, 9.31514072], [79.03987122, 9.3148613], [79.04013824, 9.3148613], [79.04013824, 9.31458473], [79.04069519, 9.31458473], [79.04069519, 9.31430531], [79.04096985, 9.31431103], [79.04096985, 9.31403065], [79.04152679, 9.31403065], [79.04152679, 9.31374168], [79.04180908, 9.31375122], [79.04180908, 9.31347275], [79.0423584, 9.31347275], [79.0423584, 9.31319523], [79.04264069, 9.31319523], [79.04264069, 9.31291676], [79.04319763, 9.31292057], [79.04319763, 9.31264114], [79.04347229, 9.31264114], [79.04347229, 9.3123579], [79.04402924, 9.31235981], [79.04402924, 9.31208229], [79.04430389, 9.31208229], [79.04430389, 9.31180668], [79.04486084, 9.31181145], [79.04486084, 9.31153107], [79.04514313, 9.31153107], [79.04514313, 9.31125069], [79.04567719, 9.31125069], [79.04567719, 9.31097031], [79.04597473, 9.31097221], [79.04597473, 9.31069374], [79.04652405, 9.31069374], [79.04652405, 9.31041622], [79.04680634, 9.31042099], [79.04680634, 9.31014061], [79.04736328, 9.31014061], [79.04736328, 9.30957985], [79.04792023, 9.30958366], [79.04792023, 9.30930424], [79.04846954, 9.30931091], [79.04846954, 9.30903053], [79.04902649, 9.30903053], [79.04902649, 9.30875015], [79.04930878, 9.30875015], [79.04930878, 9.30847168], [79.04985809, 9.30847168], [79.04985809, 9.30819416], [79.05041504, 9.30819416], [79.05041504, 9.30791569], [79.05069733, 9.3079319], [79.05069733, 9.30764008], [79.05124664, 9.30764008], [79.05124664, 9.3073597], [79.05180359, 9.3073597], [79.05180359, 9.30708408], [79.05236053, 9.30708408], [79.05236053, 9.30680561], [79.05264282, 9.30681133], [79.05264282, 9.30653], [79.05319214, 9.30653], [79.05319214, 9.30624962], [79.05374908, 9.30624962], [79.05374908, 9.30597019], [79.05430603, 9.3059721], [79.05430603, 9.30569363], [79.05458069, 9.30569363], [79.05458069, 9.30541801], [79.05513763, 9.30541992], [79.05513763, 9.30513954], [79.05568695, 9.30513954], [79.05568695, 9.30486202], [79.05596924, 9.30486202], [79.05596924, 9.30458355], [79.05652618, 9.30458355], [79.05652618, 9.30430603], [79.05708313, 9.3043108], [79.05708313, 9.30403042], [79.05764008, 9.30403042], [79.05764008, 9.30375004], [79.0579071, 9.30375004], [79.0579071, 9.30346966], [79.05847168, 9.30347157], [79.05847168, 9.30319405], [79.05902863, 9.30319405], [79.05902863, 9.30291557], [79.0595932, 9.30292034], [79.0595932, 9.30263996], [79.05986023, 9.30263996], [79.05986023, 9.30235958], [79.06041718, 9.30236244], [79.06041718, 9.30208397], [79.06097412, 9.30208397], [79.06097412, 9.30180645], [79.06153107, 9.30180645], [79.06153107, 9.30152798], [79.06208038, 9.30153179], [79.06208038, 9.30125046], [79.06263733, 9.30125046], [79.06263733, 9.30097198], [79.06291962, 9.30097198], [79.06291962, 9.30069447], [79.06346893, 9.30069447], [79.06346893, 9.3004179], [79.06404114, 9.3004179], [79.06404114, 9.30014038], [79.06458282, 9.30014038], [79.06458282, 9.29986191], [79.06541443, 9.29986191], [79.0654068, 9.29958057], [79.06652832, 9.29958439], [79.06652832, 9.29930592], [79.06764221, 9.29930973], [79.06764221, 9.2990303], [79.06846619, 9.2990303], [79.06846619, 9.29874039], [79.06958008, 9.29874897], [79.06958008, 9.29847145], [79.07069397, 9.29847145], [79.07069397, 9.29819584], [79.07152557, 9.29819584], [79.07152557, 9.29791546], [79.07263947, 9.29792023], [79.07263947, 9.29763985], [79.07347107, 9.29763985], [79.07347107, 9.29792023], [79.07402802, 9.29791546], [79.07402802, 9.29819584], [79.07430267, 9.29819584], [79.07430267, 9.29847145], [79.07458496, 9.29847145], [79.07458496, 9.29819584], [79.07485962, 9.29819584], [79.07485962, 9.29791546], [79.07541656, 9.29792023], [79.07541656, 9.29763985], [79.07653046, 9.29763985], [79.07653046, 9.29736137], [79.07763672, 9.29736137], [79.07763672, 9.2970829], [79.07930756, 9.2970829], [79.07930756, 9.29680538], [79.08040619, 9.29681015], [79.08040619, 9.29653168], [79.08152771, 9.29653168], [79.08152771, 9.29624939], [79.0826416, 9.29624939], [79.0826416, 9.29597092], [79.08374786, 9.29597092], [79.08374786, 9.2956953], [79.0848465, 9.29570007], [79.0848465, 9.29541969], [79.08598328, 9.29541969], [79.08598328, 9.29513931], [79.08708191, 9.29513931], [79.08708191, 9.29486084], [79.08792114, 9.29486084], [79.08792114, 9.29458141], [79.08847046, 9.29458332], [79.08847046, 9.29430485], [79.08930206, 9.29430962], [79.08930206, 9.29402924], [79.0901413, 9.29402924], [79.0901413, 9.29375076], [79.09069061, 9.29375076], [79.09069824, 9.29347134], [79.09152985, 9.29347324], [79.09152985, 9.29319477], [79.09236145, 9.29319477], [79.09236145, 9.29291725], [79.09319305, 9.29292202], [79.09319305, 9.29264069], [79.09401703, 9.29264069], [79.09401703, 9.29236126], [79.09513855, 9.29236126], [79.09513855, 9.29208279], [79.09597015, 9.29208279], [79.09597015, 9.29180527], [79.0967865, 9.29181194], [79.0967865, 9.29153061], [79.09764099, 9.29153061], [79.09764099, 9.29125118], [79.0984726, 9.29125118], [79.0984726, 9.2909708], [79.09958649, 9.2909708], [79.09958649, 9.29069519], [79.10041809, 9.29069519], [79.10041809, 9.29041672], [79.10124969, 9.29042053], [79.10124969, 9.29014111], [79.10235596, 9.29014111], [79.10235596, 9.28986073], [79.10321045, 9.28986073], [79.10319519, 9.28958321], [79.10458374, 9.28958321], [79.10458374, 9.28930473], [79.10595703, 9.28931236], [79.10595703, 9.28903103], [79.10764313, 9.28903103], [79.10764313, 9.28875065], [79.10930634, 9.28875065], [79.10930634, 9.28847122], [79.11292267, 9.28847122], [79.11292267, 9.28875065], [79.11429596, 9.28875065], [79.11429596, 9.28903103], [79.11569214, 9.28903103], [79.11569214, 9.28931236], [79.11708069, 9.28930473], [79.11708069, 9.28958321], [79.12403107, 9.28958321], [79.12403107, 9.28930473], [79.12431335, 9.28931236], [79.12431335, 9.28903103], [79.12486267, 9.28903103], [79.12486267, 9.28875065], [79.12513733, 9.28875065], [79.12513733, 9.28847122], [79.12541962, 9.28847313], [79.12541962, 9.28819466], [79.12569427, 9.28819466], [79.12569427, 9.28791714], [79.12625122, 9.28792095], [79.12625122, 9.28764057], [79.1279068, 9.28764057], [79.1279068, 9.28736115], [79.12985992, 9.28736115], [79.12985992, 9.28708267], [79.13236237, 9.28708267], [79.13236237, 9.28736115], [79.13263702, 9.28736115], [79.13263702, 9.28792095], [79.13375092, 9.28791714], [79.13375092, 9.28819466], [79.13402557, 9.28819466], [79.13402557, 9.28847313], [79.13458252, 9.28847122], [79.13458252, 9.28875065], [79.13485718, 9.28875065], [79.13485718, 9.28903103], [79.13513947, 9.28903103], [79.13513947, 9.28931236], [79.13541412, 9.28930473], [79.13541412, 9.28958321], [79.13597107, 9.28958321], [79.13597107, 9.28986073], [79.13625336, 9.28986073], [79.13625336, 9.29014111], [79.13652802, 9.2901392], [79.13652802, 9.2909708], [79.13735962, 9.2909708], [79.13735962, 9.29125118], [79.13819122, 9.29125118], [79.13819122, 9.29153061], [79.13874817, 9.29153061], [79.13874817, 9.29181194], [79.13903046, 9.29180527], [79.13903046, 9.29208279], [79.13930511, 9.29208279], [79.13930511, 9.29236126], [79.14013672, 9.29236126], [79.14013672, 9.29208279], [79.14180756, 9.29208279], [79.14180756, 9.29180527], [79.14290619, 9.29181194], [79.14290619, 9.29153061], [79.14375305, 9.29153061], [79.14375305, 9.29125118], [79.14485931, 9.29125118], [79.14485931, 9.2909708], [79.14569092, 9.2909708], [79.14569092, 9.29069519], [79.14653015, 9.29069519], [79.14653015, 9.29041672], [79.1470871, 9.29042053], [79.1470871, 9.29014111], [79.1479187, 9.29014111], [79.1479187, 9.28986073], [79.14875031, 9.28986073], [79.14875031, 9.28958321], [79.14930725, 9.28958321], [79.14930725, 9.28930473], [79.15013885, 9.28931236], [79.15013885, 9.28903103], [79.1506958, 9.28903103], [79.1506958, 9.28875065], [79.15126038, 9.28875065], [79.15126038, 9.28847122], [79.15180206, 9.28847313], [79.15180206, 9.28819466], [79.15235901, 9.28819466], [79.15235901, 9.28791714], [79.1526413, 9.28792095], [79.1526413, 9.28764057], [79.15319061, 9.28764057], [79.15319824, 9.28736115], [79.15402985, 9.28736115], [79.15402985, 9.28708267], [79.15458679, 9.28708267], [79.15458679, 9.2868042], [79.15513611, 9.2868042], [79.15513611, 9.28652859], [79.15569305, 9.28653145], [79.15569305, 9.28625107], [79.15651703, 9.28625107], [79.15651703, 9.28569031], [79.15680695, 9.28569508], [79.15680695, 9.28513813], [79.15875244, 9.28514099], [79.15875244, 9.28485966], [79.1590271, 9.28485966], [79.1590271, 9.28458214], [79.16014099, 9.28458214], [79.16014099, 9.28430653], [79.16124725, 9.28431129], [79.16124725, 9.28403091], [79.1626358, 9.28403091], [79.1626358, 9.28431129], [79.16402435, 9.28430653], [79.16402435, 9.28458214], [79.1645813, 9.28458214], [79.1645813, 9.28430653], [79.16819763, 9.28430653], [79.16819763, 9.28458214], [79.17708588, 9.28458214], [79.17708588, 9.28430653], [79.17903137, 9.28431129], [79.17903137, 9.28403091], [79.17958069, 9.28403091], [79.17958069, 9.28376198], [79.18013763, 9.28376198], [79.18013763, 9.28347015], [79.18125153, 9.28347206], [79.18125153, 9.28319359], [79.19041443, 9.28319359], [79.19041443, 9.28291607], [79.19069672, 9.28292084], [79.19069672, 9.28180885], [79.1904068, 9.28180885], [79.1904068, 9.28153133], [79.18985748, 9.28153133], [79.18985748, 9.28125], [79.18791962, 9.28125], [79.18791962, 9.28153133], [79.18653107, 9.28153133], [79.18653107, 9.28125], [79.18541718, 9.28125], [79.18541718, 9.28153133], [79.18430328, 9.28153133], [79.18430328, 9.28125], [79.18319702, 9.28125], [79.18319702, 9.28096962], [79.17958069, 9.28097153], [79.17958069, 9.28069401], [79.17930603, 9.28070068], [79.17930603, 9.28042126], [79.1784668, 9.28042126], [79.1784668, 9.28070068], [79.17736053, 9.28070068], [79.17736053, 9.28042126], [79.17708588, 9.28042126], [79.17708588, 9.28013992], [79.17597198, 9.28013992], [79.17597198, 9.27985954], [79.17236328, 9.2798624], [79.17236328, 9.27958202], [79.16930389, 9.27958202], [79.16930389, 9.27930641], [79.16874695, 9.27931118], [79.16874695, 9.27902985], [79.16707611, 9.27902985], [79.16707611, 9.27875042], [79.16569519, 9.27875042], [79.16569519, 9.27847195], [79.16374969, 9.27847195], [79.16374969, 9.27819443], [79.16208649, 9.27819443], [79.16208649, 9.27791595], [79.16069794, 9.27791977], [79.16069794, 9.27763081], [79.15736389, 9.27763844], [79.15736389, 9.27736187], [79.15680695, 9.27736187], [79.15680695, 9.27680588], [79.15598297, 9.27680969], [79.15598297, 9.27653027], [79.15374756, 9.27653027], [79.15374756, 9.27680969], [79.1526413, 9.27680969], [79.1526413, 9.27653027], [79.14958191, 9.27653027], [79.14958191, 9.27625179], [79.14875031, 9.27625179], [79.14875031, 9.27653027], [79.1479187, 9.27653027], [79.1479187, 9.27625179], [79.1470871, 9.27625179], [79.1470871, 9.27596855], [79.14653015, 9.27597237], [79.14653015, 9.27569389], [79.14569092, 9.27569389], [79.14569092, 9.27541637], [79.14541626, 9.27542019], [79.14541626, 9.27486038], [79.14375305, 9.27486229], [79.14375305, 9.2743063], [79.14347076, 9.27431011], [79.14347076, 9.27415085], [79.14347076, 9.27402782], [79.14319611, 9.27402973], [79.14319611, 9.27347183], [79.14291382, 9.27347183], [79.14291382, 9.27291775], [79.14263916, 9.27291965], [79.14263916, 9.27264023], [79.1415329, 9.27264023], [79.1415329, 9.27235889], [79.13680267, 9.27236176], [79.13625336, 9.27236176], [79.13625336, 9.27208424], [79.13458252, 9.27208424], [79.13458252, 9.27180576], [79.13263702, 9.27182102], [79.13263702, 9.27153015], [79.1295929, 9.27153015], [79.1295929, 9.27125168], [79.12847137, 9.27125168], [79.12847137, 9.2709713], [79.12735748, 9.2709713], [79.12735748, 9.27069569], [79.12625122, 9.27069569], [79.12625122, 9.27041531], [79.12541962, 9.27042198], [79.12541962, 9.2701416], [79.12431335, 9.2701416], [79.12431335, 9.26986122], [79.12319183, 9.26986122], [79.12319183, 9.26958275], [79.12180328, 9.26958275], [79.12180328, 9.26930523], [79.1204071, 9.26931], [79.1204071, 9.26902962], [79.11985779, 9.26902962], [79.11985779, 9.26876068], [79.11902618, 9.26876068], [79.11902618, 9.26847076], [79.11846924, 9.26847267], [79.11846924, 9.26819324], [79.11736298, 9.26819324], [79.11736298, 9.26791668], [79.11680603, 9.26791954], [79.11680603, 9.26764202], [79.11653137, 9.26764202], [79.11653137, 9.26736069], [79.11624908, 9.26736069], [79.11624908, 9.26708317], [79.11569214, 9.26708317], [79.11569214, 9.2668047], [79.11541748, 9.26681042], [79.11541748, 9.26653194], [79.11458588, 9.26653194], [79.11458588, 9.26625061], [79.11402893, 9.26625061], [79.11402893, 9.26597118], [79.11291504, 9.26597309], [79.11291504, 9.26569462], [79.11264038, 9.26569462], [79.11264038, 9.2654171], [79.11042023, 9.26542187], [79.11042023, 9.26514053], [79.10986328, 9.26514053], [79.10986328, 9.26486111], [79.10874939, 9.26486111], [79.10874939, 9.26514053], [79.10791779, 9.26514053], [79.10791779, 9.26486111], [79.10708618, 9.26486111], [79.10708618, 9.26458263], [79.10652924, 9.26458263], [79.10652924, 9.26430511], [79.10569763, 9.26431179], [79.10569763, 9.26403141], [79.10514069, 9.26403141], [79.10514069, 9.26375103], [79.10430908, 9.26375103], [79.10430908, 9.26347065], [79.10346985, 9.26347256], [79.10346985, 9.26319504], [79.1029129, 9.26319504], [79.1029129, 9.26263905], [79.1020813, 9.26263905], [79.1020813, 9.26236057], [79.10097504, 9.26236057], [79.10097504, 9.26208305], [79.1001358, 9.26208305], [79.1001358, 9.26180458], [79.09929657, 9.26180935], [79.09929657, 9.26153088], [79.0984726, 9.26153088], [79.0984726, 9.26125145], [79.0973587, 9.26125145], [79.0973587, 9.26097012], [79.0965271, 9.26097298], [79.0965271, 9.26069546], [79.0956955, 9.26069546], [79.0956955, 9.26041698], [79.0945816, 9.26041889], [79.0945816, 9.26014137], [79.09375, 9.26014137], [79.09375, 9.25986099], [79.09098053, 9.25986099], [79.09098053, 9.26014137], [79.08930206, 9.26014137], [79.08930206, 9.26041889], [79.08569336, 9.26041698], [79.08569336, 9.26069546], [79.07541656, 9.26069546], [79.07541656, 9.26097298], [79.06903076, 9.26097012], [79.06903076, 9.26124859], [79.06819153, 9.26125145], [79.06819153, 9.26153088], [79.06764221, 9.26153088], [79.06764221, 9.26097012], [79.06735992, 9.26097298], [79.06735992, 9.26069546], [79.06541443, 9.26069546], [79.06541443, 9.26097298], [79.06404114, 9.26097012], [79.06402588, 9.26124859], [79.06375122, 9.26125145], [79.06375122, 9.26153088], [79.06346893, 9.26153088], [79.06346893, 9.26180935], [79.06319427, 9.26180458], [79.06319427, 9.26208305], [79.06291962, 9.26208305], [79.06291962, 9.26236057], [79.05819702, 9.26236057], [79.05819702, 9.26263905], [79.05625153, 9.26263905], [79.05625153, 9.26236057], [79.05403137, 9.26236057], [79.05403137, 9.26263905], [79.05319214, 9.26263046], [79.05319214, 9.26292133], [79.05097198, 9.26291656], [79.05097198, 9.26319504], [79.05041504, 9.26319504], [79.05041504, 9.26347256], [79.04985809, 9.26347065], [79.04985809, 9.26375103], [79.04957581, 9.26375103], [79.04957581, 9.26403141], [79.04902649, 9.26403141], [79.04902649, 9.26431179], [79.04875183, 9.26430511], [79.04875183, 9.26458263], [79.04319763, 9.26458263], [79.04319763, 9.26486111], [79.04207611, 9.26486111], [79.04207611, 9.26514053], [79.04013824, 9.26514053], [79.04013824, 9.26542187], [79.03819275, 9.2654171], [79.03819275, 9.26569462], [79.03652954, 9.26569462], [79.03652954, 9.26597309], [79.03569794, 9.26597118], [79.03569794, 9.26625061], [79.03514099, 9.26625061], [79.03514099, 9.26653194], [79.03430939, 9.26653194], [79.03430176, 9.26681042], [79.03375244, 9.2668047], [79.03375244, 9.26708317], [79.0304184, 9.26708317], [79.0304184, 9.26736069], [79.02929688, 9.26736069], [79.02929688, 9.26764202], [79.0284729, 9.26764202], [79.0284729, 9.26791954], [79.02735901, 9.26791668], [79.02735901, 9.26819324], [79.02541351, 9.26819324], [79.02541351, 9.26847267], [79.02375031, 9.26847076], [79.02375031, 9.26876068], [79.02179718, 9.26876068], [79.02179718, 9.26902962], [79.0201416, 9.26902962], [79.0201416, 9.26931], [79.01791382, 9.26930523], [79.01791382, 9.26958275], [79.01569366, 9.26958275], [79.01569366, 9.26986122], [79.01346588, 9.26986122], [79.01346588, 9.2701416], [79.01125336, 9.2701416], [79.01125336, 9.27042198], [79.00958252, 9.27041531], [79.00958252, 9.27069569], [79.00819397, 9.27069569], [79.00819397, 9.2709713], [79.00624847, 9.2709713], [79.00624847, 9.27125168], [79.00430298, 9.27125168], [79.00430298, 9.27153015], [79.00208282, 9.27153015], [79.00208282, 9.27182102], [79.00041962, 9.27180576], [79.00041962, 9.27236176], [79.00013733, 9.27236176], [78.99958038, 9.27235889], [78.99958038, 9.27264023], [78.99930573, 9.27264023], [78.99930573, 9.27319336], [78.99847412, 9.27319336], [78.99847412, 9.27347183], [78.99819183, 9.27347183], [78.99819183, 9.27291775], [78.99791718, 9.27291965], [78.99791718, 9.27264023], [78.99680328, 9.27264023], [78.99680328, 9.27235889], [78.99624634, 9.27235889], [78.99624634, 9.27264023], [78.99597168, 9.27264023], [78.99597168, 9.27235889], [78.9954071, 9.27235889], [78.9954071, 9.27264023], [78.99485779, 9.27264023], [78.99485779, 9.27235889], [78.99375153, 9.27235889], [78.99375153, 9.27264023], [78.99208069, 9.27264023], [78.99208069, 9.27291965], [78.99097443, 9.27291775], [78.99097443, 9.27319336], [78.98847198, 9.27319336], [78.98847198, 9.27347183], [78.98791504, 9.27347183], [78.98791504, 9.27375031], [78.98680878, 9.27375031], [78.98680878, 9.27347183], [78.98596954, 9.27347183], [78.98596954, 9.27375031], [78.98513794, 9.27375031], [78.98513794, 9.27431011], [78.98486328, 9.2743063], [78.98486328, 9.27458382], [78.98458099, 9.27458382], [78.98458099, 9.27486229], [78.98208618, 9.27486229], [78.98208618, 9.27458382], [78.98152924, 9.27458382], [78.98152924, 9.27486229], [78.98069763, 9.27486229], [78.98069763, 9.27458382], [78.98041534, 9.27458382], [78.98041534, 9.27402782], [78.98014069, 9.27402973], [78.98014069, 9.27375031], [78.97902679, 9.27375031], [78.97902679, 9.27347183], [78.97763824, 9.27347183], [78.97763824, 9.27375031], [78.97652435, 9.27375031], [78.97652435, 9.27347183], [78.9751358, 9.27347183], [78.9751358, 9.27375031], [78.97180176, 9.27375031], [78.97180176, 9.27347183], [78.9706955, 9.27347183], [78.9706955, 9.27319336], [78.97041321, 9.27319336], [78.97041321, 9.27291775], [78.96624756, 9.27291775], [78.96624756, 9.27319336], [78.96569824, 9.27319336], [78.96569061, 9.27291775], [78.96430206, 9.27291965], [78.96430206, 9.27264023], [78.96347046, 9.27264023], [78.96347046, 9.27235889], [78.96263885, 9.27236176], [78.96263885, 9.27208424], [78.96208191, 9.27208424], [78.96208191, 9.27236176], [78.96180725, 9.27235889], [78.96180725, 9.27264023], [78.9595871, 9.27264023], [78.9595871, 9.27235889], [78.95847321, 9.27236176], [78.95847321, 9.27208424], [78.95708466, 9.27208424], [78.95708466, 9.27236176], [78.95513916, 9.27236176], [78.95513916, 9.27208424], [78.95402527, 9.27208424], [78.95402527, 9.27180576], [78.95207977, 9.27182102], [78.95207977, 9.27153015], [78.95096588, 9.27153015], [78.95096588, 9.27125168], [78.94819641, 9.27125168], [78.94819641, 9.2709713], [78.94596863, 9.2709713], [78.94596863, 9.27069569], [78.94541931, 9.27069569], [78.94541931, 9.27041531], [78.94431305, 9.27042198], [78.94431305, 9.2701416], [78.94374847, 9.2701416], [78.94374847, 9.26986122], [78.94291687, 9.26986122], [78.94291687, 9.26958275], [78.94180298, 9.26958275], [78.94180298, 9.26930523], [78.93985748, 9.26931], [78.93985748, 9.26902962], [78.93930817, 9.26902962], [78.93930817, 9.26876068], [78.93653107, 9.26876068], [78.93653107, 9.26847076], [78.93486023, 9.26847267], [78.93486023, 9.26819324], [78.93430328, 9.26819324], [78.93430328, 9.26791668], [78.93374634, 9.26791954], [78.93374634, 9.26764202], [78.93208313, 9.26764202], [78.93208313, 9.26736069], [78.93096924, 9.26736069], [78.93096924, 9.26708317], [78.92986298, 9.26708317], [78.92986298, 9.2668047], [78.92874908, 9.26681042], [78.92874908, 9.26653194], [78.92764282, 9.26653194], [78.92764282, 9.26625061], [78.92708588, 9.26625061], [78.92708588, 9.26597118], [78.92569733, 9.26597309], [78.92569733, 9.26569462], [78.92514038, 9.26569462], [78.92514038, 9.2654171], [78.92457581, 9.26542187], [78.92457581, 9.26514053], [78.92430878, 9.26514053], [78.92430878, 9.26486111], [78.92402649, 9.26486111], [78.92402649, 9.26458263], [78.92346954, 9.26458263], [78.92346954, 9.26430511], [78.92318726, 9.26431179], [78.92318726, 9.26403141], [78.92263794, 9.26403141], [78.92263794, 9.26375103], [78.92234802, 9.26375103], [78.92234802, 9.26347065], [78.92208099, 9.26347256], [78.92208099, 9.26319504], [78.92180634, 9.26319504], [78.92180634, 9.26291656], [78.92151642, 9.26292133], [78.92151642, 9.26263046], [78.92097473, 9.26263905], [78.92097473, 9.26208305], [78.92069244, 9.26208305], [78.92069244, 9.26180458], [78.92041779, 9.26180935], [78.92041779, 9.26153088], [78.91986084, 9.26153088], [78.91986084, 9.26125145], [78.91960144, 9.26125145], [78.91960144, 9.26097012], [78.91930389, 9.26097298], [78.91930389, 9.26069546], [78.91902924, 9.26069546], [78.91902924, 9.26041698], [78.91874695, 9.26041889], [78.91874695, 9.26014137], [78.91847229, 9.26014137], [78.91847229, 9.2595892], [78.91819763, 9.2595892], [78.91819763, 9.25931072], [78.91792297, 9.25931072], [78.91792297, 9.2590313], [78.91764069, 9.2590313], [78.91764069, 9.25846958], [78.91708374, 9.2584734], [78.91708374, 9.25819492], [78.91680908, 9.25819492], [78.91680908, 9.25791645], [78.91625214, 9.25792122], [78.91625214, 9.25764084], [78.91596985, 9.25764084], [78.91596985, 9.25736046], [78.91569519, 9.25736046], [78.91569519, 9.25708199], [78.9154129, 9.25708199], [78.9154129, 9.2565279], [78.91513824, 9.2565279], [78.91513824, 9.25597], [78.91486359, 9.25597191], [78.91486359, 9.2551403], [78.9145813, 9.2551403], [78.9145813, 9.25468922], [78.9145813, 9.25458431], [78.91430664, 9.25458431], [78.91430664, 9.25402832], [78.91401672, 9.25403118], [78.91401672, 9.25346088], [78.91347504, 9.25347233], [78.91347504, 9.25319386], [78.91319275, 9.25319386], [78.91319275, 9.25291634], [78.91236115, 9.2529211], [78.91236115, 9.25263977], [78.91179657, 9.25263977], [78.91179657, 9.25236034], [78.91152954, 9.25236225], [78.91152954, 9.25208378], [78.91124725, 9.25208378], [78.91124725, 9.25180626], [78.9109726, 9.25181103], [78.9109726, 9.25152969], [78.91069794, 9.25152969], [78.91069794, 9.25125027], [78.91014099, 9.25125027], [78.91014099, 9.25097179], [78.9098587, 9.25097179], [78.9098587, 9.25069427], [78.90958405, 9.25069427], [78.90958405, 9.2504158], [78.90875244, 9.25041962], [78.90875244, 9.25014019], [78.90734863, 9.25014019], [78.90734863, 9.24985981], [78.90652466, 9.24985981], [78.90652466, 9.2495842], [78.90513611, 9.2495842], [78.90513611, 9.24985981], [78.90431213, 9.24985981], [78.90431213, 9.25014019], [78.90322113, 9.25014019], [78.90319824, 9.25041962], [78.90208435, 9.2504158], [78.90208435, 9.25069427], [78.90125275, 9.25069427], [78.90125275, 9.25097179], [78.90013885, 9.25097179], [78.90013885, 9.25125027], [78.89958191, 9.25125027], [78.89958191, 9.25152969], [78.89901733, 9.25152969], [78.89901733, 9.25181103], [78.89819336, 9.25180626], [78.89819336, 9.25208378], [78.89680481, 9.25208378], [78.89680481, 9.25236225], [78.89597321, 9.25236034], [78.89597321, 9.25263977], [78.8951416, 9.25263977], [78.8951416, 9.2529211], [78.89485931, 9.2529211], [78.89485931, 9.25263977], [78.89457703, 9.25263977], [78.89457703, 9.2529211], [78.89347076, 9.25291634], [78.89347076, 9.25319386], [78.89319611, 9.25319386], [78.89319611, 9.25291634], [78.89291382, 9.25291634], [78.89291382, 9.25319386], [78.8923645, 9.25319386], [78.8923645, 9.25347233], [78.89068604, 9.25346088], [78.89069366, 9.25374985], [78.89041901, 9.25374985], [78.89041901, 9.25403118], [78.88931274, 9.25403118], [78.88931274, 9.25431061], [78.88764191, 9.25430584], [78.88764191, 9.25458431], [78.88652802, 9.25458431], [78.88652802, 9.25485992], [78.88513947, 9.25485992], [78.88513947, 9.2551403], [78.88430786, 9.2551403], [78.88430786, 9.25542068], [78.88263702, 9.25541592], [78.88263702, 9.25569439], [78.88180542, 9.25569439], [78.88180542, 9.25597191], [78.88041687, 9.25597191], [78.88041687, 9.25625038], [78.87737274, 9.25625038], [78.87737274, 9.2565279], [78.87319183, 9.2565279], [78.87319183, 9.25625038], [78.87236023, 9.25625038], [78.87236023, 9.25597191], [78.87208557, 9.25597191], [78.87208557, 9.25569439], [78.87152863, 9.25569439], [78.87152863, 9.25541592], [78.87123871, 9.25542068], [78.87123871, 9.2551403], [78.87097168, 9.2551403], [78.87097168, 9.25485992], [78.8704071, 9.25485992], [78.8704071, 9.25457954], [78.87014008, 9.25458431], [78.87014008, 9.25402832], [78.86985779, 9.25403118], [78.86985779, 9.25374985], [78.86958313, 9.25374985], [78.86958313, 9.25347233], [78.86569214, 9.25347233], [78.86569214, 9.25374985], [78.86513519, 9.25374985], [78.86513519, 9.25347233], [78.86486053, 9.25347233], [78.86486053, 9.25374985], [78.86180878, 9.25374985], [78.86180878, 9.25347233], [78.86013794, 9.25347233], [78.86013794, 9.25319386], [78.85958099, 9.25319386], [78.85958099, 9.25291634], [78.85929871, 9.2529211], [78.85929871, 9.25263977], [78.85900879, 9.25263977], [78.85900879, 9.25236034], [78.85874939, 9.25236225], [78.85874939, 9.25208378], [78.85847473, 9.25208378], [78.85847473, 9.25180626], [78.85791779, 9.25181103], [78.85791779, 9.25152969], [78.85764313, 9.25152969], [78.85764313, 9.25125027], [78.85736084, 9.25125027], [78.85736084, 9.25097179], [78.85708618, 9.25097179], [78.85708618, 9.2504158], [78.85652924, 9.25041962], [78.85652924, 9.25014019], [78.85626221, 9.25014019], [78.85626221, 9.24985981], [78.85597229, 9.24985981], [78.85597229, 9.2495842], [78.85458374, 9.2495842], [78.85458374, 9.24930573], [78.85402679, 9.24930954], [78.85402679, 9.24903011], [78.85375214, 9.24903011], [78.85375214, 9.24874973], [78.85346985, 9.24874973], [78.85346985, 9.24846935], [78.85041809, 9.24847221], [78.85041809, 9.24819374], [78.84958649, 9.24819374], [78.84958649, 9.24847221], [78.84902954, 9.24847221], [78.84902954, 9.24819374], [78.8484726, 9.24819374], [78.8484726, 9.24791622], [78.84791565, 9.24791622], [78.84791565, 9.24819374], [78.84319305, 9.24819374], [78.84319305, 9.24791622], [78.84208679, 9.24792004], [78.84208679, 9.2476511], [78.8409729, 9.2476511], [78.8409729, 9.24735928], [78.8401413, 9.24736214], [78.8401413, 9.24708366], [78.83958435, 9.24708366], [78.83958435, 9.24652767], [78.83930206, 9.24652958], [78.83930206, 9.24625015], [78.83847046, 9.24625015], [78.83847046, 9.24597168], [78.83708191, 9.24597168], [78.83708191, 9.24569321], [78.83597565, 9.24569321], [78.83597565, 9.24541759], [78.83486176, 9.24542046], [78.83486176, 9.24514198], [78.83374786, 9.24514198], [78.83374786, 9.24542046], [78.83347321, 9.24541759], [78.83347321, 9.24625015], [78.83374786, 9.24625015], [78.83374786, 9.24708366], [78.83403015, 9.24708366], [78.83403015, 9.24736214], [78.83429718, 9.24735928], [78.83429718, 9.2476511], [78.8345871, 9.24763966], [78.8345871, 9.24847221], [78.83429718, 9.24846935], [78.83429718, 9.24874973], [78.83403015, 9.24874973], [78.83403015, 9.24903011], [78.83374786, 9.24902821], [78.83374786, 9.2495842], [78.83347321, 9.2495842], [78.83347321, 9.24985981], [78.83319092, 9.24985981], [78.83319092, 9.25014019], [78.83291626, 9.25014019], [78.83291626, 9.25041962], [78.8326416, 9.2504158], [78.8326416, 9.25069427], [78.83235931, 9.25069427], [78.83235931, 9.25097179], [78.8320694, 9.25097179], [78.83208466, 9.25125027], [78.83180237, 9.25125027], [78.83180237, 9.25152969], [78.83152771, 9.25152969], [78.83152771, 9.25181103], [78.83125305, 9.25180626], [78.83125305, 9.25236225], [78.83097076, 9.25236034], [78.83097076, 9.2529211], [78.83069611, 9.25291634], [78.83069611, 9.25319386], [78.83040619, 9.25319195], [78.83040619, 9.25431061], [78.83013916, 9.25430584], [78.83013916, 9.25569439], [78.83040619, 9.25568962], [78.83040619, 9.2565279], [78.83097076, 9.2565279], [78.83097076, 9.25708199], [78.83180237, 9.25708199], [78.83180237, 9.25736046], [78.83208466, 9.25736046], [78.83208466, 9.25819492], [78.83235931, 9.25819016], [78.83235931, 9.25875092], [78.8326416, 9.25875092], [78.8326416, 9.25931072], [78.83291626, 9.25931072], [78.83291626, 9.26014137], [78.83319092, 9.26013947], [78.83319092, 9.26069546], [78.83347321, 9.26068974], [78.83347321, 9.26125145], [78.83374786, 9.26124859], [78.83374786, 9.26236057], [78.83403015, 9.26236057], [78.83403015, 9.26263905], [78.83374786, 9.26263046], [78.83374786, 9.26292133], [78.83403015, 9.26291656], [78.83403015, 9.26319504], [78.83429718, 9.26319027], [78.83429718, 9.26431179], [78.8345871, 9.26430511], [78.8345871, 9.26708317], [78.83429718, 9.26708126], [78.83429718, 9.26764202], [78.83403015, 9.26764202], [78.83403015, 9.26791954], [78.83374786, 9.26791668], [78.83374786, 9.26819324], [78.83347321, 9.26819324], [78.83347321, 9.26847267], [78.83319092, 9.26847076], [78.83319092, 9.26876068], [78.8326416, 9.26876068], [78.8326416, 9.26819134], [78.83291626, 9.26819324], [78.83291626, 9.26791668], [78.83319092, 9.26791954], [78.83319092, 9.26764202], [78.83347321, 9.26764202], [78.83347321, 9.26625061], [78.83374786, 9.26625061], [78.83374786, 9.26514053], [78.83347321, 9.26514053], [78.83347321, 9.26403141], [78.83319092, 9.26403141], [78.83319092, 9.26375103], [78.83291626, 9.26375103], [78.83291626, 9.26347065], [78.8326416, 9.26347256], [78.8326416, 9.26208305], [78.83235931, 9.26208305], [78.83235931, 9.26152897], [78.8320694, 9.26153088], [78.8320694, 9.26097012], [78.83180237, 9.26097298], [78.83180237, 9.26069546], [78.83152771, 9.26069546], [78.83152771, 9.26041698], [78.83125305, 9.26041889], [78.83125305, 9.2595892], [78.83097076, 9.2595892], [78.83097076, 9.25931072], [78.83125305, 9.25931072], [78.83125305, 9.2590313], [78.83097076, 9.2590313], [78.83097076, 9.25875092], [78.83069611, 9.25875092], [78.83069611, 9.25846958], [78.83041382, 9.2584734], [78.83041382, 9.25819492], [78.83013916, 9.25819492], [78.83013916, 9.25791645], [78.82985687, 9.25792122], [78.82985687, 9.25764084], [78.83013916, 9.25764084], [78.83013916, 9.25736046], [78.8298645, 9.25736046], [78.8298645, 9.25680733], [78.82958221, 9.25681973], [78.82958221, 9.2565279], [78.8290329, 9.2565279], [78.8290329, 9.25485992], [78.82875061, 9.25485992], [78.82875061, 9.25374985], [78.82902527, 9.25374985], [78.82902527, 9.25291634], [78.82932281, 9.2529211], [78.82932281, 9.25236034], [78.82958221, 9.25236225], [78.82958221, 9.25180626], [78.82985687, 9.25181103], [78.82985687, 9.25125027], [78.83013916, 9.25125027], [78.83013916, 9.25097179], [78.83041382, 9.25097179], [78.83041382, 9.25069427], [78.83069611, 9.25069427], [78.83069611, 9.2504158], [78.83097076, 9.25041962], [78.83097076, 9.24903011], [78.83125305, 9.24903011], [78.83125305, 9.24874973], [78.83180237, 9.24874973], [78.83180237, 9.24846935], [78.83208466, 9.24847221], [78.83208466, 9.24819374], [78.83180237, 9.24819374], [78.83180237, 9.24791622], [78.8320694, 9.24792004], [78.8320694, 9.24735928], [78.83235931, 9.24736214], [78.83235931, 9.24708366], [78.8326416, 9.24708366], [78.8326416, 9.24625015], [78.83235931, 9.24625015], [78.83235931, 9.24597168], [78.8326416, 9.24597168], [78.8326416, 9.24541759], [78.83291626, 9.24542046], [78.83291626, 9.24375153], [78.8326416, 9.24375153], [78.8326416, 9.24347115], [78.83235931, 9.24347115], [78.83235931, 9.24319553], [78.83097076, 9.24319553], [78.83097076, 9.24291706], [78.82985687, 9.24291992], [78.82985687, 9.24263859], [78.82791901, 9.24263859], [78.82791901, 9.24236107], [78.82736206, 9.24236107], [78.82736206, 9.2420826], [78.82680511, 9.2420826], [78.82680511, 9.24180508], [78.82624817, 9.24180984], [78.82624817, 9.24151993], [78.82514191, 9.2415266], [78.82514191, 9.24124908], [78.82457733, 9.24125099], [78.82457733, 9.24097061], [78.82402802, 9.24097347], [78.82402802, 9.24069309], [78.82347107, 9.24069309], [78.82347107, 9.24041653], [78.82289886, 9.24042034], [78.82289886, 9.23986053], [78.82263947, 9.23986053], [78.82263947, 9.23958302], [78.82236481, 9.23958302], [78.82236481, 9.23930454], [78.82208252, 9.23931026], [78.82208252, 9.23903179], [78.82096863, 9.23903179], [78.82096863, 9.23875141], [78.81986237, 9.23875141], [78.81986237, 9.23847103], [78.81903076, 9.23847103], [78.81903076, 9.23819542], [78.81847382, 9.23819542], [78.81847382, 9.23791695], [78.81819153, 9.23792171], [78.81819153, 9.23764133], [78.81791687, 9.23764133], [78.81791687, 9.23736095], [78.81708527, 9.23736095], [78.81708527, 9.23708344], [78.81625366, 9.23708344], [78.81625366, 9.23680496], [78.81569672, 9.23680496], [78.81569672, 9.23708344], [78.81541443, 9.23708344], [78.81541443, 9.23680496], [78.81513977, 9.23680496], [78.81513977, 9.23708344], [78.81402588, 9.23708344], [78.81402588, 9.23736095], [78.81291962, 9.23736095], [78.81291962, 9.23708344], [78.81263733, 9.23708344], [78.81263733, 9.23736095], [78.81208038, 9.23736095], [78.81208038, 9.23764133], [78.81153107, 9.23764133], [78.81153107, 9.23736095], [78.81069183, 9.23736095], [78.81069183, 9.23708344], [78.80958557, 9.23708344], [78.80958557, 9.23680496], [78.80874634, 9.23681164], [78.80874634, 9.23653126], [78.80764008, 9.23653126], [78.80764008, 9.23681164], [78.80680847, 9.23681164], [78.80680847, 9.23653126], [78.80625153, 9.23653126], [78.80625153, 9.23625088], [78.80486298, 9.23625088], [78.80486298, 9.23597145], [78.80430603, 9.23597336], [78.80430603, 9.23569489], [78.80374908, 9.23569489], [78.80374908, 9.23541737], [78.8034668, 9.23541927], [78.8034668, 9.23513889], [78.80319214, 9.23513889], [78.80319214, 9.23486137], [78.80291748, 9.23486137], [78.80291748, 9.2345829], [78.80208588, 9.2345829], [78.80208588, 9.23430538], [78.80097198, 9.2343092], [78.80097198, 9.23403072], [78.80042267, 9.23403072], [78.80042267, 9.2337513], [78.79985809, 9.2337513], [78.79985809, 9.23347282], [78.79958344, 9.23347282], [78.79958344, 9.2331953], [78.79930878, 9.2331953], [78.79930878, 9.23291683], [78.79901886, 9.23292065], [78.79901886, 9.23236275], [78.79818726, 9.23236275], [78.79818726, 9.23208046], [78.79792023, 9.23208237], [78.79792023, 9.23180676], [78.79763794, 9.23181057], [78.79763794, 9.23153114], [78.79736328, 9.23153114], [78.79736328, 9.2312479], [78.79680634, 9.23125076], [78.79680634, 9.23097324], [78.79597473, 9.23097324], [78.79597473, 9.23069382], [78.79541779, 9.23069382], [78.79541779, 9.2304163], [78.79514313, 9.23042107], [78.79514313, 9.23014069], [78.79486084, 9.23014069], [78.79486084, 9.22957993], [78.79458618, 9.22958469], [78.79458618, 9.22930431], [78.79429626, 9.22931099], [78.79429626, 9.22903061], [78.79402924, 9.22903061], [78.79402924, 9.22875023], [78.79319763, 9.22875023], [78.79319763, 9.22847176], [78.79291534, 9.22847176], [78.79291534, 9.22875023], [78.79180908, 9.22875023], [78.79180908, 9.22903061], [78.78901672, 9.22903061], [78.78901672, 9.22875023], [78.78874969, 9.22875023], [78.78874969, 9.22847176], [78.7876358, 9.22847176], [78.7876358, 9.22819424], [78.78736115, 9.22819424], [78.78736115, 9.22791576], [78.78707886, 9.22792053], [78.78707886, 9.22764015], [78.78678894, 9.22764015], [78.78678894, 9.22735977], [78.78652954, 9.22735977], [78.78652954, 9.22708416], [78.7859726, 9.22708416], [78.7859726, 9.22680569], [78.78569794, 9.22681141], [78.78569794, 9.22652054], [78.78541565, 9.22652817], [78.78541565, 9.22624969], [78.78430176, 9.22624969], [78.78430176, 9.22597027], [78.7831955, 9.22597218], [78.7831955, 9.2256937], [78.78180695, 9.2256937], [78.78180695, 9.22541809], [78.78125, 9.22541809], [78.78125, 9.2256937], [78.77986145, 9.2256937], [78.77986145, 9.22541809], [78.7784729, 9.22542095], [78.7784729, 9.22513962], [78.77820587, 9.22513962], [78.77819061, 9.22486019], [78.77708435, 9.2248621], [78.77708435, 9.22458363], [78.7765274, 9.22458363], [78.7765274, 9.22430611], [78.77597046, 9.22431087], [78.77597046, 9.22402954], [78.77540588, 9.22402954], [78.77540588, 9.22348118], [78.77484894, 9.22348118], [78.77484894, 9.22318935], [78.77458191, 9.22319412], [78.77458191, 9.22291565], [78.77401733, 9.22292042], [78.77401733, 9.22264004], [78.77375031, 9.22264004], [78.77375031, 9.22235966], [78.77347565, 9.22236156], [78.77347565, 9.22208405], [78.77263641, 9.22208405], [78.77263641, 9.22180557], [78.77178955, 9.22181034], [78.77178955, 9.22152996], [78.76985931, 9.22152996], [78.76985931, 9.22124958], [78.76875305, 9.22124958], [78.76875305, 9.2209692], [78.76735687, 9.2209692], [78.76735687, 9.22124958], [78.76708221, 9.22124958], [78.76708221, 9.2209692], [78.76625061, 9.22097206], [78.76625061, 9.22069359], [78.76541901, 9.22069359], [78.76541901, 9.22041798], [78.76486206, 9.22042179], [78.76486206, 9.22014046], [78.76431274, 9.22014046], [78.76431274, 9.21986198], [78.76374817, 9.21986198], [78.76374817, 9.21958447], [78.76319122, 9.21958447], [78.76319122, 9.21930599], [78.76290894, 9.2193079], [78.76290894, 9.21903038], [78.76235962, 9.21903038], [78.76235962, 9.21875191], [78.76125336, 9.21875191], [78.76125336, 9.21847057], [78.76069641, 9.21847057], [78.76069641, 9.21819305], [78.76013947, 9.21819305], [78.76013947, 9.2179184], [78.75958252, 9.2179203], [78.75958252, 9.21764183], [78.75875092, 9.21764183], [78.75875092, 9.2173624], [78.75819397, 9.2173624], [78.75819397, 9.21708298], [78.75791931, 9.21708298], [78.75791931, 9.21680546], [78.75763702, 9.21681023], [78.75763702, 9.21652985], [78.75708008, 9.21652985], [78.75708008, 9.21624947], [78.75680542, 9.21624947], [78.75680542, 9.21597099], [78.75624847, 9.21597099], [78.75624847, 9.21569538], [78.75541687, 9.21569538], [78.75541687, 9.21541691], [78.75319672, 9.21541977], [78.75319672, 9.21513939], [78.75096893, 9.21513939], [78.75096893, 9.21486092], [78.75068665, 9.21486092], [78.75068665, 9.21513939], [78.74958038, 9.21513939], [78.74958038, 9.21486092], [78.74930573, 9.21486092], [78.74930573, 9.2145834], [78.74903107, 9.2145834], [78.74903107, 9.21430492], [78.74874878, 9.21430492], [78.74874878, 9.2145834], [78.74791718, 9.2145834], [78.74791718, 9.21430492], [78.74597168, 9.21430969], [78.74597168, 9.21402931], [78.74458313, 9.21402931], [78.74458313, 9.21375084], [78.74430847, 9.21375084], [78.74430847, 9.21347141], [78.74375153, 9.21347332], [78.74375153, 9.21319485], [78.74346924, 9.21319485], [78.74346924, 9.21291733], [78.74318695, 9.21291924], [78.74318695, 9.21264076], [78.74208069, 9.21264076], [78.74208069, 9.21236134], [78.74153137, 9.21236134], [78.74153137, 9.21208286], [78.74097443, 9.21208286], [78.74097443, 9.21180534], [78.74041748, 9.21180534], [78.74041748, 9.21208286], [78.73819733, 9.21208286], [78.73819733, 9.21180534], [78.73542023, 9.21181202], [78.73542023, 9.21154118], [78.73486328, 9.21154118], [78.73486328, 9.21125126], [78.73458099, 9.21125126], [78.73458099, 9.21097088], [78.73347473, 9.21097088], [78.73347473, 9.21069527], [78.7326355, 9.21069527], [78.7326355, 9.21041679], [78.73208618, 9.21042156], [78.73208618, 9.21014118], [78.73124695, 9.21014118], [78.73124695, 9.2098608], [78.73097229, 9.2098608], [78.73097229, 9.20958328], [78.7298584, 9.20958328], [78.7298584, 9.20930481], [78.72930908, 9.20931244], [78.72930908, 9.20903111], [78.72846985, 9.20903111], [78.72846985, 9.20875072], [78.72763824, 9.20875072], [78.72763824, 9.20848179], [78.7270813, 9.20848179], [78.7270813, 9.20818996], [78.72680664, 9.20819473], [78.72680664, 9.20763874], [78.72651672, 9.20764065], [78.72651672, 9.20707989], [78.72624969, 9.20708275], [78.72624969, 9.20680523], [78.72569275, 9.20681095], [78.72569275, 9.20653057], [78.72541809, 9.20653057], [78.72541809, 9.20625114], [78.7251358, 9.20625114], [78.7251358, 9.20597267], [78.72458649, 9.20597267], [78.72458649, 9.20569515], [78.72374725, 9.20569515], [78.72374725, 9.20541668], [78.72319794, 9.20542145], [78.72319794, 9.20514107], [78.72264099, 9.20514107], [78.72264099, 9.20485973], [78.7223587, 9.20485973], [78.7223587, 9.20458221], [78.72208405, 9.20458221], [78.72208405, 9.2043066], [78.72180176, 9.20431137], [78.72180176, 9.20403099], [78.7215271, 9.20403099], [78.7215271, 9.20375061], [78.72097015, 9.20375061], [78.72097015, 9.20347023], [78.7206955, 9.20347214], [78.7206955, 9.20319366], [78.72041321, 9.20319366], [78.72041321, 9.20291615], [78.72013855, 9.20292091], [78.72013855, 9.20264053], [78.71985626, 9.20264053], [78.71985626, 9.20235062], [78.7195816, 9.20236015], [78.7195816, 9.20180416], [78.71930695, 9.20181084], [78.71930695, 9.20153141], [78.71901703, 9.20153141], [78.71901703, 9.20125008], [78.71848297, 9.20125008], [78.71848297, 9.2009697], [78.71819305, 9.2009716], [78.71819305, 9.20069408], [78.7179184, 9.20069408], [78.7179184, 9.20013809], [78.71763611, 9.20014], [78.71763611, 9.19931126], [78.71736145, 9.19931126], [78.71736145, 9.19791985], [78.71763611, 9.19791985], [78.71763611, 9.19764042], [78.71792603, 9.19764042], [78.71792603, 9.19791985], [78.71819305, 9.19791603], [78.71819305, 9.19847202], [78.71847534, 9.19847202], [78.71847534, 9.19819355], [78.71875, 9.19819355], [78.71875, 9.19763756], [78.71930695, 9.19764042], [78.71930695, 9.19748974], [78.71930695, 9.19736195], [78.7195816, 9.19736195], [78.7195816, 9.19708443], [78.71986389, 9.19708443], [78.71986389, 9.19624996], [78.7195816, 9.19624996], [78.7195816, 9.19570065], [78.71930695, 9.1956892], [78.71930695, 9.19291782], [78.71901703, 9.19291973], [78.71901703, 9.19097137], [78.71875, 9.19097137], [78.71875, 9.19041538], [78.71847534, 9.19041538], [78.71847534, 9.19013977], [78.71679688, 9.19014168], [78.71679688, 9.1898613], [78.71486664, 9.1898613], [78.71486664, 9.19014168], [78.71347046, 9.19013977], [78.71347046, 9.19041538], [78.71180725, 9.19041538], [78.71180725, 9.19069576], [78.71097565, 9.19069576], [78.71097565, 9.19097137], [78.7076416, 9.19097137], [78.7076416, 9.19069576], [78.70430756, 9.19069576], [78.70430756, 9.19097137], [78.70375061, 9.19097137], [78.70375061, 9.19124889], [78.70347595, 9.19124889], [78.70347595, 9.19153023], [78.70236206, 9.19153023], [78.70236206, 9.19180965], [78.70202637, 9.19180584], [78.70153046, 9.19180584], [78.70153046, 9.19208431], [78.70069122, 9.19208431], [78.70069122, 9.19236183], [78.70014191, 9.19236183], [78.70014191, 9.1926403], [78.69930267, 9.1926403], [78.69930267, 9.19291973], [78.69875336, 9.19291782], [78.69875336, 9.19319439], [78.69763947, 9.19319057], [78.69763947, 9.19348145], [78.69708252, 9.19347191], [78.69708252, 9.19375038], [78.6965332, 9.19375038], [78.6965332, 9.1940279], [78.69568634, 9.1940279], [78.69568634, 9.19431019], [78.69264221, 9.19430637], [78.69264221, 9.19458389], [78.69152832, 9.19458389], [78.69152832, 9.19486237], [78.69069672, 9.19486046], [78.69069672, 9.19542027], [78.68930817, 9.19541645], [78.68930817, 9.19569397], [78.68708038, 9.19569588], [78.68708038, 9.19597244], [78.68430328, 9.19596958], [78.68430328, 9.19624996], [78.68374634, 9.19624996], [78.68374634, 9.19596958], [78.68068695, 9.19596958], [78.68068695, 9.19624996], [78.68041992, 9.19624996], [78.68041992, 9.19654179], [78.67986298, 9.19654179], [78.67986298, 9.19624996], [78.67930603, 9.19624996], [78.67930603, 9.19654179], [78.67903137, 9.19654179], [78.67903137, 9.19624996], [78.67819214, 9.19624996], [78.67819214, 9.19654179], [78.67764282, 9.19654179], [78.67764282, 9.19681072], [78.67736053, 9.19680595], [78.67736053, 9.19736195], [78.67679596, 9.19736195], [78.67679596, 9.19764042], [78.67430878, 9.19764042], [78.67430878, 9.19736195], [78.67318726, 9.19736195], [78.67318726, 9.19791985], [78.67180634, 9.19791603], [78.67180634, 9.19819355], [78.67124939, 9.19819355], [78.67124939, 9.19847202], [78.67069244, 9.19847202], [78.67069244, 9.19819355], [78.67041779, 9.19819355], [78.67041779, 9.19791603], [78.66986084, 9.19791985], [78.66986084, 9.19764042], [78.66958618, 9.19764042], [78.66958618, 9.19736195], [78.66902924, 9.19736195], [78.66902924, 9.19708443], [78.6673584, 9.19708443], [78.6673584, 9.19680595], [78.66707611, 9.19681072], [78.66707611, 9.19596958], [78.66652679, 9.19597244], [78.66652679, 9.19569588], [78.66625214, 9.19569397], [78.66625214, 9.19513988], [78.66348267, 9.19514179], [78.66348267, 9.19486046], [78.6626358, 9.19486237], [78.6626358, 9.19458389], [78.66236115, 9.19458389], [78.66236115, 9.19430637], [78.66208649, 9.19431019], [78.66208649, 9.1940279], [78.66124725, 9.1940279], [78.66124725, 9.19375038], [78.66041565, 9.19375038], [78.66041565, 9.19347191], [78.6598587, 9.19348145], [78.6598587, 9.19291973], [78.65957642, 9.19291973], [78.65957642, 9.1926403], [78.6590271, 9.1926403], [78.6590271, 9.19236183], [78.65791321, 9.19236183], [78.65791321, 9.19208431], [78.65763855, 9.19208431], [78.65763855, 9.19180584], [78.6570816, 9.19180965], [78.6570816, 9.19124889], [78.65680695, 9.19124889], [78.65680695, 9.19041538], [78.65652466, 9.19041538], [78.65652466, 9.19013977], [78.65625, 9.19014168], [78.65625, 9.1898613], [78.65569305, 9.1898613], [78.65569305, 9.18958282], [78.65513611, 9.18958282], [78.65513611, 9.18930531], [78.65486145, 9.18931007], [78.65486145, 9.18902969], [78.65429688, 9.18902969], [78.65429688, 9.18874931], [78.65402985, 9.18874931], [78.65402985, 9.18819523], [78.65319824, 9.18819523], [78.65319061, 9.18791676], [78.6526413, 9.18791962], [78.6526413, 9.18763924], [78.65235901, 9.18763924], [78.65235901, 9.18735027], [78.65180206, 9.18736076], [78.65180206, 9.18708324], [78.65125275, 9.18708324], [78.65125275, 9.18680477], [78.65097046, 9.18680954], [78.65097046, 9.18653202], [78.6506958, 9.18653202], [78.6506958, 9.18625069], [78.65013885, 9.18625069], [78.65013885, 9.18597126], [78.6498642, 9.18597317], [78.6498642, 9.18569469], [78.64902496, 9.18569469], [78.64902496, 9.18486118], [78.64875031, 9.18486118], [78.64875031, 9.18402672], [78.64848328, 9.18403053], [78.64848328, 9.18375111], [78.64763641, 9.18375111], [78.64763641, 9.18347263], [78.64736176, 9.18347263], [78.64736176, 9.18319511], [78.6470871, 9.18319511], [78.6470871, 9.18291664], [78.64653015, 9.18292141], [78.64653015, 9.18264103], [78.64624786, 9.18264103], [78.64624786, 9.18236065], [78.64597321, 9.18236065], [78.64597321, 9.18180466], [78.64569092, 9.18180943], [78.64569092, 9.18153954], [78.6451416, 9.18153954], [78.6451416, 9.18097115], [78.64485931, 9.18097305], [78.64485931, 9.18069458], [78.64458466, 9.18069458], [78.64458466, 9.1795826], [78.64430237, 9.1795826], [78.64430237, 9.17902565], [78.64402771, 9.17903137], [78.64402771, 9.17875099], [78.64375305, 9.17875099], [78.64375305, 9.17846966], [78.64347076, 9.17847347], [78.64347076, 9.178195], [78.64319611, 9.178195], [78.64319611, 9.17735958], [78.64291382, 9.17735958], [78.64291382, 9.17675018], [78.64291382, 9.17625046], [78.64263916, 9.17625046], [78.64263916, 9.17374992], [78.64235687, 9.17374992], [78.64235687, 9.17346954], [78.64263916, 9.1734724], [78.64263916, 9.17125034], [78.64291382, 9.17125034], [78.64291382, 9.17069435], [78.64319611, 9.17069435], [78.64319611, 9.1693058], [78.64402771, 9.16930962], [78.64402771, 9.16874981], [78.64430237, 9.16874981], [78.64430237, 9.16847229], [78.64458466, 9.16847229], [78.64458466, 9.16819382], [78.6451416, 9.16819382], [78.6451416, 9.1679163], [78.64541626, 9.16792011], [78.64541626, 9.16763973], [78.64569092, 9.16763973], [78.64569092, 9.16736031], [78.64597321, 9.16736221], [78.64597321, 9.16708374], [78.64624786, 9.16708374], [78.64624786, 9.16680622], [78.64679718, 9.16681004], [78.64679718, 9.16652966], [78.6470871, 9.16652966], [78.6470871, 9.16623974], [78.64763641, 9.16625023], [78.64763641, 9.16597176], [78.6479187, 9.16597176], [78.6479187, 9.16569424], [78.64819336, 9.16569424], [78.64819336, 9.16541767], [78.64848328, 9.16541958], [78.64848328, 9.16514015], [78.64875031, 9.16514015], [78.64875031, 9.16486168], [78.64902496, 9.16486168], [78.64902496, 9.16374874], [78.64930725, 9.1637516], [78.64930725, 9.16208076], [78.64958191, 9.16208267], [78.64958191, 9.16152668], [78.64985657, 9.16152954], [78.64985657, 9.16097069], [78.65013885, 9.1609726], [78.65013885, 9.16013908], [78.65040588, 9.16014194], [78.65040588, 9.15986061], [78.6506958, 9.15986061], [78.6506958, 9.15930462], [78.65097046, 9.15931034], [78.65097046, 9.15903187], [78.65180206, 9.15903187], [78.65180206, 9.15875053], [78.65486145, 9.15875053], [78.65486145, 9.15903187], [78.65513611, 9.15903187], [78.65513611, 9.15931034], [78.65764618, 9.15931034], [78.65764618, 9.15875053], [78.65791321, 9.15875053], [78.65791321, 9.15819073], [78.65763855, 9.15819454], [78.65763855, 9.15791702], [78.65735626, 9.15792179], [78.65735626, 9.15764141], [78.6554184, 9.15764141], [78.6554184, 9.15736961], [78.6534729, 9.15736961], [78.6534729, 9.15708065], [78.6515274, 9.15708256], [78.6515274, 9.15680504], [78.64958191, 9.15681171], [78.64958191, 9.15653133], [78.64679718, 9.15653133], [78.64679718, 9.15625095], [78.64402771, 9.15625095], [78.64402771, 9.15597057], [78.64097595, 9.15597343], [78.64097595, 9.15569496], [78.63819122, 9.15569496], [78.63819122, 9.15541744], [78.63540649, 9.15542126], [78.63540649, 9.15514088], [78.63430786, 9.15514088], [78.63430786, 9.15486145], [78.63346863, 9.15486145], [78.63346863, 9.15458298], [78.63236237, 9.15458298], [78.63236237, 9.15430546], [78.63124847, 9.15430546], [78.63124847, 9.15402889], [78.63014221, 9.15402889], [78.63014221, 9.15375137], [78.62930298, 9.15375137], [78.62930298, 9.1534729], [78.62819672, 9.1534729], [78.62819672, 9.15319538], [78.62679291, 9.15319538], [78.62596893, 9.15319538], [78.62596893, 9.1534729], [78.62541962, 9.1534729], [78.62541962, 9.15375137], [78.62458038, 9.15375137], [78.62458038, 9.15402889], [78.62374878, 9.15402889], [78.62374878, 9.15430546], [78.62291718, 9.15430546], [78.62291718, 9.15402889], [78.6220932, 9.15402889], [78.6220932, 9.15375137], [78.62264252, 9.15375137], [78.62264252, 9.1534729], [78.62236023, 9.1534729], [78.62236023, 9.15319538], [78.62180328, 9.15319538], [78.62180328, 9.1534729], [78.62069702, 9.1534729], [78.62069702, 9.15319538], [78.61985779, 9.15319538], [78.61985779, 9.15291691], [78.61902618, 9.15292072], [78.61902618, 9.1526413], [78.61847687, 9.1526413], [78.61847687, 9.15236092], [78.6159668, 9.15236092], [78.6159668, 9.15207958], [78.61430359, 9.1520834], [78.61430359, 9.15152645], [78.61402893, 9.15153122], [78.61402893, 9.1512394], [78.61347198, 9.15125084], [78.61347198, 9.15097332], [78.61264038, 9.15097332], [78.61264038, 9.15069485], [78.61208344, 9.15069485], [78.61208344, 9.15041637], [78.61180878, 9.15042114], [78.61180878, 9.1501379], [78.61152649, 9.1501379], [78.61152649, 9.14986038], [78.60986328, 9.14986038], [78.60986328, 9.14958477], [78.60847473, 9.14958191], [78.60847473, 9.14930439], [78.60764313, 9.14931107], [78.60764313, 9.14903069], [78.60708618, 9.14903069], [78.60708618, 9.14875031], [78.60624695, 9.14875031], [78.60624695, 9.14847183], [78.60514069, 9.14847183], [78.60514069, 9.14819431], [78.6048584, 9.14820099], [78.6048584, 9.14792061], [78.60430908, 9.14792061], [78.60430908, 9.14764023], [78.60375214, 9.14764023], [78.60375214, 9.14735985], [78.60319519, 9.14735985], [78.60319519, 9.14708424], [78.60236359, 9.14708424], [78.60236359, 9.14680576], [78.60124969, 9.14681053], [78.60124969, 9.14653111], [78.60069275, 9.14653111], [78.60069275, 9.14624977], [78.60041046, 9.14624977], [78.60041046, 9.14597034], [78.6001358, 9.14597225], [78.6001358, 9.14569378], [78.5993042, 9.14569378], [78.5993042, 9.14541626], [78.59874725, 9.14542961], [78.59874725, 9.14513969], [78.5984726, 9.14513969], [78.5984726, 9.14486027], [78.59791565, 9.14486217], [78.59791565, 9.1445837], [78.59708405, 9.1445837], [78.59708405, 9.14430618], [78.59597015, 9.14431095], [78.59597015, 9.14402962], [78.59570313, 9.14402962], [78.59570313, 9.14375019], [78.59541321, 9.14375019], [78.59541321, 9.14347172], [78.59486389, 9.14347172], [78.59486389, 9.1431942], [78.5945816, 9.1431942], [78.5945816, 9.14291573], [78.59401703, 9.14291954], [78.59401703, 9.14264011], [78.59348297, 9.14264011], [78.59348297, 9.14235973], [78.59319305, 9.14235973], [78.59319305, 9.14208412], [78.59263611, 9.14208412], [78.59263611, 9.14180565], [78.59179687, 9.14181042], [78.59179687, 9.14153004], [78.59153748, 9.14153004], [78.59153748, 9.14124966], [78.59124756, 9.14124966], [78.59124756, 9.14096928], [78.59069824, 9.14097214], [78.59069061, 9.14069366], [78.59041595, 9.14069366], [78.59041595, 9.14041805], [78.5901413, 9.14041996], [78.5901413, 9.14013958], [78.58985901, 9.14013958], [78.58985901, 9.13986015], [78.58930206, 9.13986206], [78.58930206, 9.13958359], [78.5890274, 9.13958359], [78.5890274, 9.13930607], [78.58875275, 9.13930607], [78.58875275, 9.1390276], [78.58847046, 9.13903046], [78.58847046, 9.13875198], [78.58790588, 9.13875198], [78.58790588, 9.1384716], [78.5873642, 9.1384716], [78.5873642, 9.13791847], [78.58653259, 9.13792038], [78.58653259, 9.13764191], [78.58625031, 9.13764191], [78.58625031, 9.13696003], [78.58625031, 9.13680458], [78.58598328, 9.1368103], [78.58598328, 9.13653183], [78.58513641, 9.13653183], [78.58513641, 9.13626099], [78.58486176, 9.13626099], [78.58486176, 9.13597107], [78.58403015, 9.13597107], [78.58403015, 9.13569641], [78.58319092, 9.13569641], [78.58319092, 9.13513947], [78.58291626, 9.13513947], [78.58291626, 9.13486099], [78.5826416, 9.13486099], [78.5826416, 9.13458347], [78.58235931, 9.13458347], [78.58235931, 9.13402653], [78.58207703, 9.13402939], [78.58207703, 9.13347054], [78.58180237, 9.1334734], [78.58180237, 9.13319492], [78.58069611, 9.13319969], [78.58069611, 9.13292027], [78.58040619, 9.13292027], [78.58040619, 9.13236141], [78.58013916, 9.13236141], [78.58013916, 9.13208294], [78.5798645, 9.13208294], [78.5798645, 9.13180542], [78.57875061, 9.13181019], [78.57875061, 9.13153172], [78.57818604, 9.13153172], [78.57818604, 9.13125134], [78.57736206, 9.13125134], [78.57736206, 9.13153172], [78.57569122, 9.13153172], [78.57569122, 9.13181019], [78.57514191, 9.13180542], [78.57514191, 9.13208294], [78.57491302, 9.13208294], [78.57430267, 9.13208294], [78.57430267, 9.13236141], [78.57375336, 9.13236141], [78.57375336, 9.13264084], [78.57290649, 9.13264084], [78.57290649, 9.13292027], [78.57235718, 9.13292027], [78.57235718, 9.13319969], [78.57152557, 9.13319492], [78.57152557, 9.1334734], [78.57068634, 9.13347054], [78.57068634, 9.13375092], [78.57013702, 9.13375092], [78.57013702, 9.13402939], [78.56931305, 9.13402939], [78.56931305, 9.13430977], [78.56874847, 9.134305], [78.56874847, 9.13458347], [78.56764221, 9.13458347], [78.56764221, 9.134305], [78.56652832, 9.134305], [78.56652832, 9.13458347], [78.56624603, 9.13458061], [78.56624603, 9.13513947], [78.56458282, 9.13513947], [78.56458282, 9.13541985], [78.56402588, 9.13541698], [78.56402588, 9.13569641], [78.56319427, 9.13569641], [78.56319427, 9.13597107], [78.56263733, 9.13597107], [78.56263733, 9.13626099], [78.56208038, 9.13626099], [78.56208038, 9.13653183], [78.56014252, 9.13653183], [78.56014252, 9.13626099], [78.55986023, 9.13626099], [78.55986023, 9.13653183], [78.5595932, 9.13653183], [78.5595932, 9.1368103], [78.55680847, 9.13680458], [78.55680847, 9.13708401], [78.55458069, 9.13708401], [78.55458069, 9.13736153], [78.55347443, 9.13736153], [78.55347443, 9.13708401], [78.55236053, 9.13708401], [78.55236053, 9.13736153], [78.54875183, 9.13736153], [78.54875183, 9.13764191], [78.54846954, 9.13764191], [78.54846954, 9.13736153], [78.54541779, 9.13736153], [78.54541779, 9.13708401], [78.54402924, 9.13708401], [78.54402924, 9.13736153], [78.54347229, 9.13736153], [78.54347229, 9.13708401], [78.5404129, 9.13708401], [78.5404129, 9.13736153], [78.53874969, 9.13736153], [78.53874969, 9.13708401], [78.53791809, 9.13708401], [78.53791809, 9.13680458], [78.5376358, 9.1368103], [78.5376358, 9.13653183], [78.53679657, 9.13653183], [78.53679657, 9.1368103], [78.53542328, 9.1368103], [78.53542328, 9.13653183], [78.53151703, 9.13653183], [78.53151703, 9.13626099], [78.53098297, 9.13626099], [78.53098297, 9.13653183], [78.5304184, 9.13653183], [78.5304184, 9.13626099], [78.52902985, 9.13626099], [78.52902985, 9.13597107], [78.52458191, 9.13597107], [78.52458191, 9.13626099], [78.52403259, 9.13626099], [78.52403259, 9.13653183], [78.52375031, 9.13653183], [78.52375031, 9.13626099], [78.52179718, 9.13626099], [78.52179718, 9.13653183], [78.52097321, 9.13653183], [78.52097321, 9.13626099], [78.5201416, 9.13626099], [78.5201416, 9.13597107], [78.51957703, 9.13597107], [78.51957703, 9.13626099], [78.51875305, 9.13626099], [78.51875305, 9.13597107], [78.51791382, 9.13597107], [78.51791382, 9.13569641], [78.51708221, 9.13569641], [78.51708221, 9.13597107], [78.51652527, 9.13597107], [78.51652527, 9.13569641], [78.51430511, 9.13569641], [78.51430511, 9.13541698], [78.51319122, 9.13541985], [78.51319122, 9.13513947], [78.51040649, 9.13513947], [78.51040649, 9.13486099], [78.50985718, 9.13486099], [78.50985718, 9.13458061], [78.50846863, 9.13458347], [78.50846863, 9.134305], [78.50763702, 9.13430977], [78.50763702, 9.13402939], [78.50708771, 9.13402939], [78.50708771, 9.13375092], [78.50681305, 9.13375092], [78.50681305, 9.13347054], [78.50514221, 9.1334734], [78.50514221, 9.13319492], [78.50374603, 9.13319969], [78.50374603, 9.13292027], [78.5029068, 9.13292027], [78.5029068, 9.13264084], [78.50208282, 9.13264084], [78.50208282, 9.13236141], [78.50041962, 9.13236141], [78.50041962, 9.13208294], [78.49958038, 9.13208294], [78.49958038, 9.13180542], [78.49874878, 9.13181019], [78.49874878, 9.13153172], [78.49819183, 9.13153172], [78.49819183, 9.13125134], [78.49624634, 9.13125134], [78.49624634, 9.13097095], [78.49541473, 9.13097095], [78.49541473, 9.13069534], [78.49485779, 9.13069534], [78.49485779, 9.13041687], [78.49430847, 9.13042164], [78.49430847, 9.13012981], [78.49319458, 9.13013935], [78.49319458, 9.12986088], [78.49180603, 9.12986088], [78.49180603, 9.12958336], [78.49124908, 9.12958336], [78.49124908, 9.12930489], [78.49069214, 9.12931156], [78.49069214, 9.12903118], [78.49014282, 9.12903118], [78.49014282, 9.12874889], [78.48986053, 9.12874889], [78.48986053, 9.12847328], [78.48819733, 9.12847328], [78.48819733, 9.12819481], [78.48735809, 9.12819481], [78.48735809, 9.12847328], [78.48625183, 9.12847328], [78.48625183, 9.12819481], [78.48569489, 9.12819481], [78.48569489, 9.12791729], [78.48401642, 9.1279192], [78.48401642, 9.12874889], [78.48430634, 9.12874889], [78.48430634, 9.12903118], [78.48458099, 9.12903118], [78.48458099, 9.12874889], [78.48680878, 9.12874889], [78.48680878, 9.12931156], [78.48707581, 9.12931156], [78.48707581, 9.12986088], [78.48735809, 9.12986088], [78.48735809, 9.13125134], [78.48764038, 9.13125134], [78.48764038, 9.13181019], [78.48791504, 9.13180542], [78.48791504, 9.13208294], [78.48819733, 9.13208294], [78.48819733, 9.13236141], [78.48847198, 9.13236141], [78.48847198, 9.13264084], [78.48874664, 9.13264084], [78.48874664, 9.13292027], [78.4890213, 9.13292027], [78.4890213, 9.13513947], [78.48874664, 9.13513947], [78.48874664, 9.13569641], [78.4890213, 9.13569069], [78.4890213, 9.13792038], [78.48930359, 9.13791847], [78.48930359, 9.1384716], [78.48958588, 9.1384716], [78.48958588, 9.14124966], [78.48986053, 9.14124966], [78.48986053, 9.14235973], [78.49013519, 9.14235973], [78.49013519, 9.1431942], [78.48986053, 9.1431942], [78.48986053, 9.14347172], [78.49013519, 9.14347172], [78.49013519, 9.14375019], [78.49041748, 9.14375019], [78.49041748, 9.14431095], [78.49069214, 9.14430618], [78.49069214, 9.14486217], [78.49041748, 9.14486027], [78.49041748, 9.14513969], [78.49014282, 9.14513969], [78.49014282, 9.14624977], [78.49041748, 9.14624977], [78.49041748, 9.14820099], [78.49014282, 9.14820099], [78.49014282, 9.14903069], [78.48986053, 9.14902782], [78.48986053, 9.1501379], [78.48874664, 9.1501379], [78.48874664, 9.14958477], [78.48847198, 9.14958191], [78.48847198, 9.14930439], [78.48819733, 9.14931107], [78.48819733, 9.14820099], [78.48847198, 9.14820099], [78.48847198, 9.14764023], [78.48874664, 9.14764023], [78.48874664, 9.14708042], [78.48902893, 9.14708424], [78.48902893, 9.14652824], [78.48929596, 9.14653111], [78.48929596, 9.14542961], [78.48874664, 9.14542961], [78.48874664, 9.14458179], [78.48847198, 9.1445837], [78.48847198, 9.14402771], [78.48874664, 9.14402962], [78.48874664, 9.14318943], [78.48847198, 9.1431942], [78.48847198, 9.14152813], [78.48819733, 9.14153004], [78.48819733, 9.14096928], [78.48791504, 9.14097214], [78.48791504, 9.13875008], [78.48764038, 9.13875198], [78.48764038, 9.13819122], [78.48735809, 9.13819313], [78.48735809, 9.13708401], [78.48708344, 9.13708401], [78.48708344, 9.13652706], [78.48652649, 9.13653183], [78.48652649, 9.13626099], [78.48596191, 9.13626099], [78.48596191, 9.13653183], [78.48486328, 9.13653183], [78.48486328, 9.13597107], [78.48458099, 9.13597107], [78.48458099, 9.13541698], [78.48430634, 9.13541985], [78.48430634, 9.13513947], [78.48291779, 9.13513947], [78.48291779, 9.13541985], [78.48208618, 9.13541985], [78.48208618, 9.13486099], [78.4826355, 9.13486099], [78.4826355, 9.134305], [78.48236084, 9.13430977], [78.48236084, 9.13402939], [78.48264313, 9.13402939], [78.48264313, 9.13264084], [78.48236084, 9.13264084], [78.48236084, 9.13236141], [78.48208618, 9.13236141], [78.48208618, 9.13180542], [78.48152924, 9.13181019], [78.48152924, 9.13153172], [78.48124695, 9.13153172], [78.48124695, 9.13125134], [78.48069763, 9.13125134], [78.48069763, 9.13097095], [78.48041534, 9.13097095], [78.48041534, 9.13041687], [78.48014832, 9.13042164], [78.48014832, 9.12931156], [78.48097229, 9.12930489], [78.48097229, 9.12958336], [78.48180389, 9.12958336], [78.48180389, 9.12930489], [78.48208618, 9.12931156], [78.48208618, 9.12764072], [78.48179626, 9.12764072], [78.48179626, 9.1273613], [78.48041534, 9.1273613], [78.48041534, 9.12708282], [78.4798584, 9.12708282], [78.4798584, 9.1273613], [78.47819519, 9.1273613], [78.47819519, 9.12708282], [78.4779129, 9.12708282], [78.4779129, 9.1273613], [78.47735596, 9.1273613], [78.47735596, 9.12764072], [78.47624969, 9.12764072], [78.47624969, 9.1279192], [78.47569275, 9.1279192], [78.47569275, 9.12764072], [78.47541809, 9.12764072], [78.47541809, 9.1273613], [78.4706955, 9.1273613], [78.4706955, 9.12708282], [78.46485901, 9.12708282], [78.46485901, 9.12680531], [78.46180725, 9.12680531], [78.46180725, 9.12708282], [78.46097565, 9.12708282], [78.46097565, 9.12680531], [78.4604187, 9.12681103], [78.4604187, 9.12653065], [78.4576416, 9.12653065], [78.4576416, 9.12625122], [78.45735931, 9.12625122], [78.45735931, 9.12597275], [78.45652771, 9.12597275], [78.45652771, 9.12569523], [78.45625305, 9.12569523], [78.45625305, 9.12541676], [78.45597839, 9.12542057], [78.45597839, 9.12514114], [78.45513916, 9.12514114], [78.45513916, 9.1248579], [78.4548645, 9.12486076], [78.4548645, 9.12458229], [78.45430756, 9.12458229], [78.45430756, 9.12486076], [78.4540329, 9.1248579], [78.4540329, 9.12514114], [78.45318604, 9.12514114], [78.45318604, 9.1248579], [78.45207977, 9.12486076], [78.45207977, 9.12458229], [78.45153046, 9.12458229], [78.45153046, 9.12430668], [78.45096588, 9.12432003], [78.45096588, 9.12403107], [78.45041656, 9.12403107], [78.45041656, 9.12375069], [78.44985199, 9.12375069], [78.44985199, 9.12347031], [78.44763947, 9.12347317], [78.44763947, 9.12319374], [78.44708252, 9.12319374], [78.44708252, 9.12291622], [78.44625092, 9.12292099], [78.44625092, 9.12264061], [78.44513702, 9.12264061], [78.44513702, 9.12236023], [78.44403076, 9.12236023], [78.44403076, 9.12208462], [78.44319153, 9.12208462], [78.44319153, 9.12236023], [78.44291687, 9.12236023], [78.44291687, 9.12208462], [78.44208527, 9.12208462], [78.44208527, 9.12180424], [78.44124603, 9.12181091], [78.44124603, 9.12153053], [78.44013977, 9.12153053], [78.44013977, 9.1212616], [78.43930817, 9.1212616], [78.43930817, 9.12096977], [78.43846893, 9.12097168], [78.43846893, 9.12069416], [78.43736267, 9.12069416], [78.43736267, 9.12041569], [78.43653107, 9.12042141], [78.43653107, 9.12014008], [78.43569183, 9.12014008], [78.43569183, 9.1198597], [78.43458557, 9.1198597], [78.43458557, 9.11958218], [78.43347168, 9.11958218], [78.43347168, 9.11930561], [78.43264008, 9.11931133], [78.43264008, 9.11903], [78.43180847, 9.11903], [78.43180847, 9.11874962], [78.43096924, 9.11874962], [78.43096924, 9.11847019], [78.43013763, 9.1184721], [78.43013763, 9.11819363], [78.42986298, 9.11819363], [78.42986298, 9.11791611], [78.42958069, 9.11792088], [78.42958069, 9.11763954], [78.42903137, 9.11763954], [78.42903137, 9.11736202], [78.42791748, 9.11736202], [78.42791748, 9.11763954], [78.42736053, 9.11763954], [78.42736053, 9.11736202], [78.42541504, 9.11736202], [78.42541504, 9.11708355], [78.42514038, 9.11708355], [78.42514038, 9.11652756], [78.42375183, 9.11653042], [78.42375183, 9.11625004], [78.42346954, 9.11625004], [78.42346954, 9.11596966], [78.42263794, 9.11597157], [78.42263794, 9.11569405], [78.42236328, 9.11569405], [78.42236328, 9.11541557], [78.42180634, 9.11542034], [78.42180634, 9.11513138], [78.42124939, 9.11513996], [78.42124939, 9.11486244], [78.42069244, 9.11486244], [78.42069244, 9.11458397], [78.41958618, 9.11458397], [78.41958618, 9.11430645], [78.41902924, 9.11431026], [78.41902924, 9.11403179], [78.41847229, 9.11403179], [78.41847229, 9.11375046], [78.41819763, 9.11375046], [78.41819763, 9.11347198], [78.41791534, 9.11347198], [78.41791534, 9.11319447], [78.41708374, 9.11319447], [78.41708374, 9.11347198], [78.41652679, 9.11347198], [78.41652679, 9.11319447], [78.41596985, 9.11319447], [78.41596985, 9.1129179], [78.4154129, 9.1129179], [78.4154129, 9.11264038], [78.41401672, 9.11264038], [78.41401672, 9.11236191], [78.41374207, 9.11236191], [78.41374207, 9.11180973], [78.41347504, 9.11180592], [78.41347504, 9.11208439], [78.41152954, 9.11208439], [78.41152954, 9.11180592], [78.41069794, 9.11180973], [78.41069794, 9.11125183], [78.41042328, 9.11125183], [78.41042328, 9.11097145], [78.41014099, 9.11097145], [78.41014099, 9.11069584], [78.4098587, 9.11069584], [78.4098587, 9.11041546], [78.40930176, 9.11042023], [78.40930176, 9.11013985], [78.40875244, 9.11013985], [78.40875244, 9.10986233], [78.40847015, 9.10986233], [78.40847015, 9.10902691], [78.40820313, 9.10902977], [78.40820313, 9.10847092], [78.40791321, 9.10847092], [78.40791321, 9.1081953], [78.40763855, 9.1081953], [78.40763855, 9.10791683], [78.40735626, 9.10791969], [78.40735626, 9.10763931], [78.4070816, 9.10763931], [78.4070816, 9.10791969], [78.40680695, 9.10791969], [78.40680695, 9.10763931], [78.40569305, 9.10763931], [78.40569305, 9.10736084], [78.4054184, 9.10736084], [78.4054184, 9.10708141], [78.40486145, 9.10708332], [78.40486145, 9.10680485], [78.40458679, 9.10680962], [78.40458679, 9.10652924], [78.40429688, 9.10652924], [78.40429688, 9.10625076], [78.40402985, 9.10625076], [78.40402985, 9.10597134], [78.4034729, 9.10597324], [78.4034729, 9.10569477], [78.40319824, 9.10569477], [78.40319061, 9.10541725], [78.40291595, 9.10542202], [78.40291595, 9.10514069], [78.40235901, 9.10514069], [78.40235901, 9.10486126], [78.40208435, 9.10486126], [78.40208435, 9.10458279], [78.40125275, 9.10458279], [78.40125275, 9.10430527], [78.4006958, 9.10431194], [78.4006958, 9.10403061], [78.40040588, 9.10403061], [78.40040588, 9.10375118], [78.40013885, 9.10375118], [78.40013885, 9.10347271], [78.3998642, 9.1034708], [78.3998642, 9.10319519], [78.39930725, 9.10319519], [78.39930725, 9.10291672], [78.39874268, 9.10292244], [78.39874268, 9.10264111], [78.39848328, 9.10264111], [78.39848328, 9.10236073], [78.39819336, 9.10236073], [78.39819336, 9.10180855], [78.3979187, 9.10180855], [78.3979187, 9.10153103], [78.39653015, 9.10153103], [78.39653015, 9.10125065], [78.39624786, 9.10125065], [78.39624786, 9.10097122], [78.39597321, 9.10097313], [78.39597321, 9.10069466], [78.39569092, 9.10069466], [78.39569092, 9.10041714], [78.39541626, 9.10042095], [78.39541626, 9.10013199], [78.3951416, 9.10013866], [78.3951416, 9.09986115], [78.39485931, 9.09986115], [78.39485931, 9.09958267], [78.39458466, 9.09958267], [78.39458466, 9.09930515], [78.39402771, 9.09931087], [78.39402771, 9.09903145], [78.39319611, 9.09903145], [78.39319611, 9.09846973], [78.39291382, 9.0984726], [78.39291382, 9.09819508], [78.39263916, 9.09819508], [78.39263916, 9.0979166], [78.39235687, 9.09792137], [78.39235687, 9.09764099], [78.39208221, 9.09764099], [78.39208221, 9.09735966], [78.39152527, 9.09735966], [78.39152527, 9.09708214], [78.39125061, 9.09709167], [78.39125061, 9.09681129], [78.39068604, 9.09681129], [78.39068604, 9.09625053], [78.39013672, 9.09625053], [78.39013672, 9.09597015], [78.38957977, 9.09597206], [78.38957977, 9.09569359], [78.38930511, 9.09569359], [78.38930511, 9.09541607], [78.38903046, 9.09542084], [78.38903046, 9.09514141], [78.38874817, 9.09514141], [78.38874817, 9.09486008], [78.38846588, 9.09486008], [78.38846588, 9.0945797], [78.38791656, 9.09458447], [78.38791656, 9.09430599], [78.38735962, 9.09430885], [78.38735962, 9.09403133], [78.38709259, 9.09403133], [78.38709259, 9.09375], [78.38680267, 9.09375], [78.38680267, 9.09346962], [78.38625336, 9.09347153], [78.38625336, 9.09319401], [78.38569641, 9.09319401], [78.38569641, 9.09291553], [78.38540649, 9.09292126], [78.38540649, 9.09263992], [78.38513947, 9.09263992], [78.38513947, 9.09235954], [78.38486481, 9.0923624], [78.38486481, 9.09208202], [78.38458252, 9.09208202], [78.38458252, 9.09180641], [78.3840332, 9.09181118], [78.3840332, 9.09152985], [78.38375854, 9.09152985], [78.38375854, 9.09125042], [78.38346863, 9.09125042], [78.38346863, 9.09097195], [78.38291931, 9.09097195], [78.38291931, 9.09069443], [78.38263702, 9.09069443], [78.38263702, 9.09041595], [78.38208008, 9.09041977], [78.38208008, 9.09014034], [78.38181305, 9.09014034], [78.38181305, 9.08985996], [78.38153076, 9.08985996], [78.38153076, 9.08958435], [78.38097382, 9.08958435], [78.38097382, 9.08930588], [78.38069916, 9.08931065], [78.38069916, 9.08903027], [78.38041687, 9.08903027], [78.38041687, 9.08875179], [78.38014221, 9.08875179], [78.38014221, 9.08847046], [78.37985992, 9.08847237], [78.37985992, 9.0882206], [78.37985992, 9.08791637], [78.3795929, 9.08792019], [78.3795929, 9.08763981], [78.37902832, 9.08763981], [78.37902832, 9.08736229], [78.37847137, 9.08736229], [78.37847137, 9.08708382], [78.37819672, 9.08708382], [78.37819672, 9.0868063], [78.37763214, 9.08681011], [78.37763214, 9.08652973], [78.37718964, 9.08652973], [78.37708282, 9.08652973], [78.37708282, 9.08625031], [78.37680817, 9.08625031], [78.37680817, 9.08597183], [78.37652588, 9.08597183], [78.37652588, 9.08569431], [78.37625122, 9.08569431], [78.37625122, 9.08541775], [78.37596893, 9.08541965], [78.37596893, 9.08515072], [78.37542725, 9.08515072], [78.37541962, 9.08485889], [78.37513733, 9.08486176], [78.37513733, 9.08458424], [78.3747406, 9.08458424], [78.37458038, 9.08458424], [78.37458038, 9.08446121], [78.37458038, 9.08430576], [78.37430573, 9.08430576], [78.37430573, 9.08422565], [78.37430573, 9.08402824], [78.3740387, 9.08403015], [78.37374878, 9.08403015], [78.37374878, 9.08377171], [78.37403107, 9.08375168], [78.37403107, 9.0834713], [78.37374878, 9.0834713], [78.37374878, 9.08319569], [78.37347412, 9.08319569], [78.37347412, 9.08291531], [78.37291718, 9.08292198], [78.37291718, 9.08263969], [78.37229156, 9.08263969], [78.3720932, 9.08263969], [78.37208557, 9.08248043], [78.37208557, 9.08236122], [78.37194061, 9.08236122], [78.37180328, 9.08236122], [78.37180328, 9.08224964], [78.37180328, 9.08208275], [78.37158966, 9.08209038], [78.37152863, 9.08181], [78.37124634, 9.08181], [78.37124634, 9.08152962], [78.37097168, 9.08152962], [78.37097168, 9.08097076], [78.37014008, 9.08097267], [78.37014008, 9.08124924], [78.36985779, 9.08124924], [78.36985779, 9.08152962], [78.36958313, 9.08152962], [78.36958313, 9.08209038], [78.36930847, 9.08208275], [78.36930847, 9.08236122], [78.36846924, 9.08235931], [78.36846924, 9.08263969], [78.36819458, 9.08263969], [78.36819458, 9.08319569], [78.36791992, 9.08319569], [78.36791992, 9.0834713], [78.36736298, 9.0834713], [78.36736298, 9.08375168], [78.36708069, 9.08374882], [78.36708069, 9.08415985], [78.36708069, 9.08430958], [78.36680603, 9.08430576], [78.36680603, 9.08458424], [78.36624908, 9.08458424], [78.36624908, 9.08486176], [78.36569214, 9.08485889], [78.36569214, 9.08515072], [78.36541748, 9.08515072], [78.36541748, 9.08541965], [78.36513519, 9.08541775], [78.36513519, 9.08569431], [78.36486053, 9.08569431], [78.36486053, 9.08597183], [78.36458588, 9.08597183], [78.36458588, 9.08652973], [78.36429596, 9.08652973], [78.36429596, 9.08681011], [78.36402893, 9.0868063], [78.36402893, 9.08708382], [78.36374664, 9.08708382], [78.36374664, 9.08763981], [78.36347198, 9.08763981], [78.36347198, 9.08819389], [78.36374664, 9.08819389], [78.36374664, 9.08847237], [78.36402893, 9.08847046], [78.36402893, 9.08903027], [78.36429596, 9.08903027], [78.36429596, 9.08931065], [78.36458588, 9.08930588], [78.36458588, 9.08958435], [78.36513519, 9.08958435], [78.36513519, 9.08985996], [78.36541748, 9.08985996], [78.36541748, 9.09014034], [78.36569214, 9.09014034], [78.36569214, 9.09041977], [78.36597443, 9.09041595], [78.36597443, 9.09069443], [78.36624908, 9.09069443], [78.36624908, 9.09125042], [78.36653137, 9.09125042], [78.36653137, 9.0923624], [78.36597443, 9.0923624], [78.36597443, 9.09208202], [78.36541748, 9.09208202], [78.36541748, 9.09180641], [78.36514282, 9.09181118], [78.36514282, 9.09125042], [78.36486053, 9.09125042], [78.36486053, 9.09097195], [78.36458588, 9.09097195], [78.36458588, 9.09069443], [78.36430359, 9.09069443], [78.36430359, 9.09041595], [78.36402893, 9.09041977], [78.36402893, 9.09014034], [78.36374664, 9.09014034], [78.36374664, 9.08985996], [78.36347198, 9.08985996], [78.36347198, 9.08930588], [78.36319733, 9.08931065], [78.36319733, 9.08903027], [78.36292267, 9.08903027], [78.36292267, 9.08875179], [78.36263275, 9.08875179], [78.36263275, 9.08708191], [78.36235809, 9.08708382], [78.36235809, 9.0868063], [78.36263275, 9.08681011], [78.36263275, 9.08597183], [78.36291504, 9.08597183], [78.36290741, 9.08535862], [78.36319733, 9.08541965], [78.36319733, 9.08528137], [78.36319733, 9.08514023], [78.36347198, 9.08515072], [78.36347198, 9.08458138], [78.36374664, 9.08458424], [78.36374664, 9.08430576], [78.36429596, 9.08430958], [78.36429596, 9.08375168], [78.36458588, 9.08375168], [78.36458588, 9.08319092], [78.36486053, 9.08319569], [78.36486053, 9.08291531], [78.36514282, 9.08292198], [78.36514282, 9.08235931], [78.36541748, 9.08236122], [78.36541748, 9.08180523], [78.36569214, 9.08181], [78.36569214, 9.08124924], [78.36597443, 9.08124924], [78.3659668, 9.08097076], [78.36624908, 9.08097076], [78.36624908, 9.08041668], [78.36653137, 9.08041954], [78.36653137, 9.08014202], [78.36680603, 9.08014202], [78.36680603, 9.07986069], [78.36708069, 9.07986069], [78.36708069, 9.07913017], [78.36708069, 9.07902718], [78.36736298, 9.07902718], [78.36736298, 9.07819462], [78.36763763, 9.07819462], [78.36763763, 9.0779171], [78.36736298, 9.07792187], [78.36736298, 9.07764053], [78.36708069, 9.07764053], [78.36708069, 9.07736111], [78.36680603, 9.07736111], [78.36680603, 9.07708263], [78.36653137, 9.07708263], [78.36653137, 9.07680511], [78.36624908, 9.07681179], [78.36624908, 9.07653141], [78.3659668, 9.07653141], [78.3659668, 9.07625103], [78.36541748, 9.07625103], [78.36541748, 9.07595921], [78.36513519, 9.07597256], [78.36513519, 9.07569504], [78.36486053, 9.07569504], [78.36486053, 9.07541656], [78.36458588, 9.07542133], [78.36458588, 9.07514095], [78.36429596, 9.07514095], [78.36429596, 9.07486057], [78.36402893, 9.07486057], [78.36402893, 9.07458305], [78.36374664, 9.07458305], [78.36374664, 9.07430458], [78.36347198, 9.07430935], [78.36347198, 9.07403088], [78.36319733, 9.07403088], [78.36319733, 9.07375145], [78.36263275, 9.07375145], [78.36263275, 9.07347107], [78.36235809, 9.07347298], [78.36235809, 9.07319546], [78.36208344, 9.07319546], [78.36208344, 9.07291698], [78.36180878, 9.07291889], [78.36180878, 9.07264137], [78.36152649, 9.07264137], [78.36152649, 9.07236099], [78.36125183, 9.07236099], [78.36125183, 9.07208347], [78.36096954, 9.07208347], [78.36096954, 9.07180691], [78.36068726, 9.07181072], [78.36068726, 9.0715313], [78.36042023, 9.0715313], [78.36042023, 9.07125092], [78.36013794, 9.07125092], [78.36013794, 9.07096958], [78.35986328, 9.0709734], [78.35986328, 9.07069492], [78.35958099, 9.07069492], [78.35958099, 9.0704174], [78.35901642, 9.07042122], [78.35901642, 9.07015038], [78.35874939, 9.07015038], [78.35874939, 9.06986046], [78.35847473, 9.06986046], [78.35847473, 9.06958199], [78.35819244, 9.06958199], [78.35819244, 9.06930447], [78.35791779, 9.06931114], [78.35791779, 9.06902885], [78.35764313, 9.06902885], [78.35764313, 9.06875038], [78.35708618, 9.06875038], [78.35708618, 9.06847191], [78.35680389, 9.06847191], [78.35680389, 9.06819439], [78.35652924, 9.06819439], [78.35652924, 9.0676384], [78.35624695, 9.06764126], [78.35624695, 9.06735992], [78.35597229, 9.06735992], [78.35597229, 9.06708431], [78.35541534, 9.06708431], [78.35541534, 9.06680584], [78.35514069, 9.06681061], [78.35514069, 9.06653118], [78.3548584, 9.06653118], [78.3548584, 9.06624985], [78.35430908, 9.06624985], [78.35430908, 9.06597233], [78.35402679, 9.06597233], [78.35402679, 9.06569386], [78.35375214, 9.06569386], [78.35375214, 9.06513786], [78.35346222, 9.06513977], [78.35346222, 9.06486034], [78.35319519, 9.06486225], [78.35319519, 9.06458378], [78.35263824, 9.06458378], [78.35263824, 9.06430626], [78.35235596, 9.06431103], [78.35235596, 9.06375027], [78.35180664, 9.06375027], [78.35180664, 9.06347179], [78.35152435, 9.06347179], [78.35152435, 9.06319427], [78.35124969, 9.06319427], [78.35124969, 9.0629158], [78.35098267, 9.06291962], [78.35098267, 9.06264019], [78.35069275, 9.06264019], [78.35069275, 9.06235981], [78.35041809, 9.06235981], [78.35041809, 9.0620842], [78.3501358, 9.0620842], [78.3501358, 9.06180573], [78.34958649, 9.06181145], [78.34958649, 9.06124973], [78.34929657, 9.06124973], [78.34929657, 9.0609808], [78.34902954, 9.0609808], [78.34902954, 9.06069088], [78.34874725, 9.06069374], [78.34874725, 9.06041622], [78.34819794, 9.06042004], [78.34819794, 9.06013966], [78.34792328, 9.06013966], [78.34792328, 9.05986023], [78.34764099, 9.05986214], [78.34764099, 9.05958366], [78.34708405, 9.05958366], [78.34708405, 9.05930614], [78.34680176, 9.05930996], [78.34680176, 9.05902958], [78.3465271, 9.05902958], [78.3465271, 9.05875015], [78.34625244, 9.05875015], [78.34625244, 9.05847168], [78.3456955, 9.05847168], [78.3456955, 9.05819416], [78.34541321, 9.05819416], [78.34541321, 9.05791759], [78.34513855, 9.05792046], [78.34513855, 9.05764198], [78.34458923, 9.05764198], [78.34458923, 9.0573616], [78.34430695, 9.0573616], [78.34430695, 9.05708408], [78.34402466, 9.05708408], [78.34402466, 9.05680561], [78.34348297, 9.05681038], [78.34348297, 9.05653191], [78.34319305, 9.05653191], [78.34319305, 9.05625153], [78.3429184, 9.05625153], [78.3429184, 9.05596924], [78.34236145, 9.05597115], [78.34236145, 9.05569553], [78.34208679, 9.05569553], [78.34208679, 9.05541801], [78.34152222, 9.05541992], [78.34152222, 9.05513859], [78.34124756, 9.05513859], [78.34124756, 9.05484962], [78.3409729, 9.05486107], [78.3409729, 9.0545826], [78.34041595, 9.0545826], [78.34041595, 9.05430508], [78.3401413, 9.05430984], [78.3401413, 9.05403042], [78.33957672, 9.05403042], [78.33957672, 9.05375099], [78.33930206, 9.05375099], [78.33930206, 9.05347061], [78.3390274, 9.05347347], [78.3390274, 9.05319309], [78.33847046, 9.05319309], [78.33847046, 9.05291653], [78.3381958, 9.05292034], [78.3381958, 9.05264187], [78.33763885, 9.05264187], [78.33763885, 9.05236053], [78.3373642, 9.05236053], [78.3373642, 9.05208302], [78.33680725, 9.05208302], [78.33680725, 9.05180454], [78.33651733, 9.05181026], [78.33651733, 9.05153179], [78.33625031, 9.05153179], [78.33625031, 9.05125141], [78.33569336, 9.05125141], [78.33569336, 9.05097103], [78.3354187, 9.05097103], [78.3354187, 9.05069542], [78.33486176, 9.05069542], [78.33486176, 9.05041695], [78.3345871, 9.05042171], [78.3345871, 9.05014133], [78.33429718, 9.05014133], [78.33429718, 9.04986095], [78.33374786, 9.04986095], [78.33374786, 9.04958344], [78.33347321, 9.04958344], [78.33347321, 9.04930496], [78.33319092, 9.04931164], [78.33319092, 9.0490427], [78.33264923, 9.0490427], [78.33264923, 9.04875088], [78.33235931, 9.04875088], [78.33235931, 9.04847145], [78.33180237, 9.04847336], [78.33180237, 9.04819489], [78.33152771, 9.04819489], [78.33152771, 9.04791737], [78.33125305, 9.04791927], [78.33125305, 9.04763889], [78.33069611, 9.04763889], [78.33069611, 9.04736137], [78.33041382, 9.04736137], [78.33041382, 9.0470829], [78.33013916, 9.0470829], [78.33013916, 9.04680538], [78.32958221, 9.0468092], [78.32958221, 9.04653072], [78.32930756, 9.04653072], [78.32930756, 9.0462513], [78.32875061, 9.0462513], [78.32875061, 9.04597282], [78.32847595, 9.04598045], [78.32847595, 9.04568958], [78.32819366, 9.0456953], [78.32819366, 9.04541683], [78.32763672, 9.04542065], [78.32763672, 9.04514122], [78.32736206, 9.04514122], [78.32736206, 9.04486275], [78.32681274, 9.04486275], [78.32681274, 9.04458046], [78.32653046, 9.04458332], [78.32653046, 9.04430676], [78.32624817, 9.04431057], [78.32624817, 9.04403114], [78.32569122, 9.04403114], [78.32569122, 9.0437479], [78.32541656, 9.04375076], [78.32541656, 9.04347324], [78.32485962, 9.04347324], [78.32485962, 9.04319477], [78.32458496, 9.04319477], [78.32458496, 9.0429163], [78.32402802, 9.0429163], [78.32402802, 9.04263783], [78.32375336, 9.04264069], [78.32375336, 9.04236031], [78.32319641, 9.04236031], [78.32319641, 9.04208469], [78.32291412, 9.04208469], [78.32291412, 9.04180431], [78.32235718, 9.04181099], [78.32235718, 9.04153061], [78.32208252, 9.04153061], [78.32208252, 9.04125023], [78.32152557, 9.04125023], [78.32152557, 9.04097176], [78.32125092, 9.04097176], [78.32125092, 9.04069424], [78.32069397, 9.04069424], [78.32069397, 9.04041576], [78.32041931, 9.04042053], [78.32041931, 9.04014015], [78.31986237, 9.04014015], [78.31986237, 9.03985119], [78.31958008, 9.03985977], [78.31958008, 9.03958225], [78.31903076, 9.03958225], [78.31903076, 9.03930569], [78.31874847, 9.03931141], [78.31874847, 9.03903103], [78.31819153, 9.03903103], [78.31819153, 9.03874969], [78.31791687, 9.03874969], [78.31791687, 9.03847027], [78.31735992, 9.03847218], [78.31735992, 9.0381937], [78.31708527, 9.0381937], [78.31708527, 9.03791618], [78.31652832, 9.03792095], [78.31652832, 9.03763962], [78.31624603, 9.03763962], [78.31624603, 9.03736019], [78.31569672, 9.0373621], [78.31569672, 9.03708363], [78.31541443, 9.03708363], [78.31541443, 9.03680611], [78.31485748, 9.03681087], [78.31485748, 9.03652954], [78.31458282, 9.03652954], [78.31458282, 9.03625011], [78.31430817, 9.03625011], [78.31430817, 9.03596973], [78.31402588, 9.03597164], [78.31402588, 9.03569412], [78.31375122, 9.03569412], [78.31375122, 9.03514004], [78.31346893, 9.03514004], [78.31346893, 9.03485966], [78.31319427, 9.03486156], [78.31319427, 9.03458405], [78.31291962, 9.03458405], [78.31291962, 9.03430557], [78.31263733, 9.03431034], [78.31263733, 9.03404236], [78.31236267, 9.03404236], [78.31236267, 9.03374958], [78.31208038, 9.03374958], [78.31208038, 9.03319073], [78.31180573, 9.03319359], [78.31180573, 9.03291798], [78.3115387, 9.03292179], [78.3115387, 9.03264046], [78.31124878, 9.03264046], [78.31124878, 9.03236198], [78.31069183, 9.03236198], [78.31069183, 9.03208447], [78.31041718, 9.03208447], [78.31041718, 9.03180599], [78.30986023, 9.0318079], [78.30986023, 9.03153038], [78.30930328, 9.03153038], [78.30930328, 9.03125191], [78.30874634, 9.03125191], [78.30874634, 9.03097153], [78.30847168, 9.03097153], [78.30847168, 9.03069305], [78.30791473, 9.03069305], [78.30791473, 9.03041458], [78.30735779, 9.0304203], [78.30735779, 9.03014183], [78.30680847, 9.03014183], [78.30680847, 9.0298624], [78.30652618, 9.0298624], [78.30652618, 9.02958393], [78.30596924, 9.02958393], [78.30596924, 9.02930546], [78.30541992, 9.02931023], [78.30541992, 9.02902985], [78.30486298, 9.02902985], [78.30486298, 9.02874947], [78.30458069, 9.02874947], [78.30458069, 9.02847099], [78.30403137, 9.02847099], [78.30403137, 9.02819633], [78.30374908, 9.02819633], [78.30374908, 9.02791691], [78.30319214, 9.02791691], [78.30319214, 9.02763939], [78.30291748, 9.02763939], [78.30291748, 9.02736092], [78.30263519, 9.02736092], [78.30263519, 9.0270834], [78.30208588, 9.0270834], [78.30208588, 9.02680492], [78.30179596, 9.02680969], [78.30179596, 9.02652931], [78.30152893, 9.02652931], [78.30152893, 9.02625084], [78.30124664, 9.02625084], [78.30124664, 9.02597141], [78.30069733, 9.02597332], [78.30069733, 9.02569485], [78.30041504, 9.02569485], [78.30041504, 9.02541733], [78.30014038, 9.02542019], [78.30014038, 9.02514076], [78.29957581, 9.02514076], [78.29957581, 9.02486992], [78.29930878, 9.02486992], [78.29930878, 9.02458096], [78.29902649, 9.02458286], [78.29902649, 9.02430534], [78.29846954, 9.02431202], [78.29846954, 9.02403164], [78.29818726, 9.02403164], [78.29818726, 9.02375126], [78.29846954, 9.02375126], [78.29846954, 9.02347088], [78.29819489, 9.02347088], [78.29819489, 9.02319527], [78.29763794, 9.02319527], [78.29763794, 9.02291679], [78.29736328, 9.02292156], [78.29736328, 9.02264118], [78.29680634, 9.02264118], [78.29680634, 9.0223608], [78.29652405, 9.0223608], [78.29652405, 9.02208328], [78.29597473, 9.02208328], [78.29597473, 9.02180481], [78.29569244, 9.02181244], [78.29569244, 9.0215292], [78.29514313, 9.0215292], [78.29514313, 9.02125072], [78.29486084, 9.02125072], [78.29486084, 9.0209713], [78.29430389, 9.02097321], [78.29430389, 9.02069473], [78.29402924, 9.02069473], [78.29402924, 9.02041721], [78.29347992, 9.02042103], [78.29347992, 9.02014065], [78.29319763, 9.02014065], [78.29319763, 9.01986122], [78.29264069, 9.01986122], [78.29264069, 9.01958275], [78.2923584, 9.01958275], [78.2923584, 9.01930523], [78.29180908, 9.01931095], [78.29180908, 9.01903057], [78.29125214, 9.01903057], [78.29125214, 9.01875114], [78.29096985, 9.01875114], [78.29096985, 9.01847267], [78.2904129, 9.01847267], [78.2904129, 9.01819515], [78.28986359, 9.01819515], [78.28986359, 9.01791668], [78.28930664, 9.01792145], [78.28930664, 9.01764107], [78.28901672, 9.01764107], [78.28901672, 9.01736069], [78.28847504, 9.01736069], [78.28847504, 9.01708221], [78.28791809, 9.01708221], [78.28791809, 9.0168066], [78.28819275, 9.01681137], [78.28819275, 9.01625061], [78.28848267, 9.01625061], [78.28848267, 9.01568127], [78.28819275, 9.01569366], [78.28819275, 9.01541615], [78.28791809, 9.01541615], [78.28791809, 9.01569366], [78.2876358, 9.01569366], [78.2876358, 9.01597309], [78.2868042, 9.01597309], [78.2868042, 9.01569366], [78.28652954, 9.01569366], [78.28652954, 9.01541615], [78.28624725, 9.01542091], [78.28624725, 9.01514053], [78.28569794, 9.01514053], [78.28569794, 9.01486015], [78.28541565, 9.01486015], [78.28541565, 9.01458454], [78.28514099, 9.01458454], [78.28514099, 9.01430416], [78.2848587, 9.01430416], [78.2848587, 9.01458454], [78.28430939, 9.01458454], [78.28430176, 9.01486015], [78.2831955, 9.01486015], [78.2831955, 9.01458454], [78.28263855, 9.01458454], [78.28263855, 9.01430416], [78.28180695, 9.01431084], [78.28180695, 9.01403141], [78.28125, 9.01403141], [78.28125, 9.01375008], [78.28098297, 9.01375008], [78.28098297, 9.0134697], [78.28069305, 9.0134716], [78.28069305, 9.01319408], [78.2804184, 9.01319408], [78.2804184, 9.01263809], [78.28013611, 9.01264], [78.28013611, 9.01235962], [78.27986145, 9.01236153], [78.27986145, 9.0120821], [78.27958679, 9.0120821], [78.27958679, 9.01180553], [78.27929688, 9.01181126], [78.27929688, 9.01152992], [78.27902985, 9.01152992], [78.27902985, 9.01124954], [78.27874756, 9.01124954], [78.27874756, 9.01097202], [78.2784729, 9.01097202], [78.2784729, 9.01069355], [78.27819824, 9.01069355], [78.27819061, 9.01041603], [78.27791595, 9.0104208], [78.27791595, 9.00987053], [78.2776413, 9.00987053], [78.2776413, 9.00957966], [78.27735901, 9.00958443], [78.27735901, 9.00930595], [78.27707672, 9.00931072], [78.27707672, 9.00903034], [78.27680206, 9.00903034], [78.27680206, 9.00874996], [78.2765274, 9.00874996], [78.2765274, 9.00846958], [78.27625275, 9.00847244], [78.27625275, 9.00819397], [78.27597046, 9.00819397], [78.27597046, 9.00791645], [78.2756958, 9.00792027], [78.2756958, 9.00764179], [78.27513885, 9.00764179], [78.27513885, 9.00736046], [78.2748642, 9.00736237], [78.2748642, 9.00708389], [78.27458191, 9.00708389], [78.27458191, 9.00680637], [78.27401733, 9.00681019], [78.27401733, 9.0065279], [78.27375031, 9.0065279], [78.27375031, 9.00625038], [78.27347565, 9.00625038], [78.27347565, 9.00597191], [78.2729187, 9.00597191], [78.2729187, 9.00569439], [78.27263641, 9.00569439], [78.27263641, 9.00541782], [78.27097321, 9.00541973], [78.27097321, 9.00681019], [78.27069092, 9.00680637], [78.27069092, 9.00847244], [78.27041626, 9.00846958], [78.27041626, 9.00903034], [78.2701416, 9.00902843], [78.2701416, 9.00958443], [78.26985931, 9.00957966], [78.26985931, 9.01014042], [78.26958466, 9.01013756], [78.26958466, 9.01069355], [78.26930237, 9.01069355], [78.26930237, 9.01109982], [78.26930237, 9.01124954], [78.26902771, 9.01124954], [78.26902771, 9.01181126], [78.26875305, 9.01180553], [78.26875305, 9.01236153], [78.26847076, 9.01235962], [78.26847076, 9.01292992], [78.26819611, 9.01292992], [78.26819611, 9.01431084], [78.26847076, 9.01430416], [78.26847076, 9.01569366], [78.26819611, 9.01568127], [78.26819611, 9.01625061], [78.26735687, 9.01625061], [78.26735687, 9.01653099], [78.26708221, 9.01653099], [78.26708221, 9.01681137], [78.26680756, 9.0168066], [78.26680756, 9.01736069], [78.2665329, 9.01736069], [78.2665329, 9.01764107], [78.26597595, 9.01764107], [78.26597595, 9.01792145], [78.26569366, 9.01791668], [78.26569366, 9.01819515], [78.26513672, 9.01819515], [78.26513672, 9.01847267], [78.26457977, 9.01847267], [78.26457977, 9.01875114], [78.26431274, 9.01875114], [78.26431274, 9.01903057], [78.26374817, 9.01903057], [78.26374817, 9.01931095], [78.26180267, 9.01931095], [78.26180267, 9.01903057], [78.26152802, 9.01903057], [78.26152802, 9.01875114], [78.26097107, 9.01875114], [78.26097107, 9.01791668], [78.26125336, 9.01792145], [78.26125336, 9.01708031], [78.26569366, 9.01708221], [78.26569366, 9.0168066], [78.26597595, 9.01681137], [78.26597595, 9.01653099], [78.26624298, 9.01653099], [78.26624298, 9.01625061], [78.2665329, 9.01625061], [78.2665329, 9.01542091], [78.26680756, 9.01542091], [78.26680756, 9.01403141], [78.26708221, 9.01403141], [78.26708221, 9.01264], [78.26735687, 9.01264], [78.26735687, 9.01214123], [78.2673645, 9.01152802], [78.26763916, 9.01152992], [78.26763916, 9.0104208], [78.26790619, 9.0104208], [78.26790619, 9.00846958], [78.26763916, 9.00847244], [78.26763916, 9.00680637], [78.26680756, 9.00681019], [78.26680756, 9.0065279], [78.2665329, 9.0065279], [78.2665329, 9.00625038], [78.26624298, 9.00625038], [78.26624298, 9.00458145], [78.26652527, 9.00458431], [78.26652527, 9.00402832], [78.26680756, 9.00403023], [78.26680756, 9.00347137], [78.26708221, 9.00347137], [78.26708221, 9.00319576], [78.26680756, 9.00319576], [78.26680756, 9.00291538], [78.26624298, 9.00292015], [78.26624298, 9.00264168], [78.26597595, 9.00264168], [78.26597595, 9.00235939], [78.26569366, 9.00236225], [78.26569366, 9.00208282], [78.26513672, 9.00208282], [78.26513672, 9.00180531], [78.26486206, 9.00181007], [78.26486206, 9.00152969], [78.26457977, 9.00152969], [78.26457977, 9.00124931], [78.26403046, 9.00124931], [78.26403046, 9.00097084], [78.26374817, 9.00097084], [78.26374817, 9.00069332], [78.26347351, 9.00069332], [78.26347351, 9.00041676], [78.26264191, 9.00041962], [78.26264191, 9.00013924], [78.26207733, 9.00013924], [78.26207733, 8.99986076], [78.26125336, 8.99986076], [78.26125336, 8.99958134], [78.26097107, 8.99958324], [78.26097107, 8.99930477], [78.26069641, 8.99930954], [78.26069641, 8.99903202], [78.26040649, 8.99903202], [78.26040649, 8.99875069], [78.25985718, 8.99875069], [78.25985718, 8.99847126], [78.25958252, 8.99847317], [78.25958252, 8.99819469], [78.25930786, 8.99819469], [78.25930786, 8.99791718], [78.2590332, 8.99793053], [78.2590332, 8.99764061], [78.25846863, 8.99764061], [78.25846863, 8.99736118], [78.25819397, 8.99736118], [78.25819397, 8.99708271], [78.25763702, 8.99708271], [78.25763702, 8.99680519], [78.25737, 8.99681187], [78.25737, 8.99653053], [78.25681305, 8.99653053], [78.25681305, 8.99625111], [78.25653076, 8.99625111], [78.25653076, 8.99597263], [78.25597382, 8.99597263], [78.25597382, 8.99569511], [78.25541687, 8.99569511], [78.25541687, 8.99541664], [78.25514221, 8.99542236], [78.25514221, 8.99514103], [78.2545929, 8.99514103], [78.2545929, 8.99486065], [78.25430298, 8.99486065], [78.25430298, 8.99458313], [78.25375366, 8.99458313], [78.25375366, 8.99430466], [78.25319672, 8.99430943], [78.25319672, 8.99403095], [78.2529068, 8.99403095], [78.2529068, 8.99375057], [78.25235748, 8.99375057], [78.25235748, 8.99347115], [78.25208282, 8.99347305], [78.25208282, 8.99319458], [78.25152588, 8.99319458], [78.25152588, 8.99291706], [78.25123596, 8.99292088], [78.25123596, 8.99264145], [78.25068665, 8.99264145], [78.25068665, 8.99236107], [78.25013733, 8.99236107], [78.25013733, 8.9920826], [78.24986267, 8.9920826], [78.24986267, 8.99180698], [78.24930573, 8.99180698], [78.24930573, 8.9915266], [78.24903107, 8.99153137], [78.24903107, 8.99125099], [78.24846649, 8.99125099], [78.24846649, 8.99096966], [78.24810791, 8.99097347], [78.24791718, 8.99097347], [78.24791718, 8.990695], [78.24764252, 8.990695], [78.24764252, 8.99041653], [78.2470932, 8.9904213], [78.2470932, 8.99014091], [78.24652863, 8.99014091], [78.24652863, 8.98985958], [78.24624634, 8.98985958], [78.24624634, 8.98958206], [78.24569702, 8.98958206], [78.24569702, 8.98930359], [78.24514008, 8.98931122], [78.24514008, 8.98903084], [78.24485779, 8.98903084], [78.24485779, 8.98874092], [78.24430847, 8.98875141], [78.24430847, 8.98847198], [78.24375153, 8.98847198], [78.24375153, 8.98819447], [78.24346924, 8.98819447], [78.24346924, 8.98791599], [78.24291992, 8.98791885], [78.24291992, 8.98764133], [78.24263763, 8.98764133], [78.24263763, 8.98736], [78.24208069, 8.98736], [78.24208069, 8.98708439], [78.24153137, 8.98708439], [78.24153137, 8.98680592], [78.24124908, 8.98681068], [78.24124908, 8.98653126], [78.24069214, 8.98653126], [78.24069214, 8.98624992], [78.24014282, 8.98624992], [78.24014282, 8.98596954], [78.23986053, 8.9859724], [78.23986053, 8.98569393], [78.23929596, 8.98570061], [78.23929596, 8.98542118], [78.23874664, 8.98542118], [78.23874664, 8.98513985], [78.23847198, 8.98513985], [78.23847198, 8.98486042], [78.23791504, 8.98486233], [78.23791504, 8.98458195], [78.23735809, 8.98458195], [78.23735809, 8.98430634], [78.23707581, 8.9843111], [78.23707581, 8.98402977], [78.23652649, 8.98402977], [78.23652649, 8.98375034], [78.23625183, 8.98375034], [78.23625183, 8.98347187], [78.23596954, 8.98347187], [78.23596954, 8.98319435], [78.23542023, 8.98319435], [78.23542023, 8.98291588], [78.23513794, 8.98292065], [78.23513794, 8.98264027], [78.23486328, 8.98264027], [78.23486328, 8.98235989], [78.23458099, 8.98235989], [78.23458099, 8.98208427], [78.23402405, 8.98208427], [78.23402405, 8.9818058], [78.23374939, 8.98181057], [78.23374939, 8.98153019], [78.2334671, 8.98153019], [78.2334671, 8.98124981], [78.23319244, 8.98124981], [78.23319244, 8.98097229], [78.23291779, 8.98097229], [78.23291779, 8.98069382], [78.23236084, 8.98069382], [78.23236084, 8.9804163], [78.23208618, 8.98042011], [78.23208618, 8.98013973], [78.23179626, 8.98013973], [78.23179626, 8.97986031], [78.23152924, 8.97986221], [78.23152924, 8.97958374], [78.23097229, 8.97958374], [78.23097229, 8.97930622], [78.23069763, 8.97931004], [78.23069763, 8.97902966], [78.23042297, 8.97902966], [78.23042297, 8.97875023], [78.23013306, 8.97875023], [78.23013306, 8.97846889], [78.2298584, 8.97847176], [78.2298584, 8.97819424], [78.22930908, 8.97819424], [78.22930908, 8.97791767], [78.22902679, 8.97791958], [78.22902679, 8.97764015], [78.22875214, 8.97764015], [78.22875214, 8.97736168], [78.22846985, 8.97736168], [78.22846985, 8.97708416], [78.2279129, 8.97708416], [78.2279129, 8.97680569], [78.22763824, 8.97680569], [78.22763824, 8.97652817], [78.22735596, 8.97653198], [78.22735596, 8.9762516], [78.22706604, 8.9762516], [78.22706604, 8.97596931], [78.22680664, 8.97597122], [78.22680664, 8.97569561], [78.22624969, 8.97569561], [78.22624969, 8.97541809], [78.22598267, 8.97542], [78.22598267, 8.97513962], [78.22569275, 8.97513962], [78.22569275, 8.97485924], [78.22541809, 8.97486115], [78.22541809, 8.97458267], [78.2251358, 8.97458267], [78.2251358, 8.97430515], [78.22458649, 8.97430992], [78.22458649, 8.97402954], [78.22429657, 8.97402954], [78.22429657, 8.9737606], [78.22402954, 8.9737606], [78.22402954, 8.97347069], [78.22374725, 8.9734726], [78.22374725, 8.97319317], [78.2234726, 8.97319317], [78.2234726, 8.9729166], [78.22292328, 8.97292042], [78.22292328, 8.97264194], [78.22264099, 8.97264194], [78.22264099, 8.97236061], [78.2223587, 8.97236061], [78.2223587, 8.9721899], [78.2223587, 8.97208309], [78.22208405, 8.97208309], [78.22208405, 8.97180462], [78.22180176, 8.97181034], [78.22180176, 8.97153187], [78.22126007, 8.97153187], [78.22126007, 8.97125053], [78.22097015, 8.97125053], [78.22097015, 8.97097111], [78.2206955, 8.97097111], [78.2206955, 8.97069454], [78.22041321, 8.97070026], [78.22041321, 8.97042179], [78.22013855, 8.97042179], [78.22013855, 8.97014141], [78.21985626, 8.97014141], [78.21985626, 8.96986103], [78.2195816, 8.96986103], [78.2195816, 8.96958256], [78.21930695, 8.96958256], [78.21930695, 8.96930504], [78.21901703, 8.96931171], [78.21901703, 8.96903133], [78.21875, 8.96903133], [78.21875, 8.96875095], [78.21848297, 8.96875095], [78.21848297, 8.96847057], [78.21819305, 8.96847343], [78.21819305, 8.96819496], [78.2179184, 8.96819496], [78.2179184, 8.96791744], [78.21763611, 8.96791935], [78.21763611, 8.96763039], [78.21736145, 8.96763897], [78.21736145, 8.96736145], [78.21708679, 8.96736145], [78.21708679, 8.96708298], [78.2168045, 8.96708298], [78.2168045, 8.96680546], [78.21652985, 8.96680927], [78.21652985, 8.96652889], [78.21624756, 8.96652889], [78.21624756, 8.96625137], [78.2159729, 8.96625137], [78.2159729, 8.9659729], [78.21569824, 8.9659729], [78.21569061, 8.96569538], [78.21541595, 8.96569538], [78.21541595, 8.96541691], [78.21512604, 8.96542072], [78.21512604, 8.9651413], [78.21485901, 8.9651413], [78.21485901, 8.96486092], [78.21457672, 8.96486092], [78.21457672, 8.964571], [78.21430206, 8.9645834], [78.21430206, 8.96430683], [78.2140274, 8.96431065], [78.2140274, 8.96403122], [78.21375275, 8.96403122], [78.21375275, 8.96375084], [78.21347046, 8.96375084], [78.21347046, 8.96347046], [78.2131958, 8.96347332], [78.2131958, 8.96319485], [78.21291351, 8.96319485], [78.21291351, 8.96291733], [78.21263885, 8.96292114], [78.21263885, 8.9626379], [78.21235657, 8.9626379], [78.21235657, 8.96236038], [78.21208191, 8.96236038], [78.21208191, 8.96208477], [78.21180725, 8.96208191], [78.21180725, 8.96180439], [78.21151733, 8.96181965], [78.21151733, 8.96153069], [78.21125031, 8.96153069], [78.21125031, 8.96125031], [78.21097565, 8.96125031], [78.21097565, 8.96097183], [78.21069336, 8.96097183], [78.21069336, 8.96069431], [78.2104187, 8.96069431], [78.2104187, 8.96041584], [78.21013641, 8.96042061], [78.21013641, 8.96014118], [78.20986176, 8.96014118], [78.20986176, 8.95985985], [78.2095871, 8.95985985], [78.2095871, 8.95958233], [78.20930481, 8.95958233], [78.20930481, 8.95930576], [78.20903015, 8.95931053], [78.20903015, 8.95875931], [78.20874786, 8.95875931], [78.20874786, 8.95847034], [78.20847321, 8.95847225], [78.20847321, 8.95819378], [78.20819092, 8.95819378], [78.20819092, 8.95763779], [78.20791626, 8.95763969], [78.20791626, 8.95736027], [78.2076416, 8.95736217], [78.2076416, 8.9570837], [78.20735931, 8.9570837], [78.20735931, 8.95652771], [78.20707703, 8.95652962], [78.20707703, 8.95625019], [78.20680237, 8.95625019], [78.20680237, 8.9556942], [78.20652771, 8.9556942], [78.20652771, 8.95514011], [78.20819092, 8.95514011], [78.20819092, 8.95485973], [78.20791626, 8.95485973], [78.20791626, 8.95458412], [78.2076416, 8.95458412], [78.2076416, 8.95430565], [78.20735931, 8.95431137], [78.20735931, 8.95403004], [78.20707703, 8.95403004], [78.20707703, 8.95374966], [78.20680237, 8.95374966], [78.20680237, 8.95347023], [78.20652771, 8.95347214], [78.20652771, 8.95291805], [78.20625305, 8.95291996], [78.20625305, 8.952631], [78.20597076, 8.95263767], [78.20597076, 8.95236206], [78.20569611, 8.95236206], [78.20569611, 8.95180607], [78.20540619, 8.95181274], [78.20540619, 8.95153046], [78.20513916, 8.95153046], [78.20513916, 8.95125198], [78.20485687, 8.95125198], [78.20485687, 8.95069122], [78.20458221, 8.95069408], [78.20458221, 8.95041466], [78.20430756, 8.95042038], [78.20430756, 8.95014191], [78.2040329, 8.95014191], [78.2040329, 8.94958973], [78.20375061, 8.94958973], [78.20375061, 8.9493103], [78.20347595, 8.9493103], [78.20347595, 8.94902992], [78.20318604, 8.94902992], [78.20318604, 8.94874859], [78.20263672, 8.94874859], [78.20263672, 8.94847107], [78.20236206, 8.94847107], [78.20236206, 8.94819641], [78.20207977, 8.94819641], [78.20207977, 8.94791794], [78.20181274, 8.94791985], [78.20181274, 8.94763947], [78.20153046, 8.94763947], [78.20153046, 8.94736099], [78.20096588, 8.94736099], [78.20096588, 8.94708061], [78.20069122, 8.94708347], [78.20069122, 8.946805], [78.20041656, 8.94682121], [78.20041656, 8.94653034], [78.20012665, 8.94653034], [78.20013428, 8.94636059], [78.20014191, 8.9459734], [78.19985962, 8.9459734], [78.19985962, 8.94569492], [78.19958496, 8.94569302], [78.19958496, 8.9454174], [78.19930267, 8.94542027], [78.19930267, 8.94486141], [78.19902802, 8.94486141], [78.19902802, 8.94458294], [78.19875336, 8.94458294], [78.19875336, 8.94402695], [78.19847107, 8.94403172], [78.19847107, 8.94375134], [78.19819641, 8.94375134], [78.19819641, 8.94319534], [78.19791412, 8.94319534], [78.19791412, 8.94291687], [78.19763947, 8.94292164], [78.19763947, 8.94264126], [78.19735718, 8.94264126], [78.19735718, 8.94208145], [78.19708252, 8.94208336], [78.19708252, 8.94180489], [78.19680786, 8.94181156], [78.19680786, 8.94124889], [78.19652557, 8.94124889], [78.19652557, 8.94097328], [78.19625092, 8.94097328], [78.19625092, 8.94069481], [78.19596863, 8.94069481], [78.19596863, 8.94013882], [78.19568634, 8.94014072], [78.19568634, 8.9398613], [78.19541931, 8.9398613], [78.19541931, 8.93930531], [78.19513702, 8.93931198], [78.19513702, 8.93875122], [78.19486237, 8.93875122], [78.19486237, 8.93847275], [78.19458008, 8.93847275], [78.19458008, 8.93791676], [78.19431305, 8.93792057], [78.19431305, 8.9373579], [78.19403076, 8.93736076], [78.19403076, 8.93680668], [78.19374847, 8.93681145], [78.19374847, 8.93653107], [78.19346619, 8.93653107], [78.19346619, 8.93597031], [78.19319153, 8.93597317], [78.19319153, 8.93541622], [78.19291687, 8.93542099], [78.19291687, 8.93514061], [78.19264221, 8.93514061], [78.19264221, 8.93459129], [78.19235992, 8.93459129], [78.19235992, 8.93403053], [78.1920929, 8.93403053], [78.1920929, 8.93346977], [78.19180298, 8.93347168], [78.19180298, 8.93319416], [78.19152832, 8.93319416], [78.19152832, 8.93263817], [78.19124603, 8.93264008], [78.19124603, 8.93208027], [78.19097137, 8.93208218], [78.19097137, 8.93180561], [78.19069672, 8.93181133], [78.19069672, 8.93124962], [78.1904068, 8.93124962], [78.1904068, 8.93069172], [78.19013977, 8.93069363], [78.19013977, 8.93013763], [78.18985748, 8.93013954], [78.18985748, 8.92986012], [78.18958282, 8.92986012], [78.18958282, 8.92930603], [78.18930817, 8.9293108], [78.18930817, 8.92875004], [78.18902588, 8.92875004], [78.18902588, 8.92818928], [78.18875122, 8.92819405], [78.18875122, 8.92763996], [78.18846893, 8.92763996], [78.18846893, 8.9270792], [78.18819427, 8.92708397], [78.18819427, 8.92652798], [78.18791962, 8.92653179], [78.18791962, 8.92597198], [78.18763733, 8.92597198], [78.18763733, 8.9254179], [78.18736267, 8.9254179], [78.18736267, 8.92486191], [78.18708038, 8.92486191], [78.18708038, 8.92430592], [78.18681335, 8.92430973], [78.18681335, 8.92375183], [78.18653107, 8.92375183], [78.18653107, 8.92319107], [78.18624878, 8.92319584], [78.18624878, 8.92263985], [78.18596649, 8.92265129], [78.18596649, 8.92208099], [78.18569183, 8.92208385], [78.18569183, 8.92124939], [78.18541718, 8.92124939], [78.18541718, 8.9206934], [78.18514252, 8.9206934], [78.18514252, 8.92013931], [78.18486023, 8.92013931], [78.18486023, 8.91930962], [78.1845932, 8.91930962], [78.1845932, 8.91875076], [78.18430328, 8.91875076], [78.18430328, 8.91792202], [78.18402863, 8.91792202], [78.18402863, 8.91708088], [78.18374634, 8.91708279], [78.18374634, 8.91625118], [78.18347168, 8.91625118], [78.18347168, 8.91541672], [78.18319702, 8.91542244], [78.18319702, 8.91486073], [78.1829071, 8.91486073], [78.1829071, 8.91403103], [78.18264008, 8.91403103], [78.18264008, 8.91318989], [78.18235779, 8.91319466], [78.18235779, 8.91236115], [78.18208313, 8.91236115], [78.18208313, 8.91152668], [78.18180847, 8.91153145], [78.18180847, 8.91069031], [78.18152618, 8.91069508], [78.18152618, 8.91013908], [78.18125153, 8.91014099], [78.18125153, 8.90931129], [78.18096924, 8.90931129], [78.18096924, 8.90818977], [78.18069458, 8.90819359], [78.18069458, 8.90708542], [78.18041992, 8.90708542], [78.18041992, 8.90597153], [78.18013763, 8.90597153], [78.18013763, 8.9048624], [78.17986298, 8.9048624], [78.17986298, 8.89902782], [78.18013763, 8.89902973], [78.18013763, 8.89791965], [78.18041992, 8.89791965], [78.18041992, 8.89680958], [78.18068695, 8.89680958], [78.18068695, 8.89542007], [78.18041992, 8.89542007], [78.18041992, 8.89431], [78.18013763, 8.89431], [78.18013763, 8.89319134], [78.17986298, 8.89319324], [78.17986298, 8.89263916], [78.17819214, 8.89264202], [78.17819214, 8.8923502], [78.17763519, 8.89236069], [78.17763519, 8.89208317], [78.17708588, 8.89208317], [78.17708588, 8.8918047], [78.17652893, 8.89181042], [78.17652893, 8.89153194], [78.17595673, 8.89153194], [78.17595673, 8.89125061], [78.17569733, 8.89125061], [78.17569733, 8.89097118], [78.17541504, 8.89097118], [78.17541504, 8.89069462], [78.17514038, 8.89069462], [78.17514038, 8.8904171], [78.17485809, 8.89042187], [78.17485809, 8.89014053], [78.17457581, 8.89014053], [78.17457581, 8.88986111], [78.17430878, 8.88986111], [78.17430878, 8.88958263], [78.17402649, 8.88958263], [78.17402649, 8.88930511], [78.17346954, 8.88931179], [78.17346954, 8.88903236], [78.17318726, 8.88903236], [78.17318726, 8.88875103], [78.17292023, 8.88875103], [78.17292023, 8.88847065], [78.17263794, 8.88847256], [78.17263794, 8.88819504], [78.17236328, 8.88819504], [78.17236328, 8.88791656], [78.17208099, 8.88791943], [78.17208099, 8.88764095], [78.17180634, 8.88764095], [78.17180634, 8.88736057], [78.17152405, 8.88736057], [78.17152405, 8.88708305], [78.17124939, 8.88708305], [78.17124939, 8.88652897], [78.1709671, 8.88654041], [78.1709671, 8.88597107], [78.17069244, 8.88597298], [78.17069244, 8.88541698], [78.17041779, 8.88541889], [78.17041779, 8.88486099], [78.1701355, 8.88486099], [78.1701355, 8.88430691], [78.16986084, 8.88431072], [78.16986084, 8.88375092], [78.16958618, 8.88375092], [78.16958618, 8.88320065], [78.16929626, 8.88319016], [78.16930389, 8.88263893], [78.16902924, 8.88264084], [78.16902924, 8.88208008], [78.16874695, 8.88208199], [78.16874695, 8.88097191], [78.16847229, 8.88097191], [78.16847229, 8.87902832], [78.16819763, 8.87903118], [78.16819763, 8.87708187], [78.16791534, 8.87708378], [78.16791534, 8.8754158], [78.16764069, 8.87542057], [78.16764069, 8.87347031], [78.1673584, 8.87347221], [78.1673584, 8.87152767], [78.16764069, 8.87154102], [78.16764069, 8.86931038], [78.16792297, 8.86931038], [78.16792297, 8.86791992], [78.16819763, 8.86791992], [78.16819763, 8.86708069], [78.16847229, 8.8670826], [78.16847229, 8.86624908], [78.16874695, 8.86625195], [78.16874695, 8.8654108], [78.16847229, 8.86541653], [78.16847229, 8.85986137], [78.16819763, 8.85986137], [78.16819763, 8.8595829], [78.16791534, 8.8595829], [78.16791534, 8.85930538], [78.16764069, 8.8593092], [78.16764069, 8.85903072], [78.1673584, 8.85903072], [78.1673584, 8.85847092], [78.16708374, 8.85847282], [78.16708374, 8.8581953], [78.16680908, 8.8581953], [78.16680908, 8.85791683], [78.16625214, 8.85792065], [78.16625214, 8.85708046], [78.16596985, 8.85708332], [78.16596985, 8.85597324], [78.16625214, 8.85597324], [78.16625214, 8.85486031], [78.16652679, 8.85486031], [78.16652679, 8.84958363], [78.16680908, 8.84958363], [78.16680908, 8.84736156], [78.16707611, 8.8473711], [78.16707611, 8.84403038], [78.16680908, 8.84403038], [78.16680908, 8.84319115], [78.16652679, 8.84319401], [78.16652679, 8.84263992], [78.16625214, 8.84264183], [78.16625214, 8.84235859], [78.16596985, 8.8423624], [78.16596985, 8.84180641], [78.16570282, 8.84181023], [78.16570282, 8.84152985], [78.1654129, 8.84152985], [78.1654129, 8.84123993], [78.16513824, 8.84124947], [78.16513824, 8.84069347], [78.16486359, 8.84069347], [78.16486359, 8.83986092], [78.1645813, 8.83986092], [78.1645813, 8.83874893], [78.16430664, 8.83875084], [78.16430664, 8.83792019], [78.1645813, 8.83792019], [78.1645813, 8.83708096], [78.16486359, 8.83708286], [78.16486359, 8.83569527], [78.1645813, 8.83569527], [78.1645813, 8.83443928], [78.1645813, 8.83430481], [78.16485596, 8.83430862], [78.16485596, 8.83318996], [78.16513824, 8.83319473], [78.16513824, 8.83208275], [78.1654129, 8.83208275], [78.1654129, 8.83097267], [78.16569519, 8.83097267], [78.16569519, 8.83041668], [78.16596985, 8.83042145], [78.16596985, 8.82958031], [78.16625214, 8.82958317], [78.16625214, 8.82902908], [78.16652679, 8.82903099], [78.16652679, 8.82847023], [78.16791534, 8.82847309], [78.16791534, 8.82763767], [78.16819763, 8.82764053], [78.16819763, 8.82681084], [78.16792297, 8.82681084], [78.16792297, 8.82653141], [78.16764069, 8.82653141], [78.16764069, 8.82625961], [78.1673584, 8.82625961], [78.1673584, 8.8259697], [78.16708374, 8.8259716], [78.16708374, 8.82541561], [78.16680908, 8.82542133], [78.16680908, 8.82514], [78.16652679, 8.82514], [78.16652679, 8.82485962], [78.16625214, 8.82486153], [78.16625214, 8.8245821], [78.16596985, 8.8245821], [78.16596985, 8.82402802], [78.16570282, 8.82403088], [78.16570282, 8.82347202], [78.1654129, 8.82347202], [78.1654129, 8.82291603], [78.16513824, 8.8229208], [78.16513824, 8.82236004], [78.16485596, 8.82236004], [78.16485596, 8.82181072], [78.1645813, 8.82181072], [78.1645813, 8.82124996], [78.16430664, 8.82124996], [78.16430664, 8.82070065], [78.16401672, 8.8206892], [78.16402435, 8.82013798], [78.16374969, 8.82013798], [78.16374969, 8.81958389], [78.16402435, 8.81958389], [78.16402435, 8.8176403], [78.16374969, 8.8176403], [78.16374969, 8.81680965], [78.16348267, 8.81680965], [78.16348267, 8.81374931], [78.16319275, 8.81374931], [78.16319275, 8.81291676], [78.16348267, 8.81291962], [78.16348267, 8.81236076], [78.16374969, 8.81236076], [78.16374969, 8.81208134], [78.16402435, 8.81208324], [78.16402435, 8.81180477], [78.1645813, 8.81180954], [78.1645813, 8.81153202], [78.16485596, 8.81153202], [78.16485596, 8.81126118], [78.1654129, 8.81126118], [78.1654129, 8.81069088], [78.16513824, 8.81069469], [78.16513824, 8.80986118], [78.16486359, 8.80986118], [78.16486359, 8.80930519], [78.16430664, 8.80931187], [78.16430664, 8.80903244], [78.16401672, 8.80903244], [78.16401672, 8.80875111], [78.16347504, 8.80875111], [78.16347504, 8.80847263], [78.16236115, 8.80847263], [78.16236115, 8.80791664], [78.16208649, 8.80791855], [78.16208649, 8.80736065], [78.1618042, 8.80736065], [78.1618042, 8.80708313], [78.16208649, 8.80708313], [78.16208649, 8.80624866], [78.16236115, 8.80625057], [78.16236115, 8.80597115], [78.16291809, 8.80597305], [78.16291809, 8.80541706], [78.16319275, 8.80542088], [78.16319275, 8.80430889], [78.16348267, 8.80430889], [78.16348267, 8.80319023], [78.16374969, 8.803195], [78.16374969, 8.80236053], [78.16319275, 8.80236053], [78.16319275, 8.80264091], [78.1626358, 8.80264091], [78.1626358, 8.8029213], [78.1618042, 8.80291653], [78.1618042, 8.803195], [78.16124725, 8.803195], [78.16124725, 8.80347347], [78.16069794, 8.80346966], [78.16069794, 8.80375099], [78.15930176, 8.80375099], [78.15930176, 8.80319023], [78.15958405, 8.803195], [78.15958405, 8.80263901], [78.1598587, 8.80264091], [78.1598587, 8.80236053], [78.16041565, 8.80236053], [78.16041565, 8.80125141], [78.15930176, 8.80125141], [78.15930176, 8.80013847], [78.1590271, 8.80014133], [78.1590271, 8.79819202], [78.15875244, 8.79819393], [78.15875244, 8.79680634], [78.16069794, 8.7968111], [78.16069794, 8.79568958], [78.1609726, 8.79569435], [78.1609726, 8.79402828], [78.16124725, 8.79403019], [78.16124725, 8.79347038], [78.16208649, 8.79347229], [78.16208649, 8.79319382], [78.16291809, 8.79319382], [78.16291809, 8.7929163], [78.16236115, 8.79292011], [78.16236115, 8.79236031], [78.16208649, 8.79236221], [78.16208649, 8.79208374], [78.16152954, 8.79208374], [78.16152954, 8.79180622], [78.16098022, 8.79181004], [78.16098022, 8.79125023], [78.16124725, 8.79125023], [78.16124725, 8.79069424], [78.16152954, 8.79069424], [78.16152954, 8.78986168], [78.1618042, 8.78986168], [78.16179657, 8.78931046], [78.16208649, 8.78931046], [78.16208649, 8.78846931], [78.16236115, 8.78847122], [78.16236115, 8.78791809], [78.1626358, 8.78792], [78.1626358, 8.78735924], [78.16291809, 8.7873621], [78.16291809, 8.78652668], [78.16319275, 8.78652954], [78.16319275, 8.78597069], [78.16347504, 8.78597355], [78.16347504, 8.7854166], [78.16374969, 8.78542042], [78.16374969, 8.78319073], [78.16347504, 8.78319454], [78.16347504, 8.78263855], [78.16319275, 8.78264141], [78.16319275, 8.78236103], [78.16291809, 8.78236103], [78.16291809, 8.78514194], [78.1626358, 8.78514194], [78.1626358, 8.78542042], [78.16236115, 8.7854166], [78.16236115, 8.78569317], [78.16208649, 8.78569317], [78.16208649, 8.78597355], [78.16179657, 8.78597069], [78.16179657, 8.78652954], [78.16152954, 8.78652954], [78.16152954, 8.78680992], [78.16124725, 8.78680992], [78.16124725, 8.7870903], [78.16042328, 8.7870903], [78.16042328, 8.78652954], [78.16014099, 8.78652954], [78.16014099, 8.78597069], [78.1598587, 8.78597355], [78.1598587, 8.78513908], [78.15957642, 8.78514194], [78.15957642, 8.78403187], [78.15930176, 8.78403187], [78.15930176, 8.78319073], [78.15958405, 8.78319454], [78.15958405, 8.78263855], [78.1598587, 8.78264141], [78.1598587, 8.78208065], [78.16014099, 8.78208256], [78.16014099, 8.78097343], [78.16041565, 8.78097343], [78.16041565, 8.77958298], [78.16069794, 8.77958298], [78.16069794, 8.7784729], [78.1609726, 8.7784729], [78.1609726, 8.77736092], [78.16124725, 8.77736092], [78.16124725, 8.77680683], [78.16152954, 8.77681065], [78.16152954, 8.77625084], [78.16179657, 8.77625084], [78.16179657, 8.77597046], [78.16208649, 8.77597332], [78.16208649, 8.77541733], [78.16236115, 8.77542114], [78.16236115, 8.7751503], [78.16152954, 8.7751503], [78.16152954, 8.77542114], [78.16124725, 8.77541733], [78.16124725, 8.77597332], [78.16098022, 8.77597046], [78.16098022, 8.77653122], [78.16069794, 8.7765274], [78.16069794, 8.7770834], [78.16014099, 8.7770834], [78.16014099, 8.77736092], [78.1590271, 8.77736092], [78.1590271, 8.7770834], [78.15875244, 8.7770834], [78.15875244, 8.77680683], [78.15847015, 8.77681065], [78.15847015, 8.77625084], [78.15821075, 8.77625084], [78.15821075, 8.77597046], [78.15791321, 8.77597332], [78.15791321, 8.77541733], [78.15763855, 8.77542114], [78.15763855, 8.77431107], [78.15735626, 8.77431107], [78.15735626, 8.77346992], [78.1570816, 8.77347183], [78.1570816, 8.77235985], [78.15736389, 8.77235985], [78.15736389, 8.77152824], [78.15763855, 8.77153111], [78.15763855, 8.77097034], [78.15791321, 8.77097225], [78.15791321, 8.77069378], [78.1581955, 8.77069378], [78.1581955, 8.77041626], [78.15847015, 8.77042103], [78.15847015, 8.77013969], [78.15875244, 8.77013969], [78.15875244, 8.76986027], [78.16042328, 8.76986027], [78.16042328, 8.77013969], [78.16069794, 8.77013969], [78.16069794, 8.77042103], [78.16041565, 8.77041626], [78.16041565, 8.77069378], [78.16069794, 8.77069378], [78.16069794, 8.77097225], [78.16098022, 8.77097034], [78.16098022, 8.77153111], [78.16124725, 8.77153111], [78.16124725, 8.77181053], [78.16152954, 8.77180576], [78.16152954, 8.77235985], [78.16179657, 8.77235985], [78.16179657, 8.77264118], [78.1626358, 8.77263832], [78.1626358, 8.77347183], [78.16291809, 8.77347183], [78.16291809, 8.77375126], [78.16374969, 8.77375126], [78.16374969, 8.77347183], [78.16402435, 8.77347183], [78.16402435, 8.77291584], [78.16485596, 8.77292061], [78.16485596, 8.77264118], [78.16652679, 8.77264118], [78.16652679, 8.77235985], [78.16680908, 8.77235985], [78.16680908, 8.77208233], [78.16707611, 8.77209091], [78.16707611, 8.77181053], [78.1673584, 8.77181053], [78.1673584, 8.77153111], [78.16792297, 8.77153111], [78.16792297, 8.77124977], [78.16819763, 8.77124977], [78.16819763, 8.77097034], [78.16847229, 8.77097225], [78.16847229, 8.77069378], [78.16874695, 8.77069378], [78.16874695, 8.77041626], [78.16929626, 8.77042103], [78.16929626, 8.77013969], [78.16986084, 8.77013969], [78.16986084, 8.76986027], [78.17069244, 8.76986217], [78.17069244, 8.7695837], [78.17124939, 8.7695837], [78.17124939, 8.76930618], [78.17180634, 8.76931095], [78.17180634, 8.76902103], [78.17263794, 8.76902771], [78.17263794, 8.76875019], [78.17319489, 8.76875019], [78.17318726, 8.76847172], [78.17402649, 8.76847172], [78.17402649, 8.7681942], [78.17485809, 8.7681942], [78.17485809, 8.76791573], [78.17563629, 8.76791573], [78.17624664, 8.76792145], [78.17624664, 8.76764011], [78.17791748, 8.76764011], [78.17791748, 8.76735973], [78.18013763, 8.76735973], [78.18013763, 8.76764011], [78.18041992, 8.76764011], [78.18041992, 8.76792145], [78.18068695, 8.76792145], [78.18068695, 8.77153111], [78.18096924, 8.77153111], [78.18096924, 8.77209091], [78.18125153, 8.77208233], [78.18125153, 8.77319431], [78.18180847, 8.77319431], [78.18180847, 8.77347183], [78.18208313, 8.77347183], [78.18208313, 8.77375126], [78.18264008, 8.77375126], [78.18264008, 8.77403069], [78.18319702, 8.77403069], [78.18319702, 8.77431107], [78.18347168, 8.77430439], [78.18347168, 8.77458191], [78.18402863, 8.77458191], [78.18402863, 8.77486038], [78.1845932, 8.77486038], [78.1845932, 8.7751503], [78.18486023, 8.7751503], [78.18486023, 8.77542114], [78.18541718, 8.77541733], [78.18541718, 8.77569485], [78.18569183, 8.77569485], [78.18569183, 8.77597332], [78.18624878, 8.77597046], [78.18624878, 8.77625084], [78.18653107, 8.77625084], [78.18653107, 8.77653122], [78.18708038, 8.77653122], [78.18708038, 8.77597046], [78.18680573, 8.77597332], [78.18680573, 8.77569485], [78.18624878, 8.77569485], [78.18624878, 8.77541733], [78.18569183, 8.77542114], [78.18569183, 8.7751503], [78.18541718, 8.7751503], [78.18541718, 8.77486038], [78.18486023, 8.77486038], [78.18486023, 8.77458477], [78.18430328, 8.77458191], [78.18430328, 8.77430439], [78.18374634, 8.77431107], [78.18374634, 8.77403069], [78.18347168, 8.77403069], [78.18347168, 8.77375126], [78.18319702, 8.77375126], [78.18319702, 8.77347183], [78.18291473, 8.77347183], [78.18291473, 8.77319431], [78.18264008, 8.77319431], [78.18264008, 8.77291584], [78.18235779, 8.77292061], [78.18235779, 8.77264118], [78.18209076, 8.77264118], [78.18209076, 8.77235985], [78.18180847, 8.77235985], [78.18180847, 8.77208233], [78.18152618, 8.77209091], [78.18152618, 8.77153111], [78.18180847, 8.77153111], [78.18180847, 8.77097034], [78.18208313, 8.77097225], [78.18208313, 8.77069378], [78.18270111, 8.77069378], [78.18347168, 8.77069378], [78.18347168, 8.77097225], [78.18402863, 8.77097225], [78.18402863, 8.77013779], [78.18430328, 8.77013969], [78.18430328, 8.76818943], [78.18458557, 8.7681942], [78.18458557, 8.76791573], [78.18624878, 8.76791573], [78.18624878, 8.7681942], [78.18653107, 8.7681942], [78.18653107, 8.76847172], [78.18680573, 8.76847172], [78.18680573, 8.76875019], [78.18708038, 8.76875019], [78.18708038, 8.76931095], [78.18736267, 8.76930618], [78.18736267, 8.7695837], [78.18763733, 8.7695837], [78.18763733, 8.76986217], [78.18791962, 8.76986217], [78.18791962, 8.76875019], [78.18763733, 8.76875019], [78.18763733, 8.7681942], [78.18736267, 8.7681942], [78.18736267, 8.76764011], [78.18708038, 8.76764011], [78.18708038, 8.76681137], [78.18681335, 8.76681137], [78.18681335, 8.76653004], [78.18736267, 8.76653004], [78.18736267, 8.76624966], [78.18763733, 8.76624966], [78.18763733, 8.76595974], [78.18819427, 8.76597214], [78.18819427, 8.76569366], [78.18875122, 8.76569366], [78.18875122, 8.76541805], [78.19097137, 8.76541805], [78.19097137, 8.76569366], [78.19152832, 8.76569366], [78.19152832, 8.76597214], [78.19180298, 8.76595974], [78.19180298, 8.76653004], [78.1920929, 8.76653004], [78.1920929, 8.76681137], [78.19319153, 8.76680565], [78.19319153, 8.76708412], [78.19403076, 8.76708031], [78.19403076, 8.76764011], [78.19430542, 8.76764011], [78.19430542, 8.76875019], [78.19458008, 8.76875019], [78.19458008, 8.77013969], [78.19431305, 8.77013969], [78.19431305, 8.77042103], [78.19486237, 8.77042103], [78.19486237, 8.77013969], [78.19568634, 8.77013969], [78.19568634, 8.77042103], [78.19596863, 8.77041626], [78.19596863, 8.77097225], [78.19625092, 8.77097034], [78.19625092, 8.77153111], [78.1965332, 8.77153111], [78.1965332, 8.77209091], [78.19735718, 8.77209091], [78.19735718, 8.77264118], [78.19763947, 8.77263832], [78.19763947, 8.77319431], [78.19790649, 8.77318954], [78.19790649, 8.77403069], [78.19819641, 8.77402878], [78.19819641, 8.77486038], [78.19847107, 8.77486038], [78.19847107, 8.77542114], [78.19819641, 8.77541733], [78.19819641, 8.77569485], [78.19790649, 8.77569008], [78.19790649, 8.77625084], [78.19763947, 8.77625084], [78.19763947, 8.77653122], [78.19625092, 8.77653122], [78.19625092, 8.77597046], [78.19596863, 8.77597332], [78.19596863, 8.77541733], [78.19568634, 8.77542114], [78.19568634, 8.77486038], [78.19541931, 8.77486038], [78.19541931, 8.77347183], [78.19513702, 8.77347183], [78.19513702, 8.77208233], [78.19486237, 8.77209091], [78.19486237, 8.77153111], [78.19458008, 8.77153111], [78.19458008, 8.77124977], [78.19430542, 8.77124977], [78.19430542, 8.77235985], [78.19403076, 8.77235985], [78.19403076, 8.77403069], [78.19374847, 8.77403069], [78.19374847, 8.77431107], [78.19347382, 8.77430439], [78.19347382, 8.77458191], [78.19374847, 8.77458], [78.19374847, 8.7751503], [78.19403076, 8.77513885], [78.19403076, 8.77986145], [78.19347382, 8.77986145], [78.19347382, 8.77958298], [78.19291687, 8.77958298], [78.19291687, 8.77930546], [78.19235992, 8.77930927], [78.19235992, 8.77902889], [78.19180298, 8.77902889], [78.19180298, 8.77875137], [78.19095612, 8.77875137], [78.19095612, 8.77902889], [78.19124603, 8.77902889], [78.19124603, 8.77930927], [78.19152832, 8.77930546], [78.19152832, 8.77986145], [78.19180298, 8.77986145], [78.19180298, 8.78014088], [78.1920929, 8.78014088], [78.1920929, 8.78041935], [78.19264221, 8.78041744], [78.19264221, 8.78069496], [78.19291687, 8.78069496], [78.19291687, 8.78097343], [78.19346619, 8.78096199], [78.19346619, 8.78125095], [78.19374847, 8.78125095], [78.19374847, 8.78153229], [78.19430542, 8.78152657], [78.19430542, 8.78208256], [78.19458008, 8.78208065], [78.19458008, 8.78292179], [78.19431305, 8.78292179], [78.19431305, 8.78403187], [78.19403076, 8.78403187], [78.19403076, 8.78514194], [78.19374847, 8.78513908], [78.19374847, 8.78569317], [78.19347382, 8.78569317], [78.19347382, 8.78597355], [78.19319153, 8.78597069], [78.19319153, 8.78652954], [78.19291687, 8.78652954], [78.19291687, 8.78680992], [78.19264221, 8.78680515], [78.19264221, 8.7873621], [78.19235992, 8.78735924], [78.19235992, 8.78792], [78.19208527, 8.78791809], [78.19208527, 8.78819561], [78.19180298, 8.78819561], [78.19180298, 8.78847122], [78.19152832, 8.78846931], [78.19152832, 8.78903198], [78.19180298, 8.78903198], [78.19180298, 8.78931046], [78.1920929, 8.78931046], [78.1920929, 8.78903198], [78.19291687, 8.78903198], [78.19291687, 8.78874969], [78.19319153, 8.78874969], [78.19319153, 8.78819084], [78.19347382, 8.78819561], [78.19347382, 8.78791809], [78.19374847, 8.78792], [78.19374847, 8.78763962], [78.19486237, 8.78763962], [78.19486237, 8.78792], [78.19541931, 8.78791809], [78.19541931, 8.78819561], [78.19596863, 8.78819561], [78.19596863, 8.78847122], [78.1965332, 8.78846931], [78.1965332, 8.78874969], [78.19709015, 8.78874969], [78.19709015, 8.78903198], [78.19847107, 8.78903198], [78.19847107, 8.78874969], [78.19902802, 8.78874969], [78.19902802, 8.78846931], [78.19930267, 8.78847122], [78.19930267, 8.78791809], [78.19957733, 8.78792], [78.19957733, 8.78735924], [78.19930267, 8.7873621], [78.19930267, 8.78680515], [78.19902802, 8.78680992], [78.19902802, 8.78625202], [78.19930267, 8.78625202], [78.19930267, 8.78542042], [78.19957733, 8.78542042], [78.19957733, 8.78403187], [78.19985962, 8.78403187], [78.19985962, 8.78153229], [78.19957733, 8.78153229], [78.19957733, 8.77818966], [78.19930267, 8.77819538], [78.19930267, 8.77458477], [78.19902802, 8.77458191], [78.19902802, 8.77124977], [78.19875336, 8.77124977], [78.19875336, 8.76792145], [78.19847107, 8.76792145], [78.19847107, 8.7656889], [78.19875336, 8.76569366], [78.19875336, 8.76486206], [78.19902802, 8.76486206], [78.19902802, 8.76430607], [78.19985962, 8.76431274], [78.19985962, 8.76403046], [78.20041656, 8.76403046], [78.20041656, 8.76375198], [78.20124817, 8.76375198], [78.20124817, 8.7634716], [78.20207977, 8.7634716], [78.20207977, 8.76319408], [78.20291901, 8.76319408], [78.20291901, 8.76291561], [78.20347595, 8.76292038], [78.20347595, 8.76264191], [78.20430756, 8.76264191], [78.20430756, 8.76236153], [78.20513916, 8.76236153], [78.20513916, 8.76208401], [78.20569611, 8.76208401], [78.20569611, 8.76180553], [78.20625305, 8.7618103], [78.20625305, 8.76152992], [78.20680237, 8.76152992], [78.20680237, 8.76124859], [78.20735931, 8.76124859], [78.20735931, 8.76097107], [78.20791626, 8.76097107], [78.20791626, 8.7606926], [78.20874786, 8.7606926], [78.20874786, 8.76041794], [78.20929718, 8.76041985], [78.20929718, 8.76015091], [78.20986176, 8.76015091], [78.20986176, 8.75986099], [78.2104187, 8.75986099], [78.2104187, 8.75958347], [78.21097565, 8.75958347], [78.21097565, 8.759305], [78.21151733, 8.75930977], [78.21151733, 8.75903034], [78.21235657, 8.75903034], [78.21235657, 8.75875187], [78.2131958, 8.75875187], [78.2131958, 8.75847054], [78.2140274, 8.7584734], [78.2140274, 8.75819302], [78.21485901, 8.75819302], [78.21485901, 8.7579174], [78.21569061, 8.75792027], [78.21569824, 8.75764179], [78.21652985, 8.75764179], [78.21652985, 8.75736141], [78.21763611, 8.75736141], [78.21763611, 8.75708294], [78.21875, 8.75708294], [78.21875, 8.75680542], [78.2195816, 8.75681019], [78.2195816, 8.75653172], [78.22070313, 8.75653172], [78.22070313, 8.75625134], [78.22180176, 8.75625134], [78.22180176, 8.75597095], [78.2234726, 8.75597095], [78.2234726, 8.75513935], [78.22374725, 8.75514126], [78.22374725, 8.75458145], [78.22402954, 8.75458336], [78.22402954, 8.75430489], [78.22458649, 8.75430965], [78.22458649, 8.75401974], [78.2251358, 8.75402737], [78.2251358, 8.75374889], [78.22541809, 8.75374889], [78.22541809, 8.75347328], [78.22597504, 8.75347328], [78.22597504, 8.75319481], [78.22652435, 8.75319481], [78.22652435, 8.75291729], [78.22680664, 8.7529192], [78.22680664, 8.75264072], [78.22706604, 8.75264072], [78.22706604, 8.7523613], [78.22736359, 8.7523613], [78.22736359, 8.75208282], [78.22763824, 8.75208282], [78.22763824, 8.75180531], [78.2279129, 8.75181198], [78.2279129, 8.75153065], [78.22820282, 8.75153065], [78.22820282, 8.75125122], [78.22846985, 8.75125122], [78.22846985, 8.75097275], [78.22875214, 8.75098038], [78.22875214, 8.75042057], [78.22902679, 8.75042057], [78.22902679, 8.75014114], [78.22930908, 8.75014114], [78.22930908, 8.7498579], [78.22958374, 8.74986076], [78.22958374, 8.74958324], [78.2298584, 8.74958324], [78.2298584, 8.74930668], [78.23013306, 8.74931145], [78.23013306, 8.74875069], [78.2298584, 8.74875069], [78.2298584, 8.74818993], [78.2279129, 8.74818993], [78.2279129, 8.74875069], [78.22763824, 8.74875069], [78.22763824, 8.74903107], [78.22735596, 8.74903107], [78.22735596, 8.74931145], [78.2270813, 8.74930668], [78.2270813, 8.74986076], [78.22680664, 8.7498579], [78.22680664, 8.75014114], [78.22652435, 8.75013924], [78.22652435, 8.75069523], [78.22624969, 8.75069046], [78.22624969, 8.75098038], [78.22597504, 8.75097275], [78.22597504, 8.75125122], [78.22569275, 8.75125122], [78.22569275, 8.75181198], [78.22541809, 8.75180531], [78.22541809, 8.75208282], [78.22486115, 8.75208282], [78.22486115, 8.7523613], [78.22458649, 8.7523613], [78.22458649, 8.75264072], [78.22374725, 8.75264072], [78.22374725, 8.7529192], [78.22291565, 8.75291729], [78.22291565, 8.75319481], [78.22208405, 8.75319481], [78.22208405, 8.75347328], [78.22125244, 8.75347328], [78.22125244, 8.75374889], [78.22013855, 8.75374889], [78.22013855, 8.75402737], [78.21901703, 8.75401974], [78.21901703, 8.75430965], [78.21819305, 8.75430489], [78.21819305, 8.75458336], [78.21736145, 8.75458336], [78.21736145, 8.75486088], [78.21679688, 8.75486088], [78.21679688, 8.75514126], [78.2159729, 8.75514126], [78.2159729, 8.75542164], [78.21541595, 8.75541687], [78.21541595, 8.75569534], [78.21485901, 8.75569534], [78.21485901, 8.75597095], [78.2140274, 8.75597095], [78.2140274, 8.75625134], [78.21347046, 8.75625134], [78.21347046, 8.75653172], [78.21290588, 8.75653172], [78.21290588, 8.75681019], [78.2123642, 8.75680542], [78.2123642, 8.75708294], [78.21180725, 8.75708294], [78.21180725, 8.75736141], [78.21098328, 8.75736141], [78.21098328, 8.75764179], [78.2104187, 8.75764179], [78.2104187, 8.75792027], [78.20986176, 8.7579174], [78.20986176, 8.75819302], [78.20930481, 8.75819492], [78.20930481, 8.7584734], [78.20874786, 8.75847054], [78.20874786, 8.75875187], [78.20791626, 8.75875187], [78.20791626, 8.75903034], [78.20735931, 8.75903034], [78.20735931, 8.75930977], [78.20680237, 8.759305], [78.20680237, 8.75958347], [78.20625305, 8.75958347], [78.20625305, 8.75986099], [78.20540619, 8.75986099], [78.20540619, 8.76015091], [78.20485687, 8.76015091], [78.20485687, 8.76041985], [78.20430756, 8.76041794], [78.20430756, 8.7606926], [78.20375061, 8.7606926], [78.20375061, 8.76097107], [78.20291901, 8.76097107], [78.20291901, 8.76124859], [78.20236206, 8.76124859], [78.20236206, 8.76152992], [78.20181274, 8.76152992], [78.20181274, 8.7618103], [78.20097351, 8.76180553], [78.20097351, 8.76208401], [78.20014191, 8.76208401], [78.20014191, 8.76236153], [78.19957733, 8.76236153], [78.19957733, 8.76264191], [78.19875336, 8.76264191], [78.19875336, 8.76292038], [78.19819641, 8.76291561], [78.19819641, 8.76319408], [78.19763947, 8.76319408], [78.19763947, 8.76291561], [78.19735718, 8.76292038], [78.19735718, 8.76264191], [78.19763947, 8.76264191], [78.19763947, 8.76236153], [78.19791412, 8.76236153], [78.19791412, 8.76208401], [78.19819641, 8.76208401], [78.19819641, 8.76180553], [78.19847107, 8.7618103], [78.19847107, 8.76124859], [78.19875336, 8.76124859], [78.19875336, 8.76097107], [78.19902802, 8.76097107], [78.19902802, 8.7606926], [78.19930267, 8.7606926], [78.19930267, 8.76041794], [78.19957733, 8.76041985], [78.19957733, 8.75986099], [78.19985962, 8.75986099], [78.19985962, 8.759305], [78.20041656, 8.75930977], [78.20041656, 8.75903034], [78.20069122, 8.75903034], [78.20069122, 8.75875187], [78.20124817, 8.75875187], [78.20124817, 8.75764179], [78.20096588, 8.75764179], [78.20096588, 8.75653172], [78.20069122, 8.75653172], [78.20069122, 8.75597095], [78.20041656, 8.75597095], [78.20041656, 8.75541687], [78.20012665, 8.75542164], [78.20012665, 8.75486088], [78.19985962, 8.75486088], [78.19985962, 8.75430489], [78.19957733, 8.75430965], [78.19957733, 8.75319004], [78.19985962, 8.75319481], [78.19985962, 8.75291729], [78.20041656, 8.7529192], [78.20041656, 8.75264072], [78.20069122, 8.75264072], [78.20069122, 8.7523613], [78.20097351, 8.7523613], [78.20097351, 8.75208282], [78.20153046, 8.75208282], [78.20153046, 8.75180531], [78.20181274, 8.75181198], [78.20181274, 8.75153065], [78.20263672, 8.75153065], [78.20263672, 8.75125122], [78.20319366, 8.75125122], [78.20318604, 8.75098038], [78.20485687, 8.75098038], [78.20485687, 8.75069046], [78.20569611, 8.75069523], [78.20569611, 8.75041676], [78.20625305, 8.75042057], [78.20625305, 8.75014114], [78.20680237, 8.75014114], [78.20680237, 8.7498579], [78.20735931, 8.74986076], [78.20735931, 8.74958324], [78.20819092, 8.74958324], [78.20819092, 8.74930668], [78.20847321, 8.74931145], [78.20847321, 8.74903107], [78.20874786, 8.74903107], [78.20874786, 8.74847031], [78.20903015, 8.74847317], [78.20903015, 8.74819469], [78.20930481, 8.74819469], [78.20930481, 8.74791718], [78.2095871, 8.74792099], [78.2095871, 8.74764061], [78.21206665, 8.74764061], [78.21206665, 8.74792099], [78.2123642, 8.74791718], [78.2123642, 8.74819469], [78.21291351, 8.74819469], [78.21291351, 8.74847317], [78.2131958, 8.74847031], [78.2131958, 8.75014114], [78.21347046, 8.75014114], [78.21347046, 8.75042057], [78.21375275, 8.75041676], [78.21375275, 8.75069523], [78.2140274, 8.75069046], [78.2140274, 8.75098038], [78.21430206, 8.75097275], [78.21430206, 8.75125122], [78.21457672, 8.75125122], [78.21457672, 8.75153065], [78.21624756, 8.75153065], [78.21624756, 8.75125122], [78.21652985, 8.75125122], [78.21652985, 8.75097275], [78.21679688, 8.75098038], [78.21679688, 8.75069046], [78.21708679, 8.75069523], [78.21708679, 8.74986076], [78.21736145, 8.74986076], [78.21736145, 8.74875069], [78.21763611, 8.74875069], [78.21763611, 8.74792099], [78.21736145, 8.74792099], [78.21736145, 8.74736023], [78.21708679, 8.74736023], [78.21708679, 8.74708462], [78.2159729, 8.74708462], [78.2159729, 8.74680424], [78.21569824, 8.74681091], [78.21569061, 8.74653053], [78.21541595, 8.74653053], [78.21541595, 8.74625015], [78.21512604, 8.74625015], [78.21512604, 8.74596977], [78.21485901, 8.74597168], [78.21485901, 8.74513817], [78.21763611, 8.74514103], [78.21763611, 8.74542141], [78.21819305, 8.74541569], [78.21819305, 8.74569416], [78.21847534, 8.74569416], [78.21847534, 8.74597168], [78.21901703, 8.74596977], [78.21901703, 8.74625015], [78.21930695, 8.74625015], [78.21930695, 8.74653053], [78.21985626, 8.74653053], [78.21985626, 8.74681091], [78.22013855, 8.74680424], [78.22013855, 8.74736023], [78.21985626, 8.74736023], [78.21985626, 8.74792099], [78.2206955, 8.74791718], [78.2206955, 8.74819469], [78.22208405, 8.74819469], [78.22208405, 8.74847317], [78.2234726, 8.74847317], [78.2234726, 8.74597168], [78.22291565, 8.74597168], [78.22291565, 8.74569416], [78.2223587, 8.74569416], [78.2223587, 8.74541569], [78.22180176, 8.74542141], [78.22180176, 8.74514103], [78.22126007, 8.74514103], [78.22126007, 8.74485111], [78.22041321, 8.7448597], [78.22041321, 8.74458218], [78.21986389, 8.74458218], [78.21986389, 8.74430561], [78.21930695, 8.74431133], [78.21930695, 8.74403095], [78.21875, 8.74403095], [78.21875, 8.74374962], [78.21819305, 8.74374962], [78.21819305, 8.74347019], [78.2179184, 8.7434721], [78.2179184, 8.74319363], [78.21736145, 8.74319363], [78.21736145, 8.74291611], [78.21679688, 8.74292088], [78.21679688, 8.74263954], [78.2159729, 8.74263954], [78.2159729, 8.74292088], [78.21541595, 8.74291611], [78.21541595, 8.74319363], [78.21485901, 8.74319363], [78.21485901, 8.7434721], [78.21430206, 8.74347019], [78.21430206, 8.74374962], [78.21375275, 8.74374962], [78.21375275, 8.74403095], [78.2131958, 8.74403095], [78.2131958, 8.74431133], [78.21263885, 8.74430561], [78.21263885, 8.74458218], [78.21208191, 8.74458218], [78.21208191, 8.7448597], [78.21180725, 8.74485111], [78.21180725, 8.74514103], [78.21125031, 8.74514103], [78.21125031, 8.74542141], [78.21069336, 8.74541569], [78.21069336, 8.74569416], [78.21013641, 8.74569416], [78.21013641, 8.74597168], [78.2095871, 8.74597168], [78.2095871, 8.74625015], [78.20903015, 8.74625015], [78.20903015, 8.74653053], [78.20847321, 8.74653053], [78.20847321, 8.74681091], [78.20791626, 8.74680424], [78.20791626, 8.74708462], [78.20735931, 8.74708462], [78.20735931, 8.74736023], [78.20680237, 8.74736023], [78.20680237, 8.74764061], [78.20625305, 8.74764061], [78.20625305, 8.74792099], [78.20541382, 8.74791718], [78.20541382, 8.74819469], [78.2048645, 8.74819469], [78.2048645, 8.74847317], [78.20430756, 8.74847031], [78.20430756, 8.74875069], [78.20375061, 8.74875069], [78.20375061, 8.74903107], [78.20318604, 8.74903107], [78.20318604, 8.74931145], [78.20263672, 8.74930668], [78.20263672, 8.74958324], [78.20180511, 8.74958324], [78.20180511, 8.74986076], [78.20124817, 8.7498579], [78.20124817, 8.75014114], [78.20069122, 8.75014114], [78.20069122, 8.75042057], [78.20014191, 8.75041676], [78.20014191, 8.75069523], [78.19957733, 8.75069046], [78.19957733, 8.75098038], [78.19902802, 8.75097275], [78.19902802, 8.75125122], [78.19819641, 8.75125122], [78.19819641, 8.75153065], [78.19763947, 8.75153065], [78.19763947, 8.75181198], [78.19708252, 8.75180531], [78.19708252, 8.75208282], [78.19625092, 8.75208282], [78.19625092, 8.7523613], [78.19513702, 8.7523613], [78.19513702, 8.75264072], [78.19374847, 8.75264072], [78.19374847, 8.75208092], [78.19347382, 8.75208282], [78.19347382, 8.75152683], [78.19319153, 8.75153065], [78.19319153, 8.75125122], [78.19291687, 8.75125122], [78.19291687, 8.75069523], [78.19264221, 8.75069523], [78.19264221, 8.75041676], [78.19235992, 8.75042057], [78.19235992, 8.7498579], [78.19208527, 8.74986076], [78.19208527, 8.74930668], [78.19180298, 8.74931145], [78.19180298, 8.74903107], [78.19152832, 8.74903107], [78.19152832, 8.74847031], [78.19125366, 8.74847317], [78.19125366, 8.74791718], [78.19069672, 8.74791718], [78.19069672, 8.74819469], [78.19013977, 8.74819469], [78.19013977, 8.74847317], [78.18958282, 8.74847031], [78.18958282, 8.74875069], [78.18846893, 8.74875069], [78.18846893, 8.74903107], [78.18736267, 8.74903107], [78.18736267, 8.74931145], [78.18624878, 8.74930668], [78.18624878, 8.74958324], [78.18264008, 8.74958324], [78.18264008, 8.74930668], [78.18187714, 8.74930859], [78.18125153, 8.74931145], [78.18125153, 8.74903107], [78.18041992, 8.74903107], [78.18041992, 8.74875069], [78.17958069, 8.74875069], [78.17958069, 8.74847031], [78.17874908, 8.74847317], [78.17874908, 8.74819469], [78.17763519, 8.74819469], [78.17763519, 8.74791718], [78.17679596, 8.74792099], [78.17679596, 8.74764061], [78.17595673, 8.74764061], [78.17595673, 8.74736023], [78.17514038, 8.74736023], [78.17514038, 8.74708462], [78.17458344, 8.74708462], [78.17458344, 8.74680424], [78.17402649, 8.74681091], [78.17402649, 8.74653053], [78.17346954, 8.74653053], [78.17346954, 8.74625015], [78.17263794, 8.74625015], [78.17263794, 8.74597168], [78.17208099, 8.74597168], [78.17208099, 8.74569416], [78.17152405, 8.74569416], [78.17152405, 8.74541569], [78.17124939, 8.74542141], [78.17124939, 8.74514103], [78.17069244, 8.74514103], [78.17069244, 8.74485111], [78.17041779, 8.7448597], [78.17041779, 8.74458218], [78.1701355, 8.74458218], [78.1701355, 8.74430561], [78.16986084, 8.74431133], [78.16986084, 8.74403095], [78.16929626, 8.74403095], [78.16929626, 8.74374962], [78.16902924, 8.74374962], [78.16902924, 8.74347019], [78.16874695, 8.7434721], [78.16874695, 8.74319363], [78.16847229, 8.74319363], [78.16847229, 8.74291611], [78.16792297, 8.74292088], [78.16792297, 8.74263954], [78.16764069, 8.74263954], [78.16764069, 8.74236012], [78.1673584, 8.74236012], [78.1673584, 8.74208355], [78.16708374, 8.74208355], [78.16708374, 8.74180603], [78.16652679, 8.7418108], [78.16652679, 8.74153042], [78.16625214, 8.74153042], [78.16625214, 8.74125004], [78.16596985, 8.74125004], [78.16596985, 8.74096966], [78.16569519, 8.74097157], [78.16569519, 8.74069405], [78.1654129, 8.74069405], [78.1654129, 8.74041557], [78.16513824, 8.74042034], [78.16513824, 8.74013996], [78.16485596, 8.74013996], [78.16485596, 8.73985958], [78.1645813, 8.73986244], [78.1645813, 8.73930645], [78.16430664, 8.73931122], [78.16430664, 8.73903942], [78.16401672, 8.73903942], [78.16401672, 8.73875046], [78.16374969, 8.73875046], [78.16374969, 8.73847198], [78.16347504, 8.73847198], [78.16347504, 8.73819447], [78.16319275, 8.73819447], [78.16319275, 8.7379179], [78.16291809, 8.7379179], [78.16291809, 8.73764038], [78.1626358, 8.73764038], [78.1626358, 8.73736191], [78.16236115, 8.73736191], [78.16236115, 8.73680592], [78.16208649, 8.73680973], [78.16208649, 8.73625183], [78.16179657, 8.73625183], [78.16179657, 8.73569107], [78.16152954, 8.73569584], [78.16152954, 8.73541546], [78.16124725, 8.73542023], [78.16124725, 8.73485947], [78.1609726, 8.73486233], [78.1609726, 8.73430634], [78.16069794, 8.73431015], [78.16069794, 8.73374939], [78.16041565, 8.73374939], [78.16041565, 8.7331934], [78.16014099, 8.7331934], [78.16014099, 8.73291779], [78.1598587, 8.73291779], [78.1598587, 8.73236084], [78.15957642, 8.73236084], [78.15957642, 8.73180962], [78.15930176, 8.73180962], [78.15930176, 8.73125172], [78.1590271, 8.73125172], [78.1590271, 8.73097134], [78.15875244, 8.73097134], [78.15875244, 8.73041725], [78.15847015, 8.73042202], [78.15847015, 8.72985172], [78.1581955, 8.72986126], [78.1581955, 8.72930527], [78.15792084, 8.72931194], [78.15792084, 8.7284708], [78.15763855, 8.7284708], [78.15763855, 8.72736073], [78.15735626, 8.72736073], [78.15735626, 8.72625065], [78.1570816, 8.72625065], [78.1570816, 8.72514057], [78.15680695, 8.72514057], [78.15680695, 8.72431183], [78.15651703, 8.72431183], [78.15651703, 8.72319031], [78.15625, 8.72319508], [78.15625, 8.72208309], [78.15597534, 8.72208309], [78.15597534, 8.72125053], [78.15569305, 8.72125053], [78.15569305, 8.72014141], [78.1554184, 8.72014141], [78.1554184, 8.71542072], [78.15513611, 8.71542072], [78.15513611, 8.71403027], [78.15484619, 8.71403027], [78.15484619, 8.71264172], [78.15458679, 8.71264172], [78.15458679, 8.71181011], [78.15429688, 8.71181011], [78.15429688, 8.71152973], [78.15402985, 8.71152973], [78.15402985, 8.71097183], [78.15374756, 8.71097183], [78.15374756, 8.71069431], [78.1534729, 8.71069431], [78.1534729, 8.71041775], [78.15319824, 8.71041965], [78.15319061, 8.70997334], [78.15319061, 8.70986176], [78.15291595, 8.70986176], [78.15291595, 8.70958424], [78.1526413, 8.70958424], [78.1526413, 8.70930576], [78.15235901, 8.70930958], [78.15235901, 8.70874977], [78.15207672, 8.70874977], [78.15207672, 8.70846939], [78.15180206, 8.70847225], [78.15180206, 8.70819569], [78.1515274, 8.70819569], [78.1515274, 8.70791531], [78.15125275, 8.70792007], [78.15125275, 8.70763969], [78.1506958, 8.70763969], [78.1506958, 8.70735931], [78.15041351, 8.70736217], [78.15041351, 8.7070837], [78.15013885, 8.7070837], [78.15013885, 8.70680523], [78.14985657, 8.70681], [78.14985657, 8.70652962], [78.14958191, 8.70652962], [78.14958191, 8.70624924], [78.14901733, 8.70624924], [78.14901733, 8.70596886], [78.14875031, 8.70597363], [78.14875031, 8.70569324], [78.14847565, 8.70569324], [78.14847565, 8.70541763], [78.14819336, 8.70541954], [78.14819336, 8.70514202], [78.1479187, 8.70514202], [78.1479187, 8.70486069], [78.14736176, 8.70486069], [78.14736176, 8.70458317], [78.1470871, 8.70458317], [78.1470871, 8.7043047], [78.14679718, 8.70431042], [78.14679718, 8.70403194], [78.14653015, 8.70403194], [78.14653015, 8.70390034], [78.14653015, 8.7037487], [78.14624786, 8.70375061], [78.14624786, 8.70347118], [78.14569092, 8.70347118], [78.14569092, 8.70319462], [78.14541626, 8.70319462], [78.14541626, 8.7029171], [78.1451416, 8.7029314], [78.1451416, 8.70264244], [78.14485931, 8.70264244], [78.14485931, 8.70236111], [78.14458466, 8.70236111], [78.14458466, 8.70208263], [78.14430237, 8.70208263], [78.14430237, 8.70180511], [78.14402771, 8.70181179], [78.14402771, 8.70153236], [78.14375305, 8.70153236], [78.14375305, 8.70125103], [78.14347076, 8.70125103], [78.14347076, 8.70097065], [78.14319611, 8.70097256], [78.14319611, 8.70069504], [78.14263916, 8.70069504], [78.14263916, 8.70041656], [78.14235687, 8.70041943], [78.14235687, 8.70014095], [78.14208221, 8.70014095], [78.14208221, 8.69987011], [78.14180756, 8.69987011], [78.14180756, 8.69958115], [78.14152527, 8.69958305], [78.14152527, 8.69930458], [78.14125061, 8.69930935], [78.14125061, 8.69903088], [78.14097595, 8.69903088], [78.14097595, 8.69875145], [78.14068604, 8.69875145], [78.14068604, 8.69847107], [78.14041901, 8.69847298], [78.14041901, 8.69791698], [78.14013672, 8.69791889], [78.14013672, 8.69736099], [78.1398468, 8.69736099], [78.1398468, 8.69680023], [78.13957977, 8.69680691], [78.13957977, 8.69625092], [78.13931274, 8.69625092], [78.13931274, 8.6957016], [78.13903046, 8.69569016], [78.13903046, 8.69513893], [78.13874817, 8.69514084], [78.13874817, 8.69458008], [78.13847351, 8.69458199], [78.13847351, 8.69402885], [78.13819122, 8.69402885], [78.13819122, 8.69347], [78.13791656, 8.69347286], [78.13791656, 8.69319439], [78.13764191, 8.69319439], [78.13764191, 8.6926384], [78.13735962, 8.69264126], [78.13735962, 8.69207954], [78.13708496, 8.69208241], [78.13708496, 8.69152832], [78.1368103, 8.69153118], [78.1368103, 8.69097042], [78.13652802, 8.69097233], [78.13652802, 8.69041634], [78.13625336, 8.6904211], [78.13625336, 8.68986034], [78.13597107, 8.68986225], [78.13597107, 8.68930626], [78.13569641, 8.68931103], [78.13569641, 8.68875027], [78.13540649, 8.68875027], [78.13540649, 8.68793201], [78.13513947, 8.68793201], [78.13513947, 8.68681145], [78.13485718, 8.68681145], [78.13485718, 8.68569183], [78.13458252, 8.68569374], [78.13458252, 8.68458366], [78.13430786, 8.68458366], [78.13430786, 8.68347168], [78.13402557, 8.68347168], [78.13402557, 8.68208408], [78.13375092, 8.68208408], [78.13375092, 8.68069553], [78.13346863, 8.68069553], [78.13346863, 8.67930508], [78.13318634, 8.67930984], [78.13318634, 8.67792034], [78.13291931, 8.67792034], [78.13291931, 8.67542171], [78.13263702, 8.67542171], [78.13263702, 8.67430973], [78.13236237, 8.67430973], [78.13236237, 8.67319107], [78.13208008, 8.67319489], [78.13208008, 8.67236137], [78.13180542, 8.67236137], [78.13180542, 8.6706953], [78.13208008, 8.6706953], [78.13208008, 8.66875076], [78.13236237, 8.66875076], [78.13236237, 8.66736031], [78.13208008, 8.66736031], [78.13208008, 8.6665287], [78.13181305, 8.66653061], [78.13181305, 8.66596985], [78.13153076, 8.66597176], [78.13153076, 8.66513824], [78.13124847, 8.66514111], [78.13124847, 8.66431141], [78.13096619, 8.66431141], [78.13096619, 8.66375923], [78.13069153, 8.66375923], [78.13069153, 8.66403103], [78.13041687, 8.66403103], [78.13041687, 8.66431141], [78.12958527, 8.66430569], [78.12958527, 8.66458225], [78.12819672, 8.66458225], [78.12819672, 8.66430569], [78.12708282, 8.66430569], [78.12708282, 8.66458225], [78.12652588, 8.66458225], [78.12652588, 8.66402817], [78.12625122, 8.66403103], [78.12625122, 8.66347027], [78.12652588, 8.66347218], [78.12652588, 8.6631937], [78.12680817, 8.6631937], [78.12680817, 8.66236019], [78.12652588, 8.66236019], [78.12652588, 8.66180611], [78.12625122, 8.66181087], [78.12625122, 8.66152954], [78.12596893, 8.66152954], [78.12596893, 8.66125011], [78.12568665, 8.66125011], [78.12568665, 8.66096973], [78.12541962, 8.66097164], [78.12541962, 8.66069412], [78.12625122, 8.66069412], [78.12625122, 8.66097164], [78.12680817, 8.66096973], [78.12680817, 8.66125011], [78.12708282, 8.66125011], [78.12708282, 8.66152954], [78.12735748, 8.66152954], [78.12735748, 8.66181087], [78.12763977, 8.66180611], [78.12763977, 8.66208363], [78.12819672, 8.66208363], [78.12819672, 8.66236019], [78.12847137, 8.66236019], [78.12847137, 8.66263962], [78.12985992, 8.66263962], [78.12985992, 8.66292095], [78.13069153, 8.66292095], [78.13069153, 8.66236019], [78.13041687, 8.66236019], [78.13041687, 8.66180611], [78.13014221, 8.66181087], [78.13014221, 8.66125011], [78.12985992, 8.66125011], [78.12985992, 8.6607008], [78.1295929, 8.6607008], [78.1295929, 8.66014004], [78.12930298, 8.66014004], [78.12930298, 8.65958023], [78.12902832, 8.65958405], [78.12902832, 8.65847206], [78.12875366, 8.65847206], [78.12875366, 8.6576376], [78.12847137, 8.6576376], [78.12847137, 8.65513992], [78.12819672, 8.65513992], [78.12819672, 8.65347099], [78.12791443, 8.65347099], [78.12791443, 8.65180492], [78.12763977, 8.65181923], [78.12763977, 8.65042019], [78.12735748, 8.65041733], [78.12735748, 8.65097141], [78.12680817, 8.65097141], [78.12680817, 8.65125179], [78.12625122, 8.65125179], [78.12625122, 8.65153027], [78.12568665, 8.65153027], [78.12568665, 8.65181923], [78.12541962, 8.65180492], [78.12541962, 8.6520834], [78.12486267, 8.6520834], [78.12486267, 8.65236187], [78.12431335, 8.65236187], [78.12431335, 8.65264034], [78.12374878, 8.65264034], [78.12374878, 8.65291977], [78.12264252, 8.65291786], [78.12264252, 8.65319347], [78.12152863, 8.65319061], [78.12152863, 8.65402985], [78.12124634, 8.65402794], [78.12124634, 8.65458393], [78.12208557, 8.65458393], [78.12208557, 8.6548624], [78.12264252, 8.65485859], [78.12264252, 8.65513992], [78.12291718, 8.65513992], [78.12291718, 8.65569401], [78.12319183, 8.65569401], [78.12319183, 8.65597153], [78.12346649, 8.65597153], [78.12346649, 8.65653038], [78.12374878, 8.65652847], [78.12374878, 8.65708447], [78.12403107, 8.65708447], [78.12403107, 8.65458393], [78.12430573, 8.65458393], [78.12430573, 8.65402794], [78.12458038, 8.65402985], [78.12458038, 8.65374947], [78.12541962, 8.65374947], [78.12541962, 8.65402985], [78.12596893, 8.65402985], [78.12596893, 8.65431023], [78.12625122, 8.65430641], [78.12625122, 8.6548624], [78.12596893, 8.65485859], [78.12596893, 8.65513992], [78.12568665, 8.65513992], [78.12568665, 8.6554203], [78.12541962, 8.65541553], [78.12541962, 8.65597153], [78.12568665, 8.65597153], [78.12568665, 8.65625191], [78.12596893, 8.65625191], [78.12596893, 8.6568079], [78.12625122, 8.65680599], [78.12625122, 8.65708447], [78.12652588, 8.65708447], [78.12652588, 8.65819359], [78.12625122, 8.65819168], [78.12625122, 8.65874958], [78.12596893, 8.65874958], [78.12596893, 8.65902996], [78.12568665, 8.65902996], [78.12568665, 8.65931129], [78.12541962, 8.65930557], [78.12541962, 8.65958405], [78.12403107, 8.65958405], [78.12403107, 8.65930557], [78.12319183, 8.65930557], [78.12319183, 8.65986156], [78.12236023, 8.65986156], [78.12236023, 8.65930557], [78.12210083, 8.65931129], [78.12210083, 8.65874958], [78.12069702, 8.65874958], [78.12069702, 8.65902996], [78.11958313, 8.65902996], [78.11958313, 8.6607008], [78.12319183, 8.6607008], [78.12319183, 8.66125011], [78.12291718, 8.66125011], [78.12291718, 8.66181087], [78.12264252, 8.66180611], [78.12264252, 8.66236019], [78.11902618, 8.66236019], [78.11902618, 8.66208363], [78.11736298, 8.66208363], [78.11736298, 8.66180611], [78.11708069, 8.66181087], [78.11708069, 8.66152954], [78.1167984, 8.66152763], [78.11653137, 8.66152954], [78.11653137, 8.66125011], [78.11624908, 8.66125011], [78.11624908, 8.66096973], [78.11569214, 8.66097164], [78.11569214, 8.66069412], [78.1159668, 8.6607008], [78.1159668, 8.66042137], [78.11624908, 8.66042137], [78.1162796, 8.66014004], [78.11653137, 8.66014004], [78.11653137, 8.65985966], [78.11680603, 8.65985966], [78.11680603, 8.65958405], [78.11708069, 8.65958405], [78.11708069, 8.65930557], [78.11736298, 8.65931129], [78.11736298, 8.65902996], [78.11763763, 8.65902996], [78.11763763, 8.65847015], [78.11791992, 8.65847206], [78.11791992, 8.65819359], [78.11819458, 8.65819359], [78.11819458, 8.65791798], [78.11763763, 8.65791798], [78.11763763, 8.65819359], [78.1156311, 8.65819359], [78.11541748, 8.65819359], [78.11541748, 8.65758991], [78.11541748, 8.65736198], [78.11513519, 8.65736198], [78.11513519, 8.65708447], [78.11402893, 8.65708447], [78.11402893, 8.65680599], [78.11347198, 8.6568079], [78.11347198, 8.65653038], [78.11319733, 8.65653038], [78.11319733, 8.65625191], [78.1129303, 8.65625191], [78.1129303, 8.65597153], [78.11264038, 8.65597153], [78.11264038, 8.65569401], [78.11208344, 8.65569401], [78.11208344, 8.65541553], [78.11069489, 8.65541553], [78.11069489, 8.65569401], [78.10986328, 8.65569401], [78.10986328, 8.65597153], [78.10847473, 8.65597153], [78.10847473, 8.65569401], [78.10791779, 8.65569401], [78.10791779, 8.65541553], [78.10764313, 8.6554203], [78.10764313, 8.65513992], [78.10736084, 8.65513992], [78.10736084, 8.65485859], [78.10708618, 8.6548624], [78.10708618, 8.65458393], [78.10652924, 8.65458393], [78.10652924, 8.65430641], [78.10624695, 8.65431023], [78.10624695, 8.65374947], [78.10597229, 8.65374947], [78.10597229, 8.65319347], [78.10569763, 8.65319347], [78.10569763, 8.65264034], [78.10542297, 8.65264034], [78.10542297, 8.65208054], [78.10514069, 8.6520834], [78.10514069, 8.6515274], [78.1048584, 8.65153027], [78.1048584, 8.65125179], [78.10542297, 8.65125179], [78.10542297, 8.65097141], [78.10597229, 8.65097141], [78.10597229, 8.65069485], [78.10680389, 8.65069485], [78.10680389, 8.65041733], [78.10736084, 8.65042019], [78.10736084, 8.65014172], [78.10987091, 8.65014172], [78.10987091, 8.65042019], [78.11125183, 8.65041733], [78.11125183, 8.65069485], [78.11152649, 8.65069485], [78.11152649, 8.65097141], [78.11180878, 8.65097141], [78.11180878, 8.65125179], [78.11207581, 8.65125179], [78.11207581, 8.65153027], [78.11235809, 8.65153027], [78.11235809, 8.65181923], [78.11264038, 8.65181923], [78.11264038, 8.65153027], [78.11319733, 8.65153027], [78.11319733, 8.65125179], [78.11347198, 8.65125179], [78.11347198, 8.65097141], [78.11360931, 8.65097141], [78.11402893, 8.65097141], [78.11402893, 8.65069485], [78.11430359, 8.65069485], [78.11430359, 8.65041733], [78.11402893, 8.65042019], [78.11402893, 8.65014172], [78.11374664, 8.65014172], [78.11374664, 8.64958096], [78.11347198, 8.64958286], [78.11347198, 8.64930534], [78.11319733, 8.64930534], [78.11319733, 8.64902687], [78.1129303, 8.64903164], [78.1129303, 8.6487627], [78.11264038, 8.6487627], [78.11264038, 8.64847088], [78.11235809, 8.64847088], [78.11235809, 8.64791679], [78.11207581, 8.64792156], [78.11207581, 8.64763927], [78.11180878, 8.64763927], [78.11180878, 8.64735889], [78.11208344, 8.6473608], [78.11208344, 8.64708328], [78.11235809, 8.64708328], [78.11235809, 8.64680481], [78.11260986, 8.64680958], [78.11264038, 8.6465292], [78.1129303, 8.6465292], [78.1129303, 8.64514065], [78.11319733, 8.64514065], [78.11319733, 8.6434679], [78.11347198, 8.64347076], [78.11347198, 8.64291668], [78.11319733, 8.64292145], [78.11319733, 8.64262962], [78.11291504, 8.64263916], [78.11291504, 8.64236069], [78.11264038, 8.64236069], [78.11264038, 8.6418047], [78.11235809, 8.64181137], [78.11235809, 8.64153099], [78.11207581, 8.64153099], [78.11207581, 8.64125061], [78.11180878, 8.64125061], [78.11180878, 8.64097023], [78.11152649, 8.64097309], [78.11152649, 8.64069462], [78.11125183, 8.64069462], [78.11125183, 8.64013767], [78.11096954, 8.64014053], [78.11096954, 8.63986015], [78.11069489, 8.63986015], [78.11069489, 8.63958454], [78.10986328, 8.63958454], [78.10986328, 8.63986015], [78.10930634, 8.63986015], [78.10930634, 8.64014053], [78.1084671, 8.64014053], [78.1084671, 8.64042091], [78.10791779, 8.6404171], [78.10791779, 8.64069462], [78.10708618, 8.64069462], [78.10708618, 8.64097309], [78.10652924, 8.64097023], [78.10652924, 8.64125061], [78.10597229, 8.64125061], [78.10597229, 8.64153099], [78.10569763, 8.64153099], [78.10569763, 8.64181137], [78.10531616, 8.6418047], [78.10514069, 8.6418047], [78.10514069, 8.64208317], [78.10375214, 8.64208317], [78.10375214, 8.6418047], [78.10320282, 8.64181137], [78.10320282, 8.64153099], [78.1029129, 8.64153099], [78.1029129, 8.64125061], [78.10235596, 8.64125061], [78.10235596, 8.64097023], [78.1020813, 8.64097309], [78.1020813, 8.64069462], [78.10152435, 8.64069462], [78.10152435, 8.6404171], [78.10124969, 8.64042091], [78.10124969, 8.64014053], [78.10067749, 8.64014053], [78.10068512, 8.63869953], [78.10069275, 8.63819408], [78.10124969, 8.63819408], [78.10124969, 8.63791561], [78.10151672, 8.63792133], [78.10151672, 8.63764095], [78.10180664, 8.63764095], [78.10180664, 8.63735962], [78.1020813, 8.63736343], [78.1020813, 8.6370821], [78.10236359, 8.6370821], [78.10236359, 8.63680553], [78.1029129, 8.63681984], [78.1029129, 8.63653088], [78.10320282, 8.63653088], [78.10320282, 8.63624954], [78.10346985, 8.63624954], [78.10346985, 8.63597012], [78.10375214, 8.63597202], [78.10375214, 8.63569355], [78.10430908, 8.63569355], [78.10430908, 8.63541603], [78.10708618, 8.6354208], [78.10708618, 8.63514042], [78.10736084, 8.63514042], [78.10736084, 8.63486004], [78.10791779, 8.63486004], [78.10791779, 8.63458443], [78.10819244, 8.63458443], [78.10819244, 8.63392067], [78.10819244, 8.63319397], [78.10791779, 8.63319397], [78.10791779, 8.63263798], [78.10771942, 8.63264179], [78.1076355, 8.63263798], [78.1076355, 8.63233471], [78.1076355, 8.63208389], [78.10736084, 8.63208389], [78.10736084, 8.6315279], [78.10708618, 8.63153172], [78.10708618, 8.63125038], [78.10652924, 8.63125038], [78.10652924, 8.63097191], [78.10569763, 8.63097191], [78.10569763, 8.63069439], [78.10152435, 8.63069439], [78.10152435, 8.62874985], [78.10124969, 8.62874985], [78.10124969, 8.62791538], [78.10151672, 8.62792015], [78.10151672, 8.62375164], [78.10124969, 8.62375164], [78.10124969, 8.61903095], [78.10151672, 8.61903095], [78.10151672, 8.6181879], [78.10180664, 8.61819458], [78.10180664, 8.61763859], [78.1020813, 8.61764145], [78.1020813, 8.61707973], [78.1029129, 8.6170826], [78.1029129, 8.61736107], [78.10375214, 8.61736107], [78.10373688, 8.61707973], [78.10346985, 8.6170826], [78.10346985, 8.61597347], [78.10180664, 8.61597347], [78.10180664, 8.61486053], [78.10319519, 8.61486053], [78.10319519, 8.61458302], [78.10402679, 8.61458302], [78.10402679, 8.61430359], [78.10624695, 8.61431122], [78.10624695, 8.61403084], [78.10700989, 8.61402893], [78.10708618, 8.61402893], [78.10708618, 8.61377144], [78.10597229, 8.61375141], [78.10597229, 8.61347294], [78.10514069, 8.61347294], [78.10514069, 8.61319542], [78.1048584, 8.61319542], [78.1048584, 8.61291695], [78.10457611, 8.61291885], [78.10457611, 8.61264992], [78.10430908, 8.61264992], [78.10430908, 8.61207962], [78.10263824, 8.61208153], [78.10263824, 8.61236], [78.10180664, 8.61236], [78.10180664, 8.61208153], [78.10124969, 8.61208153], [78.10124969, 8.61152935], [78.1009903, 8.61153126], [78.1009903, 8.61096954], [78.10069275, 8.6109724], [78.10069275, 8.61013794], [78.10041809, 8.6101408], [78.10041809, 8.6093111], [78.1001358, 8.6093111], [78.1001358, 8.60875034], [78.09986115, 8.60875034], [78.09986115, 8.60791588], [78.09958649, 8.60792065], [78.09958649, 8.60625172], [78.09929657, 8.60625172], [78.09929657, 8.60486031], [78.09902954, 8.60486221], [78.09902954, 8.60458374], [78.09874725, 8.60458374], [78.09874725, 8.60430622], [78.0984726, 8.60431004], [78.0984726, 8.60402966], [78.09819794, 8.60402966], [78.09819794, 8.60375023], [78.09791565, 8.60375023], [78.09791565, 8.60347176], [78.09764099, 8.60348129], [78.09764099, 8.60319138], [78.0973587, 8.60319424], [78.0973587, 8.60291576], [78.09707642, 8.60291958], [78.09707642, 8.60207939], [78.09680176, 8.60208416], [78.09680176, 8.60097218], [78.0965271, 8.60097218], [78.0965271, 8.60041809], [78.09707642, 8.60042], [78.09707642, 8.60013962], [78.09764099, 8.60013962], [78.09764099, 8.59985924], [78.09791565, 8.5998621], [78.09791565, 8.59958363], [78.0984726, 8.59958363], [78.0984726, 8.59930611], [78.09958649, 8.59930611], [78.09958649, 8.59958363], [78.09986115, 8.59958363], [78.09986115, 8.5998621], [78.1001358, 8.59985924], [78.1001358, 8.60013962], [78.10041809, 8.60013962], [78.10041809, 8.60042], [78.10069275, 8.60041809], [78.10069275, 8.60069561], [78.10097504, 8.60069561], [78.10097504, 8.60097218], [78.10180664, 8.60096931], [78.10180664, 8.60124969], [78.10263824, 8.60124969], [78.10263824, 8.60069084], [78.10236359, 8.60069561], [78.10236359, 8.60013962], [78.1020813, 8.60013962], [78.1020813, 8.59902954], [78.10180664, 8.59902954], [78.10180664, 8.59847069], [78.1020813, 8.59847355], [78.1020813, 8.59819317], [78.10180664, 8.59819317], [78.10180664, 8.59624863], [78.1009903, 8.59625053], [78.1009903, 8.59653187], [78.10041809, 8.59653187], [78.10041809, 8.59681034], [78.09986115, 8.59680462], [78.09986115, 8.59708309], [78.09902954, 8.59708309], [78.09902954, 8.59736061], [78.0984726, 8.59736061], [78.0984726, 8.59764194], [78.09793091, 8.59764194], [78.09793091, 8.59792042], [78.09513855, 8.59792042], [78.09513855, 8.59708118], [78.09541321, 8.59708309], [78.09541321, 8.59541702], [78.09570312, 8.59542179], [78.09570312, 8.59431171], [78.09597015, 8.59431171], [78.09597015, 8.59402943], [78.09625244, 8.59402943], [78.09625244, 8.59375095], [78.0965271, 8.59375095], [78.0965271, 8.59347057], [78.09680176, 8.59347343], [78.09680176, 8.59319496], [78.09708405, 8.59319496], [78.09708405, 8.59291744], [78.09764099, 8.59291935], [78.09764099, 8.59264088], [78.09793091, 8.59264088], [78.09793091, 8.59236145], [78.09819794, 8.59236145], [78.09819794, 8.59208298], [78.09791565, 8.59208298], [78.09791565, 8.59152699], [78.09764099, 8.59154034], [78.09764099, 8.59125137], [78.0973587, 8.59125137], [78.0973587, 8.5909729], [78.09708405, 8.5909729], [78.09708405, 8.59069538], [78.09680176, 8.59069538], [78.09680176, 8.59041691], [78.09625244, 8.59042072], [78.09625244, 8.5901413], [78.09597015, 8.5901413], [78.09597015, 8.58986092], [78.0956955, 8.58986092], [78.0956955, 8.5895834], [78.09541321, 8.5895834], [78.09541321, 8.58930683], [78.09513855, 8.58931065], [78.09513855, 8.58903122], [78.0945816, 8.58903122], [78.0945816, 8.58875084], [78.09430695, 8.58875084], [78.09430695, 8.5884819], [78.09401703, 8.5884819], [78.09401703, 8.58819008], [78.09430695, 8.58819485], [78.09430695, 8.58791733], [78.0945816, 8.58792114], [78.0945816, 8.58763885], [78.09513855, 8.58763885], [78.09513855, 8.58736134], [78.09541321, 8.58736134], [78.09541321, 8.58708191], [78.0956955, 8.58708191], [78.0956955, 8.58680439], [78.09597015, 8.58681107], [78.09597015, 8.58653069], [78.09625244, 8.58653069], [78.09625244, 8.58625126], [78.09680176, 8.58625126], [78.09680176, 8.58597279], [78.09708405, 8.58597279], [78.09708405, 8.58569527], [78.0973587, 8.58569527], [78.0973587, 8.58347225], [78.09708405, 8.58347225], [78.09708405, 8.58263779], [78.09680176, 8.58263969], [78.09680176, 8.58181095], [78.0965271, 8.58181095], [78.0965271, 8.58125019], [78.09680176, 8.58125019], [78.09680176, 8.58097172], [78.0973587, 8.58097172], [78.0973587, 8.5806942], [78.09764099, 8.5806942], [78.09764099, 8.58041573], [78.09793091, 8.58042145], [78.09793091, 8.58014011], [78.0984726, 8.58014011], [78.0984726, 8.57985973], [78.09874725, 8.57985973], [78.09874725, 8.57958412], [78.0993042, 8.57958412], [78.0993042, 8.57930565], [78.09958649, 8.57931137], [78.09958649, 8.57903004], [78.1001358, 8.57903004], [78.1001358, 8.57874966], [78.10263824, 8.57874966], [78.10263824, 8.57903004], [78.10430908, 8.57903004], [78.10430908, 8.57931137], [78.10569763, 8.57930565], [78.10569763, 8.57958412], [78.10736084, 8.57958412], [78.10736084, 8.57985973], [78.10791779, 8.57985973], [78.10791779, 8.58014011], [78.10819244, 8.58014011], [78.10819244, 8.58042145], [78.10847473, 8.58041573], [78.10847473, 8.5806942], [78.10874939, 8.5806942], [78.10874939, 8.58097172], [78.10930634, 8.58097172], [78.10930634, 8.58125019], [78.10958099, 8.58125019], [78.10958099, 8.58153057], [78.10987091, 8.58153057], [78.10987091, 8.58181095], [78.10958099, 8.58180618], [78.10958099, 8.58236027], [78.10930634, 8.58235073], [78.10930634, 8.58263969], [78.10902405, 8.58263779], [78.10902405, 8.58319378], [78.10874939, 8.58319187], [78.10874939, 8.58374977], [78.1084671, 8.58374977], [78.1084671, 8.58431053], [78.10819244, 8.58430672], [78.10819244, 8.58485985], [78.10986328, 8.58485985], [78.10986328, 8.58458233], [78.11180878, 8.58458233], [78.11180878, 8.58402824], [78.11207581, 8.58403111], [78.11207581, 8.58374977], [78.11235809, 8.58374977], [78.11235809, 8.58319187], [78.11264038, 8.58319378], [78.11264038, 8.58291626], [78.1129303, 8.58292103], [78.1129303, 8.58263969], [78.11319733, 8.58263969], [78.11319733, 8.58207989], [78.11347198, 8.5820837], [78.11347198, 8.58152771], [78.11374664, 8.58153057], [78.11374664, 8.58042145], [78.11402893, 8.58042145], [78.11402893, 8.57985973], [78.11486053, 8.57985973], [78.11486053, 8.58153057], [78.11458588, 8.58152771], [78.11458588, 8.58347225], [78.11486053, 8.58347225], [78.11486053, 8.58458233], [78.11513519, 8.58458233], [78.11513519, 8.58485985], [78.11541748, 8.58485985], [78.11541748, 8.58542061], [78.11569214, 8.58541584], [78.11569214, 8.58569527], [78.11597443, 8.58569527], [78.11597443, 8.58597279], [78.11680603, 8.58597279], [78.11680603, 8.58625126], [78.11708069, 8.58625126], [78.11708069, 8.58653069], [78.11736298, 8.58653069], [78.11736298, 8.58681107], [78.11791992, 8.58680439], [78.11791992, 8.58708191], [78.11819458, 8.58708191], [78.11819458, 8.58736134], [78.11846924, 8.58736134], [78.11846924, 8.58763885], [78.11875153, 8.58763885], [78.11875153, 8.58792114], [78.11930847, 8.58791733], [78.11930847, 8.58819485], [78.11958313, 8.58819008], [78.11958313, 8.5884819], [78.1204071, 8.5884819], [78.1204071, 8.58792114], [78.12069702, 8.58792114], [78.12069702, 8.58736134], [78.12208557, 8.58736134], [78.12208557, 8.58763885], [78.12236023, 8.58763885], [78.12236023, 8.58792114], [78.12291718, 8.58791733], [78.12291718, 8.58819485], [78.12319183, 8.58819008], [78.12319183, 8.5884819], [78.12346649, 8.5884819], [78.12346649, 8.58903122], [78.12374878, 8.5890274], [78.12374878, 8.5895834], [78.12430573, 8.5895834], [78.12430573, 8.58986092], [78.12458038, 8.58986092], [78.12458038, 8.5901413], [78.12513733, 8.5901413], [78.12513733, 8.59042072], [78.12569427, 8.59041691], [78.12569427, 8.59069538], [78.12625122, 8.59069538], [78.12625122, 8.5909729], [78.12680817, 8.5909729], [78.12680817, 8.59125137], [78.12763977, 8.59125137], [78.12763977, 8.59154034], [78.12819672, 8.59154034], [78.12819672, 8.59180927], [78.12875366, 8.59180546], [78.12875366, 8.59208298], [78.12930298, 8.59208298], [78.12930298, 8.59236145], [78.1295929, 8.59236145], [78.1295929, 8.59264088], [78.13014221, 8.59264088], [78.13014221, 8.59291935], [78.13041687, 8.59291744], [78.13041687, 8.59319496], [78.13124847, 8.59319496], [78.13124847, 8.59291744], [78.13318634, 8.59291935], [78.13318634, 8.59264088], [78.13375092, 8.59264088], [78.13375092, 8.59236145], [78.13458252, 8.59236145], [78.13458252, 8.59208298], [78.13597107, 8.59208107], [78.13597107, 8.59375095], [78.13569641, 8.59375095], [78.13569641, 8.59431171], [78.13541412, 8.59430504], [78.13541412, 8.59458256], [78.13485718, 8.59458065], [78.13486481, 8.59486103], [78.13458252, 8.59486103], [78.13458252, 8.59514236], [78.13404083, 8.59514236], [78.13404083, 8.59542179], [78.13375092, 8.59541702], [78.13375092, 8.59569454], [78.13346863, 8.59569454], [78.13346863, 8.59597111], [78.13291931, 8.59597111], [78.13291931, 8.59625053], [78.13263702, 8.59624863], [78.13263702, 8.59708309], [78.13236237, 8.59708309], [78.13236237, 8.59736061], [78.13208008, 8.59736061], [78.13208008, 8.59764194], [78.13181305, 8.59764194], [78.13181305, 8.59792042], [78.13153076, 8.59791756], [78.13153076, 8.59819317], [78.13097382, 8.59819317], [78.13097382, 8.59791756], [78.13124847, 8.59792042], [78.13124847, 8.59681034], [78.13153076, 8.59681034], [78.13153076, 8.59625053], [78.12819672, 8.59625053], [78.12819672, 8.59597111], [78.12763977, 8.59597111], [78.12763977, 8.59569454], [78.12735748, 8.59569454], [78.12735748, 8.59541702], [78.12680817, 8.59542179], [78.12680817, 8.59514236], [78.12625122, 8.59514236], [78.12625122, 8.59486103], [78.12568665, 8.59486103], [78.12568665, 8.59514236], [78.12596893, 8.59514236], [78.12596893, 8.59542179], [78.12625122, 8.59541702], [78.12625122, 8.59569454], [78.12652588, 8.59569454], [78.12652588, 8.59597111], [78.12680817, 8.59597111], [78.12680817, 8.59625053], [78.1279068, 8.59625053], [78.1279068, 8.59653187], [78.12847137, 8.59653187], [78.12847137, 8.59681034], [78.12902832, 8.59680462], [78.12902832, 8.59736061], [78.12930298, 8.59736061], [78.12930298, 8.60236168], [78.12874603, 8.60236168], [78.12874603, 8.60207939], [78.12819672, 8.60208416], [78.12819672, 8.60180569], [78.12763977, 8.60181046], [78.12763977, 8.60153008], [78.12708282, 8.60153008], [78.12708282, 8.60124969], [78.12680817, 8.60124969], [78.12680817, 8.60069084], [78.12652588, 8.60069561], [78.12652588, 8.60013962], [78.12680817, 8.60013962], [78.12680817, 8.59957886], [78.12708282, 8.59958363], [78.12708282, 8.59902668], [78.12735748, 8.59902954], [78.12735748, 8.59847069], [78.12763977, 8.59847355], [78.12763977, 8.59791756], [78.12680817, 8.59792042], [78.12680817, 8.59764194], [78.12568665, 8.59764194], [78.12568665, 8.59736061], [78.1248703, 8.59736061], [78.1248703, 8.59764194], [78.12431335, 8.59764194], [78.12431335, 8.59792042], [78.12346649, 8.59792042], [78.12346649, 8.59764194], [78.12319183, 8.59764194], [78.12319183, 8.59708118], [78.12374878, 8.59708309], [78.12374878, 8.59680462], [78.12431335, 8.59681034], [78.12431335, 8.59653187], [78.1248703, 8.59653187], [78.1248703, 8.59625053], [78.12541962, 8.59625053], [78.12541962, 8.59597111], [78.12513733, 8.59597111], [78.12513733, 8.59569454], [78.12458038, 8.59569454], [78.12458038, 8.59541702], [78.12431335, 8.59542179], [78.12431335, 8.59514236], [78.12374878, 8.59514236], [78.12374878, 8.59458065], [78.12403107, 8.59458256], [78.12403107, 8.59402657], [78.12431335, 8.59402943], [78.12431335, 8.59375095], [78.12458038, 8.59375095], [78.12458038, 8.59347057], [78.12430573, 8.59347343], [78.12430573, 8.59319496], [78.12403107, 8.59319496], [78.12403107, 8.59263897], [78.12374878, 8.59264088], [78.12374878, 8.59236145], [78.12319183, 8.59236145], [78.12319183, 8.59208298], [78.12264252, 8.59208298], [78.12264252, 8.59180546], [78.12210083, 8.59180927], [78.12210083, 8.59154034], [78.1204071, 8.59154034], [78.1204071, 8.59125137], [78.11846924, 8.59125137], [78.11846924, 8.5909729], [78.11819458, 8.5909729], [78.11819458, 8.59069538], [78.11791992, 8.59069538], [78.11791992, 8.59041691], [78.11763763, 8.59042072], [78.11763763, 8.5901413], [78.11736298, 8.5901413], [78.11736298, 8.58986092], [78.11707306, 8.58986092], [78.11680603, 8.58986092], [78.11680603, 8.5895834], [78.11653137, 8.5895834], [78.11653137, 8.58930683], [78.11624908, 8.58931065], [78.11624908, 8.58903122], [78.11567688, 8.58903122], [78.11567688, 8.58875084], [78.11541748, 8.58875084], [78.11541748, 8.5884819], [78.11514282, 8.5884819], [78.11514282, 8.58819008], [78.11458588, 8.58819485], [78.11458588, 8.58791733], [78.11429596, 8.58792114], [78.11429596, 8.58763885], [78.11402893, 8.58763885], [78.11402893, 8.58708477], [78.11374664, 8.58708191], [78.11374664, 8.58652878], [78.11347198, 8.58653069], [78.11347198, 8.58625126], [78.11319733, 8.58625126], [78.11319733, 8.58597279], [78.11291504, 8.58597279], [78.11291504, 8.58569527], [78.10986328, 8.58569527], [78.10986328, 8.58625126], [78.10958099, 8.58625126], [78.10958099, 8.58681107], [78.10930634, 8.58680439], [78.10930634, 8.58763885], [78.10901642, 8.58763885], [78.10901642, 8.58875084], [78.10874939, 8.58875084], [78.10874939, 8.5895834], [78.1084671, 8.58957958], [78.10847473, 8.58986092], [78.10819244, 8.58986092], [78.10819244, 8.5901413], [78.10791779, 8.5901413], [78.10791779, 8.59042072], [78.1076355, 8.59041691], [78.1076355, 8.59069538], [78.10736084, 8.59069538], [78.10736084, 8.5909729], [78.10541534, 8.5909729], [78.10541534, 8.59069538], [78.10430908, 8.59069538], [78.10430908, 8.5909729], [78.10373688, 8.59097099], [78.10375214, 8.59125137], [78.10346985, 8.59125137], [78.10346985, 8.59154034], [78.1029129, 8.59154034], [78.1029129, 8.59180927], [78.10263824, 8.59180546], [78.10263824, 8.59208298], [78.1020813, 8.59208298], [78.1020813, 8.59236145], [78.10180664, 8.59236145], [78.10180664, 8.59375095], [78.1020813, 8.59375095], [78.1020813, 8.59514236], [78.10263824, 8.59514236], [78.10263824, 8.59458065], [78.1029129, 8.59458256], [78.1029129, 8.59347343], [78.10319519, 8.59347343], [78.10319519, 8.59291744], [78.10458374, 8.59291744], [78.10458374, 8.59319496], [78.1048584, 8.59319496], [78.1048584, 8.59347343], [78.10542297, 8.59347057], [78.10542297, 8.59375095], [78.10569763, 8.59375095], [78.10569763, 8.59402943], [78.10597229, 8.59402943], [78.10597229, 8.59514236], [78.10569763, 8.59514236], [78.10569763, 8.59653187], [78.10541534, 8.5965271], [78.10541534, 8.59736061], [78.10514069, 8.59736061], [78.10514069, 8.59792042], [78.1048584, 8.59791756], [78.1048584, 8.59847355], [78.10457611, 8.59847069], [78.10457611, 8.59902954], [78.10430908, 8.59902954], [78.10430908, 8.59930992], [78.10402679, 8.59930992], [78.10402679, 8.60181046], [78.10430908, 8.60180569], [78.10430908, 8.60319424], [78.10457611, 8.60319138], [78.10457611, 8.60348129], [78.1048584, 8.60348129], [78.1048584, 8.60402966], [78.10514069, 8.60402966], [78.10514069, 8.60431004], [78.10541534, 8.60430622], [78.10541534, 8.60458374], [78.10569763, 8.60458374], [78.10569763, 8.60486221], [78.10597229, 8.60486031], [78.10597229, 8.60542011], [78.10624695, 8.6054163], [78.10624695, 8.60569382], [78.10652924, 8.60569382], [78.10652924, 8.60597229], [78.10736084, 8.60597038], [78.10736084, 8.60625172], [78.10819244, 8.60624981], [78.10819244, 8.60652828], [78.10901642, 8.60652065], [78.10901642, 8.60681057], [78.10958099, 8.6068058], [78.10958099, 8.60708427], [78.11013794, 8.60708046], [78.11013794, 8.60764027], [78.11069489, 8.60764027], [78.11069489, 8.60819435], [78.11042023, 8.60818958], [78.11042023, 8.60903072], [78.11013794, 8.60903072], [78.11013794, 8.6093111], [78.10986328, 8.60930634], [78.10986328, 8.60986233], [78.10958099, 8.60986042], [78.10958099, 8.61042118], [78.10930634, 8.61041641], [78.10930634, 8.6109724], [78.10958099, 8.61096954], [78.10958099, 8.61124992], [78.10987091, 8.61124992], [78.10987091, 8.61153126], [78.11013794, 8.61152935], [78.11013794, 8.61208153], [78.11042023, 8.61208153], [78.11042023, 8.61236], [78.11235809, 8.61236], [78.11235809, 8.61180687], [78.11264038, 8.61181068], [78.11264038, 8.61069202], [78.11291504, 8.61069393], [78.11291504, 8.61013794], [78.11319733, 8.6101408], [78.11319733, 8.60986042], [78.11347198, 8.60986233], [78.11347198, 8.60958195], [78.11374664, 8.60958195], [78.11374664, 8.60930634], [78.11402893, 8.6093111], [78.11402893, 8.60903072], [78.11429596, 8.60903072], [78.11429596, 8.60875034], [78.11458588, 8.60875034], [78.11458588, 8.60847187], [78.11513519, 8.60847187], [78.11513519, 8.60819435], [78.11569214, 8.60819435], [78.11569214, 8.60791588], [78.1159668, 8.60792065], [78.1159668, 8.60764027], [78.11653137, 8.60764027], [78.11653137, 8.60735989], [78.11567688, 8.60735989], [78.11567688, 8.60681057], [78.11541748, 8.60681057], [78.11541748, 8.60597038], [78.11513519, 8.60597229], [78.11513519, 8.60486221], [78.11486053, 8.60486221], [78.11486053, 8.60458374], [78.11458588, 8.60458374], [78.11458588, 8.60430622], [78.11429596, 8.60431004], [78.11429596, 8.60402966], [78.11402893, 8.60402966], [78.11402893, 8.60375023], [78.11374664, 8.60375023], [78.11374664, 8.60347176], [78.11347198, 8.60348129], [78.11347198, 8.60291958], [78.11319733, 8.60291958], [78.11319733, 8.60264015], [78.1129303, 8.60264015], [78.1129303, 8.60236168], [78.11264038, 8.60236168], [78.11264038, 8.60208416], [78.11235809, 8.60208416], [78.11235809, 8.60152817], [78.11207581, 8.60153008], [78.11207581, 8.60096931], [78.11180878, 8.60097218], [78.11180878, 8.60013962], [78.11235809, 8.60013962], [78.11235809, 8.59985924], [78.11271667, 8.5998621], [78.11291504, 8.5998621], [78.11291504, 8.59958363], [78.11347198, 8.59958363], [78.11347198, 8.59930611], [78.11429596, 8.59930992], [78.11429596, 8.59902954], [78.11514282, 8.59902954], [78.11514282, 8.59875202], [78.11567688, 8.59875202], [78.11567688, 8.59847069], [78.11653137, 8.59847355], [78.11653137, 8.59819317], [78.11708069, 8.59819317], [78.11708069, 8.59791756], [78.11791992, 8.59792042], [78.11791992, 8.59764194], [78.11846924, 8.59764194], [78.11846924, 8.59736061], [78.12069702, 8.59736061], [78.12069702, 8.59764194], [78.12152863, 8.59764194], [78.12152863, 8.59792042], [78.12208557, 8.59791756], [78.12208557, 8.59819317], [78.12236023, 8.59819126], [78.12236023, 8.59875202], [78.12264252, 8.59874916], [78.12264252, 8.59958363], [78.12208557, 8.59958363], [78.12208557, 8.5998621], [78.12152863, 8.59985924], [78.12152863, 8.60013962], [78.12097168, 8.60013962], [78.12097168, 8.60042], [78.12014008, 8.60041809], [78.12014008, 8.60069561], [78.11930847, 8.60069561], [78.11930847, 8.60097218], [78.11846924, 8.60096931], [78.11846924, 8.60124969], [78.11763763, 8.60124969], [78.11763763, 8.60153008], [78.11680603, 8.60153008], [78.11680603, 8.60181046], [78.11708069, 8.60180569], [78.11708069, 8.60208416], [78.11736298, 8.60208416], [78.11736298, 8.60236168], [78.11763763, 8.60236168], [78.11763763, 8.60291958], [78.11791992, 8.60291958], [78.11791992, 8.60348129], [78.11763763, 8.60348129], [78.11763763, 8.60402966], [78.11736298, 8.60402775], [78.11736298, 8.60458374], [78.11708069, 8.60458183], [78.11708069, 8.60513973], [78.11680603, 8.60513973], [78.11680603, 8.60542011], [78.11708069, 8.6054163], [78.11708069, 8.60569382], [78.11736298, 8.60569382], [78.11736298, 8.60597229], [78.11902618, 8.60597229], [78.11902618, 8.60569382], [78.12014008, 8.60569382], [78.12014008, 8.60597229], [78.12124634, 8.60597229], [78.12124634, 8.60569382], [78.12208557, 8.60569382], [78.12208557, 8.6054163], [78.12430573, 8.6054163], [78.12430573, 8.60569382], [78.12458038, 8.60569382], [78.12458038, 8.60652828], [78.12430573, 8.60652828], [78.12430573, 8.60708427], [78.12403107, 8.60708046], [78.12403107, 8.60764027], [78.12346649, 8.60764027], [78.12346649, 8.60903072], [78.12430573, 8.60902786], [78.12430573, 8.61069393], [78.12403107, 8.61069393], [78.12403107, 8.61319542], [78.12291718, 8.61319542], [78.12291718, 8.61291695], [78.12181091, 8.61291885], [78.12181091, 8.61264992], [78.12152863, 8.61264992], [78.12152863, 8.61236], [78.12124634, 8.61236], [78.12124634, 8.61208153], [78.12097168, 8.61207962], [78.12097168, 8.61291885], [78.12152863, 8.61291695], [78.12152863, 8.61347294], [78.12181091, 8.61347008], [78.12181091, 8.61431122], [78.12208557, 8.61430359], [78.12208557, 8.61486053], [78.12236023, 8.61486053], [78.12236023, 8.6154213], [78.12264252, 8.61541653], [78.12264252, 8.615695], [78.12291718, 8.61569023], [78.12291718, 8.61625099], [78.12319183, 8.61625099], [78.12319183, 8.61680889], [78.12346649, 8.61680889], [78.12346649, 8.61653137], [78.12374878, 8.61653137], [78.12374878, 8.61625099], [78.12431335, 8.61625099], [78.12431335, 8.61597061], [78.12458038, 8.61597347], [78.12458038, 8.615695], [78.12486267, 8.615695], [78.12486267, 8.61541653], [78.12569427, 8.61541653], [78.12569427, 8.615695], [78.12596893, 8.61569023], [78.12596893, 8.61625099], [78.12625122, 8.61625099], [78.12625122, 8.61680889], [78.12596893, 8.61680889], [78.12596893, 8.61875057], [78.12541962, 8.61875057], [78.12541962, 8.61903095], [78.1248703, 8.61903095], [78.1248703, 8.61930943], [78.12458038, 8.61930466], [78.12458038, 8.61958313], [78.12403107, 8.61958313], [78.12403107, 8.61986065], [78.12346649, 8.61986065], [78.12346649, 8.62014103], [78.12319183, 8.62014103], [78.12319183, 8.62041855], [78.12291718, 8.62041664], [78.12291718, 8.62069511], [78.12264252, 8.62069511], [78.12264252, 8.62097263], [78.12208557, 8.62097263], [78.12208557, 8.6212492], [78.12180328, 8.6212492], [78.12180328, 8.62152672], [78.12152863, 8.62152004], [78.12152863, 8.62181187], [78.12124634, 8.62180519], [78.12124634, 8.62208271], [78.12097168, 8.6220808], [78.12097168, 8.62292194], [78.12124634, 8.62292194], [78.12124634, 8.62403202], [78.12152863, 8.62403202], [78.12152863, 8.62458992], [78.12181091, 8.62458992], [78.12181091, 8.62541962], [78.12208557, 8.62541771], [78.12208557, 8.62597084], [78.12236023, 8.62597084], [78.12236023, 8.62624931], [78.12264252, 8.62624931], [78.12264252, 8.62681007], [78.12291718, 8.62680626], [78.12291718, 8.62708378], [78.12319183, 8.62708092], [78.12319183, 8.62765121], [78.12346649, 8.62765121], [78.12346649, 8.62792015], [78.12374878, 8.62791538], [78.12374878, 8.62819576], [78.12403107, 8.62819576], [78.12403107, 8.62874985], [78.12430573, 8.62874985], [78.12430573, 8.62958431], [78.12403107, 8.62958241], [78.12403107, 8.63153172], [78.12430573, 8.6315279], [78.12430573, 8.63347244], [78.12458038, 8.633461], [78.12458038, 8.63514042], [78.1248703, 8.63514042], [78.1248703, 8.63624954], [78.12513733, 8.63624954], [78.12513733, 8.63653088], [78.12541962, 8.63653088], [78.12541962, 8.63681984], [78.12569427, 8.63680553], [78.12569427, 8.6370821], [78.12596893, 8.6370821], [78.12596893, 8.63736343], [78.12652588, 8.63735962], [78.12652588, 8.63764095], [78.12680817, 8.63764095], [78.12680817, 8.63792133], [78.12708282, 8.63791561], [78.12708282, 8.63819408], [78.12735748, 8.63819408], [78.12735748, 8.6384716], [78.12791443, 8.6384716], [78.12791443, 8.63680553], [78.12763977, 8.63681984], [78.12763977, 8.63568974], [78.12735748, 8.63569355], [78.12735748, 8.63069439], [78.12708282, 8.63069439], [78.12708282, 8.62708378], [78.12735748, 8.62708378], [78.12735748, 8.62680626], [78.12708282, 8.62681007], [78.12708282, 8.62319088], [78.12735748, 8.62319469], [78.12735748, 8.61902905], [78.12763977, 8.61903095], [78.12763977, 8.61625099], [78.1279068, 8.61625099], [78.1279068, 8.61514091], [78.12819672, 8.61514091], [78.12819672, 8.61403084], [78.12847137, 8.61403084], [78.12847137, 8.61291885], [78.12874603, 8.61291885], [78.12874603, 8.61153126], [78.12902832, 8.61153126], [78.12902832, 8.61042118], [78.12930298, 8.61042118], [78.12930298, 8.6093111], [78.1295929, 8.6093111], [78.1295929, 8.60846996], [78.12985992, 8.60847187], [78.12985992, 8.60791588], [78.13014221, 8.60792065], [78.13014221, 8.60708046], [78.13041687, 8.60708427], [78.13041687, 8.60624981], [78.13069153, 8.60625172], [78.13069153, 8.60569191], [78.13097382, 8.60569382], [78.13097382, 8.60486221], [78.13124847, 8.60486221], [78.13124847, 8.60402775], [78.13153076, 8.60402966], [78.13153076, 8.60348129], [78.13181305, 8.60348129], [78.13181305, 8.60291958], [78.13208008, 8.60291958], [78.13208008, 8.60236168], [78.13236237, 8.60236168], [78.13236237, 8.60180569], [78.13263702, 8.60181046], [78.13263702, 8.60124969], [78.13291931, 8.60124969], [78.13291931, 8.60069084], [78.13319397, 8.60069561], [78.13319397, 8.60013962], [78.13346863, 8.60013962], [78.13346863, 8.59957886], [78.13375092, 8.59958363], [78.13375092, 8.59902668], [78.13404083, 8.59902954], [78.13404083, 8.59847069], [78.13430786, 8.59847355], [78.13430786, 8.59791756], [78.13458252, 8.59792042], [78.13458252, 8.59736061], [78.13486481, 8.59736061], [78.13486481, 8.59680462], [78.13513947, 8.59681034], [78.13513947, 8.59625053], [78.13540649, 8.59625053], [78.13540649, 8.59569073], [78.13569641, 8.59569454], [78.13569641, 8.59513855], [78.13597107, 8.59514236], [78.13597107, 8.59458065], [78.13625336, 8.59458256], [78.13625336, 8.59402657], [78.13652802, 8.59402943], [78.13652802, 8.59347057], [78.13680267, 8.59347343], [78.13680267, 8.59291744], [78.13710022, 8.59291935], [78.13710022, 8.59236145], [78.13735962, 8.59236145], [78.13735962, 8.59152699], [78.13764191, 8.59154034], [78.13764191, 8.59097099], [78.13791656, 8.5909729], [78.13791656, 8.59069538], [78.13819122, 8.59069538], [78.13819122, 8.58986092], [78.13847351, 8.58986092], [78.13846588, 8.58875084], [78.13874817, 8.58875084], [78.13874817, 8.58681107], [78.13846588, 8.58681107], [78.13846588, 8.58514118], [78.13819122, 8.58514118], [78.13819122, 8.58347034], [78.13791656, 8.58347225], [78.13791656, 8.58236027], [78.13764191, 8.58236027], [78.13764191, 8.58125019], [78.13735962, 8.58125019], [78.13735962, 8.58041573], [78.13710022, 8.58042145], [78.13710022, 8.57931137], [78.1368103, 8.57931137], [78.1368103, 8.57874966], [78.13652802, 8.57874966], [78.13652802, 8.5781889], [78.13625336, 8.57819366], [78.13625336, 8.57736206], [78.13597107, 8.57736206], [78.13597107, 8.5759716], [78.13569641, 8.5759716], [78.13569641, 8.57458401], [78.13541412, 8.57458401], [78.13541412, 8.5731926], [78.13513947, 8.5731926], [78.13513947, 8.57208443], [78.13486481, 8.57208443], [78.13486481, 8.57124901], [78.13458252, 8.57125187], [78.13458252, 8.57014179], [78.13430786, 8.57014179], [78.13430786, 8.56931019], [78.13404083, 8.56931019], [78.13404083, 8.56847095], [78.13375092, 8.56847095], [78.13375092, 8.56763935], [78.13346863, 8.56763935], [78.13346863, 8.56652927], [78.13318634, 8.56652927], [78.13318634, 8.56569099], [78.13291931, 8.56569481], [78.13291931, 8.56375122], [78.13263702, 8.56375122], [78.13263702, 8.55736256], [78.13236237, 8.5573597], [78.13236237, 8.55624962], [78.13208008, 8.55624962], [78.13208008, 8.55540943], [78.13180542, 8.55541611], [78.13180542, 8.55458355], [78.13153076, 8.55458355], [78.13153076, 8.55347157], [78.13124847, 8.55347157], [78.13124847, 8.55291557], [78.13096619, 8.5529213], [78.13096619, 8.55237103], [78.13069153, 8.55237103], [78.13069153, 8.55181122], [78.13041687, 8.55181122], [78.13041687, 8.55125046], [78.13014221, 8.55125046], [78.13014221, 8.55069447], [78.12985992, 8.55069447], [78.12985992, 8.5504179], [78.1295929, 8.55042267], [78.1295929, 8.54986191], [78.12930298, 8.54986191], [78.12930298, 8.54930592], [78.12902832, 8.54930973], [78.12902832, 8.54875183], [78.12874603, 8.54875183], [78.12874603, 8.54819107], [78.12847137, 8.54819584], [78.12847137, 8.54763985], [78.12819672, 8.54763985], [78.12819672, 8.54708099], [78.12791443, 8.54708385], [78.12791443, 8.54625034], [78.12763977, 8.54625034], [78.12763977, 8.54541779], [78.12735748, 8.54541969], [78.12735748, 8.54458141], [78.12708282, 8.54458332], [78.12708282, 8.54374886], [78.12680817, 8.54374886], [78.12680817, 8.54291725], [78.12652588, 8.54292202], [78.12652588, 8.54208088], [78.12625122, 8.54208279], [78.12625122, 8.54125118], [78.12596893, 8.54125118], [78.12596893, 8.54041672], [78.12568665, 8.54043102], [78.12568665, 8.53931046], [78.12541962, 8.53931046], [78.12541962, 8.53818989], [78.12513733, 8.53819466], [78.12513733, 8.53708267], [78.12486267, 8.53708267], [78.12486267, 8.5359726], [78.12458038, 8.5359726], [78.12458038, 8.53486061], [78.12430573, 8.53486061], [78.12430573, 8.53374767], [78.12403107, 8.53375053], [78.12403107, 8.5320797], [78.12374878, 8.5320816], [78.12374878, 8.52986336], [78.12347412, 8.52986336], [78.12347412, 8.52764034], [78.12319183, 8.52764034], [78.12319183, 8.52542973], [78.12291718, 8.52542973], [78.12291718, 8.52347183], [78.12264252, 8.52347183], [78.12264252, 8.52180576], [78.12236023, 8.52180958], [78.12236023, 8.51653194], [78.12264252, 8.51653194], [78.12264252, 8.51431179], [78.12291718, 8.51431179], [78.12291718, 8.51320171], [78.12319183, 8.51320171], [78.12319183, 8.51264095], [78.12346649, 8.51264095], [78.12346649, 8.51208115], [78.12374878, 8.51208305], [78.12374878, 8.51180458], [78.12403107, 8.51180935], [78.12403107, 8.51125145], [78.12431335, 8.51125145], [78.12431335, 8.51097107], [78.12458038, 8.51097298], [78.12458038, 8.51041698], [78.1248703, 8.51041889], [78.1248703, 8.50986099], [78.12513733, 8.50986099], [78.12513733, 8.50958347], [78.12541962, 8.50958347], [78.12541962, 8.50902653], [78.12568665, 8.5090313], [78.12568665, 8.50875092], [78.12596893, 8.50875092], [78.12596893, 8.50819016], [78.12625122, 8.50819492], [78.12625122, 8.50763893], [78.12652588, 8.50764084], [78.12652588, 8.50736141], [78.12680817, 8.50736141], [78.12680817, 8.50680542], [78.12708282, 8.50680923], [78.12708282, 8.50597], [78.12680817, 8.50597286], [78.12680817, 8.50485992], [78.12652588, 8.50485992], [78.12652588, 8.50430679], [78.12625122, 8.50432014], [78.12625122, 8.50374985], [78.12596893, 8.50374985], [78.12596893, 8.50319386], [78.12569427, 8.50319386], [78.12569427, 8.50263786], [78.12596893, 8.50264072], [78.12596893, 8.50181103], [78.12625122, 8.50181103], [78.12625122, 8.50126171], [78.12652588, 8.50126171], [78.12652588, 8.50069046], [78.12680817, 8.50069427], [78.12680817, 8.50014019], [78.12708282, 8.50014019], [78.12708282, 8.49986172], [78.12735748, 8.49986172], [78.12735748, 8.49931145], [78.12763977, 8.49931145], [78.12763977, 8.49903011], [78.12819672, 8.49903011], [78.12819672, 8.49874973], [78.12847137, 8.49874973], [78.12847137, 8.49847031], [78.12902832, 8.49847221], [78.12902832, 8.49819374], [78.12958527, 8.49819374], [78.12958527, 8.49791622], [78.12985992, 8.49792004], [78.12985992, 8.49763966], [78.13041687, 8.49763966], [78.13041687, 8.4970789], [78.13014221, 8.49708366], [78.13014221, 8.49652767], [78.12985992, 8.49652958], [78.12985992, 8.49625015], [78.12958527, 8.49625015], [78.12958527, 8.49569416], [78.12930298, 8.49569416], [78.12930298, 8.49541569], [78.12902832, 8.49542046], [78.12902832, 8.4948597], [78.12875366, 8.4948597], [78.12875366, 8.49458408], [78.12847137, 8.49458408], [78.12847137, 8.49402809], [78.12819672, 8.49403], [78.12819672, 8.49374962], [78.1279068, 8.49374962], [78.1279068, 8.49318886], [78.12763977, 8.49319363], [78.12763977, 8.49291801], [78.12735748, 8.49291992], [78.12735748, 8.49263954], [78.12708282, 8.49263954], [78.12708282, 8.49236202], [78.12680817, 8.49236202], [78.12680817, 8.49208355], [78.12652588, 8.49208355], [78.12652588, 8.49180603], [78.12625122, 8.49180984], [78.12625122, 8.49153042], [78.12596893, 8.49153042], [78.12596893, 8.49097061], [78.12569427, 8.49097443], [78.12569427, 8.49069309], [78.12541962, 8.49069309], [78.12541962, 8.49041843], [78.12513733, 8.49042034], [78.12513733, 8.48986053], [78.12486267, 8.48986053], [78.12486267, 8.48958302], [78.12458038, 8.48958302], [78.12458038, 8.48902702], [78.12431335, 8.48903179], [78.12431335, 8.48875141], [78.12403107, 8.48875141], [78.12403107, 8.48819542], [78.12374878, 8.48819542], [78.12374878, 8.48791695], [78.12346649, 8.48792171], [78.12346649, 8.48763943], [78.12319183, 8.48763943], [78.12319183, 8.48708057], [78.12291718, 8.48708344], [78.12291718, 8.48680496], [78.12264252, 8.48680973], [78.12264252, 8.48625088], [78.12236023, 8.48625088], [78.12236023, 8.48597145], [78.12208557, 8.48597336], [78.12208557, 8.48569489], [78.12180328, 8.48569489], [78.12180328, 8.48513889], [78.12152863, 8.48513889], [78.12152863, 8.48486137], [78.12124634, 8.48486137], [78.12124634, 8.4845829], [78.12097168, 8.4845829], [78.12097168, 8.48430538], [78.1204071, 8.4843092], [78.1204071, 8.48403072], [78.12014008, 8.48403072], [78.12014008, 8.4837513], [78.11985779, 8.4837513], [78.11985779, 8.48347282], [78.11958313, 8.48347282], [78.11958313, 8.4831953], [78.11930847, 8.4831953], [78.11930847, 8.48291683], [78.11875153, 8.48292065], [78.11875153, 8.48264122], [78.11846924, 8.48264122], [78.11846924, 8.48236084], [78.11818695, 8.48236084], [78.11818695, 8.48208046], [78.11791992, 8.48208332], [78.11791992, 8.48180485], [78.11763763, 8.48181152], [78.11763763, 8.48153114], [78.11736298, 8.48153114], [78.11736298, 8.48124886], [78.11708069, 8.48125076], [78.11708069, 8.48097324], [78.11680603, 8.48097324], [78.11680603, 8.48069477], [78.11653137, 8.48069477], [78.11653137, 8.48041725], [78.11624908, 8.48042107], [78.11624908, 8.48012924], [78.11597443, 8.48013878], [78.11597443, 8.47986126], [78.11569214, 8.47986126], [78.11569214, 8.47958469], [78.11541748, 8.47958469], [78.11541748, 8.47930431], [78.11514282, 8.47931099], [78.11514282, 8.47903061], [78.11486053, 8.47903061], [78.11486053, 8.47875118], [78.11458588, 8.47875118], [78.11458588, 8.47847271], [78.11430359, 8.47847271], [78.11430359, 8.47819519], [78.11402893, 8.47819519], [78.11402893, 8.47791576], [78.11374664, 8.47792053], [78.11374664, 8.47764111], [78.11347198, 8.47764111], [78.11347198, 8.47735977], [78.11319733, 8.47735977], [78.11319733, 8.47708225], [78.1129303, 8.47709084], [78.1129303, 8.47681141], [78.11235809, 8.47681141], [78.11235809, 8.47653103], [78.11207581, 8.47653103], [78.11207581, 8.47624969], [78.11180878, 8.47624969], [78.11180878, 8.47597027], [78.11152649, 8.47597218], [78.11152649, 8.4756937], [78.11125183, 8.4756937], [78.11125183, 8.47541618], [78.11096954, 8.47542095], [78.11096954, 8.47513962], [78.11068726, 8.47513962], [78.11068726, 8.47486019], [78.11042023, 8.47486019], [78.11042023, 8.4743042], [78.11013794, 8.47431087], [78.11013794, 8.47403145], [78.10987091, 8.47403145], [78.10987091, 8.47375011], [78.10958099, 8.47375011], [78.10958099, 8.47346973], [78.10930634, 8.47347164], [78.10930634, 8.47319412], [78.10902405, 8.47319412], [78.10902405, 8.47291565], [78.10874939, 8.47292137], [78.10874939, 8.47264004], [78.1084671, 8.47264004], [78.1084671, 8.47235966], [78.10819244, 8.47236156], [78.10819244, 8.47208405], [78.10791779, 8.47208405], [78.10791779, 8.47152805], [78.10764313, 8.47152996], [78.10764313, 8.47124958], [78.10736084, 8.47124958], [78.10736084, 8.47096062], [78.10708618, 8.47097206], [78.10708618, 8.47069359], [78.10680389, 8.47069359], [78.10680389, 8.47041798], [78.10652924, 8.47042274], [78.10652924, 8.47014046], [78.10624695, 8.47014046], [78.10624695, 8.46986198], [78.10597229, 8.46986198], [78.10597229, 8.46930599], [78.10569763, 8.46931267], [78.10569763, 8.46903038], [78.10542297, 8.46903038], [78.10542297, 8.46875191], [78.10514069, 8.46875191], [78.10514069, 8.46846867], [78.1048584, 8.46847153], [78.1048584, 8.46819401], [78.10458374, 8.46819401], [78.10458374, 8.46791553], [78.10402679, 8.4679203], [78.10402679, 8.46763992], [78.10373688, 8.46763992], [78.10373688, 8.46735954], [78.10346985, 8.4673624], [78.10346985, 8.46708393], [78.10319519, 8.46708393], [78.10319519, 8.46680641], [78.1029129, 8.46681023], [78.1029129, 8.46652985], [78.10263824, 8.46652985], [78.10263824, 8.46625042], [78.1020813, 8.46625042], [78.1020813, 8.46597195], [78.10180664, 8.46597195], [78.10180664, 8.46569347], [78.10152435, 8.46569347], [78.10152435, 8.46541786], [78.10124969, 8.46541977], [78.10124969, 8.46515083], [78.1009903, 8.46515083], [78.1009903, 8.46486187], [78.10067749, 8.46486187], [78.10067749, 8.46458054], [78.1001358, 8.46458435], [78.1001358, 8.46430492], [78.09986115, 8.46430969], [78.09986115, 8.46403027], [78.09958649, 8.46403027], [78.09958649, 8.46375179], [78.09929657, 8.46375179], [78.09929657, 8.46347141], [78.09902954, 8.46347141], [78.09902954, 8.4631958], [78.09874725, 8.4631958], [78.09874725, 8.46291733], [78.0984726, 8.46292019], [78.0984726, 8.46236134], [78.09819794, 8.46236134], [78.09819794, 8.46208286], [78.09793091, 8.46208954], [78.09793091, 8.46181202], [78.09764099, 8.46181202], [78.09764099, 8.46153164], [78.0973587, 8.46153164], [78.0973587, 8.46125126], [78.09707642, 8.46125126], [78.09707642, 8.46097088], [78.09680176, 8.46097088], [78.09680176, 8.46069527], [78.0965271, 8.46069527], [78.0965271, 8.46041679], [78.09625244, 8.46041965], [78.09625244, 8.45985889], [78.09597015, 8.4598608], [78.09597015, 8.45958328], [78.0956955, 8.45958328], [78.0956955, 8.45930481], [78.09541321, 8.45930958], [78.09541321, 8.45901966], [78.09513855, 8.4590292], [78.09513855, 8.45874882], [78.09485626, 8.45875072], [78.09485626, 8.4584713], [78.0945816, 8.45847321], [78.0945816, 8.45791721], [78.09430695, 8.45792198], [78.09430695, 8.45764065], [78.09401703, 8.45764065], [78.09401703, 8.45736122], [78.09375, 8.45736122], [78.09375, 8.45680523], [78.09348297, 8.4568119], [78.09348297, 8.45653057], [78.09319305, 8.45653057], [78.09319305, 8.45625114], [78.09236145, 8.45625114], [78.09236145, 8.45597267], [78.09124756, 8.45597267], [78.09124756, 8.45569515], [78.09069824, 8.45569515], [78.09069061, 8.45541668], [78.09041595, 8.45542145], [78.09041595, 8.45514107], [78.08985901, 8.45514107], [78.08985901, 8.45486069], [78.08957672, 8.45486069], [78.08957672, 8.45458031], [78.0890274, 8.45458317], [78.0890274, 8.4543047], [78.08873749, 8.45431137], [78.08873749, 8.45375061], [78.08847046, 8.45375061], [78.08847046, 8.45347023], [78.0881958, 8.45347309], [78.0881958, 8.45319462], [78.08791351, 8.45319462], [78.08791351, 8.45263863], [78.08763885, 8.45264053], [78.08763885, 8.45207977], [78.0873642, 8.45208168], [78.0873642, 8.45152855], [78.08708191, 8.45153141], [78.08708191, 8.4509697], [78.08680725, 8.45097256], [78.08680725, 8.4495821], [78.08708191, 8.4495821], [78.08708191, 8.44847202], [78.08680725, 8.44847202], [78.08680725, 8.44819355], [78.08652496, 8.44819355], [78.08652496, 8.44791603], [78.08625031, 8.4479208], [78.08625031, 8.44764042], [78.08599091, 8.44764042], [78.08599091, 8.44707966], [78.08569336, 8.44708443], [78.08569336, 8.44680595], [78.0854187, 8.44681072], [78.0854187, 8.44653034], [78.08513641, 8.44653034], [78.08513641, 8.44624996], [78.08486176, 8.44624996], [78.08486176, 8.44596958], [78.0845871, 8.44597244], [78.0845871, 8.44569397], [78.08430481, 8.44569397], [78.08430481, 8.44541645], [78.08403015, 8.44542122], [78.08403015, 8.44514179], [78.08374786, 8.44514179], [78.08374786, 8.44458199], [78.08347321, 8.44458199], [78.08347321, 8.44430637], [78.08319092, 8.44431114], [78.08319092, 8.44402122], [78.08291626, 8.4440279], [78.08291626, 8.44375038], [78.0826416, 8.44375038], [78.0826416, 8.44347191], [78.08235931, 8.44347191], [78.08235931, 8.44319439], [78.08208466, 8.44319439], [78.08208466, 8.44291592], [78.08180237, 8.44291973], [78.08180237, 8.44236183], [78.08152771, 8.44236183], [78.08152771, 8.44208431], [78.08125305, 8.44208431], [78.08125305, 8.44180584], [78.08097076, 8.44180965], [78.08097076, 8.44153023], [78.08069611, 8.44153023], [78.08069611, 8.44124985], [78.08040619, 8.44124985], [78.08040619, 8.44069099], [78.08013916, 8.44069576], [78.08013916, 8.44013977], [78.07985687, 8.44013977], [78.07985687, 8.43985939], [78.07958221, 8.43986225], [78.07958221, 8.43930626], [78.07930756, 8.43931007], [78.07930756, 8.43875027], [78.07902527, 8.43875027], [78.07902527, 8.43847084], [78.07875061, 8.43847084], [78.07875061, 8.43791771], [78.07847595, 8.43791962], [78.07847595, 8.43735886], [78.07819366, 8.43736172], [78.07819366, 8.43708324], [78.07791901, 8.43708324], [78.07791901, 8.43680477], [78.07763672, 8.43680954], [78.07763672, 8.43625164], [78.07736206, 8.43625164], [78.07736206, 8.43597126], [78.07707977, 8.43597126], [78.07707977, 8.43569469], [78.07680511, 8.43569469], [78.07680511, 8.4351387], [78.07653046, 8.43514156], [78.07653046, 8.43484974], [78.07624817, 8.43486118], [78.07624817, 8.43458271], [78.07597351, 8.43458271], [78.07597351, 8.43430519], [78.07569122, 8.43431187], [78.07569122, 8.4337492], [78.07541656, 8.4337492], [78.07541656, 8.43347263], [78.07514191, 8.43347263], [78.07514191, 8.43319511], [78.07485962, 8.43319511], [78.07485962, 8.43291664], [78.07459259, 8.43291855], [78.07459259, 8.43264103], [78.07430267, 8.43264103], [78.07430267, 8.43208122], [78.07402802, 8.43208313], [78.07402802, 8.43180466], [78.07376099, 8.43181038], [78.07376099, 8.43153095], [78.07347107, 8.43153095], [78.07347107, 8.43125057], [78.07319641, 8.43125057], [78.07319641, 8.43097115], [78.07291412, 8.43097305], [78.07291412, 8.43069458], [78.07263947, 8.43069458], [78.07263947, 8.43013859], [78.07235718, 8.43014145], [78.07235718, 8.42986107], [78.07208252, 8.42986107], [78.07208252, 8.4295826], [78.07180786, 8.4295826], [78.07180786, 8.42930698], [78.0715332, 8.42930889], [78.0715332, 8.42875099], [78.07125092, 8.42875099], [78.07125092, 8.42847061], [78.07096863, 8.42847347], [78.07096863, 8.428195], [78.07069397, 8.428195], [78.07069397, 8.42763901], [78.07041931, 8.42764091], [78.07041931, 8.42736053], [78.07013702, 8.42736053], [78.07013702, 8.42708302], [78.06986237, 8.42708302], [78.06986237, 8.42652893], [78.06958008, 8.42653084], [78.06958008, 8.42625141], [78.06930542, 8.42625141], [78.06930542, 8.42569542], [78.06903076, 8.42569542], [78.06903076, 8.42541695], [78.06874847, 8.42541885], [78.06874847, 8.42514133], [78.06846619, 8.42514133], [78.06846619, 8.42457962], [78.06819153, 8.42458153], [78.06819153, 8.42430687], [78.06791687, 8.42431068], [78.06791687, 8.42375088], [78.06762695, 8.42375088], [78.06762695, 8.42346954], [78.06735992, 8.4234724], [78.06735992, 8.42291641], [78.06708527, 8.42291641], [78.06708527, 8.42263794], [78.06680298, 8.4226408], [78.06680298, 8.42208004], [78.06652832, 8.42208195], [78.06652832, 8.42152786], [78.06624603, 8.42153072], [78.06624603, 8.42125034], [78.06597137, 8.42125034], [78.06597137, 8.42069435], [78.06569672, 8.42069435], [78.06569672, 8.42041588], [78.0654068, 8.42042065], [78.0654068, 8.4198513], [78.06513977, 8.41985989], [78.06513977, 8.41902828], [78.06485748, 8.41903019], [78.06485748, 8.41736031], [78.06458282, 8.41736221], [78.06458282, 8.41625023], [78.06430817, 8.41625023], [78.06430817, 8.41541576], [78.06402588, 8.41541958], [78.06402588, 8.41457939], [78.06375122, 8.41458416], [78.06375122, 8.41374969], [78.06346893, 8.41374969], [78.06346893, 8.41263962], [78.06318665, 8.41263962], [78.06318665, 8.41152954], [78.06291962, 8.41152954], [78.06291962, 8.41042042], [78.06263733, 8.41042042], [78.06263733, 8.40931034], [78.06236267, 8.40931034], [78.06236267, 8.4079113], [78.06208038, 8.40791702], [78.06208038, 8.40624905], [78.06182098, 8.40625095], [78.06182098, 8.40541935], [78.06153107, 8.40541935], [78.06153107, 8.40487003], [78.06124878, 8.40487003], [78.06124878, 8.40430927], [78.06096649, 8.40430927], [78.06096649, 8.40207958], [78.06069183, 8.4020834], [78.06069183, 8.40125084], [78.06041718, 8.40125084], [78.06041718, 8.39958], [78.06014252, 8.39958286], [78.06014252, 8.39847279], [78.05986023, 8.39847279], [78.05986023, 8.39791679], [78.0595932, 8.39792061], [78.0595932, 8.39764118], [78.05930328, 8.39764118], [78.05930328, 8.39708042], [78.05902863, 8.39708233], [78.05902863, 8.39680672], [78.0587616, 8.39681053], [78.0587616, 8.39653111], [78.05847168, 8.39653111], [78.05847168, 8.39597034], [78.05819702, 8.39597225], [78.05819702, 8.39541626], [78.0579071, 8.39542103], [78.0579071, 8.39457989], [78.05764008, 8.3945837], [78.05764008, 8.39375019], [78.05735779, 8.39375019], [78.05735779, 8.39263821], [78.05708313, 8.39264011], [78.05708313, 8.39181137], [78.05680847, 8.39181137], [78.05680847, 8.39097023], [78.05652618, 8.39097214], [78.05652618, 8.38986206], [78.05625153, 8.38987064], [78.05625153, 8.38903046], [78.05596924, 8.38903046], [78.05596924, 8.38792038], [78.05568695, 8.38792038], [78.05568695, 8.38652992], [78.05541992, 8.38652992], [78.05541992, 8.38514042], [78.05513763, 8.38514042], [78.05513763, 8.38374043], [78.05486298, 8.38374901], [78.05486298, 8.38291836], [78.05513763, 8.38292027], [78.05513763, 8.38236141], [78.05541992, 8.38236141], [78.05541992, 8.38180542], [78.05568695, 8.38181019], [78.05568695, 8.38125134], [78.05541992, 8.38125134], [78.05541992, 8.38152981], [78.05513763, 8.38152981], [78.05513763, 8.38181019], [78.05486298, 8.38180542], [78.05486298, 8.38208294], [78.05347443, 8.38208294], [78.05347443, 8.38180542], [78.05291748, 8.38181019], [78.05291748, 8.38152981], [78.05124664, 8.38152981], [78.05124664, 8.38181019], [78.04985809, 8.38181019], [78.04985809, 8.38152981], [78.04959106, 8.38152981], [78.04959106, 8.38041973], [78.04985809, 8.38041973], [78.04985809, 8.38013935], [78.05042267, 8.38013935], [78.05042267, 8.37986088], [78.05069733, 8.37986088], [78.05069733, 8.37958336], [78.05124664, 8.37958336], [78.05124664, 8.37930489], [78.05152893, 8.37930965], [78.05152893, 8.37902927], [78.05262756, 8.37902927], [78.05262756, 8.37874889], [78.05430603, 8.37874889], [78.05430603, 8.37902927], [78.05458069, 8.37902927], [78.05458069, 8.37930965], [78.05513763, 8.37930489], [78.05513763, 8.37958336], [78.05541992, 8.37958336], [78.05541992, 8.37986088], [78.05596924, 8.37986088], [78.05596924, 8.38013935], [78.05680847, 8.38013935], [78.05680847, 8.37986088], [78.05735779, 8.37986088], [78.05735779, 8.37958336], [78.05764008, 8.37958336], [78.05764008, 8.37930489], [78.0579071, 8.37930965], [78.0579071, 8.37902927], [78.05819702, 8.37902927], [78.05819702, 8.37874889], [78.05847168, 8.37874889], [78.05847168, 8.37819481], [78.05874634, 8.37819481], [78.05874634, 8.37791729], [78.05902863, 8.37793064], [78.05902863, 8.37764072], [78.05930328, 8.37764072], [78.05930328, 8.3773613], [78.05958557, 8.3773613], [78.05958557, 8.37708282], [78.05986023, 8.37708282], [78.05986023, 8.37680531], [78.06014252, 8.37681198], [78.06014252, 8.37653065], [78.06041718, 8.37653065], [78.06041718, 8.37597084], [78.06069183, 8.37597084], [78.06069183, 8.37569523], [78.06097412, 8.37569523], [78.06097412, 8.37541676], [78.06124878, 8.37542057], [78.06124878, 8.37514114], [78.06318665, 8.37514114], [78.06318665, 8.37542057], [78.06402588, 8.37541676], [78.06402588, 8.37569523], [78.06513977, 8.37569523], [78.06513977, 8.37541676], [78.06597137, 8.37542057], [78.06597137, 8.37514114], [78.06652832, 8.37514114], [78.06652832, 8.37485886], [78.06708527, 8.37486076], [78.06708527, 8.37458324], [78.06764221, 8.37458324], [78.06764221, 8.37402916], [78.06791687, 8.37403107], [78.06791687, 8.37347126], [78.06819153, 8.37347317], [78.06819153, 8.3726387], [78.06791687, 8.37264061], [78.06791687, 8.37236118], [78.06764221, 8.37236118], [78.06764221, 8.37180424], [78.06735992, 8.37180424], [78.06735992, 8.37125111], [78.06708527, 8.37125111], [78.06708527, 8.37069511], [78.06680298, 8.37069511], [78.06680298, 8.37041569], [78.0654068, 8.37042141], [78.0654068, 8.37014103], [78.06402588, 8.37014103], [78.06402588, 8.3698597], [78.06291962, 8.3698597], [78.06291962, 8.36958218], [78.05764008, 8.36958218], [78.05764008, 8.36930656], [78.05652618, 8.36931133], [78.05652618, 8.36903095], [78.05568695, 8.36903095], [78.05568695, 8.36874104], [78.05541992, 8.36874962], [78.05541992, 8.3684721], [78.05486298, 8.3684721], [78.05486298, 8.36819363], [78.05458069, 8.36819363], [78.05458069, 8.36791611], [78.05403137, 8.36792088], [78.05403137, 8.36763954], [78.05179596, 8.36763954], [78.05179596, 8.36736012], [78.04985809, 8.36736012], [78.04985809, 8.36708355], [78.04763794, 8.36708355], [78.04763794, 8.36680603], [78.04736328, 8.3668108], [78.04736328, 8.36653137], [78.04682159, 8.36653137], [78.04682159, 8.36625004], [78.04653168, 8.36625004], [78.04653168, 8.36596966], [78.04597473, 8.36597157], [78.04597473, 8.36569405], [78.04569244, 8.36570072], [78.04569244, 8.3654213], [78.04502869, 8.36541843], [78.04429626, 8.3654213], [78.04429626, 8.36513996], [78.04374695, 8.36513996], [78.04374695, 8.36485958], [78.04291534, 8.36486244], [78.04291534, 8.36458206], [78.0423584, 8.36458206], [78.0423584, 8.36430645], [78.04152679, 8.36431122], [78.04152679, 8.36403275], [78.04068756, 8.36403275], [78.04068756, 8.36375046], [78.03985596, 8.36375046], [78.03985596, 8.36347198], [78.03874969, 8.36347198], [78.03874969, 8.36319447], [78.03791809, 8.36319447], [78.03791809, 8.36291599], [78.03542328, 8.36292267], [78.03542328, 8.36264038], [78.03514099, 8.36264038], [78.03514099, 8.36236191], [78.03458405, 8.36236191], [78.03458405, 8.36208439], [78.03375244, 8.36208439], [78.03375244, 8.36180592], [78.03263855, 8.36180973], [78.03263855, 8.3615303], [78.03180695, 8.3615303], [78.03180695, 8.36124992], [78.02958679, 8.36124992], [78.02958679, 8.36096859], [78.02902985, 8.3609724], [78.02902985, 8.36069584], [78.0284729, 8.36069584], [78.0284729, 8.36041641], [78.02819824, 8.36042023], [78.02819061, 8.36013985], [78.0276413, 8.36013985], [78.0276413, 8.35986042], [78.02708435, 8.35986233], [78.02708435, 8.35958385], [78.0265274, 8.35958385], [78.0265274, 8.35930634], [78.02571106, 8.35931015], [78.02571106, 8.35902977], [78.0229187, 8.35902977], [78.0229187, 8.35875034], [78.02236176, 8.35875034], [78.02236176, 8.35847187], [78.0220871, 8.35847187], [78.0220871, 8.3581934], [78.02153015, 8.3581934], [78.02153015, 8.35791779], [78.02124786, 8.35791969], [78.02124786, 8.35764027], [78.02069092, 8.35764027], [78.02069092, 8.35736179], [78.02041626, 8.35736179], [78.02041626, 8.35708427], [78.01985931, 8.35708427], [78.01985931, 8.35680485], [78.01930237, 8.35680485], [78.01930237, 8.35652733], [78.01875305, 8.35653019], [78.01875305, 8.35624886], [78.01819611, 8.35624886], [78.01819611, 8.35597134], [78.01763916, 8.35597134], [78.01763916, 8.35569572], [78.01680756, 8.35569572], [78.01680756, 8.35541534], [78.01625061, 8.35542202], [78.01625061, 8.35514164], [78.01568604, 8.35514164], [78.01568604, 8.35486126], [78.01513672, 8.35486126], [78.01513672, 8.35458279], [78.01486206, 8.35458279], [78.01486206, 8.35430527], [78.01431274, 8.35431194], [78.01431274, 8.3540287], [78.01403046, 8.3540287], [78.01403046, 8.35376072], [78.01348114, 8.35376072], [78.01348114, 8.35346889], [78.01319122, 8.3534708], [78.01319122, 8.35319519], [78.01264191, 8.35319519], [78.01264191, 8.35291672], [78.01235962, 8.35291958], [78.01235962, 8.3526392], [78.01180267, 8.3526392], [78.01180267, 8.35236073], [78.01152802, 8.35236073], [78.01152802, 8.35208321], [78.01125336, 8.35208321], [78.01125336, 8.35180473], [78.01097107, 8.35181046], [78.01097107, 8.35153198], [78.01071167, 8.35153198], [78.01071167, 8.35125065], [78.01042175, 8.35125065], [78.01042175, 8.35153198], [78.00985718, 8.35153198], [78.00985718, 8.35181046], [78.00958252, 8.35180473], [78.00958252, 8.35208321], [78.00930786, 8.3520813], [78.00930786, 8.3526392], [78.00818634, 8.3526392], [78.00818634, 8.35236073], [78.00763702, 8.35236073], [78.00763702, 8.35208321], [78.00708008, 8.35208321], [78.00708008, 8.35180473], [78.00624847, 8.35181046], [78.00624847, 8.35153198], [78.00569153, 8.35153198], [78.00569153, 8.35125065], [78.00514221, 8.35125065], [78.00514221, 8.35097122], [78.00485992, 8.35097313], [78.00485992, 8.35069466], [78.00457764, 8.35070038], [78.00457764, 8.35042191], [78.00428772, 8.35042191], [78.00428772, 8.35014057], [78.00374603, 8.35014057], [78.00374603, 8.34986115], [78.00347137, 8.34986115], [78.00347137, 8.34958267], [78.00319672, 8.34958267], [78.00319672, 8.34930515], [78.00263977, 8.34930515], [78.00263977, 8.34958267], [78.00096893, 8.34958267], [78.00096893, 8.34930515], [77.99986267, 8.34931183], [77.99958038, 8.34931183], [77.99958038, 8.34875107], [77.99874878, 8.34875107], [77.99874878, 8.34847069], [77.99819183, 8.3484726], [77.99819183, 8.34819508], [77.99764252, 8.34819508], [77.99764252, 8.3479166], [77.9970932, 8.34792137], [77.9970932, 8.34762955], [77.99652863, 8.34763908], [77.99652863, 8.34736061], [77.99569702, 8.34736061], [77.99569702, 8.34708309], [77.99514008, 8.34708309], [77.99514008, 8.34680462], [77.99458313, 8.34681129], [77.99458313, 8.34653091], [77.99402618, 8.34653091], [77.99402618, 8.34625053], [77.99346924, 8.34625053], [77.99346924, 8.34597015], [77.99291992, 8.34597301], [77.99291992, 8.34569454], [77.99208069, 8.34569454], [77.99208069, 8.34541702], [77.99153137, 8.34542084], [77.99153137, 8.34514141], [77.9909668, 8.34514141], [77.9909668, 8.34486103], [77.99041748, 8.34486103], [77.99041748, 8.3445816], [77.98986053, 8.3445816], [77.98986053, 8.34430695], [77.98902893, 8.34430885], [77.98902893, 8.34403133], [77.98847198, 8.34403133], [77.98847198, 8.34375095], [77.98792267, 8.34375095], [77.98792267, 8.34346962], [77.98764038, 8.34347343], [77.98764038, 8.34319401], [77.98735809, 8.34319401], [77.98735809, 8.34292984], [77.98680878, 8.34292126], [77.98680878, 8.34264088], [77.98654175, 8.34264088], [77.98654175, 8.34235954], [77.98625183, 8.34236336], [77.98625183, 8.34208202], [77.98596954, 8.34208202], [77.98596954, 8.34180641], [77.98542023, 8.34181976], [77.98542023, 8.3415308], [77.98319244, 8.3415308], [77.98319244, 8.34125042], [77.98236084, 8.34125042], [77.98236084, 8.34097195], [77.98208618, 8.34097195], [77.98208618, 8.34069443], [77.98152924, 8.34069443], [77.98152924, 8.34041595], [77.98097229, 8.34042072], [77.98097229, 8.34014034], [77.98040771, 8.34014034], [77.98040771, 8.33985996], [77.98014069, 8.33985996], [77.98014069, 8.33958435], [77.9798584, 8.33958435], [77.9798584, 8.33930588], [77.97957611, 8.33931065], [77.97957611, 8.33903027], [77.97930908, 8.33903027], [77.97930908, 8.33875942], [77.97902679, 8.33875942], [77.97902679, 8.33847046], [77.97875214, 8.33847237], [77.97875214, 8.33819389], [77.97846985, 8.33819389], [77.97846985, 8.33791637], [77.97820282, 8.33792114], [77.97820282, 8.33764172], [77.9779129, 8.33764172], [77.9779129, 8.33736038], [77.97763824, 8.33736229], [77.97763824, 8.33708382], [77.97736359, 8.33708191], [77.97736359, 8.3368063], [77.9770813, 8.33681107], [77.9770813, 8.33652973], [77.97651672, 8.33652973], [77.97651672, 8.33625031], [77.97624969, 8.33625031], [77.97624969, 8.33597183], [77.97597504, 8.33597183], [77.97597504, 8.33569431], [77.97569275, 8.33569431], [77.97569275, 8.33541584], [77.9751358, 8.33541965], [77.9751358, 8.33514023], [77.97460175, 8.33514023], [77.97460175, 8.33485985], [77.97402954, 8.33485985], [77.97402954, 8.33458424], [77.9734726, 8.33458424], [77.9734726, 8.33430576], [77.97292328, 8.33430958], [77.97292328, 8.33403015], [77.9723587, 8.33403015], [77.9723587, 8.33374977], [77.97180176, 8.33374977], [77.97180176, 8.33346939], [77.97125244, 8.33347225], [77.97125244, 8.33319378], [77.9706955, 8.33319378], [77.9706955, 8.33291626], [77.97013855, 8.33292007], [77.97013855, 8.33263111], [77.96847534, 8.33263969], [77.96847534, 8.33236217], [77.96819305, 8.33236217], [77.96819305, 8.3320837], [77.96763611, 8.3320837], [77.96763611, 8.33180618], [77.96736145, 8.33181], [77.96736145, 8.33152962], [77.96679688, 8.33152962], [77.96679688, 8.33096886], [77.96708679, 8.33097076], [77.96708679, 8.33041763], [77.9659729, 8.33041954], [77.9659729, 8.33014202], [77.96540833, 8.33014202], [77.96540833, 8.32986164], [77.96485901, 8.32986164], [77.96485901, 8.32958317], [77.96430206, 8.32958984], [77.96430206, 8.32931042], [77.96375275, 8.32931042], [77.96375275, 8.32903194], [77.96347046, 8.32903194], [77.96347046, 8.32891083], [77.96347046, 8.3287487], [77.96318054, 8.32879257], [77.9631958, 8.32847118], [77.96260834, 8.32846928], [77.96263885, 8.3281908], [77.9623642, 8.32819462], [77.9623642, 8.3279171], [77.96208191, 8.32792187], [77.96208191, 8.32764244], [77.96180725, 8.32764244], [77.96180725, 8.3273592], [77.96152496, 8.32736111], [77.96152496, 8.32708263], [77.96125031, 8.32708263], [77.96125031, 8.32680511], [77.96098328, 8.32682133], [77.96098328, 8.32652855], [77.96069336, 8.32652855], [77.96069336, 8.32625103], [77.9604187, 8.32625103], [77.9604187, 8.32597065], [77.96013641, 8.32597256], [77.96013641, 8.32569313], [77.95986176, 8.32569313], [77.95986176, 8.32513905], [77.95960236, 8.32514095], [77.95960236, 8.32486057], [77.95903015, 8.32486057], [77.95903015, 8.32458305], [77.95819092, 8.32458305], [77.95819092, 8.32430458], [77.95791626, 8.3243103], [77.95791626, 8.32403088], [77.9576416, 8.32403088], [77.9576416, 8.32375145], [77.95735931, 8.32375145], [77.95735931, 8.32346153], [77.95680237, 8.32347298], [77.95680237, 8.32319546], [77.95652771, 8.32319546], [77.95652771, 8.32291698], [77.95623779, 8.32291889], [77.95623779, 8.32208061], [77.95597076, 8.32208347], [77.95597076, 8.32152653], [77.95569611, 8.3215313], [77.95569611, 8.32097054], [77.95541382, 8.3209734], [77.95541382, 8.32069492], [77.95513916, 8.32069492], [77.95513916, 8.32013893], [77.95485687, 8.32014084], [77.95485687, 8.31986141], [77.95458221, 8.31986141], [77.95458221, 8.31958294], [77.95430756, 8.31958294], [77.95430756, 8.31819534], [77.95458221, 8.31819534], [77.95458221, 8.31763935], [77.95430756, 8.31764984], [77.95430756, 8.31735992], [77.95402527, 8.31735992], [77.95402527, 8.31486034], [77.95375061, 8.31486034], [77.95375061, 8.31402779], [77.95291901, 8.31403065], [77.95291901, 8.31375027], [77.95236206, 8.31375027], [77.95236206, 8.31319427], [77.95207977, 8.31319427], [77.95207977, 8.3129158], [77.95181274, 8.31292057], [77.95181274, 8.31264019], [77.95096588, 8.31264019], [77.95096588, 8.31236172], [77.95014191, 8.31236172], [77.95014191, 8.31208038], [77.94985962, 8.3120842], [77.94985962, 8.31180573], [77.94930267, 8.31181145], [77.94930267, 8.31152058], [77.94875336, 8.31152821], [77.94875336, 8.31124973], [77.94790649, 8.31124973], [77.94790649, 8.31097031], [77.94736481, 8.31097221], [77.94736481, 8.31069374], [77.94680786, 8.31069374], [77.94680786, 8.31041622], [77.94625092, 8.31042004], [77.94625092, 8.31013966], [77.94541931, 8.31013966], [77.94541931, 8.30986023], [77.94486237, 8.30986214], [77.94486237, 8.30958366], [77.94458008, 8.30958366], [77.94458008, 8.30930614], [77.94403076, 8.30931091], [77.94403076, 8.30902958], [77.94319153, 8.30902958], [77.94319153, 8.30875015], [77.94291687, 8.30875015], [77.94291687, 8.30847168], [77.94264221, 8.30847168], [77.94264221, 8.30819416], [77.94235992, 8.30819416], [77.94235992, 8.30791569], [77.9420929, 8.30792046], [77.9420929, 8.30764008], [77.94180298, 8.30764008], [77.94180298, 8.3073597], [77.94152832, 8.3073597], [77.94152832, 8.30708408], [77.94097137, 8.30708408], [77.94097137, 8.30680561], [77.94069672, 8.30681038], [77.94069672, 8.30653], [77.94013977, 8.30653], [77.94013977, 8.30624962], [77.93958282, 8.30624962], [77.93958282, 8.30596924], [77.93930817, 8.3059721], [77.93930817, 8.30569363], [77.93875122, 8.30569363], [77.93875122, 8.30541801], [77.93681335, 8.30541992], [77.93681335, 8.30513954], [77.93653107, 8.30513954], [77.93653107, 8.30486202], [77.93596649, 8.30486202], [77.93596649, 8.30458069], [77.93569183, 8.30458355], [77.93569183, 8.30430603], [77.93543243, 8.30430984], [77.93543243, 8.30403042], [77.93486023, 8.30403042], [77.93486023, 8.30375195], [77.9345932, 8.30375195], [77.9345932, 8.30347061], [77.93430328, 8.30347061], [77.93430328, 8.30319309], [77.93374634, 8.30319309], [77.93374634, 8.30291843], [77.93347168, 8.30292034], [77.93347168, 8.30265141], [77.93319702, 8.30265141], [77.93319702, 8.30236053], [77.93273163, 8.30236053], [77.93235779, 8.30236053], [77.93235779, 8.30208302], [77.93208313, 8.30208302], [77.93208313, 8.30180454], [77.93180847, 8.30181026], [77.93180847, 8.30153179], [77.93152618, 8.30153179], [77.93152618, 8.30125237], [77.93096924, 8.30125237], [77.93096924, 8.30097103], [77.93013763, 8.30097103], [77.93013763, 8.30041695], [77.92986298, 8.30041981], [77.92986298, 8.29958057], [77.92958069, 8.29958344], [77.92958069, 8.29902744], [77.92949677, 8.29902744], [77.92903137, 8.29902935], [77.92903137, 8.29875088], [77.92874908, 8.29875088], [77.92874908, 8.2982502], [77.92847443, 8.29819489], [77.92847443, 8.29791737], [77.92791748, 8.29791927], [77.92791748, 8.29763889], [77.92764282, 8.29763889], [77.92764282, 8.29736137], [77.92569733, 8.29736137], [77.92569733, 8.2970829], [77.92319489, 8.2970829], [77.92319489, 8.29680538], [77.92292023, 8.29681015], [77.92292023, 8.29652023], [77.92208099, 8.29652691], [77.92208099, 8.2962513], [77.92151642, 8.2962513], [77.92151642, 8.29597092], [77.92124939, 8.29597092], [77.92124939, 8.2956953], [77.92097473, 8.2956953], [77.92097473, 8.29541683], [77.92012787, 8.2954216], [77.92012787, 8.29514122], [77.91929626, 8.29514122], [77.91929626, 8.29486084], [77.91902924, 8.29486084], [77.91902924, 8.29458332], [77.91680908, 8.29458332], [77.91680908, 8.29430485], [77.91625214, 8.29431152], [77.91625214, 8.29403114], [77.91570282, 8.29403114], [77.91570282, 8.29374886], [77.9154129, 8.29375076], [77.9154129, 8.29347324], [77.91485596, 8.29348183], [77.91485596, 8.29319], [77.91430664, 8.29319477], [77.91430664, 8.29291725], [77.91400909, 8.29292107], [77.91400909, 8.29264069], [77.91374969, 8.29264069], [77.91374969, 8.29236126], [77.91347504, 8.29236126], [77.91347504, 8.29208469], [77.91291809, 8.29208469], [77.91291809, 8.29180527], [77.9126358, 8.29181099], [77.9126358, 8.29153061], [77.91236115, 8.29153061], [77.91236115, 8.29125118], [77.91179657, 8.29125118], [77.91179657, 8.29096985], [77.91152954, 8.29097271], [77.91152954, 8.29069519], [77.9109726, 8.29069519], [77.9109726, 8.29041672], [77.91042328, 8.29042053], [77.91042328, 8.29014111], [77.91014099, 8.29014111], [77.91014099, 8.28985977], [77.90957642, 8.28985977], [77.90957642, 8.28958035], [77.90875244, 8.28958225], [77.90875244, 8.28930664], [77.90791321, 8.28931141], [77.90791321, 8.28903103], [77.90735626, 8.28903103], [77.90735626, 8.28874969], [77.90651703, 8.28874969], [77.90651703, 8.28847027], [77.90597534, 8.28847218], [77.90597534, 8.2881937], [77.9054184, 8.2881937], [77.9054184, 8.28791618], [77.90512848, 8.28792095], [77.90512848, 8.28764057], [77.90458679, 8.28764057], [77.90458679, 8.28736019], [77.9043045, 8.28736019], [77.9043045, 8.28708363], [77.90374756, 8.28708363], [77.90374756, 8.2868042], [77.90319824, 8.28681087], [77.90319061, 8.28653145], [77.90206909, 8.28653145], [77.90206909, 8.28625011], [77.9015274, 8.28625011], [77.9015274, 8.28596973], [77.90097046, 8.28597164], [77.90097046, 8.28569412], [77.9006958, 8.28569412], [77.9006958, 8.28541565], [77.90040588, 8.28542137], [77.90040588, 8.28514004], [77.90013885, 8.28514004], [77.90013885, 8.28485966], [77.8998642, 8.28486156], [77.8998642, 8.28458405], [77.89930725, 8.28458405], [77.89930725, 8.28430557], [77.89903259, 8.28431129], [77.89903259, 8.28402996], [77.89875031, 8.28402996], [77.89875031, 8.28382969], [77.89875031, 8.28374958], [77.89848328, 8.28374958], [77.89848328, 8.28347015], [77.89819336, 8.28347206], [77.89819336, 8.28291607], [77.8979187, 8.28292274], [77.8979187, 8.28264046], [77.89763641, 8.28264046], [77.89763641, 8.28236198], [77.89736176, 8.28236198], [77.89736176, 8.28208447], [77.8970871, 8.28208447], [77.8970871, 8.28180599], [77.89679718, 8.28181267], [77.89679718, 8.28154182], [77.89653015, 8.28154182], [77.89653015, 8.28125], [77.89624786, 8.28125], [77.89624786, 8.28096962], [77.89597321, 8.28097153], [77.89597321, 8.28069401], [77.89569092, 8.28069401], [77.89569092, 8.28013992], [77.89541626, 8.28013992], [77.89541626, 8.27985954], [77.8951416, 8.2798624], [77.8951416, 8.27930641], [77.89485931, 8.27931023], [77.89485931, 8.27902985], [77.8951416, 8.27902985], [77.8951416, 8.27875042], [77.89485931, 8.27875042], [77.89485931, 8.27847195], [77.89457703, 8.27848053], [77.89457703, 8.27819061], [77.89402771, 8.27819443], [77.89402771, 8.27791786], [77.89375305, 8.27791977], [77.89375305, 8.27764034], [77.89318848, 8.27764034], [77.89318848, 8.27708054], [77.89291382, 8.27708435], [77.89291382, 8.27680588], [77.89263916, 8.27680969], [77.89263916, 8.27653027], [77.89235687, 8.27653027], [77.89235687, 8.27625179], [77.89208221, 8.27625179], [77.89208221, 8.27597141], [77.89180756, 8.27597141], [77.89180756, 8.2756958], [77.89152527, 8.2756958], [77.89152527, 8.27541542], [77.89125061, 8.27542019], [77.89125061, 8.27513885], [77.89097595, 8.27513885], [77.89097595, 8.27486134], [77.89013672, 8.27486134], [77.89013672, 8.27458286], [77.88986206, 8.27458286], [77.88986206, 8.27430534], [77.88931274, 8.27431202], [77.88931274, 8.27374935], [77.88903046, 8.27374935], [77.88903046, 8.27319527], [77.88819122, 8.27319527], [77.88819122, 8.27291679], [77.88735962, 8.27291965], [77.88735962, 8.27263927], [77.8840332, 8.27263927], [77.8840332, 8.27235031], [77.88375092, 8.2723608], [77.88375092, 8.27208328], [77.88319397, 8.27208328], [77.88319397, 8.27180481], [77.88291931, 8.27180958], [77.88291931, 8.2715292], [77.88263702, 8.2715292], [77.88263702, 8.27125072], [77.88208008, 8.27125072], [77.88208008, 8.2709713], [77.88180542, 8.27097321], [77.88180542, 8.27069473], [77.88153076, 8.27069473], [77.88153076, 8.27041721], [77.88095856, 8.27042198], [77.88095856, 8.27014065], [77.88014221, 8.27014065], [77.88014221, 8.26986122], [77.87985992, 8.26986122], [77.87985992, 8.26958275], [77.87930298, 8.26958275], [77.87930298, 8.26930523], [77.87847137, 8.2693119], [77.87847137, 8.26903057], [77.87789917, 8.26903057], [77.87789917, 8.26875114], [77.87763977, 8.26875114], [77.87763977, 8.26847267], [77.87708282, 8.26847267], [77.87708282, 8.26819515], [77.87680817, 8.26819515], [77.87680817, 8.26791668], [77.87625122, 8.26792145], [77.87625122, 8.26764107], [77.87596893, 8.26764107], [77.87596893, 8.26736069], [77.87504578, 8.26736069], [77.87430573, 8.26736069], [77.87430573, 8.26708317], [77.87319183, 8.26708317], [77.87319183, 8.2668047], [77.8720932, 8.26681232], [77.8720932, 8.26653957], [77.87097168, 8.26653957], [77.87097168, 8.26625061], [77.8704071, 8.26625061], [77.8704071, 8.26597118], [77.86985779, 8.26597309], [77.86985779, 8.26569462], [77.86930847, 8.26569462], [77.86930847, 8.2654171], [77.86875153, 8.26542091], [77.86875153, 8.26514053], [77.86846924, 8.26514053], [77.86846924, 8.26486111], [77.86819458, 8.26486111], [77.86819458, 8.26458263], [77.86708069, 8.26458263], [77.86708069, 8.26486111], [77.86541748, 8.26486111], [77.86541748, 8.26458263], [77.86486053, 8.26458263], [77.86486053, 8.26430416], [77.86429596, 8.26431084], [77.86429596, 8.26403141], [77.86402893, 8.26403141], [77.86402893, 8.26375103], [77.86347198, 8.26375103], [77.86347198, 8.26347923], [77.86292267, 8.26347923], [77.86292267, 8.26319027], [77.86264038, 8.26319504], [77.86264038, 8.26291561], [77.86207581, 8.26292133], [77.86207581, 8.26264095], [77.86152649, 8.26264095], [77.86152649, 8.26235962], [77.86125183, 8.26236343], [77.86125183, 8.2620821], [77.86069489, 8.2620821], [77.86069489, 8.26180744], [77.8601532, 8.26181126], [77.8601532, 8.26153088], [77.85958099, 8.26153088], [77.85958099, 8.26124954], [77.85901642, 8.26124954], [77.85901642, 8.26097012], [77.85847473, 8.26097202], [77.85847473, 8.26069355], [77.85791779, 8.26069355], [77.85791779, 8.26041603], [77.85736084, 8.26041603], [77.85736084, 8.26013756], [77.85678864, 8.26014042], [77.85678864, 8.25986004], [77.85624695, 8.25986004], [77.85624695, 8.25958443], [77.85569763, 8.25958443], [77.85569763, 8.25930595], [77.8548584, 8.25931072], [77.8548584, 8.2590313], [77.85401917, 8.2590313], [77.85401917, 8.25874996], [77.85320282, 8.25874996], [77.85320282, 8.25846958], [77.85236359, 8.25847244], [77.85236359, 8.25819397], [77.85152435, 8.25819397], [77.85152435, 8.25791645], [77.85098267, 8.25792122], [77.85098267, 8.25764275], [77.84986115, 8.25764275], [77.84986115, 8.25735092], [77.84902954, 8.25736237], [77.84902954, 8.25708199], [77.8484726, 8.25708199], [77.8484726, 8.25680637], [77.84764099, 8.25681114], [77.84764099, 8.25653267], [77.84680176, 8.25653267], [77.84680176, 8.25625038], [77.84597015, 8.25625038], [77.84597015, 8.25597191], [77.84513855, 8.25597191], [77.84513855, 8.25569439], [77.84402466, 8.25569439], [77.84402466, 8.25541592], [77.84319305, 8.25541973], [77.84319305, 8.2551403], [77.84236145, 8.2551403], [77.84236145, 8.25486183], [77.8401413, 8.25486183], [77.8401413, 8.25458431], [77.83958435, 8.25458431], [77.83958435, 8.25430584], [77.83904266, 8.25430965], [77.83904266, 8.25403023], [77.8381958, 8.25403023], [77.8381958, 8.25374985], [77.83735657, 8.25374985], [77.83735657, 8.25346947], [77.83680725, 8.25347233], [77.83680725, 8.25319386], [77.83569336, 8.25319386], [77.83569336, 8.25291634], [77.83429718, 8.25292015], [77.83429718, 8.25263977], [77.83374786, 8.25263977], [77.83374786, 8.25236034], [77.83319092, 8.25236225], [77.83319092, 8.25208378], [77.83235931, 8.25208378], [77.83235931, 8.25180626], [77.83152771, 8.25181007], [77.83152771, 8.25154114], [77.83040619, 8.25154114], [77.83040619, 8.25125027], [77.82958221, 8.25125027], [77.82958221, 8.25097179], [77.82847595, 8.25097179], [77.82847595, 8.25069332], [77.82707977, 8.25069332], [77.82707977, 8.25041771], [77.82653046, 8.25041962], [77.82653046, 8.25014019], [77.82541656, 8.25014019], [77.82541656, 8.24985886], [77.82430267, 8.24986172], [77.82430267, 8.2495842], [77.82347107, 8.2495842], [77.82347107, 8.24930477], [77.82235718, 8.24930954], [77.82235718, 8.24903202], [77.8215332, 8.24903202], [77.8215332, 8.24875164], [77.82068634, 8.24875164], [77.82068634, 8.24847126], [77.81986237, 8.24847126], [77.81986237, 8.24819565], [77.81930542, 8.24819565], [77.81930542, 8.24791527], [77.81874847, 8.24792194], [77.81874847, 8.24764156], [77.81819153, 8.24764156], [77.81819153, 8.24735928], [77.81764221, 8.24736118], [77.81764221, 8.24708271], [77.81735992, 8.24708271], [77.81735992, 8.24680519], [77.81680298, 8.24680996], [77.81680298, 8.24652863], [77.81652832, 8.24652863], [77.81652832, 8.2462492], [77.81346893, 8.2462492], [77.81346893, 8.24597263], [77.81291962, 8.24597263], [77.81291962, 8.24569321], [77.81263733, 8.24569321], [77.81263733, 8.24541664], [77.81208038, 8.24541664], [77.81208038, 8.24513912], [77.81181335, 8.24514103], [77.81181335, 8.24486065], [77.81124878, 8.24486065], [77.81124878, 8.24458313], [77.81097412, 8.24458313], [77.81097412, 8.24430466], [77.81069183, 8.24431038], [77.81069183, 8.24403191], [77.81014252, 8.24403191], [77.81014252, 8.24375057], [77.80986023, 8.24375057], [77.80986023, 8.24347115], [77.80902863, 8.24347305], [77.80902863, 8.24319458], [77.80847168, 8.24319458], [77.80847168, 8.24291706], [77.8079071, 8.24292183], [77.8079071, 8.24264145], [77.80735779, 8.24264145], [77.80735779, 8.24236965], [77.80708313, 8.24236965], [77.80708313, 8.24208069], [77.80680847, 8.2420826], [77.80680847, 8.24180698], [77.80596924, 8.24180889], [77.80596924, 8.24153137], [77.80513763, 8.24153137], [77.80513763, 8.24125099], [77.80486298, 8.24125099], [77.80486298, 8.24097061], [77.80458069, 8.24097347], [77.80458069, 8.240695], [77.80430603, 8.240695], [77.80430603, 8.24041653], [77.8034668, 8.2404213], [77.8034668, 8.24014091], [77.80236053, 8.24014091], [77.80236053, 8.2404213], [77.80208588, 8.2404213], [77.80208588, 8.24180889], [77.80264282, 8.24180889], [77.80264282, 8.24236965], [77.80319214, 8.24236965], [77.80319214, 8.24264145], [77.8034668, 8.24264145], [77.8034668, 8.24403191], [77.80374908, 8.24402714], [77.80374908, 8.2462492], [77.80403137, 8.2462492], [77.80403137, 8.24652863], [77.80430603, 8.24652672], [77.80430603, 8.24708271], [77.80458069, 8.2470789], [77.80458069, 8.24792194], [77.80430603, 8.24791527], [77.80430603, 8.24819565], [77.80403137, 8.24819565], [77.80403137, 8.24791527], [77.80374908, 8.24792194], [77.80374908, 8.24735928], [77.80347443, 8.24736118], [77.80347443, 8.24652672], [77.80319214, 8.24652863], [77.80319214, 8.24540997], [77.80291748, 8.24541664], [77.80291748, 8.24513912], [77.80236053, 8.24514103], [77.80236053, 8.24486065], [77.80208588, 8.24486065], [77.80208588, 8.24430466], [77.80179596, 8.24431038], [77.80179596, 8.24347115], [77.80152893, 8.24347305], [77.80152893, 8.24319458], [77.80124664, 8.24319458], [77.80124664, 8.24263859], [77.80097198, 8.24264145], [77.80097198, 8.24236965], [77.80069733, 8.24236965], [77.80069733, 8.24208069], [77.80041504, 8.2420826], [77.80041504, 8.2415266], [77.80014038, 8.24153137], [77.80014038, 8.23856163], [77.80014038, 8.23791695], [77.79987335, 8.23791885], [77.79987335, 8.23764133], [77.79957581, 8.23764133], [77.79957581, 8.23653126], [77.79987335, 8.23653126], [77.79987335, 8.23596954], [77.79958344, 8.23597336], [77.79958344, 8.23541641], [77.79930878, 8.23542118], [77.79930878, 8.2343111], [77.79902649, 8.2343111], [77.79902649, 8.23403072], [77.79875183, 8.23403072], [77.79875183, 8.23375034], [77.79846954, 8.23375034], [77.79846954, 8.23347187], [77.79819489, 8.23347187], [77.79819489, 8.23319435], [77.79763794, 8.23319435], [77.79763794, 8.23291588], [77.79708099, 8.23292065], [77.79708099, 8.23264027], [77.79680634, 8.23264027], [77.79680634, 8.23235989], [77.79651642, 8.23235989], [77.79651642, 8.23181057], [77.79624939, 8.23181057], [77.79624939, 8.23153019], [77.79569244, 8.23153019], [77.79569244, 8.23125172], [77.79541779, 8.23125172], [77.79541779, 8.23097038], [77.79486084, 8.23097229], [77.79486084, 8.23069382], [77.79430389, 8.23069382], [77.79430389, 8.2304163], [77.79402924, 8.23042965], [77.79402924, 8.23013973], [77.79373932, 8.23013973], [77.79373932, 8.22986031], [77.79347229, 8.22986221], [77.79347229, 8.22958374], [77.79319763, 8.22958374], [77.79319763, 8.22902775], [77.79264069, 8.22902966], [77.79264069, 8.22875023], [77.7923584, 8.22875023], [77.7923584, 8.22847176], [77.79180908, 8.22847176], [77.79180908, 8.22819424], [77.79152679, 8.22819424], [77.79152679, 8.22791576], [77.79125214, 8.22791958], [77.79125214, 8.22764015], [77.79096985, 8.22764015], [77.79096985, 8.22737122], [77.7904129, 8.22737122], [77.7904129, 8.22707939], [77.78986359, 8.22708416], [77.78986359, 8.22680569], [77.7895813, 8.22681046], [77.7895813, 8.22653008], [77.78901672, 8.22653008], [77.78901672, 8.22624969], [77.78848267, 8.22624969], [77.78848267, 8.22596931], [77.78791809, 8.22597218], [77.78791809, 8.2256937], [77.7876358, 8.2256937], [77.7876358, 8.22541809], [77.78708649, 8.22542], [77.78708649, 8.22513962], [77.78679657, 8.22513962], [77.78679657, 8.22485924], [77.78652954, 8.2248621], [77.78652954, 8.22458363], [77.78624725, 8.22458363], [77.78624725, 8.22430611], [77.7859726, 8.22430611], [77.7859726, 8.22402763], [77.78569794, 8.22402954], [77.78569794, 8.22347069], [77.78541565, 8.22347069], [77.78541565, 8.22319317], [77.7848587, 8.22319317], [77.7848587, 8.22264004], [77.78457642, 8.22264194], [77.78457642, 8.22208118], [77.78430176, 8.22208309], [77.78430176, 8.22124863], [77.7840271, 8.22124863], [77.7840271, 8.22069454], [77.78375244, 8.22069454], [77.78375244, 8.22041702], [77.78347015, 8.22042179], [77.78347015, 8.21986103], [77.78291321, 8.21986103], [77.78291321, 8.22013855], [77.78263855, 8.22013855], [77.78263855, 8.22042179], [77.7820816, 8.22042179], [77.7820816, 8.21958065], [77.78291321, 8.21958256], [77.78291321, 8.21652699], [77.78263855, 8.21652889], [77.78263855, 8.21543121], [77.78235626, 8.21543121], [77.78235626, 8.2143116], [77.78263855, 8.2143116], [77.78263855, 8.21403122], [77.78291321, 8.21403122], [77.78291321, 8.21347141], [77.7831955, 8.21347332], [77.7831955, 8.21291733], [77.78347015, 8.21291924], [77.78347015, 8.21207142], [77.7831955, 8.21208286], [77.7831955, 8.21125126], [77.78347015, 8.21125126], [77.78347015, 8.21041679], [77.78375244, 8.21042061], [77.78375244, 8.20903111], [77.7840271, 8.20903111], [77.7840271, 8.20764065], [77.78430176, 8.20764065], [77.78430176, 8.20736027], [77.7840271, 8.20736027], [77.7840271, 8.20652771], [77.78375244, 8.20653057], [77.78375244, 8.20542145], [77.78347015, 8.20542145], [77.78347015, 8.20514011], [77.78320313, 8.20514011], [77.78320313, 8.20458031], [77.78291321, 8.20458412], [77.78291321, 8.20263767], [77.78263855, 8.20263958], [77.78263855, 8.20236015], [77.7820816, 8.20236206], [77.7820816, 8.20180607], [77.78179932, 8.20181274], [77.78179932, 8.20125008], [77.7815094, 8.20125008], [77.7815094, 8.20068932], [77.78125, 8.20069408], [77.78125, 8.20041561], [77.78069305, 8.20042038], [77.78069305, 8.20013142], [77.7804184, 8.20014], [77.7804184, 8.19958401], [77.77986145, 8.19958401], [77.77986145, 8.19930553], [77.77958679, 8.1993103], [77.77958679, 8.19902992], [77.77929688, 8.19902992], [77.77929688, 8.19874954], [77.77902985, 8.19874954], [77.77902985, 8.19847202], [77.77874756, 8.19847202], [77.77874756, 8.19819355], [77.7784729, 8.19819355], [77.7784729, 8.19791794], [77.77819824, 8.19791985], [77.77819061, 8.19764042], [77.7776413, 8.19764042], [77.7776413, 8.19736195], [77.77707672, 8.19736195], [77.77707672, 8.19707012], [77.7765274, 8.19708443], [77.7765274, 8.19680595], [77.77625275, 8.19680977], [77.77625275, 8.19653034], [77.77597046, 8.19653034], [77.77597046, 8.19625187], [77.7756958, 8.19625187], [77.7756958, 8.19597054], [77.77513885, 8.19597054], [77.77513885, 8.19569588], [77.77236176, 8.19569302], [77.77236176, 8.19541454], [77.77153015, 8.19542027], [77.77153015, 8.19514179], [77.77041626, 8.19514179], [77.77041626, 8.19486141], [77.76958466, 8.19486141], [77.76958466, 8.19458294], [77.76875305, 8.19458294], [77.76875305, 8.19430542], [77.76790619, 8.19432068], [77.76790619, 8.19402981], [77.76568604, 8.19402981], [77.76568604, 8.19374943], [77.76557159, 8.19374943], [77.76541901, 8.19374943], [77.76541901, 8.19337082], [77.76541901, 8.19319534], [77.76528931, 8.19319534], [77.76513672, 8.19319534], [77.76513672, 8.19291687], [77.76486206, 8.19291973], [77.76486206, 8.19263935], [77.76457977, 8.19263935], [77.76457977, 8.19236088], [77.76430511, 8.19236088], [77.76430511, 8.19222546], [77.76430511, 8.19180489], [77.7637558, 8.19180965], [77.7637558, 8.19152927], [77.76346588, 8.19152927], [77.76346588, 8.19126034], [77.76264191, 8.19126034], [77.76264191, 8.19097137], [77.76208496, 8.19097328], [77.76208496, 8.19069481], [77.76180267, 8.19069481], [77.76180267, 8.19041729], [77.76125336, 8.1904192], [77.76125336, 8.19014072], [77.76097107, 8.19014072], [77.76097107, 8.1898613], [77.76041412, 8.1898613], [77.76041412, 8.18958282], [77.76013947, 8.18958282], [77.76013947, 8.18930531], [77.75985718, 8.18931198], [77.75985718, 8.18903065], [77.75958252, 8.18903065], [77.75958252, 8.18875122], [77.75930786, 8.18875122], [77.75930786, 8.18847084], [77.75875092, 8.18847084], [77.75875092, 8.18819523], [77.75791931, 8.18819523], [77.75791931, 8.18791676], [77.75708008, 8.18792152], [77.75708008, 8.18764114], [77.75653076, 8.18764114], [77.75653076, 8.18708134], [77.75624847, 8.18708324], [77.75624847, 8.18680477], [77.75596619, 8.1868124], [77.75596619, 8.18653107], [77.75569153, 8.18653107], [77.75569153, 8.18625069], [77.75541687, 8.18625069], [77.75541687, 8.18597126], [77.75514221, 8.18597317], [77.75514221, 8.18569469], [77.75430298, 8.18569469], [77.75430298, 8.18597317], [77.75347137, 8.18597126], [77.75347137, 8.18625069], [77.7518158, 8.18625069], [77.7518158, 8.18542099], [77.75347137, 8.18542099], [77.75347137, 8.18513203], [77.75375366, 8.1851387], [77.75375366, 8.18486118], [77.75402832, 8.18486118], [77.75402832, 8.18458271], [77.75430298, 8.18458271], [77.75430298, 8.18430519], [77.7545929, 8.18431091], [77.7545929, 8.18406105], [77.75458527, 8.18319511], [77.75430298, 8.18319511], [77.75430298, 8.18291664], [77.75402832, 8.18292141], [77.75402832, 8.18264103], [77.75319672, 8.18264103], [77.75319672, 8.1823597], [77.75291443, 8.1823597], [77.75291443, 8.18208218], [77.75263977, 8.18208218], [77.75263977, 8.18180656], [77.75235748, 8.18181133], [77.75235748, 8.18153095], [77.75152588, 8.18153095], [77.75152588, 8.18124962], [77.75096893, 8.18124962], [77.75096893, 8.18097019], [77.75069427, 8.1809721], [77.75069427, 8.18069363], [77.75041962, 8.18069363], [77.75041962, 8.18013763], [77.74958038, 8.18014145], [77.74958038, 8.17986012], [77.74874878, 8.17986012], [77.74874878, 8.17958355], [77.74819183, 8.17958355], [77.74819183, 8.17930603], [77.74764252, 8.17932034], [77.74764252, 8.17903137], [77.74736023, 8.17903137], [77.74736023, 8.17846966], [77.74708557, 8.17847157], [77.74708557, 8.17763805], [77.74680328, 8.17763996], [77.74680328, 8.17735958], [77.74624634, 8.17736244], [77.74624634, 8.17708206], [77.74541473, 8.17708206], [77.74541473, 8.17680645], [77.74430847, 8.17681122], [77.74430847, 8.17653275], [77.74375153, 8.17653275], [77.74375153, 8.17625046], [77.74318695, 8.17625046], [77.74318695, 8.17597198], [77.74291992, 8.17597198], [77.74291992, 8.17569447], [77.74263763, 8.17569447], [77.74263763, 8.17541599], [77.74180603, 8.17542267], [77.74180603, 8.17514038], [77.74014282, 8.17514038], [77.74014282, 8.17486191], [77.73929596, 8.17486191], [77.73929596, 8.17457867], [77.73902893, 8.17458439], [77.73902893, 8.17430592], [77.73735809, 8.17431068], [77.73735809, 8.1740303], [77.73681641, 8.1740303], [77.73681641, 8.17374992], [77.73568726, 8.17374992], [77.73568726, 8.17346954], [77.73542023, 8.17346954], [77.73542023, 8.17374992], [77.73438263, 8.17374992], [77.73430634, 8.17357159], [77.73430634, 8.1734724], [77.73347473, 8.1734724], [77.73347473, 8.17319584], [77.73236084, 8.17319584], [77.73236084, 8.17291641], [77.73152924, 8.17292023], [77.73152924, 8.17263985], [77.73124695, 8.17263985], [77.73124695, 8.17208195], [77.73069763, 8.17208385], [77.73069763, 8.17236233], [77.73014069, 8.17236042], [77.73014069, 8.17263985], [77.72930908, 8.17263985], [77.72930908, 8.17236042], [77.72902679, 8.17236233], [77.72902679, 8.17208385], [77.72846985, 8.17208385], [77.72846985, 8.17236233], [77.7279129, 8.17236233], [77.7279129, 8.17208385], [77.72763824, 8.17208385], [77.72763824, 8.17236233], [77.72736359, 8.17236233], [77.72736359, 8.17208385], [77.72680664, 8.17208385], [77.72680664, 8.17180634], [77.72624969, 8.17181015], [77.72624969, 8.17152977], [77.72541809, 8.17152977], [77.72541809, 8.17125034], [77.72458649, 8.17125034], [77.72458649, 8.17097187], [77.7234726, 8.17097187], [77.7234726, 8.17069435], [77.72319794, 8.17069435], [77.72319794, 8.17041779], [77.72264099, 8.17041969], [77.72264099, 8.16958141], [77.72208405, 8.16958427], [77.72208405, 8.16902733], [77.72180176, 8.16903019], [77.72180176, 8.16874886], [77.7215271, 8.16874886], [77.7215271, 8.16819572], [77.7206955, 8.16819572], [77.7206955, 8.16791534], [77.7195816, 8.16792202], [77.7195816, 8.16764164], [77.71930695, 8.16764164], [77.71930695, 8.16736126], [77.71875, 8.16736126], [77.71875, 8.16708279], [77.7179184, 8.16709042], [77.7179184, 8.16681004], [77.71708679, 8.16681004], [77.71708679, 8.16652966], [77.71652985, 8.16652966], [77.71652985, 8.16624928], [77.71624756, 8.16624928], [77.71624756, 8.16569328], [77.7159729, 8.16569328], [77.7159729, 8.1659708], [77.71485901, 8.1659708], [77.71485901, 8.16569328], [77.7131958, 8.16569328], [77.7131958, 8.1659708], [77.71263885, 8.16597271], [77.71263885, 8.16624928], [77.71180725, 8.16624928], [77.71180725, 8.16597271], [77.71013641, 8.1659708], [77.71013641, 8.16569328], [77.70986176, 8.16569328], [77.70986176, 8.16541672], [77.70929718, 8.16541958], [77.70929718, 8.1651392], [77.70903015, 8.1651392], [77.70903015, 8.16486073], [77.70707703, 8.16486073], [77.70707703, 8.1645813], [77.70680237, 8.16458321], [77.70680237, 8.16486073], [77.70652008, 8.16486073], [77.70652008, 8.1651392], [77.70540619, 8.1651392], [77.70540619, 8.16486073], [77.70513916, 8.16486073], [77.70513916, 8.16458321], [77.7048645, 8.16458321], [77.7048645, 8.16430473], [77.7040329, 8.16431046], [77.7040329, 8.16403198], [77.70291901, 8.16403198], [77.70291901, 8.16375065], [77.70263672, 8.16375065], [77.70263672, 8.16347122], [77.69985962, 8.16347313], [77.69985962, 8.16319466], [77.69958496, 8.16319466], [77.69958496, 8.16347313], [77.69875336, 8.16347313], [77.69875336, 8.16319466], [77.69819641, 8.16319466], [77.69819641, 8.16291714], [77.69652557, 8.16291714], [77.69652557, 8.16319466], [77.69625092, 8.16319466], [77.69625092, 8.16291714], [77.69569397, 8.16291714], [77.69569397, 8.16319466], [77.69513702, 8.16319466], [77.69513702, 8.16347313], [77.69486237, 8.16347313], [77.69486237, 8.16319466], [77.69458008, 8.16319466], [77.69458008, 8.16291714], [77.69264221, 8.16292191], [77.69264221, 8.16236115], [77.68875122, 8.16236115], [77.68875122, 8.16208267], [77.68680573, 8.16208267], [77.68680573, 8.16236115], [77.68653107, 8.16236115], [77.68653107, 8.16208267], [77.68541718, 8.16208267], [77.68541718, 8.16180515], [77.68514252, 8.16181183], [77.68514252, 8.16153145], [77.68264008, 8.16153145], [77.68264008, 8.16125107], [77.68235016, 8.16125107], [77.68235016, 8.16095924], [77.68125153, 8.1609726], [77.68125153, 8.16069508], [77.68013763, 8.16069508], [77.68013763, 8.1609726], [77.67736053, 8.1609726], [77.67736053, 8.16069508], [77.67624664, 8.16069508], [77.67624664, 8.1604166], [77.67597198, 8.16042137], [77.67597198, 8.16014099], [77.67569733, 8.16014099], [77.67569733, 8.15986061], [77.67541504, 8.15986061], [77.67541504, 8.15958309], [77.67346954, 8.15958309], [77.67346954, 8.15930462], [77.67319489, 8.15930462], [77.67319489, 8.15958309], [77.67292023, 8.15958309], [77.67292023, 8.15930462], [77.67263794, 8.15930462], [77.67263794, 8.15958309], [77.67236328, 8.15958309], [77.67236328, 8.15930462], [77.67041016, 8.15930939], [77.67041016, 8.15903091], [77.67014313, 8.15903091], [77.67014313, 8.15930939], [77.66986084, 8.15930939], [77.66986084, 8.15903091], [77.66902924, 8.15903091], [77.66902924, 8.15930939], [77.66874695, 8.15930939], [77.66874695, 8.15903091], [77.66680908, 8.15903091], [77.66680908, 8.15930939], [77.66652679, 8.15930939], [77.66652679, 8.15903091], [77.66570282, 8.15903091], [77.66570282, 8.15930939], [77.66430664, 8.15930939], [77.66430664, 8.15903091], [77.66348267, 8.15903091], [77.66348267, 8.15875053], [77.66236115, 8.15875053], [77.66236115, 8.15847111], [77.66208649, 8.15847111], [77.66208649, 8.15875053], [77.66179657, 8.15875053], [77.66179657, 8.15847111], [77.66014099, 8.15847301], [77.66014099, 8.15819454], [77.65847015, 8.15819454], [77.65847015, 8.15847301], [77.65791321, 8.15847301], [77.65791321, 8.15791702], [77.65680695, 8.15791702], [77.65680695, 8.15819454], [77.65569305, 8.15819454], [77.65569305, 8.15847301], [77.65513611, 8.15847111], [77.65513611, 8.15875053], [77.65486145, 8.15875053], [77.65486145, 8.15903091], [77.6534729, 8.15903091], [77.6534729, 8.15875053], [77.65180206, 8.15875053], [77.65180206, 8.15903091], [77.65125275, 8.15902901], [77.65125275, 8.15958309], [77.65097046, 8.15958023], [77.65097046, 8.16014099], [77.65013885, 8.16014099], [77.65013885, 8.15986061], [77.64958191, 8.15986061], [77.64958191, 8.15958309], [77.64902496, 8.15958309], [77.64902496, 8.15902901], [77.64875031, 8.15903091], [77.64875031, 8.15875053], [77.64848328, 8.15875053], [77.64848328, 8.15847111], [77.6470871, 8.15847301], [77.6470871, 8.15819454], [77.64653015, 8.15819454], [77.64653015, 8.15791702], [77.64485931, 8.15792084], [77.64485931, 8.15764141], [77.64290619, 8.15764141], [77.64290619, 8.15736103], [77.64068604, 8.15736103], [77.64068604, 8.15764141], [77.64013672, 8.15764141], [77.64013672, 8.15736103], [77.63986206, 8.15736103], [77.63986206, 8.15708256], [77.63930511, 8.15708256], [77.63930511, 8.15680695], [77.63903046, 8.15680885], [77.63903046, 8.15653133], [77.63819122, 8.15653133], [77.63819122, 8.15625095], [77.63707733, 8.15625095], [77.63707733, 8.15596962], [77.63625336, 8.15597343], [77.63625336, 8.15569496], [77.63541412, 8.15569496], [77.63541412, 8.15541553], [77.63485718, 8.15542126], [77.63485718, 8.15515041], [77.63430023, 8.15515041], [77.63430023, 8.15542126], [77.63318634, 8.15542126], [77.63318634, 8.15515041], [77.63153076, 8.15515041], [77.63153076, 8.15485954], [77.63097382, 8.15485954], [77.63097382, 8.15458202], [77.63069153, 8.15458202], [77.63069153, 8.15430737], [77.62958527, 8.15430737], [77.62958527, 8.15458202], [77.62902832, 8.15458202], [77.62902832, 8.15430737], [77.62847137, 8.15431118], [77.62847137, 8.1540308], [77.62819672, 8.1540308], [77.62819672, 8.15375042], [77.62763977, 8.15375042], [77.62763977, 8.15347195], [77.62596893, 8.15347195], [77.62596893, 8.15319443], [77.62458038, 8.15319443], [77.62458038, 8.15291595], [77.62374878, 8.15292072], [77.62374878, 8.15264034], [77.62264252, 8.15264034], [77.62264252, 8.15235996], [77.62152863, 8.15235996], [77.62152863, 8.15208435], [77.62069702, 8.15209103], [77.62069702, 8.15181065], [77.61985779, 8.15181065], [77.61985779, 8.15153122], [77.61791992, 8.15153122], [77.61791992, 8.15124989], [77.61736298, 8.15124989], [77.61736298, 8.15097046], [77.61624908, 8.15097237], [77.61624908, 8.15069389], [77.61513519, 8.15069389], [77.61513519, 8.15041637], [77.61458588, 8.15042114], [77.61458588, 8.15014267], [77.61429596, 8.15014267], [77.61429596, 8.15042114], [77.61402893, 8.15042114], [77.61402893, 8.15014267], [77.61292267, 8.15014267], [77.61292267, 8.14986038], [77.61235809, 8.14986229], [77.61235809, 8.14958382], [77.61152649, 8.14958191], [77.61152649, 8.1493063], [77.61096954, 8.1493063], [77.61096954, 8.14958191], [77.61069489, 8.14958191], [77.61069489, 8.1493063], [77.61042023, 8.14931107], [77.61042023, 8.14902115], [77.60958099, 8.14902782], [77.60958099, 8.14875031], [77.60901642, 8.14875031], [77.60901642, 8.14847183], [77.60791779, 8.14847183], [77.60791779, 8.14819431], [77.60736084, 8.14819431], [77.60736084, 8.14791584], [77.60708618, 8.14791965], [77.60708618, 8.14764023], [77.60597229, 8.14764023], [77.60597229, 8.14735985], [77.6048584, 8.14735985], [77.6048584, 8.14708424], [77.60430908, 8.14708424], [77.60430908, 8.14680576], [77.60402679, 8.14680958], [77.60402679, 8.14653015], [77.60346985, 8.14653015], [77.60346985, 8.14624977], [77.6029129, 8.14624977], [77.6029129, 8.14595985], [77.60236359, 8.14597225], [77.60236359, 8.14569378], [77.60124969, 8.14569378], [77.60124969, 8.14541626], [77.60069275, 8.14542007], [77.60069275, 8.14513969], [77.59929657, 8.14513969], [77.59929657, 8.14486027], [77.59874725, 8.14486217], [77.59874725, 8.1445837], [77.59819794, 8.1445837], [77.59819794, 8.14430618], [77.5973587, 8.14431], [77.5973587, 8.14402962], [77.59625244, 8.14402962], [77.59625244, 8.14375019], [77.5956955, 8.14375019], [77.5956955, 8.14347172], [77.59541321, 8.14347172], [77.59541321, 8.14319324], [77.59430695, 8.14319324], [77.59430695, 8.14291763], [77.59263611, 8.14291954], [77.59263611, 8.14264202], [77.59179688, 8.14264202], [77.59179688, 8.14291954], [77.59152985, 8.14291954], [77.59152985, 8.14264202], [77.59124756, 8.14264202], [77.59124756, 8.14236164], [77.5901413, 8.14236164], [77.5901413, 8.14208412], [77.5890274, 8.14208412], [77.5890274, 8.1418047], [77.58875275, 8.14181042], [77.58875275, 8.14153194], [77.58847046, 8.14153194], [77.58847046, 8.14125156], [77.5881958, 8.14125156], [77.5881958, 8.14097118], [77.58763885, 8.14097118], [77.58763885, 8.14069557], [77.58680725, 8.14069557], [77.58680725, 8.1404171], [77.58625031, 8.14042187], [77.58625031, 8.14015102], [77.58598328, 8.14015102], [77.58598328, 8.1398592], [77.58569336, 8.13986111], [77.58569336, 8.13958263], [77.5854187, 8.13958263], [77.5854187, 8.13930511], [77.58486176, 8.13931179], [77.58486176, 8.13902855], [77.5845871, 8.13902855], [77.5845871, 8.13875103], [77.58347321, 8.13875103], [77.58347321, 8.13847065], [77.5826416, 8.13847256], [77.5826416, 8.13819313], [77.58180237, 8.13819313], [77.58180237, 8.13791656], [77.58125305, 8.13792038], [77.58125305, 8.13764191], [77.58040619, 8.13764191], [77.58040619, 8.13736057], [77.57958221, 8.13736057], [77.57958221, 8.13708305], [77.57902527, 8.13708305], [77.57902527, 8.13680458], [77.57847595, 8.1368103], [77.57847595, 8.13653183], [77.57763672, 8.13653183], [77.57763672, 8.13625145], [77.5770874, 8.13625145], [77.5770874, 8.13597107], [77.57653046, 8.13597107], [77.57653046, 8.13569546], [77.57569122, 8.13569546], [77.57569122, 8.13513947], [77.57541656, 8.13514137], [77.57541656, 8.13458061], [77.57514191, 8.13458347], [77.57514191, 8.13434124], [77.57514191, 8.1334734], [77.57485962, 8.1334734], [77.57485962, 8.13319492], [77.57458496, 8.13319492], [77.57458496, 8.1329174], [77.57430267, 8.13291931], [77.57430267, 8.13264084], [77.57347107, 8.13264084], [77.57347107, 8.13236141], [77.57319641, 8.13236141], [77.57319641, 8.13208294], [77.57263947, 8.13208294], [77.57263947, 8.13180542], [77.57208252, 8.13180923], [77.57208252, 8.13152885], [77.57125092, 8.13152885], [77.57125092, 8.13097954], [77.570961, 8.13097954], [77.570961, 8.13014126], [77.57068634, 8.13014126], [77.57068634, 8.12957954], [77.57041931, 8.12958241], [77.57041931, 8.12902641], [77.57013702, 8.12903118], [77.57013702, 8.12847042], [77.56986237, 8.12847328], [77.56986237, 8.12819386], [77.56958008, 8.12819386], [77.56958008, 8.12791634], [77.56874847, 8.1279211], [77.56874847, 8.12764072], [77.56846619, 8.12764072], [77.56846619, 8.12736034], [77.56791687, 8.12736034], [77.56791687, 8.12708473], [77.56735992, 8.12708473], [77.56735992, 8.12680435], [77.5670929, 8.12681103], [77.5670929, 8.12653065], [77.56680298, 8.12653065], [77.56680298, 8.12625027], [77.56652832, 8.12625027], [77.56652832, 8.12513828], [77.56624603, 8.12514019], [77.56624603, 8.12458038], [77.56569672, 8.1245842], [77.56569672, 8.12430573], [77.56485748, 8.12431145], [77.56485748, 8.12403107], [77.56458282, 8.12403107], [77.56458282, 8.12374973], [77.56430817, 8.12374973], [77.56430817, 8.12347031], [77.56402588, 8.12347221], [77.56402588, 8.12319374], [77.56375122, 8.12319374], [77.56375122, 8.12291622], [77.56346893, 8.12292099], [77.56346893, 8.12263966], [77.56318665, 8.12263966], [77.56318665, 8.12236023], [77.56291962, 8.12236214], [77.56291962, 8.12208366], [77.56236267, 8.12208366], [77.56236267, 8.12180614], [77.56181335, 8.12181091], [77.56181335, 8.12152958], [77.56153107, 8.12152958], [77.56153107, 8.12125015], [77.56124878, 8.12125015], [77.56124878, 8.12097168], [77.56097412, 8.12097168], [77.56097412, 8.12069416], [77.56069183, 8.12069416], [77.56069183, 8.12014008], [77.56014252, 8.12014008], [77.56014252, 8.1198597], [77.55958557, 8.1198597], [77.55958557, 8.11958408], [77.55930328, 8.11958408], [77.55930328, 8.1184721], [77.55958557, 8.1184721], [77.55958557, 8.11819363], [77.55986023, 8.11819363], [77.55986023, 8.11736202], [77.56014252, 8.11736202], [77.56014252, 8.11708355], [77.55986023, 8.11708355], [77.55986023, 8.11652756], [77.5595932, 8.11653042], [77.5595932, 8.11569118], [77.55930328, 8.11569309], [77.55930328, 8.11513996], [77.559021, 8.11514187], [77.559021, 8.11458111], [77.55874634, 8.11458302], [77.55874634, 8.11402702], [77.55847168, 8.11403179], [77.55847168, 8.11319065], [77.55819702, 8.11319542], [77.55819702, 8.11208344], [77.55791473, 8.11208344], [77.55791473, 8.11124897], [77.55764008, 8.11125088], [77.55764008, 8.11069107], [77.55791473, 8.11069489], [77.55791473, 8.10986137], [77.55819702, 8.10986137], [77.55819702, 8.10930538], [77.55847168, 8.10931015], [77.55847168, 8.1087513], [77.55874634, 8.1087513], [77.55874634, 8.10847092], [77.55902863, 8.10847092], [77.55902863, 8.10791683], [77.55930328, 8.1079216], [77.55930328, 8.10404015], [77.559021, 8.10404015], [77.559021, 8.10292053], [77.55874634, 8.10292053], [77.55874634, 8.10235977], [77.55847168, 8.10235977], [77.55847168, 8.10152912], [77.55874634, 8.10153103], [77.55874634, 8.10125065], [77.55847168, 8.10125065], [77.55847168, 8.09958172], [77.55874634, 8.09958363], [77.55874634, 8.0993042], [77.559021, 8.09931087], [77.559021, 8.09903145], [77.55930328, 8.09903145], [77.55930328, 8.09846973], [77.55958557, 8.09847164], [77.55958557, 8.09791565], [77.55930328, 8.09791565], [77.55930328, 8.09763813], [77.559021, 8.09764004], [77.559021, 8.09735966], [77.55874634, 8.09736156], [77.55874634, 8.09652805], [77.559021, 8.09652996], [77.559021, 8.09624958], [77.55930328, 8.09624958], [77.55930328, 8.09597015], [77.55986023, 8.09597206], [77.55986023, 8.09569359], [77.56041718, 8.09569359], [77.56041718, 8.09597206], [77.56069183, 8.09597015], [77.56069183, 8.09624958], [77.56124878, 8.09624958], [77.56124878, 8.09652996], [77.56153107, 8.09652996], [77.56153107, 8.09681129], [77.56208038, 8.09680557], [77.56208038, 8.09708214], [77.56236267, 8.09708214], [77.56236267, 8.09680557], [77.56319427, 8.09680557], [77.56319427, 8.09735966], [77.56402588, 8.09735966], [77.56402588, 8.09764004], [77.56430817, 8.09763813], [77.56430817, 8.09791565], [77.56458282, 8.09791565], [77.56458282, 8.09819412], [77.56430817, 8.09819412], [77.56430817, 8.09847164], [77.56458282, 8.09846973], [77.56458282, 8.09875011], [77.56430817, 8.09875011], [77.56430817, 8.09958363], [77.56458282, 8.09958363], [77.56458282, 8.09986019], [77.56485748, 8.09986019], [77.56485748, 8.0993042], [77.5651474, 8.09931087], [77.5651474, 8.09542274], [77.56485748, 8.09542274], [77.56485748, 8.09375], [77.5651474, 8.09375], [77.5651474, 8.09318924], [77.56541443, 8.09319401], [77.56541443, 8.09291553], [77.56569672, 8.0929203], [77.56569672, 8.09263992], [77.56597137, 8.09263992], [77.56597137, 8.09208202], [77.56513977, 8.09208393], [77.56513977, 8.09180641], [77.56458282, 8.09181023], [77.56458282, 8.09152985], [77.56346893, 8.09152985], [77.56346893, 8.09125042], [77.56318665, 8.09125042], [77.56318665, 8.09097195], [77.56291962, 8.09097195], [77.56291962, 8.09125042], [77.56236267, 8.09125042], [77.56236267, 8.09152985], [77.56181335, 8.09152985], [77.56181335, 8.09125042], [77.56153107, 8.09125042], [77.56153107, 8.09097195], [77.56124878, 8.09097195], [77.56124878, 8.09069443], [77.56097412, 8.09069443], [77.56097412, 8.09041786], [77.55986023, 8.09041977], [77.55986023, 8.09014034], [77.55930328, 8.09014034], [77.55930328, 8.08986187], [77.559021, 8.08986187], [77.559021, 8.08958054], [77.55847168, 8.08958435], [77.55847168, 8.08930588], [77.55764008, 8.08930969], [77.55764008, 8.08875179], [77.55735779, 8.08875179], [77.55735779, 8.08847141], [77.55708313, 8.08847141], [77.55708313, 8.0881958], [77.55652618, 8.0881958], [77.55652618, 8.08791542], [77.55625153, 8.08792019], [77.55625153, 8.08736134], [77.55596924, 8.08736134], [77.55596924, 8.08708286], [77.55541992, 8.08708286], [77.55541992, 8.08680534], [77.55513763, 8.08681011], [77.55513763, 8.08624935], [77.55486298, 8.08624935], [77.55486298, 8.08569527], [77.55430603, 8.08569527], [77.55430603, 8.08541679], [77.55403137, 8.08541965], [77.55403137, 8.08513927], [77.55374908, 8.08513927], [77.55374908, 8.08485889], [77.55347443, 8.0848608], [77.55347443, 8.08458328], [77.55291748, 8.08458328], [77.55291748, 8.08430481], [77.55264282, 8.08430958], [77.55264282, 8.08125114], [77.55291748, 8.08125114], [77.55291748, 8.08041668], [77.55264282, 8.0804224], [77.55264282, 8.07987022], [77.55236053, 8.07987022], [77.55236053, 8.07958126], [77.55208588, 8.07958317], [77.55208588, 8.0793047], [77.55236053, 8.07930946], [77.55236053, 8.07792091], [77.55208588, 8.07792091], [77.55208588, 8.07736111], [77.55180359, 8.07736111], [77.55180359, 8.07708263], [77.55152893, 8.07708263], [77.55152893, 8.07680511], [77.55097198, 8.07680511], [77.55097198, 8.07652569], [77.55069733, 8.07652569], [77.55069733, 8.07680511], [77.55041504, 8.07680511], [77.55041504, 8.07736111], [77.55014801, 8.07736111], [77.55014801, 8.07792091], [77.54902649, 8.07792091], [77.54902649, 8.07764053], [77.54846954, 8.07764053], [77.54846954, 8.07792091], [77.54680634, 8.07792091], [77.54680634, 8.07764053], [77.54624939, 8.07764053], [77.54624939, 8.07736111], [77.54569244, 8.07736111], [77.54569244, 8.07764053], [77.54514313, 8.07764053], [77.54514313, 8.07792091], [77.54319763, 8.0779171], [77.54319763, 8.07819462], [77.54165649, 8.07819462], [77.53902435, 8.07819462], [77.53902435, 8.07847309], [77.53874969, 8.07847309], [77.53874969, 8.07819462], [77.53847504, 8.07819462], [77.53847504, 8.07847309], [77.5376358, 8.07847309], [77.5376358, 8.07819462], [77.53624725, 8.07819462], [77.53624725, 8.0779171], [77.53542328, 8.07792091], [77.53542328, 8.07764053], [77.53485107, 8.07764053], [77.53485107, 8.07736111], [77.53291321, 8.07736111], [77.53291321, 8.07708263], [77.53125, 8.07708263], [77.53125, 8.07736111], [77.53098297, 8.07736111], [77.53098297, 8.07930946], [77.53069305, 8.07930946], [77.53069305, 8.07987022], [77.53013611, 8.07987022], [77.53013611, 8.08014107], [77.52986145, 8.08014107], [77.52986145, 8.0804224], [77.5293045, 8.08041668], [77.5293045, 8.08069515], [77.5284729, 8.08069515], [77.5284729, 8.08097267], [77.5276413, 8.08097267], [77.5276413, 8.08125114], [77.52735901, 8.08125114], [77.52735901, 8.08097267], [77.52680206, 8.08097267], [77.52680206, 8.08125114], [77.52597809, 8.08125114], [77.52597809, 8.08153057], [77.52291107, 8.08153057], [77.52291107, 8.0818119], [77.52236176, 8.0818119], [77.52236176, 8.08153057], [77.52179718, 8.08153057], [77.52179718, 8.0818119], [77.51985168, 8.0818119], [77.51985168, 8.08153057], [77.51930237, 8.08153057], [77.51930237, 8.0818119], [77.51875305, 8.08180523], [77.51875305, 8.08236122], [77.5173645, 8.08236122], [77.5173645, 8.08208275], [77.51680756, 8.08208275], [77.51680756, 8.08180523], [77.5165329, 8.0818119], [77.5165329, 8.08264065], [77.51457977, 8.08264065], [77.51457977, 8.08293056], [77.51097107, 8.08291721], [77.51097107, 8.08319473], [77.51041412, 8.08319473], [77.51041412, 8.08347321], [77.50958252, 8.0834713], [77.50958252, 8.08375072], [77.50818634, 8.08375072], [77.50818634, 8.0834713], [77.50681305, 8.0834713], [77.50681305, 8.08375072], [77.50653076, 8.08375072], [77.50653076, 8.0840292], [77.50569153, 8.0840292], [77.50569153, 8.08430958], [77.50541687, 8.08430481], [77.50541687, 8.08458328], [77.50514221, 8.08458328], [77.50514221, 8.0848608], [77.50486755, 8.08485889], [77.50486755, 8.08513927], [77.50319672, 8.08513927], [77.50319672, 8.08541965], [77.50152588, 8.08541679], [77.50152588, 8.08569527], [77.50069427, 8.08569527], [77.50069427, 8.08597088], [77.50013733, 8.08597088], [77.50013733, 8.08624935], [77.49903107, 8.08624935], [77.49903107, 8.08652973], [77.49874878, 8.08652973], [77.49874878, 8.08681011], [77.49819183, 8.08680534], [77.49819183, 8.08708286], [77.49319458, 8.08708286], [77.49319458, 8.08680534], [77.49263763, 8.08680534], [77.49263763, 8.08708286], [77.49180603, 8.08708286], [77.49180603, 8.08736134], [77.48929596, 8.08736134], [77.48930359, 8.08763981], [77.48819733, 8.08763981], [77.48819733, 8.08792019], [77.48735809, 8.08791542], [77.48735809, 8.0881958], [77.48596954, 8.0881958], [77.48596954, 8.08847141], [77.48542023, 8.08847141], [77.48542023, 8.08875179], [77.48458099, 8.08875179], [77.48458099, 8.08847141], [77.48430634, 8.08847141], [77.48430634, 8.0881958], [77.48347473, 8.0881958], [77.48347473, 8.08847141], [77.48264313, 8.08847141], [77.48264313, 8.08875179], [77.48179626, 8.08875179], [77.48179626, 8.08847141], [77.48152924, 8.08847141], [77.48152924, 8.08875179], [77.48097229, 8.08875179], [77.48097229, 8.08847141], [77.48041534, 8.08847141], [77.48041534, 8.08958435], [77.47957611, 8.08958054], [77.47958374, 8.08986187], [77.4770813, 8.08986187], [77.4770813, 8.08958435], [77.47569275, 8.08958435], [77.47569275, 8.08986187], [77.47486115, 8.08986187], [77.47486115, 8.09014034], [77.47292328, 8.09014034], [77.47292328, 8.09041977], [77.47097015, 8.09041786], [77.47097015, 8.09069443], [77.46930695, 8.09069443], [77.46930695, 8.09097195], [77.46874237, 8.09097195], [77.46875, 8.09125042], [77.46736145, 8.09125042], [77.46736145, 8.09152985], [77.46624756, 8.09152985], [77.46624756, 8.09181023], [77.46541595, 8.09180641], [77.46541595, 8.09208393], [77.46458435, 8.09208393], [77.46458435, 8.0923624], [77.46208191, 8.09235954], [77.46208191, 8.09263992], [77.46125031, 8.09263992], [77.46125031, 8.0929203], [77.45874786, 8.09291553], [77.45874786, 8.09319401], [77.4576416, 8.09319401], [77.4576416, 8.09291553], [77.45735931, 8.09291553], [77.45735931, 8.09319401], [77.45680237, 8.09319401], [77.45680237, 8.09347153], [77.45597076, 8.09347153], [77.45597076, 8.09319401], [77.45513916, 8.09319401], [77.45513916, 8.09347153], [77.45291901, 8.09346962], [77.45291901, 8.09375], [77.45124817, 8.09375], [77.45124817, 8.09403038], [77.44847107, 8.09403038], [77.44847107, 8.09431076], [77.44680786, 8.09430599], [77.44680786, 8.09458447], [77.44541931, 8.0945797], [77.44541931, 8.09487057], [77.44457245, 8.09487057], [77.44457245, 8.09514046], [77.44291687, 8.09514046], [77.44291687, 8.09542274], [77.44180298, 8.09541607], [77.44180298, 8.09569359], [77.44152832, 8.09569359], [77.44152832, 8.09597206], [77.44097137, 8.09597015], [77.44097137, 8.09624958], [77.43985748, 8.09624958], [77.43985748, 8.09652996], [77.43902588, 8.09652996], [77.43902588, 8.09681129], [77.43791962, 8.09680557], [77.43791962, 8.09708214], [77.43763733, 8.09708214], [77.43763733, 8.09736156], [77.43680573, 8.09736156], [77.43680573, 8.09708214], [77.43569183, 8.09708214], [77.43569183, 8.09736156], [77.43430328, 8.09736156], [77.43430328, 8.09708214], [77.43374634, 8.09708214], [77.43374634, 8.09736156], [77.4329071, 8.09735966], [77.4329071, 8.09764004], [77.43264008, 8.09763813], [77.43264008, 8.09791565], [77.43235779, 8.09791565], [77.43235779, 8.09819412], [77.43208313, 8.09819412], [77.43208313, 8.09847164], [77.43125153, 8.09846973], [77.43125153, 8.09875011], [77.43096924, 8.09875011], [77.43096924, 8.09903145], [77.43013763, 8.09903145], [77.43013763, 8.09931087], [77.42819214, 8.0993042], [77.42819214, 8.09958363], [77.42736053, 8.09958363], [77.42736053, 8.09986019], [77.42708588, 8.09986019], [77.42708588, 8.10014057], [77.42652893, 8.10014057], [77.42652893, 8.09986019], [77.42375183, 8.09986019], [77.42375183, 8.10014057], [77.42263794, 8.10014057], [77.42263794, 8.10042095], [77.42208099, 8.10041618], [77.42208099, 8.1006937], [77.42124939, 8.1006937], [77.42124939, 8.10097218], [77.42069244, 8.10097027], [77.42069244, 8.10125065], [77.41929626, 8.10125065], [77.41929626, 8.10153103], [77.41847229, 8.10153103], [77.41847229, 8.10181141], [77.41708374, 8.10180664], [77.41708374, 8.10208225], [77.41596985, 8.10208225], [77.41596985, 8.10235977], [77.4154129, 8.10235977], [77.4154129, 8.10264111], [77.41513824, 8.10264111], [77.41513824, 8.10292053], [77.4145813, 8.10291672], [77.4145813, 8.10319519], [77.41402435, 8.10319519], [77.41402435, 8.10291672], [77.41374969, 8.10291672], [77.41374969, 8.10319519], [77.41319275, 8.10319519], [77.41319275, 8.10347271], [77.41291809, 8.10347271], [77.41291809, 8.10375118], [77.41042328, 8.10375118], [77.41042328, 8.10404015], [77.4098587, 8.10404015], [77.4098587, 8.10431099], [77.4090271, 8.10430527], [77.4090271, 8.10458279], [77.4081955, 8.10458279], [77.4081955, 8.10486126], [77.40651703, 8.10486126], [77.40651703, 8.10514069], [77.4054184, 8.10514069], [77.4054184, 8.10542107], [77.40458679, 8.10541725], [77.40458679, 8.10569477], [77.40402985, 8.10569477], [77.40402985, 8.10597324], [77.40208435, 8.10597324], [77.40208435, 8.10624886], [77.4015274, 8.10624886], [77.4015274, 8.10653114], [77.40097046, 8.10653114], [77.40097046, 8.10681152], [77.40041351, 8.10680485], [77.40041351, 8.10708332], [77.39985657, 8.10708141], [77.3998642, 8.10736084], [77.39930725, 8.10736084], [77.39930725, 8.10764122], [77.39819336, 8.10764122], [77.39819336, 8.1079216], [77.39680481, 8.10791683], [77.39680481, 8.1081953], [77.39597321, 8.1081953], [77.39597321, 8.10847092], [77.3951416, 8.10847092], [77.3951416, 8.1087513], [77.39430237, 8.1087513], [77.39430237, 8.10903168], [77.39375305, 8.10903168], [77.39375305, 8.10931015], [77.39319611, 8.10930538], [77.39319611, 8.1095829], [77.3923645, 8.1095829], [77.3923645, 8.10986137], [77.39180756, 8.10985184], [77.39180756, 8.11013889], [77.39097595, 8.11013889], [77.39097595, 8.11042023], [77.39013672, 8.11041737], [77.39013672, 8.11069489], [77.38957977, 8.11069489], [77.38957977, 8.11097336], [77.38903046, 8.11097145], [77.38903046, 8.11125088], [77.38819122, 8.11125088], [77.38819122, 8.11152935], [77.38735962, 8.11152935], [77.38735962, 8.11180973], [77.38652802, 8.11180496], [77.38652802, 8.11208344], [77.38569641, 8.11208344], [77.38569641, 8.11236095], [77.38430786, 8.11236095], [77.38430786, 8.11263943], [77.38319397, 8.11263943], [77.38319397, 8.11291695], [77.38236237, 8.11291695], [77.38236237, 8.11319542], [77.38097382, 8.11319542], [77.38097382, 8.11347103], [77.37958527, 8.11347103], [77.37958527, 8.11374855], [77.378479, 8.11374855], [77.378479, 8.11403179], [77.3779068, 8.11403179], [77.3779068, 8.11431026], [77.37735748, 8.11431026], [77.37735748, 8.11403179], [77.37680817, 8.11403179], [77.37680817, 8.11431026], [77.37513733, 8.11430454], [77.37513733, 8.11458302], [77.37430573, 8.11458302], [77.37430573, 8.11486244], [77.37346649, 8.11486244], [77.37346649, 8.11514187], [77.37291718, 8.11514187], [77.37291718, 8.11542034], [77.37264252, 8.11541843], [77.37264252, 8.11569309], [77.3720932, 8.11569118], [77.3720932, 8.1159811], [77.37097168, 8.1159811], [77.37097168, 8.11625195], [77.37069702, 8.11625004], [77.37069702, 8.11736202], [77.3704071, 8.11736202], [77.3704071, 8.11708069], [77.36875153, 8.11708355], [77.36875153, 8.11736202], [77.36818695, 8.11736202], [77.36818695, 8.11763954], [77.36763763, 8.11763954], [77.36763763, 8.11791992], [77.36624908, 8.11791801], [77.36624908, 8.11819363], [77.36597443, 8.11819363], [77.36597443, 8.1184721], [77.36569214, 8.11846924], [77.36569214, 8.11874962], [77.36486053, 8.11874962], [77.36486053, 8.11904144], [77.36458588, 8.11904144], [77.36458588, 8.11931038], [77.36402893, 8.11930561], [77.36402893, 8.11958408], [77.36374664, 8.11958408], [77.36374664, 8.1198597], [77.36347198, 8.1198597], [77.36347198, 8.11958408], [77.36180878, 8.11958408], [77.36180878, 8.1198597], [77.36125183, 8.1198597], [77.36125183, 8.12014008], [77.35958099, 8.12014008], [77.35958099, 8.12042046], [77.35902405, 8.12041569], [77.35902405, 8.12069416], [77.35736084, 8.12069416], [77.35736084, 8.12097168], [77.35708618, 8.12097168], [77.35708618, 8.12125015], [77.35679626, 8.12125015], [77.35679626, 8.12152958], [77.35542297, 8.12152958], [77.35542297, 8.12125015], [77.35514069, 8.12125015], [77.35514069, 8.12152958], [77.35457611, 8.12152958], [77.35457611, 8.12181091], [77.35402679, 8.12180614], [77.35402679, 8.12208366], [77.3529129, 8.12208366], [77.3529129, 8.12236214], [77.3520813, 8.12236023], [77.3520813, 8.12263966], [77.35180664, 8.12263966], [77.35180664, 8.12236023], [77.35098267, 8.12236023], [77.35098267, 8.12263966], [77.35041809, 8.12263966], [77.35041809, 8.12292099], [77.34902954, 8.12291622], [77.34902954, 8.12319374], [77.34819794, 8.12319374], [77.34819794, 8.12291622], [77.34764099, 8.12292099], [77.34764099, 8.12263966], [77.3473587, 8.12263966], [77.3473587, 8.12292099], [77.34680939, 8.12291622], [77.34680176, 8.12319374], [77.34625244, 8.12319374], [77.34625244, 8.12347221], [77.34485626, 8.12347031], [77.34485626, 8.12374973], [77.34401703, 8.12374973], [77.34401703, 8.12403107], [77.34348297, 8.12403107], [77.34348297, 8.12431145], [77.34208679, 8.12431145], [77.34208679, 8.12403107], [77.3409729, 8.12403107], [77.3409729, 8.12431145], [77.34041595, 8.12430573], [77.34041595, 8.1245842], [77.33985901, 8.1245842], [77.33985901, 8.12485981], [77.33930969, 8.12485123], [77.33930969, 8.12514019], [77.33735657, 8.12514019], [77.33735657, 8.12542057], [77.33597565, 8.1254158], [77.33597565, 8.12569427], [77.33513641, 8.12569427], [77.33513641, 8.12597179], [77.33318329, 8.12596989], [77.33319092, 8.12625027], [77.3326416, 8.12625027], [77.3326416, 8.12597179], [77.33207703, 8.12596989], [77.33208466, 8.12625027], [77.33097076, 8.12625027], [77.33097076, 8.12653065], [77.33013916, 8.12653065], [77.33013916, 8.12625027], [77.32818604, 8.12625027], [77.32818604, 8.12596989], [77.32791901, 8.12597179], [77.32791901, 8.12569427], [77.32763672, 8.12569427], [77.32763672, 8.12597179], [77.32680511, 8.12597179], [77.32681274, 8.12625027], [77.32596588, 8.12625027], [77.32596588, 8.12653065], [77.32485962, 8.12653065], [77.32485962, 8.12625027], [77.32402802, 8.12625027], [77.32402802, 8.12597179], [77.32347107, 8.12597179], [77.32347107, 8.12513828], [77.32375336, 8.12514019], [77.32375336, 8.12431145], [77.32347107, 8.12431145], [77.32347107, 8.12403107], [77.32319641, 8.12403107], [77.32319641, 8.12347031], [77.32291412, 8.12347221], [77.32291412, 8.12236214], [77.32263947, 8.12236214], [77.32263947, 8.12208366], [77.32180786, 8.12208366], [77.32180786, 8.12236214], [77.3215332, 8.12236023], [77.3215332, 8.12263966], [77.32124329, 8.12263966], [77.32124329, 8.12292099], [77.32096863, 8.12291622], [77.32096863, 8.12319374], [77.32069397, 8.12319374], [77.32069397, 8.12291622], [77.32041931, 8.12292099], [77.32041931, 8.12263966], [77.31986237, 8.12263966], [77.31986237, 8.12292099], [77.31958008, 8.12291622], [77.31958008, 8.12319374], [77.31874847, 8.12319374], [77.31874847, 8.12097168], [77.31847382, 8.12097168], [77.31847382, 8.12069416], [77.31764221, 8.12069416], [77.31764221, 8.12097168], [77.31708527, 8.12097168], [77.31708527, 8.12125015], [77.31680298, 8.12125015], [77.31680298, 8.12097168], [77.31597137, 8.12097168], [77.31597137, 8.12125015], [77.31569672, 8.12125015], [77.31569672, 8.12152958], [77.3154068, 8.12152958], [77.3154068, 8.12181091], [77.31513977, 8.12180614], [77.31513977, 8.12208366], [77.31485748, 8.12208366], [77.31485748, 8.12236214], [77.31458282, 8.12236023], [77.31458282, 8.12292099], [77.31430817, 8.12291622], [77.31430817, 8.12319374], [77.31402588, 8.12319374], [77.31402588, 8.12347221], [77.31291962, 8.12347031], [77.31291962, 8.12374973], [77.31236267, 8.12374973], [77.31236267, 8.12403107], [77.31207275, 8.12403107], [77.31207275, 8.12431145], [77.31153107, 8.12430573], [77.31153107, 8.12569427], [77.31124878, 8.12569427], [77.31121826, 8.12597179], [77.31096649, 8.12596989], [77.31097412, 8.12625027], [77.31041718, 8.12625027], [77.31041718, 8.12653065], [77.31014252, 8.12653065], [77.31014252, 8.12681103], [77.30847168, 8.12680435], [77.30847168, 8.12708473], [77.30791473, 8.12708473], [77.30791473, 8.12736034], [77.30764008, 8.12736034], [77.30764008, 8.12764072], [77.30735779, 8.12764072], [77.30735779, 8.1279211], [77.30708313, 8.12791634], [77.30708313, 8.12819386], [77.30680847, 8.12819386], [77.30680847, 8.12791634], [77.30652618, 8.1279211], [77.30652618, 8.12764072], [77.30625916, 8.12764072], [77.30625916, 8.1279211], [77.30569458, 8.12791634], [77.30569458, 8.12847328], [77.30596924, 8.12847042], [77.30596924, 8.12903118], [77.30568695, 8.12903118], [77.30568695, 8.12931061], [77.30596924, 8.12931061], [77.30596924, 8.13042068], [77.30568695, 8.13042068], [77.30568695, 8.13097954], [77.30513763, 8.13097286], [77.30513763, 8.13125134], [77.30430603, 8.13125134], [77.30430603, 8.13152885], [77.3034668, 8.13152885], [77.3034668, 8.13180923], [77.30374908, 8.13180542], [77.30374908, 8.13208294], [77.30347443, 8.13208294], [77.30347443, 8.13236141], [77.30374908, 8.13236141], [77.30374908, 8.13319492], [77.30403137, 8.13319016], [77.30403137, 8.13375092], [77.30430603, 8.13375092], [77.30430603, 8.13402653], [77.30403137, 8.13401985], [77.30403137, 8.13514137], [77.30374908, 8.13514137], [77.30374908, 8.13541889], [77.30403137, 8.13541889], [77.30403137, 8.13764191], [77.30374908, 8.13763905], [77.30374908, 8.13847256], [77.3034668, 8.13847065], [77.3034668, 8.13875103], [77.30264282, 8.13875103], [77.30264282, 8.13902855], [77.30236053, 8.13902855], [77.30236053, 8.13875103], [77.30208588, 8.13875103], [77.30208588, 8.13931179], [77.30180359, 8.13930511], [77.30180359, 8.13958263], [77.30152893, 8.13958073], [77.30152893, 8.14015102], [77.30180359, 8.14013863], [77.30180359, 8.14069557], [77.30208588, 8.14069557], [77.30208588, 8.14097118], [77.30236053, 8.14097118], [77.30236053, 8.14153194], [77.30208588, 8.14152718], [77.30208588, 8.14319324], [77.30179596, 8.14319134], [77.30180359, 8.14375019], [77.30152893, 8.14375019], [77.30152893, 8.14402962], [77.30124664, 8.14402771], [77.30124664, 8.1445837], [77.30097198, 8.14458084], [77.30097198, 8.14513969], [77.30042267, 8.14513969], [77.30042267, 8.14542007], [77.30014038, 8.14541626], [77.30014038, 8.14569378], [77.29985809, 8.14569378], [77.29985809, 8.14597225], [77.29930878, 8.14595985], [77.29930878, 8.14624977], [77.29902649, 8.14624977], [77.29902649, 8.14680958], [77.29875183, 8.14680576], [77.29875183, 8.14708424], [77.29846954, 8.14708424], [77.29846954, 8.14735985], [77.29818726, 8.14735985], [77.29818726, 8.14764023], [77.29792023, 8.14764023], [77.29792023, 8.14791965], [77.29763794, 8.14791584], [77.29763794, 8.14819431], [77.29736328, 8.14819431], [77.29736328, 8.14847183], [77.29707336, 8.14847183], [77.29708099, 8.14875031], [77.29680634, 8.14875031], [77.29680634, 8.14931107], [77.29652405, 8.1493063], [77.29652405, 8.14958191], [77.29486084, 8.14958382], [77.29486084, 8.14986229], [77.29458618, 8.14986038], [77.29458618, 8.15014267], [77.29429626, 8.15014267], [77.29429626, 8.15042114], [77.29402924, 8.15041637], [77.29402924, 8.15069389], [77.29347229, 8.15069389], [77.29347229, 8.15097237], [77.29319763, 8.15097046], [77.29319763, 8.15124989], [77.29292297, 8.15124989], [77.29292297, 8.15153122], [77.29264069, 8.15153122], [77.29264069, 8.15181065], [77.2923584, 8.15181065], [77.2923584, 8.15209103], [77.29207611, 8.15209103], [77.29208374, 8.15235996], [77.29096985, 8.15235996], [77.29096985, 8.15264034], [77.29070282, 8.15264034], [77.29070282, 8.15292072], [77.29013824, 8.15291595], [77.29013824, 8.15319443], [77.28985596, 8.15318966], [77.28986359, 8.15375042], [77.28930664, 8.15375042], [77.28930664, 8.1540308], [77.28901672, 8.1540308], [77.28901672, 8.15431118], [77.28874969, 8.15430737], [77.28874969, 8.15458202], [77.28791809, 8.15458202], [77.28791809, 8.15485954], [77.28736115, 8.15485954], [77.28736115, 8.15515041], [77.28652954, 8.15513802], [77.28652954, 8.15569496], [77.28624725, 8.15569019], [77.28624725, 8.15625095], [77.2859726, 8.15625095], [77.2859726, 8.15680885], [77.2848587, 8.15680695], [77.2848587, 8.15708256], [77.2840271, 8.15708256], [77.2840271, 8.15736103], [77.28375244, 8.15736103], [77.28375244, 8.15764141], [77.28320313, 8.15764141], [77.28320313, 8.15792084], [77.28236389, 8.15791702], [77.28236389, 8.15819454], [77.2820816, 8.15819454], [77.2820816, 8.15847301], [77.28263855, 8.15847111], [77.28263855, 8.15875053], [77.28206635, 8.15875053], [77.28206635, 8.15903091], [77.28180695, 8.15903091], [77.28180695, 8.15930939], [77.28125, 8.15930462], [77.28125, 8.15958309], [77.28097534, 8.15958309], [77.28097534, 8.15986061], [77.2804184, 8.15986061], [77.2804184, 8.16014099], [77.27986145, 8.16014099], [77.27986145, 8.16042137], [77.27958679, 8.1604166], [77.27958679, 8.16069508], [77.27902985, 8.16069508], [77.27902985, 8.1609726], [77.27874756, 8.16095924], [77.27874756, 8.16125107], [77.27819824, 8.16125107], [77.27819824, 8.16153145], [77.27791595, 8.16153145], [77.27791595, 8.16181183], [77.27735901, 8.16180515], [77.27735901, 8.16208267], [77.27680206, 8.16208267], [77.27680206, 8.16236115], [77.27625275, 8.16236115], [77.27625275, 8.16264057], [77.2756958, 8.16264057], [77.2756958, 8.16292191], [77.27513885, 8.16291714], [77.27513885, 8.16319466], [77.27430725, 8.16319466], [77.27430725, 8.16347313], [77.27375031, 8.16347122], [77.27375031, 8.16375065], [77.27319336, 8.16375065], [77.27319336, 8.16403198], [77.27263641, 8.16403198], [77.27263641, 8.16431046], [77.2720871, 8.16430473], [77.2720871, 8.16458321], [77.27153015, 8.16458321], [77.27153015, 8.16486073], [77.27097321, 8.16486073], [77.27097321, 8.1651392], [77.27041626, 8.1651392], [77.27041626, 8.16541958], [77.26985931, 8.16541672], [77.26985931, 8.16569328], [77.26902771, 8.16569328], [77.26902771, 8.1659708], [77.26847076, 8.16597271], [77.26847076, 8.16624928], [77.26790619, 8.16624928], [77.26790619, 8.16652966], [77.26735687, 8.16652966], [77.26735687, 8.16681004], [77.26680756, 8.16681004], [77.26680756, 8.16709042], [77.26625061, 8.16708279], [77.26625061, 8.16736126], [77.26597595, 8.16736126], [77.26597595, 8.16764164], [77.26541901, 8.16764164], [77.26541901, 8.16792202], [77.26486206, 8.16791534], [77.26486206, 8.16819572], [77.26430511, 8.16819572], [77.26430511, 8.16847134], [77.26403046, 8.16847134], [77.26403046, 8.16874886], [77.26346588, 8.16874886], [77.26346588, 8.16903019], [77.26291656, 8.16903019], [77.26291656, 8.16930962], [77.26235962, 8.1693058], [77.26235962, 8.16958427], [77.26207733, 8.16958141], [77.26208496, 8.16986179], [77.26152802, 8.16986179], [77.26152802, 8.17014027], [77.26069641, 8.17013073], [77.26069641, 8.17041969], [77.25986481, 8.17041779], [77.25986481, 8.17069435], [77.25930786, 8.17069435], [77.25930786, 8.17097187], [77.25846863, 8.17097187], [77.25846863, 8.17125034], [77.25791931, 8.17125034], [77.25791931, 8.17152977], [77.25708008, 8.17152977], [77.25708008, 8.17181015], [77.25653076, 8.17180634], [77.25653076, 8.17208385], [77.25569153, 8.17208385], [77.25569153, 8.17236233], [77.25514984, 8.17236042], [77.25514984, 8.17263985], [77.25374603, 8.17263985], [77.25374603, 8.17292023], [77.25263977, 8.17291641], [77.25263977, 8.17319584], [77.25069427, 8.17319584], [77.25069427, 8.17291641], [77.24958038, 8.17292023], [77.24958038, 8.17263985], [77.24846649, 8.17263985], [77.24846649, 8.17236042], [77.24819183, 8.17236042], [77.24819183, 8.17263985], [77.24764252, 8.17263985], [77.24764252, 8.17292023], [77.24680328, 8.17291641], [77.24680328, 8.17319584], [77.24624634, 8.17319584], [77.24624634, 8.1734724], [77.24595642, 8.17346954], [77.24595642, 8.17374992], [77.24569702, 8.17374992], [77.24569702, 8.1740303], [77.2454071, 8.1740303], [77.2454071, 8.17431068], [77.24514008, 8.17430592], [77.24514008, 8.17458439], [77.24485779, 8.17458439], [77.24485779, 8.17486191], [77.24458313, 8.17486191], [77.24458313, 8.17514038], [77.24430847, 8.17514038], [77.24430847, 8.17542267], [77.24375153, 8.17541599], [77.24375153, 8.17569447], [77.24346924, 8.17569447], [77.24346924, 8.17597198], [77.24318695, 8.17597198], [77.24319458, 8.17625046], [77.24291992, 8.17625046], [77.24291992, 8.17653275], [77.23930359, 8.17652798], [77.23930359, 8.17736244], [77.23902893, 8.17735958], [77.23902893, 8.1779213], [77.23874664, 8.17791557], [77.23874664, 8.17819405], [77.23847198, 8.17819405], [77.23847198, 8.17847157], [77.23819733, 8.17846966], [77.23819733, 8.17875004], [77.23792267, 8.17875004], [77.23792267, 8.17903137], [77.23764038, 8.17903137], [77.23764038, 8.17932034], [77.23708344, 8.17930603], [77.23708344, 8.17958355], [77.23680878, 8.17958355], [77.23680878, 8.17986012], [77.23625183, 8.17986012], [77.23625183, 8.18014145], [77.23596954, 8.18014145], [77.23596954, 8.18042088], [77.23542023, 8.18041611], [77.23542023, 8.18069363], [77.23513794, 8.18069363], [77.23513794, 8.1809721], [77.23486328, 8.18097019], [77.23486328, 8.18124962], [77.23458099, 8.18124962], [77.23458099, 8.18181133], [77.23430634, 8.18180656], [77.23430634, 8.18208218], [77.23401642, 8.18207073], [77.23401642, 8.18264103], [77.23374939, 8.18263817], [77.23374939, 8.18319511], [77.23347473, 8.18319511], [77.23347473, 8.18347263], [77.23319244, 8.18347263], [77.23319244, 8.18375111], [77.23264313, 8.18375111], [77.23264313, 8.18403053], [77.23208618, 8.18403053], [77.23208618, 8.18431091], [77.23180389, 8.18430519], [77.23180389, 8.18458271], [77.23152924, 8.18458271], [77.23152924, 8.18486118], [77.23124695, 8.18486118], [77.23124695, 8.1851387], [77.23069763, 8.18513203], [77.23069763, 8.18542099], [77.23041534, 8.18541718], [77.23041534, 8.18736076], [77.23014069, 8.18735886], [77.23014069, 8.18792152], [77.2298584, 8.18791676], [77.2298584, 8.18847084], [77.22930908, 8.18847084], [77.22930908, 8.18875122], [77.22846985, 8.18875122], [77.22846985, 8.18903065], [77.2279129, 8.18902683], [77.2279129, 8.18958282], [77.22763824, 8.18958092], [77.22763824, 8.19014072], [77.22736359, 8.19013882], [77.22736359, 8.19069481], [77.2270813, 8.19069099], [77.2270813, 8.19126034], [77.22680664, 8.19126034], [77.22680664, 8.19180965], [77.22651672, 8.19180965], [77.22652435, 8.19236088], [77.22624969, 8.19236088], [77.22624969, 8.19291973], [77.22597504, 8.19291687], [77.22597504, 8.19374943], [77.22541809, 8.19374943], [77.22541809, 8.19402981], [77.22458649, 8.19402981], [77.22458649, 8.19432068], [77.2243042, 8.19430542], [77.2243042, 8.19486141], [77.22402954, 8.19486141], [77.22402954, 8.19569111], [77.22374725, 8.19569969], [77.22374725, 8.19625187], [77.2234726, 8.19625187], [77.2234726, 8.19653034], [77.22292328, 8.19653034], [77.22292328, 8.19680977], [77.22264099, 8.19680595], [77.22264099, 8.19694042], [77.22264099, 8.19708443], [77.2224884, 8.19708443], [77.2223587, 8.19708443], [77.2223587, 8.19736195], [77.22203827, 8.19736195], [77.22180939, 8.19736195], [77.22179413, 8.19752121], [77.2217865, 8.19764042], [77.22162628, 8.19767761], [77.2215271, 8.19770145], [77.2215271, 8.19791985], [77.22125244, 8.19791794], [77.22125244, 8.19819355], [77.2206955, 8.19819355], [77.2206955, 8.19847202], [77.22041321, 8.19847202], [77.22041321, 8.19874954], [77.22013855, 8.19874954], [77.22013855, 8.19902992], [77.2195816, 8.19902992], [77.2195816, 8.1993103], [77.21930695, 8.19930553], [77.21930695, 8.19958401], [77.21902466, 8.19958401], [77.21902466, 8.19986153], [77.21847534, 8.19986153], [77.21847534, 8.20014], [77.21819305, 8.20013142], [77.21819305, 8.20042038], [77.21763611, 8.20041561], [77.21763611, 8.20069408], [77.21736145, 8.20069408], [77.21736145, 8.2009716], [77.21679687, 8.2009697], [77.21679687, 8.20125008], [77.21652985, 8.20125008], [77.21652985, 8.20153046], [77.21598053, 8.20153046], [77.21598053, 8.20181274], [77.21569824, 8.20180607], [77.21569824, 8.20208359], [77.2151413, 8.20208359], [77.2151413, 8.20236206], [77.21485901, 8.20236015], [77.21485901, 8.20263958], [77.21430206, 8.20263958], [77.21430206, 8.20292091], [77.2140274, 8.20292091], [77.2140274, 8.20320129], [77.21347046, 8.20319366], [77.21347046, 8.20347214], [77.21290588, 8.20347023], [77.21290588, 8.20374966], [77.21235657, 8.20374966], [77.21235657, 8.20403004], [77.21180725, 8.20403004], [77.21180725, 8.20431137], [77.21125031, 8.20430565], [77.21125031, 8.20458412], [77.21069336, 8.20458412], [77.21069336, 8.20485973], [77.21013641, 8.20485973], [77.21013641, 8.20514011], [77.2095871, 8.20514011], [77.2095871, 8.20542145], [77.20903015, 8.20541573], [77.20903015, 8.2056942], [77.20847321, 8.2056942], [77.20847321, 8.20597172], [77.20819092, 8.20597172], [77.20819092, 8.20626163], [77.2076416, 8.20626163], [77.2076416, 8.20653057], [77.20707703, 8.20653057], [77.20707703, 8.20681095], [77.20680237, 8.20680428], [77.20680237, 8.2070837], [77.20625305, 8.2070837], [77.20625305, 8.20736027], [77.20597076, 8.20736027], [77.20597076, 8.20764065], [77.20540619, 8.20764065], [77.20540619, 8.20792103], [77.20513916, 8.20791626], [77.20513916, 8.20819378], [77.20458221, 8.20819378], [77.20458221, 8.20847225], [77.20430756, 8.20847034], [77.20430756, 8.20875072], [77.20375061, 8.20875072], [77.20375061, 8.20903111], [77.20347595, 8.2090292], [77.20347595, 8.20930672], [77.20291901, 8.20930672], [77.20291901, 8.20958233], [77.20263672, 8.20958233], [77.20263672, 8.20985985], [77.20207977, 8.20985985], [77.20207977, 8.21014118], [77.20181274, 8.21014118], [77.20181274, 8.21042061], [77.20124817, 8.21041679], [77.20124817, 8.21069527], [77.20069122, 8.21069527], [77.20069122, 8.21097279], [77.20041656, 8.21097279], [77.20041656, 8.21125126], [77.19985962, 8.21125126], [77.19985962, 8.21153069], [77.19930267, 8.21153069], [77.19930267, 8.21181107], [77.19875336, 8.21180534], [77.19875336, 8.21208286], [77.19847107, 8.21208477], [77.19847107, 8.21236134], [77.19790649, 8.21236134], [77.19790649, 8.21263885], [77.19735718, 8.21263885], [77.19735718, 8.21291924], [77.19680786, 8.21291733], [77.19680786, 8.21319485], [77.19625092, 8.21319485], [77.19625092, 8.21347332], [77.19568634, 8.21347141], [77.19568634, 8.21375084], [77.19513702, 8.21375084], [77.19513702, 8.21403122], [77.19458008, 8.21403122], [77.19458008, 8.2143116], [77.19403076, 8.21430492], [77.19403076, 8.2145834], [77.19346619, 8.21458054], [77.19347382, 8.21486092], [77.19291687, 8.21486092], [77.19291687, 8.2151413], [77.19181061, 8.2151413], [77.19181061, 8.21543121], [77.19125366, 8.21541691], [77.19125366, 8.21569538], [77.19041443, 8.21569538], [77.19041443, 8.21597099], [77.18985748, 8.21597099], [77.18985748, 8.21625137], [77.18930817, 8.21625137], [77.18930817, 8.21652889], [77.18875122, 8.21652889], [77.18875122, 8.21681023], [77.18846893, 8.21680546], [77.18846893, 8.21708298], [77.18791962, 8.21708298], [77.18791962, 8.21736145], [77.18736267, 8.21736145], [77.18736267, 8.21764088], [77.18681335, 8.21764088], [77.18681335, 8.21791935], [77.18653107, 8.21791935], [77.18653107, 8.21819973], [77.18597412, 8.21819305], [77.18597412, 8.21847343], [77.18567657, 8.21847057], [77.18567657, 8.21875095], [77.18541718, 8.21875095], [77.18541718, 8.21902943], [77.18514252, 8.21902943], [77.18514252, 8.21930981], [77.18458557, 8.21930504], [77.18458557, 8.21958256], [77.18430328, 8.21958256], [77.18430328, 8.21986103], [77.18402863, 8.21986103], [77.18402863, 8.22042179], [77.18374634, 8.22041702], [77.18374634, 8.22097111], [77.18347168, 8.22097111], [77.18347168, 8.22124863], [77.18319702, 8.22124004], [77.18319702, 8.22181034], [77.18291473, 8.22180462], [77.18291473, 8.22236156], [77.18264008, 8.22236156], [77.18264008, 8.22292042], [77.18235779, 8.22291756], [77.18235779, 8.22319317], [77.18208313, 8.22319126], [77.18208313, 8.22375202], [77.18180847, 8.22375011], [77.18180847, 8.22458363], [77.18152618, 8.22457886], [77.18152618, 8.22542], [77.18125153, 8.22542], [77.18125153, 8.22624969], [77.18096924, 8.22624969], [77.18096924, 8.22681046], [77.18069458, 8.22680569], [77.18069458, 8.22708416], [77.17987061, 8.22707939], [77.17987061, 8.22737122], [77.17958069, 8.22737122], [77.17958069, 8.22764015], [77.17930603, 8.22764015], [77.17930603, 8.22791958], [77.17903137, 8.22791576], [77.17903137, 8.22819424], [77.17874908, 8.22819424], [77.17874908, 8.22847176], [77.1784668, 8.22846985], [77.17847443, 8.22875023], [77.17819214, 8.22875023], [77.17819214, 8.22902966], [77.17791748, 8.22902966], [77.17791748, 8.22931099], [77.17763519, 8.22930622], [77.17763519, 8.22986221], [77.17736053, 8.22986031], [77.17736053, 8.23013973], [77.17708588, 8.23013973], [77.17708588, 8.23042965], [77.17680359, 8.2304163], [77.17680359, 8.23069382], [77.17652893, 8.23069382], [77.17652893, 8.23097229], [77.17624664, 8.23097038], [77.17624664, 8.23125172], [77.17597198, 8.23125172], [77.17597198, 8.23181057], [77.17569733, 8.2318058], [77.17569733, 8.23208427], [77.17541504, 8.23208427], [77.17541504, 8.23235989], [77.17514038, 8.23235989], [77.17514038, 8.23264027], [77.17485809, 8.23264027], [77.17485809, 8.23292065], [77.17458344, 8.23291588], [77.17458344, 8.23319435], [77.17430878, 8.23319435], [77.17430878, 8.23347187], [77.17373657, 8.23346996], [77.17375183, 8.23375034], [77.17346954, 8.23375034], [77.17346954, 8.23403072], [77.17318726, 8.23403072], [77.17318726, 8.2343111], [77.17292023, 8.23430634], [77.17292023, 8.23458195], [77.17263794, 8.23458195], [77.17263794, 8.23486042], [77.17236328, 8.23486042], [77.17236328, 8.2351408], [77.17208099, 8.2351408], [77.17208099, 8.23542118], [77.17180634, 8.23541641], [77.17180634, 8.23569393], [77.17124939, 8.23569393], [77.17124939, 8.23597336], [77.17097473, 8.23597336], [77.17097473, 8.23625088], [77.17067719, 8.23624134], [77.17067719, 8.23653126], [77.17041779, 8.23653126], [77.17041779, 8.23681068], [77.16986084, 8.23680687], [77.16986084, 8.23736095], [77.1701355, 8.23736095], [77.1701355, 8.23847294], [77.16986084, 8.23847294], [77.16986084, 8.23875141], [77.16958618, 8.23875141], [77.16958618, 8.23903084], [77.16929626, 8.23903084], [77.16929626, 8.23930931], [77.16874695, 8.23930454], [77.16874695, 8.23958302], [77.16847229, 8.23958015], [77.16847229, 8.24014091], [77.16819763, 8.24014091], [77.16819763, 8.2404213], [77.16791534, 8.24041653], [77.16791534, 8.24097347], [77.16764069, 8.24097061], [77.16764069, 8.24264145], [77.1673584, 8.24264145], [77.1673584, 8.24375057], [77.16707611, 8.24375057], [77.16707611, 8.24431038], [77.16680908, 8.24430466], [77.16680908, 8.24486065], [77.16625214, 8.24486065], [77.16625214, 8.24514103], [77.16569519, 8.24513912], [77.16569519, 8.24569321], [77.1645813, 8.24569321], [77.1645813, 8.24597263], [77.16402435, 8.24597263], [77.16402435, 8.2462492], [77.16348267, 8.2462492], [77.16348267, 8.24652863], [77.16208649, 8.24652863], [77.16208649, 8.24597073], [77.1618042, 8.24597263], [77.1618042, 8.24569321], [77.16208649, 8.24569321], [77.16208649, 8.24541664], [77.16291809, 8.24541664], [77.16291809, 8.24486065], [77.1626358, 8.24486065], [77.1626358, 8.24514103], [77.16236115, 8.24514103], [77.16236115, 8.24458122], [77.16208649, 8.24458313], [77.16208649, 8.24486065], [77.16179657, 8.24486065], [77.16179657, 8.24514103], [77.16152954, 8.24513912], [77.16152954, 8.24541664], [77.16124725, 8.24541664], [77.16124725, 8.24569321], [77.1609726, 8.24569321], [77.1609726, 8.24597263], [77.16041565, 8.24597263], [77.16041565, 8.2462492], [77.1598587, 8.2462492], [77.1598587, 8.24652863], [77.15930939, 8.24652863], [77.15930176, 8.24680996], [77.15875244, 8.24680519], [77.15875244, 8.24708271], [77.15847015, 8.24708271], [77.15847015, 8.24736118], [77.15820313, 8.24735928], [77.15820313, 8.24792194], [77.15791321, 8.24791527], [77.15791321, 8.24819565], [77.15763855, 8.24819565], [77.15763855, 8.24847126], [77.1570816, 8.24847126], [77.1570816, 8.24875164], [77.15680695, 8.24875164], [77.15680695, 8.24903202], [77.15625, 8.24903202], [77.15625, 8.24930954], [77.15597534, 8.24930477], [77.15597534, 8.24986172], [77.15570068, 8.24985886], [77.15570068, 8.25014019], [77.15513611, 8.25014019], [77.15513611, 8.25041962], [77.15486145, 8.25041771], [77.15486145, 8.25069332], [77.1543045, 8.25069332], [77.1543045, 8.25097179], [77.15402985, 8.25097179], [77.15402985, 8.25125027], [77.1534729, 8.25125027], [77.1534729, 8.25154114], [77.15319824, 8.25154114], [77.15319824, 8.25181007], [77.1526413, 8.25180626], [77.1526413, 8.25208378], [77.15235901, 8.25208378], [77.15235901, 8.25236225], [77.15207672, 8.25236034], [77.15207672, 8.25263977], [77.1515274, 8.25263977], [77.1515274, 8.25292015], [77.15125275, 8.25291634], [77.15125275, 8.25319386], [77.15097046, 8.25319386], [77.15097046, 8.25347233], [77.15040588, 8.25346947], [77.15041351, 8.25374985], [77.15013885, 8.25374985], [77.15013885, 8.25403023], [77.14956665, 8.25403023], [77.14956665, 8.25430965], [77.14930725, 8.25430584], [77.14930725, 8.25458431], [77.14902496, 8.25458431], [77.14902496, 8.25486183], [77.14848328, 8.25486183], [77.14848328, 8.2551403], [77.14819336, 8.2551403], [77.14819336, 8.25541973], [77.1479187, 8.25541592], [77.1479187, 8.25569439], [77.14736176, 8.25569439], [77.14736176, 8.25597191], [77.1470871, 8.25597191], [77.1470871, 8.25625038], [77.14653015, 8.25625038], [77.14653015, 8.25681114], [77.14624786, 8.25680637], [77.14624786, 8.25736237], [77.14597321, 8.25735092], [77.14597321, 8.25764275], [77.14541626, 8.25764275], [77.14541626, 8.25792122], [77.1451416, 8.25791645], [77.1451416, 8.25819397], [77.14458466, 8.25819397], [77.14458466, 8.25847244], [77.14402771, 8.25846958], [77.14402771, 8.25874996], [77.14376068, 8.25874996], [77.14376068, 8.2590313], [77.14319611, 8.2590313], [77.14319611, 8.25931072], [77.14291382, 8.25930595], [77.14291382, 8.25958443], [77.14235687, 8.25957966], [77.1423645, 8.25986004], [77.14125061, 8.25986004], [77.14125061, 8.26014042], [77.14041901, 8.26013756], [77.14041901, 8.26041603], [77.14013672, 8.26041603], [77.14013672, 8.26069355], [77.13986206, 8.26069355], [77.13986206, 8.26097202], [77.13957977, 8.26097012], [77.13957977, 8.26124954], [77.13903046, 8.26124954], [77.13903046, 8.26153088], [77.13874817, 8.26153088], [77.13874817, 8.26181126], [77.13847351, 8.26180744], [77.13847351, 8.2620821], [77.13791656, 8.2620821], [77.13791656, 8.26236343], [77.13762665, 8.26235962], [77.13762665, 8.26264095], [77.13735962, 8.26264095], [77.13735962, 8.26292133], [77.13708496, 8.26291561], [77.13708496, 8.26319504], [77.13680267, 8.26319027], [77.13680267, 8.26347923], [77.13652802, 8.26347923], [77.13652802, 8.26375103], [77.13625336, 8.26375103], [77.13625336, 8.26403141], [77.13597107, 8.26403141], [77.13597107, 8.26431084], [77.13541412, 8.26430416], [77.13541412, 8.26458263], [77.13513947, 8.26458263], [77.13513947, 8.26486111], [77.13456726, 8.26486111], [77.13456726, 8.26514053], [77.13430786, 8.26514053], [77.13430786, 8.26542091], [77.13375092, 8.2654171], [77.13375092, 8.26569462], [77.13346863, 8.26569462], [77.13346863, 8.26597309], [77.13291931, 8.26597118], [77.13291931, 8.26625061], [77.13263702, 8.26625061], [77.13263702, 8.26653957], [77.13153076, 8.26653957], [77.13153076, 8.26681232], [77.13124847, 8.2668047], [77.13124847, 8.26708317], [77.13096619, 8.26708031], [77.13097382, 8.26736069], [77.13069153, 8.26736069], [77.13069153, 8.26792145], [77.13041687, 8.26791668], [77.13041687, 8.26819515], [77.13014221, 8.26819515], [77.13014221, 8.26847267], [77.12985992, 8.26847267], [77.12985992, 8.26875114], [77.1295929, 8.26875114], [77.1295929, 8.26903057], [77.12847137, 8.26902676], [77.12847137, 8.26958275], [77.12819672, 8.26958275], [77.12819672, 8.26986122], [77.12763977, 8.26986122], [77.12763977, 8.27014065], [77.12735748, 8.27014065], [77.12735748, 8.27042198], [77.12708282, 8.27041721], [77.12708282, 8.27069473], [77.12652588, 8.27069473], [77.12652588, 8.27097321], [77.12625122, 8.2709713], [77.12625122, 8.27125072], [77.12596893, 8.27125072], [77.12596893, 8.2715292], [77.12541962, 8.2715292], [77.12541962, 8.27180958], [77.12513733, 8.27180481], [77.12513733, 8.27208328], [77.12458038, 8.27208328], [77.12458038, 8.2723608], [77.12403107, 8.27235031], [77.12403107, 8.27263927], [77.12346649, 8.27263927], [77.12346649, 8.27291965], [77.12291718, 8.27291679], [77.12291718, 8.27319527], [77.12264252, 8.27319527], [77.12264252, 8.27347088], [77.12236023, 8.27347088], [77.12236023, 8.27374935], [77.1220932, 8.27374935], [77.1220932, 8.27403164], [77.12152863, 8.27403164], [77.12152863, 8.27431202], [77.12124634, 8.27430534], [77.12124634, 8.27458286], [77.12097168, 8.27458286], [77.12097168, 8.27486134], [77.12069702, 8.27486134], [77.12069702, 8.27513885], [77.1204071, 8.27513885], [77.1204071, 8.27542019], [77.11985779, 8.27541542], [77.11985779, 8.2756958], [77.11958313, 8.2756958], [77.11958313, 8.27597141], [77.11930847, 8.27597141], [77.11930847, 8.27625179], [77.11902618, 8.27625179], [77.11902618, 8.27653027], [77.11846924, 8.27653027], [77.11846924, 8.27680969], [77.11819458, 8.27680588], [77.11819458, 8.27708435], [77.11791992, 8.27708435], [77.11791992, 8.27736187], [77.11736298, 8.27736187], [77.11736298, 8.27764034], [77.11708069, 8.27764034], [77.11708069, 8.27791977], [77.11680603, 8.27791786], [77.11680603, 8.27819443], [77.11624908, 8.27819061], [77.11624908, 8.27848053], [77.1159668, 8.27848053], [77.11597443, 8.27875042], [77.11569214, 8.27875042], [77.11569214, 8.27902985], [77.11514282, 8.27902985], [77.11514282, 8.27931023], [77.11486053, 8.27930641], [77.11486053, 8.27958393], [77.11458588, 8.27958393], [77.11458588, 8.2798624], [77.11429596, 8.27985954], [77.11429596, 8.28013992], [77.11402893, 8.28013992], [77.11402893, 8.2804203], [77.11374664, 8.28041553], [77.11374664, 8.28069401], [77.11319733, 8.28069401], [77.11319733, 8.28097153], [77.11292267, 8.28096962], [77.11292267, 8.28125], [77.11235809, 8.28125], [77.11235809, 8.28154182], [77.11207581, 8.28154182], [77.11207581, 8.28181267], [77.11180878, 8.28180599], [77.11180878, 8.28208447], [77.11125183, 8.28208447], [77.11125183, 8.28236198], [77.11096954, 8.28236198], [77.11096954, 8.28264046], [77.11068726, 8.28264046], [77.11068726, 8.28292274], [77.11042023, 8.28291607], [77.11042023, 8.28319359], [77.10986328, 8.28319359], [77.10986328, 8.28347206], [77.10958099, 8.28347015], [77.10958099, 8.28374958], [77.10930634, 8.28374958], [77.10930634, 8.28402996], [77.10901642, 8.28402996], [77.10901642, 8.28431129], [77.10847473, 8.28430557], [77.10847473, 8.28458405], [77.10819244, 8.28458405], [77.10819244, 8.28486156], [77.10765076, 8.28485966], [77.10765076, 8.28514004], [77.10736084, 8.28514004], [77.10736084, 8.28542137], [77.10708618, 8.28541565], [77.10708618, 8.28569412], [77.10652924, 8.28569412], [77.10652924, 8.28597164], [77.10624695, 8.28596973], [77.10624695, 8.28625011], [77.10569763, 8.28625011], [77.10569763, 8.28653145], [77.10514069, 8.28653145], [77.10514069, 8.28681087], [77.10458374, 8.2868042], [77.10458374, 8.28708363], [77.10430908, 8.28708363], [77.10430908, 8.28736019], [77.10375214, 8.28736019], [77.10375214, 8.28764057], [77.10346985, 8.28764057], [77.10346985, 8.28792095], [77.1029129, 8.28791618], [77.1029129, 8.2881937], [77.10263824, 8.2881937], [77.10263824, 8.28847218], [77.1020813, 8.28847027], [77.1020813, 8.28874969], [77.10180664, 8.28874969], [77.10180664, 8.28903103], [77.10151672, 8.28903103], [77.10151672, 8.28931141], [77.10097504, 8.28930664], [77.10097504, 8.28958225], [77.10069275, 8.28958225], [77.10069275, 8.28985977], [77.10041809, 8.28985977], [77.10041809, 8.29042053], [77.09958649, 8.29041672], [77.09958649, 8.29069519], [77.09902954, 8.29069519], [77.09902954, 8.29097271], [77.09874725, 8.29097271], [77.09874725, 8.29125118], [77.09845734, 8.29125118], [77.09845734, 8.29153061], [77.09792328, 8.29153061], [77.09792328, 8.29181099], [77.09764099, 8.29180527], [77.09764099, 8.29208469], [77.09708405, 8.29208469], [77.09708405, 8.29236126], [77.09680939, 8.29236126], [77.09680176, 8.29264069], [77.0965271, 8.29263878], [77.0965271, 8.29319477], [77.09597015, 8.29319], [77.09597015, 8.29348183], [77.09513855, 8.29347324], [77.09513855, 8.29375076], [77.09485626, 8.29374886], [77.09485626, 8.29403114], [77.0945816, 8.29403114], [77.0945816, 8.29431152], [77.09430695, 8.29430485], [77.09430695, 8.29458332], [77.09401703, 8.29458141], [77.09402466, 8.29486084], [77.09375, 8.29486084], [77.09375, 8.29514122], [77.09319305, 8.29514122], [77.09319305, 8.2954216], [77.0929184, 8.29541683], [77.0929184, 8.2956953], [77.09236145, 8.2956953], [77.09236145, 8.2962513], [77.09208679, 8.2962513], [77.09208679, 8.29652691], [77.09179688, 8.29652023], [77.09179688, 8.29681015], [77.09124756, 8.29680538], [77.09124756, 8.2970829], [77.0909729, 8.2970829], [77.0909729, 8.29736137], [77.09069824, 8.29736137], [77.09069824, 8.29747009], [77.09648895, 8.29806995], [77.09822083, 8.30150032], [77.1046524, 8.30160046], [77.10085297, 8.31165123], [77.10883331, 8.31287956], [77.11152649, 8.31649017], [77.12194824, 8.32294178], [77.13062286, 8.32423019], [77.13703156, 8.32009125], [77.14470673, 8.32022953], [77.14977264, 8.32194233], [77.15210724, 8.31946182], [77.15483093, 8.31361103], [77.15965271, 8.31250095], [77.15966797, 8.31738091], [77.15318298, 8.32566071], [77.15106201, 8.33094025], [77.15093231, 8.3354702], [77.15680695, 8.34519958], [77.15460968, 8.35139942], [77.15203857, 8.35473061], [77.14749908, 8.35458088], [77.1415329, 8.3491497], [77.13577271, 8.34566975], [77.13537598, 8.35174084], [77.14322662, 8.36227131], [77.14121246, 8.36899185], [77.13584137, 8.37251091], [77.13481903, 8.37852955], [77.14074707, 8.38280964], [77.14579773, 8.38169956], [77.14939117, 8.37543964], [77.15368652, 8.37744141], [77.16448212, 8.38784027], [77.16709137, 8.39546013], [77.17222595, 8.40170002], [77.17977905, 8.409091], [77.18039703, 8.41860199], [77.18267059, 8.4274807], [77.18868256, 8.43474102], [77.19877625, 8.43677998], [77.20951843, 8.43771935], [77.21022797, 8.44305038], [77.2090683, 8.45068073], [77.20513153, 8.45551014], [77.19877625, 8.46023941], [77.19462585, 8.4693718], [77.19091797, 8.48819065], [77.18649292, 8.49337101], [77.1920166, 8.49938107], [77.19857788, 8.50393963], [77.20639038, 8.50443172], [77.21726227, 8.49613953], [77.22255707, 8.4883213], [77.22754669, 8.49059963], [77.23240662, 8.49591923], [77.24125671, 8.49812984], [77.24754333, 8.50137997], [77.25248718, 8.51708126], [77.25817108, 8.52812958], [77.26515961, 8.53744984], [77.26508331, 8.54255962], [77.25969696, 8.54906178], [77.25152588, 8.57098961], [77.24285889, 8.58055019], [77.23761749, 8.58842945], [77.2321167, 8.59211922], [77.22840881, 8.59781265], [77.22786713, 8.60309124], [77.22827911, 8.61290073], [77.21869659, 8.61837959], [77.21237946, 8.62877941], [77.20825195, 8.63115025], [77.20523071, 8.63528156], [77.1984787, 8.64109993], [77.19523621, 8.64868069], [77.19033813, 8.65489101], [77.18710327, 8.66229153], [77.19046783, 8.67118931], [77.18975067, 8.67737961], [77.18772125, 8.68376064], [77.18296814, 8.69003105], [77.17929077, 8.69961929], [77.17234802, 8.70324993], [77.16703033, 8.70763111], [77.16172791, 8.71516132], [77.16294098, 8.720891], [77.15737915, 8.73118114], [77.15531921, 8.73756027], [77.15724182, 8.74075985], [77.16274261, 8.73518085], [77.17093658, 8.73338032], [77.1765213, 8.73502064], [77.18107605, 8.74081039], [77.18370819, 8.74814034], [77.18344116, 8.75336075], [77.18076324, 8.75756168], [77.18300629, 8.76111031], [77.19143677, 8.75839138], [77.19780731, 8.75774193], [77.20224762, 8.76088047], [77.19933319, 8.76559067], [77.19837952, 8.76949978], [77.20529175, 8.77039146], [77.20960999, 8.77371025], [77.2146759, 8.77576065], [77.21536255, 8.78666019], [77.21736145, 8.79703045], [77.22396851, 8.79833126], [77.22735596, 8.80056], [77.23159027, 8.80709171], [77.23085785, 8.81157112], [77.23195648, 8.81346035], [77.23616791, 8.81762791], [77.24704742, 8.83187962], [77.2428894, 8.84123993], [77.24595642, 8.84307957], [77.24562073, 8.84508133], [77.24040985, 8.85147095], [77.24318695, 8.85509109], [77.24298859, 8.85927105], [77.24150085, 8.86478233], [77.23986816, 8.86806107], [77.23203278, 8.86905003], [77.22712708, 8.87181854], [77.22318268, 8.87781143], [77.22389984, 8.88514996], [77.22145081, 8.88813972], [77.21473694, 8.89212036], [77.2116394, 8.89305019], [77.20625305, 8.8931818], [77.20204163, 8.90668106], [77.20736694, 8.91389179], [77.20474243, 8.91741085], [77.1980896, 8.91930962], [77.19386292, 8.92191029], [77.18976593, 8.91957188], [77.18675232, 8.91567039], [77.18966675, 8.91257], [77.18476868, 8.9101696], [77.18044281, 8.91574955], [77.18061829, 8.91845131], [77.17919159, 8.92098045], [77.18187714, 8.92883015], [77.18164825, 8.93256092], [77.17967224, 8.93749046], [77.18123627, 8.94197083], [77.18016815, 8.94701958], [77.17529297, 8.95083046], [77.17473602, 8.95685196], [77.1632309, 8.96234035], [77.15844727, 8.97819138], [77.14689636, 8.98694992], [77.1440506, 8.99184132], [77.14392853, 8.99184132], [77.14319611, 8.99788094], [77.13725281, 8.99822044], [77.13424683, 8.99997997], [77.13510895, 9.00547028], [77.13326263, 9.00825119], [77.13217926, 9.01185036], [77.13648987, 9.01310062], [77.14055634, 9.01543045], [77.14689636, 9.02156067], [77.14533234, 9.02721977], [77.14824677, 9.03298187], [77.15376282, 9.03656006], [77.16742706, 9.0385313], [77.17014313, 9.03388023], [77.18208313, 9.03650093], [77.18019104, 9.04480076], [77.18286896, 9.04710102], [77.18434906, 9.05064011], [77.1886673, 9.05648041], [77.19148254, 9.06195164], [77.19284821, 9.06503105], [77.19062042, 9.06997013], [77.18974304, 9.07518005], [77.19586182, 9.08842182], [77.2022171, 9.09138012], [77.20482635, 9.09581089], [77.20935059, 9.09757042], [77.21173096, 9.10636139], [77.21704865, 9.10809135], [77.22572327, 9.1141386], [77.23015594, 9.1148119], [77.23258209, 9.11791134], [77.23766327, 9.1299696], [77.24537659, 9.13554955], [77.24606323, 9.13924026], [77.25177765, 9.14304066], [77.24960327, 9.15603924], [77.25229645, 9.16495132], [77.2483902, 9.17578125], [77.24550629, 9.17597008], [77.24328613, 9.17612076], [77.23661804, 9.17919064], [77.23957062, 9.18656063], [77.23973083, 9.18994999], [77.24704742, 9.18925953], [77.25026703, 9.19023991], [77.2532959, 9.19336033], [77.25817871, 9.20007038], [77.26680756, 9.20881939], [77.26139069, 9.21698093], [77.2594986, 9.22441101], [77.26364899, 9.23185921], [77.26248169, 9.24090958], [77.26566315, 9.24368095], [77.26590729, 9.25529099], [77.2678299, 9.25787067], [77.26760864, 9.26239967], [77.27411652, 9.26317024], [77.26714325, 9.28168964], [77.26682281, 9.2908802], [77.27011108, 9.29177094], [77.27345276, 9.29419136], [77.27768707, 9.29526043], [77.28350067, 9.30091], [77.28423309, 9.30506039], [77.28675842, 9.30811024], [77.28681946, 9.31006145], [77.2853775, 9.31560135], [77.28230286, 9.31961918], [77.28515625, 9.32123089], [77.28414154, 9.32747078], [77.28687286, 9.32690144], [77.29055023, 9.327672], [77.30010986, 9.32495022], [77.30702972, 9.327631], [77.31134033, 9.32790184], [77.30966187, 9.33464146], [77.32061005, 9.35109043], [77.32000732, 9.35480022], [77.32303619, 9.35856056], [77.31954193, 9.36326027], [77.31980133, 9.37613106], [77.32579041, 9.37868118], [77.32608795, 9.38046074], [77.32488251, 9.38354015], [77.32762909, 9.38980961], [77.3274231, 9.39406109], [77.32137299, 9.40180111], [77.32167816, 9.40565014], [77.3241272, 9.40818024], [77.33007813, 9.41521072], [77.33185577, 9.42138958], [77.33461761, 9.42393112], [77.3342514, 9.43105125], [77.34292603, 9.4404211], [77.34542847, 9.445261], [77.35160828, 9.44970131], [77.35655212, 9.44791031], [77.3602066, 9.44367981], [77.3636322, 9.4433012], [77.36765289, 9.44390106], [77.37223816, 9.44527054], [77.37858582, 9.45075035], [77.37737274, 9.45866013], [77.38220978, 9.46118069], [77.38683319, 9.46737099], [77.38405609, 9.46977997], [77.38391876, 9.47909069], [77.38551331, 9.48619175], [77.38788605, 9.49096012], [77.3962326, 9.49654198], [77.39486694, 9.50439072], [77.39008331, 9.50463104], [77.38639832, 9.50679111], [77.3867569, 9.51673985], [77.37071991, 9.50869179], [77.36625671, 9.51479053], [77.36097717, 9.51616955], [77.35470581, 9.52390957], [77.35054779, 9.52629185], [77.35057068, 9.54026031], [77.34880829, 9.5461998], [77.34655762, 9.5485611], [77.33996582, 9.54911041], [77.33805084, 9.55027008], [77.33743286, 9.55486012], [77.33587646, 9.55683041], [77.3405304, 9.56406116], [77.34371185, 9.56384945], [77.34525299, 9.56727028], [77.34091949, 9.57763958], [77.34320068, 9.58481121], [77.34481812, 9.58760929], [77.34623718, 9.58780956], [77.34922028, 9.58649921], [77.35132599, 9.58804035], [77.35106659, 9.58930016], [77.34089661, 9.59505081], [77.32850647, 9.57322979], [77.32478333, 9.5632], [77.32100677, 9.56737137], [77.31067657, 9.57036114], [77.30976105, 9.5759697], [77.31201172, 9.57815075], [77.31078339, 9.58450127], [77.31484985, 9.58862114], [77.31371307, 9.59013939], [77.30901337, 9.58883095], [77.30430603, 9.59304142], [77.28649139, 9.58729935], [77.27954102, 9.58006954], [77.27497101, 9.58095169], [77.27529144, 9.57658958], [77.26113892, 9.56667995], [77.25785828, 9.56816196], [77.25501251, 9.564991], [77.25054932, 9.56541061], [77.24672699, 9.56866074], [77.24475861, 9.56861115], [77.24198914, 9.57154083], [77.2388916, 9.57336044], [77.22989655, 9.57592201], [77.22280884, 9.57279015], [77.21466827, 9.57880116], [77.20910645, 9.58443928], [77.20861053, 9.58883953], [77.2053833, 9.59227943], [77.20081329, 9.5923996], [77.19657898, 9.59570026], [77.19593811, 9.60419178], [77.18596649, 9.60592175], [77.18398285, 9.6024313], [77.17914581, 9.60146046], [77.17456818, 9.59716129], [77.1672821, 9.60066891], [77.15550232, 9.60150146], [77.15187073, 9.60601997], [77.15487671, 9.60838127], [77.15457916, 9.61395168], [77.1622467, 9.61981106], [77.16065216, 9.6273098], [77.16062927, 9.63024139], [77.16588593, 9.6379509], [77.16565704, 9.6482296], [77.16887665, 9.65157986], [77.17308807, 9.65184021], [77.17251587, 9.65620041], [77.17959595, 9.66038036], [77.18219757, 9.66871929], [77.18477631, 9.67147923], [77.18589783, 9.67817116], [77.19168854, 9.68618202], [77.18900299, 9.69750023], [77.19021606, 9.70615196], [77.18992615, 9.71551037], [77.19991302, 9.71728992], [77.20822906, 9.72167015], [77.20603943, 9.7374897], [77.21135712, 9.74524975], [77.2124176, 9.75539017], [77.21859741, 9.76000977], [77.21069336, 9.76638889], [77.20981598, 9.77994061], [77.22254944, 9.78177071], [77.2266922, 9.78675079], [77.2339859, 9.78851986], [77.23203278, 9.79441071], [77.23282623, 9.79728985], [77.22708893, 9.80631065], [77.21945953, 9.80884075], [77.21898651, 9.81325054], [77.21235657, 9.81293201], [77.20892334, 9.81452179], [77.21502686, 9.83087063], [77.21335602, 9.832901], [77.21383667, 9.83854008], [77.22373962, 9.84296131], [77.22366333, 9.84901047], [77.2183075, 9.8534708], [77.21325684, 9.85198021], [77.20919037, 9.85379028], [77.19911194, 9.8659811], [77.20144653, 9.869771], [77.2027359, 9.87474155], [77.20654297, 9.87776184], [77.20443726, 9.89431953], [77.21689606, 9.90576077], [77.22094727, 9.91775131], [77.2219162, 9.92282009], [77.23448181, 9.93811131], [77.23471069, 9.94283104], [77.23594666, 9.94338036], [77.23661041, 9.94138145], [77.24021149, 9.94306087], [77.24991608, 9.94253922], [77.25527954, 9.95018959], [77.25898743, 9.953372], [77.2614212, 9.96372128], [77.25952148, 9.96620083], [77.24983978, 9.97278118], [77.2487793, 9.97740078], [77.25076294, 9.98140144], [77.24672699, 9.98149014], [77.24514771, 9.98622131], [77.2478714, 9.99116039], [77.24772644, 9.99116039], [77.24768066, 9.99484062], [77.24088287, 10.00013065], [77.2407074, 10.00289059], [77.24443054, 10.00774956], [77.24893188, 10.01581097], [77.24809265, 10.02023029], [77.24556732, 10.02362156], [77.2423172, 10.02615166], [77.23707581, 10.03520203], [77.23065948, 10.03952122], [77.2244873, 10.04554939], [77.22068024, 10.05061054], [77.21817017, 10.05686092], [77.2129364, 10.0584507], [77.20443726, 10.06849098], [77.19906616, 10.07066059], [77.19519806, 10.07354164], [77.19072723, 10.08115196], [77.18979645, 10.08655071], [77.18990326, 10.09097004], [77.18779755, 10.09250164], [77.18814087, 10.09565163], [77.19460297, 10.10624886], [77.19787598, 10.10647964], [77.20330048, 10.10362244], [77.20600128, 10.10603142], [77.21234894, 10.10876083], [77.2154007, 10.10929203], [77.21872711, 10.11129093], [77.22126007, 10.11537075], [77.22511292, 10.11845016], [77.2305069, 10.12012005], [77.23483276, 10.11665058], [77.23990631, 10.11413956], [77.24608612, 10.11235142], [77.25327301, 10.11140919], [77.25498962, 10.11631203], [77.25978088, 10.11908054], [77.26101685, 10.12869167], [77.26013947, 10.13066101], [77.25756073, 10.13222027], [77.25743103, 10.13588142], [77.25961304, 10.14122963], [77.25914764, 10.15535069], [77.26441193, 10.17973995], [77.26941681, 10.18710041], [77.2713623, 10.19406033], [77.26966858, 10.19678974], [77.27297974, 10.19776058], [77.27385712, 10.20146942], [77.27620697, 10.20366192], [77.27905273, 10.20401096], [77.28044891, 10.20725155], [77.27482605, 10.22054958], [77.26996613, 10.22433186], [77.26622772, 10.22509003], [77.25875092, 10.22385979], [77.25556946, 10.22552967], [77.25418854, 10.22332191], [77.2512207, 10.22436142], [77.24915314, 10.22205925], [77.24652863, 10.22060966], [77.2455368, 10.22625065], [77.24577332, 10.23215103], [77.24482727, 10.24518967], [77.24530029, 10.24857044], [77.24755859, 10.25157166], [77.25054932, 10.2537508], [77.24652863, 10.25755024], [77.23191833, 10.27723026], [77.22093201, 10.29603958], [77.21720886, 10.29800034], [77.2144928, 10.30580139], [77.21833038, 10.32201958], [77.22251129, 10.32853127], [77.22216034, 10.34030056], [77.21444702, 10.34136963], [77.19946289, 10.34195137], [77.19274139, 10.3434], [77.1889801, 10.34617043], [77.18136597, 10.34317017], [77.17312622, 10.34401131], [77.16883087, 10.34598923], [77.16295624, 10.34628105], [77.14823151, 10.33405972], [77.13405609, 10.32371998], [77.12673187, 10.32024193], [77.11933136, 10.31551075], [77.11425781, 10.31056023], [77.10832214, 10.30717087], [77.10072327, 10.30445004], [77.09224701, 10.30426979], [77.08795929, 10.30176067], [77.08170319, 10.29965019], [77.07344055, 10.29579163], [77.06755066, 10.29022121], [77.06078339, 10.28646088], [77.05187988, 10.28548145], [77.05111694, 10.2828598], [77.05332184, 10.27989006], [77.0460968, 10.27429008], [77.03383636, 10.27217102], [77.04250336, 10.26197147], [77.03855133, 10.24816036], [77.03025818, 10.24293232], [77.01859283, 10.24183083], [77.01603699, 10.24096012], [77.01522064, 10.23759174], [77.00666809, 10.23637009], [76.99939728, 10.22979927], [76.99577332, 10.22935009], [76.99372101, 10.22772121], [76.99141693, 10.22299957], [76.98726654, 10.21994019], [76.98145294, 10.21990967], [76.97458649, 10.21393204], [76.97078705, 10.20865059], [76.96734619, 10.21257973], [76.96176147, 10.21581173], [76.95878601, 10.21873188], [76.95226288, 10.2197504], [76.94587708, 10.22279072], [76.93920898, 10.2211113], [76.92777252, 10.22958946], [76.92500305, 10.22978115], [76.92030334, 10.22544098], [76.90934753, 10.22319889], [76.90547943, 10.22475147], [76.90123749, 10.22781181], [76.89872742, 10.2325592], [76.89231873, 10.23267078], [76.89356232, 10.23744106], [76.89182281, 10.24308014], [76.8846283, 10.25507927], [76.87705994, 10.25631046], [76.87081909, 10.26408195], [76.86229706, 10.26706123], [76.86157227, 10.26962852], [76.86206818, 10.28254986], [76.86427307, 10.29004097], [76.86057281, 10.29074097], [76.85788727, 10.28926182], [76.85073853, 10.2828207], [76.84056854, 10.28361034], [76.83985901, 10.28143978], [76.83988953, 10.27754021], [76.83854675, 10.27759933], [76.83525085, 10.2816906], [76.83194733, 10.28377056], [76.83000183, 10.29111004], [76.82492065, 10.29383087], [76.81967163, 10.2952404], [76.81961823, 10.30263996], [76.82419586, 10.31231117], [76.82585907, 10.32004166], [76.82676697, 10.33026123], [76.82569122, 10.33421135], [76.82756042, 10.33758163], [76.83577728, 10.34636974], [76.83624268, 10.35296059], [76.83934784, 10.35970974], [76.83815765, 10.36264133], [76.83069611, 10.37210178], [76.82460785, 10.37524033], [76.82048798, 10.38179016], [76.8156662, 10.38653088], [76.82264709, 10.39406109], [76.82264709, 10.39893246], [76.82145691, 10.40340996], [76.81503296, 10.40178967], [76.81196594, 10.41138935], [76.80732727, 10.41491985], [76.81745148, 10.43848991], [76.82097626, 10.48023129], [76.82028961, 10.49067974], [76.82525635, 10.50298119], [76.83143616, 10.52457142], [76.83196259, 10.52916145], [76.8245163, 10.53763962], [76.82572937, 10.54298019], [76.83017731, 10.55298138], [76.82907104, 10.55706024], [76.82546234, 10.56156158], [76.82601166, 10.56751919], [76.82932281, 10.5764513], [76.82972717, 10.58506203], [76.82834625, 10.58827972], [76.82450104, 10.58956146], [76.81539917, 10.58829975], [76.80861664, 10.59448147], [76.80961609, 10.60427856], [76.80847931, 10.60727024], [76.80497742, 10.60913181], [76.80326843, 10.61408043], [76.80568695, 10.62082958], [76.80499268, 10.62634087], [76.81468964, 10.6260004], [76.8224411, 10.62738132], [76.82685089, 10.627141], [76.83129883, 10.62588978], [76.83822632, 10.62671089], [76.84471893, 10.62627125], [76.85246277, 10.62394142], [76.85952759, 10.62520027], [76.87261963, 10.62943172], [76.87460327, 10.63922977], [76.87216949, 10.65353107], [76.86947632, 10.65635967], [76.87036896, 10.66076088], [76.87016296, 10.66409969], [76.86769867, 10.66623974], [76.86326599, 10.66695976], [76.85507202, 10.67240047], [76.8555069, 10.67527199], [76.85980225, 10.67714119], [76.86190033, 10.68056202], [76.86160278, 10.68626022], [76.8651123, 10.69293976], [76.87504578, 10.70672035], [76.88101196, 10.70606136], [76.88374329, 10.70735073], [76.88128662, 10.71292973], [76.87931824, 10.72023964], [76.88040161, 10.72614002], [76.88680267, 10.73674965], [76.88765717, 10.74300957], [76.89035034, 10.74749088], [76.8931427, 10.75040245], [76.89427948, 10.75535202], [76.89385986, 10.76055145], [76.89668274, 10.76607132], [76.89750671, 10.77079964], [76.89148712, 10.79216003], [76.88829803, 10.79988194], [76.88194275, 10.80107117], [76.85999298, 10.79980183], [76.85259247, 10.80850124], [76.84041595, 10.8076601], [76.83712769, 10.81553936], [76.84342957, 10.82250023], [76.84519196, 10.82650185], [76.84266663, 10.83185101], [76.83872986, 10.83762169], [76.83407593, 10.84270191], [76.82762909, 10.84714031], [76.82459259, 10.85044193], [76.82089233, 10.85891056], [76.81755829, 10.86180115], [76.79094696, 10.87096977], [76.78527069, 10.87147236], [76.78128052, 10.87390137], [76.77773285, 10.87897015], [76.77298737, 10.88164139], [76.76669312, 10.88174057], [76.76191711, 10.87977028], [76.74910736, 10.88478184], [76.74395752, 10.88492107], [76.73943329, 10.88443089], [76.7326889, 10.88097954], [76.73079681, 10.88408184], [76.7278595, 10.88679886], [76.72283936, 10.88762188], [76.71846008, 10.88984108], [76.71142578, 10.89556026], [76.70040131, 10.90079021], [76.69300079, 10.90227032], [76.68460083, 10.90243053], [76.67487335, 10.90640163], [76.65278625, 10.91996002], [76.64916229, 10.92415237], [76.64739227, 10.92897034], [76.65558624, 10.93427086], [76.65727997, 10.93868065], [76.654953, 10.94219112], [76.65931702, 10.95048046], [76.66044617, 10.96045971], [76.67777252, 10.97970104], [76.67868805, 10.98605061], [76.68081665, 10.99265957], [76.67978668, 10.99943066], [76.6904068, 11.01749992], [76.69883728, 11.0226717], [76.70652008, 11.03135109], [76.71205139, 11.03245068], [76.73239899, 11.02897072], [76.74401855, 11.02590084], [76.75697327, 11.02459145], [76.78183746, 11.02895069], [76.78678131, 11.03225136], [76.79247284, 11.0423727], [76.79342651, 11.04701138], [76.7899704, 11.04968166], [76.7754364, 11.03428173], [76.7671814, 11.03221035], [76.76232147, 11.03426075], [76.754776, 11.03919983], [76.75112915, 11.04675961], [76.74649048, 11.04697037], [76.74022675, 11.04562855], [76.73709869, 11.04751015], [76.73600006, 11.05445194], [76.73443604, 11.05832195], [76.73449707, 11.06389046], [76.74643707, 11.07087135], [76.74803925, 11.0751009], [76.7462616, 11.07885933], [76.74572754, 11.08392143], [76.74272919, 11.08600044], [76.73858643, 11.08395958], [76.73413849, 11.0933609], [76.73500061, 11.09910011], [76.73937225, 11.10361099], [76.74060822, 11.10991001], [76.7388916, 11.11485958], [76.73871613, 11.12129021], [76.73493195, 11.12512112], [76.72930908, 11.12539005], [76.72220612, 11.12251186], [76.71536255, 11.12842083], [76.71266174, 11.13286972], [76.70983124, 11.1402998], [76.70298767, 11.14178181], [76.70269012, 11.13862038], [76.70555878, 11.13612938], [76.70361328, 11.13201141], [76.70014954, 11.1314497], [76.69667816, 11.13268089], [76.6950531, 11.14023018], [76.69117737, 11.14451027], [76.68601227, 11.15770054], [76.68902588, 11.16508961], [76.6934967, 11.16672039], [76.69676971, 11.17187977], [76.70133209, 11.17453957], [76.70643616, 11.1796217], [76.71375275, 11.17801094], [76.72115326, 11.18451118], [76.71791077, 11.19240093], [76.71795654, 11.19831085], [76.72654724, 11.20646954], [76.72557831, 11.20889091], [76.72261047, 11.20810032], [76.72054291, 11.21163273], [76.71038818, 11.21831036], [76.69696808, 11.23133087], [76.67938995, 11.2270298], [76.67784119, 11.22280025], [76.67816925, 11.21883011], [76.66819, 11.21068001], [76.65344238, 11.20429134], [76.64164734, 11.19651031], [76.62966919, 11.19080067], [76.62303925, 11.18567085], [76.60205841, 11.1954689], [76.59333801, 11.19749069], [76.57778168, 11.19684124], [76.54801178, 11.19314194], [76.53611755, 11.18931103], [76.5212326, 11.19027042], [76.51024628, 11.19528198], [76.50601196, 11.20197964], [76.50231171, 11.20286179], [76.48764801, 11.20279026], [76.474823, 11.20125961], [76.46586609, 11.19874191], [76.46653748, 11.18609047], [76.45883179, 11.18412971], [76.45272064, 11.18021011], [76.443573, 11.1908989], [76.44030762, 11.19125938], [76.43802643, 11.19454956], [76.44287872, 11.20009136], [76.44638824, 11.23046112], [76.48812866, 11.25196171], [76.51352692, 11.26196003], [76.51309204, 11.26466084], [76.51593018, 11.2724514], [76.52194977, 11.28120136], [76.53405762, 11.28796101], [76.54016876, 11.29234791], [76.5304718, 11.29574203], [76.52854156, 11.30344963], [76.53048706, 11.30963993], [76.53524017, 11.3163414], [76.53978729, 11.32095146], [76.54075623, 11.32704067], [76.53820038, 11.35159016], [76.52986145, 11.34768105], [76.51637268, 11.34897137], [76.50949097, 11.34661198], [76.50673676, 11.34766006], [76.50945282, 11.3537302], [76.51007843, 11.36115074], [76.47286987, 11.37534142], [76.44838715, 11.38141918], [76.43934631, 11.39066982], [76.41838837, 11.40526962], [76.40817261, 11.41481972], [76.41004944, 11.42520142], [76.41039276, 11.43359089], [76.39057922, 11.42796135], [76.37058258, 11.44089985], [76.36148071, 11.44796085], [76.35308075, 11.45083046], [76.33905792, 11.45417976], [76.33368683, 11.45871067], [76.32090759, 11.44469929], [76.30593872, 11.45335102], [76.297966, 11.4588604], [76.28903961, 11.4563179], [76.28407288, 11.46243954], [76.28769684, 11.46599102], [76.28578949, 11.46857071], [76.27806091, 11.47453117], [76.26608276, 11.46869183], [76.25792694, 11.47322273], [76.24726868, 11.46414948], [76.24009705, 11.45964146], [76.24089813, 11.47521019], [76.24475861, 11.49432087], [76.24288177, 11.49868965], [76.24151611, 11.50479126], [76.23320007, 11.51867962], [76.23964691, 11.52094078], [76.24295807, 11.5241909], [76.24246979, 11.52879047], [76.2383194, 11.53335953], [76.23445892, 11.54648113], [76.22693634, 11.55968189], [76.22574615, 11.56443977], [76.25969696, 11.5869379], [76.266716, 11.58932018], [76.27097321, 11.59290886], [76.27600098, 11.58995056], [76.27793884, 11.5835104], [76.28588867, 11.58295155], [76.29064178, 11.58056068], [76.29316711, 11.57176113], [76.29377747, 11.56503105], [76.29789734, 11.56433105], [76.30517578, 11.57042122], [76.30919647, 11.56960011], [76.31109619, 11.57751083], [76.32858276, 11.58855057], [76.3334198, 11.58512974], [76.33349609, 11.58065033], [76.33558655, 11.57834053], [76.34034729, 11.58056068], [76.35011292, 11.58274174], [76.3653717, 11.59171867], [76.37069702, 11.59346962], [76.37106323, 11.60069942], [76.37683868, 11.60464001], [76.37674713, 11.61474133], [76.38006592, 11.62241936], [76.39618683, 11.62531185], [76.42128754, 11.62510014], [76.42479706, 11.62329006], [76.42588806, 11.62903118], [76.43070221, 11.62963104], [76.43421936, 11.63352108], [76.43557739, 11.63770103], [76.43461609, 11.64161015], [76.4298172, 11.6450901], [76.42767334, 11.64752197], [76.42346191, 11.65932083], [76.4312973, 11.65657043], [76.45136261, 11.6551199], [76.46660614, 11.67232132], [76.47367859, 11.67813969], [76.47377777, 11.68422031], [76.47934723, 11.68240166], [76.48532104, 11.68234921], [76.48781586, 11.68545055], [76.50421143, 11.69804096], [76.51307678, 11.69419193], [76.52468872, 11.68601036], [76.53531647, 11.67704105], [76.54042053, 11.67050934], [76.5430069, 11.66296959], [76.54308319, 11.65648079], [76.54521942, 11.64825058], [76.54705811, 11.6357708], [76.54968262, 11.62697124], [76.55322266, 11.61953163], [76.55362701, 11.61291981], [76.56006622, 11.61012077], [76.5748291, 11.60571957], [76.58096313, 11.60940075], [76.58615875, 11.60799026], [76.58827972, 11.60435963], [76.59671021, 11.6033802], [76.60144043, 11.60122108], [76.60787201, 11.60044193], [76.62565613, 11.60381889], [76.63372803, 11.60352993], [76.66443634, 11.60509968], [76.67904663, 11.60414124], [76.69309998, 11.6044302], [76.70749664, 11.60593891], [76.72020721, 11.60505009], [76.73542786, 11.60523033], [76.74104309, 11.60580921], [76.74626923, 11.61054134], [76.75139618, 11.60670853], [76.77377319, 11.60342979], [76.78082275, 11.60357094], [76.79075623, 11.59970093], [76.80832672, 11.59618187], [76.81651306, 11.59720993], [76.8236084, 11.59130001], [76.82993317, 11.58982086], [76.83349609, 11.58703136], [76.83596802, 11.58403015], [76.83728027, 11.57448006], [76.84375763, 11.58603096], [76.84733582, 11.58864021], [76.85090637, 11.60182953], [76.84588623, 11.60605145], [76.84581757, 11.61164093], [76.84155273, 11.61322117], [76.83825684, 11.61584187], [76.83798218, 11.6187706], [76.83882141, 11.62341976], [76.83309174, 11.62529087], [76.82969666, 11.62934113], [76.829216, 11.63497066], [76.82775116, 11.63842964], [76.82847595, 11.64410973], [76.83003235, 11.64904022], [76.83230591, 11.65266132], [76.83566284, 11.65607071], [76.83838654, 11.66466999], [76.84137726, 11.66977119], [76.84472656, 11.67737198], [76.84617615, 11.6824789], [76.84910583, 11.68721962], [76.85572815, 11.69433975], [76.8535614, 11.69878197], [76.86457062, 11.71053123], [76.87558746, 11.71789932], [76.880867, 11.72459126], [76.88172913, 11.73009014], [76.88600922, 11.74448109], [76.88851166, 11.75043201], [76.88934326, 11.76060104], [76.88796997, 11.76589966], [76.89150238, 11.77011204], [76.89335632, 11.77730274], [76.89968872, 11.78327179], [76.90679169, 11.78123188], [76.91348267, 11.78036976], [76.92666626, 11.78089046], [76.93239594, 11.77737141], [76.93580627, 11.77674198], [76.94032288, 11.78102016], [76.94444275, 11.7813406], [76.95025635, 11.77543068], [76.95316315, 11.7712698], [76.95960236, 11.76519966], [76.96330261, 11.77079964], [76.96539307, 11.77647972], [76.97483826, 11.79102135], [76.97341156, 11.79511166], [76.97277069, 11.80106926], [76.9821167, 11.79953957], [76.99035645, 11.79931927], [77.00443268, 11.80301952], [77.00884247, 11.79696178], [77.01344299, 11.79917145], [77.01857758, 11.79732037], [77.02275848, 11.79498196], [77.02855682, 11.78911972], [77.02767944, 11.78668976], [77.03167725, 11.78395081], [77.03026581, 11.77830124], [77.02233887, 11.76470089], [77.02757263, 11.76169968], [77.04125977, 11.7775898], [77.04569244, 11.77915955], [77.05253601, 11.77923107], [77.05654144, 11.77711964], [77.0618515, 11.77206135], [77.05438995, 11.76496124], [77.05010986, 11.75774956], [77.07385254, 11.72954082], [77.07163239, 11.72500992], [77.07588959, 11.72389126], [77.0962677, 11.72312069], [77.10367584, 11.71554947], [77.10929871, 11.71280098], [77.10830688, 11.72243023], [77.10540009, 11.73158073], [77.10323334, 11.74588013], [77.10573578, 11.75064087], [77.10610962, 11.75622082], [77.1053009, 11.75948048], [77.10282898, 11.7631197], [77.11096954, 11.76314926], [77.1138916, 11.76183033], [77.11972046, 11.76338196], [77.12738037, 11.76093197], [77.13102722, 11.7623806], [77.13459015, 11.76641083], [77.13723755, 11.7719717], [77.14379883, 11.77129936], [77.15541077, 11.77427101], [77.16591644, 11.77423], [77.17230225, 11.77573013], [77.17842102, 11.77952003], [77.18966675, 11.78281975], [77.20392609, 11.78447056], [77.21642303, 11.78476048], [77.22705078, 11.78374958], [77.23707581, 11.7881918], [77.24125671, 11.79399967], [77.24173737, 11.80245972], [77.24848175, 11.8008604], [77.27227783, 11.79117966], [77.27829742, 11.78973961], [77.28235626, 11.79286003], [77.28481293, 11.79836178], [77.29045105, 11.79416084], [77.30623627, 11.77870178], [77.31356049, 11.76998043], [77.32611847, 11.75893974], [77.34565735, 11.76406956], [77.35092926, 11.76858044], [77.35515594, 11.77837181], [77.35948944, 11.77879143], [77.36223602, 11.7758007], [77.38189697, 11.77616119], [77.40145111, 11.76403141], [77.40654755, 11.76233959], [77.41246796, 11.76228142], [77.4125061, 11.75612926], [77.4134903, 11.75115204], [77.41925049, 11.75067139], [77.4207077, 11.7602911], [77.42384338, 11.76608944], [77.43105316, 11.77168179], [77.43028259, 11.77667141], [77.43209076, 11.77894115], [77.43622589, 11.78176975], [77.44087219, 11.79134178], [77.44246674, 11.80647087], [77.44650269, 11.81149197], [77.44658661, 11.81626034], [77.45159149, 11.82341194], [77.45629883, 11.83912182], [77.45536041, 11.84268188], [77.45096588, 11.84431171], [77.45252991, 11.84910011], [77.45210266, 11.85323048], [77.45387268, 11.85733891], [77.45516205, 11.8672514], [77.45329285, 11.87089062], [77.45302582, 11.87589073], [77.45385742, 11.8819418], [77.45279694, 11.88853073], [77.45392609, 11.89055061], [77.46333313, 11.88727093], [77.46743011, 11.88321018], [77.4704361, 11.88361073], [77.47367096, 11.87780094], [77.47690582, 11.87601185], [77.47721863, 11.88177967], [77.47596741, 11.88955021], [77.47733307, 11.8952713], [77.47949982, 11.9003706], [77.48219299, 11.91214085], [77.48394012, 11.9214716], [77.48282623, 11.92869186], [77.48439789, 11.93239975], [77.49043274, 11.92973995], [77.50063324, 11.92723083], [77.51095581, 11.92534161], [77.51402283, 11.92568111], [77.52365112, 11.92148113], [77.53132629, 11.92649937], [77.54799652, 11.93074989], [77.57328796, 11.92401123], [77.5789566, 11.9282999], [77.58573151, 11.92945957], [77.591362, 11.92633057], [77.59596252, 11.92928028], [77.60372162, 11.93026924], [77.61517334, 11.93414974], [77.63021851, 11.93797016], [77.63672638, 11.94026089], [77.63949585, 11.94283199], [77.64341736, 11.94417191], [77.64675903, 11.93871117], [77.6548233, 11.93735886], [77.66044617, 11.93814087], [77.664711, 11.93970013], [77.66371155, 11.95296001], [77.66705322, 11.95893192], [77.67719269, 11.98427105], [77.6810379, 11.99123096], [77.68115234, 11.99123096], [77.68945313, 12.00994968], [77.69410706, 12.01519203], [77.70155334, 12.02714062], [77.70722961, 12.03328133], [77.71264648, 12.04138184], [77.71562195, 12.04850197], [77.72036743, 12.05335236], [77.73396301, 12.06022072], [77.74610138, 12.06932068], [77.75052643, 12.08051014], [77.75634003, 12.09195995], [77.75826263, 12.09440136], [77.76280975, 12.09748173], [77.76638794, 12.1009903], [77.76844788, 12.10559177], [77.76700592, 12.1091404], [77.75282288, 12.11797047], [77.74729156, 12.12232018], [77.74421692, 12.12669182], [77.74024963, 12.12928963], [77.74046326, 12.14258194], [77.73906708, 12.14785957], [77.73195648, 12.15461063], [77.7290802, 12.15995979], [77.72635651, 12.16732025], [77.71951294, 12.17152023], [77.71077728, 12.1733408], [77.7012558, 12.17259979], [77.67282104, 12.18138885], [77.6681366, 12.18371964], [77.65544891, 12.18774986], [77.64466858, 12.18857002], [77.63301086, 12.18642139], [77.62890625, 12.18632126], [77.62561035, 12.1897192], [77.62136841, 12.19170189], [77.61582184, 12.18978119], [77.61051941, 12.19159031], [77.60411835, 12.19516182], [77.59659576, 12.19530106], [77.59113312, 12.19056034], [77.58421326, 12.18884182], [77.56955719, 12.18807125], [77.56533813, 12.19045067], [77.55583191, 12.18711185], [77.54667664, 12.19037056], [77.53852081, 12.19448853], [77.53341675, 12.19383144], [77.53102112, 12.19014072], [77.52805328, 12.19001102], [77.52445221, 12.18824005], [77.51979828, 12.18866158], [77.51130676, 12.18397141], [77.49246216, 12.18719196], [77.48248291, 12.19011974], [77.47875214, 12.19398117], [77.47493744, 12.19582939], [77.46923828, 12.19651127], [77.46566772, 12.20226097], [77.4683609, 12.21019936], [77.47229004, 12.21726036], [77.47366333, 12.22494125], [77.46676636, 12.23398018], [77.46295166, 12.23577118], [77.46350098, 12.24403954], [77.46666718, 12.24847126], [77.46723175, 12.25318241], [77.4701767, 12.26187038], [77.4752121, 12.26597023], [77.47844696, 12.26965141], [77.48423004, 12.2697897], [77.4906311, 12.27305984], [77.49318695, 12.27279091], [77.49796295, 12.2683897], [77.50208282, 12.2663002], [77.51834106, 12.2695303], [77.52352142, 12.28100109], [77.53954315, 12.28239059], [77.54270935, 12.28371143], [77.54515076, 12.29269028], [77.55609894, 12.29716015], [77.56603241, 12.31670094], [77.56859589, 12.32419014], [77.57530975, 12.32625103], [77.58616638, 12.3363018], [77.59120178, 12.3491993], [77.60024261, 12.35122108], [77.60382843, 12.35375118], [77.6063385, 12.36026001], [77.60753632, 12.36765957], [77.60987854, 12.3736496], [77.61094666, 12.38564968], [77.61329651, 12.39780045], [77.61582947, 12.40488052], [77.62008667, 12.40847969], [77.62065125, 12.41376019], [77.61712646, 12.41866112], [77.61694336, 12.42464066], [77.62010193, 12.43809032], [77.61815643, 12.4431324], [77.62169647, 12.45444965], [77.62520599, 12.47726154], [77.61728668, 12.48550987], [77.6108017, 12.4780407], [77.59664917, 12.4646101], [77.57536316, 12.46837997], [77.58249664, 12.47631073], [77.60177612, 12.49166107], [77.60473633, 12.49488163], [77.60636902, 12.49979115], [77.60520172, 12.50333023], [77.59516144, 12.50366974], [77.57850647, 12.50701141], [77.57982635, 12.51148129], [77.57763672, 12.52347088], [77.57644653, 12.5368309], [77.57235718, 12.54042053], [77.5700531, 12.5579319], [77.57119751, 12.56354141], [77.57422638, 12.56723118], [77.58145905, 12.58423138], [77.5821228, 12.60508919], [77.58539581, 12.61193085], [77.59352875, 12.6165514], [77.59781647, 12.62102032], [77.594841, 12.62710953], [77.59552002, 12.63043118], [77.59169006, 12.63275146], [77.58937073, 12.63664246], [77.58796692, 12.6426897], [77.58927917, 12.64825153], [77.59033966, 12.65754128], [77.59783936, 12.65902042], [77.60943604, 12.66335106], [77.6329422, 12.67013073], [77.63878632, 12.67014027], [77.65428925, 12.67416954], [77.67030334, 12.6712389], [77.66590881, 12.66436005], [77.66929626, 12.66193962], [77.66738129, 12.65283012], [77.66780853, 12.65063953], [77.6733017, 12.65042973], [77.67835999, 12.6490202], [77.68753052, 12.65190029], [77.69547272, 12.6512394], [77.70178986, 12.65824986], [77.70381927, 12.67374134], [77.71411133, 12.67027855], [77.71412659, 12.66539097], [77.71531677, 12.6630106], [77.71839905, 12.66198063], [77.7232132, 12.66321182], [77.73140717, 12.66397953], [77.73320007, 12.67189121], [77.730896, 12.67797089], [77.72725677, 12.68287182], [77.73355865, 12.69147968], [77.74001312, 12.68855095], [77.7470932, 12.68664074], [77.75023651, 12.68716145], [77.75598145, 12.69705009], [77.75733948, 12.70398998], [77.76152802, 12.70771027], [77.76303864, 12.71446037], [77.75557709, 12.71557045], [77.75166321, 12.71840096], [77.75306702, 12.72509861], [77.75836945, 12.72931957], [77.76695251, 12.72963047], [77.77807617, 12.73367119], [77.78292084, 12.73882198], [77.78497314, 12.74505138], [77.77829742, 12.74787045], [77.77384949, 12.75113201], [77.77163696, 12.75477791], [77.77162933, 12.75983143], [77.7815094, 12.77103138], [77.78304291, 12.77612019], [77.78793335, 12.78132057], [77.79353333, 12.78387165], [77.7979126, 12.78292084], [77.79949188, 12.78685856], [77.79650116, 12.78961945], [77.79136658, 12.79631996], [77.79441071, 12.80580997], [77.79876709, 12.80491924], [77.80066681, 12.80562973], [77.79868317, 12.8117609], [77.80101776, 12.82080936], [77.79232025, 12.82137012], [77.78803253, 12.82364178], [77.78356171, 12.82825089], [77.78488159, 12.83380985], [77.78859711, 12.83535004], [77.78948975, 12.83877087], [77.79196167, 12.83983135], [77.79981995, 12.83784103], [77.80493927, 12.84275055], [77.80902863, 12.84272957], [77.81362915, 12.84401131], [77.81704712, 12.84898186], [77.82209015, 12.8498497], [77.82224274, 12.85461998], [77.82559967, 12.85898972], [77.83094025, 12.85786057], [77.83644867, 12.85763073], [77.83963013, 12.85585117], [77.84407043, 12.85589027], [77.84944153, 12.85786057], [77.85449982, 12.85673141], [77.85884857, 12.85762024], [77.86219025, 12.85692024], [77.86689758, 12.85861969], [77.87800598, 12.85928059], [77.88226318, 12.85839939], [77.8874588, 12.86692142], [77.89427948, 12.86822891], [77.90052032, 12.86788273], [77.90219879, 12.87337112], [77.90933228, 12.87295246], [77.91436768, 12.87354183], [77.9177475, 12.87837124], [77.92428589, 12.87784004], [77.92900848, 12.87477016], [77.92871857, 12.87143135], [77.91838074, 12.86887169], [77.91967773, 12.86349964], [77.93356323, 12.86168957], [77.93444824, 12.85604], [77.93105316, 12.85621071], [77.92878723, 12.85425091], [77.92780304, 12.85046959], [77.91844177, 12.84736061], [77.91533661, 12.84427071], [77.91487885, 12.83899021], [77.91182709, 12.83243084], [77.90923309, 12.82201958], [77.91047668, 12.81971073], [77.91825104, 12.81921196], [77.92076111, 12.81621933], [77.92479706, 12.8137207], [77.93297577, 12.81292057], [77.93990326, 12.82934856], [77.93612671, 12.83380985], [77.93255615, 12.83963108], [77.93345642, 12.84478092], [77.93860626, 12.84969139], [77.94555664, 12.8493309], [77.94856262, 12.84811974], [77.94684601, 12.83808136], [77.95134735, 12.83786201], [77.95522308, 12.83870983], [77.95800018, 12.83634186], [77.95501709, 12.82516003], [77.95746613, 12.82153034], [77.97129822, 12.82264042], [77.97360229, 12.81816959], [77.97457886, 12.81444168], [77.98134613, 12.81042099], [77.98139954, 12.79564095], [77.98602295, 12.79530144], [77.98972321, 12.79719067], [78.0014801, 12.79543972], [78.00559998, 12.80326939], [78.0032959, 12.80583096], [77.99330139, 12.81367111], [77.9998703, 12.81904125], [78.00382233, 12.8179493], [78.00712585, 12.8200407], [78.00804901, 12.82296085], [78.00711823, 12.82820129], [78.00907898, 12.83370018], [78.01677704, 12.83352947], [78.01685333, 12.83836079], [78.01435852, 12.84298992], [78.0149231, 12.84592056], [78.01957703, 12.84620953], [78.02215576, 12.84122086], [78.04000854, 12.83821106], [78.04202271, 12.8421011], [78.04673004, 12.84237003], [78.05060577, 12.83858204], [78.05139923, 12.83230972], [78.06456757, 12.83016968], [78.06639862, 12.82668114], [78.06594849, 12.81893063], [78.07367706, 12.821311], [78.0761261, 12.82051086], [78.08246613, 12.80915165], [78.08647919, 12.80333996], [78.09514618, 12.80023098], [78.09765625, 12.79592991], [78.10205078, 12.7933979], [78.10946655, 12.79140186], [78.11448669, 12.78707123], [78.117836, 12.77989197], [78.1206665, 12.7700119], [78.12711334, 12.77015972], [78.13163757, 12.76966953], [78.1364975, 12.76916027], [78.14302826, 12.76664066], [78.14771271, 12.76329994], [78.15814209, 12.76022053], [78.16156006, 12.76226139], [78.16615295, 12.76500034], [78.17530823, 12.76331139], [78.17871857, 12.75992012], [78.18395996, 12.76260853], [78.19024658, 12.76107979], [78.19538116, 12.7575407], [78.1989212, 12.75509071], [78.20233917, 12.75507927], [78.21248627, 12.75506973], [78.22064972, 12.75259018], [78.2199173, 12.74962139], [78.21927643, 12.7470293], [78.22886658, 12.72020245], [78.22722626, 12.71517181], [78.22032928, 12.70328999], [78.21382141, 12.70236015], [78.20980835, 12.69926071], [78.20324707, 12.6990099], [78.19999695, 12.69622135], [78.19608307, 12.69668961], [78.19473267, 12.69526958], [78.19934082, 12.68997955], [78.19877625, 12.68871117], [78.18946075, 12.68355083], [78.18984985, 12.6813097], [78.1953125, 12.67996979], [78.19683838, 12.67859077], [78.20011139, 12.67564201], [78.21398926, 12.67475128], [78.22808075, 12.67385101], [78.22664642, 12.68014145], [78.22744751, 12.68928146], [78.23265839, 12.69376087], [78.23906708, 12.69239235], [78.26442719, 12.69184017], [78.26722717, 12.68743038], [78.28418732, 12.66761971], [78.28700256, 12.65814972], [78.28885651, 12.6565609], [78.29045868, 12.65292072], [78.29496765, 12.65424061], [78.30876923, 12.64999962], [78.32235718, 12.63720036], [78.32939911, 12.6384306], [78.33883667, 12.63190079], [78.34835815, 12.62364101], [78.36054993, 12.61511135], [78.36833954, 12.61184025], [78.37420654, 12.61309147], [78.38613892, 12.61387062], [78.3975296, 12.61359024], [78.39955902, 12.61335087], [78.39980316, 12.6133194], [78.40711212, 12.61752033], [78.41233063, 12.61831093], [78.41834259, 12.62064171], [78.42489624, 12.61490059], [78.43943787, 12.61692047], [78.44744873, 12.61650085], [78.45140076, 12.61575127], [78.45478058, 12.61201954], [78.45961761, 12.61740971], [78.46008301, 12.62045956], [78.45907593, 12.63152027], [78.4618988, 12.6322794], [78.46292877, 12.63537025], [78.45935822, 12.63876057], [78.45765686, 12.66224957], [78.47406006, 12.65917969], [78.48855591, 12.66334248], [78.49344635, 12.66959095], [78.4940567, 12.67470074], [78.49711609, 12.67648983], [78.49740601, 12.67924976], [78.49340057, 12.68103027], [78.49357605, 12.68575001], [78.48956299, 12.68660927], [78.48631287, 12.69051075], [78.48754883, 12.69262886], [78.49090576, 12.69329166], [78.49301147, 12.69369984], [78.494133, 12.69794083], [78.49340057, 12.70347023], [78.49492645, 12.70372963], [78.49788666, 12.69851112], [78.49978638, 12.69685173], [78.50389099, 12.6933012], [78.5045929, 12.69800091], [78.5098114, 12.69878006], [78.51051331, 12.70176983], [78.5090332, 12.7049017], [78.49362946, 12.71116924], [78.49146271, 12.71706963], [78.48441315, 12.72305012], [78.47966003, 12.73001957], [78.48435211, 12.73478127], [78.48886108, 12.7319603], [78.4943161, 12.73037148], [78.49710083, 12.72411919], [78.50180054, 12.72150993], [78.50315857, 12.71809959], [78.50356293, 12.71337128], [78.50740814, 12.7130909], [78.5093689, 12.71979141], [78.51094055, 12.72172165], [78.51230621, 12.70800972], [78.51474762, 12.70698929], [78.51618958, 12.70640087], [78.51616669, 12.7062397], [78.51597595, 12.70352077], [78.52641296, 12.70123005], [78.52745819, 12.69730091], [78.52561188, 12.69474983], [78.52085876, 12.6971817], [78.51853943, 12.69237995], [78.52015686, 12.6870079], [78.52436829, 12.67969036], [78.52774811, 12.67900181], [78.53127289, 12.67993164], [78.53978729, 12.68422127], [78.54135895, 12.68501186], [78.54371643, 12.68460083], [78.54467773, 12.68443966], [78.54767609, 12.68559074], [78.54773712, 12.68911171], [78.54509735, 12.6926012], [78.54801178, 12.69536972], [78.55195618, 12.69433975], [78.55224609, 12.6970911], [78.54931641, 12.70070076], [78.54550934, 12.70738125], [78.54824829, 12.71498013], [78.55224609, 12.72039127], [78.55393219, 12.72606087], [78.55088806, 12.72622967], [78.54564667, 12.72861195], [78.55030823, 12.73876095], [78.54554749, 12.74391079], [78.54663086, 12.74560928], [78.55091858, 12.74680996], [78.55406189, 12.74606991], [78.5581131, 12.7516489], [78.56157684, 12.75257015], [78.56684875, 12.75214958], [78.56572723, 12.75901127], [78.57765961, 12.76585007], [78.5800705, 12.76724052], [78.5819397, 12.77077103], [78.58290863, 12.77622032], [78.58251953, 12.78532124], [78.58976746, 12.79244995], [78.59060669, 12.7979002], [78.5881958, 12.80478001], [78.59767151, 12.81107998], [78.59562683, 12.81548977], [78.59379578, 12.83300114], [78.59229279, 12.83677006], [78.59156799, 12.83854961], [78.59900665, 12.84947014], [78.60443115, 12.8574419], [78.60462189, 12.86600018], [78.60597229, 12.87369919], [78.61222839, 12.88856125], [78.61554718, 12.89321995], [78.61965179, 12.90207195], [78.62477112, 12.91418076], [78.62570953, 12.91918182], [78.62770081, 12.91792107], [78.6307373, 12.91597939], [78.63746643, 12.91588116], [78.64671326, 12.9190197], [78.63566589, 12.93834019], [78.6289978, 12.95311069], [78.63791656, 12.9544096], [78.62024689, 12.97391033], [78.61366272, 12.97889042], [78.62049866, 12.98252106], [78.62837982, 12.9897213], [78.63733673, 12.99684143], [78.641716, 13.00161076], [78.64505005, 13.00731087], [78.6489563, 13.0163517], [78.65110779, 13.01793194], [78.66861725, 13.01105976], [78.67935944, 13.00897026], [78.6937561, 13.00439167], [78.69597626, 13.01252079], [78.7012558, 13.04426003], [78.70244598, 13.05615139], [78.72550201, 13.05278015], [78.73217773, 13.05040264], [78.73951721, 13.04549122], [78.74601746, 13.0454092], [78.7544632, 13.04698181], [78.77752686, 13.05315971], [78.7830658, 13.05637169], [78.78659058, 13.06215191], [78.79418182, 13.06975937], [78.8008728, 13.07553005], [78.80809021, 13.07793045], [78.81342316, 13.0746479], [78.83226776, 13.06959057], [78.84393311, 13.0714798], [78.85835266, 13.07106972], [78.86068726, 13.0795002], [78.86473846, 13.08468056], [78.87032318, 13.08692074], [78.8760376, 13.08615971], [78.88352203, 13.08198929], [78.88040924, 13.06960201], [78.88088989, 13.04428101], [78.87937164, 13.02550125], [78.88191986, 13.01976204], [78.8901062, 13.01982975], [78.9159317, 13.02306175], [78.92299652, 13.02176094], [78.92463684, 13.01864147], [78.9286499, 13.021451], [78.92745972, 13.02346134], [78.92043304, 13.02862072], [78.91739655, 13.03254986], [78.90439606, 13.03105068], [78.89839935, 13.0316906], [78.89346313, 13.03509235], [78.90091705, 13.05210114], [78.90867615, 13.05045986], [78.9108429, 13.05610085], [78.91204071, 13.06328201], [78.91438293, 13.06776142], [78.9300766, 13.06602192], [78.93663788, 13.06997108], [78.94584656, 13.06350994], [78.95001221, 13.06608963], [78.95509338, 13.06492996], [78.95918274, 13.06544018], [78.9629364, 13.07155991], [78.96465302, 13.07279968], [78.97167969, 13.07511997], [78.97959137, 13.07651043], [78.98174286, 13.07619953], [78.98825073, 13.07265186], [78.99523926, 13.06304073], [79.00036621, 13.05788136], [79.01142883, 13.05782986], [79.02281952, 13.05640125], [79.02588654, 13.04957962], [79.03353882, 13.04566002], [79.04389191, 13.04372025], [79.05326843, 13.03799057], [79.05397797, 13.02816105], [79.06057739, 13.02083969], [79.06906891, 13.01415062], [79.08278656, 13.0124712], [79.10437775, 13.02422047], [79.11927032, 13.02256966], [79.13114929, 13.01676273], [79.14163208, 13.00981998], [79.15270233, 13.00729275], [79.16120148, 13.01179886], [79.17059326, 13.01568031], [79.17310333, 13.01928139], [79.1743927, 13.02525043], [79.17662048, 13.0297699], [79.17697144, 13.03337955], [79.17653656, 13.03827095], [79.17227173, 13.04372025], [79.17473602, 13.04967976], [79.16942596, 13.05300999], [79.17910004, 13.060112], [79.18065643, 13.06704044], [79.1835022, 13.07294083], [79.18699646, 13.07705021], [79.18891907, 13.08461857], [79.19332123, 13.08969021], [79.20220947, 13.09029007], [79.20744324, 13.09144115], [79.2142868, 13.0968399], [79.21827698, 13.10394192], [79.21827698, 13.1103096], [79.22244263, 13.11600971], [79.21826935, 13.12043095], [79.21466064, 13.12767029], [79.21832275, 13.13555145], [79.22635651, 13.13461018], [79.23304749, 13.12769985], [79.23670197, 13.1267519], [79.24333954, 13.13335037], [79.24423981, 13.14115143], [79.2472229, 13.14808178], [79.25137329, 13.14619923], [79.25267029, 13.14129925], [79.25646973, 13.13654041], [79.26120758, 13.14074993], [79.26741028, 13.14120102], [79.27128601, 13.13806057], [79.27266693, 13.12666035], [79.27384949, 13.12090111], [79.27751923, 13.11972046], [79.28495026, 13.12285042], [79.2881012, 13.11828041], [79.29876709, 13.11483192], [79.29747009, 13.0973711], [79.30793762, 13.09691143], [79.31002808, 13.0999403], [79.30973053, 13.10690022], [79.31239319, 13.11376953], [79.31672668, 13.11936855], [79.33068848, 13.12123108], [79.33531952, 13.12751007], [79.33779144, 13.12317085], [79.34435272, 13.12356091], [79.35009766, 13.12545013], [79.35457611, 13.12977123], [79.34674835, 13.13486099], [79.34686279, 13.14015102], [79.34783936, 13.14381981], [79.34709167, 13.15395069], [79.34777069, 13.16301918], [79.35472107, 13.16133976], [79.36120605, 13.15604115], [79.36493683, 13.16037083], [79.36717224, 13.16558075], [79.37078094, 13.16858959], [79.3690033, 13.17626095], [79.37835693, 13.18243122], [79.38437653, 13.18472099], [79.39256287, 13.18446159], [79.3979187, 13.18642235], [79.41329193, 13.18584919], [79.42059326, 13.18446159], [79.42378998, 13.1874609], [79.42156982, 13.19318104], [79.42315674, 13.19891071], [79.42315674, 13.2038002], [79.42163086, 13.20853138], [79.44550323, 13.21677113], [79.4454422, 13.2217207], [79.44245911, 13.22918034], [79.43609619, 13.2298317], [79.42690277, 13.22274017], [79.41816711, 13.21846199], [79.41699982, 13.21220112], [79.4108429, 13.21216202], [79.40865326, 13.21959019], [79.40968323, 13.22815037], [79.407341, 13.23766136], [79.40866852, 13.24674129], [79.41230011, 13.25751019], [79.41902161, 13.2663393], [79.41799164, 13.26906109], [79.41837311, 13.27458954], [79.42502594, 13.2813406], [79.42177582, 13.28666019], [79.40542603, 13.28541088], [79.39897919, 13.28915119], [79.38562775, 13.29470062], [79.37460327, 13.30303955], [79.40139771, 13.31575108], [79.41732025, 13.32195854], [79.42887878, 13.32356167], [79.45464325, 13.32432079], [79.47927856, 13.32145977], [79.48722839, 13.31655121], [79.49781036, 13.31482124], [79.50953674, 13.31470013], [79.52271271, 13.31593132], [79.53578186, 13.31107044], [79.53887177, 13.30092144], [79.53922272, 13.28975964], [79.54144287, 13.27893162], [79.54634094, 13.27404976], [79.54872894, 13.26712132], [79.55478668, 13.25918102], [79.56537628, 13.24940109], [79.570961, 13.2473793], [79.58026123, 13.24537086], [79.5854187, 13.24710083], [79.58644867, 13.25348091], [79.58867645, 13.26041126], [79.59485626, 13.26304245], [79.60114288, 13.26772976], [79.60510254, 13.26736069], [79.61075592, 13.26459122], [79.61519623, 13.26045036], [79.62075806, 13.25895023], [79.62431335, 13.26202011], [79.62956238, 13.26086044], [79.63072205, 13.26815987], [79.63250732, 13.2735424], [79.63848114, 13.2761898], [79.64376831, 13.2733593], [79.64862823, 13.2733593], [79.65338135, 13.27456856], [79.65740204, 13.2684803], [79.66256714, 13.26814175], [79.66590118, 13.27327919], [79.66853333, 13.28193092], [79.67932129, 13.26933193], [79.68161011, 13.26555061], [79.68430328, 13.25667953], [79.67376709, 13.24702072], [79.67111206, 13.23584175], [79.67331696, 13.22949028], [79.68068695, 13.22837067], [79.68456268, 13.23384953], [79.69193268, 13.23852921], [79.69603729, 13.23389053], [79.69574738, 13.2237606], [79.68943787, 13.21125031], [79.68875122, 13.20740986], [79.69243622, 13.20753098], [79.69963837, 13.20268059], [79.70568848, 13.20923138], [79.71142578, 13.21047974], [79.71570587, 13.21440029], [79.71856689, 13.2225914], [79.72283173, 13.22185135], [79.72651672, 13.21738052], [79.73252869, 13.21496105], [79.73368073, 13.21023178], [79.73750305, 13.20552063], [79.73826599, 13.19825935], [79.74437714, 13.194911], [79.75183105, 13.20477962], [79.75772095, 13.20557117], [79.76333618, 13.20885086], [79.76716614, 13.21333981], [79.7735672, 13.21751976], [79.77733612, 13.2171917], [79.78325653, 13.21791935], [79.78489685, 13.22348022], [79.78325653, 13.22816181], [79.77539063, 13.23411942], [79.7527771, 13.24376011], [79.74558258, 13.24821091], [79.73938751, 13.25443077], [79.72177887, 13.26573086], [79.72129059, 13.27223969], [79.72963715, 13.27507973], [79.74149323, 13.27666187], [79.74614716, 13.28000069], [79.74975586, 13.29088116], [79.75055695, 13.29881001], [79.75405884, 13.30278969], [79.76835632, 13.28962994], [79.77422333, 13.28513145], [79.77980042, 13.28207016], [79.78727722, 13.28462029], [79.79226685, 13.29164028], [79.7950058, 13.29857063], [79.80029297, 13.30432129], [79.80848694, 13.30508041], [79.82404327, 13.30231953], [79.83059692, 13.30206013], [79.8367691, 13.30299854], [79.83905792, 13.30334091], [79.85116577, 13.3034296], [79.85568237, 13.30814075], [79.8588562, 13.31374073], [79.86519623, 13.31072998], [79.87055206, 13.31175995], [79.87496185, 13.31740093], [79.88015747, 13.32043934], [79.88607788, 13.32129192], [79.8917923, 13.32461929], [79.89736176, 13.32948971], [79.903862, 13.33327103], [79.90628815, 13.33905125], [79.91068268, 13.34370041], [79.91713715, 13.34103966], [79.92550659, 13.33594036], [79.9287262, 13.34353065], [79.93998718, 13.35811138], [79.94064331, 13.36098099], [79.93974304, 13.36910057], [79.94803619, 13.36722088], [79.95358276, 13.37411118], [79.95028687, 13.38197136], [79.93562317, 13.38484955], [79.93557739, 13.39059067], [79.93247986, 13.40437126], [79.93595123, 13.40957165], [79.94426727, 13.41078186], [79.95085144, 13.40812016], [79.95848083, 13.41285133], [79.96322632, 13.41791058], [79.96102142, 13.42766094], [79.9630661, 13.44057274], [79.96218872, 13.44413853], [79.96186066, 13.45127964], [79.96826935, 13.45643139], [79.98747253, 13.46191025], [79.99056244, 13.46205997], [79.9907608, 13.45921993], [79.99537659, 13.45945072], [80.00440216, 13.47826004], [80.00589752, 13.48777103], [80.01885223, 13.48637199], [80.02481842, 13.48670006], [80.03604126, 13.4844799], [80.0371933, 13.49282169], [80.03697968, 13.49935055], [80.03275299, 13.50183964], [80.0256424, 13.5039711], [80.01908875, 13.50166035], [80.01361847, 13.50391197], [80.00842285, 13.50830173], [80.00623322, 13.51506233], [80.00039673, 13.51237202], [79.99017334, 13.51009083], [79.98973846, 13.51300144], [79.9892807, 13.51900005], [79.98967743, 13.5267601], [79.994133, 13.52960014], [80.00771332, 13.53237247], [80.01449585, 13.52849007], [80.01754761, 13.52513123], [80.0295105, 13.52359009], [80.03409576, 13.52180099], [80.04541779, 13.52198124], [80.05098724, 13.53051186], [80.05950928, 13.5325489], [80.06561279, 13.53476048], [80.06717682, 13.53592014], [80.06944275, 13.53759098], [80.07276154, 13.53392124], [80.07582092, 13.5267601], [80.07627869, 13.52612019], [80.07943726, 13.52936077], [80.08672333, 13.52724075], [80.08766937, 13.52661037], [80.0879364, 13.52595997], [80.08866882, 13.52552986], [80.09377289, 13.5135603], [80.09565735, 13.50984001], [80.09670258, 13.50821018], [80.09942627, 13.50631046], [80.10035706, 13.50520039], [80.10504913, 13.50363159], [80.10691071, 13.50394154], [80.11687469, 13.50280857], [80.11819458, 13.5084734], [80.11819458, 13.5065279], [80.11846924, 13.50653076], [80.11846924, 13.50624084], [80.11902618, 13.50625038], [80.11902618, 13.50597191], [80.12014008, 13.50597191], [80.12014008, 13.50569439], [80.12124634, 13.50569439], [80.12124634, 13.50541592], [80.12236023, 13.50542068], [80.12236023, 13.5051403], [80.12317657, 13.5051403], [80.12317657, 13.50542068], [80.12430573, 13.50541592], [80.12430573, 13.50569439], [80.12541962, 13.50569439], [80.12541962, 13.50625038], [80.12569427, 13.50625038], [80.12569427, 13.50708199], [80.12596893, 13.50708008], [80.12596893, 13.50764084], [80.12625122, 13.50763798], [80.12625122, 13.5084734], [80.12652588, 13.50846958], [80.12652588, 13.50931072], [80.12680817, 13.50931072], [80.12680817, 13.51125145], [80.12652588, 13.51125145], [80.12652588, 13.51319504], [80.12625122, 13.51319504], [80.12625122, 13.51347256], [80.12596893, 13.51347065], [80.12596893, 13.51375103], [80.12541962, 13.51375103], [80.12541962, 13.51403141], [80.12513733, 13.51403141], [80.12513733, 13.51431179], [80.12486267, 13.51430511], [80.12486267, 13.51569462], [80.12513733, 13.51569462], [80.12513733, 13.51597309], [80.12541962, 13.51597118], [80.12541962, 13.51653194], [80.12568665, 13.51653194], [80.12568665, 13.51681042], [80.12680817, 13.5168047], [80.12680817, 13.51708317], [80.12847137, 13.51708317], [80.12847137, 13.5168047], [80.12902832, 13.51681042], [80.12902832, 13.51653194], [80.12985992, 13.51653194], [80.12985992, 13.51625061], [80.13041687, 13.51625061], [80.13041687, 13.51597118], [80.13097382, 13.51597309], [80.13097382, 13.51569462], [80.13153076, 13.51569462], [80.13153076, 13.5154171], [80.13180542, 13.5154171], [80.13180542, 13.51513863], [80.13237, 13.51514053], [80.13237, 13.51486111], [80.13291931, 13.51486111], [80.13291931, 13.51458263], [80.13319397, 13.51458263], [80.13319397, 13.51430511], [80.13375092, 13.51431179], [80.13375092, 13.51403141], [80.1340332, 13.51403141], [80.1340332, 13.51375103], [80.13430786, 13.51375103], [80.13430786, 13.51347065], [80.13486481, 13.51347256], [80.13486481, 13.51319504], [80.13513947, 13.51319504], [80.13513947, 13.51291656], [80.13569641, 13.51292133], [80.13569641, 13.51264095], [80.13597107, 13.51264095], [80.13597107, 13.51237202], [80.13817596, 13.51237202], [80.13817596, 13.51208019], [80.13847351, 13.51208305], [80.13847351, 13.51180458], [80.13874817, 13.51180935], [80.13874817, 13.51153088], [80.13903046, 13.51153088], [80.13903046, 13.51125145], [80.13931274, 13.51125145], [80.13931274, 13.51068974], [80.13957977, 13.51069546], [80.13957977, 13.51041698], [80.13986206, 13.51041889], [80.13986206, 13.51014137], [80.14013672, 13.51014137], [80.14013672, 13.50986099], [80.14041901, 13.50986099], [80.14041901, 13.50957966], [80.14069366, 13.50958157], [80.14069366, 13.50930691], [80.14097595, 13.50931072], [80.14097595, 13.5090313], [80.14125061, 13.5090313], [80.14125061, 13.50875092], [80.14154053, 13.50875092], [80.14154053, 13.50846958], [80.14180756, 13.5084734], [80.14180756, 13.50819397], [80.14208221, 13.50819397], [80.14208221, 13.50791645], [80.14235687, 13.50792122], [80.14235687, 13.50764084], [80.14263916, 13.50764084], [80.14263916, 13.50736046], [80.14291382, 13.50736046], [80.14291382, 13.50708199], [80.14319611, 13.50708199], [80.14319611, 13.5065279], [80.14347076, 13.50653076], [80.14347076, 13.50597], [80.14375305, 13.50597191], [80.14375305, 13.50541592], [80.14402771, 13.50542068], [80.14402771, 13.50457954], [80.14430237, 13.50458431], [80.14430237, 13.50402832], [80.14457703, 13.50403118], [80.14457703, 13.50347042], [80.14485931, 13.50347233], [80.14485931, 13.50291634], [80.1451416, 13.5029211], [80.1451416, 13.50208187], [80.14541626, 13.50208378], [80.14541626, 13.50152779], [80.14569092, 13.50152969], [80.14569092, 13.50097179], [80.14597321, 13.50097179], [80.14597321, 13.50043201], [80.14624786, 13.50043201], [80.14624786, 13.49985981], [80.14653015, 13.49985981], [80.14653015, 13.49930573], [80.14679718, 13.49930954], [80.14679718, 13.49874973], [80.1470871, 13.49874973], [80.1470871, 13.49819088], [80.14736176, 13.49819374], [80.14736176, 13.49791622], [80.14763641, 13.49792004], [80.14763641, 13.49737072], [80.1479187, 13.49737072], [80.1479187, 13.4970789], [80.14819336, 13.49708366], [80.14819336, 13.49680614], [80.14875031, 13.49680996], [80.14875031, 13.49652958], [80.14903259, 13.49652958], [80.14903259, 13.49625015], [80.14958191, 13.49625015], [80.14958191, 13.49597073], [80.1498642, 13.49597359], [80.1498642, 13.49569321], [80.15013885, 13.49569321], [80.15013885, 13.49541759], [80.1506958, 13.49542046], [80.1506958, 13.49514198], [80.15097046, 13.49514198], [80.15097046, 13.4948616], [80.1515274, 13.4948616], [80.1515274, 13.49458122], [80.15180206, 13.49458313], [80.15180206, 13.49430466], [80.15235901, 13.49430466], [80.15235901, 13.49402714], [80.15319061, 13.49403191], [80.15319824, 13.49375153], [80.15429687, 13.49375153], [80.15429687, 13.49347115], [80.15486145, 13.49347115], [80.15486145, 13.49319553], [80.15569305, 13.49319553], [80.15569305, 13.49291706], [80.15625, 13.49292183], [80.15625, 13.49263859], [80.1570816, 13.49263859], [80.1570816, 13.49236107], [80.15735626, 13.49236107], [80.15735626, 13.49208069], [80.15763855, 13.4920826], [80.15763855, 13.49180508], [80.15791321, 13.49181175], [80.15791321, 13.49152946], [80.15847015, 13.49152946], [80.15847015, 13.49123955], [80.15875244, 13.49124908], [80.15875244, 13.49097347], [80.1590271, 13.49097347], [80.1590271, 13.49069309], [80.15958405, 13.49069309], [80.15958405, 13.49041653], [80.16014099, 13.49042034], [80.16014099, 13.49014091], [80.1609726, 13.49014091], [80.1609726, 13.48986053], [80.16152954, 13.48986053], [80.16152954, 13.48958302], [80.1626358, 13.48958302], [80.1626358, 13.48986053], [80.16374969, 13.48986053], [80.16374969, 13.49014091], [80.1645813, 13.49014091], [80.1645813, 13.49042034], [80.16569519, 13.49041653], [80.16569519, 13.49069309], [80.16708374, 13.49069309], [80.16708374, 13.49041653], [80.1673584, 13.49042034], [80.1673584, 13.49014091], [80.16792297, 13.49014091], [80.16792297, 13.48986053], [80.16819763, 13.48986053], [80.16819763, 13.49014091], [80.16847992, 13.49014091], [80.16847992, 13.49042034], [80.16902924, 13.49041653], [80.16902924, 13.49069309], [80.16930389, 13.49069309], [80.16930389, 13.49097347], [80.16958618, 13.49097347], [80.16958618, 13.49124908], [80.16986084, 13.49123955], [80.16986084, 13.49152946], [80.17041779, 13.49152946], [80.17041779, 13.49181175], [80.17069244, 13.49180508], [80.17069244, 13.4920826], [80.1709671, 13.49208069], [80.1709671, 13.49236107], [80.17151642, 13.49236107], [80.17151642, 13.49263859], [80.17208099, 13.49263859], [80.17208099, 13.49292183], [80.17263794, 13.49291706], [80.17263794, 13.49319553], [80.17319489, 13.49319553], [80.17319489, 13.49347115], [80.17375183, 13.49347115], [80.17375183, 13.49375153], [80.17430878, 13.49375153], [80.17430878, 13.49403191], [80.17514038, 13.49402714], [80.17514038, 13.49430466], [80.17624664, 13.49430466], [80.17624664, 13.49458313], [80.17708588, 13.49458122], [80.17708588, 13.4948616], [80.17958069, 13.4948616], [80.17958069, 13.49458122], [80.18125153, 13.49458313], [80.18125153, 13.49430466], [80.18152618, 13.49430466], [80.18152618, 13.49374866], [80.18180847, 13.49375153], [80.18180847, 13.49347115], [80.18208313, 13.49347115], [80.18208313, 13.49319553], [80.18264008, 13.49319553], [80.18264008, 13.49291706], [80.18319702, 13.49292183], [80.18319702, 13.49263859], [80.18345642, 13.49263859], [80.18345642, 13.49236107], [80.18402863, 13.49236107], [80.18402863, 13.49208069], [80.18458557, 13.4920826], [80.18458557, 13.49180508], [80.18569183, 13.49181175], [80.18569183, 13.49152946], [80.18763733, 13.49152946], [80.18763733, 13.49123955], [80.18930817, 13.49124908], [80.18930817, 13.49097347], [80.19097137, 13.49097347], [80.19097137, 13.49069309], [80.19264221, 13.49069309], [80.19264221, 13.49041653], [80.19403076, 13.49042034], [80.19403076, 13.49014091], [80.19568634, 13.49014091], [80.19568634, 13.48986053], [80.19736481, 13.48986053], [80.19736481, 13.48958302], [80.19902802, 13.48958302], [80.19902802, 13.48930454], [80.20069122, 13.48931026], [80.20069122, 13.48903179], [80.20236206, 13.48903179], [80.20236206, 13.48875141], [80.2040329, 13.48875141], [80.2040329, 13.48847103], [80.2048645, 13.48847103], [80.2048645, 13.48819542], [80.20569611, 13.48820019], [80.20569611, 13.48792171], [80.20652771, 13.48792171], [80.20652771, 13.48764133], [80.20764923, 13.48764133], [80.20764923, 13.48736095], [80.20847321, 13.48736095], [80.20847321, 13.48708057], [80.20930481, 13.48708344], [80.20930481, 13.48680496], [80.21153259, 13.48681164], [80.21153259, 13.48653126], [80.2140274, 13.48653126], [80.2140274, 13.48625088], [80.21624756, 13.48625088], [80.21624756, 13.48597145], [80.22569275, 13.48597336], [80.22569275, 13.48569489], [80.22624969, 13.48569489], [80.22624969, 13.48541737], [80.2270813, 13.48542976], [80.2270813, 13.48513889], [80.2279129, 13.48513889], [80.2279129, 13.48486137], [80.22846985, 13.48486137], [80.22846985, 13.48513889], [80.2298584, 13.48513889], [80.2298584, 13.48542976], [80.23014069, 13.48542976], [80.23014069, 13.48513889], [80.23042297, 13.48513889], [80.23042297, 13.48486137], [80.23097229, 13.48486137], [80.23097229, 13.4845829], [80.23124695, 13.4845829], [80.23124695, 13.48430538], [80.23430634, 13.4843092], [80.23430634, 13.48403072], [80.23707581, 13.48403072], [80.23707581, 13.4843092], [80.23735809, 13.48430538], [80.23735809, 13.4845829], [80.23708344, 13.4845829], [80.23708344, 13.48486137], [80.23680878, 13.48486137], [80.23680878, 13.48513889], [80.23652649, 13.48513889], [80.23652649, 13.48542976], [80.23625183, 13.48541737], [80.23625183, 13.48569489], [80.23596954, 13.48569489], [80.23596954, 13.48597336], [80.23542023, 13.48597145], [80.23542023, 13.48625088], [80.23486328, 13.48625088], [80.23486328, 13.48681164], [80.23457336, 13.48681164], [80.23457336, 13.48736095], [80.23430634, 13.48736095], [80.23430634, 13.48792171], [80.23652649, 13.48792171], [80.23652649, 13.48764133], [80.23680878, 13.48764133], [80.23680878, 13.48736095], [80.23735809, 13.48736095], [80.23735809, 13.48708057], [80.23764038, 13.48708344], [80.23764038, 13.48680496], [80.23819733, 13.48681164], [80.23819733, 13.48653126], [80.23847198, 13.48653126], [80.23847198, 13.48625088], [80.23874664, 13.48625088], [80.23874664, 13.48604965], [80.23874664, 13.48597336], [80.2390213, 13.48597336], [80.23902893, 13.48541737], [80.23929596, 13.48542976], [80.23929596, 13.48513889], [80.23958588, 13.48513889], [80.23958588, 13.48486137], [80.23986053, 13.48486137], [80.23986053, 13.48430538], [80.24014282, 13.4843092], [80.24014282, 13.4837513], [80.24041748, 13.4837513], [80.24041748, 13.48318958], [80.24069214, 13.4831953], [80.24069214, 13.48263931], [80.2409668, 13.48264122], [80.2409668, 13.48208046], [80.24153137, 13.48208237], [80.24153137, 13.48180676], [80.24208069, 13.48181057], [80.24208069, 13.48153114], [80.24263763, 13.48153114], [80.24263763, 13.48125076], [80.24291992, 13.48125076], [80.24291992, 13.48097038], [80.24346924, 13.48097229], [80.24346924, 13.48069382], [80.24402618, 13.48069382], [80.24402618, 13.4804163], [80.24458313, 13.48042107], [80.24458313, 13.48014069], [80.24485779, 13.48014069], [80.24485779, 13.47986031], [80.24514008, 13.47986031], [80.24514008, 13.47958469], [80.24541473, 13.47958469], [80.24541473, 13.47930431], [80.24569702, 13.47930431], [80.24569702, 13.47902775], [80.24597168, 13.47903061], [80.24597168, 13.47846985], [80.24624634, 13.47847176], [80.24624634, 13.47819424], [80.24652863, 13.47819424], [80.24652863, 13.47791576], [80.24680328, 13.47792053], [80.24680328, 13.47764015], [80.2470932, 13.47764015], [80.2470932, 13.47735977], [80.24736023, 13.47735977], [80.24736023, 13.4756918], [80.24764252, 13.4756937], [80.24764252, 13.47541809], [80.24736023, 13.47542095], [80.24736023, 13.47431087], [80.2470932, 13.47431087], [80.2470932, 13.47346973], [80.24680328, 13.47347164], [80.24680328, 13.47319412], [80.2470932, 13.4732008], [80.2470932, 13.47292042], [80.24736023, 13.47292042], [80.24736023, 13.47264004], [80.24986267, 13.47264004], [80.24986267, 13.47235966], [80.25041962, 13.47235966], [80.25041962, 13.47207928], [80.25152588, 13.47207928], [80.25152588, 13.47235966], [80.25319672, 13.47235966], [80.25319672, 13.47264004], [80.25347137, 13.47264004], [80.25347137, 13.47292042], [80.25402832, 13.47292042], [80.25402832, 13.4732008], [80.25430298, 13.47319412], [80.25430298, 13.47347164], [80.2545929, 13.47346973], [80.2545929, 13.47375202], [80.25485992, 13.47375202], [80.25485992, 13.47402954], [80.25514221, 13.47402954], [80.25514221, 13.47431087], [80.25930786, 13.47431087], [80.25930786, 13.47402954], [80.25985718, 13.47402954], [80.25985718, 13.47375202], [80.26040649, 13.47375202], [80.26040649, 13.47346973], [80.26097107, 13.47347164], [80.26097107, 13.47319412], [80.26152802, 13.4732008], [80.26152802, 13.47292042], [80.26209259, 13.47292042], [80.26209259, 13.47264004], [80.26235962, 13.47264004], [80.26235962, 13.47207928], [80.26264191, 13.47208405], [80.26264191, 13.47180557], [80.26291656, 13.47181034], [80.26291656, 13.47152996], [80.26319122, 13.47152996], [80.26319122, 13.4709692], [80.26347351, 13.47097206], [80.26347351, 13.47069359], [80.26374817, 13.47069359], [80.26374817, 13.47041798], [80.26403046, 13.47042179], [80.26403046, 13.46986198], [80.26431274, 13.46986198], [80.26430511, 13.46958447], [80.26457977, 13.46958447], [80.26457977, 13.46902847], [80.26486969, 13.46903038], [80.26486969, 13.46847057], [80.26513672, 13.46847057], [80.26513672, 13.4679184], [80.26541901, 13.4679203], [80.26541901, 13.46764183], [80.26568604, 13.46764183], [80.26568604, 13.46736145], [80.26625061, 13.46736145], [80.26625061, 13.46708298], [80.26652527, 13.46708298], [80.26652527, 13.46680546], [80.26708221, 13.46681023], [80.26708221, 13.46291924], [80.26735687, 13.46291924], [80.26735687, 13.45931244], [80.26680756, 13.45931244], [80.26680756, 13.45875072], [80.26708221, 13.45875072], [80.26708221, 13.45819855], [80.26735687, 13.45819855], [80.26735687, 13.45792103], [80.26763916, 13.45792103], [80.26763916, 13.45764065], [80.26819611, 13.45764065], [80.26819611, 13.45736122], [80.26847076, 13.45736122], [80.26847076, 13.45708275], [80.26902771, 13.45708275], [80.26902771, 13.45485973], [80.26930237, 13.45485973], [80.26930237, 13.45431137], [80.26957703, 13.45431137], [80.26957703, 13.45374966], [80.26985931, 13.45374966], [80.26985931, 13.45318985], [80.2701416, 13.45319366], [80.2701416, 13.45263767], [80.27041626, 13.45264053], [80.27041626, 13.45207119], [80.27069092, 13.45208359], [80.27069092, 13.4515276], [80.27097321, 13.45153141], [80.27097321, 13.4509697], [80.27124786, 13.4509716], [80.27124786, 13.45041561], [80.27153015, 13.45042133], [80.27153015, 13.44985962], [80.27180481, 13.44986153], [80.27180481, 13.44902802], [80.2720871, 13.44902992], [80.2720871, 13.44847202], [80.27236176, 13.44847202], [80.27236176, 13.44763756], [80.27263641, 13.44764042], [80.27263641, 13.44708157], [80.2729187, 13.44708443], [80.2729187, 13.44652843], [80.27319336, 13.44653034], [80.27319336, 13.4456892], [80.27347565, 13.44569397], [80.27347565, 13.44513988], [80.27374268, 13.44514179], [80.27374268, 13.44458199], [80.27402496, 13.44458389], [80.27402496, 13.44430637], [80.27430725, 13.44431019], [80.27430725, 13.44402981], [80.27458191, 13.44402981], [80.27458191, 13.44375038], [80.27485657, 13.44375038], [80.27485657, 13.44347191], [80.27513885, 13.44347191], [80.27513885, 13.44319439], [80.27541351, 13.44319439], [80.27541351, 13.44291782], [80.2756958, 13.44291973], [80.2756958, 13.44236183], [80.27597046, 13.44236183], [80.27597046, 13.44208145], [80.27625275, 13.44208431], [80.27625275, 13.44180584], [80.2765274, 13.44180965], [80.2765274, 13.44153023], [80.27680969, 13.44153023], [80.27680969, 13.44124889], [80.27708435, 13.44124889], [80.27707672, 13.44097137], [80.27735901, 13.44097137], [80.27735901, 13.44069576], [80.2776413, 13.44069576], [80.2776413, 13.44041538], [80.27707672, 13.44042015], [80.27707672, 13.44013023], [80.27625275, 13.44013977], [80.27625275, 13.4398613], [80.27708435, 13.4398613], [80.27708435, 13.43958282], [80.27791595, 13.43958282], [80.27791595, 13.43930531], [80.27874756, 13.43931007], [80.27874756, 13.43902969], [80.27986908, 13.43902969], [80.27986908, 13.43874931], [80.28069305, 13.43874931], [80.28069305, 13.43819141], [80.28097534, 13.43819523], [80.28097534, 13.43763924], [80.27874756, 13.43763924], [80.27874756, 13.43791962], [80.27540588, 13.43791962], [80.27540588, 13.43736076], [80.27513885, 13.43736076], [80.27513885, 13.43514061], [80.27540588, 13.43514061], [80.27540588, 13.43153095], [80.27513885, 13.43153095], [80.27513885, 13.43096066], [80.2748642, 13.43097305], [80.2748642, 13.43069458], [80.27458191, 13.43069458], [80.27458191, 13.43041706], [80.27430725, 13.43042088], [80.27430725, 13.42986107], [80.27402496, 13.42986107], [80.27402496, 13.4295826], [80.27375031, 13.4295826], [80.27375031, 13.42902565], [80.27348328, 13.42903137], [80.27348328, 13.42875099], [80.27319336, 13.42875099], [80.27319336, 13.42846966], [80.2729187, 13.42847347], [80.2729187, 13.42791557], [80.27263641, 13.4279213], [80.27263641, 13.42764091], [80.27236176, 13.42764091], [80.27236176, 13.42735958], [80.2720871, 13.42735958], [80.2720871, 13.4268074], [80.27179718, 13.42681122], [80.27179718, 13.42625046], [80.27153015, 13.42625046], [80.27153015, 13.4256897], [80.27124786, 13.42569447], [80.27124786, 13.42513847], [80.27097321, 13.42515182], [80.27097321, 13.42457962], [80.27069092, 13.42458439], [80.27069092, 13.4240284], [80.27041626, 13.42403126], [80.27041626, 13.42346954], [80.2701416, 13.4234724], [80.2701416, 13.42291641], [80.26985931, 13.42292118], [80.26985931, 13.42209053], [80.26957703, 13.42209053], [80.26957703, 13.42097187], [80.26930237, 13.42097187], [80.26930237, 13.42014027], [80.26902771, 13.42014027], [80.26902771, 13.41930962], [80.26875305, 13.41930962], [80.26875305, 13.41819096], [80.26847076, 13.41819382], [80.26847076, 13.41736221], [80.26875305, 13.41736031], [80.26875305, 13.41763973], [80.26902771, 13.41763973], [80.26902771, 13.41819382], [80.26930237, 13.41819096], [80.26930237, 13.41874981], [80.26957703, 13.41874981], [80.26957703, 13.41930962], [80.26985931, 13.41930962], [80.26985931, 13.41986179], [80.2701416, 13.41985989], [80.2701416, 13.42069435], [80.27041626, 13.42069244], [80.27041626, 13.42125034], [80.27068329, 13.42125034], [80.27068329, 13.42209053], [80.27097321, 13.42209053], [80.27097321, 13.42263985], [80.27124786, 13.42263794], [80.27124786, 13.42319393], [80.27153015, 13.42319202], [80.27153015, 13.42431068], [80.27179718, 13.42431068], [80.27179718, 13.42542076], [80.2720871, 13.42541599], [80.2720871, 13.42597198], [80.27236176, 13.42597008], [80.27236176, 13.42625046], [80.27263641, 13.42625046], [80.27263641, 13.42653084], [80.2729187, 13.42652893], [80.2729187, 13.42708206], [80.27319336, 13.42708206], [80.27319336, 13.42735958], [80.27348328, 13.42735958], [80.27348328, 13.4279213], [80.27375031, 13.42791557], [80.27375031, 13.428195], [80.27402496, 13.428195], [80.27402496, 13.42847347], [80.27430725, 13.42846966], [80.27430725, 13.42903137], [80.27458191, 13.42903137], [80.27458191, 13.42930889], [80.27513885, 13.42930698], [80.27513885, 13.4295826], [80.27540588, 13.42957973], [80.27540588, 13.42986107], [80.2756958, 13.42986107], [80.2756958, 13.43042088], [80.27597046, 13.43041706], [80.27597046, 13.43069458], [80.27625275, 13.4306879], [80.27625275, 13.43125057], [80.2765274, 13.43125057], [80.2765274, 13.43180943], [80.27680206, 13.43180466], [80.27680206, 13.43375111], [80.27708435, 13.43375111], [80.27708435, 13.43486118], [80.27735901, 13.43486118], [80.27735901, 13.43542194], [80.2776413, 13.43541718], [80.2776413, 13.43569469], [80.27902985, 13.43569469], [80.27902985, 13.43541718], [80.28125, 13.43541718], [80.28125, 13.43569469], [80.28263855, 13.43569469], [80.28263855, 13.43541718], [80.28291321, 13.43542194], [80.28291321, 13.43514061], [80.28320313, 13.43514061], [80.28320313, 13.4345808], [80.28347015, 13.43458271], [80.28347015, 13.43430519], [80.28375244, 13.43431187], [80.28375244, 13.43403053], [80.2840271, 13.43403053], [80.2840271, 13.43375111], [80.28430176, 13.43375111], [80.28430176, 13.43347073], [80.28458405, 13.43347263], [80.28458405, 13.43319511], [80.2848587, 13.43319511], [80.2848587, 13.43291664], [80.28514099, 13.43292141], [80.28514099, 13.43264103], [80.2859726, 13.43264103], [80.2859726, 13.43292141], [80.28624725, 13.43291664], [80.28624725, 13.43319511], [80.2868042, 13.43319511], [80.2868042, 13.43347263], [80.28708649, 13.43347073], [80.28708649, 13.43375111], [80.28736115, 13.43375111], [80.28736115, 13.43403053], [80.28791809, 13.43403053], [80.28791809, 13.43431187], [80.28819275, 13.43430519], [80.28819275, 13.43458271], [80.28874969, 13.43458271], [80.28874969, 13.43486118], [80.29013824, 13.43486118], [80.29013824, 13.43458271], [80.2904129, 13.43458271], [80.2904129, 13.43430519], [80.29070282, 13.43431187], [80.29070282, 13.43375111], [80.29096985, 13.43375111], [80.29096985, 13.43347073], [80.29125214, 13.43347263], [80.29125214, 13.43319511], [80.29152679, 13.43319511], [80.29152679, 13.43291664], [80.29180908, 13.43292141], [80.29180908, 13.43264103], [80.29207611, 13.43264103], [80.29207611, 13.43236065], [80.2923584, 13.43236065], [80.2923584, 13.43180943], [80.29264069, 13.43180943], [80.29264069, 13.43153095], [80.29292297, 13.43153095], [80.29292297, 13.43125057], [80.29374695, 13.43125057], [80.29374695, 13.43096066], [80.29402924, 13.43097305], [80.29402924, 13.43069458], [80.29430389, 13.43069458], [80.29430389, 13.42930698], [80.29458618, 13.42930889], [80.29458618, 13.42875099], [80.29486847, 13.42875099], [80.29486847, 13.42735958], [80.29541779, 13.42735958], [80.29541779, 13.42708206], [80.29736328, 13.42708206], [80.29736328, 13.4268074], [80.29763794, 13.42681122], [80.29763794, 13.42653084], [80.2979126, 13.42653084], [80.2979126, 13.42681122], [80.29921722, 13.4268074], [80.30042267, 13.42681122], [80.30042267, 13.42653084], [80.30069733, 13.42653084], [80.30069733, 13.42515182], [80.30152893, 13.42515182], [80.30152893, 13.42457962], [80.30124664, 13.42458439], [80.30124664, 13.42430592], [80.30097198, 13.42431068], [80.30097198, 13.42374992], [80.30124664, 13.42374992], [80.30124664, 13.42346954], [80.30097198, 13.4234724], [80.30097198, 13.42291641], [80.30069733, 13.42292118], [80.30069733, 13.42236042], [80.30041504, 13.42236233], [80.30041504, 13.42152786], [80.30014038, 13.42153263], [80.30014038, 13.42097187], [80.29985809, 13.42097187], [80.29985809, 13.41985989], [80.29957581, 13.41986179], [80.29957581, 13.41902065], [80.29985809, 13.41902828], [80.29985809, 13.41847229], [80.30014038, 13.41847229], [80.30014038, 13.4179163], [80.30042267, 13.41792011], [80.30042267, 13.41763973], [80.30069733, 13.41763973], [80.30069733, 13.41736031], [80.30124664, 13.41736221], [80.30124664, 13.41708374], [80.30152893, 13.41708374], [80.30152893, 13.41652775], [80.30179596, 13.41652966], [80.30179596, 13.41625023], [80.30236053, 13.41625023], [80.30236053, 13.41596031], [80.30263519, 13.41597176], [80.30263519, 13.41736221], [80.30236053, 13.41736031], [80.30236053, 13.41874981], [80.30208588, 13.41874981], [80.30208588, 13.41930962], [80.30180359, 13.4193058], [80.30180359, 13.41958427], [80.30152893, 13.41957855], [80.30152893, 13.4218111], [80.30179596, 13.4218111], [80.30179596, 13.42209053], [80.30208588, 13.42209053], [80.30208588, 13.42292118], [80.30236053, 13.42291641], [80.30236053, 13.42319393], [80.30263519, 13.42319393], [80.30263519, 13.4234724], [80.30291748, 13.42346954], [80.30291748, 13.42403126], [80.30319214, 13.42403126], [80.30319214, 13.42431068], [80.3034668, 13.42431068], [80.3034668, 13.42486], [80.30374908, 13.42486], [80.30374908, 13.42515182], [80.304039, 13.42515182], [80.304039, 13.42542076], [80.30458069, 13.42541599], [80.30458069, 13.42569447], [80.30486298, 13.42569447], [80.30486298, 13.42597198], [80.30541992, 13.42597008], [80.30541992, 13.42625046], [80.30568695, 13.42625046], [80.30568695, 13.42653084], [80.30625153, 13.42653084], [80.30625153, 13.42681122], [80.30652618, 13.4268074], [80.30652618, 13.42708206], [80.30680847, 13.42708206], [80.30680847, 13.42735958], [80.30735779, 13.42735958], [80.30735779, 13.42764091], [80.30819702, 13.42764091], [80.30819702, 13.4279213], [80.30930328, 13.42791557], [80.30930328, 13.428195], [80.31041718, 13.428195], [80.31041718, 13.42791557], [80.31069183, 13.42791557], [80.31069183, 13.428195], [80.31263733, 13.428195], [80.31263733, 13.42791557], [80.31299591, 13.42791557], [80.31375122, 13.42791557], [80.31375122, 13.428195], [80.31597137, 13.428195], [80.31597137, 13.42847347], [80.31625366, 13.42847347], [80.31625366, 13.428195], [80.31652832, 13.428195], [80.31652832, 13.42735958], [80.31680298, 13.42735958], [80.31680298, 13.42708206], [80.31652832, 13.42708206], [80.31652832, 13.42625046], [80.31680298, 13.42625046], [80.31680298, 13.42597008], [80.31708527, 13.42597198], [80.31708527, 13.42569447], [80.31791687, 13.42569447], [80.31791687, 13.42513847], [80.31764221, 13.42515182], [80.31764221, 13.42457962], [80.31735992, 13.42458439], [80.31735992, 13.4234724], [80.31708527, 13.4234724], [80.31708527, 13.42291641], [80.31735992, 13.42292118], [80.31735992, 13.42263985], [80.31791687, 13.42263985], [80.31791687, 13.42236042], [80.31846619, 13.42236042], [80.31846619, 13.42263985], [80.31874847, 13.42263985], [80.31874847, 13.4218111], [80.31846619, 13.4218111], [80.31846619, 13.42125034], [80.31819153, 13.42125034], [80.31819153, 13.42069244], [80.31847382, 13.42069435], [80.31847382, 13.42014027], [80.31874847, 13.42014027], [80.31874847, 13.41957855], [80.31903076, 13.41958427], [80.31903076, 13.4193058], [80.31931305, 13.41930962], [80.31931305, 13.41902065], [80.31958008, 13.41902828], [80.31958008, 13.41847229], [80.31986237, 13.41847229], [80.31986237, 13.4179163], [80.32013702, 13.41792011], [80.32013702, 13.41736031], [80.32041931, 13.41736221], [80.32041931, 13.41652775], [80.32068634, 13.41652966], [80.32068634, 13.41486168], [80.32041931, 13.41486168], [80.32041931, 13.4145813], [80.32013702, 13.41458416], [80.32013702, 13.41430473], [80.31986237, 13.41431046], [80.31986237, 13.41403198], [80.31958008, 13.41403198], [80.31958008, 13.4137516], [80.31874847, 13.4137516], [80.31874847, 13.41347122], [80.31847382, 13.41347122], [80.31847382, 13.41319561], [80.31819153, 13.41319561], [80.31819153, 13.41291809], [80.31764221, 13.41292191], [80.31764221, 13.41263866], [80.31735992, 13.41263866], [80.31735992, 13.41208076], [80.31725311, 13.41208267], [80.31708527, 13.41208267], [80.31708527, 13.41180515], [80.31732941, 13.41180992], [80.31735992, 13.41152954], [80.31764221, 13.41152954], [80.31764221, 13.41180992], [80.31847382, 13.41180515], [80.31847382, 13.41208267], [80.31930542, 13.41208267], [80.31930542, 13.41236115], [80.31958008, 13.41235924], [80.31958008, 13.41263866], [80.31986237, 13.41263866], [80.31986237, 13.41292191], [80.32041931, 13.41291809], [80.32041931, 13.41319561], [80.32096863, 13.41319561], [80.32096863, 13.41291809], [80.3215332, 13.41292191], [80.3215332, 13.41125107], [80.32180786, 13.41125107], [80.32180786, 13.40986061], [80.32208252, 13.40986061], [80.32208252, 13.40958118], [80.32236481, 13.40958309], [80.32236481, 13.40930462], [80.32263947, 13.40931034], [80.32263947, 13.40792179], [80.32290649, 13.40792179], [80.32290649, 13.40736103], [80.32319641, 13.40736103], [80.32319641, 13.40681171], [80.32347107, 13.40681171], [80.32347107, 13.40653133], [80.32375336, 13.40653133], [80.32375336, 13.40625095], [80.32402802, 13.40625095], [80.32402802, 13.40597057], [80.32430267, 13.40597343], [80.32430267, 13.40569496], [80.32458496, 13.40569496], [80.32458496, 13.40541744], [80.32485199, 13.40542126], [80.32485199, 13.40514088], [80.32514191, 13.40514088], [80.32514191, 13.40402031], [80.32485962, 13.40402889], [80.32485962, 13.40291691], [80.32457733, 13.40292072], [80.32457733, 13.40236092], [80.32430267, 13.40236092], [80.32430267, 13.40207958], [80.32375336, 13.40208244], [80.32375336, 13.40152645], [80.32402802, 13.40153122], [80.32402802, 13.40125275], [80.32430267, 13.40125275], [80.32430267, 13.4009819], [80.32485199, 13.4009819], [80.32485199, 13.40069008], [80.32514191, 13.40069485], [80.32514191, 13.40041637], [80.32541656, 13.40042114], [80.32541656, 13.40014076], [80.32569122, 13.40014076], [80.32569122, 13.39986038], [80.32624817, 13.39986038], [80.32624817, 13.39902782], [80.32653046, 13.39903069], [80.32653046, 13.39597034], [80.32624817, 13.39597225], [80.32624817, 13.39569378], [80.32597351, 13.39569378], [80.32597351, 13.39486217], [80.32569122, 13.39486217], [80.32569122, 13.39235973], [80.32541656, 13.39235973], [80.32541656, 13.39207935], [80.32458496, 13.39208412], [80.32458496, 13.39180565], [80.32430267, 13.39181042], [80.32430267, 13.39153004], [80.32375336, 13.39153004], [80.32375336, 13.39124966], [80.32290649, 13.39124966], [80.32290649, 13.3906889], [80.32263947, 13.39069366], [80.32263947, 13.39013767], [80.32235718, 13.39013958], [80.32235718, 13.3898592], [80.32319641, 13.3898592], [80.32319641, 13.39013958], [80.32402802, 13.39013958], [80.32402802, 13.39041996], [80.32458496, 13.39041805], [80.32458496, 13.39069366], [80.32514191, 13.39069366], [80.32514191, 13.39041805], [80.32569122, 13.39041996], [80.32569122, 13.39013958], [80.32596588, 13.39013958], [80.32596588, 13.3898592], [80.32624817, 13.38986206], [80.32624817, 13.38958359], [80.32680511, 13.38958359], [80.32680511, 13.38930607], [80.32707977, 13.38931179], [80.32707977, 13.38904095], [80.32736206, 13.38904095], [80.32736206, 13.38875198], [80.32791901, 13.38875198], [80.32791901, 13.38847065], [80.32819366, 13.38847065], [80.32819366, 13.38819313], [80.32847595, 13.38819313], [80.32847595, 13.38791847], [80.32875061, 13.38792038], [80.32875061, 13.38764191], [80.32930756, 13.38764191], [80.32930756, 13.38736153], [80.32958221, 13.38736153], [80.32958221, 13.38708401], [80.3298645, 13.38708401], [80.3298645, 13.38486099], [80.33013916, 13.38486099], [80.33013916, 13.38042164], [80.33040619, 13.38042164], [80.33040619, 13.3779192], [80.33013916, 13.3779192], [80.33013916, 13.37764072], [80.32985687, 13.37764072], [80.32985687, 13.37707996], [80.32958221, 13.37708282], [80.32958221, 13.37680531], [80.32930756, 13.37681103], [80.32930756, 13.37653065], [80.3290329, 13.37653065], [80.3290329, 13.37625122], [80.32875061, 13.37625122], [80.32875061, 13.37597275], [80.32847595, 13.37597275], [80.32847595, 13.37542057], [80.32818604, 13.37542057], [80.32818604, 13.37514114], [80.32791901, 13.37514114], [80.32791901, 13.3748579], [80.32763672, 13.37485981], [80.32763672, 13.37458229], [80.32736206, 13.37458229], [80.32736206, 13.37430668], [80.32681274, 13.37431145], [80.32681274, 13.37403965], [80.32653046, 13.37403965], [80.32653046, 13.37375069], [80.32624817, 13.37375069], [80.32624817, 13.37318993], [80.32597351, 13.37319374], [80.32597351, 13.37263775], [80.32569122, 13.37264061], [80.32569122, 13.37236023], [80.32541656, 13.37236023], [80.32541656, 13.37180424], [80.32514191, 13.37181091], [80.32514191, 13.37153053], [80.32485199, 13.37153053], [80.32485199, 13.37096977], [80.32458496, 13.37097168], [80.32458496, 13.37069416], [80.32430267, 13.37069416], [80.32430267, 13.37041569], [80.32457733, 13.37042141], [80.32457733, 13.37014008], [80.32485199, 13.37014008], [80.32485199, 13.3698597], [80.32514191, 13.3698597], [80.32514191, 13.36958027], [80.32541656, 13.36958218], [80.32541656, 13.36930561], [80.32569122, 13.36931133], [80.32569122, 13.36903], [80.32596588, 13.36903], [80.32596588, 13.36874962], [80.32624817, 13.36874962], [80.32624817, 13.36847019], [80.32653046, 13.3684721], [80.32653046, 13.36819363], [80.32680511, 13.36819363], [80.32680511, 13.36791611], [80.32707977, 13.36791611], [80.32707977, 13.36763763], [80.32736206, 13.36763954], [80.32736206, 13.36736202], [80.32763672, 13.36736202], [80.32763672, 13.36708164], [80.32819366, 13.36708355], [80.32819366, 13.36680603], [80.32847595, 13.3668108], [80.32847595, 13.36653042], [80.3290329, 13.36653042], [80.3290329, 13.36763954], [80.32875061, 13.36763763], [80.32875061, 13.3684721], [80.32847595, 13.36847019], [80.32847595, 13.36874962], [80.32818604, 13.36874962], [80.32818604, 13.36903], [80.32791901, 13.36903], [80.32791901, 13.36931133], [80.32736206, 13.36930561], [80.32736206, 13.36958218], [80.32707977, 13.36958027], [80.32707977, 13.37014008], [80.32736206, 13.37013817], [80.32736206, 13.37097168], [80.32763672, 13.37096977], [80.32763672, 13.37181091], [80.32791901, 13.37181091], [80.32791901, 13.37292099], [80.32819366, 13.37291622], [80.32819366, 13.37319374], [80.32847595, 13.37319374], [80.32847595, 13.37347317], [80.32875061, 13.37347031], [80.32875061, 13.37375069], [80.3290329, 13.37375069], [80.3290329, 13.37403965], [80.32930756, 13.37403965], [80.32930756, 13.37431145], [80.32958221, 13.37430668], [80.32958221, 13.37458229], [80.3298645, 13.37458229], [80.3298645, 13.37485981], [80.33013916, 13.3748579], [80.33013916, 13.37514114], [80.33040619, 13.37514114], [80.33040619, 13.37542057], [80.33069611, 13.37541676], [80.33069611, 13.37569523], [80.33097076, 13.37569523], [80.33097076, 13.37625122], [80.33125305, 13.37625122], [80.33125305, 13.37653065], [80.33152771, 13.37652874], [80.33152771, 13.37958336], [80.33180237, 13.37958145], [80.33180237, 13.38375092], [80.33152771, 13.38375092], [80.33152771, 13.38542175], [80.33125305, 13.38542175], [80.33125305, 13.38792038], [80.33097839, 13.38792038], [80.33097839, 13.39124966], [80.33069611, 13.39124966], [80.33069611, 13.39291954], [80.33041382, 13.39291573], [80.33041382, 13.39347172], [80.33013916, 13.39346981], [80.33013916, 13.39402962], [80.3298645, 13.39402771], [80.3298645, 13.3945837], [80.32958221, 13.39458179], [80.32958221, 13.39513969], [80.32930756, 13.39513779], [80.32930756, 13.39569378], [80.3290329, 13.39569187], [80.3290329, 13.39624977], [80.32875061, 13.39624977], [80.32875061, 13.39681053], [80.32847595, 13.39680576], [80.32847595, 13.39735985], [80.32819366, 13.39735985], [80.32819366, 13.39847183], [80.32791901, 13.39846992], [80.32791901, 13.40014076], [80.32763672, 13.40014076], [80.32763672, 13.40153122], [80.32736206, 13.40152645], [80.32736206, 13.40319538], [80.32707977, 13.40319538], [80.32707977, 13.40458298], [80.32681274, 13.40458012], [80.32681274, 13.40542126], [80.32653046, 13.40541744], [80.32653046, 13.40597343], [80.32624817, 13.40597057], [80.32624817, 13.40653133], [80.32597351, 13.40652657], [80.32597351, 13.40708256], [80.32569122, 13.40708065], [80.32569122, 13.40764141], [80.32541656, 13.40764141], [80.32541656, 13.40792179], [80.32514191, 13.40791702], [80.32514191, 13.40819454], [80.32485962, 13.40819454], [80.32485962, 13.40847301], [80.32457733, 13.40847111], [80.32457733, 13.40875053], [80.32430267, 13.40875053], [80.32430267, 13.40903187], [80.32402802, 13.40903187], [80.32402802, 13.40931034], [80.32375336, 13.40930462], [80.32375336, 13.40986061], [80.32347107, 13.40986061], [80.32347107, 13.41015053], [80.32375336, 13.41015053], [80.32375336, 13.41125107], [80.32402802, 13.41124916], [80.32402802, 13.41236115], [80.32375336, 13.41236115], [80.32375336, 13.41319561], [80.32347107, 13.41319561], [80.32347107, 13.41347122], [80.32375336, 13.41347122], [80.32375336, 13.41431046], [80.32402802, 13.41430473], [80.32402802, 13.41458416], [80.32375336, 13.4145813], [80.32375336, 13.41541958], [80.32402802, 13.41541767], [80.32402802, 13.41597176], [80.32375336, 13.41596031], [80.32375336, 13.41652966], [80.32347107, 13.41652775], [80.32347107, 13.41736221], [80.32319641, 13.41736031], [80.32319641, 13.41763973], [80.32291412, 13.41763973], [80.32291412, 13.41847229], [80.32263947, 13.41847229], [80.32263947, 13.41902828], [80.32290649, 13.41902065], [80.32290649, 13.41930962], [80.32263947, 13.41930962], [80.32263947, 13.41986179], [80.32235718, 13.41986179], [80.32235718, 13.42014027], [80.32152557, 13.42014027], [80.32152557, 13.42069435], [80.32125092, 13.42069244], [80.32125092, 13.42125034], [80.32096863, 13.42125034], [80.32096863, 13.4218111], [80.32069397, 13.42180634], [80.32069397, 13.42236233], [80.32041931, 13.42236042], [80.32041931, 13.42292118], [80.32013702, 13.42291641], [80.32013702, 13.4234724], [80.31986237, 13.42346954], [80.31986237, 13.42374992], [80.31931305, 13.42374992], [80.31931305, 13.42403126], [80.31958008, 13.4240284], [80.31958008, 13.42458439], [80.31986237, 13.42457962], [80.31986237, 13.42653084], [80.32013702, 13.42653084], [80.32013702, 13.42681122], [80.32041931, 13.4268074], [80.32041931, 13.42708206], [80.32069397, 13.42708206], [80.32069397, 13.42735958], [80.3215332, 13.42735958], [80.3215332, 13.42764091], [80.32263947, 13.42764091], [80.32263947, 13.42735958], [80.32291412, 13.42735958], [80.32291412, 13.4268074], [80.32319641, 13.42681122], [80.32319641, 13.4256897], [80.32347107, 13.42569447], [80.32347107, 13.42708206], [80.32375336, 13.42708206], [80.32375336, 13.42735958], [80.32402802, 13.42735958], [80.32402802, 13.42764091], [80.32457733, 13.42764091], [80.32457733, 13.4279213], [80.32485962, 13.42791557], [80.32485962, 13.428195], [80.32514191, 13.428195], [80.32514191, 13.42847347], [80.32541656, 13.42846966], [80.32541656, 13.42903137], [80.32569122, 13.42903137], [80.32569122, 13.42930889], [80.32596588, 13.42930889], [80.32596588, 13.42986107], [80.32624817, 13.42986107], [80.32624817, 13.43125057], [80.32596588, 13.43125057], [80.32597351, 13.43236065], [80.32569122, 13.43236065], [80.32569122, 13.43458271], [80.32541656, 13.4345808], [80.32541656, 13.43625069], [80.32514191, 13.43625069], [80.32514191, 13.43791962], [80.32485199, 13.43791962], [80.32485199, 13.43902969], [80.32457733, 13.43902969], [80.32457733, 13.44236183], [80.32485199, 13.44236183], [80.32485199, 13.4426403], [80.32514191, 13.4426403], [80.32514191, 13.44319439], [80.32541656, 13.44319057], [80.32541656, 13.44375038], [80.32569122, 13.44375038], [80.32569122, 13.44319057], [80.32597351, 13.44319439], [80.32597351, 13.4426403], [80.32624817, 13.4426403], [80.32624817, 13.43958092], [80.32653046, 13.43958282], [80.32653046, 13.43791676], [80.32681274, 13.43791962], [80.32681274, 13.43625069], [80.32707977, 13.43625069], [80.32707977, 13.43431187], [80.32736206, 13.43431187], [80.32736206, 13.43264103], [80.32763672, 13.43264103], [80.32763672, 13.43125057], [80.32791901, 13.43125057], [80.32791901, 13.42986107], [80.32818604, 13.42986107], [80.32818604, 13.42681122], [80.32791901, 13.42681122], [80.32791901, 13.4256897], [80.32819366, 13.42569447], [80.32819366, 13.42513847], [80.32847595, 13.42515182], [80.32847595, 13.42209053], [80.32818604, 13.42209053], [80.32818604, 13.42153263], [80.32791901, 13.42153263], [80.32791901, 13.42097187], [80.32763672, 13.42097187], [80.32763672, 13.42041588], [80.32736206, 13.42041969], [80.32736206, 13.42014027], [80.32707977, 13.42014027], [80.32707977, 13.41986179], [80.32736206, 13.41986179], [80.32736206, 13.41930962], [80.32763672, 13.41930962], [80.32763672, 13.41902065], [80.32791901, 13.41902828], [80.32791901, 13.41847229], [80.32819366, 13.41847229], [80.32819366, 13.41680622], [80.32847595, 13.41681004], [80.32847595, 13.4145813], [80.32875061, 13.41458416], [80.32875061, 13.40847301], [80.32902527, 13.40847301], [80.32902527, 13.40708256], [80.32875061, 13.40708256], [80.32875061, 13.40680504], [80.3290329, 13.40681171], [80.3290329, 13.40486145], [80.32930756, 13.40486145], [80.32930756, 13.40458298], [80.32958221, 13.40458298], [80.32958221, 13.40430546], [80.32985687, 13.40430927], [80.32985687, 13.40375137], [80.32958221, 13.40375137], [80.32958221, 13.40236092], [80.32985687, 13.40236092], [80.32985687, 13.40125275], [80.32958221, 13.40125275], [80.32958221, 13.40014076], [80.32985687, 13.40014076], [80.32985687, 13.39986038], [80.33013916, 13.39986038], [80.33013916, 13.39847183], [80.33041382, 13.39847183], [80.33041382, 13.39763832], [80.33069611, 13.39764023], [80.33069611, 13.39653111], [80.33097839, 13.39653111], [80.33097839, 13.39513969], [80.33125305, 13.39513969], [80.33125305, 13.39485073], [80.33097076, 13.39486217], [80.33097076, 13.39430618], [80.33125305, 13.39431095], [80.33125305, 13.39346981], [80.33152771, 13.39347172], [80.33152771, 13.39235973], [80.33180237, 13.39235973], [80.33180237, 13.39124966], [80.33207703, 13.39124966], [80.33207703, 13.39013958], [80.33235931, 13.39013958], [80.33235931, 13.38904095], [80.3326416, 13.38904095], [80.3326416, 13.38792038], [80.33291626, 13.38792038], [80.33291626, 13.3868103], [80.33319092, 13.3868103], [80.33319092, 13.38569069], [80.33347321, 13.38569641], [80.33347321, 13.38458347], [80.33374786, 13.38458347], [80.33374786, 13.3834734], [80.33403015, 13.3834734], [80.33403015, 13.38236141], [80.33430481, 13.38236141], [80.33430481, 13.38125134], [80.3345871, 13.38125134], [80.3345871, 13.38014126], [80.33486176, 13.38014126], [80.33486176, 13.37903118], [80.33513641, 13.37903118], [80.33513641, 13.3779192], [80.3354187, 13.3779192], [80.3354187, 13.37681103], [80.33569336, 13.37681103], [80.33569336, 13.37597275], [80.33598328, 13.37597275], [80.33597565, 13.37485981], [80.33625031, 13.37485981], [80.33625031, 13.37375069], [80.33651733, 13.37375069], [80.33651733, 13.37264061], [80.33680725, 13.37264061], [80.33680725, 13.37181091], [80.33651733, 13.37181091], [80.33651733, 13.37069035], [80.33680725, 13.37069416], [80.33680725, 13.37097168], [80.33708191, 13.37097168], [80.33708191, 13.37069416], [80.3373642, 13.37069416], [80.3373642, 13.36958218], [80.33763885, 13.36958218], [80.33763885, 13.3684721], [80.33791351, 13.3684721], [80.33791351, 13.36736202], [80.3381958, 13.36736202], [80.3381958, 13.36653042], [80.33847046, 13.36653042], [80.33847046, 13.36542034], [80.33875275, 13.36542034], [80.33875275, 13.36431026], [80.3390274, 13.36431026], [80.3390274, 13.36375046], [80.33875275, 13.36375046], [80.33875275, 13.36347198], [80.3390274, 13.36347198], [80.3390274, 13.36236191], [80.33930206, 13.36236191], [80.33930206, 13.36208057], [80.33958435, 13.36208439], [80.33958435, 13.36097145], [80.33985901, 13.36097145], [80.33985901, 13.36041546], [80.33957672, 13.36042023], [80.33957672, 13.35986233], [80.33985901, 13.35986233], [80.33985901, 13.35763931], [80.34014893, 13.35763931], [80.34014893, 13.35708141], [80.34041595, 13.35708332], [80.34041595, 13.35624886], [80.34069061, 13.35625076], [80.34069824, 13.35568237], [80.3409729, 13.35569477], [80.3409729, 13.35513878], [80.34124756, 13.35514069], [80.34124756, 13.35293102], [80.34152985, 13.35293102], [80.34152985, 13.35236073], [80.34179687, 13.35236073], [80.34179687, 13.35097122], [80.34152985, 13.35097313], [80.34152985, 13.35013866], [80.34179687, 13.35014057], [80.34179687, 13.34986973], [80.34208679, 13.34986973], [80.34208679, 13.34903145], [80.34236145, 13.34903145], [80.34236145, 13.34735966], [80.34263611, 13.34735966], [80.34263611, 13.34514141], [80.3429184, 13.34514141], [80.3429184, 13.34431076], [80.34319305, 13.34431076], [80.34319305, 13.34263992], [80.34348297, 13.34263992], [80.34348297, 13.34208202], [80.34375, 13.34208202], [80.34375, 13.34180641], [80.34401703, 13.34181118], [80.34401703, 13.34042263], [80.34375, 13.34042263], [80.34375, 13.33985996], [80.34401703, 13.33985996], [80.34401703, 13.33903027], [80.34430695, 13.33903027], [80.34430695, 13.33793163], [80.3445816, 13.33793163], [80.3445816, 13.33763981], [80.34430695, 13.33763981], [80.34430695, 13.33625031], [80.3445816, 13.33625031], [80.3445816, 13.33569145], [80.34486389, 13.33569431], [80.34486389, 13.33541775], [80.3445816, 13.33541965], [80.3445816, 13.33430958], [80.34485626, 13.33430958], [80.34485626, 13.33180141], [80.3445816, 13.33180523], [80.3445816, 13.33152676], [80.34401703, 13.33152962], [80.34401703, 13.33124924], [80.3445816, 13.33124924], [80.3445816, 13.33097076], [80.34513855, 13.33097076], [80.34513855, 13.33014202], [80.34541321, 13.33014202], [80.34541321, 13.32764053], [80.34570313, 13.32764053], [80.34570313, 13.32597065], [80.34597015, 13.32597256], [80.34597015, 13.32541656], [80.34570313, 13.32542133], [80.34570313, 13.32181072], [80.34541321, 13.32181072], [80.34541321, 13.32069016], [80.3456955, 13.32069492], [80.3456955, 13.3204174], [80.34596252, 13.32042122], [80.34596252, 13.31986046], [80.34625244, 13.31986046], [80.34625244, 13.31958199], [80.34597015, 13.31958199], [80.34597015, 13.31902885], [80.34570313, 13.31903076], [80.34570313, 13.31764126], [80.34596252, 13.31764126], [80.34596252, 13.3154211], [80.34625244, 13.3154211], [80.34625244, 13.31347179], [80.3465271, 13.31347179], [80.3465271, 13.31318855], [80.34680176, 13.31319427], [80.34680176, 13.31180573], [80.3465271, 13.31180954], [80.3465271, 13.31124973], [80.34680176, 13.31124973], [80.34680176, 13.30847168], [80.3465271, 13.30847168], [80.3465271, 13.30764008], [80.34625244, 13.30764008], [80.34625244, 13.3073616], [80.34597015, 13.3073616], [80.34596252, 13.30513859], [80.34625244, 13.30513859], [80.34625244, 13.3045702], [80.3465271, 13.3045826], [80.3465271, 13.3040266], [80.34570313, 13.30403042], [80.34570313, 13.30375099], [80.34541321, 13.30375099], [80.34541321, 13.30264187], [80.34625244, 13.30264187], [80.34625244, 13.30182076], [80.3465271, 13.30182076], [80.3465271, 13.30014133], [80.34596252, 13.30014133], [80.34596252, 13.29931164], [80.34625244, 13.29931164], [80.34625244, 13.2968092], [80.34596252, 13.2968092], [80.34596252, 13.29596996], [80.34625244, 13.29597282], [80.34625244, 13.29486084], [80.34596252, 13.29486275], [80.34596252, 13.29347038], [80.34625244, 13.29347324], [80.34625244, 13.29236031], [80.3465271, 13.29236031], [80.3465271, 13.29152775], [80.34625244, 13.29153061], [80.34625244, 13.29125023], [80.3456955, 13.29125023], [80.3456955, 13.29069424], [80.34597015, 13.29069424], [80.34597015, 13.29041576], [80.34570313, 13.29042053], [80.34570313, 13.28985977], [80.34597015, 13.28985977], [80.34596252, 13.28931141], [80.34570313, 13.28931141], [80.34570313, 13.28847027], [80.34541321, 13.28847218], [80.34541321, 13.28791618], [80.34485626, 13.28792095], [80.34485626, 13.28763962], [80.34348297, 13.28763962], [80.34348297, 13.28652954], [80.34319305, 13.28652954], [80.34319305, 13.28431034], [80.34348297, 13.28431034], [80.34348297, 13.2804203], [80.34319305, 13.2804203], [80.34319305, 13.28014183], [80.34348297, 13.28014183], [80.34348297, 13.27958107], [80.34375, 13.27958393], [80.34375, 13.27902699], [80.3445816, 13.27903175], [80.3445816, 13.27847099], [80.34430695, 13.27847099], [80.34430695, 13.27791691], [80.34401703, 13.27791977], [80.34401703, 13.27765083], [80.34375, 13.27765083], [80.34375, 13.27736092], [80.34347534, 13.27736092], [80.34347534, 13.2770834], [80.34319305, 13.2770834], [80.34319305, 13.27597332], [80.3429184, 13.27597332], [80.3429184, 13.27569485], [80.34263611, 13.27569485], [80.34263611, 13.27541733], [80.3429184, 13.27542019], [80.3429184, 13.27514076], [80.34319305, 13.27514076], [80.34319305, 13.27486134], [80.34402466, 13.27486134], [80.34402466, 13.27458286], [80.3445816, 13.27458954], [80.3445816, 13.27431202], [80.34485626, 13.27431202], [80.34485626, 13.27319145], [80.3445816, 13.27319527], [80.3445816, 13.27291679], [80.34401703, 13.27292156], [80.34401703, 13.27264118], [80.34348297, 13.27264118], [80.34348297, 13.2723608], [80.34319305, 13.2723608], [80.34319305, 13.27208328], [80.3429184, 13.27208328], [80.3429184, 13.27180481], [80.3418045, 13.27180481], [80.3418045, 13.27208328], [80.34152985, 13.27208328], [80.34152985, 13.27319527], [80.34124756, 13.27319527], [80.34124756, 13.27291679], [80.3409729, 13.27292156], [80.3409729, 13.27264118], [80.34069824, 13.27264118], [80.34069061, 13.27181244], [80.34041595, 13.27181244], [80.34041595, 13.2709713], [80.3401413, 13.27097321], [80.3401413, 13.27041721], [80.33985901, 13.27042103], [80.33985901, 13.26986122], [80.33958435, 13.26986122], [80.33958435, 13.26930523], [80.33930206, 13.26931095], [80.33930206, 13.26792145], [80.33875275, 13.26792145], [80.33875275, 13.26764107], [80.33847046, 13.26764107], [80.33847046, 13.26708031], [80.3390274, 13.26708221], [80.3390274, 13.26652908], [80.33875275, 13.26653099], [80.33875275, 13.26568985], [80.33847046, 13.26569366], [80.33847046, 13.26541615], [80.33875275, 13.26542091], [80.33875275, 13.26514053], [80.33847046, 13.26514053], [80.33847046, 13.26457977], [80.3381958, 13.26458454], [80.3381958, 13.26375008], [80.33790588, 13.26375008], [80.33790588, 13.26292133], [80.33763885, 13.26292133], [80.33763885, 13.26235962], [80.3373642, 13.26236153], [80.3373642, 13.26124954], [80.33708191, 13.26124954], [80.33708191, 13.25403023], [80.33735657, 13.25403023], [80.33735657, 13.25264168], [80.33708191, 13.25264168], [80.33708191, 13.25208092], [80.33680725, 13.25208282], [80.33680725, 13.25097084], [80.33651733, 13.25097084], [80.33651733, 13.25013924], [80.33625031, 13.25013924], [80.33625031, 13.24930954], [80.33598328, 13.24930954], [80.33598328, 13.24875069], [80.33569336, 13.24875069], [80.33569336, 13.24792194], [80.3354187, 13.24792194], [80.3354187, 13.24653053], [80.33513641, 13.24653053], [80.33513641, 13.24542236], [80.33486176, 13.24542236], [80.33486176, 13.24486065], [80.3345871, 13.24486065], [80.3345871, 13.24430943], [80.33429718, 13.24430943], [80.33429718, 13.24403095], [80.3345871, 13.24403095], [80.3345871, 13.24375057], [80.33429718, 13.24375057], [80.33429718, 13.24207973], [80.33403015, 13.2420826], [80.33403015, 13.24180698], [80.33429718, 13.24180889], [80.33429718, 13.24152184], [80.33403015, 13.2415266], [80.33403015, 13.24041653], [80.33374786, 13.2404213], [80.33374786, 13.24014091], [80.33402252, 13.24014091], [80.33402252, 13.23985958], [80.33374786, 13.23985958], [80.33374786, 13.2393074], [80.33347321, 13.23931122], [80.33347321, 13.23875141], [80.33291626, 13.23875141], [80.33291626, 13.23848248], [80.3326416, 13.23848248], [80.3326416, 13.2381897], [80.33235931, 13.23819447], [80.33235931, 13.23791599], [80.33180237, 13.23792076], [80.33180237, 13.23681068], [80.33152771, 13.23681068], [80.33152771, 13.23624992], [80.33125305, 13.23624992], [80.33125305, 13.23596954], [80.33097076, 13.2359724], [80.33097076, 13.23569393], [80.33041382, 13.23569393], [80.33041382, 13.23541641], [80.32958221, 13.23542118], [80.32958221, 13.23513985], [80.3290329, 13.23513985], [80.3290329, 13.23542118], [80.32875061, 13.23542118], [80.32875061, 13.23513985], [80.32818604, 13.23513985], [80.32818604, 13.23542118], [80.32791901, 13.23542118], [80.32791901, 13.23513985], [80.32763672, 13.23513985], [80.32763672, 13.23486042], [80.32680511, 13.23486233], [80.32680511, 13.23458195], [80.32624817, 13.23458195], [80.32624817, 13.23430634], [80.32569122, 13.2343111], [80.32569122, 13.23402977], [80.32541656, 13.23402977], [80.32541656, 13.23375034], [80.32514191, 13.23375034], [80.32514191, 13.23347187], [80.32485962, 13.23347187], [80.32485962, 13.23319435], [80.32402802, 13.23319435], [80.32402802, 13.23291588], [80.32290649, 13.23291969], [80.32290649, 13.23264027], [80.32208252, 13.23264027], [80.32208252, 13.2323513], [80.3215332, 13.2323513], [80.3215332, 13.23264027], [80.32125092, 13.23264027], [80.32125092, 13.2323513], [80.32041931, 13.23235989], [80.32041931, 13.23208427], [80.31981659, 13.23208427], [80.31903076, 13.23208427], [80.31903076, 13.2318058], [80.31874847, 13.23181057], [80.31874847, 13.23153019], [80.31819153, 13.23153019], [80.31819153, 13.23124981], [80.31708527, 13.23124981], [80.31708527, 13.23235989], [80.31680298, 13.23235989], [80.31680298, 13.23319435], [80.31652832, 13.23318863], [80.31652832, 13.23402977], [80.31625366, 13.23402786], [80.31625366, 13.23486233], [80.315979, 13.23486042], [80.315979, 13.23624992], [80.31624603, 13.23624992], [80.31624603, 13.23848248], [80.31652832, 13.23848248], [80.31652832, 13.23931122], [80.31680298, 13.2393074], [80.31680298, 13.23985958], [80.3170929, 13.23985958], [80.3170929, 13.2404213], [80.31680298, 13.2404213], [80.31680298, 13.24125099], [80.31652832, 13.24125099], [80.31652832, 13.24292088], [80.31624603, 13.24292088], [80.31624603, 13.24430943], [80.31597137, 13.24430466], [80.31597137, 13.24458313], [80.31569672, 13.24458122], [80.31569672, 13.24486065], [80.3154068, 13.24486065], [80.3154068, 13.24514103], [80.31513977, 13.24514103], [80.31513977, 13.24542236], [80.31485748, 13.24541664], [80.31485748, 13.24569511], [80.31458282, 13.24569511], [80.31458282, 13.24597263], [80.31430817, 13.24597073], [80.31430817, 13.24653053], [80.31375122, 13.24653053], [80.31375122, 13.24514103], [80.31402588, 13.24514103], [80.31402588, 13.24430943], [80.31458282, 13.24430943], [80.31458282, 13.24403095], [80.31513977, 13.24403095], [80.31513977, 13.24236107], [80.3154068, 13.24236107], [80.3154068, 13.23931122], [80.31513977, 13.23931122], [80.31513977, 13.23875141], [80.31485748, 13.23875141], [80.31485748, 13.23624992], [80.31458282, 13.23624992], [80.31458282, 13.23542118], [80.31430817, 13.23542118], [80.31430817, 13.2343111], [80.31402588, 13.2343111], [80.31402588, 13.23318863], [80.31375122, 13.23319435], [80.31375122, 13.23264027], [80.31346893, 13.23264027], [80.31346893, 13.2323513], [80.31319427, 13.23235989], [80.31319427, 13.23152828], [80.31346893, 13.23153019], [80.31346893, 13.23124981], [80.31375122, 13.23124981], [80.31375122, 13.23097038], [80.31402588, 13.23097229], [80.31402588, 13.23069382], [80.31430817, 13.23069382], [80.31430817, 13.2304163], [80.31458282, 13.23042011], [80.31458282, 13.23013973], [80.31485748, 13.23013973], [80.31485748, 13.22958183], [80.31513977, 13.22958374], [80.31513977, 13.22930622], [80.3154068, 13.22931004], [80.3154068, 13.22902966], [80.31569672, 13.22902966], [80.31569672, 13.22846889], [80.31597137, 13.22847176], [80.31597137, 13.22819424], [80.31625366, 13.22819424], [80.31625366, 13.22764015], [80.31652832, 13.22764015], [80.31652832, 13.22736168], [80.31680298, 13.22736168], [80.31680298, 13.2270813], [80.31708527, 13.22708416], [80.31708527, 13.22680569], [80.31735992, 13.22681046], [80.31735992, 13.22654057], [80.31764221, 13.22654057], [80.31764221, 13.22597122], [80.31680298, 13.22597122], [80.31680298, 13.22569561], [80.31569672, 13.22569561], [80.31569672, 13.22541809], [80.31485748, 13.22542], [80.31485748, 13.22513962], [80.31375122, 13.22513962], [80.31375122, 13.22485924], [80.31346893, 13.22486115], [80.31346893, 13.22458267], [80.31319427, 13.22458267], [80.31319427, 13.22430515], [80.31263733, 13.22430992], [80.31263733, 13.22402954], [80.31236267, 13.22402954], [80.31236267, 13.22348022], [80.31208038, 13.22348022], [80.31208038, 13.22292042], [80.31153107, 13.22292042], [80.31153107, 13.22264194], [80.31069183, 13.22264194], [80.31069183, 13.22125053], [80.31096649, 13.22125053], [80.31096649, 13.22069073], [80.31124878, 13.22069454], [80.31124878, 13.21986103], [80.31096649, 13.21986103], [80.31096649, 13.21903133], [80.31069183, 13.21903133], [80.31069183, 13.21875095], [80.31041718, 13.21875095], [80.31041718, 13.21847057], [80.31014252, 13.21847343], [80.31014252, 13.21819496], [80.30986023, 13.21819496], [80.30986023, 13.21791744], [80.3095932, 13.21791935], [80.3095932, 13.21764088], [80.30930328, 13.21764088], [80.30930328, 13.21735191], [80.30874634, 13.21736145], [80.30874634, 13.21708298], [80.30847168, 13.21708298], [80.30847168, 13.21680546], [80.3079071, 13.21680927], [80.3079071, 13.21652889], [80.30735779, 13.21652889], [80.30735779, 13.21625137], [80.30708313, 13.21625137], [80.30708313, 13.21597099], [80.30680847, 13.2159729], [80.30680847, 13.21541691], [80.30652618, 13.21542072], [80.30652618, 13.2151413], [80.30625153, 13.2151413], [80.30625153, 13.21486092], [80.30652618, 13.21486092], [80.30652618, 13.21460056], [80.30652618, 13.21430683], [80.30680847, 13.21431065], [80.30680847, 13.21236038], [80.30708313, 13.21236038], [80.30708313, 13.21180439], [80.30735779, 13.21181107], [80.30735779, 13.21125031], [80.30819702, 13.21125031], [80.30819702, 13.21264076], [80.3079071, 13.21264076], [80.3079071, 13.21431065], [80.30764008, 13.21431065], [80.30764008, 13.21486092], [80.3079071, 13.21486092], [80.3079071, 13.2151413], [80.30819702, 13.21513939], [80.30819702, 13.21545982], [80.30819702, 13.21569538], [80.30847168, 13.21569538], [80.30847168, 13.2159729], [80.30874634, 13.21597099], [80.30874634, 13.21625137], [80.30902863, 13.21625137], [80.30902863, 13.21680927], [80.30930328, 13.21680546], [80.30930328, 13.21708298], [80.31041718, 13.21708298], [80.31041718, 13.21664143], [80.31041718, 13.21541691], [80.31097412, 13.21541691], [80.31097412, 13.21569538], [80.31124878, 13.21569538], [80.31124878, 13.2159729], [80.31153107, 13.21597099], [80.31153107, 13.21625137], [80.31181335, 13.21625137], [80.31181335, 13.21652889], [80.31208038, 13.21652889], [80.31208038, 13.21680927], [80.31236267, 13.21680546], [80.31236267, 13.21708298], [80.31263733, 13.21708298], [80.31263733, 13.21736145], [80.31291199, 13.21735191], [80.31291199, 13.21764088], [80.31319427, 13.21763897], [80.31319427, 13.21819496], [80.31291199, 13.21819019], [80.31291199, 13.21931171], [80.31319427, 13.21930504], [80.31319427, 13.22041702], [80.31346893, 13.22041702], [80.31346893, 13.22208309], [80.31402588, 13.22208118], [80.31402588, 13.22236061], [80.31430817, 13.22236061], [80.31430817, 13.22264194], [80.31485748, 13.22264194], [80.31485748, 13.22292042], [80.31541443, 13.2229166], [80.31541443, 13.22319317], [80.31569672, 13.22319126], [80.31569672, 13.22348022], [80.31624603, 13.22348022], [80.31624603, 13.22375202], [80.31652832, 13.22375202], [80.31652832, 13.22402954], [80.3170929, 13.22402954], [80.3170929, 13.22375202], [80.31746674, 13.22375202], [80.31791687, 13.22375202], [80.31791687, 13.22181034], [80.31764221, 13.22181034], [80.31764221, 13.22153187], [80.31735992, 13.22153187], [80.31735992, 13.22125053], [80.3170929, 13.22125053], [80.3170929, 13.22069073], [80.31680298, 13.22069454], [80.31680298, 13.22041702], [80.31652832, 13.22041702], [80.31652832, 13.22013855], [80.31624603, 13.22014141], [80.31624603, 13.21986103], [80.31569672, 13.21986103], [80.31569672, 13.21958065], [80.31513977, 13.21958256], [80.31513977, 13.21930504], [80.31346893, 13.21931171], [80.31346893, 13.21903133], [80.31375122, 13.21903133], [80.31375122, 13.21847057], [80.31388855, 13.21847057], [80.31402588, 13.21847343], [80.31402588, 13.21736145], [80.31375122, 13.21736145], [80.31375122, 13.21625137], [80.31346893, 13.21625137], [80.31346893, 13.21568966], [80.31319427, 13.21569538], [80.31319427, 13.21513939], [80.31291199, 13.2151413], [80.31291199, 13.21457958], [80.31263733, 13.2145834], [80.31263733, 13.21402645], [80.31236267, 13.21403122], [80.31236267, 13.21319008], [80.31208038, 13.21319485], [80.31208038, 13.21236038], [80.31180573, 13.21236038], [80.31180573, 13.21180439], [80.31153107, 13.21181107], [80.31153107, 13.21096992], [80.31124878, 13.21097183], [80.31124878, 13.21013832], [80.31096649, 13.21014118], [80.31096649, 13.20958042], [80.31069183, 13.20958424], [80.31069183, 13.20902824], [80.31153107, 13.20903111], [80.31153107, 13.20931053], [80.31180573, 13.20930576], [80.31180573, 13.20985985], [80.31208038, 13.20985985], [80.31208038, 13.21014118], [80.31236267, 13.21013832], [80.31236267, 13.21069431], [80.31263733, 13.21068954], [80.31263733, 13.21125031], [80.31291199, 13.21125031], [80.31291199, 13.21181107], [80.31318665, 13.21181107], [80.31318665, 13.21264076], [80.31346893, 13.2126379], [80.31346893, 13.21319485], [80.31375122, 13.21319008], [80.31375122, 13.21403122], [80.31402588, 13.21402645], [80.31402588, 13.2145834], [80.31430817, 13.21457958], [80.31430817, 13.2151413], [80.31458282, 13.21513939], [80.31458282, 13.21569538], [80.31485748, 13.21568966], [80.31485748, 13.21625137], [80.31513977, 13.21625137], [80.31513977, 13.21708298], [80.3154068, 13.21708012], [80.3154068, 13.21791935], [80.31569672, 13.21791744], [80.31569672, 13.21847343], [80.315979, 13.21847057], [80.315979, 13.21875095], [80.31613159, 13.21875095], [80.31624603, 13.21875095], [80.31624603, 13.21903133], [80.31652832, 13.21903133], [80.31652832, 13.21931171], [80.31680298, 13.21930504], [80.31680298, 13.21958256], [80.31708527, 13.21958256], [80.31708527, 13.21986103], [80.31735992, 13.21986103], [80.31735992, 13.22041702], [80.31764221, 13.22041702], [80.31764221, 13.22097111], [80.31791687, 13.22097111], [80.31791687, 13.22125053], [80.31874847, 13.22125053], [80.31874847, 13.22181034], [80.31903839, 13.22181034], [80.31903839, 13.22292042], [80.31931305, 13.22292042], [80.31931305, 13.22402954], [80.31958008, 13.22402954], [80.31958008, 13.22513962], [80.31986237, 13.22513962], [80.31986237, 13.22569561], [80.32013702, 13.22569561], [80.32013702, 13.22597122], [80.32041931, 13.22597122], [80.32041931, 13.22654057], [80.32096863, 13.22654057], [80.32096863, 13.22681046], [80.32125092, 13.22681046], [80.32125092, 13.22736168], [80.3215332, 13.22736168], [80.3215332, 13.22764015], [80.32180786, 13.22764015], [80.32180786, 13.22791958], [80.32208252, 13.22791767], [80.32208252, 13.22819424], [80.32263947, 13.22819424], [80.32263947, 13.22847176], [80.32319641, 13.22846889], [80.32319641, 13.22902966], [80.32430267, 13.22902966], [80.32430267, 13.22931004], [80.32458496, 13.22930622], [80.32458496, 13.22958374], [80.32514191, 13.22958374], [80.32514191, 13.22986221], [80.32569122, 13.22986031], [80.32569122, 13.23013973], [80.32736206, 13.23013973], [80.32736206, 13.23042011], [80.32763672, 13.2304163], [80.32763672, 13.23069382], [80.32791901, 13.23069382], [80.32791901, 13.23097229], [80.32818604, 13.23097038], [80.32818604, 13.23153019], [80.32875061, 13.23153019], [80.32875061, 13.23181057], [80.32902527, 13.2318058], [80.32902527, 13.23208427], [80.32958221, 13.23208427], [80.32958221, 13.23235989], [80.32985687, 13.2323513], [80.32985687, 13.23264027], [80.33040619, 13.23264027], [80.33040619, 13.23291969], [80.33069611, 13.23291588], [80.33069611, 13.23319435], [80.33097076, 13.23319435], [80.33097076, 13.23347187], [80.33125305, 13.23347187], [80.33125305, 13.23375034], [80.33097839, 13.23375034], [80.33097839, 13.23513985], [80.33180237, 13.23513985], [80.33180237, 13.23542118], [80.33347321, 13.23542118], [80.33347321, 13.23513985], [80.33374786, 13.23513985], [80.33374786, 13.23486042], [80.33347321, 13.23486233], [80.33347321, 13.23430634], [80.33319092, 13.2343111], [80.33319092, 13.23402977], [80.3326416, 13.23402977], [80.3326416, 13.23375034], [80.33207703, 13.23375034], [80.33207703, 13.23347187], [80.33152771, 13.23347187], [80.33152771, 13.2318058], [80.33125305, 13.23181057], [80.33125305, 13.23124981], [80.33097839, 13.23124981], [80.33097839, 13.23042011], [80.33069611, 13.23042011], [80.33069611, 13.22958183], [80.33041382, 13.22958374], [80.33041382, 13.22930622], [80.33013916, 13.22931004], [80.33013916, 13.22875023], [80.32985687, 13.22875023], [80.32985687, 13.22846889], [80.32958221, 13.22847176], [80.32958221, 13.22819424], [80.32930756, 13.22819424], [80.32930756, 13.22764015], [80.32958221, 13.22764015], [80.32958221, 13.22654057], [80.32985687, 13.22654057], [80.32985687, 13.2262516], [80.32958221, 13.2262516], [80.32958221, 13.22542], [80.32930756, 13.22542], [80.32930756, 13.22513962], [80.32875061, 13.22513962], [80.32875061, 13.22458076], [80.32847595, 13.22458267], [80.32847595, 13.22402668], [80.32818604, 13.22402954], [80.32818604, 13.22236061], [80.32847595, 13.22236061], [80.32847595, 13.22125053], [80.32791901, 13.22125053], [80.32791901, 13.22069073], [80.32763672, 13.22069454], [80.32763672, 13.21986103], [80.32736206, 13.21986103], [80.32736206, 13.21819019], [80.32707977, 13.21819496], [80.32707977, 13.21791744], [80.32681274, 13.21791935], [80.32681274, 13.21625137], [80.32653046, 13.21625137], [80.32653046, 13.21568966], [80.32624817, 13.21569538], [80.32624817, 13.2145834], [80.32597351, 13.2145834], [80.32597351, 13.21430683], [80.32569122, 13.21431065], [80.32569122, 13.21403122], [80.32541656, 13.21403122], [80.32541656, 13.21375084], [80.32514191, 13.21375084], [80.32514191, 13.21181107], [80.32485199, 13.21181107], [80.32485199, 13.21154022], [80.32457733, 13.21154022], [80.32457733, 13.21096992], [80.32430267, 13.21097183], [80.32430267, 13.21041584], [80.32402802, 13.21042061], [80.32402802, 13.20985985], [80.32375336, 13.20985985], [80.32375336, 13.20958424], [80.32347107, 13.20958424], [80.32347107, 13.20930576], [80.32263947, 13.20931053], [80.32263947, 13.20847034], [80.32291412, 13.20847225], [80.32291412, 13.20819378], [80.32319641, 13.20819378], [80.32319641, 13.20791626], [80.32347107, 13.20792103], [80.32347107, 13.20763969], [80.32375336, 13.20763969], [80.32375336, 13.20681095], [80.32347107, 13.20681095], [80.32347107, 13.20625019], [80.32290649, 13.20625019], [80.32290649, 13.20596981], [80.32263947, 13.20597172], [80.32263947, 13.20485973], [80.32290649, 13.20485973], [80.32290649, 13.20457935], [80.32263947, 13.20458412], [80.32263947, 13.20430565], [80.32290649, 13.20431042], [80.32290649, 13.20346928], [80.32319641, 13.20347214], [80.32319641, 13.20319366], [80.32347107, 13.20319366], [80.32347107, 13.20291805], [80.32319641, 13.20291996], [80.32319641, 13.20263958], [80.32290649, 13.20263958], [80.32290649, 13.20237064], [80.32263947, 13.20237064], [80.32263947, 13.20208168], [80.32236481, 13.20208359], [80.32236481, 13.2015276], [80.32208252, 13.20153046], [80.32208252, 13.2009716], [80.32180786, 13.2009716], [80.32180786, 13.20069408], [80.32152557, 13.20069408], [80.32152557, 13.20041466], [80.32125092, 13.20042038], [80.32125092, 13.20014191], [80.32096863, 13.20014191], [80.32096863, 13.19958115], [80.32125092, 13.19958401], [80.32125092, 13.19930553], [80.3215332, 13.1993103], [80.3215332, 13.19847107], [80.32125092, 13.19847107], [80.32125092, 13.19736099], [80.32096863, 13.19736099], [80.32096863, 13.19680977], [80.32068634, 13.19680977], [80.32068634, 13.19653034], [80.32041931, 13.19653034], [80.32041931, 13.19597054], [80.32013702, 13.1959734], [80.32013702, 13.19569492], [80.31986237, 13.19569111], [80.31986237, 13.1954174], [80.31958008, 13.19542027], [80.31958008, 13.19486141], [80.31930542, 13.19486141], [80.31930542, 13.19430542], [80.31903839, 13.19431019], [80.31903839, 13.19181156], [80.31874847, 13.19181156], [80.31874847, 13.19124889], [80.31846619, 13.19124889], [80.31846619, 13.19069004], [80.31819153, 13.19069481], [80.31819153, 13.18958282], [80.31791687, 13.18958282], [80.31791687, 13.18930531], [80.31764221, 13.18931198], [80.31764221, 13.18625069], [80.31735992, 13.18625069], [80.31735992, 13.18486023], [80.31708527, 13.18486023], [80.31708527, 13.18375015], [80.31680298, 13.18375015], [80.31680298, 13.18208027], [80.31652832, 13.18208218], [80.31652832, 13.18124962], [80.31625366, 13.18124962], [80.31625366, 13.1809721], [80.31597137, 13.1809721], [80.31597137, 13.18013763], [80.31569672, 13.18013954], [80.31569672, 13.17986012], [80.3154068, 13.17986012], [80.3154068, 13.17957973], [80.31513977, 13.17958355], [80.31513977, 13.17930603], [80.31485748, 13.1793108], [80.31485748, 13.17875004], [80.31458282, 13.17875004], [80.31458282, 13.17792034], [80.31430817, 13.17792034], [80.31430817, 13.17735958], [80.31458282, 13.17736244], [80.31458282, 13.17708397], [80.31430817, 13.17708397], [80.31430817, 13.17652798], [80.31402588, 13.17653179], [80.31402588, 13.17625046], [80.31375122, 13.17625046], [80.31375122, 13.17597198], [80.31346893, 13.17597198], [80.31346893, 13.1740284], [80.31318665, 13.1740303], [80.31318665, 13.17319107], [80.31291962, 13.17319584], [80.31291962, 13.17236233], [80.31263733, 13.17236233], [80.31263733, 13.17124939], [80.31236267, 13.17124939], [80.31236267, 13.17041969], [80.31208038, 13.17041969], [80.31208038, 13.16875076], [80.31181335, 13.16875076], [80.31181335, 13.16764069], [80.31153107, 13.16764069], [80.31153107, 13.16736126], [80.31124878, 13.16736126], [80.31124878, 13.16680527], [80.31096649, 13.16681194], [80.31096649, 13.1659708], [80.31069183, 13.1659708], [80.31069183, 13.16569519], [80.31041718, 13.16569519], [80.31041718, 13.16458321], [80.31014252, 13.16458321], [80.31014252, 13.16319466], [80.3095932, 13.16319942], [80.3095932, 13.16292095], [80.30930328, 13.16292095], [80.30930328, 13.16236115], [80.30874634, 13.16236115], [80.30874634, 13.1609726], [80.30819702, 13.1609726], [80.30819702, 13.15986061], [80.30791473, 13.15986061], [80.30791473, 13.15930653], [80.30764008, 13.15931129], [80.30764008, 13.15847015], [80.30735779, 13.15847301], [80.30735779, 13.15791607], [80.30708313, 13.15792084], [80.30708313, 13.15764141], [80.30735779, 13.15764141], [80.30735779, 13.15736008], [80.30708313, 13.15736008], [80.30708313, 13.15681076], [80.30680847, 13.15681076], [80.30680847, 13.15625], [80.30652618, 13.15625], [80.30652618, 13.15569019], [80.30625153, 13.15569401], [80.30625153, 13.15541553], [80.30596924, 13.15542126], [80.30596924, 13.15513992], [80.30568695, 13.15513992], [80.30568695, 13.15458202], [80.30541992, 13.15458202], [80.30541992, 13.15402794], [80.30513763, 13.15403271], [80.30513763, 13.15375042], [80.30486298, 13.15375042], [80.30486298, 13.15235996], [80.30513763, 13.15235996], [80.30513763, 13.15207958], [80.30486298, 13.15208435], [80.30486298, 13.15180588], [80.30458069, 13.15181065], [80.30458069, 13.15069199], [80.30430603, 13.15069389], [80.30430603, 13.15041637], [80.30374908, 13.15042019], [80.30374908, 13.15013981], [80.3034668, 13.15013981], [80.3034668, 13.14931011], [80.30319214, 13.14931011], [80.30319214, 13.14875031], [80.30291748, 13.14875031], [80.30291748, 13.14764023], [80.30264282, 13.14764023], [80.30264282, 13.14735889], [80.30236053, 13.14736176], [80.30236053, 13.14680576], [80.30208588, 13.14680958], [80.30208588, 13.14625168], [80.30179596, 13.14625168], [80.30179596, 13.1459713], [80.30152893, 13.1459713], [80.30152893, 13.14541531], [80.30124664, 13.14542007], [80.30124664, 13.14513016], [80.30097198, 13.14513969], [80.30097198, 13.14458275], [80.30069733, 13.14458275], [80.30069733, 13.14402676], [80.30042267, 13.14402962], [80.30042267, 13.14347076], [80.30014038, 13.14347363], [80.30014038, 13.14319324], [80.29985809, 13.14319324], [80.29985809, 13.14291668], [80.30014038, 13.14291954], [80.30014038, 13.14264202], [80.29985809, 13.14264202], [80.29985809, 13.14042187], [80.29957581, 13.14042187], [80.29957581, 13.14014053], [80.29930878, 13.14014053], [80.29930878, 13.13932133], [80.29902649, 13.13932133], [80.29902649, 13.13875103], [80.29985809, 13.13875103], [80.29985809, 13.13764095], [80.29957581, 13.13764095], [80.29957581, 13.13653088], [80.29930878, 13.13653088], [80.29930878, 13.13568974], [80.29875183, 13.13569546], [80.29875183, 13.13458347], [80.29930878, 13.13458347], [80.29930878, 13.13430691], [80.29985809, 13.13431072], [80.29985809, 13.13319016], [80.30014038, 13.13319492], [80.30014038, 13.1329174], [80.30042267, 13.13292122], [80.30042267, 13.13264084], [80.30069733, 13.13264084], [80.30069733, 13.13236046], [80.30041504, 13.13236046], [80.30041504, 13.13208199], [80.29763794, 13.13208199], [80.29763794, 13.13097191], [80.29792023, 13.13097191], [80.29792023, 13.13069439], [80.29819489, 13.13069439], [80.29819489, 13.13041592], [80.29846954, 13.13042068], [80.29846954, 13.13013077], [80.29875183, 13.1301384], [80.29875183, 13.12930584], [80.29846954, 13.12931061], [80.29846954, 13.12763977], [80.29818726, 13.12763977], [80.29818726, 13.12736034], [80.29792023, 13.12736225], [80.29792023, 13.12680626], [80.29763794, 13.12681103], [80.29763794, 13.12661934], [80.29763794, 13.12652779], [80.2979126, 13.12652969], [80.2979126, 13.12597179], [80.29818726, 13.12597179], [80.29818726, 13.12568855], [80.29846954, 13.12569427], [80.29846954, 13.12485981], [80.29819489, 13.12485981], [80.29819489, 13.12430573], [80.29763794, 13.12431145], [80.29763794, 13.12403011], [80.2979126, 13.12403011], [80.2979126, 13.12374973], [80.29846954, 13.12374973], [80.29846954, 13.12347031], [80.29875183, 13.12347221], [80.29875183, 13.12319374], [80.29958344, 13.12319374], [80.29958344, 13.12291622], [80.29985809, 13.12292004], [80.29985809, 13.12236023], [80.30014038, 13.12236214], [80.30014038, 13.12152767], [80.30042267, 13.12152958], [80.30042267, 13.12125015], [80.30069733, 13.12125015], [80.30069733, 13.12096024], [80.30097198, 13.12097168], [80.30097198, 13.12069416], [80.30124664, 13.12069416], [80.30124664, 13.1198616], [80.30152893, 13.1198616], [80.30152893, 13.11874866], [80.30179596, 13.11874866], [80.30179596, 13.11763954], [80.30236053, 13.11763954], [80.30236053, 13.11653042], [80.30264282, 13.11653042], [80.30264282, 13.11625195], [80.30236053, 13.11625195], [80.30236053, 13.11515141], [80.30208588, 13.11515141], [80.30208588, 13.11458111], [80.30236053, 13.11458302], [80.30236053, 13.11347103], [80.30263519, 13.11347103], [80.30263519, 13.11319542], [80.30319214, 13.11319542], [80.30319214, 13.11291695], [80.3034668, 13.11292171], [80.3034668, 13.11264133], [80.30374908, 13.11264133], [80.30374908, 13.11209202], [80.304039, 13.11209202], [80.304039, 13.11153126], [80.30458069, 13.11153126], [80.30458069, 13.11125088], [80.30486298, 13.11125088], [80.30486298, 13.11069012], [80.30458069, 13.11069489], [80.30458069, 13.1095829], [80.30486298, 13.1095829], [80.30486298, 13.10791683], [80.30458069, 13.10792065], [80.30458069, 13.10736275], [80.30513763, 13.10736275], [80.30513763, 13.10708046], [80.30486298, 13.10708332], [80.30486298, 13.10680676], [80.30430603, 13.10681057], [80.30430603, 13.10653114], [80.304039, 13.10653114], [80.304039, 13.10542107], [80.30374908, 13.10542107], [80.30374908, 13.10431099], [80.30319214, 13.10430431], [80.30319214, 13.10458469], [80.30263519, 13.10458469], [80.30263519, 13.10486031], [80.30208588, 13.10486031], [80.30208588, 13.10514069], [80.30179596, 13.10514069], [80.30179596, 13.10542107], [80.30208588, 13.10541725], [80.30208588, 13.10597324], [80.30152893, 13.10596085], [80.30152893, 13.10764122], [80.30291748, 13.10764122], [80.30291748, 13.11013889], [80.3034668, 13.11013889], [80.3034668, 13.11041927], [80.30374908, 13.11041927], [80.30374908, 13.11153126], [80.30319214, 13.11153126], [80.30319214, 13.11181164], [80.30263519, 13.11180496], [80.30264282, 13.11236095], [80.30208588, 13.11236095], [80.30208588, 13.11292171], [80.30179596, 13.11292171], [80.30179596, 13.11236095], [80.30152893, 13.11236095], [80.30152893, 13.11181164], [80.30124664, 13.11181164], [80.30124664, 13.11041927], [80.30097198, 13.11041927], [80.30097198, 13.10986137], [80.30069733, 13.10986137], [80.30069733, 13.1095829], [80.30041504, 13.1095829], [80.30041504, 13.10902882], [80.30014038, 13.10902882], [80.30014038, 13.1087513], [80.30042267, 13.1087513], [80.30041504, 13.10791683], [80.30014038, 13.10792065], [80.30014038, 13.10653114], [80.29985809, 13.10653114], [80.29985809, 13.10569], [80.29958344, 13.10569477], [80.29958344, 13.10458469], [80.29930878, 13.10458469], [80.29930878, 13.10375023], [80.29902649, 13.10375023], [80.29902649, 13.10264111], [80.29875183, 13.10264111], [80.29875183, 13.10181141], [80.29846954, 13.10181141], [80.29846954, 13.10042095], [80.29902649, 13.10042095], [80.29902649, 13.10015202], [80.29957581, 13.10015202], [80.29957581, 13.09986019], [80.30041504, 13.0998621], [80.30041504, 13.09958363], [80.30097198, 13.09958363], [80.30097198, 13.09930611], [80.30124664, 13.09931087], [80.30124664, 13.09902954], [80.30152893, 13.09902954], [80.30152893, 13.09875011], [80.30097198, 13.09875011], [80.30097198, 13.09818935], [80.30069733, 13.09819412], [80.30069733, 13.09791565], [80.30014038, 13.09792042], [80.30014038, 13.09735966], [80.29985809, 13.09736156], [80.29985809, 13.09708405], [80.29875183, 13.09708405], [80.29875183, 13.09680557], [80.29846954, 13.09680557], [80.29846954, 13.09708405], [80.29819489, 13.09708405], [80.29819489, 13.09736156], [80.29763794, 13.09736156], [80.29763794, 13.09819412], [80.29708099, 13.09819412], [80.29708099, 13.09624958], [80.29680634, 13.09624958], [80.29680634, 13.09597015], [80.29652405, 13.09597206], [80.29652405, 13.09569359], [80.29624939, 13.09569359], [80.29624939, 13.0951376], [80.2959671, 13.09514046], [80.2959671, 13.09486198], [80.29569244, 13.09486198], [80.29569244, 13.09347153], [80.29652405, 13.09347153], [80.29652405, 13.09319401], [80.29708099, 13.09319401], [80.29708099, 13.09291458], [80.2979126, 13.0929203], [80.2979126, 13.09264183], [80.29818726, 13.09264183], [80.29818726, 13.0923624], [80.29958344, 13.0923624], [80.29958344, 13.09208393], [80.30014038, 13.09208393], [80.30014038, 13.0923624], [80.30069733, 13.0923624], [80.30069733, 13.09264183], [80.30097198, 13.09264183], [80.30097198, 13.0929203], [80.30124664, 13.09291458], [80.30124664, 13.09319401], [80.30152893, 13.09319401], [80.30152893, 13.09347153], [80.30179596, 13.09347153], [80.30179596, 13.09375191], [80.30208588, 13.09375], [80.30208588, 13.09402847], [80.30236053, 13.09402084], [80.30236053, 13.09430981], [80.30264282, 13.09430981], [80.30264282, 13.09514046], [80.30291748, 13.09514046], [80.30291748, 13.09542274], [80.30319214, 13.09541798], [80.30319214, 13.09569359], [80.3034668, 13.09569073], [80.3034668, 13.09681129], [80.30291748, 13.09680557], [80.30291748, 13.09708405], [80.30263519, 13.09708405], [80.30263519, 13.09735966], [80.30291748, 13.09735966], [80.30291748, 13.09902954], [80.30319214, 13.09902763], [80.30319214, 13.09958363], [80.30347443, 13.09958363], [80.30347443, 13.1006937], [80.30374908, 13.1006918], [80.30374908, 13.10124969], [80.304039, 13.10124969], [80.304039, 13.10153103], [80.30458069, 13.10153103], [80.30458069, 13.10181141], [80.30513763, 13.10181141], [80.30513763, 13.10153103], [80.30596924, 13.10153103], [80.30596924, 13.10042095], [80.30568695, 13.10042095], [80.30568695, 13.10015202], [80.30513763, 13.10015202], [80.30513763, 13.09986019], [80.30486298, 13.0998621], [80.30486298, 13.09930611], [80.30458069, 13.09931087], [80.30458069, 13.09818935], [80.30486298, 13.09819412], [80.30486298, 13.09791565], [80.30458069, 13.09792042], [80.30458069, 13.09764004], [80.30430603, 13.09764004], [80.30430603, 13.09707928], [80.30403137, 13.09708405], [80.30403137, 13.09624958], [80.30430603, 13.09624958], [80.30430603, 13.09597015], [80.30458069, 13.09597206], [80.30458069, 13.09569359], [80.30430603, 13.09569359], [80.30430603, 13.09375], [80.304039, 13.09375191], [80.304039, 13.09264183], [80.30374908, 13.09264183], [80.30374908, 13.09208107], [80.30347443, 13.09208393], [80.30347443, 13.09097099], [80.30319214, 13.09097958], [80.30319214, 13.08958054], [80.30291748, 13.0895834], [80.30291748, 13.08930492], [80.30264282, 13.08930969], [80.30264282, 13.08903027], [80.30208588, 13.08903027], [80.30208588, 13.08875084], [80.30179596, 13.08875084], [80.30179596, 13.08847141], [80.30152893, 13.08847332], [80.30152893, 13.08819485], [80.30097198, 13.08819485], [80.30097198, 13.08791733], [80.30069733, 13.08792019], [80.30069733, 13.08708096], [80.30041504, 13.08708286], [80.30041504, 13.08680534], [80.30069733, 13.08681202], [80.30069733, 13.08542156], [80.30042267, 13.08542156], [80.30042267, 13.08485031], [80.30014038, 13.0848608], [80.30014038, 13.08458328], [80.29846954, 13.08458328], [80.29846954, 13.08430481], [80.29818726, 13.08430862], [80.29818726, 13.0840292], [80.29763794, 13.0840292], [80.29763794, 13.08318996], [80.29736328, 13.08319473], [80.29736328, 13.08291721], [80.29708099, 13.08292103], [80.29708099, 13.08236122], [80.29680634, 13.08236122], [80.29680634, 13.08208275], [80.29652405, 13.08208275], [80.29652405, 13.08180523], [80.29624939, 13.0818119], [80.29624939, 13.08125114], [80.2959671, 13.08125114], [80.2959671, 13.0809679], [80.29569244, 13.08097267], [80.29569244, 13.08041668], [80.29541779, 13.08042145], [80.29541779, 13.07986069], [80.2951355, 13.07986069], [80.2951355, 13.0793066], [80.29486847, 13.07931137], [80.29486847, 13.07903957], [80.29458618, 13.07903957], [80.29458618, 13.07847023], [80.29430389, 13.07847309], [80.29430389, 13.07763767], [80.29402924, 13.07764053], [80.29402924, 13.07736015], [80.29374695, 13.07736015], [80.29374695, 13.0765276], [80.29347229, 13.07653141], [80.29347229, 13.07597923], [80.29319763, 13.07597923], [80.29319763, 13.07569027], [80.29291534, 13.07569408], [80.29291534, 13.07541561], [80.29264069, 13.07542133], [80.29264069, 13.07458019], [80.2923584, 13.0745821], [80.2923584, 13.07402802], [80.29207611, 13.07403088], [80.29207611, 13.07374954], [80.29180908, 13.07374954], [80.29180908, 13.07319164], [80.29152679, 13.07319355], [80.29152679, 13.07291603], [80.29125214, 13.07291603], [80.29125214, 13.07152843], [80.29096985, 13.07153034], [80.29096985, 13.07096958], [80.29069519, 13.07097244], [80.29069519, 13.07069397], [80.2904129, 13.0706892], [80.2904129, 13.07013988], [80.29013824, 13.07014179], [80.29013824, 13.06958199], [80.2904129, 13.06958389], [80.2904129, 13.06930637], [80.29013824, 13.06931019], [80.29013824, 13.06847191], [80.28986359, 13.06847191], [80.28986359, 13.06819439], [80.28902435, 13.06819439], [80.28902435, 13.06791782], [80.28819275, 13.06791782], [80.28819275, 13.06819439], [80.28736115, 13.06819439], [80.28736115, 13.06847191], [80.28679657, 13.06847191], [80.2868042, 13.06875038], [80.28630829, 13.06875038], [80.2859726, 13.06875038], [80.2859726, 13.06902981], [80.28569794, 13.06902981], [80.28569794, 13.06875038], [80.28514099, 13.06875038], [80.28514099, 13.06847191], [80.28541565, 13.06847191], [80.28541565, 13.06819439], [80.28569794, 13.06819439], [80.28569794, 13.06791782], [80.28595734, 13.06791782], [80.28624725, 13.06791973], [80.28624725, 13.0676403], [80.28679657, 13.0676403], [80.28679657, 13.06736183], [80.28708649, 13.06736183], [80.28708649, 13.06708145], [80.28736115, 13.06708431], [80.28736115, 13.06624985], [80.2876358, 13.06624985], [80.2876358, 13.06569099], [80.28736115, 13.06569576], [80.28736115, 13.06513977], [80.2876358, 13.06513977], [80.2876358, 13.06374931], [80.28736115, 13.06374931], [80.28736115, 13.06347084], [80.28679657, 13.06347084], [80.28679657, 13.06319141], [80.28541565, 13.06319332], [80.28542328, 13.06347084], [80.2848587, 13.06347084], [80.2848587, 13.06319141], [80.28430176, 13.06319332], [80.28430176, 13.06263924], [80.2840271, 13.06263924], [80.2840271, 13.06153202], [80.28375244, 13.06153202], [80.28375244, 13.06097126], [80.28347015, 13.06097126], [80.28347015, 13.06041718], [80.28375244, 13.06042194], [80.28375244, 13.05847073], [80.28347015, 13.05847263], [80.28347015, 13.05819511], [80.2831955, 13.05819511], [80.2831955, 13.05763912], [80.28291321, 13.05764103], [80.28291321, 13.05736065], [80.28263855, 13.05736065], [80.28263855, 13.05680943], [80.28235626, 13.05680943], [80.28235626, 13.05653095], [80.2820816, 13.05653095], [80.2820816, 13.05486965], [80.28180695, 13.05486965], [80.28180695, 13.05264091], [80.28151703, 13.05264091], [80.28151703, 13.0506897], [80.28125, 13.05069447], [80.28125, 13.04986858], [80.28125, 13.04958534], [80.28097534, 13.04958534], [80.28097534, 13.04874992], [80.28069305, 13.04874992], [80.28069305, 13.04514027], [80.2804184, 13.04514027], [80.2804184, 13.04374981], [80.28069305, 13.04374981], [80.28069305, 13.04293156], [80.2804184, 13.04293156], [80.2804184, 13.04236031], [80.28013611, 13.04236221], [80.28013611, 13.04069424], [80.27986145, 13.04069424], [80.27986145, 13.03986168], [80.28013611, 13.03987122], [80.28013611, 13.03931046], [80.2804184, 13.03931046], [80.2804184, 13.03874969], [80.28069305, 13.03874969], [80.28069305, 13.03846931], [80.2804184, 13.03847122], [80.2804184, 13.03819561], [80.28069305, 13.03819561], [80.28069305, 13.03763962], [80.28098297, 13.03763962], [80.28098297, 13.03735924], [80.28069305, 13.0373621], [80.28069305, 13.03652668], [80.2804184, 13.03652954], [80.2804184, 13.03625202], [80.28013611, 13.03625202], [80.28013611, 13.03542042], [80.27986908, 13.03542042], [80.27986908, 13.03514194], [80.28013611, 13.03514194], [80.28013611, 13.03458118], [80.27986145, 13.03458309], [80.27986145, 13.03041744], [80.27958679, 13.03041935], [80.27958679, 13.02818966], [80.27986145, 13.02819538], [80.27986145, 13.02763939], [80.27958679, 13.0276413], [80.27958679, 13.02681065], [80.27929688, 13.02681065], [80.27929688, 13.02514076], [80.27902985, 13.02514076], [80.27902985, 13.02458], [80.27874756, 13.02458191], [80.27874756, 13.02347183], [80.2784729, 13.02347183], [80.2784729, 13.02319431], [80.27874756, 13.02319431], [80.27874756, 13.02291584], [80.2784729, 13.02292061], [80.2784729, 13.02235985], [80.27874756, 13.02235985], [80.27874756, 13.02180576], [80.2784729, 13.02180576], [80.2784729, 13.01930618], [80.27819824, 13.01931095], [80.27819061, 13.01880455], [80.27819061, 13.01846981], [80.27791595, 13.01847172], [80.27791595, 13.01735973], [80.2776413, 13.01735973], [80.2776413, 13.01624966], [80.27735901, 13.01624966], [80.27735901, 13.01570129], [80.27680969, 13.01570129], [80.27680969, 13.01541996], [80.27625275, 13.01541996], [80.27625275, 13.01513958], [80.2756958, 13.01513958], [80.2756958, 13.01486015], [80.27541351, 13.01486206], [80.27541351, 13.01458359], [80.2748642, 13.01458359], [80.2748642, 13.01430607], [80.27402496, 13.01430607], [80.27402496, 13.01458359], [80.27347565, 13.01458359], [80.27347565, 13.01486206], [80.2729187, 13.01486206], [80.2729187, 13.01458359], [80.27180481, 13.01458359], [80.27180481, 13.01486206], [80.27041626, 13.01486206], [80.27041626, 13.01458359], [80.26985931, 13.01458359], [80.26985931, 13.01430607], [80.26957703, 13.01431274], [80.26957703, 13.01403046], [80.26790619, 13.01403046], [80.26790619, 13.01375198], [80.26772308, 13.01375008], [80.26763916, 13.01375008], [80.26763916, 13.0134716], [80.26708221, 13.0134716], [80.26708221, 13.01319408], [80.26680756, 13.01319408], [80.26680756, 13.01264], [80.26735687, 13.01264191], [80.26735687, 13.01293087], [80.26747894, 13.01291561], [80.27124786, 13.01293087], [80.27124786, 13.01264191], [80.27097321, 13.01264191], [80.27097321, 13.0118103], [80.27124786, 13.0118103], [80.27124786, 13.01124859], [80.27179718, 13.01124859], [80.27179718, 13.01097107], [80.27236176, 13.01097107], [80.27236176, 13.0106926], [80.27263641, 13.0106926], [80.27263641, 13.01097107], [80.27458191, 13.01097107], [80.27458191, 13.01124859], [80.27513885, 13.01124859], [80.27513885, 13.01152992], [80.27540588, 13.01152992], [80.27540588, 13.0118103], [80.2756958, 13.01180553], [80.2756958, 13.01208401], [80.27597046, 13.01208401], [80.27597046, 13.01236153], [80.27625275, 13.01236153], [80.27625275, 13.01264191], [80.2765274, 13.01264191], [80.2765274, 13.01236153], [80.27680206, 13.01236153], [80.27680206, 13.01208401], [80.27708435, 13.01208401], [80.27708435, 13.01097107], [80.27680206, 13.01097107], [80.27680206, 13.01041794], [80.2765274, 13.01042175], [80.2765274, 13.00930977], [80.27625275, 13.00930977], [80.27625275, 13.00847054], [80.27597046, 13.0084734], [80.27597046, 13.00819492], [80.27540588, 13.00819111], [80.27541351, 13.0079174], [80.27485657, 13.00792027], [80.27485657, 13.00764179], [80.27458191, 13.00764179], [80.27458191, 13.00708103], [80.27430725, 13.00708294], [80.27430725, 13.00569534], [80.27458191, 13.00569534], [80.27458191, 13.00513935], [80.27485657, 13.00514126], [80.27485657, 13.00458145], [80.27458191, 13.00458336], [80.27458191, 13.00402737], [80.27430725, 13.00402927], [80.27430725, 13.00376034], [80.27401733, 13.00376034], [80.27401733, 13.00347137], [80.27375031, 13.00347328], [80.27375031, 13.00319481], [80.27347565, 13.00319481], [80.27347565, 13.00263882], [80.27319336, 13.00264072], [80.27319336, 13.0023613], [80.27263641, 13.0023613], [80.27263641, 13.00208282], [80.27236176, 13.00208282], [80.27236176, 13.00180531], [80.2720871, 13.00181198], [80.2720871, 13.00153065], [80.27179718, 13.00153065], [80.27179718, 13.00097275], [80.27153015, 13.00097275], [80.27153015, 13.00042057], [80.27124786, 13.00042057], [80.27124786, 13.00014114], [80.27124786, 12.9998579], [80.27153015, 12.99986076], [80.27153015, 12.99791718], [80.2720871, 12.99792099], [80.2720871, 12.99625015], [80.27179718, 12.99625015], [80.27179718, 12.99514103], [80.27153015, 12.99514103], [80.27153015, 12.99374962], [80.27124786, 12.99374962], [80.27124786, 12.99263954], [80.27097321, 12.99263954], [80.27097321, 12.99125004], [80.27068329, 12.99125004], [80.27068329, 12.99013996], [80.27041626, 12.99013996], [80.27041626, 12.98931122], [80.2701416, 12.98931122], [80.2701416, 12.98876095], [80.26985931, 12.98876095], [80.26985931, 12.98819065], [80.26958466, 12.98819447], [80.26958466, 12.98736191], [80.26930237, 12.98736191], [80.26930237, 12.98569107], [80.26902771, 12.98569584], [80.26902771, 12.98430634], [80.26875305, 12.98431015], [80.26875305, 12.98262978], [80.26847076, 12.98263931], [80.26847076, 12.98124886], [80.26819611, 12.98125076], [80.26819611, 12.97986126], [80.26791382, 12.97986126], [80.26791382, 12.97875118], [80.26763916, 12.97875118], [80.26763916, 12.97736073], [80.26735687, 12.97736073], [80.26735687, 12.97597122], [80.26708221, 12.97597313], [80.26708221, 12.97486115], [80.26680756, 12.97486115], [80.26680756, 12.97375107], [80.2665329, 12.97375107], [80.2665329, 12.97292137], [80.26625061, 12.97292137], [80.26625061, 12.97181129], [80.26597595, 12.97181129], [80.26597595, 12.97097015], [80.26569366, 12.97097301], [80.26569366, 12.9701376], [80.26541901, 12.97014141], [80.26541901, 12.96931076], [80.26513672, 12.96931076], [80.26513672, 12.96819019], [80.26486206, 12.96819401], [80.26486206, 12.96708202], [80.26457977, 12.96708202], [80.26457977, 12.96569443], [80.26430511, 12.96569443], [80.26430511, 12.96458435], [80.26403046, 12.96459103], [80.26403046, 12.96375179], [80.26374817, 12.96375179], [80.26374817, 12.96152115], [80.26347351, 12.96152782], [80.26347351, 12.95986176], [80.26319122, 12.95986176], [80.26319122, 12.95847225], [80.26291656, 12.95847225], [80.26291656, 12.95680523], [80.26264191, 12.95681], [80.26264191, 12.95541954], [80.26235962, 12.95541954], [80.26235962, 12.95446014], [80.26235962, 12.95402718], [80.26207733, 12.95403194], [80.26207733, 12.95236111], [80.26180267, 12.95236111], [80.26180267, 12.95097256], [80.26152802, 12.95097256], [80.26152802, 12.94930458], [80.26125336, 12.94930935], [80.26125336, 12.94736099], [80.26097107, 12.94736099], [80.26097107, 12.94542122], [80.26069641, 12.94542122], [80.26069641, 12.94375134], [80.26040649, 12.94375134], [80.26040649, 12.94181061], [80.26013947, 12.94181061], [80.26013947, 12.93986034], [80.25986481, 12.93986225], [80.25986481, 12.93819427], [80.25958252, 12.93819427], [80.25958252, 12.93680573], [80.25930786, 12.93681145], [80.25930786, 12.93597031], [80.25846863, 12.93597221], [80.25846863, 12.93430614], [80.25874329, 12.93430996], [80.25874329, 12.9323616], [80.25846863, 12.9323616], [80.25846863, 12.93013954], [80.25818634, 12.93013954], [80.25818634, 12.92792034], [80.25791931, 12.92792034], [80.25791931, 12.92569065], [80.25763702, 12.92569542], [80.25763702, 12.92374897], [80.25736237, 12.92375088], [80.25736237, 12.92208099], [80.25708008, 12.9220829], [80.25708008, 12.92041683], [80.25681305, 12.92042065], [80.25681305, 12.91847038], [80.25653076, 12.91847324], [80.25653076, 12.91625118], [80.25624847, 12.91625118], [80.25624847, 12.91374969], [80.25596619, 12.91374969], [80.25596619, 12.91125011], [80.25569916, 12.91125011], [80.25569916, 12.90902996], [80.25541687, 12.90902996], [80.25541687, 12.90680981], [80.25514221, 12.90680981], [80.25514221, 12.90458107], [80.25485992, 12.90458393], [80.25485992, 12.90236092], [80.25458527, 12.90236092], [80.25458527, 12.90013885], [80.25430298, 12.90014172], [80.25430298, 12.89792156], [80.25402832, 12.89792156], [80.25402832, 12.89568996], [80.25375366, 12.89569473], [80.25375366, 12.89291668], [80.25347137, 12.89292145], [80.25347137, 12.88986015], [80.25319672, 12.88986015], [80.25319672, 12.8870821], [80.25291443, 12.8870821], [80.25291443, 12.88486004], [80.25263977, 12.88486004], [80.25263977, 12.88346958], [80.25235748, 12.88347244], [80.25235748, 12.88236237], [80.25208282, 12.88236237], [80.25208282, 12.8815279], [80.25180817, 12.88152981], [80.25180817, 12.88097191], [80.25208282, 12.88097191], [80.25208282, 12.8801403], [80.25235748, 12.8801403], [80.25235748, 12.87874985], [80.25208282, 12.87874985], [80.25208282, 12.87819099], [80.25180817, 12.87819576], [80.25180817, 12.87458324], [80.25152588, 12.87458324], [80.25152588, 12.87319469], [80.25096893, 12.87319469], [80.25096893, 12.87125111], [80.25069427, 12.87125111], [80.25069427, 12.86930466], [80.25096893, 12.86930943], [80.25096893, 12.86903095], [80.25068665, 12.86903095], [80.25068665, 12.86792088], [80.25096893, 12.86792088], [80.25096893, 12.86707973], [80.25069427, 12.8670826], [80.25069427, 12.86625099], [80.25041962, 12.86625099], [80.25041962, 12.86543274], [80.25013733, 12.86543274], [80.25013733, 12.86124992], [80.24986267, 12.86124992], [80.24986267, 12.8601408], [80.24957275, 12.8601408], [80.24957275, 12.85929871], [80.24986267, 12.85930634], [80.24986267, 12.85847187], [80.24958038, 12.85847187], [80.24958038, 12.8568058], [80.24931335, 12.85681057], [80.24931335, 12.85542011], [80.24957275, 12.85542011], [80.24957275, 12.85431004], [80.24931335, 12.85431004], [80.24931335, 12.85153008], [80.24903107, 12.85153008], [80.24903107, 12.84736061], [80.24874878, 12.84736061], [80.24874878, 12.84125137], [80.24846649, 12.84125996], [80.24847412, 12.83901119], [80.24847412, 12.83708477], [80.24819183, 12.83708191], [80.24819183, 12.83319378], [80.24791718, 12.83319378], [80.24791718, 12.83291626], [80.24819183, 12.83292103], [80.24819183, 12.83236027], [80.24791718, 12.83236027], [80.24791718, 12.82680607], [80.24764252, 12.82681274], [80.24764252, 12.82569122], [80.24736023, 12.82569408], [80.24736023, 12.81680489], [80.24764252, 12.81680965], [80.24764252, 12.81096077], [80.24791718, 12.81097317], [80.24791718, 12.80930424], [80.24819183, 12.80931091], [80.24819183, 12.80542088], [80.24791718, 12.80542088], [80.24791718, 12.80515194], [80.24736023, 12.80515194], [80.24736023, 12.80542088], [80.24680328, 12.80542088], [80.24680328, 12.80624962], [80.2454071, 12.80624962], [80.2454071, 12.80597019], [80.24430847, 12.8059721], [80.24430847, 12.80569363], [80.24402618, 12.80569363], [80.24402618, 12.80541611], [80.24208069, 12.80541611], [80.24208069, 12.80569363], [80.24180603, 12.80569363], [80.24180603, 12.8059721], [80.24153137, 12.80597019], [80.24153137, 12.80624962], [80.24124908, 12.80624962], [80.24124908, 12.80708218], [80.24097443, 12.80708218], [80.24097443, 12.80847168], [80.24069214, 12.80847168], [80.24069214, 12.80875111], [80.24097443, 12.80875111], [80.24097443, 12.81236076], [80.24013519, 12.81236076], [80.24014282, 12.81347275], [80.23986053, 12.81347275], [80.23986053, 12.8148613], [80.23958588, 12.8148613], [80.23958588, 12.8154192], [80.23930359, 12.81541729], [80.23930359, 12.81569481], [80.23902893, 12.81569099], [80.23902893, 12.81652927], [80.23874664, 12.81652927], [80.23874664, 12.81736088], [80.23847198, 12.81736088], [80.23847198, 12.81819534], [80.23819733, 12.81819534], [80.23819733, 12.81986141], [80.23792267, 12.81986141], [80.23792267, 12.82292175], [80.23764038, 12.82291794], [80.23764038, 12.82347107], [80.23735809, 12.82347107], [80.23735809, 12.82402992], [80.23707581, 12.82402992], [80.23707581, 12.82514], [80.23680878, 12.82514], [80.23680878, 12.82544136], [80.23680878, 12.82681274], [80.23707581, 12.82681274], [80.23707581, 12.82874966], [80.23735809, 12.82874966], [80.23735809, 12.82985973], [80.23763275, 12.82985973], [80.23763275, 12.83181095], [80.23735809, 12.83180618], [80.23735809, 12.83347225], [80.23707581, 12.83347034], [80.23707581, 12.83403111], [80.23680878, 12.83402824], [80.23680878, 12.83597279], [80.23652649, 12.83596992], [80.23652649, 12.83653069], [80.23625183, 12.83652878], [80.23625183, 12.83708191], [80.23596954, 12.83708], [80.23596954, 12.83764076], [80.23569489, 12.83763885], [80.23569489, 12.83819485], [80.23542023, 12.83819485], [80.23542023, 12.83847332], [80.23513794, 12.83847046], [80.23513794, 12.83903122], [80.23486328, 12.83903122], [80.23486328, 12.83986092], [80.23458099, 12.83986092], [80.23458099, 12.84069538], [80.23430634, 12.84068966], [80.23430634, 12.84152889], [80.23402405, 12.84152699], [80.23402405, 12.84210968], [80.23402405, 12.84347343], [80.23374939, 12.84347057], [80.23374939, 12.84625053], [80.23264313, 12.84625053], [80.23264313, 12.84486103], [80.23291779, 12.84486103], [80.23291779, 12.84319115], [80.23319244, 12.84319496], [80.23319244, 12.84226131], [80.23319244, 12.84180546], [80.2334671, 12.84180927], [80.2334671, 12.83847046], [80.23374939, 12.83847332], [80.23374939, 12.83819485], [80.23402405, 12.83819485], [80.23402405, 12.83763885], [80.23430634, 12.83764076], [80.23430634, 12.83736134], [80.23458099, 12.83736134], [80.23458099, 12.83680439], [80.23486328, 12.83681107], [80.23486328, 12.83568954], [80.23513794, 12.83569431], [80.23513794, 12.83347225], [80.23542023, 12.83347225], [80.23542023, 12.8320837], [80.23569489, 12.8320837], [80.23569489, 12.82680607], [80.23596954, 12.82681274], [80.23596954, 12.82514], [80.23625183, 12.82514], [80.23625183, 12.82402992], [80.23652649, 12.82402992], [80.23652649, 12.82347107], [80.23680878, 12.82347107], [80.23680878, 12.8231926], [80.23652649, 12.8231926], [80.23652649, 12.82264042], [80.23680878, 12.82264042], [80.23680878, 12.81875134], [80.23707581, 12.81875134], [80.23707581, 12.81792164], [80.23735809, 12.81792164], [80.23735809, 12.81763935], [80.23707581, 12.81763935], [80.23707581, 12.81709003], [80.23680878, 12.81709003], [80.23680878, 12.81569099], [80.23708344, 12.81569481], [80.23708344, 12.81458282], [80.23735809, 12.81458282], [80.23735809, 12.81375122], [80.23763275, 12.81375122], [80.23763275, 12.81319046], [80.23791504, 12.81319523], [80.23791504, 12.81263924], [80.23819733, 12.81264114], [80.23819733, 12.8123579], [80.23847198, 12.81236076], [80.23847198, 12.81208324], [80.23874664, 12.81208324], [80.23874664, 12.81152916], [80.23902893, 12.81153107], [80.23902893, 12.81068993], [80.23930359, 12.81069469], [80.23930359, 12.8101387], [80.23902893, 12.81014061], [80.23902893, 12.80986023], [80.23874664, 12.80986023], [80.23874664, 12.80958462], [80.23819733, 12.80958462], [80.23819733, 12.80791569], [80.23792267, 12.80792141], [80.23792267, 12.80624962], [80.23819733, 12.80624962], [80.23819733, 12.80542088], [80.23763275, 12.80542088], [80.23763275, 12.80515194], [80.23735809, 12.80515194], [80.23735809, 12.80486012], [80.23680878, 12.80486012], [80.23680878, 12.80457973], [80.23625183, 12.80458355], [80.23625183, 12.80430603], [80.23596954, 12.8043108], [80.23596954, 12.80375004], [80.23542023, 12.80375004], [80.23542023, 12.80346966], [80.23513794, 12.80347157], [80.23513794, 12.80263805], [80.23486328, 12.80263996], [80.23486328, 12.80209064], [80.23457336, 12.80209064], [80.23457336, 12.80153275], [80.23445892, 12.80153275], [80.23430634, 12.80153275], [80.23430634, 12.80097198], [80.23402405, 12.80097198], [80.23402405, 12.8004179], [80.23374939, 12.80041981], [80.23374939, 12.79986191], [80.2334671, 12.79986191], [80.2334671, 12.79901886], [80.23319244, 12.7990284], [80.23319244, 12.79791641], [80.23291779, 12.79792023], [80.23291779, 12.79681015], [80.23264313, 12.79681015], [80.23264313, 12.79652977], [80.23208618, 12.79652977], [80.23208618, 12.79569054], [80.23374939, 12.7956934], [80.23374939, 12.79541779], [80.2338562, 12.79541779], [80.23401642, 12.79541969], [80.23401642, 12.79486084], [80.23430634, 12.79486084], [80.23430634, 12.79403019], [80.23457336, 12.79403019], [80.23457336, 12.79292202], [80.23486328, 12.79292202], [80.23486328, 12.79208088], [80.23458099, 12.79208279], [80.23458099, 12.79152679], [80.23430634, 12.79153156], [80.23430634, 12.79015064], [80.23401642, 12.79015064], [80.23401642, 12.78903103], [80.23374939, 12.78903103], [80.23374939, 12.78875065], [80.23401642, 12.78875065], [80.23401642, 12.78819275], [80.23430634, 12.78819466], [80.23430634, 12.78791714], [80.23401642, 12.78792191], [80.23401642, 12.78764057], [80.23310089, 12.78764057], [80.23264313, 12.78764057], [80.23264313, 12.78681183], [80.23208618, 12.78681183], [80.23208618, 12.78569031], [80.23180389, 12.78569508], [80.23180389, 12.78486061], [80.23208618, 12.78486061], [80.23208618, 12.78431129], [80.23301697, 12.78430653], [80.23374939, 12.78431129], [80.23374939, 12.78402042], [80.23457336, 12.78402042], [80.23457336, 12.78431129], [80.23513794, 12.78431129], [80.23513794, 12.78402042], [80.23596954, 12.78402901], [80.23596954, 12.78375053], [80.23680878, 12.78375053], [80.23680878, 12.78402901], [80.23792267, 12.78402042], [80.23792267, 12.78875065], [80.23819733, 12.78875065], [80.23819733, 12.78931046], [80.23847198, 12.78930473], [80.23847198, 12.78958321], [80.23874664, 12.78958321], [80.23874664, 12.78930473], [80.23986053, 12.78931046], [80.23986053, 12.78986073], [80.24014282, 12.78986073], [80.24014282, 12.79153156], [80.23986053, 12.79152679], [80.23986053, 12.79319477], [80.23958588, 12.79319096], [80.23958588, 12.79541969], [80.23930359, 12.79541779], [80.23930359, 12.79597092], [80.23902893, 12.79596043], [80.23902893, 12.79652977], [80.23874664, 12.79652786], [80.23874664, 12.80069447], [80.23930359, 12.80069447], [80.23930359, 12.80097198], [80.23958588, 12.80097198], [80.23958588, 12.80125046], [80.23986053, 12.80125046], [80.23986053, 12.80153275], [80.24014282, 12.80153275], [80.24014282, 12.80181122], [80.24041748, 12.80181122], [80.24041748, 12.80209064], [80.24069214, 12.80208397], [80.24069214, 12.80236244], [80.2409668, 12.80235958], [80.2409668, 12.80263996], [80.24375916, 12.80263996], [80.24375916, 12.80125046], [80.24346924, 12.80125046], [80.24346924, 12.80041981], [80.24375916, 12.80041981], [80.24375916, 12.80014038], [80.24485779, 12.80013847], [80.24485779, 12.80097198], [80.24514008, 12.80097198], [80.24514008, 12.80153275], [80.2454071, 12.80153275], [80.2454071, 12.80181122], [80.24569702, 12.80181122], [80.24569702, 12.80209064], [80.24597168, 12.80208397], [80.24597168, 12.80236244], [80.24624634, 12.80235958], [80.24624634, 12.80263996], [80.24819183, 12.80263996], [80.24819183, 12.80235958], [80.24847412, 12.80236244], [80.24847412, 12.80125046], [80.24874878, 12.80125046], [80.24874878, 12.8006916], [80.24903107, 12.80069447], [80.24903107, 12.8004179], [80.24931335, 12.80041981], [80.24931335, 12.79930973], [80.24957275, 12.79930973], [80.24957275, 12.79763985], [80.24931335, 12.79763985], [80.24931335, 12.79596043], [80.24958038, 12.79597092], [80.24958038, 12.79430485], [80.24931335, 12.79430962], [80.24931335, 12.79403019], [80.24957275, 12.79403019], [80.24957275, 12.79347134], [80.24986267, 12.79347134], [80.24986267, 12.79319477], [80.25013733, 12.79319477], [80.25013733, 12.79291725], [80.25041962, 12.79292202], [80.25041962, 12.79236126], [80.25069427, 12.79236126], [80.25069427, 12.79125118], [80.25096893, 12.79125118], [80.25096893, 12.79096889], [80.25152588, 12.7909708], [80.25152588, 12.79069519], [80.25208282, 12.79069519], [80.25208282, 12.79041672], [80.25402832, 12.79041862], [80.25402832, 12.79015064], [80.25430298, 12.79015064], [80.25430298, 12.78903103], [80.2545929, 12.78903103], [80.2545929, 12.78792191], [80.25485992, 12.78792191], [80.25485992, 12.78681183], [80.25514221, 12.78681183], [80.25514221, 12.78486061], [80.25485992, 12.78486061], [80.25485992, 12.78319454], [80.25458527, 12.78319454], [80.25458527, 12.78180695], [80.25430298, 12.78181076], [80.25430298, 12.78042126], [80.25402832, 12.78042126], [80.25402832, 12.7790308], [80.25374603, 12.7790308], [80.25374603, 12.77818966], [80.25347137, 12.77819443], [80.25347137, 12.77708435], [80.25319672, 12.77708435], [80.25319672, 12.77624989], [80.2529068, 12.77625179], [80.2529068, 12.77542019], [80.25263977, 12.77542019], [80.25263977, 12.77485085], [80.25235748, 12.77486229], [80.25235748, 12.77402782], [80.25208282, 12.77402973], [80.25208282, 12.77319145], [80.25180817, 12.77319431], [80.25180817, 12.77264023], [80.25152588, 12.77264023], [80.25152588, 12.77180958], [80.25125122, 12.77180958], [80.25125122, 12.77096939], [80.25096893, 12.77097225], [80.25096893, 12.76986217], [80.25069427, 12.76986217], [80.25069427, 12.76902676], [80.25041962, 12.76904106], [80.25041962, 12.76708126], [80.25013733, 12.76708317], [80.25013733, 12.7662487], [80.24986267, 12.76625156], [80.24986267, 12.7656908], [80.24958038, 12.76569462], [80.24958038, 12.76486111], [80.24930573, 12.76486111], [80.24930573, 12.76402664], [80.24903107, 12.76402855], [80.24903107, 12.76319122], [80.24874878, 12.76319504], [80.24874878, 12.76236057], [80.24847412, 12.76236057], [80.24847412, 12.76152897], [80.24819183, 12.76153088], [80.24819183, 12.76068974], [80.24791718, 12.76069546], [80.24791718, 12.75986099], [80.24764252, 12.75986099], [80.24764252, 12.75902653], [80.24736023, 12.7590313], [80.24736023, 12.7582016], [80.2470932, 12.75819016], [80.24708557, 12.75736141], [80.24680328, 12.75736141], [80.24680328, 12.75652885], [80.24652863, 12.75653076], [80.24652863, 12.75568962], [80.24597168, 12.75569534], [80.24597168, 12.7551384], [80.24624634, 12.75514126], [80.24624634, 12.75485992], [80.24597168, 12.75485992], [80.24597168, 12.75403976], [80.24569702, 12.75403976], [80.24569702, 12.75319195], [80.24541473, 12.75319386], [80.24541473, 12.75236034], [80.24514008, 12.75236034], [80.24514008, 12.75152779], [80.24485779, 12.75153065], [80.24485779, 12.75069046], [80.24458313, 12.75069427], [80.24458313, 12.74985981], [80.24430847, 12.74986172], [80.24430847, 12.74903011], [80.24402618, 12.74903011], [80.24402618, 12.74847031], [80.24375153, 12.74847221], [80.24375153, 12.74763775], [80.24346924, 12.74763966], [80.24346924, 12.74680996], [80.24318695, 12.74680996], [80.24318695, 12.74597168], [80.24291992, 12.74597168], [80.24291992, 12.74514008], [80.24263763, 12.74514198], [80.24263763, 12.74457932], [80.24236298, 12.74458408], [80.24236298, 12.74402809], [80.24208069, 12.74403], [80.24208069, 12.74374962], [80.24180603, 12.74374962], [80.24180603, 12.74208069], [80.24153137, 12.74208355], [80.24153137, 12.7415266], [80.24124908, 12.74153042], [80.24124908, 12.74069118], [80.24097443, 12.74069309], [80.24097443, 12.74013901], [80.24069977, 12.74014187], [80.24069977, 12.73986053], [80.24041748, 12.73986053], [80.24041748, 12.73847103], [80.24013519, 12.73847103], [80.24013519, 12.73763943], [80.23986053, 12.73764229], [80.23986053, 12.73680973], [80.23958588, 12.73680973], [80.23958588, 12.73597145], [80.23930359, 12.73597336], [80.23930359, 12.73541737], [80.23902893, 12.73541927], [80.23902893, 12.73458099], [80.23874664, 12.7345829], [80.23874664, 12.73402691], [80.23847198, 12.73403072], [80.23847198, 12.73318958], [80.23819733, 12.7331953], [80.23819733, 12.73236084], [80.23792267, 12.73236084], [80.23792267, 12.73153114], [80.23763275, 12.73153114], [80.23763275, 12.73097038], [80.23735809, 12.73097324], [80.23735809, 12.73013878], [80.23707581, 12.73014069], [80.23707581, 12.72903061], [80.23680878, 12.72903061], [80.23680878, 12.72819042], [80.23652649, 12.72819519], [80.23652649, 12.72763824], [80.23625183, 12.72764111], [80.23625183, 12.72681141], [80.23596954, 12.72681141], [80.23596954, 12.72597027], [80.23569489, 12.72597218], [80.23569489, 12.72513771], [80.23542023, 12.72513962], [80.23542023, 12.72458172], [80.23513794, 12.72458363], [80.23513794, 12.72375011], [80.23486328, 12.72375011], [80.23486328, 12.72291565], [80.23457336, 12.72292137], [80.23457336, 12.72235966], [80.23430634, 12.72236156], [80.23430634, 12.72152805], [80.23401642, 12.72152996], [80.23401642, 12.72068024], [80.23374939, 12.72069359], [80.23374939, 12.7201376], [80.2334671, 12.72014046], [80.2334671, 12.71930981], [80.23319244, 12.71930981], [80.23319244, 12.71875191], [80.23291779, 12.71875191], [80.23291779, 12.71793175], [80.23264313, 12.71793175], [80.23264313, 12.71708107], [80.23236084, 12.71708393], [80.23236084, 12.71652794], [80.23208618, 12.71652985], [80.23208618, 12.71569061], [80.23180389, 12.71569347], [80.23180389, 12.71486187], [80.23152924, 12.71487141], [80.23152924, 12.71430969], [80.23124695, 12.71430969], [80.23124695, 12.71347141], [80.23097229, 12.71347141], [80.23097229, 12.71263885], [80.23069763, 12.71264172], [80.23069763, 12.71208096], [80.23041534, 12.71208286], [80.23041534, 12.71125126], [80.23014069, 12.71125126], [80.23014069, 12.71041965], [80.2298584, 12.71041965], [80.2298584, 12.70985889], [80.22958374, 12.7098608], [80.22958374, 12.7090292], [80.22930908, 12.7090292], [80.22930908, 12.70819092], [80.22902679, 12.70819473], [80.22902679, 12.70736122], [80.22875214, 12.70736122], [80.22875214, 12.70680523], [80.22846985, 12.7068119], [80.22846985, 12.7059679], [80.22819519, 12.70597267], [80.22819519, 12.70513916], [80.2279129, 12.70514107], [80.2279129, 12.70431137], [80.22763824, 12.70431137], [80.22763824, 12.70347023], [80.22736359, 12.70347309], [80.22736359, 12.70263863], [80.2270813, 12.70264053], [80.2270813, 12.70153141], [80.22680664, 12.70153141], [80.22680664, 12.70014095], [80.22651672, 12.70014095], [80.22651672, 12.69957066], [80.22624969, 12.6995821], [80.22624969, 12.69902802], [80.22598267, 12.69903088], [80.22598267, 12.6979208], [80.22569275, 12.6979208], [80.22569275, 12.69679928], [80.22541809, 12.69680595], [80.22541809, 12.69652843], [80.2251358, 12.69653034], [80.2251358, 12.69570065], [80.22486115, 12.6956892], [80.22486115, 12.69486237], [80.22458649, 12.69486237], [80.22458649, 12.69430637], [80.22429657, 12.69431114], [80.22429657, 12.69347191], [80.22402954, 12.69347191], [80.22402954, 12.6926403], [80.22374725, 12.6926403], [80.22374725, 12.69180965], [80.2234726, 12.69180965], [80.2234726, 12.69069958], [80.22319794, 12.69069958], [80.22319794, 12.69013977], [80.22292328, 12.69013977], [80.22292328, 12.68931007], [80.22263336, 12.68931007], [80.22263336, 12.68847084], [80.2223587, 12.68847084], [80.2223587, 12.68791962], [80.22207642, 12.68791962], [80.22207642, 12.68708134], [80.22180176, 12.68708324], [80.22180176, 12.68624878], [80.2215271, 12.68625164], [80.2215271, 12.68542194], [80.22125244, 12.68542194], [80.22125244, 12.68457031], [80.22097015, 12.68458271], [80.22097015, 12.6837492], [80.2206955, 12.6837492], [80.2206955, 12.68291664], [80.22041321, 12.68291855], [80.22041321, 12.68208122], [80.22013855, 12.68208313], [80.22013855, 12.68124866], [80.21985626, 12.68125057], [80.21985626, 12.6806879], [80.2195816, 12.68069458], [80.2195816, 12.6790266], [80.21901703, 12.67903137], [80.21901703, 12.67819023], [80.21875, 12.678195], [80.21875, 12.67708302], [80.21847534, 12.67708302], [80.21847534, 12.67652893], [80.21819305, 12.67653084], [80.21819305, 12.67597008], [80.2179184, 12.67597294], [80.2179184, 12.67541695], [80.21763611, 12.67542076], [80.21763611, 12.67486], [80.21736145, 12.67486], [80.21736145, 12.67431068], [80.21708679, 12.67431068], [80.21708679, 12.67346954], [80.2168045, 12.6734724], [80.2168045, 12.67263794], [80.21652985, 12.67263794], [80.21652985, 12.67152786], [80.21624756, 12.67153072], [80.21624756, 12.67068958], [80.2159729, 12.67069435], [80.2159729, 12.66985989], [80.21569824, 12.66986179], [80.21569061, 12.66903019], [80.21541595, 12.66903019], [80.21541595, 12.66847038], [80.2151413, 12.66847229], [80.2151413, 12.6679163], [80.21485901, 12.66792011], [80.21485901, 12.66736031], [80.21458435, 12.66736221], [80.21458435, 12.66680622], [80.21430206, 12.66681957], [80.21430206, 12.66596985], [80.2140274, 12.66597176], [80.2140274, 12.66485977], [80.21375275, 12.66485977], [80.21375275, 12.66403008], [80.21346283, 12.66403008], [80.21346283, 12.66292], [80.2131958, 12.66292], [80.2131958, 12.66207886], [80.21291351, 12.66208363], [80.21291351, 12.66124916], [80.21263885, 12.66125202], [80.21263885, 12.66014194], [80.21235657, 12.66014194], [80.21235657, 12.65931034], [80.21208191, 12.65931034], [80.21208191, 12.65819073], [80.21180725, 12.65819454], [80.21180725, 12.65736103], [80.21151733, 12.65736103], [80.21151733, 12.65681171], [80.21125031, 12.65681171], [80.21125031, 12.65597057], [80.21097565, 12.65597343], [80.21097565, 12.65541744], [80.21069336, 12.65541935], [80.21069336, 12.65458965], [80.2104187, 12.65458965], [80.2104187, 12.65402889], [80.21013641, 12.65402889], [80.21013641, 12.65318966], [80.20986176, 12.65319538], [80.20986176, 12.65263939], [80.2095871, 12.6526413], [80.2095871, 12.6518116], [80.20929718, 12.6518116], [80.20929718, 12.65125084], [80.20903015, 12.65125084], [80.20903015, 12.65069008], [80.20874786, 12.65069485], [80.20874786, 12.65041733], [80.20847321, 12.65042114], [80.20847321, 12.64986134], [80.20819092, 12.64986134], [80.20819092, 12.64958477], [80.20791626, 12.64958286], [80.20791626, 12.64819527], [80.2076416, 12.64819527], [80.2076416, 12.64791679], [80.20735931, 12.64792061], [80.20735931, 12.64764118], [80.20707703, 12.64764118], [80.20707703, 12.64735985], [80.20680237, 12.64735985], [80.20680237, 12.64597225], [80.20652771, 12.64597225], [80.20652771, 12.64486027], [80.20625305, 12.64486027], [80.20625305, 12.64402771], [80.20597076, 12.64403057], [80.20597076, 12.64375019], [80.20569611, 12.64375019], [80.20569611, 12.64235973], [80.20540619, 12.64235973], [80.20540619, 12.64181137], [80.20513916, 12.64181137], [80.20513916, 12.64153004], [80.20485687, 12.64153004], [80.20485687, 12.64097023], [80.20458221, 12.64097214], [80.20458221, 12.64013767], [80.20430756, 12.64013958], [80.20430756, 12.63986015], [80.20402527, 12.63986206], [80.20402527, 12.63875008], [80.20375061, 12.63875198], [80.20375061, 12.63818932], [80.20347595, 12.63819408], [80.20347595, 12.63764], [80.20318604, 12.63764], [80.20318604, 12.63707924], [80.20291901, 12.63708401], [80.20291901, 12.63652802], [80.20263672, 12.63652802], [80.20263672, 12.63569355], [80.20236206, 12.63569355], [80.20236206, 12.63486195], [80.20207977, 12.63486195], [80.20207977, 12.63403034], [80.20181274, 12.63403034], [80.20181274, 12.63346004], [80.20153046, 12.63347054], [80.20153046, 12.63263893], [80.20124817, 12.63264179], [80.20124817, 12.63153172], [80.20096588, 12.63153172], [80.20096588, 12.63041973], [80.20069122, 12.63041973], [80.20069122, 12.62958145], [80.20041656, 12.62958336], [80.20041656, 12.62874889], [80.20014191, 12.62874889], [80.20014191, 12.62764072], [80.19985962, 12.62764072], [80.19985962, 12.62653065], [80.19957733, 12.62653065], [80.19957733, 12.6248579], [80.19930267, 12.62486076], [80.19930267, 12.62180424], [80.19902802, 12.62181091], [80.19902802, 12.61819172], [80.19930267, 12.61819363], [80.19930267, 12.61763763], [80.19985962, 12.61763954], [80.19985962, 12.61736012], [80.20014191, 12.61736012], [80.20014191, 12.61625004], [80.19985962, 12.61625004], [80.19985962, 12.61569023], [80.19958496, 12.61569405], [80.19958496, 12.61541557], [80.19930267, 12.6154213], [80.19930267, 12.61513996], [80.19875336, 12.61513996], [80.19875336, 12.61485958], [80.19847107, 12.61486244], [80.19847107, 12.61430645], [80.19819641, 12.61431122], [80.19819641, 12.61375046], [80.19790649, 12.61375046], [80.19790649, 12.6131916], [80.19763947, 12.61319447], [80.19763947, 12.61263847], [80.19735718, 12.61264038], [80.19735718, 12.61208153], [80.19708252, 12.61208439], [80.19708252, 12.61124992], [80.19680786, 12.61124992], [80.19680786, 12.61069107], [80.19652557, 12.61069584], [80.19652557, 12.60986233], [80.19625092, 12.60986233], [80.19625092, 12.60930634], [80.19596863, 12.60931015], [80.19596863, 12.60875034], [80.19568634, 12.60875034], [80.19568634, 12.60819054], [80.19541931, 12.6081934], [80.19541931, 12.60764027], [80.19513702, 12.60764027], [80.19513702, 12.60708141], [80.19486237, 12.60708427], [80.19486237, 12.60652733], [80.19458008, 12.60654068], [80.19458008, 12.60597134], [80.19430542, 12.60597134], [80.19430542, 12.60541534], [80.19403076, 12.60542202], [80.19403076, 12.60431194], [80.19374847, 12.60431194], [80.19374847, 12.6026392], [80.19319153, 12.6026392], [80.19319153, 12.6020813], [80.19291687, 12.60208321], [80.19291687, 12.60180473], [80.19264984, 12.60181046], [80.19264984, 12.60097122], [80.19235992, 12.60097313], [80.19235992, 12.60041714], [80.19208527, 12.60041714], [80.19208527, 12.59958267], [80.19180298, 12.59958267], [80.19180298, 12.59902668], [80.19152832, 12.59903145], [80.19152832, 12.59847069], [80.19125366, 12.5984726], [80.19125366, 12.59819508], [80.19152832, 12.59819508], [80.19152832, 12.59736061], [80.19125366, 12.59736061], [80.19125366, 12.59708309], [80.19097137, 12.59708309], [80.19097137, 12.59652901], [80.19069672, 12.59653091], [80.19069672, 12.59625053], [80.1904068, 12.59625053], [80.1904068, 12.59568977], [80.19013977, 12.59569454], [80.19013977, 12.59486103], [80.18985748, 12.59486103], [80.18985748, 12.5945797], [80.19013977, 12.5945816], [80.19013977, 12.59375095], [80.18985748, 12.59375095], [80.18985748, 12.59346962], [80.18958282, 12.59347343], [80.18958282, 12.59319401], [80.18930817, 12.59319401], [80.18930817, 12.59291553], [80.18902588, 12.59292126], [80.18902588, 12.59181118], [80.18875122, 12.59181118], [80.18875122, 12.59154034], [80.18846893, 12.59154034], [80.18846893, 12.59068966], [80.18819427, 12.59069443], [80.18819427, 12.58902836], [80.18791962, 12.58903027], [80.18791962, 12.58875179], [80.18763733, 12.58875179], [80.18763733, 12.58817959], [80.18736267, 12.58819389], [80.18736267, 12.58791637], [80.18708038, 12.58792114], [80.18708038, 12.58681107], [80.18681335, 12.58681107], [80.18681335, 12.58569241], [80.18653107, 12.58569431], [80.18653107, 12.58430576], [80.18624878, 12.58430958], [80.18624878, 12.58152962], [80.18596649, 12.58152962], [80.18596649, 12.57958126], [80.18569183, 12.57958317], [80.18569183, 12.5793047], [80.18596649, 12.57931042], [80.18596649, 12.57875156], [80.18569183, 12.57875156], [80.18569183, 12.57847118], [80.18541718, 12.57847118], [80.18541718, 12.57763863], [80.18345642, 12.57764244], [80.18345642, 12.57792187], [80.18235779, 12.57792187], [80.18235779, 12.57764244], [80.18180847, 12.57764244], [80.18180847, 12.5773592], [80.18125153, 12.57736111], [80.18125153, 12.57708263], [80.18069458, 12.57708263], [80.18069458, 12.57736111], [80.18013763, 12.5773592], [80.18013763, 12.57764244], [80.17986298, 12.57764244], [80.17986298, 12.57792187], [80.17930603, 12.5779171], [80.17930603, 12.57819462], [80.17874908, 12.57819462], [80.17874908, 12.57847118], [80.17819214, 12.57847118], [80.17819214, 12.57856655], [80.17819214, 12.57875156], [80.17764282, 12.57875156], [80.17764282, 12.57903194], [80.17708588, 12.57903194], [80.17708588, 12.57931042], [80.17680359, 12.5793047], [80.17680359, 12.57958317], [80.17624664, 12.57958126], [80.17624664, 12.57986164], [80.17569733, 12.57986164], [80.17569733, 12.58014202], [80.17542267, 12.58014202], [80.17542267, 12.58041954], [80.17514038, 12.58041763], [80.17514038, 12.58069324], [80.17458344, 12.58069324], [80.17458344, 12.58097363], [80.17402649, 12.58096886], [80.17402649, 12.58125019], [80.17375183, 12.58125019], [80.17375183, 12.58181], [80.17319489, 12.58180618], [80.17319489, 12.5820837], [80.17263794, 12.58208084], [80.17263794, 12.58237076], [80.17208099, 12.58237076], [80.17208099, 12.58263969], [80.17180634, 12.58263969], [80.17180634, 12.58319378], [80.17152405, 12.58319378], [80.17152405, 12.58347225], [80.17124939, 12.58346939], [80.17124939, 12.58403015], [80.1709671, 12.58403015], [80.1709671, 12.58514023], [80.17069244, 12.58514023], [80.17069244, 12.58652973], [80.1709671, 12.58652973], [80.1709671, 12.58681107], [80.17124939, 12.5868063], [80.17124939, 12.58708191], [80.17151642, 12.58708191], [80.17151642, 12.58764172], [80.17180634, 12.58764172], [80.17180634, 12.58792114], [80.17208099, 12.58791637], [80.17208099, 12.58819389], [80.17346954, 12.58819389], [80.17346954, 12.58847237], [80.17375183, 12.58847046], [80.17375183, 12.58875179], [80.17402649, 12.58875179], [80.17402649, 12.58903027], [80.17430878, 12.58902836], [80.17430878, 12.58958435], [80.17457581, 12.58957958], [80.17457581, 12.59014034], [80.17485809, 12.59013844], [80.17485809, 12.59069443], [80.17514038, 12.59069443], [80.17514038, 12.59347343], [80.17541504, 12.59347343], [80.17541504, 12.5945816], [80.17514038, 12.5945797], [80.17514038, 12.59514141], [80.17457581, 12.59514141], [80.17457581, 12.59431076], [80.17430878, 12.59431076], [80.17430878, 12.59346962], [80.17402649, 12.59347343], [80.17402649, 12.59291553], [80.17375183, 12.59292126], [80.17375183, 12.59235954], [80.17346954, 12.59236336], [80.17346954, 12.59180641], [80.17318726, 12.59181118], [80.17318726, 12.59154034], [80.17292023, 12.59154034], [80.17292023, 12.59125042], [80.17263794, 12.59125042], [80.17263794, 12.59097004], [80.17151642, 12.59097004], [80.17151642, 12.59154034], [80.17180634, 12.59154034], [80.17180634, 12.59292126], [80.17208099, 12.59292126], [80.17208099, 12.59403133], [80.17124939, 12.59403133], [80.17124939, 12.59431076], [80.1709671, 12.59431076], [80.1709671, 12.59486103], [80.17124939, 12.59486103], [80.17124939, 12.59514141], [80.17151642, 12.59514141], [80.17151642, 12.59542084], [80.17236328, 12.59542084], [80.17236328, 12.59625053], [80.17208099, 12.59625053], [80.17208099, 12.59653091], [80.17180634, 12.59653091], [80.17180634, 12.59681129], [80.17152405, 12.59680462], [80.17152405, 12.59708309], [80.17180634, 12.59708309], [80.17180634, 12.59736061], [80.17346954, 12.59735203], [80.17346954, 12.59764099], [80.17402649, 12.59764099], [80.17402649, 12.59792137], [80.17430878, 12.5979166], [80.17430878, 12.59819508], [80.17514038, 12.59819508], [80.17514038, 12.5984726], [80.17542267, 12.59847069], [80.17542267, 12.59875107], [80.17569733, 12.59875107], [80.17569733, 12.59903145], [80.17597198, 12.59903145], [80.17597198, 12.59931183], [80.17624664, 12.59930515], [80.17624664, 12.59986115], [80.17597198, 12.59986115], [80.17597198, 12.60014057], [80.17569733, 12.60013866], [80.17569733, 12.60041714], [80.17542267, 12.60041046], [80.17542267, 12.60153198], [80.17569733, 12.60153198], [80.17569733, 12.60236073], [80.17542267, 12.60236073], [80.17542267, 12.6026392], [80.17569733, 12.6026392], [80.17569733, 12.60319519], [80.17597198, 12.60319138], [80.17597198, 12.60348034], [80.17652893, 12.60348034], [80.17652893, 12.6026392], [80.17736053, 12.6026392], [80.17736053, 12.60319519], [80.17763519, 12.60319519], [80.17763519, 12.60374928], [80.17791748, 12.60374928], [80.17791748, 12.60403156], [80.17819214, 12.60402679], [80.17819214, 12.60458279], [80.1784668, 12.60458088], [80.1784668, 12.60514164], [80.17874908, 12.60514164], [80.17874908, 12.60542202], [80.17903137, 12.60541534], [80.17903137, 12.60624886], [80.17930603, 12.60624886], [80.17930603, 12.60680962], [80.17986298, 12.60680485], [80.17986298, 12.60708427], [80.18013763, 12.60708141], [80.18013763, 12.60764027], [80.18041992, 12.60764027], [80.18041992, 12.6081934], [80.18069458, 12.6081934], [80.18069458, 12.60847187], [80.18096924, 12.60847187], [80.18096924, 12.60875034], [80.18125153, 12.60875034], [80.18125153, 12.60902977], [80.18152618, 12.60902786], [80.18152618, 12.60986233], [80.17930603, 12.60986233], [80.17930603, 12.60902786], [80.17903137, 12.60902977], [80.17903137, 12.60819054], [80.17819214, 12.6081934], [80.17819214, 12.60764027], [80.17791748, 12.60764027], [80.17791748, 12.60486126], [80.17763519, 12.60486126], [80.17763519, 12.60430527], [80.17624664, 12.60430527], [80.17624664, 12.60458279], [80.17597198, 12.60458088], [80.17597198, 12.60514164], [80.17569733, 12.60514164], [80.17569733, 12.60542202], [80.17402649, 12.60541534], [80.17402649, 12.60569572], [80.17319489, 12.60569572], [80.17319489, 12.60597134], [80.17263794, 12.60597134], [80.17263794, 12.60624886], [80.17208099, 12.60624886], [80.17208099, 12.60654068], [80.17151642, 12.60654068], [80.17151642, 12.60680962], [80.17041779, 12.60680962], [80.17041779, 12.60654068], [80.16929626, 12.60654068], [80.16929626, 12.60624886], [80.16764069, 12.60624886], [80.16764069, 12.60597134], [80.1673584, 12.60597134], [80.1673584, 12.60569572], [80.16680908, 12.60569572], [80.16680908, 12.60597134], [80.16625214, 12.60597134], [80.16625214, 12.60541534], [80.16596985, 12.60542202], [80.16596985, 12.60514164], [80.16570282, 12.60514164], [80.16570282, 12.60486126], [80.1654129, 12.60486126], [80.1654129, 12.60430527], [80.16513824, 12.60431194], [80.16513824, 12.60374928], [80.16485596, 12.60374928], [80.16485596, 12.60291958], [80.16513824, 12.60291958], [80.16513824, 12.6026392], [80.16570282, 12.6026392], [80.16570282, 12.60236073], [80.16596985, 12.60236073], [80.16596985, 12.6020813], [80.16625214, 12.60208321], [80.16625214, 12.60180473], [80.1673584, 12.60181046], [80.1673584, 12.60153198], [80.16764069, 12.60153198], [80.16764069, 12.60125065], [80.16792297, 12.60125065], [80.16792297, 12.60041046], [80.16764069, 12.60041714], [80.16764069, 12.59986115], [80.16707611, 12.59986115], [80.16707611, 12.60014057], [80.16652679, 12.60013866], [80.16652679, 12.60041714], [80.16625214, 12.60041714], [80.16625214, 12.60069466], [80.16513824, 12.60069466], [80.16513824, 12.60013866], [80.16485596, 12.60014057], [80.16485596, 12.5995779], [80.1645813, 12.59958267], [80.1645813, 12.59875107], [80.16430664, 12.59875107], [80.16430664, 12.59819031], [80.16402435, 12.59819508], [80.16402435, 12.59763908], [80.16374969, 12.59764099], [80.16374969, 12.59735203], [80.16402435, 12.59736061], [80.16402435, 12.59680462], [80.16430664, 12.59681129], [80.16430664, 12.59653091], [80.16401672, 12.59653091], [80.16401672, 12.59568977], [80.16374969, 12.59569454], [80.16374969, 12.59541702], [80.16348267, 12.59542084], [80.16348267, 12.59403133], [80.16401672, 12.59403133], [80.16401672, 12.59375095], [80.16485596, 12.59375095], [80.16485596, 12.59403133], [80.16513824, 12.59403133], [80.16513824, 12.59431076], [80.16569519, 12.59430695], [80.16569519, 12.5945816], [80.16625214, 12.5945797], [80.16625214, 12.59514141], [80.16819763, 12.59514141], [80.16819763, 12.59486103], [80.16847992, 12.59486103], [80.16847229, 12.5945816], [80.1701355, 12.5945816], [80.1701355, 12.59402943], [80.16986084, 12.59403133], [80.16986084, 12.59375095], [80.16958618, 12.59375095], [80.16958618, 12.59346962], [80.16930389, 12.59347343], [80.16930389, 12.59319401], [80.16902924, 12.59319401], [80.16902924, 12.59347343], [80.16874695, 12.59346962], [80.16874695, 12.59375095], [80.16847992, 12.59375095], [80.16847992, 12.59403133], [80.16764069, 12.59403133], [80.16764069, 12.59375095], [80.16652679, 12.59375095], [80.16652679, 12.59346962], [80.16625214, 12.59347343], [80.16625214, 12.59319401], [80.16569519, 12.59319401], [80.16569519, 12.59291553], [80.16542053, 12.59292126], [80.16542053, 12.59264088], [80.16485596, 12.59264088], [80.16485596, 12.59235954], [80.16430664, 12.59236336], [80.16430664, 12.59180641], [80.16401672, 12.59181118], [80.16401672, 12.59125042], [80.16374969, 12.59125042], [80.16374969, 12.58957958], [80.1626358, 12.58958435], [80.1626358, 12.58930588], [80.16234589, 12.58931065], [80.16234589, 12.58903027], [80.16208649, 12.58903027], [80.16208649, 12.58847046], [80.1618042, 12.58847237], [80.1618042, 12.58736229], [80.16152954, 12.58736229], [80.16152954, 12.58625031], [80.16124725, 12.58625031], [80.16124725, 12.58541107], [80.16152954, 12.58541584], [80.16152954, 12.58514023], [80.16179657, 12.58514023], [80.16179657, 12.58485985], [80.16208649, 12.58486176], [80.16208649, 12.58458424], [80.1626358, 12.58458424], [80.1626358, 12.58430576], [80.16348267, 12.58430958], [80.16348267, 12.58403015], [80.16401672, 12.58403015], [80.16401672, 12.58374977], [80.1645813, 12.58374977], [80.1645813, 12.58346939], [80.1654129, 12.58347225], [80.1654129, 12.58319378], [80.16596985, 12.58319378], [80.16596985, 12.58291626], [80.16625214, 12.58292007], [80.16625214, 12.58263969], [80.16652679, 12.58263969], [80.16652679, 12.58237076], [80.16707611, 12.58237076], [80.16707611, 12.58208084], [80.1673584, 12.5820837], [80.1673584, 12.58180618], [80.16764069, 12.58181], [80.16764069, 12.58152962], [80.16819763, 12.58152962], [80.16819763, 12.58125019], [80.16902924, 12.58125019], [80.16902924, 12.58096886], [80.16986084, 12.58097076], [80.16986084, 12.58069324], [80.17041779, 12.58069324], [80.17041779, 12.58041763], [80.17124939, 12.58041954], [80.17124939, 12.58014202], [80.17208099, 12.58014202], [80.17208099, 12.57986164], [80.17318726, 12.57986164], [80.17318726, 12.57958126], [80.17375183, 12.57958317], [80.17375183, 12.5793047], [80.17430878, 12.57931042], [80.17430878, 12.57903194], [80.17457581, 12.57903194], [80.17457581, 12.57875156], [80.17514038, 12.57875156], [80.17514038, 12.57847118], [80.17569733, 12.57847118], [80.17569733, 12.57819462], [80.17652893, 12.57819462], [80.17652893, 12.5779171], [80.17679596, 12.57792187], [80.17679596, 12.57764244], [80.17736053, 12.57764244], [80.17736053, 12.5773592], [80.17772675, 12.57736111], [80.17791748, 12.57736111], [80.17791748, 12.57708263], [80.17819214, 12.57708263], [80.17819214, 12.57680511], [80.17874908, 12.57681179], [80.17874908, 12.57652855], [80.17903137, 12.57652855], [80.17903137, 12.57623959], [80.18013763, 12.57624912], [80.18013763, 12.57597256], [80.18235779, 12.57597256], [80.18235779, 12.57624912], [80.1829071, 12.57623959], [80.1829071, 12.57652855], [80.18402863, 12.57652855], [80.18402863, 12.57623959], [80.18458557, 12.57624912], [80.18458557, 12.57458305], [80.18430328, 12.57458305], [80.18430328, 12.57375145], [80.18402863, 12.57375145], [80.18402863, 12.57317924], [80.18374634, 12.57319546], [80.18374634, 12.57263947], [80.18345642, 12.57264137], [80.18345642, 12.5715313], [80.18319702, 12.5715313], [80.18319702, 12.57125092], [80.1829071, 12.57125092], [80.1829071, 12.57014084], [80.18264008, 12.57014084], [80.18264008, 12.56986141], [80.18235779, 12.56986141], [80.18235779, 12.56930542], [80.18208313, 12.56930923], [80.18208313, 12.56903076], [80.18180847, 12.56903076], [80.18180847, 12.56875134], [80.18152618, 12.56875134], [80.18152618, 12.56818962], [80.18125153, 12.56819534], [80.18125153, 12.56763935], [80.18096924, 12.56764126], [80.18096924, 12.56707954], [80.18069458, 12.56708241], [80.18069458, 12.56569386], [80.18041992, 12.56569386], [80.18041992, 12.56486034], [80.18013763, 12.56486034], [80.18013763, 12.56347179], [80.17986298, 12.56347179], [80.17986298, 12.56236172], [80.17958069, 12.56236172], [80.17958069, 12.56124115], [80.17930603, 12.56124973], [80.17930603, 12.56097221], [80.17903137, 12.56097221], [80.17903137, 12.56041622], [80.17874908, 12.56042004], [80.17874908, 12.56013966], [80.1784668, 12.56013966], [80.1784668, 12.55931091], [80.17819214, 12.55931091], [80.17819214, 12.55792046], [80.17791748, 12.55792046], [80.17791748, 12.55681038], [80.17764282, 12.55681038], [80.17764282, 12.55596924], [80.17736053, 12.5559721], [80.17736053, 12.55541801], [80.17708588, 12.55543137], [80.17708588, 12.55458069], [80.17680359, 12.55458355], [80.17680359, 12.55402756], [80.17652893, 12.55403042], [80.17652893, 12.55347061], [80.17624664, 12.55347061], [80.17624664, 12.55263996], [80.17597198, 12.55264187], [80.17597198, 12.55236053], [80.17569733, 12.55236053], [80.17569733, 12.55097103], [80.17541504, 12.55097103], [80.17541504, 12.55041695], [80.17514038, 12.55042171], [80.17514038, 12.54958057], [80.17485809, 12.54958344], [80.17485809, 12.54874897], [80.17457581, 12.54875088], [80.17457581, 12.54819107], [80.17430878, 12.54819489], [80.17430878, 12.54763889], [80.17402649, 12.54763889], [80.17402649, 12.54708099], [80.17375183, 12.5470829], [80.17375183, 12.5462513], [80.17346954, 12.54626179], [80.17346954, 12.54568958], [80.17319489, 12.5456953], [80.17319489, 12.54513931], [80.17292023, 12.54514122], [80.17292023, 12.54458046], [80.17263794, 12.54458332], [80.17263794, 12.54375076], [80.17236328, 12.54375076], [80.17236328, 12.54291725], [80.17208099, 12.54292107], [80.17208099, 12.54236126], [80.17180634, 12.54236126], [80.17180634, 12.5415287], [80.17151642, 12.54153061], [80.17151642, 12.54069042], [80.17124939, 12.54069519], [80.17124939, 12.53985977], [80.1709671, 12.53985977], [80.1709671, 12.53931141], [80.17069244, 12.53931141], [80.17069244, 12.53847027], [80.17041779, 12.53847218], [80.17041779, 12.53763771], [80.17014313, 12.53764057], [80.17014313, 12.53707123], [80.16986084, 12.53708363], [80.16986084, 12.53625011], [80.16958618, 12.53625011], [80.16958618, 12.53542137], [80.16929626, 12.53542137], [80.16929626, 12.53458023], [80.16902924, 12.53458405], [80.16902924, 12.53374958], [80.16874695, 12.53374958], [80.16874695, 12.53292274], [80.16847992, 12.53292274], [80.16847992, 12.53236198], [80.16819763, 12.53236198], [80.16819763, 12.53153038], [80.16792297, 12.53153038], [80.16792297, 12.53068924], [80.16764069, 12.53069401], [80.16764069, 12.52902794], [80.1673584, 12.52902985], [80.1673584, 12.52875042], [80.16707611, 12.52875042], [80.16707611, 12.52819061], [80.16680908, 12.52819443], [80.16680908, 12.52708435], [80.16652679, 12.52708435], [80.16652679, 12.52541542], [80.16625214, 12.52542019], [80.16625214, 12.52513027], [80.16596985, 12.52513885], [80.16596985, 12.52486134], [80.16569519, 12.52486134], [80.16569519, 12.52291679], [80.16542053, 12.52291965], [80.16542053, 12.52180958], [80.16513824, 12.52180958], [80.16513824, 12.52069092], [80.16486359, 12.52069473], [80.16486359, 12.51930523], [80.1645813, 12.51932144], [80.1645813, 12.5184679], [80.16430664, 12.51847267], [80.16430664, 12.51763916], [80.16401672, 12.51764107], [80.16401672, 12.51653099], [80.16430664, 12.51653099], [80.16430664, 12.51625061], [80.16401672, 12.51625061], [80.16401672, 12.51568985], [80.16374969, 12.51569462], [80.16374969, 12.51458263], [80.16347504, 12.51458263], [80.16347504, 12.51347256], [80.16319275, 12.51347256], [80.16319275, 12.5120821], [80.16291809, 12.5120821], [80.16291809, 12.51041603], [80.1626358, 12.5104208], [80.1626358, 12.50874996], [80.16234589, 12.50874996], [80.16234589, 12.50736046], [80.16208649, 12.50736237], [80.16208649, 12.50597191], [80.1618042, 12.50597191], [80.1618042, 12.50430584], [80.16152954, 12.50430965], [80.16152954, 12.50292015], [80.16124725, 12.50292015], [80.16124725, 12.50152969], [80.1609726, 12.50152969], [80.1609726, 12.49903202], [80.16069794, 12.49903202], [80.16069794, 12.49819088], [80.16041565, 12.49819565], [80.16041565, 12.49652672], [80.16014099, 12.49652863], [80.16014099, 12.49515057], [80.1598587, 12.49515057], [80.1598587, 12.49347115], [80.15958405, 12.49347305], [80.15958405, 12.4920826], [80.1592865, 12.49209023], [80.1592865, 12.49180889], [80.15957642, 12.49180889], [80.15957642, 12.49125099], [80.1592865, 12.49125099], [80.1592865, 12.4904213], [80.1590271, 12.4904213], [80.1590271, 12.48764133], [80.15875244, 12.48764133], [80.15875244, 12.4843111], [80.15847015, 12.4843111], [80.15847015, 12.48153019], [80.15820313, 12.48153019], [80.15820313, 12.47875023], [80.15791321, 12.47875023], [80.15791321, 12.47596931], [80.15763855, 12.47597218], [80.15763855, 12.47347069], [80.15736389, 12.47347069], [80.15736389, 12.47124863], [80.1570816, 12.47125244], [80.1570816, 12.46986103], [80.15680695, 12.46986103], [80.15680695, 12.46902943], [80.15651703, 12.46902943], [80.15651703, 12.46847057], [80.15625, 12.46847343], [80.15625, 12.46763897], [80.15598297, 12.46764088], [80.15598297, 12.46681023], [80.15569305, 12.46681023], [80.15569305, 12.46625137], [80.1554184, 12.46625137], [80.1554184, 12.46568966], [80.15513611, 12.46569538], [80.15513611, 12.46513939], [80.15486145, 12.4651413], [80.15486145, 12.46458054], [80.15458679, 12.4645834], [80.15458679, 12.4640274], [80.15429687, 12.46403122], [80.15429687, 12.46347141], [80.15402985, 12.46347332], [80.15402985, 12.46291733], [80.15374756, 12.46291924], [80.15374756, 12.46254063], [80.15374756, 12.46236134], [80.15345764, 12.46242046], [80.15348053, 12.46181107], [80.15319824, 12.46181107], [80.15319061, 12.46125126], [80.15291595, 12.46125126], [80.15291595, 12.46068954], [80.1526413, 12.46069527], [80.1526413, 12.46013927], [80.15235901, 12.46014118], [80.15235901, 12.45958042], [80.15208435, 12.45958233], [80.15208435, 12.4590292], [80.15180206, 12.45903969], [80.15180206, 12.45847034], [80.1515274, 12.45847225], [80.1515274, 12.45791626], [80.15125275, 12.45792103], [80.15125275, 12.45736027], [80.15097046, 12.45736027], [80.15097046, 12.45680428], [80.1506958, 12.45681095], [80.1506958, 12.45653057], [80.15040588, 12.45653057], [80.15040588, 12.45598125], [80.15013885, 12.45598125], [80.15013885, 12.45569038], [80.1498642, 12.4556942], [80.1498642, 12.45513821], [80.14958191, 12.45514011], [80.14958191, 12.45458031], [80.14930725, 12.45458412], [80.14930725, 12.45430565], [80.14901733, 12.45431137], [80.14901733, 12.45374966], [80.14875031, 12.45374966], [80.14875031, 12.45347023], [80.14847565, 12.45347214], [80.14847565, 12.45291805], [80.14819336, 12.45291805], [80.14819336, 12.45236206], [80.1479187, 12.45236206], [80.1479187, 12.45208359], [80.14763641, 12.45208359], [80.14763641, 12.4515276], [80.1473465, 12.45153046], [80.1473465, 12.45125198], [80.1470871, 12.45125198], [80.1470871, 12.45068932], [80.14680481, 12.45069408], [80.14680481, 12.45014], [80.14653015, 12.45014], [80.14653015, 12.44957924], [80.14624786, 12.44958401], [80.14624786, 12.44930553], [80.14597321, 12.4493103], [80.14597321, 12.44874954], [80.14569092, 12.44874954], [80.14569092, 12.44819069], [80.14541626, 12.44819355], [80.14541626, 12.44791794], [80.1451416, 12.44791985], [80.1451416, 12.44736195], [80.14485931, 12.44736195], [80.14485931, 12.44680977], [80.14457703, 12.44680977], [80.14457703, 12.44625187], [80.14431, 12.44625187], [80.14431, 12.44597054], [80.14402771, 12.44597054], [80.14402771, 12.44541836], [80.14375305, 12.44542027], [80.14375305, 12.44514179], [80.14347076, 12.44514179], [80.14347076, 12.44486141], [80.14319611, 12.44486141], [80.14319611, 12.44430542], [80.14290619, 12.44431019], [80.14290619, 12.44404125], [80.14263916, 12.44404125], [80.14263916, 12.44374943], [80.14235687, 12.44374943], [80.14235687, 12.44319057], [80.14208221, 12.44319534], [80.14208221, 12.44291687], [80.14180756, 12.44291973], [80.14180756, 12.44263935], [80.14154053, 12.44263935], [80.14154053, 12.44208145], [80.14125061, 12.44208336], [80.14125061, 12.44180489], [80.14097595, 12.44180965], [80.14097595, 12.44152927], [80.14068604, 12.44152927], [80.14068604, 12.44097137], [80.14041901, 12.44097328], [80.14041901, 12.44069481], [80.14013672, 12.44069481], [80.14013672, 12.44041729], [80.13986206, 12.4404192], [80.13986206, 12.4398613], [80.13957977, 12.4398613], [80.13957977, 12.43958282], [80.13930511, 12.43958282], [80.13930511, 12.43930531], [80.13903046, 12.43931198], [80.13903046, 12.43875122], [80.13874817, 12.43875122], [80.13874817, 12.43847084], [80.13846588, 12.43847084], [80.13846588, 12.43819046], [80.13819122, 12.43819523], [80.13819122, 12.43763924], [80.13791656, 12.43764114], [80.13791656, 12.43735886], [80.13764191, 12.43736076], [80.13764191, 12.43708324], [80.13735962, 12.43708324], [80.13735962, 12.43652916], [80.13707733, 12.43653107], [80.13707733, 12.43625069], [80.13680267, 12.43625069], [80.13680267, 12.43597126], [80.13652802, 12.43597317], [80.13652802, 12.43541718], [80.13625336, 12.43542099], [80.13625336, 12.43514061], [80.13597107, 12.43514061], [80.13597107, 12.43486977], [80.13569641, 12.43486977], [80.13569641, 12.43431091], [80.13540649, 12.43431091], [80.13540649, 12.43403053], [80.13513947, 12.43403053], [80.13513947, 12.43375111], [80.13485718, 12.43375111], [80.13485718, 12.43319035], [80.13458252, 12.43319511], [80.13458252, 12.43291664], [80.13430786, 12.43292141], [80.13430786, 12.43264103], [80.1340332, 12.43264103], [80.1340332, 12.43208027], [80.13375092, 12.43208218], [80.13375092, 12.43180656], [80.13346863, 12.43181133], [80.13346863, 12.43153095], [80.13318634, 12.43153095], [80.13318634, 12.43097019], [80.13291931, 12.4309721], [80.13291931, 12.43069363], [80.13263702, 12.43069363], [80.13263702, 12.43013763], [80.13237, 12.43014145], [80.13237, 12.42986012], [80.13208008, 12.42986012], [80.13208008, 12.4293108], [80.13181305, 12.4293108], [80.13181305, 12.42903137], [80.13153076, 12.42903137], [80.13153076, 12.42875004], [80.13124847, 12.42875004], [80.13124847, 12.4279213], [80.13096619, 12.4279213], [80.13096619, 12.42735958], [80.13069153, 12.42736244], [80.13069153, 12.42708206], [80.13041687, 12.42708206], [80.13041687, 12.42680645], [80.13014221, 12.42681122], [80.13014221, 12.42625046], [80.12985992, 12.42625046], [80.12985992, 12.42597198], [80.12958527, 12.42597198], [80.12958527, 12.42569447], [80.12930298, 12.42569447], [80.12930298, 12.42541599], [80.12902832, 12.42542267], [80.12902832, 12.42486191], [80.12874603, 12.42486191], [80.12874603, 12.42457867], [80.12847137, 12.42458439], [80.12847137, 12.42374992], [80.12819672, 12.42374992], [80.12819672, 12.42293167], [80.12763977, 12.42293167], [80.12763977, 12.42263985], [80.12735748, 12.42263985], [80.12735748, 12.42236042], [80.12708282, 12.42236233], [80.12708282, 12.42180634], [80.12680817, 12.42181015], [80.12680817, 12.42152977], [80.12652588, 12.42152977], [80.12652588, 12.42097187], [80.12625122, 12.42097187], [80.12625122, 12.42069435], [80.12596893, 12.42069435], [80.12596893, 12.42014027], [80.12568665, 12.42014027], [80.12568665, 12.41987133], [80.12541962, 12.41987133], [80.12541962, 12.41930962], [80.12513733, 12.41930962], [80.12513733, 12.41903019], [80.12486267, 12.41903019], [80.12486267, 12.41847134], [80.12458038, 12.41847134], [80.12458038, 12.41819572], [80.12430573, 12.41819572], [80.12430573, 12.41791534], [80.12403107, 12.41792202], [80.12403107, 12.41736126], [80.12374878, 12.41736126], [80.12374878, 12.41708279], [80.12347412, 12.41708279], [80.12347412, 12.41680527], [80.12317657, 12.41681004], [80.12317657, 12.41624928], [80.12291718, 12.41624928], [80.12291718, 12.41569138], [80.12264252, 12.41569519], [80.12264252, 12.41541672], [80.12236023, 12.41541958], [80.12236023, 12.4151392], [80.1220932, 12.4151392], [80.1220932, 12.4145813], [80.12180328, 12.41458321], [80.12180328, 12.41430473], [80.12152863, 12.41431046], [80.12152863, 12.41292191], [80.12097168, 12.41292191], [80.12097168, 12.41264057], [80.12069702, 12.41264057], [80.12069702, 12.4120779], [80.12041473, 12.41208267], [80.12041473, 12.41125107], [80.11985779, 12.41125107], [80.11985779, 12.41097069], [80.11958313, 12.4109726], [80.11958313, 12.41013908], [80.11930847, 12.41014099], [80.11930847, 12.40986061], [80.11875153, 12.40986061], [80.11875153, 12.40958309], [80.11846924, 12.40958309], [80.11846924, 12.40902901], [80.11818695, 12.40903091], [80.11818695, 12.40875053], [80.11791992, 12.40875053], [80.11791992, 12.40818977], [80.11763763, 12.40819454], [80.11763763, 12.40763855], [80.11737061, 12.40764141], [80.11737061, 12.4070797], [80.11708069, 12.40708256], [80.11708069, 12.40680695], [80.11680603, 12.40681076], [80.11680603, 12.40653133], [80.11653137, 12.40653133], [80.11653137, 12.40596962], [80.11624908, 12.40597343], [80.11624908, 12.40541553], [80.1159668, 12.40542126], [80.1159668, 12.40514088], [80.11569214, 12.40514088], [80.11569214, 12.40487194], [80.11541748, 12.40487194], [80.11541748, 12.40458012], [80.11513519, 12.40458202], [80.11513519, 12.40402794], [80.11486053, 12.4040308], [80.11486053, 12.40375042], [80.11458588, 12.40375042], [80.11458588, 12.40347004], [80.11430359, 12.40347195], [80.11430359, 12.40319443], [80.11402893, 12.40319443], [80.11402893, 12.40291595], [80.11374664, 12.40292072], [80.11374664, 12.40264034], [80.11347198, 12.40264034], [80.11347198, 12.40235996], [80.11319733, 12.40235996], [80.11319733, 12.40207958], [80.11291504, 12.40208435], [80.11291504, 12.40180588], [80.11264038, 12.40180588], [80.11264038, 12.40152836], [80.11235809, 12.40153122], [80.11235809, 12.40125179], [80.11207581, 12.40125179], [80.11207581, 12.40097046], [80.11180878, 12.40097237], [80.11180878, 12.40041637], [80.11152649, 12.40042114], [80.11152649, 12.40014267], [80.11123657, 12.40014267], [80.11123657, 12.39986038], [80.11096954, 12.39986229], [80.11096954, 12.3993063], [80.11068726, 12.39931107], [80.11068726, 12.39902973], [80.11042023, 12.39902973], [80.11042023, 12.39873886], [80.11013794, 12.39875031], [80.11013794, 12.39847183], [80.10986328, 12.39847183], [80.10986328, 12.39791584], [80.10958099, 12.39791965], [80.10958099, 12.39764023], [80.10930634, 12.39764023], [80.10930634, 12.39735985], [80.10902405, 12.39735985], [80.10902405, 12.39708424], [80.10874939, 12.39708424], [80.10874939, 12.39652824], [80.1084671, 12.39653015], [80.1084671, 12.39624977], [80.10820007, 12.39624977], [80.10820007, 12.39596939], [80.10791779, 12.39597225], [80.10791779, 12.39541626], [80.10764313, 12.39542007], [80.10764313, 12.39513969], [80.10736084, 12.39513969], [80.10736084, 12.39486027], [80.10708618, 12.39486217], [80.10708618, 12.3945837], [80.10680389, 12.3945837], [80.10680389, 12.39402771], [80.10652924, 12.39402962], [80.10652924, 12.39375019], [80.10624695, 12.39375019], [80.10624695, 12.39346886], [80.10597229, 12.39347363], [80.10597229, 12.39319324], [80.10569763, 12.39319324], [80.10569763, 12.39291763], [80.1054306, 12.39293098], [80.1054306, 12.39236164], [80.10514069, 12.39236164], [80.10514069, 12.39208126], [80.1048584, 12.39208412], [80.1048584, 12.3918047], [80.10457611, 12.39181042], [80.10457611, 12.39153194], [80.10430908, 12.39153194], [80.10430908, 12.39125156], [80.10402679, 12.39125156], [80.10402679, 12.3906908], [80.10375214, 12.39069557], [80.10375214, 12.3904171], [80.10346985, 12.39042187], [80.10346985, 12.39013863], [80.10320282, 12.39013863], [80.10320282, 12.3898592], [80.1029129, 12.38986111], [80.1029129, 12.38958263], [80.10263824, 12.38958263], [80.10263824, 12.38930511], [80.10235596, 12.38931179], [80.10235596, 12.38875103], [80.1020813, 12.38875103], [80.1020813, 12.38847065], [80.10180664, 12.38847256], [80.10180664, 12.38819313], [80.10152435, 12.38819313], [80.10152435, 12.38791656], [80.10124969, 12.38792038], [80.10124969, 12.38764095], [80.10098267, 12.38764095], [80.10098267, 12.38736057], [80.10069275, 12.38736057], [80.10069275, 12.38680458], [80.10041809, 12.38680458], [80.10041809, 12.38652706], [80.1001358, 12.38653183], [80.1001358, 12.38625145], [80.09986115, 12.38625145], [80.09986115, 12.38597107], [80.09958649, 12.38597107], [80.09958649, 12.38569546], [80.0993042, 12.38569546], [80.0993042, 12.38541698], [80.09902954, 12.38541889], [80.09902954, 12.38514137], [80.09874725, 12.38514137], [80.09874725, 12.38458061], [80.0984726, 12.38458347], [80.0984726, 12.384305], [80.09819794, 12.38431168], [80.09819794, 12.3840313], [80.09792328, 12.3840313], [80.09792328, 12.38376045], [80.09764099, 12.38376045], [80.09764099, 12.38347054], [80.0973587, 12.3834734], [80.0973587, 12.38319492], [80.09707642, 12.38319016], [80.09708405, 12.3829174], [80.09680176, 12.38292122], [80.09680176, 12.38264084], [80.0965271, 12.38264084], [80.0965271, 12.38236141], [80.09625244, 12.38236141], [80.09625244, 12.38208294], [80.09597015, 12.38208294], [80.09597015, 12.38180542], [80.09570313, 12.38180923], [80.09570313, 12.38153076], [80.09541321, 12.38153076], [80.09541321, 12.38125134], [80.09513855, 12.38125134], [80.09513855, 12.38070202], [80.09485626, 12.38070202], [80.09485626, 12.38042068], [80.0945816, 12.38042068], [80.0945816, 12.38014126], [80.09430695, 12.38014126], [80.09430695, 12.37986088], [80.09401703, 12.37986088], [80.09401703, 12.37957954], [80.09375, 12.37958241], [80.09375, 12.37930679], [80.0934906, 12.37931061], [80.0934906, 12.37903118], [80.09320068, 12.37903118], [80.09320068, 12.3787508], [80.0929184, 12.3787508], [80.0929184, 12.37847042], [80.09263611, 12.37847328], [80.09263611, 12.37819386], [80.09236145, 12.37819386], [80.09236145, 12.37791634], [80.09208679, 12.3779211], [80.09208679, 12.37762928], [80.0918045, 12.37763786], [80.0918045, 12.37736034], [80.09152985, 12.37736034], [80.09152985, 12.37708473], [80.09124756, 12.37708473], [80.09124756, 12.37680435], [80.0909729, 12.37681103], [80.0909729, 12.37653065], [80.09069824, 12.37653065], [80.09069061, 12.37597179], [80.09041595, 12.37597179], [80.09041595, 12.37569046], [80.0901413, 12.37569427], [80.0901413, 12.3754158], [80.08985901, 12.37542057], [80.08985901, 12.37514019], [80.08957672, 12.37514019], [80.08957672, 12.37486172], [80.08930206, 12.37486172], [80.08930206, 12.37457085], [80.0890274, 12.3745842], [80.0890274, 12.37402821], [80.08847046, 12.37403011], [80.08847046, 12.37374973], [80.0881958, 12.37374973], [80.0881958, 12.37347031], [80.08763885, 12.37347221], [80.08763885, 12.37337017], [80.08763885, 12.37319374], [80.08747864, 12.37319374], [80.0873642, 12.37319374], [80.0873642, 12.37307072], [80.0873642, 12.37291622], [80.08722687, 12.37291813], [80.08706665, 12.37292099], [80.08708191, 12.37275887], [80.08708191, 12.37236214], [80.08680725, 12.37236214], [80.08680725, 12.37208366], [80.08652496, 12.37208366], [80.08652496, 12.37180614], [80.08625031, 12.37182045], [80.08625031, 12.37152958], [80.08598328, 12.37152958], [80.08598328, 12.37125015], [80.08569336, 12.37125015], [80.08569336, 12.37096977], [80.0854187, 12.37097168], [80.0854187, 12.37069416], [80.08513641, 12.37069416], [80.08513641, 12.37014008], [80.08486176, 12.37014008], [80.08486176, 12.3698597], [80.0845871, 12.3698597], [80.0845871, 12.36957932], [80.08430481, 12.36958408], [80.08430481, 12.36902809], [80.08403015, 12.36903], [80.08403015, 12.36876106], [80.08374786, 12.36876106], [80.08374786, 12.36846924], [80.08347321, 12.3684721], [80.08347321, 12.36819363], [80.08319092, 12.36819363], [80.08319092, 12.36763763], [80.08291626, 12.36763954], [80.08291626, 12.36736202], [80.0826416, 12.36736202], [80.0826416, 12.36708069], [80.08235931, 12.36708355], [80.08235931, 12.36680603], [80.08207703, 12.36680984], [80.08207703, 12.36542034], [80.08180237, 12.36542034], [80.08180237, 12.36486244], [80.08152771, 12.36486244], [80.08152771, 12.36458302], [80.08097076, 12.36458302], [80.08097076, 12.36430454], [80.08069611, 12.36431026], [80.08069611, 12.36403179], [80.08040619, 12.36403179], [80.08040619, 12.36375237], [80.08013916, 12.36375237], [80.08013916, 12.36347103], [80.0798645, 12.36347103], [80.0798645, 12.36319542], [80.07958221, 12.36319542], [80.07958221, 12.36291695], [80.07930756, 12.36291981], [80.07930756, 12.36236095], [80.07902527, 12.36236095], [80.07902527, 12.36180496], [80.07875061, 12.36180973], [80.07875061, 12.36152935], [80.07847595, 12.36152935], [80.07847595, 12.36125088], [80.07818604, 12.36125088], [80.07818604, 12.36097145], [80.07791901, 12.36097336], [80.07791901, 12.36069489], [80.07763672, 12.36069489], [80.07763672, 12.36041737], [80.07736206, 12.36041927], [80.07736206, 12.35986137], [80.07707977, 12.35986137], [80.07707977, 12.3595829], [80.07681274, 12.35958958], [80.07681274, 12.35931015], [80.07653046, 12.35931015], [80.07653046, 12.35903168], [80.07624817, 12.35903168], [80.07624817, 12.3587513], [80.07596588, 12.3587513], [80.07596588, 12.35847092], [80.07569122, 12.35847092], [80.07569122, 12.3581953], [80.07541656, 12.3581953], [80.07541656, 12.35791683], [80.07512665, 12.3579216], [80.07512665, 12.35764122], [80.07488251, 12.35764122], [80.07485962, 12.35736084], [80.07470703, 12.35736084], [80.07457733, 12.35736084], [80.07458496, 12.35719013], [80.07458496, 12.35708332], [80.07430267, 12.35708332], [80.07430267, 12.35680485], [80.07402802, 12.35682106], [80.07402802, 12.35653114], [80.07375336, 12.35653114], [80.07375336, 12.35624886], [80.07347107, 12.35624886], [80.07347107, 12.35597324], [80.07319641, 12.35597324], [80.07319641, 12.35569477], [80.07291412, 12.35569477], [80.07291412, 12.35541725], [80.07263947, 12.35542107], [80.07263947, 12.35514069], [80.07235718, 12.35514069], [80.07235718, 12.35486126], [80.07208252, 12.35486126], [80.07208252, 12.35458279], [80.07180786, 12.35458279], [80.07180786, 12.35430527], [80.0715332, 12.35431099], [80.0715332, 12.35375118], [80.07125092, 12.35375118], [80.07125092, 12.35346127], [80.07096863, 12.35347271], [80.07096863, 12.35319519], [80.07069397, 12.35319519], [80.07069397, 12.35291672], [80.07041931, 12.35292053], [80.07041931, 12.35264111], [80.07013702, 12.35264111], [80.07013702, 12.35208035], [80.06986237, 12.35208225], [80.06986237, 12.35152912], [80.06958008, 12.35153103], [80.06958008, 12.35132122], [80.0694809, 12.35129356], [80.06932068, 12.35125065], [80.06931305, 12.35106087], [80.06930542, 12.3506937], [80.06903076, 12.3506937], [80.06903076, 12.35013771], [80.06874847, 12.35014057], [80.06874847, 12.34986019], [80.06847382, 12.34986019], [80.06847382, 12.3493042], [80.06819153, 12.34931087], [80.06819153, 12.34903145], [80.06791687, 12.34903145], [80.06791687, 12.34846973], [80.06764221, 12.34847164], [80.06764221, 12.34819412], [80.06735992, 12.34819412], [80.06735992, 12.34763813], [80.0670929, 12.34764862], [80.0670929, 12.34735966], [80.06680298, 12.34736156], [80.06680298, 12.34708214], [80.06652832, 12.34708214], [80.06652832, 12.34652805], [80.06624603, 12.34652996], [80.06624603, 12.34624958], [80.06597137, 12.34624958], [80.06597137, 12.34597015], [80.06569672, 12.34597206], [80.06569672, 12.34541607], [80.0654068, 12.34542274], [80.0654068, 12.34514046], [80.06513977, 12.34514046], [80.06513977, 12.34486198], [80.06485748, 12.34486198], [80.06485748, 12.34431267], [80.06458282, 12.34431267], [80.06458282, 12.34403038], [80.06430817, 12.34403038], [80.06430817, 12.34375], [80.06402588, 12.34375], [80.06402588, 12.34318924], [80.06375122, 12.34319401], [80.06375122, 12.34291553], [80.06346893, 12.3429203], [80.06346893, 12.34263992], [80.06318665, 12.34263992], [80.06318665, 12.34235954], [80.06291962, 12.3423624], [80.06291962, 12.34208393], [80.06263733, 12.34208393], [80.06263733, 12.34152794], [80.06236267, 12.34152794], [80.06236267, 12.34125042], [80.06208038, 12.34125042], [80.06208038, 12.34097195], [80.06180573, 12.34097195], [80.06180573, 12.34041786], [80.06153107, 12.34041977], [80.06153107, 12.34014034], [80.06124878, 12.34014034], [80.06124878, 12.33986187], [80.06096649, 12.33986187], [80.06096649, 12.33930969], [80.06069183, 12.33930969], [80.06069183, 12.33903027], [80.06041718, 12.33903027], [80.06041718, 12.33875179], [80.06012726, 12.33875179], [80.06012726, 12.33819103], [80.05986023, 12.3381958], [80.05986023, 12.33791542], [80.0595932, 12.33792019], [80.0595932, 12.33736134], [80.05930328, 12.33736134], [80.05930328, 12.33708286], [80.05902863, 12.33708286], [80.05902863, 12.33624935], [80.05874634, 12.33624935], [80.05874634, 12.33541965], [80.0579071, 12.33541965], [80.0579071, 12.33485889], [80.05764008, 12.3348608], [80.05764008, 12.33458328], [80.05735779, 12.33458328], [80.05735779, 12.33430481], [80.05709076, 12.33430958], [80.05709076, 12.33375072], [80.05680847, 12.33375072], [80.05680847, 12.3334713], [80.05652618, 12.33347321], [80.05652618, 12.33319473], [80.05625153, 12.33319473], [80.05625153, 12.33263874], [80.05596924, 12.33265114], [80.05596924, 12.33236122], [80.05569458, 12.33236122], [80.05569458, 12.33208275], [80.05541992, 12.33208275], [80.05541992, 12.33180523], [80.05513763, 12.3318119], [80.05513763, 12.33153057], [80.05486298, 12.33153057], [80.05486298, 12.33125114], [80.05458069, 12.33125114], [80.05458069, 12.33069038], [80.05430603, 12.33069515], [80.05430603, 12.33041668], [80.05403137, 12.3304224], [80.05403137, 12.33014107], [80.05374908, 12.33014107], [80.05374908, 12.32958126], [80.05319214, 12.32958317], [80.05319214, 12.3293047], [80.05291748, 12.32930946], [80.05291748, 12.32875061], [80.05264282, 12.32875061], [80.05264282, 12.32847118], [80.05236053, 12.32847309], [80.05236053, 12.32819462], [80.05208588, 12.32819462], [80.05208588, 12.32763863], [80.05179596, 12.32764053], [80.05179596, 12.32736111], [80.05152893, 12.32736111], [80.05152893, 12.32708263], [80.05124664, 12.32708263], [80.05124664, 12.32680511], [80.05095673, 12.32681084], [80.05095673, 12.32625103], [80.05069733, 12.32625103], [80.05069733, 12.3259697], [80.04985809, 12.3259697], [80.04985809, 12.32625103], [80.05014038, 12.32625103], [80.05014038, 12.32681084], [80.05041504, 12.32680511], [80.05041504, 12.32736111], [80.05069733, 12.32736111], [80.05069733, 12.32792091], [80.05097198, 12.3279171], [80.05097198, 12.32847309], [80.05124664, 12.32847118], [80.05124664, 12.32903099], [80.05179596, 12.32903099], [80.05179596, 12.32930946], [80.05208588, 12.3293047], [80.05208588, 12.32958317], [80.05264282, 12.32958126], [80.05264282, 12.33014107], [80.05291748, 12.33014107], [80.05291748, 12.33125114], [80.05319214, 12.33125114], [80.05319214, 12.33236122], [80.0534668, 12.33236122], [80.0534668, 12.33292198], [80.05374908, 12.33291721], [80.05374908, 12.33347321], [80.05403137, 12.3334713], [80.05403137, 12.3340292], [80.05430603, 12.3340292], [80.05430603, 12.33458328], [80.05458069, 12.33458138], [80.05458069, 12.33513927], [80.05486298, 12.33513927], [80.05486298, 12.33549023], [80.05486298, 12.33569527], [80.0550766, 12.33569145], [80.05513763, 12.33624935], [80.05541992, 12.33624935], [80.05541992, 12.33652973], [80.05569458, 12.33652687], [80.05569458, 12.33708286], [80.05596924, 12.33708096], [80.05596924, 12.33764172], [80.05625153, 12.33764172], [80.05625153, 12.33792019], [80.05652618, 12.33791542], [80.05652618, 12.33847141], [80.05680847, 12.33845997], [80.05680847, 12.33903027], [80.05708313, 12.33902836], [80.05708313, 12.33986187], [80.05735779, 12.33986187], [80.05735779, 12.34069443], [80.05764008, 12.34069443], [80.05764008, 12.34152794], [80.05791473, 12.34152794], [80.05791473, 12.3423624], [80.05819702, 12.3423624], [80.05819702, 12.34347153], [80.05847168, 12.34346962], [80.05847168, 12.34403038], [80.05874634, 12.34403038], [80.05874634, 12.34431267], [80.05902863, 12.34431267], [80.05902863, 12.34486198], [80.05930328, 12.34486198], [80.05930328, 12.34514046], [80.0595932, 12.34514046], [80.0595932, 12.34542274], [80.05986023, 12.34541607], [80.05986023, 12.34569359], [80.06012726, 12.34569168], [80.06012726, 12.34624958], [80.06041718, 12.34624958], [80.06041718, 12.34652996], [80.06069183, 12.34652996], [80.06069183, 12.34681129], [80.06124878, 12.34680557], [80.06124878, 12.34708214], [80.06180573, 12.34708214], [80.06180573, 12.34735966], [80.06208038, 12.34735966], [80.06208038, 12.34764862], [80.06236267, 12.34763813], [80.06236267, 12.34819412], [80.06263733, 12.34819412], [80.06263733, 12.34847164], [80.06291962, 12.34846973], [80.06291962, 12.34875011], [80.06346893, 12.34875011], [80.06346893, 12.34931087], [80.06375122, 12.3493042], [80.06375122, 12.34986019], [80.06402588, 12.34986019], [80.06402588, 12.35042095], [80.06375122, 12.35042095], [80.06375122, 12.35181141], [80.06402588, 12.35181141], [80.06402588, 12.35235977], [80.06375122, 12.35235977], [80.06375122, 12.35319519], [80.06346893, 12.35319042], [80.06346893, 12.35375118], [80.06318665, 12.35375118], [80.06318665, 12.35403061], [80.06291962, 12.35403061], [80.06291962, 12.35431099], [80.06236267, 12.35430527], [80.06236267, 12.35458279], [80.06153107, 12.35458279], [80.06153107, 12.35486126], [80.06096649, 12.35486126], [80.06096649, 12.35514069], [80.06041718, 12.35514069], [80.06041718, 12.35542107], [80.05958557, 12.35541725], [80.05958557, 12.35569477], [80.05874634, 12.35569477], [80.05874634, 12.35597324], [80.05764008, 12.35597324], [80.05764008, 12.35624886], [80.05680847, 12.35624886], [80.05680847, 12.35736084], [80.05708313, 12.35736084], [80.05708313, 12.3581953], [80.05735779, 12.35819054], [80.05735779, 12.35931015], [80.05764008, 12.35931015], [80.05764008, 12.36013889], [80.05791473, 12.36013889], [80.05791473, 12.36069489], [80.05819702, 12.36069107], [80.05819702, 12.36236095], [80.05791473, 12.36236095], [80.05791473, 12.36569309], [80.05819702, 12.36569118], [80.05819702, 12.36736202], [80.05680847, 12.36736202], [80.05680847, 12.36763954], [80.05596924, 12.36763954], [80.05596924, 12.36736202], [80.05568695, 12.36736202], [80.05568695, 12.36708069], [80.05541992, 12.36708355], [80.05541992, 12.36680603], [80.05513763, 12.36680984], [80.05513763, 12.36653042], [80.05486298, 12.36653042], [80.05486298, 12.36625195], [80.05458069, 12.36625195], [80.05458069, 12.36597061], [80.05430603, 12.36597061], [80.05430603, 12.36569309], [80.05403137, 12.36569309], [80.05403137, 12.36541843], [80.05374908, 12.36542034], [80.05374908, 12.36486244], [80.05347443, 12.36486244], [80.05347443, 12.36458302], [80.05319214, 12.36458302], [80.05319214, 12.36347103], [80.05291748, 12.36347103], [80.05291748, 12.36319542], [80.05180359, 12.36319542], [80.05180359, 12.36291695], [80.05124664, 12.36291981], [80.05124664, 12.36262989], [80.04957581, 12.36262989], [80.04957581, 12.36291981], [80.04930878, 12.36291695], [80.04930878, 12.36319542], [80.04792023, 12.36319542], [80.04792023, 12.36347103], [80.04763794, 12.36347103], [80.04763794, 12.36375237], [80.04708099, 12.36375237], [80.04708099, 12.36403179], [80.04651642, 12.36403179], [80.04651642, 12.36375237], [80.04429626, 12.36375237], [80.04429626, 12.36347103], [80.04402924, 12.36347103], [80.04402924, 12.36319542], [80.04347229, 12.36319542], [80.04347229, 12.36291695], [80.04319763, 12.36291981], [80.04319763, 12.36262989], [80.04291534, 12.36263943], [80.04291534, 12.36236095], [80.04264069, 12.36236095], [80.04264069, 12.36208057], [80.0423584, 12.36208344], [80.0423584, 12.36152744], [80.04264069, 12.36152935], [80.04264069, 12.36097145], [80.04291534, 12.36097336], [80.04291534, 12.36041737], [80.04319763, 12.36041927], [80.04319763, 12.35986137], [80.04347229, 12.35986137], [80.04347229, 12.35930538], [80.04374695, 12.35931015], [80.04374695, 12.35903168], [80.04402924, 12.35903168], [80.04402924, 12.35847092], [80.04430389, 12.35847092], [80.04430389, 12.3581953], [80.04402924, 12.3581953], [80.04402924, 12.35791683], [80.04374695, 12.3579216], [80.04374695, 12.35764122], [80.04319763, 12.35764122], [80.04319763, 12.35736084], [80.04292297, 12.35736084], [80.04292297, 12.35708141], [80.04264069, 12.35708332], [80.04264069, 12.35680485], [80.0423584, 12.35682106], [80.0423584, 12.35653114], [80.04209137, 12.35653114], [80.04209137, 12.35569], [80.0423584, 12.35569477], [80.0423584, 12.35541725], [80.04264069, 12.35542107], [80.04264069, 12.35486126], [80.0423584, 12.35486126], [80.0423584, 12.35458279], [80.04208374, 12.35458279], [80.04208374, 12.35430527], [80.04180908, 12.35431099], [80.04180908, 12.35403061], [80.04070282, 12.35403061], [80.04070282, 12.35375118], [80.0404129, 12.35375118], [80.0404129, 12.35319042], [80.04013824, 12.35319519], [80.04013824, 12.35291672], [80.0395813, 12.35292053], [80.0395813, 12.35264111], [80.03901672, 12.35264111], [80.03901672, 12.35292053], [80.03847504, 12.35291672], [80.03847504, 12.35319519], [80.03819275, 12.35319519], [80.03819275, 12.35347271], [80.0376358, 12.35346127], [80.0376358, 12.35375118], [80.03736115, 12.35375118], [80.03736115, 12.35319042], [80.03708649, 12.35319519], [80.03708649, 12.3526392], [80.03679657, 12.35264111], [80.03679657, 12.35208035], [80.03652954, 12.35208225], [80.03652954, 12.35180664], [80.03595734, 12.35181141], [80.03595734, 12.35153103], [80.03569794, 12.35153103], [80.03569794, 12.35125065], [80.03514099, 12.35125065], [80.03514099, 12.35097027], [80.03375244, 12.35097027], [80.03375244, 12.35125065], [80.03263855, 12.35125065], [80.03263855, 12.35097027], [80.0320816, 12.35097218], [80.0320816, 12.35041618], [80.03180695, 12.35042095], [80.03180695, 12.35014057], [80.03151703, 12.35014057], [80.03151703, 12.34986019], [80.03125, 12.34986019], [80.03125, 12.3493042], [80.03069305, 12.34931087], [80.03069305, 12.34903145], [80.03015137, 12.34903145], [80.03015137, 12.34875011], [80.02986145, 12.34875011], [80.02986145, 12.34792137], [80.02958679, 12.34792137], [80.02958679, 12.34764862], [80.02929688, 12.34764862], [80.02929688, 12.34735966], [80.02902985, 12.34736156], [80.02902985, 12.34708214], [80.0276413, 12.34708214], [80.0276413, 12.34680557], [80.0267868, 12.34681129], [80.0267868, 12.34652996], [80.02485657, 12.34652996], [80.02485657, 12.34514046], [80.02458191, 12.34514046], [80.02458191, 12.34486198], [80.02263641, 12.34486198], [80.02263641, 12.34403038], [80.0229187, 12.34403038], [80.0229187, 12.34375], [80.02319336, 12.34375], [80.02319336, 12.34318924], [80.02347565, 12.34319401], [80.02347565, 12.3423624], [80.02319336, 12.3423624], [80.02319336, 12.34208393], [80.02041626, 12.34208393], [80.02041626, 12.34180641], [80.01930237, 12.34181023], [80.01930237, 12.34152126], [80.01902771, 12.34152794], [80.01902771, 12.34097195], [80.01847076, 12.34097195], [80.01847076, 12.34069443], [80.0173645, 12.34069443], [80.0173645, 12.34041786], [80.01708221, 12.34041977], [80.01708221, 12.33958054], [80.0173645, 12.33958435], [80.0173645, 12.33930588], [80.01763916, 12.33930969], [80.01763916, 12.33903027], [80.02069092, 12.33903027], [80.02069092, 12.33875179], [80.02098083, 12.33875179], [80.02098083, 12.33845997], [80.0201416, 12.33847141], [80.0201416, 12.3381958], [80.01819611, 12.3381958], [80.01819611, 12.33791542], [80.01763916, 12.33792019], [80.01763916, 12.33708096], [80.01791382, 12.33708286], [80.01791382, 12.33680534], [80.01875305, 12.33681011], [80.01875305, 12.33652973], [80.01847076, 12.33652973], [80.01847076, 12.33597088], [80.01819611, 12.33597088], [80.01819611, 12.33569527], [80.01791382, 12.33569527], [80.01791382, 12.33458328], [80.01763916, 12.33458328], [80.01763916, 12.33374882], [80.01735687, 12.33375072], [80.01735687, 12.33319092], [80.01708221, 12.33319473], [80.01708221, 12.33291721], [80.01680756, 12.33292198], [80.01680756, 12.33208084], [80.01708221, 12.33208275], [80.01708221, 12.33180523], [80.01735687, 12.3318119], [80.01735687, 12.33096886], [80.01708221, 12.33097267], [80.01708221, 12.33069515], [80.01597595, 12.33069515], [80.01597595, 12.33041668], [80.01513672, 12.3304224], [80.01513672, 12.33014107], [80.01431274, 12.33014107], [80.01431274, 12.32986069], [80.01403046, 12.32986069], [80.01403046, 12.32958126], [80.01347351, 12.32958317], [80.01347351, 12.3293047], [80.01319122, 12.32930946], [80.01319122, 12.32903099], [80.01291656, 12.32903099], [80.01291656, 12.32875061], [80.01235962, 12.32875061], [80.01235962, 12.32847118], [80.01208496, 12.32847309], [80.01208496, 12.32819462], [80.01041412, 12.32819462], [80.01041412, 12.32708263], [80.01097107, 12.32708263], [80.01097107, 12.32736111], [80.01125336, 12.32736111], [80.01125336, 12.32764053], [80.01207733, 12.32764053], [80.01207733, 12.32736111], [80.01235962, 12.32736111], [80.01235962, 12.32708263], [80.01264191, 12.32708263], [80.01264191, 12.32680511], [80.01291656, 12.32681084], [80.01291656, 12.32625103], [80.01319122, 12.32625103], [80.01319122, 12.3259697], [80.01347351, 12.32597256], [80.01347351, 12.32291603], [80.01374817, 12.3229208], [80.01374817, 12.32264137], [80.01431274, 12.32264137], [80.01431274, 12.3229208], [80.01457977, 12.32291603], [80.01457977, 12.32319355], [80.0148468, 12.32318974], [80.0148468, 12.32403088], [80.01541901, 12.32403088], [80.01541901, 12.32431126], [80.01569366, 12.32430744], [80.01569366, 12.3245821], [80.01597595, 12.3245821], [80.01597595, 12.32485962], [80.01625061, 12.32485962], [80.01625061, 12.32514095], [80.0165329, 12.32514095], [80.0165329, 12.32542133], [80.01708221, 12.32541656], [80.01708221, 12.32569504], [80.01763916, 12.32569504], [80.01763916, 12.32597256], [80.01821136, 12.3259697], [80.01821136, 12.32625103], [80.01930237, 12.32625103], [80.01930237, 12.32652569], [80.01957703, 12.32652187], [80.01957703, 12.32681084], [80.01985931, 12.32680511], [80.01985931, 12.32708263], [80.0201416, 12.32708263], [80.0201416, 12.32736111], [80.02041626, 12.32736111], [80.02041626, 12.32764053], [80.02069092, 12.32764053], [80.02069092, 12.32792091], [80.02097321, 12.3279171], [80.02097321, 12.32847309], [80.02124786, 12.32847118], [80.02124786, 12.32875061], [80.0220871, 12.32875061], [80.0220871, 12.32903099], [80.02263641, 12.32903099], [80.02263641, 12.32930946], [80.0229187, 12.3293047], [80.0229187, 12.32958317], [80.02319336, 12.32958126], [80.02319336, 12.33014107], [80.02348328, 12.33014107], [80.02348328, 12.3304224], [80.02375031, 12.33041668], [80.02375031, 12.33069515], [80.02402496, 12.33069515], [80.02402496, 12.33097076], [80.02430725, 12.33096886], [80.02430725, 12.33125114], [80.02458191, 12.33125114], [80.02458191, 12.33153057], [80.02485657, 12.33153057], [80.02485657, 12.3318119], [80.02513885, 12.33180523], [80.02513885, 12.33208275], [80.02541351, 12.33208275], [80.02541351, 12.33236122], [80.02597046, 12.33236122], [80.02597046, 12.33265114], [80.02625275, 12.33265114], [80.02625275, 12.33292198], [80.0265274, 12.33291721], [80.0265274, 12.33319473], [80.0267868, 12.33319092], [80.0267868, 12.33375072], [80.02707672, 12.33375072], [80.02707672, 12.33430958], [80.02791595, 12.33430481], [80.02791595, 12.33458328], [80.0284729, 12.33458328], [80.0284729, 12.33430481], [80.03013611, 12.33430481], [80.03013611, 12.33458328], [80.03069305, 12.33458328], [80.03069305, 12.3348608], [80.03151703, 12.33485889], [80.03151703, 12.33513927], [80.0320816, 12.33513927], [80.0320816, 12.33541965], [80.03236389, 12.33541679], [80.03236389, 12.33569527], [80.03263855, 12.33569527], [80.03263855, 12.33597088], [80.03291321, 12.33597088], [80.03291321, 12.33624935], [80.0340271, 12.33624935], [80.0340271, 12.33652973], [80.03542328, 12.33652973], [80.03542328, 12.33681011], [80.03569794, 12.33680534], [80.03569794, 12.33708286], [80.03595734, 12.33708096], [80.03595734, 12.33764172], [80.03708649, 12.33764172], [80.03708649, 12.33792019], [80.03791809, 12.33792019], [80.03791809, 12.33764172], [80.03848267, 12.33764172], [80.03848267, 12.33792019], [80.03930664, 12.33792019], [80.03930664, 12.33764172], [80.0395813, 12.33764172], [80.0395813, 12.33736134], [80.04096985, 12.33736134], [80.04096985, 12.33708286], [80.04152679, 12.33708286], [80.04152679, 12.33680534], [80.04180908, 12.33681011], [80.04180908, 12.33652973], [80.04515076, 12.33652973], [80.04515076, 12.33681011], [80.04541779, 12.33680534], [80.04541779, 12.33708286], [80.04569244, 12.33708286], [80.04569244, 12.33736134], [80.0459671, 12.33736134], [80.0459671, 12.33792019], [80.04624939, 12.33791542], [80.04624939, 12.3381958], [80.04652405, 12.3381958], [80.04652405, 12.33847141], [80.04680634, 12.33845997], [80.04680634, 12.33875179], [80.04708099, 12.33875179], [80.04708099, 12.33930969], [80.04736328, 12.33930588], [80.04736328, 12.33958435], [80.04763794, 12.33958054], [80.04763794, 12.33986187], [80.04792023, 12.33986187], [80.04792023, 12.34041977], [80.04819489, 12.34041786], [80.04819489, 12.34069443], [80.04846954, 12.34069443], [80.04846954, 12.34097195], [80.04875183, 12.34097195], [80.04875183, 12.34125042], [80.04902649, 12.34125042], [80.04902649, 12.34181023], [80.04930878, 12.34180641], [80.04930878, 12.3423624], [80.04957581, 12.34235954], [80.04957581, 12.3429203], [80.04985809, 12.34291553], [80.04985809, 12.34319401], [80.05014038, 12.34319401], [80.05014038, 12.34347153], [80.05042267, 12.34346962], [80.05042267, 12.34375], [80.05069733, 12.34375], [80.05069733, 12.34431267], [80.05095673, 12.34431267], [80.05095673, 12.34459114], [80.05124664, 12.34459114], [80.05124664, 12.34514046], [80.05152893, 12.34514046], [80.05152893, 12.34542274], [80.05208588, 12.34541607], [80.05208588, 12.34569359], [80.05236053, 12.34569359], [80.05236053, 12.34597206], [80.05264282, 12.34597015], [80.05264282, 12.34652996], [80.05291748, 12.34652996], [80.05291748, 12.34681129], [80.05319214, 12.34680557], [80.05319214, 12.34708214], [80.0534668, 12.34708023], [80.05347443, 12.34735966], [80.05403137, 12.34735966], [80.05403137, 12.34764862], [80.05430603, 12.34764862], [80.05430603, 12.34792137], [80.05486298, 12.34791565], [80.05486298, 12.34847164], [80.05513763, 12.34846973], [80.05513763, 12.34875011], [80.05541992, 12.34875011], [80.05541992, 12.34903145], [80.05596924, 12.34903145], [80.05596924, 12.34931087], [80.05625153, 12.3493042], [80.05625153, 12.34958363], [80.05680847, 12.34958363], [80.05680847, 12.34986019], [80.05709076, 12.34986019], [80.05709076, 12.35014057], [80.05735779, 12.35014057], [80.05735779, 12.35042095], [80.05764008, 12.35041618], [80.05764008, 12.3506937], [80.05791473, 12.3506937], [80.05791473, 12.35097218], [80.0595932, 12.35097027], [80.0595932, 12.35125065], [80.05986023, 12.35125065], [80.05986023, 12.35153103], [80.06041718, 12.35153103], [80.06041718, 12.35181141], [80.06069183, 12.35180664], [80.06069183, 12.35208225], [80.06096649, 12.35208035], [80.06096649, 12.35235977], [80.06181335, 12.35235977], [80.06180573, 12.35208225], [80.06208038, 12.35208225], [80.06208038, 12.35180664], [80.06236267, 12.35181141], [80.06236267, 12.35153103], [80.06291962, 12.35153103], [80.06291962, 12.35125065], [80.06318665, 12.35125065], [80.06318665, 12.3506918], [80.06291962, 12.3506937], [80.06291962, 12.35013771], [80.06263733, 12.35014057], [80.06263733, 12.34986019], [80.06236267, 12.34986019], [80.06236267, 12.3493042], [80.06208038, 12.34931087], [80.06208038, 12.34875011], [80.06096649, 12.34875011], [80.06096649, 12.34846973], [80.06041718, 12.34847164], [80.06041718, 12.34819412], [80.06014252, 12.34819412], [80.06014252, 12.34791565], [80.05986023, 12.34792137], [80.05986023, 12.34764862], [80.05930328, 12.34764862], [80.05930328, 12.34735966], [80.05874634, 12.34736156], [80.05874634, 12.34708214], [80.05847168, 12.34708214], [80.05847168, 12.34652805], [80.05819702, 12.34652996], [80.05819702, 12.34624958], [80.0579071, 12.34624958], [80.0579071, 12.34569168], [80.05764008, 12.34569359], [80.05764008, 12.3451376], [80.05735779, 12.34514046], [80.05735779, 12.34346962], [80.05708313, 12.34347153], [80.05708313, 12.34319401], [80.05735779, 12.34319401], [80.05735779, 12.34291553], [80.05709076, 12.3429203], [80.05709076, 12.34208202], [80.05680847, 12.34208393], [80.05680847, 12.34125042], [80.05652618, 12.34125042], [80.05652618, 12.34014034], [80.05625153, 12.34014034], [80.05625153, 12.33958054], [80.05596924, 12.33958435], [80.05596924, 12.33930588], [80.05568695, 12.33930969], [80.05568695, 12.33903027], [80.05541992, 12.33903027], [80.05541992, 12.33845997], [80.05513763, 12.33847141], [80.05513763, 12.33736134], [80.05486298, 12.33736134], [80.05486298, 12.33708286], [80.05458069, 12.33708286], [80.05458069, 12.33652687], [80.05430603, 12.33652973], [80.05430603, 12.33569145], [80.05403137, 12.33569527], [80.05403137, 12.33513927], [80.05374908, 12.33513927], [80.05374908, 12.33485889], [80.05347443, 12.3348608], [80.05347443, 12.33430481], [80.05319214, 12.33430958], [80.05319214, 12.3340292], [80.05291748, 12.3340292], [80.05291748, 12.33375072], [80.05264282, 12.33375072], [80.05264282, 12.3334713], [80.05236053, 12.33347321], [80.05236053, 12.33319473], [80.05208588, 12.33319473], [80.05208588, 12.33291721], [80.05179596, 12.33292198], [80.05179596, 12.33236122], [80.05152893, 12.33236122], [80.05152893, 12.33152676], [80.05124664, 12.33153057], [80.05124664, 12.3312006], [80.05124664, 12.33097267], [80.05097198, 12.33097267], [80.05097198, 12.33084965], [80.05097198, 12.33069515], [80.05084991, 12.33069515], [80.05069733, 12.33069515], [80.05069733, 12.33041668], [80.05042267, 12.3304224], [80.05042267, 12.33014107], [80.05014038, 12.33014107], [80.05014038, 12.32978058], [80.05014038, 12.32958317], [80.04998779, 12.32958317], [80.04985809, 12.32958317], [80.04985809, 12.32942104], [80.04985809, 12.3293047], [80.04957581, 12.32930946], [80.04957581, 12.32907009], [80.04958344, 12.3287487], [80.04930878, 12.3287487], [80.04930878, 12.32847309], [80.04902649, 12.32847309], [80.04902649, 12.32835197], [80.04902649, 12.32819462], [80.04889679, 12.32819462], [80.04875183, 12.32819462], [80.0486908, 12.32792091], [80.04846954, 12.32792091], [80.04846954, 12.32764053], [80.04818726, 12.32764053], [80.04819489, 12.327281], [80.04819489, 12.32708263], [80.0480423, 12.32708263], [80.04792023, 12.32708263], [80.04792023, 12.32693005], [80.04792023, 12.32652569], [80.04819489, 12.32652569], [80.04819489, 12.32513809], [80.04736328, 12.32514095], [80.04736328, 12.32485962], [80.04708099, 12.32485962], [80.04708099, 12.32430744], [80.04680634, 12.32431126], [80.04680634, 12.32374954], [80.04651642, 12.32374954], [80.04651642, 12.32346058], [80.04624939, 12.32347202], [80.04624939, 12.32319355], [80.04569244, 12.32319355], [80.04569244, 12.32263756], [80.04541779, 12.32264137], [80.04541779, 12.32236004], [80.0451355, 12.32236004], [80.0451355, 12.32180595], [80.04486084, 12.32181072], [80.04486084, 12.32096958], [80.04458618, 12.32097244], [80.04458618, 12.32069397], [80.04402924, 12.32069016], [80.04402924, 12.32041645], [80.04374695, 12.32042122], [80.04374695, 12.32014275], [80.04347229, 12.32014275], [80.04347229, 12.31958199], [80.04319763, 12.31958199], [80.04319763, 12.31930637], [80.04292297, 12.31931114], [80.04292297, 12.31903267], [80.04264069, 12.31903267], [80.04264069, 12.31847191], [80.0423584, 12.31847191], [80.0423584, 12.31819439], [80.04208374, 12.31819439], [80.04208374, 12.3176403], [80.04180908, 12.3176403], [80.04180908, 12.31707859], [80.04152679, 12.31708431], [80.04152679, 12.31652832], [80.04125214, 12.31653023], [80.04125214, 12.31597042], [80.04096985, 12.31597233], [80.04096985, 12.31541634], [80.04070282, 12.31542015], [80.04070282, 12.31486034], [80.0404129, 12.31486225], [80.0404129, 12.31430626], [80.04013824, 12.31431007], [80.04013824, 12.31347179], [80.0404129, 12.31347179], [80.0404129, 12.31375027], [80.04070282, 12.31375027], [80.04070282, 12.31402969], [80.04096985, 12.31402969], [80.04096985, 12.31431007], [80.04125214, 12.31430626], [80.04125214, 12.31486225], [80.04152679, 12.31486034], [80.04152679, 12.31513977], [80.04180908, 12.31513977], [80.04180908, 12.31542015], [80.04208374, 12.31541634], [80.04208374, 12.31597233], [80.0423584, 12.31597042], [80.0423584, 12.31624985], [80.04264069, 12.31624985], [80.04264069, 12.31681061], [80.04291534, 12.31680584], [80.04291534, 12.31708431], [80.04319763, 12.31707859], [80.04319763, 12.3176403], [80.04347229, 12.3176403], [80.04347229, 12.31819439], [80.04374695, 12.31819439], [80.04374695, 12.31847191], [80.04402924, 12.31847191], [80.04402924, 12.31903267], [80.04429626, 12.31903267], [80.04429626, 12.31931114], [80.04458618, 12.31930637], [80.04458618, 12.31986237], [80.04486084, 12.31986046], [80.04486084, 12.32014275], [80.04515076, 12.32014275], [80.04515076, 12.32042122], [80.04541779, 12.32041645], [80.04541779, 12.32097244], [80.04569244, 12.32096958], [80.04569244, 12.32124996], [80.0459671, 12.32124996], [80.0459671, 12.3215313], [80.04624939, 12.3215313], [80.04624939, 12.32181072], [80.04651642, 12.32181072], [80.04651642, 12.32236004], [80.04680634, 12.32236004], [80.04680634, 12.32264137], [80.04708099, 12.32264137], [80.04708099, 12.3229208], [80.04736328, 12.32291603], [80.04736328, 12.32347202], [80.04763794, 12.32346058], [80.04763794, 12.32374954], [80.04792023, 12.32374954], [80.04792023, 12.32403088], [80.04819489, 12.32402897], [80.04819489, 12.3245821], [80.04846954, 12.3245821], [80.04846954, 12.32485962], [80.04875183, 12.32485962], [80.04875183, 12.32542133], [80.04957581, 12.32542133], [80.04957581, 12.32514095], [80.05014038, 12.32514095], [80.05014038, 12.32485962], [80.04985809, 12.32485962], [80.04985809, 12.32430744], [80.04957581, 12.32431126], [80.04957581, 12.32403088], [80.04930878, 12.32403088], [80.04930878, 12.32346058], [80.04902649, 12.32347202], [80.04902649, 12.32319355], [80.04875183, 12.32319355], [80.04875183, 12.32263756], [80.04846954, 12.32264137], [80.04846954, 12.32236004], [80.04818726, 12.32236004], [80.04818726, 12.32181072], [80.04792023, 12.32181072], [80.04792023, 12.3215313], [80.04763794, 12.3215313], [80.04763794, 12.32096958], [80.04736328, 12.32097244], [80.04736328, 12.32069397], [80.04708099, 12.32069016], [80.04708099, 12.32041645], [80.04680634, 12.32042122], [80.04680634, 12.31986046], [80.04652405, 12.31986237], [80.04652405, 12.31958199], [80.04624939, 12.31958199], [80.04624939, 12.31930637], [80.0459671, 12.31931114], [80.0459671, 12.31875038], [80.04569244, 12.31875038], [80.04569244, 12.31847191], [80.04541779, 12.31847191], [80.04541779, 12.31791592], [80.04515076, 12.31791973], [80.04515076, 12.3176403], [80.04486084, 12.3176403], [80.04486084, 12.31735992], [80.04458618, 12.31735992], [80.04458618, 12.31681061], [80.04429626, 12.31681061], [80.04429626, 12.31653023], [80.04402924, 12.31653023], [80.04402924, 12.31624985], [80.04374695, 12.31624985], [80.04374695, 12.31569099], [80.04347229, 12.31569386], [80.04347229, 12.31541634], [80.04319763, 12.31542015], [80.04319763, 12.31486034], [80.04291534, 12.31486225], [80.04291534, 12.31458378], [80.04264069, 12.31458378], [80.04264069, 12.31430626], [80.0423584, 12.31431007], [80.0423584, 12.31375027], [80.04208374, 12.31375027], [80.04208374, 12.31347179], [80.04180908, 12.31347179], [80.04180908, 12.31319141], [80.04152679, 12.31319427], [80.04152679, 12.31264019], [80.04125214, 12.31264019], [80.04125214, 12.31235886], [80.04096985, 12.31236172], [80.04096985, 12.31180573], [80.04070282, 12.31180954], [80.04070282, 12.31152058], [80.0404129, 12.31152725], [80.0404129, 12.31124878], [80.04013824, 12.31125164], [80.04013824, 12.31069088], [80.03986359, 12.31069565], [80.03986359, 12.31041527], [80.0395813, 12.31042194], [80.0395813, 12.30985928], [80.03930664, 12.30986118], [80.03930664, 12.30930519], [80.03901672, 12.30930996], [80.03901672, 12.30902958], [80.03874969, 12.30902958], [80.03874969, 12.3087492], [80.03847504, 12.3087492], [80.03847504, 12.30847263], [80.03819275, 12.30848026], [80.03819275, 12.3081913], [80.03791809, 12.30819321], [80.03791809, 12.30763912], [80.0376358, 12.30764198], [80.0376358, 12.30708122], [80.03736115, 12.30708313], [80.03736115, 12.30680466], [80.03708649, 12.30681038], [80.03708649, 12.30653191], [80.03679657, 12.30653191], [80.03679657, 12.30625057], [80.03652954, 12.30625057], [80.03652954, 12.30597115], [80.03624725, 12.30597305], [80.03624725, 12.30513859], [80.03569794, 12.30514145], [80.03569794, 12.30458069], [80.03541565, 12.3045826], [80.03541565, 12.30430508], [80.03514099, 12.30430889], [80.03514099, 12.30375099], [80.03457642, 12.30375099], [80.03457642, 12.30319023], [80.03430176, 12.303195], [80.03430176, 12.30291653], [80.0340271, 12.3029213], [80.0340271, 12.30264091], [80.03375244, 12.30264091], [80.03375244, 12.30208015], [80.03347015, 12.30208302], [80.03347015, 12.30152893], [80.03321075, 12.30153084], [80.03321075, 12.30097103], [80.03291321, 12.30097294], [80.03291321, 12.30069542], [80.03263855, 12.30069542], [80.03263855, 12.30013943], [80.03235626, 12.30014133], [80.03235626, 12.29957962], [80.0320816, 12.29958344], [80.0320816, 12.29902554], [80.03180695, 12.29903126], [80.03180695, 12.29846954], [80.03152466, 12.29847336], [80.03152466, 12.29819489], [80.03125, 12.29819489], [80.03125, 12.29763794], [80.03098297, 12.2976408], [80.03098297, 12.29708004], [80.03069305, 12.29708195], [80.03069305, 12.29652786], [80.0304184, 12.29654026], [80.0304184, 12.29625034], [80.03013611, 12.29625034], [80.03013611, 12.29569435], [80.02986145, 12.29569435], [80.02986145, 12.29541588], [80.02958679, 12.29542065], [80.02958679, 12.29486179], [80.02929688, 12.29486179], [80.02929688, 12.29458046], [80.02902985, 12.29458427], [80.02902985, 12.29402828], [80.02874756, 12.29403114], [80.02874756, 12.29348087], [80.0284729, 12.29348087], [80.0284729, 12.29319191], [80.02819824, 12.29319382], [80.02819061, 12.29263783], [80.02791595, 12.29263973], [80.02791595, 12.29236031], [80.0276413, 12.29236221], [80.0276413, 12.29180622], [80.02735901, 12.29181099], [80.02735901, 12.29152966], [80.02707672, 12.29152966], [80.02707672, 12.29096985], [80.02680206, 12.29097176], [80.02680206, 12.29069424], [80.0265274, 12.29069424], [80.0265274, 12.29014015], [80.02625275, 12.29014015], [80.02625275, 12.28985977], [80.02597046, 12.28985977], [80.02597046, 12.28931046], [80.0256958, 12.28931046], [80.0256958, 12.28903008], [80.02540588, 12.28903008], [80.02540588, 12.28846931], [80.02513885, 12.28847218], [80.02513885, 12.2881937], [80.0248642, 12.2881937], [80.0248642, 12.28763771], [80.02458191, 12.28763962], [80.02458191, 12.2873497], [80.02430725, 12.2873621], [80.02430725, 12.28680611], [80.02401733, 12.28680992], [80.02401733, 12.28652954], [80.02375031, 12.28652954], [80.02375031, 12.28597164], [80.02347565, 12.28597164], [80.02347565, 12.28569317], [80.02319336, 12.28569317], [80.02319336, 12.28514004], [80.0229187, 12.28514194], [80.0229187, 12.28486156], [80.02263641, 12.28486156], [80.02263641, 12.28430462], [80.02236176, 12.28431034], [80.02236176, 12.28403187], [80.0220871, 12.28403187], [80.0220871, 12.2834692], [80.02180481, 12.28347111], [80.02180481, 12.28291702], [80.02153015, 12.28292179], [80.02153015, 12.28263855], [80.02124786, 12.28263855], [80.02124786, 12.28208065], [80.02097321, 12.28208256], [80.02097321, 12.28152657], [80.02069092, 12.28154087], [80.02069092, 12.28097057], [80.02041626, 12.28097343], [80.02041626, 12.28069305], [80.0201416, 12.28069305], [80.0201416, 12.28013897], [80.01985931, 12.28014088], [80.01985931, 12.27958107], [80.01958466, 12.27958298], [80.01958466, 12.27902699], [80.01930237, 12.27902889], [80.01930237, 12.27875137], [80.01902771, 12.27875137], [80.01902771, 12.27818108], [80.01875305, 12.27819538], [80.01875305, 12.27763939], [80.01847076, 12.2776413], [80.01847076, 12.27708054], [80.01819611, 12.2770834], [80.01819611, 12.27680492], [80.01792145, 12.2768116], [80.01792145, 12.27625084], [80.01763916, 12.27625084], [80.01763916, 12.27569008], [80.0173645, 12.27569485], [80.0173645, 12.27513885], [80.01708221, 12.27514076], [80.01708221, 12.27458], [80.01680756, 12.27458286], [80.01680756, 12.27180672], [80.0165329, 12.27181053], [80.0165329, 12.27014065], [80.01597595, 12.27014065], [80.01597595, 12.26986027], [80.01569366, 12.26986027], [80.01569366, 12.26958466], [80.01541901, 12.26958466], [80.01541901, 12.26902771], [80.01513672, 12.26903057], [80.01513672, 12.26847172], [80.01486206, 12.26847172], [80.01486206, 12.26763821], [80.01457977, 12.26764011], [80.01457977, 12.26681137], [80.01431274, 12.26681137], [80.01431274, 12.26597023], [80.01403046, 12.26597214], [80.01403046, 12.26513767], [80.01374817, 12.26513958], [80.01374817, 12.26431274], [80.01346588, 12.26431274], [80.01346588, 12.2634697], [80.01319122, 12.2634716], [80.01319122, 12.26291561], [80.01291656, 12.26292038], [80.01291656, 12.26235962], [80.01264191, 12.26236153], [80.01264191, 12.26180553], [80.01235962, 12.2618103], [80.01235962, 12.26124954], [80.01207733, 12.26124954], [80.01207733, 12.26097202], [80.01180267, 12.26097202], [80.01180267, 12.26041794], [80.01152802, 12.26042938], [80.01152802, 12.26014042], [80.01125336, 12.26014042], [80.01125336, 12.25958061], [80.01097107, 12.25958443], [80.01097107, 12.25930595], [80.01069641, 12.25930977], [80.01069641, 12.25875187], [80.01040649, 12.25875187], [80.01040649, 12.25847054], [80.01013947, 12.25847054], [80.01013947, 12.25791454], [80.00985718, 12.25792027], [80.00985718, 12.25737095], [80.00958252, 12.25737095], [80.00958252, 12.25708103], [80.00930786, 12.25708294], [80.00930786, 12.25652695], [80.00904083, 12.25652981], [80.00904083, 12.25624943], [80.00763702, 12.25624943], [80.00763702, 12.25652981], [80.00791931, 12.25652695], [80.00791931, 12.25708294], [80.00818634, 12.25708103], [80.00818634, 12.25737095], [80.00846863, 12.25737095], [80.00846863, 12.25764179], [80.00875092, 12.25763988], [80.00875092, 12.25819302], [80.00902557, 12.25819302], [80.00902557, 12.25847054], [80.00930786, 12.25847054], [80.00930786, 12.25903034], [80.00958252, 12.25902843], [80.00958252, 12.25958443], [80.00985718, 12.25958061], [80.00985718, 12.26014042], [80.01013947, 12.26013756], [80.01013947, 12.26069355], [80.01040649, 12.26069069], [80.01040649, 12.26124954], [80.01069641, 12.26124954], [80.01069641, 12.26152992], [80.01097107, 12.26152802], [80.01097107, 12.26208401], [80.01125336, 12.26208401], [80.01125336, 12.26236153], [80.01152802, 12.26235962], [80.01152802, 12.26264], [80.01180267, 12.26264], [80.01180267, 12.26319408], [80.01208496, 12.26319408], [80.01208496, 12.2634716], [80.01235962, 12.2634697], [80.01235962, 12.26403046], [80.01264191, 12.2640276], [80.01264191, 12.26458359], [80.01235962, 12.26458168], [80.01235962, 12.26513958], [80.01207733, 12.26513958], [80.01207733, 12.26542091], [80.01152802, 12.26542091], [80.01152802, 12.26513958], [80.01125336, 12.26513958], [80.01125336, 12.26486015], [80.01097107, 12.26486206], [80.01097107, 12.26458359], [80.01041412, 12.26458359], [80.01041412, 12.26430607], [80.01013947, 12.26431274], [80.01013947, 12.26403046], [80.00985718, 12.26403046], [80.00985718, 12.26375008], [80.00958252, 12.26375008], [80.00958252, 12.2634697], [80.00930786, 12.2634716], [80.00930786, 12.26319408], [80.00902557, 12.26319408], [80.00902557, 12.26291561], [80.00875092, 12.26292038], [80.00875092, 12.26264], [80.00846863, 12.26264], [80.00846863, 12.26235962], [80.00819397, 12.26236153], [80.00819397, 12.26208401], [80.00791931, 12.26208401], [80.00791931, 12.26180553], [80.00763702, 12.2618103], [80.00763702, 12.26152992], [80.00736237, 12.26152992], [80.00736237, 12.26097202], [80.00708008, 12.26097202], [80.00708008, 12.26069355], [80.00680542, 12.26069355], [80.00680542, 12.26041794], [80.00653076, 12.26042938], [80.00653076, 12.25986195], [80.00624847, 12.25986195], [80.00624847, 12.25958061], [80.00569153, 12.25958443], [80.00569153, 12.25930595], [80.00485992, 12.25930595], [80.00485992, 12.25958443], [80.00458527, 12.25958443], [80.00458527, 12.26097202], [80.00485992, 12.26097202], [80.00485992, 12.26264], [80.00514221, 12.26264], [80.00514221, 12.26375008], [80.00541687, 12.26375008], [80.00541687, 12.26431274], [80.00569153, 12.26430607], [80.00569153, 12.26486206], [80.00598145, 12.26486015], [80.00598145, 12.26542091], [80.00624847, 12.26541615], [80.00624847, 12.26597214], [80.00653076, 12.26597023], [80.00653076, 12.26653099], [80.00680542, 12.26652813], [80.00680542, 12.26708221], [80.00708008, 12.26708031], [80.00708008, 12.26735973], [80.00763702, 12.26735973], [80.00763702, 12.26792145], [80.00791931, 12.26792145], [80.00791931, 12.26903057], [80.00819397, 12.26902771], [80.00819397, 12.26958466], [80.00846863, 12.26958466], [80.00846863, 12.26986027], [80.00904083, 12.26986027], [80.00904083, 12.27014065], [80.00930786, 12.27014065], [80.00930786, 12.27042103], [80.00958252, 12.27041626], [80.00958252, 12.27069378], [80.01013947, 12.27069378], [80.01013947, 12.27097321], [80.01040649, 12.27097034], [80.01040649, 12.27125072], [80.01097107, 12.27125072], [80.01097107, 12.27153111], [80.01125336, 12.2715292], [80.01125336, 12.27208233], [80.01152802, 12.27208042], [80.01152802, 12.27264118], [80.01013947, 12.27264118], [80.01013947, 12.27237034], [80.00985718, 12.27237034], [80.00985718, 12.27208042], [80.00958252, 12.27208233], [80.00958252, 12.27180672], [80.00930786, 12.27181053], [80.00930786, 12.27153111], [80.00907898, 12.27148533], [80.00902557, 12.27125072], [80.00894165, 12.27125072], [80.00846863, 12.27125072], [80.00846863, 12.27097034], [80.00819397, 12.27097321], [80.00819397, 12.27069378], [80.00791931, 12.27069378], [80.00791931, 12.27041626], [80.00763702, 12.27042103], [80.00763702, 12.27014065], [80.00736237, 12.27014065], [80.00736237, 12.26988125], [80.00736237, 12.26958466], [80.00708008, 12.26958466], [80.00708008, 12.26902771], [80.00681305, 12.26903057], [80.00681305, 12.26764011], [80.00653076, 12.26764011], [80.00653076, 12.26735973], [80.00597382, 12.26735973], [80.00597382, 12.26708221], [80.00569153, 12.26708221], [80.00569153, 12.26652813], [80.00541687, 12.26653099], [80.00541687, 12.26624107], [80.00514221, 12.26624966], [80.00514221, 12.26569366], [80.00485992, 12.26569366], [80.00485992, 12.26541615], [80.0045929, 12.26542091], [80.0045929, 12.26486015], [80.00430298, 12.26486206], [80.00430298, 12.26291561], [80.00402832, 12.26292038], [80.00402832, 12.26152992], [80.00374603, 12.26152992], [80.00374603, 12.25958061], [80.00347137, 12.25958443], [80.00347137, 12.25847054], [80.00319672, 12.25847054], [80.00319672, 12.25819588], [80.0029068, 12.25819111], [80.00291443, 12.25791454], [80.00235748, 12.25792027], [80.00235748, 12.25764179], [80.00152588, 12.25764179], [80.00152588, 12.25737095], [80.00096893, 12.25737095], [80.00096893, 12.25708103], [79.99986267, 12.25708294], [79.99877167, 12.25708294], [79.99819183, 12.25708294], [79.99819183, 12.25680542], [79.99791718, 12.25681019], [79.99791718, 12.25652981], [79.99736023, 12.25652981], [79.99736023, 12.25624943], [79.99681091, 12.25624943], [79.99681091, 12.25652981], [79.99624634, 12.25652695], [79.99624634, 12.25708294], [79.99569702, 12.25708294], [79.99569702, 12.25680542], [79.9954071, 12.25681019], [79.9954071, 12.25624943], [79.99514008, 12.25624943], [79.99514008, 12.25569057], [79.99485779, 12.25569534], [79.99485779, 12.25541687], [79.99404144, 12.25541973], [79.99404144, 12.25513935], [79.99375153, 12.25513935], [79.99375153, 12.25486088], [79.99346924, 12.25486088], [79.99346924, 12.25458145], [79.99291992, 12.25458336], [79.99291992, 12.25430489], [79.99236298, 12.25430489], [79.99236298, 12.25402737], [79.99180603, 12.25402927], [79.99180603, 12.25374889], [79.9909668, 12.25374889], [79.9909668, 12.25347137], [79.99069214, 12.25347328], [79.99069214, 12.25319481], [79.99041748, 12.25319481], [79.99041748, 12.25291729], [79.98986053, 12.25292015], [79.98986053, 12.25264072], [79.98929596, 12.25264072], [79.98929596, 12.2523613], [79.98847198, 12.2523613], [79.98847198, 12.25208282], [79.98791504, 12.25208282], [79.98791504, 12.25180531], [79.98707581, 12.25181198], [79.98707581, 12.2515316], [79.98652649, 12.2515316], [79.98652649, 12.25123978], [79.98625183, 12.25125122], [79.98625183, 12.25097084], [79.98596954, 12.25097084], [79.98596954, 12.25069141], [79.98542023, 12.25069523], [79.98542023, 12.25041676], [79.98513794, 12.25042152], [79.98513794, 12.24985886], [79.98486328, 12.24986076], [79.98486328, 12.24930477], [79.98458099, 12.2493124], [79.98458099, 12.24875069], [79.98430634, 12.24875069], [79.98430634, 12.24847126], [79.98402405, 12.24847317], [79.98402405, 12.24819469], [79.98374939, 12.24819946], [79.98374939, 12.24681091], [79.9834671, 12.24681091], [79.9834671, 12.24625111], [79.98319244, 12.24625111], [79.98319244, 12.24542999], [79.98291779, 12.24542999], [79.98291779, 12.24431133], [79.98264313, 12.24431133], [79.98264313, 12.24375057], [79.98210144, 12.24375057], [79.98210144, 12.24347019], [79.98152924, 12.2434721], [79.98152924, 12.24319363], [79.98124695, 12.24319363], [79.98124695, 12.24291611], [79.98069763, 12.24292088], [79.98069763, 12.24264145], [79.98014069, 12.24264145], [79.98014069, 12.24236012], [79.97957611, 12.24236012], [79.97957611, 12.24207973], [79.97930908, 12.24208355], [79.97930908, 12.24180603], [79.97875214, 12.2418108], [79.97875214, 12.24153137], [79.97820282, 12.24153137], [79.97820282, 12.24125004], [79.97763824, 12.24125004], [79.97763824, 12.24096966], [79.9770813, 12.24097157], [79.9770813, 12.24069405], [79.97652435, 12.24069405], [79.97652435, 12.24041557], [79.97624969, 12.2404213], [79.97624969, 12.24013996], [79.97567749, 12.24013996], [79.97567749, 12.23985958], [79.9751358, 12.23986244], [79.9751358, 12.23958206], [79.97458649, 12.23958206], [79.97458649, 12.23930645], [79.97402954, 12.23930645], [79.97402954, 12.23902798], [79.97374725, 12.23903275], [79.97374725, 12.23875046], [79.9734726, 12.23875046], [79.9734726, 12.23847198], [79.97319794, 12.23847198], [79.97319794, 12.23819447], [79.97291565, 12.23819447], [79.97291565, 12.23763847], [79.97264099, 12.23764038], [79.97264099, 12.23736], [79.9723587, 12.23736], [79.9723587, 12.23707962], [79.97208405, 12.23708439], [79.97208405, 12.23680592], [79.97180176, 12.23681068], [79.97180176, 12.2365303], [79.97097015, 12.2365303], [79.97097015, 12.23626137], [79.96930695, 12.23626137], [79.96930695, 12.23596954], [79.96902466, 12.2359724], [79.96902466, 12.23569393], [79.96819305, 12.23569393], [79.96819305, 12.23541641], [79.9679184, 12.23542023], [79.9679184, 12.23513985], [79.96763611, 12.23513985], [79.96763611, 12.23486042], [79.96736145, 12.23486233], [79.96736145, 12.23458385], [79.96708679, 12.23458385], [79.96708679, 12.23430634], [79.96681213, 12.23431015], [79.96681213, 12.23402977], [79.96652985, 12.23402977], [79.96652985, 12.23375034], [79.9659729, 12.23375034], [79.9659729, 12.23291969], [79.96541595, 12.23291969], [79.96541595, 12.23264027], [79.96485901, 12.23264027], [79.96485901, 12.23236179], [79.9640274, 12.23236179], [79.9640274, 12.23208141], [79.96347046, 12.23208427], [79.96347046, 12.2318058], [79.96290588, 12.23180962], [79.96290588, 12.23153019], [79.96208191, 12.23153019], [79.96208191, 12.23124886], [79.96180725, 12.23124886], [79.96180725, 12.23097134], [79.96125031, 12.23097134], [79.96125031, 12.23069572], [79.96097565, 12.23069572], [79.96097565, 12.23041534], [79.9604187, 12.23042202], [79.9604187, 12.22985935], [79.96013641, 12.22986126], [79.96013641, 12.22958279], [79.95986176, 12.22958279], [79.95986176, 12.22930527], [79.95929718, 12.22931004], [79.95929718, 12.22902966], [79.95874786, 12.22902966], [79.95874786, 12.22874928], [79.95819092, 12.22874928], [79.95819092, 12.22846889], [79.9576416, 12.2284708], [79.9576416, 12.22819328], [79.95708466, 12.22819328], [79.95708466, 12.22791672], [79.95652771, 12.22791958], [79.95652771, 12.22736073], [79.95540619, 12.22736073], [79.95540619, 12.22706985], [79.95513916, 12.22708321], [79.95513916, 12.22680473], [79.95487213, 12.22681046], [79.95487213, 12.22653198], [79.9540329, 12.22653198], [79.9540329, 12.22625065], [79.95375061, 12.22625065], [79.95375061, 12.22597122], [79.95319366, 12.22597313], [79.95319366, 12.22569466], [79.95263672, 12.22569466], [79.95263672, 12.22541714], [79.95207977, 12.22542191], [79.95207977, 12.22514057], [79.95124817, 12.22514057], [79.95124817, 12.22486115], [79.95097351, 12.22486115], [79.95097351, 12.22458267], [79.95041656, 12.22458267], [79.95041656, 12.22430515], [79.94985962, 12.22430515], [79.94985962, 12.22458267], [79.94958496, 12.22458267], [79.94958496, 12.22430515], [79.94930267, 12.22432137], [79.94930267, 12.22403145], [79.94902802, 12.22403145], [79.94902802, 12.22375107], [79.9487381, 12.22375107], [79.9487381, 12.22319031], [79.94847107, 12.22319508], [79.94847107, 12.2229166], [79.94790649, 12.22292233], [79.94790649, 12.22264099], [79.94735718, 12.22264099], [79.94735718, 12.22236061], [79.94680786, 12.22236061], [79.94680786, 12.22208309], [79.94625092, 12.22208309], [79.94625092, 12.22180462], [79.94596863, 12.22180939], [79.94596863, 12.22153091], [79.9457016, 12.22153091], [79.9457016, 12.22097111], [79.94541931, 12.22097301], [79.94541931, 12.22069454], [79.94513702, 12.22069454], [79.94513702, 12.22041702], [79.94486237, 12.22042084], [79.94486237, 12.22014141], [79.94458008, 12.22014141], [79.94458008, 12.21986103], [79.94486237, 12.21986103], [79.94486237, 12.21931076], [79.94569397, 12.21930695], [79.94569397, 12.21958256], [79.94625092, 12.21958256], [79.94625092, 12.21914959], [79.94625092, 12.21902561], [79.94581604, 12.21902943], [79.94513702, 12.21903133], [79.94513702, 12.21872997], [79.94513702, 12.21819496], [79.94541931, 12.21819496], [79.94541931, 12.21791744], [79.9457016, 12.21792126], [79.9457016, 12.21764088], [79.94596863, 12.21764088], [79.94596863, 12.21735954], [79.94736481, 12.21735954], [79.94736481, 12.21708202], [79.94763947, 12.21708202], [79.94763947, 12.21652889], [79.94790649, 12.2165308], [79.94790649, 12.21597004], [79.94875336, 12.21597195], [79.94875336, 12.21569443], [79.94985962, 12.21569443], [79.94985962, 12.21541595], [79.95014191, 12.21542072], [79.95014191, 12.2151289], [79.95069122, 12.21513844], [79.95069122, 12.21458435], [79.95097351, 12.21458435], [79.95097351, 12.21430588], [79.95179749, 12.21431065], [79.95179749, 12.21403122], [79.95291901, 12.21403122], [79.95291901, 12.21375275], [79.95263672, 12.21375275], [79.95263672, 12.21347046], [79.95207977, 12.21347237], [79.95207977, 12.21319389], [79.95236206, 12.21319389], [79.95236206, 12.21291637], [79.95263672, 12.21292114], [79.95263672, 12.21264267], [79.95318604, 12.21264267], [79.95318604, 12.21236038], [79.95347595, 12.21236229], [79.95347595, 12.21208191], [79.95402527, 12.21208191], [79.95402527, 12.21236229], [79.9548645, 12.21236229], [79.9548645, 12.21208191], [79.95513916, 12.21208191], [79.95513916, 12.2118063], [79.95652771, 12.2118063], [79.95652771, 12.21208191], [79.95680237, 12.21208191], [79.95680237, 12.21236229], [79.95707703, 12.21236038], [79.95707703, 12.21264267], [79.9576416, 12.21264267], [79.9576416, 12.21292114], [79.95791626, 12.21291637], [79.95791626, 12.21319389], [79.95819092, 12.21319389], [79.95819092, 12.21347237], [79.95847321, 12.21347046], [79.95847321, 12.21375275], [79.95874786, 12.21375275], [79.95874786, 12.21403122], [79.95847321, 12.21402836], [79.95847321, 12.21458435], [79.95929718, 12.21457958], [79.95929718, 12.21485996], [79.95986176, 12.21485996], [79.95986176, 12.21542072], [79.96013641, 12.21541595], [79.96013641, 12.21597195], [79.9604187, 12.21597004], [79.9604187, 12.2165308], [79.96069336, 12.21652889], [79.96069336, 12.21708202], [79.9604187, 12.21708012], [79.9604187, 12.21875095], [79.96099091, 12.21875095], [79.96099091, 12.21903133], [79.96125031, 12.21903133], [79.96125031, 12.21931076], [79.96180725, 12.21930695], [79.96180725, 12.21958256], [79.96208191, 12.2195797], [79.96208191, 12.21986103], [79.96235657, 12.21986103], [79.96235657, 12.22042084], [79.96263885, 12.22041702], [79.96263885, 12.22097301], [79.96290588, 12.22097111], [79.96290588, 12.22153091], [79.9631958, 12.22153091], [79.9631958, 12.22180939], [79.96291351, 12.22180462], [79.96291351, 12.22236061], [79.96263885, 12.22236061], [79.96263885, 12.22208309], [79.96208191, 12.22208309], [79.96208191, 12.22216034], [79.96208191, 12.22264099], [79.962883, 12.22263908], [79.9631958, 12.22263908], [79.9631958, 12.2229166], [79.96333313, 12.2229166], [79.96347046, 12.2229166], [79.96347046, 12.2234726], [79.96406555, 12.22343159], [79.9640274, 12.22375107], [79.96434021, 12.22371483], [79.96430206, 12.22432137], [79.96457672, 12.22432137], [79.96457672, 12.22403145], [79.9651413, 12.22403145], [79.9651413, 12.22432137], [79.96569061, 12.22432137], [79.96569824, 12.22403145], [79.9659729, 12.22402668], [79.9659729, 12.22486115], [79.96569824, 12.22486115], [79.96569824, 12.22511196], [79.96569824, 12.22542191], [79.9659729, 12.22541714], [79.9659729, 12.22569466], [79.96626282, 12.22569466], [79.96652985, 12.22569466], [79.96652985, 12.22597313], [79.96681213, 12.22597122], [79.96681213, 12.22625065], [79.96736145, 12.22625065], [79.96736145, 12.22653198], [79.9679184, 12.22653198], [79.9679184, 12.22681046], [79.96847534, 12.22680473], [79.96847534, 12.22708321], [79.96875, 12.22706985], [79.96875, 12.22736073], [79.96930695, 12.22736073], [79.96930695, 12.2276392], [79.9695816, 12.2276392], [79.9695816, 12.22791958], [79.97013855, 12.22791672], [79.97013855, 12.22819328], [79.97041321, 12.22819328], [79.97041321, 12.2284708], [79.9706955, 12.2284708], [79.9706955, 12.22874928], [79.97097015, 12.22874928], [79.97097015, 12.22902966], [79.97125244, 12.22902966], [79.97125244, 12.22931004], [79.9715271, 12.22930527], [79.9715271, 12.22958279], [79.97180176, 12.22958279], [79.97180939, 12.22986126], [79.97207642, 12.22985935], [79.97207642, 12.23014164], [79.9723587, 12.23013973], [79.9723587, 12.23069572], [79.97264099, 12.23069572], [79.97264099, 12.23097134], [79.97319794, 12.23097134], [79.97319794, 12.23124886], [79.9734726, 12.23124886], [79.9734726, 12.23097134], [79.9743042, 12.23097134], [79.9743042, 12.23124886], [79.97458649, 12.23124886], [79.97458649, 12.23153019], [79.9751358, 12.23153019], [79.9751358, 12.23180962], [79.97569275, 12.2318058], [79.97569275, 12.23208427], [79.97596741, 12.23208141], [79.97596741, 12.23236179], [79.97651672, 12.23236179], [79.97651672, 12.23264027], [79.9770813, 12.23264027], [79.9770813, 12.23180962], [79.97735596, 12.23180962], [79.97735596, 12.23153019], [79.9779129, 12.23152828], [79.9779129, 12.23208427], [79.97820282, 12.23208141], [79.97820282, 12.23291969], [79.97846985, 12.23291779], [79.97846985, 12.23347187], [79.97902679, 12.23347187], [79.97902679, 12.23375034], [79.97957611, 12.23375034], [79.97957611, 12.23402977], [79.98014069, 12.23402977], [79.98014069, 12.23431015], [79.98042297, 12.23431015], [79.98042297, 12.23513985], [79.98097229, 12.23513985], [79.98097229, 12.23542023], [79.98124695, 12.23541641], [79.98124695, 12.23569393], [79.98152924, 12.23569202], [79.98152924, 12.2365303], [79.98181152, 12.2365303], [79.98181152, 12.23681068], [79.98208618, 12.23680592], [79.98208618, 12.23736], [79.98236084, 12.23736], [79.98236084, 12.23764038], [79.98291779, 12.23763847], [79.98291779, 12.23847198], [79.98319244, 12.23847198], [79.98319244, 12.23903275], [79.98374939, 12.23902798], [79.98374939, 12.23930645], [79.98402405, 12.23930645], [79.98402405, 12.23958206], [79.98430634, 12.23958015], [79.98430634, 12.24013996], [79.98458099, 12.24013996], [79.98458099, 12.2404213], [79.98486328, 12.24041557], [79.98486328, 12.24097157], [79.98513794, 12.24096966], [79.98513794, 12.24125004], [79.98568726, 12.24125004], [79.98568726, 12.2418108], [79.98596954, 12.24180603], [79.98596954, 12.24208355], [79.98708344, 12.24208355], [79.98707581, 12.24223042], [79.98707581, 12.24236012], [79.98735809, 12.24236012], [79.98735809, 12.24292088], [79.98764038, 12.24291611], [79.98764038, 12.24319363], [79.98791504, 12.24319363], [79.98791504, 12.2434721], [79.98819733, 12.24347019], [79.98819733, 12.24375057], [79.98847198, 12.24375057], [79.98847198, 12.24403095], [79.98874664, 12.24402905], [79.98874664, 12.24458218], [79.98902893, 12.24458027], [79.98902893, 12.2448597], [79.98929596, 12.2448597], [79.98929596, 12.24514103], [79.98958588, 12.24514103], [79.98958588, 12.24542999], [79.98986053, 12.24541664], [79.98986053, 12.24569511], [79.99013519, 12.24569511], [79.99013519, 12.24597263], [79.99041748, 12.24596977], [79.99041748, 12.24625111], [79.99069214, 12.24625111], [79.99069214, 12.24653053], [79.9909668, 12.24653053], [79.9909668, 12.24681091], [79.99153137, 12.24680519], [79.99153137, 12.24708271], [79.99180603, 12.24708271], [79.99180603, 12.24736118], [79.99208069, 12.24736118], [79.99208069, 12.24764061], [79.99236298, 12.24764061], [79.99236298, 12.24792099], [79.99263763, 12.24792099], [79.99263763, 12.24819946], [79.99291992, 12.24819469], [79.99291992, 12.24847317], [79.99404144, 12.24847126], [79.99404144, 12.24875069], [79.99430847, 12.24875069], [79.99430847, 12.24903107], [79.99458313, 12.24903107], [79.99458313, 12.2493124], [79.99485779, 12.24930477], [79.99485779, 12.24986076], [79.99500275, 12.24986076], [79.99514008, 12.24985886], [79.99514008, 12.25014114], [79.99541473, 12.25013924], [79.99541473, 12.25069523], [79.99597168, 12.25069141], [79.99597168, 12.25097084], [79.99624634, 12.25097084], [79.99624634, 12.2515316], [79.99681091, 12.2515316], [79.99681091, 12.25181198], [79.99708557, 12.25180531], [79.99708557, 12.25208282], [79.99764252, 12.25208282], [79.99764252, 12.2523613], [79.99819183, 12.2523613], [79.99819183, 12.25264072], [79.99903107, 12.25264072], [79.99903107, 12.25292015], [79.99958038, 12.25291729], [79.99958038, 12.25319481], [80.00013733, 12.25319481], [80.00180817, 12.25319481], [80.00180817, 12.25347328], [80.00235748, 12.25347137], [80.00235748, 12.25374889], [80.00263977, 12.25374889], [80.00263977, 12.25402927], [80.00319672, 12.25402737], [80.00319672, 12.25430489], [80.00485992, 12.25430489], [80.00485992, 12.25458336], [80.00624847, 12.25458145], [80.00624847, 12.25486088], [80.00681305, 12.25486088], [80.00680542, 12.25458336], [80.00708008, 12.25458336], [80.00708008, 12.25374889], [80.00680542, 12.25374889], [80.00680542, 12.25347328], [80.00653076, 12.25347328], [80.00653076, 12.25291729], [80.00624847, 12.25292015], [80.00624847, 12.25264072], [80.00598145, 12.25264072], [80.00598145, 12.25208092], [80.00541687, 12.25208282], [80.00541687, 12.25125122], [80.00514221, 12.25125122], [80.00514221, 12.25069523], [80.00485992, 12.25069523], [80.00485992, 12.25041676], [80.0045929, 12.25042152], [80.0045929, 12.24985886], [80.00430298, 12.24986076], [80.00430298, 12.24930477], [80.00402832, 12.2493124], [80.00402832, 12.24875069], [80.00374603, 12.24875069], [80.00374603, 12.24847126], [80.00347137, 12.24847317], [80.00347137, 12.24791718], [80.00319672, 12.24792099], [80.00319672, 12.24736118], [80.00291443, 12.24736118], [80.00291443, 12.24708271], [80.00263977, 12.24708271], [80.00263977, 12.24652863], [80.00235748, 12.24653053], [80.00235748, 12.24596977], [80.00208282, 12.24597263], [80.00208282, 12.24541664], [80.00180817, 12.24542999], [80.00180817, 12.2448597], [80.00152588, 12.2448597], [80.00152588, 12.24431133], [80.00125122, 12.24431133], [80.00125122, 12.24375057], [80.00096893, 12.24375057], [80.00096893, 12.24347019], [80.00069427, 12.2434721], [80.00069427, 12.24291611], [80.00041962, 12.24292088], [80.00041962, 12.24264145], [80.00013733, 12.24264145], [80.00013733, 12.24207973], [79.99986267, 12.24208355], [79.99986267, 12.24180603], [79.99958038, 12.2418108], [79.99958038, 12.24096966], [79.99930573, 12.24097157], [79.99930573, 12.24069405], [79.99903107, 12.24069405], [79.99903107, 12.24041557], [79.99874878, 12.2404213], [79.99874878, 12.24013996], [79.99846649, 12.24013996], [79.99846649, 12.23985958], [79.99819183, 12.23986244], [79.99819183, 12.23958206], [79.99736023, 12.23958206], [79.99736023, 12.23986244], [79.99710083, 12.23985958], [79.99710083, 12.24013996], [79.99681091, 12.24013996], [79.99681091, 12.2404213], [79.99624634, 12.2404213], [79.99624634, 12.23958015], [79.99652863, 12.23958206], [79.99652863, 12.23930645], [79.99736023, 12.23930645], [79.99736023, 12.23902798], [79.99764252, 12.23903275], [79.99764252, 12.23764038], [79.99736023, 12.23764038], [79.99736023, 12.23736], [79.99708557, 12.23736], [79.99708557, 12.23680592], [79.99681091, 12.23681068], [79.99681091, 12.2365303], [79.99652863, 12.2365303], [79.99652863, 12.23596954], [79.99624634, 12.2359724], [79.99624634, 12.23569393], [79.99597168, 12.23569393], [79.99597168, 12.23513985], [79.99569702, 12.23513985], [79.99569702, 12.23458195], [79.99541473, 12.23458385], [79.99541473, 12.23402786], [79.99514008, 12.23402977], [79.99514008, 12.23375034], [79.99485779, 12.23375034], [79.99485779, 12.23347187], [79.99458313, 12.23347187], [79.99458313, 12.23319435], [79.99404144, 12.23320007], [79.99404144, 12.23291969], [79.99375153, 12.23291969], [79.99375153, 12.23180962], [79.99346924, 12.23180962], [79.99346924, 12.23097134], [79.99319458, 12.23097134], [79.99319458, 12.23041534], [79.99291992, 12.23042202], [79.99291992, 12.22985935], [79.99263763, 12.22986126], [79.99263763, 12.22930527], [79.99236298, 12.22931004], [79.99236298, 12.22902966], [79.99208069, 12.22902966], [79.99208069, 12.22874928], [79.99180603, 12.22874928], [79.99180603, 12.22846889], [79.99153137, 12.2284708], [79.99153137, 12.22819328], [79.99124908, 12.22819328], [79.99124908, 12.22736073], [79.9909668, 12.22736073], [79.9909668, 12.22681046], [79.99069214, 12.22681046], [79.99069214, 12.22625065], [79.99041748, 12.22625065], [79.99041748, 12.22569084], [79.99013519, 12.22569466], [79.99013519, 12.22541714], [79.98986053, 12.22542191], [79.98986053, 12.22486115], [79.98958588, 12.22486115], [79.98958588, 12.22430515], [79.98929596, 12.22432137], [79.98929596, 12.22403145], [79.98902893, 12.22403145], [79.98902893, 12.22375107], [79.98874664, 12.22375107], [79.98874664, 12.22347069], [79.98847198, 12.2234726], [79.98847198, 12.22319508], [79.98819733, 12.22319508], [79.98819733, 12.22263908], [79.98790741, 12.22264099], [79.98790741, 12.22236061], [79.98764038, 12.22236061], [79.98764038, 12.22208309], [79.98735809, 12.22208309], [79.98735809, 12.22152901], [79.98707581, 12.22153091], [79.98707581, 12.22097111], [79.98680878, 12.22097301], [79.98680878, 12.22069454], [79.98652649, 12.22069454], [79.98652649, 12.22013855], [79.98625183, 12.22014141], [79.98625183, 12.21986103], [79.98596954, 12.21986103], [79.98596954, 12.2195797], [79.98569489, 12.21958256], [79.98569489, 12.21930695], [79.98542023, 12.21931076], [79.98542023, 12.21903133], [79.98513794, 12.21903133], [79.98513794, 12.21875095], [79.98487091, 12.21875095], [79.98487091, 12.21846962], [79.98458099, 12.21847343], [79.98458099, 12.21819496], [79.98430634, 12.21819496], [79.98430634, 12.21791744], [79.98401642, 12.21792126], [79.98401642, 12.21764088], [79.98374939, 12.21764088], [79.98374939, 12.21597004], [79.98347473, 12.21597195], [79.98347473, 12.21569443], [79.98319244, 12.21569443], [79.98319244, 12.21485996], [79.98291779, 12.21485996], [79.98291779, 12.21431065], [79.98264313, 12.21431065], [79.98264313, 12.21375275], [79.98181152, 12.21375275], [79.98181152, 12.21347046], [79.98152924, 12.21347237], [79.98152924, 12.21291637], [79.98124695, 12.21292114], [79.98124695, 12.21236038], [79.98097229, 12.21236229], [79.98097229, 12.2118063], [79.98069763, 12.21181107], [79.98069763, 12.21152973], [79.98042297, 12.21152973], [79.98042297, 12.21097183], [79.98014069, 12.21097183], [79.98014069, 12.21041584], [79.9798584, 12.21041965], [79.9798584, 12.20985985], [79.97958374, 12.20985985], [79.97958374, 12.20930576], [79.97930908, 12.20932198], [79.97930908, 12.20874977], [79.97902679, 12.20874977], [79.97902679, 12.20819092], [79.97875214, 12.20819378], [79.97875214, 12.20791626], [79.97846985, 12.20792007], [79.97846985, 12.20736027], [79.97819519, 12.20736217], [79.97819519, 12.20680618], [79.9779129, 12.20681], [79.9779129, 12.20625019], [79.97763824, 12.20625019], [79.97763824, 12.20569134], [79.97736359, 12.2056942], [79.97736359, 12.20514011], [79.9770813, 12.20514202], [79.9770813, 12.20486164], [79.97680664, 12.20486164], [79.97680664, 12.20458126], [79.97652435, 12.20458412], [79.97652435, 12.20430565], [79.97624969, 12.20431042], [79.97624969, 12.20403194], [79.97596741, 12.20403194], [79.97596741, 12.20375156], [79.97567749, 12.20375156], [79.97567749, 12.2031889], [79.97541809, 12.20319557], [79.97541809, 12.20263863], [79.9751358, 12.20263863], [79.9751358, 12.2023592], [79.97486115, 12.20236111], [79.97486115, 12.20180511], [79.97458649, 12.20181179], [79.97458649, 12.20125103], [79.97429657, 12.20125103], [79.97429657, 12.20097065], [79.97402954, 12.20097256], [79.97402954, 12.20041656], [79.97374725, 12.20042038], [79.97374725, 12.19986057], [79.9734726, 12.19986057], [79.9734726, 12.19958305], [79.97319794, 12.19958305], [79.97319794, 12.19902706], [79.97293091, 12.19903183], [79.97293091, 12.19847107], [79.97264099, 12.19847107], [79.97264099, 12.19819546], [79.9723587, 12.19819546], [79.9723587, 12.19763947], [79.97207642, 12.19764137], [79.97207642, 12.19709015], [79.97180176, 12.19709015], [79.97180176, 12.1965313], [79.97097015, 12.1965313], [79.97097015, 12.19625092], [79.97070313, 12.19625092], [79.97070313, 12.19569969], [79.97041321, 12.19569016], [79.97041321, 12.1954174], [79.97013855, 12.19541931], [79.97013855, 12.19486141], [79.96986389, 12.19486141], [79.96986389, 12.19458294], [79.9695816, 12.19458294], [79.9695816, 12.19402885], [79.96930695, 12.19403076], [79.96930695, 12.19347095], [79.96902466, 12.19347286], [79.96902466, 12.19291687], [79.96875, 12.19292068], [79.96875, 12.19264126], [79.96848297, 12.19264126], [79.96848297, 12.19207954], [79.96819305, 12.19208336], [79.96819305, 12.19152641], [79.9679184, 12.19153118], [79.9679184, 12.1912508], [79.96763611, 12.1912508], [79.96763611, 12.19069004], [79.96736145, 12.19069481], [79.96736145, 12.19013786], [79.96708679, 12.19014072], [79.96708679, 12.18957996], [79.9668045, 12.18958473], [79.9668045, 12.18930435], [79.96652985, 12.18931103], [79.96652985, 12.18875027], [79.96624756, 12.18875027], [79.96624756, 12.18847179], [79.9659729, 12.18847179], [79.9659729, 12.18792057], [79.96569824, 12.18792057], [79.96569061, 12.18736172], [79.96541595, 12.18736172], [79.96541595, 12.18708038], [79.9651413, 12.18708229], [79.9651413, 12.18652821], [79.96485901, 12.18653107], [79.96485901, 12.18624973], [79.96457672, 12.18624973], [79.96457672, 12.18569183], [79.96430206, 12.18569374], [79.96430206, 12.18541622], [79.9640274, 12.18542099], [79.9640274, 12.18486023], [79.96375275, 12.18486214], [79.96375275, 12.18458366], [79.96347046, 12.18458366], [79.96347046, 12.18402767], [79.9631958, 12.18402958], [79.9631958, 12.18375015], [79.96290588, 12.18375015], [79.96290588, 12.18318939], [79.96263885, 12.18319416], [79.96263885, 12.18291569], [79.96235657, 12.18292046], [79.96235657, 12.18264008], [79.96208191, 12.18264008], [79.96208191, 12.18209076], [79.96180725, 12.18209076], [79.96180725, 12.18181038], [79.96151733, 12.18181038], [79.96151733, 12.18124962], [79.96125031, 12.18124962], [79.96125031, 12.18096924], [79.96097565, 12.1809721], [79.96097565, 12.18041801], [79.9606781, 12.18041992], [79.9606781, 12.18013954], [79.9604187, 12.18013954], [79.9604187, 12.17958069], [79.96013641, 12.17958355], [79.96013641, 12.17902756], [79.95986176, 12.17902756], [79.95986176, 12.17875004], [79.9595871, 12.17875195], [79.9595871, 12.17819118], [79.95930481, 12.17819309], [79.95930481, 12.17791462], [79.95903015, 12.17792034], [79.95903015, 12.17736244], [79.95874786, 12.17736244], [79.95874786, 12.17708397], [79.95847321, 12.17708397], [79.95847321, 12.17680454], [79.95819092, 12.17681026], [79.95819092, 12.17624855], [79.95791626, 12.17624855], [79.95791626, 12.17597103], [79.9576416, 12.17597103], [79.9576416, 12.17541695], [79.95735931, 12.17541981], [79.95735931, 12.17513943], [79.95707703, 12.17513943], [79.95707703, 12.17486095], [79.95680237, 12.17486095], [79.95680237, 12.17430973], [79.95652771, 12.17430973], [79.95652771, 12.1740303], [79.95625305, 12.1740303], [79.95625305, 12.17375088], [79.95597076, 12.17375088], [79.95597076, 12.17319107], [79.95569611, 12.17319489], [79.95569611, 12.17291737], [79.95540619, 12.17292023], [79.95540619, 12.17263889], [79.95513916, 12.17263889], [79.95513916, 12.17208099], [79.9548645, 12.1720829], [79.9548645, 12.17180538], [79.95458221, 12.17181015], [79.95458221, 12.17153168], [79.95430756, 12.17153168], [79.95430756, 12.17097092], [79.95402527, 12.17097092], [79.95402527, 12.1706953], [79.95375061, 12.1706953], [79.95375061, 12.17013931], [79.95347595, 12.17015266], [79.95347595, 12.16986084], [79.95318604, 12.16986084], [79.95318604, 12.16931152], [79.95291901, 12.16931152], [79.95291901, 12.16902924], [79.95263672, 12.16902924], [79.95263672, 12.16874886], [79.95236206, 12.16874886], [79.95236206, 12.16819477], [79.95207977, 12.16819477], [79.95207977, 12.16791725], [79.95179749, 12.16792107], [79.95179749, 12.16736126], [79.95153046, 12.16736126], [79.95153046, 12.16708279], [79.95124817, 12.16708279], [79.95124817, 12.1665287], [79.95096588, 12.16653061], [79.95096588, 12.16625118], [79.95069122, 12.16625118], [79.95069122, 12.16569042], [79.95041656, 12.16569519], [79.95041656, 12.16541672], [79.95014191, 12.16542053], [79.95014191, 12.16486073], [79.94985962, 12.16486073], [79.94985962, 12.16458035], [79.94958496, 12.16458225], [79.94958496, 12.16402912], [79.94930267, 12.16402912], [79.94930267, 12.16375065], [79.94902802, 12.16375065], [79.94902802, 12.1631918], [79.94875336, 12.1631937], [79.94875336, 12.16263771], [79.94847107, 12.16264057], [79.94847107, 12.16236019], [79.94819641, 12.16236019], [79.94819641, 12.1618042], [79.94790649, 12.16181087], [79.94790649, 12.16153145], [79.94763947, 12.16153145], [79.94763947, 12.16097927], [79.94735718, 12.16097927], [79.94735718, 12.16042137], [79.94708252, 12.16042137], [79.94708252, 12.16014004], [79.94680786, 12.16014004], [79.94680786, 12.15985966], [79.94652557, 12.15986156], [79.94652557, 12.15930557], [79.94625092, 12.15931129], [79.94625092, 12.15903091], [79.9457016, 12.15903091], [79.9457016, 12.15874958], [79.94541931, 12.15874958], [79.94541931, 12.15819168], [79.94513702, 12.15819359], [79.94513702, 12.15791607], [79.94486237, 12.15792274], [79.94486237, 12.15736008], [79.94458008, 12.15736008], [79.94458008, 12.1570797], [79.94430542, 12.15708447], [79.94430542, 12.15652847], [79.94403076, 12.15653038], [79.94403076, 12.15625], [79.94374847, 12.15625], [79.94374847, 12.15568924], [79.94347382, 12.15569401], [79.94347382, 12.15513992], [79.94319153, 12.15513992], [79.94319153, 12.15485096], [79.94291687, 12.1548624], [79.94291687, 12.15430641], [79.94264221, 12.15431023], [79.94264221, 12.15402985], [79.94235992, 12.15402985], [79.94235992, 12.15347195], [79.94208527, 12.15347195], [79.94208527, 12.15319443], [79.94180298, 12.15319443], [79.94180298, 12.15264034], [79.94152832, 12.15264034], [79.94152832, 12.15236187], [79.94124603, 12.15236187], [79.94124603, 12.15180969], [79.94097137, 12.15180969], [79.94097137, 12.15153027], [79.94069672, 12.15153027], [79.94069672, 12.15125179], [79.9404068, 12.15125179], [79.9404068, 12.15069103], [79.94013977, 12.1506958], [79.94013977, 12.15041542], [79.93985748, 12.15042019], [79.93985748, 12.15013981], [79.93956757, 12.15013981], [79.93956757, 12.14985943], [79.93930817, 12.14986229], [79.93930817, 12.14930534], [79.93902588, 12.14931011], [79.93902588, 12.14904118], [79.93875122, 12.14904118], [79.93875122, 12.14874935], [79.93846893, 12.14874935], [79.93846893, 12.14847088], [79.93819427, 12.14847088], [79.93819427, 12.14791679], [79.93791962, 12.14791965], [79.93791962, 12.14735889], [79.93736267, 12.1473608], [79.93736267, 12.14708328], [79.93708038, 12.14708328], [79.93708038, 12.14652729], [79.9367981, 12.1465292], [79.9367981, 12.14625072], [79.93653107, 12.14625072], [79.93653107, 12.14514065], [79.93624878, 12.14514065], [79.93624878, 12.14458084], [79.93541718, 12.14458275], [79.93541718, 12.14430523], [79.93514252, 12.1443119], [79.93514252, 12.14375114], [79.93486023, 12.14375114], [79.93486023, 12.14346886], [79.93458557, 12.14347267], [79.93458557, 12.14291668], [79.93430328, 12.14291668], [79.93430328, 12.1418047], [79.93402863, 12.14180946], [79.93402863, 12.14153099], [79.9337616, 12.14153099], [79.9337616, 12.14125061], [79.93347168, 12.14125061], [79.93347168, 12.14068985], [79.93319702, 12.14069462], [79.93319702, 12.1404171], [79.9329071, 12.14042091], [79.9329071, 12.13985157], [79.93264008, 12.13986111], [79.93264008, 12.13875103], [79.93235779, 12.13875103], [79.93235779, 12.1384697], [79.93180847, 12.13847256], [79.93180847, 12.13819504], [79.93125153, 12.13819504], [79.93125153, 12.13763905], [79.93152618, 12.13764095], [79.93152618, 12.13735962], [79.93180847, 12.13735962], [79.93180847, 12.1370821], [79.93152618, 12.1370821], [79.93152618, 12.13652897], [79.93125153, 12.13653088], [79.93125153, 12.13625145], [79.93096924, 12.13625145], [79.93096924, 12.13568974], [79.93069458, 12.13569355], [79.93069458, 12.13541603], [79.93041992, 12.1354208], [79.93041992, 12.13457966], [79.93013763, 12.13458538], [79.93013763, 12.13430595], [79.92986298, 12.13431072], [79.92986298, 12.13404179], [79.92958069, 12.13404179], [79.92958069, 12.13374996], [79.92930603, 12.13374996], [79.92930603, 12.13346958], [79.92903137, 12.13347244], [79.92903137, 12.13291645], [79.92874908, 12.13292122], [79.92874908, 12.13264275], [79.9284668, 12.13264275], [79.9284668, 12.13208199], [79.92819214, 12.13208199], [79.92819214, 12.13180637], [79.92791748, 12.13181114], [79.92791748, 12.13125038], [79.92762756, 12.13125038], [79.92762756, 12.13068867], [79.92736053, 12.13069439], [79.92736053, 12.13041592], [79.92708588, 12.13042068], [79.92708588, 12.12985992], [79.92679596, 12.12985992], [79.92679596, 12.12957954], [79.92652893, 12.12958431], [79.92652893, 12.12902832], [79.92624664, 12.12903023], [79.92624664, 12.12847042], [79.92597198, 12.12847233], [79.92597198, 12.12819386], [79.92569733, 12.12819386], [79.92569733, 12.12763786], [79.92542267, 12.12763977], [79.92542267, 12.12708187], [79.92514038, 12.12708378], [79.92514038, 12.12680626], [79.92485809, 12.12681007], [79.92485809, 12.12625027], [79.92456818, 12.12625027], [79.92456818, 12.12597179], [79.92430878, 12.12597179], [79.92430878, 12.12541962], [79.92402649, 12.12541962], [79.92402649, 12.12487125], [79.92375183, 12.12487125], [79.92375183, 12.12458134], [79.92346954, 12.1245842], [79.92346954, 12.12402821], [79.92318726, 12.12403202], [79.92318726, 12.12347126], [79.92292023, 12.12347126], [79.92292023, 12.12319565], [79.92263794, 12.12319565], [79.92263794, 12.12263966], [79.92236328, 12.12263966], [79.92236328, 12.1220789], [79.92208099, 12.12208271], [79.92208099, 12.12180519], [79.92182159, 12.12180996], [79.92182159, 12.1212492], [79.92152405, 12.1212492], [79.92152405, 12.12097359], [79.92124939, 12.12097359], [79.92124939, 12.12041664], [79.9209671, 12.12042046], [79.9209671, 12.11986065], [79.92069244, 12.11986065], [79.92069244, 12.11931038], [79.92041779, 12.11931038], [79.92041779, 12.11875057], [79.92014313, 12.11875057], [79.92014313, 12.11847115], [79.91986084, 12.11847115], [79.91986084, 12.11819458], [79.91958618, 12.11819458], [79.91958618, 12.11791706], [79.91929626, 12.11792183], [79.91929626, 12.11764145], [79.91902924, 12.11764145], [79.91902924, 12.11708069], [79.91874695, 12.1170826], [79.91874695, 12.1165266], [79.91847229, 12.11653137], [79.91847229, 12.11597061], [79.91819763, 12.11597347], [79.91819763, 12.11541653], [79.91792297, 12.11541939], [79.91792297, 12.11486053], [79.91764069, 12.11486053], [79.91764069, 12.11430454], [79.9173584, 12.11430931], [79.9173584, 12.11375141], [79.91707611, 12.11375141], [79.91707611, 12.1131897], [79.91680908, 12.11319542], [79.91680908, 12.11291695], [79.91652679, 12.1129303], [79.91652679, 12.11236095], [79.91625214, 12.11236095], [79.91625214, 12.11181068], [79.91596985, 12.11181068], [79.91596985, 12.11153126], [79.91568756, 12.11153126], [79.91568756, 12.11096954], [79.9154129, 12.11097336], [79.9154129, 12.11041737], [79.91513824, 12.11042118], [79.91513824, 12.1101408], [79.91485596, 12.1101408], [79.91485596, 12.10958004], [79.9145813, 12.10958195], [79.9145813, 12.10902882], [79.91430664, 12.10903072], [79.91430664, 12.10875034], [79.91401672, 12.10875034], [79.91401672, 12.10846996], [79.91374969, 12.10847187], [79.91374969, 12.10791588], [79.91348267, 12.10792065], [79.91348267, 12.10764122], [79.91319275, 12.10764122], [79.91319275, 12.10736275], [79.91291809, 12.10736275], [79.91291809, 12.10681057], [79.91262817, 12.10681057], [79.91262817, 12.10653114], [79.91236115, 12.10653114], [79.91236115, 12.10569191], [79.91208649, 12.10569382], [79.91208649, 12.10513783], [79.91179657, 12.10513973], [79.91179657, 12.10458183], [79.91152954, 12.10458374], [79.91152954, 12.10430622], [79.91124725, 12.10431099], [79.91124725, 12.10374069], [79.9109726, 12.10375023], [79.9109726, 12.10347176], [79.91069794, 12.10347176], [79.91069794, 12.10291576], [79.91042328, 12.10291958], [79.91042328, 12.10264015], [79.91014099, 12.10264015], [79.91014099, 12.10207939], [79.9098587, 12.10208416], [79.9098587, 12.10180569], [79.90959167, 12.10181141], [79.90959167, 12.10153008], [79.90930176, 12.10153008], [79.90930176, 12.10097027], [79.9090271, 12.10097218], [79.9090271, 12.1006937], [79.90875244, 12.1006937], [79.90875244, 12.10013771], [79.90847015, 12.10013962], [79.90847015, 12.09986019], [79.9081955, 12.0998621], [79.9081955, 12.09930611], [79.9070816, 12.09930992], [79.9070816, 12.09902954], [79.9068222, 12.09902954], [79.9068222, 12.09847164], [79.90652466, 12.09847164], [79.90652466, 12.0979147], [79.90625, 12.09793091], [79.90625, 12.09764194], [79.90598297, 12.09764194], [79.90598297, 12.09708118], [79.90569305, 12.09708405], [79.90569305, 12.09680557], [79.9054184, 12.09681034], [79.9054184, 12.09624863], [79.90513611, 12.09624863], [79.90513611, 12.0959692], [79.90486145, 12.09597111], [79.90486145, 12.09541798], [79.90458679, 12.09542179], [79.90458679, 12.09514046], [79.90429688, 12.09514046], [79.90429688, 12.09458065], [79.90402985, 12.09458256], [79.90402985, 12.09402657], [79.90374756, 12.09403038], [79.90374756, 12.09375191], [79.90345764, 12.09375191], [79.90345764, 12.09319115], [79.90319824, 12.09319305], [79.90319061, 12.09263897], [79.90291595, 12.09264183], [79.90291595, 12.09236145], [79.9026413, 12.09236145], [79.9026413, 12.09180546], [79.90235901, 12.09180546], [79.90235901, 12.09125137], [79.90207672, 12.09125137], [79.90207672, 12.09097099], [79.90180206, 12.09097099], [79.90180206, 12.09041691], [79.9015274, 12.09042168], [79.9015274, 12.0901413], [79.90125275, 12.0901413], [79.90125275, 12.08958054], [79.90097046, 12.0895834], [79.90097046, 12.0890274], [79.90068817, 12.08902931], [79.90068817, 12.08874035], [79.90041351, 12.08874893], [79.90041351, 12.08819485], [79.90013885, 12.08819485], [79.90013885, 12.08763885], [79.89985657, 12.08763885], [79.89985657, 12.08736134], [79.89958191, 12.08736134], [79.89958191, 12.08680534], [79.89930725, 12.08681202], [79.89930725, 12.08625126], [79.89901733, 12.08625126], [79.89901733, 12.08570194], [79.89875031, 12.08570194], [79.89875031, 12.08542061], [79.89848328, 12.08542061], [79.89848328, 12.0848608], [79.89819336, 12.0848608], [79.89819336, 12.08430672], [79.8979187, 12.08431053], [79.8979187, 12.08375072], [79.89765167, 12.08375072], [79.89765167, 12.08347034], [79.89736176, 12.08347321], [79.89736176, 12.08291626], [79.8970871, 12.08292103], [79.8970871, 12.08236027], [79.89680481, 12.08236027], [79.89680481, 12.08180428], [79.89653015, 12.08181095], [79.89653015, 12.08125019], [79.89624786, 12.08125019], [79.89624786, 12.08097172], [79.89597321, 12.08097172], [79.89597321, 12.08041573], [79.89569092, 12.08042145], [79.89569092, 12.07985973], [79.89541626, 12.07985973], [79.89541626, 12.07931137], [79.8951416, 12.07931137], [79.8951416, 12.07903099], [79.89485931, 12.07903099], [79.89485931, 12.07847023], [79.89458466, 12.07847214], [79.89458466, 12.07791615], [79.89430237, 12.07792091], [79.89430237, 12.07736015], [79.89402771, 12.07736206], [79.89402771, 12.07708359], [79.89375305, 12.07708359], [79.89375305, 12.0765276], [79.89347076, 12.07653046], [79.89347076, 12.07625008], [79.89319611, 12.07625008], [79.89319611, 12.07568932], [79.89291382, 12.07569408], [79.89291382, 12.07541561], [79.89263916, 12.07542038], [79.89263916, 12.07485962], [79.8923645, 12.07486153], [79.8923645, 12.07458401], [79.89208221, 12.07458401], [79.89208221, 12.07402802], [79.89180756, 12.07402992], [79.89180756, 12.07376099], [79.89151764, 12.07376099], [79.89151764, 12.07319069], [79.89125061, 12.07319355], [79.89125061, 12.07291794], [79.89097595, 12.07291985], [79.89097595, 12.07236195], [79.89068604, 12.07236195], [79.89068604, 12.07208061], [79.89041901, 12.07208443], [79.89041901, 12.07152843], [79.89013672, 12.07153034], [79.89013672, 12.07125187], [79.88986206, 12.07125187], [79.88986206, 12.07097244], [79.88957977, 12.07097244], [79.88957977, 12.07041454], [79.88931274, 12.07042027], [79.88931274, 12.07014179], [79.88903046, 12.07014179], [79.88903046, 12.06985855], [79.88874817, 12.06986237], [79.88874817, 12.06958389], [79.88847351, 12.06958389], [79.88847351, 12.06902695], [79.88819122, 12.06902981], [79.88819122, 12.06874943], [79.88791656, 12.06874943], [79.88791656, 12.06847095], [79.88764191, 12.06847095], [79.88764191, 12.06791782], [79.88735962, 12.06791973], [79.88735962, 12.06763268], [79.88708496, 12.06763935], [79.88708496, 12.06736088], [79.88680267, 12.06736088], [79.88680267, 12.06708145], [79.88652802, 12.06708336], [79.88652802, 12.06652737], [79.88625336, 12.06653023], [79.88625336, 12.06624889], [79.88597107, 12.06624889], [79.88597107, 12.06597137], [79.88569641, 12.06597328], [79.88569641, 12.06569481], [79.88541412, 12.06569481], [79.88541412, 12.06513882], [79.88513947, 12.06514168], [79.88513947, 12.0648613], [79.88486481, 12.0648613], [79.88486481, 12.06319523], [79.88458252, 12.06319523], [79.88458252, 12.06236076], [79.88430786, 12.06236076], [79.88430786, 12.06208324], [79.88346863, 12.06208324], [79.88346863, 12.06152916], [79.88318634, 12.06153107], [79.88318634, 12.06097126], [79.88291931, 12.06097317], [79.88291931, 12.06041718], [79.88265228, 12.06042099], [79.88265228, 12.05931091], [79.88236237, 12.05931091], [79.88236237, 12.05846977], [79.88208008, 12.05847263], [79.88208008, 12.05791664], [79.88181305, 12.05792141], [79.88181305, 12.05764103], [79.88153076, 12.05764103], [79.88153076, 12.05736065], [79.88124847, 12.05736065], [79.88124847, 12.05681133], [79.88096619, 12.05681133], [79.88096619, 12.05625057], [79.88069153, 12.05625057], [79.88069153, 12.05569172], [79.88041687, 12.05569363], [79.88041687, 12.05513763], [79.88014221, 12.05514145], [79.88014221, 12.05457973], [79.87985992, 12.05458546], [79.87985992, 12.05375004], [79.87957764, 12.05375004], [79.87957764, 12.05319023], [79.87930298, 12.05319405], [79.87930298, 12.05263805], [79.87902832, 12.05263805], [79.87902832, 12.05208206], [79.87875366, 12.05208206], [79.87875366, 12.05180645], [79.87930298, 12.05181122], [79.87930298, 12.05125046], [79.87902832, 12.05125046], [79.87902832, 12.05097198], [79.87847137, 12.05097198], [79.87847137, 12.05069447], [79.87819672, 12.05069447], [79.87819672, 12.05013847], [79.8779068, 12.05014038], [79.8779068, 12.04959106], [79.87763977, 12.04959106], [79.87763977, 12.0490303], [79.87735748, 12.0490303], [79.87735748, 12.04846954], [79.87708282, 12.0484724], [79.87708282, 12.04763794], [79.87680817, 12.04763985], [79.87680817, 12.04708195], [79.87652588, 12.04708385], [79.87652588, 12.04652786], [79.87625122, 12.04652977], [79.87625122, 12.04597187], [79.87596893, 12.04597187], [79.87596893, 12.04541779], [79.87568665, 12.04541969], [79.87568665, 12.04458141], [79.87541962, 12.04458427], [79.87541962, 12.04402828], [79.87513733, 12.04403019], [79.87513733, 12.04345989], [79.87486267, 12.04347134], [79.87486267, 12.04291534], [79.87458038, 12.04292011], [79.87458038, 12.04235935], [79.87430573, 12.04236221], [79.87430573, 12.04180527], [79.87403107, 12.04181004], [79.87403107, 12.04124928], [79.87374878, 12.04124928], [79.87374878, 12.04069138], [79.87347412, 12.04069328], [79.87347412, 12.0401392], [79.87319183, 12.0401392], [79.87319183, 12.0395813], [79.87291718, 12.03958321], [79.87291718, 12.03902721], [79.87264252, 12.03903198], [79.87264252, 12.03847122], [79.87236023, 12.03847122], [79.87236023, 12.03791714], [79.8720932, 12.03792191], [79.8720932, 12.03765106], [79.87180328, 12.03765106], [79.87180328, 12.03736115], [79.87152863, 12.03736115], [79.87152863, 12.03708267], [79.87124634, 12.03708267], [79.87124634, 12.03652668], [79.87097168, 12.0365324], [79.87097168, 12.03541946], [79.87071228, 12.03541946], [79.87071228, 12.03486061], [79.87041473, 12.03486061], [79.87041473, 12.03402901], [79.87014008, 12.03403091], [79.87014008, 12.03347111], [79.86985779, 12.03347301], [79.86985779, 12.03291702], [79.86958313, 12.03292084], [79.86958313, 12.03236103], [79.86930847, 12.03236103], [79.86930847, 12.03181076], [79.86902618, 12.03181076], [79.86902618, 12.03125095], [79.86875153, 12.03125095], [79.86875153, 12.03069019], [79.86846924, 12.03069496], [79.86846924, 12.02930355], [79.86818695, 12.02931118], [79.86818695, 12.0290308], [79.86791992, 12.0290308], [79.86791992, 12.02846146], [79.86763763, 12.0284729], [79.86763763, 12.02819443], [79.86736298, 12.02819443], [79.86736298, 12.02791595], [79.86708069, 12.02792072], [79.86708069, 12.02735996], [79.86680603, 12.02735996], [79.86680603, 12.02681065], [79.86653137, 12.02681065], [79.86653137, 12.02625275], [79.86624908, 12.02625275], [79.86624908, 12.02597046], [79.86597443, 12.02597237], [79.86597443, 12.0251379], [79.86569214, 12.02514267], [79.86569214, 12.02402973], [79.86541748, 12.02402973], [79.86541748, 12.02318859], [79.86513519, 12.02319431], [79.86513519, 12.02264023], [79.86486053, 12.02265167], [79.86486053, 12.02235985], [79.86458588, 12.02235985], [79.86458588, 12.02208424], [79.86430359, 12.02208424], [79.86430359, 12.02152824], [79.86402893, 12.02153015], [79.86402893, 12.02069187], [79.86374664, 12.02069378], [79.86374664, 12.01930618], [79.86347198, 12.01931], [79.86347198, 12.01846886], [79.86319733, 12.01847172], [79.86319733, 12.01791573], [79.86292267, 12.01791954], [79.86292267, 12.01736164], [79.86264038, 12.01736164], [79.86264038, 12.01708126], [79.86235809, 12.01708412], [79.86235809, 12.01680565], [79.86207581, 12.01681042], [79.86207581, 12.01596928], [79.86180878, 12.01597118], [79.86180878, 12.01569557], [79.86152649, 12.01569557], [79.86152649, 12.01541805], [79.86125183, 12.01541996], [79.86125183, 12.01513958], [79.86096954, 12.01513958], [79.86096954, 12.01458073], [79.86069489, 12.01458263], [79.86069489, 12.01402664], [79.86042023, 12.01403046], [79.86042023, 12.01375198], [79.86013794, 12.01375198], [79.86013794, 12.01292038], [79.85986328, 12.01292038], [79.85986328, 12.0118103], [79.85958099, 12.0118103], [79.85958099, 12.01153183], [79.85930634, 12.01153183], [79.85930634, 12.01069069], [79.85902405, 12.01069546], [79.85902405, 12.01013947], [79.85874939, 12.01014137], [79.85874939, 12.00986099], [79.85901642, 12.00986099], [79.85901642, 12.00958061], [79.85930634, 12.00958347], [79.85930634, 12.00902653], [79.85874939, 12.0090313], [79.85874939, 12.00847054], [79.85847473, 12.0084734], [79.85847473, 12.00763893], [79.85819244, 12.00764084], [79.85819244, 12.00680923], [79.85791779, 12.00680923], [79.85791779, 12.00597095], [79.8576355, 12.00597286], [79.8576355, 12.00541687], [79.85736084, 12.00542068], [79.85736084, 12.00486088], [79.85708618, 12.00486088], [79.85708618, 12.00457954], [79.85680389, 12.00458336], [79.85680389, 12.0037508], [79.85652924, 12.0037508], [79.85652924, 12.00347042], [79.85624695, 12.00347328], [79.85624695, 12.00291729], [79.85597229, 12.0029211], [79.85597229, 12.00264072], [79.85624695, 12.00264072], [79.85624695, 12.00207996], [79.85597229, 12.00208473], [79.85597229, 12.00180435], [79.85569763, 12.00181103], [79.85569763, 12.00014114], [79.85542297, 12.00014114], [79.85542297, 11.99986267], [79.85542297, 11.99931145], [79.85514069, 11.99931145], [79.85514069, 11.99874973], [79.8548584, 11.99874973], [79.8548584, 11.99819183], [79.85458374, 11.99819374], [79.85458374, 11.99763775], [79.85430908, 11.99763966], [79.85430908, 11.99707985], [79.85402679, 11.99708366], [79.85402679, 11.99652767], [79.85375214, 11.99652958], [79.85375214, 11.99597168], [79.85346985, 11.99597168], [79.85346985, 11.9948616], [79.85319519, 11.9948597], [79.85319519, 11.99430561], [79.8529129, 11.99431133], [79.8529129, 11.99403], [79.85320282, 11.99403], [79.85320282, 11.99374962], [79.8529129, 11.99374962], [79.8529129, 11.99347019], [79.85263824, 11.9934721], [79.85263824, 11.99263763], [79.85234833, 11.99263954], [79.85234833, 11.99208164], [79.8520813, 11.99208355], [79.8520813, 11.99097157], [79.85180664, 11.99097157], [79.85180664, 11.99069405], [79.85152435, 11.99069405], [79.85152435, 11.99041462], [79.85124969, 11.99042034], [79.85124969, 11.98931026], [79.85098267, 11.98931026], [79.85098267, 11.98903179], [79.85069275, 11.98903179], [79.85069275, 11.98874855], [79.8501358, 11.98874855], [79.8501358, 11.98847103], [79.84986115, 11.98847103], [79.84986115, 11.98819256], [79.84958649, 11.98819256], [79.84958649, 11.98764038], [79.84928894, 11.98764038], [79.84928894, 11.98654079], [79.84986115, 11.98654079], [79.84986115, 11.98569107], [79.84958649, 11.98569489], [79.84958649, 11.9845829], [79.8493042, 11.9845829], [79.8493042, 11.9837513], [79.84902954, 11.9837513], [79.84902954, 11.9829216], [79.84874725, 11.9829216], [79.84874725, 11.98208141], [79.84819794, 11.98208332], [79.84819794, 11.98124886], [79.84791565, 11.98124886], [79.84791565, 11.98069477], [79.84764099, 11.98069477], [79.84764099, 11.98041725], [79.8473587, 11.98041725], [79.8473587, 11.98013878], [79.84707642, 11.98014069], [79.84707642, 11.97819042], [79.84680176, 11.97819519], [79.84680176, 11.97708321], [79.8465271, 11.97708321], [79.8465271, 11.97680664], [79.84625244, 11.97681141], [79.84625244, 11.97625065], [79.84597015, 11.97625065], [79.84597015, 11.97403145], [79.84570313, 11.97403145], [79.84570313, 11.97375011], [79.84541321, 11.97375011], [79.84541321, 11.97346973], [79.84513855, 11.97347164], [79.84513855, 11.97208214], [79.84486389, 11.97208214], [79.84486389, 11.97069359], [79.8445816, 11.97069359], [79.8445816, 11.96930599], [79.84430695, 11.96931076], [79.84430695, 11.96875], [79.84348297, 11.96875], [79.84348297, 11.96763992], [79.84375, 11.96763992], [79.84375, 11.96735954], [79.84402466, 11.9673624], [79.84402466, 11.96708393], [79.84375, 11.96708393], [79.84375, 11.96680641], [79.84348297, 11.96681023], [79.84348297, 11.96569061], [79.84319305, 11.96569443], [79.84319305, 11.96458435], [79.84263611, 11.96458435], [79.84263611, 11.96430588], [79.84236145, 11.96430969], [79.84236145, 11.96347237], [79.84263611, 11.96347237], [79.84263611, 11.9631958], [79.84236145, 11.9631958], [79.84236145, 11.96208382], [79.84208679, 11.96208382], [79.84208679, 11.96124935], [79.84179688, 11.96124935], [79.84179688, 11.96013927], [79.84152985, 11.96013927], [79.84152985, 11.95875072], [79.84124756, 11.95875072], [79.84124756, 11.95792198], [79.8409729, 11.95792198], [79.8409729, 11.95708084], [79.84069824, 11.95708275], [79.84069061, 11.95625114], [79.84041595, 11.95625114], [79.84041595, 11.95458317], [79.8401413, 11.95458317], [79.8401413, 11.95319462], [79.83985901, 11.95319462], [79.83985901, 11.95263863], [79.8401413, 11.95264053], [79.8401413, 11.95207977], [79.83985901, 11.95208263], [79.83985901, 11.95125103], [79.83957672, 11.95125103], [79.83957672, 11.95042992], [79.83930206, 11.95042992], [79.83930206, 11.95014095], [79.8390274, 11.95014095], [79.8390274, 11.94958019], [79.83875275, 11.94958305], [79.83875275, 11.94930363], [79.8390274, 11.94931126], [79.8390274, 11.94903088], [79.83875275, 11.94903088], [79.83875275, 11.94791889], [79.83847046, 11.94791889], [79.83847046, 11.94707966], [79.8381958, 11.94708538], [79.8381958, 11.94680691], [79.83847046, 11.94681072], [79.83847046, 11.9465313], [79.8381958, 11.9465313], [79.8381958, 11.94542122], [79.83790588, 11.94542122], [79.83790588, 11.94403267], [79.83763885, 11.94403267], [79.83763885, 11.94375038], [79.83790588, 11.94375038], [79.83790588, 11.94347], [79.83763885, 11.94347191], [79.83763885, 11.9426403], [79.83790588, 11.9426403], [79.83790588, 11.94235992], [79.83763885, 11.94235992], [79.83763885, 11.94054985], [79.83069611, 11.94024944], [79.82540131, 11.94014931], [79.82540131, 11.94001007], [79.81800079, 11.94039059], [79.81420135, 11.94062138], [79.8110199, 11.94250965], [79.8081131, 11.94651031], [79.80632782, 11.95526886], [79.80602264, 11.95922089], [79.80458832, 11.96314144], [79.79972839, 11.96428967], [79.7979126, 11.96352196], [79.79527283, 11.96189022], [79.79242706, 11.95705128], [79.79165649, 11.94774055], [79.79030609, 11.94255066], [79.78756714, 11.9383707], [79.78333282, 11.94373035], [79.77879333, 11.94640064], [79.77575684, 11.94601059], [79.77272034, 11.9467907], [79.77181244, 11.94640064], [79.76937866, 11.94145107], [79.76544952, 11.93916035], [79.76420593, 11.93459034], [79.75814056, 11.93040085], [79.74784088, 11.92890167], [79.7472229, 11.91783047], [79.74751282, 11.91516113], [79.7408371, 11.90945053], [79.74053955, 11.90716076], [79.73690033, 11.9071703], [79.73658752, 11.91020966], [79.73690033, 11.92739105], [79.73356628, 11.93729973], [79.73361206, 11.94721031], [79.7144928, 11.95525074], [79.71570587, 11.9674511], [79.71790314, 11.96887112], [79.72209167, 11.96743965], [79.72692108, 11.96249199], [79.73544312, 11.96361065], [79.73816681, 11.9670496], [79.74240875, 11.96704102], [79.74513245, 11.97085094], [79.74906921, 11.97236919], [79.75244141, 11.97612953], [79.75260925, 11.97945976], [79.74964905, 11.98613071], [79.73468018, 11.99431133], [79.72899628, 11.98602104], [79.72885895, 11.98602104], [79.72711182, 11.97996998], [79.72493744, 11.97790146], [79.71985626, 11.97646046], [79.71695709, 11.97544193], [79.71259308, 11.97563076], [79.7098999, 11.97622108], [79.70584869, 11.97737026], [79.70359039, 11.98005009], [79.7016983, 11.98608971], [79.69539642, 11.99268055], [79.69075775, 11.99627972], [79.69048309, 12.00112057], [79.69242096, 12.01107121], [79.69155884, 12.0174408], [79.679039, 12.01926041], [79.67645264, 12.0128603], [79.67151642, 12.01162148], [79.66890717, 12.00729179], [79.66326141, 12.00638103], [79.65930939, 11.99689102], [79.65236664, 11.99830055], [79.64731598, 11.99722958], [79.6470108, 11.99332142], [79.64434052, 11.99267197], [79.64441681, 11.98627186], [79.64428711, 11.98627186], [79.64234161, 11.975811], [79.64420319, 11.97321033], [79.65122223, 11.97201061], [79.65960693, 11.97705078], [79.66143036, 11.97285938], [79.6653595, 11.96752167], [79.67114258, 11.97476006], [79.67344666, 11.97236919], [79.67749786, 11.97399044], [79.68113708, 11.97284126], [79.68416595, 11.97472954], [79.68689728, 11.9739809], [79.68997955, 11.9756403], [79.69480133, 11.97511101], [79.6990509, 11.97205925], [79.69921875, 11.97003078], [79.69525909, 11.96103096], [79.70192719, 11.95643139], [79.70155334, 11.95218086], [79.69315338, 11.95079041], [79.68667603, 11.94728088], [79.68543243, 11.9451704], [79.68312836, 11.94650078], [79.68148041, 11.94336033], [79.6776886, 11.93935108], [79.67819977, 11.93653202], [79.68414307, 11.92722034], [79.69023895, 11.92618275], [79.69200134, 11.92448044], [79.69277954, 11.9211998], [79.69782257, 11.91668129], [79.69608307, 11.92010021], [79.69451141, 11.92593193], [79.6946106, 11.93133068], [79.6964798, 11.93245029], [79.7060318, 11.92870998], [79.70407867, 11.91299057], [79.72489929, 11.89151001], [79.71750641, 11.88924026], [79.71601868, 11.8866806], [79.71692657, 11.87684155], [79.71537018, 11.87497044], [79.70831299, 11.87395191], [79.70437622, 11.87460136], [79.70173645, 11.87654972], [79.69153595, 11.8784008], [79.69168854, 11.89777088], [79.70250702, 11.89843178], [79.70258331, 11.90250015], [79.68286133, 11.90470886], [79.67983246, 11.89344978], [79.68229675, 11.89185047], [79.68382263, 11.88745975], [79.6799469, 11.88615036], [79.68065643, 11.8819418], [79.67987061, 11.87926197], [79.67591095, 11.87932968], [79.6687088, 11.87463093], [79.66821289, 11.87625122], [79.66036987, 11.87732029], [79.65907288, 11.87212181], [79.65907288, 11.86566925], [79.67118073, 11.86660099], [79.67090607, 11.86983109], [79.67315674, 11.86995029], [79.67838287, 11.86957073], [79.68036652, 11.87062168], [79.68205261, 11.87335014], [79.69050598, 11.87406063], [79.69573212, 11.87337971], [79.69345093, 11.85389137], [79.69766998, 11.85242081], [79.70379639, 11.83829021], [79.70668793, 11.84708977], [79.71798706, 11.84762955], [79.71817017, 11.84836197], [79.73034668, 11.84687996], [79.72776031, 11.83233929], [79.73840332, 11.83500099], [79.73944855, 11.84986115], [79.74339294, 11.85363102], [79.74363708, 11.85972118], [79.74980927, 11.8605299], [79.75099945, 11.85894966], [79.75495148, 11.85783958], [79.7557373, 11.85046959], [79.75393677, 11.84224033], [79.7515564, 11.84166145], [79.75028229, 11.83598137], [79.74871063, 11.83584023], [79.74730682, 11.83270168], [79.75213623, 11.82445145], [79.75811005, 11.82210064], [79.76043701, 11.82303143], [79.76360321, 11.83250999], [79.76539612, 11.83333111], [79.76712036, 11.84047985], [79.77849579, 11.83882999], [79.78176117, 11.840271], [79.78616333, 11.83840179], [79.78787231, 11.83508968], [79.79097748, 11.83181], [79.79402161, 11.83020973], [79.79176331, 11.82697201], [79.79281616, 11.81945992], [79.79296875, 11.81764984], [79.79397583, 11.81564045], [79.79682159, 11.81153965], [79.80041504, 11.8083992], [79.80041504, 11.80764008], [79.80069733, 11.80764008], [79.80069733, 11.80708027], [79.80041504, 11.80708408], [79.80041504, 11.80652809], [79.80014038, 11.80653], [79.80014038, 11.80568027], [79.79958344, 11.80569363], [79.79958344, 11.80513763], [79.79930878, 11.80513954], [79.79930878, 11.80263996], [79.79902649, 11.80263996], [79.79902649, 11.80181026], [79.79875183, 11.80181026], [79.79875183, 11.80125046], [79.79846954, 11.80125046], [79.79846954, 11.7990303], [79.79820251, 11.7990303], [79.79820251, 11.79875183], [79.79763794, 11.79875183], [79.79763794, 11.79653168], [79.79736328, 11.79653168], [79.79736328, 11.79347134], [79.79708099, 11.79347324], [79.79708099, 11.79263878], [79.79680634, 11.79264069], [79.79680634, 11.79181194], [79.79708099, 11.79181194], [79.79708099, 11.79014111], [79.79680634, 11.79014111], [79.79680634, 11.78903103], [79.79651642, 11.78903103], [79.79651642, 11.78875065], [79.79680634, 11.78875065], [79.79680634, 11.78736019], [79.79652405, 11.78736019], [79.79652405, 11.78625107], [79.79624939, 11.78625107], [79.79624939, 11.78514099], [79.7959671, 11.78514099], [79.7959671, 11.78431129], [79.79569244, 11.78431129], [79.79569244, 11.78374958], [79.79543304, 11.78374958], [79.79543304, 11.78318977], [79.79486084, 11.78319359], [79.79486084, 11.78291607], [79.79458618, 11.78292084], [79.79458618, 11.78236008], [79.79569244, 11.78236008], [79.79569244, 11.77874088], [79.79541779, 11.77875042], [79.79541779, 11.77764034], [79.79514313, 11.77764034], [79.79514313, 11.77596855], [79.79541779, 11.77597237], [79.79541779, 11.77513981], [79.7951355, 11.77513981], [79.7951355, 11.77486229], [79.79458618, 11.77486229], [79.79458618, 11.77319336], [79.79430389, 11.77319336], [79.79430389, 11.77152729], [79.79402924, 11.77153015], [79.79402924, 11.77042198], [79.79429626, 11.77042198], [79.79429626, 11.76986122], [79.79402924, 11.76986122], [79.79402924, 11.76930523], [79.79429626, 11.7693119], [79.79429626, 11.76903152], [79.79402924, 11.76903152], [79.79402924, 11.76791859], [79.79374695, 11.76791859], [79.79374695, 11.76764107], [79.79347229, 11.76764107], [79.79347229, 11.76679993], [79.79319763, 11.7668047], [79.79319763, 11.76569462], [79.79291534, 11.76569462], [79.79291534, 11.76375103], [79.79264069, 11.76375961], [79.79264069, 11.76347065], [79.79291534, 11.76347256], [79.79291534, 11.76291656], [79.79264069, 11.76292133], [79.79264069, 11.76264095], [79.7923584, 11.76264095], [79.7923584, 11.76208019], [79.79208374, 11.76208305], [79.79208374, 11.76180458], [79.79180908, 11.76181126], [79.79180908, 11.76069927], [79.79152679, 11.76069927], [79.79152679, 11.75957966], [79.79125214, 11.75958157], [79.79125214, 11.75791645], [79.79096985, 11.75792122], [79.79096985, 11.75681114], [79.79070282, 11.75681114], [79.79070282, 11.75597], [79.7904129, 11.75597191], [79.7904129, 11.7551403], [79.79013824, 11.7551403], [79.79013824, 11.75431061], [79.78985596, 11.75431061], [79.78985596, 11.75319195], [79.7895813, 11.75319386], [79.7895813, 11.74819565], [79.78930664, 11.74819565], [79.78930664, 11.74791527], [79.78900909, 11.74792004], [79.78900909, 11.74597073], [79.78874969, 11.74597359], [79.78874969, 11.74430466], [79.78848267, 11.74431038], [79.78848267, 11.74319077], [79.78819275, 11.74319458], [79.78819275, 11.74291706], [79.78791809, 11.74292183], [79.78791809, 11.74263], [79.7876358, 11.74263859], [79.7876358, 11.7420826], [79.78736115, 11.7420826], [79.78736115, 11.74124908], [79.7876358, 11.74125099], [79.7876358, 11.74041939], [79.78736115, 11.74041939], [79.78736115, 11.73903084], [79.78708649, 11.73903084], [79.78708649, 11.73764133], [79.78679657, 11.73764133], [79.78679657, 11.73653126], [79.78652954, 11.73653126], [79.78652954, 11.73597145], [79.78624725, 11.73597336], [79.78624725, 11.73513889], [79.7859726, 11.7351408], [79.7859726, 11.7343092], [79.78569794, 11.7343092], [79.78569794, 11.7337513], [79.78541565, 11.7337513], [79.78541565, 11.7331953], [79.78514099, 11.7331953], [79.78514099, 11.73291588], [79.78542328, 11.73292065], [79.78542328, 11.73236275], [79.78514099, 11.73236275], [79.78514099, 11.73208046], [79.7848587, 11.73208237], [79.7848587, 11.73124981], [79.78457642, 11.73125267], [79.78457642, 11.72931099], [79.78430176, 11.72931099], [79.78430176, 11.72792053], [79.7840271, 11.72792053], [79.7840271, 11.72708035], [79.78375244, 11.72708416], [79.78375244, 11.7256937], [79.78347015, 11.7256937], [79.78347015, 11.72541809], [79.78320313, 11.72542], [79.78320313, 11.72513962], [79.78291321, 11.72513962], [79.78291321, 11.72459126], [79.78263855, 11.72459126], [79.78263855, 11.72375202], [79.78291321, 11.72375202], [79.78291321, 11.72319126], [79.78263855, 11.72319412], [79.78263855, 11.72208405], [79.78236389, 11.72208405], [79.78236389, 11.72180557], [79.7820816, 11.72181034], [79.7820816, 11.72124958], [79.78180695, 11.72124958], [79.78180695, 11.7209692], [79.78152466, 11.72097206], [79.78152466, 11.72069263], [79.78069305, 11.72069263], [79.78069305, 11.72041798], [79.7804184, 11.72042179], [79.7804184, 11.71986198], [79.78069305, 11.71986198], [79.78069305, 11.71958065], [79.78097534, 11.71958447], [79.78097534, 11.71819305], [79.78069305, 11.71819305], [79.78069305, 11.71736145], [79.7804184, 11.71736145], [79.7804184, 11.71708298], [79.78013611, 11.71708298], [79.78013611, 11.71680546], [79.77986145, 11.71681023], [79.77986145, 11.71652889], [79.77958679, 11.71652889], [79.77958679, 11.71597099], [79.77902985, 11.71597099], [79.77902985, 11.71374893], [79.77874756, 11.71375084], [79.77874756, 11.71347141], [79.7784729, 11.71347332], [79.7784729, 11.71236134], [79.77819824, 11.71236134], [79.77819061, 11.71152687], [79.77791595, 11.71153069], [79.77791595, 11.71097088], [79.7776413, 11.71097279], [79.7776413, 11.71013927], [79.77735901, 11.71014118], [79.77735901, 11.7098608], [79.77708435, 11.7098608], [79.77708435, 11.70958328], [79.77625275, 11.70958328], [79.77625275, 11.7098608], [79.77597046, 11.7098608], [79.77597046, 11.71014118], [79.7756958, 11.71013927], [79.7756958, 11.71097279], [79.77540588, 11.71097088], [79.77540588, 11.71125126], [79.77513885, 11.71125126], [79.77513885, 11.71097088], [79.7748642, 11.71097279], [79.7748642, 11.71041679], [79.77458191, 11.71042061], [79.77458191, 11.70847034], [79.7748642, 11.70847321], [79.7748642, 11.70819473], [79.77513885, 11.70819473], [79.77513885, 11.70763874], [79.7756958, 11.70764065], [79.7756958, 11.70736122], [79.77625275, 11.70736122], [79.77625275, 11.70708466], [79.77680206, 11.70708466], [79.77680206, 11.70680428], [79.77735901, 11.70681095], [79.77735901, 11.7059679], [79.77708435, 11.70597267], [79.77708435, 11.7056942], [79.7765274, 11.7056942], [79.7765274, 11.70541573], [79.77680206, 11.70542145], [79.77680206, 11.70431137], [79.7765274, 11.70431137], [79.7765274, 11.70292091], [79.77625275, 11.70292091], [79.77625275, 11.70181084], [79.77597046, 11.70181084], [79.77597046, 11.70042133], [79.7756958, 11.70042133], [79.7756958, 11.69931126], [79.77540588, 11.69931126], [79.77540588, 11.69819164], [79.77513885, 11.69819355], [79.77513885, 11.69680595], [79.77485657, 11.69680977], [79.77485657, 11.69596863], [79.77458191, 11.69597244], [79.77458191, 11.69569397], [79.7748642, 11.69569397], [79.7748642, 11.69541645], [79.77513885, 11.69542027], [79.77513885, 11.69431019], [79.77485657, 11.69431019], [79.77485657, 11.69291973], [79.77458191, 11.69291973], [79.77458191, 11.6926403], [79.77432251, 11.6926403], [79.77432251, 11.69236183], [79.7740097, 11.69236183], [79.7740097, 11.69180965], [79.77432251, 11.69180965], [79.77432251, 11.69124889], [79.77458191, 11.69124889], [79.77458191, 11.69042015], [79.77485657, 11.69042015], [79.77485657, 11.68958092], [79.77458191, 11.68958282], [79.77458191, 11.68930531], [79.77432251, 11.68931198], [79.77432251, 11.6890316], [79.7740097, 11.6890316], [79.7740097, 11.68848038], [79.77375031, 11.68848038], [79.77375031, 11.68403053], [79.77348328, 11.68403053], [79.77348328, 11.68375111], [79.77319336, 11.68375111], [79.77319336, 11.68292141], [79.7729187, 11.68292141], [79.7729187, 11.68181133], [79.77263641, 11.68181133], [79.77263641, 11.68125057], [79.77236176, 11.68125057], [79.77236176, 11.68042088], [79.7720871, 11.68042088], [79.7720871, 11.67903137], [79.77179718, 11.67903137], [79.77179718, 11.67819023], [79.77153015, 11.67819405], [79.77153015, 11.6773634], [79.77124786, 11.6773634], [79.77124786, 11.67625046], [79.77097321, 11.67625046], [79.77097321, 11.67374992], [79.77069092, 11.67374992], [79.77069092, 11.67153263], [79.77041626, 11.67153263], [79.77041626, 11.67041111], [79.7701416, 11.67041588], [79.7701416, 11.6693058], [79.76985931, 11.66930962], [79.76985931, 11.66819096], [79.76958466, 11.66819572], [79.76958466, 11.66736221], [79.76930237, 11.66736221], [79.76930237, 11.66597366], [79.76902771, 11.6659708], [79.76902771, 11.66458321], [79.76875305, 11.66458321], [79.76875305, 11.66319466], [79.76847076, 11.66319466], [79.76847076, 11.66180515], [79.76818848, 11.66181183], [79.76818848, 11.66069126], [79.76791382, 11.66069508], [79.76791382, 11.65930462], [79.76763916, 11.65931034], [79.76763916, 11.65792179], [79.76735687, 11.65792179], [79.76735687, 11.65625095], [79.76708221, 11.65625095], [79.76708221, 11.65514088], [79.76680756, 11.65514088], [79.76680756, 11.65375137], [79.76652527, 11.65375137], [79.76652527, 11.65208244], [79.76625061, 11.65208244], [79.76625061, 11.65041637], [79.76597595, 11.65042114], [79.76597595, 11.64875031], [79.76568604, 11.64875031], [79.76568604, 11.64708042], [79.76541901, 11.64708424], [79.76541901, 11.64541626], [79.76512909, 11.64542007], [79.76512909, 11.64375019], [79.76486206, 11.64375019], [79.76486206, 11.64207935], [79.76457977, 11.64208412], [79.76457977, 11.64041805], [79.76431274, 11.6404314], [79.76431274, 11.63875198], [79.76403046, 11.63875198], [79.76403046, 11.63708115], [79.76374817, 11.63708305], [79.76374817, 11.63625145], [79.76346588, 11.63625145], [79.76346588, 11.63597107], [79.76319122, 11.63597107], [79.76319122, 11.63513947], [79.76291656, 11.63514233], [79.76291656, 11.63458061], [79.76264191, 11.63458347], [79.76264191, 11.63374901], [79.76235962, 11.63375092], [79.76235962, 11.63347054], [79.76264191, 11.6334734], [79.76264191, 11.63319492], [79.76235962, 11.63319111], [79.76235962, 11.6329174], [79.76180267, 11.63291931], [79.76180267, 11.63236141], [79.76152802, 11.63236141], [79.76152802, 11.63208294], [79.76125336, 11.63208294], [79.76125336, 11.63180542], [79.76097107, 11.63180923], [79.76097107, 11.6312418], [79.76125336, 11.63125134], [79.76125336, 11.63041687], [79.76152802, 11.63042068], [79.76152802, 11.62903118], [79.76125336, 11.62903118], [79.76125336, 11.62820244], [79.76097107, 11.62820244], [79.76097107, 11.6273613], [79.76069641, 11.6273613], [79.76069641, 11.62708473], [79.76041412, 11.62708473], [79.76041412, 11.62680435], [79.76013947, 11.62681103], [79.76013947, 11.62597275], [79.76040649, 11.62597275], [79.76040649, 11.62569046], [79.76069641, 11.62569523], [79.76069641, 11.6254158], [79.76040649, 11.62543011], [79.76040649, 11.62514114], [79.76069641, 11.62514114], [79.76069641, 11.62458038], [79.76097107, 11.62458229], [79.76097107, 11.62402821], [79.76069641, 11.62403107], [79.76069641, 11.62374973], [79.76040649, 11.62374973], [79.76040649, 11.62318993], [79.76069641, 11.62319374], [79.76069641, 11.62236023], [79.76097107, 11.62236023], [79.76097107, 11.62208366], [79.76125336, 11.62208366], [79.76125336, 11.62097168], [79.76097107, 11.62097168], [79.76097107, 11.62069416], [79.76069641, 11.62069416], [79.76069641, 11.62013817], [79.76040649, 11.62014008], [79.76040649, 11.61847019], [79.76013947, 11.6184721], [79.76013947, 11.61791801], [79.75985718, 11.61791992], [79.75985718, 11.61736202], [79.75958252, 11.61736202], [79.75958252, 11.61708164], [79.75930786, 11.61708355], [79.75930786, 11.61680603], [79.75902557, 11.61680603], [79.75902557, 11.61708355], [79.75818634, 11.61708164], [79.75818634, 11.61763954], [79.75791931, 11.61763954], [79.75791931, 11.61791992], [79.75763702, 11.61791801], [79.75763702, 11.6184721], [79.75708008, 11.6184721], [79.75708008, 11.61763763], [79.75681305, 11.61763954], [79.75681305, 11.61653042], [79.75763702, 11.61653042], [79.75763702, 11.61626053], [79.75818634, 11.61626053], [79.75818634, 11.61568928], [79.75902557, 11.61569405], [79.75902557, 11.61541557], [79.76040649, 11.61542034], [79.76040649, 11.61485958], [79.76013947, 11.61486244], [79.76013947, 11.61402798], [79.75985718, 11.61403179], [79.75985718, 11.61320019], [79.75958252, 11.61320019], [79.75958252, 11.61291981], [79.75932312, 11.61291981], [79.75932312, 11.61236191], [79.75902557, 11.61236191], [79.75902557, 11.61180496], [79.75875092, 11.61180973], [79.75875092, 11.6115303], [79.7590332, 11.6115303], [79.7590332, 11.61069107], [79.75930786, 11.61069584], [79.75930786, 11.61013889], [79.75958252, 11.61013889], [79.75958252, 11.60902691], [79.75932312, 11.60903168], [79.75932312, 11.6087513], [79.75958252, 11.6087513], [79.75958252, 11.60763931], [79.75932312, 11.60763931], [79.75932312, 11.60625076], [79.7590332, 11.60625076], [79.7590332, 11.6034708], [79.75875092, 11.6034708], [79.75875092, 11.60041714], [79.75846863, 11.60042095], [79.75846863, 11.59846973], [79.75819397, 11.5984726], [79.75819397, 11.5951376], [79.75791931, 11.5951376], [79.75791931, 11.59180641], [79.75763702, 11.59181118], [79.75763702, 11.58792019], [79.75736237, 11.58792019], [79.75736237, 11.58403015], [79.75708008, 11.58403015], [79.75708008, 11.5781908], [79.75736237, 11.57819462], [79.75736237, 11.56735992], [79.75708008, 11.56735992], [79.75708008, 11.56707954], [79.75736237, 11.56708431], [79.75736237, 11.56680584], [79.75763702, 11.56681061], [79.75763702, 11.56458187], [79.75736237, 11.56458378], [79.75736237, 11.56430626], [79.75708008, 11.56431103], [79.75708008, 11.56375027], [79.75736237, 11.56375027], [79.75736237, 11.56319237], [79.75763702, 11.56319427], [79.75763702, 11.56041622], [79.75791931, 11.56042004], [79.75791931, 11.5581913], [79.75819397, 11.55819321], [79.75819397, 11.55597115], [79.75846863, 11.55597115], [79.75846863, 11.55374908], [79.75875092, 11.55375099], [79.75875092, 11.55208111], [79.75902557, 11.55208302], [79.75902557, 11.55195999], [79.75902557, 11.55069542], [79.75930786, 11.55069542], [79.75930786, 11.54902744], [79.75958252, 11.54903126], [79.75958252, 11.54653072], [79.75985718, 11.54653072], [79.75985718, 11.5462513], [79.76013947, 11.5462513], [79.76013947, 11.54458046], [79.76041412, 11.54458237], [79.76041412, 11.5429163], [79.76069641, 11.54292107], [79.76069641, 11.54207993], [79.76097107, 11.54208374], [79.76097107, 11.54097176], [79.76125336, 11.54098129], [79.76125336, 11.53985977], [79.76152802, 11.53985977], [79.76152802, 11.5381918], [79.76125336, 11.5381937], [79.76125336, 11.5373621], [79.76152802, 11.5373621], [79.76152802, 11.53708363], [79.76208496, 11.53708363], [79.76208496, 11.53625011], [79.76235962, 11.53625202], [79.76235962, 11.53542042], [79.76264191, 11.53542042], [79.76264191, 11.53485012], [79.76291656, 11.53485966], [79.76291656, 11.53374958], [79.76319122, 11.53374958], [79.76319122, 11.53236198], [79.76346588, 11.53236198], [79.76346588, 11.53208065], [79.76374817, 11.53208447], [79.76374817, 11.53180599], [79.76403046, 11.53180981], [79.76403046, 11.53097057], [79.76430511, 11.53097057], [79.76430511, 11.53013897], [79.76457977, 11.53014183], [79.76457977, 11.52958107], [79.76430511, 11.52958298], [79.76430511, 11.52902699], [79.76457977, 11.52904129], [79.76457977, 11.52875137], [79.76430511, 11.52875137], [79.76430511, 11.52819538], [79.76403046, 11.52819538], [79.76403046, 11.52791691], [79.76374817, 11.52791977], [79.76374817, 11.52736092], [79.76403046, 11.52736092], [79.76403046, 11.52680969], [79.76457977, 11.52680492], [79.76457977, 11.5270834], [79.76486206, 11.5270834], [79.76486206, 11.52680492], [79.76541901, 11.52680969], [79.76541901, 11.52652931], [79.76568604, 11.52652931], [79.76568604, 11.52625084], [79.76597595, 11.52625084], [79.76597595, 11.52598], [79.76625061, 11.52598], [79.76625061, 11.52541924], [79.7665329, 11.52541924], [79.7665329, 11.52486134], [79.76680756, 11.52486134], [79.76680756, 11.52430534], [79.76708221, 11.52431202], [79.76708221, 11.52375126], [79.76735687, 11.52375126], [79.76735687, 11.52291012], [79.76763916, 11.52291679], [79.76763916, 11.52263927], [79.76790619, 11.52264118], [79.76790619, 11.52153111], [79.76818848, 11.52153111], [79.76818848, 11.5209713], [79.76847076, 11.52097321], [79.76847076, 11.52041721], [79.76875305, 11.52042103], [79.76875305, 11.51958275], [79.76902771, 11.51958466], [79.76902771, 11.51902866], [79.76930237, 11.51903057], [79.76930237, 11.51819038], [79.76958466, 11.51819515], [79.76958466, 11.51791573], [79.76930237, 11.51792145], [79.76930237, 11.51735973], [79.76957703, 11.51735973], [79.76957703, 11.51653099], [79.76985931, 11.51653099], [79.76985931, 11.51597023], [79.7701416, 11.51597214], [79.7701416, 11.51541615], [79.77041626, 11.51542091], [79.77041626, 11.51486015], [79.77069092, 11.51486015], [79.77069092, 11.51458359], [79.77097321, 11.51458359], [79.77097321, 11.51430416], [79.77126312, 11.51431084], [79.77126312, 11.51375008], [79.77153015, 11.51375008], [79.77153015, 11.51292133], [79.77126312, 11.51292133], [79.77126312, 11.51264], [79.77153015, 11.51264], [79.77153015, 11.51235962], [79.77180481, 11.51236153], [79.77180481, 11.51208401], [79.7720871, 11.51208401], [79.7720871, 11.51152802], [79.77236176, 11.51152992], [79.77236176, 11.51097202], [79.77263641, 11.51097202], [79.77263641, 11.51041603], [79.7729187, 11.51041985], [79.7729187, 11.50986195], [79.77319336, 11.50986195], [79.77319336, 11.50791073], [79.77347565, 11.50791645], [79.77347565, 11.50736237], [79.77402496, 11.50736237], [79.77402496, 11.50708389], [79.77430725, 11.50708389], [79.77430725, 11.50680637], [79.77458191, 11.50681019], [79.77458191, 11.50625038], [79.77485657, 11.50625038], [79.77485657, 11.50569057], [79.77513885, 11.50569344], [79.77513885, 11.50541782], [79.77540588, 11.50541973], [79.77540588, 11.5051403], [79.7756958, 11.5051403], [79.7756958, 11.50458145], [79.77597046, 11.50458431], [79.77597046, 11.50430489], [79.77625275, 11.50430965], [79.77625275, 11.50403023], [79.7765274, 11.50403023], [79.7765274, 11.50347137], [79.77680206, 11.50347137], [79.77680206, 11.50319576], [79.77708435, 11.50319576], [79.77708435, 11.50291538], [79.77735901, 11.50292015], [79.77735901, 11.50264168], [79.7776413, 11.50264168], [79.7776413, 11.50208092], [79.77791595, 11.50208282], [79.77791595, 11.50180531], [79.77819061, 11.50181198], [79.77819824, 11.5015316], [79.7784729, 11.5015316], [79.7784729, 11.50124931], [79.77874756, 11.50124931], [79.77874756, 11.50069141], [79.77958679, 11.50069523], [79.77958679, 11.50041676], [79.77986145, 11.50041962], [79.77986145, 11.49958134], [79.78013611, 11.49958324], [79.78013611, 11.49847317], [79.7804184, 11.49847317], [79.7804184, 11.49736118], [79.78069305, 11.49736118], [79.78069305, 11.49625111], [79.78098297, 11.49625111], [79.78097534, 11.49513912], [79.78125, 11.49514103], [79.78125, 11.49403095], [79.78151703, 11.49403095], [79.78151703, 11.4931879], [79.78180695, 11.49319458], [79.78180695, 11.49208164], [79.7820816, 11.49208164], [79.7820816, 11.49097347], [79.78236389, 11.49097347], [79.78236389, 11.49013805], [79.78263855, 11.49014091], [79.78263855, 11.48931122], [79.78291321, 11.48931122], [79.78291321, 11.48847008], [79.7831955, 11.48847198], [79.7831955, 11.48763847], [79.78347015, 11.48764038], [79.78347015, 11.48653126], [79.78375244, 11.48653126], [79.78375244, 11.48569202], [79.7840271, 11.48569393], [79.7840271, 11.48486233], [79.78430176, 11.48486233], [79.78430176, 11.48402786], [79.78457642, 11.48403263], [79.78457642, 11.48319244], [79.7848587, 11.48319435], [79.7848587, 11.48264027], [79.78514099, 11.48264027], [79.78514099, 11.48180962], [79.78542328, 11.48180962], [79.78542328, 11.48124981], [79.78569794, 11.48124981], [79.78569794, 11.48069382], [79.7859726, 11.48069382], [79.7859726, 11.47986221], [79.78624725, 11.47986221], [79.78624725, 11.47930622], [79.78652954, 11.47931004], [79.78652954, 11.47846889], [79.7868042, 11.4784708], [79.7868042, 11.47791767], [79.78708649, 11.47793102], [79.78708649, 11.47736168], [79.78736115, 11.47736168], [79.78736115, 11.47681046], [79.7876358, 11.47681046], [79.7876358, 11.4762516], [79.78791809, 11.4762516], [79.78791809, 11.47597122], [79.78819275, 11.47597122], [79.78819275, 11.47569466], [79.78847504, 11.47569466], [79.78847504, 11.47513866], [79.78874969, 11.47514153], [79.78874969, 11.47486973], [79.78900909, 11.47486973], [79.78900909, 11.47430992], [79.78929901, 11.47430992], [79.78929901, 11.47402859], [79.7895813, 11.47402859], [79.7895813, 11.47347069], [79.78986359, 11.4734726], [79.78986359, 11.47319317], [79.79013824, 11.47319317], [79.79013824, 11.4729166], [79.7904129, 11.47292042], [79.7904129, 11.47236061], [79.79069519, 11.47236061], [79.79069519, 11.47208309], [79.79096985, 11.47208309], [79.79096985, 11.4715271], [79.79125214, 11.47153187], [79.79125214, 11.47125053], [79.79152679, 11.47125053], [79.79152679, 11.47069073], [79.79180908, 11.47069454], [79.79180908, 11.47041702], [79.79207611, 11.47042179], [79.79207611, 11.46986103], [79.7923584, 11.46986103], [79.7923584, 11.46958065], [79.79264069, 11.46958256], [79.79264069, 11.46902657], [79.79292297, 11.46903133], [79.79292297, 11.46874046], [79.79319763, 11.46875095], [79.79319763, 11.46847343], [79.79347229, 11.46847343], [79.79347229, 11.46791744], [79.79374695, 11.46792126], [79.79374695, 11.46764088], [79.79402924, 11.46764088], [79.79402924, 11.46708012], [79.79430389, 11.46708298], [79.79430389, 11.46680546], [79.79458618, 11.46680927], [79.79458618, 11.46652889], [79.79486084, 11.46652889], [79.79486084, 11.46597004], [79.7951355, 11.4659729], [79.7951355, 11.46569538], [79.79543304, 11.4656992], [79.79543304, 11.4651413], [79.79569244, 11.4651413], [79.79569244, 11.46485996], [79.7959671, 11.46485996], [79.7959671, 11.46431065], [79.79624939, 11.46431065], [79.79624939, 11.46403122], [79.79651642, 11.46403122], [79.79651642, 11.46375275], [79.79680634, 11.46375275], [79.79680634, 11.46319199], [79.79708099, 11.46319389], [79.79708099, 11.46291637], [79.79736328, 11.46292114], [79.79736328, 11.46236038], [79.79763794, 11.46236038], [79.79763794, 11.46208191], [79.79792023, 11.46208191], [79.79792023, 11.4618063], [79.79820251, 11.46181107], [79.79820251, 11.46125031], [79.79846954, 11.46125031], [79.79846954, 11.46068954], [79.79875183, 11.46069431], [79.79875183, 11.46014023], [79.79902649, 11.46014023], [79.79902649, 11.45957088], [79.79930878, 11.45958424], [79.79930878, 11.45902824], [79.79957581, 11.45903015], [79.79957581, 11.45847034], [79.79985809, 11.45847225], [79.79985809, 11.45791626], [79.80014038, 11.45792103], [79.80014038, 11.45736027], [79.80041504, 11.45736217], [79.80041504, 11.45680618], [79.80069733, 11.45680618], [79.80069733, 11.45625019], [79.80097198, 11.45625019], [79.80097198, 11.45568943], [79.80124664, 11.4556942], [79.80124664, 11.45514011], [79.80152893, 11.45514011], [79.80152893, 11.45457935], [79.80180359, 11.45458412], [79.80180359, 11.45402813], [79.80208588, 11.45403004], [79.80208588, 11.45346928], [79.80236053, 11.45347214], [79.80236053, 11.45263958], [79.80264282, 11.45263958], [79.80264282, 11.45208073], [79.80291748, 11.45208359], [79.80291748, 11.4515276], [79.80319214, 11.45153046], [79.80319214, 11.45069981], [79.8034668, 11.45069981], [79.8034668, 11.45014191], [79.80374908, 11.45014191], [79.80374908, 11.44958115], [79.80403137, 11.44958305], [79.80403137, 11.44902706], [79.8042984, 11.44903183], [79.8042984, 11.4487524], [79.80458069, 11.4487524], [79.80458069, 11.44819069], [79.80486298, 11.44819546], [79.80486298, 11.44791698], [79.80513763, 11.44791985], [79.80513763, 11.44736099], [79.80541992, 11.44736099], [79.80541992, 11.44708061], [79.80569458, 11.44708347], [79.80569458, 11.44652653], [79.80596924, 11.44652939], [79.80596924, 11.44597054], [79.80625153, 11.4459734], [79.80625153, 11.44569302], [79.80652618, 11.44569302], [79.80652618, 11.44513893], [79.80680847, 11.44514084], [79.80680847, 11.44486141], [79.80708313, 11.44486141], [79.80708313, 11.44458294], [79.80735779, 11.44458294], [79.80735779, 11.44375134], [79.80708313, 11.44375134], [79.80708313, 11.44318962], [79.80735779, 11.44319534], [79.80735779, 11.44236088], [79.80764008, 11.44236088], [79.80764008, 11.4412508], [79.8079071, 11.4412508], [79.8079071, 11.44014072], [79.80819702, 11.44014072], [79.80819702, 11.43903065], [79.80847168, 11.43903065], [79.80847168, 11.43792057], [79.80874634, 11.43792057], [79.80874634, 11.43708038], [79.80902863, 11.43708229], [79.80902863, 11.43624973], [79.80930328, 11.43624973], [79.80930328, 11.43542099], [79.8095932, 11.43542099], [79.8095932, 11.43457985], [79.80986023, 11.43458366], [79.80986023, 11.43319416], [79.81014252, 11.43319416], [79.81014252, 11.43263817], [79.81041718, 11.43263817], [79.81041718, 11.43208408], [79.81069183, 11.43208408], [79.81069183, 11.43152809], [79.81096649, 11.43153], [79.81096649, 11.43068886], [79.81124878, 11.43069363], [79.81124878, 11.42958355], [79.81153107, 11.42959118], [79.81153107, 11.42818928], [79.81180573, 11.42819405], [79.81180573, 11.42708397], [79.81208038, 11.42708397], [79.81208038, 11.42597198], [79.81236267, 11.42597198], [79.81236267, 11.42486191], [79.81263733, 11.42486191], [79.81263733, 11.42375183], [79.81291962, 11.42375183], [79.81291962, 11.42292023], [79.81317902, 11.42292023], [79.81317902, 11.42181015], [79.81346893, 11.42181015], [79.81346893, 11.42097092], [79.81375122, 11.42097092], [79.81375122, 11.42013931], [79.81402588, 11.42013931], [79.81402588, 11.4191227], [79.81402588, 11.41902733], [79.81430817, 11.41902924], [79.81430817, 11.41792202], [79.81458282, 11.41792202], [79.81458282, 11.41625118], [79.81485748, 11.41625118], [79.81485748, 11.41459179], [79.81513977, 11.41459179], [79.81513977, 11.41292095], [79.8154068, 11.41292095], [79.8154068, 11.41125107], [79.81569672, 11.41125107], [79.81569672, 11.40958023], [79.81597137, 11.40958214], [79.81597137, 11.40791607], [79.8162384, 11.40792084], [79.8162384, 11.40625], [79.81652832, 11.40625], [79.81652832, 11.40458202], [79.81680298, 11.40458202], [79.81680298, 11.40236187], [79.8170929, 11.40236187], [79.81708527, 11.4006958], [79.81735992, 11.4006958], [79.81735992, 11.40013981], [79.81764221, 11.40013981], [79.81764221, 11.39931011], [79.81791687, 11.39931011], [79.81791687, 11.39875031], [79.81819153, 11.39875031], [79.81819153, 11.39764023], [79.81846619, 11.39764023], [79.81846619, 11.39652061], [79.81874847, 11.39652729], [79.81874847, 11.39513874], [79.81903076, 11.3951416], [79.81903076, 11.39374924], [79.81931305, 11.39374924], [79.81930542, 11.39263916], [79.81958008, 11.39264202], [79.81958008, 11.39125061], [79.81986237, 11.39125061], [79.81986237, 11.39014053], [79.82013702, 11.39014053], [79.82013702, 11.38875103], [79.82041931, 11.38875103], [79.82041931, 11.38736057], [79.82069397, 11.38736057], [79.82069397, 11.38624859], [79.82096863, 11.38625145], [79.82096863, 11.38514137], [79.82125092, 11.38514137], [79.82125092, 11.38431072], [79.8215332, 11.38431072], [79.8215332, 11.38375092], [79.82180786, 11.38375092], [79.82180786, 11.38292122], [79.82208252, 11.38292122], [79.82208252, 11.38236046], [79.82236481, 11.38236046], [79.82236481, 11.38180733], [79.82263947, 11.38181114], [79.82263947, 11.38125038], [79.82290649, 11.38125038], [79.82290649, 11.38097], [79.82319641, 11.38097191], [79.82319641, 11.38041592], [79.82347107, 11.38042068], [79.82347107, 11.3801403], [79.82375336, 11.3801403], [79.82375336, 11.37957954], [79.82402802, 11.37958431], [79.82402802, 11.37902832], [79.82430267, 11.37903118], [79.82430267, 11.37874985], [79.82347107, 11.37874985], [79.82347107, 11.37708187], [79.82319641, 11.37708378], [79.82319641, 11.3754158], [79.82347107, 11.37541962], [79.82347107, 11.37457943], [79.82375336, 11.3745842], [79.82375336, 11.37374973], [79.82402802, 11.37374973], [79.82402802, 11.37292004], [79.82430267, 11.37292004], [79.82430267, 11.37042046], [79.82457733, 11.37042046], [79.82457733, 11.3698616], [79.82485962, 11.3698616], [79.82485962, 11.36931038], [79.82514191, 11.36931038], [79.82514191, 11.36847115], [79.82541656, 11.36847115], [79.82541656, 11.36791706], [79.82569122, 11.36792183], [79.82569122, 11.36736107], [79.82596588, 11.36736107], [79.82596588, 11.36654091], [79.82624817, 11.36654091], [79.82624817, 11.36597061], [79.82653046, 11.36597347], [79.82653046, 11.36541653], [79.82681274, 11.36542034], [79.82681274, 11.36486053], [79.82707977, 11.36486053], [79.82707977, 11.36347103], [79.82736206, 11.36347961], [79.82736206, 11.36292171], [79.82402802, 11.36291695], [79.82402802, 11.36319542], [79.82375336, 11.36319065], [79.82375336, 11.36347961], [79.82347107, 11.36347961], [79.82347107, 11.36375141], [79.82319641, 11.36375141], [79.82319641, 11.36403179], [79.82290649, 11.36403179], [79.82290649, 11.36431026], [79.82263947, 11.36430454], [79.82263947, 11.36486053], [79.82237244, 11.36486053], [79.82237244, 11.36514091], [79.82208252, 11.36514091], [79.82208252, 11.36542034], [79.82069397, 11.36541653], [79.82069397, 11.36569309], [79.82041931, 11.36569118], [79.82041931, 11.36625099], [79.81986237, 11.36625099], [79.81986237, 11.36680984], [79.81958008, 11.36680984], [79.81958008, 11.36763859], [79.81931305, 11.36763859], [79.81931305, 11.36792183], [79.81903076, 11.36791706], [79.81903076, 11.36819553], [79.81874847, 11.36819553], [79.81874847, 11.36847115], [79.81846619, 11.36847115], [79.81846619, 11.36875153], [79.81819153, 11.36875153], [79.81819153, 11.36903191], [79.81791687, 11.36903191], [79.81791687, 11.36931038], [79.81735992, 11.36930466], [79.81735992, 11.36958408], [79.81652832, 11.36958122], [79.81652832, 11.3698616], [79.81597137, 11.3698616], [79.81597137, 11.37014198], [79.81569672, 11.37014198], [79.81569672, 11.37042046], [79.81236267, 11.37041759], [79.81236267, 11.37069321], [79.81180573, 11.37069321], [79.81180573, 11.37208366], [79.81208038, 11.3720789], [79.81208038, 11.37263966], [79.81236267, 11.37263966], [79.81236267, 11.37319374], [79.81263733, 11.37319374], [79.81263733, 11.37347221], [79.81291962, 11.37346935], [79.81291962, 11.37374973], [79.81317902, 11.37374973], [79.81317902, 11.37403011], [79.81346893, 11.37402821], [79.81346893, 11.3745842], [79.81375122, 11.37457943], [79.81375122, 11.37597179], [79.81346893, 11.37597179], [79.81346893, 11.37763977], [79.81317902, 11.37763977], [79.81317902, 11.3779211], [79.81291962, 11.3779211], [79.81291962, 11.37848091], [79.81263733, 11.37848091], [79.81263733, 11.37903118], [79.81236267, 11.37903118], [79.81236267, 11.37931061], [79.81208038, 11.37931061], [79.81208038, 11.37985992], [79.81153107, 11.37985992], [79.81153107, 11.3801403], [79.81124878, 11.3801403], [79.81124878, 11.38042068], [79.81097412, 11.38041592], [79.81097412, 11.38069439], [79.81069183, 11.38069439], [79.81069183, 11.38097191], [79.81041718, 11.38097191], [79.81043243, 11.38125038], [79.81014252, 11.38125038], [79.81014252, 11.38264084], [79.81041718, 11.38263798], [79.81041718, 11.3834734], [79.81014252, 11.38346958], [79.81014252, 11.38375092], [79.8095932, 11.38375092], [79.8095932, 11.38346958], [79.80930328, 11.3834734], [79.80930328, 11.38236046], [79.80902863, 11.38236046], [79.80902863, 11.38097191], [79.80930328, 11.38097191], [79.80930328, 11.38069439], [79.80958557, 11.38069439], [79.80958557, 11.38041592], [79.80986023, 11.38042068], [79.80986023, 11.3801403], [79.81014252, 11.3801403], [79.81014252, 11.37957954], [79.81041718, 11.37958431], [79.81041718, 11.37930584], [79.81069183, 11.37931061], [79.81069183, 11.37903118], [79.81096649, 11.37903118], [79.81096649, 11.37848091], [79.81153107, 11.37848091], [79.81153107, 11.3779211], [79.81181335, 11.3779211], [79.81181335, 11.37763977], [79.81208038, 11.37763977], [79.81208038, 11.37736034], [79.81236267, 11.37736225], [79.81236267, 11.37680626], [79.81263733, 11.37681103], [79.81263733, 11.37652969], [79.81291962, 11.37652969], [79.81291962, 11.37597179], [79.81263733, 11.37597179], [79.81263733, 11.37541962], [79.81236267, 11.37541962], [79.81236267, 11.37485981], [79.81208038, 11.37485981], [79.81208038, 11.3745842], [79.81180573, 11.3745842], [79.81180573, 11.37430573], [79.81153107, 11.37430954], [79.81153107, 11.37374973], [79.81124878, 11.37374973], [79.81124878, 11.37319088], [79.81097412, 11.37319374], [79.81097412, 11.37263966], [79.81069183, 11.37263966], [79.81069183, 11.37097073], [79.81097412, 11.37097073], [79.81097412, 11.37041759], [79.81124878, 11.37042046], [79.81124878, 11.37014198], [79.81153107, 11.37014198], [79.81153107, 11.36958122], [79.81180573, 11.36958408], [79.81180573, 11.36930466], [79.81208038, 11.36931038], [79.81208038, 11.36903191], [79.81291962, 11.36903191], [79.81291962, 11.36875153], [79.81375122, 11.36875153], [79.81375122, 11.36819077], [79.81402588, 11.36819553], [79.81402588, 11.36791706], [79.81458282, 11.36791706], [79.81458282, 11.36819553], [79.81485748, 11.36819553], [79.81485748, 11.36847115], [79.81541443, 11.36847115], [79.81541443, 11.36819553], [79.81569672, 11.36819553], [79.81569672, 11.36680508], [79.8162384, 11.36680984], [79.8162384, 11.36654091], [79.81652832, 11.36654091], [79.81652832, 11.36625099], [79.8170929, 11.36625099], [79.8170929, 11.36597061], [79.81735992, 11.36597347], [79.81735992, 11.36569309], [79.81819153, 11.36569309], [79.81819153, 11.36541653], [79.81846619, 11.36542034], [79.81846619, 11.36486053], [79.81874847, 11.36486053], [79.81874847, 11.36458302], [79.81819153, 11.36458302], [79.81819153, 11.36430454], [79.81791687, 11.36430454], [79.81791687, 11.36458302], [79.81652832, 11.36458302], [79.81652832, 11.36430454], [79.81680298, 11.36431026], [79.81680298, 11.36375141], [79.8170929, 11.36375141], [79.8170929, 11.36319065], [79.81735992, 11.36319542], [79.81735992, 11.36263943], [79.81764221, 11.36264133], [79.81764221, 11.36208057], [79.81791687, 11.36208344], [79.81791687, 11.36152744], [79.81819153, 11.36153126], [79.81819153, 11.36097145], [79.81847382, 11.36097336], [79.81847382, 11.36041737], [79.81874847, 11.36041737], [79.81874847, 11.35986137], [79.81903076, 11.35986137], [79.81903076, 11.3595829], [79.81930542, 11.3595829], [79.81930542, 11.35930538], [79.81958008, 11.3593092], [79.81958008, 11.35903072], [79.82013702, 11.35903072], [79.82013702, 11.3587513], [79.82096863, 11.3587513], [79.82096863, 11.35818958], [79.82125092, 11.3581953], [79.82125092, 11.35763931], [79.8215332, 11.35764122], [79.8215332, 11.3573513], [79.82180786, 11.35735989], [79.82180786, 11.35708237], [79.82208252, 11.35708046], [79.82208252, 11.35764122], [79.82237244, 11.35764122], [79.82237244, 11.35792065], [79.82263947, 11.35792065], [79.82263947, 11.3587513], [79.82290649, 11.3587513], [79.82290649, 11.3593092], [79.82347107, 11.35930538], [79.82347107, 11.3595829], [79.82430267, 11.3595829], [79.82430267, 11.35930538], [79.82457733, 11.3593092], [79.82457733, 11.3587513], [79.82485962, 11.3587513], [79.82485962, 11.35846996], [79.82514191, 11.35847282], [79.82514191, 11.3581953], [79.82541656, 11.3581953], [79.82541656, 11.35791683], [79.82569122, 11.35792065], [79.82569122, 11.3573513], [79.82597351, 11.35735989], [79.82597351, 11.35708237], [79.82707977, 11.35708237], [79.82707977, 11.35680676], [79.82736206, 11.35681057], [79.82736206, 11.35653114], [79.82817841, 11.35653114], [79.82817841, 11.35569], [79.82847595, 11.35569382], [79.82847595, 11.3554163], [79.82875061, 11.35542107], [79.82875061, 11.35514069], [79.8290329, 11.35514069], [79.8290329, 11.35486031], [79.82930756, 11.35486031], [79.82930756, 11.35458469], [79.83041382, 11.35458469], [79.83041382, 11.35430431], [79.83154297, 11.35431099], [79.83154297, 11.35403061], [79.83235931, 11.35403061], [79.83235931, 11.35375023], [79.8326416, 11.35375023], [79.8326416, 11.35346985], [79.83319092, 11.35346985], [79.83319092, 11.35375023], [79.83374786, 11.35375023], [79.83374786, 11.35403061], [79.83431244, 11.35403061], [79.83431244, 11.35431099], [79.8345871, 11.35430431], [79.8345871, 11.35458469], [79.83513641, 11.35458469], [79.83513641, 11.35486031], [79.8354187, 11.35486031], [79.8354187, 11.35792065], [79.83569336, 11.35791683], [79.83569336, 11.35847282], [79.83597565, 11.35847282], [79.83597565, 11.3595829], [79.83569336, 11.3595829], [79.83569336, 11.35986137], [79.83513641, 11.35986137], [79.83513641, 11.36125088], [79.83347321, 11.36125088], [79.83347321, 11.36153126], [79.83319092, 11.36153126], [79.83319092, 11.36181164], [79.83347321, 11.36180496], [79.83347321, 11.36208344], [79.83403015, 11.36208057], [79.83403015, 11.36236095], [79.83431244, 11.36236095], [79.83431244, 11.36264133], [79.83569336, 11.36264133], [79.83569336, 11.36208057], [79.83597565, 11.36208344], [79.83597565, 11.36180496], [79.83625031, 11.36181164], [79.83625031, 11.36125088], [79.83651733, 11.36125088], [79.83651733, 11.36069012], [79.83680725, 11.36069489], [79.83680725, 11.36013889], [79.83708191, 11.36013889], [79.83708191, 11.3593092], [79.83734894, 11.3593092], [79.83734894, 11.35792065], [79.83763885, 11.35792065], [79.83763885, 11.35681057], [79.83790588, 11.35681057], [79.83790588, 11.35486031], [79.8381958, 11.35486031], [79.8381958, 11.35263824], [79.83847046, 11.35264015], [79.83847046, 11.34817791], [79.83875275, 11.34819412], [79.83875275, 11.3423624], [79.83847046, 11.34237099], [79.83847046, 11.33902931], [79.8381958, 11.33902931], [79.8381958, 11.33736134], [79.83791351, 11.33736134], [79.83791351, 11.33541679], [79.8381958, 11.33542156], [79.8381958, 11.33318138], [79.83791351, 11.33319473], [79.83791351, 11.33041668], [79.83763885, 11.33043003], [79.83763885, 11.32792091], [79.83734894, 11.32792091], [79.83734894, 11.32514], [79.83708191, 11.32514], [79.83708191, 11.3220787], [79.83680725, 11.32208443], [79.83680725, 11.31847191], [79.83652496, 11.31847191], [79.83652496, 11.31541538], [79.83680725, 11.31543064], [79.83680725, 11.31291962], [79.83708191, 11.31291962], [79.83708191, 11.30986118], [79.8373642, 11.30986118], [79.8373642, 11.30402565], [79.83763885, 11.30403137], [79.83763885, 11.30013084], [79.83791351, 11.30013847], [79.83791351, 11.29652786], [79.8381958, 11.29652977], [79.8381958, 11.29319096], [79.83847046, 11.29319382], [79.83847046, 11.29041767], [79.83875275, 11.29041958], [79.83875275, 11.28763866], [79.8390274, 11.28763866], [79.8390274, 11.28486061], [79.83930206, 11.28486061], [79.83930206, 11.28292179], [79.83957672, 11.28292179], [79.83957672, 11.28153133], [79.83985901, 11.28153133], [79.83985901, 11.28014088], [79.8401413, 11.28014088], [79.8401413, 11.27847004], [79.84041595, 11.2784729], [79.84041595, 11.2770834], [79.84069061, 11.2770834], [79.84069824, 11.27569485], [79.8409729, 11.27569485], [79.8409729, 11.27375031], [79.84124756, 11.27375031], [79.84124756, 11.27124977], [79.84152985, 11.27124977], [79.84152985, 11.26902962], [79.84179688, 11.26902962], [79.84179688, 11.2670908], [79.84208679, 11.2670908], [79.84208679, 11.2656889], [79.84236145, 11.26569366], [79.84236145, 11.26458359], [79.84263611, 11.26458359], [79.84263611, 11.26375008], [79.8429184, 11.26375198], [79.8429184, 11.2618103], [79.84319305, 11.2618103], [79.84319305, 11.26069069], [79.84347534, 11.26069641], [79.84347534, 11.25958347], [79.84375, 11.25958347], [79.84375, 11.2584734], [79.84402466, 11.2584734], [79.84402466, 11.25736141], [79.84430695, 11.25736141], [79.84430695, 11.25625134], [79.8445816, 11.25625134], [79.8445816, 11.2551527], [79.84485626, 11.2551527], [79.84485626, 11.25403118], [79.84513855, 11.25403118], [79.84513855, 11.2529192], [79.84541321, 11.2529192], [79.84541321, 11.25181103], [79.84570313, 11.25181103], [79.84570313, 11.25042057], [79.84597015, 11.25042057], [79.84597015, 11.24901962], [79.84625244, 11.24902916], [79.84625244, 11.24791622], [79.84654236, 11.24792099], [79.84654236, 11.24653053], [79.84680176, 11.24653053], [79.84680176, 11.24514008], [79.84654236, 11.24514008], [79.84654236, 11.24403], [79.84625244, 11.24403], [79.84625244, 11.24347019], [79.84597015, 11.2434721], [79.84597015, 11.24291611], [79.84570313, 11.24292088], [79.84570313, 11.24236202], [79.84541321, 11.24236202], [79.84541321, 11.24153042], [79.84513855, 11.24153042], [79.84513855, 11.24042034], [79.84485626, 11.24042034], [79.84485626, 11.2395792], [79.8445816, 11.23958397], [79.8445816, 11.23930645], [79.84430695, 11.23931026], [79.84430695, 11.23903179], [79.84375, 11.23903179], [79.84375, 11.23875046], [79.84319305, 11.23875046], [79.84319305, 11.23847198], [79.8429184, 11.23847198], [79.8429184, 11.23819447], [79.8418045, 11.23819447], [79.8418045, 11.2379179], [79.8381958, 11.23791981], [79.8381958, 11.23764038], [79.83708191, 11.23764038], [79.83708191, 11.23736191], [79.83680725, 11.23736191], [79.83680725, 11.23708057], [79.83652496, 11.23708439], [79.83652496, 11.23680592], [79.83598328, 11.23680973], [79.83598328, 11.2365303], [79.8354187, 11.2365303], [79.8354187, 11.23625183], [79.83460236, 11.23625183], [79.83460236, 11.23597145], [79.83403015, 11.23597145], [79.83403015, 11.23569584], [79.83319092, 11.23569584], [79.83319092, 11.23541546], [79.83069611, 11.23542023], [79.83069611, 11.23513985], [79.83013916, 11.23513985], [79.83013916, 11.23542023], [79.82985687, 11.23542023], [79.82985687, 11.23625183], [79.83040619, 11.23625183], [79.83040619, 11.23597145], [79.83180237, 11.23597145], [79.83180237, 11.23625183], [79.83235931, 11.23625183], [79.83235931, 11.2365303], [79.83291626, 11.2365303], [79.83291626, 11.23680973], [79.83430481, 11.23680592], [79.83430481, 11.23708439], [79.8345871, 11.23708439], [79.8345871, 11.23736191], [79.83431244, 11.23736191], [79.83431244, 11.23764038], [79.83403015, 11.23764038], [79.83403015, 11.23791981], [79.83347321, 11.2379179], [79.83347321, 11.23819447], [79.83125305, 11.23819447], [79.83125305, 11.23847198], [79.83069611, 11.23847198], [79.83069611, 11.23875046], [79.83013916, 11.23875046], [79.83013916, 11.23903179], [79.82958221, 11.23903179], [79.82958221, 11.23931026], [79.82902527, 11.23930645], [79.82902527, 11.23958397], [79.82875061, 11.2395792], [79.82875061, 11.24015141], [79.82846832, 11.24015141], [79.82846832, 11.24042034], [79.82819366, 11.24041557], [79.82819366, 11.24069405], [79.82791901, 11.24069405], [79.82791901, 11.24097157], [79.82771301, 11.24097157], [79.82681274, 11.24096966], [79.82681274, 11.24125004], [79.82430267, 11.24125004], [79.82430267, 11.24096966], [79.82402802, 11.24097157], [79.82402802, 11.24069405], [79.82375336, 11.24069405], [79.82375336, 11.23958397], [79.82430267, 11.23958397], [79.82430267, 11.23986244], [79.82569122, 11.23985958], [79.82569122, 11.24015141], [79.82624817, 11.24015141], [79.82624817, 11.23985958], [79.82653046, 11.23986244], [79.82653046, 11.23958397], [79.82680511, 11.23958397], [79.82680511, 11.23902798], [79.82707977, 11.23903179], [79.82707977, 11.23875046], [79.82736206, 11.23875046], [79.82736206, 11.23819065], [79.82653046, 11.23819447], [79.82653046, 11.2379179], [79.82597351, 11.2379179], [79.82597351, 11.23819447], [79.82569122, 11.23819447], [79.82569122, 11.2379179], [79.82402802, 11.23791981], [79.82402802, 11.23764038], [79.82375336, 11.23764038], [79.82375336, 11.23736191], [79.82347107, 11.23736191], [79.82347107, 11.23708057], [79.82319641, 11.23708439], [79.82319641, 11.23680592], [79.82263947, 11.23680973], [79.82263947, 11.23625183], [79.82237244, 11.23625183], [79.82237244, 11.23597145], [79.82180786, 11.23597145], [79.82180786, 11.23569584], [79.82125092, 11.23569584], [79.82125092, 11.23541546], [79.82096863, 11.23542023], [79.82096863, 11.23513985], [79.82125092, 11.23513985], [79.82125092, 11.23486233], [79.82152557, 11.23486233], [79.82152557, 11.2345829], [79.82263947, 11.2345829], [79.82263947, 11.23486233], [79.82291412, 11.23486233], [79.82291412, 11.23430538], [79.82263947, 11.23431015], [79.82263947, 11.23402119], [79.82236481, 11.23402691], [79.82236481, 11.23347092], [79.82208252, 11.23347092], [79.82208252, 11.2331953], [79.82180786, 11.2331953], [79.82180786, 11.23291683], [79.8215332, 11.23291969], [79.8215332, 11.23263931], [79.82096863, 11.23263931], [79.82096863, 11.23236084], [79.82041931, 11.23236084], [79.82041931, 11.23208141], [79.81903076, 11.23208332], [79.81903076, 11.23180485], [79.81791687, 11.23180962], [79.81791687, 11.23152924], [79.8162384, 11.23152924], [79.8162384, 11.23180962], [79.81597137, 11.23180485], [79.81597137, 11.23208332], [79.81430817, 11.23208141], [79.81430817, 11.23236084], [79.81346893, 11.23236084], [79.81346893, 11.23291969], [79.81319427, 11.23291683], [79.81319427, 11.2331953], [79.81236267, 11.2331953], [79.81236267, 11.23347092], [79.81153107, 11.23347092], [79.81153107, 11.23374939], [79.81097412, 11.23374939], [79.81097412, 11.23402691], [79.81014252, 11.23402119], [79.81014252, 11.23431015], [79.80958557, 11.23430538], [79.80958557, 11.23486233], [79.80902863, 11.23486233], [79.80902863, 11.23513985], [79.80874634, 11.23513985], [79.80874634, 11.23542023], [79.80847168, 11.23541546], [79.80847168, 11.23569584], [79.80735779, 11.23569584], [79.80735779, 11.23597145], [79.80680847, 11.23597145], [79.80680847, 11.23625183], [79.80568695, 11.23625183], [79.80568695, 11.2365303], [79.80541992, 11.2365303], [79.80541992, 11.23680973], [79.80458069, 11.23680973], [79.80458069, 11.23625183], [79.80541992, 11.23625183], [79.80541992, 11.23597145], [79.80596924, 11.23597145], [79.80596924, 11.23569584], [79.80652618, 11.23569584], [79.80652618, 11.23541546], [79.80708313, 11.23542023], [79.80708313, 11.23513985], [79.80764008, 11.23513985], [79.80764008, 11.23486233], [79.80847168, 11.23486233], [79.80847168, 11.2345829], [79.80902863, 11.2345829], [79.80902863, 11.23430538], [79.80930328, 11.23431015], [79.80930328, 11.23402119], [79.80958557, 11.23402691], [79.80958557, 11.23374939], [79.80986023, 11.23374939], [79.80986023, 11.23347092], [79.81041718, 11.23347092], [79.81041718, 11.2331953], [79.81097412, 11.2331953], [79.81097412, 11.23291683], [79.81124878, 11.23291969], [79.81124878, 11.23263931], [79.81181335, 11.23263931], [79.81181335, 11.23236084], [79.81208038, 11.23236084], [79.81208038, 11.23208141], [79.81236267, 11.23208332], [79.81236267, 11.23180485], [79.81263733, 11.23180962], [79.81263733, 11.23152924], [79.81317902, 11.23152924], [79.81317902, 11.23125076], [79.81402588, 11.23125076], [79.81402588, 11.23069096], [79.81819153, 11.23069096], [79.81819153, 11.23097992], [79.81846619, 11.23097992], [79.81846619, 11.23125076], [79.81958008, 11.23125076], [79.81958008, 11.23152924], [79.82041931, 11.23152924], [79.82041931, 11.23180962], [79.82096863, 11.23180962], [79.82096863, 11.23152924], [79.82125092, 11.23152924], [79.82125092, 11.23180962], [79.82180786, 11.23180485], [79.82180786, 11.23208332], [79.82208252, 11.23208141], [79.82208252, 11.23236084], [79.82237244, 11.23236084], [79.82237244, 11.23263931], [79.82263947, 11.23263931], [79.82263947, 11.23291969], [79.82319641, 11.23291683], [79.82319641, 11.2331953], [79.82430267, 11.2331953], [79.82430267, 11.23347092], [79.82596588, 11.23347092], [79.82596588, 11.23374939], [79.82791901, 11.23374939], [79.82791901, 11.23347092], [79.82930756, 11.23347092], [79.82930756, 11.23374939], [79.829422, 11.23374939], [79.83013916, 11.23374939], [79.83013916, 11.23402691], [79.83097076, 11.23402119], [79.83097076, 11.23431015], [79.83403015, 11.23431015], [79.83403015, 11.23402119], [79.8354187, 11.23402691], [79.8354187, 11.2331953], [79.83513641, 11.2331953], [79.83513641, 11.23291683], [79.83486176, 11.23291969], [79.83486176, 11.23208141], [79.8345871, 11.23208332], [79.8345871, 11.23152924], [79.83431244, 11.23152924], [79.83431244, 11.23125076], [79.83403015, 11.23125076], [79.83403015, 11.23097992], [79.83374786, 11.23097992], [79.83374786, 11.23069096], [79.83347321, 11.23069477], [79.83347321, 11.23041725], [79.83319092, 11.23042202], [79.83319092, 11.23014069], [79.83291626, 11.23014069], [79.83291626, 11.22986126], [79.83319092, 11.22986126], [79.83319092, 11.22958279], [79.83403015, 11.22958279], [79.83403015, 11.22986126], [79.83431244, 11.22986126], [79.83431244, 11.23014069], [79.83460236, 11.23014069], [79.83460236, 11.23042202], [79.83486176, 11.23042202], [79.83486176, 11.23152924], [79.8354187, 11.23152924], [79.8354187, 11.23180962], [79.83597565, 11.23180485], [79.83597565, 11.23208332], [79.83763885, 11.23208332], [79.83763885, 11.23180485], [79.8381958, 11.23180485], [79.8381958, 11.23208332], [79.83958435, 11.23208332], [79.83958435, 11.23180485], [79.83985901, 11.23180962], [79.83985901, 11.23152924], [79.8401413, 11.23152924], [79.8401413, 11.23125076], [79.84040833, 11.23125076], [79.84040833, 11.23014069], [79.83985901, 11.23014069], [79.83985901, 11.22986126], [79.83930206, 11.22986126], [79.83930206, 11.22958279], [79.8390274, 11.22958279], [79.8390274, 11.22930527], [79.83930206, 11.22931194], [79.83930206, 11.22903061], [79.8401413, 11.22903061], [79.8401413, 11.22931194], [79.84041595, 11.22930527], [79.84041595, 11.22958279], [79.84069824, 11.22958279], [79.84069824, 11.22986126], [79.84152985, 11.22986126], [79.84152985, 11.23014069], [79.84208679, 11.23014069], [79.84208679, 11.23042202], [79.84263611, 11.23041725], [79.84263611, 11.23069477], [79.8429184, 11.23069096], [79.8429184, 11.23097992], [79.84319305, 11.23097992], [79.84319305, 11.23125076], [79.84375, 11.23125076], [79.84375, 11.23152924], [79.8445816, 11.23152924], [79.8445816, 11.23180962], [79.84486389, 11.23180485], [79.84486389, 11.23208332], [79.84570313, 11.23208141], [79.84570313, 11.23236084], [79.84597015, 11.23236084], [79.84597015, 11.23263931], [79.84570313, 11.23263931], [79.84570313, 11.23291969], [79.84513855, 11.23291683], [79.84513855, 11.2331953], [79.84541321, 11.23319054], [79.84541321, 11.23374939], [79.84570313, 11.23374939], [79.84570313, 11.23431015], [79.84597015, 11.23430538], [79.84597015, 11.2345829], [79.84625244, 11.23458099], [79.84625244, 11.23513985], [79.8465271, 11.23513985], [79.8465271, 11.23569584], [79.84680176, 11.23569584], [79.84680939, 11.23616982], [79.84680939, 11.2365303], [79.84707642, 11.2365303], [79.84707642, 11.23764038], [79.8473587, 11.23763657], [79.8473587, 11.23847198], [79.84707642, 11.23847198], [79.84707642, 11.23903179], [79.84680176, 11.23903179], [79.84680176, 11.23875046], [79.8465271, 11.23875046], [79.8465271, 11.23847198], [79.84625244, 11.23847198], [79.84625244, 11.2379179], [79.84597015, 11.23791981], [79.84597015, 11.23764038], [79.84570313, 11.23764038], [79.84570313, 11.23708057], [79.84430695, 11.23708439], [79.84430695, 11.23736191], [79.84375, 11.23736191], [79.84375, 11.23764038], [79.84430695, 11.23764038], [79.84430695, 11.23791981], [79.8445816, 11.2379179], [79.8445816, 11.23819447], [79.84486389, 11.23819447], [79.84486389, 11.23847198], [79.84513855, 11.23847198], [79.84513855, 11.23875046], [79.84541321, 11.23875046], [79.84541321, 11.23903179], [79.84570313, 11.23903179], [79.84570313, 11.23931026], [79.84597015, 11.23930645], [79.84597015, 11.23986244], [79.84625244, 11.23985958], [79.84625244, 11.24015141], [79.84654236, 11.24015141], [79.84654236, 11.24042034], [79.84625244, 11.24041557], [79.84625244, 11.24097157], [79.84597015, 11.24096966], [79.84597015, 11.24125004], [79.84625244, 11.24125004], [79.84625244, 11.2418108], [79.8465271, 11.24180603], [79.8465271, 11.24236202], [79.84680176, 11.24236202], [79.84680939, 11.24292088], [79.84764099, 11.24292088], [79.84764099, 11.24015141], [79.84792328, 11.24015141], [79.84792328, 11.23875046], [79.84819794, 11.23875046], [79.84819794, 11.23763657], [79.8484726, 11.23764038], [79.8484726, 11.2365303], [79.84874725, 11.2365303], [79.84874725, 11.23542023], [79.84902954, 11.23542023], [79.84902954, 11.23319054], [79.8493042, 11.2331953], [79.8493042, 11.23208332], [79.84902954, 11.23208332], [79.84902954, 11.23152733], [79.84928894, 11.23152924], [79.84928894, 11.22931194], [79.84960175, 11.22931194], [79.84960175, 11.22764111], [79.84986115, 11.22764111], [79.84986115, 11.22597122], [79.8501358, 11.22597313], [79.8501358, 11.2234726], [79.85041809, 11.2234726], [79.85041809, 11.2201376], [79.85069275, 11.22014141], [79.85069275, 11.21708202], [79.85097504, 11.21708202], [79.85097504, 11.21625042], [79.85124969, 11.21625042], [79.85124969, 11.21513844], [79.85151672, 11.21514034], [79.85151672, 11.21347046], [79.85180664, 11.21347237], [79.85180664, 11.21208382], [79.85152435, 11.21208382], [79.85152435, 11.2118063], [79.85124969, 11.21181011], [79.85124969, 11.21097183], [79.85152435, 11.21097183], [79.85152435, 11.21069431], [79.85180664, 11.21069431], [79.85180664, 11.20902824], [79.8520813, 11.20903015], [79.8520813, 11.20792198], [79.85234833, 11.20792198], [79.85234833, 11.20624924], [79.85263824, 11.20624924], [79.85263824, 11.20402718], [79.8529129, 11.20404053], [79.8529129, 11.20347118], [79.85319519, 11.20347309], [79.85319519, 11.2029171], [79.8529129, 11.20292187], [79.8529129, 11.20264053], [79.85263824, 11.20264053], [79.85263824, 11.20097065], [79.8529129, 11.20097256], [79.8529129, 11.19930458], [79.85320282, 11.19930935], [79.85320282, 11.19736099], [79.85346985, 11.19736099], [79.85346985, 11.19569492], [79.85375214, 11.19569492], [79.85375214, 11.19402885], [79.85402679, 11.19402885], [79.85402679, 11.19235992], [79.85430908, 11.19235992], [79.85430908, 11.19013786], [79.85457611, 11.19013977], [79.85457611, 11.18818855], [79.85430908, 11.18819427], [79.85430908, 11.18652821], [79.85402679, 11.18653011], [79.85402679, 11.18568039], [79.85375214, 11.18569374], [79.85375214, 11.18541622], [79.85402679, 11.18542004], [79.85402679, 11.18513966], [79.85457611, 11.18513966], [79.85457611, 11.18486023], [79.8548584, 11.18486214], [79.8548584, 11.18430614], [79.85542297, 11.18430996], [79.85542297, 11.18208122], [79.85569763, 11.18208408], [79.85569763, 11.17763901], [79.85597229, 11.17764187], [79.85597229, 11.17347145], [79.85624695, 11.17347336], [79.85624695, 11.16902637], [79.85652924, 11.16903114], [79.85652924, 11.16458035], [79.85680389, 11.16458225], [79.85680389, 11.16014004], [79.85708618, 11.16014004], [79.85708618, 11.1554203], [79.85736084, 11.1554203], [79.85736084, 11.15097141], [79.8576355, 11.15097332], [79.8576355, 11.14763927], [79.85791779, 11.14764118], [79.85791779, 11.14708138], [79.85819244, 11.14708328], [79.85819244, 11.14624882], [79.85791779, 11.14625072], [79.85791779, 11.14486122], [79.85819244, 11.14486122], [79.85819244, 11.14402866], [79.85791779, 11.14403057], [79.85791779, 11.1434679], [79.85819244, 11.14347267], [79.85819244, 11.14069366], [79.85848236, 11.14070129], [79.85848236, 11.13986015], [79.85902405, 11.13986015], [79.85902405, 11.12208271], [79.85874939, 11.12208271], [79.85874939, 11.1165266], [79.85848236, 11.11653137], [79.85848236, 11.09431171], [79.85819244, 11.09431171], [79.85819244, 11.089571], [79.85819244, 11.08930683], [79.85791779, 11.08931065], [79.85791779, 11.08568954], [79.8576355, 11.08569431], [79.8576355, 11.08236217], [79.85736084, 11.08236217], [79.85736084, 11.07680607], [79.85708618, 11.07681274], [79.85708618, 11.07625198], [79.85764313, 11.07625198], [79.85764313, 11.0759716], [79.85819244, 11.0759716], [79.85819244, 11.07569408], [79.85874939, 11.07569408], [79.85874939, 11.07541466], [79.85901642, 11.07542038], [79.85901642, 11.07319069], [79.85874939, 11.07319641], [79.85874939, 11.07291794], [79.85791779, 11.07291794], [79.85791779, 11.07319641], [79.85736084, 11.07319641], [79.85736084, 11.07347107], [79.85708618, 11.07347107], [79.85708618, 11.07124901], [79.85679626, 11.07125092], [79.85679626, 11.05542088], [79.85652924, 11.05542088], [79.85652924, 11.04819107], [79.85624695, 11.04819584], [79.85624695, 11.03736115], [79.85597229, 11.03736115], [79.85597229, 11.03097153], [79.85624695, 11.03097153], [79.85624695, 11.0298624], [79.85652924, 11.0298624], [79.85652924, 11.02958202], [79.85624695, 11.02958202], [79.85624695, 11.02875042], [79.85652924, 11.02875042], [79.85652924, 11.02680588], [79.85679626, 11.02681065], [79.85679626, 11.02597046], [79.8576355, 11.02597237], [79.8576355, 11.0251379], [79.85819244, 11.0251379], [79.85819244, 11.02458382], [79.85791779, 11.02458382], [79.85791779, 11.0243063], [79.85736084, 11.0243063], [79.85736084, 11.02458382], [79.85708618, 11.02458382], [79.85708618, 11.02375031], [79.8576355, 11.02375031], [79.8576355, 11.02347183], [79.85736084, 11.02347183], [79.85736084, 11.02319431], [79.85680389, 11.02319431], [79.85680389, 11.02347183], [79.85652924, 11.02347183], [79.85652924, 11.02013969], [79.85624695, 11.02013969], [79.85624695, 11.01625061], [79.85597229, 11.01625061], [79.85597229, 11.00986099], [79.85569763, 11.00986099], [79.85569763, 11.00430584], [79.85542297, 11.00431061], [79.85542297, 11.00152969], [79.85514069, 11.00152969], [79.85514069, 11.00068855], [79.8548584, 11.00069427], [79.8548584, 11.0004158], [79.85457611, 11.00042057], [79.85457611, 11.00014019], [79.85457611, 10.99985981], [79.85458374, 10.99791622], [79.8548584, 10.99792004], [79.8548584, 10.99514198], [79.85514069, 10.99514198], [79.85514069, 10.97764111], [79.8548584, 10.97764111], [79.8548584, 10.97604275], [79.85457611, 10.97602177], [79.85058594, 10.97579002], [79.84440613, 10.97597027], [79.83763885, 10.97643948], [79.83537292, 10.97662163], [79.83448029, 10.97671127], [79.8344574, 10.97681999], [79.82441711, 10.97949123], [79.82491302, 10.98479939], [79.82478333, 10.98662853], [79.81389618, 10.98714924], [79.81302643, 10.98485184], [79.81202698, 10.98295975], [79.80979919, 10.9820509], [79.80454254, 10.98287964], [79.80256653, 10.9848814], [79.80145264, 10.98621178], [79.79741669, 10.98490047], [79.79644775, 10.98306942], [79.79191589, 10.98092937], [79.79036713, 10.97853184], [79.78962708, 10.97338104], [79.78705597, 10.9698], [79.78341675, 10.96733189], [79.77723694, 10.96793079], [79.77392578, 10.97101116], [79.77435303, 10.97724247], [79.77227783, 10.97956181], [79.76521301, 10.97919941], [79.76051331, 10.98058128], [79.75260162, 10.97989178], [79.74823761, 10.98153114], [79.74305725, 10.98506069], [79.73721313, 10.98910046], [79.73190308, 10.98703957], [79.73017883, 10.98510933], [79.72986603, 10.9813509], [79.73163605, 10.97529125], [79.73015594, 10.97101116], [79.7381897, 10.96931934], [79.73951721, 10.9660902], [79.74381256, 10.96701145], [79.74131012, 10.96326065], [79.73914337, 10.96146107], [79.73813629, 10.95860958], [79.73992157, 10.95578098], [79.74456024, 10.95447063], [79.74572754, 10.94929028], [79.7455368, 10.9433403], [79.74009705, 10.94365025], [79.73265076, 10.94116116], [79.73169708, 10.94816017], [79.7266922, 10.95235062], [79.72093201, 10.95060062], [79.71546173, 10.95328999], [79.71150208, 10.95227146], [79.70365143, 10.95186138], [79.70391846, 10.94761086], [79.70287323, 10.94562054], [79.70323944, 10.9382906], [79.70435333, 10.93518925], [79.70934296, 10.93558121], [79.71481323, 10.93412971], [79.71555328, 10.9382906], [79.7191925, 10.94054127], [79.72122955, 10.93531036], [79.72022247, 10.93222046], [79.71585083, 10.93050957], [79.71299744, 10.9279213], [79.70847321, 10.92671108], [79.70767212, 10.92341137], [79.70848083, 10.9211607], [79.70437622, 10.92103958], [79.70423126, 10.91887093], [79.71042633, 10.91913986], [79.71034241, 10.9174099], [79.70803833, 10.91510105], [79.70863342, 10.91415501], [79.70922852, 10.91320038], [79.72083282, 10.91070175], [79.71958923, 10.90579128], [79.72119141, 10.9052], [79.72389984, 10.90802193], [79.72590637, 10.90690136], [79.72557068, 10.90358925], [79.72838593, 10.90229034], [79.72688293, 10.8974514], [79.74298096, 10.89936066], [79.74485016, 10.89674854], [79.74180603, 10.89444065], [79.74220276, 10.89054966], [79.7414093, 10.88329124], [79.74302673, 10.8819418], [79.74578094, 10.88724136], [79.74532318, 10.89307976], [79.74794769, 10.8952198], [79.74919891, 10.88941956], [79.75415802, 10.88665962], [79.75186157, 10.88085938], [79.75694275, 10.88010025], [79.76045227, 10.88315201], [79.76122284, 10.8914299], [79.77317047, 10.8895607], [79.77635956, 10.88167953], [79.77493286, 10.87890244], [79.77005768, 10.87798119], [79.76735687, 10.87555122], [79.76698303, 10.87276173], [79.7724762, 10.87325191], [79.77562714, 10.87578106], [79.78026581, 10.87131023], [79.78486633, 10.87355042], [79.78833008, 10.87292957], [79.79245758, 10.87000179], [79.80278778, 10.8711319], [79.80898285, 10.86744022], [79.81138611, 10.86443138], [79.80558014, 10.86365032], [79.79178619, 10.86394978], [79.78956604, 10.8617506], [79.79727173, 10.85809135], [79.80345917, 10.85748005], [79.80745697, 10.8526907], [79.80815887, 10.8488903], [79.80338287, 10.84731007], [79.79940796, 10.84468269], [79.79563141, 10.84381199], [79.7922821, 10.84883118], [79.79113007, 10.84570122], [79.7931366, 10.83949089], [79.79667664, 10.83589172], [79.80307007, 10.83368969], [79.80589294, 10.82804012], [79.80819702, 10.8313818], [79.81204224, 10.83282185], [79.81326294, 10.82874012], [79.81368256, 10.81837177], [79.81167603, 10.8157692], [79.81333923, 10.81408119], [79.81976318, 10.81110191], [79.8319931, 10.81137085], [79.83571625, 10.8117218], [79.84329224, 10.81225109], [79.85124969, 10.81377125], [79.85124969, 10.80097103], [79.85097504, 10.80097103], [79.85097504, 10.79930496], [79.85069275, 10.79930973], [79.85069275, 10.79736137], [79.85097504, 10.79736137], [79.85097504, 10.79597282], [79.85069275, 10.79597282], [79.85069275, 10.7956953], [79.85097504, 10.7956953], [79.85097504, 10.78402805], [79.85069275, 10.78402996], [79.85069275, 10.78347015], [79.85097504, 10.78347206], [79.85097504, 10.7798624], [79.85124969, 10.7798624], [79.85124969, 10.77597427], [79.85152435, 10.77597427], [79.85152435, 10.76930523], [79.85180664, 10.7693119], [79.85180664, 10.76486015], [79.85152435, 10.76486015], [79.85152435, 10.76319408], [79.85124969, 10.76319408], [79.85124969, 10.76291561], [79.85069275, 10.76292133], [79.85069275, 10.76068974], [79.85097504, 10.76069355], [79.85097504, 10.75541782], [79.85069275, 10.75541973], [79.85069275, 10.75458241], [79.85041809, 10.75458431], [79.85041809, 10.75347233], [79.85069275, 10.75347233], [79.85069275, 10.75291538], [79.85098267, 10.75292015], [79.85098267, 10.75013924], [79.85069275, 10.75013924], [79.85069275, 10.74958134], [79.85097504, 10.74958324], [79.85097504, 10.74902725], [79.85124969, 10.74903202], [79.85124969, 10.7462492], [79.85152435, 10.7462492], [79.85151672, 10.74514103], [79.85124969, 10.74514103], [79.85124969, 10.74403095], [79.85151672, 10.74403095], [79.85151672, 10.73958015], [79.85124969, 10.73958302], [79.85124969, 10.73930359], [79.85151672, 10.73931122], [79.85151672, 10.73791885], [79.85180664, 10.73791885], [79.85180664, 10.73596954], [79.85152435, 10.7359724], [79.85152435, 10.73569393], [79.85180664, 10.73569393], [79.85180664, 10.73513794], [79.8520813, 10.7351408], [79.8520813, 10.73042011], [79.85234833, 10.73042011], [79.85234833, 10.72596931], [79.85263824, 10.72597218], [79.85263824, 10.72347355], [79.85236359, 10.72347355], [79.85236359, 10.72291756], [79.85263824, 10.72292042], [79.85263824, 10.72153187], [79.8529129, 10.72153187], [79.8529129, 10.71263885], [79.85319519, 10.71263885], [79.85319519, 10.70180607], [79.8529129, 10.70181274], [79.8529129, 10.70069122], [79.85319519, 10.70069408], [79.85319519, 10.69986153], [79.85346985, 10.69986153], [79.85346985, 10.69375134], [79.85319519, 10.69375134], [79.85319519, 10.69347095], [79.85346985, 10.69347095], [79.85346985, 10.69236088], [79.85319519, 10.69236088], [79.85319519, 10.69097328], [79.8529129, 10.69097328], [79.8529129, 10.6898613], [79.85319519, 10.6898613], [79.85319519, 10.68930531], [79.85346985, 10.68930531], [79.85346985, 10.68902683], [79.85375214, 10.68903065], [79.85375214, 10.68764114], [79.85346985, 10.68764114], [79.85346985, 10.68708038], [79.85319519, 10.68708324], [79.85319519, 10.68625069], [79.85346985, 10.68626022], [79.85346985, 10.68542099], [79.85375214, 10.68542099], [79.85375214, 10.68514061], [79.85346985, 10.68514061], [79.85346985, 10.68431091], [79.85320282, 10.68431091], [79.85320282, 10.68375111], [79.85346985, 10.68375111], [79.85346985, 10.68208218], [79.85375214, 10.68208218], [79.85375214, 10.66819477], [79.85346985, 10.66819477], [79.85346985, 10.65513802], [79.85320282, 10.65514088], [79.85320282, 10.65375042], [79.85346985, 10.65375042], [79.85346985, 10.65319443], [79.85375214, 10.65319443], [79.85375214, 10.64764023], [79.85402679, 10.64764023], [79.85402679, 10.64208126], [79.85430908, 10.64208317], [79.85430908, 10.63652897], [79.85457611, 10.63653088], [79.85457611, 10.63097], [79.8548584, 10.63097286], [79.8548584, 10.6254158], [79.85514069, 10.62542057], [79.85514069, 10.6198597], [79.85541534, 10.6198597], [79.85541534, 10.61430454], [79.85569763, 10.61431026], [79.85569763, 10.60903072], [79.85597229, 10.60903072], [79.85597229, 10.60375118], [79.85624695, 10.60375118], [79.85624695, 10.60124969], [79.85597229, 10.60124969], [79.85597229, 10.60097027], [79.85541534, 10.60097218], [79.85541534, 10.60041618], [79.85569763, 10.60042095], [79.85569763, 10.59931087], [79.85597229, 10.59931087], [79.85597229, 10.59542274], [79.85569763, 10.59542274], [79.85569763, 10.59514046], [79.85597229, 10.59514046], [79.85597229, 10.59486198], [79.85624695, 10.59486198], [79.85624695, 10.5923624], [79.85597229, 10.5923624], [79.85597229, 10.59152794], [79.85624695, 10.59152985], [79.85624695, 10.59069061], [79.85652924, 10.59069347], [79.85652924, 10.58930492], [79.85624695, 10.58930969], [79.85624695, 10.58819103], [79.85652924, 10.5881958], [79.85652924, 10.58791733], [79.85624695, 10.58792019], [79.85624695, 10.58708096], [79.85652924, 10.58708286], [79.85652924, 10.58680534], [79.85679626, 10.58681202], [79.85679626, 10.58597088], [79.85652924, 10.58597088], [79.85652924, 10.58569527], [79.85680389, 10.58569527], [79.85680389, 10.58291721], [79.85708618, 10.58292198], [79.85708618, 10.58125114], [79.85679626, 10.58125114], [79.85679626, 10.57986069], [79.85708618, 10.57986069], [79.85708618, 10.57902908], [79.85736084, 10.57903099], [79.85736084, 10.57514095], [79.85764313, 10.57514095], [79.85764313, 10.57181072], [79.85791779, 10.57181072], [79.85791779, 10.56875038], [79.85819244, 10.56875038], [79.85819244, 10.56597233], [79.85847473, 10.56597233], [79.85847473, 10.56513977], [79.85819244, 10.56513977], [79.85819244, 10.56485939], [79.85847473, 10.56486225], [79.85847473, 10.56291771], [79.85874939, 10.56293106], [79.85874939, 10.55986977], [79.85901642, 10.55986977], [79.85901642, 10.55708122], [79.85930634, 10.55708313], [79.85930634, 10.5540266], [79.85958099, 10.55403137], [79.85958099, 10.55014133], [79.85986328, 10.55014133], [79.85986328, 10.54514027], [79.86013794, 10.54514027], [79.86013794, 10.54257202], [79.86013794, 10.54041576], [79.86042023, 10.54041958], [79.86042023, 10.53542042], [79.86068726, 10.53542042], [79.86068726, 10.52930927], [79.86096954, 10.52930927], [79.86096954, 10.52153111], [79.86125183, 10.52153111], [79.86125183, 10.51375198], [79.86154175, 10.51375198], [79.86154175, 10.50458145], [79.86125183, 10.50458336], [79.86125183, 10.50430489], [79.86154175, 10.50430965], [79.86154175, 10.50347137], [79.86208344, 10.50347328], [79.86208344, 10.50319481], [79.86264038, 10.50319481], [79.86264038, 10.50152683], [79.86235809, 10.50153065], [79.86235809, 10.50097084], [79.86207581, 10.50097084], [79.86207581, 10.50069046], [79.86152649, 10.50069523], [79.86152649, 10.50041676], [79.86180878, 10.50042057], [79.86180878, 10.4998579], [79.86208344, 10.49986076], [79.86208344, 10.49902916], [79.86180878, 10.49903107], [79.86180878, 10.49764061], [79.86207581, 10.49764061], [79.86207581, 10.49736118], [79.86235809, 10.49736118], [79.86235809, 10.4948597], [79.86264038, 10.4948597], [79.86264038, 10.49208355], [79.86291504, 10.49208355], [79.86291504, 10.48291779], [79.86264038, 10.48291969], [79.86264038, 10.48124886], [79.86291504, 10.48124886], [79.86291504, 10.48069572], [79.86319733, 10.48069572], [79.86319733, 10.47958279], [79.86291504, 10.47958279], [79.86291504, 10.47902679], [79.86319733, 10.4790287], [79.86319733, 10.47874928], [79.86347198, 10.47874928], [79.86347198, 10.47791672], [79.86374664, 10.47791958], [79.86374664, 10.4776392], [79.86319733, 10.4776392], [79.86319733, 10.47736073], [79.86291504, 10.47736073], [79.86291504, 10.47652912], [79.86319733, 10.47653198], [79.86319733, 10.47542191], [79.86292267, 10.47542191], [79.86292267, 10.47514057], [79.86347198, 10.47514057], [79.86347198, 10.4745779], [79.86319733, 10.47458267], [79.86319733, 10.47430515], [79.86292267, 10.47431183], [79.86292267, 10.47403145], [79.86319733, 10.47403145], [79.86319733, 10.46819019], [79.86347198, 10.46819401], [79.86347198, 10.46541595], [79.86319733, 10.46542072], [79.86319733, 10.46403027], [79.86347198, 10.46403027], [79.86347198, 10.46375179], [79.86374664, 10.46375179], [79.86374664, 10.45903015], [79.86402893, 10.45903015], [79.86402893, 10.45514202], [79.86374664, 10.45514202], [79.86374664, 10.45458126], [79.86402893, 10.45458317], [79.86402893, 10.45402718], [79.86428833, 10.45403194], [79.86428833, 10.45014095], [79.86457825, 10.45014095], [79.86457825, 10.44486141], [79.86486053, 10.44486141], [79.86486053, 10.44069386], [79.86458588, 10.44069386], [79.86458588, 10.44041634], [79.86486053, 10.4404211], [79.86486053, 10.43931103], [79.86514282, 10.43931103], [79.86514282, 10.43375015], [79.86541748, 10.43375015], [79.86541748, 10.42819309], [79.86569214, 10.42819309], [79.86569214, 10.42152691], [79.8659668, 10.42154121], [79.8659668, 10.41625118], [79.86624908, 10.41625118], [79.86624908, 10.41597271], [79.86653137, 10.41597271], [79.86653137, 10.41485977], [79.86680603, 10.41485977], [79.86680603, 10.4118042], [79.86708069, 10.41181087], [79.86708069, 10.40874958], [79.86680603, 10.40874958], [79.86680603, 10.40847015], [79.86708069, 10.40847206], [79.86708069, 10.40819359], [79.86736298, 10.40819359], [79.86736298, 10.40652847], [79.86763763, 10.40653038], [79.86763763, 10.40347195], [79.86791992, 10.40347195], [79.86791992, 10.40180588], [79.86763763, 10.40180969], [79.86763763, 10.40069103], [79.86791992, 10.4006958], [79.86791992, 10.40041542], [79.86818695, 10.40043068], [79.86818695, 10.39763927], [79.86846924, 10.39763927], [79.86846924, 10.39542198], [79.86818695, 10.39542198], [79.86818695, 10.39486122], [79.86846924, 10.39486122], [79.86846924, 10.39458275], [79.86875153, 10.39458275], [79.86875153, 10.3918047], [79.86902618, 10.39181232], [79.86902618, 10.38931084], [79.86930847, 10.38931084], [79.86930847, 10.38708019], [79.86958313, 10.3870821], [79.86958313, 10.38458443], [79.86985779, 10.38458443], [79.86985779, 10.38208199], [79.87014008, 10.38208199], [79.87014008, 10.37986183], [79.87041473, 10.37986183], [79.87041473, 10.37736225], [79.87069702, 10.37736225], [79.87069702, 10.37486172], [79.87097168, 10.37486172], [79.87097168, 10.3726387], [79.87124634, 10.37264156], [79.87124634, 10.37012959], [79.87152863, 10.37013912], [79.87152863, 10.36819458], [79.87180328, 10.36819458], [79.87180328, 10.3670826], [79.87208557, 10.3670826], [79.87208557, 10.365695], [79.87236023, 10.365695], [79.87236023, 10.36458302], [79.87264252, 10.36458302], [79.87264252, 10.36319542], [79.87291718, 10.36319542], [79.87291718, 10.36180687], [79.87319183, 10.36181068], [79.87319183, 10.36069202], [79.87347412, 10.36069393], [79.87347412, 10.35930634], [79.87374878, 10.3593111], [79.87374878, 10.35818958], [79.87403107, 10.35819435], [79.87403107, 10.3568058], [79.87431335, 10.35681057], [79.87431335, 10.35569191], [79.87458038, 10.35569382], [79.87458038, 10.35430622], [79.87486267, 10.35431099], [79.87486267, 10.35319233], [79.87513733, 10.35319424], [79.87513733, 10.35180569], [79.87541962, 10.35181046], [79.87541962, 10.35069084], [79.87569427, 10.3506937], [79.87569427, 10.34930611], [79.87596893, 10.34931946], [79.87596893, 10.34792042], [79.87625122, 10.34792042], [79.87625122, 10.34681034], [79.87651825, 10.34681034], [79.87651825, 10.34542179], [79.87680817, 10.34542179], [79.87680817, 10.34430981], [79.87651825, 10.34430981], [79.87651825, 10.34347057], [79.87680817, 10.34347343], [79.87680817, 10.34319305], [79.87708282, 10.34319305], [79.87708282, 10.34291744], [79.87735748, 10.34291935], [79.87735748, 10.34125137], [79.87763977, 10.34125137], [79.87763977, 10.34013939], [79.87791443, 10.34013939], [79.87791443, 10.3390274], [79.87819672, 10.33903122], [79.87819672, 10.33763885], [79.87847137, 10.33763885], [79.87847137, 10.33625126], [79.87875366, 10.33625126], [79.87874603, 10.33485985], [79.87902832, 10.33485985], [79.87902832, 10.33347225], [79.87930298, 10.33347225], [79.87930298, 10.33236027], [79.87958527, 10.33236027], [79.87958527, 10.33097172], [79.87985992, 10.33097172], [79.87985992, 10.32958412], [79.88014221, 10.32958412], [79.88014221, 10.32819366], [79.88041687, 10.32819366], [79.88041687, 10.32680607], [79.88069153, 10.32681274], [79.88069153, 10.32568932], [79.88097382, 10.32569408], [79.88097382, 10.32430553], [79.88124847, 10.3243103], [79.88124847, 10.32291985], [79.88153076, 10.32291985], [79.88153076, 10.32153034], [79.88181305, 10.32153034], [79.88181305, 10.32014179], [79.88208008, 10.32014179], [79.88208008, 10.31902027], [79.88236237, 10.31902695], [79.88236237, 10.31763935], [79.88265228, 10.31763935], [79.88265228, 10.31652927], [79.88291931, 10.31652927], [79.88291931, 10.31596184], [79.88319397, 10.31597328], [79.88319397, 10.31513882], [79.88346863, 10.31514072], [79.88346863, 10.31458092], [79.88375092, 10.31458282], [79.88375092, 10.31402683], [79.8840332, 10.31403065], [79.8840332, 10.30597019], [79.88375092, 10.3059721], [79.88375092, 10.30541611], [79.88346863, 10.30542088], [79.88346863, 10.30486012], [79.88318634, 10.30486012], [79.88318634, 10.3043108], [79.88291931, 10.3043108], [79.88291931, 10.30375004], [79.88265228, 10.30375004], [79.88265228, 10.30319023], [79.88236237, 10.30319405], [79.88236237, 10.30291557], [79.88291931, 10.3029213], [79.88291931, 10.30235958], [79.88263702, 10.30236244], [79.88263702, 10.30208206], [79.88236237, 10.30208206], [79.88236237, 10.30180645], [79.88208008, 10.30181122], [79.88208008, 10.30153275], [79.88181305, 10.30153275], [79.88181305, 10.30125046], [79.88153076, 10.30125046], [79.88153076, 10.30097198], [79.88124847, 10.30098057], [79.88124847, 10.30042267], [79.88096619, 10.30042267], [79.88096619, 10.29986191], [79.88069153, 10.29986191], [79.88069153, 10.29930592], [79.88041687, 10.29931068], [79.88041687, 10.29874992], [79.88014221, 10.29874992], [79.88014221, 10.29819107], [79.87985992, 10.29819584], [79.87985992, 10.29763985], [79.87957764, 10.29763985], [79.87957764, 10.29708195], [79.87930298, 10.29708385], [79.87930298, 10.29652786], [79.87902832, 10.29652977], [79.87902832, 10.29625034], [79.87874603, 10.29625034], [79.87874603, 10.29597187], [79.87847137, 10.29597187], [79.87847137, 10.29569435], [79.87819672, 10.29569435], [79.87819672, 10.29541779], [79.87763977, 10.29541969], [79.87763977, 10.29514027], [79.87735748, 10.29514027], [79.87735748, 10.29485035], [79.87708282, 10.29486179], [79.87708282, 10.29458427], [79.87680817, 10.29458427], [79.87680817, 10.2943058], [79.87651825, 10.29430962], [79.87651825, 10.29403019], [79.87596893, 10.29403019], [79.87596893, 10.29374886], [79.87569427, 10.29374886], [79.87569427, 10.29347134], [79.87541962, 10.29347134], [79.87541962, 10.29319572], [79.87513733, 10.29319572], [79.87513733, 10.29291534], [79.87486267, 10.29292202], [79.87486267, 10.29264164], [79.87458038, 10.29264164], [79.87458038, 10.29236126], [79.87403107, 10.29236126], [79.87403107, 10.29264164], [79.87374878, 10.29264164], [79.87374878, 10.29236126], [79.87347412, 10.29236126], [79.87347412, 10.29180527], [79.87319183, 10.29181004], [79.87319183, 10.29152966], [79.87291718, 10.29152966], [79.87291718, 10.29124928], [79.87264252, 10.29124928], [79.87264252, 10.29097271], [79.87236023, 10.2909708], [79.87236023, 10.29069328], [79.87208557, 10.29069328], [79.87208557, 10.29041672], [79.87180328, 10.29041958], [79.87180328, 10.2901392], [79.87124634, 10.2901392], [79.87124634, 10.28986073], [79.87097168, 10.28986073], [79.87097168, 10.28958321], [79.87069702, 10.28958321], [79.87069702, 10.28930473], [79.87042236, 10.28931046], [79.87042236, 10.28904057], [79.87014008, 10.28904057], [79.87014008, 10.28875065], [79.86930847, 10.28875065], [79.86930847, 10.28847122], [79.86902618, 10.28847313], [79.86902618, 10.28819466], [79.86875153, 10.28819466], [79.86875153, 10.28791714], [79.86846924, 10.28792191], [79.86846924, 10.28764057], [79.86818695, 10.28764057], [79.86818695, 10.28736115], [79.86791992, 10.28736115], [79.86791992, 10.28708267], [79.86763763, 10.28708267], [79.86763763, 10.28680515], [79.86736298, 10.28681183], [79.86736298, 10.28653145], [79.86708069, 10.28653145], [79.86708069, 10.28625107], [79.86624908, 10.28625107], [79.86624908, 10.28598022], [79.86541748, 10.28598022], [79.86541748, 10.28569031], [79.86513519, 10.28569508], [79.86513519, 10.2854166], [79.86486053, 10.28542137], [79.86486053, 10.28514099], [79.86457825, 10.28514099], [79.86457825, 10.28486061], [79.86402893, 10.28486061], [79.86402893, 10.28458309], [79.86264038, 10.28458309], [79.86264038, 10.28430462], [79.86207581, 10.28430939], [79.86207581, 10.28403091], [79.86180878, 10.28403091], [79.86180878, 10.28375053], [79.86068726, 10.28375053], [79.86068726, 10.28347111], [79.86013794, 10.28347301], [79.86013794, 10.28319454], [79.85930634, 10.28319454], [79.85930634, 10.28263855], [79.85901642, 10.28264141], [79.85901642, 10.28181076], [79.85764313, 10.28181076], [79.85764313, 10.28153133], [79.85679626, 10.28153133], [79.85679626, 10.28125095], [79.85624695, 10.28125095], [79.85624695, 10.28096962], [79.85541534, 10.28097343], [79.85541534, 10.28069496], [79.8548584, 10.28069496], [79.8548584, 10.28041553], [79.85346985, 10.28041553], [79.85346985, 10.28069496], [79.8529129, 10.28069496], [79.8529129, 10.27985954], [79.85263824, 10.27985954], [79.85263824, 10.27958202], [79.8520813, 10.27958202], [79.8520813, 10.27930737], [79.85098267, 10.27931118], [79.85098267, 10.2790308], [79.8501358, 10.2790308], [79.8501358, 10.27875042], [79.84928894, 10.27875042], [79.84928894, 10.27847004], [79.84764099, 10.27847195], [79.84764099, 10.27819443], [79.8465271, 10.27819443], [79.8465271, 10.27791595], [79.84541321, 10.27792072], [79.84541321, 10.27764034], [79.84401703, 10.27764034], [79.84401703, 10.27735996], [79.8429184, 10.27735996], [79.8429184, 10.27708435], [79.8418045, 10.27708435], [79.8418045, 10.27680588], [79.84040833, 10.27681065], [79.84040833, 10.27653122], [79.83930206, 10.27653122], [79.83930206, 10.27625179], [79.8381958, 10.27625179], [79.8381958, 10.27597046], [79.83680725, 10.27597237], [79.83680725, 10.27569389], [79.83569336, 10.27569389], [79.83569336, 10.27541637], [79.82430267, 10.27542114], [79.82430267, 10.27514267], [79.82347107, 10.27514267], [79.82347107, 10.27486038], [79.82290649, 10.27486038], [79.82290649, 10.27514267], [79.82013702, 10.27514267], [79.82013702, 10.27486038], [79.81680298, 10.27486229], [79.81680298, 10.27458382], [79.81375122, 10.27458191], [79.81375122, 10.2743063], [79.81043243, 10.27431107], [79.81043243, 10.27403927], [79.80708313, 10.27403927], [79.80708313, 10.27375031], [79.8034668, 10.27375031], [79.8034668, 10.27403927], [79.80236053, 10.27403927], [79.80236053, 10.27375031], [79.80014038, 10.27375031], [79.80014038, 10.27347183], [79.79819489, 10.27347183], [79.79819489, 10.27319431], [79.79597473, 10.27319431], [79.79597473, 10.27291584], [79.78708649, 10.27291584], [79.78708649, 10.27319431], [79.77319336, 10.27319431], [79.77319336, 10.27347183], [79.76699066, 10.27347183], [79.76568604, 10.27347183], [79.76569366, 10.27375031], [79.75846863, 10.27375031], [79.75846863, 10.27403927], [79.75485992, 10.27403927], [79.75485992, 10.27431107], [79.75125122, 10.2743063], [79.75125122, 10.27458191], [79.74791718, 10.27458382], [79.74791718, 10.27486229], [79.74430847, 10.27486038], [79.74430847, 10.27514267], [79.74291992, 10.2751379], [79.74291992, 10.27569389], [79.74263763, 10.27569199], [79.74263763, 10.27625179], [79.74236298, 10.27625179], [79.74236298, 10.27681065], [79.74208069, 10.27680588], [79.74208069, 10.27735996], [79.74180603, 10.27735996], [79.74180603, 10.27792072], [79.74153137, 10.27791595], [79.74153137, 10.27847195], [79.74291992, 10.27847195], [79.74291992, 10.27763844], [79.74318695, 10.27764034], [79.74318695, 10.27681065], [79.74624634, 10.27680588], [79.74624634, 10.27708435], [79.74597168, 10.27708435], [79.74597168, 10.27735996]]]]}}, {\\\"id\\\": \\\"29\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.32_1\\\", \\\"HASC_1\\\": \\\"IN.TG\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Telangana\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -11.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 604.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1135.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -530.0, \\\"geo-id\\\": 29, \\\"hpm25_child_popweighted\\\": -110.2, \\\"hpm25_female_popweighted\\\": -126.7, \\\"hpm25_male_popweighted\\\": -91.2, \\\"location\\\": \\\"Telangana\\\", \\\"mort_apm25_6cod_mean_total\\\": 7039.0, \\\"mort_hpm25_6cod_mean_total\\\": -13259.0, \\\"mort_tpm25_6cod_mean_total\\\": -6219.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[79.21147156, 16.36281013], [79.22323608, 16.35036087], [79.22785187, 16.33681107], [79.22982025, 16.30022049], [79.22505951, 16.25007057], [79.21868896, 16.23964119], [79.2075119, 16.23067093], [79.19198608, 16.22271919], [79.17658234, 16.21713066], [79.16272736, 16.2202282], [79.15117645, 16.22462082], [79.14248657, 16.22925949], [79.13317871, 16.23637962], [79.12300873, 16.23791122], [79.06859589, 16.23814011], [79.05407715, 16.24255943], [79.04252625, 16.24495125], [79.03093719, 16.2457428], [79.0201416, 16.24427032], [79.01017761, 16.24044991], [78.99243164, 16.22830009], [78.97805786, 16.22307014], [78.95900726, 16.21722031], [78.94108582, 16.20981026], [78.92549896, 16.20233917], [78.90808105, 16.19104004], [78.90545654, 16.18186951], [78.90558624, 16.16492081], [78.92086029, 16.13367081], [78.92186737, 16.12187195], [78.91726685, 16.11351967], [78.91335297, 16.10884094], [78.91047668, 16.1052227], [78.90117645, 16.09762192], [78.8890686, 16.09856033], [78.87267303, 16.11017036], [78.86942291, 16.12162971], [78.86802673, 16.13526154], [78.86633301, 16.14385986], [78.86293793, 16.15308952], [78.85645294, 16.15859985], [78.84628296, 16.15954018], [78.83783722, 16.15673828], [78.83213043, 16.15176964], [78.83049774, 16.14215088], [78.83127594, 16.13297844], [78.83394623, 16.12014008], [78.83808899, 16.11086082], [78.84028625, 16.10283089], [78.83937836, 16.09424019], [78.83650208, 16.08737755], [78.82155609, 16.06220055], [78.81376648, 16.05219078], [78.80799866, 16.04619026], [78.79001617, 16.03269958], [78.7750473, 16.02360916], [78.75393677, 16.02100945], [78.73898315, 16.02114105], [78.72596741, 16.02304077], [78.71366882, 16.02666092], [78.68656158, 16.04038048], [78.67498016, 16.0490303], [78.66837311, 16.05579948], [78.65776062, 16.07143974], [78.646698, 16.08273125], [78.63648987, 16.09144974], [78.61701202, 16.09890938], [78.60350037, 16.09643936], [78.59256744, 16.08723068], [78.57643127, 16.07034111], [78.56711578, 16.06187057], [78.55912781, 16.05637169], [78.54689789, 16.05620003], [78.5328598, 16.06232262], [78.52083588, 16.0650692], [78.49559784, 16.0730896], [78.45101166, 16.0810318], [78.42095184, 16.0828495], [78.40566254, 16.08094978], [78.38424683, 16.07183075], [78.37003326, 16.05984116], [78.35311127, 16.05451012], [78.34041595, 16.05277061], [78.33114624, 16.04709053], [78.32356262, 16.03724289], [78.31620789, 16.02915192], [78.29218292, 16.02849007], [78.28105927, 16.03209114], [78.26815796, 16.03475952], [78.25666809, 16.03129959], [78.25138092, 16.02568054], [78.25868225, 16.00508118], [78.25974274, 15.99473095], [78.25293732, 15.97844028], [78.25110626, 15.97083855], [78.24835968, 15.9683094], [78.2473526, 15.96004963], [78.24401093, 15.9469614], [78.24286652, 15.93704891], [78.23796844, 15.9290514], [78.22786713, 15.92348099], [78.20539856, 15.91706085], [78.19667053, 15.91224003], [78.18003082, 15.90044975], [78.17919159, 15.89494038], [78.18148804, 15.88765144], [78.17907715, 15.87977886], [78.17384338, 15.87252045], [78.17066193, 15.86643887], [78.16867065, 15.85317039], [78.16467285, 15.84899044], [78.15093231, 15.84904003], [78.14840698, 15.84996986], [78.13791656, 15.85024071], [78.1258316, 15.84893131], [78.12687683, 15.83492088], [78.11978912, 15.83026886], [78.10958099, 15.82718086], [78.10114288, 15.82792187], [78.0636673, 15.84456158], [78.05847168, 15.85041046], [78.04886627, 15.87075138], [78.04071808, 15.87220097], [78.03981781, 15.89810085], [78.03629303, 15.90209103], [78.02879333, 15.90269089], [78.02423859, 15.89858246], [78.01696777, 15.89514923], [78.01473236, 15.88881111], [78.00660706, 15.87197018], [78.0018692, 15.85923004], [77.99360657, 15.86098003], [77.9728775, 15.87411976], [77.96308136, 15.87590027], [77.94402313, 15.87491035], [77.92829895, 15.87650967], [77.90756226, 15.88489056], [77.88768005, 15.89592171], [77.87638092, 15.89600182], [77.86694336, 15.8923893], [77.85565186, 15.87576103], [77.85011292, 15.87382126], [77.83976746, 15.87394047], [77.83384705, 15.87551022], [77.8253479, 15.87379074], [77.81772614, 15.86949062], [77.80921936, 15.86702919], [77.79918671, 15.86532021], [77.78978729, 15.86658859], [77.77889252, 15.8693018], [77.77020264, 15.87327194], [77.76004791, 15.876791], [77.74964142, 15.87587929], [77.73883057, 15.87852097], [77.73195648, 15.88221073], [77.72486115, 15.88479137], [77.71611786, 15.88657093], [77.70730591, 15.88409996], [77.69944763, 15.88043976], [77.69249725, 15.87532139], [77.68353271, 15.87389183], [77.65894318, 15.87652016], [77.64821625, 15.87893963], [77.63960266, 15.88313103], [77.63204956, 15.89180088], [77.62570953, 15.89913082], [77.61882019, 15.90375137], [77.61384583, 15.90783024], [77.60637665, 15.91172981], [77.59868622, 15.90874195], [77.58841705, 15.90699196], [77.58010101, 15.91020966], [77.57163239, 15.91232014], [77.54884338, 15.91366863], [77.53173828, 15.91611958], [77.50945282, 15.92086029], [77.51457977, 15.94342995], [77.51589966, 15.95746136], [77.51487732, 15.96315193], [77.50901031, 15.96744061], [77.50551605, 15.97266865], [77.50549316, 15.97876167], [77.50839996, 15.99582958], [77.51010895, 16.00225067], [77.5016861, 16.00554085], [77.50028229, 16.01135063], [77.4985733, 16.01389122], [77.49881744, 16.01716042], [77.49207306, 16.02556992], [77.49072266, 16.03063011], [77.4956665, 16.04771042], [77.49447632, 16.04977989], [77.49621582, 16.05477905], [77.49952698, 16.05426025], [77.50293732, 16.07323265], [77.4930191, 16.0796299], [77.4928894, 16.08377075], [77.49788666, 16.09721947], [77.50347137, 16.10152054], [77.50939941, 16.10353088], [77.50271606, 16.10947037], [77.49543762, 16.11465073], [77.49022675, 16.11615944], [77.48667145, 16.1157608], [77.48858643, 16.12646103], [77.48809814, 16.14739037], [77.48680878, 16.15307808], [77.48362732, 16.15855026], [77.4883728, 16.17868042], [77.49491882, 16.18712044], [77.49494171, 16.19535065], [77.49369812, 16.20617104], [77.49532318, 16.21300125], [77.50232697, 16.21570015], [77.50878143, 16.21494293], [77.51116943, 16.21718979], [77.51075745, 16.22333908], [77.50222778, 16.22478104], [77.49362183, 16.22302055], [77.4887619, 16.22434998], [77.48890686, 16.24183083], [77.48755646, 16.24982071], [77.49897003, 16.25786018], [77.50020599, 16.26068115], [77.50122833, 16.26781082], [77.51309204, 16.27071953], [77.51933289, 16.27088165], [77.52442169, 16.26978111], [77.52581787, 16.26702118], [77.53378296, 16.26263046], [77.53975677, 16.28263283], [77.54321289, 16.28705978], [77.54950714, 16.29067039], [77.56498718, 16.29771042], [77.56925964, 16.29477119], [77.57434082, 16.28894043], [77.58068085, 16.28606033], [77.59030151, 16.28685188], [77.59227753, 16.29010963], [77.58835602, 16.29565048], [77.59099579, 16.30461121], [77.5908432, 16.31197929], [77.5866394, 16.32044983], [77.58438873, 16.32804108], [77.59160614, 16.33751106], [77.58644104, 16.33793068], [77.57184601, 16.33595085], [77.55452728, 16.34156036], [77.54949188, 16.34468079], [77.54432678, 16.34975815], [77.53515625, 16.35293961], [77.52863312, 16.35836029], [77.51885986, 16.37010956], [77.51014709, 16.37018013], [77.49449158, 16.37578964], [77.48137665, 16.37776947], [77.46131134, 16.3754406], [77.44896698, 16.37580109], [77.43811035, 16.3744297], [77.43519592, 16.37267113], [77.42778015, 16.36507988], [77.42220306, 16.36284256], [77.41174316, 16.36268044], [77.40112305, 16.36602974], [77.38813782, 16.37179947], [77.37319946, 16.37992096], [77.35253906, 16.3766098], [77.34294891, 16.37972069], [77.33273315, 16.38829994], [77.30696869, 16.39402008], [77.29457855, 16.39960289], [77.28466034, 16.40299988], [77.27820587, 16.41070938], [77.27475739, 16.41773987], [77.26925659, 16.42308044], [77.26438904, 16.4300518], [77.25820923, 16.44730949], [77.25245667, 16.45329094], [77.23517609, 16.46808052], [77.23886108, 16.47290993], [77.24452209, 16.47221947], [77.25151062, 16.46790123], [77.28536224, 16.47151184], [77.29199982, 16.47363853], [77.29580688, 16.48134041], [77.29688263, 16.48588943], [77.29664612, 16.49147034], [77.30909729, 16.48933983], [77.31362152, 16.48755074], [77.32440948, 16.48093033], [77.32995605, 16.48069191], [77.34365845, 16.48205948], [77.3436203, 16.48488045], [77.34790039, 16.4855175], [77.35163116, 16.48332024], [77.35816956, 16.48315048], [77.36628723, 16.48410988], [77.36717224, 16.48693085], [77.36730957, 16.4937706], [77.36908722, 16.50210953], [77.37290192, 16.50601959], [77.37908173, 16.51072121], [77.38115692, 16.51153946], [77.38871002, 16.51210976], [77.39351654, 16.51486015], [77.40061188, 16.51595116], [77.41197968, 16.51381111], [77.41532135, 16.5178299], [77.41565704, 16.54400063], [77.40157318, 16.54677963], [77.4004364, 16.55023003], [77.39705658, 16.55289268], [77.39653778, 16.55554008], [77.39480591, 16.55824089], [77.39261627, 16.55945015], [77.39029694, 16.5597496], [77.39144135, 16.56520081], [77.39753723, 16.56335068], [77.40213013, 16.56629181], [77.41728973, 16.56390953], [77.42095947, 16.56517029], [77.43672943, 16.58120918], [77.44326019, 16.58205986], [77.45639038, 16.58099937], [77.46038055, 16.58346939], [77.46417236, 16.58420944], [77.46418762, 16.58719063], [77.46134186, 16.59065819], [77.45877838, 16.59205055], [77.46034241, 16.59555054], [77.46420288, 16.59514046], [77.4646759, 16.59744072], [77.46363068, 16.60481071], [77.45388031, 16.60741997], [77.4538269, 16.61379814], [77.45556641, 16.62001038], [77.4613266, 16.62478065], [77.46247101, 16.62920952], [77.46586609, 16.63594055], [77.47133636, 16.6435318], [77.46939087, 16.64691162], [77.46141815, 16.64883041], [77.45478058, 16.64487076], [77.44851685, 16.63883018], [77.44406128, 16.63579178], [77.43836975, 16.63620186], [77.43293762, 16.63763809], [77.43622589, 16.64253044], [77.43247223, 16.64306068], [77.43026733, 16.64472961], [77.42809296, 16.65007973], [77.42119598, 16.65199089], [77.41684723, 16.65475082], [77.41657257, 16.66281128], [77.43715668, 16.6665802], [77.44642639, 16.67416], [77.46170044, 16.67235947], [77.46504211, 16.67828178], [77.46750641, 16.69680023], [77.46746063, 16.70237923], [77.46877289, 16.70870972], [77.46679688, 16.71194077], [77.46103668, 16.71316147], [77.45627594, 16.71068954], [77.44845581, 16.71357918], [77.44541168, 16.71380043], [77.4373703, 16.70754814], [77.43325806, 16.70911026], [77.43000793, 16.71170044], [77.4254303, 16.71175957], [77.42341614, 16.71453094], [77.4241333, 16.71780014], [77.42672729, 16.71837997], [77.42755127, 16.72113991], [77.42633057, 16.72274971], [77.42569733, 16.72706032], [77.42784119, 16.72948265], [77.43128967, 16.73644066], [77.43534088, 16.74954987], [77.43721008, 16.76313019], [77.43527985, 16.77762032], [77.43753815, 16.78321075], [77.44454193, 16.78004265], [77.46733856, 16.77659988], [77.471138, 16.77913094], [77.47162628, 16.78518105], [77.47175598, 16.79628944], [77.46575928, 16.80083084], [77.46272278, 16.80451965], [77.45941162, 16.81776237], [77.45662689, 16.82374954], [77.46039581, 16.84411049], [77.46031189, 16.85453033], [77.45759583, 16.87928009], [77.45223999, 16.88159943], [77.45426178, 16.88612938], [77.45581818, 16.90465927], [77.45391846, 16.90627289], [77.45339966, 16.90903282], [77.4601059, 16.91292953], [77.46537018, 16.91407967], [77.46774292, 16.91711044], [77.46787262, 16.92419815], [77.46459961, 16.92489815], [77.46354675, 16.92904091], [77.4659729, 16.93457031], [77.46430206, 16.93980026], [77.46465302, 16.94637108], [77.46407318, 16.95269012], [77.46917725, 16.95384026], [77.47374725, 16.95947075], [77.47918701, 16.96803284], [77.47998047, 16.97517014], [77.47837067, 16.99024963], [77.481987, 16.99719048], [77.48323059, 16.99867821], [77.49357605, 17.0058403], [77.49938965, 17.0073204], [77.49819946, 17.01519966], [77.49199677, 17.02165031], [77.49323273, 17.0329895], [77.49186707, 17.03884125], [77.486763, 17.04467964], [77.48306274, 17.05344009], [77.47805786, 17.06098938], [77.47543335, 17.06989098], [77.47783661, 17.07226944], [77.47692108, 17.07623291], [77.46842957, 17.08111191], [77.46386719, 17.08671188], [77.46031189, 17.09284019], [77.46263885, 17.10407066], [77.45237732, 17.1076107], [77.44841766, 17.11149979], [77.43862915, 17.11458015], [77.43376923, 17.11115074], [77.42352295, 17.11405754], [77.41178894, 17.12051964], [77.4037323, 17.12321091], [77.39890289, 17.13191986], [77.37632751, 17.13788986], [77.37541962, 17.14870071], [77.36686707, 17.15133095], [77.35999298, 17.16162109], [77.36490631, 17.16494942], [77.36354828, 17.16948128], [77.36837006, 17.17648125], [77.36753082, 17.18320084], [77.37075043, 17.19007111], [77.37671661, 17.19300079], [77.38173676, 17.1937294], [77.39148712, 17.19236946], [77.39344788, 17.2069397], [77.39881134, 17.20877838], [77.39901733, 17.21153069], [77.39318848, 17.21147919], [77.38458252, 17.2129612], [77.38128662, 17.21632195], [77.38035583, 17.21977043], [77.38401794, 17.22331047], [77.39225006, 17.22855949], [77.39585114, 17.23285103], [77.3988266, 17.23188972], [77.40545654, 17.23740959], [77.41493988, 17.22987938], [77.41776276, 17.23278999], [77.42002106, 17.24160957], [77.42047882, 17.24933052], [77.4225769, 17.25325012], [77.43736267, 17.26136971], [77.44248199, 17.26859093], [77.44967651, 17.26986122], [77.45450592, 17.27589035], [77.45279694, 17.28663063], [77.4469986, 17.2888298], [77.434021, 17.28825951], [77.43776703, 17.29668999], [77.44043732, 17.2978096], [77.44798279, 17.31345177], [77.44963837, 17.31489944], [77.45137024, 17.32723045], [77.45250702, 17.32793045], [77.45510101, 17.3379097], [77.45635223, 17.34498978], [77.45298004, 17.34880829], [77.44976807, 17.35004807], [77.44988251, 17.3630619], [77.45159912, 17.37049103], [77.47931671, 17.36961174], [77.4753418, 17.36815071], [77.47241211, 17.36317825], [77.47447205, 17.35917091], [77.48261261, 17.35445976], [77.49237823, 17.35551071], [77.49912262, 17.35407066], [77.509758, 17.3592701], [77.52081299, 17.36205101], [77.52802277, 17.37211037], [77.53018188, 17.3778801], [77.52658844, 17.37882996], [77.52133179, 17.38633156], [77.53357697, 17.39884949], [77.5355072, 17.40410042], [77.53357697, 17.40610123], [77.52671814, 17.4059906], [77.51068878, 17.41254044], [77.51014709, 17.42725945], [77.52337646, 17.43668938], [77.53347015, 17.44095039], [77.54884338, 17.43492126], [77.5577774, 17.43527031], [77.57256317, 17.42951965], [77.57195282, 17.43855095], [77.57319641, 17.45420074], [77.59041595, 17.44810295], [77.59590149, 17.44268036], [77.60447693, 17.44309044], [77.61061096, 17.44423294], [77.61144257, 17.45290947], [77.61010742, 17.46463966], [77.61094666, 17.46994019], [77.61564636, 17.47140121], [77.62657166, 17.47120094], [77.6340332, 17.47223091], [77.64042664, 17.47601128], [77.64259338, 17.48344994], [77.64422607, 17.49489975], [77.64794922, 17.49936295], [77.65276337, 17.50325012], [77.64897156, 17.49155235], [77.64808655, 17.48117828], [77.66488647, 17.47628975], [77.68401337, 17.4728508], [77.68467712, 17.48522949], [77.68696594, 17.49156952], [77.68799591, 17.49854279], [77.68562317, 17.50564957], [77.68325043, 17.50402069], [77.68202972, 17.50666809], [77.67893982, 17.50510025], [77.66606903, 17.50995064], [77.66120911, 17.51481056], [77.65661621, 17.52133942], [77.64987946, 17.52107048], [77.64531708, 17.5187912], [77.63315582, 17.52308083], [77.62121582, 17.52225113], [77.61657715, 17.52935028], [77.60797119, 17.53107262], [77.60325623, 17.53069115], [77.59925079, 17.5340004], [77.59172821, 17.53268051], [77.592453, 17.5490799], [77.59185791, 17.55505943], [77.58982849, 17.5627594], [77.5854187, 17.56204033], [77.58538818, 17.55836105], [77.56083679, 17.5535202], [77.55612946, 17.55215073], [77.55281067, 17.55000114], [77.54839325, 17.54945946], [77.54395294, 17.55459976], [77.53669739, 17.57132912], [77.5320816, 17.5730896], [77.52742004, 17.57322121], [77.51390076, 17.55724907], [77.50965881, 17.54916954], [77.50161743, 17.5408802], [77.49681854, 17.5433712], [77.49555206, 17.54652977], [77.49563599, 17.55002975], [77.48999786, 17.56627083], [77.47408295, 17.56511116], [77.47207642, 17.56913185], [77.46911621, 17.56818008], [77.46515656, 17.57465935], [77.46121979, 17.57703018], [77.43992615, 17.58147049], [77.44207001, 17.59581184], [77.44050598, 17.60409164], [77.44130707, 17.60663033], [77.44650269, 17.60724068], [77.44580078, 17.61230087], [77.44882202, 17.62278938], [77.45321655, 17.63076973], [77.45081329, 17.63236046], [77.44753265, 17.64711952], [77.44500732, 17.64842033], [77.44564819, 17.65746117], [77.44909668, 17.66611099], [77.4509964, 17.68086052], [77.45140839, 17.68774033], [77.4503479, 17.69129944], [77.45462036, 17.69409752], [77.45786285, 17.69896126], [77.47155762, 17.70401001], [77.47415161, 17.70139122], [77.47867584, 17.70302963], [77.48108673, 17.70685005], [77.48446655, 17.70364952], [77.48932648, 17.70680046], [77.49173737, 17.71286011], [77.49427795, 17.71603966], [77.50544739, 17.7145195], [77.50946808, 17.71996117], [77.52258301, 17.72402954], [77.52755737, 17.72711754], [77.53398895, 17.72520256], [77.53936005, 17.72542191], [77.54412079, 17.73339081], [77.55187988, 17.73438072], [77.55464172, 17.74113083], [77.56202698, 17.74711037], [77.56595612, 17.76411057], [77.55445099, 17.76125908], [77.53697205, 17.7704525], [77.53449249, 17.77469063], [77.52760315, 17.77666092], [77.52304077, 17.77962112], [77.50934601, 17.7800808], [77.50448608, 17.78259087], [77.50701904, 17.79295921], [77.51087952, 17.80144119], [77.51805115, 17.80772018], [77.52607727, 17.81168938], [77.52600098, 17.82681847], [77.54371643, 17.82626915], [77.54479218, 17.81701088], [77.54973602, 17.8180294], [77.55432129, 17.83049011], [77.55918884, 17.83864021], [77.56346893, 17.84200096], [77.56215668, 17.84913063], [77.56604004, 17.84955978], [77.56743622, 17.86614037], [77.57274628, 17.87281036], [77.57772827, 17.87122917], [77.58127594, 17.87574959], [77.59275818, 17.86977959], [77.59668732, 17.87045097], [77.59777832, 17.87706947], [77.59249115, 17.87949944], [77.58521271, 17.8925209], [77.58307648, 17.89838028], [77.58516693, 17.90822983], [77.59979248, 17.90367126], [77.60444641, 17.90549088], [77.61657715, 17.90286827], [77.61894989, 17.91348076], [77.6186676, 17.92180824], [77.61952972, 17.93007088], [77.6167984, 17.93810081], [77.62001038, 17.94445992], [77.62428284, 17.94369125], [77.62886047, 17.94851112], [77.62899017, 17.95384026], [77.62374115, 17.95775032], [77.6297226, 17.96297073], [77.63182068, 17.95353127], [77.63561249, 17.95051956], [77.64061737, 17.9496212], [77.64398956, 17.94637108], [77.64742279, 17.95318985], [77.6428299, 17.95729065], [77.64425659, 17.96269035], [77.6520462, 17.96430016], [77.65339661, 17.96935272], [77.64742279, 17.97043991], [77.64360809, 17.97344971], [77.64888763, 17.97841072], [77.64978027, 17.98586273], [77.64775085, 17.98732185], [77.6461792, 17.9932003], [77.64228821, 17.99590111], [77.63822174, 17.99654007], [77.63272858, 17.99514008], [77.62879944, 17.99251938], [77.62145233, 17.99834061], [77.62390137, 18.00115967], [77.62229156, 18.00465965], [77.61585236, 18.00608826], [77.61006165, 18.01048088], [77.60666656, 18.01801109], [77.5994873, 18.01573944], [77.59224701, 18.01016808], [77.58724976, 18.01333046], [77.58496857, 18.02478981], [77.57448578, 18.03074074], [77.55782318, 18.03520012], [77.55311584, 18.03466988], [77.55206299, 18.04693985], [77.54807281, 18.0479908], [77.54574585, 18.05376053], [77.54743195, 18.06363106], [77.55670929, 18.06217003], [77.56048584, 18.07113075], [77.56733704, 18.07629013], [77.57744598, 18.07686996], [77.58979797, 18.08028984], [77.59745789, 18.08428955], [77.60056305, 18.09939957], [77.59661102, 18.12103081], [77.59350586, 18.12786102], [77.59777069, 18.15184021], [77.5891571, 18.15345955], [77.57936096, 18.16212082], [77.57753754, 18.16827011], [77.57247162, 18.17894936], [77.57002258, 18.18915939], [77.5643158, 18.18997955], [77.56430817, 18.20055008], [77.5743866, 18.19992065], [77.58496094, 18.21674156], [77.58106995, 18.22273827], [77.57676697, 18.23310089], [77.57253265, 18.24056053], [77.58149719, 18.25632095], [77.59194183, 18.26177025], [77.59902954, 18.27291107], [77.60301971, 18.27799988], [77.59784698, 18.28121948], [77.58381653, 18.28308105], [77.57433319, 18.28684807], [77.57463837, 18.28931046], [77.57065582, 18.29047012], [77.56098175, 18.28310966], [77.54995728, 18.29134941], [77.55503082, 18.29831123], [77.57022858, 18.30817986], [77.56691742, 18.3179493], [77.55335999, 18.33122253], [77.54219055, 18.33390045], [77.52732849, 18.33940125], [77.51950073, 18.3492527], [77.52140045, 18.36465073], [77.53050232, 18.37577057], [77.54155731, 18.38521957], [77.54930115, 18.3877182], [77.5552063, 18.4178524], [77.54413605, 18.42041016], [77.53515625, 18.42118073], [77.53598022, 18.42345047], [77.52593994, 18.427351], [77.52848053, 18.44048119], [77.53450775, 18.44239998], [77.54644775, 18.44055939], [77.56017303, 18.43504906], [77.56693268, 18.43861008], [77.57411957, 18.4393425], [77.5826416, 18.44306946], [77.58521271, 18.44544983], [77.58328247, 18.44719124], [77.58364868, 18.45355034], [77.55908966, 18.45800018], [77.54979706, 18.45796967], [77.54888153, 18.46080971], [77.54619598, 18.46338272], [77.54651642, 18.46571922], [77.55809021, 18.465271], [77.56040192, 18.46749115], [77.57063293, 18.46685982], [77.57652283, 18.48377991], [77.59075928, 18.48110962], [77.59311676, 18.47351074], [77.60106659, 18.47421074], [77.60375214, 18.4852581], [77.60283661, 18.49138069], [77.59388733, 18.49386978], [77.58627319, 18.50292015], [77.58706665, 18.50984955], [77.59646606, 18.51499939], [77.60144806, 18.52194977], [77.60040283, 18.52497101], [77.59329224, 18.52314186], [77.59329224, 18.52802086], [77.59819031, 18.5350399], [77.59726715, 18.54754066], [77.61087036, 18.54776955], [77.61329651, 18.54239082], [77.61582184, 18.54294014], [77.61633301, 18.54866982], [77.62906647, 18.55064011], [77.63440704, 18.54518127], [77.64048004, 18.55393028], [77.64881134, 18.55261993], [77.64955139, 18.54966164], [77.65219879, 18.54963112], [77.64946747, 18.54133034], [77.64528656, 18.53630066], [77.65756989, 18.5272007], [77.66207886, 18.53325081], [77.67590332, 18.54133987], [77.68274689, 18.54080963], [77.71235657, 18.55443954], [77.72793579, 18.55154037], [77.73651123, 18.55480957], [77.73538208, 18.56318092], [77.74716187, 18.58908081], [77.74809265, 18.60531044], [77.74298859, 18.62140083], [77.73602295, 18.63089752], [77.72972107, 18.64273262], [77.72975922, 18.64558983], [77.73011017, 18.64812279], [77.73092651, 18.65532112], [77.73317719, 18.65570068], [77.73324585, 18.66212845], [77.72811127, 18.66420937], [77.73285675, 18.6760006], [77.74466705, 18.68388939], [77.74949646, 18.68978119], [77.74990845, 18.6978302], [77.75762939, 18.70709038], [77.76438141, 18.70793915], [77.76879883, 18.7016201], [77.76940155, 18.6905899], [77.78643799, 18.68412018], [77.78650665, 18.69432068], [77.80222321, 18.71611977], [77.80271912, 18.72924995], [77.81038666, 18.74024963], [77.82318115, 18.76850128], [77.8275528, 18.78601265], [77.83746338, 18.80746078], [77.85922241, 18.81406021], [77.90759277, 18.82951927], [77.92874908, 18.82172012], [77.94255066, 18.82229042], [77.94522858, 18.83210945], [77.94413757, 18.84229088], [77.92964935, 18.84649086], [77.93235779, 18.85093117], [77.92459869, 18.85414124], [77.92533875, 18.85921097], [77.90606689, 18.86731911], [77.89920044, 18.86792755], [77.89865875, 18.88373947], [77.88767242, 18.88512039], [77.88260651, 18.89637947], [77.88157654, 18.90853119], [77.8692627, 18.91032028], [77.85663605, 18.90607071], [77.84049988, 18.91130066], [77.84113312, 18.92146111], [77.84430695, 18.93032074], [77.84870148, 18.93138123], [77.85372925, 18.95227814], [77.83049774, 18.95020103], [77.82739258, 18.94572067], [77.81269073, 18.94945908], [77.81520081, 18.95923996], [77.81286621, 18.96006012], [77.81713867, 18.98237038], [77.78713226, 18.98428154], [77.7815094, 18.97632027], [77.76735687, 18.98142052], [77.76843262, 18.99938011], [77.76574707, 19.00737953], [77.76532745, 19.0153904], [77.76426697, 19.0196209], [77.76216125, 19.02050972], [77.76023865, 19.02264023], [77.75739288, 19.0285511], [77.76093292, 19.0512104], [77.75955963, 19.05930138], [77.76168823, 19.06204033], [77.77098846, 19.05615997], [77.77794647, 19.05437088], [77.78309631, 19.05483055], [77.7911377, 19.05065918], [77.79454041, 19.05019188], [77.79718018, 19.05130959], [77.79566956, 19.0610199], [77.79715729, 19.06488037], [77.79353333, 19.07121086], [77.79445648, 19.07336998], [77.79728699, 19.07459068], [77.80130768, 19.08440971], [77.79976654, 19.0945797], [77.80024719, 19.09887123], [77.80265045, 19.10196114], [77.80576324, 19.10334015], [77.81517029, 19.10366249], [77.82237244, 19.09639931], [77.8254776, 19.0916996], [77.82861328, 19.08494186], [77.8338089, 19.08653259], [77.84218597, 19.08677101], [77.84658813, 19.08851814], [77.8481369, 19.09008026], [77.84818268, 19.09259987], [77.84414673, 19.09607124], [77.84519196, 19.11421013], [77.83863831, 19.11885071], [77.83393097, 19.13273811], [77.83109283, 19.13565254], [77.837677, 19.13830948], [77.84924316, 19.15528107], [77.84874725, 19.15942955], [77.85016632, 19.16231155], [77.85035706, 19.16765022], [77.85385895, 19.16943169], [77.85423279, 19.1722908], [77.85301971, 19.17682076], [77.85839081, 19.18077278], [77.84453583, 19.18819046], [77.84654999, 19.19697952], [77.85267639, 19.20459175], [77.85233307, 19.20971107], [77.85845184, 19.21846962], [77.86152649, 19.22629166], [77.86228943, 19.23396111], [77.86540222, 19.2379303], [77.86808014, 19.24611092], [77.86738586, 19.25526047], [77.8846283, 19.26023102], [77.89187622, 19.25709915], [77.90039062, 19.25612068], [77.90570831, 19.26721954], [77.90067291, 19.27712822], [77.89305878, 19.27839279], [77.8753891, 19.27977943], [77.86192322, 19.28409958], [77.86084747, 19.28763962], [77.86264038, 19.2953701], [77.86087799, 19.30212975], [77.87111664, 19.30573082], [77.87522888, 19.30890083], [77.88804626, 19.31241035], [77.89325714, 19.32116127], [77.8995285, 19.31779099], [77.90577698, 19.31578064], [77.91227722, 19.3179512], [77.92204285, 19.32591248], [77.92632294, 19.33190918], [77.93723297, 19.33575058], [77.94062805, 19.34250069], [77.9489212, 19.34127998], [77.96270752, 19.33176994], [77.96665192, 19.3273201], [77.97690582, 19.32105064], [77.98549652, 19.30899048], [77.99588776, 19.30571747], [78.01161194, 19.30111122], [78.01824951, 19.29632759], [78.02728271, 19.2786808], [78.03288269, 19.27411079], [78.04574585, 19.27086067], [78.04944611, 19.26272964], [78.04762268, 19.25563049], [78.04804993, 19.24751282], [78.0511322, 19.24176025], [78.05755615, 19.23974991], [78.07514191, 19.24654961], [78.0822525, 19.25477028], [78.09512329, 19.24985123], [78.09938812, 19.24547958], [78.12670898, 19.24640274], [78.13926697, 19.23944092], [78.14974213, 19.23005104], [78.1700592, 19.23633003], [78.18331909, 19.24154091], [78.186409, 19.24934959], [78.18325806, 19.26116943], [78.18315125, 19.27896118], [78.19317627, 19.30294037], [78.19551086, 19.31438065], [78.19506073, 19.32496071], [78.19715118, 19.33172989], [78.18711853, 19.3386097], [78.18225098, 19.34544754], [78.17959595, 19.35301018], [78.18136597, 19.3607502], [78.18445587, 19.36821938], [78.18482208, 19.37629128], [78.18698883, 19.38454819], [78.18756866, 19.39562035], [78.18216705, 19.41176987], [78.19811249, 19.40744972], [78.20548248, 19.41435051], [78.21508026, 19.42705154], [78.22426605, 19.43403244], [78.23361969, 19.43288994], [78.24581146, 19.42898941], [78.2519989, 19.4300499], [78.26183319, 19.44009972], [78.26692963, 19.44792938], [78.27321625, 19.45384026], [78.28199005, 19.45298958], [78.29115295, 19.44879913], [78.29733276, 19.44882965], [78.3088913, 19.45640945], [78.31195831, 19.46590042], [78.31204987, 19.47925949], [78.31001282, 19.48643112], [78.30361176, 19.49376106], [78.29943085, 19.50412941], [78.29870605, 19.51356125], [78.29548645, 19.53083992], [78.29502869, 19.53728104], [78.2914505, 19.5431118], [78.28460693, 19.55039024], [78.27910614, 19.55820084], [78.28534698, 19.56034088], [78.29650879, 19.55838013], [78.29928589, 19.56129265], [78.2999115, 19.56678009], [78.30612183, 19.56744194], [78.3111496, 19.57176971], [78.31204224, 19.57856178], [78.31004333, 19.58671188], [78.31098938, 19.60417938], [78.3088913, 19.6114006], [78.29897308, 19.62341118], [78.29550171, 19.63183022], [78.29242706, 19.64416122], [78.28755951, 19.65446091], [78.2726593, 19.6601696], [78.26972198, 19.66312981], [78.27339172, 19.67015076], [78.28581238, 19.68967056], [78.3049469, 19.68843079], [78.31606293, 19.69055176], [78.32010651, 19.69671059], [78.32269287, 19.70364952], [78.33251953, 19.70850945], [78.34527588, 19.71356964], [78.34429932, 19.72433281], [78.34541321, 19.73442268], [78.35320282, 19.73775101], [78.3608017, 19.75398064], [78.36479187, 19.76733971], [78.36773682, 19.78108025], [78.36699677, 19.79454041], [78.36048889, 19.80574036], [78.35161591, 19.81035042], [78.33921051, 19.81351089], [78.33598328, 19.81866074], [78.34136963, 19.83294106], [78.33899689, 19.83917999], [78.30316925, 19.84583092], [78.29412842, 19.84955025], [78.29421234, 19.85555077], [78.29769135, 19.87329292], [78.30761719, 19.90849113], [78.31019592, 19.91274071], [78.31951141, 19.91546822], [78.32837677, 19.9160881], [78.3351059, 19.91011047], [78.3345871, 19.9043026], [78.32660675, 19.89937973], [78.32296753, 19.89497185], [78.32524109, 19.89048195], [78.33625031, 19.88319016], [78.34668732, 19.88140106], [78.36575317, 19.8828907], [78.37446594, 19.87927055], [78.38414764, 19.87922287], [78.38497162, 19.87389183], [78.38417816, 19.86362076], [78.38597107, 19.85569954], [78.38593292, 19.85270119], [78.38923645, 19.84617805], [78.3976593, 19.83640289], [78.40904236, 19.82986069], [78.42867279, 19.82311058], [78.44458771, 19.81923103], [78.46465302, 19.8162117], [78.47618866, 19.81636047], [78.48429108, 19.80718994], [78.48947144, 19.7985096], [78.49391937, 19.79314995], [78.50366974, 19.79241943], [78.50961304, 19.80118942], [78.51239014, 19.81427956], [78.51921082, 19.81990051], [78.52626801, 19.82165909], [78.55792236, 19.81561089], [78.57370758, 19.81380272], [78.58499146, 19.81168938], [78.5917511, 19.81541061], [78.59527588, 19.81735039], [78.60365295, 19.81750107], [78.61434174, 19.81326103], [78.61933899, 19.8087101], [78.63520813, 19.8037796], [78.64833832, 19.80146027], [78.68637085, 19.78993988], [78.69590759, 19.789711], [78.70178986, 19.78557968], [78.70918274, 19.7727108], [78.71644592, 19.76679993], [78.72473145, 19.76897049], [78.73184204, 19.77285004], [78.73834991, 19.77943039], [78.74308777, 19.77965927], [78.75224304, 19.77729034], [78.76322937, 19.77563095], [78.77321625, 19.77937126], [78.78486633, 19.77874947], [78.79695129, 19.76857948], [78.80317688, 19.7600708], [78.80760956, 19.75798988], [78.8171463, 19.76041985], [78.82528687, 19.76037979], [78.83830261, 19.76208115], [78.84433746, 19.75900078], [78.84562683, 19.75835037], [78.85357666, 19.73800087], [78.85691833, 19.73130035], [78.8573761, 19.71973991], [78.86167145, 19.70590019], [78.86347961, 19.69676971], [78.86398315, 19.68670082], [78.86321259, 19.67949295], [78.85912323, 19.66890907], [78.8588028, 19.65631104], [78.87793732, 19.65680122], [78.89097595, 19.65526009], [78.90379333, 19.66455841], [78.91590881, 19.66773033], [78.93498993, 19.66217995], [78.94359589, 19.66514015], [78.95419312, 19.66341019], [78.96167755, 19.65876961], [78.96895599, 19.64923286], [78.96800232, 19.63936996], [78.9646759, 19.62955284], [78.96286011, 19.61732292], [78.96562195, 19.60451126], [78.97132874, 19.59725952], [78.978302, 19.59041023], [78.98052979, 19.5850811], [78.97785187, 19.5799427], [78.96898651, 19.57345963], [78.96470642, 19.57028008], [78.95446014, 19.56272125], [78.94956207, 19.55747032], [78.9545517, 19.55183029], [78.96485138, 19.55033112], [78.97355652, 19.54990005], [78.97847748, 19.55092239], [78.98635101, 19.5570507], [78.99285889, 19.56204033], [78.99556732, 19.5610199], [79.00006104, 19.55937004], [79.01219177, 19.5437603], [79.01835632, 19.5399704], [79.03881836, 19.54499054], [79.0515213, 19.54527283], [79.060112, 19.53872108], [79.06339264, 19.53125], [79.07383728, 19.52861023], [79.09661102, 19.53047943], [79.10286713, 19.52795029], [79.10235596, 19.51935959], [79.10473633, 19.51274109], [79.11281586, 19.50978088], [79.12644958, 19.50649071], [79.14026642, 19.50111008], [79.15696716, 19.48554993], [79.1690979, 19.46776962], [79.17778778, 19.46069145], [79.18904114, 19.45870018], [79.21871185, 19.46450043], [79.22293854, 19.4677906], [79.22068787, 19.47558975], [79.20877838, 19.48479843], [79.20684814, 19.49167061], [79.20807648, 19.4986496], [79.21570587, 19.51058006], [79.22342682, 19.51700974], [79.23200226, 19.52075005], [79.2366333, 19.52679825], [79.23835754, 19.53276062], [79.23934174, 19.54204941], [79.23816681, 19.55093193], [79.23976898, 19.55948067], [79.25010681, 19.57768059], [79.24868011, 19.58686066], [79.24378204, 19.59334183], [79.23770142, 19.59954071], [79.23709106, 19.60948944], [79.24386597, 19.61255264], [79.25522614, 19.61120987], [79.26786041, 19.60666084], [79.29323578, 19.59672165], [79.30484009, 19.59015083], [79.30961609, 19.58201027], [79.31426239, 19.56552124], [79.32150269, 19.57175064], [79.3296814, 19.57368088], [79.34088898, 19.57377052], [79.36902618, 19.57123184], [79.37119293, 19.56154823], [79.38070679, 19.55585098], [79.38896942, 19.54891968], [79.40184784, 19.53983116], [79.41361237, 19.53347969], [79.42318726, 19.53284073], [79.43028259, 19.53510094], [79.44126129, 19.53351021], [79.45818329, 19.51896095], [79.46512604, 19.50901031], [79.47042084, 19.49745178], [79.48004913, 19.50381279], [79.49331665, 19.5051918], [79.51339722, 19.51806068], [79.51584625, 19.52235985], [79.51595306, 19.53680992], [79.51481628, 19.54076195], [79.51499176, 19.54195023], [79.52622223, 19.54606056], [79.53499603, 19.54807091], [79.54265594, 19.54852295], [79.5447464, 19.54271126], [79.54519653, 19.5340004], [79.54769897, 19.52608109], [79.55249786, 19.52004242], [79.56559753, 19.5109005], [79.57344055, 19.50663948], [79.58265686, 19.50305176], [79.59134674, 19.50173187], [79.59805298, 19.50377083], [79.60085297, 19.50795174], [79.60243988, 19.51452065], [79.60293579, 19.52106857], [79.60721588, 19.53946114], [79.61090851, 19.54917908], [79.61580658, 19.55862999], [79.6213913, 19.56509972], [79.6397171, 19.57500076], [79.65261841, 19.57669258], [79.66504669, 19.57716942], [79.67801666, 19.57656288], [79.68479156, 19.57916832], [79.69568634, 19.58109093], [79.70511627, 19.58122063], [79.71292877, 19.58333015], [79.7299118, 19.59656906], [79.74032593, 19.60313988], [79.7542572, 19.60233116], [79.76628876, 19.60015106], [79.77754974, 19.59767914], [79.78542328, 19.59358978], [79.78629303, 19.58965111], [79.79329681, 19.58008957], [79.8052063, 19.57675934], [79.81109619, 19.57384109], [79.81659698, 19.56900978], [79.81954956, 19.56148911], [79.82063293, 19.552351], [79.82315826, 19.54430962], [79.82821655, 19.53701019], [79.85623169, 19.51711082], [79.86379242, 19.51359749], [79.87021637, 19.50496101], [79.87822723, 19.5007019], [79.90223694, 19.49649048], [79.911026, 19.49234009], [79.91779327, 19.48554039], [79.92354584, 19.47758102], [79.93286896, 19.46912193], [79.93725586, 19.46696091], [79.94020844, 19.46450996], [79.94499969, 19.45881844], [79.94621277, 19.45093918], [79.94577026, 19.44078064], [79.95923615, 19.42591095], [79.97000122, 19.40946007], [79.97305298, 19.40102005], [79.97260284, 19.39158058], [79.9707489, 19.38212967], [79.96724701, 19.37458038], [79.96652222, 19.36088943], [79.96452332, 19.3506794], [79.95715332, 19.33456993], [79.9573822, 19.32447052], [79.96364594, 19.30653954], [79.96177673, 19.29749107], [79.94895935, 19.28886032], [79.9451828, 19.28412056], [79.93190002, 19.25932121], [79.92016602, 19.22640991], [79.91932678, 19.21501923], [79.92250824, 19.20340919], [79.93525696, 19.18385124], [79.94243622, 19.17588043], [79.94320679, 19.17060089], [79.94069672, 19.1644001], [79.92611694, 19.16094971], [79.92230988, 19.15712929], [79.90596771, 19.14178848], [79.87120819, 19.12269974], [79.86310577, 19.11582184], [79.85804749, 19.10411072], [79.8600769, 19.09095955], [79.86109924, 19.05994987], [79.85700989, 19.04220009], [79.85958862, 19.03462982], [79.87103271, 19.03554153], [79.88111115, 19.04138947], [79.89084625, 19.04545021], [79.90293884, 19.04797935], [79.91610718, 19.04735947], [79.92597961, 19.04249001], [79.93306732, 19.02968979], [79.93448639, 19.02169991], [79.93279266, 18.99570084], [79.93134308, 18.97479057], [79.93221283, 18.97158051], [79.93588257, 18.95763969], [79.94094086, 18.93766022], [79.94135284, 18.91576958], [79.94011688, 18.89673805], [79.94094849, 18.87738991], [79.93900299, 18.85889244], [79.93332672, 18.84504128], [79.92550659, 18.83754158], [79.92082214, 18.83621025], [79.90409851, 18.83488083], [79.89401245, 18.83083916], [79.90909576, 18.80669022], [79.9162674, 18.79734039], [79.93199158, 18.78442955], [79.94007111, 18.78179169], [79.95014954, 18.77990913], [79.98153687, 18.77428055], [79.99291992, 18.77351952], [80.00908661, 18.76857948], [80.01235199, 18.76675987], [80.01448822, 18.76012993], [80.0165329, 18.75702095], [80.01870728, 18.75101089], [80.02966309, 18.74869919], [80.0328598, 18.74644089], [80.0463562, 18.72092056], [80.05326843, 18.71779823], [80.06189728, 18.71651268], [80.06549072, 18.71326256], [80.06790924, 18.70870972], [80.07470703, 18.70256042], [80.0789032, 18.70133972], [80.0821228, 18.7024498], [80.08444214, 18.70084], [80.08695221, 18.6975708], [80.10054779, 18.68495941], [80.10655975, 18.67752838], [80.11081696, 18.67618942], [80.11599731, 18.67584991], [80.11841583, 18.67913246], [80.12129211, 18.68120956], [80.130867, 18.68541145], [80.13658905, 18.68680191], [80.14227295, 18.68625259], [80.14874268, 18.69324112], [80.15220642, 18.69527817], [80.15808105, 18.69594002], [80.1619873, 18.69403076], [80.16462708, 18.69029808], [80.16739655, 18.68007088], [80.1709671, 18.67733955], [80.17565155, 18.67589951], [80.18895721, 18.67558098], [80.19095612, 18.67897034], [80.19165802, 18.6836319], [80.19410706, 18.68853188], [80.20191193, 18.6974411], [80.20787811, 18.70046043], [80.2143631, 18.70112991], [80.22000885, 18.69919014], [80.22531891, 18.69614983], [80.22998047, 18.69753075], [80.23557281, 18.70042038], [80.24169159, 18.70022011], [80.24666595, 18.70132065], [80.26036835, 18.71409988], [80.26753998, 18.71796989], [80.27091217, 18.71350098], [80.27790833, 18.71096039], [80.28884125, 18.69500923], [80.29631042, 18.68564034], [80.29946136, 18.67921066], [80.30780792, 18.65228081], [80.31500244, 18.63628769], [80.31931305, 18.62173271], [80.33146667, 18.59659958], [80.33667755, 18.59052086], [80.33879089, 18.58820915], [80.34184265, 18.58644104], [80.348526, 18.58848953], [80.35289764, 18.59094048], [80.35594177, 18.59370995], [80.35749054, 18.59834099], [80.35972595, 18.60218048], [80.36251831, 18.60374069], [80.36695099, 18.6046505], [80.37052917, 18.60305977], [80.38156128, 18.59359932], [80.38558197, 18.59649086], [80.38939667, 18.59925842], [80.39325714, 18.60296059], [80.40209198, 18.60717964], [80.40703583, 18.60774994], [80.41599274, 18.60878754], [80.41755676, 18.61071968], [80.45020294, 18.6263504], [80.45524597, 18.62490273], [80.4630127, 18.6226902], [80.46774292, 18.62280083], [80.47218323, 18.62368965], [80.48005676, 18.62763977], [80.48204803, 18.62791824], [80.4834671, 18.62812042], [80.48838806, 18.62672043], [80.49812317, 18.61765289], [80.51071167, 18.61567116], [80.51383209, 18.6131382], [80.51525116, 18.6072998], [80.518013, 18.60345078], [80.52179718, 18.60075951], [80.52857208, 18.59370041], [80.52871704, 18.59284973], [80.52931976, 18.58980942], [80.53003693, 18.58879089], [80.53199768, 18.58605957], [80.54043579, 18.58295059], [80.55779266, 18.57275963], [80.56195068, 18.5695591], [80.56794739, 18.56145096], [80.58146667, 18.55745125], [80.5955658, 18.5490799], [80.60098267, 18.54503059], [80.60402679, 18.54071999], [80.61081696, 18.53353119], [80.61384583, 18.52605057], [80.62132263, 18.52312851], [80.62697601, 18.51816177], [80.6326828, 18.51884079], [80.63347626, 18.51761246], [80.63497925, 18.51531029], [80.63564301, 18.51158905], [80.63640594, 18.50723076], [80.63533783, 18.50572968], [80.63350677, 18.50315094], [80.63395691, 18.50125122], [80.63459015, 18.49863052], [80.63681793, 18.49394989], [80.64485168, 18.48351097], [80.64826202, 18.4790802], [80.65077972, 18.4722805], [80.66236115, 18.4657402], [80.66610718, 18.46264076], [80.66982269, 18.46121025], [80.67153168, 18.45973969], [80.67318726, 18.45831108], [80.67414856, 18.45631981], [80.6805191, 18.45355034], [80.68245697, 18.45001984], [80.68280029, 18.44716072], [80.68309021, 18.44462013], [80.69191742, 18.44045067], [80.69496918, 18.4407711], [80.69889069, 18.43600082], [80.69525909, 18.43457031], [80.69262695, 18.42885017], [80.69100952, 18.41934967], [80.71302795, 18.4057312], [80.71734619, 18.40908051], [80.71827698, 18.40979958], [80.72248077, 18.41032028], [80.72653961, 18.40899086], [80.72878265, 18.40380096], [80.72712708, 18.39999962], [80.72400665, 18.39524841], [80.71572876, 18.38729095], [80.71594238, 18.38552284], [80.71626282, 18.38294029], [80.71862793, 18.37924194], [80.7227478, 18.37580109], [80.72424316, 18.37198257], [80.72306824, 18.36790085], [80.72289276, 18.3642292], [80.72276306, 18.36131096], [80.72405243, 18.35737038], [80.72638702, 18.35025024], [80.73478699, 18.33868027], [80.74292755, 18.32216072], [80.74443817, 18.3168602], [80.7452774, 18.30508995], [80.74462128, 18.30218124], [80.75132751, 18.29747009], [80.7529068, 18.29127121], [80.75702667, 18.28470993], [80.75949097, 18.28256989], [80.76156616, 18.28210258], [80.76322174, 18.28172112], [80.76638031, 18.27823257], [80.77340698, 18.26493073], [80.77739716, 18.25974083], [80.78161621, 18.25958252], [80.78489685, 18.25809097], [80.78663635, 18.25591087], [80.78811646, 18.25403976], [80.78827667, 18.24978065], [80.78726959, 18.24656105], [80.7842865, 18.24327087], [80.76937866, 18.2364006], [80.75688934, 18.22949982], [80.73326874, 18.21879005], [80.73226166, 18.20545006], [80.73253632, 18.19419098], [80.73455811, 18.17171288], [80.74507141, 18.16483116], [80.75385284, 18.16389084], [80.76239777, 18.16296959], [80.78691864, 18.16418076], [80.79364014, 18.16546059], [80.79792786, 18.16629982], [80.81085205, 18.17847252], [80.81067657, 18.18325996], [80.81791687, 18.18712044], [80.81874847, 18.19202042], [80.81772614, 18.21276093], [80.81835175, 18.21903038], [80.81719208, 18.22521019], [80.81891632, 18.23098183], [80.82419586, 18.23357964], [80.82958984, 18.23411942], [80.83423615, 18.23328018], [80.8396225, 18.2280407], [80.85910034, 18.22600174], [80.86174774, 18.22167015], [80.86353302, 18.21718979], [80.86749268, 18.20725822], [80.86725616, 18.20318031], [80.86564636, 18.20099258], [80.86126709, 18.19869995], [80.85650635, 18.19842911], [80.84915924, 18.20021057], [80.84877777, 18.19919014], [80.84819794, 18.19765091], [80.84848022, 18.19594955], [80.84893799, 18.19318962], [80.85222626, 18.18348122], [80.85263062, 18.17850113], [80.85167694, 18.16835976], [80.85578918, 18.15168953], [80.8555069, 18.14915085], [80.85526276, 18.14678955], [80.85549927, 18.14501953], [80.8557663, 18.14293098], [80.85838318, 18.1391201], [80.86035156, 18.13750076], [80.86160278, 18.1364727], [80.8620224, 18.13266945], [80.88111877, 18.13253021], [80.89292908, 18.13445091], [80.90072632, 18.13467026], [80.9119873, 18.13850975], [80.93199158, 18.14941025], [80.93582153, 18.15253067], [80.93672943, 18.15480042], [80.94422913, 18.15709114], [80.94985962, 18.16422844], [80.95419312, 18.16698074], [80.96556854, 18.16835976], [80.97367859, 18.16814995], [80.97383881, 18.1583004], [80.97480011, 18.15192032], [80.97263336, 18.14355087], [80.96753693, 18.13799286], [80.94935608, 18.12318039], [80.94754791, 18.11683846], [80.94979858, 18.1036911], [80.94983673, 18.0983181], [80.94835663, 18.09127045], [80.94597626, 18.08424187], [80.94399261, 18.08102036], [80.95243835, 18.07188034], [80.96350098, 18.04977989], [80.96595764, 18.04346848], [80.96227264, 18.03153038], [80.96264648, 18.03117943], [80.96321106, 18.02816963], [80.96389771, 18.02444077], [80.96617126, 18.01859856], [80.96845245, 18.0118103], [80.9699173, 18.00305939], [80.97151947, 17.99736977], [80.97264099, 17.99317932], [80.9731369, 17.98635292], [80.97383881, 17.97681046], [80.9759903, 17.96291924], [80.97805786, 17.9496212], [80.97981262, 17.94573021], [80.98013306, 17.94326019], [80.98058319, 17.93985939], [80.98329163, 17.93495178], [80.98464966, 17.92290115], [80.99196625, 17.91937065], [80.99433899, 17.91423035], [80.99723816, 17.89516068], [81.0018692, 17.86473083], [81.00332642, 17.8491497], [81.00434875, 17.83834839], [81.01257324, 17.81666946], [81.03244781, 17.78973007], [81.03765106, 17.78623962], [81.04522705, 17.78399086], [81.05597687, 17.78283119], [81.06128693, 17.78359032], [81.06581116, 17.78424072], [81.06910706, 17.78511047], [81.07360077, 17.78629112], [81.07647705, 17.79050064], [81.07956696, 17.79497147], [81.08708191, 17.80334282], [81.08908844, 17.81087112], [81.09770203, 17.81710052], [81.10903168, 17.82312012], [81.12124634, 17.82832909], [81.15956879, 17.85263062], [81.17637634, 17.84912109], [81.18379211, 17.84926987], [81.18730164, 17.84834099], [81.1919632, 17.84710121], [81.21349335, 17.83304977], [81.22036743, 17.82935905], [81.2279129, 17.82629013], [81.25403595, 17.81212997], [81.2633667, 17.81046295], [81.29812622, 17.80985069], [81.31505585, 17.81233978], [81.32598877, 17.81241035], [81.33537292, 17.81125069], [81.3445282, 17.81158066], [81.35749817, 17.81042099], [81.36107635, 17.80961037], [81.36760712, 17.8080883], [81.3744278, 17.80532074], [81.38413239, 17.80348969], [81.38497162, 17.80659294], [81.39431, 17.80812073], [81.40276337, 17.80532074], [81.40925598, 17.80483818], [81.41445923, 17.81011009], [81.41433716, 17.81643105], [81.41941833, 17.8205986], [81.42592621, 17.82127953], [81.43387604, 17.81575966], [81.43756866, 17.81529045], [81.45942688, 17.82471085], [81.46684265, 17.82492065], [81.47012329, 17.82318115], [81.47271729, 17.81789017], [81.47457123, 17.80999947], [81.47870636, 17.80470848], [81.48117828, 17.80286026], [81.48583984, 17.8026104], [81.49632263, 17.80647087], [81.51130676, 17.80656052], [81.52572632, 17.81087112], [81.55393982, 17.8163681], [81.56459045, 17.82569122], [81.56874084, 17.82788086], [81.57486725, 17.82734108], [81.59395599, 17.81911087], [81.59973907, 17.81544113], [81.61115265, 17.81536293], [81.61569977, 17.82201004], [81.62397766, 17.82442284], [81.63143921, 17.83044052], [81.6365509, 17.83628082], [81.64279175, 17.83928108], [81.64614105, 17.84687042], [81.64601898, 17.85626984], [81.64906311, 17.86246872], [81.65270233, 17.86819077], [81.6569519, 17.8728199], [81.66306305, 17.87693024], [81.66805267, 17.87842941], [81.67774963, 17.87758064], [81.6832428, 17.87948036], [81.68828583, 17.88479996], [81.69787598, 17.87553978], [81.69927216, 17.8697319], [81.70317078, 17.86112976], [81.72631836, 17.87409973], [81.75829315, 17.89336014], [81.7634201, 17.88540077], [81.76885986, 17.87869835], [81.78144073, 17.87071991], [81.78753662, 17.86251068], [81.79277039, 17.8525219], [81.79440308, 17.84415054], [81.78784943, 17.83924103], [81.78235626, 17.83195114], [81.76393127, 17.82992935], [81.75293732, 17.81830978], [81.7388916, 17.8216095], [81.72959137, 17.8192997], [81.72342682, 17.81522179], [81.70951843, 17.80511093], [81.70398712, 17.79956055], [81.69824219, 17.78449059], [81.69138336, 17.77570152], [81.68477631, 17.77056122], [81.67469025, 17.76711082], [81.65299988, 17.76561165], [81.64189911, 17.76564026], [81.62306213, 17.76279068], [81.61859131, 17.75858116], [81.61281586, 17.74693108], [81.60919952, 17.7436409], [81.58194733, 17.73065948], [81.57662201, 17.72609138], [81.5729599, 17.71866989], [81.57198334, 17.71183014], [81.57108307, 17.70289993], [81.57116699, 17.68786812], [81.56819153, 17.68283081], [81.56018066, 17.67665291], [81.5536499, 17.66638947], [81.54608917, 17.65069962], [81.54432678, 17.64529991], [81.53414917, 17.63042259], [81.51895905, 17.61878967], [81.51187897, 17.60988045], [81.50927734, 17.60355949], [81.50926971, 17.59832954], [81.50789642, 17.59532166], [81.50292969, 17.58987999], [81.51267242, 17.58296013], [81.52089691, 17.57574081], [81.52390289, 17.57261086], [81.52371979, 17.56970978], [81.52030945, 17.56460953], [81.51374054, 17.55726051], [81.50907898, 17.54932022], [81.5014267, 17.53936005], [81.49946594, 17.53153992], [81.49803162, 17.51007271], [81.49951172, 17.50154114], [81.49816132, 17.48999977], [81.49360657, 17.47702026], [81.49373627, 17.4659996], [81.49585724, 17.46037102], [81.49536133, 17.45380974], [81.49341583, 17.44882011], [81.481987, 17.43220139], [81.47223663, 17.41953087], [81.45726013, 17.40539932], [81.45155334, 17.39833069], [81.44608307, 17.39069176], [81.44151306, 17.38171005], [81.43364716, 17.37494278], [81.42011261, 17.37218285], [81.41831207, 17.36638069], [81.41564941, 17.36162949], [81.40644836, 17.36141014], [81.38522339, 17.35513115], [81.37864685, 17.35612106], [81.37180328, 17.3571682], [81.36395264, 17.36026001], [81.34983826, 17.36852264], [81.34329987, 17.37572098], [81.34292603, 17.38541031], [81.33734894, 17.38999939], [81.33035278, 17.39209938], [81.3246994, 17.3906498], [81.32247162, 17.38915062], [81.31162262, 17.37478065], [81.30162048, 17.35972977], [81.29881287, 17.35214043], [81.28916931, 17.33754921], [81.28179932, 17.3297596], [81.26716614, 17.31999969], [81.26222229, 17.32194138], [81.25752258, 17.32266045], [81.23429108, 17.32282066], [81.21875, 17.3217392], [81.19030762, 17.32736969], [81.18154144, 17.32222939], [81.17822266, 17.31451035], [81.17195892, 17.30545044], [81.17061615, 17.29646111], [81.17114258, 17.26666069], [81.17463684, 17.26037025], [81.18055725, 17.25460052], [81.16799927, 17.24232101], [81.16278839, 17.23258018], [81.14554596, 17.23166275], [81.11817932, 17.2245903], [81.08450317, 17.21364021], [81.06221008, 17.20409966], [81.05384064, 17.21014023], [81.04654694, 17.2138176], [81.04386139, 17.20454025], [81.03996277, 17.19994164], [81.03485107, 17.1972599], [81.03145599, 17.19235039], [81.02617645, 17.1866684], [81.00540161, 17.18444824], [80.99771881, 17.18201065], [80.99125671, 17.17970276], [80.98516083, 17.17938995], [80.96633148, 17.1845417], [80.95598602, 17.18820953], [80.94773102, 17.19333076], [80.93904877, 17.20038033], [80.9306488, 17.20503044], [80.92064667, 17.20582962], [80.91384888, 17.20525932], [80.90534973, 17.20129013], [80.90763855, 17.19285965], [80.90699005, 17.18384171], [80.90847778, 17.17803955], [80.91301727, 17.17378044], [80.91487122, 17.16983986], [80.91400146, 17.16077042], [80.9121933, 17.15350914], [80.91330719, 17.14595032], [80.90939331, 17.14245033], [80.90397644, 17.14114952], [80.89615631, 17.1407795], [80.88886261, 17.14105034], [80.87676239, 17.14520073], [80.87030792, 17.14630127], [80.8667984, 17.12462044], [80.86347198, 17.11799812], [80.85504913, 17.11141014], [80.86421204, 17.09581757], [80.86239624, 17.08563042], [80.86254883, 17.08152962], [80.85646057, 17.06851959], [80.85884857, 17.05085182], [80.85489655, 17.04404068], [80.85053253, 17.0401516], [80.84487915, 17.03284073], [80.83246613, 17.02571106], [80.82930756, 17.0323391], [80.82322693, 17.03778076], [80.80322266, 17.0425396], [80.79284668, 17.04303932], [80.78528595, 17.04762268], [80.78019714, 17.04879951], [80.76609802, 17.0503006], [80.74659729, 17.05491829], [80.7257309, 17.06460953], [80.71261597, 17.06546021], [80.69516754, 17.06834984], [80.68399811, 17.06874084], [80.68139648, 17.06430054], [80.67563629, 17.0612793], [80.66777039, 17.05992126], [80.66059875, 17.05672073], [80.64919281, 17.05458069], [80.63960266, 17.05512047], [80.63392639, 17.05887985], [80.6377182, 17.06561089], [80.63775635, 17.07193947], [80.64438629, 17.07710075], [80.65541077, 17.08397102], [80.65664673, 17.08776283], [80.64626312, 17.09445953], [80.63640594, 17.09699059], [80.62523651, 17.10173988], [80.62975311, 17.11001968], [80.62391663, 17.11188126], [80.61654663, 17.11569977], [80.61292267, 17.11664009], [80.60388184, 17.11551094], [80.59510803, 17.11956024], [80.58026123, 17.13095093], [80.57348633, 17.13529015], [80.56017303, 17.1380291], [80.54907227, 17.12362289], [80.54165649, 17.12041092], [80.53542328, 17.11978912], [80.52916718, 17.11364937], [80.51941681, 17.10815048], [80.51172638, 17.10621071], [80.49611664, 17.10786057], [80.49653625, 17.10129166], [80.49240112, 17.09244156], [80.48873138, 17.08733177], [80.48678589, 17.08289909], [80.48462677, 17.06759071], [80.48465729, 17.05631065], [80.48220062, 17.05027008], [80.47506714, 17.04281044], [80.47174835, 17.0381012], [80.46422577, 17.03718185], [80.45288849, 17.03704262], [80.44624329, 17.01702118], [80.43266296, 17.02178192], [80.42053986, 17.02486038], [80.41777802, 17.02861023], [80.41429138, 17.0417881], [80.40087128, 17.05418968], [80.39890289, 17.05978966], [80.39977264, 17.0652504], [80.3973465, 17.07389069], [80.3950882, 17.07756805], [80.39319611, 17.07781029], [80.39012146, 17.07620049], [80.37905884, 17.06615067], [80.37416077, 17.06311035], [80.36699677, 17.05656815], [80.36775208, 17.05269814], [80.37162018, 17.04752922], [80.37838745, 17.03412056], [80.37722015, 17.02787018], [80.37789154, 17.02334023], [80.38376617, 17.01975822], [80.38871765, 17.01406097], [80.38790894, 17.00729942], [80.3864975, 17.00294113], [80.38197327, 17.00004005], [80.37119293, 16.99584007], [80.37120056, 16.99315071], [80.37161255, 16.98711967], [80.36972046, 16.98295021], [80.36106873, 16.9744606], [80.35824585, 16.97063065], [80.36042023, 16.97050095], [80.38080597, 16.96251106], [80.39762115, 16.95701027], [80.41234589, 16.95417023], [80.44254303, 16.94494057], [80.45308685, 16.9383297], [80.46324921, 16.93021011], [80.46985626, 16.92651176], [80.47688293, 16.92117119], [80.48781586, 16.91744041], [80.48558807, 16.92703819], [80.48693848, 16.93685913], [80.49130249, 16.94818115], [80.509758, 16.94243813], [80.52069092, 16.93639946], [80.53173828, 16.95017815], [80.56948853, 16.92688942], [80.58419037, 16.92651939], [80.58914185, 16.91666985], [80.59030914, 16.91163063], [80.5893631, 16.9071312], [80.58587646, 16.90432167], [80.5821228, 16.90310287], [80.58123779, 16.89677811], [80.58335876, 16.89060974], [80.58577728, 16.88716125], [80.58674622, 16.87393951], [80.57650757, 16.87310028], [80.56497192, 16.86903954], [80.56482697, 16.84991074], [80.56400299, 16.84256172], [80.56243134, 16.83632088], [80.55458069, 16.82478905], [80.55602264, 16.81841087], [80.56124878, 16.81712914], [80.56700897, 16.81710052], [80.57176971, 16.81209946], [80.58584595, 16.8066597], [80.59364319, 16.79791832], [80.59777832, 16.79203033], [80.60410309, 16.78775978], [80.59751892, 16.78508949], [80.56933594, 16.77075005], [80.56281281, 16.76283073], [80.54650879, 16.76765823], [80.53005981, 16.77005959], [80.51806641, 16.76876831], [80.51098633, 16.76993752], [80.48953247, 16.77585983], [80.48464966, 16.78131104], [80.47905731, 16.78495026], [80.47101593, 16.78832054], [80.45639801, 16.79002953], [80.45507813, 16.80648041], [80.4526062, 16.81529045], [80.44476318, 16.81939125], [80.43183136, 16.82385063], [80.43210602, 16.82718086], [80.4228363, 16.82930946], [80.42140961, 16.83712006], [80.41867065, 16.84231949], [80.39971161, 16.84973907], [80.400177, 16.83704948], [80.39914703, 16.83158112], [80.39422607, 16.82516289], [80.3793869, 16.81953049], [80.37784576, 16.81248093], [80.37587738, 16.8106308], [80.37293243, 16.81110001], [80.36711121, 16.82676125], [80.36472321, 16.83890152], [80.36120605, 16.85038185], [80.35862732, 16.8549099], [80.35090637, 16.85330009], [80.33495331, 16.85573959], [80.33731079, 16.86708069], [80.32731628, 16.87101936], [80.3192215, 16.87094116], [80.3184433, 16.87743759], [80.31600189, 16.88400078], [80.31613159, 16.89466286], [80.31328583, 16.91200256], [80.31537628, 16.91238976], [80.30784607, 16.92381287], [80.30396271, 16.93947029], [80.30137634, 16.95586014], [80.28898621, 16.97680283], [80.27617645, 16.99324989], [80.26217651, 17.01062965], [80.25026703, 17.00737953], [80.2411499, 17.00280952], [80.23574829, 17.00233078], [80.23223877, 17.0049305], [80.2178421, 17.0196209], [80.21321869, 17.0191803], [80.2012558, 17.01313972], [80.19554901, 17.01804161], [80.19610596, 17.02568817], [80.19426727, 17.04251289], [80.18212891, 17.04494095], [80.17053223, 17.03041267], [80.16718292, 17.02362061], [80.14911652, 17.00805092], [80.14247131, 17.0014801], [80.14057159, 16.99328995], [80.13385773, 16.98535919], [80.12689972, 16.98533058], [80.12014771, 16.98681068], [80.11467743, 16.98587036], [80.11279297, 16.98232079], [80.10578918, 16.98131943], [80.09947205, 16.98280144], [80.08769226, 16.98744011], [80.08394623, 16.9776783], [80.08423615, 16.96319008], [80.04588318, 16.96529961], [80.03705597, 16.93647003], [80.02849579, 16.92741013], [80.01860046, 16.91880989], [80.009552, 16.90726089], [80.0027771, 16.89146805], [79.99505615, 16.87731171], [79.99167633, 16.86325073], [79.994133, 16.86218071], [80.01383209, 16.85293961], [80.03309631, 16.85244942], [80.03436279, 16.84776115], [80.03439331, 16.83912277], [80.03666687, 16.83238983], [80.0418396, 16.82606125], [80.06967163, 16.81360817], [80.06492615, 16.80251122], [80.05767059, 16.78187943], [80.05158997, 16.77128983], [80.04789734, 16.74515152], [80.04335022, 16.73970032], [80.03276062, 16.73178101], [80.0233078, 16.71847916], [80.01667786, 16.71183014], [80.002388, 16.70294952], [79.99368286, 16.69444084], [79.99151611, 16.69255066], [79.97302246, 16.6595211], [79.95815277, 16.64204979], [79.94256592, 16.63262939], [79.92366791, 16.63073921], [79.91382599, 16.63313103], [79.90207672, 16.63784981], [79.89092255, 16.64956093], [79.88065338, 16.67617035], [79.87330627, 16.68869972], [79.86183929, 16.69822121], [79.84456635, 16.69646072], [79.8259201, 16.69146919], [79.81025696, 16.69049072], [79.7833786, 16.72484016], [79.77490234, 16.7295208], [79.76309204, 16.7271328], [79.75048065, 16.72011948], [79.7338028, 16.69802094], [79.72274017, 16.69260979], [79.6830368, 16.6903801], [79.66864014, 16.68400955], [79.65550232, 16.67408943], [79.64803314, 16.66200066], [79.63329315, 16.6608696], [79.61680603, 16.66464043], [79.59990692, 16.66327095], [79.58558655, 16.65135002], [79.57402039, 16.64359093], [79.56359863, 16.63806915], [79.55399323, 16.63459015], [79.53671265, 16.63156128], [79.51212311, 16.63365173], [79.49717712, 16.63051033], [79.47009277, 16.61874962], [79.45059204, 16.60914993], [79.44315338, 16.59370041], [79.43450165, 16.58566093], [79.42658997, 16.58252144], [79.40270996, 16.58044052], [79.34552765, 16.57956123], [79.33333588, 16.57852173], [79.31977844, 16.57587051], [79.29512024, 16.56735039], [79.28237915, 16.56544113], [79.26611328, 16.56147003], [79.26077271, 16.54642105], [79.23044586, 16.51929092], [79.22527313, 16.50822067], [79.22410583, 16.49213982], [79.23091125, 16.48167038], [79.23513031, 16.47068977], [79.23618317, 16.45853996], [79.22635651, 16.45253944], [79.21906281, 16.43816948], [79.21501923, 16.41576195], [79.21260071, 16.39376068], [79.21330261, 16.37438965], [79.21147156, 16.36281013]]]}}, {\\\"id\\\": \\\"30\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.33_1\\\", \\\"HASC_1\\\": \\\"IN.TR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Tripura\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": -5.8, \\\"dalys_apm25_rate_6cod_mean_total\\\": 884.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -2038.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1154.0, \\\"geo-id\\\": 30, \\\"hpm25_child_popweighted\\\": -173.1, \\\"hpm25_female_popweighted\\\": -199.0, \\\"hpm25_male_popweighted\\\": -143.3, \\\"location\\\": \\\"Tripura\\\", \\\"mort_apm25_6cod_mean_total\\\": 1370.0, \\\"mort_hpm25_6cod_mean_total\\\": -3099.0, \\\"mort_tpm25_6cod_mean_total\\\": -1728.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[91.38983154, 23.17717171], [91.38968658, 23.17726326], [91.38961792, 23.17733574], [91.38951874, 23.17742538], [91.38946533, 23.17752838], [91.38930511, 23.17773056], [91.38920593, 23.17787743], [91.38913727, 23.17794991], [91.38907623, 23.17809677], [91.38897705, 23.1782856], [91.3888855, 23.17844582], [91.38885498, 23.17857742], [91.3888092, 23.17868042], [91.38871765, 23.17886925], [91.38867188, 23.17901421], [91.3886261, 23.17911911], [91.38864136, 23.17930794], [91.38877106, 23.17939377], [91.38885498, 23.17943001], [91.38983154, 23.17717171]]], [[[91.41801453, 23.25741768], [91.41793823, 23.25728226], [91.41781616, 23.2571888], [91.41768646, 23.25718689], [91.41764832, 23.25725174], [91.41779327, 23.2573452], [91.41801453, 23.25741768]]], [[[92.03777313, 24.37796402], [92.03799438, 24.37792587], [92.03791809, 24.37782097], [92.03777313, 24.37796402]]], [[[91.71310425, 22.98869514], [91.71295929, 22.98880577], [91.71283722, 22.9889164], [91.71266174, 22.98898888], [91.71246338, 22.98899269], [91.7122879, 22.98898888], [91.71205139, 22.98907471], [91.71180725, 22.98895454], [91.71189117, 22.98889542], [91.71147919, 22.98868752], [91.71131897, 22.98848915], [91.71115112, 22.98822594], [91.71101379, 22.98796654], [91.71108246, 22.98776245], [91.71123505, 22.98749924], [91.71130371, 22.98731422], [91.71131897, 22.9871788], [91.71128082, 22.98686218], [91.71128845, 22.9866333], [91.71131897, 22.98617172], [91.71137238, 22.98588371], [91.71134949, 22.98570061], [91.71146393, 22.98517227], [91.71152496, 22.98477364], [91.71154022, 22.9845314], [91.71155548, 22.98442841], [91.71160889, 22.98410034], [91.71160126, 22.98391914], [91.71157837, 22.98371124], [91.71142578, 22.98364639], [91.71131897, 22.98344994], [91.71115112, 22.98308372], [91.71115875, 22.98298645], [91.71099091, 22.98266983], [91.71081543, 22.98253059], [91.71055603, 22.9823761], [91.70991516, 22.98211288], [91.7097702, 22.98209], [91.70934296, 22.98201561], [91.70901489, 22.98201752], [91.70891571, 22.9820118], [91.70874786, 22.98198509], [91.70856476, 22.98200226], [91.70840454, 22.98205757], [91.70815277, 22.98215675], [91.70798492, 22.98234749], [91.70782471, 22.98242569], [91.7076416, 22.98247528], [91.70758057, 22.98254776], [91.70735168, 22.98269272], [91.70716095, 22.98278046], [91.70693207, 22.98304749], [91.70664978, 22.9833374], [91.70652771, 22.98364639], [91.70617676, 22.98404694], [91.70587158, 22.98445892], [91.70581055, 22.98460007], [91.70543671, 22.98502541], [91.70522308, 22.98531723], [91.70513916, 22.98541641], [91.70504761, 22.98555756], [91.70481873, 22.98593521], [91.70471191, 22.98594284], [91.70459747, 22.98616982], [91.70445251, 22.98649788], [91.70428467, 22.98673439], [91.70420074, 22.98676682], [91.70397186, 22.98699188], [91.70376587, 22.98723984], [91.7036972, 22.98739624], [91.70361328, 22.9877243], [91.70350647, 22.9879818], [91.70343018, 22.98817825], [91.70333862, 22.98827744], [91.70317078, 22.98838806], [91.70298767, 22.98845673], [91.70278931, 22.98854637], [91.70253754, 22.98863983], [91.70223999, 22.98880386], [91.70192719, 22.98891258], [91.70162964, 22.989048], [91.70148468, 22.989048], [91.70111847, 22.98910332], [91.70090485, 22.989151], [91.70068359, 22.9891758], [91.70013428, 22.98905373], [91.69994354, 22.98901176], [91.69957733, 22.98892975], [91.69924164, 22.98883057], [91.6990509, 22.98879242], [91.69873047, 22.98879433], [91.69828033, 22.98874855], [91.69793701, 22.98873901], [91.69772339, 22.98866653], [91.69705963, 22.98842239], [91.6966629, 22.98836708], [91.69625092, 22.98834801], [91.69608307, 22.9883194], [91.69590759, 22.98836136], [91.69566345, 22.98843956], [91.69529724, 22.98849487], [91.69506073, 22.98844719], [91.69483185, 22.98844719], [91.69436646, 22.98848915], [91.69385529, 22.98841858], [91.69361115, 22.98844719], [91.69329834, 22.98828125], [91.69290924, 22.98813057], [91.69264221, 22.98800278], [91.69242859, 22.98781967], [91.69216156, 22.98751068], [91.69192505, 22.98719215], [91.69180298, 22.98707199], [91.69164276, 22.98682022], [91.69158173, 22.98663902], [91.69152832, 22.98633194], [91.69140625, 22.98575783], [91.69145203, 22.98542976], [91.69145203, 22.98530769], [91.69145203, 22.98497009], [91.69142914, 22.98458672], [91.6913147, 22.98420143], [91.69113922, 22.98397255], [91.69100952, 22.98374176], [91.69091034, 22.98341179], [91.69089508, 22.98314285], [91.69059753, 22.98288727], [91.69029999, 22.98266602], [91.68974304, 22.98228645], [91.6893158, 22.98210526], [91.68922424, 22.98206902], [91.68882751, 22.9818058], [91.68856812, 22.9818058], [91.68823242, 22.98180389], [91.68804932, 22.98174095], [91.68785095, 22.98163414], [91.68768311, 22.98157883], [91.68750763, 22.98148918], [91.68719482, 22.9813385], [91.68674469, 22.98111725], [91.68658447, 22.98106575], [91.68643188, 22.98102188], [91.68626404, 22.9810009], [91.68609619, 22.98106003], [91.68583679, 22.98095512], [91.6856308, 22.98084068], [91.68545532, 22.98068619], [91.68530273, 22.98058128], [91.68505859, 22.98043251], [91.6849823, 22.9803772], [91.68489838, 22.98029709], [91.68466949, 22.98001862], [91.68460846, 22.97992325], [91.68450928, 22.9797554], [91.68434906, 22.97958755], [91.68416595, 22.97932053], [91.68367767, 22.97854424], [91.68360901, 22.97844315], [91.68350983, 22.97830582], [91.68336487, 22.9781971], [91.68312836, 22.97797012], [91.68299103, 22.97789764], [91.68268585, 22.97769165], [91.68243408, 22.97756958], [91.68215942, 22.97750664], [91.68190765, 22.97743416], [91.6816864, 22.97738838], [91.68135071, 22.97743416], [91.68102264, 22.97749329], [91.68094635, 22.9775238], [91.68078613, 22.97758865], [91.68066406, 22.97774315], [91.6805191, 22.97797012], [91.68031311, 22.97816086], [91.68025208, 22.97823715], [91.68012238, 22.97839737], [91.68001556, 22.97848511], [91.67987823, 22.97856903], [91.67980194, 22.97867775], [91.67972565, 22.97880363], [91.67967224, 22.97894859], [91.67961884, 22.97909546], [91.67950439, 22.97939301], [91.67946625, 22.97952652], [91.67938995, 22.97968483], [91.67926788, 22.97992706], [91.67919159, 22.98010254], [91.67903137, 22.98029327], [91.67888641, 22.98041344], [91.6787796, 22.98050308], [91.67855072, 22.9806385], [91.67835236, 22.98074722], [91.67827606, 22.98078537], [91.67809296, 22.98087502], [91.67795563, 22.98089218], [91.6774826, 22.98095512], [91.67705536, 22.98094749], [91.67683411, 22.98095512], [91.67671967, 22.98092842], [91.67642212, 22.98081017], [91.67616272, 22.98073578], [91.67591858, 22.98063469], [91.67569733, 22.98054695], [91.67547607, 22.98044014], [91.6751709, 22.98038292], [91.67476654, 22.98029518], [91.67459869, 22.98025513], [91.67444611, 22.98007393], [91.67427826, 22.97987366], [91.67419434, 22.9797554], [91.67391205, 22.97951889], [91.67377472, 22.97940826], [91.6734848, 22.97919846], [91.67316437, 22.97891045], [91.67301941, 22.97871971], [91.67287445, 22.97856522], [91.67266083, 22.97834396], [91.67256165, 22.97821999], [91.67247772, 22.97805977], [91.67222595, 22.97779274], [91.67203522, 22.97761154], [91.6717453, 22.97748947], [91.67153168, 22.97740173], [91.67129517, 22.97731781], [91.67110443, 22.97725677], [91.67092133, 22.97719193], [91.67077637, 22.9771843], [91.67067719, 22.97723961], [91.67050171, 22.97726822], [91.6703949, 22.97725296], [91.67022705, 22.97729301], [91.67007446, 22.97737694], [91.66991425, 22.97748375], [91.66975403, 22.97758293], [91.66947174, 22.97768402], [91.66934204, 22.97696877], [91.66920471, 22.97799683], [91.66905212, 22.97808266], [91.66877747, 22.97833633], [91.66864014, 22.97842407], [91.66845703, 22.97848892], [91.66838074, 22.97852707], [91.66825104, 22.97860146], [91.66805267, 22.97861481], [91.66791534, 22.97870827], [91.66781616, 22.97874641], [91.66762543, 22.97882462], [91.66726685, 22.97894669], [91.6672821, 22.97910309], [91.66706085, 22.97931099], [91.66690063, 22.97949219], [91.66674042, 22.97967148], [91.66649628, 22.97988892], [91.66635132, 22.98008728], [91.66623688, 22.98026848], [91.66612244, 22.98044014], [91.66603851, 22.98058128], [91.66589355, 22.98072624], [91.665802, 22.98084641], [91.66564178, 22.98101044], [91.66544342, 22.98115349], [91.66523743, 22.98131752], [91.66498566, 22.9815464], [91.66478729, 22.98172188], [91.66465759, 22.98177528], [91.664505, 22.98179245], [91.66429901, 22.98181152], [91.66418457, 22.9817791], [91.66407013, 22.98167419], [91.6639328, 22.98146439], [91.66383362, 22.98128319], [91.66375732, 22.98104668], [91.66366577, 22.98091698], [91.66363525, 22.98077583], [91.66357422, 22.98062134], [91.66349792, 22.98049164], [91.66336823, 22.98034096], [91.66323853, 22.98018646], [91.66312408, 22.98000908], [91.6629715, 22.97973824], [91.66278839, 22.97955704], [91.66261292, 22.97944832], [91.66249084, 22.97942924], [91.66229248, 22.97937584], [91.66204834, 22.9793396], [91.66176605, 22.97932625], [91.66160583, 22.97936821], [91.66140747, 22.97944641], [91.66119385, 22.97961998], [91.66109467, 22.9796772], [91.66085052, 22.9798851], [91.66064453, 22.98005104], [91.66056824, 22.98012161], [91.66047668, 22.980299], [91.66039276, 22.9804287], [91.66014862, 22.98070908], [91.65986633, 22.98098564], [91.65982056, 22.98117638], [91.65965271, 22.98128319], [91.65953064, 22.98132706], [91.65938568, 22.98139191], [91.65918732, 22.98153877], [91.65900421, 22.98160934], [91.65883636, 22.98166084], [91.65854645, 22.98179436], [91.65831757, 22.98183632], [91.65804291, 22.98188591], [91.65786743, 22.98188019], [91.65766144, 22.98189926], [91.65729523, 22.98188591], [91.65711975, 22.98180008], [91.65701294, 22.98176003], [91.65684509, 22.98168182], [91.65668488, 22.98159218], [91.65660095, 22.98150063], [91.65647888, 22.98130226], [91.65636444, 22.98113823], [91.65629578, 22.98096085], [91.65625763, 22.98077774], [91.65628052, 22.98060799], [91.65638733, 22.98045158], [91.65645599, 22.98036194], [91.65651703, 22.98027611], [91.65662384, 22.9801445], [91.6566925, 22.98011971], [91.65678406, 22.98010826], [91.6569519, 22.98008347], [91.65710449, 22.98003387], [91.6572113, 22.97998619], [91.65729523, 22.97989655], [91.65756989, 22.9797039], [91.65770721, 22.97957802], [91.65782166, 22.97948265], [91.65790558, 22.9793663], [91.65794373, 22.97924995], [91.65800476, 22.97900963], [91.65800476, 22.97885323], [91.65800476, 22.97837448], [91.65802765, 22.97826576], [91.65794373, 22.97822762], [91.65785217, 22.97821236], [91.65765381, 22.97807884], [91.65750885, 22.97802734], [91.65739441, 22.97795677], [91.65724182, 22.97781563], [91.65705872, 22.97766876], [91.65686035, 22.97754097], [91.65677643, 22.97737122], [91.65666962, 22.97730827], [91.65661621, 22.97721672], [91.65651703, 22.97714043], [91.65640259, 22.97709465], [91.65610504, 22.97688484], [91.65600586, 22.97683144], [91.65544891, 22.97670364], [91.65509033, 22.97664261], [91.65493011, 22.97664833], [91.65474701, 22.97667503], [91.65426636, 22.97670364], [91.65368652, 22.97677231], [91.65349579, 22.97680855], [91.65332031, 22.97681999], [91.65310669, 22.97686577], [91.65291595, 22.97689247], [91.65280151, 22.97688675], [91.65262604, 22.97686195], [91.65236664, 22.9768219], [91.65213013, 22.97680473], [91.65194702, 22.97681046], [91.65181732, 22.97681808], [91.65168762, 22.97682762], [91.65150452, 22.97684288], [91.65129852, 22.97688103], [91.65115356, 22.97697258], [91.65106201, 22.97703552], [91.65090179, 22.97713661], [91.65084076, 22.97727966], [91.65080261, 22.97755051], [91.65074921, 22.97773743], [91.65068054, 22.97790146], [91.65058899, 22.97821426], [91.6505661, 22.9783783], [91.65060425, 22.97857475], [91.65060425, 22.9786911], [91.65059662, 22.97897339], [91.65059662, 22.97909927], [91.65058899, 22.97937584], [91.6505661, 22.97962761], [91.65055847, 22.97988892], [91.65054321, 22.98011208], [91.6505661, 22.98043251], [91.65057373, 22.98060608], [91.65058136, 22.98093605], [91.65058899, 22.98117065], [91.65060425, 22.98135185], [91.65060425, 22.98150444], [91.65055084, 22.98168564], [91.6505127, 22.98178482], [91.65035248, 22.9820137], [91.65021515, 22.9822197], [91.65011597, 22.98228073], [91.65001678, 22.98243141], [91.64994049, 22.98252106], [91.64995575, 22.98265648], [91.64984131, 22.98277473], [91.64965057, 22.98301697], [91.64951324, 22.98319054], [91.6493988, 22.98335648], [91.64927673, 22.98348999], [91.64905548, 22.98361969], [91.64878082, 22.98377609], [91.64858246, 22.98394585], [91.64829254, 22.98412704], [91.64807892, 22.98431206], [91.64783478, 22.98456001], [91.64772034, 22.98464775], [91.64751434, 22.98473549], [91.64736938, 22.98483086], [91.6470108, 22.98503304], [91.64668274, 22.98516273], [91.64641571, 22.98524475], [91.64630127, 22.98526382], [91.64611816, 22.98529816], [91.64584351, 22.98530769], [91.64571381, 22.98528671], [91.64559937, 22.98525238], [91.64546204, 22.98519707], [91.64532471, 22.9851265], [91.64520264, 22.98501587], [91.64521027, 22.98480797], [91.64514923, 22.98468971], [91.64515686, 22.9844265], [91.64511871, 22.9840641], [91.6451416, 22.9839592], [91.64517212, 22.98369217], [91.64520264, 22.98328209], [91.6452179, 22.98305511], [91.64524841, 22.98293114], [91.64528656, 22.98263741], [91.64531708, 22.9825573], [91.64537048, 22.98243713], [91.64544678, 22.98192978], [91.64546967, 22.98155403], [91.64550781, 22.98124504], [91.64559937, 22.98088646], [91.64559937, 22.98064041], [91.64562988, 22.98051643], [91.64573669, 22.98036194], [91.64575958, 22.98027039], [91.64574432, 22.98013878], [91.64573669, 22.98000717], [91.64570618, 22.97981453], [91.64567566, 22.97955132], [91.64565277, 22.97945786], [91.64566803, 22.97934532], [91.64570618, 22.97903442], [91.64572144, 22.97877693], [91.64580536, 22.97847748], [91.64575958, 22.97826767], [91.6457901, 22.97808075], [91.64572906, 22.97802162], [91.64568329, 22.97779655], [91.64569855, 22.97757149], [91.64569855, 22.97748184], [91.64572144, 22.97717285], [91.64573669, 22.97704124], [91.64566803, 22.97675133], [91.64546967, 22.976408], [91.64536285, 22.97635078], [91.64519501, 22.97620583], [91.64501953, 22.97613144], [91.64494324, 22.97609138], [91.64485168, 22.97605705], [91.64478302, 22.97601891], [91.64458466, 22.9759903], [91.6443634, 22.97599792], [91.64415741, 22.97604179], [91.64388275, 22.97608566], [91.64375305, 22.97608757], [91.64336395, 22.97609138], [91.64324951, 22.97608566], [91.64287567, 22.97605705], [91.64234924, 22.97601891], [91.64218903, 22.97596931], [91.64205933, 22.97590256], [91.64186859, 22.97587013], [91.641716, 22.97584724], [91.64144135, 22.97571754], [91.64131165, 22.97563934], [91.64120483, 22.97554207], [91.64092255, 22.97520638], [91.64080048, 22.97509575], [91.64074707, 22.97501755], [91.64073181, 22.97479439], [91.64071655, 22.97449684], [91.64069366, 22.9743042], [91.64070129, 22.97420692], [91.64073181, 22.9736824], [91.64073181, 22.97344398], [91.64070892, 22.97315216], [91.64071655, 22.97302437], [91.64070892, 22.97280884], [91.64070129, 22.97250557], [91.64071655, 22.9721508], [91.640625, 22.9716835], [91.64060211, 22.97138977], [91.64058685, 22.97120667], [91.64053345, 22.97075462], [91.64045715, 22.97047615], [91.64041138, 22.97040939], [91.64033508, 22.97034645], [91.64025879, 22.97032928], [91.64015961, 22.97025108], [91.64022827, 22.97013855], [91.64019775, 22.97006798], [91.64012146, 22.96992111], [91.63999939, 22.96965981], [91.63990784, 22.9695015], [91.63980103, 22.96933556], [91.6397171, 22.96920967], [91.63961792, 22.96904945], [91.63951111, 22.96889687], [91.63937378, 22.96868324], [91.63928223, 22.96860886], [91.63920593, 22.96856689], [91.63912201, 22.9685688], [91.63905334, 22.96845436], [91.63899231, 22.96835709], [91.63890839, 22.96832085], [91.63871002, 22.96799088], [91.63861084, 22.96783066], [91.63845825, 22.96767998], [91.63832855, 22.96747971], [91.63819885, 22.96728516], [91.63803864, 22.9671154], [91.63793182, 22.96699333], [91.63763428, 22.96658707], [91.63757324, 22.96652412], [91.63746643, 22.9664135], [91.63741302, 22.96626663], [91.63733673, 22.96615982], [91.63722992, 22.96604919], [91.63711548, 22.96589851], [91.63710022, 22.9657383], [91.6370163, 22.96550369], [91.63695526, 22.96534157], [91.6370697, 22.96498489], [91.63710022, 22.96477699], [91.63712311, 22.9645195], [91.63716125, 22.96440697], [91.63719177, 22.96419716], [91.63722229, 22.96412086], [91.63722229, 22.96390533], [91.63721466, 22.96370125], [91.63708496, 22.96339417], [91.63706207, 22.96325684], [91.63706207, 22.96316719], [91.63690948, 22.96307182], [91.63681793, 22.96293068], [91.63673401, 22.96277428], [91.63661957, 22.96254921], [91.63650513, 22.96243477], [91.63640594, 22.96221352], [91.63625336, 22.96201515], [91.63595581, 22.96171761], [91.63586426, 22.96162796], [91.63569641, 22.96143532], [91.63565063, 22.96133995], [91.63560486, 22.96125412], [91.63550568, 22.96116829], [91.63538361, 22.96105385], [91.63529968, 22.96106911], [91.63523865, 22.96102524], [91.63516998, 22.96097946], [91.6348877, 22.96073914], [91.63467407, 22.96060562], [91.63454437, 22.96057129], [91.63442993, 22.96058655], [91.63419342, 22.96045876], [91.63404846, 22.96035576], [91.6339035, 22.96030426], [91.63375854, 22.96026421], [91.63356781, 22.96016693], [91.63311768, 22.95995331], [91.63275146, 22.95981598], [91.63259888, 22.95976257], [91.63240814, 22.95968819], [91.63215637, 22.95956993], [91.63181305, 22.95941734], [91.63167572, 22.95939445], [91.63147736, 22.95929909], [91.63115692, 22.95923996], [91.63082123, 22.95920753], [91.63069916, 22.95921135], [91.63034058, 22.95929909], [91.62973022, 22.95962524], [91.62955475, 22.95970535], [91.62931824, 22.95985031], [91.62910461, 22.95993996], [91.62882996, 22.96011734], [91.62865448, 22.96027374], [91.62854767, 22.96037483], [91.6284256, 22.96045685], [91.62817383, 22.96071434], [91.62805176, 22.96083832], [91.62741852, 22.96016121], [91.62734222, 22.95955849], [91.62732697, 22.95940971], [91.62792969, 22.95788574], [91.62908936, 22.95690918], [91.62767792, 22.95508575], [91.62755585, 22.95495415], [91.62557983, 22.95281029], [91.62537384, 22.95258713], [91.62533569, 22.9525013], [91.62506104, 22.95217133], [91.62493896, 22.95202446], [91.6248703, 22.95180702], [91.62462616, 22.95149994], [91.62438202, 22.9511013], [91.62420654, 22.95084953], [91.62399292, 22.95053482], [91.62380981, 22.95027161], [91.62372589, 22.95011711], [91.62364197, 22.95002556], [91.6235733, 22.9498539], [91.62350464, 22.9496994], [91.6234436, 22.94954109], [91.62345123, 22.94937325], [91.62346649, 22.94921875], [91.62350464, 22.94911957], [91.62345123, 22.94897079], [91.62350464, 22.94866943], [91.62358856, 22.94853783], [91.62356567, 22.94846344], [91.62380981, 22.948246], [91.62391663, 22.94813347], [91.62397766, 22.94798279], [91.62407684, 22.94788551], [91.62416077, 22.94777679], [91.62428284, 22.94761658], [91.62436676, 22.94748306], [91.62439728, 22.94737816], [91.62456512, 22.94717216], [91.62467957, 22.94711113], [91.62481689, 22.94696236], [91.62488556, 22.94684029], [91.62515259, 22.94647408], [91.62516022, 22.9462204], [91.62533569, 22.94585037], [91.62546539, 22.94549751], [91.62554169, 22.9451313], [91.62554932, 22.94474983], [91.62553406, 22.94445992], [91.62547302, 22.94418144], [91.62532043, 22.94394493], [91.62518311, 22.94376183], [91.62496185, 22.94372559], [91.62492371, 22.94363594], [91.62477112, 22.94338608], [91.62452698, 22.94319344], [91.62438202, 22.94312096], [91.62422943, 22.94301796], [91.62411499, 22.94284821], [91.62372589, 22.94266701], [91.6233139, 22.94233322], [91.62282562, 22.94187546], [91.62236023, 22.94142151], [91.62212372, 22.94114494], [91.62195587, 22.94089317], [91.62174988, 22.9406414], [91.62149811, 22.94029427], [91.62140656, 22.94014168], [91.621315, 22.94005585], [91.62120819, 22.94000435], [91.62120819, 22.93988228], [91.6211319, 22.93981934], [91.62071228, 22.93928909], [91.62054443, 22.93907166], [91.62042236, 22.93888664], [91.620224, 22.93867493], [91.62000275, 22.93858719], [91.61988068, 22.93854523], [91.61972046, 22.93853951], [91.61934662, 22.93851089], [91.61902618, 22.93848991], [91.61878967, 22.93852615], [91.61849976, 22.9385643], [91.61823273, 22.93857956], [91.61793518, 22.93865395], [91.6175766, 22.93880272], [91.61728668, 22.93900108], [91.61717987, 22.93912506], [91.61701202, 22.93935013], [91.61682129, 22.93969345], [91.61669159, 22.94009018], [91.61662292, 22.94046974], [91.6166153, 22.94102287], [91.61668396, 22.94159508], [91.61678314, 22.94226265], [91.61690521, 22.94276237], [91.61695862, 22.94319725], [91.61699677, 22.94346428], [91.61698151, 22.94371796], [91.61694336, 22.94393921], [91.61688995, 22.94417953], [91.61682129, 22.94422531], [91.61660004, 22.94424057], [91.61607361, 22.94437981], [91.61585999, 22.9444809], [91.61560822, 22.94466591], [91.61528015, 22.94484329], [91.6146698, 22.94513702], [91.61411285, 22.94539261], [91.61389923, 22.94555092], [91.61371613, 22.94564247], [91.61340332, 22.94597626], [91.61320496, 22.94607544], [91.6129837, 22.94628525], [91.61289215, 22.9466629], [91.6126709, 22.94719315], [91.61267853, 22.94731712], [91.61268616, 22.94749641], [91.61261749, 22.94760704], [91.61260223, 22.94767952], [91.61260223, 22.947752], [91.61254883, 22.94799614], [91.61248779, 22.94831085], [91.6125412, 22.94861794], [91.61253357, 22.94890594], [91.61260986, 22.94933319], [91.61270142, 22.94942284], [91.61277008, 22.94953537], [91.61292267, 22.94972038], [91.61309052, 22.94977188], [91.61339569, 22.94982147], [91.61376953, 22.94973373], [91.61408997, 22.94967079], [91.61447144, 22.94963646], [91.61465454, 22.949543], [91.6149826, 22.94938278], [91.615242, 22.94935226], [91.61560822, 22.94924736], [91.61574554, 22.94923782], [91.61585236, 22.94922829], [91.61612701, 22.9491539], [91.61629486, 22.94919968], [91.61640167, 22.94926262], [91.6163559, 22.94961357], [91.61651611, 22.94982719], [91.61663818, 22.94996262], [91.61663055, 22.95016289], [91.61653137, 22.95040703], [91.6164093, 22.95064545], [91.61634064, 22.95083427], [91.61626434, 22.95092201], [91.61621094, 22.95097351], [91.61611938, 22.9511528], [91.61600494, 22.95129776], [91.61578369, 22.95158768], [91.61538696, 22.95189667], [91.61526489, 22.95199013], [91.61502075, 22.95212746], [91.61476898, 22.9522953], [91.61432648, 22.95249367], [91.6137619, 22.95256424], [91.61360168, 22.95254898], [91.61333466, 22.95247459], [91.6132431, 22.95236206], [91.61319733, 22.95226479], [91.61304474, 22.95219994], [91.61294556, 22.95213509], [91.61277771, 22.95213699], [91.61228943, 22.95202065], [91.61190033, 22.95196342], [91.61170959, 22.95188713], [91.61149597, 22.95178223], [91.61133575, 22.9516964], [91.61121368, 22.95160294], [91.6109848, 22.95148849], [91.61058807, 22.95127487], [91.61006927, 22.95108986], [91.60979462, 22.95089531], [91.60948944, 22.95067596], [91.60807037, 22.95047188], [91.60861206, 22.95028687], [91.60814667, 22.95018196], [91.60783386, 22.95010948], [91.6074295, 22.9500885], [91.60716248, 22.95014572], [91.60705566, 22.95016289], [91.60694885, 22.95027161], [91.60688782, 22.95040321], [91.60671997, 22.95067596], [91.60661316, 22.9509449], [91.6067276, 22.95120811], [91.60676575, 22.95148087], [91.60678864, 22.95172501], [91.60688019, 22.95198059], [91.60690308, 22.9521389], [91.60700989, 22.95229721], [91.60707092, 22.95247459], [91.60712433, 22.9525795], [91.60717773, 22.95271683], [91.60734558, 22.95305252], [91.60762787, 22.95353699], [91.60784912, 22.95381546], [91.60800934, 22.95410538], [91.608284, 22.95439339], [91.60860443, 22.95477867], [91.60879517, 22.95502472], [91.60894775, 22.95516968], [91.60932159, 22.95570946], [91.60944366, 22.95587921], [91.60947418, 22.95602036], [91.60931396, 22.95611572], [91.60888672, 22.95648193], [91.60668945, 22.95611572], [91.60581207, 22.95612144], [91.6055069, 22.95589638], [91.60535431, 22.95575714], [91.60501862, 22.95551109], [91.60490417, 22.95540619], [91.60445404, 22.95503235], [91.60437012, 22.95493889], [91.60429382, 22.95484543], [91.60401154, 22.95464706], [91.60386658, 22.9545517], [91.60349274, 22.95417595], [91.60308075, 22.95381927], [91.60273743, 22.95354652], [91.60254669, 22.95346451], [91.60236359, 22.95338249], [91.60216522, 22.95345688], [91.60198212, 22.95341492], [91.60190582, 22.95335388], [91.60179901, 22.95334625], [91.60153961, 22.95343781], [91.60142517, 22.95344543], [91.60131073, 22.95346451], [91.60127258, 22.95353889], [91.60088348, 22.95382881], [91.60077667, 22.95393181], [91.6005249, 22.95413971], [91.60037994, 22.95422935], [91.60025024, 22.95445251], [91.6002121, 22.9546299], [91.60012054, 22.95484161], [91.60002136, 22.95508003], [91.60004425, 22.9552803], [91.60001373, 22.95542336], [91.60002899, 22.956007], [91.60005951, 22.95615005], [91.6001358, 22.95624161], [91.60017395, 22.9563446], [91.60031891, 22.95649147], [91.60032654, 22.95668221], [91.60034943, 22.95676804], [91.60050964, 22.95701408], [91.60079193, 22.95749855], [91.60105133, 22.95791054], [91.6013031, 22.95824242], [91.60152435, 22.95851135], [91.60179138, 22.95894814], [91.60186005, 22.95911407], [91.60207367, 22.95933151], [91.60218048, 22.95948029], [91.60240173, 22.95965958], [91.60256195, 22.95978737], [91.60263824, 22.95990562], [91.6027832, 22.96003914], [91.60295105, 22.96031189], [91.6030426, 22.96047592], [91.60330963, 22.96075058], [91.60342407, 22.96092987], [91.60361481, 22.96114922], [91.60387421, 22.96139526], [91.60424805, 22.96175385], [91.60469055, 22.96221352], [91.60478973, 22.96231079], [91.60492706, 22.96237755], [91.60505676, 22.96239471], [91.60520935, 22.96243668], [91.60536194, 22.96245193], [91.60547638, 22.96251488], [91.60572815, 22.96244621], [91.60599518, 22.96235657], [91.60620117, 22.96231079], [91.60641479, 22.96227646], [91.60667419, 22.96218681], [91.60679626, 22.96214867], [91.6072998, 22.96331787], [91.60800934, 22.96423531], [91.60786438, 22.9642868], [91.60669708, 22.96468544], [91.60631561, 22.96486092], [91.60595703, 22.96505737], [91.60561371, 22.96530342], [91.60532379, 22.96580887], [91.60519409, 22.96615791], [91.60516357, 22.96643829], [91.60518646, 22.96676445], [91.60526276, 22.96731949], [91.60536194, 22.96784973], [91.60553741, 22.96850014], [91.60577393, 22.96932602], [91.60612488, 22.97023964], [91.60620117, 22.97047234], [91.60623932, 22.97077751], [91.60629272, 22.97112846], [91.6062851, 22.97143745], [91.60623169, 22.97166061], [91.60611725, 22.97190666], [91.60603333, 22.97203827], [91.60584259, 22.9721241], [91.6055603, 22.97216988], [91.60482025, 22.97203064], [91.60388184, 22.97191238], [91.60365295, 22.97182465], [91.60327148, 22.97167969], [91.59967041, 22.96972656], [91.59729004, 22.97052002], [91.59747314, 22.97247314], [91.59828186, 22.97514153], [91.59767914, 22.97571373], [91.59745026, 22.97561264], [91.59727478, 22.97541237], [91.59684753, 22.97516441], [91.59638214, 22.97482872], [91.59589386, 22.97443962], [91.59532928, 22.97400284], [91.59479523, 22.97362137], [91.59453583, 22.97340584], [91.59436798, 22.9732933], [91.59402466, 22.97306633], [91.59367371, 22.97294807], [91.5934906, 22.97278404], [91.59336853, 22.97271538], [91.59319305, 22.97269058], [91.59284973, 22.97276497], [91.59264374, 22.97296524], [91.59242249, 22.97313118], [91.59233093, 22.97340202], [91.59223175, 22.97359085], [91.59209442, 22.97398376], [91.5920105, 22.97445488], [91.59187317, 22.97509003], [91.59172821, 22.97568512], [91.59166718, 22.97605705], [91.59159851, 22.97628593], [91.59145355, 22.97660065], [91.59133911, 22.97671509], [91.59106445, 22.97691154], [91.59082794, 22.97701836], [91.59060669, 22.97705269], [91.59038544, 22.97705841], [91.59017944, 22.9769783], [91.58998871, 22.97687531], [91.58985138, 22.97676849], [91.58979034, 22.97644997], [91.5894928, 22.97598076], [91.58882904, 22.97527313], [91.58861542, 22.97504616], [91.58848572, 22.97479248], [91.58766937, 22.97406006], [91.58692932, 22.9734211], [91.58638763, 22.97300529], [91.58550262, 22.97229958], [91.58498383, 22.9718895], [91.58448792, 22.97154999], [91.58362579, 22.97088814], [91.58244324, 22.96992683], [91.58085632, 22.96865082], [91.5796814, 22.96770287], [91.57888031, 22.9671154], [91.57866669, 22.96693993], [91.57823944, 22.96658325], [91.57778931, 22.96629333], [91.57736206, 22.96595573], [91.57695007, 22.96559143], [91.57675934, 22.96537399], [91.57635498, 22.96563721], [91.57624054, 22.96589851], [91.57553864, 22.96749306], [91.57500458, 22.9688282], [91.57456207, 22.9690361], [91.56768799, 22.97229004], [91.56729126, 22.97278595], [91.5663147, 22.97333145], [91.56607056, 22.97347069], [91.56563568, 22.97372246], [91.5640564, 22.97460365], [91.56231689, 22.97561836], [91.56092834, 22.97637367], [91.55990601, 22.97698212], [91.55843353, 22.97785759], [91.55717468, 22.97860336], [91.55712128, 22.97987747], [91.5570755, 22.98105431], [91.55705261, 22.98163795], [91.55701447, 22.98324776], [91.55696106, 22.98574448], [91.55692291, 22.98769379], [91.55695343, 22.98999596], [91.55696869, 22.99114418], [91.55696869, 22.99139595], [91.55700684, 22.99212074], [91.55699921, 22.99283791], [91.55291748, 22.99267578], [91.54901886, 22.99475479], [91.54746246, 22.99436188], [91.54698181, 22.99485207], [91.54684448, 22.99499893], [91.54595184, 22.99592018], [91.54566956, 22.99622154], [91.54485321, 22.99709129], [91.54362488, 22.99839211], [91.54314423, 22.99890518], [91.54244995, 22.99965286], [91.54270172, 23.0005722], [91.54272461, 23.00064659], [91.54319, 23.00222588], [91.54358673, 23.00358582], [91.54397583, 23.00494957], [91.5443573, 23.00625038], [91.54465485, 23.00727844], [91.54534149, 23.00960922], [91.54568481, 23.01083755], [91.54647064, 23.01356888], [91.54665375, 23.01420403], [91.54689026, 23.01504135], [91.54548645, 23.01488113], [91.54560089, 23.01519585], [91.54638672, 23.01730347], [91.54412842, 23.0178833], [91.54512787, 23.01937675], [91.54341125, 23.01937294], [91.54092407, 23.01936531], [91.53964996, 23.01935768], [91.53834534, 23.01935577], [91.53863525, 23.01977539], [91.53910828, 23.02045822], [91.53926849, 23.02074814], [91.53948212, 23.02112198], [91.54045105, 23.02247238], [91.5406189, 23.02269936], [91.54121399, 23.02356339], [91.54173279, 23.02431679], [91.5422821, 23.02511978], [91.54290771, 23.02604103], [91.5440979, 23.0281601], [91.54521179, 23.03012848], [91.54607391, 23.03155708], [91.54681396, 23.0327816], [91.54750061, 23.03392601], [91.54761505, 23.03412628], [91.5480957, 23.03493309], [91.54850006, 23.03560829], [91.54878235, 23.03608131], [91.54933929, 23.03700829], [91.55028534, 23.03854752], [91.55011749, 23.03854752], [91.54865265, 23.03855515], [91.5464325, 23.0385685], [91.54451752, 23.03857994], [91.54255676, 23.03858948], [91.5417099, 23.0385952], [91.54137421, 23.03859711], [91.54088593, 23.03855515], [91.54063416, 23.03853607], [91.53997803, 23.03852081], [91.53859711, 23.03849602], [91.53608704, 23.03847885], [91.53587341, 23.03847694], [91.53390503, 23.03846359], [91.53156281, 23.03844452], [91.53070068, 23.0384388], [91.53043365, 23.03843689], [91.53090668, 23.04018211], [91.53141022, 23.04203606], [91.53144073, 23.04213905], [91.53156281, 23.04258919], [91.53210449, 23.04390144], [91.53274536, 23.04545784], [91.53336334, 23.04694557], [91.53372955, 23.04790497], [91.53427887, 23.0494175], [91.53468323, 23.05060577], [91.53505707, 23.05158997], [91.53526306, 23.052145], [91.53529358, 23.05222893], [91.5322876, 23.05310059], [91.53131104, 23.05328369], [91.53117371, 23.05330658], [91.53011322, 23.05348015], [91.52999878, 23.05343246], [91.52857971, 23.05364037], [91.52951813, 23.05548668], [91.52913666, 23.05548859], [91.52839661, 23.05548859], [91.52757263, 23.05548859], [91.52523804, 23.05549622], [91.52490997, 23.05549812], [91.52511597, 23.05671883], [91.525177, 23.05710602], [91.52532196, 23.05780792], [91.52559662, 23.0591259], [91.52577209, 23.06013107], [91.52754974, 23.06075859], [91.52902222, 23.0612812], [91.52973175, 23.06153297], [91.53321838, 23.06276321], [91.53525543, 23.06348038], [91.53520966, 23.06357002], [91.5348587, 23.06422043], [91.53397369, 23.0658741], [91.53382874, 23.06614876], [91.53327179, 23.06719017], [91.53259277, 23.06846809], [91.53247833, 23.06869125], [91.53199768, 23.06963921], [91.53124237, 23.07113457], [91.53017426, 23.07318306], [91.52952576, 23.0744133], [91.52858734, 23.07621193], [91.52801514, 23.0772438], [91.52725983, 23.07867622], [91.5267334, 23.07969284], [91.52613831, 23.08083916], [91.5250473, 23.08296585], [91.52713013, 23.08424377], [91.52842712, 23.08502007], [91.52881622, 23.08525276], [91.52988434, 23.08590889], [91.52983856, 23.08818436], [91.52980804, 23.08934975], [91.52978516, 23.09049606], [91.5297699, 23.09117889], [91.52976227, 23.0915966], [91.52919769, 23.09170151], [91.52841949, 23.09168434], [91.5266037, 23.09219933], [91.52635956, 23.09224701], [91.52468109, 23.09269905], [91.5240097, 23.09288025], [91.52294159, 23.09316444], [91.52157593, 23.09352684], [91.52010345, 23.09391975], [91.51886749, 23.09428406], [91.51929474, 23.095438], [91.51973724, 23.09665108], [91.52047729, 23.09883118], [91.52101135, 23.10039139], [91.52152252, 23.1019001], [91.52158356, 23.10208321], [91.52133179, 23.10237122], [91.51902008, 23.10254288], [91.51756287, 23.10316277], [91.51662445, 23.10425186], [91.51564789, 23.10427284], [91.51318359, 23.10430717], [91.51293945, 23.1043129], [91.51124573, 23.10434341], [91.51148224, 23.10658073], [91.51165009, 23.10821533], [91.51168823, 23.10853386], [91.51171112, 23.10874748], [91.51194763, 23.11082649], [91.51211548, 23.11229324], [91.51223755, 23.11336708], [91.51477814, 23.11375046], [91.51620483, 23.1139679], [91.51779938, 23.11421585], [91.51844788, 23.11431503], [91.52033234, 23.11459351], [91.52023315, 23.11486435], [91.52014923, 23.1151104], [91.51944733, 23.11710739], [91.51925659, 23.11764526], [91.51917267, 23.1178894], [91.51714325, 23.11784172], [91.5162735, 23.11782074], [91.51534271, 23.11779785], [91.51530457, 23.11797523], [91.51512909, 23.11874771], [91.51507568, 23.11897087], [91.51495361, 23.11944199], [91.51464081, 23.12078094], [91.51442719, 23.1216507], [91.51419067, 23.12269211], [91.51589203, 23.12401581], [91.51486206, 23.1249218], [91.51373291, 23.12537003], [91.51174927, 23.12545013], [91.51011658, 23.12623978], [91.50971222, 23.1264801], [91.509552, 23.12662888], [91.5091629, 23.12668037], [91.50782776, 23.12685394], [91.50571442, 23.12713623], [91.50374603, 23.12739372], [91.50360107, 23.12814331], [91.50350189, 23.1286087], [91.50320435, 23.13010979], [91.50308228, 23.13063431], [91.50439453, 23.13153648], [91.5063324, 23.13287544], [91.50762939, 23.13376236], [91.50901794, 23.13472939], [91.51168823, 23.13657188], [91.51261902, 23.13720131], [91.51210022, 23.13731003], [91.50904083, 23.13796043], [91.50745392, 23.1398735], [91.50722504, 23.1398983], [91.50711823, 23.13995171], [91.5070343, 23.14003563], [91.50695801, 23.1401825], [91.50692749, 23.14033127], [91.50688171, 23.14039803], [91.50680542, 23.14043617], [91.50668335, 23.14042282], [91.50648499, 23.14033508], [91.50636292, 23.1402607], [91.50627136, 23.14023209], [91.50615692, 23.14022636], [91.50605011, 23.1402359], [91.50592041, 23.14031601], [91.50576019, 23.14039612], [91.50550079, 23.14049149], [91.50521851, 23.14056778], [91.50510406, 23.14060974], [91.50498199, 23.14061165], [91.5049057, 23.14061165], [91.50478363, 23.1405735], [91.5046463, 23.14049149], [91.50444794, 23.14045906], [91.50443268, 23.14057732], [91.50442505, 23.14066505], [91.50447083, 23.14075089], [91.50444031, 23.14084244], [91.50435638, 23.14083862], [91.50419617, 23.14073944], [91.5041275, 23.14077759], [91.50413513, 23.14088821], [91.50409698, 23.14103889], [91.50403595, 23.14118576], [91.50392151, 23.14134789], [91.50382233, 23.14144516], [91.50367737, 23.14157867], [91.50362396, 23.14166832], [91.50357056, 23.14179039], [91.50350189, 23.14188766], [91.50338745, 23.14193153], [91.50318909, 23.14201927], [91.50312042, 23.14207268], [91.50296783, 23.14217186], [91.50284576, 23.14225006], [91.50273132, 23.1423378], [91.50259399, 23.14242744], [91.5025177, 23.1424942], [91.50243378, 23.14253044], [91.50234985, 23.14256477], [91.50228119, 23.14263725], [91.50222015, 23.14273643], [91.50205231, 23.14280701], [91.50189972, 23.14289474], [91.50182343, 23.1429882], [91.50174713, 23.14307976], [91.50167084, 23.14314461], [91.50157928, 23.14320564], [91.50149536, 23.14321709], [91.5014267, 23.14315033], [91.50138855, 23.1430645], [91.501297, 23.14299011], [91.50128937, 23.14311981], [91.50125122, 23.14325142], [91.50115967, 23.14326286], [91.50107574, 23.1432457], [91.50106812, 23.14315987], [91.50105286, 23.14305878], [91.50099945, 23.14297295], [91.50089264, 23.14290237], [91.50072479, 23.14293289], [91.50050354, 23.14298248], [91.50037384, 23.14293861], [91.50026703, 23.1429081], [91.50020599, 23.14286804], [91.50011444, 23.14273834], [91.50011444, 23.14264679], [91.50010681, 23.14255333], [91.50014496, 23.14240837], [91.50016022, 23.14231682], [91.50016022, 23.14222717], [91.50010681, 23.14217377], [91.50003052, 23.14211273], [91.49987793, 23.14216805], [91.49966431, 23.14235497], [91.49945831, 23.14256096], [91.49936676, 23.14266586], [91.49926758, 23.14274979], [91.4991684, 23.14280319], [91.49894714, 23.14283943], [91.49887085, 23.1428051], [91.49879456, 23.14273643], [91.49866486, 23.14267921], [91.49869537, 23.14285088], [91.49871826, 23.14293098], [91.49874115, 23.14300346], [91.498703, 23.14311409], [91.49861908, 23.1431694], [91.4985199, 23.14330101], [91.49855042, 23.14339256], [91.4986496, 23.14346695], [91.49880219, 23.14353943], [91.49886322, 23.14361191], [91.49889374, 23.14371109], [91.49893951, 23.14382935], [91.49892426, 23.14391899], [91.49886322, 23.14397812], [91.49879456, 23.14403534], [91.498703, 23.14403725], [91.49862671, 23.14404106], [91.49852753, 23.14401627], [91.4984436, 23.14400864], [91.49833679, 23.14395905], [91.49825287, 23.14400864], [91.4982605, 23.14409447], [91.49821472, 23.14416885], [91.4981308, 23.14422417], [91.49810028, 23.14430428], [91.49804688, 23.1443882], [91.49797821, 23.14448357], [91.49795532, 23.14455414], [91.49790955, 23.14462471], [91.49782562, 23.14462852], [91.4977417, 23.14464951], [91.49767303, 23.144701], [91.49760437, 23.14478683], [91.49756622, 23.14486885], [91.49754333, 23.14496994], [91.4974823, 23.14513206], [91.49738312, 23.14526749], [91.49724579, 23.14535332], [91.4970932, 23.14544487], [91.49698639, 23.14544868], [91.49690247, 23.14542961], [91.49678802, 23.14541054], [91.49671173, 23.14541817], [91.49662781, 23.14544106], [91.49656677, 23.14548874], [91.49653625, 23.1455574], [91.496521, 23.14564133], [91.4964447, 23.14574814], [91.49634552, 23.14575005], [91.49624634, 23.14578438], [91.49626923, 23.14586258], [91.49634552, 23.14603043], [91.49637604, 23.14626694], [91.49632263, 23.14635468], [91.49627686, 23.14641571], [91.49629974, 23.14652252], [91.4963913, 23.14657974], [91.49648285, 23.14666748], [91.49642944, 23.14673996], [91.49628448, 23.14681053], [91.49610138, 23.14686775], [91.49595642, 23.1469059], [91.49580383, 23.14688683], [91.49557495, 23.14685059], [91.49538422, 23.14685822], [91.49523163, 23.14687157], [91.49516296, 23.14691162], [91.49510956, 23.14699936], [91.49503326, 23.14709854], [91.49489594, 23.14714622], [91.49468231, 23.14722252], [91.49682617, 23.14821243], [91.49838257, 23.14892769], [91.501091, 23.15017128], [91.50170898, 23.15045929], [91.50286865, 23.15100098], [91.50406647, 23.15169144], [91.50653076, 23.15312004], [91.50683594, 23.15329742], [91.50728607, 23.15356064], [91.50717926, 23.15426445], [91.507164, 23.15440559], [91.50528717, 23.15411186], [91.50384521, 23.15387154], [91.50193787, 23.15356255], [91.50121307, 23.1534462], [91.50087738, 23.1533947], [91.49991608, 23.15324211], [91.49757385, 23.15287399], [91.49628448, 23.15267181], [91.49428558, 23.15236282], [91.49398804, 23.15284538], [91.49383545, 23.15308762], [91.49324036, 23.15404129], [91.49273682, 23.15485001], [91.49227142, 23.15558243], [91.49143219, 23.15691376], [91.49088287, 23.15776253], [91.49193573, 23.15915298], [91.49256897, 23.15999603], [91.49297333, 23.16053772], [91.49324799, 23.16057396], [91.49333191, 23.16065025], [91.49333191, 23.16150093], [91.49337006, 23.16162872], [91.49349976, 23.16169548], [91.49357605, 23.16155052], [91.49370575, 23.16150475], [91.49476624, 23.16210747], [91.49503326, 23.16286278], [91.49528503, 23.16357803], [91.49620819, 23.16620636], [91.49664307, 23.16744804], [91.49697113, 23.16838264], [91.49749756, 23.16988564], [91.49812317, 23.17178726], [91.49634552, 23.17189789], [91.49611664, 23.17191315], [91.49559784, 23.17193031], [91.49398804, 23.17201233], [91.49228668, 23.17209244], [91.4921875, 23.17295074], [91.49217224, 23.17312622], [91.49208069, 23.17396927], [91.49189758, 23.17555237], [91.49180603, 23.17640686], [91.49172211, 23.17721748], [91.4916687, 23.17771149], [91.49328613, 23.17834854], [91.49462128, 23.17887115], [91.49633789, 23.17955208], [91.49687195, 23.17976379], [91.49729919, 23.17993546], [91.49846649, 23.18001938], [91.49966431, 23.18010139], [91.50081635, 23.18018341], [91.50108337, 23.18020439], [91.50130463, 23.18021965], [91.50209045, 23.18027306], [91.5029068, 23.18032646], [91.50334167, 23.18035316], [91.50346375, 23.18034363], [91.50367737, 23.18032646], [91.50408173, 23.18029404], [91.50483704, 23.180233], [91.50666809, 23.18008423], [91.50673676, 23.18041039], [91.50682831, 23.18085289], [91.50701904, 23.18182564], [91.50706482, 23.18202019], [91.50720215, 23.18265915], [91.50730896, 23.18314552], [91.50735474, 23.18334389], [91.50689697, 23.18350029], [91.50629425, 23.18414307], [91.50604248, 23.18420601], [91.50596619, 23.18422699], [91.50517273, 23.18441772], [91.50411224, 23.18467903], [91.50323486, 23.18489838], [91.50286865, 23.18498421], [91.50156403, 23.1852951], [91.50102997, 23.18541908], [91.50198364, 23.18662071], [91.50215912, 23.18683815], [91.50074768, 23.18691063], [91.49562073, 23.18731117], [91.49192047, 23.18765259], [91.49054718, 23.18700027], [91.4887085, 23.1872406], [91.48712158, 23.18760109], [91.4838562, 23.18805122], [91.48149872, 23.18587112], [91.47891235, 23.18630981], [91.47477722, 23.18839836], [91.47424316, 23.18883705], [91.47615814, 23.19251442], [91.47649384, 23.19315529], [91.47579193, 23.19356346], [91.47506714, 23.19399071], [91.47422791, 23.1944809], [91.47330475, 23.19502831], [91.47251892, 23.19548416], [91.47163391, 23.19600677], [91.4706955, 23.19655991], [91.47180939, 23.19676018], [91.47325897, 23.19701385], [91.4744873, 23.19721985], [91.47499084, 23.19730759], [91.47592163, 23.1974659], [91.4765625, 23.19757462], [91.47735596, 23.19771004], [91.47831726, 23.19787598], [91.47924805, 23.19803429], [91.48058319, 23.19826317], [91.48162079, 23.19843292], [91.4823761, 23.19856644], [91.48249817, 23.19920921], [91.48267365, 23.20017433], [91.4828949, 23.20137215], [91.48313904, 23.20269012], [91.4833374, 23.20374489], [91.48361969, 23.20530128], [91.48384857, 23.20650291], [91.48395538, 23.20708275], [91.48408508, 23.20775986], [91.48423004, 23.20851326], [91.48436737, 23.20933533], [91.48370361, 23.21012688], [91.48343658, 23.21045494], [91.4829483, 23.2110672], [91.48215485, 23.21204948], [91.4815979, 23.21273994], [91.48125458, 23.21317101], [91.48077393, 23.2137661], [91.48009491, 23.21461487], [91.47980499, 23.21497726], [91.47924805, 23.21565819], [91.47896576, 23.21600533], [91.47857666, 23.21598053], [91.47371674, 23.2143116], [91.46714783, 23.21245193], [91.46559906, 23.21239281], [91.4642868, 23.2122097], [91.46380615, 23.2128582], [91.4621582, 23.21306038], [91.46177673, 23.21405983], [91.46081543, 23.21438408], [91.46007538, 23.21407509], [91.45924377, 23.21372795], [91.45856476, 23.21344757], [91.45849609, 23.21357155], [91.45838165, 23.21367455], [91.45822906, 23.21376228], [91.45809174, 23.21386528], [91.45806122, 23.21399117], [91.45804596, 23.21417046], [91.45806122, 23.21437836], [91.45809174, 23.21459389], [91.45806122, 23.21474648], [91.45804596, 23.21490288], [91.45812988, 23.21515656], [91.45822144, 23.21536446], [91.45827484, 23.21556854], [91.45827484, 23.21567154], [91.45824432, 23.21575356], [91.45809937, 23.21584511], [91.45788574, 23.21593475], [91.45756531, 23.21601486], [91.4572525, 23.21618652], [91.45675659, 23.21644783], [91.4564209, 23.21661568], [91.45618439, 23.21673203], [91.45582581, 23.21693802], [91.45550537, 23.21708107], [91.45531464, 23.21713638], [91.4551239, 23.21724701], [91.45503235, 23.21730614], [91.45497894, 23.21736526], [91.45482635, 23.21746254], [91.45448303, 23.21749687], [91.45420074, 23.21763802], [91.45407867, 23.2176609], [91.45401001, 23.21769905], [91.45391083, 23.21772766], [91.45384216, 23.21784019], [91.45378113, 23.21797752], [91.45373535, 23.2181263], [91.4539032, 23.21821785], [91.45407104, 23.21829987], [91.45414734, 23.21840858], [91.45413208, 23.21848869], [91.45399475, 23.21853447], [91.45383453, 23.21853256], [91.45359802, 23.21850204], [91.45336914, 23.21844482], [91.45314789, 23.21841431], [91.45294952, 23.21846771], [91.45269775, 23.21852112], [91.45251465, 23.21855164], [91.45236206, 23.21862793], [91.45219421, 23.21874237], [91.45210266, 23.21885681], [91.45201874, 23.21898079], [91.45188904, 23.21907043], [91.45167542, 23.21913719], [91.45157623, 23.21917152], [91.45142365, 23.21925545], [91.45126343, 23.21931839], [91.45110321, 23.21930695], [91.45101166, 23.21926308], [91.45088196, 23.21923637], [91.45079041, 23.21928596], [91.45074463, 23.21942139], [91.45066071, 23.21949005], [91.45050049, 23.21959877], [91.45062256, 23.21985245], [91.45067596, 23.22006035], [91.45069885, 23.22028542], [91.45072174, 23.22041702], [91.45079803, 23.22045898], [91.45097351, 23.22047234], [91.45101166, 23.22060394], [91.45109558, 23.2207489], [91.4513092, 23.22087097], [91.4515152, 23.22099304], [91.45155334, 23.22110367], [91.45161438, 23.22121048], [91.4516983, 23.2212429], [91.45179749, 23.22124863], [91.45201874, 23.22120857], [91.45214844, 23.22119522], [91.45223236, 23.22114944], [91.45236969, 23.22112846], [91.45243835, 23.22115517], [91.4524765, 23.22122192], [91.45248413, 23.22130203], [91.45248413, 23.22138405], [91.45243835, 23.22146034], [91.45236969, 23.2215519], [91.45238495, 23.22162628], [91.45243835, 23.22171021], [91.45279694, 23.22167397], [91.45281219, 23.22186279], [91.45289612, 23.22204399], [91.45294952, 23.22216415], [91.45303345, 23.22220993], [91.45314026, 23.22222328], [91.45324707, 23.22226143], [91.45333099, 23.22234917], [91.45336151, 23.22258949], [91.45327759, 23.22269058], [91.45304108, 23.22265244], [91.45294189, 23.22268867], [91.45294189, 23.22279167], [91.45304108, 23.22301483], [91.453125, 23.2231884], [91.45320129, 23.2232914], [91.45339966, 23.22336197], [91.45357513, 23.22340202], [91.45383453, 23.22344589], [91.45393372, 23.22350502], [91.45400238, 23.2235775], [91.45418549, 23.22350883], [91.45426941, 23.22365952], [91.45510101, 23.22387314], [91.45635986, 23.2242012], [91.45857239, 23.22477341], [91.46041107, 23.22525024], [91.46279144, 23.22586823], [91.46372223, 23.22610283], [91.46564484, 23.22659683], [91.46794128, 23.2271862], [91.47024536, 23.22777748], [91.46952057, 23.22891045], [91.46820831, 23.23095894], [91.46721649, 23.23252106], [91.46589661, 23.23458481], [91.46473694, 23.23639679], [91.46338654, 23.23851204], [91.46247864, 23.23999977], [91.46193695, 23.23999214], [91.46115112, 23.24117088], [91.46045685, 23.24220848], [91.46031952, 23.24241447], [91.45825958, 23.24258995], [91.45670319, 23.24200821], [91.45574951, 23.24165916], [91.45372009, 23.24197006], [91.45168304, 23.2434597], [91.45184326, 23.24463654], [91.45137787, 23.244524], [91.45069885, 23.24429512], [91.45011139, 23.24418449], [91.44911194, 23.24399567], [91.44853973, 23.24388695], [91.44885254, 23.24459839], [91.45362091, 23.25566864], [91.45393372, 23.25640106], [91.45204926, 23.25665092], [91.4434433, 23.25810051], [91.43660736, 23.25842094], [91.43260956, 23.2583847], [91.42917633, 23.25835419], [91.42861176, 23.25834846], [91.4263382, 23.25832939], [91.42504883, 23.25700951], [91.42368317, 23.25502014], [91.42177582, 23.2572403], [91.42201233, 23.25972939], [91.42201996, 23.26138115], [91.42113495, 23.26192856], [91.42095184, 23.26152229], [91.42062378, 23.26079559], [91.41982269, 23.25902557], [91.41941833, 23.25806236], [91.41877747, 23.25654602], [91.41837311, 23.25558662], [91.41825104, 23.25561142], [91.41834259, 23.25580978], [91.41842651, 23.25593948], [91.41849518, 23.25606346], [91.41844177, 23.25624657], [91.41825104, 23.25641632], [91.41821289, 23.25650978], [91.41825867, 23.25662613], [91.41833496, 23.25679398], [91.418396, 23.25697899], [91.41838074, 23.25713348], [91.41831207, 23.25728989], [91.41825104, 23.25732803], [91.41814423, 23.25735474], [91.41801453, 23.25741768], [91.41832733, 23.25759125], [91.41838837, 23.25766945], [91.41851044, 23.25792122], [91.41867828, 23.25837517], [91.41863251, 23.25849724], [91.41849518, 23.25862503], [91.418396, 23.25862312], [91.41832733, 23.25859261], [91.41816711, 23.25846863], [91.41809082, 23.25842857], [91.41798401, 23.25843811], [91.41798401, 23.25855064], [91.41809082, 23.25857162], [91.41816711, 23.25862694], [91.41822815, 23.25882912], [91.41808319, 23.25888062], [91.41797638, 23.25893211], [91.41797638, 23.25906563], [91.41808319, 23.25916672], [91.41796875, 23.25926399], [91.41796875, 23.2593441], [91.41782379, 23.25949669], [91.41772461, 23.2596283], [91.4176712, 23.25970459], [91.41765594, 23.25991631], [91.41756439, 23.26008415], [91.41732025, 23.26005936], [91.4169693, 23.25994682], [91.41685486, 23.2599144], [91.41677094, 23.25993919], [91.41673279, 23.26015282], [91.41670227, 23.26049805], [91.41664124, 23.26075363], [91.41655731, 23.26080322], [91.41639709, 23.26080322], [91.41632843, 23.26082993], [91.41628265, 23.26088905], [91.41624451, 23.26102066], [91.41624451, 23.26132393], [91.41621399, 23.26153564], [91.41616821, 23.26161194], [91.41607666, 23.26167107], [91.41597748, 23.26167297], [91.41569519, 23.26173019], [91.41566467, 23.26183701], [91.41578674, 23.26198959], [91.41581726, 23.26206017], [91.41576385, 23.26227379], [91.4158783, 23.26235008], [91.41609955, 23.26229477], [91.41622925, 23.26231194], [91.41635132, 23.26238441], [91.41640472, 23.26247787], [91.41623688, 23.26270294], [91.41600037, 23.26275444], [91.41584015, 23.2626915], [91.41567993, 23.26263046], [91.41557312, 23.26271057], [91.41564178, 23.26302528], [91.41580963, 23.26311493], [91.4158783, 23.26319885], [91.41582489, 23.26334572], [91.41565704, 23.26343727], [91.41557312, 23.26346016], [91.41535187, 23.26348495], [91.41543579, 23.2635746], [91.41592407, 23.2637558], [91.4162674, 23.26395798], [91.41636658, 23.26405525], [91.41639709, 23.26413727], [91.41629791, 23.26428413], [91.41629028, 23.264431], [91.41638947, 23.26453972], [91.41638947, 23.26462746], [91.41635132, 23.26477051], [91.41635895, 23.26490211], [91.41638947, 23.26498413], [91.41648102, 23.26506805], [91.41659546, 23.26480293], [91.41662598, 23.26471901], [91.41675568, 23.26464081], [91.41717529, 23.26452637], [91.41737366, 23.26462364], [91.41735077, 23.26471901], [91.41723633, 23.26485252], [91.41725922, 23.26494789], [91.41720581, 23.26502037], [91.41713715, 23.26504707], [91.41693115, 23.26498795], [91.41685486, 23.26505852], [91.4168396, 23.26513672], [91.41690063, 23.26561737], [91.41687012, 23.26581192], [91.41682434, 23.26599884], [91.4167099, 23.26616478], [91.4165802, 23.2662735], [91.41649628, 23.26641273], [91.41649628, 23.26654434], [91.41632843, 23.26691246], [91.41673279, 23.26664734], [91.41684723, 23.26658249], [91.41706848, 23.26655388], [91.41710663, 23.26667595], [91.41710663, 23.26680183], [91.41702271, 23.26700783], [91.41693878, 23.26712608], [91.41684723, 23.26721954], [91.41690063, 23.26744461], [91.41692352, 23.2677803], [91.41690826, 23.26800728], [91.41686249, 23.2682724], [91.41678619, 23.26835632], [91.41653442, 23.2685585], [91.4164505, 23.26872826], [91.41652679, 23.26886749], [91.41647339, 23.26893997], [91.41629791, 23.26911354], [91.41590118, 23.26949692], [91.41589355, 23.26962471], [91.41599274, 23.26966286], [91.41646576, 23.26927567], [91.41656494, 23.26923943], [91.41668701, 23.2692585], [91.41674805, 23.26938057], [91.41684723, 23.26952171], [91.41698456, 23.2695694], [91.41740417, 23.26963425], [91.4176712, 23.26964378], [91.41783142, 23.26965332], [91.4179306, 23.26965904], [91.41808319, 23.2697258], [91.41815948, 23.26980972], [91.41818237, 23.26998711], [91.41814423, 23.27024078], [91.41815948, 23.27056885], [91.41821289, 23.27067566], [91.41843414, 23.27095604], [91.41864777, 23.27127457], [91.41867065, 23.27136993], [91.41867065, 23.27147865], [91.41864014, 23.27166557], [91.41860199, 23.27182007], [91.41863251, 23.27200508], [91.41867828, 23.27215767], [91.41872406, 23.27230453], [91.41876984, 23.27237511], [91.41893005, 23.27235413], [91.41915131, 23.27235031], [91.41934204, 23.27252007], [91.41951752, 23.27274704], [91.41954041, 23.27289009], [91.41954803, 23.27305222], [91.41951752, 23.27342987], [91.41928101, 23.27363968], [91.41919708, 23.27367592], [91.41910553, 23.27374649], [91.41900635, 23.27380562], [91.41889191, 23.27380753], [91.41882324, 23.27383041], [91.41875458, 23.27394295], [91.41873932, 23.27407837], [91.41869354, 23.27425766], [91.4185791, 23.27427292], [91.4184494, 23.27429008], [91.41835785, 23.27431488], [91.41837311, 23.27442932], [91.41841125, 23.27474976], [91.41841888, 23.27483368], [91.41820526, 23.27487946], [91.41810608, 23.27487564], [91.41799164, 23.2748642], [91.41782379, 23.27482796], [91.41766357, 23.27485657], [91.4176712, 23.2749691], [91.41770172, 23.27505875], [91.41775513, 23.27523804], [91.4177475, 23.27534294], [91.41742706, 23.27530479], [91.41732788, 23.27537155], [91.41732025, 23.27546501], [91.41733551, 23.27560234], [91.41739655, 23.27569199], [91.41746521, 23.27581978], [91.41753387, 23.27586937], [91.41759491, 23.27592659], [91.4176712, 23.27598763], [91.4178009, 23.27611351], [91.41782379, 23.27619934], [91.4178009, 23.27627373], [91.4177475, 23.27632904], [91.41764069, 23.27632141], [91.41741943, 23.27627182], [91.41730499, 23.27622986], [91.41721344, 23.27620125], [91.41707611, 23.27614784], [91.41700745, 23.2761116], [91.41693115, 23.27599525], [91.41687012, 23.2759285], [91.41682434, 23.27584267], [91.41670227, 23.27578735], [91.41655731, 23.27579117], [91.41670227, 23.27590752], [91.41675568, 23.27607918], [91.41679382, 23.27624893], [91.41682434, 23.27646255], [91.41683197, 23.27661705], [91.41687775, 23.27683258], [91.41697693, 23.27684975], [91.4172287, 23.2768364], [91.41728973, 23.27689362], [91.41734314, 23.27713203], [91.41733551, 23.27723694], [91.41761017, 23.27731705], [91.4176712, 23.27736092], [91.41755676, 23.27752304], [91.41728973, 23.2776432], [91.41706848, 23.27774811], [91.41713715, 23.27788734], [91.41717529, 23.27811813], [91.41710663, 23.27832603], [91.41699982, 23.27851295], [91.41693878, 23.27857971], [91.41665649, 23.27864647], [91.4165802, 23.27872276], [91.4165802, 23.27882576], [91.41661835, 23.27893066], [91.41671753, 23.27913094], [91.4167099, 23.27924538], [91.41665649, 23.27931786], [91.4165802, 23.27933311], [91.41638947, 23.27925682], [91.4163208, 23.27931023], [91.41636658, 23.27941132], [91.41635895, 23.27952766], [91.41630554, 23.27963829], [91.41624451, 23.27972221], [91.41611481, 23.27975273], [91.416008, 23.27970123], [91.41595459, 23.2796402], [91.41599274, 23.27951622], [91.41600037, 23.27943039], [91.41594696, 23.27932549], [91.41578674, 23.27930069], [91.41561127, 23.27937508], [91.41553497, 23.27943993], [91.41548157, 23.27961731], [91.41543579, 23.27975273], [91.41544342, 23.27986336], [91.41546631, 23.27993965], [91.41547394, 23.28002357], [91.41546631, 23.28011513], [91.4154129, 23.28022766], [91.41536713, 23.28038216], [91.41534424, 23.2804966], [91.41534424, 23.28059387], [91.41537476, 23.28073502], [91.41545868, 23.28103065], [91.41558838, 23.28147316], [91.41552734, 23.28162193], [91.41542816, 23.28169823], [91.41535187, 23.2817955], [91.41530609, 23.28190804], [91.41523743, 23.28205109], [91.41526031, 23.28212929], [91.41532135, 23.28218842], [91.41545105, 23.28227806], [91.41558838, 23.28236198], [91.41560364, 23.28243256], [91.41559601, 23.28251457], [91.41556549, 23.28263664], [91.41556549, 23.28273582], [91.41559601, 23.28281403], [91.41559601, 23.28289986], [91.41552734, 23.28292465], [91.41531372, 23.28283119], [91.41522217, 23.28274345], [91.41510773, 23.28264236], [91.4149704, 23.28255463], [91.4145813, 23.28247833], [91.41448975, 23.28242874], [91.41428375, 23.28224564], [91.41416931, 23.28212166], [91.41398621, 23.28186798], [91.4139328, 23.28175926], [91.41399384, 23.28165245], [91.41409302, 23.28156281], [91.41410828, 23.28146553], [91.41402435, 23.2814312], [91.41390991, 23.28142738], [91.41370392, 23.28149033], [91.4134903, 23.28157997], [91.4133606, 23.28162575], [91.41330719, 23.28170776], [91.41329193, 23.28185272], [91.41327667, 23.28201103], [91.41320801, 23.28217888], [91.41313171, 23.28230858], [91.41308594, 23.28248787], [91.41307831, 23.28262711], [91.41304016, 23.28285408], [91.41294098, 23.28286934], [91.41283417, 23.28285027], [91.41273499, 23.28296661], [91.41264343, 23.28307343], [91.41254425, 23.28312302], [91.41246033, 23.28308868], [91.41236877, 23.28300095], [91.412323, 23.28287888], [91.41226196, 23.28268623], [91.41213989, 23.28265572], [91.41208649, 23.28271484], [91.41203308, 23.28289413], [91.4119339, 23.28310013], [91.41182709, 23.28329849], [91.41170502, 23.2834568], [91.41159058, 23.28360176], [91.41155243, 23.28368378], [91.41156769, 23.28377342], [91.41158295, 23.28396606], [91.41149902, 23.2841053], [91.41138458, 23.28420258], [91.41129303, 23.28424644], [91.41106415, 23.2842083], [91.41098022, 23.28420639], [91.41075134, 23.28424072], [91.4106369, 23.28419685], [91.41049957, 23.28413963], [91.4103775, 23.28412247], [91.41026306, 23.28415298], [91.4102478, 23.28425407], [91.41018677, 23.28441238], [91.41001892, 23.28460693], [91.40992737, 23.28463173], [91.40983582, 23.28460312], [91.40973663, 23.2845211], [91.40963745, 23.2844162], [91.40953827, 23.28437042], [91.40933228, 23.28434753], [91.40927124, 23.28438568], [91.40925598, 23.28452873], [91.4092865, 23.28464127], [91.40929413, 23.28473663], [91.4092865, 23.28483772], [91.40924835, 23.28491402], [91.40917206, 23.28507805], [91.40908051, 23.28518677], [91.40896606, 23.28528023], [91.40883636, 23.28532219], [91.40885162, 23.28505516], [91.40885925, 23.28475952], [91.40890503, 23.28373909], [91.40897369, 23.28247452], [91.40908051, 23.28048897], [91.40911102, 23.27989197], [91.40914154, 23.2793026], [91.40920258, 23.27812576], [91.40924835, 23.27714729], [91.40930939, 23.275877], [91.40934753, 23.27500725], [91.40938568, 23.27428436], [91.40940857, 23.27386665], [91.40946198, 23.27289391], [91.40956116, 23.27149582], [91.40962219, 23.27085304], [91.40975952, 23.26953888], [91.4098587, 23.26857948], [91.40994263, 23.26774216], [91.41009521, 23.26638222], [91.41021729, 23.26526642], [91.41026306, 23.26483154], [91.41033936, 23.26412392], [91.41046143, 23.26298904], [91.41047668, 23.26285362], [91.41055298, 23.26213837], [91.4105835, 23.26184273], [91.41069031, 23.26086044], [91.41077423, 23.26007462], [91.41087341, 23.25945282], [91.4109726, 23.25856972], [91.41107941, 23.25751495], [91.41118622, 23.25644302], [91.41123199, 23.25581551], [91.4101181, 23.25597954], [91.40969086, 23.25597191], [91.40849304, 23.25609589], [91.4077301, 23.25617409], [91.40770721, 23.25398064], [91.40770721, 23.25356293], [91.40849304, 23.25276947], [91.40908813, 23.25217247], [91.41104889, 23.25020981], [91.41316223, 23.24880981], [91.4156723, 23.24488258], [91.41485596, 23.24458885], [91.40725708, 23.24283028], [91.40303802, 23.23771095], [91.4061203, 23.23182106], [91.40647125, 23.23115921], [91.40400696, 23.22616005], [91.39582062, 23.22344017], [91.39697266, 23.2186203], [91.39691925, 23.21813202], [91.39678955, 23.21810913], [91.39658356, 23.21805191], [91.39641571, 23.21805382], [91.39630127, 23.21805573], [91.39617157, 23.21805763], [91.39602661, 23.21804428], [91.39585114, 23.21804619], [91.39569092, 23.2180481], [91.39555359, 23.21800613], [91.39539337, 23.21796608], [91.39527893, 23.21793747], [91.39514923, 23.21786499], [91.39501953, 23.21779442], [91.39488983, 23.21772194], [91.39479828, 23.21764946], [91.3946991, 23.21757889], [91.39461517, 23.21751976], [91.39456177, 23.21744728], [91.39450836, 23.21736145], [91.39443207, 23.21730232], [91.39437103, 23.21721649], [91.39428711, 23.21712875], [91.39415741, 23.21713829], [91.39412689, 23.2170639], [91.39380646, 23.21706581], [91.39341736, 23.21704674], [91.39331818, 23.21693039], [91.39292908, 23.21698189], [91.39272308, 23.21680641], [91.39257813, 23.21679497], [91.39233398, 23.21684837], [91.39212799, 23.2169323], [91.39192963, 23.21701813], [91.39176941, 23.21708298], [91.39146423, 23.21718597], [91.39110565, 23.21730614], [91.39072418, 23.21747017], [91.39026642, 23.21767044], [91.38962555, 23.21679115], [91.38894653, 23.21582222], [91.38851929, 23.21522903], [91.38822937, 23.21481895], [91.38742828, 23.21419907], [91.38668823, 23.21359253], [91.38542175, 23.2125206], [91.38452148, 23.2117672], [91.38386536, 23.21121788], [91.38301849, 23.21051407], [91.38227844, 23.20989227], [91.38134003, 23.20910835], [91.38069916, 23.20856667], [91.38204956, 23.20846176], [91.38341522, 23.20835686], [91.38462067, 23.2082653], [91.38503265, 23.20823479], [91.38587189, 23.20816803], [91.38645172, 23.20812416], [91.38768005, 23.20802307], [91.38761902, 23.20740891], [91.38755798, 23.20685005], [91.38748169, 23.20633125], [91.38742065, 23.20591927], [91.38726044, 23.204813], [91.38718414, 23.20423889], [91.38702393, 23.20310974], [91.38690948, 23.20223427], [91.38671875, 23.20100212], [91.38657379, 23.19998169], [91.38648987, 23.19936371], [91.3862915, 23.19791031], [91.3861618, 23.19721603], [91.38602448, 23.19626236], [91.38587189, 23.19507599], [91.38582611, 23.19470596], [91.38570404, 23.19360352], [91.38562012, 23.19303513], [91.38547516, 23.19198227], [91.38497162, 23.19195175], [91.38399506, 23.19189644], [91.38291931, 23.1918354], [91.38202667, 23.19178581], [91.38156128, 23.19176292], [91.38092041, 23.19173622], [91.3808136, 23.19111443], [91.38064575, 23.19005394], [91.38040924, 23.18859863], [91.38030243, 23.1879406], [91.38014984, 23.18673515], [91.38001251, 23.18569946], [91.37989044, 23.18476295], [91.37986755, 23.18461227], [91.38063049, 23.18470764], [91.38082886, 23.18473625], [91.38116455, 23.18478584], [91.38150787, 23.18479156], [91.38225555, 23.18471146], [91.38295746, 23.18462944], [91.38282776, 23.18379021], [91.38265228, 23.18239784], [91.38252258, 23.18141937], [91.38237762, 23.18045235], [91.3822403, 23.17939758], [91.3821106, 23.17815018], [91.38202667, 23.17731094], [91.38191223, 23.17602921], [91.3818512, 23.17536736], [91.38183594, 23.17515182], [91.38265991, 23.17520714], [91.38362122, 23.17525864], [91.38385773, 23.17527008], [91.38454437, 23.17530823], [91.38516998, 23.17534065], [91.38515472, 23.17517662], [91.38541412, 23.17514038], [91.38576508, 23.17507172], [91.38595581, 23.17505455], [91.38608551, 23.1751194], [91.38631439, 23.17513275], [91.38658905, 23.1751442], [91.38676453, 23.17513275], [91.38690186, 23.17515373], [91.38723755, 23.1751461], [91.38739777, 23.17515373], [91.38762665, 23.17516708], [91.38777161, 23.17525482], [91.38793182, 23.1752243], [91.38803101, 23.1752243], [91.38825989, 23.17526817], [91.38841248, 23.17529678], [91.38857269, 23.17529678], [91.38869476, 23.17532539], [91.38884735, 23.175354], [91.38918304, 23.17542839], [91.389328, 23.17548561], [91.38945007, 23.17555809], [91.38956451, 23.17557144], [91.3897171, 23.17564583], [91.3898468, 23.17570114], [91.38999939, 23.17577553], [91.39012909, 23.17584801], [91.39030457, 23.17596436], [91.39035797, 23.17510986], [91.39293671, 23.16765022], [91.39084625, 23.15761948], [91.39089203, 23.15728951], [91.39147186, 23.15258026], [91.39157104, 23.15246201], [91.39319611, 23.15057945], [91.39435577, 23.14998055], [91.39583588, 23.14752007], [91.39595032, 23.1471653], [91.39599609, 23.14702988], [91.39597321, 23.14686012], [91.39595032, 23.14674187], [91.39595795, 23.14654922], [91.39595032, 23.14635468], [91.39593506, 23.1462059], [91.39593506, 23.14602852], [91.39592743, 23.14581871], [91.39593506, 23.1457119], [91.39592743, 23.14553452], [91.39592743, 23.14542961], [91.39593506, 23.14532471], [91.39592743, 23.14515877], [91.39590454, 23.14495277], [91.39591217, 23.14484024], [91.39594269, 23.14470291], [91.39598846, 23.1445694], [91.39605713, 23.14440918], [91.39612579, 23.14424706], [91.39617157, 23.14409256], [91.3962326, 23.14386177], [91.39627838, 23.143713], [91.3963089, 23.14341545], [91.39631653, 23.14320564], [91.39631653, 23.14304352], [91.3963089, 23.14289474], [91.39628601, 23.14274597], [91.39628601, 23.14258194], [91.3962326, 23.14246559], [91.39611053, 23.14221764], [91.3960495, 23.14208794], [91.39600372, 23.14198494], [91.39595032, 23.1418972], [91.39588928, 23.14178085], [91.39584351, 23.14165115], [91.39579773, 23.14151955], [91.39576721, 23.14137268], [91.39576721, 23.14125443], [91.39576721, 23.14112091], [91.39577484, 23.14101791], [91.39577484, 23.14091492], [91.39577484, 23.14081192], [91.39582062, 23.14069176], [91.39585876, 23.14058685], [91.39591217, 23.14049721], [91.39595795, 23.14036369], [91.39600372, 23.14024353], [91.3960495, 23.14015388], [91.39610291, 23.14002037], [91.39619446, 23.13995743], [91.39632416, 23.13990974], [91.396492, 23.13985825], [91.39659882, 23.13982391], [91.39678955, 23.13976097], [91.39690399, 23.13977432], [91.39707184, 23.1397953], [91.39723206, 23.13978767], [91.39733887, 23.13978386], [91.39746094, 23.13978004], [91.39759064, 23.13979149], [91.39771271, 23.13980103], [91.39783478, 23.1397953], [91.39794159, 23.13982201], [91.3980484, 23.13984871], [91.39820862, 23.13988686], [91.39839935, 23.139925], [91.39861298, 23.1399765], [91.40119171, 23.13519096], [91.40310669, 23.12914276], [91.40325928, 23.12522125], [91.40349579, 23.11904144], [91.40380859, 23.11798096], [91.40503693, 23.11590004], [91.40541077, 23.11528969], [91.40666962, 23.11401939], [91.40748596, 23.11318016], [91.4088974, 23.11007118], [91.40999603, 23.10680962], [91.4090271, 23.10445976], [91.40930176, 23.10386276], [91.40805817, 23.09511948], [91.40801239, 23.09473038], [91.40821075, 23.09469032], [91.40943909, 23.09449959], [91.41240692, 23.09477806], [91.41297913, 23.09357071], [91.41216278, 23.09166908], [91.41284943, 23.09115982], [91.4125061, 23.08657074], [91.41226196, 23.08337021], [91.41283417, 23.08284187], [91.41291809, 23.08282852], [91.41326904, 23.08277512], [91.41339111, 23.08275604], [91.41426849, 23.08262062], [91.41439056, 23.08256912], [91.41477966, 23.08260918], [91.41497803, 23.08265495], [91.41523743, 23.08278084], [91.41532135, 23.08288956], [91.41539764, 23.08309174], [91.41545105, 23.08314705], [91.41558838, 23.0831852], [91.41637421, 23.08308792], [91.41652679, 23.08288383], [91.41659546, 23.08284378], [91.4168396, 23.08305359], [91.41725159, 23.0830307], [91.41741943, 23.08299255], [91.41748047, 23.08275986], [91.41744995, 23.0826683], [91.41752625, 23.08252144], [91.4171524, 23.08213234], [91.41648865, 23.08161545], [91.41630554, 23.08114243], [91.41625977, 23.08067703], [91.4162674, 23.08058548], [91.41629028, 23.0802803], [91.41635895, 23.07938576], [91.41633606, 23.07913971], [91.41624451, 23.07879448], [91.41608429, 23.07854843], [91.41592407, 23.07831192], [91.41584015, 23.07788658], [91.41592407, 23.0776844], [91.41606903, 23.07754326], [91.41612244, 23.07738876], [91.41616058, 23.07715225], [91.41615295, 23.07702446], [91.41610718, 23.07678604], [91.41604614, 23.07665634], [91.41477966, 23.07643509], [91.41370392, 23.07619095], [91.41349792, 23.07601929], [91.41332245, 23.07559586], [91.41332245, 23.07529449], [91.41344452, 23.07504845], [91.41364288, 23.07497215], [91.41363525, 23.07483101], [91.4134903, 23.07344627], [91.41339111, 23.07249451], [91.41324615, 23.0710392], [91.41312408, 23.06988525], [91.41313171, 23.06966019], [91.4127655, 23.06951523], [91.41265106, 23.06907845], [91.41259003, 23.06863213], [91.41229248, 23.06818008], [91.41186523, 23.06770325], [91.41130829, 23.06706238], [91.41114807, 23.06692505], [91.41101074, 23.06673431], [91.41082001, 23.06642723], [91.41079712, 23.06617928], [91.4108429, 23.06607819], [91.41108704, 23.06588364], [91.41196442, 23.06558037], [91.41282654, 23.06557655], [91.41290283, 23.06556129], [91.41372681, 23.06539154], [91.41421509, 23.06527138], [91.41467285, 23.06516075], [91.4152832, 23.06505585], [91.41578674, 23.06515312], [91.41639709, 23.06527138], [91.41687012, 23.06523895], [91.41716766, 23.06515694], [91.41731262, 23.06499672], [91.41716003, 23.06470108], [91.41681671, 23.06440544], [91.41657257, 23.06409264], [91.41674805, 23.06395912], [91.41689301, 23.0638752], [91.41699982, 23.06380081], [91.41707611, 23.06372452], [91.41727448, 23.06363487], [91.41738892, 23.06356621], [91.41754913, 23.06347847], [91.41773987, 23.0633812], [91.41783905, 23.06332779], [91.41796875, 23.06326866], [91.41807556, 23.0632], [91.41822815, 23.06317139], [91.418396, 23.06308937], [91.41848755, 23.06310844], [91.41866302, 23.06310081], [91.41876984, 23.063097], [91.41893768, 23.0631237], [91.41909027, 23.06310654], [91.41989136, 23.0614109], [91.42199707, 23.05924988], [91.41765594, 23.05561066], [91.41246796, 23.05408287], [91.41255951, 23.05440903], [91.41262817, 23.0545845], [91.41268158, 23.05473328], [91.41270447, 23.05483246], [91.41273499, 23.05498505], [91.4127121, 23.05508614], [91.41270447, 23.05537415], [91.41272736, 23.0555439], [91.41262054, 23.05565643], [91.41259003, 23.05574036], [91.41259766, 23.05593681], [91.41262817, 23.05611801], [91.41260529, 23.0562706], [91.4125824, 23.05639648], [91.41256714, 23.05650711], [91.41255188, 23.056633], [91.41253662, 23.05677032], [91.4125061, 23.05687904], [91.41255188, 23.05706406], [91.41246033, 23.05714607], [91.41235352, 23.05714607], [91.41197205, 23.05723381], [91.4118042, 23.05729294], [91.41171265, 23.05731392], [91.41156769, 23.0573597], [91.41146088, 23.05740929], [91.41134644, 23.05745506], [91.41121674, 23.0575161], [91.41111755, 23.05761909], [91.41103363, 23.0577507], [91.41099548, 23.05788612], [91.41091919, 23.05810547], [91.41087341, 23.05825043], [91.41085052, 23.05841827], [91.41085052, 23.05853844], [91.41085815, 23.05865669], [91.41086578, 23.05879784], [91.41086578, 23.05887985], [91.41086578, 23.05906868], [91.41087341, 23.05924225], [91.41088104, 23.05933571], [91.41088867, 23.05951309], [91.41092682, 23.05962563], [91.41095734, 23.05978394], [91.41098022, 23.05985832], [91.41101837, 23.0600071], [91.41107178, 23.06012535], [91.41110992, 23.06024551], [91.41114044, 23.06038094], [91.41116333, 23.06046104], [91.4111557, 23.06055832], [91.41120911, 23.06072807], [91.41123199, 23.06098557], [91.41125488, 23.06110764], [91.41127014, 23.06122589], [91.41127777, 23.06133842], [91.41130066, 23.06149483], [91.41127014, 23.06168365], [91.41077423, 23.06125259], [91.41059113, 23.06119728], [91.41055298, 23.06095695], [91.4098053, 23.06072617], [91.40930939, 23.06044006], [91.40908813, 23.06035423], [91.40883636, 23.0603447], [91.40864563, 23.06018066], [91.40853882, 23.06011772], [91.40837097, 23.06010246], [91.4074707, 23.06008911], [91.40699005, 23.06008148], [91.40686798, 23.05998611], [91.40677643, 23.05984497], [91.40673065, 23.05978394], [91.40652466, 23.05947113], [91.40628052, 23.05936241], [91.40626526, 23.0591259], [91.40557098, 23.05913353], [91.40501404, 23.05908775], [91.4046936, 23.05880547], [91.40459442, 23.05875397], [91.4036026, 23.05924606], [91.40306091, 23.05916023], [91.40260315, 23.05870247], [91.40229797, 23.05848312], [91.40196228, 23.05846596], [91.40170288, 23.05841255], [91.40110779, 23.05831146], [91.40093231, 23.05857849], [91.40068817, 23.05853081], [91.40059662, 23.05854607], [91.40049744, 23.05852699], [91.40024567, 23.05854797], [91.40006256, 23.0585537], [91.39961243, 23.05856323], [91.39918518, 23.05857086], [91.39899445, 23.0575428], [91.39867401, 23.05664635], [91.39855194, 23.05661774], [91.39833832, 23.05665779], [91.39811707, 23.05654716], [91.39779663, 23.05646133], [91.39772034, 23.05640984], [91.39712524, 23.05637169], [91.3970108, 23.05626869], [91.39664459, 23.05614281], [91.39651489, 23.05625916], [91.39581299, 23.05620384], [91.39573669, 23.0562973], [91.39559174, 23.05638885], [91.39508057, 23.05673027], [91.39429474, 23.05724716], [91.3931427, 23.05800819], [91.39152527, 23.05918312], [91.3903656, 23.06002045], [91.38977051, 23.06005669], [91.38909912, 23.06044579], [91.3878479, 23.06116486], [91.38764191, 23.06128502], [91.38695526, 23.06167984], [91.38613129, 23.06215858], [91.38491821, 23.0628624], [91.38414001, 23.06328583], [91.38341522, 23.06367493], [91.38249207, 23.06416321], [91.38154602, 23.06466484], [91.3809433, 23.06498528], [91.38027954, 23.06533432], [91.3793335, 23.06583023], [91.37911987, 23.06594467], [91.37856293, 23.06624222], [91.37840271, 23.06636429], [91.3781662, 23.0665493], [91.37786102, 23.06674576], [91.37750244, 23.06678581], [91.37671661, 23.06687355], [91.37604523, 23.06720734], [91.37535095, 23.06757164], [91.37485504, 23.06782341], [91.37425995, 23.06813049], [91.37362671, 23.06845665], [91.37307739, 23.06877518], [91.37272644, 23.06895447], [91.37232971, 23.06916237], [91.3719635, 23.06935692], [91.37189484, 23.06939507], [91.37168121, 23.06951141], [91.37146759, 23.06965446], [91.37078094, 23.07004166], [91.37032318, 23.07027245], [91.36972046, 23.07052231], [91.36936188, 23.07107735], [91.36858368, 23.07226563], [91.36804962, 23.07308006], [91.36773682, 23.07355118], [91.36668396, 23.07509613], [91.36601257, 23.0761013], [91.36497498, 23.07761574], [91.36450195, 23.07831192], [91.36391449, 23.07917976], [91.3634491, 23.07986259], [91.36281586, 23.08077812], [91.3620224, 23.08194351], [91.36058044, 23.0840435], [91.35929871, 23.08591652], [91.35835266, 23.08731651], [91.35810852, 23.08778381], [91.35749817, 23.08868027], [91.35696411, 23.08946228], [91.35626221, 23.09055138], [91.35532379, 23.09192467], [91.35460663, 23.09298515], [91.35398865, 23.09391403], [91.35346222, 23.09469032], [91.35284424, 23.09561348], [91.35233307, 23.09636688], [91.3514328, 23.09770203], [91.35009766, 23.09912491], [91.34885406, 23.10045052], [91.34838867, 23.10094833], [91.34731293, 23.10207939], [91.3471756, 23.10221291], [91.3469162, 23.10245895], [91.3469696, 23.10420799], [91.34700012, 23.10530663], [91.34703827, 23.10671616], [91.34707642, 23.10786629], [91.3470993, 23.10853958], [91.34711456, 23.10906982], [91.34712982, 23.10949707], [91.34716034, 23.11022568], [91.34718323, 23.11117744], [91.34716797, 23.11185646], [91.34719086, 23.11287308], [91.34725952, 23.11418343], [91.34729767, 23.11555099], [91.347435, 23.11674309], [91.34745026, 23.11688232], [91.34742737, 23.11714935], [91.3475647, 23.11893082], [91.34729004, 23.11888695], [91.3467865, 23.11880875], [91.34558105, 23.11860085], [91.34410095, 23.11834335], [91.34277344, 23.11811829], [91.3418045, 23.11795807], [91.34168243, 23.11849022], [91.34169006, 23.1195488], [91.34169006, 23.12037659], [91.34169769, 23.12183952], [91.34170532, 23.12355614], [91.34172821, 23.12494278], [91.34171295, 23.12590599], [91.34168243, 23.12764168], [91.34165955, 23.12889481], [91.34081268, 23.12931442], [91.33933258, 23.13004684], [91.33823395, 23.13059235], [91.33701324, 23.13120079], [91.33681488, 23.13220978], [91.33647919, 23.13388443], [91.33613586, 23.13586807], [91.33575439, 23.13801765], [91.33551788, 23.13934135], [91.33506012, 23.14149857], [91.33477783, 23.14352226], [91.3345108, 23.1449852], [91.33428955, 23.14617538], [91.33424377, 23.14640617], [91.33409882, 23.14713669], [91.33383179, 23.14866638], [91.33363342, 23.14978409], [91.33348083, 23.15061188], [91.33329773, 23.15166473], [91.33305359, 23.15301704], [91.33158875, 23.15387535], [91.33041382, 23.15450287], [91.32901001, 23.15525055], [91.32810974, 23.15572357], [91.32720184, 23.15619278], [91.32609558, 23.15682411], [91.32492065, 23.15741348], [91.32331848, 23.15822029], [91.32413483, 23.16007042], [91.32419586, 23.16139984], [91.32426453, 23.16266441], [91.3243103, 23.16339302], [91.32432556, 23.16363907], [91.32437134, 23.16434669], [91.32445526, 23.1656456], [91.32453918, 23.16688156], [91.32459259, 23.16766739], [91.32466888, 23.16877556], [91.32463074, 23.16971779], [91.32459259, 23.17136383], [91.32456207, 23.17237473], [91.32452393, 23.17372131], [91.32443237, 23.17609978], [91.32436371, 23.17799187], [91.32433319, 23.17885208], [91.32427216, 23.18103409], [91.32418823, 23.18336868], [91.32411957, 23.18516541], [91.32406616, 23.18669128], [91.32400513, 23.1883297], [91.32394409, 23.19017601], [91.32385254, 23.192379], [91.32383728, 23.19462776], [91.32381439, 23.19637871], [91.32380676, 23.19702339], [91.32376862, 23.1985569], [91.32374573, 23.1993351], [91.32372284, 23.20096397], [91.32371521, 23.20172882], [91.3237381, 23.20336533], [91.32374573, 23.20471764], [91.32370758, 23.20562935], [91.32373047, 23.207407], [91.32373047, 23.208498], [91.3237381, 23.21001625], [91.32374573, 23.21119118], [91.32375336, 23.21164703], [91.32375336, 23.2118721], [91.32375336, 23.21331406], [91.32373047, 23.21467781], [91.32371521, 23.21579361], [91.32369995, 23.21719742], [91.32368469, 23.21814346], [91.3236618, 23.21953583], [91.3236618, 23.22026825], [91.32365417, 23.22178078], [91.32364655, 23.22315788], [91.32361603, 23.22510719], [91.32361603, 23.22608185], [91.3236084, 23.22686386], [91.3236084, 23.22817421], [91.32361603, 23.22853661], [91.3236084, 23.23001671], [91.32360077, 23.23129272], [91.32359314, 23.23302078], [91.32359314, 23.23474121], [91.32358551, 23.23660088], [91.32358551, 23.23701096], [91.32358551, 23.23760605], [91.32228851, 23.23826599], [91.32009888, 23.23937607], [91.31886292, 23.24000931], [91.31881714, 23.24097633], [91.31874847, 23.24273682], [91.31867218, 23.2444458], [91.31864929, 23.24514961], [91.3186264, 23.24562073], [91.3203125, 23.24603653], [91.32223511, 23.2464962], [91.32391357, 23.24691772], [91.32409668, 23.2469635], [91.32456207, 23.24707985], [91.32542419, 23.24728584], [91.32559967, 23.24810791], [91.32575226, 23.2487812], [91.32595062, 23.24967575], [91.32623291, 23.25100136], [91.32654572, 23.25243759], [91.3249054, 23.25255966], [91.3234787, 23.25264931], [91.32275391, 23.25270653], [91.32152557, 23.2528019], [91.32109833, 23.25283051], [91.32060242, 23.25286484], [91.31989288, 23.25291634], [91.31795502, 23.25304794], [91.31781006, 23.25346565], [91.31757355, 23.25414467], [91.3168335, 23.25630951], [91.31674194, 23.25654602], [91.31648254, 23.25720596], [91.31613922, 23.25828171], [91.31568146, 23.25951958], [91.31532288, 23.26054001], [91.31490326, 23.26179504], [91.31479645, 23.26210403], [91.31459045, 23.2626915], [91.3140564, 23.26419258], [91.31352997, 23.26568222], [91.31309509, 23.26695633], [91.3126297, 23.26826096], [91.31250763, 23.26860237], [91.31214142, 23.26961708], [91.31188965, 23.27037048], [91.31135559, 23.27193069], [91.31092072, 23.27317047], [91.31076813, 23.27362251], [91.31032562, 23.27483749], [91.3097229, 23.27651024], [91.31103516, 23.27719688], [91.31193542, 23.27767181], [91.31215668, 23.27778435], [91.31296539, 23.27819824], [91.31363678, 23.27856255], [91.3145752, 23.27902603], [91.31516266, 23.27931786], [91.31568909, 23.27957344], [91.31581116, 23.27979088], [91.31628418, 23.28063965], [91.31667328, 23.28133202], [91.31671906, 23.28141403], [91.31661987, 23.28201866], [91.31575012, 23.28228951], [91.31413269, 23.28279114], [91.31260681, 23.28326416], [91.31157684, 23.28358459], [91.31032562, 23.28397751], [91.30895233, 23.28441048], [91.30823517, 23.28456116], [91.30814362, 23.28459167], [91.30714417, 23.28491783], [91.3068161, 23.28502464], [91.30394745, 23.28594971], [91.30228424, 23.28649521], [91.30172729, 23.28814697], [91.30144501, 23.28894043], [91.30101776, 23.29013824], [91.30079651, 23.29075623], [91.30019379, 23.29242134], [91.30015564, 23.29257584], [91.30030823, 23.29273415], [91.30114746, 23.29361153], [91.30220795, 23.29468536], [91.30357361, 23.2961483], [91.30451202, 23.29712677], [91.30471802, 23.29734039], [91.30543518, 23.29810333], [91.30601501, 23.29873848], [91.30686951, 23.29962158], [91.3069458, 23.29970169], [91.30715179, 23.29991341], [91.30809784, 23.29949188], [91.30874634, 23.29922485], [91.30928802, 23.29899788], [91.31004333, 23.29870033], [91.31118011, 23.29825974], [91.3125, 23.29949951], [91.31441498, 23.29958344], [91.3139801, 23.30179596], [91.31390381, 23.30216789], [91.31362915, 23.30357552], [91.31329346, 23.30538368], [91.31319427, 23.30588913], [91.31307983, 23.30648041], [91.31237793, 23.30793953], [91.31194305, 23.30883789], [91.31173706, 23.30928802], [91.31162262, 23.30955124], [91.31105804, 23.31079292], [91.31044769, 23.31196976], [91.30947113, 23.31400108], [91.3092041, 23.31399536], [91.30744171, 23.31395721], [91.30523682, 23.31390762], [91.3039093, 23.31385422], [91.30365753, 23.31384468], [91.30226898, 23.31378937], [91.30206299, 23.31378365], [91.30145264, 23.31376839], [91.30123138, 23.31375694], [91.30075836, 23.31373596], [91.29995728, 23.31369781], [91.29959869, 23.31368065], [91.29883575, 23.31364822], [91.29646301, 23.31356239], [91.29612732, 23.31357384], [91.29547119, 23.31411552], [91.29347229, 23.31572151], [91.29306793, 23.31604576], [91.29256439, 23.31645393], [91.29073334, 23.31794357], [91.28979492, 23.31865883], [91.2898941, 23.31889153], [91.29008484, 23.31935883], [91.29068756, 23.32084846], [91.29140472, 23.32260704], [91.29166412, 23.32324791], [91.29183197, 23.32366753], [91.29229736, 23.32479858], [91.29255676, 23.32598877], [91.29278564, 23.32695007], [91.2930069, 23.32790756], [91.29356384, 23.33023643], [91.29399872, 23.33207512], [91.29425049, 23.33315086], [91.29468536, 23.33509445], [91.29493713, 23.33613777], [91.2951355, 23.33695793], [91.29541016, 23.3380909], [91.29573822, 23.33944893], [91.29611206, 23.34099579], [91.29691315, 23.34103775], [91.29978943, 23.3419342], [91.30317688, 23.34298134], [91.30505371, 23.34354591], [91.30547333, 23.34347343], [91.30782318, 23.34306717], [91.31049347, 23.3426075], [91.31072998, 23.34256554], [91.31043243, 23.34407425], [91.31031036, 23.34466553], [91.31005096, 23.34594917], [91.31045532, 23.34884453], [91.31077576, 23.35121727], [91.31093597, 23.35241699], [91.31096649, 23.35262108], [91.31100464, 23.35282516], [91.31121826, 23.35287285], [91.31134796, 23.35290337], [91.3115387, 23.35311508], [91.31150818, 23.35330009], [91.31149292, 23.3533802], [91.31151581, 23.35349655], [91.31163788, 23.35357857], [91.31178284, 23.35360718], [91.31201935, 23.35363579], [91.31214905, 23.35377312], [91.31227112, 23.35400009], [91.31251526, 23.3540535], [91.31280518, 23.35404778], [91.31311035, 23.35398293], [91.3133316, 23.3537159], [91.31355286, 23.35321617], [91.31383514, 23.35299301], [91.31421661, 23.35279465], [91.31436157, 23.35277939], [91.31472778, 23.35274506], [91.31507874, 23.35286713], [91.31543732, 23.35299492], [91.31578064, 23.35326958], [91.31588745, 23.35324669], [91.31617737, 23.35339546], [91.31660461, 23.35320091], [91.31710052, 23.35301018], [91.31738281, 23.35295486], [91.31763458, 23.35300827], [91.31790161, 23.35310364], [91.31815338, 23.35334206], [91.31816864, 23.35344887], [91.31819916, 23.3536396], [91.31863403, 23.35520554], [91.31904602, 23.35669899], [91.31919861, 23.35725021], [91.319664, 23.35894203], [91.32002258, 23.36023712], [91.31837463, 23.36050034], [91.31813049, 23.36054039], [91.31663513, 23.35996628], [91.31654358, 23.35990524], [91.316185, 23.35970116], [91.31232452, 23.35747337], [91.31224823, 23.35743141], [91.30932617, 23.35528564], [91.3069458, 23.35469055], [91.30471802, 23.35424995], [91.30425262, 23.35393333], [91.30405426, 23.35380173], [91.30311584, 23.35316658], [91.3009491, 23.35169792], [91.30084991, 23.35169029], [91.29995728, 23.35161591], [91.29886627, 23.35151482], [91.29761505, 23.35139084], [91.29620361, 23.35128593], [91.29572296, 23.35124779], [91.29505157, 23.35119438], [91.29457092, 23.35115433], [91.29337311, 23.35102654], [91.29225922, 23.3509407], [91.29162598, 23.35089111], [91.29099274, 23.35079002], [91.29115295, 23.35133362], [91.29125977, 23.35153198], [91.29156494, 23.35237312], [91.29225922, 23.35430145], [91.29238892, 23.35466576], [91.29256439, 23.35518837], [91.29290771, 23.35620689], [91.29348755, 23.35784531], [91.29450989, 23.36074638], [91.29483795, 23.36133575], [91.29293823, 23.36177635], [91.2908783, 23.36223221], [91.28996277, 23.36242485], [91.28848267, 23.36275673], [91.28792572, 23.36288071], [91.28692627, 23.36310387], [91.28655243, 23.36318588], [91.28611755, 23.36328125], [91.28583527, 23.36437225], [91.28535461, 23.36654472], [91.28490448, 23.36839867], [91.2844696, 23.37019348], [91.28442383, 23.37038422], [91.28436279, 23.3706398], [91.28420258, 23.37129974], [91.28516388, 23.37130928], [91.28620148, 23.37131882], [91.28798676, 23.37135315], [91.29111481, 23.37138748], [91.29092407, 23.37181282], [91.29381561, 23.37216187], [91.29393005, 23.37289429], [91.29430389, 23.37484741], [91.2937088, 23.37534714], [91.29347229, 23.37561798], [91.29335022, 23.37582588], [91.29331207, 23.3761692], [91.29323578, 23.37643814], [91.29320526, 23.37683487], [91.29322052, 23.37723923], [91.29325867, 23.37745285], [91.2913208, 23.37689209], [91.29047394, 23.37708855], [91.29013062, 23.37655067], [91.28973389, 23.37611198], [91.28965759, 23.37602043], [91.2894516, 23.37595749], [91.28908539, 23.37590218], [91.28877258, 23.37571144], [91.28858185, 23.375597], [91.28848267, 23.37554359], [91.28836823, 23.37554932], [91.28819275, 23.37561226], [91.28810883, 23.37571144], [91.28783417, 23.37592888], [91.28762817, 23.37609673], [91.28748322, 23.37622833], [91.28726959, 23.37622833], [91.28713226, 23.37618637], [91.28694916, 23.37606239], [91.2864151, 23.37626839], [91.28578949, 23.3764801], [91.28569794, 23.37652016], [91.28543091, 23.37677193], [91.28511047, 23.37717247], [91.28407288, 23.37708092], [91.2837677, 23.37691307], [91.28278351, 23.37665939], [91.28263092, 23.37650871], [91.2821579, 23.37603951], [91.28205109, 23.37599945], [91.28192902, 23.37604332], [91.28171539, 23.3761158], [91.28105164, 23.37638855], [91.28086853, 23.37658691], [91.28066254, 23.37674141], [91.28049469, 23.37674713], [91.28045654, 23.37658119], [91.28028107, 23.37678528], [91.28009796, 23.37672043], [91.2796936, 23.37677765], [91.27961731, 23.37781143], [91.27954102, 23.37878418], [91.27950287, 23.37922287], [91.27939606, 23.38071632], [91.27936554, 23.38111115], [91.27933502, 23.38143921], [91.27923584, 23.38256264], [91.27920532, 23.38290977], [91.27914429, 23.38380623], [91.27905273, 23.38499832], [91.27893829, 23.3864212], [91.27882385, 23.38791466], [91.27864838, 23.3899498], [91.27861023, 23.39042091], [91.27851868, 23.39149857], [91.27848816, 23.39182281], [91.27842712, 23.39249229], [91.27835083, 23.39379311], [91.27831268, 23.39422417], [91.27824402, 23.39505005], [91.27812195, 23.39649582], [91.27803802, 23.39761162], [91.27801514, 23.39785767], [91.27794647, 23.39876366], [91.2779007, 23.39945602], [91.27776337, 23.40062714], [91.27759552, 23.40240288], [91.27745819, 23.40373039], [91.27738953, 23.40450478], [91.2772522, 23.40571404], [91.27715302, 23.40685272], [91.27706146, 23.40784645], [91.27696991, 23.40873718], [91.27685547, 23.40984344], [91.27671814, 23.41117477], [91.27663422, 23.41197968], [91.27646637, 23.41386414], [91.27637482, 23.41482735], [91.2749176, 23.41579437], [91.27440643, 23.4161377], [91.27349091, 23.41676331], [91.27278137, 23.41724205], [91.27165222, 23.41804314], [91.27111816, 23.41842461], [91.27070618, 23.41871071], [91.26969147, 23.41941643], [91.26925659, 23.41971588], [91.26895905, 23.41994858], [91.26811218, 23.42054558], [91.2676239, 23.42088699], [91.26659393, 23.42160034], [91.26611328, 23.42193794], [91.26560974, 23.42229462], [91.26522827, 23.42255783], [91.26448822, 23.42306328], [91.26403809, 23.42337608], [91.26395416, 23.4234333], [91.26338959, 23.42385101], [91.26423645, 23.42451477], [91.26480865, 23.42500305], [91.26592255, 23.42594528], [91.26687622, 23.42676163], [91.26737213, 23.42718124], [91.26779175, 23.42753983], [91.26851654, 23.42815208], [91.26908112, 23.42863464], [91.26953888, 23.42903137], [91.26993561, 23.42937279], [91.27060699, 23.42993546], [91.26912689, 23.43120956], [91.26894379, 23.43136978], [91.26854706, 23.43171883], [91.26828003, 23.43195915], [91.2678833, 23.4323101], [91.26780701, 23.43238449], [91.26676178, 23.43333244], [91.26636505, 23.43364716], [91.26615143, 23.433815], [91.26544189, 23.43437958], [91.26454163, 23.43514061], [91.26346588, 23.43608665], [91.26262665, 23.43679428], [91.26208496, 23.43722916], [91.26164246, 23.43759727], [91.26092529, 23.43820953], [91.25947571, 23.43916512], [91.25941467, 23.43920517], [91.25872803, 23.43965149], [91.25780487, 23.44043159], [91.25701141, 23.44114304], [91.2565918, 23.44151688], [91.25640106, 23.44169426], [91.25637054, 23.44237709], [91.25628662, 23.44408989], [91.25627136, 23.4442749], [91.25624084, 23.44495583], [91.25592041, 23.44659615], [91.25572205, 23.44751358], [91.25536346, 23.44797897], [91.25474548, 23.44881058], [91.2545166, 23.44910049], [91.25410461, 23.44967842], [91.25371552, 23.45021057], [91.25326538, 23.45092773], [91.25293732, 23.45144081], [91.25270844, 23.45180511], [91.25167847, 23.45344734], [91.2514801, 23.45377731], [91.25196838, 23.45484924], [91.25200653, 23.45493698], [91.25279999, 23.45671463], [91.25341797, 23.45814514], [91.25337982, 23.45933342], [91.25335693, 23.46060562], [91.2533493, 23.46154213], [91.2525177, 23.46189117], [91.2517395, 23.46229172], [91.25112152, 23.46282768], [91.25102997, 23.46290779], [91.25095367, 23.46340752], [91.25082397, 23.46387291], [91.25075531, 23.46448326], [91.25105286, 23.46500969], [91.25138092, 23.46552658], [91.25153351, 23.46613312], [91.25158691, 23.46681023], [91.2515564, 23.46723938], [91.25160217, 23.46780968], [91.25160217, 23.46788216], [91.25157928, 23.46814346], [91.25144958, 23.468647], [91.25135803, 23.46901703], [91.25131989, 23.46907806], [91.25112915, 23.46942711], [91.25072479, 23.46976852], [91.25094604, 23.47058296], [91.2510376, 23.47099113], [91.25115967, 23.47152519], [91.2514801, 23.47289276], [91.25158691, 23.4740696], [91.25163269, 23.4746151], [91.2518158, 23.47690773], [91.25183868, 23.47719574], [91.25193024, 23.478302], [91.25196838, 23.47877121], [91.25202942, 23.47948647], [91.25205994, 23.47982788], [91.25215149, 23.48090935], [91.25217438, 23.48114586], [91.25190735, 23.48180389], [91.2515564, 23.48267365], [91.25119781, 23.48357391], [91.25100708, 23.48407364], [91.25050354, 23.48538399], [91.25009918, 23.48639107], [91.24981689, 23.48765373], [91.24951935, 23.48908043], [91.24936676, 23.48979568], [91.24925995, 23.49031258], [91.24365997, 23.49035454], [91.24121857, 23.490448], [91.24069214, 23.49038887], [91.23965454, 23.4901104], [91.2387619, 23.48985481], [91.23630524, 23.48914528], [91.23659515, 23.4912281], [91.23678589, 23.49263763], [91.2371521, 23.4952774], [91.23620605, 23.49562263], [91.23573303, 23.49579048], [91.2347641, 23.4961319], [91.23435974, 23.49627304], [91.23439789, 23.49643898], [91.23448181, 23.49682236], [91.23480988, 23.49843407], [91.23490906, 23.49893761], [91.23516083, 23.5001297], [91.23551178, 23.50191879], [91.2354126, 23.50187302], [91.23235321, 23.50048256], [91.23208618, 23.50036049], [91.2307663, 23.49975777], [91.23015594, 23.49947357], [91.22962952, 23.49922752], [91.22901154, 23.49904251], [91.2279129, 23.49872971], [91.22757721, 23.49863052], [91.22605896, 23.49818611], [91.22515106, 23.49793434], [91.22354889, 23.49750137], [91.22335815, 23.49744797], [91.22296906, 23.49743271], [91.2226181, 23.49742508], [91.22148132, 23.49796295], [91.21994019, 23.49869728], [91.21923828, 23.49902725], [91.21836853, 23.49943924], [91.21792603, 23.49964714], [91.21831512, 23.50060463], [91.21860504, 23.50137138], [91.21893311, 23.50227547], [91.21930695, 23.50327682], [91.21975708, 23.50446892], [91.22071075, 23.50698853], [91.22116852, 23.50822449], [91.22170258, 23.50952721], [91.22189331, 23.51002121], [91.22222137, 23.51086807], [91.22259521, 23.51181984], [91.22341156, 23.51392746], [91.22290039, 23.51391602], [91.21808624, 23.51342392], [91.21796417, 23.51338196], [91.21551514, 23.51251221], [91.21235657, 23.51349449], [91.21202087, 23.51340294], [91.21125793, 23.51318741], [91.20992279, 23.51281548], [91.20775604, 23.51221275], [91.20601654, 23.51417732], [91.20521545, 23.51508141], [91.20503998, 23.51527405], [91.20479584, 23.51555252], [91.20400238, 23.51644707], [91.2039032, 23.5165596], [91.20347595, 23.51703453], [91.2024231, 23.51822853], [91.20111084, 23.519701], [91.20070648, 23.52016258], [91.20070648, 23.52026176], [91.20069122, 23.52087212], [91.20068359, 23.52108192], [91.20065308, 23.52217484], [91.20063019, 23.52314568], [91.20124817, 23.52461052], [91.20199585, 23.526371], [91.20307922, 23.52896309], [91.20368958, 23.53041077], [91.20391846, 23.53096771], [91.20424652, 23.53170967], [91.20451355, 23.53236389], [91.20480347, 23.53305817], [91.20519257, 23.53398705], [91.20558929, 23.53520966], [91.20578003, 23.53582001], [91.20631409, 23.53756142], [91.20674896, 23.53894615], [91.20689392, 23.53936577], [91.20746613, 23.54123306], [91.20787811, 23.54251671], [91.2080307, 23.54297066], [91.20809937, 23.5431881], [91.21035767, 23.54416084], [91.21231079, 23.54501152], [91.21296692, 23.54528236], [91.21295929, 23.54568863], [91.2129364, 23.54802704], [91.2129364, 23.54814529], [91.21284485, 23.54811287], [91.21230316, 23.54782104], [91.21089935, 23.54689407], [91.21032715, 23.54689407], [91.2104187, 23.54665947], [91.20964813, 23.54649925], [91.20939636, 23.54613686], [91.20909119, 23.54602051], [91.20861816, 23.54587364], [91.20827484, 23.54579163], [91.20806122, 23.54594803], [91.20779419, 23.54603577], [91.20742798, 23.54550362], [91.20713043, 23.54546928], [91.20664978, 23.54567909], [91.20636749, 23.54569817], [91.20574951, 23.54553223], [91.20527649, 23.54540443], [91.2041626, 23.54699898], [91.20362091, 23.54776573], [91.20227814, 23.54744911], [91.20219421, 23.54746819], [91.19952393, 23.5480957], [91.19924927, 23.5483551], [91.19890594, 23.54806328], [91.19897461, 23.547472], [91.19801331, 23.54743576], [91.19586182, 23.547369], [91.19438171, 23.54732323], [91.1944046, 23.54768562], [91.19441986, 23.54802322], [91.19462585, 23.55164528], [91.19483185, 23.55528259], [91.19502258, 23.55861092], [91.19507599, 23.55960464], [91.19515991, 23.56114197], [91.19520569, 23.5619297], [91.19522095, 23.56213951], [91.19509888, 23.56261063], [91.19502258, 23.56271553], [91.19484711, 23.56294632], [91.19394684, 23.56414986], [91.19294739, 23.56549072], [91.1917038, 23.567173], [91.19047546, 23.5688343], [91.18940735, 23.57028961], [91.18904877, 23.57078934], [91.18844604, 23.57159996], [91.18739319, 23.57302475], [91.18721008, 23.57326698], [91.18721771, 23.57339287], [91.18709564, 23.5735321], [91.1871109, 23.57363319], [91.18711853, 23.57387352], [91.18713379, 23.57440948], [91.1872406, 23.57765961], [91.18671417, 23.57767487], [91.18591309, 23.57769775], [91.18408966, 23.57942581], [91.18397522, 23.57953644], [91.18231201, 23.58065224], [91.18136597, 23.58127975], [91.18112946, 23.58143806], [91.18036652, 23.58218575], [91.18019867, 23.58235359], [91.18006134, 23.58252716], [91.1780014, 23.58410263], [91.17681122, 23.58416176], [91.17572021, 23.58514023], [91.17517853, 23.58562851], [91.17514801, 23.58580589], [91.17507935, 23.58630371], [91.17533112, 23.58671951], [91.17648315, 23.58782387], [91.17622375, 23.58870888], [91.17607117, 23.58893776], [91.17638397, 23.58946228], [91.17694855, 23.5900135], [91.17801666, 23.59188461], [91.17704773, 23.59332657], [91.17668152, 23.59334564], [91.17491913, 23.59344864], [91.17424774, 23.59347916], [91.17224121, 23.59329605], [91.17168427, 23.59326172], [91.16914368, 23.5930233], [91.16866302, 23.59273338], [91.1673584, 23.59327126], [91.16357422, 23.59486389], [91.16272736, 23.59520912], [91.16243744, 23.59519577], [91.16249847, 23.59592247], [91.16251373, 23.59617996], [91.16251373, 23.59698105], [91.16248322, 23.59752655], [91.16240692, 23.59753036], [91.16207886, 23.59755135], [91.16208649, 23.5979538], [91.16210175, 23.59881973], [91.16329956, 23.60060883], [91.16368103, 23.60117149], [91.16207886, 23.60489273], [91.16110229, 23.6075592], [91.16047668, 23.6091671], [91.15960693, 23.61144257], [91.1604538, 23.61309624], [91.16094208, 23.61406326], [91.1606369, 23.61454773], [91.16077423, 23.61460304], [91.1607666, 23.61509705], [91.16036224, 23.61593437], [91.15934753, 23.6170826], [91.15922546, 23.61705971], [91.15907288, 23.61733818], [91.15882111, 23.61945724], [91.15847778, 23.61945152], [91.15855408, 23.62029457], [91.15844727, 23.62098885], [91.15804291, 23.62192154], [91.1580658, 23.62421799], [91.15814972, 23.62485886], [91.15830994, 23.62608719], [91.15914154, 23.62613678], [91.15865326, 23.62905312], [91.16094971, 23.63135529], [91.1596756, 23.63480568], [91.15962219, 23.63602066], [91.15913391, 23.63707733], [91.15893555, 23.64004517], [91.15897369, 23.64096642], [91.15885925, 23.64146233], [91.158638, 23.64149284], [91.15895844, 23.64200401], [91.15931702, 23.64233208], [91.15970612, 23.64337349], [91.1598587, 23.64556694], [91.15962982, 23.64570618], [91.15998077, 23.64634705], [91.16039276, 23.64759064], [91.16056824, 23.64819908], [91.16077423, 23.64816666], [91.16095734, 23.64891052], [91.1609726, 23.64990425], [91.16096497, 23.65184402], [91.16077423, 23.65181923], [91.1607666, 23.65218163], [91.16075897, 23.65246773], [91.16095734, 23.65249443], [91.16121674, 23.6540451], [91.16131592, 23.65445709], [91.16101837, 23.65506935], [91.15995026, 23.65723419], [91.15990448, 23.65743637], [91.15975189, 23.65739822], [91.15971375, 23.6584816], [91.1595459, 23.65938187], [91.15859222, 23.66256142], [91.15851593, 23.66279793], [91.15761566, 23.66523743], [91.15694427, 23.66704369], [91.15697479, 23.66712379], [91.15676117, 23.66851616], [91.15643311, 23.66930008], [91.15627289, 23.6696701], [91.15634155, 23.6704998], [91.15625763, 23.67084503], [91.157341, 23.6701889], [91.15742493, 23.67013359], [91.15748596, 23.67009354], [91.15854645, 23.66933632], [91.15943146, 23.66846085], [91.15966034, 23.66788292], [91.15992737, 23.66758919], [91.1603241, 23.66745758], [91.16052246, 23.66742325], [91.16036224, 23.66808128], [91.16127014, 23.6706028], [91.16131592, 23.67071533], [91.16330719, 23.66825676], [91.16338348, 23.66817284], [91.16491699, 23.6652832], [91.16812134, 23.66403961], [91.17163849, 23.6623497], [91.17221069, 23.66179657], [91.17230988, 23.66168785], [91.17392731, 23.65987968], [91.17543793, 23.65806007], [91.17560577, 23.65830421], [91.1756897, 23.65848541], [91.17573547, 23.65855408], [91.17578888, 23.65876007], [91.17584229, 23.65897942], [91.17583466, 23.6591568], [91.17585754, 23.65956497], [91.17601776, 23.65973473], [91.17608643, 23.65963554], [91.1761322, 23.65949631], [91.17606354, 23.65915298], [91.1760025, 23.65889549], [91.17598724, 23.65872955], [91.17597961, 23.65861511], [91.17601013, 23.6583786], [91.17604828, 23.65812302], [91.17616272, 23.65796661], [91.17626953, 23.65789795], [91.17644501, 23.65780067], [91.17657471, 23.65778732], [91.17667389, 23.65782738], [91.17701721, 23.65801811], [91.17714691, 23.65813255], [91.17725372, 23.65826607], [91.17725372, 23.65839005], [91.17731476, 23.65859413], [91.17738342, 23.65867424], [91.17770386, 23.65868568], [91.17778778, 23.65861893], [91.17786407, 23.65849113], [91.17806244, 23.65815544], [91.17816925, 23.65798187], [91.17832184, 23.65785217], [91.17845917, 23.65774727], [91.1787796, 23.65759468], [91.17925262, 23.65745735], [91.17943573, 23.65739441], [91.17971039, 23.65731049], [91.1798172, 23.65725899], [91.17996216, 23.65716553], [91.18016815, 23.65702248], [91.18035126, 23.65693283], [91.18066406, 23.65677452], [91.18083954, 23.65666962], [91.18101501, 23.65656281], [91.18125153, 23.65651131], [91.18154144, 23.65649223], [91.18173981, 23.65649986], [91.18228912, 23.65664101], [91.18264771, 23.65675545], [91.18273926, 23.65688896], [91.18278503, 23.65707779], [91.18273926, 23.65724373], [91.18260193, 23.6572876], [91.18239594, 23.65728378], [91.18217468, 23.65724945], [91.18202972, 23.65725517], [91.18193817, 23.65730667], [91.18195343, 23.65743446], [91.18205261, 23.65768814], [91.18235779, 23.6583786], [91.18244934, 23.65882301], [91.18249512, 23.65916252], [91.18247223, 23.65939331], [91.18237305, 23.65966034], [91.18239594, 23.65976715], [91.18247986, 23.65983009], [91.18276978, 23.65979576], [91.18294525, 23.65960693], [91.18300629, 23.6593914], [91.18322754, 23.65888214], [91.18326569, 23.65868568], [91.18338013, 23.65858459], [91.18367767, 23.65831947], [91.1836853, 23.65823174], [91.18382263, 23.65815926], [91.1839447, 23.65802383], [91.18408203, 23.65794563], [91.1842041, 23.65784836], [91.18427277, 23.65774727], [91.18441772, 23.65753746], [91.18451691, 23.65731812], [91.18460846, 23.65717506], [91.18490601, 23.65682983], [91.18502808, 23.65676689], [91.18512726, 23.65670395], [91.18572235, 23.65654755], [91.1868515, 23.65623665], [91.18724823, 23.65612793], [91.18825531, 23.65584946], [91.18960571, 23.65547562], [91.19117737, 23.65504456], [91.19248962, 23.65467644], [91.19288635, 23.654562], [91.19224548, 23.65237617], [91.19155884, 23.65002632], [91.19094849, 23.64791107], [91.19070435, 23.64709282], [91.19190979, 23.64673424], [91.19324493, 23.64633751], [91.19377899, 23.6461792], [91.19643402, 23.64645004], [91.1969223, 23.64649773], [91.19797516, 23.64660263], [91.19935608, 23.64674187], [91.19940186, 23.64728355], [91.19947815, 23.64816093], [91.19963837, 23.64981842], [91.20140076, 23.65006828], [91.20165253, 23.65010834], [91.20272827, 23.65026283], [91.20453644, 23.65052795], [91.20366669, 23.65200996], [91.20289612, 23.65333366], [91.20246124, 23.65405846], [91.20298767, 23.65404892], [91.2050705, 23.65405273], [91.20494843, 23.65512657], [91.20423126, 23.65530586], [91.20350647, 23.65549088], [91.20140076, 23.65609169], [91.20150757, 23.65620232], [91.20259857, 23.6573391], [91.20362854, 23.65841103], [91.20297241, 23.66077995], [91.2024765, 23.66254044], [91.20232391, 23.66303444], [91.20252991, 23.66445351], [91.20258331, 23.66487503], [91.20288849, 23.66687202], [91.20313263, 23.66850853], [91.2033844, 23.67017365], [91.20352173, 23.6710186], [91.20381927, 23.67294312], [91.20404053, 23.67439842], [91.20441437, 23.67683411], [91.20458221, 23.67784119], [91.20491028, 23.67991447], [91.20428467, 23.68003654], [91.20394135, 23.6801033], [91.20320129, 23.68024254], [91.20328522, 23.6803875], [91.20339966, 23.6805954], [91.2035141, 23.68094635], [91.20350647, 23.68103981], [91.20353699, 23.68112755], [91.20359802, 23.68128395], [91.20368195, 23.68136215], [91.20388794, 23.68153763], [91.20402527, 23.6817627], [91.20417786, 23.68188095], [91.20428467, 23.68193054], [91.20439148, 23.68208313], [91.20443726, 23.68225098], [91.20445251, 23.68234253], [91.20452881, 23.68247414], [91.20479584, 23.68251228], [91.20491028, 23.68254089], [91.20494843, 23.68264771], [91.20505524, 23.68268967], [91.20550537, 23.68261528], [91.20581818, 23.68263054], [91.20592499, 23.68270493], [91.20607758, 23.68313408], [91.20611572, 23.68322945], [91.20620728, 23.68346024], [91.20630646, 23.68366051], [91.20632172, 23.68384171], [91.2064209, 23.68419456], [91.20632935, 23.68431282], [91.20627594, 23.68445206], [91.20635223, 23.68485832], [91.20643616, 23.6849556], [91.20658112, 23.68498421], [91.20690155, 23.68496132], [91.20726776, 23.68497849], [91.20761871, 23.68502235], [91.20785522, 23.68549538], [91.20798492, 23.68582344], [91.20790863, 23.68588066], [91.20792389, 23.68606567], [91.20837402, 23.68639946], [91.20846558, 23.68657303], [91.20697784, 23.68626022], [91.20482635, 23.68582153], [91.20404053, 23.6856575], [91.20361328, 23.68556023], [91.20340729, 23.68582726], [91.2024231, 23.68711853], [91.20202637, 23.68765259], [91.19963837, 23.68933105], [91.19889832, 23.68985367], [91.19800568, 23.69048691], [91.19637299, 23.69164658], [91.1960907, 23.69184875], [91.19548035, 23.69228172], [91.19522858, 23.69195366], [91.19476318, 23.69134521], [91.19445801, 23.69093895], [91.19376373, 23.6900444], [91.19204712, 23.69000626], [91.1907196, 23.68997192], [91.18894958, 23.68993378], [91.18699646, 23.689888], [91.18521118, 23.68984604], [91.18400574, 23.68981934], [91.18237305, 23.68978119], [91.18029785, 23.68973541], [91.17951202, 23.68971634], [91.17784882, 23.68968201], [91.17733765, 23.68966484], [91.17682648, 23.68964386], [91.17610168, 23.68961334], [91.17526245, 23.68958664], [91.17463684, 23.68956947], [91.1733017, 23.68953896], [91.1726532, 23.6895256], [91.17152405, 23.6894989], [91.17034912, 23.6894722], [91.16843414, 23.68943214], [91.16611481, 23.68930054], [91.16349792, 23.68914413], [91.16100311, 23.68899727], [91.15827179, 23.68883133], [91.15689087, 23.68873405], [91.15589142, 23.68866158], [91.15507507, 23.68860054], [91.15418243, 23.6885376], [91.1539917, 23.68875122], [91.15346527, 23.68935585], [91.15344238, 23.68959618], [91.15325165, 23.69158745], [91.15312958, 23.69257927], [91.15306854, 23.69309998], [91.1529007, 23.69487953], [91.15233612, 23.69714165], [91.15209961, 23.69807243], [91.15209198, 23.6991024], [91.15206909, 23.69960785], [91.15209198, 23.70030975], [91.15209198, 23.70082474], [91.15211487, 23.70166016], [91.15196228, 23.70204163], [91.15184021, 23.70238304], [91.15180969, 23.70283699], [91.15162659, 23.70409203], [91.1516037, 23.70446777], [91.15149689, 23.70479965], [91.15156555, 23.70510483], [91.15155029, 23.70557976], [91.15071106, 23.70593262], [91.15048218, 23.7069912], [91.15026855, 23.70793343], [91.14995575, 23.70937729], [91.1498642, 23.70983124], [91.15007019, 23.71045876], [91.14963531, 23.710989], [91.14912415, 23.71166801], [91.14970398, 23.71290588], [91.15013885, 23.7138176], [91.15026093, 23.7143383], [91.15045166, 23.71514893], [91.15065765, 23.71608734], [91.15093231, 23.71735001], [91.15112305, 23.71770287], [91.1518631, 23.71907234], [91.15279388, 23.72122002], [91.15296173, 23.72296143], [91.15287018, 23.72418022], [91.1528244, 23.72471046], [91.15323639, 23.72574997], [91.15381622, 23.727211], [91.15406036, 23.72781754], [91.15483093, 23.72977638], [91.15518188, 23.73064613], [91.15499115, 23.73186493], [91.15509033, 23.73260689], [91.1559906, 23.7348156], [91.15621185, 23.73555565], [91.15615845, 23.73595238], [91.15614319, 23.73610497], [91.15628052, 23.73649406], [91.15725708, 23.73811531], [91.15729523, 23.73817825], [91.15802002, 23.7393856], [91.1574173, 23.73957825], [91.1563797, 23.73991013], [91.15665436, 23.74091148], [91.1570282, 23.74215317], [91.15847015, 23.74185181], [91.15878296, 23.74178505], [91.16014862, 23.7432766], [91.16059113, 23.74374771], [91.16085052, 23.74402046], [91.16160583, 23.74481964], [91.16175079, 23.74500465], [91.16239929, 23.74570656], [91.16285706, 23.74620247], [91.16332245, 23.74668312], [91.16358948, 23.74697685], [91.16421509, 23.74767876], [91.16500854, 23.74830246], [91.16577148, 23.74890137], [91.1661377, 23.74910927], [91.167099, 23.7495327], [91.16759491, 23.74978256], [91.16819763, 23.74979782], [91.16874695, 23.74985123], [91.16901398, 23.74983406], [91.16999817, 23.7497673], [91.17009735, 23.75004959], [91.17019653, 23.75016212], [91.17032623, 23.75024605], [91.17043304, 23.75031471], [91.17051697, 23.75036621], [91.17062378, 23.75044823], [91.17075348, 23.75050545], [91.17086029, 23.7505722], [91.17108154, 23.75068283], [91.17115784, 23.75074768], [91.17121124, 23.75082016], [91.17115021, 23.75092125], [91.17110443, 23.75099564], [91.17105865, 23.75115395], [91.17118073, 23.75123215], [91.17128754, 23.7512989], [91.17138672, 23.75136185], [91.1723938, 23.75201416], [91.17247772, 23.75200653], [91.17810059, 23.75170898], [91.18310547, 23.75128174], [91.18768311, 23.75128174], [91.18927002, 23.75170898], [91.19487, 23.75316048], [91.19549561, 23.7532959], [91.19936371, 23.7531414], [91.20007324, 23.75311279], [91.20546722, 23.75222969], [91.21038818, 23.75162125], [91.21092987, 23.75160599], [91.21429443, 23.75012207], [91.21496582, 23.74867058], [91.21583557, 23.74699402], [91.21587372, 23.7468853], [91.21708679, 23.74368095], [91.21996307, 23.74118996], [91.22052765, 23.74092484], [91.22117615, 23.74263191], [91.22183228, 23.7443409], [91.22241211, 23.74585724], [91.22323608, 23.74700165], [91.22423553, 23.74839973], [91.2253952, 23.74999809], [91.22561646, 23.75030136], [91.22599792, 23.75084496], [91.22629547, 23.75126266], [91.22625732, 23.75143433], [91.22605133, 23.75244713], [91.22595215, 23.75293159], [91.22589111, 23.75323677], [91.22579956, 23.7536602], [91.22541809, 23.75548553], [91.22516632, 23.75666809], [91.22599792, 23.75794601], [91.22637939, 23.75852966], [91.22698975, 23.75946617], [91.22763062, 23.76044846], [91.22801208, 23.76103592], [91.22834015, 23.76153564], [91.22938538, 23.76316452], [91.22990417, 23.76396179], [91.23051453, 23.76486397], [91.23064423, 23.76506042], [91.2306366, 23.76587296], [91.23062134, 23.76679993], [91.23058319, 23.76901245], [91.23053741, 23.77147293], [91.23049927, 23.77351379], [91.23046112, 23.77606201], [91.23028564, 23.77760124], [91.23006439, 23.77938271], [91.23027802, 23.78206444], [91.23044586, 23.78410721], [91.23047638, 23.78453445], [91.23029327, 23.78464317], [91.22991943, 23.78482437], [91.22888947, 23.78539467], [91.22832489, 23.78570747], [91.22865295, 23.78719139], [91.2286911, 23.7873497], [91.2286377, 23.78770256], [91.2285614, 23.78825378], [91.22846985, 23.78893471], [91.2280426, 23.78941727], [91.22709656, 23.79021263], [91.22693634, 23.79034615], [91.22679138, 23.79046822], [91.22660065, 23.79073143], [91.22637939, 23.79110336], [91.22663116, 23.79183388], [91.22711182, 23.79322624], [91.227211, 23.79334068], [91.22720337, 23.79348564], [91.22830963, 23.7952919], [91.22879028, 23.79575157], [91.22914124, 23.79609108], [91.22969818, 23.79655075], [91.23008728, 23.79686928], [91.23046112, 23.79718018], [91.23080444, 23.79744339], [91.23110962, 23.79768753], [91.23100281, 23.79822159], [91.23127747, 23.79827118], [91.23153687, 23.79831886], [91.23134613, 23.79907036], [91.23132324, 23.79917336], [91.23137665, 23.79936409], [91.23171997, 23.80057526], [91.23249054, 23.80252647], [91.2326889, 23.80317879], [91.23314667, 23.80464554], [91.23335266, 23.80533028], [91.23366547, 23.80633163], [91.2338028, 23.8067894], [91.23390961, 23.80705261], [91.23377991, 23.80725288], [91.23368835, 23.80742264], [91.23365784, 23.80759048], [91.23374939, 23.80777931], [91.23376465, 23.80788803], [91.23365784, 23.80814743], [91.23365021, 23.80832291], [91.23358154, 23.80844879], [91.23353577, 23.80864334], [91.23355103, 23.80939674], [91.23353577, 23.81004143], [91.23368835, 23.8109684], [91.23397064, 23.81097794], [91.23403931, 23.81128311], [91.23409271, 23.81154633], [91.23435974, 23.81166267], [91.23445892, 23.81172562], [91.23441315, 23.81186104], [91.23451233, 23.81193161], [91.23473358, 23.8119297], [91.23479462, 23.81205177], [91.23484802, 23.81211472], [91.23503876, 23.81227303], [91.2352829, 23.81241035], [91.23526001, 23.81248093], [91.23548126, 23.81251717], [91.23564911, 23.81251907], [91.23582458, 23.81256294], [91.23591614, 23.81263351], [91.23617554, 23.81268883], [91.23642731, 23.81295967], [91.23651886, 23.81308746], [91.23667908, 23.8131485], [91.23683167, 23.81320763], [91.23707581, 23.8135376], [91.23733521, 23.81374168], [91.23748016, 23.81373787], [91.23756409, 23.81391907], [91.23860168, 23.81573677], [91.23971558, 23.81769562], [91.24009705, 23.81835556], [91.24063873, 23.81927681], [91.24069214, 23.81937599], [91.24113464, 23.82014275], [91.24221039, 23.8219986], [91.24285889, 23.82311058], [91.24371338, 23.82427406], [91.24384308, 23.8244648], [91.2448349, 23.82582283], [91.24593353, 23.82733154], [91.24750519, 23.82949448], [91.24933624, 23.83198738], [91.25061035, 23.833395], [91.25171661, 23.83462715], [91.25260162, 23.83561516], [91.2534256, 23.83652687], [91.25399017, 23.83715439], [91.25404358, 23.83812904], [91.25325012, 23.8398056], [91.25301361, 23.84030151], [91.25289917, 23.84055328], [91.25282288, 23.84072113], [91.25266266, 23.84105301], [91.25193787, 23.84259224], [91.25135803, 23.84382057], [91.25065613, 23.84529495], [91.24985504, 23.84698868], [91.24958801, 23.84801483], [91.24932861, 23.84899902], [91.24880981, 23.85095406], [91.24834442, 23.8515892], [91.24806213, 23.85197067], [91.24710846, 23.85326576], [91.24611664, 23.85461807], [91.24520874, 23.85585785], [91.24436951, 23.85699844], [91.24339294, 23.85832405], [91.24201965, 23.86019897], [91.24129486, 23.86117935], [91.24080658, 23.86184311], [91.24049377, 23.86268616], [91.24007416, 23.8638134], [91.23918152, 23.86620522], [91.23882294, 23.86715317], [91.23851013, 23.86798096], [91.23855591, 23.8680706], [91.23847198, 23.86812973], [91.23827362, 23.87022781], [91.23819733, 23.87109375], [91.23814392, 23.87165833], [91.23808289, 23.87233734], [91.2379837, 23.87257385], [91.23784637, 23.87287521], [91.23744965, 23.87376595], [91.2366333, 23.87558365], [91.23652649, 23.87581825], [91.23571014, 23.87766075], [91.23442078, 23.87784386], [91.23377228, 23.87794113], [91.23175812, 23.87823486], [91.23133087, 23.8787117], [91.23067474, 23.8794632], [91.22970581, 23.88055611], [91.22954559, 23.88073921], [91.22943115, 23.88254166], [91.22934723, 23.88386917], [91.22924805, 23.8854599], [91.22915649, 23.88692093], [91.22905731, 23.88847542], [91.22897339, 23.8897686], [91.22885132, 23.89190292], [91.22875214, 23.89370346], [91.22866821, 23.89525986], [91.22855377, 23.89684486], [91.22849274, 23.89767075], [91.2284317, 23.89877892], [91.22881317, 23.89876938], [91.22982788, 23.89916992], [91.23000336, 23.89923859], [91.23032379, 23.89936638], [91.23100281, 23.89963341], [91.23325348, 23.90052032], [91.23530579, 23.90133286], [91.23655701, 23.90209198], [91.23738098, 23.90259361], [91.23825073, 23.90312386], [91.23986053, 23.90410614], [91.24227905, 23.90557861], [91.24459076, 23.90698051], [91.24481201, 23.90711594], [91.24490356, 23.90779877], [91.24501038, 23.90854454], [91.24515533, 23.90886497], [91.24551392, 23.91048622], [91.24594879, 23.91243935], [91.24612427, 23.91322517], [91.24613953, 23.91384697], [91.24506378, 23.9158783], [91.24406433, 23.91777992], [91.24330902, 23.9192009], [91.24137878, 23.92284584], [91.23969269, 23.9236908], [91.23779297, 23.92464638], [91.23723602, 23.92492485], [91.23628998, 23.9254055], [91.23518372, 23.92596817], [91.23391724, 23.92661095], [91.23295593, 23.92709541], [91.23387146, 23.9279995], [91.23460388, 23.92792892], [91.23472595, 23.92791748], [91.23503113, 23.92788696], [91.23560333, 23.92783165], [91.23531342, 23.92868042], [91.23651123, 23.9296875], [91.23920441, 23.92952347], [91.23950195, 23.92950439], [91.24684906, 23.92837906], [91.25183868, 23.9289875], [91.25443268, 23.92753983], [91.25708008, 23.92730713], [91.2623291, 23.92651367], [91.26727295, 23.92712402], [91.27205658, 23.92698097], [91.2724762, 23.92697334], [91.27261353, 23.92691612], [91.27270508, 23.92689896], [91.2753067, 23.9264183], [91.27467346, 23.92933273], [91.27417755, 23.93162346], [91.27371216, 23.93378639], [91.2733078, 23.9356308], [91.27293396, 23.93733025], [91.27282715, 23.93778419], [91.27188873, 23.938591], [91.27178955, 23.9386673], [91.27082825, 23.9393959], [91.26961517, 23.94030952], [91.26855469, 23.94110298], [91.2681427, 23.94140244], [91.26691437, 23.94230843], [91.26613617, 23.94288254], [91.26393127, 23.94437027], [91.26430511, 23.94515991], [91.26474762, 23.94610214], [91.26503754, 23.94671631], [91.26572418, 23.94848633], [91.26646423, 23.95039177], [91.26741791, 23.95281029], [91.26773071, 23.9535923], [91.26851654, 23.95558167], [91.2696228, 23.95833015], [91.2702179, 23.95981026], [91.27072906, 23.96114731], [91.27145386, 23.96304703], [91.27184296, 23.9636116], [91.27189636, 23.9636879], [91.27331543, 23.9666748], [91.27593231, 23.97005463], [91.27868652, 23.97387695], [91.27987671, 23.97680855], [91.27992249, 23.97692108], [91.28157806, 23.98017883], [91.28164673, 23.98030663], [91.28367615, 23.9831028], [91.28557587, 23.98309326], [91.28570557, 23.98309326], [91.28541565, 23.98196793], [91.28553772, 23.98205185], [91.28562164, 23.98205948], [91.28572083, 23.98198509], [91.28588867, 23.98195076], [91.28595734, 23.98200607], [91.28606415, 23.98215485], [91.28617096, 23.98207664], [91.28599548, 23.98184967], [91.28593445, 23.98173141], [91.28590393, 23.98153877], [91.28583527, 23.98122025], [91.28578186, 23.9809494], [91.28572845, 23.98060608], [91.28569794, 23.98045731], [91.28562164, 23.9804039], [91.28536987, 23.98035812], [91.28522491, 23.98029327], [91.28505707, 23.98009872], [91.284935, 23.97998047], [91.28488159, 23.97973824], [91.2849884, 23.97961235], [91.28510284, 23.97945404], [91.28517914, 23.97938728], [91.2852478, 23.97920609], [91.28520203, 23.97903824], [91.28507996, 23.97875786], [91.28491974, 23.97839546], [91.28479004, 23.97808075], [91.28478241, 23.97800636], [91.28462982, 23.97763062], [91.28460693, 23.97739601], [91.28469086, 23.9772892], [91.2846756, 23.97715187], [91.28477478, 23.97700691], [91.28487396, 23.97689247], [91.2851944, 23.97664452], [91.28541565, 23.9765892], [91.28554535, 23.9765625], [91.28569031, 23.97651291], [91.28581238, 23.97632217], [91.28588867, 23.97622871], [91.28598785, 23.97614098], [91.28619385, 23.97606087], [91.28636169, 23.97605515], [91.28657532, 23.9761219], [91.28662109, 23.97606468], [91.28665924, 23.97587395], [91.28656769, 23.97552872], [91.28652954, 23.97525406], [91.28650665, 23.97499466], [91.28652191, 23.97489357], [91.28656006, 23.97479439], [91.28665161, 23.97468567], [91.28676605, 23.97461891], [91.28697968, 23.97445107], [91.28701019, 23.97436714], [91.28701019, 23.97422791], [91.28700256, 23.97402], [91.287117, 23.97388268], [91.28722382, 23.97380257], [91.28739166, 23.97397232], [91.28751373, 23.97410965], [91.28751373, 23.97418404], [91.28759003, 23.97417068], [91.28765106, 23.97411728], [91.28767395, 23.97404099], [91.28761292, 23.97386551], [91.28748322, 23.97363663], [91.28739929, 23.97346497], [91.28736115, 23.97333145], [91.28731537, 23.97308159], [91.28723145, 23.97285461], [91.28707123, 23.97277451], [91.28690338, 23.97269058], [91.28672791, 23.97257042], [91.28668976, 23.97243881], [91.28672791, 23.97234344], [91.28682709, 23.97218704], [91.2869873, 23.97202682], [91.28707123, 23.97190475], [91.28712463, 23.97178268], [91.28712463, 23.9715519], [91.28717041, 23.9713192], [91.28733826, 23.9710083], [91.2875061, 23.97083855], [91.2877121, 23.97070313], [91.28791809, 23.97045517], [91.2878418, 23.97037315], [91.28765869, 23.9703083], [91.28756714, 23.97022057], [91.28751373, 23.9701252], [91.28746033, 23.96993446], [91.28734589, 23.96971703], [91.28702545, 23.96945572], [91.28699493, 23.96937752], [91.28697205, 23.96926689], [91.28697968, 23.9691906], [91.28704071, 23.96903229], [91.28716278, 23.96885681], [91.28733826, 23.96863556], [91.28736115, 23.96851921], [91.28742981, 23.96831322], [91.28760529, 23.96817207], [91.28770447, 23.96814537], [91.28778839, 23.96818161], [91.28784943, 23.96825218], [91.28790283, 23.96834564], [91.28801727, 23.96853447], [91.28817749, 23.96858788], [91.28833008, 23.96861458], [91.28857422, 23.96858978], [91.28878021, 23.96858788], [91.28897858, 23.96854782], [91.28907013, 23.96846771], [91.2893219, 23.96843338], [91.28939056, 23.96835518], [91.28948212, 23.96820068], [91.28948975, 23.96807861], [91.29057312, 23.96850204], [91.29309082, 23.96948242], [91.2942276, 23.97022057], [91.29430389, 23.9702816], [91.29594421, 23.97157097], [91.2960968, 23.97161865], [91.29946899, 23.97265053], [91.2983551, 23.97450256], [91.29810333, 23.97491837], [91.2975769, 23.97578621], [91.2974472, 23.97599792], [91.29721069, 23.97638702], [91.29801941, 23.9778614], [91.29819489, 23.97818375], [91.29849243, 23.97873497], [91.29898834, 23.97964096], [91.29973602, 23.98103333], [91.30072784, 23.9828701], [91.30075836, 23.98327446], [91.30076599, 23.98334694], [91.30101776, 23.98374176], [91.30192566, 23.98501968], [91.30230713, 23.98583984], [91.3026886, 23.98657417], [91.30342102, 23.987957], [91.30330658, 23.98801994], [91.30316162, 23.9881134], [91.30295563, 23.98883247], [91.30281067, 23.98913956], [91.3026886, 23.98924065], [91.30259705, 23.98923111], [91.30250549, 23.98922157], [91.30237579, 23.98924637], [91.30223083, 23.98936081], [91.30228424, 23.9895668], [91.30229187, 23.98970795], [91.30217743, 23.98995018], [91.30219269, 23.99023438], [91.30219269, 23.99030685], [91.30204773, 23.99064445], [91.30217743, 23.99074936], [91.30224609, 23.99082756], [91.30213928, 23.99092293], [91.30200195, 23.99096107], [91.30194855, 23.99103737], [91.30188751, 23.99114799], [91.30188751, 23.99123764], [91.30194855, 23.99141121], [91.30197906, 23.99159813], [91.30206299, 23.99176407], [91.30219269, 23.99183273], [91.30223846, 23.99196625], [91.30221558, 23.99217987], [91.30211639, 23.9924736], [91.30210876, 23.99259377], [91.30201721, 23.9928112], [91.30186462, 23.99319077], [91.30168915, 23.99330902], [91.3015976, 23.99337959], [91.30157471, 23.99348259], [91.30152893, 23.99367332], [91.30137634, 23.99377632], [91.3013382, 23.99385071], [91.30138397, 23.99394035], [91.3014679, 23.99396896], [91.30151367, 23.99412537], [91.30156708, 23.99428558], [91.30162048, 23.99445343], [91.30175018, 23.99455643], [91.30179596, 23.99462318], [91.30181885, 23.99476814], [91.30194855, 23.99489403], [91.30198669, 23.99497604], [91.30200958, 23.99508095], [91.30202484, 23.99535751], [91.30207825, 23.99551773], [91.3024826, 23.99568176], [91.3025589, 23.99575615], [91.30251312, 23.99599457], [91.30258179, 23.99604988], [91.30265808, 23.99611473], [91.30275726, 23.99614525], [91.30290222, 23.99619293], [91.30297089, 23.99629593], [91.30290985, 23.99642754], [91.302948, 23.9965744], [91.30322266, 23.99662209], [91.30342865, 23.99672127], [91.30352783, 23.9967308], [91.30358124, 23.99682808], [91.30364227, 23.99700928], [91.3034668, 23.99705315], [91.3033371, 23.99698257], [91.3032608, 23.99694443], [91.30318451, 23.99690056], [91.30304718, 23.99690247], [91.30305481, 23.99700928], [91.3031311, 23.99706841], [91.30328369, 23.99721336], [91.30325317, 23.99729729], [91.30313873, 23.99733353], [91.30337524, 23.99761009], [91.30349731, 23.99791718], [91.30357361, 23.99803734], [91.30382538, 23.99805641], [91.30394745, 23.99814034], [91.30405426, 23.99799347], [91.30399323, 23.99750519], [91.30414581, 23.99733543], [91.30420685, 23.99725342], [91.30434418, 23.99712944], [91.30458832, 23.99677086], [91.30432892, 23.99647331], [91.30445862, 23.99601173], [91.30480194, 23.9960022], [91.30492401, 23.99584007], [91.30501556, 23.995718], [91.30511475, 23.99565125], [91.30513763, 23.99539566], [91.3052597, 23.99535942], [91.30545807, 23.99555779], [91.30558014, 23.99554634], [91.30567169, 23.99541092], [91.30575562, 23.99535942], [91.30593109, 23.99526024], [91.30605316, 23.99517441], [91.30636597, 23.9952755], [91.30691528, 23.99509811], [91.30705261, 23.9949913], [91.30755615, 23.99489212], [91.30763245, 23.99484825], [91.3075943, 23.99461365], [91.30775452, 23.99457169], [91.30786133, 23.99451065], [91.30792236, 23.99428749], [91.30799866, 23.9942379], [91.30819702, 23.99421692], [91.30839539, 23.99420547], [91.30858612, 23.99415016], [91.30866241, 23.99409294], [91.308815, 23.99394035], [91.30895233, 23.99387741], [91.30909729, 23.99378777], [91.30912781, 23.99359322], [91.30921173, 23.99350929], [91.30934906, 23.99344254], [91.30945587, 23.99333382], [91.30963135, 23.99327469], [91.30970764, 23.99309731], [91.31002808, 23.99313164], [91.31022644, 23.99330711], [91.31032562, 23.99329567], [91.31025696, 23.99306107], [91.31008148, 23.992836], [91.31015015, 23.99278069], [91.31026459, 23.99279213], [91.31040192, 23.99279594], [91.31053162, 23.99271202], [91.3106308, 23.99258804], [91.3108902, 23.99250031], [91.31095123, 23.9924469], [91.31085205, 23.99231529], [91.3109436, 23.99224663], [91.31106567, 23.99217033], [91.31098938, 23.99193001], [91.31106567, 23.99185371], [91.31127167, 23.9919529], [91.31147003, 23.99192238], [91.31175232, 23.99173164], [91.31202698, 23.99179077], [91.31217194, 23.99160767], [91.31237793, 23.9915905], [91.31257629, 23.99145889], [91.31322479, 23.99128914], [91.3134079, 23.99128151], [91.31354523, 23.99121857], [91.31386566, 23.99121284], [91.31407166, 23.99127007], [91.31415558, 23.99113083], [91.31424713, 23.99120903], [91.31434631, 23.99126244], [91.31446075, 23.99114037], [91.31454468, 23.99090195], [91.31474304, 23.99068832], [91.31488037, 23.99057198], [91.31515503, 23.99064064], [91.31534576, 23.99070168], [91.31575012, 23.99069023], [91.3159256, 23.99067116], [91.31600952, 23.99067879], [91.31616974, 23.99088097], [91.31637573, 23.99076843], [91.31651306, 23.99068069], [91.31673431, 23.99069786], [91.31680298, 23.99079323], [91.3168869, 23.99085236], [91.31699371, 23.99101448], [91.31721497, 23.99143219], [91.31764221, 23.99170303], [91.31778717, 23.99193382], [91.31803131, 23.99210358], [91.31816101, 23.99221802], [91.31826019, 23.99225616], [91.31838989, 23.99235916], [91.31850433, 23.99240494], [91.31868744, 23.99254799], [91.31908417, 23.99261284], [91.31923676, 23.99283981], [91.31952667, 23.99301529], [91.31974792, 23.99311256], [91.31996918, 23.99309921], [91.32022858, 23.99326706], [91.32038116, 23.99336624], [91.32051849, 23.99368477], [91.32079315, 23.99374008], [91.32082367, 23.99391747], [91.32150269, 23.99376488], [91.3217392, 23.99380684], [91.32219696, 23.99412155], [91.32283783, 23.99431038], [91.32305908, 23.99445343], [91.32325745, 23.99446106], [91.32346344, 23.99463463], [91.32363892, 23.99461555], [91.32385254, 23.99427986], [91.32392883, 23.9942112], [91.32437897, 23.99424362], [91.32444763, 23.99412346], [91.3243866, 23.99398804], [91.324646, 23.99377251], [91.32472992, 23.99354172], [91.32520294, 23.99353218], [91.32566833, 23.99262047], [91.32574463, 23.99247551], [91.32604218, 23.99250984], [91.32616425, 23.9922123], [91.32666016, 23.99213982], [91.32682037, 23.99170494], [91.32744598, 23.99187851], [91.3279953, 23.99165535], [91.32798004, 23.99176598], [91.32820129, 23.9919796], [91.32839203, 23.99189758], [91.32859802, 23.99190903], [91.32884979, 23.99197197], [91.32904053, 23.9922123], [91.32915497, 23.99225616], [91.32931519, 23.99238777], [91.32984161, 23.99239731], [91.32998657, 23.99261665], [91.33022308, 23.99233627], [91.33036804, 23.99235916], [91.33032227, 23.99202919], [91.33073425, 23.99195671], [91.33097839, 23.99201393], [91.33119202, 23.99209595], [91.33132172, 23.99202156], [91.33135223, 23.99190712], [91.33141327, 23.99181747], [91.33135223, 23.99160767], [91.33145142, 23.99147224], [91.33153534, 23.99135208], [91.33182526, 23.99150848], [91.33191681, 23.99146461], [91.33197784, 23.99128151], [91.33224487, 23.9910717], [91.33267212, 23.99126625], [91.33275604, 23.99103928], [91.33305359, 23.99111176], [91.33334351, 23.9907074], [91.33371735, 23.99079323], [91.33374023, 23.9905777], [91.33377075, 23.99040413], [91.33388519, 23.99038506], [91.33406067, 23.99041367], [91.33413696, 23.9903717], [91.33412933, 23.99001884], [91.33395386, 23.99000168], [91.33392334, 23.98962593], [91.33426666, 23.98963737], [91.33425903, 23.98955917], [91.33424377, 23.98904419], [91.3345108, 23.9889164], [91.33475494, 23.98871803], [91.33499146, 23.98871803], [91.33503723, 23.98877716], [91.33509827, 23.98887062], [91.33521271, 23.98893356], [91.33555603, 23.98879051], [91.33557129, 23.98858643], [91.33570862, 23.98855019], [91.33578491, 23.98848534], [91.33570862, 23.9883194], [91.33560944, 23.9881649], [91.33567047, 23.98798943], [91.33579254, 23.98793221], [91.3359375, 23.98770714], [91.33609009, 23.98767471], [91.33623505, 23.98724365], [91.33640289, 23.98711586], [91.33644867, 23.98701286], [91.33628845, 23.98674965], [91.3363266, 23.98651695], [91.33653259, 23.98657417], [91.33669281, 23.98650169], [91.33705902, 23.98638153], [91.33692169, 23.98615265], [91.33686829, 23.98607063], [91.33687592, 23.98587418], [91.33689117, 23.98563957], [91.33705139, 23.98527527], [91.33721924, 23.9847374], [91.33734894, 23.98456955], [91.33757782, 23.98452759], [91.33778381, 23.98458481], [91.33791351, 23.98441315], [91.33816528, 23.98443794], [91.33837891, 23.98431778], [91.33855438, 23.98441124], [91.33879089, 23.98436546], [91.33896637, 23.984375], [91.33912659, 23.98433495], [91.33937836, 23.98408699], [91.33934021, 23.98384666], [91.33940887, 23.98378181], [91.33959198, 23.98373985], [91.33957672, 23.98348427], [91.33956146, 23.98329544], [91.33970642, 23.98311615], [91.33988953, 23.9829464], [91.34008026, 23.98284531], [91.34028625, 23.98273277], [91.34043884, 23.98260117], [91.34050751, 23.98241997], [91.34056854, 23.9822464], [91.34082031, 23.98219681], [91.34116364, 23.98212624], [91.34140778, 23.98225403], [91.34159088, 23.98229408], [91.34174347, 23.98229599], [91.34211731, 23.98241234], [91.34226227, 23.98267174], [91.3423996, 23.9827404], [91.34266663, 23.98275566], [91.34281921, 23.98313332], [91.34290314, 23.98318863], [91.34315491, 23.9831295], [91.34377289, 23.98300934], [91.34413147, 23.98292923], [91.34446716, 23.9828701], [91.34455872, 23.98289108], [91.34498596, 23.98332405], [91.34555054, 23.9831562], [91.34567261, 23.98333359], [91.34599304, 23.98378754], [91.34630585, 23.98377037], [91.3465271, 23.98397446], [91.34687042, 23.98410797], [91.34720612, 23.98433304], [91.34746552, 23.98434258], [91.34777069, 23.98409081], [91.34803009, 23.98410225], [91.34873962, 23.98396492], [91.34914398, 23.9838047], [91.34940338, 23.98374557], [91.3496933, 23.98357964], [91.34994507, 23.98337555], [91.34985352, 23.98316574], [91.34992981, 23.98307991], [91.35009003, 23.98310471], [91.35017395, 23.98306656], [91.35025787, 23.98299217], [91.35025787, 23.98277473], [91.35050201, 23.98281288], [91.35064697, 23.98265839], [91.35080719, 23.98264694], [91.35084534, 23.98270798], [91.35152435, 23.98264122], [91.35169983, 23.98269272], [91.35189819, 23.98258781], [91.35194397, 23.98246765], [91.352211, 23.98241425], [91.35250092, 23.98233032], [91.35266113, 23.9822197], [91.3527298, 23.98186684], [91.35300446, 23.98200607], [91.35321045, 23.98209], [91.35335541, 23.98221207], [91.35355377, 23.9822731], [91.35373688, 23.9823761], [91.35404205, 23.982584], [91.3540802, 23.98283386], [91.35428619, 23.9829216], [91.35424042, 23.98316002], [91.3543396, 23.98329163], [91.35494232, 23.98357773], [91.35502625, 23.9837265], [91.35590363, 23.98408127], [91.35636139, 23.98415565], [91.35726929, 23.98407745], [91.35873413, 23.98441696], [91.35905457, 23.98548508], [91.36022949, 23.986063], [91.36100006, 23.98625565], [91.3615799, 23.9863987], [91.36245728, 23.98551559], [91.36276245, 23.98529053], [91.36380768, 23.98469925], [91.36412811, 23.98451614], [91.36580658, 23.98356819], [91.36975098, 23.98079109], [91.3704834, 23.98028564], [91.37310791, 23.97851563], [91.37548828, 23.97747803], [91.37823486, 23.97695732], [91.37902832, 23.9786911], [91.3789978, 23.97885704], [91.37892914, 23.9792347], [91.37944794, 23.97909927], [91.3795929, 23.97915649], [91.37944794, 23.97939301], [91.3793335, 23.97948837], [91.37911224, 23.97966957], [91.37900543, 23.97975922], [91.37905121, 23.98018456], [91.37876892, 23.9801178], [91.37859344, 23.97991562], [91.37836456, 23.97986603], [91.37830353, 23.97998238], [91.37831116, 23.98021698], [91.37826538, 23.98028374], [91.37789917, 23.98006821], [91.37767792, 23.98005676], [91.37768555, 23.98026466], [91.37846375, 23.98097038], [91.37862396, 23.98088646], [91.37830353, 23.98263741], [91.37815094, 23.98274231], [91.37798309, 23.98285294], [91.3779068, 23.98287964], [91.37776947, 23.98288345], [91.3775177, 23.98288536], [91.37732697, 23.9827919], [91.37727356, 23.98297882], [91.37736511, 23.98311043], [91.37745667, 23.98324585], [91.3775177, 23.98346519], [91.37723541, 23.98354721], [91.37715149, 23.98357201], [91.37718201, 23.98369408], [91.37727356, 23.98403168], [91.37717438, 23.98420525], [91.37710571, 23.98432732], [91.37726593, 23.9845829], [91.37766266, 23.98467255], [91.3777771, 23.98477554], [91.37785339, 23.98495293], [91.37776947, 23.98525047], [91.37767792, 23.98553467], [91.37743378, 23.98544502], [91.37739563, 23.98534775], [91.37747192, 23.98504066], [91.37741089, 23.98496056], [91.37725067, 23.98498726], [91.37714386, 23.98509598], [91.37709045, 23.98524284], [91.37706757, 23.98568535], [91.37696075, 23.9857502], [91.37673187, 23.98584366], [91.37661743, 23.98598099], [91.37657928, 23.98622704], [91.3765564, 23.98661613], [91.37613678, 23.98680878], [91.37617493, 23.98693848], [91.37619019, 23.98701096], [91.37640381, 23.98728943], [91.37664795, 23.98745728], [91.37676239, 23.98753548], [91.37683868, 23.9876461], [91.37665558, 23.98796272], [91.37647247, 23.98827362], [91.37651062, 23.98844337], [91.37660217, 23.98843002], [91.37703705, 23.98814774], [91.37689209, 23.9901123], [91.37690735, 23.99027634], [91.37660217, 23.99018288], [91.37664795, 23.99047661], [91.37666321, 23.99059105], [91.37670898, 23.99072266], [91.37695312, 23.99086761], [91.37714386, 23.99332047], [91.37705231, 23.99332809], [91.37691498, 23.99325371], [91.37684631, 23.99315834], [91.37657928, 23.99279404], [91.37638855, 23.99292564], [91.37625122, 23.99315262], [91.3762207, 23.9934082], [91.37627411, 23.99349213], [91.37646484, 23.99375534], [91.37639618, 23.99383926], [91.37612152, 23.99390411], [91.37562561, 23.99383354], [91.37523651, 23.9937706], [91.37506866, 23.9938755], [91.37494659, 23.9939537], [91.37502289, 23.99411392], [91.37504578, 23.99431992], [91.37503815, 23.99447441], [91.37493896, 23.99472427], [91.37461853, 23.99489403], [91.37438965, 23.99501228], [91.37417603, 23.99510384], [91.37418365, 23.99531746], [91.37428284, 23.99543381], [91.37453461, 23.99552345], [91.37526703, 23.99558067], [91.37542725, 23.99551392], [91.37585449, 23.99519348], [91.3761673, 23.99529076], [91.37622833, 23.99543381], [91.37611389, 23.99565506], [91.37605286, 23.99576569], [91.37599182, 23.99595261], [91.37508392, 23.99669456], [91.37506866, 23.99654388], [91.37520599, 23.99645042], [91.37527466, 23.99640083], [91.37532043, 23.99624825], [91.37537384, 23.9961586], [91.37521362, 23.99611092], [91.3751297, 23.99609566], [91.37495422, 23.99606133], [91.37471771, 23.99622345], [91.37465668, 23.99650574], [91.37463379, 23.99660873], [91.3748703, 23.99687195], [91.37432861, 23.99731445], [91.37418365, 23.99732208], [91.37387848, 23.99747086], [91.37369537, 23.99776649], [91.37373352, 23.99825478], [91.37375641, 23.99855042], [91.37376404, 23.9987011], [91.37413788, 23.99894142], [91.37451172, 23.99920273], [91.37464905, 23.99918175], [91.37493896, 23.99900818], [91.37503052, 23.99892807], [91.37512207, 23.99925232], [91.37516785, 23.99941063], [91.37509155, 23.99971962], [91.37483978, 24.00003624], [91.37454224, 24.00029182], [91.37427521, 24.0004921], [91.37393188, 24.00075722], [91.373909, 24.00092888], [91.37388611, 24.00109863], [91.37391663, 24.00151253], [91.37413025, 24.00181198], [91.3742981, 24.00189209], [91.3744812, 24.00197983], [91.37475586, 24.0020237], [91.37492371, 24.00214386], [91.37490082, 24.00231743], [91.37467957, 24.00246048], [91.37428284, 24.00253868], [91.37397766, 24.00244904], [91.3733902, 24.00228119], [91.37329102, 24.00237465], [91.37326813, 24.00257111], [91.37325287, 24.0028038], [91.37358093, 24.0032692], [91.37404633, 24.00354385], [91.37421417, 24.00364304], [91.37435913, 24.00384521], [91.37432098, 24.00393677], [91.37409973, 24.00438118], [91.3742218, 24.00445366], [91.37590027, 24.00663376], [91.37771606, 24.0089817], [91.37949371, 24.01128578], [91.38126373, 24.01356697], [91.38306427, 24.01589203], [91.38485718, 24.01820946], [91.38618469, 24.01993179], [91.38686371, 24.02080917], [91.38729858, 24.02138138], [91.38756561, 24.02171707], [91.38923645, 24.02388382], [91.39080811, 24.02591133], [91.39074707, 24.02791405], [91.39109039, 24.02878761], [91.39148712, 24.02981949], [91.3941803, 24.03678894], [91.3948822, 24.03858566], [91.39567566, 24.04064178], [91.39638519, 24.04247093], [91.39639282, 24.04301453], [91.3964386, 24.04532242], [91.396492, 24.04785919], [91.39649963, 24.04833794], [91.39653778, 24.04975319], [91.39628601, 24.05014229], [91.39488983, 24.05231094], [91.39321136, 24.05491257], [91.39207458, 24.05669403], [91.39060211, 24.05897713], [91.389534, 24.06064034], [91.3883667, 24.06245232], [91.38722229, 24.06423187], [91.38552856, 24.06685638], [91.38471985, 24.0681076], [91.38350677, 24.06999969], [91.3822937, 24.07187843], [91.38137817, 24.07330894], [91.38098907, 24.07391357], [91.37966156, 24.07596397], [91.37849426, 24.0778923], [91.37841797, 24.07802391], [91.37759399, 24.07918167], [91.37723541, 24.07974052], [91.3770752, 24.07999229], [91.3769455, 24.08118629], [91.37683105, 24.08232117], [91.37656403, 24.08484077], [91.37631226, 24.08721542], [91.37605286, 24.08971977], [91.37593079, 24.0908432], [91.37591553, 24.09101677], [91.37590027, 24.09112358], [91.37587738, 24.09134674], [91.37582397, 24.09189034], [91.37581635, 24.09197617], [91.37578583, 24.09220314], [91.3757782, 24.09231186], [91.3755188, 24.09478188], [91.37532043, 24.09667778], [91.37500763, 24.09964943], [91.3747406, 24.10218811], [91.37452698, 24.10417938], [91.37439728, 24.10538101], [91.37434387, 24.10593414], [91.37432098, 24.10613632], [91.3744812, 24.10743523], [91.37453461, 24.10789871], [91.37481689, 24.10760307], [91.37490082, 24.10752678], [91.37528992, 24.10728264], [91.37547302, 24.10724258], [91.37548828, 24.10748291], [91.37802124, 24.10950089], [91.38356018, 24.1089592], [91.3844986, 24.10888672], [91.3862915, 24.10888672], [91.38769531, 24.10931396], [91.38941193, 24.10988617], [91.38952637, 24.10988426], [91.39161682, 24.10985947], [91.39170837, 24.10985565], [91.39489746, 24.10931396], [91.39618683, 24.10923576], [91.39665985, 24.10935593], [91.39694977, 24.109478], [91.39750671, 24.10970879], [91.39772034, 24.10967064], [91.3980484, 24.10961342], [91.39819336, 24.10968399], [91.39850616, 24.10984039], [91.39910889, 24.11035347], [91.39930725, 24.11052513], [91.39989471, 24.11125183], [91.40013123, 24.1114769], [91.40111542, 24.11156845], [91.40146637, 24.11160278], [91.40109253, 24.11100388], [91.40106201, 24.1108532], [91.40106964, 24.11076736], [91.40131378, 24.10976219], [91.40200043, 24.10952377], [91.40226746, 24.10957718], [91.40287781, 24.10953712], [91.40294647, 24.10949516], [91.40306854, 24.10942078], [91.40373993, 24.10920715], [91.4043808, 24.1092453], [91.40493011, 24.10928726], [91.40565491, 24.10934448], [91.40650177, 24.10940552], [91.40670776, 24.10941887], [91.40745544, 24.1094017], [91.40843201, 24.10932732], [91.40894318, 24.10936546], [91.40974426, 24.10938835], [91.41007996, 24.10951996], [91.41030884, 24.10970879], [91.41067505, 24.11000633], [91.41085815, 24.11010361], [91.411026, 24.11013985], [91.41249847, 24.11008453], [91.41372681, 24.10986328], [91.41437531, 24.10968018], [91.41521454, 24.10928535], [91.41624451, 24.10880852], [91.41668701, 24.10857391], [91.41677856, 24.10852242], [91.41714478, 24.10831451], [91.41770172, 24.10844231], [91.41822815, 24.10856438], [91.41848755, 24.1086216], [91.41883087, 24.10864639], [91.41914368, 24.10866928], [91.41975403, 24.10860062], [91.42015076, 24.10855865], [91.420578, 24.10845947], [91.42094421, 24.10837555], [91.42223358, 24.10796547], [91.42354584, 24.10755157], [91.42511749, 24.10738373], [91.42557526, 24.10703087], [91.42571259, 24.10795021], [91.42645264, 24.10796356], [91.42654419, 24.10796547], [91.42694092, 24.10814095], [91.42717743, 24.10824394], [91.42749786, 24.10844231], [91.42778778, 24.10853958], [91.42805481, 24.10858727], [91.42835999, 24.10848236], [91.42856598, 24.10835266], [91.4286499, 24.10817337], [91.42858124, 24.10797501], [91.4288559, 24.10792732], [91.42894745, 24.10790062], [91.42905426, 24.10787964], [91.43049622, 24.10758591], [91.43083954, 24.10424042], [91.43187714, 24.10210991], [91.4319458, 24.10208702], [91.43370056, 24.10148048], [91.4337616, 24.10159492], [91.43424225, 24.10156631], [91.4343338, 24.10126114], [91.43440247, 24.10103226], [91.43444061, 24.10095596], [91.43453979, 24.10093117], [91.43477631, 24.10095024], [91.43506622, 24.10096931], [91.43539429, 24.10111809], [91.43572998, 24.10131264], [91.436409, 24.10193825], [91.43677521, 24.10245132], [91.43694305, 24.10266304], [91.43711853, 24.10283089], [91.4372406, 24.10287094], [91.43779755, 24.10281372], [91.43796539, 24.10272217], [91.43873596, 24.10314941], [91.4405365, 24.10309219], [91.44067383, 24.10308838], [91.44207764, 24.10089111], [91.44412231, 24.09796906], [91.44425964, 24.09800529], [91.44432831, 24.0983429], [91.44445038, 24.09853363], [91.44483185, 24.0987339], [91.44506073, 24.09888458], [91.44541168, 24.09913254], [91.44585419, 24.09911346], [91.44642639, 24.09941483], [91.44662476, 24.0993309], [91.44680023, 24.09939957], [91.44660187, 24.09965897], [91.44681549, 24.09976387], [91.44691467, 24.09974861], [91.44701385, 24.09960365], [91.44706726, 24.09949684], [91.44750214, 24.09944916], [91.4477005, 24.09955978], [91.44779205, 24.09953499], [91.4479599, 24.09968376], [91.44760132, 24.09976768], [91.44762421, 24.09991264], [91.44749451, 24.10003853], [91.44744873, 24.10013199], [91.44781494, 24.10023689], [91.44816589, 24.10042381], [91.44815063, 24.10076141], [91.44832611, 24.1008625], [91.44848633, 24.10046577], [91.44856262, 24.10057068], [91.4486618, 24.1008358], [91.44878387, 24.10087204], [91.44883728, 24.1007328], [91.44895172, 24.10074615], [91.44904327, 24.10085106], [91.44918823, 24.10070229], [91.44924927, 24.10085869], [91.44950867, 24.10105324], [91.44934082, 24.10110283], [91.44944, 24.10156441], [91.44953918, 24.10159492], [91.44978333, 24.10129738], [91.4496994, 24.10120583], [91.44985962, 24.10099411], [91.4499054, 24.1012001], [91.45019531, 24.10114288], [91.45027924, 24.10132027], [91.45036316, 24.10130882], [91.45043182, 24.10121536], [91.45083618, 24.10123253], [91.45072937, 24.10097885], [91.45095062, 24.10097694], [91.4509201, 24.10082436], [91.45087433, 24.1006794], [91.45111847, 24.10064697], [91.45114899, 24.10046768], [91.45088959, 24.100317], [91.45089722, 24.10024071], [91.45118713, 24.10006332], [91.4512558, 24.09994698], [91.45120239, 24.09983063], [91.45110321, 24.09962082], [91.45155334, 24.09970474], [91.45197296, 24.09945297], [91.45191193, 24.09931183], [91.45189667, 24.09920502], [91.45178986, 24.09898376], [91.45211029, 24.09869766], [91.45199585, 24.09840584], [91.45240021, 24.09826469], [91.4525528, 24.09820557], [91.4528656, 24.09831047], [91.45315552, 24.09845161], [91.4532547, 24.09838486], [91.45322418, 24.09814644], [91.45343781, 24.09814262], [91.45363617, 24.09803772], [91.45346832, 24.09850121], [91.45346832, 24.09863091], [91.45360565, 24.09870338], [91.45379639, 24.09868813], [91.45388794, 24.09871292], [91.45399475, 24.09876251], [91.45420074, 24.09878922], [91.4552002, 24.09803009], [91.45532227, 24.09803009], [91.45794678, 24.09804916], [91.46125793, 24.09810066], [91.46383667, 24.0975914], [91.46387482, 24.09765434], [91.46394348, 24.09770012], [91.46412659, 24.09799576], [91.4642868, 24.09810257], [91.4648056, 24.09845352], [91.46540833, 24.09877205], [91.46579742, 24.09883308], [91.46594238, 24.09889603], [91.46726227, 24.09921837], [91.46798706, 24.09935379], [91.46833038, 24.09938622], [91.46846008, 24.09935188], [91.46881104, 24.09926033], [91.46923828, 24.09912682], [91.46970367, 24.09897423], [91.46993256, 24.09889984], [91.47055817, 24.09878922], [91.47065735, 24.09880829], [91.47084808, 24.09884453], [91.47122955, 24.09892464], [91.47163391, 24.09916878], [91.47187042, 24.09979057], [91.47195435, 24.09993935], [91.47262573, 24.10108757], [91.47310638, 24.10190773], [91.47315979, 24.10185051], [91.47335815, 24.10171318], [91.47364807, 24.1016655], [91.4731369, 24.10084534], [91.4730835, 24.10060692], [91.47304535, 24.10046387], [91.47335815, 24.10007477], [91.47351074, 24.10008621], [91.47364044, 24.10008621], [91.47375488, 24.10008621], [91.47389221, 24.10008812], [91.47396851, 24.10008812], [91.47441101, 24.10009193], [91.47451019, 24.10022926], [91.47486115, 24.10034561], [91.4750061, 24.10024071], [91.47515106, 24.10051918], [91.47544098, 24.1004467], [91.47575378, 24.10065842], [91.47580719, 24.10050583], [91.47606659, 24.10051346], [91.47612762, 24.10005569], [91.47618103, 24.09978294], [91.47634888, 24.09982109], [91.47628784, 24.0995636], [91.47670746, 24.09926796], [91.47678375, 24.09921265], [91.47789001, 24.09843445], [91.47807312, 24.09830856], [91.47814178, 24.0982151], [91.47821045, 24.09817314], [91.47870636, 24.09807777], [91.47935486, 24.09816933], [91.47962952, 24.09820557], [91.48021698, 24.09828186], [91.48047638, 24.09830666], [91.48060608, 24.09832573], [91.48087311, 24.09824371], [91.48120117, 24.09810066], [91.48149872, 24.09805298], [91.48175812, 24.0981617], [91.48195648, 24.0979805], [91.48280334, 24.09796906], [91.48284149, 24.09783363], [91.48307037, 24.09765434], [91.48348999, 24.09759903], [91.48329926, 24.09716606], [91.4834137, 24.09686661], [91.4835968, 24.09665871], [91.48368835, 24.09653282], [91.48421478, 24.09658051], [91.48491669, 24.09655762], [91.48511505, 24.09647751], [91.48592377, 24.09614563], [91.48671722, 24.09600639], [91.48730469, 24.09583473], [91.48727417, 24.09546471], [91.4872818, 24.09539223], [91.48735809, 24.09539032], [91.48755646, 24.09560585], [91.48789215, 24.09556007], [91.48847198, 24.09583664], [91.48884583, 24.09559059], [91.48903656, 24.09557724], [91.48919678, 24.09566116], [91.48900604, 24.09586906], [91.48934937, 24.09611893], [91.48973846, 24.09629631], [91.49048615, 24.09634399], [91.49137115, 24.09652519], [91.49127197, 24.09679985], [91.49155426, 24.09708786], [91.49168396, 24.09722137], [91.49211121, 24.09718513], [91.49267578, 24.09684753], [91.49329376, 24.09650993], [91.49356079, 24.09636688], [91.49493408, 24.09564972], [91.49462128, 24.0950489], [91.49443817, 24.09467888], [91.49375916, 24.09353065], [91.49328613, 24.09262466], [91.49308777, 24.09224319], [91.49339294, 24.09057808], [91.49407196, 24.09026337], [91.49460602, 24.09001541], [91.49542999, 24.08951187], [91.49588013, 24.0891819], [91.49647522, 24.08873749], [91.4966507, 24.08860397], [91.49757385, 24.08743477], [91.50019836, 24.08726501], [91.50205231, 24.08703232], [91.50289154, 24.08717537], [91.5040741, 24.08712769], [91.50465393, 24.0871067], [91.50582123, 24.08707047], [91.50636292, 24.08700752], [91.50740814, 24.08667946], [91.50856781, 24.08657837], [91.50982666, 24.08618546], [91.51236725, 24.08539581], [91.51315308, 24.08516312], [91.51462555, 24.08475876], [91.51557159, 24.08444977], [91.51642609, 24.08412552], [91.51754761, 24.08370018], [91.51821899, 24.08348465], [91.52057648, 24.08273315], [91.52337646, 24.08181], [91.5253067, 24.08126068], [91.52758026, 24.08054161], [91.52881622, 24.08010101], [91.5297699, 24.07988358], [91.53079224, 24.0795536], [91.53369904, 24.07878494], [91.53488159, 24.07836533], [91.53659821, 24.07785416], [91.53879547, 24.07680321], [91.54039001, 24.07627678], [91.54087067, 24.0762043], [91.54167938, 24.07608986], [91.54283142, 24.07612038], [91.54332733, 24.07613182], [91.54415894, 24.07607651], [91.54473114, 24.07579231], [91.54503632, 24.07486916], [91.54521179, 24.07434464], [91.54563904, 24.07444], [91.54817963, 24.07499695], [91.5484848, 24.07506371], [91.54844666, 24.07520485], [91.54869843, 24.07550049], [91.54896545, 24.07584381], [91.54908752, 24.07601738], [91.54919434, 24.07612991], [91.54922485, 24.07625198], [91.54914093, 24.07635689], [91.54904938, 24.07647133], [91.54891205, 24.07659149], [91.54884338, 24.07666397], [91.54872894, 24.07684517], [91.54870605, 24.07696724], [91.54872894, 24.07707787], [91.5488205, 24.07720184], [91.54888916, 24.07733345], [91.5489502, 24.07747269], [91.54898071, 24.07759666], [91.54901886, 24.07769394], [91.54908752, 24.07782745], [91.54917908, 24.07795334], [91.55072021, 24.07786751], [91.55310059, 24.07657242], [91.55508423, 24.07650948], [91.55518341, 24.07653046], [91.55713654, 24.07849121], [91.55977631, 24.07891083], [91.56352234, 24.0785408], [91.56764221, 24.07834053], [91.57126617, 24.07837105], [91.57198334, 24.07864952], [91.57280731, 24.07897377], [91.57291412, 24.07924652], [91.57324219, 24.07923889], [91.57339478, 24.07920456], [91.57369232, 24.07932091], [91.57377625, 24.07935905], [91.57398987, 24.07937241], [91.57378387, 24.0798378], [91.57403564, 24.0799675], [91.57414246, 24.08009148], [91.57440186, 24.08014679], [91.57524109, 24.07958984], [91.57640076, 24.07979012], [91.57872009, 24.07977295], [91.58103943, 24.07853127], [91.58460999, 24.07611084], [91.58747864, 24.07695007], [91.58841705, 24.07723045], [91.59220123, 24.07883263], [91.59251404, 24.07914162], [91.59287262, 24.07956505], [91.59311676, 24.08001518], [91.59334564, 24.08065605], [91.59340668, 24.08115387], [91.59362793, 24.08225441], [91.59384155, 24.08279419], [91.59400177, 24.08300018], [91.59431458, 24.08314514], [91.59487152, 24.08328629], [91.5954895, 24.08332825], [91.5957489, 24.08330917], [91.59620667, 24.08332634], [91.59649658, 24.08333588], [91.59732056, 24.0834198], [91.59777832, 24.08368492], [91.59807587, 24.08402634], [91.59843445, 24.08460617], [91.59856415, 24.08541298], [91.59860992, 24.08572006], [91.59863281, 24.08617783], [91.59864044, 24.08635521], [91.59848022, 24.08664131], [91.59838104, 24.08677673], [91.59806061, 24.08699989], [91.59751129, 24.08724403], [91.59658813, 24.08751106], [91.59609985, 24.08774376], [91.59539032, 24.08826828], [91.59474182, 24.08867645], [91.5940094, 24.08891106], [91.59355164, 24.08906174], [91.59296417, 24.08933258], [91.59281921, 24.08960533], [91.5925293, 24.09039116], [91.59239197, 24.09070206], [91.59223938, 24.09125328], [91.59194183, 24.09165573], [91.59121704, 24.09275818], [91.59108734, 24.09313774], [91.59121704, 24.09340858], [91.59169006, 24.09368134], [91.59228516, 24.09360504], [91.59276581, 24.09329033], [91.59337616, 24.0929966], [91.59365845, 24.09293556], [91.59382629, 24.09288788], [91.59438324, 24.09296227], [91.59451294, 24.09300804], [91.59474182, 24.09309387], [91.5942688, 24.09469032], [91.59564972, 24.09558678], [91.59535217, 24.09598351], [91.5944519, 24.09665298], [91.59484863, 24.09676361], [91.59512329, 24.09684753], [91.59562683, 24.0970974], [91.59584808, 24.09712601], [91.59617615, 24.09662056], [91.59660339, 24.09648323], [91.59679413, 24.09632683], [91.59709167, 24.09608078], [91.59727478, 24.09599113], [91.59799957, 24.09616852], [91.59835052, 24.09630203], [91.59802246, 24.09658623], [91.5980072, 24.09675026], [91.59812164, 24.09682655], [91.59845734, 24.09693146], [91.59872437, 24.09712601], [91.5991745, 24.09724426], [91.59915924, 24.09686089], [91.5993042, 24.09672928], [91.59928131, 24.09640121], [91.59971619, 24.09646416], [91.59992981, 24.09636307], [91.60014343, 24.09620285], [91.60060883, 24.09606934], [91.60012054, 24.09570503], [91.6000824, 24.09555244], [91.60028076, 24.09544754], [91.60055542, 24.09551811], [91.60095215, 24.09568787], [91.6018219, 24.09576035], [91.60198975, 24.09608078], [91.60169983, 24.09642601], [91.60186768, 24.096632], [91.6020813, 24.09680367], [91.60253143, 24.09674454], [91.60303497, 24.09648514], [91.60276794, 24.09646606], [91.60246277, 24.09632492], [91.6023941, 24.09604073], [91.60250854, 24.095644], [91.60266876, 24.09552574], [91.60282135, 24.09547424], [91.60302734, 24.09560585], [91.60330963, 24.09559631], [91.60352325, 24.09565544], [91.60390472, 24.09614372], [91.60404205, 24.09621811], [91.60422516, 24.09618378], [91.60446167, 24.09591866], [91.60453796, 24.09564018], [91.60396576, 24.09524345], [91.60389709, 24.09513283], [91.60375214, 24.09489059], [91.60357666, 24.09465981], [91.60346985, 24.09455109], [91.60342407, 24.09432411], [91.603508, 24.0942173], [91.60371399, 24.09420395], [91.60392761, 24.09425926], [91.60431671, 24.09404564], [91.6044693, 24.09404564], [91.60463715, 24.09429932], [91.60479736, 24.09453583], [91.60497284, 24.09452248], [91.60508728, 24.09448051], [91.60525513, 24.09444618], [91.60547638, 24.09439659], [91.60564423, 24.09426498], [91.60552979, 24.0939827], [91.6055603, 24.09387398], [91.60552216, 24.09374046], [91.60543823, 24.09347916], [91.60547638, 24.09341621], [91.60562134, 24.09343147], [91.60584259, 24.09348297], [91.60579681, 24.09339523], [91.60581207, 24.09329224], [91.60590363, 24.0932579], [91.60607147, 24.09326363], [91.6062088, 24.09348869], [91.60638428, 24.09345245], [91.60646057, 24.093256], [91.60643768, 24.0929718], [91.60648346, 24.09288406], [91.60669708, 24.09298706], [91.60694885, 24.09313583], [91.60726929, 24.09331703], [91.60732269, 24.09347534], [91.60728455, 24.09368896], [91.60752869, 24.09378433], [91.60803223, 24.09342384], [91.60835266, 24.09311104], [91.60858154, 24.09288597], [91.60865784, 24.09275246], [91.60868073, 24.09248734], [91.6087265, 24.09227371], [91.60879517, 24.09220123], [91.60884857, 24.09214783], [91.6089859, 24.09216118], [91.60903168, 24.09231186], [91.60917664, 24.09280205], [91.60931396, 24.09299088], [91.60943604, 24.09291077], [91.60966492, 24.09280968], [91.6100769, 24.09273148], [91.61051178, 24.09267235], [91.61116791, 24.09246635], [91.61126709, 24.09230232], [91.61122894, 24.09206581], [91.61086273, 24.09197235], [91.6105957, 24.09189415], [91.61057281, 24.09181213], [91.61096191, 24.09179878], [91.61119843, 24.09181595], [91.61146545, 24.09196472], [91.61148071, 24.0921402], [91.61138153, 24.09268379], [91.61174774, 24.09316635], [91.61190033, 24.09328842], [91.61220551, 24.09316826], [91.61251068, 24.09319305], [91.61277008, 24.09314537], [91.61315155, 24.09309006], [91.61356354, 24.09297752], [91.61375427, 24.09292603], [91.61392975, 24.09302521], [91.61411285, 24.0933075], [91.61408234, 24.09366608], [91.61392975, 24.09404564], [91.61390686, 24.0943737], [91.61396027, 24.09459496], [91.61403656, 24.09458923], [91.61429596, 24.09462357], [91.61444092, 24.09472847], [91.61463165, 24.09487152], [91.61480713, 24.09430313], [91.61496735, 24.0941925], [91.61510468, 24.09432602], [91.61518097, 24.09459496], [91.61516571, 24.0951004], [91.615242, 24.09527779], [91.61566925, 24.09557724], [91.61582184, 24.09556198], [91.61579132, 24.09547234], [91.61567688, 24.09515953], [91.61569214, 24.09501457], [91.61608124, 24.09468651], [91.61660004, 24.09451103], [91.61693573, 24.09439468], [91.61714935, 24.0944519], [91.61722565, 24.09462357], [91.61725616, 24.09487724], [91.61701965, 24.09488106], [91.61681366, 24.09498978], [91.61678314, 24.09526062], [91.61710358, 24.09549713], [91.61762238, 24.09564209], [91.61785126, 24.09575272], [91.61811829, 24.09536552], [91.61843872, 24.09511185], [91.61857605, 24.09512329], [91.61855316, 24.09538651], [91.6186676, 24.09568024], [91.61860657, 24.09598923], [91.61865997, 24.09611893], [91.61888885, 24.09615707], [91.61915588, 24.0960865], [91.61935425, 24.09600449], [91.61949921, 24.09600067], [91.61955261, 24.09606361], [91.61927795, 24.09625626], [91.6193161, 24.09645653], [91.61949921, 24.09659004], [91.61972809, 24.09683037], [91.61985779, 24.0967865], [91.62005615, 24.09667969], [91.62049103, 24.09645844], [91.62084198, 24.09654617], [91.62091064, 24.09658432], [91.62094879, 24.09649467], [91.62093353, 24.09610176], [91.62116241, 24.09576225], [91.62137604, 24.09539413], [91.62146759, 24.09541512], [91.62162781, 24.09562874], [91.62189484, 24.09587669], [91.62191772, 24.09594917], [91.62195587, 24.09614372], [91.62177277, 24.09634399], [91.62186432, 24.09656715], [91.62237549, 24.09664726], [91.62277985, 24.09673309], [91.62271118, 24.09691048], [91.62254333, 24.09710312], [91.62252808, 24.09729195], [91.62256622, 24.09737015], [91.62271881, 24.09744263], [91.62516022, 24.09859467], [91.6257019, 24.09880066], [91.62579346, 24.09883308], [91.62561035, 24.09904671], [91.62554932, 24.09916878], [91.62570953, 24.09943199], [91.62587738, 24.09955215], [91.62611389, 24.09955215], [91.62622833, 24.09937096], [91.62632751, 24.09902573], [91.62698364, 24.09926224], [91.62702179, 24.0994854], [91.62705994, 24.09956932], [91.62744904, 24.09943008], [91.62760925, 24.0994873], [91.62765503, 24.09960747], [91.62763977, 24.09991837], [91.62757874, 24.10040283], [91.62773132, 24.10055923], [91.62787628, 24.1006279], [91.62819672, 24.10029793], [91.62856293, 24.10091972], [91.62880707, 24.10123634], [91.62897491, 24.10146713], [91.62917328, 24.10160637], [91.62936401, 24.10154533], [91.62947083, 24.10146332], [91.62940216, 24.10130119], [91.6291275, 24.10087585], [91.6290741, 24.1007309], [91.62919617, 24.10068893], [91.62934875, 24.1007061], [91.62932587, 24.10083961], [91.62937164, 24.1009407], [91.62949371, 24.10104942], [91.62968445, 24.10099983], [91.62984467, 24.10079193], [91.63015747, 24.10068893], [91.63026428, 24.1005497], [91.63407898, 24.10256958], [91.63776398, 24.1053257], [91.63671875, 24.10669708], [91.63703918, 24.10692215], [91.63832855, 24.10783386], [91.63946533, 24.10864067], [91.63970184, 24.10928917], [91.64054108, 24.1116333], [91.64110565, 24.11322403], [91.64061737, 24.11573982], [91.64022827, 24.11773682], [91.63986969, 24.11955261], [91.63983154, 24.11983299], [91.63946533, 24.12244606], [91.63920593, 24.12430954], [91.63905334, 24.12535667], [91.63877869, 24.12736511], [91.63851166, 24.12924576], [91.63844299, 24.12973595], [91.63708496, 24.13253593], [91.63596344, 24.1348362], [91.63545227, 24.13589287], [91.63472748, 24.13738441], [91.63436127, 24.13817787], [91.634758, 24.13881493], [91.63601685, 24.14073563], [91.6365509, 24.14155006], [91.63732147, 24.14272308], [91.63949585, 24.14603424], [91.64089966, 24.14818001], [91.64231873, 24.15033531], [91.64309692, 24.15152359], [91.64472198, 24.15400124], [91.64551544, 24.15521622], [91.64599609, 24.15594482], [91.64656067, 24.15674973], [91.64634705, 24.1578331], [91.64621735, 24.15859795], [91.64598846, 24.15995789], [91.64576721, 24.16125679], [91.64551544, 24.16274643], [91.64539337, 24.16346741], [91.6452713, 24.16419792], [91.64507294, 24.1653614], [91.64479065, 24.16700745], [91.64452362, 24.16858864], [91.64430237, 24.16988945], [91.64415741, 24.17072868], [91.64425659, 24.17101669], [91.64439392, 24.17145538], [91.64466095, 24.17230797], [91.64518738, 24.17399597], [91.64563751, 24.17544365], [91.64609528, 24.17689133], [91.64645386, 24.17801094], [91.64668274, 24.17875671], [91.6472702, 24.17854881], [91.64949799, 24.17776108], [91.65164185, 24.17700958], [91.65390015, 24.17620659], [91.65493011, 24.17584229], [91.65501404, 24.17586327], [91.65587616, 24.1760788], [91.65622711, 24.17628288], [91.65616608, 24.176548], [91.65608978, 24.17697906], [91.65594482, 24.17744446], [91.65590668, 24.17772675], [91.65610504, 24.17785263], [91.65621185, 24.17796707], [91.65628052, 24.1780529], [91.65641022, 24.17800331], [91.65670013, 24.17811203], [91.65685272, 24.17821503], [91.65707397, 24.17832375], [91.65717316, 24.17867088], [91.65740967, 24.17970276], [91.65727234, 24.17972946], [91.65710449, 24.17990494], [91.65727997, 24.1801033], [91.65721893, 24.18019676], [91.65701294, 24.18024254], [91.65706635, 24.18040848], [91.65689087, 24.18030167], [91.65679169, 24.18036079], [91.65704346, 24.18068123], [91.65723419, 24.18077087], [91.65731049, 24.18075562], [91.65739441, 24.18082619], [91.65760803, 24.18096352], [91.65769196, 24.18094254], [91.65791321, 24.1818428], [91.65818024, 24.18293953], [91.65835571, 24.18340683], [91.6582489, 24.18351936], [91.65846252, 24.18390656], [91.65857697, 24.18398094], [91.6584549, 24.18400002], [91.65817261, 24.18396378], [91.65811157, 24.18403435], [91.65822601, 24.18415833], [91.6584549, 24.18439674], [91.65849304, 24.18452454], [91.65846252, 24.18460846], [91.65825653, 24.18450737], [91.65808868, 24.18446159], [91.6574173, 24.1848278], [91.65744019, 24.1849308], [91.65788269, 24.18507957], [91.65808105, 24.18520164], [91.65834045, 24.1851387], [91.6583786, 24.1854229], [91.65857697, 24.18561172], [91.65852356, 24.18612099], [91.65847015, 24.18632698], [91.65840149, 24.18646622], [91.65830231, 24.18653679], [91.65830994, 24.18673134], [91.65841675, 24.18670845], [91.65860748, 24.18656731], [91.65871429, 24.18648529], [91.65877533, 24.18660355], [91.65888977, 24.18682289], [91.65882874, 24.18691635], [91.65849304, 24.18688393], [91.65827942, 24.18717766], [91.65816498, 24.18742752], [91.65831757, 24.18751335], [91.65856171, 24.18738174], [91.65868378, 24.18746948], [91.65871429, 24.187603], [91.65866852, 24.18786049], [91.65866852, 24.18798065], [91.65885925, 24.18810463], [91.65911865, 24.18814087], [91.65917206, 24.18829155], [91.65910339, 24.18835258], [91.65884399, 24.18837738], [91.65888977, 24.18853188], [91.65917206, 24.18859863], [91.65920258, 24.18870926], [91.65913391, 24.18884277], [91.65922546, 24.18906403], [91.65962219, 24.18935204], [91.6595993, 24.18945122], [91.65940857, 24.18951416], [91.65939331, 24.1896534], [91.65969086, 24.1896553], [91.65927887, 24.19122124], [91.65924835, 24.19136238], [91.65904999, 24.19140434], [91.65885162, 24.19145966], [91.65870667, 24.19130516], [91.65859222, 24.19141388], [91.65842438, 24.19152641], [91.65836334, 24.19160652], [91.65881348, 24.19176865], [91.65872955, 24.1918602], [91.65821075, 24.19188499], [91.65816498, 24.19198227], [91.65841675, 24.19220161], [91.65843964, 24.19241333], [91.65816498, 24.19295883], [91.6581192, 24.19305229], [91.65792847, 24.19314957], [91.657547, 24.19327545], [91.65750122, 24.19338226], [91.65769196, 24.19347], [91.6579361, 24.19345284], [91.65817261, 24.19340324], [91.65830231, 24.19338989], [91.65839386, 24.19350052], [91.65465546, 24.19523048], [91.65454102, 24.19514847], [91.65442657, 24.19523048], [91.6544342, 24.19533539], [91.65327454, 24.19587326], [91.65309906, 24.19595528], [91.65280914, 24.19589806], [91.65267181, 24.1959362], [91.65253448, 24.19602585], [91.6525116, 24.19630623], [91.65264893, 24.19652939], [91.65289307, 24.19667816], [91.65319824, 24.19647217], [91.65351105, 24.19657707], [91.65337372, 24.19678497], [91.65335846, 24.19709778], [91.65313721, 24.19729805], [91.65301514, 24.1972084], [91.65283203, 24.19704247], [91.65279388, 24.19730759], [91.6526947, 24.19751549], [91.65265656, 24.19758987], [91.65284729, 24.19762039], [91.65286255, 24.19771004], [91.65266418, 24.19777679], [91.65258789, 24.19788551], [91.65311432, 24.19802856], [91.65309906, 24.19814301], [91.65263367, 24.19818878], [91.65264893, 24.19832611], [91.65280151, 24.19849586], [91.65306091, 24.19868088], [91.6532135, 24.19905663], [91.65345001, 24.19908524], [91.65354919, 24.19909859], [91.65372467, 24.1989727], [91.65395355, 24.19858932], [91.65403748, 24.19861984], [91.65393829, 24.19896126], [91.65385437, 24.19923401], [91.653862, 24.19956398], [91.65395355, 24.20007324], [91.65393066, 24.20025063], [91.65390015, 24.20044518], [91.65367126, 24.20067406], [91.65368652, 24.20082474], [91.65369415, 24.20090103], [91.65377808, 24.20111465], [91.65345764, 24.2011795], [91.65333557, 24.20133209], [91.65345764, 24.20166779], [91.65339661, 24.20178413], [91.65299988, 24.20183182], [91.65312195, 24.20201111], [91.65350342, 24.20215416], [91.65357208, 24.20217896], [91.65385437, 24.20237923], [91.65377045, 24.2025795], [91.65361023, 24.20252037], [91.65345001, 24.2025547], [91.65350342, 24.20273781], [91.65362549, 24.20292664], [91.65351105, 24.20320511], [91.65335083, 24.20322227], [91.6532135, 24.20322418], [91.65319824, 24.20337486], [91.65338135, 24.20351601], [91.65331268, 24.20367813], [91.65316772, 24.20367432], [91.65306854, 24.20360374], [91.65280151, 24.20347214], [91.65268707, 24.20353317], [91.65254974, 24.20371628], [91.65259552, 24.20399857], [91.65271759, 24.20416451], [91.65290833, 24.20429039], [91.65302277, 24.20438004], [91.6529541, 24.20454025], [91.65292358, 24.20461655], [91.65287781, 24.20472908], [91.65260315, 24.20472527], [91.65235138, 24.20477486], [91.65223694, 24.20487595], [91.6523819, 24.20499229], [91.65276337, 24.20500565], [91.65273285, 24.20507813], [91.65266418, 24.20524216], [91.65232086, 24.20529938], [91.65222931, 24.20542717], [91.65232849, 24.20554161], [91.65248871, 24.20571899], [91.65242767, 24.20592117], [91.6519165, 24.2075119], [91.65179443, 24.207901], [91.65175629, 24.20804214], [91.65169525, 24.20814896], [91.65168762, 24.20840263], [91.65150452, 24.20863914], [91.65132904, 24.20896721], [91.6512146, 24.20896339], [91.65106201, 24.20895958], [91.65101624, 24.20902634], [91.65110016, 24.20916176], [91.65003967, 24.21096039], [91.64925385, 24.21232414], [91.64916229, 24.21248627], [91.64919281, 24.21265221], [91.64922333, 24.21273804], [91.64949036, 24.21294403], [91.64955139, 24.2131176], [91.6493988, 24.2132473], [91.64930725, 24.2131443], [91.64907837, 24.21319771], [91.64887238, 24.21335983], [91.64878845, 24.21356392], [91.64875793, 24.21371269], [91.64901733, 24.21372414], [91.6492691, 24.21373177], [91.64930725, 24.21399307], [91.64888763, 24.21430206], [91.64868927, 24.21457672], [91.64866638, 24.21479225], [91.64854431, 24.2148838], [91.64820862, 24.21465683], [91.64796448, 24.21474838], [91.64787292, 24.21478271], [91.64762878, 24.21506119], [91.6473465, 24.21520996], [91.64715576, 24.21532249], [91.64722443, 24.21552277], [91.64765167, 24.21558189], [91.64789581, 24.21566772], [91.64818573, 24.21570969], [91.64837646, 24.21577835], [91.64845276, 24.21590805], [91.64842987, 24.21617889], [91.64837646, 24.21637535], [91.64849854, 24.216465], [91.64871979, 24.21659088], [91.64868927, 24.2166748], [91.64848328, 24.21665573], [91.64825439, 24.21651268], [91.64809418, 24.2166481], [91.64826202, 24.21683693], [91.64860535, 24.21704674], [91.6488266, 24.2171917], [91.64884186, 24.21731949], [91.64849854, 24.21731186], [91.64839935, 24.21735764], [91.64834595, 24.21744728], [91.64859772, 24.21783638], [91.64852905, 24.21794701], [91.64823914, 24.21805763], [91.64817047, 24.21829605], [91.64801788, 24.21839714], [91.64774323, 24.21848297], [91.64766693, 24.21862602], [91.64775085, 24.21871948], [91.64794922, 24.218853], [91.64808655, 24.21901512], [91.64804077, 24.21930122], [91.64820099, 24.21949387], [91.64848328, 24.21959686], [91.64865112, 24.21969414], [91.64875793, 24.21982193], [91.64887238, 24.22024918], [91.64904022, 24.22026253], [91.64955139, 24.21999168], [91.64959717, 24.22006798], [91.64959717, 24.22044182], [91.64968109, 24.22059059], [91.64985657, 24.22039795], [91.64992523, 24.22006416], [91.65016937, 24.21984482], [91.64997101, 24.21966743], [91.64962006, 24.21966553], [91.6495285, 24.21945572], [91.64963531, 24.21926689], [91.64969635, 24.21921158], [91.65019989, 24.21910095], [91.65029907, 24.21907425], [91.65039063, 24.21904945], [91.65047455, 24.21888542], [91.65059662, 24.21868134], [91.65070343, 24.2185154], [91.65084839, 24.21850204], [91.65089417, 24.21869278], [91.65072632, 24.21892548], [91.65058899, 24.2191925], [91.65105438, 24.21945], [91.65162659, 24.21973228], [91.65195465, 24.21982193], [91.65198517, 24.21996307], [91.65192413, 24.22012138], [91.6519165, 24.2202549], [91.65198517, 24.22032547], [91.6521759, 24.22032738], [91.65219879, 24.22022247], [91.6521759, 24.21984291], [91.65229797, 24.21973991], [91.65244293, 24.21997833], [91.65245819, 24.22018242], [91.65233612, 24.22029686], [91.6522522, 24.22042084], [91.65224457, 24.22051048], [91.65233612, 24.22046852], [91.65267944, 24.22033882], [91.65279388, 24.22035408], [91.65296173, 24.22049522], [91.65296173, 24.2208252], [91.65305328, 24.22098541], [91.65348816, 24.22132683], [91.65361786, 24.22146797], [91.65366364, 24.22163773], [91.65381622, 24.22161102], [91.65412903, 24.22149467], [91.65423584, 24.22164917], [91.65427399, 24.22206116], [91.6542511, 24.22231674], [91.65406799, 24.22298813], [91.65407562, 24.22315788], [91.65423584, 24.22335052], [91.65460205, 24.22326469], [91.65459442, 24.22304726], [91.65522766, 24.22315788], [91.65538788, 24.22330856], [91.65547943, 24.22352409], [91.65571594, 24.22406197], [91.65576172, 24.22435188], [91.65588379, 24.22443962], [91.65598297, 24.22466278], [91.65592194, 24.2247448], [91.65590668, 24.22496414], [91.65595245, 24.22507286], [91.65607452, 24.2251606], [91.65633392, 24.22515106], [91.65663147, 24.22540283], [91.65645599, 24.22551918], [91.65634155, 24.22577286], [91.65621185, 24.22598076], [91.65616608, 24.22615242], [91.65620422, 24.22622871], [91.65653992, 24.2261219], [91.65692902, 24.2259922], [91.65706635, 24.22607613], [91.6569519, 24.22631836], [91.65683746, 24.22656822], [91.65676117, 24.22678185], [91.65673828, 24.22691536], [91.65699768, 24.22696114], [91.65731049, 24.22704887], [91.65744019, 24.22719002], [91.6574707, 24.22738457], [91.65739441, 24.22751999], [91.6576767, 24.22769928], [91.6577301, 24.22783661], [91.65786743, 24.22794914], [91.65802765, 24.22795677], [91.65826416, 24.22794342], [91.65840912, 24.22803116], [91.65843201, 24.22819519], [91.65848541, 24.22837448], [91.65864563, 24.22833061], [91.65911865, 24.22818756], [91.65937805, 24.22842026], [91.6595993, 24.228405], [91.65966797, 24.22846985], [91.65958405, 24.22873306], [91.65961456, 24.22891617], [91.66014099, 24.22877502], [91.66042328, 24.22885132], [91.66055298, 24.22883224], [91.66069794, 24.22873878], [91.66077423, 24.22875214], [91.66098785, 24.22894478], [91.66099548, 24.22909355], [91.66078949, 24.22917175], [91.66068268, 24.22930908], [91.66110229, 24.22960472], [91.66140747, 24.22943878], [91.66188049, 24.22947121], [91.66196442, 24.22959518], [91.66195679, 24.22974968], [91.66203308, 24.2299614], [91.6622467, 24.23011398], [91.6627121, 24.23022842], [91.66271973, 24.22964668], [91.66300201, 24.229599], [91.66319275, 24.22949409], [91.66324615, 24.22935486], [91.66329193, 24.2292366], [91.66355133, 24.22936249], [91.66364288, 24.22940254], [91.66374969, 24.22926331], [91.66385651, 24.22912407], [91.66395569, 24.22916031], [91.66414642, 24.22922707], [91.66424561, 24.22950363], [91.66405487, 24.22985458], [91.66425323, 24.23026657], [91.66413116, 24.23054123], [91.66384888, 24.23107529], [91.66381836, 24.23148727], [91.66421509, 24.23187447], [91.66410828, 24.23203468], [91.66412354, 24.23225784], [91.66444397, 24.23259735], [91.66468811, 24.23272324], [91.66481781, 24.23286819], [91.66517639, 24.23298454], [91.66517639, 24.23314285], [91.6649704, 24.23326683], [91.6648941, 24.23348236], [91.66508484, 24.23365211], [91.66534424, 24.23365593], [91.66556549, 24.23344803], [91.66571808, 24.23318863], [91.66587067, 24.23316765], [91.66599274, 24.2331295], [91.66622162, 24.23318291], [91.66638184, 24.23306274], [91.66629028, 24.23286629], [91.66630554, 24.23276901], [91.6663208, 24.23268509], [91.66650391, 24.23246765], [91.66665649, 24.23226166], [91.66674042, 24.23198318], [91.66685486, 24.23181725], [91.66708374, 24.2317543], [91.66737366, 24.23181343], [91.66755676, 24.23176575], [91.66783142, 24.23153496], [91.66793823, 24.23141289], [91.66799164, 24.23119736], [91.66790009, 24.23099709], [91.66764069, 24.23105049], [91.66742706, 24.23103142], [91.66729736, 24.23094559], [91.66714478, 24.23062706], [91.66731262, 24.23046684], [91.66738129, 24.23034859], [91.66752625, 24.23040009], [91.66874695, 24.22719955], [91.66872406, 24.22559166], [91.66867065, 24.22156906], [91.66909027, 24.21875191], [91.66763306, 24.21579742], [91.66746521, 24.21569252], [91.66712952, 24.21559525], [91.6672287, 24.21523476], [91.66718292, 24.21498299], [91.66684723, 24.21490669], [91.6668396, 24.2147789], [91.66699982, 24.21457481], [91.6668396, 24.21451569], [91.6667099, 24.21437836], [91.66692352, 24.21427345], [91.66705322, 24.21419144], [91.66728973, 24.21412277], [91.66735077, 24.21399307], [91.66710663, 24.21371651], [91.66719818, 24.2131424], [91.66686249, 24.21321106], [91.66679382, 24.21303177], [91.66679382, 24.21269035], [91.66660309, 24.21232414], [91.66659546, 24.21202278], [91.66673279, 24.21202469], [91.66718292, 24.21249771], [91.6673584, 24.21235657], [91.66714478, 24.21218109], [91.667099, 24.21174049], [91.66721344, 24.21137238], [91.66709137, 24.21103859], [91.6669693, 24.210886], [91.66690826, 24.21066093], [91.66755676, 24.21056175], [91.66777802, 24.21046066], [91.66791534, 24.21039581], [91.66802979, 24.21020889], [91.66806793, 24.20999336], [91.66809845, 24.20977592], [91.66811371, 24.209692], [91.66835022, 24.20990944], [91.66846466, 24.20989799], [91.66841125, 24.20969391], [91.66885376, 24.20929718], [91.66906738, 24.20939064], [91.66905975, 24.20911598], [91.66901398, 24.20895195], [91.66916656, 24.20891571], [91.66923523, 24.20895386], [91.66960144, 24.20915031], [91.6696167, 24.20901108], [91.66950989, 24.20884323], [91.66941833, 24.20878792], [91.66933441, 24.2087326], [91.66923523, 24.2086525], [91.66931915, 24.20843887], [91.66945648, 24.20837212], [91.66957092, 24.2083683], [91.66983032, 24.20848083], [91.66994476, 24.20837212], [91.67073059, 24.20761108], [91.67363739, 24.20421982], [91.67379761, 24.20275688], [91.67404175, 24.20252037], [91.67409515, 24.20232964], [91.67405701, 24.20213699], [91.67390442, 24.2017498], [91.67420959, 24.20175171], [91.67441559, 24.20200348], [91.67459106, 24.20223618], [91.67470551, 24.20219803], [91.67456818, 24.20174217], [91.67457581, 24.20145988], [91.67446136, 24.20143318], [91.67408752, 24.20148468], [91.6739502, 24.20133972], [91.67385864, 24.20124626], [91.67396545, 24.20115662], [91.67458344, 24.20106506], [91.67475891, 24.2010498], [91.67500305, 24.20127487], [91.67527771, 24.20145416], [91.67604065, 24.20129967], [91.67632294, 24.20116806], [91.67649078, 24.20103073], [91.67662048, 24.20075798], [91.67665863, 24.20043182], [91.67636108, 24.20020103], [91.67596436, 24.20022964], [91.67571259, 24.20012665], [91.67562103, 24.19998932], [91.67563629, 24.1998024], [91.67550659, 24.19962311], [91.67549133, 24.19947815], [91.67568207, 24.19932175], [91.67578125, 24.19944572], [91.67597198, 24.1997261], [91.67619324, 24.19983101], [91.67635345, 24.19965363], [91.67634583, 24.19929504], [91.67626953, 24.19912529], [91.67698669, 24.19865036], [91.67709351, 24.19748688], [91.6771698, 24.19663811], [91.67729187, 24.19688416], [91.67736053, 24.19693947], [91.6776123, 24.19690514], [91.67788696, 24.19686699], [91.67778015, 24.19640541], [91.67776489, 24.1963253], [91.67762756, 24.19605827], [91.67723846, 24.19585991], [91.67713165, 24.19580269], [91.67694092, 24.19561577], [91.67694855, 24.19540977], [91.67711639, 24.19522285], [91.67723083, 24.19510078], [91.67722321, 24.19443703], [91.6774826, 24.19447136], [91.67745972, 24.19466591], [91.6775589, 24.19483757], [91.6776123, 24.1949501], [91.6780014, 24.19467926], [91.67831421, 24.19460297], [91.6784668, 24.19452477], [91.67831421, 24.19425774], [91.67835236, 24.19412422], [91.67897797, 24.19399643], [91.67913818, 24.19392967], [91.67935181, 24.19384193], [91.67953491, 24.19362259], [91.67960358, 24.19327545], [91.6795578, 24.19244003], [91.67952728, 24.19223595], [91.67955017, 24.19203758], [91.67948151, 24.19174957], [91.67959595, 24.1916256], [91.68004608, 24.19161034], [91.68019867, 24.19153976], [91.68009186, 24.19127083], [91.68006134, 24.19109726], [91.68002319, 24.19079971], [91.67983246, 24.19026756], [91.68000031, 24.18981743], [91.68041229, 24.18941498], [91.68052673, 24.18919373], [91.68051147, 24.18893623], [91.68036652, 24.18880844], [91.68010712, 24.18868256], [91.67990875, 24.18884277], [91.68010712, 24.18704033], [91.68231964, 24.18214989], [91.68257141, 24.17714119], [91.68422699, 24.17146111], [91.68493652, 24.16937065], [91.68836975, 24.16527939], [91.69043732, 24.16274071], [91.69159698, 24.16072273], [91.69182587, 24.16083336], [91.69195557, 24.16060829], [91.69228363, 24.16041183], [91.69233704, 24.16031456], [91.6924057, 24.1601181], [91.6922226, 24.16002655], [91.69195557, 24.16005325], [91.69203186, 24.15992355], [91.69210815, 24.15980148], [91.69230652, 24.15978241], [91.69258881, 24.15991402], [91.69277954, 24.15991211], [91.69282532, 24.16007042], [91.69303894, 24.1600666], [91.69320679, 24.16001511], [91.69325256, 24.16033745], [91.69337463, 24.16034126], [91.69345856, 24.16022301], [91.69360352, 24.1600399], [91.69366455, 24.15995789], [91.69385529, 24.15991974], [91.69410706, 24.15986061], [91.6943512, 24.15982246], [91.69456482, 24.15976906], [91.69490051, 24.15966988], [91.69507599, 24.15971184], [91.69502258, 24.15981865], [91.69488525, 24.15999413], [91.69502258, 24.16021729], [91.69528198, 24.16013908], [91.69527435, 24.16044235], [91.69538116, 24.16049957], [91.69564056, 24.16045761], [91.69577789, 24.16055107], [91.6958313, 24.16072083], [91.69574738, 24.16085052], [91.69569397, 24.16096878], [91.69557953, 24.16110611], [91.69544983, 24.16123962], [91.69551086, 24.16139221], [91.69563293, 24.16131973], [91.69577026, 24.16124344], [91.69580078, 24.16134644], [91.69579315, 24.16164589], [91.69599152, 24.16164017], [91.69641876, 24.16154671], [91.69657898, 24.16152191], [91.6966629, 24.16161919], [91.6966629, 24.16186714], [91.69692993, 24.16204643], [91.69702148, 24.1621685], [91.69690704, 24.16224861], [91.69656372, 24.16230011], [91.69658661, 24.16249084], [91.6967392, 24.16267204], [91.69687653, 24.16264153], [91.69689941, 24.16247368], [91.69696808, 24.1623745], [91.6971283, 24.16232872], [91.69735718, 24.16251564], [91.69749451, 24.16265297], [91.6975708, 24.1627636], [91.69748688, 24.16282463], [91.69723511, 24.16293526], [91.6971283, 24.16304779], [91.69706726, 24.16341972], [91.69725037, 24.16362572], [91.69736481, 24.16379929], [91.69762421, 24.16388893], [91.69769287, 24.16370964], [91.69761658, 24.16348457], [91.69764709, 24.1633873], [91.69797516, 24.16351891], [91.6982193, 24.16352272], [91.69854736, 24.16337585], [91.69870758, 24.16332245], [91.69887543, 24.16339302], [91.69904327, 24.16341209], [91.69923401, 24.16343117], [91.69944, 24.1635952], [91.69931793, 24.16376114], [91.69927979, 24.16400337], [91.69943237, 24.1640625], [91.6995697, 24.16395569], [91.69966888, 24.16385841], [91.69979095, 24.16365433], [91.69991302, 24.16352463], [91.70000458, 24.163517], [91.70018768, 24.16350937], [91.70066071, 24.16402626], [91.70075989, 24.16403198], [91.70083618, 24.16384506], [91.70090485, 24.1636734], [91.70102692, 24.1634922], [91.70106506, 24.16342735], [91.70114899, 24.16327095], [91.70122528, 24.16327286], [91.70130157, 24.16327286], [91.70152283, 24.16323662], [91.70160675, 24.16348648], [91.70185852, 24.16360283], [91.70198822, 24.16381836], [91.70213318, 24.16402245], [91.70227814, 24.16405678], [91.70230865, 24.16388512], [91.70222473, 24.1635685], [91.70233154, 24.16348457], [91.70249176, 24.1634655], [91.7027359, 24.16362762], [91.70304108, 24.16376114], [91.70328522, 24.16367912], [91.70342255, 24.16357422], [91.7035675, 24.16330528], [91.70341492, 24.16331482], [91.70324707, 24.16348457], [91.70306396, 24.16342926], [91.70304871, 24.1632843], [91.70303345, 24.16312599], [91.70322418, 24.16300201], [91.70323944, 24.16290474], [91.70328522, 24.16275024], [91.70336914, 24.16270065], [91.70355988, 24.16283989], [91.70368195, 24.16277695], [91.70379639, 24.16263008], [91.70378113, 24.16254616], [91.70371246, 24.16248322], [91.70349121, 24.16256905], [91.70348358, 24.16240692], [91.70349121, 24.16224098], [91.70365143, 24.16221237], [91.70393372, 24.16230965], [91.70400238, 24.16226768], [91.70407867, 24.16221809], [91.70405579, 24.16211128], [91.70401001, 24.16199112], [91.70394135, 24.16189575], [91.70385742, 24.1618042], [91.70368958, 24.16162682], [91.70388794, 24.16141701], [91.70404816, 24.16141319], [91.7040329, 24.16150475], [91.704216, 24.16161728], [91.70427704, 24.16167259], [91.70450592, 24.16174507], [91.70463562, 24.16172791], [91.7045517, 24.16157341], [91.70436096, 24.16143036], [91.7043457, 24.1613369], [91.70442963, 24.16116333], [91.70468903, 24.16124153], [91.70484161, 24.16121674], [91.70472717, 24.16101456], [91.70468903, 24.16088867], [91.70455933, 24.16070747], [91.70487976, 24.16036797], [91.70498657, 24.16025352], [91.70568085, 24.1595211], [91.70575714, 24.1583519], [91.70576477, 24.1582756], [91.70615387, 24.15801811], [91.70633698, 24.15788269], [91.70631409, 24.15777588], [91.70611572, 24.15764999], [91.70600891, 24.15755272], [91.70631409, 24.15698624], [91.70630646, 24.15673256], [91.70627594, 24.15643311], [91.70626831, 24.15631676], [91.70633698, 24.1561451], [91.7063446, 24.15606689], [91.70636749, 24.15593719], [91.70631409, 24.15548706], [91.70613861, 24.15500069], [91.70610046, 24.15480614], [91.70593262, 24.15455627], [91.70600891, 24.15441322], [91.7061615, 24.15441322], [91.70644379, 24.15449333], [91.70690918, 24.15462875], [91.70760345, 24.15486145], [91.70772552, 24.15489578], [91.70796967, 24.15488434], [91.70818329, 24.15480042], [91.70868683, 24.15445709], [91.70915222, 24.15411568], [91.70941162, 24.15424347], [91.70983124, 24.15431786], [91.71017456, 24.15424538], [91.71083069, 24.15417862], [91.71118927, 24.15409088], [91.71156311, 24.15391922], [91.71188354, 24.15376854], [91.71208954, 24.1536274], [91.71208954, 24.15349007], [91.71214294, 24.15335464], [91.71218109, 24.15323639], [91.71230316, 24.15322685], [91.7125473, 24.15323257], [91.71281433, 24.15323257], [91.7131424, 24.15315247], [91.71331024, 24.15301704], [91.71348572, 24.15306854], [91.71374512, 24.15343666], [91.7140274, 24.15380096], [91.71417236, 24.15385056], [91.71434784, 24.15390587], [91.71461487, 24.15382195], [91.71479797, 24.15358543], [91.71490479, 24.15343285], [91.71501923, 24.15327263], [91.71530151, 24.15310097], [91.71551514, 24.15309525], [91.71564484, 24.15324974], [91.71570587, 24.15332413], [91.71630859, 24.15321541], [91.71658325, 24.1531086], [91.71649933, 24.15301132], [91.71640778, 24.15297127], [91.71619415, 24.15287399], [91.71603394, 24.15269089], [91.71609497, 24.1525898], [91.71637726, 24.1523056], [91.71652985, 24.15217018], [91.71672058, 24.15212822], [91.71692657, 24.15220833], [91.7171402, 24.1522789], [91.71726227, 24.15233421], [91.71741486, 24.15240288], [91.71736145, 24.15257645], [91.71737671, 24.15273285], [91.71751404, 24.15275192], [91.71781921, 24.15254784], [91.71789551, 24.15239906], [91.71794128, 24.1523056], [91.71809387, 24.15239716], [91.71829987, 24.15251541], [91.71851349, 24.15240479], [91.71869659, 24.15224457], [91.71897125, 24.15211105], [91.71904755, 24.15209198], [91.71920013, 24.15205574], [91.7193222, 24.15220451], [91.71923828, 24.15237236], [91.71918488, 24.15246964], [91.71932983, 24.15261841], [91.71945953, 24.15261078], [91.71964264, 24.15237999], [91.71981812, 24.15225792], [91.72013855, 24.15229607], [91.72035217, 24.15218925], [91.72099304, 24.15268326], [91.72109985, 24.15287399], [91.72122192, 24.15278816], [91.7212677, 24.15262413], [91.72148132, 24.15261841], [91.72169495, 24.15261841], [91.72179413, 24.1524868], [91.72174072, 24.1523838], [91.72158051, 24.15227318], [91.72163391, 24.15220642], [91.72197723, 24.15212059], [91.72216797, 24.15185165], [91.72209167, 24.15158653], [91.72225952, 24.15148544], [91.72232056, 24.15136909], [91.7220993, 24.15122414], [91.72235107, 24.15077591], [91.72254944, 24.15074539], [91.72280121, 24.1507988], [91.72293091, 24.150774], [91.72290802, 24.15069008], [91.72286224, 24.15051651], [91.72298431, 24.15009117], [91.72293854, 24.14991951], [91.72296906, 24.14971924], [91.72332001, 24.14920807], [91.72337341, 24.14907265], [91.72323608, 24.14888191], [91.72317505, 24.14873123], [91.72325897, 24.14847755], [91.72356415, 24.14807701], [91.72390747, 24.14774895], [91.72428131, 24.14761734], [91.724617, 24.14743042], [91.72460175, 24.14733124], [91.72454834, 24.14710426], [91.72465515, 24.1469593], [91.7247467, 24.14690781], [91.72496796, 24.14683533], [91.72536469, 24.1467762], [91.72554779, 24.146698], [91.7256546, 24.14665031], [91.72593689, 24.14673615], [91.72612762, 24.14674759], [91.72636414, 24.14683151], [91.72660828, 24.1467495], [91.72678375, 24.1465683], [91.72676086, 24.14618111], [91.72680664, 24.14604568], [91.72693634, 24.14596748], [91.72720337, 24.14591789], [91.72737885, 24.14584732], [91.72759247, 24.14547157], [91.72777557, 24.14517784], [91.72810364, 24.14505005], [91.72833252, 24.1449604], [91.72844696, 24.14485168], [91.72847748, 24.1447773], [91.72838593, 24.14460182], [91.72818756, 24.14440155], [91.72774506, 24.14434052], [91.72750092, 24.14434624], [91.72737885, 24.14434814], [91.727211, 24.14430237], [91.7273407, 24.14416313], [91.72743225, 24.14406586], [91.72763062, 24.14390564], [91.72774506, 24.14383316], [91.72792053, 24.14372253], [91.72833252, 24.14340782], [91.72883606, 24.14367485], [91.72904968, 24.14373779], [91.72927856, 24.1437912], [91.72949982, 24.1438427], [91.72982788, 24.14397812], [91.73040009, 24.1438179], [91.73067474, 24.14373779], [91.73098755, 24.14376068], [91.73122406, 24.14391708], [91.7313385, 24.14437866], [91.73146057, 24.14459419], [91.73142242, 24.1449337], [91.73165131, 24.1454792], [91.73212433, 24.14581299], [91.73236847, 24.14589882], [91.73253632, 24.14561081], [91.73268127, 24.14533997], [91.7328949, 24.14497375], [91.73310089, 24.14468002], [91.73345184, 24.14439011], [91.73378754, 24.14415359], [91.73403931, 24.14386368], [91.73418427, 24.14383125], [91.73433685, 24.14394951], [91.73445129, 24.14422798], [91.73458099, 24.14451599], [91.73466492, 24.14473915], [91.73477936, 24.14488602], [91.73484039, 24.14496231], [91.73506927, 24.14514732], [91.73530579, 24.14525414], [91.73554993, 24.14533806], [91.73612213, 24.14572716], [91.73633575, 24.14585686], [91.7366333, 24.14603806], [91.73716736, 24.14529991], [91.73749542, 24.14513016], [91.73802185, 24.1447258], [91.73804474, 24.14465332], [91.7379303, 24.14434052], [91.73792267, 24.14424706], [91.73822784, 24.14396477], [91.73816681, 24.14360809], [91.73801422, 24.14339828], [91.73795319, 24.1432476], [91.73844147, 24.14342117], [91.7385788, 24.14325905], [91.73866272, 24.14329529], [91.73873138, 24.14321136], [91.73867798, 24.14314461], [91.73889923, 24.14288712], [91.73981476, 24.14181137], [91.73991394, 24.1420536], [91.73988342, 24.14212227], [91.7397995, 24.14230537], [91.7399292, 24.142519], [91.74017334, 24.14260864], [91.74051666, 24.14265633], [91.74072266, 24.14286995], [91.74082947, 24.14293098], [91.74121857, 24.14293289], [91.74152374, 24.14280891], [91.74176025, 24.14264679], [91.74187469, 24.14250946], [91.74181366, 24.14208603], [91.74179077, 24.14172173], [91.74188232, 24.14153862], [91.74201965, 24.14145088], [91.74230957, 24.1414814], [91.7425766, 24.1415596], [91.74275208, 24.14161491], [91.74298096, 24.14160919], [91.74305725, 24.14152718], [91.74310303, 24.14146423], [91.74317169, 24.14135742], [91.74328613, 24.14118576], [91.74351501, 24.14117622], [91.74360657, 24.14124298], [91.74385071, 24.1414299], [91.74407959, 24.14158249], [91.74420929, 24.14161491], [91.74459839, 24.14213753], [91.7443924, 24.14256477], [91.7444458, 24.14264107], [91.7445755, 24.14282417], [91.74463654, 24.14299202], [91.74472809, 24.14317322], [91.74507904, 24.14316177], [91.74538422, 24.1430912], [91.74562073, 24.14307785], [91.74575043, 24.14311981], [91.7458725, 24.14298439], [91.74549103, 24.14237595], [91.74555206, 24.14216423], [91.74578857, 24.14203453], [91.74597931, 24.14185333], [91.74608612, 24.14169502], [91.74616241, 24.14140511], [91.74621582, 24.14126968], [91.74633026, 24.14132118], [91.7464447, 24.14147758], [91.74642181, 24.14168549], [91.74634552, 24.14185905], [91.74627686, 24.14194298], [91.7464447, 24.14202309], [91.74672699, 24.14196205], [91.74694824, 24.14192963], [91.74765015, 24.14216614], [91.74774933, 24.14212418], [91.7478714, 24.14181709], [91.74790192, 24.14160728], [91.74807739, 24.14159393], [91.74828339, 24.14163208], [91.74849701, 24.14167023], [91.74871063, 24.14160156], [91.74923706, 24.14178467], [91.7492981, 24.14189911], [91.74938965, 24.14201927], [91.74947357, 24.14213181], [91.74983215, 24.14209938], [91.75007629, 24.1420784], [91.75041199, 24.14219475], [91.75053406, 24.14223671], [91.75055695, 24.14237595], [91.75057983, 24.14248085], [91.75067902, 24.14251137], [91.75100708, 24.14240074], [91.75110626, 24.14243317], [91.75165558, 24.14272308], [91.75173187, 24.14265251], [91.75180054, 24.14258385], [91.75189209, 24.14230728], [91.7519989, 24.14214706], [91.7525177, 24.14201927], [91.75305176, 24.14188766], [91.75320435, 24.14190483], [91.75336456, 24.14197731], [91.7535553, 24.14203262], [91.75382996, 24.14205551], [91.7539444, 24.14206505], [91.75417328, 24.14208031], [91.75428772, 24.14213371], [91.75447845, 24.14232445], [91.75460815, 24.14245415], [91.754776, 24.14239502], [91.75488281, 24.142313], [91.75505066, 24.14215851], [91.75517273, 24.14203072], [91.75533295, 24.14211082], [91.75547791, 24.14227104], [91.7555542, 24.14230347], [91.75582886, 24.14212608], [91.75614166, 24.14190674], [91.75637817, 24.14178848], [91.7565918, 24.14167213], [91.75680542, 24.14156914], [91.75701904, 24.14153099], [91.7572937, 24.14146614], [91.75737, 24.14138412], [91.75743103, 24.14134026], [91.75775909, 24.14136696], [91.75798798, 24.14141273], [91.75617218, 24.14270782], [91.75951385, 24.14196014], [91.75963593, 24.14217567], [91.75973511, 24.14232063], [91.75971985, 24.14245033], [91.7596817, 24.14261436], [91.75960541, 24.14274597], [91.75949097, 24.14305687], [91.75948334, 24.1432209], [91.75946808, 24.1434269], [91.75949097, 24.14356232], [91.75953674, 24.14369202], [91.75957489, 24.14379692], [91.75962067, 24.14389038], [91.75964355, 24.14398766], [91.75964355, 24.14409828], [91.75965881, 24.14421463], [91.75967407, 24.1443615], [91.75964355, 24.14459229], [91.75967407, 24.14472389], [91.75969696, 24.14483643], [91.75975037, 24.14552116], [91.759552, 24.14611626], [91.75938416, 24.14658356], [91.75902557, 24.14737892], [91.75875854, 24.1492939], [91.75847626, 24.15127754], [91.75844574, 24.15151024], [91.75807953, 24.15409279], [91.75794983, 24.15503502], [91.75772095, 24.15664101], [91.75744629, 24.15865135], [91.75737, 24.15918922], [91.75675201, 24.16350555], [91.75637054, 24.1662178], [91.7559967, 24.16887665], [91.75585938, 24.1698761], [91.75576782, 24.17052078], [91.75543213, 24.17289543], [91.7552948, 24.17385864], [91.75489807, 24.17670631], [91.75452423, 24.17936707], [91.75402069, 24.18295479], [91.75352478, 24.18648338], [91.75305939, 24.18976593], [91.75273895, 24.19206619], [91.75261688, 24.1929245], [91.7522583, 24.19545937], [91.75212097, 24.19639969], [91.7516861, 24.19950676], [91.75125885, 24.20251083], [91.751091, 24.20373917], [91.75078583, 24.20586777], [91.75042725, 24.20845604], [91.75003815, 24.21116066], [91.74988556, 24.21224022], [91.74948883, 24.21504593], [91.74932861, 24.2162056], [91.74903107, 24.21832657], [91.74871063, 24.22049522], [91.74829865, 24.22349167], [91.74782562, 24.22682953], [91.74760437, 24.22844696], [91.74729156, 24.23061371], [91.74673462, 24.23458672], [91.74630737, 24.23764229], [91.74608612, 24.23921204], [91.74586487, 24.2407608], [91.74560547, 24.24261856], [91.74507141, 24.24641228], [91.74497223, 24.24708557], [91.74537659, 24.24685478], [91.74615479, 24.24640846], [91.74908447, 24.24472427], [91.75215149, 24.2429657], [91.75360107, 24.24213028], [91.75706482, 24.24013901], [91.75949097, 24.23874474], [91.76094818, 24.2379055], [91.76377106, 24.23621559], [91.7645874, 24.23575401], [91.7664032, 24.23472214], [91.76941681, 24.23301506], [91.77276611, 24.23111534], [91.774086, 24.23036766], [91.77600098, 24.22928429], [91.7780838, 24.22810555], [91.78094482, 24.22648239], [91.78334045, 24.22512245], [91.78457642, 24.22442055], [91.78756714, 24.22274017], [91.78784943, 24.22258377], [91.78797913, 24.2225132], [91.78862762, 24.22214699], [91.78869629, 24.22211266], [91.79110718, 24.22096252], [91.79296875, 24.22083473], [91.79295349, 24.22092819], [91.79312134, 24.22092247], [91.79330444, 24.22096634], [91.7934494, 24.22080994], [91.79356384, 24.22090149], [91.79360199, 24.22096443], [91.79370117, 24.22103882], [91.79388428, 24.22098732], [91.79398346, 24.22079086], [91.79376221, 24.22051048], [91.79369354, 24.22038269], [91.79399109, 24.2202282], [91.79404449, 24.22009468], [91.79400635, 24.21993446], [91.79405212, 24.21977234], [91.79424286, 24.21964836], [91.79444885, 24.21965218], [91.794487, 24.21974564], [91.79450226, 24.21985054], [91.79463196, 24.21993637], [91.79479218, 24.22002792], [91.79503632, 24.2201004], [91.79530334, 24.22023582], [91.79521942, 24.2204628], [91.79547119, 24.22054291], [91.79553986, 24.2205658], [91.79568481, 24.2206192], [91.79584503, 24.22046661], [91.79582977, 24.22039604], [91.79579926, 24.22025871], [91.7958374, 24.22008514], [91.79593658, 24.21991348], [91.79615021, 24.21980286], [91.79623413, 24.21978951], [91.79641724, 24.21990204], [91.79654694, 24.21986771], [91.79657745, 24.21978951], [91.79666901, 24.21973991], [91.79684448, 24.21969032], [91.79698181, 24.21967125], [91.79725647, 24.21977043], [91.79733276, 24.21988106], [91.79743958, 24.21992111], [91.79759979, 24.21978188], [91.79782104, 24.21967888], [91.79797363, 24.21973419], [91.79806519, 24.21977997], [91.798172, 24.21982384], [91.79824066, 24.2200737], [91.79833221, 24.2201786], [91.79837799, 24.22023773], [91.79847717, 24.22036362], [91.79843903, 24.22055054], [91.79851532, 24.22063446], [91.79871368, 24.22059631], [91.79875946, 24.22065735], [91.79872131, 24.22087669], [91.7988739, 24.22089005], [91.79898834, 24.22060394], [91.79910278, 24.22046661], [91.79924011, 24.22034264], [91.79964447, 24.22032738], [91.79980469, 24.22032166], [91.79985046, 24.22041893], [91.8000412, 24.22043419], [91.80012512, 24.22029305], [91.80017853, 24.22005272], [91.80032349, 24.22008514], [91.80060577, 24.22022057], [91.80066681, 24.22015572], [91.80078888, 24.21997643], [91.80091095, 24.21989632], [91.80104065, 24.2197094], [91.80114746, 24.21972466], [91.8013916, 24.21966934], [91.80166626, 24.21970749], [91.8017807, 24.21982956], [91.80192566, 24.21974945], [91.80208588, 24.21955299], [91.80226898, 24.21947479], [91.80238342, 24.2195816], [91.80240631, 24.21973228], [91.80226898, 24.21988869], [91.80231476, 24.21997261], [91.80252838, 24.21996498], [91.80266571, 24.21985626], [91.80278015, 24.21992111], [91.802948, 24.22013283], [91.80305481, 24.22023392], [91.80319214, 24.22036171], [91.80329895, 24.22041702], [91.80353546, 24.22034454], [91.80369568, 24.2203331], [91.80393219, 24.22037315], [91.80401611, 24.22048378], [91.80392456, 24.2205658], [91.80408478, 24.2206459], [91.80422974, 24.22052956], [91.80428314, 24.22035599], [91.80443573, 24.22031403], [91.80461884, 24.22014427], [91.80477905, 24.22025871], [91.80492401, 24.22035599], [91.80510712, 24.22035217], [91.8052597, 24.22039223], [91.80529785, 24.22055244], [91.80530548, 24.22068405], [91.80551147, 24.220644], [91.80577087, 24.2206459], [91.80588531, 24.22073746], [91.80601501, 24.22084427], [91.8061676, 24.22082329], [91.80640411, 24.22065353], [91.80662537, 24.22052956], [91.80669403, 24.22038651], [91.806633, 24.22027397], [91.80662537, 24.2201767], [91.80673981, 24.22010231], [91.80678558, 24.21995735], [91.80686951, 24.21979141], [91.80677032, 24.21956253], [91.80672455, 24.2194519], [91.80683899, 24.21940994], [91.80704498, 24.21935844], [91.80699921, 24.21907043], [91.80651093, 24.21919632], [91.80648804, 24.21903038], [91.80639648, 24.2189045], [91.80632782, 24.21882057], [91.80622101, 24.21884727], [91.80606842, 24.21899223], [91.80584717, 24.21883774], [91.80620575, 24.21870995], [91.80630493, 24.2185421], [91.80698395, 24.2184639], [91.80713654, 24.21834373], [91.8073349, 24.21825218], [91.80757904, 24.21822929], [91.80757904, 24.218153], [91.80731964, 24.21809578], [91.80751038, 24.2179451], [91.80828857, 24.21791649], [91.80866241, 24.21799469], [91.8087616, 24.21800995], [91.80886078, 24.21802521], [91.80879974, 24.21809959], [91.80913544, 24.21816826], [91.80931854, 24.21789551], [91.80937958, 24.21803665], [91.80943298, 24.2182045], [91.80957031, 24.21837997], [91.80969238, 24.21822357], [91.80976868, 24.21792603], [91.80982971, 24.21788788], [91.80990601, 24.21757889], [91.81001282, 24.21755981], [91.81005096, 24.21776199], [91.81040192, 24.21771622], [91.81021881, 24.21748352], [91.81011963, 24.21735382], [91.81031036, 24.21733093], [91.81036377, 24.21718407], [91.81044006, 24.21721649], [91.81061554, 24.21729469], [91.81069946, 24.21720314], [91.81077576, 24.21705437], [91.81069183, 24.21689034], [91.81035614, 24.21677971], [91.8104248, 24.21666145], [91.81079102, 24.216465], [91.81095123, 24.2165432], [91.81091309, 24.21673203], [91.81106567, 24.2168293], [91.81111145, 24.21673584], [91.81118011, 24.21618271], [91.81118011, 24.21596527], [91.81125641, 24.21579933], [91.81141663, 24.21567917], [91.81144714, 24.21553993], [91.8115387, 24.21547508], [91.81155396, 24.2154026], [91.81130981, 24.21530533], [91.81175995, 24.21504974], [91.81192017, 24.21497917], [91.8116684, 24.21484375], [91.81163025, 24.21478271], [91.81172943, 24.21469879], [91.81182098, 24.21464729], [91.81216431, 24.21464348], [91.81233978, 24.21452141], [91.81220245, 24.21427917], [91.8123703, 24.21413422], [91.81243896, 24.21394157], [91.8126297, 24.21383286], [91.81258392, 24.21370506], [91.81269073, 24.21363068], [91.81278229, 24.21377373], [91.81291962, 24.21369553], [91.81287384, 24.21316147], [91.81272125, 24.21295357], [91.81267548, 24.21261597], [91.81253052, 24.21248245], [91.81251526, 24.21237564], [91.81264496, 24.21223068], [91.81299591, 24.21257019], [91.81317139, 24.21269798], [91.81315613, 24.21245956], [91.81362152, 24.2123394], [91.81376648, 24.21235466], [91.81389618, 24.21233559], [91.8140564, 24.21241379], [91.81414795, 24.21242142], [91.81434631, 24.21218491], [91.81452179, 24.2121048], [91.81460571, 24.21219635], [91.81469727, 24.21203232], [91.81477356, 24.21195221], [91.81491089, 24.21186638], [91.81499481, 24.21189499], [91.81503296, 24.21207237], [91.81520081, 24.21218681], [91.81529999, 24.21214104], [91.81536865, 24.2118988], [91.81544495, 24.21185493], [91.81550598, 24.21190453], [91.8156662, 24.21175385], [91.81569672, 24.21162224], [91.81576538, 24.21156883], [91.81582642, 24.21146393], [91.81588745, 24.21140099], [91.815979, 24.21133995], [91.81606293, 24.21130943], [91.81611633, 24.21125412], [91.81625366, 24.2109623], [91.81612396, 24.21062851], [91.81604767, 24.21051216], [91.81606293, 24.21035957], [91.81613922, 24.21020889], [91.81619263, 24.21011353], [91.81629944, 24.21008301], [91.81646729, 24.21007919], [91.81658936, 24.21012497], [91.81666565, 24.21046448], [91.81682587, 24.21051216], [91.81697845, 24.2105484], [91.81694031, 24.21035767], [91.81700897, 24.21031952], [91.81710815, 24.21021271], [91.81726837, 24.21020699], [91.81738281, 24.21002197], [91.81747437, 24.20993233], [91.81768036, 24.21004486], [91.81748962, 24.21021843], [91.81747437, 24.21031761], [91.81745911, 24.21047783], [91.81760406, 24.21066666], [91.81784058, 24.21069908], [91.81801605, 24.21074867], [91.81806183, 24.21052361], [91.81826019, 24.21060181], [91.81835938, 24.21064186], [91.81848145, 24.21062088], [91.81850433, 24.210495], [91.8187027, 24.21046066], [91.81873322, 24.21076393], [91.81879425, 24.21080971], [91.8189621, 24.21080017], [91.81902313, 24.21076202], [91.8190918, 24.21067619], [91.81909943, 24.21049309], [91.81902313, 24.21031952], [91.81919861, 24.21018219], [91.81909943, 24.2099514], [91.81916809, 24.20983315], [91.81936646, 24.20979691], [91.81954956, 24.20988274], [91.8194046, 24.20996094], [91.81948853, 24.21014977], [91.81943512, 24.2102356], [91.81941223, 24.21038437], [91.81950378, 24.21030807], [91.81960297, 24.21025848], [91.81980896, 24.21009445], [91.81984711, 24.21002197], [91.82136536, 24.21073532], [91.82132721, 24.21095276], [91.82151794, 24.21101189], [91.82176208, 24.2110424], [91.82184601, 24.21096039], [91.82185364, 24.21068954], [91.82202148, 24.21063995], [91.82218933, 24.21056557], [91.82254791, 24.21072006], [91.82260895, 24.21064758], [91.82234192, 24.21035957], [91.82250214, 24.21039009], [91.82276154, 24.21052933], [91.82279968, 24.21042633], [91.82279205, 24.2102375], [91.82279205, 24.21013069], [91.82290649, 24.21017838], [91.8230896, 24.21024132], [91.82363892, 24.21016121], [91.82378387, 24.2102375], [91.82373047, 24.21040154], [91.82348633, 24.21053696], [91.82335663, 24.21060562], [91.82334137, 24.21071243], [91.82339478, 24.21088028], [91.82350159, 24.21102905], [91.82363129, 24.21113396], [91.82379913, 24.21123695], [91.82382965, 24.21142387], [91.8239212, 24.21150589], [91.82406616, 24.21146202], [91.82422638, 24.21137238], [91.82444763, 24.21113396], [91.82462311, 24.21110725], [91.82475281, 24.21121979], [91.82482147, 24.21143532], [91.82473755, 24.2115612], [91.82468414, 24.21167374], [91.8246994, 24.21179008], [91.82472229, 24.2119236], [91.82476044, 24.21198654], [91.82492828, 24.21211052], [91.82498932, 24.21224594], [91.82493591, 24.21234894], [91.82492828, 24.21248436], [91.82502747, 24.2126503], [91.82530212, 24.21273613], [91.82545471, 24.21283722], [91.82550812, 24.21293449], [91.8256073, 24.21302986], [91.82566071, 24.21310616], [91.82580566, 24.21315765], [91.82595825, 24.21316338], [91.82604218, 24.21324158], [91.82607269, 24.21333313], [91.82611847, 24.21343422], [91.82618713, 24.21356392], [91.82630157, 24.21369171], [91.82640839, 24.21376801], [91.82666779, 24.21377754], [91.8267746, 24.21370316], [91.82695007, 24.21352005], [91.82704926, 24.21346664], [91.82717896, 24.21350479], [91.82733154, 24.21353722], [91.82740784, 24.2135582], [91.82754517, 24.21352768], [91.82770538, 24.21342087], [91.82788849, 24.21331978], [91.82805634, 24.21327591], [91.82904053, 24.21323204], [91.82915497, 24.21327972], [91.82918549, 24.21336937], [91.82904053, 24.21346855], [91.82889557, 24.21367455], [91.82888794, 24.21383858], [91.82897949, 24.213871], [91.82897186, 24.21400833], [91.8289566, 24.21409607], [91.82894897, 24.21418381], [91.82904053, 24.21429062], [91.829216, 24.21429634], [91.82930756, 24.21441078], [91.82944489, 24.21471596], [91.82950592, 24.21485329], [91.82959747, 24.21492386], [91.82974243, 24.21497917], [91.82988739, 24.21515656], [91.83003998, 24.21562195], [91.83013153, 24.21563339], [91.83026123, 24.21562195], [91.83035278, 24.21571922], [91.83052063, 24.21590805], [91.83066559, 24.21590424], [91.83093262, 24.21589851], [91.83107758, 24.21605682], [91.83109283, 24.21616554], [91.83106232, 24.21634674], [91.83097076, 24.21658134], [91.83103943, 24.21666336], [91.83114624, 24.21674538], [91.83130646, 24.21684265], [91.83142853, 24.21703529], [91.83148193, 24.21713257], [91.83145905, 24.21723557], [91.8314209, 24.21733093], [91.83148193, 24.21747589], [91.83148193, 24.21759033], [91.8314743, 24.21776581], [91.83152008, 24.21796227], [91.83141327, 24.21810341], [91.83125305, 24.21813965], [91.83115387, 24.21815109], [91.8312149, 24.21834373], [91.8313446, 24.21832848], [91.83163452, 24.21824646], [91.83189392, 24.21816254], [91.83195496, 24.21836281], [91.83213043, 24.21832466], [91.83222198, 24.21822739], [91.83235168, 24.21816635], [91.83250427, 24.21823502], [91.83265686, 24.21822166], [91.83274841, 24.2183609], [91.83292389, 24.2183094], [91.83302307, 24.21821404], [91.83303833, 24.21805954], [91.83313751, 24.21802711], [91.83332062, 24.21805], [91.83326721, 24.21834755], [91.83335114, 24.21829605], [91.83342743, 24.21825218], [91.83353424, 24.2182827], [91.83361053, 24.21842194], [91.83372498, 24.2185154], [91.83377075, 24.21837044], [91.83387756, 24.21834946], [91.83407593, 24.21835327], [91.83415985, 24.21833801], [91.83433533, 24.21824646], [91.83444977, 24.21829987], [91.83454132, 24.21834183], [91.83466339, 24.21839905], [91.8374176, 24.21968079], [91.83753204, 24.2212925], [91.8375473, 24.22145653], [91.83759308, 24.22204208], [91.83744812, 24.22211647], [91.83731842, 24.22233772], [91.83711243, 24.22273064], [91.83708954, 24.22285461], [91.83712006, 24.22298813], [91.83707428, 24.22306824], [91.83708954, 24.22315788], [91.83746338, 24.22325897], [91.83743286, 24.22343826], [91.83726501, 24.2235775], [91.83705139, 24.22382355], [91.83721924, 24.22388458], [91.83773041, 24.22395706], [91.83785248, 24.22397614], [91.83798218, 24.22403145], [91.83802795, 24.22412491], [91.83779907, 24.22429848], [91.83773041, 24.22442245], [91.83752441, 24.22458076], [91.83745575, 24.22471428], [91.83747101, 24.22478676], [91.83763123, 24.22476196], [91.8377533, 24.22489738], [91.83758545, 24.22506714], [91.83733368, 24.22524261], [91.83720398, 24.22502327], [91.83711243, 24.22491646], [91.83680725, 24.22496796], [91.83677673, 24.22513771], [91.83679199, 24.22523117], [91.83686066, 24.22552681], [91.83695221, 24.2257061], [91.83735657, 24.22567177], [91.837677, 24.22561264], [91.837883, 24.22583389], [91.83798218, 24.22612572], [91.83818054, 24.22637749], [91.83848572, 24.22653961], [91.83869171, 24.22652435], [91.83904266, 24.22640038], [91.83925629, 24.22632027], [91.83991241, 24.22722816], [91.84389496, 24.22907639], [91.8447876, 24.22890854], [91.84747314, 24.22827148], [91.84471893, 24.22584534], [91.84490967, 24.22571754], [91.84572601, 24.22505379], [91.84593964, 24.22472191], [91.84603119, 24.22439384], [91.84597015, 24.22418022], [91.84594727, 24.22410774], [91.84563446, 24.22386932], [91.84529114, 24.22366905], [91.84472656, 24.22348022], [91.84365845, 24.22340584], [91.84339142, 24.22335434], [91.8432312, 24.22332382], [91.84317017, 24.22327423], [91.84291077, 24.22306633], [91.842659, 24.22274971], [91.84257507, 24.22236252], [91.8425827, 24.22208023], [91.84262848, 24.22174835], [91.84264374, 24.22163963], [91.8427124, 24.22118568], [91.84291077, 24.22064972], [91.84297943, 24.22037506], [91.84325409, 24.22025299], [91.84358978, 24.22022438], [91.84393311, 24.22038651], [91.84431458, 24.22067261], [91.84465027, 24.22092247], [91.84508514, 24.22122383], [91.84555817, 24.22143364], [91.84591675, 24.22145653], [91.84636688, 24.22145844], [91.84683228, 24.22145653], [91.84761047, 24.22144318], [91.84812164, 24.2215786], [91.84856415, 24.22153854], [91.84896088, 24.22143936], [91.84925079, 24.22133636], [91.84954834, 24.22110176], [91.85140991, 24.22147751], [91.85150146, 24.22149658], [91.85263062, 24.21879196], [91.85268402, 24.21865463], [91.85491943, 24.2164917], [91.85687256, 24.21429443], [91.85674286, 24.21430016], [91.85327148, 24.21447754], [91.85231781, 24.21457672], [91.85331726, 24.21414566], [91.85422516, 24.21382904], [91.85457611, 24.21366692], [91.85488892, 24.21343422], [91.85508728, 24.21320534], [91.85509491, 24.21253204], [91.85507202, 24.21220779], [91.85505676, 24.21201515], [91.85469818, 24.21182442], [91.85440826, 24.21178055], [91.85351563, 24.21198845], [91.85305786, 24.21207428], [91.85274506, 24.21220016], [91.85249329, 24.21238136], [91.85197449, 24.2130127], [91.85168457, 24.21326256], [91.85137939, 24.21332359], [91.8509903, 24.21335411], [91.85083008, 24.21336555], [91.85038757, 24.21328354], [91.8500824, 24.21307755], [91.84976196, 24.21289063], [91.84960175, 24.21254921], [91.84957886, 24.21219444], [91.84964752, 24.21181679], [91.84979248, 24.21151543], [91.85023499, 24.21088982], [91.85055542, 24.21038818], [91.85103607, 24.20993042], [91.85147858, 24.20952988], [91.85178375, 24.20925713], [91.85198975, 24.20900726], [91.85206604, 24.20874405], [91.85204315, 24.2085762], [91.85202789, 24.20843315], [91.8518219, 24.20795059], [91.85155487, 24.20780182], [91.85131836, 24.20779991], [91.85105896, 24.20794106], [91.85060883, 24.20840263], [91.8503418, 24.20870972], [91.85018158, 24.20886803], [91.84966278, 24.20892334], [91.84934235, 24.20876312], [91.84928894, 24.20868683], [91.8491745, 24.20852852], [91.84902954, 24.20810509], [91.84880829, 24.20701408], [91.85043335, 24.20709229], [91.85018921, 24.2044487], [91.84991455, 24.20227051], [91.84962463, 24.20200729], [91.84750366, 24.20004082], [91.84742737, 24.20004082], [91.84662628, 24.20004272], [91.84614563, 24.20094299], [91.84600067, 24.20072556], [91.84580231, 24.20078278], [91.84521484, 24.20120239], [91.84455109, 24.20182228], [91.84409332, 24.20204353], [91.84392548, 24.20212555], [91.84342957, 24.20215988], [91.84283447, 24.20210266], [91.84226227, 24.20183754], [91.84190369, 24.20148087], [91.84194183, 24.2011013], [91.84211731, 24.20078659], [91.84244537, 24.20063972], [91.84277344, 24.2005806], [91.84326172, 24.20044327], [91.84371185, 24.20026207], [91.84391785, 24.20009041], [91.84413147, 24.19987488], [91.84429932, 24.19956779], [91.84436035, 24.19911575], [91.84363556, 24.19763374], [91.84379578, 24.19744873], [91.84383392, 24.19734001], [91.84388733, 24.19706154], [91.84391785, 24.19687653], [91.84404755, 24.19669533], [91.84420013, 24.19669533], [91.84427643, 24.19673538], [91.84423828, 24.1968708], [91.84422302, 24.19700813], [91.84415436, 24.19717979], [91.84422302, 24.19727325], [91.84434509, 24.19742966], [91.84456635, 24.19753265], [91.84474945, 24.19756317], [91.84484863, 24.19758034], [91.84508514, 24.19757271], [91.84518433, 24.1974926], [91.84526062, 24.19736862], [91.84519958, 24.19709587], [91.84506989, 24.1968441], [91.84487915, 24.1965332], [91.8447876, 24.19628525], [91.84474182, 24.19605064], [91.84470367, 24.19584274], [91.84474945, 24.19569016], [91.844841, 24.19562721], [91.84497833, 24.19553566], [91.84515381, 24.19557571], [91.84518433, 24.19571114], [91.84524536, 24.19581985], [91.84532166, 24.19607544], [91.84539032, 24.19614983], [91.84549713, 24.19614983], [91.84560394, 24.1961174], [91.84563446, 24.19589615], [91.84560394, 24.19563675], [91.84555817, 24.19542503], [91.84550476, 24.19517899], [91.84560394, 24.19511414], [91.84581757, 24.19536209], [91.84599304, 24.1955471], [91.846138, 24.19543076], [91.84619141, 24.19534302], [91.84615326, 24.19519615], [91.84615326, 24.19503021], [91.84615326, 24.1947403], [91.84611511, 24.19446373], [91.846138, 24.19436836], [91.84608459, 24.19408226], [91.84603882, 24.19380188], [91.84606171, 24.19370079], [91.84631348, 24.19363403], [91.84647369, 24.19368362], [91.84667969, 24.1936245], [91.84690094, 24.19353676], [91.84700775, 24.1934433], [91.84711456, 24.19324684], [91.84713745, 24.19314575], [91.84703064, 24.1930542], [91.8469162, 24.19298744], [91.84672546, 24.19296455], [91.84645081, 24.19302559], [91.84623718, 24.19313049], [91.84609222, 24.19304848], [91.84610748, 24.19297218], [91.84633636, 24.19270134], [91.84648132, 24.19252396], [91.84658813, 24.1923542], [91.84661102, 24.19228363], [91.84666443, 24.1920948], [91.84662628, 24.19194984], [91.84656525, 24.19188118], [91.84616089, 24.19187164], [91.84580994, 24.19186783], [91.84552002, 24.19181442], [91.84538269, 24.19169617], [91.84535217, 24.19151115], [91.84537506, 24.19137955], [91.84567261, 24.19119263], [91.8456955, 24.19111824], [91.84562683, 24.19100571], [91.84548187, 24.19087601], [91.84546661, 24.19078636], [91.84545898, 24.19059944], [91.84531403, 24.19045639], [91.84529877, 24.19029045], [91.84523773, 24.19018364], [91.84501648, 24.19013786], [91.84499359, 24.1900692], [91.84480286, 24.18992996], [91.84494781, 24.18989372], [91.84514618, 24.18962288], [91.84536743, 24.18956947], [91.84540558, 24.18938065], [91.84549713, 24.18934441], [91.84558868, 24.18935204], [91.84576416, 24.18938828], [91.84585571, 24.18935394], [91.84600067, 24.1892662], [91.84616852, 24.18924141], [91.84625244, 24.18922997], [91.84630585, 24.18917465], [91.84638977, 24.18902397], [91.84650421, 24.18906403], [91.8466568, 24.18912125], [91.84676361, 24.18915176], [91.84677887, 24.18905067], [91.84677124, 24.18897057], [91.84676361, 24.18886566], [91.8467865, 24.18873978], [91.84692383, 24.18860626], [91.8469696, 24.18850708], [91.84707642, 24.18846703], [91.84714508, 24.18838501], [91.8471756, 24.18830109], [91.84711456, 24.18823242], [91.84719086, 24.18809319], [91.847229, 24.18802834], [91.84736633, 24.18800735], [91.84734344, 24.18790817], [91.84724426, 24.18788338], [91.8470993, 24.18772316], [91.84713745, 24.18754959], [91.84721375, 24.18747711], [91.84728241, 24.18745422], [91.84732056, 24.18737411], [91.84729004, 24.18721199], [91.84726715, 24.18713951], [91.847229, 24.18698883], [91.84727478, 24.18691635], [91.84740448, 24.18677902], [91.84751892, 24.1866951], [91.84767151, 24.18664169], [91.84779358, 24.18660164], [91.84796906, 24.18654442], [91.84793091, 24.18647385], [91.84772491, 24.18639755], [91.84747314, 24.1862812], [91.84749603, 24.18620872], [91.84761047, 24.18596649], [91.84766388, 24.18589401], [91.84789276, 24.1858902], [91.84806824, 24.18588448], [91.8480835, 24.18572998], [91.84790039, 24.18552589], [91.84786224, 24.18542671], [91.84793854, 24.18531799], [91.84793091, 24.18522835], [91.84796906, 24.18507385], [91.84797668, 24.1849556], [91.84807587, 24.18491554], [91.84816742, 24.18491364], [91.84825134, 24.18500519], [91.84832764, 24.18502998], [91.84846497, 24.18512154], [91.84867096, 24.18515968], [91.84877014, 24.18526459], [91.84886932, 24.18532944], [91.84899902, 24.18539238], [91.84925079, 24.18541336], [91.84923553, 24.18520546], [91.84919739, 24.18506241], [91.84921265, 24.18492889], [91.84934998, 24.18486404], [91.84923553, 24.18460846], [91.8493576, 24.18448639], [91.84949493, 24.18441582], [91.84958649, 24.18429375], [91.84967041, 24.18420792], [91.84976959, 24.18411636], [91.84989166, 24.18401718], [91.84992218, 24.18390846], [91.84978485, 24.18374825], [91.84976959, 24.18361282], [91.84979248, 24.18347549], [91.84985352, 24.18340302], [91.84996796, 24.18334579], [91.85019684, 24.18336678], [91.85030365, 24.18313217], [91.85019684, 24.18308067], [91.85018921, 24.18286705], [91.85041809, 24.18273926], [91.85049438, 24.18268776], [91.85055542, 24.18250275], [91.85110474, 24.18247223], [91.85119629, 24.18245697], [91.85114288, 24.18228912], [91.85101318, 24.18221855], [91.85098267, 24.18210793], [91.85105133, 24.18198967], [91.8511734, 24.1819458], [91.85126495, 24.18197632], [91.85144806, 24.18194771], [91.85160065, 24.18201828], [91.85173035, 24.18209457], [91.85185242, 24.18206596], [91.85186768, 24.18198013], [91.85198212, 24.18185043], [91.8521347, 24.1817627], [91.8522644, 24.18170738], [91.85234833, 24.18177032], [91.85237122, 24.18188858], [91.85227966, 24.18202972], [91.85225677, 24.18223953], [91.85246277, 24.18235207], [91.85253143, 24.18240166], [91.85275269, 24.18246841], [91.85286713, 24.18254471], [91.85283661, 24.18270302], [91.85287476, 24.18281174], [91.85301208, 24.18286896], [91.85306549, 24.18280792], [91.85312653, 24.18271637], [91.85320282, 24.18269348], [91.85325623, 24.18275261], [91.85340118, 24.18285561], [91.85354614, 24.18281555], [91.85362244, 24.18278122], [91.85383606, 24.18287659], [91.85391998, 24.18291092], [91.85387421, 24.18305397], [91.85391235, 24.18314934], [91.85411072, 24.18330383], [91.85413361, 24.18343925], [91.85415649, 24.18359184], [91.85424042, 24.18352509], [91.85434723, 24.18343925], [91.85442352, 24.18338013], [91.854599, 24.18325806], [91.85466003, 24.18317604], [91.85475159, 24.18305397], [91.85487366, 24.18299294], [91.85503387, 24.18294334], [91.85520935, 24.18308449], [91.8553009, 24.18317223], [91.85535431, 24.18322372], [91.85547638, 24.18329811], [91.85566711, 24.18328285], [91.85572815, 24.1831913], [91.85574341, 24.18310738], [91.85562897, 24.18302917], [91.85548401, 24.18294334], [91.85522461, 24.18286705], [91.85526276, 24.18274117], [91.85535431, 24.18262863], [91.8556366, 24.1825676], [91.85583496, 24.18255615], [91.85592651, 24.1824894], [91.85592651, 24.18241501], [91.85579681, 24.1822834], [91.85570526, 24.1822319], [91.85559082, 24.18217659], [91.85535431, 24.18205833], [91.85540009, 24.18196487], [91.85544586, 24.18188286], [91.85545349, 24.18177223], [91.85553741, 24.18159294], [91.85565186, 24.1816082], [91.85577393, 24.18173027], [91.85596466, 24.18168449], [91.85607147, 24.1817646], [91.85618591, 24.18177414], [91.85637665, 24.1817894], [91.85646057, 24.18183708], [91.85652161, 24.1819191], [91.85662079, 24.18204689], [91.85666656, 24.18216133], [91.85663605, 24.18235016], [91.85673523, 24.18241501], [91.85689545, 24.18238068], [91.85699463, 24.18230057], [91.85710144, 24.18194199], [91.85719299, 24.18194771], [91.8574295, 24.18206978], [91.85758972, 24.18210793], [91.85784912, 24.1819191], [91.85788727, 24.18173599], [91.85796356, 24.18151855], [91.85809326, 24.18148422], [91.85927582, 24.18155479], [91.85939789, 24.18177414], [91.85949707, 24.18182182], [91.85974121, 24.18194008], [91.85997009, 24.18197632], [91.86018372, 24.18177795], [91.86029816, 24.18161583], [91.8604126, 24.18162155], [91.86044312, 24.18172646], [91.86051178, 24.18205643], [91.86054993, 24.1821785], [91.86061859, 24.18222809], [91.86081696, 24.18232727], [91.86074066, 24.1825161], [91.86071014, 24.18261147], [91.86064911, 24.18283272], [91.86063385, 24.18290329], [91.86071014, 24.18294907], [91.86083984, 24.18300819], [91.86112976, 24.18289375], [91.86136627, 24.18273544], [91.86146545, 24.18265152], [91.86157227, 24.18252754], [91.86138153, 24.18234253], [91.86136627, 24.18225288], [91.86136627, 24.18207741], [91.86121368, 24.18195343], [91.86109161, 24.18181419], [91.86099243, 24.18165588], [91.86128235, 24.18165398], [91.8613739, 24.18180084], [91.86151123, 24.18196869], [91.86165619, 24.18196106], [91.86177826, 24.1818924], [91.86185455, 24.18175888], [91.86199188, 24.18172264], [91.86206818, 24.18195343], [91.86212158, 24.182024], [91.86221313, 24.18200684], [91.86232758, 24.18194962], [91.86244965, 24.18188667], [91.86244965, 24.18164635], [91.86256409, 24.1816349], [91.86270905, 24.18150139], [91.86282349, 24.18161392], [91.86318207, 24.18140602], [91.86338806, 24.18135071], [91.86374664, 24.18123627], [91.86378479, 24.18112755], [91.86373138, 24.18107796], [91.86360168, 24.18101883], [91.8635025, 24.18089294], [91.86345673, 24.18081093], [91.86385345, 24.18041039], [91.86399078, 24.18031502], [91.86418152, 24.18013954], [91.86437225, 24.1802063], [91.86453247, 24.18021965], [91.86457062, 24.18029022], [91.86474609, 24.18033409], [91.86485291, 24.18032265], [91.8650589, 24.18016434], [91.86508942, 24.17995644], [91.86512756, 24.17975235], [91.86504364, 24.17957497], [91.86493683, 24.17943954], [91.86486053, 24.17930603], [91.86479187, 24.17907333], [91.86478424, 24.17889214], [91.86491394, 24.1787281], [91.86500549, 24.17864418], [91.86511993, 24.17851257], [91.86517334, 24.17835999], [91.86527252, 24.17821312], [91.86542511, 24.17810822], [91.86575317, 24.1780014], [91.86582184, 24.17795563], [91.86598206, 24.17782974], [91.86611938, 24.17774963], [91.86617279, 24.17767334], [91.86599731, 24.17752075], [91.86595154, 24.17734718], [91.86606598, 24.17735291], [91.86631012, 24.17737198], [91.86647034, 24.17727661], [91.86643219, 24.17719078], [91.86634064, 24.1771431], [91.8662796, 24.17704964], [91.86613464, 24.17692184], [91.86602783, 24.17686462], [91.86601257, 24.17676353], [91.86603546, 24.17666626], [91.86612701, 24.17661285], [91.86639404, 24.17657852], [91.86655426, 24.17657661], [91.86677551, 24.1765976], [91.86706543, 24.17675018], [91.86713409, 24.17687988], [91.86721802, 24.17707062], [91.8673172, 24.177248], [91.86738586, 24.17737007], [91.86745453, 24.17747688], [91.86764526, 24.17762375], [91.86774445, 24.17756081], [91.86772919, 24.17719841], [91.86775208, 24.1769619], [91.86785889, 24.17689323], [91.8678894, 24.17676926], [91.86833191, 24.17656326], [91.86855316, 24.17658234], [91.86863708, 24.17663383], [91.86853027, 24.17671204], [91.8684082, 24.17677689], [91.86844635, 24.17690086], [91.86858368, 24.17695618], [91.86872864, 24.17696381], [91.86901855, 24.1771965], [91.86919403, 24.17733002], [91.86927795, 24.17733574], [91.86941528, 24.177248], [91.86888123, 24.17695808], [91.86880493, 24.17691803], [91.86891174, 24.17685318], [91.86909485, 24.17686653], [91.86919403, 24.17698288], [91.86927032, 24.17690277], [91.86933899, 24.17676353], [91.86943817, 24.17660713], [91.86974335, 24.17648506], [91.86989594, 24.17654228], [91.87011719, 24.17661858], [91.87029266, 24.17663383], [91.87033081, 24.17643547], [91.87026215, 24.17619324], [91.87029266, 24.17612076], [91.87030792, 24.1759491], [91.87030792, 24.17584801], [91.87029266, 24.17570496], [91.87083435, 24.17520523], [91.87088776, 24.17515564], [91.87099457, 24.17519188], [91.87111664, 24.1751461], [91.87127686, 24.17506218], [91.87133026, 24.174963], [91.87138367, 24.1747036], [91.87145996, 24.17463303], [91.8715744, 24.17468071], [91.87166595, 24.1746254], [91.8718338, 24.17463875], [91.87201691, 24.17471695], [91.87207794, 24.17496872], [91.87213135, 24.17504501], [91.87220764, 24.17511368], [91.87226868, 24.17522621], [91.87233734, 24.17534447], [91.8724823, 24.17546844], [91.87255096, 24.17530823], [91.87260437, 24.17524147], [91.87277222, 24.17505646], [91.87293243, 24.17487717], [91.8731308, 24.17468834], [91.87322998, 24.17459106], [91.87335968, 24.17457008], [91.8734436, 24.17461205], [91.87369537, 24.17461967], [91.87381744, 24.17464638], [91.87391663, 24.17461777], [91.87388611, 24.17446899], [91.87380219, 24.17447662], [91.87371826, 24.17448425], [91.87354279, 24.17451668], [91.87352753, 24.1744442], [91.87358856, 24.17438126], [91.87376404, 24.17422485], [91.87397003, 24.1740036], [91.87380981, 24.17373276], [91.87377167, 24.17366791], [91.87385559, 24.17363358], [91.87397003, 24.17353058], [91.87378693, 24.17335892], [91.87369537, 24.17303848], [91.87361145, 24.1728611], [91.87364197, 24.17271996], [91.87345886, 24.17268753], [91.87332153, 24.17277908], [91.87322235, 24.17284393], [91.87306213, 24.17292213], [91.8730011, 24.17269707], [91.87306213, 24.17259979], [91.87316132, 24.17246819], [91.87321472, 24.17240334], [91.87336731, 24.17239571], [91.87359619, 24.17232704], [91.87368011, 24.1723156], [91.87388611, 24.17228699], [91.87410736, 24.17235947], [91.87418365, 24.17229652], [91.87423706, 24.1721096], [91.87419891, 24.17200089], [91.87403107, 24.17194557], [91.87389374, 24.17188835], [91.87381744, 24.17185211], [91.87373352, 24.17198753], [91.87350464, 24.17206955], [91.87336731, 24.17191696], [91.8733902, 24.17177963], [91.87361145, 24.17171669], [91.87362671, 24.17162895], [91.87358856, 24.17149734], [91.87343597, 24.17119789], [91.8734436, 24.17111969], [91.87362671, 24.17106438], [91.87384033, 24.17096901], [91.87397003, 24.17097855], [91.87406921, 24.17103767], [91.87387848, 24.17118454], [91.87379456, 24.17124939], [91.873703, 24.17137718], [91.87393188, 24.17158508], [91.87400055, 24.17155266], [91.87401581, 24.17137909], [91.87406158, 24.1713047], [91.87432098, 24.17124748], [91.87441254, 24.1713028], [91.87450409, 24.17148209], [91.87460327, 24.17154694], [91.87481689, 24.17152214], [91.875, 24.17148018], [91.87516785, 24.17144203], [91.87541962, 24.17141342], [91.87549591, 24.17127609], [91.87545013, 24.17115593], [91.87535858, 24.1710453], [91.87521362, 24.17099762], [91.87505341, 24.1709404], [91.87510681, 24.17055511], [91.87507629, 24.17032814], [91.87515259, 24.17030144], [91.87533569, 24.1703167], [91.87538147, 24.17043877], [91.87539673, 24.17050934], [91.8754425, 24.17058182], [91.87559509, 24.17056084], [91.87583923, 24.1705246], [91.87595367, 24.17043304], [91.87601471, 24.17038155], [91.87609863, 24.17037201], [91.87608337, 24.17027664], [91.87588501, 24.17022896], [91.87586975, 24.16992188], [91.87595367, 24.16991615], [91.87620544, 24.1699543], [91.87625122, 24.16989708], [91.87599182, 24.16968536], [91.87585449, 24.16961479], [91.87571716, 24.16958046], [91.87550354, 24.16952515], [91.87526703, 24.16938782], [91.87509155, 24.16937637], [91.87491608, 24.16941643], [91.87483215, 24.16945839], [91.87477875, 24.16957092], [91.87471771, 24.1696682], [91.87463379, 24.16970253], [91.87454224, 24.16969109], [91.87439728, 24.16962242], [91.87432098, 24.16963577], [91.8742218, 24.16965294], [91.87405396, 24.16968536], [91.87402344, 24.16946983], [91.87412262, 24.16936493], [91.87402344, 24.16913795], [91.87393951, 24.16912079], [91.87382507, 24.16909409], [91.87371063, 24.16900253], [91.87369537, 24.1688633], [91.87373352, 24.16870499], [91.87391663, 24.16847801], [91.87397766, 24.16832352], [91.87386322, 24.16824341], [91.87366486, 24.1682415], [91.87345886, 24.16830254], [91.87339783, 24.16822052], [91.87329865, 24.16802025], [91.87329865, 24.16788483], [91.87337494, 24.16780472], [91.87348175, 24.16785812], [91.87369537, 24.16808891], [91.87380981, 24.16806984], [91.87395477, 24.16801071], [91.87418365, 24.16784096], [91.87428284, 24.16778564], [91.87442017, 24.16775703], [91.87450409, 24.16780472], [91.87468719, 24.16781044], [91.87470245, 24.16773415], [91.87474823, 24.16763878], [91.87463379, 24.16759682], [91.87449646, 24.16748428], [91.87438965, 24.16733932], [91.87428284, 24.16711998], [91.87417603, 24.16702271], [91.87405396, 24.16697121], [91.8739624, 24.16701317], [91.87397003, 24.16720772], [91.87391663, 24.16749382], [91.8737793, 24.16747093], [91.87372589, 24.16739464], [91.87374115, 24.16719437], [91.87368774, 24.1671257], [91.87355804, 24.16699219], [91.87355042, 24.16679001], [91.87367249, 24.16669464], [91.87374878, 24.16672134], [91.87389374, 24.16658592], [91.87400055, 24.1664753], [91.87426758, 24.16653633], [91.8745575, 24.16652679], [91.87471771, 24.1665287], [91.87484741, 24.1664505], [91.87479401, 24.16620827], [91.87472534, 24.16614151], [91.87456512, 24.16612053], [91.8744812, 24.16602325], [91.87464905, 24.16594124], [91.87476349, 24.16577721], [91.87483215, 24.16547394], [91.87490082, 24.16526413], [91.87483215, 24.165205], [91.87461853, 24.16520309], [91.87459564, 24.16501808], [91.87454224, 24.164814], [91.87449646, 24.16459465], [91.87443542, 24.16433144], [91.87434387, 24.16418266], [91.87426758, 24.16391182], [91.87419128, 24.16413879], [91.87408447, 24.16412926], [91.87394714, 24.16404724], [91.87406158, 24.16372871], [91.87419128, 24.16370201], [91.87427521, 24.16367912], [91.8746109, 24.16340065], [91.8745575, 24.16333008], [91.8742218, 24.16328049], [91.87413788, 24.16326904], [91.87393951, 24.16350555], [91.8738327, 24.16351891], [91.87374115, 24.16350365], [91.873703, 24.16342545], [91.87369537, 24.16332626], [91.87379456, 24.16308594], [91.87413788, 24.16294479], [91.87422943, 24.16282845], [91.87427521, 24.1626358], [91.87438965, 24.16252136], [91.8744812, 24.16254425], [91.87457275, 24.16256714], [91.87470245, 24.16272545], [91.87477875, 24.16279793], [91.87491608, 24.16286659], [91.87499237, 24.16287041], [91.87511444, 24.16282463], [91.87493134, 24.16269684], [91.87487793, 24.16261292], [91.87482452, 24.16253281], [91.87470245, 24.16222191], [91.8746109, 24.16216087], [91.87466431, 24.16201019], [91.87475586, 24.16205978], [91.87502289, 24.16215515], [91.87507629, 24.16202736], [91.87522888, 24.16187477], [91.87538147, 24.16178513], [91.87556458, 24.16169357], [91.87579346, 24.16155434], [91.87588501, 24.16147041], [91.87599182, 24.16140175], [91.87613678, 24.16142654], [91.87633514, 24.16158104], [91.87639618, 24.16164398], [91.87657928, 24.16157532], [91.87657928, 24.16144371], [91.87654114, 24.16134453], [91.87652588, 24.16119194], [91.87651062, 24.1610508], [91.87643433, 24.16086197], [91.87644196, 24.16073418], [91.87670898, 24.16080093], [91.8768158, 24.16066551], [91.87683105, 24.16055489], [91.87680817, 24.16042709], [91.87662506, 24.16041565], [91.87657166, 24.16049004], [91.87644196, 24.16054916], [91.87631989, 24.16044617], [91.87633514, 24.16034698], [91.87646484, 24.16009331], [91.87636566, 24.16001701], [91.87617493, 24.16006088], [91.87612915, 24.15998268], [91.87624359, 24.15993118], [91.87618256, 24.15983772], [91.87606812, 24.15974617], [91.87595367, 24.15968704], [91.87596893, 24.15957832], [91.87607574, 24.15950584], [91.87619019, 24.15939522], [91.8764267, 24.15931129], [91.87644958, 24.15916634], [91.87625885, 24.15919685], [91.8761673, 24.15907478], [91.87634277, 24.15896034], [91.87649536, 24.15888405], [91.87679291, 24.15895653], [91.87689972, 24.1588974], [91.8767395, 24.1587162], [91.87683105, 24.15853691], [91.87680817, 24.15841103], [91.87656403, 24.15840149], [91.87637329, 24.15845299], [91.87634277, 24.15837288], [91.8764267, 24.15831947], [91.8766098, 24.15820313], [91.87669373, 24.15811729], [91.87686157, 24.1580677], [91.87692261, 24.15781212], [91.8771286, 24.15787315], [91.87719727, 24.15784454], [91.87723541, 24.15769386], [91.8769989, 24.15763664], [91.87693024, 24.15745354], [91.87661743, 24.15739441], [91.87660217, 24.15727615], [91.87666321, 24.15707397], [91.87663269, 24.15695953], [91.87638855, 24.1569252], [91.87617493, 24.1567173], [91.87623596, 24.15654564], [91.87599182, 24.15649223], [91.87599182, 24.15641403], [91.8759079, 24.15637589], [91.87730408, 24.15428543], [91.87734222, 24.15422249], [91.87740326, 24.15397835], [91.87744904, 24.15410233], [91.87758636, 24.15397072], [91.87758636, 24.15368271], [91.87757874, 24.15325165], [91.87760162, 24.15316963], [91.87762451, 24.15307999], [91.87772369, 24.15306091], [91.87792206, 24.15300179], [91.87779236, 24.15288925], [91.87788391, 24.1528492], [91.87808228, 24.15280724], [91.8780899, 24.15267754], [91.87807465, 24.15234947], [91.87804413, 24.15217781], [91.87809753, 24.1521244], [91.87824249, 24.1522274], [91.87836456, 24.15237617], [91.8784256, 24.15230942], [91.87836456, 24.15218163], [91.87831879, 24.15210342], [91.87831116, 24.1520195], [91.87853241, 24.15187645], [91.87856293, 24.15180588], [91.878479, 24.15178108], [91.87839508, 24.1517868], [91.87836456, 24.15151024], [91.8786087, 24.1516304], [91.87876129, 24.15175438], [91.87885284, 24.15182304], [91.87901306, 24.15163803], [91.87890625, 24.15151787], [91.87869263, 24.15141678], [91.87867737, 24.15134621], [91.87888336, 24.15119362], [91.87901306, 24.15104294], [91.87898254, 24.15096664], [91.87885284, 24.1510067], [91.87873077, 24.15106773], [91.87847137, 24.1512661], [91.87839508, 24.15119362], [91.87837982, 24.15112305], [91.87844849, 24.15084076], [91.87847137, 24.15069199], [91.87834167, 24.15071106], [91.8781662, 24.1509304], [91.87822723, 24.15056038], [91.87825775, 24.15030861], [91.87809753, 24.15016937], [91.87796783, 24.15011978], [91.87799072, 24.15003777], [91.87812042, 24.15005684], [91.87828064, 24.15015793], [91.87843323, 24.15005302], [91.87831116, 24.14988899], [91.87822723, 24.14972687], [91.87812042, 24.14964676], [91.8783493, 24.14950752], [91.87828064, 24.14943314], [91.87825775, 24.14912796], [91.87838745, 24.14915657], [91.87850189, 24.14918137], [91.87879944, 24.14916611], [91.87883759, 24.14897919], [91.87874603, 24.14894676], [91.8785553, 24.14889526], [91.87841797, 24.14878654], [91.87844086, 24.14846802], [91.87837219, 24.14838219], [91.87846375, 24.14812469], [91.87836456, 24.14805984], [91.87817383, 24.14811134], [91.87797546, 24.14805222], [91.8779068, 24.14799881], [91.87783813, 24.1479454], [91.87787628, 24.14785576], [91.8780365, 24.14779472], [91.87815094, 24.14772987], [91.87827301, 24.14770889], [91.87844849, 24.14766312], [91.87848663, 24.14758682], [91.87837219, 24.14749908], [91.87828827, 24.14743233], [91.87828827, 24.14731026], [91.87837982, 24.14728737], [91.8786087, 24.14733315], [91.87882233, 24.14735413], [91.87883759, 24.14745903], [91.87882996, 24.14761543], [91.87897491, 24.1476593], [91.87911224, 24.14739227], [91.87910461, 24.14722443], [91.87909698, 24.14691925], [91.87897491, 24.1468792], [91.87865448, 24.1468544], [91.87853241, 24.14683533], [91.87847137, 24.1467762], [91.87850952, 24.14666939], [91.87849426, 24.14655876], [91.87857819, 24.14643669], [91.87862396, 24.14634895], [91.87875366, 24.14622307], [91.87905121, 24.1462326], [91.87910461, 24.14612579], [91.87917328, 24.14603424], [91.87918854, 24.14595795], [91.87939453, 24.14582443], [91.87947083, 24.14572144], [91.87969208, 24.14540291], [91.87973022, 24.14534187], [91.87983704, 24.14532852], [91.88009644, 24.14563751], [91.88018036, 24.14575958], [91.88022614, 24.14582443], [91.88035583, 24.14596367], [91.88058472, 24.14587593], [91.88082886, 24.14592552], [91.88095093, 24.14595795], [91.88109589, 24.14599419], [91.88118744, 24.14595032], [91.8811264, 24.14582062], [91.88153076, 24.14550781], [91.8818512, 24.14486122], [91.88199615, 24.14487839], [91.88195801, 24.14464569], [91.88234711, 24.14385796], [91.88253784, 24.14396858], [91.88260651, 24.14404678], [91.88282013, 24.14391136], [91.88301849, 24.14370728], [91.8832016, 24.14347076], [91.8833847, 24.14333725], [91.88354492, 24.14326668], [91.8835907, 24.14320374], [91.88362122, 24.1431179], [91.88365173, 24.14286804], [91.88365936, 24.1427536], [91.88368988, 24.14262581], [91.88392639, 24.14272118], [91.88414764, 24.14289093], [91.88430023, 24.14277077], [91.88437653, 24.14271355], [91.8844223, 24.14251518], [91.88420868, 24.14238167], [91.88405609, 24.14228249], [91.88394165, 24.14215088], [91.88389587, 24.14176559], [91.88396454, 24.1416626], [91.8841629, 24.14157486], [91.88431549, 24.14147186], [91.88439178, 24.14134026], [91.88441467, 24.14125633], [91.88435364, 24.14113998], [91.88430023, 24.1410141], [91.88667297, 24.13868904], [91.88681793, 24.13870239], [91.88696289, 24.13872147], [91.88728333, 24.13872719], [91.88782501, 24.13856125], [91.8879776, 24.13855362], [91.88807678, 24.13857269], [91.88816071, 24.13866615], [91.88820648, 24.13872337], [91.88835907, 24.13899994], [91.88871002, 24.13900185], [91.88894653, 24.13898277], [91.88903046, 24.13891411], [91.88909149, 24.13882828], [91.88913727, 24.13876152], [91.88923645, 24.13859177], [91.88931274, 24.13838577], [91.88925171, 24.13831329], [91.88910675, 24.13821602], [91.88898468, 24.1381588], [91.88900757, 24.13807678], [91.88916779, 24.13799095], [91.88954926, 24.13793755], [91.88964081, 24.13792038], [91.88977051, 24.13781929], [91.88977051, 24.13756371], [91.88980103, 24.13741302], [91.89190674, 24.13787842], [91.89302063, 24.13878059], [91.89315033, 24.1388855], [91.89447021, 24.13994026], [91.89569092, 24.14007568], [91.8972168, 24.13948822], [91.89730072, 24.1394558], [91.89753723, 24.13936234], [91.89775085, 24.13956833], [91.89782715, 24.13960838], [91.8980484, 24.13955307], [91.89815521, 24.13947678], [91.89822388, 24.13943672], [91.89839935, 24.13935471], [91.89846039, 24.1392746], [91.89945221, 24.13866615], [91.90192413, 24.13714409], [91.90216064, 24.13710213], [91.90228271, 24.13788986], [91.90254974, 24.13783836], [91.90273285, 24.13799286], [91.90349579, 24.13851166], [91.90364838, 24.13861465], [91.90436554, 24.13856506], [91.90488434, 24.13864517], [91.90502167, 24.13876534], [91.90527344, 24.13891411], [91.90570068, 24.13881493], [91.90591431, 24.13934708], [91.90579224, 24.13951492], [91.90589905, 24.13975906], [91.90586853, 24.14001083], [91.90583801, 24.14010811], [91.90581512, 24.14020157], [91.90544128, 24.14091873], [91.90568542, 24.14127541], [91.90588379, 24.14161301], [91.9056778, 24.14178467], [91.9056778, 24.14196205], [91.90605927, 24.14193535], [91.90616608, 24.14202499], [91.90596771, 24.14229965], [91.90582275, 24.14250183], [91.90553284, 24.14255524], [91.90544891, 24.14270401], [91.90576935, 24.14289665], [91.90605164, 24.14295387], [91.90612793, 24.14296722], [91.90608215, 24.14307785], [91.90605927, 24.14321709], [91.90592957, 24.14321899], [91.9058609, 24.14349556], [91.90603638, 24.14367867], [91.90609741, 24.14374161], [91.90616608, 24.14382553], [91.90604401, 24.14391708], [91.90585327, 24.14405823], [91.90592957, 24.14439964], [91.90576935, 24.1445446], [91.90593719, 24.14484215], [91.90600586, 24.1449604], [91.90638733, 24.14507675], [91.90670013, 24.14545059], [91.90726471, 24.14571953], [91.90763855, 24.14575768], [91.90774536, 24.14592361], [91.90764618, 24.14612389], [91.90789795, 24.14625168], [91.90828705, 24.14608574], [91.90859222, 24.1460743], [91.90869904, 24.14608574], [91.90877533, 24.14609146], [91.90890503, 24.14608002], [91.90899658, 24.14618683], [91.90971375, 24.14645004], [91.9099884, 24.14648056], [91.91012573, 24.14646912], [91.9101944, 24.14661598], [91.91020203, 24.14673042], [91.90984344, 24.14673233], [91.90979767, 24.14689255], [91.90974426, 24.1470108], [91.90976715, 24.14717293], [91.91009521, 24.14718819], [91.91011047, 24.14731979], [91.90996552, 24.14748192], [91.90981293, 24.14776039], [91.90996552, 24.14809418], [91.91039276, 24.14824867], [91.91087341, 24.14843559], [91.91106415, 24.14851189], [91.91103363, 24.14872742], [91.91095734, 24.14886284], [91.91090393, 24.14897156], [91.91101074, 24.14904213], [91.91114807, 24.14910507], [91.91121674, 24.14917564], [91.91120148, 24.1492672], [91.91088867, 24.14936066], [91.91069031, 24.14941978], [91.91051483, 24.14975357], [91.91044617, 24.14989471], [91.91036987, 24.14999008], [91.91034698, 24.15006065], [91.91027832, 24.15042686], [91.91014099, 24.1503849], [91.91000366, 24.15037918], [91.90985107, 24.15037346], [91.9095993, 24.15066147], [91.90962219, 24.15076065], [91.90974426, 24.15091896], [91.90994263, 24.1510601], [91.9103241, 24.15133667], [91.9106369, 24.15145111], [91.91110229, 24.15224648], [91.91093445, 24.15226555], [91.91104126, 24.15255356], [91.91105652, 24.15268517], [91.91110229, 24.15315819], [91.91133118, 24.15371895], [91.91145325, 24.15373802], [91.91160583, 24.15373993], [91.91171265, 24.15370178], [91.91177368, 24.15363312], [91.9118576, 24.15355873], [91.91202545, 24.15341568], [91.91225433, 24.15329933], [91.91259766, 24.15337944], [91.91321564, 24.15339088], [91.91348267, 24.15340996], [91.91365051, 24.15344048], [91.91383362, 24.15351677], [91.91392517, 24.15354347], [91.91417694, 24.15360832], [91.91437531, 24.15363121], [91.91443634, 24.15368462], [91.91447449, 24.15376854], [91.91443634, 24.15386772], [91.91432953, 24.15397072], [91.9141922, 24.15401459], [91.91410065, 24.15407562], [91.91395569, 24.15408516], [91.91382599, 24.15403366], [91.91370392, 24.15398407], [91.91355133, 24.15392685], [91.913414, 24.15394592], [91.91314697, 24.15392494], [91.91299438, 24.15393639], [91.91293335, 24.15402412], [91.91288757, 24.15413094], [91.91280365, 24.15433121], [91.9127655, 24.15457153], [91.91274261, 24.15467453], [91.91278076, 24.15476036], [91.91287231, 24.15480995], [91.91300201, 24.15488434], [91.91319275, 24.15498924], [91.91326904, 24.15502357], [91.91345215, 24.15505791], [91.91359711, 24.15506935], [91.9136734, 24.1550808], [91.91378021, 24.15508461], [91.91391754, 24.15507698], [91.91402435, 24.1550808], [91.91410828, 24.15515327], [91.91416168, 24.1552906], [91.91408539, 24.15542793], [91.91400909, 24.15546608], [91.91390228, 24.15546989], [91.91369629, 24.15543556], [91.91347504, 24.15534782], [91.91322327, 24.15543175], [91.91300201, 24.15575218], [91.91312408, 24.15587425], [91.91326141, 24.1559906], [91.91357422, 24.15610504], [91.91365051, 24.15613365], [91.91381836, 24.15622902], [91.91371155, 24.15642166], [91.91348267, 24.15666008], [91.91339874, 24.15683556], [91.91334534, 24.15699196], [91.91321564, 24.15731812], [91.91314697, 24.15751266], [91.91321564, 24.15769196], [91.91344452, 24.15769768], [91.91372681, 24.15770912], [91.91390228, 24.15771675], [91.91404724, 24.1577549], [91.91414642, 24.15776634], [91.91429901, 24.15789604], [91.91434479, 24.15803146], [91.91418457, 24.15812874], [91.91392517, 24.15811539], [91.91365051, 24.15820313], [91.9136734, 24.15829086], [91.91373444, 24.15842819], [91.91373444, 24.15858841], [91.91370392, 24.15878105], [91.91378784, 24.15893745], [91.91374207, 24.15907478], [91.91369629, 24.15929985], [91.9138031, 24.15934753], [91.91395569, 24.15941048], [91.91411591, 24.15947533], [91.91414642, 24.1595459], [91.91392517, 24.15972519], [91.91379547, 24.159832], [91.91370392, 24.1598835], [91.91320801, 24.16003418], [91.91333771, 24.16011429], [91.91349792, 24.16023636], [91.913414, 24.16034126], [91.91320801, 24.16028023], [91.91311646, 24.16022873], [91.91303253, 24.16020966], [91.91298676, 24.16030121], [91.91296387, 24.16049576], [91.91285706, 24.16067505], [91.91278076, 24.16079903], [91.91269684, 24.16083336], [91.91260529, 24.16086197], [91.91247559, 24.16094971], [91.91259003, 24.1610527], [91.91279602, 24.16119385], [91.91278076, 24.16156197], [91.91282654, 24.16165161], [91.9130249, 24.16166496], [91.91329193, 24.16168022], [91.91352081, 24.16164017], [91.91363525, 24.16166687], [91.91358185, 24.16174889], [91.91352081, 24.16179848], [91.913414, 24.16181946], [91.9132309, 24.16186333], [91.91313171, 24.16189194], [91.91309357, 24.16195869], [91.91307068, 24.16203117], [91.91318512, 24.16214561], [91.91331482, 24.16223717], [91.91350555, 24.16230965], [91.91362762, 24.16230774], [91.91374969, 24.1622982], [91.91386414, 24.16233253], [91.91381073, 24.16247177], [91.91368866, 24.16251183], [91.9135437, 24.16257668], [91.91344452, 24.16255188], [91.91335297, 24.16258621], [91.91336823, 24.16271019], [91.91343689, 24.16275597], [91.91339874, 24.16287613], [91.91330719, 24.16293716], [91.91319275, 24.16297913], [91.9131012, 24.16300774], [91.91296387, 24.16313934], [91.91288757, 24.16323853], [91.91285706, 24.16333199], [91.91278839, 24.16339684], [91.91270447, 24.16341209], [91.91261292, 24.16337776], [91.91253662, 24.16334915], [91.91236877, 24.16337013], [91.91230774, 24.16345978], [91.9122467, 24.16350365], [91.91212463, 24.16347313], [91.91184998, 24.16349792], [91.91182709, 24.1635952], [91.91170502, 24.16371155], [91.91162109, 24.1638546], [91.91147614, 24.16400719], [91.91133881, 24.16413307], [91.91137695, 24.16423798], [91.91156769, 24.16426659], [91.91172028, 24.16430473], [91.9118042, 24.1642952], [91.91199493, 24.16439438], [91.91217041, 24.16444397], [91.91226959, 24.16443062], [91.91248322, 24.16446686], [91.91271973, 24.16463661], [91.91287231, 24.16475105], [91.91281128, 24.16491508], [91.91275787, 24.16507339], [91.91267395, 24.16520882], [91.91274261, 24.16534042], [91.91273499, 24.16544724], [91.91281128, 24.16551208], [91.91303253, 24.16562653], [91.91319275, 24.16570473], [91.91330719, 24.16574287], [91.91358948, 24.16581154], [91.91382599, 24.16583633], [91.91407776, 24.16587257], [91.9140625, 24.16608429], [91.9140625, 24.16621017], [91.91416168, 24.16634178], [91.91421509, 24.16642952], [91.91431427, 24.16646004], [91.91446686, 24.16638184], [91.91453552, 24.16634941], [91.91468811, 24.16628265], [91.9148407, 24.16623116], [91.91487122, 24.16674805], [91.91469574, 24.1668396], [91.9145813, 24.16693497], [91.91446686, 24.16689873], [91.91432953, 24.16681099], [91.91425323, 24.16683197], [91.91411591, 24.16695213], [91.91405487, 24.16705894], [91.91399384, 24.16716385], [91.91401672, 24.16724586], [91.91400909, 24.16735649], [91.91399384, 24.16750145], [91.91395569, 24.16760445], [91.91385651, 24.1675663], [91.91366577, 24.16757011], [91.91353607, 24.16767502], [91.91347504, 24.16773033], [91.9133606, 24.16782188], [91.9131012, 24.16781616], [91.91293335, 24.16786194], [91.91269684, 24.16794586], [91.91255951, 24.16806793], [91.9123764, 24.16810608], [91.91214752, 24.16817284], [91.91207123, 24.1683445], [91.91200256, 24.16849518], [91.9119339, 24.16853523], [91.91184998, 24.16854477], [91.91177368, 24.1684742], [91.91171265, 24.16836929], [91.91165161, 24.16825485], [91.91158295, 24.16817665], [91.91149139, 24.1681118], [91.91137695, 24.16804314], [91.91127777, 24.16804314], [91.91132355, 24.16831589], [91.91159821, 24.16926765], [91.91188049, 24.17021561], [91.91201782, 24.17066956], [91.91218567, 24.17124176], [91.91259003, 24.17263222], [91.9132309, 24.17481232], [91.91397858, 24.17733955], [91.91466522, 24.17966461], [91.91563416, 24.18297768], [91.91623688, 24.1850071], [91.9168396, 24.18720818], [91.91796112, 24.19073677], [91.91915894, 24.19494057], [91.91938019, 24.19570541], [91.92011261, 24.19819069], [91.92071533, 24.20023346], [91.92165375, 24.20340157], [91.92241669, 24.20600319], [91.9235611, 24.20989418], [91.92453003, 24.21319389], [91.92533112, 24.21590424], [91.92583466, 24.21762466], [91.92589569, 24.21782303], [91.9259491, 24.21799278], [91.9260025, 24.21818161], [91.92605591, 24.21837044], [91.92635345, 24.2193737], [91.92682648, 24.22097588], [91.92787933, 24.22455025], [91.92867279, 24.22724342], [91.92923737, 24.22917366], [91.9296875, 24.2306881], [91.93061066, 24.23383522], [91.93105316, 24.23534012], [91.931633, 24.23730278], [91.93202972, 24.23853683], [91.93228149, 24.23950958], [91.93299866, 24.24194145], [91.93354034, 24.24377823], [91.93403625, 24.24547958], [91.93464661, 24.24755287], [91.93508148, 24.24902534], [91.93601227, 24.25217438], [91.93638611, 24.25344276], [91.93695068, 24.255373], [91.93788147, 24.25851822], [91.93860626, 24.2610054], [91.93910217, 24.26266289], [91.93990326, 24.26538658], [91.94074249, 24.26823807], [91.93998718, 24.27076149], [91.93972778, 24.27161407], [91.93942261, 24.27262688], [91.9391098, 24.27366638], [91.93849182, 24.27575111], [91.93758392, 24.278759], [91.93671417, 24.28166199], [91.93588257, 24.2844162], [91.93516541, 24.28680992], [91.93476868, 24.28814507], [91.93427277, 24.28977776], [91.93361664, 24.29197693], [91.93326569, 24.29313469], [91.93254089, 24.29554176], [91.93199921, 24.29734802], [91.93119049, 24.30004311], [91.93074799, 24.30151367], [91.93027496, 24.30307579], [91.93002319, 24.30392075], [91.92990875, 24.30431557], [91.92894745, 24.30748749], [91.92867279, 24.308424], [91.92803192, 24.31056023], [91.92768097, 24.31170464], [91.92741394, 24.31261253], [91.92671204, 24.3149395], [91.92604065, 24.31718636], [91.92545319, 24.31925964], [91.92498779, 24.32067108], [91.92493439, 24.32083321], [91.9249115, 24.32091713], [91.92436981, 24.3226757], [91.92382813, 24.32448387], [91.92312622, 24.32683182], [91.92284393, 24.32777596], [91.92189026, 24.33095741], [91.92160797, 24.33190918], [91.92076111, 24.33473587], [91.92045593, 24.3357563], [91.91992188, 24.3375206], [91.92028046, 24.33709335], [91.92049408, 24.33667755], [91.92070007, 24.33657455], [91.92088318, 24.33654976], [91.92098999, 24.33658791], [91.92105865, 24.336483], [91.92114258, 24.33631325], [91.92134094, 24.33621788], [91.92140961, 24.33601379], [91.92156982, 24.33586311], [91.92166901, 24.33582497], [91.921875, 24.33573532], [91.92201996, 24.33581352], [91.92211914, 24.33579826], [91.92221069, 24.33582497], [91.92227173, 24.33576584], [91.92237091, 24.33582497], [91.92254639, 24.33584785], [91.92264557, 24.33583641], [91.92279816, 24.33594131], [91.92284393, 24.33587456], [91.92295837, 24.33596992], [91.92312622, 24.33597565], [91.92312622, 24.33605957], [91.9233017, 24.33605385], [91.92343903, 24.33616066], [91.92351532, 24.33611298], [91.92360687, 24.3361187], [91.92379761, 24.33615112], [91.92385864, 24.33620071], [91.92393494, 24.33613586], [91.92407227, 24.33611679], [91.92411804, 24.33618164], [91.92409515, 24.33629799], [91.92409515, 24.33639145], [91.92423248, 24.33642197], [91.92433167, 24.33637428], [91.92434692, 24.33649063], [91.92446136, 24.33646011], [91.92453003, 24.33636093], [91.92462158, 24.3363781], [91.92464447, 24.33627129], [91.92472839, 24.33629799], [91.92469788, 24.33636665], [91.92487335, 24.33649063], [91.92504883, 24.336483], [91.92498779, 24.33639908], [91.92508698, 24.33639908], [91.92524719, 24.33653259], [91.92532349, 24.33666229], [91.92540741, 24.33660889], [91.9254837, 24.33661842], [91.92546082, 24.3367157], [91.92557526, 24.33664894], [91.9256897, 24.33670425], [91.92572784, 24.33663177], [91.92568207, 24.33655357], [91.9258728, 24.33657265], [91.92597961, 24.33656693], [91.92594147, 24.33666229], [91.9259491, 24.33687401], [91.92603302, 24.33691978], [91.92613983, 24.33716393], [91.92617035, 24.33723259], [91.92627716, 24.33728981], [91.92636108, 24.33729172], [91.92646027, 24.3374176], [91.92640686, 24.33750534], [91.92643738, 24.33771133], [91.92645264, 24.33788872], [91.92640686, 24.33798409], [91.92653656, 24.33796692], [91.92664337, 24.33805275], [91.92662048, 24.33826828], [91.92671204, 24.33832741], [91.92675781, 24.3385582], [91.92689514, 24.33840561], [91.92697144, 24.33838272], [91.92707825, 24.33845901], [91.92704773, 24.33857918], [91.92714691, 24.33864212], [91.92719269, 24.33871841], [91.92701721, 24.33889198], [91.92704773, 24.33896065], [91.92714691, 24.33894539], [91.92722321, 24.3390522], [91.92712402, 24.33917809], [91.92733765, 24.33915901], [91.92752075, 24.33918381], [91.92760468, 24.33922386], [91.92770386, 24.3393631], [91.92779541, 24.33936501], [91.92787933, 24.33943367], [91.92791748, 24.33951759], [91.92808533, 24.33951569], [91.92809296, 24.33959007], [91.92816162, 24.33964348], [91.92823029, 24.3396759], [91.92832184, 24.33971977], [91.92830658, 24.33980179], [91.92838287, 24.33979034], [91.92848969, 24.33972168], [91.92869568, 24.33971596], [91.9288559, 24.3397274], [91.929039, 24.33972931], [91.92912292, 24.33970451], [91.92933655, 24.33967018], [91.92951202, 24.33976364], [91.92959595, 24.33989525], [91.92959595, 24.33997345], [91.92967987, 24.34000969], [91.92977905, 24.33992767], [91.92990112, 24.33998108], [91.92990112, 24.33989143], [91.93002319, 24.33981895], [91.9305954, 24.34018517], [91.9307251, 24.34026909], [91.93161011, 24.34060097], [91.9316864, 24.34062958], [91.93196106, 24.34069061], [91.93203735, 24.34084129], [91.93190002, 24.34090805], [91.9320755, 24.34099388], [91.93218231, 24.34114838], [91.93206024, 24.34119225], [91.93202209, 24.34127998], [91.93216705, 24.34125519], [91.93222046, 24.34141541], [91.93235016, 24.34132957], [91.93247986, 24.34118271], [91.93270874, 24.34116364], [91.93278503, 24.34118271], [91.93297577, 24.34120178], [91.93302155, 24.3413887], [91.93309784, 24.3413887], [91.93312073, 24.34117889], [91.93312073, 24.34108543], [91.9331131, 24.3409729], [91.9331665, 24.34075165], [91.93338776, 24.34096146], [91.93344879, 24.34091568], [91.93347931, 24.34070778], [91.9335022, 24.34056473], [91.93352509, 24.34045982], [91.93358612, 24.3403511], [91.93364716, 24.34039116], [91.93367767, 24.34049606], [91.93365479, 24.34070206], [91.93372345, 24.34075737], [91.93383026, 24.34060287], [91.93408203, 24.34052849], [91.93434906, 24.34050751], [91.93440247, 24.3404541], [91.93428802, 24.34034157], [91.93437195, 24.34025383], [91.9344635, 24.34019661], [91.93445587, 24.34004784], [91.93467712, 24.34005928], [91.93480682, 24.34004593], [91.93478394, 24.33994293], [91.93481445, 24.33983994], [91.93495178, 24.33990669], [91.93516541, 24.34013748], [91.93508911, 24.3402195], [91.93500519, 24.34026527], [91.93500519, 24.34036064], [91.93507385, 24.34044647], [91.93516541, 24.34053993], [91.93517303, 24.34076118], [91.93526459, 24.34098434], [91.93543243, 24.34111786], [91.93561554, 24.3412838], [91.93569183, 24.34147263], [91.93574524, 24.34140205], [91.93582153, 24.34130669], [91.93589783, 24.34128952], [91.93595123, 24.34133911], [91.93603516, 24.34142494], [91.93619537, 24.34136391], [91.93628693, 24.3413868], [91.93653107, 24.34141731], [91.93658447, 24.34149361], [91.93637848, 24.3415947], [91.93636322, 24.34172058], [91.93649292, 24.34178543], [91.93688202, 24.34169579], [91.93681335, 24.34190941], [91.93684387, 24.34198761], [91.93704987, 24.34193039], [91.93699646, 24.34205055], [91.93713379, 24.34211731], [91.93714142, 24.3421936], [91.93709564, 24.34225845], [91.93710327, 24.34243774], [91.93743896, 24.34255028], [91.93764496, 24.34261894], [91.93753052, 24.34277534], [91.93786621, 24.34288406], [91.93796539, 24.34280777], [91.93802643, 24.34294319], [91.93805695, 24.34311485], [91.93814087, 24.34306908], [91.93825531, 24.34304619], [91.93841553, 24.34323502], [91.93833923, 24.34337807], [91.93845367, 24.34339714], [91.93859863, 24.34323883], [91.9387207, 24.34321404], [91.93888092, 24.34327507], [91.93891144, 24.34320068], [91.938797, 24.34300232], [91.94030762, 24.34350586], [91.94156647, 24.34538841], [91.94167328, 24.34554672], [91.9418335, 24.34577942], [91.94174957, 24.34598732], [91.94176483, 24.34615898], [91.94180298, 24.346241], [91.94200134, 24.34625435], [91.94213867, 24.34621811], [91.94219208, 24.34629059], [91.9420929, 24.34641647], [91.94206238, 24.34652328], [91.94218445, 24.34649277], [91.94229889, 24.3464489], [91.94234467, 24.34650993], [91.94239807, 24.34659195], [91.94223022, 24.34667206], [91.94200134, 24.3469944], [91.9420929, 24.34729958], [91.94215393, 24.34734917], [91.94251251, 24.34731674], [91.94241333, 24.34758186], [91.94251251, 24.34763145], [91.94291687, 24.34766006], [91.94306946, 24.3477478], [91.94326019, 24.34799767], [91.9431839, 24.34805107], [91.94309235, 24.34805298], [91.94301605, 24.34815025], [91.94321442, 24.34872627], [91.94332123, 24.34890938], [91.94328308, 24.34906387], [91.94346619, 24.34900284], [91.94351959, 24.34891319], [91.94364166, 24.3487072], [91.94372559, 24.34865761], [91.94385529, 24.34888268], [91.94417572, 24.3487072], [91.94438934, 24.34864998], [91.94443512, 24.34871101], [91.94459534, 24.3488903], [91.94477081, 24.34887123], [91.94506073, 24.34897614], [91.94521332, 24.34915924], [91.94618225, 24.34956741], [91.94639587, 24.34984779], [91.94641113, 24.34998512], [91.94641113, 24.35015678], [91.94632721, 24.35033417], [91.94618988, 24.35044861], [91.94619751, 24.3505249], [91.94617462, 24.3507061], [91.94618225, 24.35081291], [91.94643402, 24.35084152], [91.9466629, 24.3510437], [91.94675446, 24.35105705], [91.94680786, 24.35099602], [91.94698334, 24.35081291], [91.94719696, 24.35090446], [91.94728851, 24.35092545], [91.94755554, 24.35083199], [91.94765472, 24.35088348], [91.94762421, 24.3509903], [91.94763184, 24.35115433], [91.94771576, 24.35110474], [91.94789124, 24.35104179], [91.94813538, 24.35104942], [91.94834137, 24.35107231], [91.948349, 24.35098648], [91.94837189, 24.35087013], [91.94856262, 24.35066032], [91.9490509, 24.35102463], [91.94915009, 24.35109711], [91.94924164, 24.35116768], [91.9495163, 24.35137749], [91.94960022, 24.35134125], [91.94976044, 24.35112381], [91.94992065, 24.35091972], [91.95008087, 24.35094643], [91.95010376, 24.35110664], [91.9502182, 24.35126686], [91.95031738, 24.35147476], [91.95057678, 24.35147858], [91.95078278, 24.35150146], [91.95085144, 24.35164833], [91.95108032, 24.35192108], [91.95109558, 24.3520298], [91.95090485, 24.35201263], [91.95081329, 24.35223389], [91.95082855, 24.35236168], [91.95079803, 24.35246277], [91.95107269, 24.35254669], [91.95134735, 24.35275459], [91.95162201, 24.35296059], [91.95172119, 24.35303307], [91.95185089, 24.35313225], [91.95222473, 24.35341072], [91.95259094, 24.35365105], [91.9526825, 24.35371971], [91.95606995, 24.35572052], [91.95610046, 24.35585976], [91.9562149, 24.35600662], [91.95622253, 24.35612869], [91.95633698, 24.35634041], [91.95640564, 24.35662842], [91.95666504, 24.35681725], [91.95710754, 24.35658073], [91.95747375, 24.35645103], [91.95774841, 24.35619926], [91.95788574, 24.35604095], [91.95805359, 24.35583878], [91.95838928, 24.3554287], [91.95887756, 24.35484314], [91.95922852, 24.35445786], [91.95956421, 24.35428047], [91.95995331, 24.35416603], [91.96066284, 24.35404396], [91.96078491, 24.35396004], [91.96125031, 24.35389519], [91.96160126, 24.35379028], [91.9619751, 24.35353088], [91.96224213, 24.35330009], [91.96238708, 24.35310173], [91.96251678, 24.35276413], [91.96303558, 24.35181046], [91.96337891, 24.35115433], [91.96350098, 24.35103607], [91.96392822, 24.35063362], [91.96429443, 24.35043144], [91.96459198, 24.35033798], [91.96490479, 24.350317], [91.96535492, 24.35032463], [91.96593475, 24.35041428], [91.96633148, 24.35047531], [91.96708679, 24.35052681], [91.967453, 24.35060883], [91.96773529, 24.35067177], [91.96828461, 24.3506031], [91.96858215, 24.35046387], [91.96891785, 24.35027695], [91.96904755, 24.35006332], [91.96913147, 24.34985161], [91.96909332, 24.34958458], [91.96899414, 24.34939575], [91.96891785, 24.34925652], [91.96873474, 24.34906197], [91.96855164, 24.34890556], [91.96833038, 24.34882927], [91.96727753, 24.34851265], [91.96631622, 24.34809494], [91.9659729, 24.34777641], [91.96583557, 24.34749222], [91.96573639, 24.34719276], [91.96577454, 24.34707832], [91.9658432, 24.34684944], [91.96607208, 24.34661484], [91.96642303, 24.34637833], [91.96794891, 24.34582901], [91.96873474, 24.34539032], [91.96925354, 24.34498215], [91.96983337, 24.34452629], [91.97034454, 24.34388161], [91.97088623, 24.3432045], [91.97117615, 24.34268379], [91.97142029, 24.34220505], [91.97157288, 24.34145737], [91.97154999, 24.34065056], [91.97147369, 24.33958817], [91.97147369, 24.33942795], [91.97146606, 24.33922195], [91.97150421, 24.33865929], [91.97175598, 24.33751106], [91.97205353, 24.33654022], [91.97219849, 24.33625031], [91.97248077, 24.33530426], [91.97284698, 24.3343029], [91.97316742, 24.33339882], [91.97344971, 24.33288002], [91.97377014, 24.33267212], [91.97406006, 24.33238029], [91.97438049, 24.33206558], [91.9748764, 24.33155632], [91.97910309, 24.33179283], [91.98291016, 24.33111572], [91.98607635, 24.3260498], [91.99007416, 24.3239727], [91.99015045, 24.32402611], [91.99029541, 24.32406044], [91.99047089, 24.32402992], [91.99098969, 24.32380486], [91.99126434, 24.32365036], [91.99156189, 24.32343102], [91.99217224, 24.32291031], [91.99228668, 24.322855], [91.99330902, 24.32235527], [91.99356842, 24.32222939], [91.99459076, 24.3222332], [91.99585724, 24.32217979], [91.99584961, 24.32320786], [91.99584198, 24.32332993], [91.99584198, 24.32342529], [91.99582672, 24.32376289], [91.99588776, 24.32405472], [91.99593353, 24.3243103], [91.99597931, 24.32437515], [91.99611664, 24.32439041], [91.99617767, 24.32497787], [91.99626923, 24.32557869], [91.99629211, 24.32591057], [91.9963913, 24.3265667], [91.99639893, 24.32673073], [91.99619293, 24.32674789], [91.99597168, 24.32675743], [91.99572754, 24.326828], [91.99572754, 24.32692719], [91.99571991, 24.32712364], [91.99568939, 24.32745552], [91.99567413, 24.32761955], [91.99567413, 24.32772446], [91.99531555, 24.32778931], [91.99530792, 24.32798004], [91.9952774, 24.32844353], [91.99524689, 24.32890701], [91.99521637, 24.32912827], [91.99501801, 24.32921219], [91.99501038, 24.32932854], [91.99499512, 24.32943726], [91.99495697, 24.32978249], [91.99490356, 24.33036423], [91.99489594, 24.33049202], [91.99488831, 24.33099747], [91.99491882, 24.33156967], [91.99565887, 24.33186722], [91.99565125, 24.33272743], [91.99562836, 24.33420563], [91.99582672, 24.33420753], [91.99586487, 24.33465004], [91.99608612, 24.33465004], [91.99610138, 24.33525085], [91.99625397, 24.33525276], [91.99627686, 24.33564949], [91.99667358, 24.33563805], [91.9967804, 24.33694458], [91.99651337, 24.33689117], [91.9963913, 24.33709908], [91.99629211, 24.33810997], [91.9956131, 24.3392086], [91.993927, 24.33993912], [91.99302673, 24.33996964], [91.99291992, 24.34160805], [91.99291229, 24.34170723], [91.99290466, 24.34184837], [91.99282837, 24.3424511], [91.99204254, 24.34350395], [91.98920441, 24.34375], [91.98840332, 24.34647942], [91.98835754, 24.346632], [91.98828125, 24.3468914], [91.98815918, 24.34690475], [91.98795319, 24.34691811], [91.98786926, 24.34713745], [91.98777771, 24.34737015], [91.98770142, 24.34760094], [91.98754883, 24.34778595], [91.98739624, 24.34788704], [91.98735046, 24.34803772], [91.98727417, 24.34817123], [91.98715973, 24.34817505], [91.98696899, 24.34819603], [91.98683929, 24.34823608], [91.98667145, 24.34835815], [91.98653412, 24.34840012], [91.98638916, 24.34842873], [91.98627472, 24.3484726], [91.9862442, 24.34856033], [91.98626709, 24.34866905], [91.98623657, 24.34889412], [91.98626709, 24.34905434], [91.98632813, 24.34920502], [91.98627472, 24.34931183], [91.98628235, 24.34945297], [91.98604584, 24.3495121], [91.98588562, 24.34955978], [91.98587799, 24.34967422], [91.9859314, 24.34979057], [91.98592377, 24.35003281], [91.98581696, 24.35016441], [91.985672, 24.35023308], [91.98553467, 24.35027504], [91.98543549, 24.35037231], [91.98535156, 24.35042572], [91.9851532, 24.35048676], [91.98497009, 24.3505497], [91.98480225, 24.35062408], [91.98468018, 24.35069084], [91.98459625, 24.35088921], [91.98453522, 24.35106087], [91.98442841, 24.35120964], [91.98428345, 24.35130882], [91.98413849, 24.35142136], [91.98386383, 24.35157776], [91.9836731, 24.35170937], [91.98361206, 24.35181999], [91.98344421, 24.35196686], [91.98335266, 24.35207748], [91.98319244, 24.35213661], [91.98292542, 24.35219193], [91.98279572, 24.35232925], [91.98275757, 24.35252953], [91.98271179, 24.35266876], [91.9826355, 24.3529129], [91.98253632, 24.35302544], [91.98238373, 24.35318375], [91.98230743, 24.35330391], [91.98220825, 24.35345268], [91.98220062, 24.35362244], [91.98226166, 24.3539257], [91.98220062, 24.35404205], [91.9821167, 24.35416412], [91.98197937, 24.35439301], [91.98187256, 24.35444069], [91.98156738, 24.35447502], [91.98132324, 24.35449219], [91.98117065, 24.35455132], [91.9810791, 24.35452843], [91.98091888, 24.35448265], [91.98078156, 24.35456085], [91.98087311, 24.35462952], [91.98105621, 24.35476303], [91.9811554, 24.3548851], [91.98129272, 24.3550148], [91.98146057, 24.35516739], [91.98143768, 24.35526657], [91.98137665, 24.35545921], [91.98124695, 24.3555088], [91.9810791, 24.35546684], [91.98091125, 24.35535622], [91.98070526, 24.3552475], [91.98054504, 24.35520172], [91.9804306, 24.3552494], [91.98018646, 24.35540199], [91.97994232, 24.35566711], [91.97982025, 24.35582352], [91.97963715, 24.35605049], [91.97950745, 24.35620117], [91.9794693, 24.35636139], [91.97959137, 24.35647011], [91.97967529, 24.35655594], [91.97969055, 24.35671806], [91.97962952, 24.35676956], [91.97948456, 24.35682869], [91.97937012, 24.35685349], [91.97916412, 24.35689735], [91.97872162, 24.3569355], [91.97846222, 24.35708237], [91.97830963, 24.35722542], [91.97821045, 24.35735512], [91.97807312, 24.35751152], [91.97803497, 24.35761261], [91.97808075, 24.35774994], [91.97814941, 24.35780716], [91.97830963, 24.35786819], [91.97851563, 24.35795021], [91.97878265, 24.3579731], [91.97886658, 24.35800934], [91.97895813, 24.35808372], [91.97904205, 24.35817337], [91.97903442, 24.35835457], [91.9790802, 24.35844994], [91.97920227, 24.35851479], [91.97917175, 24.35873032], [91.97908783, 24.35874176], [91.97893524, 24.35871696], [91.97880554, 24.35876274], [91.97881317, 24.35887146], [91.97884369, 24.35900497], [91.97885895, 24.3591404], [91.97894287, 24.35923958], [91.97904968, 24.3592968], [91.97911835, 24.35941696], [91.97917175, 24.35953903], [91.97923279, 24.35969543], [91.97928619, 24.35980797], [91.97938538, 24.35981178], [91.97950745, 24.35974121], [91.97960663, 24.35967064], [91.97974396, 24.35968971], [91.97971344, 24.35983086], [91.97964478, 24.36002541], [91.97951508, 24.3603096], [91.97950745, 24.36052322], [91.97957611, 24.36058426], [91.9797287, 24.36053276], [91.97980499, 24.36046791], [91.97992706, 24.36032677], [91.98004913, 24.36022758], [91.98014069, 24.36006927], [91.98023224, 24.35997963], [91.98033905, 24.35998917], [91.98065948, 24.36006355], [91.98085785, 24.36008263], [91.98097229, 24.36003304], [91.98110199, 24.35997772], [91.98124695, 24.35996819], [91.98134613, 24.35995102], [91.98152924, 24.36021042], [91.98431396, 24.36066818], [91.98445129, 24.36069107], [91.98451233, 24.36078072], [91.98457336, 24.3608551], [91.98457336, 24.36101151], [91.98458099, 24.36118698], [91.98448944, 24.36129189], [91.98435974, 24.36143684], [91.98423767, 24.36157417], [91.98413849, 24.36169243], [91.98400116, 24.36169815], [91.98379517, 24.36196327], [91.98369598, 24.36208344], [91.98353577, 24.36222649], [91.9834137, 24.36226845], [91.98324585, 24.36228943], [91.98308563, 24.36221123], [91.98292542, 24.36219978], [91.98267365, 24.36243248], [91.98254395, 24.3624897], [91.98234558, 24.36256599], [91.98205566, 24.36256981], [91.98187256, 24.36250687], [91.98175049, 24.36252594], [91.98160553, 24.3625164], [91.98152924, 24.36271286], [91.98146057, 24.36293602], [91.98152924, 24.36303711], [91.98140717, 24.36318779], [91.98132324, 24.36318588], [91.98119354, 24.36328506], [91.98106384, 24.36325455], [91.98094177, 24.36329842], [91.98081207, 24.363451], [91.98065948, 24.36360931], [91.98052979, 24.36371422], [91.98027802, 24.36384583], [91.98014832, 24.36393356], [91.98010254, 24.36405182], [91.98011017, 24.36414337], [91.98009491, 24.36427879], [91.98011017, 24.36439705], [91.98011017, 24.36458397], [91.98009491, 24.36476326], [91.98006439, 24.36492538], [91.9800415, 24.36508751], [91.97999573, 24.36530113], [91.97996521, 24.36541748], [91.9799118, 24.36551285], [91.97983551, 24.3656311], [91.97972107, 24.36581039], [91.97966766, 24.3659687], [91.97944641, 24.36589432], [91.97924042, 24.36591721], [91.97898865, 24.36602211], [91.97875214, 24.36623192], [91.97851563, 24.36646461], [91.97839355, 24.36663818], [91.97827911, 24.36677551], [91.97821808, 24.3668766], [91.97814941, 24.36704445], [91.97814178, 24.36724663], [91.97821045, 24.36751366], [91.97827148, 24.36774445], [91.97844696, 24.36812973], [91.97855377, 24.36850548], [91.97862244, 24.36887741], [91.97866821, 24.36907005], [91.97875977, 24.36944199], [91.97889709, 24.36970329], [91.97884369, 24.36990929], [91.97872162, 24.370224], [91.97844696, 24.37059212], [91.97833252, 24.37067032], [91.97806549, 24.37086678], [91.97777557, 24.37123489], [91.97768402, 24.37132072], [91.9776535, 24.37140656], [91.97761536, 24.371521], [91.97759247, 24.37159729], [91.97745514, 24.3717289], [91.97731018, 24.3717556], [91.97721863, 24.37177277], [91.97703552, 24.37200165], [91.97701263, 24.37207222], [91.977211, 24.37235641], [91.9773407, 24.37242126], [91.97750854, 24.37261581], [91.97747803, 24.37279129], [91.97745514, 24.37288666], [91.97736359, 24.37299919], [91.97714996, 24.37308502], [91.97701263, 24.37299728], [91.97689056, 24.37267494], [91.97673035, 24.37239838], [91.97650909, 24.37210655], [91.97622681, 24.3718586], [91.97585297, 24.37172508], [91.97546387, 24.37132263], [91.97510529, 24.37110138], [91.97467041, 24.37083626], [91.97425079, 24.37071609], [91.97400665, 24.37069893], [91.97380829, 24.37080574], [91.97361755, 24.37095451], [91.97357178, 24.37106323], [91.97356415, 24.37134361], [91.97361755, 24.37141609], [91.97357941, 24.37148476], [91.97354126, 24.37154961], [91.97319794, 24.37217903], [91.97285461, 24.37257004], [91.97266388, 24.3727684], [91.97251129, 24.37290573], [91.97220612, 24.37307358], [91.97194672, 24.37320709], [91.97180176, 24.3732872], [91.97168732, 24.37339211], [91.97148132, 24.3735981], [91.97132111, 24.37364388], [91.97121429, 24.373703], [91.97103882, 24.37387085], [91.97080994, 24.37401581], [91.97060394, 24.37424278], [91.97057343, 24.37432861], [91.97048187, 24.37433434], [91.9703064, 24.37438774], [91.97011566, 24.37447357], [91.970047, 24.3745575], [91.96988678, 24.37488747], [91.97007751, 24.3750248], [91.97044373, 24.37518501], [91.97070312, 24.37532043], [91.97105408, 24.37555695], [91.97128296, 24.37570572], [91.97143555, 24.37580872], [91.97187805, 24.37618065], [91.97245789, 24.3768158], [91.97265625, 24.37716293], [91.97273254, 24.3774395], [91.97280121, 24.37770844], [91.97280121, 24.37817574], [91.97272491, 24.37869072], [91.97248077, 24.37919426], [91.97215271, 24.37965775], [91.9719696, 24.37976074], [91.97167206, 24.37992668], [91.97132874, 24.38007164], [91.9710083, 24.38016319], [91.97064209, 24.38016891], [91.97022247, 24.38005257], [91.96992493, 24.37995338], [91.96945953, 24.37965965], [91.96907043, 24.37944412], [91.96862793, 24.37914085], [91.96831512, 24.37896919], [91.96788025, 24.37884521], [91.9675827, 24.37882233], [91.96738434, 24.37893105], [91.96711731, 24.37904167], [91.96703339, 24.37916183], [91.96695709, 24.37938881], [91.96690369, 24.37950134], [91.96685028, 24.37981415], [91.96686554, 24.38015938], [91.96691132, 24.38052177], [91.9670639, 24.38098717], [91.96721649, 24.38128662], [91.96741486, 24.38155937], [91.96776581, 24.38196373], [91.96819305, 24.38245201], [91.96856689, 24.38280106], [91.9688797, 24.38313293], [91.96931458, 24.38353729], [91.96958923, 24.38390541], [91.96975708, 24.38407707], [91.97003174, 24.38439751], [91.9701004, 24.38445091], [91.97035217, 24.38465691], [91.97045898, 24.38468933], [91.97073364, 24.38477516], [91.97107697, 24.38484383], [91.97151184, 24.38489914], [91.9719162, 24.38488007], [91.97221375, 24.38482094], [91.97267151, 24.38468933], [91.97309113, 24.38446045], [91.97332001, 24.38433075], [91.97361755, 24.38409233], [91.97393799, 24.38380432], [91.97445679, 24.38333511], [91.9750061, 24.38284111], [91.9754715, 24.38253212], [91.97585297, 24.38233948], [91.97628784, 24.38220024], [91.97671509, 24.38207436], [91.97725677, 24.38196754], [91.97780609, 24.38186073], [91.97839355, 24.3817997], [91.97899628, 24.38168526], [91.97946167, 24.38166237], [91.98002625, 24.3816185], [91.98040771, 24.38154411], [91.98078156, 24.38144493], [91.98109436, 24.38134193], [91.98162842, 24.38115501], [91.98197937, 24.38085556], [91.98232269, 24.38062286], [91.98257446, 24.38035202], [91.98274994, 24.37995338], [91.98287964, 24.37952995], [91.98307037, 24.37890053], [91.98316193, 24.37832069], [91.98326874, 24.37789536], [91.98336029, 24.37763023], [91.98350525, 24.37737083], [91.98366547, 24.37723923], [91.98379517, 24.37710571], [91.98440552, 24.3768692], [91.98467255, 24.37674713], [91.98508453, 24.37679672], [91.98544312, 24.37693787], [91.98568726, 24.37700462], [91.98587799, 24.37724113], [91.98609924, 24.37753677], [91.9853363, 24.38170815], [91.98590088, 24.38427734], [91.98591614, 24.38435364], [91.98609924, 24.38546181], [91.98703766, 24.386343], [91.9899292, 24.38897514], [91.99209595, 24.38817596], [91.99203491, 24.38883781], [91.99199677, 24.38903427], [91.99189758, 24.38927841], [91.99143982, 24.38962173], [91.99079895, 24.38984299], [91.99054718, 24.3898735], [91.99016571, 24.38991737], [91.98950958, 24.38994789], [91.98955536, 24.39030647], [91.98977661, 24.39042091], [91.98997498, 24.39047623], [91.99003601, 24.39053154], [91.99034882, 24.39071083], [91.99048615, 24.39070511], [91.9907608, 24.39050102], [91.99086761, 24.39048004], [91.99120331, 24.39041328], [91.99146271, 24.39021301], [91.99185181, 24.39023781], [91.99210358, 24.38995743], [91.99233246, 24.38980103], [91.99267578, 24.3895607], [91.99295044, 24.38914299], [91.9931488, 24.38888359], [91.99334717, 24.38869095], [91.99332428, 24.38853455], [91.99333191, 24.38840866], [91.99337769, 24.38834572], [91.99350739, 24.38831711], [91.9936676, 24.38830566], [91.99423981, 24.38823891], [91.99465179, 24.38817787], [91.99481201, 24.38819504], [91.99489594, 24.38825989], [91.99546814, 24.38868904], [91.99559021, 24.38877678], [91.99571228, 24.38916969], [91.99584961, 24.38953018], [91.99595642, 24.3897438], [91.99611664, 24.3905983], [91.99617004, 24.39073372], [91.99611664, 24.39091873], [91.9960556, 24.3911171], [91.99591064, 24.39139748], [91.9957428, 24.39143753], [91.99539948, 24.3917141], [91.99530792, 24.39172173], [91.99525452, 24.39178467], [91.99513245, 24.39192009], [91.99499512, 24.39200592], [91.99475861, 24.39215088], [91.9947052, 24.39227104], [91.99482727, 24.39236832], [91.9949646, 24.39238358], [91.99528503, 24.39220619], [91.99568176, 24.39213562], [91.99586487, 24.39225197], [91.99607086, 24.39247322], [91.99617767, 24.39261436], [91.99620819, 24.39270401], [91.99620056, 24.39283752], [91.99620819, 24.39335823], [91.99620819, 24.39351654], [91.99620056, 24.39359856], [91.99628448, 24.39374352], [91.99642181, 24.39382744], [91.99649811, 24.39387512], [91.99669647, 24.39378929], [91.99694061, 24.39369011], [91.99707031, 24.3935585], [91.99716949, 24.39342499], [91.99723816, 24.39325714], [91.99730682, 24.39280128], [91.99729919, 24.39255333], [91.99736786, 24.3924942], [91.99751282, 24.39243507], [91.99769592, 24.39247131], [91.99804688, 24.39246178], [91.99845123, 24.3922863], [91.99852753, 24.39226151], [91.99863434, 24.39225769], [91.99876404, 24.39235115], [91.99884796, 24.39237213], [91.99918365, 24.39240456], [91.99925232, 24.39233398], [91.99945068, 24.39213943], [91.99964142, 24.39192772], [91.99974823, 24.39183044], [91.99996185, 24.39197731], [92.00004578, 24.39203453], [92.00012207, 24.39208984], [92.00091553, 24.39068604], [92.00390625, 24.38891602], [92.00671387, 24.38690186], [92.00671387, 24.38677025], [92.00668335, 24.38311768], [92.00668335, 24.38303185], [92.01013184, 24.3819809], [92.0102005, 24.38202286], [92.0100174, 24.38223076], [92.01006317, 24.38232422], [92.01016235, 24.38231277], [92.01031494, 24.38253975], [92.0105896, 24.38276291], [92.01078796, 24.38291168], [92.01103973, 24.3828392], [92.01115417, 24.38298607], [92.01132965, 24.38289452], [92.01147461, 24.38298988], [92.01160431, 24.38286591], [92.01291656, 24.38365173], [92.0134964, 24.38377762], [92.01342773, 24.38391304], [92.01358032, 24.38409805], [92.01370239, 24.38420486], [92.01385498, 24.38385391], [92.01407623, 24.38392258], [92.01422119, 24.38396835], [92.01437378, 24.38401794], [92.01454163, 24.38407135], [92.01499176, 24.38409996], [92.01516724, 24.38413811], [92.01532745, 24.38417244], [92.01543427, 24.38419533], [92.01553345, 24.38421631], [92.01594543, 24.38430595], [92.01581573, 24.38437271], [92.01576233, 24.38449097], [92.01602173, 24.38452911], [92.01613617, 24.384758], [92.01628113, 24.38475227], [92.01652527, 24.38472939], [92.01672363, 24.38478661], [92.01689148, 24.38476372], [92.0171814, 24.38472748], [92.01730347, 24.38459778], [92.0174408, 24.38476181], [92.01753235, 24.38472748], [92.01764679, 24.38467216], [92.01769257, 24.38486671], [92.01783752, 24.38504219], [92.01802826, 24.38508415], [92.01811981, 24.38521194], [92.01818085, 24.38525391], [92.01832581, 24.38537979], [92.01838684, 24.3854866], [92.0185318, 24.38551331], [92.01861572, 24.38562393], [92.01872253, 24.38573837], [92.01894379, 24.385849], [92.01909637, 24.38601685], [92.01922607, 24.38604736], [92.01926422, 24.38619995], [92.01937866, 24.38632774], [92.01950836, 24.38648033], [92.01972198, 24.38639069], [92.01977539, 24.38655853], [92.01986694, 24.38666534], [92.01998901, 24.38669205], [92.0201416, 24.38653946], [92.02028656, 24.38652802], [92.02046967, 24.38641548], [92.02069855, 24.38628006], [92.02093506, 24.3862381], [92.02111053, 24.38613701], [92.02137756, 24.38605499], [92.02155304, 24.38602448], [92.02193451, 24.3861599], [92.02237701, 24.38619041], [92.02264404, 24.38612747], [92.02275848, 24.38609695], [92.02288055, 24.38609695], [92.02307129, 24.38607407], [92.02329254, 24.38587952], [92.02346802, 24.38580132], [92.02354431, 24.38576889], [92.02362823, 24.3856926], [92.02372742, 24.38557816], [92.0236969, 24.38549423], [92.02361298, 24.38531113], [92.0235672, 24.38522148], [92.02347565, 24.38510513], [92.02335358, 24.38490486], [92.02339935, 24.38483238], [92.02333832, 24.38474464], [92.02313232, 24.38478279], [92.02294922, 24.38483047], [92.02294159, 24.38455009], [92.02287292, 24.38444328], [92.02271271, 24.38440323], [92.0226059, 24.38438988], [92.02255249, 24.38420296], [92.0223465, 24.38403511], [92.02224731, 24.38395691], [92.02210236, 24.38393402], [92.02193451, 24.38384056], [92.02178955, 24.38378906], [92.0216217, 24.38394737], [92.021492, 24.38394547], [92.0214386, 24.38386917], [92.02147675, 24.38366508], [92.02144623, 24.38353729], [92.02146149, 24.38344193], [92.0215683, 24.3833828], [92.02173615, 24.38317108], [92.02181244, 24.38306808], [92.02199554, 24.38299942], [92.02216339, 24.38289261], [92.02241516, 24.3829422], [92.02269745, 24.38299751], [92.02296448, 24.38303566], [92.02318573, 24.383255], [92.02349854, 24.38340569], [92.02373505, 24.38353157], [92.02384949, 24.3835144], [92.02407837, 24.38341904], [92.02425385, 24.38369179], [92.02438354, 24.38371658], [92.02469635, 24.38363457], [92.02464294, 24.38346672], [92.02474976, 24.38337517], [92.02490234, 24.3834095], [92.02487183, 24.38319016], [92.02488708, 24.38310814], [92.02494049, 24.38290596], [92.02487183, 24.38272476], [92.02507019, 24.38265228], [92.02502441, 24.38255119], [92.02494812, 24.38249016], [92.02522278, 24.38228798], [92.02540588, 24.38232803], [92.02558136, 24.38229561], [92.02600098, 24.38221359], [92.02624512, 24.38220596], [92.02645111, 24.38221931], [92.02663422, 24.38195038], [92.02666473, 24.38150215], [92.02680206, 24.38143349], [92.02681732, 24.38121605], [92.02677155, 24.38084412], [92.02675629, 24.38071251], [92.02680969, 24.38062859], [92.02696228, 24.38057709], [92.02692413, 24.38035202], [92.02676392, 24.38021088], [92.0266571, 24.37995911], [92.02674866, 24.37975502], [92.02697754, 24.37990761], [92.02711487, 24.37988663], [92.0272522, 24.37967873], [92.02758789, 24.37962723], [92.02783966, 24.37981796], [92.02794647, 24.37966728], [92.02812195, 24.3796463], [92.02824402, 24.37971115], [92.02828979, 24.37985611], [92.02855682, 24.3800602], [92.02869415, 24.38002205], [92.02893829, 24.37986946], [92.02902985, 24.3800869], [92.02928162, 24.38023186], [92.02948761, 24.38019943], [92.02957153, 24.37999344], [92.02957916, 24.37984276], [92.03062439, 24.3801136], [92.03199768, 24.38046646], [92.0320816, 24.38043213], [92.0343399, 24.37947083], [92.03455353, 24.37950706], [92.03462982, 24.37981224], [92.03483582, 24.38002396], [92.03491211, 24.3799839], [92.03505707, 24.37997627], [92.03530884, 24.37981033], [92.03538513, 24.37981606], [92.03555298, 24.3798008], [92.03549957, 24.37995148], [92.03555298, 24.38010025], [92.03565216, 24.38022232], [92.03578949, 24.38025665], [92.03581238, 24.38018799], [92.03569794, 24.38013268], [92.03577423, 24.38001823], [92.03605652, 24.37982559], [92.03604889, 24.37973785], [92.036026, 24.37954521], [92.03630066, 24.37927628], [92.03624725, 24.37903214], [92.03635406, 24.3790226], [92.03666687, 24.37917709], [92.03675842, 24.37921143], [92.03675079, 24.37912369], [92.03674316, 24.37904739], [92.03691864, 24.37901306], [92.03697968, 24.37893867], [92.03689575, 24.37888908], [92.03704071, 24.37878799], [92.03714752, 24.37874222], [92.03723907, 24.37853432], [92.03733063, 24.37858009], [92.03736877, 24.37864494], [92.03743744, 24.37860489], [92.03762054, 24.37837601], [92.03775787, 24.37841034], [92.03778839, 24.3782177], [92.0375824, 24.3780117], [92.03777313, 24.37796402], [92.03778839, 24.37775612], [92.03778839, 24.37765503], [92.03803253, 24.3775425], [92.03820038, 24.37753296], [92.03826904, 24.37745667], [92.03824615, 24.37732697], [92.03839111, 24.37717628], [92.03847504, 24.3771801], [92.03868866, 24.37731934], [92.03907013, 24.37701225], [92.03917694, 24.37691116], [92.03933716, 24.37690163], [92.03946686, 24.37689018], [92.03959656, 24.37693405], [92.03969574, 24.37693596], [92.03968811, 24.37679672], [92.04008484, 24.37683487], [92.04007721, 24.37690926], [92.03988647, 24.37693596], [92.03987122, 24.37711906], [92.04001617, 24.37707329], [92.04006958, 24.3769989], [92.04018402, 24.37701416], [92.0403595, 24.3771019], [92.04043579, 24.37706184], [92.04055023, 24.37701797], [92.04061127, 24.37714195], [92.04064178, 24.3772583], [92.04078674, 24.37722206], [92.04093933, 24.37725258], [92.04115295, 24.3772583], [92.04128265, 24.37734032], [92.04137421, 24.37737274], [92.04149628, 24.37732124], [92.04167938, 24.377388], [92.04192352, 24.37746239], [92.04206848, 24.37747574], [92.04237366, 24.37742615], [92.04256439, 24.37738609], [92.04263306, 24.37745857], [92.04286957, 24.37770653], [92.04299164, 24.37764931], [92.04312897, 24.37754059], [92.04320526, 24.37733459], [92.04318237, 24.3772049], [92.04303741, 24.37705421], [92.0429306, 24.3769474], [92.04281616, 24.37679863], [92.04267883, 24.3767128], [92.04283905, 24.37658501], [92.04298401, 24.37663078], [92.04310608, 24.37661171], [92.04312897, 24.3768177], [92.04327393, 24.37688637], [92.04333496, 24.37684059], [92.04457855, 24.3759594], [92.0453949, 24.37614441], [92.04533386, 24.37624931], [92.04527283, 24.37636566], [92.04532623, 24.37644958], [92.04551697, 24.3764534], [92.04562378, 24.37648392], [92.04571533, 24.37659073], [92.04579163, 24.37650871], [92.04587555, 24.37651253], [92.04602051, 24.37661743], [92.04605103, 24.37629509], [92.04636383, 24.37636566], [92.04646301, 24.37638855], [92.04660034, 24.37641907], [92.04654694, 24.37631989], [92.04679108, 24.37627029], [92.04676819, 24.37638092], [92.04680634, 24.37646484], [92.04690552, 24.37668228], [92.04682159, 24.37699127], [92.04705048, 24.37694359], [92.04724884, 24.37709999], [92.04759216, 24.37694931], [92.04766083, 24.37710762], [92.04788208, 24.37723732], [92.04798126, 24.37742043], [92.04815674, 24.37747955], [92.04808807, 24.37762451], [92.04813385, 24.3776989], [92.04825592, 24.37770653], [92.04834747, 24.37762451], [92.0484848, 24.37757111], [92.04864502, 24.37755966], [92.04873657, 24.37771034], [92.0488739, 24.37770271], [92.0489502, 24.37766075], [92.0490036, 24.37717247], [92.04894257, 24.37706375], [92.04903412, 24.37698555], [92.04914856, 24.37680435], [92.05627441, 24.37609863], [92.0605545, 24.37586975], [92.06427002, 24.37567139], [92.07189941, 24.37527657], [92.07680511, 24.37521935], [92.07691956, 24.37525558], [92.07723999, 24.3752327], [92.07743835, 24.37523842], [92.0776825, 24.37530518], [92.07776642, 24.37548065], [92.07797241, 24.3754406], [92.07842255, 24.37534142], [92.0786438, 24.37515259], [92.07900238, 24.37508965], [92.07935333, 24.37509537], [92.07954407, 24.37503624], [92.07987976, 24.3749218], [92.0801239, 24.37477303], [92.08026886, 24.37490845], [92.08059692, 24.37491608], [92.08089447, 24.37483025], [92.08098602, 24.37488556], [92.08131409, 24.37498474], [92.08164978, 24.37499237], [92.08200836, 24.37500381], [92.0821991, 24.37501335], [92.08247375, 24.37508583], [92.08269501, 24.37517738], [92.08309174, 24.37512207], [92.08319092, 24.37524414], [92.08338165, 24.37537956], [92.08357239, 24.37541389], [92.08393097, 24.37548637], [92.08411407, 24.37547493], [92.08432007, 24.3755722], [92.0845108, 24.37547684], [92.08469391, 24.37557602], [92.08494568, 24.37546539], [92.08514404, 24.37574577], [92.08541107, 24.37561226], [92.08574677, 24.37528992], [92.08904266, 24.37342072], [92.09368896, 24.37432861], [92.09656525, 24.37544441], [92.09664917, 24.37552071], [92.09729767, 24.3761158], [92.09724426, 24.37623787], [92.09731293, 24.37635612], [92.09741211, 24.37640953], [92.09754944, 24.37634659], [92.09990692, 24.37852287], [92.10002136, 24.37862778], [92.10011292, 24.37871361], [92.10114288, 24.38011742], [92.10105133, 24.38021088], [92.10089874, 24.38052559], [92.10085297, 24.38061523], [92.10054016, 24.38069725], [92.10018921, 24.38058472], [92.09997559, 24.38064766], [92.10009766, 24.38080406], [92.10023499, 24.38092804], [92.10046387, 24.38098907], [92.10083771, 24.38101959], [92.10094452, 24.38104248], [92.10111237, 24.38107681], [92.10126495, 24.38133049], [92.10132599, 24.38144684], [92.10148621, 24.38160706], [92.10163116, 24.38172913], [92.10194397, 24.38192749], [92.10194397, 24.38218117], [92.10179138, 24.38241959], [92.10162354, 24.38251686], [92.10168457, 24.38267517], [92.10186768, 24.38287354], [92.10196686, 24.38293457], [92.10232544, 24.38305664], [92.10256195, 24.38301277], [92.10289764, 24.38298225], [92.10333252, 24.38287735], [92.1036911, 24.38263512], [92.10382843, 24.38243484], [92.10394287, 24.38229179], [92.10407257, 24.38207436], [92.10404968, 24.38182449], [92.10405731, 24.38141251], [92.1040802, 24.38117599], [92.10437012, 24.38114166], [92.10544586, 24.38211441], [92.10571289, 24.38222504], [92.10562897, 24.38285446], [92.10561371, 24.38302422], [92.10559845, 24.38323784], [92.10559845, 24.38337898], [92.10826874, 24.38212776], [92.11187744, 24.38287354], [92.11594391, 24.38446426], [92.11608887, 24.38452148], [92.11933136, 24.3839035], [92.12200928, 24.38599777], [92.12192535, 24.38607407], [92.12168121, 24.38625526], [92.12171936, 24.38641357], [92.12187958, 24.3865757], [92.12182617, 24.38677788], [92.12145996, 24.38682938], [92.1213913, 24.38707161], [92.1217041, 24.38706398], [92.12181091, 24.38706207], [92.12190247, 24.3871479], [92.1217041, 24.3874054], [92.12159729, 24.3873806], [92.12121582, 24.38729477], [92.1209259, 24.38732147], [92.12046814, 24.38790321], [92.12002563, 24.38757515], [92.11985779, 24.38779449], [92.11986542, 24.38813019], [92.12012482, 24.38870239], [92.11966705, 24.38856888], [92.11933136, 24.38851929], [92.1191864, 24.38858795], [92.11907959, 24.38874245], [92.11962128, 24.38899803], [92.11968231, 24.38912201], [92.11973572, 24.38923836], [92.11985779, 24.38954544], [92.12017822, 24.38965607], [92.12031555, 24.38958359], [92.12049103, 24.38929558], [92.12069702, 24.38944054], [92.12068176, 24.38966751], [92.12031555, 24.38988304], [92.12008667, 24.38999176], [92.11951447, 24.38961411], [92.11940002, 24.38980484], [92.11929321, 24.38985062], [92.11897278, 24.38998413], [92.11882019, 24.39003181], [92.11883545, 24.3901577], [92.11902618, 24.39024353], [92.11916351, 24.39055824], [92.11975098, 24.39063644], [92.11971283, 24.39076042], [92.11963654, 24.39099884], [92.11981964, 24.39129639], [92.11962128, 24.3915081], [92.12023163, 24.39187813], [92.11980438, 24.39201927], [92.11978912, 24.39213753], [92.11982727, 24.39228249], [92.12008667, 24.39246559], [92.12039948, 24.39245796], [92.12080383, 24.39236641], [92.1210556, 24.39247131], [92.12168121, 24.39319992], [92.12172699, 24.39325905], [92.12162018, 24.39367867], [92.12173462, 24.3938961], [92.12202454, 24.39396858], [92.12206268, 24.39410973], [92.12204742, 24.39430237], [92.12220764, 24.39460373], [92.12224579, 24.39476013], [92.12226105, 24.39499855], [92.12232208, 24.39515305], [92.12246704, 24.39538574], [92.12245178, 24.39562988], [92.12241364, 24.39587784], [92.12248993, 24.39606667], [92.12290955, 24.39616394], [92.1231308, 24.39624786], [92.12322235, 24.39646149], [92.12362671, 24.39678001], [92.12373352, 24.39678001], [92.12409973, 24.39627647], [92.12421417, 24.3962059], [92.12441254, 24.39621544], [92.12547302, 24.39711571], [92.12736511, 24.39875031], [92.12736511, 24.3988781], [92.1269989, 24.39915848], [92.12683868, 24.39978027], [92.12689209, 24.39989662], [92.12751007, 24.40005875], [92.12817383, 24.39970589], [92.12825775, 24.39988327], [92.12840271, 24.40019035], [92.1282196, 24.40067101], [92.12797546, 24.40069389], [92.12787628, 24.40070343], [92.12770844, 24.40099716], [92.12738037, 24.40118027], [92.12729645, 24.40138054], [92.12728119, 24.40177345], [92.12734985, 24.40182304], [92.12760925, 24.40183449], [92.12788391, 24.4020462], [92.12807465, 24.40225601], [92.12837219, 24.40258789], [92.12875366, 24.40266991], [92.1292038, 24.40323067], [92.12953186, 24.40350342], [92.1295166, 24.40387344], [92.1295929, 24.40425682], [92.13005066, 24.40403557], [92.13036346, 24.40404892], [92.13033295, 24.40419197], [92.13008118, 24.40434837], [92.13008881, 24.40451431], [92.13014221, 24.40476799], [92.13040161, 24.40508842], [92.13084412, 24.40561485], [92.13101959, 24.40590858], [92.13122559, 24.40626335], [92.13161469, 24.40629959], [92.13174438, 24.40657043], [92.13144684, 24.40675926], [92.13175964, 24.40706825], [92.13182068, 24.40701866], [92.13204193, 24.40693474], [92.1321106, 24.40678406], [92.13195801, 24.40657806], [92.13201141, 24.40628052], [92.132164, 24.4060688], [92.13231659, 24.4060936], [92.1324234, 24.40618324], [92.13249207, 24.40668869], [92.13264465, 24.4068737], [92.13288879, 24.40678406], [92.13312531, 24.40674973], [92.13314819, 24.40691185], [92.13308716, 24.40716743], [92.13298798, 24.40747261], [92.13316345, 24.40751648], [92.13327789, 24.40723991], [92.13339996, 24.40695572], [92.13369751, 24.40677643], [92.13388062, 24.40675354], [92.13398743, 24.40696716], [92.13407898, 24.40715027], [92.13427734, 24.40728378], [92.13435364, 24.40720749], [92.13499451, 24.40763092], [92.13491058, 24.40803337], [92.13467407, 24.40828323], [92.13470459, 24.40838432], [92.13474274, 24.40849495], [92.13464355, 24.40885353], [92.13471222, 24.40924644], [92.13467407, 24.40954018], [92.13439178, 24.40958977], [92.13420105, 24.40960693], [92.13417816, 24.409729], [92.13433838, 24.41000557], [92.13438416, 24.41008759], [92.13442993, 24.41020584], [92.1342392, 24.41028595], [92.13393402, 24.41028976], [92.13381958, 24.4106636], [92.13380432, 24.41089821], [92.13372803, 24.41098022], [92.13359833, 24.41100502], [92.13322449, 24.41088295], [92.13296509, 24.41077995], [92.13254547, 24.41110802], [92.13249207, 24.41127205], [92.13261414, 24.41147804], [92.13277435, 24.41149712], [92.13309479, 24.41137505], [92.13328552, 24.41142464], [92.13334656, 24.4118576], [92.13342285, 24.41224289], [92.13362122, 24.41267395], [92.13356781, 24.41277313], [92.13343811, 24.41293716], [92.1332016, 24.41311073], [92.13314056, 24.41331291], [92.13331604, 24.41363716], [92.13331604, 24.4137516], [92.13298798, 24.4140358], [92.13288116, 24.41430092], [92.13278961, 24.41451836], [92.13298798, 24.41483498], [92.13309479, 24.41522217], [92.13317108, 24.41575623], [92.13342285, 24.41603279], [92.1332016, 24.41630936], [92.13317108, 24.41643524], [92.13344574, 24.41673088], [92.13323975, 24.41706467], [92.133461, 24.41720009], [92.13370514, 24.41753197], [92.13402557, 24.41774559], [92.13440704, 24.41789627], [92.13454437, 24.41813278], [92.13468933, 24.41836548], [92.13493347, 24.41851616], [92.13505554, 24.41861916], [92.13502502, 24.41888237], [92.13529968, 24.41906357], [92.13567352, 24.41918564], [92.135849, 24.41947746], [92.13605499, 24.41945457], [92.13619995, 24.41956902], [92.1363678, 24.41982841], [92.13651276, 24.42004967], [92.13660431, 24.42016792], [92.13648224, 24.42040634], [92.13644409, 24.42064095], [92.13659668, 24.42103767], [92.13626862, 24.42128181], [92.13621521, 24.42139435], [92.13629913, 24.42164993], [92.13645172, 24.42188263], [92.13647461, 24.4220562], [92.13625336, 24.42218018], [92.13608551, 24.42227364], [92.13613129, 24.42282104], [92.13601685, 24.423069], [92.13599396, 24.42333221], [92.13622284, 24.42362595], [92.13647461, 24.42386627], [92.13671875, 24.42406654], [92.13680267, 24.42413139], [92.13687134, 24.42418671], [92.13686371, 24.424263], [92.13676453, 24.42439842], [92.13670349, 24.42461777], [92.1366272, 24.42480278], [92.13658142, 24.42489433], [92.13669586, 24.42509842], [92.13681793, 24.4251194], [92.13706207, 24.42505646], [92.13726044, 24.42505264], [92.13759613, 24.42505455], [92.13793182, 24.42505836], [92.13821411, 24.42513275], [92.13838196, 24.42523766], [92.13848114, 24.42528725], [92.13863373, 24.42525673], [92.13882446, 24.4250164], [92.13891602, 24.42486382], [92.13904572, 24.42465973], [92.13909912, 24.42449951], [92.14051056, 24.42461395], [92.14277649, 24.42486], [92.14287567, 24.42486763], [92.14795685, 24.42420959], [92.15216064, 24.42518044], [92.15228271, 24.42529297], [92.15311432, 24.42557526], [92.15322876, 24.42561531], [92.15337372, 24.42566299], [92.15361786, 24.42574692], [92.15571594, 24.42645836], [92.15599823, 24.42637062], [92.15979767, 24.42486954], [92.16377258, 24.42172241], [92.16622162, 24.42207336], [92.16584015, 24.42238045], [92.16571045, 24.4225769], [92.16573334, 24.42266846], [92.16579437, 24.4227066], [92.16624451, 24.42273712], [92.16654968, 24.4227562], [92.16662598, 24.42286682], [92.16666412, 24.42295456], [92.16663361, 24.42310715], [92.16658783, 24.4234314], [92.16661835, 24.42358398], [92.16680908, 24.42376328], [92.16707611, 24.42404938], [92.16732788, 24.42423248], [92.16747284, 24.42453194], [92.16764069, 24.42492867], [92.16775513, 24.42525673], [92.16779327, 24.42546654], [92.16770935, 24.42593193], [92.16754913, 24.42638016], [92.16752625, 24.42646408], [92.16746521, 24.4266758], [92.16738129, 24.4270134], [92.16740417, 24.42714119], [92.16744995, 24.42723465], [92.16772461, 24.42739296], [92.16809845, 24.42746735], [92.1684494, 24.42752647], [92.16881561, 24.42763519], [92.16894531, 24.42776871], [92.16904449, 24.42791176], [92.16895294, 24.42805481], [92.16882324, 24.42817688], [92.16862488, 24.42823792], [92.16844177, 24.42829132], [92.16817474, 24.42835426], [92.16765594, 24.42841339], [92.16752625, 24.42839432], [92.16719818, 24.42834091], [92.16664124, 24.42819023], [92.1661911, 24.42807388], [92.16601562, 24.42813301], [92.16591644, 24.4282589], [92.16596985, 24.42849731], [92.16613007, 24.42886925], [92.16631317, 24.42935371], [92.16636658, 24.42974281], [92.16637421, 24.42986298], [92.16638947, 24.43005371], [92.16640472, 24.43029976], [92.16648865, 24.43058014], [92.16655731, 24.4307003], [92.16659546, 24.43077469], [92.16669464, 24.4308567], [92.16694641, 24.43126488], [92.16697693, 24.43155098], [92.16680908, 24.43187523], [92.16648865, 24.43242455], [92.16625977, 24.43267632], [92.16608429, 24.43292618], [92.16595459, 24.43322563], [92.16590881, 24.43343544], [92.16607666, 24.43362808], [92.16617584, 24.43371391], [92.16661835, 24.43374062], [92.16687012, 24.43373489], [92.1671524, 24.43378258], [92.16737366, 24.43394661], [92.16743469, 24.43416023], [92.16736603, 24.43443871], [92.16734314, 24.43469048], [92.16724396, 24.43490791], [92.16705322, 24.43518066], [92.16688538, 24.43539047], [92.16673279, 24.43558311], [92.16664124, 24.43578911], [92.16654968, 24.43619537], [92.16651917, 24.43632507], [92.16602325, 24.43679047], [92.16592407, 24.4368763], [92.16560364, 24.43663597], [92.16539764, 24.43654823], [92.16500854, 24.43643379], [92.16455078, 24.43639183], [92.16414642, 24.4364624], [92.16396332, 24.43658257], [92.16379547, 24.43675804], [92.16368103, 24.43696022], [92.16368103, 24.43720818], [92.16368103, 24.43742943], [92.16377258, 24.43766403], [92.16386414, 24.43796349], [92.16410065, 24.43829346], [92.16416931, 24.43838501], [92.16429138, 24.43855667], [92.16435242, 24.43873978], [92.16434479, 24.43895531], [92.16422272, 24.43906784], [92.16416168, 24.43917465], [92.16408539, 24.43931389], [92.16377258, 24.43948936], [92.16342163, 24.43954086], [92.16313934, 24.43959808], [92.16288757, 24.43964958], [92.16271973, 24.43976212], [92.16252136, 24.44003487], [92.16260529, 24.44018364], [92.16275024, 24.44035339], [92.16291809, 24.44043159], [92.16305542, 24.44049072], [92.16303253, 24.44073296], [92.16291809, 24.4438858], [92.16426849, 24.44491577], [92.16422272, 24.44497871], [92.16386414, 24.44522476], [92.16357422, 24.44547844], [92.16345215, 24.44560623], [92.16334534, 24.44586182], [92.16316986, 24.44615746], [92.16291809, 24.44641685], [92.1627655, 24.44654083], [92.16252899, 24.44677734], [92.16213226, 24.44705772], [92.16201019, 24.4472065], [92.16199493, 24.44731903], [92.16207886, 24.44767952], [92.16210938, 24.4479351], [92.16210938, 24.44820404], [92.16197205, 24.4484539], [92.16175079, 24.44862938], [92.16149139, 24.44870567], [92.16104126, 24.4487648], [92.16091156, 24.44886017], [92.16085815, 24.44915962], [92.16082001, 24.44951057], [92.16085815, 24.44972229], [92.16109467, 24.45004272], [92.16130066, 24.45020103], [92.16179657, 24.45044708], [92.16213226, 24.45067215], [92.1622467, 24.45085907], [92.16230011, 24.45107841], [92.16226196, 24.45125771], [92.16214752, 24.45146179], [92.16196442, 24.45182037], [92.16186523, 24.45207787], [92.16182709, 24.45216942], [92.16172791, 24.45245552], [92.16158295, 24.45277977], [92.16133118, 24.45299911], [92.16096497, 24.45312881], [92.16059875, 24.4531765], [92.16024017, 24.45312691], [92.15984344, 24.45311928], [92.1595993, 24.45320511], [92.15949249, 24.45339394], [92.1595459, 24.45365715], [92.15976715, 24.4539566], [92.16001129, 24.45429802], [92.16013336, 24.45447159], [92.16022491, 24.45465088], [92.16027832, 24.4548111], [92.16034698, 24.45510101], [92.16036987, 24.45546532], [92.16042328, 24.45561981], [92.1608963, 24.45586205], [92.16107941, 24.45596123], [92.16116333, 24.45615768], [92.16120148, 24.45639801], [92.16106415, 24.45667648], [92.16098785, 24.45683289], [92.16085052, 24.45713043], [92.16070557, 24.45727539], [92.1601181, 24.45908356], [92.15981293, 24.45904732], [92.15935516, 24.45893288], [92.15881348, 24.45878983], [92.15848541, 24.45885277], [92.1583252, 24.45896149], [92.15820312, 24.45921898], [92.15811157, 24.45946121], [92.15799713, 24.45979118], [92.15804291, 24.46020889], [92.15816498, 24.46037102], [92.15840149, 24.46044731], [92.15789795, 24.46069336], [92.15787506, 24.46278], [92.15787506, 24.46290207], [92.1585083, 24.46390724], [92.15834808, 24.46392441], [92.1583252, 24.46406174], [92.15837097, 24.46436119], [92.15855408, 24.46477318], [92.15862274, 24.46516609], [92.15860748, 24.4653244], [92.15858459, 24.46545982], [92.15850067, 24.46566391], [92.15837097, 24.46598053], [92.15816498, 24.4662075], [92.15790558, 24.46642685], [92.15757751, 24.46644402], [92.15737915, 24.46643448], [92.15718079, 24.4663372], [92.15686798, 24.46600533], [92.15659332, 24.46573639], [92.1563797, 24.46549606], [92.15624237, 24.46543694], [92.15607452, 24.46543884], [92.15597534, 24.46548653], [92.15582275, 24.4655571], [92.15550995, 24.46578217], [92.15545654, 24.46594048], [92.15546417, 24.46617699], [92.1556015, 24.46661568], [92.15574646, 24.46704483], [92.15582275, 24.46756744], [92.15584564, 24.46774483], [92.15585327, 24.46781731], [92.15589142, 24.46801758], [92.15617371, 24.46844292], [92.15641785, 24.46873474], [92.15665436, 24.46885872], [92.15693665, 24.46899223], [92.15718079, 24.46886444], [92.15736389, 24.46865273], [92.15744781, 24.46845627], [92.15750122, 24.46808052], [92.15756226, 24.46775818], [92.15763092, 24.46757317], [92.15776825, 24.46749115], [92.15795898, 24.46753883], [92.15811157, 24.46763229], [92.15813446, 24.46780968], [92.15815735, 24.46806717], [92.15805054, 24.46854019], [92.15805817, 24.46884727], [92.15805054, 24.46930122], [92.15809631, 24.46971893], [92.15796661, 24.47014236], [92.15782166, 24.47021484], [92.15751648, 24.47025299], [92.1570282, 24.47018051], [92.15670776, 24.47001839], [92.15641785, 24.46990776], [92.15627289, 24.46976852], [92.15597534, 24.46961784], [92.15578461, 24.46962166], [92.15553284, 24.46970177], [92.15533447, 24.46980858], [92.15518951, 24.46995354], [92.15515137, 24.47020912], [92.1552124, 24.47041893], [92.15538025, 24.47073364], [92.15548706, 24.47092819], [92.15559387, 24.47109985], [92.15557861, 24.47123718], [92.15544891, 24.47134399], [92.15530396, 24.47137451], [92.15502167, 24.47151566], [92.15483093, 24.47158623], [92.15459442, 24.47175407], [92.15428925, 24.47204399], [92.15419006, 24.47220993], [92.15419769, 24.47245789], [92.15422821, 24.47255135], [92.15431976, 24.47282028], [92.15450287, 24.47318649], [92.15475464, 24.4734726], [92.15497589, 24.47377205], [92.15531158, 24.47400665], [92.15542603, 24.47407341], [92.15567017, 24.47402763], [92.15578461, 24.47389221], [92.15581512, 24.47377777], [92.15575409, 24.47342873], [92.1555481, 24.47301483], [92.15561676, 24.47283936], [92.15573883, 24.47259712], [92.15592957, 24.47251701], [92.15614319, 24.47274017], [92.15634155, 24.47282982], [92.15670776, 24.472929], [92.15699005, 24.47305679], [92.15710449, 24.47311783], [92.15717316, 24.47329903], [92.15716553, 24.47363472], [92.15717316, 24.47410011], [92.15713501, 24.47426796], [92.1570282, 24.47438622], [92.1567688, 24.47462082], [92.15631104, 24.47488594], [92.15606689, 24.47506523], [92.1558075, 24.47529411], [92.15578461, 24.47547722], [92.15584564, 24.47570419], [92.15592957, 24.47595978], [92.15601349, 24.4762249], [92.15613556, 24.47661591], [92.15614319, 24.47675323], [92.15614319, 24.47686195], [92.15609741, 24.47706413], [92.15599823, 24.47725677], [92.15586853, 24.47739792], [92.15564728, 24.47751617], [92.15509796, 24.47785759], [92.1545639, 24.47816086], [92.15408325, 24.4784832], [92.15380096, 24.47868347], [92.15366364, 24.47882271], [92.15366364, 24.47903824], [92.15366364, 24.47912407], [92.15367889, 24.47967529], [92.15374756, 24.4802475], [92.15367126, 24.48049545], [92.15356445, 24.48062134], [92.15315247, 24.48108673], [92.15267944, 24.48151016], [92.15258026, 24.48163414], [92.152565, 24.48200417], [92.15259552, 24.4822216], [92.1526947, 24.48246956], [92.15284729, 24.48265648], [92.15310669, 24.48285675], [92.15320587, 24.48303032], [92.1531601, 24.48329926], [92.15307617, 24.48366928], [92.15304565, 24.48386002], [92.15309906, 24.48404503], [92.1532135, 24.48421097], [92.15349579, 24.48442268], [92.15374756, 24.48461723], [92.15383148, 24.48468018], [92.15370178, 24.48485374], [92.15365601, 24.4851017], [92.15345764, 24.48526192], [92.1530304, 24.48564148], [92.15296936, 24.48587227], [92.15286255, 24.48610878], [92.15288544, 24.48626709], [92.15293121, 24.48642921], [92.15301514, 24.48658752], [92.15330505, 24.4869194], [92.15319061, 24.48749352], [92.15294647, 24.48737907], [92.15267944, 24.48721695], [92.1524353, 24.48713493], [92.15219116, 24.48715973], [92.15192413, 24.48728371], [92.15180206, 24.48750114], [92.15196228, 24.4881134], [92.15197754, 24.48836136], [92.15198517, 24.48851013], [92.15189362, 24.48886681], [92.15164948, 24.48947906], [92.15166473, 24.489851], [92.15176392, 24.48999596], [92.15210724, 24.49020195], [92.1521759, 24.49041939], [92.15219116, 24.4906044], [92.1519165, 24.49072647], [92.1516571, 24.49084282], [92.15150452, 24.49086952], [92.15129089, 24.49098396], [92.15119171, 24.49114609], [92.1512146, 24.49136162], [92.15136719, 24.49153137], [92.15155029, 24.49158859], [92.15184784, 24.49157906], [92.1525116, 24.49147415], [92.15283966, 24.49144745], [92.15309143, 24.49150848], [92.15320587, 24.4915638], [92.1534729, 24.49169922], [92.15356445, 24.49177361], [92.15342712, 24.49210739], [92.15328217, 24.49226379], [92.15297699, 24.49266434], [92.15248871, 24.49318504], [92.15226746, 24.49349976], [92.15218353, 24.49369049], [92.15216064, 24.49381828], [92.15216064, 24.49408722], [92.1521759, 24.49453354], [92.15206146, 24.49481964], [92.15193176, 24.49487114], [92.15146637, 24.49505615], [92.15136719, 24.49509621], [92.15111542, 24.49520302], [92.15093231, 24.49525261], [92.15052795, 24.49529839], [92.15039825, 24.49536705], [92.15042114, 24.49559402], [92.15048218, 24.49565506], [92.15074158, 24.49580193], [92.15107727, 24.49600029], [92.15133667, 24.49614716], [92.15136719, 24.49625206], [92.15141296, 24.49651146], [92.15143585, 24.49684525], [92.15143585, 24.49731827], [92.15142059, 24.49772072], [92.15144348, 24.49792862], [92.1515274, 24.49818611], [92.15156555, 24.49852562], [92.15148926, 24.49890137], [92.15151978, 24.49913597], [92.1516037, 24.49938011], [92.15174866, 24.49960518], [92.15197754, 24.49980545], [92.15222168, 24.50007057], [92.15252686, 24.50030518], [92.15293121, 24.50131607], [92.15262604, 24.50156593], [92.15236664, 24.50189018], [92.15218353, 24.50225258], [92.15221405, 24.5024147], [92.15245056, 24.50269508], [92.15258026, 24.50280952], [92.1526947, 24.50291824], [92.15291595, 24.50297928], [92.15309906, 24.50300789], [92.15351868, 24.50300598], [92.15361786, 24.50300789], [92.15409851, 24.50419617], [92.15412903, 24.50426674], [92.1541748, 24.50436974], [92.15447998, 24.50488281], [92.15612793, 24.50769043], [92.15883636, 24.50772095], [92.15831757, 24.50825119], [92.15801239, 24.50855446], [92.15763092, 24.50885773], [92.157341, 24.50907135], [92.15703583, 24.50934601], [92.15667725, 24.50965118], [92.15638733, 24.50990295], [92.15592194, 24.51010513], [92.15567017, 24.51024818], [92.15531921, 24.51041031], [92.15490723, 24.51062012], [92.15470886, 24.51081848], [92.15465546, 24.5110321], [92.15466309, 24.51146889], [92.15468597, 24.51178932], [92.1546936, 24.51189423], [92.15454865, 24.51207733], [92.15435791, 24.51209831], [92.15411377, 24.51199532], [92.15382385, 24.51186943], [92.15365601, 24.51181984], [92.1534729, 24.51197243], [92.15344238, 24.51205635], [92.15339661, 24.51218414], [92.15343475, 24.51234436], [92.15361786, 24.51255226], [92.15390015, 24.51267242], [92.15423584, 24.51270294], [92.15458679, 24.51269341], [92.15494537, 24.51275063], [92.15524292, 24.51291656], [92.15537262, 24.51328659], [92.15556335, 24.51335716], [92.15571594, 24.51361465], [92.15586853, 24.51374245], [92.15602875, 24.51377106], [92.15615082, 24.51363945], [92.15621948, 24.51345253], [92.15629578, 24.51314545], [92.15634155, 24.51297379], [92.15644836, 24.51272202], [92.15654755, 24.51262665], [92.15682983, 24.51260757], [92.15697479, 24.51268196], [92.15694427, 24.51282692], [92.15687561, 24.51321602], [92.15679169, 24.51352692], [92.15677643, 24.51367569], [92.15675354, 24.51382637], [92.15677643, 24.51410103], [92.15692902, 24.5143528], [92.15710449, 24.51454163], [92.1571579, 24.51460266], [92.15737915, 24.51477814], [92.15776062, 24.51497459], [92.15802765, 24.51518059], [92.15813446, 24.51533508], [92.1580658, 24.5154686], [92.15801239, 24.51554108], [92.15756989, 24.5155983], [92.15717316, 24.51567078], [92.15680695, 24.51573753], [92.15648651, 24.51592445], [92.15625763, 24.51612663], [92.15608978, 24.51643372], [92.15601349, 24.51669312], [92.15596008, 24.51699257], [92.15585327, 24.51720238], [92.15578461, 24.51739883], [92.15568542, 24.51752663], [92.15554047, 24.51768112], [92.15543365, 24.51803207], [92.15537262, 24.5182457], [92.15509033, 24.51928711], [92.15561676, 24.522686], [92.155159, 24.522686], [92.15500641, 24.52275276], [92.15487671, 24.52290535], [92.15486145, 24.52311897], [92.1550293, 24.52323151], [92.15530396, 24.52328873], [92.1554718, 24.52327728], [92.15571594, 24.5232563], [92.15588379, 24.52429199], [92.15782928, 24.52485275], [92.15790558, 24.52487564], [92.16005707, 24.52566147], [92.15999603, 24.5258522], [92.1598053, 24.52607918], [92.15943909, 24.52638435], [92.15921021, 24.52670479], [92.15890503, 24.52710915], [92.15877533, 24.52744865], [92.15872955, 24.52760124], [92.15886688, 24.52775764], [92.15890503, 24.52782059], [92.15898895, 24.52799416], [92.15904236, 24.52825928], [92.15914154, 24.5285244], [92.15921021, 24.52866936], [92.15933228, 24.52882576], [92.15939331, 24.52890587], [92.15940094, 24.52904892], [92.15959167, 24.52929306], [92.15968323, 24.52943993], [92.15982819, 24.52951241], [92.15986633, 24.52928734], [92.15990448, 24.5290451], [92.1600647, 24.52902603], [92.16031647, 24.52901268], [92.16059875, 24.52900887], [92.16099548, 24.52893066], [92.16126251, 24.52890396], [92.16137695, 24.52878952], [92.16143036, 24.52868462], [92.16143036, 24.52842522], [92.16143036, 24.52799606], [92.16144562, 24.52777481], [92.16146851, 24.52767372], [92.16159058, 24.52762413], [92.16177368, 24.52762222], [92.16202545, 24.52782249], [92.16226196, 24.52817917], [92.16226196, 24.52832413], [92.16257477, 24.5284996], [92.16271973, 24.52856827], [92.16294098, 24.52845001], [92.16325378, 24.52840424], [92.16353607, 24.52829742], [92.16359711, 24.52836037], [92.16375732, 24.528368], [92.16410065, 24.52867508], [92.16433716, 24.52893257], [92.16452789, 24.52906609], [92.16464996, 24.52923965], [92.16512299, 24.52916145], [92.16532898, 24.52919388], [92.16560364, 24.52923584], [92.16565704, 24.5293541], [92.16572571, 24.52950096], [92.16576385, 24.52980804], [92.16569519, 24.530056], [92.1656723, 24.53047943], [92.16551971, 24.53090286], [92.16540527, 24.5310955], [92.16542816, 24.53135681], [92.16549683, 24.5314064], [92.16561127, 24.53153801], [92.16588593, 24.53158569], [92.16598511, 24.53161049], [92.1662674, 24.53168106], [92.16651154, 24.53176689], [92.16668701, 24.53183174], [92.16697693, 24.53193474], [92.16718292, 24.53201485], [92.16729736, 24.53193855], [92.16733551, 24.53182983], [92.16731262, 24.53162575], [92.16729736, 24.53154564], [92.16725922, 24.53137589], [92.16724396, 24.5311718], [92.16723633, 24.53102875], [92.16736603, 24.53098297], [92.16763306, 24.53092766], [92.16778564, 24.53090096], [92.16802216, 24.53093147], [92.16831207, 24.53114891], [92.16853333, 24.53136635], [92.16875458, 24.53155327], [92.16902161, 24.53180504], [92.16918182, 24.53187943], [92.16939545, 24.53187752], [92.16957855, 24.53177834], [92.16983795, 24.53160858], [92.16989899, 24.53155518], [92.17340088, 24.53402138], [92.17767334, 24.53070068], [92.1796875, 24.52868652], [92.17932129, 24.52667236], [92.17877197, 24.5237999], [92.17897797, 24.52387619], [92.17910767, 24.52399635], [92.17934418, 24.52409172], [92.17953491, 24.52423668], [92.17969513, 24.52420807], [92.17987823, 24.52407074], [92.17999268, 24.52395058], [92.18019867, 24.52373695], [92.18025208, 24.52355766], [92.18026733, 24.52346039], [92.18022156, 24.52322197], [92.1802063, 24.52313042], [92.18014526, 24.52293015], [92.18012238, 24.52278519], [92.18005371, 24.52256966], [92.18031311, 24.52241898], [92.18045044, 24.5225296], [92.18043518, 24.52270317], [92.18057251, 24.52299881], [92.18070221, 24.52314568], [92.18082428, 24.52329063], [92.18097687, 24.52342415], [92.18112183, 24.52352333], [92.18122101, 24.52357674], [92.18133545, 24.52363968], [92.18151093, 24.52375031], [92.18180847, 24.52387619], [92.18206787, 24.5239563], [92.18218231, 24.52393532], [92.18231201, 24.52386093], [92.18237305, 24.52372932], [92.18236542, 24.52362633], [92.18230438, 24.52355576], [92.18225098, 24.5232811], [92.18231964, 24.52314949], [92.1824646, 24.52298737], [92.18386078, 24.52293777], [92.18395996, 24.52301216], [92.18419647, 24.52312851], [92.18431854, 24.52319336], [92.18437958, 24.52327347], [92.18454742, 24.52335358], [92.18471527, 24.52338219], [92.18489075, 24.52334976], [92.18506622, 24.52323723], [92.18528748, 24.52314949], [92.18540192, 24.52306175], [92.18556976, 24.52290535], [92.18572998, 24.52270889], [92.18591309, 24.52252579], [92.18595886, 24.52234077], [92.18746948, 24.52125549], [92.18764496, 24.52129364], [92.18779755, 24.52132416], [92.18789673, 24.52122498], [92.18791962, 24.52108955], [92.18798828, 24.52098274], [92.18807983, 24.52082062], [92.18895721, 24.52019119], [92.19126129, 24.52098083], [92.19268799, 24.52148438], [92.1942749, 24.51971436], [92.19708252, 24.51672363], [92.19989014, 24.51531982], [92.19983673, 24.5112915], [92.19989014, 24.51123238], [92.2000351, 24.51105881], [92.20007324, 24.51087952], [92.20009613, 24.51075172], [92.20010376, 24.51044083], [92.20020294, 24.51023293], [92.20024872, 24.51015091], [92.20045471, 24.51002312], [92.20053864, 24.50989151], [92.20063019, 24.50964165], [92.20067596, 24.50934219], [92.20066071, 24.50895119], [92.20074463, 24.50883293], [92.20083618, 24.50873375], [92.20108032, 24.50868416], [92.20136261, 24.50863075], [92.20158386, 24.50852966], [92.20172882, 24.50835228], [92.20172119, 24.50820541], [92.20155334, 24.50800514], [92.2014389, 24.50784683], [92.20145416, 24.5077095], [92.20147705, 24.50759697], [92.20167542, 24.50746918], [92.20194244, 24.50748062], [92.20201874, 24.50748062], [92.20214844, 24.50748062], [92.20264435, 24.50754166], [92.20293427, 24.50749207], [92.20311737, 24.50743294], [92.20341492, 24.50736809], [92.20375824, 24.50730324], [92.20409393, 24.50725174], [92.20440674, 24.50719643], [92.20477295, 24.5070858], [92.20505524, 24.50704575], [92.2053833, 24.50699425], [92.20561981, 24.50693703], [92.20573425, 24.50692177], [92.20588684, 24.50683403], [92.20600891, 24.50677681], [92.20607758, 24.50656509], [92.20607758, 24.50640869], [92.20615387, 24.50629234], [92.20628357, 24.50623703], [92.20644379, 24.50620461], [92.20670319, 24.50622177], [92.20683289, 24.50623322], [92.20710754, 24.50629425], [92.20738983, 24.50624847], [92.20753479, 24.50625229], [92.20760345, 24.50619316], [92.20771027, 24.50602722], [92.20782471, 24.50591469], [92.20796204, 24.50566101], [92.20806885, 24.50547981], [92.20811462, 24.5053196], [92.20821381, 24.5051918], [92.20832825, 24.50491905], [92.20839691, 24.50469589], [92.20846558, 24.50447464], [92.2086792, 24.50432587], [92.20878601, 24.50426483], [92.20891571, 24.50424194], [92.20920563, 24.50427246], [92.20939636, 24.50436592], [92.20967102, 24.50440407], [92.20993042, 24.50447655], [92.21015167, 24.50449181], [92.21038818, 24.50451469], [92.21060944, 24.50452805], [92.21075439, 24.50450897], [92.21091461, 24.50443268], [92.2110672, 24.5043602], [92.21122742, 24.50426674], [92.21147919, 24.50416946], [92.21164703, 24.50411034], [92.21182251, 24.5040493], [92.21191406, 24.50401878], [92.21212006, 24.50393677], [92.21231842, 24.50385475], [92.21244049, 24.50381088], [92.21253204, 24.50376892], [92.21316528, 24.50477982], [92.21450043, 24.50564766], [92.21514893, 24.50669479], [92.21572876, 24.50774193], [92.21714783, 24.50720024], [92.22027588, 24.50628662], [92.22113037, 24.50292969], [92.22148132, 24.50151062], [92.230896, 24.49969482], [92.23094177, 24.50222969], [92.23099518, 24.50409126], [92.23426819, 24.5004406], [92.23468018, 24.49932861], [92.23510742, 24.49829102], [92.23547363, 24.49688721], [92.23615265, 24.49484444], [92.23632813, 24.49432373], [92.23660278, 24.49282265], [92.23950195, 24.4899292], [92.23384094, 24.48471069], [92.23029327, 24.4800396], [92.22891998, 24.47210121], [92.22895813, 24.47200203], [92.23117065, 24.46544075], [92.23109436, 24.46081352], [92.23108673, 24.46051025], [92.23114777, 24.46041489], [92.2322998, 24.45849609], [92.23506927, 24.45643234], [92.23593903, 24.45378113], [92.23606873, 24.45027161], [92.23931885, 24.44732666], [92.25632477, 24.4364109], [92.25653076, 24.4362793], [92.25747681, 24.43251991], [92.25595856, 24.41897964], [92.25863647, 24.41464615], [92.25927734, 24.41351318], [92.26268005, 24.40981102], [92.26330566, 24.40808105], [92.26264954, 24.40491676], [92.26267242, 24.40482903], [92.26428223, 24.39770508], [92.26989746, 24.39489746], [92.27050781, 24.39093018], [92.27308655, 24.38845062], [92.27270508, 24.3862915], [92.2726593, 24.38622284], [92.26994324, 24.38228989], [92.2698822, 24.38219833], [92.27187347, 24.38003349], [92.27246857, 24.37928009], [92.27225494, 24.37768936], [92.26830292, 24.3747921], [92.2677002, 24.37329102], [92.26812744, 24.36730957], [92.26415253, 24.36226082], [92.26409912, 24.36214828], [92.21289063, 24.24932861], [92.24047852, 24.25067139], [92.25958252, 24.25049019], [92.25970459, 24.25048828], [92.28478241, 24.25206757], [92.28491211, 24.25205231], [92.29187012, 24.25128174], [92.29660797, 24.25172997], [92.29668427, 24.25174141], [92.29709625, 24.24954033], [92.2953186, 24.24806976], [92.29412842, 24.24432373], [92.29492188, 24.24072266], [92.296875, 24.23809814], [92.29632568, 24.23608398], [92.29632568, 24.23388672], [92.29946899, 24.23162079], [92.29931641, 24.22949219], [92.29920959, 24.22934151], [92.29769897, 24.22731781], [92.30105591, 24.22553444], [92.30187988, 24.22509766], [92.30113983, 24.22448158], [92.30088043, 24.22204018], [92.30342102, 24.22165298], [92.30353546, 24.22163582], [92.31083679, 24.2225399], [92.31375122, 24.22288322], [92.31359863, 24.22113037], [92.30966949, 24.21612167], [92.30974579, 24.21479988], [92.31265259, 24.21109772], [92.31610107, 24.21331787], [92.3190918, 24.20910645], [92.32470703, 24.20587158], [92.32489014, 24.20471191], [92.32480621, 24.20470428], [92.3203125, 24.20430946], [92.3203125, 24.20269775], [92.32506561, 24.19908333], [92.32510376, 24.1989994], [92.32557678, 24.19753647], [92.32470703, 24.19628906], [92.32476044, 24.19476128], [92.32949066, 24.19114113], [92.32891083, 24.18911171], [92.32971191, 24.18829346], [92.32958221, 24.18818855], [92.3270874, 24.18609619], [92.33040619, 24.18483162], [92.33087158, 24.18212891], [92.33002472, 24.18013763], [92.33002472, 24.1800499], [92.32993317, 24.17465019], [92.32855988, 24.1661129], [92.32946777, 24.16452026], [92.33190918, 24.16369629], [92.33447266, 24.15087891], [92.33691406, 24.14691162], [92.33688354, 24.14677811], [92.33627319, 24.14432335], [92.33532715, 24.14367676], [92.3336792, 24.14428711], [92.33353424, 24.14426804], [92.33296967, 24.14419365], [92.33227539, 24.14402962], [92.33227539, 24.14050293], [92.32928467, 24.13989258], [92.32830048, 24.13862038], [92.32816315, 24.13516998], [92.329216, 24.13162613], [92.32878113, 24.12972069], [92.32888031, 24.1296463], [92.33111572, 24.12811279], [92.33101654, 24.12799072], [92.32832336, 24.12468338], [92.32867432, 24.11590576], [92.33174133, 24.11314583], [92.33187103, 24.11187363], [92.33188629, 24.11176109], [92.32937622, 24.11036682], [92.33229065, 24.10688782], [92.33229065, 24.10680962], [92.33227539, 24.10528564], [92.32950592, 24.10293007], [92.3296814, 24.10132408], [92.32967377, 24.10109329], [92.32834625, 24.09859848], [92.33142853, 24.09874535], [92.33068085, 24.09697342], [92.33027649, 24.09615326], [92.33014679, 24.09602356], [92.32794952, 24.09370232], [92.32878113, 24.08912086], [92.32814026, 24.08515549], [92.32811737, 24.08502007], [92.32904816, 24.08225632], [92.32814026, 24.08068085], [92.32805634, 24.08062744], [92.32282257, 24.07748032], [92.32284546, 24.07726669], [92.32287598, 24.07695961], [92.3270874, 24.07647705], [92.32727051, 24.07452393], [92.32369232, 24.07326317], [92.32292175, 24.07187462], [92.32293701, 24.07180023], [92.32330322, 24.06970215], [92.32128906, 24.06848145], [92.3192749, 24.06951904], [92.31828308, 24.06912422], [92.3182373, 24.06904411], [92.3168869, 24.06689835], [92.31880188, 24.06202126], [92.3190918, 24.0612793], [92.32176971, 24.05866051], [92.31871033, 24.05735016], [92.31999969, 24.05231667], [92.32028961, 24.05116272], [92.31904602, 24.0501194], [92.31682587, 24.05135155], [92.31526947, 24.0486908], [92.31549072, 24.04492188], [92.31754303, 24.03952026], [92.31719971, 24.03750038], [92.31506348, 24.0355587], [92.31413269, 24.03471184], [92.3192749, 24.03131104], [92.3192749, 24.03027344], [92.3167572, 24.02802467], [92.31669617, 24.02797127], [92.3190918, 24.0255127], [92.31848145, 24.02270508], [92.32171631, 24.0189209], [92.32165527, 24.0188446], [92.32092285, 24.0178833], [92.31890869, 24.01928711], [92.31750488, 24.0189209], [92.31713867, 24.01761246], [92.32470703, 24.00653076], [92.32746124, 24.00420952], [92.32727051, 24.00189209], [92.32905579, 23.98965073], [92.32589722, 23.98753548], [92.32579803, 23.98747063], [92.32736969, 23.98604584], [92.32769775, 23.98571777], [92.32778931, 23.98470116], [92.32614899, 23.98365974], [92.32552338, 23.98326111], [92.32409668, 23.97949219], [92.32285309, 23.97978592], [92.32274628, 23.97981071], [92.32208252, 23.97528076], [92.31964111, 23.97532082], [92.31768036, 23.97210121], [92.31513977, 23.97216606], [92.31530762, 23.97088623], [92.31360626, 23.97049141], [92.31269836, 23.9702301], [92.3133316, 23.96108818], [92.31333923, 23.96096992], [92.31155396, 23.96060562], [92.31144714, 23.96058273], [92.31265259, 23.95750618], [92.31123352, 23.94568443], [92.31347656, 23.94329834], [92.31268311, 23.94128418], [92.31347656, 23.93450928], [92.31807709, 23.93035126], [92.32116699, 23.92611122], [92.32128906, 23.92607498], [92.3278656, 23.92401695], [92.32971191, 23.9230957], [92.33065796, 23.92144966], [92.32939148, 23.91885948], [92.33114624, 23.91180229], [92.33052826, 23.90783119], [92.330513, 23.90771484], [92.33048248, 23.90759659], [92.32989502, 23.90551758], [92.32778168, 23.90621948], [92.32592773, 23.90447998], [92.32579041, 23.90449524], [92.32372284, 23.90466881], [92.32360077, 23.90467834], [92.32331085, 23.90441322], [92.32315063, 23.90426636], [92.32171631, 23.89147949], [92.32157898, 23.8914547], [92.32067871, 23.89129639], [92.31988525, 23.88989258], [92.3192749, 23.89068604], [92.31919861, 23.89066887], [92.31863403, 23.89053917], [92.3184967, 23.89048958], [92.31902313, 23.88915443], [92.31832886, 23.88793182], [92.31952667, 23.88610077], [92.31932831, 23.88372421], [92.31713104, 23.88408852], [92.31642151, 23.88343811], [92.31628418, 23.88330078], [92.31671143, 23.88171387], [92.31750488, 23.88153076], [92.31747437, 23.8813858], [92.31712341, 23.87926483], [92.31710815, 23.87918091], [92.3190918, 23.87768555], [92.32041168, 23.8780098], [92.32198334, 23.87415886], [92.32209015, 23.87390327], [92.32209015, 23.87379074], [92.32208252, 23.86987305], [92.32198334, 23.86982536], [92.31845856, 23.86799431], [92.31824493, 23.86713982], [92.3203125, 23.86590576], [92.32022095, 23.86581039], [92.31968689, 23.86530876], [92.31954956, 23.86524773], [92.3156662, 23.86354637], [92.31552887, 23.86352539], [92.30987549, 23.8626709], [92.30731201, 23.8638916], [92.30432129, 23.86382294], [92.30426025, 23.8638649], [92.30068207, 23.8664608], [92.29510498, 23.86547852], [92.29514313, 23.87010956], [92.29388428, 23.87127686], [92.29338074, 23.87134743], [92.29201508, 23.87140846], [92.28790283, 23.86688232], [92.28790283, 23.86309814], [92.28592682, 23.85886574], [92.28530121, 23.85747147], [92.2765274, 23.8528862], [92.27474976, 23.84905815], [92.2741394, 23.84361076], [92.27393341, 23.84169769], [92.27587891, 23.83990479], [92.2770462, 23.83670998], [92.27713013, 23.8366127], [92.28210449, 23.83087158], [92.28160858, 23.82630157], [92.28159332, 23.82616043], [92.28366852, 23.82418633], [92.28346252, 23.82349968], [92.28568268, 23.82263184], [92.28681183, 23.81676102], [92.28588867, 23.81567383], [92.28374481, 23.81623459], [92.28084564, 23.81515884], [92.27911377, 23.81671143], [92.2766571, 23.81520844], [92.26947784, 23.81777954], [92.25953674, 23.81502914], [92.25939941, 23.814991], [92.26068115, 23.80712891], [92.2623291, 23.80487061], [92.26348877, 23.79968262], [92.26374054, 23.79168892], [92.26779938, 23.76997185], [92.26802826, 23.7665081], [92.26728058, 23.76273346], [92.26711273, 23.76189995], [92.26824951, 23.75651741], [92.26824188, 23.75640488], [92.26647949, 23.7387085], [92.26848602, 23.72869682], [92.26850128, 23.72861099], [92.2691803, 23.72811127], [92.27626038, 23.72187042], [92.27670288, 23.72106171], [92.27965546, 23.71568108], [92.27905273, 23.71653175], [92.27820587, 23.71752167], [92.27739716, 23.71825027], [92.27587891, 23.71954536], [92.27468872, 23.7204113], [92.27297974, 23.72093201], [92.27111816, 23.72144699], [92.26811981, 23.722332], [92.26641846, 23.72335815], [92.26610565, 23.72435188], [92.26599121, 23.72472572], [92.26488495, 23.72476959], [92.26437378, 23.72479057], [92.26421356, 23.72459221], [92.26340485, 23.72358322], [92.2616272, 23.72344208], [92.26023865, 23.72465324], [92.25985718, 23.72498894], [92.25784302, 23.72524643], [92.25717926, 23.72506523], [92.25636292, 23.72484016], [92.25502014, 23.72499275], [92.25398254, 23.72439957], [92.25192261, 23.72431755], [92.25113678, 23.72408295], [92.25081635, 23.72423935], [92.25074005, 23.7242775], [92.24941254, 23.72430611], [92.24875641, 23.72342873], [92.24822235, 23.72270775], [92.24720001, 23.72267342], [92.24681854, 23.72266006], [92.24571228, 23.7202816], [92.24562836, 23.72016144], [92.24324799, 23.71670151], [92.24317169, 23.71656418], [92.24151611, 23.71368408], [92.24115753, 23.71068573], [92.24113464, 23.71060562], [92.24053192, 23.70848083], [92.24085236, 23.70614815], [92.24085999, 23.70606995], [92.24250793, 23.70428467], [92.24273682, 23.70377922], [92.24446106, 23.69992256], [92.24477386, 23.69890785], [92.24487305, 23.69848633], [92.24613953, 23.69592285], [92.24622345, 23.6958065], [92.24707031, 23.69470215], [92.24691772, 23.69189262], [92.24434662, 23.69009399], [92.2441864, 23.689991], [92.24245453, 23.68896484], [92.24236298, 23.68890953], [92.24217987, 23.68650055], [92.24205017, 23.68590164], [92.24191284, 23.6854763], [92.24188232, 23.68538094], [92.241745, 23.68455887], [92.24030304, 23.68309593], [92.24021912, 23.68301201], [92.23965454, 23.68252754], [92.23950195, 23.6809082], [92.23954773, 23.68028069], [92.23921204, 23.67968178], [92.23910522, 23.67948914], [92.23904419, 23.67936707], [92.23896027, 23.67920494], [92.23867798, 23.6787281], [92.2386322, 23.67866135], [92.23753357, 23.67685318], [92.23748779, 23.67678261], [92.23748779, 23.67547607], [92.23803711, 23.67247391], [92.23805237, 23.67235756], [92.23813629, 23.67027092], [92.23496246, 23.66749954], [92.2336731, 23.66540718], [92.23248291, 23.66369629], [92.2305069, 23.66146278], [92.22963715, 23.66055489], [92.22953033, 23.66043854], [92.22853088, 23.65929222], [92.22841644, 23.65924072], [92.22629547, 23.65830612], [92.2260437, 23.65769005], [92.22596741, 23.65718842], [92.22612762, 23.65617561], [92.22569275, 23.65524483], [92.22420502, 23.65484238], [92.22329712, 23.65455246], [92.22323608, 23.65429878], [92.22270203, 23.65300941], [92.22175598, 23.65324783], [92.22077942, 23.65267944], [92.22008514, 23.6523056], [92.2195282, 23.65210915], [92.21930695, 23.65203476], [92.21916962, 23.65205383], [92.21781158, 23.65224457], [92.21759796, 23.65222359], [92.21643829, 23.65211105], [92.21629333, 23.65272903], [92.2151947, 23.65279198], [92.21447754, 23.65283203], [92.21250916, 23.65288734], [92.21189117, 23.65304375], [92.21146393, 23.65315247], [92.21048737, 23.65393448], [92.21063995, 23.65527344], [92.21138, 23.65571404], [92.21087646, 23.65700531], [92.21118164, 23.65761185], [92.21100616, 23.65888405], [92.20954132, 23.65976715], [92.20847321, 23.66034889], [92.20672607, 23.66109657], [92.20672607, 23.66268539], [92.20693207, 23.66486549], [92.20677948, 23.66638947], [92.20741272, 23.66697693], [92.20748138, 23.66704178], [92.20766449, 23.66720581], [92.20722198, 23.6680336], [92.20687103, 23.66868782], [92.20622253, 23.6696167], [92.20639038, 23.67085457], [92.20648956, 23.67162704], [92.20611572, 23.67202377], [92.20581055, 23.67234039], [92.20603943, 23.6726799], [92.20623779, 23.67298126], [92.20625305, 23.67420578], [92.20638275, 23.67486191], [92.20643616, 23.67516327], [92.20664215, 23.67558479], [92.20703888, 23.67642784], [92.20721436, 23.67697525], [92.20742798, 23.6776619], [92.20834351, 23.67728806], [92.20868683, 23.67798424], [92.21021271, 23.67871094], [92.21039581, 23.67898178], [92.21072388, 23.67946815], [92.21137238, 23.67994499], [92.2124939, 23.68123627], [92.21239471, 23.6816597], [92.21270752, 23.68205833], [92.21272278, 23.68226433], [92.21279144, 23.68309402], [92.21308899, 23.68461037], [92.21378326, 23.68513489], [92.21338654, 23.68589973], [92.21305084, 23.686409], [92.2124939, 23.68652153], [92.21229553, 23.68729401], [92.21208954, 23.68746758], [92.21162415, 23.68759537], [92.21138, 23.68790245], [92.21086884, 23.6887722], [92.21084595, 23.69007111], [92.21130371, 23.69067764], [92.2104187, 23.69140625], [92.21018219, 23.69115257], [92.20976257, 23.69157982], [92.20994568, 23.69247818], [92.20969391, 23.69282913], [92.20925903, 23.69348717], [92.20918274, 23.69441414], [92.20913696, 23.69511414], [92.20911407, 23.69542313], [92.2088089, 23.69636536], [92.20864105, 23.69660378], [92.20825958, 23.69745255], [92.20769501, 23.69825554], [92.2072525, 23.69891167], [92.20733643, 23.6991024], [92.20710754, 23.70001221], [92.2068634, 23.70003891], [92.20697021, 23.70065117], [92.20646667, 23.70088387], [92.20559692, 23.70186806], [92.20491791, 23.70157051], [92.20481873, 23.70152664], [92.20439911, 23.70177269], [92.20401001, 23.70201111], [92.20375824, 23.70259476], [92.20391846, 23.70379448], [92.20375061, 23.70407486], [92.20352936, 23.70433617], [92.20341492, 23.70456696], [92.2029953, 23.70471954], [92.20281219, 23.70591927], [92.20237732, 23.70591164], [92.20202637, 23.7057972], [92.20180511, 23.70572281], [92.20102692, 23.70599556], [92.20004272, 23.70680428], [92.19827271, 23.70700836], [92.19789886, 23.70729828], [92.19711304, 23.70716667], [92.19682312, 23.70711708], [92.19676208, 23.70704651], [92.19651794, 23.70677185], [92.19610596, 23.70681572], [92.19563293, 23.70686531], [92.1953125, 23.70664787], [92.19422913, 23.70694923], [92.1934967, 23.70685005], [92.19296265, 23.70709419], [92.19278717, 23.70750427], [92.19165802, 23.70757294], [92.19097137, 23.70798683], [92.19084167, 23.70832443], [92.19002533, 23.70849991], [92.18940735, 23.7092247], [92.1886673, 23.71007347], [92.18854523, 23.71007729], [92.18829346, 23.71008301], [92.18682861, 23.71042824], [92.18661499, 23.71037102], [92.18651581, 23.71050262], [92.18608093, 23.71106911], [92.18558502, 23.71061516], [92.18539429, 23.70982552], [92.18536377, 23.709692], [92.18516541, 23.7096386], [92.18440247, 23.70943451], [92.18477631, 23.70929146], [92.18486023, 23.70925713], [92.18467712, 23.70824051], [92.18331909, 23.7080574], [92.18320465, 23.70804024], [92.1831131, 23.7079258], [92.18288422, 23.70764351], [92.18273163, 23.70767784], [92.1812439, 23.70801544], [92.18030548, 23.70808792], [92.17987061, 23.70797348], [92.17848969, 23.70813942], [92.17819977, 23.70788574], [92.177948, 23.70767021], [92.17768097, 23.70767021], [92.17762756, 23.7078743], [92.17739868, 23.70874977], [92.17697144, 23.70937538], [92.17750549, 23.70969391], [92.17750549, 23.7103653], [92.17677307, 23.71084595], [92.17681885, 23.71111107], [92.17658997, 23.71179008], [92.17634583, 23.71252823], [92.17679596, 23.71344757], [92.17656708, 23.71364403], [92.17656708, 23.71500778], [92.17649078, 23.71654129], [92.1751709, 23.71736908], [92.17373657, 23.71779442], [92.17351532, 23.71786308], [92.17342377, 23.71784973], [92.17304993, 23.71779823], [92.17288971, 23.7180748], [92.17249298, 23.71876335], [92.17205048, 23.71951485], [92.17140961, 23.72065353], [92.17089844, 23.72167397], [92.1708374, 23.72180557], [92.1707077, 23.7226963], [92.16985321, 23.72321129], [92.16959381, 23.7233696], [92.16950226, 23.72477722], [92.17005157, 23.72476768], [92.17067719, 23.72508812], [92.17140961, 23.72631836], [92.17131805, 23.72783661], [92.17093658, 23.72920799], [92.17108917, 23.7299099], [92.17108154, 23.73004532], [92.17102814, 23.73067856], [92.1709137, 23.73138046], [92.17076111, 23.73230362], [92.17076874, 23.7328968], [92.1720047, 23.73377609], [92.17224884, 23.73462868], [92.17250824, 23.73490906], [92.17269897, 23.73537445], [92.17287445, 23.73580933], [92.1727066, 23.73608971], [92.17245483, 23.73651695], [92.17259216, 23.73680878], [92.17254639, 23.7368679], [92.17227173, 23.73723221], [92.17176056, 23.73744392], [92.17191315, 23.73780441], [92.17206573, 23.73817825], [92.17179108, 23.73870659], [92.17105103, 23.73902512], [92.16971588, 23.73976326], [92.16854095, 23.73991776], [92.16748047, 23.73999214], [92.16665649, 23.74027443], [92.16616058, 23.74011612], [92.16543579, 23.73932648], [92.16487885, 23.73899651], [92.16379547, 23.73916054], [92.16346741, 23.73958397], [92.16307831, 23.73962784], [92.16235352, 23.73971176], [92.16110992, 23.73920631], [92.16106415, 23.73913383], [92.16077423, 23.73868179], [92.15984344, 23.73831177], [92.15901184, 23.7382412], [92.15834808, 23.73818588], [92.1574173, 23.73771477], [92.15700531, 23.7371521], [92.15603638, 23.73686218], [92.15576172, 23.73648453], [92.15581512, 23.73605347], [92.15590668, 23.73538971], [92.15545654, 23.73500061], [92.15480804, 23.73444366], [92.15419769, 23.73464775], [92.15380096, 23.73477936], [92.15370178, 23.73481178], [92.15291595, 23.73448563], [92.15198517, 23.73410034], [92.15096283, 23.7345047], [92.15052795, 23.73575401], [92.14948273, 23.73541451], [92.1493988, 23.73552895], [92.14928436, 23.73568726], [92.14855957, 23.73570633], [92.14780426, 23.73529053], [92.14766693, 23.73495293], [92.14713287, 23.73481941], [92.14654541, 23.73474503], [92.14553833, 23.73405647], [92.14492798, 23.73376274], [92.14419556, 23.73321724], [92.14375305, 23.73214722], [92.14349365, 23.73130417], [92.1434021, 23.73008919], [92.14296722, 23.7295723], [92.14239502, 23.72946358], [92.14253235, 23.72855568], [92.14234161, 23.72711372], [92.14221191, 23.72621155], [92.14208984, 23.7253952], [92.14179993, 23.72526932], [92.14148712, 23.72430611], [92.14100647, 23.72419739], [92.14048767, 23.72338676], [92.14057159, 23.72272682], [92.13935852, 23.72181129], [92.13930511, 23.72152138], [92.13890076, 23.72141647], [92.1388855, 23.721632], [92.13838196, 23.72100449], [92.13922882, 23.72032166], [92.13819122, 23.72000504], [92.13825226, 23.71953201], [92.1367569, 23.71904373], [92.13648224, 23.71808052], [92.13601685, 23.71799088], [92.13594818, 23.71772003], [92.1353302, 23.71752167], [92.13550568, 23.71715546], [92.13474274, 23.71661186], [92.13450623, 23.71603012], [92.13404083, 23.71591759], [92.13375854, 23.71584892], [92.13379669, 23.71555328], [92.13391113, 23.71470451], [92.13234711, 23.71374321], [92.13140106, 23.71238708], [92.13178253, 23.71170998], [92.13150787, 23.71120071], [92.13111115, 23.7109108], [92.1308136, 23.71071243], [92.1306076, 23.71074486], [92.13037872, 23.70985794], [92.12954712, 23.70926666], [92.12929535, 23.70918846], [92.12900543, 23.70909691], [92.12900543, 23.70898438], [92.12900543, 23.70798874], [92.12799835, 23.70745277], [92.12744904, 23.70768166], [92.1266098, 23.70670128], [92.1262207, 23.70691872], [92.12522888, 23.70656586], [92.12522888, 23.70561218], [92.12493134, 23.70554924], [92.12514496, 23.70520401], [92.12447357, 23.70415878], [92.12406921, 23.70303726], [92.12478638, 23.70216179], [92.12431335, 23.70171738], [92.12474823, 23.70090866], [92.12371826, 23.70040131], [92.12356567, 23.69995308], [92.12289429, 23.69960213], [92.12350464, 23.69907379], [92.12330627, 23.69814873], [92.12416077, 23.6974659], [92.12321472, 23.69683075], [92.12353516, 23.6960125], [92.1237793, 23.69575119], [92.12271881, 23.69509697], [92.12132263, 23.69352913], [92.1207962, 23.69304848], [92.12075806, 23.69279289], [92.12028503, 23.69257927], [92.1180954, 23.69058228], [92.11712646, 23.68969727], [92.11453247, 23.6870594], [92.11359406, 23.68588448], [92.11273956, 23.68481064], [92.11080933, 23.68239594], [92.11026764, 23.68171883], [92.11019897, 23.68158913], [92.10945892, 23.68032074], [92.10935974, 23.68014908], [92.10852051, 23.67871094], [92.105896, 23.67651367], [92.10467529, 23.67608643], [92.10391235, 23.67609024], [92.10308075, 23.67595291], [92.10299683, 23.67593956], [92.10107422, 23.67669678], [92.10009003, 23.67707825], [92.0998764, 23.67720985], [92.09970093, 23.67678642], [92.09929657, 23.67687607], [92.09887695, 23.67696953], [92.09798431, 23.67675209], [92.0969162, 23.67729759], [92.09636688, 23.67709732], [92.09537506, 23.67786407], [92.09384155, 23.67782593], [92.09322357, 23.67850113], [92.09235382, 23.67802238], [92.09195709, 23.67777824], [92.09171295, 23.67765427], [92.0917511, 23.67713928], [92.09130859, 23.67745399], [92.0899353, 23.67843819], [92.08878326, 23.679142], [92.08789825, 23.67944145], [92.08753204, 23.68070221], [92.08660889, 23.68048286], [92.08660126, 23.68033409], [92.086586, 23.67955589], [92.08560181, 23.68021393], [92.0854187, 23.68033791], [92.08506775, 23.68089104], [92.08459473, 23.68012047], [92.08441162, 23.68012047], [92.08306885, 23.68012619], [92.08278656, 23.67892265], [92.08312988, 23.67712402], [92.08188629, 23.6760273], [92.08166504, 23.67583466], [92.081604, 23.67473602], [92.08110046, 23.67308235], [92.08057404, 23.67135811], [92.0798111, 23.67127228], [92.0783844, 23.67111397], [92.07744598, 23.66958809], [92.07630157, 23.66804504], [92.07659912, 23.66786385], [92.07697296, 23.66735458], [92.07706451, 23.66731262], [92.07801819, 23.66687202], [92.07826233, 23.66577911], [92.0783844, 23.66522026], [92.07894135, 23.6649971], [92.07952881, 23.6647644], [92.07946014, 23.66427803], [92.07941437, 23.66397476], [92.08001709, 23.66232109], [92.07949066, 23.65997314], [92.07901764, 23.65881157], [92.07872009, 23.65787315], [92.07923126, 23.65611076], [92.07928467, 23.65591621], [92.07884979, 23.65551376], [92.07775116, 23.6544857], [92.07834625, 23.65405846], [92.07850647, 23.65394974], [92.07837677, 23.65363121], [92.07785034, 23.65231514], [92.07844543, 23.65192795], [92.07827759, 23.65120697], [92.07879639, 23.64980698], [92.07925415, 23.64869881], [92.07833099, 23.64845276], [92.07649994, 23.64888191], [92.07569122, 23.64854813], [92.07476044, 23.64751244], [92.07411194, 23.64774895], [92.0737915, 23.64758682], [92.07244873, 23.64690399], [92.07099152, 23.64741135], [92.07002258, 23.64772224], [92.06907654, 23.64827728], [92.06795502, 23.64797401], [92.06713104, 23.64699745], [92.06614685, 23.64670944], [92.06596375, 23.64612389], [92.06506348, 23.64623642], [92.06358337, 23.64583778], [92.06343079, 23.6453495], [92.06335449, 23.64511108], [92.06169891, 23.64551163], [92.0614624, 23.64620972], [92.06114197, 23.64716339], [92.05973053, 23.64748383], [92.05936432, 23.64787292], [92.05815125, 23.64811325], [92.05763245, 23.64855385], [92.05678558, 23.64849854], [92.05615234, 23.64845467], [92.05551147, 23.6487999], [92.05368042, 23.6486969], [92.05290222, 23.64883995], [92.05263519, 23.64888382], [92.05218506, 23.64896011], [92.05150604, 23.64923859], [92.05120087, 23.64905357], [92.05064392, 23.64945602], [92.04976654, 23.64936447], [92.04946136, 23.64834404], [92.04823303, 23.64787483], [92.048172, 23.64816666], [92.0477829, 23.64726448], [92.04764557, 23.6469326], [92.04602814, 23.64683342], [92.04496002, 23.64814949], [92.04426575, 23.64832497], [92.04395294, 23.64840508], [92.0430069, 23.6487484], [92.04199982, 23.6480999], [92.04029846, 23.64878654], [92.03887177, 23.6505127], [92.03926086, 23.65134811], [92.03799438, 23.65198517], [92.03742981, 23.65226364], [92.03699493, 23.65192413], [92.03691101, 23.65185738], [92.03688812, 23.65194702], [92.03675079, 23.65267563], [92.03561401, 23.65325737], [92.03528595, 23.65325928], [92.034729, 23.653265], [92.03427887, 23.65350533], [92.03408051, 23.65361214], [92.03311157, 23.65472603], [92.03314972, 23.65530014], [92.03234863, 23.65538406], [92.03210449, 23.65541077], [92.03211975, 23.65556145], [92.03215027, 23.65590858], [92.03147888, 23.65592194], [92.03124237, 23.65592766], [92.03127289, 23.65610695], [92.03145599, 23.65699959], [92.03083038, 23.65710068], [92.03043365, 23.65716362], [92.03053284, 23.65794373], [92.02999878, 23.65790749], [92.02960205, 23.65846252], [92.02851868, 23.65798569], [92.02799988, 23.65825844], [92.02790833, 23.65834045], [92.02767944, 23.6587429], [92.02722931, 23.65850449], [92.02703857, 23.6584816], [92.02706146, 23.65879822], [92.02635193, 23.65874481], [92.02609253, 23.65815353], [92.02478027, 23.65784454], [92.02470398, 23.65764618], [92.02458954, 23.65737343], [92.0243454, 23.65750122], [92.02397919, 23.65769577], [92.02368164, 23.65771484], [92.02314758, 23.65799332], [92.02304077, 23.6580162], [92.02259827, 23.65811539], [92.0221405, 23.65821838], [92.02233124, 23.65880775], [92.0223999, 23.65902519], [92.02250671, 23.65933418], [92.02265167, 23.65977097], [92.02366638, 23.66053009], [92.02420044, 23.66134262], [92.02390289, 23.66166496], [92.02418518, 23.66235924], [92.02336121, 23.66286278], [92.0231781, 23.66297722], [92.02313232, 23.66288567], [92.02285767, 23.6622982], [92.02224731, 23.66244125], [92.02213287, 23.66246796], [92.02225494, 23.66263771], [92.02226257, 23.6627903], [92.02207184, 23.66277885], [92.02111816, 23.66272926], [92.02050781, 23.66217804], [92.02016449, 23.66259003], [92.01987457, 23.66293716], [92.01842499, 23.66223335], [92.0173645, 23.66163445], [92.0165863, 23.66119766], [92.01589966, 23.65990829], [92.01469421, 23.66026306], [92.01457977, 23.6602993], [92.01397705, 23.66137886], [92.01361084, 23.66301346], [92.01321411, 23.66336823], [92.01292419, 23.66363144], [92.01207733, 23.66348648], [92.01147461, 23.66308403], [92.01046753, 23.66351318], [92.01006317, 23.66368294], [92.00953674, 23.66358757], [92.00892639, 23.66347694], [92.00842285, 23.66373062], [92.00771332, 23.66475868], [92.00691223, 23.66690636], [92.0066452, 23.66781044], [92.00719452, 23.66879272], [92.00659943, 23.66941261], [92.00632477, 23.67088509], [92.00517273, 23.67171478], [92.00328064, 23.67189598], [92.00166321, 23.67078781], [92.00123596, 23.67074776], [92.00053406, 23.670681], [91.99995422, 23.67133331], [92.00009918, 23.6733036], [92.00063324, 23.67353058], [91.99970245, 23.67436981], [91.99945068, 23.67459488], [91.99936676, 23.67518425], [91.9992981, 23.6756897], [91.99913788, 23.67816353], [91.9990387, 23.67777252], [91.99795532, 23.67920685], [91.99707794, 23.67969322], [91.99668884, 23.67990685], [91.99673462, 23.680233], [91.99610138, 23.68303108], [91.9953537, 23.68401146], [91.99545288, 23.68505669], [91.9948349, 23.6860466], [91.99458313, 23.68666458], [91.99503326, 23.68749428], [91.99383545, 23.6877346], [91.99356842, 23.68960571], [91.994133, 23.69129944], [91.99389648, 23.69293022], [91.99349976, 23.69327545], [91.99313354, 23.69482613], [91.99169922, 23.69608116], [91.99072266, 23.6979084], [91.98984528, 23.6999054], [91.9887619, 23.7011795], [91.98870087, 23.70206642], [91.98907471, 23.70257378], [91.9887619, 23.7030468], [91.98892212, 23.7048912], [91.9881897, 23.70605278], [91.98721313, 23.70838737], [91.98735809, 23.70983315], [91.98705292, 23.71133614], [91.98701477, 23.71153259], [91.98600769, 23.71310997], [91.98623657, 23.71369934], [91.98606873, 23.71510696], [91.98616028, 23.71557617], [91.98513031, 23.71650505], [91.98544312, 23.71919441], [91.98602295, 23.7200985], [91.98536682, 23.7218647], [91.98513794, 23.72304153], [91.98434448, 23.72309875], [91.98401642, 23.72409821], [91.98331451, 23.72369003], [91.98260498, 23.72327995], [91.980896, 23.72312737], [91.9804306, 23.7236557], [91.98013306, 23.72496223], [91.97963715, 23.72632027], [91.97976685, 23.7273674], [91.97917175, 23.72853851], [91.97802734, 23.73133278], [91.97802734, 23.73146439], [91.97805786, 23.73334122], [91.97684479, 23.73306847], [91.97729492, 23.73150635], [91.977211, 23.73149109], [91.97088623, 23.73028564], [91.96892548, 23.73002434], [91.96847534, 23.72963524], [91.96713257, 23.72963524], [91.96694946, 23.72982025], [91.96617889, 23.72974968], [91.96427155, 23.72913933], [91.96211243, 23.72770119], [91.95932007, 23.72340965], [91.95761108, 23.72062874], [91.95668793, 23.71913719], [91.95672607, 23.71789551], [91.95727539, 23.71588135], [91.95831299, 23.71307373], [91.95835114, 23.71007156], [91.95665741, 23.70795059], [91.95657349, 23.70714951], [91.95652771, 23.70676041], [91.95743561, 23.70386124], [91.95755005, 23.70341682], [91.95756531, 23.70328712], [91.95774078, 23.70160103], [91.95759583, 23.70074844], [91.95755005, 23.70049477], [91.95752716, 23.70036125], [91.95727539, 23.69909668], [91.95619965, 23.6975956], [91.95663452, 23.69755173], [91.95713806, 23.69750214], [91.9571991, 23.69622421], [91.95729065, 23.6943512], [91.95730591, 23.69398308], [91.95545197, 23.69397545], [91.95373535, 23.69338989], [91.95250702, 23.69181633], [91.9520874, 23.69128418], [91.95167542, 23.69097519], [91.95160675, 23.69091988], [91.94953918, 23.68925095], [91.94892883, 23.68887711], [91.94881439, 23.68880653], [91.94846344, 23.68850136], [91.94836426, 23.68843079], [91.94534302, 23.68624306], [91.94521332, 23.68612671], [91.94423676, 23.6853466], [91.94415283, 23.68523026], [91.94256592, 23.68329048], [91.94230652, 23.68180847], [91.94242096, 23.6814003], [91.94371033, 23.67669106], [91.94374084, 23.67660332], [91.94684601, 23.66825485], [91.94687653, 23.66816902], [91.95007324, 23.65808105], [91.95185089, 23.64694023], [91.95147705, 23.63928223], [91.95134735, 23.63695145], [91.95095825, 23.63286972], [91.95193481, 23.62936783], [91.95211029, 23.62873077], [91.95214844, 23.62866783], [91.95489502, 23.62371826], [91.95672607, 23.61791992], [91.95658112, 23.61429024], [91.95648193, 23.60809326], [91.95471191, 23.59588623], [91.95375824, 23.5932312], [91.95404816, 23.59184265], [91.95542145, 23.58995438], [91.95407867, 23.58693123], [91.95425415, 23.58652878], [91.95475769, 23.58675575], [91.95567322, 23.58717155], [91.95681763, 23.58734512], [91.95691681, 23.58729935], [91.95901489, 23.58634567], [91.95906067, 23.5862751], [91.96234131, 23.58133698], [91.96388245, 23.57888985], [91.96392059, 23.5788269], [91.96368408, 23.57507324], [91.96221161, 23.57174301], [91.96212769, 23.57160187], [91.96146393, 23.57050896], [91.96143341, 23.57042503], [91.96115112, 23.56950951], [91.96113586, 23.56943893], [91.96051025, 23.56707764], [91.96054077, 23.56655121], [91.96087646, 23.56591797], [91.96127319, 23.56510925], [91.96135712, 23.56503105], [91.96215057, 23.56401062], [91.96252441, 23.56373787], [91.96252441, 23.56263924], [91.96252441, 23.5625], [91.96255493, 23.56228447], [91.96279907, 23.56009293], [91.96287537, 23.55908012], [91.96290588, 23.55899811], [91.96368408, 23.55670166], [91.96389008, 23.55606651], [91.96398163, 23.55599213], [91.96429443, 23.5557251], [91.96569824, 23.55407715], [91.96508789, 23.55133057], [91.96490479, 23.55047607], [91.96448517, 23.54776382], [91.9644165, 23.54760933], [91.96335602, 23.54554939], [91.9629364, 23.54421806], [91.96276855, 23.5436821], [91.9627533, 23.54354858], [91.96252441, 23.54187012], [91.9620285, 23.54115295], [91.96251678, 23.54025841], [91.96278381, 23.53883171], [91.96308899, 23.5372448], [91.96450806, 23.53537369], [91.96437836, 23.5351181], [91.96347809, 23.53332138], [91.96163177, 23.53301048], [91.95885468, 23.53237534], [91.95793152, 23.53047562], [91.95788574, 23.53037643], [91.95678711, 23.52917671], [91.95623779, 23.52583504], [91.95782471, 23.52232552], [91.95962524, 23.51991463], [91.96006775, 23.51855087], [91.96034241, 23.51857567], [91.96443176, 23.51893425], [91.9631958, 23.51746368], [91.96421814, 23.51588058], [91.96522522, 23.51552391], [91.96616364, 23.51519394], [91.96607208, 23.51504898], [91.96813202, 23.51379776], [91.9686203, 23.51248741], [91.9686203, 23.5124073], [91.96871185, 23.5109272], [91.96871185, 23.51077271], [91.96858978, 23.50970078], [91.96898651, 23.50896072], [91.97027588, 23.50830078], [91.97187805, 23.50699043], [91.9730835, 23.50592041], [91.97423553, 23.50436592], [91.9743042, 23.50427246], [91.97406006, 23.50362015], [91.97394562, 23.50309753], [91.9724884, 23.50177956], [91.97210693, 23.50067139], [91.97169495, 23.49937057], [91.97223663, 23.49789047], [91.97271729, 23.49688721], [91.97515869, 23.49616814], [91.97607422, 23.49596024], [91.97603607, 23.49511909], [91.97598267, 23.49500465], [91.9755249, 23.49407959], [91.97363281, 23.49275017], [91.97323608, 23.49253845], [91.97305298, 23.49244118], [91.9727478, 23.49061012], [91.97374725, 23.48859978], [91.97384644, 23.48835182], [91.97387695, 23.48828125], [91.97451019, 23.48670387], [91.97453308, 23.4865551], [91.97458649, 23.48557091], [91.97518921, 23.48241043], [91.97332764, 23.480896], [91.97192383, 23.4810791], [91.97052002, 23.4814949], [91.97039795, 23.48153305], [91.96968079, 23.4815712], [91.96944427, 23.4815979], [91.96970367, 23.47862816], [91.96910858, 23.47650146], [91.96712494, 23.4772377], [91.96726227, 23.47809982], [91.96624756, 23.47836113], [91.96542358, 23.47857285], [91.96229553, 23.47831726], [91.96142578, 23.47824669], [91.95819092, 23.47966194], [91.95852661, 23.47763634], [91.95869446, 23.47661209], [91.95867157, 23.4730587], [91.95700836, 23.47413826], [91.95640564, 23.47588348], [91.95511627, 23.47553635], [91.95449066, 23.47491264], [91.95428467, 23.47467041], [91.95350647, 23.47392845], [91.95288086, 23.47332764], [91.95223236, 23.47248077], [91.95185852, 23.47052956], [91.94946289, 23.47035027], [91.94848633, 23.47027588], [91.94821167, 23.47026443], [91.94764709, 23.46970558], [91.94776917, 23.46678352], [91.94557953, 23.46596336], [91.94463348, 23.46777916], [91.94242096, 23.46665764], [91.94246674, 23.46648216], [91.94245148, 23.4663868], [91.94205475, 23.46411514], [91.94203186, 23.46401215], [91.94152832, 23.46148682], [91.94152832, 23.46087646], [91.94287109, 23.45770264], [91.94390869, 23.45587158], [91.94451904, 23.45471191], [91.94470215, 23.45391846], [91.94592285, 23.45050049], [91.94625092, 23.44951057], [91.94628143, 23.4494381], [91.94695282, 23.44768143], [91.94708252, 23.44653893], [91.94708252, 23.44628906], [91.94732666, 23.4440918], [91.94686127, 23.44350433], [91.94680023, 23.44340134], [91.94650269, 23.44286728], [91.94631958, 23.4417305], [91.94488525, 23.43988037], [91.94287109, 23.43847656], [91.94269562, 23.43832779], [91.94313049, 23.43710899], [91.94273376, 23.43524742], [91.94210815, 23.43494034], [91.94113922, 23.43522835], [91.94052124, 23.4354763], [91.94021606, 23.43494034], [91.93854523, 23.43423462], [91.9373703, 23.43252373], [91.93632507, 23.43288231], [91.93518829, 23.43323708], [91.93419647, 23.43368912], [91.93480682, 23.4352951], [91.9340744, 23.43563461], [91.93308258, 23.43602371], [91.93289185, 23.43530273], [91.93125153, 23.43455315], [91.93041992, 23.43535805], [91.92989349, 23.43465042], [91.92893982, 23.43455505], [91.92835236, 23.43413162], [91.92672729, 23.43391037], [91.92626953, 23.43447876], [91.92501831, 23.43432045], [91.92399597, 23.43375587], [91.92346954, 23.43488312], [91.9229126, 23.43542671], [91.92216492, 23.43644524], [91.92169189, 23.43694115], [91.92176056, 23.43808937], [91.92108154, 23.43827057], [91.92025757, 23.4388504], [91.91931915, 23.43841553], [91.91894531, 23.43957901], [91.91841125, 23.43973923], [91.91746521, 23.43851852], [91.9169693, 23.43899536], [91.91642761, 23.43874359], [91.91614532, 23.43830872], [91.91550446, 23.43810463], [91.91497803, 23.43759727], [91.91435242, 23.43711472], [91.91352081, 23.43751526], [91.91337585, 23.43688011], [91.91199493, 23.43684578], [91.91056824, 23.4370594], [91.91009521, 23.4368248], [91.90932465, 23.43670654], [91.90869141, 23.43702507], [91.90802765, 23.4371357], [91.90730286, 23.43746376], [91.90646362, 23.43703079], [91.90570831, 23.43790627], [91.90488434, 23.43767738], [91.90419769, 23.43860626], [91.90400696, 23.43863297], [91.9029541, 23.43877792], [91.90277863, 23.43948174], [91.90244293, 23.43962097], [91.90048218, 23.44042587], [91.89964294, 23.44072151], [91.899086, 23.44040871], [91.8993454, 23.43953514], [91.89975739, 23.43941307], [91.8997879, 23.43909264], [91.89969635, 23.43875885], [91.89958191, 23.43837357], [91.89971924, 23.43829346], [91.90106201, 23.43711281], [91.90046692, 23.43593788], [91.89836884, 23.43515778], [91.89782715, 23.4349556], [91.8976593, 23.43504906], [91.8973999, 23.4348278], [91.89694214, 23.43400764], [91.89646912, 23.43375969], [91.89567566, 23.43353081], [91.89601135, 23.43259048], [91.89519501, 23.43152428], [91.8940506, 23.4315815], [91.89363098, 23.43247986], [91.89334869, 23.43252373], [91.89278412, 23.43261147], [91.89230347, 23.43328857], [91.89186859, 23.43347359], [91.89138031, 23.4336834], [91.89057159, 23.43378258], [91.88993835, 23.43351936], [91.88897705, 23.43343925], [91.88832092, 23.43316269], [91.88735199, 23.43311119], [91.88773346, 23.43206596], [91.88777161, 23.43153381], [91.88814545, 23.43083763], [91.88851929, 23.43026161], [91.88864899, 23.42945671], [91.88807678, 23.42912674], [91.88781738, 23.42849541], [91.88707733, 23.42783356], [91.88687134, 23.42698288], [91.8855896, 23.42634964], [91.88508606, 23.42596054], [91.8841629, 23.4255867], [91.88339233, 23.42564011], [91.88304138, 23.42539597], [91.88231659, 23.42532921], [91.88186646, 23.42399597], [91.88046265, 23.42397308], [91.87996674, 23.42367744], [91.87975311, 23.42309189], [91.87866974, 23.42302132], [91.87825775, 23.42230988], [91.87638092, 23.4224205], [91.87584686, 23.42056084], [91.87477875, 23.4200325], [91.87401581, 23.41926575], [91.8735199, 23.41662216], [91.87316132, 23.41538811], [91.87309265, 23.41514587], [91.87316132, 23.4149971], [91.87355042, 23.4141922], [91.87296295, 23.41433525], [91.87231445, 23.41411018], [91.87185669, 23.4141407], [91.87153625, 23.41415977], [91.87145233, 23.414114], [91.87104797, 23.41369438], [91.87052155, 23.41303444], [91.87000275, 23.41313362], [91.86971283, 23.41318893], [91.86933136, 23.41326332], [91.86871338, 23.41265678], [91.86846924, 23.41241837], [91.86830902, 23.41244125], [91.86688232, 23.41168213], [91.86639404, 23.41119576], [91.86629486, 23.41109848], [91.86557007, 23.40982628], [91.8655014, 23.4097538], [91.86495209, 23.40984154], [91.86399841, 23.40916443], [91.86392212, 23.40866852], [91.86307526, 23.40784264], [91.86190033, 23.40760422], [91.86032867, 23.40626717], [91.86038971, 23.40598679], [91.8605423, 23.4053154], [91.85852814, 23.40513611], [91.85843658, 23.40521622], [91.85758972, 23.40593147], [91.85679626, 23.40528679], [91.85660553, 23.40550423], [91.85617828, 23.40599823], [91.85540771, 23.40594101], [91.85535431, 23.4066658], [91.85474396, 23.40681076], [91.85385895, 23.40649796], [91.85284424, 23.4063797], [91.8528595, 23.40557671], [91.85194397, 23.40506935], [91.85165405, 23.40448952], [91.85085297, 23.40421295], [91.85041046, 23.40489197], [91.84841919, 23.40529251], [91.84503937, 23.4047699], [91.84533691, 23.40287399], [91.84529114, 23.4007225], [91.8430481, 23.40031242], [91.84307098, 23.39932823], [91.84192657, 23.39976501], [91.84104156, 23.39985466], [91.8407135, 23.39897346], [91.84091949, 23.39791107], [91.84150696, 23.39692307], [91.84150696, 23.39427376], [91.84144592, 23.39154625], [91.84185791, 23.39097404], [91.84205627, 23.38939476], [91.84185791, 23.38847923], [91.83853149, 23.38715553], [91.83685303, 23.38742638], [91.8369751, 23.38699722], [91.8361969, 23.38660622], [91.83635712, 23.38554764], [91.8365097, 23.38329124], [91.8369751, 23.38127708], [91.83779907, 23.37875557], [91.83750916, 23.37717056], [91.83707428, 23.37535477], [91.83758545, 23.37508965], [91.83777618, 23.37410355], [91.8379364, 23.37314415], [91.83789825, 23.37287331], [91.83761597, 23.37090683], [91.83589172, 23.37021446], [91.83548737, 23.37013245], [91.83283234, 23.36959457], [91.83242798, 23.3699131], [91.83187866, 23.36845779], [91.83219147, 23.36722374], [91.83177948, 23.36591148], [91.83156586, 23.36523628], [91.83047485, 23.36421776], [91.83003235, 23.36467171], [91.82847595, 23.36626434], [91.82823944, 23.36527252], [91.82714844, 23.36506462], [91.82627106, 23.36355209], [91.82556152, 23.36329269], [91.8258667, 23.36279297], [91.82538605, 23.35972977], [91.82532501, 23.35931969], [91.82556915, 23.35864258], [91.82556152, 23.35802841], [91.82523346, 23.35726929], [91.82511902, 23.35634232], [91.8248291, 23.35612297], [91.82518005, 23.35599709], [91.82521057, 23.35550499], [91.82548523, 23.35512352], [91.82515717, 23.35489655], [91.8249588, 23.35420799], [91.82530212, 23.35352516], [91.82505035, 23.35245323], [91.82471466, 23.35249138], [91.82423401, 23.35205269], [91.82299042, 23.35193253], [91.82246399, 23.35156441], [91.82208252, 23.35151672], [91.82161713, 23.3514576], [91.82143402, 23.35143471], [91.82115936, 23.35176659], [91.82021332, 23.35134697], [91.81964874, 23.35110664], [91.81920624, 23.35122871], [91.8189621, 23.3507843], [91.81851196, 23.35051155], [91.81855011, 23.34954262], [91.818367, 23.3490963], [91.81851959, 23.34883881], [91.81771088, 23.34874916], [91.81742096, 23.34807777], [91.81744385, 23.34771538], [91.81731415, 23.34755135], [91.81789398, 23.3474617], [91.817276, 23.34715271], [91.81772614, 23.34711647], [91.81761169, 23.34698105], [91.81752014, 23.34668922], [91.81803131, 23.346735], [91.81796265, 23.34649849], [91.81717682, 23.34608078], [91.81716156, 23.345644], [91.81684113, 23.34567261], [91.81629181, 23.34515381], [91.8164444, 23.34489059], [91.81585693, 23.34472847], [91.81520844, 23.34436417], [91.81538391, 23.34410095], [91.81491852, 23.34393883], [91.81497192, 23.34423828], [91.81462097, 23.34415627], [91.81448364, 23.3443203], [91.8144455, 23.34439278], [91.81349945, 23.34366226], [91.81343079, 23.34361458], [91.81053925, 23.34155083], [91.80882263, 23.33940697], [91.80825806, 23.33870697], [91.80751801, 23.33725739], [91.80774689, 23.3373642], [91.80764771, 23.33711052], [91.80818939, 23.33721161], [91.80712891, 23.33648872], [91.80718231, 23.33585739], [91.80704498, 23.33592224], [91.80714417, 23.33569717], [91.80686188, 23.33538246], [91.80651855, 23.33530045], [91.80651855, 23.33485031], [91.80628204, 23.33498192], [91.8059845, 23.33436394], [91.80644226, 23.33407784], [91.80582428, 23.33343315], [91.80532837, 23.33298302], [91.80527496, 23.3328743], [91.80516052, 23.33263969], [91.80263519, 23.32894516], [91.80253601, 23.32876968], [91.79888916, 23.32232666], [91.79608154, 23.31750488], [91.79533386, 23.31635475], [91.79528809, 23.31628418], [91.79174042, 23.31072617], [91.79208374, 23.31235504], [91.7902832, 23.30908203], [91.78990936, 23.30810738], [91.78987885, 23.30801964], [91.78937531, 23.30649757], [91.7893219, 23.30637169], [91.78845978, 23.30434608], [91.78839111, 23.30419159], [91.78808594, 23.30352783], [91.78676605, 23.30063057], [91.78631592, 23.29968262], [91.78533936, 23.29862976], [91.78520966, 23.29855919], [91.78309631, 23.29412079], [91.78305817, 23.29401588], [91.7822876, 23.29187012], [91.7817688, 23.2907505], [91.78112793, 23.28851318], [91.78030396, 23.28786278], [91.78025055, 23.28776741], [91.77988434, 23.28712273], [91.77983856, 23.28704071], [91.77947998, 23.28668213], [91.77830505, 23.28529167], [91.7782135, 23.28511238], [91.7769165, 23.2824707], [91.77614594, 23.28007126], [91.77575684, 23.27947998], [91.77484894, 23.27806091], [91.77490234, 23.27612305], [91.77481842, 23.27288818], [91.77288818, 23.27008057], [91.77294159, 23.26990509], [91.77313995, 23.26991081], [91.77329254, 23.26988602], [91.77339172, 23.269907], [91.77349854, 23.26996613], [91.77359772, 23.27015877], [91.77378845, 23.2701664], [91.77387238, 23.27009773], [91.77394104, 23.27005005], [91.77398682, 23.26994705], [91.77392578, 23.26984024], [91.77390289, 23.2697525], [91.77391815, 23.26965714], [91.77399445, 23.26952934], [91.774086, 23.26943016], [91.77416992, 23.26937485], [91.77426147, 23.26936531], [91.7744751, 23.26938438], [91.77458954, 23.26940346], [91.77472687, 23.26936531], [91.77500916, 23.26943207], [91.77510834, 23.2696476], [91.77513123, 23.2697258], [91.77534485, 23.26990318], [91.77552795, 23.27008438], [91.7756424, 23.2701664], [91.77584839, 23.27018356], [91.77594757, 23.27012253], [91.77602386, 23.2700386], [91.77610016, 23.26993942], [91.77622986, 23.26986504], [91.77641296, 23.2697773], [91.77659607, 23.26973343], [91.77666473, 23.26969337], [91.77667999, 23.26958084], [91.77674866, 23.26950836], [91.7769165, 23.26943779], [91.7769928, 23.26936531], [91.77695465, 23.26923943], [91.77696991, 23.26916885], [91.77694702, 23.26909065], [91.77687073, 23.26901627], [91.77674866, 23.26887703], [91.77661896, 23.26865768], [91.77655792, 23.26855469], [91.77655792, 23.26848221], [91.77651978, 23.26841736], [91.77645874, 23.26827049], [91.77639771, 23.26819038], [91.77629852, 23.26807594], [91.77624512, 23.26796722], [91.77622223, 23.26788521], [91.77619171, 23.26778221], [91.77613831, 23.26763344], [91.77618408, 23.26751709], [91.77620697, 23.2674408], [91.77619934, 23.26734352], [91.7760849, 23.26720428], [91.77602386, 23.26707077], [91.77600098, 23.26696777], [91.77601624, 23.26682281], [91.77606964, 23.266716], [91.77613831, 23.26666832], [91.77629089, 23.26663208], [91.77645874, 23.26660919], [91.77654266, 23.2665863], [91.77659607, 23.26646614], [91.77659607, 23.26634979], [91.77648926, 23.2660141], [91.77639771, 23.26580238], [91.77632141, 23.26569557], [91.77627563, 23.26560974], [91.77623749, 23.26550102], [91.77616119, 23.26544189], [91.77610016, 23.26537895], [91.77604675, 23.2652607], [91.77612305, 23.26498795], [91.77610779, 23.26488876], [91.77610016, 23.26478195], [91.77616882, 23.26451874], [91.77620697, 23.26444054], [91.77630615, 23.26424599], [91.77642059, 23.26406097], [91.77655029, 23.26388931], [91.77661896, 23.26381111], [91.77663422, 23.2637043], [91.77669525, 23.26357651], [91.77667999, 23.2634964], [91.77659607, 23.26342201], [91.77643585, 23.26345062], [91.77632904, 23.26343346], [91.77615356, 23.26329803], [91.77605438, 23.26322746], [91.77586365, 23.26311684], [91.77574158, 23.26300812], [91.77572632, 23.26293755], [91.77575684, 23.26282692], [91.77588654, 23.26275826], [91.77600098, 23.26271629], [91.77610779, 23.26262283], [91.77614594, 23.26249886], [91.77614594, 23.26237106], [91.77606201, 23.26226807], [91.77587128, 23.26219559], [91.77561188, 23.26216698], [91.77544403, 23.26218796], [91.77529907, 23.26212883], [91.77535248, 23.26196671], [91.77535248, 23.26185989], [91.77536011, 23.26167297], [91.775383, 23.26158905], [91.7754364, 23.26151466], [91.77553558, 23.26140976], [91.7756958, 23.26127434], [91.77577209, 23.26122856], [91.77594757, 23.26115608], [91.77614594, 23.26104736], [91.77628326, 23.26095963], [91.77639771, 23.2609005], [91.7765274, 23.26088905], [91.77670288, 23.26088524], [91.77683258, 23.26088524], [91.77696228, 23.26086044], [91.77703094, 23.26078415], [91.77706146, 23.26069832], [91.77711487, 23.26057434], [91.77722931, 23.26045609], [91.7773819, 23.26019287], [91.77745819, 23.26006126], [91.77741241, 23.25984764], [91.7773056, 23.25969315], [91.77722931, 23.25958443], [91.77700806, 23.25959587], [91.7769165, 23.25965118], [91.77675629, 23.25975227], [91.7766571, 23.25978279], [91.77658081, 23.25973892], [91.77658081, 23.25965881], [91.77653503, 23.25960159], [91.77651215, 23.25952148], [91.77646637, 23.25941467], [91.77643585, 23.25934029], [91.77639771, 23.25913239], [91.77631378, 23.2589798], [91.77627563, 23.2588768], [91.77623749, 23.25871658], [91.77624512, 23.25855446], [91.77624512, 23.25843811], [91.77628326, 23.25835228], [91.77637482, 23.25825691], [91.776474, 23.25808525], [91.77661896, 23.25792122], [91.7768631, 23.25762558], [91.77689362, 23.25752258], [91.77675629, 23.2574501], [91.77663422, 23.25738525], [91.77656555, 23.25734138], [91.77645111, 23.25728607], [91.77629852, 23.25730515], [91.77609253, 23.25738144], [91.77597809, 23.25754547], [91.77587128, 23.25761414], [91.77577209, 23.25766754], [91.7756424, 23.25753975], [91.77555084, 23.25743675], [91.77541351, 23.25735855], [91.77532196, 23.25734138], [91.77516937, 23.25728607], [91.77502441, 23.25719643], [91.7749176, 23.2570591], [91.77487946, 23.25695038], [91.7749176, 23.25680542], [91.77503204, 23.25659943], [91.77510071, 23.25642395], [91.77513885, 23.25625038], [91.77515411, 23.25607681], [91.77510071, 23.25592422], [91.77510071, 23.25583267], [91.7751236, 23.25574303], [91.77522278, 23.25567055], [91.77539062, 23.25568008], [91.77561951, 23.25563812], [91.77578735, 23.25561523], [91.77597046, 23.25554276], [91.77611542, 23.25547028], [91.77633667, 23.25535202], [91.77642822, 23.25532341], [91.77653503, 23.25532532], [91.77661133, 23.25529861], [91.77679443, 23.25521469], [91.77690887, 23.25518799], [91.7769928, 23.25518227], [91.77710724, 23.25528526], [91.77720642, 23.25543976], [91.77722168, 23.25563622], [91.77723694, 23.25574684], [91.77734375, 23.25592041], [91.7774353, 23.25606918], [91.77751923, 23.25623131], [91.77762604, 23.25632668], [91.77771759, 23.25642586], [91.77797699, 23.25657463], [91.7780838, 23.25659561], [91.77815247, 23.25653267], [91.77819061, 23.25644684], [91.77819061, 23.25628662], [91.77820587, 23.25616646], [91.77824402, 23.25607872], [91.77824402, 23.25597382], [91.77819824, 23.25581169], [91.77816772, 23.25568771], [91.77812195, 23.25559616], [91.77809143, 23.25549698], [91.77809143, 23.2553463], [91.77812958, 23.25518799], [91.77819824, 23.25505829], [91.77822876, 23.25492477], [91.77828979, 23.25481606], [91.77842712, 23.25470924], [91.77858734, 23.25455856], [91.77867889, 23.25452805], [91.77879333, 23.25447655], [91.77886963, 23.25449181], [91.77896881, 23.25441742], [91.77913666, 23.25435829], [91.77926636, 23.25428009], [91.77934265, 23.25423622], [91.77951813, 23.25406647], [91.7796936, 23.25389671], [91.77970123, 23.2537899], [91.77941895, 23.25350761], [91.77933502, 23.2534523], [91.77919769, 23.25332642], [91.77909088, 23.25321388], [91.77896881, 23.25304985], [91.77886963, 23.25289726], [91.77864075, 23.25262642], [91.77856445, 23.25247192], [91.77850342, 23.25240326], [91.77845764, 23.25231171], [91.77841187, 23.25216484], [91.77839661, 23.25205421], [91.77840424, 23.2519207], [91.77845001, 23.25180244], [91.77851868, 23.25174522], [91.77864075, 23.25177765], [91.77872467, 23.25180817], [91.77883911, 23.25184822], [91.77901459, 23.25184631], [91.77914429, 23.25184631], [91.77926636, 23.25180054], [91.77935028, 23.25175476], [91.77936554, 23.25168228], [91.77932739, 23.25155449], [91.77931213, 23.25143623], [91.77932739, 23.2513485], [91.77936554, 23.2512188], [91.77938843, 23.25105095], [91.77939606, 23.25082016], [91.77938843, 23.25069427], [91.77944946, 23.25051308], [91.77944183, 23.2504406], [91.77950287, 23.25029182], [91.77944946, 23.25018692], [91.77940369, 23.2501297], [91.7793045, 23.25006866], [91.77919006, 23.24998093], [91.77905273, 23.24987602], [91.77901459, 23.24981308], [91.77901459, 23.24971581], [91.77910614, 23.24955368], [91.7792511, 23.24945068], [91.77933502, 23.24935722], [91.77935791, 23.24928856], [91.77931976, 23.24881172], [91.77934265, 23.2486496], [91.77936554, 23.24848557], [91.77936554, 23.24834251], [91.77938843, 23.24819756], [91.7793808, 23.24799538], [91.77944946, 23.24794769], [91.7795639, 23.24787521], [91.77963257, 23.24777603], [91.77968597, 23.24764252], [91.77977753, 23.247509], [91.77985382, 23.24747086], [91.77993774, 23.24744225], [91.78007507, 23.2474308], [91.78022003, 23.24734879], [91.78030396, 23.24720573], [91.7803421, 23.24712181], [91.78031158, 23.24698639], [91.78029633, 23.246912], [91.7802124, 23.24682426], [91.78005219, 23.24684334], [91.7800293, 23.24674034], [91.77991486, 23.24671555], [91.77980804, 23.24668884], [91.77973175, 23.24678802], [91.77959442, 23.24678612], [91.7795105, 23.24688148], [91.77926636, 23.24692535], [91.7791748, 23.24691391], [91.77909851, 23.24692917], [91.77898407, 23.24692917], [91.77889252, 23.24689674], [91.77875519, 23.24682426], [91.77867889, 23.24674988], [91.7786026, 23.24664307], [91.77853394, 23.24654198], [91.77842712, 23.24640465], [91.77836609, 23.24626923], [91.77826691, 23.24596596], [91.77824402, 23.24570465], [91.77817535, 23.24560547], [91.77809143, 23.24551582], [91.77797699, 23.24546242], [91.77776337, 23.2454071], [91.77770996, 23.24535561], [91.77768707, 23.24522591], [91.77770233, 23.24506378], [91.77783203, 23.24503326], [91.77783203, 23.24489975], [91.77785492, 23.24481583], [91.77787018, 23.24470711], [91.77785492, 23.24460793], [91.77780914, 23.24453545], [91.77774811, 23.24447441], [91.77765656, 23.24441147], [91.77735138, 23.24438667], [91.77721405, 23.24436188], [91.77709198, 23.24433517], [91.77700806, 23.2443428], [91.77687073, 23.24434471], [91.77680206, 23.24431419], [91.7765274, 23.2442627], [91.7763443, 23.24419212], [91.77728271, 23.24291992], [91.77830505, 23.24123764], [91.77841187, 23.24121094], [91.77851105, 23.24118614], [91.77864075, 23.24114037], [91.77877045, 23.2411232], [91.77888489, 23.24105072], [91.77898407, 23.24093819], [91.77902985, 23.24084282], [91.77905273, 23.24070168], [91.77908325, 23.24049377], [91.7791748, 23.24043083], [91.77935028, 23.24030876], [91.77957916, 23.24032211], [91.77967834, 23.24028587], [91.77970886, 23.24015808], [91.77967072, 23.24008179], [91.77990723, 23.23991394], [91.77993774, 23.24008751], [91.77997589, 23.24017525], [91.78007507, 23.24032021], [91.78012848, 23.24045181], [91.78025818, 23.24060631], [91.78040314, 23.24077415], [91.78047943, 23.24090576], [91.78062439, 23.24099159], [91.7807312, 23.24105072], [91.78083801, 23.24107742], [91.78096008, 23.24116516], [91.78100586, 23.24123192], [91.78108978, 23.24131584], [91.78115082, 23.24148369], [91.78121185, 23.2415638], [91.78122711, 23.24165916], [91.78123474, 23.24173737], [91.78121948, 23.24183655], [91.78113556, 23.24190903], [91.78108215, 23.24200058], [91.78096771, 23.24199295], [91.78089905, 23.24204063], [91.78073883, 23.24197197], [91.78051758, 23.24205208], [91.78038788, 23.24215508], [91.78031921, 23.24219131], [91.78020477, 23.24222755], [91.78012848, 23.24233627], [91.78014374, 23.24247932], [91.78011322, 23.24264526], [91.78011322, 23.2427845], [91.78012848, 23.24286652], [91.78028107, 23.24306679], [91.78032684, 23.24318886], [91.7803421, 23.24329948], [91.78048706, 23.24344444], [91.78063965, 23.24353409], [91.7807312, 23.24349785], [91.78089905, 23.24357986], [91.78097534, 23.24360847], [91.78115082, 23.24362564], [91.78131104, 23.24360847], [91.78139496, 23.24352837], [91.78148651, 23.2434082], [91.78156281, 23.24333382], [91.7816925, 23.24332047], [91.7817688, 23.24337959], [91.78186035, 23.24354362], [91.78183746, 23.24367142], [91.7818985, 23.24378014], [91.78197479, 23.24377441], [91.78207397, 23.24377823], [91.78213501, 23.24370766], [91.78227234, 23.2435627], [91.78227234, 23.24343491], [91.78227234, 23.24333572], [91.78230286, 23.24326134], [91.78239441, 23.24324417], [91.78250885, 23.24331284], [91.78263855, 23.24340439], [91.78277588, 23.24344826], [91.78295135, 23.24348259], [91.78314972, 23.24348068], [91.78329468, 23.24349976], [91.7833786, 23.24350739], [91.78348541, 23.24342728], [91.78353119, 23.24336243], [91.78340912, 23.24318886], [91.78331757, 23.24306488], [91.78320313, 23.24295235], [91.78305054, 23.24280739], [91.78302002, 23.24273872], [91.78307343, 23.24262619], [91.78321838, 23.24245644], [91.7833252, 23.2423172], [91.78343201, 23.24220848], [91.78350067, 23.2421627], [91.78363037, 23.24213028], [91.78372955, 23.24206543], [91.78382111, 23.24197769], [91.78383636, 23.24189568], [91.78383636, 23.24180031], [91.78383636, 23.24158478], [91.78386688, 23.24150276], [91.78394318, 23.24148941], [91.78421021, 23.24148178], [91.78433228, 23.24140358], [91.78445435, 23.24133301], [91.78448486, 23.24118233], [91.78442383, 23.24105453], [91.7842865, 23.24096489], [91.78416443, 23.24084091], [91.7841568, 23.24070168], [91.78411865, 23.24051094], [91.78411865, 23.24041748], [91.7841568, 23.24029732], [91.78424835, 23.24019623], [91.78436279, 23.24013329], [91.78451538, 23.24004936], [91.78468323, 23.23989677], [91.78482819, 23.23976517], [91.7850647, 23.23963737], [91.78517914, 23.23948288], [91.78526306, 23.23935699], [91.78531647, 23.23925781], [91.78533936, 23.23917389], [91.78533936, 23.23897552], [91.78527832, 23.23892403], [91.78521729, 23.2388649], [91.78514099, 23.23882103], [91.7850647, 23.23881531], [91.78497314, 23.2388382], [91.78490448, 23.23889732], [91.78487396, 23.23896599], [91.78474426, 23.23910141], [91.78466797, 23.23915672], [91.78451538, 23.2392292], [91.78440094, 23.23921967], [91.78426361, 23.23915291], [91.78421021, 23.23906898], [91.78417969, 23.23899269], [91.78417206, 23.23877907], [91.78417969, 23.23870277], [91.78423309, 23.2384758], [91.78425598, 23.23832512], [91.78432465, 23.23819351], [91.78438568, 23.23804855], [91.78439331, 23.23790359], [91.7844162, 23.23773956], [91.78443909, 23.23753357], [91.78448486, 23.2373333], [91.78456116, 23.23719406], [91.7845459, 23.23698616], [91.78451538, 23.23690414], [91.7844162, 23.23683357], [91.78426361, 23.23673439], [91.78414154, 23.23662567], [91.78422546, 23.23653984], [91.78432465, 23.23644257], [91.78729248, 23.23352051], [91.7888031, 23.23214149], [91.79206848, 23.22916794], [91.79203796, 23.22909355], [91.79187012, 23.22887039], [91.79158783, 23.22871017], [91.79102325, 23.22694016], [91.79096222, 23.22675514], [91.7909317, 23.226614], [91.7907486, 23.22552681], [91.79090118, 23.22570419], [91.79100037, 23.22582245], [91.79111481, 23.22578621], [91.79116058, 23.22569656], [91.79118347, 23.22556686], [91.79114532, 23.22545624], [91.7911377, 23.22537994], [91.79113007, 23.22523499], [91.79113007, 23.22480202], [91.79111481, 23.22462845], [91.79111481, 23.22444153], [91.79111481, 23.22432137], [91.79108429, 23.22424507], [91.79084015, 23.22392464], [91.79083252, 23.22381401], [91.79091644, 23.22374153], [91.79105377, 23.22374535], [91.79137421, 23.2237606], [91.79149628, 23.22372627], [91.79161835, 23.2236805], [91.79162598, 23.22360611], [91.79161835, 23.22352982], [91.79158783, 23.2233429], [91.79151917, 23.22322464], [91.79136658, 23.22311592], [91.79132843, 23.2230072], [91.79116821, 23.22297096], [91.79107666, 23.22293472], [91.79087067, 23.22295189], [91.79034424, 23.22281647], [91.79030609, 23.22273064], [91.7903595, 23.22255516], [91.79042816, 23.22242546], [91.79051208, 23.22231293], [91.7905426, 23.22220993], [91.79050446, 23.22211647], [91.79046631, 23.22195244], [91.79029083, 23.22179794], [91.79019928, 23.22168922], [91.7901535, 23.22157097], [91.7901535, 23.22139168], [91.79017639, 23.22118187], [91.79022217, 23.22102356], [91.79032898, 23.22088242], [91.79046631, 23.22079086], [91.79058838, 23.22073555], [91.79073334, 23.22062683], [91.79084015, 23.22055435], [91.79105377, 23.22028542], [91.79113007, 23.22013664], [91.79130554, 23.21984863], [91.79132843, 23.21975708], [91.79138184, 23.21964836], [91.79151917, 23.2195015], [91.79164124, 23.21934128], [91.79172516, 23.21911812], [91.79179382, 23.21866989], [91.79184723, 23.21841049], [91.79184723, 23.2182827], [91.79171753, 23.2181015], [91.79156494, 23.21799278], [91.79144287, 23.21794701], [91.79125214, 23.21783829], [91.79101563, 23.21770287], [91.79088593, 23.21765709], [91.79071808, 23.2176342], [91.7903595, 23.21752167], [91.78995514, 23.21742058], [91.78977966, 23.21737289], [91.78949738, 23.21731949], [91.78929901, 23.21725845], [91.78904724, 23.2171936], [91.78879547, 23.21708488], [91.78845215, 23.216959], [91.78833008, 23.21690369], [91.78823853, 23.21679688], [91.7881546, 23.21666718], [91.78810883, 23.21650887], [91.78810883, 23.21635246], [91.78813171, 23.21596146], [91.78804016, 23.21573257], [91.78794098, 23.21556664], [91.78822327, 23.21493721], [91.78847504, 23.21479607], [91.7886734, 23.21470642], [91.78878784, 23.21465111], [91.78897858, 23.21456146], [91.7891922, 23.21445084], [91.78931427, 23.21439743], [91.78942108, 23.21434212], [91.78970337, 23.21429062], [91.78987885, 23.21425247], [91.79003143, 23.21421432], [91.79018402, 23.21410751], [91.79026031, 23.2140522], [91.79031372, 23.21397591], [91.79038239, 23.21380234], [91.7904129, 23.21362686], [91.79051971, 23.21347237], [91.79058838, 23.21336365], [91.7906723, 23.21324921], [91.79084778, 23.21291542], [91.79095459, 23.21281242], [91.7910614, 23.21274376], [91.79129791, 23.21267128], [91.79140472, 23.2126255], [91.79154968, 23.21253395], [91.79160309, 23.21245193], [91.79160309, 23.21236229], [91.79155731, 23.21227264], [91.79146576, 23.21215248], [91.79138947, 23.21207237], [91.79130554, 23.21202469], [91.79108429, 23.21194458], [91.79090881, 23.21191025], [91.79076385, 23.21183586], [91.79071808, 23.21174812], [91.79074097, 23.21163559], [91.79083252, 23.21155357], [91.79096985, 23.21145439], [91.79109192, 23.21141815], [91.79118347, 23.21138382], [91.79128265, 23.21137238], [91.79140472, 23.2113266], [91.79151154, 23.21128082], [91.79170227, 23.21114349], [91.79177856, 23.21107292], [91.79192352, 23.21087265], [91.79189301, 23.21074867], [91.79187012, 23.21061897], [91.7918396, 23.21052933], [91.79176331, 23.21035957], [91.79164124, 23.21017075], [91.79180145, 23.21002007], [91.79186249, 23.21013641], [91.7919693, 23.21016502], [91.79205322, 23.21014595], [91.79216003, 23.21004105], [91.79227448, 23.2099247], [91.79239655, 23.20971107], [91.79252625, 23.20954704], [91.79256439, 23.20942116], [91.79255676, 23.20927048], [91.79272461, 23.20910645], [91.79290771, 23.20849609], [91.79299164, 23.20779991], [91.79351807, 23.20568848], [91.79389191, 23.20147705], [91.79394531, 23.2014122], [91.79501343, 23.20017815], [91.79512787, 23.20010757], [91.79607391, 23.19950867], [91.79612732, 23.19944], [91.79651642, 23.19893837], [91.79683685, 23.19853592], [91.79721069, 23.19794846], [91.79727936, 23.19783783], [91.79940796, 23.19667816], [91.8000946, 23.19268608], [91.80006409, 23.19257545], [91.79992676, 23.19207764], [91.79933167, 23.1903038], [91.79929352, 23.19022179], [91.79897308, 23.18922043], [91.79872894, 23.18706894], [91.80029297, 23.18548584], [91.80056763, 23.18413162], [91.80076599, 23.18406487], [91.80085754, 23.18402481], [91.80097198, 23.18391228], [91.80104065, 23.18381691], [91.80110931, 23.18363762], [91.80112457, 23.18354988], [91.80105591, 23.18343735], [91.80097961, 23.18333244], [91.80096436, 23.18325996], [91.80092621, 23.18313217], [91.80098724, 23.18302917], [91.80120087, 23.18289566], [91.8013382, 23.18282318], [91.80146027, 23.18273544], [91.80153656, 23.18264961], [91.8015976, 23.18254089], [91.80173492, 23.18245125], [91.80191803, 23.18234062], [91.80200195, 23.18230438], [91.80213165, 23.18220901], [91.80239868, 23.18203354], [91.80259705, 23.18193245], [91.80283356, 23.18185234], [91.80307007, 23.18183899], [91.80318451, 23.18182373], [91.80334473, 23.18179703], [91.80354309, 23.18174744], [91.80369568, 23.18165588], [91.80375671, 23.18156624], [91.80379486, 23.18142509], [91.80383301, 23.18128586], [91.80393982, 23.18114281], [91.80399323, 23.18108368], [91.80412292, 23.18105316], [91.80429077, 23.18100548], [91.80445099, 23.18095207], [91.80455017, 23.18091202], [91.80476379, 23.18086052], [91.80492401, 23.18082237], [91.80505371, 23.1807518], [91.80516815, 23.18068123], [91.80528259, 23.18047523], [91.805336, 23.18033409], [91.8053894, 23.18020439], [91.80539703, 23.18007088], [91.80535126, 23.17986298], [91.80545044, 23.17967033], [91.80558014, 23.179533], [91.80571747, 23.1794281], [91.80588531, 23.1793766], [91.80605316, 23.17934227], [91.80618286, 23.17926407], [91.80620575, 23.17918777], [91.80603027, 23.17903328], [91.80584717, 23.17891312], [91.80574036, 23.17882156], [91.80558014, 23.17861748], [91.80547333, 23.17854309], [91.80535126, 23.17848778], [91.8052063, 23.17851257], [91.80503082, 23.17853737], [91.80483246, 23.17848778], [91.80474854, 23.17848015], [91.80465698, 23.17842102], [91.80455017, 23.17835426], [91.80451965, 23.17827797], [91.80445862, 23.17815781], [91.80437469, 23.1780014], [91.80430603, 23.17788124], [91.80426788, 23.17763329], [91.80427551, 23.17751122], [91.80434418, 23.17720985], [91.80431366, 23.17706299], [91.80425262, 23.17694664], [91.80414581, 23.17688751], [91.80405426, 23.17690849], [91.80386353, 23.17694092], [91.80360413, 23.17697716], [91.80352783, 23.17701149], [91.80331421, 23.17705536], [91.80318451, 23.17704391], [91.80311584, 23.17698669], [91.80312347, 23.1768074], [91.80318451, 23.17669106], [91.80336761, 23.17653656], [91.80345154, 23.17644691], [91.80356598, 23.17628479], [91.80370331, 23.17606544], [91.80393982, 23.17595291], [91.80406189, 23.17595673], [91.80422211, 23.17591095], [91.80430603, 23.17583275], [91.80437469, 23.17573738], [91.80439758, 23.17555618], [91.80442047, 23.17539597], [91.80444336, 23.17526817], [91.80435944, 23.17510223], [91.80419922, 23.17492676], [91.80406952, 23.17477608], [91.80405426, 23.17468834], [91.80410767, 23.17460442], [91.80423737, 23.17460442], [91.80437469, 23.17462921], [91.80446625, 23.17465973], [91.80459595, 23.17465973], [91.8046875, 23.1746788], [91.80484009, 23.17474937], [91.80495453, 23.17485619], [91.80500793, 23.1749382], [91.80501556, 23.17507935], [91.80502319, 23.17515564], [91.80500793, 23.17531967], [91.80493164, 23.17560959], [91.80496216, 23.17572021], [91.80500793, 23.17580795], [91.8050766, 23.17585564], [91.80523682, 23.17586708], [91.80534363, 23.17589188], [91.8054657, 23.17583084], [91.80555725, 23.17577744], [91.80560303, 23.17572021], [91.80566406, 23.17557716], [91.80574036, 23.17544174], [91.80583191, 23.17538071], [91.80596924, 23.17539215], [91.80609894, 23.17546463], [91.80622864, 23.17549324], [91.80643463, 23.17551613], [91.80654144, 23.17550278], [91.806633, 23.17544556], [91.80667114, 23.17535591], [91.80667114, 23.17526436], [91.80667114, 23.17518234], [91.80664825, 23.17509651], [91.80645752, 23.17487907], [91.80636597, 23.17482567], [91.80632782, 23.17476463], [91.80619049, 23.17462921], [91.80595398, 23.1746273], [91.80578613, 23.17456055], [91.80555725, 23.17452621], [91.80532837, 23.17442513], [91.80510712, 23.17434883], [91.80503082, 23.17428398], [91.80505371, 23.1742115], [91.8050766, 23.17414284], [91.8052597, 23.17394257], [91.80538177, 23.17386627], [91.80548096, 23.17384911], [91.80558014, 23.17383003], [91.80573273, 23.1738987], [91.8058548, 23.17396164], [91.80595398, 23.17393684], [91.80603027, 23.17388535], [91.80607605, 23.17381096], [91.80610657, 23.17370224], [91.80610657, 23.17361259], [91.80607605, 23.1734581], [91.80602264, 23.17331696], [91.80599213, 23.17312241], [91.8059845, 23.17294884], [91.80599213, 23.17278099], [91.80600739, 23.1727047], [91.80604553, 23.17263603], [91.80614471, 23.17261314], [91.80625153, 23.17261314], [91.806427, 23.17266655], [91.806633, 23.17269897], [91.80677795, 23.17271233], [91.80686951, 23.17265892], [91.8068924, 23.1725769], [91.80686188, 23.17234993], [91.8068924, 23.17216301], [91.8068924, 23.17202759], [91.8068924, 23.1719017], [91.80680847, 23.17181396], [91.80670166, 23.17178535], [91.80653381, 23.17186737], [91.8061142, 23.17214012], [91.80599976, 23.17224884], [91.80590057, 23.17231369], [91.80576324, 23.17235947], [91.80568695, 23.17231941], [91.80564117, 23.17223167], [91.8055954, 23.1721344], [91.80556488, 23.17201805], [91.80555725, 23.17190933], [91.80557251, 23.17183113], [91.80566406, 23.17175102], [91.80573273, 23.17163277], [91.80581665, 23.17154503], [91.80586243, 23.17140579], [91.80593872, 23.1713047], [91.80605316, 23.17119598], [91.80612946, 23.17106056], [91.8061676, 23.17092896], [91.80619049, 23.17081451], [91.80622101, 23.1706543], [91.8062439, 23.17042351], [91.80613708, 23.17029762], [91.80596161, 23.17021179], [91.80703735, 23.16898918], [91.80735016, 23.16666985], [91.80735016, 23.16638565], [91.80757141, 23.16625404], [91.80771637, 23.16618156], [91.80786133, 23.1661129], [91.80802917, 23.16605759], [91.80818176, 23.16605377], [91.80831909, 23.16601944], [91.80844879, 23.16600037], [91.80857086, 23.16595459], [91.80867004, 23.16591835], [91.80875397, 23.16588211], [91.80884552, 23.16587639], [91.80903625, 23.16581726], [91.80921936, 23.16572762], [91.80940247, 23.16566277], [91.80960846, 23.1655426], [91.80970001, 23.16552925], [91.80982971, 23.16552544], [91.80992889, 23.16539383], [91.81000519, 23.16521835], [91.81002045, 23.16509438], [91.81000519, 23.16501427], [91.80993652, 23.16492081], [91.80989838, 23.16483879], [91.80988312, 23.16457367], [91.80983734, 23.16449547], [91.80956268, 23.16421127], [91.8094101, 23.16403961], [91.80924225, 23.16354752], [91.80905151, 23.16351318], [91.80897522, 23.1634922], [91.80885315, 23.16344261], [91.80851746, 23.16334152], [91.80840302, 23.16333961], [91.80831909, 23.16329384], [91.80805969, 23.16320419], [91.80789948, 23.16316986], [91.80765533, 23.16312981], [91.80754852, 23.1631012], [91.80737305, 23.16304016], [91.80716705, 23.16287613], [91.8070755, 23.16280174], [91.80700684, 23.16273308], [91.80690765, 23.16264343], [91.80686188, 23.16255569], [91.80687714, 23.16244125], [91.8069458, 23.16241074], [91.80704498, 23.16240692], [91.80712891, 23.16238403], [91.80722046, 23.16233444], [91.80730438, 23.16230965], [91.80741882, 23.16221237], [91.80751038, 23.16212273], [91.80757904, 23.16203499], [91.80762482, 23.16193962], [91.80761719, 23.16182899], [91.8075943, 23.16171646], [91.80757141, 23.161623], [91.80754089, 23.16144943], [91.80751038, 23.1613121], [91.80741119, 23.16097641], [91.80718994, 23.16055107], [91.80701447, 23.16022491], [91.80677795, 23.15984726], [91.80675507, 23.15971565], [91.80664825, 23.15945816], [91.8065567, 23.15923882], [91.80649567, 23.15904427], [91.80631256, 23.15863991], [91.8062973, 23.158535], [91.8062439, 23.15833855], [91.80622864, 23.15820694], [91.80621338, 23.15809631], [91.80613708, 23.15783882], [91.80603027, 23.15758133], [91.80603027, 23.15744972], [91.80606079, 23.15736961], [91.80612946, 23.15729141], [91.80620575, 23.15721703], [91.80632019, 23.15716553], [91.806633, 23.1570282], [91.80706787, 23.15680885], [91.80719757, 23.15672112], [91.80728149, 23.15662384], [91.80749512, 23.15649605], [91.80760956, 23.15642357], [91.80770874, 23.15633202], [91.80780029, 23.15624809], [91.8081131, 23.15606499], [91.80820465, 23.15600967], [91.80831909, 23.15592766], [91.80840302, 23.15577126], [91.80845642, 23.15570068], [91.80851746, 23.15558052], [91.80861664, 23.15543747], [91.80877686, 23.15524673], [91.80895996, 23.15504456], [91.80905151, 23.15493584], [91.80918884, 23.15476608], [91.80931091, 23.15460777], [91.8094635, 23.15445518], [91.80960083, 23.15431595], [91.80976868, 23.15409279], [91.80995178, 23.15401077], [91.81015015, 23.15393448], [91.81026459, 23.15391159], [91.81034088, 23.15385056], [91.81048584, 23.15372086], [91.8105545, 23.1536026], [91.81069946, 23.15326118], [91.81070709, 23.15310669], [91.81077576, 23.15279388], [91.8107605, 23.15269279], [91.81053925, 23.15260315], [91.81044006, 23.15258217], [91.81034851, 23.15250397], [91.81026459, 23.15247536], [91.81019592, 23.15243149], [91.81012726, 23.15235329], [91.810112, 23.15226173], [91.810112, 23.1521759], [91.81014252, 23.15204811], [91.81018066, 23.15197372], [91.81023407, 23.15189171], [91.81047821, 23.15179253], [91.81061554, 23.15177536], [91.81089783, 23.15220261], [91.81118011, 23.15256882], [91.81138611, 23.15287399], [91.8116684, 23.15330124], [91.81201172, 23.15372849], [91.81215668, 23.15385628], [91.8134079, 23.15088844], [91.81337738, 23.14998055], [91.81404114, 23.14750481], [91.81408691, 23.14727783], [91.81417084, 23.14549255], [91.81417847, 23.14528847], [91.81411743, 23.1450119], [91.81401062, 23.14483643], [91.8137207, 23.14452744], [91.81365967, 23.14447212], [91.813591, 23.14442253], [91.81352234, 23.14434242], [91.81335449, 23.14429092], [91.81320953, 23.14414024], [91.81302643, 23.14383698], [91.81288147, 23.14389992], [91.81268311, 23.14402962], [91.81259155, 23.14418602], [91.81256104, 23.14426041], [91.81250763, 23.14434052], [91.81230164, 23.14453506], [91.81222534, 23.14459038], [91.81204224, 23.14464188], [91.81187439, 23.14467239], [91.81142426, 23.14474678], [91.81118774, 23.14476395], [91.81098938, 23.14474297], [91.81095886, 23.14464188], [91.81098938, 23.14451027], [91.81098938, 23.14438248], [91.81095123, 23.14403725], [91.8108902, 23.14374542], [91.81082153, 23.14364815], [91.81072235, 23.14358139], [91.81065369, 23.14349747], [91.81060791, 23.14341736], [91.81053925, 23.14327049], [91.81049347, 23.14314842], [91.81047058, 23.14306259], [91.81035614, 23.14274597], [91.81031036, 23.14263916], [91.81022644, 23.14247322], [91.81014252, 23.14234924], [91.81006622, 23.14220428], [91.80989838, 23.14202118], [91.8097229, 23.14169884], [91.80949402, 23.1413765], [91.80918121, 23.14106941], [91.80882263, 23.14061546], [91.80876923, 23.14047813], [91.80870819, 23.14035988], [91.80870819, 23.14020538], [91.80875397, 23.13996887], [91.80870819, 23.13979912], [91.80870819, 23.13971519], [91.8086853, 23.13962364], [91.80858612, 23.13944626], [91.80844879, 23.13941574], [91.80825806, 23.13932419], [91.80810547, 23.13917923], [91.80825806, 23.13877487], [91.80834198, 23.13855171], [91.80841064, 23.13823128], [91.80844879, 23.13796234], [91.80853271, 23.13784409], [91.80860138, 23.13770866], [91.80880737, 23.13752174], [91.80886078, 23.13737488], [91.80892944, 23.13726616], [91.80905914, 23.13688087], [91.80911255, 23.13679123], [91.80918884, 23.13667297], [91.80919647, 23.13656807], [91.80908966, 23.13648224], [91.80898285, 23.13633919], [91.809021, 23.13623428], [91.80892944, 23.13615227], [91.80878448, 23.13610649], [91.80861664, 23.13603783], [91.8085022, 23.13596535], [91.80821228, 23.13591957], [91.8080368, 23.13578796], [91.80805969, 23.13566399], [91.80814362, 23.13543701], [91.8082428, 23.13515472], [91.80825043, 23.13501167], [91.80835724, 23.13484573], [91.80848694, 23.13466644], [91.80859375, 23.13453674], [91.80870056, 23.13432121], [91.80892944, 23.13405228], [91.80905151, 23.13399696], [91.80921936, 23.13394737], [91.8093338, 23.13394737], [91.80944824, 23.13399315], [91.80953979, 23.13400078], [91.80964661, 23.13401222], [91.8098526, 23.1339016], [91.81002045, 23.13382721], [91.81019592, 23.13380814], [91.81033325, 23.13382149], [91.81054688, 23.13393974], [91.81079865, 23.13418388], [91.81085968, 23.13435364], [91.81088257, 23.13455009], [91.8108139, 23.13467598], [91.8107605, 23.13503647], [91.81079102, 23.1356411], [91.81080627, 23.13573456], [91.81079102, 23.13587952], [91.81083679, 23.13602638], [91.81083679, 23.13614464], [91.8108139, 23.13633537], [91.81076813, 23.13643837], [91.8107605, 23.13656044], [91.8108139, 23.13665199], [91.81080627, 23.13686943], [91.81086731, 23.13702393], [91.8110199, 23.13707161], [91.81112671, 23.13702583], [91.81119537, 23.13677979], [91.81124878, 23.1359539], [91.81124878, 23.13579941], [91.81131744, 23.13558197], [91.81132507, 23.13532829], [91.81132507, 23.13489914], [91.81139374, 23.13479042], [91.81143188, 23.13458252], [91.8115387, 23.13435555], [91.81165314, 23.13424301], [91.8118515, 23.13424683], [91.8120575, 23.13426399], [91.81240082, 23.13427544], [91.81253815, 23.13430023], [91.81261444, 23.13433647], [91.81298065, 23.13435555], [91.81317902, 23.13430214], [91.81343842, 23.13424683], [91.81358337, 23.13420868], [91.81375122, 23.1341362], [91.81388855, 23.13409996], [91.81402588, 23.13401413], [91.81413269, 23.13391876], [91.81429291, 23.13381195], [91.8145752, 23.13368225], [91.81463623, 23.13358879], [91.81469727, 23.13342476], [91.81471252, 23.13327408], [91.81469727, 23.13308334], [91.81469727, 23.13289833], [91.8147583, 23.13267899], [91.81477356, 23.13244629], [91.81481171, 23.13231087], [91.81479645, 23.13220787], [91.81486511, 23.13197327], [91.81486511, 23.13183022], [91.81472778, 23.13158417], [91.8146286, 23.13150215], [91.81443787, 23.13140297], [91.81429291, 23.13137627], [91.81398773, 23.13126373], [91.81381226, 23.13122177], [91.81357574, 23.13123894], [91.81345367, 23.13122177], [91.81336212, 23.13123131], [91.8131485, 23.13118744], [91.81280518, 23.13111115], [91.81252289, 23.1309948], [91.81235504, 23.13093185], [91.81229401, 23.13085365], [91.81225586, 23.13075256], [91.81231689, 23.13066864], [91.81248474, 23.13057518], [91.81252289, 23.13040352], [91.81274414, 23.1302681], [91.81282806, 23.13021851], [91.81313324, 23.13002777], [91.8136673, 23.12969971], [91.813797, 23.12960815], [91.81501007, 23.12938118], [91.81555939, 23.12938118], [91.81674957, 23.1289711], [91.81671143, 23.1282959], [91.81787109, 23.12768555], [91.81732178, 23.12609863], [91.81633759, 23.12483406], [91.81628418, 23.12371826], [91.81616974, 23.12361908], [91.81504822, 23.12273026], [91.81420135, 23.12203217], [91.81349945, 23.12153625], [91.813797, 23.11907196], [91.81394196, 23.1190052], [91.81410217, 23.11902428], [91.81435394, 23.11909676], [91.81468964, 23.11920547], [91.81502533, 23.11933136], [91.8152771, 23.11932182], [91.81536865, 23.11932182], [91.81549835, 23.11926079], [91.81556702, 23.11919212], [91.81561279, 23.11902046], [91.8159256, 23.11907578], [91.815979, 23.11914635], [91.81741333, 23.12061882], [91.81751251, 23.12072372], [91.81756592, 23.12080574], [91.81829834, 23.1217041], [91.81850433, 23.12199593], [91.81872559, 23.12231445], [91.81988525, 23.12310791], [91.81996155, 23.12306213], [91.82086182, 23.1225338], [91.82086945, 23.12240028], [91.82087708, 23.12221909], [91.82092285, 23.12091064], [91.82067871, 23.11828613], [91.8194809, 23.11593056], [91.81887054, 23.11468124], [91.81848907, 23.11388779], [91.81845856, 23.11375237], [91.81798553, 23.11231613], [91.81848145, 23.11187744], [91.81986237, 23.11179161], [91.82116699, 23.11174011], [91.82269287, 23.11169434], [91.82292938, 23.11066818], [91.82315826, 23.1101532], [91.82319641, 23.10890007], [91.82330322, 23.10888672], [91.82452393, 23.10748291], [91.82460022, 23.10736847], [91.82507324, 23.10668945], [91.8245697, 23.1056881], [91.82404327, 23.10451698], [91.82400513, 23.10443497], [91.82315063, 23.10383797], [91.82308197, 23.10379028], [91.82269287, 23.10351563], [91.82236481, 23.1028862], [91.82287598, 23.10211182], [91.82312012, 23.10150146], [91.82330322, 23.10089111], [91.82427979, 23.10028076], [91.82514954, 23.09993935], [91.82692719, 23.10015106], [91.82952881, 23.10070801], [91.83167267, 23.10011292], [91.83270264, 23.09887695], [91.83443451, 23.09664536], [91.83449554, 23.09658432], [91.83551025, 23.09552002], [91.83551025, 23.09387207], [91.83546448, 23.09378052], [91.83556366, 23.09366035], [91.83563995, 23.09356499], [91.83571625, 23.09342575], [91.83572388, 23.09331894], [91.83573914, 23.09318542], [91.83569336, 23.09303856], [91.83556366, 23.09285736], [91.83548737, 23.09281731], [91.83550262, 23.09274101], [91.83531952, 23.09261703], [91.83522797, 23.09254837], [91.8351059, 23.09249496], [91.8350296, 23.09249496], [91.83482361, 23.09249496], [91.83460236, 23.09249306], [91.83429718, 23.09251213], [91.83407593, 23.09254456], [91.83383179, 23.0925827], [91.83366394, 23.0926342], [91.83343506, 23.09269905], [91.83327484, 23.09270287], [91.83300018, 23.09269142], [91.83293915, 23.09256744], [91.83290863, 23.09244156], [91.83293152, 23.09234428], [91.83293915, 23.09220505], [91.83298492, 23.09212685], [91.83306122, 23.09201813], [91.83312225, 23.09187508], [91.83320618, 23.09171867], [91.83331299, 23.09156799], [91.83338928, 23.09144592], [91.83345032, 23.09128571], [91.83340454, 23.09111786], [91.83329773, 23.09103775], [91.83323669, 23.09098434], [91.83314514, 23.0909977], [91.8330307, 23.09105682], [91.83293915, 23.09113121], [91.83285522, 23.09115028], [91.83268738, 23.09119606], [91.83255768, 23.09119034], [91.83216858, 23.09118271], [91.83195496, 23.09121895], [91.83181, 23.09119034], [91.83172607, 23.09116936], [91.83161926, 23.09114075], [91.83152771, 23.09109306], [91.83136749, 23.09087563], [91.83133698, 23.09073448], [91.83137512, 23.09055519], [91.83148193, 23.09037018], [91.83148193, 23.09024239], [91.83144379, 23.09004974], [91.83139038, 23.08995056], [91.83132172, 23.08989334], [91.83120728, 23.0899353], [91.83110809, 23.09003448], [91.83110809, 23.09016228], [91.83109283, 23.09024239], [91.83097839, 23.09026909], [91.83094025, 23.09038734], [91.83081818, 23.0905056], [91.83059692, 23.0907135], [91.83052063, 23.09088516], [91.83039093, 23.09103775], [91.8302536, 23.09120941], [91.83013153, 23.09140778], [91.82995605, 23.09161377], [91.82985687, 23.09171486], [91.82967377, 23.09179115], [91.82962036, 23.09172058], [91.82952118, 23.09167862], [91.82936096, 23.0915966], [91.82924652, 23.09169579], [91.82917786, 23.09141731], [91.82914734, 23.09119987], [91.8291626, 23.09101105], [91.8291626, 23.09086227], [91.82917023, 23.09077835], [91.8290329, 23.09054756], [91.83227539, 23.08947754], [91.83193207, 23.08947754], [91.83061981, 23.08933067], [91.82990265, 23.08922005], [91.82963562, 23.08860397], [91.8289032, 23.08840942], [91.82831573, 23.0883522], [91.82765198, 23.08817101], [91.82706451, 23.08798981], [91.82633972, 23.08787346], [91.82542419, 23.0877552], [91.82530212, 23.08774567], [91.8252182, 23.08773994], [91.82505798, 23.08760262], [91.82468414, 23.08744812], [91.82465363, 23.08731461], [91.82442474, 23.08717537], [91.8243103, 23.08712387], [91.82407379, 23.08707428], [91.82367706, 23.08703232], [91.82350922, 23.08701706], [91.82331085, 23.08701897], [91.82308197, 23.08697701], [91.8229599, 23.08687592], [91.82286835, 23.08683586], [91.82279968, 23.08675957], [91.8227005, 23.08674049], [91.8225708, 23.08654404], [91.82249451, 23.08641624], [91.8223877, 23.08627319], [91.82236481, 23.0861969], [91.82219696, 23.08584976], [91.82219696, 23.08571434], [91.82228851, 23.08557892], [91.82234955, 23.08548355], [91.82252502, 23.08533287], [91.82266998, 23.0851841], [91.8229599, 23.08498192], [91.82315826, 23.08490753], [91.82331848, 23.08479691], [91.8234787, 23.08472252], [91.82362366, 23.08461189], [91.82370758, 23.08452988], [91.8239212, 23.08436203], [91.82402039, 23.08427048], [91.82418823, 23.08412361], [91.82426453, 23.08396721], [91.82437134, 23.08382416], [91.82427216, 23.08358002], [91.82415009, 23.0834198], [91.82405853, 23.08330345], [91.82395935, 23.08325005], [91.82369995, 23.08311081], [91.82344818, 23.08303261], [91.82309723, 23.08288193], [91.82293701, 23.08282089], [91.82260132, 23.08260345], [91.82250214, 23.08250618], [91.82236481, 23.08237267], [91.82215881, 23.08223724], [91.82198334, 23.08207321], [91.82191467, 23.08201599], [91.82178497, 23.08190918], [91.82167053, 23.08180428], [91.8214798, 23.08170319], [91.82117462, 23.08139992], [91.82108307, 23.08132935], [91.82087708, 23.08114624], [91.82060242, 23.08094215], [91.82052612, 23.08086205], [91.82043457, 23.08075905], [91.8203125, 23.08065033], [91.82015228, 23.08048439], [91.82009888, 23.08034897], [91.81998444, 23.08023643], [91.81990814, 23.08014679], [91.8197403, 23.07997894], [91.81954193, 23.07990074], [91.81943512, 23.07991219], [91.8193512, 23.07994843], [91.8192749, 23.08005714], [91.81920624, 23.08025742], [91.8192215, 23.08045006], [91.81923676, 23.08057022], [91.81918335, 23.08078766], [91.81912231, 23.08090591], [91.81903839, 23.08114243], [91.81895447, 23.08138275], [91.81893158, 23.08146477], [91.81887817, 23.08179474], [91.8188858, 23.08187103], [91.81881714, 23.08209419], [91.81879425, 23.08226395], [91.8187027, 23.08243752], [91.81863403, 23.08254814], [91.81854248, 23.08271599], [91.8184433, 23.08299637], [91.81835175, 23.0831089], [91.81820679, 23.08314323], [91.81812286, 23.08314514], [91.81803131, 23.08315849], [91.8179245, 23.08315849], [91.81780243, 23.08313751], [91.81765747, 23.08314514], [91.81742096, 23.08309555], [91.81726074, 23.0830555], [91.81719971, 23.08298492], [91.81712341, 23.08293343], [91.81702423, 23.08278656], [91.81699371, 23.08267593], [91.81694794, 23.08255196], [91.81684875, 23.08241653], [91.81684113, 23.08226585], [91.81687927, 23.08205605], [91.81678772, 23.08171463], [91.81676483, 23.08154869], [91.81671143, 23.08131981], [91.81665039, 23.08119202], [91.8164444, 23.08092117], [91.81632233, 23.08091164], [91.81616211, 23.08094788], [91.81606293, 23.08102417], [91.81591797, 23.08101273], [91.81563568, 23.08100319], [91.81525421, 23.08093452], [91.81508636, 23.08090973], [91.81486511, 23.08085632], [91.81468964, 23.08071518], [91.81461334, 23.08058548], [91.81463623, 23.08051109], [91.81466675, 23.08041573], [91.81471252, 23.0803318], [91.81483459, 23.08023262], [91.81505585, 23.08014679], [91.81518555, 23.08010864], [91.8152771, 23.08008003], [91.81538391, 23.08004951], [91.81602478, 23.07971382], [91.81621552, 23.07961655], [91.81652832, 23.07953262], [91.81665802, 23.07949448], [91.81684875, 23.07944679], [91.81698608, 23.07937241], [91.81706238, 23.07931709], [91.81716156, 23.07920456], [91.81721497, 23.07910156], [91.81726837, 23.0789032], [91.81734467, 23.07857704], [91.81737518, 23.07844162], [91.81745911, 23.07814407], [91.81757355, 23.07790184], [91.81764221, 23.07763863], [91.81769562, 23.07747841], [91.81777191, 23.0772419], [91.81782532, 23.07689095], [91.81781769, 23.07667351], [91.81781006, 23.07656288], [91.81784821, 23.0764389], [91.81783295, 23.07628441], [91.81781006, 23.07595253], [91.81775665, 23.07582474], [91.81764221, 23.0757122], [91.81752014, 23.07563972], [91.81741333, 23.07567787], [91.81733704, 23.07566261], [91.8172226, 23.07567596], [91.81707764, 23.07561111], [91.81681824, 23.07552147], [91.81650543, 23.07539177], [91.81637573, 23.07532883], [91.81620026, 23.07526207], [91.81606293, 23.07513237], [91.81595612, 23.07504845], [91.81584167, 23.07492065], [91.81584167, 23.07481003], [91.81591034, 23.07468033], [91.81602478, 23.07457352], [91.81611633, 23.07441902], [91.81621552, 23.07431602], [91.81637573, 23.07417297], [91.81655884, 23.07406235], [91.81686401, 23.07394218], [91.81697845, 23.07388687], [91.81730652, 23.07385063], [91.81777954, 23.07385063], [91.81791687, 23.07383347], [91.8181076, 23.07381248], [91.81825256, 23.07366371], [91.81833649, 23.07345963], [91.81838226, 23.07326508], [91.81832886, 23.07294846], [91.81822205, 23.0727787], [91.81806183, 23.07262421], [91.81800842, 23.07254219], [91.81790161, 23.07242966], [91.81783295, 23.07234001], [91.81773376, 23.07229424], [91.81745911, 23.07216835], [91.81734467, 23.07213783], [91.81706238, 23.07208443], [91.81682587, 23.07203102], [91.81658936, 23.07201195], [91.81638336, 23.07198334], [91.81621552, 23.07199478], [91.81594849, 23.0720005], [91.81585693, 23.07204819], [91.81569672, 23.07208443], [91.81547546, 23.072155], [91.81533051, 23.07221603], [91.81522369, 23.07229996], [91.81507874, 23.07243919], [91.81491089, 23.07266235], [91.81479645, 23.07288361], [91.81471252, 23.07299232], [91.81465912, 23.07310104], [91.81454468, 23.07322693], [91.81443024, 23.07331848], [91.81422424, 23.07346535], [91.81414795, 23.07356071], [91.81394958, 23.07367516], [91.81372833, 23.07377243], [91.81354523, 23.07378769], [91.81339264, 23.07377052], [91.81326294, 23.07375336], [91.81319427, 23.07370186], [91.81311035, 23.07364845], [91.81302643, 23.07353783], [91.81292725, 23.07336998], [91.81290436, 23.07326508], [91.81285095, 23.07315826], [91.81275177, 23.07299042], [91.81260681, 23.07274055], [91.81253815, 23.07267952], [91.81243134, 23.07237244], [91.81241608, 23.07226753], [91.81246948, 23.07220268], [91.81250763, 23.07209587], [91.81261444, 23.07201195], [91.81270599, 23.07193375], [91.81278229, 23.07188988], [91.8128891, 23.07182884], [91.81298828, 23.07174683], [91.81313324, 23.071661], [91.81334686, 23.07144356], [91.81348419, 23.07128525], [91.81357574, 23.07121086], [91.81364441, 23.07110786], [91.81370544, 23.07098198], [91.81375885, 23.07083321], [91.81378174, 23.0707283], [91.8137207, 23.07064629], [91.81359863, 23.07055092], [91.81346893, 23.07048416], [91.81330109, 23.07050133], [91.8130722, 23.07056046], [91.81291199, 23.07057762], [91.81278229, 23.07056236], [91.81250763, 23.07055855], [91.81233978, 23.07053185], [91.81208801, 23.07042503], [91.81201172, 23.07036781], [91.81193542, 23.07032776], [91.81188202, 23.07026863], [91.81181335, 23.07016182], [91.8117218, 23.07010078], [91.8115921, 23.06997871], [91.81153107, 23.06981277], [91.81150818, 23.06965065], [91.81153107, 23.06954384], [91.81156921, 23.06918335], [91.81156921, 23.06906509], [91.81158447, 23.06896782], [91.81165314, 23.06886482], [91.81166077, 23.06878281], [91.81170654, 23.0687027], [91.81191254, 23.06847382], [91.81202698, 23.0683136], [91.81210327, 23.0681324], [91.81221771, 23.06803131], [91.8122406, 23.06793404], [91.81229401, 23.06783485], [91.81234741, 23.06774712], [91.81238556, 23.06757927], [91.81242371, 23.06740379], [91.81243134, 23.06716728], [91.81245422, 23.06707954], [91.81240845, 23.06700325], [91.81240845, 23.06668663], [91.81232452, 23.06642723], [91.81224823, 23.06634331], [91.81204987, 23.06624031], [91.8117981, 23.06613541], [91.81147003, 23.0662384], [91.81109619, 23.06632805], [91.81098175, 23.06640053], [91.81076813, 23.06650925], [91.81062317, 23.06655502], [91.81045532, 23.06667328], [91.81032562, 23.06669998], [91.81020355, 23.06670952], [91.80998993, 23.066782], [91.80987549, 23.06679153], [91.80970764, 23.06681824], [91.80957031, 23.06680489], [91.80924225, 23.06675529], [91.80883026, 23.06669235], [91.8086319, 23.06667137], [91.80838776, 23.06660271], [91.80817413, 23.0666008], [91.80809021, 23.06659889], [91.80783081, 23.06667328], [91.80747223, 23.06671906], [91.80728149, 23.06681442], [91.80708313, 23.06692696], [91.80702209, 23.06698227], [91.80693817, 23.06705093], [91.80680084, 23.06710625], [91.80670929, 23.06710815], [91.80656433, 23.06714439], [91.80635071, 23.06698799], [91.80615997, 23.06713104], [91.80593109, 23.06711388], [91.80584717, 23.0670414], [91.80567932, 23.06683922], [91.80562592, 23.06671715], [91.80561066, 23.0666008], [91.80566406, 23.06643867], [91.80580902, 23.0662365], [91.80593109, 23.06603622], [91.80607605, 23.06606674], [91.80630493, 23.06568336], [91.80648041, 23.06553078], [91.80659485, 23.06524086], [91.80669403, 23.06509781], [91.80673981, 23.06497955], [91.80679321, 23.06486702], [91.80680847, 23.06459808], [91.80682373, 23.06404495], [91.80677032, 23.06393623], [91.80672455, 23.06376648], [91.80664825, 23.0636692], [91.80662537, 23.06356812], [91.80657196, 23.06345558], [91.80638885, 23.06332779], [91.80620575, 23.06327438], [91.80610657, 23.06323624], [91.80597687, 23.06316185], [91.80580902, 23.06320381], [91.80556488, 23.06324196], [91.80505371, 23.06326866], [91.80469513, 23.06329727], [91.80460358, 23.06329346], [91.80423737, 23.06339264], [91.80413055, 23.06341934], [91.80393982, 23.06345749], [91.80381775, 23.06348991], [91.80373383, 23.06351852], [91.80362701, 23.06353378], [91.80339813, 23.06369591], [91.80304718, 23.06395721], [91.80284119, 23.0640583], [91.8026123, 23.06419945], [91.8024292, 23.06427574], [91.8022995, 23.06435204], [91.80207825, 23.06440353], [91.80184937, 23.06451416], [91.80147552, 23.06462479], [91.80135345, 23.06469727], [91.80112457, 23.06476402], [91.80082703, 23.06487465], [91.80057526, 23.06490898], [91.80028534, 23.06502342], [91.79984283, 23.06510735], [91.79953003, 23.06509018], [91.79909515, 23.06510162], [91.79865265, 23.06502724], [91.79823303, 23.06495285], [91.79797363, 23.06479263], [91.79785919, 23.06475067], [91.79773712, 23.06464386], [91.7975769, 23.06443787], [91.79750061, 23.0643692], [91.79741669, 23.06425667], [91.7972641, 23.06416893], [91.7971344, 23.06404114], [91.79707336, 23.06395149], [91.79666138, 23.06357002], [91.79654694, 23.06346512], [91.79637146, 23.06324959], [91.79608917, 23.06300926], [91.79584503, 23.06276894], [91.79576874, 23.06271744], [91.79541016, 23.06241989], [91.79528809, 23.0623455], [91.7951355, 23.0622673], [91.79497528, 23.06224632], [91.79463959, 23.06226158], [91.79429626, 23.06231499], [91.79417419, 23.06239128], [91.79400635, 23.06242752], [91.79385376, 23.06255722], [91.79373932, 23.06275177], [91.79364014, 23.06292343], [91.79348755, 23.06332397], [91.79342651, 23.06368256], [91.79338074, 23.06391716], [91.79338837, 23.06423759], [91.79344177, 23.06471443], [91.79351807, 23.06501389], [91.79363251, 23.06522369], [91.79364014, 23.06534386], [91.79373169, 23.06551933], [91.79389191, 23.06577873], [91.79408264, 23.06597137], [91.7943573, 23.06620598], [91.79446411, 23.06625938], [91.79455566, 23.06629753], [91.79467773, 23.06630707], [91.7948761, 23.06633186], [91.79457092, 23.06664276], [91.79367828, 23.06768036], [91.79405212, 23.0690136], [91.79396057, 23.06905365], [91.79366302, 23.06917572], [91.79355621, 23.06917], [91.79345703, 23.06918526], [91.79328156, 23.06917], [91.79315186, 23.06912994], [91.79291534, 23.06906891], [91.7926178, 23.06899834], [91.79246521, 23.0689888], [91.79228973, 23.06894493], [91.792099, 23.06891823], [91.7918396, 23.06887817], [91.79154968, 23.06882668], [91.79124451, 23.06881332], [91.79093933, 23.06876183], [91.79072571, 23.06876755], [91.79032135, 23.06874847], [91.79017639, 23.06877327], [91.78997803, 23.06876564], [91.7897644, 23.06887054], [91.78967285, 23.06896973], [91.7896347, 23.06907654], [91.78953552, 23.06930733], [91.78951263, 23.06944656], [91.789505, 23.06981659], [91.78949738, 23.06998253], [91.78949738, 23.07024574], [91.78957367, 23.07072258], [91.7896347, 23.07089806], [91.78972626, 23.07104111], [91.78974152, 23.07118797], [91.78972626, 23.07144737], [91.78968048, 23.07165909], [91.78953552, 23.07180214], [91.78938293, 23.0718174], [91.78928375, 23.07179832], [91.78908539, 23.07167244], [91.7889328, 23.07150841], [91.78877258, 23.07134438], [91.78849792, 23.07118607], [91.78838348, 23.07107544], [91.78827667, 23.07091331], [91.78816223, 23.07058716], [91.78807068, 23.07027626], [91.78803253, 23.07003975], [91.78806305, 23.06982613], [91.7881012, 23.06963539], [91.78813934, 23.06951904], [91.78826904, 23.06936455], [91.78834534, 23.06924057], [91.78848267, 23.06905174], [91.78855133, 23.06889915], [91.78865051, 23.06876183], [91.78877258, 23.06863022], [91.78891754, 23.06841087], [91.78903961, 23.06823349], [91.78907013, 23.0681591], [91.78919983, 23.06785774], [91.78919983, 23.06774521], [91.78917694, 23.06762886], [91.78903198, 23.0674057], [91.78889465, 23.06734848], [91.78878784, 23.067379], [91.78862, 23.06746483], [91.78845978, 23.06748772], [91.78817749, 23.06753349], [91.78788757, 23.06762505], [91.78768921, 23.06771851], [91.78752899, 23.06781197], [91.78742218, 23.06782722], [91.78730774, 23.06787491], [91.78720093, 23.06789398], [91.78702545, 23.06796837], [91.78686523, 23.06805801], [91.78636169, 23.0681839], [91.78627777, 23.06817436], [91.78618622, 23.06824112], [91.78600311, 23.068367], [91.78594208, 23.06845665], [91.78585815, 23.0684967], [91.78578949, 23.06871414], [91.78574371, 23.06900597], [91.78579712, 23.06945419], [91.78585815, 23.07010269], [91.78586578, 23.07026482], [91.78586578, 23.07053185], [91.7858429, 23.07066154], [91.78582764, 23.07073402], [91.78574371, 23.07096863], [91.78560638, 23.07118607], [91.7855072, 23.07134056], [91.78541565, 23.07138443], [91.78533173, 23.07140923], [91.78513336, 23.07145691], [91.7849884, 23.07152748], [91.78474426, 23.07162476], [91.78450775, 23.07158661], [91.78437042, 23.07158661], [91.78397369, 23.0716362], [91.78382111, 23.07165909], [91.78358459, 23.07165527], [91.78282928, 23.07157516], [91.78240967, 23.07152367], [91.78204346, 23.07143021], [91.78179169, 23.07137489], [91.78153992, 23.07139015], [91.78125763, 23.07136726], [91.78075409, 23.07131767], [91.7804718, 23.07131195], [91.78015137, 23.07126617], [91.78002167, 23.07126427], [91.7797699, 23.07122803], [91.77914429, 23.07115173], [91.77881622, 23.07108879], [91.77872467, 23.07104111], [91.77861786, 23.07103348], [91.7781601, 23.07091904], [91.77794647, 23.07077026], [91.77787018, 23.07076836], [91.77731323, 23.07061577], [91.77700806, 23.07053947], [91.77670288, 23.07050514], [91.77645874, 23.07050323], [91.77632904, 23.07045746], [91.77619934, 23.07039833], [91.77601624, 23.07039452], [91.77565765, 23.07027626], [91.77502441, 23.06999016], [91.77468109, 23.06982231], [91.77445984, 23.06971741], [91.77422333, 23.06945419], [91.77402496, 23.06921196], [91.77394104, 23.06909943], [91.77387238, 23.06891823], [91.77374268, 23.06867218], [91.77367401, 23.06853867], [91.77359009, 23.06836891], [91.77351379, 23.06797791], [91.77346802, 23.0676651], [91.77339935, 23.06741142], [91.77334595, 23.06711006], [91.77340698, 23.06674767], [91.77352905, 23.0664444], [91.77376556, 23.0660305], [91.77392578, 23.06577873], [91.77416992, 23.06552505], [91.77428436, 23.06540489], [91.77449799, 23.0651741], [91.77482605, 23.06488419], [91.77490997, 23.0648632], [91.77534485, 23.06443787], [91.77552795, 23.0643177], [91.77563477, 23.06418991], [91.77573395, 23.06411934], [91.77579498, 23.06403923], [91.77587128, 23.06392097], [91.77610016, 23.06372643], [91.77633667, 23.06356812], [91.77654266, 23.06336021], [91.77667236, 23.06328392], [91.77689362, 23.0631218], [91.77710724, 23.06298065], [91.77722168, 23.06284142], [91.77747345, 23.06261444], [91.77757263, 23.06248665], [91.77768707, 23.06241417], [91.7778244, 23.06227684], [91.77806091, 23.06204033], [91.77826691, 23.06187057], [91.77835083, 23.06177521], [91.77843475, 23.06173325], [91.77855682, 23.06161499], [91.77864838, 23.06144333], [91.77880096, 23.06123352], [91.7789917, 23.06097031], [91.77906036, 23.06085396], [91.77908325, 23.06074333], [91.77918243, 23.06048775], [91.77922821, 23.06025505], [91.77935791, 23.0600872], [91.77941132, 23.05987358], [91.77941895, 23.05969048], [91.77944183, 23.05956268], [91.77944183, 23.05937958], [91.77960968, 23.05925941], [91.77935791, 23.05903625], [91.77935028, 23.05896187], [91.77928162, 23.05879402], [91.77921295, 23.05841446], [91.77919769, 23.0581913], [91.77913666, 23.05789566], [91.77906036, 23.05772781], [91.77896881, 23.05759621], [91.77889252, 23.05751801], [91.7787323, 23.0573597], [91.77858734, 23.0573101], [91.77802277, 23.05711365], [91.77761078, 23.05696869], [91.78109741, 23.05555725], [91.7824707, 23.05328369], [91.78295898, 23.05282974], [91.78471375, 23.05131721], [91.78479767, 23.05124664], [91.78668213, 23.04888916], [91.78692627, 23.04797554], [91.787323, 23.04576111], [91.78747559, 23.04211426], [91.78697968, 23.04027748], [91.78703308, 23.0366497], [91.78588867, 23.0335083], [91.78509521, 23.03167725], [91.78378296, 23.03154945], [91.7833252, 23.03149414], [91.78051758, 23.03112793], [91.78037262, 23.03139305], [91.78033447, 23.03100586], [91.7804184, 23.03071594], [91.78050995, 23.03046036], [91.78054047, 23.03011513], [91.78059387, 23.02968788], [91.78055573, 23.02935028], [91.78050232, 23.02921867], [91.78043365, 23.02919006], [91.78035736, 23.02913475], [91.78028107, 23.02897263], [91.78012085, 23.02878761], [91.77999878, 23.02867126], [91.77971649, 23.02853775], [91.77961731, 23.02847099], [91.7794342, 23.02839088], [91.77911377, 23.02820587], [91.77898407, 23.0281353], [91.77884674, 23.02809525], [91.77843475, 23.02791786], [91.77739716, 23.02748299], [91.77714539, 23.02737427], [91.77700043, 23.02731895], [91.77689362, 23.02730942], [91.77661133, 23.02721024], [91.77637482, 23.02706718], [91.77618408, 23.02703667], [91.77584076, 23.02700043], [91.775383, 23.02701187], [91.77468109, 23.02700996], [91.77423859, 23.02725029], [91.7738266, 23.02767372], [91.77365875, 23.02795792], [91.77353668, 23.02821922], [91.77337646, 23.02897644], [91.77313995, 23.02933884], [91.77302551, 23.02966499], [91.77297211, 23.02982903], [91.77296448, 23.03003502], [91.77287292, 23.03041077], [91.77282715, 23.03088951], [91.77289581, 23.03104782], [91.77294159, 23.03148079], [91.772789, 23.03186035], [91.77278137, 23.03224945], [91.77285004, 23.03273201], [91.77282715, 23.03308105], [91.77297974, 23.03349113], [91.77308655, 23.03383064], [91.77310181, 23.03400803], [91.77325439, 23.03453445], [91.77333069, 23.03469467], [91.77326202, 23.03483582], [91.77333832, 23.03493881], [91.77331543, 23.03504372], [91.77336121, 23.03520966], [91.77361298, 23.03604317], [91.77393341, 23.03678703], [91.77410889, 23.0369606], [91.77407837, 23.03712845], [91.77412415, 23.0372448], [91.77121735, 23.03679466], [91.77078247, 23.03613281], [91.77096558, 23.03587151], [91.77111816, 23.03559303], [91.77159882, 23.03480148], [91.77184296, 23.034235], [91.77191925, 23.03398705], [91.77200317, 23.03347397], [91.77197266, 23.03336143], [91.77185822, 23.03320122], [91.77165222, 23.03309631], [91.77149963, 23.03299904], [91.77085114, 23.03301048], [91.77030945, 23.03299713], [91.76996613, 23.0330925], [91.76969147, 23.03324318], [91.76947021, 23.03354073], [91.76921082, 23.03373337], [91.76908112, 23.03382683], [91.76874542, 23.03404427], [91.76835632, 23.03433228], [91.7681427, 23.03440094], [91.76804352, 23.0343132], [91.76789856, 23.03416061], [91.76766968, 23.03389549], [91.76750183, 23.03381348], [91.76738739, 23.03373337], [91.76722717, 23.0335865], [91.76698303, 23.03340721], [91.7668457, 23.03320885], [91.76662445, 23.03303719], [91.76641083, 23.03280449], [91.76609039, 23.03248215], [91.76571655, 23.03205872], [91.76557922, 23.03191566], [91.7654953, 23.03187943], [91.76539612, 23.031847], [91.7647934, 23.03133583], [91.76439667, 23.03107071], [91.76408386, 23.03091812], [91.76354218, 23.0308342], [91.76314545, 23.03074074], [91.76271057, 23.03068352], [91.76168823, 23.03046417], [91.76102448, 23.02999115], [91.76093292, 23.02973747], [91.76092529, 23.02952194], [91.76099396, 23.02941322], [91.76099396, 23.0292244], [91.7613678, 23.02764702], [91.76143646, 23.02740479], [91.76146698, 23.02677536], [91.76147461, 23.02653122], [91.76141357, 23.02634811], [91.76098633, 23.02582169], [91.76028442, 23.02503204], [91.75994873, 23.02482605], [91.75938416, 23.02461624], [91.7591095, 23.02461433], [91.75774384, 23.02457809], [91.75748444, 23.02454185], [91.75782013, 23.02117348], [91.75799561, 23.02068138], [91.75804138, 23.02031326], [91.75811005, 23.01990318], [91.75608826, 23.01569366], [91.75603485, 23.01563263], [91.75109863, 23.0100708], [91.74627686, 23.00671387], [91.74572754, 23.00628662], [91.74169159, 23.00514412], [91.74156952, 23.00512123], [91.73931885, 23.00466919], [91.73924255, 23.00463676], [91.73896027, 23.00446701], [91.73370361, 23.00128174], [91.72894287, 22.99755096], [91.72808838, 22.99688721], [91.72747803, 22.99487305], [91.72737122, 22.99454117], [91.72711182, 22.99371338], [91.72690582, 22.99263191], [91.72607422, 22.9899292], [91.7258606, 22.98957825], [91.72570801, 22.98940849], [91.72559357, 22.98927689], [91.72403717, 22.9887104], [91.72342682, 22.98965645], [91.72241974, 22.98929024], [91.72145081, 22.98884583], [91.72132111, 22.98835754], [91.72123718, 22.98820877], [91.721138, 22.98806381], [91.72083282, 22.98778152], [91.72052765, 22.98755074], [91.7203064, 22.98746109], [91.720047, 22.9873867], [91.71977997, 22.98727989], [91.71931458, 22.98713684], [91.71878052, 22.98690605], [91.71845245, 22.98680878], [91.71831512, 22.9867363], [91.71810913, 22.98671913], [91.7175293, 22.98674583], [91.71697235, 22.9867878], [91.71656799, 22.98686218], [91.71624756, 22.98697472], [91.71560669, 22.98726463], [91.71476746, 22.98766708], [91.71440887, 22.98785973], [91.71414948, 22.98808098], [91.71360779, 22.98840714], [91.71337891, 22.988554], [91.71321106, 22.98861504], [91.71310425, 22.98869514]], [[91.81077576, 24.21705437], [91.81054688, 24.21708298], [91.81060791, 24.21698761], [91.81077576, 24.21705437]], [[91.7907486, 23.22552681], [91.79064941, 23.22492409], [91.79076385, 23.22495079], [91.79089355, 23.22505379], [91.79090118, 23.22515869], [91.7908783, 23.22524452], [91.79083252, 23.22538567], [91.7907486, 23.22552681]], [[91.16204834, 23.66392899], [91.16113281, 23.66510391], [91.16120148, 23.66400528], [91.16162109, 23.66396713], [91.16204834, 23.66392899]], [[91.16082764, 23.66613579], [91.16074371, 23.66648483], [91.16066742, 23.66646576], [91.16074371, 23.66613197], [91.16082764, 23.66613579]], [[91.87788391, 24.15058136], [91.8777771, 24.15035439], [91.87781525, 24.15028954], [91.87789917, 24.15027237], [91.87791443, 24.150383], [91.87788391, 24.15058136]], [[91.57254791, 24.07493782], [91.57284546, 24.07489777], [91.57288361, 24.07507896], [91.57254791, 24.07493782]]], [[[91.74414063, 24.24369812], [91.74346924, 24.24712753], [91.74507141, 24.24641228], [91.74497986, 24.24634171], [91.74488068, 24.24621201], [91.7448349, 24.24607849], [91.74471283, 24.24596405], [91.74469757, 24.24586296], [91.74469757, 24.24570656], [91.74472046, 24.24559402], [91.7447052, 24.2454834], [91.74468994, 24.24539948], [91.74466705, 24.24531746], [91.74467468, 24.24522018], [91.74464417, 24.24511147], [91.74462891, 24.24501419], [91.7445755, 24.2447567], [91.74449921, 24.24452591], [91.7443924, 24.2442379], [91.74424744, 24.24390221], [91.74414063, 24.24369812]]]]}}, {\\\"id\\\": \\\"31\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.34_1\\\", \\\"HASC_1\\\": \\\"IN.UP\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Uttar Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"United Provinces\\\", \\\"apm25_popweighted\\\": -30.3, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1009.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -2092.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1083.0, \\\"geo-id\\\": 31, \\\"hpm25_child_popweighted\\\": -288.8, \\\"hpm25_female_popweighted\\\": -332.0, \\\"hpm25_male_popweighted\\\": -239.0, \\\"location\\\": \\\"Uttar Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 68523.0, \\\"mort_hpm25_6cod_mean_total\\\": -144881.0, \\\"mort_tpm25_6cod_mean_total\\\": -76358.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[77.70540619, 26.88027954], [77.69773102, 26.8800106], [77.69637299, 26.87659073], [77.69371796, 26.87289047], [77.68937683, 26.87347031], [77.68636322, 26.87832069], [77.68235016, 26.87916946], [77.67835236, 26.87832069], [77.67468262, 26.87462997], [77.67166901, 26.87407112], [77.66697693, 26.86238289], [77.66462708, 26.85984039], [77.65730286, 26.85641098], [77.62487793, 26.84674835], [77.61620331, 26.84847069], [77.61319733, 26.84446907], [77.61186218, 26.83964157], [77.60853577, 26.8345108], [77.60450745, 26.83280182], [77.60083771, 26.83423042], [77.60016632, 26.84250069], [77.59615326, 26.84165192], [77.5881424, 26.83337975], [77.57746887, 26.83310127], [77.57211304, 26.83196068], [77.5687561, 26.82741165], [77.56476593, 26.82456017], [77.55641937, 26.82199097], [77.54740906, 26.82172012], [77.5357132, 26.82542992], [77.52838135, 26.8245697], [77.52069092, 26.82200813], [77.51435852, 26.8245697], [77.5120163, 26.82798958], [77.51233673, 26.83826065], [77.51535034, 26.84140015], [77.51367188, 26.84510231], [77.50666809, 26.84738159], [77.50197601, 26.84653091], [77.49797821, 26.84794998], [77.49698639, 26.83797073], [77.48932648, 26.80861092], [77.48664856, 26.80120087], [77.48232269, 26.7940712], [77.48098755, 26.78779984], [77.48432159, 26.78239059], [77.48932648, 26.77724838], [77.49668884, 26.77411079], [77.49334717, 26.76699066], [77.48635864, 26.76101112], [77.48036194, 26.75387955], [77.44831085, 26.74674988], [77.45730591, 26.76214027], [77.46166992, 26.76584816], [77.46431732, 26.76955032], [77.45597076, 26.78038025], [77.45095062, 26.78067017], [77.44528198, 26.77753067], [77.43894196, 26.77581024], [77.43428802, 26.77239037], [77.4285965, 26.77011108], [77.42726898, 26.77609253], [77.42858887, 26.78578949], [77.43192291, 26.79235077], [77.43824005, 26.80887985], [77.43921661, 26.81915092], [77.43421173, 26.82541084], [77.42719269, 26.8316803], [77.42584991, 26.83567047], [77.4228363, 26.83680916], [77.4174881, 26.8427906], [77.4214859, 26.84877968], [77.42616272, 26.85305977], [77.42347717, 26.85762024], [77.42247009, 26.86701965], [77.42648315, 26.8670311], [77.4318161, 26.8658905], [77.43650818, 26.8678875], [77.44182587, 26.87759018], [77.45052338, 26.87501144], [77.45417786, 26.8767395], [77.455513, 26.88043976], [77.45517731, 26.8895607], [77.46478271, 26.89266014], [77.47377777, 26.89978981], [77.48246765, 26.90377998], [77.49584198, 26.90578079], [77.51856995, 26.91547966], [77.5453186, 26.92204094], [77.55735779, 26.92603111], [77.57975006, 26.93087006], [77.5847702, 26.94227028], [77.58744812, 26.94454956], [77.59176636, 26.94398117], [77.59379578, 26.93770981], [77.59812927, 26.94026947], [77.60482788, 26.94595909], [77.64227295, 26.96730042], [77.64894104, 26.9738102], [77.65260315, 26.97494125], [77.65660858, 26.97406006], [77.65960693, 26.96808052], [77.66529846, 26.96692085], [77.66861725, 26.96917915], [77.67028046, 26.97710991], [77.69191742, 26.97899246], [77.70123291, 26.98431969], [77.70992279, 26.98769951], [77.71459198, 26.99166107], [77.72328186, 26.98823929], [77.73634338, 26.98822021], [77.73900604, 26.99106026], [77.73969269, 26.9979496], [77.74336243, 26.99765968], [77.74771118, 26.99850082], [77.74607849, 27.00294113], [77.74246216, 27.00570107], [77.74254608, 27.00634956], [77.74546051, 27.00868988], [77.74616241, 27.01086044], [77.74529266, 27.01336098], [77.74768066, 27.01762962], [77.75501251, 27.02276039], [77.75311279, 27.02363014], [77.74389648, 27.02374077], [77.74085236, 27.02552032], [77.73935699, 27.0275898], [77.73840332, 27.03268051], [77.7355423, 27.033741], [77.72648621, 27.03153992], [77.72216034, 27.02614021], [77.7201767, 27.01404953], [77.72104645, 27.00570107], [77.72336578, 27.00390816], [77.72231293, 27.00033951], [77.71761322, 27.00002098], [77.71392059, 26.99796104], [77.70858002, 27.00110245], [77.70358276, 27.0003109], [77.69896698, 27.0057106], [77.69661713, 27.00695038], [77.69567108, 27.01605034], [77.69374084, 27.01951981], [77.68202209, 27.03294182], [77.68486023, 27.0398407], [77.68430328, 27.04491997], [77.67816925, 27.05052948], [77.67331696, 27.05155945], [77.67076874, 27.0489006], [77.66329956, 27.03030968], [77.6598587, 27.02503967], [77.6570282, 27.02273178], [77.65196991, 27.02257919], [77.64334106, 27.02719116], [77.63426208, 27.02701187], [77.63092041, 27.0234108], [77.62740326, 27.01550102], [77.62425232, 27.01689911], [77.62201691, 27.02186966], [77.61949921, 27.02490807], [77.61559296, 27.02739906], [77.6034317, 27.02909279], [77.59881592, 27.02882957], [77.5943222, 27.03119087], [77.59059143, 27.03166008], [77.58875275, 27.03705978], [77.58392334, 27.03931999], [77.57509613, 27.04157066], [77.56820679, 27.03932953], [77.56067657, 27.03565025], [77.55739594, 27.03689957], [77.55893707, 27.04878998], [77.56112671, 27.05157089], [77.56523895, 27.05397987], [77.56680298, 27.06026077], [77.56694031, 27.06632042], [77.56572723, 27.06903076], [77.5684433, 27.07248116], [77.56568146, 27.07801056], [77.56324005, 27.07862282], [77.55422974, 27.07722092], [77.54631805, 27.08073044], [77.54139709, 27.07739067], [77.53366089, 27.06981087], [77.52915955, 27.06711006], [77.52654266, 27.06650925], [77.52136993, 27.0672226], [77.51429749, 27.07042122], [77.51468658, 27.07406044], [77.51773834, 27.0797596], [77.51822662, 27.0880928], [77.51738739, 27.08949089], [77.51377869, 27.09137917], [77.51474762, 27.09189987], [77.51100159, 27.09391975], [77.49938965, 27.09398079], [77.49841309, 27.09519005], [77.49903107, 27.09584045], [77.50231934, 27.09922028], [77.50821686, 27.1028595], [77.51383972, 27.10808945], [77.52082062, 27.1058197], [77.52937317, 27.10414124], [77.53209686, 27.10968971], [77.53948212, 27.11125946], [77.54444885, 27.11560059], [77.54576874, 27.11512947], [77.55612183, 27.11581993], [77.57466888, 27.1221199], [77.58342743, 27.12068176], [77.58587646, 27.12424088], [77.59078217, 27.12308121], [77.59567261, 27.12615967], [77.59726715, 27.12905121], [77.59455109, 27.13368034], [77.59591675, 27.13721085], [77.59239197, 27.14011955], [77.59210968, 27.14476967], [77.59365845, 27.14795113], [77.59807587, 27.14800072], [77.60653687, 27.15414047], [77.6059494, 27.15890121], [77.60407257, 27.16431999], [77.6051178, 27.16847992], [77.61480713, 27.17478943], [77.62252045, 27.1749897], [77.6254425, 27.17436028], [77.6282959, 27.17312241], [77.63079834, 27.17020988], [77.63591766, 27.17012978], [77.64334106, 27.17440033], [77.65461731, 27.17558098], [77.66124725, 27.18278122], [77.6654129, 27.1861496], [77.67199707, 27.19506073], [77.67299652, 27.20036125], [77.66719055, 27.20709991], [77.65664673, 27.21302032], [77.65500641, 27.21178055], [77.64778137, 27.21454811], [77.64202881, 27.21476936], [77.63951874, 27.2172718], [77.6394577, 27.22323036], [77.64318085, 27.23180962], [77.64420319, 27.23887825], [77.63839722, 27.24065018], [77.63800812, 27.24253845], [77.63913727, 27.24712944], [77.63890839, 27.24714088], [77.6342392, 27.25368118], [77.62957764, 27.25549126], [77.62581635, 27.26234055], [77.62329865, 27.26382065], [77.61284637, 27.26030159], [77.60900116, 27.2650795], [77.60661316, 27.2727108], [77.61125183, 27.27433968], [77.61414337, 27.27916145], [77.60935211, 27.28166962], [77.60909271, 27.28799057], [77.60307312, 27.29487991], [77.59832764, 27.29635048], [77.59166718, 27.30055809], [77.59172821, 27.30273056], [77.59702301, 27.30470085], [77.6000824, 27.30470085], [77.603302, 27.30992126], [77.60887909, 27.3119297], [77.6135025, 27.31476021], [77.61553192, 27.32541084], [77.61559296, 27.33453941], [77.61634064, 27.33831024], [77.61411285, 27.34338951], [77.61036682, 27.34439278], [77.60753632, 27.34215927], [77.60481262, 27.33794975], [77.5929718, 27.3379612], [77.58661652, 27.33527184], [77.58229828, 27.33163071], [77.58043671, 27.32845116], [77.57454681, 27.32673073], [77.57273865, 27.33008957], [77.56777191, 27.33323097], [77.56671906, 27.33361053], [77.56173706, 27.33543968], [77.5427475, 27.34242821], [77.5404129, 27.34758949], [77.53909302, 27.35307121], [77.53539276, 27.35293961], [77.53074646, 27.35276985], [77.52200317, 27.35763931], [77.51567841, 27.36273003], [77.50936127, 27.36782074], [77.50802612, 27.37278175], [77.50385284, 27.37405968], [77.50219727, 27.37735939], [77.49724579, 27.38136292], [77.48696136, 27.38562965], [77.47586823, 27.38772964], [77.46660614, 27.3842907], [77.461586, 27.38759041], [77.44326019, 27.39332962], [77.43578339, 27.39678955], [77.4318924, 27.39915848], [77.4295578, 27.4043808], [77.42999268, 27.4050293], [77.42677307, 27.41661072], [77.42508698, 27.41887283], [77.41517639, 27.42537117], [77.41703033, 27.43824005], [77.41828156, 27.4421711], [77.42073059, 27.44729042], [77.42295074, 27.44943047], [77.42727661, 27.45100975], [77.42878723, 27.45545959], [77.42959595, 27.46204948], [77.42543793, 27.46480942], [77.41545105, 27.46614075], [77.41136932, 27.47269058], [77.40738678, 27.47636986], [77.39642334, 27.47780991], [77.39359283, 27.48194122], [77.39234924, 27.48610115], [77.39155579, 27.49356079], [77.39202881, 27.50204277], [77.38955688, 27.50542259], [77.38326263, 27.51148987], [77.38241577, 27.51655006], [77.37619019, 27.51860046], [77.36122894, 27.51851082], [77.35816956, 27.51947975], [77.35222626, 27.51997948], [77.34026337, 27.52477264], [77.33513641, 27.53002167], [77.33252716, 27.53854942], [77.33545685, 27.54170036], [77.34015656, 27.54673958], [77.33843994, 27.54964256], [77.33357239, 27.55459023], [77.33067322, 27.56375122], [77.33120728, 27.56862831], [77.33039856, 27.57110977], [77.33109283, 27.57344055], [77.33306122, 27.57604027], [77.33838654, 27.57660294], [77.3434906, 27.58550262], [77.3483963, 27.59012032], [77.35011292, 27.59340096], [77.33516693, 27.60153008], [77.32811737, 27.59604073], [77.32578278, 27.59687805], [77.31121063, 27.61169052], [77.31321716, 27.61732101], [77.33233643, 27.6377697], [77.3423233, 27.6530304], [77.34276581, 27.65720177], [77.33934784, 27.66242027], [77.33716583, 27.6696701], [77.33746338, 27.67580986], [77.33500671, 27.68142128], [77.33679199, 27.68546295], [77.33654785, 27.69618034], [77.33444214, 27.69948959], [77.3339386, 27.70792007], [77.33053589, 27.71113968], [77.32447815, 27.71319008], [77.32034302, 27.71268272], [77.31725311, 27.71124077], [77.30845642, 27.71390915], [77.30235291, 27.71321106], [77.29760742, 27.71868134], [77.29634094, 27.72982979], [77.31067657, 27.73686981], [77.31233215, 27.73867989], [77.31210327, 27.74017143], [77.30966949, 27.74278831], [77.30599976, 27.74469948], [77.305336, 27.74922943], [77.30134583, 27.75645828], [77.30169678, 27.76006126], [77.30280304, 27.76119041], [77.30296326, 27.76465034], [77.30152893, 27.76896095], [77.3014679, 27.77170944], [77.30368805, 27.77598], [77.30414581, 27.78800964], [77.30110931, 27.79368019], [77.29794312, 27.79785919], [77.29538727, 27.79984093], [77.29064178, 27.80170059], [77.27932739, 27.80280113], [77.27577972, 27.80654907], [77.27707672, 27.80673981], [77.27934265, 27.8119812], [77.28347778, 27.81591988], [77.28970337, 27.81783295], [77.29062653, 27.81970978], [77.28888702, 27.82913971], [77.29915619, 27.83138275], [77.3048172, 27.83123016], [77.30632019, 27.83200073], [77.31292725, 27.83005142], [77.31719208, 27.83324051], [77.32211304, 27.83472061], [77.32733154, 27.83772087], [77.32406616, 27.8408699], [77.32924652, 27.85198975], [77.33120728, 27.85268021], [77.33265686, 27.85489082], [77.33933258, 27.85959053], [77.34406281, 27.85898972], [77.35264587, 27.8564415], [77.36483002, 27.86059189], [77.37001038, 27.86313057], [77.37388611, 27.86370277], [77.38208008, 27.86309052], [77.39282227, 27.85894966], [77.40377808, 27.85824013], [77.41239166, 27.85907173], [77.41442108, 27.86069107], [77.41369629, 27.86260033], [77.40629578, 27.86967087], [77.40512848, 27.87174988], [77.40453339, 27.8758297], [77.40155029, 27.88190079], [77.40409088, 27.88661003], [77.40709686, 27.88912964], [77.41104126, 27.89501953], [77.41229248, 27.89615822], [77.41423035, 27.89652061], [77.42220306, 27.89447975], [77.430336, 27.88884163], [77.44219971, 27.87848091], [77.44584656, 27.87840843], [77.45848846, 27.88529968], [77.46981812, 27.89472961], [77.4724884, 27.90120125], [77.474617, 27.91206169], [77.47245026, 27.9192009], [77.47086334, 27.92061043], [77.47059631, 27.92789268], [77.46845245, 27.93188095], [77.46872711, 27.93291092], [77.47766113, 27.94021034], [77.48474884, 27.94391251], [77.48796082, 27.94145012], [77.49060059, 27.93394852], [77.49225616, 27.93180847], [77.49537659, 27.93077087], [77.49777985, 27.93141174], [77.50585938, 27.93614006], [77.51116943, 27.9374218], [77.5137558, 27.93634033], [77.51921082, 27.93188095], [77.53137207, 27.94181824], [77.53613281, 27.94930267], [77.53733826, 27.95776939], [77.53591919, 27.96554947], [77.52900696, 27.96624947], [77.51502991, 27.9654808], [77.51059723, 27.96820831], [77.50958252, 27.97333145], [77.51344299, 27.97743988], [77.52667999, 27.98402023], [77.53215027, 27.98884964], [77.53521729, 27.99333], [77.52011108, 28.00654984], [77.5118866, 28.01025009], [77.50937653, 28.01772118], [77.50652313, 28.02234077], [77.50177002, 28.02737999], [77.49743652, 28.03063965], [77.49517059, 28.03429985], [77.48970795, 28.0393219], [77.47911072, 28.04416275], [77.47763824, 28.04910088], [77.48284912, 28.05764961], [77.48287201, 28.0589447], [77.48290253, 28.06071091], [77.47683716, 28.07331276], [77.47173309, 28.07875061], [77.47001648, 28.0837307], [77.46887207, 28.08601189], [77.47306824, 28.10371971], [77.47479248, 28.10428047], [77.47823334, 28.10797119], [77.48278046, 28.10785294], [77.48602295, 28.09739113], [77.49014282, 28.09529114], [77.49230957, 28.09801102], [77.49373627, 28.10227013], [77.49324036, 28.10817909], [77.49137115, 28.11271095], [77.49939728, 28.12259102], [77.49964142, 28.12735939], [77.49846649, 28.1356926], [77.48796082, 28.13878059], [77.48725128, 28.14143181], [77.48986816, 28.14438057], [77.49529266, 28.14581108], [77.49636841, 28.15987015], [77.498909, 28.16300964], [77.51159668, 28.16489029], [77.5317688, 28.17025948], [77.54236603, 28.1816597], [77.53794861, 28.19089127], [77.53018951, 28.1929493], [77.52082062, 28.19174004], [77.50566101, 28.19547081], [77.50151825, 28.18719101], [77.49211884, 28.18510056], [77.49061584, 28.19305992], [77.48912048, 28.21199036], [77.49759674, 28.21302032], [77.51056671, 28.20633125], [77.51281738, 28.20168114], [77.51911926, 28.20178032], [77.52327728, 28.20717049], [77.52157593, 28.21739006], [77.51703644, 28.22138977], [77.51557922, 28.22976112], [77.53562164, 28.24052048], [77.54120636, 28.2477417], [77.53878021, 28.25440979], [77.52501678, 28.25342941], [77.51225281, 28.25432968], [77.51159668, 28.25455093], [77.51062012, 28.25489044], [77.50206757, 28.25784111], [77.48707581, 28.26176071], [77.46730042, 28.26972008], [77.46481323, 28.27742958], [77.47225189, 28.28120995], [77.48808289, 28.27911949], [77.49273682, 28.28063011], [77.49476624, 28.29261017], [77.49417114, 28.30026054], [77.49578857, 28.30704117], [77.4818573, 28.32361984], [77.47355652, 28.32788086], [77.46592712, 28.33394051], [77.46375275, 28.33801079], [77.46640778, 28.34120941], [77.48517609, 28.35021019], [77.49423981, 28.35826111], [77.4920578, 28.36952019], [77.48589325, 28.37970161], [77.46953583, 28.39430046], [77.46684265, 28.39968109], [77.47386169, 28.40381241], [77.47455597, 28.41351128], [77.46869659, 28.41753006], [77.45610046, 28.42098808], [77.45147705, 28.42485809], [77.44399261, 28.42897034], [77.43599701, 28.43161011], [77.42829895, 28.44406128], [77.42578125, 28.45454025], [77.4181366, 28.45578957], [77.40828705, 28.45560074], [77.39779663, 28.45864105], [77.39483643, 28.46279907], [77.40003204, 28.4666996], [77.39789581, 28.47117043], [77.38816833, 28.47281837], [77.37600708, 28.47616005], [77.36936188, 28.4806881], [77.36412048, 28.48565102], [77.36396027, 28.49290085], [77.36048126, 28.49785995], [77.34319305, 28.50361061], [77.33773804, 28.50897026], [77.33682251, 28.51568031], [77.33396912, 28.52070236], [77.330513, 28.52410126], [77.32151031, 28.53585052], [77.314888, 28.54149055], [77.31069946, 28.54368973], [77.30306244, 28.55045128], [77.2951889, 28.5612011], [77.29380035, 28.5667305], [77.29364777, 28.57971954], [77.29490662, 28.58242989], [77.30713654, 28.59691048], [77.30992126, 28.59896088], [77.31694031, 28.59996033], [77.32784271, 28.60488129], [77.33315277, 28.60671234], [77.33618164, 28.60886955], [77.33753204, 28.61749268], [77.33708191, 28.62190056], [77.33422089, 28.62699127], [77.33045959, 28.6314106], [77.32095337, 28.63602066], [77.31358337, 28.64320183], [77.31121063, 28.64464188], [77.31307983, 28.64666939], [77.31533051, 28.651371], [77.31542969, 28.66327095], [77.31756592, 28.67161942], [77.31791687, 28.67934036], [77.32538605, 28.68250275], [77.32713318, 28.68515968], [77.32758331, 28.69184113], [77.32092285, 28.69967079], [77.31983948, 28.70364189], [77.32167816, 28.71183014], [77.32348633, 28.71587181], [77.31716156, 28.71722031], [77.30622101, 28.71767044], [77.30146027, 28.71673012], [77.29563141, 28.7130394], [77.29294586, 28.7097702], [77.28489685, 28.71245956], [77.28365326, 28.7189827], [77.2844162, 28.72393036], [77.28069305, 28.73002052], [77.2768631, 28.7343998], [77.27111816, 28.7381897], [77.26637268, 28.7392807], [77.25991821, 28.73812294], [77.25617218, 28.73991966], [77.25187683, 28.74550056], [77.25319672, 28.75279045], [77.24846649, 28.75753021], [77.24585724, 28.75735092], [77.23799133, 28.75922012], [77.22904205, 28.77243805], [77.22090912, 28.7779007], [77.21710205, 28.78168106], [77.22206879, 28.783741], [77.22467804, 28.78762817], [77.21826935, 28.78762817], [77.21305084, 28.7864399], [77.20845032, 28.78718948], [77.20269012, 28.78940964], [77.1969223, 28.79528046], [77.19444275, 28.80229187], [77.1946106, 28.81536293], [77.21364594, 28.81349945], [77.2173233, 28.83527946], [77.21061707, 28.84529114], [77.21147156, 28.85493088], [77.20783234, 28.86021996], [77.20479584, 28.86291122], [77.199646, 28.86494064], [77.19348907, 28.86535072], [77.18686676, 28.86681938], [77.18318939, 28.87177086], [77.17829132, 28.88004112], [77.17803955, 28.8855629], [77.18177032, 28.88980103], [77.19909668, 28.89268112], [77.20530701, 28.89460945], [77.21687317, 28.90034294], [77.22119141, 28.90413284], [77.22149658, 28.90813065], [77.21602631, 28.91143036], [77.20204926, 28.91555977], [77.19676971, 28.92093086], [77.20536804, 28.93646049], [77.204422, 28.93997955], [77.19078827, 28.94686127], [77.19013977, 28.95566177], [77.19095612, 28.96165085], [77.20375061, 28.9822998], [77.20790863, 28.99106026], [77.21418762, 29.00596046], [77.21404266, 29.00669098], [77.21113586, 29.01138115], [77.20379639, 29.01671982], [77.19159698, 29.02129173], [77.1765213, 29.03647041], [77.1626358, 29.04857063], [77.16163635, 29.05244064], [77.162323, 29.06537247], [77.15718842, 29.07753181], [77.14929962, 29.08324051], [77.14160156, 29.08681107], [77.13176727, 29.09464836], [77.12438202, 29.10148811], [77.12204742, 29.1057682], [77.12441254, 29.11346054], [77.13620758, 29.12784004], [77.13858032, 29.13476944], [77.12661743, 29.15402031], [77.12734222, 29.16291046], [77.13240814, 29.17181015], [77.13999176, 29.18208122], [77.13813782, 29.20106125], [77.1361618, 29.20745087], [77.13262939, 29.21311951], [77.12770081, 29.21842003], [77.12522125, 29.22487068], [77.12722015, 29.22814178], [77.14279938, 29.23779106], [77.14402008, 29.24333191], [77.14247894, 29.25160027], [77.13498688, 29.26649284], [77.12948608, 29.27279091], [77.13761902, 29.28746986], [77.14437103, 29.2961998], [77.1423111, 29.30151176], [77.15421295, 29.31692123], [77.1536026, 29.3222599], [77.15104675, 29.32551956], [77.15001678, 29.33169174], [77.15394592, 29.33547974], [77.1518631, 29.33929062], [77.14644623, 29.34506035], [77.12757874, 29.34433937], [77.12368774, 29.34498978], [77.12003326, 29.34979057], [77.11752319, 29.35715103], [77.11884308, 29.36195946], [77.11669922, 29.37257957], [77.11694336, 29.37668037], [77.12046814, 29.37877083], [77.13105011, 29.38070107], [77.13864899, 29.38390923], [77.14679718, 29.38977051], [77.14597321, 29.39248085], [77.14006805, 29.39472008], [77.133461, 29.39843941], [77.12908936, 29.40249062], [77.12586975, 29.41064072], [77.12487793, 29.42217064], [77.13577271, 29.43222046], [77.13845062, 29.43686295], [77.13938904, 29.44210052], [77.13774872, 29.44659042], [77.1319809, 29.45049095], [77.12413788, 29.45294189], [77.117836, 29.45646095], [77.11429596, 29.46186066], [77.1140213, 29.47029114], [77.115448, 29.47540283], [77.12039185, 29.48006058], [77.12332153, 29.4860611], [77.11989594, 29.49732971], [77.11451721, 29.50315857], [77.10340881, 29.50954056], [77.09761047, 29.51201248], [77.08648682, 29.52826118], [77.08490753, 29.53359032], [77.08622742, 29.53949928], [77.0894165, 29.54469109], [77.09529877, 29.54764938], [77.10443115, 29.54891014], [77.10971832, 29.55298996], [77.10675812, 29.56636047], [77.10198212, 29.57699966], [77.09378052, 29.5872097], [77.08989716, 29.59043121], [77.08680725, 29.59646988], [77.08561707, 29.60079956], [77.09218597, 29.60867119], [77.09388733, 29.61297035], [77.0945282, 29.61776924], [77.10047913, 29.62227249], [77.10160065, 29.62491989], [77.10106659, 29.63307953], [77.10489655, 29.63557816], [77.10782623, 29.63996124], [77.10970306, 29.64723969], [77.12180328, 29.65353966], [77.12941742, 29.65859032], [77.13130188, 29.66299057], [77.13114166, 29.66634941], [77.11997986, 29.6802597], [77.11917114, 29.68584061], [77.12110138, 29.69156075], [77.12552643, 29.69691086], [77.13218689, 29.69948006], [77.13987732, 29.70022964], [77.14260101, 29.70163918], [77.14332581, 29.70597076], [77.14021301, 29.7172718], [77.12255859, 29.73603821], [77.12256622, 29.74282074], [77.11515808, 29.74496078], [77.11295319, 29.74860001], [77.11421967, 29.75429153], [77.11785889, 29.76043129], [77.11889648, 29.76422119], [77.11704254, 29.77090073], [77.11828613, 29.77555084], [77.12349701, 29.7778492], [77.13199615, 29.77898026], [77.13743591, 29.78220177], [77.14222717, 29.78757095], [77.1523819, 29.79327965], [77.15400696, 29.79768944], [77.15171814, 29.80347061], [77.15209961, 29.80766106], [77.15396881, 29.81378174], [77.15564728, 29.81678963], [77.16526794, 29.82448959], [77.16903687, 29.82958031], [77.16703796, 29.84370995], [77.16758728, 29.84638977], [77.17810822, 29.86215973], [77.18006134, 29.86914063], [77.18245697, 29.87327957], [77.18229675, 29.88158989], [77.18496704, 29.89030838], [77.1848526, 29.89490128], [77.1795578, 29.90226936], [77.18016815, 29.90621185], [77.18591309, 29.91305161], [77.18689728, 29.91748047], [77.18913269, 29.92204285], [77.1955719, 29.92727089], [77.20256805, 29.9310894], [77.21112823, 29.94071007], [77.22373962, 29.95475006], [77.22489929, 29.95858955], [77.22957611, 29.96190262], [77.23194885, 29.96632195], [77.23310852, 29.97363091], [77.23548126, 29.98117256], [77.25047302, 29.988451], [77.25476074, 29.99316025], [77.25512695, 29.99596977], [77.26316071, 30.00214958], [77.26154327, 30.00561905], [77.26191711, 30.0073204], [77.26434326, 30.01305962], [77.26544189, 30.01803017], [77.26759338, 30.02210999], [77.26969147, 30.02746964], [77.27313995, 30.03404045], [77.27176666, 30.03991127], [77.2698822, 30.04422951], [77.27040863, 30.04833984], [77.27625275, 30.05047035], [77.2804184, 30.05251122], [77.28610992, 30.0574894], [77.29184723, 30.05849075], [77.29759216, 30.0603199], [77.30290985, 30.06058121], [77.31291199, 30.06053925], [77.32480621, 30.06180191], [77.33174133, 30.06445122], [77.33716583, 30.06824112], [77.34842682, 30.0766983], [77.35697937, 30.08415031], [77.36849976, 30.09155846], [77.37342834, 30.09301949], [77.38034058, 30.09304047], [77.39245605, 30.09441185], [77.39673615, 30.09576035], [77.40857697, 30.10255241], [77.41442871, 30.10713005], [77.4141922, 30.11111069], [77.41008759, 30.11108971], [77.40603638, 30.11130905], [77.40061188, 30.11326027], [77.39800262, 30.11872292], [77.40326691, 30.12105942], [77.40865326, 30.12320137], [77.41261292, 30.12771034], [77.41552734, 30.13349915], [77.41783905, 30.14118195], [77.41490173, 30.1434803], [77.41082764, 30.14587975], [77.41142273, 30.14969063], [77.41532135, 30.1566906], [77.42354584, 30.16847992], [77.43061066, 30.16642952], [77.43517303, 30.16995811], [77.44033813, 30.16920853], [77.44684601, 30.16860962], [77.45153809, 30.17362976], [77.45598602, 30.18096161], [77.46021271, 30.1837883], [77.4732666, 30.188591], [77.47677612, 30.19501114], [77.47997284, 30.20215988], [77.48390198, 30.2100811], [77.48853302, 30.21874046], [77.49372101, 30.2274704], [77.49598694, 30.23363113], [77.50550842, 30.24224091], [77.51983643, 30.26013184], [77.52250671, 30.26619911], [77.52468109, 30.2779808], [77.52677917, 30.28231239], [77.53218079, 30.2868576], [77.54042053, 30.29096985], [77.5453186, 30.29413986], [77.55577087, 30.30257034], [77.56355286, 30.30608177], [77.57035065, 30.31122971], [77.5738678, 30.3189106], [77.57501221, 30.32607079], [77.57009888, 30.3315506], [77.56989288, 30.33711052], [77.57463074, 30.34695053], [77.58278656, 30.35843849], [77.59201813, 30.37086105], [77.59012604, 30.37726021], [77.58444214, 30.38136101], [77.57489014, 30.38451958], [77.57615662, 30.38989067], [77.57292175, 30.3930912], [77.56785583, 30.39875984], [77.56305695, 30.40448952], [77.56710815, 30.40484047], [77.56858826, 30.40682983], [77.56958008, 30.40789986], [77.57112122, 30.40863991], [77.5728302, 30.41033173], [77.5749588, 30.41174126], [77.57753754, 30.41245842], [77.57971191, 30.41192055], [77.58436584, 30.40998077], [77.58467865, 30.40878105], [77.58638763, 30.40801048], [77.58699036, 30.40806007], [77.58777618, 30.40846252], [77.59107208, 30.40904999], [77.59246063, 30.40949059], [77.59778595, 30.4088707], [77.59896851, 30.40891075], [77.60273743, 30.40841293], [77.60411072, 30.40875053], [77.60597229, 30.40948105], [77.60707092, 30.40963173], [77.60822296, 30.41019249], [77.60916138, 30.41040993], [77.61122894, 30.40757179], [77.61450958, 30.40582085], [77.61694336, 30.4052906], [77.61818695, 30.40533066], [77.62207031, 30.4047699], [77.62354279, 30.40516281], [77.62552643, 30.4070816], [77.63053131, 30.4108696], [77.63288116, 30.41117287], [77.63421631, 30.41087914], [77.63569641, 30.41012192], [77.63661957, 30.40920067], [77.63941193, 30.40710068], [77.63986969, 30.40640068], [77.64138031, 30.40536118], [77.643013, 30.40454292], [77.64450836, 30.40257835], [77.64569092, 30.40199089], [77.64762115, 30.39807129], [77.65193176, 30.39550018], [77.65529633, 30.39477921], [77.65805817, 30.39401054], [77.65969086, 30.39393806], [77.66034698, 30.39374161], [77.66126251, 30.39323044], [77.66153717, 30.3926506], [77.66243744, 30.39167023], [77.66300964, 30.39057159], [77.66369629, 30.38751984], [77.66348267, 30.38557816], [77.66320801, 30.38473129], [77.66410828, 30.3839798], [77.66581726, 30.38343811], [77.66687775, 30.38365936], [77.66880035, 30.38352966], [77.67183685, 30.38394165], [77.6733017, 30.38565063], [77.67386627, 30.38459969], [77.67700195, 30.38080025], [77.67751312, 30.37912941], [77.67977142, 30.37560081], [77.6802597, 30.37434006], [77.68273926, 30.37138939], [77.68390656, 30.3696003], [77.68434143, 30.36816025], [77.68596649, 30.36688042], [77.68707275, 30.36457825], [77.69064331, 30.35972977], [77.69126892, 30.35824013], [77.69277954, 30.35724068], [77.69341278, 30.35569191], [77.69425201, 30.35534286], [77.6971283, 30.3516407], [77.6977005, 30.35031128], [77.70108032, 30.34747124], [77.70491791, 30.34387016], [77.70773315, 30.34132195], [77.70993805, 30.33991051], [77.71077728, 30.33876038], [77.71308899, 30.33793259], [77.71537781, 30.33687973], [77.71766663, 30.33609962], [77.72088623, 30.33542824], [77.72265625, 30.33415031], [77.72553253, 30.33291054], [77.7297287, 30.33147812], [77.73239136, 30.32991028], [77.73581696, 30.32925034], [77.73771667, 30.32819176], [77.74017334, 30.3283329], [77.7425766, 30.32760811], [77.74828339, 30.32537079], [77.751297, 30.32464981], [77.75705719, 30.320961], [77.75866699, 30.3200798], [77.76069641, 30.31913948], [77.76268005, 30.31849098], [77.76496124, 30.31736946], [77.77301025, 30.3130703], [77.7772522, 30.30987167], [77.77848053, 30.30929947], [77.78320313, 30.30641937], [77.78430939, 30.30549049], [77.7889328, 30.30365944], [77.79930878, 30.29763031], [77.80179596, 30.2959919], [77.80737305, 30.29362106], [77.80905151, 30.29217911], [77.81240845, 30.2907505], [77.8186264, 30.28918076], [77.82405853, 30.28635979], [77.8286972, 30.28467941], [77.83277893, 30.28378105], [77.83629608, 30.28228951], [77.84030151, 30.28121185], [77.84246826, 30.28033066], [77.84755707, 30.27877045], [77.85189056, 30.27658272], [77.85587311, 30.27393913], [77.85788727, 30.27237129], [77.86103058, 30.27135086], [77.86554718, 30.27048111], [77.86714172, 30.271101], [77.868927, 30.27210045], [77.87148285, 30.27441978], [77.87397003, 30.27415085], [77.87985992, 30.27193069], [77.88220978, 30.27046967], [77.89021301, 30.26823997], [77.89164734, 30.26735115], [77.89636993, 30.26601028], [77.90029907, 30.26440811], [77.90363312, 30.26267815], [77.90795135, 30.26073074], [77.91030121, 30.25931168], [77.91362762, 30.25761032], [77.91684723, 30.25617027], [77.91996765, 30.2540493], [77.92189026, 30.2517395], [77.92386627, 30.24981117], [77.92539978, 30.24871063], [77.92823792, 30.24775124], [77.93148041, 30.24695969], [77.93026733, 30.24300194], [77.92977142, 30.24180984], [77.92932129, 30.23999023], [77.92713165, 30.23641968], [77.923172, 30.23179817], [77.92182159, 30.22970009], [77.9180603, 30.22479057], [77.91454315, 30.22180939], [77.91139221, 30.21877289], [77.90762329, 30.21698952], [77.90439606, 30.21520805], [77.90312958, 30.21306038], [77.90229797, 30.20976067], [77.90039825, 30.20578003], [77.89990997, 30.20401001], [77.8989563, 30.19487953], [77.89833069, 30.19226074], [77.89707184, 30.18822289], [77.89599609, 30.18629265], [77.89280701, 30.18342972], [77.89012146, 30.18037987], [77.88793945, 30.17874908], [77.8793869, 30.16967964], [77.87798309, 30.16860008], [77.87664032, 30.16695976], [77.87332916, 30.16393089], [77.87204742, 30.16303062], [77.86871338, 30.15880013], [77.86548615, 30.15507126], [77.86499786, 30.15209961], [77.86444092, 30.14993858], [77.8613205, 30.1440506], [77.85990143, 30.1415596], [77.85909271, 30.14048195], [77.8579483, 30.13809967], [77.85527039, 30.13362122], [77.85233307, 30.13092995], [77.85051727, 30.12865829], [77.84809875, 30.1245327], [77.84723663, 30.12346077], [77.84468842, 30.11950111], [77.84361267, 30.11831284], [77.84274292, 30.11677933], [77.83853149, 30.11227036], [77.83747864, 30.11143112], [77.8360672, 30.10995293], [77.83283234, 30.10800934], [77.83058167, 30.10724068], [77.82842255, 30.10612106], [77.82656097, 30.10552025], [77.82530975, 30.10473061], [77.82395172, 30.10127068], [77.82189178, 30.09888077], [77.82186127, 30.09694862], [77.81996918, 30.09363937], [77.81790924, 30.09157944], [77.81519318, 30.09016991], [77.81307983, 30.08963013], [77.81070709, 30.08954811], [77.80806732, 30.09020996], [77.80548096, 30.09196091], [77.80413055, 30.09363937], [77.80278015, 30.09456062], [77.80101776, 30.09617805], [77.79873657, 30.09786034], [77.7977066, 30.09885979], [77.79503632, 30.10061073], [77.79392242, 30.10108757], [77.79186249, 30.10185051], [77.78956604, 30.10153008], [77.78643799, 30.09996986], [77.78595734, 30.09910965], [77.78513336, 30.09678078], [77.78276062, 30.09325981], [77.78174591, 30.09086037], [77.78005219, 30.08916283], [77.77868652, 30.08543968], [77.77729797, 30.08240128], [77.77585602, 30.07765007], [77.77523041, 30.07631111], [77.77337646, 30.07386017], [77.77189636, 30.07249069], [77.76978302, 30.06838036], [77.7690506, 30.06809998], [77.76793671, 30.06694031], [77.76531982, 30.06306076], [77.76442719, 30.06088066], [77.76148987, 30.05544281], [77.75833893, 30.05050087], [77.75757599, 30.04823112], [77.75820923, 30.04654121], [77.75982666, 30.0449295], [77.7620163, 30.04318047], [77.76389313, 30.04216957], [77.76570129, 30.0396595], [77.7700882, 30.03688049], [77.77255249, 30.03370094], [77.77326202, 30.03303909], [77.77388763, 30.03210068], [77.77353668, 30.02956963], [77.7722702, 30.0262928], [77.76944733, 30.02384758], [77.76779938, 30.02293968], [77.76288605, 30.02163124], [77.75974274, 30.02042961], [77.75756073, 30.01951981], [77.75325012, 30.01736069], [77.74912262, 30.01410103], [77.74642944, 30.01134109], [77.74462128, 30.00880241], [77.74323273, 30.00596046], [77.74080658, 29.99411964], [77.736763, 29.99072075], [77.73007965, 29.98745155], [77.73100281, 29.98433113], [77.744133, 29.97186089], [77.74495697, 29.96759987], [77.74347687, 29.96377945], [77.74014282, 29.95890045], [77.7326889, 29.95498085], [77.72946167, 29.9518795], [77.72898102, 29.94561958], [77.72541809, 29.94351959], [77.72067261, 29.93902969], [77.71768188, 29.93495178], [77.71894073, 29.93284035], [77.72416687, 29.9300518], [77.72879791, 29.92856026], [77.72956085, 29.92280006], [77.73301697, 29.91348076], [77.73111725, 29.91129112], [77.727211, 29.90904236], [77.72483063, 29.90590096], [77.72009277, 29.90279007], [77.71752167, 29.89463043], [77.71302032, 29.89157295], [77.71105194, 29.88812065], [77.70301819, 29.88975906], [77.70250702, 29.88570023], [77.70316315, 29.87845039], [77.70201874, 29.8717804], [77.70326233, 29.86767006], [77.7060318, 29.86374092], [77.70957947, 29.8594799], [77.71334839, 29.85647964], [77.73005676, 29.85308075], [77.73092651, 29.84190178], [77.72918701, 29.83756065], [77.73203278, 29.83455086], [77.73895264, 29.83027077], [77.74234009, 29.82463264], [77.74398804, 29.81628036], [77.74128723, 29.81141853], [77.74214935, 29.80952072], [77.74932861, 29.80435944], [77.75296021, 29.79743958], [77.76470184, 29.78545952], [77.76053619, 29.78128052], [77.7607193, 29.77877998], [77.76539612, 29.77573013], [77.76352692, 29.77036095], [77.76571655, 29.76371002], [77.76165009, 29.75576019], [77.76085663, 29.75270081], [77.76187134, 29.74382019], [77.76735687, 29.73781013], [77.76925659, 29.73464966], [77.76792145, 29.73056984], [77.7637558, 29.72610092], [77.75771332, 29.71591949], [77.75891113, 29.71342087], [77.76203918, 29.71178818], [77.76980591, 29.70992088], [77.78269196, 29.70832062], [77.79492188, 29.70046043], [77.7974472, 29.6978302], [77.78916931, 29.68588066], [77.79251862, 29.68192101], [77.80448914, 29.67690086], [77.81108093, 29.67248917], [77.82129669, 29.66899109], [77.82897186, 29.6693306], [77.83426666, 29.67188263], [77.83843994, 29.67551994], [77.8406601, 29.67935944], [77.84294128, 29.68130112], [77.84706879, 29.68062973], [77.84863281, 29.68418121], [77.85405731, 29.68890953], [77.85851288, 29.68806076], [77.8662262, 29.69341087], [77.86991119, 29.69400978], [77.87003326, 29.69878006], [77.87387848, 29.70197105], [77.87722778, 29.70038986], [77.88218689, 29.70000267], [77.88683319, 29.70070076], [77.89994049, 29.69782066], [77.91020966, 29.69893837], [77.90483856, 29.7025528], [77.90634918, 29.70409966], [77.9083786, 29.70286942], [77.9095459, 29.70384026], [77.90804291, 29.70528984], [77.90962982, 29.7063694], [77.91072845, 29.70549011], [77.91622925, 29.71165085], [77.92015839, 29.71385956], [77.92491913, 29.71265984], [77.92722321, 29.71458054], [77.93049622, 29.71305275], [77.93665314, 29.71391106], [77.93895721, 29.71475983], [77.94081879, 29.71459961], [77.94245148, 29.71240044], [77.94943237, 29.70766258], [77.95198059, 29.70536995], [77.9462204, 29.70376968], [77.94229126, 29.70203018], [77.94114685, 29.70004082], [77.94359589, 29.69672966], [77.94628143, 29.69546127], [77.94328308, 29.69363976], [77.94306946, 29.69157982], [77.94491577, 29.69143295], [77.94377899, 29.68943024], [77.94470215, 29.68935966], [77.94539642, 29.68723106], [77.94727325, 29.68707085], [77.95176697, 29.68567085], [77.95411682, 29.68133163], [77.95668793, 29.67904091], [77.95831299, 29.67683029], [77.96156311, 29.67240906], [77.96228027, 29.67027092], [77.9631958, 29.67020035], [77.9691925, 29.67385101], [77.97126007, 29.67576981], [77.97218323, 29.6756897], [77.97207642, 29.67465973], [77.97277069, 29.67253113], [77.97162628, 29.67053986], [77.9704895, 29.66856956], [77.96936035, 29.66657066], [77.96913147, 29.66451073], [77.96891785, 29.66246033], [77.96788025, 29.66151047], [77.96673584, 29.6595211], [77.96537781, 29.65547943], [77.96750641, 29.64907074], [77.97168732, 29.64456749], [77.97445679, 29.64435005], [77.97537994, 29.64426994], [77.97702026, 29.64206123], [77.97471619, 29.63809967], [77.97312927, 29.63199043], [77.97351837, 29.62676239], [77.97493744, 29.62249947], [77.97541809, 29.61831093], [77.97683716, 29.61403847], [77.97464752, 29.61108971], [77.97025299, 29.61351967], [77.96633148, 29.61174965], [77.96240234, 29.60999107], [77.95986176, 29.61227989], [77.95822144, 29.61449051], [77.95568848, 29.61679077], [77.95186615, 29.61603928], [77.9496994, 29.61310959], [77.95040131, 29.61096954], [77.95101166, 29.60778999], [77.95240784, 29.60351944], [77.95323181, 29.60241127], [77.95092773, 29.59844017], [77.94876862, 29.5954895], [77.94854736, 29.59342957], [77.94832611, 29.59136963], [77.94728851, 29.59043121], [77.94822693, 29.5903492], [77.9498291, 29.58813095], [77.95157623, 29.58694077], [77.95320892, 29.58472061], [77.95598602, 29.58444977], [77.95987701, 29.58621025], [77.96174622, 29.5860405], [77.96337128, 29.58382988], [77.96631622, 29.5845108], [77.96736145, 29.58572006], [77.96955109, 29.58518982], [77.97268677, 29.58315086], [77.97299957, 29.58333969], [77.97704315, 29.58333015], [77.97881317, 29.58536911], [77.98101044, 29.58781052], [77.98232269, 29.58901024], [77.98375702, 29.58805084], [77.98457336, 29.58455276], [77.98404694, 29.57986069], [77.9807663, 29.56875992], [77.97881317, 29.5681591], [77.97675323, 29.56384087], [77.97705841, 29.55811119], [77.97885895, 29.55413055], [77.98802185, 29.54586029], [77.99415588, 29.55509949], [78.00351715, 29.5560894], [78.01661682, 29.55462074], [78.01927185, 29.55405045], [78.03256226, 29.55170059], [78.03688049, 29.55262947], [78.03826141, 29.56143951], [78.03721619, 29.5652504], [78.04264069, 29.57191277], [78.0407486, 29.5753212], [78.03730011, 29.57776833], [78.03650665, 29.58086014], [78.03975677, 29.58798027], [78.04393005, 29.59307098], [78.0506897, 29.59805107], [78.05924988, 29.60161018], [78.06826019, 29.60141182], [78.07315826, 29.59991074], [78.07850647, 29.59954262], [78.08206177, 29.60181046], [78.08867645, 29.61330032], [78.09062195, 29.62477112], [78.09423828, 29.62803078], [78.09683228, 29.63059998], [78.09751129, 29.63078117], [78.10697937, 29.63318062], [78.10913849, 29.63669968], [78.11482239, 29.64516068], [78.13400269, 29.65851021], [78.13912201, 29.67609978], [78.1659317, 29.67952919], [78.18222046, 29.69155121], [78.19229889, 29.70659065], [78.19352722, 29.71005821], [78.22126007, 29.71762276], [78.23139954, 29.70409012], [78.26476288, 29.72679138], [78.28193665, 29.74234009], [78.30293274, 29.75759125], [78.33174133, 29.79618073], [78.33193207, 29.79611969], [78.33853912, 29.7925396], [78.35125732, 29.78625107], [78.38598633, 29.77386093], [78.39842224, 29.77213287], [78.40838623, 29.77343941], [78.41256714, 29.77242088], [78.42431641, 29.76165009], [78.43212891, 29.75811958], [78.45215607, 29.75213814], [78.46473694, 29.75101089], [78.47357941, 29.74847031], [78.48757935, 29.7413826], [78.49021149, 29.72491837], [78.5002594, 29.71533966], [78.50184631, 29.71170807], [78.50601959, 29.69388962], [78.50744629, 29.69083023], [78.50724792, 29.67696953], [78.50763702, 29.6729126], [78.50961304, 29.66847992], [78.50921631, 29.65965271], [78.51151276, 29.65069008], [78.51774597, 29.63915062], [78.52546692, 29.62977028], [78.52735901, 29.62436295], [78.53054047, 29.62393188], [78.56121063, 29.59373093], [78.57647705, 29.58057022], [78.6052475, 29.5617981], [78.61515808, 29.55787086], [78.62149811, 29.55289078], [78.63957214, 29.54777908], [78.65039063, 29.54068947], [78.67655945, 29.52135086], [78.68540955, 29.5135498], [78.69335938, 29.50887108], [78.70826721, 29.50942039], [78.72660828, 29.50871086], [78.73152161, 29.50574112], [78.73905945, 29.50498009], [78.74225616, 29.5012207], [78.76577759, 29.48378944], [78.77474976, 29.48093987], [78.7855072, 29.47603035], [78.79695129, 29.47595024], [78.81138611, 29.46982956], [78.81669617, 29.46857071], [78.82376862, 29.46969032], [78.83006287, 29.46850967], [78.84612274, 29.46365166], [78.86575317, 29.45960045], [78.87542725, 29.4599781], [78.8826828, 29.45784187], [78.8901062, 29.45754051], [78.89601898, 29.45618057], [78.90033722, 29.45618057], [78.91979218, 29.46014977], [78.92292786, 29.45618057], [78.90714264, 29.45183182], [78.90040588, 29.44668961], [78.89647675, 29.42358017], [78.89061737, 29.41642952], [78.88719177, 29.40899086], [78.88279724, 29.40480042], [78.87275696, 29.39856911], [78.87018585, 29.39236259], [78.86599731, 29.39311981], [78.86258698, 29.39460945], [78.8602066, 29.39388275], [78.85888672, 29.39147949], [78.86003113, 29.38931084], [78.85975647, 29.38767052], [78.85679626, 29.3855896], [78.84039307, 29.3799305], [78.83631134, 29.38143158], [78.8325119, 29.38134956], [78.83185577, 29.37658119], [78.8347168, 29.37434959], [78.83580017, 29.37228775], [78.83625793, 29.37140846], [78.83436584, 29.36967087], [78.82881927, 29.36818123], [78.8239212, 29.36844063], [78.81417847, 29.3700428], [78.81176758, 29.37231064], [78.81095886, 29.38027954], [78.81500244, 29.38533974], [78.81160736, 29.38470078], [78.80898285, 29.38287926], [78.80776978, 29.38027191], [78.80684662, 29.37315178], [78.79720306, 29.35563087], [78.79014587, 29.35211945], [78.79012299, 29.35040092], [78.79167175, 29.34787941], [78.79270172, 29.34342766], [78.7979126, 29.33831978], [78.79738617, 29.33697128], [78.79133606, 29.33499908], [78.78884125, 29.32928276], [78.78132629, 29.33196068], [78.78444672, 29.34292984], [78.78246307, 29.34644127], [78.78089142, 29.34352112], [78.77905273, 29.3422718], [78.7696228, 29.34065056], [78.76593018, 29.3410511], [78.76384735, 29.34320068], [78.76532745, 29.34572983], [78.76352692, 29.34739113], [78.75740814, 29.34976006], [78.74704742, 29.34333992], [78.74608612, 29.34091949], [78.74164581, 29.33588028], [78.74150085, 29.33262062], [78.73478699, 29.3317585], [78.7315979, 29.33431053], [78.72834778, 29.33415985], [78.7277298, 29.33138084], [78.72570801, 29.32998276], [78.72592163, 29.32512093], [78.72860718, 29.31896019], [78.7273407, 29.31748962], [78.72110748, 29.31945992], [78.71975708, 29.31842041], [78.71412659, 29.31933022], [78.71385956, 29.31735039], [78.72080231, 29.31228065], [78.72756195, 29.31278992], [78.73139191, 29.31101036], [78.73889923, 29.30631065], [78.74675751, 29.30270958], [78.76107788, 29.29333115], [78.76552582, 29.28992081], [78.76683044, 29.28590965], [78.75863647, 29.28667068], [78.78153992, 29.2712307], [78.78600311, 29.27301979], [78.78736877, 29.26533127], [78.78994751, 29.26299095], [78.79286957, 29.26260948], [78.79988098, 29.25785255], [78.81378174, 29.25229073], [78.81611633, 29.25382805], [78.82289886, 29.25579071], [78.82756042, 29.25793076], [78.83125305, 29.26073837], [78.83319092, 29.25942039], [78.83405304, 29.25619125], [78.84233093, 29.25428009], [78.84519196, 29.25814056], [78.84668732, 29.25824928], [78.8506012, 29.26222992], [78.85262299, 29.26131058], [78.85383606, 29.25921059], [78.85437775, 29.25542068], [78.85787201, 29.25220108], [78.86406708, 29.24949265], [78.87097931, 29.24073029], [78.87359619, 29.23525238], [78.87303925, 29.23225975], [78.86958313, 29.22953987], [78.87014771, 29.22853088], [78.88286591, 29.22532082], [78.88445282, 29.21951294], [78.88687897, 29.21783066], [78.89103699, 29.21647263], [78.89214325, 29.21487236], [78.89225769, 29.21285057], [78.88774872, 29.21033287], [78.89356232, 29.20483971], [78.89916229, 29.20259285], [78.89720917, 29.19869041], [78.89434814, 29.19589996], [78.89911652, 29.19063187], [78.90130615, 29.18273926], [78.90570068, 29.18033981], [78.9057312, 29.17748833], [78.90239716, 29.17449951], [78.9045105, 29.17057037], [78.90332031, 29.16768074], [78.90571594, 29.16521072], [78.90479279, 29.16316986], [78.89961243, 29.16142082], [78.89504242, 29.15681076], [78.89589691, 29.15579033], [78.89834595, 29.15488815], [78.90040588, 29.15061951], [78.9144516, 29.14898109], [78.92077637, 29.15286064], [78.92363739, 29.1571312], [78.93371582, 29.15420914], [78.94438934, 29.14958954], [78.94888306, 29.15278053], [78.95146942, 29.15970993], [78.95610809, 29.16037178], [78.9608078, 29.16159821], [78.96127319, 29.16317749], [78.96035004, 29.16460037], [78.96057892, 29.16587067], [78.96232605, 29.16681099], [78.96662903, 29.16555023], [78.97319794, 29.16082001], [78.97901154, 29.15475082], [78.98262787, 29.1469593], [78.98353577, 29.13734818], [78.98809814, 29.13512039], [78.99262238, 29.13363266], [78.9954071, 29.12927055], [78.99465942, 29.12537003], [78.99838257, 29.12294006], [79.0005722, 29.11655045], [79.00657654, 29.12051964], [79.01700592, 29.11786079], [79.02185059, 29.11892128], [79.02606964, 29.12154961], [79.02970123, 29.12543106], [79.03096771, 29.13022995], [79.02768707, 29.13296127], [79.02352142, 29.13312912], [79.01899719, 29.13508987], [79.01187134, 29.13471031], [79.00875854, 29.13622093], [79.00859833, 29.13936234], [79.01203918, 29.14487076], [79.01278687, 29.14912987], [79.01048279, 29.15302849], [79.01095581, 29.15722084], [79.01335144, 29.15769005], [79.01696777, 29.15397072], [79.02147675, 29.1508007], [79.02639771, 29.14986038], [79.02867889, 29.15239906], [79.02742004, 29.15588188], [79.0275116, 29.16074944], [79.02388, 29.16338921], [79.02175903, 29.16730118], [79.02307129, 29.17079163], [79.02614594, 29.17196083], [79.02696228, 29.17226982], [79.03378296, 29.17110062], [79.0382309, 29.16629028], [79.04612732, 29.15472984], [79.05438232, 29.15518188], [79.05947876, 29.15626907], [79.07286072, 29.15199089], [79.09223938, 29.13674164], [79.10074615, 29.13167953], [79.10853577, 29.13043976], [79.11361694, 29.13066292], [79.11779022, 29.13388062], [79.13080597, 29.1293602], [79.13384247, 29.12416077], [79.14221954, 29.11972809], [79.14398193, 29.1066227], [79.14319611, 29.09894943], [79.1370163, 29.09090805], [79.13471985, 29.08191109], [79.13698578, 29.06933975], [79.14369965, 29.06009102], [79.15345764, 29.05476952], [79.1654129, 29.05125809], [79.16015625, 29.0433197], [79.15866852, 29.03421021], [79.15421295, 29.03292084], [79.15451813, 29.02741051], [79.15827942, 29.02287865], [79.16410065, 29.02058983], [79.16562653, 29.01729965], [79.16858673, 29.0158596], [79.17759705, 29.0196209], [79.18493652, 29.01801109], [79.18296051, 29.02420998], [79.19758606, 29.02209091], [79.19911194, 29.02527809], [79.2040329, 29.02910042], [79.21116638, 29.02370071], [79.22154236, 29.01729012], [79.23774719, 29.00683975], [79.23937225, 28.99990082], [79.24389648, 28.99648094], [79.24996948, 28.99217987], [79.25801849, 28.98694992], [79.26434326, 28.98213959], [79.26846313, 28.97739983], [79.27052307, 28.97542953], [79.27365112, 28.97287178], [79.27887726, 28.96483994], [79.28600311, 28.96050262], [79.29547882, 28.95429993], [79.29892731, 28.95311165], [79.30150604, 28.95285034], [79.30467987, 28.95393944], [79.30718994, 28.95846939], [79.31215668, 28.95806122], [79.31658936, 28.95679092], [79.32095337, 28.9567585], [79.32881165, 28.95540047], [79.33368683, 28.95498276], [79.33763885, 28.95453072], [79.34390259, 28.95313072], [79.349617, 28.95210075], [79.35189056, 28.95243073], [79.35476685, 28.9534111], [79.35389709, 28.95681953], [79.35275269, 28.95882034], [79.35285187, 28.96123123], [79.35507965, 28.96528053], [79.3571167, 28.96797943], [79.35967255, 28.97047997], [79.36338806, 28.96665955], [79.36506653, 28.96199036], [79.36743164, 28.95994949], [79.36897278, 28.95767975], [79.3707428, 28.95458031], [79.37224579, 28.9511795], [79.37252045, 28.94762993], [79.37336731, 28.9418602], [79.37490082, 28.93939018], [79.37702942, 28.93704987], [79.37934113, 28.93629074], [79.38497925, 28.93731117], [79.38942719, 28.93830109], [79.39556122, 28.93675041], [79.3983078, 28.93515968], [79.40143585, 28.93226051], [79.40261841, 28.92904091], [79.40139771, 28.92136955], [79.39900208, 28.9169693], [79.40007782, 28.91101074], [79.40123749, 28.90186119], [79.40114594, 28.89977074], [79.400383, 28.89558983], [79.39565277, 28.88544083], [79.3979187, 28.88104057], [79.40187836, 28.87728119], [79.40429688, 28.87490082], [79.4048233, 28.87112999], [79.40493774, 28.86745262], [79.40621948, 28.86225128], [79.4087677, 28.85801125], [79.41121674, 28.85588074], [79.41712189, 28.85584259], [79.41963196, 28.8553009], [79.42388916, 28.85523987], [79.42752838, 28.85725021], [79.43031311, 28.8597908], [79.43345642, 28.86164284], [79.43976593, 28.86104965], [79.44777679, 28.86005974], [79.45510864, 28.86005974], [79.4597168, 28.85915947], [79.46338654, 28.86053085], [79.46470642, 28.86275291], [79.46776581, 28.86491013], [79.47663116, 28.86717033], [79.48262787, 28.86622047], [79.48654938, 28.86459923], [79.49137115, 28.86259842], [79.49691772, 28.86239052], [79.50248718, 28.86276054], [79.5072403, 28.86330032], [79.51013184, 28.86470032], [79.51406097, 28.86759186], [79.51732635, 28.87058067], [79.51996613, 28.87329102], [79.52259827, 28.87632942], [79.52591705, 28.88199806], [79.52989197, 28.88689041], [79.53308868, 28.89031029], [79.53645325, 28.89253998], [79.53866577, 28.89241028], [79.54332733, 28.89066124], [79.55049896, 28.88418007], [79.55253601, 28.88153076], [79.55397034, 28.87852097], [79.55374146, 28.87481117], [79.55166626, 28.86824989], [79.5512619, 28.86610985], [79.55120087, 28.86320114], [79.54991913, 28.86016083], [79.54767609, 28.85429955], [79.54821777, 28.85004997], [79.55092621, 28.84589195], [79.5535965, 28.84505081], [79.55716705, 28.84568977], [79.5594101, 28.84670067], [79.56233978, 28.84790993], [79.56347656, 28.8487606], [79.56578827, 28.84946823], [79.57189941, 28.84902], [79.57427979, 28.84930038], [79.57655334, 28.85028076], [79.57878876, 28.85238266], [79.58197021, 28.85584259], [79.59226227, 28.86655045], [79.59805298, 28.86491966], [79.60360718, 28.86470032], [79.60868073, 28.86671066], [79.61354828, 28.86873055], [79.61904144, 28.86758041], [79.62399292, 28.86268997], [79.63075256, 28.85885811], [79.634552, 28.8584404], [79.64109802, 28.85646248], [79.6432724, 28.85322952], [79.64393616, 28.852911], [79.65405273, 28.84873962], [79.6594696, 28.84773064], [79.66619873, 28.84832954], [79.6672821, 28.8500309], [79.66709137, 28.85409927], [79.67285919, 28.8576107], [79.68434143, 28.8573494], [79.68643951, 28.86700058], [79.68814087, 28.86819077], [79.69233704, 28.86832047], [79.69705963, 28.87028122], [79.70189667, 28.86989975], [79.70517731, 28.87022018], [79.7056427, 28.8723526], [79.70672607, 28.87523842], [79.70961761, 28.87920952], [79.71218872, 28.88068008], [79.71555328, 28.88178062], [79.71813202, 28.88275909], [79.72836304, 28.88507271], [79.73282623, 28.88309097], [79.73726654, 28.88259125], [79.74044037, 28.88318062], [79.74128723, 28.88535118], [79.74487305, 28.88978004], [79.748703, 28.89154053], [79.74996948, 28.89335251], [79.75977325, 28.88953018], [79.76197052, 28.8896904], [79.77446747, 28.89183044], [79.79064178, 28.87742996], [79.79125214, 28.87380981], [79.79161835, 28.87039757], [79.79485321, 28.86987114], [79.79696655, 28.87045097], [79.80280304, 28.87182045], [79.80574036, 28.86905098], [79.80693817, 28.86631012], [79.8086319, 28.86283112], [79.80901337, 28.85890961], [79.80812073, 28.85629082], [79.79991913, 28.85427094], [79.7946167, 28.8528595], [79.79669952, 28.84955025], [79.79815674, 28.84803963], [79.798172, 28.84604073], [79.79431152, 28.84303093], [79.79367065, 28.8392601], [79.79920197, 28.83623123], [79.80146027, 28.8332901], [79.80119324, 28.82963753], [79.79988098, 28.82468987], [79.79782104, 28.82081032], [79.79704285, 28.81649017], [79.79479218, 28.8147316], [79.79189301, 28.81517029], [79.78940582, 28.81970024], [79.78617096, 28.82093048], [79.78214264, 28.81319046], [79.78336334, 28.80541992], [79.78544617, 28.80620956], [79.79203033, 28.80303955], [79.7947464, 28.80380058], [79.8012619, 28.80454063], [79.80303955, 28.80558968], [79.80419922, 28.80706024], [79.80503845, 28.80873108], [79.80905151, 28.81075096], [79.81128693, 28.81138039], [79.81407166, 28.81060982], [79.81591034, 28.81225967], [79.81503296, 28.81458092], [79.81465149, 28.81912041], [79.81620789, 28.8217411], [79.8157196, 28.82468033], [79.81282806, 28.83018112], [79.813797, 28.83171082], [79.82234955, 28.8417511], [79.82446289, 28.84478951], [79.82965088, 28.84667969], [79.83383942, 28.84439087], [79.84171295, 28.84260941], [79.8441391, 28.84354019], [79.8494873, 28.84538078], [79.85404968, 28.84428978], [79.85468292, 28.84140968], [79.85560608, 28.83905983], [79.86061096, 28.83413124], [79.87101746, 28.83065033], [79.87532043, 28.83024025], [79.87547302, 28.82128906], [79.87563324, 28.8183403], [79.87123871, 28.81641006], [79.86042023, 28.81791115], [79.85423279, 28.82082939], [79.84971619, 28.8217411], [79.84620667, 28.82130051], [79.84332275, 28.81504059], [79.8405304, 28.80866051], [79.84648895, 28.80496025], [79.85336304, 28.80080032], [79.85965729, 28.79845047], [79.86728668, 28.79644966], [79.87307739, 28.79646111], [79.88012695, 28.79681969], [79.88604736, 28.79881096], [79.89480591, 28.80145073], [79.90129089, 28.80212021], [79.9005661, 28.79940033], [79.89813232, 28.79488754], [79.8934021, 28.79186249], [79.8889389, 28.78577042], [79.89209747, 28.78125954], [79.89450836, 28.77900124], [79.8992691, 28.77386093], [79.90571594, 28.77209854], [79.91204834, 28.76496124], [79.91014099, 28.76333046], [79.91172791, 28.75928116], [79.91808319, 28.75219917], [79.92150879, 28.74500084], [79.92233276, 28.73829079], [79.92237854, 28.73270988], [79.92951965, 28.72651291], [79.94087219, 28.72145844], [79.95288849, 28.71752167], [79.96782684, 28.71562004], [79.97483063, 28.7167511], [79.98825836, 28.71701813], [79.99958038, 28.72564125], [80.00286865, 28.72694969], [80.00565338, 28.72949982], [80.0136261, 28.73736954], [80.02297211, 28.74867058], [80.02906799, 28.75806046], [80.03124237, 28.76055908], [80.03344727, 28.76138115], [80.03476715, 28.76323128], [80.03398132, 28.76638031], [80.0345459, 28.76904106], [80.03816223, 28.77511978], [80.04045868, 28.78310966], [80.03623962, 28.79071999], [80.0326767, 28.79417992], [80.02736664, 28.79737854], [80.02568817, 28.79985046], [80.03198242, 28.80348969], [80.03360748, 28.80546951], [80.03408813, 28.80982971], [80.0584259, 28.83526039], [80.06381226, 28.83189964], [80.0696106, 28.8298912], [80.07013702, 28.8296833], [80.07025146, 28.82963943], [80.07238007, 28.82974434], [80.07671356, 28.82438278], [80.10886383, 28.82771873], [80.11964417, 28.82871437], [80.11980438, 28.82872963], [80.11997223, 28.82860565], [80.12274933, 28.82657433], [80.12705994, 28.82342148], [80.13316345, 28.81895256], [80.14019775, 28.81383514], [80.15667725, 28.79784012], [80.16027069, 28.79434776], [80.16233826, 28.79234123], [80.16316223, 28.79154015], [80.16493225, 28.78982162], [80.17298889, 28.7820015], [80.18338013, 28.77579498], [80.20236206, 28.76446152], [80.21772766, 28.75528336], [80.22679901, 28.75714684], [80.23535919, 28.75914192], [80.23592377, 28.75922012], [80.23698425, 28.75836945], [80.23831177, 28.75730705], [80.24319458, 28.75612068], [80.24704742, 28.75592613], [80.25228882, 28.75782204], [80.25449371, 28.75608826], [80.26358795, 28.74894142], [80.26679993, 28.74350548], [80.26622772, 28.73775864], [80.2634201, 28.73271561], [80.25946045, 28.73026848], [80.25790405, 28.72933578], [80.2622757, 28.72587013], [80.26802063, 28.72131538], [80.27370453, 28.71471977], [80.27651215, 28.71141434], [80.27922058, 28.70991516], [80.2926712, 28.71107864], [80.29541779, 28.71131516], [80.29850769, 28.70967484], [80.29953766, 28.70803642], [80.30062103, 28.70631981], [80.30558777, 28.70535278], [80.30961609, 28.70461464], [80.31851959, 28.7001152], [80.32236481, 28.69488716], [80.3236618, 28.68937492], [80.32369232, 28.68923187], [80.32423401, 28.68693352], [80.32299042, 28.68121719], [80.32758331, 28.66978264], [80.32758331, 28.66829681], [80.32758331, 28.66630363], [80.33892059, 28.6607151], [80.35031891, 28.65324593], [80.35501862, 28.65011597], [80.35691833, 28.64704132], [80.36238098, 28.64492989], [80.35890198, 28.64144897], [80.35968018, 28.63969994], [80.36091614, 28.63701439], [80.36371613, 28.63501358], [80.36991882, 28.63481522], [80.37236786, 28.63245773], [80.37258148, 28.63225555], [80.37332153, 28.62902069], [80.3769455, 28.62911415], [80.37804413, 28.62827492], [80.3846283, 28.63063622], [80.38786316, 28.62962914], [80.40626526, 28.63483238], [80.41641998, 28.63911438], [80.4256134, 28.63711548], [80.4280014, 28.63759613], [80.43412018, 28.63721466], [80.43930817, 28.63523483], [80.44102478, 28.63287926], [80.44430542, 28.62841988], [80.45067596, 28.62867928], [80.45281982, 28.6288147], [80.45820618, 28.62332535], [80.46281433, 28.62071609], [80.46401978, 28.61781502], [80.46446991, 28.61698723], [80.46466064, 28.61696625], [80.46590424, 28.61510277], [80.46573639, 28.61470604], [80.4655304, 28.61423302], [80.46479034, 28.61464691], [80.46270752, 28.61451912], [80.46411133, 28.61252213], [80.46632385, 28.60565567], [80.46788788, 28.6007061], [80.47316742, 28.59085083], [80.4733429, 28.59052658], [80.4726181, 28.58453178], [80.47170258, 28.5843029], [80.47013092, 28.58390999], [80.47025299, 28.58291626], [80.47708893, 28.58304024], [80.48031616, 28.58527756], [80.48154449, 28.58527756], [80.48162079, 28.5853157], [80.48280334, 28.58527756], [80.48542023, 28.58201599], [80.49659729, 28.57521057], [80.50141907, 28.56961441], [80.50814056, 28.56798744], [80.51172638, 28.56365776], [80.51698303, 28.55731583], [80.51934052, 28.55172348], [80.52161407, 28.55421448], [80.52441406, 28.5527153], [80.53199005, 28.57342529], [80.53195953, 28.57351112], [80.52729797, 28.57322311], [80.52331543, 28.5768261], [80.51650238, 28.61585808], [80.51299286, 28.62371063], [80.51288605, 28.62429428], [80.50792694, 28.64631081], [80.50518799, 28.66522598], [80.50780487, 28.67089081], [80.54161835, 28.69053841], [80.55177307, 28.69153023], [80.55587769, 28.69066048], [80.56707764, 28.6884594], [80.57041931, 28.68780327], [80.57919312, 28.68452454], [80.59204102, 28.67972565], [80.58259583, 28.66256332], [80.58184814, 28.66120911], [80.58379364, 28.6606102], [80.59925079, 28.65586472], [80.5970459, 28.65355873], [80.59145355, 28.64762497], [80.60011292, 28.65006828], [80.6079483, 28.65225983], [80.61064148, 28.64566994], [80.61328888, 28.63921165], [80.63491821, 28.63721466], [80.64321899, 28.64321518], [80.65031433, 28.63621521], [80.6529007, 28.63389969], [80.6583786, 28.63654518], [80.66934204, 28.64182091], [80.67246246, 28.6282959], [80.68127441, 28.62045479], [80.67970276, 28.60910416], [80.67962646, 28.6085434], [80.67903137, 28.60429192], [80.68694305, 28.60386467], [80.69742584, 28.60329628], [80.69192505, 28.5870285], [80.70562744, 28.57869148], [80.70782471, 28.57646942], [80.71630096, 28.5678978], [80.7233429, 28.57273865], [80.72621918, 28.57471466], [80.72809601, 28.5735302], [80.74030304, 28.56581497], [80.74005127, 28.57421684], [80.75148773, 28.57072449], [80.76065063, 28.56809425], [80.76963043, 28.56551743], [80.77101898, 28.55176163], [80.77124023, 28.54961014], [80.77375793, 28.54906464], [80.7844162, 28.54671478], [80.79181671, 28.54351616], [80.79161072, 28.54297638], [80.78627777, 28.52923012], [80.7880249, 28.52729034], [80.79075623, 28.52425957], [80.80144501, 28.52102852], [80.81014252, 28.5208168], [80.81356049, 28.52071953], [80.81373596, 28.52071571], [80.8172226, 28.52065468], [80.83172607, 28.51173019], [80.84379578, 28.50100136], [80.84529877, 28.49963188], [80.84605408, 28.49542046], [80.85699463, 28.49704361], [80.86728668, 28.48943901], [80.86332703, 28.5041256], [80.87762451, 28.50971794], [80.88355255, 28.50851822], [80.89789581, 28.50559998], [80.90151978, 28.5004158], [80.90702057, 28.49941444], [80.90856171, 28.49846458], [80.90960693, 28.4977932], [80.91030884, 28.49753952], [80.90873718, 28.48979568], [80.90869904, 28.4896183], [80.90311432, 28.48561478], [80.90692139, 28.46814919], [80.90744781, 28.46572685], [80.90969086, 28.46387863], [80.91459656, 28.45982933], [80.91738892, 28.45752335], [80.91706848, 28.46009064], [80.91611481, 28.46771622], [80.92121887, 28.4637146], [80.9210968, 28.46343994], [80.91938019, 28.45963669], [80.92718506, 28.45887184], [80.93258667, 28.45835495], [80.93399811, 28.46250534], [80.93416595, 28.46299171], [80.94422913, 28.46833611], [80.94692993, 28.46613121], [80.93404388, 28.45851898], [80.9450531, 28.45510674], [80.94651794, 28.45471573], [80.95262909, 28.45545006], [80.95330811, 28.45553589], [80.95341492, 28.44745827], [80.9550705, 28.44774055], [80.95903015, 28.44841194], [80.96582031, 28.44961548], [80.96881866, 28.4569149], [80.98151398, 28.45516205], [80.96794128, 28.44555092], [80.96659851, 28.44459915], [80.96839142, 28.44363594], [80.96983337, 28.44285965], [80.96697235, 28.43776512], [80.98088837, 28.43431091], [80.97961426, 28.44251442], [80.99093628, 28.44163895], [80.99754333, 28.44944382], [81.00139618, 28.45392036], [81.01779938, 28.45178413], [81.01831818, 28.45170021], [81.01917267, 28.45155907], [81.01483154, 28.43855476], [81.01469421, 28.43813705], [81.02091217, 28.43167496], [81.02729797, 28.43585205], [81.03121948, 28.43841553], [81.03560638, 28.42783356], [81.01854706, 28.41563988], [81.02051544, 28.4131546], [81.02281952, 28.41031456], [81.02639008, 28.40660095], [81.03411865, 28.39871597], [81.03661346, 28.41331482], [81.04428101, 28.41096878], [81.04451752, 28.41089821], [81.04772186, 28.4099369], [81.06912994, 28.39439201], [81.07267761, 28.39166069], [81.074646, 28.39014626], [81.07508087, 28.38981056], [81.08153534, 28.3848381], [81.09111786, 28.38201523], [81.15041351, 28.371315], [81.19491577, 28.36381531], [81.20446014, 28.36198807], [81.2124176, 28.36051559], [81.21394348, 28.3592186], [81.21511841, 28.35821533], [81.22136688, 28.34480858], [81.23203278, 28.33031273], [81.23628998, 28.32456017], [81.23590088, 28.31572723], [81.23453522, 28.28888512], [81.2352066, 28.28821182], [81.23565674, 28.2877655], [81.28221893, 28.23471451], [81.29164886, 28.2249527], [81.29371643, 28.22281456], [81.29380035, 28.22278404], [81.30141449, 28.21981621], [81.32241058, 28.19716835], [81.32015991, 28.18225861], [81.32601929, 28.17547989], [81.32649994, 28.17492485], [81.32302094, 28.16871262], [81.3160553, 28.16762161], [81.30620575, 28.1684494], [81.30400848, 28.16771698], [81.30384064, 28.16692924], [81.30410004, 28.16589737], [81.30491638, 28.16291618], [81.30600739, 28.16252899], [81.30893707, 28.1614933], [81.31047821, 28.16097069], [81.31142426, 28.16062737], [81.31245422, 28.15553474], [81.31635284, 28.15743637], [81.32189941, 28.16013718], [81.32972717, 28.14820671], [81.32014465, 28.14510345], [81.31945038, 28.14317894], [81.31718445, 28.13692474], [81.31978607, 28.13341904], [81.33618927, 28.14012909], [81.34389496, 28.13950729], [81.37311554, 28.14221573], [81.37503815, 28.14489746], [81.37841797, 28.14961624], [81.38018799, 28.15541458], [81.37966919, 28.15675735], [81.3789444, 28.15864563], [81.37847137, 28.15876389], [81.37049103, 28.16075897], [81.36959839, 28.1617775], [81.36875153, 28.16274643], [81.36873627, 28.16586113], [81.37111664, 28.1699543], [81.37580872, 28.17305565], [81.37521362, 28.17542267], [81.37693787, 28.17689323], [81.3797226, 28.17630768], [81.39170837, 28.17368889], [81.41249847, 28.17455292], [81.42827606, 28.1705761], [81.44570923, 28.16213989], [81.44876862, 28.16024208], [81.44779205, 28.1559124], [81.4522934, 28.15143967], [81.45188904, 28.15056801], [81.45178223, 28.14198685], [81.45176697, 28.14075089], [81.46398163, 28.13128662], [81.46941376, 28.12708092], [81.47451019, 28.12546539], [81.48581696, 28.11813164], [81.48160553, 28.11004639], [81.48022461, 28.08251572], [81.50752258, 28.06981277], [81.52885437, 28.0589447], [81.53952026, 28.05351448], [81.54907227, 28.04903603], [81.58120728, 28.02941704], [81.58841705, 28.02501488], [81.5887146, 28.02488327], [81.58883667, 28.02442932], [81.59888458, 28.02041054], [81.60002136, 28.01995659], [81.61891174, 28.01026344], [81.61977386, 28.00916862], [81.62591553, 28.00145149], [81.6286087, 28.00156403], [81.63793182, 27.99733925], [81.64110565, 27.99697876], [81.64523315, 27.99373436], [81.6500473, 27.9932766], [81.67645264, 27.99087715], [81.69463348, 27.98942184], [81.69476318, 27.98941994], [81.69509125, 27.98941612], [81.70018005, 27.98812485], [81.70354462, 27.98540878], [81.70400238, 27.98652077], [81.75705719, 27.94296265], [81.7588501, 27.94153976], [81.7640686, 27.93743896], [81.80397034, 27.90544701], [81.80670929, 27.90324974], [81.81541443, 27.90441513], [81.82310486, 27.90288544], [81.8249588, 27.90251732], [81.82732391, 27.90040588], [81.8354187, 27.89741516], [81.84185791, 27.89096069], [81.84944153, 27.88710785], [81.86231995, 27.87781906], [81.87541962, 27.8693161], [81.88209534, 27.86221695], [81.88684845, 27.85715866], [81.89902496, 27.85479736], [81.90402222, 27.85368347], [81.92801666, 27.85964584], [81.92711639, 27.87531471], [81.9319458, 27.88253403], [81.93990326, 27.88784218], [81.94004059, 27.89359283], [81.94961548, 27.90341568], [81.95281982, 27.9101162], [81.96112061, 27.91631508], [81.96364594, 27.92302322], [81.97011566, 27.92881584], [81.99311829, 27.9291153], [82.02742004, 27.9250145], [82.04701996, 27.92441559], [82.06441498, 27.92151451], [82.06928253, 27.92215347], [82.06965637, 27.92339325], [82.07288361, 27.92252541], [82.08242798, 27.90902138], [82.09201813, 27.89931488], [82.09329987, 27.8945713], [82.10283661, 27.88599014], [82.11611938, 27.8774147], [82.12311554, 27.86775398], [82.12522125, 27.86483955], [82.14131165, 27.85978317], [82.15193939, 27.85780525], [82.15591431, 27.86611557], [82.1632309, 27.86244011], [82.16376495, 27.86217308], [82.16970062, 27.85920715], [82.17901611, 27.8545475], [82.18349457, 27.85288811], [82.19798279, 27.84752083], [82.20195007, 27.84604836], [82.21020508, 27.84299088], [82.23104858, 27.82191467], [82.23233032, 27.82062149], [82.25344849, 27.81053352], [82.25469971, 27.80993462], [82.30499268, 27.77297783], [82.30579376, 27.77242851], [82.31711578, 27.76631546], [82.33841705, 27.75461578], [82.3530426, 27.748806], [82.36901855, 27.74241447], [82.38407898, 27.72046852], [82.40332031, 27.70290947], [82.40368652, 27.70254517], [82.40471649, 27.70213127], [82.41471863, 27.69810677], [82.42572784, 27.69052124], [82.42917633, 27.68814468], [82.43899536, 27.68491364], [82.45071411, 27.67861557], [82.46733093, 27.67683601], [82.47515869, 27.67634201], [82.48381805, 27.68271446], [82.48596954, 27.68056297], [82.49192047, 27.68104935], [82.49441528, 27.68401527], [82.50224304, 27.68482208], [82.51811218, 27.69024277], [82.53247833, 27.68652725], [82.53294373, 27.68640518], [82.54064941, 27.6875248], [82.5431366, 27.68553543], [82.5514679, 27.6886425], [82.55350494, 27.68848991], [82.55643463, 27.68827057], [82.56388855, 27.6916256], [82.58688354, 27.69845963], [82.59559631, 27.69673538], [82.60205078, 27.70402718], [82.60527039, 27.70518494], [82.60591888, 27.70541573], [82.60701752, 27.70579338], [82.62081146, 27.70206451], [82.62123871, 27.70240784], [82.62950897, 27.70902443], [82.62961578, 27.71021461], [82.62975311, 27.71138573], [82.64044189, 27.70889854], [82.65721893, 27.71312523], [82.66616821, 27.72194862], [82.66656494, 27.72079468], [82.66840363, 27.71548653], [82.68271637, 27.71361542], [82.69111633, 27.71501541], [82.70088196, 27.72159386], [82.70121765, 27.72182465], [82.70394897, 27.71610641], [82.70703888, 27.71636391], [82.70974731, 27.72137833], [82.70991516, 27.72169876], [82.70751953, 27.7110157], [82.70781708, 27.70271492], [82.71191406, 27.69521523], [82.71762085, 27.6916256], [82.72020721, 27.68731117], [82.71856689, 27.68432426], [82.71691895, 27.68131447], [82.71721649, 27.67621613], [82.71723938, 27.67611313], [82.71811676, 27.67547035], [82.71798706, 27.6724472], [82.71800232, 27.6723671], [82.71513367, 27.67074776], [82.71786499, 27.66788864], [82.71739197, 27.66705513], [82.71734619, 27.66697693], [82.71687317, 27.66614914], [82.71375275, 27.66493607], [82.71621704, 27.66241455], [82.72234344, 27.66155052], [82.72097015, 27.65881729], [82.72234344, 27.65720177], [82.72458649, 27.65836716], [82.72569275, 27.65894127], [82.72653961, 27.65860558], [82.72668457, 27.65854645], [82.72756195, 27.6581955], [82.7322464, 27.65279007], [82.73241425, 27.65261459], [82.73339844, 27.64887428], [82.73309326, 27.64832687], [82.73278046, 27.64775658], [82.7321701, 27.64775658], [82.7303772, 27.64665413], [82.73004913, 27.64539528], [82.73551178, 27.64601707], [82.73526764, 27.64252472], [82.73812103, 27.64303398], [82.73961639, 27.64054871], [82.73948669, 27.63681984], [82.73700714, 27.63545418], [82.7401123, 27.63184929], [82.73564148, 27.62837219], [82.73861694, 27.62576103], [82.73770905, 27.62503242], [82.73675537, 27.62426949], [82.73281097, 27.62388229], [82.73861694, 27.62151527], [82.73503113, 27.61853027], [82.73712921, 27.61606598], [82.73683167, 27.61534119], [82.7371521, 27.61334229], [82.73825073, 27.61121941], [82.73761749, 27.61041641], [82.73687744, 27.6094799], [82.74051666, 27.60651588], [82.74421692, 27.60451508], [82.74729919, 27.60014153], [82.74681854, 27.59518814], [82.75170135, 27.59370232], [82.75198364, 27.59344292], [82.75738525, 27.58835411], [82.75758362, 27.58764458], [82.75764465, 27.5874424], [82.75788116, 27.58661461], [82.75415802, 27.58387947], [82.75291443, 27.57681465], [82.75080109, 27.57605171], [82.75099945, 27.57501221], [82.75117493, 27.57406235], [82.74978638, 27.57198143], [82.74971771, 27.57181549], [82.75341034, 27.56548691], [82.74991608, 27.56261444], [82.74597931, 27.56123543], [82.74885559, 27.55524635], [82.74906158, 27.55492401], [82.74371338, 27.55393028], [82.74197388, 27.55144501], [82.7401123, 27.55194092], [82.74048615, 27.55032539], [82.74162292, 27.55009842], [82.74297333, 27.54982948], [82.73962402, 27.54673195], [82.74171448, 27.54532051], [82.74396515, 27.54597664], [82.74272156, 27.54460907], [82.74458313, 27.54324341], [82.74344635, 27.54282951], [82.74321747, 27.54274559], [82.74371338, 27.54125404], [82.743927, 27.5412159], [82.74507904, 27.54100609], [82.74376678, 27.53999138], [82.74346924, 27.5397625], [82.74357605, 27.53856277], [82.74371338, 27.53702927], [82.74336243, 27.53695869], [82.74331665, 27.53661537], [82.7444458, 27.5355854], [82.74582672, 27.5356617], [82.7465744, 27.5339222], [82.745224, 27.53372955], [82.7448349, 27.53367424], [82.74404144, 27.53208542], [82.74394226, 27.53194809], [82.74707031, 27.53205872], [82.74700165, 27.53177261], [82.74821472, 27.53171539], [82.74736786, 27.53019524], [82.74918365, 27.53143692], [82.74712372, 27.52889442], [82.74707031, 27.52882767], [82.74734497, 27.52865982], [82.74893188, 27.52770805], [82.74879456, 27.52715302], [82.74843597, 27.5257206], [82.74946594, 27.52616882], [82.75042725, 27.52659035], [82.751297, 27.52447701], [82.75053406, 27.52382088], [82.75071716, 27.52341461], [82.75033569, 27.52283096], [82.75141907, 27.52261353], [82.74906158, 27.51938248], [82.74861908, 27.52021599], [82.74819183, 27.52087402], [82.74423981, 27.52099419], [82.74411774, 27.52101517], [82.74511719, 27.51653099], [82.73971558, 27.51821518], [82.73911285, 27.50900841], [82.73961639, 27.50856972], [82.73711395, 27.50821495], [82.73703766, 27.50453568], [82.73700714, 27.50310135], [82.76049042, 27.50111771], [82.77727509, 27.50051689], [82.78731537, 27.50001526], [82.80361176, 27.4963913], [82.83705139, 27.50150871], [82.85021973, 27.49941444], [82.87231445, 27.49841499], [82.89451599, 27.50061607], [82.92307281, 27.50112915], [82.92788696, 27.50123787], [82.93161774, 27.50086594], [82.94068146, 27.49202728], [82.94152069, 27.49121284], [82.94689941, 27.47675705], [82.95134735, 27.47249031], [82.95622253, 27.46780777], [82.9628067, 27.46582031], [82.99996948, 27.45836449], [83.01813507, 27.45408821], [83.02532196, 27.4523983], [83.03611755, 27.44871521], [83.07141876, 27.45141602], [83.07691956, 27.45264816], [83.09571075, 27.4536171], [83.11310577, 27.45451546], [83.1346817, 27.45562935], [83.14788055, 27.45640182], [83.1661911, 27.45749664], [83.16651917, 27.45751572], [83.16725159, 27.45737076], [83.17606354, 27.45562935], [83.17546844, 27.45603943], [83.19021606, 27.45401573], [83.19805908, 27.4459362], [83.20550537, 27.43470573], [83.21247864, 27.42418861], [83.2159729, 27.42075539], [83.21906281, 27.41772652], [83.22776031, 27.41176033], [83.23985291, 27.40727997], [83.2421875, 27.40642929], [83.25920105, 27.39398956], [83.2742157, 27.38341522], [83.26889801, 27.36851311], [83.26765442, 27.36540604], [83.27462006, 27.35261536], [83.2947464, 27.33595467], [83.29430389, 27.33551407], [83.29441833, 27.33541489], [83.29541016, 27.33475494], [83.29636383, 27.33471107], [83.29653168, 27.33401871], [83.29866028, 27.334198], [83.30121613, 27.33441544], [83.30179596, 27.33408356], [83.30257416, 27.33421516], [83.30680084, 27.33123207], [83.31015778, 27.33334351], [83.31528473, 27.33152199], [83.31960297, 27.32998848], [83.31755829, 27.3326664], [83.32059479, 27.3357048], [83.32026672, 27.33649635], [83.31996918, 27.33719635], [83.32605743, 27.33662224], [83.3265152, 27.33657837], [83.32691956, 27.33631516], [83.3299942, 27.33403206], [83.33090973, 27.33421516], [83.33364868, 27.33254433], [83.33370972, 27.33250618], [83.33398438, 27.33254242], [83.33699799, 27.33346939], [83.33813477, 27.33308983], [83.33831787, 27.33311462], [83.34521484, 27.33487892], [83.34606934, 27.3380661], [83.35451508, 27.33981514], [83.35444641, 27.33992386], [83.35292053, 27.34221458], [83.35762024, 27.34441566], [83.36121368, 27.34301567], [83.3605423, 27.34913826], [83.35986328, 27.35024643], [83.36658478, 27.35558319], [83.37001801, 27.35561562], [83.37179565, 27.35795021], [83.3757782, 27.35712242], [83.37612152, 27.36005592], [83.37442017, 27.36481476], [83.37602234, 27.36876297], [83.37676239, 27.3697567], [83.38481903, 27.37073898], [83.39019012, 27.37572098], [83.38845062, 27.3803196], [83.39006042, 27.38355064], [83.38838959, 27.38480377], [83.38707733, 27.38578796], [83.38681793, 27.39011574], [83.39031982, 27.39151573], [83.39463806, 27.39549446], [83.39803314, 27.39562988], [83.39950562, 27.39784241], [83.40071869, 27.39809799], [83.40758514, 27.40529823], [83.4079361, 27.40789795], [83.40851593, 27.41177559], [83.41168976, 27.4125061], [83.41156006, 27.41364861], [83.41143799, 27.41474342], [83.40921783, 27.41511536], [83.40761566, 27.41861534], [83.40187073, 27.4189682], [83.40253448, 27.4199028], [83.39789581, 27.42232513], [83.39493561, 27.42503548], [83.39381409, 27.42951584], [83.38683319, 27.43512535], [83.3866806, 27.43566132], [83.38665009, 27.43577194], [83.38633728, 27.43686485], [83.38829041, 27.43893242], [83.38839722, 27.43913841], [83.38608551, 27.4407177], [83.38601685, 27.44151688], [83.38596344, 27.44220734], [83.39170837, 27.44455147], [83.39201355, 27.4447155], [83.39366913, 27.446558], [83.39611053, 27.44640923], [83.39776611, 27.44634056], [83.40071869, 27.44891548], [83.40398407, 27.45749283], [83.40201569, 27.45971489], [83.4019928, 27.45983887], [83.40187073, 27.46345901], [83.40460205, 27.46606827], [83.40335846, 27.467062], [83.40000153, 27.46532249], [83.39791107, 27.46637154], [83.39752197, 27.46661568], [83.39761353, 27.46951485], [83.39740753, 27.46958351], [83.39068604, 27.47054291], [83.39105988, 27.47290421], [83.39439392, 27.47624016], [83.39093018, 27.47949028], [83.40857697, 27.47886848], [83.48214722, 27.47538948], [83.49269867, 27.47491455], [83.50961304, 27.47414589], [83.55323029, 27.47228241], [83.60956573, 27.46974564], [83.61673737, 27.46942329], [83.64095306, 27.45854187], [83.66812897, 27.4469986], [83.68692017, 27.43779182], [83.69441986, 27.43411446], [83.6951828, 27.43373871], [83.70932007, 27.42679787], [83.7109375, 27.42605209], [83.7473526, 27.4090271], [83.76187897, 27.40243149], [83.79705811, 27.3861599], [83.79775238, 27.38584137], [83.79941559, 27.38521576], [83.81408691, 27.37833214], [83.83322144, 27.36950874], [83.85471344, 27.3537159], [83.85850525, 27.35096169], [83.85640717, 27.34821129], [83.85624695, 27.3477211], [83.8549881, 27.34033012], [83.84934235, 27.33560944], [83.82933807, 27.32747078], [83.82833099, 27.3259182], [83.82849121, 27.32467079], [83.8289566, 27.32275963], [83.83058929, 27.32135963], [83.83625793, 27.3194809], [83.8425293, 27.32131195], [83.84523773, 27.31965256], [83.84741974, 27.3168602], [83.84797668, 27.31397057], [83.85051727, 27.31209946], [83.85463715, 27.31122971], [83.85907745, 27.3116703], [83.87240601, 27.31620979], [83.88794708, 27.32646942], [83.89356232, 27.32905006], [83.89758301, 27.33012962], [83.90804291, 27.33039093], [83.91668701, 27.32533073], [83.92359924, 27.31643105], [83.92534637, 27.30952072], [83.92565155, 27.30418968], [83.92188263, 27.29635811], [83.91883087, 27.29265976], [83.9105072, 27.28563118], [83.90406799, 27.2811718], [83.89804077, 27.27898979], [83.89615631, 27.277071], [83.89549255, 27.26815033], [83.89795685, 27.25942993], [83.90190125, 27.25213051], [83.90762329, 27.24802971], [83.91175842, 27.24650192], [83.92531586, 27.24253082], [83.94814301, 27.23833084], [83.95448303, 27.23504066], [83.95585632, 27.23352051], [83.95501709, 27.23106956], [83.96153259, 27.22795105], [83.96376038, 27.22526932], [83.96411896, 27.22319031], [83.96328735, 27.22108078], [83.96031189, 27.21665955], [83.96167755, 27.21376038], [83.96457672, 27.21100998], [83.97660828, 27.20342064], [83.97878265, 27.20043945], [83.98512268, 27.1817627], [83.98419952, 27.17871094], [83.97972107, 27.17340279], [83.9683075, 27.16559982], [83.96658325, 27.1608429], [83.95864868, 27.1486702], [83.95091248, 27.14088058], [83.95079803, 27.13908005], [83.95363617, 27.13194084], [83.9524765, 27.12898254], [83.95081329, 27.12634087], [83.94766235, 27.12362099], [83.94143677, 27.11983109], [83.93955994, 27.11667061], [83.93839264, 27.11102295], [83.93856812, 27.10732079], [83.94034576, 27.10230064], [83.93942261, 27.09299278], [83.94082642, 27.08962059], [83.94409943, 27.08725166], [83.94777679, 27.08620071], [83.9549408, 27.08612061], [83.97120667, 27.09194183], [83.97786713, 27.09262085], [83.98123169, 27.09382057], [83.99017334, 27.09884071], [83.99265289, 27.10014915], [83.99751282, 27.09848022], [84.00251007, 27.10028076], [84.00531769, 27.10403061], [84.0116272, 27.10488129], [84.01422119, 27.10008049], [84.02072144, 27.09548187], [84.01892853, 27.09344101], [84.01609802, 27.09176064], [84.01831818, 27.08723831], [84.01689148, 27.08376122], [84.01194, 27.08127975], [84.00559235, 27.07193947], [83.9910965, 27.07129288], [83.9907608, 27.06859016], [83.99489594, 27.06125069], [84.01217651, 27.05379105], [84.0242691, 27.0447197], [84.03125763, 27.04646111], [84.0356369, 27.0465107], [84.04081726, 27.04467964], [84.04030609, 27.03530121], [84.03595734, 27.02901268], [84.03572845, 27.01931953], [84.03044891, 27.01181984], [84.03993225, 27.00587273], [84.04270172, 27.00312042], [84.04516602, 26.99973106], [84.04432678, 26.99768066], [84.0495224, 26.99081039], [84.0459671, 26.98715973], [84.03901672, 26.98801994], [84.03643036, 26.98403168], [84.04250336, 26.9815712], [84.04345703, 26.98039055], [84.04125977, 26.96801186], [84.04599762, 26.96809006], [84.04666138, 26.96194077], [84.04415894, 26.96087074], [84.04086304, 26.95745277], [84.03862, 26.95775986], [84.03909302, 26.95430946], [84.03514862, 26.94872093], [84.0316925, 26.94933128], [84.02636719, 26.94896126], [84.02490234, 26.94272041], [84.02880859, 26.94120026], [84.02980804, 26.93956947], [84.03630829, 26.94113159], [84.03866577, 26.93828964], [84.03655243, 26.93301964], [84.03846741, 26.93087959], [84.04521942, 26.93042183], [84.04766846, 26.93182945], [84.04924011, 26.91459084], [84.04408264, 26.90979958], [84.04239655, 26.90912819], [84.04514313, 26.90474129], [84.04737854, 26.90621948], [84.05079651, 26.90164948], [84.04898071, 26.89994049], [84.05200195, 26.89170074], [84.05905151, 26.8907795], [84.06008911, 26.88646126], [84.07155609, 26.88187027], [84.0762558, 26.87878036], [84.08550262, 26.88524246], [84.08789063, 26.88235283], [84.08651733, 26.8789196], [84.09002686, 26.87715149], [84.09262085, 26.87783051], [84.09683228, 26.88633919], [84.09986877, 26.88799095], [84.10106659, 26.89383125], [84.09922028, 26.89521027], [84.10063171, 26.90084076], [84.10640717, 26.8950901], [84.10941315, 26.89443016], [84.11164093, 26.89188957], [84.12201691, 26.8926506], [84.12301636, 26.88902092], [84.13024902, 26.88527107], [84.14083862, 26.88758087], [84.14073944, 26.88391113], [84.13861847, 26.88306999], [84.13752747, 26.87630081], [84.13929749, 26.8740406], [84.13183594, 26.87055969], [84.13165283, 26.85569], [84.15054321, 26.83946991], [84.15727997, 26.83636093], [84.16892242, 26.83451843], [84.17471313, 26.8357811], [84.17740631, 26.8426609], [84.17533112, 26.84593964], [84.17694855, 26.84937859], [84.1764679, 26.85334015], [84.18080902, 26.85737991], [84.18531799, 26.86009026], [84.18955994, 26.85981941], [84.19655609, 26.86118126], [84.20922089, 26.87099075], [84.22109985, 26.87223816], [84.22196198, 26.87018013], [84.2286377, 26.8698101], [84.23538208, 26.86433983], [84.2410965, 26.86243057], [84.24563599, 26.85872269], [84.25211334, 26.84492111], [84.25041962, 26.83782005], [84.25102997, 26.83069992], [84.24646759, 26.8275795], [84.242836, 26.82181931], [84.2485199, 26.82089806], [84.24680328, 26.81454086], [84.25229645, 26.80867958], [84.2493515, 26.8022728], [84.24848938, 26.79268074], [84.24112701, 26.77543068], [84.23548889, 26.76698112], [84.22460938, 26.75710106], [84.2332077, 26.74510956], [84.2339859, 26.73953056], [84.24227905, 26.73077011], [84.24738312, 26.72929001], [84.25234222, 26.73147011], [84.25448608, 26.73426819], [84.25528717, 26.73896027], [84.25936127, 26.74081993], [84.26677704, 26.74207115], [84.27130127, 26.74454117], [84.27861023, 26.75123978], [84.28675079, 26.75144005], [84.29802704, 26.7532711], [84.30664825, 26.73957062], [84.30561829, 26.73768044], [84.3110199, 26.73360252], [84.31851196, 26.71623039], [84.32334137, 26.68847847], [84.32566071, 26.68425751], [84.33706665, 26.68144035], [84.34480286, 26.68042946], [84.35012054, 26.6814003], [84.35484314, 26.67888069], [84.36675262, 26.67881012], [84.40223694, 26.67122269], [84.40479279, 26.64275169], [84.40737152, 26.63805962], [84.41439819, 26.62717056], [84.4005661, 26.62413025], [84.39499664, 26.62573814], [84.38343811, 26.62150955], [84.37885284, 26.62183952], [84.37059021, 26.61539078], [84.35093689, 26.62042809], [84.3300705, 26.61832047], [84.32549286, 26.61532021], [84.3107605, 26.61457253], [84.30651855, 26.6170311], [84.30267334, 26.61747169], [84.29702759, 26.61569977], [84.29502106, 26.60663033], [84.2931366, 26.60551071], [84.28919983, 26.60699081], [84.28679657, 26.60392189], [84.27934265, 26.60658073], [84.27741241, 26.60073853], [84.27346802, 26.60135078], [84.2722168, 26.59936142], [84.26291656, 26.60302162], [84.25888824, 26.60732269], [84.25063324, 26.60794067], [84.24009705, 26.61004066], [84.2309494, 26.6097908], [84.22866821, 26.61321068], [84.22305298, 26.61309052], [84.22199249, 26.61568069], [84.21569824, 26.61868095], [84.20681763, 26.6209507], [84.20388031, 26.62053108], [84.20198822, 26.62434006], [84.18467712, 26.62585068], [84.17698669, 26.62454033], [84.16779327, 26.62629128], [84.16725159, 26.6241703], [84.14853668, 26.62774849], [84.15345764, 26.63367081], [84.15203094, 26.63850021], [84.13951111, 26.63903046], [84.13742065, 26.63648033], [84.12906647, 26.63850021], [84.12413025, 26.63741112], [84.12098694, 26.63755035], [84.12146759, 26.63462067], [84.1156311, 26.63743019], [84.1060791, 26.63723183], [84.10431671, 26.63266182], [84.09934998, 26.63396835], [84.09934998, 26.63557053], [84.09493256, 26.63648033], [84.09407806, 26.63832092], [84.08448792, 26.6401329], [84.08177948, 26.64286041], [84.08042145, 26.64075279], [84.08138275, 26.63677979], [84.08059692, 26.63392067], [84.08383942, 26.6314106], [84.08213806, 26.62655067], [84.07962036, 26.6237011], [84.08352661, 26.61825943], [84.08280182, 26.61505127], [84.08476257, 26.61055946], [84.08178711, 26.60311127], [84.08252716, 26.59959984], [84.07914734, 26.59435081], [84.07028961, 26.58925819], [84.0712204, 26.58448029], [84.06772614, 26.58130074], [84.06285095, 26.57969284], [84.05690765, 26.57341003], [84.05474854, 26.5676899], [84.04931641, 26.56159019], [84.04814148, 26.55751991], [84.04878235, 26.55033112], [84.04776001, 26.54348946], [84.0430069, 26.54096031], [84.03082275, 26.53555107], [84.02004242, 26.5320797], [84.01448059, 26.53202057], [84.00068665, 26.52501106], [83.9986496, 26.52503014], [83.99835205, 26.5273819], [83.99030304, 26.53014183], [83.9835968, 26.53146172], [83.97418976, 26.53194046], [83.97054291, 26.52943993], [83.96810913, 26.52584076], [83.96655273, 26.52095032], [83.96541595, 26.51173973], [83.9625473, 26.50860023], [83.95616913, 26.50819969], [83.94565582, 26.5102005], [83.94271851, 26.51347923], [83.94352722, 26.51589966], [83.94584656, 26.51842117], [83.9392395, 26.52128029], [83.93499756, 26.52444077], [83.93048859, 26.52478027], [83.91467285, 26.52024078], [83.90220642, 26.51807976], [83.90084076, 26.51371193], [83.90175629, 26.51044083], [83.90679169, 26.50675964], [83.90746307, 26.50037956], [83.90496826, 26.49434853], [83.90323639, 26.47227097], [83.90154266, 26.46730995], [83.90302277, 26.4610405], [83.90228271, 26.45025063], [83.9081192, 26.44950104], [83.91902161, 26.44552994], [83.9360733, 26.44168091], [83.94626617, 26.43810844], [83.96129608, 26.43714905], [83.98195648, 26.4346199], [83.9834671, 26.43490028], [83.990448, 26.44762993], [83.99263, 26.44761086], [84.00170135, 26.44359016], [84.0090332, 26.44498062], [84.01098633, 26.44845963], [84.01611328, 26.44197083], [84.01494598, 26.43947029], [84.0164032, 26.43192291], [84.02052307, 26.42884064], [84.02178192, 26.4250412], [84.03318024, 26.41378021], [84.03056335, 26.41300964], [84.03618622, 26.40784073], [84.03826141, 26.41040039], [84.04087067, 26.40849113], [84.0412674, 26.40555], [84.04498291, 26.4052906], [84.04509735, 26.40407181], [84.05497742, 26.40204811], [84.0550766, 26.40024757], [84.06181335, 26.39427948], [84.06151581, 26.39009094], [84.07061768, 26.38689041], [84.07200623, 26.38446999], [84.0772171, 26.38396263], [84.07884216, 26.38572121], [84.08055878, 26.38622093], [84.08116913, 26.38966942], [84.087677, 26.39011955], [84.08970642, 26.38751984], [84.09230042, 26.39043045], [84.09654236, 26.38791084], [84.11519623, 26.38756943], [84.11675262, 26.38524818], [84.12844086, 26.38421059], [84.13078308, 26.3821907], [84.15402985, 26.37615967], [84.15634155, 26.37825966], [84.1713562, 26.37397957], [84.1696167, 26.36256027], [84.16723633, 26.36022949], [84.16720581, 26.33810997], [84.17681885, 26.32249069], [84.18173981, 26.31703949], [84.17944336, 26.31178093], [84.17150879, 26.30369186], [84.16874695, 26.29286957], [84.1709671, 26.28664017], [84.16964722, 26.27723122], [84.16815948, 26.27367973], [84.17099762, 26.27050018], [84.1713562, 26.26773071], [84.1676178, 26.26402092], [84.16365051, 26.26136971], [84.15740204, 26.26091957], [84.15512848, 26.25772095], [84.15570831, 26.25254059], [84.15934753, 26.24590111], [84.15730286, 26.24413109], [84.1534729, 26.24526978], [84.14533997, 26.26165962], [84.1414032, 26.25774956], [84.12594604, 26.26144981], [84.12375641, 26.25881958], [84.11295319, 26.26192093], [84.11234283, 26.25657272], [84.1099472, 26.25309753], [84.11270142, 26.24967957], [84.11045837, 26.24183083], [84.10135651, 26.2430706], [84.10035706, 26.2392807], [84.09229279, 26.24022102], [84.09137726, 26.23402977], [84.08738708, 26.23653984], [84.07952118, 26.23184013], [84.08190155, 26.22710037], [84.08014679, 26.22442055], [84.07936859, 26.22121048], [84.07367706, 26.22103119], [84.07357788, 26.22488022], [84.05835724, 26.22674942], [84.05726624, 26.22521019], [84.04943848, 26.22557068], [84.04680634, 26.23019028], [84.03363037, 26.23208809], [84.03115845, 26.23567009], [84.03132629, 26.23907089], [84.02400208, 26.23958969], [84.02050018, 26.24163055], [84.01838684, 26.23878098], [84.01412201, 26.24058914], [84.01152039, 26.2406826], [84.01048279, 26.23879051], [84.01091003, 26.23581123], [84.00551605, 26.23406982], [84.0082016, 26.22531128], [84.00946045, 26.22392082], [84.01676941, 26.22161293], [84.02047729, 26.22364998], [84.0242691, 26.21976089], [84.02091217, 26.21422005], [84.01902008, 26.20928955], [84.01950073, 26.20601082], [84.02323914, 26.20449066], [84.02359009, 26.2009201], [84.02044678, 26.19755936], [84.01499939, 26.19742966], [84.00901031, 26.19955826], [84.00211334, 26.19013977], [84.00406647, 26.18069077], [84.00302124, 26.17823029], [84.01381683, 26.16698074], [84.01970673, 26.1640625], [84.02289581, 26.16534805], [84.02784729, 26.16296005], [84.02841187, 26.15962029], [84.02731323, 26.1530304], [84.02363586, 26.15414047], [84.0181427, 26.14512062], [84.03362274, 26.13747978], [84.04239655, 26.13154984], [84.04524231, 26.12042046], [84.04187775, 26.12050056], [84.04361725, 26.11717033], [84.04223633, 26.11162186], [84.04514313, 26.10631943], [84.04824829, 26.10383034], [84.04905701, 26.09970093], [84.06923676, 26.09912109], [84.08113861, 26.09976959], [84.09104156, 26.09654045], [84.1071701, 26.08171272], [84.11605072, 26.0748806], [84.12792206, 26.05553055], [84.13667297, 26.04701042], [84.1590271, 26.03224182], [84.16726685, 26.02547073], [84.166008, 26.00270081], [84.16622925, 25.99150085], [84.17024231, 25.99166107], [84.17243958, 25.99879074], [84.17640686, 25.99775124], [84.192276, 25.98953819], [84.19474792, 25.99130058], [84.20181274, 26.00056076], [84.21412659, 25.99620056], [84.22344208, 25.99117088], [84.23522949, 25.98600006], [84.24048615, 25.98275948], [84.24455261, 25.97681808], [84.25466919, 25.97108841], [84.2645874, 25.96726036], [84.27536774, 25.96129036], [84.28366089, 25.95560074], [84.29155731, 25.94828033], [84.29633331, 25.94698906], [84.30310822, 25.94639015], [84.30927277, 25.94688988], [84.3138504, 25.94796944], [84.34371185, 25.9587307], [84.34880066, 25.95998192], [84.35138702, 25.95934105], [84.36501312, 25.95053291], [84.3862915, 25.93818092], [84.40830231, 25.93135071], [84.4092865, 25.92438126], [84.4175415, 25.9114399], [84.42151642, 25.90220833], [84.42417145, 25.89833832], [84.42331696, 25.89242172], [84.4276886, 25.89118958], [84.43118286, 25.89266968], [84.44371796, 25.88966942], [84.45066071, 25.89022064], [84.46105194, 25.888731], [84.46655273, 25.88368988], [84.47867584, 25.88836098], [84.4852829, 25.8892498], [84.50652313, 25.8723793], [84.52864075, 25.87774086], [84.53164673, 25.87272072], [84.54055023, 25.86211967], [84.53990936, 25.8603611], [84.52825928, 25.86473083], [84.51999664, 25.86115074], [84.52625275, 25.85540962], [84.52697754, 25.83432961], [84.53292084, 25.83222961], [84.54425049, 25.82998085], [84.54685211, 25.84132004], [84.55654907, 25.83751106], [84.57141876, 25.82983971], [84.5871582, 25.81960106], [84.59819794, 25.80965042], [84.61089325, 25.80065918], [84.61682892, 25.79554939], [84.62021637, 25.79409027], [84.62111664, 25.79236031], [84.6190567, 25.78897095], [84.62075043, 25.77238083], [84.6146698, 25.77242279], [84.61013794, 25.77728081], [84.60289001, 25.77243996], [84.60053253, 25.76062965], [84.60318756, 25.75757027], [84.61487579, 25.75283813], [84.62232971, 25.74731827], [84.62628174, 25.74160194], [84.62989807, 25.73311043], [84.63059998, 25.72834015], [84.62419128, 25.72790909], [84.61306, 25.73073959], [84.59552002, 25.73911095], [84.55562592, 25.73640823], [84.55896759, 25.72165108], [84.55860901, 25.70098114], [84.55639648, 25.68857002], [84.55233002, 25.68403053], [84.53138733, 25.69283295], [84.53586578, 25.72649002], [84.5304718, 25.72462082], [84.52794647, 25.71537018], [84.52458954, 25.68435097], [84.51638031, 25.67770958], [84.50576782, 25.68226051], [84.49903107, 25.67739105], [84.48838806, 25.67785072], [84.48934174, 25.69108963], [84.46650696, 25.68551064], [84.46031952, 25.69071007], [84.46276093, 25.6958828], [84.4631958, 25.69864273], [84.45877838, 25.69843292], [84.45865631, 25.70321083], [84.45516968, 25.71031189], [84.44901276, 25.71138], [84.44877625, 25.71449089], [84.43855286, 25.71068001], [84.43247223, 25.71207809], [84.42417145, 25.71171951], [84.42360687, 25.6950798], [84.4108963, 25.69847107], [84.40187836, 25.69950104], [84.39710999, 25.70907021], [84.4004364, 25.71689034], [84.39546967, 25.72439957], [84.39311981, 25.72602081], [84.39364624, 25.72890282], [84.38117218, 25.73425102], [84.38448334, 25.73768044], [84.38852692, 25.74427986], [84.38001251, 25.74868965], [84.37296295, 25.74226952], [84.36953735, 25.74373055], [84.3675766, 25.74170113], [84.37168884, 25.73830032], [84.36950684, 25.7360096], [84.36617279, 25.73843956], [84.35440826, 25.74361992], [84.33748627, 25.74513054], [84.3312912, 25.74457169], [84.32562256, 25.7371006], [84.32443237, 25.73327065], [84.32318878, 25.72313118], [84.32356262, 25.70400047], [84.32071686, 25.68208122], [84.31858826, 25.67193985], [84.31339264, 25.66890907], [84.31212616, 25.67242813], [84.29876709, 25.67179108], [84.29477692, 25.6741581], [84.29212952, 25.67704964], [84.28777313, 25.67632294], [84.28357697, 25.67713928], [84.28218842, 25.67461014], [84.2928009, 25.66852951], [84.29013062, 25.66283035], [84.28557587, 25.66152954], [84.2729187, 25.66168976], [84.26843262, 25.66325951], [84.24759674, 25.66281128], [84.23322296, 25.6639595], [84.21707916, 25.66406059], [84.20291138, 25.66963959], [84.19950867, 25.67234993], [84.19719696, 25.69223022], [84.19431305, 25.70342064], [84.17398071, 25.7157402], [84.16750336, 25.72175026], [84.15550995, 25.7259407], [84.14823151, 25.73096085], [84.14524841, 25.72860909], [84.14834595, 25.72601128], [84.14453125, 25.72060966], [84.13572693, 25.71688271], [84.12930298, 25.71735954], [84.12654877, 25.71851921], [84.13150024, 25.72393036], [84.1367569, 25.72375107], [84.13669586, 25.72754097], [84.13511658, 25.73163033], [84.12309265, 25.72394943], [84.10787201, 25.72364044], [84.09439087, 25.72038078], [84.08289337, 25.71269035], [84.06964874, 25.69561005], [84.07356262, 25.68357277], [84.07402802, 25.67250061], [84.07969666, 25.65273094], [84.07650757, 25.63753128], [84.05683136, 25.63222122], [84.02822113, 25.62273979], [84.01423645, 25.61613083], [84.00004578, 25.60771942], [83.99156952, 25.60102272], [83.95587921, 25.57542992], [83.94432068, 25.56734085], [83.93966675, 25.56543159], [83.9253006, 25.56315231], [83.92098236, 25.56172943], [83.91705322, 25.55849075], [83.91356659, 25.55434036], [83.89942169, 25.53177071], [83.89626312, 25.52827263], [83.89280701, 25.5254612], [83.8881073, 25.52321053], [83.88247681, 25.52145958], [83.87692261, 25.52140808], [83.87296295, 25.52040291], [83.86820984, 25.51163292], [83.8712616, 25.5031929], [83.86672974, 25.49349976], [83.86443329, 25.49061966], [83.85977936, 25.48920059], [83.85491943, 25.48485947], [83.85112, 25.47372055], [83.8478775, 25.47100258], [83.83378601, 25.4629612], [83.82935333, 25.46149063], [83.82467651, 25.46124077], [83.82256317, 25.46202278], [83.81474304, 25.46832085], [83.81233978, 25.46790123], [83.81022644, 25.46591949], [83.80671692, 25.45850945], [83.80555725, 25.45370102], [83.80793762, 25.45325279], [83.8103714, 25.45425034], [83.81381989, 25.45389938], [83.81858826, 25.45294762], [83.82150269, 25.45158005], [83.83043671, 25.45108032], [83.83338165, 25.45014954], [83.83751678, 25.44622993], [83.83943939, 25.44211006], [83.83937073, 25.43877983], [83.83837128, 25.43688965], [83.8302002, 25.43358994], [83.82408142, 25.43324089], [83.82064819, 25.43761063], [83.81762695, 25.43732071], [83.80294037, 25.43285942], [83.79670715, 25.43279266], [83.7943573, 25.43161964], [83.79270172, 25.43015862], [83.80319214, 25.42692947], [83.80522156, 25.42453003], [83.80327606, 25.41810989], [83.79936981, 25.41098022], [83.79660797, 25.40827942], [83.78227234, 25.39872932], [83.77068329, 25.40019989], [83.7651825, 25.39966011], [83.76346588, 25.39861107], [83.76225281, 25.39114189], [83.76193237, 25.38791084], [83.74973297, 25.39206123], [83.74971771, 25.39677048], [83.75195313, 25.39839172], [83.75887299, 25.40051079], [83.75805664, 25.40121078], [83.75332642, 25.40416908], [83.7507019, 25.40497017], [83.74809265, 25.40434074], [83.74198151, 25.4005909], [83.74060059, 25.40020943], [83.73784637, 25.40089035], [83.7349472, 25.40933037], [83.7325058, 25.41060066], [83.72944641, 25.40621948], [83.72717285, 25.39850044], [83.72531128, 25.39767075], [83.71806335, 25.39981079], [83.7154007, 25.39923286], [83.70947266, 25.39525032], [83.70400238, 25.38614845], [83.70140839, 25.38585091], [83.69893646, 25.38819122], [83.69628143, 25.39635086], [83.69458008, 25.39609909], [83.69277954, 25.39377022], [83.68940735, 25.38585091], [83.67626953, 25.38170052], [83.67520142, 25.37839127], [83.67681885, 25.37675095], [83.68784332, 25.37414169], [83.68897247, 25.3712883], [83.68628693, 25.36944962], [83.67899323, 25.36658096], [83.67221832, 25.36458969], [83.66908264, 25.3644619], [83.66477966, 25.36689949], [83.66020966, 25.37100029], [83.65791321, 25.3692112], [83.66020203, 25.36387062], [83.65879822, 25.36302948], [83.65616608, 25.36366081], [83.65020752, 25.36795998], [83.6496582, 25.36544037], [83.65059662, 25.36157036], [83.65022278, 25.35910034], [83.64540863, 25.35764122], [83.64351654, 25.35444069], [83.64657593, 25.34720039], [83.64440155, 25.34500122], [83.64250183, 25.34111977], [83.63877106, 25.34015274], [83.63182831, 25.34205055], [83.62996674, 25.34324074], [83.628479, 25.34113121], [83.62898254, 25.3379097], [83.62835693, 25.33625031], [83.62477112, 25.33493805], [83.62238312, 25.32952118], [83.62005615, 25.32858086], [83.61464691, 25.33166122], [83.61065674, 25.3325901], [83.60721588, 25.33230972], [83.60320282, 25.33156967], [83.58805847, 25.32644081], [83.58389282, 25.32489014], [83.58081818, 25.32234955], [83.5788269, 25.31726837], [83.57788086, 25.31664848], [83.57224274, 25.31761932], [83.56938171, 25.31013107], [83.56417084, 25.30814934], [83.56289673, 25.30965805], [83.56426239, 25.31585121], [83.56088257, 25.31608009], [83.55430603, 25.31406975], [83.55123138, 25.31389236], [83.54747772, 25.31585121], [83.53946686, 25.31764984], [83.53465271, 25.31520081], [83.53314972, 25.31287193], [83.5443573, 25.31314278], [83.54664612, 25.31160927], [83.54531097, 25.30985069], [83.54257965, 25.30932045], [83.53118134, 25.30451012], [83.52879333, 25.30144119], [83.52561188, 25.29953957], [83.52310181, 25.30045128], [83.52002716, 25.30332184], [83.51806641, 25.3024807], [83.51693726, 25.30060959], [83.51690674, 25.29846954], [83.51795197, 25.29323959], [83.51117706, 25.28782082], [83.5080719, 25.28619957], [83.50260162, 25.28957176], [83.49820709, 25.28297043], [83.49688721, 25.28300095], [83.49572754, 25.28440285], [83.49476624, 25.28729057], [83.4912796, 25.28659058], [83.48961639, 25.28116989], [83.48619843, 25.27950287], [83.48206329, 25.28289032], [83.48026276, 25.28240967], [83.47101593, 25.27214813], [83.470047, 25.26922989], [83.4719162, 25.26545906], [83.4704361, 25.26267815], [83.46325684, 25.25640869], [83.46028137, 25.25197029], [83.45729065, 25.25041008], [83.45355225, 25.25127983], [83.44294739, 25.25926018], [83.43979645, 25.25920105], [83.43321991, 25.25356102], [83.43115234, 25.25008011], [83.43136597, 25.24450111], [83.4287262, 25.24448967], [83.42251587, 25.25224113], [83.41934204, 25.25332069], [83.41854858, 25.25206947], [83.41934204, 25.24636078], [83.41706848, 25.24611092], [83.40927124, 25.24928093], [83.40690613, 25.2472496], [83.40416718, 25.24241066], [83.40233612, 25.23755074], [83.40151215, 25.23003006], [83.39727783, 25.22521019], [83.39597321, 25.22252083], [83.39505005, 25.21690941], [83.39113617, 25.21558952], [83.38990021, 25.21412086], [83.38999176, 25.2116394], [83.38822174, 25.20700836], [83.38535309, 25.20602989], [83.38173676, 25.21079826], [83.37957764, 25.21175003], [83.37770844, 25.20965958], [83.3745575, 25.20251083], [83.37210083, 25.20111084], [83.36662292, 25.20033073], [83.36026001, 25.1963501], [83.35597229, 25.1986618], [83.34960938, 25.19894028], [83.34739685, 25.19304085], [83.34394836, 25.18740273], [83.34121704, 25.18555069], [83.33586121, 25.18357086], [83.33535767, 25.18139267], [83.3380127, 25.17991066], [83.34224701, 25.17885971], [83.3481369, 25.17860031], [83.34673309, 25.16959953], [83.34509277, 25.16669083], [83.34320831, 25.15867043], [83.35080719, 25.15339088], [83.3524704, 25.15182114], [83.35343933, 25.14916039], [83.35399628, 25.14017105], [83.35212708, 25.13121986], [83.35762787, 25.12792015], [83.35736084, 25.12419128], [83.35375977, 25.11037254], [83.34783936, 25.11079979], [83.34288788, 25.11248016], [83.34012604, 25.11240005], [83.34031677, 25.09864998], [83.33802795, 25.08806038], [83.33669281, 25.08634949], [83.33351135, 25.08479118], [83.33222198, 25.0824604], [83.33120728, 25.07335281], [83.32778168, 25.06100082], [83.33123779, 25.05982971], [83.33360291, 25.05803108], [83.3338089, 25.05099106], [83.33210754, 25.05050087], [83.33016968, 25.05097961], [83.32711792, 25.0533905], [83.32624054, 25.0553894], [83.32495117, 25.05597115], [83.3219223, 25.05583], [83.32145691, 25.05243111], [83.32345581, 25.04805183], [83.31784058, 25.04165077], [83.3164978, 25.03838158], [83.31607056, 25.02733994], [83.31817627, 25.01732063], [83.31965637, 25.01554108], [83.32765198, 25.01632118], [83.33909607, 25.01189041], [83.34208679, 25.01146126], [83.34387207, 25.01048279], [83.34487915, 25.0026207], [83.34619904, 24.99596024], [83.34593201, 24.99209023], [83.34040833, 24.97921944], [83.34052277, 24.97481918], [83.33846283, 24.96355057], [83.34393311, 24.96388054], [83.34629822, 24.96294975], [83.34938049, 24.95952988], [83.35701752, 24.95535278], [83.35790253, 24.95162964], [83.35761261, 24.94598961], [83.35852051, 24.93740082], [83.35735321, 24.91924095], [83.35803223, 24.91399002], [83.35730743, 24.91140175], [83.35598755, 24.90983963], [83.35202789, 24.90784073], [83.35121155, 24.90623283], [83.35138702, 24.90306091], [83.36001587, 24.89184952], [83.35962677, 24.89018059], [83.35617828, 24.88921928], [83.35505676, 24.88747978], [83.35489655, 24.8855381], [83.35623169, 24.88430977], [83.36180115, 24.88233948], [83.36386871, 24.88043976], [83.36424255, 24.87858009], [83.36316681, 24.87697029], [83.3572464, 24.87352753], [83.35399628, 24.87061119], [83.35575104, 24.86865044], [83.36827087, 24.86318016], [83.37864685, 24.84613991], [83.38101959, 24.84445953], [83.38076019, 24.84303093], [83.38250732, 24.84025955], [83.38527679, 24.84007072], [83.38915253, 24.83607101], [83.39038849, 24.83308029], [83.38963318, 24.82715034], [83.39131165, 24.82315826], [83.39492798, 24.8202095], [83.39566803, 24.81559944], [83.39559937, 24.81099129], [83.39006042, 24.80442047], [83.38990021, 24.80185127], [83.39254761, 24.7971096], [83.3884964, 24.79154015], [83.38633728, 24.78659058], [83.38680267, 24.78421974], [83.39409637, 24.77947044], [83.40344238, 24.77667046], [83.41129303, 24.77532005], [83.41941833, 24.76987076], [83.42542267, 24.76311111], [83.43424225, 24.75684929], [83.44146729, 24.74403], [83.44467163, 24.74044991], [83.45308685, 24.73332024], [83.46243286, 24.73513031], [83.46695709, 24.73452759], [83.47174835, 24.73567009], [83.47532654, 24.73801994], [83.47984314, 24.73783112], [83.48245239, 24.73493958], [83.48332214, 24.73106956], [83.48327637, 24.72277069], [83.48036957, 24.71620941], [83.47997284, 24.70993805], [83.48071289, 24.70573235], [83.48335266, 24.70295906], [83.48589325, 24.70271111], [83.48960876, 24.70585823], [83.49205017, 24.70516014], [83.49498749, 24.70268059], [83.49571228, 24.6962204], [83.49990082, 24.69453049], [83.50917053, 24.6847496], [83.51264954, 24.68341064], [83.51370239, 24.68115044], [83.51319122, 24.67892075], [83.50218201, 24.67158127], [83.4994812, 24.66847992], [83.49704742, 24.65921974], [83.49752045, 24.65166092], [83.49971771, 24.64941025], [83.50251007, 24.64871025], [83.50717163, 24.64937019], [83.51590729, 24.64282036], [83.52169037, 24.64453125], [83.52394104, 24.64435005], [83.52419281, 24.64209938], [83.52068329, 24.6300106], [83.53890991, 24.62774277], [83.54141235, 24.62618065], [83.54171753, 24.6245594], [83.53843689, 24.62162971], [83.53453064, 24.61560059], [83.52555847, 24.61368942], [83.51743317, 24.60322952], [83.51721954, 24.59873009], [83.51999664, 24.59101105], [83.52350616, 24.58782005], [83.52498627, 24.58503914], [83.52514648, 24.58019829], [83.52400208, 24.57502174], [83.52458954, 24.5673008], [83.51793671, 24.55494118], [83.5171814, 24.54916954], [83.50495911, 24.54438972], [83.49341583, 24.54207039], [83.49320221, 24.53607941], [83.49761963, 24.52897072], [83.49816895, 24.52705956], [83.48671722, 24.52435112], [83.48139191, 24.52391052], [83.46186829, 24.51787758], [83.45308685, 24.51711082], [83.43563843, 24.5135994], [83.42636108, 24.51278114], [83.39997864, 24.50605965], [83.39546967, 24.50377083], [83.393013, 24.50119019], [83.39212799, 24.49711037], [83.39160156, 24.49283981], [83.39360809, 24.48891068], [83.39346313, 24.48476982], [83.39256287, 24.48027992], [83.38816833, 24.47326279], [83.38820648, 24.4681282], [83.38713074, 24.46457291], [83.3842392, 24.46140099], [83.38140869, 24.45565033], [83.38978577, 24.43758965], [83.39248657, 24.43642044], [83.40067291, 24.43713951], [83.3989563, 24.41208076], [83.40013885, 24.40867996], [83.41197205, 24.41025162], [83.41652679, 24.40947914], [83.4262085, 24.40604973], [83.42988586, 24.40378952], [83.43048859, 24.39600754], [83.43292999, 24.39404106], [83.43470764, 24.39063072], [83.43884277, 24.38899994], [83.43995667, 24.38698006], [83.4397583, 24.38013077], [83.44278717, 24.37764168], [83.44320679, 24.37278938], [83.44763947, 24.36844826], [83.45144653, 24.36700058], [83.45139313, 24.36474991], [83.44567108, 24.36327171], [83.44104767, 24.3608799], [83.43431091, 24.34747124], [83.43004608, 24.34495926], [83.42661285, 24.3399601], [83.42352295, 24.33870125], [83.41118622, 24.33955002], [83.40689087, 24.33899117], [83.40332794, 24.3373909], [83.3914032, 24.32677078], [83.38530731, 24.32034111], [83.37861633, 24.31552124], [83.37593842, 24.31454086], [83.37561035, 24.31344986], [83.38027191, 24.3047905], [83.38063812, 24.30046844], [83.38182831, 24.29988098], [83.38656616, 24.29756927], [83.39050293, 24.29652023], [83.39615631, 24.29339027], [83.4005127, 24.28524017], [83.40291595, 24.27613068], [83.40188599, 24.26600075], [83.39338684, 24.25266075], [83.39343262, 24.2471199], [83.39111328, 24.24464989], [83.38085938, 24.24002075], [83.37734222, 24.23566055], [83.37689972, 24.23093033], [83.37930298, 24.22019958], [83.37840271, 24.21685982], [83.37602997, 24.213871], [83.37621307, 24.21013069], [83.37822723, 24.2052803], [83.37834167, 24.20079041], [83.37049866, 24.18675041], [83.36936188, 24.18058968], [83.36560059, 24.17196083], [83.35735321, 24.15683937], [83.35607147, 24.14773941], [83.35250092, 24.14030075], [83.34992218, 24.13709259], [83.34900665, 24.12643814], [83.34355164, 24.11878967], [83.34279633, 24.11425018], [83.33904266, 24.11045074], [83.32356262, 24.1013298], [83.31894684, 24.10645103], [83.31491089, 24.10698128], [83.31352234, 24.10140038], [83.31344604, 24.09742928], [83.3110733, 24.09276009], [83.29242706, 24.07720947], [83.28900909, 24.07290077], [83.28417206, 24.06464958], [83.28040314, 24.05507088], [83.27748871, 24.04995918], [83.27680206, 24.04566956], [83.279953, 24.03476906], [83.27646637, 24.02730942], [83.27607727, 24.0232811], [83.2738266, 24.02115059], [83.27052307, 24.02026939], [83.26574707, 24.01725006], [83.26239777, 24.01366043], [83.25894928, 24.0116291], [83.25306702, 24.01213074], [83.24703217, 24.01519966], [83.24182129, 24.013731], [83.23697662, 24.00995827], [83.23535919, 24.00715065], [83.23692322, 24.00139046], [83.23352051, 23.99831009], [83.22677612, 23.99631119], [83.22252655, 23.99205971], [83.21602631, 23.98940277], [83.21476746, 23.9862709], [83.21562958, 23.98077965], [83.21057129, 23.97725105], [83.20835114, 23.9727993], [83.21063995, 23.96541023], [83.21121216, 23.96035767], [83.20587158, 23.95379066], [83.20323181, 23.94753265], [83.20176697, 23.94054031], [83.19135284, 23.93263054], [83.19313049, 23.92690086], [83.18956757, 23.92110062], [83.18312836, 23.91948128], [83.17756653, 23.91951942], [83.17260742, 23.91765976], [83.1678772, 23.91786957], [83.16433716, 23.91510963], [83.15785217, 23.91303062], [83.15557098, 23.91130829], [83.1452179, 23.90994263], [83.13878632, 23.90437126], [83.13526154, 23.8985405], [83.13437653, 23.89455032], [83.12741089, 23.89002037], [83.08660126, 23.87817192], [83.06104279, 23.87524033], [83.04345703, 23.87939072], [83.03643799, 23.88305092], [83.02546692, 23.88162994], [83.02052307, 23.88269806], [82.99227905, 23.87850952], [82.98396301, 23.87955284], [82.95359039, 23.87277031], [82.94950104, 23.87298965], [82.93881989, 23.87586975], [82.93308258, 23.87940025], [82.93058777, 23.88196945], [82.9251709, 23.89071083], [82.92251587, 23.89269066], [82.91747284, 23.895401], [82.90608215, 23.89789963], [82.89034271, 23.90456009], [82.88118744, 23.91028023], [82.87529755, 23.91641045], [82.86569214, 23.92266273], [82.86296082, 23.92552948], [82.85515594, 23.93877983], [82.84889984, 23.94683266], [82.84133911, 23.95014954], [82.82071686, 23.9649601], [82.8077774, 23.96305847], [82.80046844, 23.96748161], [82.79888153, 23.97089005], [82.79872131, 23.97661972], [82.80050659, 23.98533058], [82.80065155, 23.99655914], [82.8014679, 24.00106239], [82.79727173, 24.0051403], [82.78990173, 24.00677109], [82.78266907, 24.00695992], [82.76628876, 24.00605011], [82.75235748, 24.00843048], [82.74588776, 24.01311111], [82.74199677, 24.02140045], [82.73992157, 24.03104973], [82.74314117, 24.03487968], [82.75576782, 24.04359818], [82.76220703, 24.05988121], [82.76625824, 24.07786751], [82.76055145, 24.07967949], [82.75492096, 24.07324028], [82.75174713, 24.07959747], [82.74803925, 24.08053017], [82.74146271, 24.07509041], [82.73768616, 24.07872963], [82.72628021, 24.08256912], [82.70839691, 24.08076096], [82.70522308, 24.0857296], [82.70136261, 24.09707069], [82.66352844, 24.12392998], [82.65738678, 24.13479805], [82.66587067, 24.14278984], [82.66519928, 24.15112114], [82.67085266, 24.15847015], [82.6794281, 24.15673065], [82.68836212, 24.14422989], [82.72036743, 24.1389904], [82.72132111, 24.1498127], [82.72307587, 24.15681076], [82.73613739, 24.16835022], [82.73478699, 24.1830101], [82.73190308, 24.20107269], [82.72699738, 24.22326088], [82.73223114, 24.22797012], [82.73706055, 24.23031044], [82.74331665, 24.23161125], [82.74991608, 24.23612976], [82.75157166, 24.24586105], [82.74938965, 24.25662041], [82.75058746, 24.26813126], [82.75460815, 24.2716198], [82.75705719, 24.27569962], [82.76413727, 24.29243088], [82.76603699, 24.31220818], [82.75981903, 24.31908035], [82.76045227, 24.32310104], [82.76299286, 24.32982826], [82.76326752, 24.34243011], [82.76449585, 24.34754944], [82.75981903, 24.35838127], [82.75892639, 24.36314964], [82.75875854, 24.36931038], [82.76058197, 24.37304115], [82.75688934, 24.37594032], [82.7544632, 24.37951088], [82.74677277, 24.37252045], [82.73478699, 24.37117958], [82.71849823, 24.37122154], [82.71286011, 24.37520981], [82.70716095, 24.38517952], [82.70758057, 24.38937759], [82.71496582, 24.41617012], [82.71936798, 24.42163086], [82.72019196, 24.42967987], [82.72572327, 24.42625809], [82.73271179, 24.43274117], [82.72730255, 24.43414116], [82.72503662, 24.44473267], [82.72602081, 24.46084023], [82.73060608, 24.47033119], [82.72377014, 24.4763298], [82.73377991, 24.48723984], [82.73654938, 24.49977112], [82.71563721, 24.51329994], [82.71414948, 24.53619957], [82.7150116, 24.54811096], [82.71253204, 24.5562191], [82.71611023, 24.55714035], [82.73352814, 24.55162048], [82.74120331, 24.55459023], [82.74536133, 24.55251122], [82.74601746, 24.54152107], [82.78093719, 24.54606819], [82.80076599, 24.55268097], [82.79644012, 24.58749962], [82.79637146, 24.59976006], [82.78542328, 24.59951019], [82.76825714, 24.59754181], [82.76007843, 24.59981918], [82.7629776, 24.60481071], [82.76789093, 24.61061287], [82.76716614, 24.62943077], [82.76580048, 24.64163017], [82.76278687, 24.64566994], [82.74312592, 24.64406967], [82.72746277, 24.64647293], [82.71460724, 24.6421299], [82.70921326, 24.64371109], [82.70207214, 24.64211273], [82.6951828, 24.64425278], [82.69169617, 24.64863968], [82.69345856, 24.66157913], [82.69586945, 24.66871262], [82.69595337, 24.67572021], [82.69230652, 24.68022919], [82.68543243, 24.68652153], [82.66555023, 24.69986153], [82.65792847, 24.70039749], [82.64569855, 24.69454956], [82.63643646, 24.68783951], [82.62996674, 24.68670082], [82.60299683, 24.67945099], [82.58764648, 24.67373085], [82.57396698, 24.66300011], [82.54425812, 24.65487862], [82.52926636, 24.65196037], [82.52398682, 24.65714073], [82.51843262, 24.67834091], [82.50905609, 24.6790905], [82.501297, 24.67840958], [82.486763, 24.67550087], [82.47667694, 24.6835804], [82.4640274, 24.68007088], [82.44885254, 24.67790031], [82.44480896, 24.68008995], [82.44838715, 24.69062042], [82.44484711, 24.69637108], [82.43231201, 24.70628166], [82.42015076, 24.70525169], [82.40738678, 24.69514084], [82.40159607, 24.68379974], [82.40679932, 24.6744194], [82.4054718, 24.66682053], [82.41178894, 24.65784836], [82.40896606, 24.64956093], [82.40904999, 24.64306068], [82.40352631, 24.6361618], [82.40364838, 24.63097954], [82.40789032, 24.62281036], [82.40567017, 24.61751175], [82.41456604, 24.60639191], [82.40917206, 24.59782982], [82.40081787, 24.59869957], [82.39359283, 24.59749985], [82.38564301, 24.59737968], [82.36084747, 24.60200119], [82.35391998, 24.60447121], [82.35051727, 24.60820961], [82.34596252, 24.61880112], [82.33506012, 24.6229496], [82.32977295, 24.62375069], [82.32373047, 24.62254906], [82.31915283, 24.6202507], [82.31530762, 24.61535072], [82.30940247, 24.61293983], [82.29833984, 24.61242104], [82.29393005, 24.61374092], [82.29302979, 24.61689949], [82.29841614, 24.6280117], [82.29579926, 24.63624191], [82.29611206, 24.64332008], [82.29469299, 24.65385246], [82.29808807, 24.65654945], [82.29189301, 24.66477966], [82.29641724, 24.67001152], [82.29107666, 24.67086983], [82.28520966, 24.67001152], [82.28173828, 24.67174149], [82.27851105, 24.68087959], [82.2694931, 24.68186951], [82.2633667, 24.6864109], [82.25834656, 24.68209076], [82.26674652, 24.67840958], [82.25305176, 24.66609192], [82.24952698, 24.66833115], [82.24797821, 24.67556953], [82.23551941, 24.67638969], [82.23420715, 24.67193985], [82.23509979, 24.66591072], [82.22992706, 24.66963959], [82.22885132, 24.67459106], [82.2286911, 24.69075966], [82.23400116, 24.69656944], [82.24304962, 24.70176125], [82.24046326, 24.71055984], [82.24394989, 24.71638107], [82.24101257, 24.7269001], [82.24143982, 24.73846054], [82.24590302, 24.74065971], [82.24962616, 24.75636864], [82.24659729, 24.75976181], [82.24365997, 24.77575111], [82.24031067, 24.77547073], [82.24108887, 24.76827049], [82.2383728, 24.75440979], [82.2323761, 24.75814819], [82.22773743, 24.76556015], [82.22338867, 24.76417923], [82.22091675, 24.76704979], [82.21853638, 24.76498032], [82.22157288, 24.75991058], [82.22280884, 24.7517395], [82.20918274, 24.75951004], [82.19948578, 24.75206947], [82.2022171, 24.74817085], [82.21340179, 24.74420929], [82.21604919, 24.73615074], [82.21375275, 24.72866058], [82.20841217, 24.7389698], [82.2026062, 24.74078941], [82.19512939, 24.73994064], [82.18873596, 24.74377823], [82.17288208, 24.73957062], [82.1914978, 24.75316048], [82.19567108, 24.76374817], [82.19061279, 24.76955986], [82.19129181, 24.77486038], [82.18936157, 24.78228188], [82.19403839, 24.78326035], [82.20179749, 24.7806797], [82.20947266, 24.78149033], [82.20493317, 24.78550911], [82.20545959, 24.79144096], [82.20871735, 24.79776955], [82.20136261, 24.80065155], [82.19491577, 24.79694939], [82.18855286, 24.79821968], [82.1812973, 24.80084991], [82.17900848, 24.80465126], [82.18090057, 24.80821991], [82.19126892, 24.81772041], [82.19596863, 24.82452965], [82.18791962, 24.82071114], [82.18244171, 24.81678963], [82.17373657, 24.81418991], [82.17176056, 24.8088398], [82.16281128, 24.80498123], [82.17336273, 24.80096054], [82.16323853, 24.79577065], [82.15939331, 24.79226112], [82.14657593, 24.79730988], [82.13224792, 24.8044796], [82.12892151, 24.79976273], [82.12637329, 24.79394913], [82.11219025, 24.79226112], [82.10778809, 24.79368019], [82.10769653, 24.8008194], [82.10475922, 24.80560112], [82.1000061, 24.80994987], [82.0946579, 24.81036949], [82.08972931, 24.8159008], [82.08187103, 24.82211113], [82.07084656, 24.82493973], [82.06520081, 24.82344055], [82.05648804, 24.82807922], [82.04232788, 24.83424187], [82.03720093, 24.83296013], [82.02427673, 24.8446312], [82.00489044, 24.85069084], [81.99793243, 24.84744072], [81.99154663, 24.8465004], [81.97544861, 24.84246063], [81.96806335, 24.84386063], [81.96498108, 24.84142113], [81.96156311, 24.83172989], [81.95915222, 24.83061028], [81.95717621, 24.83213043], [81.95488739, 24.83924103], [81.94772339, 24.84259033], [81.94615173, 24.84671021], [81.93718719, 24.85005951], [81.93466949, 24.85144997], [81.93177032, 24.85649109], [81.92672729, 24.86079025], [81.92838287, 24.87306023], [81.92366791, 24.87627029], [81.91513062, 24.87779045], [81.91339111, 24.88041115], [81.91010284, 24.88043976], [81.90628815, 24.88354111], [81.90265656, 24.88413048], [81.89644623, 24.89250946], [81.89879608, 24.8993206], [81.89846039, 24.90518188], [81.90242004, 24.91150093], [81.91030884, 24.9204998], [81.91204071, 24.93091965], [81.90962219, 24.93714905], [81.90410614, 24.94226837], [81.90096283, 24.97305107], [81.89834595, 24.97532082], [81.89845276, 24.97686958], [81.90164185, 24.98282051], [81.90052032, 24.98483086], [81.89450073, 24.98740005], [81.89483643, 24.99109077], [81.89922333, 24.99924088], [81.89994812, 25.00344086], [81.89997101, 25.0072403], [81.89846802, 25.00962067], [81.89142609, 25.0134697], [81.889328, 25.01311111], [81.88822937, 25.01098061], [81.88861084, 25.00954819], [81.89160919, 25.00505066], [81.89402008, 25.00345993], [81.89309692, 24.99982071], [81.89058685, 24.99636841], [81.88772583, 24.99340057], [81.88613129, 24.99282074], [81.88331604, 24.99365044], [81.8813858, 24.99949265], [81.8735199, 25.00214005], [81.86837006, 25.00222969], [81.86683655, 25.00015068], [81.86454773, 25.00039291], [81.86371613, 25.00357056], [81.84938049, 25.00601006], [81.84629822, 25.00712013], [81.84002686, 25.01497269], [81.8349762, 25.01828194], [81.82936859, 25.01933289], [81.79165649, 25.01000977], [81.78922272, 25.01013947], [81.78011322, 25.01519012], [81.77871704, 25.01762009], [81.77139282, 25.02323914], [81.74977112, 25.03162193], [81.74740601, 25.03362274], [81.74646759, 25.0357399], [81.74150085, 25.03697014], [81.73821259, 25.03907013], [81.73723602, 25.04194069], [81.73446655, 25.0431385], [81.7350769, 25.04452133], [81.73239136, 25.04870987], [81.71640778, 25.05297279], [81.71382141, 25.04725075], [81.71338654, 25.04006004], [81.71012115, 25.03912926], [81.70536041, 25.03790283], [81.68553925, 25.04218292], [81.6818924, 25.04377174], [81.68371582, 25.05079079], [81.68306732, 25.0567627], [81.67780304, 25.06467819], [81.67582703, 25.06598091], [81.67137909, 25.06624985], [81.66398621, 25.06394958], [81.66221619, 25.06513977], [81.66040802, 25.07146072], [81.65989685, 25.07818031], [81.65869141, 25.07973099], [81.65650177, 25.07862091], [81.65307617, 25.07503128], [81.64684296, 25.07504082], [81.64598083, 25.07055092], [81.64418793, 25.06835937], [81.63559723, 25.06179047], [81.63201141, 25.06147957], [81.62525177, 25.06245995], [81.62190247, 25.05692101], [81.61725616, 25.05712128], [81.60852051, 25.05887985], [81.60434723, 25.06074905], [81.60272217, 25.06304169], [81.6032486, 25.06435966], [81.60558319, 25.0645504], [81.60855103, 25.06331062], [81.60971069, 25.06469917], [81.60811615, 25.06682014], [81.6039505, 25.06954193], [81.60280609, 25.07183075], [81.59446716, 25.07693291], [81.59379578, 25.07979965], [81.59591675, 25.08182907], [81.60443878, 25.08299065], [81.60949707, 25.08515167], [81.61486816, 25.09404755], [81.62088776, 25.09507942], [81.62153625, 25.09836006], [81.62583923, 25.09988976], [81.62930298, 25.09972954], [81.63166046, 25.10148048], [81.63195038, 25.10326958], [81.62265015, 25.11124039], [81.62534332, 25.1178112], [81.62506104, 25.12044907], [81.62329102, 25.12193108], [81.61675262, 25.12261963], [81.61483002, 25.1198597], [81.61302948, 25.11322975], [81.6100769, 25.11170959], [81.60639191, 25.10594177], [81.60426331, 25.09966278], [81.60122681, 25.10021019], [81.60280609, 25.11244965], [81.60180664, 25.1160183], [81.60230255, 25.11750984], [81.59102631, 25.12298965], [81.59146881, 25.12735939], [81.59414673, 25.12951279], [81.59211731, 25.13638115], [81.59417725, 25.13801193], [81.59918213, 25.13982964], [81.60430145, 25.14281082], [81.61001587, 25.14717102], [81.61223602, 25.14660072], [81.61506653, 25.14393044], [81.61763763, 25.14624977], [81.618927, 25.14908981], [81.61965942, 25.15563965], [81.61898804, 25.1596508], [81.61737061, 25.16389847], [81.61441803, 25.16506958], [81.61347198, 25.17052078], [81.61000061, 25.17365265], [81.60810852, 25.17276955], [81.60675812, 25.17057037], [81.60703278, 25.16805077], [81.60549164, 25.16562843], [81.6029129, 25.16588974], [81.60114288, 25.16736984], [81.599823, 25.16603088], [81.59657288, 25.16553116], [81.58177948, 25.16827011], [81.58194733, 25.17033005], [81.58799744, 25.1837883], [81.58560944, 25.18662071], [81.57718658, 25.19129944], [81.5716629, 25.1929512], [81.56639862, 25.19574928], [81.55844116, 25.18919182], [81.54902649, 25.18658066], [81.54876709, 25.18865013], [81.53991699, 25.18765831], [81.53401184, 25.18826103], [81.53333282, 25.18756104], [81.53253937, 25.18542099], [81.52321625, 25.1857605], [81.52007294, 25.1872406], [81.5128479, 25.18790054], [81.50956726, 25.18703079], [81.50778961, 25.18497086], [81.50711823, 25.17854118], [81.5078125, 25.17625046], [81.51074219, 25.17368126], [81.52728271, 25.16662025], [81.53000641, 25.16333961], [81.52884674, 25.16133118], [81.5199585, 25.15365982], [81.51873779, 25.15183067], [81.525177, 25.14753151], [81.52465057, 25.14364052], [81.51846313, 25.14254761], [81.51566315, 25.14533997], [81.51091003, 25.14840126], [81.50496674, 25.15122032], [81.50063324, 25.1528492], [81.4954071, 25.15234947], [81.49199677, 25.14875984], [81.48995972, 25.14191818], [81.49054718, 25.13504028], [81.48960876, 25.13422012], [81.48452759, 25.13434982], [81.4801712, 25.13770103], [81.47743225, 25.13842964], [81.4746933, 25.13812065], [81.4728775, 25.1371212], [81.47175598, 25.13499069], [81.4720459, 25.13303947], [81.47812653, 25.12792015], [81.47772217, 25.12108994], [81.48171997, 25.11732101], [81.48562622, 25.11586952], [81.49314117, 25.11065292], [81.50319672, 25.11051941], [81.50757599, 25.10680962], [81.50701904, 25.10532188], [81.50286865, 25.10172081], [81.50054932, 25.10083008], [81.4942627, 25.10169983], [81.49740601, 25.09604073], [81.49462128, 25.08210945], [81.49224091, 25.08192062], [81.4864502, 25.08410072], [81.4851532, 25.0775795], [81.4837265, 25.07493973], [81.48118591, 25.07590294], [81.47740173, 25.07925034], [81.47305298, 25.08093071], [81.46539307, 25.08184052], [81.45829773, 25.08677101], [81.45781708, 25.08934975], [81.4588623, 25.09299088], [81.436409, 25.09616089], [81.42479706, 25.09943962], [81.42082977, 25.1015892], [81.41314697, 25.10399055], [81.40306854, 25.10640907], [81.40084839, 25.10777092], [81.400383, 25.10914993], [81.40300751, 25.1115799], [81.40689087, 25.11201859], [81.41147614, 25.11230087], [81.42717743, 25.1106205], [81.43546295, 25.11103821], [81.43833923, 25.11044121], [81.43910217, 25.11198997], [81.43856812, 25.11400032], [81.43437195, 25.12194061], [81.42913818, 25.12953949], [81.43022156, 25.13363075], [81.42778015, 25.13360977], [81.41970062, 25.13560295], [81.41783905, 25.13517189], [81.41604614, 25.13228035], [81.41326904, 25.13169098], [81.40020752, 25.13380051], [81.40181732, 25.13082123], [81.40667725, 25.1251297], [81.40624237, 25.12339973], [81.40431976, 25.12216759], [81.4005661, 25.1217308], [81.39753723, 25.12170029], [81.39122009, 25.1231308], [81.38903046, 25.12426186], [81.38722992, 25.12895012], [81.38500214, 25.1301403], [81.38652039, 25.13393021], [81.3843689, 25.13508034], [81.37898254, 25.13445091], [81.37428284, 25.13877106], [81.36688232, 25.13743973], [81.36450958, 25.13785934], [81.36453247, 25.13929749], [81.36643982, 25.14172935], [81.36560822, 25.14425087], [81.36251068, 25.14571953], [81.35720825, 25.15232086], [81.35549927, 25.15764999], [81.3533783, 25.16147995], [81.35089874, 25.16391945], [81.34941101, 25.16735077], [81.34459686, 25.16547012], [81.33603668, 25.16634941], [81.33103943, 25.16955757], [81.32995605, 25.17249107], [81.31964111, 25.1680603], [81.31297302, 25.16354752], [81.31073761, 25.15263939], [81.31096649, 25.14896011], [81.31225586, 25.14621925], [81.31680298, 25.14066124], [81.31598663, 25.1350708], [81.31678009, 25.12808037], [81.32026672, 25.1224308], [81.32221222, 25.12072945], [81.32301331, 25.11839294], [81.31852722, 25.11869049], [81.31830597, 25.11684036], [81.31700897, 25.1160183], [81.31466675, 25.11629105], [81.31302643, 25.11741066], [81.31195068, 25.12343025], [81.31005096, 25.12402916], [81.30838776, 25.12583923], [81.30880737, 25.13158989], [81.30696869, 25.13339043], [81.30657959, 25.13517189], [81.30802155, 25.1388607], [81.30490112, 25.14307022], [81.30429077, 25.14529037], [81.30699921, 25.15966988], [81.30638885, 25.16599274], [81.30487061, 25.16745949], [81.29254913, 25.16798019], [81.29133606, 25.16679764], [81.28468323, 25.16530991], [81.28147888, 25.1654892], [81.27522278, 25.16899109], [81.27143097, 25.16893959], [81.26911926, 25.16773987], [81.26864624, 25.16518974], [81.27390289, 25.15836906], [81.27477264, 25.15341949], [81.27059174, 25.14843941], [81.26558685, 25.14487076], [81.26146698, 25.14434814], [81.26122284, 25.1439209], [81.25974274, 25.14118195], [81.262146, 25.13108063], [81.25683594, 25.12862968], [81.25817871, 25.12363243], [81.25795746, 25.1168499], [81.25617981, 25.11454964], [81.24812317, 25.1117382], [81.24569702, 25.10554123], [81.24648285, 25.10326958], [81.24878693, 25.10071945], [81.25206757, 25.09857941], [81.25443268, 25.09270096], [81.25911713, 25.08730125], [81.25302887, 25.07904816], [81.25997925, 25.07562256], [81.26222229, 25.0728302], [81.26158905, 25.06846046], [81.25527191, 25.06082916], [81.25602722, 25.05571938], [81.25338745, 25.05443001], [81.25229645, 25.05257988], [81.24756622, 25.04149246], [81.2425766, 25.03630066], [81.23921204, 25.03136063], [81.23600769, 25.02930069], [81.23069, 25.0180912], [81.22309875, 25.01132965], [81.22023773, 25.0072403], [81.21656799, 25.00444984], [81.2113266, 25.00169182], [81.21070099, 25.00165939], [81.21016693, 25.00181961], [81.20974731, 25.0021801], [81.20900726, 25.00291824], [81.20854187, 25.00312042], [81.20735931, 25.0035305], [81.20641327, 25.00374031], [81.20581055, 25.00342941], [81.20511627, 25.00311089], [81.20482635, 25.00280952], [81.20381927, 24.99755287], [81.2016983, 24.99572945], [81.20733643, 24.9912796], [81.21129608, 24.98680115], [81.21273041, 24.98166275], [81.21230316, 24.97774124], [81.20127869, 24.97026253], [81.20001221, 24.96685028], [81.20407867, 24.96284103], [81.20600891, 24.95808983], [81.20639038, 24.95408058], [81.20437622, 24.95047951], [81.20600128, 24.9392395], [81.20749664, 24.93725014], [81.21148682, 24.93622971], [81.21260834, 24.93452072], [81.21098328, 24.93259048], [81.20729828, 24.93110275], [81.20249939, 24.92780113], [81.19948578, 24.92694092], [81.19579315, 24.92900848], [81.18441772, 24.9292202], [81.19303894, 24.93461037], [81.19828033, 24.93404961], [81.19895935, 24.93473816], [81.1884079, 24.94505119], [81.18062592, 24.94945908], [81.17658997, 24.95496941], [81.17212677, 24.95350075], [81.16967773, 24.95675087], [81.16419983, 24.95976257], [81.16143036, 24.95851135], [81.15956116, 24.95473289], [81.1568985, 24.94571114], [81.15779877, 24.94267082], [81.15602112, 24.93982124], [81.15548706, 24.9319706], [81.15233612, 24.92937279], [81.15116119, 24.92720985], [81.15090179, 24.92374039], [81.15249634, 24.91962242], [81.15231323, 24.91628075], [81.14813995, 24.91768074], [81.14272308, 24.91736984], [81.14008331, 24.91643906], [81.13331604, 24.90557098], [81.13289642, 24.90050125], [81.1342392, 24.89384079], [81.13244629, 24.89207077], [81.1281662, 24.89361954], [81.12265015, 24.89870071], [81.11678314, 24.90182114], [81.11292267, 24.90552139], [81.11073303, 24.91068077], [81.10748291, 24.91214752], [81.10381317, 24.91270065], [81.09871674, 24.91843033], [81.09654236, 24.92253113], [81.09449768, 24.92378044], [81.08950043, 24.92448044], [81.08487701, 24.93435287], [81.08156586, 24.93575096], [81.08049774, 24.9383812], [81.08246613, 24.94769096], [81.08120728, 24.95021057], [81.07641602, 24.95226097], [81.05741882, 24.95311928], [81.0508194, 24.95527267], [81.04715729, 24.9552002], [81.04312134, 24.95263863], [81.02667236, 24.95496941], [81.02320099, 24.95235062], [81.01991272, 24.95198059], [81.02139282, 24.94839096], [81.0207901, 24.94607925], [81.01924896, 24.94499969], [81.01698303, 24.94643974], [81.00952911, 24.95432091], [81.00715637, 24.95262909], [81.01258087, 24.94371986], [81.01531219, 24.94005966], [81.02114105, 24.93825912], [81.02128601, 24.93712044], [81.01799011, 24.93554115], [81.01677704, 24.93246078], [81.01467133, 24.93160057], [81.0118866, 24.9332428], [81.0087204, 24.93246078], [81.00002289, 24.94021034], [80.99672699, 24.93959045], [80.99124146, 24.93712044], [80.98448944, 24.93258095], [80.98101044, 24.9296608], [80.97792816, 24.93315125], [80.97928619, 24.93807983], [80.97225952, 24.9396019], [80.96566772, 24.93861961], [80.95838928, 24.93224907], [80.95523071, 24.92571068], [80.95111084, 24.92702293], [80.95287323, 24.93943977], [80.9522171, 24.94288063], [80.9498291, 24.94638062], [80.94481659, 24.94713974], [80.94386292, 24.95070076], [80.94668579, 24.95691109], [80.9467392, 24.96114159], [80.94484711, 24.96800995], [80.94249725, 24.97113991], [80.93682098, 24.97249985], [80.93374634, 24.97010994], [80.9284668, 24.96769905], [80.92162323, 24.96657944], [80.91596222, 24.96479034], [80.91152191, 24.96228027], [80.89730072, 24.95672035], [80.89431763, 24.95389938], [80.89331818, 24.95046043], [80.90119934, 24.94334984], [80.90278625, 24.94016075], [80.9000473, 24.93958092], [80.89795685, 24.94169044], [80.8948288, 24.94244003], [80.88870239, 24.9474411], [80.88482666, 24.94889069], [80.88123322, 24.94820023], [80.87684631, 24.94506073], [80.87500763, 24.94071007], [80.85661316, 24.93595123], [80.84091949, 24.93556023], [80.83490753, 24.93452835], [80.82901001, 24.93844986], [80.82081604, 24.93659019], [80.81542969, 24.93790817], [80.80220032, 24.94445992], [80.80290985, 24.9569397], [80.79164124, 24.96391106], [80.78994751, 24.96718025], [80.78999329, 24.97178268], [80.79360962, 24.97365189], [80.79879761, 24.97489166], [80.8065033, 24.97500992], [80.81257629, 24.97367096], [80.81864166, 24.97363091], [80.82109833, 24.98250008], [80.82470703, 24.9860611], [80.83640289, 24.98608971], [80.845047, 24.99349976], [80.84818268, 24.99814034], [80.85025024, 25.0031414], [80.84192657, 25.0125103], [80.84005737, 25.02021027], [80.82911682, 25.02997971], [80.82668304, 25.03919029], [80.83522034, 25.03968048], [80.84113312, 25.05127907], [80.84687042, 25.05327988], [80.8557663, 25.06244087], [80.87065125, 25.07105064], [80.87507629, 25.07953835], [80.86480713, 25.08434105], [80.86425018, 25.08815956], [80.86730957, 25.09402084], [80.87121582, 25.09824944], [80.87298584, 25.10256958], [80.87224579, 25.10930061], [80.86650848, 25.11943054], [80.8649826, 25.1236496], [80.86585236, 25.12552071], [80.8690033, 25.12791061], [80.87275696, 25.13389015], [80.87541962, 25.14443016], [80.88526917, 25.14001274], [80.8884201, 25.14123917], [80.89029694, 25.14635086], [80.90157318, 25.15797997], [80.90492249, 25.16031075], [80.90556335, 25.16448021], [80.89597321, 25.17126083], [80.88902283, 25.17469025], [80.8861618, 25.17717171], [80.8780365, 25.19560051], [80.86953735, 25.18865967], [80.86416626, 25.18786049], [80.86315155, 25.18921089], [80.86036682, 25.1905899], [80.84858704, 25.19003105], [80.84108734, 25.19347954], [80.83628082, 25.19268036], [80.83515167, 25.19046974], [80.83589172, 25.18540955], [80.84111023, 25.17525291], [80.84230042, 25.1711998], [80.84188843, 25.16794014], [80.83744049, 25.16031075], [80.83384705, 25.14561272], [80.83209991, 25.14141083], [80.83479309, 25.13252068], [80.8377533, 25.12751007], [80.83344269, 25.11327171], [80.82769775, 25.1103096], [80.82393646, 25.11465263], [80.82315826, 25.11777115], [80.82151794, 25.1200428], [80.82168579, 25.12285042], [80.82139587, 25.12560081], [80.81864166, 25.13055038], [80.80961609, 25.13070107], [80.80771637, 25.13310051], [80.80828094, 25.14081955], [80.8032074, 25.1435318], [80.79957581, 25.14641762], [80.79786682, 25.14624023], [80.79367065, 25.14232063], [80.7906723, 25.14273071], [80.78613281, 25.13796043], [80.78369904, 25.13836288], [80.78214264, 25.13708115], [80.7766571, 25.14484024], [80.77403259, 25.1466198], [80.76605988, 25.14088821], [80.75956726, 25.14059067], [80.75086212, 25.14170074], [80.74043274, 25.13741112], [80.73809814, 25.13459969], [80.73545837, 25.13521957], [80.73206329, 25.14052963], [80.73227692, 25.14236259], [80.72865295, 25.14289856], [80.7277298, 25.14740181], [80.72305298, 25.14878273], [80.71763611, 25.14660072], [80.71530914, 25.14665985], [80.71478271, 25.14328003], [80.71061707, 25.13844109], [80.70092773, 25.1380806], [80.69963837, 25.13714981], [80.69847107, 25.13137245], [80.7008667, 25.12803841], [80.70746613, 25.12743187], [80.71730042, 25.1289196], [80.72244263, 25.12599182], [80.72537231, 25.12288284], [80.7199173, 25.11725807], [80.7190094, 25.10402107], [80.72049713, 25.10139275], [80.72524261, 25.09795952], [80.72931671, 25.09729767], [80.73343658, 25.1013298], [80.74577332, 25.09939957], [80.74931335, 25.09777069], [80.75205231, 25.09540939], [80.75100708, 25.09428978], [80.75112152, 25.09111977], [80.76703644, 25.08559036], [80.77597809, 25.08430099], [80.77961731, 25.07786942], [80.7813797, 25.069561], [80.77825928, 25.06386948], [80.77593994, 25.06169128], [80.76595306, 25.06114006], [80.75566864, 25.06257057], [80.7514267, 25.06399918], [80.74410248, 25.06233025], [80.7335968, 25.06244087], [80.72921753, 25.06553268], [80.72720337, 25.07182121], [80.7144165, 25.06775284], [80.71096039, 25.06726265], [80.70948792, 25.06632042], [80.70831299, 25.06492996], [80.70533752, 25.06142044], [80.69801331, 25.06155014], [80.68688965, 25.05879021], [80.67829895, 25.05457115], [80.67356873, 25.05417061], [80.67465973, 25.06019974], [80.67507935, 25.06253052], [80.67192078, 25.06456947], [80.67180634, 25.06732941], [80.67421722, 25.0680809], [80.67788696, 25.07310104], [80.67896271, 25.07578087], [80.67926025, 25.08181953], [80.66828918, 25.08675194], [80.66670227, 25.08426285], [80.66610718, 25.08053017], [80.66580963, 25.08019066], [80.66422272, 25.07839012], [80.65629578, 25.07444191], [80.65373993, 25.07645988], [80.65052795, 25.08753014], [80.64554596, 25.0906105], [80.6414566, 25.09314919], [80.63645172, 25.09395981], [80.63574982, 25.09605026], [80.63523865, 25.09756088], [80.63434601, 25.09717941], [80.63391876, 25.09379959], [80.62861633, 25.09328842], [80.62516785, 25.09555817], [80.62354279, 25.09519958], [80.62195587, 25.09338951], [80.62230682, 25.08929062], [80.62004089, 25.08958054], [80.617836, 25.09366035], [80.6084671, 25.09860039], [80.60655212, 25.10157967], [80.60135651, 25.10440826], [80.60682678, 25.1065197], [80.61329651, 25.10654068], [80.61506653, 25.11120987], [80.61476898, 25.11386108], [80.61823273, 25.11580086], [80.61875153, 25.11808014], [80.61923218, 25.12021065], [80.62229919, 25.12202072], [80.63123322, 25.11980057], [80.63239288, 25.12328148], [80.62802124, 25.13029099], [80.62496185, 25.13767052], [80.62245178, 25.13606071], [80.6159668, 25.13812065], [80.6083374, 25.13294983], [80.60547638, 25.13635063], [80.6056366, 25.14278984], [80.60578918, 25.14928055], [80.60269928, 25.1523819], [80.59960938, 25.15546989], [80.59458923, 25.15524101], [80.59105682, 25.14129066], [80.59011078, 25.13482094], [80.59075928, 25.13158035], [80.59757233, 25.1281395], [80.60037994, 25.1253109], [80.60144806, 25.12281036], [80.59642029, 25.12202072], [80.59137726, 25.11799049], [80.58777618, 25.10910034], [80.59188843, 25.09600258], [80.59333801, 25.09420967], [80.59435272, 25.09295082], [80.60002136, 25.09075165], [80.60675812, 25.07620049], [80.60730743, 25.07308006], [80.60710144, 25.07273293], [80.60678101, 25.07217979], [80.60452271, 25.07262993], [80.59594727, 25.07818031], [80.5932312, 25.08152962], [80.58872223, 25.08434105], [80.58757782, 25.08587074], [80.58011627, 25.08695984], [80.57866669, 25.08826256], [80.57263947, 25.08580017], [80.56804657, 25.08528137], [80.56562805, 25.08718109], [80.56243896, 25.0914402], [80.56109619, 25.08876991], [80.56117249, 25.07928276], [80.55999756, 25.07498932], [80.55766296, 25.07292175], [80.55536652, 25.07089806], [80.55245209, 25.06928062], [80.54862213, 25.06931114], [80.54676819, 25.06797028], [80.54341888, 25.06766129], [80.53882599, 25.06965828], [80.53203583, 25.07591057], [80.52812958, 25.07705116], [80.51899719, 25.08193016], [80.51731873, 25.08479118], [80.51515961, 25.08846092], [80.51425934, 25.09577751], [80.51288605, 25.0982399], [80.50950623, 25.10102081], [80.50190735, 25.10413933], [80.49471283, 25.10494041], [80.49212646, 25.10223007], [80.48391724, 25.10281944], [80.48030853, 25.10157967], [80.47612762, 25.10225105], [80.47447968, 25.10182953], [80.47471619, 25.09906006], [80.47759247, 25.09641266], [80.48729706, 25.09180069], [80.49433136, 25.09205055], [80.49777222, 25.09139061], [80.49997711, 25.08955956], [80.49842834, 25.08257103], [80.49453735, 25.07956123], [80.49059296, 25.07821083], [80.50007629, 25.07097054], [80.5021286, 25.06735039], [80.50231934, 25.06286049], [80.50019836, 25.05877113], [80.49724579, 25.0560112], [80.49317169, 25.05431938], [80.49420929, 25.04532051], [80.48583221, 25.04730988], [80.48314667, 25.04725075], [80.47901154, 25.04434967], [80.47693634, 25.04388809], [80.47331238, 25.04358292], [80.4701767, 25.04469109], [80.46142578, 25.05798912], [80.45996857, 25.06970024], [80.45593262, 25.07382011], [80.45297241, 25.06878281], [80.445961, 25.06583023], [80.44420624, 25.06817055], [80.44464111, 25.07081032], [80.44225311, 25.07328033], [80.44164276, 25.07600021], [80.44342041, 25.07733917], [80.44513702, 25.08017159], [80.44428253, 25.0812912], [80.4417572, 25.08101273], [80.44071198, 25.0820694], [80.43509674, 25.0809803], [80.43292236, 25.07839012], [80.4311676, 25.07394028], [80.42951202, 25.07254028], [80.42450714, 25.07150078], [80.42272949, 25.07131958], [80.40991974, 25.07671928], [80.40677643, 25.06344986], [80.40525055, 25.06085014], [80.40268707, 25.06095123], [80.39746857, 25.06562042], [80.39807892, 25.06928062], [80.39412689, 25.07202148], [80.38944244, 25.0682106], [80.38640594, 25.0673008], [80.38414764, 25.06534004], [80.38347626, 25.0616703], [80.3792572, 25.05595016], [80.36724854, 25.05886078], [80.3657608, 25.05776024], [80.36627197, 25.05307961], [80.36406708, 25.04771996], [80.36750793, 25.04609108], [80.37520599, 25.0456295], [80.37906647, 25.04440117], [80.38020325, 25.04160118], [80.38043213, 25.03890038], [80.37831116, 25.03680992], [80.3747406, 25.03660011], [80.37287903, 25.03470039], [80.37177277, 25.03276062], [80.3723526, 25.02918053], [80.37612915, 25.02799988], [80.38088226, 25.02765846], [80.38304138, 25.01869011], [80.38915253, 25.01490974], [80.38739014, 25.01242065], [80.38218689, 25.00974083], [80.37283325, 25.00832939], [80.36921692, 25.01888084], [80.36885834, 25.02383995], [80.36782074, 25.02543068], [80.35884857, 25.02607918], [80.35507202, 25.02449036], [80.35257721, 25.01988029], [80.34793854, 25.01646805], [80.34456635, 25.01947021], [80.33798218, 25.02094078], [80.3289566, 25.00543022], [80.32739258, 25.00434113], [80.32594299, 25.00311089], [80.32491302, 25.00307083], [80.3243866, 25.00303078], [80.32388306, 25.00298119], [80.323349, 25.00296021], [80.32285309, 25.00294113], [80.32231903, 25.00291061], [80.3217926, 25.00291061], [80.32128143, 25.00290108], [80.32079315, 25.00291061], [80.32025909, 25.00291061], [80.31973267, 25.00291824], [80.31922913, 25.00294113], [80.31871033, 25.00296974], [80.31819916, 25.0030117], [80.31768036, 25.00303078], [80.31716919, 25.0030899], [80.31665039, 25.0031414], [80.31614685, 25.00320053], [80.31564331, 25.0032692], [80.31511688, 25.0033493], [80.31462097, 25.00342178], [80.31410217, 25.00350952], [80.31278229, 25.00432014], [80.31236267, 25.00629807], [80.29897308, 25.01603127], [80.28919983, 25.02114105], [80.27849579, 25.02164841], [80.26693726, 25.03024292], [80.26727295, 25.0316124], [80.26876831, 25.03269958], [80.27078247, 25.03417969], [80.27327728, 25.0371418], [80.27487946, 25.03903961], [80.2771759, 25.04294014], [80.27780151, 25.04397964], [80.27941132, 25.05267906], [80.28115845, 25.05673981], [80.28157043, 25.06005096], [80.28195953, 25.06322098], [80.2876358, 25.06689072], [80.2947464, 25.06909943], [80.30478668, 25.07551003], [80.31051636, 25.08195114], [80.3132019, 25.0892601], [80.31472015, 25.0940609], [80.31327057, 25.10117149], [80.32283783, 25.1066494], [80.33835602, 25.12125015], [80.34411621, 25.12491989], [80.34752655, 25.13002014], [80.34861755, 25.14069176], [80.35128784, 25.14490128], [80.35614777, 25.14841843], [80.36245728, 25.14973068], [80.37343597, 25.15517807], [80.38066864, 25.16077995], [80.3867569, 25.16288185], [80.40358734, 25.16505051], [80.41548157, 25.16529274], [80.42256927, 25.17221069], [80.42369843, 25.17414284], [80.42237854, 25.18136024], [80.41812897, 25.19192123], [80.41162872, 25.19943047], [80.4095459, 25.20586014], [80.40423584, 25.21404076], [80.4016571, 25.22095108], [80.39906311, 25.24296951], [80.39070129, 25.24568748], [80.3829422, 25.24195099], [80.3813324, 25.23829842], [80.37802887, 25.23751068], [80.36289215, 25.24682999], [80.35771179, 25.25113106], [80.35359192, 25.25638962], [80.35173798, 25.26024055], [80.35041046, 25.2652626], [80.34926605, 25.26955032], [80.3409729, 25.27860069], [80.33766174, 25.27941132], [80.31983948, 25.28049088], [80.31201172, 25.28215027], [80.30404663, 25.28889275], [80.30307007, 25.2911396], [80.30267334, 25.29696083], [80.30912018, 25.30585098], [80.31069183, 25.31065178], [80.31173706, 25.33420944], [80.30980682, 25.34127045], [80.30358887, 25.35251236], [80.30262756, 25.35828018], [80.30536652, 25.36207962], [80.30861664, 25.36372948], [80.31324768, 25.37225914], [80.31121063, 25.3810997], [80.31075287, 25.38731766], [80.30905151, 25.39183998], [80.30857849, 25.39233017], [80.29532623, 25.40776062], [80.28964233, 25.41271973], [80.28431702, 25.41588974], [80.27372742, 25.42503929], [80.26123047, 25.42617989], [80.255867, 25.42871094], [80.253479, 25.42346954], [80.25241089, 25.41877174], [80.24730682, 25.41146088], [80.24739838, 25.40738106], [80.24518585, 25.40489006], [80.22956085, 25.4109211], [80.22657776, 25.41064072], [80.2140274, 25.40423012], [80.21137238, 25.40394974], [80.20244598, 25.40673065], [80.19786835, 25.41056061], [80.19832611, 25.41269112], [80.19724274, 25.4149704], [80.19391632, 25.41623116], [80.19143677, 25.41271019], [80.19093323, 25.40904045], [80.18882751, 25.4064312], [80.18916321, 25.38922119], [80.18789673, 25.38364983], [80.18261719, 25.38151932], [80.17201233, 25.38069153], [80.16668701, 25.37895012], [80.15917969, 25.37764931], [80.15828705, 25.37265968], [80.15912628, 25.36619949], [80.15315247, 25.3628006], [80.14496613, 25.36010933], [80.13712311, 25.35573006], [80.13273621, 25.35032082], [80.12708282, 25.34061813], [80.12329865, 25.3384304], [80.119133, 25.34269905], [80.106987, 25.34418106], [80.09609222, 25.35157967], [80.09337616, 25.35383034], [80.08329773, 25.35583115], [80.07839966, 25.35344124], [80.07234192, 25.34509087], [80.07002258, 25.34309959], [80.06150055, 25.34204102], [80.05486298, 25.34129906], [80.04444122, 25.34185028], [80.0371933, 25.34096909], [80.02419281, 25.34459114], [80.02073669, 25.34316063], [80.01449585, 25.33111], [80.01265717, 25.33011055], [80.00991058, 25.32475281], [80.01264954, 25.30171967], [80.0083313, 25.30067825], [79.998703, 25.29376984], [79.99385834, 25.28884125], [79.99220276, 25.28524971], [79.99125671, 25.28316116], [79.9921875, 25.28098106], [79.99559784, 25.27672958], [79.99534607, 25.27466011], [79.99733734, 25.27013016], [79.99672699, 25.26865005], [79.99221039, 25.26930046], [79.97727966, 25.26494026], [79.96951294, 25.26816177], [79.96717072, 25.26847076], [79.96304321, 25.26824951], [79.94921875, 25.26530075], [79.94256592, 25.2718792], [79.94095612, 25.26971054], [79.93437958, 25.26486969], [79.93332672, 25.26301956], [79.93196106, 25.25985909], [79.93257141, 25.25032043], [79.92410278, 25.25155067], [79.92099762, 25.25070953], [79.91345215, 25.2334404], [79.91220856, 25.23376274], [79.91062927, 25.23604965], [79.91056061, 25.24497986], [79.90629578, 25.25418091], [79.90532684, 25.25547028], [79.90239716, 25.25691986], [79.89962006, 25.25657082], [79.89834595, 25.25510025], [79.8972702, 25.24959946], [79.89615631, 25.24753952], [79.89360046, 25.2462101], [79.8866272, 25.24641037], [79.87500763, 25.25299072], [79.87245941, 25.25379181], [79.86595917, 25.24682045], [79.86097717, 25.24299049], [79.85755157, 25.2419014], [79.8509903, 25.24156952], [79.84713745, 25.24020004], [79.84572601, 25.23838234], [79.8452301, 25.23655128], [79.84716034, 25.23241043], [79.85285187, 25.2250309], [79.86136627, 25.22095108], [79.86303711, 25.2191906], [79.85618591, 25.2136097], [79.85411835, 25.21042061], [79.85185242, 25.20347977], [79.8547821, 25.19909286], [79.85878754, 25.19022942], [79.85810852, 25.18185806], [79.86154175, 25.17906952], [79.86260223, 25.17696953], [79.85965729, 25.16205025], [79.86058807, 25.15606117], [79.86300659, 25.15390968], [79.87210083, 25.15030289], [79.87217712, 25.14851189], [79.86483002, 25.14499283], [79.85740662, 25.14281082], [79.85161591, 25.13977814], [79.84767151, 25.13339043], [79.84796906, 25.12823105], [79.84657288, 25.12227058], [79.84268188, 25.1163311], [79.84580994, 25.11046982], [79.85309601, 25.10275078], [79.855896, 25.09850121], [79.84921265, 25.09698105], [79.84085846, 25.09639931], [79.8312912, 25.0981102], [79.8272171, 25.10012054], [79.82434082, 25.10370064], [79.82327271, 25.10640907], [79.8187027, 25.11015129], [79.81640625, 25.11086273], [79.80516815, 25.11097908], [79.79325104, 25.11837959], [79.78833771, 25.12039185], [79.76921844, 25.1252594], [79.76274872, 25.12982941], [79.75772095, 25.13452911], [79.75110626, 25.14066124], [79.74781799, 25.14260101], [79.74563599, 25.14388275], [79.73957825, 25.14295959], [79.72603607, 25.13573265], [79.72455597, 25.13540077], [79.71776581, 25.13381958], [79.70728302, 25.13331985], [79.68698883, 25.13686943], [79.6765976, 25.13698959], [79.67418671, 25.13577843], [79.67079163, 25.13208961], [79.66616821, 25.12712097], [79.66053772, 25.12796021], [79.65659332, 25.12951279], [79.65419006, 25.1304512], [79.64302826, 25.13236046], [79.64070129, 25.13239861], [79.6378479, 25.13108063], [79.63285065, 25.13282967], [79.62003326, 25.14266968], [79.60608673, 25.13249969], [79.60514832, 25.13223076], [79.60209656, 25.1313591], [79.5978775, 25.13143158], [79.59516907, 25.13413239], [79.59541321, 25.13562012], [79.59748077, 25.13955116], [79.59854889, 25.1453495], [79.60276794, 25.15310097], [79.60279083, 25.15384293], [79.60280609, 25.1547699], [79.60003662, 25.15497971], [79.59326935, 25.14635086], [79.59233856, 25.14631081], [79.59144592, 25.14627075], [79.59052277, 25.14680099], [79.58969879, 25.14727974], [79.58573914, 25.15286255], [79.5762558, 25.15705109], [79.57396698, 25.15945053], [79.56893921, 25.17552185], [79.56552124, 25.17755127], [79.5595932, 25.17597008], [79.55033875, 25.16940117], [79.5427475, 25.16055107], [79.53795624, 25.15262985], [79.53494263, 25.14762115], [79.53363037, 25.14644051], [79.52864838, 25.14497948], [79.52731323, 25.14310074], [79.52857971, 25.13801193], [79.52868652, 25.13738251], [79.52658844, 25.13563919], [79.51795959, 25.1312294], [79.51377106, 25.12572289], [79.51394653, 25.12210083], [79.51815796, 25.10770035], [79.51828766, 25.10443115], [79.51722717, 25.10178757], [79.51535797, 25.10104179], [79.5133667, 25.10025024], [79.50527191, 25.10130119], [79.50016022, 25.0992012], [79.4937973, 25.0920105], [79.49118042, 25.08612251], [79.49112701, 25.08488274], [79.49106598, 25.08329964], [79.48987579, 25.08275032], [79.48243713, 25.08510971], [79.4715271, 25.08719063], [79.46053314, 25.09633064], [79.4701767, 25.13068008], [79.4701767, 25.13380051], [79.46951294, 25.13404083], [79.46837616, 25.13445091], [79.45656586, 25.12499046], [79.45022583, 25.11783028], [79.44478607, 25.11309052], [79.43637085, 25.10782051], [79.43106842, 25.10750961], [79.43067169, 25.10806084], [79.42990875, 25.10913277], [79.42951965, 25.11148262], [79.42945862, 25.1117897], [79.43115997, 25.11594963], [79.43344879, 25.12000084], [79.4344101, 25.12170029], [79.43525696, 25.1265316], [79.43297577, 25.13141823], [79.43113708, 25.13540077], [79.42590332, 25.13839912], [79.41760254, 25.1384697], [79.41512299, 25.13909912], [79.41477203, 25.13736916], [79.4178009, 25.1350708], [79.418396, 25.13352013], [79.41710663, 25.12726974], [79.41496277, 25.12299919], [79.40918732, 25.11565971], [79.40196991, 25.11335945], [79.39914703, 25.11346054], [79.39317322, 25.1161499], [79.39080811, 25.11790276], [79.38928986, 25.12058067], [79.38873291, 25.13162994], [79.38704681, 25.13614273], [79.38389587, 25.14003944], [79.38212585, 25.14593124], [79.38022614, 25.14912033], [79.38006592, 25.15372086], [79.38387299, 25.17028046], [79.39150238, 25.17964935], [79.40389252, 25.18958092], [79.40421295, 25.19441032], [79.40455627, 25.19947052], [79.40809631, 25.20751953], [79.40957642, 25.20876122], [79.41734314, 25.20392036], [79.42125702, 25.20323944], [79.42460632, 25.20264816], [79.42617798, 25.20305824], [79.42800903, 25.20353127], [79.43213654, 25.20277977], [79.43578339, 25.20465851], [79.44270325, 25.21256065], [79.44239807, 25.22095108], [79.43231201, 25.22180176], [79.42701721, 25.22503853], [79.43297577, 25.23600006], [79.43418121, 25.24178123], [79.43855286, 25.24827194], [79.4417572, 25.25172043], [79.44358826, 25.2486496], [79.44490814, 25.24811935], [79.44834137, 25.25081062], [79.45285034, 25.25650024], [79.45522308, 25.26521111], [79.45919037, 25.26945114], [79.46070099, 25.26960945], [79.46401215, 25.26799965], [79.47453308, 25.26657295], [79.47911835, 25.26516914], [79.48396301, 25.26498032], [79.48973846, 25.26564026], [79.49082947, 25.26901054], [79.49040222, 25.2703495], [79.48446655, 25.27273941], [79.47772217, 25.27238274], [79.4763031, 25.27316093], [79.47532654, 25.27487946], [79.47527313, 25.27671051], [79.47525024, 25.27749062], [79.4752121, 25.27917099], [79.47312164, 25.2821312], [79.45741272, 25.2838707], [79.45307159, 25.28256035], [79.4527359, 25.27526855], [79.45157623, 25.27360916], [79.43121338, 25.25955009], [79.42665863, 25.25842285], [79.41530609, 25.25922012], [79.40122223, 25.26235962], [79.40188599, 25.2792511], [79.39229584, 25.28486061], [79.38861084, 25.28624916], [79.38600159, 25.28415108], [79.38353729, 25.28360939], [79.37931061, 25.28672028], [79.37561798, 25.29109955], [79.37256622, 25.2933197], [79.36975098, 25.29409981], [79.36741638, 25.29432106], [79.36444855, 25.29252052], [79.36717224, 25.27557945], [79.36724091, 25.27242088], [79.36573792, 25.26807022], [79.36168671, 25.26427078], [79.35829926, 25.26351929], [79.35296631, 25.26538086], [79.35109711, 25.26995087], [79.35161591, 25.27799034], [79.34970856, 25.28841972], [79.34308624, 25.29042053], [79.33249664, 25.29230118], [79.33164978, 25.29257965], [79.33104706, 25.29277992], [79.33075714, 25.29404831], [79.34187317, 25.30458069], [79.3414917, 25.30768967], [79.33769989, 25.31090927], [79.33448029, 25.31739807], [79.33837891, 25.32492828], [79.34588623, 25.33304024], [79.34458923, 25.33444977], [79.3337326, 25.33258057], [79.33023071, 25.3337307], [79.32512665, 25.33724976], [79.30930328, 25.33856964], [79.30422211, 25.33984947], [79.29473114, 25.3402195], [79.29408264, 25.33937073], [79.29371643, 25.33236122], [79.2913208, 25.32928848], [79.28341675, 25.33008957], [79.27760315, 25.32805061], [79.27651978, 25.32703018], [79.26760101, 25.31875038], [79.26013947, 25.31023979], [79.25798798, 25.29837036], [79.25601196, 25.29171944], [79.25683594, 25.28499031], [79.25627899, 25.28211975], [79.25650787, 25.27947044], [79.25901031, 25.27420998], [79.25945282, 25.27144051], [79.26196289, 25.26773071], [79.26566315, 25.26639938], [79.26877594, 25.26646042], [79.27111053, 25.26650238], [79.27529907, 25.26929092], [79.27787018, 25.27100182], [79.28646088, 25.28107071], [79.28775024, 25.29024124], [79.29830933, 25.27577019], [79.30391693, 25.26540184], [79.31004333, 25.26192093], [79.31468964, 25.26139259], [79.31873322, 25.26307106], [79.32338715, 25.26684952], [79.33190155, 25.27626991], [79.33454132, 25.27571106], [79.33789825, 25.27318764], [79.34008789, 25.27276039], [79.3445282, 25.26429939], [79.34129333, 25.25864983], [79.34086609, 25.25607109], [79.34028625, 25.24308014], [79.34127808, 25.2390995], [79.34111786, 25.23048973], [79.33953094, 25.22809029], [79.33197784, 25.23200035], [79.33078003, 25.23207092], [79.32911682, 25.22990036], [79.33490753, 25.22286987], [79.34696198, 25.21424103], [79.34337616, 25.20998955], [79.3325882, 25.20083046], [79.32656097, 25.20850945], [79.32578278, 25.21081161], [79.32508087, 25.21387291], [79.32534027, 25.22244072], [79.32433319, 25.22257042], [79.3229599, 25.22274971], [79.31491089, 25.21960068], [79.31339264, 25.21955109], [79.31078339, 25.21948051], [79.30858612, 25.22319031], [79.30047607, 25.22744942], [79.29782104, 25.23444939], [79.29332733, 25.24020004], [79.28401184, 25.24650002], [79.27855682, 25.24782944], [79.27359772, 25.24811935], [79.27391052, 25.24650002], [79.27416992, 25.24518967], [79.27822876, 25.23829079], [79.28148651, 25.22714043], [79.28106689, 25.22434044], [79.27963257, 25.22171021], [79.27802277, 25.21063995], [79.27777863, 25.20351028], [79.27880096, 25.19739914], [79.28351593, 25.18946075], [79.28872681, 25.18626976], [79.29077911, 25.18390083], [79.30188751, 25.17534065], [79.30874634, 25.16512108], [79.31060028, 25.16090012], [79.31453705, 25.15187836], [79.31388855, 25.15096092], [79.30570984, 25.13990021], [79.30322266, 25.13332939], [79.30098724, 25.13083076], [79.29110718, 25.13125992], [79.28218079, 25.13352013], [79.27654266, 25.12026024], [79.27381897, 25.12168121], [79.26999664, 25.12615013], [79.26875305, 25.12623024], [79.2600708, 25.12210083], [79.25807953, 25.12401962], [79.25454712, 25.13046074], [79.26207733, 25.14115906], [79.26194763, 25.14191055], [79.25836182, 25.14390945], [79.25934601, 25.14694023], [79.25920105, 25.15327263], [79.2559967, 25.15728188], [79.25060272, 25.16120911], [79.24584198, 25.1619606], [79.23583984, 25.16096115], [79.22518158, 25.1581707], [79.21965027, 25.15456963], [79.21391296, 25.14838028], [79.22252655, 25.14562035], [79.22399139, 25.14318085], [79.22408295, 25.14082909], [79.2248764, 25.14023018], [79.2375412, 25.1428299], [79.23980713, 25.14273071], [79.24151611, 25.14092064], [79.24353027, 25.14079094], [79.23767853, 25.13133049], [79.23810577, 25.12672043], [79.24014282, 25.12018967], [79.2396698, 25.11783981], [79.23838043, 25.11636925], [79.23488617, 25.11746025], [79.22598267, 25.12240982], [79.22278595, 25.12325096], [79.22010803, 25.12099075], [79.21843719, 25.11819077], [79.21369934, 25.11647987], [79.21067047, 25.11445045], [79.20638275, 25.1137619], [79.20709991, 25.12439156], [79.19793701, 25.12818909], [79.19616699, 25.13167], [79.19632721, 25.13804817], [79.19671631, 25.14293098], [79.19373322, 25.1436615], [79.19010925, 25.14565086], [79.1889801, 25.14935112], [79.18768311, 25.15092278], [79.1848526, 25.15113258], [79.18110657, 25.14762115], [79.17730713, 25.14595032], [79.16837311, 25.14530754], [79.16677856, 25.14234924], [79.16652679, 25.13953018], [79.16879272, 25.13157082], [79.17987823, 25.12882996], [79.17930603, 25.11769295], [79.17411804, 25.11903], [79.17236328, 25.11847115], [79.16887665, 25.11186028], [79.15661621, 25.11190033], [79.14480591, 25.1165905], [79.13820648, 25.11841011], [79.13337708, 25.1110611], [79.12917328, 25.11076927], [79.12433624, 25.11186981], [79.12084961, 25.11340141], [79.11482239, 25.11779976], [79.12510681, 25.12921906], [79.1247406, 25.12957954], [79.10781097, 25.14369965], [79.11859131, 25.15839195], [79.12042236, 25.16418076], [79.11920929, 25.1634407], [79.10710907, 25.16814041], [79.10256195, 25.17119026], [79.09057617, 25.17622948], [79.08872986, 25.17832947], [79.08841705, 25.18372917], [79.08722687, 25.18783951], [79.08429718, 25.19252968], [79.07025909, 25.17776108], [79.06407928, 25.17249107], [79.06285858, 25.16274261], [79.05805206, 25.15081978], [79.0545578, 25.14887047], [79.04889679, 25.14751053], [79.04305267, 25.13817024], [79.03888702, 25.13722992], [79.0355072, 25.13784027], [79.02823639, 25.13993073], [79.02176666, 25.14319038], [79.02162933, 25.14693069], [79.02523804, 25.15579033], [79.03578186, 25.1739006], [79.03144836, 25.17850113], [79.02796173, 25.1803112], [79.02572632, 25.18259048], [79.02459717, 25.18657112], [79.04277802, 25.21014023], [79.04847717, 25.20979118], [79.05513, 25.21722031], [79.05673981, 25.21922112], [79.05644226, 25.22570992], [79.05232239, 25.22813034], [79.04506683, 25.23063087], [79.02648163, 25.23467064], [79.0283432, 25.24102974], [79.03103638, 25.24628067], [79.02937317, 25.24934006], [79.01474762, 25.24775124], [79.01212311, 25.24824905], [79.01161957, 25.24933052], [79.01167297, 25.25284958], [79.01599121, 25.26515007], [79.01431274, 25.27103043], [79.01235962, 25.27404022], [79.00496674, 25.27696991], [78.99265289, 25.27773094], [78.98677063, 25.27495956], [78.97722626, 25.2616806], [78.97331238, 25.25368118], [78.97116852, 25.24492073], [78.97231293, 25.24283028], [78.98741913, 25.23592949], [78.99269867, 25.23500252], [78.99466705, 25.23374939], [78.99500275, 25.23228073], [78.99453735, 25.22545052], [78.99330902, 25.22221947], [79.00035858, 25.2160511], [78.99749756, 25.2075901], [78.99733734, 25.19828987], [78.99581146, 25.19593811], [78.99275208, 25.19652176], [78.98774719, 25.19677925], [78.98240662, 25.19915009], [78.97767639, 25.20420074], [78.96920776, 25.21663284], [78.96392059, 25.21943092], [78.95284271, 25.22069168], [78.94834137, 25.22018051], [78.94235992, 25.21836281], [78.92423248, 25.2105999], [78.91916656, 25.2062397], [78.91529083, 25.20259094], [78.90804291, 25.19352913], [78.90159607, 25.18326187], [78.9006424, 25.18053818], [78.89340973, 25.17322922], [78.87713623, 25.16218185], [78.87393188, 25.16327095], [78.87184143, 25.16600037], [78.87325287, 25.17200279], [78.86921692, 25.17811966], [78.86979675, 25.18291283], [78.86759949, 25.18634033], [78.86738586, 25.18996048], [78.87104797, 25.19616127], [78.8757019, 25.20014954], [78.88011932, 25.20589828], [78.88241577, 25.21105957], [78.88162231, 25.21547127], [78.87325287, 25.22608185], [78.86707306, 25.23254013], [78.86725616, 25.23769188], [78.87217712, 25.25078964], [78.87587738, 25.25576973], [78.88022614, 25.25362015], [78.88456726, 25.24723053], [78.89169312, 25.24546051], [78.89644623, 25.24994087], [78.90859985, 25.27436066], [78.91520691, 25.27569008], [78.91828918, 25.27517128], [78.92276764, 25.27148056], [78.92581177, 25.26782036], [78.93348694, 25.26354027], [78.93643951, 25.26267815], [78.94061279, 25.26268959], [78.94618225, 25.26377106], [78.94838715, 25.2659111], [78.94799042, 25.2717495], [78.94447327, 25.27544975], [78.94378662, 25.28007126], [78.94754028, 25.28370094], [78.95384979, 25.28562927], [78.96469879, 25.2838707], [78.970047, 25.28520966], [78.97027588, 25.29109192], [78.95279694, 25.3118782], [78.95202637, 25.31738091], [78.9557724, 25.34776115], [78.95285797, 25.34987068], [78.94999695, 25.34827995], [78.94581604, 25.34725952], [78.94277954, 25.34511948], [78.93547058, 25.33620071], [78.93122864, 25.33241272], [78.9276123, 25.33171082], [78.92537689, 25.33457947], [78.92546082, 25.33843994], [78.92453003, 25.34192848], [78.91886902, 25.34599113], [78.91467285, 25.34644127], [78.91121674, 25.34213066], [78.90788269, 25.33940125], [78.9034729, 25.3400898], [78.89552307, 25.34351921], [78.88524628, 25.34669113], [78.87895966, 25.34687996], [78.87651825, 25.34445953], [78.87679291, 25.33921051], [78.87560272, 25.33401108], [78.87306976, 25.33082962], [78.86245728, 25.32460976], [78.85823822, 25.3208828], [78.85643768, 25.31695938], [78.85954285, 25.31455994], [78.86686707, 25.31098938], [78.86763763, 25.30134964], [78.87185669, 25.29179955], [78.87242889, 25.28820992], [78.87059021, 25.28486824], [78.86228943, 25.28313065], [78.85791779, 25.26624107], [78.85288239, 25.2588501], [78.85028839, 25.25342751], [78.84594727, 25.23378944], [78.84462738, 25.23110962], [78.8417511, 25.22916031], [78.83505249, 25.23320007], [78.82367706, 25.25107956], [78.81128693, 25.26600075], [78.80562592, 25.27093124], [78.80635071, 25.27946091], [78.81215668, 25.29409981], [78.81272125, 25.29776001], [78.81167603, 25.29984093], [78.80699158, 25.30297089], [78.80367279, 25.30199814], [78.79328918, 25.29310036], [78.79120636, 25.29301071], [78.78692627, 25.29494095], [78.7832489, 25.29761124], [78.78328705, 25.30318069], [78.78674316, 25.30972099], [78.79193878, 25.31479263], [78.79802704, 25.31452179], [78.81022644, 25.31085968], [78.81456757, 25.31096077], [78.81667328, 25.31657028], [78.8216629, 25.31874275], [78.82659912, 25.31985283], [78.8332901, 25.33134079], [78.83566284, 25.33298111], [78.84026337, 25.33185005], [78.84350586, 25.33236122], [78.84567261, 25.33518982], [78.84541321, 25.33867073], [78.8431778, 25.34208107], [78.83586121, 25.34703064], [78.83773804, 25.35217285], [78.8453598, 25.36091042], [78.86142731, 25.37702942], [78.87474823, 25.38765907], [78.88301849, 25.38951111], [78.89055634, 25.38883018], [78.90107727, 25.38925934], [78.90830994, 25.39237022], [78.91201019, 25.39699936], [78.9154129, 25.39962959], [78.92266846, 25.4004612], [78.9310379, 25.4031601], [78.94341278, 25.40312004], [78.94935608, 25.40015984], [78.95123291, 25.39645958], [78.94725037, 25.39318085], [78.93885803, 25.38907051], [78.93113708, 25.37712288], [78.92636871, 25.37734032], [78.90912628, 25.38056183], [78.89539337, 25.38079071], [78.89245605, 25.37529755], [78.89322662, 25.36901093], [78.8969574, 25.36520958], [78.90638733, 25.36338043], [78.9171524, 25.35999107], [78.92862701, 25.35180092], [78.93871307, 25.35283089], [78.94844055, 25.37000275], [78.95527649, 25.37308121], [78.97447205, 25.3725605], [78.978508, 25.3760128], [78.97840881, 25.38286018], [78.97580719, 25.38869095], [78.97106171, 25.39184952], [78.96817017, 25.39655113], [78.9655304, 25.41147995], [78.97022247, 25.42045975], [78.96891022, 25.42513275], [78.96248627, 25.43635941], [78.96012878, 25.43889046], [78.94696808, 25.44254112], [78.94258881, 25.44170189], [78.93782043, 25.43753815], [78.93415833, 25.4318924], [78.92913055, 25.42832947], [78.91259003, 25.43867111], [78.90322876, 25.44693756], [78.90631104, 25.4504509], [78.91340637, 25.4520607], [78.9197464, 25.46216011], [78.92745972, 25.46569061], [78.93003845, 25.46858978], [78.93563843, 25.48002052], [78.93612671, 25.48778152], [78.93518066, 25.49430084], [78.93315125, 25.4982605], [78.92617798, 25.50761032], [78.91918182, 25.51355171], [78.91668701, 25.51675034], [78.91638184, 25.52075005], [78.91726685, 25.52547073], [78.9196167, 25.52744293], [78.93224335, 25.52435112], [78.93844604, 25.52753067], [78.9418869, 25.53115082], [78.94381714, 25.54092026], [78.94168854, 25.55144119], [78.93566132, 25.55709076], [78.93074036, 25.55972099], [78.92568207, 25.5599575], [78.92263794, 25.55682945], [78.9204483, 25.54957008], [78.9185791, 25.54332161], [78.9168396, 25.54129028], [78.91332245, 25.54552078], [78.91036987, 25.55933952], [78.90595245, 25.56060028], [78.89678955, 25.55939102], [78.88553619, 25.56077003], [78.88276672, 25.56040955], [78.88109589, 25.5601902], [78.87435913, 25.55701256], [78.8690033, 25.55116081], [78.8684082, 25.54417992], [78.87757111, 25.53318977], [78.87837219, 25.52865982], [78.87600708, 25.5243206], [78.85128784, 25.51889038], [78.84706879, 25.51853943], [78.84120178, 25.51807022], [78.83673096, 25.51678848], [78.83394623, 25.51600075], [78.82832336, 25.50998116], [78.82699585, 25.50370026], [78.83071899, 25.49837112], [78.84603882, 25.4913826], [78.84880066, 25.48757172], [78.85164642, 25.47779083], [78.8571701, 25.4671402], [78.8572464, 25.46215248], [78.85369873, 25.45230103], [78.84533691, 25.44497108], [78.83660126, 25.43424988], [78.83426666, 25.43246078], [78.83097839, 25.43203163], [78.81973267, 25.43778038], [78.81569672, 25.44175911], [78.81387329, 25.44630814], [78.81645966, 25.44890976], [78.83036041, 25.44748116], [78.83268738, 25.44765282], [78.83718872, 25.44798088], [78.84200287, 25.45000267], [78.8457489, 25.45438957], [78.84211731, 25.45714951], [78.83764648, 25.45885086], [78.83590698, 25.45998955], [78.83339691, 25.46165085], [78.82985687, 25.46569061], [78.82549286, 25.46837044], [78.81526184, 25.47241974], [78.81019592, 25.47544098], [78.78952789, 25.48351288], [78.78172302, 25.48414993], [78.77677155, 25.48339081], [78.77297211, 25.48283005], [78.76432037, 25.4766407], [78.76051331, 25.47575951], [78.75654602, 25.47615051], [78.7494812, 25.48221016], [78.74359131, 25.48489189], [78.74154663, 25.48993111], [78.73931885, 25.49987984], [78.7360611, 25.50432968], [78.73175049, 25.50065041], [78.72631836, 25.49007034], [78.72464752, 25.46330833], [78.72766876, 25.4587307], [78.7323761, 25.45566177], [78.7436676, 25.45210075], [78.74812317, 25.44844055], [78.75180817, 25.43843079], [78.75506592, 25.43385124], [78.75997162, 25.43056107], [78.76537323, 25.43003273], [78.77207947, 25.4329319], [78.77629089, 25.43696976], [78.78218079, 25.43992043], [78.7894516, 25.44202042], [78.79528809, 25.44132805], [78.80345154, 25.43819046], [78.8117981, 25.43308067], [78.81291199, 25.43042755], [78.81138611, 25.42735291], [78.80766296, 25.42523956], [78.79464722, 25.4265995], [78.79046631, 25.42568016], [78.78823853, 25.42358017], [78.77604675, 25.42119026], [78.7562027, 25.41929817], [78.74938202, 25.41756058], [78.7454071, 25.4155407], [78.74314117, 25.41270065], [78.7405014, 25.40654182], [78.74030304, 25.40307045], [78.74156189, 25.39858055], [78.74349976, 25.39767075], [78.74754333, 25.4005394], [78.75115967, 25.40526962], [78.7546463, 25.40621948], [78.75863647, 25.40409088], [78.75962067, 25.402071], [78.75988007, 25.39775085], [78.75888824, 25.39352036], [78.75726318, 25.39252281], [78.75437164, 25.39307022], [78.75302887, 25.39195061], [78.75286102, 25.39034081], [78.75482178, 25.38619041], [78.76122284, 25.38216019], [78.76216125, 25.37437057], [78.76574707, 25.36477089], [78.76532745, 25.36044121], [78.76438141, 25.35840034], [78.75628662, 25.35750961], [78.74978638, 25.35211945], [78.735672, 25.34919167], [78.72524261, 25.35398293], [78.72112274, 25.3538208], [78.71794891, 25.35280991], [78.71362305, 25.3529892], [78.70944214, 25.35432053], [78.70384979, 25.3586483], [78.70361328, 25.36170006], [78.70455933, 25.36559105], [78.70976257, 25.37626839], [78.70903015, 25.37874985], [78.69982147, 25.38170052], [78.69711304, 25.38329124], [78.69610596, 25.38552856], [78.69275665, 25.38773918], [78.6905899, 25.38673973], [78.68914032, 25.3830204], [78.68717957, 25.3806324], [78.68386078, 25.38047981], [78.67156219, 25.38456154], [78.67352295, 25.38799095], [78.67376709, 25.39116096], [78.66940308, 25.39290047], [78.66493225, 25.38800049], [78.66117096, 25.38656044], [78.65789032, 25.38797951], [78.65592957, 25.39217186], [78.65688324, 25.39599037], [78.65666962, 25.4005394], [78.6520462, 25.41314125], [78.65367889, 25.41681099], [78.65651703, 25.42012978], [78.65930176, 25.4183712], [78.66493988, 25.40446091], [78.66909027, 25.40388107], [78.68448639, 25.41601181], [78.70024109, 25.42612076], [78.70140076, 25.42885971], [78.69983673, 25.43230057], [78.69332123, 25.43922043], [78.68924713, 25.44535065], [78.6857605, 25.44779015], [78.6816864, 25.44740105], [78.67893219, 25.44389915], [78.67751312, 25.43972969], [78.67488861, 25.43814087], [78.67041016, 25.43889046], [78.65796661, 25.44383049], [78.65271759, 25.44400024], [78.64901733, 25.44239235], [78.64541626, 25.43785095], [78.63883972, 25.44042969], [78.63365936, 25.43806076], [78.63250732, 25.4330101], [78.63749695, 25.41978836], [78.63680267, 25.41411018], [78.63379669, 25.4095211], [78.62858582, 25.40646172], [78.62362671, 25.4059906], [78.61921692, 25.40703964], [78.61692047, 25.41007042], [78.61435699, 25.41633034], [78.60349274, 25.41707039], [78.59895325, 25.41522026], [78.59461212, 25.40911293], [78.59163666, 25.39653969], [78.58834076, 25.39211273], [78.58409882, 25.3902607], [78.5789032, 25.39009094], [78.5761261, 25.39109039], [78.5686264, 25.39619064], [78.56344604, 25.39792061], [78.56112671, 25.39569283], [78.55690002, 25.38414955], [78.56009674, 25.38204956], [78.56463623, 25.38396072], [78.57034302, 25.38478279], [78.57440186, 25.38223076], [78.57775879, 25.37714005], [78.57950592, 25.36057091], [78.5789032, 25.35531807], [78.57621765, 25.35193062], [78.56204987, 25.34795189], [78.55602264, 25.34860992], [78.54473114, 25.3586998], [78.53505707, 25.36400986], [78.52806091, 25.36588097], [78.52514648, 25.36301231], [78.52336884, 25.3583107], [78.52480316, 25.35474968], [78.53044891, 25.35205078], [78.53108978, 25.34859085], [78.53069305, 25.33916855], [78.53150177, 25.33485031], [78.53359222, 25.33089256], [78.53768921, 25.32949829], [78.54145813, 25.32659912], [78.54083252, 25.3224411], [78.5389328, 25.32039261], [78.53356171, 25.31870079], [78.53098297, 25.31706047], [78.52507782, 25.30653], [78.51872253, 25.30581284], [78.51586151, 25.30433083], [78.50511169, 25.30211067], [78.50025177, 25.30413055], [78.49581146, 25.3101902], [78.49492645, 25.32069016], [78.49217224, 25.32382965], [78.4875412, 25.32019043], [78.48324585, 25.31418991], [78.47792053, 25.30869102], [78.47175598, 25.30583954], [78.46926117, 25.30332184], [78.46705627, 25.29301071], [78.45928955, 25.29665947], [78.45680237, 25.2993412], [78.44851685, 25.30328941], [78.44059753, 25.30416107], [78.43517303, 25.30252075], [78.4298172, 25.29701042], [78.42736053, 25.28867149], [78.42871094, 25.28083038], [78.43575287, 25.27324104], [78.44445038, 25.26995087], [78.4540329, 25.27060127], [78.48932648, 25.29208946], [78.49668121, 25.29385948], [78.50080872, 25.28824806], [78.50257874, 25.28342056], [78.50531769, 25.28154755], [78.52085114, 25.28803825], [78.52516937, 25.28549957], [78.52555847, 25.27817154], [78.52849579, 25.27450943], [78.53601837, 25.27194977], [78.54226685, 25.27203941], [78.55237579, 25.27087975], [78.55702209, 25.26932907], [78.56437683, 25.26521111], [78.56858063, 25.25860977], [78.56816864, 25.25405121], [78.5657959, 25.24945068], [78.56254578, 25.23867035], [78.56149292, 25.22744942], [78.56259155, 25.22602272], [78.56456757, 25.22096062], [78.56976318, 25.20195961], [78.59371185, 25.15739059], [78.59597778, 25.14858055], [78.59816742, 25.12708092], [78.59829712, 25.10808945], [78.59667969, 25.10345078], [78.59716797, 25.09787178], [78.60555267, 25.09422112], [78.61760712, 25.09271049], [78.62032318, 25.09159279], [78.6247406, 25.08641052], [78.62948608, 25.08242989], [78.63482666, 25.07419014], [78.6355896, 25.07101059], [78.63941193, 25.06637192], [78.64192963, 25.06149101], [78.64418793, 25.03524971], [78.6371994, 25.02555084], [78.6361618, 25.02136993], [78.6361618, 25.01089287], [78.63510895, 25.00432968], [78.63201904, 24.98372078], [78.62290192, 24.9677906], [78.62204742, 24.96490097], [78.62491608, 24.96194077], [78.64243317, 24.95265007], [78.64251709, 24.95029068], [78.6400528, 24.94532967], [78.64050293, 24.94036293], [78.6421814, 24.93976974], [78.65371704, 24.94421959], [78.65709686, 24.92506027], [78.65947723, 24.91752052], [78.66301727, 24.9092617], [78.668396, 24.90239906], [78.6754303, 24.8985405], [78.67965698, 24.89719009], [78.69171906, 24.89590073], [78.69634247, 24.89466095], [78.70056915, 24.88648033], [78.70289612, 24.88402748], [78.7128067, 24.88379097], [78.71887207, 24.88266182], [78.72254181, 24.88071823], [78.73163605, 24.87234116], [78.73441315, 24.87099266], [78.73838043, 24.86963081], [78.74668121, 24.87084961], [78.75061035, 24.86886024], [78.75343323, 24.86496925], [78.76135254, 24.86295128], [78.76448059, 24.86136818], [78.76716614, 24.85567093], [78.76740265, 24.84891129], [78.76888275, 24.84374809], [78.77256775, 24.83048058], [78.78054047, 24.81497192], [78.78109741, 24.81051064], [78.78011322, 24.80698967], [78.77781677, 24.80487251], [78.76722717, 24.79851151], [78.76454926, 24.79499245], [78.76319885, 24.76675987], [78.76862335, 24.7548008], [78.76895142, 24.75110054], [78.76748657, 24.74341011], [78.76912689, 24.72354126], [78.76980591, 24.71884918], [78.77308655, 24.71165085], [78.77297974, 24.70691109], [78.77239227, 24.70414162], [78.76760101, 24.69692993], [78.76534271, 24.69532967], [78.75998688, 24.69356918], [78.75878143, 24.68217087], [78.75753784, 24.67715073], [78.75498962, 24.67357063], [78.74487305, 24.66930962], [78.74427032, 24.66682053], [78.74006653, 24.65995979], [78.7405777, 24.65607071], [78.74208069, 24.65063095], [78.74635315, 24.64319038], [78.74797821, 24.63705063], [78.7485733, 24.62471008], [78.74803162, 24.61152077], [78.74946594, 24.60498047], [78.75199127, 24.60246277], [78.76661682, 24.59756279], [78.77690125, 24.59309006], [78.79382324, 24.59822845], [78.79788208, 24.60531998], [78.80182648, 24.60782814], [78.80667877, 24.6071701], [78.81112671, 24.60533905], [78.8140564, 24.60560036], [78.82039642, 24.6078701], [78.82878113, 24.60781097], [78.83084869, 24.60889053], [78.83345032, 24.62079048], [78.83599854, 24.62557983], [78.83905792, 24.6282196], [78.84436798, 24.62899017], [78.84916687, 24.62166023], [78.85240173, 24.62094116], [78.85579681, 24.62298965], [78.85919189, 24.62817955], [78.86280823, 24.64112091], [78.866539, 24.64549255], [78.87306976, 24.64694977], [78.8817215, 24.63969994], [78.89144135, 24.62207031], [78.89186859, 24.61680031], [78.89295197, 24.6138382], [78.90438843, 24.60430908], [78.90561676, 24.602211], [78.90850067, 24.58880997], [78.91314697, 24.58130074], [78.93038177, 24.56439018], [78.94299316, 24.55787849], [78.94465637, 24.55620956], [78.94550323, 24.55331039], [78.94036865, 24.54314995], [78.94001007, 24.53408051], [78.94042206, 24.53120995], [78.94393921, 24.52664757], [78.94477081, 24.52363014], [78.943367, 24.51662064], [78.94416809, 24.50950813], [78.94708252, 24.50598907], [78.95018768, 24.50447845], [78.96340942, 24.50204086], [78.96549225, 24.50028038], [78.96639252, 24.49694824], [78.96391296, 24.49378014], [78.95455933, 24.48855972], [78.94856262, 24.4861927], [78.94313812, 24.48488045], [78.93071747, 24.48454094], [78.92517853, 24.48599052], [78.92334747, 24.48839951], [78.92569733, 24.49183083], [78.92607117, 24.49638748], [78.92436218, 24.49908066], [78.92182922, 24.50107956], [78.91757965, 24.50251007], [78.91381073, 24.50084114], [78.90808105, 24.49316025], [78.90093994, 24.4883709], [78.90088654, 24.48357964], [78.9026413, 24.47837067], [78.90859222, 24.46677017], [78.91279602, 24.46351051], [78.92724609, 24.4621315], [78.93107605, 24.4599781], [78.94065857, 24.44598007], [78.94439697, 24.44325829], [78.94713593, 24.44313049], [78.95552826, 24.44512749], [78.96203613, 24.44407082], [78.97183228, 24.44473267], [78.981987, 24.44724083], [78.98438263, 24.44136047], [78.98651123, 24.43403053], [78.98777771, 24.42797089], [78.9868927, 24.42324066], [78.98087311, 24.41782951], [78.97621155, 24.40289116], [78.97422028, 24.39863968], [78.97097778, 24.38472939], [78.96717072, 24.37358284], [78.96692657, 24.37034988], [78.96833801, 24.36024284], [78.96813965, 24.35695076], [78.96687317, 24.35366058], [78.9648819, 24.35044289], [78.96099091, 24.34716988], [78.95493317, 24.34392929], [78.95088959, 24.34041023], [78.94536591, 24.33130074], [78.93245697, 24.31888962], [78.92874146, 24.31620979], [78.9241333, 24.31421852], [78.90776062, 24.30123138], [78.9070816, 24.29643059], [78.9077301, 24.29487038], [78.91284943, 24.28944969], [78.91322327, 24.28590965], [78.91172028, 24.2765007], [78.90985107, 24.27292061], [78.88558197, 24.25928116], [78.87909698, 24.25401115], [78.87827301, 24.24868965], [78.87982178, 24.24411964], [78.88105011, 24.22888947], [78.87886047, 24.22305107], [78.87368011, 24.2189312], [78.86283112, 24.21404076], [78.8582077, 24.21354103], [78.84654236, 24.21693039], [78.83876801, 24.21467972], [78.83277893, 24.20928192], [78.82772064, 24.20318985], [78.8242569, 24.20129967], [78.82007599, 24.20121956], [78.81886292, 24.20243835], [78.81638336, 24.20865059], [78.81352234, 24.21027946], [78.8105011, 24.20852089], [78.80908203, 24.20465088], [78.80795288, 24.19331932], [78.80570984, 24.18429947], [78.80224609, 24.18190002], [78.79168701, 24.18024063], [78.78848267, 24.18135834], [78.7845993, 24.18514061], [78.78205872, 24.19152069], [78.77831268, 24.2010498], [78.77625275, 24.21002007], [78.77488708, 24.21228981], [78.76983643, 24.215271], [78.76774597, 24.21777916], [78.76053619, 24.23385048], [78.76000977, 24.23651123], [78.7607193, 24.2390995], [78.76642609, 24.25057983], [78.76027679, 24.25848961], [78.75668335, 24.25972939], [78.75428772, 24.2472496], [78.75255585, 24.24367905], [78.74977112, 24.24073982], [78.74588776, 24.23927116], [78.74371338, 24.23945045], [78.74085236, 24.24016953], [78.73751831, 24.24210167], [78.73610687, 24.24510956], [78.73526001, 24.25177956], [78.73221588, 24.25382042], [78.72653961, 24.25270081], [78.72110748, 24.24122047], [78.71858215, 24.239151], [78.71111298, 24.23944092], [78.7071228, 24.23876953], [78.69886017, 24.2344799], [78.69258118, 24.23701096], [78.68113708, 24.24407005], [78.67809296, 24.24489975], [78.67311096, 24.24435043], [78.66912079, 24.24501991], [78.66535187, 24.24844933], [78.66316223, 24.25263023], [78.65779877, 24.26805115], [78.65444946, 24.27374077], [78.64363861, 24.28149986], [78.63923645, 24.28619957], [78.6341629, 24.28936958], [78.6313858, 24.29018974], [78.62602234, 24.28646278], [78.62171936, 24.2862606], [78.61940002, 24.28944969], [78.61734009, 24.2961216], [78.61788177, 24.2992897], [78.62351227, 24.30690193], [78.62281036, 24.30985069], [78.61962891, 24.31184006], [78.61492157, 24.31257248], [78.6047821, 24.31574059], [78.6020813, 24.31830025], [78.59900665, 24.32318115], [78.59364319, 24.33936119], [78.58777618, 24.34135056], [78.58470154, 24.3434391], [78.58071899, 24.34983063], [78.57888031, 24.35396194], [78.57843781, 24.35708046], [78.57489777, 24.3593502], [78.56651306, 24.35732079], [78.56265259, 24.35935974], [78.5568924, 24.3611908], [78.55258179, 24.36062813], [78.52762604, 24.37447166], [78.52511597, 24.37713814], [78.52207184, 24.38414955], [78.51922607, 24.38735008], [78.51455688, 24.39055824], [78.50537109, 24.39394951], [78.49993896, 24.39433098], [78.49819183, 24.3927803], [78.48977661, 24.38605118], [78.48430634, 24.37762833], [78.47532654, 24.36742973], [78.47280121, 24.36235046], [78.47167969, 24.35709], [78.47077179, 24.34338188], [78.46779633, 24.33934021], [78.45892334, 24.33568954], [78.45459747, 24.33322144], [78.45082855, 24.32987976], [78.44029236, 24.32553101], [78.4335022, 24.31340981], [78.43332672, 24.30900955], [78.43477631, 24.29766083], [78.42648315, 24.29018021], [78.42315674, 24.28915024], [78.41861725, 24.28946114], [78.41448975, 24.28884125], [78.41130829, 24.28758049], [78.4069519, 24.27700996], [78.40326691, 24.27547264], [78.39296722, 24.2747612], [78.38566589, 24.27305031], [78.38237, 24.2739296], [78.37963867, 24.27556038], [78.37742615, 24.27806091], [78.3730011, 24.28635979], [78.36989594, 24.28908157], [78.36624908, 24.29030991], [78.3639679, 24.29235077], [78.36168671, 24.29610062], [78.35141754, 24.29927063], [78.34453583, 24.30328941], [78.34243774, 24.30538177], [78.34140015, 24.30780983], [78.34130859, 24.31151962], [78.33943176, 24.31735992], [78.33551788, 24.31917953], [78.33181, 24.32249069], [78.32852173, 24.32550049], [78.3259964, 24.32961845], [78.32543182, 24.33436966], [78.32657623, 24.33846855], [78.33112335, 24.34255028], [78.33544922, 24.3450985], [78.34092712, 24.35242081], [78.34651947, 24.36269951], [78.36257172, 24.37815094], [78.36292267, 24.38161087], [78.36094666, 24.38578987], [78.3588562, 24.38718987], [78.35040283, 24.38953018], [78.3449173, 24.39204025], [78.33673096, 24.40386963], [78.33244324, 24.40597153], [78.31830597, 24.4103508], [78.31520081, 24.41284943], [78.31150055, 24.41744041], [78.29985046, 24.42654991], [78.28985596, 24.43312073], [78.28121185, 24.43721008], [78.26687622, 24.44737053], [78.26074982, 24.45393944], [78.26030731, 24.46001053], [78.26966095, 24.47310829], [78.2696228, 24.47618294], [78.26682281, 24.47999954], [78.263237, 24.48308182], [78.2545929, 24.4858284], [78.24621582, 24.48671913], [78.23963165, 24.48945999], [78.23789978, 24.49358177], [78.23768616, 24.49617958], [78.24150848, 24.50484276], [78.24017334, 24.50958061], [78.23806, 24.5116806], [78.2281723, 24.51645279], [78.21971893, 24.52277946], [78.21653748, 24.53164291], [78.21839905, 24.53569031], [78.22418213, 24.54133987], [78.23654938, 24.5463295], [78.24610901, 24.5486908], [78.25531769, 24.5522995], [78.25888824, 24.55818939], [78.26035309, 24.56923294], [78.2637558, 24.57872009], [78.26808167, 24.59697914], [78.26940155, 24.60502052], [78.26985168, 24.61538124], [78.26753235, 24.62191963], [78.26339722, 24.62812042], [78.25847626, 24.63780022], [78.25669098, 24.64862061], [78.25834656, 24.65283966], [78.26789856, 24.66352081], [78.26847839, 24.66710091], [78.26799774, 24.66959953], [78.25699615, 24.68593025], [78.25460815, 24.69248962], [78.25280762, 24.70094109], [78.25078583, 24.70557022], [78.23654938, 24.72463989], [78.22631836, 24.73624992], [78.22039032, 24.74736977], [78.21888733, 24.75379944], [78.21987152, 24.75819016], [78.22428894, 24.76403046], [78.22518921, 24.76639175], [78.22582245, 24.77657127], [78.22387695, 24.78300095], [78.21836853, 24.79191971], [78.20896912, 24.8130703], [78.19587708, 24.82859039], [78.19403076, 24.83156013], [78.19158173, 24.83967018], [78.18689728, 24.84280968], [78.17357635, 24.8461895], [78.1700058, 24.84647942], [78.16532898, 24.84817123], [78.1638031, 24.85709953], [78.16355133, 24.8642807], [78.16332245, 24.87099266], [78.16470337, 24.87829971], [78.1653595, 24.88174057], [78.1704483, 24.88526917], [78.17704773, 24.88733101], [78.18917084, 24.89280128], [78.19973755, 24.8962307], [78.2039566, 24.90050125], [78.21070862, 24.91234016], [78.21391296, 24.91557121], [78.22878265, 24.9240799], [78.24936676, 24.93848038], [78.25244904, 24.93950081], [78.25604248, 24.94203949], [78.25991821, 24.94924927], [78.26271057, 24.95260048], [78.2822876, 24.96320915], [78.28959656, 24.96813965], [78.30256653, 24.98397064], [78.3066864, 24.98899269], [78.30961609, 24.99124908], [78.32753754, 24.9995594], [78.33020782, 25.00374031], [78.33460999, 25.01073837], [78.33751678, 25.0207901], [78.3380661, 25.02733994], [78.33078003, 25.0453701], [78.32717896, 25.06791115], [78.32498932, 25.07249832], [78.32524872, 25.08406067], [78.32675934, 25.08688164], [78.32776642, 25.08876991], [78.33090973, 25.09163094], [78.33265686, 25.09324265], [78.34781647, 25.09996986], [78.35784149, 25.10235023], [78.36699677, 25.1045208], [78.37441254, 25.10853958], [78.37869263, 25.11269951], [78.38968658, 25.12699127], [78.39531708, 25.1305275], [78.40226746, 25.13097], [78.41072845, 25.1292305], [78.41765594, 25.12697029], [78.42468262, 25.12469101], [78.43097687, 25.1244812], [78.44291687, 25.12877083], [78.43235779, 25.13754082], [78.42294312, 25.14537048], [78.41882324, 25.15109062], [78.41829681, 25.1534996], [78.42089844, 25.15764046], [78.42870331, 25.15833092], [78.44198608, 25.15735054], [78.44284821, 25.15788078], [78.44631195, 25.1667099], [78.44645691, 25.16902161], [78.44394684, 25.17255974], [78.43913269, 25.17214966], [78.43746185, 25.17140961], [78.435112, 25.17036057], [78.42823029, 25.16964149], [78.41726685, 25.17278099], [78.4090271, 25.18202972], [78.40725708, 25.1857605], [78.40355682, 25.18894005], [78.3913269, 25.19120026], [78.38889313, 25.1928196], [78.38536072, 25.19515991], [78.38427734, 25.19933128], [78.3835907, 25.20195007], [78.3838501, 25.20486069], [78.38394928, 25.20600128], [78.38577271, 25.20868111], [78.39450073, 25.21463966], [78.39775848, 25.21775055], [78.39553833, 25.22118187], [78.39215088, 25.22234917], [78.38108826, 25.2238102], [78.37516785, 25.22575188], [78.37075806, 25.23336029], [78.36888885, 25.24166107], [78.3645401, 25.24391174], [78.35708618, 25.24417114], [78.35453033, 25.2460804], [78.35521698, 25.24996948], [78.36029816, 25.25856972], [78.36222076, 25.26543045], [78.35526276, 25.2757206], [78.34506989, 25.28297043], [78.34516144, 25.29794121], [78.34130859, 25.29927063], [78.33007813, 25.30038071], [78.31645203, 25.30458069], [78.31163788, 25.3075695], [78.30802917, 25.31098938], [78.31057739, 25.31615829], [78.31543732, 25.32073021], [78.32710266, 25.32720947], [78.32782745, 25.32761002], [78.33078003, 25.33128929], [78.3312912, 25.33671951], [78.32756042, 25.34645081], [78.32657623, 25.34902], [78.32319641, 25.35526848], [78.31626892, 25.35961914], [78.30162048, 25.36437988], [78.2962265, 25.36499023], [78.2942276, 25.36762047], [78.29551697, 25.37479973], [78.29972076, 25.38375282], [78.30340576, 25.38479042], [78.30716705, 25.3841629], [78.31067657, 25.3850708], [78.31690979, 25.39090919], [78.32151031, 25.3952198], [78.33027649, 25.40099907], [78.33248901, 25.40455055], [78.33407593, 25.41815186], [78.33518982, 25.43105125], [78.33656311, 25.43498993], [78.34378815, 25.44617844], [78.34758759, 25.45483971], [78.34925842, 25.45579147], [78.35266876, 25.45531273], [78.36097717, 25.44660187], [78.36614227, 25.44631767], [78.37077332, 25.44717026], [78.37738037, 25.44837952], [78.38088989, 25.4504509], [78.38340759, 25.45193291], [78.38568878, 25.45416069], [78.39189911, 25.46884918], [78.39309692, 25.47042084], [78.39375305, 25.47125053], [78.3960495, 25.47177124], [78.40142822, 25.47297096], [78.40672302, 25.47921944], [78.41646576, 25.47750282], [78.42072296, 25.47761917], [78.42156982, 25.47970963], [78.41947937, 25.49054146], [78.412323, 25.49766159], [78.40940857, 25.50427055], [78.408638, 25.50799942], [78.40956879, 25.51864815], [78.41124725, 25.51902008], [78.41433716, 25.51531029], [78.41628265, 25.51573944], [78.41674805, 25.51777267], [78.41529846, 25.52139091], [78.411026, 25.52738953], [78.40866089, 25.53290176], [78.40997314, 25.53771973], [78.41230774, 25.54224968], [78.4261322, 25.56145096], [78.42933655, 25.56385994], [78.43353271, 25.56524086], [78.43707275, 25.56435013], [78.43974304, 25.55895996], [78.44303894, 25.5570507], [78.44496918, 25.55499077], [78.44915009, 25.5527401], [78.45519257, 25.55195045], [78.45733643, 25.55540085], [78.46003723, 25.56455994], [78.46212006, 25.56747055], [78.46894073, 25.57298088], [78.48108673, 25.58043289], [78.48626709, 25.58222961], [78.49149323, 25.58188057], [78.51143646, 25.57296181], [78.52751923, 25.57292938], [78.53240204, 25.57028961], [78.53604889, 25.56686974], [78.54178619, 25.56513977], [78.54714966, 25.56470108], [78.55974579, 25.56780052], [78.56548309, 25.56787109], [78.57096863, 25.56735992], [78.57608032, 25.56528854], [78.58119202, 25.56430817], [78.583992, 25.56554985], [78.58706665, 25.57294083], [78.59027863, 25.57522011], [78.59525299, 25.57493019], [78.59799194, 25.57561111], [78.60015106, 25.57835007], [78.6042099, 25.58728981], [78.60573578, 25.58887291], [78.60862732, 25.58908081], [78.6181488, 25.58699036], [78.62133026, 25.58218002], [78.62020874, 25.57356071], [78.62341309, 25.57100105], [78.62883759, 25.56900024], [78.64434052, 25.56541824], [78.64862061, 25.5656395], [78.66535187, 25.58484077], [78.672966, 25.59180069], [78.67701721, 25.59410095], [78.68798828, 25.59515953], [78.69570923, 25.59984016], [78.7003479, 25.60131073], [78.70658875, 25.60327911], [78.71116638, 25.60659027], [78.72431946, 25.60844994], [78.73284149, 25.60305977], [78.74095154, 25.60387993], [78.7489624, 25.60834122], [78.75541687, 25.60959053], [78.76597595, 25.61314964], [78.78485107, 25.61548996], [78.79454803, 25.6175499], [78.79815674, 25.61922073], [78.80519104, 25.6245575], [78.806427, 25.63302994], [78.80979156, 25.63836098], [78.81124878, 25.64545059], [78.81060791, 25.66506195], [78.8113327, 25.67448044], [78.80938721, 25.67807007], [78.79576111, 25.69614029], [78.78940582, 25.69983101], [78.79070282, 25.70285034], [78.79255676, 25.70717049], [78.79123688, 25.71054077], [78.77752686, 25.71370125], [78.76074982, 25.72079086], [78.75240326, 25.72741127], [78.74803925, 25.73265076], [78.7457962, 25.73801994], [78.74550629, 25.74411964], [78.74681854, 25.74909019], [78.75128174, 25.75270081], [78.75567627, 25.75299072], [78.76241302, 25.75226021], [78.76582336, 25.75891113], [78.77578735, 25.7614994], [78.77996826, 25.77511978], [78.79062653, 25.7882309], [78.79360199, 25.7935009], [78.79606628, 25.79593086], [78.79955292, 25.79936028], [78.80413055, 25.80033112], [78.80497742, 25.80019188], [78.81169891, 25.79914093], [78.8167572, 25.7992897], [78.82050323, 25.79940033], [78.82408142, 25.80760956], [78.82376862, 25.81082153], [78.82363892, 25.81236076], [78.82227325, 25.81522751], [78.81623077, 25.81758118], [78.813797, 25.81681061], [78.80766296, 25.81151962], [78.80401611, 25.81022072], [78.80046082, 25.81287956], [78.79885864, 25.8182106], [78.80198669, 25.82220078], [78.81124878, 25.83012009], [78.81582642, 25.83114052], [78.83512878, 25.82409286], [78.84098053, 25.82064056], [78.84179688, 25.81680107], [78.84073639, 25.81208038], [78.84129333, 25.80520058], [78.8436203, 25.80130959], [78.8496933, 25.79586029], [78.8559494, 25.79443932], [78.86192322, 25.79919815], [78.8633194, 25.80208015], [78.86396027, 25.81627083], [78.86646271, 25.8296299], [78.86575317, 25.83435059], [78.85293579, 25.84361076], [78.84622192, 25.83876038], [78.84397888, 25.84531021], [78.84662628, 25.86050034], [78.85051727, 25.86561012], [78.85782623, 25.87201118], [78.86071777, 25.87332916], [78.86358643, 25.87467194], [78.86606598, 25.87485123], [78.86798096, 25.87498093], [78.87268829, 25.87302017], [78.87689209, 25.8698597], [78.8826828, 25.87026978], [78.88345337, 25.87491989], [78.88371277, 25.87647057], [78.88134003, 25.8884201], [78.88511658, 25.89286041], [78.88719177, 25.89897156], [78.8829422, 25.90635109], [78.88034821, 25.90955162], [78.87741852, 25.91316986], [78.8768692, 25.91448021], [78.87638092, 25.91566086], [78.89427185, 25.92585182], [78.89808655, 25.93087006], [78.90125275, 25.9375], [78.90394592, 25.94110107], [78.90978241, 25.94608116], [78.91532898, 25.94936943], [78.92384338, 25.95275116], [78.92112732, 25.95084763], [78.92215729, 25.95012093], [78.92484283, 25.9487114], [78.92735291, 25.94832039], [78.92952728, 25.94935989], [78.93009949, 25.95158005], [78.92742157, 25.95549965], [78.92582703, 25.95889282], [78.92547607, 25.96541977], [78.92951965, 25.9716301], [78.93113708, 25.97631073], [78.9261322, 25.97776985], [78.92362213, 25.9808712], [78.92459106, 25.98431015], [78.92720032, 25.98651123], [78.93102264, 25.98553085], [78.93621826, 25.98531914], [78.93947601, 25.98637009], [78.94316864, 25.99069023], [78.9438858, 25.99324036], [78.94330597, 25.99822807], [78.94610596, 26.00155067], [78.94658661, 26.00506973], [78.94613647, 26.00616074], [78.94441986, 26.00889015], [78.94534302, 26.01390076], [78.95040131, 26.01986122], [78.95050049, 26.02582169], [78.94618988, 26.03107262], [78.94432831, 26.03695107], [78.94863129, 26.03881264], [78.95266724, 26.04203033], [78.96144867, 26.0508194], [78.9681778, 26.05916023], [78.97579956, 26.05988121], [78.9786911, 26.0646801], [78.98248291, 26.07375908], [78.98602295, 26.07608032], [78.99188232, 26.07464027], [78.99711609, 26.07393074], [78.99915314, 26.07709122], [79.00113678, 26.0783596], [79.00315094, 26.08179283], [79.00219727, 26.08660126], [79.00437927, 26.09008026], [79.00350952, 26.09431076], [79.00049591, 26.09671021], [78.99185181, 26.09526062], [78.99011993, 26.09589958], [78.9718399, 26.1086998], [78.96977997, 26.11230087], [78.97049713, 26.12028122], [78.96922302, 26.1234417], [78.96652985, 26.12565041], [78.95810699, 26.12990952], [78.95464325, 26.13286018], [78.94438934, 26.13751984], [78.94267273, 26.13914108], [78.94576263, 26.14106178], [78.95230103, 26.14260101], [78.96032715, 26.15427017], [78.96533966, 26.15578079], [78.97064209, 26.15540123], [78.98623657, 26.1505394], [78.98966217, 26.15070915], [78.99179077, 26.15205956], [78.99459839, 26.15278053], [79.00071716, 26.15497971], [79.00092316, 26.16026115], [79.002388, 26.16472816], [79.00340271, 26.17295837], [78.99598694, 26.17551041], [78.99178314, 26.17728043], [78.97574615, 26.19281006], [78.97737885, 26.19549942], [78.98091888, 26.19841003], [78.98403931, 26.20067024], [78.99175262, 26.20396805], [78.9944458, 26.2004509], [78.99655151, 26.19898033], [79.00232697, 26.19676971], [79.0129776, 26.19686127], [79.01494598, 26.19746971], [79.01502991, 26.19815063], [79.01257324, 26.20140076], [79.01039124, 26.20277977], [79.00990295, 26.2049408], [79.02062225, 26.20857048], [79.02070618, 26.20967293], [79.01819611, 26.2125206], [79.01872253, 26.21582985], [79.01729584, 26.22369194], [79.01761627, 26.22340012], [79.01690674, 26.22800064], [79.01714325, 26.2321682], [79.02039337, 26.23425293], [79.02466583, 26.23425293], [79.02684784, 26.23336029], [79.02960968, 26.23207092], [79.03425598, 26.23154068], [79.04055023, 26.22928047], [79.04603577, 26.23354912], [79.0521698, 26.23211288], [79.05526733, 26.23238945], [79.05705261, 26.23289108], [79.05555725, 26.23964119], [79.05652618, 26.24188995], [79.06112671, 26.24369049], [79.06266785, 26.24693108], [79.05844116, 26.25391006], [79.05551147, 26.25415039], [79.05191803, 26.25324059], [79.04892731, 26.25369072], [79.04692078, 26.25539017], [79.04535675, 26.26029968], [79.04219818, 26.25996017], [79.03793335, 26.26287079], [79.03703308, 26.26699066], [79.04677582, 26.26531982], [79.04853058, 26.26597023], [79.04679871, 26.27059174], [79.05327606, 26.27960014], [79.05789185, 26.28380013], [79.0640564, 26.28263092], [79.06726837, 26.28762054], [79.06865692, 26.28777122], [79.07206726, 26.28523064], [79.07553101, 26.28713036], [79.07769012, 26.28721809], [79.0786972, 26.28448105], [79.07872772, 26.28034019], [79.07657623, 26.27882195], [79.07610321, 26.27519035], [79.07720184, 26.27359962], [79.07964325, 26.27260971], [79.08357239, 26.27240944], [79.08635712, 26.28367043], [79.08309937, 26.29389954], [79.083992, 26.29708099], [79.08769226, 26.2990303], [79.09178925, 26.30404282], [79.09147644, 26.30845261], [79.09384918, 26.31194115], [79.09797668, 26.31464958], [79.10154724, 26.3138504], [79.10875702, 26.30862045], [79.11457825, 26.31314087], [79.11911774, 26.31492805], [79.12658691, 26.3160305], [79.12724304, 26.32138062], [79.11798859, 26.32634163], [79.11573029, 26.32849121], [79.11569214, 26.33130074], [79.11564636, 26.33509064], [79.12423706, 26.33114052], [79.12586212, 26.33143806], [79.12703705, 26.33165932], [79.12731171, 26.33349037], [79.12499237, 26.33793068], [79.12680054, 26.33992004], [79.13257599, 26.34276009], [79.13374329, 26.3449707], [79.13137817, 26.34589958], [79.12320709, 26.34473038], [79.11952209, 26.35103989], [79.11662292, 26.35357285], [79.10858154, 26.35449028], [79.10526276, 26.35598946], [79.10340118, 26.35951042], [79.10038757, 26.35509109], [79.09644318, 26.35560989], [79.09673309, 26.35956955], [79.0951767, 26.35981941], [79.0930481, 26.36013985], [79.08857727, 26.3599205], [79.08421326, 26.3597126], [79.07679749, 26.36269188], [79.07675934, 26.3660202], [79.07924652, 26.37288094], [79.08911896, 26.37713051], [79.09047699, 26.37939072], [79.08849335, 26.38313293], [79.08959198, 26.38820076], [79.08699799, 26.39108276], [79.08072662, 26.40550041], [79.08682251, 26.41782188], [79.09192657, 26.41674042], [79.09268951, 26.41614914], [79.09703827, 26.41259956], [79.10067749, 26.41173172], [79.11489868, 26.41558838], [79.11723328, 26.41712189], [79.11682129, 26.42421913], [79.11911011, 26.4328804], [79.12328339, 26.4406395], [79.12676239, 26.44481087], [79.12400818, 26.4455204], [79.12098694, 26.44789124], [79.11030579, 26.45301056], [79.10515594, 26.45360184], [79.09989166, 26.45602989], [79.0949173, 26.45709991], [79.09287262, 26.45730019], [79.09118652, 26.45527077], [79.09113312, 26.45240021], [79.08943176, 26.45092964], [79.08329773, 26.4530201], [79.08274841, 26.45231056], [79.08304596, 26.44973946], [79.08094025, 26.44390106], [79.07769775, 26.44723129], [79.07417297, 26.44556808], [79.07279205, 26.44779015], [79.06906891, 26.44651985], [79.06710052, 26.44700813], [79.06684875, 26.44940948], [79.06355286, 26.44895935], [79.06130219, 26.44943047], [79.06062317, 26.45182991], [79.05802917, 26.45128059], [79.05748749, 26.45614052], [79.05323029, 26.45561028], [79.04846191, 26.45605087], [79.04676056, 26.45786095], [79.04707336, 26.46142006], [79.0634613, 26.48476028], [79.06433868, 26.4868412], [79.06230927, 26.48987961], [79.06114197, 26.49095917], [79.06093597, 26.50329971], [79.0565567, 26.50316048], [79.05335999, 26.50121117], [79.05088043, 26.50077057], [79.04971313, 26.50276947], [79.04975128, 26.50666046], [79.04374695, 26.51046944], [79.03930664, 26.5157299], [79.03959656, 26.5196991], [79.04102325, 26.52276039], [79.03946686, 26.5233593], [79.03325653, 26.52262115], [79.03129578, 26.52477074], [79.03366852, 26.53341103], [79.03309631, 26.53598976], [79.01963043, 26.54144096], [79.01863098, 26.5433197], [79.02054596, 26.55166054], [79.01724243, 26.55212975], [79.01278687, 26.54871941], [79.00804138, 26.54778099], [79.00598907, 26.55142021], [79.00284576, 26.54993057], [78.99798584, 26.55093956], [78.99575043, 26.55411148], [78.99768829, 26.55586052], [79.00518799, 26.55623055], [79.00673676, 26.55780029], [79.00437927, 26.55862045], [78.99797058, 26.56401062], [78.99912262, 26.5667305], [78.99785614, 26.57215118], [78.99820709, 26.57422256], [78.9935379, 26.5788002], [78.99134064, 26.58230972], [78.97962189, 26.57407951], [78.97952271, 26.58156967], [78.98100281, 26.58600807], [78.97802734, 26.59243011], [78.9821167, 26.59417915], [78.99133301, 26.60464096], [79.00372314, 26.60637093], [79.00566101, 26.61046982], [79.00520325, 26.61413765], [79.00311279, 26.61923027], [79.0030899, 26.62665939], [79.00084686, 26.63041115], [78.99530029, 26.63596916], [78.99130249, 26.64143944], [78.98722076, 26.6441803], [78.98686981, 26.64736748], [78.98899078, 26.65142059], [78.9912796, 26.65456963], [78.99572754, 26.66356277], [78.99814606, 26.66662025], [79.0011673, 26.6739006], [79.00041199, 26.67671013], [78.99732208, 26.68099022], [78.99317932, 26.68457031], [78.99124908, 26.68444061], [78.98728943, 26.68604088], [78.98388672, 26.68571091], [78.97387695, 26.68254089], [78.9696579, 26.6805706], [78.96393585, 26.67651749], [78.94789124, 26.66262817], [78.9437027, 26.6610508], [78.93791199, 26.66269112], [78.9360733, 26.66488075], [78.93579102, 26.6679306], [78.93698883, 26.67228127], [78.94991302, 26.69194031], [78.95015717, 26.6940403], [78.94814301, 26.6967411], [78.93076324, 26.70426941], [78.91278839, 26.71038055], [78.90792084, 26.71294022], [78.90394592, 26.71338081], [78.88288879, 26.70440102], [78.87708282, 26.7035408], [78.87123871, 26.70360947], [78.8649292, 26.70466995], [78.85431671, 26.71232033], [78.85114288, 26.71642113], [78.84068298, 26.7260704], [78.81138611, 26.7654705], [78.80610657, 26.7687912], [78.79868317, 26.76911163], [78.77414703, 26.76606941], [78.77070618, 26.76419067], [78.76638031, 26.76453972], [78.762146, 26.76683044], [78.75447845, 26.77571106], [78.74904633, 26.78440094], [78.74479675, 26.78940964], [78.74108124, 26.79252052], [78.73596954, 26.78898048], [78.73145294, 26.78310966], [78.72586823, 26.77962112], [78.72293854, 26.77934265], [78.71837616, 26.78170013], [78.7178421, 26.78717995], [78.72033691, 26.79274178], [78.72142792, 26.79771042], [78.71534729, 26.80021286], [78.69007111, 26.79602814], [78.6834259, 26.79461288], [78.67736053, 26.79238129], [78.67282867, 26.78774834], [78.66750336, 26.77424049], [78.65901947, 26.76922989], [78.65036774, 26.76972961], [78.62857056, 26.77539063], [78.62043762, 26.77519989], [78.61569214, 26.77190018], [78.61178589, 26.76711273], [78.60938263, 26.76102066], [78.60646057, 26.75752068], [78.60196686, 26.75605965], [78.57521057, 26.75599289], [78.5658493, 26.75769043], [78.56009674, 26.76221275], [78.55490112, 26.76482964], [78.53504944, 26.77166176], [78.53427124, 26.77200127], [78.52632904, 26.77853966], [78.51557159, 26.78511047], [78.49199677, 26.78795052], [78.47632599, 26.79225159], [78.46631622, 26.79341125], [78.45813751, 26.79523277], [78.45078278, 26.79805183], [78.44557953, 26.80343056], [78.43427277, 26.82411194], [78.430336, 26.82887268], [78.4258728, 26.83231926], [78.41337585, 26.83043098], [78.40032196, 26.82600975], [78.38973999, 26.82489967], [78.38559723, 26.82793999], [78.38065338, 26.83609009], [78.37480927, 26.84683037], [78.37010956, 26.85758972], [78.36688232, 26.8625927], [78.36464691, 26.86884117], [78.36250305, 26.87133026], [78.35135651, 26.87437057], [78.34120178, 26.87395096], [78.32375336, 26.8686409], [78.315979, 26.86936188], [78.30200958, 26.86911964], [78.29470062, 26.86828995], [78.28206635, 26.86408806], [78.27623749, 26.86048126], [78.27075195, 26.85559082], [78.26779175, 26.84966087], [78.2664566, 26.8409996], [78.26677704, 26.8328228], [78.26531219, 26.82467079], [78.26088715, 26.82094955], [78.2556076, 26.82028961], [78.24754333, 26.82387924], [78.23680115, 26.83169937], [78.22299194, 26.8372097], [78.21700287, 26.83767128], [78.20979309, 26.83609009], [78.21164703, 26.83846092], [78.21395111, 26.84852028], [78.20755768, 26.85233116], [78.20448303, 26.85555077], [78.20075226, 26.86240005], [78.19689178, 26.87212181], [78.19017792, 26.88346291], [78.19113922, 26.88861084], [78.19352722, 26.88952065], [78.20053864, 26.87858009], [78.20485687, 26.87738991], [78.22657013, 26.88262939], [78.22978973, 26.89389992], [78.23249817, 26.89545822], [78.24817657, 26.90063095], [78.25267029, 26.90460968], [78.25432587, 26.90974808], [78.25953674, 26.91621971], [78.26223755, 26.92351151], [78.2617569, 26.93017006], [78.26122284, 26.93177986], [78.25831604, 26.9340229], [78.25219727, 26.9349823], [78.24733734, 26.93074989], [78.24024963, 26.93363953], [78.23274231, 26.93369293], [78.23060608, 26.93678284], [78.22940063, 26.94131088], [78.22731781, 26.94358063], [78.2233963, 26.9450798], [78.22052765, 26.94767952], [78.21589661, 26.95395088], [78.21219635, 26.94961929], [78.20826721, 26.93975258], [78.20524597, 26.93889046], [78.2012558, 26.94032288], [78.19049835, 26.94676971], [78.17373657, 26.94869041], [78.16314697, 26.95269012], [78.15265656, 26.95214081], [78.14608002, 26.95305061], [78.13947296, 26.95713043], [78.13407135, 26.95700836], [78.12706757, 26.9554882], [78.11489868, 26.95486069], [78.11134338, 26.95323181], [78.10804749, 26.9500103], [78.1079483, 26.94831085], [78.10943604, 26.94487953], [78.11305237, 26.94194984], [78.11522675, 26.93819046], [78.11431122, 26.93058014], [78.11270905, 26.92749023], [78.10630798, 26.93001175], [78.10214233, 26.93085289], [78.09866333, 26.93061066], [78.09535217, 26.92905045], [78.09662628, 26.92304039], [78.09908295, 26.92061234], [78.10276031, 26.90993118], [78.10147095, 26.90498924], [78.09861755, 26.90397263], [78.09346008, 26.91008949], [78.09104919, 26.9116497], [78.08830261, 26.90993118], [78.08992004, 26.90574837], [78.0894165, 26.90286255], [78.08682251, 26.90200806], [78.07280731, 26.90755081], [78.06788635, 26.91028023], [78.06291962, 26.91485023], [78.06053925, 26.91590118], [78.05712128, 26.91329956], [78.0524826, 26.91488266], [78.04862976, 26.91377068], [78.04223633, 26.91542053], [78.04522705, 26.90286255], [78.04429626, 26.88453102], [78.04482269, 26.88211823], [78.04772949, 26.8777504], [78.04780579, 26.87480927], [78.04589081, 26.87488174], [78.03965759, 26.87734985], [78.03755951, 26.87696266], [78.03540039, 26.8745594], [78.03114319, 26.86548233], [78.02722168, 26.86218071], [78.02202606, 26.86087036], [78.01761627, 26.86164093], [78.01635742, 26.86381912], [78.02731323, 26.87347984], [78.02793121, 26.87615013], [78.02009583, 26.87961006], [78.01756287, 26.88203049], [78.02207184, 26.89019012], [78.02171326, 26.89479065], [78.01911926, 26.89743996], [78.01629639, 26.90497971], [78.01406097, 26.90839195], [78.00666046, 26.9106617], [77.99838257, 26.90985107], [77.99188995, 26.91090012], [77.98501587, 26.90138054], [77.98027802, 26.89770126], [77.9751358, 26.89752769], [77.97062683, 26.89970016], [77.96675873, 26.90302086], [77.96481323, 26.90724945], [77.96579742, 26.91098022], [77.96295929, 26.91257095], [77.94197083, 26.89978981], [77.93769836, 26.90205002], [77.93474579, 26.9051609], [77.93212891, 26.90999985], [77.92884064, 26.91283989], [77.92189026, 26.91455078], [77.90956879, 26.9142704], [77.9082489, 26.91683006], [77.90925598, 26.92082977], [77.90661621, 26.92395973], [77.89994049, 26.9245491], [77.89692688, 26.92000008], [77.89858246, 26.91542053], [77.90090179, 26.91171265], [77.90284729, 26.90114021], [77.90083313, 26.89513969], [77.89612579, 26.88972092], [77.8901062, 26.88945961], [77.88479614, 26.89232063], [77.88214111, 26.89603996], [77.87677765, 26.89920998], [77.87146759, 26.90550041], [77.84940338, 26.91242027], [77.84104156, 26.91644096], [77.83637238, 26.9195919], [77.82633209, 26.92103958], [77.82132721, 26.92620087], [77.8146286, 26.92279053], [77.80860901, 26.92566109], [77.8052597, 26.9285202], [77.79923248, 26.92825127], [77.79588318, 26.92340088], [77.78885651, 26.92228127], [77.78148651, 26.92770958], [77.77313995, 26.9325695], [77.77348328, 26.93626976], [77.76509857, 26.93799019], [77.75337982, 26.93773842], [77.748703, 26.9269104], [77.74433136, 26.92321014], [77.74064636, 26.92691994], [77.72895813, 26.92580032], [77.72392273, 26.92295074], [77.71891022, 26.91641045], [77.71083832, 26.90302086], [77.71788025, 26.89958954], [77.71987915, 26.89673042], [77.72054291, 26.89301109], [77.719841, 26.88673973], [77.7158432, 26.88133049], [77.70540619, 26.88027954]]]}}, {\\\"id\\\": \\\"32\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.35_1\\\", \\\"HASC_1\\\": \\\"IN.UT\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Uttarakhand\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Uttarakhand\\\", \\\"apm25_popweighted\\\": -3.7, \\\"dalys_apm25_rate_6cod_mean_total\\\": 706.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -1912.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1206.0, \\\"geo-id\\\": 32, \\\"hpm25_child_popweighted\\\": -260.0, \\\"hpm25_female_popweighted\\\": -299.0, \\\"hpm25_male_popweighted\\\": -215.0, \\\"location\\\": \\\"Uttarakhand\\\", \\\"mort_apm25_6cod_mean_total\\\": 2589.0, \\\"mort_hpm25_6cod_mean_total\\\": -6237.0, \\\"mort_tpm25_6cod_mean_total\\\": -3648.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[80.06291199, 28.88316345], [80.06633759, 28.837286], [80.07238007, 28.82974434], [80.07025146, 28.82963943], [80.07013702, 28.8296833], [80.0696106, 28.8298912], [80.06381226, 28.83189964], [80.0584259, 28.83526039], [80.03408813, 28.80982971], [80.03360748, 28.80546951], [80.03198242, 28.80348969], [80.02568817, 28.79985046], [80.02736664, 28.79737854], [80.0326767, 28.79417992], [80.03623962, 28.79071999], [80.04045868, 28.78310966], [80.03816223, 28.77511978], [80.0345459, 28.76904106], [80.03398132, 28.76638031], [80.03476715, 28.76323128], [80.03344727, 28.76138115], [80.03124237, 28.76055908], [80.02906799, 28.75806046], [80.02297211, 28.74867058], [80.0136261, 28.73736954], [80.00565338, 28.72949982], [80.00286865, 28.72694969], [79.99958038, 28.72564125], [79.98825836, 28.71701813], [79.97483063, 28.7167511], [79.96782684, 28.71562004], [79.95288849, 28.71752167], [79.94087219, 28.72145844], [79.92951965, 28.72651291], [79.92237854, 28.73270988], [79.92233276, 28.73829079], [79.92150879, 28.74500084], [79.91808319, 28.75219917], [79.91172791, 28.75928116], [79.91014099, 28.76333046], [79.91204834, 28.76496124], [79.90571594, 28.77209854], [79.8992691, 28.77386093], [79.89450836, 28.77900124], [79.89209747, 28.78125954], [79.8889389, 28.78577042], [79.8934021, 28.79186249], [79.89813232, 28.79488754], [79.9005661, 28.79940033], [79.90129089, 28.80212021], [79.89480591, 28.80145073], [79.88604736, 28.79881096], [79.88012695, 28.79681969], [79.87307739, 28.79646111], [79.86728668, 28.79644966], [79.85965729, 28.79845047], [79.85336304, 28.80080032], [79.84648895, 28.80496025], [79.8405304, 28.80866051], [79.84332275, 28.81504059], [79.84620667, 28.82130051], [79.84971619, 28.8217411], [79.85423279, 28.82082939], [79.86042023, 28.81791115], [79.87123871, 28.81641006], [79.87563324, 28.8183403], [79.87547302, 28.82128906], [79.87532043, 28.83024025], [79.87101746, 28.83065033], [79.86061096, 28.83413124], [79.85560608, 28.83905983], [79.85468292, 28.84140968], [79.85404968, 28.84428978], [79.8494873, 28.84538078], [79.8441391, 28.84354019], [79.84171295, 28.84260941], [79.83383942, 28.84439087], [79.82965088, 28.84667969], [79.82446289, 28.84478951], [79.82234955, 28.8417511], [79.813797, 28.83171082], [79.81282806, 28.83018112], [79.8157196, 28.82468033], [79.81620789, 28.8217411], [79.81465149, 28.81912041], [79.81503296, 28.81458092], [79.81591034, 28.81225967], [79.81407166, 28.81060982], [79.81128693, 28.81138039], [79.80905151, 28.81075096], [79.80503845, 28.80873108], [79.80419922, 28.80706024], [79.80303955, 28.80558968], [79.8012619, 28.80454063], [79.7947464, 28.80380058], [79.79203033, 28.80303955], [79.78544617, 28.80620956], [79.78336334, 28.80541992], [79.78214264, 28.81319046], [79.78617096, 28.82093048], [79.78940582, 28.81970024], [79.79189301, 28.81517029], [79.79479218, 28.8147316], [79.79704285, 28.81649017], [79.79782104, 28.82081032], [79.79988098, 28.82468987], [79.80119324, 28.82963753], [79.80146027, 28.8332901], [79.79920197, 28.83623123], [79.79367065, 28.8392601], [79.79431152, 28.84303093], [79.798172, 28.84604073], [79.79815674, 28.84803963], [79.79669952, 28.84955025], [79.7946167, 28.8528595], [79.79991913, 28.85427094], [79.80812073, 28.85629082], [79.80901337, 28.85890961], [79.8086319, 28.86283112], [79.80693817, 28.86631012], [79.80574036, 28.86905098], [79.80280304, 28.87182045], [79.79696655, 28.87045097], [79.79485321, 28.86987114], [79.79161835, 28.87039757], [79.79125214, 28.87380981], [79.79064178, 28.87742996], [79.77446747, 28.89183044], [79.76197052, 28.8896904], [79.75977325, 28.88953018], [79.74996948, 28.89335251], [79.748703, 28.89154053], [79.74487305, 28.88978004], [79.74128723, 28.88535118], [79.74044037, 28.88318062], [79.73726654, 28.88259125], [79.73282623, 28.88309097], [79.72836304, 28.88507271], [79.71813202, 28.88275909], [79.71555328, 28.88178062], [79.71218872, 28.88068008], [79.70961761, 28.87920952], [79.70672607, 28.87523842], [79.7056427, 28.8723526], [79.70517731, 28.87022018], [79.70189667, 28.86989975], [79.69705963, 28.87028122], [79.69233704, 28.86832047], [79.68814087, 28.86819077], [79.68643951, 28.86700058], [79.68434143, 28.8573494], [79.67285919, 28.8576107], [79.66709137, 28.85409927], [79.6672821, 28.8500309], [79.66619873, 28.84832954], [79.6594696, 28.84773064], [79.65405273, 28.84873962], [79.64393616, 28.852911], [79.6432724, 28.85322952], [79.64109802, 28.85646248], [79.634552, 28.8584404], [79.63075256, 28.85885811], [79.62399292, 28.86268997], [79.61904144, 28.86758041], [79.61354828, 28.86873055], [79.60868073, 28.86671066], [79.60360718, 28.86470032], [79.59805298, 28.86491966], [79.59226227, 28.86655045], [79.58197021, 28.85584259], [79.57878876, 28.85238266], [79.57655334, 28.85028076], [79.57427979, 28.84930038], [79.57189941, 28.84902], [79.56578827, 28.84946823], [79.56347656, 28.8487606], [79.56233978, 28.84790993], [79.5594101, 28.84670067], [79.55716705, 28.84568977], [79.5535965, 28.84505081], [79.55092621, 28.84589195], [79.54821777, 28.85004997], [79.54767609, 28.85429955], [79.54991913, 28.86016083], [79.55120087, 28.86320114], [79.5512619, 28.86610985], [79.55166626, 28.86824989], [79.55374146, 28.87481117], [79.55397034, 28.87852097], [79.55253601, 28.88153076], [79.55049896, 28.88418007], [79.54332733, 28.89066124], [79.53866577, 28.89241028], [79.53645325, 28.89253998], [79.53308868, 28.89031029], [79.52989197, 28.88689041], [79.52591705, 28.88199806], [79.52259827, 28.87632942], [79.51996613, 28.87329102], [79.51732635, 28.87058067], [79.51406097, 28.86759186], [79.51013184, 28.86470032], [79.5072403, 28.86330032], [79.50248718, 28.86276054], [79.49691772, 28.86239052], [79.49137115, 28.86259842], [79.48654938, 28.86459923], [79.48262787, 28.86622047], [79.47663116, 28.86717033], [79.46776581, 28.86491013], [79.46470642, 28.86275291], [79.46338654, 28.86053085], [79.4597168, 28.85915947], [79.45510864, 28.86005974], [79.44777679, 28.86005974], [79.43976593, 28.86104965], [79.43345642, 28.86164284], [79.43031311, 28.8597908], [79.42752838, 28.85725021], [79.42388916, 28.85523987], [79.41963196, 28.8553009], [79.41712189, 28.85584259], [79.41121674, 28.85588074], [79.4087677, 28.85801125], [79.40621948, 28.86225128], [79.40493774, 28.86745262], [79.4048233, 28.87112999], [79.40429688, 28.87490082], [79.40187836, 28.87728119], [79.3979187, 28.88104057], [79.39565277, 28.88544083], [79.400383, 28.89558983], [79.40114594, 28.89977074], [79.40123749, 28.90186119], [79.40007782, 28.91101074], [79.39900208, 28.9169693], [79.40139771, 28.92136955], [79.40261841, 28.92904091], [79.40143585, 28.93226051], [79.3983078, 28.93515968], [79.39556122, 28.93675041], [79.38942719, 28.93830109], [79.38497925, 28.93731117], [79.37934113, 28.93629074], [79.37702942, 28.93704987], [79.37490082, 28.93939018], [79.37336731, 28.9418602], [79.37252045, 28.94762993], [79.37224579, 28.9511795], [79.3707428, 28.95458031], [79.36897278, 28.95767975], [79.36743164, 28.95994949], [79.36506653, 28.96199036], [79.36338806, 28.96665955], [79.35967255, 28.97047997], [79.3571167, 28.96797943], [79.35507965, 28.96528053], [79.35285187, 28.96123123], [79.35275269, 28.95882034], [79.35389709, 28.95681953], [79.35476685, 28.9534111], [79.35189056, 28.95243073], [79.349617, 28.95210075], [79.34390259, 28.95313072], [79.33763885, 28.95453072], [79.33368683, 28.95498276], [79.32881165, 28.95540047], [79.32095337, 28.9567585], [79.31658936, 28.95679092], [79.31215668, 28.95806122], [79.30718994, 28.95846939], [79.30467987, 28.95393944], [79.30150604, 28.95285034], [79.29892731, 28.95311165], [79.29547882, 28.95429993], [79.28600311, 28.96050262], [79.27887726, 28.96483994], [79.27365112, 28.97287178], [79.27052307, 28.97542953], [79.26846313, 28.97739983], [79.26434326, 28.98213959], [79.25801849, 28.98694992], [79.24996948, 28.99217987], [79.24389648, 28.99648094], [79.23937225, 28.99990082], [79.23774719, 29.00683975], [79.22154236, 29.01729012], [79.21116638, 29.02370071], [79.2040329, 29.02910042], [79.19911194, 29.02527809], [79.19758606, 29.02209091], [79.18296051, 29.02420998], [79.18493652, 29.01801109], [79.17759705, 29.0196209], [79.16858673, 29.0158596], [79.16562653, 29.01729965], [79.16410065, 29.02058983], [79.15827942, 29.02287865], [79.15451813, 29.02741051], [79.15421295, 29.03292084], [79.15866852, 29.03421021], [79.16015625, 29.0433197], [79.1654129, 29.05125809], [79.15345764, 29.05476952], [79.14369965, 29.06009102], [79.13698578, 29.06933975], [79.13471985, 29.08191109], [79.1370163, 29.09090805], [79.14319611, 29.09894943], [79.14398193, 29.1066227], [79.14221954, 29.11972809], [79.13384247, 29.12416077], [79.13080597, 29.1293602], [79.11779022, 29.13388062], [79.11361694, 29.13066292], [79.10853577, 29.13043976], [79.10074615, 29.13167953], [79.09223938, 29.13674164], [79.07286072, 29.15199089], [79.05947876, 29.15626907], [79.05438232, 29.15518188], [79.04612732, 29.15472984], [79.0382309, 29.16629028], [79.03378296, 29.17110062], [79.02696228, 29.17226982], [79.02614594, 29.17196083], [79.02307129, 29.17079163], [79.02175903, 29.16730118], [79.02388, 29.16338921], [79.0275116, 29.16074944], [79.02742004, 29.15588188], [79.02867889, 29.15239906], [79.02639771, 29.14986038], [79.02147675, 29.1508007], [79.01696777, 29.15397072], [79.01335144, 29.15769005], [79.01095581, 29.15722084], [79.01048279, 29.15302849], [79.01278687, 29.14912987], [79.01203918, 29.14487076], [79.00859833, 29.13936234], [79.00875854, 29.13622093], [79.01187134, 29.13471031], [79.01899719, 29.13508987], [79.02352142, 29.13312912], [79.02768707, 29.13296127], [79.03096771, 29.13022995], [79.02970123, 29.12543106], [79.02606964, 29.12154961], [79.02185059, 29.11892128], [79.01700592, 29.11786079], [79.00657654, 29.12051964], [79.0005722, 29.11655045], [78.99838257, 29.12294006], [78.99465942, 29.12537003], [78.9954071, 29.12927055], [78.99262238, 29.13363266], [78.98809814, 29.13512039], [78.98353577, 29.13734818], [78.98262787, 29.1469593], [78.97901154, 29.15475082], [78.97319794, 29.16082001], [78.96662903, 29.16555023], [78.96232605, 29.16681099], [78.96057892, 29.16587067], [78.96035004, 29.16460037], [78.96127319, 29.16317749], [78.9608078, 29.16159821], [78.95610809, 29.16037178], [78.95146942, 29.15970993], [78.94888306, 29.15278053], [78.94438934, 29.14958954], [78.93371582, 29.15420914], [78.92363739, 29.1571312], [78.92077637, 29.15286064], [78.9144516, 29.14898109], [78.90040588, 29.15061951], [78.89834595, 29.15488815], [78.89589691, 29.15579033], [78.89504242, 29.15681076], [78.89961243, 29.16142082], [78.90479279, 29.16316986], [78.90571594, 29.16521072], [78.90332031, 29.16768074], [78.9045105, 29.17057037], [78.90239716, 29.17449951], [78.9057312, 29.17748833], [78.90570068, 29.18033981], [78.90130615, 29.18273926], [78.89911652, 29.19063187], [78.89434814, 29.19589996], [78.89720917, 29.19869041], [78.89916229, 29.20259285], [78.89356232, 29.20483971], [78.88774872, 29.21033287], [78.89225769, 29.21285057], [78.89214325, 29.21487236], [78.89103699, 29.21647263], [78.88687897, 29.21783066], [78.88445282, 29.21951294], [78.88286591, 29.22532082], [78.87014771, 29.22853088], [78.86958313, 29.22953987], [78.87303925, 29.23225975], [78.87359619, 29.23525238], [78.87097931, 29.24073029], [78.86406708, 29.24949265], [78.85787201, 29.25220108], [78.85437775, 29.25542068], [78.85383606, 29.25921059], [78.85262299, 29.26131058], [78.8506012, 29.26222992], [78.84668732, 29.25824928], [78.84519196, 29.25814056], [78.84233093, 29.25428009], [78.83405304, 29.25619125], [78.83319092, 29.25942039], [78.83125305, 29.26073837], [78.82756042, 29.25793076], [78.82289886, 29.25579071], [78.81611633, 29.25382805], [78.81378174, 29.25229073], [78.79988098, 29.25785255], [78.79286957, 29.26260948], [78.78994751, 29.26299095], [78.78736877, 29.26533127], [78.78600311, 29.27301979], [78.78153992, 29.2712307], [78.75863647, 29.28667068], [78.76683044, 29.28590965], [78.76552582, 29.28992081], [78.76107788, 29.29333115], [78.74675751, 29.30270958], [78.73889923, 29.30631065], [78.73139191, 29.31101036], [78.72756195, 29.31278992], [78.72080231, 29.31228065], [78.71385956, 29.31735039], [78.71412659, 29.31933022], [78.71975708, 29.31842041], [78.72110748, 29.31945992], [78.7273407, 29.31748962], [78.72860718, 29.31896019], [78.72592163, 29.32512093], [78.72570801, 29.32998276], [78.7277298, 29.33138084], [78.72834778, 29.33415985], [78.7315979, 29.33431053], [78.73478699, 29.3317585], [78.74150085, 29.33262062], [78.74164581, 29.33588028], [78.74608612, 29.34091949], [78.74704742, 29.34333992], [78.75740814, 29.34976006], [78.76352692, 29.34739113], [78.76532745, 29.34572983], [78.76384735, 29.34320068], [78.76593018, 29.3410511], [78.7696228, 29.34065056], [78.77905273, 29.3422718], [78.78089142, 29.34352112], [78.78246307, 29.34644127], [78.78444672, 29.34292984], [78.78132629, 29.33196068], [78.78884125, 29.32928276], [78.79133606, 29.33499908], [78.79738617, 29.33697128], [78.7979126, 29.33831978], [78.79270172, 29.34342766], [78.79167175, 29.34787941], [78.79012299, 29.35040092], [78.79014587, 29.35211945], [78.79720306, 29.35563087], [78.80684662, 29.37315178], [78.80776978, 29.38027191], [78.80898285, 29.38287926], [78.81160736, 29.38470078], [78.81500244, 29.38533974], [78.81095886, 29.38027954], [78.81176758, 29.37231064], [78.81417847, 29.3700428], [78.8239212, 29.36844063], [78.82881927, 29.36818123], [78.83436584, 29.36967087], [78.83625793, 29.37140846], [78.83580017, 29.37228775], [78.8347168, 29.37434959], [78.83185577, 29.37658119], [78.8325119, 29.38134956], [78.83631134, 29.38143158], [78.84039307, 29.3799305], [78.85679626, 29.3855896], [78.85975647, 29.38767052], [78.86003113, 29.38931084], [78.85888672, 29.39147949], [78.8602066, 29.39388275], [78.86258698, 29.39460945], [78.86599731, 29.39311981], [78.87018585, 29.39236259], [78.87275696, 29.39856911], [78.88279724, 29.40480042], [78.88719177, 29.40899086], [78.89061737, 29.41642952], [78.89647675, 29.42358017], [78.90040588, 29.44668961], [78.90714264, 29.45183182], [78.92292786, 29.45618057], [78.91979218, 29.46014977], [78.90033722, 29.45618057], [78.89601898, 29.45618057], [78.8901062, 29.45754051], [78.8826828, 29.45784187], [78.87542725, 29.4599781], [78.86575317, 29.45960045], [78.84612274, 29.46365166], [78.83006287, 29.46850967], [78.82376862, 29.46969032], [78.81669617, 29.46857071], [78.81138611, 29.46982956], [78.79695129, 29.47595024], [78.7855072, 29.47603035], [78.77474976, 29.48093987], [78.76577759, 29.48378944], [78.74225616, 29.5012207], [78.73905945, 29.50498009], [78.73152161, 29.50574112], [78.72660828, 29.50871086], [78.70826721, 29.50942039], [78.69335938, 29.50887108], [78.68540955, 29.5135498], [78.67655945, 29.52135086], [78.65039063, 29.54068947], [78.63957214, 29.54777908], [78.62149811, 29.55289078], [78.61515808, 29.55787086], [78.6052475, 29.5617981], [78.57647705, 29.58057022], [78.56121063, 29.59373093], [78.53054047, 29.62393188], [78.52735901, 29.62436295], [78.52546692, 29.62977028], [78.51774597, 29.63915062], [78.51151276, 29.65069008], [78.50921631, 29.65965271], [78.50961304, 29.66847992], [78.50763702, 29.6729126], [78.50724792, 29.67696953], [78.50744629, 29.69083023], [78.50601959, 29.69388962], [78.50184631, 29.71170807], [78.5002594, 29.71533966], [78.49021149, 29.72491837], [78.48757935, 29.7413826], [78.47357941, 29.74847031], [78.46473694, 29.75101089], [78.45215607, 29.75213814], [78.43212891, 29.75811958], [78.42431641, 29.76165009], [78.41256714, 29.77242088], [78.40838623, 29.77343941], [78.39842224, 29.77213287], [78.38598633, 29.77386093], [78.35125732, 29.78625107], [78.33853912, 29.7925396], [78.33193207, 29.79611969], [78.33174133, 29.79618073], [78.30293274, 29.75759125], [78.28193665, 29.74234009], [78.26476288, 29.72679138], [78.23139954, 29.70409012], [78.22126007, 29.71762276], [78.19352722, 29.71005821], [78.19229889, 29.70659065], [78.18222046, 29.69155121], [78.1659317, 29.67952919], [78.13912201, 29.67609978], [78.13400269, 29.65851021], [78.11482239, 29.64516068], [78.10913849, 29.63669968], [78.10697937, 29.63318062], [78.09751129, 29.63078117], [78.09683228, 29.63059998], [78.09423828, 29.62803078], [78.09062195, 29.62477112], [78.08867645, 29.61330032], [78.08206177, 29.60181046], [78.07850647, 29.59954262], [78.07315826, 29.59991074], [78.06826019, 29.60141182], [78.05924988, 29.60161018], [78.0506897, 29.59805107], [78.04393005, 29.59307098], [78.03975677, 29.58798027], [78.03650665, 29.58086014], [78.03730011, 29.57776833], [78.0407486, 29.5753212], [78.04264069, 29.57191277], [78.03721619, 29.5652504], [78.03826141, 29.56143951], [78.03688049, 29.55262947], [78.03256226, 29.55170059], [78.01927185, 29.55405045], [78.01661682, 29.55462074], [78.00351715, 29.5560894], [77.99415588, 29.55509949], [77.98802185, 29.54586029], [77.97885895, 29.55413055], [77.97705841, 29.55811119], [77.97675323, 29.56384087], [77.97881317, 29.5681591], [77.9807663, 29.56875992], [77.98404694, 29.57986069], [77.98457336, 29.58455276], [77.98375702, 29.58805084], [77.98232269, 29.58901024], [77.98101044, 29.58781052], [77.97881317, 29.58536911], [77.97704315, 29.58333015], [77.97299957, 29.58333969], [77.97268677, 29.58315086], [77.96955109, 29.58518982], [77.96736145, 29.58572006], [77.96631622, 29.5845108], [77.96337128, 29.58382988], [77.96174622, 29.5860405], [77.95987701, 29.58621025], [77.95598602, 29.58444977], [77.95320892, 29.58472061], [77.95157623, 29.58694077], [77.9498291, 29.58813095], [77.94822693, 29.5903492], [77.94728851, 29.59043121], [77.94832611, 29.59136963], [77.94854736, 29.59342957], [77.94876862, 29.5954895], [77.95092773, 29.59844017], [77.95323181, 29.60241127], [77.95240784, 29.60351944], [77.95101166, 29.60778999], [77.95040131, 29.61096954], [77.9496994, 29.61310959], [77.95186615, 29.61603928], [77.95568848, 29.61679077], [77.95822144, 29.61449051], [77.95986176, 29.61227989], [77.96240234, 29.60999107], [77.96633148, 29.61174965], [77.97025299, 29.61351967], [77.97464752, 29.61108971], [77.97683716, 29.61403847], [77.97541809, 29.61831093], [77.97493744, 29.62249947], [77.97351837, 29.62676239], [77.97312927, 29.63199043], [77.97471619, 29.63809967], [77.97702026, 29.64206123], [77.97537994, 29.64426994], [77.97445679, 29.64435005], [77.97168732, 29.64456749], [77.96750641, 29.64907074], [77.96537781, 29.65547943], [77.96673584, 29.6595211], [77.96788025, 29.66151047], [77.96891785, 29.66246033], [77.96913147, 29.66451073], [77.96936035, 29.66657066], [77.9704895, 29.66856956], [77.97162628, 29.67053986], [77.97277069, 29.67253113], [77.97207642, 29.67465973], [77.97218323, 29.6756897], [77.97126007, 29.67576981], [77.9691925, 29.67385101], [77.9631958, 29.67020035], [77.96228027, 29.67027092], [77.96156311, 29.67240906], [77.95831299, 29.67683029], [77.95668793, 29.67904091], [77.95411682, 29.68133163], [77.95176697, 29.68567085], [77.94727325, 29.68707085], [77.94539642, 29.68723106], [77.94470215, 29.68935966], [77.94377899, 29.68943024], [77.94491577, 29.69143295], [77.94306946, 29.69157982], [77.94328308, 29.69363976], [77.94628143, 29.69546127], [77.94359589, 29.69672966], [77.94114685, 29.70004082], [77.94229126, 29.70203018], [77.9462204, 29.70376968], [77.95198059, 29.70536995], [77.94943237, 29.70766258], [77.94245148, 29.71240044], [77.94081879, 29.71459961], [77.93895721, 29.71475983], [77.93665314, 29.71391106], [77.93049622, 29.71305275], [77.92722321, 29.71458054], [77.92491913, 29.71265984], [77.92015839, 29.71385956], [77.91622925, 29.71165085], [77.91072845, 29.70549011], [77.90962982, 29.7063694], [77.90804291, 29.70528984], [77.9095459, 29.70384026], [77.9083786, 29.70286942], [77.90634918, 29.70409966], [77.90483856, 29.7025528], [77.91020966, 29.69893837], [77.89994049, 29.69782066], [77.88683319, 29.70070076], [77.88218689, 29.70000267], [77.87722778, 29.70038986], [77.87387848, 29.70197105], [77.87003326, 29.69878006], [77.86991119, 29.69400978], [77.8662262, 29.69341087], [77.85851288, 29.68806076], [77.85405731, 29.68890953], [77.84863281, 29.68418121], [77.84706879, 29.68062973], [77.84294128, 29.68130112], [77.8406601, 29.67935944], [77.83843994, 29.67551994], [77.83426666, 29.67188263], [77.82897186, 29.6693306], [77.82129669, 29.66899109], [77.81108093, 29.67248917], [77.80448914, 29.67690086], [77.79251862, 29.68192101], [77.78916931, 29.68588066], [77.7974472, 29.6978302], [77.79492188, 29.70046043], [77.78269196, 29.70832062], [77.76980591, 29.70992088], [77.76203918, 29.71178818], [77.75891113, 29.71342087], [77.75771332, 29.71591949], [77.7637558, 29.72610092], [77.76792145, 29.73056984], [77.76925659, 29.73464966], [77.76735687, 29.73781013], [77.76187134, 29.74382019], [77.76085663, 29.75270081], [77.76165009, 29.75576019], [77.76571655, 29.76371002], [77.76352692, 29.77036095], [77.76539612, 29.77573013], [77.7607193, 29.77877998], [77.76053619, 29.78128052], [77.76470184, 29.78545952], [77.75296021, 29.79743958], [77.74932861, 29.80435944], [77.74214935, 29.80952072], [77.74128723, 29.81141853], [77.74398804, 29.81628036], [77.74234009, 29.82463264], [77.73895264, 29.83027077], [77.73203278, 29.83455086], [77.72918701, 29.83756065], [77.73092651, 29.84190178], [77.73005676, 29.85308075], [77.71334839, 29.85647964], [77.70957947, 29.8594799], [77.7060318, 29.86374092], [77.70326233, 29.86767006], [77.70201874, 29.8717804], [77.70316315, 29.87845039], [77.70250702, 29.88570023], [77.70301819, 29.88975906], [77.71105194, 29.88812065], [77.71302032, 29.89157295], [77.71752167, 29.89463043], [77.72009277, 29.90279007], [77.72483063, 29.90590096], [77.727211, 29.90904236], [77.73111725, 29.91129112], [77.73301697, 29.91348076], [77.72956085, 29.92280006], [77.72879791, 29.92856026], [77.72416687, 29.9300518], [77.71894073, 29.93284035], [77.71768188, 29.93495178], [77.72067261, 29.93902969], [77.72541809, 29.94351959], [77.72898102, 29.94561958], [77.72946167, 29.9518795], [77.7326889, 29.95498085], [77.74014282, 29.95890045], [77.74347687, 29.96377945], [77.74495697, 29.96759987], [77.744133, 29.97186089], [77.73100281, 29.98433113], [77.73007965, 29.98745155], [77.736763, 29.99072075], [77.74080658, 29.99411964], [77.74323273, 30.00596046], [77.74462128, 30.00880241], [77.74642944, 30.01134109], [77.74912262, 30.01410103], [77.75325012, 30.01736069], [77.75756073, 30.01951981], [77.75974274, 30.02042961], [77.76288605, 30.02163124], [77.76779938, 30.02293968], [77.76944733, 30.02384758], [77.7722702, 30.0262928], [77.77353668, 30.02956963], [77.77388763, 30.03210068], [77.77326202, 30.03303909], [77.77255249, 30.03370094], [77.7700882, 30.03688049], [77.76570129, 30.0396595], [77.76389313, 30.04216957], [77.7620163, 30.04318047], [77.75982666, 30.0449295], [77.75820923, 30.04654121], [77.75757599, 30.04823112], [77.75833893, 30.05050087], [77.76148987, 30.05544281], [77.76442719, 30.06088066], [77.76531982, 30.06306076], [77.76793671, 30.06694031], [77.7690506, 30.06809998], [77.76978302, 30.06838036], [77.77189636, 30.07249069], [77.77337646, 30.07386017], [77.77523041, 30.07631111], [77.77585602, 30.07765007], [77.77729797, 30.08240128], [77.77868652, 30.08543968], [77.78005219, 30.08916283], [77.78174591, 30.09086037], [77.78276062, 30.09325981], [77.78513336, 30.09678078], [77.78595734, 30.09910965], [77.78643799, 30.09996986], [77.78956604, 30.10153008], [77.79186249, 30.10185051], [77.79392242, 30.10108757], [77.79503632, 30.10061073], [77.7977066, 30.09885979], [77.79873657, 30.09786034], [77.80101776, 30.09617805], [77.80278015, 30.09456062], [77.80413055, 30.09363937], [77.80548096, 30.09196091], [77.80806732, 30.09020996], [77.81070709, 30.08954811], [77.81307983, 30.08963013], [77.81519318, 30.09016991], [77.81790924, 30.09157944], [77.81996918, 30.09363937], [77.82186127, 30.09694862], [77.82189178, 30.09888077], [77.82395172, 30.10127068], [77.82530975, 30.10473061], [77.82656097, 30.10552025], [77.82842255, 30.10612106], [77.83058167, 30.10724068], [77.83283234, 30.10800934], [77.8360672, 30.10995293], [77.83747864, 30.11143112], [77.83853149, 30.11227036], [77.84274292, 30.11677933], [77.84361267, 30.11831284], [77.84468842, 30.11950111], [77.84723663, 30.12346077], [77.84809875, 30.1245327], [77.85051727, 30.12865829], [77.85233307, 30.13092995], [77.85527039, 30.13362122], [77.8579483, 30.13809967], [77.85909271, 30.14048195], [77.85990143, 30.1415596], [77.8613205, 30.1440506], [77.86444092, 30.14993858], [77.86499786, 30.15209961], [77.86548615, 30.15507126], [77.86871338, 30.15880013], [77.87204742, 30.16303062], [77.87332916, 30.16393089], [77.87664032, 30.16695976], [77.87798309, 30.16860008], [77.8793869, 30.16967964], [77.88793945, 30.17874908], [77.89012146, 30.18037987], [77.89280701, 30.18342972], [77.89599609, 30.18629265], [77.89707184, 30.18822289], [77.89833069, 30.19226074], [77.8989563, 30.19487953], [77.89990997, 30.20401001], [77.90039825, 30.20578003], [77.90229797, 30.20976067], [77.90312958, 30.21306038], [77.90439606, 30.21520805], [77.90762329, 30.21698952], [77.91139221, 30.21877289], [77.91454315, 30.22180939], [77.9180603, 30.22479057], [77.92182159, 30.22970009], [77.923172, 30.23179817], [77.92713165, 30.23641968], [77.92932129, 30.23999023], [77.92977142, 30.24180984], [77.93026733, 30.24300194], [77.93148041, 30.24695969], [77.92823792, 30.24775124], [77.92539978, 30.24871063], [77.92386627, 30.24981117], [77.92189026, 30.2517395], [77.91996765, 30.2540493], [77.91684723, 30.25617027], [77.91362762, 30.25761032], [77.91030121, 30.25931168], [77.90795135, 30.26073074], [77.90363312, 30.26267815], [77.90029907, 30.26440811], [77.89636993, 30.26601028], [77.89164734, 30.26735115], [77.89021301, 30.26823997], [77.88220978, 30.27046967], [77.87985992, 30.27193069], [77.87397003, 30.27415085], [77.87148285, 30.27441978], [77.868927, 30.27210045], [77.86714172, 30.271101], [77.86554718, 30.27048111], [77.86103058, 30.27135086], [77.85788727, 30.27237129], [77.85587311, 30.27393913], [77.85189056, 30.27658272], [77.84755707, 30.27877045], [77.84246826, 30.28033066], [77.84030151, 30.28121185], [77.83629608, 30.28228951], [77.83277893, 30.28378105], [77.8286972, 30.28467941], [77.82405853, 30.28635979], [77.8186264, 30.28918076], [77.81240845, 30.2907505], [77.80905151, 30.29217911], [77.80737305, 30.29362106], [77.80179596, 30.2959919], [77.79930878, 30.29763031], [77.7889328, 30.30365944], [77.78430939, 30.30549049], [77.78320313, 30.30641937], [77.77848053, 30.30929947], [77.7772522, 30.30987167], [77.77301025, 30.3130703], [77.76496124, 30.31736946], [77.76268005, 30.31849098], [77.76069641, 30.31913948], [77.75866699, 30.3200798], [77.75705719, 30.320961], [77.751297, 30.32464981], [77.74828339, 30.32537079], [77.7425766, 30.32760811], [77.74017334, 30.3283329], [77.73771667, 30.32819176], [77.73581696, 30.32925034], [77.73239136, 30.32991028], [77.7297287, 30.33147812], [77.72553253, 30.33291054], [77.72265625, 30.33415031], [77.72088623, 30.33542824], [77.71766663, 30.33609962], [77.71537781, 30.33687973], [77.71308899, 30.33793259], [77.71077728, 30.33876038], [77.70993805, 30.33991051], [77.70773315, 30.34132195], [77.70491791, 30.34387016], [77.70108032, 30.34747124], [77.6977005, 30.35031128], [77.6971283, 30.3516407], [77.69425201, 30.35534286], [77.69341278, 30.35569191], [77.69277954, 30.35724068], [77.69126892, 30.35824013], [77.69064331, 30.35972977], [77.68707275, 30.36457825], [77.68596649, 30.36688042], [77.68434143, 30.36816025], [77.68390656, 30.3696003], [77.68273926, 30.37138939], [77.6802597, 30.37434006], [77.67977142, 30.37560081], [77.67751312, 30.37912941], [77.67700195, 30.38080025], [77.67386627, 30.38459969], [77.6733017, 30.38565063], [77.67183685, 30.38394165], [77.66880035, 30.38352966], [77.66687775, 30.38365936], [77.66581726, 30.38343811], [77.66410828, 30.3839798], [77.66320801, 30.38473129], [77.66348267, 30.38557816], [77.66369629, 30.38751984], [77.66300964, 30.39057159], [77.66243744, 30.39167023], [77.66153717, 30.3926506], [77.66126251, 30.39323044], [77.66034698, 30.39374161], [77.65969086, 30.39393806], [77.65805817, 30.39401054], [77.65529633, 30.39477921], [77.65193176, 30.39550018], [77.64762115, 30.39807129], [77.64569092, 30.40199089], [77.64450836, 30.40257835], [77.643013, 30.40454292], [77.64138031, 30.40536118], [77.63986969, 30.40640068], [77.63941193, 30.40710068], [77.63661957, 30.40920067], [77.63569641, 30.41012192], [77.63421631, 30.41087914], [77.63288116, 30.41117287], [77.63053131, 30.4108696], [77.62552643, 30.4070816], [77.62354279, 30.40516281], [77.62207031, 30.4047699], [77.61818695, 30.40533066], [77.61694336, 30.4052906], [77.61450958, 30.40582085], [77.61122894, 30.40757179], [77.60916138, 30.41040993], [77.60822296, 30.41019249], [77.60707092, 30.40963173], [77.60597229, 30.40948105], [77.60411072, 30.40875053], [77.60273743, 30.40841293], [77.59896851, 30.40891075], [77.59778595, 30.4088707], [77.59246063, 30.40949059], [77.59107208, 30.40904999], [77.58777618, 30.40846252], [77.58699036, 30.40806007], [77.58638763, 30.40801048], [77.58467865, 30.40878105], [77.58436584, 30.40998077], [77.57971191, 30.41192055], [77.57753754, 30.41245842], [77.5749588, 30.41174126], [77.5728302, 30.41033173], [77.57112122, 30.40863991], [77.56958008, 30.40789986], [77.56858826, 30.40682983], [77.56710815, 30.40484047], [77.56305695, 30.40448952], [77.5622406, 30.41006279], [77.56288147, 30.41707993], [77.56790161, 30.4217186], [77.57463074, 30.42651939], [77.58106995, 30.43029976], [77.59041595, 30.43378067], [77.60375214, 30.43744087], [77.61200714, 30.43840027], [77.61672211, 30.43623161], [77.63054657, 30.43615913], [77.63333893, 30.43976974], [77.63568115, 30.44433975], [77.63783264, 30.44948769], [77.6402359, 30.45235062], [77.64665222, 30.45245934], [77.65320587, 30.44954109], [77.66160583, 30.44878006], [77.67906952, 30.45173073], [77.68219757, 30.45769119], [77.69008636, 30.46294022], [77.69918823, 30.4686985], [77.70466614, 30.47340012], [77.71122742, 30.47727013], [77.72144318, 30.47776985], [77.72927856, 30.48233986], [77.73658752, 30.48725128], [77.74752808, 30.49404907], [77.75504303, 30.49832916], [77.76344299, 30.50024986], [77.76761627, 30.5043602], [77.78819275, 30.5060997], [77.79389954, 30.50860023], [77.79917908, 30.51139069], [77.80056, 30.51316071], [77.80197144, 30.51538086], [77.80412292, 30.52037048], [77.80502319, 30.52478027], [77.81064606, 30.53318024], [77.81220245, 30.5380497], [77.80995941, 30.5440197], [77.80680847, 30.5493412], [77.80687714, 30.55426025], [77.80586243, 30.56073952], [77.80323792, 30.56377983], [77.79827118, 30.56413078], [77.7951889, 30.5611496], [77.79058838, 30.56025124], [77.78637695, 30.56139946], [77.77826691, 30.5573597], [77.77459717, 30.55890083], [77.77091217, 30.56240082], [77.7665329, 30.56349945], [77.76184845, 30.56298828], [77.75727081, 30.56558037], [77.75353241, 30.57023048], [77.75187683, 30.57458115], [77.74948883, 30.57996941], [77.74619293, 30.5844326], [77.74362946, 30.58975983], [77.73863983, 30.59287071], [77.73192596, 30.5961895], [77.72952271, 30.59838295], [77.73126984, 30.60152054], [77.73159027, 30.6047802], [77.73210907, 30.60712814], [77.73478699, 30.60816002], [77.73832703, 30.60808945], [77.74246979, 30.6071701], [77.74971008, 30.60136986], [77.75444031, 30.60074997], [77.7572403, 30.60479927], [77.75563049, 30.61619949], [77.75660706, 30.62032127], [77.76132965, 30.61944962], [77.76711273, 30.61818123], [77.7722168, 30.61783028], [77.77864838, 30.61787987], [77.78199005, 30.61935806], [77.77960968, 30.62268066], [77.77645874, 30.62613106], [77.77127838, 30.62848091], [77.77231598, 30.63237953], [77.77545166, 30.63746834], [77.77497864, 30.64112091], [77.77217102, 30.64496994], [77.76830292, 30.65147972], [77.77025604, 30.65514946], [77.7749176, 30.65845108], [77.77905273, 30.66377068], [77.77706146, 30.66558838], [77.77423096, 30.66566086], [77.77220917, 30.66539192], [77.76950073, 30.66419029], [77.76590729, 30.66527939], [77.76294708, 30.66843033], [77.75881195, 30.67238998], [77.75419617, 30.67605972], [77.74788666, 30.67814064], [77.74275208, 30.68056107], [77.7365799, 30.68284988], [77.73340607, 30.68582916], [77.73339844, 30.69350052], [77.73358154, 30.69745255], [77.73574066, 30.70157814], [77.73690033, 30.70500946], [77.74038696, 30.7071228], [77.7410965, 30.71066093], [77.7372818, 30.71346855], [77.73432922, 30.71669006], [77.73227692, 30.72070122], [77.73068237, 30.72447968], [77.7252121, 30.72734833], [77.72219086, 30.73061943], [77.72249603, 30.73335838], [77.72171021, 30.73635292], [77.72033691, 30.7382412], [77.71765137, 30.73886108], [77.71533966, 30.73826027], [77.71289062, 30.73945236], [77.71163177, 30.7420826], [77.70928192, 30.74415016], [77.70723724, 30.74552917], [77.70435333, 30.74570084], [77.700737, 30.74496841], [77.69770813, 30.74496841], [77.69394684, 30.74617004], [77.69158936, 30.74831009], [77.6904068, 30.75132942], [77.6917572, 30.75505066], [77.69300842, 30.75785065], [77.69148254, 30.76025963], [77.68828583, 30.76866913], [77.69265747, 30.77141953], [77.69843292, 30.77342033], [77.70452881, 30.77902031], [77.70864868, 30.78450966], [77.71539307, 30.79421806], [77.71710205, 30.79949951], [77.71806335, 30.80509949], [77.71942139, 30.80830956], [77.72408295, 30.81104088], [77.7265625, 30.8144207], [77.73088837, 30.81939125], [77.73403168, 30.82406807], [77.73744965, 30.82629967], [77.74038696, 30.82766914], [77.74440765, 30.82985115], [77.74407196, 30.83624268], [77.74089813, 30.84015083], [77.73338318, 30.8474884], [77.73146057, 30.85077095], [77.73336792, 30.85420036], [77.73573303, 30.85704994], [77.73958588, 30.86018944], [77.74167633, 30.86420059], [77.74101257, 30.86992073], [77.74085236, 30.87433052], [77.74178314, 30.87828064], [77.74452209, 30.88119125], [77.74774933, 30.88227081], [77.75105286, 30.88272095], [77.75454712, 30.88244057], [77.75820923, 30.88047981], [77.76026917, 30.87784195], [77.76177979, 30.87508965], [77.76278687, 30.86816025], [77.76516724, 30.86517906], [77.76899719, 30.86295128], [77.77359772, 30.86103058], [77.77852631, 30.86000061], [77.78936768, 30.85854912], [77.7889328, 30.86495972], [77.78705597, 30.86812019], [77.78350067, 30.87206078], [77.78362274, 30.87865067], [77.78412628, 30.88215065], [77.78443909, 30.88837051], [77.78543854, 30.89335823], [77.78639984, 30.8960495], [77.79088593, 30.90067101], [77.79463196, 30.90348053], [77.7989502, 30.90879059], [77.80084991, 30.91274071], [77.79741669, 30.91674995], [77.79498291, 30.92043114], [77.79561615, 30.92379951], [77.79337311, 30.92598152], [77.79102325, 30.92613029], [77.78874207, 30.92628098], [77.78185272, 30.92621994], [77.77449036, 30.92533112], [77.7716217, 30.92419052], [77.76725769, 30.92048073], [77.76317596, 30.92015076], [77.75824738, 30.92038155], [77.75219727, 30.92095947], [77.74559784, 30.92230988], [77.74736786, 30.92872047], [77.74649811, 30.9339695], [77.74357605, 30.93522835], [77.73924255, 30.93667984], [77.73665619, 30.9396019], [77.73568726, 30.94202042], [77.73487854, 30.94401169], [77.73327637, 30.94950104], [77.73457336, 30.95956993], [77.73634338, 30.96359062], [77.74196625, 30.96764183], [77.75392151, 30.97684288], [77.76387787, 30.97698975], [77.77094269, 30.97566032], [77.77838135, 30.97232056], [77.78761292, 30.96572113], [77.79659271, 30.95843124], [77.80227661, 30.95510101], [77.80754089, 30.95371056], [77.81260681, 30.95279121], [77.8171463, 30.95356941], [77.81932068, 30.95684052], [77.81891632, 30.96009064], [77.81639099, 30.96198273], [77.81324768, 30.96244812], [77.80462646, 30.96099091], [77.80158234, 30.96356964], [77.79740143, 30.96775818], [77.79641724, 30.96982002], [77.79728699, 30.97295952], [77.79872131, 30.97611809], [77.80319214, 30.97970963], [77.80523682, 30.98163986], [77.80621338, 30.98348045], [77.80648041, 30.98503113], [77.80621338, 30.98806], [77.80754089, 30.99384117], [77.81091309, 30.9953804], [77.81360626, 30.99892044], [77.81028748, 31.00213051], [77.81005096, 31.00521088], [77.82470703, 31.0051899], [77.82533264, 31.00813293], [77.82270813, 31.01180077], [77.81884766, 31.01579094], [77.82106018, 31.02108002], [77.82160187, 31.02992058], [77.81880951, 31.03230095], [77.81511688, 31.03392982], [77.81067657, 31.04359055], [77.80502319, 31.05406952], [77.80491638, 31.05877113], [77.80060577, 31.06208038], [77.8068924, 31.06233025], [77.80960846, 31.06137085], [77.80947876, 31.05973244], [77.81469727, 31.06090164], [77.81954956, 31.06491089], [77.82472992, 31.07443047], [77.8310318, 31.07703972], [77.83746338, 31.07751083], [77.84282684, 31.0812912], [77.85037994, 31.09516907], [77.8501358, 31.10420036], [77.85153198, 31.11096954], [77.85787201, 31.11623955], [77.87275696, 31.12321091], [77.87872314, 31.12467194], [77.87905884, 31.13158989], [77.88040161, 31.13743019], [77.88575745, 31.14307022], [77.88970947, 31.14896965], [77.88748932, 31.15470123], [77.89279175, 31.15726852], [77.9021759, 31.15882111], [77.9094162, 31.15550041], [77.91468811, 31.15657806], [77.93443298, 31.16729164], [77.93921661, 31.16730118], [77.9412384, 31.17116165], [77.94602203, 31.17617035], [77.95475769, 31.1787796], [77.96938324, 31.1651516], [77.97896576, 31.16644096], [77.98522949, 31.16802025], [77.9925766, 31.16703033], [78.00772095, 31.1570797], [78.01423645, 31.15493965], [78.01654816, 31.15850067], [78.01528168, 31.16615105], [78.01622009, 31.1715126], [78.02688599, 31.18019104], [78.029953, 31.18531036], [78.03874969, 31.18715096], [78.03967285, 31.18750954], [78.05383301, 31.19293022], [78.05915833, 31.19236946], [78.07110596, 31.19276047], [78.07549286, 31.19291115], [78.08007813, 31.19070816], [78.08773804, 31.19079971], [78.09237671, 31.19283104], [78.10079193, 31.19979095], [78.10688019, 31.20248985], [78.10984802, 31.2056694], [78.11380005, 31.20623016], [78.11915588, 31.21404076], [78.13490295, 31.21611977], [78.137146, 31.22242165], [78.14360809, 31.22407913], [78.14583588, 31.22688103], [78.14782715, 31.2315712], [78.15313721, 31.23068047], [78.15542603, 31.23028755], [78.16044617, 31.23192024], [78.16308594, 31.23150063], [78.16581726, 31.23106194], [78.17141724, 31.23180962], [78.17648315, 31.23003006], [78.18492126, 31.22332954], [78.18756104, 31.22221947], [78.19284058, 31.22291183], [78.20027161, 31.22571945], [78.20398712, 31.23409081], [78.20681763, 31.2372303], [78.21209717, 31.23855019], [78.21843719, 31.23871994], [78.23258972, 31.23501968], [78.23764801, 31.2397995], [78.23751068, 31.24394035], [78.24263, 31.24336243], [78.24820709, 31.24665833], [78.2497406, 31.25055122], [78.25324249, 31.25287056], [78.25495911, 31.25659943], [78.25814056, 31.26036263], [78.26902008, 31.2713604], [78.27815247, 31.26666069], [78.28845978, 31.26420021], [78.29341888, 31.2660408], [78.29551697, 31.27285957], [78.29680634, 31.2844696], [78.29836273, 31.28820992], [78.30632782, 31.28623962], [78.31693268, 31.28507805], [78.32663727, 31.28824043], [78.33609009, 31.2874794], [78.34247589, 31.28897285], [78.3474884, 31.29011917], [78.35632324, 31.29087067], [78.36335754, 31.2901001], [78.3692627, 31.28790092], [78.37346649, 31.27920914], [78.38136292, 31.28147125], [78.38327026, 31.2743206], [78.38619232, 31.26963043], [78.39308167, 31.2622776], [78.39134979, 31.25299072], [78.3975296, 31.24779129], [78.4050827, 31.24867058], [78.41438293, 31.25090981], [78.41945648, 31.25988007], [78.42706299, 31.25597954], [78.4316864, 31.24959946], [78.44413757, 31.24419975], [78.45722198, 31.22781181], [78.46656799, 31.22093964], [78.46721649, 31.21184921], [78.47010803, 31.20375061], [78.47698212, 31.20510292], [78.48657227, 31.20417023], [78.51413727, 31.20392036], [78.537117, 31.20671082], [78.55024719, 31.21849251], [78.55632782, 31.22738075], [78.56189728, 31.22960091], [78.56658173, 31.23373985], [78.57939911, 31.23500252], [78.58392334, 31.23430061], [78.59536743, 31.23639107], [78.6006012, 31.23585129], [78.61004639, 31.23105049], [78.61329651, 31.22743988], [78.61711121, 31.22524834], [78.62831879, 31.22191811], [78.63445282, 31.2218895], [78.63600159, 31.2195797], [78.63800812, 31.20838928], [78.64549255, 31.20251846], [78.64769745, 31.19466972], [78.65067291, 31.19785118], [78.65983582, 31.20325089], [78.66575623, 31.20247269], [78.67608643, 31.20318985], [78.6955719, 31.19629097], [78.70069885, 31.19639015], [78.70746613, 31.19497108], [78.71302795, 31.1966629], [78.72038269, 31.19701958], [78.74945068, 31.1943512], [78.75759125, 31.1946907], [78.76460266, 31.1959095], [78.77088928, 31.19729996], [78.78881073, 31.20445061], [78.79503632, 31.20503998], [78.8001709, 31.20237923], [78.80316925, 31.19923019], [78.80111694, 31.1939106], [78.7980423, 31.18894958], [78.7975769, 31.18250275], [78.80050659, 31.1782608], [78.81170654, 31.16941071], [78.81021881, 31.16386032], [78.81587219, 31.15393066], [78.81873322, 31.14721107], [78.82472229, 31.14355087], [78.82897949, 31.13633919], [78.83777618, 31.13068962], [78.84432983, 31.12804031], [78.85202026, 31.12621117], [78.86225128, 31.11240959], [78.87139893, 31.10732079], [78.88004303, 31.10383987], [78.88417816, 31.10423279], [78.89074707, 31.1060791], [78.89679718, 31.10563087], [78.89942932, 31.10759926], [78.90058136, 31.11206055], [78.90379333, 31.11547089], [78.90779114, 31.11631966], [78.91265869, 31.11618042], [78.92047119, 31.10758972], [78.93257141, 31.10697937], [78.93752289, 31.10534286], [78.94211578, 31.10502815], [78.95243073, 31.10840988], [78.95582581, 31.1108799], [78.96565247, 31.1153698], [78.98486328, 31.11647034], [78.99079895, 31.11709023], [78.99658203, 31.11533928], [78.99669647, 31.11618042], [78.99669647, 31.11758995], [78.99077606, 31.13087845], [78.98919678, 31.13735962], [78.98706055, 31.14060974], [78.98480988, 31.14093971], [78.97808838, 31.1456604], [78.97579956, 31.15070915], [78.97767639, 31.15483093], [78.97747803, 31.17016029], [78.97466278, 31.17810059], [78.97187042, 31.18237114], [78.96845245, 31.18346977], [78.96615601, 31.18599129], [78.96092224, 31.18643188], [78.95284271, 31.1898098], [78.94621277, 31.19355965], [78.94486237, 31.19693947], [78.94168091, 31.20080185], [78.93585205, 31.20568085], [78.9332428, 31.21455193], [78.93506622, 31.2191906], [78.93512726, 31.22236252], [78.9196167, 31.22309113], [78.91564941, 31.2251606], [78.90991211, 31.23388863], [78.90585327, 31.2501812], [78.90688324, 31.25918961], [78.90891266, 31.25885963], [78.91308594, 31.26072121], [78.91409302, 31.26163101], [78.91459656, 31.26231956], [78.91664886, 31.26662827], [78.91686249, 31.26797295], [78.91673279, 31.27500153], [78.91619873, 31.27655983], [78.91599274, 31.28717041], [78.92354584, 31.30145073], [78.92479706, 31.30668068], [78.92518616, 31.3143692], [78.92310333, 31.32538986], [78.92537689, 31.33176041], [78.92626953, 31.33242989], [78.9302063, 31.33788109], [78.93696594, 31.34247971], [78.95223999, 31.34823036], [78.95366669, 31.34880066], [78.96124268, 31.35203171], [78.96331024, 31.35238647], [78.96827698, 31.35324097], [78.96879578, 31.35301971], [78.9805603, 31.35698128], [78.98967743, 31.36183929], [78.99160767, 31.36403084], [78.99337006, 31.36751175], [78.99310303, 31.37428284], [78.99456787, 31.37927055], [79.00682831, 31.40061951], [79.01183319, 31.40654945], [79.01374817, 31.40859985], [79.01478577, 31.40904999], [79.01544189, 31.41019058], [79.01580811, 31.41109085], [79.02150726, 31.41455078], [79.02720642, 31.4202919], [79.02823639, 31.42073059], [79.02897644, 31.42274094], [79.02964783, 31.42297935], [79.0305481, 31.42399979], [79.0322113, 31.42700195], [79.03314209, 31.42736053], [79.03417206, 31.42801094], [79.03396606, 31.44458008], [79.0355072, 31.45318031], [79.0369873, 31.45737076], [79.03823853, 31.45875931], [79.0405426, 31.46214867], [79.04519653, 31.46812057], [79.04785919, 31.47038269], [79.05210114, 31.47162247], [79.05336761, 31.4720192], [79.05677795, 31.47225952], [79.06028748, 31.46865273], [79.06211853, 31.46759987], [79.06214905, 31.4666996], [79.0634613, 31.46603966], [79.06452179, 31.46513939], [79.06558228, 31.46424294], [79.06611633, 31.46379089], [79.07621002, 31.45825005], [79.08917236, 31.45523834], [79.08966827, 31.4548111], [79.09075165, 31.45438004], [79.09127045, 31.45347023], [79.09394836, 31.45238113], [79.09423065, 31.45170975], [79.10009003, 31.44793129], [79.12255859, 31.44151115], [79.12648773, 31.43978119], [79.12666321, 31.43925095], [79.12886047, 31.43873024], [79.1296463, 31.43807983], [79.13288879, 31.43471909], [79.13345337, 31.43359947], [79.135849, 31.43025017], [79.13640594, 31.43003273], [79.14189148, 31.42002106], [79.14266968, 31.41945076], [79.14370728, 31.41722107], [79.1447525, 31.41609955], [79.14594269, 31.41473961], [79.14692688, 31.41341972], [79.14862061, 31.41114807], [79.15788269, 31.4040699], [79.1582489, 31.40336037], [79.16345215, 31.39891815], [79.17005157, 31.38646126], [79.17092896, 31.38480949], [79.17160034, 31.38418007], [79.17228699, 31.38213921], [79.17418671, 31.37737083], [79.17495728, 31.37693024], [79.17511749, 31.37647057], [79.17565918, 31.37581062], [79.17619324, 31.3751297], [79.17671967, 31.37492943], [79.17756653, 31.37220955], [79.17887878, 31.37133026], [79.17993164, 31.37087822], [79.18183899, 31.3674984], [79.18608093, 31.36374092], [79.18818665, 31.36001015], [79.18968201, 31.35894012], [79.19107056, 31.35796928], [79.19193268, 31.35653114], [79.19312286, 31.35571289], [79.1942215, 31.35495949], [79.19477844, 31.35362244], [79.19816589, 31.35195923], [79.2073822, 31.34632111], [79.21055603, 31.34501076], [79.21128082, 31.34482002], [79.21214294, 31.34456062], [79.21504974, 31.34267807], [79.22164154, 31.33730125], [79.22265625, 31.33484268], [79.22271729, 31.33157921], [79.22142792, 31.3298912], [79.22099304, 31.32925034], [79.22088623, 31.32843971], [79.22054291, 31.32793999], [79.22115326, 31.32586288], [79.22062683, 31.32450104], [79.22083282, 31.32286072], [79.22104645, 31.32028008], [79.22146606, 31.31939125], [79.22306824, 31.31736183], [79.22358704, 31.31692123], [79.2259903, 31.3151207], [79.22601318, 31.31422806], [79.23847961, 31.30421066], [79.24008942, 31.30299187], [79.24063873, 31.30185127], [79.24809265, 31.29661942], [79.24845123, 31.29500008], [79.24901581, 31.29454041], [79.24951935, 31.28961945], [79.24772644, 31.28534126], [79.24642944, 31.283741], [79.24578094, 31.28321075], [79.23710632, 31.27574921], [79.2338028, 31.2691803], [79.23342133, 31.26618958], [79.23287201, 31.26194191], [79.23388672, 31.25403976], [79.23734283, 31.25068092], [79.24333954, 31.24693108], [79.24563599, 31.2466507], [79.24743652, 31.24690056], [79.25147247, 31.24654961], [79.25280762, 31.24609947], [79.2546463, 31.24635124], [79.25518799, 31.24658012], [79.26277924, 31.24529076], [79.26445007, 31.24394035], [79.2651825, 31.24259949], [79.26628876, 31.23945999], [79.26683044, 31.23924065], [79.26737976, 31.23743057], [79.2678833, 31.23720932], [79.26863098, 31.23661041], [79.27111053, 31.23181915], [79.27217102, 31.23159981], [79.27229309, 31.23093987], [79.27281952, 31.23073959], [79.27664948, 31.22282982], [79.27719116, 31.22261047], [79.27877808, 31.21749115], [79.28629303, 31.19990158], [79.28843689, 31.19563293], [79.28814697, 31.18952751], [79.28778076, 31.18840027], [79.28494263, 31.18567085], [79.28304291, 31.18157959], [79.28211975, 31.18091011], [79.28212738, 31.17930984], [79.28270721, 31.17548943], [79.28318024, 31.17436028], [79.28489685, 31.17010117], [79.28569031, 31.16966057], [79.28676605, 31.1687603], [79.28942871, 31.16426277], [79.2918396, 31.16249084], [79.29374695, 31.15909958], [79.29611206, 31.15710068], [79.29728699, 31.15418053], [79.29780579, 31.15395927], [79.29962158, 31.14924049], [79.30761719, 31.14210129], [79.30869293, 31.1405201], [79.30869293, 31.14006042], [79.31156158, 31.13918114], [79.31275177, 31.13915062], [79.3143158, 31.13894081], [79.31790161, 31.13879013], [79.31891632, 31.13902092], [79.32132721, 31.13747025], [79.32184601, 31.13589096], [79.32263947, 31.13544083], [79.32316589, 31.13521004], [79.32509613, 31.12981033], [79.32614899, 31.12939072], [79.33059692, 31.12873077], [79.3379364, 31.12927055], [79.34082031, 31.12882996], [79.34187317, 31.12861252], [79.3447876, 31.12749863], [79.34635925, 31.1264019], [79.34996796, 31.12405014], [79.35038757, 31.1237812], [79.35389709, 31.12177277], [79.35559845, 31.12129021], [79.36061859, 31.12018013], [79.36192322, 31.12066078], [79.36994934, 31.12041092], [79.37709808, 31.12079048], [79.37889099, 31.12041473], [79.37918854, 31.12034988], [79.3818512, 31.11835098], [79.38408661, 31.11231041], [79.38511658, 31.11000061], [79.38588715, 31.10958099], [79.38639832, 31.1093502], [79.38709259, 31.10754013], [79.38967896, 31.0987606], [79.39124298, 31.08243942], [79.39169312, 31.08118057], [79.39235687, 31.0798111], [79.39469147, 31.07963181], [79.39966583, 31.0803299], [79.40042114, 31.08009911], [79.40174103, 31.0798912], [79.40624237, 31.07698822], [79.40734863, 31.07338905], [79.40788269, 31.07316971], [79.40840912, 31.07295036], [79.40842438, 31.07254219], [79.40846252, 31.07134247], [79.40888214, 31.05649185], [79.40975952, 31.05236053], [79.41136169, 31.04730988], [79.41308594, 31.03755188], [79.42175293, 31.03582954], [79.42471313, 31.0363121], [79.43322754, 31.03771019], [79.45729828, 31.03950119], [79.46109772, 31.0403595], [79.46589661, 31.04137039], [79.47200012, 31.04026031], [79.47981262, 31.03807068], [79.48735809, 31.04105949], [79.4936676, 31.04087257], [79.49706268, 31.04136276], [79.50125885, 31.0391407], [79.50209045, 31.03800011], [79.50287628, 31.03757286], [79.50279236, 31.03051758], [79.50276184, 31.02763939], [79.50403595, 31.02584076], [79.50457764, 31.02561188], [79.5045929, 31.02491951], [79.50488281, 31.0238018], [79.50538635, 31.02357101], [79.50540161, 31.02312279], [79.50775909, 31.02179909], [79.50776672, 31.02135086], [79.50830841, 31.02089119], [79.50895691, 31.02081108], [79.50940704, 31.02053642], [79.51098633, 31.01958084], [79.51463318, 31.01721954], [79.51631927, 31.01622963], [79.51709747, 31.01486969], [79.51779175, 31.014431], [79.51860809, 31.01398087], [79.51860809, 31.01351166], [79.52033997, 31.0105896], [79.52137756, 31.00992966], [79.52192688, 31.00835037], [79.52246857, 31.00812149], [79.52266693, 31.00452042], [79.52078247, 30.99901581], [79.5194931, 30.99524117], [79.51938629, 30.99344063], [79.52307129, 30.99255943], [79.52753448, 30.99214554], [79.53134155, 30.99179077], [79.53613281, 30.99218941], [79.5377121, 30.99130058], [79.53752136, 30.98703957], [79.53546143, 30.98540688], [79.53520203, 30.98520279], [79.53325653, 30.98338127], [79.53131866, 30.97789001], [79.53096008, 30.97591019], [79.5311203, 30.97410011], [79.53298187, 30.97322083], [79.5329895, 30.97276115], [79.53430939, 30.97187042], [79.53431702, 30.97141075], [79.53536224, 30.9698391], [79.5358963, 30.96985245], [79.54062653, 30.96717072], [79.54141998, 30.96652031], [79.54142761, 30.96604919], [79.54168701, 30.96536255], [79.54338837, 30.96442986], [79.54393005, 30.96443939], [79.54738617, 30.96260262], [79.5484314, 30.96203041], [79.5501709, 30.96108055], [79.55045319, 30.96042061], [79.55123138, 30.96043015], [79.55361176, 30.95885849], [79.55957794, 30.95671844], [79.57572937, 30.95438957], [79.57688904, 30.95363998], [79.58058929, 30.95029068], [79.58059692, 30.94983292], [79.58139801, 30.94940186], [79.58139801, 30.94894028], [79.58244324, 30.94828033], [79.58285522, 30.94724655], [79.58352661, 30.94556046], [79.58481598, 30.94399071], [79.58724213, 30.94309044], [79.58957672, 30.94288826], [79.59031677, 30.94324493], [79.59243011, 30.94425964], [79.59384918, 30.94631004], [79.5943222, 30.94790077], [79.59654999, 30.94918633], [79.59895325, 30.95056915], [79.60360718, 30.95268059], [79.60591888, 30.95451164], [79.60617828, 30.95543289], [79.60679626, 30.95656013], [79.6078186, 30.95679092], [79.61575317, 30.96179962], [79.62423706, 30.96533012], [79.63033295, 30.96636963], [79.64261627, 30.96760941], [79.64940643, 30.97059059], [79.65003967, 30.97171974], [79.64982605, 30.97985077], [79.65045929, 30.98054123], [79.65159607, 30.98436165], [79.65394592, 30.9857502], [79.66256714, 30.98693085], [79.67124176, 30.98425102], [79.6932373, 30.98167992], [79.69373322, 30.98191071], [79.69638062, 30.98168945], [79.69687653, 30.98180962], [79.70477295, 30.98339081], [79.71411133, 30.98565102], [79.72479248, 30.99088097], [79.72609711, 30.99204063], [79.72646332, 30.99362946], [79.72695923, 30.99521255], [79.72775269, 30.99545097], [79.72918701, 30.9963398], [79.72930145, 30.99724007], [79.73221588, 31.00156975], [79.7325058, 31.00199127], [79.73420715, 31.00291061], [79.73459625, 31.00358009], [79.73808289, 31.0060997], [79.74214935, 31.00679016], [79.74559021, 31.0061512], [79.7505722, 31.00119019], [79.75139618, 30.99893188], [79.76032257, 30.99311829], [79.77855682, 30.98826027], [79.78452301, 30.98666954], [79.78553009, 30.98641014], [79.7923584, 30.98423958], [79.80499268, 30.97776985], [79.80941772, 30.97733116], [79.81072998, 30.97756004], [79.81606293, 30.97929001], [79.81807709, 30.9801712], [79.8216095, 30.98204613], [79.8234787, 30.98304176], [79.83030701, 30.98398018], [79.84104919, 30.9808712], [79.8467865, 30.98135948], [79.85202789, 30.98023987], [79.85492706, 30.97891045], [79.85597229, 30.97735023], [79.85626221, 30.97665024], [79.85756683, 30.97575951], [79.85864258, 30.97507095], [79.85968781, 30.97125053], [79.86075592, 30.97037125], [79.86155701, 30.96990967], [79.86157227, 30.96920967], [79.86206818, 30.96899033], [79.86380005, 30.96606064], [79.8645401, 30.96439171], [79.86532593, 30.96178055], [79.8659668, 30.96120071], [79.86688995, 30.95838165], [79.86875153, 30.95275116], [79.86929321, 30.95253944], [79.87007904, 30.94983292], [79.87065887, 30.94942093], [79.87120056, 30.94919014], [79.87358856, 30.9410305], [79.87464142, 30.93879128], [79.87471008, 30.9304409], [79.87525177, 30.93021011], [79.8765564, 30.92930031], [79.87761688, 30.9263916], [79.87998962, 30.92527962], [79.8809967, 30.92510986], [79.88154602, 30.9250927], [79.89253235, 30.9235096], [79.89411163, 30.92329979], [79.89753723, 30.92174911], [79.89937592, 30.91809845], [79.90203094, 30.91566086], [79.90310669, 30.91180992], [79.90603638, 30.90957069], [79.90677643, 30.90727997], [79.90812683, 30.90325165], [79.91078186, 30.90056038], [79.91131592, 30.89920998], [79.91159058, 30.89874077], [79.91504669, 30.89221954], [79.92108917, 30.89086914], [79.93435669, 30.89298058], [79.93965912, 30.89190102], [79.94164276, 30.8920002], [79.94348145, 30.89159012], [79.94403839, 30.89142036], [79.94642639, 30.89030075], [79.95980835, 30.88558006], [79.96749878, 30.88231468], [79.96757507, 30.88228226], [79.96764374, 30.88223839], [79.98065948, 30.87394905], [79.980896, 30.87335014], [79.98757935, 30.87000084], [79.99153137, 30.86878014], [79.99471283, 30.86737823], [79.99649811, 30.86631966], [79.99916077, 30.86431122], [80.00123596, 30.86250114], [80.00152588, 30.86182022], [80.00279236, 30.86117935], [80.00332642, 30.86071968], [80.00361633, 30.86004066], [80.00836182, 30.85618973], [80.00945282, 30.8539505], [80.01782227, 30.84787941], [80.01808167, 30.84651756], [80.02490997, 30.8438282], [80.02777863, 30.84338951], [80.02906799, 30.84361076], [80.0297699, 30.84381104], [80.03824615, 30.84296036], [80.04265594, 30.84389114], [80.04411316, 30.84399986], [80.04660797, 30.84073257], [80.0477066, 30.83940125], [80.04823303, 30.83895111], [80.04846954, 30.83839035], [80.05033112, 30.83283043], [80.06420898, 30.82454109], [80.06420898, 30.82407951], [80.06463623, 30.82369041], [80.06465912, 30.82323074], [80.06648254, 30.82211113], [80.06948853, 30.81933975], [80.06965637, 30.81792068], [80.07038116, 30.81228065], [80.07161713, 30.80904007], [80.0740509, 30.79972076], [80.08306122, 30.79528999], [80.08331299, 30.79459953], [80.08487701, 30.7933197], [80.086586, 30.79186058], [80.0879364, 30.79071236], [80.08795929, 30.79026031], [80.10108185, 30.78150749], [80.10135651, 30.7808876], [80.10314941, 30.77967072], [80.10787201, 30.77901077], [80.11308289, 30.78084946], [80.11869812, 30.78633118], [80.12036133, 30.78742027], [80.12243652, 30.79101944], [80.12526703, 30.79351044], [80.1260376, 30.79394913], [80.13751984, 30.79603958], [80.13831329, 30.79670906], [80.13870239, 30.79804993], [80.1377182, 30.80552101], [80.1386261, 30.81002808], [80.13951111, 30.81115913], [80.14472198, 30.81319046], [80.14784241, 30.81342125], [80.15673828, 30.81254005], [80.15727234, 30.81275177], [80.15937042, 30.81208992], [80.16353607, 30.80997086], [80.1674881, 30.80715942], [80.16829681, 30.80554962], [80.16855621, 30.80512047], [80.16958618, 30.80330086], [80.17090607, 30.80241013], [80.17089844, 30.80195808], [80.17221069, 30.80105019], [80.17301941, 30.80060005], [80.17405701, 30.79836082], [80.17457581, 30.7981205], [80.17617798, 30.79541969], [80.17700195, 30.79481125], [80.1783371, 30.79352951], [80.18115234, 30.78932953], [80.18405914, 30.7870903], [80.1848526, 30.78663063], [80.18524933, 30.78549957], [80.18540955, 30.78032112], [80.18492126, 30.77465057], [80.18595886, 30.77036095], [80.18647003, 30.77015114], [80.18860626, 30.76675987], [80.18942261, 30.76630974], [80.19011688, 30.76490974], [80.19045258, 30.76381111], [80.19542694, 30.76111031], [80.19727325, 30.76000023], [80.20720673, 30.75753021], [80.20797729, 30.75776291], [80.21079254, 30.76408005], [80.2127533, 30.76566124], [80.21476746, 30.76645088], [80.21726227, 30.76699066], [80.2178421, 30.76704979], [80.22097778, 30.76593018], [80.22177887, 30.76501083], [80.22281647, 30.76523018], [80.22306824, 30.76455116], [80.22383881, 30.76409912], [80.22543335, 30.76095009], [80.22616577, 30.76036072], [80.22699738, 30.75844955], [80.22753143, 30.7582283], [80.22807312, 30.7580204], [80.22834778, 30.75663757], [80.22953033, 30.75370979], [80.23002625, 30.75349998], [80.23223877, 30.7487812], [80.23298645, 30.74819946], [80.23426056, 30.74558067], [80.23500061, 30.7449894], [80.23726654, 30.74065971], [80.23729706, 30.73769951], [80.2368927, 30.73656273], [80.23264313, 30.72956085], [80.23085785, 30.72257042], [80.22538757, 30.71759033], [80.22357178, 30.71465111], [80.2212677, 30.70453072], [80.22090149, 30.70113945], [80.22006989, 30.70055008], [80.21977234, 30.69725037], [80.21717834, 30.6952095], [80.20987701, 30.69135857], [80.20909119, 30.69155121], [80.19896698, 30.69013023], [80.19715118, 30.68949127], [80.19335938, 30.68772125], [80.19333649, 30.68684959], [80.19285583, 30.68638039], [80.19271851, 30.68592072], [80.18554688, 30.6823082], [80.18284607, 30.67959976], [80.18210602, 30.67811012], [80.18121338, 30.67481995], [80.18049622, 30.66986084], [80.1831665, 30.66534996], [80.1884079, 30.66220093], [80.1884079, 30.66130066], [80.19732666, 30.65675163], [80.20041656, 30.65546036], [80.20095062, 30.65500069], [80.20095062, 30.65388107], [80.20316315, 30.65221024], [80.20316315, 30.65176964], [80.20643616, 30.64891052], [80.20844269, 30.64530945], [80.20896149, 30.64508247], [80.2093811, 30.64145088], [80.20781708, 30.63673019], [80.20568848, 30.63455009], [80.20292664, 30.63061905], [80.19921875, 30.62754059], [80.19869232, 30.62663078], [80.19851685, 30.62314034], [80.19905853, 30.61932945], [80.19956207, 30.61886978], [80.20585632, 30.61639977], [80.20925903, 30.6157093], [80.2106781, 30.61557961], [80.21131897, 30.61548805], [80.21131897, 30.61503029], [80.21209717, 30.61457062], [80.21253204, 30.61345291], [80.21228027, 30.60893822], [80.21189117, 30.60782814], [80.20643616, 30.60238075], [80.20594025, 30.60124969], [80.20597076, 30.59740067], [80.20922852, 30.58753777], [80.21096039, 30.58230019], [80.21476746, 30.5798912], [80.21573639, 30.57904053], [80.22123718, 30.57632828], [80.22144318, 30.57578087], [80.22437286, 30.57496262], [80.22982025, 30.57261276], [80.23214722, 30.57102966], [80.23242188, 30.56945038], [80.2339859, 30.56855011], [80.23425293, 30.56787109], [80.23709106, 30.5662384], [80.23864746, 30.56566048], [80.24022675, 30.56540108], [80.2440567, 30.56677055], [80.24606323, 30.56749153], [80.24780273, 30.56858063], [80.24977112, 30.57252121], [80.25076294, 30.5734539], [80.25112152, 30.5737896], [80.25222015, 30.57492065], [80.25318146, 30.57515907], [80.25467682, 30.57518005], [80.25537109, 30.57518005], [80.25644684, 30.57481956], [80.25701141, 30.57422066], [80.25662231, 30.57106018], [80.25663757, 30.57093048], [80.25689697, 30.56836128], [80.25784302, 30.56796837], [80.25802612, 30.56740952], [80.26055145, 30.56653976], [80.26106262, 30.56744957], [80.26209259, 30.56792068], [80.26235199, 30.56880951], [80.26242065, 30.56964111], [80.26246643, 30.57016945], [80.26355743, 30.57112122], [80.26761627, 30.57376099], [80.2722168, 30.57406044], [80.27799988, 30.57448006], [80.2806015, 30.57390022], [80.28125, 30.57368088], [80.28199005, 30.57333946], [80.28356934, 30.57245064], [80.28412628, 30.57201958], [80.28591919, 30.57181931], [80.28672791, 30.57172966], [80.2893219, 30.57100105], [80.29242706, 30.56998062], [80.29367065, 30.5694809], [80.29456329, 30.56933975], [80.29524231, 30.56962967], [80.29676056, 30.56978035], [80.2977829, 30.56971169], [80.29885101, 30.56974983], [80.29885101, 30.56884956], [80.30145264, 30.56839943], [80.30220795, 30.5680809], [80.30560303, 30.56750107], [80.30716705, 30.56682014], [80.30761719, 30.56602097], [80.30735016, 30.56488037], [80.30895233, 30.5633297], [80.30895996, 30.56287193], [80.30918884, 30.5625782], [80.31137848, 30.55981827], [80.31191254, 30.55960846], [80.31269073, 30.55735016], [80.31347656, 30.55689049], [80.31424713, 30.5564518], [80.31558228, 30.55397034], [80.31996918, 30.55120277], [80.32833862, 30.54675102], [80.33348846, 30.54477119], [80.3377533, 30.54313087], [80.34059143, 30.54134941], [80.34140778, 30.54029274], [80.3455658, 30.53786278], [80.36517334, 30.52869034], [80.36663055, 30.52783775], [80.36828613, 30.52687073], [80.38131714, 30.52350998], [80.38195038, 30.52396774], [80.38370514, 30.52523041], [80.38754272, 30.52799034], [80.39142609, 30.52981949], [80.40055084, 30.53116989], [80.40222931, 30.53045845], [80.40273285, 30.52933121], [80.40629578, 30.5264492], [80.40805817, 30.52216148], [80.40946198, 30.5187397], [80.41256714, 30.51581955], [80.41335297, 30.5151329], [80.41559601, 30.51131058], [80.41623688, 30.51062965], [80.41676331, 30.51016998], [80.42354584, 30.5056591], [80.44805908, 30.49637032], [80.45688629, 30.49389076], [80.465065, 30.49303627], [80.47164154, 30.49234962], [80.47354889, 30.49204063], [80.4751358, 30.49185944], [80.48529816, 30.49048042], [80.48646545, 30.49012566], [80.48970795, 30.48913956], [80.49297333, 30.48679543], [80.49415588, 30.48595047], [80.49415588, 30.48483086], [80.49494934, 30.48460007], [80.49546051, 30.48347092], [80.49701691, 30.48188972], [80.49781799, 30.48143005], [80.49832916, 30.47986984], [80.49884796, 30.47964096], [80.50432587, 30.47036171], [80.50511169, 30.46992111], [80.50565338, 30.46876907], [80.50955963, 30.4654007], [80.5116806, 30.46330833], [80.51216888, 30.46292114], [80.51358795, 30.46133041], [80.51425934, 30.46063995], [80.51970673, 30.45749092], [80.5199585, 30.45658112], [80.52398682, 30.45542908], [80.52648926, 30.45430946], [80.52803802, 30.45521927], [80.52919769, 30.45929909], [80.5298233, 30.46006966], [80.53058624, 30.46108818], [80.53317261, 30.46251869], [80.53505707, 30.4635601], [80.53505707, 30.46401978], [80.53949738, 30.46467972], [80.5423584, 30.46385765], [80.54315948, 30.46362686], [80.54415131, 30.46334076], [80.55171967, 30.46465111], [80.55560303, 30.46716118], [80.55766296, 30.47033119], [80.56005859, 30.47402191], [80.56117249, 30.4757309], [80.5641861, 30.48321152], [80.56636047, 30.48860168], [80.56873322, 30.48929024], [80.56960297, 30.48940086], [80.57666016, 30.48971176], [80.579422, 30.48879814], [80.58419037, 30.48722267], [80.59355927, 30.48223114], [80.5951767, 30.48119926], [80.62306976, 30.4634285], [80.62873077, 30.45981979], [80.63105774, 30.45756912], [80.63368225, 30.4554882], [80.63366699, 30.4546299], [80.63683319, 30.45235062], [80.63681793, 30.45189095], [80.63743591, 30.45103073], [80.63820648, 30.45041275], [80.64350128, 30.44750977], [80.64473724, 30.44706917], [80.64663696, 30.44625092], [80.6472168, 30.44601059], [80.64904022, 30.44532013], [80.65059662, 30.4457798], [80.65345001, 30.44531059], [80.66073608, 30.44576073], [80.66594696, 30.44338989], [80.66638184, 30.44311714], [80.6672287, 30.44259262], [80.66728973, 30.4424305], [80.66777039, 30.44119835], [80.66932678, 30.44053078], [80.67012787, 30.43984032], [80.67514038, 30.43630409], [80.67690277, 30.43506241], [80.67690277, 30.43463326], [80.67690277, 30.43420029], [80.67860413, 30.43302155], [80.68000031, 30.43205452], [80.69980621, 30.41834259], [80.70294952, 30.4166851], [80.70717621, 30.41445732], [80.71962738, 30.40789986], [80.73129272, 30.40221977], [80.73451233, 30.40010071], [80.73748779, 30.39813995], [80.74532318, 30.39157104], [80.74556732, 30.39089012], [80.74919891, 30.38793945], [80.74919891, 30.38747025], [80.75154114, 30.38546181], [80.75231934, 30.38408279], [80.75576782, 30.37996101], [80.7567215, 30.37931252], [80.75737762, 30.37701035], [80.75846863, 30.37590981], [80.75936127, 30.37527084], [80.76403809, 30.36552048], [80.76451874, 30.36530113], [80.76635742, 30.36121941], [80.76685333, 30.36100006], [80.76711273, 30.35987091], [80.76817322, 30.35897064], [80.76869965, 30.35874939], [80.77243805, 30.3481102], [80.77387238, 30.34562111], [80.7743988, 30.34542084], [80.77600098, 30.34316063], [80.78221893, 30.33839035], [80.7824707, 30.33774948], [80.79374695, 30.3302803], [80.81128693, 30.31998062], [80.81804657, 30.31678963], [80.82073975, 30.31574059], [80.82688904, 30.31348038], [80.84580231, 30.30722809], [80.85354614, 30.30597115], [80.86499023, 30.30412102], [80.86580658, 30.30397987], [80.87049103, 30.30284119], [80.88349152, 30.29961967], [80.89646912, 30.29393005], [80.90542603, 30.29112053], [80.91673279, 30.2879715], [80.92058563, 30.28730583], [80.9299469, 30.2856884], [80.93063354, 30.28561974], [80.93424988, 30.28524971], [80.93447876, 30.28523636], [80.93640137, 30.28512955], [80.94059753, 30.2844696], [80.94225311, 30.28403091], [80.947258, 30.28256035], [80.96734619, 30.27577019], [80.97252655, 30.27440071], [80.97608185, 30.27360153], [80.97831726, 30.2730999], [80.9940567, 30.27046013], [80.99829102, 30.26854134], [81.00790405, 30.26418686], [81.0109787, 30.26279068], [81.0120697, 30.26197815], [81.01509094, 30.25962067], [81.01586151, 30.25906944], [81.01714325, 30.25747108], [81.01906586, 30.25317955], [81.01960754, 30.25295258], [81.01999664, 30.25068283], [81.01994324, 30.25014114], [81.01887512, 30.23683739], [81.01421356, 30.2395153], [81.00721741, 30.24061584], [81.00003052, 30.24507523], [80.99046326, 30.24681664], [80.98391724, 30.24391556], [80.97888184, 30.23896027], [80.9779129, 30.23799324], [80.96125793, 30.23761559], [80.93740082, 30.23476219], [80.92921448, 30.23591614], [80.92298126, 30.23165512], [80.92191315, 30.22928047], [80.92134094, 30.22806168], [80.91742706, 30.22460556], [80.91191864, 30.2232151], [80.90931702, 30.22111511], [80.90598297, 30.21673775], [80.90411377, 30.21421623], [80.90120697, 30.21313095], [80.89901733, 30.21225548], [80.89591217, 30.20622063], [80.88572693, 30.19440842], [80.88721466, 30.18831444], [80.88182068, 30.18131447], [80.87303925, 30.17583084], [80.86991882, 30.17573166], [80.86457062, 30.16889572], [80.86531067, 30.16790962], [80.86856842, 30.16666985], [80.8686676, 30.16663361], [80.87311554, 30.16091537], [80.87261963, 30.1532402], [80.87522888, 30.14432144], [80.87787628, 30.1410656], [80.87791443, 30.13661575], [80.88048553, 30.13249779], [80.87921906, 30.12851524], [80.87575531, 30.12627029], [80.86972046, 30.12540817], [80.86431885, 30.12091446], [80.85674286, 30.12030602], [80.85639954, 30.11962318], [80.85599518, 30.11881447], [80.84671021, 30.11606216], [80.84359741, 30.11052895], [80.84658813, 30.10782242], [80.84791565, 30.10661507], [80.84705353, 30.10228539], [80.83921814, 30.09771538], [80.83176422, 30.09719086], [80.83071136, 30.09749985], [80.82965088, 30.09781265], [80.82803345, 30.10004807], [80.82499695, 30.09988403], [80.82344055, 30.09980011], [80.82123566, 30.09710312], [80.81721497, 30.09631538], [80.81574249, 30.09296417], [80.81175232, 30.09142113], [80.80802917, 30.08998299], [80.80341339, 30.08561516], [80.80119324, 30.08090973], [80.79671478, 30.07781601], [80.79348755, 30.07357788], [80.79258728, 30.07333755], [80.79091644, 30.06931496], [80.78226471, 30.05801964], [80.78143311, 30.05692673], [80.77783203, 30.05431557], [80.76731873, 30.05191612], [80.76467896, 30.05047607], [80.76293182, 30.04949188], [80.76060486, 30.04440689], [80.76105499, 30.04350471], [80.75741577, 30.03941536], [80.75733948, 30.03108978], [80.75991821, 30.02761459], [80.75930023, 30.02388763], [80.75611877, 30.02061462], [80.75323486, 30.01255798], [80.74939728, 30.00662994], [80.73981476, 29.99951553], [80.72129059, 30.00037766], [80.71411896, 29.9902153], [80.7062149, 29.98571587], [80.70226288, 29.98002815], [80.69881439, 29.97951508], [80.69184875, 29.97413826], [80.6853714, 29.96695137], [80.6838913, 29.96252251], [80.67791748, 29.95811462], [80.67311859, 29.95739174], [80.65815735, 29.95512199], [80.65032196, 29.95589066], [80.64138031, 29.96124077], [80.63802338, 29.96359634], [80.63332367, 29.96476555], [80.6315155, 29.96521568], [80.62994385, 29.96499062], [80.62310791, 29.96396828], [80.61595154, 29.96061325], [80.61305237, 29.95923233], [80.60533905, 29.95871735], [80.59215546, 29.94844437], [80.58097839, 29.93252754], [80.5799942, 29.92822075], [80.57603455, 29.92343712], [80.57281494, 29.91511536], [80.57141113, 29.90904045], [80.57314301, 29.90112114], [80.57402039, 29.89450073], [80.57431793, 29.89442635], [80.56768036, 29.87921524], [80.55860901, 29.8706398], [80.55891418, 29.86961555], [80.55923462, 29.86852646], [80.5632782, 29.86644173], [80.5610199, 29.86470985], [80.55649567, 29.86206436], [80.55631256, 29.86081696], [80.55612946, 29.85957909], [80.55313873, 29.85635185], [80.55522919, 29.85299683], [80.55401611, 29.85000992], [80.55451202, 29.84923744], [80.55028534, 29.8501339], [80.54541779, 29.84631538], [80.54062653, 29.84714699], [80.53761292, 29.83870125], [80.53291321, 29.83821487], [80.52991486, 29.83361626], [80.52555084, 29.83212662], [80.52571869, 29.82911491], [80.52415466, 29.82768631], [80.52344513, 29.82701874], [80.50902557, 29.82304192], [80.50679016, 29.81931496], [80.50294495, 29.8174305], [80.49921417, 29.81101608], [80.50170898, 29.8088913], [80.5019455, 29.80875206], [80.49723816, 29.80478859], [80.49659729, 29.80216408], [80.49562073, 29.80210686], [80.49720001, 29.79746628], [80.49411774, 29.79531479], [80.48451996, 29.79641533], [80.48131561, 29.79570198], [80.47821808, 29.79791451], [80.46561432, 29.80231476], [80.45596313, 29.80241585], [80.44957733, 29.79910278], [80.44921875, 29.79891586], [80.44303894, 29.80042458], [80.43959045, 29.80384254], [80.43771362, 29.80571556], [80.4365921, 29.80449295], [80.43061829, 29.79801559], [80.41947937, 29.79603004], [80.41768646, 29.79570198], [80.41482544, 29.79185104], [80.41375732, 29.79185104], [80.41365051, 29.79185104], [80.41259003, 29.79185104], [80.408638, 29.79444504], [80.40936279, 29.79160118], [80.40848541, 29.78977394], [80.40789032, 29.78849792], [80.40885925, 29.78402138], [80.4054184, 29.78181076], [80.40641785, 29.77841568], [80.40163422, 29.77380943], [80.39792633, 29.76314354], [80.39929199, 29.7592907], [80.39811707, 29.75861549], [80.39755249, 29.75829697], [80.39271545, 29.76041603], [80.39126587, 29.75994873], [80.38687134, 29.75853157], [80.38725281, 29.75358963], [80.38748932, 29.75051308], [80.37401581, 29.7491188], [80.36972046, 29.75061607], [80.36933899, 29.75001526], [80.36701202, 29.746418], [80.36585999, 29.74015236], [80.37133026, 29.73443604], [80.36785126, 29.72995949], [80.36772919, 29.72491455], [80.37021637, 29.72161484], [80.37480927, 29.72163582], [80.37704468, 29.72026825], [80.37704468, 29.71921539], [80.37704468, 29.71815491], [80.37372589, 29.7153244], [80.37382507, 29.71516991], [80.37617493, 29.71281242], [80.37606049, 29.71159935], [80.37611389, 29.71151543], [80.3788147, 29.70251465], [80.38161469, 29.70101547], [80.38215637, 29.68860435], [80.38621521, 29.68581581], [80.38587189, 29.68161964], [80.38500214, 29.67901039], [80.38601685, 29.6750145], [80.39183807, 29.67105675], [80.39118958, 29.66792488], [80.39112091, 29.66744804], [80.39221954, 29.66450119], [80.40041351, 29.66260529], [80.4006958, 29.66220093], [80.40103149, 29.66173553], [80.40039825, 29.66095734], [80.39990234, 29.65920258], [80.40041351, 29.65862846], [80.40824127, 29.65962219], [80.41170502, 29.65364647], [80.41594696, 29.65415573], [80.41698456, 29.65276527], [80.41819, 29.65116692], [80.4163208, 29.64831543], [80.41571808, 29.64431572], [80.41757202, 29.64161491], [80.42192078, 29.63911438], [80.42116547, 29.63402176], [80.42195892, 29.63212967], [80.42281342, 29.63021469], [80.41991425, 29.62641525], [80.4127121, 29.62532425], [80.41024017, 29.62150192], [80.40982819, 29.61513519], [80.4074173, 29.61281586], [80.40971375, 29.6098156], [80.41061401, 29.60491562], [80.40949249, 29.5949192], [80.40937042, 29.59477234], [80.40488434, 29.58953285], [80.39322662, 29.58157349], [80.39191437, 29.57461548], [80.38999176, 29.57203484], [80.3808136, 29.57151413], [80.38059998, 29.56420708], [80.38051605, 29.56131554], [80.36536407, 29.5640564], [80.36469269, 29.56282806], [80.36399841, 29.56157112], [80.36569977, 29.5567112], [80.36571503, 29.55661583], [80.35891724, 29.55511475], [80.35057831, 29.55535698], [80.34759521, 29.55416489], [80.34435272, 29.55286407], [80.34734344, 29.54864693], [80.34341431, 29.54161453], [80.34775543, 29.54097557], [80.3483429, 29.54106522], [80.34913635, 29.54077148], [80.34965515, 29.54058075], [80.35070038, 29.54019547], [80.35391998, 29.53631592], [80.35903168, 29.53373337], [80.35939789, 29.5328083], [80.35977173, 29.53186989], [80.3584137, 29.52952766], [80.35012817, 29.52352524], [80.3509903, 29.52019882], [80.35132599, 29.51894569], [80.34423828, 29.51099205], [80.34212494, 29.50987244], [80.33842468, 29.51189423], [80.33666229, 29.51285553], [80.335289, 29.5127964], [80.33258057, 29.50822449], [80.33253479, 29.50814438], [80.33044434, 29.50527573], [80.32966614, 29.50495148], [80.31503296, 29.49782372], [80.31453705, 29.49657631], [80.31608582, 29.49277496], [80.31614685, 29.49262619], [80.31516266, 29.48476982], [80.31143188, 29.48526764], [80.30583954, 29.48613739], [80.3028183, 29.48925209], [80.30156708, 29.49055672], [80.30141449, 29.49054718], [80.29793549, 29.48816681], [80.29776001, 29.48800087], [80.2977829, 29.48762894], [80.29801178, 29.48340225], [80.29477692, 29.47892952], [80.28843689, 29.47722054], [80.28968048, 29.4719696], [80.29534912, 29.46432877], [80.29824066, 29.46043205], [80.30285645, 29.45705605], [80.30447388, 29.45444679], [80.30437469, 29.45390701], [80.30435181, 29.4537735], [80.30422211, 29.45307922], [80.29976654, 29.45102692], [80.2993927, 29.45085335], [80.29751587, 29.45361519], [80.29451752, 29.45321465], [80.29005432, 29.45009804], [80.28890228, 29.45088959], [80.28248596, 29.45100212], [80.28220367, 29.45100784], [80.28063202, 29.45394135], [80.28168488, 29.4563446], [80.2822113, 29.45751762], [80.27713013, 29.45842361], [80.27096558, 29.45509338], [80.27571869, 29.45260811], [80.27663422, 29.45096779], [80.27601624, 29.44947624], [80.27141571, 29.45071983], [80.26855469, 29.44848251], [80.26599121, 29.44947243], [80.25983429, 29.45180321], [80.25868225, 29.45001793], [80.25740051, 29.44802666], [80.25225067, 29.44732857], [80.24771118, 29.44674683], [80.24481964, 29.44450569], [80.24473572, 29.44113159], [80.24745941, 29.43839264], [80.24904633, 29.4368], [80.24900055, 29.43241882], [80.24568939, 29.42350388], [80.24769592, 29.41603851], [80.24334717, 29.41158676], [80.24609375, 29.40890121], [80.24768066, 29.40735054], [80.24778748, 29.40730667], [80.25563049, 29.4039917], [80.25687408, 29.4031601], [80.26582336, 29.39715767], [80.27053833, 29.39565659], [80.27129364, 29.39541626], [80.27402496, 29.39492035], [80.2769165, 29.39221573], [80.27462006, 29.38621521], [80.28060913, 29.37888908], [80.27427673, 29.37503624], [80.27281952, 29.37321663], [80.27336121, 29.37122345], [80.27340698, 29.37105942], [80.27290344, 29.36372757], [80.2808075, 29.35989952], [80.28104401, 29.35048485], [80.28110504, 29.3476162], [80.28508759, 29.34185791], [80.29217529, 29.33661079], [80.2929306, 29.33018875], [80.2930603, 29.33003998], [80.29862976, 29.3237114], [80.30404663, 29.32302094], [80.31130981, 29.32209587], [80.31813812, 29.3156395], [80.31864166, 29.31339645], [80.31764984, 29.30821037], [80.32012939, 29.30382729], [80.31989288, 29.3027668], [80.31963348, 29.30158997], [80.3130188, 29.29151535], [80.30783081, 29.28891373], [80.30596161, 29.28531075], [80.30571747, 29.2729454], [80.30571747, 29.27275848], [80.30332947, 29.26456451], [80.30111694, 29.26171494], [80.30175781, 29.25556946], [80.30186462, 29.25498772], [80.3002243, 29.24964905], [80.30198669, 29.24541855], [80.30199432, 29.24203873], [80.29241943, 29.23187256], [80.2925415, 29.22976112], [80.29728699, 29.22219467], [80.29776001, 29.22143364], [80.29679108, 29.21764183], [80.29639435, 29.21609116], [80.29580688, 29.21074295], [80.2990036, 29.20503044], [80.29529572, 29.19762421], [80.2913208, 29.19521523], [80.28620148, 29.19682693], [80.28337097, 29.2007618], [80.28269958, 29.2016964], [80.27663422, 29.2070179], [80.27490997, 29.20697403], [80.26248932, 29.20666122], [80.25950623, 29.21075058], [80.25906372, 29.2141552], [80.25861359, 29.21783066], [80.2543869, 29.22143364], [80.25036621, 29.2206955], [80.24991608, 29.22061539], [80.24881744, 29.21531487], [80.2461853, 29.21236229], [80.24436188, 29.2079277], [80.24259186, 29.20372391], [80.24241638, 29.20331573], [80.24359894, 29.20044327], [80.24930573, 29.197052], [80.2518158, 29.19561577], [80.25962067, 29.18741608], [80.26231384, 29.17471504], [80.26011658, 29.17051506], [80.26000977, 29.16576004], [80.26729584, 29.1534481], [80.27440643, 29.1447506], [80.27340698, 29.14202309], [80.27079773, 29.14053154], [80.26098633, 29.1398983], [80.25574493, 29.1378994], [80.25054932, 29.1289978], [80.2480545, 29.12698555], [80.24694061, 29.12705421], [80.23970032, 29.12121964], [80.23931885, 29.12091446], [80.23501587, 29.11841583], [80.21138763, 29.12176704], [80.20754242, 29.12499809], [80.20738983, 29.12527275], [80.20518494, 29.12929726], [80.19715881, 29.13140678], [80.19598389, 29.13170815], [80.18927765, 29.1354847], [80.1860199, 29.13731575], [80.18519592, 29.13671112], [80.18320465, 29.13533211], [80.17984009, 29.12850571], [80.17662048, 29.12671471], [80.16950989, 29.12574387], [80.16553497, 29.11692047], [80.15992737, 29.11291885], [80.14602661, 29.10300064], [80.13143158, 29.06446266], [80.13011932, 29.06099701], [80.13040161, 29.06092262], [80.13821411, 29.05891609], [80.12814331, 29.03170776], [80.13297272, 29.03042603], [80.12936401, 29.02106667], [80.1277771, 29.01695633], [80.12625885, 29.0130024], [80.13794708, 29.00954819], [80.13762665, 29.00841141], [80.13732147, 29.00731087], [80.12877655, 29.00598526], [80.12851715, 29.00591469], [80.11955261, 28.98171043], [80.10973358, 28.98431969], [80.10190582, 28.98643303], [80.09771729, 28.97521591], [80.06713867, 28.92731667], [80.06014252, 28.91631699], [80.06291199, 28.88316345]]]}}, {\\\"id\\\": \\\"33\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.36_1\\\", \\\"HASC_1\\\": \\\"IN.WB\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"West Bengal\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Bangla|Bengala Occidentale|Bengala Ocidental|Bengale occidental\\\", \\\"apm25_popweighted\\\": -26.8, \\\"dalys_apm25_rate_6cod_mean_total\\\": 777.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": -2032.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": -1255.0, \\\"geo-id\\\": 33, \\\"hpm25_child_popweighted\\\": -258.1, \\\"hpm25_female_popweighted\\\": -296.8, \\\"hpm25_male_popweighted\\\": -213.4, \\\"location\\\": \\\"West Bengal\\\", \\\"mort_apm25_6cod_mean_total\\\": 23155.0, \\\"mort_hpm25_6cod_mean_total\\\": -58389.0, \\\"mort_tpm25_6cod_mean_total\\\": -35234.0, \\\"scenario\\\": \\\"ALLLPG\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[88.01860809, 21.5727787], [88.01889038, 21.57250023], [88.01944733, 21.57250023], [88.01972198, 21.5722084], [88.02055359, 21.57222176], [88.02138519, 21.57138824], [88.02139282, 21.57110977], [88.02111053, 21.57083321], [88.02111053, 21.57055473], [88.02138519, 21.57027817], [88.02139282, 21.56944084], [88.02166748, 21.56916618], [88.02166748, 21.56888962], [88.02139282, 21.56861115], [88.02138519, 21.56833267], [88.02166748, 21.56805611], [88.02166748, 21.56777954], [88.02054596, 21.56666946], [88.02027893, 21.56666756], [88.01972198, 21.56722069], [88.01972198, 21.56750107], [88.01944733, 21.56777954], [88.01944733, 21.56805611], [88.01916504, 21.56833267], [88.01917267, 21.56861115], [88.01860809, 21.56916618], [88.01860809, 21.56944466], [88.01832581, 21.56972122], [88.01833344, 21.57027817], [88.01777649, 21.57083321], [88.01777649, 21.57111168], [88.01667023, 21.5722084], [88.01693726, 21.57250023], [88.01693726, 21.57278252], [88.01721954, 21.57305527], [88.01693726, 21.57333183], [88.01693726, 21.57361031], [88.01638794, 21.57417107], [88.01638794, 21.5755558], [88.01611328, 21.57583046], [88.01611328, 21.57639122], [88.01583099, 21.57666588], [88.01583099, 21.57694244], [88.01555634, 21.57722092], [88.01555634, 21.57749939], [88.01521301, 21.57784462], [88.01499939, 21.57806015], [88.01499939, 21.57833481], [88.01470947, 21.57860947], [88.01470947, 21.57999992], [88.01499939, 21.5802784], [88.01499939, 21.58083344], [88.01565552, 21.58149147], [88.01583099, 21.58167076], [88.01638794, 21.58111], [88.01638794, 21.58083344], [88.01638794, 21.58055687], [88.01667023, 21.5802803], [88.01667023, 21.57888985], [88.01693726, 21.57860947], [88.01694489, 21.57722473], [88.01721954, 21.57694244], [88.01721954, 21.57666588], [88.01776886, 21.57611084], [88.01776886, 21.57557106], [88.01805878, 21.57528114], [88.01805878, 21.57444191], [88.01833344, 21.57416725], [88.01832581, 21.57361031], [88.01860809, 21.57333183], [88.01860809, 21.5727787]]], [[[88.17778015, 21.60111046], [88.17778015, 21.60083008], [88.17805481, 21.60083389], [88.1783371, 21.60055542], [88.1783371, 21.59972191], [88.17778015, 21.59916687], [88.17778015, 21.59804916], [88.1783371, 21.59749985], [88.1783371, 21.59721756], [88.17888641, 21.59666634], [88.1783371, 21.59610939], [88.17805481, 21.5961113], [88.17749786, 21.59555626], [88.17749786, 21.59527969], [88.17778015, 21.59500122], [88.17778015, 21.59444046], [88.17805481, 21.59416771], [88.17804718, 21.59305954], [88.17778015, 21.59278107], [88.17778015, 21.59222031], [88.1783371, 21.59166527], [88.1783371, 21.59139061], [88.17973328, 21.59000015], [88.17972565, 21.58916664], [88.17944336, 21.58889008], [88.17973328, 21.58889008], [88.18055725, 21.58805275], [88.18055725, 21.58749962], [88.18222046, 21.58583069], [88.18222046, 21.58555603], [88.18360901, 21.58416939], [88.18499756, 21.58416748], [88.18527985, 21.58444405], [88.18583679, 21.58444405], [88.18611145, 21.58416748], [88.18640137, 21.58416939], [88.18694305, 21.58361053], [88.1875, 21.58361053], [88.18776703, 21.58332825], [88.18777466, 21.5830555], [88.18888855, 21.5819397], [88.18888855, 21.58166885], [88.18888855, 21.58138084], [88.18861389, 21.58111191], [88.1883316, 21.58111191], [88.18805695, 21.58083344], [88.18805695, 21.58055687], [88.18776703, 21.5802803], [88.18776703, 21.57971954], [88.18722534, 21.57916451], [88.18611145, 21.57917023], [88.18694305, 21.57834053], [88.18694305, 21.57806015], [88.1866684, 21.57777977], [88.1866684, 21.57722092], [88.18638611, 21.57694244], [88.18638611, 21.57479286], [88.18638611, 21.57305527], [88.18611145, 21.57278252], [88.18611145, 21.57110977], [88.18583679, 21.57083321], [88.18583679, 21.56805611], [88.1866684, 21.56722069], [88.1866684, 21.56694412], [88.18694305, 21.56666756], [88.18694305, 21.56583023], [88.1866684, 21.56555748], [88.1866684, 21.56500053], [88.18723297, 21.56443977], [88.18722534, 21.56416512], [88.1875, 21.56389046], [88.18805695, 21.56389046], [88.1883316, 21.56417084], [88.18861389, 21.56416512], [88.18888855, 21.56444359], [88.18888855, 21.56416512], [88.18860626, 21.56389046], [88.18860626, 21.56334114], [88.18888855, 21.56306076], [88.18860626, 21.56278038], [88.18805695, 21.56278038], [88.18777466, 21.56249809], [88.1875, 21.56222153], [88.1875, 21.56083107], [88.1866684, 21.55999947], [88.18416595, 21.55999947], [88.1838913, 21.5597229], [88.18360901, 21.5597229], [88.18334198, 21.55999947], [88.1827774, 21.55999947], [88.18250275, 21.56027794], [88.18222046, 21.56027031], [88.1819458, 21.56056023], [88.18026733, 21.56056023], [88.17888641, 21.56194305], [88.17888641, 21.56221962], [88.1783371, 21.56278038], [88.1783371, 21.56306076], [88.17720795, 21.56417084], [88.17694092, 21.56416512], [88.17666626, 21.56444359], [88.17666626, 21.56472206], [88.17610931, 21.56472206], [88.17500305, 21.56583023], [88.17500305, 21.56611061], [88.17444611, 21.56666756], [88.17446136, 21.56722069], [88.17414856, 21.56750107], [88.17414856, 21.56777954], [88.17388916, 21.56805611], [88.17388916, 21.56833076], [88.17360687, 21.56861115], [88.17360687, 21.56888962], [88.17388916, 21.56916618], [88.17388916, 21.56944466], [88.17414856, 21.56972122], [88.17414856, 21.57027817], [88.17305756, 21.57139015], [88.17305756, 21.57167244], [88.1727829, 21.57195282], [88.17277527, 21.5727787], [88.17222595, 21.57333183], [88.17222595, 21.57361031], [88.17193604, 21.57389069], [88.17193604, 21.57500076], [88.17166901, 21.57527733], [88.17166901, 21.57583237], [88.17138672, 21.57611084], [88.17140198, 21.57860947], [88.17111206, 21.57888985], [88.17111206, 21.58166885], [88.17082977, 21.5819397], [88.17082977, 21.5830555], [88.17111206, 21.58332825], [88.17111206, 21.58527946], [88.17140198, 21.58556175], [88.17082977, 21.58556175], [88.16971588, 21.58667183], [88.16972351, 21.58777809], [88.16889191, 21.5886097], [88.16889191, 21.58889008], [88.16916656, 21.58917046], [88.16916656, 21.58944321], [88.16889191, 21.58971977], [88.16889191, 21.59057045], [88.16860962, 21.59057045], [88.16805267, 21.59111023], [88.16805267, 21.59139061], [88.16777802, 21.59166527], [88.16777802, 21.59181023], [88.16777802, 21.59250069], [88.16805267, 21.59278107], [88.16805267, 21.59389114], [88.16777802, 21.59416771], [88.16777802, 21.5961113], [88.16805267, 21.59638977], [88.16805267, 21.59694481], [88.16832733, 21.59721756], [88.16833496, 21.59749985], [88.16889191, 21.59805489], [88.16889191, 21.59833145], [88.16944122, 21.5988903], [88.16944122, 21.59945107], [88.16999817, 21.60000038], [88.17028046, 21.60000038], [88.17056274, 21.60028267], [88.17082977, 21.60028267], [88.17111206, 21.60056114], [88.17138672, 21.60055542], [88.17166901, 21.60083389], [88.17250061, 21.60083389], [88.17277527, 21.60111046], [88.17333221, 21.60111046], [88.17360687, 21.60083008], [88.17472076, 21.60083389], [88.17500305, 21.60055542], [88.17610931, 21.60055542], [88.1763916, 21.60083389], [88.17694092, 21.60083008], [88.17720795, 21.60111046], [88.17778015, 21.60111046]]], [[[88.83472443, 21.6072216], [88.83499908, 21.60694695], [88.83528137, 21.60695076], [88.83638, 21.60583115], [88.83750153, 21.60583305], [88.83777618, 21.60555649], [88.83805847, 21.60555649], [88.83833313, 21.60527611], [88.83833313, 21.60472107], [88.83889008, 21.60416412], [88.8391571, 21.60416985], [88.83944702, 21.60388947], [88.83999634, 21.60388947], [88.84055328, 21.60333061], [88.84055328, 21.60305405], [88.8408432, 21.60277939], [88.8408432, 21.60222054], [88.84111023, 21.60194206], [88.84111023, 21.6016674], [88.84139252, 21.60167122], [88.84194183, 21.60111046], [88.84306335, 21.60111046], [88.84333038, 21.60083389], [88.84416962, 21.60083389], [88.84471893, 21.60027695], [88.84527588, 21.60028267], [88.84583282, 21.59972191], [88.84610748, 21.59972191], [88.84638977, 21.59944534], [88.84666443, 21.59944534], [88.84694672, 21.59972191], [88.84777832, 21.59972191], [88.84805298, 21.59944534], [88.84860992, 21.59945107], [88.84889221, 21.59917259], [88.85083008, 21.59917259], [88.85111237, 21.5988903], [88.85333252, 21.5988903], [88.85360718, 21.59861183], [88.85500336, 21.59861183], [88.85527802, 21.59833336], [88.85639191, 21.59833336], [88.85666656, 21.59861183], [88.85694122, 21.59861183], [88.85722351, 21.59833336], [88.85832977, 21.59833336], [88.85916901, 21.59749985], [88.85943604, 21.59749985], [88.86000061, 21.59693909], [88.86027527, 21.59694481], [88.86055756, 21.59666634], [88.86110687, 21.59666824], [88.86138916, 21.59638023], [88.86277771, 21.59638977], [88.86305237, 21.5961113], [88.86528015, 21.5961113], [88.8658371, 21.59555626], [88.86611176, 21.59555817], [88.86638641, 21.59527969], [88.86667633, 21.59527969], [88.86694336, 21.59500122], [88.86776733, 21.59500122], [88.86805725, 21.59472084], [88.86893463, 21.59476662], [88.86915588, 21.59500122], [88.8694458, 21.59500122], [88.86972046, 21.59527969], [88.87000275, 21.59527969], [88.8702774, 21.59555817], [88.87055206, 21.59527969], [88.87055206, 21.59500122], [88.87082672, 21.59472084], [88.8713913, 21.59472275], [88.87166595, 21.59444427], [88.87194824, 21.59444427], [88.8722229, 21.59416771], [88.87277985, 21.59416962], [88.87304688, 21.59389114], [88.87333679, 21.59389114], [88.87388611, 21.59332085], [88.8741684, 21.5933342], [88.87444305, 21.59305763], [88.87473297, 21.59305954], [88.875, 21.59278107], [88.87526703, 21.59278107], [88.8758316, 21.59222031], [88.87611389, 21.59222221], [88.87722015, 21.59111023], [88.87722015, 21.59028053], [88.8777771, 21.58971977], [88.8777771, 21.58944321], [88.87832642, 21.58889008], [88.87832642, 21.58805275], [88.87944794, 21.58694458], [88.87999725, 21.58638954], [88.88054657, 21.58667183], [88.88083649, 21.58638954], [88.8813858, 21.58638954], [88.88194275, 21.58583069], [88.88277435, 21.5858326], [88.88277435, 21.58527756], [88.88360596, 21.58443832], [88.88361359, 21.58416748], [88.88388824, 21.58389091], [88.88388824, 21.58361053], [88.8841629, 21.58332825], [88.8841629, 21.5830555], [88.88471985, 21.58305931], [88.88555908, 21.58221817], [88.88583374, 21.58222198], [88.8861084, 21.58194351], [88.88694763, 21.58194351], [88.88722229, 21.58166885], [88.88833618, 21.58167076], [88.88833618, 21.58138084], [88.89027405, 21.58111191], [88.89027405, 21.57916451], [88.89055634, 21.57888985], [88.89111328, 21.57888794], [88.89167023, 21.57944679], [88.89250183, 21.57944679], [88.89360809, 21.57833481], [88.89362335, 21.57806015], [88.89417267, 21.57749939], [88.89416504, 21.57722473], [88.89444733, 21.57694244], [88.89444733, 21.57638931], [88.89472198, 21.57611084], [88.89472198, 21.57583046], [88.89527893, 21.57527733], [88.89527893, 21.57500076], [88.89639282, 21.57389069], [88.89665985, 21.57389069], [88.89665985, 21.57333183], [88.89694214, 21.57305527], [88.89694214, 21.57123947], [88.89694214, 21.57111168], [88.89778137, 21.57027817], [88.89778137, 21.56999969], [88.89816284, 21.56961823], [88.89916992, 21.56861115], [88.89916992, 21.56833076], [88.90000153, 21.56749916], [88.90000153, 21.56722069], [88.90055847, 21.56666756], [88.90055847, 21.5664196], [88.90083313, 21.56611061], [88.90083313, 21.56555939], [88.90110779, 21.56528091], [88.90110779, 21.56472015], [88.90166473, 21.56416512], [88.9016571, 21.56361008], [88.90249634, 21.56277847], [88.90249634, 21.5625], [88.90270233, 21.5622921], [88.90305328, 21.56194305], [88.90305328, 21.5616703], [88.9033432, 21.56138992], [88.9033432, 21.56083107], [88.90361023, 21.56055641], [88.90361023, 21.56027031], [88.90389252, 21.55999947], [88.90389252, 21.55943871], [88.90416718, 21.55916595], [88.90416718, 21.55855179], [88.90416718, 21.55805588], [88.90389252, 21.55777931], [88.90389252, 21.55750084], [88.90361023, 21.55721092], [88.90361023, 21.55583382], [88.90000153, 21.5522213], [88.89916992, 21.5522213], [88.89888763, 21.55194664], [88.89861298, 21.55194664], [88.89833069, 21.55166435], [88.89805603, 21.55167007], [88.89778137, 21.55140114], [88.89749908, 21.55140114], [88.8972168, 21.55111122], [88.89694214, 21.55111122], [88.89665985, 21.55083084], [88.89638519, 21.55083275], [88.89611053, 21.55055428], [88.89554596, 21.55056], [88.89527893, 21.55027962], [88.89389038, 21.55027962], [88.89362335, 21.55000114], [88.89250183, 21.55000114], [88.89221954, 21.54972076], [88.88999939, 21.54972076], [88.8897171, 21.55000114], [88.88944244, 21.55000114], [88.88916779, 21.55027962], [88.88749695, 21.55027962], [88.88722229, 21.55000114], [88.88694763, 21.55000114], [88.88667297, 21.54972076], [88.88471985, 21.54972458], [88.88444519, 21.54944229], [88.88305664, 21.54944229], [88.88277435, 21.54972458], [88.88168335, 21.54972076], [88.8813858, 21.55000114], [88.8797226, 21.55000114], [88.87958527, 21.54986382], [88.87944794, 21.54972076], [88.87805176, 21.54972458], [88.8777771, 21.54944229], [88.8769455, 21.54944229], [88.87666321, 21.54916573], [88.87555695, 21.54916954], [88.87526703, 21.54889107], [88.87444305, 21.54889107], [88.8741684, 21.54916954], [88.8722229, 21.54916573], [88.87194824, 21.54944229], [88.8686142, 21.54944229], [88.86833191, 21.54972458], [88.86805725, 21.54972458], [88.86777496, 21.54944229], [88.86694336, 21.54944229], [88.8666687, 21.54972458], [88.86638641, 21.54972076], [88.86611176, 21.55000114], [88.8638916, 21.55000114], [88.86361694, 21.54972076], [88.86305237, 21.54972076], [88.86277771, 21.55000114], [88.86250305, 21.55000114], [88.86222076, 21.55027962], [88.86083221, 21.55027962], [88.86054993, 21.55000114], [88.86000061, 21.55000114], [88.86000061, 21.55111122], [88.85943604, 21.55167007], [88.85888672, 21.55167007], [88.85778046, 21.55056], [88.85610962, 21.55056], [88.85582733, 21.55027962], [88.85527802, 21.55027962], [88.85500336, 21.55000114], [88.85388947, 21.55000114], [88.85360718, 21.55027962], [88.8527832, 21.55027962], [88.85250092, 21.55056], [88.85221863, 21.55055428], [88.85055542, 21.5522213], [88.84999847, 21.5522213], [88.84972382, 21.55194664], [88.84860992, 21.55194664], [88.84833527, 21.5522213], [88.84694672, 21.55221939], [88.84694672, 21.55249977], [88.84638977, 21.55305672], [88.84527588, 21.55305672], [88.84500122, 21.55333328], [88.84388733, 21.55332947], [88.84333038, 21.55389023], [88.84278107, 21.55388832], [88.84194183, 21.55471992], [88.84194183, 21.55500031], [88.84139252, 21.55555534], [88.84139252, 21.55582809], [88.84111023, 21.55611038], [88.84111023, 21.55639076], [88.8408432, 21.55666924], [88.84055328, 21.55666733], [88.83999634, 21.55722237], [88.83972168, 21.55721092], [88.83944702, 21.55750084], [88.8391571, 21.55750084], [88.83889008, 21.55777931], [88.83860779, 21.55777931], [88.83833313, 21.5580616], [88.83805847, 21.5580616], [88.83750153, 21.55861092], [88.83750153, 21.55888939], [88.83694458, 21.55944443], [88.83666992, 21.55944443], [88.83638763, 21.5597229], [88.83611298, 21.5597229], [88.83583069, 21.55999947], [88.83583069, 21.56055641], [88.83555603, 21.56083107], [88.83555603, 21.56110954], [88.83528137, 21.56138992], [88.83528137, 21.5616703], [88.83416748, 21.56277847], [88.83416748, 21.56361008], [88.83528137, 21.56389046], [88.83528137, 21.56416512], [88.83555603, 21.56444359], [88.83555603, 21.56472015], [88.83583069, 21.56500053], [88.83528137, 21.56555939], [88.83444214, 21.56555748], [88.83389282, 21.56611061], [88.83361053, 21.56611061], [88.83333588, 21.56640053], [88.83277893, 21.56640053], [88.83249664, 21.56611061], [88.83222198, 21.56611061], [88.83222198, 21.56640053], [88.83194733, 21.56666756], [88.83194733, 21.56722069], [88.83166504, 21.56749916], [88.83167267, 21.56861115], [88.83139038, 21.56888962], [88.83139038, 21.56916618], [88.83110809, 21.56944466], [88.83110809, 21.57055473], [88.83082581, 21.57082748], [88.83082581, 21.57195282], [88.83027649, 21.57250023], [88.83027649, 21.57278252], [88.83000183, 21.57305527], [88.83000183, 21.57333183], [88.82971954, 21.57361031], [88.82971954, 21.57416725], [88.82917786, 21.57471275], [88.82917023, 21.57527733], [88.82861328, 21.57583046], [88.82861328, 21.57666588], [88.82833099, 21.57694244], [88.82833099, 21.57860947], [88.82861328, 21.57888985], [88.82861328, 21.57916451], [88.82888794, 21.57944679], [88.82888794, 21.57971954], [88.82917023, 21.57999992], [88.82944489, 21.57999992], [88.83027649, 21.58083344], [88.83027649, 21.58222198], [88.83056641, 21.58250046], [88.83056641, 21.58305931], [88.83110809, 21.58361053], [88.83082581, 21.58389091], [88.83082581, 21.58499908], [88.83055878, 21.58527756], [88.83056641, 21.58638954], [88.83082581, 21.58667183], [88.83082581, 21.58751106], [88.83110809, 21.58777809], [88.83110809, 21.58805466], [88.83139038, 21.58833122], [88.83139038, 21.58945084], [88.83194733, 21.59000015], [88.83194733, 21.59111023], [88.83166504, 21.5913887], [88.83167267, 21.59250069], [88.83139038, 21.59278107], [88.83139038, 21.59305763], [88.83166504, 21.5933342], [88.83167267, 21.59361076], [88.83139038, 21.59389114], [88.83139038, 21.59500122], [88.83110809, 21.59527969], [88.83110809, 21.5961113], [88.83083344, 21.59638977], [88.83083344, 21.59694481], [88.83056641, 21.59721756], [88.83055878, 21.60055542], [88.83082581, 21.60083008], [88.83082581, 21.60111046], [88.83056641, 21.60139275], [88.83055878, 21.6016674], [88.83082581, 21.60194016], [88.83082581, 21.60361099], [88.83110809, 21.60388947], [88.83083344, 21.60416412], [88.83139038, 21.60472107], [88.83139038, 21.60527992], [88.83277893, 21.60667038], [88.83361053, 21.60666466], [88.83398438, 21.6070385], [88.83416748, 21.6072216], [88.83472443, 21.6072216]]], [[[88.49771118, 21.59975433], [88.49829865, 21.59942818], [88.49888611, 21.59916687], [88.49888611, 21.59861183], [88.49972534, 21.59777832], [88.49973297, 21.59749985], [88.50222015, 21.59499931], [88.50250244, 21.59472084], [88.50250244, 21.59444427], [88.50333405, 21.59361076], [88.50389099, 21.59416962], [88.50417328, 21.59416962], [88.50499725, 21.59332085], [88.50527954, 21.5933342], [88.5055542, 21.59305763], [88.5063858, 21.59305954], [88.50666809, 21.59278107], [88.50723267, 21.59278107], [88.50763702, 21.59263039], [88.50784302, 21.59250069], [88.50833893, 21.59233284], [88.50887299, 21.5921402], [88.50938416, 21.59187508], [88.50987244, 21.59152031], [88.51039124, 21.59115028], [88.51095581, 21.59083939], [88.51154327, 21.59054947], [88.51207733, 21.59024048], [88.51248932, 21.58987045], [88.5128479, 21.58953094], [88.51319122, 21.58928871], [88.51352692, 21.58909988], [88.51381683, 21.58889389], [88.51409912, 21.58869362], [88.51444244, 21.58858109], [88.51477051, 21.5883503], [88.5151825, 21.58818245], [88.51563263, 21.58802032], [88.51609802, 21.58778572], [88.51657867, 21.58757019], [88.51676941, 21.58740807], [88.51694489, 21.58722115], [88.51750183, 21.58722115], [88.51777649, 21.58694458], [88.51777649, 21.58666611], [88.51805878, 21.58638954], [88.51832581, 21.58667183], [88.51860809, 21.58666611], [88.51875305, 21.58680725], [88.51889038, 21.58694458], [88.51944733, 21.58638954], [88.51972198, 21.58638954], [88.51999664, 21.58610916], [88.52047729, 21.58608055], [88.52102661, 21.58586121], [88.52162933, 21.5857296], [88.52218628, 21.5855484], [88.52272797, 21.58535194], [88.52326202, 21.58527946], [88.52500153, 21.58527756], [88.52555847, 21.58472061], [88.52583313, 21.58472252], [88.52639008, 21.58416748], [88.52722168, 21.58416939], [88.52749634, 21.58389091], [88.5283432, 21.58389091], [88.52861023, 21.58416939], [88.52889252, 21.58389091], [88.52889252, 21.58361053], [88.52944946, 21.58305931], [88.52971649, 21.58305931], [88.53221893, 21.58056068], [88.53221893, 21.5802803], [88.53277588, 21.57971954], [88.53277588, 21.57916451], [88.53388977, 21.57806015], [88.53388977, 21.57666969], [88.53360748, 21.57639122], [88.53360748, 21.57417107], [88.53388977, 21.57389069], [88.53388977, 21.57361031], [88.53360748, 21.57361031], [88.53341675, 21.57341766], [88.53305817, 21.57305527], [88.53221893, 21.5730629], [88.53193665, 21.57278252], [88.53166962, 21.57278252], [88.53083038, 21.57195282], [88.53056335, 21.57195282], [88.53028107, 21.57167244], [88.53028107, 21.57110977], [88.53083038, 21.57055473], [88.53083038, 21.57027817], [88.53056335, 21.56999969], [88.53055573, 21.56944466], [88.53028107, 21.56916618], [88.53028107, 21.56805992], [88.53083038, 21.56750107], [88.53083038, 21.56694031], [88.53111267, 21.56666756], [88.53111267, 21.56640053], [88.53166962, 21.56583023], [88.53111267, 21.56555748], [88.53083038, 21.56528091], [88.53083038, 21.56443977], [88.53166962, 21.56361389], [88.53193665, 21.56361008], [88.53221893, 21.56388855], [88.53221893, 21.56444359], [88.53250885, 21.56472015], [88.53250122, 21.56555748], [88.53356171, 21.56661415], [88.53388977, 21.56694412], [88.53388977, 21.5672226], [88.53444672, 21.56666756], [88.53444672, 21.56611061], [88.5341568, 21.56583023], [88.53416443, 21.56555748], [88.53407288, 21.56508827], [88.53395081, 21.56454849], [88.53382874, 21.56402016], [88.53360748, 21.56389046], [88.53360748, 21.56334114], [88.53333282, 21.56306076], [88.53333282, 21.56278038], [88.53305817, 21.5625], [88.53305817, 21.56195068], [88.53277588, 21.5616703], [88.53277588, 21.56110954], [88.53167725, 21.56001282], [88.53111267, 21.55944443], [88.53111267, 21.55916595], [88.52971649, 21.55777931], [88.52971649, 21.55639076], [88.52944946, 21.55611038], [88.52944183, 21.55555534], [88.52889252, 21.55500031], [88.52889252, 21.55471992], [88.52916718, 21.55444527], [88.52916718, 21.55389023], [88.52971649, 21.55332947], [88.52972412, 21.55277824], [88.52944946, 21.55249977], [88.52944183, 21.5522213], [88.52999878, 21.55166435], [88.52999878, 21.55111122], [88.52971649, 21.55083084], [88.52972412, 21.54999924], [88.52999878, 21.54972076], [88.52999878, 21.54944229], [88.53028107, 21.54916573], [88.53028107, 21.54805946], [88.53221893, 21.54611015], [88.53221893, 21.5447216], [88.53250122, 21.54444504], [88.53250885, 21.54388809], [88.53221893, 21.54360962], [88.53221893, 21.54333305], [88.53138733, 21.54249954], [88.53111267, 21.54249954], [88.53083038, 21.54220963], [88.52805328, 21.54222298], [88.52722168, 21.54138947], [88.52638245, 21.54138947], [88.52610779, 21.54111099], [88.52500153, 21.54111099], [88.52471924, 21.54138947], [88.52332306, 21.54138947], [88.52305603, 21.54166985], [88.5222168, 21.54083061], [88.52055359, 21.54083252], [88.52027893, 21.54055786], [88.51999664, 21.54055977], [88.51972198, 21.54027939], [88.51917267, 21.54027939], [88.51889038, 21.54000092], [88.51777649, 21.54000092], [88.51750946, 21.53972054], [88.51721954, 21.53972054], [88.51664734, 21.53985023], [88.51638794, 21.53985023], [88.51611328, 21.53972054], [88.51583099, 21.53972244], [88.51555634, 21.53944588], [88.51527405, 21.53972244], [88.5147171, 21.53972054], [88.51444244, 21.54000092], [88.51389313, 21.54000092], [88.51361084, 21.54027939], [88.51333618, 21.54027939], [88.51304626, 21.54055977], [88.51082611, 21.54055977], [88.51027679, 21.54000092], [88.51000214, 21.54000092], [88.50945282, 21.54055977], [88.5091629, 21.54055786], [88.50888824, 21.54083252], [88.50749969, 21.54083252], [88.50723267, 21.54111099], [88.50611115, 21.54111099], [88.50527954, 21.54194069], [88.50527954, 21.54277992], [88.5055542, 21.54305649], [88.5055542, 21.54333305], [88.5057373, 21.54381371], [88.50583649, 21.54418373], [88.50595093, 21.54457092], [88.50606537, 21.54499626], [88.50611115, 21.54527092], [88.50611115, 21.54545975], [88.50611115, 21.54639053], [88.5063858, 21.54667282], [88.5063858, 21.54916573], [88.50666809, 21.54944038], [88.50666809, 21.55055428], [88.50694275, 21.55083084], [88.50694275, 21.55111122], [88.50777435, 21.55194664], [88.50777435, 21.5522213], [88.51027679, 21.55471992], [88.51027679, 21.55500031], [88.5111084, 21.55583382], [88.5111084, 21.55694389], [88.51138306, 21.55721092], [88.51138306, 21.55750084], [88.51167297, 21.55777931], [88.51167297, 21.5580616], [88.5111084, 21.55861092], [88.5111084, 21.55916595], [88.51083374, 21.55944443], [88.51082611, 21.5597229], [88.51055908, 21.55999947], [88.51055908, 21.56027794], [88.50971985, 21.56111145], [88.5091629, 21.56110954], [88.50888824, 21.56138992], [88.50805664, 21.56138992], [88.50776672, 21.5616703], [88.5063858, 21.5616703], [88.50611115, 21.56195068], [88.50527954, 21.56194305], [88.50499725, 21.56222153], [88.5047226, 21.56221962], [88.50444794, 21.5625], [88.50444794, 21.56306076], [88.50416565, 21.56333542], [88.50417328, 21.56472015], [88.50389099, 21.56500053], [88.50305176, 21.56500053], [88.50305176, 21.56528091], [88.5027771, 21.56500053], [88.5027771, 21.56472015], [88.50305176, 21.56444359], [88.50305176, 21.56388855], [88.5027771, 21.56361008], [88.5027771, 21.56305313], [88.50305176, 21.56278038], [88.50305176, 21.5625], [88.5036087, 21.56195068], [88.5036087, 21.5616703], [88.50389099, 21.56138992], [88.50389099, 21.56110954], [88.50416565, 21.56083107], [88.50444794, 21.56083107], [88.5047226, 21.56055641], [88.50554657, 21.56056023], [88.50591278, 21.56048012], [88.50630951, 21.56038094], [88.5067215, 21.56031036], [88.50715637, 21.56027031], [88.50757599, 21.56026459], [88.50796509, 21.56021118], [88.50830841, 21.56008339], [88.50863647, 21.55997086], [88.50892639, 21.55982208], [88.5091629, 21.55963135], [88.50936127, 21.55937767], [88.50953674, 21.55903244], [88.50965881, 21.55855179], [88.50969696, 21.55793953], [88.50966644, 21.55725288], [88.50956726, 21.55653954], [88.50938416, 21.55586433], [88.50909424, 21.55526924], [88.50871277, 21.55478096], [88.50827789, 21.55431175], [88.50782013, 21.55388069], [88.50734711, 21.55344963], [88.50692749, 21.55300713], [88.5065918, 21.55254173], [88.50630951, 21.55212212], [88.50609589, 21.55174065], [88.50591278, 21.55143356], [88.50579071, 21.55111885], [88.50549316, 21.55113029], [88.50534821, 21.55091095], [88.50527954, 21.55055428], [88.50527954, 21.54972076], [88.50499725, 21.54944229], [88.50499725, 21.54611015], [88.5047226, 21.54583359], [88.5047226, 21.54500008], [88.50417328, 21.54445267], [88.50389099, 21.54444504], [88.5036087, 21.54445267], [88.503479, 21.54445267], [88.50332642, 21.54416847], [88.50305176, 21.54416847], [88.5027771, 21.54388809], [88.50250244, 21.54416847], [88.50026703, 21.54416847], [88.5, 21.54445267], [88.49965668, 21.54446983], [88.49919891, 21.54464912], [88.49865723, 21.54475975], [88.4981308, 21.544981], [88.49763489, 21.54517937], [88.49723816, 21.5454731], [88.49691772, 21.54578972], [88.4966507, 21.5460968], [88.49646759, 21.54641342], [88.49649048, 21.54684258], [88.49648285, 21.54730988], [88.49620819, 21.54775429], [88.49581909, 21.54821968], [88.49555206, 21.54861069], [88.49388885, 21.55027771], [88.49333954, 21.5503006], [88.49276733, 21.55056], [88.4916687, 21.55055428], [88.49138641, 21.55083275], [88.49111176, 21.55083275], [88.49055481, 21.55027771], [88.49027252, 21.55027962], [88.48999786, 21.55056], [88.48916626, 21.55055428], [88.4888916, 21.55083275], [88.48860931, 21.55083084], [88.48832703, 21.55111122], [88.48777771, 21.55111122], [88.48750305, 21.55140114], [88.48750305, 21.55249977], [88.48721313, 21.55278015], [88.48694611, 21.55277824], [88.48638916, 21.55333328], [88.4861145, 21.55333328], [88.48583221, 21.55361176], [88.48527527, 21.55361176], [88.48510742, 21.5537796], [88.48500061, 21.55389023], [88.48306274, 21.55389023], [88.48278046, 21.55417061], [88.48222351, 21.5541687], [88.48190308, 21.55450058], [88.48170471, 21.55472565], [88.48159027, 21.55504227], [88.48143768, 21.55537987], [88.48142242, 21.55581093], [88.48152161, 21.55631065], [88.48145294, 21.55689049], [88.48134613, 21.55750084], [88.48136139, 21.55811882], [88.48118591, 21.55880928], [88.48130798, 21.55923843], [88.48136902, 21.55966187], [88.4810791, 21.56009102], [88.48110962, 21.5604496], [88.48104095, 21.56087112], [88.48108673, 21.56129837], [88.48110962, 21.56174088], [88.48105621, 21.56212807], [88.48108673, 21.56250954], [88.48097229, 21.56287003], [88.48097229, 21.5637455], [88.48103333, 21.56483078], [88.48092651, 21.56562042], [88.48108673, 21.56587029], [88.48110962, 21.56619835], [88.48110962, 21.56657982], [88.48110962, 21.56701088], [88.48113251, 21.56742096], [88.48123169, 21.56776047], [88.48146057, 21.5682106], [88.48189545, 21.56894875], [88.48217773, 21.56987953], [88.48271179, 21.57117081], [88.48280334, 21.57146072], [88.48287201, 21.57175827], [88.48300934, 21.57204247], [88.48308563, 21.57238007], [88.48306274, 21.57279015], [88.48306274, 21.57324028], [88.48309326, 21.57370186], [88.48313904, 21.57420349], [88.48322296, 21.5748291], [88.48353577, 21.57551765], [88.4835968, 21.57575035], [88.48356628, 21.57611084], [88.48368835, 21.57632065], [88.48383331, 21.5765667], [88.48388672, 21.57691956], [88.48388672, 21.57735062], [88.48388672, 21.57783127], [88.48394775, 21.5783596], [88.48412323, 21.57889557], [88.48412323, 21.57949066], [88.48429871, 21.58008766], [88.48434448, 21.58054733], [88.48441315, 21.58105087], [88.48430634, 21.58146667], [88.48438263, 21.58165359], [88.48445892, 21.582201], [88.48480988, 21.58255959], [88.48500061, 21.58305931], [88.48527527, 21.5830555], [88.48555756, 21.58332825], [88.48555756, 21.58527946], [88.48527527, 21.58555603], [88.4852829, 21.58583069], [88.48583221, 21.58638954], [88.48583221, 21.58722115], [88.4861145, 21.58749962], [88.48610687, 21.58833122], [88.48665619, 21.58889008], [88.48721313, 21.58889008], [88.48777771, 21.58945084], [88.48777771, 21.59000015], [88.48805237, 21.59028053], [88.48805237, 21.59167099], [88.4888916, 21.59250069], [88.4888916, 21.59277534], [88.49055481, 21.59444427], [88.49054718, 21.59472084], [88.4908371, 21.59500122], [88.4908371, 21.59527969], [88.4916687, 21.5961113], [88.4916687, 21.59638023], [88.49276733, 21.59749985], [88.49277496, 21.59777832], [88.49333191, 21.59833336], [88.4936142, 21.59833336], [88.4937973, 21.59851837], [88.49388885, 21.59861183], [88.49415588, 21.59861183], [88.4944458, 21.5988903], [88.49472046, 21.5988903], [88.4952774, 21.59945107], [88.49555206, 21.59944534], [88.49583435, 21.59972191], [88.49610901, 21.59972191], [88.4963913, 21.60000038], [88.49649811, 21.60008049], [88.49659729, 21.6001606], [88.49714661, 21.60009003], [88.49771118, 21.59975433]]], [[[88.96576691, 21.64153481], [88.96607971, 21.64129829], [88.96637726, 21.64102936], [88.96675873, 21.6408329], [88.96723938, 21.64067078], [88.96772766, 21.64058113], [88.9681778, 21.6405201], [88.96862793, 21.64043045], [88.96904755, 21.64031792], [88.96948242, 21.64029121], [88.96990204, 21.64034081], [88.97035217, 21.64048195], [88.97080994, 21.64059448], [88.97128296, 21.64073944], [88.97171783, 21.64089966], [88.97215271, 21.64108086], [88.97259521, 21.64123344], [88.97303009, 21.64139938], [88.97346497, 21.64157677], [88.9739151, 21.64172173], [88.9743576, 21.64189339], [88.97481537, 21.64204216], [88.97527313, 21.64221954], [88.97572327, 21.6424408], [88.97618103, 21.64267921], [88.97627258, 21.64273262], [88.97662354, 21.64293671], [88.97708893, 21.64311981], [88.97753906, 21.6432724], [88.9779892, 21.64340019], [88.9784317, 21.64358521], [88.97891235, 21.64377975], [88.97949219, 21.6439209], [88.98009491, 21.64408112], [88.98071289, 21.64419174], [88.98133087, 21.64431953], [88.98197937, 21.64439964], [88.98264313, 21.64443016], [88.98330688, 21.64448166], [88.9839859, 21.64453125], [88.98468018, 21.64446831], [88.98538971, 21.64459038], [88.98600769, 21.64476013], [88.98654938, 21.64484024], [88.9870224, 21.64485931], [88.9874649, 21.64486313], [88.98789215, 21.64486313], [88.98835754, 21.6448307], [88.98889923, 21.64471054], [88.98956299, 21.6445961], [88.990242, 21.64438057], [88.99085999, 21.64404106], [88.99138641, 21.64356995], [88.99185181, 21.64299965], [88.99221802, 21.6423912], [88.99250031, 21.64178085], [88.9927063, 21.64118958], [88.99288177, 21.64064026], [88.99302673, 21.64015007], [88.99311066, 21.63965034], [88.99326324, 21.63918114], [88.99331665, 21.63869286], [88.99333191, 21.63818741], [88.99333954, 21.63768005], [88.99339294, 21.63718033], [88.9935379, 21.63669968], [88.99360657, 21.63620949], [88.9936676, 21.63571167], [88.99384308, 21.63519096], [88.99388885, 21.6346302], [88.99394226, 21.63406181], [88.99407196, 21.63351059], [88.99419403, 21.6329174], [88.99434662, 21.63229942], [88.99443054, 21.63165283], [88.99446106, 21.63101006], [88.99452972, 21.63042068], [88.99467468, 21.62994194], [88.99473572, 21.62946129], [88.99481201, 21.62901878], [88.99495697, 21.62862968], [88.99500275, 21.62820053], [88.99478149, 21.6277504], [88.9950943, 21.62731361], [88.99485016, 21.62685966], [88.99513245, 21.62639999], [88.99485016, 21.62592125], [88.99485016, 21.62540817], [88.99485016, 21.62513542], [88.9944458, 21.62486076], [88.99432373, 21.62418938], [88.99416351, 21.62333298], [88.9938736, 21.62318993], [88.99376678, 21.62275124], [88.99307251, 21.62194061], [88.99305725, 21.62138939], [88.99250031, 21.62083244], [88.99250031, 21.62050056], [88.99250031, 21.61916733], [88.99223328, 21.61889076], [88.99223328, 21.61778069], [88.99250031, 21.61749077], [88.99250031, 21.61666679], [88.9908371, 21.61499977], [88.99060059, 21.61499977], [88.99028015, 21.61499977], [88.98972321, 21.61445045], [88.98944092, 21.61445045], [88.98916626, 21.61417007], [88.9888916, 21.61417007], [88.98832703, 21.61361122], [88.98805237, 21.61361122], [88.98805237, 21.61333275], [88.98777771, 21.61305618], [88.98722076, 21.61305618], [88.98694611, 21.61333275], [88.98583221, 21.61333275], [88.98583221, 21.61361122], [88.98555756, 21.61388969], [88.98500061, 21.61388969], [88.98443604, 21.61333275], [88.98388672, 21.61333275], [88.98361206, 21.61305618], [88.983078, 21.61305618], [88.98166656, 21.61305618], [88.98139191, 21.61333275], [88.98000336, 21.61333275], [88.97957611, 21.6131916], [88.97571564, 21.6131916], [88.97472382, 21.61333275], [88.97389221, 21.61333275], [88.97360992, 21.61334038], [88.97305298, 21.61347961], [88.97286987, 21.61338234], [88.97277832, 21.61333275], [88.97071075, 21.61333275], [88.97000122, 21.61361122], [88.96835327, 21.61361122], [88.96749878, 21.61388969], [88.96721649, 21.61388969], [88.96694183, 21.61417007], [88.96639252, 21.61417007], [88.96611023, 21.61445045], [88.96583557, 21.61444473], [88.96555328, 21.6147213], [88.96527863, 21.61471939], [88.96499634, 21.61499977], [88.96360779, 21.61499977], [88.96333313, 21.61528015], [88.96277618, 21.61527824], [88.96250153, 21.61555481], [88.96221924, 21.61555481], [88.96166992, 21.61611176], [88.96028137, 21.61610985], [88.95970917, 21.61667061], [88.95833588, 21.61667061], [88.95804596, 21.61695099], [88.95777893, 21.61694336], [88.95749664, 21.61722183], [88.95641327, 21.6174202], [88.95591736, 21.61756706], [88.95612335, 21.61770248], [88.95612335, 21.61777687], [88.95610809, 21.61833572], [88.95639038, 21.61833], [88.95639038, 21.61889076], [88.95666504, 21.61916733], [88.95667267, 21.61972046], [88.9569397, 21.62000084], [88.95722198, 21.62000084], [88.95777893, 21.62055779], [88.95777893, 21.62083054], [88.95805359, 21.62111092], [88.95841217, 21.62147331], [88.9585495, 21.62169266], [88.95876312, 21.62202072], [88.95861053, 21.62222099], [88.95861053, 21.62249947], [88.95816803, 21.62249947], [88.95804596, 21.62249947], [88.95777893, 21.62277985], [88.95777893, 21.62305832], [88.95722198, 21.62361908], [88.95722198, 21.62388992], [88.95667267, 21.62445068], [88.95639038, 21.62445068], [88.95555878, 21.62528038], [88.95527649, 21.62528038], [88.95276642, 21.62778282], [88.95276642, 21.62805939], [88.9522171, 21.62861061], [88.9522171, 21.6288929], [88.95166779, 21.62944221], [88.95166779, 21.62972069], [88.95083618, 21.6305542], [88.95083618, 21.63083076], [88.95054626, 21.63111115], [88.95055389, 21.63138962], [88.94999695, 21.63194656], [88.94999695, 21.63305092], [88.94917297, 21.63389015], [88.9486084, 21.63388634], [88.94776917, 21.63471985], [88.94776917, 21.63500023], [88.94750214, 21.63528061], [88.94750214, 21.63555527], [88.94721985, 21.63582993], [88.94721985, 21.63611031], [88.9466629, 21.63666725], [88.94694519, 21.63694382], [88.9466629, 21.63722038], [88.9466629, 21.63750076], [88.9458313, 21.63833427], [88.94555664, 21.63832855], [88.94526672, 21.63862038], [88.94361115, 21.63861084], [88.94301605, 21.63920784], [88.94277954, 21.63944435], [88.94267273, 21.63939667], [88.94238281, 21.63974953], [88.94207001, 21.64015007], [88.9420929, 21.64055634], [88.94225311, 21.6408329], [88.94168091, 21.6415329], [88.94140625, 21.64152336], [88.94113159, 21.64180183], [88.94098663, 21.64249992], [88.94083405, 21.6427784], [88.94082642, 21.64361], [88.9402771, 21.64417076], [88.94023895, 21.64587021], [88.94000244, 21.64611053], [88.94000244, 21.64639091], [88.93972015, 21.64666748], [88.93972015, 21.64694595], [88.94000244, 21.64722061], [88.94024658, 21.64729118], [88.94058228, 21.64770126], [88.94085693, 21.6480999], [88.9411087, 21.64861107], [88.94135284, 21.64885139], [88.94166565, 21.64916611], [88.94152069, 21.64931488], [88.94139099, 21.64944458], [88.94139099, 21.64972305], [88.94185638, 21.65018845], [88.94194794, 21.65027809], [88.94194794, 21.65041924], [88.94194794, 21.65083313], [88.94220734, 21.6511097], [88.94217682, 21.65129089], [88.94229889, 21.6518116], [88.94248199, 21.65229034], [88.94262695, 21.65276909], [88.94274902, 21.65323067], [88.94281006, 21.65366936], [88.94293213, 21.65402985], [88.94309998, 21.65432358], [88.94330597, 21.65458107], [88.94346619, 21.65487099], [88.94355774, 21.65523529], [88.9438324, 21.65544319], [88.9438324, 21.65592957], [88.94420624, 21.65642929], [88.94445038, 21.65688324], [88.94468689, 21.65730095], [88.94484711, 21.65796089], [88.94494629, 21.65867996], [88.94532776, 21.6592598], [88.94554138, 21.65987968], [88.9457016, 21.66050911], [88.94586182, 21.66115952], [88.94612885, 21.66176987], [88.94645691, 21.66231918], [88.94668579, 21.66291809], [88.94696045, 21.66349983], [88.94724274, 21.66398048], [88.94753265, 21.66436958], [88.94779968, 21.66467285], [88.94805145, 21.66494942], [88.94825745, 21.66524124], [88.94837952, 21.66563988], [88.94857025, 21.66605186], [88.9487381, 21.66655922], [88.94904327, 21.66695023], [88.94937897, 21.66732788], [88.94970703, 21.66769409], [88.94986725, 21.66790962], [88.94999695, 21.66808128], [88.95025635, 21.6684761], [88.95044708, 21.6689415], [88.95059204, 21.66946793], [88.95083618, 21.66995049], [88.95111084, 21.67043114], [88.95137787, 21.67087936], [88.95159912, 21.6713295], [88.95178986, 21.67178726], [88.95197296, 21.67220116], [88.9522171, 21.67253113], [88.95243835, 21.67287445], [88.9526062, 21.67328262], [88.95282745, 21.67366028], [88.95307159, 21.67406273], [88.95332336, 21.67447853], [88.95355225, 21.67495346], [88.95365143, 21.67554092], [88.9539032, 21.6760807], [88.95423126, 21.676548], [88.95468903, 21.6769104], [88.95520782, 21.6770916], [88.95587921, 21.67682266], [88.95654297, 21.67628288], [88.95705414, 21.67577744], [88.95742035, 21.67528915], [88.95765686, 21.6748085], [88.95780945, 21.67433167], [88.95793152, 21.67385483], [88.95807648, 21.67337036], [88.95826721, 21.67290306], [88.95848083, 21.67244911], [88.95865631, 21.67198181], [88.95884705, 21.6715107], [88.95903778, 21.67110825], [88.95922089, 21.67068291], [88.95940399, 21.67024612], [88.9595871, 21.66979027], [88.95974731, 21.66932106], [88.95995331, 21.66889], [88.96013641, 21.66847038], [88.960289, 21.66798973], [88.9604187, 21.66749763], [88.96057892, 21.66699028], [88.96077728, 21.66646194], [88.96095276, 21.66595078], [88.96105194, 21.66547203], [88.96123505, 21.66501999], [88.9614563, 21.66459465], [88.96161652, 21.6641922], [88.96173096, 21.66379929], [88.96185303, 21.66335106], [88.96198273, 21.66283607], [88.96211243, 21.66228104], [88.96222687, 21.66169167], [88.9622879, 21.66102982], [88.9623642, 21.66035461], [88.96244812, 21.65963554], [88.96248627, 21.65888977], [88.96245575, 21.65814972], [88.96238708, 21.65743065], [88.96232605, 21.65674019], [88.96222687, 21.6561203], [88.9621582, 21.65555954], [88.96211243, 21.65506172], [88.96208954, 21.65459061], [88.96203613, 21.65413094], [88.96193695, 21.65365028], [88.96186066, 21.6531105], [88.96179962, 21.65254021], [88.96177673, 21.65195274], [88.9617691, 21.65137482], [88.96179199, 21.65076828], [88.96186066, 21.65011024], [88.96191406, 21.6493969], [88.96202087, 21.64867973], [88.96217346, 21.64801788], [88.96232605, 21.64743805], [88.96248627, 21.64698029], [88.96264648, 21.64657974], [88.96285248, 21.6462307], [88.96309662, 21.64590073], [88.96333313, 21.64550018], [88.96347809, 21.64504433], [88.96357727, 21.64454079], [88.96370697, 21.64408112], [88.96389008, 21.64369965], [88.96412659, 21.64339638], [88.96440125, 21.64311028], [88.96469116, 21.64280128], [88.96496582, 21.64245987], [88.96520233, 21.64209938], [88.96547699, 21.6417923], [88.96576691, 21.64153481]]], [[[88.53721619, 21.63862038], [88.53749847, 21.63806152], [88.53778076, 21.63806152], [88.53832245, 21.63750076], [88.53943634, 21.63750076], [88.54055786, 21.63639069], [88.54083252, 21.63639069], [88.54138947, 21.63582993], [88.54138947, 21.63555527], [88.54165649, 21.63528061], [88.54193115, 21.63511086], [88.54232788, 21.63490105], [88.5427475, 21.63471031], [88.54315948, 21.63449097], [88.54360962, 21.63431931], [88.54360962, 21.63417053], [88.54444885, 21.63417053], [88.54471588, 21.63389015], [88.54528046, 21.63389015], [88.54556274, 21.63360977], [88.54666901, 21.63361168], [88.54777527, 21.63249969], [88.55000305, 21.63249016], [88.55027771, 21.63278008], [88.55166626, 21.63278008], [88.55249786, 21.63194084], [88.55278015, 21.63222313], [88.55388641, 21.63222313], [88.5541687, 21.63194656], [88.55444336, 21.63222313], [88.55500031, 21.63222313], [88.55527496, 21.63194656], [88.5561142, 21.63194656], [88.55638885, 21.63166428], [88.55750275, 21.63167], [88.5577774, 21.63138962], [88.55805206, 21.63138962], [88.55832672, 21.63111115], [88.55860901, 21.63111115], [88.55944824, 21.63027954], [88.5597229, 21.63027954], [88.55999756, 21.63000107], [88.56027985, 21.63000107], [88.56083679, 21.62943268], [88.56111145, 21.62944221], [88.56138611, 21.62916756], [88.5616684, 21.62916946], [88.56223297, 21.62861061], [88.5625, 21.62861061], [88.5633316, 21.62778282], [88.56360626, 21.62778282], [88.56388855, 21.62750053], [88.56445313, 21.62750053], [88.56472015, 21.62722015], [88.56500244, 21.62722015], [88.56555176, 21.62666702], [88.56582642, 21.62668037], [88.56639099, 21.62611008], [88.56639099, 21.62555504], [88.56777954, 21.62556267], [88.56833649, 21.62500191], [88.56861877, 21.62500191], [88.56916809, 21.62444496], [88.56944275, 21.62445068], [88.57026672, 21.62361908], [88.57055664, 21.62361908], [88.57110596, 21.62305832], [88.5716629, 21.62305832], [88.5736084, 21.62111092], [88.5736084, 21.62028122], [88.57389069, 21.62000084], [88.57472229, 21.62000084], [88.57527924, 21.61944008], [88.57499695, 21.61916733], [88.57583618, 21.61833], [88.5763855, 21.61833572], [88.58027649, 21.61444473], [88.58027649, 21.61388969], [88.58139038, 21.61277962], [88.58167267, 21.61277962], [88.58304596, 21.61138916], [88.58333588, 21.61138916], [88.58389282, 21.6108284], [88.58388519, 21.60888863], [88.58416748, 21.60861015], [88.58416748, 21.60833359], [88.58499908, 21.60750008], [88.58528137, 21.60750008], [88.58583069, 21.60695076], [88.58583069, 21.60750008], [88.58638763, 21.60695076], [88.58638763, 21.60639], [88.58611298, 21.60610962], [88.58611298, 21.60583305], [88.58666992, 21.60527611], [88.58666229, 21.60416985], [88.58693695, 21.60388947], [88.58693695, 21.60333061], [88.58721924, 21.60305405], [88.58721924, 21.60222054], [88.58750153, 21.60194206], [88.58750153, 21.60138893], [88.58721924, 21.60111046], [88.58721924, 21.60056114], [88.58693695, 21.60028267], [88.58693695, 21.59972191], [88.58666992, 21.59944534], [88.58666229, 21.59917259], [88.58693695, 21.5988903], [88.58693695, 21.59833145], [88.58666992, 21.59805489], [88.58666992, 21.59749985], [88.58638763, 21.59721756], [88.58638763, 21.59638977], [88.58611298, 21.5961113], [88.58611298, 21.59527969], [88.58638763, 21.59500122], [88.58638763, 21.59444046], [88.58721924, 21.59361076], [88.58666229, 21.59305954], [88.58666229, 21.59250069], [88.58638763, 21.59222031], [88.58638763, 21.59166527], [88.58583069, 21.59111023], [88.58583069, 21.59082985], [88.58638763, 21.59027863], [88.58638763, 21.59000015], [88.58666229, 21.58971977], [88.58666229, 21.58902359], [88.58654785, 21.5884037], [88.58634949, 21.58785248], [88.58610535, 21.58739471], [88.58583832, 21.5870266], [88.58560944, 21.58670807], [88.58547974, 21.58633041], [88.585289, 21.58600616], [88.58509827, 21.58566093], [88.58487701, 21.58530998], [88.58460236, 21.58497047], [88.58435822, 21.58462524], [88.58413696, 21.58430862], [88.5839386, 21.58399963], [88.58378601, 21.58365059], [88.58359528, 21.58334923], [88.58338165, 21.58308029], [88.58319092, 21.58279228], [88.58300018, 21.58251953], [88.58280182, 21.58226967], [88.58265686, 21.58197975], [88.58246613, 21.58172035], [88.5822525, 21.58150291], [88.58206177, 21.5812397], [88.58181763, 21.58096123], [88.58158112, 21.58058167], [88.58130646, 21.58018875], [88.5810318, 21.57978058], [88.58070374, 21.57945633], [88.58035278, 21.57917023], [88.57997894, 21.57888985], [88.57958984, 21.57858276], [88.57920837, 21.57819939], [88.57888031, 21.57776642], [88.57858276, 21.57734108], [88.57826996, 21.57697105], [88.57791901, 21.57665634], [88.57756805, 21.57633972], [88.57724762, 21.57600784], [88.57695007, 21.57566833], [88.57662964, 21.57531738], [88.57554626, 21.57417107], [88.57527924, 21.57417107], [88.57472229, 21.57361031], [88.57444763, 21.57361031], [88.57417297, 21.57333183], [88.57389069, 21.57333374], [88.57333374, 21.57305527], [88.57277679, 21.57250023], [88.57250214, 21.57250023], [88.57195282, 21.57195282], [88.5716629, 21.57195282], [88.57110596, 21.57139015], [88.5708313, 21.57139015], [88.57069397, 21.57125092], [88.57055664, 21.57111168], [88.56999969, 21.57111168], [88.56972504, 21.57083321], [88.56916809, 21.57083321], [88.5680542, 21.56972313], [88.56777954, 21.56972313], [88.56749725, 21.56944466], [88.5672226, 21.56944466], [88.56694794, 21.56916618], [88.56667328, 21.56916809], [88.56639099, 21.56888962], [88.56555939, 21.56888962], [88.5652771, 21.56916618], [88.5652771, 21.56944466], [88.56555939, 21.56972122], [88.56555939, 21.57027817], [88.5652771, 21.57027817], [88.56500244, 21.56999969], [88.56428528, 21.57034111], [88.56399536, 21.56999016], [88.56365967, 21.56960106], [88.56333923, 21.5691967], [88.56305695, 21.56944466], [88.56298065, 21.56937027], [88.56277466, 21.56916618], [88.56194305, 21.56916618], [88.5616684, 21.56944466], [88.56111145, 21.56944466], [88.56097412, 21.56930542], [88.56083679, 21.56916618], [88.55832672, 21.56916809], [88.55805206, 21.56888962], [88.5577774, 21.56888962], [88.55750275, 21.56861115], [88.55665588, 21.56861115], [88.55555725, 21.56750107], [88.55526733, 21.56750107], [88.55504608, 21.56726646], [88.55472565, 21.5672226], [88.55444336, 21.56694412], [88.5541687, 21.56694412], [88.55397797, 21.56675911], [88.55388641, 21.56666756], [88.55361938, 21.56666946], [88.55194092, 21.56500053], [88.5513916, 21.56500053], [88.5513916, 21.56472015], [88.55083466, 21.56416512], [88.55055237, 21.56417084], [88.55000305, 21.56361008], [88.54972076, 21.56361008], [88.54944611, 21.56389046], [88.54915619, 21.56389046], [88.54888916, 21.56417084], [88.54833221, 21.56417084], [88.54722595, 21.56528091], [88.54694366, 21.56527519], [88.54673004, 21.56549072], [88.54611206, 21.56611061], [88.54528046, 21.56611061], [88.54499817, 21.56640053], [88.54471588, 21.56640053], [88.54444885, 21.56666946], [88.54360962, 21.56666946], [88.54360962, 21.56750107], [88.54389191, 21.56777954], [88.54389191, 21.56805611], [88.54360962, 21.56833076], [88.54360962, 21.56861115], [88.54333496, 21.56888962], [88.54332733, 21.56972122], [88.54360962, 21.56999969], [88.54360962, 21.57055473], [88.54333496, 21.57083321], [88.54333496, 21.57170105], [88.54333496, 21.57305527], [88.54305267, 21.57333183], [88.54305267, 21.57500076], [88.54277802, 21.57500076], [88.54277802, 21.5755558], [88.54250336, 21.57583046], [88.54250336, 21.57633972], [88.54250336, 21.57676125], [88.54248047, 21.57720184], [88.54236603, 21.57761955], [88.54220581, 21.57801056], [88.54202271, 21.57839966], [88.54187012, 21.5788517], [88.54165649, 21.57929039], [88.54139709, 21.57972717], [88.54116821, 21.5802021], [88.54108429, 21.58034134], [88.54089355, 21.58064651], [88.54068756, 21.58114052], [88.54052734, 21.58166885], [88.54025269, 21.58213997], [88.53996277, 21.58255959], [88.53970337, 21.58295059], [88.53944397, 21.58332443], [88.53916931, 21.58369255], [88.53888702, 21.58407211], [88.53878021, 21.58420563], [88.53858948, 21.58443832], [88.53824615, 21.58481026], [88.53787231, 21.58518791], [88.53752899, 21.58562279], [88.5372467, 21.58608818], [88.53704834, 21.58655739], [88.53694916, 21.5869503], [88.53701019, 21.5872612], [88.5375061, 21.5875206], [88.53807068, 21.58773613], [88.53869629, 21.58788109], [88.53929901, 21.58806038], [88.53991699, 21.58819962], [88.54056549, 21.58819771], [88.54112244, 21.58836174], [88.54159546, 21.58856583], [88.54205322, 21.58873367], [88.54247284, 21.58892059], [88.54286194, 21.58916283], [88.54324341, 21.58943176], [88.54360962, 21.58972549], [88.54397583, 21.59003258], [88.54438019, 21.59032059], [88.54476929, 21.59062958], [88.5451355, 21.59095192], [88.54551697, 21.59124947], [88.54589844, 21.59154892], [88.5463028, 21.59184074], [88.54669189, 21.59221077], [88.54707336, 21.59260941], [88.54747772, 21.59299088], [88.54789734, 21.5933094], [88.54831696, 21.59361076], [88.54878235, 21.59390068], [88.54928589, 21.59421539], [88.54980469, 21.59458351], [88.55032349, 21.59501457], [88.55084229, 21.59546089], [88.55137634, 21.59589958], [88.55191803, 21.59630966], [88.55249786, 21.59662819], [88.5530777, 21.59687805], [88.55362701, 21.59712029], [88.55409241, 21.59741783], [88.55448151, 21.5977211], [88.55484772, 21.59801483], [88.55521393, 21.5982933], [88.55560303, 21.59856033], [88.5559845, 21.59882736], [88.55635834, 21.59911156], [88.5566864, 21.5994606], [88.55698395, 21.5998764], [88.55724335, 21.6003418], [88.55745697, 21.60085106], [88.55760956, 21.60140991], [88.55750275, 21.6016674], [88.5577774, 21.60194206], [88.5577774, 21.60333252], [88.55666351, 21.60444641], [88.5561142, 21.60388947], [88.55610657, 21.60277939], [88.55638885, 21.60251045], [88.55639648, 21.60214996], [88.55639648, 21.60161972], [88.55630493, 21.6010704], [88.55607605, 21.60056114], [88.55574036, 21.60009956], [88.55532074, 21.59971619], [88.55486298, 21.59939003], [88.55436707, 21.59910011], [88.5539093, 21.59883118], [88.55345154, 21.5985527], [88.55298615, 21.59826088], [88.55251312, 21.59798431], [88.55204773, 21.59771347], [88.55160522, 21.59745979], [88.55119324, 21.59722519], [88.55084229, 21.59698105], [88.55052185, 21.59675026], [88.55020905, 21.59653664], [88.54988861, 21.59633064], [88.54955292, 21.59610176], [88.54917908, 21.59585953], [88.54876709, 21.59560013], [88.54836273, 21.59526443], [88.54795837, 21.59493446], [88.54754639, 21.59464073], [88.54715729, 21.59433365], [88.54677582, 21.59399986], [88.54641724, 21.59365273], [88.54607391, 21.59332657], [88.54573059, 21.59302902], [88.54537964, 21.59273911], [88.5450058, 21.59246063], [88.54464722, 21.59213066], [88.54431152, 21.59179115], [88.5439682, 21.59145546], [88.54364777, 21.59112549], [88.54335022, 21.59082985], [88.54304504, 21.59059715], [88.54271698, 21.59044075], [88.5424118, 21.59025192], [88.54212189, 21.59006119], [88.54177856, 21.58989906], [88.54144287, 21.58971977], [88.54104614, 21.58954811], [88.54055023, 21.58945847], [88.5399704, 21.58943176], [88.53933716, 21.58941078], [88.53874969, 21.5893383], [88.53826141, 21.58915901], [88.5378418, 21.58897018], [88.53740692, 21.58876991], [88.5369339, 21.58839798], [88.53659821, 21.58839417], [88.53633118, 21.58859062], [88.53604126, 21.58879852], [88.53569794, 21.58892822], [88.53544617, 21.5891304], [88.53517151, 21.58927917], [88.5348587, 21.58945084], [88.53450012, 21.58966446], [88.53411102, 21.58992195], [88.53362274, 21.59013939], [88.53312683, 21.59038925], [88.53273773, 21.59073067], [88.53231812, 21.59099007], [88.53186035, 21.59119987], [88.53141785, 21.59140015], [88.53102112, 21.59161949], [88.53056335, 21.59184647], [88.53015137, 21.59206963], [88.52974701, 21.5922966], [88.52955627, 21.59242058], [88.52937317, 21.59254265], [88.5289917, 21.59278107], [88.52858734, 21.59300995], [88.5281601, 21.59320831], [88.52765656, 21.59337044], [88.52749634, 21.59361076], [88.52722168, 21.59361076], [88.5266571, 21.59416962], [88.52639008, 21.59416771], [88.52610779, 21.59444427], [88.52583313, 21.59444046], [88.52527618, 21.59500122], [88.52500153, 21.59500122], [88.52443695, 21.59555817], [88.52388763, 21.59555626], [88.52361298, 21.59583282], [88.52333069, 21.59583282], [88.5228653, 21.59583282], [88.52242279, 21.59583282], [88.5220108, 21.59583092], [88.52163696, 21.59587097], [88.5213089, 21.59601974], [88.52091217, 21.59609985], [88.52044678, 21.59614944], [88.5200119, 21.59634018], [88.51947784, 21.59642982], [88.51899719, 21.59666061], [88.51853943, 21.59686089], [88.51805115, 21.59698105], [88.51763153, 21.59716034], [88.5171814, 21.59724998], [88.51676178, 21.59739113], [88.51633453, 21.59748459], [88.51590729, 21.59753036], [88.51551056, 21.59767723], [88.51508331, 21.59779358], [88.5146637, 21.59795189], [88.51418304, 21.5980854], [88.51370239, 21.59833145], [88.51321411, 21.59860611], [88.51271057, 21.59888458], [88.51223755, 21.59918022], [88.51187897, 21.59956551], [88.51148987, 21.59982109], [88.51125336, 21.60013962], [88.51107025, 21.60042763], [88.51085663, 21.60064125], [88.51066589, 21.60087013], [88.51053619, 21.60115051], [88.51027679, 21.60138893], [88.51027679, 21.60194206], [88.51000214, 21.60222054], [88.51027679, 21.60250092], [88.51027679, 21.60333061], [88.51055908, 21.60361099], [88.51055908, 21.60388947], [88.51083374, 21.60416412], [88.51083374, 21.60444641], [88.5111084, 21.60472107], [88.5111084, 21.60527611], [88.51139069, 21.60555649], [88.51139069, 21.60583305], [88.51167297, 21.60610962], [88.51167297, 21.60778046], [88.51194763, 21.60806084], [88.51194763, 21.6091671], [88.51167297, 21.60943985], [88.51250458, 21.61027908], [88.51277924, 21.61056137], [88.51333618, 21.61055565], [88.51361084, 21.61083412], [88.51389313, 21.61056137], [88.51472473, 21.61055565], [88.51499939, 21.61083412], [88.51526642, 21.6108284], [88.51555634, 21.61111069], [88.51555634, 21.61166573], [88.51526642, 21.61193848], [88.51526642, 21.61277962], [88.51555634, 21.6130619], [88.51555634, 21.61444473], [88.51526642, 21.61471939], [88.51526642, 21.61528015], [88.51777649, 21.61777687], [88.51777649, 21.61833], [88.51805878, 21.61861038], [88.51803589, 21.61876106], [88.51824188, 21.6192112], [88.51843262, 21.61971092], [88.51870728, 21.62020111], [88.51908875, 21.62063026], [88.51938629, 21.62111092], [88.51972198, 21.62166977], [88.52027893, 21.62166786], [88.52055359, 21.62194443], [88.52083588, 21.62194443], [88.52138519, 21.62249947], [88.52166748, 21.62249947], [88.52278137, 21.62361908], [88.52278137, 21.62388992], [88.52305603, 21.62416649], [88.52305603, 21.62471771], [88.52332306, 21.62500191], [88.52333069, 21.62527847], [88.52416992, 21.62611008], [88.52416992, 21.62666702], [88.52361298, 21.62722015], [88.52361298, 21.62778282], [88.52332306, 21.62778282], [88.52305603, 21.62805939], [88.5222168, 21.62805939], [88.52194214, 21.62778282], [88.52083588, 21.62888908], [88.52105713, 21.62906075], [88.52127838, 21.62952042], [88.52144623, 21.63005257], [88.52167511, 21.63054657], [88.52186584, 21.63100052], [88.521698, 21.63136482], [88.52150726, 21.63169861], [88.52137756, 21.63207054], [88.52122498, 21.63240623], [88.52111816, 21.63278008], [88.5210495, 21.63318062], [88.52088928, 21.63349152], [88.52083588, 21.63382912], [88.52078247, 21.63417816], [88.52059937, 21.63451004], [88.52054596, 21.63498116], [88.52050781, 21.63552284], [88.52037048, 21.63607025], [88.52050781, 21.63668251], [88.52060699, 21.63731194], [88.52085114, 21.63779831], [88.52106476, 21.6382618], [88.52115631, 21.63875008], [88.52133179, 21.6392498], [88.52127838, 21.63967514], [88.52112579, 21.64005089], [88.52104187, 21.64043999], [88.52086639, 21.64076996], [88.52079773, 21.64113998], [88.52065277, 21.64145279], [88.52056885, 21.64183044], [88.52050018, 21.64230728], [88.52031708, 21.64283943], [88.52028656, 21.64352989], [88.52039337, 21.64426994], [88.52059174, 21.64492989], [88.52083588, 21.64549637], [88.52111053, 21.6459713], [88.52118683, 21.64608192], [88.52139282, 21.64637947], [88.52163696, 21.64678192], [88.52185059, 21.64721107], [88.5220108, 21.64768028], [88.52223206, 21.6482296], [88.52249908, 21.64874077], [88.52272797, 21.64923096], [88.52278137, 21.64977074], [88.52281952, 21.65028954], [88.52297211, 21.65079117], [88.52308655, 21.65132141], [88.52333832, 21.6517601], [88.52360535, 21.65216637], [88.52384949, 21.65254021], [88.52407074, 21.65288925], [88.52437592, 21.65320015], [88.52469635, 21.65328026], [88.52501678, 21.65304947], [88.52539063, 21.65265274], [88.52572632, 21.65212059], [88.52613831, 21.65166473], [88.52653503, 21.65120125], [88.52685547, 21.65067863], [88.5271225, 21.65014076], [88.52745056, 21.64965057], [88.52777863, 21.64915466], [88.52812958, 21.6486702], [88.52861023, 21.6483326], [88.52861023, 21.64777756], [88.52916718, 21.64722061], [88.52916718, 21.64694595], [88.52944183, 21.64666748], [88.52944946, 21.64639091], [88.53028107, 21.64556122], [88.53028107, 21.64528084], [88.53083038, 21.64472008], [88.53349304, 21.64205933], [88.53359222, 21.64192772], [88.53383636, 21.64160919], [88.53425598, 21.64115906], [88.53472137, 21.64071083], [88.53521729, 21.64025116], [88.53570557, 21.63978958], [88.53623199, 21.63936043], [88.53671265, 21.63888931], [88.53721619, 21.63862038]]], [[[88.72885132, 21.63708115], [88.72886658, 21.63659096], [88.72889709, 21.63612938], [88.7289505, 21.63572693], [88.72905731, 21.63533974], [88.72914124, 21.63493347], [88.72922516, 21.63451004], [88.72936249, 21.63409615], [88.72943878, 21.63366318], [88.72952271, 21.63321114], [88.72966766, 21.63279533], [88.72981262, 21.63236046], [88.72995758, 21.63190079], [88.73007202, 21.63143539], [88.7302475, 21.63097], [88.73040771, 21.63049507], [88.73060608, 21.63009071], [88.73084259, 21.62973213], [88.73105621, 21.62938118], [88.7312088, 21.62898064], [88.73137665, 21.62859535], [88.73153687, 21.6282196], [88.73174286, 21.6279335], [88.73200226, 21.62771034], [88.73226929, 21.62745094], [88.7325592, 21.62712097], [88.73287201, 21.62673378], [88.7332077, 21.62633133], [88.73352051, 21.6258831], [88.73377228, 21.62535858], [88.73396301, 21.62477112], [88.73413086, 21.62413979], [88.73421478, 21.62347221], [88.73416138, 21.62280846], [88.73407745, 21.62219048], [88.73394775, 21.6216507], [88.73387146, 21.62112808], [88.73381805, 21.62065887], [88.73369598, 21.62024117], [88.73362732, 21.61982155], [88.73361206, 21.61942673], [88.7335968, 21.61901283], [88.73355103, 21.61856842], [88.73345184, 21.61810112], [88.73340607, 21.61758041], [88.7334671, 21.6170311], [88.73358154, 21.61648941], [88.7336731, 21.61592102], [88.73381042, 21.61538124], [88.7339325, 21.61486053], [88.73407745, 21.61442566], [88.73413849, 21.61400986], [88.73416138, 21.61363029], [88.73419952, 21.61330032], [88.73439026, 21.6129818], [88.73454285, 21.61266327], [88.73470306, 21.61239052], [88.73485565, 21.61212349], [88.73501587, 21.61188126], [88.73519135, 21.61164284], [88.73537445, 21.61137199], [88.73558044, 21.61105156], [88.73587036, 21.61067963], [88.73623657, 21.61026955], [88.73670197, 21.60984039], [88.73726654, 21.60943985], [88.73789978, 21.60910606], [88.73853302, 21.60874939], [88.73914337, 21.60836983], [88.73977661, 21.60800934], [88.74040985, 21.60767174], [88.74106598, 21.6074028], [88.7416687, 21.6071682], [88.74217224, 21.60694122], [88.74262238, 21.60674095], [88.74305725, 21.60659981], [88.74343109, 21.60642242], [88.74382019, 21.60627747], [88.7441864, 21.60612106], [88.74458313, 21.60597992], [88.74500275, 21.60586548], [88.74543762, 21.60578918], [88.74585724, 21.60567284], [88.74626923, 21.60556984], [88.74669647, 21.60547066], [88.74707031, 21.60531616], [88.74746704, 21.60518265], [88.7478714, 21.60505295], [88.74830627, 21.60494041], [88.74874115, 21.60474968], [88.74921417, 21.60458183], [88.74975586, 21.60440636], [88.75035095, 21.60421944], [88.75096893, 21.60405922], [88.75151825, 21.60378265], [88.75200653, 21.60342407], [88.75251007, 21.60310173], [88.75299835, 21.60282516], [88.75345612, 21.60259056], [88.75392914, 21.60240936], [88.75432587, 21.60214996], [88.75469208, 21.60181046], [88.75510406, 21.60145378], [88.75556183, 21.60111809], [88.75602722, 21.60079002], [88.75647736, 21.60044098], [88.7568512, 21.60005379], [88.75709534, 21.59957504], [88.75718689, 21.59897995], [88.75711823, 21.5983429], [88.75683594, 21.59779167], [88.75636292, 21.59745026], [88.755867, 21.59716034], [88.75540924, 21.59691048], [88.75497437, 21.59667778], [88.75453186, 21.59645271], [88.75408936, 21.59619141], [88.75360107, 21.59593964], [88.75311279, 21.59568024], [88.75263977, 21.59539413], [88.75222778, 21.59506989], [88.75182343, 21.59475517], [88.75138855, 21.59447289], [88.75093842, 21.59422493], [88.75056458, 21.59390259], [88.75022125, 21.59354019], [88.74991608, 21.59314919], [88.74957275, 21.5927906], [88.7492218, 21.59244537], [88.748909, 21.59206963], [88.74861908, 21.59168816], [88.74835205, 21.59132957], [88.74813843, 21.59095192], [88.74799347, 21.5905304], [88.74780273, 21.59013939], [88.74762726, 21.58973122], [88.74746704, 21.58930969], [88.74729156, 21.58884811], [88.74723053, 21.58827972], [88.7472229, 21.58764267], [88.74723053, 21.58698082], [88.74727631, 21.58634949], [88.74742126, 21.58580971], [88.74740601, 21.58530998], [88.74727631, 21.58486176], [88.74724579, 21.58443832], [88.74729156, 21.58399963], [88.74738312, 21.5835762], [88.74729919, 21.58310127], [88.74723816, 21.58255959], [88.7472229, 21.5819397], [88.7472229, 21.58134079], [88.7472229, 21.58078957], [88.7472229, 21.58029938], [88.7472229, 21.57985115], [88.7472229, 21.57971954], [88.7472229, 21.57833481], [88.74694824, 21.57806015], [88.74694824, 21.57749939], [88.74666595, 21.57749939], [88.74555206, 21.57639122], [88.74500275, 21.57639122], [88.74472046, 21.57611084], [88.74415588, 21.57611084], [88.74388885, 21.57583046], [88.74305725, 21.57583046], [88.74276733, 21.57611084], [88.7416687, 21.57611084], [88.74138641, 21.57583046], [88.7408371, 21.57583237], [88.74028015, 21.57527733], [88.74028778, 21.57500076], [88.7408371, 21.57444382], [88.7408371, 21.57388878], [88.74111176, 21.57361031], [88.74054718, 21.5730629], [88.74028015, 21.57333374], [88.73999786, 21.57333374], [88.73972321, 21.57305527], [88.7388916, 21.5730629], [88.73860931, 21.57278252], [88.73832703, 21.57278252], [88.73805237, 21.5730629], [88.73722076, 21.5730629], [88.73583221, 21.57167244], [88.73555756, 21.57167244], [88.7352829, 21.57195282], [88.73472595, 21.57195282], [88.73388672, 21.57278252], [88.73221588, 21.57278252], [88.73194122, 21.5730629], [88.73139191, 21.5730629], [88.73111725, 21.57278252], [88.73027802, 21.57278252], [88.73000336, 21.5730629], [88.72833252, 21.57305527], [88.72805786, 21.57333374], [88.72638702, 21.57333183], [88.72611237, 21.57361031], [88.72583008, 21.57361031], [88.72556305, 21.57389069], [88.72499084, 21.57389069], [88.72471619, 21.57417107], [88.72389221, 21.57417107], [88.7233429, 21.57361031], [88.72305298, 21.57361031], [88.72222137, 21.57444382], [88.72166443, 21.57444382], [88.72138977, 21.57472229], [88.72083282, 21.57472038], [88.72055817, 21.57500076], [88.72027588, 21.57500076], [88.72000122, 21.57528114], [88.71943665, 21.57528114], [88.71833038, 21.57639122], [88.71806335, 21.57639122], [88.71778107, 21.57666969], [88.71722412, 21.57666588], [88.71694183, 21.57694244], [88.71666718, 21.57694244], [88.71639252, 21.57722473], [88.71611786, 21.57722092], [88.71499634, 21.57834053], [88.71444702, 21.57833481], [88.7141571, 21.57860947], [88.7141571, 21.57888985], [88.71389008, 21.57916451], [88.71389008, 21.57971954], [88.71333313, 21.5802803], [88.71333313, 21.58055687], [88.71305847, 21.58083344], [88.71333313, 21.58111191], [88.71305084, 21.58138084], [88.71305084, 21.58167076], [88.71221924, 21.58250046], [88.71221924, 21.58278084], [88.71194458, 21.58277893], [88.71138763, 21.58332825], [88.71138763, 21.58361053], [88.71111298, 21.58389091], [88.71111298, 21.58416748], [88.71083069, 21.58444405], [88.71083069, 21.58472061], [88.71055603, 21.58499908], [88.71055603, 21.58527756], [88.70999146, 21.58583069], [88.70999146, 21.58610916], [88.70944214, 21.58667183], [88.70948029, 21.5869503], [88.70940399, 21.58732605], [88.70928192, 21.58765411], [88.70913696, 21.58797264], [88.70892334, 21.58828163], [88.70865631, 21.58860016], [88.70849609, 21.58898544], [88.70832825, 21.5893383], [88.70818329, 21.5897007], [88.70802307, 21.59007072], [88.70793915, 21.59044647], [88.707901, 21.59082985], [88.7078476, 21.5912075], [88.70774078, 21.5915947], [88.70770264, 21.5920105], [88.70767212, 21.59245491], [88.70761108, 21.59287071], [88.70748901, 21.59324074], [88.70735931, 21.59355927], [88.70726013, 21.59387016], [88.70720673, 21.59422112], [88.70720673, 21.59459114], [88.70720673, 21.59495926], [88.70723724, 21.59530258], [88.70730591, 21.59562111], [88.70752716, 21.59589005], [88.70781708, 21.59613037], [88.70809937, 21.59638023], [88.70841217, 21.59662056], [88.70871735, 21.59683037], [88.70889282, 21.59709167], [88.70904541, 21.59734535], [88.70917511, 21.59749222], [88.70916748, 21.59972191], [88.70944214, 21.60000038], [88.70944214, 21.60055542], [88.7097168, 21.60083008], [88.7097168, 21.60111046], [88.70999908, 21.60138893], [88.70999146, 21.6047802], [88.70999146, 21.60639], [88.71028137, 21.60667038], [88.71028137, 21.60694695], [88.71055603, 21.6072197], [88.71055603, 21.61000061], [88.71111298, 21.61055565], [88.71111298, 21.6108284], [88.71138763, 21.61111069], [88.71138763, 21.61166573], [88.71166992, 21.6119442], [88.71166992, 21.61222076], [88.71138763, 21.61249924], [88.71138763, 21.61277962], [88.71111298, 21.6130619], [88.71111298, 21.61388969], [88.71138763, 21.61417007], [88.71138763, 21.61444473], [88.71134186, 21.61497116], [88.71166992, 21.61527824], [88.71166992, 21.61611176], [88.71185303, 21.61629677], [88.71221924, 21.61667061], [88.71277618, 21.61666679], [88.71277618, 21.61722183], [88.71305084, 21.61749077], [88.71305084, 21.61889076], [88.71277618, 21.61916733], [88.71277618, 21.61972046], [88.71250153, 21.62000084], [88.71250153, 21.6202755], [88.71193695, 21.62083054], [88.71193695, 21.62111092], [88.71250153, 21.62166977], [88.71277618, 21.62166786], [88.71305847, 21.62194443], [88.71333313, 21.62194443], [88.71360779, 21.62222099], [88.71360779, 21.62249947], [88.71333313, 21.62277985], [88.71333313, 21.62305641], [88.71305084, 21.62333107], [88.71305084, 21.62388992], [88.71277618, 21.62416649], [88.71277618, 21.62471771], [88.71305084, 21.62500191], [88.71305084, 21.62528038], [88.71333313, 21.62555504], [88.71333313, 21.6258316], [88.71389008, 21.62639046], [88.71389008, 21.62668037], [88.71499634, 21.6277771], [88.71499634, 21.62833214], [88.71527863, 21.62833023], [88.71527863, 21.62916756], [88.71555328, 21.62944221], [88.71555328, 21.62972069], [88.7158432, 21.63000107], [88.7158432, 21.63027954], [88.71611023, 21.6305542], [88.71611786, 21.63083076], [88.71639252, 21.63111115], [88.71639252, 21.63138962], [88.71666718, 21.63166428], [88.71666718, 21.63194656], [88.71694183, 21.63222313], [88.71694183, 21.63249969], [88.71778107, 21.63333321], [88.71916962, 21.63333321], [88.71943665, 21.63305092], [88.71943665, 21.63417053], [88.71971893, 21.63444519], [88.71971893, 21.63471985], [88.72000122, 21.63500023], [88.72000122, 21.63555527], [88.72027588, 21.63582993], [88.72027588, 21.63777733], [88.72083282, 21.63833427], [88.72194672, 21.63833427], [88.7223587, 21.63824654], [88.72281647, 21.63801003], [88.72319031, 21.63764191], [88.72357941, 21.63737106], [88.72399902, 21.63718796], [88.72445679, 21.63705063], [88.72501373, 21.63704491], [88.72554779, 21.63714981], [88.72606659, 21.63728905], [88.72655487, 21.63751602], [88.72704315, 21.63780022], [88.72749329, 21.63812065], [88.72795105, 21.63836098], [88.72836304, 21.63834953], [88.72860718, 21.63801956], [88.72879028, 21.63758278], [88.72885132, 21.63708115]]], [[[88.77194214, 21.65306282], [88.77249908, 21.65250015], [88.77278137, 21.65250015], [88.77278137, 21.65222168], [88.77222443, 21.65166664], [88.7722168, 21.65138817], [88.77388763, 21.64972115], [88.77388763, 21.64916611], [88.77416992, 21.64888954], [88.77416992, 21.64833069], [88.77333069, 21.64749718], [88.77471924, 21.64750099], [88.77555847, 21.64666939], [88.77555847, 21.64528084], [88.77527618, 21.64500046], [88.77500153, 21.64500046], [88.77500153, 21.64472008], [88.77555847, 21.64416695], [88.77555847, 21.64361], [88.77500153, 21.64305305], [88.77497864, 21.64275932], [88.77471924, 21.64249992], [88.77333069, 21.64249992], [88.77333069, 21.64221954], [88.77249908, 21.64222145], [88.77194214, 21.64166641], [88.77194214, 21.64138985], [88.77278137, 21.64056015], [88.77278137, 21.64027977], [88.77305603, 21.63999939], [88.77278137, 21.63972282], [88.77278137, 21.63666725], [88.7722168, 21.63611031], [88.77166748, 21.63611031], [88.77139282, 21.63582993], [88.77111053, 21.63583374], [88.77111053, 21.63555527], [88.77083588, 21.63528061], [88.77083588, 21.63500023], [88.77054596, 21.63471985], [88.77055359, 21.63138962], [88.77111053, 21.63083076], [88.77111053, 21.62805557], [88.77166748, 21.62750053], [88.77166748, 21.62722015], [88.77249908, 21.62638855], [88.77249908, 21.62556267], [88.7722168, 21.62528038], [88.7722168, 21.62471771], [88.77249908, 21.62444496], [88.77249908, 21.6241684], [88.77278137, 21.62388992], [88.77278137, 21.62333107], [88.77305603, 21.62305641], [88.77305603, 21.62249947], [88.77333069, 21.62222099], [88.77333069, 21.62194443], [88.77361298, 21.62166786], [88.77361298, 21.62138939], [88.77388763, 21.62111092], [88.77388763, 21.61972046], [88.77462006, 21.61899185], [88.77583313, 21.61777687], [88.77639008, 21.61778069], [88.77694702, 21.61721992], [88.77694702, 21.61666679], [88.77722168, 21.61639023], [88.77694702, 21.61610985], [88.77694702, 21.61583138], [88.77639008, 21.61527824], [88.77639008, 21.61510086], [88.77639008, 21.61499977], [88.77749634, 21.61499977], [88.77777863, 21.61471939], [88.77805328, 21.6147213], [88.77861023, 21.61416626], [88.77889252, 21.61417007], [88.77916718, 21.61388969], [88.77944183, 21.61388969], [88.78028107, 21.6130619], [88.78083038, 21.6130619], [88.78115082, 21.61252975], [88.7815094, 21.61211967], [88.78192139, 21.61172104], [88.782341, 21.61130905], [88.78250122, 21.61111069], [88.78333282, 21.61027908], [88.78333282, 21.61000061], [88.7841568, 21.60917091], [88.78472137, 21.60917091], [88.78491211, 21.60868835], [88.78524017, 21.60834122], [88.78557587, 21.60795021], [88.78591919, 21.60757065], [88.78627777, 21.60724068], [88.78663635, 21.60691261], [88.78694916, 21.6065197], [88.7872467, 21.60611725], [88.78756714, 21.60573959], [88.78795624, 21.60536957], [88.78842926, 21.6049633], [88.78890228, 21.60449982], [88.78936005, 21.60408974], [88.78943634, 21.60388947], [88.79055786, 21.60277939], [88.79055786, 21.60222054], [88.79083252, 21.60194206], [88.79083252, 21.6016674], [88.79065704, 21.60145187], [88.79042053, 21.6012001], [88.79021454, 21.60095215], [88.78992462, 21.60072708], [88.78965759, 21.60050011], [88.78933716, 21.60029984], [88.78896332, 21.60013962], [88.78855896, 21.59997749], [88.78843689, 21.5999279], [88.78813934, 21.59980392], [88.7877121, 21.5996151], [88.78730774, 21.59939957], [88.78691864, 21.59915924], [88.78652191, 21.5989399], [88.78607941, 21.59877205], [88.78566742, 21.59855843], [88.7852478, 21.59833145], [88.78481293, 21.59811974], [88.78449249, 21.59794235], [88.78444672, 21.59805489], [88.78434753, 21.59795761], [88.78416443, 21.59777832], [88.78360748, 21.59777832], [88.78333282, 21.59749985], [88.78305817, 21.59749985], [88.78277588, 21.59721756], [88.78250122, 21.59722137], [88.78221893, 21.59694481], [88.78221893, 21.5961113], [88.78283691, 21.59628105], [88.78340912, 21.59641266], [88.78388214, 21.59657097], [88.78430176, 21.59669113], [88.78468323, 21.59684944], [88.78508759, 21.59701538], [88.78553772, 21.59720993], [88.786026, 21.59744263], [88.78658295, 21.59765053], [88.78713226, 21.5978508], [88.78764343, 21.59804726], [88.78813171, 21.5982399], [88.78859711, 21.59842873], [88.78896332, 21.59869194], [88.78930664, 21.59897804], [88.78951263, 21.59910774], [88.78972626, 21.59924126], [88.79019928, 21.59950638], [88.79071808, 21.59976959], [88.79123688, 21.59979248], [88.79178619, 21.59959984], [88.79239655, 21.59947968], [88.79309845, 21.59954453], [88.79373169, 21.59972954], [88.79425049, 21.59977913], [88.7947464, 21.59935951], [88.79510498, 21.5987587], [88.79519653, 21.59813499], [88.79528046, 21.59804916], [88.79528046, 21.59777832], [88.79556274, 21.59749985], [88.79555511, 21.59722137], [88.79582977, 21.59694481], [88.79582977, 21.59666634], [88.79638672, 21.59610939], [88.79638672, 21.59555626], [88.79666901, 21.59527969], [88.79666901, 21.59472084], [88.79694366, 21.59444427], [88.79722595, 21.59444427], [88.79722595, 21.59416771], [88.7977829, 21.59361076], [88.79777527, 21.59222221], [88.79805756, 21.59194565], [88.79805756, 21.59166527], [88.7977829, 21.59139061], [88.7977829, 21.59111023], [88.79750061, 21.59083557], [88.79750061, 21.59055328], [88.79722595, 21.59028053], [88.79722595, 21.59000015], [88.79638672, 21.58917046], [88.79638672, 21.58889008], [88.79611206, 21.5886097], [88.79611206, 21.58805466], [88.79555511, 21.58749962], [88.79556274, 21.58722115], [88.79416656, 21.5858326], [88.79389191, 21.5858326], [88.79292297, 21.58486366], [88.79194641, 21.58389091], [88.79165649, 21.58389091], [88.79089355, 21.58311653], [88.79027557, 21.58250046], [88.79027557, 21.58222198], [88.79000092, 21.58194351], [88.78916931, 21.58194351], [88.78833008, 21.58111191], [88.78833008, 21.58083344], [88.78805542, 21.58083344], [88.78778076, 21.58055687], [88.78666687, 21.58056068], [88.78639221, 21.5802803], [88.78527069, 21.5802803], [88.78499603, 21.57999992], [88.78472137, 21.57999992], [88.78444672, 21.5802803], [88.78360748, 21.5802803], [88.78333282, 21.57999992], [88.7822113, 21.57999992], [88.78193665, 21.5802803], [88.78056335, 21.5802803], [88.78028107, 21.57999992], [88.77971649, 21.57999992], [88.77944183, 21.5802803], [88.77861023, 21.5802803], [88.77855682, 21.58022499], [88.7783432, 21.57999992], [88.77777863, 21.57999992], [88.77749634, 21.57971954], [88.77722168, 21.57972145], [88.77694702, 21.57944679], [88.77666473, 21.57944679], [88.77639008, 21.57972145], [88.77555847, 21.57972145], [88.77500153, 21.57916451], [88.77471924, 21.57917023], [88.77443695, 21.57888985], [88.77388763, 21.57888985], [88.77361298, 21.57860947], [88.77333069, 21.57861137], [88.77305603, 21.57833481], [88.77249908, 21.57834053], [88.7722168, 21.57806015], [88.77054596, 21.57806015], [88.7702713, 21.57777977], [88.76999664, 21.57777977], [88.76972198, 21.57749939], [88.76944733, 21.57749939], [88.76917267, 21.57722092], [88.76860809, 21.57722473], [88.76833344, 21.57694244], [88.76721954, 21.57694244], [88.76694489, 21.57666588], [88.76638794, 21.57666969], [88.76611328, 21.57639122], [88.76583099, 21.57639122], [88.76555634, 21.57611084], [88.7638855, 21.57611084], [88.76361084, 21.57583237], [88.76194763, 21.57583237], [88.76167297, 21.57611084], [88.75805664, 21.57611084], [88.75776672, 21.57583046], [88.75611115, 21.57583046], [88.75583649, 21.57611084], [88.75499725, 21.57611084], [88.75444794, 21.57666969], [88.7519455, 21.57666588], [88.75166321, 21.57694244], [88.75110626, 21.57694054], [88.75055695, 21.57749939], [88.75026703, 21.57749939], [88.74944305, 21.57833481], [88.74944305, 21.57860947], [88.74916077, 21.57888985], [88.7491684, 21.57916451], [88.74888611, 21.57944107], [88.74888611, 21.5802803], [88.74861145, 21.58055687], [88.74888611, 21.58082962], [88.74888611, 21.58166885], [88.74861145, 21.5819397], [88.74861908, 21.58267021], [88.74861145, 21.58331108], [88.74861145, 21.58396149], [88.74861145, 21.58460045], [88.74861908, 21.58523941], [88.74864197, 21.58587646], [88.74869537, 21.58650398], [88.748703, 21.58711052], [88.74868011, 21.58768845], [88.74876404, 21.58821678], [88.74887085, 21.5887146], [88.74894714, 21.58918953], [88.74909973, 21.58963013], [88.7492218, 21.59010506], [88.74944305, 21.59059334], [88.74971008, 21.59111595], [88.75002289, 21.59165192], [88.75040436, 21.59214973], [88.75086975, 21.59259415], [88.75137329, 21.59299469], [88.75195313, 21.59332085], [88.75248718, 21.59362984], [88.75300598, 21.59395981], [88.753479, 21.59431839], [88.75395203, 21.59468651], [88.75449371, 21.59501266], [88.75508118, 21.59527969], [88.75565338, 21.595541], [88.75613403, 21.59579468], [88.75621033, 21.59580421], [88.7563858, 21.59583282], [88.75666809, 21.5961113], [88.75694275, 21.5961113], [88.75805664, 21.59721756], [88.75805664, 21.59749985], [88.75836182, 21.5981102], [88.75850677, 21.59867859], [88.75847626, 21.59922028], [88.75836182, 21.59966278], [88.75823975, 21.60003853], [88.75805664, 21.6003437], [88.75782776, 21.60067177], [88.75756836, 21.60104561], [88.75717926, 21.60141182], [88.75669861, 21.60182953], [88.75617981, 21.60229874], [88.75565338, 21.60277367], [88.75512695, 21.60321045], [88.7546463, 21.60362053], [88.75417328, 21.60400009], [88.75366974, 21.60434723], [88.75306702, 21.60464287], [88.75238037, 21.60487938], [88.75167847, 21.60514069], [88.75096893, 21.60542107], [88.75025177, 21.60565948], [88.74952698, 21.60589027], [88.74884033, 21.60612869], [88.74820709, 21.60638428], [88.747612, 21.60663033], [88.74700165, 21.60684013], [88.74635315, 21.60695076], [88.74568176, 21.60705948], [88.74505615, 21.60725021], [88.7444458, 21.60749054], [88.74384308, 21.60771751], [88.74317932, 21.60787773], [88.7425766, 21.60808182], [88.74204254, 21.60832024], [88.74151611, 21.60859108], [88.7410202, 21.60881805], [88.7405014, 21.6089859], [88.74002075, 21.60920334], [88.7395401, 21.60945129], [88.73903656, 21.60972023], [88.73851776, 21.61001968], [88.73796844, 21.61037827], [88.73744965, 21.61084938], [88.73693085, 21.61137009], [88.7364502, 21.6118927], [88.73607635, 21.61240959], [88.73575592, 21.61288071], [88.73555756, 21.61333847], [88.73539734, 21.61376953], [88.73529053, 21.61419106], [88.73517609, 21.61461067], [88.73506927, 21.61501312], [88.73501587, 21.6154747], [88.73500824, 21.61595154], [88.73500824, 21.61642838], [88.73501587, 21.61688042], [88.73500824, 21.61730003], [88.73500824, 21.61770058], [88.73500824, 21.61809158], [88.73500824, 21.61847115], [88.73500824, 21.61888123], [88.73501587, 21.61931992], [88.73501587, 21.61977959], [88.73505402, 21.62023735], [88.73512268, 21.62068939], [88.73523712, 21.62114716], [88.73529816, 21.62162018], [88.73539734, 21.62207985], [88.73555756, 21.62222099], [88.73555756, 21.62277985], [88.73610687, 21.62333107], [88.73610687, 21.62361908], [88.73555756, 21.6241684], [88.73555756, 21.62445068], [88.73527527, 21.62488937], [88.7350769, 21.6252346], [88.73493958, 21.62556267], [88.73475647, 21.6258316], [88.73460388, 21.62612915], [88.73442841, 21.6264801], [88.73419189, 21.62689972], [88.7338562, 21.62733078], [88.7334671, 21.62778854], [88.73306274, 21.62825012], [88.73264313, 21.62869644], [88.7322998, 21.62914085], [88.73205566, 21.62964821], [88.7318573, 21.63015938], [88.73162079, 21.63070107], [88.73132324, 21.63124657], [88.73108673, 21.63188171], [88.73086548, 21.63251114], [88.73068237, 21.63310051], [88.73052216, 21.63367081], [88.73039246, 21.63414764], [88.73036957, 21.63466072], [88.73031616, 21.63516045], [88.73029327, 21.63569069], [88.73027039, 21.63624954], [88.73020935, 21.63680267], [88.73007202, 21.63731384], [88.72998047, 21.63783455], [88.7298584, 21.63834953], [88.72970581, 21.63887978], [88.72955322, 21.63941002], [88.72956848, 21.6399498], [88.72982025, 21.64040947], [88.7301712, 21.64079094], [88.73058319, 21.64115906], [88.73104095, 21.64154053], [88.7315979, 21.64189529], [88.73206329, 21.64218712], [88.73219299, 21.64226913], [88.73277283, 21.64269829], [88.7333374, 21.64314079], [88.73390961, 21.64357758], [88.73448944, 21.64396858], [88.73503113, 21.64432907], [88.73558044, 21.64463615], [88.73618317, 21.6448307], [88.73686981, 21.64491272], [88.73757172, 21.64492989], [88.73826599, 21.64492035], [88.73895264, 21.64488029], [88.73961639, 21.64481926], [88.74028015, 21.64481354], [88.74092865, 21.64480972], [88.74158478, 21.64481735], [88.74230194, 21.64483261], [88.74301147, 21.6448307], [88.74371338, 21.6448307], [88.7443924, 21.64485741], [88.74505615, 21.64492989], [88.74565125, 21.64505959], [88.74620056, 21.64517784], [88.74672699, 21.64528275], [88.74721527, 21.64541054], [88.74769592, 21.64550972], [88.74819946, 21.64562035], [88.74871826, 21.64575958], [88.74928284, 21.64596939], [88.74978638, 21.64624977], [88.75022125, 21.64657021], [88.75060272, 21.64688873], [88.75097656, 21.64719009], [88.75135803, 21.64750099], [88.75173187, 21.64783859], [88.75211334, 21.64807129], [88.75251007, 21.64833832], [88.7529068, 21.64861107], [88.75334167, 21.64888954], [88.75379944, 21.64916611], [88.75430298, 21.64944077], [88.75483704, 21.64972115], [88.75540161, 21.64998245], [88.75598907, 21.65019035], [88.75656128, 21.65048981], [88.75723267, 21.65060043], [88.75784302, 21.65083694], [88.75844574, 21.6511097], [88.75904083, 21.65135956], [88.75966644, 21.65152931], [88.76022339, 21.6518116], [88.76074982, 21.65216255], [88.76126862, 21.65254974], [88.76177216, 21.65301514], [88.76242828, 21.65333176], [88.7631073, 21.65357018], [88.76380157, 21.65365982], [88.76438141, 21.65390968], [88.76490021, 21.65421104], [88.76539612, 21.65455055], [88.76608276, 21.65470123], [88.76679993, 21.65478897], [88.76743317, 21.65501022], [88.76805115, 21.65528107], [88.76867676, 21.65552139], [88.76931763, 21.65559196], [88.76985931, 21.65556717], [88.77033234, 21.65500069], [88.77073669, 21.65455055], [88.77110291, 21.65428925], [88.77142334, 21.65402985], [88.77171326, 21.65369987], [88.77201843, 21.65334702], [88.77194214, 21.65306282]]], [[[88.89235687, 21.65209007], [88.89261627, 21.65167236], [88.89290619, 21.65138817], [88.89375305, 21.65055847], [88.89389038, 21.65027809], [88.89444733, 21.64972115], [88.89389038, 21.64916611], [88.89333344, 21.64916611], [88.89305878, 21.64944458], [88.89277649, 21.64944458], [88.89250183, 21.64972115], [88.89250183, 21.64999962], [88.89138794, 21.6511116], [88.89111328, 21.6511097], [88.89083099, 21.65138817], [88.89083099, 21.65167236], [88.89055634, 21.65195274], [88.89027405, 21.65194511], [88.89027405, 21.65222168], [88.88916779, 21.65333176], [88.88916779, 21.65361977], [88.88889313, 21.65389061], [88.88887024, 21.6541729], [88.88900757, 21.65457344], [88.88944244, 21.65457344], [88.88999939, 21.65447044], [88.89150238, 21.65306282], [88.89164734, 21.65278053], [88.89192963, 21.65250015], [88.89235687, 21.65209007]]], [[[89.01072693, 21.65061951], [89.01094055, 21.65076065], [89.01129913, 21.65102959], [89.01158142, 21.65122986], [89.01180267, 21.65122795], [89.01208496, 21.65129471], [89.01222992, 21.65136147], [89.01265717, 21.65142822], [89.01280212, 21.65149689], [89.01307678, 21.65155983], [89.01330566, 21.65169716], [89.01402283, 21.65209961], [89.01436615, 21.65244293], [89.01465607, 21.65263939], [89.01487732, 21.65290833], [89.01509094, 21.6531105], [89.01538086, 21.65331078], [89.01558685, 21.65337944], [89.01587677, 21.65337944], [89.01602173, 21.65357971], [89.01631165, 21.65392113], [89.0165863, 21.65411949], [89.01673889, 21.65431976], [89.01702881, 21.65452385], [89.01740265, 21.65493011], [89.01760864, 21.65499878], [89.01798248, 21.65511513], [89.01825714, 21.65520287], [89.0189743, 21.65526772], [89.01940155, 21.65533447], [89.01993561, 21.65525436], [89.02031708, 21.65503311], [89.02073669, 21.65492249], [89.02114868, 21.65476036], [89.02159119, 21.65471077], [89.02204895, 21.65460014], [89.02243805, 21.65436172], [89.02275848, 21.65402603], [89.0230484, 21.65359116], [89.02333832, 21.65314293], [89.02361298, 21.65273094], [89.02349091, 21.65236092], [89.02313232, 21.65209007], [89.0229187, 21.65122032], [89.02276611, 21.65081024], [89.02277374, 21.64933205], [89.02220154, 21.64852524], [89.02220154, 21.6473217], [89.02213287, 21.64692116], [89.02198029, 21.64624023], [89.02191162, 21.64583969], [89.02175903, 21.64526939], [89.021698, 21.64476013], [89.02162933, 21.64416122], [89.02133942, 21.64355087], [89.02127075, 21.64307976], [89.02118683, 21.64226913], [89.02127075, 21.64159966], [89.02133942, 21.64113045], [89.02133942, 21.64079094], [89.02140808, 21.63985062], [89.02140808, 21.63953018], [89.02140808, 21.63906097], [89.02176666, 21.63832855], [89.02194214, 21.63798332], [89.02204895, 21.63777924], [89.02218628, 21.6371727], [89.02226257, 21.63650131], [89.02233887, 21.63609505], [89.02269745, 21.63562965], [89.02276611, 21.63521767], [89.02297974, 21.63482094], [89.02311707, 21.63462067], [89.02340698, 21.63414955], [89.02355194, 21.63388062], [89.0236969, 21.6334095], [89.02423096, 21.63240051], [89.02439117, 21.6319809], [89.02458954, 21.63153076], [89.02484894, 21.63111115], [89.02513885, 21.63070679], [89.02549744, 21.6303215], [89.02583313, 21.62988853], [89.02617645, 21.62947083], [89.02654266, 21.62911987], [89.0266571, 21.62897491], [89.02681732, 21.62876892], [89.02715302, 21.62854958], [89.02742767, 21.62830925], [89.02765656, 21.62808228], [89.02792358, 21.62791252], [89.02818298, 21.62779045], [89.02840424, 21.62772751], [89.02857208, 21.62759972], [89.02879333, 21.62751007], [89.02910614, 21.62746811], [89.02953339, 21.62733078], [89.03003693, 21.62724113], [89.03061676, 21.62718964], [89.03116608, 21.62702942], [89.03166962, 21.62691689], [89.03206635, 21.6267128], [89.03245544, 21.62656784], [89.03279877, 21.62636948], [89.0331192, 21.62616158], [89.03350067, 21.62594795], [89.03392792, 21.62570953], [89.03444672, 21.62549019], [89.03501129, 21.6252594], [89.03575897, 21.62464905], [89.03604889, 21.62424088], [89.03626251, 21.62384033], [89.03633118, 21.62350082], [89.03640747, 21.62317085], [89.03647614, 21.62282944], [89.03647614, 21.62148094], [89.03642273, 21.62120438], [89.03636932, 21.62097168], [89.03614807, 21.6207695], [89.03601074, 21.6206398], [89.03585815, 21.62029839], [89.03585815, 21.62015915], [89.03614807, 21.61996269], [89.03629303, 21.61982918], [89.03665161, 21.61976051], [89.03679657, 21.61951065], [89.03707886, 21.61901283], [89.03734589, 21.61856842], [89.03749084, 21.61812973], [89.03753662, 21.61761093], [89.03753662, 21.61660004], [89.03748322, 21.61613083], [89.03739929, 21.61552048], [89.0372467, 21.61485291], [89.0372467, 21.61458015], [89.03660583, 21.61355972], [89.03638458, 21.61330986], [89.03601074, 21.61281013], [89.0356369, 21.61235046], [89.03533936, 21.61190987], [89.03509521, 21.61158371], [89.03503418, 21.6115036], [89.03472137, 21.61109161], [89.03439331, 21.61065292], [89.03399658, 21.61024094], [89.033638, 21.60983086], [89.03327942, 21.60941124], [89.03292847, 21.60902405], [89.03258514, 21.60866737], [89.03141022, 21.60798073], [89.03105164, 21.60764503], [89.03048706, 21.60718155], [89.03003693, 21.60684013], [89.02976227, 21.60650063], [89.02947998, 21.60609818], [89.02905273, 21.60509109], [89.02876282, 21.60482216], [89.02832031, 21.60486412], [89.02760315, 21.60493279], [89.02703094, 21.60493279], [89.02610016, 21.60453033], [89.02574158, 21.60425949], [89.02545166, 21.60399246], [89.02502441, 21.60385895], [89.02437592, 21.60353279], [89.02394867, 21.60332108], [89.02345276, 21.6031208], [89.02274323, 21.60292053], [89.02237701, 21.60277939], [89.02159119, 21.60264778], [89.02130127, 21.60264778], [89.02101135, 21.60251236], [89.02072906, 21.60251236], [89.02060699, 21.60251045], [89.02032471, 21.60263634], [89.02015686, 21.60267448], [89.02003479, 21.60270119], [89.019104, 21.60270119], [89.0185318, 21.60256958], [89.01817322, 21.60251045], [89.01766205, 21.60237122], [89.01716614, 21.60223007], [89.01695251, 21.60223007], [89.0165863, 21.60230064], [89.01631165, 21.60230064], [89.01595306, 21.60243034], [89.01573944, 21.60264015], [89.0152359, 21.6030426], [89.01494598, 21.60331154], [89.01465607, 21.60331154], [89.01409149, 21.60316849], [89.01402283, 21.60297012], [89.01380157, 21.60283852], [89.01344299, 21.60223007], [89.01287079, 21.60203171], [89.01222992, 21.6020298], [89.01187134, 21.60209846], [89.01158142, 21.60223579], [89.01129913, 21.60223579], [89.01087189, 21.60209846], [89.01065063, 21.60197067], [89.01022339, 21.60182953], [89.00979614, 21.60182953], [89.00958252, 21.60189438], [89.00936127, 21.60203171], [89.00901031, 21.60223579], [89.00850677, 21.60223579], [89.00821686, 21.60216331], [89.00746918, 21.60217094], [89.00704956, 21.60214615], [89.00647736, 21.60244179], [89.00650024, 21.60330391], [89.00641632, 21.60337067], [89.00602722, 21.60331154], [89.00563049, 21.60296059], [89.00520325, 21.60284996], [89.00488281, 21.60248184], [89.00445557, 21.6020298], [89.00392151, 21.60188293], [89.00359344, 21.60206795], [89.00295258, 21.60223579], [89.00244141, 21.60231209], [89.00199127, 21.60216522], [89.0014801, 21.60204124], [89.00086975, 21.60207176], [89.00026703, 21.60209084], [89.0, 21.60167122], [88.99972534, 21.60207176], [88.99967194, 21.60242271], [88.99888611, 21.60251045], [88.99868011, 21.60309601], [88.99850464, 21.60324287], [88.99836731, 21.60370827], [88.99806976, 21.60474014], [88.99852753, 21.60639954], [88.99867249, 21.6066761], [88.99860382, 21.60680199], [88.99868011, 21.6072197], [88.99888611, 21.60833359], [88.99861145, 21.60861206], [88.99861145, 21.60944366], [88.9985733, 21.60996056], [88.99861145, 21.61027718], [88.99841309, 21.61083412], [88.99855804, 21.61124992], [88.99833679, 21.61168289], [88.99833679, 21.61361122], [88.9983902, 21.61420822], [88.99835968, 21.61468124], [88.99833679, 21.61515045], [88.99833679, 21.61562729], [88.99833679, 21.61611176], [88.99833679, 21.6165905], [88.99833679, 21.61707115], [88.99833679, 21.6175251], [88.99832916, 21.61796188], [88.99830627, 21.61839294], [88.99820709, 21.61882973], [88.99809265, 21.61930084], [88.9980545, 21.61984253], [88.99804688, 21.62044144], [88.99804688, 21.62107277], [88.99804688, 21.62166977], [88.99803162, 21.62220955], [88.99794769, 21.62265968], [88.99781036, 21.62304115], [88.99777222, 21.6233902], [88.9977417, 21.62369919], [88.99762726, 21.62397957], [88.99752045, 21.62435532], [88.99746704, 21.62477112], [88.99732971, 21.6251812], [88.99723053, 21.62560081], [88.99713135, 21.62602806], [88.99697876, 21.62642097], [88.99690247, 21.62686539], [88.99671173, 21.62725067], [88.99637604, 21.62776756], [88.99664307, 21.62829971], [88.99658966, 21.62884521], [88.99642944, 21.62935448], [88.9963913, 21.62991333], [88.99636841, 21.63047218], [88.99632263, 21.63100243], [88.99614716, 21.63152122], [88.99603271, 21.63210106], [88.99585724, 21.6326828], [88.99581909, 21.63330841], [88.9957428, 21.63390923], [88.99558258, 21.63445663], [88.99549103, 21.63500023], [88.99531555, 21.6355381], [88.99524689, 21.63612938], [88.99513245, 21.63669586], [88.99500275, 21.6371994], [88.99484253, 21.63765526], [88.99474335, 21.63807106], [88.99446869, 21.63839912], [88.9942627, 21.63879013], [88.9941864, 21.63935089], [88.994133, 21.63993263], [88.99402618, 21.64042664], [88.993927, 21.64087486], [88.99384308, 21.64129066], [88.99369049, 21.64163017], [88.99356079, 21.64195061], [88.99340057, 21.6422596], [88.9932785, 21.64262009], [88.9930954, 21.64298248], [88.99289703, 21.64336014], [88.99264526, 21.64374924], [88.99236298, 21.64414024], [88.99201202, 21.64451981], [88.99163055, 21.64488029], [88.99120331, 21.6451683], [88.99072266, 21.64536667], [88.99019623, 21.64551926], [88.98961639, 21.64565086], [88.9890213, 21.64583015], [88.98835754, 21.64599991], [88.98758698, 21.64606857], [88.98678589, 21.64608955], [88.98597717, 21.64609146], [88.98516846, 21.64608192], [88.984375, 21.64603424], [88.98361969, 21.64593315], [88.9828949, 21.64591217], [88.98222351, 21.64580154], [88.98159027, 21.6456604], [88.9809494, 21.64557076], [88.98029327, 21.64552879], [88.97962189, 21.64545059], [88.97895813, 21.64530563], [88.97827148, 21.6451683], [88.97762299, 21.64495087], [88.97702026, 21.64470291], [88.97641754, 21.6444397], [88.97583008, 21.64418411], [88.97523499, 21.64396667], [88.97464752, 21.64377975], [88.97410583, 21.64356995], [88.97360992, 21.64332008], [88.97312927, 21.6430397], [88.97266388, 21.64276695], [88.97220612, 21.64250946], [88.9717865, 21.6423111], [88.97142029, 21.64213943], [88.97109985, 21.64199066], [88.97071838, 21.64191818], [88.97027588, 21.64185905], [88.96981812, 21.64173126], [88.9696579, 21.6417141], [88.96933746, 21.64167976], [88.96885681, 21.64167976], [88.96839905, 21.64169884], [88.96798706, 21.64178085], [88.96762848, 21.64196014], [88.9673233, 21.64215279], [88.96689606, 21.6424408], [88.96649933, 21.64270592], [88.96613312, 21.64302063], [88.96575165, 21.64334106], [88.96535492, 21.64364815], [88.96518707, 21.64383125], [88.96499634, 21.64403915], [88.96470642, 21.64450073], [88.96444702, 21.64495087], [88.96421051, 21.6453495], [88.96401978, 21.64574051], [88.96385956, 21.64612961], [88.96370697, 21.64651108], [88.96360016, 21.64694977], [88.96347809, 21.64743042], [88.96338654, 21.64796638], [88.96330261, 21.64854813], [88.96318054, 21.6491394], [88.96311951, 21.64971733], [88.96311188, 21.65027809], [88.96312714, 21.65087128], [88.9631958, 21.65150642], [88.96325684, 21.65220261], [88.9631958, 21.65295982], [88.96321869, 21.65377998], [88.96331787, 21.65459061], [88.96341705, 21.65537071], [88.96355438, 21.65607834], [88.96361542, 21.65654182], [88.96363831, 21.65674973], [88.96372986, 21.65735054], [88.9638443, 21.65787506], [88.96389771, 21.65836143], [88.96391296, 21.65881348], [88.96390533, 21.65924263], [88.96385193, 21.65966225], [88.96372986, 21.66007233], [88.96366119, 21.66055107], [88.96360016, 21.66104889], [88.96350861, 21.66152954], [88.96340179, 21.66201019], [88.96334076, 21.66250038], [88.96325684, 21.66299057], [88.96308899, 21.66345024], [88.96291351, 21.66392326], [88.9627533, 21.66440964], [88.9625473, 21.66488075], [88.96240234, 21.66534805], [88.96221924, 21.6657505], [88.9620285, 21.66609764], [88.96189117, 21.66642952], [88.96173859, 21.66671753], [88.96160126, 21.66702271], [88.96147919, 21.66732788], [88.96135712, 21.6676712], [88.96121216, 21.66803932], [88.9610672, 21.66847038], [88.96089935, 21.66895294], [88.96074677, 21.66949081], [88.96059418, 21.66995811], [88.96044922, 21.67037964], [88.96032715, 21.67073822], [88.96022797, 21.67106247], [88.96009064, 21.67136192], [88.95996094, 21.6717205], [88.95980072, 21.67213821], [88.9596405, 21.67262077], [88.95944214, 21.67310524], [88.95923615, 21.67354965], [88.95907593, 21.67395782], [88.95890808, 21.67428207], [88.95876312, 21.67457008], [88.95861816, 21.67487907], [88.95848846, 21.67517281], [88.95836639, 21.67547035], [88.95825195, 21.67576981], [88.95806885, 21.67604828], [88.95783997, 21.67636108], [88.95757294, 21.67671967], [88.95722961, 21.6770916], [88.95664978, 21.67739105], [88.95582581, 21.67749977], [88.95555878, 21.67777824], [88.95555878, 21.67805481], [88.95500183, 21.67861176], [88.95500183, 21.67889023], [88.95444489, 21.67944527], [88.95443726, 21.68083191], [88.95471954, 21.68111038], [88.95471954, 21.68139076], [88.95444489, 21.68166733], [88.95443726, 21.68222046], [88.95471954, 21.68250084], [88.95471954, 21.68278122], [88.95443726, 21.68305969], [88.95443726, 21.68638992], [88.95417023, 21.68666458], [88.95417023, 21.68753052], [88.9541626, 21.68806076], [88.95417023, 21.68849945], [88.95417023, 21.68889046], [88.95414734, 21.68927002], [88.95405579, 21.6897068], [88.9539032, 21.69020844], [88.95372009, 21.6907692], [88.9536972, 21.69135094], [88.95370483, 21.69189644], [88.95357513, 21.69247055], [88.95334625, 21.69293022], [88.95317078, 21.69331932], [88.95298767, 21.69366837], [88.95285797, 21.69400978], [88.95276642, 21.69433975], [88.9526825, 21.69465065], [88.95249176, 21.69489861], [88.95230103, 21.69514275], [88.95220947, 21.69543076], [88.95213318, 21.69571114], [88.95207977, 21.69605064], [88.95198822, 21.6964283], [88.95191193, 21.69688034], [88.95166779, 21.69734192], [88.95140076, 21.69785118], [88.95118713, 21.6984005], [88.95111847, 21.69896126], [88.95108032, 21.69945908], [88.95094299, 21.69992065], [88.95083618, 21.70036125], [88.95084381, 21.70072174], [88.95096588, 21.70100975], [88.9513092, 21.70123863], [88.95173645, 21.70143127], [88.95244598, 21.7014904], [88.95324707, 21.70142174], [88.95397186, 21.70137978], [88.95462036, 21.70137024], [88.95523834, 21.70135117], [88.95583344, 21.70129967], [88.95638275, 21.70116997], [88.95694733, 21.7010994], [88.95748901, 21.70103073], [88.95797729, 21.70088959], [88.95847321, 21.70080185], [88.95893097, 21.7007122], [88.95933533, 21.70056915], [88.95972443, 21.70048332], [88.96009827, 21.70041275], [88.96047211, 21.70031929], [88.96086121, 21.70022964], [88.96127319, 21.70014954], [88.96166992, 21.70009995], [88.96203613, 21.70015907], [88.96237946, 21.7002697], [88.96272278, 21.7003994], [88.96312714, 21.70047951], [88.96363068, 21.70051193], [88.9641571, 21.70051956], [88.96470642, 21.70051956], [88.96526337, 21.70051956], [88.9658432, 21.70051193], [88.96641541, 21.70049667], [88.9670105, 21.70041847], [88.96756744, 21.70021057], [88.96810913, 21.69991493], [88.96861267, 21.69955254], [88.96911621, 21.69918442], [88.96962738, 21.69883347], [88.97012329, 21.69848442], [88.9706192, 21.69813919], [88.97112274, 21.6978302], [88.9716568, 21.69760323], [88.97220612, 21.6974659], [88.97270203, 21.69736099], [88.97315979, 21.6973896], [88.97357941, 21.69761658], [88.97399902, 21.69782257], [88.97438812, 21.69809151], [88.97475433, 21.69841194], [88.97511292, 21.69874001], [88.97541046, 21.69909096], [88.97570038, 21.69940758], [88.97595978, 21.69971085], [88.97618866, 21.70002937], [88.97644806, 21.70033073], [88.97672272, 21.70064926], [88.97696686, 21.70096016], [88.97724152, 21.70131111], [88.9776001, 21.70169258], [88.97808075, 21.70216942], [88.97838593, 21.70247078], [88.97869873, 21.70275688], [88.97917938, 21.70301056], [88.97944641, 21.70308113], [88.97968292, 21.7031498], [88.97994995, 21.70326042], [88.98030853, 21.7033596], [88.98072052, 21.70349503], [88.98116302, 21.70365143], [88.98162079, 21.70386124], [88.9821167, 21.7041111], [88.98265839, 21.70438957], [88.98323059, 21.70477104], [88.98384094, 21.70532036], [88.98448944, 21.70568848], [88.98509216, 21.70554924], [88.9852829, 21.70556259], [88.98555756, 21.7052803], [88.98583221, 21.7052803], [88.98680878, 21.70430183], [88.98944092, 21.70166779], [88.98944092, 21.70140076], [88.98944092, 21.70111084], [88.98972321, 21.70083046], [88.98972321, 21.70000076], [88.99001312, 21.69972038], [88.98999786, 21.69805336], [88.99028015, 21.69778061], [88.99028015, 21.69750023], [88.99001312, 21.69721985], [88.98999786, 21.69555473], [88.99028015, 21.69527817], [88.99001312, 21.69499969], [88.98999786, 21.69444466], [88.98972321, 21.69416618], [88.98972321, 21.69361115], [88.98944092, 21.69333267], [88.98944092, 21.69305611], [88.98972321, 21.6927681], [88.98944092, 21.69249916], [88.98950195, 21.69225121], [88.98989105, 21.69212151], [88.99017334, 21.69181252], [88.99038696, 21.6913662], [88.99060059, 21.69087982], [88.99084473, 21.69042778], [88.99106598, 21.69003105], [88.99127197, 21.68969727], [88.99143219, 21.68939018], [88.99160767, 21.68908882], [88.99172211, 21.6887207], [88.99185181, 21.68834114], [88.99198151, 21.68792915], [88.99217224, 21.6875], [88.99194336, 21.68722153], [88.99250031, 21.68666458], [88.99250031, 21.68638992], [88.99223328, 21.68610954], [88.99222565, 21.68472481], [88.99194336, 21.68444633], [88.99194336, 21.68361092], [88.99138641, 21.68305588], [88.99138641, 21.68250084], [88.9916687, 21.68222046], [88.9916687, 21.68000031], [88.99194336, 21.67972183], [88.99194336, 21.67888832], [88.99223328, 21.67861176], [88.99222565, 21.67833328], [88.99250031, 21.67805481], [88.99250031, 21.67777824], [88.99333191, 21.67694092], [88.99333191, 21.67611122], [88.99307251, 21.67583084], [88.9936142, 21.67527962], [88.99333191, 21.67500114], [88.99333191, 21.6747303], [88.99360657, 21.67444038], [88.9936142, 21.67388916], [88.99388885, 21.67361069], [88.99388885, 21.67305946], [88.99360657, 21.67278099], [88.99360657, 21.67193985], [88.99333191, 21.67111206], [88.99250031, 21.67027855], [88.99092102, 21.66966057], [88.99063873, 21.66938972], [88.98934937, 21.66845131], [88.9888916, 21.66722107], [88.98790741, 21.66629982], [88.98734283, 21.66483116], [88.98705292, 21.6610508], [88.98690033, 21.65782738], [88.98719025, 21.65592957], [88.98761749, 21.6543293], [88.98790741, 21.6529808], [88.98833466, 21.65217781], [88.98860168, 21.65188026], [88.990448, 21.65032959], [88.9908371, 21.64999962], [88.9931488, 21.64925194], [88.99430084, 21.64898109], [88.99544525, 21.64903259], [88.99598694, 21.64908981], [88.99610901, 21.64916992], [88.9963913, 21.64903831], [88.99861145, 21.64944458], [88.99888611, 21.64945412], [89.0, 21.64944077], [89.00039673, 21.64969063], [89.00080872, 21.64970016], [89.00123596, 21.64972115], [89.00166321, 21.64972115], [89.00208282, 21.64972115], [89.00248718, 21.64973068], [89.00280762, 21.64964104], [89.00327301, 21.64966965], [89.00389862, 21.64973068], [89.00431824, 21.64979935], [89.0045929, 21.64992905], [89.00537872, 21.64999962], [89.00579834, 21.64999962], [89.00621796, 21.64999962], [89.00662231, 21.65003967], [89.00707245, 21.65001678], [89.00721741, 21.65008354], [89.00772095, 21.65008354], [89.00788116, 21.65016365], [89.00800323, 21.65022087], [89.00836182, 21.65028954], [89.00858307, 21.65028954], [89.00901031, 21.65041924], [89.0092926, 21.65041924], [89.00938416, 21.65044785], [89.00952148, 21.65048981], [89.00979614, 21.65044975], [89.01014709, 21.65055847], [89.01036835, 21.65055466], [89.01072693, 21.65061951]]], [[[88.23166656, 21.64110947], [88.23138428, 21.64067841], [88.23110199, 21.64018822], [88.23078156, 21.63965607], [88.23043823, 21.63907814], [88.22997284, 21.63859749], [88.2294693, 21.63820267], [88.22899628, 21.6378212], [88.22852325, 21.6375103], [88.22807312, 21.63723183], [88.22766113, 21.63696289], [88.22724915, 21.63671112], [88.22680664, 21.63649559], [88.22644043, 21.63620949], [88.22611237, 21.63583374], [88.22595978, 21.63555527], [88.22583771, 21.63554764], [88.22569275, 21.6355381], [88.22512817, 21.63486099], [88.22496796, 21.63484955], [88.22499084, 21.63458061], [88.22444153, 21.63360977], [88.22416687, 21.63361168], [88.22389221, 21.63333321], [88.22360992, 21.63333321], [88.22333527, 21.63305664], [88.22305298, 21.63305664], [88.22270203, 21.63270569], [88.22166443, 21.63166428], [88.22138977, 21.63167], [88.22122192, 21.63150024], [88.22111511, 21.63143158], [88.22114563, 21.63157082], [88.22076416, 21.63118935], [88.22032166, 21.63082123], [88.21987152, 21.63041115], [88.21942139, 21.6299305], [88.21893311, 21.62944984], [88.21840668, 21.62899017], [88.21790314, 21.62861061], [88.21743011, 21.62825966], [88.21700287, 21.62793922], [88.21665192, 21.62758064], [88.21630859, 21.62723923], [88.21592712, 21.62689972], [88.21556091, 21.62653542], [88.21517944, 21.62615967], [88.21476746, 21.62582779], [88.21438599, 21.62547112], [88.21409607, 21.62500954], [88.2138443, 21.62456894], [88.21357727, 21.62419128], [88.21334839, 21.62388992], [88.21317291, 21.6235981], [88.2130127, 21.62333107], [88.21283722, 21.62308121], [88.21272278, 21.62277031], [88.21251678, 21.62249947], [88.21234131, 21.62214088], [88.21218872, 21.62169838], [88.21193695, 21.62111092], [88.21166992, 21.62083054], [88.21166992, 21.62000084], [88.21138763, 21.61972046], [88.21060181, 21.61810493], [88.21073914, 21.61695099], [88.21055603, 21.61611176], [88.21055603, 21.61583138], [88.21083069, 21.61555481], [88.21083069, 21.61527824], [88.21111298, 21.61499977], [88.21111298, 21.61417007], [88.21083069, 21.61388969], [88.21083069, 21.61361122], [88.21028137, 21.6130619], [88.21028137, 21.61249924], [88.21057129, 21.61222076], [88.21055603, 21.6119442], [88.21083069, 21.61166573], [88.21083069, 21.61111069], [88.21111298, 21.6108284], [88.21111298, 21.60944366], [88.21138763, 21.6091671], [88.21138763, 21.60861015], [88.21166992, 21.60833359], [88.21166992, 21.60806084], [88.21221924, 21.60750008], [88.21221924, 21.60695076], [88.21250153, 21.60695076], [88.21305847, 21.60639], [88.21277618, 21.60610962], [88.21277618, 21.60555649], [88.21305847, 21.60527611], [88.21305847, 21.60499954], [88.21331787, 21.60472107], [88.21333313, 21.60361099], [88.21360779, 21.60333061], [88.21360779, 21.60277748], [88.21389008, 21.60251045], [88.21389008, 21.60194016], [88.21279907, 21.60194206], [88.21221924, 21.60194206], [88.21194458, 21.6016674], [88.21166992, 21.60194206], [88.2097168, 21.60194016], [88.20889282, 21.60277939], [88.20888519, 21.60305405], [88.20861053, 21.60333061], [88.20861053, 21.60361099], [88.20833588, 21.60388947], [88.20804596, 21.60388947], [88.20777893, 21.60416412], [88.20833588, 21.60472488], [88.20861053, 21.60472107], [88.20916748, 21.60527611], [88.20916748, 21.60555649], [88.20888519, 21.60583305], [88.20888519, 21.60611153], [88.20861053, 21.60611153], [88.20610809, 21.60861015], [88.20610809, 21.60889053], [88.20582581, 21.60917091], [88.20555878, 21.6091671], [88.20500183, 21.60972023], [88.20500183, 21.61000061], [88.20471954, 21.61027908], [88.20471954, 21.61111069], [88.20417023, 21.61166573], [88.20417023, 21.6119442], [88.20388794, 21.61222076], [88.20388794, 21.61249924], [88.20361328, 21.61277962], [88.20361328, 21.61361122], [88.20305634, 21.61417007], [88.20305634, 21.61499977], [88.20277405, 21.61527824], [88.20276642, 21.61610985], [88.2022171, 21.61667061], [88.2022171, 21.61778069], [88.20194244, 21.61805344], [88.20194244, 21.61833], [88.2013855, 21.61888885], [88.20137787, 21.61944008], [88.20083618, 21.62000084], [88.20111084, 21.6202755], [88.20111084, 21.62055779], [88.20083618, 21.62083054], [88.20057678, 21.62121964], [88.20054626, 21.62138939], [88.20027924, 21.62166786], [88.20027924, 21.62222099], [88.19999695, 21.62249947], [88.19999695, 21.62305641], [88.19972229, 21.62333107], [88.19972229, 21.62388992], [88.19944763, 21.62416649], [88.19922638, 21.62464905], [88.19904327, 21.62486076], [88.19889069, 21.62500191], [88.19880676, 21.62528038], [88.1987381, 21.62549019], [88.19874573, 21.62569809], [88.1986084, 21.62583351], [88.19834137, 21.62615013], [88.19809723, 21.62662888], [88.19787598, 21.62713051], [88.19773865, 21.62765121], [88.1975174, 21.62807655], [88.19733429, 21.62851334], [88.1971817, 21.62897682], [88.19695282, 21.6293602], [88.19668579, 21.62973976], [88.19650269, 21.63015938], [88.1963501, 21.63062096], [88.19610596, 21.63099098], [88.19583893, 21.63132095], [88.19557953, 21.63163757], [88.19532776, 21.6319294], [88.19507599, 21.63219261], [88.19481659, 21.63241005], [88.19469452, 21.63269806], [88.19489288, 21.63338089], [88.19495392, 21.63402557], [88.19485474, 21.63467407], [88.19447327, 21.63531113], [88.1938324, 21.63582611], [88.19384003, 21.63636971], [88.19387817, 21.63696289], [88.19384766, 21.63750076], [88.19365692, 21.63790894], [88.19351959, 21.63826942], [88.19332886, 21.63857079], [88.19311523, 21.63884926], [88.19294739, 21.63916016], [88.19281006, 21.63948059], [88.19277954, 21.63986969], [88.19277954, 21.64025116], [88.19283295, 21.64066124], [88.19300079, 21.64110947], [88.19304657, 21.64162064], [88.1930542, 21.64215851], [88.19304657, 21.6427002], [88.1930542, 21.64325714], [88.19301605, 21.64381027], [88.19285583, 21.64434052], [88.19258118, 21.64479065], [88.19241333, 21.64523125], [88.19225311, 21.64561081], [88.19219208, 21.64596558], [88.19206238, 21.64626122], [88.19193268, 21.64657021], [88.19174957, 21.64689064], [88.1916275, 21.64728928], [88.19139862, 21.64764977], [88.19115448, 21.64800644], [88.19091034, 21.64835167], [88.1906662, 21.64875031], [88.1905899, 21.64929008], [88.19058228, 21.64990044], [88.1904068, 21.65041924], [88.19009399, 21.65080833], [88.18977356, 21.6511116], [88.18952179, 21.65135956], [88.1893158, 21.65159035], [88.18930817, 21.65196991], [88.18927765, 21.65234756], [88.18914795, 21.65265274], [88.18904877, 21.65297127], [88.18901825, 21.65340042], [88.18889618, 21.65382957], [88.18870544, 21.65424538], [88.18855286, 21.65473938], [88.18831635, 21.65526009], [88.1880722, 21.65582275], [88.18788147, 21.65642929], [88.18778229, 21.65703773], [88.18772888, 21.65757942], [88.18762207, 21.65799522], [88.18747711, 21.65831184], [88.18730164, 21.65856934], [88.18719482, 21.65882683], [88.18707275, 21.65906143], [88.18694305, 21.65929985], [88.18682861, 21.65958595], [88.18672943, 21.65998077], [88.18669128, 21.66053009], [88.1865387, 21.66114616], [88.186203, 21.66178131], [88.18615723, 21.66242027], [88.18630981, 21.66300964], [88.18622589, 21.66348076], [88.18608856, 21.66386986], [88.18595886, 21.66418266], [88.18582916, 21.6644516], [88.18569183, 21.66469955], [88.18548584, 21.66491127], [88.18521881, 21.66514015], [88.18515778, 21.6656208], [88.18538666, 21.66630554], [88.18545532, 21.66695213], [88.18528748, 21.66749382], [88.18512726, 21.66800117], [88.18514252, 21.66860008], [88.18499756, 21.66916275], [88.18480682, 21.66978264], [88.18457031, 21.6703701], [88.18416595, 21.67080688], [88.18369293, 21.67120361], [88.18335724, 21.67159081], [88.18354797, 21.67208099], [88.18356323, 21.67258072], [88.18347931, 21.67313957], [88.18327332, 21.67368126], [88.18310547, 21.67425728], [88.18305206, 21.67485809], [88.18302917, 21.67542648], [88.18295288, 21.67588425], [88.18282318, 21.67625809], [88.1827774, 21.67666817], [88.18276215, 21.67712975], [88.18250275, 21.67749977], [88.1827774, 21.67778969], [88.1827774, 21.68111038], [88.18250275, 21.68138885], [88.18250275, 21.68181038], [88.18250275, 21.68194389], [88.18222046, 21.68222046], [88.18226624, 21.68305016], [88.18235016, 21.6842308], [88.18205261, 21.6847496], [88.18147278, 21.68576431], [88.18138885, 21.68610954], [88.18138885, 21.6866703], [88.18139648, 21.68694687], [88.18133545, 21.68753433], [88.18138123, 21.68811226], [88.18138885, 21.68830109], [88.18139648, 21.68868065], [88.18148804, 21.68921852], [88.18167114, 21.68967438], [88.18184662, 21.69009972], [88.18199158, 21.69054985], [88.18218231, 21.6909256], [88.18232727, 21.69133186], [88.18251038, 21.69170952], [88.18270874, 21.69207573], [88.18286133, 21.69246674], [88.1830368, 21.69283485], [88.18319702, 21.6932106], [88.18335724, 21.69366074], [88.18353271, 21.69411087], [88.18362427, 21.69466782], [88.18374634, 21.69520187], [88.1840744, 21.69547081], [88.18418884, 21.69582176], [88.18416595, 21.69667053], [88.18444824, 21.69695091], [88.18444824, 21.69805336], [88.1847229, 21.69832993], [88.1847229, 21.69916534], [88.18499756, 21.69944], [88.18519592, 21.69992828], [88.18528748, 21.70006943], [88.18527985, 21.70027542], [88.18583679, 21.70083046], [88.18583679, 21.70111084], [88.18611145, 21.70138931], [88.18611145, 21.70194435], [88.18638611, 21.70222282], [88.18640137, 21.70249939], [88.1866684, 21.70277977], [88.1866684, 21.7033329], [88.18694305, 21.70360756], [88.18694305, 21.70416641], [88.18722534, 21.70444489], [88.18723297, 21.70500183], [88.1875, 21.7052784], [88.1875, 21.70611191], [88.18777466, 21.70638847], [88.18778229, 21.70648956], [88.18778992, 21.70667267], [88.18782806, 21.70675468], [88.18795776, 21.70704079], [88.18810272, 21.70746613], [88.1883316, 21.70776939], [88.1883316, 21.70806122], [88.1911087, 21.71084023], [88.19139099, 21.7108326], [88.19166565, 21.71111107], [88.19194794, 21.71111107], [88.1938858, 21.71305656], [88.19416809, 21.71305084], [88.19437408, 21.71326256], [88.19499969, 21.71389961], [88.19528198, 21.71389961], [88.19722748, 21.71584129], [88.19917297, 21.71777916], [88.19944763, 21.71777916], [88.19972229, 21.71805573], [88.19972229, 21.7183342], [88.20083618, 21.71944427], [88.20083618, 21.71970749], [88.20111084, 21.72000122], [88.20111084, 21.72027779], [88.20152283, 21.72069359], [88.20194244, 21.7211113], [88.2022171, 21.72110939], [88.20240021, 21.72138596], [88.20275879, 21.72166252], [88.20317841, 21.72187996], [88.20358276, 21.72191048], [88.20387268, 21.7217598], [88.20405579, 21.72166252], [88.20424652, 21.72146988], [88.20450592, 21.72118187], [88.20465851, 21.72064018], [88.20504761, 21.71970749], [88.20583344, 21.71888924], [88.20610809, 21.71894836], [88.20639038, 21.71861076], [88.20667267, 21.71832848], [88.20666504, 21.71777725], [88.20694733, 21.71750069], [88.20694733, 21.7172184], [88.20749664, 21.71666718], [88.2075119, 21.71639061], [88.20777893, 21.71611023], [88.20777893, 21.71582985], [88.20833588, 21.71527863], [88.20833588, 21.71500015], [88.20861053, 21.71471977], [88.20861053, 21.71444511], [88.20868683, 21.71417046], [88.20999908, 21.71249962], [88.21028137, 21.71249962], [88.21083069, 21.71194077], [88.21131897, 21.71160889], [88.21193695, 21.71138954], [88.21353149, 21.70944023], [88.21389008, 21.70916748], [88.2141571, 21.70889282], [88.2141571, 21.70861053], [88.21470642, 21.70763969], [88.21527863, 21.7069416], [88.215271, 21.70646477], [88.21536255, 21.7062664], [88.21555328, 21.70583344], [88.21583557, 21.70555496], [88.21586609, 21.70500183], [88.21606445, 21.70439529], [88.21611023, 21.70375061], [88.21615601, 21.70310974], [88.21634674, 21.70248985], [88.21643829, 21.701828], [88.2166214, 21.7011795], [88.21659088, 21.70054054], [88.21624756, 21.7000103], [88.21580505, 21.69957352], [88.21530914, 21.69925499], [88.21482086, 21.69902039], [88.21431732, 21.69894981], [88.21379852, 21.6989193], [88.21327209, 21.69890022], [88.21273804, 21.69885063], [88.21226501, 21.69868088], [88.21175385, 21.6985817], [88.21128082, 21.69841003], [88.21073914, 21.69833946], [88.21013641, 21.69833565], [88.2095108, 21.69833183], [88.20887756, 21.69828606], [88.20826721, 21.69809151], [88.2076416, 21.69799614], [88.20701599, 21.69782257], [88.20639038, 21.69777107], [88.20578003, 21.69769287], [88.20521545, 21.69752884], [88.2046814, 21.69742012], [88.20425415, 21.69722748], [88.20384979, 21.69704056], [88.20361328, 21.69695091], [88.20333099, 21.69666672], [88.20305634, 21.69667053], [88.20276642, 21.69639015], [88.20249939, 21.69639015], [88.2022171, 21.69610977], [88.2013855, 21.69611168], [88.20111084, 21.6958313], [88.20055389, 21.6958313], [88.19999695, 21.69527817], [88.19972229, 21.69528008], [88.19917297, 21.69472122], [88.19889069, 21.69472122], [88.1986084, 21.69444466], [88.19833374, 21.69444466], [88.19638824, 21.69249916], [88.19638824, 21.69222069], [88.19555664, 21.69138908], [88.19525909, 21.69111061], [88.19528198, 21.69055939], [88.19528198, 21.69028091], [88.19499969, 21.69000053], [88.19499969, 21.68972969], [88.19473267, 21.68943977], [88.19472504, 21.68916893], [88.19416809, 21.68861008], [88.19416809, 21.68805695], [88.19444275, 21.68778038], [88.19444275, 21.6875], [88.19473267, 21.68721962], [88.19472504, 21.6855545], [88.19499969, 21.68527985], [88.19499969, 21.68473053], [88.1955719, 21.68416977], [88.1955719, 21.68333054], [88.19527435, 21.68305588], [88.19528198, 21.68278122], [88.1955719, 21.68250084], [88.19555664, 21.68194389], [88.1958313, 21.68166733], [88.1958313, 21.68139076], [88.19610596, 21.68111038], [88.19610596, 21.68083191], [88.19638824, 21.68055534], [88.1966629, 21.68056107], [88.19695282, 21.68028259], [88.19695282, 21.68000031], [88.19721985, 21.67972183], [88.19721985, 21.67888832], [88.19750214, 21.67861176], [88.19750214, 21.67833328], [88.19777679, 21.67805481], [88.19777679, 21.67749977], [88.19805908, 21.67721748], [88.19805908, 21.67694473], [88.1986084, 21.67638969], [88.19904327, 21.67584038], [88.19950867, 21.67537117], [88.20008087, 21.67501068], [88.20067596, 21.67469025], [88.20124817, 21.67431068], [88.20179749, 21.67393112], [88.20237732, 21.6736393], [88.20294952, 21.67340088], [88.20337677, 21.67307854], [88.20376587, 21.67278862], [88.20413971, 21.67252922], [88.2045517, 21.67238808], [88.20498657, 21.67224121], [88.20545197, 21.67220879], [88.20571136, 21.67198181], [88.20617676, 21.67177582], [88.20670319, 21.67160988], [88.20717621, 21.67155838], [88.20780182, 21.67150688], [88.20845795, 21.67135048], [88.20892334, 21.67110062], [88.20957184, 21.67093086], [88.20999908, 21.6707077], [88.21054077, 21.67057991], [88.2109375, 21.67042351], [88.2116394, 21.67046165], [88.21213531, 21.67030716], [88.21264648, 21.67028046], [88.21315765, 21.67025185], [88.21360779, 21.67013359], [88.21403503, 21.67002106], [88.21450806, 21.66999817], [88.2150116, 21.66995811], [88.21553802, 21.66981506], [88.21605682, 21.66995049], [88.21659851, 21.67003822], [88.21711731, 21.67021942], [88.2177124, 21.67027283], [88.21836853, 21.67028046], [88.21907043, 21.67032242], [88.21926117, 21.67037392], [88.21977234, 21.67051125], [88.22046661, 21.67052078], [88.22115326, 21.67037964], [88.22186279, 21.67041969], [88.22251129, 21.67050171], [88.22309875, 21.67058754], [88.22362518, 21.67079163], [88.22421265, 21.67083549], [88.22450256, 21.67081642], [88.22481537, 21.67079735], [88.22537231, 21.67061043], [88.22590637, 21.67046165], [88.22632599, 21.67021179], [88.22665405, 21.66985703], [88.22693634, 21.66941833], [88.227211, 21.66889], [88.22740173, 21.6682663], [88.22750092, 21.6675396], [88.22757721, 21.66675949], [88.22772217, 21.6659584], [88.2277832, 21.66583061], [88.22777557, 21.66527748], [88.22750092, 21.66500092], [88.22750092, 21.66278839], [88.22693634, 21.66221809], [88.22721863, 21.66194534], [88.22693634, 21.66167068], [88.22721863, 21.6613903], [88.22721863, 21.66110992], [88.22694397, 21.66083336], [88.22694397, 21.66027832], [88.22721863, 21.65999985], [88.22721863, 21.65971947], [88.22750092, 21.65944672], [88.22750092, 21.65805435], [88.2277832, 21.65722084], [88.22805786, 21.65638924], [88.22805786, 21.65444183], [88.22833252, 21.65416718], [88.22831726, 21.65250015], [88.22853088, 21.6516819], [88.22859955, 21.65146065], [88.22888184, 21.65132141], [88.22916412, 21.6511116], [88.22923279, 21.65076637], [88.22923279, 21.65055847], [88.22914124, 21.64992905], [88.22914124, 21.64958763], [88.22984314, 21.64903069], [88.23005676, 21.64840126], [88.23026276, 21.64810944], [88.23060608, 21.64749718], [88.23082733, 21.64722061], [88.23083496, 21.64666748], [88.23110962, 21.64639091], [88.23110962, 21.64528084], [88.23139191, 21.64500046], [88.23139191, 21.64389038], [88.23166656, 21.64361], [88.23166656, 21.64333344], [88.23139191, 21.64305305], [88.23139191, 21.64167976], [88.23166656, 21.64138985], [88.23166656, 21.64110947]]], [[[88.57688141, 21.69173431], [88.57701874, 21.69137192], [88.57717896, 21.69111061], [88.5772934, 21.69081116], [88.57744598, 21.6905098], [88.57756042, 21.6901226], [88.57769775, 21.68970108], [88.57769775, 21.68917847], [88.57758331, 21.68861961], [88.57756042, 21.68811035], [88.57756805, 21.68803406], [88.57765198, 21.68746185], [88.57781219, 21.68696213], [88.57801056, 21.68656349], [88.57815552, 21.68615913], [88.57829285, 21.6857605], [88.57836151, 21.68530083], [88.57849121, 21.68481827], [88.57859039, 21.68433762], [88.57866669, 21.68382072], [88.57884979, 21.68328094], [88.57901001, 21.68269157], [88.57920074, 21.68210983], [88.57943726, 21.68153191], [88.57966614, 21.68091393], [88.57980347, 21.68023109], [88.58001709, 21.67958069], [88.58027649, 21.67896271], [88.58055878, 21.67839813], [88.58081818, 21.67790413], [88.58107758, 21.67745209], [88.58131409, 21.67702484], [88.58153534, 21.67661095], [88.58170319, 21.67617035], [88.58192444, 21.67579651], [88.5821228, 21.67539978], [88.58233643, 21.67503357], [88.58261871, 21.67468834], [88.58289337, 21.67431068], [88.58311462, 21.67389297], [88.58334351, 21.67346954], [88.58355713, 21.67305946], [88.58361053, 21.67291069], [88.58370972, 21.67260742], [88.58390808, 21.67217827], [88.58411407, 21.6717453], [88.58428955, 21.67122078], [88.58436584, 21.67085075], [88.58441162, 21.67063522], [88.58450317, 21.67000008], [88.58467102, 21.66941071], [88.58479309, 21.66879845], [88.58499146, 21.66824532], [88.58516693, 21.66771126], [88.58525848, 21.66719246], [88.58530426, 21.66670418], [88.58535767, 21.66624451], [88.58530426, 21.66579437], [88.58528137, 21.66531944], [88.58527374, 21.66482162], [88.585289, 21.66430855], [88.58532715, 21.66381073], [88.58551025, 21.66332054], [88.5855484, 21.66283035], [88.58555603, 21.66234589], [88.5855484, 21.66186333], [88.58528137, 21.66166878], [88.58555603, 21.6613903], [88.58555603, 21.65999985], [88.58583069, 21.65971947], [88.58583069, 21.65805435], [88.58611298, 21.65777969], [88.58611298, 21.65750122], [88.58666229, 21.65694046], [88.58666992, 21.6566658], [88.58694458, 21.6566658], [88.58721924, 21.65638924], [88.58750153, 21.65639114], [88.58777618, 21.65611076], [88.58805847, 21.65611076], [88.58860779, 21.65555954], [88.58889008, 21.65555954], [88.5891571, 21.65528107], [88.58944702, 21.65528107], [88.58972168, 21.65500069], [88.59027863, 21.65500069], [88.59055328, 21.65472031], [88.5911026, 21.65472031], [88.59166718, 21.65472221], [88.59194183, 21.65444374], [88.59249878, 21.65444374], [88.59305573, 21.65423965], [88.59343719, 21.65390015], [88.59377289, 21.6535511], [88.59384155, 21.65324974], [88.59388733, 21.65305519], [88.59361267, 21.65306282], [88.59333038, 21.65278053], [88.59333038, 21.65195274], [88.59361267, 21.65167236], [88.59361267, 21.65083122], [88.59388733, 21.65055466], [88.59388733, 21.65027809], [88.59471893, 21.64944077], [88.59471893, 21.64916611], [88.59500122, 21.64888954], [88.59527588, 21.64888954], [88.59638977, 21.64777946], [88.59638977, 21.64750099], [88.5966568, 21.64722061], [88.59666443, 21.64638901], [88.59694672, 21.64611053], [88.59694672, 21.64556122], [88.59722137, 21.64528084], [88.59722137, 21.64443016], [88.59750366, 21.64416695], [88.59749603, 21.64361], [88.59777832, 21.64333344], [88.59777832, 21.64305305], [88.59860229, 21.64221954], [88.59860992, 21.64194489], [88.59889221, 21.64166641], [88.59889221, 21.64138985], [88.59916687, 21.64110947], [88.59916687, 21.63999939], [88.59944153, 21.63972282], [88.59944153, 21.63916588], [88.59971619, 21.63888931], [88.59971619, 21.63862038], [88.59916687, 21.63806152], [88.59916687, 21.63722038], [88.59972382, 21.63666725], [88.59971619, 21.63611031], [88.59918213, 21.63556862], [88.59916687, 21.63500023], [88.59967804, 21.63448906], [88.59999847, 21.63416862], [88.60028076, 21.63417053], [88.60056305, 21.63389015], [88.60083008, 21.63389015], [88.60138702, 21.63332939], [88.60138702, 21.63194656], [88.60166931, 21.63166428], [88.60166168, 21.63138962], [88.60193634, 21.63111115], [88.60193634, 21.63000107], [88.60221863, 21.62972069], [88.60221863, 21.62916756], [88.60250092, 21.6288929], [88.60294342, 21.62902451], [88.60309601, 21.62851524], [88.60334778, 21.62802124], [88.60361481, 21.62750053], [88.60305786, 21.62750053], [88.60305786, 21.62668037], [88.60415649, 21.62556267], [88.60457611, 21.62590408], [88.60496521, 21.62565041], [88.60526276, 21.62537956], [88.60546112, 21.62507629], [88.60558319, 21.62473106], [88.60571289, 21.62440109], [88.60559082, 21.62411118], [88.60555267, 21.62388992], [88.60527802, 21.62361908], [88.60527802, 21.62333107], [88.60472107, 21.62277985], [88.6047287, 21.62249947], [88.60419464, 21.62196732], [88.60333252, 21.62111092], [88.60305786, 21.62111092], [88.6027832, 21.62083054], [88.60250092, 21.62083244], [88.60221863, 21.62055779], [88.60166931, 21.62055779], [88.60138702, 21.6202755], [88.60028076, 21.62028122], [88.59999847, 21.62000084], [88.59971619, 21.62000084], [88.59944153, 21.61972046], [88.59805298, 21.61972046], [88.59777832, 21.62000084], [88.59694672, 21.62000084], [88.5966568, 21.62028122], [88.59583282, 21.6202755], [88.59527588, 21.62083244], [88.59500122, 21.62083244], [88.59500122, 21.62000084], [88.59388733, 21.61889076], [88.59388733, 21.61861038], [88.59305573, 21.61861038], [88.59249878, 21.61805344], [88.59194183, 21.61805344], [88.59166718, 21.61833572], [88.59111023, 21.61833572], [88.58889008, 21.62055779], [88.58860779, 21.62055016], [88.58805847, 21.62111092], [88.58777618, 21.62111092], [88.58750153, 21.62138939], [88.58694458, 21.62138939], [88.58638763, 21.62194061], [88.58599091, 21.62208748], [88.58565521, 21.62236595], [88.58524323, 21.6225605], [88.5848465, 21.62279892], [88.58450317, 21.62308121], [88.584198, 21.62339973], [88.58389282, 21.62375069], [88.58355713, 21.62411118], [88.58318329, 21.62446976], [88.58273315, 21.62485123], [88.58220673, 21.62521172], [88.58164978, 21.62554741], [88.58108521, 21.62586021], [88.58052826, 21.62615204], [88.58001709, 21.6264801], [88.57953644, 21.62684059], [88.57905579, 21.62717056], [88.57849121, 21.62741089], [88.57808685, 21.62773514], [88.57772827, 21.62804413], [88.57736969, 21.62833023], [88.57701874, 21.6286087], [88.57665253, 21.62887192], [88.57627869, 21.62912941], [88.57589722, 21.62936592], [88.57544708, 21.62953949], [88.5750351, 21.62974548], [88.574646, 21.63005257], [88.57415771, 21.63035011], [88.57360077, 21.63068008], [88.57299805, 21.63105011], [88.57231903, 21.63138008], [88.57161713, 21.63167], [88.57095337, 21.63194656], [88.57036591, 21.63222122], [88.56985474, 21.63247108], [88.5693512, 21.63261032], [88.56916809, 21.63222122], [88.56861877, 21.63278008], [88.56833649, 21.63277817], [88.56777954, 21.63333321], [88.56749725, 21.63333321], [88.5672226, 21.63361168], [88.56639099, 21.63360977], [88.56625366, 21.63375092], [88.5661087, 21.63389015], [88.56555939, 21.63367081], [88.56510162, 21.63367081], [88.5647049, 21.63384056], [88.56427765, 21.63393211], [88.56388092, 21.63412285], [88.56341553, 21.63417053], [88.56291962, 21.63423347], [88.56246185, 21.63443947], [88.5619812, 21.63463974], [88.56143188, 21.63461113], [88.56085968, 21.63457108], [88.5606308, 21.63461876], [88.56027985, 21.63469124], [88.55967712, 21.63472748], [88.55909729, 21.63479805], [88.55856323, 21.63499069], [88.55832672, 21.63500023], [88.55805206, 21.63528061], [88.5577774, 21.63528061], [88.55750275, 21.63500023], [88.55722046, 21.63528061], [88.5569458, 21.6352787], [88.55638885, 21.63583374], [88.55584717, 21.63612938], [88.55549622, 21.63657951], [88.55513, 21.63697052], [88.55486298, 21.6373806], [88.55470276, 21.63777924], [88.55452728, 21.63811111], [88.55444336, 21.63845634], [88.55435944, 21.6388092], [88.5541687, 21.63915062], [88.55397797, 21.63953018], [88.55387115, 21.63999748], [88.55371094, 21.64046478], [88.55362701, 21.64096069], [88.55361176, 21.6415081], [88.55361938, 21.64208984], [88.55361176, 21.6427269], [88.55361176, 21.64338112], [88.55363464, 21.6440239], [88.55373383, 21.64456367], [88.55384064, 21.64500427], [88.55387115, 21.64515114], [88.55391693, 21.64538193], [88.55403137, 21.64570618], [88.55414581, 21.64604378], [88.55422974, 21.6464119], [88.55429077, 21.64651108], [88.5544281, 21.64673042], [88.55459595, 21.64709091], [88.55477142, 21.64743042], [88.55502319, 21.64770126], [88.55528259, 21.64794159], [88.55555725, 21.64816284], [88.55583191, 21.64843941], [88.55610657, 21.64878273], [88.55640411, 21.64915848], [88.55678558, 21.64948463], [88.55709839, 21.64987946], [88.55744171, 21.65027809], [88.55776215, 21.65068817], [88.55805969, 21.65114021], [88.55838776, 21.65158081], [88.55877686, 21.65196991], [88.55916595, 21.65237999], [88.55957031, 21.65276718], [88.5599823, 21.6531105], [88.56039429, 21.6534462], [88.56080627, 21.65374947], [88.56117249, 21.65411949], [88.56154633, 21.65446091], [88.5619278, 21.65483093], [88.56227875, 21.65522003], [88.56266785, 21.65557098], [88.56304169, 21.65594864], [88.5634079, 21.65633965], [88.563797, 21.65671158], [88.56417847, 21.65711021], [88.56458282, 21.6574707], [88.56501007, 21.65777969], [88.56541443, 21.65807724], [88.5657196, 21.65844154], [88.56587982, 21.65893555], [88.56611633, 21.65941048], [88.56639099, 21.6599102], [88.56667328, 21.66041756], [88.56698608, 21.6608696], [88.56742859, 21.66115952], [88.56780243, 21.66146088], [88.56808472, 21.66178513], [88.56837463, 21.66210175], [88.5686264, 21.66246223], [88.56887817, 21.66283035], [88.56905365, 21.66322136], [88.56919861, 21.66358948], [88.56939697, 21.66385078], [88.5696106, 21.66409492], [88.56977081, 21.6643219], [88.56999969, 21.66451073], [88.57022095, 21.66473961], [88.57040405, 21.66501045], [88.57054901, 21.66531944], [88.57065582, 21.66566086], [88.57080841, 21.66600037], [88.57086182, 21.66641045], [88.57099915, 21.66684723], [88.57109833, 21.66734123], [88.57113647, 21.66789055], [88.57129669, 21.66841125], [88.57137299, 21.66895294], [88.57139587, 21.66949081], [88.57144165, 21.6700058], [88.57152557, 21.67022324], [88.57162476, 21.67048454], [88.5716629, 21.67098045], [88.57167816, 21.67148972], [88.57167053, 21.67198753], [88.57167053, 21.67248154], [88.57167053, 21.67297173], [88.57167816, 21.67346954], [88.5716629, 21.67398071], [88.57159424, 21.67447853], [88.57142639, 21.67493057], [88.57138824, 21.67535973], [88.57138824, 21.67575073], [88.57138824, 21.6760807], [88.57138824, 21.67644119], [88.5713501, 21.67684555], [88.57115173, 21.67727089], [88.57108307, 21.67780113], [88.57090759, 21.67827988], [88.57077026, 21.6787796], [88.57072449, 21.67889023], [88.5705719, 21.67923355], [88.57042694, 21.67972183], [88.57026672, 21.68023109], [88.57010651, 21.68074036], [88.57000732, 21.68123055], [88.56994629, 21.68166733], [88.56976318, 21.68198967], [88.56972504, 21.68233681], [88.56969452, 21.68266296], [88.56955719, 21.68294907], [88.56942749, 21.68332291], [88.56923676, 21.68370819], [88.56912994, 21.68422127], [88.56891632, 21.68470955], [88.56876373, 21.68525696], [88.56861877, 21.68577957], [88.5684433, 21.68628883], [88.56832123, 21.68679428], [88.56815338, 21.68725967], [88.56803894, 21.68771744], [88.56787109, 21.68810463], [88.56775665, 21.68847084], [88.56759644, 21.68880081], [88.56751251, 21.68917847], [88.56749725, 21.68961143], [88.56748962, 21.69005394], [88.56752777, 21.69046974], [88.56770325, 21.69081879], [88.56800079, 21.69110298], [88.56841278, 21.69133186], [88.56900024, 21.6914196], [88.56958771, 21.69153976], [88.57012939, 21.69164085], [88.57064056, 21.69164467], [88.57110596, 21.69155884], [88.57154083, 21.69148064], [88.57196808, 21.69146156], [88.57235718, 21.69164085], [88.57276917, 21.69177818], [88.57319641, 21.69190025], [88.57366943, 21.69199944], [88.57408905, 21.69219017], [88.57459259, 21.69236565], [88.57514954, 21.69252968], [88.57572174, 21.6926899], [88.57627869, 21.69252968], [88.57663727, 21.6921196], [88.57688141, 21.69173431]]], [[[88.30931091, 21.69219017], [88.30893707, 21.69258118], [88.30860901, 21.69296837], [88.30831909, 21.69331169], [88.30805206, 21.6936245], [88.30778503, 21.69393349], [88.30751038, 21.69427109], [88.30722809, 21.69468117], [88.30693817, 21.69511986], [88.306633, 21.69560051], [88.30627441, 21.69607735], [88.30584717, 21.69651031], [88.30542755, 21.69693947], [88.30503845, 21.69734192], [88.30472565, 21.69775772], [88.30444336, 21.69815445], [88.3041687, 21.69852066], [88.30389404, 21.69887161], [88.3035965, 21.6991806], [88.30332947, 21.69953728], [88.30304718, 21.69987106], [88.30275726, 21.70021057], [88.30243683, 21.70048523], [88.30208588, 21.70070076], [88.30182648, 21.70095062], [88.30158997, 21.70119095], [88.30134583, 21.70144081], [88.30110931, 21.70175934], [88.3008728, 21.70211029], [88.30065155, 21.70242882], [88.30051422, 21.70285416], [88.3004303, 21.70344162], [88.30036926, 21.70402908], [88.30042267, 21.70455933], [88.30057526, 21.70498466], [88.30084991, 21.70536995], [88.3012085, 21.70578957], [88.30163574, 21.70625687], [88.30207825, 21.70675468], [88.3026123, 21.70705986], [88.30316925, 21.70732117], [88.30371857, 21.70748329], [88.30428314, 21.70756149], [88.30480957, 21.70773125], [88.30512238, 21.70770073], [88.30537415, 21.70767403], [88.30593872, 21.70752144], [88.30651093, 21.70744133], [88.30708313, 21.70743561], [88.30751801, 21.70730019], [88.30791473, 21.7071743], [88.3082962, 21.70697021], [88.30871582, 21.70683098], [88.30911255, 21.70664978], [88.30948639, 21.70643044], [88.30996704, 21.70639038], [88.31041718, 21.70638657], [88.31051636, 21.70638084], [88.31108093, 21.70635033], [88.3116684, 21.70611191], [88.3152771, 21.70611191], [88.31555176, 21.70583344], [88.31639099, 21.70583344], [88.31666565, 21.70555496], [88.31833649, 21.70555496], [88.31861115, 21.70583344], [88.32305908, 21.70583344], [88.32333374, 21.70611191], [88.32389069, 21.70611191], [88.32416534, 21.70583344], [88.32444763, 21.70583344], [88.32472229, 21.70555496], [88.32639313, 21.70556259], [88.32666779, 21.7052803], [88.32713318, 21.7052803], [88.32861328, 21.7052803], [88.32917023, 21.7047081], [88.32944489, 21.70472145], [88.33027649, 21.70388985], [88.33055878, 21.70388985], [88.33110809, 21.70332909], [88.33139038, 21.7033329], [88.33249664, 21.70222282], [88.33277893, 21.70222282], [88.33333588, 21.70166779], [88.33390045, 21.70166969], [88.33499908, 21.70055962], [88.33499908, 21.70028114], [88.33555603, 21.69972038], [88.33555603, 21.69944572], [88.33583069, 21.69916534], [88.33721924, 21.69778061], [88.33805847, 21.69778061], [88.33860779, 21.69721985], [88.33833313, 21.69694328], [88.33860779, 21.69667053], [88.33860779, 21.69639015], [88.34055328, 21.69444275], [88.34059906, 21.69474983], [88.34089661, 21.69444275], [88.34122467, 21.69413948], [88.34150696, 21.69379044], [88.34187317, 21.69354439], [88.34220123, 21.69324875], [88.34249115, 21.69290924], [88.34275055, 21.69254112], [88.3430481, 21.69222069], [88.34333038, 21.69187927], [88.34361267, 21.69153976], [88.34388733, 21.69121552], [88.34416962, 21.69087982], [88.34444427, 21.69054985], [88.34471893, 21.69019127], [88.345047, 21.68976212], [88.34610748, 21.68861008], [88.34583282, 21.68833351], [88.34583282, 21.68805695], [88.34610748, 21.68778038], [88.34610748, 21.68695831], [88.34638977, 21.6866703], [88.34638977, 21.68638992], [88.3466568, 21.68610954], [88.34694672, 21.68611145], [88.34693146, 21.68564987], [88.34732056, 21.68526077], [88.34789276, 21.6849308], [88.34805298, 21.68447113], [88.34812927, 21.68405151], [88.34828186, 21.68369675], [88.34835052, 21.68336105], [88.34845734, 21.68305969], [88.34864044, 21.68275452], [88.34888458, 21.68240929], [88.34912872, 21.68198967], [88.34942627, 21.68155098], [88.34976959, 21.68110085], [88.35020447, 21.68075562], [88.35056305, 21.68028259], [88.35028076, 21.68000031], [88.35028076, 21.67972183], [88.35055542, 21.67944527], [88.35056305, 21.67889023], [88.35083008, 21.67861176], [88.35083008, 21.67833328], [88.35111237, 21.67805481], [88.35111237, 21.67555618], [88.35083008, 21.67527962], [88.35083008, 21.67444038], [88.34999847, 21.67361069], [88.34971619, 21.67361069], [88.34916687, 21.67305946], [88.35056305, 21.67165947], [88.35028076, 21.67138863], [88.35028076, 21.67111015], [88.34944153, 21.67027855], [88.34944153, 21.67000008], [88.34916687, 21.6697197], [88.34916687, 21.66944313], [88.34944153, 21.66917038], [88.34916687, 21.66889], [88.34916687, 21.66833115], [88.34999847, 21.66749954], [88.34999847, 21.66638947], [88.34944153, 21.66583061], [88.34944153, 21.66555595], [88.34887695, 21.66500092], [88.34887695, 21.66443825], [88.34860992, 21.6641674], [88.34860992, 21.66332817], [88.34805298, 21.66277885], [88.34777832, 21.66278839], [88.34729004, 21.66229057], [88.34722137, 21.66221809], [88.34694672, 21.66222191], [88.34666443, 21.66194534], [88.34638977, 21.66194916], [88.34610748, 21.66167068], [88.34610748, 21.6613903], [88.34638977, 21.66110992], [88.34638977, 21.66055679], [88.34693146, 21.66001129], [88.34722137, 21.65972137], [88.34750366, 21.65972137], [88.34833527, 21.65888977], [88.34833527, 21.6586113], [88.34860992, 21.65833282], [88.34860992, 21.65638924], [88.34887695, 21.65611076], [88.34887695, 21.65583038], [88.34777832, 21.65472221], [88.34750366, 21.65472221], [88.34666443, 21.6538887], [88.34638977, 21.65389061], [88.34638977, 21.65333176], [88.34750366, 21.65222168], [88.34777832, 21.65222168], [88.34805298, 21.65250015], [88.34805298, 21.65278053], [88.34860992, 21.65278053], [88.34887695, 21.65306282], [88.34916687, 21.65305519], [88.34944153, 21.65333366], [88.34999847, 21.65333176], [88.3500824, 21.65341377], [88.35028076, 21.65361977], [88.35111237, 21.65361977], [88.35138702, 21.65333176], [88.35138702, 21.65305519], [88.35221863, 21.65222168], [88.35221863, 21.65194511], [88.35250092, 21.65167236], [88.35250092, 21.6511097], [88.35305786, 21.65055466], [88.35305786, 21.65027809], [88.35388947, 21.64944077], [88.35416412, 21.64944458], [88.35472107, 21.64888954], [88.35527802, 21.64888954], [88.35555267, 21.64861107], [88.35694122, 21.64861107], [88.35807037, 21.64750099], [88.35807037, 21.64722061], [88.35778046, 21.64694595], [88.35778046, 21.64666748], [88.35666656, 21.64556122], [88.35639191, 21.6455574], [88.35610962, 21.64583588], [88.35500336, 21.64583588], [88.35472107, 21.6455574], [88.35444641, 21.64556122], [88.35388947, 21.64500046], [88.35360718, 21.64500046], [88.35332489, 21.64476776], [88.35305786, 21.64472198], [88.35277557, 21.64444351], [88.35250092, 21.64444351], [88.35194397, 21.64388847], [88.35166931, 21.64389038], [88.35138702, 21.64417076], [88.35083008, 21.64417076], [88.35028076, 21.64361], [88.34999847, 21.64333344], [88.34999847, 21.6427784], [88.34971619, 21.64249992], [88.34971619, 21.64138985], [88.34944153, 21.64110947], [88.34944153, 21.6408329], [88.34916687, 21.6408329], [88.34889221, 21.64055634], [88.34887695, 21.64027977], [88.34860992, 21.63999939], [88.34860992, 21.63943863], [88.34860992, 21.63926506], [88.34838104, 21.63894844], [88.34817505, 21.63866806], [88.3481369, 21.63835526], [88.3482666, 21.63800049], [88.34829712, 21.63764954], [88.34822083, 21.63731956], [88.34805298, 21.6370182], [88.34784698, 21.63673019], [88.34763336, 21.6364212], [88.34734344, 21.63616943], [88.34694672, 21.63611031], [88.3466568, 21.63582993], [88.34583282, 21.63583374], [88.34555817, 21.63555527], [88.34416962, 21.63555908], [88.34388733, 21.63528061], [88.34416962, 21.63500023], [88.34416962, 21.63389015], [88.34443665, 21.63360977], [88.34444427, 21.63333321], [88.34471893, 21.63305664], [88.34444427, 21.63277817], [88.34443665, 21.63249016], [88.34416962, 21.63222313], [88.34416962, 21.63194656], [88.34444427, 21.63166428], [88.34416962, 21.63138962], [88.34381866, 21.63138962], [88.34361267, 21.63138962], [88.34278107, 21.63055992], [88.34278107, 21.63027954], [88.34221649, 21.62972069], [88.34222412, 21.62944221], [88.34194183, 21.62916756], [88.34194183, 21.62805939], [88.34139252, 21.62750053], [88.34139252, 21.62722015], [88.34083557, 21.62666702], [88.3408432, 21.62611008], [88.34111023, 21.62583351], [88.34111023, 21.62500191], [88.3408432, 21.62471771], [88.33999634, 21.62472153], [88.33853149, 21.62353706], [88.33838654, 21.62259293], [88.33838654, 21.62179184], [88.33724213, 21.62111664], [88.33553314, 21.62083817], [88.33337402, 21.62071609], [88.33138275, 21.61977005], [88.33094025, 21.61896515], [88.330513, 21.61815834], [88.32950592, 21.61762047], [88.32807922, 21.61721802], [88.32749939, 21.61636925], [88.3272171, 21.61610985], [88.3263855, 21.61611176], [88.32570648, 21.61722183], [88.32527924, 21.61750031], [88.32472229, 21.61694336], [88.32470703, 21.61639023], [88.32444763, 21.61610985], [88.32444763, 21.61583138], [88.3236084, 21.61583138], [88.32333374, 21.61555481], [88.32305908, 21.61555481], [88.32277679, 21.61583138], [88.32250214, 21.61583138], [88.32250214, 21.61499977], [88.32196045, 21.61445045], [88.32196045, 21.61388969], [88.32138824, 21.61333275], [88.32138824, 21.61318207], [88.32098389, 21.61284256], [88.32070923, 21.61250877], [88.32045746, 21.61214828], [88.32015991, 21.61175156], [88.31983185, 21.61129761], [88.31938171, 21.61090088], [88.31887054, 21.61058044], [88.31837463, 21.61030579], [88.31788635, 21.61008072], [88.31739807, 21.61001015], [88.31691742, 21.60997963], [88.31645966, 21.60988426], [88.31614685, 21.60960007], [88.31595612, 21.60923958], [88.31582642, 21.60889053], [88.31582642, 21.60861015], [88.3152771, 21.60805511], [88.31500244, 21.60805511], [88.31472015, 21.60833359], [88.31277466, 21.60833359], [88.3125, 21.60861206], [88.31222534, 21.60833359], [88.31194305, 21.60833359], [88.3116684, 21.60861206], [88.31138611, 21.60861015], [88.31111145, 21.60889053], [88.31083679, 21.60889053], [88.31054688, 21.60917091], [88.31027985, 21.6091671], [88.3097229, 21.60972214], [88.30944824, 21.60972023], [88.30805206, 21.61111069], [88.30792236, 21.61148453], [88.30776215, 21.61186028], [88.30755615, 21.61222076], [88.30750275, 21.61265945], [88.30744171, 21.61314011], [88.30723572, 21.61360741], [88.30702972, 21.61413002], [88.30695343, 21.61472321], [88.3069458, 21.61531639], [88.30691528, 21.61584473], [88.30678558, 21.61627197], [88.3066864, 21.61667252], [88.30667114, 21.61709023], [88.30664063, 21.61757088], [88.30651093, 21.61809158], [88.30641174, 21.61862946], [88.30640411, 21.61912537], [88.30644226, 21.61952209], [88.30632782, 21.61984253], [88.30621338, 21.62034035], [88.30632019, 21.62093163], [88.30625153, 21.62140083], [88.3061676, 21.6218605], [88.30618286, 21.62238693], [88.30612946, 21.62288284], [88.30610657, 21.62342262], [88.30605316, 21.62394524], [88.30589294, 21.62446976], [88.30583954, 21.62500954], [88.30583191, 21.62556267], [88.30583191, 21.62611008], [88.30583191, 21.62664413], [88.30583191, 21.62714958], [88.30583191, 21.62763023], [88.30583191, 21.6280899], [88.30581665, 21.62855911], [88.30575562, 21.62906075], [88.30583954, 21.62959671], [88.30597687, 21.6301403], [88.30609131, 21.6307106], [88.3061142, 21.63129807], [88.30615234, 21.63189316], [88.30636597, 21.6324482], [88.30654907, 21.63305092], [88.30673981, 21.63368034], [88.30690765, 21.63428688], [88.30696106, 21.6348896], [88.30696106, 21.6354866], [88.30705261, 21.63603973], [88.30724335, 21.63656044], [88.30750275, 21.63705063], [88.30776978, 21.63754082], [88.3080368, 21.6380291], [88.30831909, 21.63850021], [88.30854797, 21.63898087], [88.30869293, 21.63948059], [88.30887604, 21.63987541], [88.30902863, 21.6402607], [88.30917358, 21.64066887], [88.30932617, 21.64110947], [88.30948639, 21.64159966], [88.30973053, 21.64205933], [88.30993652, 21.6425209], [88.31011963, 21.64297867], [88.31034851, 21.64340019], [88.31056213, 21.64382935], [88.3107605, 21.64427948], [88.31083679, 21.64472008], [88.31111145, 21.64500046], [88.31111145, 21.64528084], [88.31138611, 21.6455574], [88.31138611, 21.64583015], [88.3116684, 21.64611053], [88.3116684, 21.64666748], [88.31194305, 21.64694595], [88.31194305, 21.64722061], [88.31223297, 21.64750099], [88.31223297, 21.64777946], [88.3125, 21.64805984], [88.3125, 21.64888954], [88.31305695, 21.64944458], [88.31305695, 21.64972115], [88.3133316, 21.64999962], [88.3133316, 21.65055466], [88.31305695, 21.65083122], [88.31305695, 21.65138817], [88.31361389, 21.65194511], [88.31360626, 21.65333176], [88.31416321, 21.6538887], [88.31416321, 21.65444374], [88.31445313, 21.65472031], [88.31445313, 21.65528107], [88.31472015, 21.65555573], [88.31472015, 21.65722466], [88.31495667, 21.65750694], [88.31500244, 21.65777969], [88.3152771, 21.65805435], [88.3152771, 21.65833092], [88.3152771, 21.65888023], [88.31532288, 21.6593895], [88.31550598, 21.65985107], [88.31561279, 21.66036987], [88.31582642, 21.66082954], [88.31606293, 21.6613102], [88.3161087, 21.66188812], [88.31611633, 21.66251945], [88.3162384, 21.66318893], [88.31636047, 21.66387939], [88.31642914, 21.66460991], [88.31659698, 21.66535187], [88.31665802, 21.66607094], [88.31665802, 21.66676521], [88.31656647, 21.6674099], [88.31620789, 21.6679554], [88.31601715, 21.66847038], [88.31613922, 21.66905785], [88.31633759, 21.66971016], [88.31639099, 21.67041779], [88.31633759, 21.6711216], [88.31608582, 21.67176819], [88.31583405, 21.67237854], [88.31597137, 21.67307091], [88.31590271, 21.67368126], [88.31585693, 21.67424011], [88.31591797, 21.67476082], [88.31601715, 21.67527962], [88.31587982, 21.67575073], [88.31582642, 21.67620277], [88.31583405, 21.67664909], [88.31583405, 21.67711449], [88.3157959, 21.67759132], [88.31561279, 21.67804909], [88.31552887, 21.67856979], [88.31539154, 21.67910194], [88.31523895, 21.67959976], [88.31501007, 21.68014717], [88.31481171, 21.68075943], [88.31468964, 21.68139076], [88.3144989, 21.6819191], [88.31442261, 21.68239975], [88.31429291, 21.6827774], [88.31416321, 21.68310165], [88.31398773, 21.68338966], [88.31389618, 21.68370247], [88.31382751, 21.68400955], [88.3136673, 21.68425941], [88.31352234, 21.68452072], [88.31333923, 21.68475914], [88.31317139, 21.68502808], [88.31302643, 21.68534088], [88.31286621, 21.68562889], [88.31278992, 21.68592834], [88.31275177, 21.68626785], [88.31263733, 21.6865406], [88.31250763, 21.68684959], [88.31239319, 21.68719292], [88.31221771, 21.68753052], [88.31202698, 21.68788147], [88.31189728, 21.68828964], [88.31167603, 21.68862534], [88.3114624, 21.68897057], [88.31130219, 21.68937111], [88.31108093, 21.68970108], [88.31082916, 21.68999863], [88.31056213, 21.69029427], [88.31034851, 21.69062805], [88.31018829, 21.69103622], [88.30993652, 21.69138908], [88.30963135, 21.69177055], [88.30931091, 21.69219017]]], [[[88.4540329, 21.70934105], [88.45444489, 21.70916748], [88.45500183, 21.70861053], [88.45500183, 21.70833015], [88.45555878, 21.70777702], [88.45527649, 21.70777702], [88.45583344, 21.70722008], [88.45583344, 21.70694351], [88.45639038, 21.70638847], [88.45639038, 21.70611191], [88.45718384, 21.70549393], [88.45719147, 21.70514488], [88.45724487, 21.70474815], [88.45735931, 21.70430946], [88.4575119, 21.70385551], [88.45770264, 21.70336151], [88.45783234, 21.70284462], [88.45805359, 21.70239067], [88.45826721, 21.70197105], [88.4584198, 21.70153046], [88.45861053, 21.7011528], [88.45879364, 21.70079041], [88.45895386, 21.70041084], [88.45915985, 21.70004272], [88.45936584, 21.69964981], [88.45952606, 21.69923019], [88.45973969, 21.69883537], [88.45996857, 21.69843864], [88.4601593, 21.69800949], [88.46031189, 21.69756317], [88.46048737, 21.69713974], [88.46065521, 21.69671059], [88.46086884, 21.69628906], [88.46110535, 21.69588852], [88.4613266, 21.69544983], [88.46140289, 21.69492722], [88.46150208, 21.69439125], [88.46173096, 21.6939106], [88.46198273, 21.69342041], [88.46222687, 21.69293022], [88.46247864, 21.69244957], [88.462677, 21.69197083], [88.46290588, 21.69152641], [88.46311188, 21.69108009], [88.46333313, 21.69067001], [88.46360016, 21.69029617], [88.46388245, 21.68992805], [88.4641571, 21.68952942], [88.46444702, 21.68909073], [88.46473694, 21.68861961], [88.46505737, 21.68816185], [88.46538544, 21.68773079], [88.46567535, 21.68725967], [88.46595001, 21.68677521], [88.46613312, 21.68621063], [88.46633148, 21.68560982], [88.46644592, 21.68497849], [88.46660614, 21.68439102], [88.46669769, 21.68387985], [88.46684265, 21.68343925], [88.46694183, 21.68302917], [88.46701813, 21.68260956], [88.4671402, 21.68221283], [88.46702576, 21.68173027], [88.46722412, 21.68128204], [88.46748352, 21.68081856], [88.46769714, 21.68032074], [88.46803284, 21.67988014], [88.4683075, 21.67942429], [88.46845245, 21.6788559], [88.46850586, 21.67823029], [88.46853638, 21.67811012], [88.46865845, 21.67767906], [88.46885681, 21.67720985], [88.4690094, 21.67673111], [88.46918488, 21.67642021], [88.46925354, 21.67629242], [88.46955872, 21.67578888], [88.46994019, 21.67528915], [88.47026062, 21.67476082], [88.47055054, 21.6742878], [88.47073364, 21.67384529], [88.4706955, 21.67341423], [88.47068787, 21.6729908], [88.47027588, 21.67277527], [88.46971893, 21.67222023], [88.46971893, 21.67164993], [88.46971893, 21.67083549], [88.46950531, 21.67029762], [88.46922302, 21.66990089], [88.46916962, 21.6697216], [88.46888733, 21.66944313], [88.46888733, 21.66917038], [88.46721649, 21.66749954], [88.46611023, 21.66749954], [88.46607971, 21.66776276], [88.46594238, 21.66797256], [88.4658432, 21.66825485], [88.46573639, 21.66860962], [88.46563721, 21.66901016], [88.4656601, 21.6694603], [88.46576691, 21.66990089], [88.46582031, 21.67036247], [88.4658432, 21.67084122], [88.46585846, 21.6713562], [88.46591187, 21.67189026], [88.46605682, 21.67243767], [88.46617126, 21.67304039], [88.46639252, 21.67361069], [88.46639252, 21.67368889], [88.46639252, 21.67444038], [88.46666718, 21.6747303], [88.46666718, 21.67555809], [88.46611023, 21.67611122], [88.46583557, 21.67611122], [88.46555328, 21.67583275], [88.46555328, 21.67499924], [88.46527863, 21.6747303], [88.46527863, 21.67416954], [88.46512604, 21.6738205], [88.46498108, 21.67345619], [88.46479797, 21.67307091], [88.46475983, 21.67263985], [88.46475983, 21.67220116], [88.46475983, 21.67176819], [88.46473694, 21.67135048], [88.46466064, 21.67093086], [88.46461487, 21.67046928], [88.4646225, 21.66995811], [88.46463776, 21.66949081], [88.46463013, 21.66908264], [88.46460724, 21.66868973], [88.4646225, 21.66823959], [88.46466827, 21.66770744], [88.46478271, 21.66718102], [88.46489716, 21.66672134], [88.46496582, 21.66628838], [88.46491241, 21.66584969], [88.46479034, 21.6654129], [88.46472931, 21.6649437], [88.46466064, 21.66449356], [88.46444702, 21.6641674], [88.46444702, 21.66389084], [88.46472168, 21.66361046], [88.46469879, 21.65942192], [88.46452332, 21.65897751], [88.46446228, 21.65855026], [88.46443939, 21.65813065], [88.46438599, 21.65772057], [88.46422577, 21.65733147], [88.46409607, 21.6568985], [88.46389008, 21.65647125], [88.46366882, 21.65603256], [88.46350861, 21.65551949], [88.46337128, 21.65501976], [88.46325684, 21.65457153], [88.4630661, 21.65423965], [88.46286011, 21.65398979], [88.46260071, 21.65378952], [88.46235657, 21.65354538], [88.46212769, 21.65324974], [88.46195984, 21.6529007], [88.46194458, 21.65250015], [88.46138763, 21.65195274], [88.46138763, 21.65083122], [88.46166992, 21.65055466], [88.46138763, 21.65027809], [88.46111298, 21.65027809], [88.46083069, 21.64999962], [88.46028137, 21.64999962], [88.46006012, 21.64971161], [88.45967865, 21.6497612], [88.45928955, 21.64978981], [88.45892334, 21.64960289], [88.45861053, 21.64944077], [88.45888519, 21.64944458], [88.45888519, 21.64916611], [88.45916748, 21.64888954], [88.45916748, 21.64861107], [88.45999908, 21.64777946], [88.45999908, 21.64500046], [88.4597168, 21.64472008], [88.45972443, 21.64388847], [88.45916748, 21.64332962], [88.45916748, 21.6427784], [88.45944214, 21.64249992], [88.45944214, 21.64221954], [88.45916748, 21.64194489], [88.45916748, 21.64166641], [88.45833588, 21.6408329], [88.45861053, 21.64055634], [88.45861053, 21.63943863], [88.45833588, 21.63916588], [88.45833588, 21.63862038], [88.45777893, 21.63806152], [88.45777893, 21.63777924], [88.45749664, 21.63750076], [88.45749664, 21.6369381], [88.45722198, 21.63666725], [88.45722961, 21.63639069], [88.45694733, 21.63611031], [88.45694733, 21.63582993], [88.45666504, 21.63555527], [88.45667267, 21.63528061], [88.45610809, 21.63471985], [88.45610809, 21.63444519], [88.45582581, 21.63417053], [88.45582581, 21.63360977], [88.45527649, 21.63305664], [88.45527649, 21.63277817], [88.45500183, 21.63249016], [88.45500183, 21.63166428], [88.45527649, 21.63138962], [88.45500183, 21.63111115], [88.45471954, 21.63111115], [88.45417023, 21.63055992], [88.45388794, 21.63055992], [88.45388794, 21.63027954], [88.45361328, 21.63000107], [88.45361328, 21.62916946], [88.45333099, 21.6288929], [88.45333099, 21.62861061], [88.45305634, 21.62833023], [88.45305634, 21.6277771], [88.45276642, 21.62750053], [88.45276642, 21.62694168], [88.45249939, 21.62666702], [88.45305634, 21.62611008], [88.45305634, 21.62583351], [88.45388794, 21.62500191], [88.45400238, 21.62477112], [88.45388794, 21.62445068], [88.45388794, 21.6241684], [88.45361328, 21.62388992], [88.45361328, 21.62361908], [88.45333099, 21.62333107], [88.45333099, 21.62305641], [88.45276642, 21.62249947], [88.45276642, 21.62222099], [88.45111084, 21.62055779], [88.45055389, 21.62055779], [88.45027924, 21.6202755], [88.44999695, 21.62028122], [88.44972229, 21.62000084], [88.44889069, 21.62000084], [88.4486084, 21.61972046], [88.44805908, 21.61972237], [88.44750214, 21.61916733], [88.44695282, 21.61917114], [88.44676208, 21.61898613], [88.4466629, 21.61888885], [88.44610596, 21.61889076], [88.4458313, 21.61861038], [88.44555664, 21.61861038], [88.44526672, 21.61833], [88.44527435, 21.61805344], [88.44416809, 21.61695099], [88.44416809, 21.61667061], [88.44249725, 21.61499977], [88.44223022, 21.61499977], [88.44194794, 21.61528015], [88.4411087, 21.61527824], [88.44055176, 21.61582947], [88.44055176, 21.61639023], [88.4411087, 21.61694336], [88.4411087, 21.61722183], [88.44139099, 21.61749077], [88.44139099, 21.61861038], [88.44167328, 21.61889076], [88.44139099, 21.61917114], [88.44139099, 21.62000084], [88.4411087, 21.6202755], [88.4411087, 21.62144279], [88.44137573, 21.62200356], [88.44153595, 21.62264061], [88.44152069, 21.62335587], [88.44112396, 21.62396431], [88.44068909, 21.62451935], [88.44030762, 21.62508965], [88.43992615, 21.62560081], [88.44005585, 21.62593079], [88.44013977, 21.62630081], [88.43998718, 21.62673759], [88.43976593, 21.62722015], [88.43976593, 21.62775993], [88.43991852, 21.6282692], [88.4397583, 21.62866402], [88.43965912, 21.62903023], [88.4394989, 21.62932014], [88.43942261, 21.6296463], [88.43927002, 21.62990952], [88.43914795, 21.63021088], [88.43898773, 21.63047791], [88.43887329, 21.63079071], [88.43875885, 21.6310997], [88.43859863, 21.63137054], [88.4384079, 21.63161087], [88.43827057, 21.63187027], [88.43809509, 21.6321373], [88.43801117, 21.63253975], [88.43776703, 21.63298988], [88.4375, 21.63347816], [88.43721008, 21.63396645], [88.43688202, 21.63439178], [88.43651581, 21.6347599], [88.436203, 21.63517761], [88.43585968, 21.6355896], [88.43551636, 21.63602066], [88.43517303, 21.63640022], [88.43488312, 21.63679123], [88.43464661, 21.63712692], [88.43435669, 21.63733101], [88.43415833, 21.63758278], [88.43395996, 21.63780594], [88.43376923, 21.63804817], [88.43357849, 21.63831711], [88.43332672, 21.63859749], [88.4330368, 21.63891029], [88.432724, 21.63921547], [88.43241119, 21.63954353], [88.43214417, 21.63993454], [88.43180847, 21.64027023], [88.43144226, 21.64060974], [88.43112183, 21.64097977], [88.43080902, 21.64137077], [88.43044281, 21.64167976], [88.43005371, 21.64199829], [88.42971802, 21.64236069], [88.42938995, 21.64273071], [88.42901611, 21.64306068], [88.42865753, 21.64339066], [88.42832947, 21.64376068], [88.42797089, 21.64410973], [88.42753601, 21.64439011], [88.42707062, 21.6446209], [88.42669678, 21.6449604], [88.42635345, 21.64530945], [88.4260025, 21.64567375], [88.42567444, 21.64608383], [88.42527771, 21.64645004], [88.42487335, 21.64684105], [88.42447662, 21.64725685], [88.42414856, 21.6477623], [88.42373657, 21.6482048], [88.42328644, 21.64859962], [88.42281342, 21.64897537], [88.42240143, 21.64938354], [88.42214203, 21.64978027], [88.42178345, 21.65003586], [88.4214859, 21.65032005], [88.42124939, 21.65066528], [88.42089844, 21.65094948], [88.42064667, 21.65135002], [88.42050934, 21.65192032], [88.42027283, 21.65246964], [88.4200592, 21.65307045], [88.42011261, 21.65372086], [88.42028809, 21.65437126], [88.42050171, 21.65496826], [88.42059326, 21.65554237], [88.42076874, 21.65595818], [88.42082977, 21.65637016], [88.4208374, 21.65677834], [88.4208374, 21.65717316], [88.4208374, 21.65757942], [88.42082214, 21.65800858], [88.42072296, 21.6584301], [88.42059326, 21.65883064], [88.42055511, 21.65926552], [88.42055511, 21.6597023], [88.42056274, 21.66012955], [88.42056274, 21.66056824], [88.42054749, 21.66100883], [88.42047119, 21.66145325], [88.42034912, 21.66188049], [88.42047119, 21.66236115], [88.4203186, 21.66283035], [88.42028046, 21.66332054], [88.42028809, 21.66385078], [88.42038727, 21.66442108], [88.42048645, 21.66504097], [88.4203186, 21.66568756], [88.42028046, 21.66638184], [88.42027283, 21.66708183], [88.42028046, 21.6677494], [88.42034149, 21.66835976], [88.42049408, 21.66887856], [88.42043304, 21.66941833], [88.42050171, 21.66995049], [88.42054749, 21.67038918], [88.42056274, 21.67076111], [88.42055511, 21.67107773], [88.42057037, 21.67346954], [88.42042542, 21.67481804], [88.42037964, 21.67501831], [88.41999817, 21.67656708], [88.41942596, 21.6777401], [88.41932678, 21.67817116], [88.41919708, 21.67866135], [88.41916656, 21.67925072], [88.41912842, 21.67988014], [88.41894531, 21.68051147], [88.41887665, 21.68115807], [88.41876984, 21.68184662], [88.41855621, 21.6825695], [88.41886139, 21.68316078], [88.41913605, 21.68369102], [88.41918182, 21.68394279], [88.41931152, 21.68404007], [88.41944122, 21.68472481], [88.41944122, 21.68610954], [88.41945648, 21.6866703], [88.41945648, 21.68806076], [88.41937256, 21.68841934], [88.41941071, 21.68917847], [88.41960907, 21.6896801], [88.41959381, 21.68982887], [88.42020416, 21.69026375], [88.42061615, 21.69053078], [88.4210434, 21.69074059], [88.42141724, 21.6909523], [88.42176819, 21.69117355], [88.42218018, 21.69136047], [88.42253113, 21.69164085], [88.42286682, 21.69159126], [88.42321777, 21.69178963], [88.42373657, 21.69181252], [88.42428589, 21.6923027], [88.42462158, 21.69272041], [88.42481995, 21.69306183], [88.42511749, 21.69333267], [88.42558289, 21.69346619], [88.42608643, 21.69358826], [88.42649078, 21.69388008], [88.42712402, 21.69442558], [88.42734528, 21.69457245], [88.42767334, 21.69499969], [88.42806244, 21.69528961], [88.42842102, 21.69557953], [88.42871094, 21.6959095], [88.42904663, 21.69617271], [88.42928314, 21.69650078], [88.42946625, 21.69680977], [88.42971039, 21.69704819], [88.42991638, 21.69728279], [88.4300766, 21.6975708], [88.43026733, 21.69779968], [88.43041229, 21.69804955], [88.43054962, 21.69832039], [88.43067169, 21.69859123], [88.43081665, 21.69888115], [88.4309082, 21.69921875], [88.43109131, 21.69951057], [88.43144226, 21.69986534], [88.43193054, 21.70090294], [88.43200684, 21.70107269], [88.43244171, 21.70215034], [88.4332962, 21.70309067], [88.43443298, 21.70400047], [88.43467712, 21.70446014], [88.43518066, 21.7048111], [88.4356308, 21.70518684], [88.43605042, 21.7055645], [88.43645477, 21.70594215], [88.43687439, 21.70627594], [88.43730927, 21.7065506], [88.43775177, 21.70680237], [88.43817902, 21.70705986], [88.43859863, 21.7073307], [88.43902588, 21.70759964], [88.43945313, 21.70784187], [88.43991852, 21.70806122], [88.44037628, 21.70827293], [88.44087982, 21.70846939], [88.44140625, 21.70863533], [88.44194794, 21.70878983], [88.4425354, 21.70890427], [88.44316864, 21.70900154], [88.44385529, 21.70903206], [88.44451904, 21.70902061], [88.44512939, 21.70898056], [88.44573212, 21.70903969], [88.44634247, 21.70909309], [88.44696808, 21.70915031], [88.44757843, 21.70922279], [88.44815063, 21.70919991], [88.44872284, 21.70923996], [88.4492569, 21.70933533], [88.44983673, 21.70936966], [88.4504776, 21.70940018], [88.45111847, 21.70941925], [88.45183563, 21.70944595], [88.45227814, 21.70947266], [88.45257568, 21.70949173], [88.45332336, 21.70942497], [88.4540329, 21.70934105]]], [[[88.63444519, 21.6566658], [88.6341629, 21.65638924], [88.63388824, 21.65639114], [88.63381195, 21.65631294], [88.63370514, 21.65620422], [88.6333313, 21.65583229], [88.6333313, 21.65527725], [88.63305664, 21.65500069], [88.63305664, 21.65444183], [88.63361359, 21.6538887], [88.63360596, 21.65306282], [88.63388824, 21.65278053], [88.63388824, 21.65195274], [88.63445282, 21.65138817], [88.63360596, 21.65055847], [88.63305664, 21.65055847], [88.63276672, 21.65027809], [88.63276672, 21.64999962], [88.63194275, 21.64916992], [88.63166809, 21.64916992], [88.6313858, 21.64888954], [88.63111115, 21.64916992], [88.63027954, 21.64916611], [88.62832642, 21.6511097], [88.62832642, 21.65138817], [88.6277771, 21.65194511], [88.6277771, 21.65222168], [88.62750244, 21.65250015], [88.62750244, 21.6543808], [88.62750244, 21.65806007], [88.62832642, 21.65888977], [88.62833405, 21.65916443], [88.6286087, 21.65944672], [88.6286087, 21.66055679], [88.62889862, 21.66082954], [88.62889099, 21.66194534], [88.62916565, 21.66222191], [88.62917328, 21.66332817], [88.62944794, 21.66361046], [88.62944794, 21.6641674], [88.6297226, 21.66443825], [88.6297226, 21.66527748], [88.63027954, 21.66583252], [88.63166809, 21.66722107], [88.63166809, 21.66749954], [88.63194275, 21.66777802], [88.6313858, 21.66833115], [88.6313858, 21.66889], [88.63249969, 21.67000008], [88.63249969, 21.67028046], [88.63276672, 21.67056084], [88.63277435, 21.67138863], [88.63360596, 21.67222023], [88.63361359, 21.67250061], [88.63391113, 21.67278099], [88.63417053, 21.67316818], [88.6344223, 21.67360306], [88.63462067, 21.67413139], [88.63491058, 21.67461967], [88.63526154, 21.67505074], [88.63560486, 21.67547035], [88.63595581, 21.6758194], [88.63630676, 21.67612648], [88.63661957, 21.67642212], [88.63691711, 21.67671967], [88.63719177, 21.6770153], [88.63744354, 21.67729378], [88.63766479, 21.67754364], [88.63788605, 21.67774963], [88.63817596, 21.67785072], [88.63855743, 21.67803955], [88.6390686, 21.67815971], [88.63955688, 21.67836952], [88.63999939, 21.67856979], [88.64039612, 21.67857361], [88.64065552, 21.6783886], [88.64082336, 21.67809105], [88.64090729, 21.67781067], [88.64108276, 21.6774807], [88.64112091, 21.67703056], [88.64112091, 21.67651558], [88.64111328, 21.67598915], [88.64111328, 21.67550087], [88.64111328, 21.6750412], [88.64109039, 21.67460251], [88.64097595, 21.67414856], [88.64079285, 21.67365265], [88.64055634, 21.67313004], [88.64041138, 21.67282295], [88.64029694, 21.67258072], [88.64009857, 21.67201042], [88.64006042, 21.6713829], [88.64009857, 21.67076111], [88.63993835, 21.67028999], [88.63977051, 21.66987991], [88.6397171, 21.66945648], [88.63964844, 21.66906929], [88.63948059, 21.66876984], [88.63944244, 21.66860008], [88.63944244, 21.66805649], [88.63916779, 21.66777992], [88.63916779, 21.66749954], [88.63889313, 21.66722107], [88.6388855, 21.6669445], [88.63833618, 21.66638947], [88.63833618, 21.66610909], [88.63777161, 21.66556168], [88.63777161, 21.66527939], [88.63749695, 21.66500092], [88.63749695, 21.66472054], [88.63639069, 21.66361046], [88.63639069, 21.66332817], [88.6361084, 21.66305542], [88.6361084, 21.66278839], [88.63582611, 21.66250038], [88.63582611, 21.66221809], [88.63471985, 21.66111183], [88.63444519, 21.66111183], [88.63444519, 21.66055679], [88.6341629, 21.66027832], [88.6341629, 21.65971947], [88.63388824, 21.65944672], [88.63388824, 21.6586113], [88.6341629, 21.65833282], [88.6341629, 21.65694237], [88.63444519, 21.6566658]]], [[[88.19560242, 21.72447968], [88.19499969, 21.72417068], [88.19473267, 21.72445107], [88.19473267, 21.72556114], [88.19499969, 21.72583961], [88.19499969, 21.72611046], [88.19528198, 21.72639084], [88.19527435, 21.7266674], [88.19555664, 21.72694588], [88.1955719, 21.72722054], [88.1958313, 21.72750092], [88.1958313, 21.72833252], [88.19555664, 21.72861099], [88.19559479, 21.72942162], [88.19579315, 21.72972107], [88.19586945, 21.73006821], [88.19600677, 21.73032951], [88.19613647, 21.73057938], [88.19633484, 21.73080444], [88.19655609, 21.73102951], [88.1967392, 21.73137093], [88.19695282, 21.7316494], [88.19721222, 21.73191833], [88.19747925, 21.73220253], [88.19776154, 21.73249245], [88.19802856, 21.73278046], [88.19824982, 21.73308945], [88.19847107, 21.73338509], [88.19868469, 21.73373413], [88.1989212, 21.73411942], [88.19918823, 21.73449516], [88.19944763, 21.73485184], [88.1996994, 21.73520279], [88.19991302, 21.73554039], [88.20013428, 21.7358284], [88.20034027, 21.73607063], [88.20056152, 21.73624992], [88.20077515, 21.73636436], [88.20101166, 21.73641396], [88.20105743, 21.73654175], [88.20111084, 21.73666954], [88.20137787, 21.73666954], [88.20137787, 21.73639107], [88.20194244, 21.73583031], [88.20194244, 21.73500061], [88.20166779, 21.73472023], [88.20166779, 21.73361015], [88.2013855, 21.73333359], [88.2013855, 21.73305511], [88.20111084, 21.73278046], [88.20111084, 21.73138809], [88.20054626, 21.73082924], [88.20055389, 21.73055649], [88.20027924, 21.73027992], [88.20027924, 21.72972107], [88.19999695, 21.7294445], [88.19999695, 21.72888947], [88.19972229, 21.72861099], [88.19972229, 21.72833061], [88.19944763, 21.72805786], [88.19944763, 21.72777939], [88.19889069, 21.72722054], [88.19895172, 21.72698021], [88.19864655, 21.72678947], [88.19834137, 21.72661972], [88.19802856, 21.72636986], [88.19773865, 21.7260685], [88.19747925, 21.72576904], [88.19719696, 21.72553253], [88.19696808, 21.72532272], [88.19671631, 21.7251606], [88.19650269, 21.7250042], [88.19626617, 21.72485733], [88.19600677, 21.72467995], [88.19560242, 21.72447968]]], [[[88.38195038, 21.66722107], [88.38194275, 21.66805649], [88.38166809, 21.6697197], [88.38166809, 21.67000008], [88.38195038, 21.67028046], [88.38194275, 21.67055321], [88.38166809, 21.67083549], [88.38195038, 21.67111015], [88.38166809, 21.67138863], [88.38166809, 21.67166519], [88.3813858, 21.67194366], [88.3805542, 21.67194366], [88.38027954, 21.67222214], [88.37999725, 21.67222023], [88.3797226, 21.67250061], [88.3797226, 21.67333031], [88.37999725, 21.67361069], [88.37999725, 21.67416954], [88.38011932, 21.67456055], [88.38023376, 21.67504692], [88.38026428, 21.67559624], [88.38025665, 21.67617035], [88.38021088, 21.67675018], [88.38004303, 21.67720985], [88.37983704, 21.67760086], [88.37999725, 21.67778969], [88.37999725, 21.67944527], [88.3797226, 21.67972183], [88.3797226, 21.68028259], [88.37999725, 21.68055534], [88.3797226, 21.68083191], [88.38027954, 21.68139076], [88.38027954, 21.68166733], [88.3805542, 21.68194389], [88.3805542, 21.68222237], [88.38078308, 21.68268394], [88.38109589, 21.68316078], [88.38141632, 21.68366241], [88.38176727, 21.6841526], [88.38215637, 21.68468094], [88.38253021, 21.68524742], [88.38297272, 21.68580246], [88.38345337, 21.68632507], [88.38400269, 21.68679047], [88.38451385, 21.68728828], [88.38500977, 21.68779182], [88.38574982, 21.68830109], [88.3859024, 21.68862915], [88.38632202, 21.68900108], [88.38703156, 21.68926048], [88.38719177, 21.68949127], [88.3875351, 21.68969727], [88.38788605, 21.68985748], [88.38819122, 21.69013786], [88.38848877, 21.69044113], [88.38883209, 21.69078255], [88.3891983, 21.69112778], [88.38963318, 21.6914196], [88.39006805, 21.69171715], [88.39054108, 21.69195175], [88.39096832, 21.69221687], [88.39135742, 21.69249344], [88.39196014, 21.69287109], [88.39244843, 21.69313049], [88.39274597, 21.69360161], [88.39309692, 21.69372749], [88.39348602, 21.69401932], [88.3939743, 21.69419861], [88.39437866, 21.69449043], [88.39490509, 21.69488907], [88.39520264, 21.69519234], [88.39595032, 21.69571495], [88.39643097, 21.69612122], [88.3969574, 21.69659615], [88.39749908, 21.69721985], [88.39768219, 21.69752884], [88.39807129, 21.69783211], [88.39844513, 21.69810295], [88.39874268, 21.6984539], [88.39904022, 21.6987896], [88.39923859, 21.69922829], [88.39946747, 21.69965363], [88.39972687, 21.70005226], [88.39998627, 21.70041084], [88.40021515, 21.70077515], [88.40028381, 21.70124435], [88.40054321, 21.70163155], [88.4006958, 21.70197105], [88.40100861, 21.70214081], [88.40106201, 21.70232964], [88.40136719, 21.70260048], [88.40156555, 21.70292664], [88.40167999, 21.70330429], [88.4019928, 21.70374107], [88.40209198, 21.70421028], [88.40245056, 21.70478058], [88.402771, 21.70540047], [88.4029541, 21.70584679], [88.4030304, 21.70603561], [88.40317535, 21.70664215], [88.40322113, 21.70713806], [88.4033432, 21.70750046], [88.40348053, 21.70779037], [88.40358734, 21.70808029], [88.40368652, 21.70838928], [88.40387726, 21.70866966], [88.40406799, 21.70899963], [88.40415955, 21.70941925], [88.40421295, 21.70988083], [88.40439606, 21.71030807], [88.40439606, 21.71075058], [88.40418243, 21.71116257], [88.4039917, 21.71158028], [88.40390778, 21.71199036], [88.40388489, 21.71241379], [88.40383911, 21.71285057], [88.40378571, 21.71344566], [88.40381622, 21.71385193], [88.40382385, 21.71453857], [88.40387726, 21.71519089], [88.4037323, 21.7157402], [88.40362549, 21.71623611], [88.40354156, 21.7166729], [88.40335846, 21.71700096], [88.40319824, 21.71731567], [88.40296936, 21.71759987], [88.402771, 21.71793556], [88.40257263, 21.71829987], [88.40245819, 21.71878052], [88.40222931, 21.71927071], [88.40197754, 21.71983528], [88.40174103, 21.72044945], [88.40135193, 21.72097969], [88.40085602, 21.72142982], [88.40036011, 21.72184753], [88.39982605, 21.72219849], [88.39927673, 21.72244072], [88.39898682, 21.72254944], [88.39826202, 21.72278976], [88.39814758, 21.72334862], [88.3975296, 21.72340965], [88.3972168, 21.72375107], [88.39689636, 21.7240715], [88.39650726, 21.72432709], [88.39609528, 21.72454834], [88.39563751, 21.72472954], [88.39514923, 21.72492981], [88.39457703, 21.72504044], [88.39402771, 21.7252655], [88.39341736, 21.7254715], [88.3927536, 21.72567368], [88.39205933, 21.72585487], [88.3914032, 21.72610092], [88.39080048, 21.72629929], [88.39028931, 21.72636223], [88.38988495, 21.72624779], [88.38935852, 21.72590065], [88.38916779, 21.72611046], [88.38833618, 21.72611046], [88.38804626, 21.72639084], [88.38582611, 21.72639084], [88.38555908, 21.72611046], [88.38471985, 21.72611046], [88.38445282, 21.72583961], [88.38276672, 21.72583961], [88.38249969, 21.72556114], [88.38195038, 21.72556114], [88.38166809, 21.72583961], [88.3813858, 21.72556114], [88.37999725, 21.72556114], [88.3797226, 21.72528076], [88.37832642, 21.72528076], [88.3777771, 21.72472], [88.37722015, 21.72472191], [88.37695313, 21.72500038], [88.37666321, 21.72500038], [88.37631989, 21.72495079], [88.3759613, 21.72478485], [88.37554169, 21.72467422], [88.37516022, 21.72448349], [88.37472534, 21.72439957], [88.37433624, 21.72421074], [88.37391663, 21.7241497], [88.37352753, 21.72405815], [88.37317657, 21.72392082], [88.37280273, 21.7238884], [88.37239838, 21.72386169], [88.37201691, 21.72373962], [88.3716507, 21.72363091], [88.37126923, 21.72364426], [88.37107849, 21.72373009], [88.37090302, 21.7238102], [88.37047577, 21.72397041], [88.37008667, 21.72418976], [88.36974335, 21.7244606], [88.3694458, 21.72478294], [88.36917114, 21.7251358], [88.36894989, 21.72553253], [88.36885071, 21.72602654], [88.36868286, 21.72648048], [88.36862183, 21.72693062], [88.36863708, 21.7273407], [88.3687973, 21.72768784], [88.3690033, 21.72802353], [88.36929321, 21.72832108], [88.36964417, 21.72861099], [88.37006378, 21.72888565], [88.3705368, 21.72911072], [88.37110138, 21.7292099], [88.37155914, 21.72943115], [88.37200165, 21.7296257], [88.37249756, 21.72972107], [88.37277985, 21.72999954], [88.37333679, 21.72999954], [88.37361145, 21.73027992], [88.37388611, 21.73027992], [88.375, 21.73083305], [88.37527466, 21.73083305], [88.37555695, 21.73055649], [88.37611389, 21.73027992], [88.37652588, 21.73069191], [88.3769455, 21.73111153], [88.3777771, 21.73110962], [88.37805176, 21.73138809], [88.37999725, 21.73138809], [88.38041687, 21.73162079], [88.38095856, 21.73171043], [88.38145447, 21.73190689], [88.38198853, 21.73200035], [88.38240814, 21.73217964], [88.38288879, 21.73227501], [88.38334656, 21.73250008], [88.38382721, 21.73282814], [88.38427734, 21.73295975], [88.38461304, 21.73310089], [88.38508606, 21.73311234], [88.38523102, 21.73315048], [88.38562012, 21.73321342], [88.38651276, 21.73365974], [88.38674164, 21.73385048], [88.38718414, 21.73451614], [88.38751221, 21.73483086], [88.38771057, 21.73507118], [88.38774872, 21.73538971], [88.38801575, 21.73560524], [88.388237, 21.73587036], [88.38845825, 21.7362175], [88.38877106, 21.73656082], [88.38909912, 21.73693848], [88.38942719, 21.73731995], [88.38975525, 21.73770905], [88.39006805, 21.73808289], [88.39044952, 21.73838043], [88.39070129, 21.73868942], [88.39097595, 21.73913193], [88.3911972, 21.73958015], [88.39161682, 21.74006081], [88.3916626, 21.74073029], [88.39167023, 21.7408371], [88.39193726, 21.74134064], [88.39203644, 21.7414608], [88.391922, 21.74221039], [88.3920517, 21.74259758], [88.39219666, 21.74298096], [88.39221954, 21.74341583], [88.39221954, 21.74385071], [88.39221954, 21.74430084], [88.39222717, 21.74477005], [88.39225006, 21.74522972], [88.39228821, 21.74570084], [88.39245605, 21.74611092], [88.39250183, 21.74653053], [88.39256287, 21.74695969], [88.39274597, 21.74734116], [88.39290619, 21.74775505], [88.39308167, 21.74814415], [88.3932724, 21.74850082], [88.39334106, 21.74894142], [88.39344025, 21.74940109], [88.39363098, 21.7498703], [88.3938446, 21.75035477], [88.39393616, 21.75087166], [88.3940506, 21.75141335], [88.39389038, 21.75194359], [88.39389038, 21.75234985], [88.39389038, 21.75277519], [88.39444733, 21.75333595], [88.39444733, 21.75444031], [88.39499664, 21.75500107], [88.3951416, 21.75485992], [88.39527893, 21.7547226], [88.39585876, 21.75447464], [88.39627838, 21.75417519], [88.39672089, 21.75389099], [88.39722443, 21.75363922], [88.39779663, 21.75345993], [88.39842224, 21.75328827], [88.39898682, 21.75304985], [88.3995285, 21.75275993], [88.40000916, 21.75241661], [88.40035248, 21.75193024], [88.40062714, 21.75138092], [88.40085602, 21.75082016], [88.40104675, 21.75024033], [88.40110016, 21.74962044], [88.40106201, 21.74901009], [88.40090942, 21.74844933], [88.40084839, 21.74786949], [88.4008255, 21.7473278], [88.40075684, 21.74685097], [88.4005661, 21.74644089], [88.400383, 21.74604034], [88.40019989, 21.74561882], [88.39998627, 21.74518967], [88.39981842, 21.74477196], [88.39974213, 21.74431801], [88.39971924, 21.74388123], [88.39972687, 21.74347115], [88.39980316, 21.74310112], [88.39994812, 21.74278069], [88.40009308, 21.74241066], [88.40022278, 21.7420063], [88.40032959, 21.74154091], [88.40048218, 21.7410984], [88.40055847, 21.74067116], [88.40062714, 21.74026108], [88.40077209, 21.73991966], [88.40087891, 21.73956108], [88.40100861, 21.73925209], [88.40113831, 21.73894882], [88.40129852, 21.73867035], [88.40142059, 21.73838997], [88.40158081, 21.73812103], [88.40177155, 21.73782539], [88.40206146, 21.73752022], [88.40248108, 21.73720169], [88.40294647, 21.73685074], [88.40341187, 21.73649979], [88.40391541, 21.73625565], [88.40441895, 21.73612022], [88.40492249, 21.73603058], [88.4054184, 21.73587036], [88.40593719, 21.73580742], [88.40647125, 21.73574066], [88.40698242, 21.73558044], [88.40748596, 21.73545837], [88.40792084, 21.73521996], [88.40834045, 21.73493958], [88.40880585, 21.73464966], [88.4092865, 21.73434639], [88.40970612, 21.73398018], [88.41009521, 21.7336216], [88.41047668, 21.73329735], [88.4108429, 21.73298073], [88.41120148, 21.73265266], [88.41153717, 21.73223114], [88.41192627, 21.73176956], [88.41233826, 21.7312603], [88.41271973, 21.7306881], [88.41306305, 21.73009872], [88.41342926, 21.72954178], [88.41384888, 21.72906113], [88.41427612, 21.72859001], [88.41468811, 21.7281189], [88.41514587, 21.72770119], [88.41552734, 21.72722054], [88.41583252, 21.72670364], [88.41610718, 21.7262249], [88.41636658, 21.72579193], [88.4165802, 21.72538185], [88.41682434, 21.72503281], [88.41710663, 21.72472954], [88.41741943, 21.72443008], [88.4177475, 21.72409821], [88.4180603, 21.72365952], [88.41833496, 21.72314835], [88.41864777, 21.72257042], [88.41900635, 21.72198105], [88.41944122, 21.72142029], [88.41956329, 21.7212925], [88.41992188, 21.72092247], [88.42041016, 21.72048187], [88.42085266, 21.72002029], [88.42127991, 21.71956062], [88.42170715, 21.7191124], [88.42195129, 21.71861076], [88.42214966, 21.71813011], [88.42232513, 21.71768188], [88.42248535, 21.71722603], [88.42259216, 21.71672821], [88.42276764, 21.71623039], [88.42292023, 21.71569061], [88.42307281, 21.7151413], [88.42326355, 21.71459579], [88.42337036, 21.7140007], [88.42340851, 21.71366119], [88.42354584, 21.71137047], [88.42455292, 21.70935631], [88.42556, 21.7071991], [88.42655945, 21.7055912], [88.42713165, 21.70478058], [88.42784882, 21.70357323], [88.42856598, 21.70255852], [88.42856598, 21.70201111], [88.42832184, 21.70154953], [88.42797852, 21.7011528], [88.42758942, 21.70078087], [88.42723846, 21.70040512], [88.42691803, 21.7000103], [88.4265213, 21.69971085], [88.42613983, 21.69944572], [88.4257431, 21.69922256], [88.42527771, 21.69916534], [88.42444611, 21.69917107], [88.42415619, 21.69890022], [88.42360687, 21.69890022], [88.42333221, 21.69861031], [88.42305756, 21.69861031], [88.4227829, 21.69832993], [88.42250061, 21.69833565], [88.4223938, 21.69822502], [88.42222595, 21.69805336], [88.42193604, 21.69806099], [88.42159271, 21.69787025], [88.42115021, 21.69775009], [88.42048645, 21.69779015], [88.42022705, 21.69761086], [88.41993713, 21.69750977], [88.41979218, 21.69745827], [88.41954041, 21.69721031], [88.41816711, 21.69658279], [88.41716766, 21.69551086], [88.41487885, 21.69334984], [88.41330719, 21.69106674], [88.41282654, 21.68864059], [88.41279602, 21.6884861], [88.41274261, 21.68811035], [88.41253662, 21.68750954], [88.41239929, 21.68686104], [88.41191864, 21.68624115], [88.41183472, 21.68610573], [88.41156006, 21.68567276], [88.41152191, 21.68512917], [88.41151428, 21.68495369], [88.41151428, 21.68421936], [88.41136932, 21.68391037], [88.41136932, 21.68351936], [88.41165924, 21.68318176], [88.4118042, 21.68134689], [88.41152191, 21.68000031], [88.41179657, 21.67865944], [88.4122467, 21.67756081], [88.41238403, 21.67732239], [88.41226196, 21.67675209], [88.41233826, 21.67638969], [88.41265869, 21.67592239], [88.41261292, 21.67548943], [88.41305542, 21.67507553], [88.41308594, 21.67461014], [88.4132309, 21.67424965], [88.41331482, 21.6738987], [88.41333771, 21.67349052], [88.41338348, 21.67303276], [88.41356659, 21.67252922], [88.41365814, 21.67194939], [88.41368103, 21.67119026], [88.41323853, 21.67064095], [88.41268158, 21.66930389], [88.41225433, 21.66849518], [88.41196442, 21.66782379], [88.41182709, 21.66741943], [88.41226196, 21.66655159], [88.4121933, 21.66609383], [88.4120636, 21.66566467], [88.41195679, 21.66524124], [88.41194153, 21.6647892], [88.41192627, 21.66432953], [88.41182709, 21.66389084], [88.41174316, 21.66345978], [88.41168976, 21.66302109], [88.41166687, 21.66257095], [88.41162872, 21.66210175], [88.41150665, 21.66161728], [88.41140747, 21.66108131], [88.41131592, 21.66051292], [88.41114807, 21.66000175], [88.41110992, 21.65951538], [88.41110992, 21.65908051], [88.41116333, 21.6586628], [88.41133881, 21.6582737], [88.41137695, 21.65784073], [88.41143036, 21.65736961], [88.41161346, 21.65696144], [88.41169739, 21.65650177], [88.41186523, 21.65607452], [88.41204071, 21.65564156], [88.41203308, 21.65513802], [88.41221619, 21.65458107], [88.41240692, 21.65418053], [88.41253662, 21.65359116], [88.41279602, 21.65302086], [88.41305542, 21.65249062], [88.41333008, 21.65196991], [88.41361237, 21.65147018], [88.41387177, 21.6509819], [88.41409302, 21.6505146], [88.41424561, 21.65006065], [88.41442108, 21.6496582], [88.41454315, 21.64923096], [88.41473389, 21.64885139], [88.41498566, 21.64848518], [88.41523743, 21.6480999], [88.41555023, 21.64774895], [88.41584015, 21.64736938], [88.41616821, 21.64699554], [88.41654968, 21.64661407], [88.41692352, 21.64614868], [88.4173584, 21.64569092], [88.4178009, 21.64524078], [88.41797638, 21.64488029], [88.41822052, 21.64437103], [88.41842651, 21.64405823], [88.41882324, 21.64380264], [88.41934204, 21.64354324], [88.41999817, 21.64315987], [88.42069244, 21.64278412], [88.42095184, 21.64249992], [88.42121887, 21.64223099], [88.42151642, 21.64198112], [88.42191315, 21.64176941], [88.42228699, 21.64146042], [88.42272186, 21.64117241], [88.42307281, 21.64084053], [88.42339325, 21.64056778], [88.42368317, 21.64034081], [88.42397308, 21.64017868], [88.42421722, 21.63996124], [88.42450714, 21.63972282], [88.42482758, 21.63943863], [88.42518616, 21.63913536], [88.42552948, 21.63877106], [88.42582703, 21.63834572], [88.42610931, 21.63788986], [88.4263916, 21.63742065], [88.42666626, 21.63695145], [88.42693329, 21.63648987], [88.42722321, 21.63603973], [88.42755127, 21.63563919], [88.42790222, 21.63528824], [88.42822266, 21.63498116], [88.42843628, 21.63463974], [88.42867279, 21.63438034], [88.42887878, 21.63414001], [88.429039, 21.63388062], [88.42917633, 21.63362122], [88.42935181, 21.63339996], [88.42945099, 21.63311005], [88.42954254, 21.6328373], [88.42967224, 21.63260078], [88.42974854, 21.6323185], [88.42988586, 21.63203049], [88.43001556, 21.63170815], [88.43016815, 21.63133812], [88.43031311, 21.63090134], [88.43056488, 21.63049316], [88.43086243, 21.63007927], [88.43119049, 21.62965965], [88.43154907, 21.62924957], [88.43179321, 21.62875938], [88.43192291, 21.62827682], [88.4319458, 21.62780952], [88.43193817, 21.62735939], [88.43187714, 21.62692833], [88.43174744, 21.62656975], [88.4311142, 21.62555504], [88.43110657, 21.62528038], [88.43083191, 21.62500191], [88.43055725, 21.6241684], [88.43055725, 21.62388992], [88.43026733, 21.62361908], [88.43026733, 21.62333107], [88.42973328, 21.62278938], [88.4291687, 21.6222229], [88.4291687, 21.62194443], [88.42888641, 21.62166786], [88.42861176, 21.62166977], [88.42804718, 21.62111092], [88.42722321, 21.62111092], [88.42693329, 21.62083054], [88.42666626, 21.62083244], [88.42610931, 21.6202755], [88.42582703, 21.62028122], [88.42555237, 21.62000084], [88.42527771, 21.62000084], [88.42472076, 21.61944008], [88.42444611, 21.61944008], [88.42388916, 21.62000084], [88.42360687, 21.62000084], [88.42333221, 21.62028122], [88.42305756, 21.62028122], [88.42222595, 21.61944008], [88.42138672, 21.6194458], [88.42111206, 21.61972237], [88.42028046, 21.61972046], [88.41999817, 21.62000084], [88.41889191, 21.62000084], [88.41860962, 21.61972046], [88.41833496, 21.61972237], [88.4180603, 21.62000084], [88.41777802, 21.62000084], [88.41750336, 21.61972046], [88.41666412, 21.61972237], [88.41638947, 21.6194458], [88.41610718, 21.61972046], [88.41610718, 21.62000084], [88.41583252, 21.6202755], [88.41583252, 21.62055779], [88.41555786, 21.62083244], [88.41499329, 21.62083054], [88.41471863, 21.62111092], [88.41443634, 21.62111092], [88.41416931, 21.62138939], [88.41416931, 21.62249947], [88.41388702, 21.62249947], [88.41361237, 21.62277985], [88.41333008, 21.62277985], [88.41305542, 21.62250137], [88.41278076, 21.62222099], [88.41278076, 21.62055779], [88.41166687, 21.6194458], [88.41139221, 21.6194458], [88.41110992, 21.61916733], [88.41055298, 21.61917114], [88.41027832, 21.61889076], [88.40999603, 21.61889076], [88.40777588, 21.61667061], [88.40777588, 21.61639023], [88.40750122, 21.61610985], [88.40750122, 21.61583138], [88.40721893, 21.61555481], [88.40721893, 21.61444473], [88.40805817, 21.61361122], [88.40833282, 21.61361122], [88.40860748, 21.61333275], [88.40860748, 21.61322594], [88.40836334, 21.61297035], [88.40810394, 21.61271286], [88.40789032, 21.61240959], [88.40773773, 21.61202049], [88.40777588, 21.6119442], [88.40750122, 21.61166573], [88.40750122, 21.61138916], [88.40721893, 21.61111069], [88.40721893, 21.6108284], [88.40694427, 21.61055565], [88.40693665, 21.60972023], [88.40721893, 21.60944366], [88.40721893, 21.60888863], [88.40693665, 21.60861015], [88.40666962, 21.60861206], [88.40638733, 21.60833359], [88.40555573, 21.60833359], [88.40555573, 21.6072216], [88.40611267, 21.60666466], [88.4061203, 21.60610962], [88.40555573, 21.60555649], [88.40555573, 21.60444641], [88.40583038, 21.60416412], [88.40583038, 21.60388947], [88.4061203, 21.60361099], [88.40611267, 21.60333252], [88.40638733, 21.60305405], [88.40638733, 21.60222054], [88.40648651, 21.60212326], [88.40666962, 21.60194206], [88.40666962, 21.60138893], [88.40692902, 21.60110092], [88.40701294, 21.60087013], [88.40718842, 21.60069084], [88.40740204, 21.60046768], [88.40751648, 21.60001945], [88.40748596, 21.59951401], [88.40721893, 21.59916687], [88.40638733, 21.59833145], [88.40583038, 21.59833336], [88.40496063, 21.59745979], [88.40472412, 21.59722137], [88.40444183, 21.59722137], [88.40361023, 21.59805489], [88.40333557, 21.59805489], [88.40309143, 21.59782028], [88.40305328, 21.59749985], [88.40277863, 21.59721756], [88.40277863, 21.59694481], [88.40194702, 21.5961113], [88.40194702, 21.59555626], [88.40055847, 21.59555626], [88.40027618, 21.59583282], [88.39916992, 21.59583282], [88.39888763, 21.59555626], [88.39861298, 21.59555626], [88.39833069, 21.59583092], [88.39826965, 21.59589005], [88.3980484, 21.59609795], [88.39782715, 21.59638023], [88.39774323, 21.59679031], [88.39758301, 21.59717178], [88.39750671, 21.59757614], [88.39749908, 21.59804916], [88.39749908, 21.59916687], [88.39694214, 21.59972191], [88.39694214, 21.60000038], [88.39499664, 21.60194206], [88.39499664, 21.60222244], [88.39389038, 21.60222244], [88.39277649, 21.60333061], [88.39277649, 21.60361099], [88.39250183, 21.60388947], [88.39250183, 21.60472107], [88.39221954, 21.60499954], [88.39221954, 21.60639], [88.39193726, 21.60667038], [88.39194489, 21.60694695], [88.39167023, 21.6072216], [88.39027405, 21.6072216], [88.38916779, 21.60832024], [88.38916779, 21.60888863], [88.38819122, 21.60994148], [88.38774872, 21.61041451], [88.38736725, 21.61148071], [88.38745117, 21.61190987], [88.38736725, 21.61235046], [88.38725281, 21.61283112], [88.38726044, 21.61334801], [88.38743591, 21.61375046], [88.38768005, 21.61404991], [88.3878479, 21.61446953], [88.38800812, 21.61495972], [88.38804626, 21.61548996], [88.38807678, 21.61593819], [88.38825226, 21.61628914], [88.38848877, 21.61658478], [88.38864899, 21.61693954], [88.3888855, 21.61727905], [88.38916016, 21.61766052], [88.38916779, 21.61778069], [88.38999939, 21.61861038], [88.38999939, 21.61889076], [88.39027405, 21.61916733], [88.39027405, 21.61991119], [88.39027405, 21.62055779], [88.39055634, 21.62083244], [88.39055634, 21.62194061], [88.38999939, 21.62249947], [88.38999939, 21.62277985], [88.38972473, 21.62305641], [88.3897171, 21.62333107], [88.38944244, 21.62361908], [88.38944244, 21.62416649], [88.3888855, 21.62472153], [88.3888855, 21.62500191], [88.38805389, 21.62583351], [88.38777924, 21.6258316], [88.38722229, 21.62639046], [88.38667297, 21.62639046], [88.38639069, 21.62668037], [88.38608551, 21.62666893], [88.38576508, 21.6267643], [88.38557434, 21.62689018], [88.38545227, 21.62697029], [88.38510895, 21.62724113], [88.38474274, 21.62759972], [88.38444519, 21.62808228], [88.38417816, 21.62860107], [88.38394165, 21.62909126], [88.38368225, 21.62945938], [88.38348389, 21.62979317], [88.38339233, 21.63027954], [88.3833313, 21.63104439], [88.38331604, 21.63150978], [88.38331604, 21.6319809], [88.38342285, 21.63258743], [88.38358307, 21.63303185], [88.38361359, 21.63348961], [88.38360596, 21.63393974], [88.38359833, 21.63436127], [88.38350677, 21.63472748], [88.38339233, 21.6350708], [88.38337708, 21.63555908], [88.38343811, 21.63624001], [88.38367462, 21.63691902], [88.38405609, 21.63739014], [88.38440704, 21.63777924], [88.38468933, 21.63813972], [88.38490295, 21.63856125], [88.38498688, 21.63912964], [88.3850174, 21.6397953], [88.38512421, 21.64051628], [88.38529968, 21.64113998], [88.38555145, 21.64175034], [88.38581848, 21.64232063], [88.3860321, 21.64284706], [88.3861618, 21.6433506], [88.38637543, 21.64376831], [88.38654327, 21.64420128], [88.3866806, 21.64468765], [88.38683319, 21.64518166], [88.38696289, 21.64568138], [88.38713074, 21.64613152], [88.3871994, 21.6465416], [88.38777924, 21.64694023], [88.38722229, 21.64750099], [88.38722229, 21.64916611], [88.38694763, 21.64944458], [88.38694763, 21.64972305], [88.38667297, 21.64999962], [88.38666534, 21.65055466], [88.38646698, 21.65081215], [88.3862381, 21.65109062], [88.38595581, 21.65133095], [88.38581085, 21.65164185], [88.38562012, 21.65191269], [88.38547516, 21.65229607], [88.38531494, 21.6527729], [88.38527679, 21.65336037], [88.38529968, 21.65398979], [88.38536835, 21.65459061], [88.38526154, 21.65513039], [88.38507843, 21.65559959], [88.38491821, 21.65603256], [88.38469696, 21.65639114], [88.38448334, 21.65674019], [88.38426208, 21.65713501], [88.38404846, 21.65757942], [88.38379669, 21.65802765], [88.38349915, 21.65841103], [88.38313293, 21.65872192], [88.38285828, 21.65908051], [88.38259888, 21.65944099], [88.38233185, 21.65979004], [88.3821106, 21.6602211], [88.38187408, 21.66057777], [88.38166046, 21.66096115], [88.3814621, 21.66131973], [88.38127899, 21.66167641], [88.38114166, 21.66208076], [88.3811264, 21.66258812], [88.38121796, 21.66315269], [88.38140869, 21.66373062], [88.38166046, 21.66427994], [88.38195038, 21.66443825], [88.38194275, 21.66527748], [88.38208008, 21.66541672], [88.38277435, 21.66610909], [88.38208771, 21.66703415], [88.38195038, 21.66722107]]], [[[89.05430603, 21.61780357], [89.05337524, 21.61793709], [89.05309296, 21.61834145], [89.05258942, 21.61834145], [89.05208588, 21.61793709], [89.05194855, 21.61780357], [89.05187225, 21.61753464], [89.05158997, 21.61753082], [89.05143738, 21.61774063], [89.05130768, 21.61774063], [89.05108643, 21.61814117], [89.05094147, 21.61833954], [89.05072784, 21.61848068], [89.05045319, 21.61868095], [89.05016327, 21.61888123], [89.04979706, 21.61921692], [89.04972839, 21.61955261], [89.04950714, 21.61989021], [89.04943848, 21.62022591], [89.04892731, 21.62055016], [89.04836273, 21.62089539], [89.04794312, 21.62123108], [89.04750824, 21.62157059], [89.04707336, 21.62217522], [89.04664612, 21.62243843], [89.04638672, 21.62276077], [89.04541779, 21.62333107], [89.04431915, 21.62436104], [89.04411316, 21.62463951], [89.04396057, 21.62483025], [89.04353333, 21.6252346], [89.0433197, 21.62543106], [89.04316711, 21.62564278], [89.0426712, 21.62610817], [89.04238892, 21.62643814], [89.04217529, 21.62664795], [89.04189301, 21.62697983], [89.04123688, 21.62738991], [89.04102325, 21.62759018], [89.0406723, 21.62778854], [89.0402298, 21.6281929], [89.03987885, 21.62859535], [89.03952026, 21.62892914], [89.03923798, 21.62927055], [89.03887939, 21.6296711], [89.03866577, 21.62986946], [89.03837585, 21.63020897], [89.03830719, 21.63034058], [89.0382309, 21.63047981], [89.03805542, 21.6305542], [89.03778076, 21.63083267], [89.03749847, 21.63083076], [89.03694153, 21.63138962], [89.03666687, 21.63138962], [89.03639221, 21.63167], [89.03610992, 21.63166428], [89.03555298, 21.63222313], [89.03504944, 21.6328907], [89.03475952, 21.63310051], [89.03469086, 21.63330269], [89.03447723, 21.63357162], [89.03418732, 21.6341095], [89.03418732, 21.63471031], [89.03425598, 21.63517952], [89.03440094, 21.63552284], [89.03469086, 21.63605499], [89.03497314, 21.63631821], [89.0351181, 21.63672638], [89.03526306, 21.63706017], [89.03547668, 21.63754082], [89.03590393, 21.63820648], [89.03626251, 21.63874054], [89.03655243, 21.63921547], [89.03705597, 21.63974953], [89.03740692, 21.6398201], [89.03769684, 21.64009094], [89.03769684, 21.64029121], [89.03762817, 21.64056015], [89.03733826, 21.64069939], [89.03697968, 21.64056015], [89.03647614, 21.64022064], [89.03604889, 21.63988876], [89.03569031, 21.63941956], [89.03518677, 21.63894844], [89.03504944, 21.63853836], [89.03475952, 21.6380043], [89.0345459, 21.63766861], [89.03425598, 21.63726997], [89.03404236, 21.63680077], [89.03391266, 21.63659096], [89.03382874, 21.63618851], [89.03368378, 21.63605499], [89.03362274, 21.63558006], [89.03347015, 21.63518143], [89.03333282, 21.63471031], [89.03318787, 21.63451004], [89.03296661, 21.63425064], [89.03275299, 21.63397026], [89.03253937, 21.63375092], [89.03090668, 21.63380051], [89.02999878, 21.63417053], [89.02979279, 21.63430023], [89.02944183, 21.63445091], [89.0289917, 21.63478088], [89.02884674, 21.63504982], [89.02848816, 21.63531876], [89.02841949, 21.63565254], [89.02841949, 21.63699722], [89.02855682, 21.63713074], [89.02856445, 21.6375351], [89.02863312, 21.63772964], [89.02848816, 21.63801003], [89.02848816, 21.63874817], [89.02841949, 21.63908386], [89.02820587, 21.63948631], [89.02806091, 21.63982582], [89.02798462, 21.64009476], [89.02797699, 21.64035034], [89.02791595, 21.64076614], [89.02755737, 21.64110184], [89.02741241, 21.64143753], [89.02726746, 21.64176941], [89.02713776, 21.64217949], [89.0269165, 21.64258003], [89.02662659, 21.64285088], [89.02648163, 21.64332008], [89.02612305, 21.64365959], [89.02605438, 21.64392662], [89.02619934, 21.64500237], [89.02648163, 21.64526939], [89.02677155, 21.64574051], [89.02705383, 21.64634705], [89.02707672, 21.64672089], [89.0273056, 21.64798737], [89.02735138, 21.64818954], [89.02749634, 21.64888954], [89.02777863, 21.64944077], [89.02784729, 21.64979935], [89.02805328, 21.65027809], [89.02862549, 21.65062332], [89.02868652, 21.6511097], [89.02861023, 21.65166664], [89.02805328, 21.65333176], [89.02778625, 21.65389061], [89.02749634, 21.6541996], [89.0275116, 21.65457916], [89.02722168, 21.65472221], [89.02694702, 21.65506172], [89.02639008, 21.65611076], [89.02610779, 21.65638924], [89.02610779, 21.65694237], [89.02619171, 21.65742493], [89.02640533, 21.65813255], [89.02719879, 21.65854454], [89.02806091, 21.65848541], [89.02913666, 21.65815926], [89.02966309, 21.65776062], [89.03015137, 21.65721321], [89.0307312, 21.65671158], [89.03131866, 21.65617943], [89.03151703, 21.6558094], [89.03188324, 21.65519333], [89.03240204, 21.6547451], [89.03273773, 21.65452957], [89.03304291, 21.65467453], [89.03283691, 21.65528107], [89.03244781, 21.65579414], [89.03208923, 21.65620995], [89.03160858, 21.65687943], [89.03108215, 21.65729523], [89.03044891, 21.6578083], [89.03000641, 21.65823174], [89.0296936, 21.65852547], [89.02908325, 21.65896988], [89.02806091, 21.65937614], [89.02725983, 21.65945816], [89.02571106, 21.6595974], [89.02542877, 21.65965462], [89.02500916, 21.65991974], [89.02459717, 21.66047859], [89.02424622, 21.6606102], [89.0238266, 21.66075516], [89.02348328, 21.66082001], [89.022995, 21.66096687], [89.02235413, 21.66104317], [89.02166748, 21.66110992], [89.02126312, 21.66167068], [89.02111053, 21.66194916], [89.02090454, 21.66235733], [89.02089691, 21.66290092], [89.02106476, 21.66325951], [89.02160645, 21.66374969], [89.02175903, 21.66396523], [89.02196503, 21.66451263], [89.02189636, 21.66535187], [89.02194977, 21.66589928], [89.02217102, 21.66651917], [89.02236176, 21.6668129], [89.02258301, 21.66708946], [89.022995, 21.66750908], [89.0230484, 21.66785049], [89.02341461, 21.66819954], [89.02340698, 21.66854286], [89.02368927, 21.66888809], [89.02376556, 21.66965485], [89.02390289, 21.67074013], [89.02375793, 21.67187691], [89.02368927, 21.67268944], [89.02362061, 21.67362976], [89.02355957, 21.67424011], [89.02348328, 21.6747303], [89.02355194, 21.67534447], [89.02362061, 21.67604065], [89.02368164, 21.67638969], [89.02390289, 21.67715073], [89.02388763, 21.67749977], [89.02403259, 21.68001747], [89.02416992, 21.68083191], [89.02430725, 21.68097687], [89.02437592, 21.68132019], [89.02458954, 21.68187714], [89.02471924, 21.68222237], [89.02500916, 21.6826458], [89.02527618, 21.68333244], [89.02548981, 21.68354034], [89.02555847, 21.68388939], [89.02583313, 21.68443108], [89.02604675, 21.68507957], [89.02610779, 21.6855545], [89.02619171, 21.68610191], [89.02633667, 21.68743324], [89.02641296, 21.68791008], [89.02632904, 21.68847084], [89.02597809, 21.68908119], [89.02575684, 21.69000053], [89.0256958, 21.69034767], [89.02555847, 21.69055557], [89.02548981, 21.69110107], [89.02506256, 21.69236565], [89.02500153, 21.6927681], [89.02500153, 21.69361115], [89.02472687, 21.69486046], [89.02452087, 21.69514275], [89.02410126, 21.69624519], [89.02396393, 21.69652367], [89.02355194, 21.69742393], [89.02348328, 21.6977005], [89.02320862, 21.69819069], [89.02313232, 21.69868088], [89.02285767, 21.69896126], [89.02200317, 21.70038033], [89.01999664, 21.70166779], [89.01979065, 21.70173454], [89.01944733, 21.70194054], [89.01895905, 21.70207977], [89.01860809, 21.70222092], [89.01832581, 21.70228958], [89.01805878, 21.70249939], [89.0174408, 21.70283508], [89.01694489, 21.70284462], [89.01625061, 21.70290947], [89.01583099, 21.70305824], [89.01438904, 21.70325851], [89.01361084, 21.7033329], [89.01311493, 21.70325851], [89.01212311, 21.70330429], [89.01174927, 21.70332527], [89.0111084, 21.70332909], [89.01062775, 21.70346642], [89.01027679, 21.70361137], [89.01000214, 21.70374107], [89.00979614, 21.70487022], [89.00995636, 21.7052784], [89.01016235, 21.70589066], [89.01051331, 21.7064476], [89.01036835, 21.70705986], [89.01049805, 21.70754051], [89.01076508, 21.70791245], [89.01154327, 21.70776939], [89.01194763, 21.70792961], [89.01222229, 21.70833206], [89.01259613, 21.70852661], [89.01277924, 21.70862007], [89.0135498, 21.70862007], [89.01390076, 21.70833969], [89.01499939, 21.70827484], [89.01555634, 21.7080555], [89.01750183, 21.70806122], [89.01848602, 21.70820808], [89.01917267, 21.70854378], [89.01951599, 21.70874977], [89.01998901, 21.70889282], [89.0203476, 21.70910072], [89.02098846, 21.70923233], [89.02201843, 21.71008682], [89.02237701, 21.71063232], [89.02250671, 21.7110405], [89.02265167, 21.71159935], [89.02300262, 21.71275139], [89.02292633, 21.71403122], [89.02229309, 21.71484947], [89.0222168, 21.71528053], [89.02289581, 21.7161293], [89.02360535, 21.71653175], [89.02409363, 21.71674347], [89.02444458, 21.7166748], [89.02471924, 21.71666718], [89.02555847, 21.71666908], [89.02590179, 21.71687889], [89.02612305, 21.71693993], [89.02667236, 21.71708679], [89.02722168, 21.7172184], [89.02755737, 21.71730232], [89.02805328, 21.71736526], [89.02861786, 21.71744156], [89.02999878, 21.71777916], [89.03028107, 21.71805954], [89.03083038, 21.71805573], [89.03111267, 21.7183342], [89.03138733, 21.71832848], [89.03166962, 21.71861076], [89.03221893, 21.71861076], [89.03277588, 21.71916962], [89.03305817, 21.7191658], [89.0331955, 21.71930504], [89.03333282, 21.71944427], [89.03360748, 21.71944427], [89.03388977, 21.71972275], [89.03444672, 21.71970749], [89.03472137, 21.72000122], [89.0358429, 21.72000122], [89.03610992, 21.72027969], [89.03694153, 21.72027969], [89.03721619, 21.72056007], [89.03861237, 21.72055626], [89.03879547, 21.72074127], [89.03888702, 21.72083282], [89.03916931, 21.72055626], [89.03971863, 21.72055626], [89.04000092, 21.72083282], [89.04083252, 21.72083282], [89.04135895, 21.72085953], [89.04279327, 21.72085953], [89.0431366, 21.7209301], [89.0435791, 21.72113037], [89.04371643, 21.72113037], [89.04415131, 21.72119713], [89.04437256, 21.72126007], [89.04450989, 21.72133064], [89.04486847, 21.72146606], [89.04515839, 21.72153282], [89.04544067, 21.72159958], [89.04593658, 21.72167015], [89.04715729, 21.72167015], [89.04773712, 21.72174072], [89.04830933, 21.72174072], [89.04973602, 21.72159958], [89.05002594, 21.72159958], [89.05045319, 21.72174072], [89.05088806, 21.72187042], [89.0513382, 21.72186852], [89.05483246, 21.72187042], [89.05548096, 21.72180176], [89.056633, 21.72180176], [89.05699158, 21.72187042], [89.05741119, 21.72187042], [89.05848694, 21.7220726], [89.05885315, 21.7220726], [89.05905914, 21.72200394], [89.0592041, 21.72180367], [89.05941772, 21.72173309], [89.05978394, 21.7218132], [89.05983734, 21.7219429], [89.06041718, 21.7219429], [89.06070709, 21.72174072], [89.06092072, 21.72146988], [89.06112671, 21.7210598], [89.06099701, 21.72043991], [89.06128693, 21.7201004], [89.06164551, 21.71990204], [89.06193542, 21.71949959], [89.06214905, 21.71923065], [89.06223297, 21.71883011], [89.06228638, 21.71856117], [89.06236267, 21.71821976], [89.06250763, 21.71788406], [89.06278992, 21.71734619], [89.06299591, 21.7171402], [89.06321716, 21.71707726], [89.06343842, 21.71693993], [89.0637207, 21.7166748], [89.06401062, 21.7163372], [89.06414795, 21.7159996], [89.06443787, 21.71566582], [89.06450653, 21.71545982], [89.06465149, 21.71526146], [89.06494141, 21.71506119], [89.06522369, 21.71452332], [89.06522369, 21.71391678], [89.06529999, 21.71351051], [89.06536865, 21.71317673], [89.06536865, 21.71257019], [89.06543732, 21.71236992], [89.06550598, 21.71210098], [89.06558228, 21.71162987], [89.06565857, 21.71122742], [89.0657959, 21.71103287], [89.0657959, 21.71068192], [89.06594086, 21.71035576], [89.06594086, 21.70994949], [89.06608582, 21.70955086], [89.06623077, 21.70920753], [89.06643677, 21.70874023], [89.06665802, 21.70833969], [89.06681824, 21.7080822], [89.0668869, 21.70801353], [89.06715393, 21.7077446], [89.06729889, 21.70759583], [89.06758881, 21.70740128], [89.06777954, 21.70722008], [89.0680542, 21.70694351], [89.06821442, 21.7063942], [89.06829071, 21.70625877], [89.06829071, 21.70578957], [89.0684967, 21.70539093], [89.06871796, 21.70518112], [89.0687561, 21.70510101], [89.06886292, 21.70484734], [89.06893158, 21.7047081], [89.0691452, 21.70451164], [89.06929016, 21.70424271], [89.06958008, 21.70390511], [89.06965637, 21.70363998], [89.06971741, 21.70343018], [89.06986237, 21.70330048], [89.07015228, 21.7027607], [89.07028961, 21.70229149], [89.07036591, 21.70202255], [89.07057953, 21.70175362], [89.07057953, 21.70108223], [89.07064819, 21.70094681], [89.07064819, 21.69973946], [89.07071686, 21.69953918], [89.07071686, 21.69779015], [89.07079315, 21.69745064], [89.07086182, 21.69725037], [89.07086182, 21.69663811], [89.07079315, 21.69637489], [89.07064819, 21.69597054], [89.07057953, 21.69582939], [89.07051086, 21.69563484], [89.07022095, 21.69529915], [89.06954956, 21.69485283], [89.0694046, 21.69451714], [89.06925964, 21.69417953], [89.06925964, 21.69296837], [89.06921387, 21.69284248], [89.06912231, 21.69256592], [89.06890106, 21.69215965], [89.06861877, 21.69169235], [89.06840515, 21.69128609], [89.06826019, 21.69108963], [89.06826019, 21.69087982], [89.06811523, 21.69061661], [89.06797028, 21.69041061], [89.06768799, 21.69014549], [89.06739807, 21.68988037], [89.06726074, 21.68974113], [89.06690216, 21.68967247], [89.06604004, 21.68967247], [89.06568146, 21.68974113], [89.06546783, 21.68981171], [89.06510925, 21.69028091], [89.06496429, 21.69034767], [89.064888, 21.69035912], [89.06453705, 21.69041443], [89.06453705, 21.69021225], [89.06460571, 21.69001007], [89.06475067, 21.68974113], [89.06481934, 21.68954277], [89.06490326, 21.68941116], [89.06490326, 21.68927002], [89.06504059, 21.6890049], [89.06517792, 21.68886757], [89.06532288, 21.68873024], [89.06546783, 21.68866539], [89.06768799, 21.68867111], [89.06783295, 21.68860054], [89.06826019, 21.68847084], [89.06861877, 21.68840027], [89.06897736, 21.68840027], [89.06919098, 21.6883297], [89.06939697, 21.6883297], [89.06961823, 21.68840027], [89.06990814, 21.68860054], [89.07026672, 21.68880081], [89.07048035, 21.6890049], [89.07063293, 21.68919945], [89.07112122, 21.68940544], [89.07141113, 21.68967438], [89.07206726, 21.68989372], [89.07265472, 21.6897316], [89.07333374, 21.68916893], [89.07389069, 21.68861008], [89.07402039, 21.68861198], [89.07430267, 21.68833351], [89.07444763, 21.68805695], [89.07485962, 21.6875], [89.07499695, 21.68721962], [89.07540894, 21.68659973], [89.07554626, 21.68638992], [89.07583618, 21.68610954], [89.07597351, 21.68583488], [89.07805634, 21.68361092], [89.07833099, 21.6834774], [89.07936096, 21.68215942], [89.07956696, 21.68194962], [89.07985687, 21.68146324], [89.08082581, 21.68083191], [89.08110809, 21.68083382], [89.08153534, 21.68082428], [89.08189392, 21.68054581], [89.08195496, 21.68020248], [89.08181, 21.67965508], [89.08172607, 21.67951965], [89.08185577, 21.67891121], [89.08235931, 21.67870331], [89.0828476, 21.67896271], [89.08312988, 21.67937088], [89.0836792, 21.67949104], [89.08390045, 21.67887115], [89.08338928, 21.6782608], [89.0830307, 21.67798042], [89.08303833, 21.67752266], [89.08338165, 21.67742729], [89.08403015, 21.67802238], [89.08441162, 21.67792702], [89.08489227, 21.67782784], [89.0851059, 21.67725945], [89.08506012, 21.67683983], [89.08480072, 21.67637062], [89.08499908, 21.67572021], [89.08570099, 21.67465019], [89.08608246, 21.67416], [89.08617401, 21.67403221], [89.08644867, 21.6738224], [89.08666992, 21.67361069], [89.08679962, 21.67333031], [89.08694458, 21.67305756], [89.08701324, 21.67284966], [89.08693695, 21.6722908], [89.08693695, 21.67193985], [89.08694458, 21.67138863], [89.08809662, 21.67023087], [89.08824921, 21.67003059], [89.08838654, 21.66962051], [89.08875275, 21.66922188], [89.08889771, 21.66908646], [89.08924866, 21.66868019], [89.08939362, 21.66854858], [89.0896759, 21.66842079], [89.08996582, 21.66814995], [89.09011078, 21.66794014], [89.09017944, 21.66774178], [89.09053802, 21.66740608], [89.09053802, 21.66727066], [89.09068298, 21.66706848], [89.0909729, 21.66699982], [89.09111023, 21.66700172], [89.0915451, 21.66693497], [89.09175873, 21.66679955], [89.09189606, 21.66667175], [89.09197235, 21.66653252], [89.09204865, 21.66633034], [89.09211731, 21.66605949], [89.09233093, 21.66572571], [89.09233093, 21.6649189], [89.09226227, 21.66472054], [89.09211731, 21.6644516], [89.09218597, 21.66418266], [89.09233093, 21.66411018], [89.09247589, 21.66398048], [89.09262085, 21.66377068], [89.09268951, 21.66357231], [89.09262085, 21.66337013], [89.09254456, 21.66303444], [89.09247589, 21.66283226], [89.09233093, 21.66263199], [89.0923996, 21.66229439], [89.09254456, 21.66222954], [89.09275818, 21.66208839], [89.09283447, 21.6619606], [89.09297943, 21.66142273], [89.09290314, 21.66094971], [89.09275818, 21.66074944], [89.09275818, 21.6603508], [89.09290314, 21.66007805], [89.0930481, 21.66000938], [89.09333038, 21.65971947], [89.09377289, 21.65897369], [89.09377289, 21.65870476], [89.09370422, 21.65829849], [89.09355927, 21.6579628], [89.09342194, 21.65769577], [89.09342194, 21.65715981], [89.09364319, 21.65702057], [89.09377289, 21.65695572], [89.09391785, 21.65688705], [89.09420776, 21.65654945], [89.09435272, 21.65568161], [89.09420776, 21.65534019], [89.09413147, 21.65500641], [89.09435272, 21.65454102], [89.09468842, 21.6541996], [89.09477997, 21.65406036], [89.09492493, 21.65366173], [89.09492493, 21.65312386], [89.09484863, 21.65298843], [89.09468842, 21.65265274], [89.09470367, 21.65218163], [89.09484863, 21.65198135], [89.09492493, 21.65184784], [89.09497833, 21.65130806], [89.09506226, 21.65103912], [89.09513855, 21.65063095], [89.09513855, 21.64969635], [89.09518433, 21.64887238], [89.09518433, 21.64658546], [89.09510803, 21.64619064], [89.09510803, 21.64565086], [89.09503937, 21.64511108], [89.09503937, 21.64396095], [89.09489441, 21.6434269], [89.09482574, 21.64302254], [89.09468079, 21.64221573], [89.09468079, 21.64195061], [89.09453583, 21.64147949], [89.09440613, 21.64113998], [89.09425354, 21.64073563], [89.09411621, 21.64039993], [89.09396362, 21.64012909], [89.09375, 21.63966179], [89.09361267, 21.63945961], [89.09353638, 21.63920021], [89.09332275, 21.63871956], [89.09329224, 21.63841248], [89.09314728, 21.63773918], [89.09300995, 21.63726616], [89.09285736, 21.63693047], [89.09250641, 21.63652992], [89.09221649, 21.63619232], [89.0919342, 21.63592339], [89.09150696, 21.63585663], [89.09121704, 21.63565254], [89.09107208, 21.63538551], [89.09085846, 21.63504982], [89.09063721, 21.63465118], [89.09063721, 21.63438034], [89.09070587, 21.63417816], [89.09063721, 21.63390923], [89.09043121, 21.63376808], [89.09007263, 21.63357162], [89.08985901, 21.63349915], [89.08956909, 21.63336945], [89.0894165, 21.63323021], [89.0887146, 21.63310051], [89.08856964, 21.63297081], [89.08827972, 21.63262939], [89.08792114, 21.63223076], [89.08757019, 21.63182068], [89.08728027, 21.63162041], [89.08699036, 21.63134956], [89.08663177, 21.63108253], [89.08649445, 21.63094711], [89.0861969, 21.63068008], [89.08584595, 21.63041115], [89.0854187, 21.63021088], [89.08512878, 21.6301403], [89.08455658, 21.6300106], [89.08393097, 21.6300106], [89.08355713, 21.63027954], [89.08326721, 21.63094711], [89.08312225, 21.6312809], [89.08319855, 21.63148499], [89.08348083, 21.63175392], [89.08377075, 21.63209152], [89.08393097, 21.63228989], [89.08397675, 21.63262939], [89.084198, 21.63290024], [89.08455658, 21.63310051], [89.08470154, 21.63317108], [89.08492279, 21.63344193], [89.08506012, 21.63371277], [89.0849762, 21.63384056], [89.08463287, 21.63384056], [89.08398438, 21.63397408], [89.08383942, 21.63397408], [89.08312225, 21.6337719], [89.0827713, 21.63350105], [89.08269501, 21.63323212], [89.08255005, 21.63303375], [89.08241272, 21.63262939], [89.08226776, 21.63228989], [89.08226776, 21.63202286], [89.08219147, 21.63188934], [89.0821228, 21.63168907], [89.08197784, 21.63141823], [89.08170319, 21.63114929], [89.0815506, 21.63095284], [89.0815506, 21.63054276], [89.08161926, 21.63034248], [89.08183289, 21.63020897], [89.08190918, 21.6301403], [89.08190918, 21.6300106], [89.08197784, 21.62953949], [89.08197784, 21.62820053], [89.08221436, 21.62816811], [89.08220673, 21.6278801], [89.08196259, 21.62786484], [89.08193207, 21.62759018], [89.08168793, 21.6275959], [89.08168793, 21.62736702], [89.08075714, 21.62734032], [89.08055115, 21.62709999], [89.08040619, 21.62683105], [89.07997131, 21.62648964], [89.07975769, 21.62635612], [89.07939911, 21.6262207], [89.0788269, 21.62608719], [89.07875061, 21.6260376], [89.07839966, 21.62581825], [89.07804108, 21.62548065], [89.07775879, 21.62521362], [89.0776825, 21.62501335], [89.07746887, 21.62494469], [89.07725525, 21.62474442], [89.076828, 21.62474442], [89.07624817, 21.62460899], [89.07602692, 21.62454033], [89.07567596, 21.62447548], [89.07524872, 21.62413788], [89.07502747, 21.62400055], [89.07474518, 21.62386894], [89.07453156, 21.62387085], [89.07424927, 21.62372971], [89.07381439, 21.6235981], [89.0735321, 21.62339973], [89.07331848, 21.62339973], [89.07280731, 21.62333107], [89.07253265, 21.6232605], [89.07224274, 21.62306213], [89.07202911, 21.62265778], [89.07195282, 21.62252045], [89.07152557, 21.62225533], [89.07138824, 21.62222099], [89.07090759, 21.62228966], [89.06970215, 21.62215042], [89.06920624, 21.62228012], [89.06892395, 21.62220573], [89.06867218, 21.62105942], [89.06835938, 21.62061119], [89.06797028, 21.62037086], [89.06680298, 21.62014008], [89.06607819, 21.62013054], [89.06500244, 21.62020111], [89.06450653, 21.62013054], [89.06401825, 21.61965942], [89.06326294, 21.61880112], [89.06261444, 21.61854362], [89.06233215, 21.61841011], [89.06196594, 21.61833954], [89.0615387, 21.61827469], [89.06104279, 21.61814117], [89.06060791, 21.6180706], [89.060112, 21.6180706], [89.05944824, 21.61814117], [89.05924988, 21.61847687], [89.05903625, 21.61854362], [89.05853271, 21.61841011], [89.05844879, 21.61834526], [89.05817413, 21.61814117], [89.05774689, 21.61787033], [89.05745697, 21.61780357], [89.05702972, 21.61773872], [89.05638885, 21.61766815], [89.05545044, 21.61753082], [89.05459595, 21.6176033], [89.05430603, 21.61780357]]], [[[88.69712067, 21.71287918], [88.69734192, 21.71264076], [88.69750214, 21.71228027], [88.69766998, 21.71192169], [88.69777679, 21.71157265], [88.69792175, 21.71125031], [88.69802856, 21.71093941], [88.69805145, 21.71060944], [88.69806671, 21.71027946], [88.69813538, 21.70998955], [88.69829559, 21.70972061], [88.69834137, 21.70939445], [88.69837952, 21.70903778], [88.69848633, 21.70866966], [88.69851685, 21.70830917], [88.6985321, 21.70800018], [88.6986084, 21.70771027], [88.69869232, 21.70735168], [88.69886017, 21.70686913], [88.69888306, 21.7062397], [88.69884491, 21.7055397], [88.69869232, 21.70483017], [88.69877625, 21.70415115], [88.6988678, 21.70353127], [88.69883728, 21.70297813], [88.69875336, 21.70248985], [88.69886017, 21.70203972], [88.69888306, 21.70158005], [88.69882965, 21.70112038], [88.69886017, 21.70062065], [88.69888306, 21.7001152], [88.69889832, 21.69961166], [88.69895935, 21.69911957], [88.6991272, 21.69866371], [88.6991806, 21.6981678], [88.69929504, 21.69766426], [88.69950104, 21.69715309], [88.69968414, 21.69657707], [88.69975281, 21.69589996], [88.69983673, 21.6952095], [88.69979858, 21.69452286], [88.69998169, 21.69396782], [88.70012665, 21.69349098], [88.70024872, 21.69310951], [88.70028687, 21.69277954], [88.7003479, 21.69248199], [88.70052338, 21.69223213], [88.70061493, 21.69193649], [88.70079803, 21.69162941], [88.70088959, 21.69124985], [88.70108795, 21.69087982], [88.70132446, 21.69051743], [88.70156097, 21.6901207], [88.70185089, 21.68971634], [88.70213318, 21.689291], [88.70226288, 21.68875122], [88.7024231, 21.6882782], [88.70258331, 21.68782043], [88.70277405, 21.68741989], [88.70300293, 21.68702126], [88.70329285, 21.68663979], [88.70359039, 21.68626022], [88.70388794, 21.68586349], [88.7041626, 21.68548584], [88.70444489, 21.68512154], [88.70471954, 21.68475914], [88.70500946, 21.6843605], [88.70536041, 21.68394279], [88.70578766, 21.68350983], [88.70614624, 21.68300056], [88.70642853, 21.68247223], [88.70674896, 21.68200684], [88.7071228, 21.68161964], [88.70742798, 21.68119049], [88.70779419, 21.68081093], [88.70822906, 21.68046761], [88.70856476, 21.6800518], [88.708992, 21.67973137], [88.70942688, 21.67944717], [88.70981598, 21.67913055], [88.71029663, 21.6788311], [88.71079254, 21.67850113], [88.71109009, 21.67790794], [88.71153259, 21.67758942], [88.71206665, 21.677351], [88.71231842, 21.67682266], [88.71277618, 21.67638969], [88.71330261, 21.67598915], [88.71379089, 21.67559052], [88.71424866, 21.6752739], [88.71465302, 21.67497635], [88.71498871, 21.67468262], [88.71531677, 21.67440987], [88.71566772, 21.67416], [88.71602631, 21.67389107], [88.71643066, 21.67362022], [88.71689606, 21.67337036], [88.7173996, 21.67305946], [88.71793365, 21.67275047], [88.71842194, 21.67241478], [88.71889496, 21.67212677], [88.71935272, 21.6718998], [88.71974182, 21.6716404], [88.72011566, 21.67138481], [88.72048187, 21.6711216], [88.72087097, 21.67087936], [88.72128296, 21.67064095], [88.72164154, 21.6703186], [88.72202301, 21.67002106], [88.72245026, 21.66975021], [88.72286224, 21.66945076], [88.72329712, 21.6691494], [88.72371674, 21.66879082], [88.72418213, 21.66844749], [88.72467041, 21.66809082], [88.72512054, 21.66765976], [88.72556305, 21.66723251], [88.72602844, 21.6668644], [88.7264328, 21.66646194], [88.72686005, 21.66606903], [88.72731018, 21.66564941], [88.72785187, 21.66526985], [88.72842407, 21.66489029], [88.7289505, 21.6644516], [88.72947693, 21.664011], [88.73002625, 21.66360092], [88.73056793, 21.66319084], [88.73110199, 21.66281891], [88.73158264, 21.66242981], [88.73200226, 21.66202736], [88.7324295, 21.66169167], [88.73284912, 21.66140938], [88.73329163, 21.66117096], [88.73381805, 21.66094971], [88.73426056, 21.66062927], [88.73468781, 21.66028976], [88.73500061, 21.65986061], [88.7352829, 21.65944672], [88.73557281, 21.65904808], [88.73587036, 21.65869713], [88.73618317, 21.65836906], [88.73649597, 21.65807343], [88.73682404, 21.65778351], [88.7371521, 21.6574955], [88.73748016, 21.65720177], [88.7378006, 21.65689087], [88.73815155, 21.65660095], [88.73846436, 21.65629959], [88.7387619, 21.65600204], [88.73906708, 21.65570068], [88.73941803, 21.6554203], [88.73972321, 21.65512085], [88.74000549, 21.6548233], [88.74029541, 21.65453529], [88.74061584, 21.65426064], [88.74099731, 21.65401268], [88.74136353, 21.65370941], [88.74183655, 21.65352821], [88.74227905, 21.65331078], [88.74273682, 21.65313148], [88.74321747, 21.6529808], [88.74371338, 21.65276909], [88.7443161, 21.65264893], [88.74488831, 21.65241051], [88.74547577, 21.65223885], [88.74608612, 21.65209007], [88.74668884, 21.65192413], [88.74728394, 21.65173721], [88.74790192, 21.6516304], [88.74842834, 21.65141106], [88.74893951, 21.65117073], [88.74942017, 21.65093994], [88.74981689, 21.65081024], [88.75016022, 21.65048409], [88.75051117, 21.65017319], [88.75083923, 21.64979935], [88.7511673, 21.64946175], [88.75148773, 21.64925957], [88.75159454, 21.64906883], [88.75137329, 21.64871979], [88.75079346, 21.64826965], [88.7502594, 21.64791107], [88.74983978, 21.64756012], [88.74946594, 21.64724922], [88.74913025, 21.64700127], [88.74875641, 21.64680099], [88.74834442, 21.64663124], [88.74790192, 21.64645958], [88.74745178, 21.64629173], [88.74698639, 21.64616013], [88.74646759, 21.6460495], [88.74591064, 21.64595222], [88.74529266, 21.64588928], [88.74463654, 21.64587021], [88.74395752, 21.64586067], [88.74328613, 21.64585686], [88.74262238, 21.64583969], [88.74192047, 21.64580536], [88.74124146, 21.64574051], [88.74055481, 21.64572906], [88.73987579, 21.64571762], [88.73922729, 21.64570045], [88.73856354, 21.64571381], [88.73786163, 21.64570427], [88.73719025, 21.64566803], [88.73655701, 21.64561081], [88.73597717, 21.64546967], [88.73549652, 21.64528847], [88.73504639, 21.64507103], [88.73457336, 21.64481926], [88.73403931, 21.64454842], [88.7334671, 21.64423943], [88.73292542, 21.64393616], [88.7324295, 21.64365959], [88.73194885, 21.6433506], [88.73147583, 21.64307022], [88.73104095, 21.64277267], [88.73059082, 21.6424408], [88.73015594, 21.64207268], [88.72972107, 21.64167976], [88.72927094, 21.64128113], [88.72895813, 21.6409893], [88.72884369, 21.64088058], [88.72838593, 21.64050293], [88.72808838, 21.64029312], [88.72790527, 21.64016914], [88.72738647, 21.63986969], [88.72686768, 21.63955307], [88.72639465, 21.63914871], [88.72589111, 21.638731], [88.72563934, 21.63855362], [88.72536469, 21.63836479], [88.72511292, 21.63820267], [88.72483826, 21.63813019], [88.72446442, 21.63804054], [88.72402191, 21.63804817], [88.72357941, 21.63812065], [88.72315216, 21.63832855], [88.72289276, 21.63862038], [88.72281647, 21.63887978], [88.72277832, 21.63916588], [88.72305298, 21.63944435], [88.72305298, 21.63972282], [88.72305298, 21.63999939], [88.72333527, 21.64027786], [88.72333527, 21.64111137], [88.72250366, 21.64194489], [88.72249603, 21.64221954], [88.72222137, 21.64249992], [88.72222137, 21.6427784], [88.72166443, 21.64333344], [88.72138977, 21.64333344], [88.72138977, 21.64361], [88.72083282, 21.64417076], [88.72055817, 21.64416695], [88.72027588, 21.64444351], [88.72001648, 21.64438248], [88.71956635, 21.64460945], [88.71903229, 21.64473724], [88.71835327, 21.6448307], [88.71817017, 21.6451683], [88.7179184, 21.64559746], [88.71756744, 21.64605141], [88.7172699, 21.64647102], [88.71710968, 21.64689827], [88.7169342, 21.64722252], [88.71685028, 21.6473217], [88.71671295, 21.64748001], [88.71649933, 21.64776993], [88.71621704, 21.64804077], [88.71585846, 21.64827919], [88.71554565, 21.64857864], [88.71525574, 21.64888191], [88.7150116, 21.64919281], [88.71490479, 21.64958763], [88.71478271, 21.64999008], [88.71459198, 21.65038872], [88.71425629, 21.65075302], [88.71373749, 21.6510601], [88.71336365, 21.65146065], [88.7130661, 21.65192032], [88.71282959, 21.65246964], [88.71270752, 21.65312958], [88.71244812, 21.65370941], [88.71205139, 21.65418053], [88.71169281, 21.65460968], [88.71138, 21.65500832], [88.71111298, 21.65534973], [88.71087646, 21.65571022], [88.71070862, 21.65610313], [88.71053314, 21.6565094], [88.71027374, 21.65689087], [88.7100296, 21.65728378], [88.70986938, 21.6577282], [88.70960999, 21.65809059], [88.70941162, 21.65845108], [88.70916748, 21.65875053], [88.7089386, 21.65903091], [88.7088089, 21.65937042], [88.70861053, 21.6596489], [88.70841217, 21.65993118], [88.7082901, 21.66029549], [88.70805359, 21.66055679], [88.70804596, 21.66082954], [88.70916748, 21.66194916], [88.70972443, 21.66194534], [88.70999146, 21.66221809], [88.70999146, 21.66250038], [88.7097168, 21.66278839], [88.70972443, 21.66305542], [88.70944214, 21.66333389], [88.70861053, 21.66332817], [88.70833588, 21.66361046], [88.70777893, 21.66361046], [88.70722198, 21.6641674], [88.70722198, 21.66472244], [88.70694733, 21.66472054], [88.70639038, 21.66527939], [88.70471954, 21.66527939], [88.70417786, 21.66472054], [88.70361328, 21.66472244], [88.70333862, 21.66500092], [88.70305634, 21.66527748], [88.70321655, 21.66496086], [88.70270538, 21.66509247], [88.70220947, 21.6652832], [88.70173645, 21.66547966], [88.70131683, 21.66569138], [88.70104218, 21.66603088], [88.70078278, 21.66648102], [88.70037842, 21.6668911], [88.69999695, 21.66731071], [88.69962311, 21.66773987], [88.69921112, 21.66813087], [88.69882202, 21.66855049], [88.69841766, 21.66892052], [88.69806671, 21.6692791], [88.69777679, 21.6696167], [88.69753265, 21.66991043], [88.69737244, 21.67025948], [88.69716644, 21.67060089], [88.69696045, 21.67095566], [88.69680023, 21.67134094], [88.69664764, 21.67175102], [88.69644928, 21.67223358], [88.69610596, 21.67288971], [88.69593048, 21.67354965], [88.69610596, 21.67361069], [88.69555664, 21.67416763], [88.69555664, 21.67444038], [88.69444275, 21.67555618], [88.69444275, 21.67583084], [88.69361115, 21.67666626], [88.69361115, 21.67694473], [88.6922226, 21.67833328], [88.6922226, 21.67861176], [88.69194794, 21.67861176], [88.68805695, 21.68250084], [88.68769073, 21.68282127], [88.68728638, 21.68305016], [88.68704224, 21.68333054], [88.68712616, 21.68362045], [88.6873703, 21.68396759], [88.68762207, 21.68437576], [88.68782806, 21.68475914], [88.68810272, 21.68507004], [88.68833923, 21.68538094], [88.68859863, 21.68571091], [88.68884277, 21.68609047], [88.68913269, 21.68647957], [88.68940735, 21.68689919], [88.68971252, 21.68733025], [88.69000244, 21.68778992], [88.6902771, 21.68828011], [88.69055176, 21.68882179], [88.69078064, 21.68942261], [88.69090271, 21.69011116], [88.69111633, 21.69075012], [88.69138336, 21.69133759], [88.69165802, 21.69195175], [88.69186401, 21.69260216], [88.69194794, 21.69324303], [88.69203186, 21.69380951], [88.69218445, 21.69428062], [88.69226837, 21.69471359], [88.69245148, 21.69506454], [88.69250488, 21.69542313], [88.69258118, 21.69576073], [88.69274139, 21.6960907], [88.69283295, 21.69650459], [88.69300842, 21.69692421], [88.69307709, 21.69742966], [88.69319916, 21.69791985], [88.69333649, 21.69778061], [88.69361115, 21.69805336], [88.69361115, 21.69832993], [88.6938858, 21.69861031], [88.6938858, 21.69916534], [88.69416809, 21.69944], [88.69416809, 21.70055962], [88.69416046, 21.70112991], [88.69416046, 21.70167351], [88.69410706, 21.70220947], [88.69394684, 21.70272827], [88.69400024, 21.70319748], [88.69407654, 21.70373535], [88.69422913, 21.70429993], [88.69444275, 21.7048111], [88.69465637, 21.70531082], [88.6947403, 21.70580864], [88.69489288, 21.70627022], [88.69507599, 21.70668983], [88.69541931, 21.70705986], [88.69574738, 21.70747757], [88.69587708, 21.70800018], [88.69606781, 21.70843124], [88.69617462, 21.70892715], [88.69629669, 21.70947075], [88.69624329, 21.7100811], [88.69631958, 21.71069336], [88.69619751, 21.71125031], [88.6958313, 21.71166992], [88.6958313, 21.71278], [88.69611359, 21.71277618], [88.69638824, 21.71305656], [88.69638824, 21.71333313], [88.69675446, 21.71320534], [88.69692993, 21.7130394], [88.69712067, 21.71287918]]], [[[88.59194183, 21.69416618], [88.59306335, 21.69306183], [88.59333038, 21.69306183], [88.59388733, 21.69249916], [88.59388733, 21.69222069], [88.59500122, 21.69111061], [88.59500122, 21.69082832], [88.59610748, 21.68972206], [88.59638977, 21.68972969], [88.5966568, 21.68943977], [88.59750366, 21.68944359], [88.59777832, 21.68916893], [88.59790802, 21.68913078], [88.59848785, 21.68872643], [88.59906769, 21.68828964], [88.59958649, 21.68783951], [88.60011292, 21.68750572], [88.60058594, 21.68721962], [88.60102844, 21.68694115], [88.60146332, 21.68665695], [88.60192871, 21.68632126], [88.60241699, 21.68591118], [88.6029129, 21.68540001], [88.60336304, 21.68478012], [88.60386658, 21.68416023], [88.60434723, 21.68354034], [88.60471344, 21.68289948], [88.60500336, 21.6823082], [88.60534668, 21.68188095], [88.60561371, 21.68142891], [88.60585785, 21.68102074], [88.60604095, 21.68062973], [88.60619354, 21.68029213], [88.6063385, 21.67997742], [88.60621643, 21.6796627], [88.60582733, 21.6794529], [88.60527802, 21.67889023], [88.60527802, 21.67861176], [88.60472107, 21.67805481], [88.60416412, 21.67805481], [88.60360718, 21.67749596], [88.60333252, 21.6772213], [88.60361481, 21.67694473], [88.60361481, 21.67638969], [88.60527802, 21.6747303], [88.60556793, 21.67445755], [88.60549164, 21.67386246], [88.60526276, 21.67333221], [88.60500336, 21.67277527], [88.6047287, 21.67250061], [88.60472107, 21.67194366], [88.60444641, 21.67166519], [88.60444641, 21.67111206], [88.60166931, 21.66833115], [88.60166931, 21.66805649], [88.60028076, 21.66667175], [88.60028076, 21.66638947], [88.59999847, 21.66610909], [88.59999847, 21.66583061], [88.59972382, 21.66555595], [88.59971619, 21.66527939], [88.59860229, 21.66416931], [88.59860229, 21.66389084], [88.59749603, 21.66278839], [88.59694672, 21.66278839], [88.5966568, 21.66250038], [88.59610748, 21.66250038], [88.59471893, 21.66110992], [88.59444427, 21.66111183], [88.59388733, 21.66055679], [88.59361267, 21.66055679], [88.59305573, 21.65999985], [88.59278107, 21.65999985], [88.59240723, 21.65962601], [88.59222412, 21.65944672], [88.59194183, 21.65944672], [88.59111023, 21.6586113], [88.59083557, 21.6586113], [88.59055328, 21.65833282], [88.59027863, 21.65833282], [88.58999634, 21.65805435], [88.58972168, 21.65806007], [88.58944702, 21.65777969], [88.58889008, 21.65777969], [88.5887146, 21.65755272], [88.58854675, 21.65733147], [88.58830261, 21.6576004], [88.58805847, 21.65776062], [88.5878067, 21.65789032], [88.58759308, 21.65807915], [88.58745575, 21.6583786], [88.58721924, 21.65860939], [88.58721924, 21.65888977], [88.58693695, 21.65917015], [88.58693695, 21.66500092], [88.58721924, 21.66527939], [88.58721924, 21.66556168], [88.58708191, 21.6659584], [88.58698273, 21.66648102], [88.58695221, 21.66699982], [88.58693695, 21.66748047], [88.58693695, 21.66789818], [88.58689117, 21.66826057], [88.58676147, 21.66855431], [88.58669281, 21.66884041], [88.58663177, 21.66916275], [88.58653259, 21.66949081], [88.58638763, 21.66987991], [88.58624268, 21.6703186], [88.58610535, 21.67078972], [88.58596802, 21.67124557], [88.58582306, 21.6716404], [88.58566284, 21.67200089], [88.58550262, 21.67233849], [88.58531189, 21.67263222], [88.58513641, 21.67295456], [88.58499146, 21.67334175], [88.5848465, 21.67374039], [88.58466339, 21.67410088], [88.58448029, 21.67443085], [88.58435059, 21.67477989], [88.58416748, 21.67513084], [88.58396149, 21.67551041], [88.58377838, 21.67593193], [88.58355713, 21.67636108], [88.58331299, 21.67680931], [88.58304596, 21.67728806], [88.58278656, 21.67778969], [88.58255768, 21.6782608], [88.58242798, 21.67872047], [88.58228302, 21.67910194], [88.58216858, 21.67944908], [88.58198547, 21.67970467], [88.58183289, 21.67996979], [88.58167267, 21.68021965], [88.58148956, 21.68046761], [88.58133698, 21.68074226], [88.58117676, 21.68101311], [88.58106995, 21.68132019], [88.58092499, 21.68158722], [88.58078003, 21.68185043], [88.58061218, 21.68213081], [88.58048248, 21.6825161], [88.58039093, 21.68299484], [88.58052063, 21.68354034], [88.58082581, 21.68405914], [88.58133698, 21.68444061], [88.58187103, 21.68481064], [88.58232117, 21.68516731], [88.5827713, 21.68551254], [88.58322906, 21.68581009], [88.58367157, 21.68609047], [88.5841217, 21.68635941], [88.58457947, 21.6866703], [88.58508301, 21.6869812], [88.58565521, 21.6872654], [88.58626556, 21.68749428], [88.58688354, 21.68769646], [88.58750916, 21.68782043], [88.58811188, 21.68798065], [88.58870697, 21.6880722], [88.58925629, 21.68818092], [88.58973694, 21.68834114], [88.59017181, 21.68852997], [88.59055328, 21.68871117], [88.59086609, 21.68892288], [88.59108734, 21.68917084], [88.59123993, 21.68946075], [88.59139252, 21.68972969], [88.59166718, 21.69000053], [88.59166718, 21.69028091], [88.59194183, 21.69055939], [88.59194183, 21.69138908], [88.59166718, 21.69166946], [88.59166718, 21.69249916], [88.59111023, 21.69305611], [88.59111023, 21.69333267], [88.5908432, 21.69361115], [88.59064484, 21.69400024], [88.59046173, 21.69432068], [88.59021759, 21.69468117], [88.58994293, 21.69506836], [88.58963776, 21.69549561], [88.58934021, 21.69593239], [88.58903503, 21.69634819], [88.58875275, 21.69672966], [88.58848572, 21.69709778], [88.58825684, 21.69745827], [88.5880661, 21.69783592], [88.58789063, 21.69824982], [88.5877533, 21.69874001], [88.58759308, 21.69923973], [88.58751678, 21.69976044], [88.58751678, 21.70029831], [88.58758545, 21.70088577], [88.58779144, 21.70144081], [88.5880661, 21.70158958], [88.58835602, 21.70150948], [88.58860779, 21.70138931], [88.58889008, 21.70111084], [88.58889008, 21.70055962], [88.5891571, 21.70028114], [88.5891571, 21.69944], [88.58944702, 21.69916534], [88.58944702, 21.69890022], [88.58972168, 21.69861031], [88.58972168, 21.69750023], [88.59139252, 21.69582939], [88.59139252, 21.69555473], [88.59166718, 21.69527817], [88.59166718, 21.69499969], [88.59194183, 21.69472122], [88.59194183, 21.69416618]]], [[[88.80665588, 21.70667267], [88.80722046, 21.70611191], [88.80750275, 21.70611191], [88.80805206, 21.70555496], [88.80860901, 21.70556259], [88.8088913, 21.7052803], [88.80916595, 21.7052803], [88.8097229, 21.7047081], [88.8097229, 21.70444489], [88.80999756, 21.70416641], [88.80999756, 21.69917107], [88.8097229, 21.69890022], [88.8097229, 21.69528008], [88.80999756, 21.69499969], [88.80999756, 21.69388962], [88.81027985, 21.69361115], [88.81027985, 21.69281006], [88.81014252, 21.69146156], [88.81014252, 21.69011688], [88.81028748, 21.68864059], [88.80999756, 21.68721962], [88.80999756, 21.68527794], [88.8097229, 21.68499947], [88.8097229, 21.68333054], [88.80916595, 21.6827774], [88.80916595, 21.68222046], [88.8088913, 21.68194389], [88.8088913, 21.68027687], [88.80860901, 21.68000031], [88.80860901, 21.67972183], [88.80805206, 21.67916679], [88.80805206, 21.67861176], [88.8077774, 21.67833328], [88.8077774, 21.67694473], [88.80750275, 21.67666626], [88.80750275, 21.67583084], [88.80722046, 21.67555618], [88.80722046, 21.67525101], [88.80722046, 21.67499924], [88.80639648, 21.67416954], [88.80610657, 21.67416954], [88.80639648, 21.67389107], [88.80639648, 21.67361069], [88.8069458, 21.67305756], [88.8069458, 21.6697197], [88.80722046, 21.66944313], [88.80722046, 21.66583061], [88.8069458, 21.66555595], [88.8069458, 21.66472054], [88.80666351, 21.66444397], [88.80666351, 21.66389084], [88.80610657, 21.66332817], [88.8061142, 21.66305542], [88.80555725, 21.66250038], [88.80555725, 21.66221809], [88.80472565, 21.6613884], [88.80473328, 21.66110992], [88.8041687, 21.66055679], [88.8041687, 21.66027832], [88.80304718, 21.65917015], [88.80304718, 21.65888977], [88.80222321, 21.65806007], [88.80194092, 21.65806007], [88.80166626, 21.65777969], [88.8013916, 21.65777969], [88.80110931, 21.65750122], [88.80027008, 21.65750122], [88.80000305, 21.65722084], [88.79944611, 21.65722466], [88.79833221, 21.65611076], [88.79805756, 21.65611076], [88.7977829, 21.65583038], [88.79750061, 21.65583229], [88.79694366, 21.65527725], [88.79666901, 21.65555954], [88.79444122, 21.65555573], [88.79416656, 21.65583229], [88.79305267, 21.65583038], [88.79277802, 21.65611076], [88.79250336, 21.65611076], [88.79222107, 21.65639114], [88.79166412, 21.65638924], [88.79146576, 21.6565876], [88.79138947, 21.6566658], [88.79083252, 21.6566658], [88.79055786, 21.65694237], [88.79000092, 21.65694046], [88.78943634, 21.65750122], [88.78888702, 21.65750122], [88.78833008, 21.65806007], [88.78805542, 21.65805435], [88.78778076, 21.65833282], [88.78778076, 21.65860939], [88.78722382, 21.65916443], [88.78721619, 21.65944099], [88.78778076, 21.65999985], [88.78805542, 21.65999985], [88.78833008, 21.66028023], [88.78888702, 21.66027832], [88.78916931, 21.66055679], [88.78971863, 21.66055679], [88.79000092, 21.66083336], [88.79055786, 21.66083336], [88.79083252, 21.66111183], [88.79165649, 21.66110992], [88.79194641, 21.6613903], [88.79250336, 21.6613903], [88.79277802, 21.66167068], [88.79305267, 21.66167068], [88.79389191, 21.66250038], [88.79389191, 21.66278839], [88.79416656, 21.66305542], [88.79416656, 21.66332817], [88.79444122, 21.66361046], [88.79444122, 21.6641674], [88.79416656, 21.66444397], [88.79305267, 21.66333389], [88.79305267, 21.66305542], [88.79250336, 21.66250038], [88.79083252, 21.66250038], [88.79055786, 21.66221809], [88.79000092, 21.66222191], [88.78971863, 21.66194534], [88.78888702, 21.66194916], [88.78861237, 21.66167068], [88.78749847, 21.66167068], [88.78694153, 21.66110992], [88.78666687, 21.66111183], [88.78583527, 21.66027832], [88.78499603, 21.66028023], [88.78472137, 21.65999985], [88.78388977, 21.65999985], [88.78360748, 21.66028023], [88.78333282, 21.66027832], [88.78305817, 21.66055679], [88.78277588, 21.66055679], [88.78250122, 21.66083336], [88.78250122, 21.66110992], [88.7822113, 21.6613903], [88.78193665, 21.66110992], [88.78166962, 21.6613903], [88.78138733, 21.6613903], [88.78111267, 21.66167068], [88.78083038, 21.66167068], [88.78056335, 21.66194916], [88.77999878, 21.66194534], [88.77972412, 21.66222191], [88.77944183, 21.66221809], [88.77889252, 21.66278839], [88.77889252, 21.66305542], [88.77916718, 21.66333389], [88.77861023, 21.66332817], [88.77805328, 21.66389084], [88.77777863, 21.66389084], [88.77749634, 21.66416931], [88.77583313, 21.66416931], [88.77555847, 21.66389084], [88.77471924, 21.66389084], [88.77443695, 21.66416931], [88.77416992, 21.6641674], [88.77388763, 21.66444397], [88.77333069, 21.66444397], [88.77305603, 21.66472244], [88.77278137, 21.66472054], [88.77249908, 21.66500092], [88.77166748, 21.66500092], [88.77139282, 21.66527939], [88.77083588, 21.66527939], [88.77054596, 21.66556168], [88.76832581, 21.66556168], [88.76805878, 21.66527939], [88.76777649, 21.66527939], [88.76768494, 21.66518784], [88.76721954, 21.66472244], [88.76638794, 21.66472244], [88.76620483, 21.66453934], [88.76583099, 21.6641674], [88.76526642, 21.66416931], [88.76499939, 21.66389084], [88.76333618, 21.66389084], [88.76304626, 21.66361046], [88.76139069, 21.66361046], [88.76110077, 21.66332817], [88.76083374, 21.66333389], [88.76055908, 21.66305542], [88.76027679, 21.66333389], [88.76000214, 21.66333389], [88.75971985, 21.66305542], [88.75944519, 21.66305542], [88.7591629, 21.66333389], [88.75888824, 21.66332817], [88.75805664, 21.6641674], [88.75805664, 21.66444397], [88.75666809, 21.66583061], [88.75666809, 21.66610909], [88.7555542, 21.66722107], [88.75527954, 21.66722107], [88.7491684, 21.67333412], [88.74888611, 21.67333031], [88.74804687, 21.67416954], [88.74777985, 21.67416954], [88.7472229, 21.6747303], [88.74694824, 21.6747303], [88.74666595, 21.67500114], [88.7463913, 21.67500114], [88.74610138, 21.67527962], [88.74582672, 21.67527962], [88.74555206, 21.67555809], [88.7452774, 21.67555618], [88.74500275, 21.67583275], [88.74472046, 21.67583084], [88.7444458, 21.67611122], [88.74415588, 21.67611122], [88.74360657, 21.67666817], [88.74333191, 21.67666626], [88.74305725, 21.67694473], [88.74277496, 21.67694473], [88.74223328, 21.67749977], [88.74194336, 21.67749977], [88.7408371, 21.67861176], [88.74054718, 21.67861176], [88.73972321, 21.6794529], [88.73944092, 21.6794529], [88.7388916, 21.68000031], [88.73860931, 21.68000031], [88.73832703, 21.68028259], [88.73805237, 21.68028259], [88.73777771, 21.68056107], [88.73750305, 21.68055534], [88.73722076, 21.68083382], [88.73694611, 21.68083191], [88.73665619, 21.68111038], [88.73638916, 21.68111038], [88.73610687, 21.68139076], [88.73583221, 21.68139076], [88.73555756, 21.68167114], [88.73500061, 21.68166733], [88.73472595, 21.68194389], [88.73416901, 21.68194389], [88.73388672, 21.68222237], [88.73361206, 21.68222046], [88.73332977, 21.68250084], [88.73306274, 21.68250084], [88.73278046, 21.68278122], [88.73249817, 21.68278122], [88.73221588, 21.68305969], [88.73194122, 21.68305969], [88.73083496, 21.68416405], [88.73083496, 21.68444633], [88.73055267, 21.68472099], [88.73055267, 21.68638611], [88.73139191, 21.68722153], [88.73194122, 21.68721962], [88.73199463, 21.68727684], [88.73221588, 21.6875], [88.73665619, 21.6875], [88.73722076, 21.68806076], [88.73805237, 21.68805695], [88.73833466, 21.68833351], [88.73860931, 21.68833351], [88.7388916, 21.68861198], [88.73916626, 21.68861008], [88.73944092, 21.68889046], [88.73972321, 21.68889046], [88.73999786, 21.68917084], [88.74028015, 21.68916893], [88.74041748, 21.68930435], [88.74055481, 21.68944359], [88.74111176, 21.68944359], [88.74138641, 21.68916893], [88.74194336, 21.68917084], [88.74250031, 21.68861008], [88.74250031, 21.68833351], [88.74277496, 21.68805695], [88.74276733, 21.68721962], [88.74305725, 21.68694687], [88.74276733, 21.6866703], [88.74276733, 21.68638992], [88.74250031, 21.68610954], [88.74250031, 21.68527794], [88.74276733, 21.68499947], [88.74276733, 21.68444061], [88.74333191, 21.68388939], [88.74333191, 21.68359947], [88.7444458, 21.68250084], [88.74472046, 21.68250084], [88.74500275, 21.68222046], [88.74583435, 21.68222237], [88.74610901, 21.68194389], [88.74749756, 21.68194389], [88.74777985, 21.68222237], [88.74833679, 21.68222046], [88.74861145, 21.68250084], [88.74916077, 21.68250084], [88.74944305, 21.68278122], [88.74973297, 21.68278122], [88.75, 21.68305969], [88.75027466, 21.68305588], [88.75055695, 21.68333244], [88.75250244, 21.68333244], [88.7527771, 21.68305588], [88.75305176, 21.68305969], [88.75332642, 21.68278122], [88.75417328, 21.68278122], [88.75444794, 21.68250084], [88.75499725, 21.68250084], [88.75528717, 21.68222046], [88.75749969, 21.68227577], [88.75776672, 21.68250084], [88.7583313, 21.68250084], [88.75860596, 21.68278122], [88.7591629, 21.68278122], [88.75945282, 21.68305969], [88.75971985, 21.68305588], [88.76000214, 21.68333244], [88.76027679, 21.68333244], [88.76087189, 21.68392944], [88.76166534, 21.68472481], [88.76167297, 21.68499947], [88.76222229, 21.6855545], [88.76222229, 21.68583488], [88.76249695, 21.68610954], [88.76249695, 21.68638992], [88.76277924, 21.6866703], [88.76277924, 21.68916893], [88.76305389, 21.68944359], [88.76304626, 21.69082832], [88.76333618, 21.69111061], [88.76333618, 21.69138908], [88.76389313, 21.6919384], [88.76444244, 21.69249916], [88.76444244, 21.6927681], [88.76454926, 21.69288635], [88.7647171, 21.69306183], [88.76499939, 21.69306183], [88.76526642, 21.6927681], [88.76583099, 21.69277763], [88.76611328, 21.69249916], [88.76667023, 21.69249916], [88.76694489, 21.69277763], [88.76889038, 21.6927681], [88.76917267, 21.69306183], [88.76972198, 21.69305611], [88.76990509, 21.69324112], [88.76999664, 21.69333267], [88.77083588, 21.69333267], [88.77111053, 21.69361115], [88.7722168, 21.69361115], [88.77249908, 21.69388962], [88.77416992, 21.69388962], [88.77443695, 21.69417191], [88.77471924, 21.69416618], [88.77500153, 21.69444466], [88.77527618, 21.69444466], [88.77555847, 21.69472122], [88.77610779, 21.69472122], [88.7766571, 21.69528008], [88.77694702, 21.69527817], [88.77722168, 21.69555473], [88.77749634, 21.69555473], [88.77777863, 21.6958313], [88.77889252, 21.6958313], [88.77925873, 21.69620323], [88.77944183, 21.69639015], [88.77971649, 21.69639015], [88.78028107, 21.69695091], [88.78083038, 21.69695091], [88.78138733, 21.69750023], [88.78166962, 21.69750023], [88.78193665, 21.69778061], [88.78221893, 21.6977787], [88.78277588, 21.69833565], [88.78305817, 21.69832993], [88.78360748, 21.69890022], [88.78388977, 21.69890022], [88.7841568, 21.69917107], [88.78472137, 21.69916534], [88.78500366, 21.69944572], [88.78555298, 21.69944], [88.78610992, 21.70000076], [88.78639221, 21.70000076], [88.78666687, 21.70028114], [88.78694153, 21.70028114], [88.78721619, 21.70055962], [88.78749847, 21.70055771], [88.78778076, 21.70083427], [88.78806305, 21.70083046], [88.78833008, 21.70111084], [88.78861237, 21.70111084], [88.78916931, 21.70166969], [88.78944397, 21.70166779], [88.78971863, 21.70194435], [88.79000092, 21.70194435], [88.79027557, 21.70222282], [88.79055786, 21.70222092], [88.79110718, 21.70277977], [88.79139709, 21.70277977], [88.79148102, 21.70287132], [88.79165649, 21.70305824], [88.79222107, 21.70305634], [88.79250336, 21.7033329], [88.79305267, 21.70332909], [88.79333496, 21.70360756], [88.79360962, 21.70388985], [88.79444122, 21.70388985], [88.79471588, 21.70416832], [88.79528046, 21.70416641], [88.79555511, 21.70444489], [88.79638672, 21.70444489], [88.79666901, 21.70472145], [88.79722595, 21.7047081], [88.79750061, 21.70500183], [88.7977829, 21.70500183], [88.79833221, 21.70556259], [88.79972076, 21.70555496], [88.79988861, 21.7057209], [88.80000305, 21.70583344], [88.80027771, 21.70583344], [88.80055237, 21.70611191], [88.80110931, 21.70611191], [88.80125427, 21.70625114], [88.8013916, 21.70639038], [88.80304718, 21.70639038], [88.8033371, 21.70667267], [88.80361176, 21.70667267], [88.80388641, 21.70639038], [88.8041687, 21.70639038], [88.80473328, 21.70583153], [88.80527496, 21.70583344], [88.80555725, 21.70555496], [88.80583191, 21.70583153], [88.80583191, 21.70639038], [88.80610657, 21.70667267], [88.80665588, 21.70667267]]], [[[88.56243134, 21.70505905], [88.56301117, 21.70483589], [88.563591, 21.70450592], [88.56414032, 21.70407104], [88.56463623, 21.7035408], [88.56505585, 21.70294189], [88.56532288, 21.70228004], [88.5655899, 21.70169258], [88.56587219, 21.70119858], [88.56585693, 21.70063019], [88.56584167, 21.70008469], [88.56584167, 21.69955254], [88.56585693, 21.69902039], [88.56594849, 21.69849968], [88.56600952, 21.69799423], [88.56588745, 21.69747353], [88.56584167, 21.69694901], [88.56582642, 21.69641113], [88.56581116, 21.69588852], [88.56574249, 21.69536018], [88.56564331, 21.69482994], [88.56583405, 21.69416618], [88.56583405, 21.69363976], [88.56583405, 21.69305611], [88.5661087, 21.6927681], [88.5661087, 21.6922226], [88.56583405, 21.69194412], [88.56583405, 21.69138908], [88.56555939, 21.69111061], [88.56555176, 21.69055557], [88.5652771, 21.69028091], [88.5652771, 21.68972969], [88.56555939, 21.68943977], [88.56555176, 21.68916893], [88.5652771, 21.68889046], [88.5652771, 21.68695831], [88.56555939, 21.6866703], [88.56555939, 21.68556023], [88.56582642, 21.68527985], [88.56582642, 21.68499947], [88.5661087, 21.68472099], [88.5661087, 21.68416405], [88.56639099, 21.68388939], [88.56639099, 21.68333054], [88.56666565, 21.68305588], [88.56667328, 21.68250084], [88.56694794, 21.68222237], [88.56694794, 21.68166733], [88.5672226, 21.68139076], [88.5672226, 21.68111038], [88.56749725, 21.68083191], [88.56749725, 21.68027687], [88.56777954, 21.68000031], [88.56777954, 21.6794529], [88.56804657, 21.67917252], [88.56804657, 21.67861176], [88.56833649, 21.67833328], [88.56833649, 21.67805481], [88.56861115, 21.67777824], [88.56861877, 21.67749977], [88.5688858, 21.6772213], [88.5688858, 21.67527962], [88.56861877, 21.67500114], [88.56861877, 21.67278099], [88.5688858, 21.67250061], [88.56861877, 21.67222023], [88.56861115, 21.67055321], [88.5688858, 21.67028046], [88.5688858, 21.6697197], [88.56916809, 21.66944313], [88.5688858, 21.66917038], [88.5688858, 21.66889], [88.56861877, 21.66860008], [88.56861115, 21.66833115], [88.56833649, 21.66805649], [88.56833649, 21.66722107], [88.5680542, 21.6669445], [88.5680542, 21.66610909], [88.56777954, 21.66583061], [88.56777954, 21.66527748], [88.56694794, 21.66443825], [88.56694794, 21.6641674], [88.56667328, 21.66389084], [88.56667328, 21.66361046], [88.56555176, 21.66250038], [88.5652771, 21.66250038], [88.5644455, 21.66166878], [88.56445313, 21.6613903], [88.56416321, 21.66110992], [88.56360626, 21.66110992], [88.5633316, 21.6613903], [88.5633316, 21.66082954], [88.56277466, 21.66027832], [88.56276703, 21.65999985], [88.56249237, 21.65999985], [88.56266022, 21.65974045], [88.56210327, 21.65942764], [88.5616684, 21.65888977], [88.56111145, 21.65833092], [88.56111145, 21.65749931], [88.56083679, 21.65722084], [88.5605545, 21.65722466], [88.5588913, 21.65555573], [88.55860901, 21.65555954], [88.55722809, 21.6541748], [88.5567627, 21.65370941], [88.55638885, 21.65333366], [88.55626678, 21.65333366], [88.55596161, 21.6530571], [88.55568695, 21.65279961], [88.55544281, 21.65254021], [88.55516815, 21.65209007], [88.55480194, 21.65179062], [88.55458069, 21.65146065], [88.55439758, 21.65114021], [88.55417633, 21.65089035], [88.55399323, 21.65064049], [88.55384064, 21.65036964], [88.5536499, 21.65010071], [88.5535202, 21.64976311], [88.55330658, 21.64941978], [88.55305481, 21.64904404], [88.55278015, 21.64861107], [88.55278015, 21.64833069], [88.55249786, 21.64805794], [88.55249786, 21.64777946], [88.55222321, 21.64750099], [88.55222321, 21.64639091], [88.55194092, 21.64611053], [88.55194092, 21.64556122], [88.55166626, 21.64528084], [88.55194092, 21.64500046], [88.55194092, 21.64443016], [88.5513916, 21.64388847], [88.5513916, 21.6408329], [88.55166626, 21.64055634], [88.55166626, 21.63943863], [88.55194092, 21.63916588], [88.55194092, 21.63777733], [88.55190277, 21.63713074], [88.55156708, 21.63665962], [88.55091858, 21.63648987], [88.55052948, 21.63659096], [88.55017853, 21.63659096], [88.54972076, 21.6364994], [88.54920197, 21.63656044], [88.54859161, 21.63640022], [88.54833221, 21.63666916], [88.54777527, 21.63666725], [88.54750061, 21.63694382], [88.54694366, 21.63694382], [88.54666901, 21.63666725], [88.54638672, 21.63666725], [88.54556274, 21.63750076], [88.54528046, 21.63750076], [88.54499817, 21.63777733], [88.54462433, 21.63796234], [88.54411316, 21.63813019], [88.54368591, 21.63842964], [88.54325104, 21.63869286], [88.54283142, 21.63891983], [88.5424118, 21.63916969], [88.5419693, 21.63939667], [88.54145813, 21.63952446], [88.54099274, 21.63974953], [88.54058075, 21.64010048], [88.54019165, 21.64051437], [88.53974915, 21.6409111], [88.53929138, 21.64131927], [88.53872681, 21.64159012], [88.53827667, 21.64198494], [88.53778839, 21.6423912], [88.53733063, 21.64286041], [88.53692627, 21.64337921], [88.53655243, 21.64386177], [88.53616333, 21.64430046], [88.53582001, 21.64474106], [88.53546906, 21.64519882], [88.53505707, 21.64562988], [88.53468323, 21.64608955], [88.53430939, 21.64653015], [88.53392792, 21.64697456], [88.53354645, 21.64742279], [88.53312683, 21.64784813], [88.53273773, 21.6483078], [88.53237152, 21.64874268], [88.53203583, 21.64915466], [88.53172302, 21.64954185], [88.53143311, 21.64993286], [88.5311203, 21.65027809], [88.53083801, 21.65065956], [88.53056335, 21.65105247], [88.53031158, 21.6514492], [88.5300827, 21.65187073], [88.52981567, 21.65224648], [88.52957916, 21.65265274], [88.52947235, 21.65307999], [88.52944946, 21.6534729], [88.52944946, 21.65379906], [88.52942657, 21.65407562], [88.52934265, 21.65433311], [88.52925873, 21.65457344], [88.52915955, 21.65479279], [88.52899933, 21.6550312], [88.52881622, 21.65531921], [88.52856445, 21.65558815], [88.52832031, 21.65596962], [88.52809906, 21.65642929], [88.52805328, 21.65699005], [88.52805328, 21.65755272], [88.52805328, 21.65806961], [88.52805328, 21.6585331], [88.52805328, 21.65896034], [88.52809143, 21.65934944], [88.52826691, 21.65968323], [88.52836609, 21.66006088], [88.52855682, 21.66040993], [88.52871704, 21.66081429], [88.52890778, 21.66120338], [88.52901459, 21.66135216], [88.52913666, 21.66153145], [88.52931976, 21.66181183], [88.5295105, 21.66201401], [88.52971649, 21.66222191], [88.52997589, 21.66250038], [88.53024292, 21.66287994], [88.53053284, 21.66329956], [88.53082275, 21.66374969], [88.53110504, 21.66422653], [88.53141785, 21.66472435], [88.5318222, 21.66517067], [88.53222656, 21.66571999], [88.53263092, 21.6662693], [88.53277588, 21.6669445], [88.53305817, 21.66722107], [88.53305817, 21.66749954], [88.53333282, 21.66777802], [88.53333282, 21.66860008], [88.53305817, 21.66889], [88.53194427, 21.67000008], [88.53193665, 21.67111015], [88.53166962, 21.67138863], [88.53166962, 21.67166519], [88.53111267, 21.67222023], [88.53111267, 21.67416954], [88.53085327, 21.67435074], [88.53076935, 21.67440796], [88.53063202, 21.67465973], [88.5306778, 21.67510986], [88.53083801, 21.67564964], [88.53100586, 21.67624474], [88.53102875, 21.67690468], [88.53083801, 21.67747116], [88.53058624, 21.67791939], [88.53037262, 21.67833138], [88.530159, 21.67874908], [88.53002167, 21.67929077], [88.529953, 21.67991066], [88.52970886, 21.68053818], [88.52941132, 21.6811409], [88.52912903, 21.68169022], [88.52890778, 21.68223953], [88.52881622, 21.68280792], [88.52861023, 21.68321991], [88.52837372, 21.68357086], [88.52812958, 21.68388367], [88.52789307, 21.68416023], [88.52767944, 21.68445015], [88.5275116, 21.68476677], [88.52736664, 21.68513107], [88.52722168, 21.68558121], [88.52706909, 21.68606186], [88.52696991, 21.68656349], [88.52693939, 21.6870594], [88.52694702, 21.68751907], [88.5269928, 21.68792915], [88.52713013, 21.68827057], [88.52739716, 21.6885128], [88.52752686, 21.68889046], [88.52770233, 21.6892662], [88.527771, 21.68972969], [88.52777863, 21.6902504], [88.52773285, 21.6907692], [88.52754211, 21.69128036], [88.5274353, 21.69176865], [88.52723694, 21.69219017], [88.52702332, 21.69260025], [88.52675629, 21.6929512], [88.52646637, 21.69319725], [88.52614594, 21.69342041], [88.52581787, 21.69375038], [88.5255661, 21.69440079], [88.52513885, 21.69479561], [88.52453613, 21.69490814], [88.52414703, 21.69555664], [88.52380371, 21.69564247], [88.52349854, 21.69596481], [88.52329254, 21.69628906], [88.52310944, 21.69657707], [88.52302551, 21.69689941], [88.52287292, 21.69712067], [88.52269745, 21.69729996], [88.52258301, 21.69747162], [88.52259064, 21.6977005], [88.52250671, 21.69802094], [88.52233887, 21.69832039], [88.5222168, 21.69861031], [88.5221405, 21.69889069], [88.52197266, 21.69917107], [88.52185059, 21.69948769], [88.52172089, 21.69985008], [88.52156067, 21.70028114], [88.52131653, 21.70070076], [88.52150726, 21.70111084], [88.52196503, 21.70124626], [88.52222443, 21.70194435], [88.5222168, 21.70222092], [88.52054596, 21.70388985], [88.52055359, 21.70416641], [88.52083588, 21.70443916], [88.52027893, 21.70500183], [88.52027893, 21.7052803], [88.51999664, 21.70555496], [88.51999664, 21.70583344], [88.51983643, 21.70585251], [88.51889801, 21.70596695], [88.51860809, 21.70611191], [88.51833344, 21.70638847], [88.51832581, 21.7069416], [88.51819611, 21.70708847], [88.51819611, 21.70722008], [88.51789093, 21.70778847], [88.51777649, 21.7082901], [88.51763153, 21.70874977], [88.51756287, 21.70915031], [88.51751709, 21.70952988], [88.51747894, 21.70992279], [88.51734924, 21.7103405], [88.51724243, 21.71084023], [88.51721954, 21.71140099], [88.51727295, 21.71195984], [88.51747131, 21.71242905], [88.51761627, 21.71284485], [88.51773834, 21.7131958], [88.51781464, 21.71354294], [88.51798248, 21.7138195], [88.51815033, 21.71410751], [88.51832581, 21.71439934], [88.51847076, 21.71473122], [88.51863861, 21.71507835], [88.51889038, 21.71538925], [88.51916504, 21.71570396], [88.51944733, 21.7160244], [88.51973724, 21.71633148], [88.52009583, 21.71661186], [88.52058411, 21.71679115], [88.52115631, 21.71691322], [88.52180481, 21.71694183], [88.52245331, 21.71694374], [88.52307129, 21.71694374], [88.52366638, 21.71694374], [88.52420807, 21.71694374], [88.52471924, 21.71694374], [88.52638245, 21.71693993], [88.5283432, 21.71888924], [88.52879333, 21.71931267], [88.52921295, 21.71977806], [88.52953339, 21.72021294], [88.5297699, 21.72058105], [88.52996826, 21.72087097], [88.53010559, 21.72115707], [88.53025818, 21.72141075], [88.53038025, 21.72170067], [88.5305481, 21.7219429], [88.53070831, 21.72217941], [88.53085327, 21.72243118], [88.53096771, 21.72269249], [88.53111267, 21.72294807], [88.53122711, 21.72323036], [88.53138733, 21.72350311], [88.53151703, 21.7238121], [88.53166199, 21.7241497], [88.53179932, 21.72456169], [88.53195953, 21.72501945], [88.53213501, 21.72550964], [88.53225708, 21.72606087], [88.53238678, 21.72662926], [88.53253174, 21.72719193], [88.53268433, 21.72774124], [88.53283691, 21.7282505], [88.53302765, 21.72865105], [88.53318024, 21.72900009], [88.5333252, 21.72931862], [88.53347015, 21.72961044], [88.53365326, 21.72987175], [88.53382111, 21.73010826], [88.53395844, 21.73038483], [88.53411865, 21.73063087], [88.53425598, 21.73090935], [88.53444672, 21.73116875], [88.53464508, 21.73145294], [88.53483582, 21.73181152], [88.53509521, 21.73225784], [88.53547668, 21.73271179], [88.53596497, 21.73313904], [88.53650665, 21.73351097], [88.53710175, 21.73386955], [88.53768921, 21.7342205], [88.53824615, 21.73460007], [88.5388031, 21.73493195], [88.53936768, 21.73521996], [88.53990936, 21.7354908], [88.54046631, 21.73574066], [88.54107666, 21.73592949], [88.54174042, 21.73604012], [88.54235077, 21.73611641], [88.5428772, 21.73620033], [88.54335022, 21.7362709], [88.54379272, 21.73628807], [88.54425049, 21.73628044], [88.54473877, 21.73624992], [88.54520416, 21.73619652], [88.54566956, 21.73612976], [88.54611206, 21.73612022], [88.54656219, 21.7361412], [88.54701233, 21.73612976], [88.54746246, 21.73612022], [88.5479126, 21.73611069], [88.54836273, 21.73611069], [88.54882813, 21.73610115], [88.54930878, 21.7360611], [88.54981232, 21.73598099], [88.55039215, 21.73588943], [88.55102539, 21.7357769], [88.55165863, 21.73563957], [88.55230713, 21.73554039], [88.55292511, 21.73542976], [88.5535202, 21.73526382], [88.55407715, 21.73506737], [88.55458832, 21.73483849], [88.55506134, 21.73455811], [88.55550385, 21.73425674], [88.55591583, 21.73392105], [88.55631256, 21.73353958], [88.55666351, 21.73315048], [88.55697632, 21.73269081], [88.55730438, 21.73220062], [88.55761719, 21.73167038], [88.55795288, 21.73110962], [88.55828094, 21.73057938], [88.5586319, 21.73015976], [88.55896759, 21.72982979], [88.55930328, 21.72961235], [88.55966187, 21.72945786], [88.56004333, 21.72936058], [88.56041718, 21.72930717], [88.56079865, 21.72936058], [88.56115723, 21.72951126], [88.56151581, 21.72972107], [88.56192017, 21.72995186], [88.56237793, 21.73022079], [88.56289673, 21.73050117], [88.56347656, 21.73076057], [88.56407166, 21.73108101], [88.56463623, 21.73140526], [88.56520081, 21.7317009], [88.56577301, 21.7319603], [88.56632233, 21.73218727], [88.56659698, 21.73226929], [88.56687927, 21.73235321], [88.56745148, 21.7324028], [88.56802368, 21.73237038], [88.56859589, 21.73230362], [88.56920624, 21.73230171], [88.56989288, 21.7324295], [88.57055664, 21.73250008], [88.5708313, 21.73250008], [88.57110596, 21.7322216], [88.57111359, 21.73194504], [88.5716629, 21.73138809], [88.5716629, 21.73110962], [88.57138824, 21.73111153], [88.57120514, 21.73092842], [88.5708313, 21.73055649], [88.57055664, 21.7305584], [88.5716629, 21.72944069], [88.5716629, 21.72833252], [88.57194519, 21.72805786], [88.57195282, 21.72777939], [88.57250214, 21.72722054], [88.57254028, 21.72636604], [88.57253265, 21.72602272], [88.57264709, 21.72568893], [88.5728302, 21.72533798], [88.57306671, 21.72497177], [88.57332611, 21.72456169], [88.5736084, 21.72410011], [88.57389832, 21.72360039], [88.57417297, 21.72309113], [88.57444763, 21.72260094], [88.57470703, 21.72215271], [88.57495117, 21.72170067], [88.57513428, 21.7212677], [88.57533264, 21.72091293], [88.57556152, 21.72065353], [88.57581329, 21.72044754], [88.5760498, 21.72020149], [88.5762558, 21.71985054], [88.57646942, 21.71943855], [88.5766983, 21.71902084], [88.57698059, 21.71865082], [88.57730103, 21.71834183], [88.57762909, 21.71805954], [88.57795715, 21.71780014], [88.57832336, 21.71755981], [88.57867432, 21.71728706], [88.5790863, 21.71698952], [88.57949829, 21.71654892], [88.57994843, 21.71611023], [88.58035278, 21.71554947], [88.58084106, 21.71512413], [88.58135986, 21.71477509], [88.58191681, 21.71449089], [88.58247375, 21.71417618], [88.58297729, 21.71380997], [88.58344269, 21.71340942], [88.58388519, 21.7130661], [88.5843277, 21.71276283], [88.58473206, 21.71243095], [88.58513641, 21.71207047], [88.58554077, 21.71170235], [88.58596039, 21.71133041], [88.5863266, 21.71088982], [88.58667755, 21.71043968], [88.58696747, 21.71002007], [88.5872345, 21.70965958], [88.58744049, 21.70927811], [88.58751678, 21.70881271], [88.58759308, 21.70829964], [88.58773041, 21.70776939], [88.58779144, 21.70721245], [88.5878067, 21.70661545], [88.58779144, 21.70600128], [88.58771515, 21.70543289], [88.58751678, 21.7049408], [88.58744049, 21.70478821], [88.58728027, 21.7044754], [88.58703613, 21.70395851], [88.58677673, 21.70339012], [88.58663177, 21.7027607], [88.58670044, 21.70220947], [88.58664703, 21.70171165], [88.58643341, 21.70119476], [88.58622742, 21.700634], [88.58612061, 21.70002174], [88.5860672, 21.69942856], [88.58616638, 21.69893265], [88.58634949, 21.69856453], [88.58650208, 21.69823265], [88.58665466, 21.69791412], [88.58679962, 21.69753838], [88.58700562, 21.69711876], [88.58728027, 21.69663811], [88.58761597, 21.69614029], [88.58796692, 21.69561958], [88.58833313, 21.6950798], [88.58869934, 21.6945591], [88.58908081, 21.69407845], [88.58943176, 21.69360161], [88.58974457, 21.69309235], [88.59002686, 21.69256783], [88.59030151, 21.69206047], [88.59055328, 21.69153976], [88.59067535, 21.69103813], [88.59069824, 21.69062805], [88.59052277, 21.69028091], [88.59020233, 21.69001389], [88.58981323, 21.68982124], [88.5893631, 21.68970299], [88.58888245, 21.6896019], [88.58840942, 21.68943977], [88.58790588, 21.689291], [88.58744812, 21.68912125], [88.58701324, 21.68895912], [88.58657837, 21.68882751], [88.58612061, 21.68868065], [88.58563995, 21.68852043], [88.58519745, 21.68832016], [88.58474731, 21.68814087], [88.5843277, 21.68798065], [88.58390808, 21.68777084], [88.58347321, 21.68755341], [88.58305359, 21.68725014], [88.58261108, 21.68693352], [88.58214569, 21.68662262], [88.5816803, 21.68629646], [88.58126068, 21.68585968], [88.58088684, 21.68533707], [88.58055878, 21.68486977], [88.58024597, 21.68468094], [88.57997894, 21.68490982], [88.57971191, 21.68511581], [88.57953644, 21.68548965], [88.57946014, 21.68597794], [88.57942963, 21.68613815], [88.57937622, 21.68646049], [88.57925415, 21.68690681], [88.57918549, 21.68737221], [88.5791626, 21.68786049], [88.57910919, 21.68836975], [88.57897186, 21.68886948], [88.5789032, 21.68939972], [88.5788269, 21.68995285], [88.57868195, 21.69046021], [88.5785675, 21.69097519], [88.57837677, 21.6914711], [88.57819366, 21.69201469], [88.57788849, 21.69247818], [88.57752991, 21.69296837], [88.5771637, 21.69346428], [88.57670593, 21.69390488], [88.57623291, 21.69432068], [88.575737, 21.69474983], [88.57530212, 21.69518852], [88.57489777, 21.69563293], [88.57448578, 21.69597626], [88.57411194, 21.69631958], [88.5737381, 21.6966629], [88.57337952, 21.69698906], [88.57304382, 21.69734383], [88.57272339, 21.69769287], [88.57241058, 21.69803047], [88.57213593, 21.69831276], [88.57189178, 21.6985817], [88.57167053, 21.69883728], [88.5714798, 21.69912338], [88.57132721, 21.69947243], [88.57111359, 21.69983292], [88.57086945, 21.70024109], [88.57064056, 21.70070076], [88.57047272, 21.70121193], [88.57032776, 21.7017498], [88.57022095, 21.70232964], [88.57009888, 21.70294189], [88.57009125, 21.70360756], [88.57021332, 21.70427895], [88.57026672, 21.70496941], [88.57028198, 21.70563698], [88.5703125, 21.7062645], [88.57039642, 21.70685959], [88.57050323, 21.70743942], [88.57054901, 21.70802116], [88.57055664, 21.70855331], [88.57052612, 21.70902061], [88.57042694, 21.70940018], [88.5703125, 21.70973015], [88.57022858, 21.71003914], [88.57009125, 21.71032715], [88.56993866, 21.71062088], [88.56967926, 21.71086121], [88.56935883, 21.71105003], [88.56896973, 21.71113396], [88.56859589, 21.71124458], [88.5682373, 21.71136093], [88.56788635, 21.71149063], [88.56742096, 21.71158981], [88.56690216, 21.71167755], [88.56639862, 21.71178055], [88.56591034, 21.71173668], [88.56543732, 21.7116909], [88.56497955, 21.71169853], [88.56455231, 21.7118206], [88.56412506, 21.71191597], [88.56369019, 21.71199799], [88.56328583, 21.71212959], [88.56282806, 21.71220016], [88.56234741, 21.7122364], [88.56188965, 21.71231461], [88.56143951, 21.71244812], [88.56098938, 21.71259117], [88.56059265, 21.71277618], [88.56021118, 21.71301079], [88.55982971, 21.71327019], [88.55950165, 21.7135582], [88.55927277, 21.71390915], [88.55912018, 21.71431923], [88.55899048, 21.71475983], [88.55893707, 21.715271], [88.55892944, 21.71575928], [88.55890656, 21.71620941], [88.55888367, 21.71660614], [88.55880737, 21.71695137], [88.55869293, 21.71725082], [88.55858612, 21.71755791], [88.55845642, 21.71786118], [88.55823517, 21.7181263], [88.55796051, 21.71837997], [88.55767059, 21.71866989], [88.55738831, 21.71898079], [88.55708313, 21.71929932], [88.55677032, 21.71961594], [88.55646515, 21.71993446], [88.55619049, 21.72027016], [88.55596924, 21.72067833], [88.5557785, 21.72113037], [88.55554962, 21.72157669], [88.55526733, 21.72203064], [88.5549469, 21.72249031], [88.55455017, 21.72290039], [88.55410767, 21.72326088], [88.55365753, 21.72356987], [88.55321503, 21.72383308], [88.55280304, 21.72404099], [88.55236053, 21.72419739], [88.55187988, 21.72431183], [88.55138397, 21.72442436], [88.55085754, 21.72454453], [88.55033875, 21.72466087], [88.54982758, 21.72476006], [88.54930878, 21.72483063], [88.54875946, 21.72486687], [88.54816437, 21.72488403], [88.54750061, 21.72492218], [88.54676819, 21.72492027], [88.5460434, 21.72485161], [88.54537964, 21.72472191], [88.54476166, 21.72459221], [88.54417419, 21.72447205], [88.54364014, 21.72434616], [88.54322052, 21.72417068], [88.54301453, 21.72391319], [88.54305267, 21.72367287], [88.54329681, 21.72356224], [88.54367065, 21.7235527], [88.5440979, 21.72351074], [88.544487, 21.72330093], [88.54479218, 21.72287941], [88.54493713, 21.72229958], [88.54499054, 21.72164917], [88.54503632, 21.72103119], [88.54515076, 21.72055244], [88.54534149, 21.72032738], [88.545578, 21.72041512], [88.54577637, 21.72076416], [88.54586029, 21.72121811], [88.54582977, 21.72166252], [88.54576111, 21.72211075], [88.54573059, 21.72258568], [88.54576874, 21.72305489], [88.54590607, 21.72341347], [88.54615021, 21.72362328], [88.5464859, 21.72375488], [88.54688263, 21.72383308], [88.5473175, 21.72387123], [88.5477829, 21.72388458], [88.54824829, 21.72386932], [88.54870605, 21.72381973], [88.54915619, 21.72372055], [88.54963684, 21.72367287], [88.55008698, 21.72364044], [88.55053711, 21.72360992], [88.55095673, 21.7235508], [88.55136871, 21.7234211], [88.55178833, 21.72332573], [88.55220795, 21.72319984], [88.55264282, 21.72301102], [88.55309296, 21.72270012], [88.55354309, 21.7222805], [88.55400085, 21.72178078], [88.55448914, 21.72131157], [88.55444336, 21.72110939], [88.55500031, 21.72055626], [88.55500031, 21.72027969], [88.55610657, 21.71916962], [88.55631256, 21.71857071], [88.55658722, 21.71819496], [88.55690002, 21.71783066], [88.55721283, 21.71742058], [88.55747223, 21.7169342], [88.55764771, 21.71636581], [88.55776215, 21.71580505], [88.55780029, 21.71524048], [88.55782318, 21.71468163], [88.55796051, 21.71419334], [88.55815887, 21.71373177], [88.55839539, 21.71331024], [88.55866241, 21.71293831], [88.55896759, 21.71261978], [88.55930328, 21.7123394], [88.55969238, 21.71211243], [88.56011963, 21.71187592], [88.56054688, 21.71158981], [88.5610199, 21.7113018], [88.56163025, 21.71108055], [88.56227112, 21.71088982], [88.5629425, 21.71073914], [88.56358337, 21.71055031], [88.5641861, 21.71037102], [88.56478119, 21.71030045], [88.56532288, 21.71027946], [88.5657959, 21.71027946], [88.56624603, 21.71027946], [88.56668854, 21.71026993], [88.56713104, 21.71025848], [88.56755829, 21.71019173], [88.56793213, 21.71000671], [88.56829834, 21.70976067], [88.56859589, 21.70941925], [88.56880951, 21.70900345], [88.56893158, 21.70849228], [88.56900024, 21.70796585], [88.56893921, 21.70743942], [88.56890869, 21.70689011], [88.56887054, 21.70633125], [88.56878662, 21.70578957], [88.56868744, 21.70522118], [88.56864929, 21.70460701], [88.5686264, 21.70400047], [88.56864166, 21.70339966], [88.56868744, 21.70284081], [88.56884003, 21.70232964], [88.56894684, 21.70177269], [88.56915283, 21.70119095], [88.56936646, 21.7005806], [88.56958771, 21.6999855], [88.56978607, 21.69942284], [88.57002258, 21.69896317], [88.57028198, 21.69858932], [88.57052612, 21.69823074], [88.57077789, 21.69785118], [88.57106018, 21.69748116], [88.57135773, 21.69712067], [88.57167816, 21.6967411], [88.572052, 21.69638443], [88.57247162, 21.69600487], [88.5729599, 21.69558144], [88.5735321, 21.69511223], [88.57406616, 21.69452667], [88.57420349, 21.69402695], [88.5739212, 21.69379044], [88.5735321, 21.69364548], [88.5730896, 21.69358063], [88.57267761, 21.69341278], [88.57224274, 21.69316101], [88.57162476, 21.69313622], [88.57095337, 21.69326973], [88.57023621, 21.69330978], [88.56952667, 21.69326019], [88.56885529, 21.69307709], [88.56820679, 21.69293022], [88.56781006, 21.69286728], [88.56762695, 21.69284058], [88.56743622, 21.69300842], [88.567276, 21.69314957], [88.56720734, 21.6937809], [88.56720734, 21.69440079], [88.56723022, 21.69494629], [88.56729126, 21.69546127], [88.56743622, 21.69598961], [88.56749725, 21.6965847], [88.56752014, 21.69722939], [88.56755829, 21.69791031], [88.56764221, 21.69859123], [88.56755829, 21.69927979], [88.56751251, 21.69993973], [88.56748962, 21.70055962], [88.56743622, 21.70110512], [88.56730652, 21.70153809], [88.56719208, 21.70196152], [88.56704712, 21.70230865], [88.56693268, 21.70264816], [88.5667572, 21.70297623], [88.56656647, 21.70331955], [88.56630707, 21.70369148], [88.56600189, 21.70412064], [88.56558228, 21.70454979], [88.56512451, 21.70500183], [88.56459045, 21.70544052], [88.5639801, 21.70580101], [88.56333923, 21.70609665], [88.56272125, 21.70636368], [88.56212616, 21.70657921], [88.56150818, 21.70671082], [88.56091309, 21.70685959], [88.56027985, 21.70691109], [88.55963898, 21.70691109], [88.559021, 21.70685959], [88.5585022, 21.70671082], [88.55799103, 21.70660019], [88.5577774, 21.70639038], [88.5569458, 21.70639038], [88.55583191, 21.7052803], [88.55555725, 21.7052803], [88.55488586, 21.70460701], [88.55472565, 21.70444489], [88.55421448, 21.70418167], [88.55371857, 21.70369148], [88.5533371, 21.70361137], [88.5533371, 21.7033329], [88.55278015, 21.70277977], [88.5533371, 21.70222092], [88.55377197, 21.70249939], [88.55420685, 21.70281029], [88.55464935, 21.7031002], [88.5550766, 21.70339966], [88.5555191, 21.70369148], [88.55594635, 21.70400047], [88.55638123, 21.70428848], [88.55658722, 21.704422], [88.55683136, 21.7045784], [88.55732727, 21.70482063], [88.55786133, 21.70501709], [88.55838013, 21.70519829], [88.55890656, 21.70527077], [88.55940247, 21.70531082], [88.5598526, 21.70540047], [88.56030273, 21.70547104], [88.5607605, 21.70537949], [88.56128693, 21.70531082], [88.56185913, 21.70523071], [88.56243134, 21.70505905]]], [[[88.88305664, 21.74527931], [88.88276672, 21.74500084], [88.88360596, 21.74500084], [88.88388824, 21.74472046], [88.88444519, 21.74472237], [88.88471985, 21.74444389], [88.88500214, 21.74416733], [88.88555908, 21.74416924], [88.88639069, 21.74332809], [88.88666534, 21.74333382], [88.88722229, 21.74277878], [88.88749695, 21.74278069], [88.88777924, 21.74250031], [88.88804626, 21.74250031], [88.88833618, 21.74221992], [88.88861084, 21.74222183], [88.8888855, 21.74194527], [88.88916779, 21.74194908], [88.88944244, 21.74167061], [88.8897171, 21.74167061], [88.89055634, 21.74081993], [88.89111328, 21.74083328], [88.89138794, 21.74055672], [88.89167023, 21.74055672], [88.89194489, 21.74027824], [88.89221954, 21.74028015], [88.89332581, 21.73917007], [88.89362335, 21.73917007], [88.89389038, 21.73888969], [88.89417267, 21.73888969], [88.89444733, 21.73861122], [88.89472198, 21.73861122], [88.89583588, 21.73750114], [88.89611053, 21.73750114], [88.89639282, 21.73722076], [88.89666748, 21.73722267], [88.89694214, 21.73694229], [88.89722443, 21.73694229], [88.89749908, 21.73666573], [88.89778137, 21.73666954], [88.89778137, 21.73639107], [88.89805603, 21.73639107], [88.90083313, 21.73361015], [88.90110779, 21.73361015], [88.90139008, 21.73333359], [88.90166473, 21.73333359], [88.90528107, 21.72972298], [88.90555573, 21.72972298], [88.90583038, 21.7294445], [88.90638733, 21.7294445], [88.90666962, 21.72916794], [88.90693665, 21.72916985], [88.90750122, 21.72861099], [88.90859985, 21.72861099], [88.90888977, 21.72833061], [88.90916443, 21.72833252], [88.90944672, 21.72805786], [88.91027832, 21.72805977], [88.91055298, 21.72777939], [88.91110992, 21.72777939], [88.91139221, 21.72750092], [88.91221619, 21.72750092], [88.91388702, 21.72583961], [88.91388702, 21.72556114], [88.91416931, 21.72528076], [88.91416931, 21.72500038], [88.91388702, 21.72472], [88.91388702, 21.72305489], [88.91416931, 21.72277832], [88.91416931, 21.72167015], [88.91443634, 21.72138977], [88.91443634, 21.72110939], [88.91471863, 21.72083282], [88.91471863, 21.72055626], [88.91500092, 21.72027969], [88.91500092, 21.72000122], [88.9152832, 21.71970749], [88.91500092, 21.71944427], [88.91500092, 21.71888924], [88.9152832, 21.71861076], [88.91527557, 21.71805573], [88.91583252, 21.71750069], [88.91583252, 21.71693993], [88.91611481, 21.71666718], [88.91610718, 21.71639061], [88.91638947, 21.71611023], [88.91638947, 21.71582985], [88.91666412, 21.71555519], [88.91665649, 21.71528053], [88.91694641, 21.71500015], [88.91694641, 21.71471977], [88.91722107, 21.71444511], [88.91722107, 21.71389961], [88.91750336, 21.7136097], [88.91750336, 21.71333313], [88.91805267, 21.71277618], [88.91805267, 21.71249962], [88.91944122, 21.71111107], [88.91944122, 21.71084023], [88.92028046, 21.71000099], [88.92056274, 21.71000099], [88.92333221, 21.70722008], [88.9236145, 21.70722008], [88.92416382, 21.70666695], [88.92472076, 21.70667267], [88.92527771, 21.70611191], [88.92555237, 21.70611191], [88.92583466, 21.70583344], [88.9263916, 21.70583344], [88.92694092, 21.7052784], [88.92749786, 21.7052803], [88.92778015, 21.70500183], [88.9283371, 21.70500183], [88.92861176, 21.7047081], [88.92888641, 21.70472145], [88.9291687, 21.70444489], [88.92944336, 21.70444489], [88.92972565, 21.70416641], [88.93000031, 21.70416832], [88.93026733, 21.70388985], [88.93110657, 21.70388985], [88.93138885, 21.70360756], [88.93166351, 21.70361137], [88.9319458, 21.7033329], [88.9327774, 21.7033329], [88.93305206, 21.70305634], [88.93332672, 21.70305824], [88.93360901, 21.70277977], [88.9338913, 21.70277977], [88.93416595, 21.70249939], [88.93444824, 21.70249939], [88.9347229, 21.70222092], [88.93527985, 21.70222282], [88.93583679, 21.70166779], [88.93611145, 21.70166969], [88.9375, 21.70028114], [88.9375, 21.70000076], [88.93860626, 21.69890022], [88.93860626, 21.69861031], [88.93916321, 21.69806099], [88.93916321, 21.69778061], [88.93945313, 21.69750023], [88.9394455, 21.69666672], [88.93972015, 21.69639015], [88.93972015, 21.69610977], [88.94000244, 21.6958313], [88.94000244, 21.69555473], [88.9402771, 21.69527817], [88.94000244, 21.69499969], [88.94000244, 21.69472122], [88.9402771, 21.69444466], [88.9402771, 21.69416618], [88.94055176, 21.69388962], [88.94055176, 21.69333267], [88.94083405, 21.69305611], [88.94082642, 21.6919384], [88.9411087, 21.69166756], [88.9411087, 21.69111061], [88.94167328, 21.69055939], [88.94167328, 21.69000053], [88.94194794, 21.68972206], [88.94139099, 21.68917084], [88.94139099, 21.68778038], [88.94075775, 21.68624115], [88.94062042, 21.6850338], [88.93990326, 21.68382263], [88.93939972, 21.68254471], [88.93898773, 21.68182945], [88.93889618, 21.68167114], [88.93868256, 21.68066025], [88.93854523, 21.6794529], [88.93854523, 21.67864418], [88.9383316, 21.67804909], [88.9383316, 21.67638969], [88.93776703, 21.67583084], [88.93777466, 21.67555618], [88.9375, 21.67527962], [88.9375, 21.67500114], [88.93776703, 21.6747303], [88.9375, 21.67444038], [88.9375, 21.67416763], [88.93723297, 21.67389107], [88.93723297, 21.67305946], [88.93694305, 21.67278099], [88.93694305, 21.67193985], [88.93722534, 21.67166519], [88.93694305, 21.67138863], [88.93694305, 21.67111015], [88.93722534, 21.67111206], [88.93722534, 21.67083549], [88.93694305, 21.67055321], [88.93694305, 21.67028046], [88.93638611, 21.6697197], [88.93638611, 21.66944313], [88.93582916, 21.66889], [88.93582916, 21.66777992], [88.93611145, 21.66777992], [88.93611145, 21.66722107], [88.93583679, 21.66722107], [88.93583679, 21.66666603], [88.93553925, 21.66638947], [88.93553925, 21.66610909], [88.93527985, 21.66583061], [88.93527985, 21.66555595], [88.9347229, 21.66500092], [88.9347229, 21.66389084], [88.93444824, 21.66361046], [88.93444824, 21.66332817], [88.93360901, 21.66250038], [88.93360901, 21.66194916], [88.93305206, 21.6613903], [88.93305206, 21.66082954], [88.9327774, 21.66055679], [88.9327774, 21.66027832], [88.93250275, 21.65999985], [88.93250275, 21.65971947], [88.93222046, 21.65944672], [88.9315033, 21.65834236], [88.93083191, 21.65722466], [88.93083191, 21.65694237], [88.93027496, 21.65638924], [88.93026733, 21.65528107], [88.93000031, 21.65500069], [88.93000031, 21.65472031], [88.92944336, 21.65416718], [88.92944336, 21.65389061], [88.9291687, 21.65361977], [88.9291687, 21.65333176], [88.92805481, 21.65222168], [88.92805481, 21.65138817], [88.92749786, 21.65083122], [88.92749786, 21.65027809], [88.92722321, 21.64999962], [88.92722321, 21.64972115], [88.92610931, 21.64861107], [88.92610931, 21.64750099], [88.92555237, 21.64694023], [88.92555237, 21.64527512], [88.92527771, 21.64500046], [88.92527771, 21.64439964], [88.92527771, 21.64333344], [88.92500305, 21.64305305], [88.92500305, 21.64221954], [88.92472076, 21.64194489], [88.92472076, 21.64138794], [88.92444611, 21.64110947], [88.92444611, 21.63972282], [88.92416382, 21.63944435], [88.92416382, 21.63861084], [88.92388916, 21.63832855], [88.92388916, 21.63694382], [88.9236145, 21.63666725], [88.92359924, 21.63582993], [88.92305756, 21.6352787], [88.92305756, 21.63500023], [88.9227829, 21.63471985], [88.92277527, 21.63416862], [88.92233276, 21.63372993], [88.92194366, 21.63291168], [88.92138672, 21.63277817], [88.92082977, 21.63222122], [88.92055511, 21.63222313], [88.9201355, 21.63207817], [88.91945648, 21.63220024], [88.91887665, 21.63237], [88.91859436, 21.63264275], [88.91776276, 21.63306808], [88.91776276, 21.63362122], [88.91779327, 21.63445091], [88.91779327, 21.63528061], [88.91750336, 21.63555908], [88.91750336, 21.63611031], [88.91722107, 21.63639069], [88.91694641, 21.63639069], [88.91665649, 21.63666916], [88.91638947, 21.63666916], [88.91610718, 21.63639069], [88.91555786, 21.63638878], [88.91500092, 21.63694382], [88.91471863, 21.63694382], [88.91443634, 21.63722038], [88.91443634, 21.63750076], [88.91416931, 21.63777924], [88.91387939, 21.63779259], [88.91332245, 21.63861084], [88.91319275, 21.63862038], [88.91319275, 21.63916588], [88.91333008, 21.63972282], [88.91222382, 21.6408329], [88.91194153, 21.6408329], [88.91166687, 21.64111137], [88.91106415, 21.64115524], [88.91083527, 21.64138794], [88.91055298, 21.64110947], [88.91027832, 21.64111137], [88.90944672, 21.64194107], [88.90859985, 21.6427803], [88.90860748, 21.64305305], [88.90833282, 21.64333344], [88.90833282, 21.64361382], [88.90721893, 21.64472008], [88.90721893, 21.64500046], [88.90611267, 21.64611053], [88.90611267, 21.64639091], [88.90583038, 21.64666748], [88.90583038, 21.64694595], [88.90556335, 21.64722061], [88.90556335, 21.64750099], [88.90528107, 21.64777946], [88.90528107, 21.64805984], [88.90459442, 21.64957047], [88.90374756, 21.64995956], [88.90027618, 21.65278053], [88.89971924, 21.65278053], [88.89943695, 21.65306282], [88.89916992, 21.65278053], [88.89888763, 21.65278053], [88.89861298, 21.65250015], [88.89833069, 21.65250015], [88.89805603, 21.65222168], [88.89611053, 21.65222168], [88.89583588, 21.65250015], [88.89499664, 21.65250015], [88.89472198, 21.65278053], [88.89444733, 21.65278053], [88.89342499, 21.65420723], [88.89277649, 21.65444183], [88.89221191, 21.65512085], [88.89083099, 21.65611076], [88.89026642, 21.65611076], [88.88999939, 21.65639114], [88.88972473, 21.65638924], [88.88916779, 21.65694237], [88.88889313, 21.65694046], [88.88777924, 21.65805435], [88.88777924, 21.65833282], [88.88749695, 21.65860939], [88.88749695, 21.65888977], [88.88722229, 21.65916443], [88.88722229, 21.65944672], [88.88667297, 21.65999985], [88.88666534, 21.66027832], [88.88582611, 21.66110992], [88.88582611, 21.6613903], [88.88555908, 21.66166878], [88.88555908, 21.66221809], [88.88527679, 21.66250038], [88.88527679, 21.66278839], [88.88500214, 21.66305923], [88.88500214, 21.66389084], [88.88471985, 21.6641674], [88.88471985, 21.66444397], [88.88445282, 21.66472054], [88.88471985, 21.66500092], [88.88500214, 21.66500092], [88.88527679, 21.66527748], [88.88527679, 21.66583061], [88.88555908, 21.66610909], [88.88555908, 21.6669445], [88.88582611, 21.66722107], [88.88582611, 21.66777992], [88.88555908, 21.66805649], [88.88555908, 21.66833115], [88.88583374, 21.66861153], [88.88582611, 21.6697197], [88.8861084, 21.67000008], [88.88527679, 21.67083549], [88.88527679, 21.67222023], [88.88471985, 21.67278099], [88.88471985, 21.67389107], [88.88500214, 21.67416954], [88.88500214, 21.6747303], [88.88471985, 21.67500114], [88.88471985, 21.67555618], [88.88444519, 21.67583275], [88.88445282, 21.67638969], [88.8841629, 21.67666817], [88.8841629, 21.67749977], [88.88388824, 21.67777824], [88.88388824, 21.67804909], [88.88305664, 21.67889023], [88.88305664, 21.67917252], [88.8833313, 21.6794529], [88.8833313, 21.68028259], [88.88305664, 21.68055534], [88.88305664, 21.68083191], [88.88277435, 21.68111038], [88.88277435, 21.68194389], [88.88249969, 21.68222046], [88.88249969, 21.68250084], [88.88223267, 21.68278122], [88.88222504, 21.68305588], [88.88194275, 21.68333244], [88.88194275, 21.68361092], [88.88111115, 21.68444633], [88.88083649, 21.68444633], [88.88054657, 21.68472099], [88.8805542, 21.6855545], [88.88027954, 21.68583107], [88.88027954, 21.68638992], [88.8797226, 21.68695831], [88.8797226, 21.6875], [88.87916565, 21.68805695], [88.87916565, 21.68833351], [88.87889099, 21.68861198], [88.87889099, 21.68944359], [88.8786087, 21.68916893], [88.87832642, 21.68917084], [88.87750244, 21.6883297], [88.87610626, 21.68972969], [88.87610626, 21.69055939], [88.87555695, 21.69111061], [88.87555695, 21.69138908], [88.875, 21.69194412], [88.875, 21.69222069], [88.87472534, 21.69249916], [88.87472534, 21.69277763], [88.8730545, 21.69444466], [88.8730545, 21.6958313], [88.87277985, 21.69610977], [88.87277985, 21.69750023], [88.87249756, 21.6977787], [88.87248993, 21.69832993], [88.8722229, 21.69861031], [88.8722229, 21.69916534], [88.87194824, 21.69944], [88.87194824, 21.70249939], [88.87166595, 21.70277977], [88.87166595, 21.7047081], [88.8713913, 21.70500183], [88.8713913, 21.70694351], [88.87166595, 21.70722008], [88.87166595, 21.70776939], [88.8713913, 21.7080555], [88.8713913, 21.70944214], [88.87166595, 21.70972061], [88.87166595, 21.71027946], [88.87194824, 21.71055412], [88.87194824, 21.71194649], [88.87166595, 21.71222115], [88.87166595, 21.71249962], [88.87185669, 21.71268845], [88.87194824, 21.71277618], [88.87194824, 21.71287918], [88.87194824, 21.7136097], [88.8722229, 21.71388626], [88.8722229, 21.71471977], [88.87248993, 21.71500015], [88.8722229, 21.71528053], [88.8722229, 21.71639061], [88.87248993, 21.71639061], [88.87277985, 21.71666718], [88.87277985, 21.71694374], [88.87248993, 21.7172184], [88.87248993, 21.71777916], [88.87277985, 21.71805954], [88.87277985, 21.7191658], [88.87248993, 21.71943855], [88.87249756, 21.72055626], [88.87277985, 21.72083282], [88.87277985, 21.72110939], [88.87304688, 21.72138977], [88.8730545, 21.72166634], [88.87361145, 21.72221947], [88.87361145, 21.72249985], [88.87388611, 21.72277832], [88.87388611, 21.72333336], [88.8741684, 21.72360992], [88.8741684, 21.7238903], [88.87472534, 21.72444344], [88.87473297, 21.72472], [88.87526703, 21.72528076], [88.87526703, 21.72583961], [88.87555695, 21.72611046], [88.87555695, 21.72638893], [88.87638855, 21.72722054], [88.87638855, 21.72805786], [88.87666321, 21.72833061], [88.87666321, 21.72861099], [88.87695313, 21.72887993], [88.8769455, 21.72916794], [88.87722015, 21.72944069], [88.87722015, 21.72999954], [88.87750244, 21.73027992], [88.87750244, 21.73110962], [88.87805176, 21.73167038], [88.87805176, 21.73250008], [88.8777771, 21.73278046], [88.87805176, 21.73305511], [88.87805176, 21.73333359], [88.87833405, 21.73361015], [88.87833405, 21.73444366], [88.87861633, 21.73472023], [88.87861633, 21.7352829], [88.87889099, 21.73555946], [88.87889099, 21.73611069], [88.87944794, 21.73666573], [88.87944794, 21.73694229], [88.8797226, 21.73722076], [88.8797226, 21.73777962], [88.87999725, 21.73805428], [88.87999725, 21.73833084], [88.88027954, 21.73861122], [88.87999725, 21.73888969], [88.87999725, 21.73971939], [88.88027954, 21.73999977], [88.88027954, 21.74194527], [88.88054657, 21.74221992], [88.88054657, 21.74278069], [88.88083649, 21.74305534], [88.88083649, 21.74332809], [88.88111115, 21.74361038], [88.88111115, 21.74389076], [88.8813858, 21.74389076], [88.8813858, 21.74443817], [88.88223267, 21.74527931], [88.88305664, 21.74527931]]], [[[88.97799683, 21.72687531], [88.97860718, 21.72665024], [88.97914124, 21.72639084], [88.97966003, 21.72617912], [88.98020935, 21.72608185], [88.98073578, 21.72594261], [88.98123932, 21.72579956], [88.98171234, 21.72561073], [88.98216248, 21.72551346], [88.98256683, 21.72537613], [88.98298645, 21.72529984], [88.98343658, 21.72527122], [88.98387909, 21.72521973], [88.98427582, 21.72505951], [88.98471069, 21.72500038], [88.9851532, 21.72494125], [88.98552704, 21.72479057], [88.98596191, 21.72473335], [88.98639679, 21.72470284], [88.98683167, 21.72462845], [88.98726654, 21.72449112], [88.98771667, 21.72442245], [88.98816681, 21.72431946], [88.98860168, 21.72418976], [88.9887619, 21.7241497], [88.98904419, 21.72407913], [88.98944092, 21.72390938], [88.98985291, 21.7237606], [88.99026489, 21.72359657], [88.99069977, 21.72340965], [88.99118805, 21.72324181], [88.99169922, 21.72302055], [88.99221802, 21.72278023], [88.99272156, 21.72249985], [88.99318695, 21.72221947], [88.99359131, 21.72191048], [88.99394226, 21.72154999], [88.99423218, 21.72121429], [88.99452972, 21.72089767], [88.99479675, 21.72058105], [88.99505615, 21.72023773], [88.99532318, 21.71985054], [88.99559784, 21.71941948], [88.99591064, 21.71894073], [88.99628448, 21.71847916], [88.99672699, 21.71804047], [88.99721527, 21.71760559], [88.99775696, 21.71721077], [88.99832916, 21.71677589], [88.99888611, 21.71630096], [88.99944305, 21.71587944], [88.99972534, 21.71527863], [88.99973297, 21.71582985], [89.0, 21.71611023], [89.00026703, 21.71582985], [89.00128937, 21.71546555], [89.00189972, 21.71536064], [89.00245667, 21.715271], [89.00298309, 21.71517944], [89.00348663, 21.71517944], [89.00415802, 21.7151432], [89.00460815, 21.71519279], [89.00508881, 21.71517181], [89.00559235, 21.71525574], [89.00585938, 21.71534348], [89.00627899, 21.71550941], [89.00672913, 21.71566963], [89.00717163, 21.71583748], [89.00760651, 21.7159996], [89.00804901, 21.71613121], [89.00852203, 21.71627045], [89.00900269, 21.71638107], [89.00949097, 21.71648979], [89.00995636, 21.71665001], [89.01040649, 21.71680832], [89.010849, 21.71707726], [89.01123047, 21.71731377], [89.01154327, 21.71731186], [89.01185608, 21.71730804], [89.01229095, 21.7171402], [89.01275635, 21.71715546], [89.01328278, 21.7172184], [89.01383972, 21.71731949], [89.0144577, 21.71751976], [89.01509857, 21.71769905], [89.01557159, 21.71751976], [89.01604462, 21.71726608], [89.01651001, 21.71690941], [89.01698303, 21.71647453], [89.0174942, 21.71603012], [89.01802826, 21.71558952], [89.01863098, 21.71522331], [89.01927948, 21.71489716], [89.01988983, 21.71455956], [89.0202713, 21.71408653], [89.02052307, 21.71355057], [89.02051544, 21.71297646], [89.02027893, 21.71243095], [89.02001953, 21.71196175], [89.01972198, 21.7115593], [89.01943207, 21.71122169], [89.01911926, 21.71095848], [89.01873779, 21.7107811], [89.01838684, 21.7105484], [89.01802826, 21.71033287], [89.01753235, 21.7103157], [89.01696777, 21.71041489], [89.0164032, 21.71032333], [89.01586914, 21.71028519], [89.01539612, 21.71030807], [89.01499176, 21.71043968], [89.01461792, 21.71055031], [89.01422882, 21.71055984], [89.01381683, 21.71055984], [89.01338959, 21.71055984], [89.01293945, 21.71055984], [89.01248932, 21.71055031], [89.01204681, 21.71047974], [89.01161194, 21.7103157], [89.0111084, 21.71026039], [89.01095581, 21.71020699], [89.01063538, 21.71009636], [89.0100708, 21.70993996], [89.00950623, 21.70968819], [89.00898743, 21.70935249], [89.00863647, 21.70889473], [89.00833893, 21.70846558], [89.00811768, 21.70808983], [89.00801849, 21.70773125], [89.00786591, 21.70743942], [89.00778961, 21.70713043], [89.00777435, 21.70677567], [89.00775146, 21.70638084], [89.00762939, 21.70594978], [89.00752258, 21.70549965], [89.00751495, 21.7053299], [89.00749969, 21.70503998], [89.00753021, 21.70459938], [89.00762939, 21.70421028], [89.00773621, 21.70392036], [89.00782013, 21.70363045], [89.00799561, 21.70335579], [89.00814056, 21.70297813], [89.00818634, 21.70286942], [89.00834656, 21.70250893], [89.00865936, 21.70202065], [89.0091629, 21.70166969], [89.00971222, 21.7013607], [89.01025391, 21.70111465], [89.01078796, 21.70090485], [89.01134491, 21.70080185], [89.0117569, 21.70067024], [89.01190948, 21.70062256], [89.0125351, 21.70056152], [89.01321411, 21.70059586], [89.01390076, 21.7007885], [89.01460266, 21.70083237], [89.01526642, 21.70079041], [89.01586914, 21.70059776], [89.0164566, 21.70051193], [89.0169754, 21.70031738], [89.01753235, 21.7002182], [89.01802063, 21.7000103], [89.01854706, 21.69980812], [89.01913452, 21.69967842], [89.01965332, 21.69935036], [89.02005005, 21.69872665], [89.02046204, 21.69815063], [89.02076721, 21.69758987], [89.02083588, 21.69701958], [89.02083588, 21.6964798], [89.02084351, 21.69598007], [89.02091217, 21.69549942], [89.02108765, 21.69503021], [89.02120209, 21.69450951], [89.02140045, 21.69400024], [89.02165222, 21.69352913], [89.02184296, 21.6930294], [89.02197266, 21.69255257], [89.02220917, 21.69216728], [89.02239227, 21.69177055], [89.02259827, 21.69137383], [89.02281952, 21.69093132], [89.02311707, 21.69048119], [89.02339935, 21.68997955], [89.02363586, 21.68942451], [89.02389526, 21.6888752], [89.02411652, 21.6883297], [89.02416229, 21.6877327], [89.02412415, 21.68714523], [89.02391052, 21.68665123], [89.02368164, 21.68618011], [89.02349854, 21.68571091], [89.02333069, 21.68556023], [89.02333069, 21.68499947], [89.0230484, 21.68472099], [89.02305603, 21.68444633], [89.02278137, 21.68416405], [89.02278137, 21.68388939], [89.02249908, 21.68359947], [89.02249908, 21.68305588], [89.0222168, 21.68278122], [89.0222168, 21.68250084], [89.02194214, 21.68222046], [89.02194214, 21.68194389], [89.02166748, 21.68166733], [89.02166748, 21.68083191], [89.02138519, 21.68055534], [89.02139282, 21.67972183], [89.02131653, 21.67964554], [89.02111053, 21.67944527], [89.02111053, 21.67745018], [89.02111053, 21.67472267], [89.02083588, 21.67444038], [89.02083588, 21.67361069], [89.02111053, 21.67333031], [89.02111053, 21.67111206], [89.02083588, 21.67083549], [89.02083588, 21.67055321], [89.02082825, 21.66995811], [89.02076721, 21.66930962], [89.02056122, 21.66878128], [89.02036285, 21.66826057], [89.02020264, 21.66772079], [89.01994324, 21.66722107], [89.01963806, 21.66674042], [89.01924896, 21.66633224], [89.01889801, 21.66585922], [89.01860809, 21.66533089], [89.01829529, 21.66512871], [89.01798248, 21.66447067], [89.01796722, 21.66395569], [89.018013, 21.66347122], [89.01789093, 21.66305923], [89.01795197, 21.66237068], [89.01795959, 21.66172409], [89.01783752, 21.66118622], [89.01740265, 21.66085052], [89.01689911, 21.66064644], [89.01667023, 21.66055107], [89.01527405, 21.65944672], [89.01499176, 21.65923309], [89.01413727, 21.65882111], [89.01384735, 21.65854073], [89.01385498, 21.65810585], [89.01402283, 21.65740967], [89.01389313, 21.65707016], [89.01361084, 21.65686035], [89.0131073, 21.65666008], [89.01299286, 21.65645027], [89.01277924, 21.65611076], [89.01249695, 21.65583038], [89.01222229, 21.65583229], [89.01194763, 21.65555573], [89.01167297, 21.65555954], [89.0109787, 21.65482712], [89.01035309, 21.65416718], [89.01013184, 21.65396118], [89.00930023, 21.65325928], [89.00888824, 21.65306282], [89.0083313, 21.65262985], [89.00805664, 21.65250015], [89.00775909, 21.65222168], [89.00734711, 21.65222168], [89.00694275, 21.65222168], [89.00637817, 21.65208054], [89.00395966, 21.65201187], [89.00318146, 21.65242386], [89.00235748, 21.6523571], [89.00197601, 21.65223122], [89.0014267, 21.65223122], [89.00077057, 21.65216255], [89.0, 21.65222168], [88.99954987, 21.65219116], [88.99899292, 21.65209961], [88.99871063, 21.65195274], [88.99833679, 21.65192032], [88.99801636, 21.65176964], [88.99765015, 21.65167809], [88.99724579, 21.65166092], [88.9968338, 21.65166473], [88.99641418, 21.65166473], [88.99598694, 21.65163422], [88.99556732, 21.65151978], [88.99514008, 21.65141106], [88.99471283, 21.65138817], [88.99427032, 21.65138817], [88.99384308, 21.65138817], [88.99341583, 21.65138817], [88.99299622, 21.65142059], [88.99263, 21.65160942], [88.99223328, 21.65167618], [88.99183655, 21.65178108], [88.99147797, 21.65198708], [88.99114227, 21.65229607], [88.9908371, 21.65265274], [88.99060059, 21.65302086], [88.99040222, 21.65335846], [88.99025726, 21.65373421], [88.99007416, 21.6541214], [88.98996735, 21.65462112], [88.98980713, 21.65513992], [88.9897995, 21.65565872], [88.98995209, 21.65625954], [88.99001312, 21.6568203], [88.98999786, 21.65733719], [88.9899826, 21.65784073], [88.98992157, 21.65833092], [88.98983765, 21.65877914], [88.98973846, 21.65924072], [88.98972321, 21.65969276], [88.98971558, 21.66013527], [88.98964691, 21.66059113], [88.98947906, 21.66105843], [88.98944092, 21.66161919], [88.98944092, 21.66223145], [88.98944855, 21.66286469], [88.98950195, 21.66348267], [88.98964691, 21.66403961], [88.98978424, 21.66460037], [88.99001312, 21.66505814], [88.99024963, 21.66546059], [88.99045563, 21.66586685], [88.99060822, 21.66627121], [88.99085999, 21.66664124], [88.99118805, 21.66699982], [88.99164581, 21.66732025], [88.99212646, 21.66770554], [88.99256134, 21.66812134], [88.99305725, 21.66859055], [88.99365234, 21.66905022], [88.99417877, 21.66950798], [88.99436951, 21.66978264], [88.99472046, 21.67027855], [88.99472046, 21.67083549], [88.99500275, 21.67111015], [88.99500275, 21.67138863], [88.99555206, 21.67194366], [88.99555206, 21.67222023], [88.99581909, 21.67250061], [88.99581909, 21.67278099], [88.99577332, 21.67325974], [88.99560547, 21.67375565], [88.99552917, 21.67423058], [88.99545288, 21.67468262], [88.99550629, 21.67517281], [88.99551392, 21.67564583], [88.9954071, 21.67609978], [88.99525452, 21.67655182], [88.99507141, 21.67698097], [88.99492645, 21.67741966], [88.99474335, 21.67782021], [88.99463654, 21.6782608], [88.99443817, 21.67867088], [88.9942627, 21.67904282], [88.99421692, 21.67914009], [88.9940567, 21.67970848], [88.99386597, 21.68028259], [88.9936142, 21.68166733], [88.99333191, 21.68194389], [88.99333191, 21.68222237], [88.99307251, 21.68250084], [88.99305725, 21.6827774], [88.99360657, 21.68333054], [88.9936142, 21.68416405], [88.99388885, 21.68444061], [88.99388885, 21.68499947], [88.99415588, 21.68527985], [88.99415588, 21.6875], [88.99388885, 21.68777847], [88.99388885, 21.68833351], [88.99360657, 21.68861008], [88.9936142, 21.68916893], [88.99333191, 21.68943977], [88.99333191, 21.68972206], [88.99307251, 21.69000053], [88.99307251, 21.69028091], [88.99277496, 21.69055557], [88.99277496, 21.69083405], [88.99266052, 21.69095039], [88.99250031, 21.69111061], [88.99250031, 21.69166756], [88.99223328, 21.6919384], [88.99222565, 21.69249916], [88.99194336, 21.69277763], [88.99194336, 21.69439125], [88.99194336, 21.69472122], [88.99185181, 21.69481659], [88.9916687, 21.69499969], [88.9916687, 21.69555473], [88.99194336, 21.6958313], [88.99194336, 21.69610977], [88.99223328, 21.69639015], [88.99223328, 21.69778061], [88.99250031, 21.69806099], [88.99250031, 21.69890022], [88.9927597, 21.69917107], [88.9927597, 21.70000076], [88.99250031, 21.70028114], [88.99250031, 21.70139122], [88.99222565, 21.70166779], [88.99222565, 21.70194435], [88.99194336, 21.70222092], [88.99194336, 21.70249939], [88.9916687, 21.70277977], [88.9916687, 21.70305634], [88.99138641, 21.7033329], [88.99138641, 21.70360756], [88.9908371, 21.70416641], [88.9908371, 21.70443916], [88.99001312, 21.7052803], [88.99001312, 21.70556259], [88.98916626, 21.70639038], [88.9888916, 21.70639038], [88.98472595, 21.71055984], [88.98443604, 21.71055984], [88.98332977, 21.71166992], [88.98305511, 21.7116642], [88.98249817, 21.71222305], [88.98221588, 21.71222115], [88.98166656, 21.71278], [88.98139191, 21.71277618], [88.98110962, 21.71305656], [88.98083496, 21.71305656], [88.98055267, 21.71333313], [88.98027802, 21.71333313], [88.98000336, 21.7136116], [88.97972107, 21.7136097], [88.97944641, 21.71389961], [88.97915649, 21.71389961], [88.97860718, 21.71445084], [88.97833252, 21.71444511], [88.9777832, 21.71500015], [88.97750092, 21.71500015], [88.97693634, 21.71556091], [88.97666931, 21.71556091], [88.97611237, 21.71611023], [88.97583008, 21.71611023], [88.97528076, 21.71666908], [88.97499847, 21.71666718], [88.97467041, 21.71699524], [88.97333527, 21.7183342], [88.97305298, 21.71832848], [88.97249603, 21.71888924], [88.97222137, 21.71888924], [88.97110748, 21.72000122], [88.97110748, 21.72027779], [88.97055817, 21.72083282], [88.97055817, 21.72110939], [88.97110748, 21.72166634], [88.97110748, 21.7219429], [88.97164917, 21.72249985], [88.97193909, 21.72249985], [88.97194672, 21.72277832], [88.97389221, 21.72472], [88.97389221, 21.72500038], [88.97416687, 21.72528076], [88.97416687, 21.72556114], [88.97528076, 21.72667122], [88.97555542, 21.7266674], [88.97583008, 21.72694588], [88.97611237, 21.72694588], [88.97638702, 21.72722244], [88.97666931, 21.72722244], [88.97729492, 21.72712135], [88.97775269, 21.72696114], [88.97799683, 21.72687531]]], [[[87.91194153, 22.43222046], [87.91194153, 22.43194389], [87.91278076, 22.43111038], [87.91306305, 22.43139076], [87.91305542, 22.43166733], [87.91361237, 22.43222237], [87.91388702, 22.43222237], [87.91444397, 22.43166733], [87.9152832, 22.43167114], [87.91555023, 22.43139076], [87.91610718, 22.43139076], [87.91638947, 22.43111038], [87.91665649, 22.43111038], [87.91694641, 22.43083191], [87.91750336, 22.43083382], [87.91777802, 22.43055534], [87.91805267, 22.43056107], [87.9183197, 22.43029022], [87.9183197, 22.43000031], [87.91777802, 22.4294529], [87.91694641, 22.42944527], [87.91666412, 22.42972374], [87.91638947, 22.42944527], [87.91583252, 22.4294529], [87.9152832, 22.42889023], [87.91443634, 22.42889023], [87.91416931, 22.42861176], [87.91388702, 22.42889023], [87.91278076, 22.42889023], [87.9125061, 22.42917061], [87.91166687, 22.42917061], [87.91139221, 22.4294529], [87.91083527, 22.42944527], [87.91055298, 22.42972374], [87.90999603, 22.42972183], [87.90972137, 22.43000031], [87.90888977, 22.43000031], [87.90805817, 22.43083191], [87.90805817, 22.43167114], [87.90888977, 22.43250084], [87.9091568, 22.43222046], [87.90944672, 22.43222046], [87.90972137, 22.43250084], [87.90999603, 22.43250084], [87.91055298, 22.43305969], [87.91110992, 22.43305969], [87.91194153, 22.43222046]]], [[[88.85916901, 22.46944427], [88.85916901, 22.46666908], [88.85888672, 22.46639061], [88.85888672, 22.4636097], [88.85861206, 22.46333313], [88.85861206, 22.46222687], [88.85805511, 22.46166611], [88.85806274, 22.46138954], [88.85778046, 22.46111107], [88.85778046, 22.4608326], [88.85749817, 22.46055794], [88.85749054, 22.46000099], [88.85721588, 22.45972252], [88.85722351, 22.45944595], [88.85666656, 22.45889091], [88.85610962, 22.45889091], [88.85610962, 22.45916939], [88.85555267, 22.45972252], [88.85555267, 22.45999908], [88.85527802, 22.46027184], [88.85527802, 22.46055794], [88.85555267, 22.4608326], [88.85555267, 22.46111107], [88.85610962, 22.46138954], [88.85639191, 22.46138954], [88.85721588, 22.46222115], [88.85721588, 22.46389198], [88.85749054, 22.46417046], [88.85749817, 22.46555519], [88.85722351, 22.46583366], [88.85721588, 22.46693993], [88.85778046, 22.46750069], [88.85778046, 22.46805573], [88.85806274, 22.46833038], [88.85749054, 22.46889114], [88.85639191, 22.46889114], [88.85610962, 22.46916771], [88.85639191, 22.46944427], [88.85639191, 22.46972275], [88.85610962, 22.47000122], [88.85610962, 22.47055626], [88.85639191, 22.47083282], [88.85639191, 22.47139168], [88.85666656, 22.47166634], [88.85666656, 22.47221375], [88.85694122, 22.47250175], [88.85721588, 22.47250175], [88.85832977, 22.47139168], [88.85832977, 22.47083282], [88.85861206, 22.47055626], [88.85861206, 22.4702816], [88.85888672, 22.47000122], [88.85888672, 22.46972275], [88.85916901, 22.46944427]]], [[[87.93805695, 22.39666939], [87.93776703, 22.39666939], [87.9375, 22.39694977], [87.9375, 22.39749908], [87.93722534, 22.39777946], [87.93723297, 22.39833069], [87.93694305, 22.39860916], [87.93694305, 22.39888763], [87.9366684, 22.39916611], [87.9366684, 22.39944458], [87.93638611, 22.39972305], [87.93638611, 22.39998817], [87.93611145, 22.40027809], [87.93611145, 22.40083313], [87.93583679, 22.4011116], [87.93583679, 22.40250015], [87.93554688, 22.40278053], [87.93554688, 22.40361023], [87.93527985, 22.40389061], [87.93527985, 22.40500069], [87.93499756, 22.40527725], [87.93499756, 22.40583038], [87.9347229, 22.4061203], [87.9347229, 22.40639114], [87.93444824, 22.4066658], [87.93444824, 22.40694046], [87.9338913, 22.40750122], [87.9338913, 22.40777969], [87.9327774, 22.40888977], [87.9327774, 22.40916634], [87.93333435, 22.40972137], [87.93499756, 22.40805435], [87.93499756, 22.40777969], [87.93583679, 22.40694046], [87.93583679, 22.4066658], [87.93611145, 22.40639114], [87.93611145, 22.40583038], [87.93638611, 22.40555573], [87.93638611, 22.40500069], [87.93667603, 22.40472031], [87.9366684, 22.40444374], [87.93694305, 22.40416718], [87.93694305, 22.40389061], [87.93723297, 22.40361023], [87.93722534, 22.40305519], [87.9375, 22.40277863], [87.9375, 22.40195274], [87.93776703, 22.40167046], [87.93776703, 22.40055084], [87.93805695, 22.40027809], [87.93805695, 22.39971924], [87.9383316, 22.39944458], [87.9383316, 22.39805794], [87.93860626, 22.39777946], [87.93860626, 22.39722061], [87.93805695, 22.39666939]]], [[[88.86777496, 22.41083336], [88.86805725, 22.41055489], [88.86888885, 22.41055489], [88.8694458, 22.41000175], [88.86972046, 22.41000175], [88.8713913, 22.40833092], [88.87166595, 22.40833473], [88.87277985, 22.40722656], [88.8730545, 22.40722656], [88.87361145, 22.40666771], [88.87388611, 22.40667152], [88.8741684, 22.40639305], [88.8741684, 22.40612221], [88.87444305, 22.40583229], [88.87444305, 22.40555573], [88.8741684, 22.40528488], [88.87304688, 22.40528488], [88.87277985, 22.40500069], [88.87248993, 22.40528488], [88.87194824, 22.40527725], [88.8713913, 22.40583229], [88.8713913, 22.40639305], [88.87110901, 22.40666771], [88.87110901, 22.40694427], [88.87082672, 22.40722084], [88.87083435, 22.40749931], [88.87000275, 22.40833473], [88.86888885, 22.40833092], [88.86805725, 22.40918159], [88.86777496, 22.40916634], [88.86750031, 22.40944481], [88.86722565, 22.40944481], [88.86667633, 22.41000175], [88.86638641, 22.41000175], [88.86611176, 22.41028023], [88.86611176, 22.41083336], [88.86777496, 22.41083336]]], [[[88.91889954, 22.42653275], [88.91889191, 22.42527962], [88.91860962, 22.42500114], [88.91860962, 22.42472267], [88.91777802, 22.42389107], [88.91750336, 22.42389107], [88.91722107, 22.42361259], [88.91638947, 22.42361259], [88.91622925, 22.42334938], [88.91584778, 22.42333031], [88.91542053, 22.42329025], [88.91501617, 22.42311287], [88.91448975, 22.42305946], [88.91394043, 22.42302132], [88.91343689, 22.42284203], [88.91320801, 22.42278099], [88.91295624, 22.42280006], [88.91262054, 22.42292213], [88.91230011, 22.42305183], [88.91195679, 22.42318535], [88.91163635, 22.4233799], [88.91143036, 22.42369652], [88.91139221, 22.42416954], [88.91145325, 22.42472267], [88.91168213, 22.42521095], [88.91200256, 22.42558289], [88.91240692, 22.42580223], [88.9128418, 22.42591286], [88.91313171, 22.42616081], [88.91330719, 22.42648125], [88.91353607, 22.42667961], [88.91420746, 22.42646027], [88.91490173, 22.42630196], [88.91557312, 22.42646027], [88.91599274, 22.42672157], [88.91607666, 22.42710495], [88.91607666, 22.42753029], [88.91649628, 22.42802811], [88.91678619, 22.4287014], [88.91719055, 22.42902946], [88.91732025, 22.42892456], [88.91738129, 22.42886925], [88.91765594, 22.42862892], [88.9180069, 22.42834282], [88.91835022, 22.4278965], [88.91867065, 22.42741966], [88.91889954, 22.42653275]]], [[[87.92568207, 22.42482948], [87.92539215, 22.42469406], [87.92395782, 22.42561913], [87.92266083, 22.42657089], [87.92194366, 22.42764282], [87.92064667, 22.42831421], [87.91978455, 22.42871666], [87.91921234, 22.42910957], [87.9193573, 22.42951965], [87.91979218, 22.4297905], [87.92076874, 22.42923927], [87.9212265, 22.42897987], [87.92223358, 22.42831421], [87.92337799, 22.42791176], [87.92395782, 22.42737579], [87.92481995, 22.42683983], [87.92539215, 22.42617035], [87.92568207, 22.42482948]]], [[[88.89389038, 22.37055969], [88.89360809, 22.37083244], [88.89305878, 22.37083244], [88.89277649, 22.37111092], [88.89250183, 22.37111092], [88.89221954, 22.37138748], [88.89138794, 22.37138748], [88.89111328, 22.37167168], [88.88964844, 22.37166595], [88.88964844, 22.37260246], [88.88993835, 22.37301064], [88.89022064, 22.37314034], [88.89022064, 22.37354088], [88.89051056, 22.37448311], [88.89051056, 22.37488556], [88.89065552, 22.37542152], [88.8897934, 22.37622261], [88.88949585, 22.37622261], [88.88893127, 22.37635994], [88.88792419, 22.37635612], [88.88735199, 22.37649345], [88.88576508, 22.37649345], [88.88562775, 22.37595558], [88.88548279, 22.37554932], [88.88548279, 22.37528229], [88.88576508, 22.37448311], [88.88591003, 22.37421227], [88.88634491, 22.37367821], [88.8866272, 22.37341118], [88.8867569, 22.37260246], [88.88639069, 22.37249756], [88.8861084, 22.37277985], [88.88569641, 22.37332916], [88.88540649, 22.37376976], [88.88516998, 22.37419319], [88.88496399, 22.37459755], [88.884758, 22.37500191], [88.88459015, 22.37550163], [88.88439178, 22.37608147], [88.88414001, 22.37655067], [88.88388062, 22.37695122], [88.88361359, 22.37731552], [88.88336182, 22.3776722], [88.88316345, 22.37808418], [88.88298035, 22.3785305], [88.88272095, 22.37894058], [88.88246918, 22.37933922], [88.88217163, 22.37968254], [88.88184357, 22.37999916], [88.88153076, 22.38033485], [88.88131714, 22.38076973], [88.88104248, 22.38120079], [88.88074493, 22.38164711], [88.88034058, 22.38203621], [88.87999725, 22.3824501], [88.87968445, 22.38282585], [88.87943268, 22.3831501], [88.87919617, 22.38339043], [88.8789978, 22.38363075], [88.87879944, 22.38386917], [88.87856293, 22.38408089], [88.87825775, 22.38428307], [88.87804413, 22.38451958], [88.87785339, 22.38475609], [88.87768555, 22.38498688], [88.87751007, 22.38520241], [88.87731171, 22.38547707], [88.87709045, 22.38589287], [88.87684631, 22.38639259], [88.87660217, 22.38691711], [88.87666321, 22.38750267], [88.8767395, 22.38816261], [88.87696075, 22.38876152], [88.87719727, 22.38924217], [88.87737274, 22.38970947], [88.87753296, 22.39018059], [88.8777771, 22.39065552], [88.8780365, 22.39119148], [88.87821198, 22.39180374], [88.87847137, 22.39234543], [88.87879944, 22.39282036], [88.87909698, 22.39331055], [88.87930298, 22.39367294], [88.87944031, 22.39392281], [88.87957764, 22.39418221], [88.8797226, 22.3944416], [88.87985992, 22.39472771], [88.87999725, 22.39504051], [88.88011932, 22.39536858], [88.88026428, 22.39565468], [88.88034821, 22.39598846], [88.88044739, 22.39653206], [88.88058472, 22.39707756], [88.88065338, 22.39764214], [88.88084412, 22.3981514], [88.88108063, 22.39863205], [88.8812561, 22.39917183], [88.88141632, 22.39972496], [88.88165283, 22.40023232], [88.88183594, 22.40073967], [88.88197327, 22.40125275], [88.88217926, 22.40171814], [88.88222504, 22.40222359], [88.88224792, 22.40272331], [88.8822937, 22.40319061], [88.88218689, 22.40363693], [88.88189697, 22.40400124], [88.88150787, 22.40432167], [88.8811264, 22.40463066], [88.88079071, 22.40499115], [88.88044739, 22.40533257], [88.87993622, 22.40563011], [88.87943268, 22.40594673], [88.87888336, 22.40624046], [88.87828064, 22.4065609], [88.87761688, 22.4068203], [88.87692261, 22.40710258], [88.87621307, 22.40731812], [88.87558746, 22.40754128], [88.87504578, 22.40779305], [88.87452698, 22.40806007], [88.87403107, 22.40834808], [88.87356567, 22.40865707], [88.87312317, 22.40897942], [88.87272644, 22.40937233], [88.87232971, 22.40973091], [88.87194061, 22.41007042], [88.87155151, 22.41037941], [88.87113953, 22.41061974], [88.87075806, 22.41085243], [88.87039948, 22.41106987], [88.87003326, 22.41123009], [88.86965179, 22.4113903], [88.8692627, 22.41155052], [88.86880493, 22.41169548], [88.86833191, 22.41189194], [88.86782837, 22.41193199], [88.86730957, 22.41194916], [88.8667984, 22.41194916], [88.86628723, 22.41194916], [88.86582947, 22.41193199], [88.86541748, 22.41194916], [88.86505127, 22.41196632], [88.86470032, 22.41205406], [88.86430359, 22.41202736], [88.86386871, 22.4120121], [88.86341095, 22.41220284], [88.86292267, 22.41238213], [88.86237335, 22.41254997], [88.8618927, 22.41283989], [88.86148071, 22.41321182], [88.86116028, 22.41356277], [88.86086273, 22.41391373], [88.860672, 22.41431999], [88.86045074, 22.41469002], [88.86018372, 22.41501236], [88.85991669, 22.41535378], [88.85964203, 22.41568184], [88.85942841, 22.41612053], [88.85920715, 22.41657066], [88.85890961, 22.41698837], [88.8586731, 22.41743469], [88.85848236, 22.41790009], [88.85816956, 22.41827011], [88.85793304, 22.41873169], [88.85767365, 22.41918945], [88.85748291, 22.41965485], [88.85726929, 22.42006111], [88.85719299, 22.42049217], [88.85700989, 22.42081451], [88.85695648, 22.42119789], [88.85668182, 22.4216404], [88.85639191, 22.42218971], [88.85612488, 22.42278099], [88.85597992, 22.42339134], [88.8560791, 22.42400169], [88.85610962, 22.42457008], [88.85608673, 22.42511177], [88.85595703, 22.42564011], [88.85581207, 22.42621803], [88.85559845, 22.42679024], [88.85558319, 22.42745018], [88.85565948, 22.42810249], [88.85558319, 22.42852211], [88.8555603, 22.42891121], [88.85555267, 22.42928505], [88.85555267, 22.42966461], [88.8555603, 22.43005943], [88.85555267, 22.43049049], [88.85552979, 22.43098259], [88.8553772, 22.43153381], [88.85530853, 22.43219185], [88.85527039, 22.43281937], [88.85517883, 22.43340111], [88.85492706, 22.43401146], [88.85482788, 22.43473244], [88.8547821, 22.4354229], [88.85473633, 22.43597984], [88.85472107, 22.43646049], [88.85472107, 22.43692207], [88.8547287, 22.43740654], [88.8547821, 22.43792152], [88.85500336, 22.43840981], [88.85529327, 22.43885422], [88.85566711, 22.4391613], [88.85607147, 22.43943977], [88.85649109, 22.43970299], [88.85690308, 22.43997002], [88.85728455, 22.44025612], [88.85768127, 22.44053078], [88.85810852, 22.44074821], [88.8585434, 22.44091988], [88.85890961, 22.44115257], [88.85919952, 22.44143867], [88.85944366, 22.44179344], [88.85970306, 22.44219017], [88.85999298, 22.44262123], [88.86027527, 22.44308281], [88.86051178, 22.44356155], [88.86064911, 22.44407082], [88.8608017, 22.44454575], [88.86090088, 22.44502068], [88.86104584, 22.44548225], [88.86103821, 22.44593811], [88.86089325, 22.44637108], [88.86083984, 22.4467907], [88.86080933, 22.44717216], [88.86071014, 22.44748116], [88.86057281, 22.44777107], [88.86044312, 22.44807053], [88.86030579, 22.4484005], [88.8602066, 22.4487896], [88.86003876, 22.4491539], [88.85988617, 22.44955444], [88.85971069, 22.44995689], [88.85948944, 22.45038033], [88.85927582, 22.45081139], [88.85904694, 22.45119286], [88.8588028, 22.45150948], [88.85856628, 22.45184135], [88.85830688, 22.45218086], [88.85797119, 22.45255089], [88.8575592, 22.45293999], [88.85719299, 22.45345116], [88.85697937, 22.45412827], [88.8568573, 22.45482063], [88.85675812, 22.45548248], [88.85683441, 22.45608711], [88.856987, 22.45667076], [88.85720062, 22.45718956], [88.85739899, 22.45763969], [88.85761261, 22.45799065], [88.85783386, 22.4582653], [88.85805511, 22.45854568], [88.85830688, 22.45888138], [88.8585968, 22.45927238], [88.8588562, 22.45971107], [88.85906219, 22.46014214], [88.85916901, 22.46129036], [88.85974121, 22.46323586], [88.86013031, 22.46608162], [88.86022949, 22.46661186], [88.8602829, 22.46710014], [88.86029053, 22.4675827], [88.86034393, 22.46805191], [88.86044312, 22.46851158], [88.86031342, 22.46895027], [88.86019897, 22.46936226], [88.86003876, 22.46973228], [88.85995483, 22.47014236], [88.85978699, 22.47051048], [88.85968018, 22.47091675], [88.85949707, 22.4712925], [88.85941315, 22.47168159], [88.85926056, 22.47197723], [88.85912323, 22.47224808], [88.85894012, 22.4724884], [88.85884094, 22.47278023], [88.8586731, 22.47303009], [88.85856628, 22.47337151], [88.85842133, 22.47370911], [88.85834503, 22.47410965], [88.85832977, 22.4745636], [88.8583374, 22.47504997], [88.85837555, 22.4755497], [88.85848999, 22.47603226], [88.85838318, 22.47652245], [88.85823822, 22.47701073], [88.85814667, 22.47751045], [88.85823822, 22.47800255], [88.85830688, 22.47844124], [88.8583374, 22.47884941], [88.8583374, 22.47927475], [88.8583374, 22.4797802], [88.85832977, 22.48040199], [88.8583374, 22.48111153], [88.85839081, 22.48184013], [88.85858154, 22.48252869], [88.8588028, 22.48312187], [88.85923767, 22.48344231], [88.85971069, 22.48354912], [88.86009979, 22.48357964], [88.86038971, 22.48361015], [88.86064148, 22.48381042], [88.86092377, 22.48396873], [88.86125183, 22.4840641], [88.86161804, 22.48404121], [88.86196899, 22.48397255], [88.86226654, 22.48393059], [88.86252594, 22.48404121], [88.86274719, 22.48426819], [88.86299133, 22.48440742], [88.86328888, 22.48452568], [88.86364746, 22.48466682], [88.86408234, 22.48472214], [88.86455536, 22.48479462], [88.86499786, 22.48500252], [88.86543274, 22.48526955], [88.8658905, 22.48552513], [88.86638641, 22.48568344], [88.86683655, 22.48586082], [88.86721802, 22.48613167], [88.86753082, 22.4864521], [88.86773682, 22.48687172], [88.86776733, 22.48737144], [88.86773682, 22.48786736], [88.86752319, 22.48829079], [88.86717987, 22.48862267], [88.86670685, 22.48885155], [88.8662262, 22.48901176], [88.86588287, 22.48918915], [88.8655014, 22.48943138], [88.86507416, 22.48967743], [88.86460114, 22.48999977], [88.864151, 22.4903717], [88.86380768, 22.49081993], [88.86351776, 22.49124718], [88.86332703, 22.49140167], [88.86300659, 22.49175262], [88.86280823, 22.4920311], [88.86250305, 22.49240494], [88.86213684, 22.49294281], [88.86210632, 22.49329376], [88.86186981, 22.49378014], [88.86171722, 22.49440193], [88.86159515, 22.49505424], [88.86161804, 22.49567795], [88.8615799, 22.49626541], [88.86146545, 22.49682426], [88.86144257, 22.49736977], [88.86143494, 22.49785805], [88.86142731, 22.49827003], [88.86139679, 22.49863815], [88.86132813, 22.49903107], [88.86110687, 22.49941063], [88.86073303, 22.49981117], [88.86023712, 22.50025749], [88.85965729, 22.50064468], [88.85912323, 22.50103951], [88.85858917, 22.50138283], [88.85804749, 22.50160027], [88.85746002, 22.50173759], [88.85688782, 22.50187111], [88.85629272, 22.50193977], [88.85569763, 22.50201225], [88.8551178, 22.50213051], [88.85453796, 22.5022049], [88.85266113, 22.50217247], [88.85223389, 22.50217247], [88.85144043, 22.50210762], [88.85108185, 22.50196838], [88.85072327, 22.50190544], [88.85029602, 22.50177193], [88.84964752, 22.50156975], [88.84921265, 22.50150108], [88.84871674, 22.50143623], [88.84763336, 22.50143623], [88.84720612, 22.50150108], [88.84570312, 22.50169945], [88.84526062, 22.50191116], [88.84513092, 22.50204277], [88.84497833, 22.5023098], [88.84461975, 22.50284004], [88.84446716, 22.50317955], [88.84403992, 22.50411797], [88.84390259, 22.50465202], [88.84390259, 22.50512123], [88.84382629, 22.50552177], [88.84368134, 22.50633049], [88.84361267, 22.5067997], [88.84361267, 22.50739861], [88.84403992, 22.50766945], [88.84429169, 22.50794029], [88.84467316, 22.50816154], [88.84481049, 22.50830269], [88.84516907, 22.50850105], [88.84545898, 22.50863075], [88.84624481, 22.50876808], [88.84804535, 22.50876808], [88.8483963, 22.50883484], [88.84928894, 22.50901222], [88.84972382, 22.50900841], [88.85001373, 22.50914192], [88.85037231, 22.50914192], [88.85108948, 22.50907707], [88.85217285, 22.50893974], [88.85256958, 22.50897026], [88.85364532, 22.50896645], [88.85436249, 22.5090313], [88.85486603, 22.50910187], [88.85521698, 22.50923157], [88.85559082, 22.50937271], [88.85630798, 22.50977135], [88.85666656, 22.50997353], [88.85709381, 22.51077461], [88.85795593, 22.51197815], [88.8585968, 22.51387215], [88.85869598, 22.51445961], [88.85881805, 22.51498413], [88.85890198, 22.51546478], [88.8589859, 22.51589012], [88.85912323, 22.51625824], [88.85922241, 22.51662254], [88.85943604, 22.51694298], [88.85943604, 22.51751137], [88.85972595, 22.51777649], [88.85972595, 22.51833344], [88.86000061, 22.51860809], [88.86000061, 22.51889229], [88.8602829, 22.51889229], [88.86054993, 22.51917076], [88.86138916, 22.51916885], [88.86166382, 22.51944542], [88.86187744, 22.51942253], [88.86235809, 22.51955223], [88.8628006, 22.5197506], [88.86325073, 22.51999092], [88.86373901, 22.52020073], [88.8642807, 22.52034187], [88.86478424, 22.52056122], [88.86527252, 22.52079582], [88.86580658, 22.52095222], [88.86633301, 22.52115059], [88.86681366, 22.52139282], [88.86724091, 22.52166939], [88.86759186, 22.52197075], [88.86785126, 22.52229118], [88.86806488, 22.52260017], [88.8682785, 22.52293968], [88.86840057, 22.52339172], [88.86855316, 22.5239315], [88.86859894, 22.52458191], [88.86855316, 22.52524185], [88.86839294, 22.52581978], [88.86766052, 22.52815056], [88.86715698, 22.53049278], [88.86730194, 22.5322361], [88.86730194, 22.53451157], [88.86781311, 22.53738976], [88.86830902, 22.5392704], [88.86895752, 22.54047394], [88.86923981, 22.54068375], [88.86966705, 22.5408802], [88.87024689, 22.54115105], [88.87068176, 22.54128075], [88.87125397, 22.5413456], [88.87182617, 22.54141426], [88.87166595, 22.5411129], [88.8713913, 22.54083061], [88.87110901, 22.54083443], [88.87083435, 22.54055405], [88.87055206, 22.54055977], [88.8702774, 22.5402813], [88.87000275, 22.5402813], [88.86972046, 22.54000282], [88.86972046, 22.53972054], [88.8694458, 22.53944588], [88.8694458, 22.53805733], [88.8702774, 22.53722382], [88.8702774, 22.53666878], [88.8694458, 22.53582954], [88.8694458, 22.53555489], [88.86805725, 22.53416634], [88.86805725, 22.53306007], [88.86833191, 22.5327816], [88.86833191, 22.53251076], [88.86888885, 22.53194237], [88.86888885, 22.5316658], [88.86915588, 22.53139305], [88.86915588, 22.53083229], [88.8694458, 22.53055573], [88.87000275, 22.53056145], [88.87082672, 22.53139305], [88.8713913, 22.53139305], [88.87166595, 22.53111076], [88.87194824, 22.53111076], [88.8722229, 22.53138733], [88.8722229, 22.53194618], [88.87277985, 22.53194427], [88.87288666, 22.5320549], [88.8730545, 22.53222466], [88.87333679, 22.53222084], [88.87333679, 22.5327816], [88.87361145, 22.53305626], [88.87361145, 22.53360939], [88.87388611, 22.53389168], [88.87388611, 22.53471947], [88.8741684, 22.53500175], [88.8741684, 22.53527832], [88.87458801, 22.53569794], [88.875, 22.53611374], [88.87555695, 22.53611374], [88.87695313, 22.53750038], [88.8769455, 22.53777695], [88.87750244, 22.53832054], [88.87750244, 22.53861046], [88.87610626, 22.54000282], [88.87610626, 22.53972054], [88.87555695, 22.5402813], [88.8758316, 22.54055405], [88.87587738, 22.54082489], [88.87610626, 22.5411129], [88.87750244, 22.5411129], [88.87800598, 22.54155159], [88.87880707, 22.54306984], [88.87908173, 22.54332542], [88.87922668, 22.54346275], [88.87970734, 22.54384041], [88.88022614, 22.54416084], [88.88072205, 22.5444603], [88.88105011, 22.54491234], [88.88126373, 22.54541397], [88.8814621, 22.54588127], [88.88173676, 22.54627037], [88.88204956, 22.54661179], [88.88239288, 22.54692078], [88.88273621, 22.54721832], [88.8830719, 22.54754066], [88.88334656, 22.54790306], [88.88362122, 22.54828072], [88.88388824, 22.54869461], [88.8841629, 22.54911232], [88.88449097, 22.54945374], [88.88487244, 22.54972267], [88.88523865, 22.54999161], [88.88552856, 22.55033112], [88.88572693, 22.55072212], [88.88594818, 22.55105782], [88.88617706, 22.55133247], [88.88640594, 22.55156136], [88.8866272, 22.55179024], [88.88678741, 22.55207062], [88.88696289, 22.55240059], [88.88722229, 22.55278206], [88.88804626, 22.55362129], [88.88833618, 22.55389214], [88.88861084, 22.55389214], [88.88889313, 22.55417061], [88.88944244, 22.55417061], [88.88999939, 22.55362129], [88.89026642, 22.55333138], [88.89027405, 22.55305481], [88.88944244, 22.5522213], [88.88944244, 22.55194664], [88.88916779, 22.55166817], [88.88889313, 22.55167389], [88.88861084, 22.55138969], [88.88861084, 22.55027962], [88.88889313, 22.55000114], [88.88861084, 22.54972267], [88.88916779, 22.54916573], [88.88916779, 22.54889107], [88.8897171, 22.54833031], [88.88999939, 22.54833412], [88.89055634, 22.54777718], [88.89083099, 22.5477829], [88.89167023, 22.54861259], [88.89167023, 22.54889107], [88.89193726, 22.54916954], [88.89250183, 22.54916954], [88.89277649, 22.54889107], [88.89305878, 22.54889107], [88.89332581, 22.54861259], [88.89389038, 22.54916573], [88.89389038, 22.5494442], [88.89417267, 22.54972267], [88.89416504, 22.55027962], [88.89444733, 22.55055809], [88.89444733, 22.55083466], [88.89472198, 22.55111122], [88.89472198, 22.55167389], [88.89554596, 22.55249977], [88.89554596, 22.55278206], [88.89472198, 22.55362129], [88.89488983, 22.55418968], [88.89546204, 22.55417061], [88.89588928, 22.55389977], [88.89620209, 22.55356026], [88.89640045, 22.55314064], [88.89654541, 22.55275726], [88.89663696, 22.55239296], [88.89665985, 22.55204201], [88.89669037, 22.55175209], [88.89682007, 22.55153084], [88.89691162, 22.55131149], [88.8969574, 22.55104637], [88.89704895, 22.55076027], [88.89717102, 22.55045128], [88.89726257, 22.55014801], [88.89769745, 22.54886055], [88.89797211, 22.54811859], [88.89878082, 22.54745865], [88.89906311, 22.54754066], [88.89925385, 22.54747391], [88.89938354, 22.54743195], [88.89975739, 22.5471611], [88.90011597, 22.54678154], [88.90035248, 22.54632759], [88.90048218, 22.54585266], [88.90049744, 22.54537964], [88.9004364, 22.54490089], [88.90026093, 22.54442406], [88.89985657, 22.54401207], [88.89981079, 22.54374123], [88.89993286, 22.54347038], [88.8999939, 22.54307938], [88.9000473, 22.54260254], [88.90022278, 22.54207039], [88.90027618, 22.54146004], [88.90033722, 22.5408535], [88.90055847, 22.54034996], [88.90083313, 22.53987312], [88.90106964, 22.53938103], [88.90126801, 22.53890038], [88.901474, 22.53849792], [88.90177155, 22.53820229], [88.90211487, 22.53777695], [88.90248108, 22.53725815], [88.90273285, 22.53673172], [88.90278625, 22.53614807], [88.90278625, 22.53557014], [88.90277863, 22.53502655], [88.90267944, 22.53451157], [88.90248108, 22.53406143], [88.90222168, 22.53365517], [88.90194702, 22.53324318], [88.90171814, 22.53276253], [88.9016571, 22.53211021], [88.90167999, 22.53138161], [88.90176392, 22.5306263], [88.90195465, 22.52989006], [88.9021759, 22.5291729], [88.90228271, 22.52845955], [88.90237427, 22.52782822], [88.90232086, 22.52728081], [88.90235138, 22.52685928], [88.90249634, 22.52652168], [88.90273285, 22.52615547], [88.90296173, 22.52564621], [88.90322876, 22.52513123], [88.90358734, 22.52474785], [88.90393829, 22.5243206], [88.90441895, 22.52392006], [88.90489197, 22.52349281], [88.90525055, 22.52296829], [88.90553284, 22.52240753], [88.9057312, 22.5218029], [88.90577698, 22.52113342], [88.90569305, 22.52052116], [88.90548706, 22.52010155], [88.9052124, 22.51976967], [88.90487671, 22.5194416], [88.90454865, 22.51905441], [88.90425873, 22.51852989], [88.9039917, 22.51792908], [88.90364838, 22.51740074], [88.90368652, 22.51696968], [88.90383148, 22.51650238], [88.90388489, 22.51589775], [88.90387726, 22.51521111], [88.90387726, 22.5144825], [88.90386963, 22.51376724], [88.90390015, 22.51305962], [88.90395355, 22.5123539], [88.903862, 22.51156807], [88.90364838, 22.51080132], [88.90357208, 22.51000595], [88.90335083, 22.50930023], [88.90318298, 22.50863075], [88.90305328, 22.50834274], [88.90305328, 22.50722313], [88.90277863, 22.50694466], [88.90305328, 22.50666618], [88.90305328, 22.50556946], [88.9033432, 22.50528145], [88.9033432, 22.50444221], [88.90277863, 22.50388718], [88.90194702, 22.5038929], [88.90083313, 22.50500298], [88.90083313, 22.50528145], [88.9016571, 22.50611305], [88.90166473, 22.50666618], [88.90110779, 22.50722313], [88.90083313, 22.50722313], [88.90055847, 22.5075016], [88.90027618, 22.5075016], [88.89916992, 22.50861168], [88.89833069, 22.50861168], [88.89694214, 22.50722313], [88.89694214, 22.50694466], [88.89638519, 22.50639153], [88.89638519, 22.50527954], [88.89554596, 22.50444221], [88.89555359, 22.50388718], [88.89527893, 22.50361061], [88.89527893, 22.50333214], [88.89527893, 22.50194359], [88.89499664, 22.50166893], [88.89499664, 22.5008297], [88.89638519, 22.49944305], [88.89666748, 22.49944305], [88.89698029, 22.49913216], [88.89778137, 22.49833488], [88.89778137, 22.49805641], [88.89805603, 22.49778175], [88.89861298, 22.49778175], [88.89916992, 22.4972229], [88.89971924, 22.49722481], [88.90000153, 22.49694633], [88.90055847, 22.49694443], [88.90222168, 22.49860954], [88.90222168, 22.49889183], [88.90249634, 22.49916649], [88.90249634, 22.49944305], [88.90277863, 22.49972343], [88.90305328, 22.49972343], [88.90333557, 22.50000191], [88.90510559, 22.5004406], [88.90525818, 22.49971962], [88.90529633, 22.49903488], [88.9052887, 22.49839211], [88.90523529, 22.49778938], [88.90499878, 22.49728966], [88.90471649, 22.49682045], [88.90442657, 22.49638176], [88.90405273, 22.4960041], [88.90361023, 22.49565315], [88.90315247, 22.49529839], [88.90265656, 22.49497032], [88.90220642, 22.49459267], [88.90172577, 22.49425125], [88.90120697, 22.49395943], [88.90080261, 22.49364662], [88.90040588, 22.49333954], [88.8999939, 22.49305534], [88.89955902, 22.49278069], [88.89913177, 22.49250221], [88.89874268, 22.49221992], [88.89861298, 22.49222374], [88.89833069, 22.49194527], [88.89778137, 22.4919529], [88.89737701, 22.49154663], [88.89715576, 22.49132156], [88.89694214, 22.49111176], [88.89694214, 22.49083328], [88.89416504, 22.48805618], [88.89417267, 22.48777962], [88.89305878, 22.48666954], [88.89305878, 22.48639107], [88.89277649, 22.48611259], [88.89277649, 22.48528099], [88.89250183, 22.48500252], [88.89232635, 22.48441124], [88.89227295, 22.48389244], [88.89225769, 22.48337746], [88.89231873, 22.48289299], [88.89244843, 22.48243523], [88.89261627, 22.48199272], [88.89290619, 22.4816227], [88.89331055, 22.48129082], [88.89372253, 22.48095131], [88.89398193, 22.4805603], [88.89420319, 22.48018837], [88.89441681, 22.47985268], [88.89457703, 22.47948265], [88.89476013, 22.4791317], [88.89505005, 22.47881126], [88.89531708, 22.47837257], [88.8956604, 22.47795486], [88.89593506, 22.47746658], [88.89610291, 22.47697258], [88.89624023, 22.476511], [88.89634705, 22.47600174], [88.89652252, 22.47548294], [88.8966217, 22.47493172], [88.89659119, 22.47442436], [88.89637756, 22.47402573], [88.8961792, 22.4736805], [88.89617157, 22.47336388], [88.89633179, 22.47302055], [88.89636993, 22.47246933], [88.89630127, 22.47184944], [88.89608002, 22.47133064], [88.89588165, 22.47087288], [88.89570618, 22.47048187], [88.89551544, 22.47023964], [88.89503479, 22.46975517], [88.89476776, 22.46946335], [88.89447021, 22.46916389], [88.89414978, 22.46881294], [88.89377594, 22.46839905], [88.89338684, 22.46797943], [88.89305878, 22.46751595], [88.89277649, 22.46701241], [88.89250183, 22.46647263], [88.89228821, 22.46593475], [88.89232635, 22.46535301], [88.89252472, 22.4648571], [88.89277649, 22.46446037], [88.89306641, 22.46411705], [88.89343262, 22.46380043], [88.89388275, 22.4634304], [88.89430237, 22.46306229], [88.89472198, 22.46271324], [88.89514923, 22.46237373], [88.89556885, 22.46209145], [88.89599609, 22.46173286], [88.89633179, 22.46119118], [88.89665985, 22.46063042], [88.89698792, 22.46012115], [88.89732361, 22.45967865], [88.89749908, 22.45919228], [88.89762115, 22.45872307], [88.89772034, 22.45827675], [88.897789, 22.45782089], [88.89789581, 22.45739174], [88.89798737, 22.45696259], [88.8980484, 22.45652008], [88.89808655, 22.45607185], [88.89818573, 22.45564079], [88.89808655, 22.45520973], [88.89813995, 22.45479965], [88.89829254, 22.45440102], [88.89837646, 22.45393944], [88.8985672, 22.45353127], [88.89862823, 22.45306969], [88.89872742, 22.45265007], [88.89890289, 22.45229149], [88.89910126, 22.45197105], [88.89916229, 22.45158958], [88.89916992, 22.45121956], [88.89920807, 22.45088005], [88.89936829, 22.4505825], [88.89939117, 22.4502182], [88.89924622, 22.44979286], [88.89918518, 22.44937706], [88.89924622, 22.44894981], [88.89940643, 22.44854164], [88.89948273, 22.44810295], [88.89962769, 22.44772148], [88.89971161, 22.4472847], [88.8997879, 22.4467907], [88.90000153, 22.44632149], [88.90023041, 22.44585228], [88.90031433, 22.44539452], [88.90046692, 22.4450779], [88.90055847, 22.44483948], [88.90065765, 22.44461823], [88.9008255, 22.44440079], [88.90104675, 22.44413567], [88.90132904, 22.44389153], [88.90161133, 22.44366264], [88.90184784, 22.44341087], [88.90200806, 22.44309044], [88.90220642, 22.44282722], [88.90238953, 22.44252968], [88.90263367, 22.44225693], [88.90297699, 22.44201279], [88.90331268, 22.44167137], [88.90361023, 22.44125557], [88.90388489, 22.44080162], [88.90413666, 22.44032097], [88.9043045, 22.43981361], [88.90460205, 22.43941689], [88.9048996, 22.43901253], [88.90527344, 22.43865585], [88.90565491, 22.43824196], [88.90602875, 22.43779182], [88.90636444, 22.43736649], [88.90661621, 22.43697166], [88.90685272, 22.43662834], [88.90703583, 22.43627167], [88.90722656, 22.43589973], [88.90744781, 22.43550301], [88.90762329, 22.43506622], [88.90779877, 22.43460846], [88.90801239, 22.43415642], [88.90805817, 22.43364143], [88.90805054, 22.43310165], [88.90799713, 22.4325695], [88.90792084, 22.43204308], [88.90783691, 22.43152046], [88.90776825, 22.43102074], [88.9076767, 22.43058777], [88.90756989, 22.43019295], [88.9074707, 22.42979431], [88.90731049, 22.42939186], [88.90714264, 22.42892647], [88.90688324, 22.42844963], [88.90648651, 22.4279995], [88.90611267, 22.4274807], [88.90578461, 22.42689896], [88.90545654, 22.42631912], [88.90512085, 22.42579079], [88.90478516, 22.42528915], [88.90445709, 22.42482567], [88.90416718, 22.42435265], [88.90387726, 22.42386055], [88.90361023, 22.42336464], [88.90332794, 22.42287254], [88.9030838, 22.42247963], [88.90305328, 22.42222595], [88.90277863, 22.42194557], [88.90277863, 22.4197216], [88.90249634, 22.41944695], [88.90249634, 22.41777992], [88.90278625, 22.41750145], [88.90277863, 22.41472435], [88.90303802, 22.41444588], [88.90315247, 22.41407967], [88.90332031, 22.41373444], [88.90345001, 22.41335869], [88.90363312, 22.41301155], [88.90387726, 22.41269112], [88.90413666, 22.41233253], [88.90434265, 22.41192055], [88.9045105, 22.41167259], [88.90473938, 22.4114666], [88.90502167, 22.41125298], [88.90535736, 22.41104317], [88.9057312, 22.41082191], [88.90611267, 22.4105835], [88.90654755, 22.41039848], [88.90699768, 22.41021156], [88.90751648, 22.40998268], [88.90804291, 22.40971184], [88.90854645, 22.40944862], [88.90905762, 22.40921974], [88.90960693, 22.40912628], [88.91010284, 22.40892029], [88.91062164, 22.40880013], [88.91107178, 22.40865135], [88.9115448, 22.40858269], [88.91197968, 22.40844917], [88.91243744, 22.40829277], [88.91291046, 22.40808487], [88.91345978, 22.40793419], [88.91407013, 22.40775871], [88.91464996, 22.40753174], [88.9152298, 22.40736961], [88.91573334, 22.40718269], [88.91612244, 22.40694237], [88.91647339, 22.40670013], [88.91685486, 22.40647888], [88.91726685, 22.40623283], [88.91779327, 22.4059639], [88.91833496, 22.40564728], [88.91887665, 22.40525246], [88.91931152, 22.40474129], [88.91944122, 22.40472221], [88.92111206, 22.40305519], [88.92111206, 22.40278053], [88.92138672, 22.40250206], [88.92138672, 22.40167046], [88.92166901, 22.40139008], [88.92166901, 22.40055275], [88.92138672, 22.40027809], [88.92138672, 22.39971924], [88.92111206, 22.39944458], [88.92111206, 22.39916992], [88.91779327, 22.39583015], [88.91722107, 22.39583397], [88.91702271, 22.39550209], [88.91670227, 22.39511108], [88.91615295, 22.39487648], [88.91558838, 22.39458275], [88.91507721, 22.39419937], [88.91452026, 22.3938942], [88.91398621, 22.39363289], [88.91348267, 22.39346123], [88.91304016, 22.39331055], [88.9126358, 22.39312172], [88.91220093, 22.39306068], [88.91175842, 22.39305115], [88.91131592, 22.39302254], [88.91091919, 22.39288139], [88.91047668, 22.39279556], [88.90997314, 22.39277077], [88.90942383, 22.39273262], [88.90892029, 22.39260864], [88.90843964, 22.39246941], [88.9079895, 22.39231491], [88.90751648, 22.39221382], [88.90705109, 22.39208794], [88.90657806, 22.39192009], [88.90614319, 22.39167213], [88.90567017, 22.39138222], [88.9052124, 22.39105034], [88.90471649, 22.39074326], [88.90419006, 22.39043427], [88.90368652, 22.39008141], [88.90320587, 22.38971519], [88.90274048, 22.38932991], [88.90229797, 22.3889637], [88.90182495, 22.38866234], [88.90139008, 22.38837242], [88.90099335, 22.38809013], [88.90055847, 22.38785934], [88.90013885, 22.38763237], [88.89971924, 22.38739204], [88.89933777, 22.38715172], [88.89894104, 22.38692284], [88.89855194, 22.38670349], [88.89816284, 22.3864994], [88.89779663, 22.38625145], [88.89749146, 22.38591957], [88.89720154, 22.38554955], [88.89691162, 22.3851738], [88.89655304, 22.38486862], [88.89624023, 22.38457298], [88.89599609, 22.38422203], [88.89581299, 22.38396454], [88.89566803, 22.38372993], [88.89552307, 22.38352013], [88.89533997, 22.38328171], [88.89521027, 22.38298607], [88.89502716, 22.38269234], [88.89490509, 22.38233376], [88.89466095, 22.3819828], [88.89444733, 22.38156128], [88.89416504, 22.38111305], [88.89416504, 22.3797245], [88.89444733, 22.37944412], [88.89444733, 22.37888908], [88.89472198, 22.37861061], [88.89472198, 22.37806129], [88.89444733, 22.37778473], [88.89417267, 22.37806129], [88.89389038, 22.37806129], [88.89277649, 22.37917137], [88.89250183, 22.37916756], [88.89221954, 22.37944412], [88.89083099, 22.37944412], [88.89055634, 22.37916756], [88.8897171, 22.37917137], [88.88944244, 22.37889481], [88.88889313, 22.37889481], [88.88861084, 22.37861061], [88.88833618, 22.37861061], [88.88804626, 22.37833214], [88.88805389, 22.3777771], [88.88861084, 22.37722206], [88.88916779, 22.37722206], [88.88944244, 22.37694359], [88.88972473, 22.37694359], [88.88990784, 22.37713051], [88.88999939, 22.37722206], [88.89027405, 22.37722206], [88.89055634, 22.37694359], [88.89138794, 22.37694359], [88.89167023, 22.37666893], [88.89167023, 22.37639046], [88.89193726, 22.37611389], [88.89194489, 22.37500191], [88.89305878, 22.37389183], [88.89305878, 22.37307358], [88.89277649, 22.37278175], [88.89389038, 22.37167168], [88.89472198, 22.37166595], [88.89499664, 22.37194252], [88.89499664, 22.37277985], [88.89555359, 22.37333298], [88.89527893, 22.37361145], [88.89583588, 22.3741703], [88.89639282, 22.37361145], [88.89611053, 22.37333298], [88.89611053, 22.37305641], [88.89665985, 22.37167168], [88.89665985, 22.37111092], [88.89694214, 22.37083244], [88.89694214, 22.3702774], [88.89833069, 22.36889076], [88.89833069, 22.36861229], [88.89861298, 22.36833], [88.89861298, 22.36722183], [88.89805603, 22.36666679], [88.89778137, 22.36667061], [88.89694214, 22.36750221], [88.89665985, 22.36750221], [88.89611053, 22.36805534], [88.89611053, 22.36833], [88.89527893, 22.36916924], [88.89527893, 22.36944389], [88.89499664, 22.36972237], [88.89472198, 22.36972237], [88.89417267, 22.37028313], [88.89417267, 22.3705616], [88.89389038, 22.37055969]]], [[[88.93419647, 22.5640316], [88.93483734, 22.56388855], [88.93553925, 22.56369972], [88.93596649, 22.56343269], [88.93609619, 22.5631237], [88.93615723, 22.56279945], [88.93625641, 22.56245995], [88.93630219, 22.56208038], [88.93621063, 22.56169319], [88.93627167, 22.56133461], [88.93609619, 22.5612011], [88.93547058, 22.56139183], [88.93496704, 22.56163979], [88.93452454, 22.56189919], [88.93400574, 22.56211281], [88.93339539, 22.56214333], [88.93280792, 22.56192207], [88.93235779, 22.56162643], [88.93222046, 22.5616703], [88.93222046, 22.56139183], [88.93250275, 22.56110954], [88.93250275, 22.56083107], [88.9327774, 22.56055641], [88.93276978, 22.56028175], [88.93444824, 22.55861092], [88.93444824, 22.55833244], [88.93416595, 22.55805969], [88.9338913, 22.5580616], [88.93360901, 22.55778313], [88.93332672, 22.5580616], [88.93305206, 22.55805969], [88.9327774, 22.55833244], [88.93250275, 22.55833244], [88.9319458, 22.55888748], [88.9319458, 22.55916977], [88.93166351, 22.55944443], [88.93165588, 22.55971909], [88.93110657, 22.56028175], [88.93096924, 22.5605526], [88.93070984, 22.56087303], [88.9305191, 22.56125069], [88.93032074, 22.56163216], [88.9302063, 22.5620594], [88.93005371, 22.56241417], [88.93002319, 22.56278038], [88.93000793, 22.56312752], [88.93009186, 22.56342506], [88.93035889, 22.56361389], [88.93078613, 22.56367111], [88.9313736, 22.56372643], [88.93196869, 22.56394386], [88.93250275, 22.56403542], [88.93302917, 22.56396484], [88.93360138, 22.56406212], [88.93389893, 22.56404686], [88.93419647, 22.5640316]]], [[[88.93650818, 22.61913681], [88.93535614, 22.61982155], [88.93486023, 22.6206913], [88.93457031, 22.62149239], [88.93605042, 22.62157059], [88.93650818, 22.61913681]]], [[[88.78138733, 22.50056267], [88.78193665, 22.50000191], [88.78277588, 22.50000191], [88.78305817, 22.50028038], [88.78333282, 22.50028038], [88.78398132, 22.50008965], [88.78449249, 22.49976158], [88.78500366, 22.49950218], [88.7855835, 22.49934578], [88.78614044, 22.49919319], [88.78668976, 22.49910927], [88.7871933, 22.49892807], [88.78775024, 22.49889565], [88.78832245, 22.49894333], [88.78887177, 22.49912071], [88.78943634, 22.49921036], [88.79001617, 22.49932289], [88.7906189, 22.49919319], [88.7911911, 22.49905968], [88.79167175, 22.49885941], [88.79208374, 22.49861336], [88.79248047, 22.49835014], [88.79292297, 22.4980545], [88.793396, 22.4976902], [88.79384613, 22.49727058], [88.79429626, 22.49681473], [88.79479218, 22.49638176], [88.79522705, 22.49592018], [88.79554749, 22.49543381], [88.79582214, 22.49501228], [88.7960434, 22.49463081], [88.79618835, 22.49422264], [88.79638672, 22.49376106], [88.79659271, 22.49318123], [88.79669189, 22.49249268], [88.79684448, 22.49181557], [88.79691315, 22.49115944], [88.79693604, 22.49063301], [88.79701233, 22.49025154], [88.79718018, 22.48997307], [88.79727936, 22.48962212], [88.79746246, 22.48927116], [88.79766083, 22.4888382], [88.7978363, 22.48835182], [88.79810333, 22.48790169], [88.79841614, 22.48751831], [88.79881287, 22.48719978], [88.79919434, 22.48690414], [88.79953003, 22.48660088], [88.79988861, 22.48636246], [88.80023193, 22.48615074], [88.80062866, 22.48601151], [88.80101013, 22.48581886], [88.80145264, 22.48559952], [88.8020401, 22.48545265], [88.80270386, 22.4853096], [88.80338287, 22.4852314], [88.80396271, 22.48500252], [88.80451202, 22.48477745], [88.80519867, 22.48468208], [88.80587006, 22.48444366], [88.80648041, 22.48410988], [88.80693054, 22.48363495], [88.80728149, 22.48310852], [88.80767822, 22.48263168], [88.80821991, 22.48226547], [88.808815, 22.48193932], [88.80983734, 22.48119354], [88.80998993, 22.48099136], [88.81020355, 22.48059273], [88.81048584, 22.48011971], [88.81092072, 22.47958565], [88.81121063, 22.47891045], [88.8112793, 22.47831154], [88.81121063, 22.47690392], [88.81121063, 22.47596931], [88.81162262, 22.47416115], [88.81166077, 22.47369957], [88.81169891, 22.47320938], [88.81182098, 22.47275162], [88.8119278, 22.47240257], [88.81202698, 22.47205162], [88.81223297, 22.47177315], [88.81244659, 22.47147179], [88.81256866, 22.4710598], [88.81272125, 22.47058296], [88.81273651, 22.47002983], [88.81266785, 22.46953392], [88.81253815, 22.46908379], [88.8125, 22.46861458], [88.81249237, 22.46813011], [88.81246185, 22.46764946], [88.81233215, 22.46720314], [88.8122406, 22.4667511], [88.81221771, 22.46631813], [88.81223297, 22.46587944], [88.81224823, 22.4654026], [88.81233215, 22.46489143], [88.81224823, 22.46441078], [88.81217957, 22.46395302], [88.81194305, 22.46389198], [88.81194305, 22.46222115], [88.81222534, 22.46194458], [88.81208038, 22.46010399], [88.81194305, 22.45944595], [88.81199646, 22.45788383], [88.81228638, 22.45452118], [88.81234741, 22.45417976], [88.81276703, 22.45361137], [88.81291199, 22.4533329], [88.81305695, 22.45305824], [88.8133316, 22.45278168], [88.8133316, 22.4525013], [88.81360626, 22.4521122], [88.81387329, 22.45178032], [88.81407928, 22.45145226], [88.81427765, 22.45106125], [88.81458282, 22.4507103], [88.81492615, 22.45039177], [88.81536865, 22.45018959], [88.81582642, 22.45003128], [88.81630707, 22.44994545], [88.81671906, 22.44978142], [88.8171463, 22.44971275], [88.81754303, 22.44964027], [88.81790924, 22.4494915], [88.81835175, 22.44944763], [88.81884003, 22.44943619], [88.81935883, 22.44944191], [88.81984711, 22.44944191], [88.82029724, 22.44943047], [88.82073212, 22.44941139], [88.82117462, 22.44937325], [88.82164764, 22.44935036], [88.82206726, 22.44945908], [88.82256317, 22.44966316], [88.82316589, 22.44976234], [88.82382965, 22.44987297], [88.82446289, 22.44968987], [88.82499695, 22.44941139], [88.82539368, 22.44906425], [88.82576752, 22.44876289], [88.82608032, 22.44841957], [88.82644653, 22.44804382], [88.82685089, 22.4474144], [88.82730103, 22.44676971], [88.82743073, 22.44618034], [88.8273468, 22.44567108], [88.82718658, 22.4451313], [88.82694244, 22.44461823], [88.8266983, 22.44413185], [88.82653809, 22.44368553], [88.82633209, 22.44336128], [88.82613373, 22.44309616], [88.8259964, 22.44280624], [88.82582855, 22.44255257], [88.82564545, 22.4423008], [88.82549286, 22.44201851], [88.82528687, 22.44175148], [88.82505798, 22.44144821], [88.82480621, 22.44114113], [88.82448578, 22.44087029], [88.82415009, 22.44057465], [88.82382965, 22.44026375], [88.82354736, 22.43992043], [88.82328796, 22.43954468], [88.82298279, 22.43919945], [88.82264709, 22.43889046], [88.82229614, 22.43859291], [88.82198334, 22.43824959], [88.82167816, 22.4378891], [88.82144928, 22.43747139], [88.82138824, 22.43692017], [88.82138062, 22.4363308], [88.8214035, 22.43574905], [88.82148743, 22.43521309], [88.82168579, 22.43478966], [88.82194519, 22.43445206], [88.82225037, 22.43414116], [88.82260895, 22.43388176], [88.82298279, 22.43361092], [88.82337189, 22.43335152], [88.82390594, 22.43317032], [88.82454681, 22.43313789], [88.82512665, 22.43319893], [88.82555389, 22.43321419], [88.82692719, 22.43313026], [88.82843781, 22.4331913], [88.829216, 22.43333244], [88.82987213, 22.43346977], [88.83045197, 22.43359947], [88.83109283, 22.43373108], [88.83203125, 22.43400192], [88.83296204, 22.43427086], [88.83346558, 22.43440437], [88.83454132, 22.43460655], [88.8348999, 22.43460655], [88.83518982, 22.43453979], [88.83526611, 22.43433952], [88.83512115, 22.43408012], [88.83483124, 22.43380356], [88.83447266, 22.43367386], [88.83410645, 22.43340111], [88.83361053, 22.43325996], [88.83289337, 22.43319511], [88.83253479, 22.43306541], [88.83217621, 22.43306541], [88.83102417, 22.43272972], [88.829216, 22.43253136], [88.82699585, 22.43238831], [88.82423401, 22.43205452], [88.82367706, 22.43211174], [88.82320404, 22.43218994], [88.82273102, 22.43221474], [88.82224274, 22.43220329], [88.82173157, 22.43211746], [88.82121277, 22.43199158], [88.820961, 22.43195152], [88.82067871, 22.43194389], [88.82026672, 22.4319706], [88.81978607, 22.432127], [88.81922913, 22.43225288], [88.81874847, 22.43248177], [88.81832886, 22.43266106], [88.81793976, 22.43279266], [88.81758881, 22.43294907], [88.81719208, 22.43307304], [88.81674957, 22.43323708], [88.81624603, 22.43341637], [88.81584167, 22.4337635], [88.81548309, 22.43413353], [88.81513977, 22.43444252], [88.81481934, 22.43470955], [88.8144989, 22.43494987], [88.81417847, 22.43519592], [88.81388092, 22.43548012], [88.81355286, 22.43580055], [88.81314087, 22.43611908], [88.81269073, 22.43647575], [88.81223297, 22.43687248], [88.81175995, 22.43730545], [88.81136322, 22.43781281], [88.81096649, 22.43833542], [88.81059265, 22.43885994], [88.81022644, 22.43941307], [88.8098526, 22.43992043], [88.80937195, 22.44032097], [88.80887604, 22.44059181], [88.80850983, 22.44087029], [88.80821991, 22.44113731], [88.80765533, 22.44136238], [88.80686951, 22.44155312], [88.80623627, 22.44188118], [88.80584717, 22.44234276], [88.80551147, 22.4426899], [88.80515289, 22.44299126], [88.80487061, 22.44336128], [88.80458832, 22.44373512], [88.80427551, 22.44408607], [88.80397034, 22.44445229], [88.80371094, 22.44487953], [88.80351257, 22.4453373], [88.8033371, 22.44579124], [88.80316925, 22.44621086], [88.8030777, 22.44662285], [88.80304718, 22.44701958], [88.80300903, 22.44742012], [88.80290222, 22.44779968], [88.80280304, 22.44820213], [88.80278015, 22.44865036], [88.80278015, 22.44910812], [88.80278015, 22.44959068], [88.80278778, 22.45008278], [88.80282593, 22.45055199], [88.80296326, 22.45092964], [88.80307007, 22.45127106], [88.8030014, 22.45182037], [88.80288696, 22.45235252], [88.8028183, 22.45284081], [88.80278015, 22.45335388], [88.80272675, 22.45392036], [88.80262756, 22.45456123], [88.80258179, 22.45526314], [88.80256653, 22.45594978], [88.80241394, 22.45641708], [88.80210114, 22.45672226], [88.80179596, 22.45714188], [88.80162811, 22.45774841], [88.80142212, 22.45838356], [88.80131531, 22.45900154], [88.80116272, 22.45951271], [88.8010788, 22.46003151], [88.80093384, 22.46046257], [88.80084991, 22.46080017], [88.80080414, 22.4611187], [88.8006897, 22.46140099], [88.80053711, 22.46172142], [88.80030823, 22.46207237], [88.80008698, 22.46249962], [88.79981995, 22.46297264], [88.79953766, 22.46350288], [88.79920197, 22.46398163], [88.79888153, 22.46445274], [88.79857635, 22.4648819], [88.79830933, 22.4652195], [88.79806519, 22.46549797], [88.79785156, 22.4657917], [88.79767609, 22.46617317], [88.79746246, 22.46656227], [88.79740143, 22.46723175], [88.79734039, 22.46783829], [88.79701233, 22.46813583], [88.79670715, 22.46846962], [88.79641724, 22.46885109], [88.79611969, 22.4691906], [88.79586029, 22.46955299], [88.79566193, 22.46992111], [88.79553223, 22.47029495], [88.79537964, 22.47061157], [88.79524994, 22.47092247], [88.79508209, 22.47125053], [88.79494476, 22.4717083], [88.79471588, 22.47221375], [88.79442596, 22.4727726], [88.79413605, 22.47334099], [88.79386139, 22.47391891], [88.79363251, 22.47448349], [88.79350281, 22.47504997], [88.79354095, 22.4756794], [88.79341125, 22.47632027], [88.79325867, 22.47693634], [88.79310608, 22.47754097], [88.7930603, 22.47817039], [88.79299927, 22.47875786], [88.79283905, 22.47929192], [88.79271698, 22.47982216], [88.7925415, 22.48028183], [88.79234314, 22.48075294], [88.79216003, 22.48130226], [88.79194641, 22.48181343], [88.79171753, 22.48228455], [88.79148102, 22.48272133], [88.79115295, 22.48306084], [88.790802, 22.48338127], [88.79046631, 22.48370171], [88.79016113, 22.48402023], [88.78987885, 22.4842968], [88.78960419, 22.48454475], [88.78926849, 22.48477364], [88.7889328, 22.4850502], [88.78859711, 22.48537827], [88.78830719, 22.4857502], [88.78798676, 22.48621178], [88.78756714, 22.48669243], [88.78710938, 22.4869175], [88.78665161, 22.48712349], [88.78620148, 22.48739433], [88.78582001, 22.48780441], [88.78543854, 22.48823166], [88.78501129, 22.48859978], [88.78459167, 22.48892021], [88.78425598, 22.48925209], [88.78401947, 22.4895916], [88.78382874, 22.48989105], [88.78362274, 22.49012184], [88.78341675, 22.49036217], [88.78325653, 22.49062157], [88.78305054, 22.49089241], [88.7828064, 22.49121475], [88.78246307, 22.49160767], [88.7820816, 22.49205971], [88.78172302, 22.49262047], [88.78142548, 22.49319649], [88.78120422, 22.49371338], [88.78111267, 22.49361229], [88.78055573, 22.49416733], [88.78056335, 22.49500275], [88.78028107, 22.49528122], [88.78055573, 22.49555779], [88.78055573, 22.49694443], [88.78028107, 22.4972229], [88.78028107, 22.49916649], [88.78055573, 22.49944305], [88.78056335, 22.49971962], [88.78083038, 22.50000191], [88.78083038, 22.50028038], [88.78111267, 22.50056267], [88.78138733, 22.50056267]]], [[[89.65219879, 26.0621624], [89.65222931, 26.06225777], [89.65227509, 26.06243515], [89.65228271, 26.06256676], [89.65229797, 26.06265068], [89.65229797, 26.06279564], [89.65228271, 26.06288147], [89.65227509, 26.06295776], [89.6522522, 26.06305313], [89.65224457, 26.06314278], [89.65216064, 26.06351852], [89.6521225, 26.06380081], [89.65209961, 26.0641098], [89.65206909, 26.06440163], [89.65205383, 26.06458664], [89.65201569, 26.06481934], [89.65200806, 26.0650425], [89.6519928, 26.06529427], [89.65202332, 26.06554222], [89.65268707, 26.0635891], [89.65235138, 26.06223106], [89.65219879, 26.0621624]]], [[[88.88509369, 26.24045753], [88.88491058, 26.24035645], [88.88476563, 26.24032974], [88.88461304, 26.24033356], [88.88446045, 26.24035263], [88.88427734, 26.24050713], [88.88407898, 26.24067688], [88.88388824, 26.24094963], [88.88368225, 26.24123955], [88.88352966, 26.24142265], [88.88336182, 26.24160576], [88.88321686, 26.24180222], [88.88306427, 26.24201393], [88.88294983, 26.24221039], [88.88285828, 26.24238968], [88.88279724, 26.24250984], [88.88272858, 26.24269104], [88.88265228, 26.24285507], [88.88253021, 26.24304962], [88.88244629, 26.24324226], [88.88226318, 26.24355698], [88.88217163, 26.2437191], [88.88204956, 26.24388313], [88.88192749, 26.24403572], [88.88256836, 26.24439049], [88.88389587, 26.24529076], [88.88497162, 26.24414063], [88.88507843, 26.2420311], [88.88509369, 26.24045753]]], [[[89.02344513, 26.242733], [89.02387238, 26.24292374], [89.02420807, 26.24292183], [89.02462006, 26.24283981], [89.02500916, 26.24282074], [89.02526093, 26.24280167], [89.02557373, 26.24275589], [89.02576447, 26.24274635], [89.02587128, 26.24268532], [89.02592468, 26.24249268], [89.0259552, 26.24216652], [89.02585602, 26.24173164], [89.02568817, 26.24116898], [89.02555847, 26.24082375], [89.025383, 26.24058723], [89.02520752, 26.24062157], [89.02489471, 26.24069405], [89.02445221, 26.2407608], [89.02401733, 26.24075699], [89.02362061, 26.2407856], [89.02332306, 26.24083328], [89.0230484, 26.24098778], [89.02298737, 26.24106216], [89.02293396, 26.24115372], [89.02280426, 26.24128532], [89.0226593, 26.24155617], [89.02248383, 26.2416153], [89.02201843, 26.24267006], [89.02223969, 26.24267006], [89.0225296, 26.24266243], [89.02288055, 26.24266815], [89.02313995, 26.24256706], [89.02344513, 26.242733]]], [[[87.75389099, 21.69639015], [87.75389099, 21.69610977], [87.7536087, 21.6958313], [87.7536087, 21.69555473], [87.75333405, 21.69527817], [87.75332642, 21.69444275], [87.7536087, 21.69416618], [87.7536087, 21.69361115], [87.75305176, 21.69306183], [87.75250244, 21.69361115], [87.75222015, 21.69361115], [87.75195313, 21.69388962], [87.75166321, 21.69388962], [87.75138855, 21.69417191], [87.7508316, 21.69417191], [87.75055695, 21.69388962], [87.75, 21.69388962], [87.74972534, 21.69361115], [87.74972534, 21.69305611], [87.74944305, 21.6927681], [87.74944305, 21.6922226], [87.7491684, 21.69194412], [87.7491684, 21.69138908], [87.74944305, 21.69111061], [87.74944305, 21.69082832], [87.75, 21.6902771], [87.75, 21.69011116], [87.75, 21.69000053], [87.75027466, 21.68972206], [87.75026703, 21.68889046], [87.75000763, 21.68861008], [87.75, 21.68833351], [87.74973297, 21.68777847], [87.75000763, 21.68721962], [87.75027466, 21.68722153], [87.75027466, 21.68666458], [87.74888611, 21.68527985], [87.74888611, 21.68472099], [87.7480545, 21.68388939], [87.74777985, 21.68388939], [87.7472229, 21.68333054], [87.74666595, 21.68333244], [87.7463913, 21.68361092], [87.74583435, 21.68361092], [87.74555206, 21.68333244], [87.7452774, 21.68333244], [87.7450943, 21.68314934], [87.74472046, 21.6827774], [87.7444458, 21.68278122], [87.74415588, 21.68250084], [87.74388123, 21.68250084], [87.74351501, 21.68213081], [87.74333191, 21.68194389], [87.74333191, 21.68138885], [87.74250031, 21.68056107], [87.74223328, 21.68056107], [87.7416687, 21.68000031], [87.74138641, 21.68000031], [87.74054718, 21.67917252], [87.74028015, 21.67917252], [87.73999786, 21.67889023], [87.73999786, 21.67861176], [87.73972321, 21.67833328], [87.73916626, 21.67833328], [87.7388916, 21.67805481], [87.73860931, 21.67805481], [87.73833466, 21.67777824], [87.73805237, 21.67778969], [87.73777771, 21.67749977], [87.73750305, 21.67749977], [87.73722076, 21.67721748], [87.73694611, 21.6772213], [87.73666382, 21.67694473], [87.73638916, 21.67694473], [87.73583221, 21.67638969], [87.73555756, 21.67638969], [87.7352829, 21.67611122], [87.73500061, 21.67611122], [87.73361206, 21.67506027], [87.73249817, 21.6747303], [87.73221588, 21.67444038], [87.73166656, 21.6744442], [87.73139191, 21.67416763], [87.73110962, 21.67416954], [87.73055267, 21.67361069], [87.73027802, 21.67361069], [87.73000336, 21.67333031], [87.72972107, 21.67333412], [87.72916412, 21.67277527], [87.72888184, 21.67278099], [87.72860718, 21.67250061], [87.72805786, 21.67250061], [87.7277832, 21.67222023], [87.72750092, 21.67222214], [87.72721863, 21.67194366], [87.72694397, 21.67194366], [87.72666931, 21.67166519], [87.72583008, 21.67166519], [87.72555542, 21.67138863], [87.72528076, 21.67139053], [87.72514343, 21.67124939], [87.72499847, 21.67111015], [87.72472382, 21.67111206], [87.72455597, 21.67094421], [87.72444153, 21.67083549], [87.72416687, 21.67083549], [87.72389221, 21.67055321], [87.72305298, 21.67056084], [87.72277832, 21.67028046], [87.72249603, 21.67028046], [87.72222137, 21.67000008], [87.72194672, 21.67000008], [87.7216568, 21.6697197], [87.72138977, 21.6697216], [87.72110748, 21.66944313], [87.72083282, 21.66945076], [87.72055817, 21.66917038], [87.72027588, 21.66917038], [87.72000122, 21.66889], [87.7197113, 21.66889], [87.71942139, 21.66866302], [87.71916962, 21.66861153], [87.71888733, 21.66833115], [87.71861267, 21.66833115], [87.71798706, 21.66790962], [87.71778107, 21.66777802], [87.71749878, 21.66784286], [87.71707916, 21.66764069], [87.71694183, 21.66756248], [87.71666718, 21.66749191], [87.71611023, 21.66740608], [87.71562958, 21.66719818], [87.71527863, 21.6669445], [87.71472168, 21.6669445], [87.71458435, 21.66680527], [87.71444702, 21.66666603], [87.71389771, 21.66667175], [87.71360779, 21.66638947], [87.71333313, 21.66638947], [87.71305847, 21.66610909], [87.71277618, 21.66610909], [87.71250153, 21.66583061], [87.71221924, 21.66583252], [87.71194458, 21.66555405], [87.71166992, 21.66527748], [87.71138763, 21.66527939], [87.71111298, 21.66500092], [87.71083069, 21.66500092], [87.7103653, 21.66475487], [87.70982361, 21.66470528], [87.70928955, 21.66469002], [87.70889282, 21.66452026], [87.70847321, 21.66436005], [87.70810699, 21.66415024], [87.7077179, 21.66394615], [87.7072525, 21.66386414], [87.70677948, 21.6637764], [87.70639038, 21.66360092], [87.70601654, 21.66340828], [87.70561981, 21.66327095], [87.70523834, 21.66308975], [87.70481873, 21.66294289], [87.70439911, 21.66280365], [87.70396423, 21.66270065], [87.70355988, 21.66255951], [87.70314789, 21.66246033], [87.70305634, 21.6622982], [87.70276642, 21.66221809], [87.70166779, 21.66201973], [87.70111084, 21.66167068], [87.70027924, 21.66167068], [87.69999695, 21.6613903], [87.69972229, 21.6613903], [87.69944763, 21.66110992], [87.69889069, 21.66111183], [87.6986084, 21.66083336], [87.69833374, 21.66083336], [87.69805908, 21.66055679], [87.69750214, 21.66055679], [87.69721985, 21.66027832], [87.6966629, 21.66028023], [87.69638824, 21.65999985], [87.69555664, 21.65999985], [87.69526672, 21.65971947], [87.69499969, 21.65972137], [87.69472504, 21.65944672], [87.69416809, 21.65944672], [87.6938858, 21.65916443], [87.69333649, 21.65917015], [87.69304657, 21.65888977], [87.69277191, 21.65888977], [87.69255066, 21.65866661], [87.69249725, 21.65860939], [87.69166565, 21.6586113], [87.69139099, 21.65833282], [87.69083405, 21.65833282], [87.69055176, 21.65805435], [87.6902771, 21.65806007], [87.68972778, 21.65750122], [87.68860626, 21.65750122], [87.6883316, 21.65722084], [87.6875, 21.65722466], [87.68722534, 21.65694237], [87.6866684, 21.65694237], [87.68638611, 21.6566658], [87.68583679, 21.6566658], [87.6855545, 21.65638924], [87.68527985, 21.65639114], [87.68499756, 21.65611076], [87.68416595, 21.65611076], [87.6838913, 21.65583038], [87.68333435, 21.65583229], [87.68305206, 21.65555573], [87.68257141, 21.6552906], [87.68222046, 21.65528107], [87.68145752, 21.65513992], [87.6811142, 21.65500069], [87.68055725, 21.65500069], [87.68028259, 21.65472031], [87.67972565, 21.65472221], [87.67944336, 21.65444374], [87.67888641, 21.65444374], [87.67861176, 21.65416718], [87.67804718, 21.6541729], [87.67778778, 21.65389061], [87.67648315, 21.65374947], [87.67583466, 21.65361023], [87.67555237, 21.65361977], [87.67527771, 21.65333176], [87.67472076, 21.65333366], [87.67453766, 21.65314865], [87.67444611, 21.65305519], [87.67388916, 21.65306282], [87.67360687, 21.65278053], [87.6727829, 21.65278053], [87.67250061, 21.65250015], [87.67118073, 21.65236092], [87.67082977, 21.65222168], [87.67007446, 21.65202332], [87.66972351, 21.65194511], [87.66916656, 21.6518116], [87.66889191, 21.65167236], [87.66709137, 21.65146065], [87.66666412, 21.65138817], [87.66438293, 21.65105247], [87.66388702, 21.6511116], [87.66305542, 21.6511116], [87.66278076, 21.65083313], [87.66222382, 21.65083313], [87.66194153, 21.65055466], [87.66139221, 21.65055847], [87.66110992, 21.65027809], [87.65888977, 21.65027809], [87.65860748, 21.64999962], [87.65805817, 21.64999962], [87.65777588, 21.64972115], [87.65721893, 21.64972305], [87.65712738, 21.64962959], [87.65694427, 21.64944458], [87.65583038, 21.64944458], [87.65555573, 21.64916611], [87.65471649, 21.64916992], [87.65444183, 21.64888954], [87.65361023, 21.64888954], [87.65333557, 21.64861107], [87.65000153, 21.64861107], [87.64971924, 21.64888954], [87.64888763, 21.64888954], [87.64861298, 21.64916992], [87.64778137, 21.64916611], [87.64749908, 21.64944458], [87.64722443, 21.64944458], [87.64694214, 21.64972305], [87.64611053, 21.64972115], [87.64583588, 21.64999962], [87.64554596, 21.64999962], [87.6452713, 21.64977837], [87.64472198, 21.64972115], [87.64444733, 21.64999962], [87.64347076, 21.65063095], [87.64332581, 21.65083122], [87.64250183, 21.65166664], [87.64214325, 21.65263939], [87.64215088, 21.65305519], [87.64209747, 21.65410995], [87.64208221, 21.65444183], [87.64193726, 21.65466118], [87.64193726, 21.65500069], [87.64173126, 21.65555573], [87.64167023, 21.65583229], [87.64167786, 21.65611076], [87.64194489, 21.65638924], [87.64221954, 21.65679359], [87.64277649, 21.65694046], [87.64299011, 21.65715027], [87.64437103, 21.65846825], [87.64444733, 21.65860939], [87.64472198, 21.65888977], [87.64472198, 21.65917015], [87.64487457, 21.65964508], [87.64437866, 21.65998077], [87.64360809, 21.65999985], [87.64305878, 21.65944099], [87.64277649, 21.65944672], [87.64138794, 21.65805435], [87.64105988, 21.65776062], [87.64063263, 21.65756035], [87.64026642, 21.65750122], [87.63987732, 21.65730095], [87.63941193, 21.65695], [87.63893127, 21.65659904], [87.63865662, 21.65638924], [87.63846588, 21.65624428], [87.63800812, 21.65591049], [87.63755798, 21.65559959], [87.637146, 21.65524101], [87.63679504, 21.65484238], [87.63648987, 21.65441132], [87.63625336, 21.65396118], [87.63613129, 21.6534996], [87.6359787, 21.65304947], [87.63574982, 21.65269089], [87.63550568, 21.6524086], [87.63527679, 21.65205956], [87.63504791, 21.65164566], [87.63481903, 21.65114021], [87.63469696, 21.6505909], [87.63454437, 21.65018272], [87.63444519, 21.64983749], [87.63430023, 21.64954948], [87.63408661, 21.64921951], [87.63381958, 21.64889908], [87.63342285, 21.64860725], [87.6329422, 21.64830017], [87.63248444, 21.64800072], [87.63204193, 21.64767265], [87.63160706, 21.64734077], [87.63111877, 21.64712143], [87.63061523, 21.64692879], [87.63011932, 21.64673042], [87.6295929, 21.64665222], [87.62906647, 21.6465435], [87.62854004, 21.64636803], [87.62799835, 21.64616013], [87.627388, 21.646101], [87.6267395, 21.64603043], [87.62608337, 21.64586258], [87.62540436, 21.64576149], [87.62475586, 21.64559364], [87.62406921, 21.64550972], [87.62341309, 21.6453228], [87.62274933, 21.64518166], [87.62208557, 21.64499474], [87.6214447, 21.64480782], [87.62078857, 21.64471054], [87.6202774, 21.64472198], [87.62000275, 21.64444351], [87.61833191, 21.64444351], [87.61804962, 21.64422226], [87.61749268, 21.64417076], [87.61723328, 21.64389038], [87.61694336, 21.64417076], [87.61528015, 21.64417076], [87.61499786, 21.64389038], [87.61277771, 21.64389038], [87.6125946, 21.64370537], [87.61222076, 21.64333344], [87.61194611, 21.64333344], [87.61166382, 21.64305305], [87.60978699, 21.64285088], [87.60906982, 21.64271927], [87.60835266, 21.6426506], [87.60799408, 21.64251518], [87.60706329, 21.64232063], [87.60634613, 21.64204979], [87.60549927, 21.64216995], [87.60527802, 21.64194107], [87.60472107, 21.64194489], [87.60407257, 21.64189148], [87.60341644, 21.64176559], [87.60286713, 21.64162064], [87.60238647, 21.6414299], [87.60188293, 21.64138985], [87.60135651, 21.64137077], [87.60083771, 21.64126015], [87.60028076, 21.64108086], [87.59970093, 21.64088058], [87.59908295, 21.6408329], [87.59849548, 21.64080811], [87.59798431, 21.64069176], [87.59751129, 21.64053917], [87.5970459, 21.64038086], [87.59648132, 21.64030075], [87.59584045, 21.64033127], [87.59541321, 21.64029694], [87.59519958, 21.64028358], [87.59455109, 21.64023018], [87.59395599, 21.64012909], [87.59346008, 21.63999939], [87.59300232, 21.63989449], [87.59256744, 21.6397686], [87.59208679, 21.63955116], [87.59147644, 21.63937187], [87.5908432, 21.63920021], [87.59017181, 21.63915825], [87.58956909, 21.63914108], [87.58904266, 21.63911057], [87.58857727, 21.63896942], [87.5881424, 21.6388607], [87.58773041, 21.638731], [87.58732605, 21.63862038], [87.58692932, 21.63853073], [87.58653259, 21.63838959], [87.58609009, 21.63829994], [87.58566284, 21.63817024], [87.58522034, 21.63804054], [87.58476257, 21.63786125], [87.58428192, 21.63772774], [87.58377075, 21.63757133], [87.58320618, 21.63750076], [87.58266449, 21.63744736], [87.58223724, 21.63728142], [87.58178711, 21.63721657], [87.58135223, 21.63714027], [87.58097076, 21.63699341], [87.58052063, 21.63693047], [87.58004761, 21.63684082], [87.57953644, 21.63669968], [87.57901764, 21.63662529], [87.57850647, 21.63646126], [87.57800293, 21.63639069], [87.57752228, 21.63631821], [87.57707977, 21.63620186], [87.57665253, 21.63612175], [87.57621765, 21.63589478], [87.57592773, 21.63574791], [87.57533264, 21.63576126], [87.57485962, 21.63563919], [87.57435608, 21.63562012], [87.57382965, 21.63533974], [87.57330322, 21.63513947], [87.57279205, 21.63507652], [87.57226563, 21.63521385], [87.5716629, 21.63517189], [87.57147217, 21.6350708], [87.57100677, 21.63502693], [87.57058716, 21.63495064], [87.57019806, 21.63476944], [87.56977844, 21.63469124], [87.56941986, 21.63455009], [87.56906128, 21.63446045], [87.56873322, 21.63439941], [87.56838989, 21.63425064], [87.56803131, 21.63414955], [87.56763458, 21.63402939], [87.56716919, 21.63392258], [87.56667328, 21.63396072], [87.56629944, 21.63393974], [87.56604767, 21.63389969], [87.56575775, 21.63389015], [87.56539917, 21.63388062], [87.56498718, 21.63381958], [87.56461334, 21.63365364], [87.56421661, 21.63353348], [87.56381989, 21.63344383], [87.56330872, 21.63349342], [87.56291199, 21.6333847], [87.56277466, 21.63333321], [87.56118011, 21.63306427], [87.56083679, 21.63305664], [87.56027985, 21.63300514], [87.55937195, 21.63327026], [87.559021, 21.63348961], [87.55805206, 21.63388634], [87.55770874, 21.63396454], [87.55750275, 21.63409042], [87.55715179, 21.63425064], [87.5569458, 21.63445091], [87.55583191, 21.63555908], [87.55444336, 21.63555908], [87.55388641, 21.63611031], [87.55304718, 21.63611031], [87.55166626, 21.63471985], [87.5513916, 21.63472176], [87.55110931, 21.63444519], [87.55000305, 21.63445091], [87.54944611, 21.63389015], [87.54944611, 21.63360977], [87.54916382, 21.63333321], [87.54916382, 21.63222313], [87.54833221, 21.63138962], [87.54833221, 21.63083076], [87.54805756, 21.63083267], [87.54777527, 21.6305542], [87.54722595, 21.63055992], [87.54693604, 21.63027954], [87.54666901, 21.63027954], [87.54638672, 21.63000107], [87.54611206, 21.62972069], [87.54611206, 21.62944221], [87.54582977, 21.62916756], [87.54556274, 21.62916946], [87.54545593, 21.62906647], [87.54528046, 21.62888908], [87.54444122, 21.6288929], [87.54416656, 21.62861061], [87.54389191, 21.62861061], [87.54360962, 21.62833023], [87.54166412, 21.62833214], [87.54138947, 21.62805557], [87.54110718, 21.62805939], [87.54083252, 21.62778282], [87.54055786, 21.62778282], [87.5402832, 21.62750053], [87.53943634, 21.62750053], [87.53916931, 21.62722015], [87.53749847, 21.62722015], [87.5368042, 21.62680244], [87.53499603, 21.62668037], [87.53472137, 21.62639046], [87.53444672, 21.62639046], [87.5341568, 21.62611008], [87.53360748, 21.62597656], [87.53257751, 21.62505913], [87.53221893, 21.62480164], [87.53166962, 21.62445068], [87.53083038, 21.62444496], [87.53055573, 21.62472153], [87.53028107, 21.62472153], [87.52973175, 21.62417221], [87.52916718, 21.62361145], [87.52889252, 21.62361908], [87.52861023, 21.62333107], [87.52805328, 21.62333298], [87.52777863, 21.62305641], [87.52749634, 21.62305832], [87.52738953, 21.6229496], [87.52722931, 21.62277985], [87.52587891, 21.62224007], [87.52487946, 21.62216949], [87.52444458, 21.62217331], [87.52351379, 21.62176895], [87.52250671, 21.62177277], [87.52186584, 21.62170029], [87.52166748, 21.62138939], [87.5212326, 21.62125969], [87.52068329, 21.62124062], [87.52011871, 21.62129974], [87.5196228, 21.62118912], [87.51912689, 21.62109947], [87.51864624, 21.62100029], [87.51819611, 21.62085915], [87.51771545, 21.62078667], [87.51727295, 21.6206398], [87.51679993, 21.62055588], [87.5163269, 21.6204586], [87.51589203, 21.62029839], [87.51544952, 21.62015915], [87.51502991, 21.6199894], [87.51463318, 21.6198082], [87.51419067, 21.61969185], [87.51306915, 21.61961174], [87.51249695, 21.61944008], [87.51194763, 21.6194458], [87.51166534, 21.61916733], [87.51139069, 21.61917114], [87.51082611, 21.61861038], [87.51055908, 21.61861038], [87.50988007, 21.6185894], [87.50937653, 21.61850929], [87.50892639, 21.61837006], [87.50843048, 21.61828995], [87.50791931, 21.61812973], [87.50737762, 21.61800957], [87.50686646, 21.61785126], [87.50636292, 21.61771965], [87.50585938, 21.61755371], [87.50527954, 21.61750031], [87.50499725, 21.61750031], [87.5047226, 21.61722183], [87.5036087, 21.61722183], [87.50333405, 21.61694336], [87.50305939, 21.61695099], [87.50296021, 21.61685181], [87.5027771, 21.61666679], [87.50195313, 21.61667061], [87.50176239, 21.6164856], [87.50166321, 21.61638832], [87.50110626, 21.61639023], [87.49989319, 21.61572075], [87.49938965, 21.61572075], [87.498703, 21.61560059], [87.49860382, 21.61558151], [87.49760437, 21.61517715], [87.4972229, 21.61499977], [87.49694824, 21.61471939], [87.4963913, 21.6147213], [87.49610901, 21.61444473], [87.49555206, 21.61445045], [87.4952774, 21.61417007], [87.49500275, 21.61417007], [87.49415588, 21.61333275], [87.49285126, 21.61352921], [87.49227142, 21.61292267], [87.49098969, 21.61272049], [87.49027252, 21.61252022], [87.48976898, 21.61225128], [87.48890686, 21.61211967], [87.48806, 21.61164093], [87.48777771, 21.61138916], [87.48750305, 21.61111069], [87.48694611, 21.61111069], [87.48665619, 21.6108284], [87.48638916, 21.61083412], [87.4861145, 21.61055565], [87.48583221, 21.61056137], [87.48458862, 21.61018944], [87.48401642, 21.61005974], [87.48323059, 21.60957909], [87.48278046, 21.6091671], [87.48249817, 21.60889053], [87.48221588, 21.60889053], [87.48203278, 21.60870361], [87.48175812, 21.60946274], [87.48171234, 21.61383057], [87.48265839, 21.61803246], [87.48208618, 21.62586975], [87.4785614, 21.62794113], [87.47751617, 21.63175964], [87.47074127, 21.64307022], [87.46776581, 21.64565086], [87.46090698, 21.64445114], [87.45864868, 21.64493942], [87.4604187, 21.65712929], [87.46491241, 21.65855026], [87.46349335, 21.66876984], [87.46507263, 21.67110062], [87.46520233, 21.67513084], [87.46826172, 21.67727089], [87.46839142, 21.68378067], [87.46969604, 21.6916008], [87.4675293, 21.69565964], [87.46929169, 21.69845009], [87.47083282, 21.70718002], [87.46264648, 21.71706009], [87.46083069, 21.72050095], [87.46231842, 21.72224998], [87.46573639, 21.7235775], [87.46605682, 21.72519112], [87.46517944, 21.72636032], [87.46276855, 21.72640038], [87.45419312, 21.72943115], [87.44293213, 21.72904968], [87.44441986, 21.732481], [87.45137024, 21.73241043], [87.45111084, 21.7354126], [87.44563293, 21.7379303], [87.44330597, 21.74212074], [87.44245911, 21.75533104], [87.44367218, 21.76088905], [87.43930817, 21.76436043], [87.43139648, 21.76440048], [87.42481995, 21.76565933], [87.41208649, 21.76375008], [87.40283203, 21.7655201], [87.40101624, 21.76486015], [87.39993286, 21.76256943], [87.39524078, 21.76242256], [87.39377594, 21.76377106], [87.39315796, 21.76613808], [87.38990021, 21.76654053], [87.39240265, 21.76898193], [87.39096069, 21.77044106], [87.38330078, 21.77086067], [87.37542725, 21.76799965], [87.37348938, 21.76641083], [87.37306213, 21.76204109], [87.37166595, 21.76039124], [87.37011719, 21.76007271], [87.36873627, 21.76263046], [87.37045288, 21.76802063], [87.36779785, 21.77463913], [87.35736084, 21.77724075], [87.35504913, 21.77927971], [87.3520813, 21.78573036], [87.34449768, 21.78596115], [87.34046173, 21.78395844], [87.33922577, 21.7808094], [87.33666992, 21.77918053], [87.33500671, 21.78013039], [87.33573151, 21.78121185], [87.33534241, 21.78363037], [87.33270264, 21.78720093], [87.33011627, 21.78770256], [87.32618713, 21.78564072], [87.32427216, 21.78537941], [87.32286072, 21.78596115], [87.31730652, 21.78572083], [87.31685638, 21.78854942], [87.31796265, 21.79055023], [87.30916595, 21.78890991], [87.30755615, 21.79268265], [87.30605316, 21.79385948], [87.29872131, 21.79444122], [87.29656982, 21.79533005], [87.294487, 21.79842186], [87.29480743, 21.80389023], [87.29281616, 21.80546951], [87.2869873, 21.80384827], [87.28060913, 21.7991581], [87.27350616, 21.8020401], [87.27333832, 21.80360031], [87.27156067, 21.80340004], [87.27165222, 21.80471992], [87.27314758, 21.80579948], [87.27379608, 21.81171989], [87.27147675, 21.81307983], [87.26542664, 21.81289101], [87.26242065, 21.81385994], [87.26326752, 21.81604195], [87.26780701, 21.81970978], [87.26756287, 21.82149124], [87.26346588, 21.82501984], [87.26357269, 21.82719994], [87.26226044, 21.82982826], [87.26169586, 21.83329964], [87.25888824, 21.83501053], [87.25714874, 21.84137917], [87.25527191, 21.8438797], [87.24762726, 21.84820747], [87.24475098, 21.85637093], [87.24900055, 21.86380005], [87.24897766, 21.86651993], [87.24732971, 21.87172127], [87.23480988, 21.89560127], [87.23651886, 21.90272141], [87.23937225, 21.90682983], [87.25054932, 21.91518021], [87.25240326, 21.91780281], [87.25208282, 21.92097282], [87.23542786, 21.93374062], [87.23223114, 21.94036102], [87.23232269, 21.94646263], [87.23500061, 21.95298958], [87.23484802, 21.95438004], [87.22873688, 21.95607948], [87.22561646, 21.9571209], [87.22440338, 21.95401955], [87.22323608, 21.95323181], [87.22119141, 21.95321083], [87.20957184, 21.95737076], [87.20291138, 21.95643997], [87.19510651, 21.95356941], [87.18837738, 21.95701027], [87.17497253, 21.96619987], [87.17085266, 21.97261047], [87.16744232, 21.97340965], [87.16520691, 21.96751022], [87.16056061, 21.96244049], [87.16127777, 21.95389938], [87.15976715, 21.94908142], [87.15989685, 21.93392944], [87.15828705, 21.93054962], [87.15641785, 21.9289093], [87.15168762, 21.9279995], [87.14782715, 21.92592812], [87.14112854, 21.91969109], [87.1367569, 21.91797066], [87.13091278, 21.91801071], [87.12351227, 21.92024994], [87.11618042, 21.92064095], [87.11424255, 21.92217064], [87.11255646, 21.92115021], [87.1103363, 21.91802025], [87.10785675, 21.91741943], [87.10468292, 21.91781998], [87.10180664, 21.91608047], [87.09955597, 21.91098022], [87.09353638, 21.90789986], [87.09101868, 21.89923096], [87.08876801, 21.89812088], [87.08853912, 21.89507294], [87.0894165, 21.89240074], [87.09314728, 21.88986969], [87.09612274, 21.88624954], [87.09626007, 21.88210106], [87.0929184, 21.87420273], [87.09464264, 21.86034012], [87.0777359, 21.85980034], [87.06210327, 21.86018944], [87.05377197, 21.86094284], [87.03024292, 21.86531067], [87.02511597, 21.87034988], [87.01996613, 21.88574982], [87.0167923, 21.88722992], [87.01478577, 21.88968277], [87.00483704, 21.8955307], [87.00125885, 21.90584183], [86.99793243, 21.90750122], [87.00061035, 21.91438103], [86.99939728, 21.91814041], [87.0025177, 21.92235947], [87.00408173, 21.9354229], [87.00554657, 21.94065094], [87.01490021, 21.95326042], [87.02030945, 21.96836281], [87.03085327, 21.97883987], [87.03224182, 21.98610115], [87.03431702, 21.98919106], [87.0319519, 21.99567032], [87.02796936, 21.99842262], [87.02500916, 22.00395012], [87.02226257, 22.0120697], [87.02350616, 22.02102089], [87.02604675, 22.02874947], [87.02469635, 22.03269005], [87.01761627, 22.04128075], [87.0094223, 22.04148102], [87.00470734, 22.04278946], [87.00093079, 22.04500008], [86.99517822, 22.04579926], [86.99048615, 22.04938126], [86.98754883, 22.05507278], [86.97190857, 22.06627083], [86.97046661, 22.07399178], [86.96705627, 22.07775116], [86.95723724, 22.0833683], [86.95197296, 22.08134079], [86.94426727, 22.08197975], [86.93203735, 22.08584976], [86.92901611, 22.08453941], [86.92225647, 22.08576012], [86.90876007, 22.08638], [86.84790039, 22.09835052], [86.84603119, 22.09514999], [86.84169006, 22.09180069], [86.83200836, 22.09510994], [86.83132935, 22.10069084], [86.82540131, 22.10863113], [86.82331085, 22.11292076], [86.8208313, 22.11362076], [86.81484985, 22.11244011], [86.81217194, 22.11367035], [86.80621338, 22.11416054], [86.80438232, 22.11707115], [86.80796814, 22.12382126], [86.806633, 22.12536049], [86.80396271, 22.12613106], [86.79785919, 22.12528038], [86.79709625, 22.12613106], [86.79984283, 22.12848091], [86.80047607, 22.1304512], [86.799263, 22.13908958], [86.80045319, 22.1459198], [86.79032135, 22.1539402], [86.78681183, 22.15372276], [86.78283691, 22.15014076], [86.77694702, 22.1490097], [86.77153778, 22.14678001], [86.75670624, 22.14519119], [86.75222015, 22.14396095], [86.73953247, 22.14508247], [86.73233795, 22.14491081], [86.72280884, 22.14274025], [86.71544647, 22.14349174], [86.71520996, 22.15872002], [86.71689606, 22.16376114], [86.71534729, 22.17440987], [86.71277618, 22.17828941], [86.71335602, 22.18135262], [86.71721649, 22.18556976], [86.71607208, 22.19379997], [86.71766663, 22.19792938], [86.71996307, 22.21018982], [86.72278595, 22.21524811], [86.72534943, 22.21350098], [86.73375702, 22.21121979], [86.74106598, 22.21080971], [86.74780273, 22.20798111], [86.75509644, 22.20798111], [86.76703644, 22.21134186], [86.76992035, 22.21455002], [86.77522278, 22.21462822], [86.77455902, 22.2233696], [86.77207184, 22.22768021], [86.77275085, 22.23034286], [86.77588654, 22.23154068], [86.77996826, 22.23172188], [86.78681946, 22.2293396], [86.79220581, 22.22384262], [86.79115295, 22.22030067], [86.78250122, 22.22536278], [86.77892303, 22.22171974], [86.77601624, 22.21377945], [86.77906036, 22.21152115], [86.78356934, 22.21165085], [86.78594208, 22.21405029], [86.79136658, 22.21754074], [86.80011749, 22.21363068], [86.8091507, 22.2331028], [86.80986786, 22.23800278], [86.80137634, 22.23863029], [86.7995224, 22.23518944], [86.79756165, 22.23394966], [86.79283142, 22.23872948], [86.79316711, 22.24398994], [86.79068756, 22.25323105], [86.79026794, 22.26280022], [86.80062866, 22.26192284], [86.79641724, 22.24991035], [86.79846191, 22.24544907], [86.79650879, 22.24508095], [86.79691315, 22.24306107], [86.79960632, 22.24097252], [86.80242157, 22.24180984], [86.80394745, 22.24397087], [86.80660248, 22.24378014], [86.80744171, 22.24582291], [86.80895233, 22.2464695], [86.80996704, 22.24954987], [86.80919647, 22.25379944], [86.8113327, 22.25948143], [86.81186676, 22.26393127], [86.81256104, 22.25928116], [86.81382751, 22.2580204], [86.81633759, 22.2493], [86.81912231, 22.25354958], [86.82034302, 22.26061058], [86.82280731, 22.26132965], [86.82842255, 22.25922966], [86.83371735, 22.25959969], [86.83605194, 22.26078987], [86.84127045, 22.2571106], [86.85015106, 22.25926971], [86.85069275, 22.26049042], [86.85423279, 22.25678062], [86.85835266, 22.25443077], [86.86460876, 22.25348282], [86.86904907, 22.25464058], [86.87313843, 22.25447083], [86.88568115, 22.25212097], [86.88667297, 22.25900078], [86.88555908, 22.26342964], [86.88562775, 22.26890945], [86.88796234, 22.26958275], [86.88860321, 22.27569962], [86.88845062, 22.28141022], [86.88684845, 22.28668976], [86.88623047, 22.29412079], [86.88511658, 22.29670906], [86.88080597, 22.29640961], [86.87258911, 22.2987709], [86.87121582, 22.30266953], [86.86808014, 22.30458069], [86.86295319, 22.30381966], [86.84719086, 22.31315041], [86.84066772, 22.31381035], [86.8368988, 22.31675148], [86.82919312, 22.32459068], [86.82853699, 22.32949066], [86.83006287, 22.33839989], [86.82894135, 22.34150124], [86.83634186, 22.36087036], [86.84094238, 22.36902046], [86.83822632, 22.37861061], [86.84047699, 22.3842392], [86.84359741, 22.38764191], [86.8449173, 22.39232826], [86.84393311, 22.39606094], [86.83875275, 22.40135956], [86.83090973, 22.40637016], [86.81841278, 22.41230011], [86.8052597, 22.41649055], [86.78897858, 22.41825294], [86.77867889, 22.42149162], [86.76925659, 22.42158127], [86.76389313, 22.42288971], [86.76226044, 22.42523193], [86.75794983, 22.43565941], [86.75707245, 22.44244957], [86.75744629, 22.44638062], [86.7514801, 22.45067978], [86.74900055, 22.46033287], [86.74513245, 22.47053909], [86.7454071, 22.4756794], [86.74826813, 22.47866058], [86.75332642, 22.48011971], [86.76066589, 22.47891045], [86.76953125, 22.4759407], [86.77571106, 22.47730064], [86.78251648, 22.47735023], [86.7855072, 22.47665024], [86.78922272, 22.47451019], [86.79556274, 22.47968292], [86.79801178, 22.48398972], [86.797966, 22.48699188], [86.79701233, 22.48875809], [86.79296112, 22.49060059], [86.79096222, 22.49362946], [86.79860687, 22.49882126], [86.78962708, 22.50757027], [86.78930664, 22.50965118], [86.79177856, 22.51343918], [86.79139709, 22.51666069], [86.789711, 22.52038002], [86.7828064, 22.52437019], [86.78520966, 22.52931023], [86.78531647, 22.53244019], [86.78279114, 22.5357399], [86.78617096, 22.53741074], [86.78407288, 22.54424095], [86.77789307, 22.54541016], [86.77630615, 22.54700851], [86.77137756, 22.54583931], [86.77126312, 22.54831123], [86.76451874, 22.55063057], [86.76348114, 22.55252075], [86.76696014, 22.55603027], [86.76741791, 22.56088829], [86.76344299, 22.5646286], [86.7599411, 22.57242966], [86.75598907, 22.57427025], [86.72767639, 22.57463837], [86.70601654, 22.58036041], [86.68340302, 22.57676125], [86.67388916, 22.57349014], [86.67279816, 22.57238007], [86.66139984, 22.57443047], [86.65727997, 22.57270813], [86.65170288, 22.57579041], [86.64932251, 22.58204079], [86.65109253, 22.58426285], [86.64827728, 22.59160995], [86.63897705, 22.59375], [86.63432312, 22.59725952], [86.63400269, 22.60401154], [86.63239288, 22.60997963], [86.63510132, 22.62265968], [86.6367569, 22.63081932], [86.63548279, 22.64719963], [86.63668823, 22.65512085], [86.63037872, 22.66250992], [86.62236786, 22.66631126], [86.61786652, 22.67338943], [86.61016083, 22.67741966], [86.6029129, 22.67983055], [86.59670258, 22.68544006], [86.59121704, 22.68864059], [86.58078003, 22.68899155], [86.57401276, 22.69463921], [86.55510712, 22.70788002], [86.5495224, 22.7109108], [86.54634857, 22.71528816], [86.53925323, 22.72064972], [86.53369904, 22.71657944], [86.52017975, 22.71790123], [86.51644897, 22.71478081], [86.50995636, 22.71606064], [86.50805664, 22.70816994], [86.50955963, 22.70226288], [86.5065918, 22.70152092], [86.50035858, 22.7110405], [86.49653625, 22.7154808], [86.48993683, 22.71981049], [86.48774719, 22.72328949], [86.48162079, 22.72474098], [86.47898102, 22.72239113], [86.47001648, 22.73740768], [86.46666718, 22.74023056], [86.46604156, 22.74645042], [86.45401001, 22.75963974], [86.4438858, 22.7585907], [86.43982697, 22.76268005], [86.42887115, 22.76843071], [86.42198944, 22.7741909], [86.41615295, 22.77650833], [86.4126358, 22.78643036], [86.41796875, 22.78981972], [86.42159271, 22.80882072], [86.43390656, 22.82859039], [86.43300629, 22.83533287], [86.43321991, 22.84058952], [86.43126678, 22.84638023], [86.43283844, 22.8604908], [86.44687653, 22.85877991], [86.44769287, 22.86173058], [86.44667053, 22.86944962], [86.44928741, 22.87705994], [86.44696045, 22.8834095], [86.45101929, 22.88297081], [86.46304321, 22.89663124], [86.46234894, 22.89898109], [86.44845581, 22.90192032], [86.43241882, 22.91576958], [86.43113708, 22.92013931], [86.43282318, 22.92340279], [86.43708801, 22.92728996], [86.45104218, 22.93046951], [86.45820618, 22.93296051], [86.4580307, 22.93879128], [86.46206665, 22.94423103], [86.47012329, 22.94662285], [86.47042084, 22.94944954], [86.4743576, 22.94882965], [86.47344971, 22.94408035], [86.47872162, 22.9405899], [86.4838028, 22.93824959], [86.48452759, 22.9342804], [86.48680115, 22.93554115], [86.48943329, 22.94406128], [86.49246979, 22.94423103], [86.49401093, 22.94148827], [86.49577332, 22.94129181], [86.49772644, 22.94512939], [86.49662018, 22.94754028], [86.49868774, 22.94774055], [86.50757599, 22.94535828], [86.51272583, 22.94619179], [86.51835632, 22.94433022], [86.52339172, 22.94868088], [86.52757263, 22.95792961], [86.52662659, 22.96087074], [86.53244781, 22.96223259], [86.53851318, 22.96186829], [86.53774261, 22.96583939], [86.54203033, 22.97434044], [86.5402832, 22.9872303], [86.5341568, 22.98135948], [86.52076721, 22.97282982], [86.52271271, 22.97215843], [86.51876068, 22.96811295], [86.51223755, 22.96626091], [86.49991608, 22.96854019], [86.50762177, 22.97277069], [86.50401306, 22.97801971], [86.49730682, 22.98314857], [86.4973526, 22.98990822], [86.47936249, 22.98884964], [86.4749527, 22.98566055], [86.46618652, 22.98863029], [86.46308899, 22.98521805], [86.45108795, 22.98760986], [86.44779205, 22.9871006], [86.44522858, 22.98509026], [86.44168854, 22.98732948], [86.44056702, 22.99007988], [86.43170166, 22.99032974], [86.41628265, 22.99479103], [86.41052246, 22.98701859], [86.4003067, 22.98314095], [86.3968811, 22.97781944], [86.39303589, 22.97423935], [86.38730621, 22.97673035], [86.38360596, 22.98013115], [86.38096619, 22.98441124], [86.38044739, 22.99074936], [86.36949921, 22.99431038], [86.3632431, 22.99274826], [86.35997772, 22.99668121], [86.35160828, 22.99491119], [86.35048676, 22.98917961], [86.34648895, 22.9930191], [86.34133148, 22.99328041], [86.3347168, 22.98935127], [86.33215332, 22.98890114], [86.32585907, 22.9924202], [86.31529236, 22.99555969], [86.31217957, 22.99521065], [86.30989075, 22.9981308], [86.30992889, 23.00065041], [86.3059082, 23.00248909], [86.30211639, 23.00335121], [86.30020142, 23.00630188], [86.30042267, 23.00831985], [86.30069733, 23.01035118], [86.30030823, 23.01234055], [86.29825592, 23.01328278], [86.29751587, 23.01325989], [86.29638672, 23.0102005], [86.29482269, 23.00914192], [86.29400635, 23.00811005], [86.29191589, 23.00905037], [86.29199219, 23.0100708], [86.28475952, 23.01086044], [86.27937317, 23.0107193], [86.27552032, 23.00860023], [86.27350616, 23.00653076], [86.26972198, 23.00443077], [86.26500702, 23.00040054], [86.26328278, 22.99936104], [86.26378632, 22.99802971], [86.2612915, 22.99553108], [86.25086212, 22.99497986], [86.24508667, 22.99546051], [86.2386322, 22.99488831], [86.23448181, 22.99336815], [86.23095703, 22.99214172], [86.22706604, 22.99287033], [86.21697235, 22.99160957], [86.21247864, 22.9918499], [86.20642853, 22.99407005], [86.20381165, 22.99785805], [86.20024109, 23.00974846], [86.20436096, 23.0132103], [86.2008667, 23.01514244], [86.18118286, 23.01296043], [86.17838287, 23.01172066], [86.17562866, 23.01299095], [86.17249298, 23.02305031], [86.1667099, 23.02695084], [86.162323, 23.03380966], [86.16015625, 23.03906059], [86.15365601, 23.03722954], [86.15001678, 23.04089928], [86.14833069, 23.05266953], [86.14604187, 23.05572128], [86.1381073, 23.05932999], [86.13456726, 23.0629406], [86.13363647, 23.06990051], [86.13803864, 23.08048058], [86.13656616, 23.08310127], [86.12864685, 23.0857296], [86.12735748, 23.08908081], [86.11569214, 23.09363174], [86.11418152, 23.09196091], [86.10640717, 23.09028816], [86.10476685, 23.08889961], [86.09710693, 23.09166908], [86.09179688, 23.09077072], [86.08358765, 23.09859085], [86.08322144, 23.10093117], [86.08096313, 23.10429955], [86.07000732, 23.1014328], [86.05928802, 23.1055603], [86.047966, 23.10868073], [86.04424286, 23.11186028], [86.04653931, 23.12068748], [86.04897308, 23.12484932], [86.04839325, 23.12916946], [86.04199219, 23.13596916], [86.03692627, 23.14361], [86.03227234, 23.1450901], [86.02835846, 23.1457119], [86.0247879, 23.14319992], [86.01799774, 23.14048958], [86.01389313, 23.14164162], [86.00971985, 23.14497948], [86.00609589, 23.14490128], [86.00258636, 23.14616966], [85.99555969, 23.14442062], [85.99006653, 23.14628029], [85.98194122, 23.14590073], [85.97048187, 23.14002991], [85.9593277, 23.13977242], [85.95629883, 23.13947105], [85.95155334, 23.13816071], [85.94790649, 23.13396072], [85.9467392, 23.13088036], [85.94380951, 23.12947083], [85.93628693, 23.1296711], [85.92581177, 23.13065147], [85.92202759, 23.12939835], [85.92147064, 23.12593079], [85.91957092, 23.12695122], [85.91781616, 23.1311512], [85.91499329, 23.12952995], [85.91160583, 23.13358116], [85.90673828, 23.14207077], [85.900383, 23.1480999], [85.88916016, 23.1517601], [85.88640594, 23.15335083], [85.87731171, 23.15866089], [85.87657928, 23.16127968], [85.87780762, 23.17101288], [85.87721252, 23.17296028], [85.85984802, 23.19239044], [85.85752106, 23.19436264], [85.85192108, 23.19255066], [85.84391022, 23.19412994], [85.83500671, 23.19210052], [85.83241272, 23.1926403], [85.83155823, 23.19511986], [85.83371735, 23.20190048], [85.83281708, 23.20614052], [85.83072662, 23.21063995], [85.83068848, 23.21397018], [85.83184052, 23.21783066], [85.83067322, 23.24323082], [85.82636261, 23.26312065], [85.83365631, 23.2806797], [85.83912659, 23.2820797], [85.84173584, 23.28432083], [85.84446716, 23.28956985], [85.85240936, 23.2944603], [85.85785675, 23.3010807], [85.86149597, 23.30332947], [85.86077118, 23.31497955], [85.86830139, 23.31587982], [85.87523651, 23.32067108], [85.87798309, 23.32370949], [85.87751007, 23.32625961], [85.87535095, 23.32874107], [85.87159729, 23.33015823], [85.8708725, 23.35251999], [85.87277985, 23.35527992], [85.87301636, 23.35689926], [85.8666687, 23.36148071], [85.86625671, 23.36484909], [85.87503052, 23.36828041], [85.88527679, 23.37375832], [85.89337921, 23.36953926], [85.89569092, 23.37059021], [85.89585876, 23.37697983], [85.89434814, 23.37968063], [85.89057922, 23.38103294], [85.88247681, 23.3810997], [85.88212585, 23.38371086], [85.88478088, 23.38734055], [85.87731171, 23.40043068], [85.8782959, 23.4021492], [85.8817215, 23.40372086], [85.87845612, 23.40802956], [85.87419891, 23.41050911], [85.8722229, 23.40853119], [85.86287689, 23.40997124], [85.86089325, 23.42818069], [85.85975647, 23.44161987], [85.85954285, 23.45095062], [85.86206055, 23.45496941], [85.86354828, 23.45948982], [85.86602783, 23.4702301], [85.87007904, 23.47480011], [85.87412262, 23.47623062], [85.87757874, 23.4758606], [85.89125061, 23.47598076], [85.90637207, 23.47175026], [85.91269684, 23.46729851], [85.91752625, 23.46235085], [85.9379425, 23.45513916], [85.94390869, 23.45462036], [85.94979858, 23.45545006], [85.95289612, 23.45962906], [85.95717621, 23.46193123], [85.96781921, 23.46537018], [85.97566223, 23.47072983], [85.99037933, 23.47637939], [85.99475098, 23.47553253], [86.00137329, 23.47879982], [86.00557709, 23.48269081], [86.01023102, 23.48315048], [86.01545715, 23.48516083], [86.02037048, 23.48791122], [86.02559662, 23.48808098], [86.02906799, 23.48715973], [86.03575134, 23.49032021], [86.04136658, 23.49024963], [86.04722595, 23.49364281], [86.05150604, 23.49900055], [86.0508728, 23.50155067], [86.04860687, 23.5026207], [86.03276825, 23.50484085], [86.03269196, 23.51802254], [86.03156281, 23.52096748], [86.02703857, 23.52425003], [86.02506256, 23.53174973], [86.01854706, 23.54243088], [86.02110291, 23.54549026], [86.01077271, 23.55164909], [86.01100922, 23.56124115], [86.01760864, 23.56361008], [86.02511597, 23.57229805], [86.03009796, 23.57476044], [86.03533936, 23.57509041], [86.0373764, 23.58345985], [86.04686737, 23.58386993], [86.05133057, 23.57889938], [86.06530762, 23.58073044], [86.07144165, 23.57847977], [86.07276917, 23.56822014], [86.08268738, 23.56857109], [86.08795929, 23.5676403], [86.09358215, 23.57001114], [86.09835815, 23.570961], [86.10154724, 23.57389832], [86.10485077, 23.57196045], [86.1102066, 23.57073021], [86.11943817, 23.57391167], [86.1266861, 23.56674957], [86.13172913, 23.56623077], [86.13607025, 23.56926918], [86.13861084, 23.57002068], [86.14476776, 23.56777191], [86.14819336, 23.56542015], [86.14842987, 23.56393051], [86.14628601, 23.55866051], [86.14846802, 23.55550957], [86.15326691, 23.55159187], [86.15273285, 23.5482502], [86.14969635, 23.54117966], [86.14427948, 23.53524017], [86.14292908, 23.52734184], [86.15455627, 23.51914978], [86.15328979, 23.50975037], [86.15511322, 23.5042305], [86.14517975, 23.49398994], [86.14585876, 23.48612976], [86.14331055, 23.4812603], [86.14267731, 23.47733116], [86.1455307, 23.47307014], [86.15296173, 23.47698975], [86.16792297, 23.47608948], [86.17233276, 23.47854042], [86.17914581, 23.47512054], [86.1787796, 23.46772957], [86.18102264, 23.46692085], [86.18676758, 23.46837044], [86.19180298, 23.46442032], [86.19536591, 23.46347046], [86.19956207, 23.46404839], [86.20326233, 23.45868111], [86.20970917, 23.45923042], [86.22097778, 23.4559803], [86.22406006, 23.4572506], [86.22319794, 23.46480751], [86.22532654, 23.46988106], [86.23226929, 23.47072029], [86.23874664, 23.46969032], [86.23517609, 23.45598984], [86.22735596, 23.44960976], [86.22502136, 23.4428196], [86.22466278, 23.43568039], [86.23110962, 23.42951965], [86.23954773, 23.43168068], [86.2390976, 23.42571068], [86.23989105, 23.42258072], [86.24317932, 23.41958046], [86.24646759, 23.41918945], [86.25083923, 23.42221069], [86.25305176, 23.42485046], [86.24794769, 23.43083954], [86.2466507, 23.4341526], [86.25006104, 23.43559074], [86.25244141, 23.43749046], [86.25784302, 23.43821907], [86.26374817, 23.43657112], [86.26629639, 23.43795967], [86.26719666, 23.44000053], [86.27348328, 23.43894958], [86.2784729, 23.44112015], [86.2806778, 23.43960953], [86.28115082, 23.43544769], [86.28237152, 23.42745972], [86.28967285, 23.42287064], [86.30000305, 23.42006111], [86.3133316, 23.42606163], [86.3142395, 23.42828941], [86.31286621, 23.43143082], [86.31227875, 23.43732071], [86.30998993, 23.43761063], [86.30578613, 23.43618011], [86.30034637, 23.4406395], [86.30014801, 23.44371033], [86.30647278, 23.44820976], [86.31208801, 23.44860077], [86.31511688, 23.45267105], [86.3212204, 23.45448112], [86.32621002, 23.45756149], [86.32863617, 23.45498085], [86.32926941, 23.44824028], [86.33135986, 23.44724083], [86.34041595, 23.45239258], [86.33834076, 23.45697975], [86.33789825, 23.46109009], [86.34703827, 23.46116257], [86.35183716, 23.46363068], [86.35222626, 23.46819115], [86.34897614, 23.47249985], [86.35549927, 23.48155975], [86.36440277, 23.48214912], [86.36850739, 23.48396111], [86.37052155, 23.48163986], [86.37194824, 23.48266029], [86.37214661, 23.48607826], [86.37059784, 23.49026108], [86.36205292, 23.49188995], [86.3585968, 23.48958969], [86.35370636, 23.49641991], [86.35706329, 23.51025009], [86.35690308, 23.51288986], [86.36503601, 23.51543808], [86.36701202, 23.51885986], [86.36765289, 23.52255821], [86.36495209, 23.52548981], [86.36383057, 23.52807045], [86.35965729, 23.53067017], [86.3587265, 23.53363991], [86.36048126, 23.53848076], [86.35797119, 23.5430603], [86.36048126, 23.54612923], [86.36160278, 23.54966164], [86.36422729, 23.55134964], [86.36480713, 23.55705261], [86.36789703, 23.55920982], [86.37304688, 23.5613308], [86.37486267, 23.56851959], [86.37812042, 23.56883812], [86.38288116, 23.57201958], [86.38176727, 23.57550049], [86.38220215, 23.5789299], [86.38092804, 23.58436012], [86.38697052, 23.58535957], [86.38941956, 23.58877945], [86.40019226, 23.58945274], [86.40622711, 23.58798027], [86.41036987, 23.59802246], [86.41356659, 23.60133171], [86.41821289, 23.60341263], [86.42466736, 23.60491943], [86.42727661, 23.61033058], [86.43045807, 23.61111069], [86.43456268, 23.60845184], [86.43963623, 23.60910034], [86.43959808, 23.61667252], [86.43791962, 23.62417984], [86.43847656, 23.62779236], [86.43988037, 23.62961006], [86.44490814, 23.63153267], [86.46642303, 23.6296196], [86.47162628, 23.6312809], [86.48129272, 23.63503838], [86.50171661, 23.63157845], [86.51187897, 23.62906075], [86.5236969, 23.62836075], [86.52865601, 23.62898064], [86.53743744, 23.63462067], [86.55201721, 23.64009285], [86.56524658, 23.64627075], [86.58310699, 23.65884018], [86.59062195, 23.66224098], [86.58850861, 23.66544151], [86.58796692, 23.66908073], [86.59160614, 23.67115021], [86.61580658, 23.6716404], [86.62444305, 23.67276955], [86.63334656, 23.6757412], [86.64884949, 23.68287086], [86.66873169, 23.68605042], [86.68334961, 23.68974113], [86.69384766, 23.69452095], [86.71100616, 23.69722939], [86.73169708, 23.69379044], [86.73654938, 23.68876076], [86.73591614, 23.6790905], [86.73812866, 23.6776104], [86.75850677, 23.67848015], [86.77269745, 23.68188095], [86.79203796, 23.6873703], [86.79567719, 23.69347954], [86.79305267, 23.69502258], [86.79093933, 23.69849968], [86.79351044, 23.70601273], [86.79837036, 23.71634102], [86.80451202, 23.73985291], [86.80800629, 23.74381065], [86.81163025, 23.74480057], [86.81610107, 23.74483109], [86.81933594, 23.75226974], [86.81977081, 23.76107025], [86.81671906, 23.77614975], [86.80841064, 23.78827095], [86.79769135, 23.79771805], [86.80097198, 23.8133297], [86.79747009, 23.82403946], [86.79220581, 23.82726288], [86.79283905, 23.83138084], [86.79738617, 23.83186913], [86.80018616, 23.83263016], [86.80367279, 23.83068085], [86.80647278, 23.8281002], [86.80786896, 23.82455254], [86.80702209, 23.81814957], [86.80930328, 23.81413078], [86.813797, 23.81216049], [86.82077026, 23.81130981], [86.82591248, 23.81319809], [86.83500671, 23.81925964], [86.84442902, 23.82185173], [86.8544693, 23.83247757], [86.85704803, 23.83950043], [86.86084747, 23.84217262], [86.87121582, 23.84418106], [86.87309265, 23.83448029], [86.87329102, 23.82723045], [86.87693024, 23.82133102], [86.87693024, 23.81344986], [86.88226318, 23.81447983], [86.88437653, 23.81920052], [86.88768768, 23.82216072], [86.88690948, 23.82732964], [86.88474274, 23.83049011], [86.88478851, 23.83436966], [86.88017273, 23.84220123], [86.88226318, 23.85661125], [86.8753891, 23.85745049], [86.87526703, 23.86238098], [86.88008881, 23.86650085], [86.88461304, 23.87335014], [86.89138031, 23.87639046], [86.8950119, 23.87995148], [86.90365601, 23.8789711], [86.90688324, 23.87951088], [86.92415619, 23.86588097], [86.92540741, 23.85384178], [86.92813873, 23.84995842], [86.93637848, 23.84486008], [86.94319916, 23.84286118], [86.95123291, 23.84587097], [86.95575714, 23.84961128], [86.95771027, 23.85913086], [86.95957184, 23.86231041], [86.96304321, 23.8647728], [86.96691132, 23.86529922], [86.97187805, 23.86283112], [86.98013306, 23.85638046], [86.99455261, 23.85353088], [87.00205994, 23.85248947], [87.01345825, 23.8469429], [87.02243042, 23.84052277], [87.03440857, 23.83682823], [87.0569458, 23.81625938], [87.06423187, 23.81349945], [87.07276917, 23.81233978], [87.07660675, 23.80911064], [87.0845108, 23.80526924], [87.08840179, 23.80780983], [87.09130096, 23.80961037], [87.09572601, 23.80948067], [87.10592651, 23.79952049], [87.10771179, 23.80187035], [87.11258698, 23.80553818], [87.1160965, 23.80480194], [87.11633301, 23.80196953], [87.1146698, 23.80008125], [87.11025238, 23.79906273], [87.11299896, 23.79681015], [87.12416077, 23.79503822], [87.13362885, 23.79634094], [87.13920593, 23.80006027], [87.14354706, 23.79636192], [87.14874268, 23.79437065], [87.15364838, 23.79845047], [87.15592957, 23.80372047], [87.16644287, 23.81958961], [87.16220856, 23.82761955], [87.15912628, 23.82830048], [87.15399933, 23.82574081], [87.14581299, 23.83661079], [87.13772583, 23.84580994], [87.13033295, 23.85091019], [87.12944031, 23.85490036], [87.12963104, 23.8581295], [87.12786102, 23.86244011], [87.13092804, 23.86696053], [87.13581848, 23.86813927], [87.13860321, 23.86740112], [87.14076996, 23.86510086], [87.14750671, 23.86268234], [87.1529007, 23.86559105], [87.1566925, 23.86488914], [87.16668701, 23.8604908], [87.16911316, 23.8577919], [87.17295074, 23.85622025], [87.17662048, 23.85246277], [87.18060303, 23.85153008], [87.18427277, 23.852911], [87.18736267, 23.85717964], [87.19565582, 23.85425949], [87.19541931, 23.8508606], [87.18869781, 23.84631157], [87.18856812, 23.84083748], [87.19164276, 23.84044266], [87.19433594, 23.84212112], [87.19944763, 23.84749985], [87.20302582, 23.84617233], [87.2073288, 23.85301018], [87.21282196, 23.85027122], [87.21675873, 23.85094261], [87.22248077, 23.85763931], [87.22782898, 23.85530281], [87.23623657, 23.85306931], [87.23513794, 23.84824181], [87.23174286, 23.84456062], [87.22796631, 23.84290123], [87.22410583, 23.84268951], [87.22235107, 23.83483124], [87.21855927, 23.83080101], [87.21975708, 23.82720947], [87.22912598, 23.82300949], [87.23375702, 23.82534981], [87.23880005, 23.82485008], [87.24272919, 23.82616043], [87.24572754, 23.82807159], [87.25521851, 23.83930016], [87.25270081, 23.84286118], [87.25152588, 23.84766006], [87.24742889, 23.85131073], [87.24608612, 23.85658073], [87.24904633, 23.86582947], [87.24487305, 23.86840057], [87.24442291, 23.87807846], [87.24530029, 23.88060951], [87.24311066, 23.8848629], [87.24608612, 23.89493942], [87.2443161, 23.90039063], [87.24822235, 23.90701103], [87.25242615, 23.91011047], [87.25666046, 23.90759277], [87.25920105, 23.90420151], [87.25987244, 23.90211105], [87.25630951, 23.89814949], [87.26088715, 23.89217949], [87.26412964, 23.87997055], [87.26174927, 23.87817192], [87.26493073, 23.87482834], [87.27041626, 23.87294006], [87.27832031, 23.88194847], [87.28129578, 23.88420105], [87.28552246, 23.88361168], [87.29258728, 23.89014053], [87.2906723, 23.89870071], [87.29454803, 23.89857101], [87.28768921, 23.92023087], [87.28782654, 23.9259491], [87.28513336, 23.93388939], [87.29193115, 23.93875122], [87.2904892, 23.94745255], [87.29181671, 23.95569992], [87.28666687, 23.95749092], [87.27805328, 23.95755959], [87.26925659, 23.96532059], [87.26452637, 23.9634819], [87.26154327, 23.96616936], [87.25953674, 23.96992111], [87.26072693, 23.97809029], [87.26602173, 23.9818306], [87.26802826, 23.98463058], [87.26692963, 23.98777962], [87.26206207, 23.99509048], [87.26271057, 23.99912071], [87.26081848, 24.00290108], [87.25718689, 23.99978065], [87.25640869, 23.99909019], [87.25621033, 23.99827003], [87.25595856, 23.99788094], [87.25565338, 23.99751091], [87.25531006, 23.99716949], [87.25493622, 23.99689102], [87.2545166, 23.99661064], [87.25408936, 23.99636078], [87.25363159, 23.99614906], [87.25311279, 23.99599075], [87.25260162, 23.99587059], [87.25208282, 23.99578094], [87.25157928, 23.99572754], [87.251091, 23.99571037], [87.25060272, 23.99572754], [87.25009918, 23.99578094], [87.24960327, 23.99587059], [87.24909973, 23.99599075], [87.24862671, 23.99612999], [87.24816132, 23.99632072], [87.24769592, 23.99653053], [87.24727631, 23.99677086], [87.24687195, 23.99702072], [87.24616241, 23.99765015], [87.24581146, 23.99802017], [87.24539948, 23.99855042], [87.24356842, 24.00101089], [87.24059296, 24.00572014], [87.24034882, 24.01066017], [87.23922729, 24.01478004], [87.23536682, 24.01754951], [87.23265076, 24.02459908], [87.23348236, 24.03268814], [87.23480225, 24.03731918], [87.23797607, 24.04121971], [87.24359894, 24.04211998], [87.2490387, 24.04012108], [87.25345612, 24.03734016], [87.2578125, 24.0354805], [87.26387024, 24.03469086], [87.26918793, 24.03301048], [87.27427673, 24.03184128], [87.27915955, 24.02935982], [87.28264618, 24.02692986], [87.28621674, 24.02717972], [87.28956604, 24.03030968], [87.29654694, 24.03016281], [87.30368042, 24.02937126], [87.30877686, 24.0319519], [87.31373596, 24.03239059], [87.31997681, 24.03144073], [87.32628632, 24.03013039], [87.33235931, 24.03100967], [87.33550262, 24.02386284], [87.33319092, 24.0222702], [87.3323288, 24.01753998], [87.32743073, 24.01662064], [87.32417297, 24.01748085], [87.32225037, 24.01316261], [87.32054138, 24.00927925], [87.31828308, 24.00687027], [87.31581116, 24.00708961], [87.31539154, 24.00442123], [87.31788635, 24.00152016], [87.31989288, 23.99917984], [87.32395935, 23.99706268], [87.32787323, 23.99599075], [87.3372879, 23.99495125], [87.34810638, 23.99579048], [87.3502121, 23.99697113], [87.35098267, 23.99920273], [87.35334778, 24.00225067], [87.35484314, 24.00559807], [87.35663605, 24.00918961], [87.36038971, 24.00734138], [87.36479187, 24.00677109], [87.37400818, 24.00657845], [87.37687683, 24.00317001], [87.38234711, 24.00270081], [87.38976288, 24.00196266], [87.39389038, 23.99924088], [87.39427185, 23.99653053], [87.4003067, 23.99392128], [87.41452789, 23.99084282], [87.4185791, 23.98935127], [87.42212677, 23.99080086], [87.42637634, 23.99032021], [87.42735291, 23.98792839], [87.42758942, 23.98397064], [87.4292984, 23.98186111], [87.43398285, 23.98168945], [87.43656158, 23.97915077], [87.43910217, 23.97813034], [87.44547272, 23.98146057], [87.44898224, 23.98429108], [87.45359802, 23.98339081], [87.45796967, 23.98142052], [87.45980072, 23.98483276], [87.45835876, 23.99349976], [87.45487976, 23.99689102], [87.45067596, 23.99924088], [87.45018768, 23.99999046], [87.44676971, 24.00062943], [87.44330597, 24.00094032], [87.44139862, 24.00323105], [87.44246674, 24.00530052], [87.44487762, 24.00576019], [87.44610596, 24.00696945], [87.44676971, 24.00835037], [87.44423676, 24.00909996], [87.44087219, 24.00946045], [87.43844604, 24.00904083], [87.43678284, 24.00781059], [87.43464661, 24.00686073], [87.43383026, 24.00832176], [87.43650055, 24.01094246], [87.43872833, 24.01251984], [87.44316101, 24.01375961], [87.44625092, 24.01428986], [87.44851685, 24.01634026], [87.45226288, 24.01506042], [87.45490265, 24.01496124], [87.45691681, 24.01406288], [87.45926666, 24.01297951], [87.46209717, 24.01311111], [87.46393585, 24.01262093], [87.46733856, 24.01217842], [87.46924591, 24.01156235], [87.4713974, 24.01089096], [87.47345734, 24.01143265], [87.47619629, 24.01301193], [87.47915649, 24.0141201], [87.48275757, 24.0136528], [87.48642731, 24.01595116], [87.48847961, 24.01933098], [87.4912262, 24.02337074], [87.49476624, 24.02435112], [87.49649048, 24.02316093], [87.5013504, 24.02232933], [87.50131226, 24.02609062], [87.50196075, 24.02815056], [87.50393677, 24.03009033], [87.50670624, 24.03199959], [87.5090332, 24.03467941], [87.51055145, 24.03983116], [87.50845337, 24.0425396], [87.50784302, 24.04566956], [87.5042572, 24.04618263], [87.50137329, 24.04751015], [87.49539185, 24.04997063], [87.4912262, 24.05202103], [87.49185181, 24.05553055], [87.49331665, 24.05924988], [87.49423218, 24.06265068], [87.49252319, 24.06470108], [87.49075317, 24.06657028], [87.48890686, 24.06966019], [87.48973083, 24.07323074], [87.49318695, 24.07473946], [87.49685669, 24.07369041], [87.49978638, 24.07254028], [87.50123596, 24.07331848], [87.50260162, 24.07526016], [87.50357056, 24.07766914], [87.50535583, 24.07942963], [87.50578308, 24.08208084], [87.50216675, 24.0832901], [87.4980011, 24.08435059], [87.49324036, 24.08460045], [87.49001312, 24.08546829], [87.48892212, 24.08819962], [87.48964691, 24.09004021], [87.49353027, 24.09309006], [87.49281311, 24.09547043], [87.49365234, 24.09724045], [87.49584961, 24.0971508], [87.49694824, 24.0993309], [87.49656677, 24.1026783], [87.49536896, 24.10547066], [87.49384308, 24.10815048], [87.49310303, 24.11193085], [87.49359894, 24.11520958], [87.49659729, 24.11580086], [87.49951172, 24.11458015], [87.50293732, 24.1128006], [87.50717926, 24.11128044], [87.51052856, 24.1103611], [87.51367188, 24.11082077], [87.516922, 24.11100006], [87.51889038, 24.10872078], [87.51991272, 24.1058712], [87.52130127, 24.10423088], [87.52406311, 24.10370827], [87.52693939, 24.10378075], [87.52986145, 24.10240936], [87.53069305, 24.09921074], [87.53096771, 24.09486961], [87.53449249, 24.09140968], [87.53916931, 24.08780098], [87.54419708, 24.0865612], [87.54825592, 24.08546066], [87.55261993, 24.0845108], [87.55628204, 24.08230972], [87.5597229, 24.08288956], [87.56344604, 24.08450127], [87.56672668, 24.08641052], [87.57021332, 24.08762169], [87.57316589, 24.0862999], [87.57615662, 24.08526039], [87.57644653, 24.08710098], [87.5743103, 24.09015083], [87.57064819, 24.09547043], [87.56949615, 24.10098076], [87.5692215, 24.10675049], [87.57211304, 24.10971069], [87.5748291, 24.1089592], [87.57779694, 24.11042023], [87.57965088, 24.11501122], [87.57952118, 24.11951065], [87.58172607, 24.12339973], [87.59262085, 24.12424088], [87.59541321, 24.12487984], [87.60041046, 24.12537003], [87.60481262, 24.12656975], [87.60761261, 24.12894249], [87.6049118, 24.1321106], [87.60119629, 24.13517952], [87.59794617, 24.1379509], [87.59391785, 24.14147949], [87.59004211, 24.14410019], [87.58602142, 24.14752007], [87.58087158, 24.15044022], [87.57646942, 24.15275955], [87.57142639, 24.15440941], [87.56938171, 24.15565109], [87.5766983, 24.15888023], [87.57975006, 24.16153908], [87.58407593, 24.16146088], [87.59037781, 24.1600914], [87.5955658, 24.15980911], [87.59957886, 24.16050911], [87.60415649, 24.16399956], [87.6104126, 24.16488075], [87.61605835, 24.1646595], [87.62166595, 24.16386986], [87.62754059, 24.16313171], [87.63162994, 24.16028976], [87.63632965, 24.15738106], [87.64067078, 24.15493011], [87.6457901, 24.15379906], [87.65054321, 24.15452957], [87.6569519, 24.15591049], [87.66361237, 24.15427971], [87.66777802, 24.15143967], [87.67353058, 24.15134048], [87.68016815, 24.14797974], [87.68435669, 24.14916992], [87.68956757, 24.1498394], [87.69248199, 24.15447044], [87.69364166, 24.15917015], [87.6932373, 24.16434097], [87.69645691, 24.16721153], [87.69641113, 24.17131042], [87.69667816, 24.17534828], [87.69378662, 24.1784687], [87.69399261, 24.18197823], [87.69255829, 24.18618011], [87.68891144, 24.18514061], [87.68353271, 24.18905258], [87.67830658, 24.19111061], [87.67460632, 24.1952095], [87.67378998, 24.20049095], [87.67095184, 24.20573807], [87.6661377, 24.20611191], [87.65901947, 24.20740128], [87.65278625, 24.20618248], [87.64509583, 24.20799065], [87.63772583, 24.21158028], [87.63844299, 24.21614075], [87.64151001, 24.21960068], [87.64315796, 24.22459984], [87.643013, 24.23010063], [87.63951874, 24.23472023], [87.63658142, 24.23818016], [87.63571167, 24.24253082], [87.64002991, 24.24603081], [87.64173126, 24.24986076], [87.64714813, 24.24855995], [87.64929962, 24.24662018], [87.64985657, 24.24365997], [87.6519165, 24.24015045], [87.65429688, 24.23658943], [87.65703583, 24.23539925], [87.6590271, 24.23835754], [87.66028595, 24.2419796], [87.66190338, 24.24495125], [87.6654129, 24.24349022], [87.66876984, 24.24274063], [87.67067719, 24.24427986], [87.67384338, 24.24670029], [87.67791748, 24.24645233], [87.68135834, 24.24644089], [87.68309784, 24.24855042], [87.68496704, 24.25284958], [87.6886673, 24.25560951], [87.69301605, 24.25739098], [87.69740295, 24.25972939], [87.70263672, 24.25992012], [87.70452881, 24.26375961], [87.70598602, 24.2678299], [87.70543671, 24.27170944], [87.70461273, 24.2745018], [87.70617676, 24.2781105], [87.70833588, 24.28038979], [87.7094574, 24.28290939], [87.71008301, 24.28657913], [87.71031952, 24.29207039], [87.71573639, 24.29001045], [87.71977234, 24.28803062], [87.72395325, 24.28749275], [87.72718811, 24.28622055], [87.73015594, 24.2876091], [87.73304749, 24.28791046], [87.73638153, 24.28894043], [87.73620605, 24.29199982], [87.74046326, 24.29272842], [87.74312592, 24.29772186], [87.7457428, 24.29980278], [87.74819946, 24.30148125], [87.75209808, 24.30465126], [87.75627899, 24.30359268], [87.75849915, 24.30783081], [87.76035309, 24.31303978], [87.75946045, 24.31688118], [87.76007843, 24.31952095], [87.76248169, 24.32068062], [87.76448059, 24.32279015], [87.76420593, 24.32522011], [87.76055908, 24.32817078], [87.7612381, 24.33331108], [87.76451874, 24.3385601], [87.7678833, 24.34045982], [87.76941681, 24.34539986], [87.77262878, 24.34938049], [87.77658844, 24.35341072], [87.77922821, 24.35705948], [87.78235626, 24.3602314], [87.78494263, 24.36763191], [87.78765106, 24.37166977], [87.78994751, 24.37701035], [87.79376984, 24.38076019], [87.79750824, 24.38218117], [87.7975769, 24.38606071], [87.79811096, 24.3907795], [87.7973175, 24.39229965], [87.79469299, 24.39217949], [87.79263306, 24.3930912], [87.79257965, 24.39644051], [87.79476929, 24.40007973], [87.79821014, 24.39973068], [87.8015213, 24.40192032], [87.80425262, 24.40354919], [87.80745697, 24.40435982], [87.81002045, 24.40662003], [87.80899048, 24.40923119], [87.80847931, 24.41213036], [87.80639648, 24.41472054], [87.80522156, 24.41814041], [87.80134583, 24.41341972], [87.79862976, 24.41122246], [87.79297638, 24.41063118], [87.78790283, 24.41152954], [87.78475189, 24.41454124], [87.78620911, 24.41862106], [87.79003143, 24.42167091], [87.79220581, 24.4238205], [87.79226685, 24.42687035], [87.79038239, 24.42939949], [87.7881012, 24.43209267], [87.78978729, 24.43465996], [87.79103851, 24.4377594], [87.79290009, 24.43980026], [87.79595184, 24.43939972], [87.79688263, 24.44186974], [87.79988098, 24.44371986], [87.79972076, 24.44544983], [87.80094147, 24.4473896], [87.80251312, 24.45014], [87.80687714, 24.45259857], [87.81125641, 24.4518795], [87.81494904, 24.45134926], [87.81524658, 24.45359993], [87.81614685, 24.45531273], [87.81735992, 24.4589901], [87.81772614, 24.46232033], [87.81659698, 24.46547127], [87.81784821, 24.46845055], [87.81478882, 24.47006035], [87.8137207, 24.47274017], [87.81138611, 24.47480965], [87.80909729, 24.47659111], [87.81035614, 24.48037148], [87.8130188, 24.48512077], [87.81685638, 24.48608017], [87.82025909, 24.48584938], [87.82099152, 24.48843002], [87.82145691, 24.49008942], [87.82244873, 24.49234009], [87.82287598, 24.49440956], [87.82190704, 24.49644089], [87.8197403, 24.49591064], [87.82022095, 24.49347115], [87.81867981, 24.49205971], [87.81555939, 24.4928093], [87.81225586, 24.4915905], [87.81021118, 24.49209023], [87.81001282, 24.49452972], [87.81111145, 24.49641991], [87.81178284, 24.49900055], [87.81021881, 24.50204086], [87.80831146, 24.50456047], [87.80734253, 24.50619125], [87.80758667, 24.5093708], [87.80667114, 24.51060104], [87.80526733, 24.50963974], [87.80391693, 24.50723076], [87.80374146, 24.50476074], [87.80342865, 24.50164032], [87.80298615, 24.49864006], [87.80101776, 24.49481964], [87.79853058, 24.49185944], [87.79515076, 24.49105072], [87.79380035, 24.49426079], [87.79260254, 24.49722862], [87.7939682, 24.50032043], [87.79823303, 24.50242996], [87.79994202, 24.50424957], [87.79850769, 24.50699997], [87.79850006, 24.50942993], [87.79972076, 24.51172066], [87.80116272, 24.51463127], [87.80121613, 24.51769066], [87.79901886, 24.52091026], [87.79756927, 24.52462959], [87.79712677, 24.53001022], [87.79798126, 24.53535843], [87.79749298, 24.53866959], [87.79985046, 24.54116058], [87.8035965, 24.54010963], [87.8057785, 24.54244041], [87.80634308, 24.54520035], [87.8048172, 24.54922104], [87.80261993, 24.55428123], [87.79936981, 24.55890083], [87.7961731, 24.56238174], [87.79158783, 24.56568909], [87.78572845, 24.56858063], [87.77774811, 24.57138062], [87.77317047, 24.57188034], [87.76757813, 24.57156944], [87.76792145, 24.57602119], [87.76940918, 24.58176041], [87.77966309, 24.58209038], [87.78536224, 24.5823307], [87.79067993, 24.58107948], [87.79505157, 24.57966995], [87.79889679, 24.57781029], [87.80224609, 24.57802963], [87.80500793, 24.57752037], [87.80899811, 24.576231], [87.81166077, 24.57444], [87.81420898, 24.57261276], [87.81685638, 24.57007027], [87.82015228, 24.5683918], [87.82327271, 24.56655121], [87.82388306, 24.56335258], [87.82450867, 24.55948257], [87.82698822, 24.55816078], [87.83480072, 24.55632973], [87.84111023, 24.55441093], [87.84497833, 24.55278015], [87.8482132, 24.55105019], [87.84996033, 24.5537281], [87.84921265, 24.5569191], [87.85047913, 24.55783272], [87.85378265, 24.55603027], [87.85632324, 24.55459023], [87.860466, 24.55526161], [87.86389923, 24.55657959], [87.86443329, 24.55870819], [87.86585999, 24.56083107], [87.86863708, 24.5612812], [87.87661743, 24.56108284], [87.8807373, 24.56295967], [87.88732147, 24.56270981], [87.88989258, 24.57191086], [87.89025879, 24.57472992], [87.89148712, 24.57962036], [87.89608765, 24.58062172], [87.89737701, 24.58245087], [87.89940643, 24.58357048], [87.90326691, 24.58238983], [87.90544891, 24.58380127], [87.90683746, 24.58735085], [87.90873718, 24.5911808], [87.90997314, 24.59386826], [87.90912628, 24.5963726], [87.90762329, 24.59939766], [87.90773773, 24.60436821], [87.9081192, 24.60817909], [87.90290833, 24.60804176], [87.8986969, 24.60807037], [87.89348602, 24.60834122], [87.88871002, 24.60820961], [87.88802338, 24.60532951], [87.88613129, 24.60514069], [87.88118744, 24.60696983], [87.87799835, 24.60944939], [87.87596893, 24.60885811], [87.87528992, 24.60990906], [87.87354279, 24.60931969], [87.8727417, 24.61071968], [87.87346649, 24.61347008], [87.87483215, 24.61552048], [87.87700653, 24.61629105], [87.87911224, 24.61475182], [87.88215637, 24.61359024], [87.88552094, 24.61178017], [87.88828278, 24.61133003], [87.89118195, 24.61219978], [87.89383698, 24.61296272], [87.89631653, 24.61186981], [87.89948273, 24.6114006], [87.90161133, 24.61258125], [87.90213013, 24.61650085], [87.90139008, 24.62002945], [87.90180206, 24.62257004], [87.90225983, 24.62592125], [87.89885712, 24.62574005], [87.89539337, 24.62449265], [87.89177704, 24.62368011], [87.887146, 24.62446976], [87.88461304, 24.62664986], [87.8868103, 24.62949944], [87.88886261, 24.63142014], [87.89227295, 24.63204956], [87.8968811, 24.6303997], [87.90000153, 24.62942123], [87.90200806, 24.62943077], [87.90428925, 24.63042068], [87.90629578, 24.63264275], [87.9076767, 24.63678169], [87.90796661, 24.64208984], [87.90785217, 24.64682961], [87.90886688, 24.65130997], [87.91013336, 24.65493011], [87.91340637, 24.6585598], [87.91159821, 24.66229057], [87.90647888, 24.66436005], [87.90319824, 24.66695976], [87.89990997, 24.6693306], [87.89507294, 24.66850281], [87.89038086, 24.67033005], [87.88661957, 24.67410278], [87.88625336, 24.67808914], [87.88941193, 24.68177986], [87.89274597, 24.68574905], [87.89656067, 24.69066048], [87.897789, 24.69497108], [87.8990097, 24.69968033], [87.8961792, 24.7024498], [87.89750671, 24.70647049], [87.89884949, 24.7098999], [87.90091705, 24.71050262], [87.90291595, 24.70993805], [87.90313721, 24.71190071], [87.9033432, 24.71455956], [87.90215302, 24.71849823], [87.90083313, 24.72159958], [87.89565277, 24.72302055], [87.89077759, 24.72258949], [87.8871994, 24.72544289], [87.88545227, 24.72929955], [87.88423157, 24.73347092], [87.88244629, 24.73627281], [87.8777771, 24.73908043], [87.87493896, 24.73508835], [87.87088013, 24.73002815], [87.86738586, 24.72940063], [87.86103821, 24.73125076], [87.85234833, 24.73493958], [87.83970642, 24.7381897], [87.82533264, 24.75221062], [87.82050323, 24.75206947], [87.81607819, 24.75204086], [87.81389618, 24.75336075], [87.81603241, 24.75960922], [87.81806183, 24.76598167], [87.82209015, 24.76671982], [87.82565308, 24.76931], [87.82785034, 24.77192116], [87.82836914, 24.77670288], [87.83001709, 24.78297043], [87.83368683, 24.78786087], [87.83753204, 24.78780174], [87.83847046, 24.78470993], [87.83899689, 24.78014183], [87.83687592, 24.77734947], [87.833992, 24.77464104], [87.83378601, 24.76968002], [87.83376312, 24.7658596], [87.83524323, 24.76323128], [87.83885956, 24.76536179], [87.84246826, 24.76285934], [87.84677887, 24.7610302], [87.85022736, 24.76127052], [87.85453796, 24.76431084], [87.8584671, 24.76781082], [87.85999298, 24.77200127], [87.86538696, 24.7743206], [87.86650848, 24.77614975], [87.86486053, 24.7785511], [87.86654663, 24.78244972], [87.86810303, 24.7870903], [87.87005615, 24.79087067], [87.87233734, 24.79193115], [87.87291718, 24.78977013], [87.87475586, 24.78980064], [87.87666321, 24.79368973], [87.87751007, 24.79800034], [87.87760925, 24.80101013], [87.87583923, 24.80311012], [87.87284851, 24.8052597], [87.87271881, 24.8075695], [87.87210846, 24.81186295], [87.87029266, 24.81524277], [87.8681488, 24.81811905], [87.86631012, 24.82074928], [87.86766815, 24.82298279], [87.86924744, 24.8234005], [87.87471771, 24.82271957], [87.88170624, 24.8203907], [87.88655853, 24.81966019], [87.89070892, 24.82287979], [87.8961792, 24.82259941], [87.89842224, 24.82452965], [87.89591217, 24.82756996], [87.89391327, 24.82917023], [87.8949585, 24.83389282], [87.89569092, 24.83959007], [87.89724731, 24.84174919], [87.89776611, 24.84278107], [87.89466858, 24.84775925], [87.89135742, 24.84815979], [87.88897705, 24.85293961], [87.89701843, 24.85435295], [87.91124725, 24.85593987], [87.92154694, 24.86024094], [87.92874146, 24.86588287], [87.93644714, 24.86961174], [87.94464111, 24.87267113], [87.9523468, 24.87685966], [87.96124268, 24.87905121], [87.96650696, 24.88129997], [87.96936798, 24.88512039], [87.97220612, 24.89142036], [87.9733429, 24.89648247], [87.97228241, 24.9033699], [87.97123718, 24.91003036], [87.97041321, 24.91607094], [87.9699707, 24.92358017], [87.9664917, 24.92959976], [87.96169281, 24.93593025], [87.95627594, 24.94141006], [87.9502182, 24.94534111], [87.94621277, 24.94889069], [87.93904877, 24.95573044], [87.930336, 24.96179962], [87.92444611, 24.96718025], [87.91851044, 24.9728508], [87.91352844, 24.97890282], [87.90648651, 24.98581123], [87.90336609, 24.99839973], [87.90242004, 24.99945068], [87.89292145, 25.00894928], [87.88082123, 25.02053833], [87.88117981, 25.02150917], [87.87697601, 25.02803993], [87.86434174, 25.03985023], [87.8550415, 25.04623985], [87.84262085, 25.05220032], [87.83493805, 25.05701828], [87.8201828, 25.06150055], [87.79989624, 25.07123947], [87.7928772, 25.07573128], [87.77986145, 25.08735085], [87.7765274, 25.09127045], [87.77266693, 25.09909821], [87.76983643, 25.11470985], [87.76928711, 25.12700081], [87.77120972, 25.138731], [87.77104187, 25.15227127], [87.77275085, 25.15961838], [87.77900696, 25.17692947], [87.7804718, 25.18527031], [87.78466797, 25.19960022], [87.78518677, 25.20907974], [87.7875824, 25.2204895], [87.80134583, 25.21824074], [87.81004333, 25.21173286], [87.82119751, 25.20808983], [87.82965851, 25.20405006], [87.83230591, 25.20078087], [87.83664703, 25.19926071], [87.83683777, 25.20310974], [87.83380127, 25.21336937], [87.82277679, 25.23434067], [87.82493591, 25.23655128], [87.83024597, 25.23966026], [87.83228302, 25.24464989], [87.83553314, 25.24981117], [87.84158325, 25.25358009], [87.84555054, 25.2522583], [87.84729004, 25.25225067], [87.84925079, 25.25342751], [87.85103607, 25.25796127], [87.8497467, 25.26148033], [87.84996796, 25.26728058], [87.85137939, 25.26906967], [87.85428619, 25.26791], [87.85652161, 25.2777729], [87.85616302, 25.28297043], [87.85501099, 25.2895298], [87.853302, 25.28936958], [87.85137939, 25.29249954], [87.85041046, 25.29743767], [87.84037018, 25.2983799], [87.83114624, 25.30216026], [87.82892609, 25.30342102], [87.82035065, 25.31282043], [87.8110733, 25.31916046], [87.80162811, 25.3234005], [87.79728699, 25.32208061], [87.79144287, 25.32233047], [87.78398132, 25.33242989], [87.78159332, 25.33839989], [87.78486633, 25.34460068], [87.78736115, 25.35486031], [87.78882599, 25.3722496], [87.77671814, 25.37084961], [87.77379608, 25.37195015], [87.76570129, 25.37799072], [87.76268768, 25.38623047], [87.76255798, 25.38899994], [87.76306915, 25.39561081], [87.76644897, 25.40353012], [87.76381683, 25.4048996], [87.75910187, 25.40504074], [87.75975037, 25.41008949], [87.76213837, 25.41206169], [87.76413727, 25.40897942], [87.76798248, 25.40876961], [87.76998138, 25.40983009], [87.77127075, 25.41155815], [87.77242279, 25.41491127], [87.77120209, 25.41852951], [87.76586151, 25.42429161], [87.77011108, 25.42876816], [87.77651215, 25.42897034], [87.7796402, 25.43659973], [87.78132629, 25.44465065], [87.78652191, 25.44869995], [87.79260254, 25.44561958], [87.7933197, 25.44219971], [87.79830933, 25.44186974], [87.80680084, 25.43477821], [87.80864716, 25.43419075], [87.81922913, 25.43753815], [87.82092285, 25.43977165], [87.82171631, 25.44302177], [87.82578278, 25.445261], [87.82496643, 25.44939041], [87.8273468, 25.45158958], [87.82559967, 25.45754051], [87.82769012, 25.45883179], [87.8338089, 25.45881081], [87.83381653, 25.46457291], [87.84955597, 25.46499062], [87.85067749, 25.46834946], [87.86347198, 25.46538925], [87.86428833, 25.46788979], [87.86390686, 25.47031975], [87.86052704, 25.47783089], [87.86086273, 25.48605156], [87.86348724, 25.49342918], [87.86872864, 25.49718285], [87.86988068, 25.50300026], [87.88136292, 25.50556946], [87.88047791, 25.51332092], [87.87921906, 25.51597023], [87.88532257, 25.51708984], [87.88815308, 25.5127697], [87.89501953, 25.5099411], [87.89585114, 25.50472069], [87.89898682, 25.50430107], [87.9005127, 25.50723076], [87.90480804, 25.50733948], [87.90271759, 25.51122093], [87.90631866, 25.51366806], [87.9030304, 25.5190506], [87.90815735, 25.52412033], [87.91374969, 25.52376938], [87.91456604, 25.52523041], [87.91440582, 25.5309391], [87.91609955, 25.53190994], [87.91963196, 25.53083992], [87.92411041, 25.53564835], [87.92604828, 25.53621292], [87.93354797, 25.5349617], [87.93804932, 25.53528976], [87.94287872, 25.53467751], [87.95239258, 25.53646088], [87.95561218, 25.5380497], [87.96408844, 25.53308105], [87.96914673, 25.52606964], [87.97225952, 25.5232296], [87.98603821, 25.52482986], [87.98764801, 25.52394104], [87.98819733, 25.52260017], [87.98780823, 25.52071953], [87.98055267, 25.51585007], [87.98496246, 25.50811005], [87.9866333, 25.50263023], [87.99276733, 25.49785042], [87.99835205, 25.49539948], [88.00424194, 25.49403954], [88.00300598, 25.49969101], [88.00377655, 25.50481987], [88.00747681, 25.51039124], [88.01167297, 25.50756073], [88.00792694, 25.50283051], [88.00994873, 25.50097084], [88.01573181, 25.50049973], [88.02028656, 25.4953804], [88.02868652, 25.4889698], [88.02754974, 25.4861412], [88.03122711, 25.48599052], [88.03450775, 25.49273109], [88.03862762, 25.49155807], [88.03660583, 25.48654175], [88.04213715, 25.48538971], [88.04633331, 25.4826107], [88.04933929, 25.48271942], [88.04947662, 25.48615074], [88.05296326, 25.48662949], [88.05580139, 25.483881], [88.06167603, 25.48558998], [88.06593323, 25.48115158], [88.07041168, 25.48050117], [88.06815338, 25.48984909], [88.06812286, 25.49679947], [88.06981659, 25.50188255], [88.07285309, 25.50390053], [88.07125854, 25.50488091], [88.06642914, 25.50503922], [88.0638504, 25.50617027], [88.06491089, 25.5085125], [88.06886292, 25.51304817], [88.06687927, 25.51642036], [88.05748749, 25.52567101], [88.05812073, 25.52870941], [88.05597687, 25.52993011], [88.0507431, 25.53051949], [88.04884338, 25.53333092], [88.04605103, 25.53433037], [88.04247284, 25.53206062], [88.03909302, 25.53318977], [88.0357132, 25.53672981], [88.03787994, 25.54618073], [88.0298233, 25.55039024], [88.0270462, 25.55327034], [88.03042603, 25.55754852], [88.02961731, 25.55948067], [88.03343964, 25.56145096], [88.03547668, 25.56038094], [88.03824615, 25.56388092], [88.03392792, 25.5659008], [88.02818298, 25.56631088], [88.02526855, 25.5690918], [88.03002167, 25.57434082], [88.02194214, 25.58292007], [88.02102661, 25.58692169], [88.02649689, 25.58590126], [88.03138733, 25.58749962], [88.03121948, 25.59101105], [88.03858948, 25.59504128], [88.03983307, 25.59736061], [88.03565216, 25.59698105], [88.03131104, 25.59826279], [88.02970123, 25.60003853], [88.03605652, 25.60240173], [88.04139709, 25.60549927], [88.03930664, 25.60848999], [88.04042816, 25.61046028], [88.0372467, 25.6155777], [88.03502655, 25.61705017], [88.03694153, 25.62200928], [88.03942871, 25.62730026], [88.04376984, 25.62822914], [88.04749298, 25.6276207], [88.0542984, 25.63286018], [88.04347992, 25.63207054], [88.04081726, 25.63611984], [88.03555298, 25.63683128], [88.03582001, 25.64097977], [88.04016113, 25.64191246], [88.04294586, 25.63899994], [88.04438782, 25.63965988], [88.044487, 25.64287949], [88.04614258, 25.64441109], [88.0473175, 25.64302254], [88.04853821, 25.64390945], [88.04537201, 25.64810944], [88.04397583, 25.65258026], [88.04876709, 25.65542984], [88.04888153, 25.6579895], [88.04538727, 25.65980148], [88.0431366, 25.67388916], [88.04467773, 25.67696953], [88.04910278, 25.68147087], [88.0508194, 25.68580055], [88.04862976, 25.69057083], [88.0451889, 25.69000053], [88.04332733, 25.69469261], [88.03985596, 25.69813919], [88.03475189, 25.69403076], [88.03219604, 25.69647026], [88.03016663, 25.69881058], [88.02677917, 25.6989212], [88.02239227, 25.6915226], [88.01615906, 25.69171906], [88.01434326, 25.6943512], [88.01431274, 25.69748116], [88.01751709, 25.70249939], [88.01667023, 25.70471191], [88.00676727, 25.70651054], [88.00196838, 25.70910072], [87.99717712, 25.71191025], [87.99256134, 25.71912956], [87.98770905, 25.72002029], [87.98779297, 25.72367096], [87.98184204, 25.72170067], [87.97966766, 25.71846008], [87.9716568, 25.72006989], [87.96099854, 25.72468185], [87.96199799, 25.72969818], [87.96047974, 25.73212051], [87.95665741, 25.73544121], [87.95102692, 25.73862076], [87.94415283, 25.74381256], [87.94386292, 25.74814034], [87.93862915, 25.74854088], [87.9420166, 25.75323105], [87.94164276, 25.75595093], [87.93752289, 25.75830078], [87.93734741, 25.76794052], [87.93239594, 25.77132034], [87.92919922, 25.77209091], [87.92862701, 25.76785088], [87.91866302, 25.77404022], [87.90497589, 25.77196121], [87.90125275, 25.76923943], [87.89846802, 25.76976013], [87.89774323, 25.77181053], [87.90094757, 25.78030968], [87.89800262, 25.79927063], [87.89919281, 25.8002491], [87.90159607, 25.80050087], [87.90305328, 25.80187035], [87.90188599, 25.80398941], [87.89907074, 25.80550194], [87.89501953, 25.80468941], [87.89672852, 25.81105995], [87.89927673, 25.81159019], [87.90119171, 25.81069946], [87.90203857, 25.81101036], [87.90200806, 25.81314087], [87.90313721, 25.81413078], [87.9076004, 25.80939293], [87.90947723, 25.81069183], [87.9105072, 25.8148098], [87.90445709, 25.81892014], [87.89874268, 25.82014084], [87.89385223, 25.8250618], [87.89795685, 25.82765007], [87.8964386, 25.82909012], [87.89379883, 25.82916069], [87.89096832, 25.82650948], [87.88433838, 25.82731056], [87.88339996, 25.82860947], [87.88764954, 25.83287048], [87.88935852, 25.83280182], [87.89261627, 25.8350811], [87.89530945, 25.83317947], [87.89742279, 25.83452034], [87.8973465, 25.83959961], [87.91091156, 25.85174942], [87.90483093, 25.85308838], [87.90138245, 25.85624123], [87.89945221, 25.85983086], [87.88481903, 25.86465263], [87.88121796, 25.85840988], [87.87874603, 25.85845947], [87.87223816, 25.85965919], [87.87068939, 25.86600113], [87.86766052, 25.86445045], [87.86528015, 25.8675518], [87.855896, 25.86473083], [87.85043335, 25.86707115], [87.84314728, 25.86871147], [87.83454132, 25.86874008], [87.82283783, 25.87146759], [87.81986237, 25.88097954], [87.81828308, 25.88148117], [87.81706238, 25.88334084], [87.81550598, 25.88554001], [87.81552124, 25.88796043], [87.81796265, 25.88845062], [87.82026672, 25.89376068], [87.81891632, 25.89715958], [87.81459045, 25.89884186], [87.81365967, 25.89995193], [87.81680298, 25.90487099], [87.81726074, 25.90918922], [87.81646729, 25.91270828], [87.81186676, 25.9131794], [87.81066132, 25.91399956], [87.80780029, 25.90899086], [87.80375671, 25.91214943], [87.80355835, 25.91394806], [87.80747986, 25.91583061], [87.80745697, 25.91827011], [87.80358124, 25.92072105], [87.80573273, 25.92843056], [87.80696106, 25.92991829], [87.81787109, 25.93301964], [87.82350922, 25.93135071], [87.82681274, 25.93185043], [87.82993317, 25.93545151], [87.82711029, 25.93778038], [87.82830811, 25.94111061], [87.82480621, 25.94366074], [87.82390594, 25.94645119], [87.82657623, 25.95004272], [87.82704926, 25.95358086], [87.82538605, 25.95872116], [87.83097839, 25.96223068], [87.83126068, 25.96409988], [87.82987976, 25.97187996], [87.82618713, 25.98368263], [87.82604218, 25.98831177], [87.82720184, 25.99234009], [87.83075714, 25.9921608], [87.83333588, 26.00109291], [87.84062195, 26.01976967], [87.83892822, 26.02287102], [87.84165192, 26.03230095], [87.84126282, 26.04120827], [87.84211731, 26.04448128], [87.84915161, 26.04496956], [87.86325073, 26.05610085], [87.87520599, 26.05557823], [87.87769318, 26.05791092], [87.87606049, 26.06619072], [87.88471985, 26.07151985], [87.88826752, 26.07193947], [87.88928223, 26.07509995], [87.89256287, 26.08035088], [87.89572906, 26.07987022], [87.91293335, 26.0909729], [87.91750336, 26.08801079], [87.91652679, 26.07969856], [87.92185974, 26.07687187], [87.92253876, 26.07180977], [87.93112946, 26.06895065], [87.93470001, 26.0705204], [87.93820953, 26.07676125], [87.93694305, 26.07975006], [87.93788147, 26.08446121], [87.94300842, 26.08469009], [87.95052338, 26.08304024], [87.9598465, 26.08403969], [87.96401215, 26.08325005], [87.96813202, 26.08136177], [87.97219086, 26.08485031], [87.97025299, 26.08735085], [87.96948242, 26.0916481], [87.96570587, 26.09192085], [87.96273041, 26.09472084], [87.95765686, 26.09708977], [87.95812988, 26.10085106], [87.95440674, 26.10279274], [87.95494843, 26.10568237], [87.95823669, 26.1088295], [87.96935272, 26.10931015], [87.97563171, 26.12162971], [87.96740723, 26.12537193], [87.95868683, 26.12569809], [87.95713043, 26.12886047], [87.9678421, 26.13183022], [87.97097015, 26.13714027], [87.96877289, 26.13935089], [87.96869659, 26.14787102], [87.96334076, 26.14888954], [87.96405792, 26.15197945], [87.96953583, 26.15440941], [87.97479248, 26.15286064], [87.98210907, 26.15917969], [87.98840332, 26.14861107], [87.99603271, 26.14179039], [87.99910736, 26.1403904], [88.00681305, 26.14328957], [88.01306915, 26.14087105], [88.01509094, 26.1429081], [88.01078033, 26.14929008], [88.01174164, 26.15479088], [88.01751709, 26.15555954], [88.02662659, 26.16279984], [88.02852631, 26.16728973], [88.03363037, 26.17028999], [88.03233337, 26.17351913], [88.03743744, 26.17770004], [88.04046631, 26.17681122], [88.04618073, 26.17788124], [88.04836273, 26.17464066], [88.05233002, 26.17167282], [88.05864716, 26.17375946], [88.06343079, 26.17667007], [88.06710052, 26.17762947], [88.06983185, 26.17571831], [88.07141876, 26.17879295], [88.0748291, 26.18128014], [88.07298279, 26.18539047], [88.08162689, 26.19235039], [88.08724213, 26.19444084], [88.08759308, 26.19797134], [88.08969116, 26.20323181], [88.09359741, 26.20653915], [88.09718323, 26.20643044], [88.10246277, 26.21224976], [88.10572815, 26.21640015], [88.10838318, 26.21705055], [88.11601257, 26.2229805], [88.11390686, 26.22397995], [88.11187744, 26.22620964], [88.11995697, 26.22794914], [88.12560272, 26.22789955], [88.12612915, 26.22691917], [88.13105011, 26.22681046], [88.13582611, 26.22821045], [88.13880157, 26.2308197], [88.13593292, 26.23715019], [88.13741302, 26.2437706], [88.14063263, 26.24572945], [88.14064789, 26.24963951], [88.14444733, 26.25279999], [88.15882874, 26.25691032], [88.16311646, 26.25753021], [88.16706085, 26.25720024], [88.17690277, 26.26172829], [88.1833725, 26.27468109], [88.1893692, 26.27510071], [88.19448853, 26.27412987], [88.20410156, 26.27959061], [88.21115875, 26.28000069], [88.21425629, 26.28168106], [88.21498108, 26.28493118], [88.21900177, 26.28567123], [88.22101593, 26.28821945], [88.22458649, 26.2894001], [88.22677612, 26.29664993], [88.22690582, 26.30397034], [88.23177338, 26.31035805], [88.23416138, 26.30668068], [88.2364502, 26.30540085], [88.23912811, 26.31319809], [88.24469757, 26.3162899], [88.24819946, 26.32653809], [88.25370789, 26.3277607], [88.25630951, 26.33011818], [88.25801086, 26.33423996], [88.26113129, 26.33785057], [88.26526642, 26.33649063], [88.26859283, 26.33700943], [88.26976013, 26.33268929], [88.27243805, 26.3305397], [88.27626038, 26.33249283], [88.27955627, 26.33553123], [88.28170013, 26.33980942], [88.27935028, 26.34634972], [88.28336334, 26.34930992], [88.28913879, 26.35113907], [88.29191589, 26.35391045], [88.28990173, 26.35691071], [88.2818985, 26.36013031], [88.27397919, 26.37728119], [88.26994324, 26.37887955], [88.26759338, 26.38116074], [88.26164246, 26.38002968], [88.25489807, 26.37446976], [88.25126648, 26.37585831], [88.24511719, 26.37599754], [88.24312592, 26.37409019], [88.23760986, 26.37537766], [88.23171234, 26.38490105], [88.22924805, 26.38985062], [88.23044586, 26.39396095], [88.23581696, 26.39616966], [88.25538635, 26.4158802], [88.26315308, 26.41501045], [88.26834869, 26.41792107], [88.26790619, 26.42175293], [88.26560974, 26.4233799], [88.26275635, 26.42808914], [88.25963593, 26.43066978], [88.25219727, 26.43379021], [88.24835205, 26.43880081], [88.24340057, 26.44930077], [88.23664856, 26.4493103], [88.23388672, 26.44625092], [88.22897339, 26.44715118], [88.22460175, 26.45574951], [88.21533966, 26.46573067], [88.22112274, 26.46684837], [88.22595978, 26.4720211], [88.22622681, 26.4762516], [88.21315765, 26.47777939], [88.21264648, 26.47458076], [88.21694183, 26.47265053], [88.21479034, 26.46973038], [88.1937561, 26.4720211], [88.19164276, 26.48307991], [88.18295288, 26.48526001], [88.18340302, 26.48839951], [88.179039, 26.49057961], [88.17920685, 26.49398041], [88.18634033, 26.50007057], [88.19386292, 26.50801086], [88.1998291, 26.51065063], [88.20635986, 26.51006126], [88.20665741, 26.51498032], [88.21865082, 26.52370071], [88.22582245, 26.52663994], [88.23336029, 26.53236961], [88.23114777, 26.53921127], [88.23120117, 26.55198288], [88.22180939, 26.55323029], [88.21539307, 26.55726814], [88.21389008, 26.55076981], [88.21922302, 26.54859161], [88.22080231, 26.54627991], [88.21689606, 26.54156113], [88.21235657, 26.54166985], [88.20966339, 26.54072189], [88.21109009, 26.53869057], [88.21534729, 26.53791046], [88.21456146, 26.53558922], [88.20742035, 26.5352211], [88.2049408, 26.53725052], [88.20405579, 26.53955078], [88.20149231, 26.53860092], [88.19924164, 26.53872108], [88.19898987, 26.54175186], [88.19668579, 26.54356003], [88.19050598, 26.54430962], [88.18573761, 26.54413986], [88.18242645, 26.5429306], [88.17913055, 26.53699112], [88.17962646, 26.53449059], [88.17868042, 26.53087044], [88.17382813, 26.53282928], [88.17063141, 26.53650284], [88.1682663, 26.53736115], [88.16602325, 26.53446007], [88.16538239, 26.52164078], [88.15744019, 26.51874161], [88.15506744, 26.51577187], [88.15090179, 26.51692009], [88.14769745, 26.51663971], [88.14539337, 26.51097107], [88.14129639, 26.51179123], [88.13765717, 26.51419258], [88.13217926, 26.51258087], [88.12354279, 26.52013969], [88.11514282, 26.53018951], [88.11030579, 26.53024101], [88.10819244, 26.5352211], [88.10614777, 26.53562355], [88.10621643, 26.53601456], [88.10504913, 26.53584862], [88.10547638, 26.53903961], [88.1054306, 26.53940773], [88.10649872, 26.53948402], [88.10860443, 26.54097176], [88.11408997, 26.54484558], [88.1139679, 26.54496765], [88.11009979, 26.5501709], [88.10871887, 26.55033493], [88.10798645, 26.55042076], [88.10797119, 26.55428696], [88.10798645, 26.56060982], [88.11032104, 26.56010056], [88.11185455, 26.55673218], [88.11594391, 26.55787659], [88.11608124, 26.55872154], [88.11618805, 26.55936813], [88.11320496, 26.56172943], [88.11326599, 26.56178093], [88.11768341, 26.5654583], [88.11681366, 26.56645203], [88.11569214, 26.56458664], [88.11531067, 26.56461906], [88.11420441, 26.56471252], [88.11517334, 26.5661869], [88.1139679, 26.56798553], [88.11594391, 26.57229233], [88.11660767, 26.57120895], [88.11730957, 26.57005501], [88.12151337, 26.56781578], [88.12016296, 26.57428169], [88.12339783, 26.5753994], [88.12551117, 26.57192039], [88.12774658, 26.57415581], [88.12559509, 26.57631302], [88.12551117, 26.57639313], [88.12799835, 26.57726288], [88.12805176, 26.57716942], [88.13098145, 26.57229233], [88.13191986, 26.5728302], [88.13272095, 26.57328606], [88.13248444, 26.57888985], [88.13246918, 26.57925415], [88.12985992, 26.58161354], [88.13272095, 26.58459473], [88.13239288, 26.58590889], [88.13209534, 26.58708191], [88.13431549, 26.59255791], [88.13446045, 26.59292221], [88.13431549, 26.5976162], [88.13365173, 26.5988636], [88.13250732, 26.60102844], [88.13821411, 26.60561562], [88.14179993, 26.60651779], [88.14464569, 26.62548256], [88.14663696, 26.62647629], [88.14677429, 26.62727547], [88.14688873, 26.62796783], [88.147995, 26.62835884], [88.15074158, 26.6293335], [88.15720367, 26.63020325], [88.15994263, 26.63255882], [88.16080475, 26.63567162], [88.16192627, 26.63598442], [88.16304016, 26.63629341], [88.16053009, 26.63976479], [88.1656189, 26.64574051], [88.16751099, 26.67001534], [88.16664124, 26.67819595], [88.17049408, 26.68364143], [88.16999817, 26.69892693], [88.17559052, 26.70775032], [88.17991638, 26.71071625], [88.18466187, 26.71918488], [88.18491364, 26.72713661], [88.18741608, 26.73061562], [88.18714142, 26.73400497], [88.18901062, 26.73819733], [88.18912506, 26.74006653], [88.1897583, 26.75062561], [88.18852997, 26.75650978], [88.18988037, 26.76019478], [88.19049835, 26.7714119], [88.18752289, 26.78281212], [88.18019104, 26.80331802], [88.18071747, 26.80846596], [88.18151855, 26.81621552], [88.1750946, 26.82568741], [88.17434692, 26.82902145], [88.17683411, 26.83314323], [88.17021942, 26.83711624], [88.17114258, 26.84150124], [88.17321777, 26.84481621], [88.17316437, 26.84487534], [88.17037201, 26.84693718], [88.1701889, 26.8481102], [88.16999817, 26.84929848], [88.17339325, 26.85099411], [88.17667389, 26.85397148], [88.17608643, 26.85513878], [88.17636108, 26.85625648], [88.17708588, 26.85923958], [88.1758194, 26.85960197], [88.17447662, 26.85998535], [88.17608643, 26.86520576], [88.17448425, 26.86890221], [88.17346954, 26.86917496], [88.16923523, 26.87022209], [88.16431427, 26.88061523], [88.16017914, 26.88272858], [88.15982056, 26.88381577], [88.15943909, 26.8849659], [88.15446472, 26.88521385], [88.15371704, 26.8842144], [88.1496582, 26.88819504], [88.14825439, 26.8890667], [88.14800262, 26.8898201], [88.14539337, 26.89093018], [88.14438629, 26.89365005], [88.14425659, 26.8937912], [88.13893127, 26.898386], [88.13911438, 26.8993187], [88.13930511, 26.90025139], [88.14181519, 26.90151596], [88.14143372, 26.9050045], [88.14685822, 26.91579628], [88.14711761, 26.91631508], [88.14663696, 26.91727638], [88.14862061, 26.92041588], [88.14849854, 26.92056656], [88.14001465, 26.93100357], [88.14129639, 26.93069839], [88.13980103, 26.93350792], [88.1348114, 26.93778992], [88.13345337, 26.93832207], [88.13134766, 26.93914795], [88.12301636, 26.9501152], [88.12574768, 26.9598217], [88.12451935, 26.96501541], [88.12590027, 26.96959114], [88.13321686, 26.98031616], [88.13748169, 26.98526764], [88.13742828, 26.98533058], [88.13669586, 26.98624802], [88.12650299, 26.98724174], [88.12581635, 26.98722649], [88.12078857, 26.98711777], [88.11813354, 26.98828697], [88.11768341, 26.98848534], [88.11283112, 26.99134254], [88.11147308, 26.99484062], [88.10699463, 26.99718475], [88.10179138, 27.0033989], [88.09503937, 27.00403976], [88.09111023, 27.00789452], [88.09111786, 27.01531601], [88.08624268, 27.02241135], [88.08561707, 27.02861595], [88.07950592, 27.03508186], [88.07827759, 27.03444672], [88.07244873, 27.0313015], [88.07191467, 27.0310154], [88.07006836, 27.0309391], [88.06697845, 27.03086281], [88.06221771, 27.02871513], [88.06051636, 27.0314827], [88.05847931, 27.03217125], [88.05243683, 27.03421783], [88.04792023, 27.0364151], [88.04292297, 27.03637314], [88.04026031, 27.03631783], [88.03752136, 27.04291725], [88.03672028, 27.04320526], [88.03578186, 27.04353905], [88.03023529, 27.05072594], [88.02959442, 27.05304718], [88.02841949, 27.05741501], [88.02522278, 27.06280136], [88.02459717, 27.06702614], [88.01900482, 27.07324028], [88.01863861, 27.07671928], [88.02349091, 27.08203697], [88.02372742, 27.08740616], [88.01850128, 27.0881443], [88.01531219, 27.093256], [88.01441956, 27.09711456], [88.01167297, 27.09797096], [88.01119995, 27.09939384], [88.00518036, 27.1034584], [88.00434113, 27.10468102], [88.00391388, 27.1043148], [88.00297546, 27.10343742], [87.99788666, 27.10320663], [87.99417114, 27.10520744], [87.99190521, 27.11637306], [87.99005127, 27.11897278], [87.99093628, 27.11979294], [87.99141693, 27.12331581], [87.9934082, 27.12568283], [87.99381256, 27.13054085], [88.0012207, 27.13341522], [88.0032196, 27.14001465], [88.00669098, 27.14151764], [88.00992584, 27.14295959], [88.01291656, 27.15441513], [88.01217651, 27.15737343], [88.01291656, 27.15811539], [88.01366425, 27.15886497], [88.0135498, 27.16542625], [88.01692963, 27.16659737], [88.02198792, 27.17066956], [88.02147675, 27.17195511], [88.02124786, 27.17253494], [88.02017975, 27.17334557], [88.01561737, 27.17823601], [88.01615143, 27.17912102], [88.01651764, 27.19041443], [88.01861572, 27.19291496], [88.01802063, 27.19951439], [88.01430511, 27.20352364], [88.01435089, 27.20360565], [88.01826477, 27.21056175], [88.0173111, 27.21151161], [88.01513672, 27.21654129], [88.01696777, 27.21887207], [88.02398682, 27.22066116], [88.03292847, 27.22103119], [88.04676056, 27.21611023], [88.05819702, 27.21389008], [88.06173706, 27.2112999], [88.06433868, 27.20783043], [88.0682373, 27.20473099], [88.07495117, 27.20084], [88.07540894, 27.19880104], [88.0688324, 27.1943512], [88.06745148, 27.19026947], [88.06926727, 27.18494987], [88.07232666, 27.17934036], [88.07309723, 27.1744175], [88.0786972, 27.16792107], [88.08325958, 27.16504288], [88.08390808, 27.16106987], [88.08299255, 27.14893913], [88.08383179, 27.14501953], [88.08584595, 27.14151001], [88.08863831, 27.13875008], [88.09266663, 27.13627815], [88.09593964, 27.13550949], [88.12329102, 27.12379074], [88.12690735, 27.12308121], [88.1366272, 27.11687851], [88.14377594, 27.11707115], [88.15231323, 27.11170959], [88.15544128, 27.1121006], [88.15843964, 27.11435127], [88.17260742, 27.1303196], [88.17899323, 27.13471031], [88.18367767, 27.1352005], [88.18850708, 27.13442039], [88.19561768, 27.13623047], [88.20986938, 27.13340187], [88.21383667, 27.1351223], [88.22151184, 27.12527084], [88.22690582, 27.12138939], [88.2325058, 27.11976814], [88.24006653, 27.12037086], [88.25154877, 27.12536049], [88.26345825, 27.12737083], [88.27088928, 27.13013077], [88.27735138, 27.13119125], [88.27813721, 27.13083076], [88.29490662, 27.12477112], [88.29988861, 27.12799835], [88.30449677, 27.12860107], [88.31127167, 27.12535095], [88.31881714, 27.1193409], [88.32048798, 27.11664009], [88.32007599, 27.10732079], [88.32383728, 27.10490036], [88.33174133, 27.10816765], [88.34079742, 27.11067009], [88.34516144, 27.10690117], [88.34793854, 27.10332108], [88.35230255, 27.1010704], [88.36387634, 27.0984211], [88.37065125, 27.09941292], [88.38751984, 27.09840965], [88.3976593, 27.09443092], [88.41100311, 27.09070015], [88.42914581, 27.08362007], [88.4319458, 27.08160973], [88.43962097, 27.08416939], [88.44628143, 27.08539963], [88.45449829, 27.0896492], [88.46018219, 27.09584999], [88.46479797, 27.10479164], [88.46672058, 27.11394119], [88.46907806, 27.11730194], [88.47377777, 27.12070084], [88.48127747, 27.12285042], [88.48668671, 27.12677956], [88.49185181, 27.1248703], [88.4956131, 27.12536049], [88.49640656, 27.12815285], [88.49890137, 27.13121986], [88.50295258, 27.13405037], [88.50750732, 27.13599014], [88.51222992, 27.14103127], [88.51596069, 27.1437397], [88.51870728, 27.14780045], [88.52171326, 27.15034294], [88.52674103, 27.14977264], [88.52993011, 27.1501503], [88.5320282, 27.1543293], [88.52672577, 27.1602726], [88.52980804, 27.16579056], [88.52047729, 27.17502975], [88.52075195, 27.17818069], [88.52899933, 27.17776108], [88.54084015, 27.1837101], [88.55899048, 27.18875122], [88.56629181, 27.18786049], [88.58509064, 27.19283295], [88.58702087, 27.19053268], [88.59147644, 27.19445992], [88.59400177, 27.19118118], [88.59751892, 27.19271088], [88.59810638, 27.19137192], [88.60352325, 27.19115257], [88.60678864, 27.18966103], [88.61901855, 27.18785286], [88.63327789, 27.17453003], [88.6387558, 27.16772079], [88.64248657, 27.16715813], [88.65645599, 27.1624012], [88.6595993, 27.16221046], [88.66806793, 27.17198944], [88.67350006, 27.17661095], [88.68036652, 27.17951012], [88.6844101, 27.18022919], [88.6914978, 27.17869949], [88.70197296, 27.17411041], [88.71180725, 27.16514969], [88.71496582, 27.15023994], [88.71779633, 27.14397049], [88.72454071, 27.13852119], [88.73253632, 27.13735008], [88.73718262, 27.13952065], [88.74694061, 27.14536476], [88.74604034, 27.14429665], [88.7483902, 27.1421051], [88.74949646, 27.14170265], [88.75088501, 27.141222], [88.75208282, 27.14065742], [88.75318909, 27.14041901], [88.75466156, 27.1401844], [88.75622559, 27.13970566], [88.75715637, 27.13905525], [88.75844574, 27.13857269], [88.75927734, 27.13816833], [88.76074982, 27.13768768], [88.76148987, 27.13728333], [88.76250458, 27.13712692], [88.76397705, 27.13681221], [88.76602936, 27.13624382], [88.76730347, 27.1361351], [88.76869965, 27.13650513], [88.7695694, 27.1363945], [88.77043915, 27.13646126], [88.77137756, 27.13646889], [88.77193451, 27.13673592], [88.77418518, 27.13612747], [88.77671051, 27.13552284], [88.77867126, 27.13535118], [88.78120422, 27.13505745], [88.78400421, 27.13508224], [88.7858963, 27.1350975], [88.78820801, 27.13536835], [88.79030609, 27.13569832], [88.79226685, 27.13596535], [88.7951355, 27.13642883], [88.79737091, 27.13713646], [88.79777527, 27.13721466], [88.79940033, 27.13752937], [88.80141449, 27.13892555], [88.8039093, 27.13908958], [88.80397034, 27.13784027], [88.80475616, 27.1361599], [88.80587769, 27.13486862], [88.80711365, 27.13305283], [88.80787659, 27.13160133], [88.80902863, 27.13031006], [88.80999756, 27.12915039], [88.81126404, 27.12834549], [88.81246948, 27.12716484], [88.81408691, 27.12617493], [88.81522369, 27.12474251], [88.81628418, 27.12374687], [88.81846619, 27.12288666], [88.82169342, 27.12266159], [88.82324219, 27.12179565], [88.82437897, 27.12086487], [88.82648468, 27.11981583], [88.82866669, 27.11901855], [88.83050537, 27.11784172], [88.83275604, 27.11629295], [88.83293915, 27.11622238], [88.83501434, 27.11543274], [88.83634186, 27.11506653], [88.83824158, 27.11508179], [88.83985138, 27.11465645], [88.84075928, 27.11358452], [88.84143066, 27.11222267], [88.84359741, 27.11154938], [88.84577179, 27.11162949], [88.84759521, 27.11101723], [88.84957123, 27.10965347], [88.85167694, 27.10941887], [88.85218048, 27.10946655], [88.85314941, 27.1095562], [88.85462189, 27.10944366], [88.85636902, 27.10951996], [88.85832977, 27.11009789], [88.86022186, 27.1100502], [88.861763, 27.10974884], [88.8635788, 27.11026573], [88.86540222, 27.11027145], [88.86713409, 27.11151314], [88.86764526, 27.11255646], [88.86834717, 27.11101913], [88.86884308, 27.11051559], [88.86998749, 27.10914612], [88.87007904, 27.10827637], [88.87001801, 27.10748672], [88.87000275, 27.10726166], [88.87007904, 27.10674477], [88.87026978, 27.10552216], [88.8702774, 27.10441208], [88.87028503, 27.10392761], [88.87033844, 27.10373306], [88.87088013, 27.10170555], [88.87179565, 27.09999084], [88.87232208, 27.09750366], [88.87283325, 27.09566498], [88.87326813, 27.09384918], [88.87356567, 27.09253311], [88.87326813, 27.09059334], [88.87402344, 27.08833694], [88.87340546, 27.0866394], [88.8737793, 27.08469772], [88.8736496, 27.0833168], [88.87373352, 27.08212662], [88.87374115, 27.0807476], [88.87320709, 27.07946968], [88.87377167, 27.07792664], [88.87483215, 27.07674217], [88.87574768, 27.07551003], [88.8760376, 27.07512283], [88.87619781, 27.07349205], [88.87479401, 27.07092094], [88.87553406, 27.06882668], [88.87684631, 27.06748009], [88.8782959, 27.06661034], [88.8788681, 27.06523514], [88.87800598, 27.06334496], [88.87799072, 27.06152916], [88.87774658, 27.06036949], [88.87759399, 27.0596447], [88.87746429, 27.05795097], [88.87726593, 27.056633], [88.87704468, 27.05514145], [88.87745667, 27.05282593], [88.87737274, 27.0510025], [88.87737274, 27.04915428], [88.87722015, 27.04799461], [88.87718201, 27.04719543], [88.87715149, 27.04647064], [88.87717438, 27.04480171], [88.87702179, 27.04364014], [88.8775177, 27.04233932], [88.87796783, 27.04104996], [88.87871552, 27.04020119], [88.87897491, 27.03990746], [88.87873077, 27.03861237], [88.878685, 27.03839302], [88.87772369, 27.03693199], [88.87688446, 27.0354023], [88.87615204, 27.03366661], [88.87562561, 27.03210449], [88.87519073, 27.0304966], [88.87509918, 27.03016472], [88.87463379, 27.02853394], [88.87451935, 27.02812576], [88.8742218, 27.02701759], [88.87382507, 27.02536392], [88.87371826, 27.02423859], [88.87368774, 27.02394104], [88.873703, 27.02200317], [88.8738327, 27.01953888], [88.87447357, 27.01721382], [88.87438202, 27.01531982], [88.87374115, 27.01334381], [88.87310791, 27.01185036], [88.87307739, 27.0104847], [88.87297058, 27.00845528], [88.87205505, 27.00629425], [88.87133026, 27.00474167], [88.87112427, 27.00275803], [88.87070465, 27.00171661], [88.86965179, 26.99906921], [88.86894989, 26.99613571], [88.86875916, 26.99455833], [88.86904144, 26.99226379], [88.86980438, 26.99064636], [88.87068939, 26.98896027], [88.87101746, 26.98840523], [88.87156677, 26.98746872], [88.87195587, 26.9857502], [88.87189484, 26.98323822], [88.87137604, 26.98069572], [88.87122345, 26.97949791], [88.87091827, 26.97707939], [88.87101746, 26.97545433], [88.87145996, 26.97374725], [88.87159729, 26.97250366], [88.87171936, 26.97142982], [88.8717041, 26.97108269], [88.87164307, 26.97001266], [88.87127686, 26.96803284], [88.87067413, 26.96636581], [88.86994934, 26.96475792], [88.86981201, 26.96397591], [88.86963654, 26.96298409], [88.87018585, 26.9611721], [88.87145996, 26.9603138], [88.87289429, 26.95476341], [88.87328339, 26.95316124], [88.87477875, 26.95180702], [88.87532043, 26.94843102], [88.87615967, 26.94587898], [88.87699127, 26.94433403], [88.87830353, 26.94507408], [88.87961578, 26.94618034], [88.88051605, 26.9474411], [88.88188934, 26.94913864], [88.88774109, 26.95759392], [88.89090729, 26.96132278], [88.89302826, 26.96277428], [88.89434052, 26.96481514], [88.89512634, 26.96649551], [88.89559174, 26.9673481], [88.89651489, 26.96917534], [88.897995, 26.97160912], [88.89989471, 26.97347641], [88.90200806, 26.97522736], [88.90348053, 26.97737312], [88.90467072, 26.97879601], [88.90808105, 26.97938156], [88.91007996, 26.97939682], [88.91192627, 26.98204041], [88.91150665, 26.9838295], [88.91268921, 26.98563194], [88.91351318, 26.98678398], [88.91439819, 26.9880352], [88.91638947, 26.98984337], [88.91785431, 26.98985291], [88.92077637, 26.99118996], [88.92090607, 26.9916687], [88.92116547, 26.99226952], [88.92150879, 26.99381638], [88.92253876, 26.99268341], [88.92327118, 26.99188232], [88.92521667, 26.99045372], [88.92654419, 26.9892292], [88.92707062, 26.98874283], [88.92736816, 26.98847008], [88.92887878, 26.98727417], [88.9315567, 26.98507118], [88.9343338, 26.98286629], [88.9369812, 26.98071861], [88.93704987, 26.98065376], [88.93878937, 26.97904968], [88.94119263, 26.97737694], [88.94287109, 26.97568321], [88.94413757, 26.97469711], [88.9458313, 26.97368431], [88.94855499, 26.97146416], [88.94998169, 26.97030258], [88.95081329, 26.9686985], [88.9514389, 26.96528816], [88.95157623, 26.96404266], [88.95150757, 26.9613781], [88.95291138, 26.96004868], [88.95270538, 26.95664024], [88.95238495, 26.95485497], [88.95275116, 26.95186043], [88.95271301, 26.95137405], [88.95250702, 26.94886971], [88.95211792, 26.94755173], [88.95172882, 26.94623566], [88.95094299, 26.94491386], [88.94989014, 26.94335365], [88.94857025, 26.94226837], [88.9475174, 26.94022751], [88.94727325, 26.93819427], [88.94728851, 26.93652153], [88.94611359, 26.9355278], [88.9460144, 26.9353447], [88.94589996, 26.93512535], [88.94483948, 26.93496895], [88.94368744, 26.93431091], [88.94475555, 26.93388939], [88.94587708, 26.93342018], [88.94646454, 26.93309212], [88.9473114, 26.93276405], [88.94828033, 26.93210411], [88.9500885, 26.93100548], [88.95365906, 26.92918968], [88.95638275, 26.92789459], [88.95860291, 26.92672539], [88.96086121, 26.92565536], [88.96150208, 26.92533112], [88.96305084, 26.9245472], [88.96646118, 26.92294884], [88.97064209, 26.92103386], [88.97142029, 26.92072105], [88.9755249, 26.91906929], [88.98036957, 26.91724968], [88.98297119, 26.91890526], [88.98416138, 26.91962624], [88.98455048, 26.91985703], [88.98486328, 26.92004013], [88.98615265, 26.92080116], [88.98779297, 26.92161942], [88.99021912, 26.92263794], [88.99090576, 26.92292595], [88.99249268, 26.92374611], [88.9940033, 26.92494583], [88.99575043, 26.92640305], [89.0109787, 26.93500328], [89.01587677, 26.93776512], [89.02124786, 26.94079971], [89.02182007, 26.93928337], [89.022995, 26.93615723], [89.02352905, 26.9351387], [89.02988434, 26.92305756], [89.041008, 26.92288017], [89.04640961, 26.91889191], [89.04802704, 26.91769791], [89.05024719, 26.91605568], [89.04911804, 26.90265846], [89.04881287, 26.89905167], [89.06747437, 26.90327263], [89.06950378, 26.9037323], [89.07466888, 26.90035248], [89.0796051, 26.89711952], [89.09033966, 26.89353752], [89.0956192, 26.89177704], [89.0949173, 26.88756943], [89.09403992, 26.8822937], [89.09244537, 26.87271309], [89.09810638, 26.86764145], [89.10076141, 26.86526108], [89.10586548, 26.86069107], [89.10612488, 26.86045837], [89.10095978, 26.84406471], [89.1005249, 26.84268761], [89.10128021, 26.84174538], [89.108284, 26.83299637], [89.10901642, 26.83208084], [89.11525726, 26.82428551], [89.1240921, 26.82222748], [89.13427734, 26.80783653], [89.14907837, 26.81188202], [89.17632294, 26.81932831], [89.17910004, 26.81797028], [89.19359589, 26.81088257], [89.19677734, 26.81158257], [89.22727203, 26.81829643], [89.23929596, 26.81889915], [89.26225281, 26.8139019], [89.26429749, 26.81833076], [89.26515961, 26.81914902], [89.26573944, 26.81971741], [89.26607513, 26.82000351], [89.26631165, 26.82026482], [89.26655579, 26.82050514], [89.26705933, 26.82096481], [89.26759338, 26.82148933], [89.26809692, 26.82199287], [89.26867676, 26.82249641], [89.26947021, 26.82330513], [89.27005005, 26.82383156], [89.27043915, 26.82424736], [89.27127838, 26.82505608], [89.27178955, 26.82551575], [89.2719574, 26.82566833], [89.27246094, 26.82621574], [89.2729187, 26.82658768], [89.27359772, 26.8272438], [89.2743454, 26.82798767], [89.2749939, 26.82862282], [89.27532959, 26.82890701], [89.27561951, 26.82870483], [89.27637482, 26.82811928], [89.27835083, 26.82659531], [89.28038788, 26.83036232], [89.28082275, 26.83116722], [89.28869629, 26.83485413], [89.295784, 26.84022141], [89.29821014, 26.84065437], [89.30069733, 26.84249115], [89.30282593, 26.84241486], [89.30567932, 26.84466743], [89.30723572, 26.84494019], [89.31005096, 26.84543419], [89.31832123, 26.85152626], [89.32087708, 26.85162354], [89.32186127, 26.85147476], [89.32305908, 26.85129356], [89.32376099, 26.84976578], [89.32430267, 26.84858513], [89.32670593, 26.84331894], [89.33386993, 26.84593964], [89.3651123, 26.85737228], [89.36740875, 26.85821342], [89.36975861, 26.85907364], [89.37892914, 26.86242485], [89.3835907, 26.85912895], [89.3894577, 26.84226036], [89.38954926, 26.84199333], [89.40517426, 26.84112358], [89.41113281, 26.8407917], [89.41356659, 26.84065628], [89.41480255, 26.84003639], [89.41487885, 26.83999825], [89.41650391, 26.83918381], [89.42250061, 26.83617973], [89.42527771, 26.83696365], [89.43871307, 26.84075546], [89.44438171, 26.83591843], [89.4499588, 26.83115959], [89.44883728, 26.82602882], [89.4504776, 26.81803513], [89.4516983, 26.81664658], [89.46105194, 26.80597496], [89.46316528, 26.80518532], [89.46974945, 26.80272675], [89.47431946, 26.802742], [89.47609711, 26.80317688], [89.5044632, 26.81011963], [89.50723267, 26.81079674], [89.50785065, 26.81156349], [89.50880432, 26.81151772], [89.50965118, 26.81237984], [89.51076508, 26.81243134], [89.52294159, 26.81367493], [89.52391815, 26.81373978], [89.52532196, 26.81292915], [89.52700043, 26.81274605], [89.52923584, 26.8133812], [89.53132629, 26.81401443], [89.53272247, 26.81402016], [89.53377533, 26.81396103], [89.53475189, 26.81365013], [89.53601074, 26.8132782], [89.53769684, 26.81246758], [89.53831482, 26.81231117], [89.53964996, 26.81197166], [89.54147339, 26.8115387], [89.5430069, 26.81116676], [89.54486084, 26.81085777], [89.54689026, 26.81170464], [89.54831696, 26.81243706], [89.55046844, 26.81324959], [89.55249786, 26.81395721], [89.5552597, 26.81428146], [89.55743408, 26.81422806], [89.55995941, 26.81322861], [89.55950928, 26.81143188], [89.56023407, 26.80952835], [89.56121063, 26.80714989], [89.56291962, 26.80547333], [89.56391144, 26.80428314], [89.56404114, 26.80284119], [89.56404877, 26.80121613], [89.56516266, 26.80022049], [89.56751251, 26.79985619], [89.56916046, 26.79950333], [89.5712204, 26.79897881], [89.5727005, 26.79838562], [89.57433319, 26.79776955], [89.57588196, 26.79709435], [89.57759857, 26.79678917], [89.5794754, 26.79631042], [89.58095551, 26.79552078], [89.58259583, 26.7948246], [89.58435059, 26.79430008], [89.58605957, 26.79323578], [89.58857727, 26.79192734], [89.5912323, 26.79249763], [89.5930481, 26.79212761], [89.59451294, 26.79175377], [89.59550476, 26.79148102], [89.59674835, 26.79055595], [89.59796906, 26.78938675], [89.59951019, 26.78853989], [89.60138702, 26.7885437], [89.60396576, 26.7878933], [89.60549927, 26.78764534], [89.6072464, 26.78765106], [89.60836792, 26.7870903], [89.60978699, 26.78666878], [89.61297607, 26.78666306], [89.6155014, 26.78629303], [89.61654663, 26.78479195], [89.6180954, 26.78354073], [89.6190033, 26.78235245], [89.61961365, 26.78125], [89.62090302, 26.77815437], [89.62184143, 26.77855873], [89.62397766, 26.77947998], [89.62634277, 26.78074074], [89.6292038, 26.78212738], [89.63046265, 26.78281975], [89.63192749, 26.78338814], [89.63318634, 26.78307915], [89.63486481, 26.78276825], [89.63567352, 26.7824688], [89.63654327, 26.78214645], [89.63831329, 26.78211212], [89.63996887, 26.78090096], [89.64105988, 26.77974892], [89.64251709, 26.77844238], [89.64318848, 26.77789879], [89.64536285, 26.77794647], [89.64640808, 26.77796936], [89.64884949, 26.77759933], [89.65090942, 26.77643013], [89.65048218, 26.77430153], [89.65020752, 26.77295876], [89.65132141, 26.7701416], [89.65258789, 26.76795006], [89.65338135, 26.76706886], [89.6499939, 26.76693916], [89.64878082, 26.76535606], [89.64769745, 26.7640152], [89.64756775, 26.76182556], [89.64377594, 26.76059914], [89.64455414, 26.75864792], [89.64524078, 26.75709343], [89.64530945, 26.75625992], [89.64549255, 26.75548363], [89.64562225, 26.75476074], [89.64537811, 26.75259399], [89.64377594, 26.75008965], [89.64063263, 26.74741554], [89.63852692, 26.74707794], [89.63685608, 26.74685097], [89.6346283, 26.74614525], [89.63246155, 26.7451992], [89.63142395, 26.74431801], [89.63009644, 26.74331093], [89.62821198, 26.7429924], [89.62654114, 26.74242401], [89.62535095, 26.74154282], [89.6240387, 26.74062347], [89.6230545, 26.73948479], [89.62229156, 26.73783493], [89.62200928, 26.73725128], [89.62159729, 26.73639107], [89.62062073, 26.73513412], [89.62007141, 26.73281288], [89.61923981, 26.73161888], [89.61903381, 26.73067856], [89.61761475, 26.72885895], [89.61785126, 26.72779083], [89.61904144, 26.72653961], [89.62121582, 26.72579193], [89.62306976, 26.72353935], [89.6229248, 26.72276497], [89.62276459, 26.72187233], [89.6232605, 26.72002792], [89.62376404, 26.71867561], [89.62473297, 26.71870422], [89.62748718, 26.71766281], [89.6290741, 26.71926117], [89.63103485, 26.71901703], [89.63143921, 26.71953392], [89.63180542, 26.72000694], [89.63254547, 26.72167397], [89.63383484, 26.72445488], [89.63531494, 26.72495842], [89.63720703, 26.7246418], [89.64021301, 26.72339439], [89.64200592, 26.72283554], [89.64209747, 26.72280693], [89.643013, 26.72252274], [89.64504242, 26.72233963], [89.64657593, 26.72159195], [89.64860535, 26.72009087], [89.64868164, 26.71962357], [89.64896393, 26.71783447], [89.65315247, 26.71796989], [89.65330505, 26.71797752], [89.65594482, 26.7181015], [89.65818024, 26.7189846], [89.65985107, 26.71939087], [89.66027069, 26.71949196], [89.66122437, 26.72082138], [89.6618042, 26.72162819], [89.66360474, 26.72489357], [89.66390991, 26.725214], [89.66486359, 26.72621346], [89.66539764, 26.72714996], [89.66576385, 26.7277832], [89.66638947, 26.72853661], [89.6672287, 26.729496], [89.66743469, 26.72973061], [89.66861725, 26.73073578], [89.66938019, 26.73243141], [89.66944885, 26.73387337], [89.66944122, 26.73563004], [89.66918945, 26.73609924], [89.66936493, 26.73798561], [89.6696167, 26.73848534], [89.67076874, 26.73965454], [89.67453003, 26.73971748], [89.67586517, 26.73963737], [89.67753601, 26.73953629], [89.67997742, 26.73834991], [89.68132019, 26.73722649], [89.68222046, 26.73647308], [89.68453217, 26.73560143], [89.68613434, 26.73466301], [89.68844604, 26.73347664], [89.68979645, 26.73325157], [89.69200134, 26.73467636], [89.69298553, 26.7348671], [89.69367981, 26.73524475], [89.69514465, 26.73549843], [89.69605255, 26.73600197], [89.69674683, 26.73625374], [89.697052, 26.7364769], [89.69752502, 26.73682404], [89.69786835, 26.73689651], [89.69839478, 26.73701859], [89.69874573, 26.73707581], [89.6992569, 26.73718262], [89.69973755, 26.73730469], [89.70022583, 26.73726845], [89.7009964, 26.73688507], [89.70198822, 26.73639107], [89.70259094, 26.73605537], [89.70321655, 26.73535919], [89.70446014, 26.73480415], [89.70571136, 26.73313141], [89.70773315, 26.73188019], [89.70928955, 26.73090744], [89.71161652, 26.73049164], [89.71456909, 26.73035812], [89.71674347, 26.7302227], [89.71798706, 26.72994614], [89.7178421, 26.72799301], [89.72001648, 26.72632408], [89.72173309, 26.72534943], [89.7220993, 26.72493744], [89.72223663, 26.72478104], [89.72235107, 26.72465324], [89.72288513, 26.72427368], [89.72390747, 26.72354126], [89.72499847, 26.72354317], [89.72763824, 26.72438431], [89.73104858, 26.72606468], [89.73280334, 26.72662544], [89.73368835, 26.72690773], [89.73554993, 26.72774696], [89.73628998, 26.72794724], [89.73865509, 26.72859001], [89.74192047, 26.72943306], [89.74456024, 26.7302742], [89.74472046, 26.73037148], [89.74720764, 26.73187637], [89.74777222, 26.7322197], [89.74906921, 26.73292923], [89.75098419, 26.73465157], [89.75244141, 26.73556137], [89.75473022, 26.73418045], [89.75626373, 26.73279572], [89.75777435, 26.73054504], [89.75789642, 26.72857285], [89.7570343, 26.72590256], [89.75613403, 26.72403908], [89.75461578, 26.72116661], [89.75418854, 26.71979141], [89.75553894, 26.71772385], [89.75621796, 26.71759796], [89.7578125, 26.71730042], [89.75972748, 26.7166214], [89.76128387, 26.71538544], [89.76374817, 26.71183777], [89.7644577, 26.71052742], [89.7645874, 26.71012306], [89.76564026, 26.70686722], [89.76680756, 26.70453262], [89.76839447, 26.70336723], [89.77022552, 26.7026062], [89.7705307, 26.70254898], [89.77223969, 26.70222855], [89.79200745, 26.70697784], [89.79485321, 26.70766068], [89.79834747, 26.70845032], [89.80813599, 26.71019173], [89.81214905, 26.71098137], [89.84100342, 26.70583534], [89.8600769, 26.70137405], [89.86141205, 26.70034981], [89.87142944, 26.68353081], [89.87148285, 26.67921829], [89.86946869, 26.67381096], [89.86933899, 26.67094994], [89.87052155, 26.66621971], [89.86987305, 26.66267014], [89.86828613, 26.66076088], [89.86805725, 26.65661812], [89.87275696, 26.65185928], [89.87637329, 26.64949989], [89.87583923, 26.64630127], [89.87367249, 26.64351082], [89.86126709, 26.63555908], [89.85729218, 26.63208961], [89.85704041, 26.62341118], [89.85900116, 26.61721039], [89.86183167, 26.61515045], [89.87161255, 26.61495972], [89.87722778, 26.61305046], [89.87663269, 26.60634232], [89.87522125, 26.60116959], [89.87254333, 26.59757042], [89.87211609, 26.5947094], [89.8742218, 26.58921242], [89.87754822, 26.58424187], [89.86987305, 26.57950974], [89.86200714, 26.57788277], [89.86152649, 26.57456017], [89.86499786, 26.57027054], [89.86548615, 26.56583977], [89.86432648, 26.56077957], [89.86461639, 26.54829025], [89.86141968, 26.5431881], [89.86226654, 26.53729057], [89.86183929, 26.53046036], [89.85443115, 26.52107811], [89.85350037, 26.51723289], [89.85560608, 26.5051403], [89.85497284, 26.49430275], [89.85269165, 26.48777962], [89.86102295, 26.47478104], [89.86237335, 26.46607018], [89.86709595, 26.46581078], [89.87020874, 26.46397972], [89.87062073, 26.45989037], [89.86943054, 26.45728111], [89.86949921, 26.44841957], [89.86112976, 26.44042015], [89.8576889, 26.4381218], [89.85520172, 26.43404961], [89.85299683, 26.42456055], [89.84976196, 26.42225075], [89.84778595, 26.42175293], [89.84764862, 26.41982269], [89.84980774, 26.41420937], [89.84484863, 26.4102211], [89.83634186, 26.41127014], [89.8332901, 26.41229057], [89.82946777, 26.40328026], [89.82727814, 26.39647293], [89.82797241, 26.39347839], [89.83058929, 26.39019966], [89.84039307, 26.39081955], [89.84449768, 26.39435005], [89.84606171, 26.39779282], [89.84681702, 26.40274048], [89.85032654, 26.3982811], [89.85315704, 26.39599037], [89.85729218, 26.38446045], [89.85507202, 26.38203049], [89.85125732, 26.38405037], [89.84549713, 26.38402939], [89.84092712, 26.37775993], [89.83402252, 26.38126183], [89.83098602, 26.38203049], [89.82787323, 26.38112068], [89.82559204, 26.37931824], [89.82440948, 26.37689018], [89.8274231, 26.36981964], [89.82705688, 26.36664963], [89.82106018, 26.35906982], [89.82341003, 26.3552494], [89.82118988, 26.35113907], [89.82009888, 26.35038185], [89.81556702, 26.3514595], [89.81362915, 26.35317039], [89.81149292, 26.35802078], [89.81154633, 26.36071014], [89.81266785, 26.36240005], [89.81723022, 26.36610031], [89.82041931, 26.37062073], [89.81256104, 26.36700058], [89.8098526, 26.36650085], [89.80400085, 26.36234283], [89.79032135, 26.35806274], [89.78201294, 26.35327911], [89.78089142, 26.35217094], [89.77906036, 26.3474102], [89.77921295, 26.34320259], [89.78103638, 26.33584023], [89.7808609, 26.33088112], [89.77774811, 26.3277607], [89.7685318, 26.32380295], [89.76196289, 26.3170681], [89.75364685, 26.32180023], [89.75166321, 26.32216072], [89.75054169, 26.32146072], [89.75089264, 26.30624008], [89.75914001, 26.29259109], [89.75865936, 26.28932953], [89.75710297, 26.28853035], [89.74888611, 26.2894001], [89.74606323, 26.29076195], [89.74234772, 26.29520988], [89.73179626, 26.29290009], [89.72344971, 26.29475021], [89.72088623, 26.29628944], [89.71980286, 26.29863167], [89.72276306, 26.30755043], [89.72025299, 26.30813026], [89.71782684, 26.3057003], [89.71568298, 26.30198097], [89.71544647, 26.2970295], [89.71705627, 26.29305267], [89.72109222, 26.28816986], [89.72918701, 26.28293991], [89.73745728, 26.271101], [89.7336731, 26.26646042], [89.73345184, 26.26250076], [89.73227692, 26.26033974], [89.72521973, 26.2584095], [89.71734619, 26.259161], [89.71142578, 26.26326942], [89.71084595, 26.2645607], [89.71154022, 26.26958084], [89.70894623, 26.27082062], [89.7048111, 26.26990128], [89.70067596, 26.26084137], [89.7009964, 26.25918961], [89.70362091, 26.25697136], [89.71138763, 26.25803947], [89.71537018, 26.25649071], [89.71642303, 26.25526047], [89.71652222, 26.25233841], [89.71502686, 26.24897194], [89.71572113, 26.24637985], [89.72357178, 26.24353981], [89.7287674, 26.23820114], [89.72332001, 26.23292923], [89.7181778, 26.23162079], [89.7128067, 26.22896957], [89.71170807, 26.22774124], [89.71022797, 26.21914101], [89.70555878, 26.21706009], [89.70310211, 26.21730995], [89.6995697, 26.21890068], [89.69722748, 26.21722984], [89.69754791, 26.21594238], [89.70024872, 26.21376038], [89.70307922, 26.21329117], [89.71549988, 26.21478081], [89.72438049, 26.21729088], [89.73127747, 26.21491051], [89.73203278, 26.21228981], [89.73132324, 26.21076965], [89.72566223, 26.20607948], [89.7232132, 26.2053299], [89.72062683, 26.20617104], [89.7172699, 26.20561028], [89.71421814, 26.20597839], [89.71163177, 26.20319939], [89.71556091, 26.20265007], [89.71747589, 26.20012093], [89.7181015, 26.19679832], [89.71613312, 26.19132805], [89.71405029, 26.18935966], [89.71073914, 26.18856049], [89.70822144, 26.18683815], [89.70536804, 26.1880703], [89.70184326, 26.18815041], [89.69757843, 26.19086075], [89.69483948, 26.18907166], [89.70020294, 26.18482971], [89.70061493, 26.18346405], [89.70253754, 26.17712021], [89.70427704, 26.1745491], [89.70652008, 26.17313004], [89.71161652, 26.1735096], [89.71705627, 26.17720985], [89.71980286, 26.17793846], [89.73023987, 26.17700005], [89.73314667, 26.1758709], [89.73417664, 26.1749897], [89.73375702, 26.17337036], [89.73293304, 26.17297173], [89.72705078, 26.17387962], [89.72509766, 26.17160988], [89.72509766, 26.16963005], [89.71930695, 26.16640663], [89.71875763, 26.16604805], [89.71869659, 26.1661377], [89.71812439, 26.16588593], [89.7178421, 26.16576004], [89.71696472, 26.16537285], [89.7164917, 26.1660099], [89.7168045, 26.16649246], [89.71695709, 26.16711044], [89.71687317, 26.1674366], [89.71664429, 26.16836357], [89.71447754, 26.16885757], [89.71318054, 26.16833496], [89.71263885, 26.16811371], [89.71199799, 26.16681099], [89.71115112, 26.16480827], [89.71042633, 26.16270065], [89.71086884, 26.16059113], [89.71054077, 26.15848923], [89.70989227, 26.15630913], [89.70899963, 26.15533447], [89.70828247, 26.15454674], [89.70661163, 26.15372467], [89.70539093, 26.15316391], [89.70501709, 26.15299034], [89.70306396, 26.15216827], [89.7013092, 26.15185738], [89.70115662, 26.15367317], [89.70011139, 26.15561295], [89.6988678, 26.15689468], [89.69718933, 26.15855789], [89.69496155, 26.15962601], [89.69284821, 26.16038322], [89.68365479, 26.16367912], [89.68087769, 26.16467476], [89.67963409, 26.16511917], [89.67425537, 26.16704559], [89.67514038, 26.16728783], [89.68414307, 26.16973495], [89.68487549, 26.16996193], [89.68547821, 26.17014885], [89.68858337, 26.17024612], [89.69106293, 26.16979599], [89.6934433, 26.16930962], [89.69451904, 26.16944122], [89.69633484, 26.16972542], [89.69780731, 26.17001152], [89.69979858, 26.17140388], [89.70114899, 26.17231369], [89.70148468, 26.17293358], [89.70158386, 26.17315102], [89.70198822, 26.17406273], [89.69828796, 26.17501068], [89.69564056, 26.17539215], [89.69396973, 26.17563248], [89.69174194, 26.17763519], [89.68441772, 26.18786049], [89.68350983, 26.1894722], [89.68210602, 26.1925354], [89.6819458, 26.19349289], [89.6812973, 26.19733238], [89.68125916, 26.19756317], [89.68120575, 26.19787598], [89.68053436, 26.1978302], [89.67806244, 26.19766235], [89.67349243, 26.20569992], [89.67344666, 26.20578384], [89.67380524, 26.20626068], [89.67586517, 26.20900726], [89.6759491, 26.20904922], [89.67838287, 26.21027946], [89.67897034, 26.21030617], [89.68032837, 26.21036911], [89.68178558, 26.20957756], [89.68193054, 26.20929718], [89.68314362, 26.20853424], [89.68338013, 26.20838547], [89.68558502, 26.20700264], [89.68683624, 26.2093811], [89.68708038, 26.20979691], [89.68821716, 26.21035957], [89.69124603, 26.21168709], [89.69142151, 26.21176147], [89.69164276, 26.21357155], [89.68969727, 26.21297836], [89.68912506, 26.21240425], [89.68836975, 26.21165085], [89.68809509, 26.21149063], [89.68669128, 26.21068764], [89.6858902, 26.20974731], [89.68503571, 26.20874405], [89.6832962, 26.20921516], [89.68313599, 26.21039009], [89.68276215, 26.21060753], [89.68182373, 26.21212387], [89.67971802, 26.2140274], [89.67965698, 26.21408844], [89.67961884, 26.21421814], [89.67906952, 26.21648979], [89.67862701, 26.21953011], [89.67865753, 26.2217865], [89.67888641, 26.22351837], [89.67897797, 26.22418976], [89.68032837, 26.22382736], [89.6815567, 26.22130775], [89.68419647, 26.2202034], [89.68690491, 26.21998215], [89.6891098, 26.2212162], [89.68938446, 26.22136879], [89.68920898, 26.22183037], [89.68907928, 26.22215843], [89.68792725, 26.22170067], [89.68570709, 26.22128105], [89.68419647, 26.22125053], [89.68229675, 26.22128105], [89.68187714, 26.22184944], [89.68276978, 26.22286034], [89.68416595, 26.2232933], [89.68371582, 26.22375298], [89.68360901, 26.22386169], [89.68621063, 26.22571373], [89.68595886, 26.22604942], [89.68622589, 26.22628593], [89.68659973, 26.22598076], [89.68711853, 26.22636604], [89.68746185, 26.22661591], [89.68567657, 26.22665405], [89.68570709, 26.22674751], [89.68577576, 26.22695351], [89.68595123, 26.22746849], [89.68486023, 26.22709084], [89.68379974, 26.22782898], [89.68348694, 26.22747231], [89.68278503, 26.22759056], [89.68195343, 26.2277317], [89.68179321, 26.22775841], [89.68073273, 26.23051071], [89.6802597, 26.23232079], [89.68009186, 26.2330513], [89.67980957, 26.234272], [89.67971802, 26.23449898], [89.67755127, 26.23112106], [89.67584991, 26.22948074], [89.67556, 26.22921944], [89.67420197, 26.22718811], [89.67427826, 26.2236824], [89.67436981, 26.22174072], [89.67449951, 26.21906281], [89.67324829, 26.21867943], [89.67047882, 26.21889114], [89.66670227, 26.21946144], [89.66320801, 26.21809006], [89.66086578, 26.21767044], [89.65717316, 26.21846962], [89.6556015, 26.21912766], [89.65549469, 26.21917343], [89.65512085, 26.22025299], [89.65502167, 26.22052956], [89.65288544, 26.22058296], [89.65093994, 26.22097206], [89.65066528, 26.22102547], [89.65040588, 26.22107697], [89.65032959, 26.22115326], [89.6481781, 26.22324371], [89.6472702, 26.22410393], [89.64624023, 26.22508812], [89.64563751, 26.22569847], [89.64326477, 26.22610855], [89.64102936, 26.2261219], [89.63871002, 26.22796822], [89.63846588, 26.22816467], [89.63835144, 26.22825813], [89.63809967, 26.22886276], [89.63772583, 26.22918701], [89.63769531, 26.2293663], [89.63751221, 26.23040962], [89.63536072, 26.23097229], [89.63379669, 26.23034668], [89.63361359, 26.22829628], [89.63379669, 26.22751045], [89.6341095, 26.22616577], [89.6346283, 26.22421265], [89.63481903, 26.22348976], [89.63394928, 26.22201157], [89.63733673, 26.22237015], [89.63759613, 26.22234917], [89.63725281, 26.21886063], [89.63739777, 26.21665001], [89.63685608, 26.2133007], [89.63683319, 26.21307945], [89.63666534, 26.21105385], [89.63833618, 26.21108818], [89.63890839, 26.20879173], [89.64054108, 26.20783043], [89.64096832, 26.20756912], [89.64102936, 26.20738983], [89.64192963, 26.20425034], [89.64305115, 26.20020294], [89.64370728, 26.19746971], [89.64639282, 26.19512558], [89.6475296, 26.19306946], [89.64820099, 26.19323921], [89.64838409, 26.19179153], [89.64980316, 26.19146156], [89.64994049, 26.19029808], [89.64980316, 26.19026566], [89.64832306, 26.18992996], [89.64762115, 26.18935204], [89.64743805, 26.18777847], [89.64589691, 26.1890049], [89.64553833, 26.18862915], [89.64737701, 26.18528938], [89.64710236, 26.18523407], [89.64496613, 26.1848526], [89.64450073, 26.18497086], [89.64367676, 26.18528366], [89.64235687, 26.18538094], [89.64211273, 26.18579292], [89.64150238, 26.18599129], [89.64138031, 26.1860199], [89.64089203, 26.18606186], [89.64016724, 26.18672371], [89.63798523, 26.18686485], [89.63796234, 26.18817139], [89.63716888, 26.18802071], [89.637146, 26.18833733], [89.63713074, 26.18857193], [89.63764191, 26.18862152], [89.63790131, 26.18864441], [89.63786316, 26.18979645], [89.63548279, 26.19022179], [89.63645172, 26.18904114], [89.63430023, 26.18856049], [89.63212585, 26.18806076], [89.63131714, 26.18786812], [89.62983704, 26.18618965], [89.63076019, 26.18412971], [89.63181305, 26.18263054], [89.63224792, 26.18239594], [89.6322403, 26.1826973], [89.6322403, 26.18280029], [89.63301086, 26.18278885], [89.63296509, 26.18200874], [89.63343048, 26.18176079], [89.63475037, 26.18180084], [89.63736725, 26.18062019], [89.6391983, 26.17951012], [89.63928986, 26.1794796], [89.6402359, 26.18234444], [89.64318085, 26.18270302], [89.64364624, 26.18289185], [89.64597321, 26.18161583], [89.6476059, 26.18131828], [89.65014648, 26.18053436], [89.65048218, 26.18092918], [89.6528244, 26.18097878], [89.65315247, 26.18157005], [89.65544128, 26.18152618], [89.65577698, 26.18023872], [89.65622711, 26.18023872], [89.65904236, 26.17893028], [89.66057587, 26.17681122], [89.66062164, 26.17563057], [89.65952301, 26.17336082], [89.65753937, 26.17201996], [89.65745544, 26.17193413], [89.65612793, 26.17051125], [89.65582275, 26.17006493], [89.65567017, 26.17008591], [89.65528107, 26.17002487], [89.654953, 26.17020226], [89.65471649, 26.17028236], [89.6545105, 26.17032433], [89.65454102, 26.17040443], [89.6530838, 26.17019272], [89.65126038, 26.17100334], [89.650383, 26.17012596], [89.65018463, 26.1699276], [89.65072632, 26.16864204], [89.6502533, 26.16820526], [89.64981079, 26.1678009], [89.64982605, 26.16712189], [89.64982605, 26.16686821], [89.64983368, 26.1662674], [89.64954376, 26.16625404], [89.64933014, 26.16624451], [89.64931488, 26.16591835], [89.64927673, 26.1652317], [89.64923859, 26.16453171], [89.64603424, 26.16455269], [89.64551544, 26.16556358], [89.64412689, 26.16575813], [89.64225769, 26.16555977], [89.64141083, 26.16604996], [89.64011383, 26.16680145], [89.63864899, 26.16693878], [89.63837433, 26.16696548], [89.6383667, 26.16727257], [89.63835907, 26.16804695], [89.63778687, 26.16898727], [89.63779449, 26.17063904], [89.63784027, 26.17107582], [89.63792419, 26.17185593], [89.63781738, 26.17222214], [89.63513184, 26.17204094], [89.63386536, 26.17201805], [89.63208008, 26.17198563], [89.63189697, 26.17335892], [89.6318512, 26.17371941], [89.63290405, 26.173563], [89.63334656, 26.17349815], [89.63359833, 26.17454147], [89.6337204, 26.17506981], [89.6353302, 26.17505836], [89.63581848, 26.17523766], [89.6360321, 26.17531586], [89.6361618, 26.17605209], [89.63624573, 26.17652893], [89.6370697, 26.17634964], [89.63729858, 26.17629814], [89.63731384, 26.177248], [89.63707733, 26.17737961], [89.63469696, 26.1782093], [89.63318634, 26.17818069], [89.63076782, 26.17674065], [89.62935638, 26.17534065], [89.62805176, 26.17308044], [89.62689972, 26.17145157], [89.6247406, 26.17140579], [89.62471771, 26.17133331], [89.62451172, 26.17130089], [89.62391663, 26.17120934], [89.62281799, 26.17129517], [89.62275696, 26.17189026], [89.6219635, 26.17186928], [89.62195587, 26.17238045], [89.62194824, 26.1728611], [89.62245178, 26.17282677], [89.62277222, 26.17280388], [89.62277222, 26.17343521], [89.62165833, 26.17352295], [89.62184143, 26.17384529], [89.62200165, 26.17414093], [89.62294769, 26.17432022], [89.62327576, 26.17438316], [89.62314606, 26.17519569], [89.62332153, 26.17531013], [89.62319946, 26.17715836], [89.62303925, 26.1774559], [89.62380219, 26.17768478], [89.62380981, 26.17804337], [89.62384033, 26.17921638], [89.62111664, 26.17939377], [89.61808777, 26.1793499], [89.61476135, 26.17866898], [89.61480713, 26.17846298], [89.6151886, 26.176548], [89.61487579, 26.1765728], [89.61326599, 26.17670631], [89.61260986, 26.17704773], [89.61277771, 26.17798996], [89.61183929, 26.17809296], [89.61180878, 26.17828178], [89.60926056, 26.17865944], [89.60938263, 26.17891884], [89.6098938, 26.17992973], [89.61013031, 26.18041039], [89.60871124, 26.18068504], [89.60855865, 26.18033981], [89.60835266, 26.17987442], [89.60796356, 26.17961693], [89.60738373, 26.17923737], [89.60746765, 26.17897797], [89.60764313, 26.17841911], [89.60804749, 26.17856026], [89.60849762, 26.17671013], [89.60816193, 26.176651], [89.60823059, 26.17644119], [89.61242676, 26.17637444], [89.61239624, 26.17582703], [89.61402893, 26.17546844], [89.61411285, 26.17545128], [89.614151, 26.17562103], [89.61424255, 26.17607498], [89.61508942, 26.17597771], [89.61522675, 26.1742878], [89.6153183, 26.17311859], [89.61355591, 26.17328072], [89.6136322, 26.17351723], [89.61330414, 26.1735878], [89.61320496, 26.17361069], [89.61325073, 26.17375946], [89.61346436, 26.17455864], [89.6116333, 26.17510986], [89.61164856, 26.17467308], [89.61166382, 26.17442131], [89.61144257, 26.17442894], [89.61091614, 26.17444801], [89.61094666, 26.17402267], [89.61115265, 26.17118454], [89.6115036, 26.17113495], [89.61142731, 26.17055321], [89.61138916, 26.17030907], [89.61156464, 26.17027283], [89.61174774, 26.17023468], [89.61164856, 26.16995239], [89.61116791, 26.16870308], [89.61122894, 26.1686573], [89.61277771, 26.16746902], [89.61470795, 26.16817474], [89.61491394, 26.16825104], [89.61524963, 26.1683712], [89.61769867, 26.16915321], [89.61800385, 26.16925049], [89.61823273, 26.16849709], [89.61915588, 26.16866112], [89.61837769, 26.16818619], [89.6197052, 26.1681881], [89.61875153, 26.16770363], [89.61856842, 26.16761017], [89.61865234, 26.16739464], [89.61895752, 26.16745949], [89.62129211, 26.1677227], [89.62197113, 26.16680908], [89.61992645, 26.16553116], [89.61738586, 26.16436958], [89.61676025, 26.16344261], [89.6163559, 26.16284943], [89.61598206, 26.16172028], [89.61450958, 26.16146088], [89.61267853, 26.16102982], [89.611763, 26.15922165], [89.61181641, 26.15837097], [89.61344147, 26.15755081], [89.61435699, 26.15571976], [89.61348724, 26.15335274], [89.61152649, 26.15200996], [89.60970306, 26.15215111], [89.60945892, 26.15300179], [89.60932159, 26.15376282], [89.60901642, 26.15370369], [89.60848999, 26.15360069], [89.60693359, 26.15449715], [89.60757446, 26.15669823], [89.60790253, 26.15820122], [89.60797882, 26.15843201], [89.60741425, 26.15849304], [89.60738373, 26.15767479], [89.60720825, 26.15812683], [89.60652161, 26.158041], [89.60597992, 26.15777397], [89.6053772, 26.15914726], [89.60431671, 26.1585331], [89.60440826, 26.15837288], [89.6053009, 26.15690613], [89.60455322, 26.15639687], [89.60446167, 26.15641975], [89.60411072, 26.15650368], [89.60375977, 26.1565876], [89.60121155, 26.15788269], [89.6001358, 26.1602726], [89.599617, 26.16047287], [89.59689331, 26.15949059], [89.59469604, 26.15703964], [89.59458923, 26.15690994], [89.59498596, 26.15653419], [89.59599304, 26.15646362], [89.59706116, 26.15505028], [89.59741211, 26.15458298], [89.5974884, 26.15452766], [89.59785461, 26.15400696], [89.59788513, 26.15376663], [89.5983429, 26.15052986], [89.59658051, 26.1499939], [89.59754944, 26.14851379], [89.59777069, 26.14818001], [89.59771729, 26.14762688], [89.59738159, 26.14429665], [89.59554291, 26.1400013], [89.59568787, 26.13996887], [89.59706879, 26.13965225], [89.59818268, 26.1390934], [89.59810638, 26.13734627], [89.59764099, 26.13642502], [89.59741211, 26.13597107], [89.59649658, 26.13530159], [89.5966568, 26.13517189], [89.5978775, 26.13415909], [89.59825134, 26.13278008], [89.59790802, 26.13255119], [89.59967804, 26.13131142], [89.60074615, 26.13021469], [89.60235596, 26.12680626], [89.60276031, 26.12674332], [89.60305023, 26.12672615], [89.6033783, 26.12833214], [89.60345459, 26.12836838], [89.60418701, 26.12870979], [89.60671234, 26.12602997], [89.60745239, 26.12569046], [89.60840607, 26.1259594], [89.60927582, 26.12515068], [89.60943604, 26.12452507], [89.61035156, 26.12626648], [89.61201477, 26.12759018], [89.61234283, 26.1278553], [89.61339569, 26.12667084], [89.61351776, 26.12557983], [89.61353302, 26.12546921], [89.61547089, 26.12338066], [89.61710358, 26.12056541], [89.62036133, 26.11985207], [89.62043762, 26.1198349], [89.62049103, 26.11992645], [89.62132263, 26.12141037], [89.62190247, 26.12244797], [89.62251282, 26.12613678], [89.62371826, 26.12786102], [89.62566376, 26.12835884], [89.62630463, 26.12852287], [89.62738037, 26.12750435], [89.62776184, 26.12714195], [89.62847137, 26.12783051], [89.63121033, 26.12620163], [89.63188171, 26.12370872], [89.63215637, 26.12265968], [89.63298798, 26.1189003], [89.63297272, 26.11758995], [89.63160706, 26.11544991], [89.62676239, 26.11211967], [89.62651062, 26.11194992], [89.62420654, 26.1100502], [89.62217712, 26.10860062], [89.62045288, 26.10696983], [89.6187973, 26.10642815], [89.61702728, 26.10623169], [89.61598206, 26.10663986], [89.61516571, 26.10718918], [89.61405945, 26.10689735], [89.61196136, 26.10795021], [89.61061859, 26.1086235], [89.60877991, 26.10831833], [89.60733032, 26.10756683], [89.60543823, 26.10658073], [89.60519409, 26.10645294], [89.60513306, 26.10666084], [89.60440063, 26.10911942], [89.6029892, 26.10930443], [89.60292053, 26.1093483], [89.60260773, 26.10905075], [89.60212708, 26.10860062], [89.60044861, 26.10885048], [89.59979248, 26.10876656], [89.59848785, 26.10860062], [89.59832764, 26.10818291], [89.59811401, 26.10762215], [89.59903717, 26.10744476], [89.59932709, 26.10778999], [89.60071564, 26.10758591], [89.60047913, 26.10627747], [89.59999084, 26.10354805], [89.59971619, 26.10362625], [89.59684753, 26.1044445], [89.59423065, 26.10344505], [89.59416199, 26.10321808], [89.59384918, 26.10224152], [89.59532166, 26.10030746], [89.59671021, 26.09802246], [89.59868622, 26.0969162], [89.60147858, 26.09580803], [89.6042099, 26.09481621], [89.60579681, 26.09341812], [89.60704041, 26.09045792], [89.60825348, 26.08850479], [89.60971069, 26.0897007], [89.61001587, 26.08994675], [89.61016846, 26.09007454], [89.60912323, 26.09308434], [89.60943604, 26.09547997], [89.6113205, 26.09649086], [89.61222839, 26.09627914], [89.61277771, 26.09615326], [89.61383057, 26.09527588], [89.61492157, 26.09608269], [89.61713409, 26.0950985], [89.61604309, 26.09803581], [89.61360168, 26.1009388], [89.61386871, 26.10342789], [89.61389923, 26.10370064], [89.61608124, 26.10426712], [89.61759949, 26.10326767], [89.61849976, 26.10353088], [89.62001038, 26.10317039], [89.62097931, 26.10225105], [89.62214661, 26.10113525], [89.6227417, 26.10174942], [89.62337494, 26.1030159], [89.62364197, 26.10567474], [89.62355804, 26.10750389], [89.62385559, 26.10782623], [89.6240387, 26.10801506], [89.62526703, 26.10836601], [89.62748718, 26.10821724], [89.62791443, 26.10801315], [89.62856293, 26.10831261], [89.62872314, 26.10839081], [89.63169098, 26.10732079], [89.63266754, 26.10696983], [89.63455963, 26.10482979], [89.63471222, 26.10466003], [89.63529968, 26.10244179], [89.6362915, 26.10116959], [89.63935089, 26.09958839], [89.63977814, 26.09890938], [89.63748169, 26.09661102], [89.63555908, 26.09465027], [89.63780212, 26.09308052], [89.63928223, 26.09235191], [89.63922119, 26.09209824], [89.63917542, 26.09191132], [89.63912964, 26.09172821], [89.63908386, 26.09150314], [89.63903046, 26.09126854], [89.63898468, 26.09112167], [89.63934326, 26.09096909], [89.63919067, 26.08973312], [89.63838959, 26.08974266], [89.63733673, 26.0897541], [89.63716888, 26.08934212], [89.63641357, 26.08747673], [89.63657379, 26.08574295], [89.63591766, 26.08619881], [89.63562775, 26.08640289], [89.63475037, 26.08525658], [89.63414001, 26.08444977], [89.63340759, 26.08262825], [89.63398743, 26.08010674], [89.63529205, 26.07834435], [89.63562775, 26.0777607], [89.63671875, 26.07540512], [89.6392746, 26.07413483], [89.64155579, 26.07324028], [89.6442337, 26.07150841], [89.64588928, 26.07024002], [89.64825439, 26.06848717], [89.64965057, 26.06640053], [89.65000153, 26.06448364], [89.64953613, 26.06303596], [89.64920807, 26.06201363], [89.64902496, 26.06145287], [89.64790344, 26.06197739], [89.6470871, 26.06235886], [89.64428711, 26.06212044], [89.64099121, 26.06068993], [89.63896942, 26.06026077], [89.6375885, 26.06034088], [89.63636017, 26.06121445], [89.63478851, 26.06105614], [89.63321686, 26.06206703], [89.6317215, 26.06302834], [89.63048553, 26.062397], [89.62802124, 26.06113625], [89.62741852, 26.05755997], [89.62657166, 26.05745506], [89.62504578, 26.05726433], [89.62440491, 26.056633], [89.62225342, 26.05450821], [89.62162018, 26.05429268], [89.62068939, 26.05397415], [89.61934662, 26.0535183], [89.61719513, 26.05437851], [89.61611176, 26.05692673], [89.61753845, 26.05983734], [89.61772919, 26.06022453], [89.61682892, 26.06002235], [89.61620331, 26.05988121], [89.61598206, 26.05982971], [89.61540985, 26.05974579], [89.61309814, 26.05940819], [89.6101532, 26.0600605], [89.6096344, 26.06219673], [89.60870361, 26.06382942], [89.60836029, 26.06361008], [89.60788727, 26.06157112], [89.60891724, 26.05940056], [89.61065674, 26.05817986], [89.61273193, 26.05768967], [89.61345673, 26.05729103], [89.61441803, 26.05676079], [89.61614227, 26.05435181], [89.61667633, 26.05297279], [89.61559296, 26.05140114], [89.61260986, 26.04997063], [89.60975647, 26.0486412], [89.60832214, 26.04815292], [89.60690308, 26.04766273], [89.60678864, 26.04758263], [89.60391235, 26.04548073], [89.60201263, 26.04459763], [89.60037231, 26.04422951], [89.59941864, 26.0440197], [89.59790802, 26.04409027], [89.59596252, 26.04424095], [89.59564972, 26.0439682], [89.59506989, 26.0434494], [89.59555054, 26.04296112], [89.59630585, 26.04217911], [89.59841919, 26.04055977], [89.60053253, 26.03944969], [89.60172272, 26.03803062], [89.59938049, 26.0365696], [89.59606934, 26.03508186], [89.59449005, 26.0346508], [89.5934906, 26.03523064], [89.59329224, 26.03550529], [89.59140015, 26.03570366], [89.59104156, 26.03658676], [89.59005737, 26.03647995], [89.58934784, 26.03558922], [89.5892868, 26.03575897], [89.58914948, 26.03604126], [89.58911896, 26.03619957], [89.58901215, 26.0363369], [89.58909607, 26.03684044], [89.5892868, 26.03830338], [89.58904266, 26.03847122], [89.58874512, 26.03862953], [89.58849335, 26.03872871], [89.5880661, 26.0388031], [89.58773804, 26.03884888], [89.5876236, 26.03879547], [89.58681488, 26.03842163], [89.58657837, 26.03505898], [89.58579254, 26.03464317], [89.58365631, 26.0335083], [89.58364105, 26.03340149], [89.58315277, 26.03033829], [89.58423615, 26.02907753], [89.58527374, 26.02636528], [89.58428192, 26.02524948], [89.58356476, 26.02445221], [89.58348846, 26.02444267], [89.58148193, 26.02420807], [89.58106995, 26.02205086], [89.58270264, 26.01777077], [89.5841217, 26.01172066], [89.58364105, 26.00946045], [89.58248901, 26.00786972], [89.58409119, 26.00513077], [89.58367157, 26.00320053], [89.58602905, 26.00095177], [89.58899689, 25.99829102], [89.59176636, 25.99398994], [89.59136963, 25.99207115], [89.58847809, 25.9889183], [89.58930969, 25.98538971], [89.59059143, 25.98299026], [89.59118652, 25.9808712], [89.59120941, 25.97847748], [89.5907135, 25.97591591], [89.59051514, 25.97598457], [89.59038544, 25.97600746], [89.590271, 25.97600174], [89.59008026, 25.9759388], [89.58987427, 25.97583008], [89.58953094, 25.97560501], [89.58942413, 25.97553635], [89.58769989, 25.97615051], [89.58740234, 25.97649193], [89.58545685, 25.97774506], [89.58509064, 25.97766495], [89.58511353, 25.97600174], [89.58431244, 25.97600555], [89.58423615, 25.97600555], [89.58374023, 25.97774506], [89.58366394, 25.97800636], [89.5835495, 25.97840691], [89.58342743, 25.97884941], [89.5814209, 25.97904778], [89.58052826, 25.97913551], [89.57989502, 25.97919846], [89.5779953, 25.97861481], [89.57795715, 25.97661972], [89.57795715, 25.97623062], [89.57853699, 25.97578812], [89.57920837, 25.97529984], [89.58113098, 25.9736805], [89.58127594, 25.9719429], [89.58133698, 25.97123909], [89.58040619, 25.9681797], [89.57692719, 25.96685982], [89.5735321, 25.9674511], [89.573349, 25.96770859], [89.57311249, 25.96821213], [89.57068634, 25.96778679], [89.56884003, 25.96785927], [89.56735229, 25.9704895], [89.56739807, 25.97178268], [89.5654068, 25.9701004], [89.56260681, 25.96799088], [89.56144714, 25.96606255], [89.55799103, 25.96461868], [89.55792999, 25.96472359], [89.55786896, 25.9648571], [89.55779266, 25.9650631], [89.55758667, 25.96545982], [89.55430603, 25.96553802], [89.55177307, 25.96602821], [89.55006409, 25.96636581], [89.54990387, 25.96639633], [89.54974365, 25.966465], [89.5495224, 25.96661568], [89.54729462, 25.96814537], [89.54695892, 25.96813965], [89.54498291, 25.96810913], [89.5408783, 25.9696312], [89.53874969, 25.9722023], [89.53852844, 25.97337723], [89.5381546, 25.9753685], [89.5381012, 25.97567558], [89.53937531, 25.97816658], [89.54019928, 25.98037148], [89.5415802, 25.98319817], [89.54161835, 25.98328018], [89.54151154, 25.98343849], [89.53755951, 25.98481369], [89.53671265, 25.98505211], [89.53623962, 25.98548317], [89.53601074, 25.98569489], [89.5361557, 25.98701096], [89.53621674, 25.98770714], [89.53618622, 25.988451], [89.53617096, 25.98875046], [89.53569031, 25.98885536], [89.53509521, 25.98898888], [89.53572083, 25.99067688], [89.53639984, 25.99009132], [89.53715515, 25.99060059], [89.53787231, 25.99089622], [89.53784943, 25.99149704], [89.53728485, 25.99178123], [89.53772736, 25.99430656], [89.54098511, 25.99556732], [89.5421524, 25.9960289], [89.54285431, 25.99708557], [89.54543304, 25.99729919], [89.54537964, 25.99806213], [89.54798126, 25.9981041], [89.54812622, 26.00006104], [89.548172, 26.00069809], [89.54734039, 26.00115776], [89.54663086, 26.00048637], [89.54651642, 26.00037766], [89.54560089, 26.00039101], [89.54499817, 26.00039864], [89.5447464, 26.00270081], [89.54288483, 26.00270844], [89.54283142, 26.00367737], [89.54231262, 26.00444794], [89.54128265, 26.00448418], [89.53968048, 26.0031395], [89.53762817, 26.00281525], [89.53740692, 26.00223541], [89.53665161, 26.00252724], [89.53635406, 26.00261307], [89.53567505, 26.00312233], [89.53424072, 26.00353813], [89.5318985, 26.00393105], [89.53044891, 26.00521469], [89.5297699, 26.00583649], [89.52921295, 26.00562668], [89.52844238, 26.00534058], [89.52793884, 26.00515175], [89.52606201, 26.00485229], [89.52549744, 26.00590515], [89.52521515, 26.00608063], [89.52485657, 26.00613976], [89.52363586, 26.00624275], [89.52200317, 26.00527], [89.52126312, 26.0082798], [89.51706696, 26.00670052], [89.51634216, 26.00597763], [89.5136261, 26.00328064], [89.51164246, 26.00131989], [89.50829315, 26.00033951], [89.50434113, 26.00159073], [89.50152588, 26.00271034], [89.50045776, 26.00325966], [89.49944305, 26.00357056], [89.49759674, 26.00344086], [89.4968338, 26.00295639], [89.49601746, 26.00318718], [89.49698639, 26.003479], [89.49661255, 26.0039196], [89.49640656, 26.00416756], [89.49523926, 26.00413513], [89.4941864, 26.00406265], [89.49433899, 26.00465584], [89.49273682, 26.00512505], [89.49247742, 26.0057106], [89.49136353, 26.00601006], [89.49120331, 26.00605392], [89.49077606, 26.00430679], [89.4882431, 26.00278091], [89.48805237, 26.00182724], [89.48685455, 26.00028229], [89.48575592, 25.99991417], [89.48403931, 25.99933815], [89.48180389, 25.99752617], [89.48124695, 25.99754524], [89.48094177, 25.99734306], [89.48047638, 25.99714279], [89.48036194, 25.99712563], [89.48040009, 25.99698639], [89.47834015, 25.99670982], [89.47725677, 25.99690056], [89.47519684, 25.99727058], [89.47312164, 25.99706841], [89.46948242, 25.99768066], [89.46734619, 25.99803352], [89.46578979, 25.99809456], [89.461586, 25.99846077], [89.4610672, 25.99895477], [89.46100616, 25.99901009], [89.45985413, 25.9998436], [89.4597702, 25.99990463], [89.45932007, 26.00022888], [89.45891571, 26.0003643], [89.45864105, 26.00045776], [89.45807648, 26.00064659], [89.45798492, 26.00067902], [89.45485687, 26.00302696], [89.45243835, 26.00495911], [89.44991302, 26.00644875], [89.449646, 26.00647163], [89.44621277, 26.0068512], [89.44507599, 26.0069809], [89.43850708, 26.00859833], [89.43732452, 26.00936127], [89.43634796, 26.00949669], [89.43341064, 26.01021385], [89.43096161, 26.01114464], [89.42741394, 26.01324081], [89.42669678, 26.01532364], [89.42716217, 26.01527786], [89.42789459, 26.01520729], [89.42784119, 26.01470947], [89.42858887, 26.01459694], [89.42816925, 26.01616669], [89.42734528, 26.01925087], [89.42878723, 26.02244186], [89.43038177, 26.02516747], [89.43179321, 26.02773476], [89.43389893, 26.03053474], [89.43268585, 26.03854752], [89.43263245, 26.038908], [89.4315033, 26.0405674], [89.4295578, 26.04344749], [89.42950439, 26.04351997], [89.42938995, 26.04354477], [89.4282074, 26.04380608], [89.42582703, 26.0443306], [89.42378235, 26.04701042], [89.42306519, 26.04696465], [89.42267609, 26.04693985], [89.42428589, 26.04442787], [89.42437744, 26.04428482], [89.42329407, 26.04360771], [89.42123413, 26.04367447], [89.41891479, 26.04198456], [89.41783905, 26.04188347], [89.41519165, 26.0416584], [89.41339874, 26.04133415], [89.41184235, 26.04105186], [89.41049957, 26.04080963], [89.40739441, 26.04161263], [89.40679932, 26.04115486], [89.40626526, 26.04074669], [89.40720367, 26.04015541], [89.40750885, 26.0394783], [89.407547, 26.03939056], [89.40745544, 26.03939247], [89.40694427, 26.03940201], [89.40644836, 26.03787231], [89.40740967, 26.03624344], [89.40590668, 26.0352478], [89.40567017, 26.03498268], [89.40480804, 26.03401566], [89.40662384, 26.03305435], [89.40657043, 26.031744], [89.40656281, 26.03161812], [89.4052124, 26.03133011], [89.40427399, 26.03112793], [89.4039917, 26.0302639], [89.40361023, 26.02911377], [89.40317535, 26.02779579], [89.40312958, 26.027668], [89.40100098, 26.02630424], [89.3985672, 26.02603912], [89.39635468, 26.02462578], [89.3952179, 26.02396774], [89.39401245, 26.02327347], [89.39351654, 26.02298737], [89.39117432, 26.02303314], [89.39080811, 26.02304077], [89.39051819, 26.01926041], [89.39160156, 26.01857567], [89.39182281, 26.01843643], [89.39160156, 26.01794434], [89.39109039, 26.01681709], [89.39347076, 26.01527596], [89.39344025, 26.01385117], [89.39443207, 26.01325035], [89.39369965, 26.01202393], [89.39392853, 26.01064301], [89.39379883, 26.00918007], [89.39376068, 26.00872803], [89.39324951, 26.00814438], [89.3924408, 26.00723076], [89.39199066, 26.00933456], [89.3915863, 26.00943375], [89.39110565, 26.00955391], [89.39022827, 26.00860977], [89.39013672, 26.0085125], [89.38933563, 26.00844574], [89.38973999, 26.0091629], [89.38787079, 26.00997925], [89.3864975, 26.00969124], [89.383461, 26.00955009], [89.38072205, 26.00942993], [89.37911224, 26.01053047], [89.37783813, 26.01007652], [89.37773895, 26.00980949], [89.37757111, 26.00935173], [89.37702942, 26.00977898], [89.37535095, 26.00910187], [89.37338257, 26.00905991], [89.37162018, 26.00925064], [89.37126923, 26.00919533], [89.37117767, 26.00909042], [89.37052917, 26.00912476], [89.3692627, 26.00888062], [89.3677063, 26.00851822], [89.36593628, 26.00810814], [89.36312866, 26.00761986], [89.36078644, 26.00889015], [89.36039734, 26.00928879], [89.36005402, 26.00868225], [89.35964203, 26.00793839], [89.35951233, 26.00909424], [89.35949707, 26.0092411], [89.35822296, 26.00857544], [89.35710907, 26.00799179], [89.35666656, 26.00902939], [89.35626984, 26.00996971], [89.35588074, 26.00935555], [89.3553009, 26.00843239], [89.35536194, 26.00889778], [89.35441589, 26.01010895], [89.35428619, 26.01008987], [89.35243988, 26.01051903], [89.35225677, 26.01016426], [89.35171509, 26.00995255], [89.35113525, 26.01014137], [89.35105133, 26.01104355], [89.35099792, 26.01156616], [89.35055542, 26.01137543], [89.35037231, 26.01129913], [89.35022736, 26.0112381], [89.35017395, 26.01117897], [89.34959412, 26.01058197], [89.34913635, 26.01039314], [89.34848785, 26.01048088], [89.34875488, 26.01110649], [89.34902954, 26.01174736], [89.3482666, 26.01223946], [89.34708405, 26.01183128], [89.34643555, 26.01160622], [89.34420776, 26.01329803], [89.34559631, 26.01323318], [89.34689331, 26.0136013], [89.34692383, 26.01384735], [89.34703827, 26.01489449], [89.34664917, 26.01475906], [89.34606934, 26.01547813], [89.34576416, 26.0150528], [89.3453598, 26.01448822], [89.34361267, 26.01599884], [89.34368134, 26.01713562], [89.34298706, 26.01671028], [89.3433075, 26.01587296], [89.34349823, 26.01586151], [89.34358978, 26.01585579], [89.34342957, 26.01468658], [89.34313965, 26.01536942], [89.34217072, 26.01493645], [89.34003448, 26.01534653], [89.34098816, 26.01550484], [89.33995819, 26.01747704], [89.33892822, 26.01714706], [89.33971405, 26.01787376], [89.33727264, 26.01807594], [89.33847046, 26.01821518], [89.33903503, 26.01828003], [89.33861542, 26.01843834], [89.33728027, 26.0189476], [89.33718109, 26.02007484], [89.33827972, 26.01962662], [89.33869171, 26.01946068], [89.33865356, 26.02009392], [89.3385849, 26.02110291], [89.33719635, 26.020504], [89.3372879, 26.02180099], [89.33731842, 26.02223778], [89.33624268, 26.02039337], [89.33563232, 26.02027512], [89.33447266, 26.0200882], [89.33469391, 26.0209465], [89.33512115, 26.02086067], [89.3353653, 26.02080917], [89.33740997, 26.02300835], [89.3385849, 26.02340698], [89.33774567, 26.02344131], [89.33633423, 26.02350044], [89.33706665, 26.02477646], [89.33670807, 26.02556038], [89.33667755, 26.02589607], [89.33661652, 26.0265274], [89.33625031, 26.02636528], [89.33480835, 26.0257206], [89.33419037, 26.02747345], [89.33415222, 26.02757645], [89.33350372, 26.02726555], [89.33286285, 26.02696037], [89.33319092, 26.02828979], [89.33184052, 26.0293541], [89.33159637, 26.02954483], [89.33073425, 26.02913094], [89.33095551, 26.02774429], [89.3309021, 26.02762604], [89.33073425, 26.0272789], [89.32884979, 26.02834129], [89.3293457, 26.02860069], [89.33002472, 26.02895927], [89.32977295, 26.02956581], [89.32959747, 26.02996445], [89.32945251, 26.03031349], [89.32804108, 26.03036499], [89.32758331, 26.03038216], [89.32894897, 26.03153419], [89.32644653, 26.03187943], [89.32597351, 26.0325489], [89.32662964, 26.03274345], [89.32733154, 26.03294945], [89.32789612, 26.03331757], [89.32778931, 26.03410149], [89.32698059, 26.03437233], [89.32550812, 26.03486633], [89.32588959, 26.03524399], [89.32644653, 26.03597832], [89.32585907, 26.03663445], [89.32542419, 26.03631783], [89.32507324, 26.03606224], [89.32427979, 26.03604889], [89.32446289, 26.03671837], [89.32291412, 26.03772545], [89.32027435, 26.03814125], [89.31917572, 26.03926086], [89.3190918, 26.03845406], [89.31789398, 26.03797531], [89.31690979, 26.03758049], [89.31586456, 26.03734589], [89.31550598, 26.03726387], [89.31510925, 26.03756142], [89.31571198, 26.0381031], [89.31654358, 26.03832626], [89.31719971, 26.03849983], [89.3168869, 26.03902245], [89.31632996, 26.0390377], [89.31475067, 26.03908157], [89.31422424, 26.03936005], [89.31318665, 26.03991318], [89.31089783, 26.04099846], [89.308815, 26.04269791], [89.30731964, 26.04535675], [89.30724335, 26.04527092], [89.30641174, 26.04440308], [89.30615234, 26.04660797], [89.3057251, 26.04611778], [89.30509949, 26.04540825], [89.30480957, 26.04594994], [89.30371094, 26.04566574], [89.30406952, 26.04623413], [89.30459595, 26.04706955], [89.30257416, 26.04666519], [89.30266571, 26.04685783], [89.30185699, 26.04634285], [89.30123138, 26.04593277], [89.29928589, 26.04566956], [89.29719543, 26.0466156], [89.29657745, 26.04541969], [89.29519653, 26.04618645], [89.29355621, 26.04601479], [89.2919693, 26.04643059], [89.29161835, 26.04652023], [89.2911911, 26.04581642], [89.29090881, 26.04536438], [89.29080963, 26.0466938], [89.28913116, 26.04684639], [89.2891922, 26.0482502], [89.28407288, 26.04848099], [89.27877045, 26.0486393], [89.27850342, 26.04864693], [89.27566528, 26.04917526], [89.2767868, 26.0514946], [89.27706909, 26.05140114], [89.27895355, 26.05078506], [89.27911377, 26.05150986], [89.27949524, 26.05316544], [89.28000641, 26.05432892], [89.28010559, 26.05431557], [89.28074646, 26.05422211], [89.28087616, 26.05451965], [89.28161621, 26.05618858], [89.28162384, 26.05626869], [89.28157806, 26.05783653], [89.28067017, 26.05780411], [89.28100586, 26.0586071], [89.28096008, 26.06081963], [89.28124237, 26.0620594], [89.28120422, 26.06240845], [89.28113556, 26.06306648], [89.28166199, 26.0635376], [89.28179169, 26.06365585], [89.28244781, 26.06424522], [89.28099823, 26.06476021], [89.28097534, 26.06569481], [89.27839661, 26.06652641], [89.27823639, 26.06657791], [89.27809143, 26.06554794], [89.27800751, 26.06500816], [89.27667999, 26.06476784], [89.27642822, 26.06454277], [89.27587891, 26.06404495], [89.27588654, 26.06307983], [89.27588654, 26.06279755], [89.2762146, 26.06219101], [89.27579498, 26.0622654], [89.2752533, 26.06236267], [89.27519989, 26.0616169], [89.27612305, 26.06128502], [89.27574158, 26.06120872], [89.27409363, 26.06088257], [89.27379608, 26.06178093], [89.27241516, 26.06071854], [89.27186584, 26.06170845], [89.27079773, 26.06190681], [89.27043915, 26.06197166], [89.27007294, 26.06092262], [89.27085114, 26.0608654], [89.27083588, 26.06049728], [89.27082062, 26.06002045], [89.26935577, 26.06012344], [89.26908112, 26.06091118], [89.26696014, 26.06089592], [89.26542664, 26.06152725], [89.26430511, 26.06173515], [89.2644577, 26.06245804], [89.26383209, 26.06212616], [89.26043701, 26.06263542], [89.25937653, 26.06232834], [89.25824738, 26.06295013], [89.25802612, 26.06343079], [89.25759888, 26.06293106], [89.25722504, 26.06292534], [89.25704193, 26.06413841], [89.25602722, 26.06422234], [89.25598145, 26.06365013], [89.25434875, 26.06421471], [89.25489807, 26.06573677], [89.25431061, 26.06584549], [89.25437164, 26.06744385], [89.25463104, 26.06797409], [89.2549057, 26.06854057], [89.25514984, 26.06905556], [89.25601196, 26.07182121], [89.25520325, 26.07303047], [89.25505066, 26.07425308], [89.25465393, 26.07476044], [89.25522614, 26.0754509], [89.25571442, 26.07604408], [89.25601196, 26.07653618], [89.25630188, 26.07701683], [89.25634766, 26.07731819], [89.25680542, 26.08016014], [89.25712585, 26.08000374], [89.25772095, 26.07972336], [89.25791931, 26.08037186], [89.25803375, 26.08073997], [89.25836182, 26.0806942], [89.2587738, 26.08063698], [89.25904083, 26.08119965], [89.25946045, 26.08208275], [89.25966644, 26.08221436], [89.26081085, 26.08296204], [89.26042938, 26.08429909], [89.26134491, 26.08588028], [89.26580048, 26.08791161], [89.26550293, 26.09086609], [89.26630402, 26.09127235], [89.26644135, 26.09134293], [89.26638031, 26.09142494], [89.26563263, 26.0923996], [89.26675415, 26.09247971], [89.26644135, 26.09272766], [89.26584625, 26.0932045], [89.26546478, 26.09350586], [89.26559448, 26.09316635], [89.26580048, 26.09260941], [89.26421356, 26.09315872], [89.2639389, 26.09327316], [89.26373291, 26.09287834], [89.26333618, 26.0921936], [89.26114655, 26.09222031], [89.26025391, 26.09209061], [89.25972748, 26.09184456], [89.25974274, 26.09201622], [89.25888062, 26.09189034], [89.25743103, 26.09221268], [89.25734711, 26.09247398], [89.25567627, 26.09212494], [89.25669098, 26.09266281], [89.25521088, 26.09341621], [89.25304413, 26.09260368], [89.25296783, 26.09257507], [89.2529068, 26.09233093], [89.25275421, 26.09165764], [89.2515564, 26.09145737], [89.25112152, 26.09285545], [89.25148773, 26.09285545], [89.25230408, 26.09285545], [89.25214386, 26.09308434], [89.25136566, 26.09418106], [89.2502594, 26.09454918], [89.25049591, 26.09481812], [89.25141144, 26.09588623], [89.25143433, 26.0965519], [89.2514801, 26.0979538], [89.25232697, 26.097929], [89.2522583, 26.09863281], [89.25160217, 26.09860802], [89.2509613, 26.10027313], [89.25171661, 26.10131645], [89.25050354, 26.10107613], [89.24923706, 26.10081863], [89.24936676, 26.10115051], [89.24972534, 26.10207748], [89.24982452, 26.10231781], [89.24766541, 26.10181618], [89.2484436, 26.10370064], [89.24725342, 26.10453796], [89.24704742, 26.10468292], [89.24488068, 26.10667038], [89.24369812, 26.10497093], [89.24414825, 26.10610008], [89.24256897, 26.10594368], [89.24194336, 26.10588074], [89.24150085, 26.10583687], [89.24274445, 26.10727882], [89.241539, 26.1060276], [89.24101257, 26.10680389], [89.24214935, 26.10915184], [89.24039459, 26.10771561], [89.23986816, 26.1086235], [89.23947906, 26.10930634], [89.24008942, 26.10962486], [89.24128723, 26.11024666], [89.23999786, 26.11035919], [89.23921204, 26.11042786], [89.23955536, 26.11155891], [89.23787689, 26.11277771], [89.2377243, 26.11262894], [89.23745728, 26.11283302], [89.23635864, 26.11365891], [89.23548889, 26.11481476], [89.23352814, 26.11341095], [89.23304749, 26.11307144], [89.23329926, 26.11371613], [89.23348236, 26.11417198], [89.23300934, 26.11513138], [89.23168945, 26.11723709], [89.23055267, 26.11618996], [89.22971344, 26.11648941], [89.22917938, 26.11668205], [89.2303772, 26.11738586], [89.23066711, 26.11755753], [89.23007965, 26.11845398], [89.22879791, 26.12005997], [89.2284317, 26.12051582], [89.22911835, 26.120924], [89.22941589, 26.12110329], [89.22937775, 26.12289047], [89.22847748, 26.12317276], [89.22814941, 26.12313271], [89.22822571, 26.12291336], [89.22756958, 26.12244225], [89.22716522, 26.12215042], [89.22687531, 26.12298012], [89.22679901, 26.12318802], [89.22544098, 26.12433052], [89.22463226, 26.12377167], [89.22348785, 26.12511826], [89.22177887, 26.12566185], [89.22029877, 26.12565422], [89.21968842, 26.12461662], [89.21906281, 26.1245327], [89.21911621, 26.12472916], [89.21931458, 26.12542915], [89.2196579, 26.12663078], [89.21837616, 26.12673759], [89.21704102, 26.12563705], [89.21703339, 26.12636757], [89.21382904, 26.12697411], [89.21465302, 26.12635994], [89.21450806, 26.12602997], [89.21430206, 26.12553024], [89.21420288, 26.12529182], [89.21352386, 26.12585068], [89.21310425, 26.12546921], [89.21278381, 26.12517929], [89.21161652, 26.12449455], [89.2113266, 26.1243248], [89.21091461, 26.1252327], [89.21060944, 26.12589836], [89.20999908, 26.12665939], [89.20899963, 26.12678909], [89.20890045, 26.12666702], [89.20851135, 26.12685204], [89.20838928, 26.12691116], [89.20752716, 26.12664986], [89.20691681, 26.12648964], [89.20500946, 26.12453079], [89.20362091, 26.12431908], [89.20330811, 26.12437248], [89.20331573, 26.12452507], [89.20332336, 26.12462425], [89.20336151, 26.12477493], [89.2033844, 26.1248951], [89.2033844, 26.12504196], [89.20336914, 26.12524223], [89.20333099, 26.12538528], [89.20333862, 26.12548256], [89.20333862, 26.12565231], [89.20331573, 26.12583923], [89.20331573, 26.12600136], [89.20332336, 26.12609291], [89.20336151, 26.12619781], [89.20339966, 26.12630272], [89.20346069, 26.12636948], [89.20352173, 26.12644005], [89.20362854, 26.12637329], [89.20371246, 26.12631989], [89.20379639, 26.12627983], [89.20391846, 26.12629318], [89.20404816, 26.12635422], [89.20419312, 26.12642288], [89.20491028, 26.12731934], [89.20284271, 26.12935829], [89.20220947, 26.12876511], [89.20187378, 26.12908745], [89.20148468, 26.12854195], [89.2011795, 26.12899399], [89.20011902, 26.12860107], [89.19966125, 26.12751579], [89.19963074, 26.12744331], [89.19945526, 26.12744141], [89.19862366, 26.12743187], [89.1986084, 26.12720871], [89.19855499, 26.12637329], [89.19812775, 26.12575912], [89.19830322, 26.12680244], [89.19813538, 26.12645149], [89.1971817, 26.12670708], [89.1950531, 26.12727928], [89.19550323, 26.1267643], [89.19634247, 26.12581253], [89.19540405, 26.12592316], [89.19468689, 26.12600899], [89.1945343, 26.12532616], [89.19441986, 26.12481499], [89.19329071, 26.12478256], [89.19291687, 26.12387466], [89.19101715, 26.12519836], [89.18978119, 26.12453842], [89.18966675, 26.12647057], [89.18942261, 26.12682724], [89.18898773, 26.12688065], [89.18670654, 26.12662125], [89.18508148, 26.12675095], [89.18343353, 26.12851906], [89.18319702, 26.12813187], [89.18232727, 26.12938499], [89.18132019, 26.1281662], [89.18064117, 26.12928581], [89.18015289, 26.12817764], [89.18010712, 26.12808418], [89.17986298, 26.12829208], [89.17852783, 26.12941742], [89.17845917, 26.13035202], [89.17756653, 26.13012314], [89.17726898, 26.13029861], [89.17590332, 26.13110542], [89.17664337, 26.13157463], [89.17650604, 26.13207626], [89.17520905, 26.13185501], [89.17491913, 26.13111305], [89.17487335, 26.13100433], [89.17474365, 26.13098717], [89.17248535, 26.13068199], [89.17240906, 26.13083267], [89.17066956, 26.13062668], [89.17002869, 26.13055038], [89.17004395, 26.13124466], [89.17005157, 26.13140869], [89.16985321, 26.13142395], [89.16797638, 26.131567], [89.16687775, 26.13027], [89.16649628, 26.13235664], [89.16439819, 26.13174438], [89.16368866, 26.13353539], [89.16291046, 26.13324165], [89.16240692, 26.13305473], [89.16184998, 26.13433075], [89.16220093, 26.13524437], [89.16233063, 26.13557625], [89.16210175, 26.13553429], [89.16049957, 26.13524437], [89.16040039, 26.13545227], [89.16022491, 26.13581467], [89.16104889, 26.13735199], [89.16003418, 26.13672066], [89.15914917, 26.13686562], [89.15992737, 26.13711166], [89.15973663, 26.13737679], [89.1594162, 26.13783264], [89.16025543, 26.13829422], [89.1605835, 26.13847542], [89.16002655, 26.13920403], [89.15953064, 26.13985252], [89.15823364, 26.13837242], [89.15795135, 26.13909721], [89.15699005, 26.14006233], [89.15672302, 26.13939667], [89.15666962, 26.13925171], [89.15615845, 26.13904381], [89.15532684, 26.13870811], [89.15488434, 26.13960266], [89.15523529, 26.14072418], [89.15468597, 26.1414814], [89.15435028, 26.14189339], [89.153862, 26.14248657], [89.15418243, 26.14284515], [89.15353394, 26.14322853], [89.15353394, 26.14356995], [89.15353394, 26.14388847], [89.15335083, 26.14366722], [89.15312958, 26.14453506], [89.15345764, 26.14427948], [89.15363312, 26.14495087], [89.15343475, 26.14490509], [89.15309906, 26.14486122], [89.15301514, 26.1453476], [89.15213776, 26.14568138], [89.15211487, 26.14582825], [89.1520462, 26.14628792], [89.15222931, 26.14650917], [89.15280151, 26.14720345], [89.1517868, 26.14682579], [89.15222931, 26.14747047], [89.15227509, 26.14766502], [89.15242767, 26.14826202], [89.15241241, 26.1484623], [89.15148163, 26.14806366], [89.1512146, 26.14840126], [89.15093231, 26.14876366], [89.15136719, 26.14935493], [89.15175629, 26.14988899], [89.15169525, 26.15167809], [89.1498642, 26.15305138], [89.15024567, 26.15487289], [89.14931488, 26.15493202], [89.14922333, 26.15493774], [89.14926147, 26.15604591], [89.14926147, 26.15613747], [89.14845276, 26.15819359], [89.14862823, 26.15872574], [89.14887238, 26.15948296], [89.15139771, 26.15977859], [89.15532684, 26.15963936], [89.15549469, 26.15995407], [89.15607452, 26.16107368], [89.15677643, 26.1624279], [89.15722656, 26.16328812], [89.15435791, 26.16389656], [89.15323639, 26.16399956], [89.15300751, 26.16456032], [89.15235138, 26.16526222], [89.1521225, 26.16529274], [89.15185547, 26.16532898], [89.15187073, 26.16629028], [89.15188599, 26.16696739], [89.15136719, 26.16776657], [89.15071869, 26.16871071], [89.15049744, 26.16908455], [89.15003204, 26.16900444], [89.15036774, 26.16930008], [89.14905548, 26.16941643], [89.14910889, 26.17013359], [89.14754486, 26.17019844], [89.14643097, 26.17024422], [89.14543152, 26.17009544], [89.14543915, 26.16973114], [89.14473724, 26.1697197], [89.14474487, 26.16950417], [89.14474487, 26.16934204], [89.14440918, 26.16934776], [89.14250946, 26.16938782], [89.14096069, 26.16939545], [89.14020538, 26.17244148], [89.14015961, 26.17338371], [89.14015198, 26.17355728], [89.14040375, 26.17381287], [89.14105988, 26.17447662], [89.1411438, 26.17589951], [89.14025879, 26.1759491], [89.13965607, 26.17549515], [89.13965607, 26.17609596], [89.13842773, 26.17605591], [89.13841248, 26.17637634], [89.13748169, 26.17636299], [89.13690948, 26.17839241], [89.13713074, 26.17917061], [89.13685608, 26.18003654], [89.13522339, 26.18007851], [89.13511658, 26.18026543], [89.13455963, 26.18127823], [89.13499451, 26.18161964], [89.13553619, 26.18166351], [89.13568115, 26.18173981], [89.13608551, 26.18194389], [89.13605499, 26.18357658], [89.13657379, 26.18362427], [89.13648987, 26.18504333], [89.13539124, 26.18555069], [89.13542175, 26.18621254], [89.13548279, 26.18738747], [89.13619995, 26.18770409], [89.13711548, 26.18766022], [89.13707733, 26.18806267], [89.13704681, 26.18837547], [89.13802338, 26.18846512], [89.13818359, 26.18863678], [89.13830566, 26.18876648], [89.13845062, 26.18942451], [89.13864136, 26.1903553], [89.13869476, 26.19130325], [89.13922119, 26.19224358], [89.13886261, 26.19354248], [89.13912201, 26.19444466], [89.13916016, 26.19456673], [89.13926697, 26.19464111], [89.13990784, 26.1950779], [89.13999939, 26.19513702], [89.13980865, 26.19716644], [89.1397934, 26.19729805], [89.1394577, 26.19803238], [89.13928223, 26.19840622], [89.13986969, 26.19853401], [89.14028168, 26.19862175], [89.14019012, 26.19916916], [89.14009857, 26.19972992], [89.14207458, 26.199646], [89.14248657, 26.20077515], [89.14352417, 26.20047951], [89.14385223, 26.20038605], [89.14399719, 26.20269585], [89.1440506, 26.20350266], [89.14710999, 26.20490646], [89.147995, 26.20651817], [89.1484375, 26.20645332], [89.14852905, 26.20643997], [89.14880371, 26.20742416], [89.14820099, 26.20760345], [89.14825439, 26.20798874], [89.14837646, 26.20885849], [89.14929199, 26.20896149], [89.14925385, 26.20912552], [89.14897919, 26.21035004], [89.14787292, 26.21041298], [89.14749908, 26.21028137], [89.14741516, 26.21113586], [89.14685822, 26.21176529], [89.14667511, 26.21116829], [89.14570618, 26.21128082], [89.14459991, 26.21263313], [89.14369202, 26.21311378], [89.14373016, 26.21360397], [89.1428299, 26.21360779], [89.1426239, 26.21470261], [89.14207458, 26.21464157], [89.14174652, 26.21630478], [89.14154816, 26.21734238], [89.14178467, 26.21739388], [89.1421051, 26.21746063], [89.14170837, 26.21871376], [89.14217377, 26.21886063], [89.14215088, 26.21993637], [89.14211273, 26.22049141], [89.14206696, 26.2210865], [89.1431427, 26.22126007], [89.1437912, 26.22136307], [89.14091492, 26.22505569], [89.1410141, 26.22541428], [89.14030457, 26.22590828], [89.14054108, 26.22653008], [89.14065552, 26.2268486], [89.14082336, 26.22729111], [89.13972473, 26.22922516], [89.13951111, 26.22961426], [89.14073181, 26.23114204], [89.14125061, 26.23178864], [89.14093781, 26.23476601], [89.14087677, 26.23587418], [89.13935089, 26.2381382], [89.13764954, 26.23677635], [89.13695526, 26.23665047], [89.13396454, 26.23757744], [89.1336441, 26.23828316], [89.13357544, 26.23843384], [89.13593292, 26.23989296], [89.13596344, 26.24006462], [89.13607025, 26.24067879], [89.13533783, 26.2412281], [89.13182831, 26.23963547], [89.13248444, 26.24196815], [89.13091278, 26.24274826], [89.13174438, 26.24492264], [89.13187408, 26.2452507], [89.13211823, 26.24587631], [89.13109589, 26.24733925], [89.13064575, 26.24798012], [89.13001251, 26.24889374], [89.12693024, 26.24892998], [89.12674713, 26.24934769], [89.12670135, 26.24945641], [89.12612152, 26.25081253], [89.12513733, 26.25070763], [89.1242981, 26.25061989], [89.12417603, 26.25060654], [89.12412262, 26.25047493], [89.12390137, 26.24985123], [89.12368011, 26.25000191], [89.11985016, 26.25268364], [89.11978912, 26.25272942], [89.12002563, 26.25290489], [89.12036896, 26.25316238], [89.12029266, 26.25331497], [89.12007141, 26.25377464], [89.11987305, 26.25420189], [89.12090302, 26.25458336], [89.12088776, 26.2551403], [89.12221527, 26.25564384], [89.12203979, 26.25642967], [89.12136078, 26.25832748], [89.12329102, 26.25876236], [89.12324524, 26.25997925], [89.12329865, 26.26007652], [89.12358856, 26.26062202], [89.12386322, 26.26114845], [89.12532806, 26.26132584], [89.1252594, 26.26154518], [89.12496948, 26.26247215], [89.12516022, 26.26356316], [89.12310028, 26.26514626], [89.1200943, 26.26674271], [89.11976624, 26.26696777], [89.11787415, 26.26828575], [89.11700439, 26.26889229], [89.11505127, 26.26988983], [89.11437988, 26.27090836], [89.11381531, 26.27111435], [89.11235809, 26.27164078], [89.11159515, 26.27275658], [89.10996246, 26.2723465], [89.10933685, 26.27219009], [89.10861206, 26.27368355], [89.10903931, 26.27535629], [89.10887146, 26.27540207], [89.10784149, 26.27567482], [89.10633087, 26.27424812], [89.10601807, 26.27396011], [89.10527039, 26.27467155], [89.1050415, 26.27524185], [89.10494995, 26.27548409], [89.1049118, 26.27556801], [89.10496521, 26.27602386], [89.10501862, 26.2765007], [89.10513306, 26.27757454], [89.10515594, 26.27777481], [89.10544586, 26.27791786], [89.10591888, 26.27815437], [89.10600281, 26.27941322], [89.10597229, 26.28118515], [89.10582733, 26.28117561], [89.1056366, 26.28116608], [89.10552979, 26.28116035], [89.10436249, 26.2810955], [89.10393524, 26.28107071], [89.1033783, 26.28111839], [89.10337067, 26.28086853], [89.10328674, 26.27869225], [89.10300446, 26.27857971], [89.10198975, 26.27816963], [89.10017395, 26.27947998], [89.10005188, 26.27956581], [89.10015106, 26.27967262], [89.10120392, 26.28085518], [89.10127258, 26.28093147], [89.10183716, 26.28130913], [89.10237122, 26.28166962], [89.10258484, 26.28180885], [89.10231781, 26.28189278], [89.10186768, 26.28203201], [89.10168457, 26.28310966], [89.10198212, 26.28423882], [89.10234833, 26.28615189], [89.10237122, 26.2863121], [89.10253906, 26.28871346], [89.10347748, 26.28928566], [89.10449219, 26.28928375], [89.10430908, 26.28998184], [89.10641479, 26.29043961], [89.10696411, 26.29152489], [89.10707855, 26.29174995], [89.10497284, 26.29252052], [89.10433197, 26.2929306], [89.10326385, 26.29360962], [89.10346222, 26.29537773], [89.10365295, 26.29703712], [89.10494232, 26.29784584], [89.10731506, 26.29932785], [89.10417938, 26.30172729], [89.10377502, 26.30203629], [89.10295105, 26.30216789], [89.09973907, 26.30268097], [89.09919739, 26.30412102], [89.09959412, 26.30459595], [89.10053253, 26.30569267], [89.10155487, 26.30689812], [89.10287476, 26.30839729], [89.10287476, 26.30854034], [89.10269928, 26.31189156], [89.10268402, 26.31225014], [89.10347748, 26.31279182], [89.10335541, 26.31334114], [89.10482788, 26.31320763], [89.10466766, 26.3139267], [89.10463715, 26.31492615], [89.10469055, 26.3159256], [89.10495758, 26.31591034], [89.10603333, 26.3158474], [89.1060791, 26.31539536], [89.10503387, 26.31530571], [89.10497284, 26.31399155], [89.10501862, 26.31390953], [89.105896, 26.31377983], [89.10601044, 26.31376266], [89.10635376, 26.31371117], [89.1062851, 26.31337929], [89.10654449, 26.31334686], [89.10824585, 26.31312752], [89.10823059, 26.31297874], [89.10791016, 26.30932045], [89.10887909, 26.30937195], [89.10887146, 26.30837822], [89.10886383, 26.30735779], [89.10906219, 26.30731201], [89.10961914, 26.30845261], [89.11051941, 26.31100082], [89.11071777, 26.31270027], [89.11110687, 26.31456947], [89.11155701, 26.31568909], [89.11251831, 26.3169899], [89.11371613, 26.31687164], [89.11553192, 26.3139019], [89.11634064, 26.31100082], [89.11708832, 26.30861092], [89.11859894, 26.30705833], [89.12062073, 26.30629921], [89.12224579, 26.30277061], [89.12319183, 26.2994194], [89.1233902, 26.29796982], [89.12361908, 26.29623985], [89.1243515, 26.29369164], [89.12451172, 26.29411697], [89.1267395, 26.29577827], [89.12725067, 26.29615784], [89.12835693, 26.29619408], [89.12845612, 26.29619789], [89.12839508, 26.29669189], [89.12822723, 26.297966], [89.13053894, 26.29806519], [89.13134766, 26.29755402], [89.13156891, 26.29741478], [89.13131714, 26.29813576], [89.13111115, 26.29872131], [89.13230133, 26.29881477], [89.13240814, 26.2988224], [89.13235474, 26.30031967], [89.12995148, 26.30045128], [89.13012695, 26.29985046], [89.13034058, 26.2991333], [89.13038635, 26.29897499], [89.12862396, 26.29889107], [89.12809753, 26.30125237], [89.12797546, 26.30132675], [89.12785339, 26.30139923], [89.12739563, 26.30167007], [89.12743378, 26.30256271], [89.12746429, 26.30313683], [89.1288681, 26.30321121], [89.1288147, 26.30261993], [89.12877655, 26.30218697], [89.12872314, 26.30163956], [89.1288147, 26.30161858], [89.13127899, 26.30101013], [89.13080597, 26.30213928], [89.13067627, 26.30244255], [89.13010406, 26.30339813], [89.12999725, 26.30356979], [89.13077545, 26.30365181], [89.13057709, 26.30487823], [89.13051605, 26.3052845], [89.12989044, 26.30488205], [89.12837219, 26.3042717], [89.1282959, 26.30424118], [89.12822723, 26.30429268], [89.12747955, 26.30487061], [89.1271286, 26.30514145], [89.12564087, 26.30425072], [89.12516022, 26.30544853], [89.12718201, 26.30607414], [89.12765503, 26.3062191], [89.12901306, 26.30585861], [89.129776, 26.30593109], [89.13143158, 26.30608368], [89.13169861, 26.30610847], [89.13319397, 26.30596733], [89.13368988, 26.30592155], [89.1340332, 26.30685806], [89.13420105, 26.30732155], [89.13425446, 26.30747032], [89.13454437, 26.30747795], [89.13477325, 26.30779076], [89.13605499, 26.30790138], [89.1361618, 26.30828476], [89.13634491, 26.30891418], [89.13532257, 26.30887032], [89.13513947, 26.30955887], [89.13488007, 26.31135368], [89.13289642, 26.31128883], [89.13276672, 26.31197166], [89.13381195, 26.31206322], [89.13477325, 26.31214523], [89.13486481, 26.31215477], [89.13476563, 26.31324768], [89.1296463, 26.31259155], [89.12953186, 26.3125782], [89.12950134, 26.31313705], [89.12974548, 26.31316376], [89.13034058, 26.31322479], [89.1339035, 26.31377411], [89.13446045, 26.31385803], [89.13515472, 26.31466675], [89.13536072, 26.31467819], [89.1359787, 26.31471252], [89.13596344, 26.31700134], [89.13619232, 26.31962776], [89.13624573, 26.32021713], [89.13565063, 26.32032585], [89.13524628, 26.32040215], [89.13535309, 26.32059097], [89.13565826, 26.32112312], [89.13578033, 26.32133102], [89.13468933, 26.32144165], [89.13456726, 26.32145309], [89.13450623, 26.32136345], [89.13395691, 26.32062912], [89.13237, 26.32062149], [89.13093567, 26.32061386], [89.13076782, 26.31991959], [89.13053894, 26.31900406], [89.13027954, 26.31899071], [89.12825012, 26.3188858], [89.12820435, 26.31968498], [89.12604523, 26.31949997], [89.12529755, 26.32008362], [89.12522125, 26.32014084], [89.12509918, 26.32009125], [89.12371063, 26.3194294], [89.12226868, 26.31925964], [89.12201691, 26.31922913], [89.12043762, 26.31972122], [89.12030029, 26.31974983], [89.11985016, 26.32103729], [89.11932373, 26.32094002], [89.11937714, 26.3203392], [89.1193161, 26.32022858], [89.11736298, 26.32036018], [89.11701202, 26.3202877], [89.1164856, 26.32019615], [89.11632538, 26.32016754], [89.11544037, 26.32001305], [89.11636353, 26.31870079], [89.11642456, 26.31861496], [89.1162796, 26.31859589], [89.1149292, 26.31842041], [89.1145401, 26.31868172], [89.1126709, 26.31851006], [89.11148071, 26.32011414], [89.1115036, 26.3206768], [89.11073303, 26.3217411], [89.11045074, 26.32212257], [89.11184692, 26.32238388], [89.11177826, 26.3230381], [89.11139679, 26.32376671], [89.11019897, 26.32454872], [89.11010742, 26.32486725], [89.10996246, 26.32536125], [89.10871887, 26.32557106], [89.10826874, 26.32546616], [89.10781097, 26.32669258], [89.10726929, 26.32685852], [89.10692596, 26.32671928], [89.1065979, 26.32658577], [89.10564423, 26.32661057], [89.10566711, 26.32651711], [89.10580444, 26.3259182], [89.10567474, 26.32548714], [89.10549164, 26.32489777], [89.10466766, 26.325037], [89.10463715, 26.32489777], [89.10428619, 26.32338715], [89.10409546, 26.32338333], [89.10335541, 26.32336998], [89.10360718, 26.32301712], [89.10308075, 26.32308388], [89.10044861, 26.32341385], [89.1004715, 26.32354164], [89.10055542, 26.32402611], [89.09864807, 26.32417107], [89.09860229, 26.32468605], [89.09856415, 26.32502174], [89.09857941, 26.32514], [89.09864044, 26.32586098], [89.09934235, 26.32837677], [89.09915161, 26.32847023], [89.09892273, 26.32858086], [89.0982666, 26.32890129], [89.09816742, 26.32892799], [89.09673309, 26.32932281], [89.09642792, 26.32773399], [89.09551239, 26.32686996], [89.09550476, 26.32678413], [89.09545898, 26.32636261], [89.09537506, 26.32567596], [89.09527588, 26.32568932], [89.09355927, 26.32590866], [89.09352112, 26.32574463], [89.09316254, 26.32419586], [89.09290314, 26.32431412], [89.09277344, 26.32436943], [89.09275055, 26.32427216], [89.0921936, 26.32189178], [89.09185028, 26.3204155], [89.0916214, 26.32041359], [89.09145355, 26.32040977], [89.08979034, 26.3224678], [89.08925629, 26.32226563], [89.08744049, 26.32158852], [89.08742523, 26.32172585], [89.08721924, 26.3231163], [89.08720398, 26.32322884], [89.08686829, 26.3230896], [89.08439636, 26.32205009], [89.0837326, 26.32229805], [89.08364105, 26.32322693], [89.08454132, 26.32366943], [89.08579254, 26.32427979], [89.08879089, 26.32547188], [89.08950043, 26.32726479], [89.09120178, 26.32801056], [89.09157562, 26.3281765], [89.0911026, 26.32916451], [89.09088898, 26.32959557], [89.09142303, 26.32984161], [89.09274292, 26.32972717], [89.09306335, 26.32969856], [89.09320068, 26.32995796], [89.09527588, 26.32988167], [89.09544373, 26.33126068], [89.09546661, 26.33143425], [89.09558868, 26.33139992], [89.09619141, 26.3312397], [89.09642029, 26.33356857], [89.09646606, 26.33403397], [89.09708405, 26.33393288], [89.09734344, 26.33389091], [89.09809113, 26.33433342], [89.0982132, 26.33543587], [89.09828186, 26.33602905], [89.10016632, 26.33655167], [89.10087585, 26.33660316], [89.10128784, 26.33663368], [89.10126495, 26.33716011], [89.10071564, 26.33723068], [89.10015869, 26.33730316], [89.10015869, 26.33741188], [89.10022736, 26.33904266], [89.09931946, 26.33904457], [89.09899902, 26.33921242], [89.09771729, 26.33986855], [89.09779358, 26.34029388], [89.09809113, 26.34184265], [89.09873962, 26.34189415], [89.09848785, 26.34316254], [89.09807587, 26.34521294], [89.09809875, 26.34532738], [89.09851837, 26.34786415], [89.09815979, 26.34860802], [89.09789276, 26.34987259], [89.09599304, 26.35025215], [89.09590912, 26.35032272], [89.09577942, 26.35062218], [89.09545898, 26.35137749], [89.09515381, 26.35208893], [89.09535217, 26.35255814], [89.09580994, 26.3536396], [89.09590912, 26.35387611], [89.09506226, 26.35405731], [89.09443665, 26.35254669], [89.0940094, 26.3527317], [89.0933075, 26.3530407], [89.09386444, 26.35471535], [89.0958252, 26.35427475], [89.09584808, 26.35441971], [89.09637451, 26.35728073], [89.0981369, 26.35814857], [89.09822083, 26.35819054], [89.09825897, 26.35868073], [89.09828186, 26.35902786], [89.09632111, 26.35928154], [89.09630585, 26.35960197], [89.09627533, 26.36018562], [89.09461975, 26.36019135], [89.09397125, 26.36019325], [89.09377289, 26.36056709], [89.09370422, 26.3598175], [89.09268188, 26.35980415], [89.09265137, 26.35994339], [89.09249115, 26.3608036], [89.09203339, 26.36077309], [89.09141541, 26.36073303], [89.09011841, 26.36064529], [89.08982086, 26.36062622], [89.08972168, 26.36174774], [89.08969879, 26.36207962], [89.08921051, 26.36217499], [89.08691406, 26.36263084], [89.08575439, 26.36285973], [89.08575439, 26.36362648], [89.08576202, 26.3639698], [89.08441925, 26.36413574], [89.0841217, 26.36417198], [89.08325958, 26.36340141], [89.0831604, 26.36309052], [89.08289337, 26.36222458], [89.08273315, 26.36226082], [89.07965851, 26.36293793], [89.07966614, 26.36304665], [89.07985687, 26.36632538], [89.07988739, 26.36677551], [89.08617401, 26.36605263], [89.08694458, 26.36595917], [89.08685303, 26.36611748], [89.08718872, 26.36764908], [89.08795166, 26.36821175], [89.08898926, 26.36834717], [89.08898926, 26.37088203], [89.08898926, 26.37132835], [89.08989716, 26.37130165], [89.09038544, 26.37408829], [89.0904541, 26.37444115], [89.0905838, 26.37518501], [89.08901978, 26.37580109], [89.08887482, 26.3758564], [89.08889008, 26.37629318], [89.08894348, 26.37866974], [89.08896637, 26.37973404], [89.08899689, 26.38085175], [89.08899689, 26.38101768], [89.08943939, 26.38099861], [89.09034729, 26.38095665], [89.09046936, 26.38167], [89.09049225, 26.38181686], [89.09176636, 26.38258934], [89.09172821, 26.38319778], [89.09161377, 26.38538551], [89.08997345, 26.38547897], [89.09004211, 26.38567734], [89.09082794, 26.3881588], [89.09249878, 26.38968468], [89.09365082, 26.38946724], [89.0942688, 26.3893528], [89.09431458, 26.38950157], [89.09461212, 26.3904705], [89.09568024, 26.39154053], [89.0955658, 26.39159775], [89.09339142, 26.39267731], [89.09339905, 26.39280891], [89.09269714, 26.39256096], [89.0923233, 26.3924408], [89.09092712, 26.39210129], [89.09069061, 26.39221382], [89.09062195, 26.39212608], [89.0904007, 26.3918457], [89.08892059, 26.39204597], [89.08641052, 26.39238548], [89.0859375, 26.39245033], [89.08582306, 26.39192009], [89.08576965, 26.39170265], [89.08531952, 26.39163589], [89.08339691, 26.39134979], [89.08335114, 26.39044571], [89.08334351, 26.39037132], [89.08298492, 26.39035606], [89.08126831, 26.39028358], [89.08125305, 26.3903656], [89.08116913, 26.39110184], [89.08105469, 26.39114761], [89.08084106, 26.39123154], [89.08003235, 26.39155197], [89.07991791, 26.39159393], [89.08003998, 26.39180565], [89.08055115, 26.39270401], [89.08072662, 26.39302254], [89.081604, 26.39270401], [89.08206177, 26.39253807], [89.08216858, 26.39258194], [89.08380127, 26.3932724], [89.08478546, 26.39368629], [89.08517456, 26.39385033], [89.08668518, 26.39535141], [89.08721924, 26.39757156], [89.08727264, 26.39776421], [89.08616638, 26.39775467], [89.08537292, 26.39751053], [89.08396912, 26.39542007], [89.08326721, 26.39474106], [89.08168793, 26.39499092], [89.08132935, 26.39687157], [89.08101654, 26.39712143], [89.07530212, 26.39608002], [89.07524872, 26.39574051], [89.07484436, 26.39335632], [89.07453156, 26.39145279], [89.07447815, 26.39112473], [89.07374573, 26.39126968], [89.07379913, 26.39153099], [89.0747757, 26.3960743], [89.07118225, 26.39850235], [89.0708847, 26.39841461], [89.06943512, 26.39798164], [89.0693512, 26.39795685], [89.06848145, 26.39769936], [89.06841278, 26.39783859], [89.0675354, 26.39950562], [89.06633759, 26.39867973], [89.06437683, 26.39822578], [89.06438446, 26.39689064], [89.06439209, 26.39673424], [89.06424713, 26.39679718], [89.06302643, 26.39735031], [89.06180573, 26.39790344], [89.06266785, 26.39938354], [89.06227112, 26.39965057], [89.06143188, 26.39828491], [89.06124115, 26.39833641], [89.06053162, 26.39852333], [89.05911255, 26.39889717], [89.05896759, 26.39893532], [89.05893707, 26.39872932], [89.05852509, 26.39591408], [89.05843353, 26.39585304], [89.05789185, 26.39551544], [89.05780029, 26.39545441], [89.05567932, 26.39594269], [89.05535126, 26.39683151], [89.05531311, 26.39692497], [89.05509949, 26.39751434], [89.05440521, 26.39841652], [89.05414581, 26.39875031], [89.054039, 26.39875221], [89.05045319, 26.39885902], [89.0497818, 26.3988781], [89.04964447, 26.39893913], [89.04889679, 26.39927292], [89.04821777, 26.39957237], [89.04624939, 26.39993095], [89.04582214, 26.39793968], [89.04471588, 26.39723015], [89.04132843, 26.39799118], [89.04103851, 26.39792061], [89.04096222, 26.39799118], [89.04065704, 26.39931107], [89.04076385, 26.39999008], [89.03939056, 26.40029144], [89.03921509, 26.40023804], [89.03840637, 26.39997292], [89.0377655, 26.39976501], [89.03781128, 26.39858818], [89.03784943, 26.39746284], [89.03785706, 26.39731979], [89.03746033, 26.3968544], [89.0381012, 26.39666367], [89.03804016, 26.39653969], [89.03746796, 26.39539909], [89.03739929, 26.39526558], [89.03713226, 26.39530563], [89.03666687, 26.3953743], [89.03664398, 26.39496422], [89.0335083, 26.39553261], [89.0343399, 26.39956284], [89.03289795, 26.40003395], [89.0318222, 26.39966393], [89.03174591, 26.39968681], [89.03177643, 26.40052223], [89.03181458, 26.40166664], [89.0318222, 26.40184784], [89.03166199, 26.40186501], [89.03128815, 26.40190506], [89.03129578, 26.40202904], [89.03136444, 26.40392685], [89.03048706, 26.40384674], [89.02998352, 26.40380096], [89.02934265, 26.404953], [89.02992249, 26.40694809], [89.02996826, 26.4071064], [89.02977753, 26.40717888], [89.02864075, 26.40759659], [89.02798462, 26.40783691], [89.02667236, 26.40751457], [89.02584839, 26.40731049], [89.02439117, 26.40782356], [89.02426147, 26.4068737], [89.02310944, 26.40608215], [89.02212524, 26.40589714], [89.02197266, 26.40586853], [89.02200317, 26.40578461], [89.02211761, 26.40547371], [89.02259064, 26.40415001], [89.02264404, 26.40401077], [89.02136993, 26.40402985], [89.02032471, 26.40413284], [89.01935577, 26.40422821], [89.01891327, 26.40616035], [89.02040863, 26.40688324], [89.0205307, 26.4069519], [89.02155304, 26.40839386], [89.02277374, 26.40833282], [89.02302551, 26.40831947], [89.02240753, 26.41210747], [89.02173615, 26.41408348], [89.02170563, 26.41417122], [89.02140808, 26.41423035], [89.02003479, 26.41450882], [89.01799011, 26.41519356], [89.01787567, 26.41523361], [89.01750183, 26.41497231], [89.01725769, 26.41480446], [89.01444244, 26.41422462], [89.01219177, 26.41338348], [89.00994873, 26.41313934], [89.00814819, 26.41294289], [89.007164, 26.41283417], [89.00720215, 26.41312408], [89.00733185, 26.41430092], [89.007164, 26.41430664], [89.00667572, 26.41432571], [89.00619507, 26.41572762], [89.00582123, 26.4167881], [89.00565338, 26.41679764], [89.00502777, 26.41683006], [89.00508881, 26.4171772], [89.00489807, 26.41712952], [89.00348663, 26.41788292], [89.00335693, 26.41996193], [89.00049591, 26.41996193], [88.99913025, 26.42134285], [88.99906921, 26.42139816], [88.99875641, 26.42044449], [88.99832916, 26.42049217], [88.99568176, 26.42078972], [88.99568939, 26.42089462], [88.99573517, 26.42142677], [88.99585724, 26.42268944], [88.99474335, 26.42288399], [88.99367523, 26.42307091], [88.99346161, 26.42228317], [88.99295807, 26.4203968], [88.99311829, 26.42036438], [88.9956665, 26.4198246], [88.99595642, 26.41976357], [88.99590302, 26.41953468], [88.99559021, 26.41818428], [88.99524689, 26.41675377], [88.99578857, 26.41667938], [88.99790192, 26.41553307], [88.99819946, 26.41417885], [88.99822998, 26.41404724], [88.99835968, 26.41344833], [88.99839783, 26.41327477], [88.9963913, 26.41254044], [88.99397278, 26.41289711], [88.99411011, 26.41394424], [88.99423981, 26.41494942], [88.99422455, 26.41525078], [88.99414063, 26.41685677], [88.99220276, 26.41709709], [88.99211121, 26.41710854], [88.99226379, 26.417593], [88.9927063, 26.4189949], [88.99136353, 26.42023468], [88.98838806, 26.4204483], [88.98547363, 26.42022705], [88.98308563, 26.42109489], [88.9829483, 26.42114639], [88.98340607, 26.42359543], [88.98357391, 26.42448997], [88.98159027, 26.42508507], [88.98069, 26.42535591], [88.98108673, 26.42577171], [88.98151398, 26.42621994], [88.98143005, 26.42628098], [88.98085022, 26.42669868], [88.98279572, 26.4285202], [88.98384094, 26.42949867], [88.98297882, 26.43097687], [88.98140717, 26.43041039], [88.98036957, 26.43168831], [88.97976685, 26.43384552], [88.97884369, 26.43393517], [88.97854614, 26.43396378], [88.97872162, 26.4360981], [88.98120117, 26.43664551], [88.9828186, 26.43808365], [88.98311615, 26.44012833], [88.9832077, 26.44079208], [88.98423004, 26.44169044], [88.98317719, 26.44212151], [88.98290253, 26.44161034], [88.98087311, 26.44184875], [88.98091125, 26.4430027], [88.9809494, 26.44425201], [88.9824295, 26.4440136], [88.98285675, 26.44542885], [88.9832077, 26.44659424], [88.98088837, 26.44689178], [88.97871399, 26.44633102], [88.97846985, 26.44626999], [88.97847748, 26.44800758], [88.97847748, 26.4481926], [88.97927094, 26.44822884], [88.97935486, 26.44973183], [88.97724915, 26.44921112], [88.97669983, 26.44630814], [88.97640991, 26.44637108], [88.97576141, 26.44651413], [88.97592926, 26.44706917], [88.97612, 26.44771385], [88.97499084, 26.44874001], [88.97498322, 26.44995308], [88.97138214, 26.45031357], [88.97103119, 26.45143509], [88.96728516, 26.45136261], [88.96624756, 26.45134163], [88.96632385, 26.45176315], [88.96639252, 26.45217514], [88.9665451, 26.45298576], [88.96613312, 26.45298958], [88.96559143, 26.4529953], [88.96560669, 26.45445251], [88.96562958, 26.45598221], [88.96565247, 26.45765114], [88.9646759, 26.45741081], [88.95877838, 26.45910263], [88.95713806, 26.45953178], [88.95579529, 26.46029663], [88.95545959, 26.45991135], [88.95720673, 26.45915222], [88.9572525, 26.4548645], [88.95796204, 26.45464516], [88.95908356, 26.45429039], [88.95933533, 26.45318031], [88.95941925, 26.45300674], [88.9597168, 26.45240021], [88.95996094, 26.45241928], [88.9628067, 26.4526329], [88.96521759, 26.4519825], [88.96398163, 26.45116806], [88.96277618, 26.45013428], [88.96144104, 26.44913101], [88.96054077, 26.44837189], [88.95821381, 26.44959831], [88.95365906, 26.45186234], [88.95344543, 26.45196724], [88.95108795, 26.45211983], [88.95181274, 26.44849777], [88.94992065, 26.44812775], [88.94612885, 26.44803619], [88.94599915, 26.44498444], [88.94660187, 26.4448719], [88.94704437, 26.44478989], [88.9468689, 26.44413757], [88.94669342, 26.44349098], [88.94737244, 26.44342041], [88.94902039, 26.44324684], [88.9489975, 26.44207382], [88.94895935, 26.43999672], [88.94684601, 26.43942261], [88.94777679, 26.4389534], [88.9491272, 26.43826675], [88.95042419, 26.4358654], [88.9512558, 26.43510628], [88.95124054, 26.43486977], [88.95114136, 26.43371582], [88.95050049, 26.4335289], [88.94786072, 26.43317032], [88.9454422, 26.43281937], [88.94497681, 26.43166924], [88.94475555, 26.43111038], [88.94457245, 26.43065643], [88.94548798, 26.43044281], [88.94549561, 26.42969513], [88.94549561, 26.42910004], [88.94429779, 26.42916298], [88.9443512, 26.4284935], [88.94275665, 26.42828178], [88.94290161, 26.4273243], [88.94322968, 26.42702866], [88.9439621, 26.42636871], [88.94471741, 26.42568398], [88.9418335, 26.42539406], [88.93831635, 26.42570114], [88.93800354, 26.42572784], [88.93804169, 26.42734528], [88.93806458, 26.42821884], [88.93728638, 26.42918968], [88.93630981, 26.43039894], [88.93388367, 26.43167114], [88.92809296, 26.4330368], [88.9281311, 26.43206596], [88.92614746, 26.43216324], [88.92543793, 26.42912292], [88.92588806, 26.42772675], [88.92601013, 26.42767525], [88.92751312, 26.42700958], [88.93148041, 26.42743492], [88.93271637, 26.42756653], [88.93360901, 26.42662239], [88.93309784, 26.42622375], [88.932724, 26.42593575], [88.93171692, 26.42506409], [88.9319458, 26.42288971], [88.93369293, 26.42110825], [88.9363327, 26.41988945], [88.93701172, 26.41851997], [88.93662262, 26.41682053], [88.93525696, 26.41370964], [88.93373871, 26.41218948], [88.93094635, 26.41044998], [88.92854309, 26.41052818], [88.92749023, 26.40884399], [88.92697906, 26.40782356], [88.92650604, 26.40689278], [88.92424011, 26.40698624], [88.92363739, 26.4070797], [88.91970062, 26.40751076], [88.91815186, 26.40773773], [88.9156189, 26.40828896], [88.91461945, 26.40859413], [88.91382599, 26.408638], [88.91253662, 26.40870857], [88.9125824, 26.4081459], [88.91010284, 26.4076767], [88.90670776, 26.406744], [88.90473175, 26.40856552], [88.90393829, 26.40813446], [88.90543365, 26.40610123], [88.90563965, 26.40582848], [88.90557098, 26.40559387], [88.90518951, 26.40432358], [88.90611267, 26.40361786], [88.90621185, 26.40362549], [88.90866852, 26.40380669], [88.90872192, 26.4030304], [88.90882111, 26.40153503], [88.90971375, 26.40098572], [88.90989685, 26.40087128], [88.91155243, 26.40103722], [88.91251373, 26.40146446], [88.91290283, 26.40317154], [88.91576385, 26.40366364], [88.91719818, 26.40327072], [88.91746521, 26.40249252], [88.91757965, 26.40216064], [88.91802216, 26.40088463], [88.91809082, 26.40000534], [88.91817474, 26.39905357], [88.91830444, 26.39756775], [88.91876984, 26.39504433], [88.91868591, 26.39404297], [88.91859436, 26.39302635], [88.9185791, 26.3927803], [88.91840363, 26.39023018], [88.91830444, 26.39024162], [88.91727448, 26.3903389], [88.91638947, 26.3893013], [88.91683197, 26.38791275], [88.91613007, 26.38665962], [88.91622925, 26.38615417], [88.9164505, 26.38496017], [88.91629028, 26.38488388], [88.91416168, 26.38389397], [88.91207886, 26.38372612], [88.91208649, 26.38258934], [88.90969849, 26.3823185], [88.90943909, 26.38146019], [88.90904236, 26.38013649], [88.91229248, 26.38038445], [88.9136734, 26.37801743], [88.91481018, 26.37841034], [88.9153595, 26.378088], [88.91782379, 26.37833214], [88.92054749, 26.37864876], [88.92114258, 26.37763977], [88.92134094, 26.37730408], [88.92123413, 26.377285], [88.91963196, 26.37698555], [88.91952515, 26.37687111], [88.91968536, 26.37617302], [88.91983032, 26.37553024], [88.92002106, 26.3746891], [88.91777039, 26.37465096], [88.918396, 26.37319183], [88.91989136, 26.3699398], [88.92214203, 26.36865997], [88.92455292, 26.3686924], [88.92662811, 26.36828041], [88.92685699, 26.36663055], [88.92648315, 26.36540985], [88.92627716, 26.36474228], [88.92697906, 26.36450386], [88.92788696, 26.3642025], [88.92892456, 26.36385345], [88.92900848, 26.36358643], [88.9291687, 26.36365128], [88.92930603, 26.36385155], [88.93032074, 26.36534119], [88.93139648, 26.36621284], [88.93254089, 26.36713982], [88.93519592, 26.36762047], [88.93547821, 26.36688042], [88.93593597, 26.36568069], [88.93768311, 26.36293983], [88.94052124, 26.36165047], [88.94111633, 26.36137009], [88.94539642, 26.36018944], [88.94732666, 26.36005402], [88.94731903, 26.36070061], [88.94839478, 26.36083603], [88.94846344, 26.36139488], [88.94860077, 26.36245155], [88.94866943, 26.36301804], [88.9491806, 26.36465454], [88.95042419, 26.36632156], [88.95330048, 26.36606598], [88.95397186, 26.36392975], [88.9543457, 26.36287689], [88.95469666, 26.36190605], [88.9548111, 26.361866], [88.95481873, 26.36226082], [88.95568085, 26.36610985], [88.95677185, 26.36803055], [88.96086884, 26.36770058], [88.96250153, 26.36655045], [88.96362305, 26.36580276], [88.96450806, 26.36503029], [88.96549988, 26.36418915], [88.96460724, 26.36234474], [88.96450806, 26.36213112], [88.96432495, 26.36173439], [88.96414948, 26.36136055], [88.96286774, 26.36081696], [88.96258545, 26.36069679], [88.96226501, 26.36067009], [88.96194458, 26.36042213], [88.96156311, 26.36026192], [88.96126556, 26.3599987], [88.96120453, 26.35994148], [88.95887756, 26.35789108], [88.95620728, 26.35626984], [88.95549774, 26.35371971], [88.95448303, 26.35152054], [88.95362091, 26.34897041], [88.9540329, 26.34699059], [88.95625305, 26.34673119], [88.95884705, 26.34737968], [88.95985413, 26.3475647], [88.95920563, 26.34799004], [88.95911407, 26.34804916], [88.95928955, 26.34818077], [88.95955658, 26.34837914], [88.96044922, 26.3490448], [88.96066284, 26.34920692], [88.96056366, 26.35087204], [88.96052551, 26.35153198], [88.96134949, 26.35240364], [88.96305847, 26.35191727], [88.96318817, 26.35019112], [88.96486664, 26.34968185], [88.9645462, 26.34897232], [88.96590424, 26.34964752], [88.96668243, 26.35193443], [88.96778107, 26.35034943], [88.96839905, 26.3501873], [88.96996307, 26.34977722], [88.97121429, 26.3499794], [88.97144318, 26.35001755], [88.97148132, 26.35056496], [88.97155762, 26.35149574], [88.97264099, 26.35180283], [88.9732666, 26.3510704], [88.97494507, 26.35089111], [88.97550964, 26.34944153], [88.97657776, 26.34905624], [88.97801971, 26.34745598], [88.97737122, 26.34709549], [88.97966766, 26.34661102], [88.9803009, 26.34799004], [88.9825058, 26.34810829], [88.98252869, 26.34824371], [88.98268127, 26.34910965], [88.98445129, 26.34916496], [88.98529053, 26.34850121], [88.98461914, 26.34928513], [88.98415375, 26.349823], [88.98508453, 26.35004425], [88.98719788, 26.34805679], [88.98666382, 26.34823799], [88.98768616, 26.34721375], [88.98671722, 26.34726715], [88.9861145, 26.34729958], [88.98610687, 26.34657097], [88.98674011, 26.34654427], [88.98711395, 26.34252167], [88.98871613, 26.34126091], [88.9899826, 26.33857727], [88.98905182, 26.33840561], [88.98722839, 26.33808708], [88.98783112, 26.33867264], [88.98857117, 26.3393898], [88.9885788, 26.33946609], [88.98592377, 26.3399086], [88.98609161, 26.34030533], [88.98659515, 26.3414669], [88.98455048, 26.34082985], [88.98348236, 26.34166527], [88.98174286, 26.34110451], [88.98182678, 26.34078979], [88.98228455, 26.33911324], [88.98453522, 26.33657074], [88.98479462, 26.33403015], [88.98646545, 26.33249283], [88.98686218, 26.3321228], [88.9890976, 26.3324852], [88.9899826, 26.33437157], [88.99002838, 26.33548164], [88.99259949, 26.33491516], [88.99214172, 26.33404541], [88.99179077, 26.33338928], [88.99190521, 26.33333969], [88.99368286, 26.33252716], [88.99626923, 26.33196259], [88.99877167, 26.33189011], [88.99940491, 26.33015823], [89.00090027, 26.32985687], [89.00080109, 26.32948112], [89.00095367, 26.32948494], [89.00119781, 26.32952118], [89.00153351, 26.32959747], [89.00191498, 26.32972145], [89.0022583, 26.32986069], [89.00263977, 26.33000183], [89.00300598, 26.33020782], [89.00340271, 26.33046341], [89.0037384, 26.33070946], [89.00397491, 26.3309021], [89.0041275, 26.33106804], [89.00424957, 26.33136368], [89.0043335, 26.33169937], [89.00445557, 26.33202553], [89.00457764, 26.33220482], [89.00465393, 26.33230591], [89.00485229, 26.33237267], [89.00508118, 26.33245659], [89.00531006, 26.33250999], [89.00538635, 26.33261108], [89.00530243, 26.33282089], [89.00519562, 26.33315659], [89.00507355, 26.3334465], [89.00499725, 26.33358383], [89.00489044, 26.33372307], [89.00491333, 26.3338871], [89.00665283, 26.33279991], [89.00726318, 26.33131027], [89.00762939, 26.32863998], [89.0065918, 26.32661057], [89.00405121, 26.32471085], [89.00271606, 26.32448959], [89.00002289, 26.3247509], [88.99944305, 26.32310295], [89.00094604, 26.32152939], [89.00232697, 26.32009125], [89.00269318, 26.31972122], [89.00328827, 26.31817818], [89.00337219, 26.31796074], [89.00228882, 26.31660271], [89.00032806, 26.31661987], [88.997612, 26.31785011], [88.99642181, 26.3183918], [88.99585724, 26.31866074], [88.99397278, 26.32003403], [88.99425507, 26.317276], [88.99705505, 26.31653404], [88.99632263, 26.31545448], [88.99488068, 26.31334305], [88.99331665, 26.3150425], [88.99191284, 26.3151207], [88.9905014, 26.31240082], [88.99047089, 26.30864906], [88.99076843, 26.30723], [88.99114227, 26.30607986], [88.99188995, 26.30477905], [88.99352264, 26.30391121], [88.99610901, 26.30291939], [88.9988327, 26.30216026], [89.00154877, 26.30201912], [89.00331879, 26.30183029], [89.00348663, 26.30001068], [89.00321198, 26.29926109], [89.00213623, 26.29639053], [89.0021286, 26.29549026], [89.00232697, 26.29557419], [89.00340271, 26.2960186], [89.00358582, 26.29644585], [89.00450134, 26.2986145], [89.00415039, 26.30215836], [89.00418091, 26.30243683], [89.0043335, 26.30377388], [89.00578308, 26.30274773], [89.00587463, 26.3029213], [89.0065918, 26.30428696], [89.00666809, 26.30443382], [89.00754547, 26.30424309], [89.00763702, 26.30422211], [89.00805664, 26.30231476], [89.00812531, 26.30199051], [89.00839233, 26.30198288], [89.00948334, 26.30195808], [89.00995636, 26.30194664], [89.01021576, 26.30194092], [89.01036072, 26.30119896], [89.01040649, 26.30095673], [89.01051331, 26.29881096], [89.01078033, 26.29870415], [89.01299286, 26.29807472], [89.01282501, 26.29783249], [89.01236725, 26.29716873], [89.0120697, 26.29373169], [89.01235962, 26.29340553], [89.01423645, 26.29133606], [89.01490784, 26.29086113], [89.01683044, 26.28949356], [89.0169754, 26.28970909], [89.01850128, 26.29200363], [89.01869202, 26.29246712], [89.01890564, 26.29296875], [89.01920319, 26.29367256], [89.01985931, 26.29371834], [89.0200119, 26.29372787], [89.01992798, 26.29395294], [89.01965332, 26.29468155], [89.01956177, 26.29509354], [89.01818848, 26.29554176], [89.01720428, 26.29663277], [89.01718903, 26.29674339], [89.0169754, 26.29824829], [89.01589966, 26.29968834], [89.01470184, 26.29901886], [89.01452637, 26.29892349], [89.01443481, 26.29942894], [89.01433563, 26.29994583], [89.01426697, 26.30033684], [89.01545715, 26.30034637], [89.01557922, 26.30034828], [89.01608276, 26.30112839], [89.01631927, 26.30149651], [89.01555634, 26.3022213], [89.01638031, 26.30345726], [89.0164566, 26.30356979], [89.01674652, 26.30341721], [89.01725769, 26.30314827], [89.01740265, 26.30371666], [89.01766205, 26.30475235], [89.01977539, 26.30506897], [89.02005768, 26.30511093], [89.01893616, 26.30539322], [89.01878357, 26.30543327], [89.01867676, 26.30720901], [89.02020264, 26.30713463], [89.02035522, 26.307127], [89.02086639, 26.30850792], [89.02111053, 26.30917549], [89.02122498, 26.30886841], [89.02172089, 26.30752373], [89.02189636, 26.30766678], [89.02259827, 26.30825996], [89.0243454, 26.30774689], [89.02523041, 26.30708694], [89.02561951, 26.30870056], [89.02688599, 26.30965996], [89.0322876, 26.30784035], [89.03322601, 26.30624008], [89.03189087, 26.3037529], [89.03018188, 26.30167961], [89.02928162, 26.29947281], [89.02947235, 26.2976017], [89.02942657, 26.29527092], [89.02865601, 26.29335022], [89.02813721, 26.29222107], [89.02836609, 26.29033852], [89.03061676, 26.28918266], [89.03201294, 26.28865051], [89.03279877, 26.28693008], [89.03308105, 26.28623009], [89.03334808, 26.28556061], [89.03527069, 26.28544235], [89.03560638, 26.28541946], [89.03894806, 26.28640938], [89.04083252, 26.28610039], [89.04270172, 26.28504944], [89.04447174, 26.28498077], [89.04485321, 26.28533173], [89.0453186, 26.28675842], [89.04554749, 26.28746033], [89.04550171, 26.28867531], [89.04548645, 26.28925133], [89.04605865, 26.28911591], [89.04495239, 26.28964996], [89.04421997, 26.29000854], [89.04232025, 26.29009819], [89.04206085, 26.29010963], [89.04315186, 26.29115295], [89.04527283, 26.29112244], [89.04560089, 26.29323769], [89.04585266, 26.29491234], [89.04621124, 26.2954998], [89.04634857, 26.29573441], [89.04947662, 26.29614639], [89.05058289, 26.29555893], [89.05228424, 26.29614258], [89.05240631, 26.29548264], [89.05245209, 26.29522324], [89.05348206, 26.29657173], [89.05593872, 26.29718399], [89.05597687, 26.29705429], [89.05634308, 26.29678726], [89.05664825, 26.29650307], [89.05687714, 26.29632759], [89.05715179, 26.29612923], [89.05756378, 26.29584122], [89.05807495, 26.29546928], [89.05836487, 26.29522705], [89.05856323, 26.29505157], [89.05869293, 26.29487038], [89.05879974, 26.29470825], [89.05895233, 26.29447174], [89.05901337, 26.29428864], [89.05905914, 26.29403305], [89.05906677, 26.29380226], [89.05890656, 26.29351997], [89.05876923, 26.29332733], [89.05867004, 26.29317665], [89.05948639, 26.29138374], [89.06025696, 26.28969574], [89.05818939, 26.28728294], [89.05760956, 26.28627205], [89.05747223, 26.28603554], [89.05831146, 26.28508377], [89.06053925, 26.28340721], [89.0610199, 26.28304672], [89.06213379, 26.28167343], [89.06227112, 26.27921867], [89.06223297, 26.27897453], [89.06241608, 26.27891541], [89.06217957, 26.27864456], [89.06215668, 26.2784977], [89.06208801, 26.27807045], [89.06192017, 26.27802849], [89.06574249, 26.27621078], [89.06729889, 26.27403069], [89.06788635, 26.27073288], [89.06785583, 26.26691055], [89.06846619, 26.26266289], [89.06838226, 26.26027107], [89.06855774, 26.25880051], [89.06922913, 26.25657272], [89.06970215, 26.25533295], [89.06745148, 26.25530815], [89.06622314, 26.25626945], [89.063591, 26.25795174], [89.0610733, 26.25819969], [89.06025696, 26.25729752], [89.06012726, 26.25692368], [89.06287384, 26.255867], [89.06267548, 26.25510597], [89.06232452, 26.25373268], [89.05988312, 26.25465393], [89.05905151, 26.25408745], [89.05841064, 26.25491905], [89.05754089, 26.25349045], [89.0569458, 26.25251961], [89.05654144, 26.2497406], [89.05715942, 26.24690056], [89.05745697, 26.24502182], [89.05567932, 26.24366951], [89.054039, 26.24358177], [89.05182648, 26.24382973], [89.04984283, 26.24438095], [89.04973602, 26.2444706], [89.0496521, 26.24410057], [89.04945374, 26.2432251], [89.04964447, 26.24314499], [89.05101776, 26.24258232], [89.05062103, 26.24176979], [89.04895782, 26.24211121], [89.04769897, 26.24153137], [89.04598236, 26.24076462], [89.04222107, 26.24292183], [89.04006958, 26.24422836], [89.03729248, 26.24583244], [89.03707123, 26.24464989], [89.03666687, 26.24247551], [89.03656006, 26.2424984], [89.03407288, 26.24301147], [89.03377533, 26.24594498], [89.03285217, 26.24607658], [89.03296661, 26.24679565], [89.03015137, 26.24727249], [89.02764893, 26.24686813], [89.02742004, 26.24677467], [89.02739716, 26.2464447], [89.02726746, 26.24416161], [89.0270462, 26.24416542], [89.02444458, 26.24421501], [89.02442169, 26.24501038], [89.02140808, 26.24508476], [89.02063751, 26.24465179], [89.02042389, 26.2439785], [89.01997375, 26.24254417], [89.01913452, 26.24229431], [89.01896667, 26.24224472], [89.01820374, 26.24201965], [89.01818848, 26.24266434], [89.01815033, 26.24374771], [89.01646423, 26.24364281], [89.01583862, 26.24472046], [89.01293945, 26.24467468], [89.00921631, 26.24461174], [89.00257111, 26.24451065], [88.9987793, 26.244524], [88.99790955, 26.24471474], [88.99723053, 26.2448864], [88.99511719, 26.24529839], [88.99373627, 26.24556923], [88.99010468, 26.2454052], [88.98801422, 26.24519539], [88.98580933, 26.24497223], [88.98330688, 26.24488068], [88.98300171, 26.24488831], [88.98277283, 26.24485207], [88.98036957, 26.24490929], [88.97982025, 26.24464989], [88.97882843, 26.24411392], [88.97880554, 26.24378014], [88.97875214, 26.24308205], [88.97861481, 26.24278069], [88.97849274, 26.24278069], [88.9768219, 26.24278831], [88.97669983, 26.24245834], [88.97570038, 26.24250603], [88.97501373, 26.24220848], [88.97501373, 26.24196434], [88.97501373, 26.24171066], [88.97475433, 26.24167633], [88.97420502, 26.24160385], [88.97419739, 26.24185371], [88.97418976, 26.24195671], [88.97370911, 26.242033], [88.97364807, 26.2416172], [88.97361755, 26.24141312], [88.97329712, 26.24143028], [88.97299194, 26.24144554], [88.97280884, 26.24147606], [88.97275543, 26.24165535], [88.97248077, 26.24164391], [88.9719696, 26.24172592], [88.97193909, 26.24162102], [88.97173309, 26.24083328], [88.97163391, 26.24050903], [88.97163391, 26.2403183], [88.97158051, 26.24026299], [88.97140503, 26.24024582], [88.97131348, 26.24015427], [88.97088623, 26.24015427], [88.9706955, 26.23984528], [88.9703064, 26.23976135], [88.97028351, 26.23967934], [88.96982574, 26.23975182], [88.96973419, 26.23970032], [88.96945953, 26.24002457], [88.96952057, 26.24032021], [88.96913147, 26.24023247], [88.96867371, 26.23988914], [88.96831512, 26.2398262], [88.96831512, 26.23965263], [88.967453, 26.2393837], [88.9670105, 26.23930168], [88.96699524, 26.23915291], [88.96619415, 26.23899841], [88.96537781, 26.23884392], [88.96530914, 26.23878479], [88.96490479, 26.23893929], [88.96457672, 26.23906517], [88.96411896, 26.23915863], [88.96339417, 26.23917961], [88.96321106, 26.23918533], [88.96192169, 26.23963928], [88.95896912, 26.24021149], [88.95820618, 26.24035835], [88.95804596, 26.24039078], [88.95703125, 26.24058723], [88.95677948, 26.24065971], [88.95698547, 26.24267387], [88.95661163, 26.24266624], [88.9548645, 26.24263], [88.9546051, 26.24201775], [88.95360565, 26.24206352], [88.95308685, 26.24208832], [88.95304871, 26.24219322], [88.95237732, 26.24393082], [88.95227051, 26.24422264], [88.95246124, 26.24427414], [88.95278168, 26.2444191], [88.95157623, 26.24615288], [88.95133209, 26.24663162], [88.95066071, 26.24780464], [88.94986725, 26.24781609], [88.94982147, 26.24796677], [88.94960022, 26.24872208], [88.94918823, 26.24951744], [88.94902802, 26.24977684], [88.94844055, 26.2507267], [88.94830322, 26.25095749], [88.94792938, 26.25142479], [88.94773865, 26.25166512], [88.94721222, 26.25232506], [88.94731903, 26.25241089], [88.9471817, 26.25254822], [88.94690704, 26.25246429], [88.94604492, 26.25326347], [88.94592285, 26.25321579], [88.94439697, 26.25459862], [88.9442749, 26.25457573], [88.94394684, 26.25550079], [88.94374084, 26.25608063], [88.94359589, 26.25642586], [88.94355011, 26.25655174], [88.94337463, 26.25653267], [88.94334412, 26.25665665], [88.94350433, 26.25671577], [88.9430542, 26.25793648], [88.94295502, 26.25796318], [88.94247437, 26.25882912], [88.94231415, 26.25896645], [88.94224548, 26.25904846], [88.94195557, 26.25949287], [88.94190979, 26.25958633], [88.94203186, 26.25969124], [88.9410553, 26.26124191], [88.94065094, 26.26226997], [88.94054413, 26.26298141], [88.94018555, 26.26360893], [88.93998718, 26.26365852], [88.93950653, 26.26409531], [88.93832397, 26.2647171], [88.93811035, 26.26471329], [88.93725586, 26.26530457], [88.93647766, 26.26585197], [88.93627167, 26.26605797], [88.9360199, 26.26630592], [88.9356842, 26.26714134], [88.93553925, 26.2671299], [88.93511963, 26.2671032], [88.93505096, 26.26730919], [88.93482208, 26.26798248], [88.93421173, 26.26977921], [88.93421936, 26.27014923], [88.93412781, 26.27024078], [88.93399048, 26.27072144], [88.93405151, 26.27091789], [88.93341827, 26.27218437], [88.93288422, 26.27321053], [88.93258667, 26.27374649], [88.93245697, 26.27376366], [88.93156433, 26.27444267], [88.93131256, 26.27521896], [88.93139648, 26.27526855], [88.93140411, 26.27634239], [88.93138885, 26.27665138], [88.93127441, 26.27666664], [88.93108368, 26.27752876], [88.93041992, 26.27838326], [88.92977142, 26.27897644], [88.92858887, 26.28003883], [88.92749786, 26.28186417], [88.92622375, 26.28389359], [88.92469788, 26.28416634], [88.92453766, 26.28395844], [88.92449188, 26.28389359], [88.92406464, 26.28380394], [88.92379761, 26.28384781], [88.92366028, 26.28414154], [88.92243958, 26.28417206], [88.92227936, 26.28503418], [88.92048645, 26.28493309], [88.92037964, 26.28445435], [88.91983795, 26.28457832], [88.9197998, 26.28472519], [88.91937256, 26.28523254], [88.91960144, 26.28531456], [88.91939545, 26.28634453], [88.91831207, 26.28627777], [88.91809082, 26.28788948], [88.91807556, 26.28802872], [88.9178772, 26.28801918], [88.91721344, 26.28798485], [88.91692352, 26.28796959], [88.91678619, 26.28796196], [88.91519165, 26.28787994], [88.91386414, 26.28760529], [88.91343689, 26.28754234], [88.91333008, 26.28776932], [88.90982056, 26.2875309], [88.90918732, 26.28760529], [88.90843964, 26.28768921], [88.90842438, 26.28819466], [88.90791321, 26.28810501], [88.90687561, 26.28811264], [88.90641785, 26.28811646], [88.90381622, 26.28820229], [88.90089417, 26.28839493], [88.90052032, 26.28844261], [88.89820099, 26.28874397], [88.89691162, 26.2885437], [88.89586639, 26.28838348], [88.89344025, 26.28804398], [88.89099884, 26.28789139], [88.88993073, 26.28785133], [88.88835907, 26.2877903], [88.888237, 26.28778648], [88.88708496, 26.28760338], [88.88476563, 26.28735733], [88.88062286, 26.28700447], [88.87744141, 26.28673744], [88.87670135, 26.28669739], [88.87600708, 26.28632927], [88.8755722, 26.28580284], [88.87480164, 26.28491974], [88.87306976, 26.28243065], [88.87281036, 26.28107071], [88.87146759, 26.27966118], [88.86942291, 26.27865028], [88.86820984, 26.27746964], [88.86876678, 26.27565956], [88.86963654, 26.27030945], [88.86804962, 26.26749039], [88.86785889, 26.2653904], [88.86776733, 26.26090813], [88.86802673, 26.25785065], [88.87010193, 26.25460052], [88.87262726, 26.25316048], [88.87471771, 26.25132942], [88.87703705, 26.24875069], [88.8781662, 26.24777985], [88.87886047, 26.24600983], [88.87872314, 26.24356842], [88.87913513, 26.24353027], [88.87914276, 26.2432785], [88.87903595, 26.24310875], [88.87854767, 26.2422905], [88.87866974, 26.24227905], [88.87875366, 26.24224854], [88.87898254, 26.24204826], [88.87947845, 26.24199295], [88.8795166, 26.24163437], [88.8796463, 26.24146271], [88.87976074, 26.24133682], [88.87985992, 26.24127388], [88.87997437, 26.24118042], [88.88004303, 26.24110031], [88.88014221, 26.24100685], [88.88025665, 26.24091339], [88.88031769, 26.24085045], [88.88051605, 26.24080086], [88.88070679, 26.24089622], [88.88095856, 26.24091911], [88.88119507, 26.24095726], [88.88130188, 26.24088669], [88.88141632, 26.2407856], [88.8814621, 26.24067307], [88.88154602, 26.24059868], [88.88163757, 26.24040794], [88.88179016, 26.24027824], [88.88188171, 26.24024391], [88.88195801, 26.24019051], [88.88208008, 26.24010468], [88.88212585, 26.24003601], [88.88220978, 26.23991013], [88.88233185, 26.23975182], [88.88243103, 26.23962784], [88.88252258, 26.23944092], [88.88259125, 26.23928642], [88.88266754, 26.23908615], [88.88272858, 26.23886871], [88.88278961, 26.23860741], [88.88285065, 26.2384243], [88.88293457, 26.23822403], [88.88298035, 26.23799706], [88.88298035, 26.2378788], [88.88306427, 26.2378006], [88.88317108, 26.2377243], [88.88337708, 26.23767853], [88.88356018, 26.23768997], [88.8836441, 26.23770142], [88.88374329, 26.23772621], [88.88386536, 26.23767662], [88.88392639, 26.23762703], [88.88394165, 26.23752213], [88.88393402, 26.23737335], [88.88394165, 26.23725128], [88.88381958, 26.23708534], [88.88350677, 26.23665047], [88.88173676, 26.23655128], [88.87667847, 26.23644066], [88.87670135, 26.23625183], [88.87698364, 26.23555183], [88.87781525, 26.23349571], [88.8776474, 26.23348236], [88.87245941, 26.23311234], [88.87203217, 26.23363113], [88.87160492, 26.23414993], [88.86872864, 26.23350525], [88.86509705, 26.23242569], [88.86301422, 26.23257446], [88.86012268, 26.23239136], [88.86000061, 26.23223877], [88.85973358, 26.23154068], [88.85962677, 26.23155212], [88.85865784, 26.23166084], [88.85862732, 26.23225975], [88.85665131, 26.23383522], [88.85556793, 26.23399544], [88.85546875, 26.23402214], [88.85533142, 26.23405838], [88.85422516, 26.23515511], [88.85395813, 26.23516273], [88.85295105, 26.23518944], [88.85192871, 26.23521805], [88.85122681, 26.2343502], [88.84913635, 26.23373985], [88.84809875, 26.23397446], [88.84809113, 26.23388672], [88.8480835, 26.2335968], [88.84624481, 26.2333622], [88.84379578, 26.2325058], [88.84376526, 26.23224831], [88.84389496, 26.23067284], [88.84026337, 26.23140907], [88.83847046, 26.23219681], [88.83837128, 26.23442459], [88.83846283, 26.2367363], [88.83833313, 26.23723221], [88.83807373, 26.23823929], [88.83423615, 26.23775482], [88.83365631, 26.23837471], [88.83352661, 26.23851585], [88.83310699, 26.23846626], [88.83189392, 26.23832512], [88.83101654, 26.24015808], [88.83096313, 26.24027061], [88.83033752, 26.24017143], [88.82757568, 26.23972702], [88.82753754, 26.24001312], [88.82720947, 26.242239], [88.82711029, 26.24291039], [88.82688904, 26.24482536], [88.82707214, 26.24487495], [88.82859039, 26.24529457], [88.82857513, 26.24544907], [88.82847595, 26.24648857], [88.82881165, 26.24728394], [88.82909393, 26.24980545], [88.82775879, 26.25006676], [88.8276062, 26.24971199], [88.82741547, 26.24929428], [88.82731628, 26.24927711], [88.8234024, 26.24862671], [88.82361603, 26.2495079], [88.8234024, 26.25056267], [88.82331085, 26.25098038], [88.82347107, 26.25101089], [88.82411194, 26.25113297], [88.82396698, 26.25150108], [88.82360077, 26.25238991], [88.82314301, 26.25344658], [88.82151031, 26.25384712], [88.81951904, 26.25385094], [88.81903076, 26.2552948], [88.81489563, 26.25524902], [88.81475067, 26.25501442], [88.81464386, 26.25484467], [88.81430054, 26.25428391], [88.81391907, 26.25447845], [88.81365204, 26.25461006], [88.81352234, 26.25467491], [88.81282043, 26.25693512], [88.81288147, 26.25704956], [88.81372833, 26.25877762], [88.81355286, 26.25884819], [88.8131485, 26.25901413], [88.81313324, 26.26014328], [88.81309509, 26.26175499], [88.81299591, 26.26195335], [88.81295776, 26.26202011], [88.81210327, 26.26363945], [88.8121109, 26.26409912], [88.81212616, 26.2647171], [88.81217957, 26.26487541], [88.81464386, 26.26526451], [88.81478119, 26.26599503], [88.81503296, 26.26732254], [88.81494904, 26.26910973], [88.81409454, 26.2696476], [88.81417847, 26.27164841], [88.81410217, 26.27198029], [88.81380463, 26.27321625], [88.81373596, 26.27348518], [88.81229401, 26.27361679], [88.8102951, 26.2743454], [88.81034088, 26.27536392], [88.80996704, 26.27702141], [88.81034851, 26.27699852], [88.81093597, 26.27696228], [88.81112671, 26.27777672], [88.81169128, 26.28015137], [88.81206512, 26.28167915], [88.81230927, 26.28292656], [88.81246948, 26.28377533], [88.8125, 26.28396988], [88.81287384, 26.28634453], [88.81314087, 26.28807259], [88.81320953, 26.28852654], [88.81343842, 26.28875732], [88.81568909, 26.29102898], [88.8170166, 26.29242897], [88.81824493, 26.29372406], [88.81906891, 26.29459], [88.81510162, 26.29633331], [88.81310272, 26.29721451], [88.81219482, 26.2983799], [88.81059265, 26.29918289], [88.80947113, 26.30083275], [88.80802155, 26.30166054], [88.80715942, 26.30166435], [88.80437469, 26.30437088], [88.80175781, 26.30641556], [88.79890442, 26.30760002], [88.79597473, 26.30814171], [88.79347229, 26.31007385], [88.79064178, 26.30755997], [88.78746796, 26.30589676], [88.78708649, 26.30577278], [88.78688049, 26.30559349], [88.78487396, 26.30421829], [88.78180695, 26.30310059], [88.77937317, 26.30325317], [88.77754211, 26.3035965], [88.77619934, 26.30374908], [88.77591705, 26.30335617], [88.77505493, 26.30268288], [88.77416229, 26.30215836], [88.77329254, 26.30167007], [88.77302551, 26.3013401], [88.77180481, 26.30064011], [88.77172852, 26.30065346], [88.77072906, 26.30035973], [88.76993561, 26.3001461], [88.76966095, 26.30002022], [88.76820374, 26.29984093], [88.76654816, 26.29974937], [88.76570129, 26.29954338], [88.76515198, 26.29940987], [88.76478577, 26.29926872], [88.76403046, 26.29898071], [88.76381683, 26.29900932], [88.7634964, 26.29906273], [88.76346588, 26.29898453], [88.76259613, 26.29924965], [88.76178741, 26.29954147], [88.76069641, 26.29998589], [88.75970459, 26.30033493], [88.75968933, 26.30088997], [88.75946045, 26.30093956], [88.75941467, 26.30199051], [88.75954437, 26.30218315], [88.75961304, 26.30315971], [88.75952148, 26.30319786], [88.75925446, 26.30414391], [88.75923157, 26.30422401], [88.75894928, 26.30496979], [88.75868225, 26.30489922], [88.7583313, 26.3059597], [88.75702667, 26.30758286], [88.75655365, 26.30901718], [88.75656128, 26.31057549], [88.75349426, 26.31042862], [88.75314331, 26.31025696], [88.75222015, 26.3102417], [88.75158691, 26.31064987], [88.75039673, 26.31030846], [88.75024414, 26.31093216], [88.7497406, 26.31087303], [88.74953461, 26.31056213], [88.74784851, 26.31087303], [88.74766541, 26.31105042], [88.74662781, 26.31111145], [88.74550629, 26.30895042], [88.74530029, 26.30858231], [88.74536133, 26.30820656], [88.74494171, 26.30591202], [88.74456024, 26.30592155], [88.74430847, 26.30368042], [88.74412537, 26.30365181], [88.744133, 26.30306816], [88.74414063, 26.30291367], [88.7440567, 26.3026104], [88.74364471, 26.30111885], [88.74321747, 26.29932404], [88.74253082, 26.29934502], [88.74256897, 26.29884148], [88.74234772, 26.29850197], [88.74168396, 26.2974987], [88.74130249, 26.29767799], [88.74077606, 26.29568672], [88.74234772, 26.2953167], [88.74253845, 26.29446602], [88.74343109, 26.29444695], [88.74333954, 26.29387283], [88.74330902, 26.29368401], [88.74391937, 26.2936058], [88.74394226, 26.29369926], [88.74492645, 26.29361153], [88.74536896, 26.29357147], [88.74530792, 26.29297256], [88.74565125, 26.29286766], [88.74562836, 26.2926178], [88.74546051, 26.29110146], [88.74508667, 26.29104996], [88.74505615, 26.29074478], [88.74498749, 26.29072189], [88.74411774, 26.29077911], [88.74411011, 26.29107666], [88.74362946, 26.29112434], [88.74353027, 26.29113579], [88.74350739, 26.2915802], [88.74288177, 26.29158974], [88.74276733, 26.29112053], [88.74152374, 26.29137421], [88.73962402, 26.29147148], [88.73847198, 26.29136848], [88.73731995, 26.29156494], [88.73782349, 26.29250145], [88.73736572, 26.29274178], [88.73725891, 26.29350853], [88.7368927, 26.29356384], [88.73691559, 26.29371071], [88.73620605, 26.29375839], [88.73395538, 26.29444504], [88.73244476, 26.29444695], [88.73064423, 26.29475975], [88.73028564, 26.29471588], [88.72994995, 26.29470253], [88.72966003, 26.29469109], [88.72969055, 26.29354668], [88.7305069, 26.29129982], [88.72962189, 26.29121399], [88.72953796, 26.29084206], [88.72906494, 26.29084206], [88.72902679, 26.29030228], [88.72938538, 26.29018402], [88.72917175, 26.2894001], [88.72840118, 26.28951645], [88.72833252, 26.28934288], [88.72743988, 26.28953362], [88.72746277, 26.2896595], [88.727211, 26.2897625], [88.72725677, 26.28987885], [88.72647095, 26.29024315], [88.72710419, 26.29179001], [88.72756958, 26.29292488], [88.72659302, 26.29321671], [88.72645569, 26.29322243], [88.7246933, 26.29330444], [88.72315979, 26.29311562], [88.72309875, 26.29281807], [88.72219086, 26.2928009], [88.72142792, 26.29325867], [88.71987152, 26.29310989], [88.71974945, 26.29309845], [88.71992493, 26.29203033], [88.72013092, 26.29202843], [88.72029877, 26.29202843], [88.72029877, 26.29140091], [88.72029877, 26.29115295], [88.72045135, 26.29114342], [88.72083282, 26.29112053], [88.72100067, 26.28992271], [88.72105408, 26.28985405], [88.72168732, 26.28985214], [88.72163391, 26.28900719], [88.72133636, 26.2889843], [88.72126007, 26.28855133], [88.72102356, 26.28853226], [88.72105408, 26.28777885], [88.72129059, 26.28776932], [88.72210693, 26.28773689], [88.72213745, 26.28673172], [88.72369385, 26.28624725], [88.72283936, 26.28451157], [88.72194672, 26.28292656], [88.72033691, 26.28293991], [88.7191925, 26.28277397], [88.71820068, 26.2824707], [88.71647644, 26.28231621], [88.71385193, 26.28236961], [88.71364594, 26.2822094], [88.71446228, 26.28183937], [88.71446991, 26.28166199], [88.71219635, 26.28170013], [88.71006775, 26.28180313], [88.70906067, 26.28179932], [88.70722961, 26.28161049], [88.70506287, 26.28150558], [88.70503235, 26.28186035], [88.7045517, 26.28186417], [88.70452881, 26.28149223], [88.70250702, 26.28122902], [88.70250702, 26.28056145], [88.69579315, 26.27953911], [88.69609833, 26.27737427], [88.69178772, 26.27155685], [88.69194031, 26.27142334], [88.69199371, 26.27051735], [88.69223022, 26.27037811], [88.69232178, 26.2696228], [88.69252777, 26.26961899], [88.69242859, 26.26913071], [88.69203949, 26.26905632], [88.69181824, 26.26867485], [88.69008636, 26.26861191], [88.69003296, 26.26673317], [88.68795013, 26.26672554], [88.68804169, 26.26635361], [88.68739319, 26.26626968], [88.68683624, 26.26769829], [88.68596649, 26.26766205], [88.68598938, 26.26735115], [88.68563843, 26.26729393], [88.68579865, 26.2668705], [88.68540192, 26.26683044], [88.68560028, 26.2662735], [88.68504333, 26.26619339], [88.68511963, 26.26585197], [88.68458557, 26.26574707], [88.68625641, 26.26316833], [88.68370056, 26.26159668], [88.68352509, 26.26184845], [88.68296814, 26.26171303], [88.6831665, 26.26092339], [88.68198395, 26.2604599], [88.68083954, 26.25966263], [88.6794281, 26.25901031], [88.67907715, 26.25999451], [88.6785202, 26.26156235], [88.67823792, 26.26282883], [88.67805481, 26.2642498], [88.67790985, 26.26422882], [88.67782593, 26.26461792], [88.67678833, 26.26449013], [88.67674255, 26.26476669], [88.67540741, 26.26446915], [88.67570496, 26.26369095], [88.67465973, 26.26344681], [88.67352295, 26.26337242], [88.67198181, 26.2631321], [88.67197418, 26.26395226], [88.67007446, 26.26403618], [88.6701355, 26.26322937], [88.66888428, 26.26334381], [88.66734314, 26.26347351], [88.66742706, 26.26264381], [88.66674805, 26.26269722], [88.66620636, 26.26273918], [88.66615295, 26.26335716], [88.66629028, 26.2635231], [88.66645813, 26.26486206], [88.66685486, 26.26492119], [88.66688538, 26.2657795], [88.66729736, 26.26578331], [88.66728973, 26.26625443], [88.66745758, 26.26639366], [88.66744995, 26.26663017], [88.66817474, 26.26674271], [88.66837311, 26.26677513], [88.66838837, 26.26695824], [88.66843414, 26.2673912], [88.66880035, 26.26747704], [88.6688385, 26.26733017], [88.67180634, 26.2669735], [88.67179108, 26.26777077], [88.67177582, 26.26856804], [88.67214203, 26.26856613], [88.67215729, 26.27048492], [88.67204285, 26.27232933], [88.66950989, 26.27205276], [88.66760254, 26.27204323], [88.6675415, 26.27227592], [88.66743469, 26.27258873], [88.6672287, 26.27290535], [88.66701508, 26.27290916], [88.66680145, 26.27387047], [88.66767883, 26.2739296], [88.66763306, 26.27453423], [88.66733551, 26.2745266], [88.6673584, 26.27562523], [88.66700745, 26.27558899], [88.66703033, 26.27610397], [88.6674118, 26.27615166], [88.66727448, 26.27693558], [88.66725159, 26.27757454], [88.66735077, 26.27816582], [88.6681366, 26.27820778], [88.66811371, 26.27889824], [88.66854858, 26.27890396], [88.66857147, 26.27966881], [88.66903687, 26.27967072], [88.66944122, 26.27967262], [88.66954041, 26.28037453], [88.6696167, 26.28085899], [88.66829681, 26.28203201], [88.6668396, 26.2835598], [88.66566467, 26.2848587], [88.66568756, 26.28495598], [88.66643524, 26.28512001], [88.66637421, 26.28618622], [88.6661911, 26.28630447], [88.66620636, 26.28713417], [88.66643524, 26.28714371], [88.66644287, 26.28783798], [88.66617584, 26.28932381], [88.66727448, 26.28930664], [88.66860962, 26.28928757], [88.66860199, 26.28959274], [88.66963959, 26.28964996], [88.66900635, 26.29076004], [88.66822815, 26.29212952], [88.66893005, 26.29229736], [88.66873169, 26.29353142], [88.66841888, 26.29354668], [88.66821289, 26.29441643], [88.66921234, 26.29459572], [88.66798401, 26.29726601], [88.66877747, 26.29759216], [88.66972351, 26.29771805], [88.6706543, 26.29784203], [88.67062378, 26.29828835], [88.67391205, 26.29859543], [88.67472839, 26.29852676], [88.6747818, 26.29734993], [88.67649841, 26.29737473], [88.67654419, 26.29669762], [88.67747498, 26.29670525], [88.67749786, 26.2962513], [88.67865753, 26.29604912], [88.67869568, 26.29554939], [88.6789093, 26.29516029], [88.67945862, 26.29500008], [88.67948151, 26.29515076], [88.68067169, 26.29528046], [88.68086243, 26.29426003], [88.6803894, 26.29248619], [88.68106079, 26.29252243], [88.68424988, 26.29226112], [88.68434906, 26.29086685], [88.68487549, 26.2908783], [88.685112, 26.29028511], [88.68560028, 26.2903595], [88.68579102, 26.29039001], [88.68580627, 26.29000664], [88.6858139, 26.28956223], [88.68563843, 26.28857231], [88.68643951, 26.28852463], [88.68681335, 26.28841972], [88.68717957, 26.28831863], [88.68717194, 26.2881546], [88.68713379, 26.28775978], [88.68539429, 26.28746605], [88.68434143, 26.28742599], [88.68427277, 26.2880249], [88.68338013, 26.28794479], [88.68336487, 26.28733063], [88.68153381, 26.28716087], [88.68178558, 26.28530693], [88.68234253, 26.28535271], [88.68270111, 26.28353119], [88.68424225, 26.28367996], [88.68399048, 26.28275681], [88.68518066, 26.28293228], [88.6852417, 26.28246307], [88.68572998, 26.28252411], [88.68619537, 26.28211975], [88.68704987, 26.28214836], [88.68803406, 26.28217888], [88.68782806, 26.28370476], [88.68778992, 26.28518867], [88.69034576, 26.2857151], [88.69036102, 26.28488159], [88.69107819, 26.28489685], [88.69116211, 26.28437042], [88.6904068, 26.28424454], [88.69043732, 26.28371239], [88.69109344, 26.28377151], [88.69298553, 26.28393936], [88.69312286, 26.28285217], [88.69542694, 26.28277779], [88.69530487, 26.28407288], [88.69600677, 26.2844162], [88.69683075, 26.28491974], [88.69889069, 26.28554726], [88.69931793, 26.28534889], [88.69944763, 26.28427124], [88.70139313, 26.28437233], [88.70145416, 26.2844429], [88.7013092, 26.28582573], [88.70431519, 26.28580475], [88.7046051, 26.28580284], [88.70452881, 26.28625679], [88.70446777, 26.28662491], [88.70536804, 26.28818893], [88.70552063, 26.28846169], [88.7062149, 26.28862762], [88.70700073, 26.28861427], [88.70700073, 26.28851509], [88.70772552, 26.28853798], [88.70775604, 26.28873825], [88.70832825, 26.28878212], [88.70832062, 26.28886223], [88.70903778, 26.28890991], [88.70938873, 26.28886604], [88.70920563, 26.2890377], [88.70846558, 26.28906631], [88.70803833, 26.2892189], [88.70687103, 26.28911972], [88.70578003, 26.28909302], [88.70648193, 26.29148865], [88.70352173, 26.29144859], [88.70352936, 26.29182243], [88.70277405, 26.29179955], [88.70263672, 26.29257584], [88.69978333, 26.29237175], [88.69980621, 26.2914238], [88.70266724, 26.29176521], [88.70272827, 26.29104614], [88.70262909, 26.2910347], [88.70178223, 26.29093742], [88.70143127, 26.29089737], [88.70144653, 26.29064941], [88.70149994, 26.28988647], [88.70038605, 26.2898407], [88.70041656, 26.28948212], [88.69813538, 26.28933907], [88.69799805, 26.29017067], [88.69483948, 26.29026985], [88.69482422, 26.29090309], [88.69232941, 26.2906208], [88.69217682, 26.29060364], [88.69207001, 26.29124832], [88.6942749, 26.29141045], [88.69481659, 26.2914505], [88.69481659, 26.29219627], [88.6950531, 26.29265022], [88.69413757, 26.29266739], [88.69398499, 26.29342461], [88.69314575, 26.29339981], [88.6931076, 26.29361725], [88.69345856, 26.29367828], [88.69325256, 26.29554749], [88.69261932, 26.29546356], [88.69272614, 26.29479218], [88.69246674, 26.29475403], [88.6910553, 26.29454613], [88.68968201, 26.29434204], [88.68967438, 26.2948513], [88.68858337, 26.29486656], [88.68861389, 26.29448318], [88.68738556, 26.2945385], [88.68739319, 26.29487991], [88.68596649, 26.29483032], [88.68583679, 26.29542732], [88.68474579, 26.29520226], [88.68457031, 26.29576492], [88.68508911, 26.29597473], [88.6841507, 26.29769135], [88.68338776, 26.29751396], [88.68319702, 26.29853821], [88.68244171, 26.29850578], [88.68278503, 26.29916573], [88.68353271, 26.29982948], [88.68460083, 26.30150986], [88.68313599, 26.3017025], [88.68314362, 26.30203056], [88.68190002, 26.30206108], [88.68187714, 26.30252838], [88.68160248, 26.30253601], [88.68149567, 26.30203056], [88.68012238, 26.30153465], [88.67980957, 26.30289459], [88.67823792, 26.30437279], [88.67792511, 26.30706406], [88.67844391, 26.30719376], [88.6787262, 26.30792999], [88.6806488, 26.30813217], [88.68302155, 26.30856133], [88.68301392, 26.31028366], [88.68250275, 26.31260872], [88.68097687, 26.31241035], [88.6811142, 26.31165123], [88.68077087, 26.31162643], [88.68066406, 26.31203461], [88.68049622, 26.31203079], [88.6800766, 26.31348801], [88.67928314, 26.31341553], [88.67904663, 26.31476784], [88.67790222, 26.31464577], [88.67795563, 26.31384087], [88.67840576, 26.31383324], [88.6784668, 26.3134346], [88.67740631, 26.31337929], [88.67735291, 26.31309509], [88.67694092, 26.31306648], [88.6770401, 26.31176376], [88.67637634, 26.31175804], [88.67639923, 26.3115139], [88.67523956, 26.31144905], [88.67506409, 26.31294441], [88.67594147, 26.31303024], [88.67591095, 26.31348801], [88.67468262, 26.31339645], [88.67454529, 26.31435013], [88.67580414, 26.31446075], [88.67557526, 26.31641769], [88.67614746, 26.31651497], [88.67604065, 26.31754494], [88.67514801, 26.31750298], [88.67501068, 26.31811333], [88.67550659, 26.3182106], [88.67507172, 26.32017136], [88.67822266, 26.320261], [88.67810822, 26.32150841], [88.67934418, 26.3215313], [88.67926788, 26.32224846], [88.68193054, 26.32237434], [88.68592834, 26.32285309], [88.68819427, 26.32296944], [88.6897049, 26.32312584], [88.68956757, 26.32348824], [88.68976593, 26.323843], [88.69024658, 26.3242321], [88.69048309, 26.3254509], [88.69078064, 26.32599258], [88.6909256, 26.32789612], [88.69094849, 26.32897568], [88.69197083, 26.32899094], [88.69229126, 26.32872391], [88.69346619, 26.3286705], [88.69568634, 26.32882118], [88.69578552, 26.32775879], [88.69644165, 26.32783508], [88.69646454, 26.32704735], [88.69620514, 26.32701683], [88.6962204, 26.32654572], [88.69659424, 26.32655907], [88.69674683, 26.32585144], [88.69405365, 26.32579231], [88.69223022, 26.32569504], [88.69139862, 26.32444572], [88.690979, 26.32418251], [88.68984985, 26.32344055], [88.69020844, 26.32280159], [88.69186401, 26.32256508], [88.6917572, 26.32219505], [88.69236755, 26.3216877], [88.69223022, 26.32098961], [88.69211578, 26.3201313], [88.69139862, 26.3198185], [88.69160461, 26.31953049], [88.69150543, 26.31939697], [88.69104767, 26.31939507], [88.69087982, 26.31850624], [88.69185638, 26.31755447], [88.69186401, 26.31710815], [88.69252014, 26.31708527], [88.69258118, 26.31575012], [88.69290924, 26.31572342], [88.69320679, 26.3140831], [88.6944809, 26.31409073], [88.69513702, 26.31452179], [88.69639587, 26.31442642], [88.69697571, 26.31365013], [88.69615936, 26.3126297], [88.69718933, 26.31221771], [88.6978302, 26.31264305], [88.69882202, 26.31286812], [88.6991806, 26.3137188], [88.69885254, 26.31446457], [88.70022583, 26.31484604], [88.70349884, 26.31484604], [88.70629883, 26.31477547], [88.7062149, 26.31570435], [88.70816803, 26.31539726], [88.70806122, 26.31637764], [88.70990753, 26.3169632], [88.71227264, 26.31734657], [88.71498108, 26.31805611], [88.7172699, 26.31716728], [88.71904755, 26.3157692], [88.71842194, 26.31231689], [88.71918488, 26.31225014], [88.7208252, 26.31438828], [88.72223663, 26.31487465], [88.72439575, 26.31475449], [88.7259903, 26.3156414], [88.72626495, 26.31762123], [88.72865295, 26.3181572], [88.7311554, 26.31847572], [88.73153687, 26.31930351], [88.73114014, 26.32202911], [88.73066711, 26.32193184], [88.73058319, 26.32374954], [88.73259735, 26.32375717], [88.73525238, 26.3235836], [88.73848724, 26.32369041], [88.73914337, 26.32380486], [88.74004364, 26.32273865], [88.74307251, 26.32264519], [88.74645233, 26.32247543], [88.74684143, 26.32495689], [88.74747467, 26.32698059], [88.74793243, 26.32879448], [88.74842834, 26.33060646], [88.74868011, 26.33202362], [88.74571228, 26.33253288], [88.74422455, 26.33184814], [88.74310303, 26.33179855], [88.74265289, 26.33077812], [88.73993683, 26.32945824], [88.73749542, 26.32919693], [88.73727417, 26.32878113], [88.73382568, 26.32858467], [88.73427582, 26.3308773], [88.73504639, 26.33180428], [88.73594666, 26.33406258], [88.73732758, 26.33513832], [88.73862457, 26.33513641], [88.74088287, 26.33669281], [88.74272919, 26.33679008], [88.74398804, 26.33857918], [88.74427795, 26.34091759], [88.74298859, 26.34196663], [88.74254608, 26.34419823], [88.74423981, 26.34470177], [88.74443817, 26.34346581], [88.74515533, 26.34467316], [88.74559021, 26.3447094], [88.74581909, 26.34717369], [88.74524689, 26.3479557], [88.74391937, 26.34883118], [88.73960876, 26.34882927], [88.73881531, 26.34938431], [88.73629761, 26.34955215], [88.73596191, 26.35209656], [88.73724365, 26.35194397], [88.73753357, 26.35338783], [88.73425293, 26.35379601], [88.73416138, 26.35367012], [88.73413849, 26.35330009], [88.73410797, 26.35276031], [88.73504639, 26.35036087], [88.73479462, 26.35016251], [88.73516083, 26.3501091], [88.73550415, 26.34917068], [88.73581696, 26.34918404], [88.73586273, 26.34808159], [88.73286438, 26.34812164], [88.73210144, 26.34812355], [88.72937775, 26.34625244], [88.72927094, 26.34472084], [88.72684479, 26.34466934], [88.72631073, 26.34423065], [88.72608185, 26.34136772], [88.72425842, 26.34122849], [88.72429657, 26.34210587], [88.72377777, 26.34302902], [88.72205353, 26.3433094], [88.72200012, 26.34293747], [88.72129059, 26.34294319], [88.71883392, 26.34294128], [88.71883392, 26.34343529], [88.71757507, 26.34354591], [88.71752167, 26.34388542], [88.71569061, 26.34389496], [88.71401215, 26.34381866], [88.7135849, 26.34379959], [88.71278381, 26.34372902], [88.71273804, 26.34259033], [88.71238708, 26.33817863], [88.71235657, 26.3378315], [88.71227264, 26.33784103], [88.71173859, 26.33628082], [88.71050262, 26.33389091], [88.70855713, 26.33279991], [88.70672607, 26.33279991], [88.70652008, 26.33293343], [88.70601654, 26.33282471], [88.70490265, 26.33262825], [88.70463562, 26.33258057], [88.70449066, 26.33278084], [88.70431519, 26.33301735], [88.70401764, 26.33333206], [88.70375061, 26.33420944], [88.70324707, 26.33434296], [88.70316315, 26.33428192], [88.70291901, 26.33430099], [88.70271301, 26.33449364], [88.70265198, 26.33470917], [88.70258331, 26.33479309], [88.70246887, 26.33488083], [88.70226288, 26.33543968], [88.70218658, 26.33545685], [88.70214081, 26.33620071], [88.70201874, 26.33620262], [88.70200348, 26.33644295], [88.70223999, 26.33648682], [88.70235443, 26.33647537], [88.70288086, 26.33642197], [88.70291138, 26.33688354], [88.70317078, 26.33688545], [88.70317078, 26.33723831], [88.70317841, 26.3377552], [88.70303345, 26.33776474], [88.70275879, 26.33778572], [88.70274353, 26.33808327], [88.7027359, 26.33825111], [88.70250702, 26.33823776], [88.70161438, 26.33818817], [88.70159149, 26.33888817], [88.70209503, 26.3389225], [88.70307159, 26.33898735], [88.70303345, 26.33946991], [88.70301819, 26.33970261], [88.70314789, 26.33971405], [88.70317078, 26.33991623], [88.70357513, 26.33992958], [88.70376587, 26.3399353], [88.70376587, 26.3409996], [88.70237732, 26.34218979], [88.7022934, 26.34219933], [88.70226288, 26.34188461], [88.7002182, 26.34177399], [88.70012665, 26.34172821], [88.69960785, 26.34172058], [88.69952393, 26.34127808], [88.69894409, 26.34125519], [88.6985321, 26.34123802], [88.69843292, 26.34202194], [88.69815826, 26.34202194], [88.69807434, 26.34236717], [88.6980896, 26.34272003], [88.69816589, 26.34300995], [88.69809723, 26.34326744], [88.69805908, 26.3434391], [88.69761658, 26.34370613], [88.69754028, 26.34375191], [88.6973877, 26.34368324], [88.69667816, 26.34369469], [88.69664001, 26.34399223], [88.69657135, 26.34434128], [88.69613647, 26.34429741], [88.69561005, 26.34423447], [88.69506073, 26.344244], [88.69499207, 26.34449387], [88.69487762, 26.34473801], [88.69493866, 26.34515953], [88.69495392, 26.34528542], [88.69503021, 26.34548187], [88.6950531, 26.34571266], [88.69452667, 26.34577942], [88.69441223, 26.34579468], [88.69443512, 26.34604454], [88.69435883, 26.34625816], [88.69422913, 26.34628296], [88.69420624, 26.34667778], [88.69415283, 26.34684372], [88.69404602, 26.34686661], [88.69404602, 26.34695244], [88.69467926, 26.34700966], [88.69513702, 26.34701538], [88.69536591, 26.34705544], [88.69548035, 26.34704781], [88.69593048, 26.34701729], [88.69667816, 26.34701347], [88.69660187, 26.34719849], [88.69661713, 26.34807777], [88.69711304, 26.34807205], [88.69715118, 26.34882545], [88.69719696, 26.34889984], [88.69742584, 26.34890938], [88.69741821, 26.34922409], [88.69737244, 26.34949684], [88.69736481, 26.34961891], [88.69762421, 26.34963608], [88.69779205, 26.34964752], [88.69773865, 26.34986305], [88.69771576, 26.34995461], [88.69761658, 26.35072708], [88.69758606, 26.35104179], [88.69760895, 26.35157013], [88.69792175, 26.35161209], [88.69779205, 26.35257339], [88.69784546, 26.35264587], [88.69788361, 26.35366249], [88.6979599, 26.35368156], [88.69792175, 26.35430145], [88.69788361, 26.35507774], [88.69785309, 26.35538483], [88.69776154, 26.35567093], [88.69795227, 26.35570717], [88.69801331, 26.35593033], [88.69847107, 26.35591125], [88.69844818, 26.35604668], [88.69838715, 26.35644913], [88.69661713, 26.35711479], [88.69577789, 26.3572216], [88.69507599, 26.35731125], [88.69387817, 26.35656548], [88.69378662, 26.35650635], [88.69254303, 26.35778999], [88.69244385, 26.35798454], [88.69145203, 26.36004639], [88.69178009, 26.36014748], [88.69364929, 26.3607254], [88.69403076, 26.36092186], [88.69456482, 26.3611927], [88.69613647, 26.36198997], [88.69623566, 26.36203957], [88.69592285, 26.36242676], [88.69491577, 26.36366081], [88.694664, 26.36366653], [88.69438934, 26.36367035], [88.69074249, 26.36373138], [88.68914795, 26.36375999], [88.6885376, 26.3667984], [88.68831635, 26.36789894], [88.68797302, 26.37024307], [88.68787384, 26.370224], [88.68769073, 26.37084961], [88.68764496, 26.37142944], [88.68760681, 26.37162018], [88.68749237, 26.37162399], [88.68733215, 26.37221336], [88.68721008, 26.37220764], [88.6869812, 26.37306023], [88.68675232, 26.37387466], [88.68621826, 26.37378693], [88.68573761, 26.37370682], [88.68530273, 26.37476921], [88.68527985, 26.37563324], [88.68552399, 26.37569237], [88.68601227, 26.37581062], [88.68604279, 26.37667847], [88.68667603, 26.37689972], [88.6865921, 26.37848663], [88.68609619, 26.37866974], [88.68476105, 26.3785553], [88.68403625, 26.37841797], [88.68126678, 26.37799644], [88.68122864, 26.37831306], [88.68108368, 26.3797226], [88.68103027, 26.38022041], [88.68187714, 26.38040352], [88.68278503, 26.38185883], [88.68286133, 26.38238907], [88.68331909, 26.38241196], [88.68527985, 26.38317108], [88.6890564, 26.38339424], [88.68912506, 26.38342094], [88.690979, 26.38409996], [88.69504547, 26.38523293], [88.69721985, 26.3854332], [88.69881439, 26.38557816], [88.69940948, 26.38562775], [88.69954681, 26.38563919], [88.69976044, 26.38565636], [88.70081329, 26.38574409], [88.70137024, 26.3861599], [88.70220184, 26.38762474], [88.70224762, 26.38855362], [88.70175171, 26.38879013], [88.69960785, 26.38981438], [88.69815063, 26.38928032], [88.69644928, 26.38866997], [88.69439697, 26.38801956], [88.69408417, 26.38792038], [88.69408417, 26.38766479], [88.69300842, 26.38753128], [88.69242859, 26.3874073], [88.69142914, 26.38733673], [88.69110107, 26.38729668], [88.69017029, 26.38720322], [88.68737793, 26.38692665], [88.68730164, 26.38917732], [88.68746948, 26.39018631], [88.68748474, 26.39028358], [88.68771362, 26.39165306], [88.68652344, 26.39069557], [88.68593597, 26.39022064], [88.68587494, 26.39060593], [88.68573761, 26.39151573], [88.6860199, 26.39167023], [88.68760681, 26.39253235], [88.68773651, 26.39320374], [88.68801117, 26.39463234], [88.68802643, 26.39470863], [88.68813324, 26.39472771], [88.68941498, 26.39494514], [88.68938446, 26.39519882], [88.68901825, 26.39553261], [88.68561554, 26.39525414], [88.68476868, 26.39455223], [88.6836319, 26.39361], [88.68060303, 26.3942337], [88.68044281, 26.39421272], [88.68014526, 26.39417458], [88.67933655, 26.39391327], [88.67812347, 26.39352608], [88.67810822, 26.39406013], [88.67701721, 26.39451981], [88.67638397, 26.39485741], [88.67417145, 26.39541245], [88.67343903, 26.39606094], [88.67193604, 26.39754868], [88.67029572, 26.39779282], [88.67074585, 26.39877892], [88.67163086, 26.39860725], [88.67233276, 26.39847183], [88.67198181, 26.39893913], [88.67279816, 26.39940071], [88.67487335, 26.3999691], [88.67596436, 26.40073967], [88.6757431, 26.40113831], [88.67710114, 26.40153885], [88.67932892, 26.40275955], [88.68205261, 26.40261269], [88.68328857, 26.40261269], [88.6838913, 26.4025898], [88.68461609, 26.40256119], [88.68582153, 26.40175819], [88.68599701, 26.40164948], [88.68733978, 26.40133476], [88.68726349, 26.40237999], [88.68729401, 26.40274239], [88.68692017, 26.40273285], [88.68689728, 26.4032135], [88.6867981, 26.40323448], [88.68635559, 26.40332794], [88.68645477, 26.40395927], [88.68648529, 26.40411186], [88.68628693, 26.4041481], [88.68616486, 26.4041729], [88.68617249, 26.40425491], [88.68621063, 26.40454102], [88.6858139, 26.40460968], [88.6857605, 26.40484428], [88.68559265, 26.40553474], [88.68592072, 26.40557289], [88.68676758, 26.40566826], [88.68668365, 26.4061203], [88.68612671, 26.40605927], [88.68571472, 26.4060154], [88.68573761, 26.40585136], [88.6852951, 26.40583611], [88.68421936, 26.40577698], [88.68424225, 26.40600204], [88.68431091, 26.40675545], [88.68362427, 26.40681458], [88.6835022, 26.40759087], [88.68379211, 26.40773582], [88.68380737, 26.40811348], [88.68450165, 26.40806007], [88.68451691, 26.40770531], [88.68524933, 26.40775681], [88.68561554, 26.40838814], [88.6855011, 26.40861702], [88.68560028, 26.40914536], [88.68496704, 26.40919304], [88.68492889, 26.40870094], [88.68393707, 26.40878677], [88.68405914, 26.40908623], [88.68419647, 26.40967941], [88.68440247, 26.41049385], [88.68486786, 26.41065407], [88.68501282, 26.41083336], [88.685112, 26.41108704], [88.68579865, 26.41099739], [88.68584442, 26.4112606], [88.68499756, 26.41155052], [88.68465424, 26.41152763], [88.6834259, 26.41156197], [88.68331146, 26.41254044], [88.68302155, 26.41271019], [88.68157959, 26.41247749], [88.68151855, 26.41088104], [88.68138123, 26.41070938], [88.68141937, 26.41043663], [88.68132782, 26.41033936], [88.68144989, 26.40923119], [88.68154144, 26.40846634], [88.68167114, 26.40843201], [88.68170166, 26.40803528], [88.68069458, 26.40800285], [88.68065643, 26.40854836], [88.67987061, 26.40855789], [88.67987061, 26.40872383], [88.67947388, 26.40869331], [88.67945099, 26.40886307], [88.67819214, 26.40858841], [88.67787933, 26.40781784], [88.67630768, 26.4077301], [88.67475891, 26.4077816], [88.67474365, 26.40801811], [88.6740799, 26.40791512], [88.67408752, 26.40769005], [88.67284393, 26.40770149], [88.67236328, 26.40771866], [88.67191315, 26.40767288], [88.67127991, 26.40760803], [88.67004395, 26.40761375], [88.67003632, 26.40740967], [88.66773987, 26.40730667], [88.66766357, 26.40784264], [88.66763306, 26.40804291], [88.66772461, 26.40900993], [88.66764069, 26.40903664], [88.66764832, 26.40930557], [88.66766357, 26.40964317], [88.66733551, 26.4096756], [88.6671524, 26.4097023], [88.66639709, 26.40981293], [88.66628265, 26.40978622], [88.66548157, 26.40959167], [88.66454315, 26.40984344], [88.66383362, 26.40896606], [88.66382599, 26.40971947], [88.66321564, 26.40994644], [88.66322327, 26.40979767], [88.6627655, 26.40995789], [88.66299438, 26.41068077], [88.66301727, 26.41075134], [88.66291046, 26.41077423], [88.66227722, 26.41091537], [88.66194916, 26.41167068], [88.66171265, 26.41178131], [88.66165924, 26.41259003], [88.66192627, 26.4125843], [88.66205597, 26.4125824], [88.66204071, 26.41354942], [88.66220856, 26.41357231], [88.66220856, 26.41399765], [88.66107941, 26.4140873], [88.66105652, 26.41470337], [88.6608429, 26.4147625], [88.66082764, 26.41558456], [88.66052246, 26.41565895], [88.66046906, 26.41605377], [88.66039276, 26.41640854], [88.65981293, 26.41656494], [88.65923309, 26.41658592], [88.65918732, 26.41639709], [88.65706635, 26.4164772], [88.6570282, 26.41662025], [88.65632629, 26.41665649], [88.65541077, 26.4164505], [88.65515137, 26.41628647], [88.65492249, 26.4161396], [88.65442657, 26.41607094], [88.65435028, 26.4160347], [88.65433502, 26.4157238], [88.65364838, 26.41571045], [88.65275574, 26.41569328], [88.65137482, 26.41566467], [88.65048981, 26.41562271], [88.65044403, 26.41629601], [88.65044403, 26.41663551], [88.65032196, 26.41751289], [88.64848328, 26.41754341], [88.64855194, 26.4171257], [88.64804077, 26.41710281], [88.64802551, 26.41699409], [88.64677429, 26.41704178], [88.64714813, 26.41743279], [88.64727783, 26.41757011], [88.64714813, 26.4176693], [88.6470108, 26.41762924], [88.64681244, 26.41775322], [88.64685059, 26.4179039], [88.64673615, 26.41801262], [88.6467514, 26.41820717], [88.64645386, 26.41839027], [88.64652252, 26.41867065], [88.64633179, 26.41849327], [88.64620972, 26.41838264], [88.64611816, 26.41840553], [88.64440155, 26.41883278], [88.64444733, 26.41924858], [88.64497375, 26.41994286], [88.6462326, 26.42009735], [88.64689636, 26.42009735], [88.64785004, 26.42017365], [88.64906311, 26.42027092], [88.64971924, 26.42077255], [88.65057373, 26.42142868], [88.65100861, 26.42176437], [88.65130615, 26.42457008], [88.65110016, 26.42521286], [88.65091705, 26.42580986], [88.65058136, 26.42674065], [88.65028381, 26.42754745], [88.64975739, 26.4296875], [88.64962769, 26.42965698], [88.64661407, 26.42898178], [88.64649963, 26.42901802], [88.64284515, 26.43008995], [88.64218903, 26.43001556], [88.64110565, 26.42989159], [88.64034271, 26.42980385], [88.63983917, 26.42974663], [88.63831329, 26.42957306], [88.638237, 26.42956352], [88.63814545, 26.42959023], [88.63805389, 26.42961693], [88.63598633, 26.43026543], [88.63512421, 26.43206406], [88.63478851, 26.43202019], [88.63365936, 26.43187714], [88.63200378, 26.43166542], [88.63105774, 26.43154335], [88.63093567, 26.43152618], [88.63076782, 26.43156242], [88.63063812, 26.43281937], [88.63043213, 26.43473625], [88.62945557, 26.43470573], [88.6280899, 26.43466568], [88.62789917, 26.43371391], [88.62787628, 26.43357849], [88.62768555, 26.43377304], [88.62752533, 26.43381691], [88.62587738, 26.43435097], [88.625, 26.43506622], [88.62372589, 26.43486214], [88.62371063, 26.43494415], [88.62316895, 26.43841743], [88.62471771, 26.44024277], [88.62484741, 26.44039345], [88.62491608, 26.44048119], [88.62600708, 26.44026375], [88.62650299, 26.44016457], [88.62663269, 26.44013786], [88.62824249, 26.44112587], [88.62782288, 26.44376373], [88.62746429, 26.44602013], [88.62708282, 26.44879341], [88.62703705, 26.44913483], [88.62678528, 26.45093536], [88.62648773, 26.45093155], [88.6255722, 26.4509201], [88.625, 26.4550972], [88.62469482, 26.45748138], [88.62454987, 26.45853424], [88.62364197, 26.46495819], [88.62319183, 26.46846771], [88.62201691, 26.46998978], [88.62069702, 26.47106934], [88.61843109, 26.47071838], [88.61434174, 26.47047043], [88.61155701, 26.47025108], [88.60791779, 26.47087288], [88.60608673, 26.4710331], [88.60561371, 26.47102356], [88.60502625, 26.47094154], [88.6043396, 26.47099495], [88.603508, 26.47113037], [88.60347748, 26.4707222], [88.60346222, 26.4705143], [88.60344696, 26.47033501], [88.60269928, 26.47024536], [88.60125732, 26.47045708], [88.60069275, 26.47101974], [88.60058594, 26.47105598], [88.60032654, 26.47129059], [88.5999527, 26.47127151], [88.59577179, 26.47106743], [88.59473419, 26.47093582], [88.5942688, 26.47009087], [88.59432983, 26.46939659], [88.59508514, 26.46932411], [88.59584808, 26.46927643], [88.5954361, 26.46656418], [88.59520721, 26.46286964], [88.59505463, 26.46021271], [88.595047, 26.46011162], [88.59555817, 26.4589119], [88.596138, 26.45594978], [88.596138, 26.45503044], [88.596138, 26.45321083], [88.59690094, 26.45001984], [88.59702301, 26.44939041], [88.59513855, 26.44921112], [88.59291077, 26.44917107], [88.59254456, 26.44874191], [88.59030914, 26.44890976], [88.59030914, 26.44926643], [88.58883667, 26.44948006], [88.58672333, 26.45094681], [88.58428192, 26.45038986], [88.58430481, 26.45077705], [88.5844574, 26.45326042], [88.58435059, 26.45339966], [88.58374023, 26.45420074], [88.58027649, 26.45527077], [88.57637024, 26.45625114], [88.57441711, 26.45673943], [88.57202148, 26.4568615], [88.57098389, 26.45680809], [88.5682373, 26.45716667], [88.56297302, 26.45763969], [88.56182861, 26.45675087], [88.56018829, 26.45706749], [88.55995941, 26.45711136], [88.55841064, 26.45811462], [88.55783081, 26.45895767], [88.55804443, 26.45960999], [88.55986786, 26.45940208], [88.56191254, 26.45880127], [88.56284332, 26.45916176], [88.5631485, 26.45989609], [88.56272125, 26.46046257], [88.55986786, 26.46123505], [88.55961609, 26.46174622], [88.55944061, 26.46209908], [88.55930328, 26.46421051], [88.55934143, 26.4643116], [88.5594101, 26.4643631], [88.56092072, 26.46771622], [88.55888367, 26.46669197], [88.55776215, 26.46672058], [88.55758667, 26.46746826], [88.55802155, 26.4679184], [88.55832672, 26.46823502], [88.557724, 26.46982384], [88.55768585, 26.47003365], [88.55805206, 26.47101212], [88.5586853, 26.47176552], [88.56011963, 26.47256088], [88.55966949, 26.47252274], [88.55787659, 26.47236443], [88.55626678, 26.47180748], [88.55545807, 26.47182465], [88.55430603, 26.47184944], [88.5539856, 26.47185516], [88.55389404, 26.47211456], [88.5537796, 26.47245026], [88.55640411, 26.47316933], [88.55675507, 26.47459221], [88.55682373, 26.47488213], [88.55638123, 26.47512817], [88.5557785, 26.47545815], [88.55383301, 26.47474098], [88.55328369, 26.4745388], [88.55231476, 26.47555733], [88.55226898, 26.47716522], [88.55257416, 26.47733307], [88.55345154, 26.47781944], [88.55471039, 26.47851563], [88.55493164, 26.48058128], [88.55501556, 26.48137474], [88.55651855, 26.48344612], [88.55645752, 26.48487282], [88.5561676, 26.48486328], [88.55496216, 26.48482513], [88.5525589, 26.48456764], [88.55175781, 26.48421288], [88.54936981, 26.48329926], [88.54483795, 26.48265076], [88.54189301, 26.4822998], [88.53981018, 26.48200989], [88.53929901, 26.48190117], [88.53659821, 26.48130989], [88.53295135, 26.4810791], [88.53050232, 26.48089027], [88.52848053, 26.4810009], [88.52738953, 26.48144341], [88.52645111, 26.48148918], [88.52667236, 26.48205757], [88.52671814, 26.4831028], [88.52658081, 26.48442078], [88.52513123, 26.48478317], [88.52415466, 26.4848671], [88.52514648, 26.48520851], [88.52793121, 26.486166], [88.52732849, 26.48624039], [88.52519226, 26.48650551], [88.52282715, 26.48679924], [88.52294159, 26.48696899], [88.52455139, 26.48938942], [88.52467346, 26.49167061], [88.52420807, 26.49238205], [88.52385712, 26.49291992], [88.52340698, 26.49361992], [88.52307892, 26.49412346], [88.52298737, 26.49426079], [88.52259827, 26.49520493], [88.52174377, 26.49726868], [88.52135468, 26.49820709], [88.51862335, 26.50132942], [88.52143097, 26.50357628], [88.52281952, 26.50629807], [88.52202606, 26.50805855], [88.52191925, 26.50847054], [88.51996613, 26.50862122], [88.51876831, 26.50835037], [88.51682281, 26.50799942], [88.51531219, 26.50798988], [88.51405334, 26.50815964], [88.51322174, 26.50906944], [88.5125885, 26.51021004], [88.51246643, 26.51054955], [88.51216125, 26.51154327], [88.51003265, 26.51272011], [88.50983429, 26.51307487], [88.509758, 26.5132122], [88.50932312, 26.51361084], [88.50779724, 26.51449966], [88.50102997, 26.51333046], [88.50073242, 26.51320839], [88.49996185, 26.5125103], [88.49906921, 26.51222229], [88.49754333, 26.51173019], [88.49692535, 26.51213455], [88.49511719, 26.51180077], [88.49285126, 26.51192665], [88.49240875, 26.51195145], [88.49228668, 26.51180077], [88.49151611, 26.510849], [88.49104309, 26.51074219], [88.48981476, 26.51046562], [88.48970032, 26.51044083], [88.48973083, 26.51053238], [88.49029541, 26.51230431], [88.49022675, 26.51244926], [88.48938751, 26.51424217], [88.48914337, 26.51665497], [88.48914337, 26.51761627], [88.489151, 26.51931953], [88.48914337, 26.52223396], [88.48838806, 26.52464867], [88.48786926, 26.52589798], [88.48757935, 26.52660561], [88.4879837, 26.52735329], [88.48860168, 26.52852058], [88.4886322, 26.53062248], [88.48729706, 26.53098869], [88.48720551, 26.53097916], [88.48484802, 26.53073692], [88.48298645, 26.53054619], [88.4825058, 26.53112793], [88.48239136, 26.53284454], [88.48236084, 26.53304291], [88.48215485, 26.53437614], [88.48217773, 26.53504753], [88.48223114, 26.53664207], [88.48431396, 26.5398922], [88.48352814, 26.54106903], [88.48047638, 26.54109383], [88.4781189, 26.54200554], [88.47786713, 26.54259872], [88.47754669, 26.54333878], [88.477005, 26.54351234], [88.47399139, 26.54446983], [88.47390747, 26.54447365], [88.4693985, 26.54417038], [88.46817017, 26.54422951], [88.46746063, 26.54418945], [88.46627808, 26.54416084], [88.46604919, 26.5443325], [88.46482849, 26.54439163], [88.46459961, 26.54440308], [88.46302795, 26.54399872], [88.46252441, 26.54387283], [88.46164703, 26.54691124], [88.46155548, 26.54721642], [88.45915222, 26.54722595], [88.45883179, 26.54722786], [88.45735931, 26.54494286], [88.45800018, 26.54325294], [88.45806885, 26.54272079], [88.45814514, 26.54212379], [88.45825195, 26.54129601], [88.45833588, 26.54068184], [88.45838165, 26.54032707], [88.45689392, 26.53975868], [88.45661163, 26.53965187], [88.45691681, 26.53845978], [88.45723724, 26.53721046], [88.45691681, 26.53692055], [88.45658112, 26.53660965], [88.4564209, 26.53647041], [88.45454407, 26.53634834], [88.45379639, 26.53609276], [88.4525528, 26.53593445], [88.44816589, 26.5353775], [88.44628143, 26.53692818], [88.44386292, 26.53891945], [88.44329834, 26.53938484], [88.44303894, 26.54374313], [88.44302368, 26.54407692], [88.44194794, 26.54408836], [88.43725586, 26.54414177], [88.43569946, 26.54549217], [88.43426514, 26.54673958], [88.43393707, 26.54702377], [88.43123627, 26.55015755], [88.42929077, 26.55442047], [88.42919922, 26.55463982], [88.42745972, 26.55861282], [88.42690277, 26.55985832], [88.42577362, 26.56236458], [88.42442322, 26.56524086], [88.42342377, 26.56576157], [88.42271423, 26.56612778], [88.42266083, 26.56630707], [88.42137909, 26.57028198], [88.42111969, 26.57109451], [88.42141724, 26.57114601], [88.42166138, 26.57403946], [88.42169952, 26.57444382], [88.42235565, 26.57834625], [88.42242432, 26.58028412], [88.42243195, 26.58055115], [88.42253113, 26.58286285], [88.42169952, 26.58532143], [88.42126465, 26.58651352], [88.420784, 26.58784485], [88.42068481, 26.58811378], [88.42025757, 26.58928871], [88.41944122, 26.59184074], [88.41938019, 26.59204483], [88.41988373, 26.59657669], [88.4197998, 26.5991993], [88.41902924, 26.60309029], [88.41780853, 26.60788536], [88.41690826, 26.61218834], [88.41678619, 26.61363602], [88.41677094, 26.61459923], [88.41689301, 26.61490631], [88.41692352, 26.61530685], [88.41728973, 26.61740875], [88.41733551, 26.617836], [88.41739655, 26.61836624], [88.41766357, 26.61972237], [88.41796875, 26.6215744], [88.41798401, 26.6216507], [88.41455078, 26.6225071], [88.41524506, 26.62454033], [88.41550446, 26.62557411], [88.41613007, 26.62809181], [88.41603088, 26.63170242], [88.41564178, 26.63177681], [88.41516876, 26.63186646], [88.41478729, 26.63193703], [88.41512299, 26.63326263], [88.41422272, 26.63343811], [88.41396332, 26.6334877], [88.41385651, 26.63350868], [88.41200256, 26.63407326], [88.41131592, 26.63381004], [88.41044617, 26.63313103], [88.4095993, 26.63257027], [88.40907288, 26.63376617], [88.407547, 26.63150978], [88.40446472, 26.62985802], [88.40113068, 26.62812996], [88.40078735, 26.62795448], [88.39842224, 26.62598801], [88.39836121, 26.62593651], [88.39820862, 26.62548256], [88.39785767, 26.62444305], [88.39686584, 26.62152672], [88.39626312, 26.61998367], [88.3943634, 26.61824608], [88.39050293, 26.61629105], [88.38765717, 26.61204338], [88.38792419, 26.61119461], [88.38852692, 26.6092701], [88.38859558, 26.60890579], [88.39022827, 26.60768509], [88.39048767, 26.60756493], [88.39271545, 26.60654449], [88.39328003, 26.60653687], [88.39555359, 26.60712624], [88.39601898, 26.60706711], [88.39782715, 26.60633087], [88.39827728, 26.60617828], [88.39842224, 26.60435295], [88.39846802, 26.60372543], [88.39469147, 26.60281372], [88.39420319, 26.60261917], [88.39413452, 26.60264397], [88.39079285, 26.60124588], [88.388237, 26.60025978], [88.38650513, 26.5997715], [88.38507843, 26.59936905], [88.38479614, 26.59928894], [88.38453674, 26.59921455], [88.38316345, 26.59882736], [88.38239288, 26.59860992], [88.38169861, 26.59852028], [88.37963104, 26.59825134], [88.37732697, 26.5965786], [88.37591553, 26.59426689], [88.37586975, 26.59247208], [88.37506866, 26.5875206], [88.37467957, 26.58687592], [88.373909, 26.58558083], [88.37387085, 26.58551598], [88.37458038, 26.58405876], [88.37466431, 26.58389091], [88.37464142, 26.5827446], [88.37464142, 26.58226967], [88.37456512, 26.58175659], [88.37434387, 26.5808754], [88.37421417, 26.58030891], [88.37413025, 26.57994652], [88.3739624, 26.57918739], [88.3738327, 26.57862091], [88.37275696, 26.57747269], [88.37106323, 26.57609177], [88.3706665, 26.57542992], [88.37018585, 26.57460976], [88.37018585, 26.57372856], [88.37034607, 26.5732708], [88.3705368, 26.57271957], [88.37068939, 26.57215309], [88.3707962, 26.57193375], [88.37083435, 26.57174492], [88.37096405, 26.57107353], [88.37108612, 26.57065964], [88.37126923, 26.56998825], [88.37143707, 26.56950951], [88.37156677, 26.56764793], [88.37158203, 26.5668354], [88.37136841, 26.56506157], [88.37123871, 26.56329918], [88.37120819, 26.56192589], [88.37083435, 26.56066513], [88.37041473, 26.55965424], [88.36978912, 26.55952072], [88.36927032, 26.55921745], [88.36833191, 26.55867004], [88.36722565, 26.55786133], [88.36698914, 26.55769157], [88.36681366, 26.55736923], [88.36650085, 26.55679512], [88.3664093, 26.55672836], [88.36586761, 26.55633926], [88.36531067, 26.55540848], [88.3651886, 26.55421448], [88.365242, 26.55323029], [88.36530304, 26.55293846], [88.36540222, 26.55249023], [88.36527252, 26.55212212], [88.36461639, 26.55158234], [88.36392212, 26.55103683], [88.36325073, 26.55049133], [88.36268616, 26.54980278], [88.36186981, 26.54894066], [88.36138916, 26.54800034], [88.36131287, 26.54781914], [88.36061859, 26.54553032], [88.35912323, 26.5422802], [88.35830688, 26.5401001], [88.35786438, 26.53802681], [88.35811615, 26.53731155], [88.35823059, 26.53673172], [88.3584137, 26.53613853], [88.35908508, 26.5355587], [88.35916138, 26.53549004], [88.35913086, 26.5353775], [88.35884094, 26.53434753], [88.359375, 26.53380966], [88.35961151, 26.53357506], [88.35939026, 26.53347969], [88.35926056, 26.53342247], [88.35919952, 26.53279114], [88.35916138, 26.53237915], [88.35926056, 26.53209305], [88.35930634, 26.53142357], [88.35931396, 26.53129768], [88.359375, 26.53028679], [88.35907745, 26.52964783], [88.35852051, 26.52903748], [88.35798645, 26.52848053], [88.35747528, 26.52792549], [88.35679626, 26.52752304], [88.355896, 26.52727699], [88.35544586, 26.52708435], [88.35402679, 26.5261097], [88.35368347, 26.52586174], [88.35257721, 26.52457047], [88.35185242, 26.52327347], [88.35166931, 26.52242851], [88.35161591, 26.52176666], [88.35158539, 26.52144623], [88.35162354, 26.5209446], [88.35173035, 26.52021217], [88.35187531, 26.51943398], [88.35207367, 26.51852608], [88.3522644, 26.51810455], [88.35264587, 26.51721001], [88.35269928, 26.51708412], [88.35283661, 26.51672935], [88.35302734, 26.51603699], [88.35269165, 26.51538277], [88.35261536, 26.51517677], [88.35276794, 26.51412964], [88.35257721, 26.51202011], [88.35089874, 26.50989914], [88.34970856, 26.50869942], [88.34879303, 26.50792885], [88.34873199, 26.50758743], [88.34844208, 26.50763512], [88.34770966, 26.50775337], [88.3474884, 26.50735283], [88.34715271, 26.50687027], [88.34690094, 26.50650597], [88.34632874, 26.50599289], [88.34593201, 26.50534248], [88.34472656, 26.50437737], [88.34464264, 26.50418472], [88.34436798, 26.50413513], [88.34345245, 26.50335503], [88.34249115, 26.50280571], [88.34187317, 26.5021019], [88.34037018, 26.50066948], [88.33885956, 26.49940109], [88.33760834, 26.4976902], [88.33715057, 26.49714088], [88.33489227, 26.49660683], [88.33464813, 26.49628067], [88.33415222, 26.4956646], [88.33379364, 26.49544334], [88.33351898, 26.4951725], [88.33290863, 26.49448776], [88.33237457, 26.49365807], [88.33206177, 26.4932003], [88.33184814, 26.49215317], [88.33177948, 26.49177933], [88.33165741, 26.49120522], [88.33152771, 26.48886299], [88.3314743, 26.4865284], [88.3311615, 26.48463249], [88.3313446, 26.48459244], [88.33201599, 26.48444557], [88.33346558, 26.4827404], [88.33439636, 26.48164368], [88.33435822, 26.4814949], [88.33402252, 26.48008537], [88.33371735, 26.47880745], [88.33383179, 26.47874641], [88.33457947, 26.47834969], [88.33501434, 26.47811508], [88.33562469, 26.47798347], [88.33728027, 26.47877502], [88.33760071, 26.47876358], [88.33932495, 26.47870827], [88.34068298, 26.47843742], [88.34068298, 26.47769547], [88.3411026, 26.47780037], [88.34211731, 26.47644043], [88.34200287, 26.47369957], [88.34163666, 26.47106934], [88.34202576, 26.46913338], [88.34479523, 26.46884346], [88.34625244, 26.46870041], [88.34648132, 26.46861458], [88.34703064, 26.46840477], [88.34700775, 26.46763229], [88.34646606, 26.46604347], [88.34666443, 26.46602631], [88.3482132, 26.46589279], [88.34815216, 26.46554947], [88.34777832, 26.46327209], [88.3478241, 26.46291924], [88.34820557, 26.46022606], [88.34825897, 26.46001244], [88.34954071, 26.4594593], [88.34970856, 26.45922279], [88.34977722, 26.45898628], [88.34989929, 26.45871353], [88.34979248, 26.45837402], [88.34973907, 26.45817947], [88.34973907, 26.45757675], [88.3500824, 26.45746613], [88.35028076, 26.45716858], [88.35037231, 26.45703125], [88.35036469, 26.4569416], [88.35023499, 26.45594597], [88.35045624, 26.45582771], [88.35097504, 26.45426559], [88.35160828, 26.45350075], [88.35178375, 26.4532814], [88.35201263, 26.45298195], [88.35224152, 26.4525032], [88.35279846, 26.45210266], [88.35322571, 26.45144081], [88.35334778, 26.44987488], [88.3529129, 26.44904137], [88.35243225, 26.44872665], [88.35221863, 26.44857788], [88.3520813, 26.44814873], [88.35270691, 26.44786453], [88.35334778, 26.44757652], [88.35387421, 26.44736099], [88.35477448, 26.44714165], [88.35488892, 26.44711304], [88.35523224, 26.44722557], [88.35551453, 26.44732094], [88.35578156, 26.44763184], [88.35549164, 26.44824028], [88.35539246, 26.44873047], [88.35533142, 26.45006752], [88.35622406, 26.45116997], [88.35646057, 26.45185661], [88.35662842, 26.45202637], [88.35691071, 26.45243454], [88.35720062, 26.45238686], [88.3575058, 26.45289612], [88.35787201, 26.45332336], [88.35897827, 26.45357323], [88.35980988, 26.45372772], [88.36030579, 26.45391273], [88.36062622, 26.45410156], [88.3611908, 26.45469475], [88.36148834, 26.45516777], [88.36149597, 26.45533752], [88.36144257, 26.45566368], [88.36134338, 26.45581245], [88.36101532, 26.45605278], [88.36086273, 26.45616531], [88.36053467, 26.45633698], [88.36044312, 26.45638847], [88.35978699, 26.45646858], [88.3589859, 26.45680428], [88.35894012, 26.4575634], [88.35925293, 26.4579792], [88.35946655, 26.45841408], [88.35984802, 26.45926476], [88.36001587, 26.45950699], [88.36019135, 26.4597683], [88.36036682, 26.46025658], [88.36097717, 26.46146393], [88.36071777, 26.46166229], [88.36039734, 26.46191978], [88.36008453, 26.4623909], [88.36001587, 26.46251869], [88.36004639, 26.4628849], [88.36036682, 26.46342087], [88.360466, 26.46359062], [88.36058807, 26.46414185], [88.36039734, 26.46423912], [88.36035156, 26.46440125], [88.36063385, 26.46534538], [88.36107635, 26.46605301], [88.36143494, 26.46631432], [88.36206818, 26.46678162], [88.36277008, 26.46720123], [88.36319733, 26.46730042], [88.36344147, 26.46735764], [88.3637619, 26.46774292], [88.36400604, 26.46833801], [88.36404419, 26.46843529], [88.36436462, 26.46926117], [88.36451721, 26.46982765], [88.36472321, 26.46998215], [88.36510468, 26.47027206], [88.36603546, 26.47085381], [88.36531067, 26.4715023], [88.36560822, 26.47186852], [88.36559296, 26.47236061], [88.36473083, 26.47284698], [88.36413574, 26.47299576], [88.36395264, 26.47301292], [88.36380768, 26.47302628], [88.36339569, 26.47289658], [88.36255646, 26.47300339], [88.36222839, 26.47350121], [88.36201477, 26.47409821], [88.36190033, 26.47432327], [88.36214447, 26.4745121], [88.36252594, 26.47481728], [88.36264801, 26.47524834], [88.36235046, 26.47543526], [88.36210632, 26.47559547], [88.36241913, 26.47634697], [88.36233521, 26.47682381], [88.36231995, 26.47691727], [88.36229706, 26.47720337], [88.36225891, 26.4773922], [88.36242676, 26.47760963], [88.36251068, 26.47766113], [88.3625946, 26.47771454], [88.36268616, 26.47789383], [88.36248779, 26.47799873], [88.36220551, 26.47815514], [88.36199188, 26.47835732], [88.36197662, 26.47855377], [88.36207581, 26.47917747], [88.36183167, 26.47941017], [88.36170959, 26.47968102], [88.36181641, 26.48003006], [88.36188507, 26.48011398], [88.36204529, 26.48031998], [88.36182404, 26.4806366], [88.3613205, 26.48081589], [88.36122131, 26.48079872], [88.36103821, 26.48077202], [88.36054993, 26.48067093], [88.36048126, 26.48074913], [88.36048126, 26.48095512], [88.3602066, 26.48171616], [88.3602829, 26.48196983], [88.36049652, 26.48264503], [88.36027527, 26.48280716], [88.36006927, 26.48282051], [88.35999298, 26.48291779], [88.36026001, 26.48309708], [88.36022949, 26.48355675], [88.3605957, 26.48382378], [88.36077118, 26.48402977], [88.36075592, 26.48416519], [88.36052704, 26.48430634], [88.36048889, 26.48458672], [88.36053467, 26.4847393], [88.36066437, 26.48484993], [88.36139679, 26.48497772], [88.3618927, 26.48506355], [88.36226654, 26.48531151], [88.36260986, 26.48547363], [88.36269379, 26.48604774], [88.36273193, 26.48630905], [88.36289215, 26.48638725], [88.36325836, 26.48636246], [88.36341095, 26.48644257], [88.36331177, 26.48700905], [88.36709595, 26.4876194], [88.37113953, 26.48826408], [88.37234497, 26.48840714], [88.37265015, 26.48838234], [88.37374878, 26.48846817], [88.37440491, 26.48851776], [88.3744278, 26.48786354], [88.37445831, 26.48716927], [88.37446594, 26.48692322], [88.37494659, 26.48627853], [88.37508392, 26.48591805], [88.37529755, 26.48533821], [88.37537384, 26.48500252], [88.3755722, 26.48407936], [88.37615204, 26.48414803], [88.3772583, 26.48427963], [88.37755585, 26.48431396], [88.37918854, 26.48365974], [88.38137054, 26.48371887], [88.38259125, 26.48320389], [88.38455963, 26.48319244], [88.38596344, 26.48274612], [88.38619995, 26.48293304], [88.3866806, 26.48174477], [88.38728333, 26.48148918], [88.38841248, 26.48035049], [88.3899765, 26.4793911], [88.39086914, 26.47919464], [88.39109802, 26.47924805], [88.39186859, 26.47970581], [88.39349365, 26.48066521], [88.39557648, 26.48134995], [88.39781189, 26.48206139], [88.40080261, 26.483078], [88.40123749, 26.48322678], [88.40146637, 26.48413086], [88.40233612, 26.48543739], [88.40398407, 26.48606491], [88.40415192, 26.48612785], [88.40491486, 26.48589325], [88.40552521, 26.48514748], [88.40539551, 26.48475647], [88.40627289, 26.48408127], [88.40659332, 26.48203087], [88.40747833, 26.48055077], [88.40811157, 26.47971535], [88.40860748, 26.47956848], [88.40859985, 26.47908211], [88.40886688, 26.47872925], [88.40988159, 26.4770546], [88.41040802, 26.47699165], [88.41027069, 26.47634506], [88.41014099, 26.47504044], [88.41072083, 26.47484016], [88.41210938, 26.47435951], [88.41249084, 26.47422791], [88.41251373, 26.47380066], [88.41366577, 26.47195816], [88.41394806, 26.47171211], [88.41445923, 26.47146988], [88.4145813, 26.47115326], [88.41651917, 26.46945], [88.41665649, 26.46934891], [88.41863251, 26.46940041], [88.41860962, 26.46901512], [88.41854095, 26.4679718], [88.41890717, 26.46770287], [88.41969299, 26.46708107], [88.42074585, 26.46622849], [88.42105865, 26.46600151], [88.42243958, 26.46608925], [88.42193604, 26.4669857], [88.4216156, 26.46756363], [88.42133331, 26.46865654], [88.42167664, 26.46892357], [88.42238617, 26.46949005], [88.42292786, 26.4699192], [88.42276764, 26.47278023], [88.42559814, 26.47294426], [88.42838287, 26.47302246], [88.42901611, 26.47192383], [88.42916107, 26.47177505], [88.42995453, 26.47094536], [88.43029785, 26.47071075], [88.43062592, 26.4706955], [88.4313736, 26.47159576], [88.43183136, 26.47172928], [88.43331146, 26.47216034], [88.43373108, 26.47228241], [88.43379211, 26.47178841], [88.43390656, 26.47082138], [88.43408203, 26.47084808], [88.43538666, 26.47022057], [88.4361496, 26.46903038], [88.43659973, 26.46686172], [88.4372406, 26.46606445], [88.43785095, 26.46599388], [88.44106293, 26.46572685], [88.44338989, 26.46614456], [88.44607544, 26.46676254], [88.45055389, 26.46673203], [88.45491028, 26.46678352], [88.45814514, 26.46673203], [88.4624939, 26.46618652], [88.46598053, 26.46496964], [88.46923828, 26.46432686], [88.47224426, 26.46326065], [88.47712708, 26.46208572], [88.47843933, 26.4616642], [88.47955322, 26.46130562], [88.48091888, 26.46086502], [88.48413849, 26.46052742], [88.48470306, 26.46046829], [88.48519897, 26.46035004], [88.48484039, 26.45936012], [88.4848175, 26.45920753], [88.48465729, 26.45828629], [88.48423767, 26.45669174], [88.48355103, 26.45604515], [88.48236084, 26.45568466], [88.48126984, 26.4554882], [88.48074341, 26.45539284], [88.48035431, 26.4552536], [88.48006439, 26.45516396], [88.47951508, 26.45458984], [88.47937012, 26.45379066], [88.47950745, 26.45253944], [88.48113251, 26.45209122], [88.48277283, 26.4508419], [88.48355865, 26.45058441], [88.48368073, 26.45054626], [88.48536682, 26.45074081], [88.48644257, 26.45066643], [88.48656464, 26.45025253], [88.48656464, 26.45011711], [88.48686981, 26.45005989], [88.48799896, 26.44971848], [88.48781586, 26.44761086], [88.48764038, 26.44538116], [88.48776245, 26.44472313], [88.48820496, 26.44447136], [88.48969269, 26.44431686], [88.49077606, 26.44408226], [88.49108887, 26.44348145], [88.4913559, 26.44346046], [88.49254608, 26.44305992], [88.49267578, 26.44209099], [88.49199677, 26.44031906], [88.49234772, 26.43950844], [88.49280548, 26.4391613], [88.49422455, 26.43831635], [88.49564362, 26.4374752], [88.49616241, 26.43719482], [88.49620819, 26.4369812], [88.49678802, 26.43675041], [88.49755096, 26.43567085], [88.49812317, 26.43435097], [88.4980011, 26.43276978], [88.49655914, 26.43116951], [88.49227905, 26.43050957], [88.49140167, 26.42999077], [88.49147034, 26.42902946], [88.49234772, 26.42855835], [88.49347687, 26.42852211], [88.49507904, 26.42835999], [88.49571228, 26.4281044], [88.49609375, 26.42794228], [88.49673462, 26.42755127], [88.49728394, 26.42686272], [88.49753571, 26.42655945], [88.49760437, 26.42649841], [88.49839783, 26.42580032], [88.49833679, 26.42472267], [88.49816895, 26.42446136], [88.49816895, 26.42427635], [88.49800873, 26.42420959], [88.49771118, 26.42375183], [88.496521, 26.42230988], [88.49508667, 26.42053986], [88.49420166, 26.41922951], [88.49411011, 26.41869545], [88.49478912, 26.41805458], [88.49606323, 26.41711998], [88.49697876, 26.41716003], [88.49820709, 26.41740608], [88.49958038, 26.41763115], [88.50222015, 26.41810799], [88.50265503, 26.41758919], [88.50251007, 26.41728973], [88.50237274, 26.41700172], [88.50184631, 26.41616249], [88.50074768, 26.41482162], [88.49953461, 26.41356468], [88.49876404, 26.41303825], [88.49793243, 26.41218758], [88.49690247, 26.41190529], [88.49610138, 26.4115963], [88.49533081, 26.41039467], [88.49559784, 26.40953255], [88.49650574, 26.40873146], [88.4973526, 26.40857887], [88.49784851, 26.40863228], [88.49977112, 26.40821457], [88.50032806, 26.40782928], [88.50048828, 26.4076519], [88.5010376, 26.40756035], [88.50211334, 26.40744972], [88.50361633, 26.40453911], [88.50370026, 26.40414047], [88.50383759, 26.40353203], [88.50414276, 26.40369606], [88.50523376, 26.40447617], [88.50561523, 26.4053936], [88.50627899, 26.40665436], [88.50662231, 26.40698433], [88.50714874, 26.40699005], [88.50723267, 26.40695763], [88.50776672, 26.40704155], [88.50835419, 26.40704918], [88.50874329, 26.40696144], [88.50888062, 26.40729904], [88.50952148, 26.40660095], [88.50963593, 26.4064045], [88.5099411, 26.40590858], [88.51052856, 26.40588951], [88.51072693, 26.40587997], [88.51180267, 26.40389061], [88.51225281, 26.40143967], [88.5118103, 26.40047264], [88.51111603, 26.40001106], [88.50892639, 26.39966011], [88.50772858, 26.39931107], [88.50653839, 26.39857101], [88.5075531, 26.39731979], [88.50968933, 26.39520836], [88.51190186, 26.39270973], [88.51278687, 26.3902607], [88.51294708, 26.38881111], [88.51300049, 26.38843918], [88.51300049, 26.38762474], [88.51319885, 26.38741684], [88.5134964, 26.38741493], [88.51402283, 26.38731766], [88.51457977, 26.38760185], [88.51515961, 26.38865471], [88.51565552, 26.38955688], [88.51670074, 26.39028549], [88.51678467, 26.39027977], [88.51883698, 26.39011955], [88.51909637, 26.39009857], [88.51906586, 26.38991165], [88.51920319, 26.38994026], [88.51937866, 26.38980103], [88.5202179, 26.38914108], [88.52072144, 26.38789177], [88.52015686, 26.38640976], [88.51883698, 26.38594818], [88.51763916, 26.38474083], [88.51715088, 26.38252068], [88.51564789, 26.37989044], [88.51558685, 26.37817955], [88.51515961, 26.37681007], [88.51528931, 26.37458038], [88.51611328, 26.37252998], [88.51628113, 26.37231064], [88.51750183, 26.37071991], [88.51914978, 26.37114906], [88.52040863, 26.37246704], [88.5218811, 26.37459755], [88.52347565, 26.3756218], [88.5242691, 26.37539673], [88.52478027, 26.37466621], [88.52468109, 26.37447929], [88.52461243, 26.37434578], [88.52409363, 26.37338829], [88.52340698, 26.37211037], [88.52212524, 26.37045479], [88.52202606, 26.37031937], [88.52204895, 26.370121], [88.52233887, 26.36812592], [88.52217102, 26.36723328], [88.52111816, 26.36679268], [88.51995087, 26.3663044], [88.51898193, 26.36632538], [88.51881409, 26.36632919], [88.5175705, 26.36647034], [88.51570129, 26.36597824], [88.51528168, 26.36511421], [88.51532745, 26.36423302], [88.51534271, 26.36406708], [88.51654053, 26.36253738], [88.51719666, 26.36240196], [88.51829529, 26.36217499], [88.51973724, 26.36279488], [88.5212326, 26.36327744], [88.52244568, 26.36259651], [88.52274323, 26.36220169], [88.5235672, 26.36194992], [88.52477264, 26.36092949], [88.52480316, 26.36048126], [88.52482605, 26.35983849], [88.52375793, 26.35790062], [88.52282715, 26.35658836], [88.5220108, 26.3555603], [88.52139282, 26.35447121], [88.52088928, 26.35360909], [88.51988983, 26.35218048], [88.51837158, 26.35132027], [88.51725006, 26.35124016], [88.51541901, 26.3517704], [88.5151825, 26.35188103], [88.51476288, 26.35197639], [88.51477051, 26.35210228], [88.51477814, 26.35224533], [88.5147934, 26.35237503], [88.51478577, 26.35248947], [88.51477814, 26.35259056], [88.51475525, 26.35270691], [88.51459503, 26.35272026], [88.51332855, 26.35281944], [88.51004028, 26.35285378], [88.50991058, 26.35285568], [88.50926971, 26.3527298], [88.50996399, 26.35051918], [88.50937653, 26.35077477], [88.50836182, 26.35121727], [88.50833893, 26.35113144], [88.50753021, 26.35119438], [88.50713348, 26.34885025], [88.5056076, 26.34866333], [88.50492859, 26.34873581], [88.50463104, 26.34876633], [88.5045166, 26.34877777], [88.5038147, 26.349617], [88.50474548, 26.35019684], [88.50565338, 26.3518219], [88.50549316, 26.35492325], [88.50545502, 26.35618019], [88.50543976, 26.35643196], [88.50608063, 26.35647964], [88.50700378, 26.35655022], [88.50632477, 26.35856056], [88.50731659, 26.3591938], [88.50754547, 26.35934258], [88.50770569, 26.360672], [88.50795746, 26.36094284], [88.50741577, 26.3613205], [88.50678253, 26.36091995], [88.50527954, 26.35995102], [88.50314331, 26.35845947], [88.50138855, 26.35782051], [88.49944305, 26.3578701], [88.49680328, 26.35877991], [88.49569702, 26.35907936], [88.49505615, 26.35926056], [88.49303436, 26.35950279], [88.49267578, 26.35974693], [88.49260712, 26.35979271], [88.49025726, 26.35983849], [88.48956299, 26.35920906], [88.48957062, 26.35810852], [88.48957062, 26.35784149], [88.49002838, 26.35700035], [88.49072266, 26.35573006], [88.49166107, 26.35391045], [88.49202728, 26.35213089], [88.49215698, 26.3514595], [88.49104309, 26.35042953], [88.48985291, 26.34992027], [88.48854828, 26.34950256], [88.48838043, 26.34892845], [88.48773956, 26.34909248], [88.48703766, 26.34927177], [88.4857254, 26.34960747], [88.48537445, 26.34971237], [88.48503876, 26.34969521], [88.4835434, 26.34967232], [88.483284, 26.34986305], [88.48238373, 26.35050964], [88.48184967, 26.35056496], [88.48171997, 26.35057831], [88.48023224, 26.3507328], [88.48083496, 26.35165977], [88.48016357, 26.35329628], [88.48000336, 26.35325241], [88.47889709, 26.3529377], [88.47727203, 26.35397148], [88.47724915, 26.35410881], [88.47701263, 26.35581589], [88.47705078, 26.35589218], [88.47737122, 26.35660553], [88.4764328, 26.35671043], [88.47302246, 26.35674667], [88.47291565, 26.35658264], [88.47286224, 26.35649872], [88.47229767, 26.35679817], [88.47209167, 26.35690498], [88.4719162, 26.35699463], [88.47042084, 26.35700989], [88.4692688, 26.35713959], [88.46826172, 26.35765076], [88.46685791, 26.35773087], [88.46643829, 26.35774994], [88.46629333, 26.35780716], [88.46315765, 26.35735893], [88.46318817, 26.35772133], [88.46333313, 26.35913086], [88.46326447, 26.35916901], [88.46209717, 26.3597908], [88.46131897, 26.36117744], [88.45982361, 26.36166573], [88.45856476, 26.36221504], [88.45940399, 26.36403465], [88.45788574, 26.36437416], [88.45767975, 26.36441994], [88.45729828, 26.36450577], [88.45731354, 26.36663055], [88.45797729, 26.36678505], [88.45847321, 26.3669014], [88.45863342, 26.36717987], [88.45953369, 26.36879349], [88.46002197, 26.36966896], [88.4598999, 26.37113762], [88.45745087, 26.37146378], [88.45787811, 26.37273407], [88.45814514, 26.37271309], [88.45890045, 26.37265396], [88.45906067, 26.37391472], [88.45789337, 26.37375069], [88.4573822, 26.37318039], [88.45628357, 26.37201309], [88.45413208, 26.37121964], [88.45162964, 26.37047768], [88.45154572, 26.36794662], [88.45078278, 26.36680412], [88.45035553, 26.36649132], [88.44901276, 26.36550331], [88.4486084, 26.36520195], [88.44790649, 26.36468697], [88.44664001, 26.36498833], [88.44645691, 26.3650341], [88.44548035, 26.3617897], [88.44464874, 26.36113548], [88.44420624, 26.35922813], [88.44402313, 26.3586216], [88.44392395, 26.35828781], [88.44333649, 26.3571167], [88.44298553, 26.35642433], [88.44286346, 26.35617256], [88.44273376, 26.35546112], [88.44250488, 26.35496521], [88.44275665, 26.35396194], [88.44258881, 26.35293388], [88.44094086, 26.35179901], [88.43973541, 26.35074234], [88.43915558, 26.35023499], [88.44017029, 26.34980011], [88.44074249, 26.34955597], [88.44026184, 26.3482151], [88.4380722, 26.34633636], [88.43811035, 26.34598541], [88.43829346, 26.34412193], [88.43842316, 26.34277725], [88.43793488, 26.34292603], [88.43707275, 26.34318733], [88.43702698, 26.34286118], [88.43688965, 26.34202194], [88.43684387, 26.34170341], [88.43809509, 26.34145546], [88.43864441, 26.34134674], [88.43830109, 26.33864975], [88.43810272, 26.33704948], [88.4367218, 26.33612823], [88.43493652, 26.33549118], [88.43450165, 26.33522797], [88.43366241, 26.33531952], [88.43151093, 26.3350296], [88.42984009, 26.33505058], [88.42591095, 26.33512115], [88.42451477, 26.33522987], [88.42308807, 26.3353405], [88.42114258, 26.33543968], [88.41861725, 26.33595276], [88.41736603, 26.33611107], [88.41485596, 26.33673096], [88.41308594, 26.33580971], [88.41248322, 26.33392906], [88.411026, 26.33266068], [88.40846252, 26.33163071], [88.40695953, 26.33041954], [88.40627289, 26.32933998], [88.40702057, 26.32788467], [88.40721893, 26.32786369], [88.40790558, 26.32779503], [88.40775299, 26.32711029], [88.40701294, 26.32387543], [88.40698242, 26.32374954], [88.40852356, 26.32322693], [88.40975952, 26.32322121], [88.41152191, 26.32321358], [88.41226959, 26.32399559], [88.41342163, 26.32380867], [88.41518402, 26.32431602], [88.41561127, 26.32444], [88.41574097, 26.32280159], [88.41652679, 26.32176208], [88.41641998, 26.32139206], [88.41513062, 26.3169632], [88.41526794, 26.31600761], [88.41511536, 26.31561089], [88.41495514, 26.31518555], [88.41454315, 26.3154068], [88.41423798, 26.31557465], [88.41334534, 26.31605339], [88.41293335, 26.31627846], [88.41235352, 26.31585884], [88.41207123, 26.31565666], [88.41152954, 26.31588936], [88.41051483, 26.3163166], [88.41038513, 26.31637192], [88.40963745, 26.31594276], [88.40849304, 26.31657219], [88.40646362, 26.31661415], [88.40546417, 26.31645584], [88.40532684, 26.31647301], [88.40512848, 26.31649971], [88.40399933, 26.31661797], [88.40293121, 26.31677055], [88.40148163, 26.31682014], [88.40027618, 26.31614113], [88.39929199, 26.31509972], [88.39840698, 26.31430054], [88.39740753, 26.31355095], [88.39527893, 26.3126297], [88.39325714, 26.31319809], [88.39212799, 26.31336021], [88.39058685, 26.31373787], [88.38998413, 26.31289864], [88.38987732, 26.31371689], [88.38942719, 26.31368828], [88.38906097, 26.31249809], [88.38812256, 26.31270027], [88.38780212, 26.31277084], [88.3864212, 26.31197166], [88.38581085, 26.30846977], [88.38581085, 26.30785942], [88.38360596, 26.30756187], [88.38134766, 26.3074398], [88.38072968, 26.30653], [88.38047791, 26.30521965], [88.37966919, 26.3043499], [88.37872314, 26.30429077], [88.37705994, 26.3050251], [88.37594604, 26.30483437], [88.37581635, 26.30496216], [88.37583923, 26.30467987], [88.37583923, 26.30307961], [88.37528229, 26.30239105], [88.37452698, 26.30188179], [88.3736496, 26.30227089], [88.3734436, 26.30322838], [88.37306213, 26.30289268], [88.3728714, 26.30342865], [88.37263489, 26.30407143], [88.37239075, 26.30475235], [88.37249756, 26.30488396], [88.37280273, 26.30526924], [88.3731308, 26.30568314], [88.37268066, 26.30576706], [88.37150574, 26.30599022], [88.37084198, 26.3051548], [88.37034607, 26.30508232], [88.36920929, 26.30311394], [88.36902618, 26.3019352], [88.36912537, 26.30073929], [88.369133, 26.30058479], [88.36821747, 26.29949188], [88.36781311, 26.29952431], [88.36620331, 26.29916], [88.36592102, 26.29908943], [88.36580658, 26.29886055], [88.36543274, 26.29807091], [88.36493683, 26.29652977], [88.36514282, 26.29430962], [88.36444855, 26.29241943], [88.36313629, 26.29076195], [88.36145782, 26.28853035], [88.36045837, 26.28738022], [88.35926819, 26.28629112], [88.358078, 26.28583908], [88.35700226, 26.28610992], [88.35606384, 26.28652], [88.35588074, 26.28603935], [88.35518646, 26.28539658], [88.35475159, 26.28561974], [88.35449982, 26.28502083], [88.35437775, 26.28370857], [88.35414124, 26.28285027], [88.35271454, 26.28227043], [88.35262299, 26.28223228], [88.35190582, 26.28262138], [88.35121155, 26.28289413], [88.34960175, 26.28230858], [88.34944916, 26.28152275], [88.3494339, 26.28144836], [88.34967041, 26.28121567], [88.35022736, 26.28065872], [88.35057831, 26.27954292], [88.34976959, 26.27892494], [88.34931946, 26.27825546], [88.34923553, 26.27787971], [88.35017395, 26.27698898], [88.35009003, 26.27667427], [88.35144043, 26.27650833], [88.3518219, 26.27596092], [88.35011292, 26.2752285], [88.34886169, 26.27410889], [88.34857178, 26.27348328], [88.34866333, 26.27336693], [88.34989929, 26.2726841], [88.35011292, 26.27165604], [88.34902191, 26.271101], [88.34889221, 26.26976204], [88.34812164, 26.26890564], [88.34815979, 26.26847076], [88.3495636, 26.26784515], [88.3499527, 26.26767349], [88.35015106, 26.26789856], [88.3506546, 26.26847649], [88.35076904, 26.26860619], [88.35189819, 26.26760674], [88.3518219, 26.26713943], [88.35280609, 26.26726913], [88.35382843, 26.26646996], [88.35389709, 26.26551056], [88.35352325, 26.26499176], [88.35251617, 26.26447105], [88.35176849, 26.26383972], [88.35270691, 26.26264954], [88.35309601, 26.26190948], [88.35228729, 26.26071167], [88.35183716, 26.25962067], [88.35209656, 26.25849152], [88.35217285, 26.25712013], [88.35124207, 26.25534058], [88.35035706, 26.25431061], [88.35018158, 26.25316811], [88.35050201, 26.25209045], [88.35108185, 26.2513504], [88.35125732, 26.25054932], [88.35121155, 26.25041771], [88.35148621, 26.25020218], [88.35299683, 26.24901581], [88.35362244, 26.24835777], [88.35404205, 26.24791145], [88.35382843, 26.24697304], [88.35338593, 26.24692345], [88.35140991, 26.24743462], [88.35129547, 26.24746323], [88.35114288, 26.24773216], [88.35072327, 26.24845314], [88.34976959, 26.24768448], [88.35012817, 26.24738503], [88.35076904, 26.24685287], [88.35160065, 26.24562645], [88.35162354, 26.24572372], [88.35228729, 26.24576378], [88.35238647, 26.2457695], [88.35365295, 26.24584389], [88.35492706, 26.24540901], [88.35693359, 26.24425125], [88.35775757, 26.24377823], [88.35922241, 26.242939], [88.35919952, 26.24259567], [88.35913849, 26.24150085], [88.35877228, 26.23998451], [88.3587265, 26.23980141], [88.35827637, 26.239748], [88.35557556, 26.23943329], [88.35435486, 26.23829079], [88.35431671, 26.23757362], [88.35429382, 26.23717117], [88.35489655, 26.23604965], [88.3557663, 26.23540878], [88.3559494, 26.23391914], [88.35573578, 26.23251534], [88.35397339, 26.23240471], [88.35338593, 26.23117638], [88.35334778, 26.23108864], [88.35165405, 26.2305851], [88.35115051, 26.23043633], [88.35095978, 26.22834206], [88.35105896, 26.22828102], [88.35324097, 26.22688103], [88.35118866, 26.22556877], [88.35102844, 26.22546959], [88.35062408, 26.2257843], [88.35009003, 26.2262001], [88.34934998, 26.22591782], [88.34999084, 26.22477341], [88.3505249, 26.22381401], [88.3506546, 26.22347069], [88.35101318, 26.22250557], [88.35127258, 26.22181702], [88.35102081, 26.22149467], [88.35012817, 26.22034645], [88.34925079, 26.2209568], [88.34859467, 26.22142601], [88.34781647, 26.22198486], [88.34375763, 26.22013474], [88.34301758, 26.21985817], [88.34111786, 26.21914864], [88.3407135, 26.21899605], [88.3398819, 26.21782112], [88.33976746, 26.2176609], [88.33930206, 26.21763229], [88.336586, 26.21747208], [88.33334351, 26.21604729], [88.3314209, 26.21700668], [88.3311615, 26.21714211], [88.33115387, 26.21684456], [88.33112335, 26.21462822], [88.33110046, 26.21282196], [88.32997131, 26.21318436], [88.32889557, 26.21352959], [88.32868195, 26.21359825], [88.32814026, 26.212883], [88.3265152, 26.21074104], [88.32449341, 26.21055031], [88.32447052, 26.21073151], [88.32305908, 26.21034431], [88.32315826, 26.21007729], [88.32408905, 26.20750427], [88.3245697, 26.20715141], [88.32572937, 26.20630264], [88.32549286, 26.20582771], [88.32444, 26.20482826], [88.32433319, 26.20472717], [88.32376862, 26.20474243], [88.3218689, 26.20479012], [88.32150269, 26.20446587], [88.32139587, 26.20437431], [88.32238007, 26.20241928], [88.32190704, 26.20204926], [88.32028961, 26.20124054], [88.31933594, 26.20238113], [88.31788635, 26.20345116], [88.31664276, 26.20271111], [88.31607819, 26.20111084], [88.31407166, 26.20172119], [88.31305695, 26.20245934], [88.31167603, 26.2029705], [88.30992126, 26.2025528], [88.30860901, 26.2017498], [88.30797577, 26.20049095], [88.30780792, 26.1982708], [88.30674744, 26.19735146], [88.30561066, 26.19791985], [88.30504608, 26.19878006], [88.30479431, 26.19911957], [88.3045578, 26.19898224], [88.3032608, 26.19916916], [88.30301666, 26.19970131], [88.30255127, 26.200737], [88.30273438, 26.20186806], [88.30197144, 26.20197105], [88.3012619, 26.20206451], [88.30124664, 26.20082664], [88.30122375, 26.19953918], [88.30101776, 26.19928169], [88.29989624, 26.19788551], [88.29979706, 26.19775963], [88.29973602, 26.19787979], [88.29962921, 26.19735527], [88.29931641, 26.19729614], [88.29823303, 26.19709587], [88.29764557, 26.19772911], [88.29753876, 26.19813919], [88.29719543, 26.19942856], [88.29516602, 26.19951439], [88.29419708, 26.19869423], [88.29393005, 26.1986618], [88.29251862, 26.19848442], [88.29185486, 26.19867134], [88.29193115, 26.19964027], [88.29165649, 26.19944954], [88.29073334, 26.19812965], [88.2902298, 26.19733047], [88.28916931, 26.19670105], [88.28835297, 26.19742966], [88.28803253, 26.19783401], [88.28813934, 26.19803429], [88.28818512, 26.19815254], [88.28825378, 26.19843674], [88.28790283, 26.19799614], [88.28756714, 26.19757462], [88.28749847, 26.19748497], [88.28747559, 26.19758606], [88.28742218, 26.19788551], [88.28725433, 26.19883156], [88.28717041, 26.1993103], [88.28643036, 26.20030212], [88.28596497, 26.20027161], [88.28557587, 26.20024681], [88.28347015, 26.19852066], [88.28341675, 26.19743538], [88.28284454, 26.1970253], [88.28386688, 26.19502831], [88.28270721, 26.19486809], [88.28263092, 26.1942749], [88.28231049, 26.19423676], [88.2811203, 26.1940937], [88.28077698, 26.19516945], [88.28069305, 26.19544601], [88.28029633, 26.19514275], [88.27967834, 26.194664], [88.27906036, 26.19419289], [88.27897644, 26.19272995], [88.27896118, 26.19240761], [88.27848816, 26.19221306], [88.27807617, 26.1920414], [88.27667236, 26.19037819], [88.27632904, 26.18888474], [88.27626801, 26.18860817], [88.27580261, 26.18853188], [88.27371216, 26.18818474], [88.27371216, 26.188097], [88.27371216, 26.18791008], [88.27281952, 26.18813515], [88.27147675, 26.18820381], [88.27039337, 26.18825722], [88.26976776, 26.18749619], [88.26928711, 26.18659973], [88.26630402, 26.18778419], [88.2660141, 26.18790054], [88.26412964, 26.18878937], [88.26364899, 26.19019318], [88.26317596, 26.18961525], [88.26267242, 26.18899727], [88.2625351, 26.18882179], [88.26215363, 26.18875122], [88.26056671, 26.18845558], [88.25991058, 26.18683434], [88.25953674, 26.18671989], [88.25943756, 26.18668938], [88.25920868, 26.18662071], [88.25876617, 26.18678474], [88.25833893, 26.18732262], [88.2562027, 26.18688965], [88.25621033, 26.18574905], [88.25557709, 26.18465996], [88.25421143, 26.18407822], [88.25287628, 26.18493271], [88.25235748, 26.18560028], [88.25180817, 26.18569946], [88.25084686, 26.18587494], [88.25067139, 26.18713188], [88.25031281, 26.18861389], [88.24989319, 26.18927574], [88.24943542, 26.19000816], [88.24807739, 26.19044495], [88.24747467, 26.1903286], [88.24569702, 26.18997955], [88.24492645, 26.18943214], [88.2455368, 26.18740463], [88.244133, 26.18772316], [88.24393463, 26.18797302], [88.2434845, 26.18852997], [88.24368286, 26.18859673], [88.24420929, 26.18877411], [88.24482727, 26.18955421], [88.2440033, 26.18965912], [88.24343872, 26.18899536], [88.24176788, 26.18917847], [88.24123383, 26.18742561], [88.24155426, 26.18638611], [88.24022675, 26.18573189], [88.23851776, 26.18536949], [88.23796844, 26.18376923], [88.23653412, 26.18267632], [88.23558044, 26.18249893], [88.23485565, 26.18358803], [88.23445892, 26.18487167], [88.23416138, 26.18498611], [88.23275757, 26.184021], [88.2329483, 26.18262863], [88.23317719, 26.18111801], [88.23350525, 26.18083763], [88.23459625, 26.17991257], [88.23480225, 26.17982483], [88.23626709, 26.17919731], [88.23719788, 26.1782341], [88.2371521, 26.17800903], [88.23706055, 26.17760086], [88.23748779, 26.17743111], [88.23882294, 26.17509842], [88.23800659, 26.17401123], [88.2360611, 26.17400169], [88.23455811, 26.17262077], [88.23351288, 26.17097282], [88.23206329, 26.17090034], [88.2299881, 26.17134094], [88.22866821, 26.17168045], [88.22753906, 26.17122078], [88.22762299, 26.17014122], [88.22912598, 26.16905975], [88.22956848, 26.16855049], [88.22944641, 26.16728973], [88.22750092, 26.16718292], [88.22648621, 26.16715813], [88.22518158, 26.16600037], [88.22363281, 26.16497993], [88.22199249, 26.1649704], [88.21980286, 26.16467094], [88.21866608, 26.1636982], [88.21785736, 26.16221046], [88.21698761, 26.16108894], [88.21691895, 26.16127777], [88.21687317, 26.16137886], [88.21675873, 26.16147804], [88.21665192, 26.16150284], [88.21645355, 26.16155434], [88.216362, 26.16157913], [88.21642303, 26.16172981], [88.21641541, 26.16184807], [88.21619415, 26.16191101], [88.21616364, 26.16201401], [88.2162323, 26.1620903], [88.21632385, 26.16221237], [88.21628571, 26.16234398], [88.21621704, 26.16239929], [88.21606445, 26.16255188], [88.21598053, 26.16264915], [88.21583557, 26.16308022], [88.21620178, 26.16377831], [88.21626282, 26.16390419], [88.21599579, 26.16483307], [88.21559143, 26.16496086], [88.21559906, 26.16432762], [88.21517944, 26.16308594], [88.21263123, 26.1616745], [88.20770264, 26.16108513], [88.20399475, 26.15917969], [88.20213318, 26.15928841], [88.20124054, 26.1593399], [88.20080566, 26.16020012], [88.19986725, 26.16051102], [88.19866943, 26.16085052], [88.19724274, 26.15903282], [88.19580841, 26.1569519], [88.19512177, 26.15524101], [88.19497681, 26.15478516], [88.19585419, 26.15473938], [88.19576263, 26.15455818], [88.19544983, 26.15393448], [88.19700623, 26.1539402], [88.19827271, 26.15319061], [88.19834137, 26.15212059], [88.19741058, 26.15086174], [88.19438934, 26.15113068], [88.19238281, 26.15175056], [88.18987274, 26.15236092], [88.18786621, 26.15205956], [88.18579865, 26.15125084], [88.18473816, 26.14999962], [88.18406677, 26.14850044], [88.18268585, 26.14683914], [88.18044281, 26.14569283], [88.17957306, 26.14277077], [88.17891693, 26.14031219], [88.17992401, 26.13993263], [88.17971039, 26.13951492], [88.17942047, 26.13895607], [88.17991638, 26.13804054], [88.18087006, 26.13592911], [88.18055725, 26.13388062], [88.17975616, 26.1315918], [88.17801666, 26.12935829], [88.1764679, 26.12724113], [88.17624664, 26.1261158], [88.17824554, 26.12500572], [88.17819977, 26.12480545], [88.17974854, 26.12434959], [88.18094635, 26.12350082], [88.1803894, 26.12178993], [88.17870331, 26.12012291], [88.17682648, 26.11828041], [88.17621613, 26.11737061], [88.17630005, 26.11319923], [88.17611694, 26.1112709], [88.17563629, 26.10891914], [88.1739502, 26.10760117], [88.17207336, 26.10674095], [88.16900635, 26.10569191], [88.16681671, 26.10522079], [88.16549683, 26.10338974], [88.16607666, 26.10161972], [88.16622162, 26.09974289], [88.16433716, 26.09841919], [88.16240692, 26.09640121], [88.16155243, 26.09464073], [88.16124725, 26.09246826], [88.16320801, 26.08963013], [88.16348267, 26.08911896], [88.16485596, 26.08970451], [88.16454315, 26.08745956], [88.16448212, 26.08701134], [88.16429901, 26.08570671], [88.16187286, 26.08516121], [88.15962219, 26.08372307], [88.1594696, 26.08336067], [88.15895081, 26.0820961], [88.15840912, 26.08078575], [88.15927887, 26.07804871], [88.15996552, 26.07793427], [88.16034698, 26.07787323], [88.16123199, 26.07847214], [88.16551208, 26.08136368], [88.16590881, 26.08163071], [88.1676178, 26.08286476], [88.16757202, 26.08308792], [88.16751862, 26.08334541], [88.16727448, 26.08454323], [88.16748047, 26.08437347], [88.16909027, 26.08305931], [88.16890717, 26.08207512], [88.16881561, 26.08066559], [88.16905975, 26.08033371], [88.1693573, 26.08098984], [88.16977692, 26.08183861], [88.17072296, 26.08293915], [88.17183685, 26.08288956], [88.17304993, 26.08044052], [88.17405701, 26.0782795], [88.17469788, 26.07676125], [88.17489624, 26.07629013], [88.1762619, 26.07561111], [88.17714691, 26.07516289], [88.18055725, 26.07341957], [88.18339539, 26.07169724], [88.18338013, 26.07159805], [88.18333435, 26.07151031], [88.18315125, 26.07117462], [88.18291473, 26.07096291], [88.1827774, 26.07083321], [88.1824646, 26.07052612], [88.18213654, 26.0700798], [88.18196106, 26.06982613], [88.18180084, 26.06960106], [88.18158722, 26.06931114], [88.18143463, 26.06871605], [88.18167877, 26.0671196], [88.18498993, 26.065382], [88.185112, 26.06487656], [88.18546295, 26.06343651], [88.18401337, 26.06201935], [88.18055725, 26.05865669], [88.18019104, 26.05829811], [88.1782074, 26.05931282], [88.17776489, 26.0595417], [88.1771698, 26.05984497], [88.17690277, 26.05945206], [88.17601013, 26.05812836], [88.17772675, 26.05269814], [88.17771149, 26.05222321], [88.17762756, 26.04977798], [88.17760468, 26.04901123], [88.17925262, 26.04659843], [88.17880249, 26.04680252], [88.17738342, 26.04744911], [88.17398834, 26.04899597], [88.17192078, 26.04876518], [88.1710434, 26.04866982], [88.17058563, 26.04795074], [88.16983032, 26.04677963], [88.16949463, 26.04533195], [88.17172241, 26.0431633], [88.17412567, 26.04163551], [88.17536163, 26.03979492], [88.17497253, 26.03945541], [88.17266083, 26.03743935], [88.1725769, 26.03736115], [88.17115784, 26.03654861], [88.17269897, 26.03160858], [88.17414856, 26.03116798], [88.17626953, 26.0305233], [88.17910004, 26.03008652], [88.18050385, 26.02987099], [88.18382263, 26.02980042], [88.18521118, 26.02923965], [88.18608856, 26.02827072], [88.18666077, 26.0270195], [88.18717194, 26.02582169], [88.18712616, 26.0245285], [88.1871109, 26.0240612], [88.18624115, 26.02313995], [88.1836319, 26.02198029], [88.1816864, 26.0206604], [88.17923737, 26.01944923], [88.17681122, 26.01857948], [88.17466736, 26.01890945], [88.17247772, 26.01981163], [88.17059326, 26.02013969], [88.168396, 26.0200119], [88.16501617, 26.01976013], [88.16266632, 26.01974487], [88.16164398, 26.01920891], [88.16072845, 26.01872826], [88.15899658, 26.01922798], [88.15872955, 26.01928139], [88.15756989, 26.01920128], [88.15582275, 26.01861954], [88.15374756, 26.01781273], [88.15168762, 26.01666069], [88.15000153, 26.01575089], [88.1496582, 26.01550102], [88.1484375, 26.01459122], [88.14662933, 26.01332283], [88.14525604, 26.0125103], [88.14399719, 26.01181984], [88.14319611, 26.01021957], [88.14302063, 26.00901985], [88.14496613, 26.0069809], [88.14636993, 26.00515938], [88.14662933, 26.00282288], [88.14676666, 26.00071907], [88.14583588, 25.99911118], [88.14360046, 25.99687958], [88.14276123, 25.9962101], [88.14234924, 25.9958992], [88.14080048, 25.99406052], [88.14028168, 25.9936924], [88.14019775, 25.99380875], [88.1401062, 25.99390793], [88.14004517, 25.99398994], [88.1399231, 25.99407387], [88.13983154, 25.99416161], [88.13975525, 25.99421501], [88.13967896, 25.99426842], [88.1395874, 25.99430656], [88.13951874, 25.99433517], [88.13478088, 25.99821281], [88.13475037, 25.9981308], [88.13246918, 25.9988327], [88.13148499, 25.99700737], [88.13075256, 25.99701881], [88.12963867, 25.99703789], [88.12953949, 25.9966526], [88.1288147, 25.99373245], [88.1301651, 25.9906292], [88.13014221, 25.99023247], [88.12995148, 25.98666382], [88.12994385, 25.98655319], [88.12960815, 25.98552704], [88.1293335, 25.98535728], [88.12804413, 25.98455048], [88.12802124, 25.98446655], [88.12706757, 25.98056412], [88.12700653, 25.98032188], [88.12899017, 25.98033714], [88.12863922, 25.9799366], [88.1280365, 25.97925377], [88.12799072, 25.97871208], [88.12788391, 25.97740555], [88.12782288, 25.97683907], [88.12780762, 25.97671127], [88.12457275, 25.97567749], [88.12475586, 25.97383118], [88.12557983, 25.97280121], [88.12602234, 25.97224045], [88.12732697, 25.97141075], [88.12798309, 25.97100067], [88.1280899, 25.97080994], [88.12886047, 25.96940994], [88.12874603, 25.96689034], [88.12793732, 25.96569061], [88.12594604, 25.96396828], [88.12420654, 25.96293068], [88.121521, 25.96154976], [88.12007141, 25.96071815], [88.11952209, 25.96039009], [88.11833954, 25.95862007], [88.11934662, 25.9571991], [88.12033844, 25.95630074], [88.12062073, 25.95532036], [88.11955261, 25.95420265], [88.11950684, 25.95407104], [88.11920929, 25.95377159], [88.12015533, 25.95316315], [88.12219238, 25.95001793], [88.12231445, 25.94846344], [88.12221527, 25.94838715], [88.12037659, 25.94699097], [88.11975098, 25.945961], [88.11961365, 25.94581413], [88.11764526, 25.94371986], [88.1158905, 25.94373322], [88.11290741, 25.94375801], [88.11290741, 25.93953323], [88.11191559, 25.93803406], [88.11315155, 25.93710518], [88.11322021, 25.93701172], [88.11334991, 25.93688011], [88.11344147, 25.93673325], [88.11353302, 25.93660545], [88.11363983, 25.93647194], [88.1137085, 25.93638039], [88.11347961, 25.93577003], [88.1126709, 25.93451118], [88.11186981, 25.93313026], [88.11080933, 25.93239021], [88.10912323, 25.9319191], [88.10839081, 25.93227959], [88.10623169, 25.93338013], [88.1052475, 25.93394852], [88.10485077, 25.93320084], [88.1030426, 25.93432045], [88.10254669, 25.93464279], [88.10032654, 25.93403053], [88.0982666, 25.9328804], [88.09571838, 25.93132019], [88.09372711, 25.92959976], [88.09143066, 25.92621994], [88.09026337, 25.92279053], [88.08914948, 25.92056084], [88.08834839, 25.91924095], [88.08912659, 25.91594124], [88.0879364, 25.91443825], [88.08705902, 25.91368294], [88.08927155, 25.91314125], [88.09054565, 25.9146595], [88.09072113, 25.91487312], [88.09176636, 25.91419029], [88.09194183, 25.91236115], [88.09364319, 25.91117668], [88.09352875, 25.91086578], [88.09326935, 25.91014862], [88.09403992, 25.9078083], [88.09138489, 25.90669632], [88.09144592, 25.90573883], [88.09146881, 25.90538025], [88.0912323, 25.90350914], [88.09129333, 25.90188026], [88.09133148, 25.90083885], [88.09122467, 25.90054703], [88.09046173, 25.89849854], [88.0903244, 25.89646912], [88.09311676, 25.89515114], [88.09411621, 25.89467812], [88.09920502, 25.89398766], [88.10047913, 25.89177513], [88.10268402, 25.88956261], [88.10293579, 25.88931274], [88.10274506, 25.88904762], [88.10140991, 25.88716316], [88.1006012, 25.88602448], [88.10069275, 25.88583946], [88.10118103, 25.88492966], [88.10102844, 25.88484383], [88.09828186, 25.88330841], [88.09699249, 25.88051224], [88.09685516, 25.88022041], [88.09819031, 25.87976456], [88.09888458, 25.87861633], [88.09851074, 25.87848091], [88.09657288, 25.87778282], [88.09636688, 25.87751579], [88.09494781, 25.87568283], [88.09405518, 25.8746357], [88.09385681, 25.87440109], [88.09663391, 25.87125587], [88.10003662, 25.8732357], [88.10031891, 25.87272453], [88.10240173, 25.86886978], [88.10096741, 25.86327934], [88.1014328, 25.86300659], [88.1028595, 25.86183357], [88.10482025, 25.86375427], [88.10650635, 25.86884308], [88.10891724, 25.8691349], [88.10919189, 25.86846161], [88.10998535, 25.86653519], [88.11100769, 25.86406517], [88.11090851, 25.8637886], [88.11032104, 25.86214638], [88.10970306, 25.86041451], [88.11005402, 25.85972214], [88.1109848, 25.85791779], [88.11108398, 25.85780334], [88.11120605, 25.85765648], [88.11214447, 25.8565464], [88.1128006, 25.85625076], [88.11355591, 25.85591125], [88.11431885, 25.85494041], [88.11534119, 25.85243988], [88.11530304, 25.84976006], [88.11399078, 25.84793282], [88.11087036, 25.84620285], [88.10662842, 25.8438282], [88.10449982, 25.84387016], [88.10356903, 25.8431797], [88.10289001, 25.84140968], [88.10310364, 25.84054375], [88.10350037, 25.84031677], [88.10707092, 25.8413887], [88.10746002, 25.83980179], [88.10755157, 25.83943558], [88.1088562, 25.83922005], [88.11112213, 25.83811188], [88.1116333, 25.83627129], [88.11151123, 25.83428001], [88.11147308, 25.83419037], [88.11128998, 25.8343029], [88.11109161, 25.83442879], [88.11086273, 25.83457756], [88.11066437, 25.83473015], [88.110466, 25.83487892], [88.11027527, 25.83503914], [88.11013031, 25.83515739], [88.10993195, 25.83529663], [88.1096344, 25.83550072], [88.10935211, 25.83572388], [88.10897064, 25.835989], [88.10860443, 25.83625793], [88.1081543, 25.83661079], [88.10742188, 25.83708], [88.10694885, 25.83431816], [88.10690308, 25.83407593], [88.10650635, 25.83371925], [88.10476685, 25.83215141], [88.10417938, 25.83162308], [88.10302734, 25.83166504], [88.10205078, 25.83170128], [88.10129547, 25.82964516], [88.10788727, 25.8296051], [88.10573578, 25.82801819], [88.10492706, 25.82640266], [88.10502625, 25.82639503], [88.10567474, 25.82635307], [88.10559082, 25.82595062], [88.10551453, 25.82555771], [88.10547638, 25.82538414], [88.10599518, 25.82432747], [88.10619354, 25.8239193], [88.10630035, 25.82375526], [88.10710144, 25.82251549], [88.10728455, 25.8222332], [88.10749817, 25.82206917], [88.10758209, 25.82200432], [88.10801697, 25.82187462], [88.10879517, 25.82309532], [88.10927582, 25.82285309], [88.11152649, 25.82173157], [88.11125183, 25.82154274], [88.11022186, 25.82085228], [88.11009979, 25.82063484], [88.10983276, 25.82017517], [88.10862732, 25.81808472], [88.10785675, 25.81671906], [88.10729218, 25.81571388], [88.10706329, 25.81531906], [88.106987, 25.81517982], [88.10708618, 25.81513977], [88.10783386, 25.81482506], [88.10799408, 25.8147583], [88.108284, 25.81522751], [88.10853577, 25.8156395], [88.11155701, 25.8151722], [88.11215973, 25.81507874], [88.11231995, 25.81507492], [88.11519623, 25.81499672], [88.12007141, 25.81257629], [88.11994934, 25.81229019], [88.11934662, 25.81084442], [88.11876678, 25.80945969], [88.11856842, 25.80924416], [88.11795807, 25.80857277], [88.11748505, 25.80805397], [88.11738586, 25.80794334], [88.11708069, 25.80741119], [88.116539, 25.8064537], [88.1164856, 25.80637169], [88.11535645, 25.80339622], [88.1149292, 25.79964638], [88.11466217, 25.79880524], [88.11441803, 25.79802322], [88.11477661, 25.79812622], [88.11551666, 25.79833603], [88.11572266, 25.79828835], [88.11689758, 25.79801178], [88.11917114, 25.79747581], [88.12444305, 25.79637718], [88.12488556, 25.79628563], [88.12515259, 25.79705811], [88.12519073, 25.79716492], [88.12579346, 25.79710388], [88.12708282, 25.79697227], [88.12769318, 25.79808998], [88.13072205, 25.79730797], [88.13092041, 25.79773712], [88.131073, 25.79805756], [88.13117981, 25.79802895], [88.13248444, 25.79767227], [88.13289642, 25.79755783], [88.13414764, 25.79721642], [88.13595581, 25.79722214], [88.13864136, 25.79674911], [88.13840485, 25.79590988], [88.13885498, 25.79576874], [88.13937378, 25.79560852], [88.14155579, 25.79493713], [88.14168549, 25.79487419], [88.1437912, 25.79390717], [88.1441803, 25.79372787], [88.14444733, 25.79135513], [88.14448547, 25.79103088], [88.1444931, 25.79093361], [88.1446991, 25.78817749], [88.14473724, 25.78769493], [88.14457703, 25.78740311], [88.14337921, 25.78521347], [88.14333344, 25.78511047], [88.14233398, 25.78311539], [88.1420517, 25.7825489], [88.14190674, 25.78226089], [88.14174652, 25.78106117], [88.14165497, 25.78044701], [88.14163208, 25.78023148], [88.14432526, 25.77978516], [88.14517975, 25.77964401], [88.14691925, 25.78009605], [88.14844513, 25.78107452], [88.14858246, 25.78116035], [88.14744568, 25.777668], [88.14703369, 25.77638817], [88.14743805, 25.77634048], [88.14974213, 25.7760582], [88.15214539, 25.77576447], [88.15340424, 25.77739525], [88.15405273, 25.77727509], [88.15458679, 25.7771759], [88.1548233, 25.77713203], [88.15699005, 25.77953529], [88.15671539, 25.7818718], [88.15768433, 25.78223991], [88.1593399, 25.78289413], [88.15911102, 25.78338242], [88.15878296, 25.78409386], [88.15837097, 25.78497505], [88.15849304, 25.78505898], [88.15963745, 25.78589249], [88.15959167, 25.78612709], [88.15931702, 25.78759384], [88.15961456, 25.7876606], [88.16271973, 25.78835487], [88.16443634, 25.78951263], [88.16746521, 25.78831291], [88.17235565, 25.78673363], [88.17250061, 25.78706932], [88.17319489, 25.78861618], [88.17333221, 25.78892899], [88.17359161, 25.78938866], [88.17441559, 25.79087067], [88.17461395, 25.79121971], [88.1756897, 25.7910862], [88.17565155, 25.79136086], [88.17541504, 25.79323006], [88.17565918, 25.79334641], [88.17614746, 25.79358864], [88.17649078, 25.79375648], [88.17713928, 25.79407692], [88.18027496, 25.7933445], [88.18045807, 25.79377556], [88.18102264, 25.79513359], [88.18088531, 25.7953186], [88.17985535, 25.79669762], [88.18180084, 25.79624748], [88.18160248, 25.79661369], [88.18097687, 25.7977562], [88.18097687, 25.79803658], [88.18096161, 25.79917145], [88.18293762, 25.80018425], [88.18332672, 25.80100632], [88.18370056, 25.80178452], [88.18418121, 25.80148697], [88.18482208, 25.80108452], [88.18499756, 25.80097771], [88.18771362, 25.80083084], [88.18855286, 25.80078506], [88.18868256, 25.80077744], [88.18888855, 25.80202103], [88.18919373, 25.80223274], [88.18939972, 25.80237579], [88.1897049, 25.8025856], [88.19341278, 25.80164337], [88.19334412, 25.80105782], [88.1932373, 25.80005455], [88.19428253, 25.79940414], [88.19455719, 25.79923058], [88.19477081, 25.79910278], [88.19457245, 25.79874229], [88.19477081, 25.79867172], [88.19524384, 25.79752159], [88.19703674, 25.79640007], [88.19933319, 25.7940731], [88.19926453, 25.79378891], [88.20094299, 25.79294014], [88.20194244, 25.79117966], [88.2023468, 25.78908157], [88.20705414, 25.78749657], [88.20909119, 25.78720665], [88.20960999, 25.78783607], [88.2093277, 25.78917885], [88.20908356, 25.790308], [88.20950317, 25.79162788], [88.20999908, 25.79172325], [88.21028137, 25.79285431], [88.21063232, 25.79314804], [88.21191406, 25.79421234], [88.21149445, 25.79355431], [88.21076202, 25.79240036], [88.21188354, 25.79228973], [88.21222687, 25.7922554], [88.2130127, 25.79525757], [88.21305084, 25.79659081], [88.21193695, 25.79578209], [88.21086884, 25.79502869], [88.21051788, 25.79504585], [88.2104187, 25.79504967], [88.21030426, 25.79615021], [88.21116638, 25.79680252], [88.21127319, 25.79688644], [88.21329498, 25.79828453], [88.21341705, 25.79823494], [88.21448517, 25.79780006], [88.2142868, 25.80044174], [88.21490479, 25.80091095], [88.215065, 25.80085373], [88.21561432, 25.80065918], [88.2171402, 25.8001194], [88.21954346, 25.79927063], [88.22242737, 25.79760742], [88.22266388, 25.79779434], [88.2249527, 25.79958916], [88.22560883, 25.79939842], [88.22605896, 25.79926872], [88.2271347, 25.7980175], [88.22744751, 25.79765511], [88.22825623, 25.79671288], [88.22859192, 25.79691124], [88.23028564, 25.79789925], [88.23175049, 25.79786491], [88.23219299, 25.79785538], [88.2332077, 25.79823303], [88.23345947, 25.79999924], [88.23308563, 25.80047417], [88.23070526, 25.80239296], [88.23049164, 25.80256271], [88.23171997, 25.80328369], [88.23310852, 25.80459404], [88.23425293, 25.80566788], [88.23561859, 25.8066597], [88.23538971, 25.80831528], [88.23535919, 25.80854416], [88.23563385, 25.80853271], [88.23781586, 25.80843925], [88.2387085, 25.80881882], [88.24036407, 25.80951691], [88.24053955, 25.80959129], [88.24131012, 25.80991745], [88.24178314, 25.80983734], [88.24447632, 25.80938721], [88.2468338, 25.80607986], [88.24692535, 25.80617332], [88.24758911, 25.80726814], [88.2477417, 25.80752754], [88.24799347, 25.80854607], [88.24806213, 25.80879784], [88.24771118, 25.81138802], [88.24853516, 25.81341362], [88.24893951, 25.81232643], [88.24898529, 25.81218719], [88.25327301, 25.81200218], [88.25346375, 25.81199265], [88.25395203, 25.81191826], [88.25698853, 25.81146049], [88.25866699, 25.81131172], [88.25957489, 25.81392479], [88.25998688, 25.81369209], [88.26107788, 25.81307793], [88.26303101, 25.81194878], [88.26426697, 25.81182098], [88.26548004, 25.81053925], [88.26569366, 25.81038094], [88.26593018, 25.81020355], [88.26731873, 25.8094902], [88.26992798, 25.8081398], [88.27017212, 25.80789566], [88.26998138, 25.80792046], [88.26984406, 25.8079586], [88.26966858, 25.80798531], [88.26952362, 25.80797958], [88.26954651, 25.80752563], [88.26959229, 25.80655479], [88.26960754, 25.8061161], [88.27085876, 25.80503845], [88.27097321, 25.80327988], [88.27119446, 25.79998589], [88.27120209, 25.79983902], [88.27141571, 25.79690552], [88.27147675, 25.79605865], [88.271492, 25.79585838], [88.27157593, 25.7946434], [88.27164459, 25.79360008], [88.27177429, 25.79176331], [88.27159119, 25.79134178], [88.27138519, 25.79084587], [88.27145386, 25.79034805], [88.27153778, 25.78977776], [88.27156067, 25.78962135], [88.27012634, 25.78882027], [88.26997375, 25.78873253], [88.26979065, 25.78472328], [88.26808929, 25.78398323], [88.26651764, 25.78329468], [88.26760101, 25.78190231], [88.26831818, 25.78097725], [88.26846313, 25.78079796], [88.2701416, 25.78094673], [88.27050781, 25.78075218], [88.27182007, 25.78006172], [88.27251434, 25.77969933], [88.27370453, 25.77907944], [88.27388763, 25.778759], [88.27445984, 25.77845001], [88.27746582, 25.7762928], [88.27932739, 25.77447891], [88.28188324, 25.77568817], [88.28219604, 25.77555847], [88.28464508, 25.77450371], [88.28645325, 25.77456474], [88.28659821, 25.77453995], [88.28762817, 25.77436829], [88.29074097, 25.77385139], [88.29042053, 25.77283859], [88.29251099, 25.77158165], [88.29376984, 25.76993179], [88.29328156, 25.76644707], [88.29349518, 25.76630783], [88.29637909, 25.76531219], [88.29782104, 25.76490402], [88.29967499, 25.76437569], [88.29885101, 25.76373672], [88.29969025, 25.7629528], [88.30014038, 25.76281929], [88.30002594, 25.76263618], [88.29901886, 25.76097107], [88.30200958, 25.75952721], [88.30327606, 25.75910378], [88.30667877, 25.757967], [88.31182861, 25.75568199], [88.31240082, 25.75527763], [88.3132782, 25.75466156], [88.3136673, 25.75438881], [88.31633759, 25.75318718], [88.31634521, 25.75290871], [88.31635284, 25.75216866], [88.31693268, 25.75196075], [88.31925201, 25.75072289], [88.32007599, 25.74867058], [88.31990051, 25.74644279], [88.31970215, 25.74551201], [88.32071686, 25.74526596], [88.32051086, 25.74459648], [88.32032013, 25.74395943], [88.31958771, 25.74401093], [88.3186264, 25.74407768], [88.31826019, 25.74280357], [88.31987762, 25.74092674], [88.32007599, 25.74075317], [88.32087708, 25.74004936], [88.3208847, 25.73817253], [88.32089233, 25.73757935], [88.32406616, 25.73753738], [88.32501221, 25.73752594], [88.32509613, 25.73760414], [88.32802582, 25.74017143], [88.32810974, 25.74014664], [88.3320694, 25.73903084], [88.33752441, 25.73770905], [88.33750153, 25.7373085], [88.33747101, 25.7366848], [88.3374176, 25.73539543], [88.33792114, 25.73532104], [88.33856964, 25.73522758], [88.34088135, 25.73488998], [88.34124756, 25.73423576], [88.34215546, 25.73259926], [88.34256744, 25.73184967], [88.34308624, 25.73091698], [88.34406281, 25.72954369], [88.34514618, 25.72973061], [88.34776306, 25.73017693], [88.34814453, 25.73017502], [88.34883118, 25.7301712], [88.35057068, 25.73016357], [88.35144806, 25.72827721], [88.35441589, 25.72751808], [88.35539246, 25.72727013], [88.35616302, 25.72932053], [88.35643768, 25.72919846], [88.35878754, 25.72817039], [88.35807037, 25.72531509], [88.36001587, 25.72569847], [88.36134338, 25.72404861], [88.36160278, 25.7213707], [88.36122131, 25.72054482], [88.36204529, 25.7203846], [88.36280823, 25.72023773], [88.36468506, 25.71987152], [88.36499786, 25.7182827], [88.3651123, 25.71769142], [88.365242, 25.71765327], [88.36546326, 25.71764183], [88.36698914, 25.71757126], [88.36752319, 25.71694946], [88.37193298, 25.71559334], [88.37237549, 25.71597099], [88.37308502, 25.71657944], [88.37393188, 25.71730804], [88.37402344, 25.71701622], [88.37462616, 25.71504021], [88.37463379, 25.71403503], [88.37638855, 25.71408081], [88.37857819, 25.71255112], [88.37860107, 25.71162987], [88.37697601, 25.70792007], [88.37449646, 25.70306015], [88.37413025, 25.70043182], [88.37388611, 25.69821167], [88.373909, 25.69775963], [88.37391663, 25.69754791], [88.3761673, 25.69767189], [88.37660217, 25.69759369], [88.37714386, 25.69749641], [88.37736511, 25.69745445], [88.37812042, 25.69731712], [88.37919617, 25.69712257], [88.381073, 25.697258], [88.38135529, 25.69727898], [88.38206482, 25.69733047], [88.38320923, 25.69552803], [88.38529968, 25.69576454], [88.38517761, 25.69449425], [88.38674927, 25.69426727], [88.39055634, 25.69371986], [88.3914566, 25.69359016], [88.39093781, 25.69216347], [88.39079285, 25.69176102], [88.39222717, 25.69115829], [88.39337158, 25.68962097], [88.39375305, 25.68717194], [88.39376068, 25.68557167], [88.39362335, 25.68429375], [88.39564514, 25.68528366], [88.39924622, 25.68558502], [88.40177155, 25.68605995], [88.4019165, 25.68599892], [88.40403748, 25.68510437], [88.40510559, 25.68309593], [88.4050293, 25.68293381], [88.40645599, 25.6824894], [88.40740204, 25.68078041], [88.40804291, 25.67815971], [88.40730286, 25.67655945], [88.40586853, 25.67507172], [88.40505981, 25.67318916], [88.40534973, 25.67147064], [88.40866852, 25.67071152], [88.40918732, 25.67061615], [88.41165924, 25.67016792], [88.41526794, 25.66954041], [88.41858673, 25.66776085], [88.41867828, 25.66790771], [88.42029572, 25.67037582], [88.42085266, 25.67038918], [88.42430115, 25.67046928], [88.42449188, 25.67041588], [88.42711639, 25.66970253], [88.42757416, 25.66957664], [88.42967224, 25.6687355], [88.4332428, 25.66857338], [88.43650818, 25.66799736], [88.43983459, 25.66719055], [88.44008636, 25.66712952], [88.44306183, 25.66606522], [88.44393921, 25.66508484], [88.4454422, 25.66557312], [88.4460907, 25.66545486], [88.44683838, 25.66531754], [88.44692993, 25.66530037], [88.45085907, 25.66457558], [88.45091248, 25.66484451], [88.45104218, 25.66553879], [88.45262909, 25.6652317], [88.45359039, 25.66504478], [88.45376587, 25.66501045], [88.45407867, 25.66425896], [88.45436859, 25.66355324], [88.45433807, 25.66317177], [88.45428467, 25.66243172], [88.45672607, 25.66049957], [88.45767975, 25.65640068], [88.45807648, 25.65071106], [88.45809174, 25.64614105], [88.45748901, 25.64162064], [88.45762634, 25.6371212], [88.45726776, 25.63382149], [88.45783234, 25.63120079], [88.4581604, 25.62787819], [88.45754242, 25.62543106], [88.45461273, 25.6236496], [88.45192719, 25.62267113], [88.45050049, 25.62054825], [88.45044708, 25.61798096], [88.45021057, 25.61569977], [88.44986725, 25.61526108], [88.44896698, 25.6140995], [88.448349, 25.61312294], [88.44873047, 25.61045074], [88.4492569, 25.60896111], [88.44954681, 25.60811043], [88.45024872, 25.60462952], [88.45056915, 25.60251808], [88.44908142, 25.6002903], [88.44783783, 25.59957123], [88.44702148, 25.59909058], [88.44644165, 25.59714699], [88.4480896, 25.59723854], [88.4535141, 25.59812927], [88.45704651, 25.59897804], [88.45720673, 25.596138], [88.45732117, 25.59599876], [88.45847321, 25.59628105], [88.45979309, 25.59528732], [88.45778656, 25.59544373], [88.45936584, 25.59356117], [88.46134949, 25.59324646], [88.46276855, 25.59302139], [88.46299744, 25.59298515], [88.46325684, 25.5923233], [88.46463013, 25.59209824], [88.46575165, 25.5919323], [88.4661026, 25.59065437], [88.46556854, 25.58953857], [88.46717072, 25.58877945], [88.47012329, 25.58646011], [88.47036743, 25.58509064], [88.47044373, 25.58461761], [88.47110748, 25.58519173], [88.4725647, 25.58480072], [88.47330475, 25.58460236], [88.47740173, 25.58538437], [88.4802475, 25.58539772], [88.48106384, 25.58568001], [88.48103333, 25.58242798], [88.4810257, 25.58210182], [88.48226166, 25.58228683], [88.48257446, 25.58233452], [88.48361206, 25.58660316], [88.48677063, 25.58582687], [88.49147797, 25.58458328], [88.49140167, 25.58336639], [88.49138641, 25.5830555], [88.49153137, 25.58304214], [88.49320984, 25.58287621], [88.49395752, 25.58280373], [88.49320221, 25.58427429], [88.49420166, 25.58442879], [88.49447632, 25.58441162], [88.4966507, 25.58464813], [88.49989319, 25.58405495], [88.4998703, 25.58388329], [88.49954987, 25.58135033], [88.49919128, 25.57855606], [88.49900818, 25.57468605], [88.49899292, 25.57444572], [88.49893951, 25.57323265], [88.49780273, 25.57008934], [88.49888611, 25.56821251], [88.49901581, 25.56798744], [88.5009079, 25.56406593], [88.50102997, 25.56103134], [88.501297, 25.5588932], [88.49893951, 25.55875206], [88.49796295, 25.55669594], [88.49901581, 25.55587006], [88.50019836, 25.55359077], [88.5007019, 25.55109024], [88.50100708, 25.55062866], [88.50325012, 25.5499115], [88.50537109, 25.5485878], [88.50788116, 25.54718018], [88.50865936, 25.54532814], [88.5092926, 25.54431725], [88.50939178, 25.54415894], [88.50945282, 25.54438972], [88.50984192, 25.54586411], [88.51093292, 25.54565048], [88.51148987, 25.54554176], [88.51157379, 25.5455246], [88.51242065, 25.54634476], [88.51280975, 25.54672813], [88.51374817, 25.54763603], [88.51423645, 25.54746246], [88.51720428, 25.54641342], [88.51741791, 25.54633904], [88.51901245, 25.54519081], [88.51902771, 25.5450058], [88.51912689, 25.54388428], [88.51926422, 25.54239273], [88.51935577, 25.54132652], [88.51866913, 25.53840828], [88.52086639, 25.53705788], [88.52112579, 25.53688049], [88.52342987, 25.53530884], [88.52352142, 25.5353756], [88.52424622, 25.53625107], [88.52539063, 25.53764534], [88.52648163, 25.54026031], [88.52761078, 25.54324722], [88.52767181, 25.54340744], [88.53307343, 25.54220009], [88.53304291, 25.54045486], [88.53303528, 25.53993416], [88.53318787, 25.53655815], [88.53276825, 25.53229904], [88.53374481, 25.53223991], [88.5342865, 25.53220749], [88.53445435, 25.53219795], [88.53437805, 25.5337925], [88.53445435, 25.53380775], [88.53746033, 25.53443146], [88.53909302, 25.53476906], [88.53936005, 25.53482437], [88.53944397, 25.53448868], [88.53975677, 25.53326225], [88.5403595, 25.5308342], [88.54090881, 25.5308609], [88.54078674, 25.52807045], [88.54075623, 25.52622414], [88.54050446, 25.52626419], [88.53946686, 25.52642632], [88.53798676, 25.52534676], [88.53796387, 25.52523613], [88.5377655, 25.52392578], [88.53739929, 25.52153587], [88.53733063, 25.52108765], [88.53990173, 25.52013397], [88.54036713, 25.5199604], [88.54003143, 25.51844788], [88.53959656, 25.5165062], [88.53970337, 25.51407814], [88.5401535, 25.51332092], [88.5405426, 25.51265717], [88.54117584, 25.51158714], [88.54065704, 25.51126099], [88.53968048, 25.51065254], [88.5398941, 25.50838661], [88.54153442, 25.5086422], [88.54177856, 25.50868034], [88.54349518, 25.50894737], [88.54392242, 25.50901222], [88.5463028, 25.50842667], [88.54649353, 25.50910759], [88.54695129, 25.51070023], [88.54821014, 25.51511002], [88.54826355, 25.51529312], [88.54795837, 25.51824951], [88.54878998, 25.5184021], [88.55019379, 25.51865959], [88.55154419, 25.52052307], [88.55450439, 25.52094841], [88.55485535, 25.52099991], [88.55464935, 25.51813316], [88.55434418, 25.51762772], [88.55504608, 25.51756287], [88.5566864, 25.51567841], [88.55708313, 25.51399612], [88.55958557, 25.5135746], [88.55988312, 25.51280594], [88.5599823, 25.51255608], [88.56362152, 25.51324081], [88.56612396, 25.51365089], [88.56797791, 25.51399612], [88.56825256, 25.51404762], [88.5682373, 25.51392365], [88.56822205, 25.51384735], [88.56778717, 25.51135445], [88.5708313, 25.51084518], [88.57094574, 25.51078796], [88.5719223, 25.51029778], [88.57221985, 25.51014519], [88.57282257, 25.50984573], [88.57273102, 25.50905418], [88.57526398, 25.50872993], [88.57765198, 25.50842476], [88.57976532, 25.50975609], [88.58008575, 25.50979614], [88.58577728, 25.51047707], [88.58609772, 25.50939369], [88.58670807, 25.50728989], [88.58961487, 25.50823021], [88.59027863, 25.50889587], [88.59083557, 25.50945854], [88.59144592, 25.50896072], [88.59371185, 25.50709915], [88.59394836, 25.50701523], [88.59588623, 25.50633049], [88.59606171, 25.50626945], [88.59632874, 25.50618172], [88.59859467, 25.50853729], [88.59960175, 25.50958633], [88.59951782, 25.51132584], [88.59950256, 25.51166916], [88.60031891, 25.51170731], [88.60086823, 25.5117321], [88.60103607, 25.51198578], [88.60151672, 25.5127182], [88.60259247, 25.5143528], [88.60268402, 25.51535416], [88.60274506, 25.51596642], [88.60478973, 25.51588631], [88.60525513, 25.51586723], [88.60906219, 25.51643372], [88.60907745, 25.51578712], [88.60913086, 25.51361847], [88.60929871, 25.51317787], [88.60942841, 25.51316071], [88.60999298, 25.51185036], [88.61023712, 25.50992966], [88.61264038, 25.50998878], [88.6129303, 25.50999641], [88.61300659, 25.50999832], [88.61306763, 25.50993156], [88.61392975, 25.50897217], [88.61477661, 25.50803757], [88.61487579, 25.50792885], [88.61507416, 25.50713539], [88.61515808, 25.50680733], [88.61551666, 25.50539589], [88.61607361, 25.50496483], [88.61632538, 25.50476265], [88.61760712, 25.5037632], [88.61865234, 25.50382233], [88.61965179, 25.50387955], [88.61988831, 25.50334167], [88.62030029, 25.50236702], [88.62068176, 25.50147629], [88.62130737, 25.4998951], [88.62264252, 25.49882126], [88.62290955, 25.49777031], [88.62309265, 25.4971447], [88.62696075, 25.49787521], [88.62919617, 25.4982605], [88.63330078, 25.4987545], [88.63491821, 25.49894714], [88.63973999, 25.49955368], [88.64086914, 25.49936867], [88.64363861, 25.49891663], [88.64468384, 25.49874496], [88.64480591, 25.498312], [88.64517975, 25.49698257], [88.64699554, 25.49734688], [88.6472702, 25.49715233], [88.64845276, 25.49630737], [88.6484375, 25.49444389], [88.64953613, 25.49328995], [88.65072632, 25.49154091], [88.64948273, 25.49034119], [88.6474762, 25.49033165], [88.64560699, 25.49003983], [88.64511871, 25.48924065], [88.64550018, 25.48610115], [88.64639282, 25.48073959], [88.64644623, 25.48035049], [88.64761353, 25.47856712], [88.64794922, 25.47857857], [88.65029144, 25.48027039], [88.65297699, 25.48153114], [88.65429688, 25.48152542], [88.65688324, 25.48226166], [88.66007996, 25.4818573], [88.66023254, 25.48183823], [88.66088104, 25.47927475], [88.66092682, 25.4790802], [88.66111755, 25.47917557], [88.66126251, 25.47924423], [88.66197205, 25.47959709], [88.66200256, 25.47945786], [88.66217804, 25.47851372], [88.66243744, 25.4770813], [88.6625061, 25.47671318], [88.66252899, 25.47659683], [88.6629715, 25.47376823], [88.66317749, 25.47380257], [88.66412354, 25.47396278], [88.66457367, 25.47403908], [88.66926575, 25.47482491], [88.67029572, 25.47439384], [88.67419434, 25.47464561], [88.67483521, 25.47468948], [88.67519379, 25.47471428], [88.67823029, 25.47414398], [88.67842865, 25.47410583], [88.67977905, 25.47454453], [88.68170929, 25.47517395], [88.68257141, 25.4753418], [88.68448639, 25.47571182], [88.68729401, 25.47561646], [88.68823242, 25.47558403], [88.68976593, 25.47462463], [88.69043732, 25.47420883], [88.69407654, 25.4736805], [88.69580841, 25.47342873], [88.69916534, 25.47150612], [88.69950867, 25.47130966], [88.7000885, 25.47303963], [88.70036316, 25.47593689], [88.70037842, 25.47607422], [88.70278931, 25.47617531], [88.70329285, 25.47619629], [88.7039566, 25.4762249], [88.70616913, 25.47675133], [88.70710754, 25.47697449], [88.70746613, 25.47705841], [88.70653534, 25.47953415], [88.70638275, 25.47993469], [88.70769501, 25.48007011], [88.70804596, 25.48015404], [88.70973969, 25.48056602], [88.70985413, 25.48059464], [88.71012115, 25.48065948], [88.71014404, 25.48161697], [88.70972443, 25.48363876], [88.70931244, 25.48634148], [88.7080307, 25.49237633], [88.70907593, 25.49568748], [88.70923615, 25.49618149], [88.70768738, 25.49955368], [88.70750427, 25.49994469], [88.70812988, 25.49989891], [88.7088623, 25.4998455], [88.70980072, 25.49977493], [88.71012878, 25.49975014], [88.71134949, 25.49988174], [88.71292877, 25.5000515], [88.71327209, 25.50008774], [88.71324158, 25.49821091], [88.71255493, 25.49770927], [88.71191406, 25.49724197], [88.71203613, 25.49701691], [88.71212006, 25.49685669], [88.7122345, 25.49664116], [88.7128067, 25.49555016], [88.71379852, 25.49565506], [88.71334839, 25.49817657], [88.71517944, 25.49885368], [88.71543884, 25.49894714], [88.71466827, 25.49937248], [88.71434021, 25.49955177], [88.7145462, 25.4995594], [88.71500397, 25.49957657], [88.72116089, 25.49980736], [88.72148895, 25.5016613], [88.72570801, 25.50202751], [88.72640228, 25.50232697], [88.72632599, 25.50336266], [88.72988129, 25.50371742], [88.73137665, 25.50375557], [88.7318573, 25.50376701], [88.73670197, 25.50419426], [88.73730469, 25.50429726], [88.74088287, 25.50490761], [88.74184418, 25.50507164], [88.74213409, 25.50511932], [88.74211884, 25.50434875], [88.74209595, 25.50331497], [88.74206543, 25.50185394], [88.74384308, 25.49685669], [88.74385071, 25.49648476], [88.74389648, 25.49487877], [88.74333191, 25.49510002], [88.74254608, 25.4954052], [88.74243164, 25.49514198], [88.74098969, 25.49185753], [88.74002838, 25.48941612], [88.74240112, 25.48880386], [88.74280548, 25.48869896], [88.74475861, 25.48884773], [88.74501801, 25.48886681], [88.7462616, 25.4923172], [88.7485733, 25.49370193], [88.7492218, 25.49383354], [88.75000763, 25.49399185], [88.7505722, 25.49410629], [88.75295258, 25.49416351], [88.7541275, 25.49419022], [88.75534821, 25.49385834], [88.75685883, 25.49344826], [88.76087189, 25.49337769], [88.76477814, 25.49495506], [88.76554871, 25.495718], [88.76893616, 25.4990406], [88.76944733, 25.50037193], [88.77007294, 25.5019989], [88.76927948, 25.50263023], [88.76703644, 25.50446892], [88.76567078, 25.50478363], [88.76553345, 25.50481415], [88.7645874, 25.50623703], [88.76322937, 25.50827599], [88.76303101, 25.50856781], [88.76271057, 25.50866127], [88.76194, 25.50888634], [88.75913239, 25.5097065], [88.7589035, 25.51192856], [88.76039124, 25.51858711], [88.75952911, 25.52248001], [88.75917816, 25.52403069], [88.760849, 25.52534676], [88.7616272, 25.52595901], [88.76331329, 25.52543259], [88.76436615, 25.52510262], [88.7645874, 25.52503204], [88.76708984, 25.52523804], [88.76741028, 25.52526283], [88.76744843, 25.52490425], [88.76778412, 25.5219326], [88.77027893, 25.52055168], [88.77130127, 25.51998329], [88.77289581, 25.51922989], [88.77403259, 25.51869011], [88.77565765, 25.5186882], [88.77618408, 25.51868629], [88.77614594, 25.5182476], [88.77599335, 25.51652527], [88.77628326, 25.51648521], [88.77792358, 25.51624489], [88.77896118, 25.51609421], [88.78061676, 25.51544571], [88.78207397, 25.51618195], [88.78262329, 25.51520538], [88.78277588, 25.51538467], [88.78361511, 25.51636314], [88.78370667, 25.51646996], [88.78634644, 25.51652145], [88.78636932, 25.51704025], [88.78637695, 25.51721764], [88.78639221, 25.51768112], [88.78623199, 25.51774979], [88.78496552, 25.5182991], [88.78523254, 25.51839447], [88.78959656, 25.5199852], [88.7924881, 25.52097893], [88.79232788, 25.52280617], [88.79570007, 25.52310753], [88.79896545, 25.52389336], [88.79930115, 25.5239563], [88.79975128, 25.52403641], [88.80231476, 25.52432632], [88.8032608, 25.52443504], [88.80488586, 25.52330589], [88.80615997, 25.52353287], [88.80861664, 25.52396965], [88.81019592, 25.52335739], [88.81059265, 25.5232029], [88.80944824, 25.52019119], [88.80870819, 25.51822853], [88.80808258, 25.51340675], [88.80799866, 25.51280022], [88.80963135, 25.51082993], [88.81008911, 25.51027489], [88.81003571, 25.5100193], [88.81064606, 25.50879288], [88.8111496, 25.50714111], [88.81153107, 25.50297928], [88.81147003, 25.4981308], [88.8118515, 25.49545288], [88.81297302, 25.49265099], [88.8138504, 25.48986053], [88.8143158, 25.48804283], [88.81542969, 25.48814201], [88.81630707, 25.48822021], [88.82141876, 25.48900032], [88.82620239, 25.48981476], [88.8293457, 25.49030685], [88.82965088, 25.49035454], [88.82958984, 25.48942375], [88.82958221, 25.489254], [88.82963562, 25.48918152], [88.83174896, 25.48636818], [88.83220673, 25.48494339], [88.83307648, 25.48225403], [88.83312225, 25.48200035], [88.83347321, 25.47990799], [88.83352661, 25.47958565], [88.83518982, 25.47554207], [88.83611298, 25.47435188], [88.83727264, 25.47285652], [88.83726501, 25.47262955], [88.83731842, 25.47255707], [88.837883, 25.47180748], [88.83907318, 25.46959114], [88.83937836, 25.46690941], [88.83903503, 25.46604538], [88.83850861, 25.46474075], [88.83732605, 25.46305466], [88.83825684, 25.46191406], [88.83927917, 25.45867538], [88.83919525, 25.45832062], [88.83956909, 25.45795059], [88.84156799, 25.45584106], [88.84211731, 25.45339012], [88.84099579, 25.45145035], [88.83895111, 25.44927979], [88.83563995, 25.44870949], [88.83246613, 25.44728088], [88.83120728, 25.44527817], [88.8295517, 25.44294167], [88.82872009, 25.44089127], [88.8295517, 25.43774986], [88.8296051, 25.4368], [88.83207703, 25.43704224], [88.83226013, 25.43684959], [88.83287811, 25.43621063], [88.83286285, 25.43605232], [88.83272552, 25.43442154], [88.8326416, 25.4336071], [88.83244324, 25.431633], [88.83279419, 25.43166161], [88.83377838, 25.43173981], [88.83426666, 25.43177986], [88.83441925, 25.42753029], [88.8298111, 25.42769241], [88.82854462, 25.42613411], [88.82896423, 25.4242897], [88.83071899, 25.42330551], [88.83034515, 25.42004395], [88.82995605, 25.41711426], [88.8297348, 25.41706276], [88.82668304, 25.41724586], [88.82646942, 25.41576958], [88.81977844, 25.41548347], [88.81961823, 25.41717148], [88.82019043, 25.41804695], [88.81884766, 25.4181366], [88.81827545, 25.41817474], [88.81801605, 25.41719055], [88.81748199, 25.41441727], [88.81237793, 25.41051102], [88.81447601, 25.40996552], [88.81806183, 25.4098568], [88.81930542, 25.40981865], [88.81990814, 25.40978813], [88.82318878, 25.40962791], [88.82321167, 25.40934944], [88.82343292, 25.40611267], [88.82361603, 25.40608978], [88.82594299, 25.40402985], [88.82624817, 25.40345001], [88.82637024, 25.40124321], [88.82860565, 25.40133476], [88.83454132, 25.40151596], [88.83714294, 25.4018898], [88.8378067, 25.39814949], [88.83878326, 25.3982296], [88.8395462, 25.39758682], [88.84079742, 25.39773178], [88.84080505, 25.39762878], [88.84101105, 25.39559937], [88.84117126, 25.39403343], [88.84122467, 25.39347839], [88.84017944, 25.3916893], [88.83878326, 25.39135742], [88.83779144, 25.39112091], [88.83694458, 25.39091873], [88.83733368, 25.38819695], [88.83675385, 25.38462257], [88.83758545, 25.38448524], [88.84022522, 25.38404846], [88.84026337, 25.38398743], [88.84165192, 25.3817215], [88.83842468, 25.38150024], [88.83856201, 25.37846756], [88.83840942, 25.37428474], [88.83939362, 25.37385368], [88.83779144, 25.36813927], [88.83859253, 25.36815643], [88.84008789, 25.36818695], [88.84008789, 25.36798096], [88.84010315, 25.36387062], [88.84328461, 25.36368561], [88.84568024, 25.36354637], [88.8455658, 25.36219406], [88.84635925, 25.36232758], [88.84764099, 25.36254501], [88.8547821, 25.36351395], [88.85481262, 25.36291695], [88.8548584, 25.36225319], [88.8549118, 25.36138153], [88.8549881, 25.36002922], [88.85498047, 25.35946083], [88.85518646, 25.35951042], [88.85681152, 25.35911942], [88.85874939, 25.35758018], [88.85912323, 25.35535049], [88.85923004, 25.35474586], [88.86194611, 25.35508156], [88.86251831, 25.35515213], [88.86361694, 25.35427856], [88.86369324, 25.35177231], [88.86431885, 25.35183716], [88.86538696, 25.35194778], [88.86888123, 25.35230827], [88.86920929, 25.3495121], [88.86907959, 25.34942245], [88.87033844, 25.34914017], [88.87175751, 25.34806824], [88.87158966, 25.34595108], [88.87103271, 25.34299278], [88.87103271, 25.34058952], [88.87135315, 25.33996391], [88.87187958, 25.33963966], [88.87290955, 25.33840752], [88.87339783, 25.33736992], [88.8736496, 25.33682823], [88.87399292, 25.33692551], [88.87423706, 25.33699608], [88.87565613, 25.33740425], [88.87570953, 25.33712387], [88.87609863, 25.33517838], [88.87863159, 25.33273125], [88.88018799, 25.33020973], [88.88127136, 25.32880783], [88.88380432, 25.32641029], [88.88418579, 25.32647705], [88.88509369, 25.32572937], [88.88555145, 25.32579041], [88.88851166, 25.3261795], [88.88802338, 25.32971382], [88.88786316, 25.3300724], [88.88645935, 25.3331337], [88.88574219, 25.33469391], [88.88691711, 25.33518791], [88.88762665, 25.33721161], [88.89083099, 25.33729172], [88.89099121, 25.33729744], [88.89298248, 25.33707619], [88.89352417, 25.33701515], [88.89611816, 25.33697891], [88.89831543, 25.33684731], [88.89913177, 25.33695984], [88.90244293, 25.33742142], [88.90267944, 25.33751106], [88.90514374, 25.33844376], [88.90630341, 25.33796501], [88.90638733, 25.33795166], [88.90630341, 25.33670998], [88.90622711, 25.33562279], [88.90648651, 25.33555031], [88.90818024, 25.33371925], [88.90936279, 25.33098984], [88.9095993, 25.32864952], [88.90979004, 25.3243103], [88.91026306, 25.32344627], [88.91001129, 25.32243347], [88.90965271, 25.32122612], [88.91087341, 25.32089806], [88.91121674, 25.31982994], [88.91259766, 25.31712341], [88.91264343, 25.31703568], [88.91353607, 25.31527901], [88.91505432, 25.31259918], [88.91581726, 25.31177711], [88.9159317, 25.31209755], [88.91641235, 25.31211281], [88.91692352, 25.31215096], [88.91764832, 25.31224823], [88.91847229, 25.31224632], [88.91889954, 25.31224442], [88.91967773, 25.31225395], [88.92093658, 25.3121109], [88.92188263, 25.3120842], [88.92227173, 25.31207466], [88.9236145, 25.31216049], [88.92366791, 25.31210709], [88.92395782, 25.31209373], [88.92401123, 25.31223679], [88.92404938, 25.31234932], [88.92436981, 25.31301689], [88.92444611, 25.3134346], [88.92459869, 25.31371689], [88.92475891, 25.31500626], [88.92597961, 25.3150425], [88.9259491, 25.31540489], [88.92689514, 25.31527328], [88.92794037, 25.31529617], [88.92790985, 25.31570816], [88.927742, 25.31573868], [88.92776489, 25.31729317], [88.92809296, 25.31707573], [88.92825317, 25.31697083], [88.92871857, 25.31652069], [88.92878723, 25.31628227], [88.92855072, 25.31626892], [88.92852783, 25.31546593], [88.92874146, 25.31533241], [88.92865753, 25.31520271], [88.9285965, 25.313797], [88.92874908, 25.3137989], [88.92903137, 25.31380272], [88.92900085, 25.31335068], [88.92899323, 25.31327629], [88.92894745, 25.31246948], [88.92881012, 25.31196976], [88.92855072, 25.31197548], [88.92836761, 25.31060982], [88.92864227, 25.3105526], [88.92861938, 25.31019783], [88.9288559, 25.31017494], [88.92880249, 25.30983734], [88.92900085, 25.30977821], [88.929039, 25.30911255], [88.92869568, 25.30785942], [88.92871857, 25.30687332], [88.92868042, 25.30608559], [88.92875671, 25.30598831], [88.92893219, 25.30576324], [88.92918396, 25.30471611], [88.92927551, 25.30454445], [88.92943573, 25.30421257], [88.92997742, 25.30418396], [88.9305191, 25.30415726], [88.9309082, 25.30435944], [88.93228149, 25.30562019], [88.93268585, 25.30638123], [88.93408203, 25.30898094], [88.93476868, 25.3101387], [88.93489838, 25.31035042], [88.93701172, 25.3111496], [88.93917847, 25.30973053], [88.93933868, 25.30948639], [88.94111633, 25.30676079], [88.94174957, 25.30520058], [88.94243622, 25.30351067], [88.94480133, 25.30180168], [88.94496918, 25.30183029], [88.94500732, 25.3020916], [88.94504547, 25.30231476], [88.94526672, 25.30286026], [88.94596863, 25.30283737], [88.94674683, 25.30242157], [88.94702148, 25.30236053], [88.94750214, 25.30240822], [88.94789886, 25.30256271], [88.9485321, 25.30297661], [88.9496994, 25.30383492], [88.9499054, 25.30387306], [88.95140839, 25.30337524], [88.95184326, 25.30363083], [88.95210266, 25.30391121], [88.95401764, 25.30597115], [88.95620728, 25.30779839], [88.95950317, 25.30797005], [88.96243286, 25.30779839], [88.96498871, 25.30729103], [88.96797943, 25.30711937], [88.97078705, 25.30562973], [88.97177124, 25.30519295], [88.97245789, 25.30488968], [88.97465515, 25.3025589], [88.97468567, 25.30303192], [88.9750061, 25.30306625], [88.97502136, 25.3034153], [88.9751358, 25.30343246], [88.97523499, 25.30443764], [88.97540283, 25.30443954], [88.97549438, 25.30508995], [88.97557831, 25.30590439], [88.97566223, 25.30604935], [88.97586823, 25.30629349], [88.97687531, 25.30620956], [88.97737885, 25.30620193], [88.9794693, 25.30609894], [88.97946167, 25.30595016], [88.9808197, 25.30589104], [88.98246002, 25.30602455], [88.98299408, 25.30591583], [88.98312378, 25.30589104], [88.98377991, 25.30595398], [88.98390198, 25.30570602], [88.98527527, 25.30600929], [88.98493958, 25.30553246], [88.98477936, 25.30530548], [88.98433685, 25.30468178], [88.98420715, 25.30472565], [88.98377228, 25.30420113], [88.98300171, 25.3041172], [88.98286438, 25.30348969], [88.98265076, 25.30320358], [88.98274231, 25.30275536], [88.98285675, 25.30213547], [88.98307037, 25.30178642], [88.98332214, 25.30136871], [88.98387146, 25.30080414], [88.98407745, 25.30091286], [88.98426819, 25.30163765], [88.98446655, 25.30162048], [88.98451996, 25.30171394], [88.98503113, 25.30207253], [88.98529053, 25.302145], [88.98597717, 25.30215263], [88.98638916, 25.30200768], [88.98651123, 25.30184746], [88.98660278, 25.30173492], [88.98641205, 25.3016243], [88.98638153, 25.30155563], [88.98617554, 25.30148697], [88.98621368, 25.30118752], [88.98627472, 25.30082893], [88.98635101, 25.30034065], [88.98646545, 25.29959679], [88.98672485, 25.29969597], [88.98679352, 25.29956627], [88.98711395, 25.29929161], [88.98840332, 25.29932404], [88.98848724, 25.29924202], [88.9887619, 25.29917526], [88.98985291, 25.29941177], [88.99082947, 25.29782295], [88.99101257, 25.29781342], [88.99143219, 25.29732132], [88.99176025, 25.29730034], [88.99252319, 25.29629898], [88.99352264, 25.29664993], [88.99359894, 25.29646492], [88.99518585, 25.29714012], [88.99573517, 25.29616356], [88.99611664, 25.29591179], [88.99698639, 25.29593277], [88.99765778, 25.29604149], [88.99770355, 25.29614639], [88.99795532, 25.29623032], [88.99793243, 25.29668236], [88.99864197, 25.29675865], [88.9988327, 25.29609489], [89.00164795, 25.29660988], [89.00193024, 25.29666138], [89.00216675, 25.29672623], [89.00221252, 25.29704666], [89.00257111, 25.29748344], [89.0026474, 25.29792213], [89.00328064, 25.29787827], [89.00331879, 25.29811478], [89.00299835, 25.29820824], [89.00318146, 25.29882431], [89.00331879, 25.29947281], [89.00363922, 25.29943657], [89.00387573, 25.29945755], [89.00431061, 25.2994957], [89.00534821, 25.29933548], [89.00541687, 25.29951096], [89.00593567, 25.29960823], [89.0059433, 25.29987144], [89.0059433, 25.29999542], [89.00616455, 25.29998779], [89.00628662, 25.29998398], [89.00628662, 25.30008698], [89.00624084, 25.30128479], [89.00611115, 25.30223274], [89.00611115, 25.30235481], [89.00598907, 25.30239296], [89.00583649, 25.30280495], [89.00578308, 25.30297089], [89.00706482, 25.30294609], [89.00722504, 25.3029232], [89.00850677, 25.30311203], [89.00861359, 25.3030777], [89.00887299, 25.30314064], [89.00895691, 25.30257988], [89.00904083, 25.3019104], [89.00917053, 25.30098724], [89.00933838, 25.29973984], [89.0093689, 25.29919624], [89.0093689, 25.2983551], [89.00932312, 25.29749298], [89.0092392, 25.29673004], [89.00914001, 25.29600716], [89.00902557, 25.29522324], [89.00897217, 25.29454613], [89.00891113, 25.29379654], [89.00886536, 25.29335976], [89.00876617, 25.29262924], [89.00869751, 25.2920723], [89.00865173, 25.29176712], [89.00862122, 25.29141617], [89.00857544, 25.29106331], [89.00846863, 25.29022408], [89.0083847, 25.28968811], [89.0083313, 25.28941154], [89.00827026, 25.28884888], [89.0082016, 25.28819466], [89.00799561, 25.28631783], [89.00787354, 25.28577614], [89.00780487, 25.28536797], [89.00773621, 25.28464699], [89.00763702, 25.2840519], [89.00749969, 25.28308105], [89.00737762, 25.28264809], [89.00727081, 25.28211212], [89.00727081, 25.28169441], [89.00724792, 25.28117561], [89.00717926, 25.28081131], [89.00712585, 25.28040695], [89.00714111, 25.2802906], [89.00760651, 25.27659988], [89.00724792, 25.2758007], [89.00702667, 25.27532959], [89.00671387, 25.27547646], [89.00670624, 25.27523232], [89.00671387, 25.27480125], [89.00650787, 25.27475357], [89.00645447, 25.27451515], [89.00645447, 25.27433777], [89.00675964, 25.27426338], [89.00680542, 25.27400398], [89.00666809, 25.27398682], [89.00667572, 25.27388], [89.00681305, 25.27387047], [89.00691223, 25.27307892], [89.00702667, 25.2724514], [89.00713348, 25.27180481], [89.00720978, 25.27133942], [89.00730133, 25.27070808], [89.00746155, 25.26980019], [89.00758362, 25.26907349], [89.00769043, 25.26841927], [89.00779724, 25.26789665], [89.00783539, 25.26765823], [89.00786591, 25.26746941], [89.00790405, 25.2671299], [89.00798798, 25.26637459], [89.0079422, 25.26566315], [89.00785828, 25.26503944], [89.00747681, 25.26513481], [89.00736237, 25.26513672], [89.00731659, 25.26489067], [89.00749207, 25.26484489], [89.00770569, 25.26478958], [89.00759125, 25.26374435], [89.00744629, 25.26371574], [89.00702667, 25.26370811], [89.00696564, 25.26353073], [89.00640869, 25.26358795], [89.00640869, 25.26375198], [89.00605011, 25.26383781], [89.00600433, 25.26376152], [89.0054245, 25.26387405], [89.00514984, 25.26398849], [89.00492859, 25.26407814], [89.00495911, 25.2642498], [89.00501251, 25.26455307], [89.00489807, 25.26459312], [89.00497437, 25.26486778], [89.00475311, 25.26493454], [89.00460815, 25.26497841], [89.00424194, 25.26538658], [89.00437927, 25.26601219], [89.00471497, 25.26625061], [89.00483704, 25.26634026], [89.00522614, 25.26753426], [89.00550842, 25.2688427], [89.00523376, 25.2691288], [89.00348663, 25.26901054], [89.00223541, 25.26905441], [89.00195313, 25.26928711], [89.00106049, 25.26941681], [89.00106049, 25.2694931], [89.00024414, 25.26945114], [89.00020599, 25.26933098], [88.99942017, 25.26934242], [88.9989624, 25.26923943], [88.99856567, 25.26930237], [88.99762726, 25.26917648], [88.99681091, 25.26919365], [88.99654388, 25.269701], [88.99643707, 25.26965141], [88.99586487, 25.27031326], [88.99569702, 25.27033997], [88.99493408, 25.27018547], [88.99473572, 25.27005196], [88.99442291, 25.27033234], [88.99420166, 25.27029228], [88.99410248, 25.27036858], [88.99395752, 25.27033424], [88.99391174, 25.27048874], [88.99347687, 25.27034378], [88.99312592, 25.27027702], [88.99310303, 25.27092934], [88.99317932, 25.27110481], [88.99295807, 25.27167892], [88.99278259, 25.27210999], [88.99303436, 25.27216148], [88.99289703, 25.27284241], [88.99247742, 25.27337646], [88.9923172, 25.27378845], [88.99213409, 25.27379227], [88.99183655, 25.27386856], [88.99175262, 25.2736969], [88.99150085, 25.27380562], [88.99140167, 25.27366066], [88.99060822, 25.27392006], [88.99041748, 25.2739315], [88.98989105, 25.274086], [88.98946381, 25.27416229], [88.9894104, 25.274086], [88.98882294, 25.27415085], [88.9887619, 25.274086], [88.98847961, 25.27413559], [88.98838806, 25.27401352], [88.9871521, 25.27457809], [88.986763, 25.27456665], [88.98627472, 25.27435493], [88.98631287, 25.27422523], [88.98664093, 25.27419281], [88.98649597, 25.27337265], [88.98634338, 25.27259254], [88.98592377, 25.27265167], [88.98566437, 25.27200127], [88.98508453, 25.2722683], [88.98500824, 25.271698], [88.98486328, 25.27108002], [88.98480225, 25.27083397], [88.98478699, 25.27066994], [88.98468781, 25.27058411], [88.98467255, 25.2703743], [88.98458862, 25.27036858], [88.98443604, 25.27036095], [88.98448181, 25.26991653], [88.98439026, 25.26983833], [88.98443604, 25.2696476], [88.98449707, 25.26943207], [88.98436737, 25.26937294], [88.9838562, 25.26915359], [88.9838562, 25.268713], [88.98387909, 25.26838303], [88.9832077, 25.26839066], [88.9831543, 25.26828957], [88.98254395, 25.26829147], [88.98253632, 25.268713], [88.98222351, 25.26869392], [88.9821167, 25.26844788], [88.98210907, 25.26794624], [88.98239899, 25.26789665], [88.98242188, 25.26774979], [88.9825592, 25.26771736], [88.98257446, 25.26760292], [88.98260498, 25.26740456], [88.98246765, 25.26729774], [88.98169708, 25.26730537], [88.98162079, 25.26718903], [88.98140717, 25.26725197], [88.98132324, 25.26680565], [88.98104095, 25.26589775], [88.98135376, 25.26581573], [88.98213196, 25.26560783], [88.98213959, 25.26529503], [88.98226929, 25.2652092], [88.98222351, 25.26499176], [88.98204041, 25.26495552], [88.9818573, 25.26482201], [88.98169708, 25.2648201], [88.9815979, 25.26481819], [88.98158264, 25.26489258], [88.98149109, 25.26494026], [88.98154449, 25.26507759], [88.98163605, 25.26530075], [88.98154449, 25.26538849], [88.98150635, 25.26558495], [88.98135376, 25.26559067], [88.98120117, 25.26532936], [88.98097992, 25.26531601], [88.98091888, 25.26486588], [88.98090363, 25.26478958], [88.98072052, 25.26475716], [88.98062897, 25.26459885], [88.98048401, 25.2645874], [88.98039246, 25.26428604], [88.98032379, 25.26425171], [88.98029327, 25.26410866], [88.98021698, 25.2640667], [88.97986603, 25.26409721], [88.97979736, 25.26374054], [88.97780609, 25.26403809], [88.97745514, 25.26349831], [88.97719574, 25.26358795], [88.97734833, 25.2639904], [88.97696686, 25.26412392], [88.97672272, 25.26420593], [88.97610474, 25.26418686], [88.97582245, 25.26415825], [88.97590637, 25.26349449], [88.9756546, 25.26343346], [88.97567749, 25.26267052], [88.97537231, 25.26263428], [88.97524261, 25.2615509], [88.97499084, 25.26078415], [88.97489929, 25.26065636], [88.97457886, 25.26022339], [88.9740448, 25.26031876], [88.97354126, 25.26030731], [88.97302246, 25.26028061], [88.97286987, 25.26026917], [88.97257996, 25.26020241], [88.97247314, 25.26029587], [88.97218323, 25.26035118], [88.97070313, 25.26047707], [88.97055817, 25.26012993], [88.97025299, 25.25919342], [88.97000122, 25.25867081], [88.96973419, 25.25799561], [88.9688797, 25.25802803], [88.96828461, 25.25793648], [88.96726227, 25.25796509], [88.96675873, 25.25741577], [88.96578217, 25.25680923], [88.96500397, 25.25646973], [88.96300507, 25.25565338], [88.96299744, 25.25557709], [88.96250153, 25.25543976], [88.96219635, 25.25548172], [88.96148682, 25.25557899], [88.96042633, 25.25555992], [88.95972443, 25.25541878], [88.95964813, 25.25534058], [88.95948029, 25.25527954], [88.95896912, 25.25444984], [88.95860291, 25.25454903], [88.95850372, 25.25451279], [88.95710754, 25.25488663], [88.95663452, 25.25497437], [88.95624542, 25.25515556], [88.95574951, 25.25446701], [88.95528412, 25.25397491], [88.9552002, 25.25376129], [88.95500946, 25.25359535], [88.95498657, 25.25348282], [88.95489502, 25.25342941], [88.95501709, 25.25271606], [88.95475769, 25.25263405], [88.9552002, 25.25191498], [88.95523071, 25.25085258], [88.95498657, 25.25031662], [88.95484161, 25.25000954], [88.95414734, 25.24963188], [88.95324707, 25.24902725], [88.95265961, 25.24835777], [88.95201111, 25.24748039], [88.95184326, 25.24657822], [88.95175934, 25.24615097], [88.95169067, 25.24558067], [88.95143127, 25.24374008], [88.95143127, 25.24329948], [88.95131683, 25.24230385], [88.95173645, 25.24146271], [88.95250702, 25.24018478], [88.95291138, 25.23968697], [88.95357513, 25.23886871], [88.95387268, 25.23835564], [88.95393372, 25.23784256], [88.95410156, 25.2377758], [88.95431519, 25.2371769], [88.95418549, 25.23695755], [88.95352936, 25.23609352], [88.95294189, 25.2358532], [88.95279694, 25.23549271], [88.95304871, 25.23536873], [88.95281219, 25.23502159], [88.95310974, 25.23463821], [88.95633698, 25.23046112], [88.9571228, 25.22657967], [88.95735931, 25.2234726], [88.95773315, 25.22324371], [88.95776367, 25.22250557], [88.95767975, 25.22198105], [88.95794678, 25.22104263], [88.95887756, 25.21960068], [88.9580307, 25.21871948], [88.95801544, 25.21834946], [88.95777893, 25.21713638], [88.95796204, 25.21676254], [88.95833588, 25.21696663], [88.95849609, 25.21660614], [88.95792389, 25.21549606], [88.95799255, 25.21450615], [88.95864105, 25.21305847], [88.95875549, 25.21298027], [88.95884705, 25.21282005], [88.9594574, 25.21299934], [88.95963287, 25.21221733], [88.95969391, 25.21195412], [88.9596405, 25.21150589], [88.96038818, 25.21107292], [88.96051788, 25.21118736], [88.96069336, 25.21096039], [88.96136475, 25.21059799], [88.96162415, 25.20919991], [88.96170807, 25.20916557], [88.96151733, 25.20867538], [88.96128845, 25.20866585], [88.96122742, 25.20837593], [88.96104431, 25.20827484], [88.96071625, 25.20837021], [88.9600296, 25.20837212], [88.95954132, 25.20855522], [88.95942688, 25.20843887], [88.95936584, 25.20813942], [88.95850372, 25.20895576], [88.95839691, 25.20891953], [88.95783234, 25.20919418], [88.95690155, 25.20837784], [88.95641327, 25.2082653], [88.95632935, 25.20829201], [88.95624542, 25.20820618], [88.95578003, 25.20826149], [88.95561218, 25.20791817], [88.95556641, 25.20723343], [88.95513153, 25.20695496], [88.95503998, 25.20681953], [88.95458221, 25.20671844], [88.95397949, 25.20679092], [88.95392609, 25.20685959], [88.95347595, 25.20693398], [88.9533844, 25.20687675], [88.95323181, 25.20688438], [88.95285034, 25.20715523], [88.95217133, 25.20715523], [88.95219421, 25.20755959], [88.95195007, 25.20779228], [88.95147705, 25.20672798], [88.95106506, 25.20678902], [88.95110321, 25.20718575], [88.95081329, 25.20720673], [88.95067596, 25.20641708], [88.95004272, 25.20645142], [88.95000458, 25.2066288], [88.94934845, 25.20664787], [88.94928741, 25.20672989], [88.94902039, 25.20677185], [88.94892883, 25.20683098], [88.94845581, 25.20686913], [88.94838715, 25.20700836], [88.94803619, 25.20698929], [88.94741821, 25.20676422], [88.94629669, 25.20677567], [88.94626617, 25.20668793], [88.94532013, 25.20660591], [88.9443512, 25.20622444], [88.94358063, 25.20648956], [88.94355774, 25.20676994], [88.94347382, 25.20682335], [88.94353485, 25.20731354], [88.94326782, 25.20745087], [88.94326019, 25.20800972], [88.94332123, 25.2084713], [88.94335937, 25.2088089], [88.94269562, 25.20947266], [88.94194794, 25.20886803], [88.94184113, 25.20895767], [88.94161224, 25.20898628], [88.94160461, 25.20938873], [88.94142914, 25.2094841], [88.94148254, 25.21004295], [88.9412384, 25.21009254], [88.94125366, 25.21033478], [88.94064331, 25.21043205], [88.94055939, 25.2104435], [88.94055939, 25.21026802], [88.94036102, 25.21024323], [88.94012451, 25.21028709], [88.93923187, 25.21019554], [88.93929291, 25.2109623], [88.93886566, 25.21100044], [88.93885803, 25.21164513], [88.93797302, 25.21184921], [88.93790436, 25.21146965], [88.93751526, 25.21149254], [88.93745422, 25.21105194], [88.93699646, 25.21100616], [88.93697357, 25.2107048], [88.93640137, 25.21063423], [88.93671417, 25.20993233], [88.93663788, 25.20956993], [88.93656158, 25.20897865], [88.93638611, 25.20852089], [88.93631744, 25.20820808], [88.93630981, 25.20729637], [88.93626404, 25.20689392], [88.9360199, 25.20565605], [88.93621063, 25.20495605], [88.93665314, 25.20454025], [88.93672943, 25.20419312], [88.93704987, 25.20369911], [88.93698883, 25.20332909], [88.93689728, 25.20270538], [88.93637085, 25.20248985], [88.93604279, 25.20222092], [88.93589783, 25.20210266], [88.93543243, 25.20172882], [88.93501282, 25.20147514], [88.93468475, 25.2012825], [88.93383026, 25.19990158], [88.9340744, 25.19969559], [88.93413544, 25.19951439], [88.93457031, 25.19821167], [88.93500519, 25.19732666], [88.93515015, 25.19702339], [88.93569183, 25.19666862], [88.93588257, 25.19654083], [88.9360733, 25.19629288], [88.93692017, 25.19508934], [88.93706512, 25.19532585], [88.93789673, 25.19451332], [88.93787384, 25.19428253], [88.93781281, 25.19361496], [88.93830872, 25.19354439], [88.93901062, 25.19343376], [88.94011688, 25.19331741], [88.94021606, 25.19322014], [88.94055176, 25.19312668], [88.94368744, 25.19318771], [88.9438858, 25.19325638], [88.94583893, 25.19395828], [88.94618225, 25.19408035], [88.94700623, 25.19437599], [88.94727325, 25.19447327], [88.94750214, 25.19455338], [88.94746399, 25.19443893], [88.94717407, 25.19341087], [88.94696045, 25.19266129], [88.94676971, 25.19201088], [88.94680786, 25.18953514], [88.94711304, 25.18888664], [88.94772339, 25.18757248], [88.94776917, 25.18747139], [88.94680023, 25.18658829], [88.94619751, 25.18603325], [88.94387817, 25.18429375], [88.94384766, 25.18420219], [88.94351959, 25.18320084], [88.94359589, 25.18310547], [88.9440918, 25.1829567], [88.945755, 25.18245506], [88.94845581, 25.18163681], [88.94959259, 25.18129158], [88.94862366, 25.17962074], [88.94847107, 25.17935181], [88.94845581, 25.17879677], [88.94842529, 25.17725754], [88.94841766, 25.17687416], [88.94841766, 25.17660713], [88.94841003, 25.17643166], [88.94623566, 25.17676926], [88.9458313, 25.1768322], [88.94522095, 25.17617416], [88.94415283, 25.17502213], [88.94322205, 25.17358208], [88.94174194, 25.17360115], [88.94126129, 25.17360878], [88.94102478, 25.17361069], [88.94104004, 25.17378044], [88.9412384, 25.17601776], [88.94109344, 25.17604637], [88.93926239, 25.1764431], [88.9392395, 25.1770649], [88.93922424, 25.1775341], [88.9389267, 25.17929268], [88.9369812, 25.18041229], [88.93427277, 25.18148613], [88.93417358, 25.18152809], [88.93328094, 25.1813488], [88.93050385, 25.17861176], [88.93040466, 25.17852974], [88.929039, 25.17744637], [88.9280014, 25.17648506], [88.9276886, 25.17620087], [88.9287262, 25.17498016], [88.92899323, 25.17466545], [88.92804718, 25.17466927], [88.92711639, 25.17467499], [88.92671204, 25.17430115], [88.92664337, 25.17424202], [88.92498779, 25.17270851], [88.92444611, 25.17221451], [88.92418671, 25.17197227], [88.92411041, 25.17166519], [88.92405701, 25.17142677], [88.92389679, 25.16937447], [88.92378998, 25.16897964], [88.92351532, 25.16801071], [88.92314911, 25.16672897], [88.92301941, 25.16500664], [88.92105865, 25.16567993], [88.92088318, 25.16578865], [88.91861725, 25.16723633], [88.91835022, 25.16740608], [88.91635132, 25.16723442], [88.91400909, 25.16703224], [88.91233063, 25.16806412], [88.91233826, 25.16856956], [88.91236877, 25.17043304], [88.91265869, 25.17335129], [88.91234589, 25.17422867], [88.91241455, 25.17517662], [88.91256714, 25.17737007], [88.91261292, 25.17802048], [88.91179657, 25.17827034], [88.91124725, 25.17843819], [88.9112854, 25.1787529], [88.9114151, 25.17987633], [88.91127014, 25.18003273], [88.91010284, 25.1801796], [88.90931702, 25.17995262], [88.90885925, 25.17981911], [88.90648651, 25.17965317], [88.90632629, 25.17887115], [88.90630341, 25.17874527], [88.90617371, 25.17877769], [88.90503693, 25.17907143], [88.90444183, 25.17922592], [88.90351868, 25.17946625], [88.90093994, 25.18006134], [88.90081024, 25.18013763], [88.90062714, 25.18024635], [88.89889526, 25.18127441], [88.89891815, 25.18151855], [88.89899445, 25.1825428], [88.89694214, 25.18282318], [88.89320374, 25.18332863], [88.89268494, 25.18440628], [88.89073944, 25.18461227], [88.89067078, 25.18418121], [88.89084625, 25.18264008], [88.89086151, 25.18251038], [88.89096069, 25.18122101], [88.88989258, 25.18010712], [88.88981628, 25.1784687], [88.88952637, 25.17852402], [88.88844299, 25.17873383], [88.8865509, 25.17909813], [88.88641357, 25.17910957], [88.88509369, 25.17921257], [88.88439178, 25.17926598], [88.88119507, 25.17926407], [88.8783493, 25.17910957], [88.87582397, 25.17897224], [88.87521362, 25.17946243], [88.87522125, 25.1795578], [88.87533569, 25.18131447], [88.87532043, 25.18210602], [88.87532043, 25.18257523], [88.87528229, 25.18524933], [88.87434387, 25.18753624], [88.87319183, 25.18870926], [88.87284088, 25.18906975], [88.87281036, 25.18918228], [88.8735733, 25.19087982], [88.87388611, 25.19157219], [88.87379456, 25.19174194], [88.87320709, 25.19277954], [88.87302399, 25.1931076], [88.87291718, 25.19329643], [88.87302399, 25.1933136], [88.87355804, 25.19340515], [88.87368011, 25.19342613], [88.87486267, 25.19362831], [88.87486267, 25.19374275], [88.87486267, 25.19511032], [88.8748703, 25.19632721], [88.87465668, 25.19631577], [88.87404633, 25.19627762], [88.87394714, 25.1962719], [88.87397766, 25.19526863], [88.87399292, 25.19492531], [88.87178802, 25.19487381], [88.87149811, 25.19486809], [88.87146759, 25.19263268], [88.8714447, 25.19152832], [88.868927, 25.19108963], [88.86873627, 25.19106865], [88.86828613, 25.19051361], [88.86778259, 25.18989563], [88.86764526, 25.18987656], [88.86724091, 25.18982506], [88.86546326, 25.18959999], [88.86407471, 25.19023895], [88.86421204, 25.19082832], [88.86447144, 25.19190407], [88.8645401, 25.19261742], [88.86467743, 25.19393539], [88.86496735, 25.19543648], [88.8651123, 25.19619179], [88.86471558, 25.19827843], [88.86487579, 25.20070267], [88.86388397, 25.20078659], [88.86357117, 25.2008152], [88.86356354, 25.20141792], [88.85942841, 25.20175934], [88.85749817, 25.20148277], [88.85726166, 25.20124054], [88.85651398, 25.20084381], [88.85477448, 25.19992638], [88.85317993, 25.20067215], [88.85303497, 25.20067024], [88.85176849, 25.20064163], [88.85155487, 25.20063591], [88.85150909, 25.20102882], [88.85147095, 25.20139503], [88.85135651, 25.20142555], [88.84967804, 25.20185661], [88.84925079, 25.20423126], [88.84858704, 25.20646095], [88.84864807, 25.20711136], [88.84879303, 25.20849991], [88.84906769, 25.20887566], [88.84783936, 25.21014023], [88.84490967, 25.21120071], [88.84246063, 25.2111702], [88.84218597, 25.21103859], [88.84230804, 25.21072197], [88.84159088, 25.2107563], [88.8400116, 25.21001053], [88.83786011, 25.20903969], [88.83670044, 25.20852852], [88.83669281, 25.20694351], [88.83669281, 25.20627785], [88.8321991, 25.20662689], [88.83172607, 25.20666313], [88.83041382, 25.20545387], [88.82949829, 25.2017498], [88.82905579, 25.20023727], [88.82832336, 25.19774246], [88.82830048, 25.19766426], [88.8272171, 25.19366264], [88.82707977, 25.19316864], [88.82691956, 25.19259071], [88.82667542, 25.19226265], [88.82578278, 25.19104767], [88.82305145, 25.19109535], [88.82278442, 25.19110107], [88.82272339, 25.19031906], [88.82266998, 25.1896019], [88.82139587, 25.19026184], [88.82087708, 25.1898613], [88.82077789, 25.18860054], [88.81946564, 25.18877602], [88.81785583, 25.18899155], [88.81743622, 25.18717766], [88.81719208, 25.18583298], [88.81492615, 25.18507195], [88.81482697, 25.18503761], [88.81479645, 25.18482971], [88.81462097, 25.18367958], [88.8142395, 25.18082047], [88.81371307, 25.17702675], [88.81344604, 25.17508316], [88.81343079, 25.1749649], [88.81333923, 25.17436218], [88.8106842, 25.1742897], [88.80999756, 25.17427063], [88.80924988, 25.17405891], [88.80912781, 25.17349434], [88.80908203, 25.17325783], [88.80723572, 25.17340851], [88.80605316, 25.1728096], [88.80590057, 25.17277527], [88.8058548, 25.17121506], [88.80583954, 25.17054939], [88.80115509, 25.17089272], [88.79954529, 25.17111778], [88.79836273, 25.17128181], [88.79522705, 25.17241096], [88.79302216, 25.1727314], [88.79089355, 25.17386055], [88.78903198, 25.17460442], [88.78591919, 25.17581177], [88.7828064, 25.1764946], [88.77896881, 25.17786598], [88.77548981, 25.17891693], [88.77360535, 25.17946434], [88.77392578, 25.18135071], [88.7740097, 25.18185806], [88.77398682, 25.182127], [88.77388763, 25.18350983], [88.77409363, 25.18546104], [88.77215576, 25.1856575], [88.77216339, 25.1873951], [88.77275848, 25.18949318], [88.77121735, 25.1896801], [88.7706604, 25.18925095], [88.7702713, 25.1875], [88.77017975, 25.18741035], [88.76837158, 25.18733788], [88.76809692, 25.18596458], [88.76803589, 25.18567657], [88.76696014, 25.18325615], [88.76344299, 25.18410301], [88.76055908, 25.18541527], [88.75909424, 25.18579674], [88.75894928, 25.18607521], [88.75734711, 25.18424034], [88.75672913, 25.18297005], [88.75563049, 25.1805706], [88.75430298, 25.17821121], [88.75254059, 25.17791748], [88.75203705, 25.17782974], [88.75170898, 25.17817688], [88.75110626, 25.17778587], [88.75000763, 25.17705727], [88.74871063, 25.17708397], [88.74880981, 25.17764854], [88.74894714, 25.17852211], [88.74918365, 25.17995453], [88.74945831, 25.18176842], [88.74921417, 25.18227768], [88.74893951, 25.18205452], [88.74533844, 25.18288803], [88.74512482, 25.18357277], [88.74465942, 25.18507385], [88.74279785, 25.18663216], [88.74238586, 25.18662834], [88.74016571, 25.18514252], [88.73453522, 25.1846981], [88.73458099, 25.18493652], [88.73512268, 25.18788338], [88.7352066, 25.18831062], [88.73525238, 25.18854713], [88.73538971, 25.18927193], [88.73519897, 25.18982887], [88.73497009, 25.19048309], [88.7334671, 25.19115448], [88.73355865, 25.191576], [88.73417664, 25.19445038], [88.73419952, 25.19454384], [88.7342453, 25.19490242], [88.73277283, 25.19599533], [88.73308563, 25.19711304], [88.73327637, 25.19781494], [88.73332214, 25.19955826], [88.7333374, 25.20001793], [88.73284149, 25.20010376], [88.73071289, 25.20047379], [88.73008728, 25.20017052], [88.72882843, 25.19956398], [88.72528839, 25.19900894], [88.72425079, 25.19964218], [88.72419739, 25.20172501], [88.72395325, 25.20241165], [88.72367859, 25.20258522], [88.72316742, 25.20262146], [88.72067261, 25.20246315], [88.71907043, 25.20219421], [88.71791077, 25.20199776], [88.71781158, 25.20217705], [88.71721649, 25.20328331], [88.71692657, 25.20355225], [88.71536255, 25.20499992], [88.71494293, 25.20708275], [88.71138763, 25.20745468], [88.70787048, 25.2079525], [88.70448303, 25.20828819], [88.70227814, 25.20738983], [88.6989212, 25.20801735], [88.69459534, 25.20776939], [88.68945313, 25.20793915], [88.68824768, 25.20734406], [88.68756866, 25.20755386], [88.68759918, 25.20770836], [88.68773651, 25.20842934], [88.68788147, 25.20920563], [88.68732452, 25.20949364], [88.68441772, 25.20923615], [88.6807785, 25.20905876], [88.67999268, 25.20902061], [88.67913055, 25.20738029], [88.67834473, 25.20670509], [88.67823792, 25.20661545], [88.67801666, 25.20556259], [88.67796326, 25.20532799], [88.67848969, 25.2052021], [88.67925262, 25.2050209], [88.67873383, 25.20457458], [88.67832184, 25.20328331], [88.67667389, 25.20281982], [88.67588043, 25.20215034], [88.67433167, 25.19975281], [88.67266846, 25.19852829], [88.66969299, 25.19829941], [88.66934967, 25.19834137], [88.66818237, 25.19848442], [88.6672821, 25.19859314], [88.66701508, 25.19960403], [88.66688538, 25.20010185], [88.66680908, 25.20039177], [88.6667099, 25.2007885], [88.66668701, 25.20088768], [88.6665802, 25.20088387], [88.66523743, 25.20082092], [88.66547394, 25.20199203], [88.66544342, 25.2020874], [88.66381073, 25.20281982], [88.65927124, 25.20266533], [88.6546936, 25.20370102], [88.65460968, 25.20370674], [88.65388489, 25.20376396], [88.65132141, 25.20396423], [88.64703369, 25.20437622], [88.64685059, 25.20491791], [88.64603424, 25.20502663], [88.64539337, 25.20511055], [88.64459229, 25.20521545], [88.64281464, 25.20642853], [88.641716, 25.20584106], [88.64155579, 25.20575714], [88.63851929, 25.20475578], [88.63847351, 25.20465851], [88.63801575, 25.20355034], [88.63650513, 25.20361328], [88.6353302, 25.2033329], [88.63407135, 25.20275497], [88.63279724, 25.20217896], [88.63178253, 25.20219231], [88.63098907, 25.20176697], [88.63036346, 25.20195198], [88.62979889, 25.20225906], [88.62931061, 25.20215607], [88.62902069, 25.20176697], [88.62814331, 25.20185471], [88.62749481, 25.20242119], [88.62697601, 25.20287514], [88.62662506, 25.20375061], [88.62612152, 25.20428085], [88.62471008, 25.20455551], [88.62288666, 25.20419502], [88.62212372, 25.20430183], [88.62098694, 25.20505524], [88.62020111, 25.20525932], [88.61920166, 25.20512962], [88.61875916, 25.2050724], [88.61865997, 25.20497322], [88.61814117, 25.20444489], [88.61746216, 25.20401764], [88.61696625, 25.20385551], [88.61610413, 25.20357704], [88.61530304, 25.20383644], [88.61448669, 25.20380974], [88.61299133, 25.2042923], [88.61264038, 25.20395088], [88.61222839, 25.20360947], [88.61186218, 25.20281792], [88.6115799, 25.20227432], [88.61147308, 25.20200729], [88.61121368, 25.20135307], [88.61126709, 25.20047379], [88.61096191, 25.19964981], [88.61082458, 25.19943047], [88.61034393, 25.1986866], [88.61006165, 25.19861031], [88.60926056, 25.19838905], [88.60856628, 25.19796371], [88.60835266, 25.19774818], [88.60751343, 25.19688988], [88.60564423, 25.19597435], [88.60515594, 25.19586372], [88.60464478, 25.19536591], [88.60469818, 25.19513321], [88.60399628, 25.19442177], [88.6036911, 25.19446754], [88.60177612, 25.19360161], [88.60024261, 25.1927433], [88.59832764, 25.19165611], [88.59772491, 25.19099998], [88.59675598, 25.19118118], [88.59468079, 25.19205093], [88.59342194, 25.19256401], [88.59288788, 25.19321251], [88.59265137, 25.19350243], [88.59170532, 25.19409561], [88.59144592, 25.19395065], [88.59118652, 25.19009018], [88.59111786, 25.18950272], [88.59107208, 25.18909836], [88.59118652, 25.18771553], [88.59148407, 25.18754196], [88.59190369, 25.18729401], [88.59144592, 25.18690491], [88.59113312, 25.18519402], [88.58972168, 25.18539238], [88.58959198, 25.18527985], [88.58869171, 25.18494415], [88.58824158, 25.18389511], [88.58818054, 25.18374062], [88.58691406, 25.18234253], [88.58635712, 25.18230247], [88.58370972, 25.18211746], [88.58304596, 25.18206978], [88.58268738, 25.18210602], [88.58242798, 25.18194962], [88.5814209, 25.18053818], [88.58100891, 25.1802063], [88.58096313, 25.17996979], [88.57990265, 25.17912483], [88.57980347, 25.1784153], [88.57965851, 25.17748451], [88.5796051, 25.17711258], [88.57957458, 25.17690659], [88.57597351, 25.17724419], [88.57568359, 25.17727089], [88.57556152, 25.17707443], [88.57499695, 25.17617989], [88.57422638, 25.17640114], [88.57354736, 25.17657089], [88.57254791, 25.17681885], [88.57208252, 25.17693329], [88.57161713, 25.17704773], [88.57146454, 25.17738152], [88.5711441, 25.17746162], [88.57078552, 25.17588806], [88.56636047, 25.17600441], [88.56480408, 25.17461586], [88.55989838, 25.17658043], [88.55764008, 25.17774963], [88.55556488, 25.1790657], [88.5556488, 25.18033981], [88.55580902, 25.18050957], [88.55711365, 25.18187904], [88.55800629, 25.18281937], [88.55882263, 25.18367958], [88.55908966, 25.18395996], [88.55970001, 25.18460464], [88.55963898, 25.18555832], [88.55949402, 25.18773842], [88.55968475, 25.18914795], [88.55989075, 25.19073677], [88.55992889, 25.19098473], [88.55983734, 25.19104958], [88.55757141, 25.1927166], [88.55552673, 25.19332123], [88.55371094, 25.19295883], [88.55266571, 25.19343185], [88.55195618, 25.19366455], [88.55094147, 25.19399643], [88.55068207, 25.19408035], [88.54821014, 25.19523239], [88.54802704, 25.19531631], [88.54776001, 25.19497681], [88.54692841, 25.19393921], [88.54658508, 25.19350624], [88.5456543, 25.19371033], [88.54432678, 25.19400215], [88.5442276, 25.19402313], [88.54304504, 25.19402313], [88.54243469, 25.19402313], [88.54216003, 25.19371033], [88.54160309, 25.19302368], [88.54123688, 25.19207573], [88.54108429, 25.19116402], [88.54073334, 25.18910789], [88.5388031, 25.18936157], [88.53862762, 25.18938446], [88.53833008, 25.18917656], [88.5377121, 25.18874741], [88.53754425, 25.18862915], [88.53761292, 25.18722343], [88.53694153, 25.18737984], [88.53610992, 25.18757248], [88.53504944, 25.18781853], [88.53408813, 25.18804169], [88.53392029, 25.18807983], [88.53374481, 25.18834305], [88.53359222, 25.18856049], [88.53351593, 25.18867302], [88.53354645, 25.1887722], [88.53414154, 25.19117928], [88.53384399, 25.19174194], [88.5335083, 25.19235992], [88.53292084, 25.1934433], [88.53292084, 25.1945076], [88.53384399, 25.19500542], [88.53424072, 25.19556999], [88.53450012, 25.19668961], [88.53553772, 25.19763947], [88.5361557, 25.19801331], [88.5343399, 25.19811821], [88.53421021, 25.19812584], [88.53234863, 25.19845772], [88.53065491, 25.19876099], [88.5302887, 25.19884491], [88.52945709, 25.19903564], [88.52568054, 25.19990158], [88.51997375, 25.2006588], [88.51818848, 25.20124245], [88.51543427, 25.20186615], [88.50817108, 25.20314598], [88.50788116, 25.20319748], [88.5051651, 25.20313835], [88.50447845, 25.203125], [88.50059509, 25.20340729], [88.50017548, 25.20363617], [88.49974823, 25.20386505], [88.49990082, 25.20697975], [88.49995422, 25.20803642], [88.49967957, 25.20883751], [88.49915314, 25.21032906], [88.49909973, 25.21049309], [88.49866486, 25.21050644], [88.49723816, 25.2105484], [88.49691772, 25.21055794], [88.49568939, 25.2105484], [88.49466705, 25.21054077], [88.49131012, 25.21076775], [88.48838043, 25.21113586], [88.48616028, 25.21170044], [88.48377228, 25.21195793], [88.48304749, 25.21197701], [88.48294067, 25.21198082], [88.48291016, 25.21149063], [88.48288727, 25.21101952], [88.47995758, 25.21151161], [88.47982788, 25.21172714], [88.47907257, 25.21297836], [88.47893524, 25.2132206], [88.47773743, 25.21331024], [88.47609711, 25.21219063], [88.47502899, 25.2102108], [88.47439575, 25.20885277], [88.47433472, 25.2087307], [88.47422028, 25.20848465], [88.47406006, 25.20762253], [88.47349548, 25.2069664], [88.47344971, 25.20687485], [88.47276306, 25.20545959], [88.47155762, 25.20366096], [88.47149658, 25.20160103], [88.47148132, 25.20116043], [88.47260284, 25.20018005], [88.47292328, 25.19898987], [88.47203827, 25.19828224], [88.47202301, 25.19809723], [88.47198486, 25.19762993], [88.47045898, 25.19760895], [88.4691925, 25.19759178], [88.46893311, 25.19758797], [88.46920013, 25.19730186], [88.46963501, 25.19683838], [88.46852875, 25.19713783], [88.46757507, 25.19739342], [88.46604156, 25.1965313], [88.46337128, 25.19502449], [88.46094513, 25.19570351], [88.45843506, 25.19572449], [88.45574188, 25.19617081], [88.45137787, 25.1968956], [88.44896698, 25.19727707], [88.44709015, 25.19757271], [88.44692993, 25.1975975], [88.44690704, 25.19732857], [88.44684601, 25.19672585], [88.44460297, 25.19695854], [88.444664, 25.19729233], [88.44364166, 25.19739151], [88.44425201, 25.19618988], [88.44554901, 25.19608116], [88.44384003, 25.19489098], [88.44394684, 25.19279289], [88.44436646, 25.18949127], [88.44442749, 25.18677139], [88.4446106, 25.18556976], [88.44641113, 25.18175125], [88.44677734, 25.18066978], [88.44671631, 25.17982101], [88.44476318, 25.17683029], [88.44568634, 25.1753006], [88.45025635, 25.17263031], [88.45149994, 25.17057991], [88.4526825, 25.16789818], [88.45404816, 25.16646194], [88.45656586, 25.16560555], [88.45687866, 25.16565514], [88.4569931, 25.16541672], [88.45842743, 25.16477966], [88.45935822, 25.16267014], [88.46084595, 25.15929985], [88.46109009, 25.15788078], [88.46044922, 25.15545082], [88.46157074, 25.1540699], [88.46299744, 25.15122032], [88.46218109, 25.14719963], [88.46264648, 25.14203072], [88.46238708, 25.14010048], [88.45923615, 25.1350708], [88.45530701, 25.13276291], [88.45144653, 25.13049126], [88.44757843, 25.12881088], [88.4473877, 25.12819672], [88.44594574, 25.12810326], [88.4458313, 25.12803841], [88.44468689, 25.12802315], [88.44199371, 25.12771606], [88.44135284, 25.12764359], [88.44152832, 25.12661552], [88.44178772, 25.12514687], [88.44191742, 25.12438583], [88.44261932, 25.12052917], [88.44295502, 25.1186924], [88.44299316, 25.11848831], [88.44210052, 25.11524582], [88.44205475, 25.11507034], [88.44271088, 25.11475945], [88.44364166, 25.11432457], [88.44541931, 25.11348534], [88.44555664, 25.11317635], [88.44705963, 25.10802078], [88.44708252, 25.10794258], [88.44657898, 25.10652161], [88.44618988, 25.10543633], [88.44597626, 25.1048336], [88.44472504, 25.10312271], [88.44445801, 25.10275459], [88.44437408, 25.10244179], [88.44386292, 25.10050201], [88.44405365, 25.09980774], [88.44509125, 25.09758186], [88.44517517, 25.09739494], [88.44553375, 25.09585953], [88.4461441, 25.09449387], [88.44645691, 25.09378624], [88.44638062, 25.09262848], [88.44702148, 25.09059143], [88.44718933, 25.09006882], [88.44711304, 25.08869171], [88.44710541, 25.08860016], [88.44631958, 25.08785057], [88.44632721, 25.08731079], [88.44655609, 25.08733368], [88.44768524, 25.08739853], [88.44790649, 25.08742905], [88.44795227, 25.08550262], [88.44832611, 25.08378983], [88.44893646, 25.08197021], [88.45030975, 25.08077049], [88.45199585, 25.07978058], [88.45240021, 25.07954407], [88.45285797, 25.079422], [88.45281219, 25.07930565], [88.45240784, 25.07825661], [88.45214844, 25.0775795], [88.45096588, 25.07451248], [88.4478302, 25.0705719], [88.44706726, 25.06962013], [88.4454422, 25.06758118], [88.44536591, 25.06742096], [88.44449615, 25.06531906], [88.44435883, 25.06344986], [88.44365692, 25.06118011], [88.44114685, 25.05836105], [88.4382019, 25.05630112], [88.4370575, 25.05387115], [88.4365387, 25.05018044], [88.43710327, 25.0467701], [88.43914795, 25.04368019], [88.44145203, 25.0424614], [88.44294739, 25.04259491], [88.44406891, 25.04230309], [88.44495392, 25.0420742], [88.44808197, 25.04195023], [88.45133209, 25.04141045], [88.45289612, 25.04090118], [88.45381927, 25.03866005], [88.45381165, 25.03560066], [88.45173645, 25.03373909], [88.4486084, 25.03309059], [88.44724274, 25.0326519], [88.44680786, 25.03131104], [88.44647217, 25.03021812], [88.44626617, 25.02783012], [88.44621277, 25.02709961], [88.44564819, 25.02634048], [88.44457245, 25.0248394], [88.44256592, 25.02275848], [88.44149017, 25.02094078], [88.44142151, 25.02074623], [88.44154358, 25.02028275], [88.44139862, 25.01961136], [88.44104767, 25.01900482], [88.44083405, 25.01900673], [88.4407959, 25.01890182], [88.44056702, 25.01795959], [88.44123077, 25.01802254], [88.4412384, 25.01731682], [88.44030762, 25.0168972], [88.44009399, 25.01679993], [88.43867493, 25.01666832], [88.43793488, 25.01655579], [88.4373703, 25.01647377], [88.43713379, 25.01583862], [88.43770599, 25.01550102], [88.4380722, 25.01553917], [88.43857574, 25.01558876], [88.43902588, 25.01563263], [88.43998718, 25.01556778], [88.4401474, 25.01556396], [88.44061279, 25.01485634], [88.4406662, 25.01477814], [88.44132233, 25.01383209], [88.4417038, 25.01349068], [88.44193268, 25.0132885], [88.44161987, 25.01225662], [88.44043732, 25.01144981], [88.44016266, 25.01154518], [88.43988037, 25.01148033], [88.43978119, 25.01229668], [88.43983459, 25.01251602], [88.44000244, 25.01325798], [88.43981171, 25.01342773], [88.43947601, 25.01335907], [88.43930054, 25.01332283], [88.43889618, 25.01211929], [88.43824768, 25.01017952], [88.43788147, 25.00912094], [88.43656158, 25.00658417], [88.43645477, 25.00650597], [88.43608856, 25.00622177], [88.435112, 25.00589371], [88.43474579, 25.00577164], [88.43384552, 25.00551033], [88.43323517, 25.00590324], [88.4330368, 25.00609779], [88.43017578, 25.0073204], [88.42724609, 25.00762939], [88.42549896, 25.007164], [88.42540741, 25.00670052], [88.4250946, 25.00654411], [88.42427063, 25.00676155], [88.42416382, 25.00678825], [88.42201996, 25.00704002], [88.42167664, 25.00656128], [88.42149353, 25.00631142], [88.42124939, 25.00549698], [88.4212265, 25.00474739], [88.4212265, 25.00448418], [88.4209137, 25.00413132], [88.42036438, 25.00397491], [88.42032623, 25.00374222], [88.42055511, 25.00353432], [88.4203186, 25.0032444], [88.41989899, 25.00272179], [88.41924286, 25.00190544], [88.41954041, 25.00160789], [88.420578, 25.00053406], [88.42046356, 24.99967384], [88.41808319, 24.99871063], [88.41577148, 24.99843025], [88.41527557, 24.99836922], [88.4123764, 24.99904442], [88.41236877, 24.99894524], [88.41230774, 24.99708748], [88.41204834, 24.99629402], [88.41199493, 24.99614334], [88.41343689, 24.99691963], [88.41360474, 24.99700928], [88.41378784, 24.99669838], [88.4144516, 24.99555016], [88.41461182, 24.99526978], [88.41445923, 24.99459267], [88.41307068, 24.99185181], [88.41290283, 24.9909935], [88.41277313, 24.99032974], [88.41259766, 24.9896965], [88.41249847, 24.9893322], [88.41238403, 24.98890877], [88.41197205, 24.98656654], [88.4118576, 24.98590279], [88.41177368, 24.98542213], [88.41207123, 24.9851017], [88.41365051, 24.98526001], [88.41427612, 24.98532104], [88.41641235, 24.98523331], [88.41660309, 24.98522568], [88.41656494, 24.98513603], [88.41632843, 24.98455811], [88.41667938, 24.98407555], [88.41790009, 24.98389816], [88.41860962, 24.98340607], [88.41874695, 24.98331451], [88.41864777, 24.98306656], [88.41854095, 24.98279572], [88.41796112, 24.9824276], [88.41738129, 24.98242188], [88.41701508, 24.98241806], [88.41600037, 24.9829216], [88.41530609, 24.98327827], [88.41415405, 24.98324585], [88.41304779, 24.983078], [88.41246033, 24.98253441], [88.41230011, 24.98237801], [88.41249847, 24.98199654], [88.41377258, 24.98126221], [88.41435242, 24.98092842], [88.41501617, 24.98100471], [88.41531372, 24.98086357], [88.41505432, 24.98052597], [88.41549683, 24.98018837], [88.416008, 24.98045349], [88.41621399, 24.98054886], [88.41629791, 24.98032761], [88.41694641, 24.97715378], [88.41683197, 24.97665024], [88.41667938, 24.97599792], [88.41699982, 24.97553825], [88.41738892, 24.97498131], [88.4173584, 24.97398949], [88.41616821, 24.97270012], [88.41410065, 24.97232056], [88.41210175, 24.97318077], [88.41186523, 24.97343826], [88.41086578, 24.97358131], [88.41069794, 24.97439766], [88.41053009, 24.97486305], [88.41017151, 24.97525024], [88.40849304, 24.97578049], [88.4072876, 24.97517967], [88.40579224, 24.97443962], [88.40472412, 24.97334671], [88.40572357, 24.97302246], [88.40588379, 24.97343636], [88.40628052, 24.9732914], [88.40620422, 24.97282219], [88.40604401, 24.97257805], [88.40567017, 24.97204781], [88.40530396, 24.97216225], [88.40531158, 24.97247696], [88.40463257, 24.97291756], [88.40415955, 24.97215652], [88.40415955, 24.97125435], [88.40398407, 24.97102737], [88.40315247, 24.97099876], [88.4028244, 24.97118759], [88.4030838, 24.97191811], [88.40387726, 24.97239876], [88.40383148, 24.97253609], [88.40203094, 24.97197914], [88.39997101, 24.97159958], [88.39834595, 24.96999168], [88.39797974, 24.96961975], [88.39746094, 24.96912003], [88.39663696, 24.96730995], [88.39612579, 24.96572113], [88.39604187, 24.96558571], [88.39626312, 24.96532249], [88.39620972, 24.96497917], [88.39600372, 24.96483994], [88.39589691, 24.96476555], [88.39559937, 24.96472359], [88.39548492, 24.96472931], [88.39525604, 24.96438026], [88.39515686, 24.96460724], [88.39511108, 24.96470833], [88.39492798, 24.96467781], [88.39464569, 24.96434975], [88.39418793, 24.96410561], [88.39388275, 24.96417046], [88.39360046, 24.96502876], [88.39352417, 24.96527672], [88.39287567, 24.96492386], [88.39292145, 24.96478653], [88.39323425, 24.96388245], [88.39299774, 24.96328163], [88.39290619, 24.96268845], [88.39293671, 24.96177101], [88.39315796, 24.96100807], [88.39343262, 24.96038055], [88.39388275, 24.96004295], [88.39457703, 24.95968628], [88.39512634, 24.95946312], [88.39560699, 24.95943069], [88.39583588, 24.95960426], [88.39594269, 24.95973015], [88.39608765, 24.95989418], [88.39639282, 24.9601841], [88.39687347, 24.96032333], [88.39752197, 24.96025276], [88.39796448, 24.9601059], [88.39855957, 24.95984459], [88.39900208, 24.95954323], [88.39910889, 24.95921898], [88.39903259, 24.9589119], [88.39880371, 24.95871925], [88.39851379, 24.95869637], [88.39835358, 24.95868683], [88.39810944, 24.95867348], [88.39756775, 24.95854187], [88.3973999, 24.95841789], [88.39737701, 24.95832253], [88.39730072, 24.95801544], [88.39735413, 24.95757675], [88.39743805, 24.9573288], [88.39813995, 24.95666695], [88.39865112, 24.95588875], [88.39907837, 24.95522499], [88.39941406, 24.95505714], [88.39951324, 24.95506859], [88.39979553, 24.95509911], [88.4002533, 24.95506477], [88.40044403, 24.95479965], [88.4003067, 24.9544735], [88.40010071, 24.95418358], [88.40010071, 24.95378304], [88.40039825, 24.95363426], [88.40084076, 24.953619], [88.40119934, 24.95331764], [88.40122223, 24.95293617], [88.40112305, 24.95264816], [88.40148926, 24.95221138], [88.40164185, 24.9517746], [88.40179443, 24.95085907], [88.4017868, 24.9503994], [88.40207672, 24.94966125], [88.40149689, 24.94569016], [88.39898682, 24.94299126], [88.3973465, 24.94210052], [88.39541626, 24.94104195], [88.39303589, 24.94111252], [88.39092255, 24.94112968], [88.38765717, 24.93849945], [88.38446808, 24.93777847], [88.38153839, 24.93882942], [88.38058472, 24.93979836], [88.37917328, 24.9412384], [88.37654877, 24.94263268], [88.3744278, 24.94185066], [88.37186432, 24.94242287], [88.37158203, 24.94227409], [88.37116241, 24.94227028], [88.37098694, 24.94239616], [88.37071228, 24.94259644], [88.37049866, 24.94316101], [88.37039185, 24.94335175], [88.37034607, 24.94388199], [88.37029266, 24.94445801], [88.37028503, 24.94479752], [88.37025452, 24.94568062], [88.37001801, 24.94594574], [88.36951447, 24.94594002], [88.36901855, 24.94564819], [88.36852264, 24.94537544], [88.36763, 24.9450531], [88.36753845, 24.94502068], [88.36734009, 24.94501305], [88.36720276, 24.94500923], [88.36671448, 24.94499207], [88.36636353, 24.94518089], [88.36628723, 24.94524193], [88.3658371, 24.94559479], [88.36511993, 24.94617844], [88.36505127, 24.94623566], [88.36483002, 24.94684601], [88.36501312, 24.94734383], [88.36568451, 24.94758034], [88.36598969, 24.9476757], [88.36582184, 24.94806099], [88.36581421, 24.94854736], [88.36472321, 24.94843102], [88.36412048, 24.94853783], [88.36388397, 24.94889832], [88.36393738, 24.94933891], [88.36443329, 24.95001221], [88.36525726, 24.95086288], [88.36572266, 24.95140648], [88.36606598, 24.95180893], [88.36620331, 24.95234489], [88.36618042, 24.95282173], [88.36598969, 24.95308685], [88.3658371, 24.95329666], [88.36539459, 24.95342636], [88.36462402, 24.95318794], [88.36360168, 24.95264053], [88.36287689, 24.95226097], [88.36274719, 24.95219231], [88.36265564, 24.95219421], [88.36201477, 24.95220375], [88.36138153, 24.95231056], [88.36064911, 24.95260811], [88.36006927, 24.95321465], [88.35952759, 24.95347595], [88.3587265, 24.95342827], [88.35826874, 24.95315552], [88.35796356, 24.95265579], [88.35803223, 24.95204544], [88.35842133, 24.95122719], [88.35901642, 24.95054626], [88.35986328, 24.95013428], [88.3600235, 24.95004654], [88.36043549, 24.94981575], [88.36032867, 24.94952774], [88.36013794, 24.94943047], [88.35991669, 24.94931412], [88.35945892, 24.94898415], [88.35806274, 24.94812775], [88.35732269, 24.94745064], [88.35669708, 24.94681358], [88.35614014, 24.9462719], [88.3558197, 24.94544601], [88.35543823, 24.94412422], [88.35507202, 24.94320297], [88.3549118, 24.94279289], [88.3547287, 24.94231987], [88.35428619, 24.94204712], [88.35369873, 24.94213104], [88.35306549, 24.94256783], [88.35243225, 24.94294357], [88.35177612, 24.94368172], [88.35088348, 24.94420624], [88.3507309, 24.94433784], [88.35037994, 24.94464111], [88.3497467, 24.94499779], [88.34911346, 24.94479942], [88.34861755, 24.94444847], [88.34851837, 24.94424248], [88.34837341, 24.94395065], [88.34798431, 24.94331551], [88.34754944, 24.94300461], [88.34709167, 24.94292259], [88.34610748, 24.94283485], [88.34510803, 24.94287109], [88.34490967, 24.94287872], [88.34429932, 24.94279671], [88.34390259, 24.9426384], [88.34320068, 24.94222832], [88.3425293, 24.94183922], [88.34099579, 24.94088554], [88.34020996, 24.94028473], [88.3397522, 24.93966866], [88.33974457, 24.93958855], [88.33963776, 24.93890381], [88.33977509, 24.9381218], [88.34028625, 24.93728638], [88.34078217, 24.93647003], [88.34085846, 24.93635941], [88.34120941, 24.93586349], [88.34125519, 24.93554306], [88.34130096, 24.93521309], [88.34122467, 24.93488884], [88.34098816, 24.93471527], [88.34015656, 24.93453217], [88.33957672, 24.93431473], [88.33942413, 24.93410683], [88.33924103, 24.93385315], [88.33914948, 24.93310738], [88.33913422, 24.93280029], [88.33909607, 24.93228531], [88.33874512, 24.93180275], [88.33831024, 24.93158722], [88.33761597, 24.93157959], [88.33726501, 24.93153763], [88.3369751, 24.93126678], [88.3368988, 24.93050194], [88.33691406, 24.92935562], [88.33700562, 24.92885971], [88.33734894, 24.9281559], [88.33805084, 24.92726517], [88.33811951, 24.92695999], [88.33798218, 24.92642403], [88.33744049, 24.92624664], [88.33668518, 24.92617989], [88.33628845, 24.92638588], [88.33605194, 24.92670822], [88.33576202, 24.92731285], [88.33551788, 24.92756271], [88.33507538, 24.92767143], [88.3345108, 24.92732239], [88.3342514, 24.92668915], [88.33428192, 24.92577171], [88.33452606, 24.92498589], [88.33465576, 24.92459106], [88.33467865, 24.9244175], [88.33476257, 24.92383575], [88.33483887, 24.92367744], [88.33547974, 24.92234993], [88.33592224, 24.92146111], [88.3365097, 24.91936874], [88.33660889, 24.91903114], [88.33653259, 24.91859245], [88.33638763, 24.91844749], [88.33633423, 24.91829681], [88.33615875, 24.91782951], [88.33303833, 24.91785049], [88.33159637, 24.91809082], [88.33059692, 24.91657066], [88.32965851, 24.91617966], [88.32862091, 24.91638947], [88.32759857, 24.91660118], [88.32628632, 24.91587067], [88.32583618, 24.91456985], [88.32630157, 24.91094971], [88.32636261, 24.91070747], [88.32775879, 24.90722084], [88.32937622, 24.90439796], [88.33087158, 24.90499306], [88.33187866, 24.90530777], [88.33194733, 24.90533066], [88.33358765, 24.90501595], [88.33397675, 24.90494156], [88.33425903, 24.90423012], [88.33447266, 24.90367889], [88.33449554, 24.90073967], [88.33276367, 24.89735985], [88.3327179, 24.89727592], [88.33309174, 24.89707375], [88.33453369, 24.89829254], [88.33577728, 24.89854622], [88.3365097, 24.8986969], [88.33725739, 24.89959335], [88.33743286, 24.89979935], [88.34052277, 24.90014458], [88.34158325, 24.8990345], [88.34255981, 24.90000343], [88.34358215, 24.89974785], [88.34383392, 24.89968491], [88.34392548, 24.89958382], [88.34429932, 24.89864349], [88.3445282, 24.89807701], [88.34434509, 24.89793396], [88.34615326, 24.89542389], [88.34644318, 24.89412498], [88.34653473, 24.89374161], [88.34680939, 24.89251328], [88.34477997, 24.89161873], [88.34456635, 24.89152527], [88.34461975, 24.8914566], [88.34535217, 24.89043427], [88.34500122, 24.88985825], [88.34442139, 24.88892365], [88.34437561, 24.88885689], [88.34261322, 24.8884182], [88.34320068, 24.88711929], [88.34297943, 24.88518524], [88.34293365, 24.88510513], [88.34192657, 24.88344955], [88.3418808, 24.88336754], [88.34043121, 24.8817997], [88.34024048, 24.88159561], [88.33921051, 24.88048172], [88.33893585, 24.87903214], [88.3388443, 24.87853432], [88.33881378, 24.87843704], [88.33416748, 24.87757874], [88.3342514, 24.87731934], [88.33520508, 24.87433815], [88.33423615, 24.87356186], [88.33409882, 24.87344933], [88.33254242, 24.87254715], [88.33296204, 24.87152672], [88.33295441, 24.87091255], [88.33300781, 24.87067986], [88.33306885, 24.87055016], [88.33312225, 24.87044525], [88.33145142, 24.86967087], [88.33112335, 24.8694725], [88.33098602, 24.8693924], [88.3262558, 24.86655235], [88.32608795, 24.86645317], [88.3259201, 24.86635017], [88.32579803, 24.86627579], [88.32514954, 24.8658905], [88.32820129, 24.86953163], [88.32781982, 24.86989021], [88.32735443, 24.87032509], [88.32679749, 24.87048149], [88.3263092, 24.87076187], [88.32598877, 24.8711853], [88.32579803, 24.87142563], [88.32471466, 24.87288857], [88.32463074, 24.87297821], [88.32402039, 24.87362862], [88.32267761, 24.87463951], [88.32132721, 24.87563705], [88.32106018, 24.87634087], [88.32118225, 24.87692833], [88.3212204, 24.87712669], [88.32169342, 24.87781906], [88.32193756, 24.87841415], [88.32192993, 24.87898445], [88.3219223, 24.87923622], [88.32171631, 24.88057137], [88.32128143, 24.88217354], [88.32118988, 24.88249588], [88.32107544, 24.88295937], [88.32096863, 24.88341141], [88.32058716, 24.88360023], [88.32051086, 24.88360214], [88.31983185, 24.8836174], [88.3184967, 24.88364601], [88.31822968, 24.88348961], [88.31803894, 24.88337708], [88.31751251, 24.88338089], [88.31734467, 24.8833828], [88.31707764, 24.88301468], [88.3167572, 24.88258553], [88.31671143, 24.88252258], [88.31665802, 24.88092041], [88.31665039, 24.8807621], [88.31639862, 24.88088989], [88.31530762, 24.88076019], [88.31424713, 24.87973022], [88.31292725, 24.87845039], [88.31060791, 24.87643051], [88.3081665, 24.87407112], [88.30573273, 24.87124825], [88.30428314, 24.87041092], [88.3034668, 24.8719368], [88.30319977, 24.87184525], [88.30125427, 24.87346077], [88.30169678, 24.87524414], [88.30044556, 24.8757267], [88.30013275, 24.87703323], [88.29957581, 24.87896538], [88.29808044, 24.88083458], [88.29833221, 24.88224792], [88.29838562, 24.88254547], [88.30037689, 24.8820858], [88.30056, 24.8820858], [88.30081177, 24.8827858], [88.30104828, 24.88341522], [88.30088806, 24.8841877], [88.3008194, 24.88450432], [88.30114746, 24.88479805], [88.30155182, 24.88516808], [88.3017807, 24.88557243], [88.30197906, 24.88593674], [88.30011749, 24.88583183], [88.29985809, 24.88574409], [88.29971313, 24.8856945], [88.29921722, 24.88552666], [88.29816437, 24.88517189], [88.29845428, 24.8860817], [88.29737091, 24.88759613], [88.29682922, 24.88834572], [88.29441071, 24.88839531], [88.29392242, 24.8893795], [88.29143524, 24.88951111], [88.29006195, 24.88926315], [88.28915405, 24.88878059], [88.28857422, 24.88847542], [88.28804779, 24.88814163], [88.28678131, 24.88732719], [88.28645325, 24.88711548], [88.28631592, 24.88645744], [88.2856369, 24.88652611], [88.28497314, 24.88697052], [88.28523254, 24.88793182], [88.2853775, 24.8884697], [88.2845993, 24.8886795], [88.28157806, 24.88780022], [88.27939606, 24.88731003], [88.27918243, 24.8882637], [88.27806854, 24.88815308], [88.27755737, 24.89178658], [88.27572632, 24.89189911], [88.27624512, 24.89327049], [88.27613831, 24.89338493], [88.27602386, 24.89350891], [88.2770462, 24.89571953], [88.27587128, 24.89567947], [88.27423859, 24.89450073], [88.27226257, 24.8913002], [88.2713089, 24.88975906], [88.27104187, 24.88931084], [88.27053833, 24.88766098], [88.27027893, 24.88566971], [88.26946259, 24.88182068], [88.26937866, 24.87972069], [88.2689209, 24.87776947], [88.26876068, 24.87706184], [88.26782227, 24.87587929], [88.26687622, 24.8749218], [88.26538086, 24.87482071], [88.26381683, 24.87545967], [88.26357269, 24.87576294], [88.26187134, 24.87779045], [88.26144409, 24.87777328], [88.2614212, 24.87759018], [88.26018524, 24.87761307], [88.25902557, 24.8781414], [88.25999451, 24.87947845], [88.2627182, 24.88395309], [88.26419067, 24.88794708], [88.26491547, 24.89279366], [88.26456451, 24.89676857], [88.26411438, 24.90115738], [88.26394653, 24.90277863], [88.26406097, 24.904562], [88.26428223, 24.908041], [88.26413727, 24.91456985], [88.26333618, 24.91839409], [88.26311493, 24.91905212], [88.25945282, 24.92534065], [88.25788879, 24.92707825], [88.25683594, 24.927742], [88.25351715, 24.92928123], [88.25280762, 24.92994499], [88.24964142, 24.93291283], [88.24731445, 24.93509293], [88.24298096, 24.93789864], [88.23982239, 24.94088936], [88.23683929, 24.94426155], [88.23587036, 24.94535828], [88.23547363, 24.94592476], [88.23455811, 24.9472599], [88.23290253, 24.95097733], [88.23197937, 24.95305252], [88.23148346, 24.95397377], [88.2299881, 24.95676994], [88.22929382, 24.95806694], [88.22814178, 24.95893669], [88.22759247, 24.95916748], [88.22621918, 24.95979118], [88.22497559, 24.96004677], [88.22483826, 24.96007347], [88.22360992, 24.96008301], [88.21986389, 24.95974541], [88.21983337, 24.95949936], [88.21767426, 24.95931435], [88.21587372, 24.95910645], [88.21585846, 24.95900154], [88.21338654, 24.95866966], [88.21336365, 24.95877457], [88.21108246, 24.95866585], [88.21017456, 24.95868111], [88.20989227, 24.958601], [88.20864868, 24.95851135], [88.20723724, 24.95834541], [88.20554352, 24.95807266], [88.20493317, 24.95790863], [88.20342255, 24.95765686], [88.20183563, 24.95731354], [88.19802856, 24.95580101], [88.19328308, 24.95345116], [88.19160461, 24.95324516], [88.19017792, 24.95238304], [88.18960571, 24.95219612], [88.18806458, 24.95169067], [88.18662262, 24.95181465], [88.1855545, 24.95313835], [88.18283844, 24.95350838], [88.18280029, 24.95339394], [88.18270111, 24.95307922], [88.18112946, 24.95121384], [88.17948151, 24.94988251], [88.17932892, 24.94901085], [88.17720032, 24.94737816], [88.1767807, 24.94755936], [88.1756897, 24.94655991], [88.17544556, 24.94633675], [88.1751709, 24.94646835], [88.1736145, 24.94721031], [88.17463684, 24.94848251], [88.17450714, 24.94853973], [88.1735611, 24.94931221], [88.17208099, 24.94982338], [88.17015076, 24.95049095], [88.16882324, 24.94834709], [88.16867065, 24.9481945], [88.16713715, 24.94666862], [88.16690826, 24.94643974], [88.16603851, 24.94639206], [88.16495514, 24.94633484], [88.16494751, 24.9462471], [88.16480255, 24.94390297], [88.16465759, 24.94237518], [88.16456604, 24.94142914], [88.16437531, 24.9413681], [88.16347504, 24.94108582], [88.16330719, 24.94090271], [88.16281891, 24.94088173], [88.16273499, 24.94087219], [88.16236115, 24.94073868], [88.16204834, 24.94079781], [88.16056061, 24.93984985], [88.15957642, 24.93828964], [88.15964508, 24.93810844], [88.15944672, 24.93810272], [88.1587677, 24.9370842], [88.15753937, 24.93377495], [88.15746307, 24.93358421], [88.15306091, 24.93289948], [88.1528244, 24.93283272], [88.15145874, 24.9327774], [88.15081024, 24.93274689], [88.14958191, 24.93268585], [88.14585114, 24.93496513], [88.14578247, 24.9352951], [88.14559937, 24.93615913], [88.14546204, 24.93682289], [88.14477539, 24.93676758], [88.14422607, 24.93672562], [88.14396667, 24.93670464], [88.1414566, 24.93650818], [88.14015961, 24.93641281], [88.13968658, 24.93612862], [88.13893127, 24.93194008], [88.13926697, 24.92996979], [88.1399231, 24.92624855], [88.14008331, 24.92366982], [88.14028168, 24.92074013], [88.14058685, 24.91733932], [88.14240265, 24.91494942], [88.14376831, 24.91434669], [88.14389801, 24.91428185], [88.14575958, 24.91337967], [88.14611816, 24.9130764], [88.14649963, 24.9128685], [88.14885712, 24.9112606], [88.15093994, 24.90913391], [88.15132904, 24.90866089], [88.15148163, 24.90852928], [88.15169525, 24.90833092], [88.1531601, 24.90695381], [88.15362549, 24.90649605], [88.15357208, 24.90585136], [88.15431976, 24.90485954], [88.15544128, 24.9017601], [88.15561676, 24.90126991], [88.15711975, 24.89844704], [88.15924072, 24.89806938], [88.16079712, 24.89817047], [88.16248322, 24.89780998], [88.16290283, 24.8972683], [88.16294861, 24.89720535], [88.1638031, 24.896101], [88.16481781, 24.89526558], [88.16524506, 24.89551735], [88.16680908, 24.89455414], [88.16682434, 24.89413261], [88.16685486, 24.89334869], [88.1680603, 24.8931942], [88.16888428, 24.89308739], [88.16897583, 24.89307594], [88.16921234, 24.89211845], [88.16913605, 24.8919239], [88.16898346, 24.89151573], [88.16909027, 24.89088631], [88.16864014, 24.89012146], [88.16799164, 24.89008713], [88.16748047, 24.88946152], [88.1684494, 24.88897705], [88.16866302, 24.88832474], [88.16809082, 24.88838959], [88.16623688, 24.88859749], [88.16643524, 24.88995171], [88.16579437, 24.890028], [88.16560364, 24.89005089], [88.1633606, 24.88961029], [88.16291809, 24.88898087], [88.16230774, 24.88952827], [88.16168213, 24.88938332], [88.16065979, 24.88914299], [88.16009521, 24.89027214], [88.1595993, 24.89034081], [88.15942383, 24.89071274], [88.15898895, 24.89043045], [88.15709686, 24.88918114], [88.15496826, 24.88656998], [88.15486145, 24.88514137], [88.15477753, 24.88418961], [88.15535736, 24.88379288], [88.15533447, 24.88368607], [88.15537262, 24.88169479], [88.15638733, 24.8815136], [88.15653229, 24.8814888], [88.1595993, 24.88094521], [88.16013336, 24.88085175], [88.16035461, 24.88066101], [88.16066742, 24.88038635], [88.16159058, 24.87990189], [88.16252136, 24.8794117], [88.16260529, 24.87874413], [88.16366577, 24.87807846], [88.16336823, 24.87651253], [88.16331482, 24.87624168], [88.16281128, 24.87629318], [88.1612854, 24.87532043], [88.16028595, 24.87468147], [88.15927887, 24.87217522], [88.15949249, 24.87190056], [88.16110229, 24.86986351], [88.16210937, 24.86858368], [88.16311646, 24.86730576], [88.16338348, 24.86696815], [88.16458893, 24.86530113], [88.16724396, 24.86356735], [88.17188263, 24.86380005], [88.17356873, 24.86288452], [88.17369843, 24.86281395], [88.17415619, 24.86258507], [88.17430115, 24.86250687], [88.17544556, 24.86193466], [88.1750946, 24.86064529], [88.17498779, 24.86025047], [88.1745224, 24.86026764], [88.17323303, 24.85941124], [88.17192078, 24.85950851], [88.1696701, 24.85967064], [88.16765594, 24.85906029], [88.16551971, 24.85720062], [88.16422272, 24.85606956], [88.16422272, 24.85357094], [88.16440582, 24.85045052], [88.16353607, 24.84910011], [88.16253662, 24.84851074], [88.16225433, 24.84858322], [88.16112518, 24.84886932], [88.16042328, 24.84858131], [88.1599884, 24.849226], [88.15937042, 24.85015297], [88.15929413, 24.85026169], [88.15619659, 24.85017395], [88.15564728, 24.85015869], [88.15515137, 24.85043144], [88.15506744, 24.85047531], [88.15501404, 24.85042191], [88.15455627, 24.84994888], [88.15306091, 24.85010719], [88.15224457, 24.849823], [88.15088654, 24.84934998], [88.15080261, 24.84992218], [88.15071869, 24.85050201], [88.15063477, 24.85111809], [88.15033722, 24.85343361], [88.15007782, 24.85336494], [88.14995575, 24.85333252], [88.15027618, 24.85067368], [88.15035248, 24.85006332], [88.14879608, 24.850214], [88.14762115, 24.85023499], [88.14685822, 24.85024834], [88.14685059, 24.85050011], [88.14681244, 24.85202408], [88.14638519, 24.85183907], [88.14490509, 24.8512001], [88.14547729, 24.84973145], [88.1444931, 24.84978485], [88.14442444, 24.84878731], [88.14438629, 24.84827805], [88.14468384, 24.84840012], [88.14504242, 24.8485508], [88.14487457, 24.84703064], [88.14477539, 24.84608078], [88.14476776, 24.8459301], [88.14472198, 24.84504509], [88.1446991, 24.84467316], [88.14483643, 24.84365273], [88.14550781, 24.84383583], [88.14678955, 24.84418869], [88.14692688, 24.84422684], [88.14707184, 24.84373474], [88.14513397, 24.84307671], [88.14502716, 24.84285927], [88.1435318, 24.8411293], [88.14141083, 24.83984947], [88.14109039, 24.83967018], [88.14099121, 24.83933067], [88.14015198, 24.83666039], [88.14017487, 24.83577156], [88.14102173, 24.835289], [88.14089203, 24.83447647], [88.14020538, 24.83442497], [88.14021301, 24.83427048], [88.13973999, 24.83403969], [88.13907623, 24.83372116], [88.13645935, 24.8327198], [88.13503265, 24.83176041], [88.13500977, 24.83162117], [88.13463593, 24.82847023], [88.13468933, 24.82364082], [88.13453674, 24.8207798], [88.13450623, 24.82018089], [88.13506317, 24.81608963], [88.13543701, 24.81458092], [88.13574219, 24.81335831], [88.13685608, 24.8097229], [88.13742065, 24.80648041], [88.13624573, 24.80543709], [88.1361084, 24.8053112], [88.13552856, 24.80503082], [88.13317108, 24.80390167], [88.13192749, 24.8050766], [88.13134766, 24.8050766], [88.13071442, 24.8050766], [88.1301651, 24.80599213], [88.12979889, 24.80679512], [88.12849426, 24.80961037], [88.12791443, 24.81086922], [88.12768555, 24.81136894], [88.12565613, 24.81668854], [88.1235733, 24.81942177], [88.12355042, 24.82144356], [88.12353516, 24.82316589], [88.12337494, 24.82306671], [88.1217041, 24.82203293], [88.12115479, 24.82169342], [88.12076569, 24.82140923], [88.11798859, 24.81936836], [88.11522675, 24.81716728], [88.11400604, 24.8158474], [88.11342621, 24.81526756], [88.11229706, 24.81415367], [88.11190033, 24.81351089], [88.11064911, 24.81148529], [88.11003113, 24.81047821], [88.10800934, 24.80605125], [88.10657501, 24.80323601], [88.1058197, 24.80155182], [88.1049881, 24.79966927], [88.1051178, 24.79750824], [88.10549164, 24.79526329], [88.10558319, 24.79406738], [88.10549927, 24.79403114], [88.10549164, 24.79380608], [88.1051712, 24.79374695], [88.10493469, 24.79351997], [88.10520935, 24.79195595], [88.10504913, 24.78919411], [88.10501099, 24.78679466], [88.10631561, 24.7869873], [88.10616302, 24.78534508], [88.10605621, 24.78419685], [88.10607147, 24.78080177], [88.1060791, 24.77968407], [88.10005951, 24.7799511], [88.09719086, 24.78018951], [88.09594727, 24.78032112], [88.09244537, 24.78148651], [88.09020996, 24.78247452], [88.08982849, 24.78252029], [88.08695221, 24.77895927], [88.08364105, 24.77342033], [88.08277893, 24.77256966], [88.08094788, 24.77077103], [88.08022308, 24.77058983], [88.0786438, 24.77019119], [88.07783508, 24.76920891], [88.07717896, 24.7695446], [88.0754776, 24.77043724], [88.07457733, 24.77090836], [88.07448578, 24.77095985], [88.07372284, 24.77139091], [88.07215118, 24.77093124], [88.07076263, 24.76959038], [88.07058716, 24.76942062], [88.07032776, 24.76826477], [88.07045746, 24.76819992], [88.0710907, 24.76789284], [88.07064056, 24.76706505], [88.07019043, 24.76622581], [88.07021332, 24.76551056], [88.07021332, 24.76414108], [88.07112122, 24.76265907], [88.07254791, 24.76190376], [88.07388306, 24.76119614], [88.07441711, 24.76091576], [88.07450867, 24.76086617], [88.0743866, 24.76071358], [88.07273865, 24.75870132], [88.07228088, 24.75814629], [88.07151794, 24.75720406], [88.07003021, 24.75537682], [88.06969452, 24.75489426], [88.06826019, 24.75283813], [88.06790161, 24.75260162], [88.06664276, 24.75177765], [88.06571198, 24.75081444], [88.06620789, 24.75033951], [88.06720734, 24.74939156], [88.06755829, 24.74906921], [88.07009125, 24.74673653], [88.07032776, 24.746521], [88.0710907, 24.74553108], [88.07144165, 24.74534988], [88.07312012, 24.74369049], [88.07380676, 24.74118042], [88.07142639, 24.73662186], [88.06931305, 24.73258972], [88.06761932, 24.72822952], [88.06606293, 24.72437859], [88.06474304, 24.72138023], [88.0626297, 24.71787071], [88.05986786, 24.71504974], [88.05506134, 24.71110916], [88.05056763, 24.70728111], [88.04625702, 24.70362091], [88.04232788, 24.70046806], [88.04084015, 24.69944954], [88.03814697, 24.69759941], [88.03410339, 24.6936512], [88.03206635, 24.69129944], [88.03009796, 24.68902016], [88.02585602, 24.68399048], [88.02179718, 24.67999077], [88.01837158, 24.67642975], [88.01474762, 24.67305183], [88.01281738, 24.67113113], [88.01132202, 24.66904068], [88.0112381, 24.66879082], [88.01056671, 24.66666031], [88.01127625, 24.6655407], [88.01223755, 24.66469383], [88.01530457, 24.66225052], [88.01756287, 24.6604538], [88.02075195, 24.65787125], [88.02357483, 24.65545654], [88.02662659, 24.65152359], [88.02851105, 24.64991951], [88.02941132, 24.64918709], [88.03364563, 24.64718246], [88.03687286, 24.64596176], [88.03839874, 24.64531517], [88.03939056, 24.64489746], [88.04115295, 24.64342499], [88.04216003, 24.64130402], [88.04292297, 24.64073944], [88.04615021, 24.63742065], [88.04788971, 24.63297844], [88.05018616, 24.62939072], [88.05293274, 24.62585068], [88.05517578, 24.62232018], [88.05583954, 24.62067413], [88.05593872, 24.62030411], [88.05835724, 24.61737251], [88.06078339, 24.61483955], [88.06195068, 24.61345863], [88.06469727, 24.61021996], [88.06955719, 24.60485077], [88.07279205, 24.60000038], [88.07583618, 24.59515953], [88.07876587, 24.58934975], [88.08100128, 24.58535957], [88.08654022, 24.57753944], [88.08878326, 24.57375717], [88.08938599, 24.57275009], [88.09200287, 24.56496048], [88.09387207, 24.56216049], [88.09655762, 24.55931091], [88.09841156, 24.55668068], [88.10115051, 24.55234909], [88.10375977, 24.54893112], [88.1071167, 24.54544067], [88.10926819, 24.54357529], [88.11048126, 24.54252052], [88.11493683, 24.53885078], [88.1177597, 24.53650093], [88.1220932, 24.53259087], [88.12306213, 24.53170967], [88.12565613, 24.52867126], [88.12895203, 24.52478981], [88.12976074, 24.52397537], [88.13027191, 24.52346039], [88.13156128, 24.52215958], [88.13449097, 24.51913071], [88.13722229, 24.5160408], [88.14144897, 24.51221085], [88.14369202, 24.51048851], [88.14494324, 24.50895119], [88.14614868, 24.50757599], [88.14707184, 24.50693512], [88.14835358, 24.50533104], [88.15084076, 24.50385666], [88.15364838, 24.50379753], [88.15615082, 24.50296211], [88.15821075, 24.5022049], [88.16099548, 24.50062561], [88.16152954, 24.50032043], [88.16285706, 24.49956894], [88.16482544, 24.49873543], [88.16664886, 24.49796486], [88.16943359, 24.49598503], [88.16989899, 24.49565506], [88.17170715, 24.4943676], [88.17342377, 24.49314308], [88.17404175, 24.49238777], [88.17498779, 24.49123001], [88.17543793, 24.49060249], [88.17559052, 24.49047852], [88.17577362, 24.49032021], [88.17774963, 24.48859596], [88.17796326, 24.48840904], [88.17884827, 24.48763084], [88.1802597, 24.48639107], [88.1815033, 24.48513222], [88.18397522, 24.48261833], [88.1849823, 24.48159027], [88.18595123, 24.48016167], [88.18689728, 24.47929001], [88.19007874, 24.4762001], [88.19174957, 24.47318077], [88.19274139, 24.4701004], [88.1937027, 24.46619797], [88.19838715, 24.46258163], [88.19942474, 24.4622345], [88.20014954, 24.46199226], [88.20441437, 24.45946693], [88.20478821, 24.45942307], [88.2059021, 24.45929527], [88.20700073, 24.45894241], [88.21011353, 24.45794106], [88.21044922, 24.45783424], [88.21120453, 24.45765495], [88.21369171, 24.4570694], [88.21459198, 24.45685959], [88.21627045, 24.45664215], [88.21768951, 24.45665932], [88.22014618, 24.45666504], [88.22034454, 24.45664215], [88.22052002, 24.45661545], [88.22306824, 24.45624352], [88.22354889, 24.45617294], [88.22446442, 24.45611], [88.22745514, 24.45559883], [88.2330246, 24.45377541], [88.23404694, 24.45358467], [88.23717499, 24.45300102], [88.24329376, 24.45023727], [88.2455368, 24.44971275], [88.24997711, 24.44823837], [88.25536346, 24.44778824], [88.2588501, 24.44725227], [88.26205444, 24.44634438], [88.26330566, 24.44599342], [88.2634201, 24.44590378], [88.26459503, 24.44498825], [88.2646637, 24.44493294], [88.26756287, 24.44322968], [88.27085114, 24.44144058], [88.27519226, 24.43868065], [88.28009796, 24.43518066], [88.28246307, 24.43117905], [88.28386688, 24.42799759], [88.28585815, 24.42418098], [88.28988647, 24.42039108], [88.29285431, 24.41727638], [88.29572296, 24.4142704], [88.29944611, 24.41106033], [88.3038559, 24.40768051], [88.31186676, 24.4017601], [88.3168869, 24.39712143], [88.32327271, 24.39088058], [88.3277359, 24.38675117], [88.33300781, 24.38319016], [88.33786011, 24.38076019], [88.34282684, 24.37856293], [88.34818268, 24.37647247], [88.35444641, 24.37489128], [88.36091614, 24.37375069], [88.3629837, 24.37344933], [88.36424255, 24.37340546], [88.36659241, 24.3730526], [88.36972046, 24.37320328], [88.37429047, 24.37390709], [88.38006592, 24.37430382], [88.38247681, 24.37354851], [88.38306427, 24.3733654], [88.38486481, 24.37280083], [88.38676453, 24.37220764], [88.38938904, 24.37191391], [88.39144897, 24.37220955], [88.39273071, 24.37239265], [88.39489746, 24.37270355], [88.39897156, 24.37421989], [88.40161133, 24.37455559], [88.41230011, 24.37698364], [88.41239929, 24.37700272], [88.41300201, 24.37754059], [88.41962433, 24.38149071], [88.42134094, 24.38196373], [88.42482758, 24.38326645], [88.42677307, 24.38344574], [88.430336, 24.3837738], [88.43232727, 24.38292694], [88.43325043, 24.38285446], [88.43360901, 24.38282585], [88.43588257, 24.38216591], [88.44171143, 24.3801136], [88.44632721, 24.37866783], [88.45169067, 24.37566185], [88.4538269, 24.37424088], [88.45389557, 24.37419319], [88.45923615, 24.37137032], [88.46321106, 24.36849022], [88.46975708, 24.36433792], [88.47007751, 24.36413574], [88.47125244, 24.36332512], [88.47148895, 24.36318207], [88.47806549, 24.35997391], [88.48112488, 24.3583889], [88.48307037, 24.35769272], [88.48735046, 24.35583115], [88.48920441, 24.35521698], [88.49594116, 24.35448647], [88.49649811, 24.35356712], [88.49829102, 24.35305977], [88.5003891, 24.35161972], [88.50324249, 24.34885979], [88.50718689, 24.34468079], [88.51434326, 24.34346962], [88.52667236, 24.34436798], [88.52710724, 24.34446716], [88.52713776, 24.34432602], [88.52870941, 24.34418106], [88.53050232, 24.34205818], [88.53856659, 24.32716942], [88.54165649, 24.32146072], [88.54503632, 24.31478119], [88.54849243, 24.3078804], [88.55137634, 24.30269241], [88.55500031, 24.29648972], [88.55594635, 24.29640961], [88.55696869, 24.29894257], [88.55775452, 24.30121231], [88.56151581, 24.31215668], [88.5621109, 24.31388092], [88.56220245, 24.31410408], [88.56313324, 24.31637764], [88.56336212, 24.31688881], [88.56364441, 24.31749916], [88.56399536, 24.31803131], [88.56504822, 24.31961823], [88.56526947, 24.31995201], [88.56650543, 24.3228569], [88.56700134, 24.3246212], [88.56758118, 24.32670975], [88.56816101, 24.32666779], [88.57346344, 24.32586861], [88.58158875, 24.32479286], [88.58708954, 24.32420158], [88.58724213, 24.3219471], [88.58770752, 24.31464005], [88.58804321, 24.31197739], [88.59526062, 24.31218719], [88.59548187, 24.31212997], [88.59978485, 24.31103325], [88.60308838, 24.31032562], [88.60340118, 24.31025887], [88.60347748, 24.31026077], [88.60559845, 24.31033516], [88.60605621, 24.31035042], [88.60609436, 24.31065559], [88.60657501, 24.31457138], [88.60666656, 24.31531334], [88.60736847, 24.31526756], [88.60778809, 24.3166275], [88.61859894, 24.31583977], [88.62325287, 24.31555939], [88.62367249, 24.31560326], [88.62376404, 24.31540298], [88.62464905, 24.31349754], [88.62556458, 24.31152153], [88.62850189, 24.30518913], [88.62866974, 24.30529594], [88.62978363, 24.30603027], [88.62993622, 24.30612946], [88.63284302, 24.30804825], [88.63304138, 24.30787468], [88.63385773, 24.3071537], [88.63421631, 24.30683136], [88.63431549, 24.30685234], [88.63818359, 24.30772781], [88.63822937, 24.3079319], [88.63825989, 24.30807495], [88.6416626, 24.30869484], [88.64723969, 24.31093788], [88.64889526, 24.31105995], [88.64891815, 24.31088448], [88.64898682, 24.31046104], [88.64931488, 24.30837822], [88.64977264, 24.30773926], [88.64984131, 24.30570793], [88.65014648, 24.3056469], [88.65254974, 24.30518723], [88.65493011, 24.30869484], [88.6574173, 24.31234741], [88.6588974, 24.31451797], [88.65981293, 24.31434059], [88.66110229, 24.31409264], [88.66130066, 24.31414032], [88.66415405, 24.31484032], [88.66879272, 24.31454086], [88.67012787, 24.31471252], [88.67346954, 24.31516075], [88.67346954, 24.31492233], [88.67501068, 24.31512451], [88.67510223, 24.31537819], [88.67536926, 24.31541634], [88.67597198, 24.31550026], [88.67560577, 24.31520462], [88.68131256, 24.31595039], [88.69426727, 24.3156395], [88.69617462, 24.31546021], [88.69652557, 24.31542778], [88.70023346, 24.31396484], [88.70154572, 24.31344986], [88.70456696, 24.31278229], [88.70558167, 24.31225204], [88.70588684, 24.31209183], [88.70628357, 24.31188202], [88.70833588, 24.30997849], [88.71065521, 24.30783081], [88.71221161, 24.30677414], [88.71243286, 24.30662537], [88.71442413, 24.30462646], [88.71710968, 24.30280876], [88.72001648, 24.30118561], [88.7205658, 24.30088425], [88.72241974, 24.29984856], [88.72283936, 24.29949188], [88.7237854, 24.2986908], [88.72473907, 24.29787827], [88.72549438, 24.29637337], [88.72632599, 24.2947197], [88.72673798, 24.29321861], [88.72922516, 24.28987122], [88.73154449, 24.2850914], [88.73396301, 24.27914619], [88.73540497, 24.27656555], [88.73580933, 24.27310753], [88.73736572, 24.27012253], [88.73813629, 24.265625], [88.73779297, 24.26176262], [88.73782349, 24.26099968], [88.73903656, 24.25958633], [88.74031067, 24.2563324], [88.74089813, 24.25402451], [88.74054718, 24.25133705], [88.74040985, 24.25094795], [88.74036407, 24.25081062], [88.73901367, 24.24698639], [88.73699188, 24.23575592], [88.73612976, 24.22865105], [88.73536682, 24.22570801], [88.73449707, 24.2223568], [88.73477936, 24.22054482], [88.73500061, 24.21908188], [88.73486328, 24.21809196], [88.7347641, 24.21740341], [88.73477936, 24.21596527], [88.73478699, 24.21569824], [88.73480225, 24.21377563], [88.73485565, 24.2135067], [88.73523712, 24.21160698], [88.73420715, 24.20644188], [88.73405457, 24.19978142], [88.73362732, 24.19724274], [88.73336029, 24.19561195], [88.73342133, 24.19392014], [88.73344421, 24.19332314], [88.7328949, 24.18832779], [88.73297882, 24.18637085], [88.73261261, 24.18517303], [88.7324295, 24.18456459], [88.73143768, 24.17763329], [88.73143005, 24.17642021], [88.73141479, 24.17346954], [88.73153687, 24.1717186], [88.73352051, 24.16911697], [88.73654175, 24.16686249], [88.74032593, 24.16339302], [88.74071503, 24.16236305], [88.74139404, 24.1605854], [88.74395752, 24.15060425], [88.74623108, 24.14739799], [88.7463913, 24.14717102], [88.73858643, 24.14159203], [88.73014832, 24.13556099], [88.72164154, 24.12948036], [88.71272278, 24.1231041], [88.70953369, 24.12082291], [88.71019745, 24.11891937], [88.70695496, 24.11925888], [88.7046051, 24.11950493], [88.70379639, 24.11959076], [88.70101166, 24.11894989], [88.69763184, 24.11816978], [88.69603729, 24.11728287], [88.69538116, 24.11672974], [88.69525909, 24.11662865], [88.69468689, 24.11569214], [88.69391632, 24.11442947], [88.69303894, 24.11132431], [88.69345856, 24.11007118], [88.69454193, 24.10972595], [88.69465637, 24.10974884], [88.6966095, 24.11015892], [88.69800568, 24.11045265], [88.69988251, 24.10970879], [88.70078278, 24.10825539], [88.7013092, 24.10408783], [88.70121765, 24.10325813], [88.70026398, 24.09478378], [88.70186615, 24.09433556], [88.70362091, 24.09421349], [88.70381165, 24.09438133], [88.70521545, 24.09561729], [88.70811462, 24.09772682], [88.71258545, 24.10074997], [88.71487427, 24.10229492], [88.71643829, 24.10320854], [88.71717072, 24.10349846], [88.71864319, 24.10361862], [88.72350311, 24.10401344], [88.72363281, 24.10402298], [88.72370911, 24.10396576], [88.72770691, 24.10092354], [88.72846222, 24.09233665], [88.72846222, 24.09049606], [88.72679901, 24.08539772], [88.72595978, 24.08299065], [88.72494507, 24.07995796], [88.72492218, 24.07986069], [88.72451019, 24.07770348], [88.72441101, 24.07718277], [88.72428131, 24.07638931], [88.72381592, 24.07344818], [88.72367859, 24.07329559], [88.72341156, 24.07191849], [88.72344208, 24.07114601], [88.72354889, 24.06873894], [88.72492218, 24.06639481], [88.72541046, 24.06555367], [88.72631836, 24.06523705], [88.72781372, 24.06471062], [88.72846222, 24.06448174], [88.72944641, 24.06472588], [88.73156738, 24.0652504], [88.73358154, 24.06633568], [88.73374176, 24.06616783], [88.73504639, 24.06478882], [88.73716736, 24.06255722], [88.73741913, 24.06203461], [88.73697662, 24.0616188], [88.73680878, 24.06146622], [88.7368927, 24.06126976], [88.73763275, 24.05942917], [88.73738098, 24.05663109], [88.73734283, 24.05633163], [88.73660278, 24.05562973], [88.73143005, 24.05458069], [88.72775269, 24.05380058], [88.72684479, 24.05346489], [88.72683716, 24.05324173], [88.72682953, 24.05305862], [88.72693634, 24.05295372], [88.72971344, 24.05016899], [88.73042297, 24.04997826], [88.73147583, 24.04969788], [88.73157501, 24.04971886], [88.73238373, 24.04989243], [88.73323059, 24.0510006], [88.73379517, 24.05124855], [88.73394012, 24.05114937], [88.73517609, 24.04973412], [88.73599243, 24.04915237], [88.73763275, 24.04798889], [88.73939514, 24.04590416], [88.73953247, 24.04573631], [88.73841095, 24.0402832], [88.73825073, 24.0388813], [88.73817444, 24.03819847], [88.73799896, 24.03823471], [88.73865509, 24.03617859], [88.74143219, 24.03547668], [88.74152374, 24.03545189], [88.74180603, 24.03538132], [88.74216461, 24.03342628], [88.74027252, 24.03045654], [88.73841858, 24.02789879], [88.73808289, 24.02737999], [88.73745728, 24.02325058], [88.73773193, 24.01557159], [88.73777008, 24.01375008], [88.73764038, 24.0135994], [88.73506165, 24.01078987], [88.7332077, 24.00976944], [88.73175812, 24.00896072], [88.73085785, 24.00746155], [88.73049927, 24.00470924], [88.7303772, 24.0036068], [88.72930908, 24.00076485], [88.72890472, 23.99969482], [88.72845459, 23.99887276], [88.72880554, 23.99666023], [88.72934723, 23.99606323], [88.72991943, 23.99542046], [88.7312851, 23.99537468], [88.73168182, 23.99536133], [88.73461914, 23.99526024], [88.73537445, 23.99523354], [88.73736572, 23.99648285], [88.73775482, 23.99715042], [88.73886871, 23.99905777], [88.7394104, 23.99997711], [88.73951721, 24.00010872], [88.74152374, 24.00270271], [88.74253845, 24.00401497], [88.74594879, 24.00579643], [88.74598694, 24.00568199], [88.746315, 24.00456619], [88.74957275, 24.00604439], [88.75274658, 24.00671577], [88.75410461, 24.00670242], [88.75874329, 24.00818253], [88.76241302, 24.00525093], [88.76332855, 24.001894], [88.76304626, 24.00187111], [88.76229095, 24.00182343], [88.76233673, 23.99886131], [88.76235199, 23.99877739], [88.76279449, 23.99587822], [88.76636505, 23.98923302], [88.76898193, 23.98424721], [88.76940918, 23.98254967], [88.7695694, 23.98190689], [88.76934052, 23.98149872], [88.76830292, 23.98117828], [88.76695251, 23.98104858], [88.7652359, 23.98120308], [88.76276398, 23.98225975], [88.75894928, 23.98337364], [88.75613403, 23.98430634], [88.75395203, 23.98480225], [88.75024414, 23.9853344], [88.74640656, 23.98547363], [88.74485779, 23.98552895], [88.74173737, 23.98516846], [88.73963928, 23.98462677], [88.73853302, 23.98377991], [88.73744965, 23.98267174], [88.73655701, 23.98111153], [88.7364502, 23.98043442], [88.73615265, 23.97854614], [88.73562622, 23.97754478], [88.73590088, 23.9757061], [88.73633575, 23.97387123], [88.73705292, 23.9711628], [88.7365036, 23.96785355], [88.73582458, 23.9643116], [88.73567963, 23.96355438], [88.73471832, 23.96309853], [88.73460388, 23.96304512], [88.73447418, 23.96298599], [88.73467255, 23.96295738], [88.73439789, 23.96212006], [88.73378754, 23.96167946], [88.73381805, 23.96009064], [88.73404694, 23.95957375], [88.73477173, 23.95962906], [88.73499298, 23.95858002], [88.73423767, 23.95910072], [88.73379517, 23.95828819], [88.73355103, 23.95783043], [88.73335266, 23.95746803], [88.73590851, 23.95536041], [88.7374115, 23.95350647], [88.73894501, 23.95285225], [88.73902893, 23.95309067], [88.73925781, 23.95378304], [88.73992157, 23.95397949], [88.7401886, 23.95404434], [88.74241638, 23.95114899], [88.74179077, 23.95075798], [88.74170685, 23.95077133], [88.74118805, 23.9510994], [88.74093628, 23.95125771], [88.74065399, 23.95105743], [88.74085999, 23.94901085], [88.74035645, 23.94831085], [88.73974609, 23.94742012], [88.73977661, 23.94470024], [88.74028778, 23.9434433], [88.74066925, 23.94334793], [88.74063873, 23.94281769], [88.74057007, 23.94275284], [88.73974609, 23.94195747], [88.74045563, 23.9400425], [88.74145508, 23.93907547], [88.74151611, 23.93901443], [88.74137115, 23.93895912], [88.74028015, 23.93852615], [88.74006653, 23.93844414], [88.73996735, 23.93840408], [88.74015808, 23.93730354], [88.74068451, 23.93629074], [88.7409668, 23.93574715], [88.74103546, 23.93560791], [88.74180603, 23.93391609], [88.74206543, 23.93334579], [88.74311829, 23.92974854], [88.7423172, 23.92950058], [88.74184418, 23.93053627], [88.74182129, 23.93126488], [88.74144745, 23.93104935], [88.74035645, 23.93042183], [88.74022675, 23.93034363], [88.73947144, 23.93198776], [88.73930359, 23.93234825], [88.73873901, 23.93267632], [88.73587799, 23.93223953], [88.73488617, 23.9317894], [88.73475647, 23.93167877], [88.73471832, 23.93131638], [88.7350769, 23.9310112], [88.73519135, 23.9309082], [88.73529053, 23.93081856], [88.73696136, 23.92928505], [88.7371521, 23.92910576], [88.73704529, 23.92905235], [88.73591614, 23.92848206], [88.73467255, 23.92837906], [88.73420715, 23.92812347], [88.735466, 23.92319107], [88.73549652, 23.92307472], [88.7334137, 23.92289543], [88.73374176, 23.92159081], [88.73363495, 23.92004395], [88.7341156, 23.9183712], [88.73540497, 23.91474724], [88.73504639, 23.91429901], [88.73344421, 23.91399956], [88.73314667, 23.91328812], [88.73338318, 23.91111755], [88.73247528, 23.91087914], [88.73207092, 23.91078568], [88.73104858, 23.91080666], [88.73019409, 23.91082573], [88.72978973, 23.911026], [88.72947693, 23.9112339], [88.7296524, 23.9123745], [88.73029327, 23.91292191], [88.72827148, 23.91332626], [88.72763062, 23.91328812], [88.72651672, 23.91315651], [88.72509766, 23.91299057], [88.72483826, 23.91296005], [88.72497559, 23.91366577], [88.7250061, 23.91380692], [88.72402954, 23.91506386], [88.7233429, 23.9153595], [88.72117615, 23.91543961], [88.72097015, 23.91567039], [88.71419525, 23.91425323], [88.71331024, 23.91308594], [88.71295166, 23.91261292], [88.7095871, 23.91441727], [88.70614624, 23.91413116], [88.70537567, 23.91406631], [88.70336914, 23.91207504], [88.70321655, 23.91192245], [88.70154572, 23.91226768], [88.70102692, 23.91171837], [88.70066071, 23.90967178], [88.70236206, 23.9076004], [88.70296478, 23.90703773], [88.70372009, 23.90730476], [88.70389557, 23.90706062], [88.7041626, 23.90667915], [88.70346832, 23.9065609], [88.70376587, 23.90628052], [88.70449829, 23.90562057], [88.70478821, 23.9043808], [88.70491028, 23.90386963], [88.7053299, 23.90246201], [88.7053833, 23.90227127], [88.70535278, 23.90102196], [88.70534515, 23.90072823], [88.70510864, 23.90043831], [88.70493317, 23.90003014], [88.70435333, 23.89942741], [88.70418549, 23.89925003], [88.70359802, 23.8996563], [88.70326996, 23.89987755], [88.70264435, 23.89974022], [88.70187378, 23.89957047], [88.70120239, 23.90055847], [88.70106506, 23.90071487], [88.70063019, 23.90120888], [88.70000458, 23.90057564], [88.70011139, 23.8999424], [88.70024109, 23.89916801], [88.70027161, 23.89897156], [88.69890594, 23.89940643], [88.69793701, 23.89971733], [88.69533539, 23.9002037], [88.69353485, 23.90036201], [88.69287872, 23.90042114], [88.69252777, 23.90051079], [88.68837738, 23.90157127], [88.68822479, 23.90118408], [88.68814087, 23.9009819], [88.68719482, 23.89856339], [88.68621063, 23.89547348], [88.68541718, 23.8932209], [88.68418884, 23.89027214], [88.68270874, 23.88879967], [88.68077087, 23.88738441], [88.67797852, 23.88630104], [88.67787933, 23.88619995], [88.67627716, 23.88459015], [88.67194366, 23.88394165], [88.66947937, 23.88414001], [88.66761017, 23.88305092], [88.66670227, 23.88251686], [88.66564941, 23.88250923], [88.66423798, 23.88249779], [88.66363525, 23.87949753], [88.66359711, 23.87930679], [88.66352844, 23.87895584], [88.66370392, 23.87831688], [88.66389465, 23.8776226], [88.66407776, 23.87694359], [88.6646347, 23.87561607], [88.66498566, 23.87479401], [88.6668396, 23.87218094], [88.66751099, 23.86969566], [88.6675415, 23.86959457], [88.66744232, 23.86963272], [88.6652298, 23.87046432], [88.66409302, 23.87008286], [88.66369629, 23.87018013], [88.66355896, 23.86992073], [88.66062927, 23.86881447], [88.65838623, 23.86893272], [88.65715027, 23.86935234], [88.65455627, 23.86888885], [88.65435028, 23.86840439], [88.65428925, 23.86825562], [88.65418243, 23.8680172], [88.65395355, 23.86748123], [88.65403748, 23.86736298], [88.65466309, 23.86650085], [88.65414429, 23.86557198], [88.65380096, 23.86575508], [88.65341949, 23.8659668], [88.65296173, 23.86621475], [88.65205383, 23.8665123], [88.65146637, 23.86670303], [88.65087128, 23.86717606], [88.65062714, 23.8673687], [88.6496582, 23.86741447], [88.64963531, 23.86817932], [88.64963531, 23.86831474], [88.64962769, 23.8684864], [88.64916229, 23.86856461], [88.64730835, 23.8688736], [88.64601898, 23.8696537], [88.64576721, 23.8698082], [88.6439743, 23.86919594], [88.64215088, 23.86880493], [88.64241791, 23.8684082], [88.64251709, 23.86831474], [88.64260101, 23.86826897], [88.64266205, 23.86822891], [88.64279938, 23.86812782], [88.64298248, 23.86802673], [88.64307404, 23.86796379], [88.64318848, 23.86789703], [88.64328766, 23.86782265], [88.64334869, 23.86776924], [88.64347839, 23.86764145], [88.64356995, 23.86754608], [88.64366913, 23.86744118], [88.64141083, 23.86664963], [88.63796997, 23.86323166], [88.63379669, 23.86161995], [88.63307953, 23.86136055], [88.62937927, 23.86181068], [88.62741089, 23.86272049], [88.62592316, 23.86363983], [88.6245575, 23.86655235], [88.62407684, 23.86678123], [88.62325287, 23.87021065], [88.62242889, 23.87355995], [88.62119293, 23.87446976], [88.61798096, 23.87557983], [88.6166687, 23.8752594], [88.61221313, 23.87419128], [88.61136627, 23.87350082], [88.61049652, 23.87203026], [88.60993195, 23.87107086], [88.60907745, 23.86963272], [88.60948944, 23.86747551], [88.60987854, 23.86540031], [88.60930634, 23.864048], [88.6088028, 23.86346626], [88.6084671, 23.86308289], [88.60823822, 23.86305618], [88.60736847, 23.86295509], [88.60585022, 23.86343384], [88.60439301, 23.86483765], [88.60375977, 23.8644104], [88.60253143, 23.86418915], [88.60009003, 23.86483955], [88.6000824, 23.86529922], [88.5929718, 23.86994934], [88.59237671, 23.87023544], [88.59207916, 23.87031555], [88.59178925, 23.87039375], [88.59085846, 23.87018394], [88.59020996, 23.8702774], [88.58969879, 23.87034225], [88.58727264, 23.86976051], [88.58479309, 23.86794281], [88.58470917, 23.86774063], [88.58462524, 23.86752129], [88.58473206, 23.86740494], [88.58501434, 23.86707687], [88.58487701, 23.86675072], [88.58474731, 23.86643028], [88.58467102, 23.86625671], [88.58450317, 23.86636353], [88.58425903, 23.86651993], [88.58336639, 23.8640995], [88.58241272, 23.86321831], [88.58243561, 23.86294937], [88.5824585, 23.8626194], [88.58192444, 23.86231613], [88.58139038, 23.86226463], [88.58125305, 23.86225128], [88.57910156, 23.8620472], [88.57627106, 23.86209869], [88.57615662, 23.8621006], [88.57601929, 23.86215782], [88.57534027, 23.86243629], [88.57528687, 23.86172295], [88.57614899, 23.86058044], [88.57646942, 23.86016083], [88.57658386, 23.86001587], [88.57776642, 23.85825539], [88.57795715, 23.85779572], [88.57778168, 23.85761833], [88.57697296, 23.85678101], [88.57641602, 23.85502815], [88.57662964, 23.85476303], [88.57725525, 23.85399628], [88.57754517, 23.85364914], [88.57749176, 23.85352135], [88.58086395, 23.85211372], [88.58164215, 23.8528614], [88.58276367, 23.85455894], [88.5828476, 23.85467148], [88.58405304, 23.85506248], [88.58540344, 23.85515022], [88.58660126, 23.85513878], [88.58809662, 23.85481262], [88.58866119, 23.8545742], [88.58944702, 23.85432816], [88.58935547, 23.85418129], [88.59007263, 23.85391045], [88.59020996, 23.85394669], [88.59120941, 23.85285759], [88.5915451, 23.85159683], [88.59053802, 23.85018349], [88.58929443, 23.84937859], [88.58911133, 23.84914398], [88.58853912, 23.84840393], [88.58816528, 23.84713745], [88.58791351, 23.84659004], [88.58759308, 23.84567261], [88.58718872, 23.84404564], [88.58706665, 23.84296989], [88.58706665, 23.84244347], [88.58706665, 23.84160995], [88.58721161, 23.83944893], [88.58707428, 23.83944511], [88.58739471, 23.83834457], [88.58748627, 23.83835793], [88.58747864, 23.83823967], [88.58757019, 23.83571053], [88.58766937, 23.83444023], [88.59144592, 23.8263607], [88.59294891, 23.82550812], [88.59384155, 23.82489777], [88.59460449, 23.82456589], [88.59668732, 23.82365799], [88.59885406, 23.82238579], [88.5993042, 23.82193565], [88.59951019, 23.82182121], [88.600914, 23.82062149], [88.60127258, 23.81995964], [88.60150909, 23.81951904], [88.60204315, 23.81816292], [88.60203552, 23.81651306], [88.60109711, 23.81460953], [88.60101318, 23.81444931], [88.60035706, 23.81396294], [88.59921265, 23.81311989], [88.59857178, 23.81232452], [88.59833527, 23.81062126], [88.59739685, 23.81045532], [88.59664154, 23.81140518], [88.59611511, 23.81120872], [88.59503174, 23.81080246], [88.59506226, 23.81004143], [88.59490967, 23.80987358], [88.59417725, 23.8090477], [88.59384918, 23.80931854], [88.59385681, 23.809412], [88.59399414, 23.81127548], [88.59380341, 23.81125641], [88.59044647, 23.81095314], [88.59007263, 23.81096077], [88.58933258, 23.81277847], [88.58940887, 23.81341362], [88.58927917, 23.81340027], [88.58772278, 23.8127079], [88.58757782, 23.81060028], [88.59013367, 23.80869102], [88.59130859, 23.80781555], [88.5931015, 23.80807495], [88.59308624, 23.80772972], [88.59303284, 23.8066349], [88.59354401, 23.80632401], [88.59458923, 23.80637741], [88.59549713, 23.80642319], [88.59563446, 23.80624199], [88.59612274, 23.80556107], [88.59571075, 23.80508995], [88.59559631, 23.80495644], [88.59326935, 23.80491638], [88.59285736, 23.80490875], [88.59222412, 23.80430984], [88.59205627, 23.80374718], [88.5920639, 23.80359268], [88.59217072, 23.80300522], [88.59262085, 23.80144119], [88.59272766, 23.80106735], [88.5928421, 23.80068588], [88.5930481, 23.79998016], [88.59285736, 23.79908371], [88.59233856, 23.79854584], [88.59227753, 23.79847717], [88.59215546, 23.79835129], [88.59156036, 23.79763794], [88.59024048, 23.79712486], [88.58824158, 23.7966938], [88.58756256, 23.79674911], [88.58662415, 23.79674339], [88.58511353, 23.79719543], [88.58379364, 23.79758835], [88.58369446, 23.79761887], [88.58312225, 23.79772758], [88.58213043, 23.79779434], [88.58128357, 23.7971611], [88.58100891, 23.79662895], [88.58070374, 23.79598618], [88.58084106, 23.79524612], [88.58139801, 23.79384041], [88.58157349, 23.7935524], [88.58189392, 23.79303169], [88.58211517, 23.79267693], [88.5825119, 23.791605], [88.58220673, 23.79083824], [88.5814209, 23.79018784], [88.58133698, 23.79011345], [88.58101654, 23.78995132], [88.58042908, 23.78965187], [88.57987213, 23.7888813], [88.57894135, 23.78759766], [88.57886505, 23.78757477], [88.57748413, 23.78640938], [88.57585907, 23.78539848], [88.57397461, 23.78431129], [88.57350922, 23.78400612], [88.57276154, 23.78351212], [88.57135773, 23.78328323], [88.57110596, 23.78332329], [88.57008362, 23.78348732], [88.56943512, 23.78369522], [88.56828308, 23.78435326], [88.56708527, 23.78479767], [88.56591797, 23.78495789], [88.56529236, 23.78504372], [88.56333923, 23.78533554], [88.56217194, 23.78580284], [88.5615387, 23.78591537], [88.55969238, 23.78624344], [88.55935669, 23.78630257], [88.55819702, 23.78628349], [88.55717468, 23.78580475], [88.55626678, 23.78508377], [88.55577087, 23.78445244], [88.55599976, 23.78434944], [88.55836487, 23.78368568], [88.55858612, 23.7837925], [88.5592804, 23.78413391], [88.55947113, 23.78422737], [88.55970001, 23.784338], [88.56044006, 23.78421402], [88.56069183, 23.78417015], [88.56039429, 23.78357887], [88.55969238, 23.78228378], [88.55970001, 23.78178024], [88.56019592, 23.7815609], [88.56019592, 23.7811203], [88.56020355, 23.78087044], [88.56207275, 23.78014755], [88.56237793, 23.7800293], [88.56248474, 23.77998924], [88.56257629, 23.77995491], [88.56279755, 23.77986908], [88.56304932, 23.77874947], [88.56322479, 23.7786293], [88.56499481, 23.77744293], [88.566185, 23.77704239], [88.568367, 23.77692604], [88.56903076, 23.77614784], [88.56908417, 23.77608109], [88.56929779, 23.77604103], [88.56956482, 23.77599144], [88.5703125, 23.77591133], [88.57159424, 23.77521515], [88.57180786, 23.77524948], [88.57271576, 23.77540207], [88.57375336, 23.775177], [88.57423401, 23.77526093], [88.57448578, 23.77530479], [88.57507324, 23.77540588], [88.57518005, 23.77542496], [88.57598877, 23.77475357], [88.57875061, 23.77529716], [88.5791626, 23.77512169], [88.57950592, 23.77384377], [88.57962036, 23.77338219], [88.57969666, 23.77309036], [88.57962036, 23.7725811], [88.57940674, 23.77098083], [88.57923889, 23.76974487], [88.57996368, 23.76810455], [88.58042145, 23.7661438], [88.58055115, 23.76519775], [88.58021545, 23.76327705], [88.58037567, 23.76217079], [88.58058929, 23.76067352], [88.58065796, 23.75996208], [88.58071899, 23.75933647], [88.58072662, 23.75925636], [88.580513, 23.7585144], [88.58037567, 23.75803566], [88.57975769, 23.75792694], [88.57865906, 23.75794792], [88.57863617, 23.75673103], [88.57804871, 23.7551403], [88.57582092, 23.75287056], [88.57466125, 23.75029182], [88.57389832, 23.74856186], [88.57377625, 23.74355125], [88.57421112, 23.7401619], [88.5742569, 23.73978615], [88.57239532, 23.73958588], [88.57215118, 23.73955917], [88.57159424, 23.73688698], [88.57199097, 23.73386765], [88.57333374, 23.73368454], [88.57373047, 23.73374176], [88.5742569, 23.73381805], [88.57426453, 23.73451424], [88.57427979, 23.73521042], [88.57430267, 23.73626328], [88.57365417, 23.73822975], [88.57427216, 23.73829079], [88.57444763, 23.73830795], [88.57526398, 23.73838806], [88.57627106, 23.73729134], [88.5764389, 23.73711014], [88.57682037, 23.73499107], [88.57666016, 23.73374367], [88.57659912, 23.73328018], [88.57657623, 23.73308563], [88.57417297, 23.73324966], [88.57398224, 23.73318481], [88.57366943, 23.733078], [88.57398224, 23.73257065], [88.57473755, 23.73134995], [88.57498169, 23.73044968], [88.57421875, 23.72899628], [88.5723114, 23.72903824], [88.5712204, 23.72906113], [88.57106781, 23.72906494], [88.57040405, 23.72885323], [88.57004547, 23.72873688], [88.56962585, 23.72860336], [88.56916046, 23.72766113], [88.56867981, 23.72667503], [88.56845856, 23.7262249], [88.56852722, 23.72566795], [88.56874084, 23.72410393], [88.56898499, 23.72414398], [88.5691452, 23.72418213], [88.5692749, 23.72421646], [88.56937408, 23.7242527], [88.56949615, 23.72425461], [88.56962585, 23.72427368], [88.56978607, 23.72427559], [88.56993103, 23.72427559], [88.57009125, 23.72427177], [88.57025909, 23.72424698], [88.57047272, 23.72423172], [88.57066345, 23.7241993], [88.57080078, 23.72418785], [88.57099915, 23.72413635], [88.56859589, 23.72102356], [88.56850433, 23.71982574], [88.5684433, 23.71896362], [88.56782532, 23.71912003], [88.56724548, 23.71927261], [88.56716919, 23.71878242], [88.56785583, 23.71717262], [88.56781769, 23.71548271], [88.56780243, 23.71485329], [88.5660553, 23.71417809], [88.56513977, 23.71382332], [88.56471252, 23.71317101], [88.56501007, 23.71133423], [88.5660553, 23.70829964], [88.56638336, 23.70510292], [88.56767273, 23.70241356], [88.56707001, 23.6998806], [88.56817627, 23.69836235], [88.56826782, 23.69568825], [88.56952667, 23.69125938], [88.57077789, 23.68832016], [88.5711441, 23.68531227], [88.57288361, 23.68514061], [88.57291412, 23.68502808], [88.57299042, 23.68471718], [88.5734787, 23.6827507], [88.57369995, 23.68185425], [88.5741272, 23.67904663], [88.57450867, 23.6781311], [88.57482147, 23.67724037], [88.5749054, 23.6769886], [88.57481384, 23.67675781], [88.57472992, 23.67653275], [88.57427216, 23.67595482], [88.57431793, 23.67576408], [88.57443237, 23.67535973], [88.5741272, 23.67475891], [88.57307434, 23.67445183], [88.57393646, 23.67000008], [88.5737381, 23.66769028], [88.5738678, 23.66742134], [88.57382202, 23.66675186], [88.57240295, 23.66698074], [88.56894684, 23.6658802], [88.56931305, 23.66459084], [88.57028961, 23.66131783], [88.56879425, 23.66012764], [88.56812286, 23.65969658], [88.56822968, 23.65896988], [88.56829834, 23.6584301], [88.56838226, 23.65796089], [88.56752014, 23.65703964], [88.56344604, 23.64962959], [88.56192017, 23.64624405], [88.56319427, 23.64557838], [88.56263733, 23.64274597], [88.56240845, 23.64014053], [88.56240082, 23.6400547], [88.56215668, 23.63718414], [88.56652832, 23.63647461], [88.56895447, 23.63656807], [88.57102203, 23.63613892], [88.57244873, 23.63699722], [88.57407379, 23.63797379], [88.57608032, 23.63879204], [88.57797241, 23.63860321], [88.57966614, 23.63900375], [88.58106232, 23.63893127], [88.58235168, 23.6391468], [88.58559418, 23.63921928], [88.58821869, 23.63990211], [88.58880615, 23.64046669], [88.58892822, 23.64058876], [88.58978271, 23.6410141], [88.59044647, 23.64134216], [88.59353638, 23.64093781], [88.59371185, 23.64091301], [88.59355164, 23.64039612], [88.59304047, 23.63877678], [88.59313202, 23.63834953], [88.59342194, 23.63705063], [88.59347534, 23.63684082], [88.59333038, 23.63591003], [88.59313202, 23.63461304], [88.59305573, 23.63411713], [88.59305573, 23.63394928], [88.59408569, 23.63164902], [88.59418488, 23.63142967], [88.59314728, 23.62989044], [88.59316254, 23.62914658], [88.59493256, 23.62840843], [88.59375, 23.62796974], [88.59319305, 23.62776566], [88.5932312, 23.62638092], [88.59281921, 23.62495613], [88.59282684, 23.62468338], [88.59273529, 23.6222744], [88.59272766, 23.62190628], [88.59280396, 23.62173271], [88.59371185, 23.6198082], [88.59378052, 23.61698914], [88.59060669, 23.61624718], [88.59034729, 23.6147995], [88.59018707, 23.61470032], [88.58473969, 23.61095047], [88.58283234, 23.60822105], [88.58180237, 23.60663033], [88.58168793, 23.60300064], [88.58261108, 23.60296822], [88.5869751, 23.60270691], [88.5894928, 23.60308838], [88.58986664, 23.60314369], [88.590065, 23.60315323], [88.59150696, 23.60321236], [88.59243774, 23.60325241], [88.59268188, 23.60319138], [88.59316254, 23.60307121], [88.59405518, 23.60284805], [88.5953064, 23.6030407], [88.59720612, 23.60329628], [88.59721375, 23.60345078], [88.59686279, 23.6051693], [88.59680939, 23.60541725], [88.59785461, 23.60640144], [88.59941864, 23.606493], [88.59990692, 23.60677719], [88.60266876, 23.60840416], [88.60608673, 23.6104126], [88.60623169, 23.61050034], [88.60657501, 23.61009598], [88.60145569, 23.60697937], [88.6043396, 23.60581207], [88.60475922, 23.60564232], [88.60718536, 23.60470581], [88.60765839, 23.60486794], [88.60816956, 23.6050415], [88.60835266, 23.60510445], [88.60861206, 23.6040802], [88.60881042, 23.60329247], [88.60884857, 23.60316467], [88.6085434, 23.60243416], [88.60847473, 23.60227394], [88.60835266, 23.60197258], [88.60733795, 23.60300636], [88.60726166, 23.60308266], [88.60613251, 23.60292435], [88.60609436, 23.6028347], [88.60597992, 23.60260773], [88.60541534, 23.60143852], [88.6051712, 23.60094643], [88.60490417, 23.6003952], [88.6051712, 23.60038185], [88.60639191, 23.60033035], [88.6071167, 23.60087013], [88.6102066, 23.60137367], [88.6113739, 23.60245895], [88.61376953, 23.60347557], [88.61667633, 23.60239983], [88.62034607, 23.60295105], [88.62084961, 23.60272789], [88.62102509, 23.60279655], [88.62242889, 23.60499382], [88.62260437, 23.60526466], [88.62509155, 23.60702324], [88.62705231, 23.6067524], [88.62767792, 23.60666656], [88.62963104, 23.60884094], [88.62984467, 23.60908127], [88.6301651, 23.60895729], [88.63027954, 23.60891533], [88.63160706, 23.60839844], [88.63176727, 23.6083374], [88.63275909, 23.60910034], [88.63311005, 23.60936737], [88.63560486, 23.60774422], [88.63575745, 23.60764694], [88.63663483, 23.60708046], [88.63678741, 23.60700607], [88.63705444, 23.60687637], [88.63717651, 23.60731506], [88.63806915, 23.61041069], [88.63819885, 23.61086273], [88.63980865, 23.61130333], [88.63983917, 23.61123657], [88.64050293, 23.60956764], [88.64064789, 23.60922432], [88.64303589, 23.60874939], [88.64516449, 23.60830498], [88.64599609, 23.60813141], [88.64492035, 23.60767937], [88.64494324, 23.60760689], [88.64541626, 23.60738945], [88.64538574, 23.60686111], [88.64537811, 23.60671616], [88.645401, 23.60664177], [88.64539337, 23.60643959], [88.64538574, 23.60627365], [88.64530945, 23.60309982], [88.64494324, 23.60217285], [88.63931274, 23.59716034], [88.63908386, 23.59569359], [88.63922119, 23.59538269], [88.63924408, 23.59437943], [88.63925171, 23.59366035], [88.63923645, 23.59284973], [88.6397171, 23.59242249], [88.64044189, 23.59109497], [88.64160156, 23.59122658], [88.64250946, 23.59138489], [88.64381409, 23.59161377], [88.64408112, 23.59165955], [88.64508057, 23.59123421], [88.64559937, 23.59052467], [88.64567566, 23.58955002], [88.64492798, 23.58955383], [88.64367676, 23.58955956], [88.64532471, 23.58811188], [88.64556885, 23.5879631], [88.64775085, 23.58665085], [88.6501236, 23.58547783], [88.65067291, 23.58464622], [88.65068054, 23.58402443], [88.65054321, 23.58384514], [88.65037537, 23.58361626], [88.64902496, 23.58255577], [88.64837646, 23.58154297], [88.64812469, 23.580513], [88.64849854, 23.57977676], [88.64920807, 23.57873154], [88.64981079, 23.57756615], [88.65026855, 23.57599258], [88.65036774, 23.57535362], [88.65049744, 23.5744648], [88.65093231, 23.57346153], [88.65123749, 23.572752], [88.65198517, 23.57060623], [88.65203857, 23.57021332], [88.65229034, 23.5683403], [88.65372467, 23.56553268], [88.65488434, 23.5632], [88.65476227, 23.56231499], [88.6540451, 23.56132889], [88.65545654, 23.55760956], [88.65596771, 23.55738068], [88.65670013, 23.55694962], [88.65670013, 23.55649948], [88.65744019, 23.55603027], [88.65888977, 23.55350876], [88.65975952, 23.55284882], [88.66015625, 23.55215836], [88.66015625, 23.55183983], [88.66160583, 23.55061913], [88.66162109, 23.55018806], [88.66162109, 23.5497303], [88.66455078, 23.54858971], [88.66945648, 23.54725838], [88.67087555, 23.54758453], [88.67280579, 23.54819489], [88.67390442, 23.54829216], [88.67469025, 23.54780769], [88.67552185, 23.54729652], [88.67708588, 23.54623413], [88.6782074, 23.54559898], [88.67912292, 23.54477119], [88.68017578, 23.54351234], [88.681427, 23.5427227], [88.68165588, 23.54255867], [88.68286133, 23.54169655], [88.68315125, 23.54121971], [88.68363953, 23.54021454], [88.6837616, 23.53995895], [88.68508911, 23.5390625], [88.68566895, 23.53839874], [88.68591309, 23.53759575], [88.6860199, 23.5364151], [88.68603516, 23.53559494], [88.68606567, 23.5339489], [88.68585205, 23.53278542], [88.6854248, 23.53192139], [88.68474579, 23.53130913], [88.68441772, 23.53031158], [88.68437958, 23.52985764], [88.68474579, 23.52947807], [88.68528748, 23.5294342], [88.68585968, 23.5298214], [88.68611908, 23.5300827], [88.68664551, 23.53063965], [88.68765259, 23.53160477], [88.68878937, 23.53182983], [88.69016266, 23.53155136], [88.69037628, 23.53150749], [88.69122314, 23.53085899], [88.69160461, 23.53022575], [88.69149017, 23.52879333], [88.6913147, 23.5263195], [88.69128418, 23.52594757], [88.69161224, 23.52451706], [88.69231415, 23.52411652], [88.69295502, 23.52415466], [88.69322205, 23.52417183], [88.6942749, 23.52511406], [88.69491577, 23.52571678], [88.69556427, 23.52577019], [88.69615936, 23.5254879], [88.6964035, 23.52489281], [88.69622803, 23.52391052], [88.69554901, 23.52192116], [88.69520569, 23.52022171], [88.69522095, 23.51869392], [88.69572449, 23.51750374], [88.69655609, 23.51698494], [88.69822693, 23.51594734], [88.69952393, 23.5155983], [88.70029449, 23.51580238], [88.70267487, 23.51672554], [88.70399475, 23.51709366], [88.70510864, 23.51719856], [88.70596313, 23.51696777], [88.70698547, 23.51616287], [88.70863342, 23.51431274], [88.70915222, 23.51369858], [88.70941925, 23.51337624], [88.71062469, 23.51194], [88.7119751, 23.510149], [88.71216583, 23.50989723], [88.71508026, 23.50855064], [88.71560669, 23.50861168], [88.71607208, 23.5089016], [88.71645355, 23.50940704], [88.71696472, 23.51024818], [88.71783447, 23.51113892], [88.71855927, 23.51179123], [88.71930695, 23.51198769], [88.72106934, 23.51209831], [88.72176361, 23.51236725], [88.72284698, 23.51290131], [88.72351837, 23.51285934], [88.72387695, 23.51268768], [88.72406769, 23.51259995], [88.72527313, 23.51151085], [88.7265625, 23.50987434], [88.72724152, 23.50865936], [88.7282486, 23.50714874], [88.72847748, 23.50680542], [88.72982025, 23.50423622], [88.73053741, 23.50264168], [88.73065186, 23.50123215], [88.73077393, 23.49917793], [88.73036957, 23.49838066], [88.73085022, 23.49678993], [88.73618317, 23.49345016], [88.73864746, 23.4918499], [88.73896027, 23.49164009], [88.73993683, 23.49073029], [88.74041748, 23.48913574], [88.74264526, 23.48674202], [88.7428894, 23.48497772], [88.74291992, 23.48477936], [88.74318695, 23.48447037], [88.74435425, 23.48313713], [88.74402618, 23.48301506], [88.7430191, 23.48263741], [88.74252319, 23.48211479], [88.74285889, 23.48098946], [88.74314117, 23.48127937], [88.74356079, 23.48137283], [88.74372101, 23.48093987], [88.74342346, 23.48056984], [88.74440765, 23.48015594], [88.74465179, 23.48044586], [88.74494171, 23.48078156], [88.74465179, 23.4817276], [88.74484253, 23.48297119], [88.74512482, 23.48337936], [88.74590302, 23.4836731], [88.7466507, 23.48370361], [88.74745941, 23.48325539], [88.74868011, 23.48245239], [88.75002289, 23.48134613], [88.75074768, 23.48074913], [88.75379181, 23.47914886], [88.75571442, 23.47866631], [88.75621033, 23.47903061], [88.75641632, 23.48345757], [88.7567215, 23.48490906], [88.75632477, 23.48540497], [88.75597382, 23.48654938], [88.75604248, 23.48762512], [88.75668335, 23.48868179], [88.7579422, 23.4896946], [88.75912476, 23.49037361], [88.76059723, 23.49081612], [88.76168823, 23.49084854], [88.76239014, 23.49047089], [88.76328278, 23.48925972], [88.76363373, 23.48816299], [88.76369476, 23.48792839], [88.7640686, 23.48648071], [88.7647934, 23.48496056], [88.76622009, 23.48253822], [88.76706696, 23.48170471], [88.76836395, 23.48091125], [88.76902771, 23.4807148], [88.77085876, 23.4801712], [88.77201843, 23.48130989], [88.77213287, 23.48427963], [88.77177429, 23.48517418], [88.77114868, 23.48674011], [88.76967621, 23.4869442], [88.76845551, 23.48727036], [88.76806641, 23.48760033], [88.76777649, 23.48812485], [88.76763916, 23.48896027], [88.76799011, 23.48999023], [88.76857758, 23.49101448], [88.76888275, 23.49155045], [88.76967621, 23.49301529], [88.76968384, 23.49319267], [88.76981354, 23.49495125], [88.76990509, 23.49569321], [88.77049255, 23.49713135], [88.77113342, 23.49790001], [88.77185059, 23.49840736], [88.77291107, 23.49882317], [88.7742691, 23.49917793], [88.77600861, 23.49974823], [88.7773819, 23.50019646], [88.77973175, 23.50102615], [88.7819519, 23.50185585], [88.78329468, 23.50253677], [88.78347778, 23.50268173], [88.78450012, 23.50350189], [88.78566742, 23.50489998], [88.78601074, 23.50561523], [88.78614807, 23.50589752], [88.786026, 23.5069313], [88.78655243, 23.50739098], [88.78675079, 23.50731087], [88.78686523, 23.50666046], [88.78677368, 23.50582504], [88.78668976, 23.50562859], [88.78647614, 23.50515938], [88.78642273, 23.50503922], [88.78636932, 23.50492859], [88.7862854, 23.50473213], [88.78598022, 23.50391197], [88.78475952, 23.50260735], [88.78408813, 23.50171661], [88.78357697, 23.50079155], [88.78336334, 23.50039291], [88.7833252, 23.50033188], [88.78333282, 23.50022888], [88.78337097, 23.49931717], [88.78340912, 23.49845123], [88.7844696, 23.4973011], [88.78594208, 23.4971714], [88.78704834, 23.49756432], [88.78765869, 23.49807549], [88.78800964, 23.49836922], [88.78842163, 23.49946594], [88.78869629, 23.50002098], [88.78874969, 23.50013161], [88.78968048, 23.5020256], [88.79055023, 23.50205231], [88.79185486, 23.50286102], [88.79361725, 23.50269699], [88.79426575, 23.5024662], [88.79470062, 23.50231361], [88.79528046, 23.50122452], [88.79801178, 23.49953079], [88.79868317, 23.4991188], [88.79969788, 23.49825096], [88.80042267, 23.4976368], [88.80040741, 23.49715805], [88.79974365, 23.4966526], [88.79898071, 23.49623108], [88.7979126, 23.49563599], [88.79794312, 23.49541473], [88.79827881, 23.49285316], [88.79920959, 23.49209785], [88.79934692, 23.49156189], [88.79927063, 23.49121475], [88.79872894, 23.48879242], [88.79547119, 23.48545456], [88.79743958, 23.48540115], [88.79821014, 23.48627472], [88.79949188, 23.48648643], [88.79984283, 23.48654556], [88.79997253, 23.4865284], [88.80138397, 23.48635674], [88.80088043, 23.48563576], [88.79964447, 23.48557281], [88.79947662, 23.48527336], [88.79962158, 23.48282051], [88.79797363, 23.48255348], [88.79655457, 23.4823246], [88.79608917, 23.48210144], [88.79518127, 23.48166847], [88.79454041, 23.4813652], [88.79443359, 23.4813118], [88.79406738, 23.48114014], [88.79379272, 23.47987556], [88.79376221, 23.47971535], [88.7927475, 23.47749519], [88.79247284, 23.47688293], [88.79152679, 23.47541618], [88.78984833, 23.472826], [88.78974915, 23.47266769], [88.78971863, 23.47175789], [88.78768158, 23.46996117], [88.78725433, 23.4695797], [88.78729248, 23.46920395], [88.78807068, 23.4688549], [88.78823853, 23.46856308], [88.78820038, 23.46846581], [88.78756714, 23.46743011], [88.78791809, 23.46712685], [88.7882309, 23.46685219], [88.78900146, 23.46681976], [88.78954315, 23.46679688], [88.78948975, 23.46662521], [88.78938293, 23.46629143], [88.78870392, 23.46604538], [88.78839874, 23.46593475], [88.7882843, 23.46558189], [88.78855133, 23.46545219], [88.7889328, 23.46526718], [88.78986359, 23.46585846], [88.78994751, 23.46574402], [88.7901001, 23.4655571], [88.78948975, 23.46495247], [88.78939819, 23.46478462], [88.78918457, 23.46440887], [88.78996277, 23.46422768], [88.79100037, 23.46474266], [88.79178619, 23.46323013], [88.79185486, 23.46308517], [88.79086304, 23.46298981], [88.7907486, 23.46298027], [88.79045868, 23.46030617], [88.7928009, 23.46115494], [88.79301453, 23.46103477], [88.79315186, 23.46095657], [88.79297638, 23.46044922], [88.79224396, 23.46027374], [88.78940582, 23.45959854], [88.78951263, 23.45924187], [88.79013062, 23.45881844], [88.79034424, 23.45802498], [88.79011536, 23.45679092], [88.79141998, 23.45598984], [88.79149628, 23.45594025], [88.79238129, 23.45580101], [88.79279327, 23.45548058], [88.79268646, 23.45509148], [88.79084015, 23.45374298], [88.79039764, 23.45342064], [88.79046631, 23.45287323], [88.79151154, 23.45230865], [88.79150391, 23.45116234], [88.79057312, 23.45098305], [88.79036713, 23.45058441], [88.7907486, 23.4485817], [88.79149628, 23.44799995], [88.79177856, 23.44778061], [88.79210663, 23.44787598], [88.79290009, 23.44810104], [88.79309082, 23.44803619], [88.79367828, 23.44783401], [88.79442596, 23.44757462], [88.79457092, 23.44699287], [88.79491425, 23.44560051], [88.79530334, 23.4440155], [88.79541016, 23.44360352], [88.79328156, 23.44426346], [88.79299164, 23.4423542], [88.79290771, 23.4423542], [88.7928009, 23.44241142], [88.79224396, 23.44271088], [88.79251862, 23.44394684], [88.79222107, 23.44413185], [88.79139709, 23.44461441], [88.79101563, 23.44455528], [88.79066467, 23.44371414], [88.79058838, 23.44309235], [88.79039001, 23.44157982], [88.79037476, 23.44150925], [88.78988647, 23.44139481], [88.7889328, 23.44162178], [88.7874527, 23.44177437], [88.78681183, 23.44233322], [88.78705597, 23.44260597], [88.7881012, 23.44287109], [88.78896332, 23.44281006], [88.78934479, 23.44278336], [88.78933716, 23.44298363], [88.78929901, 23.44435883], [88.78892517, 23.44457245], [88.78868103, 23.44470978], [88.78755188, 23.44475174], [88.78728485, 23.44447327], [88.78675079, 23.44463158], [88.78656769, 23.44468689], [88.78639984, 23.44473648], [88.78504944, 23.44491577], [88.78314972, 23.44195747], [88.78322601, 23.44037628], [88.78430939, 23.43990707], [88.78434753, 23.43982315], [88.78474426, 23.43900681], [88.78458405, 23.43883324], [88.78427124, 23.43849373], [88.78361511, 23.43869209], [88.78317261, 23.43942642], [88.78292847, 23.43983459], [88.78256226, 23.44020462], [88.78227997, 23.440485], [88.78148651, 23.43974876], [88.78144836, 23.43961525], [88.78138733, 23.43938065], [88.7811203, 23.43837357], [88.78192902, 23.43820381], [88.78265381, 23.43805122], [88.78297424, 23.43769264], [88.78276825, 23.43730545], [88.78168488, 23.43740273], [88.7815094, 23.43743515], [88.78089905, 23.43630028], [88.78018951, 23.43585014], [88.77797699, 23.43586922], [88.77513123, 23.43778992], [88.77350616, 23.43922997], [88.77350616, 23.43966866], [88.77304077, 23.43965912], [88.77304077, 23.44013023], [88.7700882, 23.44325829], [88.76985931, 23.44351959], [88.76883698, 23.44374084], [88.76529694, 23.44281006], [88.76442719, 23.44211006], [88.76299286, 23.43781281], [88.76265717, 23.43598366], [88.76194, 23.43425751], [88.76107788, 23.43347359], [88.76160431, 23.43285561], [88.76187897, 23.4325428], [88.76199341, 23.43240547], [88.76231384, 23.43203163], [88.76222992, 23.43157196], [88.76216125, 23.43119812], [88.7617569, 23.43110657], [88.76036072, 23.4235611], [88.75740814, 23.41900826], [88.75834656, 23.41326714], [88.75844574, 23.41324043], [88.75846863, 23.41292381], [88.75924683, 23.41069603], [88.75997162, 23.4100132], [88.76042938, 23.40973091], [88.76041412, 23.4095974], [88.76114655, 23.40891457], [88.7605896, 23.40758705], [88.76017761, 23.40721893], [88.75881195, 23.40599442], [88.75704193, 23.40464783], [88.75330353, 23.40352249], [88.75112152, 23.40286636], [88.75074005, 23.40174866], [88.75029755, 23.40048027], [88.75016785, 23.40011978], [88.74876404, 23.39814949], [88.74993134, 23.39686203], [88.75268555, 23.39582062], [88.75401306, 23.39531708], [88.75432587, 23.39519691], [88.75424957, 23.39503479], [88.75278473, 23.39221191], [88.75289917, 23.38956642], [88.75297546, 23.38927841], [88.7539978, 23.38886452], [88.75636292, 23.3885498], [88.75669861, 23.38819885], [88.75676727, 23.38812828], [88.75702667, 23.38785934], [88.75687408, 23.38633347], [88.7582016, 23.38592148], [88.75956726, 23.3847065], [88.75967407, 23.38503647], [88.76023865, 23.3868618], [88.76139069, 23.38671112], [88.76194, 23.38695526], [88.76284027, 23.38735199], [88.76187897, 23.38676834], [88.76127625, 23.38640404], [88.76113892, 23.38520241], [88.7618103, 23.38484383], [88.7624054, 23.38452721], [88.76182556, 23.38453865], [88.76130676, 23.38455009], [88.76084137, 23.38094139], [88.76081085, 23.38074303], [88.75943756, 23.38070488], [88.75914001, 23.38069725], [88.75871277, 23.37943459], [88.75869751, 23.37859917], [88.7589798, 23.37687874], [88.75924683, 23.37669563], [88.76030731, 23.37595558], [88.76007843, 23.37584114], [88.75946808, 23.37554169], [88.75911713, 23.37536812], [88.75932312, 23.37496185], [88.75953674, 23.37455368], [88.75971222, 23.37432861], [88.75987244, 23.37354851], [88.76074982, 23.37346458], [88.76197052, 23.37311554], [88.76290894, 23.37238121], [88.763237, 23.37207222], [88.76408386, 23.37126923], [88.76481628, 23.37042809], [88.76525879, 23.36991501], [88.76565552, 23.36915398], [88.76571655, 23.36831856], [88.76548767, 23.36767197], [88.76464844, 23.36642265], [88.7644577, 23.36618233], [88.7636795, 23.36517143], [88.76361847, 23.36509895], [88.76287842, 23.36406517], [88.76245117, 23.36353683], [88.76230621, 23.36174965], [88.7593689, 23.35900116], [88.75791168, 23.35832024], [88.75569916, 23.35852051], [88.75486755, 23.35881805], [88.75354767, 23.35924911], [88.75299835, 23.35943031], [88.75019836, 23.35806084], [88.74970245, 23.35806084], [88.74957275, 23.35762978], [88.74920654, 23.3564415], [88.74740601, 23.35057068], [88.74691772, 23.35011101], [88.74674988, 23.35008049], [88.74666595, 23.34961128], [88.74604034, 23.34897232], [88.74503326, 23.34872627], [88.7440033, 23.34867096], [88.74277496, 23.34897423], [88.74268341, 23.34900665], [88.74256134, 23.34904671], [88.7408905, 23.34962463], [88.73982239, 23.35019493], [88.73943329, 23.35040092], [88.73719025, 23.35174561], [88.73547363, 23.352808], [88.73438263, 23.35332489], [88.73373413, 23.35343742], [88.73316193, 23.35333824], [88.73272705, 23.3531189], [88.73218536, 23.35263634], [88.73214722, 23.35250473], [88.73194122, 23.35177422], [88.73207855, 23.35089111], [88.73240662, 23.34900665], [88.73285675, 23.34760094], [88.73327637, 23.34705353], [88.73387909, 23.34665298], [88.73397827, 23.34663391], [88.73449707, 23.34653854], [88.73535156, 23.34666443], [88.73592377, 23.34664536], [88.73698425, 23.34622383], [88.73738098, 23.34595108], [88.73786926, 23.34560966], [88.73860168, 23.34475517], [88.73894501, 23.34392166], [88.73908234, 23.34327698], [88.73898315, 23.34267998], [88.73855591, 23.34193611], [88.73773193, 23.341259], [88.73688507, 23.34055901], [88.73622131, 23.33983803], [88.73614502, 23.33971214], [88.73764038, 23.33854294], [88.73777008, 23.3380909], [88.73789215, 23.33761978], [88.73803711, 23.33151054], [88.73699188, 23.32925987], [88.73658752, 23.32835007], [88.73664856, 23.32753563], [88.73715973, 23.32761002], [88.74049377, 23.32818604], [88.74185181, 23.3282299], [88.74251556, 23.32825089], [88.74372864, 23.32809258], [88.74437714, 23.32771683], [88.74492645, 23.32707596], [88.74517059, 23.32650375], [88.74536133, 23.32521439], [88.74555969, 23.32460403], [88.74559784, 23.32447624], [88.74599457, 23.32390594], [88.74651337, 23.32343292], [88.74703979, 23.32315254], [88.74752808, 23.32289124], [88.74906158, 23.32216263], [88.7496109, 23.32176018], [88.74982452, 23.32135582], [88.74987793, 23.32090187], [88.74967194, 23.32056618], [88.74936676, 23.32020569], [88.74862671, 23.31943512], [88.74783325, 23.31830406], [88.74716949, 23.31715202], [88.74704742, 23.31690025], [88.74607849, 23.31494522], [88.74580383, 23.313797], [88.74580383, 23.31350327], [88.74597168, 23.31352425], [88.7461319, 23.31355667], [88.74623108, 23.31354904], [88.746315, 23.31349564], [88.74638367, 23.31344223], [88.74658203, 23.31326675], [88.74658966, 23.31318283], [88.74655914, 23.31309509], [88.74655914, 23.31297493], [88.74671936, 23.31277466], [88.74687195, 23.31274605], [88.74607849, 23.3098011], [88.74589539, 23.30956268], [88.7459259, 23.30892181], [88.74559784, 23.30784416], [88.74501038, 23.30712318], [88.74352264, 23.30605888], [88.74176788, 23.30520821], [88.74074554, 23.30496788], [88.74040222, 23.30488777], [88.73905945, 23.30485344], [88.73752594, 23.30507851], [88.73589325, 23.30563927], [88.73430634, 23.30645943], [88.73407745, 23.3065815], [88.7321701, 23.30787277], [88.73201752, 23.30797386], [88.73008728, 23.30963135], [88.72945404, 23.31053352], [88.72895813, 23.31165314], [88.72893524, 23.31172752], [88.7286911, 23.31258392], [88.72868347, 23.31332397], [88.72885895, 23.31382751], [88.72926331, 23.31457138], [88.72998047, 23.31546021], [88.73079681, 23.31642342], [88.73094177, 23.31672668], [88.73146057, 23.31779099], [88.73173523, 23.318964], [88.73157501, 23.31948853], [88.73117828, 23.3198204], [88.73087311, 23.31984138], [88.7305603, 23.31986237], [88.72957611, 23.319664], [88.72727966, 23.3191185], [88.72640991, 23.31885338], [88.7256012, 23.31860352], [88.72532654, 23.31837654], [88.72501373, 23.31812096], [88.72493744, 23.31766701], [88.72512054, 23.31726074], [88.72583008, 23.31681252], [88.72631073, 23.3162365], [88.72642517, 23.31610107], [88.72685242, 23.31531525], [88.72708893, 23.31436157], [88.72712708, 23.31359863], [88.7271347, 23.31252289], [88.72684479, 23.3103466], [88.72683716, 23.31010056], [88.72772217, 23.3092804], [88.72749329, 23.30632973], [88.72705078, 23.30538368], [88.727211, 23.30451775], [88.72756195, 23.30284882], [88.72742462, 23.30131721], [88.72727966, 23.30043221], [88.72694397, 23.29983139], [88.72589111, 23.29886818], [88.72494507, 23.29833412], [88.72328949, 23.29784393], [88.72112274, 23.29753876], [88.72028351, 23.29759216], [88.72013855, 23.2976017], [88.71920013, 23.29790497], [88.71888733, 23.29830933], [88.71881104, 23.29871368], [88.71898651, 23.29926491], [88.71906281, 23.29942894], [88.71671295, 23.2999897], [88.71644592, 23.30067062], [88.71523285, 23.3004303], [88.7144928, 23.30067062], [88.71324921, 23.3022728], [88.71209717, 23.30376053], [88.71113586, 23.30570412], [88.71069336, 23.30543518], [88.71038818, 23.30508041], [88.70995331, 23.30459213], [88.70910645, 23.30389214], [88.70802307, 23.30361938], [88.70787048, 23.30364037], [88.70714569, 23.30373192], [88.70644379, 23.30413246], [88.70625305, 23.30465698], [88.70616913, 23.30515862], [88.70639801, 23.30606842], [88.70655823, 23.30661011], [88.70682526, 23.30750465], [88.70713043, 23.30803108], [88.7075119, 23.30868149], [88.70825195, 23.30938148], [88.70933533, 23.30979538], [88.71073151, 23.31002235], [88.71165466, 23.31025505], [88.71191406, 23.3103199], [88.71279144, 23.31089973], [88.71299744, 23.3113327], [88.71291351, 23.31180954], [88.71260071, 23.31228447], [88.71194458, 23.31270981], [88.71072388, 23.31300926], [88.70940399, 23.31304741], [88.70875549, 23.31285858], [88.70855713, 23.31280136], [88.70796967, 23.31219864], [88.70677185, 23.31032562], [88.70541382, 23.3090229], [88.70361328, 23.30778885], [88.70222473, 23.30670357], [88.70160675, 23.3063736], [88.70011139, 23.30558586], [88.69823456, 23.30430412], [88.69685364, 23.30316925], [88.69624329, 23.30223274], [88.69625092, 23.30134773], [88.69652557, 23.29965401], [88.6968689, 23.29877281], [88.69716644, 23.29712105], [88.69719696, 23.29695892], [88.69719696, 23.29685974], [88.69716644, 23.29512405], [88.69713593, 23.29495811], [88.6969986, 23.29368401], [88.69713593, 23.29256248], [88.69763184, 23.29177666], [88.69812775, 23.29147148], [88.69875336, 23.29133224], [88.69983673, 23.29150963], [88.70159149, 23.29188156], [88.70373535, 23.29209137], [88.70534515, 23.29193687], [88.70640564, 23.2916584], [88.70760345, 23.29095268], [88.70916748, 23.28974533], [88.70948792, 23.28948593], [88.71047211, 23.28868103], [88.71115112, 23.28744507], [88.71179199, 23.2855854], [88.71192932, 23.28491783], [88.71195221, 23.28281593], [88.71154022, 23.2815609], [88.71277618, 23.27865982], [88.7140274, 23.27686119], [88.71486664, 23.27527046], [88.71537781, 23.27527046], [88.71537781, 23.27485847], [88.71704865, 23.27411079], [88.71971893, 23.27372742], [88.72173309, 23.27374268], [88.7231369, 23.27349091], [88.72331238, 23.27336502], [88.72381592, 23.272995], [88.72444153, 23.27190208], [88.72429657, 23.27106285], [88.72389221, 23.27000809], [88.72373199, 23.2696228], [88.72303009, 23.26789856], [88.72161102, 23.26506805], [88.721138, 23.26365471], [88.72081757, 23.26203156], [88.72064209, 23.26116562], [88.72033691, 23.2599411], [88.72009277, 23.25897789], [88.72003937, 23.25876999], [88.71943665, 23.25757027], [88.71885681, 23.25639534], [88.71880341, 23.25628853], [88.71949005, 23.25468826], [88.71987915, 23.25458717], [88.72246552, 23.25429726], [88.72467041, 23.25371742], [88.72677612, 23.25266075], [88.72875214, 23.25109863], [88.7294693, 23.2505455], [88.72998047, 23.25015259], [88.73291779, 23.24840736], [88.7352829, 23.24747086], [88.73636627, 23.24716949], [88.73773956, 23.24696541], [88.73864746, 23.24702072], [88.73923492, 23.24682617], [88.73994446, 23.24659348], [88.74233246, 23.24580765], [88.74294281, 23.24560928], [88.74513245, 23.24489784], [88.74739075, 23.24400711], [88.74861145, 23.24322891], [88.75035858, 23.24173737], [88.75097656, 23.24165535], [88.75227356, 23.2414856], [88.75347137, 23.24058342], [88.75390625, 23.24026108], [88.75904846, 23.24192238], [88.75998688, 23.2436161], [88.75977325, 23.24494171], [88.75962067, 23.24586487], [88.76050568, 23.24635124], [88.76241302, 23.24598503], [88.76291656, 23.24588966], [88.76434326, 23.24603653], [88.7651825, 23.24612427], [88.76594543, 23.24602318], [88.76739502, 23.24583244], [88.76799774, 23.24558067], [88.76888275, 23.24520683], [88.76947021, 23.24496269], [88.77033234, 23.24347115], [88.77127075, 23.24149895], [88.77268982, 23.24187279], [88.77285004, 23.24191475], [88.77361298, 23.24128532], [88.77424622, 23.24066353], [88.77383423, 23.23975372], [88.77296448, 23.23935127], [88.77323151, 23.2390461], [88.77451324, 23.23898697], [88.77555847, 23.23865128], [88.77590179, 23.23843384], [88.77622986, 23.23822021], [88.77618408, 23.23762703], [88.77609253, 23.23641014], [88.77796936, 23.23518372], [88.77700806, 23.23495674], [88.77571869, 23.23464966], [88.77548981, 23.23459625], [88.77469635, 23.23446274], [88.77680206, 23.2327404], [88.77802277, 23.22977829], [88.77803802, 23.22343063], [88.77900696, 23.22252846], [88.78079224, 23.2211628], [88.782341, 23.22121048], [88.78277588, 23.22196007], [88.7833252, 23.2229023], [88.78373718, 23.22278976], [88.78530121, 23.22236443], [88.78580475, 23.2222805], [88.78701019, 23.22208023], [88.7877655, 23.22195625], [88.78853607, 23.22021866], [88.78973389, 23.21848679], [88.79105377, 23.21829033], [88.79111481, 23.21878815], [88.7914505, 23.22168159], [88.79444122, 23.22003937], [88.79766846, 23.2191925], [88.80419922, 23.21879768], [88.80747223, 23.21945763], [88.8085556, 23.22006798], [88.81129456, 23.22161484], [88.81140137, 23.22167397], [88.81111145, 23.22200394], [88.80847931, 23.22497368], [88.80854034, 23.22529411], [88.8086319, 23.22571754], [88.80901337, 23.22762489], [88.80921936, 23.22865105], [88.80725861, 23.2307682], [88.8065033, 23.23159027], [88.80679321, 23.23388481], [88.80690002, 23.23501396], [88.80589294, 23.23809814], [88.80603027, 23.23853302], [88.80619049, 23.23901558], [88.8075943, 23.24333572], [88.80810547, 23.24401093], [88.80821228, 23.2440815], [88.80900574, 23.24503326], [88.80828857, 23.2455883], [88.80818939, 23.24566269], [88.80831146, 23.24581146], [88.80867004, 23.2489109], [88.80886078, 23.24937439], [88.80863953, 23.24951553], [88.80910492, 23.2513752], [88.80947113, 23.25312614], [88.80953979, 23.25335503], [88.81002045, 23.25499916], [88.81090546, 23.25476837], [88.81095123, 23.25620651], [88.81130219, 23.25624275], [88.81221771, 23.25634003], [88.81246185, 23.25597954], [88.81278229, 23.25551796], [88.81329346, 23.25379181], [88.81338501, 23.25347519], [88.81350708, 23.25271225], [88.81354523, 23.25248337], [88.81359863, 23.25216675], [88.81595612, 23.25082207], [88.81613159, 23.25074959], [88.81829834, 23.24987411], [88.81970978, 23.24907875], [88.82063293, 23.24855804], [88.82393646, 23.24729919], [88.82756042, 23.24551964], [88.82798767, 23.24530983], [88.82822418, 23.24519539], [88.82818604, 23.24498367], [88.82827759, 23.24497032], [88.83093262, 23.24468994], [88.82804108, 23.24057961], [88.82367706, 23.23742104], [88.82304382, 23.23603249], [88.82302856, 23.23548889], [88.82355499, 23.23415375], [88.82423401, 23.2337532], [88.82511139, 23.23390198], [88.82611084, 23.23438835], [88.82691193, 23.23513412], [88.82834625, 23.23617363], [88.83040619, 23.23759842], [88.83315277, 23.23948288], [88.8342514, 23.24114037], [88.83544922, 23.2429657], [88.83609009, 23.24373436], [88.83681488, 23.24381065], [88.83702087, 23.24372292], [88.83731079, 23.24359703], [88.837883, 23.24283981], [88.83867645, 23.24112511], [88.83925629, 23.23929214], [88.83930969, 23.2390976], [88.84010315, 23.23721695], [88.84030914, 23.23697472], [88.84112549, 23.23600578], [88.842659, 23.23496437], [88.84408569, 23.2341156], [88.84436798, 23.23371696], [88.84466553, 23.23328209], [88.84466553, 23.23278809], [88.84467316, 23.23270988], [88.84449768, 23.23257828], [88.84400177, 23.23221016], [88.84484863, 23.2306881], [88.84650421, 23.23057938], [88.85005188, 23.23053551], [88.85056305, 23.2311306], [88.85092926, 23.23155785], [88.85132599, 23.23408508], [88.85146332, 23.23409462], [88.8520813, 23.2341404], [88.85224152, 23.23415184], [88.8536377, 23.23425484], [88.85366058, 23.23467064], [88.85373688, 23.23646355], [88.85422516, 23.23624229], [88.85630035, 23.23530769], [88.85668945, 23.23527908], [88.85912323, 23.23508644], [88.85929871, 23.23453331], [88.85996246, 23.23243332], [88.86009979, 23.23239326], [88.86080933, 23.23218918], [88.86122131, 23.23207092], [88.86188507, 23.23381615], [88.86210632, 23.23438454], [88.86795807, 23.23393059], [88.86927032, 23.2338295], [88.87319946, 23.23420715], [88.87336731, 23.23421669], [88.87411499, 23.23425484], [88.87464905, 23.23428345], [88.87472534, 23.23408699], [88.87509155, 23.23323631], [88.87535858, 23.23259735], [88.87548828, 23.23229408], [88.87569427, 23.23230934], [88.87709045, 23.23241615], [88.87908936, 23.23139763], [88.88357544, 23.229599], [88.88475037, 23.22951317], [88.88572693, 23.22870827], [88.88572693, 23.22683907], [88.88572693, 23.22664452], [88.8857193, 23.22624016], [88.885849, 23.22620773], [88.88594818, 23.22618484], [88.88627625, 23.22610283], [88.88689423, 23.22649002], [88.88698578, 23.22696877], [88.88712311, 23.22773361], [88.88690186, 23.22977638], [88.88676453, 23.23112297], [88.88673401, 23.23142242], [88.88795471, 23.23132324], [88.88813019, 23.23130798], [88.8883667, 23.231287], [88.88925934, 23.23120499], [88.89037323, 23.2311039], [88.89086151, 23.23105812], [88.89183807, 23.2317543], [88.89225769, 23.2322979], [88.89239502, 23.23247337], [88.89256287, 23.23232841], [88.89367676, 23.23134041], [88.89488983, 23.23104286], [88.89507294, 23.23246765], [88.89588165, 23.23286247], [88.89614868, 23.23299217], [88.8962326, 23.23298836], [88.89717102, 23.23294258], [88.89784241, 23.23291016], [88.89862061, 23.23189545], [88.89876556, 23.23195267], [88.9000473, 23.23243141], [88.90032959, 23.23316193], [88.90060425, 23.23387527], [88.90132141, 23.2332077], [88.90316772, 23.23475456], [88.90391541, 23.23581886], [88.90484619, 23.23613358], [88.90498352, 23.23607445], [88.90589905, 23.235672], [88.905159, 23.23433113], [88.90640259, 23.23493385], [88.90674591, 23.23597336], [88.90678406, 23.23609734], [88.90744781, 23.23558426], [88.90803528, 23.23513222], [88.91052246, 23.23469734], [88.91091919, 23.23462868], [88.91217804, 23.23402786], [88.91207886, 23.23153496], [88.91207886, 23.2313633], [88.91256714, 23.2309494], [88.91334534, 23.23029518], [88.91407013, 23.22968102], [88.91492462, 23.22895813], [88.91487885, 23.22665215], [88.9148407, 23.22532463], [88.91479492, 23.22377586], [88.9157486, 23.22324181], [88.91660309, 23.22276306], [88.91612244, 23.21948051], [88.9147644, 23.21676064], [88.91435242, 23.21624756], [88.91387177, 23.21498108], [88.91388702, 23.2146492], [88.91390991, 23.21429825], [88.91469574, 23.21334076], [88.91478729, 23.21322441], [88.91503906, 23.21311951], [88.91610718, 23.21266747], [88.9163208, 23.21257782], [88.91753387, 23.21247482], [88.91848755, 23.21344948], [88.91851044, 23.2137928], [88.91854858, 23.21465111], [88.92001343, 23.21490669], [88.92008972, 23.21492004], [88.92093658, 23.21614647], [88.92111206, 23.21752167], [88.92118073, 23.21810913], [88.91925812, 23.2186985], [88.9188385, 23.21874428], [88.91678619, 23.21897507], [88.91661072, 23.21899414], [88.91664124, 23.21931648], [88.91664886, 23.21946907], [88.91667175, 23.21967888], [88.91899872, 23.21925926], [88.91957855, 23.21915436], [88.92025757, 23.21903229], [88.92280579, 23.21824074], [88.92302704, 23.21817207], [88.92286682, 23.21713638], [88.92275238, 23.21636581], [88.92272949, 23.21618271], [88.92295074, 23.21614456], [88.92401886, 23.21596527], [88.92478943, 23.21583748], [88.92499542, 23.21685982], [88.92519379, 23.21790123], [88.92636871, 23.21803665], [88.92646027, 23.21784401], [88.92694855, 23.21681023], [88.92706299, 23.21694756], [88.92767334, 23.21763992], [88.93023682, 23.21691704], [88.92980957, 23.21571541], [88.92856598, 23.21505356], [88.92887115, 23.21462822], [88.92897034, 23.21449089], [88.92936707, 23.21429443], [88.92961121, 23.21417236], [88.92940521, 23.21241951], [88.92939758, 23.21234512], [88.92929077, 23.21146393], [88.93315887, 23.20995712], [88.93392181, 23.20966148], [88.93455505, 23.20939827], [88.93933868, 23.20742798], [88.94215393, 23.20638275], [88.9422226, 23.20635796], [88.94746399, 23.20659065], [88.94944, 23.20932579], [88.95202637, 23.210989], [88.95241547, 23.21128273], [88.95256805, 23.21133614], [88.95270538, 23.21058083], [88.95458221, 23.21113968], [88.95482635, 23.21121979], [88.95600891, 23.21161079], [88.95650482, 23.21220779], [88.95716858, 23.21253204], [88.95762634, 23.2127533], [88.95836639, 23.21291351], [88.95936584, 23.21312904], [88.95936584, 23.21380806], [88.95937347, 23.21393394], [88.96059418, 23.2141552], [88.96399689, 23.21476936], [88.96466827, 23.21739769], [88.96540833, 23.21815491], [88.96627045, 23.21905518], [88.96643829, 23.21918678], [88.96734619, 23.21938324], [88.9675827, 23.21943283], [88.9682312, 23.21957397], [88.96871185, 23.22056961], [88.96878052, 23.22071838], [88.96886444, 23.22068024], [88.96949005, 23.22040558], [88.97026825, 23.22152328], [88.97058868, 23.22256851], [88.9706192, 23.22267532], [88.97138977, 23.22257042], [88.9716568, 23.22253418], [88.97218323, 23.2224617], [88.97317505, 23.22252083], [88.97415924, 23.22111893], [88.97422791, 23.22102356], [88.97496033, 23.2197094], [88.97530365, 23.21909523], [88.97705841, 23.21616745], [88.9776535, 23.21498299], [88.97782898, 23.21461868], [88.97893524, 23.21573639], [88.97798157, 23.21665192], [88.97639465, 23.21843338], [88.97568512, 23.21967125], [88.97542572, 23.22012901], [88.97427368, 23.22219467], [88.97418213, 23.22338867], [88.97477722, 23.22418594], [88.97494507, 23.22427177], [88.97554779, 23.22456932], [88.97678375, 23.22452927], [88.97834015, 23.22410965], [88.97943115, 23.22352219], [88.98030853, 23.22333336], [88.98110962, 23.2226181], [88.98149109, 23.22174072], [88.98141479, 23.22126198], [88.98300171, 23.22055817], [88.98257446, 23.22138977], [88.98262024, 23.22151947], [88.98274231, 23.22191048], [88.98311615, 23.2219429], [88.98350525, 23.22166634], [88.98412323, 23.22123718], [88.98445129, 23.22100258], [88.98442841, 23.22120857], [88.98435211, 23.22178459], [88.98471832, 23.22161865], [88.98493195, 23.22111702], [88.9850769, 23.22081566], [88.98566437, 23.21959305], [88.98591614, 23.21925926], [88.98893738, 23.21788979], [88.99015808, 23.21734047], [88.99207306, 23.21559525], [88.9925766, 23.21562195], [88.99269867, 23.21563148], [88.99407196, 23.21572685], [88.99500275, 23.21570969], [88.99583435, 23.21518898], [88.99599457, 23.21449661], [88.99563599, 23.21399307], [88.99506378, 23.21361542], [88.99494171, 23.21353531], [88.99398804, 23.21308517], [88.99375916, 23.21297646], [88.99272919, 23.21265984], [88.99151611, 23.21248436], [88.99093628, 23.21254158], [88.99060822, 23.21257401], [88.9897995, 23.21299934], [88.98963928, 23.21318626], [88.98886108, 23.21406937], [88.98761749, 23.21511269], [88.98626709, 23.21553421], [88.98484039, 23.21571541], [88.98461151, 23.21567345], [88.98336792, 23.21544266], [88.98236847, 23.21479225], [88.98116302, 23.21387672], [88.98044586, 23.21328545], [88.97966766, 23.21264648], [88.97940063, 23.21141624], [88.97955322, 23.21121788], [88.9801712, 23.21041679], [88.98038483, 23.21014214], [88.98139954, 23.20981407], [88.98280334, 23.20977211], [88.98314667, 23.20976067], [88.98403168, 23.20936775], [88.98426056, 23.20926857], [88.984375, 23.20921707], [88.9855957, 23.20876694], [88.98627472, 23.20793533], [88.98679352, 23.20705414], [88.98712921, 23.20576096], [88.98609161, 23.20475578], [88.98674774, 23.20395088], [88.98748779, 23.20304489], [88.98768616, 23.20279121], [88.98725891, 23.20277023], [88.986763, 23.20274734], [88.98583984, 23.20270348], [88.98561096, 23.20269203], [88.9847641, 23.20164871], [88.98442841, 23.20030975], [88.98530579, 23.19996643], [88.98404694, 23.19906998], [88.98306274, 23.1978302], [88.98273468, 23.19663239], [88.98193359, 23.19576645], [88.98176575, 23.19558144], [88.98188019, 23.19506264], [88.98196411, 23.19469452], [88.98004913, 23.19385529], [88.98144531, 23.19262695], [88.98064423, 23.19193268], [88.98025513, 23.19159889], [88.97989655, 23.1912899], [88.97977448, 23.18964386], [88.97932434, 23.18935776], [88.97819519, 23.18864822], [88.97821045, 23.18845367], [88.97827911, 23.1871376], [88.97827911, 23.18702316], [88.97888947, 23.18704605], [88.97956085, 23.18707085], [88.97871399, 23.18670273], [88.97853851, 23.18523407], [88.97867584, 23.18389893], [88.97871399, 23.18348885], [88.97962952, 23.18302727], [88.98036194, 23.18265724], [88.97950745, 23.18286705], [88.97860718, 23.18309212], [88.97820282, 23.18391991], [88.97796631, 23.18342972], [88.97746277, 23.18237305], [88.9769516, 23.18201637], [88.97644043, 23.1818943], [88.97602081, 23.18197632], [88.97598267, 23.18222237], [88.97566223, 23.18427467], [88.9756012, 23.18570137], [88.9752655, 23.18671799], [88.97514343, 23.18707466], [88.97542572, 23.18710899], [88.9757843, 23.18715096], [88.97587585, 23.1871624], [88.97586823, 23.18737602], [88.9758606, 23.18750191], [88.9757843, 23.18893242], [88.97537231, 23.1895504], [88.97499847, 23.19011688], [88.97483063, 23.19037819], [88.97467804, 23.19150734], [88.97472382, 23.19158745], [88.9748764, 23.19182396], [88.97530365, 23.19249153], [88.9743576, 23.19295883], [88.97067261, 23.19336128], [88.9664917, 23.19382477], [88.96438599, 23.19348335], [88.96224213, 23.19326782], [88.96179962, 23.19322205], [88.9617157, 23.19294357], [88.96153259, 23.19233131], [88.96122742, 23.19129372], [88.9609375, 23.1911602], [88.96063232, 23.19101906], [88.9597702, 23.19061852], [88.95941162, 23.19041634], [88.95862579, 23.18996239], [88.95826721, 23.18975639], [88.95825195, 23.18962097], [88.95792389, 23.1866684], [88.95783997, 23.18640327], [88.95738983, 23.18495941], [88.95743561, 23.18471146], [88.95770264, 23.18338776], [88.95781708, 23.1827755], [88.95715332, 23.18217278], [88.95617676, 23.18200684], [88.95462799, 23.18208313], [88.95426941, 23.1821022], [88.95419312, 23.18210602], [88.95275879, 23.18217468], [88.95095062, 23.18226051], [88.95095062, 23.1811924], [88.94787598, 23.18087769], [88.94617462, 23.18070412], [88.94606781, 23.18059349], [88.94585419, 23.18037224], [88.9434967, 23.17795944], [88.94391632, 23.17686844], [88.94412994, 23.17632294], [88.93929291, 23.1768837], [88.93901062, 23.17691803], [88.9389267, 23.17665291], [88.93815613, 23.17428207], [88.93806458, 23.1740036], [88.93795776, 23.17362976], [88.93771362, 23.17276192], [88.93649292, 23.1726284], [88.93527985, 23.1724968], [88.93526459, 23.17230415], [88.93506622, 23.1705265], [88.93424988, 23.16996956], [88.93388367, 23.16941071], [88.93345642, 23.16876602], [88.93333435, 23.16828537], [88.93269348, 23.16573906], [88.93265533, 23.16556549], [88.93344879, 23.16508293], [88.93409729, 23.16469002], [88.93428802, 23.16330147], [88.93401337, 23.16191483], [88.93340302, 23.16194725], [88.93318939, 23.1619606], [88.93250275, 23.16199684], [88.93157959, 23.16204643], [88.93156433, 23.16263962], [88.93082428, 23.16282654], [88.92819977, 23.16348648], [88.92803192, 23.16352844], [88.92783356, 23.16317749], [88.92802429, 23.16311646], [88.93013, 23.16242981], [88.93009186, 23.16219139], [88.92805481, 23.16275406], [88.92782593, 23.16101265], [88.92781067, 23.16086006], [88.92789459, 23.16086769], [88.92978668, 23.16100883], [88.93114471, 23.16008759], [88.93054962, 23.15782738], [88.93062592, 23.15768623], [88.93127441, 23.15641785], [88.93151093, 23.15637016], [88.93219757, 23.15623665], [88.93227386, 23.15622139], [88.93209076, 23.15487099], [88.93202972, 23.15440369], [88.93216705, 23.15436935], [88.93241119, 23.15430641], [88.93224335, 23.15170479], [88.93202209, 23.14969826], [88.93198395, 23.14911652], [88.93187714, 23.14715958], [88.93185425, 23.14666176], [88.93160248, 23.14561272], [88.9315033, 23.14598846], [88.93127441, 23.14685059], [88.93118286, 23.14685631], [88.9307251, 23.14688873], [88.93054199, 23.14690018], [88.93061829, 23.14551544], [88.93062592, 23.14536285], [88.93070984, 23.14483833], [88.93145752, 23.14040947], [88.93135071, 23.13858032], [88.93061829, 23.13815117], [88.92867279, 23.13857079], [88.92571259, 23.14015007], [88.92513275, 23.13992119], [88.92463684, 23.13983917], [88.92269135, 23.13948059], [88.92196655, 23.13508034], [88.92154694, 23.13252258], [88.92147064, 23.12745094], [88.92086792, 23.12610054], [88.91821289, 23.12451172], [88.91133118, 23.12355995], [88.90851593, 23.12152863], [88.90804291, 23.12152863], [88.90499878, 23.11540031], [88.90357208, 23.11383057], [88.90184021, 23.11180115], [88.89745331, 23.10608101], [88.89131927, 23.102911], [88.88787079, 23.10499001], [88.88723755, 23.10476112], [88.88580322, 23.10560036], [88.88421631, 23.10470009], [88.88179779, 23.09902954], [88.881073, 23.09832954], [88.88056946, 23.0981102], [88.87982178, 23.0977726], [88.87909698, 23.09744072], [88.87420654, 23.09765053], [88.87187195, 23.09674644], [88.87176514, 23.09580612], [88.8734436, 23.09566498], [88.8735733, 23.09465408], [88.87386322, 23.09245491], [88.873909, 23.09210587], [88.87399292, 23.0920887], [88.87482452, 23.09191513], [88.87408447, 23.09184265], [88.87400818, 23.09183502], [88.87454224, 23.09006691], [88.87458801, 23.08992004], [88.87376404, 23.08950615], [88.87364197, 23.08944511], [88.87310028, 23.08917618], [88.87281799, 23.08903313], [88.87217712, 23.08911514], [88.87107849, 23.08925629], [88.8708725, 23.08913612], [88.87091827, 23.08889008], [88.87106323, 23.08806229], [88.87108612, 23.08793449], [88.87155151, 23.08692741], [88.8712616, 23.08695602], [88.87038422, 23.08704376], [88.87036896, 23.08690262], [88.87024689, 23.08611298], [88.86819458, 23.08639526], [88.86804199, 23.08638191], [88.86698914, 23.08629417], [88.86644745, 23.0862484], [88.86616516, 23.0862236], [88.86614227, 23.08589172], [88.8660965, 23.0853157], [88.86599731, 23.08413506], [88.8659668, 23.08190918], [88.86484528, 23.08068275], [88.86467743, 23.08052254], [88.86398315, 23.07990646], [88.8636322, 23.07959366], [88.86447144, 23.07896042], [88.86514282, 23.07845879], [88.86547852, 23.07796478], [88.86553955, 23.07788086], [88.86528778, 23.07753563], [88.86487579, 23.07766151], [88.8636322, 23.07804108], [88.86253357, 23.07885551], [88.86129761, 23.0788784], [88.8611145, 23.07801437], [88.86099243, 23.07744598], [88.86327362, 23.0769825], [88.86296082, 23.07604408], [88.86603546, 23.07429504], [88.86687469, 23.07376289], [88.86755371, 23.07340622], [88.86766815, 23.07334709], [88.86817169, 23.07261848], [88.86816406, 23.07183838], [88.86786652, 23.07184029], [88.86735535, 23.07289886], [88.86722565, 23.07292366], [88.86693573, 23.07297897], [88.86673737, 23.0715847], [88.86733246, 23.0714283], [88.86753845, 23.07063484], [88.86828613, 23.06909943], [88.86859894, 23.06874657], [88.86941528, 23.06782532], [88.86959076, 23.06772614], [88.87014771, 23.06753159], [88.8703537, 23.0674572], [88.87097931, 23.06734657], [88.8724823, 23.06660461], [88.87280273, 23.06651878], [88.87378693, 23.06625557], [88.87366486, 23.06548119], [88.87324524, 23.06280136], [88.87322998, 23.06219482], [88.87363434, 23.06202126], [88.87413788, 23.06191254], [88.87452698, 23.06183052], [88.87471008, 23.06179237], [88.87503052, 23.06172562], [88.87499237, 23.06149864], [88.87468719, 23.05952454], [88.87454987, 23.05864906], [88.87431335, 23.05822754], [88.87406158, 23.05695152], [88.87451935, 23.05566406], [88.87485504, 23.05557823], [88.87478638, 23.05482101], [88.87454224, 23.05334282], [88.87435913, 23.0520668], [88.8742981, 23.05165291], [88.87416077, 23.05077934], [88.87444305, 23.05066681], [88.87499237, 23.05049515], [88.87513733, 23.05045128], [88.87481689, 23.04949951], [88.8745575, 23.04885101], [88.87467957, 23.04675293], [88.87503815, 23.04665565], [88.87497711, 23.04567528], [88.87490845, 23.0446434], [88.87494659, 23.04442406], [88.87602234, 23.04408264], [88.87698364, 23.0435257], [88.87767029, 23.04289818], [88.87850952, 23.04200935], [88.87992096, 23.04115677], [88.8816452, 23.04060936], [88.88274384, 23.04047966], [88.88318634, 23.04042625], [88.88408661, 23.04055214], [88.88407898, 23.04045105], [88.88394928, 23.03907967], [88.88421631, 23.03882408], [88.88420868, 23.03874397], [88.88368225, 23.03751183], [88.8844223, 23.0371666], [88.88420868, 23.03661346], [88.88368988, 23.03686333], [88.88343048, 23.03704453], [88.88311768, 23.03725243], [88.88267517, 23.03728294], [88.88214111, 23.03712273], [88.88208008, 23.03601646], [88.88185883, 23.0344677], [88.88173676, 23.03360748], [88.88150787, 23.03366661], [88.88076782, 23.03385735], [88.88004303, 23.03198814], [88.88054657, 23.03030586], [88.88049316, 23.02832031], [88.87989044, 23.02644348], [88.88095093, 23.02596283], [88.88090515, 23.02556038], [88.88026428, 23.02496338], [88.87968445, 23.02505875], [88.8799057, 23.02584839], [88.87900543, 23.02603722], [88.8789444, 23.0247612], [88.87963104, 23.02463341], [88.87887573, 23.02445984], [88.87806702, 23.02427101], [88.87834167, 23.02543831], [88.8784256, 23.02584648], [88.87848663, 23.02611542], [88.8776474, 23.02621078], [88.87721252, 23.0261898], [88.87704468, 23.02494812], [88.87687683, 23.02290916], [88.87567902, 23.02272987], [88.8747406, 23.02207565], [88.87374115, 23.02074242], [88.87275696, 23.01922798], [88.87252045, 23.01874542], [88.87223053, 23.01769066], [88.87217712, 23.01674843], [88.87296295, 23.01607323], [88.87355042, 23.01531601], [88.87380219, 23.01510048], [88.87407684, 23.01486206], [88.87451172, 23.01442719], [88.87462616, 23.01379776], [88.87450409, 23.01234818], [88.87440491, 23.01110649], [88.87439728, 23.01101303], [88.8742981, 23.0101738], [88.87638855, 23.0101738], [88.8784256, 23.01005554], [88.87979126, 23.00936699], [88.88017273, 23.00847435], [88.88011169, 23.00790596], [88.87973785, 23.00629044], [88.87906647, 23.00468826], [88.87847137, 23.00386047], [88.87841797, 23.00378418], [88.87786102, 23.00340271], [88.87722778, 23.00324821], [88.87661743, 23.00330162], [88.87342072, 23.00444794], [88.87341309, 23.00434113], [88.87304688, 23.00342941], [88.87082672, 23.00183105], [88.87034607, 23.00162125], [88.87021637, 23.00164032], [88.86496735, 23.00271988], [88.85787964, 23.0053196], [88.85323334, 23.00699043], [88.84868622, 23.00605965], [88.84777832, 23.00549316], [88.84777069, 23.00535774], [88.85010529, 23.00306702], [88.85205078, 23.00209236], [88.85287476, 23.00203323], [88.85431671, 23.00236702], [88.85617828, 23.00269508], [88.85803986, 23.00282288], [88.85837555, 23.00283051], [88.86050415, 23.00287056], [88.86222076, 23.00256729], [88.86377716, 23.00199127], [88.86483765, 23.00120163], [88.86558533, 23.00038338], [88.86566925, 22.99960136], [88.8653717, 22.99889755], [88.86512756, 22.99830818], [88.86437225, 22.99615097], [88.86395264, 22.99480057], [88.86389923, 22.9933567], [88.86387634, 22.99273109], [88.86385345, 22.99191856], [88.86434174, 22.98886108], [88.86488342, 22.98647308], [88.86579895, 22.98381615], [88.86656952, 22.98257446], [88.86727905, 22.98150444], [88.8673172, 22.98143959], [88.86777496, 22.98116493], [88.86903381, 22.98175621], [88.86920166, 22.98053169], [88.86919403, 22.98029518], [88.87068176, 22.97936249], [88.87107849, 22.97874641], [88.87098694, 22.9785347], [88.87062073, 22.97763443], [88.86952209, 22.97667503], [88.86904144, 22.9763813], [88.86633301, 22.97474289], [88.86499023, 22.97414589], [88.86368561, 22.9737072], [88.86038971, 22.97253609], [88.85954285, 22.97223663], [88.85845947, 22.97148514], [88.85758209, 22.97004128], [88.85697937, 22.96884155], [88.85617828, 22.96635437], [88.85557556, 22.96424294], [88.85508728, 22.96120644], [88.85498047, 22.95913315], [88.85516357, 22.95760727], [88.85585785, 22.95425797], [88.85721588, 22.95056725], [88.85820007, 22.94754219], [88.85848236, 22.94564247], [88.85889435, 22.9437542], [88.85958862, 22.94245529], [88.8599472, 22.94222069], [88.86045074, 22.94220924], [88.86075592, 22.94239807], [88.86080933, 22.94249535], [88.86102295, 22.94290924], [88.86135864, 22.94419289], [88.86206055, 22.94556236], [88.86358643, 22.9472065], [88.86468506, 22.94823456], [88.86707306, 22.95033646], [88.86828613, 22.95137405], [88.86885834, 22.95158386], [88.86917877, 22.95156479], [88.87114716, 22.95058823], [88.87210083, 22.94988632], [88.8735199, 22.94869804], [88.87411499, 22.94832993], [88.87464905, 22.94824791], [88.87537384, 22.94838905], [88.87584686, 22.94853592], [88.87615204, 22.94870567], [88.87650299, 22.94889832], [88.87733459, 22.94990921], [88.87773895, 22.95075417], [88.87779999, 22.95088577], [88.87786102, 22.95126343], [88.8780899, 22.952631], [88.8782959, 22.95350647], [88.87869263, 22.95406151], [88.8795166, 22.9542675], [88.88109589, 22.95412254], [88.88467407, 22.95380974], [88.88693237, 22.95357513], [88.8913269, 22.95306015], [88.89315796, 22.95282936], [88.89350128, 22.95269966], [88.89363098, 22.95265198], [88.89405823, 22.95248413], [88.89433289, 22.95223045], [88.89434052, 22.9519577], [88.89435577, 22.95149994], [88.89411163, 22.95108795], [88.89396667, 22.9508419], [88.89331055, 22.94963264], [88.89283752, 22.94818306], [88.89251709, 22.94708252], [88.89241028, 22.94607925], [88.89237976, 22.94427872], [88.89260864, 22.94280243], [88.89266205, 22.9419651], [88.89287567, 22.94005585], [88.89303589, 22.93868446], [88.89289856, 22.93796539], [88.89268494, 22.93767548], [88.89420319, 22.93766403], [88.8943634, 22.93766594], [88.89455414, 22.93769264], [88.89472961, 22.93772507], [88.8948822, 22.93775368], [88.89510345, 22.93779373], [88.89518738, 22.93785858], [88.89537811, 22.93790054], [88.89547729, 22.93795013], [88.89559174, 22.93799973], [88.89572144, 22.93807602], [88.89587402, 22.93816376], [88.89595795, 22.93825531], [88.89602661, 22.93836403], [88.8961792, 22.93849373], [88.89622498, 22.93862152], [88.89624786, 22.9387455], [88.89635468, 22.93886566], [88.89641571, 22.93901825], [88.89653778, 22.93918419], [88.8966217, 22.93932343], [88.89672852, 22.93946838], [88.89696503, 22.93949509], [88.89717102, 22.93939972], [88.89727783, 22.93922806], [88.89725494, 22.9391098], [88.89723206, 22.93895912], [88.8972168, 22.93885422], [88.89720154, 22.93876076], [88.89718628, 22.9386692], [88.89717102, 22.93855667], [88.89715576, 22.93844795], [88.89713287, 22.9383297], [88.89710236, 22.93814278], [88.89706421, 22.93793869], [88.89704895, 22.93783188], [88.8969574, 22.9372921], [88.89665222, 22.93547821], [88.89624786, 22.93305969], [88.89698792, 22.92674065], [88.90174866, 22.92406654], [88.90414429, 22.92303848], [88.90575409, 22.92243195], [88.90591431, 22.92231941], [88.90873718, 22.92197037], [88.91018677, 22.92179108], [88.91177368, 22.92042732], [88.91172028, 22.92037582], [88.91159058, 22.92027664], [88.91142273, 22.92012405], [88.91129303, 22.92002678], [88.91112518, 22.9199295], [88.91099548, 22.9199028], [88.91086578, 22.91990471], [88.9107132, 22.9199295], [88.9104538, 22.91992569], [88.91020966, 22.91984367], [88.91007233, 22.91975784], [88.90998077, 22.91969299], [88.90968323, 22.91953468], [88.90956116, 22.91944122], [88.90919495, 22.91926765], [88.90858459, 22.91915894], [88.90853119, 22.91867447], [88.90840149, 22.91829872], [88.90817261, 22.91762352], [88.90758514, 22.91638565], [88.90742493, 22.9160347], [88.90656281, 22.91504669], [88.90606689, 22.91479683], [88.90537262, 22.91444397], [88.90406036, 22.91416931], [88.90332794, 22.91414261], [88.89952087, 22.91426659], [88.89852142, 22.91430283], [88.8968811, 22.91454887], [88.89598846, 22.91458702], [88.89559174, 22.91443253], [88.89537811, 22.913908], [88.89532471, 22.91324806], [88.895401, 22.91285515], [88.8955307, 22.91218185], [88.8959198, 22.91139603], [88.89646912, 22.91068268], [88.89762878, 22.90971565], [88.89865112, 22.90886879], [88.90028381, 22.90760422], [88.90084839, 22.90709305], [88.90112305, 22.90672874], [88.90123749, 22.90638542], [88.90123749, 22.90598297], [88.90111542, 22.90419769], [88.90100098, 22.90331459], [88.9005661, 22.90201378], [88.90037537, 22.90166664], [88.8992157, 22.89961433], [88.89822388, 22.89782333], [88.89855194, 22.89768028], [88.89927673, 22.89736557], [88.90138245, 22.89653397], [88.90226746, 22.89577866], [88.90274048, 22.89537239], [88.9040451, 22.89574432], [88.90445709, 22.89586258], [88.90487671, 22.89522552], [88.90524292, 22.89413071], [88.90586853, 22.89407158], [88.90634155, 22.89399529], [88.90779114, 22.893713], [88.90736389, 22.89340591], [88.90632629, 22.89266586], [88.90538025, 22.89254761], [88.90534973, 22.89229393], [88.90505981, 22.88989258], [88.90518951, 22.88950729], [88.90540314, 22.88884926], [88.9056015, 22.88805771], [88.90573883, 22.88791847], [88.90584564, 22.88780975], [88.90615845, 22.88745499], [88.90705872, 22.88715363], [88.90769958, 22.88715744], [88.90808105, 22.88715363], [88.9077301, 22.8869915], [88.90801239, 22.88532066], [88.90884399, 22.88513184], [88.90982056, 22.88482666], [88.90921021, 22.88157082], [88.91191864, 22.88182449], [88.91268158, 22.88160706], [88.91252899, 22.88113976], [88.91227722, 22.88114166], [88.91194153, 22.88056183], [88.91149139, 22.88050842], [88.91096497, 22.88072205], [88.91065216, 22.88084793], [88.90962219, 22.88101768], [88.90951538, 22.88030434], [88.90982819, 22.88018608], [88.90979004, 22.8798027], [88.91203308, 22.87870789], [88.91249847, 22.87856483], [88.91307068, 22.87839127], [88.91329956, 22.87909508], [88.91352844, 22.8798008], [88.91490173, 22.8794117], [88.91537476, 22.87927818], [88.91654205, 22.87894821], [88.91799927, 22.87857437], [88.91785431, 22.87739754], [88.91880798, 22.877388], [88.91917419, 22.87766838], [88.92108154, 22.87913895], [88.92251587, 22.8802433], [88.92272186, 22.8797245], [88.92355347, 22.87761497], [88.92394257, 22.87661362], [88.92633057, 22.87530136], [88.92793274, 22.87264824], [88.93057251, 22.87363625], [88.93336487, 22.87438774], [88.93717957, 22.874403], [88.93987274, 22.87494278], [88.94030762, 22.87579918], [88.9405899, 22.87635231], [88.94115448, 22.87727928], [88.94152069, 22.877882], [88.94163513, 22.87840271], [88.9419632, 22.87987518], [88.94303894, 22.88032722], [88.94465637, 22.88062477], [88.94498444, 22.88054466], [88.94608307, 22.88008118], [88.94624329, 22.87993431], [88.9468689, 22.87892342], [88.94776154, 22.87800217], [88.94879913, 22.8777771], [88.94944763, 22.87742233], [88.94976044, 22.87639427], [88.9495697, 22.87486839], [88.94956207, 22.87478638], [88.94948578, 22.87363625], [88.94967651, 22.8730545], [88.95011902, 22.87238312], [88.95040131, 22.87230301], [88.95104218, 22.872118], [88.95154572, 22.87185287], [88.95194244, 22.87065506], [88.95227051, 22.87008286], [88.95284271, 22.86932755], [88.95332336, 22.86841965], [88.95337677, 22.8679924], [88.95346069, 22.86771584], [88.95378113, 22.86672401], [88.95368195, 22.86618614], [88.95339966, 22.86572647], [88.95300293, 22.86524963], [88.95288086, 22.86484528], [88.95296478, 22.86442757], [88.95334625, 22.86400986], [88.95344543, 22.8639946], [88.95407867, 22.86390495], [88.95483398, 22.86409378], [88.95542145, 22.86401939], [88.95595551, 22.86372566], [88.95735931, 22.86268044], [88.95789337, 22.86184692], [88.95850372, 22.86065674], [88.95874786, 22.85991669], [88.95868683, 22.85940552], [88.95821381, 22.85803604], [88.9580307, 22.85748863], [88.95795441, 22.85696602], [88.957901, 22.85663795], [88.9580307, 22.85631371], [88.95849609, 22.85594368], [88.96052551, 22.85513496], [88.96111298, 22.85468864], [88.96392822, 22.85131264], [88.96613312, 22.84826851], [88.96813965, 22.84517479], [88.96850586, 22.84414482], [88.96852875, 22.84347534], [88.9679718, 22.84131241], [88.96774292, 22.84044075], [88.96718597, 22.8383007], [88.96714783, 22.83790588], [88.96705627, 22.83685112], [88.96642303, 22.82889175], [88.96324921, 22.81937981], [88.96201324, 22.8168602], [88.96157074, 22.8135376], [88.96108246, 22.80984116], [88.96045685, 22.80938148], [88.96035004, 22.80912018], [88.95910645, 22.80599022], [88.9588089, 22.80336952], [88.95863342, 22.80184174], [88.95851898, 22.80085754], [88.95852661, 22.80068207], [88.95851898, 22.8002491], [88.95851898, 22.80007553], [88.95887756, 22.79794502], [88.95867157, 22.79763031], [88.95847321, 22.79733276], [88.95847321, 22.79715919], [88.95813751, 22.79638863], [88.95783234, 22.79600334], [88.95720673, 22.79622459], [88.95710754, 22.79625893], [88.9571991, 22.79599571], [88.95731354, 22.79595947], [88.95746613, 22.79594421], [88.95761871, 22.79592323], [88.95808411, 22.7959156], [88.95834351, 22.79593468], [88.95845795, 22.79593468], [88.95844269, 22.79421043], [88.95774078, 22.79355049], [88.95065308, 22.79214287], [88.9477005, 22.79100227], [88.94158936, 22.78806114], [88.94141388, 22.78795624], [88.94046783, 22.78741264], [88.93917084, 22.78667259], [88.93894958, 22.78651237], [88.93834686, 22.78600121], [88.9365921, 22.78457069], [88.93584442, 22.78394508], [88.93623352, 22.78306198], [88.93611908, 22.78302765], [88.93590546, 22.78243828], [88.93577576, 22.78244209], [88.9356308, 22.78198051], [88.93544769, 22.78201675], [88.93436432, 22.78223801], [88.93392181, 22.78233719], [88.9329834, 22.78155136], [88.93258667, 22.78121948], [88.93006134, 22.7748909], [88.9296875, 22.77396965], [88.92708588, 22.77189064], [88.92682648, 22.77158165], [88.9259491, 22.77061653], [88.92576599, 22.77000999], [88.92560577, 22.77003098], [88.9254303, 22.77005005], [88.92520905, 22.76980782], [88.9251709, 22.77008057], [88.92237854, 22.77040863], [88.91938782, 22.77096939], [88.91892242, 22.77105331], [88.9186554, 22.77082253], [88.91841888, 22.77061462], [88.91704559, 22.76942635], [88.91675568, 22.76910782], [88.91599274, 22.76792717], [88.91535187, 22.76675415], [88.91468048, 22.76552391], [88.91452789, 22.76522064], [88.91396332, 22.76399231], [88.91364288, 22.76364708], [88.91356659, 22.76355362], [88.91368103, 22.76351166], [88.9131012, 22.76253319], [88.91396332, 22.76224899], [88.91384888, 22.76186371], [88.91348267, 22.76067543], [88.91308594, 22.76072311], [88.91311646, 22.76019478], [88.9130249, 22.7600956], [88.91287231, 22.76009369], [88.9125824, 22.76006317], [88.91231537, 22.75994873], [88.91221619, 22.75971985], [88.91220093, 22.75951004], [88.91189575, 22.7595005], [88.91178894, 22.75941658], [88.91146851, 22.75889778], [88.91121674, 22.75824547], [88.91098022, 22.75786209], [88.91104889, 22.75765038], [88.91123962, 22.75754929], [88.91139221, 22.7574482], [88.91153717, 22.75721931], [88.91170502, 22.75696754], [88.91194153, 22.75664711], [88.91229248, 22.75628471], [88.91249084, 22.75605392], [88.9125061, 22.75587845], [88.91249847, 22.75576019], [88.91244507, 22.75555801], [88.91223145, 22.75500298], [88.91217804, 22.75483894], [88.91223145, 22.75471878], [88.91239166, 22.75471115], [88.9128952, 22.75465202], [88.91301727, 22.75463295], [88.91337585, 22.75457764], [88.91382599, 22.75432777], [88.9141922, 22.75418854], [88.91447449, 22.75407791], [88.91484833, 22.75427818], [88.91512299, 22.75463295], [88.91529846, 22.754776], [88.91519928, 22.75487328], [88.91537476, 22.75500488], [88.91545868, 22.75492668], [88.91659546, 22.75542641], [88.91760254, 22.75533867], [88.91838837, 22.75475121], [88.91921234, 22.75435448], [88.91980743, 22.75406837], [88.92017365, 22.75406456], [88.9209137, 22.75279999], [88.92073822, 22.75278091], [88.92028046, 22.75273514], [88.92063904, 22.75168228], [88.92069244, 22.75153542], [88.92110443, 22.75025558], [88.92108154, 22.74983025], [88.92066956, 22.74925804], [88.92044067, 22.74898148], [88.92028809, 22.74879074], [88.91954041, 22.7486496], [88.91941071, 22.74852753], [88.91889191, 22.74846649], [88.91843414, 22.74814415], [88.91812897, 22.74784851], [88.91762543, 22.74668694], [88.91751099, 22.74608994], [88.91738129, 22.74547386], [88.91695404, 22.7449131], [88.91661835, 22.74419785], [88.91651154, 22.74304771], [88.91681671, 22.74188995], [88.91657257, 22.74150848], [88.91619873, 22.7408123], [88.91609192, 22.74045944], [88.91586304, 22.73985863], [88.91579437, 22.73915863], [88.91581726, 22.73895836], [88.91596222, 22.73869514], [88.91565704, 22.73718834], [88.91565704, 22.73694801], [88.91566467, 22.73666954], [88.91579437, 22.73659706], [88.91579437, 22.73624229], [88.91583252, 22.73588181], [88.91598511, 22.73545456], [88.91608429, 22.73524284], [88.91612244, 22.73516273], [88.91621399, 22.73496437], [88.91636658, 22.73463631], [88.91644287, 22.73435974], [88.91651154, 22.73410034], [88.91664124, 22.73409653], [88.91672516, 22.73396873], [88.91686249, 22.73397064], [88.91734314, 22.73320389], [88.91757965, 22.73266029], [88.9177475, 22.73196602], [88.9178009, 22.73166466], [88.91808319, 22.73156357], [88.91816711, 22.73049164], [88.91817474, 22.73038292], [88.91861725, 22.73031998], [88.9186554, 22.73053741], [88.91867828, 22.73068619], [88.91905975, 22.73062515], [88.91973877, 22.73051834], [88.92089081, 22.73030663], [88.92084503, 22.73005486], [88.92080688, 22.72985077], [88.92120361, 22.72979164], [88.92198944, 22.7296772], [88.92300415, 22.72957611], [88.92320251, 22.72895813], [88.92325592, 22.72878838], [88.92329407, 22.72844887], [88.92434692, 22.72818756], [88.92517853, 22.72803688], [88.92588806, 22.72607422], [88.92596436, 22.72478294], [88.92598724, 22.72362137], [88.92632294, 22.72286415], [88.92681885, 22.72176552], [88.92731476, 22.72090149], [88.92761993, 22.72038651], [88.9276886, 22.72027779], [88.92771912, 22.72010994], [88.92781067, 22.71931076], [88.92788696, 22.71853447], [88.92791748, 22.71816444], [88.92829895, 22.71808815], [88.92848969, 22.71807098], [88.92881012, 22.71794319], [88.92915344, 22.7177887], [88.93054199, 22.7174263], [88.93170929, 22.71673393], [88.93264771, 22.71590042], [88.93448639, 22.71453857], [88.9347229, 22.71440887], [88.93517303, 22.71416092], [88.93534088, 22.71406746], [88.9362793, 22.71355438], [88.93806458, 22.71277237], [88.94070435, 22.71138763], [88.94238281, 22.70998955], [88.94411469, 22.70874023], [88.94702911, 22.70739174], [88.94760895, 22.70670891], [88.94773102, 22.70674324], [88.94827271, 22.70569801], [88.94836426, 22.70552444], [88.94858551, 22.70552063], [88.94889069, 22.70569992], [88.94988251, 22.70629501], [88.95034027, 22.70659447], [88.95111847, 22.70710564], [88.95278168, 22.70598221], [88.9539032, 22.70516205], [88.95607758, 22.70412636], [88.95697784, 22.70289612], [88.95682526, 22.70277786], [88.95785522, 22.70149422], [88.95813751, 22.70095062], [88.95830536, 22.70036888], [88.95790863, 22.700037], [88.96059418, 22.69815826], [88.96039581, 22.69788742], [88.96039581, 22.69699097], [88.96151733, 22.69590378], [88.96180725, 22.69561768], [88.96231842, 22.69510841], [88.9621582, 22.69504166], [88.96230316, 22.69458961], [88.96232605, 22.69400406], [88.9622345, 22.69329071], [88.9619751, 22.69267845], [88.96175385, 22.69199562], [88.96173096, 22.69167328], [88.96176147, 22.69119644], [88.96179199, 22.69064522], [88.96173859, 22.6902523], [88.96172333, 22.68998909], [88.9616394, 22.68965912], [88.9615097, 22.68919182], [88.96105194, 22.68832397], [88.9605484, 22.68735123], [88.9610672, 22.68680573], [88.96178436, 22.68610764], [88.96195984, 22.68593407], [88.96160889, 22.68535042], [88.96079254, 22.68530655], [88.96061707, 22.68529701], [88.9602356, 22.68527603], [88.95841217, 22.68533325], [88.95774841, 22.68542099], [88.95419312, 22.6809597], [88.95326233, 22.6801815], [88.95308685, 22.68003464], [88.94875336, 22.67028236], [88.94747162, 22.66119003], [88.94728088, 22.65985107], [88.94667816, 22.65920067], [88.94551849, 22.65793037], [88.93878937, 22.65055275], [88.9341507, 22.64796257], [88.93308258, 22.64735985], [88.9319458, 22.64554977], [88.93174744, 22.64594078], [88.93160248, 22.64641953], [88.93136597, 22.64683914], [88.93108368, 22.64723778], [88.93076324, 22.64759827], [88.93050385, 22.64805031], [88.9302597, 22.6485157], [88.93002319, 22.64899254], [88.92978668, 22.64948273], [88.92937469, 22.64980888], [88.92936707, 22.64990807], [88.92926788, 22.65007401], [88.92919922, 22.65018654], [88.92916107, 22.65025139], [88.92891693, 22.65073395], [88.9287262, 22.6512394], [88.92844391, 22.65158272], [88.9282074, 22.6519413], [88.92797852, 22.65230751], [88.92775726, 22.65268135], [88.92755127, 22.65302849], [88.92740631, 22.6534214], [88.92726898, 22.65382195], [88.92708588, 22.65415764], [88.92693329, 22.65451241], [88.92672729, 22.65487289], [88.92664337, 22.65528107], [88.92588043, 22.65709686], [88.92536163, 22.6585083], [88.92521667, 22.65891075], [88.9250412, 22.65916634], [88.92493439, 22.65947914], [88.92475891, 22.65974617], [88.92465973, 22.66011238], [88.92445374, 22.6604557], [88.92424011, 22.66083527], [88.92403412, 22.66124153], [88.9238205, 22.66166878], [88.92351532, 22.66200829], [88.92328644, 22.66241455], [88.92305756, 22.6627903], [88.92285156, 22.66316223], [88.92259979, 22.66348457], [88.92243958, 22.66386223], [88.92220306, 22.66418266], [88.92196655, 22.66445923], [88.92178345, 22.66475105], [88.92164612, 22.66504669], [88.92147827, 22.66529274], [88.9213028, 22.66555214], [88.9210968, 22.66583061], [88.92082977, 22.66612816], [88.92055511, 22.66650963], [88.92025757, 22.66694832], [88.91986847, 22.66736412], [88.91944122, 22.66778374], [88.91902161, 22.6682148], [88.91860962, 22.66861916], [88.91819763, 22.66902733], [88.91778564, 22.66944122], [88.91736603, 22.66985893], [88.91693115, 22.67026711], [88.91644287, 22.67060852], [88.91596985, 22.67098427], [88.91555786, 22.67141151], [88.91521454, 22.67193031], [88.91485596, 22.67243767], [88.91447449, 22.67282677], [88.91416931, 22.67326355], [88.91388702, 22.67370033], [88.91361237, 22.67413139], [88.91333771, 22.6746006], [88.91304779, 22.67512703], [88.9127121, 22.67567635], [88.9122467, 22.67613792], [88.91175842, 22.67656136], [88.91126251, 22.67692566], [88.91081238, 22.67721367], [88.91043091, 22.67743111], [88.91008759, 22.67752266], [88.90986633, 22.67765236], [88.90969849, 22.67778969], [88.90949249, 22.67783546], [88.90927887, 22.67794037], [88.90901947, 22.67804146], [88.90871429, 22.67813301], [88.90840912, 22.6783123], [88.90805817, 22.67846107], [88.90766144, 22.67860794], [88.90722656, 22.67873764], [88.90674591, 22.67886162], [88.90620422, 22.67892647], [88.90563202, 22.67906761], [88.9050293, 22.67910576], [88.90441895, 22.67895317], [88.90379333, 22.67900276], [88.90318298, 22.67913628], [88.90254211, 22.67916679], [88.90190125, 22.67914581], [88.90126038, 22.67902565], [88.90067291, 22.67885208], [88.9001236, 22.67863274], [88.89957428, 22.6784687], [88.89903259, 22.6783123], [88.89849854, 22.67811775], [88.89796448, 22.67797279], [88.89756012, 22.67780495], [88.89666748, 22.67694855], [88.89638519, 22.67694855], [88.89611053, 22.67666626], [88.89583588, 22.67666626], [88.89555359, 22.67638969], [88.89555359, 22.67611122], [88.89528656, 22.6760025], [88.8950119, 22.67580986], [88.89481354, 22.67560387], [88.89458466, 22.67547035], [88.89428711, 22.67533684], [88.89399719, 22.67506218], [88.89363861, 22.67487144], [88.89329529, 22.67467308], [88.89297485, 22.67445946], [88.8926239, 22.67429161], [88.89224243, 22.67410851], [88.89183044, 22.67387581], [88.89136505, 22.67359352], [88.89085388, 22.67330742], [88.89032745, 22.67298508], [88.88983917, 22.67261696], [88.88938141, 22.67224312], [88.8888855, 22.67193794], [88.88841248, 22.67163849], [88.88798523, 22.67133141], [88.88755035, 22.67105675], [88.88713837, 22.67076111], [88.88671875, 22.67046928], [88.88630676, 22.67015266], [88.88581848, 22.66991234], [88.88529968, 22.66970634], [88.884758, 22.66948891], [88.88420868, 22.66918564], [88.88362885, 22.66889381], [88.88301086, 22.66866112], [88.88236237, 22.66858101], [88.88175201, 22.66843224], [88.8811264, 22.66830635], [88.88052368, 22.66810036], [88.87994385, 22.66797829], [88.87940979, 22.66781616], [88.87885284, 22.6677475], [88.8783493, 22.66760826], [88.87786865, 22.66745377], [88.87741089, 22.66724968], [88.87692261, 22.66707993], [88.87639618, 22.66696358], [88.87585449, 22.66689873], [88.87539673, 22.66666603], [88.87498474, 22.66641235], [88.87458801, 22.66623878], [88.87425232, 22.66602707], [88.87400055, 22.66577148], [88.87335968, 22.66562462], [88.87267303, 22.6655407], [88.87223053, 22.66561317], [88.87179565, 22.66563225], [88.87132263, 22.6654892], [88.87082672, 22.66533089], [88.87030029, 22.66527748], [88.86979675, 22.66523361], [88.86935425, 22.66508675], [88.86891174, 22.66501427], [88.86846161, 22.66500282], [88.86797333, 22.66500282], [88.86746216, 22.66499138], [88.8669281, 22.66493416], [88.86640167, 22.66477585], [88.86586761, 22.66472816], [88.86535645, 22.66474724], [88.86485291, 22.66486931], [88.86436462, 22.66508293], [88.86402893, 22.66547775], [88.86383057, 22.6659584], [88.86377716, 22.66644478], [88.86364746, 22.66680717], [88.86361694, 22.66716194], [88.86360931, 22.66753197], [88.86360931, 22.66791344], [88.86360931, 22.66828728], [88.86360931, 22.66863251], [88.86360931, 22.66894341], [88.86360931, 22.66922951], [88.86360931, 22.66951561], [88.86361694, 22.66981506], [88.86363983, 22.67011833], [88.86367035, 22.67041969], [88.86363983, 22.67073631], [88.86360931, 22.67111206], [88.8638916, 22.67138863], [88.8638916, 22.67361259], [88.86360931, 22.67389107], [88.86361694, 22.67417526], [88.86361694, 22.6744442], [88.86360931, 22.67480659], [88.86360931, 22.67543983], [88.86360931, 22.67602539], [88.86360931, 22.67654037], [88.86360931, 22.67701721], [88.86358643, 22.67751122], [88.86346436, 22.67803764], [88.86334991, 22.67857361], [88.86319733, 22.67906761], [88.86297607, 22.67954826], [88.86278534, 22.68009758], [88.86262512, 22.68071938], [88.86247253, 22.68139267], [88.86232758, 22.68204308], [88.86245728, 22.6825943], [88.86249542, 22.68309975], [88.86245728, 22.68357277], [88.86228943, 22.68404388], [88.86216736, 22.68457031], [88.8620224, 22.68512535], [88.86210632, 22.68567467], [88.86234283, 22.68617058], [88.86252594, 22.68656921], [88.8627243, 22.68696022], [88.86279297, 22.68745232], [88.86286926, 22.68795967], [88.86301422, 22.68844795], [88.86309814, 22.68895531], [88.86328125, 22.68943214], [88.86334991, 22.68995094], [88.86346436, 22.6904068], [88.86359406, 22.69072914], [88.86369324, 22.69102669], [88.86384583, 22.69127846], [88.86390686, 22.69157982], [88.86395264, 22.69186974], [88.86403656, 22.69213295], [88.86414337, 22.6924572], [88.86417389, 22.69286537], [88.86415863, 22.69327736], [88.86411285, 22.6936512], [88.86396027, 22.69401741], [88.86370087, 22.69437218], [88.86345673, 22.6947422], [88.86319733, 22.695158], [88.86292267, 22.69564247], [88.86256409, 22.69605064], [88.8621521, 22.69642639], [88.86158752, 22.69668007], [88.86094666, 22.69690132], [88.86022949, 22.69696236], [88.85953522, 22.69700813], [88.8589325, 22.69696236], [88.85836792, 22.69692039], [88.85784149, 22.69679451], [88.85733795, 22.69664192], [88.85686493, 22.69639015], [88.85638428, 22.69611168], [88.85591888, 22.6958065], [88.85549164, 22.69545937], [88.85515594, 22.69506264], [88.85480499, 22.69473839], [88.85442352, 22.69448662], [88.85395813, 22.69433784], [88.85352325, 22.69416046], [88.85309601, 22.69396019], [88.85264587, 22.6938343], [88.85219574, 22.69365692], [88.85173798, 22.69359398], [88.85128784, 22.69351006], [88.85084534, 22.69340324], [88.85042572, 22.69330025], [88.85004425, 22.69315529], [88.84963226, 22.69304657], [88.84925842, 22.69317627], [88.84895325, 22.69353294], [88.84876251, 22.69394875], [88.84877777, 22.69449425], [88.84895325, 22.69498634], [88.8491745, 22.69547081], [88.84939575, 22.69597816], [88.84952545, 22.6965332], [88.84954834, 22.69713402], [88.84964752, 22.69771385], [88.84971619, 22.69830132], [88.84978485, 22.69891167], [88.84996033, 22.6995182], [88.84996033, 22.70015144], [88.84983063, 22.7008152], [88.84993744, 22.70150566], [88.84988403, 22.70213127], [88.84976196, 22.70260429], [88.84970856, 22.70306206], [88.84960938, 22.70348549], [88.84945679, 22.70388222], [88.84931946, 22.70427895], [88.84919739, 22.70471001], [88.84916687, 22.70516777], [88.84915924, 22.70560455], [88.84912109, 22.70602608], [88.84890747, 22.70702171], [88.84883881, 22.70742226], [88.84883881, 22.70815849], [88.84869385, 22.70842934], [88.84812164, 22.70889854], [88.84797668, 22.70903015], [88.84603119, 22.70903015], [88.8447876, 22.70889473], [88.84416199, 22.70889282], [88.84353638, 22.70884895], [88.84297943, 22.70866203], [88.84243774, 22.70861626], [88.84194946, 22.70861244], [88.84150696, 22.70860863], [88.84108734, 22.70857048], [88.84070587, 22.7084446], [88.84031677, 22.70835495], [88.83992767, 22.70833397], [88.83952332, 22.70833397], [88.83908844, 22.70833397], [88.83860779, 22.70833397], [88.83808899, 22.70833397], [88.8375473, 22.70837212], [88.83700562, 22.70853043], [88.83642578, 22.70865059], [88.83586121, 22.70889282], [88.83525085, 22.7091198], [88.8345871, 22.70919418], [88.83396149, 22.70932579], [88.83338928, 22.70947075], [88.83288574, 22.70964241], [88.83232117, 22.7096386], [88.83171082, 22.70970726], [88.83111572, 22.7097683], [88.83058929, 22.70995522], [88.83001709, 22.71007729], [88.82951355, 22.71037865], [88.82897949, 22.71048546], [88.82841492, 22.71054649], [88.82776642, 22.71060753], [88.82709503, 22.71079063], [88.82634735, 22.71083069], [88.82556915, 22.71083641], [88.82479858, 22.71083641], [88.82404327, 22.71083069], [88.82330322, 22.71083069], [88.82257843, 22.71083069], [88.82040405, 22.71083069], [88.819664, 22.71083069], [88.81893158, 22.71083641], [88.81822205, 22.71083641], [88.81752777, 22.71083069], [88.8168869, 22.71078682], [88.81632233, 22.71060371], [88.8157959, 22.71055794], [88.81532288, 22.71055794], [88.81489563, 22.71055222], [88.8144989, 22.71052742], [88.81411743, 22.71039391], [88.81367493, 22.71029854], [88.81315613, 22.71024513], [88.81259918, 22.71012306], [88.81202698, 22.71006966], [88.81143951, 22.71019554], [88.81090546, 22.71025848], [88.81041718, 22.71030617], [88.80998993, 22.71043587], [88.8095932, 22.71067047], [88.80925751, 22.71108437], [88.80905151, 22.71166801], [88.80913544, 22.71227074], [88.80926514, 22.71286964], [88.80944061, 22.71335983], [88.8095932, 22.7137661], [88.80970001, 22.71410751], [88.80973053, 22.71443748], [88.80978394, 22.71474648], [88.80994415, 22.71500206], [88.81002045, 22.71534157], [88.81015778, 22.71569633], [88.81036377, 22.71608353], [88.8104248, 22.71652031], [88.81049347, 22.71695137], [88.81057739, 22.71743965], [88.81072235, 22.71795464], [88.81084442, 22.71849251], [88.81095886, 22.71904564], [88.81098938, 22.7196331], [88.81098175, 22.72035408], [88.81091309, 22.7210331], [88.81082153, 22.72165489], [88.81069183, 22.72223473], [88.81058502, 22.72283936], [88.81054688, 22.72345161], [88.81049347, 22.72402191], [88.81033325, 22.72449303], [88.8102417, 22.72498894], [88.81010437, 22.72547722], [88.81002045, 22.72602081], [88.80996704, 22.72658348], [88.80982971, 22.72710228], [88.80966187, 22.72752762], [88.80937195, 22.72783852], [88.80899811, 22.72813988], [88.80865479, 22.72852325], [88.8083725, 22.72900963], [88.80813599, 22.72959328], [88.80799866, 22.7302494], [88.80801392, 22.73091888], [88.80789948, 22.73151207], [88.80764771, 22.73211288], [88.80745697, 22.73277092], [88.80755615, 22.73348236], [88.80771637, 22.73412323], [88.80789948, 22.73468208], [88.80819702, 22.73516464], [88.80854797, 22.73558426], [88.80887604, 22.7360096], [88.80918121, 22.73643303], [88.80950165, 22.73683548], [88.80982971, 22.73719788], [88.81014252, 22.73753548], [88.81038666, 22.73789787], [88.81058502, 22.73827171], [88.8108139, 22.73860741], [88.81100464, 22.73897743], [88.81112671, 22.73941612], [88.81125641, 22.73987579], [88.81138611, 22.74036217], [88.81150818, 22.74087715], [88.8115921, 22.74144363], [88.81158447, 22.74206161], [88.8115387, 22.74269485], [88.81145477, 22.74327278], [88.81139374, 22.74381638], [88.81131744, 22.74432182], [88.8111496, 22.74476051], [88.81100464, 22.74518776], [88.8108139, 22.74555397], [88.81059265, 22.74589729], [88.81040955, 22.74628639], [88.81025696, 22.74671555], [88.81008148, 22.7471714], [88.80992126, 22.74766541], [88.8097229, 22.7481308], [88.80952454, 22.74855614], [88.80934906, 22.74894524], [88.80915833, 22.74926186], [88.8089447, 22.74955177], [88.80875397, 22.74987411], [88.80866241, 22.75027084], [88.80871582, 22.75067711], [88.80908203, 22.75113678], [88.80960846, 22.7515049], [88.81021881, 22.75171852], [88.81087494, 22.7517662], [88.81150055, 22.75164223], [88.81203461, 22.75136948], [88.81256104, 22.75110435], [88.81314087, 22.75090218], [88.81375885, 22.75076294], [88.81436157, 22.75055885], [88.81495667, 22.7503643], [88.81557465, 22.75022507], [88.81619263, 22.75006676], [88.81686401, 22.74998665], [88.81752014, 22.74987411], [88.81804657, 22.74958038], [88.81832886, 22.7490139], [88.81829071, 22.74820137], [88.81802368, 22.74761772], [88.81755066, 22.74728203], [88.81702423, 22.74700928], [88.81651306, 22.7467556], [88.81608582, 22.74648476], [88.81568146, 22.74623871], [88.81528473, 22.74598885], [88.81488037, 22.745718], [88.81438446, 22.74549294], [88.81389618, 22.74523735], [88.81345367, 22.74489784], [88.81309509, 22.74448586], [88.81284332, 22.74403763], [88.81271362, 22.74358559], [88.81263733, 22.74317551], [88.81270599, 22.74279213], [88.81284332, 22.74242592], [88.81305695, 22.74209976], [88.81331635, 22.74173927], [88.81360626, 22.74132347], [88.81396484, 22.74090767], [88.81446075, 22.74057961], [88.81502533, 22.74032211], [88.81563568, 22.74014854], [88.81623077, 22.73991966], [88.81689453, 22.73974419], [88.81758881, 22.7396183], [88.8183136, 22.7394886], [88.81905365, 22.73942757], [88.81978607, 22.73934364], [88.82049561, 22.73921394], [88.82118225, 22.73912811], [88.82180023, 22.73900414], [88.82235718, 22.7388401], [88.82286072, 22.73866081], [88.82335663, 22.73853493], [88.82379913, 22.73836708], [88.82422638, 22.73823929], [88.82461548, 22.73809624], [88.82500458, 22.73798561], [88.82536316, 22.73779678], [88.82574463, 22.73763275], [88.82618713, 22.73753548], [88.82666016, 22.73749733], [88.82713318, 22.73745537], [88.8276062, 22.73737907], [88.82810211, 22.7373867], [88.82860565, 22.73756027], [88.82897186, 22.73777008], [88.82918549, 22.73796082], [88.82936859, 22.73820305], [88.82959747, 22.73853493], [88.82983398, 22.73895073], [88.83003998, 22.7393589], [88.83021545, 22.7396946], [88.83034515, 22.73999977], [88.83050537, 22.7402668], [88.83065796, 22.74054527], [88.83082581, 22.74083519], [88.83100891, 22.74115562], [88.83119202, 22.74150276], [88.83141327, 22.74184608], [88.83164215, 22.74219131], [88.83189392, 22.74253654], [88.83215332, 22.74289894], [88.83242035, 22.74331474], [88.83254242, 22.74379921], [88.83271027, 22.74428558], [88.83296204, 22.74471092], [88.83321381, 22.74508858], [88.83349609, 22.74535942], [88.83383942, 22.74550247], [88.83422852, 22.74545288], [88.83457184, 22.7451992], [88.83481598, 22.74479485], [88.83492279, 22.74431992], [88.83491516, 22.74382973], [88.83486938, 22.7433567], [88.83493805, 22.74291039], [88.83499908, 22.74246407], [88.83507538, 22.74202156], [88.83518219, 22.74158478], [88.83526611, 22.74113655], [88.83533478, 22.74068642], [88.83538818, 22.7402153], [88.83546448, 22.73969078], [88.83562469, 22.73919868], [88.83579254, 22.73877144], [88.83592224, 22.7383709], [88.83608246, 22.73800659], [88.83620453, 22.7376461], [88.83633423, 22.73731613], [88.83647919, 22.73701668], [88.83665466, 22.73673248], [88.83686829, 22.73644829], [88.83712769, 22.73615074], [88.8374176, 22.73583031], [88.83782196, 22.7355442], [88.83833313, 22.73530006], [88.83886719, 22.73507881], [88.8394165, 22.73494148], [88.83999634, 22.73497772], [88.84054565, 22.73508644], [88.84101105, 22.73529243], [88.84138489, 22.73554993], [88.84169769, 22.73582268], [88.84199524, 22.73612785], [88.84230042, 22.73646736], [88.84255219, 22.73689651], [88.84280396, 22.73735237], [88.84305573, 22.73780632], [88.84329224, 22.73824883], [88.8434906, 22.73869705], [88.84365082, 22.73918343], [88.84382629, 22.73968315], [88.84396362, 22.74022865], [88.84416199, 22.74074745], [88.84437561, 22.74123383], [88.84468079, 22.74164009], [88.84497833, 22.74200439], [88.84524536, 22.74236679], [88.84546661, 22.74274635], [88.84563446, 22.74319649], [88.84575653, 22.74369621], [88.84600067, 22.74400902], [88.84642792, 22.74409294], [88.84684753, 22.74399185], [88.84712982, 22.74404907], [88.84685516, 22.74447441], [88.84663391, 22.74508858], [88.84664154, 22.74564934], [88.84684753, 22.74607468], [88.84705353, 22.74650764], [88.84725952, 22.74693489], [88.84749603, 22.74733162], [88.84774017, 22.7477169], [88.8479538, 22.74811363], [88.8481369, 22.74851418], [88.84833527, 22.74890137], [88.848526, 22.74933624], [88.84861755, 22.74988747], [88.84851074, 22.75048256], [88.84822845, 22.75098991], [88.84780121, 22.75138664], [88.8473053, 22.75174141], [88.84666443, 22.75198936], [88.84599304, 22.75225639], [88.8453064, 22.7525177], [88.84459686, 22.75252342], [88.8438797, 22.75252724], [88.84317017, 22.75258827], [88.84252167, 22.75274849], [88.84192657, 22.75291252], [88.84146881, 22.75314713], [88.84102631, 22.7532711], [88.8405304, 22.75326729], [88.84001923, 22.75327873], [88.83948517, 22.75332451], [88.83895111, 22.75341988], [88.83846283, 22.75353813], [88.83802032, 22.75363731], [88.83760071, 22.75375938], [88.83715057, 22.75388336], [88.83670044, 22.75396538], [88.83624268, 22.75392342], [88.83578491, 22.75391197], [88.83528137, 22.75388908], [88.83499908, 22.75416756], [88.83416748, 22.75416756], [88.83388519, 22.75444412], [88.83305359, 22.75444412], [88.83249664, 22.75388908], [88.83305359, 22.75333595], [88.83333588, 22.75333595], [88.83378601, 22.75312996], [88.83424377, 22.75302315], [88.8347168, 22.75290871], [88.83519745, 22.75279617], [88.8356781, 22.7526989], [88.83614349, 22.7525692], [88.83663177, 22.75251961], [88.83711243, 22.7524929], [88.83758545, 22.75243568], [88.83802032, 22.75226784], [88.83849335, 22.75206566], [88.8390274, 22.75187111], [88.83963013, 22.75167465], [88.8403244, 22.75149918], [88.84101868, 22.75141525], [88.84169769, 22.75132561], [88.84236145, 22.75119591], [88.84303284, 22.75112343], [88.84372711, 22.75106621], [88.8444519, 22.75102806], [88.8451767, 22.75097466], [88.84585571, 22.75084877], [88.84643555, 22.75057411], [88.84680939, 22.75013924], [88.84690857, 22.74961662], [88.84681702, 22.74913979], [88.84664154, 22.74874687], [88.84645844, 22.74841118], [88.84629822, 22.74810791], [88.84613037, 22.7478466], [88.84594727, 22.74761009], [88.84573364, 22.74737358], [88.84548187, 22.74709892], [88.84522247, 22.7467556], [88.84498596, 22.74632454], [88.84474945, 22.74585915], [88.84449005, 22.74539757], [88.84423065, 22.74494362], [88.8440094, 22.74450111], [88.84382629, 22.74407578], [88.84365082, 22.74368477], [88.84350586, 22.74329948], [88.84333801, 22.74294472], [88.8431778, 22.74262047], [88.8431015, 22.74230957], [88.84303284, 22.74202538], [88.84291077, 22.7417717], [88.84278107, 22.74150276], [88.84262848, 22.74118996], [88.84248352, 22.74077415], [88.8423233, 22.74030495], [88.8421936, 22.7397728], [88.84202576, 22.73925209], [88.84178162, 22.7387867], [88.84151459, 22.7383976], [88.84133148, 22.73793221], [88.84119415, 22.73747063], [88.84107971, 22.73705482], [88.84094238, 22.73670959], [88.84081268, 22.73640251], [88.84066772, 22.73613167], [88.84052277, 22.73589516], [88.84031677, 22.73571968], [88.83999634, 22.73564339], [88.83965302, 22.73573685], [88.8392868, 22.73599052], [88.83888245, 22.73635864], [88.83841705, 22.73679543], [88.83797455, 22.73729897], [88.83763885, 22.73784828], [88.83739471, 22.7384243], [88.83717346, 22.73901176], [88.8369751, 22.73963737], [88.83680725, 22.74027252], [88.83675385, 22.74094582], [88.8367691, 22.74156189], [88.83683777, 22.74208832], [88.83681488, 22.74259949], [88.83670807, 22.74310112], [88.8366394, 22.74361229], [88.83670807, 22.74414635], [88.83666229, 22.74461365], [88.83650208, 22.74500465], [88.83633423, 22.74538994], [88.83613586, 22.74578285], [88.83592987, 22.74620056], [88.83560181, 22.74654007], [88.83515167, 22.74677849], [88.83457947, 22.74690247], [88.83393097, 22.74696541], [88.83345032, 22.74686813], [88.83304596, 22.74672127], [88.83264923, 22.74657249], [88.83227539, 22.74630928], [88.83195496, 22.74594307], [88.83168793, 22.74555397], [88.83142853, 22.74522018], [88.83113861, 22.7449398], [88.83084869, 22.74463081], [88.83060455, 22.74417305], [88.83036804, 22.74377251], [88.83017731, 22.74343109], [88.83005524, 22.74311256], [88.82996368, 22.74279213], [88.82984924, 22.74246025], [88.82971954, 22.74209023], [88.82958221, 22.74168205], [88.82939148, 22.74131393], [88.82920074, 22.74091148], [88.8290329, 22.74045944], [88.82878113, 22.73996925], [88.8283844, 22.73943901], [88.82791138, 22.73893929], [88.82750702, 22.73872185], [88.82713318, 22.73870277], [88.8266449, 22.73871994], [88.82617188, 22.73885536], [88.82569122, 22.73903084], [88.82514191, 22.7392025], [88.8245697, 22.73945045], [88.82395935, 22.73976135], [88.82336426, 22.74010658], [88.82274628, 22.7402935], [88.82217407, 22.74045753], [88.82164764, 22.74059868], [88.82115173, 22.74074745], [88.82064056, 22.74081612], [88.82012177, 22.74085045], [88.8196106, 22.74090767], [88.81911469, 22.74103546], [88.81861877, 22.74113655], [88.81812286, 22.74124718], [88.81762695, 22.74136925], [88.81711578, 22.74146461], [88.81661987, 22.74162865], [88.81610107, 22.74175835], [88.81565094, 22.74196053], [88.81523895, 22.7421627], [88.81488037, 22.74233818], [88.8146286, 22.74260521], [88.81453705, 22.7430687], [88.81472015, 22.74375343], [88.8151474, 22.74425697], [88.81567383, 22.74456215], [88.81620789, 22.7447834], [88.81671906, 22.74490166], [88.8172226, 22.74492455], [88.81769562, 22.74516869], [88.81816864, 22.74545479], [88.81858826, 22.74580574], [88.81895447, 22.74619484], [88.81928253, 22.74658966], [88.81960297, 22.74693108], [88.81987762, 22.7472477], [88.82009125, 22.7475605], [88.82029724, 22.74786377], [88.82043457, 22.74827385], [88.82045746, 22.74881554], [88.82028198, 22.74937248], [88.81993103, 22.74986458], [88.8194809, 22.75029182], [88.81899261, 22.75065613], [88.8184433, 22.75089264], [88.81793976, 22.7511158], [88.81747437, 22.75131226], [88.81698608, 22.75141525], [88.81652069, 22.75153923], [88.8160553, 22.75169182], [88.81559753, 22.75187492], [88.81511688, 22.75204659], [88.81465912, 22.75226784], [88.8141861, 22.75248528], [88.8136673, 22.75267601], [88.81311035, 22.75283051], [88.81256866, 22.75305748], [88.81202698, 22.75331116], [88.81143188, 22.75354195], [88.81078339, 22.75367928], [88.81014252, 22.7536335], [88.80951691, 22.75356483], [88.80891418, 22.75343132], [88.80838013, 22.75314713], [88.80806732, 22.75283051], [88.80784607, 22.75244522], [88.80760956, 22.75199318], [88.80744171, 22.7516861], [88.80730438, 22.75140572], [88.80715942, 22.75103569], [88.80702209, 22.75067329], [88.80699921, 22.75024605], [88.80708313, 22.74978065], [88.80725098, 22.7493248], [88.80744171, 22.74887276], [88.80753326, 22.74838448], [88.80765533, 22.74790382], [88.80779266, 22.7474308], [88.80796814, 22.74697685], [88.80819702, 22.74658394], [88.8085022, 22.74632072], [88.80876923, 22.74605751], [88.80901337, 22.74578667], [88.80923462, 22.74549294], [88.80941772, 22.74518776], [88.80957794, 22.74489021], [88.80970001, 22.7446003], [88.80982208, 22.74432945], [88.80993652, 22.74404907], [88.81001282, 22.74369621], [88.80999756, 22.74316597], [88.80995178, 22.74253654], [88.81001282, 22.74188614], [88.81000519, 22.74125862], [88.80988312, 22.74074173], [88.80969238, 22.74034691], [88.80948639, 22.74004173], [88.80930328, 22.73974609], [88.80912018, 22.73945618], [88.8088913, 22.73917961], [88.80867004, 22.73888206], [88.80852509, 22.7385273], [88.80825806, 22.73835182], [88.80801392, 22.73817062], [88.80779266, 22.73797417], [88.80760193, 22.73775291], [88.80744171, 22.73750114], [88.80722809, 22.73725891], [88.80702972, 22.73695946], [88.8068924, 22.7365818], [88.80684662, 22.73634529], [88.80671692, 22.73606682], [88.80660248, 22.73568916], [88.80641937, 22.73533821], [88.80622864, 22.73502541], [88.80609131, 22.7347126], [88.80599213, 22.73438454], [88.80586243, 22.7340374], [88.80580139, 22.73363686], [88.80577087, 22.73320007], [88.8057785, 22.73275948], [88.80578613, 22.73234367], [88.80580139, 22.73194885], [88.80583954, 22.73151207], [88.80594635, 22.73101234], [88.80609894, 22.73045921], [88.8062439, 22.72988701], [88.80638885, 22.7293644], [88.80654144, 22.72891045], [88.80670929, 22.72852325], [88.80693054, 22.72819328], [88.80716705, 22.72782135], [88.80741882, 22.72740364], [88.80764771, 22.72689629], [88.8080368, 22.72638321], [88.80882263, 22.72538185], [88.80918121, 22.72444153], [88.80882263, 22.72310066], [88.80875397, 22.72089195], [88.80839539, 22.71867943], [88.80776215, 22.71636391], [88.80771637, 22.71594429], [88.80760193, 22.71551704], [88.80751801, 22.71502113], [88.80750275, 22.7144413], [88.80749512, 22.71379089], [88.80750275, 22.71309471], [88.80753326, 22.71238518], [88.80765533, 22.71170807], [88.80778503, 22.71114731], [88.80799103, 22.71072197], [88.80821991, 22.71035385], [88.80845642, 22.70998192], [88.80873108, 22.709692], [88.80901337, 22.70946312], [88.80934143, 22.70929146], [88.80973053, 22.7091465], [88.810112, 22.7089901], [88.81056213, 22.70890617], [88.8110199, 22.70884895], [88.81142426, 22.70869637], [88.81184387, 22.70855141], [88.81224823, 22.70837784], [88.81268311, 22.70833397], [88.81311798, 22.70833015], [88.8135376, 22.70833397], [88.81394958, 22.7083683], [88.81435394, 22.70849037], [88.81479645, 22.70852089], [88.81526184, 22.70838737], [88.81572723, 22.7083683], [88.81617737, 22.70850754], [88.81667328, 22.70859718], [88.81723022, 22.70865631], [88.81778717, 22.70884323], [88.81835938, 22.7088871], [88.81894684, 22.70889282], [88.81952667, 22.70889282], [88.82010651, 22.70889282], [88.82069397, 22.70889282], [88.82128143, 22.70889282], [88.82186127, 22.70887566], [88.82243347, 22.70879173], [88.82299042, 22.70864487], [88.82354736, 22.70861244], [88.82411194, 22.70863152], [88.8246994, 22.7087307], [88.82536316, 22.70877266], [88.8259964, 22.70863152], [88.82662964, 22.70850754], [88.82724762, 22.70833778], [88.8278656, 22.70818138], [88.82848358, 22.70804977], [88.82910156, 22.70791435], [88.82974243, 22.7078228], [88.83040619, 22.70776176], [88.83106995, 22.7076664], [88.83171082, 22.70752335], [88.83235168, 22.70743179], [88.83291626, 22.70720863], [88.83345032, 22.70697212], [88.83403778, 22.70682144], [88.83469391, 22.70665741], [88.83531189, 22.70648193], [88.83587646, 22.70635414], [88.83634186, 22.70620537], [88.83674622, 22.70613289], [88.83711243, 22.70617104], [88.83747101, 22.70631218], [88.83776855, 22.70623779], [88.83808136, 22.70612907], [88.8384552, 22.70607376], [88.83885956, 22.70599556], [88.83927917, 22.70599556], [88.83969116, 22.70611763], [88.84009552, 22.70628166], [88.8405304, 22.70620918], [88.84094238, 22.70614243], [88.84133148, 22.70621681], [88.84175873, 22.70635033], [88.84222412, 22.70638847], [88.84270477, 22.70642471], [88.84317017, 22.70654488], [88.84358978, 22.70664406], [88.84400177, 22.70667076], [88.8443985, 22.70666695], [88.8454361, 22.70675278], [88.84593964, 22.70675278], [88.84651947, 22.70668602], [88.84701538, 22.70668602], [88.84723663, 22.70654869], [88.84759521, 22.70567894], [88.84780884, 22.70420647], [88.84736633, 22.70208168], [88.84724426, 22.7015667], [88.84716034, 22.70105934], [88.84698486, 22.70062828], [88.84688568, 22.70017052], [88.84670258, 22.69975853], [88.84661102, 22.69928932], [88.84648132, 22.69885063], [88.84638977, 22.6984024], [88.84631348, 22.6979599], [88.84622192, 22.69752312], [88.84613037, 22.69708061], [88.84611511, 22.69659042], [88.84610748, 22.69608116], [88.84609222, 22.69556618], [88.84607697, 22.69507408], [88.84605408, 22.69462585], [88.84605408, 22.69422722], [88.84608459, 22.69386101], [88.84614563, 22.69350433], [88.84628296, 22.69317627], [88.84644318, 22.69285965], [88.84663391, 22.6925869], [88.8467865, 22.69229317], [88.8469696, 22.69203377], [88.84720612, 22.69182205], [88.847435, 22.69161415], [88.84767914, 22.69137383], [88.8479538, 22.6911087], [88.84828186, 22.69083214], [88.84866333, 22.69056129], [88.84906769, 22.69032478], [88.84950256, 22.69019508], [88.8498764, 22.69003868], [88.85024261, 22.68995476], [88.85054016, 22.6897831], [88.85085297, 22.68972778], [88.85119629, 22.68971825], [88.85154724, 22.68971443], [88.85189819, 22.6896801], [88.85225677, 22.68958473], [88.85262299, 22.6895504], [88.8529892, 22.6896801], [88.85341644, 22.68981743], [88.85386658, 22.68997192], [88.85438538, 22.69009972], [88.8549118, 22.69030952], [88.85542297, 22.69061089], [88.85591125, 22.69101334], [88.85643768, 22.69136238], [88.85695648, 22.69167519], [88.85743713, 22.69195938], [88.85787201, 22.69223022], [88.85823059, 22.69251442], [88.85853577, 22.69280815], [88.8588028, 22.6931324], [88.85906219, 22.6934948], [88.85944366, 22.69376183], [88.85985565, 22.69400787], [88.8603363, 22.69421959], [88.86082458, 22.69434929], [88.86128235, 22.69419479], [88.8615799, 22.69374275], [88.86162567, 22.6931076], [88.86153412, 22.69243431], [88.86135864, 22.69179535], [88.86112976, 22.69124794], [88.86090088, 22.69075775], [88.86071777, 22.69028282], [88.86051941, 22.68982506], [88.86027527, 22.68936729], [88.86001587, 22.68887901], [88.8598175, 22.68834686], [88.8596344, 22.68782043], [88.85943604, 22.6873455], [88.85923767, 22.68688011], [88.85913086, 22.68626785], [88.85897827, 22.68561172], [88.85890198, 22.68489647], [88.85884094, 22.68416214], [88.85868835, 22.68351555], [88.85858154, 22.68295479], [88.85861206, 22.68277931], [88.85805511, 22.68222046], [88.85805511, 22.68166924], [88.85778046, 22.68139267], [88.85778046, 22.68027687], [88.85749817, 22.68000221], [88.85757446, 22.67948723], [88.85749817, 22.67944527], [88.85749817, 22.67833519], [88.85722351, 22.67805862], [88.85722351, 22.67749977], [88.85749817, 22.6772213], [88.85749817, 22.67611122], [88.85805511, 22.67555618], [88.85805511, 22.67527962], [88.85861206, 22.67472267], [88.85861206, 22.6744442], [88.85916901, 22.67389107], [88.85916901, 22.67361259], [88.85944366, 22.67333412], [88.85972595, 22.67333412], [88.86006927, 22.67283058], [88.86045074, 22.67232323], [88.8608017, 22.67179108], [88.86105347, 22.67120171], [88.86109161, 22.67054176], [88.86101532, 22.66991615], [88.86094666, 22.66935158], [88.86103058, 22.66880226], [88.86095428, 22.66830254], [88.86089325, 22.66781616], [88.8609848, 22.66732979], [88.86108398, 22.66686058], [88.86112976, 22.6663723], [88.8612442, 22.66592026], [88.86151123, 22.66559792], [88.86186981, 22.66533852], [88.86222076, 22.66501808], [88.86256409, 22.66465759], [88.86293793, 22.66430092], [88.86334991, 22.66399384], [88.86378479, 22.66374779], [88.86426544, 22.66359329], [88.86473083, 22.66344452], [88.86521149, 22.66329765], [88.86567688, 22.66311073], [88.86620331, 22.66307259], [88.86673737, 22.66314125], [88.86727905, 22.66328239], [88.86785889, 22.66332626], [88.86841583, 22.66333771], [88.86894226, 22.66333199], [88.86946106, 22.66333199], [88.87001801, 22.66334724], [88.87062836, 22.66342735], [88.8712616, 22.6636219], [88.87187958, 22.66385841], [88.87245178, 22.66403961], [88.87295532, 22.66425514], [88.87368011, 22.66448212], [88.8743515, 22.66480064], [88.87480164, 22.66470528], [88.87538147, 22.6646862], [88.87595367, 22.66465759], [88.8764267, 22.66475487], [88.87683105, 22.66493416], [88.87728119, 22.66499519], [88.87773132, 22.66500282], [88.87817383, 22.66500854], [88.87858582, 22.66506004], [88.87898254, 22.66514778], [88.87937164, 22.66525078], [88.87980652, 22.66527748], [88.88024139, 22.66527748], [88.8806839, 22.6652813], [88.8811264, 22.66531563], [88.88153076, 22.66545486], [88.88191986, 22.6655674], [88.88232422, 22.66571617], [88.8828125, 22.66586113], [88.88331604, 22.66607285], [88.88388062, 22.66622734], [88.88444519, 22.66636086], [88.88500214, 22.6664238], [88.88549042, 22.66657829], [88.88594818, 22.66669655], [88.88635254, 22.66689491], [88.88674927, 22.66705513], [88.88704681, 22.66723824], [88.88729095, 22.66743279], [88.88757324, 22.66759491], [88.88795471, 22.66781425], [88.88840485, 22.6681118], [88.88896942, 22.66841125], [88.88957977, 22.6687336], [88.89021301, 22.66900063], [88.89071655, 22.66929436], [88.89111328, 22.66944695], [88.89138794, 22.66944695], [88.89167023, 22.66972351], [88.89194489, 22.66972351], [88.89221954, 22.67000008], [88.89250183, 22.67000008], [88.89389038, 22.67138863], [88.89416504, 22.67138863], [88.89527893, 22.67250252], [88.89555359, 22.67250252], [88.89611053, 22.67305565], [88.89613342, 22.67328644], [88.896492, 22.67357826], [88.89691162, 22.67386818], [88.89730072, 22.67418098], [88.8976059, 22.67450905], [88.89794922, 22.67468452], [88.89820862, 22.67490578], [88.89855957, 22.67504692], [88.89894104, 22.67527199], [88.89937592, 22.67554665], [88.89984131, 22.67581367], [88.90032959, 22.67604256], [88.90083313, 22.67622375], [88.90133667, 22.67639351], [88.90184784, 22.67655373], [88.90236664, 22.67664146], [88.90287018, 22.67666054], [88.90330505, 22.67673302], [88.90381622, 22.67669868], [88.90432739, 22.6768856], [88.9048233, 22.67712975], [88.90535736, 22.67720985], [88.90592957, 22.6772213], [88.90654755, 22.67718124], [88.90717316, 22.67701721], [88.90781403, 22.67683983], [88.9083252, 22.6764431], [88.90888977, 22.67611122], [88.91000366, 22.67500114], [88.91027832, 22.67500114], [88.91110992, 22.67416573], [88.91110992, 22.67389107], [88.91139221, 22.67361259], [88.91139221, 22.67277718], [88.91222382, 22.67194557], [88.91222382, 22.6716671], [88.91249847, 22.67138863], [88.91249847, 22.67111206], [88.91278076, 22.67083549], [88.91278076, 22.67055702], [88.91305542, 22.67027855], [88.91336823, 22.66973305], [88.91375732, 22.66929436], [88.91411591, 22.66883469], [88.91442108, 22.6683445], [88.91467285, 22.66786766], [88.91498566, 22.66752815], [88.91527557, 22.66722679], [88.91555023, 22.66693878], [88.91582489, 22.66662025], [88.91610718, 22.66626549], [88.91638947, 22.66588783], [88.91666412, 22.66552544], [88.91691589, 22.6651783], [88.91714478, 22.66481018], [88.91740417, 22.6644249], [88.91768646, 22.66399384], [88.91801453, 22.66353607], [88.91833496, 22.66302681], [88.91867065, 22.66249657], [88.91898346, 22.66195107], [88.91928101, 22.66141319], [88.91956329, 22.66090202], [88.91976929, 22.66039467], [88.9200058, 22.65996742], [88.9202652, 22.65961647], [88.92047882, 22.65928841], [88.92059326, 22.6588726], [88.92071533, 22.65843964], [88.92090607, 22.65798378], [88.92113495, 22.65747833], [88.92138672, 22.65694618], [88.92149353, 22.65683937], [88.92166901, 22.6566658], [88.92166901, 22.65639114], [88.92193604, 22.65611267], [88.92193604, 22.65556145], [88.92250061, 22.65500259], [88.92250061, 22.65472031], [88.92277527, 22.65444374], [88.92277527, 22.65389061], [88.92305756, 22.65361023], [88.92305756, 22.65332985], [88.92333221, 22.65305519], [88.92336273, 22.65273285], [88.92359924, 22.65225029], [88.92386627, 22.65174484], [88.92410278, 22.65123177], [88.92440033, 22.65081215], [88.92459106, 22.65041161], [88.92472076, 22.65028191], [88.92472076, 22.64999962], [88.92582703, 22.64888954], [88.92582703, 22.64861107], [88.92610931, 22.6483326], [88.92610931, 22.64805794], [88.9263916, 22.64777946], [88.9263916, 22.64750099], [88.92666626, 22.64722252], [88.92666626, 22.64666939], [88.92694092, 22.64639091], [88.92694092, 22.64611244], [88.9283371, 22.64472008], [88.9283371, 22.64444351], [88.92861176, 22.64416695], [88.92861176, 22.64333344], [88.92889404, 22.64292526], [88.9291687, 22.64245033], [88.92947388, 22.64199448], [88.92977142, 22.64161873], [88.9298172, 22.6415329], [88.93010712, 22.64099312], [88.93025208, 22.64038277], [88.92997742, 22.63967133], [88.92979431, 22.6389904], [88.92977142, 22.63832283], [88.92985535, 22.63767052], [88.9299469, 22.63702202], [88.92999268, 22.63634109], [88.93002319, 22.63567162], [88.9300766, 22.63504028], [88.9302063, 22.63447952], [88.93026733, 22.63393974], [88.93035126, 22.63342094], [88.93050385, 22.63290215], [88.93054962, 22.6323185], [88.93055725, 22.63169289], [88.93054962, 22.63105392], [88.93054962, 22.63043022], [88.93055725, 22.62979126], [88.93060303, 22.62911034], [88.93070221, 22.62841034], [88.93078613, 22.6277523], [88.9307785, 22.62713623], [88.93081665, 22.62654114], [88.93083191, 22.6260128], [88.93083954, 22.62553978], [88.93087769, 22.62508965], [88.93106079, 22.62466431], [88.93110657, 22.62421417], [88.9311142, 22.62376213], [88.93110657, 22.6233139], [88.9311142, 22.62288475], [88.93110657, 22.62248421], [88.9311142, 22.62210655], [88.93113708, 22.62174034], [88.93122864, 22.62138176], [88.93138123, 22.62088394], [88.93156433, 22.62034988], [88.93190002, 22.61985207], [88.93222809, 22.6192894], [88.93255615, 22.6187439], [88.93299103, 22.61833], [88.93338013, 22.61800957], [88.93372345, 22.61779022], [88.93401337, 22.61765099], [88.93424225, 22.61752129], [88.93447113, 22.61744118], [88.93470001, 22.61728287], [88.93499756, 22.61718178], [88.93525696, 22.61700249], [88.93559265, 22.61691093], [88.93591309, 22.61676216], [88.93630219, 22.61663818], [88.93673706, 22.61644173], [88.93730164, 22.6162529], [88.93791962, 22.61613274], [88.93858337, 22.6160717], [88.93917847, 22.61593056], [88.93975067, 22.61606789], [88.94011688, 22.61609459], [88.94030762, 22.61611176], [88.9408493, 22.61611366], [88.94139099, 22.61611366], [88.94193268, 22.61611366], [88.94245148, 22.61611176], [88.94291687, 22.61611176], [88.94332886, 22.61613274], [88.94368744, 22.61621284], [88.94406891, 22.61636162], [88.94451141, 22.61643028], [88.94496918, 22.61660385], [88.94551086, 22.61667061], [88.9460907, 22.61665154], [88.9466629, 22.61668205], [88.94718933, 22.61678886], [88.94770813, 22.61693192], [88.94819641, 22.61709023], [88.94867706, 22.61728287], [88.94915009, 22.61744118], [88.94967651, 22.61744118], [88.95018005, 22.61761284], [88.950737, 22.61763191], [88.95128632, 22.61770058], [88.95282745, 22.61795235], [88.95476532, 22.61795044], [88.95498657, 22.61796951], [88.95627594, 22.61808777], [88.95728302, 22.61788368], [88.95777893, 22.61741447], [88.95792389, 22.61694527], [88.95800018, 22.61647987], [88.95804596, 22.61597252], [88.95806122, 22.61539268], [88.95804596, 22.61478233], [88.95802307, 22.61412239], [88.95800018, 22.61351204], [88.95797729, 22.61288261], [88.95788574, 22.61221886], [88.95778656, 22.61150169], [88.95771027, 22.61078072], [88.9574585, 22.61020088], [88.95709229, 22.60976982], [88.95664978, 22.60944939], [88.95623016, 22.60917091], [88.95578766, 22.60889244], [88.95533752, 22.60861015], [88.95504761, 22.60841942], [88.95490265, 22.60832024], [88.95448303, 22.6079998], [88.95404816, 22.60767174], [88.95359039, 22.60739326], [88.95310211, 22.60714149], [88.95263672, 22.60684967], [88.9522171, 22.60655022], [88.95181274, 22.60625267], [88.95139313, 22.60597038], [88.95101929, 22.60575294], [88.95070648, 22.60556221], [88.95044708, 22.60546112], [88.95027924, 22.60527992], [88.94999695, 22.60527992], [88.94972229, 22.60500145], [88.94944763, 22.60500145], [88.94917297, 22.60473061], [88.94889069, 22.60473061], [88.94869995, 22.60453606], [88.9486084, 22.6044445], [88.9484024, 22.60416031], [88.94800568, 22.60386848], [88.94760895, 22.60349083], [88.94719696, 22.6031208], [88.9467926, 22.6027813], [88.94642639, 22.60247231], [88.94613647, 22.60217094], [88.94591522, 22.60186386], [88.945755, 22.60149956], [88.94547272, 22.60121346], [88.94507599, 22.60099411], [88.94473267, 22.60064125], [88.94439697, 22.6002636], [88.94393921, 22.59999275], [88.94346619, 22.59973335], [88.94300079, 22.59949303], [88.94252777, 22.59929085], [88.9420929, 22.59905052], [88.94165802, 22.59885979], [88.94126129, 22.59861565], [88.94087982, 22.59837151], [88.94052887, 22.59807014], [88.94020844, 22.59774208], [88.93995667, 22.59732056], [88.93966675, 22.59690285], [88.93930817, 22.59652138], [88.93894958, 22.59614182], [88.93855286, 22.59583092], [88.93817902, 22.595541], [88.93782806, 22.5952301], [88.93751526, 22.59490776], [88.9372406, 22.59457207], [88.93701935, 22.59422493], [88.93687439, 22.59383965], [88.93667603, 22.59348106], [88.9365387, 22.59308052], [88.93636322, 22.59267235], [88.93611908, 22.59225273], [88.93593597, 22.59175301], [88.93579865, 22.59116173], [88.93560791, 22.59055138], [88.93553925, 22.58987999], [88.93553925, 22.58922958], [88.93553925, 22.58865166], [88.93556213, 22.58818436], [88.93561554, 22.58778954], [88.93570709, 22.58741188], [88.93580627, 22.58698845], [88.93582153, 22.58648109], [88.93578339, 22.58588219], [88.93569183, 22.58524323], [88.9356308, 22.58458138], [88.93569946, 22.58392525], [88.9357605, 22.5832901], [88.93578339, 22.58270073], [88.93579102, 22.58217621], [88.93579865, 22.58171272], [88.93582153, 22.58125114], [88.93582916, 22.58076286], [88.93586731, 22.58024216], [88.93601227, 22.57974434], [88.93617249, 22.57925606], [88.93634033, 22.57884026], [88.93637085, 22.57845688], [88.93637085, 22.5781498], [88.93657684, 22.57782555], [88.93663788, 22.57759285], [88.9366684, 22.57727051], [88.9367218, 22.57692146], [88.93683624, 22.57655144], [88.9369278, 22.57612038], [88.93694305, 22.57569122], [88.93694305, 22.57526207], [88.93696594, 22.57484245], [88.9370575, 22.57443047], [88.93717194, 22.57403374], [88.93723297, 22.57359505], [88.93731689, 22.57316017], [88.93741608, 22.57270813], [88.93747711, 22.57222176], [88.93754578, 22.57170486], [88.93770599, 22.57122993], [88.93775177, 22.57078171], [88.93768311, 22.57038116], [88.93760681, 22.56993294], [88.9370575, 22.56965637], [88.9362793, 22.56969452], [88.93559265, 22.56964493], [88.93495178, 22.56950188], [88.93431854, 22.56939125], [88.93370056, 22.56921959], [88.93312073, 22.56917953], [88.93257904, 22.56921959], [88.93209076, 22.56941032], [88.93158722, 22.56957054], [88.93106842, 22.56959915], [88.93057251, 22.5694294], [88.93013763, 22.56921959], [88.92973328, 22.56906128], [88.92935944, 22.56894112], [88.92900848, 22.56886292], [88.92868042, 22.56871033], [88.92832947, 22.56866455], [88.92796326, 22.56873322], [88.92761993, 22.56864738], [88.92730713, 22.56862068], [88.92701721, 22.56859016], [88.92671204, 22.56850243], [88.92639923, 22.56837463], [88.92605591, 22.56833839], [88.92569733, 22.56833076], [88.92533875, 22.56833458], [88.92495728, 22.56833458], [88.92458344, 22.56833458], [88.92424011, 22.56833076], [88.92395782, 22.56833839], [88.9236908, 22.56834793], [88.92339325, 22.56835365], [88.92305756, 22.56833076], [88.92269897, 22.56841087], [88.92229462, 22.56854439], [88.92194366, 22.56833458], [88.92082977, 22.56833458], [88.92055511, 22.5680542], [88.91999054, 22.5680027], [88.91951752, 22.56807137], [88.91916656, 22.56805992], [88.91860962, 22.56802177], [88.91831207, 22.56796265], [88.91802216, 22.5678196], [88.91771698, 22.56770134], [88.91747284, 22.56749916], [88.91720581, 22.5672493], [88.91689301, 22.56698227], [88.91655731, 22.56673431], [88.91616821, 22.56657028], [88.91581726, 22.5664196], [88.91542053, 22.56633949], [88.91506195, 22.56621361], [88.91467285, 22.56620216], [88.91426849, 22.5663147], [88.91382599, 22.56629181], [88.91342163, 22.56617165], [88.91333008, 22.56611061], [88.91221619, 22.56611061], [88.91194153, 22.56583214], [88.91166687, 22.56583595], [88.91139221, 22.56555748], [88.91110992, 22.56556129], [88.91091156, 22.56535339], [88.9108429, 22.56528473], [88.90972137, 22.56528473], [88.90944672, 22.56556129], [88.90859985, 22.56556129], [88.90833282, 22.56528473], [88.90805054, 22.56516075], [88.90766907, 22.5652523], [88.90719604, 22.56522942], [88.90670013, 22.56507111], [88.90614319, 22.56496239], [88.90559387, 22.56479836], [88.90500641, 22.56472969], [88.90441895, 22.56469727], [88.90383148, 22.56456947], [88.90320587, 22.56434631], [88.90252686, 22.56419945], [88.90184021, 22.5641613], [88.90118408, 22.56412315], [88.90061188, 22.56397057], [88.90009308, 22.5639019], [88.89958954, 22.56388855], [88.89911652, 22.56389046], [88.89868164, 22.56385994], [88.89823914, 22.56376648], [88.89775848, 22.56366539], [88.89726257, 22.56357002], [88.89683533, 22.56340218], [88.89666748, 22.56333351], [88.89638519, 22.56333351], [88.89620209, 22.5631485], [88.89611053, 22.56305504], [88.89583588, 22.56306458], [88.89554596, 22.56278038], [88.89527893, 22.56278038], [88.89472198, 22.56221962], [88.89444733, 22.56222343], [88.89416504, 22.56194496], [88.89389038, 22.56194496], [88.89333344, 22.56138992], [88.89305878, 22.56139183], [88.89289093, 22.5612011], [88.89260101, 22.56093025], [88.89225769, 22.56064987], [88.89198303, 22.5603199], [88.89176178, 22.55994987], [88.89160919, 22.55956078], [88.89141083, 22.55923843], [88.89125061, 22.55891228], [88.89111328, 22.55888748], [88.89111328, 22.5580616], [88.88916779, 22.55611229], [88.8888855, 22.55611229], [88.88871002, 22.55594063], [88.88857269, 22.55580521], [88.88822937, 22.55553246], [88.88786316, 22.55525017], [88.88754272, 22.55495262], [88.88722229, 22.55462265], [88.88690948, 22.5543232], [88.88656616, 22.55404663], [88.88626862, 22.55373955], [88.8860321, 22.55339241], [88.88582611, 22.55307198], [88.88565063, 22.55278206], [88.88546753, 22.55252647], [88.88524628, 22.55228996], [88.88500977, 22.55204201], [88.88474274, 22.55175209], [88.88445282, 22.55138969], [88.88417053, 22.5510006], [88.88388824, 22.55055046], [88.88359833, 22.55013657], [88.88330841, 22.54974174], [88.88298798, 22.54940987], [88.88263702, 22.54911995], [88.88230133, 22.54883194], [88.88199615, 22.54849052], [88.88172913, 22.54811859], [88.88146973, 22.54776192], [88.88118744, 22.54743195], [88.88088989, 22.54713058], [88.88057709, 22.54686165], [88.88024902, 22.54662323], [88.87992859, 22.54637337], [88.8796463, 22.54600334], [88.87942505, 22.54562187], [88.87923431, 22.54528236], [88.87870026, 22.54473686], [88.87854767, 22.5446434], [88.878479, 22.54460526], [88.87834167, 22.54453087], [88.87798309, 22.54453468], [88.8777771, 22.5447216], [88.8769455, 22.5447216], [88.87638855, 22.54416656], [88.87555695, 22.54417229], [88.87526703, 22.54445076], [88.875, 22.54444885], [88.87472534, 22.5447216], [88.87473297, 22.54499817], [88.87444305, 22.54528236], [88.87444305, 22.54555893], [88.87388611, 22.54611397], [88.8730545, 22.54611397], [88.87277985, 22.54583549], [88.87249756, 22.54583549], [88.8722229, 22.54555511], [88.87180328, 22.54597473], [88.87166595, 22.54611397], [88.8713913, 22.54583549], [88.8713913, 22.5447216], [88.87083435, 22.54416656], [88.87055206, 22.54416656], [88.87000275, 22.5447216], [88.87000275, 22.54499817], [88.86916351, 22.54583549], [88.86888885, 22.54583549], [88.86759186, 22.54453659], [88.86694336, 22.54388618], [88.86667633, 22.54388809], [88.8658371, 22.54306221], [88.8658371, 22.54194069], [88.86694336, 22.54083252], [88.86722565, 22.54083443], [88.86750031, 22.54055405], [88.86750031, 22.5402813], [88.86734772, 22.54018021], [88.86720276, 22.53979492], [88.86712646, 22.53931236], [88.86712646, 22.53884315], [88.8670578, 22.53804016], [88.86663055, 22.53709984], [88.86634064, 22.53562164], [88.86598206, 22.5339489], [88.86612701, 22.5334816], [88.86612701, 22.53254128], [88.86598206, 22.53167152], [88.86569214, 22.53046417], [88.86598206, 22.52859306], [88.86669922, 22.5261097], [88.86698914, 22.52510262], [88.8670578, 22.52342987], [88.86659241, 22.52303123], [88.86614227, 22.52274132], [88.86569977, 22.52252579], [88.86524963, 22.52235222], [88.8647995, 22.52222252], [88.86435699, 22.52211189], [88.86395264, 22.52198219], [88.86353302, 22.52190208], [88.86315155, 22.52176857], [88.86279297, 22.52163124], [88.86245728, 22.52140999], [88.86206818, 22.52124596], [88.86167145, 22.52111244], [88.86128235, 22.52099037], [88.8609314, 22.52086067], [88.86057281, 22.52073097], [88.86023712, 22.52055168], [88.85991669, 22.52033043], [88.85958099, 22.52011299], [88.85929108, 22.51982307], [88.85904694, 22.51950264], [88.8588028, 22.51920128], [88.85855103, 22.51890182], [88.85832977, 22.51855278], [88.85813141, 22.51814842], [88.85803986, 22.51766014], [88.85795593, 22.51716614], [88.85780334, 22.51672173], [88.85766602, 22.51628685], [88.85752869, 22.51587105], [88.85740662, 22.51547432], [88.85727692, 22.51508522], [88.85720062, 22.5146904], [88.85710144, 22.51433945], [88.85697937, 22.51403618], [88.85688019, 22.51371193], [88.85674286, 22.51342583], [88.85662079, 22.51309395], [88.85639191, 22.51277733], [88.85639191, 22.51166725], [88.85527802, 22.5105629], [88.85500336, 22.5105629], [88.85472107, 22.51028252], [88.85415649, 22.51028252], [88.85388947, 22.51000023], [88.85360718, 22.51000023], [88.85333252, 22.51028252], [88.85292816, 22.51020622], [88.85260773, 22.51031113], [88.85244751, 22.51036263], [88.85196686, 22.51031303], [88.85146332, 22.51029015], [88.85096741, 22.51028252], [88.85045624, 22.51027107], [88.84996033, 22.51023293], [88.84947968, 22.51007462], [88.84900665, 22.50994492], [88.84860229, 22.5097599], [88.84818268, 22.5096035], [88.84771729, 22.50946999], [88.84728241, 22.50936317], [88.84686279, 22.50927162], [88.84644318, 22.50938225], [88.84610748, 22.50962257], [88.8458252, 22.50979805], [88.84551239, 22.5098362], [88.84522247, 22.50975609], [88.84492493, 22.50956154], [88.84456635, 22.50930977], [88.84417725, 22.50904655], [88.84381866, 22.50875282], [88.84347534, 22.50850677], [88.84316254, 22.50834465], [88.84281158, 22.50787354], [88.84259796, 22.50720406], [88.84266663, 22.50639915], [88.84295654, 22.50486183], [88.84323883, 22.50339317], [88.84365845, 22.50204277], [88.84460449, 22.50090408], [88.84648132, 22.50040245], [88.84689331, 22.50028038], [88.84725189, 22.50016975], [88.84752655, 22.50002289], [88.84777832, 22.4999485], [88.84803772, 22.49996948], [88.84829712, 22.50004005], [88.84855652, 22.50016975], [88.84884644, 22.50025177], [88.84915924, 22.5003109], [88.84942627, 22.50041008], [88.84976959, 22.50040627], [88.85019684, 22.50045967], [88.85073853, 22.50052071], [88.85138702, 22.50053978], [88.8520813, 22.50055122], [88.85273743, 22.50055122], [88.85330963, 22.50055122], [88.85381317, 22.50055122], [88.85428619, 22.50053024], [88.85484314, 22.50045967], [88.85546875, 22.50042152], [88.85614777, 22.50048447], [88.85652161, 22.50045395], [88.85683441, 22.50042534], [88.85749054, 22.50013161], [88.85782623, 22.49988174], [88.85816193, 22.49963188], [88.85884857, 22.49915123], [88.85929108, 22.49872017], [88.85948181, 22.49823189], [88.85965729, 22.49775124], [88.85977173, 22.49722862], [88.85993958, 22.49673271], [88.86003876, 22.49616051], [88.8602066, 22.49558067], [88.86032867, 22.4949398], [88.86053467, 22.49432564], [88.86075592, 22.49370193], [88.86102295, 22.49316025], [88.86129761, 22.49269295], [88.86152649, 22.49218941], [88.861763, 22.49166298], [88.86199188, 22.49114227], [88.86226654, 22.49067879], [88.86258698, 22.49029922], [88.86295319, 22.48999214], [88.86329651, 22.48965263], [88.86364746, 22.48929024], [88.86408234, 22.48893356], [88.86460876, 22.48858643], [88.86508179, 22.48814201], [88.86524963, 22.4875164], [88.86519623, 22.48687172], [88.86483002, 22.48635292], [88.86421204, 22.48613548], [88.86360168, 22.48602486], [88.86310577, 22.48590469], [88.8625946, 22.48587227], [88.86203766, 22.48591423], [88.86143494, 22.48585892], [88.86083221, 22.48577309], [88.86029816, 22.48555374], [88.85980225, 22.48533249], [88.85931396, 22.48516273], [88.85889435, 22.48489761], [88.85848999, 22.48459053], [88.85810852, 22.48428345], [88.85777283, 22.48393822], [88.85749054, 22.48358917], [88.85726166, 22.4832325], [88.85713196, 22.48278999], [88.85710144, 22.48229599], [88.85704803, 22.48180008], [88.85695648, 22.48130226], [88.85687256, 22.48076439], [88.85671997, 22.48020363], [88.85667419, 22.47961426], [88.85666656, 22.47904778], [88.85666656, 22.47853279], [88.85666656, 22.47805977], [88.85666656, 22.47762108], [88.85666656, 22.4771595], [88.85668945, 22.47665977], [88.8567276, 22.47614288], [88.85681152, 22.47564125], [88.85666656, 22.47500038], [88.85639191, 22.47500038], [88.85610962, 22.47472191], [88.85582733, 22.47472191], [88.85555267, 22.47500038], [88.85527802, 22.47500038], [88.85500336, 22.47527885], [88.85444641, 22.47527885], [88.85432434, 22.47515488], [88.85416412, 22.47500038], [88.85333252, 22.47500038], [88.85305786, 22.47527885], [88.8527832, 22.47527122], [88.85250092, 22.47556114], [88.85166931, 22.47556114], [88.85111237, 22.47500038], [88.8527832, 22.47332954], [88.85277557, 22.47305489], [88.85333252, 22.47250175], [88.85333252, 22.4719429], [88.85361481, 22.47166634], [88.85360718, 22.47139168], [88.85388947, 22.47110939], [88.85388947, 22.47083473], [88.85444641, 22.47027779], [88.85444641, 22.47000122], [88.85472107, 22.46972275], [88.85472107, 22.4691658], [88.85500336, 22.46889114], [88.85500336, 22.46833038], [88.85472107, 22.46805573], [88.85472107, 22.46778107], [88.85444641, 22.46750069], [88.85444641, 22.46500206], [88.85472107, 22.46471977], [88.85472107, 22.46333313], [88.85444641, 22.46305847], [88.85444641, 22.46277618], [88.85388947, 22.46222115], [88.85388947, 22.46194458], [88.85333252, 22.46138954], [88.85333252, 22.46027184], [88.85305786, 22.45999908], [88.85305786, 22.45944023], [88.85277557, 22.45916748], [88.8527832, 22.45889091], [88.85250092, 22.45861244], [88.85250092, 22.45833015], [88.85277557, 22.4580555], [88.8527832, 22.45694351], [88.85194397, 22.45611382], [88.85194397, 22.45583534], [88.85221863, 22.45583534], [88.85277557, 22.4552784], [88.8527832, 22.45417023], [88.85305786, 22.45389175], [88.85333252, 22.45389175], [88.85360718, 22.45417023], [88.85444641, 22.45500183], [88.85472107, 22.45500183], [88.85500336, 22.45471954], [88.85527802, 22.45471954], [88.85555267, 22.45444679], [88.85555267, 22.45416832], [88.85582733, 22.45389175], [88.85582733, 22.45361137], [88.85610962, 22.4533329], [88.85610962, 22.45278168], [88.85582733, 22.4525013], [88.85740662, 22.45121384], [88.85775757, 22.45080566], [88.85807037, 22.45037079], [88.85838318, 22.44992256], [88.85864258, 22.44942474], [88.85887146, 22.44891167], [88.85904694, 22.44841194], [88.85914612, 22.44790459], [88.85920715, 22.44746017], [88.85933685, 22.44708061], [88.85942078, 22.44667244], [88.85948944, 22.44617462], [88.85961914, 22.44557381], [88.85961151, 22.44482994], [88.85939789, 22.44413185], [88.85904694, 22.44354057], [88.85862732, 22.4430275], [88.85817719, 22.4425602], [88.85772705, 22.44215393], [88.85729218, 22.44176483], [88.85681152, 22.44144249], [88.85629272, 22.44119072], [88.85575867, 22.44101143], [88.85527802, 22.44081116], [88.85486603, 22.44054985], [88.85452271, 22.44025993], [88.85423279, 22.43993187], [88.85398865, 22.4395504], [88.8537674, 22.43914986], [88.8535614, 22.43872261], [88.85334015, 22.4383049], [88.85314941, 22.43784142], [88.85307312, 22.43735313], [88.85305023, 22.43690109], [88.8530426, 22.43653297], [88.8530426, 22.43622017], [88.8530426, 22.4359436], [88.85305023, 22.43567467], [88.85305023, 22.43540001], [88.8530426, 22.43510246], [88.85299683, 22.43477058], [88.85298157, 22.43425179], [88.85312653, 22.43360329], [88.85306549, 22.43326759], [88.85292816, 22.43303108], [88.8527298, 22.43289185], [88.85244751, 22.43283272], [88.8520813, 22.43287086], [88.8516922, 22.4329319], [88.85131073, 22.43303108], [88.85093689, 22.4331913], [88.8505249, 22.43333435], [88.8500824, 22.43349838], [88.84962463, 22.4336586], [88.84916687, 22.43386269], [88.84872437, 22.4340744], [88.84828949, 22.43432045], [88.84792328, 22.43456078], [88.84752655, 22.43473816], [88.84711456, 22.4348774], [88.84672546, 22.43499947], [88.84632111, 22.43510437], [88.84591675, 22.43528938], [88.84552002, 22.43550301], [88.84509277, 22.43562126], [88.84464264, 22.43570137], [88.84428406, 22.43583298], [88.84393311, 22.43595314], [88.84348297, 22.43597221], [88.84291077, 22.43591118], [88.84218597, 22.43600273], [88.8414917, 22.43617058], [88.84088898, 22.4364109], [88.84039307, 22.43660164], [88.83985901, 22.43671989], [88.83934784, 22.43694878], [88.83880615, 22.43717194], [88.83821869, 22.43722916], [88.83760834, 22.43725014], [88.83699799, 22.43732262], [88.8363266, 22.43725014], [88.83571625, 22.43722916], [88.8351593, 22.43721962], [88.83463287, 22.43717194], [88.83409119, 22.43699074], [88.83347321, 22.43690872], [88.83281708, 22.4367485], [88.8321991, 22.4366703], [88.83162689, 22.43660927], [88.83114624, 22.43647194], [88.83067322, 22.4364109], [88.8302002, 22.43621254], [88.82964325, 22.43613243], [88.82901001, 22.43602943], [88.82836151, 22.43588257], [88.82766724, 22.43573952], [88.82692719, 22.43560982], [88.8261795, 22.4356041], [88.82550049, 22.4356823], [88.82496643, 22.43586159], [88.82453156, 22.43611908], [88.8241272, 22.43659019], [88.82411194, 22.43728065], [88.82444763, 22.43782425], [88.82485962, 22.43827248], [88.82533264, 22.43861198], [88.82585144, 22.43885422], [88.82637024, 22.43921471], [88.82686615, 22.43965912], [88.82733154, 22.4401226], [88.82775879, 22.44054222], [88.82816315, 22.44095039], [88.82853699, 22.44138145], [88.82884979, 22.441782], [88.8290863, 22.44215012], [88.82935333, 22.44247246], [88.82946777, 22.44286156], [88.82962036, 22.44325066], [88.82969666, 22.44369316], [88.82971954, 22.44409752], [88.82971954, 22.44445229], [88.82971954, 22.44474983], [88.82971954, 22.44503212], [88.82971954, 22.44530296], [88.82971954, 22.44559288], [88.82972717, 22.44592094], [88.82971954, 22.44630623], [88.8296814, 22.44675255], [88.8295517, 22.44720268], [88.82930756, 22.44762802], [88.82900238, 22.44807243], [88.82866669, 22.44854927], [88.82828522, 22.44902229], [88.82782745, 22.44944191], [88.8273468, 22.44984245], [88.82688141, 22.45021248], [88.82639313, 22.45049286], [88.82594299, 22.45070076], [88.82553101, 22.45088005], [88.82520294, 22.45104027], [88.82480621, 22.45111847], [88.82434082, 22.45119286], [88.82382202, 22.45136833], [88.8232193, 22.45153618], [88.82264709, 22.45178413], [88.82203674, 22.45202255], [88.82145691, 22.45229149], [88.82092285, 22.45245552], [88.82035828, 22.45253181], [88.81987, 22.45267487], [88.81943512, 22.45287323], [88.81894684, 22.45299149], [88.81847382, 22.45314217], [88.81803894, 22.4533329], [88.81758881, 22.45355034], [88.81716156, 22.45389175], [88.81672668, 22.45423508], [88.81639099, 22.45444107], [88.81582642, 22.45500183], [88.8152771, 22.4552002], [88.81472015, 22.45555496], [88.81472015, 22.45583344], [88.81416321, 22.45639229], [88.81416321, 22.45666695], [88.81417847, 22.45694351], [88.81416321, 22.45723152], [88.81416321, 22.4580555], [88.8144455, 22.45833206], [88.8144455, 22.46138954], [88.81455231, 22.46160316], [88.81445313, 22.46199226], [88.8143692, 22.46233749], [88.81429291, 22.46273232], [88.81417847, 22.46317101], [88.81404877, 22.46368217], [88.81385803, 22.46418953], [88.81368256, 22.46471977], [88.81362152, 22.46531105], [88.81360626, 22.46587181], [88.81360626, 22.46638298], [88.81360626, 22.46689034], [88.81362915, 22.46746445], [88.81369781, 22.46812439], [88.81387329, 22.46882057], [88.8139801, 22.46956825], [88.8141098, 22.4702549], [88.81421661, 22.47089958], [88.81437683, 22.47147942], [88.81435394, 22.47197723], [88.81417084, 22.47235489], [88.81397247, 22.47267914], [88.81378174, 22.47310257], [88.81359863, 22.47354507], [88.81336975, 22.47401237], [88.81317902, 22.47453117], [88.81302643, 22.47508049], [88.81284332, 22.4755764], [88.81278229, 22.47604942], [88.81273651, 22.47647667], [88.81262207, 22.47686195], [88.81253815, 22.47731018], [88.81252289, 22.47784233], [88.81251526, 22.47838593], [88.8125, 22.47890282], [88.81244659, 22.47936058], [88.81228638, 22.47969246], [88.81218719, 22.48003387], [88.8120575, 22.48032951], [88.81194305, 22.48066139], [88.81176758, 22.48101234], [88.81156158, 22.48137856], [88.81128693, 22.4817524], [88.81093597, 22.48209953], [88.81051636, 22.48240662], [88.81000519, 22.48271179], [88.80945587, 22.48304939], [88.80887604, 22.48341942], [88.80840302, 22.48383141], [88.80800629, 22.48425102], [88.80770874, 22.48466492], [88.80739594, 22.48499107], [88.8070755, 22.48526573], [88.80671692, 22.48550987], [88.80639648, 22.48579979], [88.80605316, 22.48608971], [88.80562592, 22.48633003], [88.80523682, 22.48661232], [88.80484009, 22.48682976], [88.80446625, 22.4870491], [88.80403137, 22.48721123], [88.80353546, 22.48732567], [88.80304718, 22.48747253], [88.80258179, 22.48759842], [88.80216217, 22.48774147], [88.80171967, 22.48783493], [88.80130768, 22.48800087], [88.80082703, 22.48812294], [88.80039215, 22.48833275], [88.79995728, 22.48857117], [88.79956055, 22.48880386], [88.79923248, 22.4890995], [88.79889679, 22.48942757], [88.79857635, 22.48978233], [88.79833221, 22.49020195], [88.79812622, 22.49063301], [88.79806519, 22.49110794], [88.79802704, 22.49157143], [88.797966, 22.4920311], [88.79788208, 22.49245262], [88.79782867, 22.49289131], [88.79775238, 22.49331093], [88.79759979, 22.49363899], [88.79751587, 22.49394035], [88.79741669, 22.49422836], [88.79725647, 22.4944973], [88.79710388, 22.49484253], [88.79691315, 22.49521255], [88.79666138, 22.49559212], [88.79640198, 22.49602318], [88.79612732, 22.49645042], [88.7958374, 22.49684906], [88.79550171, 22.49723244], [88.79508209, 22.49762154], [88.79462433, 22.49804497], [88.79411316, 22.4984417], [88.79363251, 22.49885941], [88.79318237, 22.4992218], [88.79272461, 22.49955177], [88.79231262, 22.49989128], [88.79194641, 22.50020409], [88.79160309, 22.5004406], [88.79125214, 22.50065994], [88.79081726, 22.50085831], [88.79027557, 22.50109673], [88.78967285, 22.50129509], [88.78902435, 22.50143623], [88.78839874, 22.50159264], [88.78777313, 22.50164223], [88.78716278, 22.50167274], [88.78662872, 22.50175285], [88.7861557, 22.50192833], [88.78569031, 22.50208092], [88.7852478, 22.50225258], [88.78485107, 22.50247192], [88.78443909, 22.50266075], [88.78409576, 22.50281715], [88.78381348, 22.50306129], [88.78353882, 22.50333977], [88.7832489, 22.5036602], [88.78302765, 22.50405121], [88.78277588, 22.50444984], [88.78255463, 22.50488091], [88.78238678, 22.50538063], [88.78211212, 22.50579643], [88.78173828, 22.50618172], [88.78132629, 22.50661278], [88.78088379, 22.50702286], [88.78042603, 22.50743294], [88.77993774, 22.50777054], [88.77947998, 22.50805473], [88.77906799, 22.50831032], [88.77868652, 22.50855064], [88.77838135, 22.50883484], [88.77806091, 22.50909233], [88.77771759, 22.50937271], [88.77732849, 22.50965118], [88.77693939, 22.5099926], [88.77648926, 22.5103302], [88.77605438, 22.51071167], [88.7755661, 22.5110302], [88.77513123, 22.51137161], [88.77468872, 22.51166534], [88.77427673, 22.51194382], [88.77389526, 22.51219749], [88.77346039, 22.51237297], [88.77300262, 22.51255989], [88.77253723, 22.51279259], [88.77207947, 22.51305771], [88.77166748, 22.51338005], [88.77144623, 22.51387215], [88.77139282, 22.51443481], [88.77144623, 22.51498985], [88.77168274, 22.51548195], [88.77196503, 22.51592827], [88.7722702, 22.51633835], [88.77259827, 22.5167408], [88.77295685, 22.51712227], [88.77332306, 22.51746941], [88.77366638, 22.51777077], [88.77405548, 22.51802826], [88.77445221, 22.51830101], [88.77487946, 22.51857376], [88.77527618, 22.51889229], [88.77583313, 22.51889229], [88.77610779, 22.51917076], [88.77639008, 22.51916885], [88.77694702, 22.51972389], [88.77777863, 22.51971817], [88.77805328, 22.52000237], [88.77889252, 22.52000237], [88.77916718, 22.52028084], [88.78056335, 22.52028084], [88.78083038, 22.52057266], [88.78138733, 22.52057266], [88.78150177, 22.52057266], [88.78198242, 22.52065086], [88.7824173, 22.52086067], [88.78282166, 22.52115059], [88.78314209, 22.5214901], [88.78341675, 22.52182388], [88.78366852, 22.52211952], [88.78388214, 22.52239037], [88.78404999, 22.52264595], [88.78417206, 22.5229435], [88.78423309, 22.52329063], [88.78424835, 22.52367973], [88.78425598, 22.52404022], [88.78423309, 22.52437019], [88.78417206, 22.52470016], [88.78416443, 22.52499962], [88.78304291, 22.52616692], [88.78266907, 22.52631569], [88.78227234, 22.52643394], [88.78188324, 22.52660179], [88.78145599, 22.52667046], [88.78105164, 22.52674294], [88.77945709, 22.52663612], [88.77895355, 22.5265007], [88.7784729, 22.52649498], [88.77801514, 22.52658653], [88.77758026, 22.5265522], [88.77716827, 22.52643013], [88.77674866, 22.5263195], [88.77632141, 22.52620125], [88.77583313, 22.52617073], [88.77534485, 22.52625656], [88.77488708, 22.52643013], [88.77445221, 22.52668953], [88.77404022, 22.52700996], [88.77368164, 22.52742386], [88.77346802, 22.52791023], [88.77346039, 22.52844048], [88.77327728, 22.52905083], [88.77300262, 22.5296936], [88.77265167, 22.53024292], [88.77224731, 22.53067207], [88.77186584, 22.53105545], [88.77147675, 22.53137016], [88.77110291, 22.53162384], [88.77070618, 22.53175163], [88.7703476, 22.53195953], [88.76998138, 22.53219032], [88.76953125, 22.53237152], [88.76893616, 22.53249168], [88.76828766, 22.5325985], [88.76763916, 22.53281212], [88.76702881, 22.53307533], [88.76647949, 22.53337288], [88.76602173, 22.53374863], [88.76568604, 22.53424263], [88.76550293, 22.53484154], [88.76541138, 22.53541183], [88.76538086, 22.53590012], [88.76537323, 22.53627968], [88.76537323, 22.5365696], [88.76531982, 22.53683281], [88.7652359, 22.53711128], [88.76519012, 22.53745842], [88.76519012, 22.53790474], [88.76522064, 22.53842354], [88.76527405, 22.53899193], [88.76528931, 22.53957939], [88.76527405, 22.54017067], [88.76524353, 22.54074478], [88.76519012, 22.54129982], [88.76513672, 22.54185486], [88.76512146, 22.54239273], [88.76513672, 22.54291534], [88.76519775, 22.54343987], [88.76522827, 22.54395103], [88.76529694, 22.54440117], [88.76531219, 22.54482269], [88.76519012, 22.54525185], [88.76493073, 22.54568291], [88.76464844, 22.54607391], [88.76436615, 22.54643059], [88.7641449, 22.54682922], [88.76391602, 22.54723167], [88.76365662, 22.54763222], [88.76321411, 22.54801559], [88.76280212, 22.5484581], [88.76250458, 22.54886055], [88.7623291, 22.54924393], [88.76222992, 22.54964638], [88.76220703, 22.55005455], [88.7620697, 22.55051994], [88.76242828, 22.55139732], [88.76271057, 22.55186272], [88.76293182, 22.55213165], [88.76329803, 22.55240059], [88.76364899, 22.55266953], [88.76461792, 22.55389977], [88.76493073, 22.55457115], [88.76527405, 22.55515671], [88.76557922, 22.5557003], [88.76579285, 22.5561924], [88.76593781, 22.55657768], [88.76605225, 22.55692482], [88.76621246, 22.55727196], [88.76635742, 22.55768013], [88.76642609, 22.55816841], [88.76641083, 22.55874062], [88.7664032, 22.55931664], [88.76644897, 22.55972481], [88.76651001, 22.56007195], [88.76660919, 22.56041145], [88.76667023, 22.56055641], [88.76638794, 22.56083488], [88.76611328, 22.56083488], [88.76580811, 22.56061745], [88.76563263, 22.56033134], [88.76551056, 22.56003189], [88.76540375, 22.55960274], [88.76534271, 22.55910683], [88.76529694, 22.55856133], [88.76528168, 22.55799294], [88.76522064, 22.55748177], [88.76512146, 22.5570507], [88.7649765, 22.55669975], [88.76477814, 22.5564003], [88.76452637, 22.55610085], [88.76428223, 22.55529213], [88.7634201, 22.55441093], [88.76216125, 22.55289841], [88.76184082, 22.55241013], [88.76146698, 22.55194473], [88.76118469, 22.55138206], [88.76101685, 22.55076027], [88.7609787, 22.55014992], [88.76110077, 22.54967308], [88.76126099, 22.54930115], [88.76140594, 22.54897118], [88.76161957, 22.54864311], [88.7618866, 22.54827118], [88.76216888, 22.54787254], [88.76239777, 22.54746819], [88.76345062, 22.54589272], [88.7638092, 22.54455757], [88.76360321, 22.54297066], [88.7636795, 22.54247284], [88.76369476, 22.54190636], [88.76371002, 22.54129028], [88.7637558, 22.54065132], [88.76378632, 22.5400486], [88.76378632, 22.53947258], [88.76374054, 22.53894043], [88.7636261, 22.53843117], [88.76348877, 22.53794289], [88.76352692, 22.53746223], [88.76371002, 22.53700066], [88.76383209, 22.53655052], [88.76389313, 22.53613091], [88.76394653, 22.53572273], [88.76404572, 22.5352993], [88.76418304, 22.53484154], [88.76434326, 22.53434181], [88.76457214, 22.53389168], [88.76490021, 22.53355026], [88.76531982, 22.53325081], [88.76574707, 22.53294373], [88.76617432, 22.53257561], [88.76660919, 22.53219414], [88.76715088, 22.53188515], [88.7677536, 22.53164101], [88.76843262, 22.5314312], [88.76913452, 22.53120041], [88.76984406, 22.53091621], [88.7702713, 22.53056145], [88.7702713, 22.53000069], [88.76972198, 22.53000069], [88.76944733, 22.52972221], [88.76889038, 22.53028297], [88.76805878, 22.53028297], [88.76777649, 22.53056145], [88.76693726, 22.53056145], [88.76638794, 22.53111076], [88.76555634, 22.53111076], [88.76526642, 22.53083229], [88.76527405, 22.53055573], [88.7647171, 22.53000069], [88.7647171, 22.52972221], [88.76499939, 22.52972221], [88.76527405, 22.52944374], [88.76526642, 22.5291729], [88.7647171, 22.52861214], [88.7647171, 22.52832985], [88.76444244, 22.52805519], [88.76444244, 22.52778053], [88.76499939, 22.52721977], [88.76526642, 22.52721977], [88.76555634, 22.52750206], [88.76583099, 22.52750206], [88.76667023, 22.52833366], [88.76694489, 22.52833366], [88.76721954, 22.52861214], [88.76741028, 22.52842522], [88.76750183, 22.52833366], [88.76777649, 22.52833366], [88.76805878, 22.52805519], [88.76860809, 22.52806282], [88.76944733, 22.52889061], [88.7702713, 22.52889061], [88.77054596, 22.52861214], [88.77111053, 22.52861214], [88.7711792, 22.5286808], [88.77139282, 22.52889061], [88.77187347, 22.52846527], [88.77199554, 22.52835655], [88.77217865, 22.52798271], [88.77246094, 22.52744865], [88.77281189, 22.52695274], [88.77323914, 22.52650261], [88.77374268, 22.52604103], [88.77430725, 22.5255909], [88.77490997, 22.52518272], [88.77561188, 22.5249157], [88.77623749, 22.5249939], [88.77693176, 22.52513123], [88.77777863, 22.52528191], [88.77805328, 22.52528191], [88.7783432, 22.52499962], [88.77889252, 22.52499962], [88.78138733, 22.52528191], [88.78166962, 22.52499962], [88.78250122, 22.52499962], [88.78277588, 22.52472115], [88.78277588, 22.52277756], [88.7822113, 22.52222252], [88.78194427, 22.52222252], [88.78166962, 22.52194405], [88.78111267, 22.52194405], [88.78083038, 22.52166939], [88.78056335, 22.52166939], [88.77997589, 22.52164268], [88.77950287, 22.52145958], [88.77902222, 22.52131844], [88.77857208, 22.5211792], [88.77815247, 22.52109909], [88.77770233, 22.52104187], [88.77731323, 22.52094078], [88.77697754, 22.52091217], [88.77694702, 22.52083397], [88.77610779, 22.52083397], [88.77583313, 22.5205555], [88.77555847, 22.52057266], [88.77527618, 22.52028084], [88.77500153, 22.52028084], [88.77471924, 22.52000237], [88.7743988, 22.51976204], [88.77397919, 22.51950836], [88.7735672, 22.5192318], [88.77313995, 22.51893425], [88.77262115, 22.51864052], [88.77205658, 22.51833153], [88.77169037, 22.51789474], [88.77139282, 22.51743507], [88.77111816, 22.51701164], [88.77086639, 22.51659966], [88.77062988, 22.51617241], [88.77043152, 22.51569939], [88.77024078, 22.51519966], [88.77000427, 22.5147419], [88.76970673, 22.51428795], [88.76935577, 22.51385307], [88.76888275, 22.51359177], [88.76837921, 22.51343918], [88.76793671, 22.5135479], [88.76751709, 22.5136013], [88.76709747, 22.51361275], [88.76668549, 22.51361084], [88.76626587, 22.51361275], [88.76582336, 22.51363754], [88.76534271, 22.51369286], [88.76473999, 22.51366234], [88.76416779, 22.51370049], [88.7636261, 22.51384163], [88.76316071, 22.51389122], [88.76270294, 22.51390266], [88.76220703, 22.51391029], [88.76171112, 22.51395988], [88.76126099, 22.51411247], [88.76082611, 22.51419258], [88.76048279, 22.51429176], [88.76019287, 22.51443481], [88.75981903, 22.51453209], [88.75937653, 22.51466942], [88.75891113, 22.51479149], [88.75847626, 22.51488304], [88.75811005, 22.51502037], [88.7576828, 22.51518059], [88.75726318, 22.51531029], [88.7568512, 22.51553154], [88.75642395, 22.51568031], [88.75601196, 22.51584435], [88.75562286, 22.51601601], [88.75520325, 22.51614189], [88.75478363, 22.5163002], [88.75434875, 22.51642036], [88.75393677, 22.51659966], [88.75348663, 22.51675224], [88.75305176, 22.51690292], [88.75245667, 22.51693153], [88.7518692, 22.5168972], [88.7507782, 22.51696587], [88.75041962, 22.51696587], [88.7501297, 22.5168972], [88.7495575, 22.51664162], [88.74897766, 22.51629066], [88.74783325, 22.51609421], [88.74674988, 22.51602745], [88.74495697, 22.51575279], [88.74372101, 22.51543617], [88.74323273, 22.51534081], [88.74276733, 22.51530266], [88.74233246, 22.5152607], [88.74185944, 22.51519966], [88.74139404, 22.51504707], [88.74092865, 22.51485252], [88.74044037, 22.51466179], [88.73994446, 22.51450157], [88.73944855, 22.51433754], [88.73898315, 22.51418114], [88.73854828, 22.51400185], [88.73812103, 22.51384544], [88.73776245, 22.51366234], [88.73744965, 22.51346016], [88.73716736, 22.51322937], [88.73687744, 22.51297379], [88.73659515, 22.51268005], [88.73629761, 22.5123806], [88.73602295, 22.51205254], [88.73571014, 22.51173973], [88.73539734, 22.51146126], [88.7350769, 22.51125145], [88.73477936, 22.51106071], [88.73446655, 22.51095963], [88.73414612, 22.51091957], [88.73382568, 22.51094818], [88.73352051, 22.51106071], [88.73322296, 22.51128197], [88.73290253, 22.51156807], [88.73259735, 22.51192474], [88.73226929, 22.51230049], [88.73197937, 22.51272964], [88.73169708, 22.51316261], [88.73139191, 22.51357841], [88.73103333, 22.51395226], [88.73059845, 22.51431084], [88.73012543, 22.51470757], [88.72963715, 22.51511383], [88.72917938, 22.51553154], [88.72880554, 22.51592827], [88.72858429, 22.51633835], [88.72835541, 22.51670647], [88.72812653, 22.51707077], [88.72776794, 22.51735115], [88.72737885, 22.51764107], [88.72721863, 22.51806068], [88.72666931, 22.51805878], [88.72638702, 22.51833534], [88.72611237, 22.51833153], [88.72556305, 22.51889229], [88.72528076, 22.51889229], [88.72532654, 22.51903915], [88.7249527, 22.51892471], [88.72454071, 22.51893997], [88.72410583, 22.51907158], [88.72364807, 22.51933289], [88.72315979, 22.51958275], [88.72261047, 22.51971245], [88.72196198, 22.51979637], [88.7212677, 22.51989174], [88.72055054, 22.52003479], [88.71990967, 22.52029037], [88.71936035, 22.52066612], [88.71884155, 22.52119637], [88.71810913, 22.52138329], [88.71723938, 22.52234459], [88.71655273, 22.52272224], [88.71627045, 22.52372169], [88.71572876, 22.52418518], [88.71533203, 22.52471352], [88.71494293, 22.52523994], [88.7144928, 22.52571297], [88.71401215, 22.52610207], [88.7135849, 22.52642059], [88.71317291, 22.52670479], [88.7127533, 22.52695274], [88.71234131, 22.52715683], [88.71195221, 22.52728081], [88.71159363, 22.52745819], [88.71124268, 22.52767372], [88.71095276, 22.52803993], [88.71057129, 22.52850533], [88.7099762, 22.52885246], [88.70925903, 22.52907753], [88.70848846, 22.5290947], [88.70778656, 22.5289402], [88.70716095, 22.52882957], [88.70664215, 22.52867317], [88.7061615, 22.52858353], [88.70571136, 22.52844048], [88.70526886, 22.52831078], [88.70484924, 22.52817535], [88.70446014, 22.52802086], [88.70410919, 22.52783394], [88.70378113, 22.52765083], [88.70352173, 22.52740288], [88.70330811, 22.52710152], [88.70307159, 22.52676201], [88.70269012, 22.52638054], [88.7022934, 22.52601051], [88.70187378, 22.52577591], [88.7013855, 22.52555656], [88.70111084, 22.52555656], [88.70083618, 22.52583313], [88.70083618, 22.5261097], [88.70166779, 22.52694321], [88.70166779, 22.52721977], [88.70194244, 22.52750206], [88.70194244, 22.52778053], [88.70276642, 22.52861214], [88.70305634, 22.52861214], [88.70361328, 22.5291729], [88.70249939, 22.53028297], [88.7022171, 22.53028297], [88.70194244, 22.53056145], [88.70083618, 22.53056145], [88.70054626, 22.53028297], [88.69999695, 22.53028297], [88.69944763, 22.52972221], [88.6986084, 22.52972221], [88.69819641, 22.52930641], [88.69777679, 22.5288887], [88.69750214, 22.52889061], [88.69721985, 22.52861214], [88.6958313, 22.52861214], [88.69555664, 22.52889061], [88.69526672, 22.52889061], [88.69502258, 22.52863503], [88.69472504, 22.52833366], [88.69444275, 22.52833366], [88.69249725, 22.52638817], [88.6922226, 22.52638817], [88.69194794, 22.52611351], [88.69194794, 22.52555656], [88.69249725, 22.52499962], [88.69444275, 22.52499962], [88.69499969, 22.52555656], [88.69527435, 22.52555656], [88.6958313, 22.52611351], [88.6966629, 22.52611351], [88.69721985, 22.52555656], [88.69721985, 22.52499962], [88.69695282, 22.52472115], [88.69667053, 22.52463531], [88.69599152, 22.52451134], [88.69532776, 22.52441978], [88.69471741, 22.52431488], [88.69419861, 22.52419281], [88.69371796, 22.52406502], [88.69315338, 22.52396393], [88.69249725, 22.52392578], [88.69185638, 22.52394295], [88.69130707, 22.52402115], [88.69093323, 22.5241909], [88.6906662, 22.52441216], [88.69050598, 22.52474022], [88.69036865, 22.52510262], [88.69029999, 22.52552032], [88.69029236, 22.52594185], [88.69035339, 22.52636147], [88.69050598, 22.52672005], [88.69065094, 22.52711868], [88.6908493, 22.52745819], [88.69106293, 22.52779961], [88.69113922, 22.52825737], [88.69126129, 22.52877235], [88.69138336, 22.52931023], [88.6914978, 22.52987289], [88.6916275, 22.5304203], [88.69168091, 22.53098679], [88.69172668, 22.53156281], [88.69181824, 22.53212166], [88.69184113, 22.53264809], [88.69168091, 22.53309059], [88.69149017, 22.53350258], [88.69135284, 22.53383255], [88.69132996, 22.53405952], [88.69078064, 22.53458977], [88.69054413, 22.53461647], [88.69030762, 22.53470039], [88.69000244, 22.53481293], [88.68963623, 22.53495979], [88.68920898, 22.53508949], [88.6887207, 22.53526115], [88.68819427, 22.53544044], [88.68768311, 22.53565025], [88.68714905, 22.53586006], [88.68667603, 22.53604126], [88.686203, 22.53609848], [88.68578339, 22.53611374], [88.68544769, 22.53614807], [88.68427277, 22.53660774], [88.68312073, 22.53685951], [88.68234253, 22.53744316], [88.68214417, 22.53784561], [88.68202209, 22.53822136], [88.68205261, 22.5385685], [88.68218231, 22.53891945], [88.68234253, 22.53936386], [88.68254852, 22.53985023], [88.68283844, 22.54031944], [88.68309021, 22.54144287], [88.68314362, 22.54212189], [88.68300629, 22.54248238], [88.68279266, 22.54283333], [88.68255615, 22.54327202], [88.68226624, 22.54378128], [88.68192291, 22.54421043], [88.68154144, 22.54462242], [88.68110657, 22.54495049], [88.6805954, 22.54519272], [88.68003845, 22.54540062], [88.67948151, 22.54562569], [88.67887115, 22.54589272], [88.67823792, 22.54618263], [88.67758942, 22.54651642], [88.67698669, 22.54691124], [88.6763916, 22.54741096], [88.67592621, 22.54789162], [88.67553711, 22.54824829], [88.67517853, 22.54856491], [88.6738739, 22.54961967], [88.67359161, 22.55002213], [88.67359161, 22.55062294], [88.67366028, 22.55096245], [88.67405701, 22.55181313], [88.67408752, 22.55237007], [88.67410278, 22.55295944], [88.67403412, 22.55356026], [88.67389679, 22.55416489], [88.6736908, 22.55476952], [88.67346954, 22.55534172], [88.67325592, 22.55589104], [88.67311859, 22.55635262], [88.67308807, 22.55672264], [88.67311859, 22.55701828], [88.67325592, 22.55726051], [88.67353058, 22.55746269], [88.67388153, 22.55762672], [88.67424011, 22.55779076], [88.67459869, 22.55799294], [88.67494965, 22.55824661], [88.6753006, 22.55856895], [88.67565155, 22.55895042], [88.67595673, 22.55936813], [88.6762085, 22.55982018], [88.67639923, 22.5603199], [88.67646027, 22.56082916], [88.67640686, 22.56136131], [88.67625427, 22.56189156], [88.67597961, 22.56240463], [88.67565155, 22.56295967], [88.67529297, 22.56359291], [88.67495728, 22.56420326], [88.67469025, 22.5647583], [88.67450714, 22.56525993], [88.6743927, 22.56567955], [88.67429352, 22.56606102], [88.67423248, 22.5664196], [88.674263, 22.56674004], [88.67468262, 22.56750298], [88.67538452, 22.5683403], [88.67619324, 22.56945992], [88.67636871, 22.56994057], [88.67662811, 22.5703907], [88.67684937, 22.57085228], [88.67698669, 22.57127953], [88.67710876, 22.57162285], [88.67717743, 22.57196808], [88.67726135, 22.57235146], [88.67736053, 22.57288551], [88.67739105, 22.57338142], [88.67735291, 22.57386208], [88.67743683, 22.57430077], [88.67763519, 22.5746212], [88.6778717, 22.57480431], [88.67812347, 22.57480431], [88.67840576, 22.57459259], [88.6787262, 22.57442284], [88.67893219, 22.57438278], [88.67912292, 22.57459259], [88.67914581, 22.57505989], [88.67912292, 22.57573128], [88.67920685, 22.5763092], [88.67943573, 22.57672882], [88.67975616, 22.57702065], [88.68016052, 22.57717705], [88.68064117, 22.57722282], [88.68087006, 22.57738495], [88.68074036, 22.57775307], [88.68044281, 22.5782032], [88.68016052, 22.57864761], [88.67997742, 22.57917976], [88.67975616, 22.57969093], [88.67948914, 22.5802021], [88.67913055, 22.58071518], [88.67871857, 22.58123207], [88.67832947, 22.58177185], [88.67797089, 22.58226395], [88.67772675, 22.58272934], [88.67772675, 22.58326149], [88.67778015, 22.58361816], [88.67778015, 22.58389091], [88.67790985, 22.58423424], [88.67805481, 22.58444405], [88.67819214, 22.58472252], [88.6783371, 22.58499908], [88.67854309, 22.58527756], [88.67861176, 22.58556175], [88.67867279, 22.58577156], [88.67881775, 22.58592033], [88.67893982, 22.58640862], [88.67893219, 22.58700371], [88.67893219, 22.58764267], [88.67887115, 22.58820343], [88.67875671, 22.58867073], [88.67863464, 22.5891037], [88.67854309, 22.58961678], [88.67850494, 22.58994484], [88.67780304, 22.59082985], [88.67773438, 22.59134865], [88.677948, 22.59213066], [88.67824554, 22.59220505], [88.67841339, 22.59259224], [88.67822266, 22.59303093], [88.6783371, 22.59361076], [88.67749786, 22.59361076], [88.67740631, 22.59349823], [88.67716217, 22.5928936], [88.67696381, 22.59220695], [88.67681122, 22.59155083], [88.67677307, 22.59095955], [88.6767807, 22.5905056], [88.67688751, 22.59010124], [88.67700958, 22.58974266], [88.67713928, 22.5894413], [88.67729187, 22.58915138], [88.67749023, 22.58887672], [88.67772675, 22.58857155], [88.67797852, 22.58815956], [88.67813873, 22.58770943], [88.67811584, 22.58730125], [88.67798615, 22.58688164], [88.67780304, 22.58644295], [88.67758179, 22.58599281], [88.67740631, 22.58551979], [88.67723083, 22.58509254], [88.67706299, 22.58472252], [88.67692566, 22.58433342], [88.67678833, 22.5839901], [88.67662811, 22.58364105], [88.67642212, 22.58328056], [88.67617035, 22.58284187], [88.67666626, 22.58222198], [88.67666626, 22.58194542], [88.67722321, 22.58138847], [88.67722321, 22.58083153], [88.67762756, 22.58069038], [88.677948, 22.58040047], [88.6782608, 22.58008766], [88.67854309, 22.57976151], [88.67878723, 22.57938194], [88.67891693, 22.57891655], [88.67899323, 22.57840157], [88.67894745, 22.57790947], [88.67878723, 22.57748222], [88.67854309, 22.57716179], [88.67822266, 22.57685852], [88.6778717, 22.57657051], [88.67753601, 22.57625008], [88.67723083, 22.5759201], [88.67693329, 22.57557106], [88.67663574, 22.57523346], [88.67636871, 22.57492256], [88.67608643, 22.57472038], [88.67581177, 22.57472038], [88.67582703, 22.57443047], [88.67583466, 22.57111168], [88.67555237, 22.57073784], [88.67520905, 22.57060051], [88.6743927, 22.56944847], [88.67366791, 22.56884956], [88.6730423, 22.56791115], [88.67279816, 22.56733894], [88.6727066, 22.56677055], [88.67256927, 22.56626129], [88.67251587, 22.56576347], [88.67253113, 22.56530952], [88.67260742, 22.56490135], [88.67272186, 22.56453514], [88.67284393, 22.56419563], [88.67304993, 22.56387138], [88.67331696, 22.56348991], [88.67362213, 22.56303978], [88.67398834, 22.56257629], [88.67437744, 22.56212044], [88.67469788, 22.56163979], [88.67488861, 22.56113243], [88.67487335, 22.56060982], [88.67463684, 22.5601902], [88.67427063, 22.55987167], [88.67385101, 22.55962563], [88.67350006, 22.5593338], [88.67315674, 22.55906487], [88.6727829, 22.55888748], [88.67243958, 22.55867195], [88.67216492, 22.55817223], [88.67192078, 22.55765343], [88.6717453, 22.55716515], [88.67169952, 22.55668449], [88.67178345, 22.5562191], [88.67195129, 22.55573273], [88.67218781, 22.55521202], [88.67243958, 22.5546875], [88.6726532, 22.5540905], [88.67301941, 22.55363464], [88.67308807, 22.55323601], [88.67308807, 22.55290031], [88.67301941, 22.55236244], [88.67258453, 22.55169487], [88.67215729, 22.55068779], [88.67222595, 22.54944038], [88.67250061, 22.5494442], [88.67388916, 22.54805565], [88.67415619, 22.54805946], [88.67444611, 22.5477829], [88.67459106, 22.54735947], [88.6751709, 22.54693031], [88.67572021, 22.54650307], [88.67620087, 22.54612541], [88.67655182, 22.54578972], [88.67746735, 22.54509735], [88.67804718, 22.54483223], [88.67854309, 22.54463005], [88.67919159, 22.54443169], [88.67970276, 22.54429054], [88.68034363, 22.54416084], [88.68077087, 22.54396248], [88.68112946, 22.54369164], [88.68112946, 22.54302025], [88.68106079, 22.54289055], [88.68091583, 22.5425396], [88.68084717, 22.54221535], [88.68070221, 22.54141045], [88.68055725, 22.54074287], [88.68055725, 22.53947258], [88.68026733, 22.53806114], [88.68091583, 22.5363884], [88.68196869, 22.53563118], [88.68263245, 22.53536034], [88.68341064, 22.53516006], [88.68419647, 22.53503227], [88.68463135, 22.53489113], [88.68563843, 22.5346241], [88.68606567, 22.53442574], [88.68678284, 22.53442574], [88.6881485, 22.53429222], [88.68908691, 22.53402138], [88.68951416, 22.53388977], [88.68994904, 22.5333519], [88.69023132, 22.53294945], [88.69052124, 22.53241158], [88.69073486, 22.53181076], [88.69072723, 22.53094482], [88.6906662, 22.53059959], [88.69052124, 22.53046989], [88.69016266, 22.53046989], [88.68994904, 22.53087044], [88.68987274, 22.53101158], [88.68987274, 22.5320797], [88.68979645, 22.53222084], [88.68930054, 22.53222084], [88.68913269, 22.53156281], [88.68897247, 22.53102493], [88.68876648, 22.53046989], [88.68875122, 22.5301609], [88.68889618, 22.52997017], [88.68908691, 22.52972221], [88.68916321, 22.52935219], [88.68917084, 22.52892685], [88.68917084, 22.52847099], [88.68916321, 22.52800179], [88.68913269, 22.52753258], [88.68903351, 22.52708435], [88.68894958, 22.52666664], [88.68881989, 22.52532387], [88.68925476, 22.52404976], [88.69019318, 22.52298164], [88.69148254, 22.52238274], [88.69306183, 22.52257729], [88.6950531, 22.52317238], [88.69565582, 22.52327156], [88.69628143, 22.52331924], [88.69687653, 22.52340126], [88.69745636, 22.52351761], [88.69792175, 22.52341461], [88.69824982, 22.52318764], [88.69859314, 22.52312088], [88.69892883, 22.52324486], [88.6993866, 22.52331924], [88.69989014, 22.52347755], [88.70044708, 22.52364159], [88.70102692, 22.52388954], [88.7016449, 22.52417946], [88.70224762, 22.5245533], [88.70272827, 22.52508163], [88.70316315, 22.52564049], [88.70359802, 22.52609825], [88.70402527, 22.52647209], [88.7044754, 22.52675438], [88.70491028, 22.52705956], [88.7053833, 22.52731133], [88.70593262, 22.52752113], [88.70655823, 22.52766228], [88.70720673, 22.52773094], [88.70748901, 22.52771378], [88.70780182, 22.5276947], [88.70830536, 22.52756882], [88.70877075, 22.52744102], [88.709198, 22.52728081], [88.7096405, 22.52713776], [88.71008301, 22.52696037], [88.71051025, 22.52679062], [88.71092224, 22.52660179], [88.71137238, 22.52642822], [88.71185303, 22.52626991], [88.71230316, 22.52607346], [88.71272278, 22.52581596], [88.71305847, 22.52544212], [88.71327209, 22.5248394], [88.71341705, 22.52425194], [88.71360779, 22.5238018], [88.713974, 22.52350235], [88.71450806, 22.52321434], [88.71495819, 22.52284241], [88.71531677, 22.52243996], [88.71565247, 22.52204895], [88.71601868, 22.52169228], [88.71643066, 22.5213604], [88.71685028, 22.52099037], [88.7171936, 22.52052879], [88.71747589, 22.5200901], [88.71776581, 22.51973152], [88.7181015, 22.51945496], [88.7184906, 22.51926231], [88.71894836, 22.51913261], [88.71942902, 22.51902199], [88.71985626, 22.5188694], [88.72026825, 22.51873207], [88.72070313, 22.51855659], [88.72114563, 22.51839256], [88.72161865, 22.51830482], [88.72210693, 22.51832008], [88.72258759, 22.51841164], [88.72299194, 22.51836967], [88.72336578, 22.51826286], [88.72371674, 22.51807022], [88.72409821, 22.51787186], [88.72452545, 22.51768494], [88.72496033, 22.51745415], [88.72535706, 22.51714516], [88.72575378, 22.51679611], [88.72611237, 22.51641273], [88.72652435, 22.51606369], [88.7269516, 22.51570892], [88.72740173, 22.51535988], [88.72786713, 22.51498222], [88.72835541, 22.51458168], [88.72886658, 22.51418114], [88.72934723, 22.51377296], [88.72975922, 22.51333046], [88.73011017, 22.51291084], [88.73039246, 22.51250267], [88.73064423, 22.51211739], [88.73092651, 22.51173592], [88.73126984, 22.51140594], [88.73165131, 22.51111031], [88.73203278, 22.51082039], [88.73239899, 22.5105648], [88.73279572, 22.51033974], [88.73321533, 22.51016426], [88.73357391, 22.5099926], [88.7339325, 22.5098896], [88.73432922, 22.50987053], [88.73477936, 22.5098629], [88.73521423, 22.50983238], [88.73554993, 22.50975609], [88.7358017, 22.5097599], [88.73600006, 22.50989342], [88.73622894, 22.51024437], [88.73647308, 22.51070213], [88.73681641, 22.51115227], [88.73718262, 22.51161766], [88.73761749, 22.5120945], [88.73812103, 22.51252174], [88.73867035, 22.51286125], [88.73921204, 22.51309776], [88.73973846, 22.5132618], [88.74022675, 22.51338005], [88.74069214, 22.51353455], [88.7411499, 22.5136013], [88.74163055, 22.5136776], [88.74206543, 22.51383018], [88.74253082, 22.51395226], [88.74297333, 22.51410103], [88.74347687, 22.5142231], [88.7440033, 22.51440048], [88.74462128, 22.5146122], [88.74526215, 22.51493263], [88.7459259, 22.51493263], [88.74656677, 22.51494026], [88.74720764, 22.5148716], [88.74780273, 22.51481056], [88.74833679, 22.5148983], [88.7488327, 22.51493263], [88.74925995, 22.5150013], [88.74968719, 22.51514816], [88.75013733, 22.51534081], [88.75063324, 22.51549721], [88.7511673, 22.5155468], [88.7517395, 22.51555443], [88.75232697, 22.51555443], [88.75291443, 22.51552391], [88.75348663, 22.51540565], [88.75408173, 22.51529121], [88.75463867, 22.51518059], [88.75512695, 22.51497269], [88.75554657, 22.51472282], [88.7559433, 22.51444054], [88.75634003, 22.51418495], [88.75676727, 22.51398277], [88.75726318, 22.51385307], [88.75773621, 22.51363182], [88.75823975, 22.51342201], [88.75874329, 22.51319313], [88.75917816, 22.5129509], [88.75961304, 22.512743], [88.75998688, 22.51254082], [88.76040649, 22.51247025], [88.76077271, 22.51236153], [88.76111603, 22.51222038], [88.7614975, 22.51210213], [88.76190186, 22.51197815], [88.7623291, 22.51189995], [88.76275635, 22.51176834], [88.76321411, 22.51181412], [88.76361084, 22.51194572], [88.7638855, 22.51166725], [88.76499939, 22.51166725], [88.76526642, 22.51194382], [88.7654953, 22.51194382], [88.76596832, 22.51194954], [88.76611328, 22.51194954], [88.7665329, 22.51194954], [88.76715088, 22.51194382], [88.7678299, 22.5119133], [88.76850128, 22.51176834], [88.76911163, 22.5116024], [88.76965332, 22.51142311], [88.76999664, 22.51138878], [88.77027893, 22.51111031], [88.77054596, 22.51111031], [88.77083588, 22.51083374], [88.77111053, 22.51083565], [88.77138519, 22.51055717], [88.77159882, 22.51052284], [88.77210236, 22.51013184], [88.77271271, 22.50972366], [88.77334595, 22.50930977], [88.7740097, 22.50892067], [88.77468872, 22.50858116], [88.77527618, 22.50819016], [88.77585602, 22.50780487], [88.77645874, 22.50748825], [88.77703857, 22.50719261], [88.77754974, 22.50688171], [88.77799225, 22.50650215], [88.77842712, 22.50608444], [88.77883148, 22.50566483], [88.77916718, 22.50523949], [88.77941895, 22.50481987], [88.77958679, 22.50444984], [88.7797699, 22.50412178], [88.77990723, 22.50374794], [88.77999115, 22.50325203], [88.78011322, 22.50282288], [88.78009796, 22.50234413], [88.78000641, 22.50182152], [88.77988434, 22.50129509], [88.77971649, 22.50081062], [88.77955627, 22.50034332], [88.77945709, 22.4998436], [88.77939606, 22.49931145], [88.77931976, 22.49876976], [88.77922058, 22.49821281], [88.77916718, 22.49764061], [88.77916718, 22.49711609], [88.77916718, 22.49664116], [88.77916718, 22.49620247], [88.77916718, 22.49577141], [88.77916718, 22.49533272], [88.77916718, 22.49490738], [88.77921295, 22.49451256], [88.77935028, 22.49417114], [88.77944183, 22.49374199], [88.77953339, 22.49315071], [88.77973938, 22.49263763], [88.7800293, 22.492342], [88.78041077, 22.49206352], [88.78072357, 22.49177742], [88.78102112, 22.49148178], [88.78132629, 22.49115944], [88.78161621, 22.4908123], [88.78186035, 22.49046135], [88.78205109, 22.49014091], [88.78218079, 22.48986626], [88.78227997, 22.48962212], [88.78240967, 22.48934174], [88.78259277, 22.48901176], [88.78286743, 22.48870468], [88.78314972, 22.4883213], [88.78344727, 22.48796272], [88.78370667, 22.48759842], [88.78391266, 22.48718071], [88.7841568, 22.48681068], [88.78444672, 22.48645973], [88.78470612, 22.48616028], [88.78472137, 22.48639107], [88.78666687, 22.48444366], [88.78694153, 22.48444557], [88.78722382, 22.4841671], [88.78769684, 22.48407173], [88.78822327, 22.4837513], [88.78869629, 22.48327065], [88.78913116, 22.48274612], [88.7894516, 22.48223305], [88.78980255, 22.48179054], [88.79016113, 22.48140144], [88.79032898, 22.48082161], [88.79046631, 22.48026085], [88.79055023, 22.47976112], [88.79057312, 22.47932434], [88.79058838, 22.4789238], [88.79071808, 22.47855949], [88.79104614, 22.47821045], [88.79131317, 22.47779274], [88.79136658, 22.47727203], [88.79136658, 22.47674751], [88.79142761, 22.47624016], [88.79157257, 22.47571945], [88.7917099, 22.47514153], [88.79193878, 22.47458076], [88.79219055, 22.47401237], [88.79241943, 22.47343636], [88.79265594, 22.4729023], [88.79288483, 22.47240257], [88.79312134, 22.47197723], [88.79335022, 22.47158051], [88.79358673, 22.4711895], [88.79379272, 22.47074318], [88.79393768, 22.47021484], [88.79413605, 22.4697094], [88.79429626, 22.46920204], [88.79449463, 22.46874619], [88.79471588, 22.46833038], [88.79496002, 22.46791267], [88.7951889, 22.46743011], [88.79538727, 22.4669323], [88.795578, 22.46643257], [88.79582214, 22.46601486], [88.79605865, 22.46558952], [88.79624939, 22.46515083], [88.7964859, 22.46474457], [88.79675293, 22.46436119], [88.79702759, 22.46398735], [88.79733276, 22.46361923], [88.79766846, 22.46326637], [88.79795837, 22.46287155], [88.79821014, 22.46247292], [88.79840851, 22.46210289], [88.79860687, 22.46182632], [88.79888916, 22.46167183], [88.79915619, 22.46138954], [88.79915619, 22.4608326], [88.79944611, 22.46055794], [88.79944611, 22.46000099], [88.79972076, 22.45972252], [88.79972076, 22.45916939], [88.80000305, 22.45889091], [88.80000305, 22.45861244], [88.80007172, 22.45852089], [88.80026245, 22.45802116], [88.8004303, 22.45755959], [88.80050659, 22.45714188], [88.80060577, 22.45674706], [88.80065918, 22.45628166], [88.80071259, 22.45578575], [88.8007431, 22.45527077], [88.80075073, 22.45473289], [88.80079651, 22.45418739], [88.8008728, 22.45356941], [88.80096436, 22.45299149], [88.80107117, 22.45235825], [88.80117035, 22.45167923], [88.80111694, 22.45105171], [88.8010788, 22.45044518], [88.80103302, 22.44987297], [88.80110931, 22.44972038], [88.80110931, 22.44861031], [88.80082703, 22.44833183], [88.80083466, 22.44750023], [88.80110931, 22.44722176], [88.80110931, 22.44666862], [88.8013916, 22.44639015], [88.8013916, 22.44611168], [88.80166626, 22.44583321], [88.80166626, 22.44555473], [88.80198669, 22.44511604], [88.80214691, 22.4444828], [88.80233765, 22.44384956], [88.80252075, 22.44342232], [88.80280304, 22.44322014], [88.80304718, 22.44302177], [88.8033371, 22.44277191], [88.80360413, 22.44246674], [88.80388641, 22.44211769], [88.80414581, 22.441782], [88.80439758, 22.44147491], [88.80470276, 22.4412384], [88.80499268, 22.44099236], [88.80531311, 22.44070053], [88.80570984, 22.44040108], [88.80618286, 22.44006157], [88.80671692, 22.4397316], [88.80726624, 22.43939018], [88.80776978, 22.43898964], [88.80821991, 22.43859291], [88.80863953, 22.43819237], [88.8090744, 22.43783951], [88.80944061, 22.43741035], [88.80982971, 22.43699074], [88.81024933, 22.43662262], [88.81062317, 22.43618202], [88.81102753, 22.43578148], [88.81141663, 22.43536186], [88.81183624, 22.43497849], [88.81224823, 22.43460274], [88.81269836, 22.43424034], [88.81317139, 22.43389893], [88.81362915, 22.43354988], [88.81400299, 22.43313026], [88.81439972, 22.43275833], [88.81482697, 22.43240929], [88.8152771, 22.43209267], [88.81571198, 22.43178558], [88.81616211, 22.43150139], [88.81664276, 22.43128014], [88.81711578, 22.43107033], [88.81755829, 22.43086052], [88.81801605, 22.43071175], [88.81848145, 22.43057251], [88.81894684, 22.43046761], [88.81941986, 22.43033028], [88.81991577, 22.43037224], [88.82041931, 22.43050957], [88.82098389, 22.43055534], [88.82156372, 22.43055534], [88.8221283, 22.43051338], [88.82261658, 22.43035507], [88.8230896, 22.43029213], [88.82350159, 22.43027115], [88.82385254, 22.43026161], [88.82417297, 22.43024826], [88.82447815, 22.43020248], [88.82483673, 22.43007278], [88.82527161, 22.43000221], [88.825737, 22.43000984], [88.82624054, 22.43008995], [88.82674408, 22.43027687], [88.82861328, 22.43029213], [88.82888794, 22.43000221], [88.83000183, 22.43000221], [88.83027649, 22.43029213], [88.83110809, 22.43029213], [88.83139038, 22.43056488], [88.83167267, 22.43029213], [88.83249664, 22.43029213], [88.83277893, 22.43056488], [88.83305359, 22.43055534], [88.83333588, 22.43083382], [88.83361053, 22.43083382], [88.83388519, 22.43111229], [88.8347168, 22.43111229], [88.83499908, 22.43139076], [88.83528137, 22.43139076], [88.83555603, 22.43167305], [88.83611298, 22.43166924], [88.83638763, 22.43194389], [88.83666992, 22.43194389], [88.83694458, 22.43222237], [88.83999634, 22.43222237], [88.84027863, 22.43250084], [88.84194183, 22.43250084], [88.84221649, 22.43222237], [88.84555817, 22.43222237], [88.84583282, 22.43194389], [88.84638977, 22.43194389], [88.84666443, 22.43166924], [88.84722137, 22.43167305], [88.8483429, 22.43056488], [88.8483429, 22.43000221], [88.84860992, 22.42972374], [88.84860992, 22.42916679], [88.84889221, 22.42889023], [88.84893036, 22.42823982], [88.84910583, 22.42776299], [88.84928131, 22.42732048], [88.84945679, 22.42691994], [88.849617, 22.42653084], [88.84968567, 22.42609787], [88.84971619, 22.42564964], [88.84976959, 22.42523384], [88.84985352, 22.42486763], [88.84996033, 22.42453957], [88.84999847, 22.42419052], [88.85003662, 22.42381096], [88.85017395, 22.42342186], [88.85029602, 22.42295265], [88.8504715, 22.42245293], [88.85063934, 22.42192459], [88.85082245, 22.421381], [88.85096741, 22.42083168], [88.85109711, 22.42025948], [88.85118866, 22.41968918], [88.85140228, 22.41916084], [88.85163879, 22.41863823], [88.85180664, 22.41807365], [88.85198975, 22.41751671], [88.85218811, 22.41697884], [88.85233307, 22.41640472], [88.85251617, 22.41584015], [88.85275269, 22.41531181], [88.85293579, 22.41481972], [88.85322571, 22.41446686], [88.85334778, 22.41410255], [88.85353851, 22.41378975], [88.85371399, 22.41347694], [88.85385132, 22.41311073], [88.85401154, 22.41273308], [88.85417175, 22.41234779], [88.85439301, 22.41199303], [88.85455322, 22.41155052], [88.85475922, 22.41113281], [88.85500336, 22.41074944], [88.85522461, 22.4104023], [88.85538483, 22.41003609], [88.85555267, 22.40969467], [88.85567474, 22.40932655], [88.85582733, 22.40892982], [88.85595703, 22.40848351], [88.85607147, 22.40801048], [88.85604858, 22.4075222], [88.85588837, 22.40705109], [88.855896, 22.40651894], [88.85600281, 22.40594292], [88.85581207, 22.40541458], [88.85552979, 22.40492058], [88.85525513, 22.40445137], [88.85502625, 22.40399361], [88.85485077, 22.40352058], [88.85472107, 22.4030323], [88.85460663, 22.40253258], [88.85452271, 22.40202141], [88.85438538, 22.40156174], [88.85420227, 22.40114784], [88.85401154, 22.4007206], [88.85381317, 22.40027618], [88.85366058, 22.39980125], [88.85360718, 22.39923859], [88.85357666, 22.39870262], [88.85353088, 22.39822388], [88.85337067, 22.39780998], [88.85328674, 22.39735222], [88.85322571, 22.39687157], [88.85302734, 22.39643478], [88.85279083, 22.3959713], [88.85259247, 22.39546013], [88.85250854, 22.39489555], [88.85250092, 22.39437294], [88.85250092, 22.39392662], [88.85250092, 22.39352608], [88.85250092, 22.39313316], [88.85250854, 22.39272881], [88.85250092, 22.39222145], [88.85221863, 22.39194679], [88.85194397, 22.39194679], [88.85166931, 22.39166832], [88.85138702, 22.39194679], [88.85083008, 22.39194679], [88.85055542, 22.39222145], [88.84750366, 22.39222145], [88.84694672, 22.39166832], [88.84694672, 22.39083481], [88.84722137, 22.39055824], [88.84722137, 22.39027977], [88.84749603, 22.3900013], [88.84638977, 22.38889122], [88.84638977, 22.38861275], [88.84610748, 22.38833237], [88.84638977, 22.3880558], [88.84638977, 22.38777733], [88.8466568, 22.38750267], [88.8466568, 22.38721848], [88.84889221, 22.38499832], [88.84889221, 22.38472176], [88.84944153, 22.38417244], [88.85028076, 22.38501167], [88.85028076, 22.38528061], [88.85083008, 22.38583565], [88.85111237, 22.38583183], [88.85166931, 22.38639259], [88.85166931, 22.38666725], [88.85194397, 22.38694572], [88.85250092, 22.38694572], [88.85277557, 22.38666725], [88.8527832, 22.38501167], [88.85299683, 22.38470268], [88.8530426, 22.38433266], [88.85305786, 22.38387108], [88.85307312, 22.38331032], [88.85314178, 22.38272285], [88.85333252, 22.38223076], [88.8535614, 22.38177109], [88.85380554, 22.38135719], [88.85401917, 22.38097191], [88.85420227, 22.38060379], [88.85443115, 22.38029289], [88.8546524, 22.37997246], [88.85475922, 22.37952995], [88.85488892, 22.37917137], [88.85501862, 22.37890625], [88.85515594, 22.37868309], [88.85528564, 22.3783741], [88.85540771, 22.37806892], [88.85558319, 22.3778019], [88.8557663, 22.37756348], [88.85597229, 22.37732124], [88.85610199, 22.37698746], [88.85617828, 22.37662315], [88.8563385, 22.37626839], [88.85637665, 22.37584114], [88.85637665, 22.37540245], [88.85637665, 22.3749218], [88.85645294, 22.37442207], [88.85663605, 22.3739109], [88.85679626, 22.373312], [88.85697937, 22.37267113], [88.85723114, 22.37207985], [88.85749054, 22.37154961], [88.85774231, 22.37105942], [88.85793304, 22.37059975], [88.85806274, 22.37028313], [88.85832977, 22.37001228], [88.85832977, 22.36972237], [88.85861206, 22.36944389], [88.85888672, 22.36944389], [88.85916901, 22.36916924], [88.85916901, 22.36889076], [88.85943604, 22.36861229], [88.85943604, 22.36806297], [88.85972595, 22.36778069], [88.85972595, 22.36750221], [88.86000061, 22.36721992], [88.86000061, 22.36694527], [88.8602829, 22.36667061], [88.86023712, 22.36638069], [88.86038208, 22.36598015], [88.8605957, 22.36562347], [88.86084747, 22.3653183], [88.86110687, 22.36502266], [88.86140442, 22.36471176], [88.86173248, 22.36438942], [88.86206055, 22.36409187], [88.86252594, 22.36392021], [88.86305237, 22.36383247], [88.86358643, 22.36367035], [88.86416626, 22.36355019], [88.8647995, 22.36343002], [88.8653183, 22.36312294], [88.8658371, 22.36284256], [88.86638641, 22.36261749], [88.86688232, 22.36240959], [88.86734009, 22.36217308], [88.86772156, 22.3618679], [88.86808777, 22.36155128], [88.86850739, 22.36128044], [88.86901855, 22.36104012], [88.86953735, 22.36069107], [88.87011719, 22.36034012], [88.87077332, 22.36004066], [88.87137604, 22.35973358], [88.87191772, 22.35944939], [88.87240601, 22.35920143], [88.8728714, 22.3590107], [88.8733139, 22.35883331], [88.87375641, 22.35862541], [88.87425232, 22.35840034], [88.87474823, 22.35811806], [88.87528229, 22.35775948], [88.87577057, 22.35728455], [88.87610626, 22.35665321], [88.87632751, 22.35598183], [88.87628937, 22.35531044], [88.8759079, 22.35492134], [88.8754425, 22.35501671], [88.87503052, 22.35527229], [88.87468719, 22.35557938], [88.87438965, 22.35586739], [88.87409973, 22.35616684], [88.8738327, 22.35648155], [88.87361145, 22.35667229], [88.8713913, 22.35889244], [88.87082672, 22.35889244], [88.87055206, 22.35917091], [88.86972046, 22.3591671], [88.86958313, 22.35930824], [88.8694458, 22.35944557], [88.86916351, 22.3591671], [88.86888885, 22.3591404], [88.86833191, 22.35904121], [88.86791229, 22.35892868], [88.86753082, 22.35886192], [88.86717987, 22.35881805], [88.86683655, 22.35878754], [88.86649323, 22.35878372], [88.86612701, 22.35877037], [88.86582184, 22.35868263], [88.8655014, 22.35851097], [88.86515808, 22.3583622], [88.86482239, 22.35828018], [88.86437225, 22.35822105], [88.86383057, 22.35819244], [88.86327362, 22.35820389], [88.8628006, 22.35828018], [88.86251831, 22.35847282], [88.8622818, 22.35871315], [88.86203003, 22.35899925], [88.86168671, 22.35923195], [88.86132813, 22.35946465], [88.86096191, 22.35970116], [88.86058044, 22.35992241], [88.86011505, 22.360075], [88.85961914, 22.3602314], [88.85906219, 22.3603611], [88.85848999, 22.36050987], [88.85785675, 22.36063957], [88.85720062, 22.36079979], [88.85652924, 22.36095238], [88.85587311, 22.36114311], [88.85523987, 22.36133766], [88.85468292, 22.36156273], [88.8542099, 22.36177254], [88.85379791, 22.36198235], [88.85337067, 22.36219215], [88.85293579, 22.36240196], [88.85250854, 22.36264229], [88.85211182, 22.36287117], [88.85166931, 22.36318398], [88.85118103, 22.36359024], [88.85068512, 22.36392975], [88.85020447, 22.36415672], [88.84971619, 22.36436653], [88.84923553, 22.36454201], [88.84908295, 22.36450195], [88.84884644, 22.3644352], [88.84845734, 22.36427116], [88.8480072, 22.36417389], [88.8475647, 22.36407661], [88.84713745, 22.36394119], [88.84668732, 22.36383247], [88.84622955, 22.36362267], [88.84570312, 22.36339188], [88.84513855, 22.36317253], [88.84456635, 22.36296844], [88.84394836, 22.36282539], [88.84329987, 22.36269188], [88.8427124, 22.36248207], [88.84213257, 22.3622551], [88.84150696, 22.36206818], [88.84088898, 22.36190224], [88.84034729, 22.36169243], [88.83982086, 22.36150169], [88.83933258, 22.36134338], [88.83886719, 22.36115074], [88.83838654, 22.36100006], [88.83789062, 22.36082268], [88.83737946, 22.36063194], [88.83683777, 22.36048698], [88.83625031, 22.36026192], [88.83557892, 22.36008644], [88.83503723, 22.35988045], [88.83460999, 22.35963821], [88.83425903, 22.35945702], [88.83389282, 22.3593502], [88.83351135, 22.35928154], [88.83308411, 22.3592186], [88.83262634, 22.35920143], [88.83218384, 22.3592186], [88.83175659, 22.35926247], [88.83138275, 22.35929298], [88.83103943, 22.35933113], [88.83074188, 22.35940933], [88.83046722, 22.35951042], [88.83013153, 22.35962105], [88.82969666, 22.35970116], [88.82920074, 22.35983276], [88.82859039, 22.36009026], [88.8279953, 22.36034775], [88.82774353, 22.36040306], [88.82746887, 22.3604641], [88.82697296, 22.36045456], [88.82647705, 22.36035728], [88.82595825, 22.36037254], [88.82544708, 22.36053467], [88.82489777, 22.36073112], [88.82431793, 22.36091042], [88.82409668, 22.36088562], [88.8238678, 22.36086082], [88.82344818, 22.36078835], [88.82303619, 22.36069107], [88.82254791, 22.36078835], [88.82195282, 22.36089134], [88.82138062, 22.36111259], [88.82138062, 22.36139107], [88.8216629, 22.36166573], [88.8216629, 22.3619442], [88.82051849, 22.36309433], [88.81972504, 22.36388969], [88.81916809, 22.36388969], [88.8188858, 22.36361122], [88.8188858, 22.36333275], [88.81861115, 22.36305618], [88.81861115, 22.36166954], [88.81833649, 22.36139107], [88.81817627, 22.36112976], [88.81797791, 22.36074066], [88.81774902, 22.36035156], [88.81748962, 22.35995865], [88.81720734, 22.35956764], [88.81693268, 22.35918045], [88.81665039, 22.3588295], [88.81639862, 22.35853004], [88.81616974, 22.35824966], [88.81593323, 22.35798073], [88.8157959, 22.35775948], [88.81564331, 22.3574295], [88.81535339, 22.35680962], [88.81508636, 22.35604095], [88.81488037, 22.35535049], [88.81466675, 22.3547802], [88.81476593, 22.35414124], [88.81498718, 22.35349083], [88.81511688, 22.35289192], [88.81503296, 22.35239029], [88.81487274, 22.35197067], [88.81466675, 22.35161972], [88.81443024, 22.35132027], [88.81416321, 22.35104942], [88.8138504, 22.35079002], [88.81355286, 22.35050964], [88.81326294, 22.35026169], [88.81300354, 22.35002518], [88.81276703, 22.34980011], [88.81254578, 22.34956932], [88.81234741, 22.3492794], [88.81215668, 22.34894943], [88.81194305, 22.34863091], [88.81170654, 22.3483429], [88.81153107, 22.34803009], [88.8116684, 22.34777832], [88.81138611, 22.34750175], [88.81138611, 22.34555817], [88.81111145, 22.34527969], [88.81111145, 22.34472084], [88.81083679, 22.34444427], [88.81083679, 22.34361076], [88.81054688, 22.34333038], [88.8105545, 22.34277534], [88.81027985, 22.34250069], [88.81027985, 22.34193993], [88.80999756, 22.34166527], [88.80944061, 22.34167099], [88.80944061, 22.34136009], [88.80938721, 22.3410511], [88.80927277, 22.34070969], [88.80914307, 22.34033012], [88.80898285, 22.33992958], [88.80882263, 22.33948326], [88.80860138, 22.33906364], [88.80834198, 22.33863449], [88.80805206, 22.33820534], [88.80776215, 22.33778], [88.80750275, 22.33737183], [88.80728149, 22.3369751], [88.80710602, 22.33657074], [88.80693054, 22.33619308], [88.80674744, 22.33580017], [88.80665588, 22.33528137], [88.80654907, 22.33469009], [88.80628967, 22.33411026], [88.80596924, 22.33362007], [88.80568695, 22.33324051], [88.80555725, 22.33305931], [88.80528259, 22.33278084], [88.80528259, 22.33250046], [88.80500031, 22.33222008], [88.80500031, 22.33194351], [88.80472565, 22.33166885], [88.80444336, 22.33167076], [88.80406952, 22.33129692], [88.80388641, 22.33110809], [88.80388641, 22.33083344], [88.80379486, 22.33106995], [88.80358887, 22.33082008], [88.8033371, 22.33053017], [88.8030777, 22.3302002], [88.80284882, 22.32983017], [88.80271912, 22.32941055], [88.80261993, 22.32898331], [88.80275726, 22.3285408], [88.80291748, 22.32809258], [88.80302429, 22.32787323], [88.8031311, 22.32764626], [88.80339813, 22.32726288], [88.8036499, 22.32685471], [88.80391693, 22.32644653], [88.80408478, 22.32616615], [88.80417633, 22.32601357], [88.80445099, 22.32553864], [88.80473328, 22.32500076], [88.80528259, 22.32440948], [88.80683899, 22.32273674], [88.80921173, 22.31993294], [88.80950928, 22.31963158], [88.80974579, 22.31922913], [88.80999756, 22.31881142], [88.81019592, 22.31836128], [88.81025696, 22.31781387], [88.81032562, 22.31721306], [88.8104248, 22.31682968], [88.81048584, 22.31660461], [88.81047058, 22.31595039], [88.81033325, 22.31532288], [88.81027985, 22.31470108], [88.81021881, 22.31414986], [88.81001282, 22.31370926], [88.80977631, 22.31327057], [88.80953979, 22.31278992], [88.80924988, 22.31232834], [88.80887604, 22.31190109], [88.80853271, 22.31146431], [88.80818176, 22.3110733], [88.8079071, 22.31068039], [88.80768585, 22.31032944], [88.80745697, 22.31003952], [88.80725098, 22.30978012], [88.80710602, 22.30948067], [88.80697632, 22.30918121], [88.80683899, 22.30879974], [88.80664063, 22.30841446], [88.806427, 22.30798149], [88.80634308, 22.30745125], [88.80635071, 22.30685806], [88.80626678, 22.30630112], [88.80618286, 22.30578041], [88.8061142, 22.30532837], [88.80605316, 22.30491066], [88.80595398, 22.30451393], [88.80586243, 22.30410767], [88.80581665, 22.30367088], [88.80571747, 22.30323982], [88.80555725, 22.30281067], [88.80544281, 22.30233192], [88.80529785, 22.30182457], [88.80522156, 22.30130386], [88.80503845, 22.3008728], [88.80493164, 22.30042076], [88.80475616, 22.30003929], [88.80462646, 22.29964066], [88.80444336, 22.29927063], [88.80420685, 22.2989006], [88.80399323, 22.29846954], [88.80356598, 22.29813004], [88.8034668, 22.29758072], [88.8033371, 22.29705811], [88.80321503, 22.29654312], [88.80310822, 22.29602051], [88.80306244, 22.29545975], [88.80305481, 22.29488754], [88.80304718, 22.29430962], [88.80304718, 22.2937603], [88.80304718, 22.29326057], [88.80304718, 22.29283905], [88.80304718, 22.29247093], [88.80304718, 22.29212952], [88.80306244, 22.29180717], [88.8030777, 22.29150963], [88.8031311, 22.29124069], [88.80326843, 22.29092407], [88.80348206, 22.29063225], [88.80358887, 22.29022408], [88.80365753, 22.28977394], [88.80383301, 22.28935051], [88.80392456, 22.28887939], [88.80407715, 22.28837013], [88.80415344, 22.28775597], [88.80416107, 22.28707123], [88.8041687, 22.28634834], [88.80419922, 22.28564072], [88.80436707, 22.28499031], [88.80455017, 22.28436279], [88.80473328, 22.28380966], [88.80467224, 22.28324127], [88.8044281, 22.2827301], [88.80409241, 22.28228188], [88.80370331, 22.2818718], [88.80332184, 22.28141022], [88.80290985, 22.28097343], [88.80251312, 22.28051949], [88.80210114, 22.2800827], [88.80162811, 22.27973938], [88.8011322, 22.27946281], [88.80066681, 22.2791996], [88.80023956, 22.27900505], [88.79985046, 22.27880096], [88.79953766, 22.27846909], [88.79918671, 22.27821159], [88.79879761, 22.27797127], [88.79833221, 22.2779541], [88.79786682, 22.27795982], [88.79749298, 22.27782059], [88.79705811, 22.27779007], [88.79663086, 22.27783966], [88.79621124, 22.27798843], [88.79576874, 22.27804947], [88.79538727, 22.27801514], [88.79482269, 22.27779007], [88.79429626, 22.27757072], [88.79377747, 22.27738953], [88.79335785, 22.27707481], [88.79299927, 22.2766552], [88.79270935, 22.2761898], [88.79271698, 22.27569389], [88.79292297, 22.27524948], [88.79309845, 22.27485085], [88.79321289, 22.27449989], [88.79310608, 22.27415085], [88.79302216, 22.2737999], [88.79283905, 22.27345276], [88.7925415, 22.27310944], [88.79225922, 22.27269363], [88.79209137, 22.27219963], [88.79217529, 22.27170944], [88.79231262, 22.2712841], [88.79251099, 22.27096176], [88.79271698, 22.27062607], [88.7928772, 22.27017975], [88.7930069, 22.26968956], [88.79306793, 22.26917839], [88.79308319, 22.26868057], [88.79304504, 22.26821327], [88.79294586, 22.26777077], [88.79281616, 22.26732063], [88.79271698, 22.26685905], [88.79256439, 22.26645088], [88.79245758, 22.26601028], [88.79231262, 22.26559067], [88.79223633, 22.26515388], [88.79219818, 22.26472664], [88.79214478, 22.26431084], [88.79216003, 22.26381111], [88.7921524, 22.26328087], [88.79207611, 22.26271057], [88.79176331, 22.26222992], [88.79151917, 22.26171112], [88.79141235, 22.26122284], [88.79135132, 22.26081467], [88.79122925, 22.26050377], [88.79110718, 22.26022339], [88.79096222, 22.25996399], [88.79079437, 22.25970268], [88.7905426, 22.25948143], [88.79017639, 22.25937653], [88.7897644, 22.25936127], [88.78930664, 22.25945091], [88.78881836, 22.2595768], [88.78831482, 22.25961304], [88.78783417, 22.25943947], [88.78733063, 22.25922966], [88.78674316, 22.25909996], [88.78616333, 22.25887108], [88.78553009, 22.25858879], [88.78491974, 22.25826073], [88.78436279, 22.25786018], [88.7837677, 22.25751877], [88.78317261, 22.25722122], [88.7826004, 22.25694275], [88.7820816, 22.25666046], [88.78161621, 22.25640106], [88.78121185, 22.25616074], [88.78087616, 22.25587654], [88.78056335, 22.25559044], [88.78014374, 22.25535393], [88.77962494, 22.25516129], [88.77910614, 22.25491905], [88.77861023, 22.25464058], [88.77812195, 22.25438118], [88.77764893, 22.25414658], [88.7771759, 22.2538929], [88.77670288, 22.25365639], [88.77620697, 22.25344086], [88.77571106, 22.25323105], [88.775177, 22.25300026], [88.7746582, 22.25272179], [88.77415466, 22.25238037], [88.77362061, 22.25206947], [88.77307892, 22.25176048], [88.77255249, 22.25151634], [88.7720871, 22.25127983], [88.77176666, 22.25101089], [88.77155304, 22.25070953], [88.77136993, 22.25042152], [88.77119446, 22.25013733], [88.77102661, 22.24978065], [88.77082062, 22.24940109], [88.77059937, 22.24893951], [88.77040863, 22.24840546], [88.77025604, 22.24781036], [88.77011108, 22.24723816], [88.7700119, 22.24669456], [88.76985931, 22.2461853], [88.76966095, 22.24566078], [88.76941681, 22.24517822], [88.76921082, 22.24464035], [88.76904297, 22.24406815], [88.76889801, 22.2435112], [88.76875305, 22.24315071], [88.76859283, 22.24287033], [88.76837158, 22.24268913], [88.76802063, 22.24264908], [88.76767731, 22.24262047], [88.76729584, 22.24263191], [88.76699066, 22.24274826], [88.76669312, 22.24285316], [88.76629639, 22.24290466], [88.76592255, 22.24306107], [88.76544952, 22.24326515], [88.76490021, 22.24343109], [88.76432037, 22.24357986], [88.76371765, 22.24360275], [88.76317596, 22.24353981], [88.76272583, 22.24335098], [88.76230621, 22.24316025], [88.76194763, 22.24302101], [88.76167297, 22.2428112], [88.76139069, 22.24265099], [88.76111603, 22.24250031], [88.76085663, 22.24238014], [88.76061249, 22.24224091], [88.76034546, 22.24212074], [88.76011658, 22.24189758], [88.75990295, 22.24155998], [88.75968933, 22.24115944], [88.75943756, 22.24073029], [88.7591629, 22.24030495], [88.75885773, 22.23989105], [88.75850677, 22.23951912], [88.75810242, 22.23919106], [88.75772858, 22.23883629], [88.75736237, 22.23846817], [88.75701904, 22.23809052], [88.75665283, 22.23773956], [88.75631714, 22.23732948], [88.75595856, 22.23694992], [88.75557709, 22.2365799], [88.75522614, 22.23620033], [88.75482178, 22.23587608], [88.75435638, 22.23564911], [88.75386047, 22.23550034], [88.75341034, 22.23530579], [88.75296021, 22.23516083], [88.75254822, 22.23501587], [88.75211334, 22.23489189], [88.75166321, 22.23470116], [88.75123596, 22.23444939], [88.7508316, 22.23419952], [88.75039673, 22.2340107], [88.75002289, 22.23376083], [88.74965668, 22.23348808], [88.74922943, 22.23327065], [88.74882507, 22.23306274], [88.74842072, 22.23287582], [88.74800873, 22.23271942], [88.74752045, 22.23248291], [88.74704742, 22.23214912], [88.74662781, 22.23174095], [88.74620819, 22.23139763], [88.74582672, 22.23110962], [88.74555206, 22.23111153], [88.7436142, 22.22916603], [88.74360657, 22.22888947], [88.74333191, 22.2286129], [88.74333191, 22.22831917], [88.7436142, 22.22805595], [88.74360657, 22.22777939], [88.74333191, 22.22750282], [88.74333191, 22.22721863], [88.7436142, 22.22694397], [88.7436142, 22.2266674], [88.74500275, 22.22528076], [88.74500275, 22.22500038], [88.7463913, 22.22360992], [88.7463913, 22.22339249], [88.74647522, 22.22343445], [88.74682617, 22.22306633], [88.74717712, 22.22270966], [88.74751282, 22.22234344], [88.74784851, 22.22199059], [88.74821472, 22.22168159], [88.74861145, 22.22139168], [88.74903107, 22.22110176], [88.74936676, 22.22073174], [88.74958801, 22.22024345], [88.74938965, 22.21965218], [88.74897003, 22.2191143], [88.74867249, 22.21869087], [88.7485733, 22.21854973], [88.74823761, 22.21803093], [88.74798584, 22.21751976], [88.74776459, 22.21703529], [88.74752045, 22.21656036], [88.74732971, 22.21603584], [88.74720764, 22.21544075], [88.74706268, 22.21486282], [88.74681091, 22.21440506], [88.74659729, 22.21392059], [88.74636078, 22.21345711], [88.7461319, 22.21299171], [88.74595642, 22.21250725], [88.74581146, 22.21203041], [88.74568176, 22.21158981], [88.74558258, 22.21116066], [88.74555206, 22.21069908], [88.74551392, 22.21028519], [88.7454071, 22.20993805], [88.74532318, 22.20959091], [88.74534607, 22.20920944], [88.74546814, 22.20878983], [88.74547577, 22.20833969], [88.74536896, 22.20792389], [88.74531555, 22.20750618], [88.74536133, 22.20709991], [88.7454834, 22.20669556], [88.7456131, 22.20619965], [88.74573517, 22.20572853], [88.74588776, 22.20528984], [88.74610901, 22.20499992], [88.74611664, 22.20471191], [88.7463913, 22.20444489], [88.7463913, 22.20305824], [88.74623871, 22.20290756], [88.74610901, 22.20277786], [88.74610138, 22.20222282], [88.74583435, 22.20194435], [88.74583435, 22.20138931], [88.7452774, 22.20083427], [88.74416351, 22.20194435], [88.74415588, 22.20360947], [88.7444458, 22.20388794], [88.7444458, 22.20471954], [88.74472046, 22.20499992], [88.74472046, 22.2052784], [88.74416351, 22.20583344], [88.74415588, 22.20722008], [88.7444458, 22.20750809], [88.74416351, 22.20777512], [88.74415588, 22.20833015], [88.7436142, 22.2088871], [88.7436142, 22.20944405], [88.74388885, 22.20972061], [88.74388885, 22.21055794], [88.74360657, 22.21083069], [88.74360657, 22.21110916], [88.74333191, 22.21138954], [88.74333191, 22.21166611], [88.74305725, 22.21194458], [88.74277496, 22.21194458], [88.74250031, 22.21221924], [88.74250031, 22.21250153], [88.74222565, 22.21277809], [88.74223328, 22.2136116], [88.7416687, 22.21417046], [88.74138641, 22.21417046], [88.74111176, 22.21445274], [88.7408371, 22.21444511], [88.74055481, 22.21472168], [88.73999786, 22.21472168], [88.73944092, 22.21416664], [88.73916626, 22.21417046], [88.7388916, 22.21389008], [88.7388916, 22.21166992], [88.73860931, 22.21138954], [88.73860931, 22.21056938], [88.7388916, 22.21027946], [88.7388916, 22.21000099], [88.73916626, 22.21000099], [88.73972321, 22.20944023], [88.73999786, 22.20944405], [88.74111176, 22.20833397], [88.74111176, 22.20694351], [88.7408371, 22.20666695], [88.7408371, 22.20639038], [88.74111176, 22.20611], [88.74111176, 22.20583344], [88.74138641, 22.20555305], [88.74138641, 22.2052803], [88.74111176, 22.20499992], [88.74111176, 22.20471954], [88.7408371, 22.20444489], [88.7408371, 22.20416641], [88.74028778, 22.20360947], [88.74028015, 22.20305634], [88.74250031, 22.20083237], [88.74250031, 22.2005558], [88.74278259, 22.20027924], [88.74278259, 22.20000076], [88.74250031, 22.19972229], [88.74194336, 22.19972229], [88.74194336, 22.19944382], [88.74138641, 22.19889069], [88.74138641, 22.1986084], [88.74111176, 22.1986084], [88.74057007, 22.19860077], [88.73989105, 22.19855118], [88.73922729, 22.19835091], [88.73860168, 22.19803047], [88.73797607, 22.1977005], [88.73738098, 22.19740105], [88.73666382, 22.1971283], [88.73609161, 22.19683838], [88.7361145, 22.19694519], [88.73583221, 22.19695091], [88.73555756, 22.19667244], [88.73527527, 22.19638634], [88.73500061, 22.19639015], [88.73486328, 22.19625092], [88.73472595, 22.19610977], [88.73416901, 22.19611168], [88.73361206, 22.19555473], [88.73194122, 22.19555473], [88.73161316, 22.19559288], [88.73118591, 22.19573021], [88.7307663, 22.19582939], [88.73034668, 22.19593048], [88.72992706, 22.1960907], [88.72947693, 22.1962204], [88.72902679, 22.19635963], [88.72852325, 22.19649124], [88.72797394, 22.19662666], [88.72735596, 22.19672012], [88.72675323, 22.19692993], [88.72609711, 22.1971302], [88.72544098, 22.19733047], [88.72473907, 22.19752502], [88.72408295, 22.19774055], [88.72341919, 22.19795036], [88.72277069, 22.19811058], [88.72219086, 22.19833946], [88.7216568, 22.19854927], [88.72112274, 22.19866943], [88.72064209, 22.19886017], [88.7201767, 22.19905281], [88.71974182, 22.19927788], [88.71930695, 22.19954109], [88.71882629, 22.1997509], [88.71835327, 22.19997978], [88.71787262, 22.20016289], [88.71733856, 22.20027733], [88.71684265, 22.20040321], [88.71640015, 22.2005825], [88.71598816, 22.20081329], [88.71556854, 22.20104027], [88.71511841, 22.20125008], [88.71469116, 22.20155525], [88.71422577, 22.20194244], [88.71369934, 22.20238686], [88.71311188, 22.20282936], [88.71253204, 22.20329094], [88.71198273, 22.20371056], [88.7114563, 22.20409966], [88.7109375, 22.20438004], [88.71051788, 22.20463943], [88.71012878, 22.20485115], [88.70973206, 22.20502663], [88.70938873, 22.20526123], [88.70905304, 22.2055397], [88.7086792, 22.2058506], [88.70832825, 22.20622253], [88.70795441, 22.20659828], [88.7075119, 22.20693016], [88.70701599, 22.20722008], [88.70654297, 22.20745087], [88.70605469, 22.20758629], [88.70565796, 22.20778465], [88.70532227, 22.20797348], [88.70498657, 22.2080307], [88.70466614, 22.20809555], [88.70429993, 22.20826149], [88.70394135, 22.2085495], [88.70355988, 22.20885277], [88.70313263, 22.20903015], [88.70274353, 22.20916939], [88.70236206, 22.2093029], [88.7019577, 22.20944214], [88.70153809, 22.20956993], [88.70110321, 22.20969772], [88.70064545, 22.20977211], [88.70022583, 22.20994949], [88.69975281, 22.2100296], [88.69927979, 22.2101326], [88.6987381, 22.21010017], [88.69821167, 22.21014023], [88.69772339, 22.21026611], [88.69724274, 22.21038055], [88.69673157, 22.21051598], [88.69615173, 22.21055031], [88.69551849, 22.21056938], [88.69503021, 22.21055984], [88.69487, 22.21055412], [88.69421387, 22.21050835], [88.69361877, 22.21033096], [88.69301605, 22.21023178], [88.69252014, 22.21004295], [88.69204712, 22.20994949], [88.69161224, 22.20984077], [88.69114685, 22.20976067], [88.69064331, 22.20972061], [88.69011688, 22.20966911], [88.68962097, 22.20955276], [88.68906403, 22.20946884], [88.68843842, 22.20944977], [88.68781281, 22.20944023], [88.6871109, 22.20944023], [88.68638611, 22.20944977], [88.68569183, 22.20950127], [88.68500519, 22.20966721], [88.6843338, 22.2097168], [88.68369293, 22.20969009], [88.68313599, 22.20954895], [88.68267059, 22.20940971], [88.68229675, 22.20922089], [88.68193817, 22.20915985], [88.68157196, 22.20915985], [88.68121338, 22.209198], [88.68089294, 22.20931816], [88.68057251, 22.20952988], [88.68028259, 22.20984077], [88.67998505, 22.21022606], [88.67961884, 22.2106514], [88.67917633, 22.21107292], [88.67871857, 22.21149063], [88.67815399, 22.21174049], [88.67759705, 22.21196365], [88.67707062, 22.21217346], [88.67650604, 22.21224213], [88.67597961, 22.21237183], [88.67550659, 22.21256828], [88.67505646, 22.21280289], [88.67460632, 22.21305847], [88.6741333, 22.2133503], [88.67365265, 22.21372032], [88.67320251, 22.21411324], [88.67274475, 22.21445274], [88.67250061, 22.21472168], [88.67222595, 22.21472168], [88.67111206, 22.21583366], [88.67082977, 22.21583366], [88.67074585, 22.21584892], [88.67015076, 22.21596336], [88.66963196, 22.21614456], [88.66918945, 22.21636391], [88.66873932, 22.21652031], [88.66829681, 22.21669006], [88.66786957, 22.21689034], [88.66736603, 22.2170105], [88.66684723, 22.21718979], [88.66625977, 22.21729088], [88.66562653, 22.2174511], [88.66494751, 22.2175293], [88.66426849, 22.21763992], [88.66353607, 22.21773911], [88.66279602, 22.21773911], [88.66205597, 22.21772957], [88.66131592, 22.21771049], [88.66059875, 22.21759987], [88.65989685, 22.21749115], [88.65923309, 22.21737099], [88.65862274, 22.21719933], [88.65808105, 22.21697807], [88.65756989, 22.21679688], [88.65709686, 22.2165699], [88.65665436, 22.21625137], [88.65625, 22.21575165], [88.65572357, 22.21520233], [88.65529633, 22.21462822], [88.65506744, 22.21398926], [88.654953, 22.21334267], [88.65468597, 22.21277046], [88.65432739, 22.21228981], [88.65388489, 22.21194077], [88.65342712, 22.21165085], [88.65297699, 22.21138954], [88.65249634, 22.21121025], [88.65198517, 22.21133804], [88.65142059, 22.2113781], [88.65087891, 22.21139526], [88.65040588, 22.21145058], [88.65000153, 22.21162987], [88.64958191, 22.21166611], [88.64916229, 22.21169472], [88.64873505, 22.21181107], [88.64828491, 22.2119236], [88.647789, 22.21194267], [88.64722443, 22.21192932], [88.64659882, 22.21191978], [88.64595795, 22.21206093], [88.64525604, 22.21216965], [88.64453125, 22.21221542], [88.64377594, 22.21224976], [88.64305878, 22.21237564], [88.64237213, 22.21250153], [88.64174652, 22.21263123], [88.64113617, 22.21276093], [88.64055634, 22.21281815], [88.64002991, 22.21299171], [88.63949585, 22.21309853], [88.63905334, 22.21331024], [88.63856506, 22.21356773], [88.63806152, 22.21380043], [88.63757324, 22.21410942], [88.63703918, 22.21445274], [88.63651276, 22.21482086], [88.63609314, 22.21529007], [88.63568878, 22.21570587], [88.63535309, 22.21607971], [88.63504028, 22.21640015], [88.63488007, 22.2168808], [88.63470459, 22.21746635], [88.634552, 22.21813965], [88.6346817, 22.21886635], [88.63479614, 22.2195797], [88.63503265, 22.22018051], [88.63526917, 22.22068024], [88.63549042, 22.22120094], [88.63564301, 22.22173119], [88.63584137, 22.22225189], [88.63606262, 22.22273636], [88.63626862, 22.22320366], [88.63645935, 22.22361755], [88.6366806, 22.22403908], [88.63691711, 22.22442055], [88.63717651, 22.22479057], [88.63739777, 22.22514915], [88.63765717, 22.22544289], [88.63794708, 22.22571945], [88.63829803, 22.22594833], [88.63861084, 22.22622108], [88.6388855, 22.22639084], [88.63944244, 22.22694397], [88.6397171, 22.22693825], [88.64167023, 22.22888947], [88.64193726, 22.22888947], [88.64221954, 22.22916985], [88.64250183, 22.22916603], [88.64277649, 22.2294445], [88.64333344, 22.2294445], [88.64360809, 22.22972107], [88.64389038, 22.22972107], [88.64416504, 22.22999954], [88.64444733, 22.22999954], [88.64472198, 22.23027992], [88.64499664, 22.23027992], [88.64527893, 22.2305603], [88.64555359, 22.23055649], [88.64583588, 22.23083305], [88.64611053, 22.23083305], [88.64638519, 22.23111153], [88.64698792, 22.2311573], [88.6472168, 22.23139], [88.64749908, 22.23139], [88.64805603, 22.23195076], [88.64861298, 22.23194313], [88.64888763, 22.2322216], [88.64916992, 22.2322197], [88.64943695, 22.23250008], [88.64971161, 22.23250008], [88.65027618, 22.23306084], [88.65055847, 22.23306084], [88.65139008, 22.23389053], [88.6516571, 22.23389053], [88.65222168, 22.23444939], [88.65249634, 22.23444939], [88.6533432, 22.23528099], [88.65361023, 22.23528099], [88.65444183, 22.23611069], [88.65471649, 22.23611069], [88.65777588, 22.23916626], [88.65777588, 22.23944473], [88.6580658, 22.23936081], [88.65809631, 22.23966026], [88.65818024, 22.23991966], [88.65833282, 22.24014091], [88.65847778, 22.24041939], [88.65866089, 22.24071121], [88.65887451, 22.24098015], [88.65904999, 22.24126244], [88.65918732, 22.24155998], [88.65936279, 22.24188995], [88.65947723, 22.24225807], [88.65970612, 22.24265099], [88.65989685, 22.24309921], [88.66002655, 22.2435894], [88.66024017, 22.24399757], [88.66036987, 22.2444191], [88.66047668, 22.24482918], [88.66054535, 22.24522972], [88.66057587, 22.24562073], [88.66065979, 22.24602699], [88.66066742, 22.24654961], [88.66065979, 22.24703979], [88.6605835, 22.24742889], [88.66057587, 22.24780083], [88.66062927, 22.24821854], [88.66062164, 22.2487812], [88.66073608, 22.24934006], [88.66083527, 22.24983788], [88.66091919, 22.25032997], [88.66108704, 22.25078964], [88.66118622, 22.25125122], [88.66137695, 22.25163078], [88.66155243, 22.25199509], [88.66168976, 22.2524395], [88.66187286, 22.2528801], [88.66201019, 22.25336075], [88.66223145, 22.2538414], [88.66249847, 22.25431442], [88.66274261, 22.25479126], [88.66285706, 22.25531006], [88.66306305, 22.25579071], [88.66324615, 22.25624275], [88.66340637, 22.25673294], [88.66358185, 22.25720787], [88.66371918, 22.25769424], [88.66394043, 22.25811386], [88.66417694, 22.25852966], [88.66445923, 22.25892067], [88.66464233, 22.25933838], [88.66477966, 22.25974083], [88.66496277, 22.26008987], [88.66503143, 22.2604866], [88.66516113, 22.26085091], [88.6652832, 22.26124001], [88.66539764, 22.26163292], [88.66557312, 22.26200104], [88.665802, 22.26235962], [88.66597748, 22.26280022], [88.66614532, 22.26328087], [88.66638184, 22.26370239], [88.66661072, 22.26409721], [88.66680145, 22.26443481], [88.66696167, 22.2647438], [88.66712189, 22.26503372], [88.66722107, 22.26534843], [88.66726685, 22.26568985], [88.66731262, 22.26596832], [88.66735077, 22.26623917], [88.66751862, 22.2664299], [88.66752625, 22.26671028], [88.66763306, 22.26701927], [88.66797638, 22.26729965], [88.6682663, 22.26769066], [88.66847229, 22.26820946], [88.66889191, 22.26861191], [88.66889191, 22.26889038], [88.66916656, 22.26916695], [88.66916656, 22.2694397], [88.66971588, 22.27000046], [88.66971588, 22.27028084], [88.66999817, 22.2705555], [88.66999817, 22.27083015], [88.67055511, 22.27138901], [88.67055511, 22.27194595], [88.67082214, 22.27222061], [88.67082214, 22.27250099], [88.67138672, 22.27305412], [88.67138672, 22.27333069], [88.67166901, 22.27362061], [88.67166901, 22.27388954], [88.67194366, 22.27388954], [88.67230988, 22.27425575], [88.67250061, 22.27444458], [88.67277527, 22.27444458], [88.67444611, 22.2761097], [88.67444611, 22.27638817], [88.67437744, 22.27645302], [88.67469788, 22.27700043], [88.67494202, 22.27765083], [88.67533875, 22.27821159], [88.6757431, 22.27867126], [88.67616272, 22.27897263], [88.6764679, 22.27939987], [88.67675018, 22.27991104], [88.67719269, 22.2803154], [88.6775589, 22.28072357], [88.67786407, 22.28105354], [88.67807007, 22.28133965], [88.67832947, 22.28162956], [88.67867279, 22.28201294], [88.67903137, 22.28252029], [88.67944336, 22.28308105], [88.6799469, 22.28360176], [88.68052673, 22.28406906], [88.6809845, 22.28448296], [88.68132782, 22.28489113], [88.68158722, 22.28540993], [88.6818161, 22.28601837], [88.68196869, 22.28664207], [88.68218231, 22.28714561], [88.68238831, 22.28765106], [88.68260956, 22.2881279], [88.68278503, 22.28853226], [88.68296814, 22.28883934], [88.6831131, 22.28917122], [88.68325043, 22.28948975], [88.68333435, 22.28990746], [88.68357849, 22.29032135], [88.68376923, 22.2907505], [88.68385315, 22.29118919], [88.68387604, 22.2916317], [88.68398285, 22.29203033], [88.68415833, 22.2923584], [88.68434906, 22.29268456], [88.68453217, 22.29305458], [88.68467712, 22.29343987], [88.68476105, 22.29387093], [88.68492126, 22.29427528], [88.68498993, 22.29470825], [88.68499756, 22.29515076], [88.68496704, 22.29556274], [88.68488312, 22.29597282], [88.68486786, 22.29649734], [88.68486786, 22.29714012], [88.68493652, 22.29776955], [88.68482971, 22.29838943], [88.68469238, 22.29906082], [88.68445587, 22.29971123], [88.68417358, 22.30033684], [88.68389893, 22.3009758], [88.68369293, 22.30161476], [88.68357086, 22.30220985], [88.68335724, 22.3026619], [88.68318176, 22.30306625], [88.68302155, 22.30347061], [88.68286133, 22.30387115], [88.68292999, 22.30436707], [88.6827774, 22.30491066], [88.68255615, 22.30548859], [88.68226624, 22.30604935], [88.68196106, 22.30651093], [88.68170929, 22.30697441], [88.68157959, 22.30752945], [88.68138123, 22.30805016], [88.68115234, 22.30854988], [88.68103027, 22.30911064], [88.68087006, 22.30964088], [88.68083191, 22.31013107], [88.6807785, 22.31055069], [88.68061066, 22.31081963], [88.68052673, 22.31105042], [88.68045044, 22.31126022], [88.68051147, 22.31151009], [88.68089294, 22.31183815], [88.68109894, 22.31213188], [88.68115234, 22.3123951], [88.68125916, 22.31265259], [88.68135834, 22.31294823], [88.68133545, 22.31333923], [88.68110657, 22.31373978], [88.68084717, 22.31418991], [88.68064117, 22.3146801], [88.68055725, 22.31516647], [88.68048096, 22.31562424], [88.680336, 22.31600189], [88.68016815, 22.31632805], [88.68016052, 22.31678009], [88.68022156, 22.31724739], [88.68016815, 22.31765175], [88.68000031, 22.31805611], [88.67973328, 22.31833076], [88.67973328, 22.31890106], [88.67944336, 22.31916618], [88.67944336, 22.31971931], [88.6791687, 22.3200016], [88.6791687, 22.32278061], [88.67888641, 22.3230629], [88.67972565, 22.32388878], [88.67972565, 22.32472229], [88.68000793, 22.32500076], [88.68000793, 22.32528114], [88.68028259, 22.32555962], [88.68083191, 22.3255558], [88.6811142, 22.32583427], [88.68165588, 22.32583046], [88.6819458, 22.32611084], [88.68499756, 22.32611084], [88.68517303, 22.32599068], [88.68560791, 22.32587624], [88.6860733, 22.32578087], [88.68650818, 22.32566643], [88.68696594, 22.32561111], [88.68743896, 22.32559586], [88.68791199, 22.3256321], [88.6884079, 22.32573318], [88.68888855, 22.32583427], [88.68916321, 22.3255558], [88.68972015, 22.3255558], [88.68986511, 22.32569695], [88.69000244, 22.32583427], [88.6902771, 22.32583046], [88.69055176, 22.32611084], [88.69055176, 22.32666588], [88.6902771, 22.32694435], [88.6883316, 22.32694435], [88.68805695, 22.32722282], [88.68694305, 22.32722282], [88.68638611, 22.32777786], [88.68583679, 22.32777023], [88.68554688, 22.32806015], [88.68527985, 22.32805443], [88.68499756, 22.3283329], [88.6847229, 22.3283329], [88.68444824, 22.32861137], [88.6838913, 22.32860947], [88.68360901, 22.32888985], [88.68165588, 22.32888985], [88.68138885, 22.32917023], [88.68083191, 22.32917023], [88.68055725, 22.32888985], [88.68028259, 22.32888985], [88.67977905, 22.32839012], [88.67944336, 22.32805443], [88.6791687, 22.32806015], [88.67888641, 22.32777023], [88.67861176, 22.32777023], [88.6783371, 22.32806015], [88.67749786, 22.32806015], [88.67666626, 22.32722092], [88.6763916, 22.32722282], [88.67610931, 22.32694435], [88.67583466, 22.32694435], [88.67555237, 22.32666588], [88.67500305, 22.32666969], [88.67415619, 22.32583046], [88.67388916, 22.32583427], [88.6736145, 22.3255558], [88.67333221, 22.3255558], [88.67305756, 22.32583427], [88.6727829, 22.32583046], [88.67222595, 22.32639122], [88.67193604, 22.32639122], [88.67154694, 22.32599449], [88.67138672, 22.32583427], [88.67111206, 22.32583046], [88.67056274, 22.32639122], [88.67055511, 22.32666588], [88.67028046, 22.32694435], [88.67028046, 22.3283329], [88.66999817, 22.32860947], [88.66999817, 22.32916641], [88.66972351, 22.32944489], [88.66971588, 22.32971954], [88.66944122, 22.32999992], [88.66944122, 22.3302803], [88.66889191, 22.33083344], [88.66889191, 22.33221817], [88.66860962, 22.33250046], [88.66860962, 22.33416748], [88.66832733, 22.33444023], [88.66832733, 22.3350029], [88.66860962, 22.33527946], [88.66860962, 22.33555603], [88.66832733, 22.3358326], [88.66832733, 22.33611107], [88.66777802, 22.33666611], [88.66777802, 22.33694458], [88.66750336, 22.33722115], [88.66750336, 22.33749962], [88.66722107, 22.33777809], [88.66722107, 22.33805466], [88.66694641, 22.33833122], [88.66677094, 22.33871078], [88.66662598, 22.33884811], [88.66648102, 22.33910751], [88.66633606, 22.33917427], [88.66612244, 22.33904076], [88.66597748, 22.33876991], [88.6656189, 22.33823776], [88.66583252, 22.33749962], [88.66665649, 22.33666992], [88.66665649, 22.33638954], [88.66694641, 22.33611107], [88.66694641, 22.3358326], [88.66722107, 22.33555603], [88.66722107, 22.3350029], [88.66694641, 22.33472252], [88.66722107, 22.33444405], [88.66722107, 22.33389091], [88.66694641, 22.33360863], [88.66694641, 22.33305931], [88.66722107, 22.33278084], [88.66722107, 22.33167076], [88.66777802, 22.33110809], [88.66777802, 22.33083344], [88.66750336, 22.33056068], [88.66781616, 22.33014107], [88.66806793, 22.32974815], [88.66829681, 22.32936096], [88.66846466, 22.32897568], [88.66858673, 22.32860947], [88.66864777, 22.32818222], [88.66873932, 22.32770538], [88.66889954, 22.32723808], [88.66909027, 22.3267498], [88.66944122, 22.32583427], [88.66972351, 22.3255558], [88.66971588, 22.32528114], [88.67056274, 22.32444], [88.67082977, 22.32444382], [88.67250061, 22.3227787], [88.67250061, 22.32250023], [88.67333221, 22.32167053], [88.67333221, 22.32139015], [88.67366028, 22.32118034], [88.67395782, 22.32095909], [88.674263, 22.32069969], [88.67453766, 22.32040977], [88.67471313, 22.32006645], [88.67485809, 22.31970978], [88.67502594, 22.31933975], [88.67523956, 22.31895065], [88.67539978, 22.31850052], [88.67557526, 22.31805038], [88.67581177, 22.31762314], [88.67597961, 22.3171463], [88.67583466, 22.31646729], [88.67562103, 22.31583023], [88.67559052, 22.3152771], [88.67569733, 22.31479073], [88.67579651, 22.31431007], [88.67584229, 22.3138485], [88.67591858, 22.31348038], [88.67611694, 22.3132], [88.67626953, 22.31287766], [88.67636871, 22.31246948], [88.67658997, 22.31199265], [88.67699432, 22.31139946], [88.67711639, 22.31071091], [88.67697906, 22.31007957], [88.67690277, 22.30950165], [88.67678833, 22.30899811], [88.67682648, 22.30860138], [88.67695618, 22.30828094], [88.67711639, 22.30799294], [88.67720032, 22.30764961], [88.67723846, 22.30724335], [88.67735291, 22.30681419], [88.67753601, 22.30634308], [88.6776886, 22.30579948], [88.67782593, 22.30527115], [88.6780014, 22.30482292], [88.67803955, 22.30442047], [88.67801666, 22.30405998], [88.67798615, 22.30371284], [88.67803192, 22.30337334], [88.6780777, 22.30297852], [88.67816925, 22.30257034], [88.67829895, 22.30214119], [88.67832947, 22.30166435], [88.67832947, 22.30138969], [88.67832947, 22.30117035], [88.6783371, 22.30027962], [88.67861176, 22.30000114], [88.67861176, 22.29916954], [88.6783371, 22.29889107], [88.6783371, 22.29722023], [88.67805481, 22.29694366], [88.67805481, 22.2966671], [88.6783371, 22.29639053], [88.6783371, 22.29500008], [88.6791687, 22.29417038], [88.6791687, 22.29389191], [88.6783371, 22.2930603], [88.6783371, 22.29249763], [88.67804718, 22.29221916], [88.67805481, 22.2919445], [88.67778015, 22.29166794], [88.67778015, 22.29138756], [88.67749786, 22.29110909], [88.67749786, 22.29083061], [88.67725372, 22.2905674], [88.67707825, 22.29014015], [88.67688751, 22.28951073], [88.6765976, 22.28886032], [88.67620087, 22.28831291], [88.67582703, 22.287817], [88.67543793, 22.28739166], [88.67508698, 22.2869606], [88.67476654, 22.28655052], [88.67451477, 22.28614044], [88.67427063, 22.28580093], [88.67408752, 22.28547287], [88.67391205, 22.28515053], [88.67372131, 22.28482819], [88.67341614, 22.28455925], [88.67314911, 22.28415108], [88.6728363, 22.28367043], [88.67247772, 22.28321075], [88.67207336, 22.28272057], [88.67170715, 22.28215027], [88.67140198, 22.28156853], [88.67112732, 22.28103065], [88.6709137, 22.28059006], [88.67063904, 22.28027916], [88.67032623, 22.28001022], [88.66995239, 22.2798233], [88.66954041, 22.27963066], [88.66921234, 22.27931976], [88.66895294, 22.27896309], [88.66869354, 22.27861214], [88.66843414, 22.27825356], [88.66822815, 22.2778244], [88.66798401, 22.27742386], [88.66775513, 22.2770462], [88.66750336, 22.27672005], [88.6672287, 22.27642059], [88.66697693, 22.27610016], [88.66669464, 22.27577019], [88.66639709, 22.27539063], [88.66607666, 22.27498245], [88.66570282, 22.27459335], [88.66532135, 22.27419281], [88.66499329, 22.27374077], [88.66467285, 22.2732811], [88.66439819, 22.27276993], [88.66413879, 22.27224731], [88.66387177, 22.27173042], [88.66359711, 22.2712326], [88.66335297, 22.27075958], [88.66310883, 22.27029419], [88.66290283, 22.26983833], [88.66265869, 22.26941299], [88.6624527, 22.26894188], [88.66220856, 22.26848221], [88.6619339, 22.26805687], [88.66160583, 22.26768112], [88.66133881, 22.26732826], [88.66107941, 22.26696014], [88.66082764, 22.26658821], [88.66057587, 22.26622009], [88.66042328, 22.26585388], [88.66030121, 22.26550865], [88.66023254, 22.26517105], [88.6601181, 22.26485825], [88.65999603, 22.26389122], [88.65947723, 22.26296997], [88.6581192, 22.26055908], [88.65783691, 22.25976181], [88.65776062, 22.25922012], [88.65783691, 22.25875092], [88.65805054, 22.25842094], [88.65820313, 22.25801086], [88.65840912, 22.25747681], [88.65847778, 22.25640106], [88.65847778, 22.25486374], [88.65833282, 22.25439453], [88.6581192, 22.25385857], [88.65783691, 22.25345993], [88.65769196, 22.25245285], [88.657547, 22.25151443], [88.65725708, 22.25097847], [88.65711212, 22.25064087], [88.65675354, 22.25010681], [88.65638733, 22.24970055], [88.65582275, 22.24916649], [88.65453339, 22.24810028], [88.65380859, 22.24641991], [88.65179443, 22.24447823], [88.65141296, 22.24395561], [88.65055847, 22.24277687], [88.65055847, 22.24250031], [88.65000153, 22.2419529], [88.65000153, 22.24167061], [88.64694214, 22.23861122], [88.64666748, 22.23861122], [88.64527893, 22.23722076], [88.64499664, 22.23749733], [88.64477539, 22.23700142], [88.64442444, 22.23650742], [88.64406586, 22.23608017], [88.64376831, 22.23562813], [88.64338684, 22.23521805], [88.64305878, 22.2347908], [88.64274597, 22.23437119], [88.64238739, 22.23406792], [88.64199066, 22.23384094], [88.64162445, 22.23360252], [88.64128876, 22.23333931], [88.64093781, 22.23307991], [88.64057922, 22.23285103], [88.64026642, 22.23257065], [88.63996887, 22.23229027], [88.63965607, 22.23200989], [88.63937378, 22.23170662], [88.63925171, 22.23159981], [88.63902283, 22.23140335], [88.63859558, 22.23113632], [88.63806152, 22.23097992], [88.63755035, 22.23080826], [88.63710022, 22.2305603], [88.63665009, 22.23031807], [88.63619232, 22.23007965], [88.63577271, 22.22977066], [88.63534546, 22.22948837], [88.63498688, 22.22916031], [88.63466644, 22.22883224], [88.63433838, 22.22852325], [88.63396454, 22.22825813], [88.63363647, 22.22792053], [88.63337708, 22.22752953], [88.63323212, 22.22704124], [88.63302612, 22.22661972], [88.63278198, 22.22623825], [88.6325531, 22.2258606], [88.63230896, 22.22547531], [88.63212585, 22.2250309], [88.63191986, 22.22461128], [88.63168335, 22.22421074], [88.63145447, 22.22380447], [88.63124847, 22.2233696], [88.63104248, 22.22293091], [88.6309433, 22.22249794], [88.63091278, 22.22204971], [88.63098145, 22.22160912], [88.631073, 22.22116089], [88.63109589, 22.22070122], [88.63111115, 22.22024918], [88.63109589, 22.21981049], [88.63108826, 22.21939087], [88.63110352, 22.21900368], [88.6311264, 22.21862411], [88.63121033, 22.21825218], [88.63134766, 22.21787643], [88.6313858, 22.21746063], [88.6313858, 22.2170105], [88.6313858, 22.21655464], [88.63140869, 22.21607208], [88.63150787, 22.21557045], [88.63166809, 22.21504974], [88.63188171, 22.21451187], [88.63212585, 22.21399117], [88.63227844, 22.21376228], [88.63246155, 22.21349907], [88.63279724, 22.21297073], [88.63318634, 22.21248055], [88.63357544, 22.21201515], [88.6340332, 22.21167564], [88.63448334, 22.21138954], [88.63491058, 22.21109962], [88.63530731, 22.21080971], [88.63574982, 22.21054077], [88.63617706, 22.21023178], [88.6366806, 22.20997047], [88.637146, 22.20965004], [88.63755798, 22.20928764], [88.63794708, 22.20895004], [88.63832092, 22.20868874], [88.63865662, 22.20846939], [88.63900757, 22.20829964], [88.63934326, 22.20812035], [88.63973999, 22.2080307], [88.64012909, 22.20788956], [88.64048004, 22.20766068], [88.64086151, 22.20755386], [88.64124298, 22.20747948], [88.64161682, 22.20738029], [88.64200592, 22.20734978], [88.64237213, 22.20734978], [88.64272308, 22.20738029], [88.6431427, 22.20744705], [88.64359283, 22.20749283], [88.64404297, 22.20749283], [88.64444733, 22.2074585], [88.64480591, 22.20742035], [88.64520264, 22.20737267], [88.64565277, 22.20740128], [88.64608765, 22.20747948], [88.64655304, 22.20750809], [88.6470871, 22.20755005], [88.6476593, 22.20772743], [88.64827728, 22.20773315], [88.64883423, 22.20754051], [88.6493454, 22.20744133], [88.64974213, 22.20726585], [88.65011597, 22.20722008], [88.65049744, 22.20722198], [88.65088654, 22.2072506], [88.65130615, 22.20740128], [88.65174866, 22.20747757], [88.65215302, 22.20754051], [88.65249634, 22.20773125], [88.65289307, 22.20776939], [88.65328979, 22.20776558], [88.65370178, 22.20779037], [88.65413666, 22.20788956], [88.65461731, 22.20801163], [88.65518188, 22.20807838], [88.65576935, 22.20824814], [88.65638733, 22.2083149], [88.65698242, 22.20825958], [88.65750885, 22.20810127], [88.6579895, 22.20806122], [88.65841675, 22.20804977], [88.65881348, 22.20805359], [88.65920258, 22.20807076], [88.65960693, 22.20814514], [88.66005707, 22.20826149], [88.66056061, 22.20824051], [88.66108704, 22.20845985], [88.66176605, 22.20850945], [88.6624527, 22.20836067], [88.66311646, 22.20828056], [88.66378021, 22.20804977], [88.6644516, 22.20783043], [88.66513062, 22.2078228], [88.665802, 22.20796967], [88.66641235, 22.20798111], [88.66702271, 22.20779037], [88.6676178, 22.20763969], [88.6681366, 22.20748138], [88.66860199, 22.20726776], [88.66903687, 22.20701981], [88.669487, 22.20677185], [88.66995239, 22.20655441], [88.67040253, 22.20627403], [88.67089844, 22.20598793], [88.6714859, 22.20574188], [88.67210388, 22.2054348], [88.67259216, 22.20505905], [88.67254639, 22.20467949], [88.67253876, 22.20420456], [88.67262268, 22.20365143], [88.67267609, 22.20303535], [88.67267609, 22.20240021], [88.67253876, 22.20179939], [88.67246246, 22.20119858], [88.67230988, 22.20063019], [88.67218018, 22.20013428], [88.67198181, 22.19964218], [88.67180634, 22.19911957], [88.67165375, 22.19857788], [88.67150116, 22.19803047], [88.6713562, 22.19749641], [88.67115784, 22.19702911], [88.67097473, 22.19658661], [88.67080688, 22.19614029], [88.67061615, 22.19572258], [88.67044067, 22.19529915], [88.67024231, 22.19488907], [88.66999054, 22.19452095], [88.66973114, 22.19409943], [88.66950226, 22.19363976], [88.66938782, 22.19304085], [88.66915894, 22.19254875], [88.66886902, 22.19210815], [88.66861725, 22.19177437], [88.66838837, 22.19142532], [88.66822815, 22.19101906], [88.66803741, 22.19060135], [88.66778564, 22.1901989], [88.6675415, 22.18975067], [88.66731262, 22.18926048], [88.66707611, 22.18874168], [88.66682434, 22.18823814], [88.66647339, 22.18786049], [88.6661377, 22.18753052], [88.66584778, 22.1872406], [88.66564178, 22.18695259], [88.66545868, 22.1866951], [88.66529083, 22.18643951], [88.66513062, 22.1861496], [88.66493225, 22.18581963], [88.66467285, 22.18540955], [88.66426849, 22.18498039], [88.6638031, 22.18451118], [88.66326904, 22.18408012], [88.66278839, 22.18363762], [88.66233826, 22.1832695], [88.66201019, 22.18287277], [88.66166687, 22.18262672], [88.66136932, 22.18240166], [88.66110229, 22.18217278], [88.66083527, 22.18193436], [88.66055298, 22.18167114], [88.66018677, 22.18138123], [88.65981293, 22.18106079], [88.65944672, 22.18066978], [88.65911102, 22.18027687], [88.6587677, 22.17990685], [88.65836334, 22.1796608], [88.65795898, 22.17942429], [88.65757751, 22.17914009], [88.6572113, 22.17881012], [88.65679932, 22.17847061], [88.65637207, 22.17811966], [88.65592957, 22.17779541], [88.65549469, 22.17753029], [88.65511322, 22.17731094], [88.65478516, 22.17708778], [88.65453339, 22.17687988], [88.65434265, 22.17667961], [88.65413666, 22.1764698], [88.65390778, 22.17623138], [88.65365601, 22.17589188], [88.65335083, 22.17550087], [88.6530304, 22.17510605], [88.65267181, 22.17477036], [88.65231323, 22.1744976], [88.6520462, 22.17421532], [88.6516571, 22.17389107], [88.65139008, 22.17361069], [88.65139008, 22.1733284], [88.65110779, 22.17305565], [88.65083313, 22.17305946], [88.65027618, 22.17250061], [88.65000153, 22.17222214], [88.65000153, 22.17194366], [88.64916992, 22.17111206], [88.64888763, 22.17073822], [88.64865112, 22.17050171], [88.64839935, 22.17020988], [88.64816284, 22.16983986], [88.64787292, 22.16945839], [88.64753723, 22.16908073], [88.64722443, 22.16867828], [88.64689636, 22.16827965], [88.646492, 22.16794968], [88.64619446, 22.16749191], [88.64602661, 22.16682816], [88.64552307, 22.16642952], [88.6453476, 22.16571236], [88.64498138, 22.16520119], [88.64456177, 22.16477966], [88.64409637, 22.16447067], [88.6436615, 22.16423988], [88.64333344, 22.16394043], [88.64305878, 22.16361046], [88.6428299, 22.1632309], [88.64265442, 22.16278839], [88.64245605, 22.16233063], [88.64239502, 22.16224098], [88.64218903, 22.16192436], [88.64190674, 22.16156769], [88.64170074, 22.16114998], [88.6415329, 22.16074371], [88.64139557, 22.16042519], [88.64128113, 22.16011047], [88.64111328, 22.15981293], [88.64098358, 22.15949631], [88.64084625, 22.15920067], [88.64076233, 22.15891457], [88.64055634, 22.15867615], [88.64025879, 22.15850067], [88.64008331, 22.15827179], [88.63995361, 22.15802574], [88.63967896, 22.15777969], [88.63948059, 22.1574707], [88.63933563, 22.15710831], [88.63916779, 22.15666962], [88.63889313, 22.15639114], [88.63889313, 22.15611076], [88.63861084, 22.1558342], [88.63861084, 22.15555763], [88.63833618, 22.15528107], [88.63833618, 22.15417099], [88.63861084, 22.15389061], [88.63861084, 22.15361023], [88.63889313, 22.15332985], [88.6388855, 22.15250015], [88.63916779, 22.15222168], [88.63916779, 22.15166664], [88.63944244, 22.15139008], [88.63944244, 22.1511097], [88.63972473, 22.15083313], [88.63972473, 22.15027809], [88.63999939, 22.14999962], [88.63999939, 22.14944267], [88.64027405, 22.14916611], [88.64026642, 22.14723015], [88.64055634, 22.14693832], [88.64055634, 22.14500046], [88.64083862, 22.14471817], [88.64064026, 22.14400673], [88.64037323, 22.14344978], [88.64002228, 22.14298058], [88.63965607, 22.1425705], [88.63931274, 22.14221954], [88.63894653, 22.14188194], [88.63858032, 22.14150238], [88.63816071, 22.1411171], [88.63768768, 22.14073181], [88.63723755, 22.14029121], [88.6368103, 22.13986969], [88.63643646, 22.13949013], [88.63613892, 22.13917923], [88.63587189, 22.13894272], [88.63559723, 22.13877106], [88.6353302, 22.13857079], [88.6350708, 22.13833046], [88.63479614, 22.13807106], [88.6344986, 22.13781929], [88.63421631, 22.13751984], [88.63394165, 22.13722992], [88.63365173, 22.13697815], [88.6333313, 22.13678932], [88.63300323, 22.13665962], [88.63269043, 22.13660049], [88.6324234, 22.1366806], [88.63226318, 22.13697815], [88.63214874, 22.13749886], [88.63200378, 22.13797379], [88.63195801, 22.13848114], [88.63194275, 22.13861084], [88.63194275, 22.13972092], [88.63166809, 22.13999939], [88.63166809, 22.1408329], [88.6313858, 22.14111137], [88.6313858, 22.14221954], [88.63111115, 22.14249992], [88.63111115, 22.14471817], [88.63054657, 22.14528084], [88.6297226, 22.14528084], [88.6297226, 22.14360809], [88.62999725, 22.14333344], [88.62999725, 22.14277649], [88.63027954, 22.14249992], [88.63027954, 22.14083099], [88.6305542, 22.14055443], [88.63054657, 22.13972092], [88.63083649, 22.13944435], [88.63083649, 22.13888931], [88.63082123, 22.13845253], [88.63087463, 22.13797188], [88.6309967, 22.13746071], [88.63121796, 22.13692856], [88.63150787, 22.13637161], [88.63140106, 22.13583374], [88.63122559, 22.13526154], [88.63102722, 22.13469124], [88.63067627, 22.1342907], [88.63034058, 22.13391113], [88.62996674, 22.13359642], [88.62966156, 22.13326073], [88.6293869, 22.13294029], [88.62914276, 22.13265038], [88.62888336, 22.13240623], [88.62858582, 22.13216972], [88.62827301, 22.13191032], [88.62796783, 22.13158417], [88.62761688, 22.13121414], [88.62728119, 22.13080978], [88.62696075, 22.13041115], [88.62667084, 22.13005066], [88.62641144, 22.12972832], [88.62622833, 22.12943077], [88.626091, 22.12912941], [88.62593842, 22.12885284], [88.62581635, 22.12857246], [88.62567139, 22.12829971], [88.62553406, 22.12801361], [88.62537384, 22.12772179], [88.62523651, 22.12737083], [88.62504578, 22.12699127], [88.62491608, 22.12650108], [88.62471008, 22.12603951], [88.62445068, 22.12560272], [88.62423706, 22.12515068], [88.62407684, 22.12466049], [88.62388611, 22.12424088], [88.62371063, 22.1238575], [88.6235733, 22.12347984], [88.6233902, 22.12319183], [88.62326813, 22.12288094], [88.62310791, 22.12262154], [88.62301636, 22.12228966], [88.62290955, 22.12195778], [88.62278748, 22.12157822], [88.62265015, 22.12112045], [88.62246704, 22.12061501], [88.62224579, 22.12008286], [88.62210083, 22.11953354], [88.62197876, 22.11904335], [88.6219101, 22.1186142], [88.6218338, 22.11825752], [88.62169647, 22.11797905], [88.62161255, 22.11764908], [88.62148285, 22.1172905], [88.62138367, 22.11684036], [88.6212616, 22.11635971], [88.62111664, 22.1158905], [88.62094879, 22.11540985], [88.62077332, 22.11488914], [88.62064362, 22.11427879], [88.62050629, 22.11364174], [88.62030792, 22.11302948], [88.62017059, 22.11243057], [88.62000275, 22.11186981], [88.6198349, 22.11134911], [88.61974335, 22.11079979], [88.61967468, 22.11017036], [88.61962891, 22.10943031], [88.61928558, 22.10884094], [88.61864471, 22.10864449], [88.61795807, 22.10863686], [88.6173172, 22.10864258], [88.61683655, 22.10843468], [88.6162796, 22.10828972], [88.61572266, 22.10810089], [88.6151123, 22.10806274], [88.61448669, 22.10806274], [88.6138916, 22.10803032], [88.61333466, 22.10791969], [88.61279297, 22.10779953], [88.61225128, 22.10773087], [88.61178589, 22.1075592], [88.61126709, 22.10750008], [88.61075592, 22.10750008], [88.61023712, 22.10758018], [88.60979462, 22.10786629], [88.60955811, 22.10840034], [88.60954285, 22.10908699], [88.60968018, 22.10972023], [88.60980225, 22.1102829], [88.61000061, 22.11067963], [88.61016846, 22.1110611], [88.6103363, 22.11145782], [88.61052704, 22.11190224], [88.61071777, 22.11240005], [88.61087036, 22.11292839], [88.61094666, 22.11349106], [88.61091614, 22.1140995], [88.61087036, 22.11468697], [88.61082458, 22.11520195], [88.61074066, 22.11562538], [88.61061859, 22.11596107], [88.61055756, 22.11629295], [88.610466, 22.1165905], [88.61032867, 22.11686516], [88.61016846, 22.11718369], [88.6099472, 22.11750031], [88.60968018, 22.11785126], [88.60943604, 22.11826134], [88.60916901, 22.11867142], [88.60889435, 22.11907387], [88.60861969, 22.11946487], [88.6083374, 22.11985207], [88.60804749, 22.12023163], [88.60774994, 22.12061119], [88.60748291, 22.12103081], [88.60722351, 22.12144089], [88.60694122, 22.12182999], [88.60664368, 22.12220573], [88.6063385, 22.12257195], [88.60608673, 22.12298965], [88.60584259, 22.12338066], [88.60559082, 22.12374115], [88.60534668, 22.12409019], [88.60510254, 22.1244297], [88.60481262, 22.1247406], [88.60450745, 22.12504959], [88.60420227, 22.1253891], [88.60391235, 22.12571907], [88.60365295, 22.12607956], [88.60340881, 22.12643814], [88.60320282, 22.12677193], [88.60299683, 22.1270504], [88.60281372, 22.12736511], [88.60263062, 22.12779236], [88.6023941, 22.12817383], [88.60214996, 22.12855339], [88.60196686, 22.12898254], [88.60166168, 22.12944031], [88.60166168, 22.13000107], [88.60111237, 22.13055992], [88.60111237, 22.13138962], [88.60083008, 22.13166809], [88.60056305, 22.13138962], [88.60055542, 22.13027954], [88.60028076, 22.13000107], [88.60028076, 22.12972069], [88.60083008, 22.12916565], [88.60083008, 22.12861061], [88.60111237, 22.12833023], [88.60111237, 22.12805557], [88.60138702, 22.12778091], [88.60138702, 22.12750053], [88.60193634, 22.12693977], [88.60083008, 22.12693977], [88.59999847, 22.12778091], [88.59999847, 22.12805557], [88.59971619, 22.12833023], [88.59972382, 22.12861061], [88.59916687, 22.12916565], [88.59916687, 22.12944412], [88.59889221, 22.1297226], [88.59889221, 22.13083076], [88.59860992, 22.13111115], [88.59860992, 22.13305473], [88.59916687, 22.13361168], [88.59889221, 22.13389015], [88.59889221, 22.1352787], [88.59921265, 22.13547134], [88.59938049, 22.13607025], [88.59947968, 22.13679504], [88.599617, 22.13751984], [88.59976196, 22.13821983], [88.59999847, 22.13880348], [88.60025787, 22.13931465], [88.60054016, 22.13978958], [88.60085297, 22.14024162], [88.60119629, 22.14043808], [88.60148621, 22.14030075], [88.60157013, 22.13983154], [88.60144806, 22.13928986], [88.60134888, 22.13879013], [88.60124207, 22.13838959], [88.60137939, 22.13805962], [88.60153198, 22.13775063], [88.60172272, 22.13746834], [88.60196686, 22.13727379], [88.60224152, 22.1373291], [88.60250854, 22.13771057], [88.60273743, 22.13817024], [88.60288239, 22.13870049], [88.60301971, 22.13926125], [88.60305023, 22.13982582], [88.60307312, 22.1403904], [88.60315704, 22.14093971], [88.60328674, 22.14149284], [88.60333252, 22.14206123], [88.60333252, 22.14262962], [88.60334015, 22.14319992], [88.6033783, 22.1437645], [88.60353088, 22.14429092], [88.60364532, 22.14482689], [88.60379028, 22.14535141], [88.60386658, 22.14593124], [88.60388947, 22.14651108], [88.60394287, 22.14705086], [88.60404968, 22.1475029], [88.60414886, 22.14789009], [88.60415649, 22.14825058], [88.60418701, 22.14857101], [88.60430145, 22.14888191], [88.60440826, 22.14928055], [88.60446167, 22.14974976], [88.60455322, 22.15023041], [88.60468292, 22.15069008], [88.60473633, 22.15114594], [88.60480499, 22.15154076], [88.60494232, 22.15185356], [88.60500336, 22.15219307], [88.60507202, 22.15254021], [88.60525513, 22.15289497], [88.60539246, 22.15332985], [88.60552216, 22.15388107], [88.60555267, 22.15453911], [88.6055603, 22.15526772], [88.60555267, 22.15600014], [88.60547638, 22.15670013], [88.60531616, 22.15730095], [88.60521698, 22.15787125], [88.60505676, 22.1583519], [88.6049881, 22.15880013], [88.60491943, 22.15919113], [88.60475922, 22.15946388], [88.60462952, 22.15977478], [88.60443878, 22.1600399], [88.60418701, 22.16032028], [88.60389709, 22.16068077], [88.60359955, 22.16106987], [88.60324097, 22.1614418], [88.60281372, 22.16174126], [88.60237885, 22.16202164], [88.60188293, 22.16225052], [88.60137939, 22.16251945], [88.60087585, 22.16277122], [88.60034943, 22.16302109], [88.59980011, 22.16321945], [88.59924316, 22.1633606], [88.59868622, 22.16351128], [88.59812927, 22.16364098], [88.59760284, 22.1638298], [88.59705353, 22.16393661], [88.59655762, 22.16410065], [88.59606934, 22.16415977], [88.5956192, 22.16418457], [88.59520721, 22.16424942], [88.59481812, 22.1644001], [88.59442139, 22.1644516], [88.59403229, 22.16451454], [88.59366608, 22.16464043], [88.59323883, 22.16471291], [88.59274292, 22.16477776], [88.59223175, 22.16493988], [88.59165955, 22.16504669], [88.59106445, 22.16521263], [88.59041595, 22.16526985], [88.58978271, 22.16534042], [88.58921051, 22.16551971], [88.58863068, 22.16567039], [88.58809662, 22.16584969], [88.58763885, 22.16611099], [88.58721161, 22.16637039], [88.5867691, 22.16661072], [88.58629608, 22.16679955], [88.58585358, 22.16704941], [88.58544922, 22.1673317], [88.58503723, 22.16765022], [88.58466339, 22.16801643], [88.5842514, 22.16839981], [88.58383942, 22.16882706], [88.58344269, 22.16925049], [88.58307648, 22.1697197], [88.58277893, 22.17020035], [88.5825119, 22.17066002], [88.58229828, 22.17112732], [88.58222198, 22.17167091], [88.58215332, 22.17223549], [88.58202362, 22.17279434], [88.58201599, 22.17334175], [88.58213806, 22.17385101], [88.58221436, 22.17433739], [88.58226776, 22.17477989], [88.5823822, 22.17518806], [88.58249664, 22.17564011], [88.58261108, 22.17615891], [88.58272552, 22.17673111], [88.5827713, 22.17735291], [88.58282471, 22.17798805], [88.582901, 22.17861557], [88.58281708, 22.17918015], [88.58274078, 22.17970276], [88.58261871, 22.18013954], [88.58246613, 22.1805191], [88.58229065, 22.18086815], [88.58213043, 22.18122292], [88.58194733, 22.18152618], [88.5817337, 22.18187141], [88.58148193, 22.18226242], [88.5811615, 22.18272209], [88.5807724, 22.1831646], [88.58035278, 22.18354988], [88.57991791, 22.18387032], [88.57950592, 22.18414116], [88.57911682, 22.18438911], [88.57872772, 22.1846199], [88.57829285, 22.18482018], [88.57784271, 22.18499756], [88.57744598, 22.1852169], [88.57704163, 22.18547249], [88.57658386, 22.18579483], [88.57602692, 22.18616104], [88.57544708, 22.18661118], [88.57492065, 22.18709946], [88.57443237, 22.18758965], [88.57406616, 22.18806267], [88.57386017, 22.18851089], [88.57377625, 22.18892097], [88.57377625, 22.18931007], [88.57386017, 22.18969917], [88.57396698, 22.19009018], [88.57414246, 22.19049072], [88.57434845, 22.19091988], [88.57453918, 22.19142914], [88.57476807, 22.1919651], [88.57504272, 22.19248962], [88.57532501, 22.19297791], [88.57563019, 22.19338989], [88.57590485, 22.1937561], [88.57611084, 22.19413948], [88.57628632, 22.19449997], [88.57642365, 22.19484901], [88.57657623, 22.19514275], [88.57673645, 22.19540977], [88.57691956, 22.19573784], [88.57710266, 22.19615364], [88.57730103, 22.19656372], [88.57750702, 22.19695854], [88.5777359, 22.19734955], [88.57785797, 22.19777107], [88.57775879, 22.19819832], [88.57749939, 22.19846916], [88.57718658, 22.19843292], [88.57691956, 22.19816017], [88.57666779, 22.19776535], [88.57641602, 22.19738007], [88.57621765, 22.19697952], [88.57602692, 22.19659042], [88.57588196, 22.19618988], [88.57572937, 22.19584846], [88.57563782, 22.19548035], [88.57556915, 22.19503975], [88.57541656, 22.19458961], [88.57518768, 22.19415092], [88.57495117, 22.19370079], [88.57466125, 22.19324112], [88.57435608, 22.19272995], [88.57408905, 22.19218826], [88.57386017, 22.19165039], [88.5736618, 22.19114113], [88.57344818, 22.19065094], [88.57319641, 22.19013977], [88.57292938, 22.18960953], [88.57274628, 22.18910027], [88.57277679, 22.18873215], [88.57283783, 22.1883316], [88.5729599, 22.18791008], [88.57316589, 22.18749046], [88.57343292, 22.18702126], [88.57373047, 22.18655014], [88.5741272, 22.18616104], [88.57454681, 22.18584251], [88.5749588, 22.18555069], [88.5753479, 22.18527603], [88.575737, 22.18499756], [88.57611847, 22.18473816], [88.57652283, 22.1844902], [88.57694244, 22.18430519], [88.57736206, 22.18411064], [88.57776642, 22.18388748], [88.57817078, 22.18366432], [88.57859802, 22.18344116], [88.57904053, 22.18317032], [88.57949066, 22.18280029], [88.57995605, 22.18235016], [88.58039856, 22.18181992], [88.58080292, 22.18126106], [88.58110809, 22.18071747], [88.58130646, 22.18019295], [88.58141327, 22.1796608], [88.58148193, 22.17914963], [88.581604, 22.17869949], [88.58164215, 22.17822838], [88.58158875, 22.17776108], [88.58144379, 22.1773262], [88.58130646, 22.17683029], [88.58117676, 22.17629814], [88.58106995, 22.17579079], [88.58091736, 22.17535019], [88.58080292, 22.17488098], [88.58067322, 22.17445374], [88.5806427, 22.17396164], [88.58065796, 22.17344093], [88.58071136, 22.17292023], [88.58081818, 22.17250061], [88.58086395, 22.17209244], [88.58088684, 22.1716404], [88.58094788, 22.17114067], [88.58112335, 22.17064095], [88.58135223, 22.17007065], [88.58167267, 22.16950989], [88.58205414, 22.16905975], [88.58244324, 22.16864967], [88.5827713, 22.16819954], [88.58309937, 22.16771126], [88.58348083, 22.16723061], [88.58390808, 22.16675758], [88.58436584, 22.16633606], [88.58483124, 22.16592979], [88.5853653, 22.16560364], [88.58595276, 22.16530037], [88.586586, 22.16501045], [88.58725739, 22.16472054], [88.58789063, 22.16444778], [88.58849335, 22.16419029], [88.58909607, 22.1639595], [88.58972931, 22.16379929], [88.59034729, 22.16366005], [88.59095764, 22.16356087], [88.59147644, 22.1633606], [88.59197235, 22.16320038], [88.592453, 22.16309929], [88.59294891, 22.16303062], [88.59346008, 22.16292953], [88.59398651, 22.16281891], [88.59453583, 22.16274071], [88.59503937, 22.16262817], [88.59552765, 22.16254044], [88.59603119, 22.16250038], [88.59654236, 22.16244125], [88.59706116, 22.16230965], [88.59758759, 22.16220284], [88.5980835, 22.16206932], [88.59855652, 22.16193962], [88.5990448, 22.16181374], [88.59958649, 22.16170883], [88.60016632, 22.16163063], [88.6007843, 22.16147995], [88.60137939, 22.16119194], [88.60196686, 22.16078949], [88.60250092, 22.16029549], [88.60299683, 22.15974998], [88.60337067, 22.15908813], [88.60360718, 22.15839577], [88.60373688, 22.15769958], [88.60365295, 22.15707397], [88.6035614, 22.15640831], [88.60336304, 22.15577126], [88.60318756, 22.15511894], [88.60308075, 22.15446854], [88.60305786, 22.15385818], [88.60305023, 22.15328026], [88.60300446, 22.15274239], [88.60282898, 22.15224075], [88.6027298, 22.15168381], [88.60254669, 22.15111923], [88.60250092, 22.15044022], [88.60249329, 22.14969635], [88.60244751, 22.14894676], [88.60227203, 22.14830017], [88.60214996, 22.14771652], [88.60199738, 22.14715958], [88.60193634, 22.14656067], [88.60188293, 22.14598274], [88.60173798, 22.14544106], [88.60166931, 22.14490509], [88.60159302, 22.14439011], [88.6014328, 22.14388084], [88.60134125, 22.14336014], [88.60116577, 22.14290047], [88.60105133, 22.14238548], [88.60082245, 22.14194107], [88.60056305, 22.14154816], [88.60027313, 22.14118004], [88.59998322, 22.14084816], [88.59966278, 22.14053154], [88.59938049, 22.14017105], [88.59914398, 22.13971138], [88.59890747, 22.1391983], [88.59868622, 22.13863945], [88.59851074, 22.13799095], [88.59844971, 22.13725471], [88.59829712, 22.1365509], [88.5981369, 22.13594055], [88.59809113, 22.1354599], [88.5980835, 22.13503075], [88.59790039, 22.1345005], [88.59764099, 22.13401985], [88.59745026, 22.1335392], [88.59735107, 22.13307953], [88.59733582, 22.13262749], [88.59739685, 22.13212013], [88.59745026, 22.13158989], [88.59749603, 22.13108253], [88.59757233, 22.13062096], [88.59771729, 22.13017273], [88.59790039, 22.12965965], [88.59812164, 22.12914085], [88.59831238, 22.1286602], [88.598526, 22.12828255], [88.59874725, 22.12798691], [88.59897614, 22.12772751], [88.59921265, 22.12747955], [88.59944916, 22.12722015], [88.59971619, 22.12695694], [88.60003662, 22.12667084], [88.60045624, 22.12638664], [88.60098267, 22.12614059], [88.60157013, 22.12597084], [88.60211182, 22.12578201], [88.60250854, 22.12552071], [88.60282135, 22.12520027], [88.60308075, 22.12482834], [88.60336304, 22.1244812], [88.60365295, 22.12415123], [88.60392761, 22.12382317], [88.60417938, 22.12346649], [88.60443878, 22.12312126], [88.60468292, 22.12277031], [88.60494232, 22.12240982], [88.60520935, 22.12203789], [88.60549164, 22.12168121], [88.60571289, 22.12125969], [88.60591125, 22.12088966], [88.60611725, 22.12057114], [88.60633087, 22.12030411], [88.60649109, 22.12005043], [88.60666656, 22.11983109], [88.60688782, 22.11962128], [88.60712433, 22.1193676], [88.60739136, 22.11905289], [88.60765839, 22.1186409], [88.60797882, 22.11823082], [88.60826874, 22.11780548], [88.60848999, 22.11735725], [88.60869598, 22.1169796], [88.60890961, 22.11665154], [88.60910797, 22.11633301], [88.60923767, 22.11594963], [88.60939026, 22.11553955], [88.60942841, 22.11502457], [88.60944366, 22.11441612], [88.60943604, 22.11374092], [88.60936737, 22.11304283], [88.60914612, 22.11234283], [88.60887909, 22.11168098], [88.60857391, 22.11109924], [88.60826111, 22.1106205], [88.60800934, 22.11032867], [88.60749817, 22.10972023], [88.60749817, 22.10944366], [88.60722351, 22.1091671], [88.60721588, 22.10889053], [88.60666656, 22.10833168], [88.60666656, 22.10777855], [88.60721588, 22.1072216], [88.60744476, 22.1070118], [88.60769653, 22.10704994], [88.6079483, 22.10700035], [88.60820007, 22.10695267], [88.60868835, 22.10684013], [88.60910034, 22.10666084], [88.60943604, 22.10639191], [88.61000061, 22.10639191], [88.6102829, 22.10611153], [88.61055756, 22.10611153], [88.6108017, 22.10605621], [88.61126709, 22.10611153], [88.61174774, 22.10616875], [88.61222076, 22.10630035], [88.61281586, 22.10633278], [88.61347961, 22.10637093], [88.614151, 22.10638046], [88.61480713, 22.10634995], [88.61546326, 22.10624123], [88.61608124, 22.10614777], [88.6166687, 22.10606956], [88.61717224, 22.10589027], [88.61772919, 22.10580063], [88.6180191, 22.10571289], [88.61828613, 22.10563087], [88.61886597, 22.10551071], [88.61936951, 22.10532951], [88.61971283, 22.1049881], [88.6199646, 22.10454941], [88.62018585, 22.10400009], [88.62043762, 22.1033802], [88.62049103, 22.10264969], [88.62034607, 22.10198021], [88.62032318, 22.10135269], [88.62037659, 22.10081482], [88.62047577, 22.10034752], [88.6205368, 22.09992027], [88.62055969, 22.09953499], [88.62058258, 22.09918022], [88.62070465, 22.09885406], [88.62081146, 22.09848022], [88.62082672, 22.09803009], [88.6208725, 22.09754944], [88.62104034, 22.0970726], [88.62119293, 22.09658241], [88.62133789, 22.09605408], [88.62138367, 22.09547234], [88.62142944, 22.0948925], [88.6215744, 22.09435272], [88.62179565, 22.09383965], [88.62203979, 22.09331322], [88.62199402, 22.09260941], [88.62203217, 22.09189987], [88.62217712, 22.09120941], [88.62224579, 22.09048843], [88.62243652, 22.08980942], [88.62280273, 22.08917809], [88.62325287, 22.08856964], [88.6233902, 22.08811951], [88.62346649, 22.08788109], [88.62340546, 22.08736992], [88.62338257, 22.08714867], [88.62335205, 22.08645058], [88.62354279, 22.08587074], [88.62358093, 22.08531952], [88.62360382, 22.08485222], [88.62362671, 22.08443832], [88.62371826, 22.0840683], [88.62397003, 22.08376694], [88.62420654, 22.0834198], [88.62419128, 22.08299255], [88.62419891, 22.08247375], [88.62431335, 22.08188629], [88.6244278, 22.08122826], [88.62451935, 22.08051109], [88.62467957, 22.07983208], [88.6247406, 22.07915497], [88.62480927, 22.07853127], [88.62497711, 22.0779705], [88.62509155, 22.07743835], [88.62523651, 22.07698059], [88.62528992, 22.07653809], [88.62532806, 22.07613945], [88.6253891, 22.07575035], [88.62547302, 22.07536125], [88.62555695, 22.07496262], [88.6257019, 22.07455254], [88.62580109, 22.07413673], [88.6258316, 22.0736599], [88.6258316, 22.07315826], [88.6258316, 22.07262993], [88.62588501, 22.07210159], [88.62605286, 22.07160187], [88.62610626, 22.07107735], [88.6261673, 22.07056999], [88.62638855, 22.07014847], [88.62661743, 22.06969833], [88.62671661, 22.06915092], [88.62689209, 22.06858063], [88.62693024, 22.06793976], [88.62689972, 22.06728935], [88.62679291, 22.06665993], [88.62692261, 22.06607437], [88.62705994, 22.06545067], [88.62700653, 22.06468964], [88.62703705, 22.06394005], [88.62690735, 22.06336021], [88.62671661, 22.06282043], [88.62666321, 22.06225014], [88.62665558, 22.06165123], [88.62665558, 22.06104279], [88.62665558, 22.06045723], [88.62666321, 22.05992126], [88.62666321, 22.0594101], [88.62665558, 22.05892372], [88.62666321, 22.05842972], [88.62667847, 22.05791283], [88.62674713, 22.05739975], [88.62687683, 22.0569191], [88.62697601, 22.05643082], [88.62708282, 22.05599022], [88.62718201, 22.05559921], [88.62722778, 22.05518913], [88.62729645, 22.05480957], [88.62742615, 22.0544529], [88.62752533, 22.05406761], [88.62763977, 22.05368042], [88.62780762, 22.05331039], [88.62802887, 22.05293274], [88.62824249, 22.05250931], [88.62848663, 22.05207825], [88.6287384, 22.05166054], [88.62902069, 22.05126762], [88.62927246, 22.05091286], [88.62953949, 22.0506115], [88.62984467, 22.05033875], [88.63021088, 22.05006981], [88.63067627, 22.04977989], [88.63119507, 22.0494442], [88.63172913, 22.0490551], [88.63228607, 22.04866982], [88.63288116, 22.04834747], [88.63339996, 22.04804993], [88.63386536, 22.04777527], [88.63426208, 22.04750061], [88.6346283, 22.04722977], [88.63497925, 22.04696846], [88.6353302, 22.04673004], [88.63569641, 22.04654121], [88.63610077, 22.04636192], [88.63638306, 22.04606819], [88.63658142, 22.04574013], [88.63665771, 22.04528999], [88.6366272, 22.04478073], [88.63645172, 22.04424095], [88.63617706, 22.04370117], [88.63609314, 22.04356384], [88.63584137, 22.04315186], [88.63547516, 22.04261398], [88.63504028, 22.04215813], [88.63463593, 22.04174995], [88.63425446, 22.04145241], [88.63395691, 22.04116058], [88.63374329, 22.04084969], [88.63349152, 22.04055595], [88.6332016, 22.04026985], [88.63288116, 22.03998756], [88.63257599, 22.03970909], [88.63227844, 22.03942108], [88.63199615, 22.03911972], [88.63170624, 22.03878021], [88.63141632, 22.03837967], [88.63108063, 22.0380249], [88.6307373, 22.03769875], [88.63038635, 22.03742027], [88.63012695, 22.03707123], [88.62989044, 22.03670692], [88.62958527, 22.03635216], [88.62928009, 22.03596306], [88.62895203, 22.03561592], [88.62865448, 22.03527451], [88.62838745, 22.03497124], [88.62812805, 22.03469276], [88.62786865, 22.03442383], [88.62758636, 22.03414536], [88.62729645, 22.03385162], [88.62698364, 22.03355217], [88.62669373, 22.03325462], [88.62644196, 22.03294945], [88.62623596, 22.03261948], [88.62602997, 22.03227997], [88.6257782, 22.03195953], [88.62546539, 22.03166389], [88.62511444, 22.0313549], [88.62477875, 22.03100395], [88.6244812, 22.03061295], [88.62417603, 22.03028679], [88.62387848, 22.02999115], [88.62359619, 22.02968979], [88.62329102, 22.02937126], [88.62303925, 22.02898026], [88.62278748, 22.02860641], [88.62256622, 22.02823067], [88.62239838, 22.02782822], [88.62217712, 22.02745056], [88.62194061, 22.02703285], [88.62166595, 22.02656746], [88.6213913, 22.02602959], [88.62111664, 22.02545166], [88.62086487, 22.02485657], [88.6206665, 22.02429008], [88.6203537, 22.02390289], [88.62005615, 22.02359962], [88.61981964, 22.02333069], [88.61962128, 22.02305984], [88.61940765, 22.02281189], [88.61917114, 22.02259254], [88.618927, 22.02235985], [88.61873627, 22.02206993], [88.61855316, 22.02176094], [88.61830139, 22.02151108], [88.6180191, 22.02132988], [88.61775208, 22.02113914], [88.61743927, 22.0210247], [88.61711884, 22.02087784], [88.616745, 22.02088547], [88.61633301, 22.02106094], [88.6158371, 22.02116013], [88.6153717, 22.02133751], [88.61489105, 22.02140808], [88.61444092, 22.02153015], [88.61400604, 22.02165031], [88.61354828, 22.02174759], [88.61305237, 22.02190971], [88.61248016, 22.02205849], [88.61186981, 22.02222061], [88.61123657, 22.02238083], [88.6105957, 22.02241135], [88.61016083, 22.02232361], [88.60997009, 22.02228165], [88.60935974, 22.02226067], [88.60875702, 22.02235031], [88.60816193, 22.02246857], [88.60753632, 22.0225296], [88.60692596, 22.02264977], [88.60632324, 22.02275085], [88.60571289, 22.02277946], [88.60507965, 22.02282906], [88.60450745, 22.02304077], [88.60394287, 22.02329063], [88.60340118, 22.02355957], [88.60292053, 22.02387047], [88.6024704, 22.02416992], [88.6020813, 22.02446175], [88.60176849, 22.02478981], [88.60155487, 22.02518272], [88.60141754, 22.02541733], [88.60132599, 22.02557182], [88.60110474, 22.0259552], [88.60089111, 22.02635956], [88.60087585, 22.0268898], [88.60105133, 22.02742958], [88.60111237, 22.02793121], [88.60115814, 22.02839661], [88.6013031, 22.02882957], [88.60142517, 22.02931595], [88.60158539, 22.02979279], [88.60171509, 22.03027153], [88.60189056, 22.03069115], [88.60196686, 22.03115082], [88.60206604, 22.03159332], [88.60218048, 22.03202057], [88.60221863, 22.03248024], [88.60222626, 22.03294182], [88.60222626, 22.03339005], [88.60222626, 22.03383064], [88.602211, 22.0342598], [88.60214233, 22.03467941], [88.60201263, 22.03511047], [88.60196686, 22.03561783], [88.6019516, 22.03614044], [88.6019516, 22.03666115], [88.60195923, 22.03713608], [88.60199738, 22.03757095], [88.60211945, 22.03796768], [88.60220337, 22.03833389], [88.60222626, 22.03869247], [88.60224915, 22.03904724], [88.60233307, 22.03938484], [88.60249329, 22.03973007], [88.6026535, 22.04014969], [88.60287476, 22.04062462], [88.6031723, 22.0410881], [88.60352325, 22.04157829], [88.60387421, 22.04208374], [88.6042099, 22.04257965], [88.60455322, 22.04301071], [88.60488892, 22.04337502], [88.60514832, 22.0437603], [88.60536957, 22.04416275], [88.60555267, 22.0445385], [88.60572052, 22.04489326], [88.60585785, 22.04525375], [88.60601044, 22.04561043], [88.60610962, 22.0460186], [88.60620117, 22.0464325], [88.60632324, 22.04682922], [88.60637665, 22.04726791], [88.60635376, 22.04772186], [88.60626221, 22.04815483], [88.60614014, 22.04853249], [88.60603333, 22.04892349], [88.60588837, 22.04929161], [88.60575104, 22.04972076], [88.60551453, 22.05012894], [88.60522461, 22.0505352], [88.6049118, 22.05095673], [88.60464478, 22.05138397], [88.60438538, 22.05180931], [88.60412598, 22.05221748], [88.60386658, 22.05261993], [88.60363007, 22.05303001], [88.6034317, 22.05345917], [88.60321808, 22.05382919], [88.60296631, 22.05414963], [88.60273743, 22.05447769], [88.60251617, 22.05482101], [88.60231781, 22.05518913], [88.60217285, 22.05558968], [88.60193634, 22.05594063], [88.60167694, 22.05628014], [88.60138702, 22.056633], [88.60108948, 22.05699158], [88.60079956, 22.05737114], [88.60044098, 22.05772972], [88.6000061, 22.05805969], [88.59957886, 22.05842972], [88.59915924, 22.05885124], [88.59873962, 22.0592804], [88.59836578, 22.05973816], [88.59807587, 22.06019974], [88.59781647, 22.06060028], [88.59763336, 22.06097031], [88.59748077, 22.06130028], [88.59733582, 22.06157684], [88.59722137, 22.06188202], [88.59710693, 22.06217957], [88.59696198, 22.06251907], [88.5968399, 22.06289101], [88.59673309, 22.06329727], [88.59671783, 22.06377029], [88.59673309, 22.0642662], [88.59680176, 22.0647316], [88.59693146, 22.06513023], [88.59707642, 22.06554985], [88.59726715, 22.06594086], [88.59749603, 22.0663681], [88.59771729, 22.06684113], [88.59797668, 22.06729698], [88.59829712, 22.06768036], [88.59863281, 22.06804085], [88.59896851, 22.06837654], [88.59931946, 22.06872749], [88.59970856, 22.06911087], [88.60011292, 22.06950188], [88.6004715, 22.06989098], [88.60077667, 22.07023811], [88.60101318, 22.07055283], [88.60121155, 22.07084084], [88.60140228, 22.07110977], [88.60160065, 22.07139015], [88.60173798, 22.0717411], [88.60186005, 22.07214737], [88.60190582, 22.07263947], [88.60183716, 22.07316017], [88.60166168, 22.07361031], [88.60111237, 22.07306099], [88.60111237, 22.07250023], [88.60083008, 22.07221985], [88.60067749, 22.07198334], [88.60050964, 22.07166481], [88.60028076, 22.07139587], [88.6000061, 22.07110977], [88.59967804, 22.07078934], [88.59931183, 22.07042122], [88.59890747, 22.07004547], [88.59851837, 22.06966019], [88.59818268, 22.06925964], [88.59785461, 22.06886292], [88.59754181, 22.06848145], [88.597229, 22.06810188], [88.59690094, 22.06771469], [88.59658051, 22.06726646], [88.59636688, 22.06668282], [88.59617615, 22.06611061], [88.59603882, 22.06559372], [88.59599304, 22.06505203], [88.59598541, 22.06453705], [88.59597015, 22.06402016], [88.59596252, 22.06349945], [88.59596252, 22.062994], [88.5959549, 22.06250381], [88.59601593, 22.06204033], [88.59610748, 22.06157112], [88.59622955, 22.06104088], [88.59645081, 22.06054115], [88.59675598, 22.06008911], [88.59707642, 22.05969238], [88.59738159, 22.0592804], [88.59764862, 22.05883026], [88.59790039, 22.05836678], [88.5982132, 22.05791283], [88.59860229, 22.05751038], [88.59901428, 22.05712318], [88.59938049, 22.05667305], [88.59976959, 22.05620384], [88.60017395, 22.05573654], [88.60054016, 22.0552597], [88.60083771, 22.05481911], [88.60108948, 22.05446053], [88.6013031, 22.05415916], [88.60150146, 22.05388069], [88.60171509, 22.05361176], [88.6019516, 22.05332375], [88.60219574, 22.05302429], [88.60240936, 22.05273056], [88.6026001, 22.05241013], [88.6027832, 22.05212021], [88.60299683, 22.05182266], [88.60322571, 22.05147934], [88.60349274, 22.05109024], [88.60379028, 22.05064964], [88.60411835, 22.05018044], [88.60446167, 22.04966354], [88.60475159, 22.04904938], [88.60491943, 22.0483284], [88.60497284, 22.04755974], [88.60488892, 22.04684258], [88.60468292, 22.04626083], [88.60443878, 22.04577065], [88.60417938, 22.04533005], [88.60394287, 22.04490089], [88.60372925, 22.0444603], [88.60348511, 22.04404259], [88.60322571, 22.0436306], [88.60295105, 22.04322624], [88.60262299, 22.04278946], [88.60222626, 22.04232025], [88.6018219, 22.04179382], [88.60144043, 22.04121971], [88.60113525, 22.04065895], [88.60090637, 22.04016113], [88.60076904, 22.03969955], [88.6006012, 22.0392704], [88.60049438, 22.03876495], [88.6003418, 22.03819084], [88.60028839, 22.0375061], [88.60027313, 22.03681946], [88.60027313, 22.03619957], [88.60027313, 22.03569984], [88.60028076, 22.0352993], [88.60031891, 22.03494072], [88.60043335, 22.03458023], [88.60051727, 22.03417969], [88.60054779, 22.03372955], [88.60055542, 22.03326225], [88.60055542, 22.03277779], [88.60056305, 22.03228951], [88.60054779, 22.03181458], [88.60049438, 22.03136826], [88.60037231, 22.03098106], [88.60029602, 22.03059196], [88.60024261, 22.03020859], [88.6001358, 22.02985191], [88.60003662, 22.02946091], [88.59997559, 22.02904129], [88.5998764, 22.02860832], [88.59977722, 22.02808952], [88.59967041, 22.02749252], [88.5994873, 22.02694511], [88.59934998, 22.02640533], [88.59932709, 22.02588081], [88.59945679, 22.02542114], [88.59965515, 22.02503967], [88.59971619, 22.02466774], [88.59971619, 22.02430916], [88.59977722, 22.02395058], [88.59990692, 22.02359581], [88.60015106, 22.02321625], [88.60051727, 22.0228405], [88.60092926, 22.02247047], [88.60134125, 22.02207947], [88.60162354, 22.02183342], [88.60173035, 22.02173615], [88.60212708, 22.0214901], [88.60256958, 22.02131081], [88.60299683, 22.021101], [88.60341644, 22.02087975], [88.60388947, 22.02083969], [88.60415649, 22.02111053], [88.6047287, 22.02111053], [88.60500336, 22.02139091], [88.60749817, 22.02139091], [88.60778809, 22.02111053], [88.60861206, 22.02111053], [88.60888672, 22.02083969], [88.60916901, 22.02083969], [88.60943604, 22.02111053], [88.61138916, 22.02111053], [88.61165619, 22.02083969], [88.61205292, 22.02083778], [88.61332703, 22.02083969], [88.61444092, 22.01972008], [88.61444092, 22.01944351], [88.61434937, 22.01935005], [88.61416626, 22.01916695], [88.61416626, 22.01861], [88.6138916, 22.01833344], [88.6138916, 22.01764488], [88.61412048, 22.0171814], [88.61415863, 22.01672554], [88.61411285, 22.01626968], [88.61393738, 22.01578903], [88.61387634, 22.01518822], [88.6138382, 22.01453018], [88.61367035, 22.01391029], [88.61361694, 22.01330376], [88.61358643, 22.01279068], [88.61348724, 22.01241112], [88.61334991, 22.0121212], [88.61323547, 22.01186371], [88.61315918, 22.01176643], [88.61306763, 22.01164436], [88.61292267, 22.01138306], [88.61277008, 22.01108932], [88.61255646, 22.01078033], [88.61235046, 22.01042938], [88.61205292, 22.01009941], [88.61174774, 22.00976563], [88.61151123, 22.00933266], [88.6111908, 22.00895119], [88.61089325, 22.00851059], [88.61062622, 22.0079689], [88.61038208, 22.00733948], [88.61009979, 22.00671959], [88.60972595, 22.00616074], [88.60939789, 22.0056591], [88.60906982, 22.00523758], [88.6088562, 22.00486565], [88.60865784, 22.00455475], [88.60852814, 22.00425529], [88.60836792, 22.00401115], [88.6082077, 22.00375938], [88.60804749, 22.00350952], [88.60786438, 22.0032177], [88.6076889, 22.00281143], [88.60744476, 22.00236893], [88.6071167, 22.00194168], [88.60682678, 22.00152969], [88.60668182, 22.0011692], [88.60677338, 22.00094986], [88.60639191, 22.00000191], [88.60669708, 21.99967957], [88.60653687, 21.99953079], [88.60639191, 21.99929047], [88.60626221, 21.99904633], [88.60611725, 21.99879074], [88.60600281, 21.99852943], [88.60579681, 21.99829483], [88.60559845, 21.99805069], [88.60547638, 21.99775124], [88.60529327, 21.99747086], [88.60511017, 21.99714088], [88.60497284, 21.99677467], [88.60478973, 21.99641418], [88.60466766, 21.99602509], [88.60452271, 21.99567986], [88.60441589, 21.99532127], [88.60430145, 21.99496269], [88.60415649, 21.99452019], [88.60399628, 21.99403381], [88.6037674, 21.99355888], [88.60356903, 21.99304962], [88.60333252, 21.99250031], [88.60305786, 21.99221992], [88.60305786, 21.99194336], [88.6027832, 21.99167061], [88.6027832, 21.99053955], [88.60250092, 21.99055481], [88.60208893, 21.99035072], [88.60194397, 21.99027824], [88.6027832, 21.98944283], [88.60277557, 21.98916626], [88.60250092, 21.98888969], [88.60250092, 21.98861122], [88.60193634, 21.9880619], [88.60111237, 21.98722267], [88.60194397, 21.98638916], [88.60193634, 21.98611069], [88.60138702, 21.98555946], [88.60138702, 21.98524094], [88.60138702, 21.9841671], [88.60111237, 21.98389053], [88.60111237, 21.98360825], [88.60083008, 21.98333359], [88.60028076, 21.98333359], [88.60028076, 21.98249817], [88.59988403, 21.98210335], [88.59972382, 21.98194695], [88.59980011, 21.98186874], [88.59999847, 21.98166847], [88.60055542, 21.98166847], [88.60055542, 21.98055458], [88.60028076, 21.98027992], [88.60028076, 21.97999954], [88.59999847, 21.97972107], [88.59999847, 21.9794445], [88.59999084, 21.97916985], [88.5997467, 21.97862053], [88.59957886, 21.97805023], [88.59944153, 21.97746086], [88.59931183, 21.97685051], [88.59915161, 21.97626686], [88.59896088, 21.97570992], [88.59884644, 21.97518921], [88.59870148, 21.97470093], [88.59879303, 21.97417259], [88.59908295, 21.97363091], [88.59903717, 21.97321129], [88.59886932, 21.97278976], [88.59866333, 21.97237968], [88.59860992, 21.97192955], [88.59860229, 21.97145844], [88.59860229, 21.97099113], [88.59860992, 21.97055626], [88.59860229, 21.97000122], [88.59881592, 21.96979523], [88.59889221, 21.96972275], [88.59889221, 21.96944427], [88.59833527, 21.96888733], [88.5983429, 21.96833038], [88.59860992, 21.96805763], [88.59860229, 21.96778107], [88.59889221, 21.96750069], [88.59889221, 21.96528053], [88.59887695, 21.96489906], [88.59889221, 21.96454811], [88.59895325, 21.9642086], [88.59906006, 21.96390533], [88.59916687, 21.96363068], [88.59928131, 21.96339226], [88.59937286, 21.96312714], [88.59916687, 21.96278], [88.59944153, 21.96249962], [88.59944153, 21.96222115], [88.59972382, 21.96194458], [88.59972382, 21.96166611], [88.59983063, 21.9615612], [88.60028076, 21.96111107], [88.60056305, 21.96111107], [88.60086823, 21.96047783], [88.60119629, 21.95988083], [88.60138702, 21.95972252], [88.60138702, 21.95916748], [88.60166168, 21.95889091], [88.60166168, 21.95832825], [88.60194397, 21.9580555], [88.60221863, 21.95833397], [88.60233307, 21.95822144], [88.60250092, 21.9580555], [88.60250092, 21.9569397], [88.60253143, 21.95669174], [88.60276031, 21.95630074], [88.60293579, 21.95582962], [88.60317993, 21.95534515], [88.60352325, 21.9549408], [88.60360718, 21.95471954], [88.60388947, 21.95444679], [88.60388947, 21.95416451], [88.60415649, 21.95388985], [88.60415649, 21.95360947], [88.60444641, 21.9533329], [88.60472107, 21.9533329], [88.60500336, 21.95305443], [88.60500336, 21.95222092], [88.60583496, 21.95138931], [88.60555267, 21.95111084], [88.60582733, 21.95083046], [88.60583496, 21.95027733], [88.60639191, 21.94972038], [88.60639191, 21.94944382], [88.60666656, 21.94916725], [88.60666656, 21.94861984], [88.60721588, 21.9480629], [88.60721588, 21.94750023], [88.60778809, 21.94695282], [88.60778809, 21.94611168], [88.60944366, 21.94444466], [88.60972595, 21.94444466], [88.60993958, 21.94408989], [88.6102829, 21.94367981], [88.61062622, 21.94320869], [88.61104584, 21.94275093], [88.61147308, 21.94227028], [88.61190796, 21.94180107], [88.61231232, 21.94129944], [88.61270905, 21.94079018], [88.61306763, 21.9402504], [88.61339569, 21.93968964], [88.61376953, 21.93915939], [88.61414337, 21.93863106], [88.61446381, 21.93809128], [88.61473846, 21.93753815], [88.61493683, 21.93699265], [88.61496735, 21.93640137], [88.61485291, 21.93582153], [88.61467743, 21.93526077], [88.61444092, 21.93476105], [88.61417389, 21.93432045], [88.6138916, 21.93391991], [88.61362457, 21.93355751], [88.61334991, 21.93321037], [88.61307526, 21.93288422], [88.61282349, 21.93255806], [88.6125412, 21.93228912], [88.61221313, 21.93209267], [88.6118927, 21.9319725], [88.61153412, 21.9318943], [88.61110687, 21.93169022], [88.61061096, 21.93172836], [88.61017609, 21.93172836], [88.60988617, 21.93185043], [88.60935211, 21.93189049], [88.60877991, 21.93239975], [88.60816956, 21.93276024], [88.6076355, 21.93304825], [88.60718536, 21.93331337], [88.60677338, 21.93355942], [88.6063385, 21.93379021], [88.60593414, 21.93394852], [88.60558319, 21.93417358], [88.60529327, 21.93439484], [88.60486603, 21.93467331], [88.60458374, 21.93440437], [88.60394287, 21.93440056], [88.60286713, 21.93480682], [88.60201263, 21.93540955], [88.60164642, 21.9355526], [88.60138702, 21.93527985], [88.60250092, 21.93416977], [88.60305786, 21.93416977], [88.60369873, 21.93352318], [88.60388947, 21.93333244], [88.60475159, 21.93245888], [88.60539246, 21.93185043], [88.605896, 21.93138313], [88.60675049, 21.93071175], [88.60746765, 21.9301033], [88.60824585, 21.92943001], [88.60947418, 21.92855835], [88.61019135, 21.92761993], [88.6103363, 21.92661095], [88.61083221, 21.92580032], [88.61083984, 21.92472649], [88.61089325, 21.9230957], [88.61067963, 21.92135048], [88.61023712, 21.92019844], [88.60988617, 21.91885948], [88.60945892, 21.91778946], [88.60916901, 21.91749954], [88.60916901, 21.91721916], [88.60861206, 21.91666794], [88.60861206, 21.91611099], [88.60806274, 21.91555023], [88.60805511, 21.91527557], [88.60749817, 21.91472054], [88.60749817, 21.91444588], [88.60694122, 21.91388893], [88.60694122, 21.91361046], [88.60666656, 21.91333008], [88.60666656, 21.91305733], [88.60611725, 21.91250992], [88.60610962, 21.91222], [88.60587311, 21.91198349], [88.60527802, 21.9113884], [88.60527802, 21.91110992], [88.60277557, 21.9086113], [88.60277557, 21.90833282], [88.60250092, 21.90805626], [88.60250092, 21.90777969], [88.60221863, 21.90750122], [88.60221863, 21.90666962], [88.60138702, 21.90582848], [88.60111237, 21.9058342], [88.60028076, 21.90500069], [88.59999847, 21.90500069], [88.59944153, 21.90443993], [88.59916687, 21.90444374], [88.59889221, 21.90416718], [88.59860229, 21.90416908], [88.59805298, 21.90360832], [88.59777832, 21.90360832], [88.59610748, 21.90195084], [88.59583282, 21.90195084], [88.59333038, 21.89944077], [88.59305573, 21.89944649], [88.59278107, 21.8991642], [88.59221649, 21.89916992], [88.59194183, 21.89888954], [88.59166718, 21.89888954], [88.59111023, 21.89833069], [88.59083557, 21.8983326], [88.59063721, 21.89813614], [88.59055328, 21.89805412], [88.59027863, 21.89805984], [88.58972168, 21.89751053], [88.58944702, 21.89751053], [88.5890274, 21.89708328], [88.58889008, 21.89694023], [88.58860779, 21.89694214], [88.58611298, 21.89444351], [88.58583069, 21.89444351], [88.58527374, 21.89388466], [88.58472443, 21.89333344], [88.58444214, 21.89333344], [88.58416748, 21.89305496], [88.58389282, 21.89306259], [88.58361816, 21.8927803], [88.58333588, 21.8927803], [88.58304596, 21.89250183], [88.58277893, 21.89250183], [88.58222198, 21.89193916], [88.58166504, 21.89194489], [88.58110809, 21.89138985], [88.58083344, 21.89138985], [88.58055878, 21.89111137], [88.58027649, 21.89111137], [88.57944489, 21.89027977], [88.57917023, 21.89027977], [88.57888794, 21.88999748], [88.57888794, 21.88972092], [88.57861328, 21.88944435], [88.57843781, 21.88944435], [88.57833099, 21.88944435], [88.57805634, 21.88972092], [88.57805634, 21.88999748], [88.57777405, 21.89027977], [88.57777405, 21.8908329], [88.5772171, 21.89138031], [88.57722473, 21.89166641], [88.57694244, 21.89194489], [88.57694244, 21.89222145], [88.57666779, 21.89250183], [88.57666779, 21.8927803], [88.5763855, 21.89305496], [88.5763855, 21.89333344], [88.57611084, 21.89361191], [88.57611084, 21.89389038], [88.57583618, 21.89417267], [88.57583618, 21.89500046], [88.57554626, 21.89528275], [88.57554626, 21.89639091], [88.57527924, 21.89666748], [88.57527924, 21.89722061], [88.57499695, 21.89751053], [88.57499695, 21.89861107], [88.57472229, 21.89888954], [88.57472229, 21.8991642], [88.57444763, 21.89944649], [88.57444763, 21.89972305], [88.57417297, 21.89999962], [88.57416534, 21.90027618], [88.57389069, 21.90055466], [88.57389069, 21.9011097], [88.5736084, 21.90139008], [88.5736084, 21.90194511], [88.57332611, 21.90221977], [88.57332611, 21.90250015], [88.57277679, 21.90305519], [88.57277679, 21.90444374], [88.57305908, 21.9047184], [88.57277679, 21.90501022], [88.57277679, 21.90555573], [88.57305908, 21.90582848], [88.57305908, 21.9066658], [88.57499695, 21.90860939], [88.57499695, 21.90888977], [88.57666779, 21.91055489], [88.57666779, 21.91083336], [88.58027649, 21.91444588], [88.58027649, 21.91472054], [88.58083344, 21.91527557], [88.58083344, 21.91555786], [88.58110809, 21.91583061], [88.58110809, 21.91611099], [88.58139038, 21.91638947], [88.58139038, 21.91805649], [88.58110809, 21.9183197], [88.58110809, 21.91917038], [88.58083344, 21.91944504], [88.58082581, 21.9197216], [88.58055878, 21.92000008], [88.58055878, 21.92028046], [88.58027649, 21.92055511], [88.58027649, 21.92111015], [88.58000183, 21.92138863], [88.58000183, 21.92333031], [88.58027649, 21.92361069], [88.58027649, 21.92389107], [88.58083344, 21.92444229], [88.58082581, 21.92472076], [88.58110809, 21.92500114], [88.58167267, 21.92500114], [88.58194733, 21.92527962], [88.58277893, 21.92527771], [88.58333588, 21.92583275], [88.58416748, 21.92583084], [88.58444214, 21.92611122], [88.58499908, 21.92611122], [88.58528137, 21.92638969], [88.58555603, 21.92638969], [88.58583069, 21.92666435], [88.58583069, 21.92694664], [88.58611298, 21.92694664], [88.58611298, 21.92749023], [88.58638763, 21.92777634], [88.58638763, 21.92805099], [88.58555603, 21.92889023], [88.5847168, 21.92805099], [88.58472443, 21.92777634], [88.58416748, 21.92721939], [88.58333588, 21.9272213], [88.58305359, 21.92694664], [88.58249664, 21.92694664], [88.58222198, 21.92666435], [88.58194733, 21.92667007], [88.58167267, 21.92638969], [88.58139038, 21.92638969], [88.58110809, 21.92611122], [88.58082581, 21.92611122], [88.58055878, 21.92583084], [88.58027649, 21.92583275], [88.57917023, 21.92472267], [88.57917023, 21.92361069], [88.57888794, 21.92333031], [88.57888794, 21.92277718], [88.57861328, 21.92250061], [88.57861328, 21.92083168], [88.57888794, 21.92055511], [88.57888794, 21.92028046], [88.57917023, 21.92000008], [88.57917023, 21.9197216], [88.57944489, 21.91944504], [88.57943726, 21.91917038], [88.57971954, 21.91889191], [88.57971954, 21.91860771], [88.58000183, 21.91833305], [88.58000183, 21.91666794], [88.57943726, 21.91611099], [88.57943726, 21.91583061], [88.57777405, 21.9141655], [88.57776642, 21.91389084], [88.57639313, 21.91250992], [88.57639313, 21.91222], [88.57611084, 21.91194344], [88.57583618, 21.91195107], [88.57499695, 21.91110992], [88.57499695, 21.91083336], [88.57472229, 21.91055489], [88.57472229, 21.91027832], [88.57277679, 21.90833282], [88.57277679, 21.90805626], [88.57250214, 21.90777969], [88.57250214, 21.90722275], [88.57221985, 21.90722275], [88.57195282, 21.90750122], [88.5716629, 21.90749931], [88.5708313, 21.90833282], [88.5708313, 21.90860939], [88.57055664, 21.90888977], [88.57055664, 21.90917015], [88.56944275, 21.91028023], [88.56916809, 21.91027832], [88.5688858, 21.91055489], [88.5688858, 21.91083336], [88.56861115, 21.91111183], [88.56833649, 21.91110992], [88.56777954, 21.91167068], [88.56777954, 21.91195107], [88.56694794, 21.91278076], [88.56666565, 21.91277695], [88.5661087, 21.9133358], [88.56582642, 21.91333008], [88.5652771, 21.91389084], [88.56500244, 21.91389084], [88.56472015, 21.91417122], [88.56361389, 21.9141655], [88.5633316, 21.91444588], [88.5633316, 21.91472054], [88.56305695, 21.91500092], [88.56276703, 21.91472054], [88.56138611, 21.91611099], [88.56083679, 21.91611099], [88.56027985, 21.91666985], [88.5597229, 21.91666794], [88.55944824, 21.9169445], [88.55805206, 21.91694069], [88.55750275, 21.91749954], [88.55665588, 21.91749954], [88.55638885, 21.91777992], [88.55555725, 21.91777992], [88.55528259, 21.9180584], [88.55472565, 21.91805649], [88.5541687, 21.91861153], [88.55388641, 21.91860771], [88.5533371, 21.91917038], [88.55305481, 21.91916656], [88.55249786, 21.9197216], [88.55222321, 21.9197216], [88.55166626, 21.92028046], [88.5513916, 21.92028046], [88.55027771, 21.92139053], [88.55055237, 21.92168045], [88.55027771, 21.9216671], [88.55027771, 21.92194366], [88.55000305, 21.92222023], [88.55000305, 21.92527962], [88.55027771, 21.92556], [88.55027771, 21.92611122], [88.55055237, 21.92638969], [88.55055237, 21.92777634], [88.55082703, 21.92805099], [88.55082703, 21.92889023], [88.55110931, 21.9291687], [88.55110931, 21.92971992], [88.5513916, 21.93000031], [88.5513916, 21.93250084], [88.55110931, 21.93277931], [88.55110931, 21.93305588], [88.5513916, 21.93333244], [88.5513916, 21.9347229], [88.55110931, 21.93499947], [88.55110931, 21.93583107], [88.55082703, 21.93610954], [88.55083466, 21.93694305], [88.55055237, 21.93721962], [88.55055237, 21.93805313], [88.55027771, 21.9383297], [88.55027771, 21.93916512], [88.55000305, 21.93943024], [88.55000305, 21.94000053], [88.54972076, 21.94028091], [88.54972076, 21.94055748], [88.54944611, 21.94083023], [88.54944611, 21.94111061], [88.54833221, 21.9422226], [88.54833221, 21.94248962], [88.54805756, 21.94277954], [88.54805756, 21.94305611], [88.54777527, 21.94333267], [88.5477829, 21.94388962], [88.54750061, 21.94416618], [88.54750061, 21.94444466], [88.54722595, 21.94472122], [88.54722595, 21.94528008], [88.54694366, 21.94555473], [88.54693604, 21.94582939], [88.54638672, 21.94639015], [88.54638672, 21.94667053], [88.54611206, 21.94695282], [88.54611206, 21.94750023], [88.54582977, 21.94778061], [88.54582977, 21.9480629], [88.54528046, 21.94861984], [88.54528046, 21.94889069], [88.54499817, 21.94916725], [88.54499817, 21.94972038], [88.54471588, 21.95000076], [88.54472351, 21.9505558], [88.54444122, 21.95083237], [88.54444885, 21.95111084], [88.54416656, 21.95138931], [88.54416656, 21.95222092], [88.54389191, 21.95249939], [88.54389191, 21.95277977], [88.54360962, 21.95305443], [88.54360962, 21.95360947], [88.54332733, 21.95388985], [88.54332733, 21.95499992], [88.54305267, 21.95527649], [88.54305267, 21.95694351], [88.54277802, 21.95721817], [88.54277802, 21.95750046], [88.54250336, 21.95778084], [88.54250336, 21.96528053], [88.54277802, 21.96556091], [88.54277802, 21.96778107], [88.54305267, 21.96805763], [88.54305267, 21.96833038], [88.54332733, 21.96861076], [88.54332733, 21.96889114], [88.54360962, 21.96916962], [88.54360962, 21.97000122], [88.54389191, 21.97027969], [88.54389191, 21.97055817], [88.54499817, 21.97166824], [88.54528046, 21.97166634], [88.54582977, 21.97222137], [88.54638672, 21.97222137], [88.54666901, 21.97250175], [88.54777527, 21.97250175], [88.54788971, 21.9726162], [88.54805756, 21.97278976], [88.54916382, 21.97277832], [88.54944611, 21.97305489], [88.55166626, 21.97305489], [88.55194092, 21.97277832], [88.55222321, 21.97305489], [88.55555725, 21.97305489], [88.55583191, 21.97277832], [88.55638885, 21.97278976], [88.55665588, 21.97250175], [88.5569458, 21.97250175], [88.55722046, 21.97222137], [88.55750275, 21.97222137], [88.55916595, 21.97055626], [88.55916595, 21.97027969], [88.55944824, 21.97000122], [88.55944824, 21.96916962], [88.55999756, 21.96861076], [88.55999756, 21.96805954], [88.56027985, 21.96778107], [88.56027985, 21.96750069], [88.56054688, 21.96722031], [88.5605545, 21.96666527], [88.56083679, 21.9663887], [88.56083679, 21.96582985], [88.56111145, 21.96555328], [88.56111145, 21.96528053], [88.56138611, 21.96500015], [88.56138611, 21.96445084], [88.5616684, 21.96417046], [88.5616684, 21.96362114], [88.56223297, 21.96305275], [88.56222534, 21.96277809], [88.56276703, 21.96222115], [88.56277466, 21.96194458], [88.56305695, 21.96166611], [88.56305695, 21.96111107], [88.5633316, 21.9608326], [88.5633316, 21.96055603], [88.56360626, 21.96027946], [88.56388855, 21.96027946], [88.56388855, 21.95999908], [88.56416321, 21.95972061], [88.5644455, 21.95972252], [88.56472015, 21.95944405], [88.56500244, 21.95944405], [88.56583405, 21.95861053], [88.5661087, 21.95861053], [88.56667328, 21.95805931], [88.56749725, 21.9580555], [88.56777954, 21.95832825], [88.56777954, 21.95889091], [88.56716919, 21.95916939], [88.5667038, 21.95952034], [88.566185, 21.9598999], [88.56562042, 21.96030426], [88.56508636, 21.96072006], [88.56468964, 21.96116066], [88.56439972, 21.96157837], [88.56414795, 21.9619503], [88.56389618, 21.96232986], [88.56365204, 21.96274948], [88.56343842, 21.96322823], [88.56327057, 21.96375084], [88.56305695, 21.96424103], [88.56285095, 21.96469879], [88.56269836, 21.96516037], [88.56253815, 21.96559715], [88.56240082, 21.96601486], [88.56223297, 21.96639442], [88.56204987, 21.96677017], [88.56186676, 21.96719551], [88.56165314, 21.96763992], [88.56138611, 21.96811104], [88.56111908, 21.96860123], [88.56088257, 21.96907997], [88.56070709, 21.96955109], [88.56050873, 21.96998978], [88.56025696, 21.97041512], [88.55995178, 21.97088051], [88.5595932, 21.97139931], [88.55914307, 21.97193718], [88.55866241, 21.97245216], [88.5581665, 21.97289467], [88.55767059, 21.9732399], [88.55721283, 21.97352028], [88.55679321, 21.97372818], [88.55634308, 21.97392082], [88.55586243, 21.97407913], [88.55531311, 21.97418594], [88.55476379, 21.97431374], [88.55417633, 21.97439957], [88.55362701, 21.97451019], [88.55309296, 21.97454071], [88.55251312, 21.97450066], [88.55198669, 21.97434807], [88.55145264, 21.9742012], [88.55090332, 21.97407913], [88.550354, 21.97399712], [88.54981232, 21.9739399], [88.54928589, 21.97385979], [88.54875946, 21.97384071], [88.54825592, 21.97382164], [88.54776001, 21.97382164], [88.54725647, 21.97377968], [88.54676056, 21.97363091], [88.54624939, 21.97348976], [88.54579163, 21.97331047], [88.54535675, 21.97310066], [88.54495239, 21.97285271], [88.54454041, 21.97258186], [88.54412842, 21.97229958], [88.54370117, 21.97200012], [88.54331207, 21.97161293], [88.54296112, 21.97113037], [88.54263306, 21.97063065], [88.54241943, 21.97005081], [88.54223633, 21.96953011], [88.54209137, 21.96904945], [88.54192352, 21.96863365], [88.54171753, 21.96823883], [88.54155731, 21.96778107], [88.54138947, 21.96730042], [88.54119873, 21.96683311], [88.54109192, 21.96633911], [88.54109192, 21.96585655], [88.54110718, 21.9654007], [88.54110718, 21.96494102], [88.54108429, 21.96445656], [88.54097748, 21.96391869], [88.5409317, 21.9633503], [88.54100037, 21.96276474], [88.54105377, 21.96214485], [88.54104614, 21.96150589], [88.54096222, 21.96086121], [88.54088593, 21.96021271], [88.54095459, 21.95957375], [88.54103851, 21.9589386], [88.54107666, 21.95829964], [88.54112244, 21.95766068], [88.54117584, 21.95702934], [88.54128265, 21.95640945], [88.54137421, 21.95580482], [88.54138947, 21.95520782], [88.54138947, 21.95465088], [88.54141235, 21.95416069], [88.54155731, 21.95372963], [88.54176331, 21.95334435], [88.54200745, 21.95295906], [88.54218292, 21.95248985], [88.54227448, 21.95196724], [88.5424118, 21.9514904], [88.54245758, 21.95100021], [88.54255676, 21.95054626], [88.54270172, 21.95009041], [88.54286194, 21.94959068], [88.54307556, 21.94909286], [88.54333496, 21.94860649], [88.54360199, 21.9481411], [88.54386902, 21.94767952], [88.54412079, 21.94721603], [88.54431152, 21.94670105], [88.54456329, 21.94621086], [88.5448761, 21.94581223], [88.5451355, 21.94540977], [88.54537201, 21.94503784], [88.54560089, 21.94470024], [88.54582977, 21.94436646], [88.54605103, 21.94400978], [88.54621887, 21.94360161], [88.54641724, 21.9431839], [88.54666138, 21.94278717], [88.54690552, 21.94241333], [88.54711151, 21.9420433], [88.54730225, 21.94171333], [88.54749298, 21.94143295], [88.54769135, 21.94117355], [88.54784393, 21.94090462], [88.54800415, 21.9406414], [88.54808807, 21.94035721], [88.54821777, 21.94010162], [88.54839325, 21.93980026], [88.5485611, 21.93949318], [88.54866791, 21.93909073], [88.54882813, 21.93868446], [88.54891205, 21.93817329], [88.54904175, 21.93761635], [88.5491333, 21.93700981], [88.54911041, 21.93634033], [88.54911041, 21.93567467], [88.54916382, 21.93501663], [88.54924011, 21.93434906], [88.54940796, 21.9336071], [88.54940033, 21.93283844], [88.54916382, 21.93216515], [88.54892731, 21.93152046], [88.54888916, 21.93086243], [88.54892731, 21.93019104], [88.54905701, 21.92950058], [88.54907227, 21.92880058], [88.54891205, 21.92813301], [88.54875183, 21.9274559], [88.54854584, 21.92687988], [88.54837799, 21.92629051], [88.54838562, 21.92572975], [88.54853058, 21.92521095], [88.54844666, 21.92463112], [88.54857635, 21.92414093], [88.54860687, 21.92366982], [88.54860687, 21.92321014], [88.54862213, 21.92274094], [88.54866791, 21.92227936], [88.54884338, 21.9218483], [88.54902649, 21.92142296], [88.549263, 21.92098999], [88.54947662, 21.92054939], [88.54972839, 21.9201107], [88.55000305, 21.91966057], [88.55024719, 21.91918945], [88.55046082, 21.9187336], [88.55079651, 21.9184761], [88.5511322, 21.91820145], [88.55150604, 21.91794014], [88.55195618, 21.91770744], [88.55243683, 21.91747093], [88.55293274, 21.91720581], [88.55342102, 21.91691589], [88.55391693, 21.91664124], [88.55444336, 21.91637993], [88.55493164, 21.91610336], [88.55541229, 21.9158287], [88.55584717, 21.91555023], [88.55625916, 21.91530418], [88.55667877, 21.9151268], [88.55709076, 21.9149704], [88.55745697, 21.91479111], [88.55789185, 21.91468239], [88.55828094, 21.91447067], [88.55871582, 21.91433144], [88.55912018, 21.91415977], [88.55953979, 21.91401482], [88.56007385, 21.91402435], [88.56069946, 21.91387177], [88.56128693, 21.91361237], [88.5618515, 21.91331482], [88.56234741, 21.91294289], [88.56273651, 21.91253853], [88.56299591, 21.91204834], [88.56338501, 21.9117527], [88.5638504, 21.91153526], [88.56429291, 21.9112606], [88.56472015, 21.91097069], [88.56513977, 21.91068268], [88.56550598, 21.91036987], [88.56604767, 21.91026115], [88.56661224, 21.91008949], [88.5671463, 21.90975571], [88.56761169, 21.90928078], [88.56815338, 21.90884018], [88.56856537, 21.90837288], [88.56887817, 21.90786552], [88.56916809, 21.90731239], [88.56948853, 21.90676308], [88.56983185, 21.90626144], [88.57009125, 21.90574265], [88.5703125, 21.90525627], [88.57052612, 21.90483093], [88.57058716, 21.90442085], [88.57064819, 21.90401459], [88.57054138, 21.90360832], [88.57032776, 21.90324974], [88.57008362, 21.90290833], [88.56968689, 21.90262032], [88.56922913, 21.90228081], [88.56878662, 21.90183258], [88.56815338, 21.90146065], [88.56756592, 21.90109634], [88.56703949, 21.90069962], [88.56659698, 21.9003315], [88.56613159, 21.8999958], [88.56565857, 21.89968872], [88.56519318, 21.89940643], [88.56475067, 21.89919853], [88.5643158, 21.89908028], [88.56391144, 21.89895058], [88.56343842, 21.89888954], [88.56291962, 21.89888], [88.56239319, 21.89888], [88.56186676, 21.89891052], [88.56139374, 21.89898682], [88.56095886, 21.89910126], [88.56048584, 21.89921951], [88.56004333, 21.89938927], [88.55954742, 21.89953041], [88.55908966, 21.8997364], [88.55863953, 21.89995193], [88.55814362, 21.90011215], [88.55773163, 21.90032005], [88.55737305, 21.90056992], [88.55702209, 21.90083885], [88.5566864, 21.9011116], [88.55635071, 21.90138054], [88.55597687, 21.9016304], [88.55555725, 21.90180969], [88.55510712, 21.90199089], [88.55472565, 21.90222549], [88.55435181, 21.90248108], [88.55394745, 21.90270805], [88.55350494, 21.90288544], [88.55304718, 21.90304947], [88.5526123, 21.90321541], [88.55218506, 21.90340233], [88.55178833, 21.90360832], [88.55140686, 21.9038372], [88.55097198, 21.90395164], [88.55055237, 21.90413094], [88.55010223, 21.90424728], [88.54966736, 21.90445328], [88.54925537, 21.90468979], [88.54882813, 21.90486908], [88.54838562, 21.90500069], [88.54795837, 21.90512466], [88.54754639, 21.9052906], [88.54714203, 21.90549088], [88.54665375, 21.90560722], [88.54615021, 21.90577126], [88.54560089, 21.90588951], [88.54504395, 21.90604019], [88.54445648, 21.90608215], [88.54386902, 21.90602875], [88.54335785, 21.90584183], [88.54286957, 21.90561104], [88.54244232, 21.90533066], [88.54201508, 21.90506172], [88.54163361, 21.90474129], [88.54125214, 21.90445328], [88.5408783, 21.90418625], [88.54055786, 21.90386963], [88.54027557, 21.90348625], [88.54000092, 21.90304947], [88.53972626, 21.90257835], [88.53949738, 21.90211105], [88.5393219, 21.90163994], [88.53920746, 21.90117073], [88.5391922, 21.90068054], [88.53926849, 21.90021515], [88.53939819, 21.89978027], [88.53949738, 21.89935112], [88.53968811, 21.8989296], [88.53992462, 21.89852142], [88.54019165, 21.89813995], [88.54048157, 21.89777946], [88.54078674, 21.89743996], [88.54107666, 21.89709091], [88.54139709, 21.89675331], [88.54174805, 21.8964138], [88.54216003, 21.89608383], [88.54264832, 21.89577866], [88.54332733, 21.8956604], [88.54363251, 21.89529991], [88.54392242, 21.8948822], [88.54431915, 21.89447975], [88.54480743, 21.89415169], [88.54534149, 21.89385033], [88.54582977, 21.89350128], [88.54615021, 21.89286041], [88.54650116, 21.89228821], [88.54683685, 21.89179039], [88.54714203, 21.89136124], [88.54737854, 21.89096069], [88.54756165, 21.89049911], [88.54772186, 21.89001083], [88.54775238, 21.88940048], [88.54772949, 21.888731], [88.54776001, 21.88803291], [88.54777527, 21.88735771], [88.5477829, 21.88670158], [88.5477829, 21.8860817], [88.54777527, 21.88552094], [88.54780579, 21.88500595], [88.54792023, 21.88454819], [88.54802704, 21.88405991], [88.54807281, 21.88348007], [88.54806519, 21.88286591], [88.5480423, 21.88224983], [88.54792786, 21.88169098], [88.54776764, 21.88119125], [88.54753876, 21.88075066], [88.54745483, 21.88056183], [88.54733276, 21.8802948], [88.54708099, 21.87986183], [88.54682922, 21.87943077], [88.54659271, 21.8789711], [88.5462265, 21.87860107], [88.54585266, 21.87821007], [88.5454483, 21.87778282], [88.54499817, 21.8773613], [88.54452515, 21.87697029], [88.54402161, 21.87665939], [88.5435791, 21.87631989], [88.54327393, 21.87587738], [88.54289246, 21.87559128], [88.5424881, 21.87533951], [88.54206085, 21.87509155], [88.54154205, 21.87494087], [88.54110718, 21.87471962], [88.54111481, 21.87444687], [88.5402832, 21.87360954], [88.54027557, 21.87333298], [88.54000092, 21.87306023], [88.54000092, 21.87277985], [88.53943634, 21.87222099], [88.53944397, 21.87194443], [88.53916931, 21.87166405], [88.53916931, 21.87138939], [88.53888702, 21.87111092], [88.53888702, 21.87055969], [88.53861237, 21.87026978], [88.53888702, 21.87000084], [88.53888702, 21.86972046], [88.53861237, 21.86944389], [88.53861237, 21.86833382], [88.53833008, 21.86805534], [88.53832245, 21.86639023], [88.53888702, 21.86583138], [88.53888702, 21.86361122], [88.53909302, 21.86361122], [88.53916931, 21.86361122], [88.53916931, 21.86333084], [88.5390625, 21.86322594], [88.53887939, 21.86299515], [88.53868103, 21.8614502], [88.53810883, 21.85943031], [88.53781891, 21.85802078], [88.53710938, 21.85775948], [88.53694153, 21.85695076], [88.53666687, 21.85667038], [88.53610992, 21.85667038], [88.53569794, 21.85639], [88.53526306, 21.85623169], [88.53483582, 21.8561306], [88.53440094, 21.85610008], [88.53395081, 21.85605431], [88.53351593, 21.85594749], [88.5330658, 21.85584068], [88.53262329, 21.85576439], [88.53223419, 21.85557365], [88.53181458, 21.85542488], [88.53166962, 21.85527039], [88.53138733, 21.85527802], [88.53111267, 21.85499954], [88.53083038, 21.85499954], [88.53056335, 21.85472107], [88.53028107, 21.85472107], [88.52944183, 21.85388947], [88.52916718, 21.85388947], [88.52861023, 21.8533287], [88.52833557, 21.85333252], [88.52805328, 21.85305595], [88.52749634, 21.85305595], [88.52713013, 21.85326958], [88.5266571, 21.8535099], [88.52600098, 21.85345268], [88.52548981, 21.85362244], [88.52507019, 21.85387039], [88.52466583, 21.85414124], [88.52424622, 21.85441971], [88.52379608, 21.85469055], [88.52333069, 21.85496712], [88.52287292, 21.85526085], [88.52240753, 21.85555267], [88.52194977, 21.85583115], [88.52147675, 21.85611916], [88.52102661, 21.85642815], [88.52069092, 21.8568306], [88.52046204, 21.85731125], [88.52024078, 21.85780144], [88.5199585, 21.85823059], [88.51959991, 21.85859108], [88.51918793, 21.85890007], [88.51882172, 21.85923958], [88.51836395, 21.85951424], [88.51793671, 21.85981941], [88.51751709, 21.86014366], [88.51709747, 21.86049461], [88.51659393, 21.86078453], [88.51599884, 21.8610096], [88.51551056, 21.86139107], [88.5150528, 21.86181831], [88.51461029, 21.86232185], [88.51410675, 21.86276054], [88.51354218, 21.86314774], [88.51304626, 21.86359215], [88.51243591, 21.86397171], [88.51189423, 21.86442947], [88.51132965, 21.86487007], [88.51071167, 21.86524963], [88.51009369, 21.86558914], [88.50971985, 21.86606979], [88.50935364, 21.86657524], [88.50886536, 21.86701012], [88.50831604, 21.86746025], [88.50775909, 21.86791039], [88.507164, 21.86828423], [88.50655365, 21.86856651], [88.50592041, 21.86874008], [88.50533295, 21.86893272], [88.50489044, 21.86925125], [88.50450134, 21.86953545], [88.50411224, 21.8697834], [88.50373077, 21.87000084], [88.50337219, 21.8702507], [88.50306702, 21.87055016], [88.5027771, 21.87088966], [88.50244904, 21.87122536], [88.50201416, 21.87149239], [88.50160217, 21.87185478], [88.50112915, 21.87215996], [88.50067902, 21.87248039], [88.50022888, 21.87276077], [88.49980927, 21.87298965], [88.4994278, 21.87324524], [88.4990387, 21.87350273], [88.49858093, 21.87371063], [88.49830627, 21.87404823], [88.4980545, 21.87438965], [88.49781799, 21.87471008], [88.49759674, 21.875], [88.49740601, 21.87525558], [88.49719238, 21.87547112], [88.49694824, 21.87567902], [88.49669647, 21.87594032], [88.49645996, 21.87631035], [88.49616241, 21.8766861], [88.49607086, 21.87680054], [88.49584961, 21.87708092], [88.49555206, 21.87747955], [88.49520111, 21.8778019], [88.49487305, 21.87817001], [88.49452209, 21.87858009], [88.4942627, 21.87909126], [88.4941864, 21.87973022], [88.49419403, 21.88037872], [88.4942627, 21.88100433], [88.49441528, 21.88158417], [88.49447632, 21.88215065], [88.49466705, 21.88270187], [88.49475861, 21.88326073], [88.49497986, 21.88371086], [88.49514008, 21.88415909], [88.49525452, 21.88458633], [88.49529266, 21.88500977], [88.49533844, 21.88539124], [88.49549866, 21.88572311], [88.49559784, 21.8860817], [88.49581909, 21.88639069], [88.4961319, 21.88668823], [88.49648285, 21.88701057], [88.49684906, 21.88726997], [88.49714661, 21.88756943], [88.49738312, 21.88793945], [88.49762726, 21.88833809], [88.49788666, 21.888731], [88.49814606, 21.8891201], [88.49842072, 21.88948059], [88.49859619, 21.88990974], [88.49872589, 21.89036179], [88.49897766, 21.89068985], [88.49919891, 21.89104462], [88.49945068, 21.89141464], [88.49971771, 21.89179993], [88.50001526, 21.89219856], [88.50042725, 21.89249039], [88.50089264, 21.89274979], [88.50132751, 21.89301109], [88.50164795, 21.89333153], [88.50189972, 21.89363098], [88.50211334, 21.89390945], [88.50226593, 21.89418983], [88.50250244, 21.89444351], [88.5027771, 21.89472008], [88.50305176, 21.89472008], [88.50305176, 21.89500046], [88.50332642, 21.89528275], [88.50332642, 21.89556122], [88.50389099, 21.89611053], [88.50389099, 21.89638901], [88.5047226, 21.89722061], [88.5047226, 21.89751053], [88.50499725, 21.89777946], [88.50499725, 21.89805412], [88.50527954, 21.89833069], [88.50527954, 21.89861107], [88.50554657, 21.89894295], [88.50572968, 21.89936066], [88.505867, 21.89978981], [88.50605774, 21.90016937], [88.50614166, 21.90063095], [88.5063324, 21.90109634], [88.50641632, 21.90167046], [88.50666809, 21.90221977], [88.50695038, 21.90275955], [88.50728607, 21.90324974], [88.50769043, 21.90366364], [88.50806427, 21.90410233], [88.50846863, 21.9045105], [88.50887299, 21.9049511], [88.50924683, 21.9054451], [88.50975037, 21.90586472], [88.51026917, 21.90625954], [88.51079559, 21.90660858], [88.51138306, 21.90681267], [88.51190948, 21.90700912], [88.51239777, 21.90723991], [88.51287079, 21.90752029], [88.51329041, 21.90788078], [88.51361847, 21.90835953], [88.51418304, 21.90858078], [88.51483917, 21.90858841], [88.51530457, 21.90879822], [88.51571655, 21.9090004], [88.51612091, 21.90923691], [88.51652527, 21.90946007], [88.51690674, 21.90973091], [88.51727295, 21.91007042], [88.5176239, 21.91040802], [88.51802826, 21.91073036], [88.51859283, 21.91085052], [88.51909637, 21.91100121], [88.51951599, 21.9113102], [88.51998138, 21.91158676], [88.520401, 21.91193962], [88.52081299, 21.91234016], [88.52115631, 21.91279984], [88.52146149, 21.91327858], [88.52177429, 21.91374207], [88.52197266, 21.91426086], [88.5222168, 21.91472816], [88.52246857, 21.91518021], [88.52262878, 21.91567993], [88.52281952, 21.91614151], [88.52305603, 21.91657257], [88.52328491, 21.91700363], [88.52335358, 21.9174633], [88.52349854, 21.91791916], [88.52366638, 21.91843033], [88.52384186, 21.91894913], [88.52391815, 21.91955948], [88.52390289, 21.92025948], [88.52411652, 21.92084122], [88.52426147, 21.92139816], [88.52436066, 21.92192078], [88.5243988, 21.92243958], [88.5243454, 21.92297745], [88.52411652, 21.92361069], [88.52429199, 21.92412567], [88.52451324, 21.92468071], [88.52465057, 21.92526054], [88.52474213, 21.92584038], [88.52489471, 21.92637825], [88.5250473, 21.92688942], [88.52524567, 21.92746544], [88.52529907, 21.92809486], [88.52542114, 21.92875481], [88.52553558, 21.92944145], [88.5255127, 21.9301548], [88.52532196, 21.93082809], [88.52527618, 21.93152809], [88.52527618, 21.93218994], [88.52527618, 21.93280029], [88.5252533, 21.93334961], [88.52509308, 21.933815], [88.52497101, 21.93427277], [88.5247879, 21.93468666], [88.52472687, 21.93512917], [88.52466583, 21.93558121], [88.52448273, 21.93596268], [88.52440643, 21.9364109], [88.52420807, 21.93678093], [88.52404785, 21.93717003], [88.52390289, 21.93756866], [88.52381897, 21.93799019], [88.52362823, 21.93837929], [88.52349854, 21.93884087], [88.52333832, 21.93934822], [88.52319336, 21.93987274], [88.52310181, 21.9403801], [88.52280426, 21.94076538], [88.52256012, 21.94118118], [88.52236938, 21.94166946], [88.52211761, 21.94218254], [88.52172089, 21.94268036], [88.52124786, 21.94319916], [88.52065277, 21.94369698], [88.52005005, 21.94421005], [88.51946259, 21.9447403], [88.51889801, 21.94527054], [88.51834106, 21.94569588], [88.51784515, 21.94605446], [88.51748657, 21.94637108], [88.51716614, 21.94660187], [88.51685333, 21.94674683], [88.51660156, 21.94692039], [88.51628876, 21.94704056], [88.5160675, 21.94723892], [88.51584625, 21.9474411], [88.51557159, 21.94759941], [88.51526642, 21.94776917], [88.51486969, 21.9479599], [88.514328, 21.94812584], [88.51374817, 21.94837189], [88.51317596, 21.94872093], [88.51275635, 21.94922066], [88.51228333, 21.94964027], [88.51171875, 21.94981956], [88.51122284, 21.95003128], [88.51077271, 21.95028114], [88.51036072, 21.95055008], [88.50993347, 21.9508152], [88.50970459, 21.95094299], [88.50949097, 21.95106125], [88.50907898, 21.95133972], [88.50860596, 21.95153618], [88.50813293, 21.95173073], [88.50771332, 21.95199966], [88.50727081, 21.95223045], [88.50683594, 21.95248985], [88.50637817, 21.95267677], [88.50588989, 21.95284271], [88.50543976, 21.95306396], [88.50499725, 21.95330048], [88.50448608, 21.95344162], [88.5039978, 21.95363045], [88.50351715, 21.95386124], [88.50295258, 21.95387077], [88.50234985, 21.95381737], [88.50179291, 21.95396042], [88.50128937, 21.9542408], [88.50077057, 21.95447159], [88.50028992, 21.95474052], [88.49984741, 21.95505333], [88.49938202, 21.95534325], [88.49887848, 21.9555912], [88.49833679, 21.95583534], [88.49777985, 21.95611382], [88.49723053, 21.95643997], [88.49668884, 21.95680618], [88.4961853, 21.95719337], [88.49564362, 21.95748329], [88.49510193, 21.95770836], [88.49465179, 21.95804024], [88.49423981, 21.958395], [88.49398804, 21.95870972], [88.49389648, 21.95882607], [88.49360657, 21.95929909], [88.49334717, 21.95981026], [88.49318695, 21.96038628], [88.4930191, 21.96100044], [88.49281311, 21.96162033], [88.49278259, 21.96228981], [88.49277496, 21.96299744], [88.49279785, 21.96368217], [88.49290466, 21.96431351], [88.49301147, 21.96487808], [88.49320221, 21.96530914], [88.49334717, 21.96569252], [88.49349213, 21.96602058], [88.49359894, 21.96635056], [88.49364471, 21.96668816], [88.49369812, 21.96705246], [88.4938736, 21.96740532], [88.49404144, 21.96778488], [88.49420166, 21.96817017], [88.49442291, 21.9684906], [88.49461365, 21.96879959], [88.49478149, 21.96912193], [88.49499512, 21.96943855], [88.49520874, 21.96977997], [88.49539948, 21.97018814], [88.49559784, 21.97063255], [88.49585724, 21.97108078], [88.49614716, 21.97150993], [88.49649811, 21.97185516], [88.49677277, 21.97223282], [88.49701691, 21.97260094], [88.49731445, 21.97288895], [88.49754333, 21.97323036], [88.49778748, 21.9735775], [88.49804688, 21.9739399], [88.49832916, 21.97434616], [88.49861145, 21.97474098], [88.498909, 21.97512054], [88.49925232, 21.97541046], [88.49960327, 21.97574043], [88.49995422, 21.97606087], [88.50038147, 21.97637177], [88.50086975, 21.97668457], [88.50138092, 21.97707367], [88.50188446, 21.97753334], [88.50239563, 21.97804451], [88.50296021, 21.97850037], [88.50354004, 21.97887993], [88.50408936, 21.97919464], [88.50453949, 21.97956467], [88.50501251, 21.9799099], [88.50550842, 21.98021889], [88.50603485, 21.98046112], [88.50623322, 21.98052788], [88.50656891, 21.98064041], [88.50702667, 21.9808712], [88.50744629, 21.98112106], [88.50785065, 21.98139], [88.50824738, 21.98166084], [88.50868225, 21.98188591], [88.50915527, 21.98206139], [88.50965118, 21.98225975], [88.51008606, 21.98250961], [88.51053619, 21.98278046], [88.51097107, 21.98303986], [88.51142883, 21.98326111], [88.51190948, 21.9834404], [88.51235199, 21.98366547], [88.51278687, 21.98393059], [88.51325226, 21.98420715], [88.5136261, 21.98448753], [88.51370239, 21.98454475], [88.51415253, 21.98488998], [88.51456451, 21.98525047], [88.51495361, 21.98555183], [88.51528931, 21.98579216], [88.51563263, 21.9858799], [88.51584625, 21.98610115], [88.51608276, 21.98630905], [88.5164566, 21.98648834], [88.51674652, 21.98678207], [88.5170517, 21.9870739], [88.51746368, 21.98729324], [88.51772308, 21.98743248], [88.5178833, 21.98752022], [88.51824951, 21.98779106], [88.51863861, 21.98804092], [88.51911926, 21.9882431], [88.51976013, 21.98830032], [88.52043152, 21.98830986], [88.52108765, 21.98830986], [88.52175903, 21.98830986], [88.52246094, 21.98830032], [88.52312469, 21.9882679], [88.5236969, 21.98817825], [88.52420807, 21.98801041], [88.5246582, 21.98776054], [88.52511597, 21.98749352], [88.52557373, 21.98721695], [88.52604675, 21.98693085], [88.52651215, 21.98660278], [88.5269165, 21.98616982], [88.52732086, 21.98570251], [88.52771759, 21.98522186], [88.52809143, 21.98474121], [88.5284729, 21.98430061], [88.52868652, 21.98407173], [88.52884674, 21.98390007], [88.52926636, 21.98352242], [88.52973938, 21.98315048], [88.53023529, 21.98278618], [88.53073883, 21.98241997], [88.53119659, 21.98200035], [88.53167725, 21.98158073], [88.53217316, 21.98117065], [88.53266907, 21.98079681], [88.53315735, 21.98043823], [88.53366852, 21.98020935], [88.53416443, 21.97998047], [88.53463745, 21.97974968], [88.53508759, 21.97956276], [88.53551483, 21.97941399], [88.5358963, 21.97925949], [88.53627014, 21.97911072], [88.53662109, 21.97894287], [88.53702545, 21.97880554], [88.5375061, 21.9786911], [88.53806305, 21.97864914], [88.53861237, 21.97870827], [88.53910828, 21.97887039], [88.53957367, 21.97905731], [88.53999329, 21.97929382], [88.54043579, 21.97954941], [88.54091644, 21.97980118], [88.54138947, 21.98007011], [88.54177856, 21.98035049], [88.54210663, 21.98066521], [88.54239655, 21.98100281], [88.54270172, 21.98133087], [88.54299927, 21.98165512], [88.5433197, 21.98199463], [88.54360199, 21.98236465], [88.54384613, 21.98275566], [88.54403687, 21.98314095], [88.54426575, 21.98348808], [88.54450226, 21.98381042], [88.54473877, 21.98414993], [88.54496002, 21.98448563], [88.54515839, 21.98487282], [88.54537201, 21.98529053], [88.54561615, 21.98576927], [88.54585266, 21.98636818], [88.54608917, 21.98699951], [88.54629517, 21.98761749], [88.54651642, 21.98818016], [88.54672241, 21.98866081], [88.54691315, 21.98907852], [88.54702759, 21.98945045], [88.54717255, 21.98977089], [88.54727936, 21.99010277], [88.54740906, 21.99043274], [88.5475769, 21.99077988], [88.54779816, 21.99115753], [88.54799652, 21.99158287], [88.54818726, 21.99204063], [88.54840088, 21.99251938], [88.54862976, 21.99303055], [88.54885101, 21.99355888], [88.5490799, 21.99407959], [88.54933167, 21.99459839], [88.54959106, 21.995121], [88.54979706, 21.99566269], [88.54998016, 21.99620628], [88.55013275, 21.9967308], [88.55029297, 21.99724007], [88.55045319, 21.99777031], [88.55056763, 21.99840546], [88.55062103, 21.99913025], [88.55083466, 22.00000191], [88.5509491, 22.00146294], [88.5509491, 22.00341606], [88.55108643, 22.00642967], [88.55108643, 22.00851059], [88.55195618, 22.01145935], [88.55317688, 22.01407051], [88.55412292, 22.01641083], [88.55548096, 22.01930046], [88.5559845, 22.02083778], [88.556633, 22.02318001], [88.556633, 22.02713966], [88.5565567, 22.02820969], [88.55612946, 22.03022003], [88.55548096, 22.03230095], [88.55504608, 22.03396988], [88.55490112, 22.03470993], [88.55476379, 22.03517532], [88.55476379, 22.03544426], [88.55461884, 22.03570938], [88.55440521, 22.03531265], [88.55440521, 22.03396988], [88.55447388, 22.03323364], [88.55461884, 22.03256226], [88.55483246, 22.03182793], [88.55504608, 22.03136063], [88.55526733, 22.03075027], [88.555336, 22.03021812], [88.55548096, 22.02927017], [88.55562592, 22.02807426], [88.55576324, 22.02747154], [88.55583954, 22.02713585], [88.55583954, 22.02652931], [88.55548096, 22.02559662], [88.555336, 22.02445602], [88.555336, 22.02379036], [88.55526733, 22.02284813], [88.55490112, 22.02178001], [88.55446625, 22.02043915], [88.55432892, 22.01976967], [88.554039, 22.01883125], [88.55377197, 22.01828957], [88.55361176, 22.01782227], [88.55303955, 22.01675034], [88.55268097, 22.01614952], [88.55224609, 22.01540947], [88.55181122, 22.01480675], [88.55137634, 22.01412964], [88.55117035, 22.01366806], [88.55103302, 22.01300049], [88.5507431, 22.01226044], [88.55045319, 22.01158905], [88.55023193, 22.01106262], [88.55016327, 22.00978088], [88.54987335, 22.00890923], [88.54959106, 22.00811005], [88.54936981, 22.00743103], [88.54936981, 22.0057621], [88.54944611, 22.00368309], [88.54944611, 22.00000191], [88.54943848, 21.99940109], [88.54930115, 21.99881935], [88.5491333, 21.99825096], [88.5489502, 21.99769974], [88.54876709, 21.99712944], [88.54858398, 21.9965744], [88.54838562, 21.99603271], [88.5482254, 21.99550629], [88.54805756, 21.99502945], [88.54788971, 21.99457169], [88.54769135, 21.99410439], [88.54745483, 21.9936409], [88.54720306, 21.99316025], [88.54697418, 21.99267387], [88.54675293, 21.99218178], [88.54654694, 21.99171829], [88.54634094, 21.99128914], [88.54613495, 21.99086571], [88.54595947, 21.99044037], [88.54579926, 21.99001694], [88.54561615, 21.98957253], [88.54547119, 21.98910332], [88.5452652, 21.98865509], [88.54503632, 21.98821068], [88.54483032, 21.98779106], [88.54467773, 21.98732948], [88.54450989, 21.98689079], [88.5443573, 21.98644829], [88.54416656, 21.98603821], [88.54395294, 21.98558998], [88.54371643, 21.98513985], [88.54342651, 21.98471069], [88.54318237, 21.98427963], [88.54297638, 21.98387146], [88.54277802, 21.98351669], [88.54260254, 21.98319817], [88.5424118, 21.98291969], [88.54218292, 21.98265076], [88.54194641, 21.98236084], [88.54170227, 21.98203087], [88.54141998, 21.98171043], [88.54110718, 21.98139954], [88.54078674, 21.98109055], [88.54043579, 21.98077965], [88.54006958, 21.98053551], [88.53970337, 21.9803009], [88.53933716, 21.98011017], [88.53894043, 21.98000336], [88.53851318, 21.9799614], [88.53805542, 21.97995186], [88.53761292, 21.97997284], [88.53717804, 21.98003006], [88.53678131, 21.98015022], [88.53636169, 21.98031235], [88.53586578, 21.98047638], [88.53536224, 21.98069], [88.53489685, 21.98092079], [88.53442383, 21.98116493], [88.53395081, 21.98142052], [88.53350067, 21.9817028], [88.53305054, 21.98199081], [88.53266907, 21.98233032], [88.53233337, 21.98269081], [88.53199768, 21.98306847], [88.53170776, 21.9834404], [88.53141785, 21.98384285], [88.53106689, 21.98421288], [88.53068542, 21.98458862], [88.53031158, 21.98497963], [88.52996826, 21.98541069], [88.52959442, 21.98582458], [88.52916718, 21.98621941], [88.52869415, 21.98661041], [88.52813721, 21.98696327], [88.527565, 21.98732948], [88.52702332, 21.98773956], [88.52646637, 21.98813057], [88.52593994, 21.9885273], [88.525383, 21.9888401], [88.52481079, 21.9890995], [88.52424622, 21.98929024], [88.52363586, 21.98938942], [88.52301788, 21.98939705], [88.52243042, 21.98941994], [88.52178955, 21.98947525], [88.52133942, 21.98947906], [88.52104187, 21.98948479], [88.52035522, 21.98944283], [88.51983643, 21.98924255], [88.51946259, 21.98887062], [88.51925659, 21.98858833], [88.51876068, 21.98858833], [88.51812744, 21.98874283], [88.5175705, 21.98872757], [88.51721954, 21.98861122], [88.51714325, 21.98856926], [88.5167923, 21.9883709], [88.51641083, 21.98816109], [88.51599121, 21.98789978], [88.51545715, 21.98764992], [88.51480103, 21.98725128], [88.51410675, 21.98688126], [88.51348114, 21.98655128], [88.51287842, 21.98633957], [88.51239014, 21.98610115], [88.51198578, 21.98584175], [88.51159668, 21.98558998], [88.51122284, 21.98541069], [88.51082611, 21.98530006], [88.51048279, 21.98514938], [88.51026154, 21.98475075], [88.50991058, 21.98441124], [88.50937653, 21.98415947], [88.50884247, 21.98392105], [88.50831604, 21.98368835], [88.50784302, 21.98343849], [88.50731659, 21.98324013], [88.50679016, 21.98303032], [88.50627136, 21.98277092], [88.5057373, 21.98248672], [88.50518799, 21.98215103], [88.50460052, 21.98181915], [88.50401306, 21.98149109], [88.50350189, 21.98109055], [88.50302887, 21.98068047], [88.50247955, 21.98032951], [88.50189972, 21.9799614], [88.50135803, 21.97947311], [88.50076294, 21.97902489], [88.50016022, 21.97857285], [88.49964142, 21.97803116], [88.49913025, 21.97748184], [88.49859619, 21.97696114], [88.49807739, 21.9764595], [88.49763489, 21.97597313], [88.4972229, 21.97556114], [88.49681854, 21.97520256], [88.49651337, 21.97480965], [88.49616241, 21.9744606], [88.49584198, 21.9740696], [88.49555206, 21.97364998], [88.49525452, 21.9732666], [88.49489594, 21.97291946], [88.49471283, 21.97242928], [88.49446869, 21.97198486], [88.49419403, 21.97156906], [88.49391174, 21.97116089], [88.49359131, 21.97079277], [88.49331665, 21.97034073], [88.49305725, 21.96988106], [88.49281311, 21.96940994], [88.49262238, 21.96891022], [88.49241638, 21.96841049], [88.49217987, 21.9679203], [88.49186707, 21.96742058], [88.49156952, 21.96689034], [88.4914093, 21.96623993], [88.49138641, 21.96556091], [88.49138641, 21.96492958], [88.49138641, 21.96433067], [88.49138641, 21.96379089], [88.49132538, 21.96329308], [88.49111176, 21.96283913], [88.49089813, 21.96232986], [88.49086761, 21.9617424], [88.49100494, 21.96110916], [88.49118805, 21.96046066], [88.49144745, 21.9598484], [88.49179077, 21.95934105], [88.49217987, 21.95890999], [88.49250031, 21.95848274], [88.49278259, 21.95810509], [88.49305725, 21.95775986], [88.49333191, 21.95741272], [88.49360657, 21.95702934], [88.49388885, 21.95661163], [88.4941864, 21.95617104], [88.49458313, 21.95582199], [88.49497223, 21.9554615], [88.49534607, 21.95508385], [88.49578094, 21.95478058], [88.49621582, 21.95445824], [88.49666595, 21.95417023], [88.4970932, 21.95388985], [88.49750519, 21.95363235], [88.49791718, 21.95340538], [88.49835205, 21.95323181], [88.49880219, 21.95309258], [88.49931335, 21.95298958], [88.49977875, 21.95274734], [88.50029755, 21.9525528], [88.50084686, 21.95239067], [88.5012207, 21.95213127], [88.50150299, 21.95186043], [88.5018158, 21.95163918], [88.50213623, 21.95137024], [88.50250244, 21.95112991], [88.50292969, 21.95096016], [88.50335693, 21.95080948], [88.50376892, 21.95059776], [88.5042572, 21.9504509], [88.50476074, 21.95029068], [88.50527954, 21.95016098], [88.50576782, 21.95004272], [88.50624084, 21.94984436], [88.50679016, 21.94970512], [88.50737, 21.94959068], [88.50778961, 21.94930267], [88.50817871, 21.94898987], [88.50853729, 21.94869041], [88.50892639, 21.94846153], [88.50933838, 21.94828987], [88.50971985, 21.9480629], [88.51010132, 21.94782829], [88.51053619, 21.94772148], [88.51095581, 21.94763947], [88.5113678, 21.94753075], [88.5118103, 21.94748116], [88.51222229, 21.9473381], [88.51261902, 21.94717979], [88.51296234, 21.94695282], [88.51326752, 21.94671059], [88.51354218, 21.94642067], [88.51386261, 21.94617271], [88.51434326, 21.94607353], [88.51486206, 21.94593048], [88.51538849, 21.94573021], [88.51577759, 21.94536018], [88.51616669, 21.94492912], [88.5165863, 21.94449043], [88.51714325, 21.94413948], [88.51767731, 21.94373131], [88.51828766, 21.94334221], [88.51888275, 21.94284248], [88.51946259, 21.94230461], [88.52000427, 21.94177055], [88.52046204, 21.94127083], [88.52062988, 21.94069099], [88.52083588, 21.94026947], [88.52104187, 21.93995667], [88.52120209, 21.93967056], [88.52137756, 21.93942261], [88.52159119, 21.93919945], [88.5218277, 21.93901062], [88.52197266, 21.93868065], [88.5221405, 21.93835068], [88.52220154, 21.9379406], [88.5222168, 21.93750954], [88.52229309, 21.93707275], [88.52249908, 21.9366703], [88.52271271, 21.93626022], [88.52275085, 21.93580818], [88.52274323, 21.93534279], [88.52276611, 21.93482971], [88.52275085, 21.9343071], [88.52268219, 21.93379021], [88.52274323, 21.93344116], [88.52281952, 21.93309975], [88.52301025, 21.9327507], [88.52305603, 21.93228912], [88.52303314, 21.93180084], [88.52295685, 21.93131828], [88.52281189, 21.93089104], [88.52276611, 21.93046951], [88.52277374, 21.93004608], [88.52276611, 21.92962074], [88.52274323, 21.92920113], [88.52258301, 21.92879295], [88.52250671, 21.92835045], [88.52246857, 21.92789078], [88.52231598, 21.92744064], [88.52223206, 21.92695045], [88.5222168, 21.9264183], [88.5222168, 21.92588806], [88.5222168, 21.92537117], [88.5222702, 21.92486191], [88.52240753, 21.92432976], [88.52224731, 21.92375946], [88.5220871, 21.92316055], [88.52194977, 21.92256737], [88.52184296, 21.92200089], [88.52173615, 21.92152977], [88.52186584, 21.92110825], [88.5218811, 21.92072105], [88.52181244, 21.92034149], [88.52170563, 21.91996574], [88.52168274, 21.91955757], [88.52173615, 21.91904259], [88.52185822, 21.91841888], [88.5217514, 21.91783905], [88.52159882, 21.91720963], [88.52124786, 21.91661072], [88.52091217, 21.91601563], [88.5206604, 21.91539574], [88.5202179, 21.91501045], [88.51973724, 21.91473961], [88.51928711, 21.91448975], [88.51882935, 21.91436195], [88.51843262, 21.9141655], [88.51808167, 21.9139328], [88.51779938, 21.91363144], [88.5174942, 21.91335678], [88.51711273, 21.91320038], [88.51661682, 21.91314888], [88.5164566, 21.9132061], [88.51610565, 21.91333961], [88.51557922, 21.91358948], [88.51506805, 21.91384125], [88.514534, 21.91388512], [88.51399994, 21.91389084], [88.51352692, 21.91394043], [88.5131073, 21.91410828], [88.51264191, 21.91410828], [88.51213837, 21.91415024], [88.51155853, 21.91410828], [88.51091003, 21.91399956], [88.51026917, 21.91412926], [88.50965118, 21.91415977], [88.50904083, 21.91417122], [88.50849915, 21.91417122], [88.50801086, 21.91421127], [88.50757599, 21.91439438], [88.50711823, 21.91444206], [88.50665283, 21.91448021], [88.50623322, 21.91466522], [88.50583649, 21.91472244], [88.50222015, 21.91472244], [88.5019455, 21.91444588], [88.50147247, 21.91439819], [88.50108337, 21.91415024], [88.50064087, 21.91394043], [88.50012207, 21.91389275], [88.49960327, 21.91386795], [88.49942017, 21.91383362], [88.4990921, 21.91377068], [88.49855042, 21.91353035], [88.4981308, 21.91353035], [88.49781036, 21.91360092], [88.49745941, 21.91361809], [88.49720001, 21.91361427], [88.49705505, 21.91361237], [88.49661255, 21.91358185], [88.4961853, 21.91342735], [88.49569702, 21.91335106], [88.49520111, 21.91333008], [88.49466705, 21.91333008], [88.494133, 21.91333961], [88.49357605, 21.91333961], [88.49304962, 21.91328812], [88.49260712, 21.91306686], [88.49221039, 21.91282272], [88.49183655, 21.91257095], [88.49143982, 21.91240883], [88.4910202, 21.91228294], [88.490448, 21.91233253], [88.48999023, 21.91228485], [88.48956299, 21.91220284], [88.48915863, 21.91208076], [88.4887619, 21.91196823], [88.4883728, 21.91191292], [88.48799896, 21.91177177], [88.48748779, 21.91162109], [88.48703766, 21.9114151], [88.4865799, 21.91128922], [88.48615265, 21.91110039], [88.48571014, 21.91090012], [88.4852066, 21.91078949], [88.48475647, 21.91055107], [88.48430634, 21.91029549], [88.48377991, 21.91012192], [88.48323822, 21.90995979], [88.48280334, 21.90966034], [88.48236847, 21.90932083], [88.48194122, 21.9090004], [88.48149872, 21.90870667], [88.4810791, 21.90840912], [88.4806366, 21.90814018], [88.48026276, 21.90777969], [88.47986603, 21.90738106], [88.47944641, 21.90693092], [88.47902679, 21.90640068], [88.47857666, 21.90587044], [88.4781189, 21.90536118], [88.47762299, 21.9048996], [88.47727203, 21.9043808], [88.47702789, 21.90383148], [88.47685242, 21.90327072], [88.47664642, 21.90272141], [88.47638702, 21.90219688], [88.47612, 21.90167046], [88.47586823, 21.90113449], [88.4756546, 21.90056229], [88.4754715, 21.90001106], [88.47535706, 21.89948082], [88.47537231, 21.89937973], [88.47541809, 21.89894676], [88.47551727, 21.89842033], [88.47556305, 21.89793015], [88.47553253, 21.89744377], [88.47537994, 21.89696693], [88.4751358, 21.89653015], [88.47489166, 21.89624977], [88.47463226, 21.89602089], [88.47438812, 21.89583015], [88.47414398, 21.89566422], [88.47386932, 21.89551544], [88.47355652, 21.89534187], [88.47316742, 21.89542961], [88.4726944, 21.89553833], [88.47219086, 21.89555359], [88.47167969, 21.89551353], [88.47113037, 21.89542961], [88.4704895, 21.89578438], [88.47023773, 21.89584351], [88.46977234, 21.89596176], [88.46895599, 21.89586067], [88.46823883, 21.89591026], [88.46762848, 21.89607048], [88.46708679, 21.89618111], [88.4666214, 21.89635086], [88.46613312, 21.89638901], [88.46563721, 21.89639473], [88.46513367, 21.89638901], [88.46460724, 21.89639091], [88.46409607, 21.89639664], [88.46357727, 21.89645195], [88.46313477, 21.89667892], [88.4628067, 21.89687157], [88.46269226, 21.89694023], [88.46224976, 21.8971653], [88.46173096, 21.89723969], [88.46124268, 21.89736938], [88.46075439, 21.8974781], [88.46047211, 21.89749527], [88.46021271, 21.89751053], [88.4596405, 21.89751625], [88.4590683, 21.89760399], [88.45855713, 21.8977375], [88.45806122, 21.89783287], [88.4576416, 21.89808846], [88.4572525, 21.89834976], [88.45683289, 21.89861107], [88.45643616, 21.89884567], [88.45612335, 21.89916039], [88.45582581, 21.89953041], [88.45561218, 21.89994812], [88.45555878, 21.90043831], [88.45555115, 21.90090942], [88.45559692, 21.9014225], [88.45575714, 21.90183258], [88.45582581, 21.90228081], [88.45583344, 21.90273094], [88.45587158, 21.90316963], [88.45604706, 21.90359116], [88.45610809, 21.90405273], [88.4561615, 21.90452194], [88.45635223, 21.90491867], [88.45648193, 21.90535164], [88.45667267, 21.90576553], [88.45687103, 21.90620041], [88.45701599, 21.90672112], [88.45722961, 21.90723038], [88.45749664, 21.9077301], [88.45777893, 21.90821075], [88.45804596, 21.90864944], [88.4582901, 21.90905762], [88.45841217, 21.90950012], [88.45862579, 21.90989113], [88.45889282, 21.91023064], [88.45915222, 21.91058922], [88.45934296, 21.91101646], [88.45952606, 21.91146088], [88.45969391, 21.91186714], [88.45976257, 21.91226959], [88.45992279, 21.91258049], [88.45999908, 21.91290855], [88.46005249, 21.91324043], [88.46018982, 21.91354942], [88.46035004, 21.91390038], [88.46052551, 21.91431618], [88.46068573, 21.91479301], [88.46083832, 21.9152813], [88.46099854, 21.91572189], [88.46111298, 21.91613007], [88.46121979, 21.91648293], [88.46136475, 21.91675949], [88.46144867, 21.91707039], [88.46160126, 21.91734123], [88.46170044, 21.91769028], [88.46188354, 21.91802979], [88.46194458, 21.91848183], [88.46193695, 21.91898537], [88.46200562, 21.91950226], [88.46209717, 21.91994286], [88.46201324, 21.92045021], [88.46216583, 21.92080879], [88.46224213, 21.92110062], [88.46221924, 21.92160988], [88.46222687, 21.92188072], [88.46222687, 21.9221611], [88.46221924, 21.92246056], [88.46219635, 21.92277718], [88.46211243, 21.92311287], [88.46196747, 21.92350006], [88.46187592, 21.92398262], [88.46164703, 21.9244709], [88.46135712, 21.9249897], [88.46099854, 21.92550087], [88.46060944, 21.92597961], [88.46029663, 21.92645073], [88.46006775, 21.92686844], [88.45985413, 21.92720413], [88.45964813, 21.9274826], [88.45947266, 21.9277401], [88.4593277, 21.92805099], [88.45915222, 21.92838097], [88.45889282, 21.92873955], [88.45858765, 21.92915916], [88.45818329, 21.92957115], [88.45775604, 21.93000031], [88.45733643, 21.93041611], [88.45684814, 21.93084145], [88.45639038, 21.93133163], [88.45597076, 21.93181229], [88.45561218, 21.93227959], [88.45532227, 21.93270683], [88.45524597, 21.93278503], [88.45501709, 21.93302345], [88.4547348, 21.93326187], [88.45452118, 21.9335041], [88.45443726, 21.9338398], [88.45432281, 21.93418121], [88.45413208, 21.93447876], [88.4540329, 21.93490028], [88.45391846, 21.93514061], [88.45375061, 21.9354496], [88.45372009, 21.93574715], [88.45361328, 21.93596268], [88.45352936, 21.93594742], [88.45345306, 21.93643951], [88.45333099, 21.93695068], [88.45324707, 21.93729973], [88.45305634, 21.93805313], [88.45310211, 21.93834305], [88.45304871, 21.93881989], [88.45289612, 21.93953705], [88.45289612, 21.94005394], [88.4529953, 21.9404583], [88.45307922, 21.94091034], [88.45323181, 21.94139099], [88.45340729, 21.94186974], [88.45365906, 21.94226646], [88.4539032, 21.94267273], [88.45417023, 21.94309998], [88.45449066, 21.94355965], [88.45487976, 21.94404984], [88.45529938, 21.94457817], [88.45573425, 21.94514656], [88.45613098, 21.94577026], [88.45677948, 21.94625092], [88.45735931, 21.9466095], [88.45799255, 21.94705963], [88.45845032, 21.94735146], [88.45906067, 21.94763947], [88.45935822, 21.9480629], [88.45981598, 21.94833183], [88.46026611, 21.94855309], [88.46066284, 21.94879341], [88.46102905, 21.94903946], [88.46144104, 21.94922829], [88.46185303, 21.94943237], [88.46227264, 21.94967079], [88.4627533, 21.94989014], [88.46347046, 21.95000648], [88.46389008, 21.95018005], [88.46406555, 21.95030403], [88.46433258, 21.95049095], [88.46481323, 21.95082283], [88.46530914, 21.9510994], [88.4658432, 21.95139122], [88.46642303, 21.9516983], [88.46704865, 21.95204735], [88.46767426, 21.95243454], [88.46823883, 21.95283127], [88.46865082, 21.95331192], [88.46897125, 21.95375061], [88.46918488, 21.95415878], [88.46944427, 21.95447159], [88.4697113, 21.95471954], [88.4699707, 21.95498085], [88.47019196, 21.9552803], [88.47032166, 21.95573044], [88.47051239, 21.95621109], [88.47062683, 21.95672989], [88.4705658, 21.95725632], [88.47048187, 21.95778084], [88.47032928, 21.95832825], [88.47020721, 21.95890045], [88.46998596, 21.95940971], [88.4697113, 21.95986938], [88.46942902, 21.96029472], [88.46912384, 21.96069717], [88.46876526, 21.96107292], [88.46835327, 21.9614296], [88.4679184, 21.96178818], [88.46746063, 21.96213913], [88.46696472, 21.96243286], [88.46641541, 21.9626236], [88.46589661, 21.96280098], [88.46542358, 21.96300125], [88.46495056, 21.96313095], [88.46450806, 21.96327972], [88.46405792, 21.96338081], [88.46368408, 21.96352005], [88.46326447, 21.96359253], [88.46276855, 21.96363258], [88.46204376, 21.96346283], [88.46128082, 21.9633503], [88.46099091, 21.96348953], [88.46080017, 21.96373177], [88.46034241, 21.96387291], [88.4597168, 21.96401024], [88.45900726, 21.96414185], [88.45826721, 21.96417046], [88.45752716, 21.96416283], [88.45681, 21.96410942], [88.45607758, 21.96397018], [88.45536041, 21.96408272], [88.45465851, 21.96392822], [88.45391846, 21.96389008], [88.45317078, 21.96389008], [88.45243073, 21.96389008], [88.45168304, 21.96389008], [88.45096588, 21.96389008], [88.45024109, 21.96389008], [88.44953156, 21.96388626], [88.44885254, 21.9638958], [88.4485321, 21.96392441], [88.4482193, 21.96395493], [88.44766998, 21.96416283], [88.44716644, 21.96438026], [88.44667816, 21.96454239], [88.44631958, 21.96487045], [88.44608307, 21.96537971], [88.44593048, 21.96595955], [88.44591522, 21.96655655], [88.445961, 21.96717453], [88.44606018, 21.9675808], [88.44609833, 21.96774292], [88.44628906, 21.96825981], [88.44642639, 21.96887016], [88.4466629, 21.96941948], [88.44689941, 21.96996117], [88.44706726, 21.97046089], [88.44718933, 21.97089958], [88.44727325, 21.97129059], [88.44742584, 21.9716301], [88.44754028, 21.97204971], [88.44774628, 21.97250175], [88.44793701, 21.97301102], [88.44812012, 21.97356987], [88.44828033, 21.97413063], [88.44837952, 21.97468758], [88.44856262, 21.97521019], [88.44861603, 21.97580719], [88.4486618, 21.97616959], [88.44869995, 21.97645187], [88.44889832, 21.97710991], [88.44909668, 21.97777939], [88.44915771, 21.97851181], [88.4491806, 21.97919846], [88.44924164, 21.97983932], [88.44939423, 21.98043442], [88.44944, 21.98101997], [88.44944763, 21.98162651], [88.44944763, 21.98224258], [88.44944763, 21.98285484], [88.44944763, 21.9834404], [88.44943237, 21.98398972], [88.44934845, 21.98447609], [88.44917297, 21.98488998], [88.44893646, 21.98533821], [88.44876862, 21.98591042], [88.44854736, 21.98648071], [88.44824219, 21.98698807], [88.44786835, 21.98743248], [88.44743347, 21.98778343], [88.44694519, 21.98806381], [88.44647217, 21.98833275], [88.44602203, 21.98860168], [88.44554901, 21.98886108], [88.4450531, 21.9890995], [88.44451904, 21.9892807], [88.44404602, 21.98949051], [88.44367981, 21.98971558], [88.4434433, 21.98991013], [88.44335938, 21.99012184], [88.44348907, 21.99051094], [88.4437027, 21.99115944], [88.44396973, 21.99180984], [88.4443512, 21.99234009], [88.44482422, 21.99274063], [88.44529724, 21.99306107], [88.44573212, 21.99336052], [88.44611359, 21.99367905], [88.44644928, 21.99400139], [88.44680786, 21.99427986], [88.44717407, 21.99453926], [88.44750977, 21.99482346], [88.44782257, 21.99510956], [88.44814301, 21.9953804], [88.44843292, 21.99567986], [88.44866943, 21.99604034], [88.4489212, 21.99643517], [88.4491806, 21.99690056], [88.44945526, 21.99741554], [88.44972992, 21.99799347], [88.44999695, 21.99862289], [88.45015717, 21.99926949], [88.45027924, 22.00000191], [88.45027924, 22.00055504], [88.45055389, 22.00083351], [88.45054626, 22.00472069], [88.45027924, 22.00500107], [88.45027924, 22.00611115], [88.45055389, 22.00638962], [88.45054626, 22.00722122], [88.4516983, 22.00830269], [88.45240784, 22.00863075], [88.45284271, 22.00869942], [88.45327759, 22.00869942], [88.4536972, 22.00882912], [88.45464325, 22.00882912], [88.45556641, 22.00876045], [88.4575882, 22.00876427], [88.45830536, 22.00896454], [88.45902252, 22.00923347], [88.45967102, 22.0096302], [88.46017456, 22.00996971], [88.46060181, 22.01057243], [88.46089172, 22.01097488], [88.46111298, 22.0112381], [88.46111298, 22.01138115], [88.46089172, 22.01157951], [88.46076965, 22.01153374], [88.46053314, 22.01144409], [88.46009827, 22.01097488], [88.45967102, 22.01057243], [88.45902252, 22.01023865], [88.45809174, 22.01004028], [88.45744324, 22.00996971], [88.45622253, 22.00996971], [88.45456696, 22.01004028], [88.45233917, 22.01004028], [88.45133972, 22.00984001], [88.45089722, 22.0095005], [88.45040131, 22.009161], [88.4498291, 22.00829506], [88.44967651, 22.00782967], [88.44933319, 22.00702095], [88.44911194, 22.00668716], [88.44889069, 22.00562096], [88.44889069, 22.00222015], [88.44916534, 22.00194359], [88.44916534, 22.00083351], [88.44889069, 22.00055504], [88.44889069, 22.00000191], [88.44892883, 21.99930954], [88.44873047, 21.99875069], [88.44850922, 21.99822617], [88.44819641, 21.99780273], [88.44787598, 21.99742126], [88.4475708, 21.99703026], [88.44724274, 21.9966507], [88.44691467, 21.99627113], [88.44656372, 21.99591827], [88.44616699, 21.99559975], [88.44577789, 21.99529266], [88.44537354, 21.99500275], [88.44496918, 21.99472237], [88.44458771, 21.99445152], [88.44421387, 21.9941864], [88.44387817, 21.99389267], [88.44353485, 21.99359894], [88.44319153, 21.99329948], [88.44285583, 21.99298096], [88.44254303, 21.99263], [88.44226837, 21.99226761], [88.4420166, 21.99188995], [88.44179535, 21.99149895], [88.4416275, 21.99106026], [88.44168854, 21.99060822], [88.44182587, 21.99020958], [88.44197083, 21.9899292], [88.44211578, 21.98968124], [88.442276, 21.98942947], [88.44245911, 21.98920822], [88.4426651, 21.98901367], [88.44289398, 21.98882484], [88.44313049, 21.98860359], [88.44341278, 21.98838425], [88.44374847, 21.98819542], [88.44410706, 21.98801994], [88.44443512, 21.98784828], [88.44477844, 21.98771286], [88.44514465, 21.98755646], [88.44555664, 21.98736191], [88.44596863, 21.98711777], [88.44641113, 21.98687172], [88.44683075, 21.98661041], [88.44719696, 21.98630905], [88.44747925, 21.9859333], [88.4477005, 21.98551559], [88.4478302, 21.98503113], [88.44798279, 21.98451805], [88.44803619, 21.98393059], [88.44805908, 21.98330116], [88.44805908, 21.98265076], [88.44803619, 21.98200035], [88.44799805, 21.98138046], [88.44783783, 21.98081017], [88.44777679, 21.98019981], [88.44777679, 21.97960663], [88.44774628, 21.97903061], [88.44764709, 21.97847939], [88.44753265, 21.97794342], [88.4474411, 21.97740364], [88.44727325, 21.97689629], [88.44718933, 21.9763298], [88.44703674, 21.97577095], [88.44690704, 21.97518921], [88.44668579, 21.97464943], [88.44650269, 21.9740696], [88.44633484, 21.97346687], [88.44610596, 21.97289085], [88.44589233, 21.97233772], [88.44576263, 21.97177124], [88.44556427, 21.97126961], [88.44538879, 21.97079277], [88.44525146, 21.97030258], [88.44507599, 21.96983719], [88.44499969, 21.96931839], [88.44490814, 21.96883583], [88.44477081, 21.96841049], [88.44472504, 21.96804237], [88.44472504, 21.96767807], [88.44471741, 21.96727943], [88.44468689, 21.96680069], [88.44464874, 21.96623993], [88.44468689, 21.96562958], [88.44481659, 21.96502113], [88.44506836, 21.96455383], [88.44532776, 21.9641552], [88.44565582, 21.96384048], [88.44607544, 21.96362114], [88.4465332, 21.96343613], [88.44703674, 21.96329117], [88.44745636, 21.96308708], [88.44780731, 21.96285057], [88.44822693, 21.96267128], [88.44867706, 21.96249962], [88.44915009, 21.96232033], [88.44963074, 21.96224022], [88.45009613, 21.96219826], [88.45053101, 21.96213913], [88.45096588, 21.96213913], [88.45144653, 21.96219826], [88.45202637, 21.96219826], [88.45264435, 21.96221161], [88.45324707, 21.96219826], [88.45379639, 21.96222115], [88.45432281, 21.96222115], [88.45478821, 21.96222115], [88.45529175, 21.96222115], [88.45584106, 21.96222115], [88.45642853, 21.96223068], [88.45703125, 21.9622612], [88.4572525, 21.96228981], [88.45761871, 21.96234131], [88.45820618, 21.96245956], [88.45883179, 21.96249962], [88.45942688, 21.96249962], [88.4599762, 21.96251106], [88.46048737, 21.96256256], [88.46096802, 21.96264076], [88.46156311, 21.96253967], [88.46224213, 21.96231079], [88.4629364, 21.96222115], [88.46362305, 21.96216011], [88.46424866, 21.96199036], [88.46484375, 21.96187592], [88.46534729, 21.96167946], [88.46582031, 21.96149635], [88.46626282, 21.96132278], [88.46666718, 21.96108818], [88.46703339, 21.96080971], [88.46737671, 21.96051788], [88.46769714, 21.96019936], [88.46801758, 21.95986176], [88.46827698, 21.95948029], [88.46852875, 21.95906067], [88.46871948, 21.95856285], [88.46892548, 21.95796967], [88.46905518, 21.95725822], [88.46900177, 21.95650101], [88.46882629, 21.95583916], [88.46855164, 21.95540047], [88.46822357, 21.95513725], [88.46791077, 21.95482254], [88.46761322, 21.95449066], [88.46725464, 21.95424652], [88.46679688, 21.9541111], [88.46642303, 21.95387077], [88.46606445, 21.95358086], [88.46562958, 21.95331955], [88.46517944, 21.95305443], [88.46485138, 21.9528656], [88.46471405, 21.95278549], [88.46422577, 21.9525528], [88.46380615, 21.95225525], [88.46338654, 21.95195007], [88.46295166, 21.95166779], [88.46248627, 21.95141029], [88.46198273, 21.95119095], [88.46143341, 21.9509964], [88.46087646, 21.95076942], [88.46032715, 21.9505291], [88.45976257, 21.9502697], [88.45921326, 21.94997406], [88.45874786, 21.94958115], [88.45819092, 21.94931984], [88.45775604, 21.94904137], [88.45722961, 21.94860268], [88.45674133, 21.94826126], [88.45613861, 21.9480381], [88.45559692, 21.94775009], [88.45519257, 21.9473629], [88.45477295, 21.94709969], [88.45445251, 21.94676781], [88.45417023, 21.94639969], [88.45383453, 21.94605827], [88.45350647, 21.94573021], [88.45320129, 21.94536972], [88.45287323, 21.94498825], [88.45253754, 21.94454956], [88.45230103, 21.94395828], [88.45211029, 21.94325066], [88.451828, 21.94259453], [88.45148468, 21.94202614], [88.45133972, 21.94146919], [88.45131683, 21.9410305], [88.45134735, 21.9409523], [88.45139313, 21.94083023], [88.4513855, 21.93944359], [88.45111084, 21.93916512], [88.45131683, 21.93856049], [88.45115662, 21.93812943], [88.45107269, 21.9376297], [88.45110321, 21.93702126], [88.45110321, 21.93667984], [88.45105743, 21.9363575], [88.45105743, 21.93540573], [88.45149231, 21.93460083], [88.4515686, 21.93334007], [88.45243073, 21.93179321], [88.45365143, 21.9300251], [88.45466614, 21.92916107], [88.45529938, 21.92828941], [88.45581818, 21.9280262], [88.45643616, 21.92723083], [88.45735931, 21.92560005], [88.45828247, 21.92435074], [88.45867157, 21.92361069], [88.45869446, 21.92318535], [88.45864868, 21.92212105], [88.45886993, 21.9217205], [88.45889282, 21.92114067], [88.45890808, 21.92046165], [88.45881653, 21.91989517], [88.45857239, 21.91940117], [88.45848083, 21.91884041], [88.45822144, 21.91852951], [88.4580307, 21.91820145], [88.457901, 21.91777039], [88.45759583, 21.91755104], [88.45730591, 21.91732025], [88.45698547, 21.91714287], [88.45665741, 21.91690636], [88.45627594, 21.91665077], [88.4559021, 21.91636658], [88.45553589, 21.91604042], [88.45526123, 21.91565704], [88.45487976, 21.91533089], [88.45412445, 21.91518211], [88.45345306, 21.91496849], [88.45284271, 21.91468239], [88.45224762, 21.91436577], [88.45168304, 21.914011], [88.4511261, 21.91365051], [88.45057678, 21.91335106], [88.4500351, 21.91313171], [88.44946289, 21.91300201], [88.44894409, 21.91283417], [88.44841766, 21.91271973], [88.44790649, 21.91256142], [88.44735718, 21.91244125], [88.44683075, 21.91228294], [88.44626617, 21.91220284], [88.44573975, 21.91212082], [88.44526672, 21.91200066], [88.44474792, 21.9119091], [88.44444275, 21.91195107], [88.44387817, 21.91194916], [88.44361115, 21.91195107], [88.44333649, 21.91167068], [88.44277954, 21.91167068], [88.44249725, 21.9113903], [88.44167328, 21.9113903], [88.44083405, 21.9105587], [88.44055176, 21.91028023], [88.44039917, 21.91011047], [88.44023132, 21.90992737], [88.43991852, 21.90954018], [88.43952179, 21.90925026], [88.43906403, 21.9090519], [88.4386673, 21.90881729], [88.43834686, 21.90849113], [88.43805695, 21.90806007], [88.43772888, 21.90760231], [88.43730927, 21.90716362], [88.43695068, 21.90664101], [88.43662262, 21.90610123], [88.4361496, 21.9056778], [88.43575287, 21.90519905], [88.43533325, 21.90475464], [88.4349823, 21.90435028], [88.43466187, 21.90397835], [88.43430328, 21.90363121], [88.43385315, 21.90330124], [88.43338776, 21.9030304], [88.43299866, 21.90281105], [88.43264008, 21.90277481], [88.43234253, 21.90275383], [88.43205261, 21.90266037], [88.43172455, 21.90275574], [88.43141174, 21.90299034], [88.43107605, 21.90313911], [88.43078613, 21.9033699], [88.43044281, 21.90363121], [88.43000793, 21.9039402], [88.42962646, 21.90439606], [88.42935944, 21.90464973], [88.42913818, 21.90485764], [88.42856598, 21.9052906], [88.4280014, 21.90575027], [88.42739868, 21.90615082], [88.42687225, 21.90659142], [88.42629242, 21.90693092], [88.42565155, 21.90722275], [88.42494965, 21.90747833], [88.42418671, 21.90771294], [88.42344666, 21.90775108], [88.42273712, 21.90764046], [88.42209625, 21.90752029], [88.42156982, 21.90744209], [88.42121124, 21.90725327], [88.42086029, 21.90711212], [88.42056274, 21.9069519], [88.42027283, 21.90679932], [88.41996765, 21.90667343], [88.41972351, 21.90655136], [88.41951752, 21.90637589], [88.41929626, 21.90614128], [88.41898346, 21.90590858], [88.41870117, 21.90558052], [88.41835022, 21.9052906], [88.41802216, 21.90501022], [88.41773987, 21.90473938], [88.4174881, 21.90449715], [88.41725159, 21.9042511], [88.41707611, 21.90390015], [88.41687012, 21.90335846], [88.41670227, 21.90278816], [88.41661835, 21.9022274], [88.41639709, 21.9017601], [88.4163208, 21.90153122], [88.41622925, 21.90127182], [88.41619873, 21.90079117], [88.41634369, 21.90029907], [88.41638184, 21.89981079], [88.41638947, 21.8993206], [88.41638947, 21.8988266], [88.41638184, 21.89829063], [88.41636658, 21.89767075], [88.41638184, 21.89700127], [88.41638947, 21.89628983], [88.41638947, 21.89556122], [88.41633606, 21.89483833], [88.4161377, 21.89420319], [88.41586304, 21.89364433], [88.41567993, 21.89307594], [88.41549683, 21.8925209], [88.41532898, 21.89199066], [88.41525269, 21.89151955], [88.41506958, 21.89115906], [88.41496277, 21.89081955], [88.41475677, 21.89055634], [88.41468048, 21.89023018], [88.41448975, 21.88993835], [88.41429901, 21.88957024], [88.41405487, 21.88917351], [88.41374207, 21.88874626], [88.41333771, 21.88830948], [88.41291809, 21.8878479], [88.4123764, 21.88744926], [88.41157532, 21.88729286], [88.4111557, 21.88687515], [88.41073608, 21.88638115], [88.41021729, 21.88606834], [88.40970612, 21.88581276], [88.40919495, 21.88555908], [88.40866852, 21.8853302], [88.40818787, 21.88519287], [88.40779114, 21.88503075], [88.40738678, 21.88495064], [88.40705872, 21.8848114], [88.40694427, 21.88472176], [88.40444183, 21.88471985], [88.40416718, 21.88500023], [88.4033432, 21.88500023], [88.40320587, 21.88500977], [88.40305328, 21.88500023], [88.40270996, 21.88486099], [88.40249634, 21.88472176], [88.40139008, 21.88583565], [88.40139008, 21.88652039], [88.40139008, 21.88666534], [88.40110779, 21.88694382], [88.40110779, 21.88722038], [88.40110016, 21.88760948], [88.40103912, 21.88799095], [88.40090942, 21.88834763], [88.40072632, 21.88872337], [88.40048218, 21.88910103], [88.40011597, 21.889431], [88.39968872, 21.88972092], [88.39923096, 21.88999748], [88.39878082, 21.89027977], [88.39834595, 21.89055824], [88.3979187, 21.89087105], [88.39745331, 21.89113998], [88.39694977, 21.89133835], [88.39638519, 21.89142227], [88.39586639, 21.8915844], [88.39539337, 21.89183044], [88.39501953, 21.89213943], [88.39459991, 21.89228821], [88.3941803, 21.89245987], [88.39369965, 21.89254761], [88.39322662, 21.89269066], [88.39273071, 21.89280319], [88.39225769, 21.89299965], [88.39183044, 21.89328957], [88.39138031, 21.8934803], [88.39089203, 21.89361954], [88.39039612, 21.89376068], [88.38996124, 21.89395142], [88.38954926, 21.89426041], [88.38912964, 21.89454079], [88.38867188, 21.89472961], [88.38819122, 21.89487076], [88.38777161, 21.89504433], [88.3874588, 21.89533424], [88.38719177, 21.89570045], [88.38690186, 21.89606094], [88.38656616, 21.89635086], [88.38620758, 21.89657211], [88.38585663, 21.89677048], [88.38555908, 21.89705086], [88.38527679, 21.89742279], [88.38504028, 21.89791107], [88.38488007, 21.89853287], [88.38474274, 21.89915276], [88.38466644, 21.89980507], [88.38463593, 21.90048027], [88.38482666, 21.90108109], [88.38504028, 21.90170288], [88.38527679, 21.90229988], [88.38556671, 21.90287018], [88.38587952, 21.90341949], [88.38621521, 21.90395164], [88.38667297, 21.9043808], [88.38712311, 21.90479088], [88.38749695, 21.90525055], [88.38796234, 21.90565109], [88.38838196, 21.90615082], [88.38887787, 21.90662956], [88.38946533, 21.90698624], [88.39002991, 21.90730286], [88.39058685, 21.90754128], [88.39113617, 21.90775108], [88.3916626, 21.90793037], [88.39212799, 21.90814018], [88.39260864, 21.90837097], [88.39303589, 21.90867043], [88.39346313, 21.90898514], [88.39391327, 21.90917015], [88.39431, 21.9093399], [88.39473724, 21.90949059], [88.39515686, 21.90966988], [88.39565277, 21.90973091], [88.39612579, 21.90986824], [88.39658356, 21.91002274], [88.39700317, 21.91024971], [88.39742279, 21.91040993], [88.39788818, 21.91057968], [88.39832306, 21.91082954], [88.39875793, 21.91107941], [88.39923859, 21.91127968], [88.39976501, 21.91142082], [88.40023804, 21.91162491], [88.40052032, 21.9116993], [88.40071106, 21.91175079], [88.40113068, 21.91195107], [88.4015274, 21.91220284], [88.40194702, 21.91244125], [88.40238953, 21.91271973], [88.40288544, 21.91293716], [88.40341187, 21.9131012], [88.40391541, 21.91327095], [88.40433502, 21.91355324], [88.40468597, 21.91387939], [88.4050293, 21.91421127], [88.40537262, 21.91455269], [88.40570831, 21.91491127], [88.4059906, 21.91530037], [88.40627289, 21.91570854], [88.40660858, 21.91607285], [88.40691376, 21.91645813], [88.4071579, 21.91690445], [88.40725708, 21.91744423], [88.40744781, 21.91797829], [88.40753937, 21.91852951], [88.40770721, 21.91899109], [88.40777588, 21.91949272], [88.40777588, 21.92000008], [88.40777588, 21.92052078], [88.40776062, 21.92102814], [88.40769958, 21.92152023], [88.40753174, 21.92195892], [88.40743256, 21.92246056], [88.40721893, 21.92294121], [88.40696716, 21.92346191], [88.40672302, 21.92401123], [88.40638733, 21.9244709], [88.40602112, 21.92490005], [88.40557861, 21.9253006], [88.40525055, 21.92576027], [88.4048996, 21.92620087], [88.40455627, 21.92658043], [88.40432739, 21.92703056], [88.40397644, 21.92741013], [88.40361023, 21.92778015], [88.40322876, 21.92815971], [88.40284729, 21.92853546], [88.40242767, 21.92888069], [88.40197754, 21.9292202], [88.40154266, 21.92958069], [88.40107727, 21.92993927], [88.40061951, 21.93029976], [88.40023041, 21.93071175], [88.39980316, 21.93103981], [88.39940643, 21.93136024], [88.39907074, 21.9316597], [88.39872742, 21.93193054], [88.39836121, 21.93219948], [88.39798737, 21.93249893], [88.39756775, 21.93283844], [88.39716339, 21.93328285], [88.39672089, 21.93369293], [88.3963089, 21.93412971], [88.39588928, 21.934515], [88.39550781, 21.93491936], [88.39509583, 21.93531036], [88.39472961, 21.93572044], [88.39441681, 21.93618011], [88.39424896, 21.93676949], [88.39418793, 21.93731117], [88.39414978, 21.9377594], [88.39406586, 21.93821907], [88.39403534, 21.93872833], [88.3941803, 21.9392128], [88.3943634, 21.93970108], [88.39454651, 21.9401207], [88.39479065, 21.94052124], [88.39504242, 21.94087982], [88.39527893, 21.9412899], [88.3955307, 21.9417305], [88.39573669, 21.94222832], [88.39592743, 21.94273949], [88.39613342, 21.94319725], [88.39639282, 21.94359016], [88.39657593, 21.94399071], [88.396698, 21.9444294], [88.39693451, 21.94479561], [88.3971405, 21.94519043], [88.39736938, 21.94560051], [88.3976059, 21.94606972], [88.39790344, 21.94651604], [88.39820862, 21.94698143], [88.39842987, 21.94748306], [88.39861298, 21.9479599], [88.39879608, 21.94841957], [88.39897156, 21.94886971], [88.39913177, 21.94933128], [88.39919281, 21.94987106], [88.39929199, 21.95045853], [88.39933014, 21.9511261], [88.39920807, 21.95182419], [88.39906311, 21.95249557], [88.39881134, 21.95309258], [88.39846802, 21.95353889], [88.39803314, 21.95387459], [88.39755249, 21.95416451], [88.39705658, 21.95442963], [88.39659882, 21.95467949], [88.39614105, 21.9548912], [88.39572906, 21.95510292], [88.39533234, 21.95529938], [88.39496613, 21.95550919], [88.39451599, 21.9555912], [88.39409637, 21.95573997], [88.3936615, 21.95582962], [88.39323425, 21.95589638], [88.39283752, 21.95605469], [88.39239502, 21.95610809], [88.39196014, 21.95615959], [88.3915863, 21.95633698], [88.39115906, 21.95639992], [88.39073944, 21.95650101], [88.39032745, 21.95664024], [88.38989258, 21.95672989], [88.38949585, 21.95689964], [88.38905334, 21.9570446], [88.38858032, 21.95717049], [88.38809204, 21.95732117], [88.38763428, 21.95750046], [88.38718414, 21.95767975], [88.38674164, 21.95783806], [88.38632202, 21.95804977], [88.38588715, 21.95823097], [88.38542938, 21.95841026], [88.38499451, 21.95861816], [88.384552, 21.95883179], [88.38411713, 21.95897484], [88.38397217, 21.95921135], [88.38388824, 21.95916748], [88.38361359, 21.95944405], [88.3833313, 21.95944405], [88.38305664, 21.95972252], [88.38276672, 21.95972061], [88.38249969, 21.95999908], [88.3822403, 21.95999908], [88.38195038, 21.96027946], [88.38166809, 21.96027946], [88.3813858, 21.96056175], [88.38111115, 21.96055603], [88.38083649, 21.9608326], [88.38054657, 21.9608326], [88.38027954, 21.96111107], [88.37997437, 21.96117401], [88.3796463, 21.96136093], [88.37922668, 21.96157837], [88.37874603, 21.96175575], [88.37831116, 21.96198082], [88.37786865, 21.96220779], [88.37744904, 21.9623909], [88.37702942, 21.96254921], [88.37666321, 21.96278], [88.37630463, 21.96301651], [88.37593079, 21.96325111], [88.3755722, 21.96352005], [88.37522125, 21.96380615], [88.37498474, 21.96398354], [88.37473297, 21.96417046], [88.37444305, 21.96445084], [88.37388611, 21.96527863], [88.37388611, 21.96665955], [88.37462616, 21.96740723], [88.375, 21.96778107], [88.37527466, 21.96777534], [88.3758316, 21.9683342], [88.37610626, 21.96833038], [88.37638855, 21.96861076], [88.37666321, 21.96861076], [88.37722015, 21.96889114], [88.37760925, 21.96906281], [88.37819672, 21.96916962], [88.37877655, 21.96927071], [88.37930298, 21.96936035], [88.37980652, 21.96941376], [88.38031006, 21.96948051], [88.38079834, 21.96957779], [88.38130188, 21.96962166], [88.38179779, 21.96964264], [88.3822937, 21.96965408], [88.38278961, 21.96965981], [88.38327789, 21.96966934], [88.38376617, 21.96966934], [88.38424683, 21.96968269], [88.38471985, 21.96969986], [88.3852005, 21.96975899], [88.38567352, 21.96985435], [88.3861618, 21.96989441], [88.38664246, 21.96987343], [88.38710022, 21.96980095], [88.38755035, 21.96976089], [88.38800812, 21.96975517], [88.38846588, 21.96977425], [88.38865662, 21.96979332], [88.3889389, 21.96982193], [88.38939667, 21.96989059], [88.38990784, 21.96988106], [88.39045715, 21.969841], [88.39109039, 21.96988106], [88.39175415, 21.97000885], [88.39243317, 21.9701519], [88.39306641, 21.97034073], [88.39367676, 21.97052956], [88.39431, 21.97066116], [88.39389038, 21.97138977], [88.39331055, 21.97170067], [88.39267731, 21.97166061], [88.39080048, 21.97145844], [88.39020538, 21.97140503], [88.3895874, 21.9713707], [88.38896179, 21.97130966], [88.38834381, 21.97121239], [88.38772583, 21.97121048], [88.38710785, 21.97129822], [88.38647461, 21.97133446], [88.38582611, 21.97131729], [88.38519287, 21.97126007], [88.38459778, 21.97120285], [88.3840332, 21.97126961], [88.38347626, 21.97128105], [88.38330078, 21.9712677], [88.3829422, 21.971241], [88.38243103, 21.97117805], [88.38195038, 21.97108078], [88.38150787, 21.97099876], [88.38105774, 21.97095108], [88.38059998, 21.97090912], [88.38011932, 21.97083092], [88.37944794, 21.97083282], [88.37722015, 21.97027969], [88.37638855, 21.97000122], [88.37581635, 21.96972084], [88.375, 21.96916771], [88.37444305, 21.96889114], [88.37277985, 21.96665955], [88.37277985, 21.96500015], [88.37304688, 21.96471977], [88.3730545, 21.96444321], [88.37333679, 21.96445084], [88.37332153, 21.96395111], [88.37360382, 21.96359062], [88.3739624, 21.96319962], [88.37444305, 21.96281815], [88.375, 21.96246338], [88.37556458, 21.9620533], [88.37612915, 21.96164131], [88.37667847, 21.96125031], [88.37722015, 21.9609375], [88.37773895, 21.96068954], [88.37819672, 21.96046829], [88.37860107, 21.96021271], [88.37895203, 21.95994949], [88.37934875, 21.95973206], [88.379776, 21.95954895], [88.38024139, 21.9593811], [88.38071442, 21.95917511], [88.38124847, 21.95896149], [88.38183594, 21.95877075], [88.38217163, 21.95863152], [88.38237, 21.9585495], [88.38279724, 21.95829964], [88.38315582, 21.95804024], [88.38345337, 21.95778084], [88.3837738, 21.95758247], [88.38414764, 21.95740128], [88.38453674, 21.95721054], [88.38491821, 21.9569397], [88.38530731, 21.95667076], [88.38574219, 21.95643044], [88.38619995, 21.95623016], [88.3866806, 21.95606613], [88.38712311, 21.95586014], [88.38757324, 21.95568085], [88.38803864, 21.95554161], [88.38851166, 21.95538712], [88.38900757, 21.95526123], [88.38948059, 21.95512581], [88.38990784, 21.9550209], [88.39027405, 21.95494461], [88.39052582, 21.9547863], [88.39083099, 21.95471954], [88.39120483, 21.95466995], [88.39161682, 21.95452118], [88.39205933, 21.95442581], [88.39247894, 21.95430946], [88.39290619, 21.95420265], [88.39335632, 21.9541111], [88.39379883, 21.95393181], [88.39430237, 21.95384216], [88.39476013, 21.95366859], [88.39523315, 21.95360947], [88.39555359, 21.95361137], [88.39611053, 21.95361137], [88.39638519, 21.9533329], [88.39666748, 21.9533329], [88.39694214, 21.95305443], [88.3972168, 21.95306015], [88.39805603, 21.95222092], [88.39805603, 21.95194435], [88.39833069, 21.95166588], [88.39833069, 21.95111084], [88.39749908, 21.95028114], [88.39749908, 21.95000076], [88.3972168, 21.94972038], [88.39722443, 21.94916725], [88.39694977, 21.94889069], [88.39694977, 21.94861984], [88.39666748, 21.94833183], [88.39666748, 21.94805527], [88.39554596, 21.94695282], [88.39560699, 21.94676018], [88.39549255, 21.94635582], [88.39527893, 21.94595337], [88.39503479, 21.94552612], [88.39480591, 21.94506073], [88.39464569, 21.94450951], [88.39441681, 21.94397163], [88.39418793, 21.94343948], [88.39398193, 21.94289589], [88.39383698, 21.94232941], [88.39362335, 21.94178009], [88.39346313, 21.94123077], [88.39331055, 21.94067955], [88.39321899, 21.94042206], [88.39312744, 21.94014549], [88.39299774, 21.93961906], [88.39283752, 21.93912125], [88.39277649, 21.93859291], [88.39277649, 21.93803978], [88.39277649, 21.93745995], [88.39284515, 21.93687057], [88.39303589, 21.93628502], [88.39322662, 21.93569183], [88.39347839, 21.93510056], [88.3936615, 21.9344635], [88.39402008, 21.93388939], [88.39437866, 21.93335342], [88.39459991, 21.93272781], [88.39479828, 21.93246078], [88.39497375, 21.93221855], [88.39530182, 21.93172836], [88.39570618, 21.93134117], [88.39610291, 21.93097115], [88.39647675, 21.93061066], [88.39691162, 21.93029022], [88.39729309, 21.92995262], [88.39769745, 21.92969322], [88.39809418, 21.92941284], [88.39850616, 21.92913055], [88.39891052, 21.92880058], [88.39933777, 21.92851448], [88.3996582, 21.92812538], [88.40011597, 21.92789078], [88.40047455, 21.92753029], [88.40090942, 21.92723083], [88.40141296, 21.92692947], [88.40189362, 21.9265728], [88.40234375, 21.92612648], [88.40283966, 21.92570114], [88.40335846, 21.92529106], [88.40387726, 21.92490005], [88.4043808, 21.92451096], [88.40471649, 21.92405128], [88.40497589, 21.92362976], [88.40518951, 21.92324066], [88.40534973, 21.92287064], [88.40554047, 21.92257118], [88.40572357, 21.92230415], [88.40584564, 21.92201042], [88.40597534, 21.92172241], [88.40597534, 21.92134094], [88.40601349, 21.92097092], [88.4061203, 21.92061043], [88.40624237, 21.92021179], [88.40636444, 21.91978455], [88.40635681, 21.91929817], [88.40625, 21.91883659], [88.40609741, 21.91839027], [88.40590668, 21.91797066], [88.40560913, 21.91763115], [88.40525055, 21.91728973], [88.40483856, 21.91694832], [88.40441132, 21.91660118], [88.40400696, 21.91618919], [88.40354919, 21.91580009], [88.40299988, 21.91549492], [88.40242004, 21.91521072], [88.40182495, 21.91498756], [88.40123749, 21.91477013], [88.4006958, 21.91469765], [88.40059662, 21.9146843], [88.40007019, 21.91445923], [88.39956665, 21.91423988], [88.39912415, 21.91402054], [88.39868164, 21.91366386], [88.39817047, 21.91344833], [88.39758301, 21.91333008], [88.3970108, 21.9132061], [88.39653015, 21.91299057], [88.3960495, 21.91289139], [88.39575958, 21.91254044], [88.39543915, 21.91225052], [88.39508057, 21.91201973], [88.39460754, 21.9118309], [88.39411926, 21.91164017], [88.39365387, 21.9113884], [88.39318085, 21.91110992], [88.39266205, 21.91083336], [88.3921051, 21.91055679], [88.39151001, 21.91028023], [88.39087677, 21.90999031], [88.39026642, 21.90966415], [88.38970947, 21.90925026], [88.38916779, 21.90880966], [88.38861847, 21.90838051], [88.38813019, 21.90809631], [88.38803101, 21.90803719], [88.38751984, 21.90767097], [88.38703918, 21.90742874], [88.38664246, 21.90715027], [88.38619232, 21.90691948], [88.38574982, 21.90665054], [88.3853302, 21.90627289], [88.38500214, 21.90579605], [88.38471985, 21.90530014], [88.3844223, 21.90484428], [88.3841095, 21.90442848], [88.38382721, 21.90398026], [88.3835144, 21.90356255], [88.38330841, 21.90303993], [88.38309479, 21.90249443], [88.38303375, 21.90188026], [88.3829422, 21.90143013], [88.38291168, 21.90127563], [88.38279724, 21.90068054], [88.38278198, 21.90007973], [88.38280487, 21.89948845], [88.38289642, 21.89891815], [88.38304138, 21.89838982], [88.38313293, 21.89792824], [88.38329315, 21.89755249], [88.38343048, 21.89718819], [88.38362122, 21.89683914], [88.38388062, 21.89648819], [88.3841629, 21.89610291], [88.38445282, 21.8956604], [88.38474274, 21.89520264], [88.38508606, 21.89476013], [88.38546753, 21.89434814], [88.38583374, 21.89392471], [88.3862915, 21.89359665], [88.38672638, 21.89324951], [88.38719177, 21.89285278], [88.38768768, 21.89246941], [88.38944244, 21.8908329], [88.39047241, 21.89002609], [88.3914032, 21.8895607], [88.39244843, 21.88941956], [88.39252472, 21.8893013], [88.3926239, 21.88915253], [88.39312744, 21.8890152], [88.39362335, 21.88875008], [88.39491272, 21.88781166], [88.39657593, 21.88638878], [88.39722443, 21.88583565], [88.39722443, 21.88555336], [88.39749908, 21.88528061], [88.3972168, 21.88389015], [88.39666748, 21.88278008], [88.39666748, 21.88249969], [88.39639282, 21.88221169], [88.39611053, 21.88138962], [88.39592743, 21.88019943], [88.39557648, 21.87971497], [88.39531708, 21.87916946], [88.39520264, 21.87853813], [88.39506531, 21.87791252], [88.39511871, 21.87723732], [88.39454651, 21.87650108], [88.39440155, 21.87535095], [88.39440155, 21.87434578], [88.39404297, 21.8730011], [88.39404297, 21.8703804], [88.39375305, 21.86870003], [88.39382935, 21.86727905], [88.39347076, 21.86358643], [88.39375305, 21.86305046], [88.39389038, 21.86277962], [88.39360809, 21.86250114], [88.39360809, 21.86166954], [88.39347076, 21.86025047], [88.39353943, 21.85951424], [88.39360809, 21.85823631], [88.39353943, 21.85568237], [88.39396667, 21.85413551], [88.39382935, 21.85231972], [88.3934021, 21.85144806], [88.39311981, 21.85117912], [88.39299011, 21.85078049], [88.39276123, 21.85039902], [88.39250183, 21.85004997], [88.39222717, 21.84972763], [88.39195251, 21.84941292], [88.39169312, 21.84906006], [88.39144135, 21.84866905], [88.39121246, 21.84826088], [88.39105988, 21.84784317], [88.39086151, 21.84755135], [88.39060211, 21.84736633], [88.39037323, 21.84716034], [88.39017487, 21.84691811], [88.38955688, 21.84613037], [88.38920593, 21.8454628], [88.38813019, 21.84445], [88.38704681, 21.84283257], [88.38577271, 21.83940315], [88.38562775, 21.83503342], [88.38634491, 21.82938576], [88.38749695, 21.82694435], [88.38748932, 21.82659912], [88.38777924, 21.82500076], [88.38804626, 21.82471848], [88.38805389, 21.82444382], [88.38833618, 21.82416725], [88.38833618, 21.82389069], [88.38861084, 21.82361031], [88.38861084, 21.82332993], [88.3888855, 21.82305527], [88.38889313, 21.82278061], [88.38916779, 21.82250023], [88.38916779, 21.82222748], [88.38944244, 21.82195091], [88.38944244, 21.82167053], [88.3897171, 21.82139015], [88.3897171, 21.82110977], [88.38999939, 21.82083321], [88.38999939, 21.82055664], [88.38999176, 21.82027626], [88.3897171, 21.81972122], [88.38972473, 21.81944656], [88.3904953, 21.81926155], [88.39038086, 21.81869125], [88.39051819, 21.81825066], [88.39076233, 21.81785011], [88.3910675, 21.81747055], [88.39126587, 21.81701088], [88.39118958, 21.81648636], [88.39129639, 21.81598091], [88.3914032, 21.81542969], [88.39160156, 21.81496811], [88.39169312, 21.81454086], [88.39192963, 21.81417274], [88.39216614, 21.81374168], [88.39225006, 21.81318092], [88.39205933, 21.81278992], [88.39186859, 21.81240463], [88.39185333, 21.8116684], [88.39221954, 21.81098175], [88.39231873, 21.81047821], [88.39257813, 21.81001091], [88.39256287, 21.80933762], [88.39250946, 21.80863953], [88.39250183, 21.80800629], [88.39250183, 21.8074398], [88.39250183, 21.80694962], [88.39248657, 21.80653954], [88.39241791, 21.80620384], [88.39226532, 21.80591011], [88.39226532, 21.80554581], [88.3924408, 21.80507088], [88.3924942, 21.804533], [88.3924942, 21.80394173], [88.39241028, 21.80333328], [88.39209747, 21.8028698], [88.39193726, 21.80278015], [88.39182281, 21.80235291], [88.3915329, 21.80126953], [88.39083099, 21.80005836], [88.39067078, 21.79898071], [88.38980103, 21.79797363], [88.38948822, 21.79774666], [88.38920593, 21.79751968], [88.38890839, 21.79734993], [88.3886261, 21.79713058], [88.3883667, 21.79685974], [88.38819122, 21.79652023], [88.38800049, 21.79617119], [88.38775635, 21.7958107], [88.38749695, 21.79541969], [88.38723755, 21.79502487], [88.38690948, 21.79467964], [88.3864975, 21.79446983], [88.3860321, 21.79432869], [88.38564301, 21.79409027], [88.38530731, 21.79372978], [88.38500977, 21.79334068], [88.38465881, 21.79299164], [88.38431549, 21.79267311], [88.38394165, 21.79244614], [88.38362885, 21.79227066], [88.38318634, 21.79207039], [88.38270569, 21.79196548], [88.38224792, 21.79190063], [88.38197327, 21.79169846], [88.38163757, 21.79158783], [88.38109589, 21.79216003], [88.38043213, 21.79231071], [88.37967682, 21.79220009], [88.37928009, 21.79249573], [88.37892151, 21.7928524], [88.37857819, 21.79319954], [88.37819672, 21.79346657], [88.37782288, 21.79371262], [88.37745667, 21.79400063], [88.3769989, 21.79421043], [88.37652588, 21.79445076], [88.37602234, 21.7947216], [88.37547302, 21.79499054], [88.37489319, 21.79528046], [88.37429047, 21.79554939], [88.37365723, 21.79576111], [88.3730011, 21.79586029], [88.37239838, 21.79603958], [88.37174225, 21.79610825], [88.37108612, 21.79616928], [88.37045288, 21.79635048], [88.36976624, 21.79639053], [88.3690567, 21.79642105], [88.36837006, 21.79653931], [88.36767578, 21.79668236], [88.36697388, 21.79685974], [88.36629486, 21.79698181], [88.36567688, 21.79717255], [88.36509705, 21.7972908], [88.36464691, 21.79749107], [88.3642807, 21.79767036], [88.36400604, 21.79783058], [88.36386871, 21.79805946], [88.3637085, 21.79825592], [88.36361694, 21.79857063], [88.3635788, 21.79896927], [88.36351776, 21.79940033], [88.36351013, 21.79988098], [88.36345673, 21.80039024], [88.36368561, 21.80075073], [88.36354828, 21.80132294], [88.36374664, 21.80170059], [88.36386871, 21.80205727], [88.36387634, 21.80238152], [88.36380005, 21.80265999], [88.36369324, 21.80296516], [88.36373138, 21.8032608], [88.3634491, 21.80365562], [88.36380768, 21.8039608], [88.36347961, 21.80476952], [88.36342621, 21.80540276], [88.36331177, 21.80602074], [88.36340332, 21.80659103], [88.36357117, 21.80713081], [88.36361694, 21.80764961], [88.36361694, 21.80814934], [88.36355591, 21.8086319], [88.3632431, 21.80903625], [88.36292267, 21.80955887], [88.36257172, 21.81018066], [88.36225128, 21.81085777], [88.36201477, 21.81153107], [88.36167908, 21.81198311], [88.36136627, 21.81241035], [88.36100769, 21.81277084], [88.36061096, 21.81306267], [88.36040497, 21.81334114], [88.36026001, 21.81377029], [88.36001587, 21.81407166], [88.35997772, 21.81423187], [88.35943604, 21.8145504], [88.35930634, 21.81483841], [88.35914612, 21.81511116], [88.35897064, 21.81537056], [88.35884094, 21.81567955], [88.35862732, 21.81596947], [88.35842133, 21.8162899], [88.35817719, 21.81666946], [88.35790253, 21.81706619], [88.35756683, 21.81742287], [88.35723877, 21.81776047], [88.35697937, 21.81808853], [88.35677338, 21.81838036], [88.35663605, 21.81868744], [88.35645294, 21.81892967], [88.35626221, 21.81918907], [88.35610962, 21.81947327], [88.3559494, 21.8197403], [88.35582733, 21.82005119], [88.35573578, 21.82036018], [88.35558319, 21.82072067], [88.35549164, 21.82115364], [88.35531616, 21.82162094], [88.35514069, 21.82212639], [88.35488129, 21.82279968], [88.35473633, 21.82347107], [88.35459137, 21.82509041], [88.35459137, 21.82683945], [88.35444641, 21.82817841], [88.35416412, 21.82925415], [88.35453033, 21.83011055], [88.35473633, 21.83060074], [88.35501862, 21.83262062], [88.35534668, 21.8350296], [88.35552979, 21.83554077], [88.35565948, 21.83607292], [88.35579681, 21.83661079], [88.35582733, 21.83719063], [88.35582733, 21.83781052], [88.35583496, 21.83842659], [88.35585785, 21.83905029], [88.35597992, 21.83966637], [88.35604858, 21.84030151], [88.35609436, 21.84099388], [88.35609436, 21.84151077], [88.35609436, 21.84172058], [88.35598755, 21.84242439], [88.35571289, 21.84303093], [88.35573578, 21.84361076], [88.35581207, 21.84412956], [88.355896, 21.8447094], [88.35561371, 21.84511757], [88.35562134, 21.84547043], [88.35557556, 21.84579659], [88.35562134, 21.84621239], [88.35578156, 21.84667969], [88.35582733, 21.84723663], [88.35577393, 21.84782219], [88.35559845, 21.84841347], [88.3555603, 21.84899139], [88.35555267, 21.84954453], [88.35555267, 21.85007477], [88.35556793, 21.8506031], [88.35562134, 21.85115242], [88.35569, 21.85174179], [88.35566711, 21.85236549], [88.3556366, 21.85294151], [88.35546875, 21.8534317], [88.35528564, 21.85386467], [88.35514069, 21.85429955], [88.35500336, 21.85474014], [88.35494232, 21.85518837], [88.35492706, 21.85565567], [88.35531616, 21.85612106], [88.35573578, 21.85663986], [88.35607147, 21.85717964], [88.35639954, 21.85762024], [88.35669708, 21.85804939], [88.35706329, 21.85838127], [88.35736847, 21.85869026], [88.35761261, 21.85900116], [88.35780334, 21.85932732], [88.35803986, 21.85963058], [88.35820007, 21.85995865], [88.35836029, 21.86027527], [88.35857391, 21.86051941], [88.35877228, 21.86077118], [88.35894775, 21.86104012], [88.35914612, 21.86125946], [88.35934448, 21.86149025], [88.35951996, 21.86174202], [88.35971832, 21.86204338], [88.35993195, 21.86242294], [88.36022949, 21.86284065], [88.36052704, 21.86338043], [88.36086273, 21.86399078], [88.36123657, 21.86456108], [88.36161804, 21.86498642], [88.36181641, 21.86540222], [88.36199951, 21.86570358], [88.36218262, 21.86592484], [88.36228943, 21.86619377], [88.36250305, 21.86642075], [88.36270905, 21.86671066], [88.36286926, 21.86704826], [88.36313629, 21.86732101], [88.36334229, 21.86761093], [88.36348724, 21.86790085], [88.36369324, 21.86815834], [88.36389923, 21.86844826], [88.36410522, 21.86880875], [88.36428833, 21.86925125], [88.36445618, 21.86977959], [88.36471558, 21.87028313], [88.36489105, 21.87072754], [88.36504364, 21.87124634], [88.3651886, 21.87158012], [88.36527252, 21.87190056], [88.36534882, 21.87219238], [88.36547852, 21.8724308], [88.36567688, 21.87268257], [88.36582947, 21.87298012], [88.36593628, 21.87337112], [88.36605072, 21.8738308], [88.36616516, 21.87434959], [88.36633301, 21.87483978], [88.3664093, 21.87532043], [88.366539, 21.87569046], [88.36666107, 21.87601089], [88.36675262, 21.87631989], [88.36691284, 21.87664032], [88.36694336, 21.87706947], [88.36699677, 21.8775692], [88.36714935, 21.87808037], [88.36725616, 21.87862015], [88.3674469, 21.87915039], [88.36752319, 21.87973022], [88.36765289, 21.88029289], [88.36775208, 21.88086891], [88.36779785, 21.88148117], [88.36789703, 21.88212967], [88.36807251, 21.88274956], [88.36828613, 21.88335037], [88.36833191, 21.88397026], [88.36834717, 21.88453102], [88.36846161, 21.88500977], [88.3685379, 21.88546944], [88.36859131, 21.88594818], [88.3686142, 21.88647461], [88.36862946, 21.8868103], [88.36864471, 21.88704872], [88.36876678, 21.88763428], [88.36891174, 21.88824081], [88.36909485, 21.88884926], [88.36915588, 21.88949013], [88.36917877, 21.89011002], [88.36924744, 21.89067078], [88.36943054, 21.89112091], [88.36956024, 21.89157104], [88.36972046, 21.89203072], [88.36984253, 21.89248085], [88.36995697, 21.89293289], [88.37001038, 21.89342117], [88.37008667, 21.89396286], [88.37025452, 21.89451981], [88.37039185, 21.8950901], [88.37052155, 21.89562035], [88.37055206, 21.89609146], [88.37055969, 21.89653015], [88.37055969, 21.89694595], [88.37055969, 21.89736176], [88.37054443, 21.89779854], [88.37051392, 21.89827156], [88.3704071, 21.8988018], [88.37033081, 21.89938927], [88.37024689, 21.89999008], [88.37013245, 21.90056229], [88.36997223, 21.90108109], [88.36977386, 21.90157127], [88.36960602, 21.902071], [88.36947632, 21.90257835], [88.36937714, 21.90306664], [88.36920929, 21.90349007], [88.3690567, 21.90393066], [88.36891937, 21.90437126], [88.3687973, 21.90478134], [88.3686676, 21.90512085], [88.36857605, 21.90544128], [88.36846161, 21.90570259], [88.36831665, 21.90594101], [88.36815643, 21.90619659], [88.36798096, 21.90646362], [88.36781311, 21.90673065], [88.36767578, 21.90705109], [88.36749268, 21.90739059], [88.36724854, 21.90780067], [88.36701202, 21.90833282], [88.36679077, 21.90895271], [88.36649323, 21.90949631], [88.36618805, 21.91001129], [88.36592102, 21.91049004], [88.36571503, 21.91095734], [88.36555481, 21.91139221], [88.36540222, 21.91179276], [88.36522675, 21.91213989], [88.36501312, 21.91245842], [88.36477661, 21.91279984], [88.36451721, 21.9131794], [88.36426544, 21.91361427], [88.36399078, 21.91407013], [88.36374664, 21.91455269], [88.36351776, 21.91503525], [88.36326599, 21.91550064], [88.36297607, 21.91597748], [88.36264801, 21.91645813], [88.3622818, 21.91697121], [88.36193848, 21.91755867], [88.36160278, 21.91817093], [88.3612442, 21.91871834], [88.36090088, 21.91918945], [88.36061096, 21.91964912], [88.36032104, 21.92008018], [88.36003876, 21.92045975], [88.3597641, 21.92084312], [88.35951233, 21.92122841], [88.35928345, 21.92162514], [88.35900116, 21.9219799], [88.35868073, 21.92233849], [88.35832214, 21.92270279], [88.35791016, 21.92307091], [88.35745239, 21.92346954], [88.35695648, 21.92389107], [88.35645294, 21.92431068], [88.35592651, 21.92465973], [88.35544586, 21.92497063], [88.35502625, 21.9252491], [88.35466003, 21.92550087], [88.35430908, 21.92571831], [88.35391998, 21.92592812], [88.35344696, 21.92613983], [88.35295868, 21.9263382], [88.35249329, 21.92654037], [88.35202026, 21.92673874], [88.35176086, 21.92685127], [88.35069275, 21.92738914], [88.35032654, 21.92746162], [88.34998322, 21.92738914], [88.34997559, 21.92718887], [88.35032654, 21.9267025], [88.35074615, 21.92638969], [88.35116577, 21.92611122], [88.35160065, 21.92585754], [88.35205841, 21.92563248], [88.35250854, 21.92538071], [88.35295868, 21.92514038], [88.35346222, 21.92490768], [88.35394287, 21.92465973], [88.35443115, 21.92440033], [88.35489655, 21.92413139], [88.3553772, 21.92383957], [88.35582733, 21.9235096], [88.35623169, 21.92313957], [88.35663605, 21.92274094], [88.35706329, 21.92233276], [88.35749054, 21.92193031], [88.35790253, 21.9215107], [88.35827637, 21.92105293], [88.35861206, 21.92053986], [88.3589325, 21.91999054], [88.35927582, 21.91942978], [88.35965729, 21.91893387], [88.36001587, 21.91845131], [88.36035156, 21.91798592], [88.360672, 21.91752052], [88.3609848, 21.91705513], [88.36128998, 21.91657066], [88.36157227, 21.91610527], [88.36183929, 21.91566277], [88.36211395, 21.91525459], [88.36236572, 21.91484833], [88.36258698, 21.91440964], [88.36280823, 21.91399956], [88.36302948, 21.91360855], [88.36322784, 21.91320992], [88.36342621, 21.91283989], [88.36364746, 21.91248131], [88.3638916, 21.91212082], [88.36414337, 21.91172981], [88.36437225, 21.91130257], [88.36457062, 21.91084099], [88.36477661, 21.91039085], [88.36500549, 21.91000175], [88.36521912, 21.90962982], [88.36538696, 21.90922165], [88.3655777, 21.90880775], [88.36579132, 21.90837097], [88.36598206, 21.90790749], [88.36618805, 21.90744972], [88.3664093, 21.90703011], [88.36663055, 21.90662956], [88.36679077, 21.90624046], [88.36695862, 21.90592194], [88.36712646, 21.90563011], [88.36727142, 21.90530968], [88.3674469, 21.90497971], [88.36754608, 21.90460014], [88.36769867, 21.90423965], [88.36781311, 21.90388107], [88.3679657, 21.90356827], [88.36808777, 21.90322113], [88.3682251, 21.90286255], [88.36831665, 21.90246964], [88.36837769, 21.90205956], [88.36847687, 21.9017067], [88.36857605, 21.901371], [88.36863708, 21.90096092], [88.36876678, 21.90048027], [88.36885834, 21.8998909], [88.36891937, 21.89921188], [88.3690033, 21.89852142], [88.36911774, 21.89788055], [88.36915588, 21.89725113], [88.36915588, 21.89661026], [88.36911011, 21.89596176], [88.36897278, 21.89530945], [88.36889648, 21.89466286], [88.36885834, 21.89406967], [88.36873627, 21.89359093], [88.36862946, 21.89315033], [88.36852264, 21.89272118], [88.36836243, 21.89233017], [88.36824799, 21.89190292], [88.36808777, 21.89151573], [88.36798859, 21.89106941], [88.367836, 21.89060974], [88.36776733, 21.89007759], [88.36767578, 21.889534], [88.36753845, 21.88898087], [88.3674469, 21.88840103], [88.36733246, 21.8878479], [88.36720276, 21.88730049], [88.36704254, 21.88680267], [88.36696625, 21.88626289], [88.36694336, 21.88570023], [88.36691284, 21.88512039], [88.36675262, 21.88457489], [88.36668396, 21.88400269], [88.36666107, 21.88344383], [88.36660767, 21.88292122], [88.36646271, 21.88245964], [88.36638641, 21.88195038], [88.36637115, 21.88146019], [88.36625671, 21.88097954], [88.36613464, 21.8805542], [88.36603546, 21.88015366], [88.36590576, 21.87978745], [88.36579132, 21.87945938], [88.36567688, 21.87914085], [88.36561584, 21.87881088], [88.3655777, 21.87841988], [88.36554718, 21.8780098], [88.36547852, 21.87759018], [88.36535645, 21.87721062], [88.36523438, 21.87685966], [88.36508942, 21.87650108], [88.36501312, 21.876091], [88.36495209, 21.87574005], [88.36480713, 21.87547112], [88.36472321, 21.87515068], [88.36463928, 21.87478065], [88.36446381, 21.87444687], [88.36429596, 21.87403107], [88.36414337, 21.87355042], [88.36390686, 21.8730793], [88.3637619, 21.87252808], [88.3636322, 21.87195015], [88.36353302, 21.87136078], [88.36330414, 21.87087822], [88.36303711, 21.87044907], [88.36281586, 21.87002945], [88.36264038, 21.86960983], [88.36244202, 21.86925125], [88.36221313, 21.8689003], [88.36199951, 21.86856079], [88.36180878, 21.86814117], [88.36151886, 21.86780739], [88.36116791, 21.86748123], [88.3609314, 21.86705208], [88.36060333, 21.86670303], [88.36029816, 21.86633873], [88.36006165, 21.8658905], [88.35983276, 21.86541939], [88.35949707, 21.86504745], [88.35917664, 21.86471748], [88.35888672, 21.86442947], [88.35861206, 21.864151], [88.35834503, 21.86389923], [88.35808563, 21.86362076], [88.35792542, 21.86322784], [88.35771942, 21.86284065], [88.3575058, 21.86248589], [88.35726929, 21.86214638], [88.35706329, 21.86181068], [88.35673523, 21.86159325], [88.35643768, 21.8613224], [88.35611725, 21.86099052], [88.35573578, 21.86066055], [88.35529327, 21.86032677], [88.3549118, 21.8599205], [88.3546524, 21.85942459], [88.3543396, 21.85900116], [88.35424805, 21.85845947], [88.35411835, 21.8579483], [88.35388184, 21.85750961], [88.35357666, 21.85715485], [88.35317993, 21.85692406], [88.35274506, 21.85674858], [88.35225677, 21.85687065], [88.35176086, 21.8569603], [88.35124969, 21.85708046], [88.3507309, 21.85716057], [88.3502121, 21.85699081], [88.34967041, 21.85695076], [88.34913635, 21.85694122], [88.34858704, 21.85694122], [88.34807587, 21.85695076], [88.34755707, 21.85695076], [88.34706116, 21.85695076], [88.34657288, 21.85695076], [88.34622192, 21.85694313], [88.34609985, 21.85694313], [88.34564972, 21.85694313], [88.34523773, 21.8569603], [88.34487915, 21.85707283], [88.3445282, 21.8572197], [88.34414673, 21.85737038], [88.34372711, 21.85752106], [88.34335327, 21.85775948], [88.34300232, 21.85804939], [88.34265137, 21.85832024], [88.34229279, 21.85859108], [88.34191132, 21.85886955], [88.34152222, 21.85916328], [88.34121704, 21.85943222], [88.34115601, 21.85949135], [88.34081268, 21.85984993], [88.34046173, 21.8602066], [88.34007263, 21.86050987], [88.33963013, 21.86078072], [88.33913422, 21.86098671], [88.33859253, 21.86112976], [88.3380661, 21.86131096], [88.33753967, 21.8614254], [88.3370285, 21.86161041], [88.33647919, 21.86166954], [88.33592224, 21.86172104], [88.3353653, 21.86187935], [88.3347168, 21.86198235], [88.33405304, 21.86211395], [88.33338928, 21.8619957], [88.3327179, 21.86197281], [88.3320694, 21.86203957], [88.33146667, 21.86214638], [88.33087921, 21.86218452], [88.33027649, 21.86218262], [88.32964325, 21.86216927], [88.32897186, 21.86215973], [88.32828522, 21.86216164], [88.32759857, 21.86215973], [88.32692719, 21.86215973], [88.32628632, 21.86215973], [88.32565308, 21.86215019], [88.32499695, 21.86207962], [88.32446289, 21.86190987], [88.32393646, 21.86174965], [88.3234024, 21.86164093], [88.32283783, 21.86156273], [88.32229614, 21.8614502], [88.32177734, 21.86135292], [88.32126617, 21.86123085], [88.32077789, 21.86107254], [88.32032013, 21.86090851], [88.31991577, 21.8607502], [88.31952667, 21.86059189], [88.3191452, 21.86048508], [88.3187561, 21.86034012], [88.31833649, 21.86024094], [88.31791687, 21.86012077], [88.31754303, 21.85997009], [88.31713867, 21.85980988], [88.31671906, 21.85969162], [88.31627655, 21.85954094], [88.31586456, 21.85932732], [88.31545258, 21.85910034], [88.31504059, 21.85885429], [88.31460571, 21.85858154], [88.31414032, 21.85829544], [88.31369019, 21.85798073], [88.31325531, 21.85765839], [88.31285858, 21.85726929], [88.31247711, 21.85680962], [88.31208038, 21.8563385], [88.31165314, 21.85584068], [88.31118774, 21.85544014], [88.31080627, 21.85553932], [88.31046295, 21.85572815], [88.31021118, 21.85596275], [88.30988312, 21.85610008], [88.30941772, 21.85621071], [88.30893707, 21.85639954], [88.30856323, 21.8568058], [88.3081131, 21.85716057], [88.30764008, 21.85749054], [88.30718231, 21.85778046], [88.30673981, 21.85805511], [88.30632019, 21.85833359], [88.3059082, 21.85860062], [88.30547333, 21.85884094], [88.30499268, 21.85902405], [88.30447388, 21.85922241], [88.30422974, 21.85935593], [88.30395508, 21.8595047], [88.30344391, 21.85987282], [88.30290985, 21.86021042], [88.30239868, 21.8605442], [88.30195618, 21.86082077], [88.30158997, 21.86103058], [88.30130005, 21.8611393], [88.30130005, 21.86136055], [88.30171204, 21.86206818], [88.30219269, 21.86268997], [88.30262756, 21.86314964], [88.30303192, 21.86348915], [88.30341339, 21.86381912], [88.30377197, 21.864151], [88.30413818, 21.86448669], [88.30449677, 21.86483192], [88.30486298, 21.86515999], [88.30519867, 21.8654995], [88.30555725, 21.86583138], [88.30590057, 21.86615944], [88.30623627, 21.86647987], [88.3065567, 21.86684608], [88.30680084, 21.86726952], [88.30699158, 21.86778831], [88.30718994, 21.86831474], [88.30737305, 21.86885071], [88.30753326, 21.86940956], [88.30770111, 21.86991882], [88.3078537, 21.87041473], [88.30800629, 21.87088013], [88.30812836, 21.87138367], [88.30825043, 21.87191963], [88.3083725, 21.87249947], [88.30853271, 21.87306023], [88.30867767, 21.87359047], [88.30883789, 21.8740406], [88.30901337, 21.87441826], [88.30915833, 21.8747406], [88.30928802, 21.87504959], [88.30942535, 21.87532806], [88.30956268, 21.87561035], [88.30973053, 21.87589073], [88.3098526, 21.87618065], [88.30999756, 21.87648773], [88.31009674, 21.87684059], [88.31011963, 21.87726974], [88.31001282, 21.87734795], [88.30979919, 21.87768364], [88.30944061, 21.87768364], [88.30918884, 21.87738991], [88.3088913, 21.87687302], [88.30882263, 21.87641716], [88.30864716, 21.87598038], [88.3084259, 21.87555122], [88.30815887, 21.87512016], [88.30789185, 21.87465096], [88.30767059, 21.87409019], [88.30745697, 21.87347031], [88.30725861, 21.87283325], [88.30706787, 21.87217522], [88.30690765, 21.87150192], [88.30680084, 21.87079811], [88.30673218, 21.87014961], [88.306633, 21.86961555], [88.30651093, 21.86917114], [88.30638123, 21.86881256], [88.30622101, 21.86847115], [88.30612946, 21.86829758], [88.30606079, 21.86816216], [88.30592346, 21.86784744], [88.30574799, 21.8675499], [88.30554962, 21.86722946], [88.30528259, 21.86692047], [88.30495453, 21.8666153], [88.30457306, 21.86630821], [88.30414581, 21.86600876], [88.30374146, 21.86567116], [88.30338287, 21.86530113], [88.30298615, 21.8649292], [88.30256653, 21.8645401], [88.3021698, 21.864151], [88.3017807, 21.86378288], [88.30145264, 21.8633709], [88.30117798, 21.86284828], [88.30109406, 21.86242676], [88.3010025, 21.86200142], [88.30059052, 21.86132622], [88.3003006, 21.8612709], [88.29982758, 21.86130905], [88.29928589, 21.86137009], [88.29872894, 21.8614006], [88.29812622, 21.8614006], [88.29751587, 21.86137962], [88.29686737, 21.86131096], [88.29615021, 21.86119843], [88.29544067, 21.86112976], [88.29477692, 21.86107254], [88.29420471, 21.86096573], [88.29367828, 21.86086845], [88.29315948, 21.86079025], [88.29265594, 21.8606987], [88.29213715, 21.86059189], [88.29161072, 21.8604908], [88.29106903, 21.86032677], [88.29051208, 21.86021805], [88.2899704, 21.86005592], [88.28942871, 21.85988045], [88.28884125, 21.85972786], [88.28820801, 21.85955238], [88.28759766, 21.8592701], [88.28694916, 21.85911179], [88.28629303, 21.85888863], [88.28559113, 21.85865021], [88.28486633, 21.85840988], [88.28409576, 21.85823822], [88.2833786, 21.85804939], [88.28269958, 21.85788727], [88.2820816, 21.85775948], [88.28156281, 21.85762978], [88.28109741, 21.85753822], [88.28066254, 21.85750771], [88.28024292, 21.85749054], [88.27983856, 21.85745621], [88.27945709, 21.85736084], [88.27908325, 21.85725975], [88.27867126, 21.85723114], [88.27820587, 21.8572197], [88.27765656, 21.8572197], [88.27703857, 21.8572197], [88.27632904, 21.8572197], [88.27558136, 21.85722733], [88.27481842, 21.85726357], [88.27407837, 21.85730171], [88.27341461, 21.85728836], [88.27281952, 21.85728073], [88.27224731, 21.85740089], [88.2718277, 21.8573513], [88.27162933, 21.85732841], [88.27106476, 21.85744858], [88.27048492, 21.85754395], [88.26990509, 21.85761452], [88.26935577, 21.85759735], [88.26883698, 21.85757065], [88.26835632, 21.85758018], [88.26782227, 21.85769272], [88.26729584, 21.85775948], [88.26677704, 21.85778999], [88.26628113, 21.85783958], [88.26580811, 21.8579483], [88.26532745, 21.85804939], [88.2648468, 21.85814476], [88.26438904, 21.85828018], [88.26390076, 21.85839081], [88.2634201, 21.85853767], [88.26293182, 21.85859489], [88.26244354, 21.85862541], [88.26197815, 21.85869026], [88.26154327, 21.85886192], [88.26111603, 21.85902977], [88.26068878, 21.85921288], [88.26026154, 21.85942268], [88.25979614, 21.85964012], [88.25933075, 21.85993004], [88.25892639, 21.86033058], [88.25858307, 21.86078072], [88.25823212, 21.86116982], [88.25795746, 21.86156273], [88.25776672, 21.86198997], [88.25760651, 21.86237907], [88.25747681, 21.86273193], [88.25733948, 21.86305618], [88.25726318, 21.86342049], [88.25721741, 21.86380959], [88.25712585, 21.86421967], [88.25701904, 21.86464119], [88.25694275, 21.86514091], [88.25685883, 21.86567116], [88.25673676, 21.86616707], [88.25665283, 21.86664963], [88.25653076, 21.86706924], [88.25643158, 21.86744308], [88.25637817, 21.86782074], [88.25630951, 21.86822128], [88.25615692, 21.8686409], [88.256073, 21.86914063], [88.25596619, 21.86970139], [88.25600433, 21.87030792], [88.25604248, 21.87043953], [88.25615692, 21.87088966], [88.25639343, 21.87143517], [88.25668335, 21.87194061], [88.25697327, 21.8724308], [88.25728607, 21.87293053], [88.25760651, 21.87338638], [88.25799561, 21.87380981], [88.25839996, 21.87420273], [88.25879669, 21.8746109], [88.25921631, 21.87498093], [88.25964355, 21.87532425], [88.26002502, 21.87572289], [88.26037598, 21.87615967], [88.26077271, 21.87659073], [88.26117706, 21.8769989], [88.26159668, 21.87739944], [88.26200104, 21.87778091], [88.26235199, 21.87817764], [88.26268005, 21.87861443], [88.26299286, 21.8791008], [88.26332855, 21.8795948], [88.26377869, 21.88000488], [88.26425171, 21.88042259], [88.2647171, 21.8808403], [88.26517487, 21.88127327], [88.26563263, 21.88170242], [88.26609802, 21.88208389], [88.2665329, 21.88243294], [88.26693726, 21.88273811], [88.26734924, 21.88299561], [88.26774597, 21.88322067], [88.26821136, 21.88339043], [88.26863098, 21.88360023], [88.26902008, 21.88383675], [88.26940155, 21.88409233], [88.26979065, 21.88435173], [88.27009583, 21.88499069], [88.2698822, 21.88512039], [88.26973724, 21.88519287], [88.26959991, 21.88519287], [88.26924896, 21.88486099], [88.26866913, 21.88459015], [88.26832581, 21.88436127], [88.26777649, 21.88418961], [88.26729584, 21.88397026], [88.26683044, 21.88373184], [88.26667023, 21.88360977], [88.26638794, 21.88361168], [88.26611328, 21.88333321], [88.26576233, 21.88293076], [88.26442719, 21.88194275], [88.26416779, 21.88194466], [88.2638855, 21.88166618], [88.2636795, 21.88159943], [88.26286316, 21.88061905], [88.26278687, 21.88021278], [88.26243591, 21.8799324], [88.26222229, 21.8797226], [88.26194763, 21.87944412], [88.26194763, 21.87916756], [88.26139069, 21.87861061], [88.26094818, 21.87825966], [88.26038361, 21.87779427], [88.25984192, 21.877285], [88.25933075, 21.87675095], [88.25884247, 21.87619781], [88.25830841, 21.87569809], [88.25779724, 21.87519073], [88.25734711, 21.87471008], [88.25700378, 21.87423515], [88.25666046, 21.87375069], [88.2563324, 21.87330246], [88.25602722, 21.87293816], [88.25576019, 21.87261009], [88.25549316, 21.8722496], [88.25527954, 21.87194061], [88.25489807, 21.8713398], [88.25469208, 21.87060165], [88.25475311, 21.8698597], [88.25481415, 21.86893082], [88.25483704, 21.86853027], [88.25495148, 21.86822319], [88.25502014, 21.86785126], [88.25507355, 21.86743927], [88.25518036, 21.8670311], [88.25524902, 21.86660194], [88.25527954, 21.86614037], [88.25528717, 21.86566925], [88.25530243, 21.86516953], [88.25535583, 21.86468315], [88.25548553, 21.86420631], [88.25559235, 21.86375237], [88.25571442, 21.86335182], [88.25584412, 21.8629837], [88.25598145, 21.86263275], [88.25611877, 21.86228561], [88.2562561, 21.86194038], [88.25641632, 21.86157036], [88.2565918, 21.86120224], [88.25682068, 21.86082649], [88.25708771, 21.86045265], [88.25740051, 21.8601017], [88.25772858, 21.85975075], [88.25811005, 21.85944366], [88.25850677, 21.85913277], [88.2589035, 21.85880661], [88.25932312, 21.85849953], [88.25977325, 21.85827065], [88.2602005, 21.85806084], [88.26059723, 21.85786057], [88.26106262, 21.85771942], [88.26154327, 21.85758018], [88.26209259, 21.85747147], [88.26268768, 21.85733223], [88.26335144, 21.85717201], [88.26400757, 21.85694122], [88.26467896, 21.85671616], [88.26537323, 21.85655975], [88.2660675, 21.85642815], [88.26674652, 21.85639572], [88.26741028, 21.85639954], [88.26805878, 21.85645294], [88.26869965, 21.8565197], [88.26918793, 21.85639954], [88.26965332, 21.85625076], [88.27005768, 21.85613632], [88.27046967, 21.85606003], [88.27085876, 21.85596275], [88.27121735, 21.85591507], [88.27155304, 21.85596275], [88.27188873, 21.85605049], [88.27227783, 21.8560009], [88.27275085, 21.85587502], [88.27327728, 21.85584068], [88.27381897, 21.85583115], [88.27436066, 21.85583115], [88.27490234, 21.85583115], [88.27545166, 21.85583115], [88.27558899, 21.85583305], [88.27601624, 21.85584068], [88.27644348, 21.85583115], [88.27658081, 21.85583115], [88.27713776, 21.85581017], [88.27765656, 21.85570335], [88.27816772, 21.8556118], [88.27867126, 21.85557365], [88.27915192, 21.8556118], [88.27955627, 21.85569572], [88.27993011, 21.85581017], [88.28029633, 21.85589027], [88.28064728, 21.85603523], [88.28107452, 21.85610008], [88.28156281, 21.8561306], [88.28203583, 21.85619926], [88.2824707, 21.85634995], [88.2829361, 21.85641098], [88.28340149, 21.85649109], [88.28385925, 21.85662079], [88.28430939, 21.8567791], [88.28475189, 21.85689545], [88.28521729, 21.85693169], [88.28568268, 21.85699081], [88.28608704, 21.85711098], [88.28650665, 21.85726929], [88.28690338, 21.85747147], [88.28734589, 21.85757065], [88.28775024, 21.85775757], [88.28816223, 21.85791969], [88.28865051, 21.85803604], [88.28917694, 21.85811043], [88.28965759, 21.85828972], [88.29014587, 21.85832977], [88.29061127, 21.85840034], [88.29105377, 21.85851479], [88.29147339, 21.85868454], [88.29190063, 21.85883141], [88.2923584, 21.858881], [88.29282379, 21.85895348], [88.29329681, 21.85901451], [88.29377747, 21.85909653], [88.29427338, 21.85920143], [88.29482269, 21.8592205], [88.29543304, 21.85929108], [88.29606628, 21.85944939], [88.29673767, 21.85965157], [88.29740906, 21.85962868], [88.29805756, 21.85948181], [88.29869843, 21.85943985], [88.29931641, 21.85938072], [88.29988861, 21.85920143], [88.30046082, 21.85909081], [88.30097198, 21.858881], [88.30148315, 21.85861015], [88.30203247, 21.85831261], [88.30257416, 21.85796547], [88.30303192, 21.85752106], [88.30334473, 21.85703468], [88.30366516, 21.8566494], [88.30391693, 21.85647774], [88.30403137, 21.85639572], [88.30438232, 21.85618973], [88.30471039, 21.8559761], [88.30504608, 21.85572052], [88.30538177, 21.85544014], [88.30567932, 21.85507011], [88.30594635, 21.85473061], [88.30628204, 21.8544426], [88.30667114, 21.85417938], [88.30710602, 21.85400009], [88.30754852, 21.85388184], [88.30793762, 21.85375023], [88.30840302, 21.85363007], [88.3088913, 21.85358238], [88.30934143, 21.85344124], [88.30980682, 21.85330009], [88.31031036, 21.85304832], [88.31080627, 21.85271263], [88.31121063, 21.8521595], [88.31156158, 21.85168266], [88.31178284, 21.85121155], [88.31201172, 21.85078049], [88.3122406, 21.85041809], [88.31247711, 21.85011101], [88.31266785, 21.84980965], [88.31281281, 21.84950066], [88.31297302, 21.84921646], [88.31310272, 21.84892273], [88.31327057, 21.84861946], [88.31339264, 21.84824944], [88.31358337, 21.84784126], [88.31376648, 21.84730911], [88.31381226, 21.84678268], [88.31382751, 21.84660721], [88.31375885, 21.84591103], [88.31363678, 21.84528351], [88.31352997, 21.84470177], [88.31331635, 21.84424019], [88.3130722, 21.8438282], [88.31284332, 21.84338188], [88.31262207, 21.84287643], [88.31243896, 21.84230995], [88.31221008, 21.84178925], [88.31196594, 21.84128952], [88.31179047, 21.8408165], [88.31163025, 21.84034157], [88.31143951, 21.83988953], [88.31130219, 21.83940125], [88.31109619, 21.83896065], [88.31084442, 21.83855438], [88.31060028, 21.83813858], [88.31033325, 21.83781052], [88.31011963, 21.83740997], [88.31002045, 21.83718872], [88.30993652, 21.83699417], [88.30970764, 21.83659744], [88.30944824, 21.83623123], [88.30918884, 21.83583069], [88.30900574, 21.83538055], [88.30884552, 21.83489799], [88.30860901, 21.83447075], [88.3083725, 21.83406258], [88.30815887, 21.83366394], [88.30795288, 21.83327293], [88.30774689, 21.83288956], [88.30748749, 21.83252907], [88.30719757, 21.83218956], [88.30691528, 21.83184814], [88.30664825, 21.83147812], [88.30638123, 21.83109283], [88.3060379, 21.83068275], [88.30560303, 21.83031845], [88.30506897, 21.8300209], [88.30453491, 21.82976723], [88.30407715, 21.82945061], [88.30367279, 21.8291111], [88.30329895, 21.82876015], [88.30290222, 21.82845688], [88.30245209, 21.82826042], [88.30201721, 21.82806969], [88.30158234, 21.8278904], [88.30111694, 21.8277607], [88.30065918, 21.82760048], [88.30020905, 21.82741928], [88.29978943, 21.82721138], [88.29938507, 21.82698059], [88.29896545, 21.82677841], [88.29852295, 21.82665825], [88.29808044, 21.82653046], [88.29762268, 21.82638359], [88.29718781, 21.82622528], [88.29673767, 21.82612991], [88.29625702, 21.82609749], [88.29577637, 21.82603073], [88.29528809, 21.82587051], [88.29472351, 21.82583427], [88.29410553, 21.82579231], [88.29348755, 21.82561493], [88.29284668, 21.82555962], [88.29220581, 21.82554817], [88.29155731, 21.82555962], [88.2914505, 21.8255558], [88.2909317, 21.82553482], [88.29032135, 21.82543373], [88.28972626, 21.82526207], [88.28911591, 21.82506943], [88.28848267, 21.82508278], [88.2878418, 21.82506943], [88.2871933, 21.82500076], [88.2865448, 21.8249054], [88.28601837, 21.82471848], [88.2855072, 21.82452965], [88.28498077, 21.82439995], [88.28447723, 21.82428551], [88.28401947, 21.82418251], [88.28358459, 21.82411766], [88.28317261, 21.82394409], [88.28270721, 21.82387733], [88.28225708, 21.82378006], [88.28182983, 21.82361984], [88.2813797, 21.82347107], [88.28092194, 21.82331085], [88.28050995, 21.82308006], [88.28005981, 21.82295227], [88.27964783, 21.82278824], [88.27923584, 21.82263947], [88.27882385, 21.82251167], [88.27838898, 21.82240677], [88.27796936, 21.82222748], [88.27754974, 21.82208443], [88.27709198, 21.82191467], [88.27664948, 21.82166481], [88.27619934, 21.82139015], [88.27574158, 21.82110977], [88.27527618, 21.82083321], [88.27481079, 21.82055664], [88.27433014, 21.82029915], [88.2738266, 21.82009125], [88.27330017, 21.81994057], [88.27285767, 21.81969261], [88.27246857, 21.81940079], [88.27210236, 21.81908035], [88.2716217, 21.81888962], [88.27110291, 21.81874084], [88.27056885, 21.81859016], [88.2700882, 21.81833076], [88.2696228, 21.81807327], [88.26914215, 21.81784058], [88.26867676, 21.81762123], [88.26835632, 21.81727982], [88.26798248, 21.81697083], [88.26756287, 21.81671143], [88.26711273, 21.81643867], [88.26663208, 21.8161602], [88.26610565, 21.81582451], [88.26557159, 21.81542587], [88.2650528, 21.81496811], [88.26451874, 21.81451797], [88.26391602, 21.81417274], [88.26339722, 21.81379509], [88.26296234, 21.81336021], [88.26277924, 21.81318474], [88.2625351, 21.81295013], [88.262146, 21.81253815], [88.26174927, 21.81216049], [88.26139069, 21.81175995], [88.26107788, 21.81137085], [88.26081085, 21.81096077], [88.26073456, 21.81085205], [88.26053619, 21.81058121], [88.26025391, 21.81022072], [88.25998688, 21.80986023], [88.25976562, 21.80952263], [88.25960541, 21.8091774], [88.25948334, 21.80885124], [88.25940704, 21.80850983], [88.25926208, 21.80823898], [88.25914001, 21.80792809], [88.25897217, 21.807621], [88.25885773, 21.80721092], [88.25868225, 21.80677986], [88.25858307, 21.80626106], [88.25846863, 21.80594254], [88.25840759, 21.80578041], [88.2583313, 21.80527115], [88.25827026, 21.80474091], [88.25823212, 21.80416107], [88.25828552, 21.8035202], [88.25832367, 21.80281258], [88.2583313, 21.80208778], [88.2583313, 21.80141068], [88.25836182, 21.80076981], [88.25852203, 21.80022812], [88.25863647, 21.79971123], [88.25884247, 21.79926109], [88.25894928, 21.79875183], [88.2591629, 21.79828262], [88.25940704, 21.79783821], [88.25965881, 21.79741096], [88.25984955, 21.79693222], [88.26004791, 21.79644203], [88.26028442, 21.79596329], [88.26055145, 21.79548073], [88.26081848, 21.794981], [88.26107788, 21.79448128], [88.26133728, 21.7939682], [88.26145935, 21.79344749], [88.26164246, 21.79297066], [88.26182556, 21.79249763], [88.26200104, 21.79203033], [88.26222992, 21.79162025], [88.26246643, 21.79120064], [88.26262665, 21.79068947], [88.26277924, 21.79013062], [88.26293945, 21.78957748], [88.2631073, 21.78906822], [88.26332092, 21.78866959], [88.26348877, 21.78831863], [88.2636261, 21.78800011], [88.26377869, 21.78772926], [88.26390839, 21.78745079], [88.26405334, 21.78717995], [88.26418304, 21.78689957], [88.264328, 21.78663063], [88.26447296, 21.78635025], [88.26463318, 21.78609085], [88.26476288, 21.78580093], [88.26491547, 21.78554916], [88.26509094, 21.78530121], [88.26526642, 21.7850399], [88.26547241, 21.78473091], [88.26573181, 21.78440475], [88.26603699, 21.78399467], [88.2664032, 21.78356552], [88.2667923, 21.78312111], [88.2670517, 21.78256989], [88.26722717, 21.78226852], [88.26734161, 21.78206444], [88.26764679, 21.78158951], [88.26794434, 21.78116608], [88.26830292, 21.78078079], [88.26863861, 21.78037643], [88.26898193, 21.77997971], [88.26922607, 21.77953911], [88.26947784, 21.77916527], [88.26970673, 21.77886963], [88.26989746, 21.77859116], [88.27002716, 21.77828979], [88.27021027, 21.7780304], [88.27038574, 21.77774429], [88.27058411, 21.77742767], [88.27082825, 21.77709961], [88.27108002, 21.77672958], [88.27134705, 21.77635384], [88.27161407, 21.7759552], [88.27192688, 21.77556038], [88.27223969, 21.77513123], [88.27257538, 21.77470589], [88.27295685, 21.77431107], [88.27336121, 21.77390671], [88.2738266, 21.7735405], [88.27430725, 21.77313042], [88.27484894, 21.77276993], [88.27542114, 21.77241707], [88.27597809, 21.77206039], [88.27642059, 21.77160263], [88.27639008, 21.77139091], [88.27694702, 21.77139091], [88.27749634, 21.77082825], [88.27777863, 21.77083397], [88.27861023, 21.77000046], [88.27861023, 21.76971817], [88.27889252, 21.76944351], [88.27889252, 21.76916885], [88.27916718, 21.76889038], [88.27945709, 21.76826096], [88.27970886, 21.7677803], [88.27997589, 21.76734161], [88.28026581, 21.76685905], [88.28056335, 21.76638985], [88.28111267, 21.76583099], [88.28111267, 21.76555443], [88.28138733, 21.76556015], [88.28193665, 21.76501083], [88.28193665, 21.76444054], [88.28221893, 21.76416588], [88.28221893, 21.76305962], [88.28231812, 21.76267815], [88.28259277, 21.76217079], [88.2824707, 21.76165962], [88.2822113, 21.76132011], [88.28193665, 21.76110077], [88.28166199, 21.7610817], [88.28112793, 21.76156807], [88.28063965, 21.7618618], [88.28013611, 21.76208115], [88.27961731, 21.76229668], [88.27916718, 21.76259041], [88.27874756, 21.76288033], [88.27825928, 21.76308823], [88.277771, 21.76329994], [88.27728271, 21.76344872], [88.2767868, 21.76362991], [88.27633667, 21.76383018], [88.27583313, 21.76392937], [88.27533722, 21.76408958], [88.27482605, 21.7642498], [88.2743454, 21.76446724], [88.27388, 21.76470184], [88.27339935, 21.76490784], [88.27289581, 21.7650795], [88.27243042, 21.76531792], [88.27199554, 21.76561165], [88.27155304, 21.76594162], [88.27108002, 21.7663002], [88.27057648, 21.7666893], [88.27011108, 21.76713943], [88.2696991, 21.76764107], [88.26930237, 21.76813126], [88.26893616, 21.76865005], [88.26857758, 21.76914406], [88.26818085, 21.76958084], [88.2678833, 21.77006912], [88.26763916, 21.7705555], [88.26742554, 21.77100945], [88.26719666, 21.77140045], [88.2669754, 21.77174377], [88.2667923, 21.77207184], [88.26661682, 21.77235222], [88.26644135, 21.77260971], [88.26628876, 21.77289009], [88.26610565, 21.77312851], [88.26590729, 21.77337074], [88.26570129, 21.77366066], [88.2654953, 21.77398682], [88.26522827, 21.77431679], [88.2649231, 21.77464485], [88.26460266, 21.77495956], [88.26425934, 21.77526093], [88.26391602, 21.77555656], [88.26361847, 21.77589035], [88.26332855, 21.77625465], [88.26304626, 21.77662086], [88.26275635, 21.77696991], [88.2624588, 21.77730942], [88.26215363, 21.77763748], [88.26182556, 21.77796173], [88.26148987, 21.77827263], [88.26113892, 21.77856445], [88.26078033, 21.77884483], [88.26042938, 21.77913094], [88.26008606, 21.77943039], [88.25974274, 21.77972794], [88.25940704, 21.78001976], [88.25904083, 21.78031158], [88.25868988, 21.78059006], [88.25833893, 21.78087997], [88.25799561, 21.78118706], [88.2576828, 21.78152275], [88.25740814, 21.78187943], [88.25710297, 21.7822094], [88.25675201, 21.78250885], [88.25640106, 21.78280258], [88.25608063, 21.78314972], [88.25582123, 21.78356552], [88.25557709, 21.7840004], [88.25536346, 21.78446007], [88.25523376, 21.78494835], [88.25508881, 21.78539467], [88.25501251, 21.7858448], [88.25493622, 21.78624916], [88.25482178, 21.7866497], [88.25476074, 21.78705025], [88.25474548, 21.78747749], [88.25473785, 21.78792381], [88.25473022, 21.78838348], [88.25467682, 21.78886414], [88.25456238, 21.78936958], [88.25449371, 21.78996086], [88.2544632, 21.79058075], [88.25443268, 21.79120064], [88.25435638, 21.79179955], [88.25423431, 21.79237175], [88.2541275, 21.79296112], [88.25400543, 21.79356194], [88.25392914, 21.79417992], [88.2538681, 21.79479027], [88.25377655, 21.79535484], [88.25364685, 21.79586029], [88.25356293, 21.79635048], [88.25343323, 21.79680824], [88.2533493, 21.79731178], [88.2532959, 21.79785156], [88.25321198, 21.79838943], [88.25306702, 21.79888916], [88.25298309, 21.79938126], [88.25286102, 21.79982948], [88.25282288, 21.80031967], [88.25283051, 21.80083275], [88.25287628, 21.80133057], [88.25283051, 21.80181885], [88.25273895, 21.80230141], [88.25263977, 21.80282402], [88.25250244, 21.80277824], [88.25166321, 21.80194283], [88.25166321, 21.80111122], [88.25195312, 21.80083275], [88.2519455, 21.79833412], [88.25200653, 21.79798317], [88.25212097, 21.79749107], [88.25224304, 21.79696274], [88.25235748, 21.79639816], [88.25251007, 21.79585075], [88.25262451, 21.79527283], [88.25276184, 21.79469681], [88.25286865, 21.79408073], [88.25296783, 21.79347038], [88.25305939, 21.79289055], [88.25311279, 21.79231834], [88.25314331, 21.79175949], [88.2532196, 21.79120827], [88.25336456, 21.79061127], [88.25354004, 21.78999138], [88.25362396, 21.78940201], [88.25357819, 21.78883743], [88.25350952, 21.78829002], [88.25353241, 21.78776932], [88.25361633, 21.78729248], [88.25366974, 21.78678513], [88.25372314, 21.78627968], [88.25379944, 21.78583145], [88.25389099, 21.78540039], [88.25393677, 21.78499985], [88.25399017, 21.78457832], [88.25406647, 21.78414917], [88.25419617, 21.78372955], [88.25434113, 21.78329277], [88.25457001, 21.78292084], [88.25485229, 21.78256989], [88.2551651, 21.78224564], [88.25550079, 21.78190994], [88.25583649, 21.78154945], [88.2562027, 21.78117943], [88.25659943, 21.78085327], [88.2570343, 21.78052521], [88.25746918, 21.78014946], [88.25790405, 21.77972984], [88.25834656, 21.77927971], [88.25879669, 21.7788105], [88.25934601, 21.77839088], [88.25990295, 21.77799034], [88.26040649, 21.7775631], [88.26085663, 21.77707291], [88.26130676, 21.77659035], [88.2617569, 21.77610016], [88.26222992, 21.77562714], [88.26270294, 21.77515984], [88.26316833, 21.77468109], [88.26361847, 21.77419853], [88.2640686, 21.77371979], [88.26449585, 21.77324104], [88.26487732, 21.77273941], [88.26521301, 21.77225113], [88.26548767, 21.7717495], [88.26570892, 21.77124977], [88.26592255, 21.77078056], [88.26616669, 21.7703476], [88.2664032, 21.76992035], [88.26660156, 21.76950645], [88.266716, 21.76914978], [88.26664734, 21.76876068], [88.26682281, 21.76861954], [88.26716614, 21.76843262], [88.26748657, 21.76809692], [88.26785278, 21.76770973], [88.26825714, 21.76729965], [88.2687149, 21.76688385], [88.26913452, 21.76641273], [88.26954651, 21.76592827], [88.26998901, 21.76548004], [88.27043152, 21.7650528], [88.27086639, 21.76465988], [88.27128601, 21.76428986], [88.27170563, 21.76400566], [88.27216339, 21.76378822], [88.2726593, 21.76365089], [88.27316284, 21.76357079], [88.27365875, 21.76342964], [88.27411652, 21.76329994], [88.27455139, 21.76310158], [88.27498627, 21.76292038], [88.27542114, 21.76272964], [88.27584076, 21.76251793], [88.27628326, 21.7623291], [88.27672577, 21.762146], [88.27713013, 21.76192093], [88.27754974, 21.76168251], [88.27802277, 21.76145363], [88.27859497, 21.76128197], [88.27922058, 21.76108742], [88.27986145, 21.76083183], [88.28054047, 21.76052094], [88.28114319, 21.76008034], [88.28167725, 21.75963974], [88.28196716, 21.75908089], [88.28226471, 21.75856209], [88.28253174, 21.75803757], [88.28273773, 21.75758171], [88.28279114, 21.75703049], [88.28275299, 21.75641251], [88.28260803, 21.75589561], [88.28250122, 21.75544167], [88.28237915, 21.75502014], [88.28221893, 21.7546196], [88.2820282, 21.75422096], [88.28187561, 21.75382805], [88.28165436, 21.75346947], [88.28141022, 21.75312996], [88.28121948, 21.75274658], [88.28105927, 21.75230026], [88.28082275, 21.75182915], [88.28050995, 21.75131989], [88.28005981, 21.75084686], [88.27971649, 21.75019264], [88.27939606, 21.74953842], [88.27894592, 21.74901962], [88.27848053, 21.74860191], [88.27807617, 21.74814987], [88.27777863, 21.74764061], [88.27745819, 21.74711037], [88.2770462, 21.74662018], [88.27670288, 21.74604034], [88.27642822, 21.7453804], [88.27632141, 21.74463463], [88.27606201, 21.7440052], [88.27562714, 21.74357986], [88.27523804, 21.74319077], [88.27497101, 21.74285126], [88.27471924, 21.74253273], [88.27449036, 21.74221039], [88.27439117, 21.7418251], [88.27422333, 21.74151039], [88.27413177, 21.74115944], [88.27394104, 21.74084091], [88.27387238, 21.74042892], [88.27374268, 21.7399807], [88.27359009, 21.73948288], [88.27334595, 21.73900032], [88.27320862, 21.73849106], [88.27310944, 21.73805237], [88.27326202, 21.73755836], [88.27345276, 21.73706245], [88.27351379, 21.73651123], [88.27328491, 21.73591805], [88.27301788, 21.73529053], [88.27304077, 21.73457527], [88.27282715, 21.73402977], [88.27278137, 21.73347664], [88.27276611, 21.73290825], [88.27272797, 21.73233032], [88.27257538, 21.73179054], [88.27263641, 21.73128128], [88.2724762, 21.73090935], [88.27223969, 21.73064995], [88.27200317, 21.73048019], [88.27159882, 21.73052979], [88.27115631, 21.73055077], [88.27079773, 21.73054123], [88.27039337, 21.7304821], [88.26995087, 21.73035622], [88.26966858, 21.73031425], [88.26947021, 21.73028755], [88.26896667, 21.73027992], [88.26847076, 21.73027992], [88.26796722, 21.7302494], [88.26747131, 21.73012543], [88.266922, 21.73002052], [88.26669312, 21.73001289], [88.26628876, 21.72999954], [88.26568604, 21.73003006], [88.26519775, 21.73021126], [88.26470184, 21.73031044], [88.26423645, 21.73051071], [88.26377106, 21.73062706], [88.26344299, 21.73092461], [88.26329803, 21.73138046], [88.26313019, 21.73181725], [88.26329041, 21.73223114], [88.26334381, 21.73264694], [88.26344299, 21.73301125], [88.26361847, 21.73335075], [88.26386261, 21.73371124], [88.26410675, 21.73415947], [88.26445007, 21.73463058], [88.2648468, 21.73511124], [88.26528931, 21.73552895], [88.26571655, 21.73591423], [88.26611328, 21.73629189], [88.26634216, 21.73651886], [88.26648712, 21.73666191], [88.26685333, 21.73703003], [88.26721191, 21.73740959], [88.26750183, 21.73782158], [88.26777649, 21.7382412], [88.26805878, 21.73867035], [88.26832581, 21.73911095], [88.26862335, 21.73953819], [88.26891327, 21.73994064], [88.26919556, 21.7403183], [88.26947784, 21.74072075], [88.26980591, 21.74111557], [88.27012634, 21.74153328], [88.27036285, 21.74201965], [88.27059937, 21.74250031], [88.27085114, 21.74299049], [88.27108765, 21.74348068], [88.27124023, 21.74401093], [88.27139282, 21.74451065], [88.27149963, 21.74495125], [88.27163696, 21.74530983], [88.27171326, 21.74568939], [88.27189636, 21.74603081], [88.27199554, 21.74649048], [88.27220154, 21.74695206], [88.27233124, 21.74744987], [88.2724762, 21.74789047], [88.27259827, 21.74827957], [88.27275848, 21.74859047], [88.27285767, 21.74895287], [88.2730484, 21.74930954], [88.27321625, 21.74975967], [88.27339172, 21.7503109], [88.27366638, 21.75089073], [88.27394867, 21.75152969], [88.27411652, 21.75224113], [88.27420044, 21.75298119], [88.27424622, 21.7536602], [88.27413177, 21.75418854], [88.27388763, 21.75462532], [88.27359009, 21.75504112], [88.27323914, 21.7554512], [88.27278137, 21.75575066], [88.27229309, 21.75603294], [88.27176666, 21.75629044], [88.27118683, 21.75655174], [88.27050018, 21.75671005], [88.2698288, 21.75689888], [88.26911926, 21.75694466], [88.26876831, 21.75694656], [88.26841736, 21.75694847], [88.26773071, 21.75694084], [88.2670517, 21.75694466], [88.26641083, 21.75694466], [88.26582336, 21.75694466], [88.26530457, 21.75694466], [88.2648468, 21.75694275], [88.26439667, 21.75694084], [88.26392365, 21.7569809], [88.26338196, 21.75713539], [88.26272583, 21.75720024], [88.26204681, 21.75722122], [88.2613678, 21.75722122], [88.26068115, 21.75722122], [88.25998688, 21.75722122], [88.25932312, 21.75723076], [88.25863647, 21.75726128], [88.25798035, 21.75733948], [88.25730896, 21.7574482], [88.25662231, 21.75749016], [88.25592804, 21.75749969], [88.25526428, 21.75749969], [88.25466919, 21.75750923], [88.25417328, 21.75758171], [88.25370789, 21.75769043], [88.2532196, 21.757761], [88.25274658, 21.75782013], [88.25229645, 21.75798035], [88.25180817, 21.7580204], [88.25131226, 21.75805855], [88.25080109, 21.75814819], [88.25028229, 21.75827408], [88.24973297, 21.75832367], [88.24920654, 21.75836945], [88.24877167, 21.7585392], [88.24828339, 21.75862122], [88.24776459, 21.75872612], [88.2472229, 21.75884056], [88.24664307, 21.75893021], [88.24611664, 21.75911713], [88.24560547, 21.75916481], [88.24510193, 21.75918961], [88.24459839, 21.75928879], [88.24408722, 21.75939941], [88.24359131, 21.75945854], [88.24311829, 21.75954056], [88.24267578, 21.75967789], [88.24217987, 21.75976944], [88.24167633, 21.7599411], [88.24111176, 21.76002121], [88.24054718, 21.76013184], [88.24001312, 21.76024055], [88.23950958, 21.76026726], [88.23905182, 21.76028061], [88.23861694, 21.76033401], [88.2381897, 21.76049042], [88.23773956, 21.76050377], [88.23728943, 21.7603817], [88.23686218, 21.76035118], [88.23641968, 21.76044083], [88.23594666, 21.76074982], [88.23551941, 21.76105118], [88.23509216, 21.76128006], [88.23465729, 21.76143074], [88.2342453, 21.76161003], [88.23383331, 21.76177979], [88.23340607, 21.76196098], [88.2330246, 21.76216888], [88.23261261, 21.76237106], [88.23219299, 21.76258087], [88.23175812, 21.76278114], [88.2313385, 21.76300049], [88.23085022, 21.76319122], [88.23023987, 21.76332474], [88.22966003, 21.76332474], [88.22910309, 21.76332283], [88.22853088, 21.76333046], [88.22795868, 21.76333046], [88.22735596, 21.76334953], [88.22676086, 21.76341057], [88.22615814, 21.7635498], [88.22553253, 21.76359177], [88.22491455, 21.7635994], [88.22428894, 21.7636013], [88.22366333, 21.76359177], [88.22305298, 21.76353264], [88.22246552, 21.7633934], [88.22187042, 21.7633419], [88.2212677, 21.76333046], [88.22065735, 21.76333046], [88.22001648, 21.76334], [88.2193985, 21.76338768], [88.21890259, 21.76356125], [88.21843719, 21.76374054], [88.21801758, 21.76394272], [88.21765137, 21.76416206], [88.21734619, 21.76437569], [88.21722412, 21.76444435], [88.21722412, 21.76694679], [88.21749878, 21.76721954], [88.21749878, 21.76749992], [88.21778107, 21.7677803], [88.21778107, 21.77028084], [88.21779633, 21.77098083], [88.21794128, 21.77166748], [88.21792603, 21.77193832], [88.21792603, 21.77305603], [88.21806335, 21.7733326], [88.21820831, 21.77361107], [88.21805573, 21.77388954], [88.21806335, 21.77721977], [88.21778107, 21.77750015], [88.21778107, 21.77806091], [88.21765137, 21.77861023], [88.21722412, 21.77972221], [88.21694183, 21.77999115], [88.21694183, 21.78028107], [88.21666718, 21.78055954], [88.21666718, 21.78139114], [88.21639252, 21.78166771], [88.21637726, 21.78222084], [88.21611023, 21.78250122], [88.21611023, 21.78277969], [88.21555328, 21.78333092], [88.2155304, 21.78376007], [88.21535492, 21.78407288], [88.21523285, 21.78446007], [88.21498871, 21.78483772], [88.21470642, 21.78525352], [88.21438599, 21.78570175], [88.21405792, 21.78616714], [88.21378326, 21.78667259], [88.21353912, 21.78720093], [88.21322632, 21.78763008], [88.21302032, 21.7880497], [88.21279144, 21.78837967], [88.21261597, 21.78869057], [88.21251678, 21.78900909], [88.21247864, 21.78938103], [88.2124176, 21.78982925], [88.21224213, 21.79031944], [88.21213531, 21.79084015], [88.21196747, 21.79124451], [88.21186066, 21.79163933], [88.21164703, 21.79199982], [88.21148682, 21.79236031], [88.21140289, 21.79276085], [88.21135712, 21.79318047], [88.21131897, 21.79358292], [88.21131134, 21.79400063], [88.21116638, 21.79445076], [88.21111298, 21.79496193], [88.21109009, 21.79551697], [88.21103668, 21.79608154], [88.21085358, 21.79658127], [88.21071625, 21.79701805], [88.21057129, 21.79737091], [88.2104187, 21.79766655], [88.21039581, 21.79804039], [88.21034241, 21.79848289], [88.21021271, 21.79889679], [88.20999908, 21.79921341], [88.20981598, 21.79955101], [88.2097168, 21.80000114], [88.20944214, 21.80027962], [88.20944214, 21.80138969], [88.20916748, 21.80166626], [88.20916748, 21.80194473], [88.20888519, 21.8022213], [88.20888519, 21.80249977], [88.20833588, 21.80305481], [88.20833588, 21.80333328], [88.20804596, 21.80360985], [88.20805359, 21.80388832], [88.20777893, 21.80416107], [88.20777893, 21.80444336], [88.20749664, 21.80472183], [88.2075119, 21.80500031], [88.20694733, 21.80555344], [88.20694733, 21.80583], [88.20610809, 21.80666542], [88.20610809, 21.80693054], [88.20527649, 21.80778122], [88.20527649, 21.80805779], [88.20500183, 21.80833054], [88.20471954, 21.80861092], [88.20471954, 21.80916786], [88.204422, 21.80978012], [88.20417786, 21.81025124], [88.20398712, 21.81068039], [88.20384979, 21.81106186], [88.2036972, 21.81137085], [88.20362091, 21.81164932], [88.20357513, 21.81193352], [88.20345306, 21.81220245], [88.20334625, 21.81248474], [88.20326233, 21.81278038], [88.203125, 21.81304932], [88.20301819, 21.81336021], [88.20287323, 21.81374741], [88.20271301, 21.81421089], [88.20252991, 21.8146553], [88.20243835, 21.81508636], [88.20230103, 21.81544304], [88.20217896, 21.81580925], [88.20201874, 21.81616974], [88.2019043, 21.816576], [88.2017746, 21.81700134], [88.20170593, 21.81745911], [88.20153809, 21.81785011], [88.20136261, 21.8182106], [88.20116425, 21.81856537], [88.20105743, 21.81900024], [88.20088196, 21.81946564], [88.20053101, 21.81986809], [88.20014191, 21.82024193], [88.19982147, 21.82069016], [88.199646, 21.82125092], [88.19950104, 21.82181931], [88.19933319, 21.82232285], [88.19908905, 21.8227005], [88.1988678, 21.82304001], [88.19863129, 21.82333755], [88.19843292, 21.82364845], [88.19827271, 21.82398987], [88.19807434, 21.82432938], [88.19805908, 21.82444382], [88.19777679, 21.82471848], [88.19777679, 21.82500076], [88.19721985, 21.8255558], [88.19721985, 21.82582855], [88.1966629, 21.82638931], [88.1966629, 21.82666969], [88.1958313, 21.82749939], [88.1958313, 21.82777786], [88.19527435, 21.8283329], [88.19527435, 21.82861137], [88.19472504, 21.82916641], [88.19472504, 21.82944489], [88.19444275, 21.82971954], [88.19444275, 21.82999992], [88.1938858, 21.83055305], [88.1938858, 21.83082962], [88.1930542, 21.83166695], [88.19304657, 21.8319397], [88.19249725, 21.83250046], [88.19249725, 21.83278084], [88.1922226, 21.8330574], [88.19220734, 21.83333015], [88.19194794, 21.83361053], [88.19194794, 21.83389091], [88.1902771, 21.83555794], [88.1902771, 21.8358326], [88.18777466, 21.83833313], [88.18777466, 21.8386116], [88.1855545, 21.84083366], [88.18527985, 21.84083176], [88.18222046, 21.84389114], [88.18222046, 21.84416962], [88.18138885, 21.84499931], [88.18113708, 21.84527016], [88.18083191, 21.84559631], [88.1805191, 21.84595108], [88.18019104, 21.84632111], [88.17987823, 21.84663963], [88.17958832, 21.84692955], [88.17933655, 21.84723091], [88.17908478, 21.84756088], [88.17879486, 21.84789467], [88.17855835, 21.84827995], [88.17832184, 21.84867859], [88.17806244, 21.84903908], [88.17784119, 21.84943008], [88.17772675, 21.84988022], [88.17755127, 21.85025024], [88.17739868, 21.85065079], [88.17720032, 21.85106277], [88.17694855, 21.85148048], [88.17694092, 21.8516674], [88.17666626, 21.85194397], [88.17666626, 21.85220909], [88.1763916, 21.85250092], [88.1763916, 21.85277939], [88.17610931, 21.85305595], [88.17610931, 21.8533287], [88.17583466, 21.8536129], [88.17583466, 21.8544445], [88.17555237, 21.85472107], [88.17555237, 21.85527802], [88.17500305, 21.85583115], [88.17500305, 21.85610962], [88.17414856, 21.85695076], [88.17416382, 21.85805321], [88.17388916, 21.85833359], [88.17388916, 21.85861015], [88.1736145, 21.85888863], [88.17360687, 21.85943985], [88.17305756, 21.86000061], [88.17305756, 21.86027527], [88.17250061, 21.86083031], [88.17250061, 21.86111069], [88.17222595, 21.8614006], [88.17222595, 21.86166763], [88.17194366, 21.8619442], [88.17193604, 21.86222076], [88.17166901, 21.86250114], [88.17166901, 21.86277962], [88.17138672, 21.86305618], [88.17140198, 21.86361122], [88.17082977, 21.86416626], [88.17082977, 21.86444473], [88.17055511, 21.8647213], [88.17056274, 21.86499977], [88.17028046, 21.86527824], [88.17028046, 21.86555481], [88.16999817, 21.86583328], [88.16999817, 21.86611176], [88.16971588, 21.86639023], [88.16971588, 21.86667252], [88.16944885, 21.86696053], [88.16944122, 21.86778069], [88.16916656, 21.86806107], [88.16916656, 21.86861038], [88.16889191, 21.86889076], [88.16889191, 21.87000084], [88.16833496, 21.87055588], [88.16832733, 21.87083054], [88.16777802, 21.87138939], [88.16777802, 21.87194443], [88.16805267, 21.87222099], [88.16805267, 21.87249947], [88.16777802, 21.87277985], [88.16777802, 21.87334061], [88.16694641, 21.8741703], [88.16694641, 21.87444687], [88.16666412, 21.87472153], [88.16666412, 21.87583351], [88.16638947, 21.87610817], [88.16638947, 21.87750053], [88.16555786, 21.87833405], [88.16388702, 21.87832832], [88.16361237, 21.87861061], [88.16361237, 21.87916756], [88.16333008, 21.87944412], [88.16361237, 21.87972069], [88.16361237, 21.88055611], [88.16388702, 21.88083267], [88.16388702, 21.88111115], [88.16416931, 21.88138962], [88.16416931, 21.88166618], [88.16333771, 21.88249969], [88.16333008, 21.88277817], [88.16361237, 21.88305473], [88.16361237, 21.88333321], [88.16388702, 21.88360977], [88.16388702, 21.88388824], [88.16400146, 21.88455963], [88.16404724, 21.88516045], [88.16429901, 21.885746], [88.1644516, 21.88641357], [88.16459656, 21.88709831], [88.16475677, 21.88778114], [88.16493988, 21.88842392], [88.16499329, 21.88905334], [88.16501617, 21.88961029], [88.1651001, 21.89006042], [88.16525269, 21.89042091], [88.16536713, 21.89074707], [88.16553497, 21.89105034], [88.16570282, 21.89138412], [88.16590118, 21.8917141], [88.16615295, 21.8920002], [88.16637421, 21.89231491], [88.16654968, 21.89266968], [88.16668701, 21.89306259], [88.16686249, 21.89342117], [88.16699982, 21.89377594], [88.16716766, 21.89410019], [88.1672821, 21.8944664], [88.16744232, 21.89480019], [88.16754913, 21.89524078], [88.1677475, 21.89564705], [88.16792297, 21.89614105], [88.16809845, 21.89669991], [88.16832733, 21.89727974], [88.16863251, 21.8978672], [88.1689682, 21.89842987], [88.16925049, 21.89899063], [88.16945648, 21.89950943], [88.16963196, 21.89997292], [88.16962433, 21.90047073], [88.16968536, 21.90089417], [88.1697464, 21.90127945], [88.16986084, 21.90167809], [88.16998291, 21.90208054], [88.17002869, 21.90253067], [88.17016602, 21.90297127], [88.17030334, 21.90348053], [88.17047119, 21.90398979], [88.17060852, 21.90452957], [88.17082214, 21.90501022], [88.17098999, 21.90543747], [88.17112732, 21.90581131], [88.17127228, 21.90612221], [88.17140198, 21.90641022], [88.17154694, 21.90669441], [88.17163849, 21.90700912], [88.17166901, 21.90739059], [88.17221832, 21.90860176], [88.17250061, 21.9091301], [88.1727829, 21.90971756], [88.17307281, 21.91028976], [88.17330933, 21.91080093], [88.17368317, 21.91146088], [88.17388916, 21.91167068], [88.17388916, 21.91305733], [88.17414856, 21.91333008], [88.17414856, 21.91389084], [88.17444611, 21.9141655], [88.17446136, 21.91472054], [88.17500305, 21.91527939], [88.17500305, 21.91611099], [88.17527771, 21.91638947], [88.17527771, 21.9169445], [88.17555237, 21.91721916], [88.17555237, 21.91805649], [88.17582703, 21.9183197], [88.17582703, 21.91889191], [88.17610931, 21.91917038], [88.17610931, 21.91944504], [88.1763916, 21.9197216], [88.1763916, 21.92111015], [88.17666626, 21.92138863], [88.17666626, 21.92194366], [88.17694092, 21.92222023], [88.17694092, 21.92389107], [88.17720795, 21.92416954], [88.17720795, 21.92611122], [88.17694092, 21.92638969], [88.17694092, 21.9272213], [88.17666626, 21.92749977], [88.17666626, 21.92833328], [88.1763916, 21.92860985], [88.1763916, 21.92944527], [88.17610931, 21.92971992], [88.17610931, 21.93027878], [88.17582703, 21.93054962], [88.17582703, 21.93111038], [88.17555237, 21.93139076], [88.17555237, 21.93166733], [88.17527771, 21.93194389], [88.17527771, 21.93221855], [88.17500305, 21.93250084], [88.17500305, 21.9327774], [88.17446136, 21.93332863], [88.17446136, 21.93362045], [88.17416382, 21.93388939], [88.17394257, 21.93412971], [88.17362213, 21.93445969], [88.17330933, 21.9348259], [88.17299652, 21.93518257], [88.1726532, 21.93551064], [88.17225647, 21.93582153], [88.171875, 21.93620682], [88.17140198, 21.93655014], [88.17087555, 21.93691826], [88.17037964, 21.93725014], [88.16994476, 21.93764305], [88.16955566, 21.93802261], [88.16916656, 21.93840981], [88.16882324, 21.93884087], [88.168396, 21.93918037], [88.16797638, 21.93949127], [88.16755676, 21.93971062], [88.1671524, 21.93992805], [88.16669464, 21.94016457], [88.16617584, 21.94046021], [88.16571808, 21.94086266], [88.16523743, 21.94131279], [88.16470337, 21.94171333], [88.16426849, 21.94214439], [88.16388702, 21.94248962], [88.16358948, 21.94280243], [88.16333008, 21.94305992], [88.16307831, 21.94330978], [88.16282654, 21.9435482], [88.16261292, 21.94377708], [88.16240692, 21.94397354], [88.16218567, 21.94416046], [88.16190338, 21.94437981], [88.1615448, 21.94469452], [88.16113281, 21.94508171], [88.16075897, 21.94552612], [88.16042328, 21.94595909], [88.1601181, 21.94635773], [88.15981293, 21.94671822], [88.15953064, 21.94712448], [88.15923309, 21.94754982], [88.15892792, 21.94800949], [88.15861511, 21.94843864], [88.15833282, 21.94882011], [88.15808105, 21.94915009], [88.15789795, 21.94944572], [88.15777588, 21.94972038], [88.15750122, 21.95000076], [88.15750122, 21.95083046], [88.15721893, 21.95111084], [88.15721893, 21.95139122], [88.15694427, 21.95166588], [88.15694427, 21.95194435], [88.15666962, 21.95222092], [88.15666962, 21.95249939], [88.15638733, 21.95277977], [88.15638733, 21.95305443], [88.15611267, 21.9533329], [88.1559906, 21.95370483], [88.15582275, 21.95399284], [88.15566254, 21.95441055], [88.1554184, 21.95494843], [88.15503693, 21.95544434], [88.15458679, 21.95581055], [88.15419006, 21.95615959], [88.15382385, 21.9565258], [88.15349579, 21.95690346], [88.15341949, 21.95743942], [88.15354919, 21.95804024], [88.1536026, 21.95862961], [88.15366364, 21.9591732], [88.15383148, 21.95960999], [88.1541214, 21.95994949], [88.15444183, 21.96026993], [88.15477753, 21.96062088], [88.15512848, 21.96102905], [88.1555481, 21.96140289], [88.15595245, 21.96178818], [88.15631104, 21.96213913], [88.15663147, 21.96244049], [88.15694427, 21.96267891], [88.1572113, 21.96289253], [88.1574173, 21.96314049], [88.15757751, 21.96347046], [88.15779114, 21.9637394], [88.15802002, 21.96400833], [88.1581955, 21.96433449], [88.15834045, 21.96475029], [88.1585083, 21.9652195], [88.1587677, 21.96567345], [88.15907288, 21.96608162], [88.15933228, 21.96651077], [88.15965271, 21.96685982], [88.15995789, 21.96715546], [88.16027069, 21.96742058], [88.16055298, 21.96775055], [88.16085052, 21.96809959], [88.16117096, 21.96846771], [88.16150665, 21.96882057], [88.16187286, 21.96915054], [88.16220856, 21.96946144], [88.16252136, 21.96977043], [88.16285706, 21.97004318], [88.16324615, 21.97026062], [88.16362, 21.97045135], [88.16394043, 21.97063446], [88.16420746, 21.97085953], [88.16452026, 21.97109985], [88.16491699, 21.97133446], [88.1654129, 21.97154045], [88.1659317, 21.97177124], [88.1664505, 21.9719696], [88.16691589, 21.97217751], [88.16739655, 21.97230339], [88.16784668, 21.97250175], [88.16832733, 21.97274017], [88.16883087, 21.97303009], [88.16944122, 21.97329903], [88.17014313, 21.97352028], [88.17072296, 21.97388077], [88.17123413, 21.97425079], [88.17160034, 21.97468948], [88.17185211, 21.97517014], [88.17208862, 21.9756012], [88.17232513, 21.97602844], [88.17263794, 21.97640228], [88.17299652, 21.9767704], [88.17340851, 21.97715759], [88.17388153, 21.97751427], [88.17434692, 21.97789192], [88.17478943, 21.97834969], [88.17523956, 21.97883606], [88.17572784, 21.97932816], [88.17623901, 21.97984123], [88.17675018, 21.98028946], [88.17719269, 21.98070908], [88.17753601, 21.98106575], [88.1778717, 21.98133087], [88.17821503, 21.98155594], [88.1785202, 21.98180199], [88.17864227, 21.98199081], [88.17874146, 21.98213959], [88.17891693, 21.98253059], [88.17912292, 21.98289108], [88.17919159, 21.98328018], [88.17933655, 21.98360062], [88.17958832, 21.98389053], [88.17991638, 21.98418045], [88.18025208, 21.9845295], [88.18055725, 21.98493958], [88.18089294, 21.98533821], [88.18123627, 21.98573112], [88.18157959, 21.98606491], [88.18191528, 21.98636246], [88.18222809, 21.98669434], [88.18250275, 21.98708153], [88.18279266, 21.98747063], [88.18312073, 21.98782921], [88.18344879, 21.98820686], [88.18375397, 21.9886322], [88.18406677, 21.98911095], [88.18434143, 21.98965073], [88.18464661, 21.99015045], [88.18491364, 21.99068642], [88.18524933, 21.99110031], [88.1855545, 21.99152565], [88.18585968, 21.99193192], [88.186203, 21.99229431], [88.18657684, 21.99262047], [88.18692017, 21.99296188], [88.18721008, 21.99332047], [88.18746948, 21.9937191], [88.18769836, 21.99415016], [88.18795013, 21.99457169], [88.18814087, 21.99505424], [88.18839264, 21.99549103], [88.18875122, 21.99591827], [88.18913269, 21.99637985], [88.18943024, 21.99690056], [88.18982697, 21.99732018], [88.19024658, 21.99769974], [88.19062042, 21.99810028], [88.19096375, 21.99851036], [88.19111633, 21.9990406], [88.19249725, 22.00000191], [88.1930542, 22.00055504], [88.19304657, 22.0008316], [88.19361115, 22.00139046], [88.19361115, 22.00166702], [88.1955719, 22.00361061], [88.1955719, 22.00389099], [88.1958313, 22.00416756], [88.1958313, 22.0047226], [88.19694519, 22.00583267], [88.19695282, 22.00611115], [88.19750214, 22.00666428], [88.19750214, 22.00694656], [88.19818878, 22.00763321], [88.19833374, 22.00777626], [88.19833374, 22.00790024], [88.19833374, 22.00805473], [88.1985321, 22.00825691], [88.1986084, 22.00833321], [88.1986084, 22.00861168], [88.1988678, 22.00887108], [88.19944763, 22.00944519], [88.19944763, 22.01000023], [88.19953156, 22.01008606], [88.19972229, 22.0102787], [88.19972229, 22.01042938], [88.19972229, 22.01083374], [88.20020294, 22.01131439], [88.20027924, 22.01139069], [88.20027924, 22.01166725], [88.20055389, 22.01194382], [88.20055389, 22.01222229], [88.20088196, 22.01255035], [88.20111084, 22.01277733], [88.20111084, 22.0130558], [88.20121765, 22.01316261], [88.2013855, 22.01333427], [88.2013855, 22.0134716], [88.2013855, 22.01361275], [88.20155334, 22.01377487], [88.20166779, 22.01388931], [88.20166779, 22.01399994], [88.20166779, 22.01416588], [88.20194244, 22.01444435], [88.20194244, 22.01472282], [88.20262909, 22.01540947], [88.20444489, 22.01722145], [88.20443726, 22.01777077], [88.20471954, 22.01805305], [88.20471954, 22.01832962], [88.20555878, 22.01916695], [88.20555878, 22.01944351], [88.20583344, 22.01972198], [88.20582581, 22.01988029], [88.20582581, 22.02000046], [88.20610809, 22.02028084], [88.20610809, 22.0205555], [88.20667267, 22.02111053], [88.20666504, 22.0213871], [88.20715332, 22.02187729], [88.20777893, 22.02250099], [88.20777893, 22.02277946], [88.20805359, 22.02305794], [88.20804596, 22.02333069], [88.20833588, 22.02361107], [88.20833588, 22.02389908], [88.20861053, 22.02416611], [88.20861053, 22.02444458], [88.20888519, 22.02472305], [88.20889282, 22.02499962], [88.20916748, 22.02527809], [88.20916748, 22.02555466], [88.20944214, 22.02583313], [88.20944214, 22.0261116], [88.2097168, 22.02639008], [88.20972443, 22.02666664], [88.20999908, 22.02694511], [88.20999908, 22.02722168], [88.21057129, 22.02778053], [88.21055603, 22.02805519], [88.21083069, 22.02833176], [88.21083069, 22.02861023], [88.21111298, 22.0288887], [88.21111298, 22.02944183], [88.21166992, 22.03000069], [88.21166992, 22.03027725], [88.21250153, 22.03194427], [88.21277618, 22.03222084], [88.21277618, 22.03250122], [88.21305847, 22.03277969], [88.21305847, 22.03305435], [88.21333313, 22.03333282], [88.21331787, 22.03360939], [88.21360779, 22.03388977], [88.21360779, 22.03444672], [88.21389008, 22.03472137], [88.21389008, 22.03555107], [88.2141571, 22.03583908], [88.21416473, 22.03694534], [88.21444702, 22.03722191], [88.21444702, 22.03832817], [88.21472168, 22.03861046], [88.21472168, 22.03943825], [88.21527863, 22.04000092], [88.21527863, 22.04027939], [88.21499634, 22.04055977], [88.21499634, 22.04138947], [88.21527863, 22.04166603], [88.21527863, 22.0419445], [88.21555328, 22.04222107], [88.21555328, 22.04277992], [88.21527863, 22.04305649], [88.21555328, 22.04333305], [88.21555328, 22.04453087], [88.21555328, 22.04583359], [88.21583557, 22.04611206], [88.2158432, 22.04833031], [88.21611023, 22.04861069], [88.21611023, 22.05138969], [88.21637726, 22.05166817], [88.21637726, 22.05250168], [88.21666718, 22.05277824], [88.21666718, 22.05361176], [88.21694183, 22.05388069], [88.21694183, 22.05417061], [88.21722412, 22.05444527], [88.21721649, 22.05472183], [88.21805573, 22.05555534], [88.21806335, 22.05583191], [88.21833038, 22.05611038], [88.21833038, 22.05639076], [88.21861267, 22.05750084], [88.21861267, 22.05805588], [88.21888733, 22.05833054], [88.21888733, 22.05916405], [88.21916962, 22.05944443], [88.21916962, 22.05972099], [88.2194519, 22.06001091], [88.21944427, 22.06027794], [88.22000122, 22.06083107], [88.22000122, 22.06138611], [88.22027588, 22.0616684], [88.22027588, 22.06222153], [88.22038269, 22.06232643], [88.22055817, 22.06249809], [88.22055817, 22.06305695], [88.22083282, 22.06333351], [88.22083282, 22.06360817], [88.22110748, 22.06388664], [88.22110748, 22.06471825], [88.22138977, 22.06500053], [88.22138977, 22.06528091], [88.2216568, 22.06555939], [88.2216568, 22.06611061], [88.22194672, 22.06638908], [88.22194672, 22.0672226], [88.22222137, 22.06750107], [88.22222137, 22.06916618], [88.22250366, 22.06944466], [88.22251129, 22.07110977], [88.22277832, 22.07139015], [88.22277832, 22.07194328], [88.22305298, 22.07221985], [88.22305298, 22.07305527], [88.2233429, 22.07332993], [88.22333527, 22.07416534], [88.22360992, 22.07444], [88.22360992, 22.0750103], [88.22389221, 22.07527542], [88.22389221, 22.07722092], [88.22416687, 22.07749748], [88.22416687, 22.08194351], [88.22389221, 22.08222008], [88.22389221, 22.08250046], [88.22416687, 22.08278084], [88.22416687, 22.08361053], [88.22389221, 22.08388901], [88.22389221, 22.08444214], [88.22360992, 22.08472061], [88.22389221, 22.08500099], [88.22389221, 22.08611107], [88.22416687, 22.08638954], [88.22389221, 22.0866642], [88.22389221, 22.08805466], [88.22416687, 22.08833313], [88.22416687, 22.08972168], [88.22389221, 22.08999062], [88.22389221, 22.09055519], [88.22416687, 22.09082985], [88.22416687, 22.09110832], [88.22444153, 22.09139061], [88.22444153, 22.09166908], [88.22389221, 22.09166718], [88.22360992, 22.09193993], [88.22360992, 22.09250069], [88.22333527, 22.09277725], [88.22333527, 22.09444427], [88.22305298, 22.09472275], [88.22305298, 22.09527969], [88.22277832, 22.09556007], [88.22277832, 22.09638977], [88.22305298, 22.09666634], [88.22305298, 22.09805489], [88.22277832, 22.09832954], [88.22277832, 22.0988903], [88.22222137, 22.09944344], [88.22222137, 22.09972191], [88.22251129, 22.10000038], [88.22251129, 22.10028076], [88.22222137, 22.10056114], [88.22222137, 22.10139084], [88.22194672, 22.1016655], [88.22194672, 22.10194397], [88.2216568, 22.10222054], [88.2216568, 22.10277939], [88.22083282, 22.10360909], [88.22083282, 22.1044445], [88.22110748, 22.10471916], [88.22110748, 22.10527992], [88.22027588, 22.10611153], [88.22027588, 22.10638809], [88.21944427, 22.1072216], [88.2194519, 22.10861015], [88.21888733, 22.1091671], [88.21888733, 22.10944176], [88.21833038, 22.11000061], [88.21833038, 22.1102829], [88.21805573, 22.11055565], [88.21806335, 22.11083031], [88.21778107, 22.11112022], [88.21778107, 22.11139107], [88.21749878, 22.11166573], [88.21749878, 22.11194038], [88.21666718, 22.11277771], [88.21666718, 22.11416435], [88.21637726, 22.11444092], [88.21637726, 22.11499977], [88.21611023, 22.11527634], [88.21637726, 22.11555099], [88.21637726, 22.11639023], [88.21666718, 22.11667061], [88.21666718, 22.11694527], [88.21637726, 22.11721992], [88.21637726, 22.11860847], [88.21694183, 22.11916733], [88.21694183, 22.11943817], [88.21637726, 22.12000084], [88.21637726, 22.12029076], [88.21555328, 22.12111282], [88.21555328, 22.12138939], [88.21527863, 22.12166595], [88.21527863, 22.12194252], [88.21472168, 22.12249947], [88.21472168, 22.12305641], [88.2141571, 22.12360954], [88.2141571, 22.1241703], [88.21389008, 22.12444305], [88.21389008, 22.12471962], [88.21360779, 22.125], [88.21360779, 22.12528038], [88.21333313, 22.12555313], [88.21333313, 22.12583351], [88.21221924, 22.12694359], [88.21221924, 22.12722015], [88.21194458, 22.12750053], [88.21193695, 22.12833023], [88.21166992, 22.12861061], [88.21166992, 22.12944412], [88.21138763, 22.1297226], [88.21138763, 22.13083076], [88.21111298, 22.13111115], [88.21111298, 22.13138962], [88.21083069, 22.13166618], [88.21083069, 22.13305473], [88.21138763, 22.13361168], [88.21138763, 22.13389015], [88.21111298, 22.13416672], [88.21111298, 22.13583183], [88.21138763, 22.13611031], [88.21138763, 22.13972092], [88.21166992, 22.13999939], [88.21166992, 22.14055443], [88.21138763, 22.14083099], [88.21138763, 22.14249992], [88.21111298, 22.1427803], [88.21057129, 22.1427803], [88.21083069, 22.14306068], [88.21111298, 22.14306068], [88.21111298, 22.14416885], [88.21083069, 22.1444397], [88.21083069, 22.14639091], [88.21055603, 22.14666748], [88.21055603, 22.14944458], [88.21028137, 22.14972115], [88.21028137, 22.14999962], [88.20999908, 22.15027809], [88.20999908, 22.15055466], [88.20972443, 22.15083313], [88.2097168, 22.1511097], [88.20944214, 22.15139008], [88.20944214, 22.15167046], [88.20916748, 22.15194321], [88.20916748, 22.15333366], [88.20889282, 22.15361023], [88.20889282, 22.15389061], [88.20861053, 22.15416527], [88.20861053, 22.15444374], [88.20833588, 22.15472031], [88.20833588, 22.15500069], [88.20804596, 22.15528107], [88.20804596, 22.15611076], [88.20777893, 22.15639114], [88.20777893, 22.1566658], [88.2075119, 22.15694046], [88.2075119, 22.15777969], [88.20722198, 22.15805626], [88.20722198, 22.15833282], [88.20694733, 22.15860748], [88.20694733, 22.15888977], [88.20666504, 22.15916634], [88.20667267, 22.15972137], [88.20639038, 22.16000175], [88.20639038, 22.16027832], [88.20583344, 22.16083336], [88.20582581, 22.16111183], [88.20555878, 22.1613903], [88.20555878, 22.16167068], [88.20527649, 22.16194534], [88.20527649, 22.16220856], [88.20500183, 22.16250038], [88.20500183, 22.16278076], [88.20471954, 22.16305542], [88.20471954, 22.16333008], [88.20443726, 22.16361046], [88.20443726, 22.16389084], [88.20417023, 22.1641674], [88.20417023, 22.16444206], [88.20388794, 22.16472054], [88.20388794, 22.16500092], [88.20361328, 22.16526985], [88.20361328, 22.16555405], [88.20333099, 22.16583061], [88.20333099, 22.16611099], [88.20305634, 22.16638947], [88.20305634, 22.16694069], [88.20055389, 22.16944695], [88.20054626, 22.1697197], [88.1986084, 22.1716671], [88.1986084, 22.17193985], [88.19805908, 22.17250061], [88.19805908, 22.17277718], [88.19750214, 22.1733284], [88.19750214, 22.17361069], [88.1966629, 22.17444038], [88.1966629, 22.17500114], [88.19638824, 22.17527962], [88.19638824, 22.17638969], [88.19555664, 22.1772213], [88.19528198, 22.17721176], [88.1930542, 22.17944336], [88.19304657, 22.17971992], [88.1922226, 22.18055534], [88.19220734, 22.18083], [88.19167328, 22.18139076], [88.19167328, 22.18167114], [88.19000244, 22.18333817], [88.19000244, 22.18361092], [88.18972015, 22.18388748], [88.18972015, 22.18416786], [88.1894455, 22.18444443], [88.18943787, 22.18471909], [88.18914795, 22.18499756], [88.18914795, 22.18556023], [88.18805695, 22.1866703], [88.18776703, 22.1866703], [88.18694305, 22.18750191], [88.1866684, 22.18750191], [88.18611145, 22.18806267], [88.18583679, 22.18806267], [88.1847229, 22.18917274], [88.18444824, 22.18916702], [88.18416595, 22.18944359], [88.1838913, 22.18943977], [88.1827774, 22.19055939], [88.18250275, 22.19055557], [88.18222046, 22.19083214], [88.1819458, 22.19083214], [88.18083191, 22.19194412], [88.18055725, 22.19166756], [88.18027496, 22.19166756], [88.18000031, 22.19194412], [88.17944336, 22.19194412], [88.1791687, 22.1922226], [88.17888641, 22.19221115], [88.1783371, 22.19277954], [88.17804718, 22.19277954], [88.17778015, 22.19305992], [88.17749786, 22.1930542], [88.17722321, 22.19333267], [88.17694092, 22.19333076], [88.1763916, 22.19388962], [88.17610931, 22.19388962], [88.17582703, 22.19417], [88.17500305, 22.19416428], [88.17472076, 22.19444466], [88.17333221, 22.19444466], [88.17305756, 22.19472313], [88.1727829, 22.19472122], [88.17250061, 22.19499969], [88.17193604, 22.19499969], [88.17166901, 22.19528008], [88.17082977, 22.19527626], [88.17055511, 22.19555473], [88.16999817, 22.19555473], [88.16972351, 22.19583321], [88.16916656, 22.19583321], [88.16889191, 22.19611168], [88.16832733, 22.19610977], [88.16777802, 22.19667053], [88.16750336, 22.19666862], [88.16694641, 22.19722176], [88.16638947, 22.19721985], [88.16610718, 22.19749832], [88.16583252, 22.19749832], [88.16555786, 22.19778061], [88.16555786, 22.19889069], [88.16526794, 22.19778061], [88.16471863, 22.19778061], [88.16443634, 22.19805908], [88.16388702, 22.19805908], [88.16361237, 22.19833946], [88.16249847, 22.19833946], [88.16220856, 22.1986084], [88.16139221, 22.1986084], [88.16110992, 22.19889069], [88.1608429, 22.19889069], [88.16055298, 22.1986084], [88.15972137, 22.1986084], [88.15972137, 22.19889069], [88.15833282, 22.19889069], [88.15805817, 22.1986084], [88.15556335, 22.1986084], [88.15528107, 22.19889069], [88.15444183, 22.19889069], [88.15416718, 22.19916916], [88.15389252, 22.19889069], [88.15249634, 22.19889069], [88.15222168, 22.19916916], [88.15166473, 22.19916725], [88.15139008, 22.19944382], [88.15055847, 22.19944382], [88.15027618, 22.19972229], [88.14916992, 22.19971848], [88.14888763, 22.20000076], [88.14833069, 22.20000076], [88.14833069, 22.19971848], [88.14778137, 22.19971848], [88.14723206, 22.20027924], [88.14639282, 22.20027924], [88.14611053, 22.20055962], [88.14583588, 22.2005558], [88.14555359, 22.20083427], [88.14527893, 22.20083237], [88.14499664, 22.20111275], [88.14416504, 22.20111275], [88.14389038, 22.20138931], [88.14360809, 22.20138168], [88.14332581, 22.20166969], [88.14138794, 22.20166588], [88.14111328, 22.20194435], [88.13972473, 22.20194435], [88.13944244, 22.20222282], [88.13777924, 22.20222282], [88.13749695, 22.20194435], [88.13666534, 22.20194435], [88.13639069, 22.20166588], [88.13555908, 22.20166588], [88.13527679, 22.20194435], [88.13444519, 22.20194435], [88.1341629, 22.20222282], [88.13249969, 22.20222282], [88.13223267, 22.20249939], [88.13166809, 22.20249939], [88.1313858, 22.20277977], [88.13054657, 22.20277977], [88.13027954, 22.20306015], [88.12944794, 22.20305634], [88.12889099, 22.20361137], [88.1286087, 22.20360947], [88.12832642, 22.20388985], [88.12805176, 22.20388985], [88.1277771, 22.20417023], [88.12750244, 22.20416641], [88.1269455, 22.20472145], [88.12666321, 22.20471954], [88.1258316, 22.20556068], [88.125, 22.20555305], [88.12472534, 22.20583344], [88.12444305, 22.20583344], [88.1241684, 22.20555305], [88.1230545, 22.20555305], [88.12277985, 22.20583344], [88.12277985, 22.20611], [88.12249756, 22.20639038], [88.12249756, 22.20666695], [88.1222229, 22.20694351], [88.12194824, 22.2069397], [88.1213913, 22.20750809], [88.12000275, 22.20750809], [88.11972046, 22.20778084], [88.11915588, 22.20778084], [88.11833191, 22.20861053], [88.11778259, 22.20861053], [88.11750031, 22.20889091], [88.1169281, 22.20889091], [88.1166687, 22.20916939], [88.11333466, 22.20916557], [88.11305237, 22.20944405], [88.11250305, 22.20944405], [88.11250305, 22.20916557], [88.1102829, 22.20916939], [88.11000061, 22.20889091], [88.10972595, 22.20889091], [88.10972595, 22.20916939], [88.10832977, 22.20916557], [88.10832977, 22.20944405], [88.10666656, 22.20944405], [88.10639191, 22.20972252], [88.10472107, 22.20972252], [88.10472107, 22.20944405], [88.10138702, 22.20944405], [88.10122681, 22.20960617], [88.10111237, 22.20972252], [88.09944153, 22.20972252], [88.09916687, 22.20944405], [88.09527588, 22.20944405], [88.09500122, 22.20916557], [88.0930481, 22.20916939], [88.09278107, 22.20889091], [88.09194183, 22.20889091], [88.09166718, 22.20861053], [88.08972168, 22.20861053], [88.08944702, 22.20833015], [88.08750153, 22.20833015], [88.08721924, 22.20861053], [88.08611298, 22.20861053], [88.08583069, 22.20889091], [88.08528137, 22.20889091], [88.08499908, 22.20916939], [88.08388519, 22.20916557], [88.08361053, 22.20944405], [88.08194733, 22.20944405], [88.08166504, 22.20972252], [88.08139038, 22.20972252], [88.08110809, 22.20944405], [88.07917023, 22.20944405], [88.07888794, 22.20972252], [88.07775879, 22.20972061], [88.07749939, 22.21000099], [88.07277679, 22.21000099], [88.07250214, 22.21027946], [88.07221985, 22.21027946], [88.07195282, 22.21056938], [88.0716629, 22.21055794], [88.07138824, 22.2108326], [88.07110596, 22.21083069], [88.0708313, 22.21110916], [88.07055664, 22.21110916], [88.06972504, 22.21194458], [88.06973267, 22.21500015], [88.06999969, 22.21527863], [88.06999969, 22.2163887], [88.07055664, 22.21694374], [88.0708313, 22.21694183], [88.07138824, 22.21750069], [88.07138824, 22.21777725], [88.07472229, 22.22110939], [88.07472229, 22.22138977], [88.07527924, 22.22194099], [88.07527924, 22.22250748], [88.07555389, 22.22277641], [88.07555389, 22.22305489], [88.07611084, 22.22360992], [88.07611084, 22.2238903], [88.07666779, 22.22444534], [88.07666779, 22.22472191], [88.07888794, 22.22694397], [88.07888794, 22.22721863], [88.07917023, 22.22750282], [88.07917023, 22.22777939], [88.08000183, 22.2286129], [88.08000183, 22.22888947], [88.08110809, 22.22999954], [88.08139038, 22.22999954], [88.08277893, 22.23139], [88.08277893, 22.23167992], [88.08305359, 22.23194313], [88.08304596, 22.2322197], [88.08333588, 22.23250008], [88.08333588, 22.23278046], [88.08361053, 22.23305321], [88.08361053, 22.23333359], [88.08389282, 22.23361015], [88.08389282, 22.23389053], [88.08444214, 22.23444366], [88.08444214, 22.23472023], [88.0847168, 22.23500061], [88.0847168, 22.23528099], [88.08499908, 22.23555946], [88.08499908, 22.23611069], [88.08528137, 22.23639107], [88.08499908, 22.23666573], [88.08528137, 22.2369442], [88.08528137, 22.23722267], [88.08555603, 22.23749733], [88.08555603, 22.23833084], [88.08583069, 22.23861122], [88.08583069, 22.23944473], [88.08611298, 22.23971939], [88.08611298, 22.24000168], [88.08638763, 22.24027824], [88.08611298, 22.24055481], [88.08611298, 22.24083328], [88.08638763, 22.24111176], [88.08638763, 22.24139023], [88.08695221, 22.2419529], [88.08694458, 22.24305534], [88.08721924, 22.24333382], [88.08721924, 22.24444389], [88.08750153, 22.24472046], [88.08750153, 22.24555588], [88.08777618, 22.24583054], [88.08777618, 22.24638939], [88.08805847, 22.24666405], [88.08805847, 22.24722099], [88.08833313, 22.24749947], [88.08833313, 22.25139046], [88.08805847, 22.25166893], [88.08805847, 22.25222206], [88.08833313, 22.25248909], [88.08833313, 22.25278091], [88.08860779, 22.25305557], [88.08833313, 22.25332832], [88.08833313, 22.25361061], [88.08805847, 22.2538929], [88.08805847, 22.25416756], [88.08777618, 22.25444412], [88.08777618, 22.2547226], [88.08750153, 22.25444412], [88.08721924, 22.2547226], [88.08721924, 22.25499916], [88.08805847, 22.25583267], [88.08805847, 22.25611115], [88.08833313, 22.25638962], [88.08833313, 22.25666618], [88.08860779, 22.25694275], [88.08860779, 22.26278114], [88.08889008, 22.26305771], [88.08889008, 22.26333046], [88.0891571, 22.26361084], [88.08916473, 22.26388741], [88.08972168, 22.264431], [88.08972168, 22.26499748], [88.08998871, 22.26555824], [88.08998871, 22.26639175], [88.09027863, 22.26666641], [88.09027863, 22.26694489], [88.09055328, 22.26722145], [88.09055328, 22.26750183], [88.09111023, 22.26805496], [88.09111023, 22.26833344], [88.09139252, 22.26861191], [88.09139252, 22.26944351], [88.09166718, 22.26972008], [88.09166718, 22.27027702], [88.09221649, 22.27083015], [88.09221649, 22.27111053], [88.09278107, 22.27166748], [88.09278107, 22.27222061], [88.0930481, 22.27250099], [88.09305573, 22.27277756], [88.09361267, 22.27333069], [88.09361267, 22.27362061], [88.09500122, 22.27499962], [88.09500122, 22.27527618], [88.09527588, 22.27555466], [88.09527588, 22.27583313], [88.09555817, 22.2761097], [88.09555817, 22.27694511], [88.09612274, 22.27749825], [88.09612274, 22.27778053], [88.09889221, 22.28055573], [88.09889221, 22.28083229], [88.09972382, 22.2816658], [88.09972382, 22.28194427], [88.09999847, 22.28222275], [88.09999847, 22.28279114], [88.10028076, 22.28305626], [88.10028076, 22.28333282], [88.10055542, 22.2836113], [88.10056305, 22.28388977], [88.10083008, 22.28416634], [88.10083008, 22.28444481], [88.10111237, 22.28471947], [88.10111237, 22.28499985], [88.10138702, 22.28527832], [88.10138702, 22.28555489], [88.10192871, 22.28610992], [88.10192871, 22.2863903], [88.10221863, 22.28666687], [88.10221863, 22.28722], [88.1027832, 22.28778076], [88.10277557, 22.28805542], [88.10305786, 22.28833008], [88.10305786, 22.2891655], [88.10277557, 22.28944397], [88.1027832, 22.28972054], [88.10360718, 22.29055977], [88.10360718, 22.29110909], [88.10388947, 22.29138756], [88.10388947, 22.29249763], [88.10416412, 22.29277992], [88.10415649, 22.29361153], [88.10444641, 22.29389191], [88.10444641, 22.29500008], [88.10472107, 22.29528046], [88.10472107, 22.29556274], [88.10388947, 22.29639053], [88.10416412, 22.2966671], [88.10415649, 22.29693985], [88.1049881, 22.29779053], [88.10472107, 22.29805946], [88.10472107, 22.29916573], [88.10527802, 22.29972267], [88.10527802, 22.30083084], [88.1049881, 22.30111122], [88.1049881, 22.30138969], [88.10472107, 22.30167007], [88.10472107, 22.30389023], [88.1049881, 22.30417061], [88.10500336, 22.30469894], [88.10317993, 22.3038578], [88.10279846, 22.30368233], [88.10136414, 22.30314636], [88.09877777, 22.30233955], [88.09519196, 22.30233955], [88.092453, 22.30233955], [88.09015656, 22.3026104], [88.08870697, 22.3031311], [88.08860779, 22.30249977], [88.08750153, 22.30056], [88.08750153, 22.30000114], [88.08721924, 22.29972076], [88.08721924, 22.29916573], [88.08695221, 22.29889107], [88.08695221, 22.29861069], [88.08666992, 22.29833221], [88.08666992, 22.29805565], [88.08638763, 22.29779053], [88.08638763, 22.29750061], [88.08611298, 22.29722023], [88.08611298, 22.2966671], [88.08555603, 22.29611015], [88.08555603, 22.29583359], [88.08444214, 22.2947216], [88.08444214, 22.29445267], [88.08361053, 22.2930603], [88.08333588, 22.29278183], [88.08333588, 22.29249763], [88.08304596, 22.29221916], [88.08305359, 22.2919445], [88.08277893, 22.29166794], [88.08277893, 22.29110909], [88.08222198, 22.29055977], [88.08222198, 22.29027939], [88.08139038, 22.28944016], [88.08139038, 22.28861046], [88.08055878, 22.28777695], [88.08055878, 22.28750038], [88.07971954, 22.28667068], [88.07971954, 22.2863903], [88.07943726, 22.28610992], [88.07944489, 22.28583336], [88.07917023, 22.28555489], [88.07917023, 22.28527832], [88.07861328, 22.28417015], [88.07861328, 22.28306007], [88.07888794, 22.28279114], [88.07888794, 22.28222275], [88.07861328, 22.28194427], [88.07861328, 22.2816658], [88.07833099, 22.28139114], [88.07833099, 22.28055954], [88.07804871, 22.28027916], [88.07775879, 22.27860832], [88.07775879, 22.27832985], [88.07749939, 22.27805519], [88.07749939, 22.27721977], [88.07722473, 22.27694511], [88.0772171, 22.27638817], [88.07666779, 22.27583122], [88.07666779, 22.27527618], [88.07694244, 22.27499962], [88.07666779, 22.27472115], [88.07666779, 22.27361107], [88.07639313, 22.27333069], [88.0763855, 22.27222252], [88.07611084, 22.27194595], [88.07611084, 22.26944351], [88.07583618, 22.26916695], [88.07583618, 22.26889038], [88.07611084, 22.26861191], [88.07611084, 22.26805496], [88.07583618, 22.2677803], [88.07611084, 22.26750183], [88.07611084, 22.26499748], [88.07583618, 22.26472092], [88.07583618, 22.26333427], [88.07611084, 22.26305771], [88.07583618, 22.26278114], [88.07583618, 22.26250076], [88.07611084, 22.26222038], [88.07583618, 22.26194382], [88.07611084, 22.26166534], [88.07611084, 22.26139069], [88.07583618, 22.26111031], [88.07583618, 22.26056099], [88.07554626, 22.26028061], [88.07554626, 22.25971985], [88.07527924, 22.25944328], [88.07527924, 22.25917053], [88.07501221, 22.25889015], [88.07501221, 22.25805283], [88.07472229, 22.25777817], [88.07472229, 22.25694275], [88.07555389, 22.25611115], [88.07554626, 22.25583267], [88.07444763, 22.2547226], [88.07444763, 22.25444412], [88.07472229, 22.25416756], [88.07501221, 22.25416946], [88.07527924, 22.2538929], [88.07527924, 22.25278091], [88.07501221, 22.25248909], [88.07499695, 22.25222206], [88.07472229, 22.25194359], [88.07472229, 22.25166893], [88.07444763, 22.25139046], [88.07444763, 22.25110817], [88.07416534, 22.25083351], [88.07416534, 22.25055504], [88.07389069, 22.25028038], [88.07389069, 22.24999809], [88.0736084, 22.24971962], [88.0736084, 22.24944687], [88.07332611, 22.2491703], [88.07332611, 22.24888992], [88.07277679, 22.24833107], [88.07277679, 22.24805832], [88.07221985, 22.24749947], [88.07221985, 22.24722099], [88.0716629, 22.24666405], [88.0716629, 22.24638939], [88.07138824, 22.24611092], [88.07138824, 22.24583054], [88.07055664, 22.24500084], [88.07055664, 22.24472046], [88.06916809, 22.24333382], [88.06916809, 22.24305534], [88.06887817, 22.24278069], [88.06887817, 22.24222183], [88.06833649, 22.24166679], [88.06804657, 22.24167061], [88.0672226, 22.24082947], [88.0672226, 22.24055481], [88.06666565, 22.24000168], [88.06666565, 22.23971939], [88.0661087, 22.23916626], [88.06581879, 22.23833084], [88.0652771, 22.23749733], [88.06500244, 22.23722267], [88.06472015, 22.23638725], [88.06472015, 22.23611069], [88.06360626, 22.23500061], [88.0633316, 22.23500061], [88.0627594, 22.23444939], [88.0616684, 22.23278046], [88.06138611, 22.23278046], [88.06111145, 22.23250008], [88.06083679, 22.2322197], [88.0605545, 22.2322216], [88.0577774, 22.2294445], [88.0577774, 22.22916603], [88.05249786, 22.2238903], [88.05222321, 22.2238903], [88.0513916, 22.22305107], [88.0513916, 22.22277641], [88.05110931, 22.22250748], [88.05110931, 22.22221947], [88.05055237, 22.22166634], [88.04944611, 22.22027969], [88.04915619, 22.22000122], [88.04860687, 22.22000122], [88.04833221, 22.21972084], [88.04722595, 22.21972084], [88.04693604, 22.22000122], [88.04641724, 22.22000122], [88.04611206, 22.22000122], [88.04582977, 22.22027969], [88.04499817, 22.22027969], [88.04471588, 22.22056007], [88.04444122, 22.22055435], [88.04416656, 22.22083282], [88.04389191, 22.22083282], [88.04360962, 22.2211113], [88.04250336, 22.22110939], [88.04222107, 22.22138977], [88.04083252, 22.22138977], [88.04055786, 22.22167015], [88.0402832, 22.22167015], [88.04000092, 22.22138977], [88.03778076, 22.22138977], [88.03749847, 22.22110939], [88.0358429, 22.22110939], [88.03555298, 22.22138977], [88.0341568, 22.22138977], [88.03388977, 22.22167015], [88.03333282, 22.22166634], [88.03305817, 22.22194481], [88.03277588, 22.22194481], [88.03263855, 22.22180557], [88.03250122, 22.22166634], [88.03055573, 22.22166634], [88.03028107, 22.22194481], [88.02777863, 22.22194481], [88.02749634, 22.22222137], [88.02693939, 22.22221947], [88.02664948, 22.22250748], [88.02610779, 22.22249985], [88.02278137, 22.22583389], [88.02249908, 22.22582817], [88.0222168, 22.22610855], [88.02194214, 22.22610855], [88.02166748, 22.22639084], [88.02139282, 22.22639084], [88.02111053, 22.22666931], [88.02027893, 22.2266674], [88.01999664, 22.22694397], [88.01889038, 22.22694397], [88.01860809, 22.22722244], [88.01832581, 22.22721863], [88.01805878, 22.22750282], [88.01750183, 22.22750282], [88.01721954, 22.22777939], [88.01693726, 22.22777939], [88.01667023, 22.22805977], [88.01611328, 22.22805595], [88.01583099, 22.22833252], [88.01526642, 22.22831917], [88.01499939, 22.2286129], [88.01470947, 22.2286129], [88.01416779, 22.22916985], [88.0138855, 22.22916603], [88.01361084, 22.2294445], [88.01305389, 22.2294445], [88.01277924, 22.22972107], [88.01249695, 22.22972107], [88.01222229, 22.22999954], [88.01196289, 22.22999954], [88.01167297, 22.23027992], [88.0111084, 22.23027992], [88.01082611, 22.2305603], [88.01055908, 22.23055649], [88.01027679, 22.23083305], [88.00971985, 22.23083115], [88.0091629, 22.23139], [88.00889587, 22.23139], [88.00860596, 22.23167992], [88.00805664, 22.23167992], [88.00776672, 22.23195076], [88.00749969, 22.23194313], [88.00722504, 22.2322216], [88.00694275, 22.2322197], [88.00666809, 22.23250008], [88.0063858, 22.23250008], [88.00611115, 22.23278046], [88.00582886, 22.23278046], [88.00553894, 22.23306084], [88.00527954, 22.23305321], [88.00444794, 22.23332977], [88.00389099, 22.23389053], [88.0036087, 22.23389053], [88.00332642, 22.23417091], [88.00305176, 22.23417091], [88.00276947, 22.23444939], [88.00222015, 22.23444939], [88.00166321, 22.23500061], [88.00110626, 22.23500061], [88.0008316, 22.23528099], [88.0, 22.23555565], [87.99926758, 22.23570824], [87.99622345, 22.23748016], [87.99584198, 22.23771095], [87.99388123, 22.23879051], [87.99356842, 22.23908806], [87.99327087, 22.23935127], [87.99291229, 22.23960114], [87.99254608, 22.23987961], [87.99209595, 22.24006081], [87.99172211, 22.24028969], [87.99137115, 22.24054909], [87.99105835, 22.24081039], [87.9907608, 22.24103928], [87.99044037, 22.2412281], [87.99008942, 22.24143982], [87.98976135, 22.24171829], [87.98944855, 22.24205971], [87.98912811, 22.2424202], [87.98879242, 22.24273109], [87.98842621, 22.24296761], [87.98804474, 22.24321175], [87.98766327, 22.24344826], [87.9872818, 22.24369812], [87.98695374, 22.24399376], [87.98664856, 22.24431992], [87.98629761, 22.24465561], [87.98584747, 22.24498177], [87.98534393, 22.24532318], [87.98486328, 22.24570084], [87.98443604, 22.24609756], [87.98404694, 22.24646378], [87.98377991, 22.24687004], [87.98351288, 22.24723053], [87.98326874, 22.24757004], [87.98301697, 22.24793053], [87.98269653, 22.24828529], [87.98221588, 22.24860954], [87.98249817, 22.24888611], [87.98027802, 22.25110817], [87.98027802, 22.25139046], [87.97944641, 22.25221825], [87.97943115, 22.25234795], [87.97910309, 22.25272942], [87.97873688, 22.2530899], [87.9784317, 22.25349045], [87.97817993, 22.2538929], [87.97792816, 22.2542572], [87.97763824, 22.25450134], [87.97742462, 22.25483131], [87.97724152, 22.25522232], [87.97697449, 22.25554466], [87.97685242, 22.25573158], [87.97673798, 22.25591087], [87.9765625, 22.25632286], [87.97634125, 22.25665665], [87.97610474, 22.2569828], [87.97583771, 22.25733185], [87.97559357, 22.25777245], [87.97531891, 22.25827408], [87.97498322, 22.25880051], [87.97465515, 22.25935173], [87.97416687, 22.25971985], [87.97389221, 22.26000023], [87.97416687, 22.26028061], [87.97416687, 22.26055527], [87.97389221, 22.26082993], [87.97389221, 22.26111031], [87.97249603, 22.26250076], [87.97249603, 22.26278114], [87.97138977, 22.26389122], [87.97166443, 22.26416588], [87.97092438, 22.26491165], [87.97055817, 22.26527977], [87.9704361, 22.26522255], [87.9701767, 22.26567078], [87.96993256, 22.26613617], [87.96953583, 22.26644325], [87.9691925, 22.26679039], [87.96891785, 22.2672081], [87.96871185, 22.26768875], [87.96849823, 22.26814079], [87.96819305, 22.26852036], [87.96792603, 22.26898956], [87.96755219, 22.26943016], [87.9672699, 22.26992989], [87.96694946, 22.27036095], [87.96669006, 22.2707901], [87.96640778, 22.27116966], [87.96619415, 22.2715683], [87.96598816, 22.27197075], [87.96580505, 22.27242851], [87.96556091, 22.27286339], [87.96528625, 22.27330971], [87.9650116, 22.27374077], [87.96475983, 22.27414894], [87.96450806, 22.27449989], [87.96427917, 22.2748909], [87.9640274, 22.27526093], [87.96369171, 22.27561951], [87.96338654, 22.27604103], [87.96305847, 22.27638817], [87.96273041, 22.27669907], [87.96235657, 22.27695084], [87.96199799, 22.27727127], [87.96170044, 22.27763748], [87.96148682, 22.27808189], [87.96131897, 22.27852058], [87.96108246, 22.27886963], [87.96083069, 22.2791996], [87.96055603, 22.27952957], [87.96028137, 22.27988052], [87.96004486, 22.28022194], [87.95993805, 22.28063965], [87.9598465, 22.28108025], [87.9597168, 22.2814312], [87.95959473, 22.2817688], [87.95946503, 22.28215027], [87.9593811, 22.28259087], [87.95921326, 22.28308105], [87.95909119, 22.28364944], [87.95889282, 22.28416061], [87.95868683, 22.28466988], [87.95861816, 22.28519821], [87.95861053, 22.2857132], [87.95864868, 22.28619385], [87.95877075, 22.28659058], [87.9588089, 22.28693008], [87.95864868, 22.28729057], [87.95864868, 22.28775024], [87.95867157, 22.28829193], [87.95887756, 22.28881454], [87.95909882, 22.28937149], [87.9593277, 22.28991127], [87.95946503, 22.29048729], [87.95963287, 22.29104805], [87.95970917, 22.29169273], [87.9597702, 22.29232979], [87.95993805, 22.29294586], [87.95988464, 22.29356384], [87.95974731, 22.29412079], [87.95975494, 22.29458618], [87.9598999, 22.29491425], [87.9599762, 22.29521179], [87.95999908, 22.29552078], [87.95999908, 22.29586029], [87.96000671, 22.29627037], [87.96005249, 22.29675674], [87.96019745, 22.29724312], [87.96009827, 22.29770279], [87.96000671, 22.29817009], [87.95999908, 22.29863548], [87.95999908, 22.29911041], [87.96002197, 22.29963112], [87.96015167, 22.30015945], [87.96029663, 22.30070114], [87.96051025, 22.30118942], [87.96055603, 22.30167007], [87.96055603, 22.30212975], [87.96055603, 22.30254936], [87.96055603, 22.30295372], [87.96055603, 22.30334854], [87.96055603, 22.30376053], [87.96055603, 22.30416107], [87.96055603, 22.30455971], [87.96050262, 22.30492973], [87.96039581, 22.30528069], [87.96029663, 22.30565071], [87.96024323, 22.3060894], [87.96008301, 22.30648994], [87.96000671, 22.3069706], [87.95995331, 22.30747986], [87.95976257, 22.30793953], [87.95966339, 22.30844116], [87.9594574, 22.30888176], [87.95928192, 22.30932999], [87.95910645, 22.30977058], [87.95888519, 22.31015205], [87.95867157, 22.31052971], [87.95857239, 22.31099892], [87.95839691, 22.31143951], [87.95835876, 22.31190109], [87.95825958, 22.31228065], [87.95809174, 22.31265068], [87.95804596, 22.31307983], [87.95802307, 22.31349754], [87.95786285, 22.31381989], [87.95777893, 22.31412125], [87.95775604, 22.31442642], [87.95765686, 22.31472015], [87.95752716, 22.31508064], [87.95746613, 22.31555557], [87.95730591, 22.31606293], [87.95722961, 22.31662941], [87.95722198, 22.31720734], [87.95722961, 22.31776047], [87.95730591, 22.31833076], [87.95742035, 22.31894112], [87.95749664, 22.31958961], [87.95750427, 22.32023811], [87.95749664, 22.32082939], [87.95750427, 22.32133675], [87.95752716, 22.32177162], [87.95762634, 22.32216454], [87.95773315, 22.32258034], [87.95775604, 22.32302094], [87.95771027, 22.32345963], [87.95774078, 22.323843], [87.95774841, 22.32417488], [87.95761871, 22.32446289], [87.95751953, 22.32477188], [87.95749664, 22.32514572], [87.95744324, 22.32557106], [87.95730591, 22.32602119], [87.9574585, 22.32653046], [87.95765686, 22.32707977], [87.95763397, 22.32762337], [87.95752716, 22.32809258], [87.9574585, 22.32851028], [87.95729828, 22.32883835], [87.95722961, 22.32920265], [87.95722198, 22.32957077], [87.95722198, 22.3299408], [87.95722198, 22.33029938], [87.95722198, 22.33065987], [87.95722198, 22.33103943], [87.95722198, 22.33145714], [87.95726013, 22.33191109], [87.95743561, 22.33240509], [87.95749664, 22.33299446], [87.95750427, 22.33362389], [87.95750427, 22.33424187], [87.95749664, 22.33481979], [87.95749664, 22.33535957], [87.95749664, 22.33586121], [87.95754242, 22.33634758], [87.95773315, 22.33681488], [87.95777893, 22.3373394], [87.95777893, 22.33790016], [87.95777893, 22.33846664], [87.95777893, 22.33905029], [87.95777893, 22.33966064], [87.95780182, 22.340271], [87.95791626, 22.34083748], [87.9580307, 22.34130287], [87.95804596, 22.34173012], [87.95806122, 22.34216118], [87.95808411, 22.34261703], [87.95819092, 22.34305954], [87.95830536, 22.34352684], [87.95833588, 22.34400558], [87.95833588, 22.34445953], [87.95833588, 22.34489059], [87.95833588, 22.34528542], [87.95832062, 22.34564972], [87.95825958, 22.34600067], [87.95810699, 22.34631538], [87.95806122, 22.34667969], [87.95806885, 22.34709167], [87.95819855, 22.34750175], [87.95831299, 22.34791183], [87.95833588, 22.34830475], [87.95832062, 22.34869003], [87.95824432, 22.34908867], [87.95809174, 22.34951019], [87.95806122, 22.34999275], [87.95804596, 22.3504715], [87.95800018, 22.35091972], [87.95783234, 22.35137177], [87.95777893, 22.35181046], [87.95775604, 22.35222054], [87.95765686, 22.35259056], [87.95756531, 22.35292625], [87.95768738, 22.3532505], [87.95776367, 22.3535881], [87.95776367, 22.35391426], [87.95767975, 22.35424805], [87.95752716, 22.35462952], [87.95749664, 22.35508919], [87.95749664, 22.35557938], [87.95749664, 22.35608292], [87.95750427, 22.35659981], [87.95749664, 22.35713005], [87.9574585, 22.35766983], [87.95731354, 22.35811806], [87.95722961, 22.35857964], [87.95717621, 22.35905075], [87.95703888, 22.35948944], [87.9569931, 22.35995293], [87.95709229, 22.36044121], [87.95713806, 22.36091995], [87.95691681, 22.3614006], [87.95665741, 22.36189079], [87.95639038, 22.36234856], [87.95615387, 22.36281967], [87.95610046, 22.36340141], [87.95600891, 22.3639698], [87.95585632, 22.3644886], [87.95583344, 22.36497879], [87.95582581, 22.36540985], [87.95583344, 22.36577988], [87.95581055, 22.36609268], [87.95569611, 22.36637115], [87.95558167, 22.36664009], [87.95555878, 22.36696815], [87.95555115, 22.36734962], [87.95555878, 22.36777115], [87.95555878, 22.36824036], [87.95555878, 22.36874008], [87.95555115, 22.36925507], [87.955513, 22.36976051], [87.95535278, 22.3702507], [87.95526123, 22.37075806], [87.9551239, 22.37126541], [87.95495605, 22.37176132], [87.95465088, 22.37212944], [87.95426941, 22.3724308], [87.95398712, 22.37286949], [87.95385742, 22.37341118], [87.95365143, 22.37393188], [87.95359039, 22.37452126], [87.95349884, 22.37508392], [87.95332336, 22.37556267], [87.95314026, 22.37596703], [87.95300293, 22.37627983], [87.95281982, 22.37653542], [87.95271301, 22.37684059], [87.95252991, 22.37718964], [87.95236206, 22.37758064], [87.95220184, 22.37796783], [87.95201111, 22.37833023], [87.95181274, 22.37870979], [87.95157623, 22.37919044], [87.95137024, 22.37973022], [87.95115662, 22.38027954], [87.95107269, 22.38083076], [87.95088196, 22.38132095], [87.950737, 22.38187027], [87.95053864, 22.38234901], [87.95033264, 22.382761], [87.95027161, 22.38320732], [87.95022583, 22.38360023], [87.95004272, 22.38391113], [87.94999695, 22.38426018], [87.94998169, 22.38466072], [87.94989777, 22.38509369], [87.94975281, 22.38553047], [87.94967651, 22.38599968], [87.9495163, 22.38635063], [87.94941711, 22.38676071], [87.94924164, 22.38718987], [87.94917297, 22.38774109], [87.94911957, 22.38833809], [87.94893646, 22.38886261], [87.94893646, 22.38937187], [87.94917297, 22.38944054], [87.94916534, 22.39027786], [87.9486084, 22.39083481], [87.94889069, 22.39110947], [87.94889069, 22.39138985], [87.94916534, 22.39166641], [87.94916534, 22.39194489], [87.94889069, 22.39221954], [87.94889069, 22.39500046], [87.94861603, 22.39528084], [87.9486084, 22.3955555], [87.94889069, 22.39583015], [87.94889069, 22.39639091], [87.94916534, 22.39666939], [87.94916534, 22.39944458], [87.9486084, 22.40000153], [87.94805908, 22.40000153], [87.94750214, 22.40055466], [87.94750214, 22.40083313], [87.94721985, 22.4011116], [87.94721985, 22.40194511], [87.94694519, 22.40222168], [87.94695282, 22.40332985], [87.9466629, 22.40361023], [87.9466629, 22.40389061], [87.94694519, 22.40416718], [87.94695282, 22.40472031], [87.9466629, 22.40500069], [87.9466629, 22.40528107], [87.94638824, 22.40555573], [87.94638824, 22.40583038], [87.94619751, 22.40602493], [87.94610596, 22.4061203], [87.94638824, 22.40611076], [87.94555664, 22.40694427], [87.94527435, 22.4066658], [87.94499969, 22.40666962], [87.94444275, 22.40611076], [87.94361115, 22.40694427], [87.94248962, 22.40694046], [87.94194794, 22.40750122], [87.94194794, 22.40777969], [87.94166565, 22.40805435], [87.94167328, 22.40860939], [87.94139099, 22.40888977], [87.9411087, 22.40888977], [87.94082642, 22.40917969], [87.9402771, 22.40916634], [87.94000244, 22.40944481], [87.93972015, 22.40944481], [87.9394455, 22.40972137], [87.9394455, 22.40999985], [87.93722534, 22.41221809], [87.93611145, 22.41333389], [87.93583679, 22.41305542], [87.93499756, 22.41305923], [87.93444824, 22.41360855], [87.93444824, 22.41389084], [87.93360901, 22.41472244], [87.93333435, 22.41472244], [87.93305206, 22.41500282], [87.9327774, 22.41499138], [87.93138885, 22.41638947], [87.93138885, 22.41666985], [87.93054962, 22.41749954], [87.9302597, 22.41749954], [87.92749023, 22.42028046], [87.92749786, 22.42055511], [87.92722321, 22.42082977], [87.92722321, 22.42111969], [87.92694092, 22.42138863], [87.92694092, 22.42194366], [87.92666626, 22.42222214], [87.92666626, 22.4244442], [87.9263916, 22.42472076], [87.9263916, 22.42610931], [87.92666626, 22.4263916], [87.92666626, 22.42750168], [87.9263916, 22.42777824], [87.9263916, 22.42805481], [87.92666626, 22.42833328], [87.92666626, 22.42861176], [87.92694092, 22.42889023], [87.92694092, 22.42917061], [87.92666626, 22.42944527], [87.92666626, 22.42972183], [87.9263916, 22.43000031], [87.9263916, 22.43029022], [87.92610931, 22.43055534], [87.92610931, 22.43083191], [87.92582703, 22.43111038], [87.92583466, 22.43166733], [87.92555237, 22.43194389], [87.92555237, 22.43222046], [87.92527771, 22.43250084], [87.92527771, 22.43278122], [87.92500305, 22.43305588], [87.92500305, 22.43333054], [87.92333221, 22.43499947], [87.92305756, 22.43472099], [87.92193604, 22.43527985], [87.92138672, 22.43527985], [87.92111206, 22.43556023], [87.92028046, 22.43556023], [87.91999817, 22.43527985], [87.9183197, 22.43527985], [87.91805267, 22.43499947], [87.91583252, 22.43499947], [87.91555023, 22.43472099], [87.91471863, 22.43472099], [87.91444397, 22.43499947], [87.91410828, 22.43500137], [87.91370392, 22.43500137], [87.91330719, 22.43502426], [87.91291809, 22.43513107], [87.91252899, 22.43521118], [87.91210938, 22.43503952], [87.91163635, 22.43500137], [87.91113281, 22.43499756], [87.91062927, 22.43499947], [87.91014862, 22.43499947], [87.90972137, 22.43499947], [87.90936279, 22.43499947], [87.90906525, 22.43499947], [87.90878296, 22.43500328], [87.90847778, 22.43505287], [87.90817261, 22.43522072], [87.90776825, 22.43527222], [87.90731812, 22.43527985], [87.90688324, 22.43532944], [87.90645599, 22.43550682], [87.90598297, 22.43555069], [87.90545654, 22.43556023], [87.904953, 22.43556023], [87.90444946, 22.43551064], [87.90406036, 22.43531036], [87.90368652, 22.43521118], [87.90338898, 22.43507957], [87.90306854, 22.43501282], [87.90267944, 22.43500137], [87.90222168, 22.43499947], [87.90171814, 22.43495941], [87.9012146, 22.43478584], [87.90061188, 22.43472672], [87.89996338, 22.4347229], [87.89927673, 22.43476105], [87.89862061, 22.43492126], [87.89795685, 22.43482971], [87.89743042, 22.43465805], [87.8969574, 22.4344902], [87.89650726, 22.43441772], [87.89612579, 22.43433952], [87.8957901, 22.43441391], [87.89544678, 22.43444061], [87.89509583, 22.4344902], [87.89476776, 22.43463707], [87.89435577, 22.43470955], [87.89392853, 22.43478012], [87.89359283, 22.43497276], [87.89322662, 22.43511963], [87.89286804, 22.4352951], [87.89251709, 22.43551254], [87.8921051, 22.43568993], [87.891716, 22.43589973], [87.8913269, 22.43616104], [87.89092255, 22.43638992], [87.89048004, 22.43657875], [87.88999176, 22.43670464], [87.88957977, 22.43694115], [87.88918304, 22.43719292], [87.88874817, 22.43737602], [87.88835144, 22.4375782], [87.88800049, 22.43774986], [87.88777924, 22.43777657], [87.88471985, 22.43951225], [87.88411713, 22.44017982], [87.88389587, 22.44091988], [87.88376617, 22.44158936], [87.8833313, 22.44082832], [87.8833313, 22.44055557], [87.88249969, 22.43971825], [87.88249969, 22.43944359], [87.8813858, 22.43833351], [87.88111115, 22.43833351], [87.88083649, 22.43805504], [87.88500977, 22.43433952], [87.88528442, 22.43395996], [87.88558197, 22.43357086], [87.88587189, 22.43317032], [87.88618469, 22.43283653], [87.88648987, 22.4324894], [87.88677216, 22.43210983], [87.8870697, 22.43170929], [87.88742828, 22.43135071], [87.88777161, 22.43094063], [87.88807678, 22.43049049], [87.8883667, 22.43000031], [87.88866425, 22.42951584], [87.88897705, 22.42906952], [87.88931274, 22.42865944], [87.88967896, 22.42834282], [87.89111328, 22.42692947], [87.89389038, 22.42416573], [87.89416504, 22.42416573], [87.89472198, 22.42361069], [87.89499664, 22.42361069], [87.89554596, 22.42305946], [87.89583588, 22.42305946], [87.89639282, 22.42250061], [87.89694214, 22.42250061], [87.8972168, 22.42222023], [87.89778137, 22.42222214], [87.89805603, 22.42194366], [87.89833069, 22.42194366], [87.89861298, 22.42166519], [87.89971924, 22.42167091], [87.90000153, 22.42139053], [87.90305328, 22.42138863], [87.90315247, 22.4214859], [87.9033432, 22.42167091], [87.90805817, 22.42166519], [87.90833282, 22.42194366], [87.90916443, 22.42194366], [87.90944672, 22.42222214], [87.91000366, 22.42222214], [87.91027832, 22.42194366], [87.91055298, 22.42194366], [87.91083527, 22.42222214], [87.91166687, 22.42194366], [87.91194153, 22.42166519], [87.9125061, 22.42167091], [87.91361237, 22.42056084], [87.91388702, 22.42028046], [87.91388702, 22.42000008], [87.91471863, 22.41917038], [87.91471863, 22.41889], [87.91500092, 22.41860962], [87.91500092, 22.41833305], [87.91593933, 22.41739082], [87.91666412, 22.41666603], [87.91665649, 22.41638947], [87.91694641, 22.4161129], [87.91694641, 22.41583252], [87.91750336, 22.41527748], [87.91777802, 22.41527939], [87.91944122, 22.41360855], [87.91971588, 22.41360855], [87.92028046, 22.41305923], [87.92056274, 22.41305923], [87.92305756, 22.41055107], [87.92305756, 22.41027641], [87.92333221, 22.40999985], [87.92333221, 22.40971947], [87.9236145, 22.40944481], [87.9236145, 22.40916634], [87.92472076, 22.40806007], [87.92472076, 22.40777969], [87.92500305, 22.40750122], [87.92555237, 22.40722084], [87.92555237, 22.40694427], [87.92583466, 22.4066658], [87.92610931, 22.40666962], [87.92722321, 22.40555954], [87.92749023, 22.40555954], [87.9283371, 22.40472031], [87.92861176, 22.40472221], [87.92972565, 22.40361023], [87.92972565, 22.40305519], [87.93000031, 22.40277863], [87.93000031, 22.40250015], [87.93028259, 22.40222168], [87.93027496, 22.40138817], [87.93054962, 22.4011116], [87.93055725, 22.40055466], [87.93083191, 22.40027809], [87.93083191, 22.39998817], [87.9311142, 22.39972305], [87.9311142, 22.39860916], [87.93138885, 22.39833069], [87.93138885, 22.39777946], [87.93165588, 22.39749908], [87.93138885, 22.39722061], [87.93138885, 22.39694405], [87.93165588, 22.39666939], [87.93165588, 22.39611053], [87.9319458, 22.39583015], [87.9319458, 22.39500046], [87.93222046, 22.39472008], [87.93222046, 22.39388847], [87.93305206, 22.39249992], [87.93305206, 22.39221954], [87.93333435, 22.39194489], [87.93333435, 22.39138794], [87.93361664, 22.39110947], [87.93360901, 22.39027786], [87.9338913, 22.38999939], [87.9338913, 22.38944054], [87.93416595, 22.38916588], [87.93416595, 22.38889122], [87.93444824, 22.38861275], [87.93444824, 22.38778114], [87.9347229, 22.38750267], [87.9347229, 22.3869381], [87.93444824, 22.38666725], [87.93444824, 22.38639069], [87.9347229, 22.3861084], [87.9347229, 22.38582993], [87.93499756, 22.38555527], [87.93527985, 22.38555908], [87.93611145, 22.38471985], [87.93611145, 22.38388634], [87.93638611, 22.38360977], [87.93638611, 22.38333321], [87.9366684, 22.38305473], [87.9366684, 22.38249969], [87.93694305, 22.38222313], [87.93694305, 22.38166618], [87.93723297, 22.38138962], [87.93722534, 22.38083267], [87.9375, 22.3805542], [87.9375, 22.38000107], [87.93776703, 22.37972069], [87.93777466, 22.37833214], [87.93805695, 22.37805557], [87.93805695, 22.37750053], [87.9383316, 22.37722015], [87.9383316, 22.37638855], [87.93860626, 22.37611008], [87.93861389, 22.37583351], [87.93888855, 22.37555504], [87.93888855, 22.3741703], [87.93916321, 22.37389183], [87.93916321, 22.37332916], [87.9394455, 22.37305641], [87.93945313, 22.37249756], [87.93972015, 22.3722229], [87.93972015, 22.37194443], [87.94000244, 22.37166595], [87.94000244, 22.37138748], [87.9402771, 22.37111092], [87.9402771, 22.37083054], [87.94055176, 22.37055779], [87.94055176, 22.37001038], [87.94082642, 22.36972046], [87.94083405, 22.36944389], [87.9411087, 22.36916542], [87.9411087, 22.36889076], [87.94139099, 22.36861038], [87.94139099, 22.36833], [87.94152832, 22.36819077], [87.94166565, 22.36805534], [87.94166565, 22.36772919], [87.94166565, 22.36750031], [87.9417572, 22.36741066], [87.94194794, 22.36722183], [87.94194794, 22.36666679], [87.9422226, 22.36638832], [87.9422226, 22.36581993], [87.9422226, 22.36555481], [87.94233704, 22.36544037], [87.94249725, 22.36527824], [87.94249725, 22.36489105], [87.94249725, 22.3647213], [87.94277954, 22.36444473], [87.94277954, 22.36392021], [87.94277954, 22.36277771], [87.94304657, 22.36250114], [87.94304657, 22.36194038], [87.94249725, 22.36138916], [87.94194794, 22.36139107], [87.94167328, 22.36166954], [87.9402771, 22.36166573], [87.94000244, 22.3619442], [87.9394455, 22.3619442], [87.93888855, 22.36138916], [87.93888855, 22.36111259], [87.94000244, 22.36000061], [87.9402771, 22.36000061], [87.94139099, 22.35889053], [87.94139099, 22.35860825], [87.94166565, 22.35833359], [87.94139099, 22.35805511], [87.94139099, 22.35749817], [87.94194794, 22.35695076], [87.9422226, 22.35695076], [87.94333649, 22.35807037], [87.94361115, 22.35807037], [87.94416809, 22.35749817], [87.94416809, 22.3572197], [87.9438858, 22.35694695], [87.9438858, 22.35610962], [87.94361115, 22.35583305], [87.94361115, 22.35499954], [87.9422226, 22.35361099], [87.94194794, 22.35388947], [87.94139099, 22.35388947], [87.9411087, 22.35416985], [87.94055176, 22.35416412], [87.9402771, 22.3544445], [87.94000244, 22.3544445], [87.93972015, 22.35472107], [87.93972015, 22.35527992], [87.9394455, 22.35527611], [87.93860626, 22.35610962], [87.93860626, 22.35638809], [87.93805695, 22.35695076], [87.93723297, 22.35695076], [87.93667603, 22.35638809], [87.93667603, 22.35610962], [87.93722534, 22.3555584], [87.9375, 22.3555603], [87.93888855, 22.35416985], [87.93888855, 22.35388947], [87.93916321, 22.35361099], [87.93945313, 22.35361099], [87.93972015, 22.35333252], [87.94000244, 22.35333252], [87.9402771, 22.35305405], [87.94082642, 22.35305977], [87.9411087, 22.35277939], [87.94167328, 22.35277939], [87.94194794, 22.35250092], [87.9422226, 22.35250092], [87.94248962, 22.35222054], [87.9438858, 22.35222244], [87.94404602, 22.35206032], [87.94472504, 22.35138893], [87.94473267, 22.35111046], [87.94527435, 22.35055542], [87.9458313, 22.35056114], [87.94610596, 22.35028076], [87.94638824, 22.35028076], [87.94695282, 22.34972191], [87.94611359, 22.3488884], [87.94555664, 22.34888077], [87.94526672, 22.34917068], [87.94499969, 22.34917068], [87.94473267, 22.34888077], [87.94444275, 22.3488884], [87.94416809, 22.34861183], [87.9438858, 22.34861183], [87.94374847, 22.3484726], [87.94361115, 22.34833336], [87.94385529, 22.34808731], [87.94444275, 22.34750175], [87.94444275, 22.34667015], [87.94526672, 22.34584236], [87.94555664, 22.3461113], [87.94638824, 22.3461113], [87.94721985, 22.34694481], [87.94750214, 22.34694481], [87.94805908, 22.34639168], [87.94721985, 22.34555817], [87.94721985, 22.34527969], [87.9458313, 22.34389114], [87.9458313, 22.34361076], [87.94610596, 22.34333038], [87.94611359, 22.34222221], [87.9458313, 22.34194374], [87.9458313, 22.34166527], [87.94610596, 22.34139061], [87.94610596, 22.34111023], [87.94638824, 22.34082985], [87.94638824, 22.34055519], [87.9466629, 22.34028053], [87.9466629, 22.3386097], [87.94694519, 22.33833313], [87.94694519, 22.33805466], [87.9466629, 22.33777809], [87.9466629, 22.33722115], [87.94694519, 22.33694458], [87.94694519, 22.33666611], [87.9466629, 22.33638954], [87.9466629, 22.33527946], [87.94638824, 22.3350029], [87.94695282, 22.33444023], [87.94694519, 22.33389091], [87.94721985, 22.33360863], [87.94721985, 22.33305931], [87.94695282, 22.33278084], [87.94695282, 22.33250046], [87.9466629, 22.33222008], [87.9466629, 22.33166885], [87.94638824, 22.33139038], [87.94638824, 22.33110809], [87.94611359, 22.33083344], [87.94610596, 22.32999992], [87.9458313, 22.32971954], [87.9458313, 22.32805443], [87.94555664, 22.32777023], [87.94555664, 22.32749939], [87.94526672, 22.32722092], [87.94527435, 22.32694435], [87.94499969, 22.32666588], [87.94499969, 22.32611084], [87.94444275, 22.32555962], [87.94444275, 22.32528114], [87.94348907, 22.32432747], [87.9430542, 22.32388878], [87.94277954, 22.32389069], [87.94194031, 22.32305527], [87.9411087, 22.32222176], [87.9411087, 22.32194519], [87.93972015, 22.32055092], [87.9394455, 22.32055473], [87.9383316, 22.31944466], [87.9383316, 22.31916618], [87.93694305, 22.31777954], [87.93694305, 22.31722069], [87.9366684, 22.31694412], [87.93638611, 22.31666946], [87.93611145, 22.31694412], [87.93583679, 22.31722069], [87.93583679, 22.31777954], [87.9355545, 22.31805611], [87.93554688, 22.31833076], [87.93583679, 22.31860924], [87.93583679, 22.31917191], [87.93611145, 22.31916618], [87.9375, 22.32055473], [87.9375, 22.32083321], [87.93777466, 22.32111168], [87.93776703, 22.32222176], [87.93805695, 22.32250023], [87.93805695, 22.32361031], [87.93861389, 22.32416725], [87.93860626, 22.32471275], [87.93888855, 22.32500076], [87.93888855, 22.32639122], [87.93916321, 22.32666969], [87.93916321, 22.32805443], [87.93945313, 22.32833099], [87.9394455, 22.32916641], [87.93972015, 22.32944489], [87.93972015, 22.32971954], [87.94000244, 22.32999992], [87.93945313, 22.33056068], [87.93916321, 22.33056068], [87.93888855, 22.3302803], [87.93860626, 22.3302803], [87.93805695, 22.32971954], [87.93723297, 22.33056068], [87.93694305, 22.33055496], [87.93638611, 22.33111191], [87.9347229, 22.33111191], [87.93360901, 22.33222008], [87.93361664, 22.33250046], [87.93527985, 22.33416748], [87.93527985, 22.33444023], [87.9347229, 22.3350029], [87.93458557, 22.33486176], [87.93444824, 22.33472252], [87.9338913, 22.33472252], [87.93360901, 22.33444405], [87.9327774, 22.33444405], [87.93250275, 22.33416748], [87.93222046, 22.33444405], [87.9319458, 22.33444405], [87.93083191, 22.33333397], [87.93083191, 22.3330555], [87.9338913, 22.32999992], [87.9338913, 22.32971954], [87.93416595, 22.32944489], [87.93416595, 22.32916641], [87.93444824, 22.32888985], [87.93444824, 22.32777023], [87.93527985, 22.32694435], [87.9355545, 22.32694435], [87.93638611, 22.32611084], [87.93638611, 22.32583046], [87.93611145, 22.3255558], [87.93611145, 22.32500076], [87.93583679, 22.32471275], [87.93583679, 22.32333374], [87.93611145, 22.32305527], [87.93611145, 22.32250023], [87.93583679, 22.32222176], [87.93583679, 22.32138824], [87.93554688, 22.32111168], [87.9355545, 22.32083321], [87.93527985, 22.32055473], [87.93527985, 22.3200016], [87.93499756, 22.31971931], [87.93499756, 22.31944466], [87.9347229, 22.31916618], [87.9347229, 22.31833076], [87.93444824, 22.31805611], [87.93444824, 22.31777954], [87.93416595, 22.31750107], [87.93416595, 22.31722069], [87.9338913, 22.31694412], [87.9338913, 22.31555557], [87.93361664, 22.31528091], [87.93361664, 22.31472015], [87.93333435, 22.31444359], [87.93333435, 22.31416512], [87.93305206, 22.31389046], [87.93305206, 22.31138992], [87.93332672, 22.31110954], [87.93305206, 22.31083488], [87.93305206, 22.31027794], [87.9327774, 22.30999947], [87.93361664, 22.30916977], [87.93361664, 22.30861282], [87.9338913, 22.30833244], [87.9338913, 22.30750275], [87.93416595, 22.30721855], [87.93416595, 22.30694389], [87.93444824, 22.30666733], [87.93444824, 22.30582809], [87.9347229, 22.30555534], [87.9347229, 22.30444908], [87.93499756, 22.30417061], [87.93499756, 22.30305099], [87.93527985, 22.30277634], [87.9347229, 22.30221939], [87.93499756, 22.30194473], [87.93499756, 22.30166626], [87.93527985, 22.30138969], [87.93527985, 22.30111122], [87.93499756, 22.30083084], [87.93499756, 22.30055428], [87.93527985, 22.30027962], [87.93527985, 22.30000114], [87.93554688, 22.29972076], [87.9355545, 22.29888916], [87.93583679, 22.29861069], [87.93583679, 22.29722023], [87.9355545, 22.29694366], [87.9355545, 22.2947216], [87.93527985, 22.29445267], [87.93527985, 22.29417038], [87.93554688, 22.29389191], [87.93554688, 22.29332924], [87.93583679, 22.29305649], [87.93583679, 22.29166031], [87.9355545, 22.29138756], [87.93554688, 22.29110909], [87.93583679, 22.29083061], [87.93583679, 22.28944397], [87.9355545, 22.2891655], [87.93554688, 22.28806114], [87.93583679, 22.28778076], [87.93583679, 22.28722], [87.9355545, 22.28694534], [87.93554688, 22.28553963], [87.93583679, 22.28527832], [87.93583679, 22.28499985], [87.93554688, 22.28471947], [87.9355545, 22.28444481], [87.93583679, 22.28416634], [87.93583679, 22.28333282], [87.9355545, 22.28305626], [87.93554688, 22.28222275], [87.93527985, 22.28194427], [87.93527985, 22.2816658], [87.93499756, 22.28139114], [87.93499756, 22.28111267], [87.93583679, 22.28027916], [87.93583679, 22.2797184], [87.93611145, 22.27944374], [87.93611145, 22.27889061], [87.93583679, 22.27860832], [87.93583679, 22.27832985], [87.93611145, 22.27805519], [87.93611145, 22.27583122], [87.93638611, 22.27555466], [87.93638611, 22.27472305], [87.93611145, 22.27444458], [87.93638611, 22.27444458], [87.93638611, 22.2741642], [87.93667603, 22.27388954], [87.9366684, 22.27166748], [87.93694305, 22.27139091], [87.93694305, 22.27000046], [87.93667603, 22.26972008], [87.9366684, 22.26888847], [87.93694305, 22.26861191], [87.93694305, 22.26694489], [87.93722534, 22.26666641], [87.93723297, 22.26611137], [87.9375, 22.2658329], [87.9375, 22.26472282], [87.9383316, 22.26388741], [87.9383316, 22.26361084], [87.93860626, 22.26333046], [87.93861389, 22.26305771], [87.93888855, 22.26278114], [87.93888855, 22.26250076], [87.93945313, 22.26194], [87.9394455, 22.26166534], [87.93972015, 22.26139069], [87.93972015, 22.26111031], [87.94000244, 22.26082993], [87.94000244, 22.2602787], [87.9411087, 22.25917053], [87.94139099, 22.25917053], [87.9422226, 22.25832939], [87.94249725, 22.25833321], [87.9438858, 22.25694466], [87.94416809, 22.25694466], [87.9458313, 22.25527763], [87.94610596, 22.25527954], [87.9466629, 22.2547226], [87.94721985, 22.2547226], [87.94833374, 22.25361061], [87.9486618, 22.25337982], [87.94890594, 22.25313187], [87.9491806, 22.25286865], [87.94947815, 22.25259018], [87.94985199, 22.25235748], [87.95015717, 22.25208092], [87.95054626, 22.25185966], [87.95097351, 22.25164223], [87.95137024, 22.25138664], [87.95175934, 22.25110817], [87.95213318, 22.25081062], [87.95246887, 22.2504921], [87.95278168, 22.25015068], [87.95310211, 22.24982262], [87.95349884, 22.24954796], [87.95388794, 22.24924088], [87.95424652, 22.2489109], [87.95462799, 22.24859047], [87.95497894, 22.24823952], [87.95532227, 22.24785805], [87.9556427, 22.24752045], [87.95596313, 22.24722099], [87.95624542, 22.24694252], [87.9564743, 22.24666023], [87.95667267, 22.24634933], [87.95689392, 22.24603844], [87.9571228, 22.24567032], [87.95745087, 22.24533272], [87.9578476, 22.24500084], [87.95825958, 22.24468994], [87.95862579, 22.24438095], [87.95900726, 22.24415016], [87.95936584, 22.24393082], [87.9597702, 22.24382019], [87.9601593, 22.2436409], [87.96058655, 22.24357414], [87.9609375, 22.2434063], [87.96134949, 22.24329948], [87.9617157, 22.24309731], [87.96218109, 22.24302101], [87.96260834, 22.24279022], [87.96308899, 22.24261093], [87.96362305, 22.24246979], [87.96409607, 22.24222183], [87.9645462, 22.24197769], [87.96499634, 22.24179077], [87.96544647, 22.24162102], [87.9658432, 22.24138069], [87.96623993, 22.24111176], [87.96665955, 22.24082947], [87.96713257, 22.24055672], [87.96759033, 22.24028587], [87.96804047, 22.24003029], [87.96840668, 22.23973274], [87.96872711, 22.23944092], [87.96901703, 22.23917007], [87.96930695, 22.23891068], [87.9696579, 22.23867035], [87.97000122, 22.23838043], [87.97033691, 22.23802948], [87.97067261, 22.23765182], [87.97099304, 22.23726082], [87.97129822, 22.23693085], [87.97154999, 22.23660088], [87.97168732, 22.23618126], [87.97193146, 22.23579979], [87.97212219, 22.23535919], [87.97225952, 22.23491096], [87.97245789, 22.2345295], [87.97257233, 22.23413086], [87.97274017, 22.23377037], [87.97281647, 22.23335838], [87.97301483, 22.23303032], [87.97306061, 22.23262215], [87.97311401, 22.23216438], [87.97329712, 22.23170853], [87.97342682, 22.2311306], [87.97357178, 22.23052406], [87.97357178, 22.22992897], [87.97344208, 22.22942162], [87.97335815, 22.22894478], [87.97340393, 22.22847557], [87.97361755, 22.2280407], [87.97387695, 22.22759056], [87.97414398, 22.22712517], [87.97437286, 22.22661018], [87.97454071, 22.22603989], [87.9746933, 22.22545052], [87.97480774, 22.22485542], [87.9749527, 22.22433281], [87.97499847, 22.22377968], [87.97505188, 22.2232399], [87.97524261, 22.22271919], [87.97538757, 22.2221508], [87.97568512, 22.22168922], [87.97608948, 22.22127914], [87.97651672, 22.22086143], [87.97696686, 22.22047997], [87.97741699, 22.22018814], [87.97776794, 22.21986008], [87.97805786, 22.21951675], [87.97833252, 22.21916962], [87.9786377, 22.21886444], [87.97892761, 22.21857834], [87.9792099, 22.21827126], [87.97946167, 22.21793175], [87.97971344, 22.21759605], [87.97997284, 22.21725082], [87.98023987, 22.21697807], [87.9805069, 22.21670914], [87.9807663, 22.21644974], [87.98105621, 22.21615982], [87.98140717, 22.21585083], [87.98190308, 22.21556282], [87.98245239, 22.21526909], [87.98295593, 22.21491814], [87.98336792, 22.21453094], [87.98371124, 22.21421814], [87.98403931, 22.21399117], [87.98426819, 22.21364975], [87.98454285, 22.21331024], [87.98484039, 22.21297073], [87.9852829, 22.21270943], [87.98573303, 22.21242714], [87.98615265, 22.21206093], [87.98660278, 22.21174049], [87.98708344, 22.21152115], [87.9875412, 22.21133232], [87.98792267, 22.21110916], [87.9883194, 22.21087074], [87.98876953, 22.21064949], [87.98918152, 22.21034241], [87.98959351, 22.21001625], [87.99002075, 22.20972061], [87.99044037, 22.2094593], [87.99088287, 22.20927048], [87.99133301, 22.20916176], [87.99143219, 22.20913696], [87.99177551, 22.20904922], [87.99220276, 22.20889091], [87.99265289, 22.20874214], [87.99312592, 22.20858383], [87.99356842, 22.20839119], [87.99407196, 22.20841408], [87.99664307, 22.2074585], [87.99764252, 22.20717812], [88.0, 22.20639038], [88.00026703, 22.20611], [88.0008316, 22.20611191], [88.00111389, 22.20583344], [88.00138855, 22.20583344], [88.00166321, 22.20555305], [88.00195313, 22.20556068], [88.00222015, 22.2052803], [88.00250244, 22.2052803], [88.00276947, 22.20499992], [88.00305176, 22.20499992], [88.00332642, 22.20471954], [88.0036087, 22.20472145], [88.00389099, 22.20444489], [88.00416565, 22.20444489], [88.00444794, 22.20416641], [88.00499725, 22.20417023], [88.00694275, 22.20222282], [88.00722504, 22.20222282], [88.00749969, 22.20194435], [88.00861359, 22.20138931], [88.00889587, 22.20138168], [88.0091629, 22.20166969], [88.00935364, 22.20148087], [88.00945282, 22.20138168], [88.00971985, 22.20138931], [88.01000214, 22.20111275], [88.01249695, 22.20111275], [88.01304626, 22.20055962], [88.01333618, 22.20083427], [88.01361084, 22.20083427], [88.01416779, 22.20027733], [88.01470947, 22.20027924], [88.01499939, 22.20055962], [88.01512909, 22.20042038], [88.01526642, 22.20027924], [88.01583099, 22.20027924], [88.01611328, 22.20000076], [88.01638794, 22.20027924], [88.01667023, 22.20000076], [88.01805878, 22.20000076], [88.01832581, 22.19971848], [88.01863861, 22.19971848], [88.01916504, 22.19972229], [88.01944733, 22.19944382], [88.01972198, 22.19972229], [88.01999664, 22.19972229], [88.02027893, 22.19944382], [88.02055359, 22.19944382], [88.02073669, 22.19962692], [88.02083588, 22.19972229], [88.02249908, 22.19972229], [88.02278137, 22.19944382], [88.02305603, 22.19944382], [88.02333069, 22.19972229], [88.02361298, 22.19972229], [88.02388763, 22.20000076], [88.02443695, 22.20000076], [88.02471924, 22.20027924], [88.02500153, 22.20027733], [88.02519989, 22.20048141], [88.02527618, 22.20055962], [88.02539825, 22.20055771], [88.02555847, 22.2005558], [88.02566528, 22.20066452], [88.02664948, 22.20166969], [88.02694702, 22.20166588], [88.02722168, 22.20194244], [88.02777863, 22.20305634], [88.02777863, 22.20360947], [88.02805328, 22.20388985], [88.02805328, 22.20499992], [88.02833557, 22.2052784], [88.02833557, 22.20583344], [88.02861023, 22.20611], [88.02861023, 22.20639038], [88.02889252, 22.20666695], [88.02889252, 22.20694351], [88.02916718, 22.20722008], [88.02916718, 22.20750046], [88.02999878, 22.20833397], [88.03028107, 22.20833397], [88.03055573, 22.20861053], [88.03083038, 22.20861053], [88.03111267, 22.20889091], [88.03166962, 22.20889091], [88.03193665, 22.20916939], [88.03250122, 22.20916557], [88.03277588, 22.20944405], [88.03472137, 22.20944405], [88.03555298, 22.20861053], [88.03639221, 22.20861053], [88.03694153, 22.20806122], [88.03778076, 22.20806122], [88.03806305, 22.20778084], [88.03887939, 22.20778084], [88.03916931, 22.20750809], [88.0402832, 22.20750809], [88.04055786, 22.20722008], [88.04277802, 22.20722198], [88.04305267, 22.20694351], [88.04360962, 22.20694351], [88.04389191, 22.20666695], [88.04471588, 22.20667076], [88.04499817, 22.20639038], [88.04556274, 22.20639038], [88.04582977, 22.20611], [88.04638672, 22.20611191], [88.04666901, 22.20583344], [88.04750061, 22.20583344], [88.04777527, 22.20555305], [88.04807281, 22.20556068], [88.04833221, 22.2052803], [88.04860687, 22.2052803], [88.04888916, 22.20499992], [88.05000305, 22.20499992], [88.05222321, 22.20277977], [88.05222321, 22.20249939], [88.05249786, 22.20222282], [88.05249786, 22.20194435], [88.05278015, 22.20166588], [88.05278015, 22.20138168], [88.05305481, 22.20111275], [88.05304718, 22.20083237], [88.05361176, 22.20027733], [88.05387878, 22.20027924], [88.05665588, 22.19749832], [88.05665588, 22.19721985], [88.05916595, 22.19472313], [88.05944824, 22.19472313], [88.0597229, 22.19444466], [88.05999756, 22.19444466], [88.06083679, 22.19361115], [88.06111145, 22.19361115], [88.06194305, 22.19277954], [88.0625, 22.19277954], [88.0627594, 22.19250107], [88.0630722, 22.19250107], [88.06360626, 22.19194031], [88.06361389, 22.19166756], [88.06388855, 22.19139099], [88.06388855, 22.19111061], [88.06445312, 22.19055939], [88.06472015, 22.19055939], [88.06555176, 22.18972015], [88.06583405, 22.18972206], [88.0661087, 22.18944359], [88.06639099, 22.18944359], [88.06666565, 22.18916702], [88.06749725, 22.18917274], [88.06804657, 22.18861008], [88.06916809, 22.18861008], [88.06944275, 22.18833351], [88.06972504, 22.18833351], [88.06999969, 22.18861008], [88.07055664, 22.18805504], [88.07110596, 22.18806267], [88.07138824, 22.18778038], [88.0716629, 22.18806267], [88.07221985, 22.18750191], [88.07250214, 22.18778038], [88.07305908, 22.18722153], [88.07416534, 22.18722153], [88.07444763, 22.18694496], [88.07501221, 22.18695259], [88.07527924, 22.1866703], [88.07554626, 22.1866703], [88.07583618, 22.18695259], [88.07666779, 22.18694496], [88.07694244, 22.18722153], [88.07722473, 22.18694496], [88.07775879, 22.18695259], [88.07804871, 22.1866703], [88.07917023, 22.1866703], [88.07943726, 22.18695259], [88.08166504, 22.18694496], [88.08194733, 22.18722153], [88.08222198, 22.18722153], [88.08249664, 22.18694496], [88.08333588, 22.18694496], [88.08361053, 22.18722153], [88.08388519, 22.18694496], [88.08555603, 22.18695259], [88.08583069, 22.1866703], [88.08611298, 22.1866703], [88.08666992, 22.18611145], [88.08694458, 22.18611145], [88.08721924, 22.18583298], [88.08750153, 22.18583298], [88.08777618, 22.18555641], [88.08833313, 22.18555641], [88.08860779, 22.18583298], [88.08889008, 22.18583298], [88.08916473, 22.18611145], [88.08944702, 22.18611145], [88.08972168, 22.18583298], [88.08999634, 22.18583298], [88.09027863, 22.18611145], [88.09055328, 22.18611145], [88.09111023, 22.1866703], [88.09111023, 22.18694496], [88.09139252, 22.18722153], [88.09139252, 22.18750191], [88.09166718, 22.18778038], [88.09166718, 22.18805504], [88.09194183, 22.18833351], [88.09194183, 22.18861008], [88.09305573, 22.18972206], [88.09333038, 22.18972015], [88.09361267, 22.19000053], [88.09388733, 22.19000053], [88.09416962, 22.19028091], [88.09443665, 22.19028091], [88.09471893, 22.19055939], [88.09555817, 22.19055557], [88.0956955, 22.19069481], [88.09583282, 22.19083214], [88.0966568, 22.19083023], [88.09694672, 22.19111061], [88.09777832, 22.19111061], [88.09805298, 22.19139099], [88.10028076, 22.19139099], [88.10056305, 22.19111061], [88.10083008, 22.19111061], [88.10111237, 22.19083023], [88.10138702, 22.19083023], [88.10166931, 22.19111061], [88.10138702, 22.19139099], [88.10166931, 22.19166946], [88.10194397, 22.19166756], [88.10221863, 22.19194412], [88.10277557, 22.19194412], [88.10277557, 22.19166756], [88.10305786, 22.19166946], [88.10333252, 22.19139099], [88.1049881, 22.19139099], [88.10527802, 22.19166946], [88.10610962, 22.19166946], [88.10639191, 22.19139099], [88.10721588, 22.19139099], [88.10749817, 22.19111061], [88.10806274, 22.19111061], [88.10832977, 22.19083214], [88.10916901, 22.19083214], [88.10944366, 22.19055557], [88.1102829, 22.19055939], [88.11083221, 22.19000053], [88.11138916, 22.19000053], [88.11165619, 22.18972015], [88.11333466, 22.18972206], [88.11416626, 22.18888855], [88.11444092, 22.18917274], [88.11472321, 22.18889046], [88.11528015, 22.18889046], [88.11554718, 22.18861008], [88.1166687, 22.18861008], [88.11694336, 22.18833351], [88.11916351, 22.18833351], [88.1194458, 22.18861008], [88.11972046, 22.18833351], [88.1202774, 22.18833351], [88.12055206, 22.18805504], [88.12110901, 22.18806267], [88.1213913, 22.18778038], [88.12194824, 22.18778038], [88.1222229, 22.18750191], [88.12306213, 22.18750191], [88.12333679, 22.18722153], [88.12388611, 22.18722153], [88.1241684, 22.18694496], [88.12473297, 22.18695259], [88.125, 22.1866703], [88.1258316, 22.1866703], [88.12609863, 22.18639946], [88.1277771, 22.18639946], [88.12805176, 22.18611145], [88.12889099, 22.18611145], [88.12916565, 22.18583298], [88.1305542, 22.18583298], [88.13083649, 22.18555641], [88.13388824, 22.18556023], [88.1341629, 22.18527985], [88.13445282, 22.18527985], [88.13471985, 22.18499756], [88.13500214, 22.18499756], [88.13529205, 22.18471909], [88.13555908, 22.1847229], [88.13861084, 22.18166542], [88.13861084, 22.18139076], [88.13889313, 22.18111038], [88.1388855, 22.18083382], [88.13916779, 22.18055534], [88.13916779, 22.18027115], [88.13944244, 22.18000031], [88.1397171, 22.18000031], [88.14026642, 22.17945099], [88.14026642, 22.17917061], [88.14167023, 22.17778015], [88.14167023, 22.17721176], [88.14194489, 22.17694473], [88.14194489, 22.17666626], [88.14221954, 22.17638969], [88.14221954, 22.17611122], [88.14250183, 22.17583275], [88.14250183, 22.17527771], [88.14277649, 22.17500114], [88.14277649, 22.17444038], [88.14305878, 22.17416573], [88.14305878, 22.17389107], [88.14332581, 22.17361069], [88.14332581, 22.1733284], [88.14389038, 22.17277718], [88.14389038, 22.17250061], [88.14417267, 22.17221832], [88.14416504, 22.17194366], [88.14444733, 22.1716671], [88.14444733, 22.17140007], [88.14472198, 22.17110825], [88.14472198, 22.17055511], [88.14554596, 22.1697197], [88.14555359, 22.16944695], [88.14583588, 22.16917038], [88.14583588, 22.16888809], [88.14611053, 22.16860962], [88.14611053, 22.1680584], [88.14639282, 22.16777992], [88.14639282, 22.16749954], [88.14694214, 22.1669445], [88.14694214, 22.16666412], [88.14833069, 22.16526985], [88.14833069, 22.16500092], [88.15194702, 22.1613903], [88.15194702, 22.16111183], [88.15222168, 22.16083336], [88.15222168, 22.16055489], [88.15249634, 22.16027832], [88.15249634, 22.15972137], [88.15277863, 22.15944481], [88.15277863, 22.15916634], [88.15303802, 22.15888977], [88.15303802, 22.15860748], [88.15777588, 22.1538887], [88.15777588, 22.15361023], [88.15833282, 22.15306091], [88.15833282, 22.15278053], [88.15888977, 22.15221977], [88.15888977, 22.15194321], [88.15972137, 22.1511097], [88.15972137, 22.15083313], [88.16249847, 22.14805603], [88.16278076, 22.14805984], [88.16722107, 22.14360809], [88.16750336, 22.14361191], [88.16805267, 22.14305496], [88.16832733, 22.14306068], [88.16860962, 22.14221954], [88.16860962, 22.14194679], [88.16889191, 22.14166641], [88.16889191, 22.14138985], [88.16999817, 22.14027977], [88.16999817, 22.13999939], [88.17082977, 22.13916969], [88.17082977, 22.13889122], [88.17111206, 22.13861084], [88.17111206, 22.13833046], [88.17138672, 22.1380558], [88.17140198, 22.13778114], [88.17166901, 22.13750076], [88.17166901, 22.13722038], [88.17388916, 22.13500023], [88.17388916, 22.13472176], [88.17416382, 22.13444519], [88.17414856, 22.13417053], [88.17446136, 22.13389015], [88.17446136, 22.13361168], [88.17722321, 22.13083267], [88.17722321, 22.13055611], [88.17888641, 22.12889099], [88.1791687, 22.12889099], [88.18083191, 22.12722015], [88.18083191, 22.12694359], [88.18333435, 22.12444305], [88.18334198, 22.1241703], [88.18360901, 22.12388992], [88.18360901, 22.12360954], [88.18416595, 22.12305641], [88.18416595, 22.12277985], [88.18554688, 22.12138939], [88.18554688, 22.12111282], [88.18611145, 22.12055969], [88.18611145, 22.12029076], [88.18805695, 22.11832809], [88.1883316, 22.11833382], [88.18888855, 22.11777878], [88.18914795, 22.11778069], [88.1911087, 22.11582947], [88.1911087, 22.11555481], [88.19166565, 22.11499977], [88.19166565, 22.1147213], [88.19194794, 22.11444473], [88.19194794, 22.11416435], [88.19333649, 22.11277771], [88.19333649, 22.11222076], [88.19361115, 22.1119442], [88.19361115, 22.11083221], [88.19333649, 22.11055565], [88.19333649, 22.10972023], [88.1930542, 22.10944366], [88.1930542, 22.10888863], [88.19249725, 22.10833168], [88.19249725, 22.10805511], [88.19220734, 22.10778046], [88.19220734, 22.10750008], [88.19194794, 22.1072216], [88.19194794, 22.10583305], [88.19139099, 22.10527992], [88.19139099, 22.10471916], [88.1911087, 22.1044445], [88.1911087, 22.10416794], [88.19055176, 22.10360909], [88.19055176, 22.10305977], [88.19000244, 22.10250092], [88.19000244, 22.10222054], [88.18972015, 22.10194397], [88.18972015, 22.10138893], [88.18943787, 22.10111046], [88.18943787, 22.10083008], [88.18916321, 22.10055542], [88.18914795, 22.10000038], [88.18888855, 22.09972], [88.18888855, 22.09916687], [88.18805695, 22.09832954], [88.18805695, 22.09805489], [88.18777466, 22.09777832], [88.18776703, 22.09749985], [88.1875, 22.09721947], [88.1875, 22.09694481], [88.18722534, 22.09666634], [88.18723297, 22.09638977], [88.18638611, 22.09555626], [88.18640137, 22.09527969], [88.18416595, 22.09277916], [88.18334198, 22.09166908], [88.18165588, 22.08971977], [88.18166351, 22.08944511], [88.18026733, 22.08805084], [88.18027496, 22.08777618], [88.17861176, 22.08611107], [88.17861176, 22.08583069], [88.17778015, 22.08499908], [88.17778015, 22.08472061], [88.17388916, 22.08083344], [88.17388916, 22.08055496], [88.17028046, 22.07694054], [88.17028046, 22.07666779], [88.16971588, 22.07611084], [88.16944122, 22.07611084], [88.16694641, 22.07361031], [88.16666412, 22.07361031], [88.16529846, 22.07224464], [88.16444397, 22.07138824], [88.16416931, 22.07139015], [88.16278076, 22.06999969], [88.16249847, 22.06999969], [88.16139221, 22.06888962], [88.16110992, 22.06888962], [88.16027832, 22.06806183], [88.15999603, 22.06806183], [88.15916443, 22.0672226], [88.15888977, 22.06694412], [88.15860748, 22.06666756], [88.15833282, 22.06666946], [88.15812683, 22.06646156], [88.15805054, 22.0664444], [88.15777588, 22.06638908], [88.15616608, 22.06477928], [88.15609741, 22.06475258], [88.15602875, 22.06472778], [88.15528107, 22.06444359], [88.15472412, 22.06444359], [88.15333557, 22.06305695], [88.15303802, 22.06306839], [88.15249634, 22.06249809], [88.15222168, 22.06249809], [88.15141296, 22.06168938], [88.15110779, 22.06138611], [88.15093994, 22.06138992], [88.15083313, 22.06138992], [88.15068817, 22.06124115], [88.15055847, 22.06111145], [88.15027618, 22.06111145], [88.14971924, 22.0605545], [88.14943695, 22.06056023], [88.14861298, 22.05972099], [88.14805603, 22.0597229], [88.14778137, 22.05944443], [88.14722443, 22.05944443], [88.14694214, 22.05916405], [88.14639282, 22.05916977], [88.14611053, 22.05888939], [88.14583588, 22.05888939], [88.14554596, 22.05861092], [88.14527893, 22.05861092], [88.14499664, 22.05833054], [88.14444733, 22.05833244], [88.14416504, 22.05805588], [88.14389038, 22.05805969], [88.14360809, 22.05778122], [88.14332581, 22.05778122], [88.14305878, 22.05750084], [88.14250183, 22.05750084], [88.14193726, 22.05694962], [88.14138794, 22.05694962], [88.14109802, 22.05667114], [88.14055634, 22.05667114], [88.14026642, 22.05639076], [88.13999939, 22.05639076], [88.1397171, 22.05611038], [88.13944244, 22.05611038], [88.13916779, 22.05583191], [88.1388855, 22.05583382], [88.13861084, 22.05555534], [88.13835144, 22.05556107], [88.13803864, 22.05528069], [88.13749695, 22.05528069], [88.13722229, 22.05500031], [88.13666534, 22.05500031], [88.1361084, 22.05444527], [88.13594818, 22.05444717], [88.13555908, 22.0544529], [88.13546753, 22.05435562], [88.13527679, 22.05416679], [88.13500214, 22.05417061], [88.13471985, 22.05388069], [88.13444519, 22.05388832], [88.1341629, 22.05361176], [88.13388824, 22.05361176], [88.1333313, 22.05305481], [88.13305664, 22.05305481], [88.13277435, 22.05277824], [88.13249969, 22.05278015], [88.13244629, 22.05272484], [88.13223267, 22.05250168], [88.13194275, 22.05250168], [88.1313858, 22.05194092], [88.13111115, 22.05194473], [88.13083649, 22.05166626], [88.13027954, 22.05166817], [88.12999725, 22.05138969], [88.1297226, 22.05138969], [88.12944794, 22.05111122], [88.12889099, 22.05111122], [88.12832642, 22.05055809], [88.12805176, 22.05055809], [88.1277771, 22.05027962], [88.12750244, 22.05027962], [88.12722015, 22.05000114], [88.12695313, 22.05000114], [88.12666321, 22.04972076], [88.12638855, 22.04972267], [88.12611389, 22.0494442], [88.12555695, 22.0494442], [88.125, 22.04888725], [88.12473297, 22.04889107], [88.1241684, 22.04833031], [88.12388611, 22.04833412], [88.12333679, 22.04777527], [88.12306213, 22.04778099], [88.12277985, 22.04750061], [88.12249756, 22.04750061], [88.12166595, 22.04667091], [88.12110901, 22.04667091], [88.12073517, 22.04629707], [88.12055206, 22.04611206], [88.1202774, 22.04611206], [88.11972046, 22.04555321], [88.1194458, 22.04556084], [88.11888885, 22.04500008], [88.11860657, 22.04500008], [88.11805725, 22.04445076], [88.11778259, 22.04445076], [88.11721802, 22.04389], [88.1166687, 22.04389], [88.11638641, 22.04360962], [88.11611176, 22.04361153], [88.11528015, 22.04277802], [88.11499786, 22.04277992], [88.11472321, 22.04249954], [88.11444092, 22.04249954], [88.11415863, 22.04222107], [88.1138916, 22.04222107], [88.11360931, 22.0419445], [88.11333466, 22.0419445], [88.11138916, 22.04000092], [88.1111145, 22.04000092], [88.11083221, 22.03972244], [88.11055756, 22.03972244], [88.10972595, 22.03889084], [88.10944366, 22.03889084], [88.10916901, 22.03861046], [88.10861206, 22.03861046], [88.10832977, 22.03832817], [88.10805511, 22.03833389], [88.10583496, 22.03611183], [88.10527802, 22.03611183], [88.10444641, 22.03527641], [88.10416412, 22.03555489], [88.10388947, 22.03527641], [88.10360718, 22.03528023], [88.10221863, 22.03388977], [88.10221863, 22.03333092], [88.10166931, 22.03277779], [88.10111237, 22.03277969], [88.10083008, 22.03306007], [88.10056305, 22.03306007], [88.10018921, 22.03268814], [88.09999847, 22.03249931], [88.09971619, 22.03250122], [88.0983429, 22.03111076], [88.09777832, 22.03111076], [88.09722137, 22.03055954], [88.0966568, 22.03055954], [88.09612274, 22.03000069], [88.09583282, 22.03000069], [88.09527588, 22.02944183], [88.09500122, 22.02944374], [88.09388733, 22.02833366], [88.09361267, 22.02833366], [88.09333038, 22.02805519], [88.0930481, 22.02806282], [88.09278107, 22.02778053], [88.09249878, 22.02778053], [88.09166718, 22.02693939], [88.09139252, 22.02694511], [88.09111023, 22.02666664], [88.0908432, 22.02667046], [88.09065247, 22.02648544], [88.09055328, 22.02639008], [88.09027863, 22.02639008], [88.08998871, 22.0261116], [88.08972168, 22.0261116], [88.08944702, 22.02583313], [88.08944702, 22.02555466], [88.08833313, 22.02444458], [88.08777618, 22.02444458], [88.08750153, 22.02416611], [88.08695221, 22.02416992], [88.08611298, 22.02333069], [88.08583069, 22.0233326], [88.08555603, 22.02305794], [88.08528137, 22.02305984], [88.08472443, 22.02250099], [88.08444214, 22.02222061], [88.08416748, 22.02222252], [88.08333588, 22.0213871], [88.08222198, 22.02139091], [88.08152008, 22.021101], [88.07943726, 22.02083969], [88.07888794, 22.02056122], [88.07861328, 22.02056122], [88.07804871, 22.02000046], [88.07775879, 22.02000046], [88.07749939, 22.01972008], [88.07722473, 22.01972198], [88.07666779, 22.01916695], [88.07639313, 22.01917076], [88.07611084, 22.01889038], [88.07527924, 22.01889038], [88.07501221, 22.01861], [88.07444763, 22.01861191], [88.07416534, 22.01833344], [88.0736084, 22.01833344], [88.07333374, 22.01805305], [88.07277679, 22.01806068], [88.07221985, 22.01749992], [88.07138824, 22.01721954], [88.07111359, 22.01694489], [88.07111359, 22.01666641], [88.06989288, 22.0154438], [88.06972504, 22.01527786], [88.06944275, 22.01527786], [88.06916809, 22.01499939], [88.06887817, 22.01499939], [88.06749725, 22.01499939], [88.0672226, 22.01527977], [88.06694794, 22.01527977], [88.06667328, 22.01499939], [88.06639099, 22.01499939], [88.0661087, 22.01471138], [88.06583405, 22.01472282], [88.06555176, 22.01444435], [88.0652771, 22.01444435], [88.06500244, 22.01416588], [88.06360626, 22.01416969], [88.0633316, 22.01389122], [88.0630722, 22.01389122], [88.06223297, 22.01305962], [88.06138611, 22.01389122], [88.06138611, 22.01416588], [88.06111145, 22.01444244], [88.06111145, 22.01499939], [88.06083679, 22.01527977], [88.0605545, 22.01527786], [88.05999756, 22.0158329], [88.0597229, 22.0158329], [88.05916595, 22.01638985], [88.0588913, 22.01638985], [88.05860901, 22.01666641], [88.05860901, 22.01694489], [88.05722046, 22.01833344], [88.0569458, 22.01861191], [88.05665588, 22.01861], [88.0541687, 22.02111053], [88.05388641, 22.02111053], [88.05305481, 22.02194405], [88.05278015, 22.02194405], [88.05249786, 22.02222252], [88.05194092, 22.02222061], [88.05027771, 22.02389908], [88.04972076, 22.02389908], [88.04471588, 22.02889061], [88.04444122, 22.0288887], [88.04389191, 22.02944374], [88.04360962, 22.02944183], [88.04277802, 22.03027725], [88.04111481, 22.03194427], [88.04083252, 22.03194427], [88.03944397, 22.03333282], [88.03943634, 22.03360939], [88.03887939, 22.03417015], [88.03861237, 22.03417015], [88.03778076, 22.03499985], [88.03778076, 22.03528023], [88.03722382, 22.03583336], [88.03722382, 22.03611183], [88.03444672, 22.03889084], [88.0341568, 22.03887749], [88.03388977, 22.0391674], [88.03388977, 22.03943825], [88.03333282, 22.04000092], [88.03333282, 22.04027939], [88.03221893, 22.04138947], [88.03221893, 22.04166603], [88.03194427, 22.0419445], [88.03193665, 22.04222107], [88.03111267, 22.04305649], [88.03111267, 22.04333115], [88.02999878, 22.04444313], [88.02999878, 22.0447197], [88.02970886, 22.04500008], [88.02972412, 22.04527855], [88.02916718, 22.04583359], [88.02889252, 22.04583359], [88.02861023, 22.04611206], [88.02833557, 22.04611206], [88.02807617, 22.04636955], [88.02749634, 22.04694366], [88.02749634, 22.04722023], [88.02693939, 22.04778099], [88.02693939, 22.04861069], [88.02722168, 22.04888725], [88.02722168, 22.04948044], [88.02722168, 22.04972076], [88.02749634, 22.05000114], [88.02749634, 22.05027962], [88.02777863, 22.05055809], [88.02777863, 22.05111122], [88.02805328, 22.05138969], [88.02805328, 22.05194473], [88.02833557, 22.0522213], [88.02833557, 22.05305481], [88.02861023, 22.05333328], [88.02861023, 22.05361176], [88.02916718, 22.05417061], [88.02916718, 22.0544529], [88.02970886, 22.05500031], [88.02999878, 22.05500031], [88.03028107, 22.05528069], [88.03056335, 22.05528069], [88.03067017, 22.05539513], [88.03083038, 22.05556107], [88.03138733, 22.05555534], [88.03166962, 22.05583382], [88.03193665, 22.05583191], [88.03360748, 22.05750084], [88.03360748, 22.05833054], [88.03388977, 22.05861092], [88.03388977, 22.05944443], [88.03360748, 22.0597229], [88.03360748, 22.06083298], [88.03333282, 22.06110954], [88.03333282, 22.06138992], [88.03277588, 22.06194687], [88.03277588, 22.06221962], [88.03250122, 22.06249809], [88.03250122, 22.06278038], [88.03221893, 22.06305695], [88.03221893, 22.06333351], [88.03193665, 22.06360817], [88.03194427, 22.06388664], [88.02999878, 22.06582069], [88.02999878, 22.06611061], [88.02944183, 22.06666756], [88.02944183, 22.06694412], [88.02805328, 22.06833267], [88.02777863, 22.06833267], [88.02749634, 22.06861115], [88.02722168, 22.06861115], [88.02693939, 22.06888962], [88.02664948, 22.06888962], [88.02527618, 22.07028008], [88.02500153, 22.07028008], [88.02361298, 22.07167053], [88.02361298, 22.07195091], [88.02278137, 22.07278061], [88.02249908, 22.0727787], [88.02194214, 22.07333374], [88.02166748, 22.07332993], [88.02083588, 22.07417107], [88.02027893, 22.07416534], [88.01750183, 22.07694435], [88.01750183, 22.07722092], [88.01693726, 22.07777977], [88.01667023, 22.07777977], [88.01555634, 22.07889175], [88.01526642, 22.07889175], [88.01499939, 22.07917023], [88.01472473, 22.07916641], [88.01389313, 22.08000183], [88.01361084, 22.08000183], [88.01333618, 22.0802803], [88.01304626, 22.0802803], [88.01277924, 22.08056259], [88.01249695, 22.08056259], [88.01167297, 22.08139038], [88.01139069, 22.08139038], [88.01027679, 22.08250046], [88.01000214, 22.08250046], [88.00889587, 22.08361053], [88.00860596, 22.08361053], [88.0083313, 22.08389091], [88.00805664, 22.08389091], [88.00776672, 22.08418083], [88.00749969, 22.08416748], [88.00722504, 22.08444214], [88.00666809, 22.08444214], [88.0063858, 22.08472252], [88.00611115, 22.08472061], [88.00553894, 22.08527946], [88.00527954, 22.08527946], [88.00444794, 22.08611107], [88.00417328, 22.08611107], [88.00389099, 22.08638954], [88.0036087, 22.08638954], [88.0027771, 22.08722305], [88.00250244, 22.08722115], [88.00222015, 22.08749962], [88.00195313, 22.08749962], [88.00166321, 22.08778], [88.00138855, 22.08777618], [88.00111389, 22.08805466], [88.0008316, 22.08805466], [88.0, 22.0886097], [87.99962616, 22.08883858], [87.99929047, 22.08941078], [87.99888611, 22.08947182], [87.99842834, 22.089571], [87.9980545, 22.08999825], [87.99695587, 22.09110832], [87.99694824, 22.09139061], [87.9963913, 22.09194374], [87.9963913, 22.0922184], [87.99610901, 22.09250069], [87.99610901, 22.09277725], [87.99582672, 22.0930481], [87.99582672, 22.09361076], [87.99555206, 22.09389114], [87.99555206, 22.0941658], [87.9952774, 22.09444237], [87.9952774, 22.09555626], [87.99500275, 22.09583282], [87.99500275, 22.09638977], [87.99472046, 22.09666634], [87.99472046, 22.09722137], [87.9944458, 22.09860992], [87.9944458, 22.09945107], [87.99388885, 22.10056114], [87.99194336, 22.10250092], [87.99111176, 22.10305977], [87.98999786, 22.10360909], [87.98916626, 22.10388947], [87.9851532, 22.10474014], [87.98448181, 22.10471916], [87.9839325, 22.10466957], [87.9835434, 22.10449982], [87.98319244, 22.10444832], [87.98288727, 22.10444641], [87.98261261, 22.10441971], [87.98216248, 22.10451126], [87.98165894, 22.10448074], [87.98120117, 22.10441971], [87.98078918, 22.10443878], [87.98034668, 22.10445023], [87.97986603, 22.10449028], [87.97939301, 22.10461998], [87.97895813, 22.10484886], [87.9785614, 22.10487175], [87.97815704, 22.10477257], [87.97776031, 22.10474205], [87.97734833, 22.10473061], [87.97692871, 22.10473061], [87.97651672, 22.10474014], [87.97615051, 22.10476112], [87.97590637, 22.10473061], [87.97583008, 22.10471916], [87.97499847, 22.10472298], [87.97472382, 22.10499763], [87.97416687, 22.10499763], [87.97389221, 22.10472298], [87.97333527, 22.10472298], [87.97305298, 22.1044445], [87.97138977, 22.1044445], [87.97110748, 22.10416794], [87.96639252, 22.10416985], [87.96389008, 22.10360909], [87.96375275, 22.10371971], [87.96335602, 22.10347748], [87.96305847, 22.10320091], [87.96277618, 22.10289001], [87.96250153, 22.10257149], [87.96225739, 22.10222626], [87.96208954, 22.10184669], [87.96182251, 22.10152054], [87.96154022, 22.10115051], [87.96120453, 22.10083389], [87.95944977, 22.09968948], [87.95932007, 22.09784317], [87.95960999, 22.09691048], [87.96037292, 22.09555054], [87.96069336, 22.09542274], [87.96260071, 22.09500122], [87.96304321, 22.09494019], [87.96346283, 22.09477234], [87.96392822, 22.0947094], [87.9644165, 22.09460068], [87.9649353, 22.09444237], [87.96704865, 22.0943985], [87.96749115, 22.09444237], [87.96788788, 22.0944519], [87.96826172, 22.0944519], [87.96869659, 22.09444237], [87.96922302, 22.09439087], [87.96983337, 22.0943203], [87.97045898, 22.09445953], [87.97107697, 22.09469986], [87.97170258, 22.09493256], [87.9723053, 22.0950985], [87.9728775, 22.0952301], [87.97344208, 22.09530067], [87.97399902, 22.09537506], [87.97451019, 22.09552002], [87.97502136, 22.09562111], [87.97541046, 22.09583282], [87.97580719, 22.09598351], [87.97622681, 22.09615135], [87.97666931, 22.0963726], [87.97715759, 22.09658241], [87.97767639, 22.09685135], [87.97823334, 22.09716988], [87.97872925, 22.09745979], [87.97911072, 22.09776688], [87.97955322, 22.09799004], [87.97992706, 22.09827042], [87.98034668, 22.09840012], [87.9807663, 22.0985508], [87.98114777, 22.0986805], [87.98146057, 22.0988102], [87.98174286, 22.09875107], [87.98193359, 22.09851074], [87.98210907, 22.09818268], [87.98230743, 22.09787178], [87.98253632, 22.0976181], [87.98271942, 22.09736061], [87.98249817, 22.09721947], [87.98278046, 22.09694481], [87.98278046, 22.09666634], [87.98306274, 22.09638977], [87.98305511, 22.0961113], [87.98332977, 22.09583282], [87.98332977, 22.09555626], [87.98388672, 22.09500122], [87.98388672, 22.09472275], [87.98444366, 22.0941658], [87.98443604, 22.09389114], [87.98500061, 22.09332848], [87.98500061, 22.09305573], [87.98638916, 22.09166718], [87.98638916, 22.09139061], [87.98860931, 22.08917046], [87.98860931, 22.08889008], [87.98972321, 22.08778], [87.99017334, 22.0873394], [87.99062347, 22.0869236], [87.99107361, 22.08666039], [87.99150848, 22.08638954], [87.9919281, 22.08608246], [87.99226379, 22.08568192], [87.99263, 22.08531952], [87.99301147, 22.0850296], [87.99333954, 22.08471107], [87.99365234, 22.08440971], [87.99397278, 22.08409119], [87.99430847, 22.08377457], [87.99473572, 22.08348274], [87.995224, 22.08317375], [87.99571228, 22.08281708], [87.99621582, 22.08250999], [87.9963913, 22.08250046], [87.99973297, 22.07917023], [88.0, 22.07917023], [88.00138855, 22.07777977], [88.00166321, 22.07777977], [88.00195313, 22.07749748], [88.00222015, 22.07749748], [88.00389099, 22.07583046], [88.00416565, 22.07583427], [88.00444794, 22.07555771], [88.0047226, 22.07555962], [88.00499725, 22.07528114], [88.00527954, 22.07528114], [88.00553894, 22.0750103], [88.00582886, 22.0750103], [88.00611115, 22.07472038], [88.0063858, 22.07472229], [88.00694275, 22.07416534], [88.00723267, 22.07417107], [88.00776672, 22.07361031], [88.00805664, 22.07361031], [88.00860596, 22.07306099], [88.00860596, 22.07278061], [88.01019287, 22.07119751], [88.0111084, 22.07027817], [88.01196289, 22.06806183], [88.01196289, 22.06750107], [88.01222229, 22.0672226], [88.01222229, 22.06694412], [88.01277924, 22.06638908], [88.01277924, 22.06611061], [88.01304626, 22.06582069], [88.01305389, 22.06555557], [88.01333618, 22.06528091], [88.01333618, 22.06471825], [88.01361084, 22.06444359], [88.01361084, 22.0616684], [88.01389313, 22.06138992], [88.01389313, 22.06056023], [88.01416779, 22.06027985], [88.01416779, 22.06001091], [88.01444244, 22.05750084], [88.01470947, 22.05722046], [88.01472473, 22.05638885], [88.01499939, 22.05611038], [88.01499939, 22.05583191], [88.01527405, 22.05555534], [88.01526642, 22.05500031], [88.01555634, 22.05472183], [88.01555634, 22.05333328], [88.01583099, 22.05305481], [88.01583099, 22.05250168], [88.01721954, 22.05111122], [88.01721954, 22.04944038], [88.01694489, 22.04916573], [88.01693726, 22.04889107], [88.01667023, 22.04861069], [88.01667023, 22.04833031], [88.01638794, 22.04805756], [88.01638794, 22.04684258], [88.01638794, 22.0447216], [88.01667023, 22.04444313], [88.01667023, 22.04277992], [88.01693726, 22.04249954], [88.01693726, 22.0419426], [88.01721954, 22.04166603], [88.01721954, 22.04138947], [88.01750183, 22.0411129], [88.01750183, 22.04083252], [88.01777649, 22.04055595], [88.01776886, 22.04027939], [88.01832581, 22.03971863], [88.01860809, 22.03972244], [88.01916504, 22.0391655], [88.02083588, 22.03750038], [88.02083588, 22.03721809], [88.02166748, 22.03638649], [88.02194214, 22.0363903], [88.02278137, 22.03555107], [88.02278137, 22.03527641], [88.02471924, 22.03333092], [88.02471924, 22.03277779], [88.02500153, 22.03250122], [88.02500153, 22.03222084], [88.02527618, 22.03194427], [88.02555847, 22.03194427], [88.03250122, 22.02499962], [88.03277588, 22.02499962], [88.03360748, 22.02416992], [88.0341568, 22.02416992], [88.03444672, 22.02389908], [88.03472137, 22.02389908], [88.03499603, 22.02361107], [88.03555298, 22.02361107], [88.03610992, 22.02305984], [88.03639221, 22.02305984], [88.03694153, 22.02250099], [88.03721619, 22.02250099], [88.03833008, 22.02139091], [88.03887939, 22.02139091], [88.03916931, 22.02111053], [88.03943634, 22.02111053], [88.03971863, 22.02083969], [88.0402832, 22.02083969], [88.04055786, 22.02056122], [88.04110718, 22.02056122], [88.04164886, 22.02000046], [88.04193878, 22.02000046], [88.04250336, 22.0194397], [88.04277802, 22.01944351], [88.04305267, 22.01916695], [88.04334259, 22.01917076], [88.04360962, 22.01889038], [88.04389191, 22.01889038], [88.04416656, 22.01861], [88.04472351, 22.01861191], [88.04499817, 22.01833344], [88.04555511, 22.01833344], [88.04582977, 22.01805305], [88.04611206, 22.01806068], [88.04638672, 22.01777077], [88.04666901, 22.0177784], [88.04694366, 22.01749992], [88.04722595, 22.01749992], [88.04750061, 22.01721954], [88.04777527, 22.01722145], [88.04833221, 22.01666641], [88.04860687, 22.01667023], [88.04915619, 22.01610947], [88.04972076, 22.01611137], [88.05000305, 22.0158329], [88.05055237, 22.0158329], [88.05083466, 22.01555634], [88.05110931, 22.01556015], [88.05166626, 22.01499939], [88.05194092, 22.01499939], [88.05222321, 22.01471138], [88.05222321, 22.01444435], [88.05249786, 22.01416588], [88.05249786, 22.01361275], [88.05278015, 22.01332855], [88.05278015, 22.0111084], [88.05304718, 22.01082993], [88.05305481, 22.0102787], [88.05278015, 22.01000023], [88.05278015, 22.00945091], [88.05249786, 22.00917053], [88.05249786, 22.00860977], [88.05222321, 22.00833321], [88.05222321, 22.00749969], [88.05194092, 22.00722122], [88.05194092, 22.00694656], [88.05110931, 22.00611115], [88.05110931, 22.00583076], [88.05083466, 22.00583267], [88.0486145, 22.00361061], [88.04860687, 22.00333023], [88.04750061, 22.00222206], [88.04750061, 22.00194359], [88.04722595, 22.00166702], [88.04722595, 22.00139046], [88.0460968, 22.00026894], [88.04582977, 22.00000191], [88.04556274, 21.99945259], [88.04556274, 21.99889183], [88.04528046, 21.99860764], [88.04528046, 21.99833298], [88.04499817, 21.99805641], [88.04499817, 21.99777985], [88.04471588, 21.99749756], [88.04471588, 21.99694061], [88.04444122, 21.99666786], [88.04444122, 21.99611092], [88.04416656, 21.99583054], [88.04416656, 21.99555779], [88.04389191, 21.99528122], [88.04389191, 21.99500084], [88.04360962, 21.99472046], [88.04360962, 21.99444389], [88.04333496, 21.99416542], [88.04334259, 21.99389076], [88.04277802, 21.99333], [88.04277802, 21.99277687], [88.04250336, 21.99250031], [88.04250336, 21.99195099], [88.04164886, 21.99110985], [88.04166412, 21.99055481], [88.04111481, 21.98999977], [88.04110718, 21.98971939], [88.04083252, 21.98944473], [88.04083252, 21.98916626], [88.04055786, 21.98888969], [88.04055786, 21.98861122], [88.0402832, 21.98833275], [88.04027557, 21.98805618], [88.04000092, 21.9880619], [88.03944397, 21.98750114], [88.03916931, 21.98722267], [88.03916931, 21.98638916], [88.03887939, 21.98611069], [88.03887939, 21.9858284], [88.03833008, 21.98527718], [88.03833008, 21.98500061], [88.03778076, 21.98443985], [88.03778076, 21.9841671], [88.03749847, 21.98417091], [88.03749847, 21.98389053], [88.03694153, 21.98332977], [88.03694153, 21.98305511], [88.03666687, 21.98278046], [88.03666687, 21.98249817], [88.03639221, 21.9822197], [88.03639221, 21.98194695], [88.0358429, 21.98139], [88.0358429, 21.98083115], [88.03610992, 21.98055458], [88.03610992, 21.98027992], [88.0358429, 21.97999954], [88.03583527, 21.9794445], [88.03555298, 21.97916412], [88.03530121, 21.97875977], [88.03514099, 21.97846985], [88.03501129, 21.97820663], [88.03490448, 21.97790146], [88.03482056, 21.9775486], [88.03486633, 21.97707939], [88.03488159, 21.97661209], [88.03469086, 21.97629738], [88.03440094, 21.97606087], [88.0341568, 21.97585106], [88.03392792, 21.97558975], [88.03385925, 21.97527122], [88.03370667, 21.97495079], [88.03360748, 21.97454071], [88.0335083, 21.97404289], [88.03340149, 21.97348022], [88.03317261, 21.97293472], [88.03285217, 21.97244263], [88.03256989, 21.97192955], [88.03240967, 21.9713192], [88.03224182, 21.9707489], [88.03209686, 21.97018051], [88.03190613, 21.96965981], [88.03165436, 21.96918869], [88.03138733, 21.96874809], [88.03111267, 21.96836662], [88.03111267, 21.96778107], [88.02999878, 21.96665955], [88.02999878, 21.96611023], [88.02970886, 21.96611023], [88.02970886, 21.96582985], [88.02944183, 21.96555328], [88.02944183, 21.96528053], [88.02916718, 21.96500015], [88.02916718, 21.96471977], [88.02889252, 21.96444321], [88.02889252, 21.96417046], [88.02916718, 21.96389008], [88.02805328, 21.96278], [88.02805328, 21.96222115], [88.02722168, 21.96138954], [88.02722168, 21.96111107], [88.02693939, 21.9608326], [88.02694702, 21.96027756], [88.02664948, 21.95999908], [88.02664948, 21.95972061], [88.02694702, 21.95944405], [88.02694702, 21.95916748], [88.02610779, 21.95832825], [88.02583313, 21.95833397], [88.02555847, 21.9580555], [88.02555847, 21.95778084], [88.02500153, 21.95721817], [88.02500153, 21.95666885], [88.02471924, 21.95639038], [88.02471924, 21.95582962], [88.02444458, 21.95555687], [88.02443695, 21.9552803], [88.02416992, 21.95499992], [88.02443695, 21.95471954], [88.02444458, 21.95388794], [88.02305603, 21.95249939], [88.02305603, 21.95222092], [88.02249908, 21.95166588], [88.02249908, 21.95139122], [88.0222168, 21.95111084], [88.0222168, 21.95083046], [88.02194214, 21.9505558], [88.02194214, 21.95028114], [88.02139282, 21.94972038], [88.02138519, 21.94861031], [88.02111053, 21.94833183], [88.02111053, 21.9477787], [88.02027893, 21.94695282], [88.02027893, 21.94639015], [88.01999664, 21.94611168], [88.01999664, 21.94583321], [88.02027893, 21.94555473], [88.02027893, 21.94499969], [88.01999664, 21.94472122], [88.01999664, 21.94416618], [88.01917267, 21.94333076], [88.01916504, 21.94277954], [88.01889038, 21.94248962], [88.01889038, 21.9422226], [88.01860809, 21.94194412], [88.01860809, 21.94166565], [88.01776886, 21.94083023], [88.01777649, 21.94055748], [88.01750183, 21.94028091], [88.01750183, 21.94000053], [88.01721954, 21.93972015], [88.01721954, 21.93916512], [88.01693726, 21.93889046], [88.01693726, 21.93861008], [88.01667023, 21.93833351], [88.01667023, 21.93805313], [88.01638794, 21.93778038], [88.01638794, 21.9375], [88.01609802, 21.93707275], [88.01583862, 21.93669891], [88.01560211, 21.93630028], [88.01542664, 21.93582153], [88.01534271, 21.93527985], [88.01537323, 21.93465042], [88.01537323, 21.93403053], [88.0151062, 21.93357086], [88.01483917, 21.93315315], [88.01468658, 21.93271255], [88.01464844, 21.93218994], [88.01441956, 21.93169975], [88.0140686, 21.93126106], [88.01378632, 21.93082428], [88.01358795, 21.93037605], [88.01344299, 21.92992973], [88.01325226, 21.92952919], [88.01302338, 21.9291935], [88.01278687, 21.92883682], [88.0125885, 21.92844963], [88.01246643, 21.92801666], [88.01229095, 21.92761993], [88.01216888, 21.92717934], [88.0120163, 21.92675018], [88.01190186, 21.92625999], [88.01174164, 21.9257412], [88.01167297, 21.92556], [88.01167297, 21.92500114], [88.01140594, 21.92423058], [88.01139069, 21.92361069], [88.01139069, 21.92333031], [88.01083374, 21.92277718], [88.01082611, 21.92194176], [88.01055908, 21.9216671], [88.01055908, 21.92121124], [88.01055908, 21.92055511], [88.01082611, 21.92028046], [88.01082611, 21.9197216], [88.01055908, 21.91944504], [88.01055908, 21.91860771], [88.01027679, 21.91833305], [88.01027679, 21.91805649], [88.01000214, 21.91777992], [88.01000214, 21.91749954], [88.00971985, 21.91721916], [88.00971985, 21.9169445], [88.00888824, 21.91611099], [88.00860596, 21.91611099], [88.0083847, 21.9158287], [88.0083313, 21.91500092], [88.00805664, 21.91472054], [88.00805664, 21.91444588], [88.00777435, 21.9141655], [88.00776672, 21.91306114], [88.00749969, 21.91278076], [88.00749969, 21.9113903], [88.0063858, 21.91028023], [88.0063858, 21.90999985], [88.00611115, 21.90971947], [88.00611115, 21.90944481], [88.00582886, 21.90917015], [88.00582886, 21.90888977], [88.0047226, 21.90777969], [88.0047226, 21.90750122], [88.00444794, 21.90722275], [88.00416565, 21.90722275], [88.00376892, 21.90682411], [88.0036087, 21.9066658], [88.0036087, 21.90582848], [88.00333405, 21.90555573], [88.00332642, 21.9047184], [88.0036087, 21.90444374], [88.0036087, 21.90389061], [88.00195313, 21.90221977], [88.0019455, 21.90166855], [88.00099182, 21.90034103], [88.00041962, 21.89923096], [88.00035095, 21.89908981], [88.00026703, 21.89902115], [88.0, 21.89861107], [87.9991684, 21.89777946], [87.9991684, 21.89751053], [87.99888611, 21.89722061], [87.99888611, 21.89694214], [87.99861145, 21.89666748], [87.99861145, 21.89611053], [87.99804688, 21.89556122], [87.99804688, 21.89528275], [87.99777985, 21.89500046], [87.99777985, 21.89472008], [87.9972229, 21.89416695], [87.9972229, 21.89389038], [87.99666595, 21.89333153], [87.99666595, 21.89305496], [87.99600983, 21.89239693], [87.99583435, 21.89222145], [87.99568176, 21.89179039], [87.99546814, 21.89137077], [87.99526978, 21.89093018], [87.99507141, 21.89048958], [87.99491882, 21.89003372], [87.99475861, 21.88966942], [87.99462891, 21.88939095], [87.99446869, 21.88911057], [87.99430847, 21.88876915], [87.99414825, 21.88831329], [87.993927, 21.88779068], [87.99371338, 21.8871994], [87.99333191, 21.88666534], [87.99250031, 21.88582993], [87.99250031, 21.88555336], [87.99194336, 21.88500023], [87.99194336, 21.88471985], [87.9916687, 21.88444328], [87.9916687, 21.88417053], [87.99138641, 21.88389015], [87.99138641, 21.88332939], [87.99111176, 21.88305473], [87.9908371, 21.88277817], [87.99082947, 21.88221169], [87.99028015, 21.88166618], [87.99028015, 21.88138962], [87.99005127, 21.88078117], [87.98987579, 21.88023949], [87.98973083, 21.87979317], [87.98944092, 21.87944412], [87.98916626, 21.87944412], [87.9888916, 21.87916756], [87.9888916, 21.87888908], [87.98828125, 21.87804985], [87.98805237, 21.87750053], [87.98805237, 21.87667084], [87.98779297, 21.87639809], [87.98779297, 21.87610817], [87.98750305, 21.87583351], [87.98744965, 21.87553406], [87.98722839, 21.87516022], [87.98698425, 21.87476921], [87.98670959, 21.87436104], [87.98645782, 21.87385941], [87.98628998, 21.87336159], [87.98607635, 21.87298965], [87.98591614, 21.87272835], [87.98581696, 21.87251091], [87.98575592, 21.87223053], [87.98564148, 21.8718605], [87.98544312, 21.87137222], [87.98526764, 21.87082291], [87.98500061, 21.87026787], [87.98470306, 21.86970139], [87.98439026, 21.86911964], [87.98416901, 21.86861038], [87.98416901, 21.86833191], [87.98361206, 21.86777687], [87.98361206, 21.86750031], [87.98293304, 21.86639023], [87.98285675, 21.86603928], [87.98272705, 21.86576653], [87.98264313, 21.86554909], [87.98249817, 21.86444473], [87.98209381, 21.86374474], [87.98195648, 21.86305618], [87.98194122, 21.86277962], [87.98194122, 21.86250114], [87.98139191, 21.86194038], [87.98139191, 21.86166763], [87.98110962, 21.8614006], [87.98110962, 21.86111069], [87.98084259, 21.86083031], [87.98083496, 21.85972214], [87.98055267, 21.85944366], [87.98055267, 21.85916519], [87.98027802, 21.85889053], [87.98055267, 21.85861015], [87.98055267, 21.85833359], [87.98047638, 21.85825729], [87.98027802, 21.85805321], [87.98027802, 21.85778046], [87.97915649, 21.85667038], [87.97915649, 21.85610962], [87.97861481, 21.85555649], [87.97833252, 21.8555603], [87.97750092, 21.85472107], [87.97750092, 21.85416603], [87.97721863, 21.85388947], [87.97721863, 21.8536129], [87.97693634, 21.8533287], [87.97694397, 21.85277748], [87.97638702, 21.85220909], [87.97638702, 21.85194397], [87.97611237, 21.8516674], [87.97611237, 21.85111046], [87.97528076, 21.85028076], [87.97499847, 21.85028076], [87.97472382, 21.85055542], [87.97471619, 21.85082817], [87.97444153, 21.85111046], [87.97444153, 21.85139084], [87.97389221, 21.85194397], [87.97360992, 21.85194397], [87.97305298, 21.85139084], [87.97186279, 21.85057259], [87.97100067, 21.84976768], [87.97071838, 21.84943008], [87.9706192, 21.84897232], [87.96949005, 21.84830475], [87.96920776, 21.84770012], [87.96835327, 21.84710121], [87.96755981, 21.84609032], [87.96705627, 21.84562111], [87.96669769, 21.84514046], [87.96598053, 21.84433746], [87.96533966, 21.84353065], [87.96425629, 21.84246826], [87.96296692, 21.84151077], [87.96247101, 21.84070587], [87.96161652, 21.84003067], [87.96068573, 21.83916092], [87.95982361, 21.83821869], [87.95903778, 21.83755112], [87.95810699, 21.83694077], [87.95802307, 21.83658028], [87.95746613, 21.83628273], [87.95722198, 21.83583069], [87.95619202, 21.83527565], [87.95575714, 21.83480072], [87.95483398, 21.83393288], [87.95401001, 21.83309174], [87.95358276, 21.83269119], [87.95307922, 21.83222008], [87.9524231, 21.83188057], [87.95213318, 21.83163071], [87.95194244, 21.8313961], [87.9513855, 21.83111191], [87.95111084, 21.83097649], [87.95014191, 21.82999992], [87.94999695, 21.82944107], [87.94942474, 21.82902527], [87.94911194, 21.82884026], [87.94882202, 21.82860184], [87.94851685, 21.8283329], [87.94816589, 21.82806015], [87.94780731, 21.82780075], [87.94745636, 21.82749939], [87.9471283, 21.82721138], [87.94683838, 21.82692909], [87.9466629, 21.82666969], [87.94416809, 21.82416916], [87.94416809, 21.82389069], [87.9438858, 21.82361031], [87.9438858, 21.82332993], [87.9430542, 21.82250023], [87.94304657, 21.82222748], [87.9422226, 21.82139015], [87.94194794, 21.82139015], [87.94167328, 21.82110977], [87.94139099, 21.82111168], [87.9411087, 21.82083321], [87.94083405, 21.82083321], [87.94055176, 21.82055664], [87.9402771, 21.82055664], [87.93972015, 21.81999969], [87.93972015, 21.81944084], [87.9394455, 21.81916428], [87.9394455, 21.8180542], [87.93888855, 21.81750107], [87.93860626, 21.81750107], [87.93805695, 21.81694031], [87.93777466, 21.81694221], [87.9375, 21.81666756], [87.93723297, 21.81666946], [87.93667603, 21.81610107], [87.9366684, 21.81583214], [87.93638611, 21.81555557], [87.93638611, 21.81528282], [87.93527985, 21.81417274], [87.93527985, 21.81306267], [87.93499756, 21.81278038], [87.93499756, 21.81250191], [87.93444824, 21.81195259], [87.93444824, 21.8116703], [87.93361664, 21.81082916], [87.93360901, 21.81055641], [87.93332672, 21.81028938], [87.93332672, 21.80999947], [87.9327774, 21.80940056], [87.9327774, 21.80805779], [87.9319458, 21.80722046], [87.9319458, 21.80666542], [87.93138885, 21.80611038], [87.93138885, 21.80528069], [87.93110657, 21.80500031], [87.93110657, 21.80445099], [87.93000031, 21.80332947], [87.93000031, 21.80277824], [87.92973328, 21.80249977], [87.92972565, 21.8022213], [87.92944336, 21.80194473], [87.92944336, 21.80111122], [87.9291687, 21.80083275], [87.9291687, 21.80055618], [87.92888641, 21.80027962], [87.92861176, 21.80027962], [87.9283371, 21.80000114], [87.92804718, 21.80000114], [87.92778015, 21.79972076], [87.92749023, 21.79972076], [87.92722321, 21.80000114], [87.92694092, 21.80000114], [87.92624664, 21.80042267], [87.92610931, 21.8005619], [87.92527771, 21.80138969], [87.92506409, 21.80166626], [87.9246521, 21.80215454], [87.92416382, 21.8022213], [87.92388916, 21.80194473], [87.9236145, 21.80194473], [87.92333221, 21.80166626], [87.92305756, 21.80166626], [87.92250061, 21.8022213], [87.92194366, 21.8022213], [87.92166901, 21.80194473], [87.92166901, 21.80166626], [87.92048645, 21.80034065], [87.92028046, 21.80020142], [87.91972351, 21.79999924], [87.91916656, 21.79943848], [87.91860962, 21.7994442], [87.91833496, 21.79916573], [87.91805267, 21.79916954], [87.91777802, 21.79888916], [87.91750336, 21.79888916], [87.91722107, 21.79861069], [87.91665649, 21.79861069], [87.91638947, 21.7983284], [87.91583252, 21.79833412], [87.91555786, 21.79805565], [87.91500092, 21.79805946], [87.91471863, 21.79777908], [87.91416931, 21.79777908], [87.91388702, 21.79750061], [87.91361237, 21.79750061], [87.91306305, 21.79693985], [87.91139221, 21.79694366], [87.91110992, 21.7966671], [87.91062927, 21.7966671], [87.90999603, 21.79667091], [87.90972137, 21.79639053], [87.9091568, 21.79639053], [87.90888977, 21.79610825], [87.90666962, 21.79611206], [87.90611267, 21.79609489], [87.90583038, 21.79609489], [87.90555573, 21.79608345], [87.90472412, 21.79611206], [87.90415192, 21.79565048], [87.90333557, 21.79499054], [87.90277863, 21.7947216], [87.90249634, 21.79444695], [87.90110779, 21.79445076], [87.90083313, 21.79444122], [87.90055847, 21.79443741], [87.90000153, 21.7947216], [87.89971924, 21.7947216], [87.89944458, 21.79500008], [87.89888763, 21.79500008], [87.89861298, 21.7947216], [87.89833069, 21.7947216], [87.89777374, 21.79416466], [87.89666748, 21.79305458], [87.8972168, 21.79249954], [87.89750671, 21.79249954], [87.89888763, 21.79111099], [87.89888763, 21.79083061], [87.89916992, 21.79055405], [87.89916992, 21.79027939], [87.89943695, 21.79000092], [87.89916992, 21.78972054], [87.89944458, 21.78944206], [87.89916992, 21.7891674], [87.89861298, 21.7891674], [87.89833069, 21.78944206], [87.89805603, 21.78944206], [87.89778137, 21.78972244], [87.89750671, 21.78972054], [87.8972168, 21.79000092], [87.89666748, 21.79000092], [87.89639282, 21.79027939], [87.89611053, 21.79027939], [87.89583588, 21.79055977], [87.89554596, 21.79055977], [87.89499664, 21.79111099], [87.89472198, 21.79111099], [87.89444733, 21.79138947], [87.89416504, 21.79138947], [87.89360809, 21.79194641], [87.89333344, 21.79194641], [87.89305878, 21.79222488], [87.89277649, 21.79222107], [87.89250183, 21.79249954], [87.89221954, 21.79249954], [87.89193726, 21.79277992], [87.89138031, 21.79277992], [87.89111328, 21.7930603], [87.89083099, 21.79305458], [87.89055634, 21.79333305], [87.8898468, 21.79353523], [87.88916016, 21.79297066], [87.88902283, 21.79276085], [87.88867188, 21.79235649], [87.88833618, 21.79166985], [87.88804626, 21.79117012], [87.88861084, 21.79055977], [87.88902283, 21.7904911], [87.8897171, 21.79000092], [87.8898468, 21.78993034], [87.89026642, 21.78924179], [87.89019775, 21.7891674], [87.89061737, 21.7888298], [87.89080048, 21.78835106], [87.89131927, 21.78799057], [87.89193726, 21.78750038], [87.89221954, 21.78750038], [87.89250183, 21.78722191], [87.89292145, 21.78701973], [87.89311981, 21.78652954], [87.89333344, 21.78611183], [87.8944397, 21.78499985], [87.8944397, 21.78471756], [87.89472198, 21.78444481], [87.89472198, 21.78388977], [87.8944397, 21.78360748], [87.89444733, 21.78305626], [87.89305878, 21.78166771], [87.89305878, 21.78083038], [87.89277649, 21.78055763], [87.89277649, 21.77999115], [87.89194489, 21.77916527], [87.89167023, 21.77917099], [87.89125061, 21.77875137], [87.89083099, 21.77832985], [87.89055634, 21.77833557], [87.89027405, 21.77805328], [87.88999939, 21.77806091], [87.8897171, 21.77778053], [87.88833618, 21.77778053], [87.88804626, 21.77806091], [87.88777924, 21.77806091], [87.88694763, 21.77721977], [87.88694763, 21.77694321], [87.88582611, 21.77583122], [87.88555908, 21.77583122], [87.88527679, 21.77555466], [87.88465118, 21.7754879], [87.88388824, 21.77472115], [87.88388824, 21.77361107], [87.8833313, 21.77306175], [87.8833313, 21.77277946], [87.88223267, 21.77166939], [87.88223267, 21.77082825], [87.88166809, 21.77027893], [87.88166809, 21.77000046], [87.8813858, 21.76971817], [87.88083649, 21.76972198], [87.88083649, 21.76944351], [87.8805542, 21.76916885], [87.88054657, 21.76889038], [87.87944031, 21.7677803], [87.87944031, 21.76749992], [87.87915039, 21.76721954], [87.87893677, 21.76680183], [87.87895203, 21.76631355], [87.87889099, 21.76610947], [87.87750244, 21.76472473], [87.87722015, 21.76472473], [87.8758316, 21.76333237], [87.87554932, 21.7630558], [87.87471008, 21.76249123], [87.87444305, 21.76222038], [87.87381744, 21.76159286], [87.87361145, 21.76139069], [87.87166595, 21.75945282], [87.8713913, 21.75944519], [87.87110901, 21.75972176], [87.87055206, 21.75972176], [87.87000275, 21.7602787], [87.87000275, 21.76044083], [87.87000275, 21.7605629], [87.8722229, 21.76278114], [87.87249756, 21.76278114], [87.87277985, 21.76305962], [87.8730545, 21.7630558], [87.8740921, 21.7640934], [87.87444305, 21.76444435], [87.87473297, 21.76444054], [87.87527466, 21.76499939], [87.87548065, 21.76520157], [87.87546539, 21.76562309], [87.87555695, 21.76610947], [87.8757019, 21.76632118], [87.87605286, 21.76667023], [87.87619019, 21.76680946], [87.87632751, 21.76688004], [87.87660217, 21.76708794], [87.8769455, 21.76722145], [87.87805176, 21.76833344], [87.87805176, 21.76860809], [87.87832642, 21.76889038], [87.87833405, 21.76916885], [87.87851715, 21.76935005], [87.8786087, 21.76944351], [87.8786087, 21.76971817], [87.87889099, 21.77000046], [87.87889099, 21.77028084], [87.87916565, 21.7705555], [87.87916565, 21.77083397], [87.87940979, 21.77135086], [87.8797226, 21.77166748], [87.88249969, 21.77444458], [87.88249969, 21.77472115], [87.88388824, 21.7761097], [87.88394928, 21.77638054], [87.8841629, 21.77667046], [87.88444519, 21.77694321], [87.88445282, 21.77721977], [87.88511658, 21.77820015], [87.88527679, 21.77861023], [87.88527679, 21.7788887], [87.88471985, 21.77944374], [87.88444519, 21.77944374], [87.8841629, 21.77916527], [87.88388824, 21.77916527], [87.88361359, 21.77944374], [87.8833313, 21.77944374], [87.88222504, 21.77833557], [87.88194275, 21.77833557], [87.88083649, 21.77722168], [87.88083649, 21.77694321], [87.88027954, 21.77639008], [87.88027954, 21.7761097], [87.87999725, 21.77583122], [87.87999725, 21.77555466], [87.8797226, 21.77527809], [87.8797226, 21.77503967], [87.8797226, 21.77444458], [87.87956238, 21.77428436], [87.87805176, 21.77277756], [87.87805176, 21.77249908], [87.87737274, 21.77166939], [87.87722015, 21.77111053], [87.87695313, 21.77055931], [87.87666321, 21.76971817], [87.8758316, 21.76888847], [87.8758316, 21.76860809], [87.875, 21.7677784], [87.87473297, 21.7677803], [87.8741684, 21.76721954], [87.87388611, 21.76722145], [87.87354279, 21.76716042], [87.87333679, 21.76723099], [87.87304688, 21.76721954], [87.8729248, 21.76688576], [87.87277985, 21.76667023], [87.87110901, 21.76501083], [87.87082672, 21.76501083], [87.87055206, 21.76472092], [87.8702774, 21.76472473], [87.87010956, 21.76454926], [87.87000275, 21.76444435], [87.86972046, 21.76444435], [87.8694458, 21.76416588], [87.86915588, 21.76416969], [87.86860657, 21.76361084], [87.86860657, 21.76333046], [87.86638641, 21.76111031], [87.8658371, 21.76111031], [87.86528015, 21.7605629], [87.86499786, 21.7605629], [87.86416626, 21.75972176], [87.8638916, 21.75972176], [87.86360931, 21.75944519], [87.86332703, 21.75945282], [87.86250305, 21.75861168], [87.86250305, 21.75805473], [87.8611145, 21.75666618], [87.86083221, 21.75666809], [87.86055756, 21.75638962], [87.86000061, 21.75638962], [87.85943604, 21.75582123], [87.85916901, 21.75583267], [87.85832977, 21.75499725], [87.85806274, 21.75500107], [87.85749817, 21.75444031], [87.85722351, 21.75444412], [87.85527802, 21.75250053], [87.85500336, 21.75250053], [87.85472107, 21.75222015], [87.85416412, 21.75222206], [87.85221863, 21.75027847], [87.85193634, 21.75028038], [87.85111237, 21.74945068], [87.85083008, 21.74945068], [87.85028076, 21.74888992], [87.84999847, 21.74888992], [87.84971619, 21.74860954], [87.84944153, 21.74861145], [87.84889221, 21.74805641], [87.84876251, 21.74772072], [87.84841156, 21.74751091], [87.84805298, 21.7472229], [87.84722137, 21.7465229], [87.84638977, 21.74638939], [87.84416962, 21.74416924], [87.84403229, 21.7439003], [87.8434906, 21.7434082], [87.84333038, 21.74333382], [87.84278107, 21.74277878], [87.84221649, 21.74221992], [87.84223175, 21.74208832], [87.84028625, 21.74055099], [87.84007263, 21.74035454], [87.83916473, 21.7397213], [87.83895874, 21.73952103], [87.83666992, 21.73749924], [87.83638763, 21.73750114], [87.83583069, 21.73694038], [87.83555603, 21.73694229], [87.83444214, 21.73583221], [87.83333588, 21.73583221], [87.83305359, 21.73555565], [87.83222198, 21.73521996], [87.83082581, 21.73417282], [87.83082581, 21.73361015], [87.83110809, 21.73333359], [87.83027649, 21.73250008], [87.82971954, 21.73250008], [87.82917023, 21.73193932], [87.82888794, 21.73194504], [87.82888794, 21.73166656], [87.82833099, 21.73110962], [87.82833099, 21.73083305], [87.82805634, 21.73055649], [87.82776642, 21.7305584], [87.8216629, 21.72445107], [87.82138824, 21.72445107], [87.82110596, 21.72417068], [87.82055664, 21.72417068], [87.81999969, 21.72360992], [87.81999969, 21.72333336], [87.81972504, 21.72305489], [87.81999969, 21.72277832], [87.81999969, 21.72249985], [87.82026672, 21.72221947], [87.82055664, 21.72221947], [87.8208313, 21.72249985], [87.82110596, 21.7226429], [87.82138824, 21.72278023], [87.82158661, 21.72305107], [87.82200623, 21.72353554], [87.82222748, 21.72360992], [87.8236084, 21.72500038], [87.82417297, 21.72500038], [87.82472229, 21.72444344], [87.82472229, 21.72417068], [87.82499695, 21.7238903], [87.82499695, 21.72360992], [87.82472229, 21.72333336], [87.82472229, 21.72305489], [87.82416534, 21.72249985], [87.82332611, 21.72249985], [87.82222748, 21.72138977], [87.82221985, 21.72027779], [87.8216629, 21.71970749], [87.82138824, 21.71972275], [87.81972504, 21.71805573], [87.81973267, 21.71777916], [87.81916046, 21.7172184], [87.81916809, 21.71694374], [87.8180542, 21.71583366], [87.8180542, 21.71555519], [87.81777954, 21.71528053], [87.81777954, 21.71471977], [87.81749725, 21.71444511], [87.81749725, 21.71417046], [87.8172226, 21.71389961], [87.8172226, 21.7136097], [87.81694794, 21.71333313], [87.81694794, 21.71305656], [87.81500244, 21.71111107], [87.81478882, 21.71096992], [87.81416321, 21.71055412], [87.81341553, 21.70981789], [87.80951691, 21.70596695], [87.8088913, 21.70583153], [87.80750275, 21.70464706], [87.80722046, 21.70443916], [87.80673981, 21.70422554], [87.80607605, 21.70397949], [87.80583191, 21.70388985], [87.805336, 21.70339203], [87.80444336, 21.70249939], [87.80375671, 21.70229912], [87.80304718, 21.70194054], [87.80236816, 21.70174217], [87.80166626, 21.70138931], [87.80146027, 21.70119095], [87.80082703, 21.70083046], [87.80007172, 21.70049667], [87.79988098, 21.70053291], [87.79972076, 21.70055962], [87.79840851, 21.70036125], [87.7977066, 21.69959068], [87.79750061, 21.69944], [87.79724121, 21.6991806], [87.79638672, 21.69833565], [87.79611206, 21.69833565], [87.79555511, 21.6977787], [87.79528046, 21.69778061], [87.79499054, 21.69750023], [87.79471588, 21.69750023], [87.79449463, 21.69727707], [87.79444122, 21.69721985], [87.79389191, 21.69722176], [87.79360962, 21.69694328], [87.79334259, 21.69695091], [87.79305267, 21.69667053], [87.79277802, 21.69667053], [87.79250336, 21.69639015], [87.79222107, 21.69639015], [87.79194641, 21.69610977], [87.79166412, 21.69611168], [87.79138947, 21.6958313], [87.79111481, 21.6958313], [87.79083252, 21.69555473], [87.79055786, 21.69555473], [87.79027557, 21.69527817], [87.79000092, 21.69528008], [87.78971863, 21.69499969], [87.78946686, 21.69499969], [87.78861237, 21.69499969], [87.78833008, 21.69472122], [87.78722382, 21.69472122], [87.78694153, 21.69466209], [87.78666687, 21.69466209], [87.78639221, 21.69472122], [87.78527832, 21.69472122], [87.78500366, 21.69473076], [87.78482056, 21.69475365], [87.78444672, 21.69479942], [87.78426361, 21.69467926], [87.78388977, 21.69444275], [87.78360748, 21.69444466], [87.78333282, 21.69416618], [87.78305054, 21.69417191], [87.78277588, 21.69411087], [87.78221893, 21.69431114], [87.78193665, 21.69417191], [87.78166962, 21.69417191], [87.78138733, 21.69388962], [87.77972412, 21.69388962], [87.77937317, 21.69403267], [87.77868652, 21.6939621], [87.77833557, 21.69388962], [87.77777863, 21.69388962], [87.77749634, 21.69361115], [87.77722168, 21.69361115], [87.77694702, 21.69388962], [87.77500153, 21.69388962], [87.77465057, 21.69403267], [87.77388763, 21.69417191], [87.77346802, 21.69417572], [87.77278137, 21.69444466], [87.77235413, 21.69445229], [87.77166748, 21.69472122], [87.77139282, 21.69499969], [87.77083588, 21.69499969], [87.77054596, 21.69528008], [87.76860809, 21.69527817], [87.76833344, 21.69555473], [87.76750183, 21.69555473], [87.76721954, 21.6958313], [87.76638794, 21.6958313], [87.76611328, 21.69611168], [87.76555634, 21.69610977], [87.76526642, 21.69639015], [87.76500702, 21.69639015], [87.76444244, 21.69695091], [87.76416779, 21.69694328], [87.7638855, 21.69722176], [87.76361084, 21.69721985], [87.76304626, 21.69778061], [87.76249695, 21.69778061], [87.76222229, 21.69806099], [87.76194763, 21.69806099], [87.76132202, 21.69743347], [87.7611084, 21.69722176], [87.7611084, 21.69694328], [87.76055908, 21.69638824], [87.75971985, 21.69721985], [87.75971985, 21.69806099], [87.75861359, 21.69916534], [87.75861359, 21.69944572], [87.7583313, 21.69944], [87.75776672, 21.70000076], [87.75749969, 21.69972038], [87.75694275, 21.69972229], [87.75666809, 21.69944572], [87.7563858, 21.69944], [87.75583649, 21.70000076], [87.75554657, 21.70000076], [87.75527954, 21.69972038], [87.75499725, 21.69972229], [87.7547226, 21.69944572], [87.75444794, 21.69944572], [87.75416565, 21.69916534], [87.7536087, 21.69972229], [87.75333405, 21.69972229], [87.75250244, 21.69888878], [87.75110626, 21.69890022], [87.75026703, 21.69806099], [87.75026703, 21.69639015], [87.75029755, 21.69625092], [87.75026703, 21.69610977], [87.75041199, 21.69605255], [87.7508316, 21.69611168], [87.75111389, 21.69611168], [87.75222015, 21.69722176], [87.75250244, 21.69721985], [87.7527771, 21.69750023], [87.75332642, 21.69750023], [87.7536087, 21.69721985], [87.75389099, 21.69722176], [87.75416565, 21.69694328], [87.75417328, 21.69667053], [87.75389099, 21.69639015]], [[88.99397278, 26.32003403], [88.99365997, 26.32025909], [88.99307251, 26.32024384], [88.99397278, 26.32003403]], [[88.2853775, 24.8884697], [88.28574371, 24.88817024], [88.28593445, 24.88802147], [88.28596497, 24.88816643], [88.28585052, 24.88828087], [88.2853775, 24.8884697]], [[88.92998505, 22.65362549], [88.93003082, 22.65386581], [88.92976379, 22.65390015], [88.92939758, 22.65398026], [88.92941284, 22.65365982], [88.92998505, 22.65362549]], [[88.58655548, 23.81160927], [88.58647919, 23.8113308], [88.58666229, 23.81118965], [88.58655548, 23.81160927]], [[89.34877777, 26.01606178], [89.34773254, 26.01514053], [89.34732056, 26.01499557], [89.34793854, 26.01499748], [89.34911346, 26.0150032], [89.34912109, 26.01525307], [89.34916687, 26.01624107], [89.34877777, 26.01606178]], [[89.56465149, 26.0606575], [89.5642395, 26.06067085], [89.563797, 26.06075096], [89.56336212, 26.06081581], [89.56300354, 26.06089783], [89.56260681, 26.06102753], [89.56218719, 26.06118774], [89.56176758, 26.06131554], [89.5612793, 26.06142616], [89.56098175, 26.06151581], [89.56070709, 26.06158829], [89.56044769, 26.06168365], [89.56021881, 26.06176758], [89.55995941, 26.06188965], [89.55970001, 26.06199455], [89.55944824, 26.0621624], [89.55922699, 26.06231117], [89.55908966, 26.06241798], [89.5589447, 26.06255531], [89.55883026, 26.06270599], [89.55872345, 26.06286621], [89.55862427, 26.06305122], [89.55856323, 26.06319046], [89.55848694, 26.06333542], [89.55841064, 26.06348419], [89.55834961, 26.06362152], [89.55828857, 26.06369972], [89.55821228, 26.06376457], [89.55806732, 26.06383514], [89.55791473, 26.06393623], [89.55776215, 26.06399155], [89.55757904, 26.06408882], [89.55743408, 26.06417274], [89.55723572, 26.06432533], [89.55706787, 26.0644474], [89.55688477, 26.06457901], [89.55675507, 26.0647068], [89.55662537, 26.06481743], [89.55651093, 26.06491852], [89.55644226, 26.064991], [89.55632782, 26.06509781], [89.55619812, 26.06519127], [89.55609894, 26.06525803], [89.55597687, 26.06534767], [89.55584717, 26.06541252], [89.55568695, 26.06548309], [89.55551147, 26.06555939], [89.55537415, 26.06558228], [89.55517578, 26.06559944], [89.55504608, 26.06556892], [89.55484009, 26.06552124], [89.55463409, 26.0654583], [89.55442047, 26.06540108], [89.5541153, 26.06531715], [89.55386353, 26.06527138], [89.55361176, 26.06523323], [89.55336761, 26.06520271], [89.55302429, 26.06508636], [89.55274963, 26.06495857], [89.55246735, 26.06477737], [89.55223083, 26.06456184], [89.55210114, 26.06430054], [89.55198669, 26.06407928], [89.55189514, 26.06382179], [89.5517807, 26.06349945], [89.55169678, 26.06321144], [89.551651, 26.06306076], [89.55162048, 26.0627594], [89.55162048, 26.06258583], [89.55162048, 26.06243706], [89.55162048, 26.06231117], [89.5515976, 26.06217003], [89.5515976, 26.06192017], [89.55162811, 26.06168747], [89.551651, 26.06150246], [89.55167389, 26.06121063], [89.55171204, 26.06094551], [89.55173492, 26.06066132], [89.55175781, 26.06038857], [89.55176544, 26.06016541], [89.55180359, 26.05986977], [89.55183411, 26.05959129], [89.55188751, 26.0592289], [89.55192566, 26.05884361], [89.55196381, 26.05851746], [89.55202484, 26.05813599], [89.55210114, 26.05779076], [89.55222321, 26.05752754], [89.55238342, 26.05724525], [89.55261993, 26.05695915], [89.55286407, 26.05672073], [89.55314636, 26.05642509], [89.55328369, 26.05620956], [89.55341339, 26.05596542], [89.55352783, 26.05573654], [89.55365753, 26.05548286], [89.55381775, 26.05523109], [89.55393982, 26.05504227], [89.55412292, 26.05486679], [89.55430603, 26.05466843], [89.55448151, 26.05444717], [89.55466461, 26.05413055], [89.55482483, 26.05380249], [89.55502319, 26.05341339], [89.55518341, 26.05304909], [89.55540466, 26.05264473], [89.55561066, 26.05238914], [89.55582428, 26.05222321], [89.55604553, 26.05204582], [89.55633545, 26.05179405], [89.5566864, 26.05147934], [89.55699158, 26.0512104], [89.55725098, 26.05098724], [89.55751038, 26.05074692], [89.55773926, 26.05056953], [89.55799103, 26.05037498], [89.55820465, 26.05025673], [89.55841064, 26.05013847], [89.55859375, 26.05014038], [89.55873108, 26.05013275], [89.55896759, 26.05008507], [89.55914307, 26.05004501], [89.55940247, 26.04999733], [89.55970001, 26.04998016], [89.55995941, 26.04996681], [89.56034851, 26.04999733], [89.56075287, 26.05003548], [89.56111908, 26.05012894], [89.56144714, 26.05021286], [89.56167603, 26.05025291], [89.56196594, 26.05032921], [89.56230927, 26.05039597], [89.5626297, 26.05047989], [89.56304169, 26.05055618], [89.56337738, 26.0506115], [89.56370544, 26.05065155], [89.56403351, 26.05071068], [89.56441498, 26.05077744], [89.56472015, 26.05083847], [89.56510162, 26.0509243], [89.56546783, 26.05097961], [89.56581879, 26.05106544], [89.56610107, 26.05109596], [89.56634521, 26.05113983], [89.56665039, 26.05123711], [89.56697845, 26.05139923], [89.56726837, 26.05155754], [89.56761169, 26.05173492], [89.56788635, 26.05192184], [89.56812286, 26.05210304], [89.56835938, 26.0522995], [89.56859589, 26.05249405], [89.56886292, 26.0527668], [89.56912231, 26.05306816], [89.56929779, 26.05326653], [89.56941986, 26.05346298], [89.56954193, 26.05360985], [89.56965637, 26.05374146], [89.56976318, 26.05385399], [89.56990051, 26.053936], [89.57003021, 26.05396843], [89.5701828, 26.05387115], [89.57035828, 26.05360985], [89.57047272, 26.05335426], [89.57065582, 26.05293655], [89.57077789, 26.0526886], [89.57087708, 26.05249977], [89.57095337, 26.05233574], [89.57107544, 26.05221558], [89.57123566, 26.05215836], [89.57136536, 26.05221558], [89.57145691, 26.05231094], [89.57158661, 26.05251312], [89.57170105, 26.05284119], [89.57175446, 26.05323792], [89.57175446, 26.05376053], [89.5717926, 26.05425262], [89.57196808, 26.05471992], [89.5721283, 26.0551281], [89.57239532, 26.05570412], [89.57258606, 26.05619621], [89.57286072, 26.05681419], [89.5730896, 26.05735779], [89.57329559, 26.05774498], [89.57350159, 26.05817795], [89.57364655, 26.05853462], [89.57375336, 26.05884171], [89.57379913, 26.05922318], [89.57383728, 26.05950165], [89.57380676, 26.05984306], [89.57375336, 26.06008148], [89.57372284, 26.0603199], [89.5737381, 26.06047249], [89.57378387, 26.06072617], [89.57384491, 26.06094933], [89.57374573, 26.06108475], [89.57355499, 26.06118393], [89.57328796, 26.06126976], [89.57312775, 26.06135178], [89.57296753, 26.06147575], [89.57280731, 26.06159782], [89.57254028, 26.06188774], [89.57256317, 26.06222725], [89.57279205, 26.06267929], [89.57283783, 26.0630188], [89.57238007, 26.06312752], [89.57159424, 26.06267166], [89.57113647, 26.06246948], [89.57091522, 26.06233978], [89.57067108, 26.06219292], [89.57034302, 26.06199837], [89.57000732, 26.06181335], [89.56954193, 26.06158257], [89.56900024, 26.06134987], [89.56848907, 26.061203], [89.5679245, 26.06101608], [89.56738281, 26.0608654], [89.5669632, 26.06079292], [89.56656647, 26.06075859], [89.56629944, 26.06072998], [89.56595612, 26.0606823], [89.56548309, 26.0606575], [89.56510925, 26.06062508], [89.56465149, 26.0606575]], [[89.50184631, 26.06993484], [89.50170898, 26.0699482], [89.50151825, 26.06996155], [89.50138855, 26.06999588], [89.50117493, 26.0700264], [89.50093842, 26.07005692], [89.50062561, 26.07007027], [89.50038147, 26.07005119], [89.50014496, 26.07004166], [89.49991608, 26.07000351], [89.49967194, 26.06996346], [89.49941254, 26.06991196], [89.49907684, 26.06979752], [89.49890137, 26.06973839], [89.498703, 26.06966972], [89.49859619, 26.06958961], [89.49855042, 26.06949425], [89.49854279, 26.06938171], [89.49848175, 26.06911278], [89.49843597, 26.06896973], [89.4983902, 26.06882858], [89.49830627, 26.06848335], [89.4982605, 26.06834412], [89.49813843, 26.0678997], [89.49808502, 26.0676918], [89.49806213, 26.06746292], [89.4980545, 26.06724358], [89.49812317, 26.06699753], [89.49817657, 26.0668602], [89.49825287, 26.06672096], [89.49832153, 26.06663322], [89.49845123, 26.06646347], [89.49853516, 26.06637955], [89.49861908, 26.06632614], [89.49874878, 26.0662384], [89.498909, 26.06613541], [89.49903107, 26.06608009], [89.49914551, 26.06604004], [89.49925995, 26.06601524], [89.4993515, 26.06596565], [89.49940491, 26.06590652], [89.49951172, 26.06581497], [89.49958801, 26.06568909], [89.49966431, 26.06554222], [89.49972534, 26.06538582], [89.49979401, 26.06510353], [89.4998703, 26.06498337], [89.49993134, 26.06484413], [89.50000763, 26.06472969], [89.50010681, 26.06462669], [89.50022888, 26.0645256], [89.50035095, 26.06442451], [89.50047302, 26.06432152], [89.50061798, 26.06421852], [89.50078583, 26.06411171], [89.50102997, 26.06399345], [89.50113678, 26.06388474], [89.50128174, 26.0637989], [89.5014267, 26.06371117], [89.50157166, 26.06360054], [89.5016861, 26.06347466], [89.50189972, 26.06322861], [89.50200653, 26.06305695], [89.50202942, 26.06288338], [89.50205231, 26.06274986], [89.50206757, 26.06262589], [89.5020752, 26.06250191], [89.50215149, 26.06219292], [89.5022049, 26.062006], [89.50228882, 26.06182289], [89.50241089, 26.06152725], [89.50247955, 26.06130791], [89.50244141, 26.06109047], [89.50242615, 26.06092834], [89.50245667, 26.06078911], [89.50247192, 26.06062698], [89.50253296, 26.06036949], [89.50257874, 26.06020737], [89.50266266, 26.06000328], [89.50292969, 26.05973816], [89.50346375, 26.05921364], [89.50360107, 26.05912018], [89.50371552, 26.05903244], [89.50373077, 26.05894661], [89.50415039, 26.05873871], [89.50428009, 26.05875778], [89.50447083, 26.05867958], [89.50461578, 26.05854225], [89.50473022, 26.05841064], [89.50483704, 26.05834007], [89.50495148, 26.05830765], [89.50505066, 26.05831337], [89.50519562, 26.05831528], [89.50537872, 26.05833435], [89.50567627, 26.05832863], [89.50591278, 26.05829048], [89.50608063, 26.0582428], [89.5062561, 26.05817604], [89.50644684, 26.05811691], [89.50655365, 26.05810356], [89.50675201, 26.05815697], [89.50694275, 26.05820084], [89.50706482, 26.05822945], [89.50723267, 26.0582428], [89.50737762, 26.05822182], [89.50752258, 26.05818748], [89.50762939, 26.05815697], [89.50774384, 26.05812836], [89.50790405, 26.05811119], [89.50810242, 26.05810738], [89.50839233, 26.05808067], [89.5085144, 26.05805397], [89.50880432, 26.0580368], [89.50891113, 26.05802536], [89.50931549, 26.0579586], [89.50951385, 26.05788994], [89.50963593, 26.05783272], [89.509758, 26.05779266], [89.51003265, 26.05764008], [89.51013947, 26.05757713], [89.51039124, 26.0574894], [89.51068115, 26.05742455], [89.5110321, 26.05742264], [89.51148224, 26.05756569], [89.51168823, 26.05766296], [89.51190186, 26.0578804], [89.51228333, 26.05828667], [89.51261902, 26.05858803], [89.51272583, 26.05867958], [89.51290131, 26.05883026], [89.51305389, 26.05896187], [89.51319122, 26.05908585], [89.51340485, 26.05925941], [89.51359558, 26.05941391], [89.51379395, 26.05967903], [89.51398468, 26.06008148], [89.51413727, 26.06047249], [89.51418304, 26.0607605], [89.51422119, 26.06092262], [89.51421356, 26.06114578], [89.51419067, 26.06146049], [89.51416779, 26.0617733], [89.51412201, 26.06215096], [89.51409149, 26.06226921], [89.5140686, 26.06240273], [89.51406097, 26.06254959], [89.51407623, 26.06271553], [89.51409149, 26.06295776], [89.51409912, 26.06310654], [89.51407623, 26.06329727], [89.51404572, 26.06336975], [89.51396179, 26.06359673], [89.51395416, 26.06372833], [89.51406097, 26.06411743], [89.51415253, 26.06424713], [89.51425934, 26.06440353], [89.51438141, 26.06457901], [89.51446533, 26.06474304], [89.51459503, 26.06499863], [89.51457214, 26.06508636], [89.51454926, 26.06522179], [89.51451111, 26.06537819], [89.5144577, 26.06547737], [89.51441193, 26.06557846], [89.51434326, 26.06562805], [89.51417542, 26.06580734], [89.51409912, 26.06586075], [89.51396179, 26.06591797], [89.51384735, 26.06598091], [89.51372528, 26.06602097], [89.51361847, 26.06604767], [89.51351929, 26.06609154], [89.51342773, 26.06612206], [89.51325989, 26.06618118], [89.51303101, 26.06625748], [89.51293182, 26.06628036], [89.51273346, 26.0663662], [89.51255798, 26.06645203], [89.5124054, 26.06652069], [89.51232147, 26.06656837], [89.5122757, 26.06649971], [89.51217651, 26.06652641], [89.51203156, 26.06658363], [89.51191711, 26.06664085], [89.51182556, 26.06666756], [89.51172638, 26.06668854], [89.51158905, 26.06674576], [89.51150513, 26.06678009], [89.5114212, 26.06682205], [89.51134491, 26.06686592], [89.5112381, 26.06692314], [89.51111603, 26.06697083], [89.5109787, 26.06699181], [89.51089478, 26.06697655], [89.51077271, 26.06695557], [89.51065826, 26.0669651], [89.51052094, 26.06698418], [89.51036072, 26.06702805], [89.51022339, 26.06704903], [89.51000977, 26.06705093], [89.50991821, 26.06707001], [89.50979614, 26.06706429], [89.50961304, 26.06708717], [89.50944519, 26.06711769], [89.50922394, 26.06716919], [89.50907898, 26.06720352], [89.50896454, 26.06723404], [89.50884247, 26.06725883], [89.50866699, 26.06723404], [89.508461, 26.0672245], [89.50823975, 26.06720543], [89.50798798, 26.0671978], [89.50776672, 26.06721306], [89.50765228, 26.06723976], [89.50738525, 26.06729698], [89.507164, 26.06739235], [89.50695038, 26.06751823], [89.50680542, 26.06765175], [89.50669098, 26.06779099], [89.50659943, 26.0679512], [89.50650787, 26.06806183], [89.50643158, 26.06821251], [89.50637817, 26.06837845], [89.50630188, 26.06852913], [89.50623322, 26.06859398], [89.50615692, 26.06863213], [89.506073, 26.06866837], [89.50585938, 26.06874084], [89.50574493, 26.06878471], [89.50562286, 26.06881905], [89.50544739, 26.06892204], [89.50535583, 26.06898499], [89.50528717, 26.06906128], [89.50522614, 26.06913185], [89.50510406, 26.0692749], [89.50504303, 26.06936836], [89.50492859, 26.069561], [89.50480652, 26.06968689], [89.50473785, 26.06975746], [89.50465393, 26.0698185], [89.50453186, 26.06987953], [89.50443268, 26.06994057], [89.50428772, 26.06995392], [89.50415039, 26.06997299], [89.50402832, 26.0700016], [89.50385284, 26.07001495], [89.50374603, 26.07000923], [89.50363159, 26.07001686], [89.50351715, 26.07003212], [89.50341034, 26.07001686], [89.50331879, 26.0700264], [89.50319672, 26.06999588], [89.50300598, 26.06995773], [89.5029068, 26.06992531], [89.50283051, 26.06993675], [89.50275421, 26.06994629], [89.50263977, 26.06996155], [89.50250244, 26.06994438], [89.5022049, 26.0699482], [89.50209808, 26.06993294], [89.50196838, 26.06991959], [89.50184631, 26.06993484]], [[89.60414124, 26.12532043], [89.60419464, 26.12583351], [89.60406494, 26.12590599], [89.60414124, 26.12532043]], [[89.63412476, 26.19461441], [89.63297272, 26.1925602], [89.63302612, 26.19170952], [89.63508606, 26.19046402], [89.6350174, 26.19173431], [89.63499451, 26.19232178], [89.63562012, 26.19325066], [89.63596344, 26.19376183], [89.63412476, 26.19461441]], [[89.58585358, 26.18371201], [89.5860672, 26.18405914], [89.58627319, 26.18457985], [89.58648682, 26.18507767], [89.58663177, 26.18537331], [89.5867691, 26.18556023], [89.58688354, 26.18564987], [89.58715057, 26.18598366], [89.58745575, 26.18638039], [89.58761597, 26.18680763], [89.58771515, 26.18757057], [89.58773041, 26.18815804], [89.58773041, 26.18846321], [89.58766937, 26.18870544], [89.58759308, 26.18883133], [89.58744049, 26.18900108], [89.58729553, 26.18915176], [89.58706665, 26.18940353], [89.58683014, 26.18947983], [89.58654022, 26.18948746], [89.58625031, 26.18952942], [89.58603668, 26.18952942], [89.58580017, 26.18950653], [89.58545685, 26.1888485], [89.58527374, 26.1885643], [89.58499908, 26.18809319], [89.58473969, 26.18762589], [89.58448029, 26.18703651], [89.58424377, 26.18648529], [89.58392334, 26.18584824], [89.58370972, 26.18541908], [89.58348846, 26.18502235], [89.58325958, 26.18462944], [89.58317566, 26.18442154], [89.58314514, 26.18412971], [89.58325195, 26.18403053], [89.58346558, 26.18393326], [89.58391571, 26.18382072], [89.58444977, 26.18372154], [89.58519745, 26.18359947], [89.58558655, 26.18357849], [89.58585358, 26.18371201]], [[89.62191772, 26.20042419], [89.62172699, 26.2009201], [89.62151337, 26.20120239], [89.62138367, 26.20137978], [89.62124634, 26.20140266], [89.62112427, 26.20135307], [89.62088013, 26.201231], [89.62062836, 26.2010994], [89.62042236, 26.20098114], [89.62017822, 26.20087051], [89.61994934, 26.20071983], [89.6197052, 26.20053864], [89.61943817, 26.20031548], [89.61921692, 26.20014191], [89.61920166, 26.20000839], [89.61927032, 26.19976044], [89.61936188, 26.19951057], [89.61946869, 26.19919777], [89.6195755, 26.19897842], [89.61965179, 26.19882393], [89.61972809, 26.19861031], [89.61977386, 26.19843864], [89.61978149, 26.1982193], [89.61975861, 26.19804192], [89.61972046, 26.19784927], [89.61961365, 26.19761276], [89.61952209, 26.19741249], [89.61940765, 26.19725418], [89.61925507, 26.19716263], [89.61907959, 26.19713211], [89.61870575, 26.19725037], [89.61840057, 26.19742775], [89.61810303, 26.19756699], [89.61785889, 26.19762421], [89.61759949, 26.19769859], [89.61732483, 26.197752], [89.61708832, 26.19782448], [89.61684418, 26.19791031], [89.61656189, 26.19803429], [89.61636353, 26.19815826], [89.61617279, 26.19826126], [89.61606598, 26.19827461], [89.61582184, 26.19824791], [89.61560059, 26.19815254], [89.61528778, 26.19796944], [89.6149292, 26.19769096], [89.61464691, 26.19749069], [89.61428833, 26.19725609], [89.61408234, 26.19714165], [89.61390686, 26.19707108], [89.61380768, 26.19700241], [89.61373901, 26.19689751], [89.6137619, 26.19665337], [89.61386871, 26.19636917], [89.61398315, 26.19610405], [89.6140976, 26.19575882], [89.61420441, 26.19539642], [89.61427307, 26.19509888], [89.61434174, 26.1947937], [89.61437988, 26.19457054], [89.6144104, 26.19429207], [89.61440277, 26.19404411], [89.61438751, 26.19385529], [89.61436462, 26.19360542], [89.61436462, 26.1934166], [89.61438751, 26.19327164], [89.61440277, 26.1931591], [89.6144104, 26.19301033], [89.61444855, 26.19286156], [89.61453247, 26.19272804], [89.61461639, 26.19257545], [89.61474609, 26.19239807], [89.61485291, 26.19226265], [89.6149826, 26.19211769], [89.61507416, 26.19197845], [89.61520386, 26.19181633], [89.61529541, 26.19161797], [89.61537933, 26.19147682], [89.61548615, 26.19126511], [89.61555481, 26.19104004], [89.6156311, 26.19086456], [89.61566925, 26.19062614], [89.6157074, 26.19046402], [89.6157608, 26.19029427], [89.61579132, 26.19012451], [89.61581421, 26.18997955], [89.61581421, 26.18983459], [89.61579132, 26.18973351], [89.61572266, 26.18959808], [89.6155014, 26.18962669], [89.61521149, 26.18977928], [89.61497498, 26.18993378], [89.61473083, 26.19009018], [89.61450958, 26.1902523], [89.61424255, 26.19043541], [89.61392212, 26.19064903], [89.61365509, 26.19079971], [89.61338043, 26.19094086], [89.61320496, 26.19107246], [89.61299133, 26.19122887], [89.61282349, 26.19141579], [89.61257172, 26.19167519], [89.61239624, 26.19190216], [89.61219788, 26.19210434], [89.6120224, 26.19224167], [89.61185455, 26.19234467], [89.61164093, 26.19241333], [89.6113739, 26.19245148], [89.61113739, 26.19244003], [89.61081696, 26.19239426], [89.61057281, 26.19234467], [89.61031342, 26.19228745], [89.61006165, 26.19226074], [89.60987854, 26.19224739], [89.60971832, 26.19223785], [89.60964966, 26.19213295], [89.60961914, 26.19206047], [89.60960388, 26.19198608], [89.60960388, 26.19186592], [89.60957336, 26.19178581], [89.60948944, 26.19176674], [89.60939026, 26.19177628], [89.60929871, 26.19177437], [89.60914612, 26.19171143], [89.60908508, 26.19162941], [89.60904694, 26.19153214], [89.60905457, 26.19131851], [89.60908508, 26.19116974], [89.60912323, 26.19104576], [89.60925293, 26.19092941], [89.60947418, 26.19076347], [89.60966492, 26.19066429], [89.60985565, 26.19055939], [89.60997772, 26.19049454], [89.61006165, 26.19043541], [89.6101532, 26.1903553], [89.61025238, 26.19026756], [89.61039734, 26.19020462], [89.61052704, 26.1901741], [89.61061096, 26.19016075], [89.61074829, 26.19002533], [89.61083221, 26.1898365], [89.61090851, 26.18970299], [89.61126709, 26.18954277], [89.61177826, 26.18935776], [89.61302948, 26.18957329], [89.61315155, 26.18961525], [89.61328125, 26.18962097], [89.61342621, 26.18961716], [89.61364746, 26.18959999], [89.61399841, 26.18955803], [89.61437225, 26.18948174], [89.61463165, 26.18940163], [89.61495972, 26.1892662], [89.61528778, 26.18911934], [89.61579132, 26.18887329], [89.61621857, 26.18862152], [89.61656952, 26.18835068], [89.61689758, 26.18800926], [89.61700439, 26.18776321], [89.61714172, 26.18755341], [89.61734772, 26.18732452], [89.61759949, 26.1870594], [89.61792755, 26.18677139], [89.61817932, 26.18653488], [89.61841583, 26.18635559], [89.61859131, 26.18621635], [89.61871338, 26.18615723], [89.618927, 26.18632317], [89.61906433, 26.18657494], [89.619133, 26.18665314], [89.61925507, 26.18678284], [89.61935425, 26.18684769], [89.61952972, 26.18696404], [89.61963654, 26.18704605], [89.61974335, 26.18719864], [89.61975861, 26.18737411], [89.61975861, 26.18757629], [89.6197052, 26.18778801], [89.61959076, 26.18802834], [89.61947632, 26.18822289], [89.61934662, 26.18850899], [89.6192627, 26.18873596], [89.61916351, 26.18921089], [89.61907196, 26.18967056], [89.61896515, 26.19002342], [89.61888885, 26.19029617], [89.61884308, 26.19046402], [89.61882782, 26.19057846], [89.61875916, 26.19065094], [89.61862946, 26.19069481], [89.61838531, 26.19072723], [89.61817169, 26.19073677], [89.61803436, 26.19076729], [89.61797333, 26.19083595], [89.61792755, 26.19090462], [89.61791229, 26.19103432], [89.61789703, 26.19115257], [89.61788177, 26.19127083], [89.61787415, 26.19143677], [89.6178894, 26.19166183], [89.61791229, 26.19192123], [89.61792755, 26.19222641], [89.61793518, 26.19250298], [89.61794281, 26.19279671], [89.61797333, 26.19324875], [89.61795807, 26.19356346], [89.61791992, 26.19370842], [89.61791229, 26.19395828], [89.6178894, 26.19419479], [89.6182785, 26.19437981], [89.61836243, 26.19438744], [89.61851501, 26.19446182], [89.61864471, 26.19460869], [89.6190567, 26.1948204], [89.61924744, 26.19478226], [89.61936188, 26.19477654], [89.61950684, 26.19480324], [89.61965179, 26.19487381], [89.61982727, 26.19501305], [89.61992645, 26.19519424], [89.62004852, 26.19542885], [89.62012482, 26.19571495], [89.62010956, 26.19598389], [89.62011719, 26.19623756], [89.62020111, 26.19649124], [89.62023926, 26.19666481], [89.62030029, 26.19677162], [89.6204071, 26.19690895], [89.62052917, 26.19701004], [89.62071228, 26.19715881], [89.62099457, 26.19731903], [89.62128448, 26.19752121], [89.62146759, 26.1977253], [89.62165833, 26.19789886], [89.62185669, 26.19809341], [89.62211609, 26.19824409], [89.62232971, 26.19837761], [89.62249756, 26.19845581], [89.62263489, 26.19855309], [89.62274933, 26.19863129], [89.62287903, 26.19876289], [89.62302399, 26.19896889], [89.62311554, 26.19914818], [89.62316132, 26.19933891], [89.62319183, 26.19955635], [89.62319183, 26.19981766], [89.62316132, 26.20002747], [89.62311554, 26.20015335], [89.62306976, 26.20024681], [89.62294006, 26.20036888], [89.62281799, 26.2004261], [89.62254333, 26.20045471], [89.62227631, 26.20043564], [89.62210083, 26.20035744], [89.62198639, 26.20033455], [89.62191772, 26.20042419]], [[89.60873413, 26.1231823], [89.60746765, 26.12268257], [89.60600281, 26.1217308], [89.60611725, 26.1203804], [89.6062088, 26.11923027], [89.60678864, 26.11819267], [89.60688019, 26.11829948], [89.60701752, 26.11844635], [89.60770416, 26.11875916], [89.60879517, 26.1206665], [89.6085968, 26.12292099], [89.60873413, 26.1231823]], [[89.60153961, 26.11189842], [89.60275269, 26.11054039], [89.6029129, 26.11040497], [89.60303497, 26.11173058], [89.60153961, 26.11189842]], [[89.15951538, 26.23424911], [89.1598053, 26.23425484], [89.1601181, 26.2342968], [89.1604538, 26.23438263], [89.16085815, 26.23446083], [89.16117096, 26.23451233], [89.16164398, 26.23461533], [89.16201019, 26.23472214], [89.16246033, 26.23486519], [89.16279602, 26.23502922], [89.1630249, 26.23519325], [89.16321564, 26.23536301], [89.16336823, 26.23552895], [89.1635437, 26.23576546], [89.16371918, 26.2360096], [89.16391754, 26.23635674], [89.16407776, 26.23661041], [89.16423798, 26.23689842], [89.1644516, 26.23729324], [89.16468048, 26.23759842], [89.16487122, 26.23784637], [89.16504669, 26.23806953], [89.16516113, 26.23822403], [89.16537476, 26.23843575], [89.16560364, 26.23867035], [89.16578674, 26.23892021], [89.16597748, 26.2392292], [89.16613007, 26.23952293], [89.16628265, 26.23978996], [89.16640472, 26.24006081], [89.16652679, 26.24029541], [89.16658783, 26.2403698], [89.16666412, 26.24042511], [89.16674805, 26.24047661], [89.16690826, 26.24055862], [89.16712189, 26.24062538], [89.16729736, 26.24067116], [89.16745758, 26.24068069], [89.16770172, 26.24065018], [89.1680069, 26.24061966], [89.16830444, 26.24057961], [89.16855621, 26.24054909], [89.1688385, 26.24050522], [89.16911316, 26.24046516], [89.16932678, 26.24042892], [89.16954041, 26.24035072], [89.16973114, 26.24031639], [89.16985321, 26.24027252], [89.17001343, 26.24020958], [89.17021942, 26.24010468], [89.17027283, 26.2400341], [89.17037964, 26.23994637], [89.17047882, 26.23989868], [89.17073822, 26.24008369], [89.17089081, 26.240345], [89.1709671, 26.24058342], [89.17097473, 26.24073982], [89.17088318, 26.24101448], [89.17071533, 26.2413063], [89.17058563, 26.24145508], [89.17047882, 26.24155807], [89.17030334, 26.24168015], [89.17006683, 26.24184799], [89.16989899, 26.24191666], [89.16972351, 26.24197197], [89.16958618, 26.24202538], [89.16936493, 26.24208832], [89.16914368, 26.24214172], [89.16895294, 26.24219322], [89.16871643, 26.24228287], [89.16851044, 26.24237442], [89.16850281, 26.2425499], [89.16854858, 26.24268341], [89.16871643, 26.24269485], [89.16889191, 26.24262619], [89.16918182, 26.24262619], [89.16920471, 26.24271774], [89.16921997, 26.24285316], [89.16924286, 26.24302864], [89.16928864, 26.24329376], [89.16936493, 26.24357605], [89.16944885, 26.24379539], [89.16950989, 26.24399185], [89.16957092, 26.24416161], [89.16967773, 26.24438858], [89.16976929, 26.24455833], [89.16964722, 26.24471092], [89.16934204, 26.24490547], [89.16917419, 26.24503326], [89.16904449, 26.24510193], [89.16887665, 26.24511528], [89.16873932, 26.24517441], [89.16867065, 26.24524307], [89.16860199, 26.24537659], [89.16854858, 26.24557686], [89.16854095, 26.24583054], [89.16854858, 26.24602318], [89.1685791, 26.24634552], [89.16857147, 26.24656868], [89.16851807, 26.24687576], [89.16846466, 26.24713516], [89.16840363, 26.24730301], [89.16832733, 26.2474575], [89.16815948, 26.24771881], [89.16792297, 26.2480278], [89.16769409, 26.24832916], [89.16744232, 26.24864769], [89.16722107, 26.24889374], [89.16702271, 26.24915123], [89.16687775, 26.24938583], [89.16677856, 26.24956512], [89.16666412, 26.24978828], [89.16660309, 26.25003052], [89.16646576, 26.25053406], [89.16639709, 26.25092125], [89.16634369, 26.25120354], [89.16633606, 26.25141716], [89.16633606, 26.25163078], [89.16636658, 26.25196457], [89.16646576, 26.2523632], [89.16656494, 26.25269127], [89.16669464, 26.25301552], [89.16676331, 26.25317383], [89.16683197, 26.25333023], [89.16693115, 26.25353622], [89.16705322, 26.25371742], [89.16717529, 26.25380135], [89.16738892, 26.25393867], [89.16757965, 26.25403595], [89.16768646, 26.25407791], [89.16781616, 26.25406265], [89.16793823, 26.25400162], [89.16805267, 26.25384712], [89.16821289, 26.25356483], [89.16835785, 26.25320816], [89.16854095, 26.25268364], [89.16867065, 26.25232506], [89.16876221, 26.25209808], [89.16884613, 26.25193024], [89.16892242, 26.25188446], [89.16899109, 26.25205231], [89.16910553, 26.25233841], [89.16925049, 26.25272369], [89.16946411, 26.25318718], [89.1696167, 26.25356293], [89.16983795, 26.25401497], [89.17009735, 26.25455856], [89.17031097, 26.2549839], [89.17047882, 26.2552948], [89.17055511, 26.25543976], [89.17054749, 26.25553513], [89.17045593, 26.25572968], [89.17029572, 26.25587654], [89.1700592, 26.25601006], [89.16977692, 26.25617409], [89.16954041, 26.25629616], [89.16928101, 26.25641823], [89.16899109, 26.25654793], [89.16873169, 26.25665092], [89.16849518, 26.25679398], [89.168396, 26.25693512], [89.16828156, 26.25715637], [89.16815948, 26.2573719], [89.16805267, 26.25754929], [89.16788483, 26.25777626], [89.16777039, 26.25792313], [89.16757965, 26.25814819], [89.16737366, 26.25839043], [89.16725159, 26.25852203], [89.16716766, 26.25867844], [89.1671524, 26.25884247], [89.16719818, 26.25905037], [89.16732025, 26.25922394], [89.16742706, 26.25930214], [89.16756439, 26.25934029], [89.16781616, 26.25936508], [89.16820526, 26.25938034], [89.16861725, 26.25938416], [89.16889954, 26.25932693], [89.16923523, 26.25928116], [89.16946411, 26.25922966], [89.16966248, 26.25921059], [89.16984558, 26.25917816], [89.16999054, 26.25909996], [89.1701355, 26.25900459], [89.17027283, 26.25879669], [89.17040253, 26.25859261], [89.17050171, 26.25841141], [89.17058563, 26.25835991], [89.17076111, 26.25829315], [89.17134857, 26.25802803], [89.17179871, 26.25782394], [89.17186737, 26.2577877], [89.17192078, 26.25770378], [89.17194366, 26.25743484], [89.17189789, 26.2570858], [89.17181396, 26.25683403], [89.17171478, 26.25677872], [89.17220306, 26.25664902], [89.1724472, 26.25669289], [89.17272949, 26.25673676], [89.17294312, 26.25675201], [89.17323303, 26.25681686], [89.17353058, 26.25688744], [89.17376709, 26.25699234], [89.17391968, 26.25713921], [89.17397308, 26.25728416], [89.17393494, 26.25746918], [89.17378998, 26.25777626], [89.17359924, 26.25815201], [89.1733551, 26.25865936], [89.17323303, 26.25893021], [89.17311859, 26.25924301], [89.17301941, 26.25953102], [89.17297363, 26.25973129], [89.172966, 26.25996208], [89.17298126, 26.26024055], [89.17288971, 26.26047325], [89.17272186, 26.26062202], [89.1724472, 26.2607708], [89.17216492, 26.2609024], [89.17189789, 26.26117706], [89.17171478, 26.26153946], [89.17169189, 26.26187706], [89.17171478, 26.26226425], [89.1717453, 26.26255989], [89.1717453, 26.26282883], [89.17173004, 26.26299667], [89.17169952, 26.26311874], [89.17163086, 26.26330948], [89.17150879, 26.26346588], [89.17131042, 26.26370239], [89.17105103, 26.2638073], [89.17082977, 26.26382446], [89.17057037, 26.26386261], [89.17029572, 26.26384163], [89.17011261, 26.26379585], [89.16984558, 26.26368904], [89.169487, 26.26359177], [89.16873169, 26.26351547], [89.16815948, 26.26346588], [89.1680603, 26.26340675], [89.1682663, 26.26319885], [89.16889954, 26.2627964], [89.16938782, 26.26251602], [89.16963959, 26.26235771], [89.1697464, 26.2622261], [89.1697998, 26.26209259], [89.16984558, 26.26199341], [89.16985321, 26.26191521], [89.16984558, 26.26180649], [89.16986084, 26.26170921], [89.1698761, 26.26157379], [89.16991425, 26.26141548], [89.16992188, 26.26124954], [89.16989136, 26.26114655], [89.16982269, 26.26098824], [89.16970062, 26.26080894], [89.16956329, 26.26069641], [89.16938782, 26.26062012], [89.16916656, 26.26059151], [89.16874695, 26.26059723], [89.16827393, 26.26065445], [89.16795349, 26.26067162], [89.16771698, 26.26072311], [89.16750336, 26.26086044], [89.16738892, 26.26104164], [89.16723633, 26.2612896], [89.16706085, 26.2614994], [89.16695404, 26.26161194], [89.16683197, 26.26169777], [89.16638947, 26.26177597], [89.16587067, 26.2618103], [89.16547394, 26.26185036], [89.16516876, 26.26185036], [89.16500092, 26.26184082], [89.16480255, 26.26182938], [89.16454315, 26.26184464], [89.16437531, 26.26194191], [89.16426086, 26.26211357], [89.16432953, 26.26223755], [89.16447449, 26.26232719], [89.16464233, 26.26239586], [89.16500854, 26.26250839], [89.16550446, 26.2625885], [89.16611481, 26.26264572], [89.16666412, 26.26269913], [89.16738129, 26.26278496], [89.1674118, 26.2629509], [89.16690826, 26.26317024], [89.16709137, 26.26332474], [89.16737366, 26.26345444], [89.16754913, 26.26353645], [89.16772461, 26.26357079], [89.16783905, 26.26358986], [89.16791534, 26.2636013], [89.16805267, 26.26369476], [89.1678009, 26.26372528], [89.16743469, 26.26377106], [89.1671524, 26.26382256], [89.16677094, 26.26395416], [89.16629791, 26.26428986], [89.16561127, 26.26490211], [89.16524506, 26.2653389], [89.1648941, 26.26584244], [89.16461945, 26.26623154], [89.1643219, 26.26657867], [89.16392517, 26.26688957], [89.1635437, 26.26700974], [89.16309357, 26.26702118], [89.16268921, 26.26697159], [89.16231537, 26.2669735], [89.16197205, 26.26693153], [89.16163635, 26.2668705], [89.16116333, 26.26682472], [89.16056061, 26.26667786], [89.15968323, 26.26650047], [89.15873718, 26.26635361], [89.15791321, 26.26635551], [89.15712738, 26.2662487], [89.15660858, 26.26616669], [89.15612793, 26.26605988], [89.15563965, 26.26603127], [89.15525818, 26.26605797], [89.15473938, 26.26617622], [89.15426636, 26.26627731], [89.15398407, 26.26634026], [89.15364075, 26.266222], [89.15341187, 26.26612854], [89.15317535, 26.26600456], [89.15306091, 26.26587868], [89.15299988, 26.26571846], [89.1529541, 26.26547623], [89.15296936, 26.26515579], [89.1530304, 26.26456833], [89.1530838, 26.26392937], [89.15309906, 26.26351357], [89.15309143, 26.26309013], [89.15305328, 26.26277924], [89.15297699, 26.26235962], [89.15288544, 26.26200867], [89.15278625, 26.26169968], [89.15268707, 26.26138496], [89.152565, 26.26112175], [89.15236664, 26.26081085], [89.15213776, 26.26046562], [89.15189362, 26.260149], [89.15171051, 26.25990486], [89.15150452, 26.25955391], [89.15125275, 26.25918961], [89.15100098, 26.25875473], [89.15078735, 26.25838852], [89.15058136, 26.25801086], [89.15042114, 26.25770187], [89.15033722, 26.25750542], [89.15022278, 26.25727844], [89.15014648, 26.25706863], [89.1500473, 26.25680542], [89.14997101, 26.256567], [89.14995575, 26.25645256], [89.14994049, 26.25623512], [89.14997101, 26.25602722], [89.15001678, 26.25579262], [89.15007782, 26.25549126], [89.1501236, 26.25524902], [89.15020752, 26.2549324], [89.15028381, 26.25462723], [89.15034485, 26.25414658], [89.15041351, 26.2536869], [89.15047455, 26.25333214], [89.15054321, 26.25300217], [89.15063477, 26.2526741], [89.15068817, 26.25242233], [89.15074158, 26.2521286], [89.15079498, 26.2519207], [89.15084076, 26.25164223], [89.15084839, 26.25140381], [89.15087128, 26.25114059], [89.15081787, 26.25081444], [89.15074158, 26.25052452], [89.15068817, 26.2502079], [89.15063477, 26.24998093], [89.15061951, 26.24979591], [89.15047455, 26.24972343], [89.15035248, 26.24974823], [89.150177, 26.24981308], [89.14994812, 26.24995613], [89.1497345, 26.25003815], [89.14962769, 26.25008392], [89.1494751, 26.25020409], [89.14935303, 26.2504406], [89.14926147, 26.25082207], [89.1492691, 26.25132751], [89.14927673, 26.25183105], [89.1492691, 26.2522316], [89.1492157, 26.2525959], [89.14911652, 26.25291634], [89.1490097, 26.25323486], [89.14891052, 26.25373459], [89.14888763, 26.2541008], [89.14889526, 26.25447655], [89.14891052, 26.25478363], [89.14889526, 26.25499725], [89.14888, 26.25510025], [89.14883423, 26.25516129], [89.14871216, 26.25514221], [89.14852142, 26.25512123], [89.14823151, 26.25504684], [89.14788055, 26.25496674], [89.14733887, 26.25487137], [89.14671326, 26.25478745], [89.14615631, 26.25478363], [89.14543915, 26.25477219], [89.14465332, 26.2548008], [89.14390564, 26.25483322], [89.14326477, 26.25486946], [89.14289856, 26.25486755], [89.14248657, 26.25491524], [89.1420517, 26.25491905], [89.14170837, 26.25490952], [89.14139557, 26.25491524], [89.14109039, 26.25493622], [89.14070892, 26.25497818], [89.14040375, 26.25505066], [89.14025879, 26.2550869], [89.14014435, 26.25519943], [89.14006042, 26.25546837], [89.13996887, 26.25584984], [89.1399231, 26.2562809], [89.13989258, 26.25693321], [89.13977051, 26.25746727], [89.13978577, 26.25797653], [89.13990784, 26.25851631], [89.14004517, 26.25900459], [89.14002991, 26.25942612], [89.1399765, 26.25986862], [89.13983917, 26.26018715], [89.13968658, 26.2604847], [89.1395874, 26.26069641], [89.13950348, 26.26092339], [89.13951874, 26.26116753], [89.13957214, 26.26146317], [89.13965607, 26.26170921], [89.13988495, 26.26212692], [89.14014435, 26.26237106], [89.14040375, 26.26255226], [89.14081573, 26.26274681], [89.14120483, 26.26283836], [89.14173126, 26.26290321], [89.14213562, 26.26268959], [89.14246368, 26.26248169], [89.14291382, 26.26228523], [89.14329529, 26.26215172], [89.14377594, 26.26198006], [89.14419556, 26.2618351], [89.1445694, 26.26171112], [89.14492035, 26.2616024], [89.14540863, 26.26145935], [89.14582062, 26.26139832], [89.14619446, 26.26138878], [89.14658356, 26.26140022], [89.14691162, 26.2615509], [89.1471405, 26.26170349], [89.1473465, 26.26190948], [89.14746857, 26.26208496], [89.14754486, 26.26226616], [89.14756775, 26.26252937], [89.14756012, 26.26287651], [89.14745331, 26.26315689], [89.14733887, 26.26342583], [89.14722443, 26.2639122], [89.1471405, 26.26429367], [89.14705658, 26.26474571], [89.1469574, 26.2651844], [89.14685822, 26.26545334], [89.14666748, 26.26562881], [89.1464386, 26.26570129], [89.14629364, 26.26579094], [89.1460495, 26.26604271], [89.14580536, 26.26626587], [89.14542389, 26.26647758], [89.14511871, 26.26651764], [89.14470673, 26.26645851], [89.14433289, 26.26639175], [89.1439209, 26.26634026], [89.14344025, 26.2663269], [89.14306641, 26.26636124], [89.14276886, 26.26643372], [89.14252472, 26.26653481], [89.14238739, 26.26665878], [89.14227295, 26.26683807], [89.14221191, 26.26700783], [89.14220428, 26.26714325], [89.1422348, 26.26733971], [89.14230347, 26.26767921], [89.14218903, 26.26815033], [89.14198303, 26.26862335], [89.14189148, 26.26909065], [89.14200592, 26.26952553], [89.14237976, 26.27026367], [89.14247894, 26.27060509], [89.14248657, 26.27090454], [89.14238739, 26.27112579], [89.14225769, 26.27116776], [89.14212799, 26.27121925], [89.14189911, 26.27139282], [89.141716, 26.27148247], [89.14148712, 26.27144051], [89.14125061, 26.27134132], [89.14100647, 26.2712059], [89.14070892, 26.2710495], [89.14026642, 26.27081299], [89.13973236, 26.27042007], [89.13941193, 26.27016258], [89.13883209, 26.26970673], [89.13842773, 26.26935768], [89.13828278, 26.26929665], [89.13794708, 26.26924133], [89.13763428, 26.26927757], [89.13746643, 26.26932144], [89.13726044, 26.26943588], [89.13708496, 26.26960564], [89.13703918, 26.26966286], [89.13697815, 26.26975822], [89.13690186, 26.2698822], [89.13680267, 26.27008247], [89.13671875, 26.27031898], [89.13660431, 26.27059555], [89.13647461, 26.27089119], [89.1363678, 26.27106285], [89.13621521, 26.27120018], [89.1360321, 26.27128792], [89.13589478, 26.27128029], [89.13580322, 26.27123833], [89.13574219, 26.27103233], [89.1357193, 26.27094841], [89.13568878, 26.27075577], [89.13570404, 26.27045441], [89.13574219, 26.27014351], [89.13582611, 26.26982307], [89.1359024, 26.26955032], [89.13604736, 26.26910973], [89.13621521, 26.26873779], [89.13640594, 26.26842117], [89.13654327, 26.26826477], [89.13667297, 26.26817513], [89.13680267, 26.26806068], [89.13693237, 26.26792145], [89.13700867, 26.26772308], [89.13706207, 26.26749611], [89.13709259, 26.26728439], [89.13708496, 26.26703453], [89.13700867, 26.26668739], [89.13681793, 26.26634216], [89.13655853, 26.2658844], [89.13629913, 26.26557159], [89.13612366, 26.26536369], [89.13586426, 26.26509666], [89.13557434, 26.26484108], [89.13529205, 26.26456833], [89.13498688, 26.26430702], [89.13472748, 26.26407051], [89.13448334, 26.26384354], [89.13425446, 26.26361084], [89.13404083, 26.26340103], [89.13388062, 26.26319122], [89.13368225, 26.26293755], [89.13353729, 26.26271629], [89.13342285, 26.26251793], [89.13337708, 26.26234818], [89.1333313, 26.26220894], [89.13331604, 26.26198769], [89.13332367, 26.26178169], [89.13335419, 26.26158714], [89.13339996, 26.26136017], [89.13348389, 26.26110649], [89.13354492, 26.26084518], [89.1336441, 26.26050186], [89.1337204, 26.26019859], [89.13379669, 26.2597332], [89.13381958, 26.25919914], [89.13386536, 26.25880241], [89.13397217, 26.25839806], [89.13409424, 26.2580471], [89.13426971, 26.25769234], [89.1344986, 26.25735664], [89.13469696, 26.25708199], [89.13485718, 26.25674629], [89.13491821, 26.25642586], [89.13500214, 26.25611305], [89.13505554, 26.25584602], [89.13510132, 26.25557518], [89.13516235, 26.25527191], [89.13518524, 26.25511169], [89.13523865, 26.25494957], [89.13529968, 26.25484657], [89.13539886, 26.2548008], [89.13558197, 26.25474167], [89.13575745, 26.25470734], [89.1359787, 26.2546463], [89.13613892, 26.25458145], [89.13628387, 26.25451851], [89.13642883, 26.25444412], [89.13655853, 26.25436401], [89.13667297, 26.25428963], [89.13676453, 26.25417519], [89.1368866, 26.25406647], [89.13700104, 26.25389481], [89.13710022, 26.25374031], [89.13717651, 26.25348854], [89.13724518, 26.25317955], [89.13732147, 26.25275421], [89.1374054, 26.25232697], [89.13748932, 26.25199699], [89.13761902, 26.2516346], [89.13774872, 26.25136375], [89.13793945, 26.25110245], [89.13811493, 26.25093651], [89.13826752, 26.25082016], [89.13851166, 26.25066566], [89.13883209, 26.25050545], [89.13893127, 26.25069046], [89.139328, 26.25062943], [89.13961029, 26.25052834], [89.13980865, 26.25044823], [89.13999176, 26.25031853], [89.14016724, 26.25021362], [89.14035797, 26.25008392], [89.14056396, 26.24993896], [89.14073181, 26.24977112], [89.1410141, 26.24952698], [89.14129639, 26.24921608], [89.14157867, 26.24893761], [89.14177704, 26.2488327], [89.14191437, 26.24881554], [89.14215088, 26.24903679], [89.14237976, 26.24929428], [89.14252472, 26.24945068], [89.14266968, 26.24951172], [89.14280701, 26.24950218], [89.1428833, 26.24946594], [89.14306641, 26.24937057], [89.14317322, 26.24927521], [89.14325714, 26.24924469], [89.14344788, 26.2493], [89.14358521, 26.24935722], [89.14369965, 26.2493763], [89.14382935, 26.24936104], [89.14394379, 26.24931526], [89.1441803, 26.24919891], [89.14437866, 26.24904442], [89.14458466, 26.24888611], [89.14476013, 26.24868584], [89.14491272, 26.24853706], [89.14500427, 26.24840736], [89.14511871, 26.24825096], [89.14522552, 26.2480793], [89.14539337, 26.24778748], [89.14553833, 26.24750137], [89.14564514, 26.2472496], [89.14575195, 26.24696541], [89.14585876, 26.24668503], [89.14595032, 26.24630928], [89.14599609, 26.24589729], [89.14596558, 26.24551392], [89.14591217, 26.24507332], [89.14582825, 26.24450493], [89.14572144, 26.24422646], [89.14561462, 26.24383736], [89.14552307, 26.24363136], [89.14537811, 26.24344254], [89.14524078, 26.24328995], [89.14512634, 26.24310875], [89.1450119, 26.24301147], [89.14488983, 26.24287796], [89.14472198, 26.24276733], [89.14455414, 26.2426796], [89.1443634, 26.24265099], [89.14414215, 26.2426033], [89.14395142, 26.24250984], [89.14385223, 26.24245834], [89.1437149, 26.24238968], [89.14349365, 26.24230385], [89.14339447, 26.24227905], [89.14324951, 26.24226379], [89.14315796, 26.24228096], [89.14299774, 26.24228096], [89.14281464, 26.24230003], [89.14269257, 26.24232292], [89.14259338, 26.24233246], [89.1425705, 26.24215126], [89.14257813, 26.24196053], [89.14259338, 26.24179459], [89.14270782, 26.24178505], [89.14286804, 26.24161339], [89.14307404, 26.24152756], [89.14334869, 26.24150467], [89.14367676, 26.24151421], [89.14408112, 26.24149704], [89.14437103, 26.24147034], [89.14478302, 26.24136734], [89.14513397, 26.24124718], [89.14536285, 26.24117851], [89.14556122, 26.24110222], [89.14562988, 26.24103355], [89.14556885, 26.24096298], [89.145401, 26.24089241], [89.14524841, 26.24080658], [89.14523315, 26.2406559], [89.14551544, 26.24039078], [89.14587402, 26.24011993], [89.1462326, 26.23982048], [89.14667511, 26.23950958], [89.14705658, 26.23928642], [89.14754486, 26.23907089], [89.14797211, 26.23886108], [89.14849854, 26.2386055], [89.14904785, 26.23834419], [89.1494751, 26.23818016], [89.14985657, 26.23806381], [89.150177, 26.23797417], [89.15045929, 26.23790741], [89.15073395, 26.23784256], [89.15109253, 26.23779106], [89.15126801, 26.23776817], [89.15154266, 26.23777771], [89.15175629, 26.23773766], [89.15201569, 26.2376194], [89.15229034, 26.23746872], [89.15250397, 26.23730278], [89.15263367, 26.23717308], [89.1526947, 26.23706055], [89.15274811, 26.23693848], [89.15293121, 26.23682976], [89.15313721, 26.23679733], [89.15332794, 26.23677826], [89.15365601, 26.23674774], [89.15390778, 26.23675919], [89.15406036, 26.2367897], [89.15418243, 26.23685646], [89.15434265, 26.23698425], [89.15454865, 26.23720169], [89.15484619, 26.23742294], [89.15509796, 26.23756981], [89.15538788, 26.23766327], [89.15570068, 26.23773003], [89.15611267, 26.23779297], [89.15639496, 26.23786354], [89.15635681, 26.23794556], [89.15639496, 26.23803902], [89.15645599, 26.23810387], [89.15647125, 26.23817825], [89.15648651, 26.2383194], [89.15647125, 26.23852348], [89.15644836, 26.23877335], [89.15639496, 26.23902893], [89.15633392, 26.23935509], [89.15627289, 26.23976135], [89.15621185, 26.24019814], [89.15618896, 26.24069595], [89.15615845, 26.24103737], [89.15609741, 26.24146271], [89.15606689, 26.24178123], [89.1561203, 26.24222374], [89.15624237, 26.2426815], [89.15641022, 26.24330139], [89.15651703, 26.24372864], [89.15657043, 26.24405289], [89.15653992, 26.2442894], [89.15649414, 26.24441338], [89.15644836, 26.24448013], [89.15635681, 26.24454117], [89.15618896, 26.24458504], [89.15591431, 26.24463844], [89.1556015, 26.24467659], [89.15535736, 26.24474144], [89.15509033, 26.24474144], [89.1548996, 26.24473763], [89.15473175, 26.2447567], [89.15460968, 26.24478149], [89.15449524, 26.24479294], [89.15426636, 26.24477768], [89.15390015, 26.24472618], [89.15357208, 26.24466705], [89.15329742, 26.24460983], [89.15311432, 26.24458885], [89.1529541, 26.2445755], [89.152771, 26.24458313], [89.15262604, 26.24458122], [89.1525116, 26.24460411], [89.15240479, 26.24470901], [89.15242767, 26.24494553], [89.15252686, 26.24537659], [89.15258789, 26.24563408], [89.15264893, 26.24582481], [89.15274048, 26.24596405], [89.15287018, 26.2460556], [89.15304565, 26.24608231], [89.15336609, 26.24607658], [89.15367889, 26.24603844], [89.15389252, 26.2460041], [89.15418243, 26.24601555], [89.15440369, 26.24608612], [89.15467072, 26.24622726], [89.15492249, 26.24634552], [89.15514374, 26.24643517], [89.15541077, 26.24653435], [89.15563202, 26.24658966], [89.15592194, 26.24662781], [89.15616608, 26.24668694], [89.15628815, 26.24671745], [89.15644836, 26.2468071], [89.15657043, 26.24688148], [89.15664673, 26.24697685], [89.15670776, 26.24709892], [89.15673828, 26.24726677], [89.15679169, 26.24746513], [89.15679932, 26.24774361], [89.15674591, 26.24804306], [89.15664673, 26.24839211], [89.15650177, 26.24876976], [89.15637207, 26.24907112], [89.15631104, 26.24938202], [89.15628815, 26.24958611], [89.15631866, 26.24971199], [89.15637207, 26.24987411], [89.15648651, 26.25], [89.15658569, 26.25008583], [89.15673828, 26.2501564], [89.15694427, 26.25020409], [89.15731049, 26.2502346], [89.15776062, 26.25031853], [89.15809631, 26.25039864], [89.15844727, 26.25046921], [89.15877533, 26.2505722], [89.15908813, 26.25067711], [89.15929413, 26.25072479], [89.15950775, 26.25075722], [89.15964508, 26.25077248], [89.15975952, 26.2507534], [89.15991211, 26.25061989], [89.1600647, 26.25033188], [89.16015625, 26.25016594], [89.1602478, 26.25005722], [89.1603775, 26.24995232], [89.16055298, 26.24990273], [89.16065979, 26.24985886], [89.16077423, 26.24971962], [89.16085052, 26.24958801], [89.1609726, 26.24921799], [89.16118622, 26.24878883], [89.16132355, 26.24840736], [89.1614151, 26.24811554], [89.16146088, 26.24787521], [89.16144562, 26.24757576], [89.16138458, 26.24739075], [89.16127777, 26.24723816], [89.16100311, 26.24711227], [89.16074371, 26.24714279], [89.16048431, 26.24717522], [89.16030884, 26.24720955], [89.16020203, 26.24712944], [89.16017151, 26.24692535], [89.16018677, 26.24655151], [89.16026306, 26.24628639], [89.16040039, 26.24599266], [89.16059113, 26.24565887], [89.16086578, 26.24536133], [89.16103363, 26.24513054], [89.1611557, 26.24495316], [89.16127014, 26.24465942], [89.16130829, 26.24442482], [89.16131592, 26.24418831], [89.16130829, 26.24396133], [89.16130829, 26.2437973], [89.16125488, 26.24359703], [89.16124725, 26.2433567], [89.16127777, 26.24313736], [89.16133881, 26.24287033], [89.16138458, 26.24259377], [89.16142273, 26.24235725], [89.16146088, 26.24221611], [89.16149139, 26.24212265], [89.16153717, 26.24198151], [89.16165924, 26.24183273], [89.16182709, 26.24173546], [89.16195679, 26.24171638], [89.16218567, 26.2417469], [89.16236877, 26.24181366], [89.16253662, 26.2418766], [89.1627121, 26.24188995], [89.16285706, 26.24188423], [89.16297913, 26.24186516], [89.1631012, 26.2417202], [89.16316986, 26.24134827], [89.16320801, 26.24103165], [89.16321564, 26.24073601], [89.1632309, 26.24037361], [89.16321564, 26.23993111], [89.16317749, 26.23949242], [89.1631546, 26.23932457], [89.16313171, 26.23919678], [89.16305542, 26.23895264], [89.16293335, 26.23890686], [89.16277313, 26.23888779], [89.16255951, 26.2388382], [89.16239166, 26.23875809], [89.16227722, 26.2386322], [89.16213226, 26.23839951], [89.16205597, 26.23822784], [89.16197968, 26.23800659], [89.16194153, 26.23781776], [89.16191864, 26.23760033], [89.16190338, 26.2374115], [89.16184235, 26.23727608], [89.16173553, 26.2372303], [89.16159821, 26.23720741], [89.16139984, 26.23718643], [89.16120911, 26.23707581], [89.16107941, 26.2369442], [89.16095734, 26.23683548], [89.16086578, 26.23673058], [89.16075134, 26.23659897], [89.1606369, 26.23649025], [89.16052246, 26.23645973], [89.16040039, 26.23648262], [89.16025543, 26.2365284], [89.16004944, 26.23665237], [89.15982056, 26.23685074], [89.15957642, 26.23717499], [89.15946198, 26.23733139], [89.15931702, 26.23739815], [89.15899658, 26.23740196], [89.15875244, 26.23732948], [89.15847015, 26.23717499], [89.15827179, 26.23700905], [89.15808868, 26.23680305], [89.15802002, 26.23669052], [89.1579895, 26.23658371], [89.1579895, 26.23639107], [89.1579895, 26.23610306], [89.1579895, 26.23580551], [89.15795898, 26.23552895], [89.15791321, 26.23534966], [89.15784454, 26.23508644], [89.15782166, 26.23494148], [89.1578064, 26.23477364], [89.15783691, 26.23467064], [89.15784454, 26.23456764], [89.15792084, 26.2345047], [89.15807343, 26.2344017], [89.15824127, 26.23433304], [89.15840149, 26.23428535], [89.15860748, 26.23426628], [89.15888214, 26.23426628], [89.15919495, 26.23425674], [89.15951538, 26.23424911]], [[89.18089294, 26.24517059], [89.18081665, 26.2452774], [89.18071747, 26.24533463], [89.18054962, 26.24537849], [89.18032837, 26.24538231], [89.18008423, 26.24535751], [89.17990112, 26.24532127], [89.17964172, 26.24524498], [89.17935181, 26.24514008], [89.17905426, 26.24502563], [89.17875671, 26.24492645], [89.17823029, 26.24492073], [89.17786407, 26.24490547], [89.17771912, 26.24482727], [89.17762756, 26.24474907], [89.17759705, 26.24466324], [89.17758179, 26.24432755], [89.17758179, 26.24395752], [89.17756653, 26.2435894], [89.17756653, 26.24339294], [89.17760468, 26.2432785], [89.17794037, 26.24334526], [89.17807007, 26.24334526], [89.17817688, 26.24328613], [89.17811584, 26.24310112], [89.17794037, 26.24261856], [89.17778778, 26.24223328], [89.17765045, 26.24172592], [89.1776123, 26.24150276], [89.17772675, 26.24110603], [89.17787933, 26.24097824], [89.17812347, 26.24087143], [89.17847443, 26.240839], [89.17877197, 26.2407074], [89.17908478, 26.24051857], [89.1794281, 26.24030876], [89.17956543, 26.24016762], [89.17970276, 26.23995209], [89.17982483, 26.23973846], [89.17993164, 26.23957253], [89.18003845, 26.2394619], [89.18010712, 26.23939133], [89.18016052, 26.23933411], [89.18026733, 26.23929977], [89.18039703, 26.23929405], [89.18067932, 26.23939896], [89.18100739, 26.23957825], [89.18132782, 26.23986626], [89.18164063, 26.24025345], [89.18196106, 26.24073029], [89.18225098, 26.24116516], [89.18258667, 26.2415905], [89.1829071, 26.24191856], [89.1831131, 26.24209404], [89.18319702, 26.24216461], [89.18327332, 26.24232101], [89.18338013, 26.24251366], [89.18351746, 26.24268723], [89.18377686, 26.242939], [89.1840744, 26.24311066], [89.18440247, 26.24317932], [89.18476105, 26.24312973], [89.18505859, 26.24305534], [89.18538666, 26.24295235], [89.18566132, 26.24287415], [89.1860199, 26.2428093], [89.18639374, 26.24277496], [89.18666077, 26.24280739], [89.18688965, 26.24285316], [89.18701935, 26.24293709], [89.18711853, 26.24300194], [89.18719482, 26.24310303], [89.18723297, 26.24319839], [89.18717957, 26.2434082], [89.1870575, 26.24364853], [89.18690491, 26.24378395], [89.18665314, 26.24389076], [89.18625641, 26.24409866], [89.18587494, 26.24438477], [89.18539429, 26.24471855], [89.18490601, 26.24482536], [89.18422699, 26.24484062], [89.18363953, 26.2449646], [89.1832428, 26.24502754], [89.18286896, 26.24507713], [89.18253326, 26.24513054], [89.18223572, 26.24515533], [89.18192291, 26.24515915], [89.18164825, 26.24517441], [89.1812973, 26.24517441], [89.18102264, 26.24516869], [89.18089294, 26.24517059]], [[89.2403717, 26.11173248], [89.23984528, 26.11161995], [89.23996735, 26.11141396], [89.2403717, 26.11173248]], [[89.07595825, 26.40121269], [89.07566071, 26.40138245], [89.07542419, 26.40153885], [89.07522583, 26.40176201], [89.07511902, 26.401968], [89.07509613, 26.40215302], [89.07515717, 26.40237999], [89.07531738, 26.40263557], [89.07549286, 26.40296745], [89.07563782, 26.40325928], [89.07575226, 26.40366745], [89.07578278, 26.40397263], [89.07572937, 26.40435219], [89.07568359, 26.40465164], [89.07558441, 26.40499878], [89.07545471, 26.40528488], [89.07533264, 26.4054184], [89.07518768, 26.40553474], [89.07509613, 26.40557671], [89.07496643, 26.40556908], [89.07478333, 26.40545845], [89.07446289, 26.40526199], [89.07423401, 26.4051609], [89.07395935, 26.40493202], [89.07371521, 26.40470505], [89.07347107, 26.40446472], [89.07326508, 26.40426254], [89.07306671, 26.40403748], [89.0728302, 26.4038105], [89.07260132, 26.40356445], [89.07245636, 26.40340424], [89.07241821, 26.40331459], [89.07239532, 26.40314674], [89.07236481, 26.40285492], [89.07233429, 26.40242004], [89.07231903, 26.40202904], [89.07231903, 26.40180588], [89.07232666, 26.40158272], [89.0723877, 26.40131378], [89.07241058, 26.40116119], [89.07247162, 26.40108871], [89.07267761, 26.40099144], [89.07300568, 26.4009552], [89.0734787, 26.40095139], [89.07389069, 26.40098572], [89.07435608, 26.40103722], [89.07463837, 26.4010582], [89.07486725, 26.40104103], [89.07504272, 26.40098763], [89.07524872, 26.40090561], [89.07551575, 26.40080261], [89.07567596, 26.40075874], [89.07579041, 26.40074158], [89.07589722, 26.40097237], [89.07595825, 26.40121269]], [[89.05809021, 26.40118599], [89.05822754, 26.4014492], [89.05841827, 26.40195847], [89.05861664, 26.40228462], [89.05887604, 26.4026165], [89.05902863, 26.40286636], [89.05923462, 26.40311623], [89.05931091, 26.40338898], [89.05934143, 26.4036274], [89.05934906, 26.40385437], [89.05931854, 26.40405464], [89.05925751, 26.40425491], [89.0590744, 26.40443611], [89.05891418, 26.40455818], [89.05858612, 26.40483475], [89.0582962, 26.40511703], [89.0579834, 26.40541267], [89.05775452, 26.40567589], [89.05757904, 26.40587234], [89.05738068, 26.40613174], [89.05712891, 26.40643883], [89.05682373, 26.40680504], [89.05653381, 26.40717888], [89.05635071, 26.40740776], [89.05621338, 26.40760803], [89.05607605, 26.4078083], [89.05596161, 26.40794754], [89.05576324, 26.40793419], [89.05531311, 26.40779495], [89.05487823, 26.4076519], [89.05435181, 26.40754128], [89.05416107, 26.40753174], [89.05467224, 26.40527725], [89.05472565, 26.4050045], [89.05477142, 26.40455246], [89.05485535, 26.40410805], [89.05500031, 26.40372658], [89.05522156, 26.40320206], [89.05542755, 26.40276527], [89.05561066, 26.40231895], [89.05574036, 26.40194893], [89.05584717, 26.40172768], [89.05594635, 26.40155029], [89.05602264, 26.40144348], [89.05609131, 26.40136337], [89.05620575, 26.40135765], [89.05638885, 26.40134811], [89.056633, 26.40133667], [89.05696106, 26.40129471], [89.05724335, 26.4012413], [89.05758667, 26.40116119], [89.05789185, 26.40109062], [89.05802917, 26.4010582], [89.05809021, 26.40118599]], [[89.12859344, 26.32184982], [89.1269989, 26.32085991], [89.12661743, 26.32070541], [89.12715149, 26.3205471], [89.12892914, 26.32077789], [89.1295929, 26.32058334], [89.12957764, 26.32076645], [89.12953949, 26.32109642], [89.12866211, 26.32105064], [89.12859344, 26.32184982]], [[89.13018036, 26.29277039], [89.12987518, 26.2929039], [89.12979889, 26.29293823], [89.12968445, 26.2928791], [89.12953186, 26.29278946], [89.12937164, 26.29264832], [89.1292572, 26.29254532], [89.1292038, 26.29244614], [89.12918091, 26.29231453], [89.12924957, 26.29210281], [89.1293335, 26.29192543], [89.12943268, 26.29178619], [89.12961578, 26.29162216], [89.12988281, 26.29139328], [89.13006592, 26.29123306], [89.13018799, 26.29113579], [89.13032532, 26.2910614], [89.13041687, 26.29101753], [89.13059998, 26.29093933], [89.13079071, 26.29093742], [89.13105774, 26.29099083], [89.13136292, 26.29105568], [89.13159943, 26.29115105], [89.13168335, 26.29123497], [89.1317749, 26.2913723], [89.13185883, 26.29168129], [89.13188171, 26.29191208], [89.13184357, 26.29217148], [89.13179779, 26.29240036], [89.13167572, 26.2926445], [89.13160706, 26.29272842], [89.13130188, 26.29282761], [89.131073, 26.29285431], [89.13082123, 26.29281616], [89.13064575, 26.29278946], [89.13052368, 26.29275322], [89.13038635, 26.29273224], [89.13018036, 26.29277039]], [[89.11239624, 26.27619171], [89.11261749, 26.2762928], [89.11281586, 26.2764473], [89.11301422, 26.27664375], [89.11325073, 26.27691078], [89.11347198, 26.27719498], [89.11371613, 26.27750397], [89.11380005, 26.27761078], [89.11351013, 26.27791977], [89.11377716, 26.27955818], [89.11405182, 26.28053093], [89.11406708, 26.28161049], [89.11395264, 26.28228951], [89.11363983, 26.28297997], [89.11237335, 26.28233528], [89.11239624, 26.28203583], [89.11239624, 26.28165817], [89.11237335, 26.28130531], [89.11235046, 26.28107262], [89.11240387, 26.28077698], [89.1124649, 26.28064728], [89.11252594, 26.28055191], [89.11261749, 26.28039169], [89.11270142, 26.28014183], [89.11274719, 26.27989578], [89.11271667, 26.27960968], [89.11265564, 26.27940369], [89.11251068, 26.27911186], [89.11233521, 26.27889252], [89.11212921, 26.27867699], [89.11190796, 26.27843094], [89.11180878, 26.27825737], [89.11170959, 26.27794838], [89.11167908, 26.27766991], [89.11164856, 26.27729225], [89.11166382, 26.27687454], [89.11170197, 26.27655792], [89.11180115, 26.276371], [89.11195374, 26.27624512], [89.11217499, 26.2761898], [89.11239624, 26.27619171]], [[89.10921478, 26.30457115], [89.11055756, 26.30461311], [89.11009979, 26.30492973], [89.10903168, 26.3065834], [89.10897064, 26.30644226], [89.10903931, 26.30456734], [89.10921478, 26.30457115]], [[89.11437988, 26.29961967], [89.11508942, 26.30080032], [89.11509705, 26.30250168], [89.11408997, 26.30283165], [89.11391449, 26.30126762], [89.11383057, 26.30092812], [89.11380005, 26.29903412], [89.11437988, 26.29961967]], [[89.13286591, 26.29480362], [89.13321686, 26.29485321], [89.13354492, 26.29494858], [89.13381958, 26.29504395], [89.13399506, 26.29514313], [89.13409424, 26.29520798], [89.13427734, 26.29541206], [89.13443756, 26.29554939], [89.13461304, 26.29564095], [89.13479614, 26.29567337], [89.13491821, 26.29579544], [89.1348877, 26.29613304], [89.13486481, 26.2965374], [89.13482666, 26.29686165], [89.13478851, 26.29707909], [89.134758, 26.29725266], [89.1346817, 26.29749107], [89.13458252, 26.29778481], [89.13450623, 26.2979641], [89.13394928, 26.2978363], [89.13376617, 26.2977829], [89.13352203, 26.29769707], [89.13323975, 26.2975769], [89.13293457, 26.29745865], [89.1326828, 26.29737473], [89.13248444, 26.29732513], [89.13218689, 26.29726028], [89.13188171, 26.29714584], [89.13154602, 26.2970295], [89.1312561, 26.29692078], [89.13106537, 26.29684258], [89.13097382, 26.29671288], [89.13097382, 26.29647636], [89.13101196, 26.29617882], [89.13105011, 26.29587746], [89.13108063, 26.29569435], [89.13114166, 26.29546547], [89.13117981, 26.2953167], [89.13126373, 26.29515457], [89.13140106, 26.29497337], [89.1315155, 26.29488182], [89.1316452, 26.29483223], [89.13183594, 26.29480171], [89.13202667, 26.29478836], [89.13227844, 26.29477692], [89.13260651, 26.29476166], [89.13286591, 26.29480362]], [[89.01126099, 26.26631546], [89.01076508, 26.26660347], [89.01023102, 26.26689529], [89.0098114, 26.26710892], [89.00939178, 26.26730537], [89.00907135, 26.26745224], [89.00891876, 26.26750565], [89.00880432, 26.2674675], [89.00868988, 26.26737976], [89.00862122, 26.26727867], [89.00852966, 26.26700783], [89.00844574, 26.26684952], [89.00831604, 26.2666893], [89.00814056, 26.26654434], [89.00794983, 26.26642227], [89.00773621, 26.26633835], [89.00747681, 26.26623154], [89.00714874, 26.26614189], [89.00678253, 26.26607704], [89.00637817, 26.26603317], [89.00596619, 26.26600266], [89.00559998, 26.26592445], [89.00522614, 26.26582146], [89.00495911, 26.26572418], [89.00478363, 26.26565552], [89.00458527, 26.26556396], [89.00445557, 26.26547432], [89.00428772, 26.2652359], [89.00426483, 26.26504326], [89.00430298, 26.26488686], [89.0045166, 26.26478386], [89.00495911, 26.26472473], [89.00528717, 26.26466942], [89.00556183, 26.26457214], [89.00569916, 26.26435852], [89.00576782, 26.26411629], [89.00575256, 26.26373291], [89.00571442, 26.26334763], [89.00559998, 26.26284218], [89.0054245, 26.26232529], [89.0052948, 26.26189995], [89.00514984, 26.26138306], [89.00506592, 26.26090622], [89.00500488, 26.26024437], [89.00497437, 26.25959206], [89.00494385, 26.25894165], [89.00495148, 26.25828552], [89.00498199, 26.25779152], [89.00500488, 26.25720406], [89.00509644, 26.25680542], [89.00512695, 26.2565937], [89.00511169, 26.25649261], [89.00505829, 26.25640678], [89.00498962, 26.25629044], [89.00492096, 26.25613213], [89.00487518, 26.25601768], [89.004776, 26.25591278], [89.0045929, 26.25581932], [89.00450897, 26.25580215], [89.00427246, 26.25570297], [89.00404358, 26.25559807], [89.00387573, 26.25560379], [89.00361633, 26.25558853], [89.00334167, 26.25556183], [89.00318909, 26.25563812], [89.00331116, 26.25610733], [89.00331879, 26.25689507], [89.00330353, 26.25762558], [89.0032196, 26.25854874], [89.00317383, 26.25952721], [89.00320435, 26.26033783], [89.00337219, 26.26105881], [89.00366974, 26.26187515], [89.0038681, 26.26249886], [89.00398254, 26.26297379], [89.00399017, 26.2633419], [89.00392914, 26.26359749], [89.0038147, 26.26382637], [89.00358582, 26.26406097], [89.00309753, 26.26394463], [89.00259399, 26.26371384], [89.00209808, 26.26349449], [89.00179291, 26.26340485], [89.00151825, 26.26333809], [89.00131989, 26.26330376], [89.00110626, 26.26315498], [89.00081635, 26.26278877], [89.00051117, 26.26241684], [89.00021362, 26.26208496], [89.0, 26.26178169], [88.99982452, 26.26148033], [88.99966431, 26.26094055], [88.99970245, 26.26041222], [88.99983215, 26.25991631], [89.00001526, 26.25959396], [89.00016785, 26.25933838], [89.00036621, 26.2588253], [89.00053406, 26.25834084], [89.00069427, 26.25773621], [89.00070953, 26.257267], [89.00057983, 26.25687408], [88.99992371, 26.256464], [88.99971771, 26.25628471], [88.99942017, 26.25608063], [88.9991684, 26.25595093], [88.99893951, 26.25581741], [88.99871826, 26.2556839], [88.9985199, 26.25559235], [88.99836731, 26.25547409], [88.99815369, 26.25521851], [88.99808502, 26.25511169], [88.99803925, 26.25491714], [88.99803925, 26.25465393], [88.99808502, 26.25438118], [88.9981842, 26.2540741], [88.9983139, 26.2537365], [88.99856567, 26.25334549], [88.99886322, 26.25296974], [88.99916077, 26.25271797], [88.99956512, 26.25248146], [89.00005341, 26.25224113], [89.00043488, 26.25209236], [89.00085449, 26.2519455], [89.00123596, 26.25178719], [89.0015564, 26.25160027], [89.00208282, 26.25130653], [89.00270081, 26.2509861], [89.00345612, 26.25060463], [89.00415802, 26.25029945], [89.0046463, 26.25015068], [89.0051651, 26.25001717], [89.00556183, 26.24990845], [89.00571442, 26.24986839], [89.00576019, 26.25001335], [89.00579834, 26.25059319], [89.00585175, 26.25165558], [89.00588226, 26.25241089], [89.00584412, 26.25280762], [89.005867, 26.25336838], [89.00585175, 26.25365829], [89.00588226, 26.25376129], [89.00598907, 26.25391769], [89.00610352, 26.25404549], [89.00621796, 26.25413704], [89.00641632, 26.25415039], [89.0066452, 26.25414276], [89.00698853, 26.25416374], [89.00721741, 26.25419426], [89.00728607, 26.25429153], [89.00732422, 26.25473976], [89.00731659, 26.25514412], [89.00727844, 26.25562477], [89.00736237, 26.25594711], [89.0075531, 26.25637817], [89.00763702, 26.25671768], [89.00778961, 26.25703621], [89.00801849, 26.25732613], [89.00823975, 26.25756073], [89.00850677, 26.25772285], [89.00873566, 26.2578125], [89.00898743, 26.25784302], [89.00926208, 26.25782204], [89.009552, 26.25780869], [89.0098114, 26.25781059], [89.01015472, 26.25787163], [89.01052094, 26.25792885], [89.01083374, 26.25805092], [89.01101685, 26.25813675], [89.01118469, 26.25824356], [89.01130676, 26.25836372], [89.01136017, 26.25855446], [89.01133728, 26.25890732], [89.01124573, 26.25930405], [89.01118469, 26.25963783], [89.01111603, 26.25999641], [89.01105499, 26.26044655], [89.01105499, 26.26086044], [89.01111603, 26.26124191], [89.01118469, 26.26144409], [89.01131439, 26.26160049], [89.0116272, 26.26184082], [89.01194, 26.2619915], [89.0121994, 26.26206398], [89.01242828, 26.26207733], [89.01261139, 26.26211739], [89.01281738, 26.26216125], [89.01298523, 26.26229286], [89.01325226, 26.26246834], [89.01360321, 26.26269531], [89.01389313, 26.26299095], [89.01406097, 26.2632637], [89.01424408, 26.26354218], [89.01441193, 26.26392365], [89.014534, 26.26433182], [89.01460266, 26.26477242], [89.01464844, 26.26522064], [89.01462555, 26.26562309], [89.01460266, 26.26574135], [89.014328, 26.26578522], [89.01383972, 26.26578712], [89.01311493, 26.26570892], [89.01251221, 26.26576424], [89.01186371, 26.26601028], [89.01126099, 26.26631546]], [[89.02735901, 26.27350235], [89.02719879, 26.2735405], [89.02703094, 26.27352333], [89.02687836, 26.27341843], [89.02667236, 26.27328682], [89.02648926, 26.27319336], [89.02625275, 26.27318954], [89.02604675, 26.27327156], [89.02584839, 26.27335167], [89.02571869, 26.27332497], [89.02558136, 26.27323914], [89.02542877, 26.27307701], [89.02526093, 26.27285385], [89.02513123, 26.27267265], [89.02503204, 26.2725544], [89.02490997, 26.27243233], [89.02474213, 26.27233696], [89.02440643, 26.27227592], [89.0240097, 26.27217102], [89.02354431, 26.2719841], [89.02326202, 26.2718811], [89.02302551, 26.27175903], [89.02268982, 26.27149391], [89.02243805, 26.27129555], [89.02236176, 26.27119446], [89.0223999, 26.27107048], [89.0224762, 26.27096176], [89.02266693, 26.27082634], [89.02282715, 26.27072525], [89.02311707, 26.27055359], [89.02345276, 26.27033424], [89.02371979, 26.27013588], [89.02397919, 26.26991653], [89.02414703, 26.2697506], [89.02427673, 26.26958656], [89.02439117, 26.26939964], [89.02442169, 26.26911736], [89.02445984, 26.2687912], [89.02445984, 26.26852989], [89.02437592, 26.26815796], [89.02422333, 26.26782036], [89.02405548, 26.26760292], [89.02385712, 26.2673645], [89.02375793, 26.26720428], [89.02367401, 26.26694489], [89.02366638, 26.26661301], [89.02374268, 26.26628304], [89.02388763, 26.26599503], [89.02405548, 26.26579666], [89.0242157, 26.26566887], [89.02445984, 26.26555443], [89.02475739, 26.26554298], [89.02516174, 26.26562691], [89.02555847, 26.26575851], [89.02575684, 26.26581573], [89.02597046, 26.26586151], [89.02610779, 26.26587677], [89.02629852, 26.26582718], [89.0265274, 26.26574326], [89.02671051, 26.26564598], [89.02690125, 26.26548004], [89.02706146, 26.26531982], [89.02714539, 26.26516914], [89.02719116, 26.26499748], [89.02719879, 26.26478767], [89.0271759, 26.2645874], [89.02707672, 26.26422119], [89.02693176, 26.26387787], [89.02690887, 26.26371956], [89.02696228, 26.26355362], [89.0271225, 26.26333618], [89.02740479, 26.26306534], [89.02767181, 26.26275826], [89.02798462, 26.26240921], [89.02817535, 26.26208878], [89.02828217, 26.26166344], [89.02838135, 26.26128006], [89.02844238, 26.26089287], [89.02850342, 26.26037216], [89.02855682, 26.25984383], [89.02857208, 26.25941277], [89.02854156, 26.25876045], [89.02849579, 26.25834274], [89.02851105, 26.25801277], [89.02859497, 26.25763702], [89.02872467, 26.25733948], [89.02884674, 26.2571907], [89.02897644, 26.25708961], [89.0292511, 26.25693893], [89.02966309, 26.25677872], [89.03002167, 26.25672913], [89.03029633, 26.25676155], [89.03052521, 26.25678444], [89.03069305, 26.25684738], [89.03086853, 26.25691032], [89.03108215, 26.25695229], [89.03121185, 26.25695038], [89.03144836, 26.25678444], [89.03160095, 26.2566452], [89.03187561, 26.25642395], [89.03213501, 26.25627136], [89.03237915, 26.25622368], [89.03284454, 26.25630379], [89.0332489, 26.25655174], [89.03353882, 26.25681305], [89.03376007, 26.25704956], [89.03393555, 26.25725555], [89.03404999, 26.25738335], [89.03421783, 26.25741959], [89.03440094, 26.25743484], [89.0345993, 26.2576046], [89.03475189, 26.25787926], [89.03481293, 26.2582531], [89.03486633, 26.25873375], [89.03494263, 26.25912285], [89.0350647, 26.25953674], [89.03520203, 26.25997734], [89.03543091, 26.26035118], [89.03562927, 26.26064491], [89.03591919, 26.26103592], [89.03612518, 26.26126099], [89.03622437, 26.26132584], [89.03632355, 26.26137733], [89.03643799, 26.26145554], [89.03649902, 26.26160622], [89.03651428, 26.2618084], [89.0364151, 26.26210213], [89.0362854, 26.26238441], [89.03620911, 26.2625618], [89.0361557, 26.26284409], [89.03619385, 26.26312637], [89.03630829, 26.2634201], [89.03653717, 26.26381302], [89.03670502, 26.26406479], [89.03678894, 26.26428032], [89.03664398, 26.26441574], [89.03633118, 26.26454163], [89.03579712, 26.2646637], [89.03534698, 26.26473427], [89.0349884, 26.26482201], [89.03453064, 26.26493454], [89.03408051, 26.26506424], [89.03351593, 26.26524544], [89.0331955, 26.26535606], [89.0329361, 26.26550102], [89.0327301, 26.26570892], [89.03266907, 26.2660141], [89.03266144, 26.26646614], [89.03265381, 26.26683998], [89.03269196, 26.26710892], [89.03273773, 26.26720047], [89.03303528, 26.2673111], [89.03346252, 26.26743889], [89.03372955, 26.26756668], [89.03384399, 26.26774788], [89.03387451, 26.26801682], [89.03386688, 26.26825905], [89.03381348, 26.26847458], [89.03372955, 26.26869202], [89.03359222, 26.26894951], [89.03343201, 26.26916885], [89.03329468, 26.26937294], [89.03307343, 26.2695961], [89.0328598, 26.26973915], [89.03266907, 26.269804], [89.03237152, 26.26986122], [89.03211975, 26.2699337], [89.03189087, 26.27018356], [89.03150177, 26.27050781], [89.03109741, 26.27083397], [89.03062439, 26.27121544], [89.03011322, 26.27158737], [89.02971649, 26.27192307], [89.02937317, 26.27218437], [89.02890778, 26.27252769], [89.02850342, 26.27279472], [89.02806854, 26.27310753], [89.02773285, 26.27332497], [89.02746582, 26.27347565], [89.02735901, 26.27350235]], [[89.04797363, 26.24597168], [89.04794312, 26.24580193], [89.0482254, 26.24575615], [89.04797363, 26.24597168]], [[88.92779541, 26.33548546], [88.92708588, 26.33567047], [88.92395782, 26.33536339], [88.92230225, 26.33554268], [88.92132568, 26.33552551], [88.9213562, 26.33524704], [88.92153931, 26.33317947], [88.92157745, 26.33113289], [88.92173004, 26.32966995], [88.92261505, 26.32975769], [88.92384338, 26.32754517], [88.92313385, 26.32710648], [88.92333221, 26.32669067], [88.92107391, 26.3263588], [88.91925049, 26.32598495], [88.91871643, 26.32583046], [88.91812134, 26.32565689], [88.91895294, 26.32448387], [88.92010498, 26.32285118], [88.92218781, 26.31995392], [88.92253113, 26.32006264], [88.9226532, 26.31978798], [88.92237854, 26.31971169], [88.92373657, 26.31822395], [88.92539978, 26.31868172], [88.92549896, 26.31760216], [88.9261322, 26.31666374], [88.92684937, 26.31632996], [88.92618561, 26.31593704], [88.9260025, 26.31612206], [88.92453003, 26.31560516], [88.92321014, 26.31522751], [88.92417145, 26.31362724], [88.92491913, 26.31385994], [88.92530823, 26.31341362], [88.92642975, 26.31208038], [88.92745209, 26.31097412], [88.92874146, 26.31095314], [88.92961884, 26.30930138], [88.93070984, 26.30741882], [88.93093872, 26.30544472], [88.93061829, 26.30406952], [88.9267807, 26.30227089], [88.92456055, 26.30010605], [88.92428589, 26.29953957], [88.92350769, 26.29794502], [88.92365265, 26.29606247], [88.92515564, 26.29424667], [88.92539215, 26.29395485], [88.92797089, 26.29188347], [88.92842865, 26.29183578], [88.92956543, 26.29171753], [88.93304443, 26.29234314], [88.93685913, 26.29007339], [88.9378891, 26.28940964], [88.93965912, 26.28831482], [88.94179535, 26.28684044], [88.94268799, 26.28679848], [88.94337463, 26.28676605], [88.94442749, 26.28413773], [88.94559479, 26.28156281], [88.94770813, 26.27930069], [88.95036316, 26.27687454], [88.95320892, 26.27537727], [88.95446014, 26.27472115], [88.95664215, 26.27556419], [88.95883179, 26.27633286], [88.96095276, 26.2769928], [88.96372986, 26.27734184], [88.96417999, 26.27742004], [88.96618652, 26.27777481], [88.96683502, 26.27776146], [88.96949005, 26.27770424], [88.97008514, 26.2782135], [88.97041321, 26.2784977], [88.97290039, 26.27825928], [88.97325134, 26.2793026], [88.97614288, 26.2781086], [88.97405243, 26.28159332], [88.97345734, 26.28197861], [88.97523499, 26.28414345], [88.9758606, 26.2837162], [88.97611237, 26.28409958], [88.97657776, 26.2840023], [88.97709656, 26.28389168], [88.98021698, 26.2832222], [88.98058319, 26.28317451], [88.98151398, 26.28305626], [88.98195648, 26.28557777], [88.98244476, 26.28775406], [88.98280334, 26.28777885], [88.98325348, 26.28941536], [88.98360443, 26.29100418], [88.98394775, 26.29319], [88.98358917, 26.29345703], [88.98358917, 26.29335403], [88.98292542, 26.2936039], [88.98303986, 26.29414368], [88.98277283, 26.2941761], [88.9831543, 26.29431343], [88.98371887, 26.29433823], [88.98392487, 26.29466057], [88.98298645, 26.29521561], [88.98412323, 26.29499817], [88.98413849, 26.295187], [88.98475647, 26.29540634], [88.98480988, 26.29668045], [88.98409271, 26.29725456], [88.98418427, 26.297472], [88.98368073, 26.29804611], [88.9835968, 26.29958344], [88.98296356, 26.30002785], [88.98270416, 26.30021858], [88.98160553, 26.30102921], [88.98142242, 26.30116272], [88.97958374, 26.30121613], [88.97949982, 26.29920769], [88.97748566, 26.29968452], [88.97741699, 26.29916954], [88.97731781, 26.29846764], [88.97679138, 26.29847336], [88.9766922, 26.29859734], [88.97640228, 26.29896736], [88.97653198, 26.29841042], [88.97660828, 26.29810524], [88.97635651, 26.29764366], [88.97615814, 26.29767609], [88.97595215, 26.29731941], [88.97615051, 26.29676247], [88.9757843, 26.29538727], [88.97363281, 26.29574394], [88.97354126, 26.29515266], [88.97141266, 26.29505348], [88.9697113, 26.29483986], [88.96977234, 26.2951622], [88.96983337, 26.29548836], [88.96894073, 26.29554939], [88.96864319, 26.29722786], [88.96828461, 26.29724121], [88.9681015, 26.29727364], [88.967659, 26.29735374], [88.96775055, 26.29640579], [88.96776581, 26.2962513], [88.96767426, 26.29623032], [88.96681213, 26.29603958], [88.96586609, 26.29602432], [88.96556854, 26.29559708], [88.96392059, 26.29564095], [88.96232605, 26.29543877], [88.96180725, 26.29509735], [88.96083832, 26.29505348], [88.96084595, 26.29562378], [88.96060944, 26.29562187], [88.96076202, 26.29588699], [88.96103668, 26.29586792], [88.96107483, 26.29644394], [88.96089172, 26.29647446], [88.96090698, 26.29717636], [88.96123505, 26.29720306], [88.9611969, 26.29822731], [88.96110535, 26.2991581], [88.96112061, 26.29989052], [88.96229553, 26.29988289], [88.96289825, 26.2998085], [88.96297455, 26.30000496], [88.96370697, 26.29992294], [88.96375275, 26.30020905], [88.96421814, 26.30016899], [88.96424103, 26.30080986], [88.96457672, 26.30082703], [88.9645462, 26.30104828], [88.96446991, 26.3010788], [88.96424866, 26.30343437], [88.96405792, 26.30341148], [88.96391296, 26.30414009], [88.96277618, 26.30399132], [88.96263885, 26.30397415], [88.9625473, 26.30457878], [88.96243286, 26.30539703], [88.96192932, 26.30534744], [88.96134186, 26.30528831], [88.96131897, 26.30516624], [88.95972443, 26.3050251], [88.95974731, 26.30430412], [88.95967102, 26.304245], [88.95967865, 26.30399513], [88.95860291, 26.30396652], [88.95832062, 26.30444336], [88.95751953, 26.30463982], [88.95689392, 26.3047924], [88.95665741, 26.30485153], [88.9562912, 26.30494499], [88.95568085, 26.30486488], [88.95501709, 26.30426788], [88.95433807, 26.30392647], [88.95420837, 26.30362701], [88.95342255, 26.30363083], [88.95330048, 26.30461884], [88.95317078, 26.30571175], [88.95310211, 26.3065567], [88.95305634, 26.30723953], [88.95327759, 26.30731773], [88.95329285, 26.30792046], [88.9552536, 26.30823898], [88.95606995, 26.30834198], [88.95637512, 26.30838013], [88.95645905, 26.30912209], [88.9549408, 26.30924988], [88.9546051, 26.30929184], [88.95376587, 26.30939865], [88.9537735, 26.31078339], [88.95314789, 26.31089401], [88.95309448, 26.31188393], [88.95281219, 26.31191826], [88.95279694, 26.31311035], [88.95252991, 26.31316185], [88.95245361, 26.31406403], [88.95227814, 26.3144989], [88.95207977, 26.31449699], [88.95207214, 26.31537819], [88.95194244, 26.31638527], [88.95001221, 26.31775665], [88.94902802, 26.31845284], [88.94795227, 26.31798363], [88.94621277, 26.31721878], [88.94320679, 26.3158226], [88.94091797, 26.31469154], [88.93903351, 26.31373215], [88.93756104, 26.31298637], [88.93747711, 26.31329918], [88.9367981, 26.31590843], [88.93611145, 26.31596184], [88.93606567, 26.31618118], [88.93586731, 26.31704903], [88.93574524, 26.31948853], [88.93559265, 26.3205986], [88.93549347, 26.3213501], [88.93754578, 26.32321358], [88.93997955, 26.32329559], [88.94017792, 26.32328796], [88.94216156, 26.32320976], [88.94225311, 26.32658195], [88.9420929, 26.32920074], [88.94168091, 26.33094025], [88.94048309, 26.33229446], [88.93967438, 26.33310699], [88.93840027, 26.33502388], [88.93569183, 26.33447456], [88.93509674, 26.33381653], [88.93152618, 26.33289528], [88.92984009, 26.33238411], [88.92776489, 26.33178329], [88.92751312, 26.33296585], [88.92794037, 26.33462524], [88.92779541, 26.33548546]], [[89.0042572, 26.42137718], [89.00550079, 26.41943932], [89.00574493, 26.42076492], [89.00588226, 26.42152405], [89.00457764, 26.42124176], [89.0042572, 26.42137718]], [[88.94125366, 26.35522079], [88.94082642, 26.35533714], [88.94042206, 26.35535622], [88.93972015, 26.35525703], [88.93904877, 26.355093], [88.93865204, 26.3550148], [88.9384079, 26.35485649], [88.93824768, 26.35482979], [88.93812561, 26.35470963], [88.93801117, 26.35438156], [88.93801117, 26.35420227], [88.93798065, 26.35387039], [88.93776703, 26.35294533], [88.93781281, 26.35261154], [88.93785095, 26.35243225], [88.93779755, 26.3521843], [88.93784332, 26.35201645], [88.93781281, 26.35184479], [88.93784332, 26.3517189], [88.93789673, 26.35155106], [88.93796539, 26.35146713], [88.93798065, 26.35135269], [88.93811798, 26.35126877], [88.93819427, 26.35115433], [88.93830872, 26.35106087], [88.93847656, 26.35097122], [88.93862915, 26.35087776], [88.9388504, 26.35079765], [88.93904114, 26.35079765], [88.93913269, 26.35090256], [88.93930054, 26.35095024], [88.93948364, 26.35099983], [88.93983459, 26.35107422], [88.94004059, 26.35104752], [88.94072723, 26.35129166], [88.94125366, 26.35151672], [88.94154358, 26.35162926], [88.94189453, 26.35183907], [88.94219971, 26.35201836], [88.94233704, 26.35222626], [88.94245911, 26.3524437], [88.94258881, 26.35247612], [88.94258881, 26.35262871], [88.94261169, 26.35303688], [88.94264984, 26.35362625], [88.94254303, 26.35442734], [88.94229889, 26.35490608], [88.9420929, 26.35520363], [88.94158936, 26.35516548], [88.94125366, 26.35522079]], [[89.04703522, 26.28692436], [89.04897308, 26.28685379], [89.04893494, 26.28704262], [89.04891968, 26.28712273], [89.04975128, 26.28768158], [89.05034637, 26.28808022], [89.04979706, 26.28899765], [89.04956055, 26.28893661], [89.04811859, 26.28856659], [89.04776001, 26.28847504], [89.04707336, 26.28715706], [89.04703522, 26.28692436]], [[89.02149963, 26.29281044], [89.02361298, 26.29238129], [89.02481842, 26.29339027], [89.02559662, 26.29582024], [89.02548218, 26.29718971], [89.02417755, 26.29964066], [89.02373505, 26.30127335], [89.02332306, 26.30063057], [89.02316284, 26.30035782], [89.02214813, 26.2986393], [89.02113342, 26.2975235], [89.02093506, 26.29730034], [89.02111816, 26.29719353], [89.02248383, 26.29641533], [89.02327728, 26.29340744], [89.0231781, 26.29338264], [89.02149963, 26.29298019], [89.02149963, 26.29281044]], [[88.95831299, 26.34260559], [88.95855713, 26.33892059], [88.95855713, 26.33806992], [88.95916748, 26.33612823], [88.95943451, 26.33605576], [88.95960236, 26.33600998], [88.96231079, 26.33632088], [88.96282959, 26.33638191], [88.96285248, 26.33683968], [88.96266174, 26.33796501], [88.96349335, 26.33856201], [88.96214294, 26.33934212], [88.96178436, 26.34062767], [88.96170044, 26.34091759], [88.96179962, 26.34162521], [88.96202087, 26.3431797], [88.96198273, 26.34463501], [88.96248627, 26.34539032], [88.96164703, 26.34518814], [88.96032715, 26.34514999], [88.95868683, 26.34477043], [88.95847321, 26.34380722], [88.95898438, 26.343647], [88.9587326, 26.34282875], [88.95831299, 26.34260559]]], [[[88.10694885, 21.89360046], [88.10722351, 21.89333344], [88.10805511, 21.89333344], [88.10861206, 21.8927784], [88.10888672, 21.8927803], [88.10972595, 21.89193916], [88.10972595, 21.89166641], [88.11055756, 21.89082909], [88.11055756, 21.89055634], [88.11165619, 21.88944054], [88.11166382, 21.88916779], [88.11194611, 21.88889122], [88.11194611, 21.88833809], [88.11165619, 21.88805962], [88.11165619, 21.88778114], [88.11138916, 21.88750076], [88.11138916, 21.88694], [88.1111145, 21.88666534], [88.11112213, 21.88639069], [88.11083221, 21.88611031], [88.11083221, 21.88582993], [88.11055756, 21.88555336], [88.11055756, 21.88528061], [88.1102829, 21.88500023], [88.11027527, 21.88472176], [88.11000061, 21.88444328], [88.11000061, 21.88417053], [88.10929871, 21.88388062], [88.1087265, 21.88442039], [88.10708618, 21.88644981], [88.10673523, 21.88686752], [88.10660553, 21.88701248], [88.10639191, 21.88722229], [88.10626984, 21.88784981], [88.10555267, 21.88833809], [88.10500336, 21.88888931], [88.1049881, 21.88972092], [88.10472107, 21.88999748], [88.10472107, 21.89027977], [88.10500336, 21.89055634], [88.1049881, 21.89110756], [88.10501099, 21.89219666], [88.10497284, 21.89261055], [88.10472107, 21.89527702], [88.10466003, 21.89562035], [88.10459137, 21.89639854], [88.10472107, 21.89694214], [88.10444641, 21.89722061], [88.10444641, 21.89777946], [88.10472107, 21.89805984], [88.10472107, 21.89861107], [88.10527802, 21.8991642], [88.10527802, 21.89944649], [88.10555267, 21.89972115], [88.10584259, 21.89999962], [88.10610962, 21.90055466], [88.10624695, 21.90068817], [88.10639954, 21.90083313], [88.10639191, 21.9011116], [88.10666656, 21.90146065], [88.10681152, 21.90195084], [88.10729218, 21.90243912], [88.10743713, 21.90285301], [88.10749817, 21.90332031], [88.10764313, 21.90348053], [88.10778046, 21.90389061], [88.10799408, 21.90416718], [88.1084671, 21.9047184], [88.10861969, 21.90479851], [88.10888672, 21.90513992], [88.10897064, 21.90549088], [88.10910034, 21.90577126], [88.10917664, 21.90611076], [88.10938263, 21.90632248], [88.10945129, 21.90666962], [88.11000061, 21.90750122], [88.11021423, 21.90777779], [88.11055756, 21.90833282], [88.11077118, 21.90854263], [88.11090851, 21.90888977], [88.11125946, 21.90923119], [88.11165619, 21.90966034], [88.11194611, 21.90999985], [88.11229706, 21.9103508], [88.11250305, 21.91055489], [88.11277771, 21.91055489], [88.11277771, 21.91027832], [88.11277008, 21.91007042], [88.11265564, 21.90994263], [88.11222076, 21.90944481], [88.11222076, 21.90917015], [88.11213684, 21.90888977], [88.11194611, 21.90833282], [88.11173248, 21.90805626], [88.11165619, 21.90777969], [88.1114502, 21.90750122], [88.11112213, 21.90694237], [88.11096954, 21.9066658], [88.11055756, 21.90611076], [88.10984039, 21.90519905], [88.10943604, 21.90443993], [88.10929108, 21.90409088], [88.10909271, 21.90374947], [88.10909271, 21.90348053], [88.10839844, 21.90257072], [88.10810852, 21.90208054], [88.10790253, 21.90180016], [88.10790253, 21.90138626], [88.10769653, 21.90118027], [88.10762787, 21.90083122], [88.10719299, 21.90013123], [88.10694122, 21.89972305], [88.10694122, 21.8991642], [88.10527802, 21.89751053], [88.10527802, 21.89694023], [88.10583496, 21.89638901], [88.10582733, 21.89611053], [88.10610962, 21.89583015], [88.10583496, 21.8955555], [88.10582733, 21.89528275], [88.10694122, 21.89417267], [88.10694885, 21.89360046]]], [[[88.13730621, 21.89513969], [88.13659668, 21.89439964], [88.13601685, 21.89447021], [88.13594818, 21.89534187], [88.13637543, 21.89587975], [88.1368103, 21.89675331], [88.13759613, 21.89769173], [88.13767242, 21.89775085], [88.13802338, 21.89802933], [88.13838196, 21.89816475], [88.13848877, 21.89813232], [88.13859558, 21.8980999], [88.13852692, 21.89789963], [88.13780975, 21.89615059], [88.13730621, 21.89513969]]], [[[88.13478851, 21.92674446], [88.13504028, 21.92642021], [88.13531494, 21.92605782], [88.13553619, 21.92562103], [88.13568878, 21.92514992], [88.13583374, 21.92471123], [88.13598633, 21.9242897], [88.13616943, 21.92394447], [88.13637543, 21.92363358], [88.1365509, 21.92332649], [88.13671112, 21.92303085], [88.13691711, 21.9227829], [88.137146, 21.92250443], [88.13742065, 21.92220497], [88.13774109, 21.92187119], [88.13809967, 21.92147064], [88.13854218, 21.92105865], [88.13902283, 21.92060089], [88.13952637, 21.92016983], [88.14000702, 21.91970062], [88.14047241, 21.91925049], [88.14090729, 21.91881943], [88.14141083, 21.91840935], [88.141922, 21.91794014], [88.14238739, 21.91739082], [88.14293671, 21.91696167], [88.14337921, 21.91658974], [88.14372253, 21.91630363], [88.14404297, 21.91608429], [88.14424133, 21.91579056], [88.14446259, 21.91553688], [88.1446228, 21.91526031], [88.14447021, 21.91502953], [88.14425659, 21.91480064], [88.14408112, 21.91455269], [88.14383698, 21.91438103], [88.14360809, 21.91415977], [88.14336395, 21.91391945], [88.14309692, 21.91365051], [88.1428833, 21.91331291], [88.14266205, 21.91296005], [88.14241028, 21.91266823], [88.14222717, 21.91235733], [88.14205933, 21.91205788], [88.14190674, 21.91179276], [88.14170837, 21.91155815], [88.14154816, 21.9112606], [88.14136505, 21.91090775], [88.14109802, 21.91056061], [88.14084625, 21.91020012], [88.14061737, 21.90982819], [88.14048767, 21.90942955], [88.14031219, 21.9091301], [88.14019775, 21.90884018], [88.14002991, 21.90862083], [88.13989258, 21.90837097], [88.13982391, 21.90828896], [88.13970947, 21.90815544], [88.13949585, 21.90793991], [88.13931274, 21.90764046], [88.13912964, 21.90733719], [88.13889313, 21.90706062], [88.1386261, 21.90677643], [88.1383667, 21.9064312], [88.13806152, 21.90603065], [88.1377182, 21.90556717], [88.1373291, 21.90509033], [88.13695526, 21.90460587], [88.13658142, 21.90415955], [88.13623047, 21.90373039], [88.13588715, 21.90335274], [88.13553619, 21.90300179], [88.13516235, 21.90265083], [88.13477325, 21.90225029], [88.13439941, 21.90177917], [88.13395691, 21.901371], [88.13350677, 21.90099525], [88.13311005, 21.90060997], [88.13275146, 21.90026093], [88.13238525, 21.89999008], [88.13201904, 21.89972878], [88.13166809, 21.89944077], [88.13111115, 21.89944649], [88.13097382, 21.89930534], [88.13083649, 21.8991642], [88.13054657, 21.89916992], [88.13027954, 21.89888954], [88.12944794, 21.89888954], [88.1286087, 21.89972305], [88.12832642, 21.89972115], [88.12805176, 21.89999962], [88.1277771, 21.89999962], [88.12750244, 21.90028], [88.12722015, 21.90027618], [88.1269455, 21.90055466], [88.12666321, 21.90055466], [88.12611389, 21.9011116], [88.12593079, 21.90098763], [88.12561798, 21.90114975], [88.12535095, 21.901371], [88.12507629, 21.90159988], [88.12490845, 21.90195847], [88.12474823, 21.90238953], [88.12465668, 21.90287018], [88.12445831, 21.90323067], [88.12428284, 21.90359116], [88.12406158, 21.90391922], [88.12393188, 21.90430069], [88.12387085, 21.90474319], [88.12377167, 21.90519905], [88.12356567, 21.90566444], [88.12324524, 21.90613174], [88.12290192, 21.90664101], [88.12249756, 21.90714073], [88.1220932, 21.90763092], [88.12165833, 21.90808105], [88.12125397, 21.90855408], [88.12077332, 21.90896988], [88.12032318, 21.90944862], [88.11988068, 21.90992355], [88.11937714, 21.91028023], [88.118927, 21.91064072], [88.11856079, 21.91102982], [88.11817169, 21.9113903], [88.11779785, 21.9117794], [88.11749268, 21.91222], [88.11721039, 21.9126606], [88.11694336, 21.91311073], [88.11675262, 21.91358185], [88.11673737, 21.9141655], [88.11688995, 21.91480827], [88.11687469, 21.91550827], [88.11662292, 21.91618919], [88.11631775, 21.91675568], [88.11612701, 21.91724014], [88.11611176, 21.91777992], [88.11611176, 21.9183197], [88.11726379, 21.91949463], [88.11756897, 21.91991806], [88.11777496, 21.92000008], [88.11888885, 21.92111015], [88.1193924, 21.92180252], [88.12082672, 21.92333984], [88.12110901, 21.92361069], [88.12166595, 21.92416954], [88.12194824, 21.92416954], [88.1222229, 21.92444992], [88.12249756, 21.92444229], [88.12306213, 21.92472076], [88.12335205, 21.92500114], [88.12361145, 21.92500114], [88.1241684, 21.92556], [88.12472534, 21.92555428], [88.125, 21.92583275], [88.12555695, 21.92583084], [88.1258316, 21.92611122], [88.12609863, 21.92611122], [88.12638855, 21.92583084], [88.12722015, 21.92583084], [88.12750244, 21.92611122], [88.12805176, 21.92611122], [88.12832642, 21.92638969], [88.12915802, 21.92638969], [88.12944794, 21.92667007], [88.1305542, 21.92666435], [88.13083649, 21.92694664], [88.13111115, 21.92694664], [88.1313858, 21.9272213], [88.13249969, 21.9272213], [88.13277435, 21.92749977], [88.13361359, 21.92749977], [88.13374329, 21.92763138], [88.13388824, 21.92778015], [88.13437653, 21.92728043], [88.13443756, 21.92721367], [88.13459778, 21.9270401], [88.13478851, 21.92674446]]], [[[88.5047226, 21.91278076], [88.50499725, 21.91250992], [88.50776672, 21.91250992], [88.50805664, 21.91222], [88.50861359, 21.91222191], [88.5091629, 21.91166687], [88.5091629, 21.91082954], [88.50888824, 21.91055489], [88.50888824, 21.91027832], [88.50860596, 21.90999985], [88.50860596, 21.90971947], [88.50722504, 21.90833282], [88.50694275, 21.90833282], [88.50653076, 21.90791893], [88.50611115, 21.90749931], [88.50611115, 21.90722275], [88.50583649, 21.90694427], [88.50583649, 21.9066658], [88.50554657, 21.9063797], [88.5055542, 21.90611076], [88.50527954, 21.90582848], [88.50499725, 21.9058342], [88.50416565, 21.90500069], [88.50416565, 21.90472221], [88.50389099, 21.90444374], [88.50389099, 21.90416718], [88.5036087, 21.90389061], [88.5036087, 21.90360832], [88.50332642, 21.90332031], [88.50333405, 21.90305519], [88.5027771, 21.90250015], [88.5027771, 21.90221977], [88.50250244, 21.90194511], [88.50250244, 21.90167046], [88.50221252, 21.90139008], [88.50221252, 21.9011097], [88.5019455, 21.90083313], [88.5019455, 21.90055466], [88.50166321, 21.90027618], [88.50166321, 21.89972115], [88.50138855, 21.89944649], [88.50138855, 21.8991642], [88.50026703, 21.89805984], [88.5, 21.89805984], [88.4991684, 21.89722061], [88.4991684, 21.89666748], [88.49888611, 21.89639091], [88.49888611, 21.89611053], [88.49861145, 21.89583015], [88.49833679, 21.89583206], [88.4980545, 21.8955555], [88.49777985, 21.89556122], [88.49694824, 21.89472008], [88.49666595, 21.89472008], [88.49610901, 21.89416695], [88.49582672, 21.89417267], [88.49472046, 21.89306259], [88.4944458, 21.89306259], [88.49415588, 21.8927803], [88.49388885, 21.8927803], [88.49276733, 21.89166832], [88.49250031, 21.89166832], [88.49194336, 21.89110756], [88.49028015, 21.88944435], [88.48916626, 21.88944435], [88.48805237, 21.8908329], [88.48722076, 21.8908329], [88.48721313, 21.89138031], [88.48694611, 21.89166641], [88.4854126, 21.89242935], [88.48082733, 21.89472008], [88.48000336, 21.8955555], [88.47944641, 21.89583015], [88.47861481, 21.89666748], [88.47849274, 21.89672852], [88.47805786, 21.89694214], [88.47805786, 21.89722061], [88.4777832, 21.89751053], [88.4777832, 21.89777946], [88.47750092, 21.89777756], [88.47693634, 21.89833069], [88.47693634, 21.89861107], [88.47666931, 21.89888954], [88.47666931, 21.8991642], [88.47694397, 21.89944649], [88.47694397, 21.90055466], [88.47721863, 21.90083122], [88.47721863, 21.90138626], [88.47733307, 21.9015007], [88.47750092, 21.90167046], [88.47750092, 21.90194511], [88.47777557, 21.90222168], [88.4777832, 21.90250015], [88.47833252, 21.90305519], [88.47833252, 21.90332031], [88.47877502, 21.90377808], [88.47915649, 21.90416908], [88.47944641, 21.90416908], [88.48194122, 21.90666962], [88.48222351, 21.9066658], [88.48278046, 21.90722275], [88.48306274, 21.90722275], [88.48332977, 21.90750122], [88.48361206, 21.90750122], [88.48388672, 21.90777969], [88.48416901, 21.90777969], [88.48443604, 21.90806007], [88.48472595, 21.90805626], [88.48500061, 21.90833282], [88.48527527, 21.90833282], [88.48555756, 21.9086113], [88.48583221, 21.90860939], [88.48610687, 21.90888977], [88.48638916, 21.90888977], [88.48665619, 21.90917015], [88.48694611, 21.90917015], [88.48721313, 21.90945053], [88.48750305, 21.90944481], [88.48777771, 21.90972137], [88.48805237, 21.90971947], [88.48860931, 21.91028023], [88.48916626, 21.91027832], [88.48944092, 21.91055489], [88.49055481, 21.91055489], [88.4908371, 21.91083336], [88.4916687, 21.91083336], [88.49194336, 21.91111183], [88.4944458, 21.91110992], [88.49472046, 21.9113903], [88.49555206, 21.9113903], [88.49582672, 21.91167068], [88.4962616, 21.91166687], [88.49694824, 21.91166687], [88.49749756, 21.91222191], [88.49777985, 21.91222], [88.49796295, 21.91240692], [88.49833679, 21.91278076], [88.498703, 21.91240692], [88.49888611, 21.91222191], [88.5, 21.91222], [88.50026703, 21.91250992], [88.5008316, 21.91250992], [88.50110626, 21.91278076], [88.50138855, 21.91278076], [88.50166321, 21.91250992], [88.5027771, 21.91250992], [88.50305176, 21.91278076], [88.5047226, 21.91278076]]], [[[88.42546082, 21.90409088], [88.42546844, 21.90380096], [88.42512512, 21.9036026], [88.42500305, 21.90360832], [88.42305756, 21.90360832], [88.4227829, 21.9039402], [88.42256165, 21.9039402], [88.42228699, 21.90365982], [88.42166901, 21.90360832], [88.42141724, 21.9036808], [88.42070007, 21.90387726], [88.4207077, 21.90402031], [88.42092133, 21.90464973], [88.42105103, 21.90480042], [88.42124939, 21.90501022], [88.42138672, 21.90527725], [88.42194366, 21.9058342], [88.42250061, 21.9058342], [88.42277527, 21.90611076], [88.42401123, 21.90604401], [88.42444611, 21.9058342], [88.4246521, 21.90576553], [88.42485809, 21.9054203], [88.42501068, 21.9052639], [88.42533875, 21.90493011], [88.4254837, 21.90472221], [88.42546082, 21.90409088]]], [[[88.45245361, 21.90633774], [88.45197296, 21.90608025], [88.45173645, 21.90594673], [88.45094299, 21.90612984], [88.45025635, 21.90620995], [88.44976807, 21.90614128], [88.44934082, 21.9061203], [88.44890594, 21.90615082], [88.4484787, 21.90623093], [88.44803619, 21.90615082], [88.44760132, 21.90610123], [88.44715881, 21.90610123], [88.44671631, 21.90610123], [88.44631958, 21.90608025], [88.445961, 21.90608978], [88.44567871, 21.90612984], [88.44542694, 21.90624237], [88.44510651, 21.90637016], [88.44470978, 21.9065609], [88.44423676, 21.90682983], [88.44372559, 21.90720558], [88.44309235, 21.90757179], [88.44268036, 21.90768814], [88.44226837, 21.90780449], [88.44218445, 21.90804482], [88.44220734, 21.90837288], [88.44226074, 21.90876961], [88.44249725, 21.90920067], [88.44284058, 21.90962982], [88.44326782, 21.91000748], [88.44374084, 21.91035271], [88.44435883, 21.91057587], [88.4450531, 21.91077423], [88.44583893, 21.91089058], [88.44664001, 21.91101646], [88.44740295, 21.91104126], [88.44809723, 21.91114807], [88.4487381, 21.9113102], [88.44934845, 21.9113903], [88.4499588, 21.91152954], [88.45053101, 21.9117794], [88.45105743, 21.91209984], [88.45168304, 21.91229057], [88.45224762, 21.91258049], [88.45278168, 21.91292953], [88.45334625, 21.91329956], [88.45401001, 21.91361809], [88.45475769, 21.9139328], [88.45561218, 21.91413116], [88.45603943, 21.91397095], [88.4564743, 21.91381454], [88.45662689, 21.91337013], [88.45652008, 21.91290283], [88.45637512, 21.91243744], [88.45619202, 21.91201973], [88.45604706, 21.91164017], [88.45584106, 21.91136169], [88.45568085, 21.91109276], [88.45554352, 21.91080093], [88.45536804, 21.91052055], [88.45520782, 21.91021156], [88.45500183, 21.90988541], [88.4548111, 21.90950966], [88.4546814, 21.90906715], [88.45443726, 21.90868187], [88.45417786, 21.9083271], [88.45394897, 21.90796852], [88.45378876, 21.90757179], [88.45350647, 21.90724945], [88.453125, 21.90699959], [88.45278931, 21.90666962], [88.45245361, 21.90633774]]], [[[88.14138794, 22.02639008], [88.14250183, 22.02527809], [88.14277649, 22.02527809], [88.14332581, 22.02471924], [88.14360809, 22.02472305], [88.14444733, 22.02388954], [88.14472198, 22.02389908], [88.14444733, 22.02361107], [88.14444733, 22.02333069], [88.14416504, 22.02305794], [88.14417267, 22.02277946], [88.14389038, 22.02250099], [88.14389038, 22.02194023], [88.14360809, 22.02166557], [88.14360809, 22.02111053], [88.14332581, 22.02083969], [88.14332581, 22.02056122], [88.14167023, 22.01889038], [88.14167023, 22.01861], [88.1388855, 22.0158329], [88.1388855, 22.01555634], [88.13722229, 22.01389122], [88.13722229, 22.01361275], [88.13694763, 22.01332855], [88.13694763, 22.0130558], [88.13529205, 22.01139069], [88.13529205, 22.0111084], [88.13424683, 22.01008224], [88.1341629, 22.01000023], [88.1341629, 22.00971985], [88.13361359, 22.00916862], [88.13360596, 22.00889969], [88.13194275, 22.00722122], [88.13194275, 22.00694656], [88.1313858, 22.00638962], [88.1313858, 22.00611115], [88.13027954, 22.00500107], [88.13027954, 22.00444031], [88.12999725, 22.00416756], [88.12999725, 22.00389099], [88.12944794, 22.00333023], [88.12944794, 22.00305557], [88.1286087, 22.00222015], [88.1286087, 22.00166702], [88.12832642, 22.00139046], [88.12832642, 22.00111008], [88.12805176, 22.00083351], [88.12805176, 22.00055504], [88.1277771, 22.00028038], [88.12722015, 22.00000191], [88.12728882, 21.99895859], [88.12722015, 21.99860764], [88.12700653, 21.99839973], [88.12695313, 21.99805832], [88.12666321, 21.99749756], [88.12638092, 21.99735832], [88.1261673, 21.99715042], [88.12602997, 21.99686813], [88.12609863, 21.99650955], [88.12589264, 21.99617767], [88.12568665, 21.99583054], [88.12547302, 21.99575615], [88.12526703, 21.99500084], [88.12526703, 21.99472046], [88.12472534, 21.99416542], [88.12473297, 21.99360085], [88.12444305, 21.99333572], [88.12444305, 21.99305534], [88.1241684, 21.99278069], [88.1241684, 21.99221992], [88.12388611, 21.99194336], [88.12388611, 21.99167061], [88.12335205, 21.99110985], [88.12333679, 21.99083328], [88.1230545, 21.99055481], [88.1230545, 21.99027824], [88.12277985, 21.98999977], [88.12277985, 21.98971939], [88.12249756, 21.98944473], [88.12249756, 21.98888969], [88.1222229, 21.98861122], [88.1222229, 21.98833275], [88.12055206, 21.98666573], [88.12055206, 21.98638916], [88.12029266, 21.98611069], [88.1202774, 21.98583412], [88.12000275, 21.98555565], [88.12000275, 21.98527908], [88.11972046, 21.98500061], [88.11972046, 21.98473167], [88.11888885, 21.98389053], [88.11888885, 21.98360825], [88.11805725, 21.98277855], [88.11805725, 21.98249817], [88.11750031, 21.98195076], [88.11750031, 21.98166084], [88.11694336, 21.98111153], [88.11694336, 21.98083305], [88.1166687, 21.98055458], [88.1166687, 21.98027992], [88.11638641, 21.97999954], [88.11638641, 21.97972107], [88.11555481, 21.97888947], [88.11554718, 21.97859955], [88.11528015, 21.97833252], [88.11528015, 21.97805405], [88.11472321, 21.97750092], [88.11472321, 21.97722054], [88.11444092, 21.97694206], [88.11444092, 21.9766674], [88.11415863, 21.97639084], [88.11415863, 21.97611046], [88.11305237, 21.97500038], [88.11305237, 21.97472191], [88.11277771, 21.97444534], [88.11277771, 21.97417259], [88.11250305, 21.9738903], [88.11248779, 21.97359848], [88.11194611, 21.97305489], [88.11194611, 21.97277832], [88.11138916, 21.97222137], [88.11138916, 21.97194481], [88.11000061, 21.97055626], [88.11000061, 21.97027969], [88.10943604, 21.96972084], [88.10944366, 21.96944427], [88.10861206, 21.96861076], [88.10861206, 21.96833038], [88.10749817, 21.96722221], [88.10749817, 21.96694374], [88.10555267, 21.96500015], [88.10555267, 21.96471977], [88.10527802, 21.96444321], [88.10527802, 21.96417046], [88.10472107, 21.96362114], [88.10472107, 21.96333122], [88.10388947, 21.96249962], [88.10388947, 21.96222115], [88.10361481, 21.96194458], [88.10361481, 21.96166611], [88.10111237, 21.95916939], [88.10111237, 21.95889091], [88.10083008, 21.95889091], [88.10083008, 21.95861053], [88.10056305, 21.95832825], [88.10055542, 21.9580555], [88.09999847, 21.95750046], [88.09999847, 21.9569397], [88.09972382, 21.95666885], [88.09971619, 21.95639038], [88.09889221, 21.95556068], [88.09889221, 21.9552803], [88.09860992, 21.95499992], [88.09860992, 21.95471954], [88.09833527, 21.95444679], [88.09833527, 21.95388794], [88.09722137, 21.95277977], [88.09722137, 21.95222092], [88.09444427, 21.94944382], [88.09424591, 21.94897652], [88.09395599, 21.94859123], [88.09366608, 21.9481926], [88.09336853, 21.94778061], [88.09307098, 21.94738388], [88.09283447, 21.94695282], [88.09259796, 21.94652939], [88.09246063, 21.94607925], [88.09220123, 21.94573975], [88.09179688, 21.9455204], [88.09194183, 21.94528008], [88.09194183, 21.94472122], [88.09166718, 21.94444466], [88.09166718, 21.94416618], [88.09139252, 21.94388962], [88.09139252, 21.94361115], [88.09111023, 21.94333076], [88.09111023, 21.94277954], [88.09055328, 21.94222069], [88.09055328, 21.94194412], [88.09027863, 21.94166565], [88.09027863, 21.94111061], [88.08998871, 21.94083023], [88.08999634, 21.94055748], [88.08972168, 21.94028091], [88.08972168, 21.93972015], [88.08944702, 21.93944359], [88.08944702, 21.93833351], [88.08916473, 21.93805313], [88.0891571, 21.9375], [88.08889008, 21.93721962], [88.08889008, 21.93638802], [88.08860779, 21.93610954], [88.08860779, 21.93527794], [88.08833313, 21.93499947], [88.08833313, 21.9347229], [88.08750153, 21.93388939], [88.08750153, 21.93277931], [88.08555603, 21.93082809], [88.08528137, 21.93083382], [88.08472443, 21.93027878], [88.0847168, 21.93054962], [88.08361053, 21.93166924], [88.08333588, 21.93166733], [88.08305359, 21.93194389], [88.08194733, 21.93194389], [88.08166504, 21.93166733], [88.08139038, 21.93166924], [88.08055878, 21.93082809], [88.08055878, 21.93055534], [88.07917023, 21.9291687], [88.07917023, 21.92889023], [88.07888794, 21.92860985], [88.07861328, 21.92861176], [88.07583618, 21.92583275], [88.07472229, 21.92583084], [88.07444763, 21.92611122], [88.07305908, 21.92611122], [88.07277679, 21.92583084], [88.07250214, 21.92583275], [88.07241058, 21.9257412], [88.07221985, 21.92555428], [88.07195282, 21.92556], [88.07138824, 21.92500114], [88.07138824, 21.92472076], [88.07111359, 21.92444229], [88.07110596, 21.92416954], [88.0708313, 21.92389107], [88.0708313, 21.92361069], [88.07110596, 21.92333031], [88.07111359, 21.92305565], [88.07138824, 21.9227829], [88.07138824, 21.92222023], [88.0708313, 21.9216671], [88.0708313, 21.92139053], [88.07055664, 21.92111015], [88.07055664, 21.92083359], [88.07027435, 21.92055511], [88.06973267, 21.92056274], [88.06944275, 21.92028046], [88.06916809, 21.92028046], [88.06887817, 21.92000008], [88.06861115, 21.92028046], [88.06804657, 21.92028046], [88.06777954, 21.92000008], [88.06694794, 21.92000008], [88.06667328, 21.9197216], [88.06583405, 21.9197216], [88.06416321, 21.91805649], [88.0633316, 21.9180584], [88.0630722, 21.91777992], [88.0630722, 21.91721916], [88.0625, 21.91722298], [88.06138611, 21.91611099], [88.06111145, 21.91611099], [88.06083679, 21.91583061], [88.0605545, 21.91583252], [88.0597229, 21.91500092], [88.05944824, 21.91500092], [88.05916595, 21.91472054], [88.0588913, 21.91472244], [88.05860901, 21.91444588], [88.05833435, 21.91444588], [88.05750275, 21.91361046], [88.05722046, 21.91361046], [88.05665588, 21.91306114], [88.05610657, 21.91306114], [88.05583191, 21.91278076], [88.05526733, 21.91278076], [88.05500031, 21.91250992], [88.05444336, 21.91250992], [88.05421448, 21.91226768], [88.0533371, 21.91222191], [88.05305481, 21.91194344], [88.05278015, 21.91195107], [88.05249786, 21.91167068], [88.0508194, 21.91167068], [88.05055237, 21.9113903], [88.04860687, 21.9113903], [88.04837799, 21.91115761], [88.04807281, 21.91110992], [88.04750061, 21.91167068], [88.04722595, 21.91167068], [88.04722595, 21.91194344], [88.04666901, 21.91222], [88.04666901, 21.91250992], [88.04611206, 21.91306114], [88.04611206, 21.91527557], [88.04582977, 21.91555786], [88.04664612, 21.91970062], [88.04722595, 21.92307091], [88.04722595, 21.92611122], [88.04786682, 21.92806816], [88.04788971, 21.92931938], [88.04746246, 21.9312706], [88.04767609, 21.93288422], [88.0493927, 21.93556976], [88.04917908, 21.93745995], [88.04917908, 21.93860054], [88.05002594, 21.94041061], [88.05083466, 21.94305611], [88.0508194, 21.94338989], [88.05182648, 21.94501114], [88.05197144, 21.94755936], [88.05303955, 21.94977951], [88.0534668, 21.9509201], [88.05388641, 21.95305443], [88.05388641, 21.9533329], [88.05477142, 21.9548912], [88.05576324, 21.95832062], [88.05640411, 21.96047211], [88.05726624, 21.96235275], [88.05841064, 21.96397018], [88.05876923, 21.96639061], [88.05956268, 21.96767044], [88.0597229, 21.96889114], [88.06001282, 21.96916962], [88.06006622, 21.96935081], [88.06157684, 21.97250938], [88.06301117, 21.97513008], [88.0633316, 21.97611046], [88.0633316, 21.97694016], [88.06388855, 21.97750092], [88.06427002, 21.97880363], [88.06555939, 21.98142052], [88.06684113, 21.98357964], [88.06820679, 21.98526001], [88.06935883, 21.98714066], [88.06999969, 21.98888969], [88.06999969, 21.98999977], [88.07027435, 21.99027824], [88.07026672, 21.99082947], [88.0708313, 21.99138832], [88.07132721, 21.99221992], [88.07250214, 21.99389076], [88.07250214, 21.99417114], [88.07332611, 21.99500084], [88.07332611, 21.99528122], [88.07554626, 21.99749756], [88.07554626, 21.99777985], [88.07694244, 21.9991703], [88.07694244, 21.99945259], [88.07749939, 22.00000191], [88.08000183, 22.00027847], [88.08018494, 22.00046158], [88.08055878, 22.00083351], [88.08083344, 22.00083351], [88.08110809, 22.00111008], [88.08139038, 22.00111008], [88.08167267, 22.00139046], [88.08194733, 22.00138855], [88.08277893, 22.00222015], [88.08277893, 22.00250053], [88.08388519, 22.00361061], [88.0847168, 22.00361061], [88.08666992, 22.00555992], [88.08666992, 22.00611115], [88.08750153, 22.00694656], [88.08777618, 22.00694656], [88.08805847, 22.00722313], [88.08833313, 22.00722122], [88.09027863, 22.00917053], [88.09055328, 22.00889969], [88.0908432, 22.00889969], [88.09221649, 22.01028061], [88.09278107, 22.01028061], [88.09388733, 22.01139069], [88.09471893, 22.01139069], [88.09500122, 22.01166916], [88.09555817, 22.01166725], [88.09583282, 22.01194382], [88.09610748, 22.01194382], [88.09638977, 22.01222229], [88.09777832, 22.01221848], [88.09805298, 22.01250076], [88.09889221, 22.01250076], [88.09918213, 22.01277924], [88.09999847, 22.01277924], [88.10028076, 22.01305962], [88.10111237, 22.0130558], [88.10124969, 22.01319504], [88.10138702, 22.01333427], [88.10192871, 22.01332855], [88.10221863, 22.01361275], [88.10250092, 22.01361275], [88.1027832, 22.01389122], [88.10333252, 22.01389122], [88.10360718, 22.01416969], [88.10416412, 22.01416588], [88.10444641, 22.01444435], [88.10500336, 22.01444435], [88.10527802, 22.01472282], [88.10582733, 22.01471138], [88.10610962, 22.01499939], [88.10694122, 22.01499939], [88.10721588, 22.01527977], [88.10806274, 22.01527977], [88.10832977, 22.01556015], [88.10916901, 22.01555634], [88.10944366, 22.0158329], [88.11000061, 22.0158329], [88.11027527, 22.01611137], [88.11083221, 22.01610947], [88.11112213, 22.01638985], [88.11250305, 22.01638985], [88.11277771, 22.01667023], [88.11305237, 22.01666641], [88.11333466, 22.01694489], [88.1138916, 22.01694489], [88.11416626, 22.01666641], [88.11472321, 22.01667023], [88.11499786, 22.01638985], [88.11528015, 22.01638985], [88.11554718, 22.01667023], [88.1158371, 22.01666641], [88.11611176, 22.01694489], [88.11722565, 22.01694489], [88.11740875, 22.0171299], [88.11750031, 22.01722145], [88.11805725, 22.01721954], [88.11833191, 22.01749992], [88.11972046, 22.01749992], [88.12194824, 22.01833344], [88.1222229, 22.01833344], [88.12249756, 22.01861191], [88.12335205, 22.01861], [88.12361145, 22.01889038], [88.12444305, 22.01889038], [88.12454224, 22.01898575], [88.12473297, 22.01917076], [88.12555695, 22.01916695], [88.12611389, 22.01972198], [88.12666321, 22.01972198], [88.1269455, 22.02000046], [88.12750244, 22.02000046], [88.1277771, 22.02028084], [88.12805176, 22.02028084], [88.1286087, 22.02083969], [88.12915802, 22.02083969], [88.12944794, 22.02111053], [88.12999725, 22.02111053], [88.13027954, 22.02139091], [88.1305542, 22.0213871], [88.13111115, 22.02194405], [88.1313858, 22.02194023], [88.13175964, 22.02231407], [88.13194275, 22.02250099], [88.13249969, 22.02250099], [88.13276672, 22.02277946], [88.13305664, 22.02277946], [88.1333313, 22.02305984], [88.13361359, 22.02305794], [88.13388824, 22.0233326], [88.1341629, 22.0233326], [88.1342392, 22.0234108], [88.13471985, 22.02389908], [88.13529205, 22.02389908], [88.13542175, 22.02403069], [88.13555908, 22.02416992], [88.1361084, 22.02416611], [88.13666534, 22.02472305], [88.13722229, 22.02471924], [88.13749695, 22.02499962], [88.13916779, 22.02499962], [88.13944244, 22.02527809], [88.13999939, 22.02527809], [88.14027405, 22.02555466], [88.14055634, 22.02555084], [88.14138794, 22.02639008]]], [[[88.16333008, 21.93722153], [88.16361237, 21.93694305], [88.16414642, 21.93695068], [88.16443634, 21.93667984], [88.16471863, 21.93667984], [88.16500092, 21.93638992], [88.16526794, 21.93638992], [88.16555786, 21.93610954], [88.16583252, 21.93611145], [88.16611481, 21.93583107], [88.16638947, 21.93583107], [88.16666412, 21.93555641], [88.16694641, 21.93556023], [88.16722107, 21.93527985], [88.16750336, 21.93527985], [88.16805267, 21.9347229], [88.16833496, 21.9347229], [88.16889191, 21.93416595], [88.16916656, 21.93416977], [88.17082977, 21.93250084], [88.17111206, 21.93250084], [88.17140198, 21.93221855], [88.17138672, 21.93139076], [88.17111206, 21.93111038], [88.17111206, 21.93082809], [88.17082977, 21.93055534], [88.17082977, 21.93000031], [88.17166901, 21.92917061], [88.17140198, 21.92889023], [88.17140198, 21.92832947], [88.17111206, 21.92805481], [88.17111206, 21.92777634], [88.17082977, 21.92749023], [88.17082977, 21.9272213], [88.17138672, 21.92666435], [88.17082977, 21.92611122], [88.17082977, 21.92527962], [88.17056274, 21.92500114], [88.17056274, 21.92444992], [88.17028046, 21.92416954], [88.17028046, 21.92361069], [88.16999817, 21.92333031], [88.16999817, 21.92250061], [88.16971588, 21.92222023], [88.16972351, 21.92138863], [88.16889191, 21.92056274], [88.16889191, 21.92028046], [88.16805267, 21.91945267], [88.16805267, 21.91917038], [88.16777802, 21.91889191], [88.16777802, 21.91860771], [88.16694641, 21.91777992], [88.16694641, 21.91749954], [88.16658783, 21.91713715], [88.16611481, 21.91666794], [88.16583252, 21.91666985], [88.16526794, 21.91611099], [88.16500092, 21.91638947], [88.16500092, 21.91666794], [88.16443634, 21.91721916], [88.16443634, 21.91749954], [88.16416931, 21.91777992], [88.16416931, 21.91805649], [88.16388702, 21.9183197], [88.16388702, 21.91889191], [88.16361237, 21.91917038], [88.16361237, 21.91944504], [88.16305542, 21.92000008], [88.16305542, 21.92083359], [88.16278076, 21.92111015], [88.16278076, 21.92139053], [88.16249847, 21.9216671], [88.16249847, 21.92194176], [88.16194153, 21.92250061], [88.16194153, 21.9227829], [88.16166687, 21.92305946], [88.16166687, 21.92361069], [88.16110992, 21.92416573], [88.16110992, 21.92472076], [88.16083527, 21.92499924], [88.1608429, 21.92583084], [88.16055298, 21.92611122], [88.16055298, 21.92666435], [88.16027832, 21.92694664], [88.16027832, 21.92749023], [88.16000366, 21.92777634], [88.16000366, 21.92833328], [88.15972137, 21.92860985], [88.15972137, 21.92917061], [88.1608429, 21.93028069], [88.1608429, 21.93139076], [88.16055298, 21.93166733], [88.16055298, 21.93222237], [88.16083527, 21.93250084], [88.1608429, 21.93499947], [88.16110992, 21.93527794], [88.16110992, 21.93583107], [88.16139221, 21.93611145], [88.16166687, 21.93638992], [88.16194153, 21.93638802], [88.16278076, 21.93722153], [88.16333008, 21.93722153]]], [[[89.02481079, 21.93172836], [89.02452087, 21.93192101], [89.02424622, 21.93207932], [89.02398682, 21.93225479], [89.02372742, 21.93264008], [89.0231781, 21.93320274], [89.02303314, 21.93352318], [89.02271271, 21.9337883], [89.02218628, 21.93404388], [89.02194214, 21.93445015], [89.02166748, 21.93483162], [89.02136993, 21.93519592], [89.02102661, 21.93552971], [89.02066803, 21.93585014], [89.02031708, 21.93618393], [89.01999664, 21.93655205], [89.01967621, 21.936903], [89.01935577, 21.93721581], [89.01902771, 21.93748283], [89.01869202, 21.93769455], [89.01834106, 21.93787193], [89.01799011, 21.9380703], [89.01764679, 21.93831253], [89.01729584, 21.93853378], [89.01696014, 21.93872261], [89.01661682, 21.9389019], [89.01628113, 21.93912315], [89.01584625, 21.93931007], [89.01543427, 21.93956566], [89.0149765, 21.93984222], [89.01449585, 21.94009209], [89.01405334, 21.9403801], [89.01356506, 21.94060707], [89.01307678, 21.94084167], [89.01261902, 21.94110489], [89.01212311, 21.94133186], [89.01158905, 21.94147301], [89.01107788, 21.94168282], [89.0105896, 21.94192314], [89.01004791, 21.94205475], [89.00953674, 21.94223213], [89.0090332, 21.94243813], [89.00848389, 21.94255257], [89.00796509, 21.94274139], [89.00740051, 21.94283676], [89.00730133, 21.94286919], [89.00687408, 21.94301796], [89.00628662, 21.94309235], [89.00572205, 21.94329262], [89.00514221, 21.94349289], [89.00469971, 21.94377708], [89.00430298, 21.94406319], [89.0039978, 21.94441795], [89.00369263, 21.94472313], [89.00370026, 21.94521141], [89.00338745, 21.94550133], [89.00292206, 21.94579124], [89.00242615, 21.94589806], [89.00202179, 21.9461937], [89.00167084, 21.94658089], [89.00134277, 21.94698143], [89.00099945, 21.94735146], [89.00068665, 21.94776917], [89.0, 21.94888878], [88.99972534, 21.94910622], [88.99954987, 21.94948387], [88.99951935, 21.94960785], [88.99945831, 21.94981956], [88.99943542, 21.95012856], [88.99937439, 21.95043373], [88.99922943, 21.95075035], [88.9991684, 21.95122147], [88.9991684, 21.95177269], [88.9991684, 21.95236015], [88.9991684, 21.95294952], [88.99925995, 21.9534874], [88.99945068, 21.95391273], [88.99961853, 21.95424461], [89.0, 21.95472145], [89.00073242, 21.95587158], [89.00125122, 21.9564743], [89.00152588, 21.95689011], [89.00215912, 21.95799828], [89.00251007, 21.95859146], [89.00265503, 21.95876694], [89.00287628, 21.95903015], [89.00312805, 21.95951271], [89.00353241, 21.95983124], [89.00370026, 21.95992088], [89.00409698, 21.96039009], [89.00444031, 21.9606781], [89.00475311, 21.96101952], [89.00511169, 21.96138191], [89.00550842, 21.96174049], [89.005867, 21.96213341], [89.00624084, 21.96247292], [89.00663757, 21.96276283], [89.00701904, 21.96305275], [89.00740814, 21.96333122], [89.00775909, 21.96362114], [89.00810242, 21.96388817], [89.00841522, 21.96416473], [89.00874329, 21.9644413], [89.00907135, 21.96473122], [89.00943756, 21.96503639], [89.00979614, 21.96537209], [89.01008606, 21.96576118], [89.01046753, 21.96602821], [89.01081085, 21.96624565], [89.01109314, 21.96646309], [89.01129913, 21.96671295], [89.01147461, 21.96700859], [89.01172638, 21.96729088], [89.01196289, 21.96764565], [89.01222992, 21.96797752], [89.01250458, 21.96827126], [89.01278687, 21.96853065], [89.01306152, 21.96878052], [89.01335144, 21.96902847], [89.0136795, 21.96925163], [89.01396942, 21.96953011], [89.01425934, 21.96980095], [89.01444244, 21.96994019], [89.01456451, 21.97003746], [89.0147934, 21.97034264], [89.01500702, 21.97066307], [89.01524353, 21.97094345], [89.01541901, 21.97125435], [89.01559448, 21.97156334], [89.01583862, 21.97182274], [89.01609039, 21.97210121], [89.01631927, 21.97243309], [89.01655579, 21.9727726], [89.01683044, 21.97312164], [89.01712799, 21.97356987], [89.01737213, 21.97401237], [89.01764679, 21.97449303], [89.01783752, 21.97525215], [89.01806641, 21.97553444], [89.01799774, 21.9760437], [89.01799011, 21.97650909], [89.0181427, 21.9770298], [89.0181427, 21.97737312], [89.01811218, 21.97772789], [89.01799011, 21.97805214], [89.01792145, 21.97859192], [89.01792145, 21.97881126], [89.01792145, 21.97919846], [89.01773834, 21.97951317], [89.01767731, 21.98008156], [89.01757813, 21.98035049], [89.01728821, 21.98078346], [89.01648712, 21.98198128], [89.01634216, 21.98240089], [89.01611328, 21.98278236], [89.01586151, 21.98315048], [89.01560974, 21.98353577], [89.01526642, 21.98384285], [89.01486969, 21.9841404], [89.01438904, 21.98436546], [89.01383209, 21.98451424], [89.01329803, 21.98471642], [89.01277161, 21.98488235], [89.01226807, 21.98502159], [89.01181793, 21.98522186], [89.01133728, 21.98527908], [89.01085663, 21.98527908], [89.01037598, 21.98527908], [89.00991058, 21.98527908], [89.00948334, 21.98527908], [89.00907135, 21.98527908], [89.00866699, 21.98527908], [89.00821686, 21.98524475], [89.00775909, 21.98504066], [89.00718689, 21.98496056], [89.00660706, 21.98476219], [89.00601196, 21.98473358], [89.00546265, 21.98486137], [89.00508118, 21.98526192], [89.00508118, 21.98591042], [89.00543976, 21.98649025], [89.006073, 21.98682213], [89.0067215, 21.9871006], [89.00739288, 21.98727989], [89.00798798, 21.9875145], [89.00853729, 21.98779106], [89.00905609, 21.98806381], [89.00956726, 21.98835182], [89.01004791, 21.98866081], [89.01056671, 21.98892021], [89.01110077, 21.98917389], [89.0116272, 21.98942947], [89.01213074, 21.98971748], [89.01262665, 21.99001694], [89.01309967, 21.99031639], [89.01356506, 21.99056435], [89.01397705, 21.99083138], [89.01436615, 21.99110985], [89.01474762, 21.99138069], [89.01513672, 21.99167061], [89.01551819, 21.99196053], [89.01587677, 21.99226952], [89.01621246, 21.99261665], [89.01651001, 21.99305153], [89.01685333, 21.9935112], [89.01724243, 21.99397087], [89.01766968, 21.99439049], [89.01821136, 21.99471664], [89.0187912, 21.9949913], [89.01940918, 21.99520302], [89.02006531, 21.99532127], [89.02066803, 21.9955101], [89.02127075, 21.99555779], [89.02181244, 21.99560165], [89.02223206, 21.99578285], [89.02268219, 21.99584579], [89.02313995, 21.99593353], [89.0235672, 21.99611092], [89.02406311, 21.99624062], [89.02471924, 21.99615479], [89.025383, 21.99605942], [89.02597809, 21.99590111], [89.02658081, 21.99585152], [89.02715302, 21.99583817], [89.02765656, 21.99583244], [89.02777863, 21.99583244], [89.02805328, 21.99583244], [89.0284729, 21.99591255], [89.02861023, 21.99611092], [89.02889252, 21.99618721], [89.02923584, 21.99625587], [89.02980042, 21.99653244], [89.03009033, 21.99675941], [89.03045654, 21.99707222], [89.03077698, 21.99728966], [89.03119659, 21.99741173], [89.03144836, 21.99758148], [89.03165436, 21.99788857], [89.03213501, 21.99821663], [89.03253174, 21.99863625], [89.03269196, 21.99897194], [89.03283691, 21.99940491], [89.03279114, 21.99973106], [89.03277588, 22.00000191], [89.03278351, 22.00094223], [89.0328598, 22.00134087], [89.03250122, 22.00208282], [89.03192139, 22.00235176], [89.03142548, 22.00235176], [89.03077698, 22.00214958], [89.0304184, 22.00168037], [89.03019714, 22.0010128], [89.03028107, 22.00000191], [89.0302887, 21.99962044], [89.03022766, 21.99926376], [89.0300827, 21.99895287], [89.02997589, 21.99862862], [89.02973938, 21.99836159], [89.02941132, 21.9981308], [89.02902222, 21.99790001], [89.02871704, 21.99763298], [89.02832794, 21.99742317], [89.02789307, 21.99727058], [89.02736664, 21.99723244], [89.02685547, 21.99723053], [89.02638245, 21.99726486], [89.02596283, 21.99736214], [89.02587128, 21.99738121], [89.02554321, 21.99745178], [89.02500153, 21.99740028], [89.02436066, 21.9972477], [89.02390289, 21.99735069], [89.02340698, 21.99752045], [89.02289581, 21.9976902], [89.02231598, 21.99755287], [89.021698, 21.99751091], [89.02102661, 21.99749184], [89.02037811, 21.99742317], [89.01979065, 21.99721909], [89.01922607, 21.99696159], [89.01869202, 21.99672508], [89.01824188, 21.99641991], [89.01776886, 21.99611092], [89.01728058, 21.99581146], [89.0168457, 21.99546432], [89.01641846, 21.99519157], [89.01602936, 21.99492455], [89.01564026, 21.9946804], [89.01526642, 21.99437141], [89.01487732, 21.99404907], [89.01441956, 21.99373055], [89.01389313, 21.99341965], [89.01338196, 21.99306297], [89.01287079, 21.99271584], [89.0124588, 21.99229431], [89.01203918, 21.99189949], [89.01167297, 21.99147224], [89.01127625, 21.99106026], [89.01070404, 21.99079514], [89.01016235, 21.99052811], [89.0096817, 21.99025154], [89.00923157, 21.99002266], [89.00875854, 21.98986244], [89.00828552, 21.98972893], [89.00779724, 21.98961067], [89.00731659, 21.98943329], [89.00680542, 21.98920631], [89.00624847, 21.98899651], [89.00580597, 21.98866844], [89.00538635, 21.98833275], [89.0050354, 21.98800659], [89.0047226, 21.98767281], [89.00441742, 21.98736191], [89.00405121, 21.98711967], [89.0036087, 21.98693848], [89.00305176, 21.98638916], [89.00305176, 21.98611259], [89.0027771, 21.9858284], [89.0027771, 21.98555565], [89.00250244, 21.98527908], [89.00250244, 21.98473167], [89.002388, 21.98434258], [89.00223541, 21.98401642], [89.00211334, 21.98364067], [89.00189972, 21.9832859], [89.00166321, 21.98291969], [89.00138855, 21.98260117], [89.00109863, 21.98232269], [89.00077057, 21.98205376], [89.0003891, 21.98153877], [89.0, 21.98139], [88.99957275, 21.98080254], [88.99933624, 21.98075485], [88.99904633, 21.98045158], [88.99875641, 21.98014259], [88.99849701, 21.97980309], [88.9981308, 21.97950172], [88.9977951, 21.97911644], [88.99743652, 21.97869301], [88.99703217, 21.97829247], [88.99668121, 21.97783279], [88.99636841, 21.97737122], [88.99604034, 21.9769783], [88.99567413, 21.97665977], [88.99532318, 21.97633171], [88.99498749, 21.97594833], [88.99462128, 21.97557449], [88.99421692, 21.97522163], [88.99386597, 21.97483253], [88.99352264, 21.97447014], [88.99317932, 21.97417259], [88.99286652, 21.9739399], [88.99254608, 21.97371101], [88.99243927, 21.97363091], [88.99172974, 21.9740448], [88.99166107, 21.97472191], [88.9916687, 21.97500038], [88.9916687, 21.97860146], [88.99138641, 21.97889137], [88.99138641, 21.97958183], [88.99143219, 21.98023987], [88.99162292, 21.9808445], [88.9916687, 21.98143387], [88.99164581, 21.98195076], [88.99151611, 21.98238182], [88.99138641, 21.9827404], [88.99124908, 21.98304939], [88.9910965, 21.98335266], [88.99093628, 21.98365974], [88.99079132, 21.98405266], [88.99055481, 21.98443413], [88.99028015, 21.98484612], [88.99000549, 21.98527145], [88.98969269, 21.98567009], [88.9892807, 21.9860096], [88.98887634, 21.98637962], [88.98841095, 21.98674011], [88.98795319, 21.98716354], [88.98739624, 21.98750114], [88.98681641, 21.98780251], [88.98629761, 21.9881382], [88.98573303, 21.9884243], [88.98511505, 21.98864174], [88.98451996, 21.9888916], [88.9839325, 21.98913383], [88.98329163, 21.98924065], [88.98269653, 21.98941231], [88.98205566, 21.98947906], [88.98142242, 21.98966026], [88.98072815, 21.98974991], [88.98004913, 21.98991966], [88.97972107, 21.98999977], [88.97915649, 21.98999977], [88.97888947, 21.99028206], [88.97833252, 21.99027824], [88.97805786, 21.99055672], [88.97750092, 21.99055672], [88.97721863, 21.99083328], [88.97666931, 21.99083328], [88.97638702, 21.99111557], [88.97583008, 21.99110985], [88.97556305, 21.99139214], [88.97807312, 21.99139214], [88.97833252, 21.99110985], [88.97860718, 21.99110985], [88.97888947, 21.99139214], [88.98000336, 21.99138832], [88.9806366, 21.9916935], [88.98109436, 21.99186134], [88.98156738, 21.99201012], [88.98204041, 21.99222755], [88.98252869, 21.99249458], [88.98306274, 21.99279976], [88.98358917, 21.99318123], [88.98410034, 21.9936161], [88.98458862, 21.99409294], [88.98506165, 21.99456215], [88.98548126, 21.99498749], [88.98581696, 21.99538994], [88.98609924, 21.99577522], [88.98631287, 21.9961319], [88.98648834, 21.99648285], [88.98670197, 21.99677658], [88.98693848, 21.99707985], [88.98718262, 21.99741554], [88.98748016, 21.99773216], [88.98780823, 21.99802971], [88.98816681, 21.998312], [88.98855591, 21.99859047], [88.98899078, 21.99887276], [88.98948669, 21.99912071], [88.99003601, 21.99932289], [88.9905777, 21.99949074], [88.99114227, 21.99969292], [88.99250031, 22.00000191], [88.9935379, 22.00087166], [88.99397278, 22.00180817], [88.9941864, 22.00214195], [88.99433136, 22.00254822], [88.99447632, 22.00302315], [88.99460602, 22.00382042], [88.99475861, 22.00442123], [88.99497986, 22.00476265], [88.99533844, 22.00522614], [88.99569702, 22.00555992], [88.9960556, 22.00583076], [88.99641418, 22.00596237], [88.99691772, 22.00616455], [88.99756622, 22.00649834], [88.99820709, 22.00663185], [88.99871063, 22.00676727], [88.99900055, 22.00682831], [88.99935913, 22.00696754], [88.99935913, 22.00710487], [88.99914551, 22.00716972], [88.99856567, 22.00716972], [88.99799347, 22.00703621], [88.99713135, 22.00703621], [88.99691772, 22.00697327], [88.99633789, 22.00682831], [88.99591064, 22.00670242], [88.9954071, 22.00657272], [88.99482727, 22.00630188], [88.99440002, 22.00603485], [88.99411774, 22.0057621], [88.99382782, 22.00536156], [88.99339294, 22.00481224], [88.99311066, 22.00428772], [88.99267578, 22.00335121], [88.99260712, 22.002882], [88.99260712, 22.00254631], [88.99253082, 22.00228119], [88.99209595, 22.00194168], [88.99138641, 22.00147247], [88.98944092, 22.00000191], [88.9890976, 21.99973106], [88.98860168, 21.99969292], [88.98825073, 21.99950981], [88.98788452, 21.99933052], [88.98751068, 21.99910164], [88.98715973, 21.99881172], [88.98681641, 21.99848175], [88.98649597, 21.99813271], [88.98620605, 21.99778175], [88.98589325, 21.99746132], [88.98552704, 21.99714279], [88.98516846, 21.9967556], [88.98487854, 21.99628639], [88.98459625, 21.99586105], [88.98429871, 21.99549294], [88.98400879, 21.99514198], [88.98369598, 21.99477959], [88.98338318, 21.99438286], [88.98303223, 21.99401474], [88.98262024, 21.9937458], [88.98220825, 21.99353218], [88.98182678, 21.99334145], [88.98145294, 21.99319267], [88.98104858, 21.99304008], [88.9806366, 21.99289131], [88.98020935, 21.99275017], [88.9797821, 21.99261665], [88.97939301, 21.99249077], [88.97902679, 21.99240112], [88.97838593, 21.99223137], [88.97499847, 21.99250031], [88.97476196, 21.99292183], [88.974617, 21.99329185], [88.97447205, 21.99364281], [88.97441864, 21.99407768], [88.97432709, 21.99455261], [88.9744873, 21.99504471], [88.9747467, 21.99549294], [88.97503662, 21.99587822], [88.97528839, 21.99624062], [88.97554016, 21.99654961], [88.97573853, 21.99686241], [88.97590637, 21.99718475], [88.97614288, 21.99745178], [88.97639465, 21.99768448], [88.97666931, 21.99793243], [88.97698212, 21.99821091], [88.97738647, 21.99850464], [88.9777832, 21.99892235], [88.97801208, 21.99942207], [88.97833252, 22.00000191], [88.97860718, 22.00028038], [88.97888947, 22.00056267], [88.97888947, 22.00139046], [88.97916412, 22.00166893], [88.97915649, 22.00222206], [88.97944641, 22.00250053], [88.97944641, 22.00333214], [88.97916412, 22.00361061], [88.97915649, 22.00472069], [88.97888947, 22.00500488], [88.97888947, 22.0055542], [88.97860718, 22.00583076], [88.97861481, 22.00611115], [88.9783783, 22.0063324], [88.97832489, 22.0063858], [88.97805786, 22.00666618], [88.97772217, 22.00700951], [88.97742462, 22.00741005], [88.97714996, 22.00787163], [88.97685242, 22.00834846], [88.97638702, 22.00863075], [88.975914, 22.00894928], [88.9754715, 22.00930977], [88.97499847, 22.00967026], [88.9744873, 22.01001167], [88.97393799, 22.01036072], [88.97338867, 22.01076317], [88.97283173, 22.01112938], [88.97227478, 22.01145935], [88.97180939, 22.01177025], [88.97132111, 22.01195908], [88.97087097, 22.01214027], [88.97044373, 22.01233101], [88.97001648, 22.01251221], [88.96961212, 22.01274681], [88.96923065, 22.0130024], [88.96888733, 22.0133152], [88.96856689, 22.01363945], [88.96823883, 22.01395226], [88.96808624, 22.01436043], [88.96806335, 22.01480484], [88.96806335, 22.01520157], [88.96807861, 22.01554108], [88.9681778, 22.01581383], [88.96833038, 22.01605225], [88.96849823, 22.0163002], [88.96862793, 22.01664162], [88.96878815, 22.01699257], [88.96894073, 22.01735115], [88.96916962, 22.01764107], [88.96942139, 22.01793098], [88.9696579, 22.0182209], [88.96987915, 22.01854324], [88.97009277, 22.01888084], [88.97027588, 22.01922035], [88.97046661, 22.01952934], [88.97055817, 22.01987457], [88.97062683, 22.02020073], [88.97080231, 22.02046013], [88.97097015, 22.02070045], [88.97110748, 22.0209713], [88.97123718, 22.02123833], [88.97138977, 22.02151489], [88.97151947, 22.0218029], [88.97164154, 22.02213097], [88.97173309, 22.02253342], [88.97195435, 22.02289009], [88.97221375, 22.02328491], [88.97245026, 22.02374077], [88.97260284, 22.02425194], [88.97278595, 22.02464104], [88.97305298, 22.02499962], [88.97305298, 22.02583313], [88.9733429, 22.0261116], [88.97338104, 22.0272007], [88.97357941, 22.02779388], [88.97374725, 22.02843285], [88.97400665, 22.02899361], [88.9743042, 22.02946281], [88.97460175, 22.02987099], [88.97492981, 22.03022957], [88.9752655, 22.03056335], [88.9756012, 22.03090096], [88.97586823, 22.03131485], [88.97612762, 22.03168297], [88.97637939, 22.03201103], [88.97658539, 22.03232384], [88.97677612, 22.03262138], [88.97696686, 22.03293037], [88.97720337, 22.03326225], [88.97740173, 22.03368187], [88.97753143, 22.03420448], [88.9777298, 22.03471947], [88.97782898, 22.03528786], [88.97807312, 22.03574944], [88.97831726, 22.03621292], [88.97859192, 22.03669167], [88.97886658, 22.03720284], [88.97911072, 22.03775978], [88.97927094, 22.03840065], [88.97953033, 22.03899193], [88.97982788, 22.03959274], [88.98023987, 22.04005814], [88.9806366, 22.04050255], [88.98104858, 22.04086685], [88.98139191, 22.04121208], [88.98171234, 22.04151917], [88.98197937, 22.04171181], [88.98219299, 22.04192162], [88.98240662, 22.04214287], [88.98266602, 22.04239082], [88.98295593, 22.04269028], [88.98327637, 22.04299736], [88.98358154, 22.04330254], [88.98387909, 22.04361153], [88.98418427, 22.04391861], [88.98445129, 22.04424095], [88.98471069, 22.04454231], [88.98493195, 22.04481316], [88.98509979, 22.04508781], [88.98525238, 22.04535103], [88.98536682, 22.0456295], [88.98550415, 22.0459156], [88.98558044, 22.04628181], [88.98568726, 22.0466404], [88.98582458, 22.04698181], [88.98594666, 22.0473423], [88.98606873, 22.04775047], [88.98610687, 22.04819298], [88.9861145, 22.04864693], [88.98610687, 22.04910088], [88.98605347, 22.04955864], [88.98590851, 22.04998207], [88.98583221, 22.05041885], [88.98575592, 22.05086136], [88.98560333, 22.0512619], [88.98551941, 22.05171013], [88.98538208, 22.05213356], [88.9852829, 22.05256081], [88.98517609, 22.0529995], [88.98503876, 22.05342484], [88.98497772, 22.0538578], [88.98488617, 22.05423164], [88.98477173, 22.0544796], [88.98477936, 22.0547123], [88.98493195, 22.05494881], [88.98516846, 22.05522346], [88.98555756, 22.05545235], [88.98615265, 22.05550194], [88.98647308, 22.0554924], [88.98682404, 22.05548286], [88.98748016, 22.05531693], [88.98814392, 22.05517387], [88.98879242, 22.05501556], [88.98940277, 22.05487633], [88.98996735, 22.05471611], [88.99045563, 22.0545578], [88.99086761, 22.05446053], [88.99111176, 22.05444527], [88.99194336, 22.05444527], [88.99205017, 22.05455208], [88.99222565, 22.05472374], [88.99250031, 22.05472183], [88.9927597, 22.05500031], [88.99294281, 22.05485153], [88.99347687, 22.05473328], [88.99401093, 22.05459023], [88.99452972, 22.05456543], [88.99501801, 22.05477905], [88.99547577, 22.05524254], [88.99594116, 22.05556488], [88.99639893, 22.05581093], [88.99685669, 22.05606461], [88.99723053, 22.05637169], [88.99765015, 22.05666351], [88.99810791, 22.05695152], [88.99859619, 22.05717278], [88.99909973, 22.05735207], [88.99957275, 22.05759239], [89.0, 22.05777931], [89.00027466, 22.05830383], [89.00077057, 22.05894279], [89.00097656, 22.05908012], [89.00119781, 22.0592804], [89.00141907, 22.05935287], [89.00170135, 22.05935287], [89.00228119, 22.05921173], [89.00241852, 22.0589447], [89.00256348, 22.05861092], [89.00255585, 22.05827141], [89.00263977, 22.05787277], [89.00285339, 22.05760384], [89.00285339, 22.05740547], [89.00299835, 22.05707169], [89.00306702, 22.0567894], [89.00314331, 22.05666542], [89.00322723, 22.0564537], [89.00357056, 22.05613136], [89.00388336, 22.05576134], [89.00411987, 22.05534935], [89.00430298, 22.05490303], [89.00449371, 22.05447197], [89.0047226, 22.05407524], [89.00496674, 22.05365944], [89.00527954, 22.0532589], [89.00562286, 22.05285263], [89.00593567, 22.05247688], [89.00614166, 22.0522995], [89.0063858, 22.0522213], [89.00777435, 22.05083275], [89.0083313, 22.0508213], [89.00881958, 22.05120277], [89.00926208, 22.05161285], [89.0096817, 22.05206108], [89.0100174, 22.05256081], [89.01023102, 22.05307961], [89.01035309, 22.05359077], [89.01055145, 22.05402184], [89.01074219, 22.0544281], [89.01092529, 22.05482864], [89.01107025, 22.05526161], [89.01117706, 22.05573082], [89.01133728, 22.05621147], [89.01145172, 22.05674744], [89.01161194, 22.0573101], [89.01173401, 22.05787659], [89.01187897, 22.05834007], [89.01199341, 22.05874062], [89.01211548, 22.05906487], [89.01222229, 22.05939293], [89.01229858, 22.05976105], [89.0124054, 22.06012917], [89.01258087, 22.06050301], [89.01280212, 22.06089211], [89.01303864, 22.0612793], [89.01335144, 22.06156731], [89.01370239, 22.06186676], [89.01381683, 22.06217957], [89.01425171, 22.06259155], [89.01467896, 22.06266022], [89.0151062, 22.06286049], [89.01547241, 22.06293106], [89.01568604, 22.06293106], [89.01618958, 22.06279182], [89.01633453, 22.06265831], [89.01661682, 22.06239128], [89.01669312, 22.06199074], [89.01669312, 22.06092262], [89.01654816, 22.06051064], [89.01633453, 22.06016159], [89.01618195, 22.05954933], [89.01605225, 22.05891228], [89.01584625, 22.05830956], [89.01566315, 22.05767822], [89.01551819, 22.05702972], [89.01535797, 22.05643272], [89.01528931, 22.05590439], [89.01528168, 22.05541039], [89.01531219, 22.05494118], [89.01541138, 22.05446053], [89.01551056, 22.0539856], [89.01554871, 22.05347252], [89.01555634, 22.05294991], [89.01557922, 22.05241203], [89.01567078, 22.05187416], [89.01587677, 22.0513649], [89.0161972, 22.05092049], [89.0166626, 22.05063057], [89.01724243, 22.05048752], [89.01781464, 22.05031776], [89.01835632, 22.05019188], [89.01889038, 22.05000114], [89.01917267, 22.04972267], [89.01998901, 22.04972267], [89.02027893, 22.05000114], [89.02054596, 22.05000114], [89.02083588, 22.05027962], [89.02137756, 22.05027962], [89.02169037, 22.05034065], [89.02211761, 22.05049324], [89.02256012, 22.0506115], [89.02295685, 22.05080032], [89.02337646, 22.05096817], [89.0238266, 22.05115318], [89.02431488, 22.05133247], [89.02487946, 22.05146217], [89.0255127, 22.05169487], [89.02620697, 22.05192375], [89.02667236, 22.05179024], [89.02710724, 22.05162239], [89.02755737, 22.05143166], [89.02811432, 22.05138588], [89.02873993, 22.0513401], [89.02942657, 22.05120277], [89.03013611, 22.05130196], [89.03087616, 22.05116081], [89.03161621, 22.05114746], [89.03231812, 22.05113029], [89.03296661, 22.05111122], [89.03356934, 22.05107307], [89.03408813, 22.05088234], [89.03463745, 22.05079269], [89.03517914, 22.05060005], [89.03579712, 22.05051041], [89.03646088, 22.05032158], [89.03715515, 22.05023575], [89.03782654, 22.05000114], [89.03849792, 22.04972839], [89.03914642, 22.04948997], [89.03981781, 22.04937744], [89.04035187, 22.04916191], [89.04080963, 22.04887199], [89.04120636, 22.04850388], [89.04157257, 22.04803658], [89.04192352, 22.04749107], [89.0422287, 22.04687309], [89.04251862, 22.04628181], [89.04283142, 22.04577446], [89.04309845, 22.04530144], [89.04330444, 22.0448513], [89.04343414, 22.04435539], [89.0435791, 22.04385185], [89.04364777, 22.04330826], [89.04382324, 22.04282951], [89.04396057, 22.04233932], [89.04415894, 22.04195976], [89.04441833, 22.04163361], [89.04457855, 22.04125786], [89.04473877, 22.04086113], [89.04492188, 22.04048157], [89.04507446, 22.04006195], [89.04528809, 22.03965187], [89.04555511, 22.0392437], [89.04582977, 22.03881264], [89.04582977, 22.03861046], [89.04611206, 22.03833008], [89.04611206, 22.03805542], [89.04666901, 22.03750038], [89.04666901, 22.03722191], [89.04777527, 22.03611183], [89.04777527, 22.03583336], [89.04805756, 22.03555107], [89.04805756, 22.03472137], [89.05055237, 22.03222656], [89.05055237, 22.03194427], [89.0513916, 22.03111076], [89.0513916, 22.03083229], [89.06416321, 22.01805305], [89.06416321, 22.01777077], [89.0661087, 22.0158329], [89.0661087, 22.01555824], [89.06803894, 22.01361275], [89.06803894, 22.01332855], [89.06833649, 22.0130558], [89.06835175, 22.01277924], [89.06861115, 22.01250267], [89.06861115, 22.01166916], [89.06944275, 22.01083183], [89.06944275, 22.01055527], [89.06990051, 22.01025391], [89.07028961, 22.00984001], [89.07065582, 22.00943184], [89.07099915, 22.00901985], [89.07131958, 22.00867271], [89.07156372, 22.00832176], [89.07176208, 22.00796318], [89.07193756, 22.00759315], [89.07209015, 22.0072403], [89.072258, 22.0069294], [89.07247162, 22.00666237], [89.07260132, 22.00630379], [89.07277679, 22.00591469], [89.07296753, 22.00547981], [89.07309723, 22.00498009], [89.07332611, 22.00455284], [89.07357788, 22.00415993], [89.07368469, 22.0037365], [89.07384491, 22.00340843], [89.07389069, 22.00306129], [89.07395935, 22.00273514], [89.0741272, 22.0024395], [89.07417297, 22.00206184], [89.07417297, 22.00164223], [89.07424164, 22.00120735], [89.07454681, 22.00090027], [89.07444763, 22.00028038], [89.07472229, 22.00000191], [89.07492828, 21.99940491], [89.07509613, 21.99913216], [89.07527161, 21.99880028], [89.07541656, 21.99847221], [89.07553101, 21.99814987], [89.07554626, 21.99778175], [89.07555389, 21.99749756], [89.07556152, 21.99735832], [89.07563019, 21.99689293], [89.07579803, 21.99640083], [89.07583618, 21.99585152], [89.0759201, 21.99537086], [89.07608032, 21.9949894], [89.07615662, 21.99463844], [89.0763092, 21.99437141], [89.07637787, 21.99406242], [89.07641602, 21.99371147], [89.07658386, 21.9933815], [89.07666016, 21.99294472], [89.07673645, 21.99245262], [89.07691956, 21.99196053], [89.07705688, 21.99142838], [89.07723236, 21.99090004], [89.07744598, 21.99039268], [89.07751465, 21.98986816], [89.07740784, 21.98941994], [89.07744598, 21.98886299], [89.07772827, 21.98830223], [89.07772827, 21.98762321], [89.07800293, 21.98693275], [89.07801819, 21.98641777], [89.07776642, 21.98592949], [89.07772827, 21.98542023], [89.07777405, 21.9849205], [89.07776642, 21.9843502], [89.07793427, 21.9839077], [89.07787323, 21.98341942], [89.07791901, 21.98269081], [89.07778931, 21.98205185], [89.07772827, 21.98149109], [89.07758331, 21.9810009], [89.07746887, 21.98048973], [89.07723999, 21.98002052], [89.07695007, 21.9795475], [89.07666779, 21.97900963], [89.07639313, 21.97841072], [89.07614899, 21.97776985], [89.07604218, 21.97707558], [89.07582855, 21.97646141], [89.07556152, 21.97591209], [89.07530975, 21.97538948], [89.07512665, 21.97486115], [89.07492828, 21.9743824], [89.07470703, 21.9738903], [89.07442474, 21.97343445], [89.07410431, 21.97296906], [89.07388306, 21.9724102], [89.07361603, 21.97186089], [89.07341766, 21.97132874], [89.07329559, 21.97077751], [89.07309723, 21.9702816], [89.07293701, 21.96941376], [89.07235718, 21.96927071], [89.07181549, 21.97034836], [89.07156372, 21.97128487], [89.07131195, 21.9718914], [89.07113647, 21.9724865], [89.07099152, 21.97301483], [89.07092285, 21.97353172], [89.07086945, 21.97406197], [89.07080841, 21.97462273], [89.07077026, 21.97522354], [89.07068634, 21.97585678], [89.07067108, 21.97652626], [89.07073975, 21.97720337], [89.0708313, 21.97784233], [89.07086182, 21.97850227], [89.07087708, 21.97915077], [89.07092285, 21.97980309], [89.07093048, 21.98045921], [89.07090759, 21.98113441], [89.07087708, 21.98181915], [89.07090759, 21.98251152], [89.07092285, 21.98317146], [89.07080841, 21.98378372], [89.07058716, 21.98429871], [89.07042694, 21.98437309], [89.07006073, 21.98473167], [89.06944275, 21.98473167], [89.06932068, 21.98437309], [89.06974792, 21.98402214], [89.07000732, 21.98305511], [89.07012177, 21.98262215], [89.07015228, 21.98249817], [89.0700531, 21.98184013], [89.07003784, 21.98125076], [89.07002258, 21.98067474], [89.06978607, 21.980093], [89.06976318, 21.97953224], [89.06970215, 21.97897148], [89.06970215, 21.9783802], [89.06969452, 21.97780991], [89.06965637, 21.9772625], [89.06960297, 21.97675133], [89.06958008, 21.9761734], [89.06958771, 21.97552299], [89.06965637, 21.97487068], [89.06980896, 21.97422218], [89.06994629, 21.97356224], [89.07003021, 21.97298241], [89.07006073, 21.97243309], [89.07013702, 21.97192955], [89.07026672, 21.97144127], [89.0704422, 21.97101021], [89.07063293, 21.97062111], [89.07080078, 21.97025108], [89.07095337, 21.96983147], [89.07115173, 21.96936989], [89.07144165, 21.96887016], [89.07183838, 21.96835136], [89.07214355, 21.96671486], [89.07193756, 21.96613503], [89.07174683, 21.96555328], [89.07190704, 21.9649353], [89.07187653, 21.96449089], [89.0715332, 21.96415138], [89.07121277, 21.9638176], [89.07125854, 21.9628315], [89.07111359, 21.96219635], [89.07116699, 21.96170807], [89.07120514, 21.9612999], [89.07113647, 21.96087074], [89.07105255, 21.96049118], [89.07086945, 21.96021271], [89.0708313, 21.95984077], [89.0708313, 21.9594326], [89.0708313, 21.95897293], [89.0708313, 21.95845222], [89.0708313, 21.95786476], [89.07069397, 21.95736122], [89.07054901, 21.95672035], [89.07047272, 21.95617104], [89.07035828, 21.95561028], [89.07028961, 21.95501709], [89.07026672, 21.95437431], [89.06996155, 21.95390511], [89.06971741, 21.95334625], [89.06952667, 21.95277977], [89.06964111, 21.95219231], [89.0694809, 21.95165825], [89.06939697, 21.95112038], [89.06922913, 21.95066261], [89.06916046, 21.95016289], [89.0690918, 21.94967842], [89.06904602, 21.94955826], [89.06892395, 21.94923782], [89.0688858, 21.94877052], [89.0688858, 21.9482708], [89.0688324, 21.94773483], [89.06859589, 21.94720268], [89.068367, 21.94663048], [89.06819916, 21.94603157], [89.06794739, 21.9455204], [89.06772614, 21.94502449], [89.06748199, 21.94453621], [89.0672226, 21.94405365], [89.06699371, 21.9435482], [89.06684875, 21.94299126], [89.06667328, 21.94246292], [89.06651306, 21.94196129], [89.06632996, 21.94149017], [89.06609344, 21.94108391], [89.06586456, 21.9406395], [89.06575012, 21.94009209], [89.06552887, 21.93954277], [89.06524658, 21.93902016], [89.06495667, 21.93855095], [89.06474304, 21.93811035], [89.06461334, 21.93767929], [89.06445313, 21.93725014], [89.06430054, 21.93678856], [89.0641098, 21.93626213], [89.06384277, 21.93572044], [89.06358337, 21.93509102], [89.06328583, 21.93451118], [89.06286621, 21.93411064], [89.06257629, 21.93383789], [89.06246948, 21.9337368], [89.0620575, 21.93342018], [89.06169128, 21.93309784], [89.06128693, 21.93283844], [89.06080627, 21.93268013], [89.06066895, 21.9325695], [89.06047058, 21.93240547], [89.06015015, 21.93212318], [89.05976105, 21.9319706], [89.05932617, 21.93193817], [89.05887604, 21.93194008], [89.05870056, 21.93194008], [89.0584259, 21.93193817], [89.05796814, 21.93195152], [89.05747223, 21.93195152], [89.05692291, 21.93192101], [89.05631256, 21.93177223], [89.05562592, 21.93168259], [89.05490112, 21.93165016], [89.05420685, 21.93155289], [89.05361176, 21.93137169], [89.05316162, 21.93111229], [89.05278015, 21.93084145], [89.05243683, 21.93055153], [89.05233765, 21.93045998], [89.05213928, 21.93028069], [89.05184937, 21.93007088], [89.05152893, 21.93010139], [89.05137634, 21.93026161], [89.05101776, 21.93064117], [89.05043793, 21.93098068], [89.04998779, 21.93139076], [89.04990387, 21.93148232], [89.04960632, 21.93180275], [89.04930115, 21.93219185], [89.04895782, 21.93253136], [89.04858398, 21.93281937], [89.04814148, 21.93304825], [89.04763031, 21.93322945], [89.04699707, 21.93326187], [89.0463562, 21.93317223], [89.04570007, 21.93310356], [89.04501343, 21.93307686], [89.04409027, 21.93268394], [89.04332733, 21.93290138], [89.04290009, 21.93342209], [89.04264069, 21.93382454], [89.04216766, 21.93404388], [89.04206085, 21.934412], [89.04223633, 21.93510246], [89.04216003, 21.93582726], [89.04221344, 21.93652725], [89.04223633, 21.93720245], [89.04225922, 21.93784904], [89.04226685, 21.93845558], [89.04226685, 21.93901443], [89.04231262, 21.93951988], [89.04227448, 21.94001198], [89.04225922, 21.94050407], [89.04226685, 21.94101143], [89.04214478, 21.9414959], [89.04199982, 21.94198036], [89.04189301, 21.9425106], [89.04178619, 21.94304085], [89.04177856, 21.94359589], [89.04187012, 21.94415092], [89.04191589, 21.94472313], [89.04193878, 21.94527626], [89.04194641, 21.94582939], [89.04194641, 21.94638824], [89.04191589, 21.94693947], [89.04187775, 21.94750023], [89.04165649, 21.94917107], [89.04185486, 21.94986534], [89.04213715, 21.95008278], [89.04193878, 21.95049858], [89.04138947, 21.9506321], [89.04103851, 21.95104408], [89.04084015, 21.95091057], [89.04057312, 21.95042992], [89.0404129, 21.95005608], [89.04062653, 21.94852257], [89.04064178, 21.94796753], [89.04057312, 21.94728088], [89.04070282, 21.9467907], [89.04086304, 21.94594193], [89.04080963, 21.94523811], [89.04080963, 21.94477272], [89.04078674, 21.94434166], [89.04074097, 21.94384766], [89.04071045, 21.94335175], [89.04082489, 21.94314575], [89.040802, 21.9425602], [89.04087067, 21.94202232], [89.04090881, 21.94141388], [89.04096985, 21.94083977], [89.04096222, 21.94045258], [89.04092407, 21.94002724], [89.04093933, 21.93962288], [89.04096222, 21.93918037], [89.04102325, 21.93869591], [89.04103088, 21.93818855], [89.04099274, 21.93771172], [89.04099274, 21.9372921], [89.04115295, 21.93640518], [89.04120636, 21.93588066], [89.04116058, 21.93535042], [89.04114532, 21.93486023], [89.04116821, 21.93440437], [89.04117584, 21.93394661], [89.04122162, 21.93350029], [89.04134369, 21.93307495], [89.04146576, 21.93263054], [89.04170227, 21.93224144], [89.04197693, 21.93193245], [89.04234314, 21.93173409], [89.04273224, 21.93166542], [89.0431366, 21.93165016], [89.04355621, 21.93166161], [89.04397583, 21.93169212], [89.04440308, 21.93177414], [89.04485321, 21.93189049], [89.04534149, 21.93195152], [89.04585266, 21.9319706], [89.04637146, 21.9319725], [89.04688263, 21.93195534], [89.04738617, 21.93189049], [89.04785156, 21.9317112], [89.04828644, 21.93147278], [89.0486908, 21.93110085], [89.0488205, 21.93095589], [89.04911041, 21.93061256], [89.04951477, 21.93003654], [89.04946136, 21.92984962], [89.04942322, 21.92970848], [89.04914093, 21.92944145], [89.04877472, 21.92920685], [89.04833221, 21.92905045], [89.04785156, 21.9289093], [89.0472641, 21.92884827], [89.04691315, 21.92873764], [89.04664612, 21.92865372], [89.04593658, 21.92860985], [89.0451889, 21.92860985], [89.04442596, 21.92858315], [89.04367065, 21.92867088], [89.04293823, 21.92876244], [89.04226685, 21.92875099], [89.04162598, 21.92847824], [89.04116058, 21.92825127], [89.04051971, 21.92823982], [89.04001617, 21.92830276], [89.03959656, 21.92826271], [89.03925323, 21.92812157], [89.03890228, 21.92805862], [89.03848267, 21.9280529], [89.03804016, 21.92801666], [89.03756714, 21.92783165], [89.03704071, 21.92778206], [89.03646088, 21.9277401], [89.03592682, 21.92754364], [89.03539276, 21.92738533], [89.03494263, 21.92707253], [89.03444672, 21.92684364], [89.03397369, 21.92666054], [89.03354645, 21.9264698], [89.03311157, 21.92635155], [89.03269958, 21.92616272], [89.03221893, 21.92612267], [89.03173828, 21.926157], [89.03122711, 21.92625999], [89.03079224, 21.92630577], [89.03032684, 21.9264431], [89.03007507, 21.92689705], [89.02967834, 21.92736626], [89.02980042, 21.92796135], [89.02960205, 21.9281826], [89.02903748, 21.92811012], [89.0284729, 21.92826271], [89.02826691, 21.92844391], [89.02793884, 21.92874336], [89.0275116, 21.92924309], [89.02722931, 21.92942047], [89.02680969, 21.92963982], [89.02648163, 21.92990112], [89.02616119, 21.93026161], [89.02585602, 21.93048286], [89.02552795, 21.93062973], [89.02523804, 21.93110466], [89.0252533, 21.93157005], [89.02481079, 21.93172836]]], [[[88.86847687, 21.9220295], [88.86803436, 21.9220047], [88.8614502, 21.91958427], [88.85658264, 21.91905975], [88.84970093, 21.92039108], [88.84111023, 21.92468834], [88.83882141, 21.92738533], [88.83452606, 21.93276024], [88.83289337, 21.93484497], [88.8299408, 21.93760109], [88.82483673, 21.93984985], [88.82084656, 21.94049644], [88.81648254, 21.94074059], [88.81639099, 21.94111061], [88.8161087, 21.94083023], [88.81500244, 21.94083595], [88.81472015, 21.94055748], [88.81416321, 21.94055939], [88.81388855, 21.94028091], [88.8133316, 21.94028091], [88.81305695, 21.94000053], [88.81222534, 21.94000053], [88.81194305, 21.93972206], [88.8116684, 21.93972206], [88.81138611, 21.93944359], [88.80999756, 21.93944359], [88.80979156, 21.93923569], [88.80944824, 21.93888855], [88.80860901, 21.93889046], [88.80832672, 21.93917084], [88.80805206, 21.93916512], [88.80786133, 21.93935966], [88.8077774, 21.93944359], [88.80750275, 21.93943024], [88.8069458, 21.94000053], [88.80639648, 21.94000053], [88.80610657, 21.94028091], [88.80526733, 21.94028091], [88.80500031, 21.94055939], [88.80444336, 21.94055748], [88.8041687, 21.94083595], [88.80388641, 21.94083023], [88.80361176, 21.94111061], [88.8033371, 21.94111061], [88.80304718, 21.94139099], [88.80249786, 21.94139099], [88.80222321, 21.94166946], [88.80194092, 21.94166565], [88.80166626, 21.94194412], [88.80083466, 21.94194412], [88.80055237, 21.9422226], [88.79750061, 21.9422226], [88.79722595, 21.94194412], [88.79499817, 21.94194412], [88.79472351, 21.94166565], [88.79332733, 21.94166946], [88.79305267, 21.94139099], [88.79139709, 21.94139099], [88.79110718, 21.94166946], [88.79055786, 21.94166946], [88.78943634, 21.94277954], [88.78944397, 21.94305611], [88.78916931, 21.94333267], [88.78916931, 21.94611168], [88.78944397, 21.94638824], [88.78943634, 21.94722176], [88.78971863, 21.94750023], [88.78971863, 21.94933128], [88.78971863, 21.94944382], [88.79000092, 21.94972229], [88.79000092, 21.95194435], [88.78971863, 21.95222092], [88.78971863, 21.95249939], [88.78916931, 21.95305443], [88.78916931, 21.95333099], [88.78833008, 21.95417023], [88.78806305, 21.95417023], [88.78722382, 21.95499992], [88.78583527, 21.95499992], [88.78555298, 21.95472145], [88.78527832, 21.95472145], [88.78500366, 21.95444679], [88.78472137, 21.95444679], [88.78416443, 21.95388794], [88.78388977, 21.95388985], [88.78277588, 21.95277977], [88.78250122, 21.95277977], [88.78111267, 21.95139122], [88.78111267, 21.95111084], [88.78056335, 21.95055962], [88.78056335, 21.95028114], [88.78028107, 21.95000076], [88.78028107, 21.94944191], [88.77999878, 21.94916725], [88.77999878, 21.94889069], [88.77985382, 21.94874573], [88.77944183, 21.94833374], [88.77944183, 21.94805527], [88.77916718, 21.94778061], [88.77916718, 21.94695282], [88.77889252, 21.94667053], [88.77889252, 21.94639015], [88.77805328, 21.94556236], [88.77805328, 21.94528008], [88.77749634, 21.94472122], [88.77749634, 21.94444466], [88.77639008, 21.94333267], [88.77555847, 21.94333076], [88.77527618, 21.94361115], [88.77500153, 21.94361115], [88.77471924, 21.94388962], [88.77443695, 21.94388962], [88.77416992, 21.94416809], [88.77388763, 21.94416618], [88.77361298, 21.94444466], [88.77333069, 21.94444466], [88.77305603, 21.94472313], [88.77278137, 21.94472122], [88.7722168, 21.94528008], [88.77194214, 21.94528008], [88.77166748, 21.94556236], [88.77111053, 21.94555473], [88.77055359, 21.94611168], [88.76999664, 21.94611168], [88.76944733, 21.94667053], [88.76917267, 21.94667053], [88.76832581, 21.94750023], [88.76805878, 21.94750023], [88.76750183, 21.9480629], [88.76722717, 21.9480629], [88.76638794, 21.94889069], [88.76611328, 21.94888878], [88.76578522, 21.94921494], [88.76305389, 21.95194435], [88.76305389, 21.95222282], [88.76277924, 21.95222092], [88.76222229, 21.95277977], [88.76167297, 21.95277977], [88.76166534, 21.95305443], [88.76139069, 21.9533329], [88.7611084, 21.9533329], [88.76083374, 21.95361137], [88.75971985, 21.95360947], [88.75945282, 21.95388985], [88.75911713, 21.95388794], [88.75805664, 21.95388985], [88.75776672, 21.95417023], [88.75749969, 21.95416451], [88.75694275, 21.95472145], [88.75666809, 21.95471954], [88.7563858, 21.95499992], [88.75611115, 21.95499992], [88.75583649, 21.9552803], [88.75528717, 21.9552803], [88.75499725, 21.95556068], [88.75444794, 21.95555687], [88.75416565, 21.95583344], [88.75333405, 21.95583344], [88.75305176, 21.95611191], [88.75250244, 21.95611191], [88.75166321, 21.9569397], [88.75166321, 21.95889091], [88.7519455, 21.95916748], [88.7519455, 21.95944405], [88.75222778, 21.95972061], [88.75222778, 21.95999908], [88.75250244, 21.96027946], [88.75250244, 21.96055603], [88.7527771, 21.9608326], [88.7527771, 21.96138954], [88.75305176, 21.96166611], [88.75305176, 21.96194267], [88.7536087, 21.96249962], [88.7536087, 21.96333122], [88.75389099, 21.96362114], [88.75389099, 21.96444321], [88.75417328, 21.96471977], [88.75416565, 21.96555328], [88.75444794, 21.96582985], [88.75444794, 21.96611023], [88.7547226, 21.9663887], [88.7547226, 21.96693993], [88.75554657, 21.96778107], [88.75554657, 21.96861076], [88.75583649, 21.96861076], [88.75583649, 21.96889114], [88.75611115, 21.96916771], [88.75611115, 21.96946144], [88.75611115, 21.97000122], [88.7563858, 21.97027969], [88.7563858, 21.97110748], [88.75666809, 21.97138977], [88.75666809, 21.97222137], [88.75694275, 21.97250175], [88.75694275, 21.97444534], [88.75666809, 21.97472191], [88.75666809, 21.97527695], [88.75611115, 21.97583008], [88.75611115, 21.97611046], [88.75583649, 21.97639084], [88.75583649, 21.9766674], [88.7555542, 21.97694206], [88.7555542, 21.97722244], [88.75333405, 21.9794445], [88.75305176, 21.97944069], [88.75222778, 21.98027992], [88.75195313, 21.98027992], [88.75166321, 21.98056221], [88.75138855, 21.9805584], [88.75111389, 21.98083305], [88.7508316, 21.98083305], [88.74972534, 21.98194695], [88.74973297, 21.9822216], [88.75, 21.98249817], [88.75, 21.98305511], [88.7508316, 21.98389053], [88.75138855, 21.98444557], [88.75166321, 21.98444176], [88.75180054, 21.9845829], [88.75195313, 21.98473167], [88.75219727, 21.98473167], [88.75250244, 21.98500252], [88.75305176, 21.98500252], [88.75332642, 21.98527908], [88.75723267, 21.98527908], [88.75776672, 21.98473167], [88.76167297, 21.98473167], [88.76194763, 21.98444176], [88.76444244, 21.98444176], [88.7647171, 21.98473167], [88.76499939, 21.98473167], [88.76526642, 21.98500252], [88.76555634, 21.98500252], [88.76583099, 21.98527908], [88.76638794, 21.98527908], [88.76667023, 21.98555946], [88.76694489, 21.98555565], [88.76721954, 21.98583412], [88.76750183, 21.9858284], [88.76777649, 21.98611259], [88.76805878, 21.98611259], [88.77054596, 21.98861122], [88.77083588, 21.98861122], [88.77166748, 21.98944664], [88.77194214, 21.98944473], [88.77205658, 21.98955536], [88.77222443, 21.9897213], [88.77444458, 21.9897213], [88.77527618, 21.98888969], [88.77555847, 21.98888969], [88.77694702, 21.98750114], [88.77722168, 21.98750114], [88.77971649, 21.98500252], [88.77999878, 21.98500252], [88.78051758, 21.9844799], [88.78083038, 21.9841671], [88.78111267, 21.98417091], [88.78138733, 21.98389244], [88.78166962, 21.98389244], [88.78238678, 21.98326302], [88.78289795, 21.98286247], [88.78325653, 21.98244858], [88.7833252, 21.98164749], [88.78209686, 21.98056984], [88.78116608, 21.97929382], [88.78055573, 21.97861099], [88.78010559, 21.97801971], [88.77999115, 21.97760201], [88.7800293, 21.97627068], [88.78031921, 21.97499275], [88.78103638, 21.97364235], [88.78196716, 21.97270393], [88.78382874, 21.97203064], [88.78526306, 21.97149086], [88.78762054, 21.9709568], [88.78990936, 21.97062111], [88.79105377, 21.97062111], [88.79105377, 21.9707222], [88.79227448, 21.97052383], [88.79251099, 21.97054291], [88.79449463, 21.9707222], [88.79628754, 21.9707222], [88.79792786, 21.97038841], [88.79921722, 21.97025108], [88.80001068, 21.97039223], [88.80029297, 21.97045326], [88.80007935, 21.97112083], [88.79950714, 21.97153091], [88.79828644, 21.97166252], [88.7932663, 21.97166252], [88.79133606, 21.97183037], [88.78971863, 21.97183037], [88.78912354, 21.97183037], [88.78640747, 21.97223473], [88.78525543, 21.9727726], [88.78482819, 21.97324181], [88.78453827, 21.97338295], [88.78411102, 21.97310638], [88.78347015, 21.97344017], [88.78224945, 21.97425461], [88.78174591, 21.97486115], [88.78189087, 21.9750576], [88.78189087, 21.97538948], [88.78145599, 21.97620201], [88.78174591, 21.9765377], [88.78174591, 21.97828484], [88.78289795, 21.97902489], [88.78411865, 21.98003006], [88.78468323, 21.98043823], [88.78489685, 21.98178482], [88.78525543, 21.98265648], [88.78546906, 21.98265457], [88.7858963, 21.98265266], [88.78675842, 21.98278809], [88.787117, 21.9831295], [88.78804779, 21.98353004], [88.78876495, 21.98373032], [88.78926849, 21.98413467], [88.78990936, 21.98434258], [88.78990936, 21.98454285], [88.7898407, 21.98527718], [88.78940582, 21.98568153], [88.78884125, 21.9857502], [88.78826904, 21.98535156], [88.78762054, 21.98508263], [88.78704834, 21.98454285], [88.78626251, 21.9842701], [88.78533173, 21.98426819], [88.78468323, 21.9843998], [88.78360748, 21.98527908], [88.78333282, 21.98527908], [88.78250122, 21.98611259], [88.7822113, 21.98611259], [88.78193665, 21.98638916], [88.78166962, 21.98638916], [88.77777863, 21.99028206], [88.77722168, 21.99027824], [88.77666473, 21.99083328], [88.77527618, 21.99083328], [88.77500153, 21.99111557], [88.77443695, 21.99110985], [88.77416992, 21.99139214], [88.7722168, 21.99139214], [88.77194214, 21.99110985], [88.77111053, 21.99111557], [88.77083588, 21.99083328], [88.77055359, 21.99083328], [88.77027893, 21.99055672], [88.76972198, 21.99055672], [88.76947784, 21.99030876], [88.76917267, 21.99028206], [88.76860809, 21.9897213], [88.76833344, 21.9897213], [88.76638794, 21.98777962], [88.76592255, 21.987463], [88.76558685, 21.98722267], [88.76544952, 21.98712349], [88.76500702, 21.98685646], [88.76499939, 21.98666954], [88.76444244, 21.98666954], [88.76416779, 21.98638916], [88.76333618, 21.98638916], [88.76304626, 21.98611259], [88.76027679, 21.98611259], [88.76000214, 21.98638916], [88.75971985, 21.98638916], [88.75945282, 21.98666954], [88.75888824, 21.98666573], [88.75861359, 21.9869442], [88.75722504, 21.9869442], [88.75694275, 21.98722267], [88.75554657, 21.98722267], [88.75528717, 21.98750114], [88.75447845, 21.98750114], [88.75417328, 21.98750114], [88.7536087, 21.98805809], [88.7536087, 21.98833275], [88.75389099, 21.98861122], [88.75389099, 21.98888969], [88.75417328, 21.98917389], [88.75444794, 21.98917389], [88.75495148, 21.98971176], [88.75499725, 21.98999977], [88.75776672, 21.99278069], [88.75777435, 21.99305534], [88.7583313, 21.99360085], [88.7583313, 21.99389076], [88.75888824, 21.99444389], [88.75888824, 21.99472237], [88.75971985, 21.99555779], [88.75971985, 21.99583244], [88.76000214, 21.99611092], [88.76000214, 21.99666786], [88.76027679, 21.99694252], [88.76027679, 21.99749756], [88.76055908, 21.99777985], [88.76055908, 21.99860764], [88.76082611, 21.99889183], [88.76082611, 22.00000191], [88.76110077, 22.00028038], [88.76112366, 22.00066948], [88.76113129, 22.00138283], [88.76111603, 22.00214958], [88.76110077, 22.00289917], [88.7611084, 22.00364494], [88.76110077, 22.00436974], [88.76113129, 22.00509071], [88.7612381, 22.00575829], [88.76148224, 22.0063343], [88.76187897, 22.00682831], [88.76243591, 22.00721169], [88.76303101, 22.00752449], [88.76360321, 22.00779152], [88.76413727, 22.00803375], [88.76461792, 22.00824547], [88.76504517, 22.00848198], [88.7654953, 22.0086956], [88.76596069, 22.0089016], [88.76646423, 22.00909805], [88.76699066, 22.00927162], [88.76745605, 22.00947189], [88.76793671, 22.00966072], [88.76844788, 22.00980186], [88.76895905, 22.00998116], [88.76950073, 22.01016045], [88.76998138, 22.01041985], [88.77047729, 22.01069069], [88.7710495, 22.01098061], [88.77166748, 22.01139069], [88.77249908, 22.01221848], [88.7722168, 22.01250267], [88.77201843, 22.01247978], [88.77127075, 22.01221848], [88.77065277, 22.01196289], [88.77012634, 22.01176643], [88.76966095, 22.01157951], [88.76924133, 22.01138496], [88.76880646, 22.01120377], [88.76837158, 22.01104164], [88.76795959, 22.01083183], [88.76752472, 22.01062202], [88.76707458, 22.01045799], [88.7666626, 22.01027107], [88.76625061, 22.01009178], [88.76577759, 22.00992012], [88.76526642, 22.00969315], [88.76468658, 22.00942612], [88.7640686, 22.00914383], [88.76345062, 22.00884819], [88.76287079, 22.00853157], [88.76235962, 22.0081749], [88.76187134, 22.00775719], [88.7616272, 22.007761], [88.76139069, 22.00796127], [88.76127625, 22.00811958], [88.76114655, 22.00830269], [88.76092529, 22.00874519], [88.76078796, 22.00932312], [88.76056671, 22.0098896], [88.76040649, 22.01048088], [88.7604599, 22.01107216], [88.76062775, 22.01161766], [88.76084137, 22.01209259], [88.76107788, 22.01254082], [88.76122284, 22.01303101], [88.76135254, 22.01352119], [88.76140594, 22.01403999], [88.7614975, 22.01452065], [88.76172638, 22.01490784], [88.76187134, 22.01503563], [88.76204681, 22.01519585], [88.76246643, 22.01537132], [88.76290131, 22.01556969], [88.76337433, 22.01578522], [88.76397705, 22.0158329], [88.76462555, 22.01583672], [88.76529694, 22.0158329], [88.76597595, 22.01584053], [88.7666626, 22.01588249], [88.76732635, 22.01601601], [88.76795959, 22.01584053], [88.76856995, 22.01563072], [88.76915741, 22.01551247], [88.77091217, 22.01493263], [88.77313995, 22.01493263], [88.77471924, 22.01486778], [88.77600861, 22.0148716], [88.77694702, 22.0150013], [88.78028107, 22.01611137], [88.78083038, 22.01638794], [88.78086853, 22.01720238], [88.78101349, 22.01760674], [88.78173065, 22.01814079], [88.78208923, 22.01820946], [88.78273773, 22.01861], [88.78316498, 22.01894569], [88.7833786, 22.01908112], [88.78381348, 22.01928139], [88.78438568, 22.01948166], [88.78488922, 22.01968193], [88.78527069, 22.02000237], [88.78527069, 22.02028084], [88.78639221, 22.0208416], [88.78666687, 22.02111244], [88.78722382, 22.0213871], [88.78806305, 22.02222252], [88.78806305, 22.02250099], [88.78916931, 22.02277946], [88.79000092, 22.02361107], [88.79111481, 22.02388954], [88.79277802, 22.02444458], [88.79499817, 22.02555275], [88.79611206, 22.02666664], [88.7977829, 22.02722168], [88.79833221, 22.02750015], [88.79944611, 22.02861214], [88.80055237, 22.02889061], [88.80055237, 22.02916908], [88.80110931, 22.02944374], [88.8013916, 22.02972221], [88.80222321, 22.02972221], [88.80305481, 22.02944374], [88.80361176, 22.02916908], [88.80388641, 22.02889061], [88.80388641, 22.02861214], [88.8041687, 22.02833176], [88.8041687, 22.02805519], [88.80444336, 22.02778053], [88.80444336, 22.02750015], [88.80473328, 22.02722168], [88.80472565, 22.02694511], [88.80500031, 22.02666664], [88.80500031, 22.02639008], [88.80526733, 22.0261116], [88.80527496, 22.02583313], [88.80555725, 22.02555656], [88.80555725, 22.02444649], [88.8061142, 22.02416992], [88.8077774, 22.02250099], [88.8088913, 22.02194023], [88.80916595, 22.02166557], [88.81027985, 22.02111244], [88.81083679, 22.02056313], [88.81083679, 22.02028084], [88.8116684, 22.02000237], [88.81276703, 22.0194416], [88.81305695, 22.01916695], [88.8133316, 22.01916695], [88.8152771, 22.01944351], [88.81555176, 22.01972008], [88.81833649, 22.02028084], [88.81944275, 22.02056313], [88.82026672, 22.0208416], [88.82195282, 22.02166939], [88.82611084, 22.02166939], [88.82639313, 22.02139091], [88.82639313, 22.02111244], [88.83027649, 22.0205555], [88.83194733, 22.02028084], [88.83304596, 22.02000237], [88.8347168, 22.0194416], [88.83583069, 22.01916695], [88.83750153, 22.01861], [88.84333038, 22.0177784], [88.84333038, 22.01749992], [88.84833527, 22.01749992], [88.8483429, 22.01777077], [88.85250092, 22.01805305], [88.85527802, 22.01861], [88.85610962, 22.01888847], [88.85778046, 22.01972008], [88.85861206, 22.02000237], [88.86083221, 22.02111244], [88.86332703, 22.02361107], [88.86416626, 22.02388954], [88.86528015, 22.02444649], [88.86638641, 22.02444649], [88.86694336, 22.02416992], [88.86833191, 22.02277946], [88.86833191, 22.02222252], [88.8686142, 22.02194405], [88.8686142, 22.02139091], [88.86915588, 22.0208416], [88.86915588, 22.02056313], [88.86972046, 22.02000237], [88.86972046, 22.01972008], [88.8702774, 22.01916695], [88.8702774, 22.01889229], [88.87055206, 22.01861], [88.87055206, 22.01666641], [88.8713913, 22.01527977], [88.87248993, 22.01471138], [88.87277985, 22.01444435], [88.87333679, 22.01416588], [88.87526703, 22.01221848], [88.87611389, 22.01194382], [88.87889099, 22.01166725], [88.8797226, 22.01139259], [88.8861084, 22.0111084], [88.88722229, 22.0111084], [88.88749695, 22.01139259], [88.89250183, 22.01166725], [88.89389038, 22.01194382], [88.89665985, 22.01221848], [88.89694214, 22.01250267], [88.89833069, 22.01277924], [88.89833069, 22.01305962], [88.89933777, 22.01305771], [88.89971924, 22.01305962], [88.90249634, 22.01166916], [88.90361023, 22.01055908], [88.90361023, 22.00917244], [88.90416718, 22.00861168], [88.90416718, 22.00805473], [88.90396881, 22.00785446], [88.90389252, 22.00777626], [88.90416718, 22.0075016], [88.90416718, 22.00722313], [88.90444183, 22.00694656], [88.90444183, 22.00277901], [88.90389252, 22.00250053], [88.90389252, 22.00000191], [88.90354919, 21.99973106], [88.90297699, 21.99435997], [88.90239716, 21.9871006], [88.90374756, 21.98077202], [88.9041214, 21.97902679], [88.90756226, 21.96935081], [88.90783691, 21.96478081], [88.90733337, 21.96159172], [88.90584564, 21.95212936], [88.90584564, 21.9426899], [88.90584564, 21.93706703], [88.90590668, 21.9360714], [88.90627289, 21.93562126], [88.90688324, 21.93404388], [88.90702057, 21.93287086], [88.90727234, 21.9313221], [88.90727234, 21.92953682], [88.90584564, 21.92819595], [88.90402222, 21.92648125], [88.90067291, 21.92480278], [88.89746094, 21.92283821], [88.89624786, 21.92261314], [88.89573669, 21.92237473], [88.89456177, 21.92194366], [88.89011383, 21.92113113], [88.88829803, 21.9207325], [88.88586426, 21.92079544], [88.88240814, 21.92229462], [88.88121033, 21.92281151], [88.8775177, 21.92257309], [88.87290192, 21.92227364], [88.86847687, 21.9220295]]], [[[88.74539185, 21.97973824], [88.7458725, 21.97972107], [88.74640656, 21.97972107], [88.74698639, 21.97969246], [88.74758911, 21.97951126], [88.74825287, 21.97937775], [88.74887085, 21.97916031], [88.74944305, 21.97888947], [88.74973297, 21.97888947], [88.75, 21.97861099], [88.75027466, 21.97861099], [88.75055695, 21.97833252], [88.7508316, 21.97833252], [88.75111389, 21.97805405], [88.75138855, 21.97805977], [88.75195313, 21.97750092], [88.75222015, 21.97750092], [88.75305176, 21.9766674], [88.75332642, 21.97667122], [88.75332642, 21.97639084], [88.75417328, 21.97556114], [88.75417328, 21.97528076], [88.7547226, 21.97472191], [88.7547226, 21.97444534], [88.7545166, 21.97380829], [88.7544632, 21.97323036], [88.75444031, 21.97262955], [88.75440216, 21.97208405], [88.75419617, 21.97158241], [88.75406647, 21.97102547], [88.75388336, 21.97048759], [88.75361633, 21.96998024], [88.75338745, 21.96947861], [88.75325012, 21.96894073], [88.75305176, 21.96844292], [88.75285339, 21.96795273], [88.75273132, 21.96742058], [88.75254059, 21.96696854], [88.75247192, 21.96652985], [88.75231171, 21.9661808], [88.75222778, 21.96584511], [88.75218964, 21.96550941], [88.75203705, 21.96523094], [88.75190735, 21.96487808], [88.75169373, 21.96451759], [88.75154114, 21.96404076], [88.75136566, 21.96352768], [88.75112152, 21.96302032], [88.75093079, 21.96250153], [88.75073242, 21.9620018], [88.75047302, 21.96157455], [88.75028229, 21.96113968], [88.75012207, 21.9606781], [88.74997711, 21.96025085], [88.74978638, 21.95986176], [88.74968719, 21.95943069], [88.74949646, 21.95903015], [88.74945068, 21.95858002], [88.74944305, 21.95811081], [88.74946594, 21.95766068], [88.74964905, 21.95726585], [88.74975586, 21.95680809], [88.74996185, 21.95635033], [88.75004578, 21.95578957], [88.75029755, 21.95528984], [88.75070953, 21.95485115], [88.75119781, 21.95445824], [88.75177765, 21.95416451], [88.75235748, 21.95388412], [88.75292206, 21.95360947], [88.75348663, 21.95334625], [88.75409698, 21.95314026], [88.75476074, 21.95300293], [88.75541687, 21.9528141], [88.7561264, 21.9527359], [88.75681305, 21.95251083], [88.75749969, 21.95228958], [88.75819397, 21.95207977], [88.75886536, 21.9518528], [88.75951385, 21.95160675], [88.76016235, 21.95137215], [88.76076508, 21.9511013], [88.7612915, 21.95077324], [88.76173401, 21.95035744], [88.76222229, 21.95000076], [88.76270294, 21.94964981], [88.76312256, 21.94922066], [88.76354218, 21.94881248], [88.76387787, 21.94835091], [88.76419067, 21.94790077], [88.764534, 21.94752693], [88.76490784, 21.94720078], [88.76528931, 21.94685555], [88.76571655, 21.94651031], [88.76618958, 21.94613075], [88.76673889, 21.94580078], [88.76725006, 21.94540024], [88.76778412, 21.94509697], [88.76832581, 21.9448719], [88.76882935, 21.94466972], [88.76927185, 21.9444294], [88.76966095, 21.94416618], [88.77002716, 21.94388962], [88.77039337, 21.94363022], [88.77076721, 21.94339943], [88.77114105, 21.94318008], [88.7715683, 21.94301033], [88.77197266, 21.94277954], [88.77240753, 21.94259262], [88.77288055, 21.94239807], [88.77336121, 21.94219971], [88.77378845, 21.94198227], [88.77423096, 21.94185829], [88.77462006, 21.94170189], [88.77503967, 21.94164085], [88.77545166, 21.94149971], [88.77584076, 21.94145012], [88.77619934, 21.94162369], [88.77658844, 21.94170189], [88.77690125, 21.94188118], [88.77728271, 21.94201088], [88.77762604, 21.94222832], [88.77799225, 21.94248962], [88.77838135, 21.94273949], [88.77876282, 21.9429512], [88.77906036, 21.94320869], [88.77937317, 21.94343185], [88.77957916, 21.94375038], [88.7797699, 21.94408989], [88.78000641, 21.9444294], [88.78028107, 21.94477844], [88.78052521, 21.94518471], [88.78069305, 21.94568062], [88.78089905, 21.94617844], [88.7811203, 21.94667053], [88.78138733, 21.94713974], [88.78164673, 21.9475956], [88.78186035, 21.94804382], [88.7820816, 21.94844818], [88.78226471, 21.94882584], [88.78250122, 21.94914436], [88.78276825, 21.94943237], [88.78303528, 21.94971657], [88.78324127, 21.95005035], [88.78340912, 21.9504509], [88.78370667, 21.95082283], [88.78409576, 21.95119667], [88.78446198, 21.95165062], [88.78495789, 21.95202065], [88.78543854, 21.95236969], [88.78595734, 21.95261192], [88.78645325, 21.95265007], [88.78690338, 21.95231819], [88.78721619, 21.95178032], [88.78742218, 21.9511795], [88.78730774, 21.9505291], [88.78742218, 21.9500103], [88.78746033, 21.94985962], [88.78746033, 21.9491787], [88.78726196, 21.94852066], [88.78721619, 21.94785118], [88.78716278, 21.94719124], [88.78697968, 21.94659615], [88.78694153, 21.94595909], [88.78694153, 21.94528008], [88.78694153, 21.94457817], [88.78694916, 21.94390106], [88.78701782, 21.9432888], [88.78712463, 21.94303322], [88.78723145, 21.94278908], [88.78749847, 21.94234276], [88.78778839, 21.94189453], [88.78811646, 21.94145966], [88.78852081, 21.94108009], [88.78890228, 21.94071388], [88.78931427, 21.94042778], [88.78975677, 21.94021988], [88.79016876, 21.93999481], [88.79055023, 21.93976784], [88.79103851, 21.93967819], [88.79151917, 21.93949127], [88.79207611, 21.93943024], [88.79268646, 21.93944168], [88.79331207, 21.93944359], [88.79393768, 21.93943024], [88.79456329, 21.93946838], [88.79515839, 21.93959808], [88.79577637, 21.93975067], [88.79637146, 21.93995857], [88.79705811, 21.94000053], [88.79777527, 21.94000244], [88.79849243, 21.94000053], [88.79917908, 21.93997192], [88.79981995, 21.93980026], [88.80046844, 21.93974113], [88.80110931, 21.93971062], [88.80170441, 21.93965149], [88.80220032, 21.9394722], [88.80269623, 21.93936539], [88.8031311, 21.93915939], [88.80355835, 21.93889046], [88.80401611, 21.93858147], [88.80446625, 21.93819046], [88.80493927, 21.9378109], [88.80527496, 21.93735123], [88.80555725, 21.93690109], [88.80578613, 21.93647957], [88.80583191, 21.9360199], [88.80583191, 21.9355793], [88.80580139, 21.93515015], [88.80562592, 21.93475533], [88.80555725, 21.93416977], [88.80555725, 21.93388939], [88.80526733, 21.93362045], [88.80526733, 21.93305969], [88.80473328, 21.93250084], [88.80472565, 21.93222237], [88.80361176, 21.93111038], [88.8033371, 21.93111038], [88.8033371, 21.93082809], [88.80287933, 21.93037224], [88.80222321, 21.92972183], [88.80222321, 21.92944527], [88.80055237, 21.92778015], [88.80055237, 21.92749023], [88.80000305, 21.92694664], [88.80000305, 21.92666435], [88.79944611, 21.92611122], [88.7993927, 21.92592812], [88.79899597, 21.92567253], [88.79857635, 21.92542076], [88.79810333, 21.92521095], [88.79759979, 21.92498207], [88.79712677, 21.92471886], [88.79666138, 21.92444992], [88.79618835, 21.92416954], [88.79572296, 21.92389107], [88.79522705, 21.92361069], [88.79471588, 21.92333221], [88.79416656, 21.92304039], [88.79364014, 21.92266846], [88.79315948, 21.9222126], [88.79270935, 21.9217205], [88.79223633, 21.92130089], [88.79178619, 21.92095375], [88.79133606, 21.92068291], [88.79083252, 21.92052841], [88.79032135, 21.92032051], [88.78971863, 21.92028046], [88.78942108, 21.92028046], [88.78914642, 21.92028046], [88.78879547, 21.92032433], [88.78846741, 21.92049026], [88.78804779, 21.92058945], [88.7876358, 21.92078018], [88.78716278, 21.92090988], [88.78670502, 21.92111969], [88.78636169, 21.92133331], [88.78627014, 21.92139053], [88.78582764, 21.92165947], [88.78534698, 21.92188072], [88.784935, 21.92213821], [88.78468323, 21.92224884], [88.78449249, 21.92233086], [88.78410339, 21.92256165], [88.78372192, 21.92279816], [88.78338623, 21.92307091], [88.78305054, 21.92336082], [88.78269196, 21.92362022], [88.78234863, 21.92389107], [88.78199768, 21.92416954], [88.78162384, 21.92443275], [88.78119659, 21.92466164], [88.78082275, 21.9249897], [88.78040314, 21.9253006], [88.77998352, 21.92561531], [88.77953339, 21.92585754], [88.77908325, 21.92611694], [88.77865601, 21.92638588], [88.77820587, 21.92661095], [88.77771759, 21.92675018], [88.7773056, 21.92697144], [88.77709961, 21.92712021], [88.77693939, 21.92724037], [88.77655792, 21.92750549], [88.77616119, 21.92777252], [88.7756958, 21.92798805], [88.77514648, 21.92811012], [88.77462006, 21.92833519], [88.77406311, 21.92858124], [88.7734375, 21.92877007], [88.77276611, 21.92892265], [88.77216339, 21.92916107], [88.77155304, 21.92939949], [88.77088165, 21.92952728], [88.7702179, 21.92969322], [88.76953125, 21.92974472], [88.76889038, 21.92986488], [88.76828766, 21.92998314], [88.7677002, 21.9300499], [88.76719666, 21.93024063], [88.76669312, 21.93028069], [88.76618958, 21.93028069], [88.76568604, 21.93028069], [88.76519012, 21.93033028], [88.76469421, 21.9305172], [88.76416016, 21.93055534], [88.76357269, 21.93055725], [88.76294708, 21.93058014], [88.76232147, 21.93072128], [88.7616806, 21.93081093], [88.76106262, 21.93074989], [88.76042938, 21.93062973], [88.75984955, 21.93079376], [88.75928497, 21.93083191], [88.7587738, 21.93080521], [88.75830841, 21.93066978], [88.75785065, 21.93058968], [88.75737, 21.93065071], [88.75686646, 21.93072128], [88.75637817, 21.93058968], [88.75582886, 21.93050957], [88.7552948, 21.93032265], [88.75465393, 21.93028069], [88.7539978, 21.93024063], [88.75340271, 21.93000031], [88.75280762, 21.92977905], [88.75221252, 21.92967033], [88.75175476, 21.9294529], [88.75132751, 21.92925835], [88.75089264, 21.92914009], [88.75054169, 21.9289093], [88.75013733, 21.92875099], [88.74973297, 21.92861366], [88.74931335, 21.92847633], [88.74890137, 21.92831039], [88.74854279, 21.92806816], [88.74813843, 21.92785835], [88.7477417, 21.92761993], [88.74728394, 21.92738152], [88.74686432, 21.92698669], [88.74637604, 21.92655945], [88.74584961, 21.92612076], [88.74539185, 21.92564964], [88.74501038, 21.92519188], [88.74471283, 21.92478943], [88.74442291, 21.92446709], [88.744133, 21.92418098], [88.7437973, 21.92389107], [88.74344635, 21.92360115], [88.74310303, 21.92327118], [88.74276733, 21.92295647], [88.74241638, 21.92270279], [88.74205017, 21.92246819], [88.74169922, 21.92224693], [88.74128723, 21.92212105], [88.74091339, 21.9219799], [88.74050903, 21.92201996], [88.74011993, 21.92218971], [88.73969269, 21.92225075], [88.73931122, 21.92243958], [88.73916626, 21.92250061], [88.7388916, 21.9227829], [88.73805237, 21.9227829], [88.73777771, 21.92305946], [88.73750305, 21.92305565], [88.73722076, 21.92333221], [88.73694611, 21.92333031], [88.73638916, 21.92389107], [88.73555756, 21.92389107], [88.7352829, 21.92416954], [88.73472595, 21.92416954], [88.73443604, 21.92444992], [88.73388672, 21.92444229], [88.73361206, 21.92472267], [88.73332977, 21.92472076], [88.73278046, 21.92527771], [88.73245239, 21.92586327], [88.73222351, 21.92624664], [88.73204041, 21.9265728], [88.73194122, 21.92690086], [88.73182678, 21.92720222], [88.73169708, 21.92749023], [88.73159027, 21.92782784], [88.73140717, 21.9281311], [88.73124695, 21.92847061], [88.73110199, 21.92879868], [88.73092651, 21.92908669], [88.73078156, 21.9293499], [88.73059082, 21.92956734], [88.73044586, 21.92982292], [88.7303009, 21.93013], [88.73020172, 21.93047523], [88.73000336, 21.93082809], [88.73000336, 21.93111038], [88.72944641, 21.93166733], [88.72944641, 21.93193817], [88.72888947, 21.93250084], [88.72888947, 21.9327774], [88.72833252, 21.93332863], [88.72833252, 21.93361282], [88.72721863, 21.9347229], [88.72721863, 21.93499947], [88.72472382, 21.9375], [88.72472382, 21.93833351], [88.72360992, 21.93944359], [88.72389221, 21.93972015], [88.72389221, 21.94055748], [88.72360992, 21.94083023], [88.72360992, 21.94139099], [88.72333527, 21.94166565], [88.72305298, 21.94194412], [88.72294617, 21.94212151], [88.72270966, 21.94236755], [88.72239685, 21.94263077], [88.72223663, 21.94297028], [88.72226715, 21.94333839], [88.72245789, 21.94371986], [88.72249603, 21.9441452], [88.72249603, 21.94460106], [88.72254944, 21.94507599], [88.72273254, 21.94551086], [88.72280121, 21.9460392], [88.72293854, 21.94655037], [88.72306061, 21.94704056], [88.72318268, 21.94746017], [88.72331238, 21.94779015], [88.7233429, 21.94809914], [88.7233429, 21.94836807], [88.7233429, 21.94861984], [88.72360992, 21.94888878], [88.72360992, 21.94944382], [88.72389221, 21.94972229], [88.72389221, 21.95222092], [88.72360992, 21.95249939], [88.72333527, 21.95249939], [88.72333527, 21.95583344], [88.72360992, 21.95610809], [88.72360992, 21.95639038], [88.72333527, 21.95666885], [88.7233429, 21.95832825], [88.72305298, 21.95861053], [88.72305298, 21.95889091], [88.72292328, 21.9591465], [88.72280121, 21.95950127], [88.72277832, 21.95986176], [88.72281647, 21.96018982], [88.7229538, 21.96046829], [88.72304535, 21.96075249], [88.72305298, 21.96105194], [88.72305298, 21.96136093], [88.72306061, 21.96166039], [88.72305298, 21.96195984], [88.72299957, 21.96224976], [88.72281647, 21.96251106], [88.72277832, 21.96285057], [88.72277832, 21.96325111], [88.72277832, 21.96371078], [88.72281647, 21.9642086], [88.72299194, 21.96471977], [88.72319794, 21.96519279], [88.7232666, 21.96557045], [88.72315979, 21.96585083], [88.72302246, 21.96611023], [88.7228241, 21.96639633], [88.72277832, 21.96677971], [88.7228241, 21.96723557], [88.7230072, 21.96771812], [88.72309113, 21.96829033], [88.72325897, 21.96884155], [88.72336578, 21.96940041], [88.72355652, 21.96988106], [88.72366333, 21.97033119], [88.72383881, 21.97063065], [88.72396851, 21.97090912], [88.72416687, 21.97116089], [88.72432709, 21.97142029], [88.72442627, 21.97171974], [88.72444916, 21.97203636], [88.72442627, 21.97233963], [88.72431946, 21.9726181], [88.72415161, 21.97291946], [88.72392273, 21.97331047], [88.72373199, 21.97381592], [88.72389221, 21.97437286], [88.72415161, 21.97492981], [88.72437286, 21.97550011], [88.72447205, 21.97612572], [88.72463226, 21.97673035], [88.72473145, 21.97735977], [88.72488403, 21.97793961], [88.72505951, 21.97845268], [88.72544098, 21.9788475], [88.72598267, 21.97916031], [88.72629547, 21.9790802], [88.72660828, 21.97900009], [88.72725677, 21.9790802], [88.72789764, 21.97949028], [88.72857666, 21.97945023], [88.72923279, 21.97944069], [88.72987366, 21.9794445], [88.73051453, 21.9794445], [88.73116302, 21.9794445], [88.73181152, 21.9794445], [88.73246765, 21.9794445], [88.73311615, 21.97944069], [88.73377228, 21.97945023], [88.73442078, 21.97944069], [88.73506165, 21.97940445], [88.73564911, 21.97920609], [88.73619843, 21.97916985], [88.73668671, 21.97916031], [88.73712158, 21.97916985], [88.73751068, 21.97916985], [88.73792267, 21.97916985], [88.7383728, 21.97916985], [88.73886108, 21.97916031], [88.73938751, 21.97916985], [88.73991394, 21.97920609], [88.74038696, 21.97940063], [88.74085999, 21.97946548], [88.74124908, 21.97957993], [88.74163055, 21.97970009], [88.74208832, 21.97973442], [88.74259186, 21.97981834], [88.74314117, 21.97997284], [88.74375153, 21.98000145], [88.74435425, 21.97997475], [88.74489594, 21.97983551], [88.74539185, 21.97973824]]], [[[88.66233063, 21.95251083], [88.66187286, 21.95275879], [88.66137695, 21.95292091], [88.6608963, 21.95307732], [88.66044617, 21.95329475], [88.65992737, 21.9533844], [88.65944672, 21.95357323], [88.65891266, 21.95364189], [88.65838623, 21.95380974], [88.6578064, 21.95392036], [88.65722656, 21.95412064], [88.65654755, 21.95417023], [88.65583801, 21.95417023], [88.65512848, 21.95417023], [88.65444946, 21.95417023], [88.65380096, 21.95417023], [88.65255737, 21.95417023], [88.65202332, 21.95417023], [88.65151978, 21.95417023], [88.65106201, 21.95417023], [88.65059662, 21.95417023], [88.65013123, 21.95413017], [88.64964294, 21.95393181], [88.64914703, 21.95393944], [88.64863586, 21.95413017], [88.64813232, 21.95417023], [88.64762115, 21.95413017], [88.64711761, 21.95393944], [88.6466217, 21.95396042], [88.64613342, 21.95410156], [88.64562988, 21.95398521], [88.64509583, 21.95389938], [88.64456177, 21.95388985], [88.64401245, 21.95388985], [88.64344788, 21.95387077], [88.64295959, 21.95377922], [88.64250946, 21.95359993], [88.64212036, 21.95334053], [88.641716, 21.9530983], [88.6413269, 21.95283127], [88.64093781, 21.95260429], [88.64057922, 21.9523735], [88.64025879, 21.95210266], [88.63988495, 21.95184517], [88.6394577, 21.95161057], [88.6390152, 21.95137024], [88.63863373, 21.95111847], [88.63825989, 21.9509201], [88.63784027, 21.95084], [88.63734436, 21.95083237], [88.63680267, 21.95083237], [88.63625336, 21.95083046], [88.63572693, 21.95084953], [88.63530731, 21.95095253], [88.63490295, 21.95107841], [88.6344223, 21.95113945], [88.63394165, 21.95133018], [88.633461, 21.95155907], [88.63304901, 21.9518795], [88.63269043, 21.95220947], [88.63237762, 21.9525528], [88.63214874, 21.95294952], [88.63186646, 21.95332718], [88.63175201, 21.95347214], [88.63156128, 21.95372009], [88.63124084, 21.95413017], [88.63088226, 21.95454979], [88.63056183, 21.95502663], [88.63027954, 21.95553017], [88.62998199, 21.95596886], [88.6297226, 21.95631981], [88.62948608, 21.95664978], [88.62924957, 21.95693779], [88.62902069, 21.95723152], [88.62880707, 21.95758247], [88.62864685, 21.9580307], [88.6286087, 21.95857048], [88.62857056, 21.95915031], [88.62837982, 21.95970917], [88.62833405, 21.96033669], [88.62832642, 21.96097946], [88.62833405, 21.9616394], [88.62832642, 21.96228981], [88.62832642, 21.96362114], [88.62832642, 21.96430016], [88.62832642, 21.96500969], [88.62833405, 21.96571732], [88.62832642, 21.96639061], [88.62833405, 21.96699524], [88.62834167, 21.96750069], [88.62840271, 21.9679203], [88.62856293, 21.96824074], [88.62864685, 21.96859169], [88.62885284, 21.96891022], [88.62890625, 21.96934128], [88.6289978, 21.96982384], [88.62915039, 21.9703331], [88.6292572, 21.97089958], [88.62940979, 21.97147369], [88.62948608, 21.97209358], [88.62968445, 21.97267342], [88.62980652, 21.97327042], [88.62996674, 21.97385025], [88.63004303, 21.97445107], [88.63022614, 21.97501945], [88.63028717, 21.97564125], [88.63040924, 21.97624016], [88.63053131, 21.97682762], [88.63059998, 21.97740936], [88.63078308, 21.97794914], [88.63083649, 21.97854042], [88.630867, 21.97915077], [88.631073, 21.97973824], [88.63111115, 21.98031807], [88.63111115, 21.98084831], [88.63111115, 21.9813385], [88.63114929, 21.98178291], [88.63132477, 21.98218918], [88.6313858, 21.98266983], [88.63144684, 21.98319817], [88.63162994, 21.98372078], [88.63166809, 21.98427963], [88.6317215, 21.98481178], [88.63194275, 21.98524094], [88.63194275, 21.98583412], [88.63222504, 21.98611069], [88.63222504, 21.9869442], [88.63240051, 21.98711967], [88.63249969, 21.98722267], [88.63249969, 21.98749924], [88.63253021, 21.98790359], [88.63273621, 21.98841476], [88.63282013, 21.98900414], [88.63302612, 21.98950958], [88.63314056, 21.99006271], [88.63331604, 21.99053955], [88.63342285, 21.99106026], [88.63358307, 21.99160957], [88.63366699, 21.99225044], [88.63384247, 21.9928894], [88.63392639, 21.99358177], [88.63414001, 21.99419403], [88.63430023, 21.99483109], [88.63457489, 21.9954052], [88.63485718, 21.9959507], [88.63520813, 21.99643135], [88.63553619, 21.99691963], [88.63588715, 21.99740028], [88.63635254, 21.99773026], [88.63687897, 21.99799156], [88.63739777, 21.99822044], [88.63792419, 21.99838638], [88.6383667, 21.99864006], [88.6388092, 21.99889946], [88.6391983, 21.99919128], [88.63954163, 21.99926758], [88.6399231, 21.99964905], [88.6402359, 21.99973106], [88.64111328, 22.00000191], [88.64105225, 22.00028038], [88.64112091, 22.00068092], [88.64096832, 22.00165939], [88.64444733, 22.00527954], [88.64499664, 22.00527954], [88.64527893, 22.00555992], [88.64555359, 22.0055542], [88.64583588, 22.00583267], [88.64611053, 22.00583076], [88.64666748, 22.00638962], [88.64666748, 22.00749969], [88.64638519, 22.00777626], [88.64638519, 22.00833321], [88.64666748, 22.00861168], [88.64665222, 22.00874329], [88.64685822, 22.00934982], [88.64704132, 22.00990105], [88.64724731, 22.0103302], [88.64739227, 22.01071548], [88.64745331, 22.0111599], [88.64776611, 22.01138115], [88.64804077, 22.01171112], [88.64826202, 22.01213264], [88.64852905, 22.01255989], [88.64875793, 22.01305962], [88.64898682, 22.01358032], [88.6492691, 22.01404953], [88.64961243, 22.01441002], [88.6497345, 22.01492882], [88.64987946, 22.0153923], [88.65018463, 22.01574135], [88.65055847, 22.01610947], [88.65093994, 22.01647949], [88.65135193, 22.01673126], [88.65168762, 22.01702118], [88.65196991, 22.017416], [88.6522522, 22.01791], [88.65254974, 22.01852989], [88.65293884, 22.01913071], [88.65357971, 22.01935005], [88.65418243, 22.01916122], [88.65468597, 22.01898766], [88.65516663, 22.01908112], [88.65561676, 22.01925087], [88.65595245, 22.01946068], [88.65624237, 22.01970291], [88.65663147, 22.01994324], [88.65674591, 22.01998138], [88.65716553, 22.02012253], [88.65781403, 22.02002335], [88.6584549, 22.01992416], [88.65898895, 22.01971054], [88.6594696, 22.01945877], [88.65997314, 22.01921272], [88.66049957, 22.01889038], [88.66099548, 22.01860237], [88.66144562, 22.01832771], [88.66190338, 22.01807976], [88.66236877, 22.01790047], [88.66280365, 22.01773262], [88.66318512, 22.0175209], [88.66358185, 22.01737785], [88.66397095, 22.01724815], [88.66438293, 22.01721954], [88.66479492, 22.01722145], [88.66520691, 22.01722145], [88.66563416, 22.01722145], [88.66609192, 22.01721954], [88.66655731, 22.0172596], [88.66703033, 22.01740837], [88.66752625, 22.01748276], [88.66805267, 22.01754761], [88.66851044, 22.01775169], [88.66900635, 22.01790047], [88.66953278, 22.0180397], [88.6700592, 22.01814079], [88.670578, 22.01834106], [88.67111969, 22.01857758], [88.67175293, 22.018713], [88.67240143, 22.01890373], [88.67302704, 22.01912308], [88.67365265, 22.01918411], [88.67425537, 22.01918221], [88.67490387, 22.01887703], [88.67550659, 22.01855087], [88.67601776, 22.01824951], [88.67640686, 22.01793098], [88.67677307, 22.01768303], [88.67713165, 22.01748848], [88.67745972, 22.01726151], [88.67778778, 22.0170002], [88.67815399, 22.01672745], [88.6785965, 22.01650047], [88.67904663, 22.01624107], [88.67953491, 22.01602173], [88.68002319, 22.01579857], [88.68048096, 22.01555252], [88.68089294, 22.01529121], [88.68132782, 22.01507187], [88.68179321, 22.01488686], [88.68231964, 22.01469994], [88.68287659, 22.01444244], [88.68349457, 22.01418877], [88.68415833, 22.01399994], [88.68477631, 22.0138092], [88.68527222, 22.01358986], [88.68566132, 22.01338005], [88.68611145, 22.01332855], [88.6866684, 22.01333427], [88.68694305, 22.0130558], [88.6875, 22.01305962], [88.68776703, 22.01277924], [88.68805695, 22.01277924], [88.6883316, 22.01250076], [88.68860626, 22.01250076], [88.68888855, 22.01221848], [88.68994904, 22.0122242], [88.69047546, 22.01217651], [88.69095612, 22.01196289], [88.69146729, 22.01166916], [88.69203186, 22.01133156], [88.69252014, 22.01082039], [88.69306183, 22.01028061], [88.69361115, 22.00971985], [88.69416809, 22.00916862], [88.69470215, 22.00864029], [88.69525146, 22.00818062], [88.69570923, 22.00774956], [88.69609833, 22.00733185], [88.69644928, 22.00691032], [88.69689941, 22.00654984], [88.69734955, 22.00610352], [88.69786835, 22.00564003], [88.69845581, 22.00526047], [88.69902802, 22.00485039], [88.69954681, 22.00448227], [88.7000351, 22.00419044], [88.70049286, 22.00395966], [88.70094299, 22.00378036], [88.70134735, 22.00362587], [88.70176697, 22.00349808], [88.70214844, 22.00333023], [88.70252991, 22.00316811], [88.70294189, 22.00305939], [88.70336914, 22.00298691], [88.70376587, 22.00281906], [88.70426941, 22.00276184], [88.70482635, 22.00266075], [88.70543671, 22.00248146], [88.70607758, 22.00225449], [88.70679474, 22.00214195], [88.70754242, 22.00216484], [88.70829773, 22.00205994], [88.70905304, 22.00214958], [88.70978546, 22.00208282], [88.71050262, 22.00218964], [88.71118164, 22.00222015], [88.71182251, 22.00221252], [88.71244049, 22.00212097], [88.71302795, 22.00192833], [88.71357727, 22.00168991], [88.71412659, 22.00154495], [88.71459961, 22.00138283], [88.71499634, 22.00120926], [88.71533966, 22.00103951], [88.71559143, 22.00086021], [88.71578217, 22.00064087], [88.71573639, 22.00054932], [88.71527863, 22.00000191], [88.71528625, 21.99930954], [88.71534729, 21.99910927], [88.71517944, 21.99876022], [88.71481323, 21.9984684], [88.71453094, 21.99810791], [88.71431732, 21.99767113], [88.71407318, 21.99724007], [88.71379089, 21.99683571], [88.71351624, 21.99641991], [88.71325684, 21.99603081], [88.7130127, 21.99566269], [88.712677, 21.99534035], [88.7122879, 21.99510193], [88.71180725, 21.99491119], [88.71134949, 21.99468803], [88.71092987, 21.99440956], [88.71053314, 21.9941082], [88.71018219, 21.99379349], [88.70985413, 21.99348831], [88.70948029, 21.99323273], [88.70907593, 21.99292946], [88.70867157, 21.99250031], [88.70836639, 21.99199295], [88.70809937, 21.99158287], [88.70783234, 21.99125099], [88.7075119, 21.99090004], [88.70704651, 21.99057007], [88.70664215, 21.99003029], [88.70625305, 21.98958015], [88.70593262, 21.98923111], [88.70569611, 21.98880959], [88.70543671, 21.98829842], [88.70503998, 21.98788071], [88.70456696, 21.98760986], [88.7040863, 21.98733521], [88.70365906, 21.9869709], [88.70323944, 21.98657227], [88.70281982, 21.98614693], [88.70240784, 21.98568916], [88.70211029, 21.98518944], [88.70191956, 21.98467255], [88.70170593, 21.9842205], [88.70145416, 21.98382378], [88.7011795, 21.98340416], [88.70087433, 21.98296356], [88.70059204, 21.98251152], [88.70040894, 21.98207283], [88.70026398, 21.98168182], [88.70011902, 21.98134995], [88.69999695, 21.98101997], [88.69985962, 21.98069954], [88.69970703, 21.98039055], [88.69954681, 21.98010063], [88.69940186, 21.97984123], [88.69922638, 21.97960091], [88.69905853, 21.97935867], [88.69888306, 21.97915077], [88.69869995, 21.97894287], [88.69856262, 21.97867966], [88.69835663, 21.97843552], [88.69809723, 21.97813988], [88.69777679, 21.97775078], [88.69742584, 21.97729111], [88.69694519, 21.97685814], [88.69651031, 21.97628975], [88.69615173, 21.97569275], [88.69584656, 21.97512054], [88.69555664, 21.97458267], [88.69528198, 21.97407913], [88.69500732, 21.97361183], [88.69478607, 21.97313118], [88.69461823, 21.97256851], [88.69441223, 21.97200012], [88.69416046, 21.9714222], [88.69389343, 21.97085381], [88.69364166, 21.97035408], [88.69335175, 21.97001648], [88.69308472, 21.96980095], [88.69277191, 21.96974182], [88.69259644, 21.96976852], [88.69239807, 21.96980095], [88.69198608, 21.97000122], [88.69150543, 21.97023392], [88.69091797, 21.97039986], [88.6902771, 21.97059059], [88.68968964, 21.9708519], [88.68913269, 21.97113991], [88.688591, 21.97144127], [88.68807983, 21.97178078], [88.68759155, 21.97213936], [88.68712616, 21.97252083], [88.68673706, 21.97295952], [88.68643951, 21.97350121], [88.68629456, 21.97412682], [88.68641663, 21.97475052], [88.6866684, 21.97530937], [88.68694305, 21.97579193], [88.68727112, 21.97618294], [88.68757629, 21.97657776], [88.6878891, 21.97695351], [88.68817902, 21.97732925], [88.6884613, 21.97769737], [88.68875885, 21.97801971], [88.68904114, 21.97835732], [88.68929291, 21.97872162], [88.68953705, 21.97908974], [88.68981934, 21.97945976], [88.69008636, 21.97985268], [88.69039917, 21.98021126], [88.69072723, 21.98054123], [88.69101715, 21.98088074], [88.69126892, 21.9812603], [88.69151306, 21.98166084], [88.69172668, 21.98207092], [88.69197083, 21.98244858], [88.69223022, 21.98279762], [88.69248199, 21.98316002], [88.69271088, 21.98357582], [88.69287109, 21.98405266], [88.69284058, 21.98456001], [88.69278717, 21.9850502], [88.69271088, 21.98551941], [88.69257355, 21.98593903], [88.69243622, 21.98637962], [88.69220734, 21.98681259], [88.69193268, 21.98728943], [88.69156647, 21.9878273], [88.6911087, 21.9883728], [88.69061279, 21.98893929], [88.69008636, 21.9895401], [88.68949127, 21.99003983], [88.68888855, 21.99056435], [88.68835449, 21.99102592], [88.68840027, 21.99110985], [88.68805695, 21.99139023], [88.68776703, 21.99139023], [88.6875, 21.99167061], [88.68723297, 21.99167061], [88.6866684, 21.99110985], [88.68777466, 21.98999977], [88.68805695, 21.98999977], [88.68839264, 21.98958969], [88.688797, 21.98923111], [88.68921661, 21.98887825], [88.68962097, 21.9885006], [88.68997192, 21.98809624], [88.69029999, 21.98768044], [88.69059753, 21.98727036], [88.69087219, 21.98687172], [88.69111633, 21.98649025], [88.69133759, 21.98610115], [88.69145966, 21.98567009], [88.69153595, 21.98524094], [88.69146729, 21.98476982], [88.69142914, 21.98430443], [88.69139862, 21.98387718], [88.69133759, 21.98352051], [88.69120026, 21.98324776], [88.69103241, 21.98297119], [88.69082642, 21.98267746], [88.69056702, 21.98236084], [88.69029236, 21.98203278], [88.69001007, 21.98168755], [88.68972778, 21.98133087], [88.68945313, 21.9809761], [88.68916321, 21.98061943], [88.68885803, 21.98024178], [88.68855286, 21.97981071], [88.68817902, 21.97936058], [88.68781281, 21.97886276], [88.68744659, 21.97837067], [88.68708801, 21.97792244], [88.68675232, 21.97749901], [88.68643188, 21.97710037], [88.68613434, 21.976717], [88.68582153, 21.97635078], [88.68553162, 21.9759407], [88.68525696, 21.97552109], [88.68501282, 21.97505951], [88.68483734, 21.97456932], [88.68482208, 21.97406006], [88.6849823, 21.97356987], [88.68515778, 21.97306252], [88.68537903, 21.97256088], [88.68564606, 21.97209167], [88.68602753, 21.97170067], [88.68643188, 21.9713707], [88.68686676, 21.97110176], [88.68732452, 21.97083092], [88.68782043, 21.97055054], [88.68837738, 21.97027588], [88.68895721, 21.96998978], [88.6895752, 21.96970367], [88.69019318, 21.96940804], [88.69042969, 21.96928024], [88.69078064, 21.9690876], [88.69124603, 21.96866989], [88.69178009, 21.96828079], [88.69232178, 21.96784019], [88.69290161, 21.96741676], [88.69330597, 21.96692276], [88.69358826, 21.96642876], [88.69381714, 21.9659996], [88.69393158, 21.96554947], [88.69412231, 21.96516037], [88.69416809, 21.96471024], [88.69416809, 21.96445084], [88.69416809, 21.96417046], [88.69444275, 21.96389008], [88.69444275, 21.96194267], [88.69472504, 21.96166611], [88.69473267, 21.96138954], [88.69444275, 21.96138954], [88.69410706, 21.96105385], [88.69361115, 21.96055603], [88.69361115, 21.95943832], [88.69333649, 21.95916748], [88.69333649, 21.95889091], [88.69304657, 21.95861053], [88.69304657, 21.95832825], [88.69277954, 21.9580555], [88.69277954, 21.95778084], [88.69249725, 21.95750046], [88.69249725, 21.95721817], [88.6922226, 21.95694351], [88.69232178, 21.95667267], [88.6920166, 21.95640945], [88.69173431, 21.95610619], [88.69133759, 21.95582962], [88.6908493, 21.9556179], [88.69030762, 21.95550919], [88.68982697, 21.95539093], [88.68933868, 21.95529938], [88.688797, 21.95524979], [88.68822479, 21.9551506], [88.68762207, 21.95496178], [88.68700409, 21.95472717], [88.6863327, 21.95453072], [88.68557739, 21.95450974], [88.68479919, 21.95458984], [88.68403625, 21.9545002], [88.68331146, 21.95442963], [88.68261719, 21.95438004], [88.68197632, 21.95424652], [88.6812973, 21.95417976], [88.68061066, 21.95414543], [88.67991638, 21.9540863], [88.67925262, 21.95394135], [88.67860413, 21.95382309], [88.67801666, 21.95365715], [88.67743683, 21.9535408], [88.67690277, 21.95338058], [88.67636871, 21.95326042], [88.6758728, 21.95311546], [88.67534637, 21.95301247], [88.67483521, 21.95288086], [88.67434692, 21.95273209], [88.67389679, 21.9525547], [88.67345428, 21.9524231], [88.67308044, 21.9522934], [88.67272186, 21.95220757], [88.67234802, 21.95218086], [88.67195129, 21.95217705], [88.67153168, 21.95218849], [88.67112732, 21.95223045], [88.67073059, 21.9522953], [88.67034149, 21.95230675], [88.66999817, 21.95240974], [88.66999817, 21.95249939], [88.66971588, 21.95249939], [88.66832733, 21.95388985], [88.66777802, 21.95333099], [88.66777802, 21.95277786], [88.66889191, 21.95168114], [88.66947937, 21.95148087], [88.67002869, 21.95129967], [88.67053223, 21.95112419], [88.67099762, 21.95098305], [88.67147827, 21.95091248], [88.67195129, 21.95095253], [88.67240143, 21.95103645], [88.67282104, 21.95109367], [88.67320251, 21.95116043], [88.67356873, 21.95128822], [88.67397308, 21.95139122], [88.6743927, 21.9514904], [88.67484283, 21.95160103], [88.67530823, 21.95168114], [88.67576599, 21.9517498], [88.67620087, 21.95189095], [88.67664337, 21.95200157], [88.67707062, 21.95214081], [88.67753601, 21.95221901], [88.6780014, 21.95228958], [88.67841339, 21.95241928], [88.67884064, 21.95249176], [88.67928314, 21.95256996], [88.6796875, 21.95269966], [88.68010712, 21.95276833], [88.6805191, 21.95284081], [88.68092346, 21.95296478], [88.68138885, 21.9530201], [88.6818924, 21.95304108], [88.68239594, 21.95304489], [88.68289185, 21.95304489], [88.68339539, 21.95304489], [88.68392181, 21.95304489], [88.68445587, 21.95304489], [88.68498993, 21.95303345], [88.68549347, 21.95298576], [88.68595886, 21.95285988], [88.68644714, 21.95288086], [88.68695831, 21.95298958], [88.68741608, 21.95298958], [88.68778992, 21.95288086], [88.68805695, 21.95277786], [88.68805695, 21.95222092], [88.68722534, 21.95138931], [88.68694305, 21.95139122], [88.68611145, 21.95055962], [88.68583679, 21.95055962], [88.68527985, 21.95000076], [88.6847229, 21.95055962], [88.68444824, 21.95028114], [88.68416595, 21.95028114], [88.6838913, 21.95000076], [88.6838913, 21.94972038], [88.68383789, 21.94955826], [88.68344116, 21.94911003], [88.68309021, 21.9486351], [88.68279266, 21.94815063], [88.68250275, 21.94767952], [88.68221283, 21.94725037], [88.68187714, 21.94688988], [88.68157959, 21.94655037], [88.68132782, 21.94617081], [88.68104553, 21.94582367], [88.68075562, 21.94545746], [88.68042755, 21.94503975], [88.6800766, 21.94464111], [88.6796875, 21.94423103], [88.67929077, 21.94386101], [88.67893219, 21.94355583], [88.67867279, 21.94326973], [88.67851257, 21.94302368], [88.67815399, 21.94286728], [88.6778717, 21.94305992], [88.67750549, 21.94323921], [88.67706299, 21.94338036], [88.67656708, 21.94362068], [88.67603302, 21.94389915], [88.67547607, 21.94421005], [88.67495728, 21.94451714], [88.67449188, 21.94486237], [88.67410278, 21.94523048], [88.67370605, 21.9455719], [88.67332458, 21.94589615], [88.67294312, 21.94621086], [88.67253113, 21.94651985], [88.67212677, 21.94683647], [88.67169189, 21.94708443], [88.67125702, 21.9473381], [88.67085266, 21.94760513], [88.6704483, 21.94787025], [88.67005157, 21.94812012], [88.6696701, 21.94837952], [88.66929626, 21.94862938], [88.66892242, 21.94886971], [88.66848755, 21.94903946], [88.66796875, 21.94915009], [88.66738129, 21.94923019], [88.66693878, 21.94947052], [88.6665802, 21.94979286], [88.6661911, 21.95004654], [88.66581726, 21.95031929], [88.66542816, 21.95057106], [88.66503906, 21.95084], [88.66461945, 21.95111084], [88.66417694, 21.95139122], [88.66372681, 21.95169067], [88.66330719, 21.95201111], [88.66281128, 21.95225906], [88.66233063, 21.95251083]]], [[[88.7591629, 21.99860764], [88.7591629, 21.9972229], [88.75888824, 21.99694633], [88.75888824, 21.99666977], [88.75871277, 21.99628448], [88.75853729, 21.99583244], [88.7583313, 21.99583244], [88.7583313, 21.99555779], [88.75776672, 21.99500084], [88.75776672, 21.99472237], [88.75749969, 21.99444389], [88.75749969, 21.99416924], [88.75723267, 21.99389076], [88.75723267, 21.99360085], [88.75682831, 21.9933815], [88.75660706, 21.99297905], [88.75636292, 21.99261284], [88.75605774, 21.99228477], [88.75569153, 21.99197197], [88.75534058, 21.99165344], [88.75497437, 21.99136162], [88.75457764, 21.99105263], [88.75415039, 21.9906826], [88.75370789, 21.99027824], [88.7536087, 21.99027824], [88.7536087, 21.98999977], [88.75332642, 21.98999977], [88.75332642, 21.9897213], [88.75305176, 21.98944664], [88.75305176, 21.98916817], [88.7527771, 21.98888969], [88.7527771, 21.98833275], [88.75250244, 21.98833275], [88.75222015, 21.98805809], [88.75195313, 21.98806381], [88.75166321, 21.98779106], [88.75138855, 21.98750114], [88.75110626, 21.98750114], [88.7508316, 21.98722267], [88.75055695, 21.98722267], [88.75037384, 21.98703957], [88.75, 21.98666573], [88.74973297, 21.98666954], [88.74954224, 21.98648643], [88.74944305, 21.98638916], [88.74804687, 21.98500252], [88.74777985, 21.98500252], [88.7472229, 21.98444176], [88.74694824, 21.98444557], [88.74653625, 21.98403358], [88.7463913, 21.98389053], [88.74582672, 21.98365974], [88.74539948, 21.98346138], [88.74500275, 21.98331451], [88.74466705, 21.98315048], [88.74430084, 21.98307228], [88.74391174, 21.98304939], [88.74352264, 21.98308182], [88.74317169, 21.98321152], [88.742836, 21.98340034], [88.74256134, 21.98371315], [88.74236298, 21.98419189], [88.74220276, 21.98474312], [88.74198914, 21.98527908], [88.74194336, 21.98584938], [88.74192047, 21.98637199], [88.74179077, 21.98682213], [88.74167633, 21.98726082], [88.74162292, 21.98771286], [88.74142456, 21.98807716], [88.74139404, 21.98844337], [88.74145508, 21.98877144], [88.74164581, 21.98904228], [88.74182129, 21.98932076], [88.74197388, 21.98958588], [88.74217224, 21.98981285], [88.74235535, 21.9901371], [88.7425766, 21.99049568], [88.74289703, 21.99083138], [88.74328613, 21.99118423], [88.74362183, 21.99155807], [88.74395752, 21.99188042], [88.7443161, 21.99211311], [88.74468994, 21.99233818], [88.74504089, 21.9926548], [88.74547577, 21.99298477], [88.74597168, 21.99337006], [88.74642944, 21.99385262], [88.74693298, 21.99432182], [88.74739838, 21.99477959], [88.74777985, 21.99527168], [88.74822235, 21.99570847], [88.74874115, 21.99614143], [88.74928284, 21.99664116], [88.74990082, 21.99711037], [88.7505188, 21.99758148], [88.75108337, 21.99809837], [88.75111389, 21.99833488], [88.75138855, 21.99832916], [88.75222778, 21.9991703], [88.75222778, 21.99945259], [88.75250244, 22.00000191], [88.7527771, 22.00028801], [88.75300598, 22.0003109], [88.75324249, 22.00047493], [88.75348663, 22.00073051], [88.75370026, 22.00107765], [88.75392914, 22.00142097], [88.75417328, 22.00175476], [88.75441742, 22.00206947], [88.75463104, 22.00241089], [88.75482941, 22.00276184], [88.75505829, 22.00312233], [88.75531006, 22.00352287], [88.75559998, 22.00395012], [88.75587463, 22.00444031], [88.75614929, 22.0049305], [88.75647736, 22.00538063], [88.75672913, 22.00576973], [88.7569809, 22.00605965], [88.75723267, 22.00629044], [88.75746155, 22.00647736], [88.7576828, 22.00669289], [88.7579422, 22.00694084], [88.75829315, 22.00712013], [88.75847626, 22.00709534], [88.75871277, 22.00706482], [88.75912476, 22.00671577], [88.75943756, 22.00621223], [88.75963593, 22.00567055], [88.75966644, 22.00508118], [88.75955963, 22.00443268], [88.75966644, 22.00379944], [88.75970459, 22.0033226], [88.75971222, 22.00316811], [88.75972748, 22.00258064], [88.75973511, 22.00203514], [88.7598114, 22.00132942], [88.75945282, 22.00000191], [88.75944519, 21.99888992], [88.7591629, 21.99860764]]], [[[88.73143768, 22.04524612], [88.73284912, 22.04360008], [88.73339081, 22.04360008], [88.73342133, 22.04309845], [88.7339859, 22.04276657], [88.7339859, 22.04226112], [88.73342133, 22.04221725], [88.73288727, 22.04252052], [88.7322998, 22.04277039], [88.73228455, 22.0430088], [88.73149872, 22.0430603], [88.73093414, 22.04359818], [88.73091888, 22.04529953], [88.73143768, 22.04524612]]], [[[88.03138733, 22.06056023], [88.03138733, 22.05944061], [88.03111267, 22.05916405], [88.03083038, 22.05916977], [88.03056335, 22.05888939], [88.02916718, 22.05888939], [88.02889252, 22.05916977], [88.02861023, 22.05916405], [88.02833557, 22.05944443], [88.02805328, 22.05944061], [88.02749634, 22.06001091], [88.02749634, 22.0605545], [88.02777863, 22.06083298], [88.02777863, 22.06110954], [88.02749634, 22.06138992], [88.02749634, 22.06194687], [88.02777863, 22.06222153], [88.02805328, 22.06222153], [88.02833557, 22.06249809], [88.02944183, 22.06249809], [88.03138733, 22.06056023]]], [[[88.63582611, 22.0508194], [88.6361084, 22.05055618], [88.6361084, 22.05027962], [88.63639069, 22.05000114], [88.63639069, 22.04944038], [88.6361084, 22.04916573], [88.63555908, 22.04861069], [88.63471222, 22.04861069], [88.63445282, 22.04889107], [88.63388824, 22.04889107], [88.63360596, 22.04916954], [88.6333313, 22.04916573], [88.63277435, 22.04972267], [88.63249969, 22.04972076], [88.63194275, 22.05027962], [88.63166809, 22.05027962], [88.6313858, 22.05055809], [88.63111115, 22.05055809], [88.62999725, 22.05166626], [88.62999725, 22.05194092], [88.62944794, 22.05250168], [88.62944794, 22.05277824], [88.62916565, 22.05305481], [88.62916565, 22.05361176], [88.62889862, 22.05388069], [88.62889862, 22.05417061], [88.6286087, 22.0544529], [88.6286087, 22.05500031], [88.62832642, 22.05528069], [88.62833405, 22.05694389], [88.62805176, 22.05722237], [88.62805176, 22.05833054], [88.6277771, 22.05861092], [88.6277771, 22.06110954], [88.6286087, 22.06195068], [88.62982178, 22.06195068], [88.62999725, 22.06195068], [88.63054657, 22.06249809], [88.63054657, 22.06278038], [88.63083649, 22.06306839], [88.63111115, 22.06306839], [88.63166809, 22.06249809], [88.63166809, 22.06221962], [88.63222504, 22.0616684], [88.63223267, 22.06138992], [88.63249969, 22.06110954], [88.63249969, 22.06083298], [88.63277435, 22.0605545], [88.63276672, 22.05944061], [88.63305664, 22.05916405], [88.63305664, 22.05861092], [88.63360596, 22.05805969], [88.63360596, 22.05667114], [88.63388824, 22.05639076], [88.63388824, 22.05583191], [88.6341629, 22.05555534], [88.6341629, 22.05528069], [88.63445282, 22.05500031], [88.63444519, 22.05444527], [88.63471222, 22.05417061], [88.63471222, 22.05332947], [88.63500214, 22.05305481], [88.63500214, 22.05277824], [88.63527679, 22.05250168], [88.63527679, 22.05221748], [88.63555908, 22.05194473], [88.63555908, 22.05166626], [88.6361084, 22.05111122], [88.63582611, 22.0508194]]], [[[88.90278625, 22.04533386], [88.9025116, 22.04473877], [88.90229797, 22.04414177], [88.90213776, 22.04354477], [88.90193176, 22.04304123], [88.90171051, 22.04257774], [88.90159607, 22.04203987], [88.90141296, 22.04151917], [88.90127563, 22.04101944], [88.90113068, 22.04060555], [88.90103912, 22.04023933], [88.90087128, 22.03996086], [88.90083313, 22.0396328], [88.90083313, 22.03925133], [88.90083313, 22.0391674], [88.90083313, 22.03805923], [88.90055847, 22.03778267], [88.90055847, 22.03722191], [88.90027618, 22.03694725], [88.90027618, 22.03667259], [88.90055847, 22.0363903], [88.90055847, 22.03583908], [88.90083313, 22.03555107], [88.90086365, 22.03511238], [88.90102386, 22.0346508], [88.90113831, 22.03409004], [88.90132141, 22.03347969], [88.90138245, 22.03280067], [88.90139008, 22.03206253], [88.90141296, 22.03129959], [88.9015274, 22.03056145], [88.90164948, 22.02983284], [88.9016571, 22.02914238], [88.9016571, 22.02848244], [88.90171051, 22.02787209], [88.90190125, 22.02733994], [88.9019928, 22.02676392], [88.90216827, 22.02621078], [88.90225983, 22.02560234], [88.90245056, 22.02505302], [88.90246582, 22.02451134], [88.90229034, 22.02403069], [88.90220642, 22.02353096], [88.90202332, 22.02311516], [88.9019165, 22.02270317], [88.90177155, 22.02230263], [88.9016571, 22.02222252], [88.90166473, 22.01888847], [88.90135956, 22.01832008], [88.90093994, 22.01793098], [88.90039825, 22.01775169], [88.89993286, 22.01754189], [88.89943695, 22.01749992], [88.89916992, 22.01749992], [88.89888763, 22.01722145], [88.89833069, 22.01722145], [88.89805603, 22.01694679], [88.89778137, 22.01694679], [88.89764404, 22.01680756], [88.89749908, 22.01666641], [88.89686584, 22.01658249], [88.89629364, 22.01629066], [88.89572144, 22.01601219], [88.89510345, 22.01579857], [88.89451599, 22.01555252], [88.89394379, 22.01530457], [88.89337158, 22.01515007], [88.89285278, 22.01498604], [88.89232635, 22.01478195], [88.89170074, 22.01472473], [88.89098358, 22.01472282], [88.89065552, 22.01472282], [88.89028931, 22.01472282], [88.8897934, 22.01472282], [88.88925171, 22.01472282], [88.8886795, 22.01473236], [88.8881073, 22.01481438], [88.88755035, 22.014925], [88.88706207, 22.01476479], [88.8865509, 22.01472664], [88.8860321, 22.01477242], [88.88555908, 22.01496315], [88.88500977, 22.0150013], [88.88444519, 22.0150013], [88.8839035, 22.0150013], [88.88341522, 22.0150013], [88.88296509, 22.0150013], [88.88252258, 22.0150013], [88.88207245, 22.01499748], [88.88160706, 22.01495171], [88.88115692, 22.01481056], [88.88063049, 22.01491928], [88.88014984, 22.01476097], [88.87960815, 22.01468086], [88.87908173, 22.01452065], [88.87851715, 22.01464272], [88.87795258, 22.01470757], [88.87744904, 22.01473236], [88.87701416, 22.01483917], [88.87666321, 22.01509285], [88.876297, 22.01535988], [88.87592316, 22.01558876], [88.87561798, 22.01585197], [88.8753891, 22.01615334], [88.87526703, 22.01651192], [88.87509918, 22.01686287], [88.87502289, 22.01724052], [88.87499237, 22.01766014], [88.87493896, 22.01807976], [88.87475586, 22.01847267], [88.87472534, 22.01892662], [88.87471771, 22.01940346], [88.87473297, 22.01987267], [88.87470245, 22.02030754], [88.87460327, 22.02066994], [88.87446594, 22.02099991], [88.87441254, 22.02137184], [88.87425232, 22.02176094], [88.87416077, 22.02218819], [88.8740387, 22.02261162], [88.87388611, 22.02299309], [88.87372589, 22.0233326], [88.8735733, 22.02365494], [88.87335968, 22.02397156], [88.87325287, 22.02436256], [88.87304688, 22.0247097], [88.87285614, 22.02507019], [88.87269592, 22.02546883], [88.87243652, 22.02580452], [88.87211609, 22.0261116], [88.87180328, 22.0264225], [88.87166595, 22.02666664], [88.87110901, 22.02722359], [88.87082672, 22.02722168], [88.87088013, 22.02750015], [88.87059021, 22.02749062], [88.87023163, 22.02753639], [88.86982727, 22.02771378], [88.8693161, 22.02776909], [88.86876678, 22.02781105], [88.86823273, 22.02798271], [88.86765289, 22.02808952], [88.86708069, 22.0282917], [88.86644745, 22.0282917], [88.86582184, 22.02815056], [88.86525726, 22.02830315], [88.86473083, 22.02837181], [88.86434937, 22.02854729], [88.86399078, 22.02867317], [88.8637085, 22.02890205], [88.86341095, 22.02918816], [88.86309052, 22.02954292], [88.86279297, 22.02996826], [88.8624115, 22.0303688], [88.8620224, 22.03075981], [88.86164856, 22.03118515], [88.86122131, 22.0315609], [88.86080933, 22.03195], [88.86032104, 22.03227806], [88.85987091, 22.03263664], [88.85948181, 22.03303146], [88.85913086, 22.03347969], [88.85871124, 22.0338726], [88.85823822, 22.03418541], [88.85782623, 22.03455353], [88.8575058, 22.03498268], [88.85714722, 22.03535271], [88.85679626, 22.03570938], [88.85639954, 22.03608131], [88.85591125, 22.03642273], [88.85540771, 22.03681946], [88.85493469, 22.03728867], [88.85441589, 22.03775215], [88.85391235, 22.0382328], [88.85346222, 22.03874969], [88.85299683, 22.03922462], [88.85253906, 22.03969002], [88.85228729, 22.0402317], [88.85218048, 22.04079247], [88.85198212, 22.04123116], [88.8519516, 22.0416832], [88.85204315, 22.04211235], [88.85232544, 22.04246712], [88.85275269, 22.04277039], [88.85327148, 22.04306221], [88.85389709, 22.04329109], [88.85463715, 22.04334068], [88.8553772, 22.04338074], [88.85604095, 22.04356194], [88.85667419, 22.04356766], [88.85730743, 22.04343987], [88.85793304, 22.0435791], [88.85855103, 22.04361153], [88.85915375, 22.04361153], [88.85971832, 22.04361153], [88.86026764, 22.04360962], [88.86080933, 22.04361153], [88.86135864, 22.04364967], [88.86190796, 22.04379082], [88.86227417, 22.04371262], [88.86245728, 22.04367065], [88.86299133, 22.04361916], [88.86348724, 22.04361153], [88.86394501, 22.04361153], [88.86433411, 22.04357719], [88.86467743, 22.04341316], [88.86508942, 22.04334068], [88.86557007, 22.04333305], [88.86612701, 22.04332924], [88.86669922, 22.04327393], [88.86724091, 22.04309845], [88.86782837, 22.04306221], [88.86846161, 22.04305267], [88.86907196, 22.04305458], [88.86968994, 22.04305458], [88.87032318, 22.04306984], [88.8709259, 22.04316139], [88.87152863, 22.04330635], [88.87216949, 22.04333305], [88.87281036, 22.04334068], [88.87342072, 22.04333305], [88.87398529, 22.04333305], [88.8744812, 22.04333305], [88.87493896, 22.04333305], [88.87539673, 22.04333305], [88.87589264, 22.04338264], [88.87641907, 22.04356956], [88.87699127, 22.04361153], [88.87759399, 22.04361916], [88.87819672, 22.04367065], [88.87879181, 22.04383278], [88.8793869, 22.04389], [88.87999725, 22.04393959], [88.88053131, 22.04411125], [88.88109589, 22.04416275], [88.88166046, 22.04417229], [88.88194275, 22.04416656], [88.88221741, 22.04416275], [88.88276672, 22.04416656], [88.88329315, 22.04420853], [88.88374329, 22.04440117], [88.88423157, 22.04444313], [88.88470459, 22.04447365], [88.88515472, 22.04459763], [88.88562012, 22.04470253], [88.88613129, 22.04476357], [88.8866272, 22.04493141], [88.887146, 22.04498291], [88.88770294, 22.04496193], [88.88816071, 22.04504585], [88.88858032, 22.04527092], [88.88904572, 22.04548645], [88.88964081, 22.04557991], [88.89021301, 22.04584312], [88.89073944, 22.04617691], [88.89116669, 22.04660225], [88.89160919, 22.04704094], [88.8917923, 22.04736328], [88.89190674, 22.04755974], [88.89205933, 22.04816055], [88.89216614, 22.04877281], [88.89204407, 22.04933739], [88.89186096, 22.04980278], [88.89169312, 22.05021286], [88.8915863, 22.05064964], [88.89138031, 22.0510006], [88.89112091, 22.05138969], [88.89082336, 22.05187035], [88.89045715, 22.05239487], [88.88999939, 22.05288506], [88.88963318, 22.05323982], [88.88948822, 22.05338097], [88.88896942, 22.05389977], [88.88844299, 22.05439568], [88.88784027, 22.0547905], [88.88729095, 22.05521965], [88.88682556, 22.05566978], [88.88633728, 22.05608177], [88.8859024, 22.05647087], [88.88562012, 22.05688477], [88.88562775, 22.05732155], [88.88593292, 22.05764961], [88.88639832, 22.05777359], [88.88691711, 22.05778313], [88.88743591, 22.05774117], [88.88787842, 22.0575428], [88.88840485, 22.0574913], [88.88893127, 22.05742836], [88.88938141, 22.05726051], [88.8898468, 22.05717278], [88.89026642, 22.05699158], [88.89055634, 22.05693626], [88.89073181, 22.05690384], [88.89112091, 22.05668449], [88.89154816, 22.05651665], [88.89202118, 22.05639076], [88.89248657, 22.05624008], [88.89295959, 22.05607033], [88.8934021, 22.05583191], [88.89389038, 22.05556488], [88.8944931, 22.05528069], [88.8951416, 22.05499077], [88.89579773, 22.05461311], [88.89633942, 22.05413246], [88.89682007, 22.05365181], [88.89726257, 22.05327225], [88.8975296, 22.0528965], [88.89780426, 22.05262566], [88.89810944, 22.05243874], [88.89837646, 22.0522213], [88.8986969, 22.05201912], [88.89907074, 22.05188179], [88.89936829, 22.05167007], [88.89965057, 22.05147171], [88.89994812, 22.05130959], [88.90023804, 22.05114746], [88.90061951, 22.05107307], [88.90100861, 22.05088997], [88.90143585, 22.05080986], [88.90184021, 22.05067253], [88.90228271, 22.05053139], [88.90268707, 22.05036354], [88.90303802, 22.05010223], [88.9033432, 22.04975128], [88.9036026, 22.04937172], [88.90380859, 22.04895973], [88.90382385, 22.04885292], [88.90388489, 22.04848671], [88.90387726, 22.04800224], [88.90377808, 22.04751015], [88.90359497, 22.04700851], [88.9033432, 22.04649162], [88.90305328, 22.04592705], [88.90278625, 22.04533386]]], [[[88.7638092, 22.05167007], [88.76432037, 22.05166054], [88.76480103, 22.05167007], [88.76529694, 22.05167007], [88.76579285, 22.05167007], [88.76629639, 22.05167007], [88.76679993, 22.05166054], [88.76728821, 22.05161667], [88.76773071, 22.0514431], [88.76819611, 22.05138969], [88.76869965, 22.05138969], [88.76920319, 22.05138969], [88.76940155, 22.05138969], [88.76967621, 22.05138969], [88.7701416, 22.05138969], [88.77054596, 22.05138969], [88.77091217, 22.05139351], [88.77125549, 22.05138969], [88.77162933, 22.05135155], [88.77205658, 22.05116081], [88.77259827, 22.05109215], [88.7731781, 22.05098534], [88.77377319, 22.05081749], [88.77429962, 22.0505619], [88.77479553, 22.05029869], [88.77526093, 22.05004311], [88.77565765, 22.04972267], [88.77606201, 22.04938316], [88.77642059, 22.04903221], [88.77677917, 22.04874992], [88.77700043, 22.04841042], [88.77723694, 22.04813194], [88.77749634, 22.04789162], [88.77780914, 22.04766655], [88.77818298, 22.04747391], [88.77854919, 22.04722023], [88.77892303, 22.04694939], [88.77928925, 22.04665947], [88.77958679, 22.04633141], [88.77974701, 22.04593086], [88.779953, 22.04557228], [88.77996063, 22.04516983], [88.77979279, 22.04477119], [88.77960968, 22.04433823], [88.77939606, 22.04391289], [88.77915192, 22.04347038], [88.77888489, 22.04302216], [88.77863312, 22.04251671], [88.77845764, 22.04193306], [88.77832794, 22.04132271], [88.77820587, 22.04073143], [88.77810669, 22.04018211], [88.77822876, 22.03968239], [88.77832031, 22.03923225], [88.77838898, 22.03881264], [88.77854156, 22.03844833], [88.77861786, 22.03803062], [88.77870941, 22.03757286], [88.77890778, 22.03718376], [88.77919769, 22.03684044], [88.77955627, 22.03655052], [88.77998352, 22.03632927], [88.78040314, 22.03613091], [88.78082275, 22.03594017], [88.78119659, 22.03574753], [88.78157806, 22.03555107], [88.78195953, 22.03532219], [88.78243256, 22.03524017], [88.7828598, 22.0350399], [88.78336334, 22.03495216], [88.78380585, 22.03477669], [88.78430939, 22.03473091], [88.78482056, 22.03471947], [88.78530884, 22.03472137], [88.78575897, 22.03467941], [88.7861557, 22.03449249], [88.78660583, 22.03444862], [88.78705597, 22.03444099], [88.78752136, 22.0343914], [88.78796387, 22.03420448], [88.78845215, 22.0341053], [88.78887939, 22.03388023], [88.78933716, 22.03361511], [88.78985596, 22.03333092], [88.7904129, 22.03299141], [88.79088593, 22.03251076], [88.79128265, 22.03199005], [88.79142761, 22.03133202], [88.79158783, 22.03066826], [88.79139709, 22.03000069], [88.79104614, 22.02937126], [88.79051971, 22.02894592], [88.78993225, 22.02860069], [88.78939056, 22.02827454], [88.78887939, 22.02794456], [88.78838348, 22.02764702], [88.78797913, 22.02729034], [88.78755188, 22.02699089], [88.78713226, 22.02669144], [88.78669739, 22.02641487], [88.78627014, 22.02612114], [88.78582764, 22.02584267], [88.78536987, 22.02555275], [88.78488922, 22.0252552], [88.7844162, 22.02489471], [88.7838974, 22.02453613], [88.78337097, 22.02412987], [88.78285217, 22.02370262], [88.78231049, 22.02334404], [88.78177643, 22.02303123], [88.78132629, 22.02272224], [88.78092194, 22.02257156], [88.78063202, 22.02269173], [88.78035736, 22.02261162], [88.78012848, 22.02224159], [88.77990723, 22.02187729], [88.77944183, 22.02111244], [88.77861023, 22.02028084], [88.77805328, 22.02000237], [88.77805328, 22.01972008], [88.77416992, 22.01972008], [88.77305603, 22.02000237], [88.76889038, 22.02000237], [88.76889038, 22.02056313], [88.76777649, 22.02083588], [88.76389313, 22.02111244], [88.76167297, 22.02139091], [88.76166534, 22.02166939], [88.7611084, 22.02194405], [88.7611084, 22.02523994], [88.7611084, 22.02555656], [88.76083374, 22.02527809], [88.76083374, 22.02596092], [88.76082611, 22.02722168], [88.76055908, 22.02750015], [88.76055908, 22.02778053], [88.76027679, 22.02805519], [88.76055908, 22.02833176], [88.76055908, 22.02889061], [88.76027679, 22.02916908], [88.76027679, 22.02944374], [88.76000214, 22.02972221], [88.76000214, 22.03194237], [88.75888824, 22.03305435], [88.75904083, 22.03383446], [88.7591095, 22.0342617], [88.75917816, 22.03468895], [88.75932312, 22.03531265], [88.75911713, 22.03558159], [88.7588501, 22.03583908], [88.75856018, 22.03613091], [88.75829315, 22.03645134], [88.75804138, 22.03685951], [88.75776672, 22.03730965], [88.75749969, 22.03781319], [88.75722504, 22.0383358], [88.75694275, 22.03884315], [88.75666046, 22.03931236], [88.75637054, 22.03975105], [88.75610352, 22.04019737], [88.75592804, 22.04047775], [88.75582886, 22.04063034], [88.75557709, 22.04108238], [88.75541687, 22.04151917], [88.75528717, 22.04186821], [88.75517273, 22.04219246], [88.75502777, 22.04249191], [88.75495911, 22.04284286], [88.754776, 22.04316139], [88.7546463, 22.04356956], [88.75444031, 22.04400063], [88.75416565, 22.04447365], [88.75389099, 22.04499245], [88.7536087, 22.04553032], [88.75332642, 22.04606056], [88.7530899, 22.04655266], [88.75296021, 22.04705048], [88.75276184, 22.04743767], [88.75253296, 22.04778099], [88.75235748, 22.04818916], [88.75216675, 22.04859161], [88.75193787, 22.04900169], [88.75171661, 22.04943275], [88.75163269, 22.04992104], [88.7514267, 22.05033302], [88.75145721, 22.05069923], [88.7516098, 22.05101967], [88.75166321, 22.05137062], [88.75172424, 22.05169106], [88.75193787, 22.05194283], [88.75213623, 22.0522213], [88.75241089, 22.05248451], [88.75247955, 22.05255127], [88.75275421, 22.05275726], [88.75315094, 22.05304337], [88.75363922, 22.05328941], [88.75424957, 22.05338097], [88.75483704, 22.05355263], [88.75543213, 22.05361176], [88.75602722, 22.05361366], [88.7565918, 22.05358315], [88.75711823, 22.05344963], [88.75762939, 22.05331993], [88.75809479, 22.05316162], [88.75855255, 22.05302429], [88.75895691, 22.05282021], [88.75946045, 22.05273819], [88.75992584, 22.05255318], [88.76043701, 22.05246162], [88.76089478, 22.05226326], [88.76140594, 22.05216789], [88.76184082, 22.05199814], [88.76233673, 22.05194283], [88.7624588, 22.05192375], [88.76282501, 22.05186653], [88.76331329, 22.05171013], [88.7638092, 22.05167007]]], [[[88.81185913, 22.06075478], [88.81230164, 22.06065178], [88.81276703, 22.06077003], [88.81322479, 22.06079292], [88.8136673, 22.06074905], [88.81401062, 22.06084824], [88.81439972, 22.06102371], [88.81491852, 22.06111336], [88.81550598, 22.06121254], [88.81613922, 22.06135178], [88.81685638, 22.06139183], [88.81762695, 22.06138039], [88.81839752, 22.06129456], [88.81900787, 22.06094933], [88.81945801, 22.06036186], [88.81983185, 22.05974197], [88.82012177, 22.05916023], [88.82035828, 22.05866051], [88.8207016, 22.05833244], [88.8208313, 22.05833244], [88.82111359, 22.05805779], [88.82138062, 22.0580616], [88.8216629, 22.05778313], [88.82195282, 22.05778313], [88.82250214, 22.05722237], [88.82277679, 22.05722237], [88.82416534, 22.05583382], [88.82444763, 22.05583382], [88.82472229, 22.05555534], [88.82525635, 22.05527115], [88.825737, 22.05496025], [88.82620239, 22.05461311], [88.82656097, 22.05427551], [88.82692719, 22.05396271], [88.8273468, 22.05372047], [88.8277359, 22.053442], [88.82805634, 22.05310249], [88.8283844, 22.0527935], [88.82870483, 22.05251884], [88.82901764, 22.05225945], [88.82935333, 22.05201721], [88.8296814, 22.05173302], [88.8300705, 22.0514431], [88.83052826, 22.05113029], [88.83101654, 22.05075073], [88.83142853, 22.05024147], [88.83174133, 22.04969406], [88.83187866, 22.04913139], [88.83178711, 22.04860306], [88.83163452, 22.04811668], [88.83139801, 22.04770088], [88.83114624, 22.04726982], [88.83085632, 22.04681969], [88.83059692, 22.04631233], [88.83039093, 22.04579544], [88.83023071, 22.04528999], [88.82993317, 22.04488945], [88.83027649, 22.0447216], [88.83027649, 22.04389], [88.83027649, 22.04335976], [88.83029175, 22.04290009], [88.83036041, 22.04244804], [88.830513, 22.04203224], [88.83055115, 22.04159737], [88.83056641, 22.0411396], [88.83056641, 22.04067993], [88.83062744, 22.04024315], [88.83079529, 22.03988457], [88.83087921, 22.0395031], [88.83106232, 22.03916931], [88.83110809, 22.03878975], [88.83110809, 22.0383625], [88.83111572, 22.03791428], [88.83114624, 22.03746223], [88.83128357, 22.03702927], [88.83138275, 22.03659821], [88.83144379, 22.0361557], [88.83161926, 22.03573036], [88.8316803, 22.03520012], [88.83177948, 22.0346508], [88.8319397, 22.03418159], [88.83210754, 22.03371239], [88.83220673, 22.03318405], [88.83228302, 22.03257942], [88.83245087, 22.03193665], [88.83249664, 22.03120995], [88.83255005, 22.03049469], [88.8327179, 22.02983856], [88.8327713, 22.0291996], [88.83275604, 22.02858925], [88.83261871, 22.0280323], [88.83246613, 22.02752113], [88.83220673, 22.02717018], [88.8318634, 22.02697563], [88.83138275, 22.02693939], [88.83084869, 22.02694321], [88.83030701, 22.02697182], [88.82981873, 22.02711487], [88.82933044, 22.02716064], [88.82909393, 22.02707863], [88.82885742, 22.0269928], [88.82836914, 22.02696037], [88.82789612, 22.02702141], [88.82740021, 22.02700233], [88.82691956, 22.02718163], [88.82643127, 22.02722359], [88.82594299, 22.02722359], [88.82544708, 22.02722359], [88.82495117, 22.02722359], [88.82444763, 22.02722359], [88.82393646, 22.02722359], [88.82343292, 22.02722359], [88.82293701, 22.02719879], [88.82247925, 22.02705956], [88.82200623, 22.02696037], [88.82151794, 22.02692986], [88.82102203, 22.02684212], [88.82052612, 22.02669334], [88.81997681, 22.02667046], [88.81941223, 22.02665138], [88.81882477, 22.02663422], [88.81827545, 22.02647972], [88.81774139, 22.02635765], [88.81732178, 22.02615166], [88.81685638, 22.02602196], [88.81639862, 22.02586174], [88.81587219, 22.02579308], [88.81536102, 22.02556801], [88.81479645, 22.02536011], [88.81420898, 22.02519417], [88.81365967, 22.02505302], [88.8131485, 22.02514076], [88.81295013, 22.02525139], [88.81278992, 22.02544975], [88.81265259, 22.02584648], [88.81252289, 22.02639008], [88.81240845, 22.02701187], [88.81221008, 22.0275631], [88.8119812, 22.02802086], [88.81175995, 22.0284214], [88.81165314, 22.02887154], [88.81150055, 22.02934456], [88.81138611, 22.02971268], [88.81138611, 22.03000069], [88.81111145, 22.03028488], [88.81083679, 22.03028488], [88.81054688, 22.03056145], [88.81027985, 22.03055763], [88.81019592, 22.03073692], [88.80992126, 22.0308094], [88.80961609, 22.0309391], [88.80931854, 22.03112984], [88.80902863, 22.03138924], [88.80870056, 22.0316658], [88.80832672, 22.03194427], [88.80789185, 22.03222656], [88.80741882, 22.03250313], [88.8068924, 22.0327816], [88.80636597, 22.03305244], [88.80584717, 22.03328133], [88.80531311, 22.03337288], [88.80484009, 22.03355217], [88.80434418, 22.03360939], [88.80384064, 22.0336132], [88.80331421, 22.0336132], [88.80277252, 22.0336132], [88.80220795, 22.0336132], [88.80163574, 22.0336132], [88.80105591, 22.0336132], [88.80047607, 22.03360176], [88.79994965, 22.0335331], [88.79953003, 22.03334236], [88.79914856, 22.03316689], [88.79879761, 22.03302193], [88.79853058, 22.03282738], [88.79821777, 22.03265953], [88.79781342, 22.03248215], [88.79734039, 22.03222084], [88.79680634, 22.03194237], [88.79627991, 22.03165627], [88.79582214, 22.03137016], [88.79541779, 22.03114891], [88.79499054, 22.03106117], [88.79466248, 22.03088951], [88.7943573, 22.0309391], [88.7940979, 22.03107834], [88.79383087, 22.03114128], [88.79359436, 22.03126526], [88.7933197, 22.03147316], [88.79296112, 22.03176308], [88.79257965, 22.03215218], [88.79223633, 22.0325985], [88.79191589, 22.03311157], [88.79151917, 22.03360176], [88.79107666, 22.03407288], [88.7906189, 22.03447151], [88.79016876, 22.03480721], [88.78966522, 22.03502464], [88.78925323, 22.03528023], [88.78887939, 22.03555107], [88.78849792, 22.0357933], [88.78806305, 22.03595924], [88.78762817, 22.03611565], [88.78720856, 22.03626633], [88.78679657, 22.0363903], [88.78639221, 22.03652954], [88.7859726, 22.03664207], [88.7855072, 22.03666878], [88.78501892, 22.03670311], [88.78453827, 22.03689194], [88.78401947, 22.03694725], [88.78347778, 22.0370121], [88.78296661, 22.03718758], [88.78243256, 22.03722191], [88.78189087, 22.03722191], [88.78136444, 22.03723717], [88.78087616, 22.03733444], [88.78045654, 22.03753471], [88.780159, 22.03783226], [88.78002167, 22.0382328], [88.77999878, 22.03870964], [88.77999878, 22.03921318], [88.77999878, 22.03973007], [88.78000641, 22.04026222], [88.78009033, 22.04079247], [88.7802887, 22.04125023], [88.78053284, 22.04169846], [88.78069305, 22.04219818], [88.78083801, 22.04267311], [88.78099823, 22.04307747], [88.7811203, 22.0434494], [88.78127289, 22.04377174], [88.78142548, 22.04403877], [88.78164673, 22.04424667], [88.78185272, 22.0444622], [88.78204346, 22.04471779], [88.78227234, 22.04498291], [88.78256989, 22.04525948], [88.7829361, 22.04554939], [88.78336334, 22.04584312], [88.78378296, 22.04614067], [88.78413391, 22.04649544], [88.78440857, 22.04689217], [88.78465271, 22.04731178], [88.78482819, 22.04777336], [88.78502655, 22.04827309], [88.78528595, 22.04879951], [88.78555298, 22.0493412], [88.78578949, 22.04990959], [88.78583527, 22.05055809], [88.78583527, 22.0511837], [88.7858429, 22.05175018], [88.78588867, 22.05224037], [88.78607178, 22.05262184], [88.78610992, 22.05297852], [88.78610992, 22.05331993], [88.78614044, 22.05363655], [88.78626251, 22.05391121], [88.78636932, 22.05421829], [88.78642273, 22.05457497], [88.78658295, 22.05494118], [88.78665924, 22.05537987], [88.78666687, 22.05585289], [88.78666687, 22.05631828], [88.78668976, 22.05678368], [88.78679657, 22.05721474], [88.78691864, 22.05764961], [88.7869873, 22.05813789], [88.78718567, 22.05864143], [88.78729248, 22.05920219], [88.78757477, 22.05962944], [88.78800964, 22.05988503], [88.78849792, 22.0597744], [88.78887939, 22.05938721], [88.78916931, 22.0589695], [88.78939819, 22.05859375], [88.78948975, 22.05812645], [88.78968811, 22.05772209], [88.78981018, 22.05730247], [88.79001617, 22.05695152], [88.79026794, 22.05661964], [88.79055023, 22.05628014], [88.79083252, 22.05593681], [88.79112244, 22.05559731], [88.79141998, 22.05529213], [88.7917099, 22.05503273], [88.79203033, 22.05482864], [88.79242706, 22.05468941], [88.79285431, 22.0545311], [88.79335785, 22.05439949], [88.79389954, 22.05424118], [88.79447174, 22.05424118], [88.79499054, 22.05439758], [88.79551697, 22.05449104], [88.79602051, 22.0547123], [88.79658508, 22.05488777], [88.79724121, 22.05498314], [88.79794312, 22.05507278], [88.79856873, 22.05529213], [88.79914856, 22.05555534], [88.79970551, 22.05583382], [88.80023956, 22.05611229], [88.80072021, 22.05640984], [88.80108643, 22.05677223], [88.80137634, 22.05717278], [88.80162811, 22.05759239], [88.80184174, 22.05803871], [88.80209351, 22.05849457], [88.80233765, 22.05903053], [88.80252838, 22.05971336], [88.80278015, 22.06038475], [88.80305481, 22.06103134], [88.80332184, 22.06163979], [88.80349731, 22.06224251], [88.80348969, 22.06284142], [88.80368805, 22.06337166], [88.80404663, 22.06377983], [88.80448914, 22.06413078], [88.80509186, 22.06433105], [88.80570984, 22.06438255], [88.80632019, 22.06417274], [88.80692291, 22.06389046], [88.80750275, 22.06349182], [88.80802917, 22.06304932], [88.80853271, 22.06260109], [88.80903625, 22.06224251], [88.80951691, 22.06194115], [88.80995178, 22.06166267], [88.81033325, 22.06139183], [88.81069183, 22.06115913], [88.8110733, 22.06100273], [88.81143951, 22.06084824], [88.81185913, 22.06075478]]], [[[88.94996643, 22.18919182], [88.95066833, 22.18916893], [88.95139313, 22.18919182], [88.95210266, 22.18923187], [88.95275879, 22.18939018], [88.95336151, 22.18941307], [88.95385742, 22.18946266], [88.95427704, 22.18956184], [88.95471191, 22.18968773], [88.95522308, 22.18973732], [88.95574188, 22.18981171], [88.95623779, 22.18995094], [88.95674133, 22.19000053], [88.9572525, 22.1900425], [88.95773315, 22.1901226], [88.95820618, 22.1902523], [88.95868683, 22.19028473], [88.95915222, 22.19022942], [88.95957947, 22.19000053], [88.9599762, 22.18975258], [88.96035767, 22.18955421], [88.96066284, 22.18935204], [88.96089172, 22.18912315], [88.96102905, 22.18886757], [88.96115112, 22.18858719], [88.96131134, 22.18836021], [88.96138763, 22.1880703], [88.96144867, 22.18775749], [88.96161652, 22.18747139], [88.96173096, 22.1870842], [88.9618988, 22.18666077], [88.96195221, 22.18612289], [88.96199799, 22.18558311], [88.96216583, 22.18513298], [88.96224976, 22.18469048], [88.96235657, 22.18430138], [88.96247101, 22.18391037], [88.96250916, 22.18346977], [88.96256256, 22.18301964], [88.96269989, 22.18258095], [88.96277618, 22.18208122], [88.9628067, 22.18156052], [88.9629364, 22.18108368], [88.96305847, 22.18058014], [88.96322632, 22.18012047], [88.96338654, 22.17967033], [88.96359253, 22.17925072], [88.96375275, 22.17883873], [88.96391296, 22.17842293], [88.96412659, 22.17806053], [88.96424103, 22.17762947], [88.96440887, 22.17724037], [88.9644928, 22.17679024], [88.9646759, 22.17635155], [88.96473694, 22.17583275], [88.96483612, 22.17533302], [88.96499634, 22.1748848], [88.96517944, 22.17451286], [88.96529388, 22.17413139], [88.96541595, 22.17380905], [88.9655304, 22.17350197], [88.96560669, 22.17318916], [88.96570587, 22.17289162], [88.96581268, 22.17256927], [88.96588898, 22.1722126], [88.96607971, 22.17187309], [88.96620941, 22.17141533], [88.96639252, 22.17089272], [88.9666214, 22.17033958], [88.96691132, 22.16983795], [88.96720886, 22.16936493], [88.96747589, 22.16890144], [88.96769714, 22.16841316], [88.96792603, 22.16790962], [88.96819305, 22.16737747], [88.96853638, 22.16687584], [88.96882629, 22.16629028], [88.96911621, 22.16567039], [88.96940613, 22.16507149], [88.96977234, 22.16456032], [88.97012329, 22.16415024], [88.97039032, 22.16376686], [88.97059631, 22.16340065], [88.97077179, 22.1631031], [88.97091675, 22.16282082], [88.97113037, 22.16259956], [88.97133636, 22.16238213], [88.97151947, 22.16208267], [88.97174072, 22.16173172], [88.97206879, 22.1613903], [88.97244263, 22.16101265], [88.97277069, 22.16057777], [88.97312927, 22.16021156], [88.97344208, 22.15987587], [88.97364807, 22.15953445], [88.97383118, 22.15921974], [88.97400665, 22.15891075], [88.97423553, 22.15863228], [88.97452545, 22.15835381], [88.97488403, 22.15805817], [88.97528839, 22.15773964], [88.97569275, 22.15735626], [88.97608948, 22.15697289], [88.97651672, 22.15665245], [88.97690582, 22.15632057], [88.97727203, 22.15599251], [88.97768402, 22.15576363], [88.97803497, 22.15546227], [88.97837067, 22.15510178], [88.97875214, 22.15475273], [88.9792099, 22.1544342], [88.97969055, 22.15409279], [88.98015594, 22.15372086], [88.98059845, 22.15332985], [88.98105621, 22.15296936], [88.98147583, 22.1525631], [88.98192596, 22.15219307], [88.98227692, 22.15175056], [88.98266602, 22.15137863], [88.98301697, 22.15100288], [88.98332977, 22.1506424], [88.98360443, 22.1502552], [88.98387146, 22.14985466], [88.98413086, 22.14946175], [88.98441315, 22.14914131], [88.98467255, 22.14883232], [88.98486328, 22.14848137], [88.98497772, 22.14812088], [88.98501587, 22.14772224], [88.98500824, 22.14731216], [88.98500061, 22.14688683], [88.98500061, 22.14645195], [88.98500061, 22.14599037], [88.98500061, 22.1455307], [88.98500061, 22.14506912], [88.98500061, 22.14460945], [88.98500061, 22.14415169], [88.98501587, 22.14372063], [88.98513031, 22.14334869], [88.98525238, 22.14301109], [88.9852829, 22.14262199], [88.98527527, 22.14222336], [88.9852829, 22.14181328], [88.98529053, 22.14141273], [88.9852829, 22.14101982], [88.98525238, 22.14063072], [88.98513794, 22.14025116], [88.98497009, 22.13983154], [88.98468018, 22.13940239], [88.98427582, 22.1389904], [88.98384857, 22.13861084], [88.98342133, 22.1382122], [88.98306274, 22.13777161], [88.98272705, 22.13733482], [88.98241425, 22.13694382], [88.98214722, 22.13656044], [88.98192596, 22.13614082], [88.98173523, 22.13573265], [88.98160553, 22.13525963], [88.98140717, 22.13478279], [88.98122406, 22.13426781], [88.98104095, 22.13372231], [88.98079681, 22.13323021], [88.98047638, 22.13286018], [88.98012543, 22.13263321], [88.97976685, 22.13251686], [88.97937775, 22.1325016], [88.97892761, 22.13259315], [88.97852325, 22.13286018], [88.97815704, 22.13323021], [88.97782135, 22.13359261], [88.97751617, 22.13393211], [88.97727203, 22.13427162], [88.97705078, 22.13462257], [88.97677612, 22.13498116], [88.97647095, 22.13536263], [88.97618866, 22.13581276], [88.97596741, 22.13634682], [88.97570801, 22.13686943], [88.97538757, 22.13735771], [88.97501373, 22.13776588], [88.97463989, 22.13814354], [88.97425842, 22.13850212], [88.97384644, 22.13883018], [88.97338867, 22.13916969], [88.97294617, 22.13958168], [88.97254944, 22.14003181], [88.97212219, 22.14046288], [88.97164917, 22.1408329], [88.97120667, 22.14116287], [88.97078705, 22.14147568], [88.97045135, 22.14180946], [88.97020721, 22.14217186], [88.96998596, 22.14252281], [88.96977997, 22.14289474], [88.96963501, 22.14332771], [88.96954346, 22.14379311], [88.96955872, 22.14428139], [88.96960449, 22.14476585], [88.96961975, 22.14526176], [88.96959686, 22.14576149], [88.96952057, 22.14626122], [88.96940613, 22.14672852], [88.96928406, 22.14717674], [88.96923065, 22.14763069], [88.96920013, 22.14808083], [88.96907043, 22.1484623], [88.96894836, 22.1488018], [88.9688797, 22.14912987], [88.96890259, 22.14946175], [88.96896362, 22.149786], [88.96909332, 22.15010834], [88.96920776, 22.15045929], [88.96936798, 22.1508007], [88.96952057, 22.15117836], [88.96973419, 22.15157509], [88.96998596, 22.15202522], [88.97027588, 22.15255356], [88.9705658, 22.15313148], [88.97080994, 22.15373039], [88.97087097, 22.15433311], [88.97080231, 22.15487099], [88.97067261, 22.15534019], [88.97051239, 22.15572166], [88.97029877, 22.15603256], [88.97003174, 22.1563015], [88.96967316, 22.15652275], [88.96924591, 22.15670395], [88.96880341, 22.15686989], [88.96828461, 22.15696526], [88.96778107, 22.15694618], [88.96729279, 22.15693855], [88.96681976, 22.15697289], [88.966362, 22.15709496], [88.96592712, 22.15728188], [88.96556091, 22.15757942], [88.965271, 22.15799141], [88.96501923, 22.15845108], [88.96478271, 22.1589222], [88.96450043, 22.15936089], [88.96414948, 22.15972137], [88.96372223, 22.16000938], [88.9631958, 22.16013908], [88.96261597, 22.16015434], [88.96222687, 22.16009712], [88.96203613, 22.16006851], [88.96156311, 22.15994263], [88.96118927, 22.15979195], [88.96082306, 22.1596508], [88.96042633, 22.15947151], [88.95999146, 22.15929985], [88.9595871, 22.15906143], [88.95921326, 22.15880394], [88.95883179, 22.15857315], [88.95845795, 22.15836334], [88.95809174, 22.15821266], [88.9577713, 22.15806961], [88.95746613, 22.158041], [88.95716095, 22.15809059], [88.95688629, 22.15809059], [88.95662689, 22.15799141], [88.95630646, 22.15791512], [88.95594788, 22.15781212], [88.95555115, 22.15773392], [88.95513916, 22.1577549], [88.95472717, 22.15781975], [88.95432281, 22.15797806], [88.9539032, 22.15824318], [88.95345306, 22.15854073], [88.95304871, 22.15874672], [88.95275116, 22.15846825], [88.95311737, 22.15805817], [88.95333099, 22.15750313], [88.95361328, 22.15722084], [88.95388794, 22.15722466], [88.95420837, 22.15703773], [88.95475769, 22.15686989], [88.95542145, 22.15686226], [88.95607758, 22.15683556], [88.95669556, 22.15686226], [88.95728302, 22.15688133], [88.95780945, 22.15691566], [88.95829773, 22.1570549], [88.95874023, 22.15724182], [88.95915985, 22.1574688], [88.95956421, 22.15776253], [88.95999146, 22.15809441], [88.96044922, 22.15842056], [88.96094513, 22.15868568], [88.96147919, 22.15888023], [88.96211243, 22.1590023], [88.9628067, 22.15894127], [88.96340179, 22.15868187], [88.96383667, 22.15828133], [88.96414948, 22.15781212], [88.9644165, 22.15734291], [88.96470642, 22.15693092], [88.9650116, 22.15654945], [88.96534729, 22.15621185], [88.96578979, 22.15597343], [88.96629333, 22.15582848], [88.96679688, 22.15572166], [88.96730042, 22.15566063], [88.96779633, 22.15566063], [88.96829987, 22.15572166], [88.96875763, 22.1556797], [88.96909332, 22.15549278], [88.96930695, 22.15517044], [88.9694519, 22.15477371], [88.96949768, 22.15429115], [88.9694519, 22.15378189], [88.96929932, 22.1532917], [88.96911621, 22.15283012], [88.96884155, 22.15242958], [88.96852112, 22.15205956], [88.9682312, 22.15167046], [88.96795654, 22.1512928], [88.96775055, 22.15090561], [88.96759033, 22.15049934], [88.96755219, 22.1500721], [88.96761322, 22.14962959], [88.96762848, 22.14918327], [88.96762085, 22.14874077], [88.96770477, 22.14826965], [88.96788025, 22.14774132], [88.96801758, 22.14717484], [88.96814728, 22.14666939], [88.96826935, 22.14620972], [88.96835327, 22.14576149], [88.96839142, 22.14531136], [88.96839905, 22.14486122], [88.96839905, 22.14442253], [88.96839142, 22.1439724], [88.96843719, 22.14349174], [88.96852112, 22.14304543], [88.96859741, 22.14264107], [88.96868134, 22.1422596], [88.96885681, 22.14189911], [88.96909332, 22.14151382], [88.9694519, 22.14115524], [88.96990204, 22.14081192], [88.97038269, 22.14040947], [88.97088623, 22.13996315], [88.97142029, 22.13949013], [88.97198486, 22.1390419], [88.97252655, 22.1385746], [88.97305298, 22.13807106], [88.97357941, 22.13755035], [88.97408295, 22.13704491], [88.97447968, 22.13648033], [88.97483063, 22.13591957], [88.97515106, 22.13542557], [88.97545624, 22.13499069], [88.97572327, 22.13457298], [88.97601318, 22.13418007], [88.9763031, 22.13381195], [88.97657776, 22.13341713], [88.97682953, 22.13301468], [88.97705841, 22.13260078], [88.9773407, 22.13226128], [88.97762299, 22.13196182], [88.97793579, 22.13169479], [88.97826385, 22.13146782], [88.9786377, 22.13131142], [88.97902679, 22.13112068], [88.97941589, 22.13098145], [88.97982025, 22.13104057], [88.98017883, 22.1312561], [88.9805069, 22.13145256], [88.9808197, 22.13167953], [88.98113251, 22.13194084], [88.98144531, 22.1322155], [88.98175049, 22.13252449], [88.98200989, 22.13288307], [88.98221588, 22.13332176], [88.98239136, 22.1337738], [88.98256683, 22.13422203], [88.98277283, 22.13462257], [88.98294067, 22.1350193], [88.98309326, 22.13541985], [88.98324585, 22.13585091], [88.98342133, 22.1362896], [88.98365021, 22.1367321], [88.9839859, 22.13716316], [88.98443604, 22.13762283], [88.98490143, 22.13813972], [88.98522186, 22.1381321], [88.985466, 22.13786888], [88.98567963, 22.13755035], [88.98581696, 22.13720322], [88.98590851, 22.13680458], [88.9860611, 22.13640594], [88.98610687, 22.13595772], [88.98610687, 22.13549232], [88.9860611, 22.1350193], [88.98587799, 22.13457298], [88.98583221, 22.13410378], [88.98582458, 22.13356209], [88.98577118, 22.13294411], [88.98567963, 22.13227272], [88.98557281, 22.13161278], [88.98548126, 22.13099289], [88.98530579, 22.13047218], [88.98526764, 22.12997246], [88.98517609, 22.12949181], [88.98506165, 22.12898064], [88.98500824, 22.12837601], [88.98499298, 22.12774277], [88.98491669, 22.12712288], [88.98475647, 22.12657356], [88.98468018, 22.12604332], [88.98457336, 22.12553024], [88.98444366, 22.12500954], [88.98430634, 22.12446022], [88.98419189, 22.1239109], [88.98416901, 22.12333107], [88.98416901, 22.12305641], [88.98387909, 22.12278366], [88.98387909, 22.12167358], [88.98332977, 22.12111282], [88.98332977, 22.11889076], [88.98306274, 22.11861229], [88.98299408, 22.11802864], [88.98280334, 22.11763191], [88.9826355, 22.11721611], [88.98249054, 22.11678123], [88.98234558, 22.1163578], [88.98223114, 22.11590004], [88.98214722, 22.11543083], [88.98197937, 22.11503029], [88.98188782, 22.11460304], [88.98179626, 22.11421394], [88.98166656, 22.11384392], [88.98153687, 22.11348152], [88.98138428, 22.11313057], [88.9812088, 22.1127739], [88.98100281, 22.11237144], [88.98078156, 22.11194992], [88.98055267, 22.11151123], [88.98029327, 22.111063], [88.98005676, 22.11060143], [88.97992706, 22.11013031], [88.97972107, 22.10976982], [88.97949982, 22.10948563], [88.9793396, 22.10918999], [88.97918701, 22.10890579], [88.97905731, 22.10855484], [88.9788208, 22.1082325], [88.97860718, 22.10778999], [88.97834015, 22.10730362], [88.97805786, 22.10677147], [88.97777557, 22.10625648], [88.97750854, 22.10582161], [88.97728729, 22.10545158], [88.97718048, 22.10509109], [88.97705841, 22.1047802], [88.97690582, 22.10451317], [88.97672272, 22.1042614], [88.97663879, 22.10395241], [88.97647858, 22.10368156], [88.97636414, 22.10339165], [88.97621155, 22.10314178], [88.97609711, 22.1028614], [88.97593689, 22.10258865], [88.97580719, 22.10227585], [88.9756012, 22.10195923], [88.97544861, 22.1015625], [88.97525787, 22.10116768], [88.97503662, 22.10080338], [88.97490692, 22.10036278], [88.97470856, 22.09995842], [88.97444916, 22.09954262], [88.9741745, 22.09906006], [88.97389984, 22.09853363], [88.97366333, 22.09798622], [88.97349548, 22.09743309], [88.97333527, 22.09690285], [88.97318268, 22.0963707], [88.97305298, 22.09581184], [88.97286987, 22.09525108], [88.97270203, 22.09465027], [88.97252655, 22.09405899], [88.97239685, 22.09338951], [88.97223663, 22.09273338], [88.97209167, 22.09205818], [88.97189331, 22.09146309], [88.97168732, 22.09089088], [88.97155762, 22.09032249], [88.9713974, 22.08976173], [88.9712677, 22.0891819], [88.971138, 22.08860207], [88.97104645, 22.08799171], [88.97084045, 22.0874958], [88.97061157, 22.08702278], [88.97038269, 22.08653069], [88.97026825, 22.08586311], [88.97014618, 22.08517265], [88.96998596, 22.08457184], [88.96977997, 22.08402061], [88.96966553, 22.08350945], [88.96944427, 22.08312798], [88.9691925, 22.08282852], [88.96890259, 22.08261299], [88.96856689, 22.08244133], [88.96827698, 22.08226967], [88.96794128, 22.0823307], [88.96759033, 22.08267403], [88.96723938, 22.08307457], [88.96688843, 22.08355331], [88.96652222, 22.0840683], [88.96620941, 22.08462906], [88.96592712, 22.08514214], [88.96567535, 22.08555031], [88.96546173, 22.0859127], [88.96527863, 22.08624077], [88.96511078, 22.0865593], [88.96494293, 22.08687019], [88.96479034, 22.08718109], [88.96472931, 22.08755493], [88.96469116, 22.08793831], [88.9646759, 22.08833122], [88.96469116, 22.08875084], [88.96469116, 22.08918571], [88.96466827, 22.08964157], [88.96457672, 22.09009171], [88.96444702, 22.09050941], [88.96425629, 22.09094048], [88.96404266, 22.09143257], [88.96370697, 22.09196281], [88.96330261, 22.09250069], [88.9628067, 22.09301949], [88.96230316, 22.09350014], [88.9617691, 22.09390068], [88.96125031, 22.09428215], [88.96070099, 22.09461021], [88.96012115, 22.09488106], [88.9595108, 22.09507942], [88.9589386, 22.09530067], [88.95842743, 22.09557152], [88.95796967, 22.09588051], [88.95757294, 22.09625626], [88.9572525, 22.09669304], [88.95697021, 22.09716225], [88.95677948, 22.09762764], [88.95668793, 22.09810448], [88.95666504, 22.09857368], [88.95666504, 22.09902763], [88.95667267, 22.09948158], [88.95664215, 22.09993744], [88.95656586, 22.10040092], [88.9564209, 22.1008625], [88.95623016, 22.10133171], [88.95597839, 22.1017704], [88.95562744, 22.10214043], [88.95519257, 22.10244942], [88.95466614, 22.10266113], [88.95411682, 22.10281944], [88.95362091, 22.1029377], [88.95317078, 22.10302162], [88.95276642, 22.1031208], [88.95246887, 22.10323143], [88.95200348, 22.10332298], [88.95192719, 22.10353279], [88.95178986, 22.10367966], [88.95179749, 22.10402489], [88.95187378, 22.1042347], [88.95207977, 22.10472298], [88.95166779, 22.10527992], [88.95054626, 22.10416985], [88.95069885, 22.10368156], [88.95111084, 22.10305977], [88.95111084, 22.1027813], [88.95173645, 22.10249138], [88.95240784, 22.10220146], [88.95303345, 22.10206795], [88.9536972, 22.1019249], [88.95433807, 22.10170364], [88.95485687, 22.10135269], [88.95522308, 22.10090446], [88.95543671, 22.10042381], [88.95553589, 22.09994888], [88.95555878, 22.09949112], [88.95553589, 22.09904289], [88.95549774, 22.09862137], [88.95537567, 22.09821892], [88.95513916, 22.09795189], [88.95503998, 22.09757042], [88.95500183, 22.09722328], [88.95541382, 22.09666634], [88.95555878, 22.09639168], [88.95639038, 22.09556007], [88.95688629, 22.09525108], [88.9573288, 22.09488106], [88.95776367, 22.09453011], [88.95822144, 22.09427071], [88.95871735, 22.09407234], [88.95923615, 22.09388161], [88.95976257, 22.09367943], [88.96026611, 22.09347153], [88.96074677, 22.09324074], [88.9611969, 22.09295082], [88.9616394, 22.09264183], [88.9620285, 22.09230614], [88.96240234, 22.09198189], [88.9627533, 22.09166145], [88.96302032, 22.09130287], [88.9631958, 22.09089088], [88.96331024, 22.09045219], [88.96334839, 22.08995247], [88.96336365, 22.08940697], [88.96334839, 22.08884239], [88.96337891, 22.08826256], [88.96341705, 22.08769035], [88.96356964, 22.08715248], [88.96369934, 22.08661079], [88.96391296, 22.08614159], [88.9641571, 22.08572197], [88.96443176, 22.08529091], [88.96472931, 22.08485794], [88.96502686, 22.08440208], [88.96534729, 22.08394241], [88.96566772, 22.08350182], [88.96594238, 22.0830822], [88.96621704, 22.08268166], [88.96649933, 22.08231163], [88.96681976, 22.08198738], [88.96716309, 22.08166695], [88.96749878, 22.08000183], [88.96721649, 22.07972145], [88.96722412, 22.07944679], [88.96694183, 22.07916832], [88.96694183, 22.07861137], [88.96611023, 22.07777977], [88.9658432, 22.07777977], [88.96537018, 22.07722855], [88.96485901, 22.07681084], [88.96437073, 22.07641029], [88.96386719, 22.0761013], [88.96334839, 22.07583046], [88.962883, 22.07555962], [88.96237946, 22.07531357], [88.96182251, 22.07516289], [88.96128082, 22.07497406], [88.96079254, 22.07473183], [88.96031189, 22.07450485], [88.95983887, 22.07430077], [88.95934296, 22.07418823], [88.95887756, 22.07410812], [88.95846558, 22.07393265], [88.95800018, 22.07388878], [88.95749664, 22.07383156], [88.95697784, 22.07365799], [88.95638275, 22.07361031], [88.95574188, 22.07361031], [88.95510101, 22.07361031], [88.95448303, 22.07361031], [88.95385742, 22.07361031], [88.95322418, 22.07361031], [88.95259094, 22.07361031], [88.95127869, 22.07361031], [88.95063782, 22.07361031], [88.94999695, 22.07361031], [88.9493866, 22.07361031], [88.94882965, 22.07362175], [88.94832611, 22.07366753], [88.94787598, 22.07383156], [88.94742584, 22.07389259], [88.94695282, 22.07389259], [88.94645691, 22.07389259], [88.94597626, 22.07389259], [88.94548798, 22.07389259], [88.94499969, 22.07389259], [88.94452667, 22.07386971], [88.94406891, 22.07377815], [88.94361877, 22.07364082], [88.94315338, 22.07361221], [88.94268799, 22.07361031], [88.94225311, 22.07359123], [88.94180298, 22.07348061], [88.94136047, 22.07339478], [88.94091034, 22.07345009], [88.94042969, 22.07338142], [88.93992615, 22.07332039], [88.93945313, 22.07320213], [88.93900299, 22.07307625], [88.93858337, 22.07299232], [88.93819427, 22.07281876], [88.93778992, 22.07275963], [88.9373703, 22.07265282], [88.93694305, 22.07250023], [88.9366684, 22.07250023], [88.93638611, 22.07222176], [88.93611145, 22.07222176], [88.9355545, 22.07166862], [88.93527985, 22.07167244], [88.93499756, 22.07139015], [88.93444824, 22.07137108], [88.93398285, 22.07111168], [88.93352509, 22.07083702], [88.93305969, 22.07056236], [88.93258667, 22.07028008], [88.93213654, 22.06999016], [88.93171692, 22.0696888], [88.93131256, 22.06937981], [88.93087769, 22.06913185], [88.93045807, 22.06889153], [88.93004608, 22.0686779], [88.92964172, 22.0685215], [88.9292984, 22.06831169], [88.92901611, 22.06802177], [88.92875671, 22.06768036], [88.9283905, 22.06741142], [88.92803192, 22.0670929], [88.92762756, 22.0668087], [88.92720795, 22.06655312], [88.92678833, 22.06635284], [88.92642212, 22.06611824], [88.92602539, 22.06591606], [88.92553711, 22.06575203], [88.92504883, 22.06525993], [88.92463684, 22.06459236], [88.92456818, 22.06402397], [88.92466736, 22.06358337], [88.92460632, 22.06323051], [88.92443085, 22.06287193], [88.92420197, 22.06247139], [88.92404175, 22.06197166], [88.92385101, 22.06147194], [88.92360687, 22.06100082], [88.92336273, 22.06051064], [88.923172, 22.0599556], [88.92302704, 22.05935287], [88.92282104, 22.05874062], [88.92267609, 22.05809212], [88.92249298, 22.05746269], [88.92230988, 22.05685234], [88.92218781, 22.05623055], [88.92202759, 22.05562019], [88.92195129, 22.05494308], [88.92191315, 22.05426216], [88.92185974, 22.05362892], [88.92179871, 22.05303955], [88.92169189, 22.05238152], [88.92172241, 22.05171013], [88.92189026, 22.05101967], [88.92193604, 22.05027962], [88.92194366, 22.0495491], [88.92195129, 22.04887199], [88.92195129, 22.04827309], [88.92193604, 22.04771805], [88.92193604, 22.04718018], [88.92197418, 22.0466938], [88.92209625, 22.04626656], [88.92220306, 22.0458889], [88.92222595, 22.04552269], [88.92222595, 22.04514694], [88.92222595, 22.04473305], [88.92227173, 22.04429054], [88.92238617, 22.04388237], [88.92250061, 22.04347801], [88.92259979, 22.04306984], [88.9227066, 22.04265976], [88.92277527, 22.04236794], [88.92281342, 22.04220581], [88.92299652, 22.04173279], [88.92304993, 22.04115105], [88.92307281, 22.04050255], [88.92312622, 22.0398407], [88.92328644, 22.03922081], [88.92336273, 22.03859138], [88.92352295, 22.03797913], [88.92359924, 22.03732109], [88.92365265, 22.0366497], [88.92384338, 22.0360508], [88.92388916, 22.03548241], [88.92388916, 22.03494835], [88.92388916, 22.03445244], [88.92388916, 22.03396034], [88.9239502, 22.03348732], [88.92415619, 22.03304291], [88.92430115, 22.03255272], [88.92420197, 22.03204155], [88.92414093, 22.03150368], [88.92406464, 22.03096581], [88.92399597, 22.03045082], [88.92392731, 22.0299511], [88.92391205, 22.02951622], [88.92392731, 22.02911949], [88.92399597, 22.02871132], [88.9241333, 22.02816391], [88.92416382, 22.02755547], [88.92415619, 22.02692986], [88.92411804, 22.0263195], [88.92411041, 22.0257225], [88.92397308, 22.02517891], [88.92388916, 22.02467346], [88.92394257, 22.02420235], [88.9241333, 22.02382088], [88.92427063, 22.0234127], [88.9243927, 22.02299309], [88.92449188, 22.02255058], [88.92461395, 22.02213478], [88.92475128, 22.02171326], [88.92494965, 22.02132225], [88.92500305, 22.02085304], [88.92504883, 22.02037239], [88.92516327, 22.01990128], [88.92527771, 22.01940918], [88.92539978, 22.01889992], [88.92555237, 22.01839447], [88.92567444, 22.01790428], [88.92577362, 22.01746559], [88.92584229, 22.01707268], [88.92591858, 22.0167408], [88.92606354, 22.01647568], [88.92610168, 22.01615906], [88.92611694, 22.01584053], [88.92617035, 22.01553154], [88.92634583, 22.01523018], [88.92644501, 22.01488113], [88.92661285, 22.01454353], [88.92671204, 22.0141201], [88.9269104, 22.01374245], [88.92708588, 22.01330757], [88.92723083, 22.0128231], [88.92739868, 22.01233101], [88.9274826, 22.0118618], [88.92752075, 22.01141357], [88.9276123, 22.01101685], [88.927742, 22.01065445], [88.92778778, 22.01020813], [88.92784119, 22.00975227], [88.927948, 22.00926208], [88.92807007, 22.00875664], [88.92823792, 22.00827789], [88.9283371, 22.0078125], [88.92845154, 22.00741005], [88.92856598, 22.00706863], [88.92862701, 22.00671959], [88.9287262, 22.00641823], [88.92884827, 22.00614738], [88.92888641, 22.00583076], [88.92896271, 22.0055027], [88.9291687, 22.00515175], [88.92938232, 22.00473213], [88.92949677, 22.00415039], [88.92973328, 22.00360107], [88.93000031, 22.00309181], [88.93026733, 22.00264168], [88.93052673, 22.00225258], [88.93071747, 22.00192451], [88.93083954, 22.00161552], [88.93094635, 22.00132942], [88.93106079, 22.00093269], [88.93110657, 22.00000191], [88.93253326, 22.00000191], [88.94393158, 22.00000191], [88.94610596, 22.00000191], [88.94638824, 22.00028038], [88.94638824, 22.00083351], [88.94610596, 22.00111008], [88.94611359, 22.00166893], [88.9458313, 22.00194359], [88.94610596, 22.00222206], [88.94610596, 22.00361061], [88.94638824, 22.00389481], [88.94638824, 22.00417137], [88.94555664, 22.00500488], [88.94499969, 22.00500488], [88.94499969, 22.00528145], [88.94416809, 22.00611305], [88.94416809, 22.00639153], [88.94393921, 22.006567], [88.94384003, 22.00664139], [88.94371033, 22.00684929], [88.94351959, 22.00719261], [88.94328308, 22.00757027], [88.94304657, 22.00806236], [88.94278717, 22.00861168], [88.94249725, 22.00913048], [88.94213867, 22.00952911], [88.94180298, 22.0098896], [88.94152832, 22.01032066], [88.94129944, 22.01080894], [88.94104004, 22.01128387], [88.94072723, 22.01166916], [88.94048309, 22.01202965], [88.94028473, 22.0123806], [88.94011688, 22.01271439], [88.93988037, 22.01299286], [88.93969727, 22.01334381], [88.93956757, 22.01375008], [88.93939209, 22.01410294], [88.93916321, 22.01441002], [88.93891907, 22.01473045], [88.93869781, 22.01511192], [88.9385376, 22.01558113], [88.93823242, 22.01589775], [88.93800354, 22.01626587], [88.93785858, 22.01667213], [88.93772125, 22.01709938], [88.93753052, 22.01751137], [88.93740082, 22.01801109], [88.93721771, 22.01851082], [88.93701935, 22.01903343], [88.93690491, 22.01961136], [88.93669891, 22.0200882], [88.9365921, 22.02060127], [88.936409, 22.02103996], [88.93637085, 22.02150154], [88.93625641, 22.0219326], [88.93611908, 22.02235985], [88.93611145, 22.02277946], [88.93611145, 22.0233326], [88.93583679, 22.02361107], [88.93582916, 22.02471924], [88.9355545, 22.02499962], [88.9355545, 22.02555656], [88.93527985, 22.02583504], [88.93530273, 22.02611351], [88.93528748, 22.02631187], [88.93527985, 22.02645302], [88.93522644, 22.02703476], [88.93504333, 22.02752876], [88.93499756, 22.02799225], [88.93499756, 22.02843285], [88.93499756, 22.02888107], [88.93499756, 22.02934074], [88.93499756, 22.02980232], [88.93502808, 22.03025246], [88.93508911, 22.03050041], [88.93512726, 22.0306797], [88.93521118, 22.03112221], [88.93509674, 22.03160286], [88.93501282, 22.0321312], [88.93499756, 22.03272057], [88.9349823, 22.03334045], [88.93492889, 22.03375053], [88.93489838, 22.03397751], [88.93474579, 22.03461266], [88.9347229, 22.03526115], [88.93470764, 22.03591919], [88.93463898, 22.03655052], [88.93451691, 22.03714943], [88.93461609, 22.03769112], [88.93465424, 22.03820229], [88.93448639, 22.03867149], [88.93444824, 22.03916931], [88.93444061, 22.0396843], [88.93444061, 22.04018402], [88.93444824, 22.04065132], [88.93444824, 22.04108238], [88.93444824, 22.04252243], [88.93444824, 22.04293251], [88.93444824, 22.04341316], [88.93444061, 22.04389], [88.93440247, 22.0444088], [88.93424225, 22.04493141], [88.93416595, 22.04554367], [88.93421173, 22.04615784], [88.93438721, 22.0467205], [88.93440247, 22.04726028], [88.93424225, 22.04774284], [88.93417358, 22.04822159], [88.93416595, 22.04870415], [88.93416595, 22.0491848], [88.93416595, 22.04964256], [88.93416595, 22.05007935], [88.93416595, 22.05050087], [88.93416595, 22.05092049], [88.93416595, 22.05135155], [88.93419647, 22.05178261], [88.93435669, 22.05218315], [88.93443298, 22.0526104], [88.93444824, 22.05307961], [88.93448639, 22.05356026], [88.93465424, 22.054039], [88.93473816, 22.05459023], [88.93486023, 22.05513954], [88.93502808, 22.05566216], [88.93527985, 22.05611229], [88.93554687, 22.05653954], [88.93579865, 22.05697441], [88.93604279, 22.05743217], [88.93625641, 22.05790901], [88.93638611, 22.05833244], [88.93722534, 22.05916786], [88.93722534, 22.05944443], [88.9375, 22.05972099], [88.9375, 22.06001091], [88.93776703, 22.06028175], [88.93776703, 22.06056023], [88.9378891, 22.06052017], [88.9382019, 22.06097221], [88.93856812, 22.0614109], [88.93897247, 22.06179237], [88.93950653, 22.06197166], [88.94004822, 22.06217957], [88.94065857, 22.06222916], [88.94123077, 22.06221962], [88.94180298, 22.0621624], [88.94233704, 22.06199074], [88.94293976, 22.0619812], [88.94355774, 22.06205368], [88.94417572, 22.06209373], [88.9447937, 22.06207657], [88.94541168, 22.06200409], [88.94603729, 22.06191063], [88.9466629, 22.06181145], [88.94728088, 22.06171227], [88.94790649, 22.06161308], [88.94853973, 22.06147194], [88.94916534, 22.06121254], [88.9497757, 22.06073952], [88.95040131, 22.06059265], [88.95101166, 22.06056023], [88.95162201, 22.0605526], [88.95222473, 22.06051254], [88.95282745, 22.06032372], [88.95349121, 22.0602417], [88.95413971, 22.06007957], [88.9548111, 22.06012154], [88.95548248, 22.06025124], [88.95614624, 22.06028175], [88.95681, 22.06028175], [88.9574585, 22.06028175], [88.95807648, 22.0602417], [88.95862579, 22.06005478], [88.9591217, 22.05981827], [88.95951843, 22.05948067], [88.9598999, 22.05916405], [88.96009827, 22.05899048], [88.96025085, 22.05885124], [88.96057129, 22.05856133], [88.96092224, 22.05833244], [88.96131134, 22.05815315], [88.96179962, 22.05805206], [88.96231842, 22.05793953], [88.9628067, 22.05772972], [88.96325684, 22.05741119], [88.96363831, 22.05699158], [88.96395111, 22.0565815], [88.96409607, 22.05618286], [88.96398926, 22.05582237], [88.96380615, 22.05550194], [88.96356201, 22.05523109], [88.96324921, 22.05499268], [88.96287537, 22.05472755], [88.96240234, 22.0544529], [88.96185303, 22.05415154], [88.96131134, 22.0537796], [88.96089172, 22.0533123], [88.96055603, 22.05282021], [88.960289, 22.05239487], [88.96013641, 22.05200958], [88.96024323, 22.05162239], [88.96031952, 22.05115318], [88.96054077, 22.05065727], [88.96077728, 22.05007935], [88.96111298, 22.04953194], [88.96146393, 22.04899788], [88.96190643, 22.04858208], [88.96234894, 22.04822159], [88.96277618, 22.04791069], [88.9631958, 22.04762077], [88.96360016, 22.04731941], [88.96398926, 22.0470047], [88.9644165, 22.04673958], [88.96482086, 22.0464325], [88.96523285, 22.04615021], [88.96559906, 22.04585075], [88.96595764, 22.04556084], [88.96630096, 22.04527092], [88.96663666, 22.04498482], [88.96697998, 22.04469872], [88.96734619, 22.04443359], [88.96770477, 22.04413414], [88.96804047, 22.04380035], [88.96837616, 22.04346275], [88.96877289, 22.04318047], [88.9691925, 22.04292107], [88.9696579, 22.04270172], [88.97006989, 22.04241943], [88.97042084, 22.04207802], [88.97078705, 22.04173279], [88.97117615, 22.04142189], [88.97162628, 22.0411396], [88.97206116, 22.0408802], [88.97254181, 22.04068184], [88.97306824, 22.04052162], [88.97357178, 22.0402813], [88.97409821, 22.04005814], [88.97467041, 22.03989983], [88.97524261, 22.03970718], [88.97579956, 22.0394516], [88.97634125, 22.03915977], [88.97680664, 22.0388279], [88.97709656, 22.03839302], [88.97705841, 22.03790092], [88.97690582, 22.03738976], [88.97666168, 22.03689194], [88.97634888, 22.03637695], [88.97599792, 22.03585243], [88.97561646, 22.03532982], [88.9752121, 22.03481483], [88.97473145, 22.03432846], [88.97425842, 22.03380585], [88.97384644, 22.03317261], [88.97340393, 22.03256416], [88.97299194, 22.03196716], [88.97260284, 22.03142929], [88.97226715, 22.03095245], [88.97200012, 22.03051186], [88.97190094, 22.0300045], [88.97170258, 22.02954865], [88.97155762, 22.0290699], [88.9713974, 22.02864265], [88.97128296, 22.02823067], [88.971138, 22.02786064], [88.97108459, 22.02749825], [88.97093964, 22.0272007], [88.97081757, 22.02690315], [88.97065735, 22.02662086], [88.97052002, 22.02630806], [88.97029877, 22.02602959], [88.97005463, 22.02570724], [88.96990204, 22.02526283], [88.9697876, 22.02477646], [88.96967316, 22.02429008], [88.96949005, 22.02386665], [88.96929932, 22.02345848], [88.96914673, 22.02306938], [88.96893311, 22.02274132], [88.96870422, 22.02239799], [88.96858215, 22.02195168], [88.96834564, 22.02158356], [88.96808624, 22.0212307], [88.96788025, 22.0208416], [88.96766663, 22.02043915], [88.96746063, 22.02003288], [88.96720886, 22.01962852], [88.96691132, 22.01923943], [88.96657562, 22.01891136], [88.9662323, 22.01867294], [88.96585083, 22.01861], [88.96549988, 22.01861], [88.96515656, 22.01867294], [88.96472168, 22.01889229], [88.96444702, 22.01889229], [88.9641571, 22.01917076], [88.96389008, 22.01917076], [88.96351624, 22.01879692], [88.96333313, 22.01861], [88.96330261, 22.01844788], [88.96305084, 22.01818275], [88.96277618, 22.01785278], [88.96250153, 22.01749992], [88.96221924, 22.01722145], [88.96221924, 22.01666832], [88.96305847, 22.01667213], [88.96389008, 22.01749992], [88.96518707, 22.01741028], [88.96526337, 22.01702309], [88.96552277, 22.01663017], [88.96565247, 22.01618195], [88.96581268, 22.01577377], [88.96588135, 22.01533318], [88.96605682, 22.01493263], [88.96611023, 22.01447105], [88.96615601, 22.01399231], [88.96629333, 22.01352119], [88.96637726, 22.0130024], [88.96646118, 22.01247215], [88.96666718, 22.01202011], [88.96694946, 22.01156044], [88.9672699, 22.01109123], [88.96766663, 22.01067162], [88.96806335, 22.0102787], [88.96842194, 22.0098896], [88.96874237, 22.00952721], [88.96907043, 22.00917816], [88.9694519, 22.00891876], [88.96985626, 22.00866127], [88.97032166, 22.00845146], [88.97077942, 22.00820351], [88.97120667, 22.00789452], [88.97163391, 22.00757408], [88.97216797, 22.00739479], [88.97267151, 22.00716972], [88.97315216, 22.00692368], [88.97363281, 22.00663948], [88.97408295, 22.00632286], [88.97446442, 22.00594521], [88.97485352, 22.00558853], [88.97521973, 22.00523186], [88.97550964, 22.0048275], [88.97569275, 22.00432014], [88.97580719, 22.00377464], [88.97583771, 22.00318718], [88.97583008, 22.00259972], [88.97576904, 22.00204277], [88.97561646, 22.00154495], [88.97544861, 22.00109291], [88.97528076, 22.00068092], [88.97527313, 22.00036049], [88.97499847, 22.00000191], [88.9747467, 21.99973106], [88.97454834, 21.99946022], [88.97441864, 21.99916267], [88.97418976, 21.99886513], [88.97390747, 21.99851036], [88.97303772, 21.99809074], [88.97290039, 21.99778938], [88.97262573, 21.99726486], [88.97278595, 21.99692535], [88.97255707, 21.99662018], [88.97241211, 21.99632072], [88.97222137, 21.99605942], [88.97203827, 21.99577141], [88.9719162, 21.99538231], [88.97168732, 21.99500084], [88.97136688, 21.99455261], [88.97138977, 21.99444389], [88.97138977, 21.99361229], [88.97123718, 21.99333572], [88.97109222, 21.99304771], [88.97096252, 21.99277306], [88.97110748, 21.99250221], [88.97110748, 21.99110985], [88.97166443, 21.99055481], [88.97194672, 21.99055672], [88.97222137, 21.99027824], [88.97222137, 21.98999977], [88.97220612, 21.9895916], [88.97220612, 21.98891258], [88.97249603, 21.98779106], [88.97305298, 21.98722267], [88.97360992, 21.9869442], [88.9753418, 21.98632622], [88.97585297, 21.98610115], [88.97637939, 21.98587227], [88.97702789, 21.98579216], [88.97766876, 21.9855957], [88.97837067, 21.98555565], [88.97910309, 21.98555183], [88.97982025, 21.98555946], [88.98049927, 21.98555183], [88.98112488, 21.98550034], [88.98168945, 21.98531914], [88.98226929, 21.98527908], [88.98284912, 21.98526955], [88.98340607, 21.98518181], [88.98397827, 21.98502922], [88.98455811, 21.98496056], [88.9850769, 21.98476219], [88.98564148, 21.98467255], [88.98609161, 21.98446083], [88.98655701, 21.98428154], [88.98707581, 21.98412514], [88.98751068, 21.98384285], [88.98774719, 21.98338127], [88.98775482, 21.98280716], [88.98763275, 21.98220253], [88.98751831, 21.98160362], [88.98745728, 21.98103523], [88.98726654, 21.98056221], [88.98722076, 21.98011017], [88.98722076, 21.97969246], [88.98718262, 21.97929382], [88.98699188, 21.97889137], [88.98694611, 21.97845268], [88.98696899, 21.97797966], [88.98709869, 21.97749138], [88.98718262, 21.9769783], [88.98706055, 21.97648048], [88.98706055, 21.97602272], [88.98722076, 21.97555733], [88.98722076, 21.97528458], [88.98750305, 21.97500038], [88.98750305, 21.97472191], [88.98777771, 21.97444725], [88.98777771, 21.9738903], [88.98818207, 21.97299194], [88.98860931, 21.97279358], [88.98895264, 21.97222137], [88.98916626, 21.97194481], [88.99055481, 21.97055626], [88.9909668, 21.97029114], [88.99138641, 21.9702816], [88.99194336, 21.97007942], [88.99223328, 21.97000313], [88.9927063, 21.97001076], [88.99388885, 21.9702816], [88.99415588, 21.97055817], [88.9944458, 21.97055626], [88.99472046, 21.97083473], [88.99500275, 21.97083092], [88.9950943, 21.9708786], [88.99546814, 21.97110748], [88.99588013, 21.97138023], [88.99634552, 21.97163391], [88.99679565, 21.97193146], [88.99724579, 21.97222137], [88.99767303, 21.97252083], [88.99797821, 21.97283745], [88.99819183, 21.97317314], [88.99867249, 21.97361183], [88.99973297, 21.9738903], [88.99973297, 21.97417259], [89.0, 21.97445107], [89.00026703, 21.97505951], [89.00049591, 21.97523308], [89.00080872, 21.97559166], [89.00112152, 21.97598076], [89.00144196, 21.97633362], [89.00179291, 21.97662163], [89.00215912, 21.97683144], [89.00242615, 21.97714043], [89.00276947, 21.97739983], [89.00312042, 21.97768021], [89.00356293, 21.97792435], [89.00395966, 21.97829247], [89.00437164, 21.97868156], [89.0047226, 21.97911263], [89.00506592, 21.97951317], [89.0054245, 21.97985649], [89.00580597, 21.98015213], [89.00617981, 21.98048973], [89.00665283, 21.98080254], [89.00718689, 21.98109245], [89.00777435, 21.98138618], [89.00837708, 21.98166084], [89.00900269, 21.98191071], [89.00963593, 21.98194885], [89.01023102, 21.98195839], [89.01076508, 21.98199463], [89.01126099, 21.98191071], [89.01166534, 21.98168755], [89.01210022, 21.98150063], [89.01246643, 21.98122215], [89.01277161, 21.98084068], [89.01301575, 21.98044395], [89.01316833, 21.9800396], [89.01331329, 21.97970009], [89.0133667, 21.97936058], [89.01352692, 21.9791069], [89.01360321, 21.97883034], [89.01361084, 21.97855186], [89.01361084, 21.97828484], [89.01361084, 21.97803688], [89.01361084, 21.97780037], [89.01361084, 21.97755051], [89.01361084, 21.97727013], [89.01359558, 21.97696686], [89.01346588, 21.97665024], [89.01331329, 21.97631264], [89.01307678, 21.97598076], [89.01283264, 21.97562027], [89.01255798, 21.97528458], [89.01225281, 21.97493362], [89.01194763, 21.97455978], [89.01167297, 21.9741497], [89.0113678, 21.97374535], [89.01101685, 21.97336006], [89.01060486, 21.97303391], [89.01019287, 21.97268677], [89.00979614, 21.97230721], [89.00939941, 21.97197151], [89.00898743, 21.97166824], [89.00859833, 21.97136116], [89.008255, 21.9710331], [89.00793457, 21.97072792], [89.00757599, 21.97051048], [89.0072937, 21.97026443], [89.00699615, 21.96999741], [89.00665283, 21.96972084], [89.00618744, 21.96944427], [89.00564575, 21.96916962], [89.00506592, 21.96889305], [89.0045166, 21.96857262], [89.00403595, 21.96819878], [89.00361633, 21.96776009], [89.00322723, 21.96727371], [89.00280762, 21.96682167], [89.00234985, 21.96669006], [89.00202179, 21.96649933], [89.00152588, 21.96582985], [89.00106049, 21.96546936], [89.00097656, 21.96534157], [89.00026703, 21.96500206], [89.0, 21.96471977], [88.99954987, 21.9644146], [88.99920654, 21.96449089], [88.99878693, 21.96419907], [88.99835968, 21.96389389], [88.9980545, 21.96361542], [88.9952774, 21.9608326], [88.99501801, 21.96046638], [88.99472046, 21.96009254], [88.9944458, 21.95970726], [88.99415588, 21.95932388], [88.99386597, 21.95894051], [88.99357605, 21.95857048], [88.99331665, 21.95815086], [88.99305725, 21.95777321], [88.992836, 21.95740509], [88.99269867, 21.95702171], [88.99252319, 21.9566803], [88.99240112, 21.95630074], [88.99220276, 21.95594978], [88.99195862, 21.95556068], [88.99177551, 21.95509529], [88.9912262, 21.95361137], [88.99093628, 21.95193481], [88.9909668, 21.95105171], [88.99101257, 21.94983864], [88.99101257, 21.94836235], [88.99151611, 21.9474926], [88.99172974, 21.94654465], [88.99266052, 21.94466019], [88.99401855, 21.94291115], [88.99459076, 21.94197273], [88.99637604, 21.94089317], [88.99738312, 21.94008827], [88.99888611, 21.93927956], [89.0, 21.93861198], [89.00047302, 21.93827248], [89.00102234, 21.93808174], [89.00157166, 21.93791008], [89.00208282, 21.93783188], [89.0026474, 21.93774414], [89.00318909, 21.93756485], [89.0037384, 21.93745995], [89.00418854, 21.93725014], [89.00466156, 21.9371891], [89.00505829, 21.93704033], [89.00547028, 21.93692017], [89.00569916, 21.93678474], [89.00583649, 21.93670273], [89.00626373, 21.93659782], [89.00662231, 21.93639374], [89.00701904, 21.936203], [89.00747681, 21.9360981], [89.00792694, 21.93596268], [89.00837708, 21.93582153], [89.00879669, 21.93565178], [89.00923157, 21.93549156], [89.00959778, 21.93526649], [89.00994873, 21.93501091], [89.01029205, 21.93480492], [89.01064301, 21.93462944], [89.01095581, 21.93442917], [89.01126862, 21.93418312], [89.01159668, 21.93394661], [89.01190186, 21.93365288], [89.0121994, 21.93333244], [89.01251984, 21.93302345], [89.01291656, 21.93275261], [89.01331329, 21.9324131], [89.01367188, 21.93201256], [89.01407623, 21.93163109], [89.01442719, 21.93122292], [89.0147171, 21.93077278], [89.01503754, 21.93036461], [89.01539612, 21.93001747], [89.01576233, 21.92971992], [89.01611328, 21.92942238], [89.01642609, 21.92912483], [89.01673889, 21.92881966], [89.0170517, 21.92851067], [89.01735687, 21.92819023], [89.01760101, 21.92782021], [89.0178833, 21.92750549], [89.01837921, 21.9269104], [89.01863098, 21.92621613], [89.01921844, 21.92541313], [89.01943207, 21.92494392], [89.01964569, 21.92433739], [89.01994324, 21.92379951], [89.02008057, 21.92319489], [89.02036285, 21.92279243], [89.0207901, 21.92231941], [89.02094269, 21.92212105], [89.02134705, 21.92165947], [89.02139282, 21.9212513], [89.02139282, 21.92080879], [89.02139282, 21.92034149], [89.02139282, 21.91988564], [89.02139282, 21.91944313], [89.02138519, 21.91901207], [89.02133179, 21.91858673], [89.02114868, 21.91816902], [89.02105713, 21.91768074], [89.02085876, 21.91720009], [89.02070618, 21.91667557], [89.0205307, 21.91616249], [89.02028656, 21.91572762], [89.02004242, 21.91533089], [89.01976013, 21.91499138], [89.01950073, 21.9146595], [89.01928711, 21.91428947], [89.01908112, 21.91389275], [89.01888275, 21.91350174], [89.01869965, 21.91312981], [89.01857758, 21.91278267], [89.01838684, 21.91251945], [89.01829529, 21.91221809], [89.01812744, 21.91198158], [89.01802063, 21.9116745], [89.01776886, 21.91076088], [89.01732635, 21.91022491], [89.01683807, 21.90974808], [89.01661682, 21.90954018], [89.01647949, 21.90934181], [89.01625824, 21.90907478], [89.01612091, 21.9088726], [89.01597595, 21.90879822], [89.01527405, 21.90833282], [89.01499939, 21.90805626], [89.01499939, 21.90750122], [89.01532745, 21.90679932], [89.01532745, 21.90619278], [89.01532745, 21.90574074], [89.01529694, 21.90517998], [89.01522827, 21.9046917], [89.01533508, 21.90415382], [89.01554871, 21.9038105], [89.01550293, 21.90341949], [89.0151062, 21.90306854], [89.01464081, 21.9027729], [89.01418304, 21.90250206], [89.01370239, 21.90227509], [89.01313019, 21.90218353], [89.01257324, 21.90199471], [89.01198578, 21.90194893], [89.01143646, 21.9019413], [89.01113892, 21.90194321], [89.01093292, 21.90194511], [89.01056671, 21.90213966], [89.01003265, 21.90226364], [89.00939941, 21.90227318], [89.00878143, 21.90232277], [89.00827026, 21.90229225], [89.00778198, 21.9024601], [89.00726318, 21.90253639], [89.00682831, 21.90271187], [89.0063858, 21.90282249], [89.00598145, 21.90302086], [89.00553894, 21.90306282], [89.00508881, 21.90306282], [89.00463104, 21.90305519], [89.00416565, 21.90308571], [89.00370026, 21.90322113], [89.0031662, 21.90334129], [89.00250244, 21.90361214], [89.00195313, 21.90361214], [89.00166321, 21.90389061], [89.0, 21.90444374], [88.99906921, 21.9041729], [88.99872589, 21.90437126], [88.99833679, 21.90450096], [88.99790955, 21.90462494], [88.99744415, 21.90474319], [88.99728394, 21.90485191], [88.99695587, 21.90507317], [88.99668121, 21.90527153], [88.99633789, 21.90561104], [88.99584961, 21.90568924], [88.99508667, 21.90572166], [88.9947052, 21.90584564], [88.9942627, 21.90620232], [88.9937439, 21.90665817], [88.99337006, 21.90678978], [88.99299622, 21.90679932], [88.99233246, 21.90694618], [88.99188995, 21.90722466], [88.99144745, 21.90750122], [88.99099731, 21.90778351], [88.99054718, 21.90806007], [88.99010468, 21.90833664], [88.98966217, 21.90860939], [88.98921967, 21.90889359], [88.98875427, 21.90917969], [88.98826599, 21.90950966], [88.98776245, 21.90987778], [88.98751831, 21.91053009], [88.98677826, 21.91090584], [88.98636627, 21.91136169], [88.98578644, 21.91137123], [88.98542786, 21.91161156], [88.98510742, 21.91171265], [88.9850769, 21.91180992], [88.98500061, 21.91194344], [88.98438263, 21.91222954], [88.98416901, 21.91250038], [88.98306274, 21.91361046], [88.98249054, 21.91374016], [88.98236847, 21.91394997], [88.98197937, 21.91406822], [88.98130798, 21.91422272], [88.98071289, 21.91459084], [88.98004913, 21.91494942], [88.97937775, 21.91527367], [88.97872925, 21.91558266], [88.97816467, 21.91592598], [88.97763824, 21.91625023], [88.97711945, 21.91657066], [88.97658539, 21.91688347], [88.97603607, 21.91719246], [88.97551727, 21.91750145], [88.97501373, 21.91778755], [88.97453308, 21.9180603], [88.97406006, 21.91833687], [88.97358704, 21.91861153], [88.9731369, 21.91889191], [88.97267151, 21.91916084], [88.97220612, 21.91942787], [88.97183228, 21.91978455], [88.97173309, 21.91988373], [88.97123718, 21.92019081], [88.97074127, 21.92015457], [88.9702301, 21.9203701], [88.96971893, 21.92056847], [88.96924591, 21.92083168], [88.96883392, 21.92113876], [88.96855164, 21.92152023], [88.96837616, 21.9219799], [88.96849823, 21.92246056], [88.96881866, 21.92294121], [88.9691925, 21.92344093], [88.96974182, 21.92384338], [88.97006226, 21.92423058], [88.97029114, 21.92479134], [88.97065735, 21.92506218], [88.97100067, 21.92533112], [88.97119141, 21.9257412], [88.97150421, 21.92622185], [88.97157288, 21.92672348], [88.97175598, 21.92731285], [88.97192383, 21.92797089], [88.97196198, 21.92854118], [88.9719696, 21.92865372], [88.97171021, 21.92926025], [88.97136688, 21.92986107], [88.97091675, 21.93042946], [88.9704361, 21.93093491], [88.96994019, 21.93137169], [88.96943665, 21.93172836], [88.96894073, 21.93201065], [88.96847534, 21.93225479], [88.96803284, 21.93248177], [88.96759033, 21.9326725], [88.96713257, 21.93280983], [88.96669769, 21.93299294], [88.96626282, 21.93314362], [88.96586609, 21.93334007], [88.96550751, 21.93354988], [88.96514893, 21.93376732], [88.96487427, 21.93406677], [88.96472168, 21.93443298], [88.96469879, 21.93460274], [88.9646759, 21.9348011], [88.96495056, 21.93512535], [88.96543121, 21.93534279], [88.96589661, 21.93554878], [88.96634674, 21.93573761], [88.96683502, 21.93589592], [88.96730042, 21.93605995], [88.96779633, 21.93621254], [88.96829224, 21.93633842], [88.96878052, 21.93642616], [88.96923828, 21.93652916], [88.96961212, 21.93668365], [88.96997833, 21.93684196], [88.97039795, 21.93694115], [88.97084045, 21.93702126], [88.9712677, 21.93715286], [88.97171021, 21.93723106], [88.97218323, 21.93730736], [88.97232056, 21.93734932], [88.97264099, 21.93744659], [88.9731369, 21.93757057], [88.97364807, 21.93772888], [88.97418213, 21.93785477], [88.97470093, 21.93803024], [88.9752121, 21.93823814], [88.97571564, 21.93854332], [88.97618866, 21.9389534], [88.97660065, 21.93945122], [88.9769516, 21.93998146], [88.97722626, 21.94043159], [88.97741699, 21.94080353], [88.9774704, 21.94112587], [88.97740936, 21.94144249], [88.97724152, 21.94176292], [88.97721863, 21.94194794], [88.97666931, 21.94249725], [88.97666931, 21.94583321], [88.97638702, 21.94611168], [88.97555542, 21.94611168], [88.97528076, 21.94583321], [88.97528076, 21.94528008], [88.97528076, 21.94486046], [88.97528076, 21.94441223], [88.97531128, 21.94397163], [88.97538757, 21.94354057], [88.97550201, 21.94312096], [88.97560883, 21.9426899], [88.97573853, 21.94224167], [88.97579956, 21.94173622], [88.97579956, 21.94120216], [88.97570801, 21.94065285], [88.97543335, 21.94015312], [88.97498322, 21.93972778], [88.97441101, 21.93935966], [88.97374725, 21.93907166], [88.97305298, 21.93885231], [88.97228241, 21.93863106], [88.97151947, 21.93843269], [88.97077179, 21.93824577], [88.97003174, 21.93803978], [88.96933746, 21.93785667], [88.96878052, 21.93765068], [88.96824646, 21.93747139], [88.96768188, 21.93735123], [88.96718597, 21.93725014], [88.96659851, 21.93708992], [88.96608734, 21.936903], [88.96560669, 21.93669319], [88.96512604, 21.93650246], [88.96469116, 21.93631744], [88.96431732, 21.93610191], [88.96398163, 21.93590355], [88.96363831, 21.93577576], [88.96333313, 21.93555641], [88.96277618, 21.93499947], [88.96250153, 21.93499947], [88.96250153, 21.9347229], [88.96305847, 21.93416595], [88.96330261, 21.93365288], [88.96362305, 21.9332428], [88.96398163, 21.93286133], [88.96442413, 21.93253136], [88.96495056, 21.9322319], [88.96555328, 21.93193817], [88.96622467, 21.93166161], [88.96692657, 21.9313755], [88.96764374, 21.93104744], [88.96832275, 21.93066978], [88.96897125, 21.93028069], [88.96955109, 21.92990112], [88.96996307, 21.92947006], [88.97026062, 21.92905045], [88.97045898, 21.92867088], [88.97054291, 21.92823982], [88.97051239, 21.92777443], [88.97032928, 21.92728996], [88.97000885, 21.92678452], [88.96939087, 21.92636871], [88.9688797, 21.92599297], [88.96840668, 21.92547035], [88.96795654, 21.92494011], [88.96776581, 21.92451477], [88.96749878, 21.92419243], [88.96708679, 21.92402077], [88.96681976, 21.9237175], [88.96669769, 21.9234333], [88.96642303, 21.92310905], [88.9661026, 21.92292976], [88.96578217, 21.92290115], [88.96541595, 21.92291069], [88.96496582, 21.92298126], [88.96443176, 21.92305946], [88.96381378, 21.92314911], [88.96318054, 21.92334938], [88.96253204, 21.92361259], [88.96186829, 21.92387581], [88.96118927, 21.92409134], [88.96053314, 21.92429352], [88.95989227, 21.92445183], [88.95928955, 21.9246006], [88.95868683, 21.92474174], [88.95812988, 21.92492294], [88.95751953, 21.92507362], [88.95688629, 21.92523384], [88.95617676, 21.92530823], [88.95549011, 21.92551994], [88.95475769, 21.92564964], [88.95409393, 21.9258461], [88.95345306, 21.92609406], [88.95284271, 21.9263134], [88.95226288, 21.92648506], [88.95174408, 21.92667389], [88.95128632, 21.92688942], [88.95083618, 21.92710304], [88.95041656, 21.92730713], [88.94998932, 21.92749214], [88.94954681, 21.92768478], [88.94910431, 21.92784691], [88.94864655, 21.92801094], [88.94818115, 21.92817307], [88.94770813, 21.92831993], [88.94724274, 21.92847252], [88.94680023, 21.92865372], [88.94639587, 21.92887306], [88.945961, 21.92903709], [88.94550323, 21.9292202], [88.94499207, 21.92945862], [88.94444275, 21.92975044], [88.94387817, 21.93010902], [88.94332123, 21.93045235], [88.94278717, 21.93077278], [88.94232941, 21.93108368], [88.94187927, 21.93139458], [88.9414444, 21.93173409], [88.94102478, 21.93213272], [88.94056702, 21.9325428], [88.94007874, 21.93296242], [88.93950653, 21.93333244], [88.93894196, 21.9337101], [88.93842316, 21.93416023], [88.9379425, 21.93460655], [88.93747711, 21.93502426], [88.93707275, 21.93543053], [88.93667603, 21.93581009], [88.93627167, 21.93613625], [88.93588257, 21.93649101], [88.93556213, 21.936903], [88.93528748, 21.9373188], [88.93504333, 21.93773079], [88.93473053, 21.93814278], [88.93438721, 21.93858147], [88.93401337, 21.93903542], [88.93360901, 21.93943214], [88.93276978, 21.94028282], [88.93276978, 21.94056129], [88.9319458, 21.9413929], [88.93147278, 21.94207764], [88.93036652, 21.94571114], [88.9302063, 21.94624138], [88.9302597, 21.94635201], [88.93019104, 21.94749069], [88.9284668, 21.95374107], [88.92617798, 21.95993042], [88.92575073, 21.96206093], [88.92565918, 21.96268654], [88.92523956, 21.96350288], [88.92475128, 21.96363258], [88.92423248, 21.96441078], [88.92250061, 21.96669006], [88.9197464, 21.97256279], [88.91842651, 21.97607994], [88.91748047, 21.97905159], [88.91732788, 21.98011971], [88.91747284, 21.98046684], [88.91738892, 21.98070908], [88.91720581, 21.98124695], [88.91682434, 21.98191643], [88.91671753, 21.98210144], [88.91629791, 21.98299599], [88.91575623, 21.9841938], [88.91558075, 21.98521233], [88.91385651, 21.99114037], [88.91271973, 21.99435997], [88.91300201, 21.99704933], [88.91414642, 21.99839592], [88.91471863, 22.00000191], [88.91468811, 22.00177193], [88.91472626, 22.00229263], [88.91481018, 22.00284195], [88.91497803, 22.00339508], [88.91513062, 22.00401115], [88.91529846, 22.00465965], [88.91552734, 22.00530815], [88.91556549, 22.00600624], [88.91559601, 22.00664139], [88.91573334, 22.00714493], [88.91576385, 22.00728035], [88.91581726, 22.00752068], [88.91583252, 22.00787163], [88.91584015, 22.0082531], [88.91587067, 22.00867271], [88.91590881, 22.00912285], [88.91590881, 22.00961113], [88.916008, 22.01011658], [88.91607666, 22.01062965], [88.91603851, 22.01117134], [88.9158783, 22.01176071], [88.91586304, 22.01234818], [88.91590881, 22.0128994], [88.91588593, 22.01335716], [88.91590881, 22.01375389], [88.91577911, 22.01400185], [88.9156723, 22.0143528], [88.91565704, 22.01485252], [88.91558075, 22.01531982], [88.91553497, 22.0158062], [88.9154129, 22.01626587], [88.91526794, 22.01670265], [88.91510773, 22.01713181], [88.91500092, 22.01758003], [88.91488647, 22.01804352], [88.91475677, 22.01851082], [88.914711, 22.0190239], [88.91462708, 22.01952171], [88.91448212, 22.01995468], [88.91443634, 22.02039146], [88.91434479, 22.02080917], [88.91423798, 22.02118111], [88.91416168, 22.02157021], [88.9140625, 22.02190018], [88.91391754, 22.02219963], [88.91382599, 22.02253342], [88.91364288, 22.02277184], [88.9134903, 22.02306175], [88.91332245, 22.02340126], [88.91310883, 22.02378464], [88.91290283, 22.02422142], [88.91269684, 22.02467728], [88.91259766, 22.02488136], [88.91248322, 22.02511024], [88.91223907, 22.0255394], [88.91203308, 22.02601051], [88.91179657, 22.02644157], [88.91159821, 22.02691841], [88.91137695, 22.02737999], [88.91114807, 22.02787971], [88.91100311, 22.02843285], [88.91079712, 22.02892113], [88.91055298, 22.02933311], [88.91030121, 22.02972984], [88.91011047, 22.0301609], [88.90985107, 22.03058052], [88.90962219, 22.0310154], [88.90937805, 22.03145027], [88.90916443, 22.03187561], [88.90894318, 22.0322628], [88.90872955, 22.03268242], [88.90856934, 22.03318977], [88.90833282, 22.03372192], [88.90805817, 22.03426933], [88.90782928, 22.03480339], [88.90782166, 22.03533363], [88.90785217, 22.03585243], [88.90804291, 22.03638268], [88.90824127, 22.03686714], [88.90843964, 22.03734589], [88.908638, 22.03778267], [88.90888977, 22.03817177], [88.9091568, 22.03853989], [88.90939331, 22.03892326], [88.90959167, 22.03931236], [88.90979004, 22.03967285], [88.90999603, 22.03997993], [88.91021729, 22.04026222], [88.91033936, 22.04058838], [88.9105072, 22.04092216], [88.91059875, 22.04138184], [88.9107666, 22.04182243], [88.91086578, 22.04233932], [88.91098022, 22.04284286], [88.91105652, 22.04334068], [88.91110992, 22.04382515], [88.91108704, 22.04432106], [88.91101837, 22.04481888], [88.91088104, 22.04525948], [88.91082764, 22.04571915], [88.91073608, 22.04618263], [88.91059875, 22.04665375], [88.91055298, 22.04720116], [88.91046906, 22.04776955], [88.91031647, 22.04833412], [88.91024017, 22.04893684], [88.91011047, 22.04948997], [88.91001892, 22.05000114], [88.90995026, 22.05045319], [88.9098587, 22.05082893], [88.90975189, 22.05115318], [88.90970612, 22.05148888], [88.90962219, 22.05180168], [88.90953064, 22.0520916], [88.90944672, 22.05233192], [88.90933228, 22.0526104], [88.9091568, 22.05290031], [88.90894318, 22.05327797], [88.90883636, 22.05380058], [88.90866089, 22.05427551], [88.90859985, 22.05472183], [88.90851593, 22.05506897], [88.90837097, 22.05529976], [88.90830994, 22.05561256], [88.90820313, 22.05595016], [88.90802002, 22.05635262], [88.90777588, 22.05681419], [88.90750885, 22.05733299], [88.90721893, 22.05785561], [88.90699768, 22.05822372], [88.90693665, 22.05833244], [88.90638733, 22.05888939], [88.90638733, 22.05944443], [88.90472412, 22.06111336], [88.90467834, 22.06117439], [88.9043808, 22.06158447], [88.90394592, 22.06195259], [88.90383911, 22.06204605], [88.90348816, 22.06235695], [88.90303802, 22.06279564], [88.90258789, 22.06320763], [88.90208435, 22.06350136], [88.90170288, 22.06386566], [88.90148163, 22.064291], [88.90139771, 22.06478882], [88.90143585, 22.06528282], [88.90170288, 22.06565475], [88.90203094, 22.06594276], [88.90231323, 22.06627083], [88.9025116, 22.0666523], [88.90278625, 22.06696129], [88.90306091, 22.06723976], [88.9033432, 22.0675106], [88.90359497, 22.06782532], [88.90379333, 22.06823158], [88.90396881, 22.06866264], [88.90425873, 22.06901741], [88.90448761, 22.06947136], [88.90471649, 22.06986237], [88.90490723, 22.07019615], [88.90502167, 22.07051277], [88.90517426, 22.07075119], [88.90528107, 22.07100105], [88.90541077, 22.07125473], [88.90556335, 22.07156181], [88.90572357, 22.07185555], [88.90585327, 22.07217979], [88.90596771, 22.0724926], [88.90607452, 22.07275963], [88.90614319, 22.07302284], [88.90628052, 22.07323647], [88.9063797, 22.0734539], [88.90640259, 22.07368279], [88.90640259, 22.0739212], [88.90644073, 22.07422066], [88.90657043, 22.07460785], [88.90672302, 22.07510948], [88.90696716, 22.07556915], [88.9072876, 22.07595253], [88.90750885, 22.07640266], [88.90770721, 22.07686043], [88.90789032, 22.07734108], [88.90804291, 22.07774162], [88.90808105, 22.07784081], [88.90836334, 22.07832146], [88.90876007, 22.07875633], [88.90924072, 22.07920265], [88.90985107, 22.07957649], [88.91043854, 22.07999229], [88.91101837, 22.08038139], [88.91159821, 22.08073616], [88.91217041, 22.08094978], [88.91277313, 22.08118248], [88.91333008, 22.08139992], [88.91384888, 22.08166695], [88.91439056, 22.08194351], [88.9149704, 22.08219528], [88.91558838, 22.08238029], [88.91607666, 22.08264732], [88.91649628, 22.08298111], [88.91694641, 22.08324623], [88.91738129, 22.08350182], [88.91778564, 22.08384895], [88.91824341, 22.08410645], [88.91867828, 22.0844326], [88.91910553, 22.08474159], [88.919487, 22.08504486], [88.91980743, 22.08535194], [88.92019653, 22.08560181], [88.92053223, 22.08587074], [88.92082977, 22.0861721], [88.92114258, 22.08649254], [88.92144775, 22.0868206], [88.92182922, 22.08708954], [88.92220306, 22.08736992], [88.9225235, 22.08774757], [88.92285156, 22.08812141], [88.92320251, 22.08847237], [88.92354584, 22.08882141], [88.92388916, 22.08916283], [88.92421722, 22.08950233], [88.92455292, 22.0898304], [88.92487335, 22.09015083], [88.92518616, 22.09047127], [88.92553711, 22.09081078], [88.92588806, 22.0911808], [88.92623901, 22.09163094], [88.92668915, 22.09207344], [88.92680359, 22.09217453], [88.92722321, 22.09254265], [88.92772675, 22.09307289], [88.92813873, 22.09379005], [88.92861176, 22.09444237], [88.92906952, 22.09505272], [88.92942047, 22.09566307], [88.92972565, 22.09620857], [88.93000031, 22.09666443], [88.93025208, 22.09705162], [88.93044281, 22.09743309], [88.93057251, 22.09777451], [88.93071747, 22.09810066], [88.93083191, 22.09851265], [88.93093872, 22.09898758], [88.93109131, 22.09952545], [88.93121338, 22.10010338], [88.93134308, 22.10062408], [88.93138123, 22.10111046], [88.93135071, 22.10159111], [88.93122864, 22.10207176], [88.93125916, 22.10262871], [88.93118286, 22.10330391], [88.93126678, 22.10394096], [88.93136597, 22.10444069], [88.93136597, 22.10487938], [88.93125916, 22.10531044], [88.93113708, 22.10578918], [88.93105316, 22.10633278], [88.93094635, 22.10688019], [88.93084717, 22.10741806], [88.93078613, 22.10793495], [88.93060303, 22.10835075], [88.93051147, 22.10880089], [88.93032074, 22.10919762], [88.93022919, 22.10964012], [88.93002319, 22.1099968], [88.92986298, 22.11041069], [88.92967987, 22.11091042], [88.92952728, 22.11153221], [88.92928314, 22.11204529], [88.92903137, 22.112463], [88.9287262, 22.1128521], [88.9285202, 22.11329079], [88.92832947, 22.11366081], [88.92813873, 22.1139698], [88.92800903, 22.11432076], [88.9278183, 22.11465263], [88.9276886, 22.11508942], [88.92747498, 22.1155014], [88.92722321, 22.11591148], [88.92691803, 22.11634254], [88.9265976, 22.11675072], [88.92626953, 22.11718369], [88.92591858, 22.11758232], [88.92565155, 22.11803246], [88.92530823, 22.11845207], [88.92500305, 22.11892128], [88.92472076, 22.11942101], [88.92444611, 22.11988449], [88.92419434, 22.12029076], [88.92403412, 22.12068939], [88.92385864, 22.12099266], [88.92363739, 22.12125969], [88.92345428, 22.12156677], [88.92328644, 22.12187386], [88.92311096, 22.12219429], [88.92308807, 22.12257957], [88.92324829, 22.12294197], [88.92357635, 22.12319183], [88.92399597, 22.12317657], [88.92420959, 22.12317085], [88.92490387, 22.12296867], [88.92549133, 22.12275124], [88.9260025, 22.12256622], [88.92656708, 22.12244987], [88.92720032, 22.1223011], [88.92793274, 22.12225151], [88.92871094, 22.12226295], [88.92949677, 22.12233734], [88.93022919, 22.12250137], [88.93093872, 22.12264442], [88.93196106, 22.12347221], [88.93289185, 22.12428093], [88.93454742, 22.12502098], [88.93582153, 22.12503815], [88.93623352, 22.1251297], [88.93663025, 22.12523079], [88.93707275, 22.12535286], [88.93750763, 22.12549019], [88.93801117, 22.12558937], [88.93850708, 22.12572289], [88.9389801, 22.12587547], [88.93940735, 22.12610054], [88.93978119, 22.12641907], [88.94008636, 22.12682152], [88.94026947, 22.12737083], [88.94034576, 22.12797737], [88.94020844, 22.12857246], [88.93990326, 22.12911987], [88.93943024, 22.12956238], [88.93891144, 22.12994957], [88.93837738, 22.13029671], [88.93791962, 22.13067436], [88.93753052, 22.13105774], [88.93717194, 22.13142967], [88.93678284, 22.13175011], [88.93634796, 22.1319809], [88.93591309, 22.13223267], [88.9355011, 22.13250542], [88.93509674, 22.13279343], [88.9347229, 22.13309288], [88.9343338, 22.1334095], [88.93392181, 22.13372231], [88.93353271, 22.13406181], [88.93312836, 22.13438225], [88.93274689, 22.1347084], [88.93235016, 22.13500023], [88.93196106, 22.13529587], [88.93162537, 22.13563156], [88.93060303, 22.13697815], [88.93044281, 22.13778305], [88.93060303, 22.13784981], [88.93087006, 22.13820076], [88.93144989, 22.13865662], [88.93165588, 22.13872147], [88.9319458, 22.1388607], [88.93238068, 22.1389904], [88.93353271, 22.13932991], [88.93395996, 22.13953209], [88.93439484, 22.13972855], [88.93496704, 22.14006233], [88.93540192, 22.14033127], [88.93567657, 22.14053154], [88.93589783, 22.14080048], [88.93626404, 22.14113808], [88.93640137, 22.14147377], [88.93647766, 22.14187431], [88.93654633, 22.14214134], [88.93654633, 22.14241219], [88.93647766, 22.14281273], [88.93618774, 22.14281273], [88.93604279, 22.14261055], [88.93596649, 22.14241219], [88.93582916, 22.14221001], [88.93547058, 22.14184189], [88.9349823, 22.14144516], [88.93479156, 22.14122963], [88.93430328, 22.14084053], [88.93376923, 22.14050102], [88.93320465, 22.14019966], [88.93260956, 22.13990974], [88.93206024, 22.13968086], [88.93154144, 22.1395092], [88.9310379, 22.13929367], [88.93052673, 22.13895988], [88.93013, 22.13852119], [88.92984009, 22.13803291], [88.92962646, 22.13749123], [88.92948151, 22.13691139], [88.92941284, 22.13637161], [88.92957306, 22.13591385], [88.92979431, 22.13554382], [88.93013, 22.135252], [88.93051147, 22.13496208], [88.93087769, 22.1346302], [88.93122864, 22.13427353], [88.93157959, 22.13394356], [88.93193817, 22.13365364], [88.93231964, 22.13340569], [88.93268585, 22.13318062], [88.9330368, 22.13290977], [88.93338013, 22.13261986], [88.93376923, 22.13234138], [88.93418884, 22.13204002], [88.93464661, 22.13171196], [88.93515015, 22.13136101], [88.93564606, 22.13092995], [88.93616486, 22.1305275], [88.93665314, 22.13017273], [88.93708801, 22.12985611], [88.93747711, 22.12957191], [88.93782043, 22.12928391], [88.9381485, 22.1289959], [88.9384613, 22.1287117], [88.93869781, 22.12838173], [88.93887329, 22.12804222], [88.93891907, 22.12770271], [88.93887329, 22.12738228], [88.93865967, 22.12711716], [88.93831635, 22.12689018], [88.93786621, 22.12669945], [88.9373703, 22.12656021], [88.93685913, 22.12643051], [88.93631744, 22.12637329], [88.93573761, 22.12632751], [88.93514252, 22.12620926], [88.93457794, 22.12605095], [88.93403625, 22.12586975], [88.93348694, 22.12571144], [88.93297577, 22.12551308], [88.93247986, 22.12529564], [88.93198395, 22.12508774], [88.9315033, 22.12485123], [88.93105316, 22.12463188], [88.9306488, 22.12439156], [88.93028259, 22.12415123], [88.9299469, 22.12393951], [88.92962646, 22.12379265], [88.92932129, 22.12366295], [88.92896271, 22.12362099], [88.9285202, 22.12363625], [88.92806244, 22.12369347], [88.9276123, 22.12364388], [88.92719269, 22.12364006], [88.92679596, 22.12373161], [88.92639923, 22.1238308], [88.92592621, 22.12389946], [88.92537689, 22.12400246], [88.92469788, 22.12406731], [88.92388916, 22.12410164], [88.92352295, 22.1243515], [88.92314148, 22.12461281], [88.92267609, 22.1248188], [88.92206573, 22.1249752], [88.92140198, 22.12504387], [88.92076111, 22.1252346], [88.92015076, 22.12543297], [88.9196167, 22.12571144], [88.91911316, 22.12590981], [88.91866302, 22.1261425], [88.91822815, 22.12640953], [88.91781616, 22.12669945], [88.91744232, 22.12701225], [88.91707611, 22.12735176], [88.91670227, 22.12764168], [88.91635132, 22.12795258], [88.91597748, 22.12820816], [88.91562653, 22.12850189], [88.91520691, 22.12870026], [88.91480255, 22.12893295], [88.91441345, 22.12919807], [88.91399384, 22.12945747], [88.91358185, 22.12973213], [88.91316986, 22.13002968], [88.91279602, 22.13039207], [88.91243744, 22.13077927], [88.91204834, 22.13113976], [88.91165924, 22.13153267], [88.91130829, 22.1319046], [88.91092682, 22.13221741], [88.91055298, 22.13251114], [88.91018677, 22.13287163], [88.90981293, 22.1332531], [88.90943909, 22.1336441], [88.90914154, 22.13417053], [88.90883636, 22.13474083], [88.90865326, 22.1353054], [88.90859985, 22.13586807], [88.90860748, 22.13641548], [88.90860748, 22.13694382], [88.90860748, 22.13745308], [88.90862274, 22.13794136], [88.90870667, 22.13840485], [88.90885162, 22.13883781], [88.90888977, 22.13928032], [88.90888977, 22.1397419], [88.90888977, 22.14021111], [88.90892029, 22.14064026], [88.90898132, 22.14100075], [88.90898132, 22.14132881], [88.90891266, 22.14165306], [88.90883636, 22.14202309], [88.90867615, 22.14240074], [88.90857697, 22.14288139], [88.90834808, 22.14338112], [88.90817261, 22.14391136], [88.90805817, 22.14443016], [88.90796661, 22.14491081], [88.90782166, 22.14531326], [88.90777588, 22.14574814], [88.90776825, 22.14621925], [88.90770721, 22.14669991], [88.907547, 22.14711952], [88.90746307, 22.14756012], [88.90724182, 22.14790154], [88.90705109, 22.14822197], [88.90692139, 22.14861107], [88.90672302, 22.14899254], [88.90653992, 22.14947891], [88.90634918, 22.15002441], [88.90611267, 22.15052223], [88.90585327, 22.15098], [88.90563202, 22.15139961], [88.90544128, 22.15177917], [88.90525055, 22.15209007], [88.90500641, 22.15234947], [88.90474701, 22.15263557], [88.90448761, 22.15300751], [88.90419006, 22.15343285], [88.90385437, 22.15391731], [88.90348053, 22.15440941], [88.90306091, 22.15485954], [88.90264893, 22.15526772], [88.90225983, 22.15565109], [88.90190125, 22.15608025], [88.90151978, 22.15654182], [88.90107727, 22.15704346], [88.9005661, 22.15752983], [88.9000473, 22.15802956], [88.89951324, 22.15844154], [88.89910126, 22.15886116], [88.89870453, 22.15917397], [88.89836121, 22.15947151], [88.89804077, 22.15979576], [88.89766693, 22.16011238], [88.89718628, 22.16044044], [88.89665222, 22.16085243], [88.89614105, 22.1612606], [88.89572144, 22.16169167], [88.89537811, 22.16211128], [88.89502716, 22.16242409], [88.89476013, 22.16275215], [88.89460754, 22.16314507], [88.89450836, 22.1635437], [88.89441681, 22.16391182], [88.89427185, 22.16423225], [88.8941803, 22.16460991], [88.89411163, 22.16503716], [88.8939743, 22.16543198], [88.8937912, 22.1657505], [88.89367676, 22.1662426], [88.89344788, 22.16674232], [88.89356995, 22.16724205], [88.89364624, 22.16774178], [88.89380646, 22.16818047], [88.89387512, 22.16863823], [88.89389038, 22.16914177], [88.89393616, 22.16969872], [88.89412689, 22.17028809], [88.89427948, 22.17093277], [88.89466858, 22.17136192], [88.89520264, 22.17161179], [88.89579773, 22.17163467], [88.89636993, 22.17144966], [88.89692688, 22.17126274], [88.89746094, 22.17106247], [88.89795685, 22.17082024], [88.89842224, 22.17055511], [88.89888763, 22.17028236], [88.89935303, 22.16999817], [88.89982605, 22.16974831], [88.90032959, 22.16954041], [88.90087128, 22.16938972], [88.90139008, 22.16916084], [88.9019165, 22.16888809], [88.90246582, 22.16860008], [88.90297699, 22.16827011], [88.90341187, 22.16789055], [88.90382385, 22.167593], [88.90431213, 22.16745949], [88.90471649, 22.16725159], [88.90515137, 22.16707039], [88.90560913, 22.16687202], [88.90604401, 22.16657829], [88.90643311, 22.16620064], [88.90683746, 22.16584969], [88.90725708, 22.16555786], [88.90764618, 22.16526985], [88.90802002, 22.16501999], [88.90833282, 22.16473198], [88.90862274, 22.16445351], [88.90894318, 22.16418266], [88.90929413, 22.16391373], [88.90974426, 22.16366005], [88.91023254, 22.1633625], [88.91070557, 22.16297722], [88.91117096, 22.16257286], [88.91163635, 22.16222954], [88.91210938, 22.16195107], [88.91256714, 22.16171074], [88.91314697, 22.16160011], [88.91368103, 22.16138268], [88.91424561, 22.16115952], [88.91490173, 22.16109276], [88.91555786, 22.1609726], [88.91622162, 22.16085243], [88.91691589, 22.16083336], [88.91759491, 22.16083336], [88.91821289, 22.1608448], [88.91872406, 22.16090584], [88.91916656, 22.16111183], [88.91971588, 22.16111183], [88.91999817, 22.1613903], [88.92028046, 22.1613903], [88.92041779, 22.16152763], [88.92056274, 22.16167068], [88.92111206, 22.16167068], [88.92095947, 22.16192055], [88.92144012, 22.16210747], [88.92175293, 22.16236115], [88.92211151, 22.16254807], [88.9224472, 22.16278458], [88.9227829, 22.1630497], [88.92315674, 22.16333389], [88.92359161, 22.16360283], [88.92402649, 22.16393089], [88.92443085, 22.1643486], [88.9247818, 22.16477013], [88.92502594, 22.16516876], [88.92524719, 22.16548347], [88.92538452, 22.16579628], [88.92552185, 22.16608238], [88.92560577, 22.16645241], [88.92578125, 22.1667614], [88.9259491, 22.16712189], [88.92608643, 22.16756248], [88.92612457, 22.16807365], [88.92611694, 22.16861343], [88.92611694, 22.16916084], [88.92613983, 22.1697216], [88.92623901, 22.17027092], [88.92623901, 22.17080116], [88.92617035, 22.1713829], [88.92621613, 22.17199135], [88.92608643, 22.17252922], [88.92597198, 22.17307281], [88.92584991, 22.17356491], [88.92565155, 22.17394829], [88.92556, 22.17440224], [88.92541504, 22.17478752], [88.92536163, 22.17521286], [88.92555237, 22.17556381], [88.92590332, 22.17584038], [88.92634583, 22.17604446], [88.92688751, 22.1760006], [88.92743683, 22.17583275], [88.92796326, 22.17564392], [88.92844391, 22.17545509], [88.92888641, 22.17526436], [88.92929077, 22.17502785], [88.92970276, 22.17482948], [88.9300766, 22.17464256], [88.93042755, 22.1744709], [88.93077087, 22.17435265], [88.93109894, 22.17420006], [88.93148804, 22.17418289], [88.9318924, 22.17426109], [88.93228912, 22.17441559], [88.93266296, 22.17451286], [88.93297577, 22.17469788], [88.93332672, 22.17486191], [88.93369293, 22.17510033], [88.934021, 22.17542076], [88.93432617, 22.17578316], [88.93467712, 22.17609215], [88.93495941, 22.17645836], [88.93521118, 22.17686462], [88.93550873, 22.17725754], [88.93580627, 22.17772102], [88.93605804, 22.17827034], [88.93636322, 22.17884254], [88.93678284, 22.17936707], [88.93730164, 22.17980003], [88.93776703, 22.18020058], [88.93835449, 22.18033028], [88.93882751, 22.1804924], [88.93920135, 22.18062019], [88.9394989, 22.18078995], [88.93982697, 22.18083], [88.94016266, 22.18087006], [88.94049072, 22.1810112], [88.94087219, 22.18105125], [88.94127655, 22.1810894], [88.94169617, 22.18111229], [88.94213867, 22.18111229], [88.94255829, 22.18111992], [88.94297791, 22.1811924], [88.943367, 22.18135071], [88.9438324, 22.18141365], [88.94429779, 22.18158722], [88.94474792, 22.18195152], [88.94525146, 22.18235779], [88.94573212, 22.18285179], [88.94612885, 22.18346977], [88.94648743, 22.18410301], [88.94664001, 22.18476486], [88.94661713, 22.18538094], [88.94641876, 22.18589973], [88.94618225, 22.18637276], [88.94583893, 22.18676949], [88.94547272, 22.18717003], [88.94499969, 22.18753242], [88.94460297, 22.18798256], [88.94411469, 22.18833733], [88.94364929, 22.18866348], [88.9432373, 22.18898201], [88.94288635, 22.18932915], [88.94255829, 22.18967247], [88.94236755, 22.19001389], [88.94264221, 22.19028473], [88.94309998, 22.19049835], [88.94371796, 22.19054985], [88.94436646, 22.19056129], [88.94496155, 22.1905117], [88.94542694, 22.19033241], [88.94589233, 22.19020271], [88.94631195, 22.19006538], [88.94674683, 22.18996811], [88.94713593, 22.1898098], [88.94756317, 22.18972969], [88.94797516, 22.18969154], [88.94837189, 22.18955994], [88.94882202, 22.18943024], [88.94934845, 22.18928528], [88.94996643, 22.18919182]]], [[[88.83602905, 22.07283211], [88.83613586, 22.07286453], [88.83625031, 22.07290077], [88.8364563, 22.07290077], [88.83683014, 22.07270241], [88.83718109, 22.07250023], [88.83738708, 22.07230186], [88.837677, 22.07203102], [88.83789825, 22.07176018], [88.83825684, 22.07169151], [88.83940887, 22.07155991], [88.84012604, 22.07156181], [88.84101105, 22.07153893], [88.8414917, 22.07167244], [88.84191895, 22.07185936], [88.8423996, 22.07201385], [88.84285736, 22.07224083], [88.84333801, 22.07250023], [88.84384918, 22.07277489], [88.84438324, 22.07304955], [88.84493256, 22.07332802], [88.84551239, 22.07362175], [88.84603119, 22.07401085], [88.84648895, 22.07444191], [88.84692383, 22.0748558], [88.84733582, 22.0752182], [88.84777832, 22.07553482], [88.84823608, 22.07579041], [88.84860992, 22.07615089], [88.84893036, 22.07658768], [88.84928131, 22.07699585], [88.84970856, 22.07730293], [88.85017395, 22.07756805], [88.8506012, 22.07782173], [88.85101318, 22.07805061], [88.85147095, 22.0782795], [88.85197449, 22.07842064], [88.85246277, 22.0785923], [88.85292053, 22.07875252], [88.8533783, 22.07887077], [88.85385895, 22.07897186], [88.85435486, 22.07904625], [88.85487366, 22.07897758], [88.85536194, 22.07888222], [88.85585022, 22.07880211], [88.85634613, 22.07891655], [88.85683441, 22.07907867], [88.85736084, 22.07914162], [88.85785675, 22.07916069], [88.85836029, 22.07916069], [88.8588562, 22.07913017], [88.85933685, 22.07904053], [88.85980225, 22.07886314], [88.86035156, 22.078722], [88.86094666, 22.07873535], [88.86149597, 22.07892036], [88.86192322, 22.07914162], [88.86228943, 22.07931709], [88.86267853, 22.07942009], [88.86309814, 22.07949257], [88.86353302, 22.07962227], [88.86399078, 22.0797081], [88.86450195, 22.07980347], [88.86508179, 22.07999229], [88.86573029, 22.08021545], [88.8663559, 22.08052254], [88.86701965, 22.08088112], [88.86769867, 22.0812664], [88.86847687, 22.08150673], [88.86915588, 22.08136559], [88.86964417, 22.08102608], [88.86997986, 22.08057213], [88.8702774, 22.08008385], [88.87050629, 22.07955551], [88.87055969, 22.07893944], [88.87055206, 22.07830238], [88.87049866, 22.0777092], [88.87032318, 22.07722282], [88.87023926, 22.07667923], [88.87003326, 22.07618141], [88.86992645, 22.07566071], [88.86975861, 22.07516289], [88.86969757, 22.07458878], [88.86956024, 22.0739994], [88.86942291, 22.07341194], [88.86920166, 22.07286263], [88.8690567, 22.07226181], [88.86886597, 22.07168007], [88.86863708, 22.0711422], [88.86849213, 22.07059288], [88.8683548, 22.0701046], [88.86833191, 22.06965065], [88.86833191, 22.06926155], [88.86833191, 22.06892967], [88.86833191, 22.06862068], [88.86833191, 22.06831169], [88.86833191, 22.06796074], [88.86837769, 22.06755829], [88.86856842, 22.06715012], [88.86860657, 22.06664085], [88.86865997, 22.06611824], [88.86888885, 22.06568909], [88.86915588, 22.0652523], [88.86940002, 22.06475258], [88.86955261, 22.06422234], [88.86972046, 22.06383705], [88.86988831, 22.06356239], [88.87001038, 22.0633049], [88.87016296, 22.06305122], [88.87037659, 22.06278038], [88.87065887, 22.06253815], [88.87098694, 22.06234169], [88.87137604, 22.06213951], [88.87180328, 22.06192207], [88.87224579, 22.0616684], [88.87272644, 22.06142044], [88.87332153, 22.06126213], [88.87390137, 22.06109047], [88.87445068, 22.06087112], [88.87506104, 22.06075096], [88.87561035, 22.06054115], [88.87612915, 22.06027794], [88.87666321, 22.06002235], [88.87722778, 22.05984306], [88.8777771, 22.05969238], [88.87822723, 22.05943871], [88.87861633, 22.05916023], [88.87896729, 22.05890274], [88.87937164, 22.05870628], [88.87983704, 22.05857277], [88.88031006, 22.05834007], [88.88083649, 22.05814362], [88.88140106, 22.05794907], [88.88197327, 22.05776024], [88.88248444, 22.05749893], [88.88295746, 22.05721283], [88.88339233, 22.05688477], [88.88378143, 22.05650139], [88.88415527, 22.05611038], [88.88447571, 22.05567932], [88.88482666, 22.0553112], [88.88522339, 22.05500031], [88.88560486, 22.05472183], [88.88600159, 22.05443954], [88.88640594, 22.05414009], [88.88680267, 22.05377007], [88.88721466, 22.05342293], [88.88765717, 22.05307961], [88.88815308, 22.05278015], [88.88863373, 22.05247307], [88.88905334, 22.05206108], [88.88943481, 22.05162621], [88.88963318, 22.05137062], [88.88977051, 22.05118942], [88.8901062, 22.05079269], [88.89034271, 22.05032158], [88.89055634, 22.04985809], [88.89073181, 22.04938316], [88.89079285, 22.04886055], [88.89060211, 22.04833031], [88.8903656, 22.04795647], [88.89028931, 22.04783249], [88.88982391, 22.0474987], [88.88935852, 22.04722023], [88.88891602, 22.04699135], [88.8884201, 22.04689217], [88.88796234, 22.04670906], [88.88736725, 22.04662132], [88.88677979, 22.0464325], [88.88613129, 22.04639244], [88.88549042, 22.04636955], [88.88490295, 22.04627037], [88.88434601, 22.04614067], [88.88379669, 22.04611015], [88.88327789, 22.0460701], [88.88278198, 22.04587173], [88.8822403, 22.04581642], [88.88168335, 22.04570961], [88.88106537, 22.04558182], [88.88038635, 22.04555511], [88.87967682, 22.04556084], [88.87898254, 22.04556084], [88.87835693, 22.04551125], [88.87786865, 22.04532242], [88.87740326, 22.04528236], [88.87696838, 22.04528999], [88.87654877, 22.0453968], [88.87637329, 22.04543686], [88.87613678, 22.04548264], [88.87569427, 22.04532433], [88.87521362, 22.04527855], [88.8747406, 22.04527473], [88.87426758, 22.04528236], [88.87380219, 22.04533386], [88.87335968, 22.04547119], [88.87291718, 22.04533958], [88.87245178, 22.04528236], [88.87198639, 22.04527664], [88.871521, 22.04528236], [88.87106323, 22.04528236], [88.8706131, 22.04528236], [88.86875916, 22.04528236], [88.86830139, 22.04528236], [88.86782837, 22.04528236], [88.86737823, 22.04527855], [88.8669281, 22.04528427], [88.86649323, 22.04535103], [88.86606598, 22.04552269], [88.86560822, 22.0455761], [88.86514282, 22.04569054], [88.8646698, 22.04578209], [88.86418915, 22.04568481], [88.86374664, 22.04557228], [88.86332703, 22.04554939], [88.86297607, 22.04557991], [88.86263275, 22.04569817], [88.86225128, 22.04581261], [88.86183167, 22.04583168], [88.86139679, 22.04585075], [88.86100006, 22.04595375], [88.86055756, 22.04611588], [88.86027527, 22.04611588], [88.86000061, 22.04583359], [88.85916901, 22.04583359], [88.8588562, 22.04583168], [88.85845184, 22.04579735], [88.85809326, 22.04562187], [88.85766602, 22.04556465], [88.85722351, 22.04555321], [88.85678101, 22.04551506], [88.85638428, 22.04532242], [88.85588074, 22.04527092], [88.85536957, 22.04520226], [88.8549118, 22.04499245], [88.85445404, 22.04476166], [88.8539505, 22.04462624], [88.85349274, 22.04443359], [88.85305786, 22.04419136], [88.85257721, 22.04398155], [88.85214233, 22.04380035], [88.85173035, 22.04360008], [88.85134125, 22.04335213], [88.85093689, 22.04316139], [88.85060883, 22.04297066], [88.85038757, 22.04270744], [88.85028839, 22.04232979], [88.8502121, 22.04191017], [88.85004425, 22.04148865], [88.85003662, 22.04103279], [88.8502121, 22.04058266], [88.85034943, 22.04006958], [88.85054016, 22.03956032], [88.85072327, 22.03903008], [88.85101318, 22.03857231], [88.85124969, 22.03808022], [88.85152435, 22.03762627], [88.85175323, 22.03714943], [88.85198975, 22.03672981], [88.85225677, 22.03638649], [88.85250092, 22.03607178], [88.85273743, 22.03576088], [88.85293579, 22.0354023], [88.85314178, 22.03494072], [88.85339355, 22.03452873], [88.85375214, 22.03416252], [88.85413361, 22.03380394], [88.85447693, 22.03341484], [88.85484314, 22.03306389], [88.85521698, 22.03273201], [88.85555267, 22.03236198], [88.85584259, 22.03194237], [88.85616302, 22.03150177], [88.85655975, 22.03107262], [88.85694122, 22.03057289], [88.85733032, 22.0300312], [88.85778046, 22.02951622], [88.85822296, 22.02898216], [88.85868073, 22.02837753], [88.85916138, 22.02780151], [88.85958862, 22.02721214], [88.85985565, 22.02662086], [88.85962677, 22.02603912], [88.85923004, 22.02557373], [88.85877991, 22.02518272], [88.85831451, 22.02490044], [88.85782623, 22.02470207], [88.85740662, 22.02444839], [88.85697937, 22.02422142], [88.85647583, 22.02409172], [88.85604095, 22.02388954], [88.85559845, 22.02368927], [88.85513306, 22.023592], [88.85470581, 22.02344513], [88.85428619, 22.0233326], [88.85389709, 22.02320862], [88.85347748, 22.02305031], [88.85301971, 22.02289581], [88.8524704, 22.02278709], [88.85189819, 22.02270317], [88.85134125, 22.02253532], [88.85076904, 22.02250099], [88.85019684, 22.02244949], [88.84970093, 22.02226067], [88.84907532, 22.02221107], [88.84835052, 22.02212715], [88.84754181, 22.02197266], [88.8471756, 22.02194786], [88.84674835, 22.02194023], [88.84616852, 22.02194405], [88.84554291, 22.0219326], [88.84493256, 22.02194023], [88.84436798, 22.02194405], [88.84385681, 22.02195168], [88.84342194, 22.02203178], [88.84307861, 22.02219772], [88.84269714, 22.02230835], [88.84234619, 22.02248955], [88.84194946, 22.02263451], [88.8415451, 22.02279091], [88.84116364, 22.02298164], [88.84070587, 22.02308273], [88.84030914, 22.02326012], [88.83988953, 22.02337074], [88.83946228, 22.02357292], [88.83895874, 22.02368927], [88.83850098, 22.02389908], [88.8380661, 22.02416611], [88.83763123, 22.02444267], [88.83721161, 22.02471924], [88.83679199, 22.02499199], [88.83635712, 22.02522278], [88.83596039, 22.02544975], [88.83565521, 22.02575302], [88.83544159, 22.02612114], [88.83527374, 22.02652931], [88.83512115, 22.02693939], [88.83499146, 22.02737999], [88.83486176, 22.02776909], [88.83473969, 22.0281353], [88.83465576, 22.02849579], [88.83449554, 22.02879143], [88.83440399, 22.02915192], [88.83421326, 22.02948189], [88.83412933, 22.02993965], [88.83408356, 22.03044891], [88.83413696, 22.03102112], [88.83411407, 22.03159714], [88.83392334, 22.03212166], [88.83374023, 22.03264618], [88.83358765, 22.033144], [88.83340454, 22.03357315], [88.83329773, 22.03399086], [88.8331604, 22.03434944], [88.83307648, 22.03465271], [88.83304596, 22.03495216], [88.83302307, 22.0352726], [88.83291626, 22.03555107], [88.83280945, 22.03583908], [88.83277893, 22.03617287], [88.83277893, 22.03655052], [88.83277893, 22.03695869], [88.83277893, 22.03738022], [88.83277893, 22.03781319], [88.83276367, 22.03822899], [88.8327179, 22.03859138], [88.83249664, 22.03889084], [88.83249664, 22.03971863], [88.83222198, 22.04000282], [88.83220673, 22.0400753], [88.83215332, 22.04039955], [88.83200073, 22.04074287], [88.83194733, 22.04116821], [88.83194733, 22.04162025], [88.83193207, 22.04208946], [88.83188629, 22.0425396], [88.83171844, 22.04294014], [88.83167267, 22.0433712], [88.83166504, 22.04379845], [88.83167267, 22.04422569], [88.83171844, 22.04465485], [88.83194733, 22.04504967], [88.83218384, 22.04549789], [88.83210754, 22.04615974], [88.8322525, 22.04679489], [88.8325119, 22.04739952], [88.83278656, 22.04801178], [88.83306122, 22.04861069], [88.83326721, 22.04917908], [88.83341217, 22.04972267], [88.83371735, 22.05008507], [88.83418274, 22.05024147], [88.83470917, 22.05027962], [88.83524323, 22.05027962], [88.83574677, 22.05027962], [88.83625031, 22.05030632], [88.83674622, 22.05040169], [88.83718872, 22.0505867], [88.83761597, 22.0508213], [88.83808136, 22.05113029], [88.83856201, 22.0514431], [88.83899689, 22.0518322], [88.83940125, 22.05225945], [88.83972931, 22.05271149], [88.840065, 22.05312538], [88.84037781, 22.05348206], [88.84072876, 22.05370331], [88.84117126, 22.05373192], [88.84168243, 22.05358315], [88.84221649, 22.05335045], [88.84279633, 22.05314445], [88.84333038, 22.05305672], [88.84361267, 22.05277824], [88.84416962, 22.05277824], [88.84444427, 22.05305672], [88.84456635, 22.05320168], [88.84471893, 22.05333519], [88.84500122, 22.05361176], [88.84500122, 22.05388069], [88.84429169, 22.05400658], [88.84365845, 22.05408859], [88.84306335, 22.05412102], [88.842453, 22.05413246], [88.84191132, 22.05423927], [88.8414917, 22.05449486], [88.84130096, 22.05485153], [88.84129333, 22.05532837], [88.84135437, 22.05579185], [88.84136963, 22.05618286], [88.84145355, 22.05654526], [88.84159851, 22.05695152], [88.84178925, 22.05740166], [88.84203339, 22.05787086], [88.84234619, 22.05829811], [88.84278107, 22.05865288], [88.84320831, 22.05900192], [88.84365082, 22.05930138], [88.84406281, 22.05964088], [88.8444519, 22.05999184], [88.84471893, 22.06028175], [88.84500122, 22.06028175], [88.84527588, 22.0605545], [88.84555054, 22.06083107], [88.84555054, 22.0616703], [88.84513092, 22.06152153], [88.84455872, 22.06126976], [88.84404755, 22.06099129], [88.84353638, 22.06065369], [88.84307098, 22.06019783], [88.84263611, 22.05973816], [88.84217072, 22.05940247], [88.84172058, 22.05913734], [88.841362, 22.05888176], [88.84107971, 22.05862236], [88.84085083, 22.05836105], [88.8406601, 22.05804062], [88.84056091, 22.05758095], [88.84047699, 22.05702019], [88.84044647, 22.05635262], [88.84037018, 22.05570793], [88.84018707, 22.05516243], [88.83991241, 22.05470085], [88.83963776, 22.05424118], [88.83933258, 22.05379295], [88.83898163, 22.05332947], [88.83860779, 22.05286217], [88.83822632, 22.05241203], [88.83782959, 22.05202293], [88.83740997, 22.05177689], [88.83701324, 22.05167961], [88.83661652, 22.05166245], [88.83622742, 22.05166054], [88.83583832, 22.05165291], [88.83541107, 22.05164146], [88.83489227, 22.05167961], [88.83429718, 22.05181313], [88.83374023, 22.05178261], [88.8332901, 22.05169106], [88.832901, 22.05167007], [88.83251953, 22.05168343], [88.83213043, 22.05177307], [88.83170319, 22.05195236], [88.83127594, 22.05219078], [88.83082581, 22.05241203], [88.83037567, 22.05265808], [88.82988739, 22.05293274], [88.82945251, 22.05331993], [88.8290329, 22.0537529], [88.82862091, 22.05415916], [88.82818604, 22.05456924], [88.82770538, 22.05497742], [88.82715607, 22.05537224], [88.82663727, 22.05582428], [88.82608795, 22.05627251], [88.82553101, 22.05672264], [88.82499695, 22.05718994], [88.82444, 22.05758095], [88.82390594, 22.05793953], [88.8234024, 22.05830193], [88.82292175, 22.05870247], [88.82237244, 22.05901146], [88.82182312, 22.05935287], [88.82139587, 22.05983162], [88.82103729, 22.06033134], [88.82069397, 22.0607605], [88.82034302, 22.06110954], [88.82003021, 22.06144333], [88.81980133, 22.06178474], [88.81973267, 22.06221962], [88.81944275, 22.06250191], [88.81944275, 22.06305695], [88.81972504, 22.06333351], [88.81973267, 22.06361198], [88.81999969, 22.06389046], [88.81999969, 22.06417274], [88.82016754, 22.06430626], [88.82030487, 22.06441307], [88.82055664, 22.06467056], [88.82102966, 22.06498718], [88.82147217, 22.06546211], [88.82189178, 22.06595039], [88.82227325, 22.06639671], [88.82276154, 22.06681633], [88.82328033, 22.06733131], [88.82383728, 22.06781197], [88.82437897, 22.06814766], [88.82482147, 22.06845474], [88.82527161, 22.0687809], [88.82578278, 22.06912613], [88.82636261, 22.06942177], [88.82692719, 22.06969833], [88.82748413, 22.06993484], [88.82806396, 22.07004929], [88.82855988, 22.07016563], [88.82898712, 22.07013512], [88.82932281, 22.0700016], [88.82961273, 22.06981087], [88.82984924, 22.06956673], [88.83004761, 22.06925011], [88.83027649, 22.06892204], [88.83056641, 22.06860161], [88.83088684, 22.06828117], [88.83122253, 22.06795311], [88.83156586, 22.06759071], [88.83190155, 22.06720543], [88.83216858, 22.06677055], [88.8323288, 22.06630135], [88.8324585, 22.06585121], [88.83252716, 22.06537056], [88.83263397, 22.06490517], [88.83281708, 22.06450081], [88.83309937, 22.0641613], [88.83346558, 22.06390953], [88.83390045, 22.06377602], [88.8343811, 22.06389046], [88.83483124, 22.06414986], [88.83527374, 22.06446648], [88.83571625, 22.06480598], [88.83615875, 22.06515121], [88.83653259, 22.06542778], [88.83685303, 22.0656414], [88.83708954, 22.06585121], [88.83727264, 22.06612968], [88.8373642, 22.06661034], [88.83743286, 22.06718254], [88.83747101, 22.06775284], [88.83756256, 22.06828117], [88.83750153, 22.06861115], [88.83732605, 22.06974983], [88.83675385, 22.0707531], [88.83631897, 22.07169151], [88.83616638, 22.07209969], [88.83602905, 22.07249641], [88.83602905, 22.07283211]]], [[[88.90408325, 22.08420753], [88.90367126, 22.08382988], [88.90328217, 22.08344078], [88.90287018, 22.08313179], [88.90254211, 22.08282852], [88.90219116, 22.08261299], [88.90180206, 22.08245659], [88.90148163, 22.08221245], [88.90112305, 22.08191109], [88.90076447, 22.08160973], [88.90033722, 22.0813427], [88.8999176, 22.08105469], [88.89943695, 22.08081245], [88.89898682, 22.08052254], [88.89864349, 22.08016777], [88.89834595, 22.0797596], [88.89803314, 22.07941246], [88.89768982, 22.07907867], [88.89735413, 22.07876015], [88.89698029, 22.07849121], [88.89662933, 22.07817268], [88.89624023, 22.07788467], [88.89585876, 22.077528], [88.89547729, 22.07715034], [88.89509583, 22.07676125], [88.8947525, 22.07632256], [88.89444733, 22.07585144], [88.89417267, 22.07542229], [88.89393616, 22.07502937], [88.89377594, 22.07463455], [88.89362335, 22.07429314], [88.89341736, 22.07395363], [88.89325714, 22.07354164], [88.89303589, 22.07310295], [88.89279938, 22.07264328], [88.89263916, 22.07208443], [88.8924942, 22.07150841], [88.89232635, 22.07092476], [88.89222717, 22.07030296], [88.89215851, 22.0696888], [88.89196014, 22.06915092], [88.89179993, 22.06861115], [88.89167023, 22.06806183], [88.89154816, 22.06752586], [88.89141846, 22.06701088], [88.89134979, 22.0664711], [88.89115143, 22.06593132], [88.89111328, 22.06533241], [88.89110565, 22.06470108], [88.89111328, 22.06403923], [88.89113617, 22.06336021], [88.89122009, 22.06269264], [88.89137268, 22.06208229], [88.89135742, 22.06147385], [88.89118195, 22.06089211], [88.89090729, 22.06035614], [88.89034271, 22.06013489], [88.88970947, 22.0602417], [88.88905334, 22.06027031], [88.88842773, 22.06020164], [88.88788605, 22.06002808], [88.88737488, 22.05999947], [88.88690186, 22.05997276], [88.8864975, 22.05983925], [88.88609314, 22.05973816], [88.88566589, 22.05972099], [88.88523865, 22.05972099], [88.8848114, 22.05968285], [88.88439941, 22.05948067], [88.88386536, 22.05944443], [88.88326263, 22.05945015], [88.88297272, 22.05944443], [88.8826828, 22.05947304], [88.88230133, 22.05962181], [88.88182831, 22.05976105], [88.88134003, 22.06001091], [88.88082886, 22.06028175], [88.88027954, 22.0605545], [88.87973022, 22.06083679], [88.87919617, 22.06110954], [88.87866211, 22.06138039], [88.87813568, 22.06157875], [88.87760925, 22.0617218], [88.8771286, 22.06189156], [88.87656403, 22.06198692], [88.87600708, 22.06217957], [88.87536621, 22.06226158], [88.87477112, 22.06245232], [88.87412262, 22.06250191], [88.87346649, 22.0625515], [88.87285614, 22.06276131], [88.87224579, 22.06300163], [88.87168884, 22.0633564], [88.87129211, 22.06385231], [88.87096405, 22.06435776], [88.8707962, 22.06490135], [88.87058258, 22.06535149], [88.87044525, 22.06579781], [88.87030792, 22.06624413], [88.8702774, 22.06676483], [88.8702774, 22.0673275], [88.8702774, 22.06790924], [88.8702774, 22.06851006], [88.87029266, 22.06910133], [88.87037659, 22.06967545], [88.87052917, 22.0702343], [88.87055206, 22.07077217], [88.87056732, 22.07131195], [88.87069702, 22.07182121], [88.87084961, 22.07241631], [88.87110901, 22.07302284], [88.87137604, 22.07362747], [88.87158203, 22.07421112], [88.8717041, 22.0747509], [88.87188721, 22.07514], [88.87194061, 22.07552147], [88.87198639, 22.07585144], [88.87217712, 22.07614708], [88.8722229, 22.07650185], [88.8722229, 22.07690048], [88.8722229, 22.07731247], [88.8722229, 22.07775307], [88.8722229, 22.07818985], [88.8722229, 22.07863045], [88.8722229, 22.07907295], [88.87218475, 22.07946777], [88.87203217, 22.07980347], [88.87195587, 22.08015442], [88.87190247, 22.08051109], [88.87171936, 22.08081245], [88.87158203, 22.08118248], [88.87137604, 22.08152962], [88.87110901, 22.08189964], [88.87083435, 22.08231735], [88.87055206, 22.08274269], [88.8702774, 22.08316231], [88.87000275, 22.08349037], [88.86974335, 22.08377266], [88.86955261, 22.0840683], [88.86942291, 22.08438492], [88.86924744, 22.08468056], [88.86924744, 22.08506966], [88.86940002, 22.08556175], [88.86950684, 22.08614159], [88.86978912, 22.08659172], [88.87020874, 22.08690071], [88.87072754, 22.08699226], [88.87124634, 22.08681297], [88.87174225, 22.08659363], [88.87224579, 22.08641815], [88.8727417, 22.08634377], [88.87321472, 22.08616829], [88.87374115, 22.08611107], [88.87425232, 22.08605003], [88.87468719, 22.0858326], [88.87509155, 22.08559418], [88.87554169, 22.08538628], [88.8759613, 22.08514977], [88.87641144, 22.08490944], [88.87686157, 22.08471107], [88.87726593, 22.08449173], [88.87773132, 22.08440971], [88.8781662, 22.0842495], [88.87870026, 22.08418083], [88.87932587, 22.08416367], [88.88001251, 22.08412361], [88.88070679, 22.08395958], [88.88140106, 22.08394241], [88.88202667, 22.08416367], [88.88260651, 22.08438492], [88.88315582, 22.08450127], [88.88363647, 22.08468056], [88.88417816, 22.08477974], [88.88468933, 22.0849514], [88.88526917, 22.08505058], [88.88580322, 22.08527946], [88.88633728, 22.08556747], [88.88690186, 22.08588028], [88.88747406, 22.08626556], [88.88802338, 22.08670235], [88.88854218, 22.08712959], [88.88907623, 22.08741951], [88.8895874, 22.08764076], [88.89006805, 22.08779716], [88.89050293, 22.08798409], [88.89096832, 22.08810234], [88.89138794, 22.08833122], [88.89186859, 22.08851051], [88.89238739, 22.08859825], [88.89292145, 22.08861351], [88.89343262, 22.08865356], [88.89383698, 22.0888195], [88.89433289, 22.08889198], [88.89483643, 22.08895302], [88.8953476, 22.08913231], [88.89597321, 22.08917046], [88.89659882, 22.08917046], [88.8972168, 22.08915138], [88.89776611, 22.08903313], [88.89830017, 22.08887482], [88.89877319, 22.0886097], [88.89920807, 22.08834267], [88.8996582, 22.08814049], [88.90016937, 22.08802032], [88.90058136, 22.08781624], [88.90104675, 22.08775139], [88.90145874, 22.08757973], [88.90189362, 22.08750534], [88.90232849, 22.08744812], [88.90273285, 22.08727074], [88.90319824, 22.08722115], [88.90368652, 22.08712959], [88.90410614, 22.08691978], [88.90444183, 22.08658218], [88.90467834, 22.08616447], [88.90471649, 22.08565331], [88.90465546, 22.08512115], [88.90441895, 22.08463478], [88.90408325, 22.08420753]]], [[[88.7758255, 22.09358978], [88.77599335, 22.09390068], [88.77613068, 22.09423256], [88.77629852, 22.09452438], [88.77638245, 22.09484291], [88.77645874, 22.09517097], [88.77661133, 22.09546852], [88.7766571, 22.09584999], [88.77671051, 22.09626961], [88.77688599, 22.09668159], [88.77694702, 22.0971508], [88.77697754, 22.09763527], [88.77710724, 22.09808159], [88.77720642, 22.09854317], [88.77723694, 22.09901237], [88.77738953, 22.09948158], [88.7775116, 22.09997749], [88.7776947, 22.1004734], [88.7779007, 22.10097313], [88.77807617, 22.10153008], [88.77833557, 22.1020565], [88.77863312, 22.10256004], [88.77899933, 22.10300255], [88.77945709, 22.10334587], [88.77990723, 22.10367012], [88.78031158, 22.10404015], [88.78072357, 22.10433388], [88.78111267, 22.10459137], [88.7815094, 22.10483742], [88.78189087, 22.10508156], [88.7822113, 22.10538483], [88.78248596, 22.1057148], [88.7827301, 22.10606384], [88.78299713, 22.10638237], [88.78333282, 22.10667038], [88.78375244, 22.10694313], [88.78427124, 22.10717392], [88.78492737, 22.10727119], [88.78556061, 22.10746193], [88.78620148, 22.10749817], [88.78678894, 22.10750008], [88.78730774, 22.10753059], [88.78781128, 22.10767174], [88.78829956, 22.10777092], [88.7888031, 22.10778046], [88.78929138, 22.10778046], [88.78975677, 22.10778046], [88.79022217, 22.10779762], [88.79065704, 22.10789299], [88.79109192, 22.10803795], [88.7915802, 22.1081295], [88.79203796, 22.10831261], [88.79254913, 22.1084137], [88.79304504, 22.10857773], [88.79357147, 22.10863495], [88.79406738, 22.10878944], [88.79457092, 22.10889435], [88.79509735, 22.10900307], [88.79567719, 22.1091404], [88.79627991, 22.10917282], [88.79689026, 22.10913277], [88.79746246, 22.10894012], [88.79802704, 22.10889435], [88.79853058, 22.10872841], [88.79889679, 22.1083622], [88.79927826, 22.10794258], [88.79959106, 22.10744476], [88.79978943, 22.10688019], [88.79999542, 22.10639191], [88.8001709, 22.10592461], [88.80026245, 22.10545349], [88.80032349, 22.10497856], [88.8004303, 22.10453987], [88.80033875, 22.10404015], [88.80029297, 22.10352135], [88.80020142, 22.10300064], [88.79994202, 22.10255241], [88.79960632, 22.1021347], [88.79924011, 22.10172081], [88.79891205, 22.10131264], [88.79865265, 22.10090065], [88.79849243, 22.10045242], [88.79836273, 22.09997177], [88.79829407, 22.09949684], [88.79818726, 22.0990696], [88.79827881, 22.09867477], [88.79833984, 22.09834099], [88.79844666, 22.09808159], [88.79862976, 22.09784126], [88.79888153, 22.09756279], [88.79917145, 22.09719849], [88.79951477, 22.09683609], [88.79995728, 22.09655952], [88.8004303, 22.09623146], [88.80084991, 22.09585762], [88.80127716, 22.09547234], [88.80164337, 22.09502983], [88.80190277, 22.09455299], [88.80207825, 22.09404945], [88.80226135, 22.09359169], [88.80243683, 22.09313011], [88.80246735, 22.09261131], [88.80241394, 22.09209251], [88.80225372, 22.09161186], [88.80210876, 22.0911541], [88.80194092, 22.09073257], [88.80175781, 22.09033585], [88.80163574, 22.08990479], [88.80148315, 22.0895195], [88.80142212, 22.08915138], [88.80149841, 22.08880043], [88.80166626, 22.08846092], [88.80187225, 22.08810234], [88.80204773, 22.08768272], [88.80223846, 22.08726692], [88.80246735, 22.08687019], [88.80267334, 22.08644485], [88.80294037, 22.08606148], [88.8032074, 22.08567619], [88.8034668, 22.08527374], [88.80375671, 22.08487129], [88.80408478, 22.08452415], [88.8044281, 22.08419609], [88.80477905, 22.08392143], [88.80517578, 22.08369255], [88.80552673, 22.08342171], [88.80584717, 22.08311272], [88.80619812, 22.08279991], [88.8065567, 22.08250999], [88.80696106, 22.08228493], [88.80745697, 22.08218956], [88.80796814, 22.08204079], [88.80847168, 22.08192635], [88.80892181, 22.08179283], [88.80937958, 22.08168983], [88.80988312, 22.08160973], [88.81036377, 22.08143425], [88.81084442, 22.08133888], [88.81118774, 22.08120155], [88.81151581, 22.0811348], [88.81186676, 22.08110237], [88.81224823, 22.08104515], [88.81266785, 22.08089256], [88.81315613, 22.08083916], [88.81363678, 22.08080101], [88.81411743, 22.08070946], [88.81458282, 22.0805912], [88.8150177, 22.08058357], [88.8154068, 22.08070946], [88.8157959, 22.08091354], [88.81619263, 22.08116913], [88.81659698, 22.08144188], [88.81703186, 22.08173561], [88.81746674, 22.08197975], [88.81789398, 22.08223724], [88.81832123, 22.08250237], [88.81874084, 22.08278084], [88.81916809, 22.08301544], [88.81961823, 22.08313942], [88.81996918, 22.08330917], [88.82026672, 22.08344078], [88.82054901, 22.08363152], [88.82085419, 22.08388138], [88.82126617, 22.08414268], [88.82174683, 22.08436012], [88.82227325, 22.08450127], [88.82276154, 22.08467102], [88.82328796, 22.0847702], [88.82376862, 22.0849514], [88.82428741, 22.08506393], [88.82471466, 22.08527756], [88.82511902, 22.08554459], [88.82553864, 22.08582115], [88.82598877, 22.08610344], [88.82652283, 22.0863266], [88.82715607, 22.08631325], [88.82778168, 22.08603477], [88.82826996, 22.08564568], [88.82879639, 22.08527946], [88.8292923, 22.08490944], [88.82969666, 22.08445168], [88.83006287, 22.08395958], [88.83040619, 22.08350563], [88.8307724, 22.08311272], [88.83109283, 22.08271217], [88.83131409, 22.08230591], [88.83145142, 22.08184814], [88.83164215, 22.08138084], [88.83178711, 22.0808506], [88.8319931, 22.0802803], [88.83222198, 22.07975769], [88.8324585, 22.07927132], [88.83261871, 22.07880211], [88.83277893, 22.07842064], [88.83293152, 22.07805061], [88.83309174, 22.07764244], [88.83329773, 22.07721138], [88.83345032, 22.07671738], [88.83361053, 22.07624245], [88.83379364, 22.07582664], [88.83395386, 22.07546806], [88.83415985, 22.07521248], [88.83435822, 22.07497978], [88.83454132, 22.07473755], [88.83473969, 22.0744915], [88.83492279, 22.07420158], [88.83496857, 22.0737896], [88.83495331, 22.07333183], [88.83486938, 22.07287979], [88.83492279, 22.07245064], [88.83518982, 22.07211113], [88.83545685, 22.07172966], [88.83570099, 22.07124138], [88.83589935, 22.07074165], [88.83610535, 22.07030869], [88.83629608, 22.06989098], [88.83641815, 22.06941986], [88.83654022, 22.06887245], [88.83661652, 22.06826973], [88.83662415, 22.06761169], [88.8365097, 22.06693077], [88.83621216, 22.06633949], [88.83574677, 22.06588173], [88.83521271, 22.06550789], [88.8347168, 22.06517982], [88.8343277, 22.06496239], [88.83400726, 22.06492043], [88.83377838, 22.06507301], [88.83358002, 22.06532097], [88.83345032, 22.06565666], [88.83336639, 22.06598282], [88.83330536, 22.06634712], [88.83322906, 22.06671333], [88.83309174, 22.06706047], [88.83296204, 22.06746101], [88.83270264, 22.06786156], [88.83229065, 22.06831169], [88.83184052, 22.06876183], [88.83142853, 22.06929016], [88.83110809, 22.06984138], [88.83082581, 22.07036018], [88.83052826, 22.07082367], [88.8301239, 22.07118034], [88.82949829, 22.07137489], [88.82920837, 22.07142448], [88.82876587, 22.07150078], [88.82807922, 22.07141304], [88.82744598, 22.07128906], [88.82697296, 22.07109261], [88.82656097, 22.07085228], [88.8261795, 22.0706501], [88.82581329, 22.07056427], [88.82552338, 22.07065964], [88.82499695, 22.0700016], [88.82472229, 22.0700016], [88.82444, 22.06972122], [88.8236084, 22.06972122], [88.8236084, 22.06944466], [88.82389069, 22.06916618], [88.8236084, 22.06889153], [88.8236084, 22.06861115], [88.82319641, 22.06839943], [88.82281494, 22.06812859], [88.82237244, 22.06788063], [88.82196045, 22.06754112], [88.82154083, 22.06711006], [88.82102966, 22.06665611], [88.82047272, 22.06617165], [88.81990051, 22.06568909], [88.81941986, 22.06514168], [88.81912231, 22.06446266], [88.81877899, 22.06382942], [88.81830597, 22.06336212], [88.81768799, 22.06308937], [88.81698608, 22.06297112], [88.81629944, 22.06297112], [88.81565094, 22.06284142], [88.81508636, 22.06261253], [88.81456757, 22.06246185], [88.81417084, 22.06226158], [88.81377411, 22.06215858], [88.81344604, 22.06200981], [88.81307983, 22.06195259], [88.81269836, 22.06195259], [88.81233215, 22.06202126], [88.81201935, 22.06215096], [88.81167603, 22.06221199], [88.81139374, 22.0622673], [88.81118774, 22.0624218], [88.81105804, 22.06265068], [88.81092834, 22.06289101], [88.81098175, 22.06316376], [88.81138611, 22.06361198], [88.81111145, 22.06389046], [88.81083679, 22.06389046], [88.81054688, 22.06361198], [88.81046295, 22.06357384], [88.81007385, 22.06339073], [88.80966187, 22.0634346], [88.80931091, 22.06368065], [88.80896759, 22.06406212], [88.80851746, 22.06441879], [88.80800629, 22.06476021], [88.80748749, 22.06508827], [88.8069458, 22.0653553], [88.80638885, 22.06557274], [88.80582428, 22.06576347], [88.8056488, 22.06575584], [88.80521393, 22.06573677], [88.80459595, 22.06557274], [88.80400085, 22.06537056], [88.8034668, 22.06509209], [88.80313873, 22.06470108], [88.80285645, 22.06427383], [88.80252075, 22.06391144], [88.80218506, 22.06352615], [88.80193329, 22.06298828], [88.80171967, 22.06240463], [88.80162811, 22.06178284], [88.80149841, 22.06123161], [88.80136108, 22.06077003], [88.80119324, 22.06043053], [88.80110168, 22.06007195], [88.80099487, 22.05973625], [88.80084991, 22.05939293], [88.8007431, 22.05900192], [88.80049896, 22.05862808], [88.80018616, 22.05825996], [88.79977417, 22.05792046], [88.7993927, 22.05751991], [88.79898071, 22.0571804], [88.79859161, 22.0568409], [88.798172, 22.05653954], [88.79769897, 22.05635071], [88.79727173, 22.05616951], [88.79679871, 22.05611801], [88.79631805, 22.05610275], [88.79582214, 22.05604935], [88.79532623, 22.05587959], [88.79473877, 22.0557785], [88.79415131, 22.05566216], [88.79354858, 22.05578423], [88.79296875, 22.0558815], [88.79252625, 22.05610275], [88.79218292, 22.05641556], [88.79190826, 22.0567894], [88.79160309, 22.05721283], [88.79125977, 22.05764008], [88.79097748, 22.05810165], [88.79084015, 22.05859947], [88.79076385, 22.05903435], [88.79059601, 22.05936241], [88.79051971, 22.0596981], [88.79033661, 22.05995941], [88.79017639, 22.06028175], [88.7899704, 22.06064224], [88.78971863, 22.06083107], [88.78888702, 22.0616703], [88.78864288, 22.06166267], [88.78837585, 22.06169891], [88.78806305, 22.06189156], [88.78765106, 22.06208038], [88.78742981, 22.06260109], [88.7875061, 22.06329536], [88.78767395, 22.06399536], [88.78783417, 22.06469345], [88.78808594, 22.06531143], [88.78839111, 22.06594276], [88.78865814, 22.06664085], [88.78865814, 22.0673027], [88.78868866, 22.06790924], [88.78864288, 22.06850243], [88.78859711, 22.06912041], [88.78853607, 22.06977272], [88.78845215, 22.07040024], [88.78833008, 22.07083321], [88.78833008, 22.07111168], [88.78806305, 22.07139015], [88.78778076, 22.07139015], [88.78749847, 22.07167244], [88.78749847, 22.07194328], [88.78739166, 22.07205009], [88.78721619, 22.07222176], [88.78666687, 22.07166862], [88.78666687, 22.07139015], [88.78694153, 22.07111168], [88.78697205, 22.07098579], [88.78726959, 22.07045174], [88.78739166, 22.06986046], [88.78730774, 22.06923294], [88.78730774, 22.06858253], [88.78730774, 22.06790924], [88.78743744, 22.0672226], [88.78741455, 22.06658554], [88.78726196, 22.0660305], [88.78714752, 22.06551933], [88.78697968, 22.06509209], [88.78687286, 22.06467056], [88.78672028, 22.06430054], [88.78662109, 22.06388283], [88.78646851, 22.06347084], [88.78637695, 22.06289101], [88.78633118, 22.06226158], [88.78613281, 22.06184387], [88.78594208, 22.06150246], [88.7857666, 22.06118202], [88.78556824, 22.06088066], [88.78538513, 22.06049156], [88.7852478, 22.05999947], [88.78499603, 22.0595417], [88.78479767, 22.05907249], [88.784729, 22.05857277], [88.78470612, 22.05810165], [88.7845993, 22.05766487], [88.7844696, 22.05722237], [88.78444672, 22.05672646], [88.7844162, 22.05621147], [88.78431702, 22.05570793], [88.78418732, 22.0551815], [88.78412628, 22.05461311], [88.78397369, 22.05408669], [88.78388214, 22.05351067], [88.78375244, 22.05291939], [88.78360748, 22.05233955], [88.78343964, 22.05175972], [88.78333282, 22.05115318], [88.78320313, 22.05058289], [88.78305817, 22.05005074], [88.78289795, 22.04957008], [88.78269196, 22.04917908], [88.7824173, 22.04882813], [88.78196716, 22.04860115], [88.78150177, 22.04839134], [88.78124237, 22.04836273], [88.78102112, 22.04843521], [88.78076935, 22.04861832], [88.78048706, 22.04887962], [88.78016663, 22.04916954], [88.77980804, 22.04947853], [88.77945709, 22.04985237], [88.77916718, 22.05028915], [88.77883911, 22.05072975], [88.77845764, 22.05110168], [88.77805328, 22.05142021], [88.77761078, 22.05169106], [88.7771759, 22.05198097], [88.77675629, 22.05227852], [88.77636719, 22.05262375], [88.77594757, 22.05291939], [88.77554321, 22.05316544], [88.77527618, 22.05333519], [88.77500153, 22.05333519], [88.77471924, 22.05361366], [88.77416992, 22.05361366], [88.77388763, 22.05388832], [88.77361298, 22.05388069], [88.77333069, 22.05417061], [88.77305603, 22.05417061], [88.77295685, 22.05428123], [88.77265167, 22.05441093], [88.77249908, 22.0544529], [88.77222443, 22.05444527], [88.77194214, 22.05472374], [88.77166748, 22.05444527], [88.77111053, 22.0544529], [88.77083588, 22.05417061], [88.77030945, 22.05417442], [88.7698822, 22.05416679], [88.76944733, 22.05417061], [88.76902008, 22.05417061], [88.76857758, 22.05417061], [88.7681427, 22.05416107], [88.76767731, 22.05411339], [88.76722717, 22.0539341], [88.76674652, 22.05388451], [88.76629639, 22.0538311], [88.76596832, 22.05367088], [88.765625, 22.05361748], [88.76526642, 22.05361176], [88.76490784, 22.05358315], [88.764534, 22.05343819], [88.76413727, 22.05335045], [88.76371765, 22.05332947], [88.76332855, 22.05338097], [88.7629776, 22.0535717], [88.76261139, 22.05361176], [88.76223755, 22.05362129], [88.76184845, 22.05366516], [88.76145935, 22.0538311], [88.76097107, 22.05393028], [88.7604599, 22.05416107], [88.75990295, 22.05436134], [88.7592392, 22.05443954], [88.75853729, 22.05451012], [88.75791168, 22.05472755], [88.75728607, 22.05496407], [88.7565918, 22.05509567], [88.75591278, 22.05529213], [88.75524139, 22.05552101], [88.75453186, 22.05564308], [88.7538681, 22.05583763], [88.75322723, 22.05603027], [88.75255585, 22.05610275], [88.75224304, 22.05610657], [88.75193787, 22.05611229], [88.75134277, 22.05603981], [88.7509613, 22.05586815], [88.75055695, 22.05579948], [88.75018311, 22.05572319], [88.74978638, 22.05589867], [88.74945831, 22.05620384], [88.74916077, 22.05653954], [88.74888611, 22.05685616], [88.74862671, 22.05713272], [88.74842834, 22.05742264], [88.74829865, 22.05779076], [88.74809265, 22.05817032], [88.74797821, 22.05870247], [88.74794006, 22.05930138], [88.74806976, 22.05985069], [88.74832153, 22.06031609], [88.74855804, 22.06076241], [88.74884033, 22.06116486], [88.74907684, 22.06158257], [88.74932098, 22.0619812], [88.74949646, 22.0623951], [88.74972534, 22.06274223], [88.74996185, 22.06307411], [88.75007629, 22.06352043], [88.7502594, 22.06394768], [88.7503891, 22.06440353], [88.7505722, 22.06483269], [88.75080109, 22.06522179], [88.75093079, 22.06563759], [88.75109863, 22.06606483], [88.75123596, 22.06649971], [88.75139618, 22.06692314], [88.75164795, 22.0673027], [88.75187683, 22.06772232], [88.75211334, 22.06820107], [88.75242615, 22.0686512], [88.75273132, 22.06913185], [88.75297546, 22.06965828], [88.75315094, 22.07024193], [88.7533493, 22.07079124], [88.75357819, 22.0712719], [88.75370789, 22.07175255], [88.75389862, 22.07217789], [88.75409698, 22.07258034], [88.75428009, 22.07302094], [88.7545166, 22.07339478], [88.75482941, 22.07373619], [88.75507355, 22.07411194], [88.75531769, 22.07441139], [88.75551605, 22.07469177], [88.75554657, 22.0750103], [88.75583649, 22.07527542], [88.75583649, 22.07559013], [88.75590515, 22.07588768], [88.756073, 22.076231], [88.75614929, 22.07673073], [88.75637817, 22.07722282], [88.75663757, 22.07773781], [88.75697327, 22.07825661], [88.75738525, 22.07879066], [88.75778961, 22.07938957], [88.75824738, 22.07991791], [88.75868988, 22.08036232], [88.75910187, 22.08076286], [88.75954437, 22.08110619], [88.76006317, 22.08139038], [88.76062012, 22.08165169], [88.76126099, 22.08181381], [88.76190186, 22.08197212], [88.76245117, 22.08222008], [88.76296997, 22.08244896], [88.7634964, 22.08254051], [88.7639389, 22.08274269], [88.76446533, 22.08282852], [88.76494598, 22.08304405], [88.76548004, 22.08326149], [88.76600647, 22.08350945], [88.76655579, 22.0837574], [88.76714325, 22.08394241], [88.76767731, 22.08418083], [88.76815796, 22.08441925], [88.76857758, 22.08464432], [88.76886749, 22.08492851], [88.76908112, 22.08525276], [88.76940155, 22.08549309], [88.7697525, 22.08547211], [88.76996613, 22.08546448], [88.77068329, 22.08517075], [88.77121735, 22.08502007], [88.77154541, 22.08509636], [88.77164459, 22.08537483], [88.77151489, 22.08582306], [88.77108002, 22.08627129], [88.77036285, 22.08646965], [88.77076721, 22.08675957], [88.77124786, 22.08719254], [88.77172852, 22.08757973], [88.77217865, 22.08792305], [88.77249146, 22.08826256], [88.77272797, 22.08856964], [88.77292633, 22.08887672], [88.77316284, 22.0891819], [88.77340698, 22.08954048], [88.77368164, 22.08995819], [88.77398682, 22.09037971], [88.77430725, 22.09082985], [88.77459717, 22.09129143], [88.77484131, 22.09177971], [88.77507782, 22.09221458], [88.77529144, 22.09260559], [88.7755127, 22.09293365], [88.77565002, 22.09328461], [88.7758255, 22.09358978]]], [[[88.69005585, 22.07998466], [88.68985748, 22.07998085], [88.68950653, 22.08031273], [88.68947601, 22.08078957], [88.68896484, 22.08111191], [88.68899536, 22.08190346], [88.68953705, 22.08190346], [88.69036102, 22.08107185], [88.69035339, 22.08048058], [88.69005585, 22.07998466]]], [[[88.29110718, 21.59527969], [88.29165649, 21.59527969], [88.29194641, 21.59555817], [88.29222107, 21.59555626], [88.29250336, 21.59583282], [88.29305267, 21.59583282], [88.29333496, 21.59555626], [88.29360962, 21.59555817], [88.29389191, 21.59527969], [88.29416656, 21.59527969], [88.29444122, 21.59500122], [88.29473114, 21.59500122], [88.29582977, 21.59389114], [88.29582977, 21.59361076], [88.29611206, 21.59332085], [88.29638672, 21.5933342], [88.29666901, 21.59305763], [88.29693604, 21.59305954], [88.29779053, 21.59222031], [88.29805756, 21.59222221], [88.29833221, 21.59194565], [88.2986145, 21.59194565], [88.3013916, 21.58916664], [88.30222321, 21.58917046], [88.3033371, 21.58805275], [88.3033371, 21.58777809], [88.3041687, 21.58694267], [88.30444336, 21.58694458], [88.30500031, 21.58638954], [88.30500031, 21.58527946], [88.30473328, 21.58499908], [88.30583191, 21.58389091], [88.30583191, 21.58361053], [88.30610657, 21.58332825], [88.3061142, 21.58194351], [88.30583191, 21.58166885], [88.30583191, 21.58111], [88.3061142, 21.58083344], [88.3061142, 21.5802784], [88.30555725, 21.57971954], [88.30555725, 21.57944679], [88.30500031, 21.57888794], [88.30500031, 21.57860947], [88.30444336, 21.57805443], [88.30444336, 21.57749939], [88.3033371, 21.57639122], [88.3033371, 21.57611084], [88.30278015, 21.57557106], [88.30249786, 21.57557106], [88.30194092, 21.57500076], [88.30194092, 21.57444191], [88.30166626, 21.57416725], [88.30166626, 21.57389069], [88.30110931, 21.57333183], [88.30110931, 21.57305527], [88.30053711, 21.57250023], [88.30053711, 21.57195282], [88.29965973, 21.57106018], [88.2986145, 21.56999969], [88.29833221, 21.56999969], [88.29779053, 21.56944084], [88.29777527, 21.56916618], [88.29666901, 21.56805992], [88.29666901, 21.56750107], [88.29582977, 21.56666946], [88.29556274, 21.56666946], [88.29499817, 21.56611061], [88.29438782, 21.56611061], [88.29416656, 21.56611061], [88.29360962, 21.56555939], [88.29360962, 21.56545067], [88.29360962, 21.56527519], [88.29305267, 21.56472015], [88.29305267, 21.56444359], [88.29166412, 21.56305313], [88.29138947, 21.56305313], [88.2911377, 21.56330681], [88.29027557, 21.56416512], [88.2902832, 21.56500053], [88.29000092, 21.56527519], [88.29000092, 21.56583023], [88.28971863, 21.56611061], [88.28971863, 21.56640053], [88.28943634, 21.56666946], [88.28916931, 21.56666756], [88.28861237, 21.5672226], [88.28805542, 21.56666756], [88.28806305, 21.56640053], [88.28749847, 21.56583023], [88.28749847, 21.56527519], [88.28778076, 21.56500053], [88.28778076, 21.56361008], [88.28583527, 21.56166649], [88.28556061, 21.5616703], [88.28527832, 21.56195068], [88.28444672, 21.56195068], [88.2841568, 21.5616703], [88.28388977, 21.5616703], [88.28360748, 21.56138992], [88.28333282, 21.56138992], [88.28305817, 21.56110954], [88.28277588, 21.56111145], [88.28250122, 21.56083107], [88.28221893, 21.56083107], [88.28152466, 21.56064987], [88.28056335, 21.56027031], [88.27999878, 21.56027794], [88.27972412, 21.55999947], [88.27944183, 21.55999947], [88.27916718, 21.5597229], [88.27889252, 21.5597229], [88.27861023, 21.55944443], [88.27805328, 21.55944443], [88.27777863, 21.55916595], [88.27694702, 21.55917168], [88.2766571, 21.55888939], [88.27639008, 21.55888939], [88.27583313, 21.55944443], [88.27555847, 21.55944443], [88.27527618, 21.5597229], [88.27500153, 21.55944443], [88.27361298, 21.55944443], [88.27333069, 21.55916595], [88.27305603, 21.55917168], [88.27249908, 21.55861092], [88.27194214, 21.55861092], [88.27166748, 21.55833054], [88.27138519, 21.55833244], [88.27119446, 21.55813789], [88.27111053, 21.55805588], [88.27085114, 21.5580616], [88.27056122, 21.55777931], [88.26889038, 21.55777931], [88.26860809, 21.5580616], [88.26611328, 21.55805588], [88.26583099, 21.55833244], [88.26555634, 21.55833244], [88.26444244, 21.55944443], [88.26444244, 21.5597229], [88.26249695, 21.5597229], [88.26222229, 21.55999947], [88.26082611, 21.55999947], [88.26027679, 21.56011963], [88.26000214, 21.56011963], [88.25970459, 21.56005478], [88.25944519, 21.55999947], [88.25749969, 21.55999947], [88.25666809, 21.56083107], [88.25583649, 21.56083107], [88.2555542, 21.56111145], [88.25499725, 21.56110954], [88.2547226, 21.56138992], [88.25389099, 21.56138992], [88.2536087, 21.5616703], [88.25332642, 21.5616703], [88.25305176, 21.56195068], [88.2527771, 21.56194305], [88.25250244, 21.56222153], [88.25166321, 21.56221962], [88.2497406, 21.56417084], [88.2491684, 21.56417084], [88.24888611, 21.56389046], [88.24833679, 21.56388855], [88.24749756, 21.56472015], [88.24749756, 21.56500053], [88.24500275, 21.56750107], [88.2444458, 21.56750107], [88.24415588, 21.56777954], [88.24368286, 21.56812096], [88.24333191, 21.56861115], [88.24305725, 21.56888962], [88.24305725, 21.56916618], [88.24276733, 21.56944084], [88.24277496, 21.56999969], [88.24222565, 21.57055473], [88.24222565, 21.57083321], [88.24211884, 21.57094002], [88.24138641, 21.57167244], [88.24138641, 21.57194519], [88.24111176, 21.5722084], [88.24111176, 21.57278252], [88.2408371, 21.57305527], [88.2408371, 21.57333183], [88.24054718, 21.57361031], [88.24054718, 21.57500076], [88.2408371, 21.57528114], [88.2408371, 21.57611084], [88.24111176, 21.57639122], [88.24111176, 21.57666588], [88.24138641, 21.57694244], [88.24138641, 21.57722473], [88.24185944, 21.57769394], [88.24222565, 21.57805443], [88.24223328, 21.57860947], [88.24250031, 21.57888794], [88.24250031, 21.57944679], [88.24388885, 21.58083344], [88.24416351, 21.58083344], [88.2444458, 21.58111191], [88.2444458, 21.58138847], [88.24500275, 21.58194351], [88.24500275, 21.58221817], [88.2452774, 21.58250046], [88.2452774, 21.58361053], [88.24500275, 21.58389091], [88.24500275, 21.58416748], [88.2452774, 21.58443832], [88.2452774, 21.58666611], [88.24555206, 21.58694267], [88.24555206, 21.59111023], [88.2452774, 21.5913887], [88.2452774, 21.59194565], [88.24388885, 21.59332085], [88.24388885, 21.59361076], [88.24305725, 21.59444427], [88.24305725, 21.59472084], [88.24276733, 21.59500122], [88.24305725, 21.59527969], [88.24305725, 21.59583282], [88.24276733, 21.59610939], [88.24277496, 21.59666634], [88.24222565, 21.59722137], [88.24194336, 21.59721756], [88.2416687, 21.59749985], [88.24111176, 21.59749985], [88.24028015, 21.59833336], [88.24028015, 21.59861183], [88.23999786, 21.59861183], [88.23944092, 21.59917259], [88.23944092, 21.59944534], [88.23916626, 21.59972191], [88.23916626, 21.60055542], [88.2388916, 21.60083008], [88.2388916, 21.60111046], [88.23860931, 21.60138893], [88.23860931, 21.60222054], [88.23777771, 21.60305977], [88.23748779, 21.60305977], [88.23665619, 21.60388947], [88.23610687, 21.60388947], [88.23583221, 21.60416412], [88.23583221, 21.60472107], [88.23555756, 21.60499954], [88.23555756, 21.60527611], [88.23500061, 21.60583305], [88.23500061, 21.60610962], [88.23306274, 21.60806084], [88.23278046, 21.60805511], [88.23249817, 21.60833359], [88.23222351, 21.60833359], [88.23083496, 21.60972214], [88.23055267, 21.60972023], [88.23027802, 21.61000061], [88.23000336, 21.61000061], [88.22972107, 21.61027908], [88.22861481, 21.61027718], [88.2277832, 21.61111069], [88.22638702, 21.61111069], [88.22583008, 21.61168289], [88.22444153, 21.61166573], [88.22416687, 21.6119442], [88.22389221, 21.61222267], [88.22360992, 21.61222076], [88.2233429, 21.61249924], [88.22305298, 21.61249924], [88.22222137, 21.61333275], [88.22194672, 21.61333275], [88.22138977, 21.61388969], [88.22083282, 21.61388969], [88.22000122, 21.6147213], [88.21992493, 21.6147213], [88.21971893, 21.6147213], [88.2194519, 21.61471939], [88.21916962, 21.61499977], [88.21806335, 21.61499977], [88.21778107, 21.61528015], [88.21722412, 21.61527824], [88.21666718, 21.61583138], [88.21666718, 21.61610985], [88.21639252, 21.61638832], [88.21639252, 21.61722183], [88.21611023, 21.61749077], [88.21653748, 21.61861038], [88.21721649, 21.61972046], [88.21774292, 21.62018013], [88.21806335, 21.62055016], [88.21839142, 21.62091064], [88.21868134, 21.62128258], [88.21900177, 21.62162781], [88.21933746, 21.6219368], [88.21967316, 21.6222496], [88.21997833, 21.62261963], [88.22029877, 21.6230545], [88.22071075, 21.62350082], [88.22116089, 21.62400627], [88.22169495, 21.62448692], [88.22222137, 21.62500954], [88.22268677, 21.62559128], [88.2231369, 21.62618256], [88.22362518, 21.62667465], [88.22418213, 21.62705994], [88.22476196, 21.62736893], [88.22534943, 21.62759972], [88.2258606, 21.6278801], [88.22632599, 21.6281395], [88.22677612, 21.62842941], [88.22724152, 21.62870026], [88.22771454, 21.62896538], [88.22816467, 21.62925148], [88.22865295, 21.62949944], [88.22908783, 21.6298008], [88.22949982, 21.63014984], [88.22992706, 21.63047981], [88.2303772, 21.63079834], [88.23085022, 21.63112068], [88.23133087, 21.63146019], [88.23175049, 21.63192177], [88.23215485, 21.63261604], [88.2322998, 21.63282967], [88.23236084, 21.63292122], [88.23287201, 21.63316917], [88.23304749, 21.63348198], [88.23348236, 21.63371468], [88.23390198, 21.63409042], [88.23403931, 21.6346302], [88.23445892, 21.63500977], [88.23473358, 21.63537788], [88.23470306, 21.63575363], [88.23490906, 21.63619232], [88.23503113, 21.63673019], [88.23519897, 21.63733673], [88.23530579, 21.63800049], [88.23554993, 21.63863564], [88.23571014, 21.63923073], [88.23590851, 21.63967896], [88.23606873, 21.6403656], [88.23592377, 21.64052391], [88.23612213, 21.64156914], [88.23604584, 21.64224052], [88.23613739, 21.64281082], [88.23648834, 21.6433506], [88.23667908, 21.64388084], [88.23670959, 21.64413071], [88.23683167, 21.64489937], [88.23673248, 21.64538574], [88.23673248, 21.64586449], [88.23657227, 21.64647102], [88.23648834, 21.64697075], [88.23641968, 21.64729118], [88.23635101, 21.64776039], [88.23619843, 21.6482296], [88.23596954, 21.64866829], [88.23580933, 21.64914131], [88.23558044, 21.64957809], [88.23539734, 21.65003967], [88.23525238, 21.65052032], [88.23500061, 21.65096092], [88.23474121, 21.65142059], [88.23445892, 21.65192032], [88.23416901, 21.6523838], [88.23388672, 21.65281296], [88.23361206, 21.65320969], [88.23332977, 21.65360069], [88.23304749, 21.65401077], [88.23277283, 21.65446091], [88.23249054, 21.6549511], [88.23221588, 21.65544128], [88.23194885, 21.65588951], [88.23169708, 21.65629959], [88.23158264, 21.65674973], [88.23145294, 21.65718651], [88.23158264, 21.65766907], [88.23166656, 21.65823174], [88.23184204, 21.65881348], [88.23190308, 21.65944099], [88.23194122, 21.66007805], [88.23194122, 21.66069984], [88.23194885, 21.6613102], [88.231987, 21.66192055], [88.23217773, 21.66250992], [88.23223877, 21.66312981], [88.23235321, 21.66372108], [88.23252106, 21.66424561], [88.23277283, 21.66470909], [88.2329483, 21.66518974], [88.23306274, 21.66527939], [88.23306274, 21.66556168], [88.23332977, 21.66638947], [88.23332977, 21.66805649], [88.23300171, 21.6690197], [88.23249817, 21.66945076], [88.23194122, 21.67000008], [88.23194122, 21.67027855], [88.23139191, 21.67083549], [88.23139191, 21.67111015], [88.23036957, 21.67224121], [88.22955322, 21.67311096], [88.22912598, 21.67331123], [88.22783661, 21.67404938], [88.22633362, 21.67505455], [88.22451782, 21.67552948], [88.22386169, 21.67571068], [88.22316742, 21.67581749], [88.22251129, 21.67583084], [88.22187042, 21.67584038], [88.22161102, 21.67583656], [88.22124481, 21.67583466], [88.22058105, 21.67583275], [88.21987915, 21.67579269], [88.21923828, 21.67560768], [88.2186203, 21.67554092], [88.21808624, 21.67542839], [88.21762085, 21.6752739], [88.21717834, 21.67510605], [88.21672058, 21.67500114], [88.21627808, 21.67487907], [88.21588135, 21.67474174], [88.21552277, 21.67464066], [88.2151947, 21.67448044], [88.21481323, 21.67444992], [88.21440125, 21.67444038], [88.213974, 21.67443085], [88.21354675, 21.67436028], [88.2131424, 21.67424011], [88.21276093, 21.67438126], [88.21237183, 21.67431068], [88.21196747, 21.67423058], [88.21154022, 21.67440033], [88.21102142, 21.67444038], [88.21083069, 21.6744442], [88.21044159, 21.67444992], [88.20983887, 21.67444038], [88.20923615, 21.67435074], [88.20865631, 21.67427063], [88.20813751, 21.67440987], [88.20761108, 21.67451096], [88.20713806, 21.67469025], [88.20661163, 21.67480087], [88.20610046, 21.67502022], [88.20558167, 21.67527771], [88.20506287, 21.67557144], [88.20462036, 21.67593575], [88.20423126, 21.67631912], [88.20384216, 21.67670059], [88.20340729, 21.67703056], [88.20305634, 21.67742729], [88.2027359, 21.67782974], [88.20244598, 21.67825127], [88.20211029, 21.67862892], [88.20178986, 21.67904282], [88.20147705, 21.67947006], [88.20118713, 21.67991066], [88.20083618, 21.68032074], [88.20049286, 21.68077278], [88.20007324, 21.68120956], [88.19972992, 21.68170738], [88.19944, 21.68218994], [88.19918823, 21.68261909], [88.19903564, 21.68304253], [88.1989212, 21.68345261], [88.19889069, 21.68394089], [88.19888306, 21.68447113], [88.19877625, 21.68501091], [88.19841003, 21.68546295], [88.19832611, 21.6859951], [88.19830322, 21.68651009], [88.19812775, 21.687397], [88.19805908, 21.68833351], [88.19785309, 21.6885376], [88.19777679, 21.68861008], [88.19777679, 21.68916893], [88.19805908, 21.68943977], [88.19805908, 21.68972206], [88.19916534, 21.69083405], [88.19989014, 21.69082832], [88.19999695, 21.69082832], [88.20027924, 21.69111061], [88.20054626, 21.69111061], [88.20083618, 21.69138908], [88.2011795, 21.69138908], [88.20182037, 21.69140053], [88.20249939, 21.69166756], [88.20306396, 21.69174194], [88.20444489, 21.69194412], [88.20542908, 21.69216347], [88.20630646, 21.69215965], [88.20694733, 21.69231987], [88.2075119, 21.69249916], [88.20833588, 21.69249916], [88.20861053, 21.69277763], [88.20888519, 21.69277763], [88.20944214, 21.69333267], [88.21028137, 21.69333267], [88.21055603, 21.69361115], [88.21111298, 21.69361115], [88.21138763, 21.69333267], [88.21166992, 21.69333267], [88.21221924, 21.69388962], [88.21250153, 21.69388962], [88.21305847, 21.69411087], [88.21354675, 21.69430923], [88.21389771, 21.69445038], [88.21417236, 21.69458961], [88.21444702, 21.6947403], [88.2149353, 21.69487572], [88.21527863, 21.69472122], [88.21555328, 21.69472122], [88.21666718, 21.6958313], [88.21694183, 21.69582939], [88.21778107, 21.69667053], [88.21778107, 21.69695091], [88.21833038, 21.69750023], [88.21833038, 21.69778061], [88.21861267, 21.69806099], [88.21888733, 21.69806099], [88.21917725, 21.69835091], [88.21967316, 21.69890022], [88.22006989, 21.69944954], [88.22038269, 21.70002937], [88.22055054, 21.70065689], [88.22070313, 21.70126915], [88.22088623, 21.7018261], [88.22106171, 21.70238113], [88.22107697, 21.70294952], [88.22094727, 21.70350075], [88.22080994, 21.7040596], [88.22059631, 21.70457268], [88.22055817, 21.70512009], [88.22054291, 21.70565987], [88.22048187, 21.70615959], [88.2203064, 21.70661926], [88.22019958, 21.70714378], [88.21998596, 21.70768356], [88.22000885, 21.70837975], [88.21971893, 21.70882988], [88.21930695, 21.70944977], [88.21900177, 21.70989037], [88.21858215, 21.71050072], [88.21834564, 21.71095657], [88.21798706, 21.71130371], [88.21749115, 21.71161079], [88.21718597, 21.71198082], [88.21692657, 21.7123661], [88.21664429, 21.71272278], [88.21636963, 21.71304321], [88.21613312, 21.71333122], [88.21592712, 21.7136097], [88.21573639, 21.7138195], [88.21549225, 21.71398163], [88.21537781, 21.71426964], [88.21517181, 21.71454239], [88.21502686, 21.71487045], [88.21495819, 21.715271], [88.21471405, 21.71557617], [88.21444702, 21.71591377], [88.2141571, 21.71626091], [88.21389008, 21.71661186], [88.21363068, 21.71696281], [88.21343231, 21.71738434], [88.21317291, 21.71779251], [88.21289825, 21.71822548], [88.212677, 21.71870041], [88.21246338, 21.71915054], [88.21221924, 21.7195816], [88.21201324, 21.71998024], [88.21193695, 21.72043419], [88.21187592, 21.72087097], [88.21170807, 21.72126007], [88.21166992, 21.72169113], [88.2116394, 21.72216034], [88.21151733, 21.72266006], [88.21141052, 21.72324181], [88.21134949, 21.72386169], [88.21115112, 21.72443008], [88.21111298, 21.72499084], [88.21111298, 21.72551918], [88.2110672, 21.72601128], [88.2109375, 21.72643852], [88.21105194, 21.7267704], [88.21116638, 21.72711182], [88.21135712, 21.72742081], [88.2115097, 21.72776985], [88.21166992, 21.72813988], [88.21183777, 21.72851944], [88.21192932, 21.72891808], [88.21193695, 21.72931862], [88.21193695, 21.72974014], [88.21199036, 21.73015976], [88.21216583, 21.73060036], [88.21221924, 21.73114967], [88.21224213, 21.73175049], [88.21234131, 21.73231506], [88.21251678, 21.73281097], [88.21272278, 21.73322105], [88.21278381, 21.73360062], [88.21286011, 21.73394203], [88.21302032, 21.73426056], [88.21305847, 21.73464775], [88.21311188, 21.73509026], [88.21328735, 21.73557091], [88.21338654, 21.73611832], [88.21360779, 21.73666191], [88.21388245, 21.73722076], [88.21411133, 21.73777962], [88.21422577, 21.73835754], [88.21438599, 21.73888016], [88.21440887, 21.73937988], [88.21437073, 21.73985672], [88.21440125, 21.74028969], [88.21446991, 21.74072075], [88.21459198, 21.74113083], [88.21469879, 21.74153709], [88.21470642, 21.74198151], [88.2146225, 21.74246025], [88.21434021, 21.74298096], [88.21430206, 21.74351883], [88.21446991, 21.74407005], [88.2146759, 21.74465942], [88.21473694, 21.74527931], [88.21472931, 21.7458992], [88.2146759, 21.74650002], [88.21453857, 21.74706841], [88.21433258, 21.74757957], [88.21440125, 21.74806976], [88.21446228, 21.74856949], [88.21460724, 21.74908066], [88.21450043, 21.74955368], [88.21434021, 21.75003433], [88.21405029, 21.75046158], [88.21393585, 21.75086975], [88.2140274, 21.75125122], [88.21414185, 21.75164032], [88.21416473, 21.75204849], [88.21421051, 21.75247192], [88.21437073, 21.75290108], [88.21444702, 21.75336075], [88.21448517, 21.75382614], [88.21445465, 21.75430298], [88.21450043, 21.75476074], [88.21469879, 21.75518036], [88.2148819, 21.75561333], [88.21499634, 21.75609016], [88.21508789, 21.75658989], [88.21526337, 21.75704956], [88.21542358, 21.75750732], [88.21560669, 21.75796127], [88.21583557, 21.75840759], [88.21604919, 21.75889015], [88.21611023, 21.75949097], [88.21617889, 21.76008034], [88.21637726, 21.76054955], [88.21659088, 21.76096153], [88.21671295, 21.76135063], [88.21691132, 21.76165962], [88.21710968, 21.76192856], [88.21744537, 21.76214981], [88.21800232, 21.76221466], [88.21868896, 21.76222229], [88.21942139, 21.76222229], [88.22016907, 21.76220703], [88.22090912, 21.76214981], [88.22164917, 21.76204681], [88.22236633, 21.76205063], [88.22309875, 21.76198959], [88.22381592, 21.76196098], [88.22454071, 21.76196098], [88.22525787, 21.76200485], [88.22596741, 21.76210594], [88.22667694, 21.76210213], [88.22736359, 21.76199913], [88.22807312, 21.76194954], [88.2287674, 21.76193237], [88.22946167, 21.76189423], [88.23013306, 21.76178932], [88.2307663, 21.76161957], [88.23132324, 21.76137924], [88.23182678, 21.76111984], [88.23227692, 21.76086998], [88.23274994, 21.76068878], [88.23323059, 21.76052094], [88.2337265, 21.76035118], [88.23432159, 21.76018906], [88.23497772, 21.75992966], [88.23560333, 21.75967026], [88.23607635, 21.75945282], [88.23671722, 21.75933075], [88.23738098, 21.75920105], [88.23809052, 21.75910187], [88.23880005, 21.75892448], [88.23953247, 21.75877762], [88.24022675, 21.75859833], [88.24089813, 21.75835991], [88.24156952, 21.75818062], [88.24224854, 21.75807953], [88.24289703, 21.75802994], [88.24349976, 21.75794983], [88.24404144, 21.75780106], [88.24453735, 21.75769806], [88.24495697, 21.75756073], [88.24542236, 21.75749016], [88.24590302, 21.75742722], [88.24638367, 21.75728035], [88.2469101, 21.75722122], [88.24745178, 21.75716972], [88.24798584, 21.75704193], [88.24852753, 21.75694084], [88.24906158, 21.75683022], [88.2495575, 21.75666428], [88.25004578, 21.75650406], [88.25056458, 21.75639915], [88.25108337, 21.75632858], [88.25157166, 21.75618935], [88.25209045, 21.75611115], [88.25263214, 21.7560997], [88.25318909, 21.7560482], [88.25376129, 21.75591087], [88.25437927, 21.75583839], [88.25506592, 21.75583267], [88.25576782, 21.75583267], [88.25646973, 21.75583458], [88.25717926, 21.75582886], [88.25788879, 21.75577927], [88.25859833, 21.75560951], [88.25930786, 21.75555992], [88.2600174, 21.75555992], [88.26071167, 21.75558281], [88.26139832, 21.75567055], [88.26209259, 21.75572968], [88.26283264, 21.75560951], [88.26358795, 21.75556374], [88.26432037, 21.75554276], [88.26465607, 21.75551987], [88.26500702, 21.75549889], [88.26563263, 21.7553997], [88.26628876, 21.75546646], [88.26669312, 21.75548553], [88.26694489, 21.75550079], [88.26751709, 21.75533104], [88.26809692, 21.75515938], [88.2686615, 21.75505066], [88.26922607, 21.75498009], [88.26976776, 21.75485611], [88.27031708, 21.75475121], [88.27089691, 21.75472069], [88.271492, 21.75467491], [88.27200317, 21.75440598], [88.27237701, 21.75395966], [88.27249146, 21.7533226], [88.27249908, 21.75266266], [88.27243042, 21.75205803], [88.2722168, 21.75164032], [88.2720108, 21.75124741], [88.2718811, 21.75081253], [88.27166748, 21.75046158], [88.27144623, 21.75015068], [88.2713089, 21.7497921], [88.27112579, 21.74950981], [88.27098846, 21.74921227], [88.27085114, 21.74889946], [88.27075958, 21.74852943], [88.27056122, 21.7481823], [88.27033997, 21.74780273], [88.27005768, 21.74744225], [88.26997375, 21.74697876], [88.26985931, 21.74651909], [88.26972198, 21.74606133], [88.26958466, 21.74556541], [88.2694397, 21.74505806], [88.26927185, 21.74454117], [88.26908875, 21.74407959], [88.26874542, 21.74380875], [88.26854706, 21.7435112], [88.26842499, 21.74318695], [88.26831818, 21.74283981], [88.2681427, 21.74257088], [88.26795959, 21.74229813], [88.26777649, 21.74202919], [88.26759338, 21.74172974], [88.26744843, 21.74136543], [88.26721954, 21.74104118], [88.26696777, 21.74072075], [88.26673889, 21.74036026], [88.26647186, 21.74002075], [88.26616669, 21.73970985], [88.26587677, 21.73940277], [88.26560211, 21.73905754], [88.26538086, 21.73863983], [88.26511383, 21.73826027], [88.2649231, 21.73780823], [88.26470184, 21.73736], [88.26442719, 21.73694038], [88.2641449, 21.7365818], [88.2638092, 21.73628044], [88.26351929, 21.73592758], [88.26317596, 21.73565102], [88.26288605, 21.73531723], [88.2627182, 21.73517609], [88.26254272, 21.7350235], [88.26235962, 21.73472023], [88.26229858, 21.73462296], [88.26215363, 21.73412132], [88.26192474, 21.73365974], [88.26169586, 21.73320961], [88.26156616, 21.73269844], [88.2614212, 21.73218918], [88.26146698, 21.73162079], [88.2616806, 21.73111916], [88.26190948, 21.73063087], [88.2620697, 21.73017311], [88.26226044, 21.72979927], [88.26246643, 21.72949982], [88.26265717, 21.72922134], [88.26295471, 21.72901344], [88.26332092, 21.7287693], [88.2637558, 21.7285099], [88.26434326, 21.7284317], [88.26490021, 21.72826958], [88.26548767, 21.72813034], [88.26613617, 21.72824097], [88.26679993, 21.72809029], [88.26750183, 21.72805977], [88.26818848, 21.72809792], [88.26838684, 21.72815704], [88.26866913, 21.72824097], [88.26883698, 21.72829247], [88.26944733, 21.72837067], [88.26995087, 21.72846031], [88.27029419, 21.72830391], [88.27047729, 21.72822189], [88.27101135, 21.72822762], [88.27158356, 21.72830391], [88.2722168, 21.72826576], [88.27284241, 21.7279911], [88.27345276, 21.7277317], [88.27410889, 21.72762108], [88.27468872, 21.72747993], [88.27514648, 21.72718239], [88.27552795, 21.72681046], [88.27555847, 21.72667122], [88.2766571, 21.72556114], [88.2766571, 21.72528076], [88.27694702, 21.72500038], [88.27694702, 21.72472], [88.27666473, 21.72444344], [88.2766571, 21.7238903], [88.27694702, 21.72360992], [88.27694702, 21.72333336], [88.27722168, 21.72305489], [88.27722168, 21.72277832], [88.27777863, 21.72221947], [88.27777863, 21.7211113], [88.27749634, 21.72083282], [88.27749634, 21.71999931], [88.27777863, 21.71970749], [88.27777863, 21.7191658], [88.2783432, 21.71861076], [88.27833557, 21.71805573], [88.27861023, 21.71777916], [88.27861023, 21.71750069], [88.27916718, 21.71693993], [88.27916718, 21.71583366], [88.27944183, 21.71555519], [88.27944183, 21.71528053], [88.27971649, 21.71500015], [88.27971649, 21.71445084], [88.27999878, 21.71417046], [88.27999878, 21.71389961], [88.28056335, 21.71333122], [88.28055573, 21.71305656], [88.28083038, 21.71305656], [88.28111267, 21.71277618], [88.28166962, 21.71278], [88.28221893, 21.71222115], [88.28221893, 21.71138954], [88.28193665, 21.71111107], [88.28221893, 21.71111107], [88.28250122, 21.71084023], [88.28250122, 21.71055984], [88.28305817, 21.71000099], [88.28305817, 21.70972061], [88.28360748, 21.70916748], [88.28360748, 21.70889282], [88.28388977, 21.70861053], [88.28388977, 21.70833015], [88.28360748, 21.7080555], [88.2841568, 21.70750046], [88.2841568, 21.70722008], [88.28444672, 21.70694351], [88.2848053, 21.70646477], [88.28520966, 21.70613289], [88.28559875, 21.70568085], [88.28601837, 21.70521927], [88.28645325, 21.70474052], [88.28694153, 21.70430946], [88.28749847, 21.70388985], [88.28778076, 21.70360756], [88.28805542, 21.70361137], [88.28888702, 21.70277977], [88.28888702, 21.70249939], [88.28916931, 21.70222092], [88.28916931, 21.70194435], [88.28944397, 21.70166779], [88.28943634, 21.70139122], [88.29083252, 21.70000076], [88.29110718, 21.70000076], [88.29389191, 21.69721985], [88.29389191, 21.69694328], [88.29528046, 21.69553947], [88.29555511, 21.69555473], [88.29666901, 21.69444466], [88.29666901, 21.69416618], [88.29722595, 21.69361115], [88.29722595, 21.69333267], [88.29777527, 21.69277763], [88.29805756, 21.69277763], [88.29916382, 21.69166756], [88.29915619, 21.69138908], [88.29972076, 21.69082832], [88.29984283, 21.69072151], [88.30025482, 21.69025612], [88.30058289, 21.68970108], [88.30090332, 21.68913078], [88.30130005, 21.68867302], [88.30169678, 21.68817329], [88.30213928, 21.68768311], [88.30256653, 21.68716812], [88.30303192, 21.68669701], [88.30345154, 21.68622017], [88.30373383, 21.68572617], [88.30397797, 21.68530083], [88.30421448, 21.6849575], [88.3044281, 21.68465042], [88.30458832, 21.68430328], [88.30477905, 21.68394279], [88.3050766, 21.68354034], [88.3054657, 21.68312836], [88.30581665, 21.68261909], [88.30610657, 21.68207169], [88.30639648, 21.68155098], [88.30667877, 21.68111801], [88.30722046, 21.68056107], [88.30722046, 21.68028259], [88.30750275, 21.68000031], [88.3077774, 21.68000031], [88.3088913, 21.67889023], [88.3088913, 21.67861176], [88.30916595, 21.67833328], [88.30916595, 21.67805481], [88.30944824, 21.67777824], [88.30944824, 21.67749977], [88.30973053, 21.67721748], [88.3097229, 21.67694473], [88.31027985, 21.67638969], [88.31027985, 21.67583084], [88.3105545, 21.67555618], [88.31054688, 21.67527962], [88.31027985, 21.67500114], [88.31054688, 21.6747303], [88.31054688, 21.67444038], [88.31083679, 21.67416763], [88.31083679, 21.67389107], [88.31111145, 21.67361069], [88.31111145, 21.67250061], [88.31143188, 21.67278099], [88.3116684, 21.67193985], [88.31138611, 21.67166519], [88.31138611, 21.67111206], [88.3105545, 21.67027855], [88.31054688, 21.6697197], [88.31027985, 21.66944313], [88.31027985, 21.66917038], [88.30973053, 21.66860008], [88.3097229, 21.66833115], [88.30944824, 21.66805649], [88.30944824, 21.66777992], [88.3088913, 21.66722107], [88.30944824, 21.66666603], [88.30916595, 21.66638947], [88.30916595, 21.66610909], [88.30860901, 21.66556168], [88.30860901, 21.66527939], [88.30805206, 21.66472054], [88.30805206, 21.66444397], [88.3077774, 21.6641674], [88.3077774, 21.66389084], [88.30750275, 21.66361046], [88.30750275, 21.66332817], [88.30583191, 21.66166878], [88.30583191, 21.66110992], [88.30556488, 21.66065979], [88.30532074, 21.6602211], [88.30509949, 21.65974045], [88.30486298, 21.65928268], [88.30469513, 21.65876389], [88.30445099, 21.65828514], [88.30419922, 21.65784073], [88.30388641, 21.65743065], [88.3035965, 21.65703964], [88.30332184, 21.65666008], [88.30304718, 21.65628815], [88.30278778, 21.65594864], [88.30257416, 21.65561676], [88.30245209, 21.65524101], [88.30223083, 21.6548996], [88.3020401, 21.65452003], [88.30191803, 21.65409279], [88.30169678, 21.65363121], [88.30148315, 21.65312195], [88.30126953, 21.65255928], [88.30105591, 21.65206909], [88.30080414, 21.65172958], [88.30053711, 21.65147018], [88.30030823, 21.65125084], [88.30014801, 21.6509819], [88.30001831, 21.65069199], [88.29994965, 21.65035057], [88.29984283, 21.65003014], [88.29972076, 21.64972115], [88.29972076, 21.64944458], [88.29944611, 21.64916611], [88.2980423, 21.64916611], [88.29528046, 21.64916992], [88.29499817, 21.64888954], [88.29444122, 21.64888954], [88.29416656, 21.64861107], [88.29389191, 21.64861107], [88.29444122, 21.64805984], [88.29444122, 21.64777946], [88.29473114, 21.64750099], [88.29522705, 21.64757729], [88.29572296, 21.64773941], [88.29625702, 21.64788055], [88.296875, 21.64798737], [88.29763794, 21.64805412], [88.29807281, 21.64798355], [88.2986145, 21.64777756], [88.29860687, 21.64722061], [88.29805756, 21.64666748], [88.29805756, 21.64639091], [88.29779053, 21.64611053], [88.29777527, 21.64583588], [88.29750061, 21.6455574], [88.29750061, 21.64528084], [88.29722595, 21.64500046], [88.29722595, 21.64472008], [88.29666901, 21.64416695], [88.29666901, 21.64361], [88.29638672, 21.64333344], [88.29638672, 21.6427784], [88.29611206, 21.64249992], [88.29611206, 21.64221954], [88.29582977, 21.64194489], [88.29582977, 21.64166641], [88.29611206, 21.64138985], [88.29556274, 21.6408329], [88.29582977, 21.64055634], [88.29582977, 21.64027977], [88.29528046, 21.63972282], [88.29528046, 21.63944435], [88.29499817, 21.63916588], [88.29499817, 21.63888931], [88.29473114, 21.63862038], [88.29470062, 21.63830948], [88.29416656, 21.63777733], [88.29416656, 21.63750076], [88.29332733, 21.63666916], [88.29332733, 21.63611031], [88.29360962, 21.63582993], [88.29360962, 21.63555527], [88.29332733, 21.63528061], [88.29332733, 21.63500023], [88.29305267, 21.63471985], [88.29305267, 21.63388634], [88.29277802, 21.63360977], [88.29277802, 21.63249969], [88.29305267, 21.63222313], [88.29277802, 21.63194656], [88.29277802, 21.63166428], [88.29138947, 21.63027954], [88.29138947, 21.63000107], [88.29110718, 21.62972069], [88.29111481, 21.62916756], [88.29083252, 21.6288929], [88.29055786, 21.6288929], [88.29037476, 21.62870407], [88.29000092, 21.62833023], [88.29000092, 21.62750053], [88.29083252, 21.62668037], [88.28943634, 21.62528038], [88.28943634, 21.62471771], [88.28916931, 21.62444496], [88.28916931, 21.62388992], [88.28833008, 21.62305832], [88.28833008, 21.62277985], [88.28916931, 21.62194061], [88.28916931, 21.62166786], [88.28888702, 21.62138939], [88.28888702, 21.62111092], [88.28916931, 21.62083054], [88.28916931, 21.6202755], [88.28859711, 21.61972046], [88.28861237, 21.6194458], [88.28888702, 21.61916733], [88.28888702, 21.61833], [88.28861237, 21.61805344], [88.28859711, 21.61778069], [88.28833008, 21.61749077], [88.28833008, 21.61666679], [88.2883606, 21.61656761], [88.28848267, 21.61611176], [88.28861237, 21.61583138], [88.28861237, 21.61527824], [88.28888702, 21.61499977], [88.28859711, 21.61471939], [88.28861237, 21.61444473], [88.28833008, 21.61417007], [88.28833008, 21.61361122], [88.28806305, 21.61333275], [88.28833008, 21.61305618], [88.28833008, 21.61277962], [88.28859711, 21.61249924], [88.28859711, 21.61193848], [88.28888702, 21.61166573], [88.28888702, 21.61111069], [88.28971863, 21.61027908], [88.28916931, 21.60972023], [88.28916931, 21.60861206], [88.28888702, 21.60833359], [88.28888702, 21.60638618], [88.28916931, 21.60610962], [88.28916931, 21.60527611], [88.28888702, 21.60499954], [88.28778076, 21.60499954], [88.28721619, 21.60444069], [88.28694153, 21.60444641], [88.28639221, 21.60388947], [88.28666687, 21.60361099], [88.28666687, 21.60277939], [88.28694153, 21.60251045], [88.28694153, 21.60222054], [88.28749847, 21.6016674], [88.28749847, 21.60111046], [88.28778076, 21.60083008], [88.28778076, 21.60000038], [88.28806305, 21.59972191], [88.28805542, 21.59944534], [88.28833008, 21.59917259], [88.28833008, 21.59861183], [88.28861237, 21.59833336], [88.28861237, 21.59777832], [88.28916931, 21.59721756], [88.28916931, 21.59666634], [88.28943634, 21.59638023], [88.29000092, 21.59638977], [88.29000092, 21.5961113], [88.29027557, 21.59583282], [88.29027557, 21.59555626], [88.29083252, 21.59500122], [88.29110718, 21.59527969]]], [[[89.00511932, 21.7649765], [89.00567627, 21.76489067], [89.00610352, 21.76493263], [89.00657654, 21.7648735], [89.00709534, 21.76496124], [89.00762939, 21.76496124], [89.00817108, 21.76489067], [89.00875854, 21.76480103], [89.00937653, 21.76481438], [89.00997925, 21.7649231], [89.01060486, 21.76494408], [89.01125336, 21.76486588], [89.0120163, 21.76490021], [89.01274109, 21.76484108], [89.0133667, 21.76463127], [89.01399231, 21.76447105], [89.01455688, 21.7643261], [89.01502228, 21.7641201], [89.01542664, 21.7638607], [89.01580048, 21.76358986], [89.01616669, 21.76330948], [89.01656342, 21.7630558], [89.01695251, 21.76279068], [89.01732635, 21.76252556], [89.01768494, 21.76224136], [89.01805115, 21.7619381], [89.01838684, 21.76160049], [89.01874542, 21.76123238], [89.01909637, 21.76080513], [89.01947021, 21.76035118], [89.0198822, 21.75984764], [89.02031708, 21.75938034], [89.02076721, 21.75897026], [89.0212326, 21.75862122], [89.02164459, 21.75831413], [89.02198029, 21.75801468], [89.02230835, 21.75777054], [89.0226059, 21.75753975], [89.02295685, 21.75736046], [89.02336884, 21.75726128], [89.02381134, 21.75723076], [89.0242691, 21.75722694], [89.02471161, 21.75720978], [89.02510071, 21.75714302], [89.02541351, 21.75696945], [89.02567291, 21.75674057], [89.02596283, 21.75647163], [89.02626038, 21.75617409], [89.02658081, 21.75586128], [89.02690125, 21.75554085], [89.02719116, 21.75518036], [89.02745819, 21.75479126], [89.02776337, 21.75442123], [89.02804565, 21.75403214], [89.02830505, 21.7536068], [89.02854919, 21.75315857], [89.02881622, 21.75275993], [89.02905273, 21.75238037], [89.02925873, 21.75209045], [89.02947235, 21.75187111], [89.02964783, 21.75167084], [89.0298233, 21.75144958], [89.02999115, 21.75121689], [89.03016663, 21.7509594], [89.03040314, 21.75069046], [89.03056335, 21.75048256], [89.03065491, 21.75036621], [89.03102112, 21.75002098], [89.03145599, 21.74963951], [89.03192139, 21.74920082], [89.03236389, 21.7487011], [89.03275299, 21.74814034], [89.03321075, 21.74765015], [89.03367615, 21.74721146], [89.03414154, 21.74675369], [89.03455353, 21.74625015], [89.03501892, 21.74577332], [89.03546143, 21.74529457], [89.03588104, 21.74479485], [89.03631592, 21.74427414], [89.03726196, 21.74324989], [89.03769684, 21.74278069], [89.03806305, 21.74231148], [89.03833771, 21.74197388], [89.03855133, 21.74163628], [89.03840637, 21.74117088], [89.03806305, 21.74096107], [89.03740692, 21.74082947], [89.03697968, 21.74082947], [89.0366745, 21.74054146], [89.03655243, 21.74042892], [89.03655243, 21.74028969], [89.03683472, 21.7399559], [89.03762054, 21.7399559], [89.03819275, 21.74002266], [89.03940582, 21.74002075], [89.03971863, 21.74028015], [89.0402832, 21.74028015], [89.04055786, 21.73999977], [89.04083252, 21.73999977], [89.04138947, 21.73944092], [89.04194641, 21.73944664], [89.04472351, 21.73666573], [89.04499817, 21.73647118], [89.04556274, 21.73611069], [89.04576111, 21.73584175], [89.04666901, 21.73527718], [89.04714966, 21.73493958], [89.04777527, 21.73472214], [89.04798126, 21.73458862], [89.04833221, 21.73444176], [89.0486145, 21.73444366], [89.04916382, 21.73388863], [89.04944611, 21.73389053], [89.04972076, 21.73361015], [89.04990387, 21.73350525], [89.05033875, 21.73336983], [89.05062103, 21.73316956], [89.05119324, 21.73262978], [89.05126953, 21.73236275], [89.05155182, 21.73216248], [89.05198669, 21.73188972], [89.0525589, 21.73169136], [89.05305481, 21.73142242], [89.05391693, 21.73101616], [89.05413055, 21.7308197], [89.0545578, 21.73055077], [89.05471802, 21.73040009], [89.05535126, 21.7301445], [89.05583191, 21.72993279], [89.05597687, 21.72982025], [89.05648804, 21.72948074], [89.05677795, 21.72928238], [89.05727386, 21.72874451], [89.05763245, 21.72861099], [89.05921173, 21.72680092], [89.0592804, 21.72591972], [89.05870819, 21.72571754], [89.05834961, 21.72524071], [89.05820465, 21.72511482], [89.05813599, 21.72484589], [89.05805969, 21.72463989], [89.05797577, 21.7246151], [89.05741882, 21.72444153], [89.05684662, 21.72423935], [89.05648804, 21.72410965], [89.05597687, 21.72404099], [89.05570221, 21.72397041], [89.05484009, 21.72404099], [89.05419922, 21.72397041], [89.0539093, 21.72389984], [89.05348206, 21.72376633], [89.05326843, 21.72363091], [89.05258942, 21.723526], [89.0522995, 21.72346115], [89.05150604, 21.72346115], [89.05072784, 21.72339058], [89.05047607, 21.72339058], [89.04929352, 21.72339058], [89.04886627, 21.72332382], [89.04829407, 21.72319031], [89.04779053, 21.72311974], [89.04621887, 21.72312164], [89.04572296, 21.72319031], [89.04535675, 21.72319031], [89.04471588, 21.72326088], [89.0440979, 21.72305107], [89.04331207, 21.72293282], [89.04037476, 21.72293282], [89.03958893, 21.72286606], [89.03923035, 21.72286987], [89.03807831, 21.72273064], [89.03765106, 21.72260094], [89.03687286, 21.72232819], [89.03600311, 21.72191811], [89.03575897, 21.72195244], [89.03533173, 21.72175026], [89.03497314, 21.72162056], [89.0344696, 21.72141075], [89.03382874, 21.72134781], [89.0324707, 21.72134781], [89.03196716, 21.72148132], [89.03167725, 21.72147942], [89.03125, 21.7217598], [89.03103638, 21.72208977], [89.03082275, 21.72255707], [89.03060913, 21.72309113], [89.03022003, 21.72355843], [89.02998352, 21.72384644], [89.02951813, 21.72442436], [89.02932739, 21.72408676], [89.02996826, 21.7228508], [89.03083801, 21.72126579], [89.03090668, 21.72092056], [89.03061676, 21.72076035], [89.0302124, 21.72055244], [89.02973175, 21.72029114], [89.02922058, 21.7200737], [89.02870941, 21.71992874], [89.02831268, 21.71970749], [89.02799988, 21.71950912], [89.02768707, 21.71935081], [89.02741241, 21.71915817], [89.02709961, 21.71898651], [89.02662659, 21.71889877], [89.02610016, 21.71883011], [89.02559662, 21.71867943], [89.02510071, 21.7186203], [89.02456665, 21.71856117], [89.02404785, 21.71834183], [89.02349854, 21.71812057], [89.02288055, 21.71799088], [89.02231598, 21.71779251], [89.02179718, 21.71763039], [89.02130127, 21.71747017], [89.02088165, 21.71725082], [89.02053833, 21.71725082], [89.02025604, 21.71731186], [89.01953888, 21.71742821], [89.01911926, 21.71742058], [89.01796722, 21.71767044], [89.01741028, 21.71777916], [89.01725769, 21.71842194], [89.01734161, 21.71901512], [89.01724243, 21.71959114], [89.01714325, 21.72021294], [89.01698303, 21.72082138], [89.01715851, 21.7213707], [89.01729584, 21.72186089], [89.01735687, 21.72239876], [89.01737213, 21.72278976], [89.01737213, 21.72325516], [89.01741791, 21.72352028], [89.01745605, 21.72370911], [89.0175705, 21.7243042], [89.01772308, 21.72500038], [89.01766205, 21.72550964], [89.01792908, 21.72601128], [89.01805115, 21.72654915], [89.01786804, 21.72709656], [89.01764679, 21.72765923], [89.0174408, 21.72829247], [89.01746368, 21.72886658], [89.01737213, 21.72937965], [89.01727295, 21.72987175], [89.01712799, 21.73040009], [89.01692963, 21.73121071], [89.0165863, 21.73181725], [89.01637268, 21.73244286], [89.01605988, 21.73298073], [89.01572418, 21.73345566], [89.01538849, 21.7338829], [89.01503754, 21.7342701], [89.01465607, 21.73467064], [89.01422119, 21.73503304], [89.01377869, 21.73539352], [89.0133667, 21.73578072], [89.01304626, 21.73623085], [89.01275635, 21.73668098], [89.01243591, 21.73711967], [89.0120163, 21.73748207], [89.01154327, 21.7378006], [89.0111084, 21.73814964], [89.01069641, 21.73847961], [89.01035309, 21.73882103], [89.01002502, 21.73913574], [89.00971985, 21.73942947], [89.00943756, 21.73971558], [89.00914764, 21.73999977], [89.00884247, 21.74032021], [89.00849152, 21.74067116], [89.00810242, 21.74107552], [89.00772858, 21.74155426], [89.00728607, 21.74200058], [89.0068512, 21.74246979], [89.00637817, 21.7428894], [89.00589752, 21.74328041], [89.00550842, 21.74367905], [89.00522614, 21.74407005], [89.00509644, 21.74440956], [89.00496674, 21.74464035], [89.00482941, 21.74496651], [89.0046463, 21.74518013], [89.00435638, 21.74533081], [89.00393677, 21.74561882], [89.00382233, 21.74616432], [89.00364685, 21.74674988], [89.0031662, 21.74708748], [89.00284576, 21.74757957], [89.0027771, 21.74817848], [89.00245667, 21.74865913], [89.00216675, 21.74899101], [89.00191498, 21.74949837], [89.00157166, 21.75002098], [89.00139618, 21.75181007], [89.00125122, 21.75229073], [89.00106812, 21.75280762], [89.00094604, 21.75375938], [89.00097656, 21.75425529], [89.00102234, 21.75473022], [89.00110626, 21.75541878], [89.00102997, 21.75601006], [89.00089264, 21.75659752], [89.00086975, 21.75718117], [89.00080872, 21.75772858], [89.00067902, 21.75822067], [89.00058746, 21.75869179], [89.00054932, 21.75914955], [89.00048065, 21.75962067], [89.0, 21.7602787], [88.99973297, 21.76054955], [88.99972534, 21.76202583], [88.99958038, 21.76305389], [88.99950409, 21.76305389], [88.99958038, 21.76338959], [88.99973297, 21.76361084], [88.99973297, 21.76389122], [89.0, 21.76416588], [89.00047302, 21.76445007], [89.00102234, 21.76458931], [89.00167084, 21.76465416], [89.00229645, 21.76464081], [89.0029068, 21.76468658], [89.00348663, 21.76488113], [89.00405884, 21.76491547], [89.00461578, 21.76499176], [89.00478363, 21.76498604], [89.00511932, 21.7649765]]], [[[88.92710114, 21.76194954], [88.9276123, 21.76194382], [88.92816162, 21.76194954], [88.92874908, 21.76194954], [88.92936707, 21.76194954], [88.92999268, 21.76194954], [88.93061829, 21.76189995], [88.93112946, 21.76170349], [88.93122101, 21.76170158], [88.93250275, 21.76167107], [88.93276978, 21.76194954], [88.9338913, 21.76194954], [88.9338913, 21.76167107], [88.93416595, 21.76167107], [88.93444824, 21.76139069], [88.9347229, 21.76139069], [88.93499756, 21.76111031], [88.93611145, 21.76111031], [88.93638611, 21.76083183], [88.93638611, 21.76055527], [88.93723297, 21.7605629], [88.9375, 21.76028061], [88.9383316, 21.76028061], [88.93860626, 21.76000023], [88.93945313, 21.76000023], [88.93972015, 21.75972176], [88.94000244, 21.75972176], [88.9402771, 21.75944519], [88.94055176, 21.75945282], [88.94082642, 21.75917244], [88.94139099, 21.75917244], [88.94167328, 21.75889015], [88.9422226, 21.75889015], [88.94249725, 21.75861168], [88.94300842, 21.75859833], [88.94351196, 21.75852013], [88.9439621, 21.75836945], [88.94447327, 21.75831032], [88.94497681, 21.75810814], [88.94554138, 21.75805855], [88.94610596, 21.7580204], [88.94663239, 21.75782013], [88.94695282, 21.75749969], [88.94721985, 21.75777817], [88.94776917, 21.75777817], [88.94832611, 21.75722122], [88.9486084, 21.75722313], [88.94916534, 21.75666618], [88.94944763, 21.75666809], [88.95027924, 21.75582123], [88.95055389, 21.75583267], [88.95083618, 21.75555611], [88.95111084, 21.75555992], [88.95139313, 21.75527954], [88.95194244, 21.75527954], [88.9522171, 21.75500107], [88.95249939, 21.75500107], [88.95276642, 21.75472069], [88.95361328, 21.7547226], [88.95388794, 21.75444412], [88.95417023, 21.75444412], [88.95464325, 21.75434113], [88.95506287, 21.7542038], [88.95549011, 21.7541256], [88.95587921, 21.75399017], [88.95626831, 21.75390816], [88.95667267, 21.75389099], [88.95707703, 21.75387955], [88.9573822, 21.75387955], [88.9575119, 21.75387955], [88.95768738, 21.75388336], [88.95794678, 21.75389099], [88.95828247, 21.75388336], [88.95839691, 21.75388145], [88.95882416, 21.75384331], [88.95922089, 21.75370789], [88.95963287, 21.75362968], [88.96005249, 21.75361061], [88.96050262, 21.75360107], [88.96095276, 21.7535553], [88.96144104, 21.75337982], [88.96200562, 21.7532692], [88.96259308, 21.75304031], [88.9631958, 21.75275421], [88.96379089, 21.75239182], [88.96432495, 21.75196266], [88.9648056, 21.75152779], [88.96511078, 21.75102997], [88.96524048, 21.75047112], [88.965271, 21.74996376], [88.96525574, 21.74949646], [88.96521759, 21.74905968], [88.96520996, 21.74862099], [88.96513367, 21.74818802], [88.96504211, 21.74773979], [88.9650116, 21.74727058], [88.96500397, 21.74679375], [88.96499634, 21.74657822], [88.96498108, 21.74630165], [88.96492004, 21.74578285], [88.96482086, 21.74518967], [88.96487427, 21.74455452], [88.96496582, 21.74385071], [88.96507263, 21.74312019], [88.96528625, 21.74248123], [88.96555328, 21.74193001], [88.96581268, 21.74143028], [88.96609497, 21.74098969], [88.96642303, 21.74055099], [88.96679688, 21.74011993], [88.96729279, 21.73978424], [88.96784973, 21.73950958], [88.96840668, 21.73934364], [88.96889496, 21.73919868], [88.96936035, 21.73912048], [88.96982574, 21.7390461], [88.97029114, 21.73899269], [88.97071838, 21.7390995], [88.97110748, 21.73918724], [88.97145081, 21.73932457], [88.97180939, 21.73942184], [88.97219086, 21.73949623], [88.97257996, 21.73967171], [88.97303009, 21.7397728], [88.97343445, 21.73996925], [88.97386932, 21.74011993], [88.97426605, 21.74031258], [88.97464752, 21.74055862], [88.97502899, 21.74082947], [88.97545624, 21.74110031], [88.97595215, 21.74137688], [88.97622681, 21.74152184], [88.97648621, 21.74166107], [88.97704315, 21.74199486], [88.97754669, 21.74241066], [88.97809601, 21.74283981], [88.97861481, 21.74331093], [88.97918701, 21.74373245], [88.97978973, 21.74410057], [88.98042297, 21.74443054], [88.98104095, 21.74472618], [88.98165894, 21.74502373], [88.98225403, 21.74531364], [88.98284149, 21.74560165], [88.98317719, 21.74573517], [88.98344421, 21.74584007], [88.98404694, 21.7460537], [88.98469543, 21.74610138], [88.98531342, 21.7460537], [88.9858017, 21.7458477], [88.98623657, 21.74558067], [88.98668671, 21.7453289], [88.98712158, 21.74507141], [88.98748016, 21.74472046], [88.98774719, 21.74430084], [88.98793793, 21.74383163], [88.98803711, 21.74332047], [88.98803711, 21.7428112], [88.98797607, 21.74234009], [88.98782349, 21.74193954], [88.98768616, 21.74151039], [88.98749542, 21.74112892], [88.98722839, 21.74073982], [88.98697662, 21.74032021], [88.9866333, 21.73991966], [88.98620605, 21.73958015], [88.98574066, 21.73932076], [88.98535156, 21.7389698], [88.98500061, 21.73863983], [88.98457336, 21.73833084], [88.98416901, 21.73805428], [88.98378754, 21.7377758], [88.98342896, 21.7374897], [88.983078, 21.73719406], [88.98269653, 21.73688507], [88.98220825, 21.73660088], [88.98165894, 21.73633957], [88.98152161, 21.73627853], [88.98106384, 21.73606873], [88.98047638, 21.73582268], [88.97995758, 21.73555374], [88.97949982, 21.73527718], [88.97908783, 21.73500061], [88.97866821, 21.73474884], [88.97820282, 21.7345829], [88.97773743, 21.73442268], [88.97757721, 21.7343235], [88.97733307, 21.73417282], [88.97721863, 21.73417282], [88.97638702, 21.73333168], [88.97638702, 21.73250008], [88.97611237, 21.7322216], [88.97611237, 21.73166656], [88.97528076, 21.73082924], [88.97528076, 21.73055649], [88.97471619, 21.72999954], [88.97471619, 21.72972107], [88.97360992, 21.72861099], [88.97360992, 21.72833252], [88.97305298, 21.72777557], [88.97305298, 21.72750092], [88.97138977, 21.72583961], [88.97138977, 21.72556114], [88.97083282, 21.72500038], [88.97083282, 21.72472], [88.97027588, 21.72416687], [88.97027588, 21.7238903], [88.96971893, 21.72332954], [88.96971893, 21.72305489], [88.96944427, 21.72277832], [88.96943665, 21.72000122], [88.96971893, 21.71970749], [88.96971893, 21.7191658], [88.97000122, 21.71888924], [88.97000122, 21.71861076], [88.97027588, 21.71832848], [88.97027588, 21.71805573], [88.97055817, 21.71777916], [88.97055817, 21.71750069], [88.97222137, 21.71582985], [88.97222137, 21.71555519], [88.97249603, 21.71528053], [88.97277832, 21.71528053], [88.97389221, 21.71417046], [88.97416687, 21.71417046], [88.97471619, 21.7136097], [88.97499847, 21.7136116], [88.97528076, 21.71333313], [88.97555542, 21.71333313], [88.97583008, 21.71305656], [88.97611237, 21.71305656], [88.97721863, 21.71194649], [88.97750092, 21.71194649], [88.97805786, 21.71138954], [88.97888947, 21.71138954], [88.98055267, 21.70972061], [88.98083496, 21.70972252], [88.98139191, 21.70916748], [88.98166656, 21.70916939], [88.98332977, 21.70750046], [88.98332977, 21.70722008], [88.98361206, 21.70694351], [88.98361206, 21.70666695], [88.98387909, 21.70639038], [88.98332977, 21.70583153], [88.98274994, 21.70550156], [88.98219299, 21.70532227], [88.98163605, 21.70518684], [88.98114777, 21.70502281], [88.98066711, 21.70487022], [88.98020172, 21.70467949], [88.97975159, 21.70446014], [88.97928619, 21.70427322], [88.97883606, 21.70408058], [88.97869873, 21.70400429], [88.97840881, 21.70384598], [88.97801208, 21.70358086], [88.97763824, 21.70329285], [88.97727203, 21.70300293], [88.97689056, 21.70271111], [88.97651672, 21.70240021], [88.97619629, 21.7020607], [88.97590637, 21.70169258], [88.97560883, 21.7013607], [88.97528839, 21.70103073], [88.97502899, 21.70064545], [88.97476959, 21.70022964], [88.97452545, 21.69981194], [88.9741745, 21.69944], [88.97373962, 21.69909096], [88.97335052, 21.69885826], [88.97325134, 21.69880295], [88.97305298, 21.69861031], [88.97222137, 21.69861031], [88.97164917, 21.69917107], [88.97138977, 21.69916534], [88.97110748, 21.69944572], [88.97083282, 21.69944], [88.97027588, 21.70000076], [88.97000122, 21.70000076], [88.96943665, 21.70055962], [88.96916962, 21.70055962], [88.96861267, 21.70111084], [88.96833038, 21.70111084], [88.96806335, 21.70139122], [88.96778107, 21.70139122], [88.96749878, 21.70166969], [88.96722412, 21.70166779], [88.96694183, 21.70194435], [88.96194458, 21.70194435], [88.96166992, 21.70166779], [88.96083069, 21.70166969], [88.96029663, 21.70168686], [88.95987701, 21.70178032], [88.95947266, 21.70189095], [88.95903778, 21.70194054], [88.95861053, 21.70201111], [88.95819855, 21.70215988], [88.95774078, 21.70226479], [88.95726776, 21.70240021], [88.95677185, 21.70248795], [88.9562912, 21.70256042], [88.95584106, 21.70270729], [88.9553833, 21.7027626], [88.95493317, 21.70277023], [88.95445251, 21.70277977], [88.95397186, 21.70279312], [88.95349884, 21.70282745], [88.95323944, 21.70280838], [88.95304108, 21.70279503], [88.95259094, 21.70277977], [88.95214844, 21.7027607], [88.95168304, 21.70270729], [88.95120239, 21.70255089], [88.950737, 21.70246124], [88.95024109, 21.70232964], [88.94979095, 21.70251083], [88.94936371, 21.70278931], [88.94895935, 21.70315361], [88.94861603, 21.70360756], [88.94831848, 21.7041111], [88.94805908, 21.70416641], [88.94805908, 21.70444489], [88.9466629, 21.70583344], [88.94638824, 21.70583344], [88.94611359, 21.70611191], [88.9458313, 21.70611191], [88.94444275, 21.70750046], [88.94416809, 21.70750046], [88.94361115, 21.70806122], [88.94333649, 21.7080555], [88.9430542, 21.70833206], [88.94277954, 21.70833015], [88.94249725, 21.70861053], [88.9422226, 21.70861053], [88.9419632, 21.70889282], [88.94166565, 21.70888901], [88.9411087, 21.70944214], [88.94082642, 21.70944023], [88.9402771, 21.71000099], [88.94000244, 21.71000099], [88.93972015, 21.71027946], [88.93945313, 21.71027946], [88.93916321, 21.71055984], [88.93889618, 21.71055984], [88.93860626, 21.71084023], [88.9383316, 21.71084023], [88.93805695, 21.71111107], [88.93776703, 21.71111107], [88.93776703, 21.71138954], [88.9375, 21.71138954], [88.93694305, 21.71194649], [88.9366684, 21.71194077], [88.93611145, 21.71249962], [88.93583679, 21.71249962], [88.93499756, 21.71333313], [88.9347229, 21.71333122], [88.93416595, 21.71389961], [88.9338913, 21.71389961], [88.93360901, 21.71417046], [88.93305206, 21.71417046], [88.93276978, 21.71445084], [88.93250275, 21.71444511], [88.93222046, 21.71472168], [88.9319458, 21.71471977], [88.93138885, 21.71528053], [88.93110657, 21.71528053], [88.93083191, 21.71556091], [88.93055725, 21.71556091], [88.93000031, 21.71611023], [88.92973328, 21.71611023], [88.92944336, 21.71639061], [88.9291687, 21.71639061], [88.92888641, 21.71666908], [88.92861176, 21.71666718], [88.9283371, 21.71694374], [88.92805481, 21.71694374], [88.92778015, 21.71722221], [88.92749786, 21.7172184], [88.92722321, 21.71750069], [88.92694092, 21.71750069], [88.92666626, 21.71777916], [88.9263916, 21.71777916], [88.92610931, 21.71805954], [88.92582703, 21.71805954], [88.92527771, 21.71861076], [88.92500305, 21.71861076], [88.92472076, 21.71888924], [88.92444611, 21.71888924], [88.92415619, 21.71916962], [88.92388916, 21.7191658], [88.9236145, 21.71944427], [88.92333221, 21.71944427], [88.92305756, 21.71972275], [88.9227829, 21.71970749], [88.9227829, 21.72000122], [88.92250061, 21.72027779], [88.92250061, 21.7211113], [88.9227829, 21.72138977], [88.92277527, 21.72166634], [88.92305756, 21.7219429], [88.92321014, 21.72200012], [88.92338562, 21.72239876], [88.92362213, 21.72278214], [88.92391205, 21.72318268], [88.924263, 21.72361946], [88.92478943, 21.72412109], [88.92498016, 21.72445107], [88.9254303, 21.72524071], [88.92575073, 21.72582054], [88.92599487, 21.72638893], [88.92636108, 21.72679138], [88.92666626, 21.72724915], [88.92695618, 21.72777939], [88.92722321, 21.72835541], [88.92749786, 21.72898293], [88.92778015, 21.72962952], [88.92804718, 21.73027039], [88.92832947, 21.73084068], [88.92858124, 21.7313652], [88.92881012, 21.73184013], [88.92910004, 21.73222542], [88.92938232, 21.73260307], [88.92957306, 21.73304939], [88.92974091, 21.73348999], [88.9299469, 21.73387909], [88.93002319, 21.73426056], [88.93003845, 21.73443604], [88.93000031, 21.73472214], [88.93110657, 21.73583031], [88.93110657, 21.73639107], [88.93083191, 21.73639107], [88.93055725, 21.73666573], [88.93083191, 21.73694038], [88.93083191, 21.73806953], [88.93055725, 21.73805428], [88.93026733, 21.73833084], [88.93027496, 21.73916435], [88.93055725, 21.73944664], [88.93027496, 21.73944664], [88.93026733, 21.73971939], [88.93055725, 21.73999977], [88.93055725, 21.74139023], [88.93027496, 21.7416687], [88.93026733, 21.74221992], [88.93000031, 21.74250031], [88.93000031, 21.74388123], [88.92972565, 21.74416733], [88.92973328, 21.74500084], [88.92944336, 21.74527931], [88.92942047, 21.74584961], [88.92930603, 21.74625969], [88.92914581, 21.74669075], [88.92912292, 21.7471714], [88.92907715, 21.74771118], [88.9289093, 21.7483902], [88.92874146, 21.748909], [88.9285202, 21.74922943], [88.92835999, 21.74963951], [88.92825317, 21.75005913], [88.92808533, 21.7504425], [88.92798615, 21.75087166], [88.92784882, 21.75116348], [88.92780304, 21.75126076], [88.92762756, 21.75170135], [88.92747498, 21.75214767], [88.92727661, 21.75255966], [88.92717743, 21.7530365], [88.92732239, 21.75350952], [88.92726898, 21.75398827], [88.92720032, 21.7543602], [88.92708588, 21.75457764], [88.92693329, 21.7548008], [88.92672729, 21.75507927], [88.92655945, 21.7553997], [88.92650604, 21.75586128], [88.9264679, 21.75607109], [88.9262085, 21.75647163], [88.9261322, 21.75680923], [88.92560577, 21.75715828], [88.92533112, 21.75749969], [88.92501831, 21.75785065], [88.92467499, 21.75820732], [88.92427063, 21.75852966], [88.92390442, 21.75893784], [88.92353821, 21.75938416], [88.92311096, 21.75980949], [88.92273712, 21.76029968], [88.92235565, 21.76074982], [88.92224884, 21.76130295], [88.92237854, 21.7618618], [88.92282867, 21.76235008], [88.92343903, 21.76267815], [88.92408752, 21.7625103], [88.92468262, 21.76229286], [88.92523193, 21.76222801], [88.9257431, 21.76222038], [88.92621613, 21.76218033], [88.92663574, 21.76200485], [88.92710114, 21.76194954]]], [[[88.84490204, 21.61999893], [88.84432983, 21.61999893], [88.84375, 21.62002373], [88.84356689, 21.62006187], [88.84319305, 21.62014198], [88.84262085, 21.62030411], [88.84201813, 21.62049294], [88.84134674, 21.6204834], [88.84072113, 21.62044144], [88.84018707, 21.62042046], [88.83972168, 21.62044716], [88.83930969, 21.62054062], [88.83891296, 21.62068939], [88.83850098, 21.6208744], [88.83805847, 21.6210804], [88.83756256, 21.62126923], [88.83698273, 21.62144089], [88.83638, 21.62161064], [88.83583832, 21.62181854], [88.83533478, 21.62205124], [88.83487701, 21.62232018], [88.83439636, 21.62253952], [88.83393097, 21.6226902], [88.83345032, 21.62265396], [88.8330307, 21.62272072], [88.83264923, 21.62286949], [88.8323288, 21.62317085], [88.83183289, 21.62343025], [88.83127594, 21.62375069], [88.8306427, 21.62389946], [88.83006287, 21.62407112], [88.82959747, 21.62401962], [88.82919312, 21.62389946], [88.82878876, 21.62389755], [88.82840729, 21.62397194], [88.82804871, 21.62418938], [88.82772827, 21.6245327], [88.82748413, 21.62500763], [88.82720947, 21.62551308], [88.82688141, 21.62597466], [88.82641602, 21.62632179], [88.82583618, 21.62663078], [88.82525635, 21.62699127], [88.82466125, 21.6269207], [88.82420349, 21.62673187], [88.8237915, 21.6267395], [88.82338715, 21.62695122], [88.82277679, 21.62750053], [88.82195282, 21.62750053], [88.8216629, 21.62778282], [88.8208313, 21.62778282], [88.82055664, 21.62750053], [88.81999969, 21.62750053], [88.81973267, 21.62778282], [88.81944275, 21.62778282], [88.81861115, 21.62861061], [88.81777954, 21.62861061], [88.81749725, 21.62833023], [88.8172226, 21.62833214], [88.81685638, 21.62860107], [88.81645966, 21.62882042], [88.81598663, 21.62895966], [88.81552887, 21.62919807], [88.81510162, 21.62949753], [88.81474304, 21.62986946], [88.81439209, 21.6303215], [88.81401062, 21.6307106], [88.81362152, 21.63108635], [88.81325531, 21.63147736], [88.81292725, 21.63187981], [88.81257629, 21.63223076], [88.81225586, 21.63255882], [88.81201172, 21.6328907], [88.81185913, 21.63324928], [88.81166077, 21.63355064], [88.81143188, 21.63385582], [88.81122589, 21.63420486], [88.81105804, 21.63458061], [88.81083679, 21.63490105], [88.81066895, 21.63516808], [88.81054688, 21.63541985], [88.81043243, 21.63568115], [88.81030273, 21.63603973], [88.81022644, 21.63652992], [88.81005859, 21.63706017], [88.80977631, 21.63751793], [88.80937958, 21.63788986], [88.80906677, 21.63837051], [88.80889893, 21.63879013], [88.80885315, 21.63918114], [88.8088913, 21.6395607], [88.80899811, 21.63993263], [88.80919647, 21.6402607], [88.80944061, 21.64060974], [88.8097229, 21.64100647], [88.81001282, 21.64145279], [88.81033325, 21.64188957], [88.81064606, 21.64229965], [88.81095886, 21.64267921], [88.81112671, 21.6431179], [88.81130219, 21.64351082], [88.81153107, 21.6438694], [88.81183624, 21.64422989], [88.81217194, 21.64467812], [88.8125, 21.6451683], [88.81285858, 21.64563942], [88.8131485, 21.64606857], [88.81337738, 21.64641571], [88.81360626, 21.64668846], [88.81381226, 21.64698982], [88.81400299, 21.64733887], [88.81414795, 21.6475811], [88.81424713, 21.64774513], [88.81455994, 21.64817429], [88.81489563, 21.64863014], [88.81523132, 21.64912033], [88.81555939, 21.6496048], [88.81587219, 21.65003967], [88.81613922, 21.65044022], [88.81640625, 21.65077972], [88.81667328, 21.6511097], [88.81693268, 21.65148735], [88.81720734, 21.65193939], [88.81749725, 21.65248108], [88.81777954, 21.65306282], [88.81804657, 21.65364075], [88.81832123, 21.6541996], [88.81858826, 21.65468788], [88.81869507, 21.65485382], [88.81887817, 21.65513039], [88.81913757, 21.65557098], [88.81926727, 21.65606117], [88.81916809, 21.65611076], [88.81944275, 21.65638924], [88.81944275, 21.65666008], [88.82055664, 21.65777779], [88.82055664, 21.65833282], [88.8208313, 21.65860939], [88.8208313, 21.65888977], [88.82110596, 21.65917015], [88.82110596, 21.66028023], [88.82119751, 21.66065025], [88.82136536, 21.66107178], [88.82150269, 21.66152954], [88.8216629, 21.66167068], [88.8216629, 21.66278839], [88.82195282, 21.66305923], [88.82195282, 21.66389084], [88.82221985, 21.6641674], [88.82221985, 21.66443825], [88.82277679, 21.66500092], [88.82277679, 21.6697197], [88.82250214, 21.67000008], [88.82250214, 21.67055321], [88.82305908, 21.67111015], [88.82277679, 21.67138863], [88.82277679, 21.67165947], [88.82257843, 21.6721611], [88.82241821, 21.6725769], [88.82226563, 21.67298126], [88.82219696, 21.67337036], [88.82211304, 21.67371178], [88.82198334, 21.6740303], [88.82192993, 21.67436981], [88.82187653, 21.67469025], [88.8217926, 21.67502022], [88.82167053, 21.67533684], [88.82154083, 21.67569351], [88.82145691, 21.67612457], [88.82125092, 21.67657089], [88.82131195, 21.67699051], [88.82112885, 21.67731285], [88.82099152, 21.6776104], [88.82097626, 21.67783737], [88.82067108, 21.67806244], [88.82079315, 21.67855835], [88.820755, 21.67891312], [88.82048798, 21.6794796], [88.82060242, 21.67951965], [88.8200531, 21.68007278], [88.81975555, 21.68003082], [88.81971741, 21.68066406], [88.81965637, 21.68132973], [88.81944275, 21.68190956], [88.81920624, 21.68242264], [88.81916046, 21.68290901], [88.81910706, 21.68334007], [88.81891632, 21.68369102], [88.81881714, 21.68405724], [88.81865692, 21.68439293], [88.81858063, 21.68479156], [88.81845093, 21.68516922], [88.81835175, 21.68558121], [88.81829834, 21.68599892], [88.81813812, 21.6863308], [88.81806946, 21.68668938], [88.81804657, 21.68708992], [88.81800842, 21.68755341], [88.81782532, 21.68805313], [88.81777954, 21.68860054], [88.81777954, 21.68921089], [88.81777954, 21.68984032], [88.81777954, 21.69000053], [88.81777954, 21.69111061], [88.81749725, 21.69138908], [88.81749725, 21.69166756], [88.81777954, 21.6919384], [88.81777954, 21.69249916], [88.81804657, 21.6927681], [88.81804657, 21.69388962], [88.81833649, 21.69416618], [88.81833649, 21.6958313], [88.81861115, 21.69610977], [88.81861115, 21.69639015], [88.8188858, 21.69666672], [88.8188858, 21.69721985], [88.81861115, 21.69750023], [88.8188858, 21.6977787], [88.8188858, 21.69833565], [88.81915283, 21.6985817], [88.81916809, 21.69890022], [88.81944275, 21.69916534], [88.81944275, 21.70194435], [88.81916809, 21.70222282], [88.81916809, 21.7033329], [88.8188858, 21.70360756], [88.8188858, 21.70388985], [88.81861115, 21.70416641], [88.81861115, 21.7047081], [88.81833649, 21.70500183], [88.81833649, 21.7052803], [88.8180542, 21.70555496], [88.81804657, 21.70583153], [88.81749725, 21.70639038], [88.81749725, 21.70666695], [88.8172226, 21.70694351], [88.8172226, 21.70722008], [88.81694794, 21.70750046], [88.81694794, 21.70776939], [88.81582642, 21.70889282], [88.81582642, 21.70916939], [88.81500244, 21.71000099], [88.81443024, 21.71044922], [88.81387329, 21.71084595], [88.81333923, 21.7111702], [88.81285858, 21.71146965], [88.81244659, 21.71180344], [88.81200409, 21.71206284], [88.81163788, 21.71237946], [88.8116684, 21.71249962], [88.81138611, 21.71249962], [88.8105545, 21.71333313], [88.81027985, 21.71333122], [88.80944061, 21.71417046], [88.8088913, 21.71417046], [88.80860901, 21.71445084], [88.80833435, 21.71444511], [88.80805206, 21.71472168], [88.80722046, 21.71471977], [88.8069458, 21.71500015], [88.80639648, 21.71500015], [88.80583191, 21.71556091], [88.80555725, 21.71555519], [88.80526733, 21.71582985], [88.80500793, 21.71611977], [88.80473328, 21.71636009], [88.80438995, 21.71652985], [88.80399323, 21.71664047], [88.80356598, 21.71661949], [88.80311584, 21.71640968], [88.80259705, 21.71618843], [88.80197906, 21.71611977], [88.80132294, 21.71606255], [88.8007431, 21.71582985], [88.80014801, 21.71560097], [88.79950714, 21.71554947], [88.79886627, 21.71551895], [88.79827118, 21.71537018], [88.79769897, 21.71528816], [88.79714966, 21.715271], [88.79664612, 21.71519089], [88.7961731, 21.71489143], [88.79548645, 21.71492004], [88.7948761, 21.71474075], [88.79434204, 21.71453094], [88.79379272, 21.71443939], [88.79325867, 21.71435928], [88.79281616, 21.71421051], [88.79242706, 21.71406174], [88.79210663, 21.71380043], [88.79168701, 21.71360207], [88.79125977, 21.71340942], [88.79077148, 21.71329498], [88.79033661, 21.71310997], [88.78991699, 21.71290016], [88.78948212, 21.71274185], [88.78909302, 21.71251106], [88.78869629, 21.71228027], [88.78832245, 21.71200943], [88.78787231, 21.71190071], [88.78743744, 21.71168137], [88.78722382, 21.71194649], [88.78722382, 21.7116642], [88.78694153, 21.71138954], [88.78666687, 21.71138954], [88.78610992, 21.71084023], [88.7858429, 21.71084023], [88.78499603, 21.71000099], [88.78472137, 21.71027946], [88.78444672, 21.71027946], [88.78398895, 21.70998955], [88.78365326, 21.70976067], [88.78333282, 21.70950127], [88.78299713, 21.70920753], [88.78262329, 21.70889282], [88.7822113, 21.70853043], [88.78194427, 21.70861053], [88.78152466, 21.70819092], [88.78111267, 21.70776939], [88.78083038, 21.70777702], [88.78083038, 21.70750046], [88.78056335, 21.70722008], [88.78055573, 21.70694351], [88.78028107, 21.70666695], [88.77999878, 21.70667267], [88.77971649, 21.70639038], [88.77944183, 21.70639038], [88.77905273, 21.70609093], [88.77855682, 21.70575905], [88.77815247, 21.70536995], [88.77771759, 21.70501518], [88.77725983, 21.7047081], [88.77677917, 21.70443726], [88.77628326, 21.70413017], [88.77584076, 21.70375061], [88.77542114, 21.70337105], [88.77497101, 21.70305824], [88.77453613, 21.70277977], [88.77414703, 21.70249939], [88.77379608, 21.70219994], [88.77349854, 21.70183945], [88.77311707, 21.70146561], [88.77263641, 21.7010994], [88.77207184, 21.70072174], [88.77138519, 21.70045662], [88.7706604, 21.7002182], [88.76998901, 21.69993782], [88.76933289, 21.6996994], [88.76873779, 21.69947624], [88.76816559, 21.69936562], [88.76802826, 21.69931412], [88.76770782, 21.69919205], [88.76727295, 21.69910622], [88.76686096, 21.69902992], [88.76643372, 21.69904518], [88.76602173, 21.69908142], [88.76589966, 21.69903755], [88.76566315, 21.69894409], [88.76531982, 21.69894218], [88.76494598, 21.69912148], [88.764534, 21.69924355], [88.76409149, 21.69944954], [88.76358795, 21.6997509], [88.76307678, 21.70015907], [88.76264191, 21.70068932], [88.76251221, 21.70137024], [88.76249695, 21.70207977], [88.76254272, 21.70278931], [88.76277924, 21.70343018], [88.76309967, 21.70401573], [88.76357269, 21.70442009], [88.76405334, 21.70474052], [88.7644577, 21.70501518], [88.76480865, 21.7052803], [88.76515198, 21.70556259], [88.76553345, 21.70582581], [88.76596069, 21.70603943], [88.7664566, 21.70615768], [88.76689911, 21.70636368], [88.76735687, 21.70651817], [88.76780701, 21.70671082], [88.76821136, 21.70695114], [88.76860809, 21.70722389], [88.76901245, 21.70749474], [88.76945496, 21.70770264], [88.77004242, 21.70768738], [88.77054596, 21.70779991], [88.77099609, 21.70800018], [88.77145386, 21.70814514], [88.77186584, 21.70835876], [88.77226257, 21.70861053], [88.7726593, 21.70889282], [88.77305603, 21.70916939], [88.77346039, 21.70944023], [88.77388, 21.70969582], [88.7743454, 21.7099247], [88.77478027, 21.71022987], [88.77523804, 21.71052933], [88.77572632, 21.71076012], [88.77619171, 21.71096039], [88.77661896, 21.71121407], [88.77703094, 21.71149445], [88.77747345, 21.71170235], [88.77783966, 21.71194077], [88.77814484, 21.71218681], [88.77845001, 21.71240044], [88.77871704, 21.71264076], [88.77908325, 21.71287918], [88.77945709, 21.7132206], [88.77987671, 21.71363068], [88.78025818, 21.71409607], [88.78031921, 21.71419716], [88.78056335, 21.71458054], [88.78084564, 21.71499634], [88.78114319, 21.71533012], [88.7813797, 21.71565628], [88.78159332, 21.7159996], [88.7817688, 21.71638107], [88.78194427, 21.71676826], [88.78208923, 21.71718979], [88.78222656, 21.71767044], [88.78235626, 21.71820259], [88.78253174, 21.71877289], [88.78278351, 21.71936035], [88.78305817, 21.71997452], [88.7832489, 21.72062111], [88.78309631, 21.72129822], [88.78305817, 21.72200966], [88.78302765, 21.72266006], [88.78289795, 21.72322083], [88.78279114, 21.72375107], [88.78272247, 21.72426987], [88.78257751, 21.72460175], [88.78251648, 21.72475052], [88.78236389, 21.7252903], [88.78224182, 21.7258606], [88.7822113, 21.7264576], [88.78209686, 21.72702026], [88.78182983, 21.72752953], [88.78157806, 21.72805977], [88.78131866, 21.72859001], [88.78100586, 21.72910118], [88.78063965, 21.72953606], [88.78040314, 21.7300396], [88.78031921, 21.73057175], [88.78051758, 21.73106194], [88.7808609, 21.73149109], [88.78131104, 21.73186493], [88.78138733, 21.73193932], [88.78157043, 21.73212624], [88.78193665, 21.73250008], [88.7822113, 21.73250008], [88.78250122, 21.73278046], [88.78333282, 21.73278046], [88.78360748, 21.73306274], [88.78555298, 21.73305511], [88.78583527, 21.73333359], [88.78694153, 21.73333359], [88.78722382, 21.73361015], [88.78806305, 21.73361015], [88.78833008, 21.73389053], [88.78861237, 21.73389053], [88.78888702, 21.73417282], [88.78922272, 21.7341671], [88.78971863, 21.7341671], [88.78985596, 21.73430443], [88.79000092, 21.73444366], [88.79055786, 21.73444366], [88.79083252, 21.73472214], [88.79138947, 21.73472214], [88.79154205, 21.73488045], [88.79165649, 21.73500061], [88.79194641, 21.73500061], [88.79222107, 21.7352829], [88.79250336, 21.73527718], [88.79305267, 21.73583031], [88.79305267, 21.73639107], [88.79333496, 21.73666573], [88.79333496, 21.73694229], [88.79305267, 21.73722076], [88.79305267, 21.73777962], [88.79277802, 21.73806953], [88.79277802, 21.73861122], [88.79222107, 21.73861122], [88.79165649, 21.73917007], [88.79138947, 21.73916435], [88.79111481, 21.73944664], [88.79055786, 21.73944664], [88.79027557, 21.7397213], [88.78916931, 21.73971939], [88.78888702, 21.73999977], [88.78849792, 21.73999977], [88.78749847, 21.73999977], [88.78721619, 21.74028015], [88.78694153, 21.74027824], [88.78666687, 21.74055672], [88.78666687, 21.74083328], [88.78668213, 21.74117279], [88.78694153, 21.74159813], [88.78721619, 21.74202919], [88.78753662, 21.74241447], [88.78788757, 21.74274063], [88.78829193, 21.74303055], [88.78865051, 21.74339104], [88.78894806, 21.74380112], [88.78927612, 21.74415016], [88.7895813, 21.74446106], [88.78978729, 21.74477959], [88.78999329, 21.74504089], [88.79013824, 21.74532127], [88.79025269, 21.7456398], [88.79033661, 21.74603081], [88.79049683, 21.74643707], [88.79064178, 21.74691963], [88.79078674, 21.74743271], [88.79083252, 21.7479229], [88.79083252, 21.74805641], [88.79083252, 21.74860954], [88.79055786, 21.74888992], [88.79083252, 21.7491703], [88.79110718, 21.7491703], [88.79139709, 21.74888992], [88.79165649, 21.74888992], [88.79194641, 21.74860954], [88.79250336, 21.74861145], [88.79277802, 21.74833107], [88.79305267, 21.74833107], [88.79333496, 21.74805641], [88.79374695, 21.74797058], [88.79424286, 21.74778938], [88.79473877, 21.74764442], [88.79516602, 21.7474575], [88.79559326, 21.7473011], [88.79601288, 21.74723053], [88.79646301, 21.7472229], [88.79698944, 21.7471199], [88.79762268, 21.74703026], [88.79833221, 21.74706078], [88.79910278, 21.74710083], [88.79988861, 21.74710083], [88.80068207, 21.74708176], [88.80142975, 21.74699974], [88.80211639, 21.74700356], [88.80271149, 21.74697495], [88.80329895, 21.74699402], [88.80361176, 21.7472229], [88.80500031, 21.7472744], [88.80526733, 21.74749947], [88.80555725, 21.74749947], [88.80583191, 21.74777985], [88.80638885, 21.74777794], [88.80648041, 21.74787331], [88.80665588, 21.74806023], [88.8077774, 21.74805641], [88.80805206, 21.74833107], [88.8088913, 21.74833107], [88.80916595, 21.74861145], [88.80944061, 21.74860954], [88.8097229, 21.74888992], [88.80999756, 21.74888992], [88.81027985, 21.7491703], [88.81083679, 21.74916649], [88.811203, 21.74953842], [88.81138611, 21.74972153], [88.8116684, 21.74971962], [88.81223297, 21.74999046], [88.81282806, 21.75029945], [88.81339264, 21.75062943], [88.81388092, 21.75098991], [88.81436157, 21.75138092], [88.81484985, 21.75177574], [88.81536102, 21.75217056], [88.81586456, 21.75255775], [88.81630707, 21.75295258], [88.8167038, 21.75329971], [88.8170929, 21.75358963], [88.81742859, 21.75387764], [88.81774139, 21.75415993], [88.81804657, 21.75445747], [88.818367, 21.75476074], [88.81868744, 21.75505066], [88.81903076, 21.75530243], [88.81936646, 21.75556183], [88.81967926, 21.75583839], [88.81996918, 21.7561512], [88.82022858, 21.75647926], [88.82045746, 21.75683975], [88.8207016, 21.75721741], [88.820961, 21.75758171], [88.82125854, 21.7578907], [88.82161713, 21.7581501], [88.82193756, 21.75843048], [88.82224274, 21.75872993], [88.82254028, 21.75906944], [88.82285309, 21.75938988], [88.82316589, 21.75969124], [88.8234787, 21.75997734], [88.82377625, 21.76025963], [88.82408142, 21.76054955], [88.82440186, 21.76083183], [88.82472992, 21.76111984], [88.82507324, 21.76139069], [88.82541656, 21.76167107], [88.82575226, 21.76194763], [88.82610321, 21.76223946], [88.82645416, 21.76253891], [88.82686615, 21.76279068], [88.82730103, 21.76305008], [88.8277359, 21.76330948], [88.82813263, 21.76360321], [88.82850647, 21.76391029], [88.82888031, 21.76424026], [88.82926178, 21.76457024], [88.82970428, 21.76478958], [88.83016205, 21.76502037], [88.8306427, 21.76530075], [88.83110809, 21.76555443], [88.8312912, 21.76573753], [88.83167267, 21.76610947], [88.83194733, 21.7658329], [88.83277893, 21.7658329], [88.83305359, 21.76555443], [88.83416748, 21.76556015], [88.83444214, 21.76527977], [88.8347168, 21.76527977], [88.83499908, 21.76556015], [88.83528137, 21.76527977], [88.83583069, 21.76527977], [88.83611298, 21.76501083], [88.83777618, 21.76501083], [88.83805847, 21.76472092], [88.83944702, 21.76472473], [88.83972168, 21.76444435], [88.84055328, 21.76444435], [88.84083557, 21.76472473], [88.84111023, 21.76444435], [88.84139252, 21.76444435], [88.84166718, 21.76416588], [88.84388733, 21.76416969], [88.84416962, 21.76389122], [88.84555054, 21.76389122], [88.84583282, 21.76361084], [88.8466568, 21.76361084], [88.84694672, 21.76333046], [88.84750366, 21.76333237], [88.84777832, 21.7630558], [88.84971619, 21.76305962], [88.84999847, 21.76278114], [88.85166931, 21.76278114], [88.85193634, 21.76250076], [88.85250092, 21.76250076], [88.8527832, 21.76222038], [88.85388947, 21.76222229], [88.85416412, 21.76194382], [88.85444641, 21.76222229], [88.85500336, 21.76222229], [88.85527802, 21.76194382], [88.85639191, 21.76194954], [88.85666656, 21.76167107], [88.85721588, 21.76177979], [88.8576355, 21.76183319], [88.85806274, 21.76171112], [88.85848999, 21.76167107], [88.85891724, 21.76167107], [88.85935974, 21.76167107], [88.85980225, 21.76167107], [88.86023712, 21.76167107], [88.86068726, 21.76167107], [88.86115265, 21.76167107], [88.8616333, 21.76161957], [88.86165619, 21.76139069], [88.86222076, 21.76139069], [88.86250305, 21.76111031], [88.86277771, 21.76111031], [88.86305237, 21.76083183], [88.86332703, 21.76111031], [88.86361694, 21.76111031], [88.8638916, 21.76083374], [88.86416626, 21.76083374], [88.86499786, 21.76000023], [88.86499786, 21.75889015], [88.86528015, 21.75861168], [88.86528015, 21.75638962], [88.86499786, 21.75611115], [88.86499786, 21.75582123], [88.86472321, 21.75555611], [88.86472321, 21.75500107], [88.86444092, 21.75472069], [88.86444092, 21.75444412], [88.86416626, 21.75416756], [88.86416626, 21.75361061], [88.86332703, 21.75278091], [88.86332703, 21.75250053], [88.86305237, 21.75222015], [88.86305237, 21.75166512], [88.86250305, 21.75111008], [88.86250305, 21.75083351], [88.86222076, 21.75055313], [88.86222076, 21.75028038], [88.86165619, 21.74971962], [88.86138916, 21.74972153], [88.86055756, 21.74888802], [88.86000061, 21.74888992], [88.85916138, 21.74811363], [88.85861206, 21.74806023], [88.85832977, 21.74777985], [88.85806274, 21.74777985], [88.85778046, 21.74749947], [88.85749054, 21.74749947], [88.85582733, 21.74582863], [88.85583496, 21.74555588], [88.85555267, 21.7455616], [88.85527802, 21.74527931], [88.85500336, 21.74527931], [88.85500336, 21.74500084], [88.85333252, 21.74332809], [88.85305786, 21.74294472], [88.85276794, 21.74259567], [88.85246277, 21.74225998], [88.85211945, 21.74194145], [88.85179901, 21.74160957], [88.85153961, 21.74122047], [88.85128021, 21.74081993], [88.8510437, 21.74046898], [88.85077667, 21.74018288], [88.85057068, 21.73986053], [88.85040283, 21.73950958], [88.85027313, 21.7391243], [88.8501358, 21.73875427], [88.84999847, 21.73888969], [88.84944153, 21.73833084], [88.84944153, 21.73805428], [88.84916687, 21.73777962], [88.84916687, 21.73750114], [88.84889221, 21.73722076], [88.84889221, 21.73666573], [88.8483429, 21.73611069], [88.84812164, 21.73552322], [88.84780121, 21.73497581], [88.84749603, 21.73439026], [88.847229, 21.73382187], [88.84697723, 21.73330116], [88.84682465, 21.73282051], [88.84667206, 21.73250008], [88.84662628, 21.73241043], [88.84638977, 21.7322216], [88.84638977, 21.73194504], [88.84583282, 21.73138809], [88.84583282, 21.73110962], [88.84555817, 21.73083305], [88.84555817, 21.73055649], [88.84527588, 21.73027992], [88.84527588, 21.72972107], [88.84500122, 21.7294445], [88.84500122, 21.72916794], [88.84471893, 21.72887993], [88.84471893, 21.72750092], [88.84443665, 21.72722054], [88.84444427, 21.72694588], [88.84416962, 21.7266674], [88.84416962, 21.72639084], [88.84388733, 21.72611046], [88.84388733, 21.72556114], [88.84361267, 21.72528076], [88.8436203, 21.72470284], [88.84388733, 21.72444344], [88.84388733, 21.72417068], [88.84333038, 21.72360992], [88.84333038, 21.72333336], [88.84292603, 21.72292328], [88.84278107, 21.72277832], [88.84278107, 21.72256279], [88.84278107, 21.72222137], [88.84249878, 21.72194481], [88.84249878, 21.7211113], [88.84222412, 21.72083282], [88.84222412, 21.71999931], [88.84194183, 21.71970749], [88.84194183, 21.71888924], [88.84139252, 21.71832848], [88.84139252, 21.71805573], [88.84111023, 21.71777916], [88.84111023, 21.71750069], [88.8408432, 21.7172184], [88.84083557, 21.71694374], [88.84027863, 21.7163887], [88.84027863, 21.71583366], [88.83999634, 21.71555519], [88.83999634, 21.71445084], [88.83972168, 21.71417046], [88.83972168, 21.71389961], [88.83999634, 21.7136097], [88.83999634, 21.70888901], [88.83972168, 21.70861053], [88.83972168, 21.70806122], [88.83944702, 21.70776939], [88.83944702, 21.70722008], [88.83916473, 21.70694351], [88.8391571, 21.70667267], [88.83972168, 21.70611191], [88.83972168, 21.70583344], [88.83999634, 21.70555496], [88.83999634, 21.70500183], [88.84012604, 21.7046299], [88.84055328, 21.70444489], [88.84027863, 21.70416641], [88.84027863, 21.70388985], [88.83972168, 21.70332909], [88.83972168, 21.70277977], [88.84027863, 21.70222092], [88.84027863, 21.70166779], [88.84055328, 21.70139122], [88.84055328, 21.69972038], [88.84083557, 21.69944572], [88.84055328, 21.69916534], [88.84055328, 21.69721985], [88.84083557, 21.69694328], [88.8408432, 21.69639015], [88.84055328, 21.69610977], [88.84055328, 21.69527817], [88.84027863, 21.69499969], [88.84027863, 21.69388962], [88.84055328, 21.69361115], [88.84055328, 21.69333267], [88.84083557, 21.69305611], [88.8408432, 21.69222069], [88.84111023, 21.69194412], [88.84111023, 21.69000053], [88.8408432, 21.68972969], [88.8408432, 21.68861008], [88.84111023, 21.68833351], [88.84111023, 21.68805695], [88.84139252, 21.68778038], [88.84139252, 21.68695831], [88.84166718, 21.6866703], [88.84166718, 21.68472099], [88.84194183, 21.68444633], [88.84194183, 21.68361092], [88.84222412, 21.68333244], [88.84222412, 21.6827774], [88.84250641, 21.68250084], [88.84249878, 21.68222237], [88.84222412, 21.68194389], [88.84222412, 21.68111038], [88.84250641, 21.68083191], [88.84249878, 21.68055534], [88.84333038, 21.67972183], [88.84366608, 21.67928314], [88.84361267, 21.67916679], [88.84388733, 21.67889023], [88.84388733, 21.67778969], [88.84443665, 21.67721748], [88.84444427, 21.67694473], [88.84500122, 21.67638969], [88.84500122, 21.67555809], [88.84527588, 21.67527962], [88.84527588, 21.67444038], [88.84555817, 21.67416763], [88.84555054, 21.67389107], [88.84610748, 21.67333031], [88.84610748, 21.67305756], [88.84638977, 21.67278099], [88.84638977, 21.67193985], [88.84694672, 21.67138863], [88.84694672, 21.67111015], [88.84722137, 21.67083549], [88.84722137, 21.67000008], [88.84805298, 21.66917038], [88.84805298, 21.66860008], [88.84833527, 21.66833115], [88.84833527, 21.66805649], [88.84860992, 21.66777992], [88.84860992, 21.66749954], [88.84889221, 21.66722107], [88.84889221, 21.66610909], [88.84916687, 21.66583061], [88.84916687, 21.66527748], [88.85028076, 21.66416931], [88.8503418, 21.66385078], [88.85054016, 21.66352081], [88.85072327, 21.66316986], [88.85092163, 21.66280174], [88.85116577, 21.66243553], [88.85140228, 21.66202927], [88.85164642, 21.66160965], [88.85190582, 21.66114044], [88.85217285, 21.66061974], [88.85247803, 21.66009331], [88.85276794, 21.65955544], [88.8530426, 21.65907288], [88.85328674, 21.6586628], [88.853508, 21.65834236], [88.85370636, 21.65806961], [88.85388947, 21.65782356], [88.85407257, 21.65757561], [88.85418701, 21.65727043], [88.85431671, 21.65694046], [88.8544693, 21.65658951], [88.85466766, 21.65621758], [88.85489655, 21.65578079], [88.85444641, 21.65528107], [88.85472107, 21.65500069], [88.85472107, 21.65472031], [88.85527802, 21.65416718], [88.85555267, 21.6541729], [88.85573578, 21.65363121], [88.85588837, 21.65320015], [88.85610199, 21.65284157], [88.85629272, 21.65248108], [88.85644531, 21.65212631], [88.85663605, 21.65183067], [88.85681152, 21.65149117], [88.85691071, 21.65108109], [88.85694122, 21.65061188], [88.85695648, 21.6501255], [88.85701752, 21.64966965], [88.85723114, 21.6493187], [88.85749054, 21.64899063], [88.85774231, 21.64863968], [88.85793304, 21.64826012], [88.85809326, 21.64783096], [88.85822296, 21.6473999], [88.85835266, 21.64694786], [88.85851288, 21.64647102], [88.85873413, 21.64598656], [88.85897064, 21.64545059], [88.85919189, 21.6448307], [88.85945129, 21.64421272], [88.85972595, 21.64361], [88.85993958, 21.64306641], [88.86000061, 21.64255905], [88.86001587, 21.6421299], [88.86009979, 21.64175987], [88.86026001, 21.64139938], [88.8604126, 21.64094734], [88.86052704, 21.64036942], [88.86054993, 21.6396904], [88.86049652, 21.63898087], [88.8602829, 21.6383419], [88.86006927, 21.63776207], [88.85995483, 21.6372261], [88.85975647, 21.63683128], [88.85952759, 21.6364994], [88.85922241, 21.63624001], [88.8589325, 21.63595009], [88.85868835, 21.63562012], [88.8584671, 21.63528061], [88.85829163, 21.63498116], [88.85807037, 21.63471985], [88.85785675, 21.63442993], [88.85765076, 21.63409042], [88.85739899, 21.63365364], [88.85707855, 21.63321686], [88.85666656, 21.63284111], [88.85623932, 21.63246155], [88.85585022, 21.63204193], [88.85549927, 21.63162041], [88.85514069, 21.63124084], [88.85482025, 21.63084984], [88.85450745, 21.63047981], [88.85423279, 21.63006973], [88.85392761, 21.62965012], [88.8536377, 21.62919807], [88.85334015, 21.62877083], [88.85305786, 21.62838936], [88.85279846, 21.62808037], [88.85256195, 21.62781906], [88.85237885, 21.62751007], [88.85217285, 21.62722015], [88.85189056, 21.62694168], [88.8515625, 21.62668037], [88.85116577, 21.62646294], [88.85069275, 21.62646294], [88.85033417, 21.62663841], [88.84999847, 21.62694168], [88.84999847, 21.62750053], [88.84889221, 21.62861061], [88.84889221, 21.62916756], [88.84860992, 21.62944221], [88.84860992, 21.62972069], [88.8483429, 21.63000107], [88.84749603, 21.63000107], [88.84726715, 21.62976837], [88.84666443, 21.6297226], [88.84610748, 21.62916756], [88.84610748, 21.6288929], [88.8466568, 21.62833023], [88.84666443, 21.62750053], [88.84694672, 21.62722015], [88.84638977, 21.62666702], [88.84606934, 21.62672043], [88.84552765, 21.62688065], [88.84506226, 21.62692833], [88.84461975, 21.62695122], [88.84420013, 21.62699509], [88.84383392, 21.62717247], [88.84349823, 21.62738991], [88.84333038, 21.62750053], [88.84305573, 21.6277771], [88.84305573, 21.62944221], [88.84278107, 21.62972069], [88.84278107, 21.63138962], [88.84306335, 21.63167], [88.84305573, 21.63277817], [88.84333038, 21.63305664], [88.84333038, 21.63332939], [88.84336853, 21.63376045], [88.84333038, 21.63389015], [88.84361267, 21.63417053], [88.84361267, 21.63611031], [88.84388733, 21.63639069], [88.84388733, 21.63750076], [88.84416962, 21.63777733], [88.84416962, 21.63832855], [88.84444427, 21.63861084], [88.84443665, 21.64110947], [88.84416962, 21.64138794], [88.84416962, 21.64194489], [88.84388733, 21.64221954], [88.84388733, 21.64305305], [88.84361267, 21.64333344], [88.84361267, 21.64361], [88.84333038, 21.64389038], [88.84333038, 21.64416695], [88.84305573, 21.64444351], [88.84306335, 21.64472008], [88.84278107, 21.64500046], [88.84278107, 21.64528084], [88.84223175, 21.64560699], [88.84181976, 21.6460743], [88.84139252, 21.64649963], [88.84113312, 21.64670181], [88.84094238, 21.64683533], [88.84083557, 21.64694595], [88.84055328, 21.64694023], [88.83999634, 21.64750099], [88.83972168, 21.64750099], [88.83944702, 21.64777946], [88.8391571, 21.64777946], [88.83889008, 21.64805984], [88.83860779, 21.64805984], [88.83805847, 21.64861107], [88.83777618, 21.64861107], [88.83757019, 21.64882088], [88.83718109, 21.64897156], [88.8367691, 21.64912033], [88.83631897, 21.6492424], [88.83585358, 21.64939117], [88.83532715, 21.64950943], [88.83479309, 21.6496582], [88.83472443, 21.64944458], [88.83444214, 21.64972305], [88.83416748, 21.64972305], [88.83389282, 21.64999962], [88.83361053, 21.64999962], [88.83333588, 21.65027809], [88.83222198, 21.65027809], [88.83139038, 21.6511116], [88.83110809, 21.6511097], [88.83056641, 21.65195274], [88.83000183, 21.65195274], [88.82971954, 21.65167236], [88.82971954, 21.65138817], [88.82917023, 21.65083122], [88.82888794, 21.65083313], [88.82861328, 21.65055466], [88.82917023, 21.64999962], [88.82971954, 21.64999962], [88.83000183, 21.65027809], [88.83027649, 21.65027809], [88.83056641, 21.64999962], [88.83083344, 21.64999962], [88.83139038, 21.64944077], [88.83166504, 21.64944458], [88.83194733, 21.64916611], [88.83222198, 21.64916992], [88.83249664, 21.64888954], [88.83280182, 21.64882088], [88.83322144, 21.64860725], [88.83362579, 21.64838982], [88.83409882, 21.64825058], [88.83454895, 21.6480999], [88.83502197, 21.64797974], [88.83547974, 21.64782906], [88.83598328, 21.64772034], [88.83647919, 21.64755058], [88.83702087, 21.64743805], [88.83756256, 21.64726067], [88.83809662, 21.64712524], [88.83856201, 21.64692116], [88.83898163, 21.64664268], [88.83938599, 21.64632034], [88.83978271, 21.64595985], [88.84020233, 21.64562416], [88.84063721, 21.64529037], [88.84105682, 21.64493942], [88.84140015, 21.64452553], [88.84171295, 21.64410973], [88.84196472, 21.64370346], [88.84218597, 21.64333344], [88.84233093, 21.64297676], [88.84247589, 21.64266014], [88.84261322, 21.64232826], [88.84274292, 21.64198112], [88.84281921, 21.64156914], [88.8429184, 21.64114952], [88.84301758, 21.64072418], [88.8430481, 21.64026642], [88.84306335, 21.63978958], [88.8430481, 21.63932228], [88.84298706, 21.63886452], [88.8428421, 21.63844872], [88.84269714, 21.63797951], [88.84255981, 21.63747978], [88.84250641, 21.63696289], [88.84243774, 21.63646126], [88.84227753, 21.63602066], [88.84216309, 21.63553047], [88.84200287, 21.63504028], [88.84191895, 21.63452911], [88.84179688, 21.63404846], [88.84163666, 21.63360023], [88.84151459, 21.6331749], [88.84159851, 21.63273621], [88.84159088, 21.63228035], [88.84141541, 21.63180923], [88.84124756, 21.63124084], [88.84130859, 21.63055038], [88.84137726, 21.62984085], [88.84143829, 21.62914085], [88.84159088, 21.62850189], [88.84174347, 21.62787628], [88.84201813, 21.62735939], [88.84234619, 21.6269207], [88.84269714, 21.62648964], [88.84306335, 21.62611008], [88.84340668, 21.62574005], [88.84374237, 21.62535095], [88.8441391, 21.62502289], [88.84455872, 21.62473106], [88.8449707, 21.62445068], [88.84542084, 21.6241684], [88.84583282, 21.62388992], [88.8460083, 21.62371254], [88.84638977, 21.62333298], [88.84638977, 21.6222229], [88.84666443, 21.62194443], [88.84666443, 21.62138939], [88.84694672, 21.62111092], [88.84583282, 21.62000084], [88.84532166, 21.62000275], [88.84490204, 21.61999893]]], [[[88.36538696, 21.76416588], [88.36593628, 21.76415062], [88.36645508, 21.76407242], [88.36688232, 21.76392365], [88.36728668, 21.76391029], [88.3677063, 21.76403046], [88.36818695, 21.76415062], [88.36868286, 21.7639904], [88.36915588, 21.76363945], [88.37001038, 21.76362038], [88.37041473, 21.76362038], [88.37082672, 21.76361084], [88.3710022, 21.76324081], [88.37094879, 21.76266479], [88.37088776, 21.762043], [88.37086487, 21.76143646], [88.37082672, 21.76081848], [88.37069702, 21.76021194], [88.3704071, 21.75967407], [88.37001038, 21.75917244], [88.36951447, 21.75871277], [88.36901093, 21.75827408], [88.36854553, 21.75784302], [88.3680954, 21.75748062], [88.36760712, 21.75728035], [88.36712646, 21.75715828], [88.366745, 21.75697327], [88.36643982, 21.75671005], [88.36620331, 21.75638008], [88.36605072, 21.75598907], [88.36589813, 21.75562096], [88.36579132, 21.75523186], [88.36563873, 21.75482941], [88.36553192, 21.75437546], [88.36538696, 21.75389099], [88.36525726, 21.75328827], [88.36504364, 21.75271225], [88.36476135, 21.75216103], [88.36438751, 21.75165558], [88.36390686, 21.75123024], [88.36340332, 21.75086021], [88.36292267, 21.75052071], [88.36248016, 21.75020409], [88.36207581, 21.74985123], [88.36171722, 21.74945068], [88.36136627, 21.7490406], [88.36109924, 21.74860191], [88.36080933, 21.748209], [88.36052704, 21.74778938], [88.36023712, 21.74735069], [88.36001587, 21.74678993], [88.35980988, 21.74620056], [88.35974884, 21.74562073], [88.35975647, 21.74514008], [88.3598175, 21.74477005], [88.35990143, 21.74447823], [88.3599472, 21.74416924], [88.36000824, 21.74386406], [88.36009216, 21.74352074], [88.3602066, 21.74315262], [88.36032104, 21.74274445], [88.36045837, 21.74233055], [88.36058807, 21.74187088], [88.3607254, 21.74139977], [88.36078644, 21.74086189], [88.36079407, 21.74029541], [88.36074829, 21.73973083], [88.36062622, 21.73918915], [88.36054993, 21.73863983], [88.36045837, 21.73813629], [88.36032867, 21.7376709], [88.36019897, 21.73721695], [88.36006165, 21.73676109], [88.3599472, 21.73628044], [88.3598175, 21.73580933], [88.35971832, 21.73531914], [88.35967255, 21.73488045], [88.35968781, 21.73450089], [88.35977936, 21.73417282], [88.3599472, 21.73385811], [88.36012268, 21.73348045], [88.3603363, 21.73304939], [88.36064148, 21.7326107], [88.36104584, 21.73223114], [88.36149597, 21.73191071], [88.36197662, 21.73163223], [88.36247253, 21.7313652], [88.36293793, 21.73122978], [88.36338043, 21.73081779], [88.36374664, 21.73036957], [88.36432648, 21.72982979], [88.36417389, 21.72888947], [88.3638916, 21.72777557], [88.36387634, 21.72694016], [88.36416626, 21.7266674], [88.36416626, 21.72500038], [88.36444092, 21.72472], [88.36444092, 21.72416687], [88.36472321, 21.7238903], [88.36472321, 21.72332954], [88.36499786, 21.72305489], [88.36499786, 21.72277832], [88.36528015, 21.72249985], [88.36528015, 21.72221947], [88.3658371, 21.72166634], [88.36611176, 21.72167015], [88.36638641, 21.72138977], [88.3666687, 21.72138977], [88.36805725, 21.72000122], [88.36833191, 21.72000122], [88.3694458, 21.71888924], [88.3694458, 21.71861076], [88.37001038, 21.71916962], [88.3702774, 21.71916962], [88.37055206, 21.71888924], [88.37082672, 21.71888924], [88.37110901, 21.71861076], [88.3713913, 21.71861076], [88.37166595, 21.71832848], [88.37194824, 21.7183342], [88.3722229, 21.71805573], [88.37249756, 21.71805954], [88.37275696, 21.71783066], [88.37328339, 21.71777916], [88.37384033, 21.71777916], [88.37445068, 21.71777725], [88.37506104, 21.71777916], [88.37565613, 21.71783066], [88.37623596, 21.71786118], [88.37671661, 21.71762085], [88.37722015, 21.71751404], [88.37774658, 21.71753883], [88.37824249, 21.71772957], [88.37876129, 21.71777916], [88.37927246, 21.71777916], [88.37980652, 21.71777916], [88.38038635, 21.71783066], [88.38098145, 21.71799088], [88.38162231, 21.7180481], [88.3822403, 21.71805763], [88.38276672, 21.71812057], [88.38320923, 21.71842957], [88.38379669, 21.71858025], [88.3841629, 21.71860123], [88.38439941, 21.71861076], [88.38694763, 21.71861076], [88.38722229, 21.71888924], [88.38833618, 21.71888924], [88.38861084, 21.71861076], [88.38889313, 21.71861076], [88.38916779, 21.7183342], [88.39083099, 21.7183342], [88.39111328, 21.71805573], [88.39250183, 21.71805954], [88.39305878, 21.71750069], [88.39389038, 21.71750069], [88.39444733, 21.71693993], [88.39444733, 21.71666718], [88.39472198, 21.71666908], [88.39554596, 21.71582985], [88.39583588, 21.71583366], [88.39638519, 21.71555519], [88.39666748, 21.71528053], [88.3972168, 21.71528053], [88.39749908, 21.71500015], [88.3972168, 21.71471977], [88.39722443, 21.71444511], [88.39749908, 21.71417046], [88.39805603, 21.7136097], [88.39805603, 21.71333313], [88.39638519, 21.7116642], [88.39639282, 21.71111107], [88.39499664, 21.70972252], [88.39499664, 21.70944214], [88.39472198, 21.70916748], [88.39472198, 21.70861053], [88.3941803, 21.70806122], [88.39389038, 21.70833206], [88.39360809, 21.70833206], [88.39338684, 21.70811081], [88.39305878, 21.70777702], [88.39305878, 21.70722008], [88.39265442, 21.70684624], [88.39234161, 21.70639038], [88.39202118, 21.70593071], [88.39160919, 21.70555878], [88.39116669, 21.70519829], [88.39074707, 21.70478821], [88.39028168, 21.70445442], [88.38976288, 21.70416641], [88.38926697, 21.70388031], [88.38891602, 21.70358086], [88.38861084, 21.70332909], [88.38861084, 21.70277977], [88.38833618, 21.70249939], [88.38722229, 21.70249939], [88.38694763, 21.70222092], [88.38694763, 21.70194435], [88.38666534, 21.70194435], [88.38527679, 21.70055771], [88.38471985, 21.70055962], [88.38453674, 21.70055962], [88.38388824, 21.70028114], [88.38327026, 21.69996071], [88.38273621, 21.69957161], [88.38219452, 21.69931793], [88.38147736, 21.69934464], [88.38092804, 21.69925117], [88.38046265, 21.69910812], [88.38004303, 21.69888115], [88.37962341, 21.69864082], [88.37917328, 21.6984005], [88.37889099, 21.69833565], [88.3786087, 21.69805336], [88.37832642, 21.69806099], [88.37805176, 21.69778061], [88.3777771, 21.69778061], [88.37750244, 21.69750023], [88.37722015, 21.69750023], [88.37695313, 21.69721985], [88.37666321, 21.69722176], [88.37541199, 21.69624519], [88.37526703, 21.69610977], [88.375, 21.6958313], [88.37472534, 21.6958313], [88.3741684, 21.69527817], [88.37304688, 21.69528008], [88.37258911, 21.69481659], [88.37249756, 21.69472122], [88.37249756, 21.69444466], [88.3722229, 21.69416618], [88.37194824, 21.69417191], [88.37166595, 21.69388962], [88.3713913, 21.69388962], [88.37110901, 21.69361115], [88.37055206, 21.69361115], [88.3702774, 21.69333267], [88.36972046, 21.69333267], [88.3694458, 21.69305611], [88.36915588, 21.69306183], [88.36888885, 21.69277763], [88.36833191, 21.69333267], [88.36776733, 21.69333267], [88.36750031, 21.69361115], [88.36723328, 21.69333267], [88.36694336, 21.69333267], [88.36638641, 21.69277763], [88.36611176, 21.69277763], [88.36611176, 21.69166756], [88.3658371, 21.69138908], [88.36611176, 21.69111061], [88.36611176, 21.68943977], [88.3658371, 21.68916893], [88.3658371, 21.6883297], [88.36555481, 21.68805695], [88.36554718, 21.68721962], [88.36499786, 21.68666458], [88.36473083, 21.68671036], [88.3644104, 21.68672943], [88.36416626, 21.6866703], [88.36416626, 21.68694687], [88.3638916, 21.68722153], [88.36333466, 21.68722153], [88.36277771, 21.68666458], [88.36194611, 21.6866703], [88.36165619, 21.68638992], [88.36138916, 21.68638992], [88.36110687, 21.6866703], [88.36081696, 21.6866703], [88.36055756, 21.68638992], [88.3602829, 21.6866703], [88.36000061, 21.68666458], [88.35896301, 21.68693352], [88.35837555, 21.68691635], [88.35787964, 21.68681908], [88.35749054, 21.68697166], [88.35713959, 21.68721771], [88.35678864, 21.68747139], [88.35636139, 21.68772316], [88.355896, 21.68800163], [88.35542297, 21.68833351], [88.35527802, 21.68861198], [88.35500336, 21.68861008], [88.35444641, 21.68917084], [88.35416412, 21.68916893], [88.35388947, 21.68944359], [88.35333252, 21.68943977], [88.35221863, 21.69055939], [88.35194397, 21.69055557], [88.35028076, 21.69222069], [88.35028076, 21.69249916], [88.34999847, 21.6927681], [88.34983063, 21.69314575], [88.34979248, 21.69334984], [88.34970093, 21.69406128], [88.34958649, 21.69445992], [88.34921265, 21.69504929], [88.34874725, 21.69540977], [88.34848022, 21.69585991], [88.3482666, 21.69630241], [88.34799194, 21.69667053], [88.34770203, 21.6970253], [88.34744263, 21.69742393], [88.34715271, 21.69778061], [88.34685516, 21.69815636], [88.34660339, 21.69854355], [88.34629822, 21.69887161], [88.34594727, 21.69917107], [88.34561157, 21.69948959], [88.3453064, 21.69985199], [88.345047, 21.70026016], [88.34474182, 21.70067024], [88.34443665, 21.70111084], [88.34443665, 21.70139122], [88.34416962, 21.70138931], [88.34333038, 21.70222282], [88.34306335, 21.7028904], [88.34224701, 21.70388985], [88.34194183, 21.70444489], [88.34151459, 21.70472145], [88.34082031, 21.70541954], [88.33999634, 21.70555496], [88.33970642, 21.70583153], [88.33970642, 21.70639038], [88.33945465, 21.70662117], [88.33921051, 21.70682335], [88.33899689, 21.70709991], [88.33874512, 21.70739555], [88.33856201, 21.70779037], [88.33831024, 21.7081852], [88.33818054, 21.70866013], [88.33798218, 21.7090435], [88.33772278, 21.70936394], [88.33756256, 21.70976067], [88.33750916, 21.71024513], [88.33750916, 21.71076965], [88.33759308, 21.71132088], [88.33777618, 21.71186066], [88.33800507, 21.71237564], [88.33815765, 21.71295357], [88.33847046, 21.71344948], [88.33889008, 21.71390915], [88.33930969, 21.71437073], [88.33978271, 21.71469688], [88.34020233, 21.71494865], [88.34049225, 21.71525002], [88.3408432, 21.71533966], [88.34133911, 21.71574974], [88.34187317, 21.71594048], [88.34220886, 21.71623039], [88.34249115, 21.71648026], [88.34295654, 21.71652985], [88.34329987, 21.71664619], [88.34361267, 21.71678162], [88.34392548, 21.71696281], [88.34422302, 21.7172184], [88.34452057, 21.7175808], [88.34475708, 21.71809578], [88.34506226, 21.71858978], [88.3454895, 21.71897125], [88.34588623, 21.71937943], [88.34630585, 21.71973991], [88.34664917, 21.72007751], [88.34676361, 21.72019005], [88.34693909, 21.72036934], [88.34716034, 21.72061348], [88.34729767, 21.72087097], [88.34736633, 21.72118187], [88.34749603, 21.72138977], [88.34750366, 21.72166634], [88.34777832, 21.72194481], [88.34777832, 21.72305489], [88.34750366, 21.72333336], [88.34749603, 21.72360992], [88.34805298, 21.72416687], [88.34805298, 21.72472], [88.34889221, 21.72555351], [88.34889221, 21.72694588], [88.34860992, 21.72722054], [88.34860992, 21.72777939], [88.34754181, 21.73227119], [88.34675598, 21.73448944], [88.34610748, 21.73583031], [88.34555817, 21.73638916], [88.34555817, 21.73694229], [88.34527588, 21.73722076], [88.34527588, 21.73777962], [88.34500122, 21.73806953], [88.3452301, 21.73806763], [88.345047, 21.73859978], [88.34494781, 21.73917007], [88.34477234, 21.73964119], [88.3446579, 21.7401104], [88.34448242, 21.74052048], [88.34436798, 21.74097061], [88.34411621, 21.74135971], [88.34384918, 21.7417202], [88.34365845, 21.74213791], [88.34361267, 21.74263954], [88.34358215, 21.74315262], [88.34346771, 21.74363708], [88.34335327, 21.74415207], [88.34329987, 21.74469948], [88.34313202, 21.74522972], [88.34306335, 21.74581909], [88.34301758, 21.74641037], [88.34281921, 21.74697113], [88.34273529, 21.74757767], [88.34266663, 21.74817276], [88.34265137, 21.74847031], [88.34261322, 21.7490654], [88.34252167, 21.74956322], [88.34265137, 21.75003815], [88.34226227, 21.75065041], [88.34243774, 21.75126076], [88.34252167, 21.75192833], [88.34264374, 21.75256348], [88.34260559, 21.75320244], [88.34255981, 21.75386047], [88.3427887, 21.75439072], [88.34310913, 21.75484085], [88.34340668, 21.75528908], [88.34364319, 21.75576973], [88.34388733, 21.75618935], [88.34413147, 21.75655174], [88.34428406, 21.75691414], [88.34437561, 21.75706863], [88.34445953, 21.7572155], [88.34466553, 21.75746346], [88.34481812, 21.75774956], [88.34501648, 21.7580471], [88.34527588, 21.75835991], [88.34555054, 21.75876999], [88.34584045, 21.75925636], [88.34618378, 21.7597847], [88.34660339, 21.76029015], [88.34705353, 21.76081085], [88.34755707, 21.76128006], [88.34845734, 21.76165962], [88.34895325, 21.76183128], [88.34971619, 21.76218033], [88.35018921, 21.76256561], [88.35095215, 21.76304245], [88.35123444, 21.76334572], [88.35167694, 21.76367188], [88.35206604, 21.76399612], [88.35263062, 21.76402473], [88.35323334, 21.76399422], [88.35388947, 21.7641201], [88.35455322, 21.76416969], [88.35513306, 21.76416969], [88.35565948, 21.76416969], [88.35616302, 21.76416969], [88.35663605, 21.76413918], [88.35710144, 21.76402283], [88.35754395, 21.76398087], [88.35801697, 21.7641201], [88.3585434, 21.76416969], [88.35906982, 21.76416969], [88.35957336, 21.76416969], [88.36003876, 21.76416969], [88.36049652, 21.76416969], [88.36096954, 21.76416969], [88.3614502, 21.76416969], [88.36194611, 21.76416016], [88.36244965, 21.76416779], [88.3629303, 21.76421165], [88.36338806, 21.76439857], [88.3636322, 21.7644062], [88.36386871, 21.76441193], [88.36434937, 21.7642765], [88.36485291, 21.76418114], [88.36511993, 21.76417351], [88.36538696, 21.76416588]]], [[[88.74888611, 21.76501083], [88.74944305, 21.76444054], [88.74944305, 21.76416588], [88.75026703, 21.76333046], [88.7505722, 21.76321411], [88.75099945, 21.76302147], [88.75140381, 21.76277924], [88.75180817, 21.7625618], [88.75226593, 21.76246071], [88.75269318, 21.76226807], [88.75315857, 21.7621727], [88.75358582, 21.76195908], [88.75405884, 21.76177979], [88.75458527, 21.76165962], [88.75512695, 21.76153564], [88.75569916, 21.76143074], [88.75627136, 21.76132965], [88.75679016, 21.76111031], [88.75726318, 21.76085091], [88.75772095, 21.76062012], [88.75819397, 21.76043129], [88.7586441, 21.76018715], [88.75894165, 21.75972939], [88.75926208, 21.75921822], [88.75911713, 21.75859833], [88.7587204, 21.75803947], [88.75834656, 21.75753021], [88.75800323, 21.75712967], [88.75777435, 21.7567749], [88.75758362, 21.75646591], [88.75743103, 21.75617027], [88.75720215, 21.75593948], [88.75694275, 21.75572968], [88.75669098, 21.75550079], [88.75644684, 21.75525856], [88.75624084, 21.75500107], [88.75604248, 21.75475121], [88.75582123, 21.75453949], [88.75559998, 21.75434113], [88.75538635, 21.75412178], [88.75517273, 21.75388145], [88.75492096, 21.75359917], [88.75463867, 21.75324059], [88.75434875, 21.7528038], [88.75416565, 21.75277519], [88.75417328, 21.75250053], [88.75389099, 21.75222206], [88.75389099, 21.75194359], [88.7536087, 21.75166512], [88.7536087, 21.75111008], [88.75333405, 21.75083351], [88.75333405, 21.75055313], [88.7527771, 21.75000954], [88.7527771, 21.74971962], [88.75250244, 21.74944305], [88.75250244, 21.74888992], [88.75222778, 21.74860954], [88.75222015, 21.7452774], [88.75250244, 21.74500084], [88.75222778, 21.74472046], [88.75222015, 21.74277878], [88.75195313, 21.74250031], [88.7519455, 21.74222183], [88.75166321, 21.74194527], [88.75166321, 21.74139023], [88.75138855, 21.74110985], [88.75138855, 21.74055672], [88.75111389, 21.74027824], [88.75110626, 21.73967934], [88.75110626, 21.73917007], [88.751091, 21.73867989], [88.75099182, 21.73823166], [88.75084686, 21.73779106], [88.75083923, 21.73734283], [88.7508316, 21.73722267], [88.7508316, 21.73694229], [88.75111389, 21.73666573], [88.75110626, 21.73555946], [88.75138855, 21.7352829], [88.75138855, 21.73417282], [88.75166321, 21.73389053], [88.75166321, 21.73361015], [88.7519455, 21.73333359], [88.7519455, 21.73305511], [88.75218964, 21.73275948], [88.75244141, 21.73243523], [88.75253296, 21.73200035], [88.75276947, 21.73157883], [88.7530899, 21.73132133], [88.75339508, 21.73100853], [88.75369263, 21.73067093], [88.75418854, 21.73054123], [88.75450134, 21.73023987], [88.75488281, 21.72998047], [88.75523376, 21.72970581], [88.75559235, 21.7294178], [88.75596619, 21.72916985], [88.75636292, 21.72894096], [88.75685883, 21.7288208], [88.7572403, 21.72835159], [88.75762177, 21.72818947], [88.75847626, 21.72779846], [88.7591629, 21.72777939], [88.75975037, 21.72751045], [88.76030731, 21.72732162], [88.76082611, 21.72719955], [88.76126099, 21.72698975], [88.76171112, 21.7269268], [88.76213837, 21.72681808], [88.76257324, 21.72673035], [88.7629776, 21.72668839], [88.76339722, 21.72667122], [88.76383209, 21.72665024], [88.76423645, 21.72653008], [88.76464844, 21.72641945], [88.76508331, 21.72637939], [88.76550293, 21.72630119], [88.76586151, 21.72613907], [88.76626587, 21.72611046], [88.76667786, 21.72611046], [88.76708984, 21.72611046], [88.76751709, 21.72611046], [88.76793671, 21.72611046], [88.76836395, 21.72611046], [88.76879883, 21.72611237], [88.76924896, 21.72611237], [88.76971436, 21.72610664], [88.77015686, 21.72603989], [88.77054596, 21.72585297], [88.77094269, 21.72571373], [88.77133179, 21.72557831], [88.77175903, 21.72556114], [88.77220154, 21.72556114], [88.7726593, 21.72551918], [88.77308655, 21.72532272], [88.77358246, 21.72525978], [88.77404022, 21.72512054], [88.77440643, 21.72492027], [88.77470398, 21.72468758], [88.77471924, 21.72445107], [88.77500153, 21.72445107], [88.77527618, 21.72417068], [88.77555847, 21.72417068], [88.77610779, 21.72360992], [88.77610779, 21.72249985], [88.77639008, 21.72221947], [88.77639008, 21.72138977], [88.7766571, 21.72110939], [88.77666473, 21.72083282], [88.77610779, 21.72027779], [88.77610779, 21.72000122], [88.77583313, 21.71970749], [88.77583313, 21.71944427], [88.77513123, 21.71902275], [88.77500153, 21.71888924], [88.77503204, 21.71879768], [88.77462769, 21.71851349], [88.77420807, 21.71825218], [88.7738266, 21.71800041], [88.7734375, 21.71776962], [88.77305603, 21.71754074], [88.77262115, 21.7173481], [88.77213287, 21.71718216], [88.77165222, 21.71697235], [88.77114105, 21.71681213], [88.77063751, 21.71664429], [88.77015686, 21.71646118], [88.76967621, 21.7163105], [88.76956177, 21.7162571], [88.76926422, 21.71611595], [88.76885986, 21.71594048], [88.76846313, 21.71577072], [88.76808167, 21.71558762], [88.76766968, 21.71545029], [88.76725006, 21.715271], [88.76694489, 21.71500015], [88.76638794, 21.71500015], [88.76611328, 21.71471977], [88.76527405, 21.71472168], [88.76472473, 21.7143383], [88.76378632, 21.71407127], [88.76293945, 21.71372986], [88.76236725, 21.71326256], [88.7611084, 21.71222305], [88.76055908, 21.7116642], [88.76027679, 21.71194649], [88.76000214, 21.7116642], [88.76000214, 21.71138954], [88.75971985, 21.71111107], [88.75860596, 21.71111107], [88.75821686, 21.71136093], [88.75759125, 21.71149063], [88.75691986, 21.71133041], [88.75631714, 21.71106911], [88.75579834, 21.71080589], [88.75533295, 21.71055031], [88.75488281, 21.71026039], [88.75444794, 21.70997047], [88.75402832, 21.70961952], [88.75356293, 21.70930862], [88.75305939, 21.7089901], [88.7525177, 21.70864868], [88.75193787, 21.70832253], [88.75134277, 21.70800018], [88.75081635, 21.70771599], [88.75038147, 21.70746994], [88.74999237, 21.70727921], [88.74957275, 21.7071991], [88.74917603, 21.70717049], [88.7488327, 21.70714951], [88.74854279, 21.70710945], [88.74827576, 21.70709038], [88.74798584, 21.7071209], [88.74767303, 21.7071991], [88.74727631, 21.70727921], [88.74687958, 21.70744705], [88.74640656, 21.70763969], [88.74589539, 21.70789909], [88.7453537, 21.70825386], [88.74484253, 21.70871353], [88.74440002, 21.70921707], [88.74388885, 21.70972061], [88.74388885, 21.71027946], [88.74333191, 21.71084023], [88.74333191, 21.71277618], [88.74360657, 21.71305084], [88.7436142, 21.71416855], [88.74359894, 21.71458817], [88.74353027, 21.71512985], [88.74338531, 21.7156086], [88.74326324, 21.71601105], [88.74308014, 21.71635056], [88.7428894, 21.71669006], [88.74266815, 21.71702576], [88.74238586, 21.71733284], [88.74209595, 21.71764183], [88.74182129, 21.71796036], [88.74156189, 21.71826935], [88.74138641, 21.71832848], [88.7408371, 21.71888924], [88.74028778, 21.71888924], [88.73999786, 21.71916962], [88.73916626, 21.7191658], [88.73916626, 21.71944427], [88.7388916, 21.71944427], [88.73860931, 21.71972275], [88.73805237, 21.71970749], [88.73777771, 21.72000122], [88.73638916, 21.72000122], [88.73610687, 21.71970749], [88.73586273, 21.71929169], [88.73623657, 21.71917534], [88.73668671, 21.71903038], [88.73719788, 21.71892738], [88.7376709, 21.71880913], [88.73806763, 21.71865082], [88.73847198, 21.71848106], [88.7388916, 21.71829224], [88.73932648, 21.71805954], [88.73979187, 21.71779442], [88.74031067, 21.71749496], [88.74085999, 21.71713066], [88.74138641, 21.71665192], [88.74183655, 21.71610641], [88.74211121, 21.7154808], [88.74221039, 21.71482277], [88.74221802, 21.71419144], [88.74215698, 21.71358109], [88.74203491, 21.71302986], [88.74198914, 21.71247292], [88.74196625, 21.71192169], [88.74199677, 21.71134758], [88.74208832, 21.71075439], [88.74230194, 21.71017265], [88.74260712, 21.70961571], [88.74294281, 21.7090683], [88.74332428, 21.70861053], [88.74371338, 21.70817947], [88.74410248, 21.70779991], [88.74446869, 21.70743942], [88.74484253, 21.70710754], [88.74523163, 21.70676994], [88.7457428, 21.70646286], [88.7462616, 21.70619011], [88.74676514, 21.7060051], [88.7472229, 21.70589066], [88.74765015, 21.70583153], [88.74804687, 21.70581055], [88.74845886, 21.70581818], [88.74886322, 21.70589066], [88.7492218, 21.70601082], [88.74958038, 21.70609093], [88.74993896, 21.70618248], [88.75030518, 21.70632553], [88.75074005, 21.70646286], [88.75119019, 21.70667648], [88.75164795, 21.70691681], [88.75215149, 21.70714951], [88.75267029, 21.70741081], [88.7531662, 21.70770836], [88.75366974, 21.70800018], [88.75417328, 21.70830917], [88.75469208, 21.70861626], [88.75521851, 21.70895958], [88.75576782, 21.70934105], [88.75637054, 21.70965958], [88.7569809, 21.7098999], [88.7575531, 21.70997047], [88.75805664, 21.70990944], [88.75821686, 21.70985603], [88.75861359, 21.70972252], [88.75861359, 21.70916748], [88.75888824, 21.70889282], [88.75860596, 21.70861053], [88.75860596, 21.70833015], [88.7583313, 21.7080555], [88.75805664, 21.70806122], [88.75804138, 21.70788956], [88.75784302, 21.70766068], [88.75771332, 21.70738983], [88.75749969, 21.70722008], [88.75749969, 21.70666695], [88.75694275, 21.70611191], [88.75694275, 21.70583344], [88.75666809, 21.70444489], [88.75694275, 21.70416641], [88.75694275, 21.70360756], [88.75666809, 21.7033329], [88.75666809, 21.70194435], [88.75694275, 21.70166779], [88.75694275, 21.70028114], [88.75723267, 21.70000076], [88.75722504, 21.69972229], [88.75747681, 21.69834137], [88.75790405, 21.69750023], [88.75817108, 21.69734764], [88.75860596, 21.69682121], [88.76055908, 21.69528008], [88.76082611, 21.69528008], [88.76139069, 21.69472122], [88.76166534, 21.69472122], [88.76249695, 21.69388962], [88.76249695, 21.69361115], [88.76270294, 21.69314003], [88.76275635, 21.69293022], [88.76277161, 21.69271278], [88.76267242, 21.69235039], [88.76236725, 21.69195175], [88.76216125, 21.6916008], [88.76198578, 21.69123077], [88.76187134, 21.69079971], [88.76171875, 21.69036293], [88.76161194, 21.68991089], [88.76146698, 21.68946075], [88.76140594, 21.68900108], [88.76140594, 21.68849182], [88.76139832, 21.68800926], [88.76139069, 21.68756104], [88.76133728, 21.68716049], [88.76122284, 21.68683624], [88.76111603, 21.68650055], [88.76100922, 21.68615532], [88.76081085, 21.68580246], [88.76055908, 21.68540955], [88.76034546, 21.68512535], [88.76025391, 21.68500137], [88.75987244, 21.68463135], [88.75944519, 21.68434906], [88.75901794, 21.68412018], [88.75861359, 21.68392944], [88.7582016, 21.68380165], [88.75778198, 21.68366432], [88.75728607, 21.68360138], [88.7567215, 21.68354416], [88.75613403, 21.68345261], [88.75553894, 21.68351936], [88.75499725, 21.68362999], [88.7545166, 21.68378067], [88.75402832, 21.68395042], [88.75350189, 21.68418121], [88.7529068, 21.68443108], [88.75224304, 21.68464279], [88.75148773, 21.68470955], [88.75074005, 21.68456268], [88.75013733, 21.68433762], [88.74964142, 21.68412018], [88.7492218, 21.68391991], [88.74880219, 21.68377495], [88.74835205, 21.68362999], [88.74780273, 21.68357468], [88.74720764, 21.68357086], [88.74659729, 21.68357849], [88.74602509, 21.68359947], [88.74550629, 21.68366241], [88.74507904, 21.68385124], [88.74471283, 21.68416023], [88.74437714, 21.68453979], [88.74414825, 21.68502808], [88.74402618, 21.68556976], [88.74411011, 21.68610954], [88.74415588, 21.6866703], [88.74420929, 21.68723106], [88.74430084, 21.68776512], [88.74415588, 21.68830109], [88.74394989, 21.68882751], [88.74369049, 21.68932152], [88.74333191, 21.68975067], [88.74292755, 21.69013786], [88.74241638, 21.69041824], [88.74185181, 21.69062805], [88.74121857, 21.69075966], [88.74054718, 21.69073105], [88.73992157, 21.69053078], [88.73932648, 21.69025993], [88.73882294, 21.68996048], [88.73840332, 21.68965912], [88.73800659, 21.68940926], [88.73763275, 21.68919945], [88.73721313, 21.68906975], [88.73675537, 21.68892479], [88.73622894, 21.68887329], [88.73567963, 21.68888092], [88.7351532, 21.6889267], [88.73468018, 21.68905258], [88.73420715, 21.68919945], [88.73375702, 21.68937111], [88.73323822, 21.6894207], [88.73269653, 21.68938065], [88.73221588, 21.68922043], [88.73175049, 21.68905258], [88.73134613, 21.68884277], [88.73101044, 21.688591], [88.73071289, 21.68832016], [88.73044586, 21.68805885], [88.73021698, 21.68782043], [88.73000336, 21.68761063], [88.72976685, 21.68740273], [88.72953796, 21.68712997], [88.72929382, 21.68675613], [88.7290802, 21.68625069], [88.72895813, 21.68565941], [88.72897339, 21.68507957], [88.72912598, 21.68457985], [88.72927856, 21.68406868], [88.72947693, 21.68359947], [88.7297287, 21.6831913], [88.72999573, 21.682827], [88.73026276, 21.68251991], [88.7305069, 21.68226051], [88.73077393, 21.68203163], [88.73110199, 21.68182564], [88.7314682, 21.68160248], [88.73187256, 21.68138123], [88.73230743, 21.68116951], [88.73279572, 21.68104362], [88.73324585, 21.68083954], [88.73369598, 21.68063545], [88.73416138, 21.68045044], [88.73462677, 21.68025017], [88.73509216, 21.68005943], [88.73558807, 21.67993546], [88.73603821, 21.67972946], [88.73648834, 21.67951393], [88.73696899, 21.67931175], [88.73745728, 21.67909622], [88.73792267, 21.6788311], [88.73831177, 21.67850494], [88.73867035, 21.67817307], [88.73903656, 21.67789078], [88.73937225, 21.67761993], [88.73977661, 21.67741013], [88.74021149, 21.67715263], [88.74067688, 21.67682457], [88.74118805, 21.67645836], [88.74175262, 21.67609978], [88.74230194, 21.67575073], [88.74282074, 21.67538071], [88.74333191, 21.67509079], [88.74384308, 21.67485809], [88.74427795, 21.67463112], [88.74472809, 21.6744194], [88.74512482, 21.67420387], [88.74552917, 21.67401123], [88.74591827, 21.67381096], [88.74630737, 21.67358017], [88.74668121, 21.67333031], [88.74705505, 21.67307854], [88.74742889, 21.67284012], [88.74777985, 21.67250061], [88.7481308, 21.67215538], [88.74852753, 21.67181969], [88.74893188, 21.67146111], [88.7493515, 21.67109108], [88.7497406, 21.67068291], [88.75016785, 21.67029953], [88.75061035, 21.66995049], [88.75105286, 21.66959], [88.75144958, 21.66919136], [88.7518692, 21.66881943], [88.7522583, 21.66842079], [88.75267029, 21.66802025], [88.75305939, 21.66762161], [88.75346375, 21.66722107], [88.7538681, 21.66683006], [88.75424957, 21.66642952], [88.7546463, 21.66605186], [88.75499725, 21.66563988], [88.75527954, 21.66519737], [88.75554657, 21.66473007], [88.75582123, 21.66423035], [88.75604248, 21.66367912], [88.7562561, 21.66315269], [88.75611115, 21.66280174], [88.75576019, 21.66250038], [88.75535583, 21.66214943], [88.75499725, 21.66167068], [88.75480652, 21.66147614], [88.75444794, 21.66111183], [88.75389099, 21.66110992], [88.75375366, 21.66125107], [88.7536087, 21.6613903], [88.75250244, 21.66028023], [88.75222778, 21.66028023], [88.75195313, 21.65999985], [88.75177765, 21.65999985], [88.75166321, 21.65999985], [88.75138855, 21.65971947], [88.75055695, 21.65972137], [88.75027466, 21.65944672], [88.75, 21.65916443], [88.74916077, 21.65917015], [88.74888611, 21.65888977], [88.74861145, 21.65888977], [88.74804687, 21.65833092], [88.74777985, 21.65833092], [88.74700165, 21.65909767], [88.74694061, 21.65915871], [88.74659729, 21.65950966], [88.74617004, 21.65993118], [88.74571228, 21.66029549], [88.74530792, 21.66068649], [88.74500275, 21.66111183], [88.74471283, 21.66152], [88.7443924, 21.66189575], [88.74402618, 21.66221809], [88.7436676, 21.66254997], [88.74334717, 21.66292572], [88.74305725, 21.66332054], [88.74272156, 21.66367912], [88.74241638, 21.66405106], [88.74199677, 21.66430664], [88.7416687, 21.66464806], [88.74137878, 21.66504097], [88.74106598, 21.66543007], [88.74069977, 21.66580009], [88.74025726, 21.6661396], [88.73986053, 21.66653633], [88.73950195, 21.66696167], [88.73918152, 21.66739273], [88.73889923, 21.66781807], [88.7386322, 21.66824913], [88.73834991, 21.66864967], [88.73804474, 21.66904259], [88.73770905, 21.66940308], [88.73734283, 21.6697197], [88.73698425, 21.67002869], [88.73664856, 21.67032242], [88.73631287, 21.67058754], [88.73595428, 21.67082977], [88.73561859, 21.67106247], [88.7353363, 21.67134094], [88.73504639, 21.67165565], [88.73470306, 21.67193985], [88.73431396, 21.67221832], [88.73388672, 21.67249107], [88.73349762, 21.67282295], [88.73317719, 21.67323112], [88.73293304, 21.67371178], [88.73253632, 21.6740284], [88.73213959, 21.67439079], [88.73168945, 21.67471695], [88.73121643, 21.67500305], [88.7307663, 21.67527962], [88.73034668, 21.67555809], [88.7299118, 21.67583084], [88.72946167, 21.67611122], [88.72904205, 21.67641258], [88.72860718, 21.67669106], [88.72817993, 21.67694664], [88.72773743, 21.67719078], [88.72728729, 21.67745018], [88.72688293, 21.67776108], [88.72647095, 21.67808723], [88.72607422, 21.67842484], [88.72563934, 21.67865944], [88.72524261, 21.67893028], [88.72483063, 21.67918015], [88.72444153, 21.6794529], [88.72406006, 21.67971992], [88.72364044, 21.6799736], [88.72322845, 21.68025017], [88.72276306, 21.68051529], [88.72229767, 21.68077278], [88.72186279, 21.68105888], [88.72138214, 21.6812706], [88.72088623, 21.6814518], [88.72046661, 21.68167686], [88.72006226, 21.68194008], [88.71964264, 21.68222046], [88.71917725, 21.6824894], [88.71868896, 21.68278122], [88.71819305, 21.6830883], [88.71774292, 21.68345261], [88.71723175, 21.68377113], [88.71674347, 21.68409729], [88.71627045, 21.68443108], [88.71581268, 21.68474007], [88.71538544, 21.68503189], [88.7150116, 21.68538284], [88.71465302, 21.68577003], [88.71425629, 21.6861496], [88.71386719, 21.68656158], [88.71343994, 21.68695831], [88.71305084, 21.68740273], [88.71269226, 21.68779945], [88.71245575, 21.68823242], [88.71222687, 21.68857956], [88.7120285, 21.68888092], [88.71185303, 21.68914795], [88.71166992, 21.68939018], [88.71148682, 21.68963242], [88.71133423, 21.6899128], [88.71111298, 21.69017982], [88.71111298, 21.69055557], [88.71083069, 21.69082832], [88.71083069, 21.69138908], [88.71055603, 21.69166946], [88.71055603, 21.69305611], [88.71028137, 21.69333267], [88.71028137, 21.69361115], [88.70999146, 21.69388962], [88.70999146, 21.69499969], [88.7097168, 21.69528008], [88.7097168, 21.69639015], [88.70944214, 21.69666672], [88.70944214, 21.69721985], [88.70916748, 21.69750023], [88.70916748, 21.69805336], [88.70888519, 21.69833565], [88.70888519, 21.69944572], [88.70861053, 21.69972229], [88.70861053, 21.70083046], [88.70848846, 21.70139122], [88.70835876, 21.70191956], [88.70829773, 21.70249557], [88.70809937, 21.70302963], [88.7080307, 21.70362091], [88.707901, 21.70418167], [88.70779419, 21.70471764], [88.70780945, 21.70524216], [88.70794678, 21.70573235], [88.70804596, 21.70583153], [88.70804596, 21.70639038], [88.70777893, 21.70666695], [88.70777893, 21.70722008], [88.70749664, 21.70750046], [88.70749664, 21.70806122], [88.70667267, 21.70889282], [88.70666504, 21.70916748], [88.70694733, 21.70944214], [88.70694733, 21.70972061], [88.70722198, 21.71000099], [88.70722198, 21.71027946], [88.70666504, 21.7108326], [88.70667267, 21.71249962], [88.70642853, 21.71306992], [88.70638275, 21.71357155], [88.70633698, 21.71403122], [88.70616913, 21.7144165], [88.70598602, 21.71479034], [88.70587921, 21.71519661], [88.7057724, 21.71558952], [88.70558167, 21.71595955], [88.70542908, 21.71634293], [88.70526123, 21.71679115], [88.70503998, 21.71723175], [88.70498657, 21.71776962], [88.70487213, 21.71832085], [88.7046814, 21.71887016], [88.70443726, 21.71939278], [88.704216, 21.71985054], [88.70411682, 21.72028923], [88.70392609, 21.72058105], [88.70384979, 21.72092056], [88.7036972, 21.72118187], [88.70362091, 21.72145271], [88.70355988, 21.72174072], [88.70333862, 21.72197723], [88.70318604, 21.72232819], [88.70298767, 21.722826], [88.7027359, 21.72335052], [88.70248413, 21.72387886], [88.70223999, 21.72430038], [88.70205688, 21.72464943], [88.70173645, 21.72505951], [88.70149994, 21.72546387], [88.70137787, 21.72587013], [88.70124817, 21.72624969], [88.7011261, 21.72660065], [88.70111084, 21.72696114], [88.70111084, 21.72730827], [88.70111084, 21.72765732], [88.70111084, 21.7279911], [88.70110321, 21.72831345], [88.70105743, 21.72861099], [88.70087433, 21.72890091], [88.70083618, 21.72925186], [88.70078278, 21.7296505], [88.70057678, 21.73006821], [88.70037842, 21.73056793], [88.7000885, 21.73112106], [88.70001984, 21.7318306], [88.69976044, 21.73225975], [88.69949341, 21.7326107], [88.6992569, 21.73295021], [88.69889069, 21.73305511], [88.6986084, 21.73333359], [88.6986084, 21.73361015], [88.69777679, 21.73444366], [88.69777679, 21.73472023], [88.69833374, 21.73527718], [88.69832611, 21.73583031], [88.69805145, 21.73611069], [88.69805908, 21.73638916], [88.69750214, 21.73694229], [88.69750214, 21.73722076], [88.69721985, 21.73750114], [88.69706726, 21.73779869], [88.69706726, 21.7382412], [88.69695282, 21.73875999], [88.69700623, 21.73926926], [88.69695282, 21.7396698], [88.69700623, 21.74002838], [88.69722748, 21.74032021], [88.69750977, 21.74058151], [88.69777679, 21.74084091], [88.69792175, 21.74110985], [88.69775391, 21.74141884], [88.69740295, 21.74180984], [88.69687653, 21.74221992], [88.69635773, 21.74263954], [88.69589233, 21.74301147], [88.69552612, 21.74336052], [88.69527435, 21.74361038], [88.69499969, 21.74389076], [88.69500732, 21.74472046], [88.69526672, 21.74500084], [88.69527435, 21.74555588], [88.69499969, 21.74583244], [88.69500732, 21.74638939], [88.69526672, 21.74666977], [88.69527435, 21.74805641], [88.69555664, 21.74833107], [88.69555664, 21.75000954], [88.6958313, 21.75027847], [88.6958313, 21.75111008], [88.69611359, 21.75138855], [88.69611359, 21.75194359], [88.69638824, 21.75222015], [88.69638824, 21.75250053], [88.6966629, 21.75278091], [88.6966629, 21.75305748], [88.69694519, 21.75333595], [88.69695282, 21.75361061], [88.69721985, 21.75389099], [88.69721985, 21.75416756], [88.69777679, 21.75472069], [88.69777679, 21.75500107], [88.69805145, 21.75527954], [88.69805908, 21.75555611], [88.69832611, 21.75582123], [88.69832611, 21.75638962], [88.6986084, 21.75666618], [88.6986084, 21.75694466], [88.69889069, 21.75722313], [88.69889069, 21.75753975], [88.69889069, 21.75805473], [88.69916534, 21.75833321], [88.69917297, 21.75861168], [88.69944763, 21.75889015], [88.69944763, 21.75916672], [88.70101929, 21.76080322], [88.70111084, 21.7609005], [88.70111084, 21.7610302], [88.7013092, 21.76142693], [88.70143127, 21.76197052], [88.70156097, 21.76274109], [88.70183563, 21.76335716], [88.70211029, 21.76390266], [88.70225525, 21.76441765], [88.70243835, 21.76493073], [88.70249176, 21.76551056], [88.70249939, 21.76611519], [88.7025528, 21.76670265], [88.70274353, 21.76721954], [88.70297241, 21.7677002], [88.70318604, 21.76817513], [88.70340729, 21.76861191], [88.70362091, 21.76902962], [88.70385742, 21.7694397], [88.70404053, 21.76986122], [88.70423889, 21.77025032], [88.70443726, 21.77058983], [88.70462799, 21.77095795], [88.70475006, 21.77140045], [88.70491028, 21.7718792], [88.7050705, 21.77240944], [88.70529175, 21.7729435], [88.70555878, 21.77347946], [88.70582581, 21.7740097], [88.70610809, 21.77450943], [88.70636749, 21.77497101], [88.70665741, 21.77540016], [88.70694733, 21.77584076], [88.70720673, 21.7763195], [88.70748138, 21.77681732], [88.70774841, 21.77734375], [88.70802307, 21.77788925], [88.70826721, 21.77843857], [88.70846558, 21.77897453], [88.70852661, 21.77948952], [88.70845032, 21.77997017], [88.70855713, 21.78038025], [88.70944214, 21.77999115], [88.70944214, 21.78166962], [88.70999908, 21.78166771], [88.71018982, 21.78185463], [88.71055603, 21.78222275], [88.71055603, 21.78333282], [88.71083069, 21.7836113], [88.71083069, 21.78475952], [88.71083069, 21.78499985], [88.71111298, 21.78527832], [88.71111298, 21.78583145], [88.71138763, 21.78611946], [88.71138763, 21.78695107], [88.71193695, 21.78750038], [88.71194458, 21.78805542], [88.71166992, 21.78833008], [88.71166992, 21.78861046], [88.71194458, 21.78888893], [88.71194458, 21.78944206], [88.71166992, 21.78972054], [88.71166992, 21.79000092], [88.71193695, 21.79027939], [88.71194458, 21.79111099], [88.7115097, 21.79154778], [88.71111298, 21.79194641], [88.71150208, 21.7923317], [88.71166992, 21.79249954], [88.71166992, 21.79277992], [88.71193695, 21.7930603], [88.71193695, 21.79389], [88.71166992, 21.79416847], [88.71166992, 21.7947216], [88.71193695, 21.79499054], [88.71194458, 21.79555511], [88.71221924, 21.79582977], [88.71221924, 21.79805565], [88.71193695, 21.7983284], [88.71194458, 21.79916573], [88.71221924, 21.79943848], [88.71221924, 21.80000114], [88.71193695, 21.80027962], [88.71194458, 21.80055618], [88.71166992, 21.80083275], [88.71166992, 21.80138969], [88.71138763, 21.80166626], [88.71138763, 21.80221939], [88.71111298, 21.80249977], [88.71111298, 21.80305481], [88.71083069, 21.80333328], [88.71083069, 21.80360985], [88.71111298, 21.80389023], [88.71111298, 21.80500031], [88.71083069, 21.80528069], [88.71105194, 21.80602074], [88.71162415, 21.80635643], [88.71219635, 21.80722046], [88.71321106, 21.80730057], [88.71362305, 21.80727577], [88.71401978, 21.80724716], [88.7144165, 21.80722046], [88.71505737, 21.80730057], [88.71560669, 21.80729103], [88.71620178, 21.80738068], [88.71656799, 21.80706024], [88.71695709, 21.80672073], [88.71736145, 21.80638123], [88.71774292, 21.80599976], [88.71806335, 21.80556107], [88.71839905, 21.80513], [88.71871948, 21.80468941], [88.71896362, 21.80422974], [88.71922302, 21.80381966], [88.71946716, 21.80340958], [88.71968842, 21.80302048], [88.71980286, 21.80257988], [88.71994019, 21.80216408], [88.72006226, 21.80173111], [88.72020721, 21.80129814], [88.72029114, 21.80079079], [88.72041321, 21.80024529], [88.7205658, 21.79965019], [88.72077942, 21.79905128], [88.72097015, 21.7984581], [88.72107697, 21.79783058], [88.72110748, 21.79726028], [88.72110748, 21.79679108], [88.72111511, 21.79641533], [88.72116852, 21.79610062], [88.72135162, 21.79585075], [88.72148132, 21.79556847], [88.72161865, 21.79529953], [88.72177124, 21.79504013], [88.72193909, 21.7947998], [88.72212982, 21.79454041], [88.72238159, 21.7942791], [88.72270966, 21.7939682], [88.72315216, 21.79371452], [88.72373199, 21.79351425], [88.72440338, 21.79335213], [88.72509003, 21.79322624], [88.7257309, 21.79304123], [88.72624969, 21.79277992], [88.7266922, 21.79248047], [88.72701263, 21.79214478], [88.72720337, 21.79178619], [88.72725677, 21.79140091], [88.72723389, 21.79100609], [88.72715759, 21.79058838], [88.727211, 21.79014969], [88.72720337, 21.78970146], [88.72710419, 21.78924179], [88.72709656, 21.78874969], [88.72720337, 21.78833961], [88.72727203, 21.78795052], [88.72738647, 21.78759003], [88.7274704, 21.78721809], [88.72751617, 21.78681183], [88.72753143, 21.78637123], [88.72750854, 21.78589058], [88.72741699, 21.78539467], [88.72721863, 21.78490448], [88.72698975, 21.78441048], [88.72680664, 21.78388977], [88.72677612, 21.78334045], [88.72687531, 21.78290558], [88.72692871, 21.78252029], [88.72694397, 21.78215218], [88.7269516, 21.78177071], [88.7269516, 21.78137016], [88.72696686, 21.78098106], [88.72705078, 21.78061104], [88.72715759, 21.7802906], [88.727211, 21.77997017], [88.72725677, 21.77964973], [88.72735596, 21.77935028], [88.72749329, 21.77907944], [88.72761536, 21.77880478], [88.7277832, 21.7785511], [88.72793579, 21.77828979], [88.72801971, 21.7779808], [88.72805786, 21.77777863], [88.72888947, 21.77778053], [88.72915649, 21.77750015], [88.72946167, 21.77775192], [88.72976685, 21.77807045], [88.73014069, 21.77833748], [88.73053741, 21.77858353], [88.73098755, 21.77877235], [88.73152161, 21.77886009], [88.7321167, 21.77888107], [88.73271942, 21.77883911], [88.73326874, 21.77869987], [88.73362732, 21.77832985], [88.73390961, 21.77789879], [88.73413849, 21.77745056], [88.73432159, 21.77696991], [88.73449707, 21.77646255], [88.73472595, 21.77593613], [88.73499298, 21.77539063], [88.73531342, 21.77495956], [88.73567963, 21.77462006], [88.73609161, 21.77433014], [88.73661804, 21.7741394], [88.73713684, 21.77396011], [88.73765564, 21.77382469], [88.7381134, 21.7736454], [88.73855591, 21.77349091], [88.73906708, 21.7734127], [88.73959351, 21.77338219], [88.74011993, 21.77336311], [88.74066162, 21.77333832], [88.74138641, 21.77306175], [88.74223328, 21.77306175], [88.74250031, 21.77277946], [88.74333191, 21.77277946], [88.74360657, 21.77249908], [88.74388885, 21.77249908], [88.74415588, 21.77222061], [88.74472046, 21.77222252], [88.7452774, 21.77166748], [88.74542236, 21.77166748], [88.74582672, 21.77166939], [88.74582672, 21.77139091], [88.74610138, 21.77111053], [88.74610138, 21.77055931], [88.7463913, 21.77028084], [88.7463913, 21.77000046], [88.74637604, 21.76971817], [88.74651337, 21.76930046], [88.74651337, 21.76888084], [88.7466507, 21.76819038], [88.74707031, 21.76764107], [88.74721527, 21.76723099], [88.74734497, 21.76695251], [88.74748993, 21.76666451], [88.74762726, 21.76625061], [88.74790955, 21.76597786], [88.74845886, 21.76527977], [88.74888611, 21.76501083]]], [[[88.11555481, 21.62583351], [88.1138916, 21.62583351], [88.11360931, 21.62611008], [88.11305237, 21.62611008], [88.11277771, 21.62639046], [88.11138916, 21.62639046], [88.11112213, 21.62611008], [88.11055756, 21.62611008], [88.11027527, 21.62583351], [88.10916901, 21.62583351], [88.10888672, 21.62611008], [88.10749817, 21.62611008], [88.10694122, 21.62666702], [88.10694122, 21.62694359], [88.10500336, 21.62694359], [88.10472107, 21.62722015], [88.10415649, 21.62722015], [88.10388947, 21.62750053], [88.10333252, 21.62750053], [88.10305786, 21.62722015], [88.1027832, 21.62722015], [88.10250092, 21.62750053], [88.10192871, 21.62750053], [88.10166931, 21.62778282], [88.10083008, 21.62778282], [88.10056305, 21.62805939], [88.09833527, 21.62805557], [88.09805298, 21.62833214], [88.09694672, 21.62833023], [88.09666443, 21.62861061], [88.09612274, 21.62861061], [88.09583282, 21.6288929], [88.09555817, 21.6288929], [88.09527588, 21.62916946], [88.09361267, 21.62916946], [88.09333038, 21.6288929], [88.09278107, 21.6288929], [88.09249878, 21.62916946], [88.09111023, 21.62916756], [88.09083557, 21.62944221], [88.09055328, 21.62944221], [88.09027863, 21.62916756], [88.08999634, 21.62916756], [88.08972168, 21.62943268], [88.08972168, 21.63000107], [88.08999634, 21.63027763], [88.08944702, 21.63083267], [88.08833313, 21.63083076], [88.08638763, 21.63278008], [88.08611298, 21.63249016], [88.08583069, 21.63249969], [88.08528137, 21.63194656], [88.08499908, 21.63194656], [88.08472443, 21.63166428], [88.08444214, 21.63166428], [88.08389282, 21.63222122], [88.08388519, 21.63277817], [88.08361053, 21.63305664], [88.08361053, 21.63333321], [88.08333588, 21.63360977], [88.08333588, 21.63417053], [88.08249664, 21.63500023], [88.08194733, 21.63500023], [88.08139038, 21.63445091], [88.08139801, 21.63430977], [88.08082581, 21.63417053], [88.08055878, 21.63417053], [88.08027649, 21.63389015], [88.08000183, 21.63417053], [88.07861328, 21.63417053], [88.07833099, 21.63389015], [88.07805634, 21.63388634], [88.07722473, 21.63472176], [88.07611084, 21.63472176], [88.07583618, 21.63444519], [88.07527924, 21.63444519], [88.07388306, 21.63488388], [88.07333374, 21.63488388], [88.07250214, 21.63472176], [88.07221985, 21.63472176], [88.07180786, 21.63430786], [88.07138824, 21.63388634], [88.07055664, 21.63389015], [88.06999969, 21.63445091], [88.06999969, 21.63500023], [88.06944275, 21.63555908], [88.06916809, 21.63555527], [88.0688858, 21.63583374], [88.06833649, 21.63582993], [88.06804657, 21.63611031], [88.06749725, 21.63611031], [88.0672226, 21.63639069], [88.06667328, 21.63639069], [88.06500244, 21.63806152], [88.06361389, 21.6380558], [88.06305695, 21.63807106], [88.06285095, 21.63806725], [88.0625, 21.6380558], [88.06223297, 21.63806152], [88.0595932, 21.64003944], [88.05860901, 21.64056015], [88.0580368, 21.64053917], [88.05747986, 21.64011955], [88.05693817, 21.64056015], [88.05665588, 21.64056015], [88.05583191, 21.64138985], [88.05555725, 21.64138985], [88.0541687, 21.6427803], [88.05388641, 21.6427784], [88.0533371, 21.64333344], [88.05278015, 21.64332962], [88.05222321, 21.64389038], [88.05194092, 21.64389038], [88.05166626, 21.64417076], [88.0513916, 21.64416695], [88.05083466, 21.64472198], [88.05055237, 21.64472008], [88.05027771, 21.64500046], [88.05000305, 21.64500046], [88.04860687, 21.64639091], [88.04833221, 21.64638901], [88.04750061, 21.64722252], [88.04722595, 21.64722061], [88.04693604, 21.64750099], [88.04666901, 21.64750099], [88.04638672, 21.64777946], [88.04611206, 21.64777946], [88.04582977, 21.64805984], [88.04555511, 21.64805794], [88.04528046, 21.6483326], [88.04499817, 21.64833069], [88.04416656, 21.64916992], [88.04354095, 21.64973068], [88.04302216, 21.64970016], [88.04166412, 21.64916611], [88.04138947, 21.64944458], [88.04138947, 21.64972115], [88.04145813, 21.64990044], [88.04141235, 21.65035057], [88.04139709, 21.65077972], [88.04138947, 21.65117836], [88.04137421, 21.65159035], [88.04132843, 21.65202332], [88.0411911, 21.65241814], [88.04104614, 21.65282059], [88.04086304, 21.65320969], [88.04083252, 21.65361977], [88.04083252, 21.65389061], [88.04055786, 21.6541729], [88.04055786, 21.65555573], [88.0402832, 21.65583038], [88.04027557, 21.65638924], [88.04055786, 21.6566658], [88.04037476, 21.65728378], [88.04020691, 21.65740013], [88.04003906, 21.65752029], [88.0399704, 21.65779686], [88.04006195, 21.65839005], [88.03988647, 21.65892601], [88.03962708, 21.65928268], [88.03942871, 21.65964127], [88.03925323, 21.65999985], [88.03916931, 21.66027832], [88.03971863, 21.66082954], [88.03971863, 21.6613903], [88.03944397, 21.66166878], [88.03943634, 21.66221809], [88.03887939, 21.66278839], [88.03887939, 21.66305923], [88.03833008, 21.66361046], [88.03833008, 21.66527939], [88.03805542, 21.66555595], [88.03806305, 21.66638947], [88.03778076, 21.66667175], [88.03778076, 21.66777802], [88.03722382, 21.66833115], [88.03722382, 21.67083549], [88.03694153, 21.67111206], [88.03694153, 21.67166519], [88.03722382, 21.67194366], [88.03721619, 21.67222023], [88.03778076, 21.67278099], [88.03778076, 21.67305946], [88.03694153, 21.67389107], [88.03694153, 21.67416763], [88.03666687, 21.67444038], [88.03666687, 21.67500114], [88.03721619, 21.67555809], [88.03722382, 21.67612076], [88.0372467, 21.67645264], [88.03726959, 21.67719078], [88.03765106, 21.67807961], [88.03749084, 21.67856979], [88.03753662, 21.67897987], [88.03775024, 21.6793499], [88.03794861, 21.67968941], [88.03809357, 21.68009758], [88.03829956, 21.68047905], [88.03852081, 21.68084717], [88.03869629, 21.68126106], [88.03874207, 21.68181801], [88.03868103, 21.68242455], [88.03844452, 21.68289375], [88.03818512, 21.6832695], [88.03808594, 21.68362045], [88.03807831, 21.68394279], [88.0381012, 21.68421936], [88.03816223, 21.68447304], [88.03829193, 21.6847496], [88.03835297, 21.68515015], [88.03836823, 21.68569946], [88.038414, 21.68633842], [88.03857422, 21.68696404], [88.03868103, 21.68760109], [88.03887939, 21.68819809], [88.03907776, 21.68881989], [88.03922272, 21.68945122], [88.03936768, 21.69001961], [88.03933716, 21.69061661], [88.03935242, 21.69117355], [88.03948975, 21.69166183], [88.03967285, 21.6920929], [88.03974915, 21.69252968], [88.03983307, 21.69296074], [88.04000854, 21.6933651], [88.04005432, 21.69380379], [88.04006195, 21.69425011], [88.04006958, 21.69473076], [88.04017639, 21.69518852], [88.04030609, 21.69564056], [88.04046631, 21.69605255], [88.04057312, 21.69645119], [88.04064941, 21.69682121], [88.04078674, 21.69712067], [88.04084015, 21.69745827], [88.04090881, 21.69779968], [88.04108429, 21.69808769], [88.04120636, 21.69842911], [88.04138184, 21.69883728], [88.04153442, 21.69932365], [88.04169464, 21.6998558], [88.04188538, 21.7003746], [88.04199219, 21.70088577], [88.04210663, 21.70129013], [88.04219818, 21.70165062], [88.04222107, 21.70197678], [88.04224396, 21.70227432], [88.04231262, 21.70256805], [88.04240417, 21.7029171], [88.0423584, 21.70337486], [88.04251099, 21.70391273], [88.04268646, 21.7045002], [88.04277039, 21.70512581], [88.04283142, 21.70577049], [88.04290009, 21.70643044], [88.0431366, 21.70703125], [88.04338837, 21.70758057], [88.04332733, 21.70821953], [88.04354858, 21.70874786], [88.04400635, 21.7091713], [88.04421234, 21.70968246], [88.04403687, 21.71035004], [88.04394531, 21.7111187], [88.04373932, 21.7116394], [88.0437088, 21.71215057], [88.04389191, 21.71261978], [88.04414368, 21.71305656], [88.04437256, 21.71352005], [88.04453278, 21.71408081], [88.04445648, 21.71470833], [88.04440308, 21.71524048], [88.04429626, 21.71562958], [88.04415894, 21.71594048], [88.04408264, 21.71635628], [88.0440979, 21.71705246], [88.0442276, 21.71769333], [88.04450989, 21.71813011], [88.04486847, 21.71845818], [88.04524231, 21.71871948], [88.04560089, 21.71898079], [88.04599762, 21.7191906], [88.04638672, 21.71947098], [88.04676056, 21.71988106], [88.04696655, 21.72044945], [88.04718781, 21.72097015], [88.04737854, 21.72145462], [88.04753876, 21.72191048], [88.04779053, 21.72229958], [88.04823303, 21.72249031], [88.04859161, 21.72274971], [88.04889679, 21.72304535], [88.04918671, 21.72330856], [88.04950714, 21.72354126], [88.04982758, 21.72373962], [88.05008698, 21.72397995], [88.05034637, 21.72425079], [88.05058289, 21.72459984], [88.05078888, 21.72499847], [88.0509491, 21.72542953], [88.05116272, 21.72581291], [88.05142212, 21.72613907], [88.05173492, 21.72650528], [88.05208588, 21.72694969], [88.05252838, 21.7274704], [88.05294037, 21.72794151], [88.0532608, 21.7282505], [88.0535202, 21.72849083], [88.05375671, 21.72865105], [88.05394745, 21.72890091], [88.05414581, 21.72915077], [88.05436707, 21.72944069], [88.05478668, 21.7296505], [88.05536652, 21.72987175], [88.05597687, 21.73009109], [88.056427, 21.73028946], [88.05674744, 21.73058128], [88.05700684, 21.73108101], [88.05716705, 21.73162079], [88.05735779, 21.73212051], [88.05773926, 21.73257256], [88.05822754, 21.73285294], [88.0588913, 21.73305511], [88.05944824, 21.73361015], [88.0597229, 21.73333359], [88.06027985, 21.73333359], [88.06138611, 21.73444176], [88.06138611, 21.73555565], [88.0616684, 21.73583031], [88.06138611, 21.73611069], [88.06138611, 21.73638916], [88.06194305, 21.73694229], [88.06194305, 21.73722076], [88.06223297, 21.73750114], [88.06222534, 21.73777771], [88.0627594, 21.73833084], [88.0627594, 21.73888969], [88.06388855, 21.73999977], [88.06388855, 21.74027824], [88.06416321, 21.74055099], [88.06416321, 21.74139023], [88.0644455, 21.7416687], [88.06445312, 21.74250031], [88.06472015, 21.74277878], [88.06472015, 21.74388123], [88.06500244, 21.74416733], [88.06500244, 21.74444389], [88.0652771, 21.74472046], [88.0652771, 21.7452774], [88.06581879, 21.74582863], [88.06583405, 21.74666595], [88.06555176, 21.74694443], [88.06555176, 21.74833107], [88.06581879, 21.74860954], [88.06583405, 21.74944305], [88.0661087, 21.74972153], [88.0661087, 21.75083351], [88.06639099, 21.75111008], [88.06639099, 21.75166512], [88.06581879, 21.75222015], [88.06581879, 21.75250053], [88.06555176, 21.75278091], [88.06555176, 21.75305748], [88.06581879, 21.75333023], [88.06581879, 21.75389099], [88.0661087, 21.75416756], [88.0661087, 21.75444412], [88.06639099, 21.75472069], [88.06639099, 21.75527954], [88.06666565, 21.75555611], [88.06667328, 21.75582123], [88.06694794, 21.75611115], [88.06694794, 21.75666618], [88.0672226, 21.75694466], [88.0672226, 21.75722122], [88.06749725, 21.75749969], [88.06749725, 21.75777817], [88.06777954, 21.75805092], [88.06777954, 21.75917244], [88.06804657, 21.75945282], [88.0680542, 21.76055527], [88.06833649, 21.76083183], [88.068367, 21.76102066], [88.06861115, 21.76158905], [88.06886292, 21.76213455], [88.06900787, 21.76265144], [88.06903839, 21.76313972], [88.06897736, 21.76363945], [88.06907654, 21.76405716], [88.06925201, 21.76447105], [88.06945801, 21.76493454], [88.06967926, 21.76543045], [88.06987762, 21.76599884], [88.07015991, 21.76651001], [88.07036591, 21.7670517], [88.07036591, 21.7676506], [88.07045746, 21.76820183], [88.07052612, 21.76873016], [88.07060242, 21.76920128], [88.07076263, 21.76958084], [88.07087708, 21.7699585], [88.07104492, 21.77032661], [88.07110596, 21.77081108], [88.07115173, 21.77135086], [88.07128143, 21.77185631], [88.07136536, 21.77235222], [88.07139587, 21.7728405], [88.07144165, 21.77334023], [88.07157135, 21.77383041], [88.07154083, 21.77436066], [88.07163239, 21.7748909], [88.07170868, 21.77543831], [88.0718689, 21.77598572], [88.07199097, 21.77656364], [88.07217407, 21.77709579], [88.07221985, 21.77757072], [88.07222748, 21.77797318], [88.07226563, 21.77831268], [88.07242584, 21.77858162], [88.07248688, 21.7789402], [88.07254028, 21.779356], [88.0727005, 21.77976418], [88.07285309, 21.78018188], [88.07306671, 21.78052521], [88.07329559, 21.78083038], [88.07344818, 21.78122139], [88.07364655, 21.78165054], [88.07401276, 21.78206825], [88.07440948, 21.78252029], [88.07480621, 21.7829895], [88.0752182, 21.7834301], [88.07556915, 21.78389931], [88.07592773, 21.78436089], [88.07631683, 21.78481293], [88.07666016, 21.78526115], [88.0769577, 21.78570747], [88.07730103, 21.7859726], [88.07766724, 21.78609085], [88.07795715, 21.78623962], [88.07804108, 21.78651047], [88.07807159, 21.78700638], [88.07826996, 21.78763962], [88.07855225, 21.78821945], [88.0789032, 21.78864098], [88.07917786, 21.78902054], [88.07940674, 21.78948975], [88.07957458, 21.79009056], [88.07984924, 21.79063988], [88.08023071, 21.79109573], [88.08055878, 21.79158211], [88.08085632, 21.79204941], [88.08117676, 21.79244041], [88.08145142, 21.79276085], [88.08167267, 21.7930603], [88.08185577, 21.79336166], [88.08197784, 21.79368019], [88.08216095, 21.79396057], [88.08229065, 21.79429054], [88.08244324, 21.79459763], [88.08255005, 21.79496956], [88.08274841, 21.79529572], [88.08290863, 21.79567146], [88.08309937, 21.79603004], [88.08332062, 21.79640961], [88.08351898, 21.79687119], [88.0836792, 21.79741096], [88.08390045, 21.79795074], [88.08416748, 21.79844666], [88.08444977, 21.79892921], [88.08473206, 21.79940987], [88.08503723, 21.79989052], [88.08535767, 21.80037117], [88.08564758, 21.80089951], [88.08587646, 21.80150604], [88.08613586, 21.80211258], [88.08644104, 21.80266953], [88.08679199, 21.80315781], [88.0871582, 21.80355263], [88.08750916, 21.80389977], [88.08782196, 21.80424118], [88.0880661, 21.80461121], [88.08825684, 21.80500984], [88.08833313, 21.80553055], [88.08840179, 21.80606079], [88.08862305, 21.80651093], [88.08886719, 21.80690956], [88.08912659, 21.80729103], [88.08937073, 21.80767632], [88.08972931, 21.80806351], [88.09014893, 21.80848312], [88.09055328, 21.80895805], [88.09076691, 21.80953026], [88.09088898, 21.81010628], [88.09107208, 21.81059647], [88.09121704, 21.81106377], [88.09139252, 21.81147957], [88.09160614, 21.81186104], [88.09185791, 21.81217194], [88.09205627, 21.81250954], [88.09224701, 21.81285667], [88.09246063, 21.81321335], [88.09263611, 21.81361961], [88.09281158, 21.81406021], [88.09301758, 21.81449127], [88.0931778, 21.81496048], [88.09337616, 21.81541061], [88.09362793, 21.81580925], [88.09394073, 21.81616402], [88.09427643, 21.81649017], [88.09445953, 21.81694031], [88.09461212, 21.81736946], [88.09481049, 21.81775093], [88.09506226, 21.81809807], [88.09536743, 21.81842232], [88.09568787, 21.81872177], [88.09601593, 21.81899643], [88.09627533, 21.81924248], [88.09646606, 21.8194828], [88.09658051, 21.81976509], [88.09655762, 21.82016945], [88.09645081, 21.82069969], [88.09660339, 21.82105446], [88.0969162, 21.82133484], [88.09720612, 21.82163048], [88.09749603, 21.82192421], [88.09765625, 21.82210922], [88.09773254, 21.82219887], [88.09788513, 21.82247162], [88.09806061, 21.82272148], [88.09825134, 21.82299042], [88.09844971, 21.82332039], [88.09867859, 21.82370186], [88.09889221, 21.82414055], [88.09900665, 21.82468414], [88.09903717, 21.82533836], [88.09926605, 21.82592773], [88.09951782, 21.82647133], [88.09971619, 21.82691956], [88.0998764, 21.82725716], [88.09996796, 21.82753181], [88.09999847, 21.82780266], [88.10002899, 21.82808113], [88.1001358, 21.8283329], [88.10031128, 21.82855797], [88.10051727, 21.82877922], [88.10069275, 21.8290596], [88.10080719, 21.82949066], [88.10089111, 21.82999039], [88.10111237, 21.8304615], [88.10134125, 21.83093071], [88.10147095, 21.83144951], [88.10166168, 21.83193016], [88.10187531, 21.83240509], [88.10217285, 21.83283997], [88.10247803, 21.83328629], [88.10282135, 21.83369827], [88.10307312, 21.83418846], [88.10333252, 21.83465958], [88.10359192, 21.83514214], [88.10388947, 21.83583069], [88.10415649, 21.83611107], [88.10415649, 21.83638954], [88.10444641, 21.83666611], [88.10444641, 21.83694077], [88.10527802, 21.83777809], [88.10527802, 21.83805084], [88.10610962, 21.83889008], [88.10610962, 21.83917046], [88.10694122, 21.84000015], [88.10694122, 21.84026909], [88.10722351, 21.84055519], [88.10721588, 21.84083176], [88.10805511, 21.84166718], [88.10806274, 21.84194183], [88.10861206, 21.84250069], [88.10861206, 21.84277725], [88.10884857, 21.84301186], [88.10916901, 21.84333038], [88.10916901, 21.84361076], [88.11055756, 21.84500122], [88.11055756, 21.84527969], [88.11083221, 21.84555435], [88.11083221, 21.84583282], [88.11194611, 21.84694099], [88.11194611, 21.84749985], [88.11277771, 21.84833336], [88.11277771, 21.84860992], [88.11333466, 21.84916878], [88.11332703, 21.84971809], [88.11416626, 21.85055542], [88.11415863, 21.85082817], [88.11499786, 21.8516674], [88.11499786, 21.85193825], [88.11554718, 21.85250092], [88.11554718, 21.85277939], [88.1158371, 21.85305595], [88.1158371, 21.8533287], [88.11611176, 21.8536129], [88.11611176, 21.85416985], [88.1169281, 21.85499954], [88.11694336, 21.85555649], [88.11750031, 21.85610962], [88.11750031, 21.85667038], [88.11777496, 21.85694313], [88.11778259, 21.85731506], [88.11798096, 21.8575592], [88.11820221, 21.85783386], [88.11856079, 21.85833168], [88.1188736, 21.85882759], [88.11915588, 21.85931015], [88.11943817, 21.85975075], [88.11971283, 21.86014938], [88.11995697, 21.86053658], [88.12013245, 21.86096191], [88.12030792, 21.86140442], [88.12050629, 21.86181831], [88.1206131, 21.86227989], [88.12078094, 21.86268044], [88.12091827, 21.86312103], [88.12111664, 21.86354065], [88.12133789, 21.86398125], [88.12143707, 21.8644619], [88.12162781, 21.8648777], [88.12174988, 21.86531067], [88.12195587, 21.86567116], [88.1222229, 21.86600113], [88.12249756, 21.86632919], [88.12278748, 21.86665154], [88.12310028, 21.86694336], [88.12342072, 21.86722183], [88.12374878, 21.86750221], [88.12407684, 21.8678112], [88.12442017, 21.86819267], [88.12475586, 21.86865044], [88.12516785, 21.8691597], [88.12565613, 21.86965942], [88.12618256, 21.87009811], [88.12664032, 21.87055969], [88.12701416, 21.87100983], [88.12740326, 21.87137985], [88.12776184, 21.87174034], [88.12809753, 21.87210083], [88.12841797, 21.87244034], [88.1287384, 21.8727417], [88.12906647, 21.8730011], [88.12944794, 21.87320709], [88.12982178, 21.87342453], [88.13018036, 21.87364006], [88.13050842, 21.87390327], [88.13082123, 21.87420273], [88.1311264, 21.87455177], [88.13145447, 21.87488556], [88.13182068, 21.87515068], [88.13218689, 21.87539291], [88.13250732, 21.87566948], [88.13285828, 21.87592697], [88.13319397, 21.87622261], [88.13356018, 21.87650108], [88.13391876, 21.87683678], [88.1342926, 21.87717247], [88.13472748, 21.87742615], [88.13500977, 21.87744713], [88.13525391, 21.87746239], [88.13576508, 21.87734795], [88.13617706, 21.87710953], [88.13639069, 21.87666893], [88.13667297, 21.87639809], [88.13639069, 21.87610817], [88.13666534, 21.87583351], [88.13666534, 21.87555695], [88.13694763, 21.87528038], [88.13694763, 21.875], [88.13722229, 21.87471962], [88.13749695, 21.875], [88.13777924, 21.87471962], [88.13777924, 21.87333298], [88.13803864, 21.87306023], [88.13803864, 21.87277985], [88.13835144, 21.87249947], [88.13832855, 21.8723774], [88.13851166, 21.87189102], [88.13864899, 21.87138939], [88.13883972, 21.87097931], [88.13897705, 21.87061119], [88.13913727, 21.87026024], [88.13923645, 21.86988068], [88.13944244, 21.86950874], [88.13965607, 21.8690815], [88.13985443, 21.86860275], [88.1400528, 21.86812019], [88.14028168, 21.8676796], [88.1404953, 21.8672657], [88.14063263, 21.86681175], [88.14084625, 21.86637115], [88.14112854, 21.86594009], [88.14142609, 21.86550903], [88.14161682, 21.86501122], [88.14173889, 21.86449623], [88.14199066, 21.86413956], [88.14225006, 21.86384964], [88.14248657, 21.86358261], [88.14269257, 21.86331749], [88.14286804, 21.86305809], [88.14305878, 21.86282349], [88.14324188, 21.86257553], [88.1434021, 21.86228943], [88.14359283, 21.86202049], [88.14376831, 21.86175346], [88.14389038, 21.86143494], [88.14399719, 21.86111069], [88.14414978, 21.86078072], [88.14428711, 21.8604393], [88.14447021, 21.86013985], [88.14467621, 21.85985947], [88.14493561, 21.8595295], [88.14530182, 21.85913086], [88.14565277, 21.85859108], [88.14559174, 21.85802078], [88.14556122, 21.85748291], [88.14561462, 21.85699463], [88.14582825, 21.85658264], [88.1460495, 21.85618973], [88.14620972, 21.85577011], [88.14634705, 21.85542107], [88.14640808, 21.85506248], [88.14651489, 21.85475159], [88.14665222, 21.85447121], [88.14678192, 21.85416985], [88.14696503, 21.85386276], [88.14717865, 21.85353851], [88.14739227, 21.85316086], [88.1476059, 21.85275078], [88.14775085, 21.85230255], [88.14782715, 21.85183334], [88.14800262, 21.85137939], [88.14805603, 21.85090065], [88.14813995, 21.85041809], [88.14831543, 21.85000229], [88.14848328, 21.84956932], [88.14863586, 21.84912109], [88.14885712, 21.84865952], [88.14906311, 21.84815025], [88.14920807, 21.84754944], [88.14943695, 21.84698677], [88.14965057, 21.84642029], [88.14974976, 21.84583092], [88.14987946, 21.84532166], [88.15003204, 21.84491348], [88.15021515, 21.84457016], [88.15032959, 21.84419632], [88.15049744, 21.84383011], [88.1505661, 21.84336281], [88.15065765, 21.8428421], [88.15084076, 21.84232712], [88.15103149, 21.84184074], [88.15116119, 21.84133339], [88.15139008, 21.84089088], [88.15161896, 21.84041977], [88.15177917, 21.83990479], [88.15196228, 21.83944702], [88.1521759, 21.83905029], [88.15236664, 21.83864594], [88.15258026, 21.83824348], [88.15278625, 21.83781052], [88.15302277, 21.83735085], [88.15315247, 21.83680916], [88.15338898, 21.83632851], [88.15365601, 21.83590508], [88.15393066, 21.83551979], [88.15418243, 21.83512115], [88.15445709, 21.83469009], [88.15472412, 21.834198], [88.15500641, 21.83365059], [88.15531158, 21.83310127], [88.15570068, 21.83263016], [88.15606689, 21.83218956], [88.15638733, 21.83172989], [88.15666962, 21.83126068], [88.15693665, 21.83077049], [88.15721893, 21.83029938], [88.15751648, 21.82987022], [88.15782166, 21.82948112], [88.15811157, 21.8291111], [88.15837097, 21.82874107], [88.15864563, 21.82842255], [88.15891266, 21.82812119], [88.15917206, 21.82781982], [88.15943909, 21.82749939], [88.15972137, 21.82715416], [88.16001892, 21.82674217], [88.16039276, 21.82628822], [88.1608429, 21.82582092], [88.16130066, 21.82538033], [88.16175079, 21.82497978], [88.16213989, 21.82454109], [88.16252136, 21.82415009], [88.16285706, 21.82380676], [88.16312408, 21.82348251], [88.16339111, 21.82318878], [88.16371155, 21.82287025], [88.16414642, 21.82250977], [88.164711, 21.82211876], [88.16526794, 21.82167053], [88.16638947, 21.82055092], [88.16666412, 21.82055664], [88.16666412, 21.82027626], [88.16694641, 21.81999969], [88.16750336, 21.81999969], [88.16916656, 21.81833076], [88.16916656, 21.8180542], [88.16999817, 21.81722069], [88.16999817, 21.81694221], [88.17028046, 21.81666756], [88.17028046, 21.81610107], [88.17055511, 21.81583214], [88.17055511, 21.81555557], [88.17082977, 21.81528282], [88.17082977, 21.81472015], [88.17138672, 21.81416702], [88.17140198, 21.8133316], [88.17194366, 21.81277847], [88.17193604, 21.81250191], [88.17250061, 21.81195259], [88.17250061, 21.81082916], [88.17194366, 21.81027985], [88.17166901, 21.81028938], [88.17155457, 21.8101635], [88.17140198, 21.80999947], [88.17082977, 21.80999947], [88.17056274, 21.80971909], [88.16972351, 21.8097229], [88.16955566, 21.80955315], [88.16944122, 21.80944443], [88.16889191, 21.80944443], [88.16860962, 21.80916786], [88.16832733, 21.80916977], [88.16777802, 21.80861092], [88.16750336, 21.80861092], [88.16722107, 21.80833054], [88.16694641, 21.80833244], [88.16611481, 21.80750084], [88.16583252, 21.80722046], [88.16583252, 21.8069458], [88.16527557, 21.80638885], [88.16526794, 21.80611038], [88.16500092, 21.80583], [88.16500092, 21.80555344], [88.16443634, 21.80500031], [88.16443634, 21.80416107], [88.16416931, 21.80388832], [88.16416931, 21.80249977], [88.16400909, 21.80191994], [88.16390991, 21.80133247], [88.1638031, 21.80074501], [88.16366577, 21.80014992], [88.16364288, 21.7995491], [88.16366577, 21.79896164], [88.16378021, 21.79842758], [88.16384888, 21.79793167], [88.16381073, 21.79745293], [88.16370392, 21.79701614], [88.16368866, 21.79656982], [88.16378784, 21.79624939], [88.16383362, 21.79610443], [88.16390228, 21.79560661], [88.16398621, 21.79510117], [88.16412354, 21.79461479], [88.16420746, 21.7940979], [88.16432953, 21.79358292], [88.16441345, 21.79305458], [88.1644516, 21.79252815], [88.16449738, 21.79199982], [88.16464996, 21.79152107], [88.16475677, 21.79099083], [88.16496277, 21.79047012], [88.1651001, 21.78992271], [88.16529083, 21.78939056], [88.16552734, 21.78889084], [88.16567993, 21.78837013], [88.16587067, 21.78790092], [88.16611481, 21.78749466], [88.16638184, 21.78709602], [88.16661072, 21.78664017], [88.16668701, 21.78602982], [88.1668396, 21.78543854], [88.1671524, 21.78494263], [88.16748047, 21.78444672], [88.16779327, 21.78391266], [88.1680603, 21.78339386], [88.16828918, 21.7829113], [88.16842651, 21.78243065], [88.16857147, 21.78199768], [88.16864014, 21.78154945], [88.16876221, 21.78108978], [88.16887665, 21.78061676], [88.16897583, 21.78014946], [88.16912842, 21.77972031], [88.16918182, 21.77931786], [88.16911316, 21.77886009], [88.16918945, 21.77856064], [88.16931915, 21.77828979], [88.16941833, 21.77799034], [88.16944122, 21.77762032], [88.16944885, 21.77720261], [88.16947174, 21.77675056], [88.16956329, 21.77629089], [88.16969299, 21.77584076], [88.1697464, 21.77539063], [88.1698761, 21.77498055], [88.17002106, 21.77459335], [88.17018127, 21.77423286], [88.17025757, 21.7737999], [88.17028809, 21.77333069], [88.17035675, 21.77282906], [88.17050171, 21.77231026], [88.17054749, 21.77176476], [88.17055511, 21.77120972], [88.17054749, 21.77067757], [88.17054749, 21.77017784], [88.17056274, 21.76971054], [88.17063141, 21.76926041], [88.17077637, 21.76880074], [88.17086792, 21.76824951], [88.17098236, 21.76768494], [88.17088318, 21.76708984], [88.17089081, 21.7665081], [88.1710434, 21.76592064], [88.1710968, 21.76531792], [88.17108917, 21.76470184], [88.17105103, 21.76405907], [88.17090607, 21.76343727], [88.17064667, 21.76284027], [88.17031097, 21.76224518], [88.1700592, 21.76165962], [88.1699295, 21.76106071], [88.16991425, 21.7605114], [88.16993713, 21.75995064], [88.16996765, 21.7593708], [88.17003632, 21.75877953], [88.17014313, 21.7582016], [88.17021942, 21.75764084], [88.17023468, 21.75707436], [88.17017365, 21.75647545], [88.17014313, 21.75588036], [88.17024994, 21.75531006], [88.17048645, 21.75476646], [88.1707077, 21.75424957], [88.17089844, 21.75374031], [88.17098236, 21.75316048], [88.17088318, 21.75257111], [88.17077637, 21.75199127], [88.17063904, 21.75146103], [88.17057037, 21.75097084], [88.17059326, 21.75052071], [88.1707077, 21.75008011], [88.17071533, 21.74964142], [88.17060089, 21.74919319], [88.17056274, 21.74873543], [88.17056274, 21.74829102], [88.17056274, 21.74785995], [88.17059326, 21.74744987], [88.17072296, 21.74706078], [88.17082214, 21.74666023], [88.1708374, 21.74619293], [88.17086029, 21.74566078], [88.17094421, 21.74510193], [88.17086029, 21.7445507], [88.17079926, 21.74399948], [88.17067719, 21.7434597], [88.17061615, 21.74291992], [88.17066193, 21.74240112], [88.17057037, 21.74192047], [88.17047119, 21.7414608], [88.1703186, 21.74104881], [88.17027283, 21.74061012], [88.17022705, 21.74021721], [88.17016602, 21.7397995], [88.16986084, 21.73917007], [88.16970825, 21.73847961], [88.16963196, 21.73783112], [88.16954803, 21.73727989], [88.1693573, 21.73677826], [88.16915131, 21.73623848], [88.16902161, 21.73570061], [88.16890717, 21.73521996], [88.16884613, 21.73483086], [88.16873932, 21.73456192], [88.16863251, 21.73428917], [88.16855621, 21.73395157], [88.16837311, 21.73361969], [88.16817474, 21.73316956], [88.1679306, 21.73269081], [88.16757965, 21.73230171], [88.16724396, 21.7319622], [88.16692352, 21.73162842], [88.16665649, 21.73124123], [88.16638947, 21.73085022], [88.16612244, 21.73045349], [88.16588593, 21.7300396], [88.16570282, 21.72958755], [88.16552734, 21.72912025], [88.16533661, 21.72866058], [88.16525269, 21.72813034], [88.16510773, 21.72758675], [88.16497803, 21.72701073], [88.16487122, 21.7264328], [88.16468811, 21.72587967], [88.16449738, 21.72537994], [88.16440582, 21.72480011], [88.16426849, 21.72421074], [88.16443634, 21.72360992], [88.16444397, 21.72194481], [88.16388702, 21.72138977], [88.16388702, 21.72056007], [88.16361237, 21.72027969], [88.16361237, 21.72000122], [88.16333008, 21.71970749], [88.16333008, 21.7191658], [88.16278076, 21.71861076], [88.16278076, 21.71805954], [88.16249847, 21.71777916], [88.16249847, 21.71750069], [88.16220856, 21.7172184], [88.16222382, 21.71666718], [88.16166687, 21.71611023], [88.16166687, 21.71582985], [88.16110992, 21.71527863], [88.16110992, 21.71500015], [88.16055298, 21.71445084], [88.16055298, 21.71389961], [88.15999603, 21.71333122], [88.16000366, 21.71305656], [88.15944672, 21.71249962], [88.15944672, 21.71138954], [88.15916443, 21.71111107], [88.15888977, 21.71111107], [88.15860748, 21.71084023], [88.15860748, 21.71055984], [88.15833282, 21.71027946], [88.15833282, 21.70944023], [88.15805817, 21.70916748], [88.15833282, 21.7089901], [88.1580658, 21.70861626], [88.15782928, 21.70824051], [88.15766907, 21.70782852], [88.15750122, 21.70722008], [88.15750122, 21.70666695], [88.15666962, 21.70583153], [88.15666962, 21.70555496], [88.15611267, 21.70500183], [88.15666962, 21.70443916], [88.15666962, 21.70388985], [88.15638733, 21.70360756], [88.15638733, 21.70222282], [88.15611267, 21.70194435], [88.15611267, 21.70111084], [88.15556335, 21.70055962], [88.15556335, 21.69972038], [88.15583038, 21.69944572], [88.15583038, 21.69861031], [88.15528107, 21.69806099], [88.15499878, 21.69750023], [88.15499878, 21.69721985], [88.15472412, 21.69694328], [88.15471649, 21.69667053], [88.15444183, 21.69639015], [88.15444183, 21.69553947], [88.15416718, 21.69527817], [88.15416718, 21.69472122], [88.15389252, 21.69444466], [88.15389252, 21.69388962], [88.15416718, 21.69361115], [88.15416718, 21.69306183], [88.15361023, 21.69249916], [88.15361023, 21.69082832], [88.15437317, 21.6909008], [88.15440369, 21.6905899], [88.1544342, 21.69028282], [88.15444183, 21.6897068], [88.15439606, 21.68919945], [88.15422058, 21.68879128], [88.15416718, 21.68835068], [88.15416718, 21.68790054], [88.15416718, 21.68742943], [88.15416718, 21.68694115], [88.15426636, 21.68645096], [88.15445709, 21.68597984], [88.15470886, 21.68554306], [88.15481567, 21.6850853], [88.15457153, 21.68453026], [88.15434265, 21.68406868], [88.15416718, 21.68359947], [88.15389252, 21.68361092], [88.15305328, 21.6827774], [88.15277863, 21.68278122], [88.15249634, 21.68250084], [88.15222168, 21.68250084], [88.15194702, 21.68222046], [88.15166473, 21.68222237], [88.15110779, 21.68166733], [88.15083313, 21.68167114], [88.15055847, 21.68139076], [88.15029144, 21.68139076], [88.14987183, 21.68094826], [88.14977264, 21.68084335], [88.14955902, 21.68061256], [88.14945984, 21.68050957], [88.14923859, 21.68042183], [88.14885712, 21.68025017], [88.14842987, 21.68007278], [88.14816284, 21.67996407], [88.14800262, 21.67990112], [88.14758301, 21.67975044], [88.14713287, 21.67967987], [88.14662933, 21.67966461], [88.14611816, 21.67964554], [88.14560699, 21.67958069], [88.14512634, 21.67956543], [88.14465332, 21.67955971], [88.14411163, 21.67955208], [88.1434021, 21.67955208], [88.14368439, 21.67914963], [88.14440155, 21.67874908], [88.14671326, 21.67847061], [88.14716339, 21.67857933], [88.14765167, 21.67872238], [88.14820099, 21.67888832], [88.14879608, 21.67910957], [88.14940643, 21.67940903], [88.14997864, 21.67976952], [88.15049744, 21.68015289], [88.15103149, 21.68041039], [88.15161133, 21.68053818], [88.15181732, 21.68056107], [88.15194702, 21.6807003], [88.15222168, 21.68111038], [88.15222168, 21.68139076], [88.15249634, 21.68167114], [88.15361023, 21.68166733], [88.15389252, 21.68194389], [88.15472412, 21.68194389], [88.15528107, 21.68138885], [88.15528107, 21.68028259], [88.15556335, 21.68000031], [88.15555573, 21.67944527], [88.15583038, 21.67917252], [88.15583038, 21.67861176], [88.15555573, 21.67833328], [88.15583038, 21.67805481], [88.15583038, 21.67666626], [88.15528107, 21.67611122], [88.15583038, 21.67555809], [88.15595245, 21.67514038], [88.15583801, 21.67469978], [88.15569305, 21.67428017], [88.15549469, 21.67395973], [88.15532684, 21.67358971], [88.1554184, 21.67317963], [88.15556335, 21.67271042], [88.15568542, 21.67222786], [88.15582275, 21.67173004], [88.15588379, 21.67122078], [88.15612793, 21.67078018], [88.15637207, 21.67036629], [88.15643311, 21.66988945], [88.15600586, 21.66926003], [88.15598297, 21.66867256], [88.15635681, 21.66813087], [88.15657806, 21.66757011], [88.15644073, 21.66712952], [88.15628052, 21.66667938], [88.15609741, 21.66624069], [88.15583038, 21.66583252], [88.15611267, 21.66555595], [88.15611267, 21.66472054], [88.15638733, 21.66444397], [88.15638733, 21.6641674], [88.15611267, 21.66416931], [88.15583038, 21.66389084], [88.15583038, 21.66221809], [88.15499878, 21.6613884], [88.15471649, 21.6613903], [88.15416718, 21.66082954], [88.15416718, 21.66027832], [88.15444183, 21.65999985], [88.15444183, 21.65971947], [88.15416718, 21.65944672], [88.15416718, 21.65888977], [88.15389252, 21.65860939], [88.15389252, 21.65583229], [88.15444183, 21.65527725], [88.15444183, 21.65389061], [88.15471649, 21.65361977], [88.15471649, 21.65306282], [88.15499878, 21.65278053], [88.15499878, 21.6511097], [88.15472412, 21.65083313], [88.15472412, 21.64999962], [88.15444183, 21.64972115], [88.15361023, 21.64972305], [88.15333557, 21.64944458], [88.15333557, 21.64916611], [88.15277863, 21.64861107], [88.15277863, 21.64833069], [88.15249634, 21.64805794], [88.15249634, 21.64750099], [88.15222168, 21.64722061], [88.15222168, 21.64694595], [88.15194702, 21.64666748], [88.15194702, 21.64639091], [88.14943695, 21.64389038], [88.14943695, 21.64361], [88.14888763, 21.64305305], [88.14861298, 21.64306068], [88.14833069, 21.6427803], [88.14805603, 21.6427803], [88.14749908, 21.64221954], [88.14694214, 21.64222145], [88.14638519, 21.64166641], [88.14639282, 21.64138985], [88.14556122, 21.64056015], [88.14554596, 21.63999939], [88.14472198, 21.63916969], [88.14444733, 21.63916969], [88.14250183, 21.63722038], [88.14250183, 21.63694382], [88.14277649, 21.63666725], [88.14221954, 21.63611031], [88.14221954, 21.63555908], [88.14250183, 21.63528061], [88.14250183, 21.63500023], [88.14332581, 21.63417053], [88.14332581, 21.63360977], [88.14221954, 21.63249969], [88.14167023, 21.63249969], [88.14138794, 21.63222313], [88.14111328, 21.63222313], [88.14055634, 21.63166428], [88.13999939, 21.63167], [88.1397171, 21.63138962], [88.13889313, 21.63138962], [88.13861084, 21.63167], [88.13833618, 21.63166428], [88.13805389, 21.63194656], [88.13777924, 21.63194656], [88.13749695, 21.63222313], [88.13666534, 21.63222313], [88.1361084, 21.63166428], [88.13582611, 21.63167], [88.13582611, 21.63138962], [88.13609314, 21.63096046], [88.13639069, 21.63055992], [88.13582611, 21.63000107], [88.13555908, 21.63000107], [88.13529205, 21.62972069], [88.13500214, 21.6297226], [88.13471985, 21.62944221], [88.13361359, 21.62944221], [88.1333313, 21.6297226], [88.13249969, 21.6297226], [88.13222504, 21.62944221], [88.13194275, 21.62944221], [88.13194275, 21.62916756], [88.13166809, 21.6288929], [88.13083649, 21.6288929], [88.13054657, 21.62861061], [88.1297226, 21.62861061], [88.12944794, 21.62833023], [88.12916565, 21.62833214], [88.12889099, 21.62805557], [88.1286087, 21.62805557], [88.12833405, 21.62833214], [88.12805176, 21.62833023], [88.1277771, 21.62861061], [88.12722015, 21.62861061], [88.12695313, 21.62833023], [88.1258316, 21.62833023], [88.12555695, 21.62861061], [88.12444305, 21.62861061], [88.1241684, 21.62833023], [88.12361145, 21.62833214], [88.12333679, 21.62805557], [88.12166595, 21.62805939], [88.1213913, 21.62778282], [88.12110901, 21.62778282], [88.12082672, 21.62750053], [88.12055206, 21.62750053], [88.12029266, 21.62722015], [88.12000275, 21.62722015], [88.11972046, 21.62694359], [88.11694336, 21.62694359], [88.1162262, 21.62622643], [88.11611176, 21.62611008], [88.1158371, 21.62611008], [88.11555481, 21.62583351]]], [[[88.99967194, 21.78546906], [89.0, 21.78471756], [89.00055695, 21.78504944], [89.00093079, 21.78511047], [89.00137329, 21.78499031], [89.0018692, 21.78502274], [89.00241089, 21.78483009], [89.00299835, 21.7846508], [89.00360107, 21.78444862], [89.00422668, 21.7842598], [89.00488281, 21.78408813], [89.00548553, 21.78388023], [89.00605774, 21.78365135], [89.0066452, 21.78347969], [89.00718689, 21.7833004], [89.0076828, 21.78307152], [89.00814819, 21.78284073], [89.00862885, 21.78264809], [89.00908661, 21.78248024], [89.00952148, 21.78224182], [89.00989532, 21.7820282], [89.01026154, 21.78178215], [89.01061249, 21.78149986], [89.01098633, 21.78121185], [89.01127625, 21.78088951], [89.01145935, 21.78053284], [89.01158142, 21.78022766], [89.01161194, 21.77994347], [89.01156616, 21.77961922], [89.01148224, 21.77927971], [89.01133728, 21.77889061], [89.01110077, 21.77849007], [89.01078033, 21.77804184], [89.01036072, 21.77760124], [89.00979614, 21.77725029], [89.00923157, 21.77695084], [89.00865173, 21.77667046], [89.00811768, 21.77639008], [89.00762939, 21.7761097], [89.00717926, 21.7758522], [89.00672913, 21.7756443], [89.00628662, 21.77550125], [89.00591278, 21.7753315], [89.00556183, 21.77522278], [89.00530243, 21.77507019], [89.00502014, 21.77499008], [89.0047226, 21.7748909], [89.00437927, 21.77474976], [89.00395966, 21.77466774], [89.00350952, 21.77448082], [89.00305176, 21.77431107], [89.00257874, 21.77414131], [89.00214386, 21.7739048], [89.00170898, 21.77366829], [89.00123596, 21.77347946], [89.00078583, 21.77329063], [89.00038147, 21.77300072], [89.0, 21.77277756], [88.99922943, 21.7725811], [88.99872589, 21.77216721], [88.99866486, 21.77211571], [88.99854279, 21.7720108], [88.99804688, 21.77166939], [88.99769592, 21.77139091], [88.99736023, 21.77098083], [88.99707031, 21.77055931], [88.99694824, 21.77000046], [88.99672699, 21.76868057], [88.99666595, 21.76832962], [88.99666595, 21.76802063], [88.99666595, 21.76749992], [88.99666595, 21.76721954], [88.99666595, 21.76694679], [88.99666595, 21.7658329], [88.99672699, 21.76555443], [88.99694824, 21.76416969], [88.99693298, 21.76395988], [88.9972229, 21.76305962], [88.99729156, 21.76278114], [88.99749756, 21.76222038], [88.99748993, 21.76194382], [88.99777985, 21.76083183], [88.99777222, 21.76062012], [88.99777222, 21.7602787], [88.99777985, 21.76000023], [88.99777985, 21.75917244], [88.99798584, 21.75889015], [88.99804688, 21.75832748], [88.9982605, 21.75805473], [88.99833679, 21.75777817], [88.99826813, 21.75749969], [88.99841309, 21.75687981], [88.99861145, 21.75638962], [88.99861145, 21.75611115], [88.99846649, 21.75582123], [88.99861145, 21.75555611], [88.99861145, 21.75500107], [88.99888611, 21.75472069], [88.99888611, 21.75416756], [88.9988327, 21.75389099], [88.99888611, 21.75361061], [88.99888611, 21.75307083], [88.9991684, 21.75278091], [88.9991684, 21.75167084], [88.99944305, 21.75139046], [88.99944305, 21.7508297], [88.99972534, 21.75055313], [89.0, 21.75000954], [89.00026703, 21.74971962], [89.00027466, 21.74944305], [89.00056458, 21.74819183], [89.00055695, 21.74781036], [89.00084686, 21.74735832], [89.00094604, 21.74711037], [89.00108337, 21.74683952], [89.00114441, 21.74653053], [89.00126648, 21.7462368], [89.00139618, 21.7459507], [89.00154114, 21.74568558], [89.00171661, 21.74542236], [89.00195313, 21.74514771], [89.00224304, 21.74481964], [89.00253296, 21.74443054], [89.0029068, 21.74402046], [89.00324249, 21.7435627], [89.00347137, 21.74305916], [89.00366974, 21.74259186], [89.00390625, 21.74221039], [89.00421143, 21.74189949], [89.00449371, 21.74160194], [89.00474548, 21.74125099], [89.00501251, 21.7409153], [89.00531769, 21.74060059], [89.00566101, 21.74031258], [89.00603485, 21.74006653], [89.00637817, 21.73977852], [89.00668335, 21.73945045], [89.0069809, 21.73913193], [89.00728607, 21.73880959], [89.00756073, 21.73846626], [89.00789642, 21.7381897], [89.00823212, 21.73789978], [89.00860596, 21.73764992], [89.0089798, 21.73741341], [89.0093689, 21.7371788], [89.00971985, 21.73689079], [89.01004791, 21.73659134], [89.01030731, 21.7362175], [89.01058197, 21.73587036], [89.01088715, 21.73557281], [89.01121521, 21.73530769], [89.01156616, 21.73508072], [89.01191711, 21.73480988], [89.01220703, 21.73444939], [89.01248169, 21.7340641], [89.01274109, 21.73366356], [89.01302338, 21.73330688], [89.01330566, 21.73296356], [89.0135498, 21.73261642], [89.01373291, 21.73223114], [89.01387787, 21.73187256], [89.01399994, 21.73150063], [89.01418304, 21.73114014], [89.01438141, 21.73074341], [89.01499939, 21.7284565], [89.01503754, 21.72792053], [89.0152359, 21.72738075], [89.01526642, 21.72678947], [89.01528931, 21.7261982], [89.01539612, 21.72565079], [89.01542664, 21.72392845], [89.01529694, 21.72319221], [89.0152359, 21.72252083], [89.0151062, 21.72191048], [89.01506805, 21.72129822], [89.01522827, 21.72072983], [89.01526642, 21.72014046], [89.01521301, 21.71959114], [89.01502991, 21.71914864], [89.01486206, 21.71879005], [89.01445007, 21.71860123], [89.01402283, 21.71845818], [89.01357269, 21.71837044], [89.0131073, 21.71807289], [89.01263428, 21.71805763], [89.0120697, 21.71820259], [89.01156616, 21.71832085], [89.0111618, 21.71828651], [89.01063538, 21.71829414], [89.01026154, 21.71800423], [89.00995636, 21.71766853], [89.00937653, 21.71763039], [89.00884247, 21.71769905], [89.00836182, 21.71754074], [89.00786591, 21.71738052], [89.0074234, 21.71718407], [89.00699615, 21.71693993], [89.0065918, 21.71672821], [89.00614929, 21.71657944], [89.00575256, 21.71639824], [89.00531769, 21.71627045], [89.00483704, 21.71613121], [89.00428009, 21.71607208], [89.00370026, 21.71607208], [89.00315857, 21.71611977], [89.00267792, 21.71623993], [89.00215912, 21.71642113], [89.00157166, 21.71664047], [89.00088501, 21.71677971], [89.0, 21.71722221], [88.99971771, 21.71742821], [88.99938202, 21.71777534], [88.99898529, 21.71805191], [88.99893188, 21.71810341], [88.99749756, 21.71944427], [88.9972229, 21.71943855], [88.99666595, 21.72000122], [88.99666595, 21.72027779], [88.99500275, 21.72194481], [88.99500275, 21.72221947], [88.9944458, 21.72277832], [88.9944458, 21.72305489], [88.99416351, 21.72333336], [88.99388885, 21.72332954], [88.99359894, 21.72346115], [88.99331665, 21.72357559], [88.99297333, 21.72370911], [88.99256897, 21.72390938], [88.99211884, 21.72414017], [88.99160767, 21.72435951], [88.99103546, 21.72454643], [88.99051666, 21.72476006], [88.99008942, 21.7250042], [88.98973083, 21.72523117], [88.98932648, 21.72540283], [88.98892212, 21.7255497], [88.98849487, 21.72567749], [88.98834991, 21.72572136], [88.98805237, 21.72581291], [88.98757172, 21.72592354], [88.98709869, 21.7260685], [88.98660278, 21.7261982], [88.98609924, 21.72634125], [88.98558044, 21.72644043], [88.9850769, 21.72661018], [88.98500061, 21.72661591], [88.98416901, 21.7266674], [88.98388672, 21.72694588], [88.98194122, 21.72694588], [88.98166656, 21.72722244], [88.9808197, 21.72722054], [88.98055267, 21.72750092], [88.97972107, 21.72750092], [88.97944641, 21.72777939], [88.97833252, 21.72777557], [88.97817993, 21.72794533], [88.97807312, 21.72805977], [88.97721863, 21.72805977], [88.97666931, 21.72861099], [88.97666931, 21.72916985], [88.97693634, 21.72954941], [88.97712708, 21.73006058], [88.97728729, 21.73063087], [88.97755432, 21.7311554], [88.97793579, 21.7315731], [88.97834778, 21.73193932], [88.97879791, 21.73223114], [88.9792099, 21.73258018], [88.97960663, 21.73290825], [88.98007202, 21.73316002], [88.98043823, 21.73348808], [88.98064423, 21.73366165], [88.98081207, 21.73380089], [88.98114777, 21.73414612], [88.98150635, 21.73442841], [88.98190308, 21.73468971], [88.98230743, 21.73492241], [88.98275757, 21.73509026], [88.98320007, 21.73526764], [88.98364258, 21.73545074], [88.98410797, 21.73565102], [88.98452759, 21.73594666], [88.98491669, 21.73631477], [88.98535919, 21.73664284], [88.98549652, 21.73672867], [88.98581696, 21.73693275], [88.98623657, 21.7372303], [88.98661804, 21.73754501], [88.98693848, 21.73791122], [88.98722839, 21.7383194], [88.98760223, 21.7387085], [88.98797607, 21.73908806], [88.98834991, 21.73945045], [88.98866272, 21.73984909], [88.98888397, 21.74032211], [88.98906708, 21.74078941], [88.98920441, 21.74124527], [88.98937988, 21.74164009], [88.98944092, 21.74207878], [88.98945618, 21.74253273], [88.98945618, 21.74300194], [88.98944092, 21.7434597], [88.98937988, 21.74385071], [88.98923492, 21.7441597], [88.989151, 21.74448013], [88.98903656, 21.74478912], [88.98892212, 21.74513054], [88.98876953, 21.7455101], [88.98854065, 21.74591255], [88.9882431, 21.74630928], [88.98787689, 21.74664879], [88.98749542, 21.74694252], [88.98711395, 21.74715042], [88.98667908, 21.7472229], [88.98625183, 21.74728394], [88.9858551, 21.74741936], [88.98583221, 21.74749947], [88.9852829, 21.74749947], [88.98500061, 21.74777985], [88.98443604, 21.74777985], [88.98416901, 21.74806023], [88.98387909, 21.74806023], [88.98368073, 21.74781036], [88.98347473, 21.74776077], [88.98314667, 21.74768066], [88.98274994, 21.74749184], [88.98233032, 21.74730492], [88.98184204, 21.74709702], [88.98137665, 21.74685097], [88.9809494, 21.74662209], [88.98055267, 21.74637413], [88.98018646, 21.7461071], [88.97982025, 21.74582863], [88.97945404, 21.74557114], [88.97905731, 21.74533081], [88.9786377, 21.74513054], [88.97823334, 21.74489975], [88.97782898, 21.74468803], [88.97743225, 21.74446106], [88.97698975, 21.74423027], [88.97650146, 21.74403954], [88.97599792, 21.74380112], [88.97563171, 21.74343109], [88.97520447, 21.74318695], [88.97476196, 21.74296951], [88.9743576, 21.74272156], [88.97396088, 21.74243927], [88.97358704, 21.74210167], [88.9732132, 21.74176979], [88.97283173, 21.74148178], [88.97237396, 21.74131966], [88.97197723, 21.74113083], [88.97174072, 21.74099731], [88.97162628, 21.74093246], [88.97127533, 21.74078369], [88.97098541, 21.74061012], [88.97068024, 21.74047661], [88.97041321, 21.74035072], [88.97009277, 21.74033928], [88.96977234, 21.74045372], [88.96942902, 21.74053383], [88.96907806, 21.74060059], [88.96871185, 21.74070549], [88.96835327, 21.74084091], [88.96800232, 21.74104881], [88.96766663, 21.74126053], [88.96734619, 21.74154091], [88.96711731, 21.74189949], [88.96687317, 21.74231148], [88.96666718, 21.74280167], [88.96647644, 21.74335289], [88.96641541, 21.74397087], [88.96639252, 21.74465942], [88.96640778, 21.74531174], [88.96641541, 21.74541092], [88.96644592, 21.74587631], [88.96644592, 21.74640274], [88.96646881, 21.74694252], [88.96659851, 21.74744034], [88.96665192, 21.74797058], [88.96666718, 21.74852943], [88.96669769, 21.74911118], [88.96669769, 21.74967957], [88.96661377, 21.75016022], [88.96644592, 21.75065231], [88.96626282, 21.75115967], [88.96605682, 21.7517128], [88.96575928, 21.75222969], [88.96533966, 21.75265121], [88.96489716, 21.75301933], [88.96443939, 21.75333214], [88.96399689, 21.75361252], [88.96360016, 21.75387955], [88.96321869, 21.75412941], [88.96282959, 21.75433159], [88.9624176, 21.75449944], [88.96199799, 21.75471115], [88.96155548, 21.75489807], [88.96105194, 21.75501251], [88.9605484, 21.75514984], [88.96002197, 21.75527], [88.95950317, 21.75535965], [88.958992, 21.75549126], [88.95861053, 21.7555294], [88.95847321, 21.75555992], [88.95614624, 21.75555992], [88.95527649, 21.75555611], [88.95500183, 21.75583267], [88.95443726, 21.75582123], [88.95417023, 21.75611115], [88.95333099, 21.75611115], [88.95305634, 21.75638962], [88.95276642, 21.75638962], [88.95249939, 21.75666809], [88.9522171, 21.75666809], [88.95111084, 21.75777817], [88.95111084, 21.75805473], [88.95155334, 21.75855446], [88.95198059, 21.75896454], [88.95251465, 21.75930023], [88.95305634, 21.75958061], [88.95361328, 21.75982094], [88.95410156, 21.76004028], [88.95456696, 21.76026917], [88.95503998, 21.76048088], [88.95552063, 21.76066971], [88.95600128, 21.76086044], [88.95644379, 21.76110649], [88.95690155, 21.76132393], [88.95709229, 21.76137352], [88.95739746, 21.76145554], [88.95778656, 21.7616806], [88.95804596, 21.76194954], [88.95833588, 21.76194954], [88.96055603, 21.76416969], [88.96083069, 21.76416969], [88.96193695, 21.76527977], [88.96221924, 21.76527977], [88.96257782, 21.76557732], [88.96287537, 21.76592445], [88.96305084, 21.76633835], [88.96333313, 21.76663971], [88.96356201, 21.76692963], [88.96366119, 21.76729965], [88.96378326, 21.7676506], [88.96396637, 21.76799011], [88.96417999, 21.76836014], [88.96444702, 21.76876068], [88.96470642, 21.76925087], [88.96496582, 21.76982117], [88.96517944, 21.77046013], [88.96555328, 21.77098083], [88.96589661, 21.77144814], [88.96630096, 21.77185059], [88.96676636, 21.77218437], [88.96727753, 21.77242088], [88.96788025, 21.77259064], [88.96842957, 21.77271461], [88.96891785, 21.7727356], [88.96935272, 21.77263069], [88.96977234, 21.7725811], [88.9701767, 21.77263069], [88.97058868, 21.77275085], [88.9710083, 21.77277946], [88.97142029, 21.77280045], [88.9717865, 21.77289963], [88.9721756, 21.77302933], [88.97263336, 21.77310753], [88.97305298, 21.77331924], [88.973526, 21.77351952], [88.97401428, 21.77376556], [88.97442627, 21.77412987], [88.97486115, 21.77446556], [88.97522736, 21.77482033], [88.97551727, 21.77521896], [88.97583771, 21.77557945], [88.97611237, 21.77596283], [88.97635651, 21.77634811], [88.97667694, 21.77667999], [88.97701263, 21.77700043], [88.97736359, 21.77729034], [88.97766876, 21.77762032], [88.97792816, 21.77799034], [88.9782486, 21.77827835], [88.97856903, 21.77856064], [88.97888184, 21.7788372], [88.97920227, 21.77913094], [88.97953033, 21.77943039], [88.97986603, 21.77972031], [88.98021698, 21.78001976], [88.98052979, 21.78034019], [88.98083496, 21.78068924], [88.98113251, 21.78103065], [88.98143768, 21.78135872], [88.98177338, 21.78166008], [88.98208618, 21.78198051], [88.98236084, 21.782341], [88.98272705, 21.78263092], [88.98304749, 21.78296661], [88.9833374, 21.78331947], [88.98365784, 21.78366089], [88.98397827, 21.78397942], [88.98430634, 21.78430367], [88.98462677, 21.78462029], [88.98497772, 21.78490448], [88.98527527, 21.7852459], [88.98555756, 21.78560066], [88.98584747, 21.78596115], [88.98615265, 21.78630257], [88.98648071, 21.78662491], [88.98677826, 21.78696251], [88.98707581, 21.78731346], [88.98747253, 21.78754807], [88.98787689, 21.7877903], [88.98828125, 21.78806114], [88.98871613, 21.7883358], [88.98919678, 21.78861237], [88.98972321, 21.78884125], [88.99025726, 21.78885078], [88.99089813, 21.78856087], [88.99147797, 21.78831863], [88.99195099, 21.78808975], [88.99240875, 21.78792572], [88.99286652, 21.78778267], [88.99333191, 21.78762054], [88.99349213, 21.78756714], [88.99381256, 21.78746033], [88.9942627, 21.78726959], [88.99474335, 21.78709984], [88.99520874, 21.78692818], [88.99565887, 21.78671837], [88.9961319, 21.7865448], [88.99660492, 21.78637505], [88.99704742, 21.78615952], [88.99750519, 21.78598976], [88.99797058, 21.78585815], [88.99843597, 21.78577995], [88.998909, 21.78572845], [88.99931335, 21.78557968], [88.99967194, 21.78546906]]], [[[88.20054626, 21.76860809], [88.20055389, 21.76805687], [88.20083618, 21.7677784], [88.20083618, 21.76749992], [88.20111084, 21.76721954], [88.20111084, 21.76666451], [88.20137787, 21.76638985], [88.20137787, 21.76556015], [88.20166779, 21.76527977], [88.20166779, 21.76501083], [88.20194244, 21.76472092], [88.20194244, 21.76444435], [88.20222473, 21.76416588], [88.2022171, 21.76389122], [88.20249939, 21.76361084], [88.20249939, 21.76305962], [88.2022171, 21.76278114], [88.2022171, 21.76250076], [88.20194244, 21.76222038], [88.20222473, 21.76166725], [88.2022171, 21.76139069], [88.20083618, 21.76000023], [88.19917297, 21.75917244], [88.19917297, 21.75889015], [88.19889069, 21.75861168], [88.19777679, 21.75805473], [88.19694519, 21.75777817], [88.19638824, 21.75749969], [88.19610596, 21.75777817], [88.1958313, 21.75777817], [88.19555664, 21.75805473], [88.1955719, 21.75832748], [88.19499969, 21.75889015], [88.19499969, 21.75917244], [88.19472504, 21.75944519], [88.19473267, 21.75972176], [88.19444275, 21.76000023], [88.19444275, 21.76083183], [88.19416809, 21.76111031], [88.19416809, 21.76194382], [88.1938858, 21.76222229], [88.1938858, 21.76333046], [88.19416809, 21.76361084], [88.19416809, 21.76389122], [88.19444275, 21.76416588], [88.19444275, 21.76444054], [88.19499969, 21.76501083], [88.19499969, 21.76527786], [88.19555664, 21.7658329], [88.1955719, 21.76610947], [88.197052, 21.76761246], [88.19721985, 21.7677803], [88.19750214, 21.7677784], [88.19833374, 21.76861191], [88.1986084, 21.76860809], [88.19917297, 21.76917076], [88.19999695, 21.76917076], [88.20027924, 21.76889038], [88.20054626, 21.76860809]]], [[[88.30249023, 21.72456169], [88.30229187, 21.72409058], [88.30216217, 21.7235775], [88.30194855, 21.72315025], [88.30176544, 21.72274971], [88.30162048, 21.72235107], [88.30142975, 21.7220211], [88.30133057, 21.72163963], [88.30114746, 21.72128487], [88.30110168, 21.72084999], [88.30103302, 21.72037125], [88.30092621, 21.72004128], [88.3008728, 21.71988487], [88.30082703, 21.71931458], [88.30080414, 21.7187252], [88.30075073, 21.7181797], [88.30081177, 21.71768951], [88.30081177, 21.71724701], [88.30069733, 21.71682167], [88.30060577, 21.71640015], [88.3006897, 21.71598816], [88.30088043, 21.71562004], [88.30105591, 21.71528053], [88.30071259, 21.71475029], [88.30057526, 21.7143383], [88.30056, 21.71398163], [88.30060577, 21.71364021], [88.30077362, 21.71333313], [88.30079651, 21.7132206], [88.30084229, 21.71297073], [88.30091858, 21.71261024], [88.30105591, 21.71225929], [88.30114746, 21.71187019], [88.30132294, 21.71145058], [88.30158997, 21.71096039], [88.30200958, 21.71042061], [88.30218506, 21.70977783], [88.30198669, 21.70919037], [88.30172729, 21.70868111], [88.30148315, 21.70827293], [88.30132294, 21.70791245], [88.30108643, 21.70765114], [88.30078888, 21.70743942], [88.30052185, 21.70721054], [88.30027008, 21.7069416], [88.29998779, 21.70664978], [88.29962921, 21.70633125], [88.29911041, 21.70598984], [88.29844666, 21.70570564], [88.29811859, 21.70556259], [88.29773712, 21.70556259], [88.29727936, 21.70560074], [88.29681396, 21.70583153], [88.29631042, 21.70607948], [88.29574585, 21.70630074], [88.29527283, 21.70662117], [88.29482269, 21.7069912], [88.29444885, 21.70740891], [88.29411316, 21.7078228], [88.29374695, 21.70819283], [88.29338837, 21.7085495], [88.29302216, 21.70886993], [88.29266357, 21.70916367], [88.29232025, 21.70944023], [88.29199219, 21.70973015], [88.29169464, 21.7100563], [88.2914505, 21.71046066], [88.29113007, 21.71079826], [88.29071808, 21.71109009], [88.29039001, 21.71146774], [88.29014587, 21.71194077], [88.28987122, 21.71244812], [88.28949738, 21.71293068], [88.28917694, 21.71351051], [88.28888702, 21.71413994], [88.28855896, 21.71473122], [88.28813934, 21.71519089], [88.2877121, 21.71562004], [88.28733826, 21.71603966], [88.287117, 21.71649551], [88.28691864, 21.71695137], [88.28666687, 21.71736908], [88.28639221, 21.7177887], [88.28610992, 21.71820259], [88.28583527, 21.71861458], [88.28556061, 21.71902084], [88.28555298, 21.7191658], [88.28499603, 21.71970749], [88.28500366, 21.71999931], [88.28416443, 21.72083282], [88.2841568, 21.72110939], [88.28388977, 21.72138977], [88.28388977, 21.72194481], [88.28360748, 21.72221947], [88.28360748, 21.72249985], [88.28221893, 21.7238903], [88.28221893, 21.72417068], [88.28193665, 21.72445107], [88.28166962, 21.72445107], [88.28115082, 21.72500992], [88.28063202, 21.7255497], [88.2800827, 21.72603989], [88.27954865, 21.72653961], [88.27896881, 21.72702026], [88.27842712, 21.72756958], [88.2780304, 21.72817039], [88.27796936, 21.72878265], [88.27799988, 21.72937584], [88.27787018, 21.72991943], [88.27775574, 21.73049736], [88.27758026, 21.73106194], [88.2775116, 21.73166656], [88.27749634, 21.73229408], [88.27746582, 21.73290825], [88.27735138, 21.73348045], [88.27725983, 21.73398018], [88.27722168, 21.73417282], [88.27722168, 21.73611069], [88.27749634, 21.73638916], [88.27749634, 21.73722076], [88.27722168, 21.73750114], [88.27722168, 21.73861122], [88.27805328, 21.73944664], [88.27805328, 21.7397213], [88.27833557, 21.73999977], [88.27833557, 21.74055672], [88.27861023, 21.74081993], [88.27861023, 21.74139023], [88.27889252, 21.7416687], [88.27902985, 21.74205971], [88.27919769, 21.74247551], [88.2794342, 21.74278259], [88.27963257, 21.74304008], [88.27980042, 21.74328041], [88.27999115, 21.7435112], [88.28019714, 21.7437706], [88.28051758, 21.74398613], [88.28081512, 21.74424362], [88.28105927, 21.74456024], [88.28122711, 21.74496078], [88.28143311, 21.74537086], [88.28166962, 21.74575615], [88.28189087, 21.74616051], [88.28195953, 21.74666786], [88.28205109, 21.74715042], [88.28224945, 21.74757957], [88.28251648, 21.74794006], [88.28279114, 21.74827003], [88.28305817, 21.7485981], [88.28333282, 21.74892426], [88.28356934, 21.74928093], [88.28373718, 21.74971962], [88.28392029, 21.7501545], [88.2841568, 21.75057983], [88.28437805, 21.75105095], [88.28457642, 21.75152016], [88.28477478, 21.75198746], [88.28499603, 21.7524395], [88.28527069, 21.75288582], [88.28547668, 21.75336075], [88.2856369, 21.75386047], [88.28579712, 21.75434113], [88.28588104, 21.75485992], [88.28607178, 21.75534058], [88.28610992, 21.75583839], [88.28611755, 21.75632858], [88.28617859, 21.75680923], [88.28634644, 21.75724983], [88.28639221, 21.75773048], [88.28639221, 21.7582016], [88.28639221, 21.75867844], [88.28639221, 21.75916672], [88.28639221, 21.76111031], [88.28639221, 21.76159477], [88.28639221, 21.76206398], [88.28637695, 21.7625103], [88.28637695, 21.7629509], [88.28639984, 21.76338959], [88.28647614, 21.76383018], [88.28663635, 21.76429939], [88.28665924, 21.76480865], [88.28658295, 21.76534271], [88.28642273, 21.76588058], [88.28639221, 21.76645851], [88.28637695, 21.7670517], [88.28637695, 21.76764107], [88.28637695, 21.7681694], [88.28639221, 21.76865005], [88.28643036, 21.76908684], [88.28662109, 21.76950073], [88.28666687, 21.76996803], [88.28666687, 21.77046967], [88.2866745, 21.77100563], [88.28673553, 21.77153969], [88.28691864, 21.77202988], [88.28704071, 21.77257919], [88.28721619, 21.77309036], [88.28734589, 21.77360153], [88.28749847, 21.77404022], [88.28764343, 21.77444649], [88.28779602, 21.77484322], [88.28797913, 21.77523041], [88.28807068, 21.77567673], [88.28819275, 21.77610016], [88.28831482, 21.7765274], [88.28840637, 21.77700043], [88.28857422, 21.77750969], [88.28862762, 21.77791023], [88.28864288, 21.77805328], [88.28890991, 21.77848434], [88.28964233, 21.77845573], [88.29032135, 21.77799988], [88.29083252, 21.77742195], [88.2912674, 21.77687454], [88.29166412, 21.77633667], [88.29205322, 21.77581596], [88.29212952, 21.7757206], [88.29245758, 21.77531624], [88.2928772, 21.77482986], [88.29337311, 21.77440834], [88.2938385, 21.77399063], [88.29424286, 21.77355957], [88.29463959, 21.77313042], [88.29496765, 21.77270317], [88.29523468, 21.77228165], [88.29553223, 21.77190971], [88.29582977, 21.77155495], [88.29611206, 21.77119255], [88.29640198, 21.77081108], [88.29666138, 21.77041817], [88.29688263, 21.77000046], [88.29708862, 21.76958084], [88.29729462, 21.76921654], [88.29753113, 21.76893997], [88.29776001, 21.7686882], [88.29794312, 21.76844978], [88.29814148, 21.76824379], [88.29833221, 21.76800919], [88.29850006, 21.76774025], [88.29866028, 21.76741028], [88.29881287, 21.76707077], [88.29891205, 21.76663971], [88.29904938, 21.76622009], [88.29917908, 21.7658329], [88.29933167, 21.76549149], [88.29943085, 21.76516533], [88.29950714, 21.76486015], [88.2996521, 21.76457977], [88.2997818, 21.76428986], [88.29992676, 21.76400185], [88.30002594, 21.76366043], [88.30016327, 21.76329994], [88.30026245, 21.7628994], [88.30032349, 21.76246262], [88.30049896, 21.76204109], [88.30059052, 21.76156807], [88.30078125, 21.76111984], [88.3008728, 21.7605896], [88.30103302, 21.76007271], [88.30117035, 21.75955772], [88.3013916, 21.75914955], [88.30161285, 21.75882149], [88.3017807, 21.75851059], [88.30194092, 21.75823975], [88.30207825, 21.75796509], [88.30208588, 21.75758171], [88.30201721, 21.75710106], [88.30215454, 21.75664902], [88.30246735, 21.75613022], [88.30288696, 21.75555992], [88.30280304, 21.75507927], [88.30265045, 21.75460052], [88.30252075, 21.75411034], [88.30249786, 21.75362206], [88.30253601, 21.75311661], [88.30271912, 21.75261116], [88.30277252, 21.75206947], [88.30281067, 21.75158119], [88.30297089, 21.75118065], [88.30304718, 21.75078011], [88.30309296, 21.75031853], [88.30323029, 21.74979973], [88.30332184, 21.7491703], [88.30337524, 21.7485199], [88.30354309, 21.74793053], [88.30360413, 21.74744225], [88.30361176, 21.74704742], [88.3035965, 21.74670982], [88.3035965, 21.74637985], [88.30361938, 21.74603271], [88.30368042, 21.7456646], [88.30384827, 21.74529457], [88.30389404, 21.74484253], [88.30394745, 21.74435043], [88.30412292, 21.74385071], [88.3041687, 21.7433033], [88.30420685, 21.7427597], [88.30444336, 21.74225044], [88.30458832, 21.74168777], [88.30446625, 21.74096107], [88.30461121, 21.74038124], [88.30474854, 21.73983955], [88.3049469, 21.73937988], [88.30500793, 21.73888016], [88.30508423, 21.73841286], [88.30524445, 21.73796272], [88.30526733, 21.73747063], [88.30527496, 21.73697662], [88.30526733, 21.73647118], [88.30526733, 21.73590279], [88.30532074, 21.7352829], [88.30555725, 21.73464584], [88.3057785, 21.73393822], [88.30583191, 21.73317719], [88.3057785, 21.73241043], [88.30555725, 21.7317276], [88.30528259, 21.73111916], [88.30500031, 21.73058128], [88.30474854, 21.73008156], [88.30458832, 21.72959328], [88.30444336, 21.72915459], [88.30432129, 21.7287693], [88.30417633, 21.72844124], [88.3041687, 21.72811127], [88.30413055, 21.72779083], [88.30396271, 21.72755051], [88.3038559, 21.72726059], [88.30368805, 21.72701073], [88.3035202, 21.72668839], [88.30329895, 21.72636032], [88.30304718, 21.72597122], [88.30281067, 21.72555733], [88.30267334, 21.72505188], [88.30249023, 21.72456169]]], [[[88.58222198, 21.77778053], [88.58249664, 21.77750015], [88.58304596, 21.77750015], [88.58333588, 21.77721977], [88.58361053, 21.77722168], [88.58416748, 21.77666664], [88.58416748, 21.77639008], [88.58444214, 21.7761097], [88.58444214, 21.77583122], [88.58472443, 21.77555466], [88.58472443, 21.77527809], [88.58499908, 21.77499962], [88.58499908, 21.76610947], [88.58472443, 21.7658329], [88.58472443, 21.76527786], [88.58444214, 21.76501083], [88.58444214, 21.76361084], [88.58416748, 21.76333046], [88.58416748, 21.76250076], [88.58392334, 21.7622509], [88.58388519, 21.76194382], [88.58361816, 21.76167107], [88.58361816, 21.76139069], [88.58389282, 21.76111031], [88.58388519, 21.76055527], [88.58361816, 21.76028061], [88.58364868, 21.75999069], [88.58362579, 21.75938034], [88.58371735, 21.75879097], [88.58390808, 21.75827026], [88.58410645, 21.75778961], [88.584198, 21.75727081], [88.5843277, 21.75678062], [88.58452606, 21.75632858], [88.58473206, 21.75587082], [88.58495331, 21.75542068], [88.5851059, 21.75489998], [88.58534241, 21.75439072], [88.58560944, 21.75389099], [88.58595276, 21.75341034], [88.58638763, 21.75301933], [88.58674622, 21.75258064], [88.5871582, 21.75222969], [88.58759308, 21.75195122], [88.58804321, 21.75170135], [88.58857727, 21.75155067], [88.58911896, 21.7513504], [88.58963013, 21.75110245], [88.59011078, 21.7508316], [88.59056091, 21.7505703], [88.59101868, 21.75037956], [88.59148407, 21.75025177], [88.5919342, 21.75005531], [88.59250641, 21.74995041], [88.59309387, 21.74968719], [88.59371185, 21.74936295], [88.59429169, 21.74899101], [88.59481049, 21.74862099], [88.59532166, 21.74830055], [88.59584808, 21.74802017], [88.59638214, 21.74777031], [88.59689331, 21.74747086], [88.59733582, 21.74710846], [88.59781647, 21.74682999], [88.59835052, 21.74660873], [88.59887695, 21.74637985], [88.59940338, 21.74612045], [88.5999527, 21.74591255], [88.60057068, 21.74579048], [88.60108948, 21.74557686], [88.60166168, 21.74542236], [88.60227966, 21.74530029], [88.6029129, 21.74522972], [88.6033783, 21.74501038], [88.60370636, 21.74478912], [88.6047821, 21.74424171], [88.60494995, 21.74419022], [88.60568237, 21.74398994], [88.60646057, 21.74394989], [88.60692596, 21.74366951], [88.6075058, 21.74361038], [88.608078, 21.74360657], [88.60861969, 21.7435627], [88.60910034, 21.74336052], [88.60959625, 21.74318123], [88.61013031, 21.74296951], [88.610672, 21.74278831], [88.61120605, 21.74266052], [88.61170197, 21.74251938], [88.61222076, 21.74250031], [88.61332703, 21.74139023], [88.61416626, 21.74139023], [88.61444092, 21.74110985], [88.61444092, 21.74083328], [88.61472321, 21.74055672], [88.61499786, 21.74083328], [88.61528015, 21.74083328], [88.61555481, 21.74055672], [88.6158371, 21.74083328], [88.61611176, 21.74083328], [88.61694336, 21.73999977], [88.61753082, 21.73978996], [88.6180954, 21.73948288], [88.61869812, 21.73913383], [88.61923218, 21.73870087], [88.61976624, 21.73831177], [88.62019348, 21.73784637], [88.62047577, 21.73728943], [88.6206131, 21.73656082], [88.62078857, 21.73584557], [88.62088013, 21.73512459], [88.62097931, 21.73446274], [88.62081909, 21.73387146], [88.62059784, 21.7333622], [88.62041473, 21.73289871], [88.6202774, 21.73246002], [88.62014771, 21.73204041], [88.62001801, 21.73163986], [88.61985016, 21.73125458], [88.61962128, 21.73088074], [88.61930084, 21.73050117], [88.618927, 21.73003006], [88.61873627, 21.7297802], [88.61852264, 21.72949409], [88.61802673, 21.72895813], [88.61748505, 21.72846794], [88.61692047, 21.72801018], [88.61637115, 21.7276268], [88.61582947, 21.72732162], [88.61531067, 21.72709084], [88.61483765, 21.72689819], [88.61440277, 21.72672081], [88.61393738, 21.72661972], [88.6135025, 21.72648621], [88.61306, 21.72640038], [88.61262512, 21.7263279], [88.61223602, 21.72616005], [88.61183929, 21.72603989], [88.61156464, 21.72590256], [88.61148071, 21.72586632], [88.61110687, 21.72570992], [88.61071777, 21.72557068], [88.61030579, 21.72543907], [88.60990906, 21.72525978], [88.60949707, 21.72507286], [88.60900879, 21.72499466], [88.60850525, 21.72490883], [88.60801697, 21.72474098], [88.60752869, 21.72459984], [88.60706329, 21.72446823], [88.60656738, 21.72439384], [88.60610962, 21.7242794], [88.6056366, 21.72420692], [88.60510254, 21.72422791], [88.60449219, 21.72431374], [88.60384369, 21.72418976], [88.60318756, 21.7240715], [88.60256195, 21.72392082], [88.60196686, 21.72381973], [88.6014328, 21.72367287], [88.60089874, 21.72354126], [88.60043335, 21.72332191], [88.59998322, 21.72310638], [88.59951782, 21.7229805], [88.59912109, 21.72283173], [88.59868622, 21.72275925], [88.59824371, 21.72271729], [88.59780884, 21.72261047], [88.59745026, 21.72232056], [88.59701538, 21.72208214], [88.59656525, 21.72182274], [88.59609222, 21.72152519], [88.59559631, 21.72125053], [88.5951004, 21.72096062], [88.59458923, 21.72070313], [88.59416962, 21.72031975], [88.59378052, 21.71988106], [88.59343719, 21.71945763], [88.5931015, 21.7190876], [88.59279633, 21.71870995], [88.59243011, 21.71902084], [88.59201813, 21.71934128], [88.59158325, 21.71953964], [88.59115601, 21.71973991], [88.59072113, 21.71997452], [88.59022522, 21.72017097], [88.5896759, 21.72034073], [88.58917999, 21.72056961], [88.58870697, 21.72083473], [88.58822632, 21.72110939], [88.58774567, 21.72137833], [88.58721924, 21.72159958], [88.58664703, 21.7217598], [88.58617401, 21.72197533], [88.58577728, 21.72225952], [88.58538055, 21.72252083], [88.58499146, 21.72278023], [88.5845871, 21.7229805], [88.5841217, 21.72312737], [88.58366394, 21.72331238], [88.58319092, 21.72347069], [88.5827179, 21.72363091], [88.58228302, 21.72380257], [88.58187103, 21.72392082], [88.58148193, 21.72409821], [88.58113861, 21.72437096], [88.58078003, 21.72480011], [88.58065033, 21.72492218], [88.58027649, 21.72528076], [88.58027649, 21.72556114], [88.58000183, 21.72556114], [88.57971954, 21.72583961], [88.57971954, 21.72639084], [88.58000183, 21.7266674], [88.58000183, 21.72694588], [88.58027649, 21.72722054], [88.58027649, 21.72777939], [88.58055878, 21.72805977], [88.58055878, 21.72861099], [88.58027649, 21.72887993], [88.58027649, 21.72916794], [88.58055878, 21.7294445], [88.58055878, 21.72972107], [88.58082581, 21.72999954], [88.58083344, 21.73027992], [88.58087158, 21.73034286], [88.58112335, 21.7308197], [88.5813446, 21.73126602], [88.58149719, 21.73176384], [88.58167267, 21.73225212], [88.58187103, 21.73273087], [88.58194733, 21.73324013], [88.58203888, 21.73367691], [88.58219147, 21.73402023], [88.58223724, 21.73436165], [88.58238983, 21.73462868], [88.58249664, 21.73490334], [88.58257294, 21.73519325], [88.58273315, 21.7354641], [88.58277893, 21.73583031], [88.58283997, 21.736269], [88.58302307, 21.73672295], [88.58312225, 21.73726082], [88.58329773, 21.73777962], [88.58333588, 21.7383461], [88.58338165, 21.7389183], [88.58358002, 21.73945808], [88.58364105, 21.74005127], [88.58361816, 21.74066925], [88.58361816, 21.74126053], [88.58365631, 21.74179077], [88.58383942, 21.74224091], [88.58389282, 21.74267006], [88.58390808, 21.74308968], [88.58396912, 21.7434864], [88.58412933, 21.74386024], [88.58416748, 21.74423981], [88.58413696, 21.74460983], [88.58402252, 21.74497986], [88.58384705, 21.74532127], [88.58377838, 21.74574089], [88.58390808, 21.74628067], [88.58384705, 21.7467308], [88.58367157, 21.74714088], [88.58361816, 21.74757195], [88.58361816, 21.7480011], [88.58355713, 21.74841118], [88.58336639, 21.74882126], [88.58323669, 21.74924088], [88.58304596, 21.74962044], [88.58283234, 21.74999046], [88.58275604, 21.7504158], [88.5826416, 21.7508049], [88.5824585, 21.7511425], [88.58224487, 21.75147247], [88.58207703, 21.75185966], [88.58193207, 21.75230026], [88.58171082, 21.7527504], [88.58141327, 21.75317764], [88.58113861, 21.75362968], [88.58090973, 21.75412178], [88.58079529, 21.75468445], [88.58055878, 21.75514984], [88.58026886, 21.7556057], [88.57994843, 21.75603104], [88.57955933, 21.75639915], [88.57920837, 21.75677109], [88.57891846, 21.7571907], [88.57859802, 21.75759315], [88.5782547, 21.75800133], [88.57781982, 21.75836182], [88.57737732, 21.75873947], [88.5769577, 21.75914955], [88.57656097, 21.75955963], [88.57624054, 21.75996971], [88.57594299, 21.76033783], [88.57578278, 21.76074982], [88.57554626, 21.76111984], [88.57527924, 21.76146317], [88.57498169, 21.76182175], [88.574646, 21.76215363], [88.5742569, 21.7624321], [88.57395172, 21.76280975], [88.57370758, 21.76325035], [88.5734787, 21.76371384], [88.57311249, 21.7641201], [88.57272339, 21.76453972], [88.57232666, 21.76498032], [88.57187653, 21.76537514], [88.5717926, 21.76545334], [88.57142639, 21.76579857], [88.57097626, 21.76624107], [88.57054138, 21.76670265], [88.57016754, 21.76719475], [88.56981659, 21.7676506], [88.56954193, 21.7680912], [88.56935883, 21.76852417], [88.56915283, 21.7688694], [88.56900024, 21.76917839], [88.5692215, 21.76947594], [88.56943512, 21.76982117], [88.56961823, 21.77018166], [88.56990051, 21.77045059], [88.57028961, 21.77063942], [88.57065582, 21.77095985], [88.57109833, 21.77114105], [88.57150269, 21.77134323], [88.57194519, 21.77141953], [88.57235718, 21.77152824], [88.57279968, 21.77168274], [88.57325745, 21.77185822], [88.5736618, 21.77219963], [88.57413483, 21.77251625], [88.57454681, 21.77289009], [88.57492828, 21.77330399], [88.57538605, 21.77362061], [88.57581329, 21.77393913], [88.57619476, 21.77424622], [88.57653046, 21.77451134], [88.57666779, 21.77472115], [88.57749939, 21.77555466], [88.57749939, 21.77583122], [88.57777405, 21.7761116], [88.57833099, 21.77667046], [88.57861328, 21.77667046], [88.57888794, 21.77639008], [88.57907867, 21.77658081], [88.57974243, 21.77671432], [88.58026886, 21.77695084], [88.58065796, 21.77721977], [88.58110809, 21.77750015], [88.58139038, 21.77750015], [88.58167267, 21.77778053], [88.58222198, 21.77778053]]], [[[88.60972595, 21.79027939], [88.61000061, 21.79000092], [88.61165619, 21.79000092], [88.61194611, 21.78972054], [88.61194611, 21.78944206], [88.61222076, 21.7891674], [88.61332703, 21.78918076], [88.61360168, 21.78890991], [88.6138916, 21.78876114], [88.61416626, 21.78876495], [88.61555481, 21.78777695], [88.61554718, 21.78724098], [88.61679077, 21.7863903], [88.61723328, 21.78499985], [88.6166687, 21.78444481], [88.6166687, 21.78388977], [88.61723328, 21.78333092], [88.61750031, 21.78333282], [88.61805725, 21.78277969], [88.61833191, 21.78277969], [88.6194458, 21.78166962], [88.6194458, 21.78111076], [88.61972809, 21.78083038], [88.61982727, 21.78090096], [88.62004852, 21.78063965], [88.62026978, 21.7804184], [88.62043762, 21.78018188], [88.62055969, 21.77988052], [88.62055206, 21.77943993], [88.62055206, 21.77861023], [88.62082672, 21.77832985], [88.62083435, 21.77805328], [88.62110901, 21.77778053], [88.62110901, 21.77750015], [88.6213913, 21.77721977], [88.6213913, 21.77666664], [88.62166595, 21.77639008], [88.6217041, 21.77614784], [88.6222229, 21.77555275], [88.6222229, 21.77499962], [88.62249756, 21.77472115], [88.62249756, 21.77416611], [88.62333679, 21.7733326], [88.62333679, 21.77194405], [88.62361145, 21.77166748], [88.62361145, 21.77111053], [88.62388611, 21.77082825], [88.62388611, 21.76916885], [88.6241684, 21.76889038], [88.6241684, 21.76805115], [88.62444305, 21.7677784], [88.62444305, 21.76638985], [88.6241684, 21.76610947], [88.6241684, 21.7658329], [88.62388611, 21.76555443], [88.62388611, 21.76501083], [88.6241684, 21.76472092], [88.6241684, 21.76388931], [88.62444305, 21.76361084], [88.62444305, 21.76333046], [88.62472534, 21.7630558], [88.62473297, 21.76278114], [88.62526703, 21.76222038], [88.62527466, 21.76166725], [88.62536621, 21.76157761], [88.62555695, 21.76138878], [88.62555695, 21.76083183], [88.62611389, 21.7602787], [88.62610626, 21.76000023], [88.62638855, 21.75972176], [88.62638855, 21.75861168], [88.6269455, 21.75805473], [88.6269455, 21.75777817], [88.62722015, 21.75749969], [88.62722015, 21.75582123], [88.62750244, 21.75555611], [88.62775421, 21.75562286], [88.62805176, 21.75527763], [88.62832642, 21.75500107], [88.62832642, 21.75472069], [88.6286087, 21.75444412], [88.6286087, 21.75333595], [88.62889099, 21.75305748], [88.62889862, 21.75056076], [88.62917328, 21.75028038], [88.62917328, 21.7491703], [88.62889862, 21.74888992], [88.62889862, 21.74860954], [88.6286087, 21.74833107], [88.6297226, 21.7472229], [88.62976837, 21.74695587], [88.6297226, 21.74641991], [88.62973785, 21.74588013], [88.62982941, 21.74537468], [88.6300354, 21.74491692], [88.63031769, 21.74448967], [88.63059998, 21.74405289], [88.63076019, 21.74352837], [88.63083649, 21.74305916], [88.63083649, 21.74250031], [88.63054657, 21.74221992], [88.6305542, 21.74055672], [88.63027954, 21.74027824], [88.63027954, 21.73999977], [88.62999725, 21.73971939], [88.62999725, 21.73944664], [88.6297226, 21.73916435], [88.6297226, 21.73888969], [88.62889862, 21.73806953], [88.6288681, 21.73747063], [88.6286087, 21.73722267], [88.6286087, 21.73694229], [88.62833405, 21.73666573], [88.62832642, 21.73639107], [88.62805176, 21.73611069], [88.62805176, 21.73583031], [88.62722015, 21.73500061], [88.62722015, 21.73417282], [88.6277771, 21.73361015], [88.62750244, 21.73333359], [88.62750244, 21.73305511], [88.6277771, 21.73278046], [88.6277771, 21.73250008], [88.62750244, 21.7322216], [88.62750244, 21.73194504], [88.62722015, 21.73166656], [88.62722015, 21.73110962], [88.6269455, 21.73083305], [88.6269455, 21.73027992], [88.62638855, 21.72972107], [88.62638855, 21.72916794], [88.6258316, 21.72861099], [88.6258316, 21.72833061], [88.62555695, 21.72805786], [88.62555695, 21.72777939], [88.62526703, 21.72750092], [88.62526703, 21.72722054], [88.6241684, 21.72611046], [88.6241684, 21.72556114], [88.62388611, 21.72528076], [88.62388611, 21.72472], [88.62361145, 21.72444344], [88.62361145, 21.72417068], [88.62194824, 21.72249985], [88.62194824, 21.7219429], [88.6213913, 21.72138977], [88.6213913, 21.72110939], [88.6202774, 21.71999931], [88.6202774, 21.71943855], [88.62000275, 21.7191658], [88.62017822, 21.71891022], [88.61998749, 21.71845818], [88.61972809, 21.7180481], [88.61949158, 21.71766281], [88.6193161, 21.71727943], [88.61906433, 21.71700478], [88.61876678, 21.71680641], [88.61849213, 21.71656036], [88.61817932, 21.7163372], [88.617836, 21.71604919], [88.6174469, 21.71576309], [88.61709595, 21.71543312], [88.6167984, 21.71513176], [88.61654663, 21.71484947], [88.6163559, 21.71450043], [88.61613464, 21.71416855], [88.6158371, 21.7136097], [88.61416626, 21.71194649], [88.6138916, 21.71194649], [88.61333466, 21.71138954], [88.61277771, 21.71138954], [88.61194611, 21.71055984], [88.61194611, 21.71027946], [88.61110687, 21.70944023], [88.61083221, 21.70944214], [88.61000061, 21.70861053], [88.60972595, 21.70861053], [88.60916901, 21.70806122], [88.60888672, 21.7080555], [88.60861206, 21.70833206], [88.60832977, 21.70833015], [88.60778809, 21.70889282], [88.60749817, 21.70888901], [88.60666656, 21.70972252], [88.60639191, 21.70972061], [88.60610962, 21.71000099], [88.60527802, 21.71000099], [88.60500336, 21.70972061], [88.60472107, 21.70972252], [88.60444641, 21.70944214], [88.60414124, 21.70944786], [88.60382843, 21.70968819], [88.60356903, 21.70997047], [88.60331726, 21.71023941], [88.6030426, 21.7105751], [88.6027298, 21.71096992], [88.60232544, 21.71140862], [88.60197449, 21.71177292], [88.60188293, 21.71186829], [88.60135651, 21.71230125], [88.60079956, 21.71269035], [88.60022736, 21.71302032], [88.59971619, 21.71333122], [88.59889221, 21.71417046], [88.59889221, 21.71445084], [88.59857941, 21.71443939], [88.59860992, 21.71479988], [88.59867859, 21.71517181], [88.59884644, 21.71552277], [88.59912872, 21.71583748], [88.59944153, 21.71611023], [88.60083008, 21.71750069], [88.60111237, 21.71750069], [88.60138702, 21.71777916], [88.60166931, 21.71777725], [88.60221863, 21.7183342], [88.60333252, 21.71832848], [88.60360718, 21.71861076], [88.60415649, 21.71861076], [88.60444641, 21.71888924], [88.60500336, 21.71888924], [88.60527802, 21.71916962], [88.60583496, 21.7191658], [88.60639191, 21.71972275], [88.60778809, 21.71970749], [88.60806274, 21.72000122], [88.60832977, 21.72000122], [88.60861206, 21.72027969], [88.60888672, 21.72027969], [88.60916901, 21.72056007], [88.60972595, 21.72055626], [88.60990906, 21.72074127], [88.61000061, 21.72083282], [88.61055756, 21.72083282], [88.61083221, 21.7211113], [88.61110687, 21.72110939], [88.61138916, 21.72138977], [88.61165619, 21.72138977], [88.61194611, 21.72167015], [88.61222076, 21.72166634], [88.61250305, 21.72194481], [88.61277771, 21.72194481], [88.61305237, 21.72222137], [88.61332703, 21.72221947], [88.6138916, 21.72278023], [88.61416626, 21.72277832], [88.61444092, 21.72305489], [88.61472321, 21.72305489], [88.61499786, 21.72333336], [88.61555481, 21.72333336], [88.6158371, 21.72361183], [88.61611176, 21.72361183], [88.61624908, 21.72375107], [88.61638641, 21.7238903], [88.6166687, 21.7238903], [88.61694336, 21.72417068], [88.61723328, 21.72417068], [88.61805725, 21.72500038], [88.61833191, 21.72500038], [88.61860657, 21.72528076], [88.61888885, 21.72528076], [88.61915588, 21.72556114], [88.6194458, 21.72555351], [88.62083435, 21.72694588], [88.62082672, 21.72722054], [88.6213913, 21.72777939], [88.6213913, 21.72805786], [88.62166595, 21.72833061], [88.62166595, 21.72861099], [88.62194824, 21.72887993], [88.62194824, 21.72916794], [88.6222229, 21.7294445], [88.6222229, 21.72972107], [88.62249756, 21.72999954], [88.62249756, 21.73027992], [88.62277985, 21.73055649], [88.62277985, 21.73083305], [88.62304688, 21.73110962], [88.62304688, 21.73138809], [88.62333679, 21.73166656], [88.62333679, 21.73583031], [88.62304688, 21.73611069], [88.6230545, 21.73666573], [88.62277985, 21.73694229], [88.62277222, 21.73722076], [88.62249756, 21.73750114], [88.62249756, 21.73777962], [88.6222229, 21.73805428], [88.6222229, 21.73833084], [88.6213913, 21.73916435], [88.6213913, 21.7397213], [88.62000275, 21.74110985], [88.62000275, 21.74139023], [88.61972809, 21.74139023], [88.61750031, 21.74361038], [88.61650848, 21.74440956], [88.61507416, 21.74508095], [88.61250305, 21.74629021], [88.6102066, 21.74656105], [88.60791779, 21.74656105], [88.60591125, 21.74682999], [88.60404968, 21.74710083], [88.6030426, 21.74736977], [88.60240936, 21.74749947], [88.60189819, 21.74777031], [88.60136414, 21.74804497], [88.60083008, 21.74833107], [88.59916687, 21.75000954], [88.59889221, 21.75000954], [88.59860229, 21.75028038], [88.59805298, 21.75028038], [88.5976181, 21.75053024], [88.59712219, 21.75069046], [88.59667206, 21.75102997], [88.59623718, 21.75136948], [88.59577942, 21.75166321], [88.5953598, 21.75193024], [88.59494019, 21.75214958], [88.59449768, 21.75230026], [88.59407043, 21.75247192], [88.59360504, 21.75254631], [88.59320068, 21.75274086], [88.5927124, 21.75286102], [88.59220886, 21.75303268], [88.59164429, 21.75311661], [88.59114838, 21.75330353], [88.59065247, 21.75341034], [88.59021759, 21.75358772], [88.58979034, 21.75369835], [88.58938599, 21.75388527], [88.58895874, 21.75407028], [88.58847809, 21.75421715], [88.58803558, 21.75446129], [88.58763885, 21.75473022], [88.58729553, 21.75501823], [88.58701324, 21.75530243], [88.58679199, 21.75559998], [88.58661652, 21.75595093], [88.58640289, 21.75626945], [88.58625031, 21.75659752], [88.58635712, 21.75699997], [88.58638763, 21.75745964], [88.58638763, 21.75799179], [88.58642578, 21.75855255], [88.58661652, 21.75906944], [88.58666992, 21.75959969], [88.58672333, 21.76009178], [88.5868988, 21.76050377], [88.58696747, 21.76094818], [88.58708191, 21.76139069], [88.58722687, 21.76184273], [88.58737183, 21.76231003], [88.58750153, 21.76280975], [88.58763123, 21.76333046], [88.5877533, 21.76389122], [88.58777618, 21.76453781], [88.58779907, 21.76523972], [88.58790588, 21.76596069], [88.58803558, 21.76669312], [88.58808136, 21.76744461], [88.58816528, 21.76818275], [88.58808136, 21.76892281], [88.58802032, 21.76971054], [88.58786774, 21.77049065], [88.58782959, 21.77127457], [88.5880127, 21.77202988], [88.5880661, 21.77280998], [88.58817291, 21.77357101], [88.58830261, 21.77429962], [88.58833313, 21.7750206], [88.58837891, 21.77569008], [88.58856964, 21.77627373], [88.58865356, 21.77687454], [88.58883667, 21.77742195], [88.58893585, 21.77799988], [88.58912659, 21.7784996], [88.5891571, 21.77900124], [88.58917236, 21.77944946], [88.58922577, 21.77984047], [88.58940125, 21.78014565], [88.58952332, 21.78046227], [88.58972168, 21.78070068], [88.58992767, 21.78093529], [88.59004211, 21.78123093], [88.59020996, 21.78149033], [88.5903244, 21.78180122], [88.59052277, 21.78209114], [88.59066772, 21.78248024], [88.59091949, 21.78286934], [88.59120178, 21.78330994], [88.59153748, 21.78376007], [88.59189606, 21.78423119], [88.59221649, 21.78473091], [88.59259033, 21.7851963], [88.59272766, 21.78530121], [88.59305573, 21.78555489], [88.59333038, 21.78555489], [88.59388733, 21.78611183], [88.59416962, 21.7863903], [88.59443665, 21.7863903], [88.59500122, 21.78695107], [88.59555817, 21.78694534], [88.59583282, 21.78722191], [88.59638977, 21.78722191], [88.5966568, 21.78750038], [88.59694672, 21.78750038], [88.59749603, 21.78806114], [88.59777832, 21.78805542], [88.59805298, 21.78833389], [88.5983429, 21.78833008], [88.59860229, 21.78861046], [88.59889221, 21.78861046], [88.59916687, 21.78889084], [88.59971619, 21.78889084], [88.59999847, 21.78918076], [88.60111237, 21.7891674], [88.60166931, 21.78972244], [88.60250092, 21.78972244], [88.60277557, 21.78944206], [88.60444641, 21.78944206], [88.60472107, 21.78972244], [88.60610962, 21.78972054], [88.60639191, 21.79000092], [88.60943604, 21.79000092], [88.60972595, 21.79027939]]], [[[88.38490295, 21.76444054], [88.38545227, 21.76416016], [88.38599396, 21.7638607], [88.38643646, 21.7634697], [88.38671112, 21.7630806], [88.38703156, 21.76280975], [88.38729858, 21.7625351], [88.38772583, 21.76235962], [88.38822937, 21.76209068], [88.38868713, 21.76172066], [88.38918304, 21.76136971], [88.3900528, 21.76025009], [88.39032745, 21.75863838], [88.39004517, 21.75734138], [88.38961792, 21.75541115], [88.38903809, 21.75258827], [88.38846588, 21.74895287], [88.38818359, 21.74720764], [88.38788605, 21.74478912], [88.38774872, 21.74385071], [88.38775635, 21.74343109], [88.38755035, 21.74290085], [88.38743591, 21.74233055], [88.38720703, 21.74180031], [88.38694763, 21.74126053], [88.38669586, 21.74067879], [88.38639069, 21.74055099], [88.38609314, 21.74000931], [88.38500977, 21.73861122], [88.38444519, 21.73861122], [88.3841629, 21.73833275], [88.38361359, 21.73833275], [88.3833313, 21.73805428], [88.38276672, 21.73806953], [88.38249969, 21.73777962], [88.38166809, 21.73777962], [88.38108826, 21.73722076], [88.37999725, 21.73722267], [88.37950897, 21.73730278], [88.3789444, 21.73715591], [88.37843323, 21.73722649], [88.37789917, 21.7373848], [88.37741089, 21.7376194], [88.37689972, 21.73771095], [88.37631989, 21.73759079], [88.37573242, 21.7376194], [88.37550354, 21.73756981], [88.37528229, 21.73752213], [88.37483215, 21.73746109], [88.37473297, 21.73750114], [88.37444305, 21.73722076], [88.3741684, 21.73722267], [88.37388611, 21.73694229], [88.37249756, 21.73694229], [88.37194824, 21.73638916], [88.37166595, 21.73639107], [88.37110901, 21.73583031], [88.37083435, 21.73583221], [88.37055206, 21.73555565], [88.37001038, 21.73555946], [88.36831665, 21.73455811], [88.36818695, 21.73443604], [88.36805725, 21.73428917], [88.36777496, 21.73388863], [88.36750031, 21.73361015], [88.36722565, 21.73361015], [88.36694336, 21.73333359], [88.3666687, 21.73333359], [88.36638641, 21.73305511], [88.36611176, 21.73306274], [88.36499786, 21.732481], [88.36486053, 21.73219681], [88.36430359, 21.73219681], [88.36420441, 21.73182106], [88.36416626, 21.73166656], [88.3638916, 21.73166656], [88.36356354, 21.73199463], [88.36333466, 21.7322216], [88.36305237, 21.7322216], [88.36291504, 21.73207855], [88.36239624, 21.73232651], [88.36190796, 21.73269844], [88.36151123, 21.73308945], [88.36123657, 21.7335701], [88.36107635, 21.73411942], [88.36099243, 21.73472023], [88.3610611, 21.73530769], [88.36112976, 21.73587036], [88.36119843, 21.7364006], [88.36135864, 21.73682785], [88.36151886, 21.73726273], [88.36166382, 21.7377224], [88.36180115, 21.73821449], [88.36190796, 21.7387619], [88.36194611, 21.73936081], [88.36196136, 21.73999023], [88.36194611, 21.74060059], [88.3618927, 21.74115944], [88.36174011, 21.74166107], [88.36161041, 21.74215508], [88.36142731, 21.74269104], [88.36125946, 21.74332047], [88.36109161, 21.74395752], [88.36099243, 21.74438095], [88.36093903, 21.74460983], [88.36090088, 21.74528885], [88.36096954, 21.74594116], [88.36110687, 21.74657822], [88.36125946, 21.74716949], [88.36151886, 21.74765968], [88.36183167, 21.74809074], [88.36222839, 21.74843025], [88.36264801, 21.74879074], [88.36305237, 21.7491703], [88.36333466, 21.74916649], [88.3637085, 21.74954033], [88.36611176, 21.75194359], [88.36611176, 21.75222015], [88.36638641, 21.75250053], [88.36670685, 21.75279045], [88.36695862, 21.75307846], [88.36711121, 21.75335121], [88.36712646, 21.75362015], [88.36708069, 21.7539196], [88.36705017, 21.75428009], [88.36709595, 21.75472069], [88.36721039, 21.75524521], [88.36738586, 21.75579262], [88.36767578, 21.75626945], [88.36804199, 21.75662994], [88.36841583, 21.7569294], [88.36882782, 21.75715065], [88.36929321, 21.75735092], [88.36981201, 21.75758171], [88.37033081, 21.75791931], [88.37077332, 21.75839615], [88.3709259, 21.75859642], [88.37116241, 21.75889969], [88.371521, 21.75934982], [88.37172699, 21.75976944], [88.37188721, 21.7602272], [88.37193298, 21.76079369], [88.37193298, 21.76148033], [88.37198639, 21.76217079], [88.37223053, 21.76263618], [88.37254333, 21.76308823], [88.37281799, 21.76360893], [88.37384796, 21.76394272], [88.37425232, 21.7644043], [88.37457275, 21.76436043], [88.37482452, 21.76467514], [88.37525177, 21.76474953], [88.37560272, 21.76490974], [88.37593842, 21.76517868], [88.37639618, 21.76548004], [88.37700653, 21.76565933], [88.37755585, 21.76584053], [88.37806702, 21.7660408], [88.37860107, 21.76622963], [88.3791275, 21.76643181], [88.37966156, 21.76667976], [88.38021088, 21.76695061], [88.38082123, 21.76715088], [88.38152313, 21.76703072], [88.3821106, 21.76660538], [88.38260651, 21.76608276], [88.38323975, 21.7656498], [88.38343811, 21.76549339], [88.38381958, 21.76519394], [88.38433075, 21.76473045], [88.38490295, 21.76444054]]], [[[88.45861053, 21.78865051], [88.45910645, 21.78864861], [88.45952606, 21.78878975], [88.45995331, 21.78893089], [88.46047974, 21.78868294], [88.4609375, 21.78853989], [88.46128845, 21.78862572], [88.46155548, 21.78879356], [88.46195221, 21.78887367], [88.46269989, 21.78876114], [88.46326447, 21.78888702], [88.46378326, 21.78911972], [88.46421814, 21.7894783], [88.46463776, 21.78981972], [88.46499634, 21.7902298], [88.46531677, 21.79066086], [88.46557617, 21.79120064], [88.46586609, 21.79171181], [88.46613312, 21.79220772], [88.46639252, 21.79265976], [88.46668243, 21.79304123], [88.46707916, 21.79328537], [88.46759033, 21.79342842], [88.46816254, 21.7936306], [88.46875763, 21.79388046], [88.4693985, 21.79401016], [88.47007751, 21.79371262], [88.47077179, 21.79364014], [88.47143555, 21.79357147], [88.47194672, 21.79333305], [88.47222137, 21.79361153], [88.47250366, 21.79333305], [88.47277832, 21.79333305], [88.47360992, 21.79249954], [88.47389221, 21.79249954], [88.47499847, 21.79138947], [88.47499847, 21.78806114], [88.47444153, 21.78750038], [88.47444153, 21.78722191], [88.47389221, 21.78666687], [88.47389221, 21.78583145], [88.47360992, 21.78555489], [88.47360992, 21.78499985], [88.4733429, 21.78471756], [88.47333527, 21.7836113], [88.47277832, 21.78305626], [88.47277832, 21.78222275], [88.47250366, 21.78194427], [88.47250366, 21.78111076], [88.4716568, 21.78055954], [88.47249603, 21.77972031], [88.47222137, 21.77944374], [88.47222137, 21.77901077], [88.47220612, 21.77860069], [88.47219086, 21.77816963], [88.47200775, 21.77775955], [88.47175598, 21.77734947], [88.47141266, 21.77697754], [88.47111511, 21.77655411], [88.47086334, 21.77610016], [88.47072601, 21.77560043], [88.47059631, 21.77513123], [88.47055817, 21.77463913], [88.47054291, 21.7741394], [88.47045135, 21.77363014], [88.47029877, 21.77310753], [88.470047, 21.77265739], [88.47000122, 21.77213097], [88.47003174, 21.77156067], [88.4702301, 21.77099037], [88.47026062, 21.7704258], [88.47020721, 21.76986122], [88.47039795, 21.76926041], [88.47009277, 21.76865005], [88.46996307, 21.76806831], [88.46976471, 21.76760483], [88.46973419, 21.76712608], [88.46977234, 21.7666111], [88.4697876, 21.76605034], [88.46971893, 21.76548004], [88.46958923, 21.76490021], [88.46946716, 21.76432037], [88.46943665, 21.76371765], [88.46940613, 21.76308823], [88.46943665, 21.76240921], [88.46943665, 21.76171112], [88.46944427, 21.76100922], [88.46943665, 21.76029968], [88.46943665, 21.75959015], [88.46943665, 21.75887108], [88.4693985, 21.75814056], [88.4691925, 21.75741959], [88.46910095, 21.75671005], [88.46894073, 21.75601006], [88.46888733, 21.75528908], [88.46888733, 21.75457001], [88.46892548, 21.75390816], [88.46916962, 21.75333023], [88.46916962, 21.75277519], [88.46861267, 21.75278091], [88.46806335, 21.75222015], [88.46805573, 21.75027847], [88.46749878, 21.74971962], [88.46749878, 21.74944305], [88.46721649, 21.7491703], [88.46721649, 21.74806023], [88.46666718, 21.74749947], [88.46639252, 21.74749947], [88.46639252, 21.74332809], [88.46583557, 21.74277878], [88.46721649, 21.74139023], [88.46721649, 21.74110985], [88.46731567, 21.74108696], [88.46723175, 21.74067307], [88.46721649, 21.74034119], [88.46721649, 21.74001122], [88.46721649, 21.73962975], [88.46721649, 21.73916054], [88.46721649, 21.73861122], [88.46721649, 21.73722076], [88.46666718, 21.73666573], [88.46666718, 21.73583031], [88.46639252, 21.73555565], [88.46639252, 21.73500061], [88.46527863, 21.73389053], [88.46527863, 21.73361015], [88.46499634, 21.73333359], [88.46499634, 21.73305511], [88.46444702, 21.73250008], [88.46444702, 21.73193932], [88.46416473, 21.73166656], [88.4641571, 21.73138809], [88.46389008, 21.73110962], [88.46389008, 21.73083305], [88.46333313, 21.73027992], [88.46333313, 21.72999954], [88.46305847, 21.72972107], [88.46305847, 21.7294445], [88.46277618, 21.72916794], [88.46277618, 21.72887993], [88.46250153, 21.72861099], [88.46250153, 21.72833061], [88.46221924, 21.72805786], [88.46221924, 21.72777939], [88.46193695, 21.72750092], [88.46193695, 21.72722054], [88.46083069, 21.72611046], [88.45889282, 21.72611046], [88.45861053, 21.72639084], [88.45805359, 21.72638893], [88.45749664, 21.72694588], [88.45713043, 21.72657394], [88.45694733, 21.72638893], [88.45694733, 21.72583961], [88.45729065, 21.72546005], [88.45742035, 21.72499084], [88.45735931, 21.72457123], [88.45729065, 21.72416115], [88.45722961, 21.72360992], [88.45722198, 21.72305489], [88.45694733, 21.72277832], [88.45694733, 21.72249985], [88.45667267, 21.72221947], [88.45666504, 21.72194481], [88.45639038, 21.72194481], [88.45639038, 21.72083282], [88.45666504, 21.72055626], [88.45667267, 21.72000122], [88.45639038, 21.71970749], [88.45639038, 21.71888924], [88.45610809, 21.71861076], [88.45610809, 21.71832848], [88.45639038, 21.71805573], [88.45641327, 21.71731949], [88.45683289, 21.71674156], [88.45664978, 21.71618271], [88.45648193, 21.71556664], [88.45646667, 21.71484947], [88.45661926, 21.71412277], [88.45665741, 21.7134285], [88.45659637, 21.71281242], [88.45641327, 21.71228218], [88.45620728, 21.71180344], [88.45591736, 21.71141815], [88.45554352, 21.71112251], [88.45506287, 21.71091461], [88.45440674, 21.71086502], [88.45366669, 21.71088982], [88.45291901, 21.71082115], [88.45215607, 21.71076012], [88.45145416, 21.71070862], [88.45102692, 21.71066856], [88.45090485, 21.71065712], [88.45036316, 21.71058083], [88.44966125, 21.71051407], [88.44893646, 21.71044159], [88.44850159, 21.71038055], [88.44391632, 21.70998192], [88.44148254, 21.70984077], [88.43990326, 21.70930481], [88.44000244, 21.70916748], [88.43955231, 21.7091198], [88.43911743, 21.70888519], [88.43869019, 21.70868111], [88.43824768, 21.70850945], [88.43781281, 21.70829964], [88.43735504, 21.70810318], [88.4369812, 21.7078476], [88.43662262, 21.70757294], [88.43622589, 21.70730019], [88.4358902, 21.70697021], [88.43558502, 21.70661163], [88.43527222, 21.70624924], [88.43489838, 21.70590019], [88.43444824, 21.70555878], [88.43395996, 21.70518112], [88.43353271, 21.70469093], [88.43313599, 21.70448112], [88.43281555, 21.7046299], [88.43247986, 21.70500374], [88.43209076, 21.70524406], [88.43157196, 21.70543289], [88.43122864, 21.70581818], [88.43106842, 21.70646286], [88.43065643, 21.70703125], [88.43083191, 21.70757294], [88.43093872, 21.70819283], [88.43081665, 21.70876122], [88.43060303, 21.70927048], [88.43044281, 21.7097702], [88.4302597, 21.71023941], [88.43003845, 21.71064949], [88.42984772, 21.71106529], [88.42955017, 21.71139336], [88.42925262, 21.71169853], [88.42900848, 21.71208572], [88.42870331, 21.71241379], [88.42842102, 21.71279907], [88.42813873, 21.71325111], [88.42780304, 21.71369743], [88.4274826, 21.71416283], [88.42711639, 21.71457291], [88.42692566, 21.7149868], [88.42687988, 21.71509171], [88.42675781, 21.71570778], [88.426651, 21.71636009], [88.42645264, 21.71706009], [88.42642975, 21.71776962], [88.4265976, 21.7184906], [88.42665863, 21.71920967], [88.42666626, 21.71989441], [88.42669678, 21.72050095], [88.42687988, 21.72096062], [88.42698669, 21.72140121], [88.42719269, 21.72170067], [88.42733002, 21.72203827], [88.42751312, 21.72232246], [88.42772675, 21.72258949], [88.42790985, 21.72290993], [88.42806244, 21.72323227], [88.42823792, 21.72354126], [88.42838287, 21.72392082], [88.42858124, 21.72426987], [88.42870331, 21.72467995], [88.42884827, 21.72507095], [88.42896271, 21.72544861], [88.4296875, 21.72642899], [88.42942047, 21.72830009], [88.42868805, 21.73021126], [88.42804718, 21.73238945], [88.42780304, 21.73284149], [88.42764282, 21.7333107], [88.42746735, 21.73372078], [88.42723846, 21.73404121], [88.42700958, 21.73438072], [88.42671967, 21.73475647], [88.42639923, 21.73523331], [88.4260788, 21.73583221], [88.42566681, 21.73641968], [88.42530823, 21.73707771], [88.42511749, 21.73756409], [88.42502594, 21.73779106], [88.42488098, 21.73854828], [88.42464447, 21.73923111], [88.42435455, 21.73980141], [88.42405701, 21.74026489], [88.42376709, 21.74069023], [88.42359924, 21.74123001], [88.42344666, 21.74178314], [88.42357635, 21.74234009], [88.42362213, 21.74291039], [88.42371368, 21.74341393], [88.42385101, 21.74373245], [88.42388153, 21.74381065], [88.42401123, 21.74418831], [88.42405701, 21.74460983], [88.42455292, 21.74496078], [88.42450714, 21.74535179], [88.42478943, 21.74620056], [88.42517853, 21.74657059], [88.42553711, 21.74706078], [88.42602539, 21.74779892], [88.42603302, 21.74830055], [88.42611694, 21.74897003], [88.42636871, 21.74949074], [88.42655945, 21.75000954], [88.42669678, 21.75049973], [88.42684174, 21.75096703], [88.42692566, 21.75142479], [88.42693329, 21.75188065], [88.42694855, 21.75232697], [88.42694092, 21.75277138], [88.42690277, 21.75323105], [88.42684174, 21.75372124], [88.42682648, 21.75420189], [88.42681885, 21.75467873], [88.42682648, 21.75506973], [88.42669678, 21.75541115], [88.426651, 21.75576019], [88.42655182, 21.75607681], [88.42643738, 21.75634956], [88.42623901, 21.75656891], [88.42614746, 21.75683975], [88.42610168, 21.75716591], [88.42604828, 21.75734711], [88.42601013, 21.75746155], [88.4258728, 21.75773048], [88.42578888, 21.75806808], [88.42559052, 21.75836945], [88.42549133, 21.75876045], [88.4253006, 21.75913048], [88.42516327, 21.75955963], [88.42501068, 21.76002121], [88.42488861, 21.76052094], [88.42471313, 21.76099968], [88.4243927, 21.76143837], [88.42402649, 21.76193237], [88.42401123, 21.76243973], [88.42362976, 21.76301956], [88.42359161, 21.76356506], [88.42351532, 21.76405334], [88.4234314, 21.76449013], [88.42334747, 21.76492119], [88.4233017, 21.76536369], [88.42314148, 21.76576424], [88.42310333, 21.76616287], [88.42327118, 21.76663971], [88.42331696, 21.76716042], [88.42336273, 21.76772499], [88.42354584, 21.76827049], [88.42381287, 21.76879311], [88.42417908, 21.76922989], [88.42459869, 21.76960945], [88.42508698, 21.76997948], [88.42560577, 21.77032089], [88.42614746, 21.77065277], [88.426651, 21.77097702], [88.42710876, 21.77131462], [88.42753601, 21.77168274], [88.42806244, 21.7719593], [88.42861938, 21.77223015], [88.42917633, 21.77252579], [88.42971039, 21.77285194], [88.43017578, 21.77316093], [88.43058777, 21.7734127], [88.43087769, 21.77366829], [88.43115234, 21.77386093], [88.43143463, 21.77397919], [88.43167114, 21.77417946], [88.4319458, 21.77440071], [88.43239594, 21.77449036], [88.43282318, 21.77472115], [88.43328857, 21.7749958], [88.43379974, 21.77528], [88.43431091, 21.7756176], [88.43470764, 21.7761116], [88.43501282, 21.7767086], [88.43527985, 21.77682114], [88.43563843, 21.77682114], [88.43599701, 21.77701759], [88.4362793, 21.77734947], [88.43663788, 21.77769279], [88.4369278, 21.77802658], [88.43706512, 21.77836227], [88.43740845, 21.77876091], [88.43808746, 21.77947807], [88.43842316, 21.77993011], [88.43878937, 21.78034973], [88.43902588, 21.78083992], [88.43921661, 21.78136063], [88.4393692, 21.78187943], [88.43950653, 21.78237915], [88.43972778, 21.78284073], [88.43994141, 21.78326035], [88.44019318, 21.78357697], [88.44033813, 21.78392029], [88.44051361, 21.78430748], [88.44061279, 21.78474998], [88.44082642, 21.78513908], [88.44106293, 21.78553009], [88.44122314, 21.78596115], [88.44136047, 21.78642082], [88.44136047, 21.78691101], [88.44127655, 21.78743172], [88.44143677, 21.78793716], [88.44165039, 21.78846169], [88.44180298, 21.78900909], [88.4418869, 21.78959084], [88.44194031, 21.79020119], [88.44194031, 21.79079819], [88.44197845, 21.79138947], [88.44215393, 21.79190636], [88.44225311, 21.79247475], [88.44243622, 21.79302406], [88.44254303, 21.79360008], [88.44277191, 21.79408073], [88.44301605, 21.79453087], [88.44320679, 21.79499054], [88.44341278, 21.79547119], [88.4437561, 21.79588127], [88.44410706, 21.79635048], [88.4446106, 21.79674911], [88.44506073, 21.79720879], [88.44554901, 21.79761124], [88.44603729, 21.79795837], [88.44658661, 21.79816246], [88.44689941, 21.79830742], [88.44709778, 21.79840088], [88.4474411, 21.79839325], [88.44766998, 21.79838943], [88.44824982, 21.79822731], [88.44876862, 21.79787064], [88.44915009, 21.79740524], [88.44943237, 21.79692078], [88.44967651, 21.7964592], [88.4499588, 21.79604912], [88.45020294, 21.79564095], [88.45044708, 21.79525948], [88.45069122, 21.79486275], [88.45093536, 21.79445457], [88.45121765, 21.79405022], [88.45150757, 21.7936554], [88.45188141, 21.79333115], [88.45226288, 21.79301071], [88.45259094, 21.79263115], [88.45282745, 21.79217911], [88.45311737, 21.79174995], [88.45349884, 21.7913475], [88.45391846, 21.7909565], [88.45440674, 21.79058838], [88.4549408, 21.7902813], [88.45545197, 21.7899971], [88.45593262, 21.78972054], [88.45639801, 21.78944016], [88.45689392, 21.78917313], [88.45745087, 21.7889595], [88.45807648, 21.78883743], [88.45861053, 21.78865051]]], [[[88.28279114, 21.76501083], [88.28250122, 21.76501083], [88.28250122, 21.76527786], [88.28056335, 21.76721954], [88.28083038, 21.76749992], [88.28083038, 21.76805687], [88.27916718, 21.76972198], [88.28055573, 21.76972198], [88.28111267, 21.76944351], [88.28194427, 21.76861191], [88.28166962, 21.76833344], [88.28250122, 21.76749992], [88.28250122, 21.76721954], [88.28221893, 21.76694679], [88.28277588, 21.76638794], [88.28279114, 21.76610947], [88.28305817, 21.7658329], [88.28305817, 21.76555443], [88.28279114, 21.76527977], [88.28279114, 21.76501083]]], [[[88.78749847, 21.74500084], [88.78694153, 21.74443817], [88.78666687, 21.74444389], [88.78610992, 21.74389076], [88.78583527, 21.74389076], [88.78444672, 21.74250031], [88.78444672, 21.74221992], [88.78388977, 21.7416687], [88.78388977, 21.74081993], [88.78360748, 21.74055672], [88.78388977, 21.74027824], [88.78388977, 21.73944092], [88.78416443, 21.73916435], [88.7841568, 21.73888969], [88.78527069, 21.73777962], [88.78610992, 21.73777962], [88.78694153, 21.73694038], [88.78639221, 21.73638916], [88.78621674, 21.73612022], [88.78592682, 21.73594093], [88.78547668, 21.73575974], [88.78498077, 21.73555183], [88.78446198, 21.73533058], [88.78383636, 21.73526192], [88.78320313, 21.73514938], [88.78256989, 21.73497963], [88.78210449, 21.73478317], [88.78197479, 21.73472786], [88.78143311, 21.73444939], [88.78089905, 21.73414993], [88.78047943, 21.73382759], [88.78000641, 21.7335701], [88.77954102, 21.73331833], [88.77908325, 21.73303986], [88.77866364, 21.73270416], [88.77828979, 21.7322979], [88.77787781, 21.73191071], [88.77767181, 21.73168945], [88.77746582, 21.73146629], [88.77690887, 21.73109055], [88.77666473, 21.73084641], [88.77635956, 21.73085022], [88.77598572, 21.73096085], [88.77561951, 21.73111916], [88.77528381, 21.73135757], [88.77489471, 21.73150444], [88.77451324, 21.73167038], [88.77410889, 21.73186111], [88.77365875, 21.7319355], [88.77318573, 21.73195267], [88.77269745, 21.73194695], [88.77220154, 21.73194504], [88.771698, 21.73194313], [88.7711792, 21.73194504], [88.77065277, 21.73199081], [88.7701416, 21.73219109], [88.76957703, 21.73236084], [88.76899719, 21.73247719], [88.76842499, 21.73250008], [88.76786804, 21.73250008], [88.76733398, 21.73250008], [88.76680756, 21.73245811], [88.76634216, 21.73223114], [88.76584625, 21.73204041], [88.76528168, 21.73215675], [88.76475525, 21.73219299], [88.76432037, 21.73228073], [88.76390076, 21.73246002], [88.76365662, 21.73248482], [88.76346588, 21.73250389], [88.76302338, 21.73256302], [88.76259613, 21.7327404], [88.76211548, 21.73279762], [88.7616806, 21.73291016], [88.76126862, 21.73303032], [88.76082611, 21.73306274], [88.76039124, 21.73306274], [88.75991821, 21.73306274], [88.75940704, 21.73306274], [88.75885773, 21.73307991], [88.75830841, 21.73322105], [88.75772858, 21.73331833], [88.75715637, 21.73335075], [88.75666046, 21.73340988], [88.75631714, 21.73374176], [88.756073, 21.73409271], [88.75583649, 21.73439026], [88.75563812, 21.73468018], [88.75556946, 21.73502541], [88.75550079, 21.7354126], [88.75531769, 21.73579979], [88.75527191, 21.73631287], [88.75519562, 21.73687553], [88.75502777, 21.73746109], [88.75492096, 21.73810959], [88.75475311, 21.73869514], [88.75470734, 21.73924065], [88.7546463, 21.7397728], [88.75450897, 21.74030685], [88.7545166, 21.74088478], [88.75450134, 21.74144173], [88.75443268, 21.74196434], [88.75431061, 21.74245262], [88.75422668, 21.74293327], [88.75435638, 21.74341965], [88.7544632, 21.74394035], [88.75460052, 21.74446106], [88.75473022, 21.74496841], [88.75488281, 21.74542236], [88.75502014, 21.74579048], [88.75520325, 21.74606133], [88.7552948, 21.74638176], [88.75541687, 21.74666405], [88.7555542, 21.74694252], [88.75570679, 21.74723053], [88.75584412, 21.74759865], [88.75601959, 21.74799156], [88.75613403, 21.74847221], [88.75631714, 21.74897003], [88.75649261, 21.74950981], [88.75676727, 21.74995995], [88.75712585, 21.75033951], [88.75743103, 21.75076294], [88.75773621, 21.75118065], [88.75801849, 21.75161552], [88.75839233, 21.75200462], [88.75879669, 21.75239944], [88.75927734, 21.75279808], [88.75977325, 21.75322723], [88.76035309, 21.75358009], [88.76094818, 21.75389099], [88.76148987, 21.75418854], [88.76190948, 21.75455284], [88.76222229, 21.75493813], [88.76249695, 21.75530243], [88.76277161, 21.75562668], [88.76277924, 21.75582123], [88.76304626, 21.75611115], [88.76305389, 21.75666618], [88.76333618, 21.75694466], [88.76361084, 21.75694466], [88.76353455, 21.75713539], [88.76381683, 21.75740051], [88.76423645, 21.75821114], [88.76438904, 21.7592907], [88.76438904, 21.76049995], [88.76396179, 21.7622509], [88.76249695, 21.76361084], [88.76194763, 21.76416969], [88.76159668, 21.76474571], [88.76107788, 21.76503944], [88.76062012, 21.76535034], [88.76026154, 21.76571274], [88.75997162, 21.76605988], [88.75951385, 21.7661953], [88.7590332, 21.76638985], [88.75849915, 21.7666111], [88.75786591, 21.76670265], [88.75727844, 21.76690865], [88.7566452, 21.7670002], [88.75627899, 21.76712799], [88.756073, 21.76720047], [88.75547791, 21.76731682], [88.75493622, 21.76746941], [88.7543869, 21.76754951], [88.75388336, 21.76774025], [88.75332642, 21.76778984], [88.75280762, 21.76789284], [88.75231934, 21.76806259], [88.75183868, 21.76826286], [88.75130463, 21.76837158], [88.75081635, 21.76860809], [88.75034332, 21.76889992], [88.74994659, 21.76923752], [88.74975586, 21.76964951], [88.74984741, 21.77011108], [88.75011444, 21.77049065], [88.75054169, 21.77077293], [88.7509613, 21.77108955], [88.75139618, 21.77139091], [88.75183105, 21.77170944], [88.75218964, 21.77210045], [88.75253296, 21.77252007], [88.75285339, 21.77290916], [88.75328064, 21.77313995], [88.75369263, 21.77337074], [88.75409698, 21.77362061], [88.7545166, 21.77390289], [88.75493622, 21.77424049], [88.75531006, 21.77463913], [88.75569153, 21.7750206], [88.75598145, 21.77544022], [88.75617218, 21.77588081], [88.7563858, 21.77620125], [88.75662231, 21.77645111], [88.75681305, 21.77668953], [88.75697327, 21.77696037], [88.75721741, 21.77724075], [88.75749207, 21.77754974], [88.75778198, 21.77791023], [88.75810242, 21.77827072], [88.758461, 21.77860641], [88.75881958, 21.77893257], [88.75914001, 21.77930069], [88.75944519, 21.77969742], [88.75984192, 21.77999115], [88.76026917, 21.78028107], [88.76069641, 21.78055954], [88.7611618, 21.78084755], [88.76161194, 21.7811985], [88.76204681, 21.78162956], [88.76255035, 21.78204536], [88.76304626, 21.78250122], [88.7635498, 21.78297806], [88.76407623, 21.78339958], [88.76452637, 21.78388977], [88.76493835, 21.78439522], [88.76526642, 21.78494263], [88.76555634, 21.78549194], [88.76583862, 21.78598976], [88.76611328, 21.78641891], [88.76637268, 21.78679085], [88.76657867, 21.78715515], [88.76670074, 21.78755951], [88.76692963, 21.78794861], [88.76715088, 21.78837967], [88.76734161, 21.78889084], [88.76754761, 21.78941917], [88.76777649, 21.78993988], [88.76799774, 21.79044914], [88.76806641, 21.79098511], [88.76811218, 21.79148102], [88.76821899, 21.79191971], [88.76831818, 21.79230118], [88.76835632, 21.79265976], [88.76837921, 21.79300117], [88.76856232, 21.79331017], [88.76870728, 21.79367065], [88.76879883, 21.79412651], [88.76872253, 21.7946949], [88.76893616, 21.79518318], [88.76917267, 21.79566193], [88.76940155, 21.79614067], [88.7694931, 21.79668236], [88.76969147, 21.79713631], [88.76984406, 21.79762077], [88.7700119, 21.79808998], [88.77021027, 21.79854965], [88.77039337, 21.79900551], [88.77057648, 21.79945374], [88.77082825, 21.79985046], [88.77109528, 21.80025864], [88.77139282, 21.80067825], [88.77166748, 21.80113983], [88.77197266, 21.8015976], [88.77211761, 21.80178261], [88.77230072, 21.80202293], [88.77264404, 21.80237007], [88.77297211, 21.80270386], [88.77324677, 21.80303955], [88.77355957, 21.80335808], [88.77381897, 21.80369949], [88.77398682, 21.80412102], [88.7742157, 21.80448723], [88.77445984, 21.80485153], [88.77472687, 21.8051796], [88.77500916, 21.80550003], [88.77526093, 21.80578995], [88.77542114, 21.80610085], [88.77557373, 21.80638885], [88.77576447, 21.80662155], [88.77586365, 21.80692482], [88.77603912, 21.80718422], [88.77614594, 21.8075428], [88.77632141, 21.8079052], [88.77639771, 21.8083744], [88.77648163, 21.80887032], [88.77658081, 21.80937958], [88.77667236, 21.80986023], [88.77677155, 21.81030273], [88.77681732, 21.81072807], [88.77677917, 21.81116104], [88.77667999, 21.81158829], [88.77666473, 21.8120575], [88.7766571, 21.81249046], [88.7766037, 21.81288528], [88.77643585, 21.81323814], [88.77640533, 21.81361771], [88.77639008, 21.81403351], [88.77639008, 21.81450081], [88.7763443, 21.81505775], [88.77614594, 21.81562042], [88.77616119, 21.81619072], [88.77638245, 21.81666946], [88.77662659, 21.81707954], [88.7767868, 21.81745911], [88.77700043, 21.8177681], [88.77723694, 21.8180809], [88.77749634, 21.81849098], [88.77781677, 21.81898689], [88.77823639, 21.81945038], [88.77865601, 21.81996155], [88.77900696, 21.82040977], [88.77928162, 21.82084084], [88.77947998, 21.82127953], [88.77968597, 21.82172012], [88.77976227, 21.82228088], [88.77997589, 21.82286072], [88.78016663, 21.82348061], [88.78044128, 21.82402992], [88.78082275, 21.82443047], [88.78124237, 21.82473183], [88.78166199, 21.82500267], [88.78210449, 21.82519341], [88.78279114, 21.82501221], [88.78338623, 21.82481575], [88.78391266, 21.8246727], [88.78437805, 21.82446671], [88.78489685, 21.82422829], [88.7853775, 21.82384109], [88.78585052, 21.82337379], [88.78630066, 21.82290077], [88.78663635, 21.82242012], [88.78690338, 21.8220005], [88.78708649, 21.821661], [88.78723907, 21.82135963], [88.7873764, 21.82107162], [88.7875061, 21.82075882], [88.7876358, 21.82040977], [88.78775024, 21.82002831], [88.78782654, 21.8196106], [88.7879715, 21.81921959], [88.78804779, 21.81880951], [88.78807068, 21.81838989], [88.78813934, 21.81801033], [88.78829956, 21.81767082], [88.78843689, 21.81727982], [88.78861237, 21.81686974], [88.78881073, 21.81644821], [88.78900909, 21.81600952], [88.78926086, 21.81563568], [88.78957367, 21.81532478], [88.78990936, 21.81506729], [88.79020691, 21.81476974], [88.79049683, 21.81442833], [88.79078674, 21.81406021], [88.79110718, 21.81365967], [88.79146576, 21.81329536], [88.79177856, 21.81290054], [88.79202271, 21.81246948], [88.79229736, 21.81211853], [88.7925415, 21.81175041], [88.79279327, 21.81137085], [88.79304504, 21.81101227], [88.79323578, 21.81062126], [88.79338837, 21.81018066], [88.79355621, 21.80974007], [88.79360199, 21.8092308], [88.79361725, 21.80869865], [88.79366302, 21.80814934], [88.79377747, 21.80760193], [88.79389191, 21.80750084], [88.79389191, 21.80611038], [88.79416656, 21.80583], [88.79416656, 21.8022213], [88.79411316, 21.80160713], [88.79390717, 21.80108833], [88.79376221, 21.80060196], [88.79356384, 21.8002224], [88.79332733, 21.79993248], [88.79302979, 21.79969025], [88.79264832, 21.79949951], [88.79213715, 21.79940033], [88.79165649, 21.79920959], [88.79110718, 21.79912949], [88.79059601, 21.79891968], [88.79004669, 21.79883385], [88.7895813, 21.79863739], [88.78910065, 21.79851532], [88.78869629, 21.79832077], [88.78832245, 21.79807281], [88.78794861, 21.79776573], [88.78759766, 21.79738045], [88.78734589, 21.79688072], [88.7872467, 21.79631805], [88.78726196, 21.79579735], [88.78740692, 21.79535103], [88.7876358, 21.79497337], [88.78790283, 21.79463387], [88.7881012, 21.7942543], [88.78837585, 21.79389572], [88.78872681, 21.79355049], [88.78916931, 21.79319], [88.78965759, 21.7928009], [88.79020691, 21.79241943], [88.79071808, 21.79193115], [88.7911911, 21.79141808], [88.79153442, 21.79110527], [88.7917099, 21.79094505], [88.79225922, 21.7905426], [88.79281616, 21.79009056], [88.79337311, 21.78967857], [88.79389954, 21.78923035], [88.79440308, 21.78879166], [88.79478455, 21.7883358], [88.79499817, 21.78806114], [88.79582977, 21.78722191], [88.79582977, 21.78611183], [88.79556274, 21.78583145], [88.7957077, 21.78574181], [88.79549408, 21.78541183], [88.79528809, 21.78514671], [88.79509735, 21.78482056], [88.79491425, 21.78449631], [88.79463196, 21.78421021], [88.79425812, 21.78393936], [88.7939682, 21.78346062], [88.79353333, 21.7829895], [88.79316711, 21.78238487], [88.79263306, 21.78189087], [88.79218292, 21.78135109], [88.79176331, 21.7808342], [88.79134369, 21.7803154], [88.79091644, 21.77977943], [88.79053497, 21.77916527], [88.7901001, 21.77861977], [88.78967285, 21.77814102], [88.78927612, 21.77778053], [88.78897858, 21.77745819], [88.78878784, 21.77713013], [88.78859711, 21.77680016], [88.78840637, 21.77646065], [88.78816986, 21.77612114], [88.78788757, 21.77579308], [88.78762817, 21.77542114], [88.78733063, 21.77510071], [88.78722382, 21.77499962], [88.78472137, 21.77249908], [88.78472137, 21.77222061], [88.78416443, 21.77166748], [88.7841568, 21.77082825], [88.78388977, 21.7705555], [88.78388977, 21.77028084], [88.78362274, 21.76992035], [88.78340149, 21.7696209], [88.78327179, 21.76927948], [88.78309631, 21.76896095], [88.78302002, 21.76859093], [88.7828598, 21.76823997], [88.78274536, 21.76783752], [88.78250122, 21.76749992], [88.78250122, 21.76721954], [88.78221893, 21.76694679], [88.78221893, 21.76277733], [88.78250122, 21.76250076], [88.78250122, 21.76083183], [88.78277588, 21.76055527], [88.78277588, 21.75917244], [88.78305817, 21.75889015], [88.78305817, 21.75832748], [88.78333282, 21.75805473], [88.78333282, 21.75722313], [88.78360748, 21.75694466], [88.78360748, 21.75666618], [88.78388977, 21.75638962], [88.78388977, 21.75611115], [88.7841568, 21.75582123], [88.78416443, 21.75555611], [88.78555298, 21.75416946], [88.78555298, 21.75389099], [88.78610992, 21.75333023], [88.78610992, 21.75305748], [88.78639221, 21.75278091], [88.78639221, 21.75250053], [88.78666687, 21.75222015], [88.78666687, 21.75194359], [88.78778076, 21.75083351], [88.78778076, 21.75055313], [88.78824615, 21.75033951], [88.78853607, 21.75004959], [88.78871918, 21.74970436], [88.78882599, 21.74933815], [88.78887177, 21.74892807], [88.78890228, 21.74848938], [88.78890991, 21.74801445], [88.78889465, 21.74748611], [88.78887177, 21.74694252], [88.78878021, 21.74641991], [88.78860474, 21.74597168], [88.7883606, 21.74559021], [88.78804779, 21.74527931], [88.78768158, 21.74501991], [88.78749847, 21.74500084]]], [[[88.54457092, 21.8103199], [88.54615021, 21.80992126], [88.54728699, 21.81005096], [88.54886627, 21.80978012], [88.55044556, 21.80924416], [88.55273437, 21.80843735], [88.55401611, 21.80763054], [88.55631256, 21.80587959], [88.55717468, 21.8044014], [88.55875397, 21.80332565], [88.56073761, 21.80265045], [88.56089783, 21.80157852], [88.56257629, 21.80070114], [88.56279755, 21.80028725], [88.56310272, 21.79993248], [88.56347656, 21.79952621], [88.56397247, 21.79911995], [88.56445313, 21.79861069], [88.5652771, 21.79777718], [88.5652771, 21.79750061], [88.56667328, 21.79610825], [88.56694794, 21.79611206], [88.5680542, 21.79500008], [88.56833649, 21.79500008], [88.56944275, 21.79388618], [88.56944275, 21.79360962], [88.56999969, 21.79305458], [88.56999969, 21.79277992], [88.56944275, 21.79222107], [88.56972504, 21.79222488], [88.5708313, 21.79111099], [88.5708313, 21.79027939], [88.57055664, 21.79000092], [88.57055664, 21.78944016], [88.5708313, 21.78944206], [88.5716629, 21.78861046], [88.57183838, 21.78860283], [88.57194519, 21.78833389], [88.57194519, 21.78805542], [88.57221985, 21.78778267], [88.57221985, 21.78722191], [88.57250214, 21.78694534], [88.57250214, 21.78583145], [88.57221985, 21.78555489], [88.57208252, 21.78551674], [88.57195282, 21.78528023], [88.57195282, 21.78499985], [88.57138824, 21.78444481], [88.57111359, 21.78444481], [88.57055664, 21.78388977], [88.56999969, 21.78388977], [88.56999969, 21.78333092], [88.56916809, 21.78333282], [88.56916809, 21.78305626], [88.56861115, 21.78249931], [88.56861877, 21.78222084], [88.56749725, 21.78111076], [88.56694794, 21.78111076], [88.56563568, 21.77980232], [88.5652771, 21.77944374], [88.56472015, 21.77944374], [88.56500244, 21.77916527], [88.56500244, 21.77889061], [88.5652771, 21.77861023], [88.56445313, 21.77778053], [88.56445313, 21.77750015], [88.56416321, 21.77722168], [88.56416321, 21.77694321], [88.56388855, 21.77667046], [88.56388855, 21.7761097], [88.56361389, 21.77583122], [88.5633316, 21.7761116], [88.5633316, 21.77499962], [88.56305695, 21.77472115], [88.56305695, 21.77388954], [88.56276703, 21.77361107], [88.56249237, 21.77361107], [88.56249237, 21.7733326], [88.56305695, 21.77277756], [88.56305695, 21.77251053], [88.56305695, 21.77222252], [88.56222534, 21.77139091], [88.56223297, 21.77028084], [88.56194305, 21.77000046], [88.56223297, 21.77000046], [88.5625, 21.76972198], [88.5625, 21.76944351], [88.56277466, 21.76916885], [88.56276703, 21.76889038], [88.56252289, 21.76861954], [88.56250763, 21.76836777], [88.56249237, 21.76806831], [88.56247711, 21.76774979], [88.56240082, 21.76741028], [88.56227112, 21.76704597], [88.56233215, 21.76662064], [88.5623703, 21.76614952], [88.56241608, 21.76565933], [88.56248474, 21.76517296], [88.5625, 21.76468468], [88.5625, 21.76422119], [88.56249237, 21.76378059], [88.56249237, 21.76334953], [88.56249237, 21.76278114], [88.56249237, 21.76028061], [88.56276703, 21.76000023], [88.56276703, 21.75972176], [88.56305695, 21.75944519], [88.56305695, 21.75917244], [88.56360626, 21.75861168], [88.56361389, 21.75833321], [88.56583405, 21.75611115], [88.56582642, 21.75582123], [88.56603241, 21.75562477], [88.56639099, 21.75527763], [88.56639099, 21.75500107], [88.56749725, 21.75389099], [88.56764221, 21.75387955], [88.56803894, 21.75337029], [88.56833649, 21.75279045], [88.56861877, 21.7522316], [88.56893158, 21.75172806], [88.56925964, 21.75127983], [88.56955719, 21.75086403], [88.56980896, 21.75045586], [88.57002258, 21.75004959], [88.57022095, 21.74965477], [88.57036591, 21.7492218], [88.57058716, 21.7488308], [88.5708313, 21.74842072], [88.57109833, 21.74798965], [88.57137299, 21.74752045], [88.5716629, 21.74707603], [88.57194519, 21.7465744], [88.5721817, 21.74601555], [88.57221985, 21.74527931], [88.57250214, 21.74500084], [88.57250214, 21.74416924], [88.57221985, 21.74388123], [88.57221985, 21.74323082], [88.57221985, 21.74222183], [88.57194519, 21.74194527], [88.57206726, 21.74159813], [88.5721283, 21.74128914], [88.57221985, 21.74083328], [88.57221985, 21.73944664], [88.57250214, 21.73916435], [88.57250214, 21.73861122], [88.57221985, 21.73861122], [88.57250214, 21.73833084], [88.57250214, 21.73555565], [88.57221985, 21.7352829], [88.57221985, 21.73500061], [88.5716629, 21.73444176], [88.5716629, 21.7341671], [88.57110596, 21.73361015], [88.57027435, 21.73361015], [88.57027435, 21.73333359], [88.56972504, 21.73333359], [88.56944275, 21.73361015], [88.56788635, 21.73361015], [88.56694794, 21.73361015], [88.56666565, 21.73333359], [88.56583405, 21.73333359], [88.56564331, 21.73314667], [88.56555176, 21.73305511], [88.56555939, 21.73278046], [88.56503296, 21.7327404], [88.56451416, 21.7325573], [88.56400299, 21.73231125], [88.56347656, 21.73197937], [88.56305695, 21.73168182], [88.56276703, 21.73167038], [88.56249237, 21.73138809], [88.56223297, 21.73138809], [88.5616684, 21.73082924], [88.56138611, 21.73083305], [88.56111145, 21.73055649], [88.56083679, 21.7305584], [88.56054688, 21.73027992], [88.56054688, 21.72999954], [88.56014252, 21.73007393], [88.55975342, 21.73019218], [88.55945587, 21.73038292], [88.55922699, 21.73064995], [88.55902863, 21.73097038], [88.55883026, 21.73131752], [88.55861664, 21.73167038], [88.5584259, 21.73207092], [88.55822754, 21.73249054], [88.55800629, 21.73293114], [88.55778503, 21.73337936], [88.55754852, 21.73378181], [88.55726624, 21.73409271], [88.5569458, 21.73434067], [88.55659485, 21.73454857], [88.55619812, 21.73476982], [88.55578613, 21.73504066], [88.55539703, 21.73538017], [88.55499268, 21.7357502], [88.55455017, 21.73609161], [88.554039, 21.73635483], [88.55348969, 21.73653984], [88.552948, 21.73664093], [88.55243683, 21.73666954], [88.55195618, 21.73672295], [88.55148315, 21.73682022], [88.55097961, 21.73687935], [88.55045319, 21.7369194], [88.54987335, 21.73698044], [88.549263, 21.73707008], [88.54857635, 21.73718071], [88.54781342, 21.73729515], [88.54709625, 21.73736954], [88.54639435, 21.73740578], [88.54567719, 21.73742485], [88.54498291, 21.73743057], [88.54434204, 21.73744965], [88.54376221, 21.73744583], [88.54325104, 21.73747253], [88.54279327, 21.73752022], [88.5423584, 21.73760986], [88.54216766, 21.73765373], [88.54197693, 21.73769951], [88.54171753, 21.73767853], [88.54160309, 21.73744011], [88.54141235, 21.73719406], [88.54109192, 21.73694801], [88.54064941, 21.73676109], [88.54016113, 21.73656845], [88.53965759, 21.73640442], [88.53911591, 21.7362709], [88.53859711, 21.73607063], [88.53811646, 21.73582268], [88.53768158, 21.73555946], [88.53723145, 21.7353096], [88.53675842, 21.73508072], [88.53630066, 21.73485756], [88.53591919, 21.73455238], [88.53551483, 21.73425484], [88.53509521, 21.73395157], [88.53471375, 21.73360252], [88.53435516, 21.73323059], [88.53404236, 21.7328167], [88.53382111, 21.73230171], [88.53353882, 21.73188591], [88.53321838, 21.7315197], [88.53292847, 21.73111916], [88.53266907, 21.73072815], [88.53244781, 21.73026085], [88.53221893, 21.72978401], [88.53196716, 21.72930717], [88.53173828, 21.72881126], [88.53153992, 21.72830391], [88.53134918, 21.72777367], [88.53111267, 21.72727585], [88.53087616, 21.72676086], [88.53068542, 21.7261982], [88.53051758, 21.72559166], [88.53032684, 21.72499084], [88.53019714, 21.72443008], [88.52999878, 21.72396088], [88.52978516, 21.72355843], [88.52955627, 21.72318268], [88.52934265, 21.72278023], [88.52908325, 21.72237968], [88.52884674, 21.7219429], [88.52876282, 21.72180367], [88.52859497, 21.72151756], [88.52835846, 21.72120285], [88.52829742, 21.72112465], [88.52796173, 21.72074509], [88.52761078, 21.72037125], [88.52752686, 21.72026634], [88.52727509, 21.71995926], [88.52693176, 21.71955109], [88.52653503, 21.71918869], [88.52603149, 21.71888924], [88.52542114, 21.71864128], [88.52510834, 21.71857071], [88.52481079, 21.71848106], [88.52443695, 21.71856117], [88.52410126, 21.71869087], [88.52381134, 21.71883392], [88.52349091, 21.7188549], [88.52331543, 21.71882629], [88.52313232, 21.71879768], [88.52274323, 21.71883011], [88.52233887, 21.7189312], [88.5218811, 21.71904945], [88.52166748, 21.71916962], [88.52139282, 21.71888924], [88.52083588, 21.71888924], [88.52054596, 21.71916962], [88.51944733, 21.7191658], [88.51889038, 21.71972275], [88.51832581, 21.71970749], [88.51750183, 21.72055626], [88.51750946, 21.72083282], [88.51738739, 21.72106361], [88.5173111, 21.72134209], [88.51725769, 21.72156906], [88.51712036, 21.72185516], [88.51711273, 21.72206306], [88.51700592, 21.72254372], [88.516716, 21.72286034], [88.51667786, 21.72324181], [88.51638031, 21.72352028], [88.51634979, 21.72394562], [88.51628876, 21.72437096], [88.51622772, 21.72481918], [88.51625824, 21.72528076], [88.51628876, 21.72570992], [88.51618195, 21.72605515], [88.51607513, 21.72641945], [88.51590729, 21.72677994], [88.51586914, 21.72714996], [88.51597595, 21.72745514], [88.51611328, 21.7277317], [88.5161972, 21.7279911], [88.51630402, 21.72822571], [88.51637268, 21.72846985], [88.51625824, 21.72874641], [88.51638794, 21.72887993], [88.51638794, 21.72983932], [88.51598358, 21.7304039], [88.51541901, 21.73040009], [88.51500702, 21.73055649], [88.5147171, 21.73082924], [88.51526642, 21.73138809], [88.51499939, 21.73166656], [88.51444244, 21.73220062], [88.51333618, 21.73278046], [88.51312256, 21.73316002], [88.51283264, 21.73353958], [88.51249695, 21.73385811], [88.51216888, 21.7342701], [88.51204681, 21.73477936], [88.51222229, 21.73534012], [88.51241302, 21.7359333], [88.51242065, 21.73637009], [88.51242065, 21.73650932], [88.51249695, 21.73666954], [88.51194763, 21.73750114], [88.51194763, 21.73777771], [88.51139069, 21.73833275], [88.5111084, 21.73833084], [88.51082611, 21.73861122], [88.51055908, 21.73861122], [88.51024628, 21.73883057], [88.50985718, 21.73928261], [88.50959778, 21.73981857], [88.50946808, 21.74046707], [88.50908661, 21.74097633], [88.5088501, 21.74155235], [88.50862122, 21.74211121], [88.50845337, 21.74267387], [88.50834656, 21.74325943], [88.50827789, 21.74386978], [88.50806427, 21.74446106], [88.50786591, 21.74504471], [88.50763702, 21.74564362], [88.50738525, 21.74619293], [88.50704956, 21.74658394], [88.50682831, 21.74687958], [88.50675964, 21.74697113], [88.50649261, 21.74736023], [88.50617981, 21.74771118], [88.50595856, 21.74806976], [88.50583649, 21.74839783], [88.50572968, 21.74868011], [88.50557709, 21.74894142], [88.50547028, 21.74920845], [88.50521088, 21.74949646], [88.50492096, 21.7498703], [88.50460052, 21.75029945], [88.50437927, 21.75076294], [88.50457001, 21.75139427], [88.5045166, 21.75205231], [88.50444031, 21.75271988], [88.50454712, 21.75336075], [88.5045166, 21.75387001], [88.50466156, 21.75434113], [88.50458527, 21.7547226], [88.5044632, 21.75509071], [88.50432587, 21.7555294], [88.50432587, 21.75597382], [88.50440979, 21.75642967], [88.50440216, 21.75691986], [88.5043869, 21.75741005], [88.50449371, 21.7578907], [88.5047226, 21.75829124], [88.50499725, 21.75867081], [88.50528717, 21.75901985], [88.50562286, 21.75933075], [88.50601959, 21.75952721], [88.50636292, 21.7598381], [88.50668335, 21.76023102], [88.50719452, 21.76050568], [88.50770569, 21.76086044], [88.50823212, 21.76127052], [88.50895691, 21.76151848], [88.50943756, 21.76171112], [88.51022339, 21.7621479], [88.51072693, 21.7625103], [88.51132202, 21.76278114], [88.51181793, 21.7630806], [88.5121994, 21.76343918], [88.51254272, 21.76381111], [88.51288605, 21.76415062], [88.51325226, 21.76447105], [88.51360321, 21.76480865], [88.51394653, 21.76516151], [88.51436615, 21.76548004], [88.5147934, 21.76580238], [88.51521301, 21.76610947], [88.51560211, 21.76642036], [88.51596069, 21.76679039], [88.51637268, 21.76719284], [88.51687622, 21.76754951], [88.5174408, 21.76797676], [88.51805115, 21.76840401], [88.51864624, 21.76883125], [88.51889038, 21.76917076], [88.51944733, 21.76916885], [88.51981354, 21.76953697], [88.51999664, 21.76972198], [88.52027893, 21.76972198], [88.52046204, 21.76990509], [88.52083588, 21.77028084], [88.52111053, 21.77028084], [88.52129364, 21.77046585], [88.52139282, 21.77055931], [88.52194214, 21.77055931], [88.52224731, 21.77095032], [88.52268219, 21.77133942], [88.52316284, 21.7717495], [88.52367401, 21.77212715], [88.52416992, 21.77248955], [88.52465057, 21.77285767], [88.52509308, 21.77325058], [88.52548218, 21.77366066], [88.52584076, 21.77409172], [88.52616882, 21.77453995], [88.52648926, 21.77498055], [88.52684784, 21.77539063], [88.52720642, 21.77577019], [88.52755737, 21.77613068], [88.52787781, 21.77648544], [88.52819061, 21.7768383], [88.5284729, 21.77724075], [88.52867126, 21.77763939], [88.52890015, 21.77801895], [88.52916718, 21.77837944], [88.52947235, 21.77877808], [88.52986145, 21.7792263], [88.53029633, 21.77972984], [88.53077698, 21.78028107], [88.53124237, 21.7808609], [88.53161621, 21.78148079], [88.53198242, 21.78205109], [88.53231812, 21.78252983], [88.53263092, 21.78296089], [88.53283691, 21.78339005], [88.53292847, 21.78383064], [88.53295135, 21.78424835], [88.53305054, 21.78467178], [88.53318787, 21.78510094], [88.53333282, 21.78551292], [88.53347015, 21.7859211], [88.53360748, 21.7863369], [88.53373718, 21.78676033], [88.53388977, 21.78719521], [88.53399658, 21.78771019], [88.53407288, 21.78827286], [88.53412628, 21.78880692], [88.53425598, 21.78934288], [88.53443909, 21.78988075], [88.53466797, 21.79041862], [88.53495026, 21.79091072], [88.53521729, 21.79137993], [88.53535461, 21.79177666], [88.53528595, 21.7920208], [88.53502655, 21.79206276], [88.53468323, 21.7918911], [88.53430939, 21.79152107], [88.53398895, 21.79105759], [88.53373718, 21.79055023], [88.53354645, 21.79008102], [88.53341675, 21.78967094], [88.53330994, 21.78931046], [88.5331955, 21.78892136], [88.53308868, 21.78846741], [88.53298187, 21.7879715], [88.53292847, 21.78741074], [88.53288269, 21.78684807], [88.53273773, 21.78632164], [88.53250885, 21.78585815], [88.53230286, 21.78544044], [88.53208923, 21.78500938], [88.53187561, 21.78455734], [88.53167725, 21.78407097], [88.53152466, 21.78362656], [88.53137207, 21.78324127], [88.53119659, 21.78289032], [88.5309906, 21.78256035], [88.53076172, 21.7822094], [88.53050995, 21.78183174], [88.53022766, 21.78146744], [88.52993011, 21.78108025], [88.52962494, 21.78067207], [88.52935028, 21.78024673], [88.52910614, 21.77984047], [88.52888489, 21.77945137], [88.52861786, 21.77910423], [88.52830505, 21.7787838], [88.52801514, 21.7784214], [88.52771759, 21.77802849], [88.52742004, 21.77763939], [88.52713013, 21.77727127], [88.52682495, 21.77689171], [88.52651215, 21.77647972], [88.52616119, 21.77609062], [88.52575684, 21.7756691], [88.52532959, 21.77517128], [88.52485657, 21.77465057], [88.52436829, 21.7741394], [88.52388, 21.77363968], [88.52336121, 21.7731781], [88.52281952, 21.77275276], [88.52227783, 21.77233124], [88.52173615, 21.77190971], [88.52111053, 21.77139091], [88.52083588, 21.77139091], [88.52065277, 21.7712059], [88.52027893, 21.77083397], [88.51972198, 21.77083397], [88.51961517, 21.77072334], [88.51944733, 21.7705555], [88.51889038, 21.77055931], [88.51860809, 21.77028084], [88.51832581, 21.77028084], [88.51810455, 21.76993942], [88.5178299, 21.76971626], [88.5173111, 21.76927948], [88.51674652, 21.76889992], [88.5161972, 21.76854706], [88.51566315, 21.76815987], [88.51512146, 21.76777077], [88.51460266, 21.76737976], [88.51410675, 21.7670002], [88.51361084, 21.76663971], [88.51316833, 21.76622963], [88.51272583, 21.76581955], [88.5121994, 21.76555061], [88.51167297, 21.76527977], [88.51112366, 21.76502037], [88.51064301, 21.76470184], [88.5102005, 21.76438522], [88.50969696, 21.76415062], [88.50920105, 21.76391983], [88.50863647, 21.76377106], [88.50810242, 21.76358604], [88.50760651, 21.76334], [88.50712585, 21.76313019], [88.50663757, 21.76305962], [88.50617981, 21.76305771], [88.50576782, 21.76300049], [88.50526428, 21.76282501], [88.50502014, 21.7627697], [88.5047226, 21.76262474], [88.50444794, 21.76250076], [88.50417328, 21.76250076], [88.50389099, 21.76278114], [88.50389099, 21.7630558], [88.5036087, 21.76333046], [88.50360107, 21.76365662], [88.50353241, 21.76394463], [88.50337219, 21.7642498], [88.50332642, 21.76464081], [88.50333405, 21.76506996], [88.50332642, 21.7655201], [88.50333405, 21.76597786], [88.50361633, 21.76625061], [88.50361633, 21.76680946], [88.50389099, 21.76749992], [88.50389099, 21.76805687], [88.50416565, 21.76833344], [88.50416565, 21.76944351], [88.50444794, 21.76971817], [88.50444794, 21.77000046], [88.50416565, 21.77027893], [88.50417328, 21.77082825], [88.50444794, 21.77111053], [88.50444794, 21.77166748], [88.5047226, 21.77193832], [88.5047226, 21.77249908], [88.50494385, 21.77263069], [88.50505829, 21.77318382], [88.50527191, 21.77360153], [88.50547028, 21.77394867], [88.50556946, 21.77430534], [88.50572205, 21.77462006], [88.50584412, 21.77495956], [88.50598907, 21.77529335], [88.50610352, 21.77565384], [88.50619507, 21.7760334], [88.5063858, 21.77634811], [88.50656891, 21.77667999], [88.50673676, 21.77700996], [88.50692749, 21.77734947], [88.50710297, 21.77774048], [88.50739288, 21.77809715], [88.5076828, 21.77850914], [88.50800323, 21.77896118], [88.50823975, 21.77945518], [88.50846863, 21.77996063], [88.50875092, 21.7804203], [88.50907135, 21.78085709], [88.50937653, 21.78129959], [88.5096817, 21.78174019], [88.50995636, 21.78219032], [88.51023865, 21.7826004], [88.51045227, 21.78302002], [88.51069641, 21.78334618], [88.51088715, 21.78364944], [88.51109314, 21.78389931], [88.51126862, 21.78416061], [88.51145172, 21.78442192], [88.51166534, 21.78469086], [88.51190186, 21.78499031], [88.51217651, 21.7852993], [88.51243591, 21.78561211], [88.51262665, 21.78594017], [88.51286316, 21.78619957], [88.51304626, 21.78645134], [88.513237, 21.78671074], [88.51341248, 21.78699493], [88.51373291, 21.7872448], [88.51407623, 21.7875309], [88.51441956, 21.78789711], [88.5147171, 21.78834343], [88.51500702, 21.78882027], [88.51534271, 21.78923988], [88.51566315, 21.78963089], [88.51605988, 21.78985596], [88.51638031, 21.79014015], [88.51667023, 21.79046059], [88.51695251, 21.79079056], [88.51725769, 21.79113579], [88.51763153, 21.79144287], [88.518013, 21.79178047], [88.51833344, 21.79220581], [88.51870728, 21.79261017], [88.51908875, 21.79308128], [88.51947021, 21.79357338], [88.51994324, 21.7939682], [88.52037048, 21.79438972], [88.52054596, 21.79445076], [88.52361298, 21.79750061], [88.52388763, 21.79750061], [88.52555847, 21.79916573], [88.52555847, 21.79943848], [88.52638245, 21.80027962], [88.5266571, 21.80027962], [88.52805328, 21.80166626], [88.52861023, 21.8022213], [88.52889252, 21.8022213], [88.53028107, 21.80361176], [88.53056335, 21.80360985], [88.53193665, 21.80500031], [88.53221893, 21.80500031], [88.53277588, 21.80556107], [88.53305817, 21.80556107], [88.53360748, 21.80611038], [88.53388977, 21.80611038], [88.5341568, 21.80639076], [88.53444672, 21.80638885], [88.53527832, 21.80722237], [88.53555298, 21.80722046], [88.53573608, 21.80740738], [88.53610992, 21.80778122], [88.53639221, 21.80778122], [88.53666687, 21.80805969], [88.53721619, 21.80805969], [88.53778076, 21.80861092], [88.53806305, 21.80861092], [88.53861237, 21.80916977], [88.53888702, 21.80916786], [88.53944397, 21.8097229], [88.53971863, 21.80971909], [88.54000092, 21.81000137], [88.54055786, 21.81055832], [88.54083252, 21.81055832], [88.54342651, 21.81059074], [88.54457092, 21.8103199]]], [[[88.42180634, 21.81109047], [88.42236328, 21.81107903], [88.42290497, 21.81108284], [88.42346954, 21.81108284], [88.42407227, 21.81103134], [88.42463684, 21.81084251], [88.42513275, 21.81048393], [88.42553711, 21.80997849], [88.4258728, 21.80940056], [88.42610168, 21.80878067], [88.42626953, 21.80817795], [88.42642212, 21.807621], [88.42658234, 21.80709076], [88.426651, 21.80653954], [88.42666626, 21.80598259], [88.42669678, 21.80542183], [88.42681122, 21.80485535], [88.42692566, 21.80427361], [88.42701721, 21.80368805], [88.4272995, 21.8031311], [88.42749786, 21.80249214], [88.42769623, 21.80185509], [88.42796326, 21.80125046], [88.42835999, 21.80078506], [88.42875671, 21.80031013], [88.42917633, 21.79990005], [88.42963409, 21.79958725], [88.43012238, 21.79937172], [88.4305954, 21.7991581], [88.43107605, 21.79897118], [88.43158722, 21.79883957], [88.43209839, 21.79870987], [88.43261719, 21.79864311], [88.43312073, 21.7986927], [88.43360901, 21.79883957], [88.4340744, 21.79888344], [88.43453979, 21.79889488], [88.43501282, 21.79891968], [88.43549347, 21.7990799], [88.43604279, 21.79920959], [88.43660736, 21.79937553], [88.43717194, 21.79953003], [88.43772125, 21.7997303], [88.43823242, 21.79993248], [88.43881989, 21.80004883], [88.4393692, 21.80021286], [88.43995667, 21.80032921], [88.44055939, 21.80051994], [88.44113922, 21.8005619], [88.4413147, 21.80055428], [88.44167328, 21.80054474], [88.44210815, 21.80043221], [88.44239807, 21.80013084], [88.44267273, 21.79988098], [88.44268799, 21.79965019], [88.4425354, 21.79940033], [88.44247437, 21.79905891], [88.44238281, 21.79870033], [88.44223022, 21.79834938], [88.44198608, 21.79800034], [88.4417572, 21.79759026], [88.44156647, 21.79712105], [88.4413681, 21.79661179], [88.44111633, 21.79611969], [88.44088745, 21.79556847], [88.4407959, 21.79497147], [88.44059753, 21.79445839], [88.44055939, 21.7939682], [88.4405365, 21.79355812], [88.44042969, 21.79320908], [88.44029999, 21.79282951], [88.44026947, 21.7923317], [88.44022369, 21.79174423], [88.44011688, 21.79111671], [88.44002533, 21.79046249], [88.44000244, 21.78980446], [88.43994141, 21.78918076], [88.43972015, 21.78860283], [88.43945313, 21.7880497], [88.43919373, 21.78754807], [88.43889618, 21.78720093], [88.43869019, 21.78686905], [88.438591, 21.7865181], [88.43843079, 21.78619194], [88.43830109, 21.78577995], [88.43810272, 21.78537941], [88.43795013, 21.78487968], [88.43772125, 21.78443718], [88.43749237, 21.7840004], [88.43723297, 21.78362083], [88.43694305, 21.78325081], [88.43666077, 21.78289032], [88.43637848, 21.78254128], [88.43609619, 21.7822094], [88.43583679, 21.78187943], [88.43557739, 21.78154945], [88.43534851, 21.78120422], [88.43502045, 21.78094673], [88.4347229, 21.78067017], [88.43441772, 21.78041077], [88.43408966, 21.78018188], [88.43386078, 21.77980042], [88.43345642, 21.77962112], [88.4330368, 21.77943039], [88.43267059, 21.77918816], [88.43229675, 21.77897072], [88.43196869, 21.7787075], [88.43170166, 21.77837944], [88.43139648, 21.77809143], [88.43108368, 21.77779388], [88.43076324, 21.77750587], [88.43044281, 21.77722168], [88.43013763, 21.77694321], [88.42987061, 21.77666283], [88.42961884, 21.77639008], [88.42936707, 21.77613068], [88.42910767, 21.77590942], [88.42881012, 21.77573967], [88.42856598, 21.77552032], [88.42832184, 21.77526093], [88.4280014, 21.7749424], [88.42758179, 21.77453995], [88.42701721, 21.77412987], [88.42693329, 21.77406693], [88.42643738, 21.77368355], [88.42577362, 21.77333641], [88.4251709, 21.77301979], [88.42473602, 21.77264023], [88.42442322, 21.77228928], [88.4241333, 21.77197075], [88.42379761, 21.77169037], [88.42342377, 21.77145767], [88.42312622, 21.77114105], [88.42280579, 21.77086067], [88.42260742, 21.77050018], [88.42236328, 21.77012062], [88.42211914, 21.76974106], [88.42183685, 21.7694149], [88.42164612, 21.76906967], [88.42144775, 21.76877022], [88.42132568, 21.76844406], [88.42115784, 21.7681694], [88.4210968, 21.76783943], [88.42099762, 21.76753044], [88.42086029, 21.76723099], [88.42080688, 21.76684952], [88.42069244, 21.76643181], [88.42058563, 21.76594925], [88.42056274, 21.76540947], [88.42055511, 21.76502991], [88.42055511, 21.76484108], [88.42053986, 21.76431274], [88.42045593, 21.76385689], [88.42043304, 21.76344872], [88.42050171, 21.76305008], [88.42063904, 21.76262093], [88.42070007, 21.76210022], [88.42082977, 21.76167107], [88.42101288, 21.76129913], [88.42119598, 21.76097107], [88.42133331, 21.7606411], [88.42150116, 21.76037025], [88.4216156, 21.76005173], [88.42168427, 21.75972176], [88.42180634, 21.75943184], [88.42195892, 21.75917244], [88.42201233, 21.75869179], [88.42189789, 21.75859451], [88.42215729, 21.75826073], [88.42251587, 21.75799942], [88.42264557, 21.75764084], [88.42282104, 21.75728989], [88.42307281, 21.75696182], [88.42418671, 21.75498009], [88.42461395, 21.75390816], [88.42518616, 21.75337029], [88.4253006, 21.75271034], [88.42505646, 21.75201035], [88.4247818, 21.75147057], [88.4245224, 21.75104332], [88.4243927, 21.7505703], [88.42418671, 21.75014114], [88.42399597, 21.74999619], [88.42379761, 21.7498455], [88.42357635, 21.74938011], [88.42336273, 21.74894142], [88.42311859, 21.7485199], [88.42256165, 21.74779892], [88.42198181, 21.74712944], [88.42157745, 21.74637032], [88.42144012, 21.7457695], [88.4211731, 21.7454319], [88.42111969, 21.74500084], [88.42095947, 21.74446106], [88.42084503, 21.7440815], [88.4209671, 21.74273109], [88.42082977, 21.74151993], [88.42082214, 21.74044609], [88.42112732, 21.73975182], [88.42137146, 21.73921776], [88.42138672, 21.7387085], [88.4214859, 21.73824501], [88.42163849, 21.73780823], [88.42170715, 21.73731995], [88.42192078, 21.73688507], [88.42209625, 21.7364006], [88.42233276, 21.73590469], [88.42251587, 21.73543358], [88.42276001, 21.73503113], [88.42303467, 21.73471642], [88.42301178, 21.73433113], [88.42310333, 21.73423958], [88.42327118, 21.73406982], [88.42356873, 21.73361969], [88.42388916, 21.73324013], [88.42388916, 21.73286819], [88.42391968, 21.73250008], [88.42403412, 21.73218346], [88.42414093, 21.73192024], [88.42417908, 21.73161125], [88.42424774, 21.73132706], [88.42442322, 21.73108101], [88.42447662, 21.73075104], [88.42463684, 21.73046112], [88.42472839, 21.73011971], [88.42466736, 21.7296505], [88.42468262, 21.7293396], [88.42462158, 21.7290287], [88.42481232, 21.72887993], [88.42506409, 21.72855759], [88.42517853, 21.72632027], [88.42517853, 21.72443962], [88.42529297, 21.72346115], [88.42524719, 21.72296906], [88.42508698, 21.72257042], [88.42497253, 21.72216988], [88.42478943, 21.72183609], [88.42469788, 21.72147942], [88.42453766, 21.7211895], [88.42443085, 21.72089195], [88.42424774, 21.72064972], [88.42398834, 21.72050476], [88.42372131, 21.72031021], [88.42339325, 21.72014046], [88.42310333, 21.71986961], [88.42276001, 21.71982002], [88.42237854, 21.72020912], [88.42204285, 21.72072983], [88.42166138, 21.72116089], [88.42127991, 21.7215271], [88.42093658, 21.72191811], [88.42057037, 21.72228622], [88.42024994, 21.72270966], [88.41994476, 21.7231369], [88.41972351, 21.72353363], [88.41956329, 21.72371483], [88.41947174, 21.72381973], [88.41925049, 21.72405052], [88.41912842, 21.72437096], [88.41890717, 21.72470284], [88.41866302, 21.72504044], [88.41841125, 21.72541046], [88.41812134, 21.72578049], [88.4178009, 21.72610092], [88.41749573, 21.72638512], [88.41726685, 21.72665405], [88.41716766, 21.72698975], [88.41702271, 21.72730064], [88.41693115, 21.72762108], [88.4168396, 21.72792816], [88.41668701, 21.72820091], [88.41656494, 21.72847557], [88.41636658, 21.72871971], [88.41615295, 21.72899055], [88.4159317, 21.72932816], [88.4156189, 21.72965813], [88.4152832, 21.73006058], [88.41490936, 21.73047066], [88.41448212, 21.73085976], [88.41404724, 21.73125076], [88.41365051, 21.73167038], [88.41333008, 21.7321701], [88.41299438, 21.7326889], [88.4125824, 21.73315048], [88.41213989, 21.7335701], [88.41165924, 21.73396111], [88.41107941, 21.73439026], [88.4105072, 21.73480415], [88.40997314, 21.73525047], [88.4094162, 21.73563957], [88.40886688, 21.73594093], [88.40833282, 21.73615074], [88.40785217, 21.73631287], [88.40733337, 21.7364006], [88.40688324, 21.73649979], [88.40653992, 21.73669052], [88.40622711, 21.73693275], [88.40589905, 21.73715973], [88.40553284, 21.73733521], [88.40512848, 21.73747063], [88.40468597, 21.73759079], [88.40422821, 21.73774719], [88.40376282, 21.73798943], [88.4033432, 21.73835754], [88.40299225, 21.73876953], [88.402771, 21.73926926], [88.40255737, 21.73974037], [88.40239716, 21.74017715], [88.40220642, 21.74055672], [88.40200806, 21.74091148], [88.40184021, 21.74131203], [88.40163422, 21.74171257], [88.40140533, 21.74212074], [88.40119934, 21.74257088], [88.40106964, 21.74308968], [88.40088654, 21.74352074], [88.40085602, 21.74394035], [88.40100098, 21.74435806], [88.40114594, 21.74477005], [88.40132141, 21.74515724], [88.40145111, 21.74559021], [88.40161133, 21.74599457], [88.40174866, 21.74643135], [88.40194702, 21.7467308], [88.40216827, 21.74702072], [88.40232849, 21.74740982], [88.40254211, 21.74786949], [88.40270996, 21.74838829], [88.402771, 21.74894142], [88.40277863, 21.74950027], [88.40273285, 21.75002098], [88.40254211, 21.75049019], [88.40236664, 21.75096321], [88.40219116, 21.75144958], [88.40194702, 21.75193977], [88.40167236, 21.7524128], [88.40136719, 21.75286102], [88.40104675, 21.75325012], [88.4006958, 21.75358963], [88.40032959, 21.75388527], [88.39994049, 21.75415993], [88.3995285, 21.75442123], [88.39909363, 21.75463295], [88.39862061, 21.75481224], [88.39810181, 21.75500107], [88.39755249, 21.75522614], [88.39698792, 21.7555027], [88.3964386, 21.75585365], [88.39611053, 21.75634193], [88.39586639, 21.75687981], [88.39575195, 21.75745773], [88.39575195, 21.75805855], [88.39568329, 21.75859833], [88.39569092, 21.75922966], [88.39562225, 21.75991821], [88.39550018, 21.76042938], [88.39547729, 21.76099586], [88.39527893, 21.76156044], [88.39507294, 21.76181984], [88.3948822, 21.76260185], [88.39457703, 21.76289368], [88.39447784, 21.76318169], [88.3944397, 21.76338005], [88.39434052, 21.76370621], [88.39404297, 21.76395988], [88.39408112, 21.76443672], [88.39360046, 21.76506042], [88.39311218, 21.76539993], [88.39279938, 21.7656002], [88.39259338, 21.76618958], [88.39234924, 21.76637077], [88.39190674, 21.76665115], [88.39157867, 21.76702118], [88.39112854, 21.76726913], [88.39071655, 21.76761055], [88.39030457, 21.76800537], [88.38996124, 21.76849174], [88.38963318, 21.76898956], [88.3894043, 21.76944733], [88.38905334, 21.76971817], [88.38871002, 21.7700119], [88.38838196, 21.77031326], [88.38804626, 21.77066994], [88.38770294, 21.77107048], [88.38729095, 21.77146721], [88.38693237, 21.77193832], [88.38656616, 21.77241707], [88.38625336, 21.77289963], [88.38591003, 21.77333069], [88.38556671, 21.77371979], [88.38527679, 21.77409935], [88.38498688, 21.77444267], [88.38469696, 21.77474976], [88.38444519, 21.77506256], [88.38423157, 21.77537155], [88.3841095, 21.7757206], [88.38391876, 21.77601051], [88.38378906, 21.77629089], [88.38355255, 21.77647018], [88.38331604, 21.77667999], [88.38308716, 21.77690125], [88.38288116, 21.77721024], [88.38280487, 21.77775192], [88.38279724, 21.77782631], [88.38269806, 21.7784996], [88.38265991, 21.77910042], [88.38282013, 21.77959633], [88.38317871, 21.77994919], [88.38352966, 21.78027916], [88.38385773, 21.78062248], [88.38421631, 21.78100014], [88.38470459, 21.78136063], [88.38527679, 21.78166962], [88.38578796, 21.7820282], [88.38617706, 21.78246117], [88.38661194, 21.78277016], [88.38696289, 21.78310013], [88.38734436, 21.78338623], [88.38787079, 21.78352165], [88.38831329, 21.7836895], [88.38871765, 21.78391266], [88.38909149, 21.78418541], [88.38944244, 21.78453445], [88.38978577, 21.7849102], [88.39013672, 21.78523064], [88.39051056, 21.78549957], [88.39090729, 21.78573036], [88.39129639, 21.78603554], [88.39170837, 21.7864399], [88.39216614, 21.78689003], [88.39267731, 21.78737068], [88.39325714, 21.78775978], [88.39382172, 21.78808022], [88.39431, 21.78841972], [88.39479828, 21.78865051], [88.39523315, 21.78897095], [88.39562225, 21.7894001], [88.3960495, 21.78981972], [88.39646149, 21.79024124], [88.39689636, 21.79063416], [88.39728546, 21.79105377], [88.39769745, 21.79142952], [88.39807129, 21.79182816], [88.39845276, 21.79220009], [88.39881897, 21.79252815], [88.39914703, 21.79283714], [88.39942932, 21.79313087], [88.39966583, 21.79342079], [88.39987183, 21.79372025], [88.40022278, 21.79390907], [88.40055847, 21.79417038], [88.40088654, 21.79450035], [88.40125275, 21.79483032], [88.40174103, 21.79507828], [88.40222168, 21.79531288], [88.40262604, 21.79564095], [88.40309143, 21.79598618], [88.40361786, 21.79630089], [88.40414429, 21.7966671], [88.40458679, 21.7970829], [88.40500641, 21.79750252], [88.40544891, 21.79793167], [88.40592957, 21.79836655], [88.40644073, 21.79885101], [88.40696716, 21.79935074], [88.40747833, 21.79981804], [88.4079361, 21.80023003], [88.40837097, 21.80060959], [88.40876007, 21.80095863], [88.40917969, 21.80126953], [88.40962219, 21.80155945], [88.41008759, 21.80176926], [88.41038513, 21.80217361], [88.41073608, 21.80244064], [88.41123962, 21.80285072], [88.41181183, 21.80324936], [88.41246033, 21.80363083], [88.4128952, 21.80402565], [88.41337585, 21.80448341], [88.41388702, 21.80495834], [88.41442108, 21.80540276], [88.41487122, 21.80583], [88.41525269, 21.80624962], [88.41557312, 21.80668831], [88.41582489, 21.80705833], [88.41587067, 21.80713081], [88.41617584, 21.8075676], [88.41647339, 21.8080101], [88.41676331, 21.80844879], [88.41713715, 21.80882072], [88.41758728, 21.8091507], [88.41802216, 21.80943108], [88.418396, 21.80970573], [88.41872406, 21.8099823], [88.41902161, 21.81026077], [88.41934204, 21.81054115], [88.41969299, 21.81079292], [88.42011261, 21.81098557], [88.42063141, 21.8110981], [88.42121887, 21.81114006], [88.42150879, 21.81111526], [88.42180634, 21.81109047]]], [[[88.82807922, 21.80402946], [88.82757568, 21.80344772], [88.82704926, 21.80296135], [88.82701111, 21.80267906], [88.82668304, 21.80235291], [88.82639313, 21.80199432], [88.82611847, 21.80160713], [88.82585144, 21.80120087], [88.82563019, 21.80078506], [88.82550049, 21.80032921], [88.82528687, 21.79993248], [88.82508087, 21.79953575], [88.82482147, 21.79911995], [88.82461548, 21.79863548], [88.82460785, 21.79801369], [88.82420349, 21.79755783], [88.82382202, 21.7971096], [88.82356262, 21.79662895], [88.82331848, 21.79617119], [88.82305908, 21.79573059], [88.82285309, 21.79528046], [88.82276917, 21.79476738], [88.82269287, 21.79429054], [88.8225708, 21.79388428], [88.82202148, 21.7928791], [88.82180786, 21.79207039], [88.82144928, 21.79051971], [88.82130432, 21.7889061], [88.82073212, 21.78703117], [88.82090759, 21.7852211], [88.82108307, 21.78487015], [88.8212204, 21.78447151], [88.8214035, 21.7840538], [88.82163239, 21.78250885], [88.82155609, 21.78083038], [88.8221283, 21.77975082], [88.82292175, 21.77843857], [88.823349, 21.77773285], [88.82463837, 21.77517891], [88.82614136, 21.77276039], [88.82641602, 21.77114105], [88.82778931, 21.76979828], [88.82892609, 21.76865005], [88.83027649, 21.76722145], [88.83027649, 21.76666451], [88.83000183, 21.76667023], [88.82949829, 21.76616287], [88.82887268, 21.76583099], [88.82827759, 21.76554871], [88.82769775, 21.76527023], [88.82714081, 21.76498032], [88.82662201, 21.76465988], [88.82614136, 21.76431084], [88.82567596, 21.76394272], [88.82518768, 21.76361084], [88.82470703, 21.76329041], [88.8243103, 21.76292038], [88.8239212, 21.76254082], [88.82353973, 21.76214981], [88.82315063, 21.76177025], [88.82274628, 21.76140976], [88.82232666, 21.76106071], [88.82196045, 21.76067924], [88.82158661, 21.76029968], [88.82121277, 21.7599411], [88.82102966, 21.75975227], [88.82086945, 21.75958633], [88.8205719, 21.75926018], [88.82029724, 21.7589798], [88.82003784, 21.7587204], [88.81980896, 21.75843048], [88.8195343, 21.75815773], [88.81921387, 21.75789261], [88.81891632, 21.75759125], [88.8186264, 21.75727081], [88.81833649, 21.7569294], [88.81809998, 21.7566185], [88.81783295, 21.75632095], [88.81755066, 21.75603104], [88.81726074, 21.75572968], [88.81697845, 21.7554245], [88.81668854, 21.75510025], [88.81639099, 21.75476837], [88.81607819, 21.75444984], [88.81574249, 21.75415039], [88.81537628, 21.75385284], [88.81500244, 21.75352287], [88.8145752, 21.75318146], [88.81412506, 21.75282478], [88.81363678, 21.75248909], [88.8131485, 21.75216103], [88.81269073, 21.75184059], [88.81227875, 21.75152016], [88.81189728, 21.75119972], [88.81150055, 21.75095177], [88.81108093, 21.7507515], [88.81073761, 21.75053787], [88.81038666, 21.75033951], [88.80998993, 21.75020981], [88.80960083, 21.75004959], [88.80944061, 21.75000954], [88.80916595, 21.75000954], [88.8088913, 21.74971962], [88.80833435, 21.74972153], [88.80805206, 21.74944305], [88.80750275, 21.74945068], [88.80722046, 21.7491703], [88.80665588, 21.7491703], [88.80639648, 21.74888992], [88.80555725, 21.74888992], [88.80526733, 21.74860954], [88.80472565, 21.74861145], [88.80444336, 21.74833107], [88.80222321, 21.74833107], [88.80194092, 21.74861145], [88.80110931, 21.74860954], [88.80082703, 21.74888992], [88.80055237, 21.74888992], [88.80055237, 21.7491703], [88.80027008, 21.74945068], [88.79972076, 21.74945068], [88.79944611, 21.7491703], [88.79915619, 21.7491703], [88.79891205, 21.74867249], [88.79888916, 21.74833107], [88.79694366, 21.74833107], [88.79666901, 21.74861145], [88.79499817, 21.74860954], [88.79471588, 21.74888992], [88.79416656, 21.74888992], [88.79389191, 21.7491703], [88.79332733, 21.7491703], [88.79305267, 21.74945068], [88.79194641, 21.74944305], [88.79166412, 21.74972153], [88.79139709, 21.74971962], [88.79110718, 21.75000954], [88.79083252, 21.75000954], [88.79053497, 21.75034714], [88.79030609, 21.75068283], [88.79009247, 21.75107384], [88.78983307, 21.75141907], [88.78954315, 21.7517395], [88.78932953, 21.75206947], [88.78917694, 21.75244522], [88.78907013, 21.75286102], [88.78888702, 21.75327873], [88.78868103, 21.75366974], [88.78853607, 21.7541008], [88.78832245, 21.75444984], [88.78806305, 21.75477982], [88.78778839, 21.75515938], [88.78756714, 21.75559616], [88.78736877, 21.75607109], [88.787117, 21.75649071], [88.78690338, 21.75690269], [88.78665924, 21.75727081], [88.78642273, 21.75760078], [88.78620911, 21.75797081], [88.78604126, 21.75839806], [88.78582764, 21.75884247], [88.78555298, 21.75929451], [88.78525543, 21.75974464], [88.78499603, 21.76021194], [88.78473663, 21.76063919], [88.78451538, 21.76104355], [88.78436279, 21.76147079], [88.78420258, 21.76189423], [88.78407288, 21.76234436], [88.78401947, 21.76284027], [88.78395081, 21.76335716], [88.7838974, 21.76390076], [88.78387451, 21.76447105], [88.78385925, 21.76502037], [88.7838974, 21.7655201], [88.78408051, 21.7659111], [88.78418732, 21.76629257], [88.78436279, 21.7666111], [88.78448486, 21.76696587], [88.78470612, 21.76729012], [88.78492737, 21.76769066], [88.78523254, 21.7680397], [88.78544617, 21.76849174], [88.78565216, 21.76896095], [88.78594208, 21.76934052], [88.78623962, 21.76972961], [88.78652954, 21.77012062], [88.78689575, 21.77039146], [88.78720856, 21.77071953], [88.78749847, 21.77111053], [88.78779602, 21.77152252], [88.78814697, 21.77191162], [88.7885437, 21.77227211], [88.78887939, 21.77268028], [88.78916931, 21.77312088], [88.78942108, 21.7735672], [88.78962708, 21.77401924], [88.78993225, 21.77439117], [88.79029083, 21.77469063], [88.79073334, 21.7748909], [88.7911377, 21.77511978], [88.79149628, 21.7754097], [88.79179382, 21.7757988], [88.79211426, 21.77615356], [88.79239655, 21.77654076], [88.79271698, 21.7768898], [88.79306793, 21.77725029], [88.79350281, 21.77763939], [88.79396057, 21.77810287], [88.79444122, 21.77859116], [88.79493713, 21.7790451], [88.79528046, 21.77955437], [88.795578, 21.78002167], [88.79585266, 21.78043938], [88.79611206, 21.78081894], [88.79638672, 21.78116989], [88.79663086, 21.78153038], [88.79679108, 21.78191948], [88.79692078, 21.78230095], [88.79696655, 21.78269958], [88.79708862, 21.78305054], [88.79722595, 21.78339386], [88.79735565, 21.78375435], [88.7974472, 21.78415489], [88.79748535, 21.78459358], [88.79750061, 21.7850399], [88.79754639, 21.78547668], [88.79759979, 21.7858696], [88.79759216, 21.78624916], [88.79751587, 21.78661728], [88.79749298, 21.78699112], [88.79743195, 21.78733063], [88.79727936, 21.78763008], [88.79722595, 21.78793907], [88.79718018, 21.78824043], [88.79708099, 21.78853035], [88.79696655, 21.78883743], [88.79693604, 21.78922081], [88.79693604, 21.7896595], [88.79693604, 21.79000092], [88.79722595, 21.79027939], [88.79722595, 21.79055405], [88.79888916, 21.79222107], [88.79888916, 21.79249954], [88.79944611, 21.7930603], [88.79946136, 21.79316711], [88.79979706, 21.79368019], [88.80011749, 21.7942028], [88.80043793, 21.7947197], [88.80072021, 21.79523087], [88.80097961, 21.79573822], [88.80134583, 21.79620171], [88.80169678, 21.79668236], [88.80208588, 21.79709053], [88.80245209, 21.79745674], [88.80277252, 21.79777908], [88.80306244, 21.79809952], [88.80335236, 21.79839706], [88.80368042, 21.79866982], [88.80401611, 21.79894829], [88.80430603, 21.79927254], [88.80462646, 21.79949951], [88.80488586, 21.79981041], [88.80500031, 21.80000114], [88.80512238, 21.80011749], [88.80610657, 21.80112076], [88.80610657, 21.80138969], [88.80750275, 21.80278015], [88.8077774, 21.80278015], [88.8088913, 21.80389023], [88.80916595, 21.80388832], [88.80944061, 21.80416107], [88.80944061, 21.80445099], [88.81111145, 21.80611038], [88.81111145, 21.80639076], [88.81138611, 21.80666542], [88.81138611, 21.8069458], [88.8116684, 21.80722046], [88.81207275, 21.80777931], [88.81241608, 21.80822945], [88.81273651, 21.8086319], [88.81304169, 21.809021], [88.81331635, 21.80941963], [88.81360626, 21.80981255], [88.81388855, 21.8101902], [88.81412506, 21.81053925], [88.81427002, 21.81090927], [88.81443787, 21.81123734], [88.81458282, 21.81153488], [88.81469727, 21.81184578], [88.81476593, 21.81216049], [88.81491089, 21.81244278], [88.81503296, 21.81273079], [88.81520081, 21.81301689], [88.81531525, 21.81335258], [88.81546783, 21.81365013], [88.81561279, 21.81397057], [88.81577301, 21.8142395], [88.81593323, 21.81451988], [88.81613922, 21.81476021], [88.81638336, 21.81501007], [88.81659698, 21.81527901], [88.81678772, 21.81555939], [88.81693268, 21.81586075], [88.81703186, 21.81616974], [88.81716156, 21.81642914], [88.81726074, 21.81674767], [88.81741333, 21.81703949], [88.81751251, 21.81735039], [88.81764221, 21.8176384], [88.81777954, 21.8179245], [88.8179245, 21.81820297], [88.81809235, 21.81848145], [88.81829071, 21.81875038], [88.81846619, 21.81908035], [88.81864166, 21.81946754], [88.81887054, 21.81986046], [88.8190918, 21.82028008], [88.81933594, 21.82070923], [88.81962585, 21.82114029], [88.81993866, 21.82159805], [88.82029724, 21.82207108], [88.82071686, 21.82245255], [88.82119751, 21.8227005], [88.82167053, 21.82290077], [88.82228088, 21.8225708], [88.82290649, 21.82240105], [88.82337189, 21.8221283], [88.82363129, 21.82167053], [88.82389069, 21.82120132], [88.82415771, 21.82076645], [88.82437134, 21.82031822], [88.82446289, 21.81978989], [88.82458496, 21.81931877], [88.82472229, 21.81887054], [88.82489014, 21.81847572], [88.82507324, 21.8180809], [88.82528687, 21.8176918], [88.82554626, 21.81731033], [88.82583618, 21.81690025], [88.82611084, 21.81645966], [88.82634735, 21.81596947], [88.82655334, 21.81542015], [88.82685089, 21.81495094], [88.82711029, 21.81449509], [88.82746124, 21.81415939], [88.82779694, 21.81386948], [88.82810211, 21.81357002], [88.82839203, 21.81324959], [88.82866669, 21.81287575], [88.82899475, 21.81254768], [88.82936096, 21.81228065], [88.82962799, 21.81195259], [88.8298645, 21.81164169], [88.83003235, 21.81131935], [88.83023834, 21.81102943], [88.83041382, 21.81072807], [88.83058929, 21.81034088], [88.83074188, 21.80993652], [88.8306427, 21.80943108], [88.83076477, 21.80892372], [88.83099365, 21.80838966], [88.83096313, 21.80779839], [88.83069611, 21.80724907], [88.8303833, 21.80677986], [88.83003998, 21.80641937], [88.82972717, 21.80608177], [88.82943726, 21.80569077], [88.82913971, 21.80524063], [88.82888031, 21.80470276], [88.82868958, 21.80455399], [88.82833099, 21.80427933], [88.82807922, 21.80402946]]], [[[88.27396393, 21.79079056], [88.27464294, 21.79063988], [88.27536774, 21.79074478], [88.27609253, 21.79060936], [88.27681732, 21.79055977], [88.2775116, 21.79055023], [88.27819061, 21.79051971], [88.27883148, 21.7904129], [88.27944183, 21.79025078], [88.279953, 21.79006386], [88.2804718, 21.78992462], [88.28096771, 21.78974152], [88.2815094, 21.78959846], [88.28208923, 21.78944016], [88.28269958, 21.7892704], [88.28334045, 21.78911972], [88.28392029, 21.7888298], [88.28443146, 21.78846169], [88.28491211, 21.78806114], [88.2853775, 21.78767014], [88.28580475, 21.78727722], [88.28617096, 21.78684807], [88.28645325, 21.78638077], [88.28668213, 21.78590584], [88.28691101, 21.78543282], [88.28712463, 21.78492928], [88.28739166, 21.78442955], [88.2873764, 21.78394127], [88.2875824, 21.78351021], [88.2877121, 21.78302002], [88.28781128, 21.78248978], [88.28800201, 21.78196144], [88.28804016, 21.78129959], [88.2879715, 21.78062248], [88.2877121, 21.78012466], [88.28742981, 21.77973175], [88.28729248, 21.77948952], [88.28720093, 21.77932549], [88.28694153, 21.77893257], [88.28668976, 21.7785511], [88.28647614, 21.77815056], [88.28623199, 21.7777729], [88.28601074, 21.77738571], [88.28579712, 21.77693176], [88.28555298, 21.77651978], [88.28533173, 21.77614212], [88.28520966, 21.77578926], [88.28501129, 21.77561951], [88.28472137, 21.77527809], [88.28472137, 21.77472115], [88.28444672, 21.77444458], [88.28444672, 21.77305603], [88.2841568, 21.77277946], [88.2841568, 21.77166939], [88.28388977, 21.77139091], [88.28388977, 21.77082825], [88.28360748, 21.7705555], [88.28360748, 21.77000046], [88.28333282, 21.76971817], [88.28333282, 21.76944351], [88.28305817, 21.76944351], [88.28277588, 21.76972198], [88.28250122, 21.76971817], [88.28250122, 21.77000046], [88.28221893, 21.77028084], [88.28193665, 21.77028084], [88.28083038, 21.77139091], [88.28028107, 21.77139091], [88.27999878, 21.77166939], [88.27971649, 21.77166939], [88.27889252, 21.77249908], [88.27861023, 21.77249908], [88.2783432, 21.77277946], [88.27805328, 21.77277756], [88.27749634, 21.7733326], [88.27722168, 21.7733326], [88.27694702, 21.77361107], [88.27666473, 21.77361107], [88.27645111, 21.77388954], [88.27607727, 21.77416611], [88.27580261, 21.77437019], [88.27567291, 21.77447128], [88.27523804, 21.77478027], [88.27482605, 21.77515984], [88.27443695, 21.77551079], [88.27406311, 21.77582932], [88.27371216, 21.77613068], [88.27339172, 21.77645111], [88.27311707, 21.77680016], [88.27294922, 21.77717018], [88.27275848, 21.77748871], [88.27255249, 21.77775192], [88.27236938, 21.77804184], [88.27215576, 21.77833748], [88.27189636, 21.77869415], [88.27163696, 21.77915955], [88.2713089, 21.77963066], [88.27094269, 21.78005028], [88.27063751, 21.78046608], [88.2703476, 21.78083229], [88.27007294, 21.78117943], [88.26980591, 21.78156281], [88.26950073, 21.78193092], [88.26912689, 21.78229713], [88.26900482, 21.78246117], [88.26876831, 21.78277016], [88.26835632, 21.7833004], [88.26793671, 21.78386116], [88.26747894, 21.78442001], [88.26702118, 21.78495979], [88.26669312, 21.78553963], [88.26638794, 21.78606987], [88.26611328, 21.78655243], [88.26583099, 21.78700066], [88.26555634, 21.78744125], [88.26528168, 21.78786469], [88.26500702, 21.78829002], [88.26477051, 21.78874016], [88.2645874, 21.78917694], [88.26442719, 21.78960037], [88.26431274, 21.79001045], [88.26418304, 21.79038048], [88.26407623, 21.79072762], [88.26394653, 21.79102707], [88.26387024, 21.7913475], [88.26374054, 21.79167938], [88.2636261, 21.79201126], [88.2636261, 21.79236031], [88.26373291, 21.79267693], [88.26390076, 21.79275131], [88.2640686, 21.79282379], [88.26420593, 21.7927742], [88.26469421, 21.79261017], [88.26534271, 21.7924614], [88.26591492, 21.79229355], [88.26647949, 21.79221344], [88.26700592, 21.79214287], [88.26746368, 21.79199791], [88.26795197, 21.7918911], [88.2684021, 21.79169846], [88.26886749, 21.79154968], [88.26933289, 21.79142952], [88.2698288, 21.79138947], [88.27030945, 21.79136086], [88.27077484, 21.79126549], [88.27128601, 21.79114914], [88.27180481, 21.79111671], [88.27231598, 21.79108429], [88.27280426, 21.79096222], [88.27333832, 21.79085159], [88.27396393, 21.79079056]]], [[[88.50527954, 21.7829895], [88.50389099, 21.78138924], [88.50377655, 21.78139114], [88.50365448, 21.78130341], [88.5034256, 21.78114891], [88.50296783, 21.78100967], [88.50250244, 21.7808342], [88.50195313, 21.78083038], [88.50166321, 21.78111076], [88.50166321, 21.78139114], [88.50138855, 21.78139114], [88.50111389, 21.78166771], [88.50101471, 21.78183174], [88.50119019, 21.78219032], [88.50135803, 21.78256989], [88.50141907, 21.78296089], [88.50157928, 21.78326035], [88.5016861, 21.78357124], [88.50186157, 21.7838192], [88.50195313, 21.78412628], [88.50205994, 21.78442001], [88.5022583, 21.78470039], [88.50250244, 21.78499031], [88.5027771, 21.78532982], [88.50308228, 21.78570747], [88.50345612, 21.78607941], [88.50392914, 21.78643036], [88.50440979, 21.78679848], [88.50486755, 21.78723145], [88.50546265, 21.78741074], [88.50583649, 21.78778648], [88.50611115, 21.78833389], [88.5063858, 21.78833389], [88.50693512, 21.78750038], [88.50639343, 21.7857666], [88.5061264, 21.78524971], [88.50611115, 21.78471756], [88.50583649, 21.78444481], [88.50569153, 21.78388977], [88.50527954, 21.7829895]]], [[[88.30583191, 21.75158119], [88.30583954, 21.75222015], [88.30583191, 21.75283051], [88.30576324, 21.75337982], [88.30544281, 21.75382042], [88.30525208, 21.75435066], [88.30503845, 21.75485992], [88.30495453, 21.75540543], [88.30474854, 21.75592041], [88.30455017, 21.75650978], [88.30445862, 21.75720978], [88.30436707, 21.75791931], [88.30410004, 21.75851631], [88.30371857, 21.7589798], [88.30382538, 21.75931549], [88.30387115, 21.75962067], [88.30381012, 21.75991058], [88.30366516, 21.76017952], [88.30361938, 21.7604866], [88.30358887, 21.76080322], [88.30345154, 21.76110077], [88.30328369, 21.7614193], [88.30308533, 21.76180458], [88.30303192, 21.76230049], [88.3028717, 21.7627697], [88.30269623, 21.76319122], [88.30251312, 21.7635479], [88.30237579, 21.7638607], [88.30222321, 21.7641201], [88.30205536, 21.76434708], [88.30193329, 21.76463127], [88.30177307, 21.76490974], [88.30166626, 21.76525116], [88.30155945, 21.76562119], [88.30141449, 21.76597977], [88.30126953, 21.76638031], [88.3010788, 21.76679993], [88.30082703, 21.76721001], [88.30053711, 21.76764107], [88.30027771, 21.76811028], [88.3000412, 21.76861954], [88.29995728, 21.76919174], [88.29973602, 21.76972961], [88.29959106, 21.77025986], [88.29946136, 21.77075577], [88.2993927, 21.77124023], [88.29920197, 21.77166939], [88.2991333, 21.77215958], [88.29892731, 21.77263069], [88.29888916, 21.77312088], [88.29888916, 21.77360153], [88.29888916, 21.77401924], [88.29885101, 21.77443504], [88.2986908, 21.77482033], [88.29859161, 21.77531815], [88.29849243, 21.77585983], [88.29850006, 21.77637672], [88.29837036, 21.77674103], [88.29833984, 21.77715111], [88.29850006, 21.7777195], [88.29860687, 21.77823067], [88.29864502, 21.77869606], [88.29865265, 21.77915955], [88.29865265, 21.77963448], [88.29866028, 21.7798996], [88.29866028, 21.78010941], [88.29872131, 21.78055954], [88.29886627, 21.78092575], [88.29901123, 21.78127289], [88.29920959, 21.78157234], [88.29946136, 21.78185081], [88.29980469, 21.78211784], [88.3003006, 21.78235817], [88.30084991, 21.78260612], [88.30136108, 21.78279305], [88.30181885, 21.78290176], [88.30226135, 21.78292847], [88.30271149, 21.78297043], [88.30303192, 21.7829361], [88.30316162, 21.78292465], [88.30358887, 21.78282928], [88.30393982, 21.78264046], [88.30426788, 21.78250122], [88.30474091, 21.78252983], [88.30526733, 21.78264046], [88.30573273, 21.78269196], [88.30615997, 21.78264236], [88.30657196, 21.78251266], [88.30698395, 21.78240585], [88.30741119, 21.78243065], [88.30782318, 21.78246117], [88.30821228, 21.78245163], [88.30857849, 21.78240585], [88.30893707, 21.78232193], [88.30931091, 21.78223038], [88.30970001, 21.78222084], [88.31011963, 21.78230095], [88.31060028, 21.78239059], [88.3105545, 21.78249931], [88.31111145, 21.78305626], [88.31111145, 21.78360748], [88.31138611, 21.78388977], [88.31138611, 21.78444481], [88.3114624, 21.78478813], [88.31144714, 21.78523064], [88.31130981, 21.7855835], [88.31110382, 21.78587341], [88.31088257, 21.78614044], [88.31066132, 21.78643036], [88.31041718, 21.78674126], [88.31021881, 21.7870903], [88.31005096, 21.78745079], [88.30996704, 21.78784943], [88.30995178, 21.78829002], [88.3099823, 21.78877068], [88.31006622, 21.7892704], [88.31024933, 21.78976059], [88.31043243, 21.79024124], [88.3106308, 21.79067039], [88.31083679, 21.79104996], [88.31104279, 21.79141808], [88.31118774, 21.79186058], [88.31129456, 21.7924099], [88.3113327, 21.79302979], [88.31128693, 21.79368019], [88.31121826, 21.79437637], [88.31108856, 21.79504013], [88.31085968, 21.79563522], [88.31048584, 21.79614067], [88.31004333, 21.79656029], [88.30960083, 21.79690361], [88.30912781, 21.79721832], [88.30863953, 21.79749107], [88.30806732, 21.79775047], [88.30744934, 21.79799652], [88.30683136, 21.79821968], [88.30622101, 21.79842949], [88.30562592, 21.79861069], [88.30506897, 21.79879951], [88.30450439, 21.79897308], [88.30394745, 21.79912376], [88.30341339, 21.79926109], [88.30285645, 21.79937553], [88.30232239, 21.79948044], [88.30181122, 21.79961014], [88.30129242, 21.79969978], [88.30076599, 21.79978943], [88.30024719, 21.79990959], [88.29972076, 21.80002785], [88.29918671, 21.80018044], [88.29866028, 21.80032921], [88.29814148, 21.80051613], [88.29775238, 21.80067444], [88.29763031, 21.80072594], [88.29709625, 21.80095863], [88.29656219, 21.80129051], [88.29638672, 21.80138969], [88.29555511, 21.8022213], [88.29556274, 21.80249977], [88.29499817, 21.80249977], [88.29444122, 21.80305481], [88.29416656, 21.80277824], [88.29389191, 21.80278015], [88.29427338, 21.80237961], [88.29458618, 21.80195045], [88.2948761, 21.80157852], [88.29518127, 21.80122757], [88.29548645, 21.80088806], [88.2958374, 21.80057907], [88.29619598, 21.80029106], [88.29656982, 21.80002975], [88.29695892, 21.79981041], [88.29737854, 21.79964066], [88.29760742, 21.79953957], [88.29779053, 21.79945755], [88.29823303, 21.7992897], [88.29839325, 21.79925156], [88.29876709, 21.79916954], [88.29936218, 21.79905128], [88.30000305, 21.79887009], [88.30065918, 21.79867744], [88.3013382, 21.79848289], [88.30204773, 21.79832077], [88.30275726, 21.79816055], [88.30348206, 21.7980423], [88.30417633, 21.79792023], [88.3048172, 21.7977562], [88.30541229, 21.79759026], [88.30596161, 21.79739952], [88.30646515, 21.79717636], [88.30696869, 21.79691887], [88.30747986, 21.79663086], [88.3080368, 21.79630089], [88.3085556, 21.79595566], [88.3090744, 21.79556274], [88.30956268, 21.79512405], [88.30998993, 21.79462051], [88.31024933, 21.79404831], [88.31034851, 21.79348564], [88.31031036, 21.79295158], [88.31019592, 21.79245186], [88.31002045, 21.79200554], [88.30982971, 21.7915802], [88.30964661, 21.7911396], [88.30941772, 21.79071045], [88.30918884, 21.7902832], [88.30898285, 21.78985977], [88.30873871, 21.78946114], [88.30851746, 21.78906059], [88.3083725, 21.78862953], [88.3085022, 21.78816032], [88.30869293, 21.78765106], [88.30889893, 21.78713989], [88.30912781, 21.78663063], [88.30938721, 21.78614044], [88.30960846, 21.78567123], [88.30976868, 21.78523254], [88.30987549, 21.78478813], [88.30980682, 21.7843399], [88.30957031, 21.78397179], [88.30973053, 21.78388977], [88.30944824, 21.7836113], [88.30860901, 21.78360748], [88.30812836, 21.7838192], [88.30761719, 21.78397369], [88.30710602, 21.78412437], [88.30657196, 21.78428459], [88.30591583, 21.78440285], [88.30515289, 21.78444862], [88.30439758, 21.78442001], [88.30388641, 21.78443909], [88.30365753, 21.78444862], [88.30285645, 21.78443909], [88.30206299, 21.78442001], [88.30129242, 21.78436089], [88.30060577, 21.78426552], [88.30005646, 21.78407097], [88.29962158, 21.78386307], [88.29924774, 21.78362083], [88.29897308, 21.78331947], [88.29868317, 21.78300095], [88.29840088, 21.78264809], [88.29810333, 21.78226471], [88.29782867, 21.78181076], [88.2975769, 21.78129959], [88.29736328, 21.78076172], [88.29719543, 21.78021049], [88.29718781, 21.77967834], [88.29720306, 21.77929115], [88.29721069, 21.77917862], [88.29721832, 21.7786808], [88.29724121, 21.77814102], [88.29732513, 21.77754021], [88.29750061, 21.77685928], [88.29741669, 21.77630234], [88.29737854, 21.7756691], [88.29721069, 21.7751503], [88.29696655, 21.77474976], [88.29675293, 21.77444267], [88.29653931, 21.7741909], [88.2963028, 21.77404976], [88.29601288, 21.77404976], [88.29569244, 21.77417946], [88.29534149, 21.77436066], [88.29496002, 21.77452278], [88.2946167, 21.77482986], [88.29431152, 21.7752285], [88.2939682, 21.77561378], [88.29363251, 21.77601433], [88.29330444, 21.77644348], [88.29302979, 21.77691269], [88.29280853, 21.77723885], [88.29272461, 21.77735901], [88.29236603, 21.77775955], [88.29202271, 21.77815056], [88.29170227, 21.77858353], [88.29138947, 21.77905846], [88.29104614, 21.77956963], [88.29064941, 21.78005219], [88.29029846, 21.78052139], [88.29003906, 21.78097343], [88.28993225, 21.78141975], [88.28975677, 21.78183174], [88.28970337, 21.78229523], [88.28959656, 21.78275108], [88.28940582, 21.78318977], [88.28910828, 21.78357697], [88.28878021, 21.78395844], [88.28851318, 21.7844696], [88.28826141, 21.78501511], [88.2880249, 21.78574371], [88.28775787, 21.78645134], [88.2874527, 21.78708267], [88.28708649, 21.78763008], [88.28672028, 21.78813744], [88.28636932, 21.78862953], [88.28598022, 21.78906822], [88.28556061, 21.78940964], [88.28508759, 21.78964996], [88.28466797, 21.78985977], [88.28423309, 21.79003906], [88.28382874, 21.79026031], [88.28341675, 21.7904911], [88.28302765, 21.79073906], [88.2826004, 21.79100037], [88.28213501, 21.79125595], [88.28159332, 21.79141808], [88.28104401, 21.7916069], [88.28047943, 21.79167938], [88.27992249, 21.79177094], [88.27936554, 21.79189301], [88.27876282, 21.79193115], [88.27818298, 21.79200935], [88.27771759, 21.79219246], [88.27725983, 21.79234123], [88.27681732, 21.79246521], [88.27635193, 21.79249954], [88.27585602, 21.79255295], [88.275383, 21.79272652], [88.27480316, 21.79277039], [88.27414703, 21.79277992], [88.27346802, 21.79277992], [88.27278137, 21.7927742], [88.27209473, 21.79278374], [88.27141571, 21.79283333], [88.27075958, 21.79298973], [88.27012634, 21.79305077], [88.26954651, 21.7930603], [88.26901245, 21.79306984], [88.26850128, 21.79310989], [88.26802826, 21.79322052], [88.26754761, 21.79331017], [88.26704407, 21.79333687], [88.26654053, 21.79336166], [88.26605225, 21.79342842], [88.26560974, 21.79357147], [88.26512146, 21.79366493], [88.26468658, 21.79381943], [88.2641983, 21.79394913], [88.26387024, 21.79417419], [88.26360321, 21.79444122], [88.26329803, 21.7947197], [88.26296234, 21.79500961], [88.26259613, 21.79532051], [88.26226044, 21.79569054], [88.26197052, 21.79611969], [88.26166534, 21.7965641], [88.26145935, 21.79689598], [88.26139832, 21.79698944], [88.2611618, 21.79741096], [88.26101685, 21.79785156], [88.26087189, 21.7982502], [88.26082611, 21.79865074], [88.26083374, 21.79903793], [88.26082611, 21.79940414], [88.26077271, 21.79974556], [88.26059723, 21.80002975], [88.26049805, 21.80040932], [88.26032257, 21.80083275], [88.26022339, 21.80141068], [88.25998688, 21.80202293], [88.25977325, 21.80270195], [88.25972748, 21.80345154], [88.25977325, 21.80420685], [88.2599411, 21.8049736], [88.26000214, 21.80574036], [88.2600708, 21.8065052], [88.26029968, 21.80719948], [88.26064301, 21.80784988], [88.26104736, 21.80844116], [88.26139069, 21.80903053], [88.26171112, 21.80958748], [88.26204681, 21.81008911], [88.26241302, 21.81057167], [88.26279449, 21.81106949], [88.26329803, 21.81147957], [88.2638092, 21.81193924], [88.26434326, 21.81241417], [88.26493073, 21.81282043], [88.26541901, 21.81330109], [88.2658844, 21.81374931], [88.26637268, 21.8141098], [88.26687622, 21.81439972], [88.26734161, 21.81469917], [88.26779938, 21.81500053], [88.26823425, 21.81529808], [88.26864624, 21.81561089], [88.26911163, 21.81585121], [88.2695694, 21.81607819], [88.2700882, 21.81621552], [88.27057648, 21.8164196], [88.27108765, 21.81666946], [88.27157593, 21.81694031], [88.27205658, 21.81721306], [88.27251434, 21.81749153], [88.27294922, 21.81777954], [88.27337646, 21.81808662], [88.27381897, 21.81837082], [88.27424622, 21.81867027], [88.27468872, 21.81887054], [88.27513885, 21.81903076], [88.27559662, 21.8191452], [88.27606964, 21.81921005], [88.27645874, 21.81940842], [88.27687073, 21.81953049], [88.27723694, 21.81973076], [88.27761841, 21.81996155], [88.27807617, 21.82016945], [88.27861786, 21.82037926], [88.27916718, 21.82063866], [88.27973938, 21.82094383], [88.28032684, 21.82122993], [88.28098297, 21.82142639], [88.28157806, 21.82163048], [88.28214264, 21.82176018], [88.28263092, 21.82193947], [88.28309631, 21.82211876], [88.28359222, 21.82228279], [88.28409576, 21.82250214], [88.28460693, 21.82272148], [88.28518677, 21.82277489], [88.2856369, 21.82279396], [88.28575134, 21.82279968], [88.28629303, 21.82294273], [88.28686523, 21.82303619], [88.28746033, 21.8230896], [88.28800964, 21.82329941], [88.28859711, 21.82343292], [88.28917694, 21.82360077], [88.28975677, 21.8237381], [88.29029846, 21.82380104], [88.29081726, 21.82368851], [88.29129791, 21.82367516], [88.29176331, 21.82381821], [88.29228973, 21.82389069], [88.29283905, 21.82395554], [88.29337311, 21.82411957], [88.29392242, 21.82415962], [88.29447174, 21.82416916], [88.29504395, 21.82420158], [88.29560852, 21.82433319], [88.29621887, 21.82447052], [88.29682159, 21.82471085], [88.29743195, 21.82492828], [88.2980423, 21.82510948], [88.2986145, 21.82530594], [88.2991333, 21.82555389], [88.29964447, 21.82580376], [88.30020905, 21.82600212], [88.30082703, 21.82616425], [88.30140686, 21.82638931], [88.30198669, 21.82665825], [88.30255127, 21.82692909], [88.3030777, 21.82721138], [88.30357361, 21.8274765], [88.30403137, 21.82773018], [88.30446625, 21.82798958], [88.30490875, 21.82825089], [88.30532074, 21.82852936], [88.30574799, 21.82880592], [88.30612183, 21.8290596], [88.30661011, 21.82938957], [88.30702209, 21.82969093], [88.30739594, 21.82999039], [88.30773163, 21.83030128], [88.30799866, 21.83061981], [88.3082428, 21.8309803], [88.30854797, 21.83134842], [88.30887604, 21.83184052], [88.30922699, 21.83236122], [88.3095932, 21.83288193], [88.30992889, 21.83331108], [88.31014252, 21.8337326], [88.31033325, 21.83411026], [88.31053925, 21.83447075], [88.31070709, 21.83488083], [88.31089783, 21.83535767], [88.31113434, 21.8358326], [88.31138611, 21.8362999], [88.3116684, 21.83677673], [88.31194305, 21.83727074], [88.31221008, 21.83782005], [88.31247711, 21.83839989], [88.31277466, 21.83899879], [88.31305695, 21.83959007], [88.3133316, 21.84015465], [88.31356812, 21.84069252], [88.31375122, 21.8412323], [88.31394958, 21.84172058], [88.31417084, 21.84214592], [88.31439972, 21.84254074], [88.31459808, 21.84295082], [88.31478119, 21.84339142], [88.31498718, 21.84381294], [88.31517792, 21.84424591], [88.31535339, 21.84465981], [88.31532288, 21.84505272], [88.31526947, 21.84543991], [88.31523132, 21.8458004], [88.31519318, 21.84613609], [88.31519318, 21.84649086], [88.31523895, 21.84691048], [88.31524658, 21.84736633], [88.31517792, 21.84782982], [88.3150177, 21.84826851], [88.31487274, 21.84870529], [88.31468964, 21.84909439], [88.31447601, 21.84943962], [88.31432343, 21.84981728], [88.31414032, 21.85017395], [88.31389618, 21.8505249], [88.31360626, 21.85087967], [88.31332397, 21.85129547], [88.31304169, 21.8517704], [88.31275177, 21.85228729], [88.31242371, 21.85279465], [88.3119812, 21.85323715], [88.31154633, 21.85363007], [88.31166077, 21.85393715], [88.31194305, 21.85427094], [88.31227112, 21.85466003], [88.31264496, 21.85507584], [88.31272125, 21.85518456], [88.31298065, 21.8555603], [88.31333923, 21.8560791], [88.31376648, 21.85653114], [88.3142395, 21.85691833], [88.31468964, 21.85725975], [88.3151474, 21.85759735], [88.31567383, 21.85786438], [88.31627655, 21.85806656], [88.31684875, 21.85828018], [88.31742859, 21.85850906], [88.31797028, 21.85877991], [88.31851959, 21.85902023], [88.31909943, 21.85920143], [88.31965637, 21.85938072], [88.32021332, 21.85951042], [88.32068634, 21.85967064], [88.32116699, 21.85979462], [88.32161713, 21.85993004], [88.322052, 21.86005974], [88.32254791, 21.86018181], [88.32309723, 21.86029816], [88.3236618, 21.86044693], [88.32428741, 21.86050987], [88.32495117, 21.86057663], [88.32565308, 21.8606739], [88.3261795, 21.86068153], [88.32640076, 21.86069107], [88.32718658, 21.86068344], [88.32797241, 21.86069679], [88.32875061, 21.86070824], [88.32952881, 21.86072159], [88.33032227, 21.86070824], [88.33113098, 21.86068726], [88.33193207, 21.86063957], [88.33264923, 21.86050034], [88.33338165, 21.86046982], [88.33409882, 21.86045265], [88.33481598, 21.8604393], [88.33551025, 21.86046982], [88.33616638, 21.86045265], [88.33677673, 21.86032295], [88.33732605, 21.8602066], [88.33779907, 21.86001968], [88.33831024, 21.85980988], [88.33879089, 21.85954094], [88.33925629, 21.85915947], [88.33973694, 21.85874939], [88.34024048, 21.85837173], [88.34076691, 21.85803032], [88.34127808, 21.85767746], [88.34175873, 21.8572998], [88.3422699, 21.85695076], [88.34279633, 21.85664177], [88.34328461, 21.85632324], [88.34372711, 21.8560009], [88.3441925, 21.85572052], [88.3446579, 21.85548973], [88.34510803, 21.85526657], [88.3454895, 21.85506248], [88.34593201, 21.85499954], [88.34635162, 21.85496521], [88.34674072, 21.85481071], [88.34716034, 21.85473251], [88.34760284, 21.85472107], [88.34806061, 21.85472107], [88.34851074, 21.85472107], [88.34895325, 21.85472107], [88.34938049, 21.85472107], [88.34979248, 21.85473061], [88.3502121, 21.85481071], [88.35063171, 21.85501099], [88.35109711, 21.85518837], [88.35163116, 21.85504913], [88.35212708, 21.85486984], [88.35248566, 21.8545742], [88.35272217, 21.85424232], [88.35277557, 21.85383797], [88.35275269, 21.85341263], [88.3526001, 21.85299683], [88.35250092, 21.85251999], [88.35238647, 21.85198021], [88.35221863, 21.85145378], [88.35204315, 21.85091019], [88.35195923, 21.85033607], [88.35189819, 21.84976006], [88.3516922, 21.84926987], [88.35154724, 21.84879112], [88.35141754, 21.84836006], [88.3514328, 21.84795189], [88.35158539, 21.84754944], [88.35165405, 21.84708977], [88.35170746, 21.84659958], [88.35188293, 21.84613991], [88.35198212, 21.84565926], [88.35218048, 21.84523964], [88.35225677, 21.84476089], [88.35246277, 21.84431076], [88.35250092, 21.84379959], [88.35248566, 21.84325981], [88.35244751, 21.84270287], [88.35249329, 21.84213066], [88.35250092, 21.8415432], [88.35250092, 21.84094048], [88.35250092, 21.84033585], [88.35250092, 21.83973122], [88.35246277, 21.83914948], [88.3522644, 21.83864975], [88.35205841, 21.83815002], [88.35189056, 21.83761024], [88.35164642, 21.83710289], [88.35144806, 21.83660126], [88.3514328, 21.83604813], [88.35138702, 21.83549118], [88.35128021, 21.83492088], [88.35108185, 21.83435249], [88.35100555, 21.83369637], [88.35085297, 21.83311081], [88.35061646, 21.83260155], [88.35054016, 21.83202171], [88.35044098, 21.83141708], [88.35029602, 21.83078957], [88.35031891, 21.83011055], [88.35054779, 21.82944107], [88.35074615, 21.82876968], [88.35077667, 21.82812119], [88.35059357, 21.82751465], [88.35046387, 21.82695007], [88.35037231, 21.82640076], [88.35050201, 21.82588005], [88.35061646, 21.82537079], [88.35070801, 21.8248024], [88.35107422, 21.82425117], [88.35107422, 21.82366943], [88.35112762, 21.82305717], [88.35128021, 21.82246971], [88.35141754, 21.82190514], [88.35163116, 21.82140923], [88.35176086, 21.82088089], [88.35195923, 21.8204155], [88.35221863, 21.81998062], [88.35250092, 21.81954384], [88.35279846, 21.81908226], [88.35316467, 21.81863022], [88.35353851, 21.8181591], [88.35387421, 21.81759644], [88.35415649, 21.81699181], [88.35459137, 21.81650734], [88.35500336, 21.8160305], [88.35544586, 21.8155899], [88.35593414, 21.81520844], [88.35629272, 21.81472969], [88.3565979, 21.81425095], [88.35688782, 21.81382942], [88.3571167, 21.81343079], [88.35732269, 21.8130703], [88.35751343, 21.81274033], [88.35772705, 21.81242943], [88.35795593, 21.81204987], [88.35824585, 21.81163979], [88.35855865, 21.8111496], [88.35887909, 21.81064034], [88.35916901, 21.81009293], [88.35943604, 21.80955124], [88.35971069, 21.80906105], [88.35988617, 21.8085804], [88.36001587, 21.80811119], [88.3602066, 21.8076725], [88.3603363, 21.80718231], [88.36055756, 21.80670166], [88.36073303, 21.80616951], [88.36060333, 21.80554962], [88.36049652, 21.80494118], [88.36029053, 21.80445099], [88.36010742, 21.8039875], [88.3599472, 21.80357361], [88.35974884, 21.80318642], [88.35964966, 21.80273056], [88.35948181, 21.80227089], [88.35946655, 21.80175018], [88.3599472, 21.79898071], [88.36081696, 21.79683113], [88.36138916, 21.79602051], [88.36293793, 21.79483223], [88.3645401, 21.79400826], [88.3659668, 21.79360008], [88.367836, 21.79333687], [88.36898804, 21.79347038], [88.36940765, 21.79347992], [88.3698349, 21.79339409], [88.37021637, 21.7933197], [88.37206268, 21.79245758], [88.37290955, 21.79206276], [88.37309265, 21.79197693], [88.37361145, 21.79185486], [88.37480927, 21.79157448], [88.37507629, 21.7914238], [88.37767792, 21.78996086], [88.37967682, 21.78848076], [88.37996674, 21.78726959], [88.37953949, 21.78619194], [88.37944794, 21.78499985], [88.37917328, 21.78471756], [88.37916565, 21.78416634], [88.37888336, 21.78388977], [88.37888336, 21.78333092], [88.37802887, 21.7793045], [88.37787628, 21.7770195], [88.3781662, 21.77486992], [88.37793732, 21.77355957], [88.37789154, 21.77306366], [88.3780365, 21.77277756], [88.3779068, 21.77249908], [88.3780365, 21.77222061], [88.3777771, 21.77166748], [88.37776184, 21.77111053], [88.37776184, 21.77082825], [88.37805176, 21.7705555], [88.37805176, 21.76971817], [88.37804413, 21.76944351], [88.3779068, 21.76860237], [88.37749481, 21.76818085], [88.37722015, 21.7677803], [88.37695313, 21.76749992], [88.37633514, 21.76725006], [88.37584686, 21.76707649], [88.37541199, 21.76692009], [88.37497711, 21.76671028], [88.37445068, 21.76663971], [88.37386322, 21.76656151], [88.37325287, 21.76666069], [88.37259674, 21.7667408], [88.37194061, 21.76678276], [88.37123871, 21.76666451], [88.37114716, 21.76665115], [88.37042236, 21.7666111], [88.36992645, 21.76679039], [88.36956024, 21.76691628], [88.36920166, 21.76694107], [88.3687973, 21.76695061], [88.36858368, 21.76694679], [88.36837006, 21.76694107], [88.36793518, 21.76694679], [88.36763, 21.76694679], [88.36750793, 21.76694679], [88.36493683, 21.76694679], [88.36450195, 21.76694679], [88.36406708, 21.76694107], [88.36367035, 21.76695061], [88.36332703, 21.76694107], [88.36305237, 21.76694679], [88.36277771, 21.76666451], [88.36250305, 21.76694679], [88.36138916, 21.76694679], [88.36134338, 21.76717567], [88.3611145, 21.7669487], [88.35916901, 21.76694679], [88.35888672, 21.76666451], [88.35749817, 21.76666451], [88.35722351, 21.76694679], [88.35706329, 21.76694679], [88.35691071, 21.76685524], [88.35668945, 21.76672554], [88.35626984, 21.76663971], [88.35587311, 21.76645088], [88.3554306, 21.76637459], [88.3549881, 21.76623917], [88.35453796, 21.76609993], [88.35408783, 21.76592064], [88.35359192, 21.76581192], [88.3531189, 21.76564026], [88.3526001, 21.76556015], [88.35206604, 21.76550102], [88.35157013, 21.76535034], [88.35103607, 21.76523972], [88.35055542, 21.76504326], [88.35002136, 21.76495743], [88.34953308, 21.76474953], [88.34900665, 21.76453972], [88.34854889, 21.76423454], [88.34805298, 21.76394463], [88.34755707, 21.76365852], [88.3470993, 21.76334], [88.34664154, 21.7630291], [88.34619141, 21.76270294], [88.34581757, 21.76232529], [88.34545898, 21.76197052], [88.3451004, 21.76167107], [88.34475708, 21.76138878], [88.34440613, 21.76111031], [88.34409332, 21.76083183], [88.34376526, 21.76055717], [88.34345245, 21.76026917], [88.34317017, 21.7599659], [88.34293365, 21.75958824], [88.34274292, 21.75914955], [88.34250641, 21.75872993], [88.34229279, 21.7582798], [88.34211731, 21.75778961], [88.34192657, 21.75728989], [88.34171295, 21.75681686], [88.34158325, 21.75632858], [88.34140015, 21.75593185], [88.34126282, 21.75557137], [88.34115601, 21.75523186], [88.34099579, 21.75493431], [88.34067535, 21.75435257], [88.34038544, 21.75412369], [88.34047699, 21.75363731], [88.34040833, 21.75309181], [88.34027863, 21.75251007], [88.34013367, 21.75195694], [88.33998108, 21.75144958], [88.3398056, 21.75101089], [88.33994293, 21.75057983], [88.33999634, 21.75013924], [88.33999634, 21.74967003], [88.33999634, 21.74913979], [88.33999634, 21.74855995], [88.34005737, 21.74797058], [88.34024048, 21.74739075], [88.34027863, 21.74683189], [88.34027863, 21.7462883], [88.34027863, 21.7457695], [88.34027863, 21.74527931], [88.34027863, 21.74477005], [88.34027863, 21.74423027], [88.34031677, 21.74365044], [88.34044647, 21.74310112], [88.34034729, 21.74257088], [88.34028625, 21.74204254], [88.34027863, 21.74151039], [88.34027863, 21.74097061], [88.34027863, 21.74047661], [88.34031677, 21.74002457], [88.34050751, 21.73968506], [88.34055328, 21.73944092], [88.34055328, 21.73888969], [88.3408432, 21.73861122], [88.34083557, 21.73805428], [88.34111023, 21.73777962], [88.34111023, 21.73722076], [88.34139252, 21.73694229], [88.34139252, 21.73555565], [88.34166718, 21.7352829], [88.34166718, 21.73500061], [88.34221649, 21.73444176], [88.34222412, 21.73333359], [88.34249878, 21.73305511], [88.34249878, 21.73167038], [88.34278107, 21.73138809], [88.34278107, 21.7305584], [88.34306335, 21.73027992], [88.34306335, 21.72999954], [88.34278107, 21.72972298], [88.34278107, 21.72916794], [88.34306335, 21.72887993], [88.34328461, 21.72838593], [88.34335327, 21.72795105], [88.34347534, 21.72752953], [88.34360504, 21.72711372], [88.34375, 21.72670555], [88.3438797, 21.72638512], [88.34443665, 21.72556114], [88.34443665, 21.72528076], [88.34416962, 21.72500038], [88.34416962, 21.72472], [88.34444427, 21.72444344], [88.34443665, 21.7238903], [88.34527588, 21.72305107], [88.34527588, 21.72249985], [88.34500122, 21.72221947], [88.34500122, 21.72166634], [88.34471893, 21.72138977], [88.34449005, 21.72107315], [88.34438324, 21.72098732], [88.34388733, 21.72055626], [88.34306335, 21.72056007], [88.34221649, 21.71970749], [88.34194183, 21.71972275], [88.34055328, 21.7183342], [88.34027863, 21.7183342], [88.33944702, 21.71750069], [88.33916473, 21.71750069], [88.33898163, 21.71731567], [88.33889008, 21.71722221], [88.33860779, 21.71722221], [88.33849335, 21.71710968], [88.33789825, 21.71651268], [88.33777618, 21.71639061], [88.33760834, 21.71623039], [88.33732605, 21.71594048], [88.33703613, 21.7156601], [88.33693695, 21.71556091], [88.33638763, 21.71500015], [88.33611298, 21.71500015], [88.33583069, 21.71471977], [88.33555603, 21.71472168], [88.33456421, 21.71379852], [88.333992, 21.71339035], [88.33361053, 21.71249962], [88.33333588, 21.71222115], [88.33333588, 21.71194649], [88.33305359, 21.7116642], [88.33262634, 21.71141052], [88.33222961, 21.71043968], [88.33195496, 21.7105732], [88.33139038, 21.71056366], [88.33110809, 21.71056366], [88.33083344, 21.71055412], [88.32888794, 21.71055984], [88.32861328, 21.71027946], [88.32833099, 21.71027946], [88.32776642, 21.70972061], [88.32749939, 21.70972252], [88.32746887, 21.70957947], [88.32704163, 21.70946121], [88.32656097, 21.70950699], [88.32648468, 21.70951462], [88.3260498, 21.70967102], [88.32550049, 21.7096405], [88.32508087, 21.70949173], [88.32492828, 21.70943832], [88.32428741, 21.70919037], [88.32346344, 21.70903206], [88.32311249, 21.70889664], [88.32264709, 21.70889282], [88.3219986, 21.70889282], [88.32126617, 21.70889282], [88.32054138, 21.70889282], [88.31920624, 21.70889282], [88.31864166, 21.70889282], [88.31813812, 21.70889282], [88.31764221, 21.70888901], [88.31710052, 21.70890999], [88.31650543, 21.70900917], [88.31585693, 21.70905304], [88.31530762, 21.70919228], [88.31482697, 21.70944214], [88.31434631, 21.70970345], [88.31382751, 21.70992279], [88.3132782, 21.7100811], [88.31277466, 21.71028328], [88.31228638, 21.71050072], [88.31172943, 21.71058655], [88.31117249, 21.71073914], [88.31060028, 21.71086502], [88.31007385, 21.71111488], [88.30954742, 21.71141052], [88.30905151, 21.71179008], [88.30857849, 21.7122097], [88.3081131, 21.71263123], [88.30776215, 21.71313095], [88.30739594, 21.7136097], [88.30703735, 21.71406746], [88.30669403, 21.71451187], [88.30641174, 21.71495438], [88.30623627, 21.71541023], [88.30612946, 21.71585083], [88.30610657, 21.71627998], [88.30606079, 21.71672058], [88.30587006, 21.7171402], [88.30580139, 21.71760559], [88.30596924, 21.71812248], [88.30609131, 21.71865082], [88.30610657, 21.71918106], [88.30615997, 21.71969795], [88.30633545, 21.72018051], [88.306427, 21.72073364], [88.30667114, 21.72126007], [88.30687714, 21.7218399], [88.30697632, 21.72249031], [88.30718231, 21.72307777], [88.30723572, 21.72369003], [88.30734253, 21.72426987], [88.30752563, 21.72480965], [88.3077774, 21.72531319], [88.30804443, 21.72581291], [88.30822754, 21.72622108], [88.30827332, 21.7263298], [88.30847931, 21.72681808], [88.30861664, 21.72727966], [88.30879211, 21.72769928], [88.30890656, 21.72809029], [88.30909729, 21.72846031], [88.30918884, 21.72884941], [88.30935669, 21.72923088], [88.30944824, 21.72966957], [88.30957031, 21.73011971], [88.30970001, 21.73060036], [88.30973053, 21.73116112], [88.3097229, 21.73177528], [88.30973053, 21.73244286], [88.30973053, 21.7331295], [88.30970001, 21.73376656], [88.30957031, 21.73431015], [88.30945587, 21.73477936], [88.30941772, 21.73520279], [88.30930328, 21.73557091], [88.30916595, 21.73596954], [88.30899811, 21.73641014], [88.30883026, 21.73689079], [88.30860138, 21.73734283], [88.30838013, 21.7377758], [88.3082962, 21.73826981], [88.30812836, 21.73872185], [88.30805206, 21.73919868], [88.30794525, 21.7396965], [88.30774689, 21.74020004], [88.30750275, 21.74073029], [88.30726624, 21.74129295], [88.30717468, 21.74188995], [88.30699158, 21.74244308], [88.30696106, 21.74295998], [88.30693817, 21.7434597], [88.30686951, 21.74392891], [88.30667114, 21.74432945], [88.30641937, 21.74474907], [88.30626678, 21.74525261], [88.30613708, 21.7457428], [88.30610657, 21.7462101], [88.30609131, 21.74666023], [88.30600739, 21.74703026], [88.30586243, 21.74736977], [88.30583191, 21.74774933], [88.30587006, 21.74815178], [88.30605316, 21.74858093], [88.30609131, 21.74911118], [88.30600739, 21.7496891], [88.30586243, 21.75029945], [88.30583191, 21.75093842], [88.30583191, 21.75158119]]], [[[88.99957275, 21.8116703], [88.99972534, 21.81083298], [88.99973297, 21.81138992], [89.0, 21.8116703], [89.00137329, 21.81117821], [89.00170898, 21.81116486], [89.00230408, 21.81113434], [89.00262451, 21.81112289], [89.00296021, 21.8109436], [89.00315857, 21.81076813], [89.00338745, 21.81064987], [89.0040741, 21.81053162], [89.00473022, 21.81083488], [89.00537109, 21.81076813], [89.00585175, 21.81046104], [89.00682831, 21.8106308], [89.00734711, 21.81060982], [89.00786591, 21.81068993], [89.00836945, 21.81044006], [89.00892639, 21.81078911], [89.00927734, 21.81098366], [89.00965118, 21.81106186], [89.01017761, 21.81129456], [89.01053619, 21.81143188], [89.01082611, 21.81143188], [89.0111084, 21.81136513], [89.01139832, 21.81136513], [89.01161194, 21.81143188], [89.01203918, 21.81163025], [89.01254272, 21.81184006], [89.01304626, 21.81196976], [89.01354218, 21.81203842], [89.01367188, 21.81207848], [89.01397705, 21.81217384], [89.01454926, 21.8123703], [89.01503754, 21.81244278], [89.01548767, 21.81250954], [89.01584625, 21.81250954], [89.01626587, 21.8122406], [89.01647949, 21.81196976], [89.01661682, 21.81163025], [89.01654816, 21.81123161], [89.01654816, 21.81082726], [89.01641083, 21.81036186], [89.0161972, 21.8096199], [89.01612091, 21.80830956], [89.01611328, 21.80799103], [89.01611328, 21.80763054], [89.01605225, 21.80724335], [89.01587677, 21.80687141], [89.01574707, 21.8064537], [89.015625, 21.80603409], [89.01548767, 21.80550957], [89.01532745, 21.80391121], [89.01528168, 21.80348587], [89.01529694, 21.80302048], [89.01512146, 21.80066299], [89.01490784, 21.79992485], [89.01447296, 21.79878044], [89.01419067, 21.7985096], [89.01383209, 21.79797363], [89.0137558, 21.79696465], [89.0137558, 21.79568863], [89.01386261, 21.7940712], [89.01436615, 21.79360962], [89.01491547, 21.79301071], [89.01515198, 21.79249573], [89.01522064, 21.7918911], [89.01515198, 21.79128075], [89.01503754, 21.79073906], [89.0147934, 21.79034996], [89.01449585, 21.79008102], [89.01412201, 21.79002953], [89.01389313, 21.78973007], [89.01395416, 21.78931808], [89.0147171, 21.78895569], [89.01499939, 21.78861046], [89.01503754, 21.78833008], [89.01506042, 21.78787041], [89.01506805, 21.78730965], [89.01506805, 21.78673172], [89.0151062, 21.78616905], [89.0152359, 21.78567123], [89.01532745, 21.78519058], [89.01547241, 21.7847805], [89.01554108, 21.78440285], [89.01555634, 21.78405952], [89.01558685, 21.78375053], [89.01568604, 21.78346062], [89.01580048, 21.78312111], [89.01589203, 21.78267288], [89.01609039, 21.78214836], [89.01631927, 21.78154945], [89.01672363, 21.78098679], [89.01669312, 21.78043938], [89.016716, 21.77987099], [89.01696014, 21.77934074], [89.01725006, 21.77888107], [89.01740265, 21.77845955], [89.01724243, 21.77786064], [89.01714325, 21.77736473], [89.01724243, 21.77691078], [89.01741028, 21.77647018], [89.0175705, 21.77602959], [89.01779175, 21.77564049], [89.01802826, 21.77526093], [89.01817322, 21.77481079], [89.01811218, 21.77432251], [89.01807404, 21.77380562], [89.01809692, 21.77331924], [89.01822662, 21.77290916], [89.01844788, 21.77255058], [89.01870728, 21.77218056], [89.01899719, 21.77173042], [89.01928711, 21.77120972], [89.01945496, 21.77059746], [89.0196228, 21.76996994], [89.01992798, 21.76947975], [89.02017212, 21.76902008], [89.02039337, 21.76859093], [89.02052307, 21.76815033], [89.02054596, 21.7676506], [89.0205307, 21.76711464], [89.02060699, 21.76658249], [89.02074432, 21.7660923], [89.02087402, 21.76561546], [89.02105713, 21.76514053], [89.02113342, 21.76468849], [89.0212326, 21.76428032], [89.02139282, 21.76391983], [89.02155304, 21.7635994], [89.02169037, 21.76330185], [89.02184296, 21.76303291], [89.02198792, 21.76276207], [89.02214813, 21.76250458], [89.02223206, 21.76214409], [89.02233124, 21.76174164], [89.0224762, 21.76131821], [89.02256775, 21.76085091], [89.02253723, 21.76021194], [89.02285004, 21.75986481], [89.02363586, 21.75954247], [89.02373505, 21.75905037], [89.02330017, 21.75897026], [89.02270508, 21.75918579], [89.02194214, 21.75939941], [89.02181244, 21.75943565], [89.02144623, 21.7599659], [89.02113342, 21.76032448], [89.02083588, 21.76074028], [89.02056122, 21.7611599], [89.02027893, 21.76155663], [89.01996613, 21.76192284], [89.0196228, 21.7622509], [89.01924896, 21.76258087], [89.01888275, 21.7628994], [89.01849365, 21.76320839], [89.01809692, 21.76356125], [89.01770782, 21.76393509], [89.0172348, 21.76429367], [89.016716, 21.76464081], [89.01616669, 21.76496124], [89.015625, 21.76527214], [89.01508331, 21.76555061], [89.01454163, 21.76579857], [89.01400757, 21.76597023], [89.01348877, 21.76608276], [89.01300049, 21.76610756], [89.0125351, 21.76611137], [89.01208496, 21.76612282], [89.01165009, 21.76616859], [89.01123047, 21.76629257], [89.01076508, 21.76637459], [89.01026917, 21.76637077], [89.00978851, 21.76633835], [89.00933838, 21.76626968], [89.00891113, 21.76622009], [89.00847626, 21.7663002], [89.00800323, 21.76633835], [89.00746155, 21.7663517], [89.00689697, 21.7663517], [89.00634003, 21.7663002], [89.00582123, 21.76618004], [89.00530243, 21.76613045], [89.00467682, 21.76610947], [89.00398254, 21.76610184], [89.00319672, 21.76608467], [89.00263977, 21.76603127], [89.00208282, 21.76597977], [89.0, 21.7658329], [88.99973297, 21.76610947], [88.99944305, 21.76638985], [88.9991684, 21.76666451], [88.99880981, 21.76694107], [88.99861145, 21.76749992], [88.99810791, 21.76861191], [88.99807739, 21.76880074], [88.99804688, 21.7690239], [88.99833679, 21.76971817], [88.99861145, 21.77000046], [88.99894714, 21.77041054], [88.99949646, 21.77075958], [89.0, 21.7705555], [89.00042725, 21.77090645], [89.0005188, 21.77098083], [89.00086975, 21.77119255], [89.00132751, 21.77153969], [89.00164795, 21.77175713], [89.0019989, 21.77203369], [89.00258636, 21.77223206], [89.00280762, 21.77231979], [89.00318909, 21.77247047], [89.00379944, 21.77271271], [89.00435638, 21.77299118], [89.00488281, 21.77330971], [89.00541687, 21.77360153], [89.00596619, 21.77383995], [89.00653839, 21.77404022], [89.00705719, 21.77423286], [89.00753021, 21.77447128], [89.00798035, 21.77472115], [89.008461, 21.77499008], [89.00897217, 21.77527046], [89.00952148, 21.77555275], [89.01004028, 21.77583122], [89.01055145, 21.77612686], [89.01100159, 21.77646065], [89.01138306, 21.77685165], [89.01168823, 21.77724648], [89.01196289, 21.77766609], [89.01222992, 21.77809143], [89.01248169, 21.77853012], [89.01267242, 21.77897072], [89.01275635, 21.77939987], [89.01278687, 21.77980042], [89.01277924, 21.78018188], [89.0127182, 21.78054428], [89.0125351, 21.78089142], [89.01235962, 21.78125], [89.01219177, 21.78160667], [89.01194763, 21.78194427], [89.01166534, 21.78228378], [89.01133728, 21.78260994], [89.01095581, 21.78292847], [89.01056671, 21.78325081], [89.01014709, 21.78354073], [89.00967407, 21.78376389], [89.00917816, 21.78392029], [89.00868988, 21.78412056], [89.00818634, 21.78427124], [89.00772858, 21.78449059], [89.00726318, 21.78473091], [89.00679016, 21.78495979], [89.00627899, 21.78512955], [89.00576019, 21.78532028], [89.00524902, 21.78553963], [89.00470734, 21.78571701], [89.00417328, 21.78588104], [89.00366974, 21.78610611], [89.00320435, 21.78631401], [89.00271606, 21.78646278], [89.00222015, 21.78662109], [89.00166321, 21.78673172], [89.00109863, 21.78691101], [89.00054932, 21.78712654], [89.0, 21.78722191], [88.99958801, 21.78739548], [88.99915314, 21.78765106], [88.99864197, 21.7877903], [88.99810028, 21.78791046], [88.9974823, 21.78802109], [88.99681091, 21.78809738], [88.99617767, 21.78833008], [88.99552917, 21.78860283], [88.99487305, 21.78881264], [88.9941864, 21.78891945], [88.99359131, 21.78909111], [88.99299622, 21.78922081], [88.99250031, 21.78938103], [88.99201965, 21.78944969], [88.99153137, 21.78950882], [88.9909668, 21.78960037], [88.99034882, 21.78975105], [88.99018097, 21.79003906], [88.99009705, 21.79042053], [88.99002075, 21.7907505], [88.98999786, 21.79111671], [88.99003601, 21.79154205], [88.990242, 21.79198074], [88.9903717, 21.7924614], [88.99057007, 21.79289436], [88.9908371, 21.79327965], [88.9910965, 21.79364967], [88.9913559, 21.79398727], [88.99154663, 21.79432869], [88.99169159, 21.79467964], [88.99191284, 21.79496956], [88.99208832, 21.79529572], [88.99221039, 21.79566193], [88.9923172, 21.7960701], [88.99251556, 21.79646683], [88.9927597, 21.79688072], [88.99298859, 21.79739952], [88.99323273, 21.79795074], [88.99346161, 21.79848862], [88.99363708, 21.79903412], [88.99378204, 21.79958153], [88.99388123, 21.80008888], [88.99396515, 21.80060959], [88.99414063, 21.80108833], [88.99425507, 21.80158615], [88.99442291, 21.8020401], [88.9944458, 21.80253029], [88.9944458, 21.80302811], [88.9944458, 21.80352974], [88.9944458, 21.80404091], [88.9944458, 21.80454826], [88.9944458, 21.80506134], [88.99446106, 21.8055706], [88.99453735, 21.80608177], [88.99460602, 21.80657005], [88.99468994, 21.80711174], [88.99465942, 21.80763626], [88.99468994, 21.80812073], [88.99460602, 21.80859947], [88.99463654, 21.80910683], [88.99449921, 21.80957222], [88.99450684, 21.80991936], [88.99451447, 21.81008148], [88.99443817, 21.81060982], [88.99446106, 21.81119919], [88.99459076, 21.8117981], [88.99485779, 21.81232643], [88.995224, 21.81250381], [88.99534607, 21.81256294], [88.99593353, 21.81254005], [88.99655151, 21.81250954], [88.99720764, 21.81245995], [88.99784851, 21.81229591], [88.9985199, 21.81215286], [88.99909973, 21.81191826], [88.99957275, 21.8116703]]], [[[88.91583252, 21.82583427], [88.91638947, 21.82527733], [88.91665649, 21.82529259], [88.91750336, 21.8244381], [88.91777802, 21.82444382], [88.91833496, 21.82389069], [88.91860962, 21.82389069], [88.91889191, 21.82361031], [88.91916656, 21.82361031], [88.91944122, 21.82332993], [88.91972351, 21.82333374], [88.91999817, 21.82305527], [88.92056274, 21.82305908], [88.92082977, 21.82278061], [88.92193604, 21.82278061], [88.92222595, 21.82305908], [88.92305756, 21.82305527], [88.9232254, 21.82322311], [88.92333221, 21.82333374], [88.92388916, 21.82332993], [88.92444611, 21.82389069], [88.92472076, 21.82389069], [88.92527771, 21.82389069], [88.92694092, 21.82222748], [88.92778015, 21.82222748], [88.92804718, 21.82195091], [88.92888641, 21.82195091], [88.9291687, 21.82222748], [88.93000031, 21.82222748], [88.93026733, 21.82250023], [88.93055725, 21.82250023], [88.93083191, 21.82278061], [88.93110657, 21.82278061], [88.93138885, 21.82250023], [88.93499756, 21.82250023], [88.93527985, 21.82222748], [88.93553925, 21.82222748], [88.93553925, 21.82195091], [88.93582916, 21.82167053], [88.93582916, 21.81999969], [88.93611145, 21.81972122], [88.93611145, 21.81916428], [88.93638611, 21.81888962], [88.93638611, 21.81861115], [88.93694305, 21.81805992], [88.93694305, 21.81777954], [88.93723297, 21.81750107], [88.93723297, 21.81666946], [88.9366684, 21.81610107], [88.9355545, 21.81611061], [88.93527985, 21.81583214], [88.93499756, 21.81583214], [88.93444824, 21.8152771], [88.93416595, 21.81528282], [88.93332672, 21.81444168], [88.93333435, 21.81416702], [88.93305206, 21.81389046], [88.93305206, 21.81361008], [88.9327774, 21.81333351], [88.9327774, 21.81305504], [88.93250275, 21.81278038], [88.93250275, 21.8116703], [88.93222046, 21.81138992], [88.93222046, 21.81082916], [88.93250275, 21.81055641], [88.93222046, 21.81028938], [88.93222046, 21.80944061], [88.9311142, 21.80833244], [88.93083191, 21.80833244], [88.93055725, 21.80805779], [88.93026733, 21.80805969], [88.93000031, 21.80778122], [88.92973328, 21.80778122], [88.92944336, 21.80750084], [88.9291687, 21.80750084], [88.92888641, 21.80722046], [88.92861176, 21.80722237], [88.92778015, 21.80638885], [88.92778015, 21.80611038], [88.92749786, 21.80583], [88.92749786, 21.80555344], [88.92722321, 21.80528069], [88.92722321, 21.80445099], [88.92694092, 21.80416107], [88.92694092, 21.80361176], [88.92722321, 21.80333328], [88.92722321, 21.80249977], [88.92749786, 21.80221939], [88.92749786, 21.80194473], [88.92778015, 21.80166626], [88.92778015, 21.80000114], [88.92749786, 21.79972076], [88.92749786, 21.7994442], [88.92666626, 21.79861069], [88.92666626, 21.7983284], [88.92555237, 21.79722214], [88.92527771, 21.79722214], [88.92472076, 21.7966671], [88.92444611, 21.79667091], [88.92388916, 21.79610825], [88.9236145, 21.79611206], [88.92305756, 21.79555511], [88.9227829, 21.79556084], [88.92193604, 21.7947197], [88.92166901, 21.7947216], [88.92111206, 21.79416847], [88.92056274, 21.79417038], [88.92028046, 21.79389], [88.91999817, 21.79389], [88.91971588, 21.79360962], [88.91944122, 21.79361153], [88.91921997, 21.79338837], [88.91833496, 21.79249954], [88.91832733, 21.79222107], [88.91805267, 21.79222488], [88.91805267, 21.79194641], [88.91777802, 21.79166412], [88.91779327, 21.79083061], [88.91805267, 21.79055405], [88.91805267, 21.79027939], [88.91860962, 21.78972054], [88.91889191, 21.78972244], [88.91916656, 21.78944206], [88.91999817, 21.78944206], [88.92028046, 21.7891674], [88.92111206, 21.7891674], [88.92138672, 21.78944206], [88.92166901, 21.78944206], [88.92194366, 21.7891674], [88.92250061, 21.78918076], [88.92305756, 21.78861046], [88.92305756, 21.78833008], [88.92333221, 21.78805542], [88.92305756, 21.78778267], [88.92305756, 21.78722191], [88.92277527, 21.78694534], [88.9227829, 21.78667259], [88.92193604, 21.78583145], [88.92194366, 21.78527832], [88.92166901, 21.78499985], [88.92166901, 21.78416824], [88.92138672, 21.78388977], [88.92138672, 21.78333092], [88.92111206, 21.78305626], [88.92111206, 21.78249931], [88.92082977, 21.78222084], [88.92082977, 21.78166771], [88.92056274, 21.78139114], [88.92056274, 21.78083038], [88.92028046, 21.78055763], [88.92028046, 21.78028107], [88.91999817, 21.77999115], [88.91999817, 21.77944374], [88.91972351, 21.77916527], [88.91971588, 21.77861023], [88.91944122, 21.77832985], [88.91944122, 21.77805328], [88.91916656, 21.77778053], [88.91916656, 21.77750015], [88.91860962, 21.77695084], [88.91860962, 21.7761097], [88.91833496, 21.77583122], [88.91833496, 21.77527809], [88.91805267, 21.77499962], [88.91805267, 21.77417946], [88.91832733, 21.77388954], [88.91832733, 21.77361107], [88.91860962, 21.7733326], [88.91860962, 21.77305603], [88.91916656, 21.77249908], [88.91916656, 21.77193832], [88.91944122, 21.77166748], [88.91944122, 21.77000046], [88.91889191, 21.7694397], [88.91860962, 21.76944351], [88.91694641, 21.7677784], [88.91665649, 21.7677803], [88.91555786, 21.76667023], [88.91555786, 21.76638985], [88.91249847, 21.76333046], [88.91249847, 21.7630558], [88.91165924, 21.76222038], [88.91166687, 21.76194382], [88.91139221, 21.76167107], [88.91139221, 21.76083183], [88.91110992, 21.76055527], [88.91110992, 21.75972176], [88.91083527, 21.75944519], [88.9108429, 21.75917244], [88.91110992, 21.75889015], [88.91110992, 21.75861168], [88.91139221, 21.75833321], [88.91139221, 21.75805473], [88.91166687, 21.75777817], [88.91165924, 21.75749969], [88.91194153, 21.75722122], [88.91194153, 21.75694466], [88.91222382, 21.75666618], [88.91221619, 21.75611115], [88.91249847, 21.75582123], [88.91249847, 21.75555611], [88.91278076, 21.75527954], [88.91165924, 21.75416946], [88.9108429, 21.75416946], [88.91062927, 21.75396156], [88.91055298, 21.75388908], [88.90944672, 21.75389099], [88.90926361, 21.75370407], [88.90888977, 21.75333023], [88.90860748, 21.75333595], [88.90833282, 21.75305748], [88.90805817, 21.75307083], [88.90777588, 21.75278091], [88.90750122, 21.75278091], [88.90718842, 21.75246811], [88.90694427, 21.75222206], [88.90638733, 21.75222206], [88.90611267, 21.75194359], [88.90583038, 21.75194359], [88.90555573, 21.75166512], [88.90222168, 21.75167084], [88.90194702, 21.75139046], [88.9016571, 21.75167084], [88.90083313, 21.75166512], [88.90055847, 21.75194359], [88.89778137, 21.75194359], [88.89749908, 21.75222206], [88.8972168, 21.75222015], [88.89694214, 21.75250053], [88.89665985, 21.75250053], [88.89639282, 21.75278091], [88.89611053, 21.75277519], [88.89554596, 21.75333023], [88.89555359, 21.75388908], [88.89499664, 21.75444031], [88.89499664, 21.75500107], [88.89472198, 21.75527954], [88.89472198, 21.75555611], [88.89499664, 21.75582123], [88.89499664, 21.75777817], [88.89527893, 21.75805473], [88.89527893, 21.75861168], [88.89554596, 21.75889015], [88.89554596, 21.75917244], [88.89583588, 21.75945282], [88.89583588, 21.76167107], [88.89611053, 21.76194382], [88.89611053, 21.76444435], [88.89639282, 21.76472092], [88.89639282, 21.76556015], [88.8972168, 21.76638985], [88.89722443, 21.76666451], [88.89749908, 21.76694679], [88.89749908, 21.76721954], [88.89778137, 21.76749992], [88.89778137, 21.76860809], [88.89805603, 21.76889038], [88.89805603, 21.77000046], [88.89833069, 21.77028084], [88.89833069, 21.7705555], [88.89861298, 21.77082825], [88.89861298, 21.77111053], [88.89944458, 21.77194405], [88.89943695, 21.77222061], [88.89971924, 21.77249908], [88.89971924, 21.77305603], [88.90000153, 21.7733326], [88.90000153, 21.77388954], [88.90027618, 21.77416611], [88.90027618, 21.77583122], [88.90055847, 21.7761097], [88.90055847, 21.77667046], [88.90083313, 21.77695084], [88.90083313, 21.77805328], [88.90055847, 21.77832985], [88.90055847, 21.78139114], [88.90027618, 21.78166771], [88.90027618, 21.78222084], [88.89971924, 21.78277969], [88.89971924, 21.78305626], [88.89943695, 21.78333092], [88.89943695, 21.78388977], [88.89916992, 21.78416634], [88.89916992, 21.78444481], [88.89888763, 21.78471756], [88.89888763, 21.78527832], [88.89833069, 21.78583145], [88.89833069, 21.78611946], [88.89805603, 21.7863903], [88.89805603, 21.78666687], [88.89814758, 21.78676033], [88.89888763, 21.78750038], [88.89944458, 21.78750038], [88.90027618, 21.78833389], [88.90055847, 21.78833008], [88.90083313, 21.78861046], [88.90110779, 21.78861046], [88.90222168, 21.78972054], [88.90222168, 21.79000092], [88.90249634, 21.79027748], [88.90249634, 21.79083252], [88.90277863, 21.79111099], [88.90278625, 21.79138947], [88.90305328, 21.79166412], [88.90305328, 21.79193115], [88.90389252, 21.79277992], [88.90416718, 21.79277992], [88.90556335, 21.79417038], [88.90638733, 21.79417038], [88.90666962, 21.79389], [88.90693665, 21.79417038], [88.90583038, 21.79528046], [88.90499878, 21.79528046], [88.90485382, 21.79513168], [88.90471649, 21.79499054], [88.90444183, 21.79500008], [88.90416718, 21.7947216], [88.90389252, 21.7947216], [88.90333557, 21.79416847], [88.90305328, 21.79417038], [88.90278625, 21.79389], [88.90278625, 21.79360962], [88.90249634, 21.79333305], [88.90249634, 21.79305458], [88.90222168, 21.79277992], [88.90222168, 21.79222107], [88.90194702, 21.79194641], [88.90194702, 21.79166412], [88.9016571, 21.79138947], [88.9016571, 21.79111099], [88.90139008, 21.79083061], [88.90139008, 21.79027748], [88.90055847, 21.78944016], [88.90027618, 21.78944206], [88.90000153, 21.7891674], [88.89943695, 21.78918076], [88.89916992, 21.78889084], [88.89833069, 21.78889084], [88.89805603, 21.78861046], [88.89778137, 21.78861046], [88.89729309, 21.78812599], [88.89694214, 21.78777695], [88.89665985, 21.78778267], [88.89639282, 21.78806114], [88.89583588, 21.78806114], [88.89499664, 21.78889084], [88.89472198, 21.78888893], [88.89416504, 21.78944206], [88.89389038, 21.78944206], [88.89360809, 21.78972244], [88.89332581, 21.78972054], [88.89305878, 21.79000092], [88.89277649, 21.79000092], [88.89194489, 21.79083252], [88.89167023, 21.79083061], [88.89083099, 21.79166412], [88.89083099, 21.79193115], [88.88999939, 21.79277992], [88.88999939, 21.7930603], [88.88916779, 21.79389], [88.88916779, 21.79416847], [88.88833618, 21.79499054], [88.88833618, 21.79528046], [88.88805389, 21.79555511], [88.88804626, 21.79582977], [88.88722229, 21.7966671], [88.88722229, 21.79694366], [88.88694763, 21.79721832], [88.88694763, 21.79750061], [88.88667297, 21.79777908], [88.88667297, 21.79805946], [88.8861084, 21.79861069], [88.8861084, 21.79888916], [88.88583374, 21.79916573], [88.88582611, 21.79943848], [88.88527679, 21.80000114], [88.88527679, 21.80027962], [88.8841629, 21.80138969], [88.8841629, 21.80166626], [88.88361359, 21.8022213], [88.88361359, 21.80305481], [88.8833313, 21.80332947], [88.8833313, 21.80388832], [88.88305664, 21.80416107], [88.88305664, 21.80444336], [88.8833313, 21.80472183], [88.8833313, 21.80722046], [88.88305664, 21.80750084], [88.88305664, 21.80805779], [88.8833313, 21.80833054], [88.8833313, 21.80861092], [88.88360596, 21.80888939], [88.88388824, 21.80888939], [88.88471985, 21.8097229], [88.88500214, 21.80971909], [88.88555908, 21.81028938], [88.88639069, 21.81028938], [88.88660431, 21.81049156], [88.88667297, 21.81055832], [88.88805389, 21.81055641], [88.88833618, 21.81083298], [88.88916779, 21.81083298], [88.88944244, 21.81055641], [88.88972473, 21.81083298], [88.89039612, 21.81083298], [88.89083099, 21.81083298], [88.89111328, 21.81111145], [88.89167023, 21.81110764], [88.89193726, 21.81138992], [88.89221954, 21.81138992], [88.89263916, 21.81180573], [88.89305878, 21.81222153], [88.89362335, 21.81222153], [88.89389038, 21.81250191], [88.89417267, 21.81250191], [88.89439392, 21.81272125], [88.89444733, 21.81278038], [88.89472198, 21.81278038], [88.89583588, 21.81389046], [88.89583588, 21.81417274], [88.89722443, 21.81555557], [88.8972168, 21.81583023], [88.89805603, 21.81666946], [88.89833069, 21.81666756], [88.89861298, 21.81694221], [88.89861298, 21.8172226], [88.89888763, 21.81722069], [88.89916229, 21.81750107], [88.89971924, 21.81805992], [88.90000153, 21.81805992], [88.90194702, 21.81999969], [88.90222168, 21.81999969], [88.90277863, 21.82055664], [88.90416718, 21.82055664], [88.90444183, 21.82083321], [88.90528107, 21.82083321], [88.90555573, 21.82111168], [88.90666962, 21.82110977], [88.90693665, 21.82139015], [88.90750122, 21.82139015], [88.90777588, 21.82167053], [88.90805817, 21.82167053], [88.90833282, 21.82195091], [88.90888977, 21.82195091], [88.90972137, 21.82278061], [88.91000366, 21.8227787], [88.91055298, 21.82333374], [88.9108429, 21.82332993], [88.91110992, 21.82361031], [88.91139221, 21.82361031], [88.91361237, 21.82583427], [88.91583252, 21.82583427]]], [[[88.18333435, 21.78750038], [88.18222046, 21.7863884], [88.1819458, 21.7863903], [88.1817627, 21.78620338], [88.18138885, 21.78583145], [88.18110657, 21.78583145], [88.18055725, 21.7863903], [88.18055725, 21.78694534], [88.18026733, 21.78722191], [88.18027496, 21.78750038], [88.18011475, 21.78766251], [88.18000031, 21.78777695], [88.18000031, 21.78833389], [88.17973328, 21.78861046], [88.17973328, 21.78889084], [88.17944336, 21.7891674], [88.17944336, 21.78972054], [88.1791687, 21.79000092], [88.1791687, 21.79083061], [88.17888641, 21.79111099], [88.17888641, 21.79305458], [88.1791687, 21.79333115], [88.1791687, 21.79388618], [88.18000031, 21.7947216], [88.18000031, 21.79500008], [88.18083191, 21.79583359], [88.18222046, 21.79444695], [88.18222046, 21.79417038], [88.18305206, 21.79333115], [88.18305206, 21.79305458], [88.18360901, 21.79249954], [88.1838913, 21.79222107], [88.1838913, 21.79194641], [88.18527985, 21.79055405], [88.18527985, 21.78944016], [88.18499756, 21.7891674], [88.18499756, 21.78889084], [88.18360901, 21.78750038], [88.18333435, 21.78750038]]], [[[88.75063324, 21.79540062], [88.75076294, 21.79471016], [88.75081635, 21.79399109], [88.75085449, 21.79333878], [88.75090027, 21.79277039], [88.75099945, 21.79229736], [88.75097656, 21.79185295], [88.75093842, 21.79141045], [88.75105286, 21.79096985], [88.75115967, 21.79051971], [88.75131989, 21.79009628], [88.7514267, 21.78964996], [88.75157928, 21.78919029], [88.75164795, 21.7887001], [88.7516861, 21.7881794], [88.75177002, 21.78767776], [88.75195313, 21.78725052], [88.7521286, 21.78684044], [88.75226593, 21.78642082], [88.75245667, 21.78606987], [88.75262451, 21.78572655], [88.7527771, 21.78541374], [88.75292969, 21.78512001], [88.75306702, 21.78483009], [88.7532196, 21.78454971], [88.75332642, 21.7842598], [88.75343323, 21.78397179], [88.75356293, 21.78370285], [88.75367737, 21.78342247], [88.75383759, 21.78314972], [88.75398254, 21.78284073], [88.75418091, 21.78254128], [88.75443268, 21.78222084], [88.75470734, 21.78184128], [88.75499725, 21.78137016], [88.75527954, 21.7808342], [88.75527954, 21.78055763], [88.75554657, 21.78028107], [88.75528717, 21.77999115], [88.75527954, 21.77972221], [88.75499725, 21.77944374], [88.75499725, 21.77916527], [88.75448608, 21.77865601], [88.75416565, 21.77833557], [88.75389099, 21.77833557], [88.75305176, 21.77750015], [88.7527771, 21.77778053], [88.75250244, 21.77778053], [88.75222778, 21.77750015], [88.7519455, 21.77750015], [88.75166321, 21.77722168], [88.75138855, 21.77721977], [88.75110626, 21.77750015], [88.7508316, 21.77750015], [88.75055695, 21.77721977], [88.75, 21.77722168], [88.74972534, 21.77694321], [88.74944305, 21.77695084], [88.74944305, 21.77639008], [88.74916077, 21.7761097], [88.7491684, 21.77583122], [88.74886322, 21.77554512], [88.74858856, 21.77518082], [88.74843597, 21.77497482], [88.74830627, 21.77480125], [88.74801636, 21.7744503], [88.74774933, 21.77414131], [88.74751282, 21.77387047], [88.74732971, 21.77360153], [88.74717712, 21.77330971], [88.74694061, 21.7730484], [88.74665833, 21.77276993], [88.74629211, 21.77248955], [88.74610901, 21.77222252], [88.74577332, 21.77231216], [88.74510956, 21.77248955], [88.74453735, 21.77309608], [88.74360657, 21.77342987], [88.74310303, 21.77370071], [88.74246216, 21.7739048], [88.74195862, 21.77390289], [88.74080658, 21.77417946], [88.73980713, 21.77404022], [88.7384491, 21.77444267], [88.73715973, 21.77478027], [88.73607635, 21.77518082], [88.73544312, 21.7761898], [88.73493958, 21.77726936], [88.73500061, 21.77806091], [88.73500061, 21.77861023], [88.73472595, 21.77889061], [88.73472595, 21.77916527], [88.73443604, 21.77943993], [88.73390198, 21.77959824], [88.73320007, 21.77970123], [88.73239899, 21.77972031], [88.73165894, 21.7796917], [88.73105621, 21.77958107], [88.73059845, 21.77947044], [88.7301712, 21.77940941], [88.72972107, 21.77944374], [88.72888947, 21.77944374], [88.72861481, 21.77972221], [88.72833252, 21.77972221], [88.72833252, 21.78471756], [88.72861481, 21.78499985], [88.72860718, 21.78583145], [88.72888947, 21.78611946], [88.72888947, 21.78694534], [88.72860718, 21.78722191], [88.72861481, 21.78805542], [88.72833252, 21.78833389], [88.72833252, 21.79222107], [88.72805786, 21.79249954], [88.72805786, 21.79277611], [88.72750092, 21.79333305], [88.72750092, 21.79360962], [88.72777557, 21.79388618], [88.72915649, 21.79528046], [88.72944641, 21.79527855], [88.73000336, 21.79583359], [88.73027039, 21.79584312], [88.73074341, 21.79602432], [88.73131561, 21.7960968], [88.73195648, 21.79611969], [88.73265076, 21.79616356], [88.73335266, 21.79627037], [88.73406982, 21.79636574], [88.73479462, 21.79644585], [88.735466, 21.79663086], [88.73610687, 21.79693985], [88.73670197, 21.79728127], [88.73723602, 21.79766464], [88.73773193, 21.79805946], [88.73815918, 21.79850006], [88.73844147, 21.7990303], [88.73866272, 21.7996006], [88.73888397, 21.80014038], [88.73908997, 21.80068398], [88.73916626, 21.80125046], [88.73925781, 21.80181122], [88.73946381, 21.80230522], [88.73970795, 21.80275917], [88.7399292, 21.80321693], [88.74009705, 21.80369949], [88.74030304, 21.80416107], [88.74054718, 21.80458069], [88.74082947, 21.80498123], [88.7411499, 21.80535126], [88.74151611, 21.8057003], [88.74192047, 21.80610657], [88.74233246, 21.80659103], [88.74277496, 21.80710983], [88.74326324, 21.80764008], [88.74384308, 21.80809593], [88.74438477, 21.80861282], [88.74481964, 21.80920982], [88.74532318, 21.80976105], [88.74582672, 21.81028938], [88.74635315, 21.81081963], [88.74687195, 21.81133652], [88.74738312, 21.81188011], [88.74790192, 21.81241989], [88.74846649, 21.81289864], [88.7490387, 21.81336212], [88.74958038, 21.81380844], [88.75011444, 21.81415939], [88.75063324, 21.81421471], [88.75102997, 21.81395149], [88.75126648, 21.81353951], [88.75130463, 21.81305885], [88.75119781, 21.81252289], [88.75112152, 21.8119278], [88.7510376, 21.81130981], [88.75089264, 21.81067085], [88.75074768, 21.81002045], [88.75052643, 21.80943108], [88.75028992, 21.80887032], [88.75006866, 21.80829811], [88.74991608, 21.8076725], [88.74972534, 21.80706787], [88.74954224, 21.80649185], [88.74938965, 21.80596161], [88.7493515, 21.80542183], [88.74937439, 21.80485916], [88.74932098, 21.80425072], [88.74932098, 21.80358124], [88.7494812, 21.80298042], [88.74964142, 21.80240822], [88.74968719, 21.80181122], [88.74962616, 21.80122757], [88.7494812, 21.8008194], [88.74944305, 21.80070877], [88.74944305, 21.80027962], [88.75, 21.79972076], [88.75, 21.79861069], [88.75026703, 21.7983284], [88.75030518, 21.79781342], [88.75035858, 21.79728508], [88.7503891, 21.79669952], [88.75051117, 21.79607964], [88.75063324, 21.79540062]]], [[[88.17111206, 21.80861092], [88.17222595, 21.80750084], [88.17222595, 21.80722046], [88.17250061, 21.8069458], [88.17250061, 21.80666542], [88.1727829, 21.80639076], [88.1727829, 21.80360985], [88.17333221, 21.80305481], [88.17333221, 21.80277824], [88.17360687, 21.80249977], [88.17360687, 21.80221939], [88.17388916, 21.80194473], [88.17388916, 21.80166626], [88.17414856, 21.80138969], [88.17414856, 21.79972076], [88.17388916, 21.7994442], [88.17388916, 21.79888916], [88.17360687, 21.79861069], [88.17360687, 21.79693985], [88.17277527, 21.79611206], [88.17305756, 21.79583359], [88.17305756, 21.79527855], [88.17222595, 21.79445076], [88.17222595, 21.79417038], [88.17193604, 21.79389], [88.17193604, 21.7930603], [88.17166901, 21.79277992], [88.17166901, 21.79193115], [88.17028046, 21.79055405], [88.16916656, 21.79055977], [88.16860962, 21.79111099], [88.16722107, 21.79111099], [88.16666412, 21.79166412], [88.16665649, 21.79360962], [88.16610718, 21.79417038], [88.16611481, 21.79444695], [88.16583252, 21.7947197], [88.16583252, 21.79555511], [88.16555786, 21.79583359], [88.16555786, 21.7983284], [88.16526794, 21.79861069], [88.16526794, 21.80027962], [88.16555786, 21.80055618], [88.16555786, 21.80194473], [88.16583252, 21.80221939], [88.16583252, 21.80277824], [88.16610718, 21.8030529], [88.16611481, 21.80388832], [88.16638947, 21.80416107], [88.16638947, 21.80528069], [88.16665649, 21.80556107], [88.16665649, 21.80611038], [88.16694641, 21.80639076], [88.16694641, 21.80666542], [88.16750336, 21.80722237], [88.16777802, 21.80722046], [88.16832733, 21.80778122], [88.16860962, 21.80778122], [88.16889191, 21.80805969], [88.16971588, 21.80805969], [88.16999817, 21.8077755], [88.17055511, 21.80833244], [88.17082977, 21.80833054], [88.17111206, 21.80861092]]], [[[88.1819458, 21.82582855], [88.18250275, 21.82527733], [88.18250275, 21.82389069], [88.1827774, 21.82361031], [88.1827774, 21.82332993], [88.18305206, 21.82305527], [88.18305206, 21.82278061], [88.18360901, 21.82222748], [88.18360901, 21.82195091], [88.18416595, 21.82139015], [88.18457031, 21.82139015], [88.18467712, 21.82131958], [88.185112, 21.82102776], [88.18547821, 21.8206501], [88.18559265, 21.8201828], [88.18548584, 21.81963158], [88.1855545, 21.81916428], [88.18527985, 21.81916428], [88.18499756, 21.81944656], [88.1847229, 21.81944656], [88.18444824, 21.81972313], [88.18416595, 21.81972122], [88.1838913, 21.81999969], [88.18360901, 21.81999969], [88.18334198, 21.82028008], [88.18305206, 21.82027626], [88.18250275, 21.82083321], [88.18222046, 21.82082939], [88.18165588, 21.82139015], [88.18138885, 21.82139015], [88.18110657, 21.82167053], [88.18083191, 21.82166862], [88.17778015, 21.82471848], [88.17778015, 21.82529259], [88.17807007, 21.82555962], [88.17861176, 21.8255558], [88.17874908, 21.82569504], [88.17888641, 21.82583427], [88.17944336, 21.82583427], [88.17973328, 21.82555962], [88.18055725, 21.82638931], [88.18083191, 21.82638931], [88.18110657, 21.82666969], [88.18138885, 21.82666969], [88.1819458, 21.82611084], [88.1819458, 21.82582855]]], [[[88.85610962, 21.86528015], [88.85694122, 21.86444092], [88.85722351, 21.86444473], [88.85749817, 21.86416626], [88.85749054, 21.86361122], [88.85721588, 21.86361122], [88.85721588, 21.86333084], [88.85666656, 21.86277962], [88.85666656, 21.86250114], [88.85639191, 21.86222076], [88.85639191, 21.8619442], [88.85610962, 21.86166763], [88.85610962, 21.8614006], [88.85582733, 21.86111069], [88.85582733, 21.86055946], [88.85555267, 21.86028099], [88.85555267, 21.85943985], [88.85527802, 21.85916519], [88.85527802, 21.85806084], [88.85555267, 21.85778046], [88.85555267, 21.8572197], [88.85630798, 21.85647011], [88.85666656, 21.85611153], [88.85694122, 21.85611153], [88.85749817, 21.85555649], [88.85778046, 21.8555603], [88.85806274, 21.85527039], [88.85861206, 21.85527802], [88.85888672, 21.85499954], [88.85916901, 21.85499954], [88.85943604, 21.85472107], [88.86027527, 21.85472107], [88.86055756, 21.8544445], [88.86166382, 21.8544445], [88.86194611, 21.85416603], [88.86222076, 21.85416603], [88.86236572, 21.85430717], [88.86250305, 21.8544445], [88.86351776, 21.8544445], [88.86499786, 21.8544445], [88.86528015, 21.85416603], [88.8658371, 21.85416985], [88.86611176, 21.85388947], [88.86667633, 21.85388947], [88.86694336, 21.8536129], [88.86723328, 21.8536129], [88.86750031, 21.85333252], [88.8686142, 21.85333252], [88.86888885, 21.85305595], [88.86915588, 21.85306168], [88.8694458, 21.85277939], [88.87082672, 21.85277939], [88.87110901, 21.85250092], [88.87194824, 21.85250092], [88.8722229, 21.85277939], [88.87304688, 21.85277939], [88.87333679, 21.85306168], [88.8741684, 21.85305595], [88.87444305, 21.85333252], [88.87472534, 21.85333252], [88.875, 21.85305595], [88.87555695, 21.85306168], [88.8758316, 21.85277939], [88.87610626, 21.85277939], [88.87722015, 21.85166931], [88.87695313, 21.85139084], [88.87722015, 21.85111046], [88.87722015, 21.85082817], [88.8769455, 21.85055542], [88.87695313, 21.85028076], [88.87638855, 21.84971809], [88.87638855, 21.84944534], [88.87610626, 21.84917068], [88.87610626, 21.8488903], [88.8758316, 21.84860992], [88.8758316, 21.84847069], [88.8758316, 21.84805679], [88.87555695, 21.84777832], [88.87555695, 21.84667015], [88.87526703, 21.84638977], [88.87526703, 21.84610939], [88.875, 21.84583282], [88.875, 21.84555435], [88.87526703, 21.84556007], [88.87526703, 21.84527969], [88.87610626, 21.84444046], [88.87611389, 21.84388924], [88.87638855, 21.84361076], [88.87638855, 21.84305954], [88.87666321, 21.84278107], [88.87666321, 21.84250069], [88.87695313, 21.84222031], [88.8769455, 21.83833313], [88.87722015, 21.83805466], [88.87722015, 21.83694458], [88.87750244, 21.83666611], [88.87750244, 21.83638954], [88.8777771, 21.83611107], [88.8777771, 21.83500099], [88.87805176, 21.83472061], [88.87805176, 21.8338871], [88.87832642, 21.83361053], [88.87832642, 21.83333015], [88.87863159, 21.8327961], [88.87999725, 21.83139038], [88.87999725, 21.83056068], [88.88027954, 21.8302803], [88.88027954, 21.82888985], [88.87999725, 21.82860947], [88.87999725, 21.82777786], [88.8797226, 21.82749939], [88.8797226, 21.82666969], [88.87944794, 21.82638931], [88.87944794, 21.82555962], [88.87924957, 21.82513046], [88.87916565, 21.82500076], [88.87916565, 21.82416725], [88.87889099, 21.82389069], [88.87889099, 21.82305908], [88.87861633, 21.82278061], [88.87861633, 21.82222748], [88.87889099, 21.82195091], [88.87889099, 21.81999969], [88.87889099, 21.8199234], [88.87889099, 21.81972122], [88.87944794, 21.81916428], [88.87944794, 21.81861115], [88.88054657, 21.81750107], [88.88054657, 21.81722069], [88.88222504, 21.81555557], [88.88223267, 21.81528282], [88.88305664, 21.81444168], [88.88305664, 21.81416702], [88.8833313, 21.81389046], [88.88305664, 21.81361008], [88.8833313, 21.81361008], [88.8833313, 21.81305504], [88.88305664, 21.81278038], [88.88305664, 21.81222153], [88.88249969, 21.81166649], [88.88249969, 21.81138992], [88.88194275, 21.81082916], [88.88194275, 21.81055641], [88.88168335, 21.81028938], [88.88168335, 21.80999947], [88.88027954, 21.80861092], [88.88027954, 21.80833054], [88.8797226, 21.8077755], [88.8797226, 21.80750084], [88.87999725, 21.80722046], [88.87999725, 21.80583572], [88.8805542, 21.80527687], [88.88054657, 21.80471992], [88.88083649, 21.80444336], [88.88083649, 21.80416107], [88.88111115, 21.80388832], [88.88111115, 21.80194283], [88.8813858, 21.80166626], [88.8813858, 21.80112076], [88.88168335, 21.80083275], [88.88166809, 21.80055618], [88.88194275, 21.80027962], [88.88194275, 21.7983284], [88.88222504, 21.79805565], [88.88223267, 21.79721832], [88.88249969, 21.79694366], [88.88249969, 21.7966671], [88.88305664, 21.79610825], [88.88305664, 21.79583359], [88.88444519, 21.79444695], [88.88445282, 21.79417038], [88.88527679, 21.79333115], [88.88527679, 21.79277611], [88.88582611, 21.79222107], [88.88583374, 21.79194641], [88.88777924, 21.79000092], [88.88804626, 21.79000092], [88.89138794, 21.78667259], [88.89138794, 21.7863903], [88.89193726, 21.7863903], [88.89277649, 21.78554916], [88.89305878, 21.78555489], [88.89389038, 21.78472137], [88.89389038, 21.78444481], [88.89527893, 21.78305626], [88.89555359, 21.78305626], [88.89694214, 21.78166771], [88.89694214, 21.78139114], [88.8972168, 21.78111076], [88.8972168, 21.78083038], [88.89778137, 21.78027534], [88.89778137, 21.77889061], [88.89805603, 21.77861023], [88.89805603, 21.77832985], [88.89749908, 21.77777863], [88.89749908, 21.77750015], [88.89694214, 21.77695084], [88.89694214, 21.77667046], [88.89611053, 21.77583122], [88.89611053, 21.77555466], [88.89583588, 21.77527809], [88.89583588, 21.77472115], [88.89555359, 21.77444458], [88.89555359, 21.77433014], [88.89555359, 21.77388954], [88.89527893, 21.77361107], [88.89527893, 21.77268982], [88.89527893, 21.77249908], [88.89499664, 21.77222061], [88.89499664, 21.77194405], [88.89444733, 21.77139091], [88.89444733, 21.77111053], [88.89389038, 21.77055931], [88.89389038, 21.77028084], [88.89362335, 21.77000046], [88.89360809, 21.76972198], [88.89333344, 21.76944351], [88.89333344, 21.76888847], [88.89305878, 21.76860809], [88.89305878, 21.76805687], [88.89277649, 21.7677784], [88.89277649, 21.76721954], [88.89250183, 21.76694679], [88.89250183, 21.7658329], [88.89221954, 21.76555443], [88.89221954, 21.76444054], [88.89138794, 21.76361084], [88.89138794, 21.76278114], [88.89111328, 21.76250076], [88.89111328, 21.76000023], [88.89083099, 21.75972176], [88.89083099, 21.75833321], [88.89111328, 21.75805473], [88.89111328, 21.75499725], [88.89138794, 21.75472069], [88.89138794, 21.75361061], [88.89193726, 21.75307083], [88.89193726, 21.75278091], [88.89250183, 21.75222015], [88.89250183, 21.75138855], [88.89305878, 21.7508297], [88.89360809, 21.75083351], [88.89389038, 21.75055313], [88.89389038, 21.75028038], [88.89554596, 21.74860954], [88.89611053, 21.74861145], [88.89694214, 21.74777794], [88.8972168, 21.74777985], [88.89778137, 21.7472229], [88.89805603, 21.7472229], [88.89833069, 21.74694443], [88.89888763, 21.74694443], [88.89916992, 21.74666595], [88.90000153, 21.74666977], [88.90000153, 21.74638939], [88.90027618, 21.74638939], [88.90046692, 21.74657822], [88.90055847, 21.74666977], [88.90110779, 21.74666977], [88.90139008, 21.74638939], [88.90278625, 21.74638939], [88.90305328, 21.74611092], [88.90721893, 21.74611092], [88.90750122, 21.74638939], [88.90805817, 21.74638939], [88.90860748, 21.74694443], [88.90888977, 21.74694443], [88.90899658, 21.74705124], [88.90916443, 21.7472229], [88.90944672, 21.74694443], [88.91055298, 21.74694443], [88.91083527, 21.7472229], [88.91139221, 21.7472229], [88.91165924, 21.74749947], [88.91388702, 21.74749947], [88.91416931, 21.74777985], [88.91610718, 21.74777985], [88.91638947, 21.74749947], [88.91722107, 21.74749947], [88.91750336, 21.7472229], [88.91777802, 21.7472229], [88.92002869, 21.74497032], [88.92138672, 21.74361038], [88.92138672, 21.74332809], [88.92166901, 21.74305534], [88.92166901, 21.74278069], [88.92193604, 21.74250031], [88.92138672, 21.74194908], [88.92111206, 21.74194908], [88.92138672, 21.74167061], [88.92111206, 21.74139023], [88.92111206, 21.74055099], [88.92082977, 21.74027824], [88.92082977, 21.73999977], [88.92028046, 21.73944092], [88.91999817, 21.73944664], [88.91972351, 21.73916435], [88.91971588, 21.73888969], [88.91889191, 21.73806953], [88.91889191, 21.73722076], [88.91860962, 21.73694229], [88.91860962, 21.73666573], [88.91832733, 21.73639107], [88.91832733, 21.73611069], [88.91779327, 21.73555946], [88.91779327, 21.7352829], [88.91694641, 21.73444176], [88.91694641, 21.7341671], [88.91665649, 21.73389053], [88.91665649, 21.73361015], [88.91611481, 21.73305511], [88.91610718, 21.73250008], [88.91583252, 21.7322216], [88.91611481, 21.73194504], [88.91611481, 21.73166656], [88.91638184, 21.73139954], [88.91555786, 21.7305584], [88.91555786, 21.73027992], [88.9152832, 21.72999954], [88.91527557, 21.72916794], [88.91443634, 21.72833061], [88.91388702, 21.72833252], [88.91333008, 21.72777939], [88.91249847, 21.72861099], [88.91139221, 21.72861099], [88.91110992, 21.72888947], [88.9108429, 21.72887993], [88.91055298, 21.72916985], [88.91027832, 21.72916794], [88.91000366, 21.7294445], [88.90944672, 21.7294445], [88.90916443, 21.72972298], [88.90888977, 21.72972107], [88.90859985, 21.72999954], [88.90777588, 21.72999954], [88.90750122, 21.73027992], [88.90721893, 21.73027992], [88.90693665, 21.7305584], [88.90666962, 21.73055649], [88.90638733, 21.73083305], [88.90611267, 21.73082924], [88.90556335, 21.73139954], [88.90556335, 21.73167038], [88.90528107, 21.73166656], [88.90499878, 21.73194504], [88.90499878, 21.7322216], [88.90444183, 21.73278046], [88.90416718, 21.73277855], [88.90361023, 21.73333359], [88.90333557, 21.73333359], [88.90305328, 21.73361015], [88.90277863, 21.73361015], [88.90211487, 21.73427963], [88.90083313, 21.73555946], [88.90055847, 21.73555946], [88.89971924, 21.73639107], [88.89943695, 21.73639107], [88.89833069, 21.73750114], [88.89805603, 21.73750114], [88.89749908, 21.73806953], [88.8972168, 21.73806953], [88.89666748, 21.73861122], [88.89639282, 21.73861122], [88.89583588, 21.73917007], [88.89555359, 21.73916435], [88.89499664, 21.7397213], [88.89472198, 21.73971939], [88.89417267, 21.74028015], [88.89389038, 21.74027824], [88.89360809, 21.74055672], [88.89333344, 21.74055672], [88.89277649, 21.74111176], [88.89250183, 21.74110985], [88.89193726, 21.74167061], [88.89167023, 21.7416687], [88.89111328, 21.74222183], [88.89083099, 21.74221992], [88.89055634, 21.74250031], [88.89026642, 21.74250031], [88.88999939, 21.74278069], [88.88972473, 21.74277878], [88.88916779, 21.74333382], [88.88889313, 21.74332809], [88.88861084, 21.74361038], [88.88833618, 21.74361038], [88.88805389, 21.74389076], [88.88777924, 21.74388123], [88.88749695, 21.74416924], [88.88722229, 21.74416733], [88.88666534, 21.74472237], [88.88639069, 21.74472046], [88.8861084, 21.74500084], [88.88582611, 21.74500084], [88.88527679, 21.7455616], [88.88471985, 21.74555588], [88.88444519, 21.74583244], [88.88388824, 21.74582863], [88.88360596, 21.74611092], [88.88305664, 21.74611092], [88.88277435, 21.74638939], [88.88222504, 21.74638939], [88.8813858, 21.7472229], [88.88111115, 21.7472229], [88.88027954, 21.74805641], [88.88027954, 21.74833107], [88.87944794, 21.7491703], [88.87944794, 21.75055313], [88.87917328, 21.7508297], [88.8797226, 21.75139046], [88.8797226, 21.75305748], [88.87944794, 21.75333595], [88.87944794, 21.75485039], [88.87944794, 21.75499725], [88.87931824, 21.75512886], [88.87916565, 21.75527763], [88.87916565, 21.7554512], [88.87917328, 21.75722122], [88.87889099, 21.75749969], [88.87889099, 21.75777817], [88.87916565, 21.75777817], [88.87917328, 21.75861168], [88.87889099, 21.75889015], [88.87889099, 21.75944519], [88.8786087, 21.75972176], [88.87861633, 21.76083183], [88.87832642, 21.76111031], [88.87833405, 21.76194382], [88.87805176, 21.76222038], [88.87805176, 21.76278114], [88.8777771, 21.76305962], [88.8777771, 21.76416588], [88.87750244, 21.76444435], [88.87750244, 21.76472092], [88.87722015, 21.76501083], [88.87722015, 21.76527977], [88.8769455, 21.76555443], [88.8769455, 21.7658329], [88.87626648, 21.76721573], [88.8758316, 21.76789284], [88.87526703, 21.76872063], [88.87484741, 21.76913071], [88.8730545, 21.77054787], [88.87262726, 21.77081108], [88.87166595, 21.77139091], [88.8713913, 21.77193069], [88.86972046, 21.77306175], [88.86916351, 21.77319145], [88.86888885, 21.7733326], [88.86860657, 21.77352905], [88.86805725, 21.77388954], [88.86776733, 21.77388954], [88.86750031, 21.77417946], [88.86722565, 21.77443504], [88.86694336, 21.77444458], [88.86659241, 21.77471352], [88.86624908, 21.77499008], [88.86611176, 21.7751255], [88.86569214, 21.77540016], [88.86534882, 21.77547073], [88.86458588, 21.7761097], [88.86416626, 21.77667046], [88.8638916, 21.77666664], [88.86332703, 21.77721977], [88.86332703, 21.77750015], [88.86349487, 21.77766037], [88.86361694, 21.77778053], [88.86416626, 21.77778053], [88.86444092, 21.77806091], [88.86472321, 21.77805328], [88.86499786, 21.77832985], [88.86499786, 21.77861023], [88.86444092, 21.77917099], [88.86416626, 21.77917099], [88.86361694, 21.77861023], [88.86305237, 21.77861023], [88.86250305, 21.77806091], [88.86222076, 21.77806091], [88.86193848, 21.77791214], [88.86083221, 21.77811241], [88.86054993, 21.77832031], [88.86042023, 21.77845955], [88.8601532, 21.77867126], [88.85978699, 21.77873993], [88.85943604, 21.77861023], [88.85888672, 21.77874947], [88.85832977, 21.77889061], [88.85778046, 21.77889061], [88.85749054, 21.77917099], [88.85639191, 21.77916527], [88.85610962, 21.77944374], [88.85555267, 21.77944374], [88.85527802, 21.77972221], [88.85250092, 21.77972221], [88.85221863, 21.78000069], [88.84972382, 21.78000069], [88.84944153, 21.77972221], [88.84916687, 21.77972221], [88.84889221, 21.77944374], [88.84777832, 21.77944374], [88.84750366, 21.77972221], [88.84471893, 21.77972221], [88.84444427, 21.78000069], [88.8440094, 21.77956772], [88.84388733, 21.77944374], [88.84388733, 21.77916527], [88.84305573, 21.77916527], [88.84278107, 21.77944374], [88.84222412, 21.77944374], [88.84194183, 21.77972221], [88.84111023, 21.77972221], [88.84083557, 21.78000069], [88.83972168, 21.77999115], [88.83944702, 21.78028107], [88.83889008, 21.78028107], [88.83860779, 21.78055954], [88.83777618, 21.78055763], [88.83750153, 21.7808342], [88.83638, 21.78083038], [88.83611298, 21.78111076], [88.83555603, 21.78111076], [88.83499908, 21.78166771], [88.83499908, 21.78360748], [88.83528137, 21.78388977], [88.83528137, 21.78444481], [88.83555603, 21.78471756], [88.83555603, 21.78527832], [88.83583069, 21.78555489], [88.83583069, 21.78583336], [88.83605957, 21.78606224], [88.83638, 21.7863903], [88.83638, 21.78667259], [88.83666992, 21.78695107], [88.83666992, 21.78778267], [88.83694458, 21.78805542], [88.83693695, 21.78833008], [88.83721924, 21.78861046], [88.83721924, 21.78889084], [88.83750153, 21.7891674], [88.83750153, 21.78944206], [88.83757782, 21.78952026], [88.83777618, 21.78972244], [88.83777618, 21.78982925], [88.83777618, 21.79000092], [88.83805847, 21.79027939], [88.83805847, 21.79055405], [88.83833313, 21.79083061], [88.83833313, 21.79111099], [88.83860779, 21.79138947], [88.83860779, 21.79166412], [88.83889008, 21.79194641], [88.83889008, 21.79333305], [88.8391571, 21.79360962], [88.83916473, 21.79444695], [88.83944702, 21.7947197], [88.83944702, 21.79555511], [88.83972168, 21.79582977], [88.83972168, 21.79805565], [88.83999634, 21.7983284], [88.83999634, 21.79861069], [88.84027863, 21.79888916], [88.84027863, 21.80000114], [88.84055328, 21.80027962], [88.84055328, 21.80249977], [88.8408432, 21.80278015], [88.8408432, 21.80528069], [88.84111023, 21.80555344], [88.84111023, 21.80722046], [88.84139252, 21.80750084], [88.84139252, 21.81278038], [88.84111023, 21.81305504], [88.84111023, 21.81333351], [88.84139252, 21.81361008], [88.84139252, 21.81528282], [88.84111023, 21.81555557], [88.84111023, 21.81611061], [88.84139252, 21.81611061], [88.84055328, 21.81694031], [88.84055328, 21.81777954], [88.84027863, 21.8180542], [88.84027863, 21.81833076], [88.84055328, 21.81861115], [88.84055328, 21.81916428], [88.84027863, 21.81944656], [88.84027863, 21.81972122], [88.84055328, 21.81999969], [88.84027863, 21.82027626], [88.84027863, 21.82110977], [88.83999634, 21.82139015], [88.83999634, 21.82195091], [88.84027863, 21.82222748], [88.84027863, 21.82305527], [88.83999634, 21.82332993], [88.83999634, 21.82500076], [88.83972168, 21.82527733], [88.83972168, 21.82582855], [88.83944702, 21.82611084], [88.83944702, 21.82638931], [88.83916473, 21.82666588], [88.83916473, 21.82722282], [88.83944702, 21.82722282], [88.83889008, 21.82777977], [88.83916473, 21.82805634], [88.8391571, 21.82860947], [88.83889008, 21.82888794], [88.83889008, 21.83110046], [88.83860779, 21.83138847], [88.83860779, 21.83194351], [88.83833313, 21.83222008], [88.83833313, 21.83361053], [88.83805847, 21.8338871], [88.83805847, 21.83444595], [88.83833313, 21.83444023], [88.83777618, 21.83500099], [88.83777618, 21.83555794], [88.83750153, 21.83583069], [88.83750153, 21.83777809], [88.83721924, 21.83805084], [88.83721924, 21.84139061], [88.83750153, 21.8416729], [88.83750153, 21.84250069], [88.83721924, 21.84250069], [88.83721924, 21.84305573], [88.83750153, 21.84333038], [88.83750153, 21.84389114], [88.83777618, 21.8441658], [88.83777618, 21.84444427], [88.83805847, 21.84472084], [88.83805847, 21.84555435], [88.83833313, 21.84583092], [88.83833313, 21.84638977], [88.83860779, 21.84666443], [88.83860779, 21.84721947], [88.83889008, 21.84749985], [88.83889008, 21.84805679], [88.83916473, 21.84833336], [88.8391571, 21.84860992], [88.83999634, 21.84944534], [88.83999634, 21.84971809], [88.84055328, 21.85028076], [88.8408432, 21.85028076], [88.84055328, 21.85055923], [88.84111023, 21.85111046], [88.84111023, 21.85139084], [88.84278107, 21.85305595], [88.84278107, 21.85333252], [88.84416962, 21.85472107], [88.84416962, 21.85499954], [88.84443665, 21.85527039], [88.84443665, 21.8555603], [88.84555054, 21.85667038], [88.84555054, 21.85695076], [88.84638977, 21.85778046], [88.84638977, 21.85806084], [88.84722137, 21.85889053], [88.84750366, 21.85888863], [88.84833527, 21.85972214], [88.84860992, 21.85972023], [88.85138702, 21.86250114], [88.85138702, 21.86277962], [88.85193634, 21.86333084], [88.85193634, 21.86361122], [88.85221863, 21.86388969], [88.85221863, 21.86416817], [88.85305786, 21.86499977], [88.85333252, 21.86499977], [88.85360718, 21.86528015], [88.85610962, 21.86528015]]], [[[88.94139099, 21.84722137], [88.9422226, 21.84638977], [88.9422226, 21.84610939], [88.94277954, 21.84555435], [88.94277954, 21.84527969], [88.94304657, 21.84500122], [88.94304657, 21.84472084], [88.94333649, 21.84444427], [88.94333649, 21.8441658], [88.9438858, 21.84361076], [88.9438858, 21.84333038], [88.94416809, 21.84305573], [88.94416809, 21.84278107], [88.94444275, 21.84250069], [88.94444275, 21.84222031], [88.94454193, 21.84212112], [88.94527435, 21.8413887], [88.94526672, 21.84111023], [88.94695282, 21.83945274], [88.94695282, 21.83917046], [88.94721985, 21.83889008], [88.94721985, 21.83832932], [88.94750214, 21.83805466], [88.94750214, 21.83777809], [88.94776917, 21.83749962], [88.94776917, 21.83723068], [88.94805908, 21.83694077], [88.94805908, 21.83638954], [88.94832611, 21.83611107], [88.94832611, 21.83527946], [88.9486084, 21.83500099], [88.9486084, 21.83444023], [88.94889069, 21.83416748], [88.94889069, 21.83361053], [88.94917297, 21.83333015], [88.94916534, 21.83277512], [88.94944763, 21.83250046], [88.94944763, 21.8319397], [88.94999695, 21.83138847], [88.94999695, 21.83082962], [88.95027924, 21.83055305], [88.95027924, 21.8302803], [88.95054626, 21.82999992], [88.95054626, 21.82944107], [88.95111084, 21.82888794], [88.95111084, 21.82860947], [88.95305634, 21.82666588], [88.95305634, 21.82638931], [88.95361328, 21.82582855], [88.95361328, 21.8255558], [88.9539032, 21.82529259], [88.95417023, 21.82529259], [88.95443726, 21.82500076], [88.95471954, 21.82500076], [88.95527649, 21.8244381], [88.95583344, 21.82444382], [88.95610809, 21.82416725], [88.95639038, 21.82416916], [88.95667267, 21.82389069], [88.95777893, 21.82389069], [88.95804596, 21.82361031], [88.95889282, 21.82361031], [88.95916748, 21.82333374], [88.95972443, 21.82333374], [88.95999908, 21.82305527], [88.96055603, 21.82305908], [88.96083069, 21.82278061], [88.9658432, 21.82278061], [88.96611023, 21.82250023], [88.97177887, 21.82250023], [88.97249603, 21.82250023], [88.97277832, 21.82278061], [88.97499847, 21.82278061], [88.97550964, 21.82226944], [88.97638702, 21.82138634], [88.97638702, 21.82110977], [88.97666931, 21.82083321], [88.97666931, 21.82055664], [88.97583008, 21.81972313], [88.97583008, 21.81916428], [88.97528076, 21.81861115], [88.97528076, 21.81814003], [88.97528076, 21.81694221], [88.97444153, 21.81611061], [88.97444153, 21.81472206], [88.97472382, 21.81444359], [88.97444153, 21.81416702], [88.97444153, 21.81389046], [88.97389221, 21.8133316], [88.97305298, 21.81333351], [88.97305298, 21.81295967], [88.97305298, 21.81277847], [88.9733429, 21.81250191], [88.97333527, 21.81194496], [88.97305298, 21.81166649], [88.97305298, 21.81082916], [88.97277832, 21.81055641], [88.97277832, 21.80971909], [88.97250366, 21.80944443], [88.97250366, 21.80916786], [88.97222137, 21.80888939], [88.97222137, 21.80861092], [88.97193909, 21.80833054], [88.97194672, 21.80722237], [88.97166443, 21.8069458], [88.97166443, 21.80527687], [88.97138977, 21.80500031], [88.97138977, 21.80445099], [88.97110748, 21.80416107], [88.97110748, 21.80388832], [88.97049713, 21.80327415], [88.97000122, 21.80277824], [88.96888733, 21.80277824], [88.96861267, 21.80305481], [88.96833038, 21.80305481], [88.96776581, 21.80362129], [88.96749878, 21.80389023], [88.96722412, 21.80388832], [88.96694183, 21.80416679], [88.96666718, 21.80416679], [88.96611023, 21.80472183], [88.96555328, 21.80471992], [88.96527863, 21.80500031], [88.96499634, 21.80500031], [88.96472168, 21.80528069], [88.96444702, 21.80527687], [88.96389008, 21.80583572], [88.96360779, 21.80583], [88.96305847, 21.80639076], [88.96250153, 21.80639076], [88.96221924, 21.80667114], [88.96166992, 21.80666542], [88.96138763, 21.8069458], [88.96083069, 21.8069458], [88.96055603, 21.80722237], [88.95833588, 21.80722046], [88.95804596, 21.80750084], [88.95639038, 21.80750084], [88.95610809, 21.80778122], [88.95555878, 21.80778122], [88.95527649, 21.80805969], [88.95417023, 21.80805969], [88.95410156, 21.80798721], [88.9539032, 21.80778122], [88.95361328, 21.80778122], [88.95333099, 21.80750084], [88.95305634, 21.80750084], [88.95276642, 21.80722046], [88.95249939, 21.80722237], [88.9513855, 21.80611038], [88.95111084, 21.80611038], [88.95083618, 21.80583], [88.95055389, 21.80583572], [88.95027924, 21.80555344], [88.94944763, 21.80556107], [88.94917297, 21.80528069], [88.9486084, 21.80528069], [88.94824219, 21.80490685], [88.94805908, 21.80471992], [88.94805908, 21.80416679], [88.94777679, 21.80388832], [88.94776917, 21.80360985], [88.94750214, 21.80333328], [88.94750214, 21.80305481], [88.94721985, 21.80277824], [88.94721985, 21.80249977], [88.94610596, 21.80138969], [88.94610596, 21.80112076], [88.94555664, 21.8005619], [88.94555664, 21.80027962], [88.94526672, 21.80000114], [88.94526672, 21.79943848], [88.94499969, 21.79916573], [88.94499969, 21.79888916], [88.94473267, 21.79861069], [88.94472504, 21.79833412], [88.94444275, 21.79805565], [88.94444275, 21.79777908], [88.9438858, 21.79721832], [88.9438858, 21.79694366], [88.94361115, 21.7966671], [88.94361115, 21.79639053], [88.94249725, 21.79528046], [88.94249725, 21.79499054], [88.9422226, 21.7947216], [88.94194794, 21.7947216], [88.9402771, 21.79305458], [88.9402771, 21.79222107], [88.94000244, 21.79194641], [88.94000244, 21.79166412], [88.93972015, 21.79138947], [88.93972015, 21.79000092], [88.93945313, 21.78972054], [88.9394455, 21.78944206], [88.93916321, 21.7891674], [88.93916321, 21.78889084], [88.93889618, 21.78861046], [88.93888855, 21.78777695], [88.93916321, 21.78750038], [88.93916321, 21.7863903], [88.93945313, 21.78611946], [88.93945313, 21.78554916], [88.93972015, 21.78527832], [88.93972015, 21.78499985], [88.93956757, 21.78432274], [88.93969727, 21.78389931], [88.93969727, 21.78375053], [88.93997192, 21.78306389], [88.94011688, 21.78278732], [88.94042206, 21.7823658], [88.94042206, 21.78249168], [88.9411087, 21.78222275], [88.94166565, 21.78166771], [88.9419632, 21.78166962], [88.94212341, 21.78150368], [88.94249725, 21.78111076], [88.94277954, 21.78111076], [88.94304657, 21.78083038], [88.94333649, 21.7808342], [88.94361115, 21.78055763], [88.9438858, 21.78055954], [88.94444275, 21.77999115], [88.94472504, 21.78000069], [88.94527435, 21.77944374], [88.94611359, 21.77944374], [88.94638824, 21.77916527], [88.94695282, 21.77917099], [88.94721985, 21.77889061], [88.94776917, 21.77889061], [88.94805908, 21.77861023], [88.94889069, 21.77861023], [88.94917297, 21.77832985], [88.94972229, 21.77833557], [88.94999695, 21.77805328], [88.95111084, 21.77806091], [88.95139313, 21.77778053], [88.9522171, 21.77778053], [88.95249939, 21.77750015], [88.95305634, 21.77750015], [88.95333099, 21.77721977], [88.95417023, 21.77722168], [88.95444489, 21.77694321], [88.95500183, 21.77695084], [88.95527649, 21.77667046], [88.95582581, 21.77667046], [88.95610809, 21.77639008], [88.95777893, 21.77639008], [88.95804596, 21.7761097], [88.95861053, 21.7761116], [88.95888519, 21.77583122], [88.95916748, 21.77583122], [88.95944214, 21.77555466], [88.95972443, 21.77555466], [88.95999908, 21.77527809], [88.95999908, 21.77499962], [88.96055603, 21.77444267], [88.96055603, 21.77416611], [88.96083069, 21.77388954], [88.96083069, 21.77361107], [88.96055603, 21.7733326], [88.96055603, 21.77277756], [88.95889282, 21.77111053], [88.95888519, 21.77083397], [88.95861053, 21.7705555], [88.95833588, 21.77055931], [88.95770264, 21.76992989], [88.95749664, 21.76972198], [88.95749664, 21.76944351], [88.95666504, 21.76861191], [88.95639038, 21.76861191], [88.95610809, 21.76833344], [88.95583344, 21.76833344], [88.95444489, 21.76694679], [88.95417023, 21.76694679], [88.95388794, 21.76666451], [88.95361328, 21.76667023], [88.95333099, 21.76638985], [88.95305634, 21.76638985], [88.95276642, 21.76610947], [88.95194244, 21.76611137], [88.95166779, 21.7658329], [88.9513855, 21.7658329], [88.95083618, 21.76527786], [88.95054626, 21.76527977], [88.9500885, 21.76481438], [88.94999695, 21.76472473], [88.94972229, 21.76472473], [88.94944763, 21.76444435], [88.94916534, 21.76444435], [88.94889069, 21.76416588], [88.94776917, 21.76416969], [88.94750214, 21.76389122], [88.94721985, 21.76389122], [88.94695282, 21.76416969], [88.9466629, 21.76416969], [88.94638824, 21.76389122], [88.94610596, 21.76389122], [88.9458313, 21.76416969], [88.94499969, 21.76416588], [88.94472504, 21.76444435], [88.94444275, 21.76444435], [88.94416809, 21.76472473], [88.94361115, 21.76472092], [88.94333649, 21.76501083], [88.9422226, 21.76501083], [88.9419632, 21.76527977], [88.94082642, 21.76527977], [88.94055176, 21.76556015], [88.93916321, 21.76555443], [88.93888855, 21.7658329], [88.93527985, 21.7658329], [88.93499756, 21.76555443], [88.9347229, 21.76555443], [88.93444824, 21.7658329], [88.93416595, 21.7658329], [88.9338913, 21.76611137], [88.93276978, 21.76610947], [88.93250275, 21.76638985], [88.9319458, 21.76638985], [88.93165588, 21.76667023], [88.92778015, 21.76666451], [88.92749786, 21.76694679], [88.92555237, 21.76694679], [88.92527771, 21.76666451], [88.92359924, 21.76667023], [88.92333221, 21.76638985], [88.92305756, 21.76638985], [88.9227829, 21.76610947], [88.92138672, 21.76611137], [88.92082977, 21.76555443], [88.92056274, 21.76556015], [88.91860962, 21.76361084], [88.91832733, 21.76361084], [88.91779327, 21.76305962], [88.91779327, 21.76250076], [88.91763306, 21.76234627], [88.91750336, 21.76222229], [88.91750336, 21.76166725], [88.91722107, 21.76139069], [88.91722107, 21.75889015], [88.91750336, 21.75861168], [88.91750336, 21.75722313], [88.91638947, 21.75611115], [88.91610718, 21.75611115], [88.91583252, 21.75582123], [88.91500092, 21.75583267], [88.91471863, 21.75555611], [88.91416931, 21.75555992], [88.91416931, 21.75611115], [88.91404724, 21.75623131], [88.91388702, 21.75638962], [88.91388702, 21.75666618], [88.91361237, 21.75694466], [88.91361237, 21.75722122], [88.91333008, 21.75749969], [88.91333008, 21.75777817], [88.91305542, 21.75805473], [88.91306305, 21.75861168], [88.91278076, 21.75889015], [88.91278076, 21.75944519], [88.91249847, 21.75972176], [88.91249847, 21.76000023], [88.91278076, 21.76028061], [88.91278076, 21.76111031], [88.91333008, 21.76167107], [88.91333008, 21.76194382], [88.91361237, 21.76222038], [88.91361237, 21.76250076], [88.91388702, 21.76278114], [88.91388702, 21.76305962], [88.91722107, 21.76638985], [88.91750336, 21.76638794], [88.91944122, 21.76833344], [88.91971588, 21.76832962], [88.92028046, 21.76889038], [88.92028046, 21.76916885], [88.92055511, 21.76944351], [88.92056274, 21.76971817], [88.92082977, 21.77000046], [88.92082977, 21.77028084], [88.92111206, 21.7705555], [88.92111206, 21.77082825], [88.92138672, 21.77111053], [88.92111206, 21.77139091], [88.92111206, 21.77194405], [88.92082977, 21.77222061], [88.92082977, 21.77277946], [88.92055511, 21.77305603], [88.92056274, 21.77361107], [88.91999817, 21.77416611], [88.91999817, 21.77472115], [88.91971588, 21.77499962], [88.91972351, 21.77527809], [88.91999817, 21.77555275], [88.91999817, 21.77639008], [88.92028046, 21.77666664], [88.92028046, 21.77722168], [88.92056274, 21.77750015], [88.92055511, 21.77805328], [88.92082977, 21.77832985], [88.92082977, 21.77861023], [88.92111206, 21.77889061], [88.92111206, 21.77916527], [88.92138672, 21.77944374], [88.92138672, 21.77999115], [88.92166901, 21.78028107], [88.92166901, 21.78055763], [88.92193604, 21.78083038], [88.92194366, 21.78166771], [88.92222595, 21.78194046], [88.92222595, 21.78250122], [88.92250061, 21.78277969], [88.92250061, 21.78333282], [88.92277527, 21.7836113], [88.9227829, 21.78388977], [88.92305756, 21.78416634], [88.92305756, 21.78471756], [88.92333221, 21.78499985], [88.92333221, 21.78555489], [88.92359924, 21.78583145], [88.92359924, 21.78611946], [88.92416382, 21.78666687], [88.92415619, 21.78722191], [88.92444611, 21.78750038], [88.92444611, 21.78889084], [88.92416382, 21.7891674], [88.92415619, 21.78944016], [88.92333221, 21.79027939], [88.92305756, 21.79027939], [88.9227829, 21.79055977], [88.92194366, 21.79055405], [88.92166901, 21.79083252], [88.92028046, 21.79083061], [88.91972351, 21.79138947], [88.91971588, 21.79193115], [88.92028046, 21.79249954], [88.92056274, 21.79249954], [88.92077637, 21.79272461], [88.92082977, 21.79277992], [88.92111206, 21.79277611], [88.92166901, 21.79333305], [88.92193604, 21.79333115], [88.92250061, 21.79389], [88.9227829, 21.79389], [88.92305756, 21.79417038], [88.92333221, 21.79417038], [88.92359924, 21.79445076], [88.92388916, 21.79444695], [88.92444611, 21.79500008], [88.92472076, 21.79500008], [88.92666626, 21.79694366], [88.92694092, 21.79693985], [88.92778015, 21.79777908], [88.92778015, 21.79805946], [88.92861176, 21.79888916], [88.92861176, 21.79916573], [88.92888641, 21.7994442], [88.92888641, 21.79972076], [88.9291687, 21.80000114], [88.9291687, 21.80112076], [88.92888641, 21.80138969], [88.92888641, 21.80194473], [88.92861176, 21.80221939], [88.92861176, 21.80277824], [88.9283371, 21.8030529], [88.9283371, 21.80528069], [88.92861176, 21.80555344], [88.92861176, 21.80583572], [88.92888641, 21.80583], [88.9291687, 21.80611038], [88.92944336, 21.80611038], [88.92973328, 21.80639076], [88.93026733, 21.80639076], [88.93055725, 21.80667114], [88.93083191, 21.80666542], [88.93138885, 21.80722237], [88.93165588, 21.80722046], [88.93305206, 21.80861092], [88.93305206, 21.80888939], [88.93333435, 21.80916786], [88.93332672, 21.80971909], [88.93360901, 21.80999947], [88.93360901, 21.81055641], [88.9338913, 21.81083298], [88.93360901, 21.81110764], [88.93360901, 21.81250191], [88.9338913, 21.81278038], [88.9338913, 21.81305504], [88.93416595, 21.81333351], [88.93416595, 21.81361008], [88.9347229, 21.81417274], [88.93583679, 21.81416702], [88.93611145, 21.81444359], [88.93694305, 21.81444359], [88.93722534, 21.81472206], [88.9375, 21.81472015], [88.9383316, 21.81555557], [88.9383316, 21.81583214], [88.93860626, 21.81610107], [88.93860626, 21.8163929], [88.93888855, 21.81666756], [88.93889618, 21.81694031], [88.9383316, 21.81750107], [88.9383316, 21.81777954], [88.93805695, 21.8180542], [88.93805695, 21.81833076], [88.93776703, 21.81861115], [88.93777466, 21.81888962], [88.93722534, 21.81944656], [88.93722534, 21.82083321], [88.9375, 21.82110977], [88.9375, 21.82139015], [88.93723297, 21.82167053], [88.93723297, 21.82195091], [88.93694305, 21.82222748], [88.93694305, 21.82250023], [88.93553925, 21.82389069], [88.93527985, 21.82389069], [88.93499756, 21.82416725], [88.93499756, 21.82444382], [88.9347229, 21.82444382], [88.93458557, 21.82430649], [88.93444824, 21.82416725], [88.93416595, 21.82416916], [88.9338913, 21.82389069], [88.93332672, 21.82389069], [88.93305206, 21.82361031], [88.93222046, 21.82361031], [88.9319458, 21.82389069], [88.93055725, 21.82389069], [88.93026733, 21.82361031], [88.93000031, 21.82361031], [88.92973328, 21.82332993], [88.92861176, 21.82332993], [88.9283371, 21.82361031], [88.92804718, 21.82361031], [88.92778015, 21.82332993], [88.92722321, 21.82332993], [88.92666626, 21.82389069], [88.9263916, 21.82389069], [88.9263916, 21.82416725], [88.92610931, 21.8244381], [88.92610931, 21.82611084], [88.92582703, 21.82638931], [88.92583466, 21.82805634], [88.92610931, 21.8283329], [88.92610931, 21.82971954], [88.92582703, 21.82999992], [88.92583466, 21.83055305], [88.92555237, 21.83082962], [88.92555237, 21.83139038], [88.92527771, 21.83167076], [88.92527771, 21.83278084], [88.92500305, 21.83306122], [88.92500305, 21.83416748], [88.92472076, 21.83444023], [88.92472076, 21.83527946], [88.92444611, 21.83555794], [88.92444611, 21.8358326], [88.92527771, 21.83583069], [88.92582703, 21.83638954], [88.92610931, 21.83638954], [88.9263916, 21.83666992], [88.92749786, 21.83666992], [88.92778015, 21.83638954], [88.92888641, 21.83638954], [88.9291687, 21.83611107], [88.93026733, 21.83611107], [88.93055725, 21.83638954], [88.93138885, 21.83638954], [88.93165588, 21.83666992], [88.93222046, 21.83666611], [88.93250275, 21.83694458], [88.9327774, 21.83694458], [88.93416595, 21.83833313], [88.93416595, 21.8386116], [88.93444824, 21.83889008], [88.93444824, 21.83944511], [88.9347229, 21.83972168], [88.9347229, 21.84305573], [88.93499756, 21.84333038], [88.93499756, 21.84500122], [88.93527985, 21.84527969], [88.93527985, 21.84556007], [88.9355545, 21.84555435], [88.93611145, 21.8461113], [88.9366684, 21.84610939], [88.93723297, 21.84667015], [88.9375, 21.84666443], [88.93777466, 21.84694672], [88.93916321, 21.84694672], [88.9394455, 21.84722137], [88.94139099, 21.84722137]]], [[[88.48487854, 21.83469009], [88.48543549, 21.83459473], [88.48597717, 21.83460808], [88.48651886, 21.83473969], [88.48705292, 21.83496284], [88.48763275, 21.83500099], [88.48823547, 21.83503532], [88.4884491, 21.83509064], [88.48877716, 21.83517265], [88.48928833, 21.83517265], [88.48976898, 21.83468246], [88.49012756, 21.83407211], [88.49045563, 21.83353043], [88.49063873, 21.83299065], [88.49079895, 21.83242989], [88.4908371, 21.83187103], [88.49088287, 21.83134079], [88.49106598, 21.83090973], [88.49121857, 21.83046341], [88.49111176, 21.8302784], [88.49138641, 21.8302803], [88.49138641, 21.82999992], [88.4916687, 21.82971954], [88.4916687, 21.82944489], [88.49222565, 21.82888794], [88.49223328, 21.82860947], [88.49250031, 21.82861137], [88.49305725, 21.82805634], [88.49333954, 21.82806015], [88.49415588, 21.82722282], [88.49416351, 21.82694435], [88.49500275, 21.82611084], [88.49500275, 21.82582855], [88.4952774, 21.8255558], [88.4952774, 21.82529259], [88.49555206, 21.82500076], [88.49594116, 21.8246212], [88.49582672, 21.8244381], [88.49777985, 21.82250023], [88.49777985, 21.82222748], [88.49804688, 21.82195091], [88.49804688, 21.82110977], [88.49833679, 21.82083321], [88.49833679, 21.82027626], [88.49888611, 21.81972122], [88.49888611, 21.81861115], [88.4991684, 21.81833076], [88.4991684, 21.81611061], [88.49972534, 21.81555557], [88.49973297, 21.81361008], [88.5, 21.81333351], [88.5, 21.81305504], [88.50026703, 21.81278038], [88.50026703, 21.81250191], [88.49973297, 21.81195259], [88.49973297, 21.81138992], [88.4992218, 21.81085968], [88.49884796, 21.8103199], [88.49836731, 21.80990028], [88.4978714, 21.80950356], [88.49742126, 21.80915833], [88.49701691, 21.80882072], [88.49668121, 21.8085022], [88.49636841, 21.80817986], [88.49608612, 21.80778122], [88.49582672, 21.80778122], [88.4952774, 21.80722046], [88.49500275, 21.80722237], [88.49472046, 21.8069458], [88.49388885, 21.8069458], [88.49301147, 21.80607224], [88.49277496, 21.80583572], [88.49277496, 21.80555344], [88.49194336, 21.80471992], [88.4916687, 21.80472183], [88.4916687, 21.80444336], [88.4908371, 21.80360985], [88.48999786, 21.80361176], [88.48962402, 21.80239296], [88.48910522, 21.80223083], [88.48862457, 21.80203438], [88.48819733, 21.80181122], [88.48782349, 21.801548], [88.48751068, 21.80116653], [88.48734283, 21.8006916], [88.48722076, 21.80055618], [88.48638916, 21.79972076], [88.48638916, 21.79916573], [88.48583221, 21.79861069], [88.48472595, 21.79861069], [88.48416901, 21.79880905], [88.48368073, 21.79888916], [88.48313141, 21.79902077], [88.48293304, 21.79915047], [88.48264313, 21.79929924], [88.48227692, 21.79953957], [88.48192596, 21.79985046], [88.48153687, 21.80010414], [88.48106384, 21.80025291], [88.48075867, 21.80026817], [88.48049927, 21.80027962], [88.47991943, 21.80023003], [88.47944641, 21.80003929], [88.47901917, 21.79993248], [88.47865295, 21.79976273], [88.47824097, 21.79968452], [88.47780609, 21.79949951], [88.47727203, 21.79940414], [88.47675323, 21.79924965], [88.47623444, 21.79932213], [88.47575378, 21.79942131], [88.47529602, 21.79945946], [88.47488403, 21.79956818], [88.47442627, 21.79969025], [88.47386932, 21.7997303], [88.47325897, 21.79977989], [88.47268677, 21.79996109], [88.47210693, 21.79999924], [88.47150421, 21.80000114], [88.47085571, 21.79999924], [88.47019196, 21.79996109], [88.4695282, 21.79976082], [88.46893311, 21.79972076], [88.46837616, 21.79972076], [88.46782684, 21.79973984], [88.4672699, 21.79985046], [88.46665192, 21.79997063], [88.46599579, 21.80000114], [88.46533203, 21.80000114], [88.46469879, 21.80000114], [88.46409607, 21.80002022], [88.46356964, 21.80013084], [88.4630661, 21.80027962], [88.46257782, 21.80046082], [88.46206665, 21.80051994], [88.4615097, 21.80044746], [88.46102905, 21.80052567], [88.4605484, 21.80055237], [88.46005249, 21.80059814], [88.45957184, 21.80079079], [88.45903778, 21.80089951], [88.4585495, 21.80111885], [88.45815277, 21.80133247], [88.45804596, 21.80138969], [88.45755005, 21.80166817], [88.45704651, 21.80195999], [88.45661163, 21.80230904], [88.45626068, 21.80273247], [88.45588684, 21.80312157], [88.45552063, 21.8035202], [88.45513153, 21.80389595], [88.45474243, 21.80426979], [88.45436859, 21.8046608], [88.45394135, 21.80499458], [88.45349884, 21.80530357], [88.45314026, 21.80566025], [88.45292664, 21.80608177], [88.45275879, 21.80644798], [88.45258331, 21.80675125], [88.45244598, 21.80708122], [88.45223999, 21.80736351], [88.45204163, 21.80768394], [88.45184326, 21.80802345], [88.45160675, 21.80833817], [88.45137787, 21.80867004], [88.45111847, 21.80898285], [88.45088196, 21.80931091], [88.45072174, 21.80970955], [88.45053101, 21.81011009], [88.45027161, 21.81051445], [88.44998169, 21.81095123], [88.44966888, 21.81142807], [88.44948578, 21.81200409], [88.44944763, 21.81262016], [88.44948578, 21.81318855], [88.44967651, 21.81368828], [88.44978333, 21.81423187], [88.45001221, 21.81472015], [88.45033264, 21.81513023], [88.45070648, 21.81544685], [88.45106506, 21.81578064], [88.45147705, 21.81611252], [88.45192719, 21.81648445], [88.45249939, 21.81638908], [88.45305634, 21.81694221], [88.45333099, 21.81694221], [88.45388794, 21.81722069], [88.45402527, 21.81735992], [88.45417023, 21.81750107], [88.45443726, 21.81750107], [88.45471954, 21.81777954], [88.45471954, 21.8180542], [88.45500183, 21.81833267], [88.45527649, 21.81833076], [88.45555878, 21.81861115], [88.45610809, 21.81861115], [88.45639038, 21.81888962], [88.45666504, 21.81888962], [88.45694733, 21.81916428], [88.45777893, 21.81916428], [88.45793915, 21.81932831], [88.45805359, 21.81944656], [88.45889282, 21.81944084], [88.45939636, 21.81973076], [88.45987701, 21.81987572], [88.46012878, 21.81995392], [88.46028137, 21.81999969], [88.46055603, 21.81999969], [88.46083069, 21.82028008], [88.46111298, 21.82027626], [88.46138763, 21.82055664], [88.46166992, 21.82055664], [88.46194458, 21.82083321], [88.46250153, 21.82083321], [88.46277618, 21.82111168], [88.46333313, 21.82110977], [88.46360779, 21.82139015], [88.46389008, 21.82139015], [88.4641571, 21.82167053], [88.46444702, 21.82167053], [88.46472168, 21.82195091], [88.46499634, 21.82195091], [88.46555328, 21.82250023], [88.46611023, 21.82250023], [88.46639252, 21.82278061], [88.46721649, 21.82278061], [88.46749878, 21.82305908], [88.46778107, 21.82305908], [88.46833038, 21.82361031], [88.46861267, 21.82361031], [88.46944427, 21.82444382], [88.46971893, 21.82444382], [88.47000122, 21.82472229], [88.47055817, 21.82471848], [88.47138977, 21.82555962], [88.47168732, 21.82611084], [88.4720459, 21.82642746], [88.47231293, 21.82679939], [88.47251892, 21.82719994], [88.47278595, 21.82755661], [88.47296906, 21.82798195], [88.47316742, 21.82834625], [88.4733429, 21.82860184], [88.47357941, 21.82884789], [88.47374725, 21.82917976], [88.47392273, 21.82957268], [88.47415161, 21.82992935], [88.47434235, 21.83031082], [88.47445679, 21.83073044], [88.47457886, 21.83114815], [88.47470856, 21.83159065], [88.474823, 21.83206177], [88.4750061, 21.83249092], [88.47531128, 21.83292007], [88.47572327, 21.83335114], [88.47614288, 21.83378029], [88.47663879, 21.83415031], [88.47712708, 21.83444023], [88.47761536, 21.83465958], [88.47808838, 21.83476448], [88.478508, 21.83493805], [88.4789505, 21.83499527], [88.47940063, 21.83503914], [88.47982788, 21.8352108], [88.48031616, 21.83536911], [88.48084259, 21.83547974], [88.4813385, 21.83529091], [88.48181915, 21.83512878], [88.48227692, 21.83502007], [88.48272705, 21.83500099], [88.48316193, 21.83498001], [88.4835434, 21.83490372], [88.48390961, 21.83475685], [88.48435211, 21.83472061], [88.48487854, 21.83469009]]], [[[88.59221649, 21.85000038], [88.59249878, 21.84971809], [88.59305573, 21.84972191], [88.59333038, 21.84944534], [88.59371948, 21.84958839], [88.59397888, 21.84922981], [88.59428406, 21.84893227], [88.59462738, 21.8486805], [88.59494019, 21.84839058], [88.59527588, 21.84805107], [88.59583282, 21.84805679], [88.59638977, 21.84749985], [88.5966568, 21.84749985], [88.59694672, 21.84778023], [88.59722137, 21.84778023], [88.59777832, 21.84721947], [88.59805298, 21.84722137], [88.59833527, 21.84694672], [88.59860992, 21.84694672], [88.59889221, 21.84666443], [88.60056305, 21.84667015], [88.60083008, 21.84638977], [88.60111237, 21.84638977], [88.60166168, 21.84583092], [88.60194397, 21.84583282], [88.60219574, 21.84557724], [88.60277557, 21.84499931], [88.6027832, 21.84473991], [88.60333252, 21.84416962], [88.60333252, 21.84389114], [88.60360718, 21.84361076], [88.60360718, 21.84305954], [88.60388947, 21.84278107], [88.60388947, 21.84194183], [88.60416412, 21.84166718], [88.60415649, 21.84139061], [88.60388947, 21.84111023], [88.60388947, 21.83972168], [88.60416412, 21.83944511], [88.60415649, 21.83917046], [88.60388947, 21.83889008], [88.60388947, 21.83832932], [88.60416412, 21.83805466], [88.60416412, 21.83749962], [88.60444641, 21.83723068], [88.60444641, 21.83666992], [88.6047287, 21.83638954], [88.60472107, 21.83611107], [88.60500336, 21.8358326], [88.60500336, 21.83555794], [88.60582733, 21.83472061], [88.60610962, 21.83472252], [88.60639191, 21.83444595], [88.60666656, 21.83444595], [88.60694122, 21.83416748], [88.60721588, 21.83416939], [88.60832977, 21.83306122], [88.60861206, 21.83306122], [88.60888672, 21.83278084], [88.60943604, 21.83278084], [88.60972595, 21.83250046], [88.61055756, 21.83250046], [88.61083221, 21.83222008], [88.6111145, 21.83222198], [88.61138916, 21.83194351], [88.61250305, 21.83194351], [88.61277771, 21.83166695], [88.61332703, 21.83167076], [88.61360168, 21.83139038], [88.61416626, 21.83139038], [88.61424255, 21.83130264], [88.61487579, 21.83110046], [88.61550903, 21.83090019], [88.61614227, 21.83077049], [88.61670685, 21.83055115], [88.61724091, 21.83026123], [88.61754608, 21.82999992], [88.61771393, 21.82985115], [88.61804962, 21.82924461], [88.61824036, 21.82853889], [88.6180191, 21.82785034], [88.61750031, 21.82722282], [88.61750031, 21.82638931], [88.61723328, 21.82611084], [88.61694336, 21.82611084], [88.61608887, 21.82529259], [88.61550903, 21.82496071], [88.61493683, 21.82464027], [88.6144104, 21.82427025], [88.6138916, 21.8239212], [88.61376953, 21.82383156], [88.61344147, 21.8235817], [88.61302948, 21.82325935], [88.61257935, 21.82304001], [88.61218262, 21.82278824], [88.61173248, 21.82257271], [88.61125183, 21.82236099], [88.61075592, 21.82213974], [88.6103363, 21.8218708], [88.61000061, 21.82166862], [88.60943604, 21.82110977], [88.60944366, 21.82083321], [88.60916901, 21.82055664], [88.60916901, 21.82027626], [88.60861206, 21.81972122], [88.60861206, 21.81916428], [88.60805511, 21.81861115], [88.60805511, 21.81777763], [88.60778809, 21.81750107], [88.60778809, 21.81722069], [88.60765076, 21.81709099], [88.60749817, 21.81694221], [88.60749817, 21.81611061], [88.60722351, 21.81583214], [88.60722351, 21.81472206], [88.60749817, 21.81444359], [88.60749817, 21.81416702], [88.60806274, 21.81361008], [88.60805511, 21.81333351], [88.61027527, 21.81111145], [88.61055756, 21.81111145], [88.61222076, 21.80944443], [88.61222076, 21.80916786], [88.61250305, 21.80888939], [88.61250305, 21.80861092], [88.61277771, 21.80833054], [88.61277771, 21.8077755], [88.61305237, 21.80750084], [88.61305237, 21.80722046], [88.61309814, 21.80710602], [88.61326599, 21.80670166], [88.61332703, 21.80622292], [88.61334991, 21.80571175], [88.61342621, 21.80518341], [88.61360931, 21.80500031], [88.61360168, 21.80445099], [88.6138916, 21.80416107], [88.6138916, 21.80333328], [88.61416626, 21.80305481], [88.61416626, 21.80277824], [88.61444092, 21.80249977], [88.61444092, 21.80221939], [88.61472321, 21.80194473], [88.61472321, 21.80138969], [88.61444092, 21.80112076], [88.61444092, 21.80083275], [88.61416626, 21.80055618], [88.61416626, 21.80027962], [88.61472321, 21.79972076], [88.61472321, 21.7994442], [88.61416626, 21.79888916], [88.61416626, 21.79861069], [88.61416626, 21.79805946], [88.6138916, 21.79805565], [88.61360931, 21.79833412], [88.61333466, 21.79833412], [88.61305237, 21.79805565], [88.61277771, 21.79805946], [88.61250305, 21.79777908], [88.61194611, 21.79777718], [88.61138916, 21.79833412], [88.61120605, 21.79833412], [88.61055756, 21.79833412], [88.61000061, 21.79777718], [88.60943604, 21.79777908], [88.60916901, 21.79805946], [88.60749817, 21.79805946], [88.60721588, 21.79777908], [88.60666656, 21.79777908], [88.60629272, 21.79740524], [88.60610962, 21.79722214], [88.60527802, 21.79721832], [88.60500336, 21.79750061], [88.60277557, 21.79750061], [88.60250092, 21.79722214], [88.59722137, 21.79722214], [88.59694672, 21.79694366], [88.59666443, 21.79694366], [88.59638977, 21.7966671], [88.59555817, 21.79667091], [88.59527588, 21.79639053], [88.59500122, 21.79667091], [88.59471893, 21.7966671], [88.59444427, 21.79694366], [88.59388733, 21.79694366], [88.59361267, 21.79722214], [88.59333038, 21.79721832], [88.59333038, 21.79750061], [88.59139252, 21.79750061], [88.59111023, 21.79777908], [88.59055328, 21.79777908], [88.59027863, 21.79805946], [88.59004974, 21.79805183], [88.58945465, 21.79832458], [88.58888245, 21.79863739], [88.58840942, 21.7990303], [88.58807373, 21.7994175], [88.58772278, 21.79971123], [88.58735657, 21.79995728], [88.5869751, 21.80015945], [88.5866394, 21.80039978], [88.58628845, 21.80063057], [88.58591461, 21.80087662], [88.58557892, 21.80118942], [88.58526611, 21.80157089], [88.5849762, 21.80199051], [88.5847168, 21.8024807], [88.5844574, 21.80296135], [88.5842514, 21.80342102], [88.5841217, 21.80386162], [88.58390808, 21.80416107], [88.5837326, 21.80446815], [88.58360291, 21.80476189], [88.58345032, 21.80503082], [88.58332825, 21.80534554], [88.58320618, 21.80566978], [88.58307648, 21.80603027], [88.58297729, 21.80643272], [88.58277893, 21.8068428], [88.58257294, 21.80722046], [88.58238983, 21.80760956], [88.58221436, 21.80795288], [88.58201599, 21.80825996], [88.58184814, 21.8085804], [88.58159637, 21.80887032], [88.58126831, 21.80914116], [88.58088684, 21.80940056], [88.58056641, 21.80971909], [88.58032227, 21.81011009], [88.58010101, 21.81054688], [88.57984161, 21.81096458], [88.57950592, 21.81132317], [88.57910919, 21.81166458], [88.5786972, 21.81202126], [88.57834625, 21.81245041], [88.57804108, 21.81291962], [88.57775116, 21.81336975], [88.57749939, 21.81384087], [88.57727814, 21.81432724], [88.57714081, 21.81488037], [88.57692719, 21.81538963], [88.57665253, 21.81591034], [88.57634735, 21.81645966], [88.57604218, 21.81703377], [88.5761261, 21.81752014], [88.57628632, 21.81799126], [88.57633209, 21.81843758], [88.5761795, 21.81885338], [88.57611847, 21.8192997], [88.57611084, 21.81978989], [88.57611084, 21.8203125], [88.57614136, 21.82083893], [88.57628632, 21.82130051], [88.57641602, 21.82172012], [88.57659912, 21.82202911], [88.57671356, 21.82234573], [88.57686615, 21.82259941], [88.57699585, 21.82291985], [88.57717133, 21.82324982], [88.57727814, 21.82372093], [88.57750702, 21.82419968], [88.57774353, 21.82471848], [88.57785034, 21.82533073], [88.57794952, 21.82593918], [88.57814789, 21.82642174], [88.57830048, 21.82692337], [88.57836151, 21.82746124], [88.57852173, 21.82798958], [88.57859802, 21.82847023], [88.57865143, 21.82889557], [88.57879639, 21.82923126], [88.57887268, 21.8296051], [88.57888794, 21.83004951], [88.57892609, 21.83055115], [88.5790863, 21.83104324], [88.57923126, 21.83160591], [88.57933807, 21.83196068], [88.57940674, 21.83217812], [88.57949066, 21.83279419], [88.57968903, 21.83332062], [88.57980347, 21.83381081], [88.57993317, 21.83420181], [88.58000183, 21.83457756], [88.58010101, 21.83497047], [88.58026886, 21.83542633], [88.58044434, 21.83597374], [88.58061218, 21.83658981], [88.58080292, 21.83723068], [88.58087158, 21.83785057], [88.58102417, 21.83840561], [88.5811615, 21.83896637], [88.58139038, 21.83943939], [88.58165741, 21.83988953], [88.58190918, 21.8403492], [88.58211517, 21.84084129], [88.58229065, 21.84134102], [88.58250427, 21.84181786], [88.58272552, 21.84227943], [88.58292389, 21.84277344], [88.58317566, 21.84326363], [88.5835495, 21.84370995], [88.58389282, 21.84424019], [88.58423615, 21.84477997], [88.58460999, 21.84529114], [88.58495331, 21.84580612], [88.58525848, 21.84635162], [88.58561707, 21.84684944], [88.58605194, 21.84725952], [88.58646393, 21.8476944], [88.58690643, 21.84803009], [88.58726501, 21.8483963], [88.58753204, 21.84879112], [88.58782196, 21.84917068], [88.58815765, 21.84955025], [88.58853912, 21.8499527], [88.58907318, 21.8502903], [88.58956909, 21.85064125], [88.58992767, 21.8510704], [88.59027863, 21.8516674], [88.59055328, 21.85194397], [88.59139252, 21.85194397], [88.59166718, 21.85222244], [88.59194183, 21.85194397], [88.59194183, 21.8516674], [88.59221649, 21.85139084], [88.59194183, 21.85111046], [88.59249878, 21.85055923], [88.59249878, 21.85028076], [88.59221649, 21.85000038]]], [[[88.95532227, 21.84774971], [88.95571136, 21.84832954], [88.95632172, 21.8488903], [88.95670319, 21.84919167], [88.95744324, 21.84971046], [88.95794678, 21.85032082], [88.95859528, 21.85085678], [88.95910645, 21.85133362], [88.95952606, 21.85182953], [88.95983887, 21.85241508], [88.96009064, 21.85293961], [88.96042633, 21.85334015], [88.96082306, 21.85373116], [88.96124268, 21.8541832], [88.96169281, 21.85469055], [88.96217346, 21.85523987], [88.96260834, 21.85580826], [88.96302032, 21.85635757], [88.96338654, 21.85688972], [88.96376038, 21.85737038], [88.96411896, 21.85779953], [88.96444702, 21.8582077], [88.96477509, 21.85857391], [88.96511078, 21.85890961], [88.9654007, 21.85927773], [88.96573639, 21.85959053], [88.96605682, 21.8599205], [88.96640778, 21.86024094], [88.96683502, 21.86045265], [88.9671936, 21.8606739], [88.96751404, 21.86094284], [88.96788025, 21.86119843], [88.96829224, 21.86143112], [88.96869659, 21.86166954], [88.96911621, 21.86188126], [88.96961212, 21.86197281], [88.97006226, 21.86214066], [88.97046661, 21.86228943], [88.97083282, 21.86251068], [88.97121429, 21.86259651], [88.97169495, 21.86282349], [88.97232819, 21.86276627], [88.97312164, 21.86301041], [88.97338104, 21.86322975], [88.97377777, 21.86349106], [88.97433472, 21.86363792], [88.974823, 21.86386108], [88.97531891, 21.86411285], [88.97583771, 21.86431885], [88.97635651, 21.86450958], [88.97686005, 21.86473083], [88.97730255, 21.86499023], [88.97772217, 21.86523819], [88.97805023, 21.8655529], [88.97830963, 21.86589813], [88.97847748, 21.8663311], [88.97870636, 21.86668968], [88.97891235, 21.8670826], [88.97912598, 21.86744118], [88.97927856, 21.8678894], [88.97944641, 21.86835098], [88.97964478, 21.86884117], [88.97967529, 21.86936188], [88.97950745, 21.86988449], [88.97943115, 21.87043953], [88.97932434, 21.87094688], [88.97917175, 21.87138939], [88.97901154, 21.87181854], [88.97881317, 21.87220192], [88.97852325, 21.8725853], [88.97814178, 21.87297058], [88.97770691, 21.87339973], [88.97721863, 21.87389946], [88.97676086, 21.87445068], [88.97634125, 21.87496948], [88.9759903, 21.87542915], [88.97577667, 21.8758831], [88.97547913, 21.87621117], [88.97524261, 21.8765564], [88.97528076, 21.87685204], [88.97518921, 21.87713051], [88.97490692, 21.87746048], [88.9746933, 21.87787056], [88.97471619, 21.87829018], [88.97471619, 21.87873077], [88.97460175, 21.87916565], [88.97442627, 21.87962151], [88.97418213, 21.8800602], [88.97400665, 21.8805542], [88.97383118, 21.88104057], [88.97360229, 21.88149071], [88.9733429, 21.8819294], [88.9731369, 21.88241959], [88.97299957, 21.88293839], [88.97277069, 21.88336754], [88.97249603, 21.88377953], [88.97224426, 21.88416672], [88.97201538, 21.88457108], [88.97187042, 21.88504028], [88.97166443, 21.88549042], [88.97141266, 21.88591957], [88.97117615, 21.88636971], [88.9708786, 21.88674736], [88.97060394, 21.88715172], [88.97035217, 21.88754463], [88.9702301, 21.88804054], [88.97001648, 21.88842964], [88.96983337, 21.88882065], [88.96968842, 21.88924026], [88.96948242, 21.8896904], [88.96930695, 21.89019012], [88.96938324, 21.89075089], [88.9696579, 21.89125061], [88.97025299, 21.89153481], [88.97091675, 21.89179039], [88.97160339, 21.89198112], [88.97228241, 21.8920784], [88.97290039, 21.89224052], [88.97344208, 21.89245987], [88.97397614, 21.89254951], [88.97445679, 21.89273071], [88.97496796, 21.89281082], [88.97543335, 21.89294434], [88.97590637, 21.89307022], [88.97644043, 21.89323807], [88.97667694, 21.89321136], [88.97701263, 21.89325905], [88.97737885, 21.89346695], [88.97789001, 21.89347267], [88.97849274, 21.89344025], [88.97905731, 21.89348984], [88.97928619, 21.89338875], [88.97956848, 21.89325905], [88.98005676, 21.89312172], [88.98057556, 21.89307213], [88.98110199, 21.89304543], [88.98161316, 21.89295959], [88.98200989, 21.89277267], [88.98236847, 21.89256859], [88.98274231, 21.89246941], [88.98311615, 21.89240074], [88.98348236, 21.89233208], [88.98384857, 21.89219856], [88.98420715, 21.8920002], [88.98461151, 21.89179993], [88.98503876, 21.89158821], [88.98547363, 21.89138985], [88.98590851, 21.89118576], [88.98636627, 21.89103127], [88.98677826, 21.89082909], [88.98717499, 21.89061737], [88.98755646, 21.8903904], [88.98797607, 21.89018059], [88.98840332, 21.88995934], [88.98883057, 21.88972092], [88.9892807, 21.88948059], [88.98972321, 21.88927078], [88.99019623, 21.88908005], [88.99064636, 21.88887024], [88.99106598, 21.8886528], [88.99151611, 21.8884697], [88.99195099, 21.88829422], [88.99234772, 21.88805199], [88.99275208, 21.88779831], [88.99317932, 21.88752937], [88.99362946, 21.88726997], [88.99411011, 21.88703918], [88.99459839, 21.88684273], [88.99508667, 21.88664055], [88.99559021, 21.88640022], [88.99610138, 21.88614082], [88.99662018, 21.88587761], [88.99720764, 21.88557053], [88.99794769, 21.88524628], [88.99973297, 21.88360977], [89.0, 21.88389015], [89.00150299, 21.88322067], [89.0018692, 21.88302994], [89.00222015, 21.88278961], [89.00260925, 21.88261032], [89.00296783, 21.88234138], [89.00375366, 21.88199425], [89.00424957, 21.88174248], [89.0044632, 21.88157463], [89.00492096, 21.88134575], [89.00538635, 21.88101006], [89.0059433, 21.88088989], [89.00634003, 21.88062286], [89.00682831, 21.88044739], [89.00786591, 21.88004112], [89.00847626, 21.87976074], [89.00911713, 21.87968063], [89.00952148, 21.87920952], [89.01007843, 21.8788166], [89.01056671, 21.87854958], [89.01117706, 21.87825012], [89.01163483, 21.87790871], [89.01210785, 21.87759972], [89.01268005, 21.87742043], [89.01304626, 21.87719345], [89.01357269, 21.8769207], [89.01390076, 21.87677956], [89.01441193, 21.87669182], [89.01477051, 21.87627029], [89.01515961, 21.8759594], [89.01555634, 21.87569046], [89.01597595, 21.87541962], [89.01641083, 21.87516785], [89.01686096, 21.87494087], [89.01728058, 21.87465096], [89.01764679, 21.87431908], [89.01802826, 21.87403107], [89.01838684, 21.87376404], [89.01879883, 21.87354279], [89.01920319, 21.87328529], [89.01965332, 21.87305069], [89.02009583, 21.87276077], [89.02052307, 21.87240028], [89.0209198, 21.87203789], [89.02133942, 21.87174034], [89.02173615, 21.8714695], [89.02216339, 21.87125015], [89.02250671, 21.87100983], [89.02288055, 21.87074089], [89.02329254, 21.87043953], [89.02371979, 21.87009048], [89.02419281, 21.86978531], [89.02466583, 21.86948967], [89.02511597, 21.86918449], [89.02555847, 21.86889076], [89.02601624, 21.86858749], [89.02643585, 21.86824989], [89.02680969, 21.86782837], [89.02720642, 21.86741829], [89.02761078, 21.86702347], [89.02806091, 21.86665916], [89.02849579, 21.86629105], [89.02889252, 21.86584282], [89.02923584, 21.86537743], [89.02960205, 21.8649292], [89.029953, 21.86444473], [89.03032684, 21.86392212], [89.03051758, 21.86353493], [89.03070068, 21.86320496], [89.03096008, 21.86278152], [89.03092957, 21.86232185], [89.03098297, 21.86186981], [89.03083801, 21.8612709], [89.03093719, 21.86095047], [89.03098297, 21.86008835], [89.0308609, 21.85951042], [89.03083038, 21.85900116], [89.03082275, 21.85855293], [89.03077698, 21.85808372], [89.03066254, 21.85756493], [89.03062439, 21.85695076], [89.03069305, 21.8563118], [89.03069305, 21.85577583], [89.03058624, 21.85520744], [89.03038025, 21.85478973], [89.03009796, 21.85422134], [89.02974701, 21.85369682], [89.02947235, 21.85309982], [89.02922821, 21.85242844], [89.02910614, 21.85172081], [89.02889252, 21.85108948], [89.02849579, 21.85066986], [89.02824402, 21.85038376], [89.02776337, 21.85019112], [89.02719116, 21.84999084], [89.02675629, 21.84968185], [89.02630615, 21.84950066], [89.02577972, 21.84941292], [89.02529907, 21.84922028], [89.02475739, 21.84921646], [89.02455902, 21.8492775], [89.02423096, 21.84938049], [89.02371979, 21.8494606], [89.02323914, 21.84955025], [89.02275085, 21.84968948], [89.0222168, 21.84978104], [89.02168274, 21.84992027], [89.02113342, 21.84997749], [89.02057648, 21.84999275], [89.0200119, 21.84999084], [89.01946259, 21.84999657], [89.0189209, 21.85001183], [89.01840973, 21.85006714], [89.01793671, 21.85019112], [89.01748657, 21.85020065], [89.01705933, 21.85009956], [89.01663208, 21.85011101], [89.01624298, 21.85023117], [89.01582336, 21.85031319], [89.01541901, 21.85041809], [89.01499176, 21.85052109], [89.01452637, 21.85055923], [89.01405334, 21.85058975], [89.01357269, 21.85066986], [89.01312256, 21.8508606], [89.01268005, 21.85110092], [89.01222229, 21.85131836], [89.01174927, 21.85152817], [89.01129913, 21.8517704], [89.01085663, 21.85206032], [89.01037598, 21.85239029], [89.00988007, 21.85277939], [89.00934601, 21.85320282], [89.00884247, 21.85370064], [89.00831604, 21.85420036], [89.00778198, 21.85472107], [89.0072403, 21.85522842], [89.00673676, 21.85576057], [89.00631714, 21.85634041], [89.00592041, 21.85690117], [89.00562286, 21.85748291], [89.00543976, 21.85808754], [89.00532532, 21.85869408], [89.00530243, 21.85926056], [89.00527954, 21.85978127], [89.00527954, 21.86024857], [89.00525665, 21.86070824], [89.00518036, 21.86119843], [89.00505829, 21.86172104], [89.00496674, 21.86225128], [89.00489044, 21.86271095], [89.00486755, 21.86312103], [89.00483704, 21.86346054], [89.00479126, 21.86378288], [89.00469971, 21.86408806], [89.00450897, 21.8644104], [89.00424957, 21.86478043], [89.00382996, 21.86523819], [89.00370026, 21.86544037], [89.00325775, 21.86577606], [89.00311279, 21.86591339], [89.00275421, 21.86611366], [89.00247192, 21.8663826], [89.00232697, 21.86664963], [89.00247192, 21.86692047], [89.00261688, 21.86698723], [89.00268555, 21.86712074], [89.00283051, 21.86732101], [89.00283051, 21.86745834], [89.00261688, 21.86758995], [89.00247192, 21.86773109], [89.0022583, 21.86786079], [89.00203705, 21.86786079], [89.0018158, 21.86779022], [89.00154114, 21.86766052], [89.00147247, 21.86738968], [89.00132751, 21.86732101], [89.00096893, 21.86738968], [89.0, 21.86805534], [88.99972534, 21.86833382], [88.99899292, 21.86876488], [88.99842072, 21.86930275], [88.9981308, 21.86982918], [88.99833679, 21.87055588], [88.99833679, 21.87083244], [88.9981308, 21.87105942], [88.99784851, 21.87117958], [88.99751282, 21.87122154], [88.99713135, 21.87124062], [88.99671173, 21.87124062], [88.99624634, 21.87122154], [88.99577332, 21.87117577], [88.99530792, 21.87104034], [88.99487305, 21.8708477], [88.99450684, 21.87058067], [88.9941864, 21.87029266], [88.99382782, 21.86998177], [88.99341583, 21.86963081], [88.99303436, 21.86918259], [88.99261475, 21.86874962], [88.99220276, 21.86836815], [88.99198151, 21.86784172], [88.99134064, 21.86771011], [88.99040985, 21.86803818], [88.99002075, 21.86806679], [88.98924255, 21.8681221], [88.98962402, 21.86779213], [88.99000549, 21.86747742], [88.99038696, 21.86720848], [88.99079132, 21.86700249], [88.99120331, 21.86683083], [88.99163055, 21.86675072], [88.99199677, 21.86683083], [88.9923172, 21.8670311], [88.99266815, 21.86728668], [88.99302673, 21.86761093], [88.99339294, 21.86798286], [88.99375153, 21.86835098], [88.99388885, 21.86833191], [88.9944458, 21.86888885], [88.9944458, 21.86944389], [88.99472046, 21.86944389], [88.99500275, 21.86972237], [88.9952774, 21.86972046], [88.99555206, 21.87000084], [88.99583435, 21.87000084], [88.99610901, 21.8702774], [88.99666595, 21.8702774], [88.9972229, 21.86972237], [88.9972229, 21.86944389], [88.99753571, 21.86903572], [88.99780273, 21.86865807], [88.99810791, 21.86826706], [88.99843597, 21.86792183], [88.99880981, 21.86766052], [88.99916077, 21.86750031], [88.99945068, 21.86743736], [89.0, 21.86720848], [89.00045013, 21.86692429], [89.00088501, 21.86652374], [89.00117493, 21.86608887], [89.00154114, 21.86568069], [89.00195313, 21.86531067], [89.00231171, 21.86493874], [89.00263214, 21.8645916], [89.00291443, 21.86424637], [89.00318909, 21.86370277], [89.00332642, 21.86335945], [89.00338745, 21.86289024], [89.003479, 21.86235046], [89.003479, 21.86194992], [89.00338745, 21.86169243], [89.00312042, 21.86140823], [89.0029068, 21.86107254], [89.00276184, 21.8608036], [89.00269318, 21.86026573], [89.00298309, 21.86005974], [89.00318909, 21.86006355], [89.00354767, 21.85972786], [89.00376129, 21.85931969], [89.00398254, 21.85878563], [89.00405121, 21.85804939], [89.00399017, 21.85750961], [89.00399017, 21.85696983], [89.00419617, 21.8567009], [89.00447845, 21.85623169], [89.00454712, 21.85610008], [89.00476837, 21.85563087], [89.00505066, 21.85522079], [89.00534058, 21.85495567], [89.0067749, 21.85347366], [89.00717163, 21.85322762], [89.0075531, 21.8529911], [89.00791931, 21.85275078], [89.00823212, 21.85248756], [89.00853729, 21.85220909], [89.00886536, 21.85193253], [89.00921631, 21.85164452], [89.00961304, 21.85136414], [89.01002502, 21.85105896], [89.01040649, 21.85071945], [89.01082611, 21.85040092], [89.01132965, 21.85019112], [89.01183319, 21.84993935], [89.01229858, 21.84966087], [89.01284027, 21.84939957], [89.0134201, 21.84917068], [89.01403809, 21.84910965], [89.01464081, 21.84900093], [89.01526642, 21.8488903], [89.01590729, 21.84879112], [89.01657867, 21.84877968], [89.01727295, 21.8486805], [89.01799774, 21.84863091], [89.01873016, 21.84861946], [89.01947021, 21.84860992], [89.02019501, 21.84861374], [89.02091217, 21.84860611], [89.02159119, 21.84857178], [89.02219391, 21.84846687], [89.0227356, 21.84831047], [89.02297211, 21.84822273], [89.02324677, 21.84811974], [89.02381897, 21.84803009], [89.02435303, 21.84787941], [89.02490997, 21.8477211], [89.02539825, 21.84749031], [89.02584076, 21.84720039], [89.02630615, 21.84687042], [89.02667236, 21.84667015], [89.02703094, 21.84646988], [89.02746582, 21.84626961], [89.02774811, 21.84585762], [89.02796173, 21.84565926], [89.02818298, 21.84519005], [89.02832031, 21.84478569], [89.02896881, 21.84437943], [89.02939606, 21.84404755], [89.02976227, 21.84364128], [89.0298996, 21.84310532], [89.03003693, 21.84263039], [89.03003693, 21.84176064], [89.02996826, 21.84115982], [89.0298233, 21.84062195], [89.0298233, 21.84008026], [89.02989197, 21.83987999], [89.02996826, 21.83926964], [89.02996826, 21.83819771], [89.0298233, 21.83773041], [89.02967834, 21.8373909], [89.02967834, 21.83704948], [89.0298233, 21.83665085], [89.0298233, 21.83625031], [89.02989197, 21.83577919], [89.029953, 21.83521843], [89.02999115, 21.83452988], [89.02976227, 21.83276558], [89.02939606, 21.83169937], [89.02915955, 21.83145142], [89.02890015, 21.83117676], [89.02864838, 21.83084106], [89.0284729, 21.83041], [89.02830505, 21.82993507], [89.02812195, 21.82946014], [89.02807617, 21.82886887], [89.02799225, 21.82871437], [89.02722931, 21.82736588], [89.02690125, 21.82685089], [89.02651978, 21.82636642], [89.02617645, 21.82588005], [89.02588654, 21.82537079], [89.02558136, 21.82489967], [89.02529144, 21.82439995], [89.02501678, 21.82387543], [89.02471161, 21.82333755], [89.02433014, 21.82285118], [89.02384186, 21.82243919], [89.02339172, 21.82197952], [89.0230484, 21.82140923], [89.02276611, 21.82082939], [89.02239227, 21.82032013], [89.02202606, 21.81990051], [89.02175903, 21.81949997], [89.02147675, 21.81918907], [89.02120209, 21.81895065], [89.02098083, 21.81867981], [89.02072144, 21.81845856], [89.02050018, 21.81812096], [89.02024078, 21.81783295], [89.01993561, 21.81759453], [89.01952362, 21.81742668], [89.01917267, 21.81718826], [89.01885223, 21.81690788], [89.01850128, 21.81666946], [89.01815033, 21.81642914], [89.01782227, 21.81615067], [89.0174408, 21.81593323], [89.01701355, 21.81583214], [89.01660156, 21.8157444], [89.01638031, 21.81585312], [89.01570129, 21.81614304], [89.01507568, 21.81678009], [89.01480103, 21.81737328], [89.01449585, 21.81785011], [89.01418304, 21.81833076], [89.01384735, 21.8187809], [89.01351166, 21.81921005], [89.01313019, 21.81962967], [89.01272583, 21.82005119], [89.01232147, 21.82049561], [89.01194763, 21.82098389], [89.01143646, 21.82144165], [89.01093292, 21.82189941], [89.01027679, 21.82243156], [89.00982666, 21.82287216], [89.00932312, 21.82294464], [89.00907135, 21.82297707], [89.00923157, 21.82242966], [89.00971985, 21.82207108], [89.01043701, 21.82122993], [89.01101685, 21.82069969], [89.01159668, 21.82015991], [89.0118866, 21.81960678], [89.01243591, 21.81908035], [89.01283264, 21.81855011], [89.01332092, 21.81814003], [89.01358032, 21.81768227], [89.01383972, 21.81728745], [89.01410675, 21.81688118], [89.01451874, 21.8164196], [89.01452637, 21.81539917], [89.01426697, 21.81491852], [89.01389313, 21.81475067], [89.01343536, 21.81466675], [89.0129776, 21.81451988], [89.01246643, 21.8144207], [89.01197815, 21.8142395], [89.01148987, 21.81414223], [89.01104736, 21.81397629], [89.01061249, 21.81386948], [89.01022339, 21.81371117], [89.00981903, 21.8135891], [89.00948334, 21.81339073], [89.0091095, 21.81324959], [89.00881195, 21.81306267], [89.00846863, 21.81291962], [89.00794983, 21.81295013], [89.00733948, 21.81302071], [89.00666809, 21.81298065], [89.00652313, 21.81294823], [89.00596619, 21.81282043], [89.00525665, 21.81278038], [89.00457001, 21.81278038], [89.00390625, 21.81282043], [89.00331116, 21.81301117], [89.00300598, 21.81303978], [89.00274658, 21.81306267], [89.00226593, 21.81310081], [89.00189209, 21.81330109], [89.00144958, 21.81343079], [89.00099945, 21.81364059], [89.00055695, 21.81382179], [89.0, 21.81417274], [88.99968719, 21.81414986], [88.99938965, 21.8144207], [88.99906158, 21.81455994], [88.99872589, 21.81471062], [88.99861145, 21.81472015], [88.99833679, 21.81500053], [88.99694824, 21.81500053], [88.99666595, 21.81472015], [88.9952774, 21.81472206], [88.99500275, 21.81444359], [88.99472046, 21.81444359], [88.9944458, 21.81416702], [88.99415588, 21.81417274], [88.99307251, 21.81306267], [88.99307251, 21.81278038], [88.9927597, 21.81250191], [88.9927597, 21.81222153], [88.99222565, 21.81166649], [88.99223328, 21.81055832], [88.99194336, 21.81028938], [88.99194336, 21.80943108], [88.99194336, 21.80882072], [88.99194336, 21.80823708], [88.99194336, 21.80805969], [88.99194336, 21.80778122], [88.99223328, 21.80750084], [88.99222565, 21.80638885], [88.99250031, 21.80611038], [88.99194336, 21.80556107], [88.99194336, 21.80500984], [88.99194336, 21.80472183], [88.99222565, 21.80444336], [88.99223328, 21.8030529], [88.99194336, 21.80277824], [88.99188995, 21.80219078], [88.991745, 21.80177116], [88.99188995, 21.80125999], [88.99188232, 21.80079269], [88.99167633, 21.80044937], [88.99144745, 21.80014992], [88.99137878, 21.79981995], [88.99131775, 21.79950714], [88.9912262, 21.79920959], [88.9910965, 21.79891968], [88.99092102, 21.79867172], [88.99077606, 21.79841042], [88.99060822, 21.79816055], [88.99051666, 21.79783821], [88.99032593, 21.79758263], [88.99008179, 21.79735756], [88.98995209, 21.79707336], [88.98976898, 21.79680252], [88.98964691, 21.79645538], [88.98944092, 21.79609108], [88.98918915, 21.79566193], [88.98896027, 21.79512024], [88.98867798, 21.79450035], [88.98842621, 21.79388046], [88.98821259, 21.79328346], [88.98803711, 21.79271507], [88.98780823, 21.79222107], [88.98755646, 21.79174042], [88.9872818, 21.79131126], [88.98703766, 21.79086113], [88.986763, 21.79039192], [88.98647308, 21.78992271], [88.9861145, 21.78952026], [88.98578644, 21.7891407], [88.9855423, 21.78872108], [88.98535156, 21.7883091], [88.98527527, 21.78777695], [88.98500061, 21.78778267], [88.98387909, 21.78667259], [88.98361206, 21.78667259], [88.98194122, 21.78499985], [88.98166656, 21.78499985], [88.97888947, 21.78222084], [88.97861481, 21.78222275], [88.97718048, 21.78082657], [88.97704315, 21.78066254], [88.97693634, 21.78053474], [88.97676849, 21.78020096], [88.97654724, 21.77984047], [88.97635651, 21.77937126], [88.97609711, 21.7789402], [88.97576904, 21.77855873], [88.97541046, 21.77819061], [88.97506714, 21.77782249], [88.97492981, 21.77763367], [88.97476959, 21.77741051], [88.97450256, 21.77699089], [88.97413635, 21.77666283], [88.97376251, 21.77634811], [88.97341919, 21.77601051], [88.97297668, 21.77577019], [88.97251892, 21.7755909], [88.97212982, 21.77542114], [88.97174835, 21.77530098], [88.97136688, 21.77522087], [88.97093964, 21.77506256], [88.97049713, 21.77509117], [88.97000122, 21.77527809], [88.96971893, 21.77555466], [88.96858215, 21.77555466], [88.96805573, 21.77555466], [88.96749878, 21.7761097], [88.96749878, 21.77639008], [88.96694183, 21.77694321], [88.96694183, 21.77721977], [88.96673584, 21.77737045], [88.96665192, 21.77748871], [88.96652222, 21.77766037], [88.96630096, 21.77809143], [88.96602631, 21.77853012], [88.9656601, 21.77887535], [88.96521759, 21.77915955], [88.96475983, 21.77940559], [88.96427917, 21.77960968], [88.96380615, 21.77980995], [88.96337128, 21.78005981], [88.96296692, 21.78035736], [88.96255493, 21.78064346], [88.96219635, 21.78096581], [88.96185303, 21.78123093], [88.96160126, 21.78156281], [88.96127319, 21.78178024], [88.96092987, 21.78197861], [88.96060181, 21.7822113], [88.96022797, 21.78240013], [88.95980072, 21.78252983], [88.95941925, 21.78275108], [88.95897675, 21.78286171], [88.95861053, 21.78302765], [88.95818329, 21.78312111], [88.9577713, 21.78329659], [88.95729828, 21.78333092], [88.95681763, 21.78335571], [88.95640564, 21.7834816], [88.95606995, 21.78362083], [88.95581818, 21.78376961], [88.95556641, 21.78386116], [88.95527649, 21.78388977], [88.95489502, 21.78389168], [88.95440674, 21.78387451], [88.95381165, 21.78378487], [88.95313263, 21.78356171], [88.95241547, 21.78331757], [88.9517746, 21.78354263], [88.95143127, 21.78363991], [88.95111847, 21.78372955], [88.95050049, 21.78389931], [88.94988251, 21.7840538], [88.9491272, 21.78404427], [88.948349, 21.78413963], [88.94763947, 21.78416634], [88.94695282, 21.78419113], [88.94629669, 21.78429985], [88.94565582, 21.78423309], [88.94509125, 21.78440285], [88.94458008, 21.7844696], [88.9441452, 21.7845974], [88.94373322, 21.78473473], [88.94335175, 21.78494263], [88.9430542, 21.78525543], [88.94281769, 21.78560066], [88.94277954, 21.78603935], [88.94278717, 21.78650093], [88.94290924, 21.78695107], [88.94306946, 21.78741074], [88.94327545, 21.78787231], [88.94346619, 21.7883606], [88.94364166, 21.78886032], [88.94387817, 21.78928947], [88.94412994, 21.78970146], [88.94443512, 21.79008675], [88.94470978, 21.79051971], [88.94499969, 21.79101944], [88.94538116, 21.79148674], [88.94574738, 21.79193115], [88.9460907, 21.79237938], [88.94637299, 21.79282951], [88.94658661, 21.79328918], [88.94674683, 21.79379272], [88.94702911, 21.79421043], [88.94724274, 21.7946682], [88.94753265, 21.79509163], [88.9478302, 21.79552078], [88.94817352, 21.79594994], [88.94851685, 21.79640961], [88.94885254, 21.79691124], [88.94917297, 21.79741096], [88.94947052, 21.79788589], [88.94979095, 21.79835129], [88.94987488, 21.79847908], [88.95009613, 21.7988224], [88.95046997, 21.79923058], [88.95079803, 21.79969978], [88.95107269, 21.80022049], [88.95144653, 21.80059814], [88.95181274, 21.80092049], [88.952034, 21.8013401], [88.95230865, 21.80174065], [88.95266724, 21.80213928], [88.95304871, 21.80255508], [88.95344543, 21.80298996], [88.95392609, 21.80329514], [88.95450592, 21.80342102], [88.95511627, 21.80358124], [88.95574188, 21.80360985], [88.95635223, 21.80356979], [88.95691681, 21.80337906], [88.9574585, 21.80328941], [88.95792389, 21.80310822], [88.95839691, 21.80297279], [88.9588623, 21.80275917], [88.95926666, 21.8024807], [88.95966339, 21.80218315], [88.96009064, 21.80195045], [88.9605484, 21.8017807], [88.96102142, 21.80161095], [88.96148682, 21.80142975], [88.96199799, 21.80134964], [88.96246338, 21.80116081], [88.96290588, 21.80097961], [88.96334839, 21.80080986], [88.96357727, 21.80071068], [88.96379089, 21.80061913], [88.96425629, 21.80051041], [88.96472168, 21.80031204], [88.96518707, 21.80018616], [88.96557617, 21.80001068], [88.96595001, 21.79987717], [88.96630859, 21.79975128], [88.96669769, 21.79969978], [88.96711731, 21.79956818], [88.96749878, 21.7994709], [88.96788788, 21.79943848], [88.96829987, 21.79945946], [88.96870422, 21.79954338], [88.96903229, 21.79969025], [88.9693222, 21.79986763], [88.9696579, 21.79997826], [88.97001648, 21.80005836], [88.97033691, 21.80025101], [88.97075653, 21.80037117], [88.97130585, 21.80056953], [88.97157288, 21.80067825], [88.97200775, 21.8007412], [88.97261047, 21.8010006], [88.97303009, 21.80120087], [88.97331238, 21.80149078], [88.97372437, 21.80168724], [88.97410583, 21.80194283], [88.97450256, 21.80220604], [88.97467041, 21.80229378], [88.97490692, 21.80240822], [88.97523499, 21.80259514], [88.9754715, 21.80285645], [88.97561646, 21.80323029], [88.97585297, 21.80357742], [88.97611237, 21.80392075], [88.97634125, 21.80428505], [88.97641754, 21.80446815], [88.97650146, 21.80468941], [88.97663879, 21.80508995], [88.97667694, 21.80552864], [88.97668457, 21.80599213], [88.97675323, 21.80644226], [88.97690582, 21.8068428], [88.97696686, 21.80727386], [88.97709656, 21.80764389], [88.97720337, 21.80792046], [88.97723389, 21.80822182], [88.97730255, 21.80853081], [88.9774704, 21.80888939], [88.97753143, 21.80934334], [88.97769928, 21.80982971], [88.9777832, 21.81044006], [88.97782135, 21.81110764], [88.97798157, 21.81175041], [88.9779129, 21.81244278], [88.97805023, 21.81301117], [88.97821808, 21.81349945], [88.97838593, 21.81393623], [88.97860718, 21.8143425], [88.97877502, 21.8148098], [88.97882843, 21.81495094], [88.9789505, 21.81528282], [88.97911835, 21.81575966], [88.97933197, 21.81620026], [88.97946167, 21.81671906], [88.97962189, 21.81726456], [88.9797287, 21.81784248], [88.97984314, 21.81839943], [88.97985077, 21.81894875], [88.97975159, 21.81945038], [88.97969055, 21.81990051], [88.97950745, 21.82022095], [88.97950745, 21.82063103], [88.97950745, 21.82086182], [88.97956085, 21.82104111], [88.97930908, 21.82138062], [88.97904205, 21.82178116], [88.97888184, 21.82222557], [88.97851563, 21.82268333], [88.97820282, 21.8230896], [88.97786713, 21.82351112], [88.97750854, 21.82390022], [88.97717285, 21.82429123], [88.97683716, 21.82464981], [88.97651672, 21.82496643], [88.97625732, 21.82513046], [88.97612762, 21.82521057], [88.97577667, 21.82550049], [88.97537994, 21.82578278], [88.97493744, 21.82606888], [88.97441864, 21.82633209], [88.97384644, 21.82655144], [88.97322845, 21.82670021], [88.97267151, 21.82695007], [88.97212982, 21.82721519], [88.97155762, 21.82743263], [88.97088623, 21.82753944], [88.97019958, 21.82765579], [88.96948242, 21.8277607], [88.96875, 21.8277607], [88.96802521, 21.82765388], [88.96805573, 21.82749939], [88.96666718, 21.82749939], [88.96639252, 21.82722282], [88.9658432, 21.82722282], [88.96555328, 21.82749939], [88.9641571, 21.82749939], [88.96382904, 21.82730293], [88.96322632, 21.82716942], [88.962677, 21.8269825], [88.9621048, 21.82682228], [88.96154785, 21.82667351], [88.96100616, 21.82654572], [88.96050262, 21.8263607], [88.95999908, 21.82625008], [88.95957184, 21.8261795], [88.95915222, 21.82613373], [88.95872498, 21.82611275], [88.95833588, 21.82612801], [88.95800018, 21.82624054], [88.95771027, 21.82639694], [88.95744324, 21.82657051], [88.95713806, 21.82668114], [88.95684814, 21.82681274], [88.95654297, 21.82694817], [88.95623016, 21.82712364], [88.95596313, 21.82740974], [88.95575714, 21.82784271], [88.95553589, 21.82826996], [88.95527649, 21.82863998], [88.95502472, 21.82895088], [88.95479584, 21.82922173], [88.95465088, 21.82950974], [88.95446014, 21.82970619], [88.95424652, 21.82990074], [88.95410919, 21.83018684], [88.95392609, 21.83045387], [88.95378876, 21.83078003], [88.95360565, 21.83106995], [88.95339966, 21.83133125], [88.95323944, 21.83163071], [88.95302582, 21.83187103], [88.95281219, 21.83207703], [88.95265961, 21.83234024], [88.95250702, 21.83266068], [88.95240021, 21.83301926], [88.95223999, 21.83339119], [88.95214844, 21.83382034], [88.95195007, 21.83421326], [88.9517746, 21.8346138], [88.95158386, 21.83497238], [88.95140076, 21.83523941], [88.95111847, 21.83559036], [88.95089722, 21.83588409], [88.95072174, 21.83617973], [88.95052338, 21.83653069], [88.95033264, 21.83686066], [88.95027924, 21.83723068], [88.95027924, 21.83763885], [88.95028687, 21.8380909], [88.95036316, 21.8386116], [88.95037079, 21.83915138], [88.95035553, 21.83969116], [88.95056152, 21.84016991], [88.95083618, 21.84065056], [88.95108032, 21.84115791], [88.95124054, 21.84174156], [88.95155334, 21.8421917], [88.95191193, 21.84256172], [88.95215607, 21.8429966], [88.9523468, 21.84346008], [88.95256042, 21.84392929], [88.95285034, 21.84435081], [88.95324707, 21.84472084], [88.95368195, 21.84511185], [88.95397949, 21.84563065], [88.95436096, 21.84612465], [88.95472717, 21.84661102], [88.95507813, 21.84710121], [88.95532227, 21.84774971]]], [[[88.40484619, 21.79929924], [88.40450287, 21.79894829], [88.40413666, 21.79858971], [88.40379333, 21.79821014], [88.4034729, 21.79781151], [88.40320587, 21.79756355], [88.40292358, 21.79761505], [88.40257263, 21.7976799], [88.40220642, 21.79776955], [88.40187073, 21.7979393], [88.4015274, 21.79803085], [88.40158081, 21.79826546], [88.40170288, 21.79858971], [88.40190125, 21.79894829], [88.40196228, 21.79933929], [88.4020462, 21.79968071], [88.40219879, 21.80001068], [88.40222168, 21.80040932], [88.40222168, 21.80060959], [88.40222168, 21.80088425], [88.40219116, 21.80142975], [88.40200043, 21.80203438], [88.40194702, 21.80264282], [88.40194702, 21.80322075], [88.40194702, 21.80375099], [88.40196991, 21.80426979], [88.4020462, 21.80481911], [88.40213013, 21.80540276], [88.40202332, 21.80592918], [88.40190125, 21.80643272], [88.40172577, 21.8068428], [88.40164948, 21.80724716], [88.40154266, 21.807621], [88.40141296, 21.80800056], [88.40132141, 21.80838013], [88.40120697, 21.80875015], [88.40113068, 21.8091011], [88.40112305, 21.80944061], [88.4010849, 21.80978775], [88.40097046, 21.81013107], [88.40083313, 21.81054688], [88.40068817, 21.81097221], [88.40058136, 21.81147194], [88.40055847, 21.81199265], [88.40053558, 21.81249046], [88.40039825, 21.81290054], [88.40014648, 21.81323814], [88.40010834, 21.8136692], [88.40006256, 21.81405067], [88.39996338, 21.81436157], [88.39977264, 21.81459236], [88.39956665, 21.8148098], [88.39946747, 21.8151207], [88.39940643, 21.81550026], [88.39929962, 21.81589127], [88.3992157, 21.81633568], [88.39913177, 21.81682968], [88.39884186, 21.81729126], [88.39861298, 21.81779099], [88.39841461, 21.81827545], [88.39833832, 21.81875992], [88.39827728, 21.81918526], [88.39809418, 21.81947327], [88.39801025, 21.8198185], [88.39782715, 21.82012939], [88.39775085, 21.82048988], [88.39758301, 21.82078934], [88.3974762, 21.82113647], [88.39730072, 21.82143021], [88.39714813, 21.82172966], [88.3969574, 21.82203293], [88.39679718, 21.82236099], [88.39656067, 21.82262993], [88.39633942, 21.82289124], [88.39605713, 21.82308006], [88.39583588, 21.82329941], [88.39562225, 21.82353973], [88.395401, 21.82378578], [88.39523315, 21.82411194], [88.39504242, 21.82448959], [88.39495087, 21.82497978], [88.3947525, 21.82549095], [88.39463043, 21.82604027], [88.39447784, 21.82656097], [88.39438629, 21.8270607], [88.39421082, 21.82741928], [88.39412689, 21.82777977], [88.39395142, 21.82802963], [88.3939209, 21.82823753], [88.39390564, 21.8283329], [88.39386749, 21.828619], [88.39373016, 21.82884026], [88.39352417, 21.82903862], [88.39334106, 21.82940483], [88.39293671, 21.83118057], [88.39251709, 21.83260155], [88.39287567, 21.83454704], [88.39299774, 21.83588982], [88.39337158, 21.83770752], [88.3938446, 21.83872795], [88.39430237, 21.83972168], [88.39573669, 21.8422699], [88.39582062, 21.84328079], [88.3961792, 21.84468842], [88.39789581, 21.84879112], [88.39861298, 21.85000038], [88.39842987, 21.85066986], [88.39861298, 21.85110092], [88.39888, 21.85150528], [88.399086, 21.85196114], [88.39985657, 21.85329437], [88.40042877, 21.85551453], [88.40071869, 21.85679054], [88.40052795, 21.85843086], [88.40055847, 21.8588295], [88.40055084, 21.8592205], [88.40050507, 21.8596077], [88.40033722, 21.85997963], [88.40027618, 21.86041069], [88.40022278, 21.86083794], [88.40009308, 21.86124039], [88.40021515, 21.86163712], [88.40027618, 21.86198235], [88.40027618, 21.86234093], [88.4002533, 21.86275101], [88.40007782, 21.86317062], [88.39996338, 21.86370277], [88.39975739, 21.86424065], [88.39971924, 21.86478806], [88.39971924, 21.86531067], [88.39969635, 21.86577988], [88.39962006, 21.86622047], [88.39953613, 21.86667252], [88.39951324, 21.86715508], [88.3996582, 21.86770248], [88.39966583, 21.86828041], [88.39951324, 21.86885071], [88.39945984, 21.86940956], [88.39943695, 21.86989021], [88.39945984, 21.87034988], [88.39953613, 21.87082291], [88.39971924, 21.87135124], [88.39998627, 21.87194061], [88.39998627, 21.87249947], [88.40027618, 21.87277794], [88.40027618, 21.87292099], [88.40027618, 21.87306023], [88.40055847, 21.87334061], [88.40083313, 21.87333298], [88.40100861, 21.87350845], [88.40194702, 21.87444687], [88.40194702, 21.87472153], [88.40305328, 21.87583351], [88.40305328, 21.87611198], [88.40389252, 21.87694359], [88.40389252, 21.87722206], [88.40410614, 21.87742805], [88.40416718, 21.87805557], [88.40424347, 21.87808228], [88.4046402, 21.87822342], [88.4050293, 21.87854958], [88.40541077, 21.87888908], [88.4058075, 21.87924957], [88.40619659, 21.87964058], [88.40664673, 21.87997437], [88.40714264, 21.88027191], [88.40760803, 21.88055038], [88.40808105, 21.88083267], [88.40852356, 21.88113594], [88.4088974, 21.88148117], [88.40927887, 21.8818512], [88.409729, 21.88216972], [88.41021729, 21.88252068], [88.41072083, 21.88290596], [88.41118622, 21.88330269], [88.41168213, 21.88360023], [88.41218567, 21.88383675], [88.4127121, 21.8840313], [88.41318512, 21.88436127], [88.41366577, 21.88481331], [88.41414642, 21.88537216], [88.41475677, 21.88577461], [88.41529083, 21.88623238], [88.41591644, 21.8866291], [88.4162674, 21.88686943], [88.41674805, 21.88708305], [88.41713715, 21.88727951], [88.41744232, 21.88762093], [88.41777039, 21.88788033], [88.41806793, 21.88830948], [88.41835022, 21.88863182], [88.41860962, 21.88894844], [88.41884613, 21.88929939], [88.41902924, 21.88972092], [88.41918182, 21.89014053], [88.41938019, 21.8905201], [88.41950226, 21.89099121], [88.41970062, 21.89147186], [88.41983795, 21.89205742], [88.41998291, 21.89268112], [88.41999817, 21.89333153], [88.41996765, 21.89396095], [88.4197998, 21.8945446], [88.41972351, 21.89512444], [88.41964722, 21.8956604], [88.41945648, 21.89611053], [88.41929626, 21.89653778], [88.41913605, 21.89694023], [88.41890717, 21.89732933], [88.41876221, 21.89776993], [88.41863251, 21.89824295], [88.41860962, 21.89874077], [88.41860962, 21.89929581], [88.41860962, 21.8998909], [88.41857147, 21.90052795], [88.41849518, 21.90118408], [88.41872406, 21.90179443], [88.41880035, 21.90195847], [88.41900635, 21.90240288], [88.41941071, 21.90283966], [88.41982269, 21.90313911], [88.42043304, 21.90308952], [88.42063141, 21.90304184], [88.42105103, 21.90294266], [88.42175293, 21.90300179], [88.42243195, 21.90298271], [88.4229126, 21.90288734], [88.42327118, 21.90274048], [88.42375183, 21.90272141], [88.4239502, 21.90270042], [88.42449951, 21.90250015], [88.42485046, 21.90243912], [88.42549133, 21.9023819], [88.42563629, 21.9024601], [88.42708588, 21.9023819], [88.42809296, 21.90231514], [88.4285202, 21.90191269], [88.42959595, 21.90151024], [88.43052673, 21.9012394], [88.43123627, 21.90089989], [88.43281555, 21.90076637], [88.43333435, 21.90083313], [88.43360901, 21.9011116], [88.43444824, 21.9011097], [88.43458557, 21.90124893], [88.4347229, 21.90139008], [88.43499756, 21.90139008], [88.43527985, 21.90167046], [88.43583679, 21.90167046], [88.4366684, 21.90250015], [88.43694305, 21.90250015], [88.43753052, 21.90307236], [88.4380722, 21.90357018], [88.43859863, 21.90409088], [88.43906403, 21.90462685], [88.43948364, 21.90517426], [88.43994141, 21.90566063], [88.44034576, 21.90614128], [88.44091797, 21.90617371], [88.44149017, 21.90590477], [88.44246674, 21.90583229], [88.44297028, 21.90569878], [88.44342804, 21.90557289], [88.44384003, 21.90545082], [88.44419861, 21.90529823], [88.44457245, 21.90516281], [88.44499969, 21.9050312], [88.44546509, 21.90500069], [88.445961, 21.90498734], [88.4464798, 21.90492058], [88.4469986, 21.9047718], [88.44747925, 21.9048481], [88.44782257, 21.9048233], [88.44843292, 21.90487289], [88.44901276, 21.90485382], [88.44963074, 21.90479469], [88.45019531, 21.90463638], [88.45096588, 21.90479088], [88.45166779, 21.90489006], [88.45201874, 21.9048481], [88.45214081, 21.90467453], [88.4522171, 21.90441322], [88.4522934, 21.9041214], [88.45246124, 21.90387535], [88.45250702, 21.90354919], [88.45256805, 21.90319061], [88.45274353, 21.90284348], [88.45285797, 21.90242958], [88.45304108, 21.90193939], [88.45318604, 21.90145111], [88.45330048, 21.90094948], [88.45355225, 21.90060997], [88.45375061, 21.90029907], [88.45391083, 21.90003014], [88.45407104, 21.89978027], [88.45410919, 21.8994236], [88.45438385, 21.89916229], [88.45454407, 21.89883041], [88.45474243, 21.89847946], [88.45497131, 21.89813232], [88.45518494, 21.89770317], [88.45542145, 21.89722061], [88.45585632, 21.89690971], [88.45594788, 21.89637184], [88.45667267, 21.89594078], [88.4570694, 21.89537239], [88.45761871, 21.89499092], [88.45818329, 21.8946991], [88.4586792, 21.89443588], [88.45913696, 21.89420128], [88.45957947, 21.89398956], [88.46005249, 21.89382172], [88.46055603, 21.89364052], [88.46113586, 21.89356041], [88.46178436, 21.89353943], [88.46244049, 21.89345932], [88.46309662, 21.89331055], [88.46378326, 21.89323807], [88.46452332, 21.89328957], [88.4650116, 21.89301109], [88.46537018, 21.89266014], [88.46575928, 21.8924427], [88.46617889, 21.89233208], [88.46652985, 21.89223862], [88.46691132, 21.89217949], [88.46727753, 21.89198112], [88.46769714, 21.89196014], [88.46814728, 21.89208412], [88.46868896, 21.89234352], [88.46936035, 21.89233589], [88.47003937, 21.89215851], [88.47062683, 21.89211082], [88.47103882, 21.89193344], [88.47137451, 21.8916893], [88.47170258, 21.89145851], [88.47208405, 21.89133263], [88.47254944, 21.89130974], [88.47312164, 21.89137077], [88.47374725, 21.89134026], [88.47437286, 21.89110756], [88.47499084, 21.89082718], [88.47557831, 21.8905201], [88.47618103, 21.89028931], [88.47680664, 21.89022064], [88.47741699, 21.8902092], [88.4779129, 21.88999557], [88.47833252, 21.88972092], [88.47873688, 21.88944054], [88.47916412, 21.88917923], [88.47963715, 21.88895035], [88.48008728, 21.88863945], [88.48056793, 21.88834763], [88.48107147, 21.88812256], [88.48162079, 21.88802147], [88.48210907, 21.88781929], [88.48242188, 21.88734055], [88.48266602, 21.88676071], [88.48309326, 21.88637161], [88.48353577, 21.88591957], [88.48382568, 21.88525009], [88.48397064, 21.88450241], [88.48413849, 21.88381195], [88.48438263, 21.88311958], [88.48451233, 21.88246536], [88.48468781, 21.88189125], [88.48472595, 21.88167191], [88.48443604, 21.88138962], [88.48443604, 21.88083267], [88.48388672, 21.88027763], [88.48416901, 21.88027954], [88.48500061, 21.8794384], [88.48500061, 21.87888908], [88.48443604, 21.87832832], [88.48444366, 21.87694359], [88.48416901, 21.87666893], [88.48443604, 21.87667084], [88.48555756, 21.87556076], [88.4852829, 21.87528038], [88.4852829, 21.87388992], [88.48555756, 21.87360954], [88.48555756, 21.8730545], [88.4852829, 21.87277985], [88.4852829, 21.87222099], [88.48500061, 21.87194443], [88.48527527, 21.87194443], [88.4861145, 21.87111092], [88.48610687, 21.87026978], [88.48800659, 21.86458397], [88.4885788, 21.86162567], [88.48972321, 21.85826111], [88.49015045, 21.85638046], [88.49030304, 21.85396194], [88.49029541, 21.85180855], [88.49072266, 21.85032082], [88.49015045, 21.84804153], [88.48972321, 21.84656334], [88.48972321, 21.84454536], [88.489151, 21.84294128], [88.48943329, 21.84118271], [88.48916626, 21.83916664], [88.48916626, 21.83889008], [88.48880768, 21.83827972], [88.48847198, 21.83782959], [88.48809052, 21.83757401], [88.48768616, 21.83755875], [88.48748779, 21.83764458], [88.48728943, 21.83773041], [88.48690033, 21.83777809], [88.48649597, 21.83777809], [88.48606873, 21.83777809], [88.48554993, 21.83777809], [88.48497772, 21.83777809], [88.48441315, 21.83777809], [88.4838562, 21.83777809], [88.48339081, 21.83773041], [88.48295593, 21.83754349], [88.48246765, 21.83749962], [88.48194122, 21.83749962], [88.48137665, 21.83753967], [88.48085022, 21.83773041], [88.48029327, 21.83777809], [88.47972107, 21.83777809], [88.47917175, 21.83777809], [88.47862244, 21.83777809], [88.47809601, 21.83773994], [88.47763062, 21.83753014], [88.47714996, 21.8374176], [88.47675323, 21.83720016], [88.47637939, 21.83694458], [88.47600555, 21.83667946], [88.47560883, 21.83644104], [88.47518921, 21.83618927], [88.47476959, 21.83601761], [88.47438049, 21.83576012], [88.47416687, 21.83555794], [88.47305298, 21.83444023], [88.47305298, 21.83361053], [88.47277832, 21.83333015], [88.47277832, 21.8330574], [88.47249603, 21.83278084], [88.47194672, 21.83278084], [88.4716568, 21.83250046], [88.47083282, 21.83167076], [88.47083282, 21.83139038], [88.47000122, 21.83056068], [88.47000122, 21.8302803], [88.46971893, 21.8302803], [88.46943665, 21.82999992], [88.46971893, 21.82971954], [88.46944427, 21.82944489], [88.46916962, 21.82944489], [88.46805573, 21.8283329], [88.46778107, 21.82861137], [88.46749878, 21.8283329], [88.46749878, 21.82805634], [88.46778107, 21.82777977], [88.46694183, 21.82694244], [88.46666718, 21.82694435], [88.46639252, 21.82666588], [88.4658432, 21.82666969], [88.46579742, 21.82638931], [88.46546936, 21.82611084], [88.46513367, 21.82583427], [88.46476746, 21.82555389], [88.46450806, 21.82538414], [88.46437073, 21.8252964], [88.46386719, 21.82513046], [88.46333313, 21.82501984], [88.4631958, 21.82500458], [88.46276093, 21.8249588], [88.46222687, 21.8247509], [88.46166992, 21.82459068], [88.46113586, 21.8244381], [88.46064758, 21.82427025], [88.460289, 21.82416916], [88.4597168, 21.82416916], [88.45944214, 21.82389069], [88.45916748, 21.82389069], [88.45889282, 21.82361031], [88.45861053, 21.82361031], [88.45833588, 21.82332993], [88.45805359, 21.82333374], [88.45749664, 21.8227787], [88.45722961, 21.82278061], [88.45694733, 21.82250023], [88.45661163, 21.82250023], [88.45607758, 21.82232285], [88.45552063, 21.82217407], [88.45496368, 21.82196808], [88.45433807, 21.82180977], [88.45374298, 21.82149124], [88.45323181, 21.82102585], [88.45265961, 21.82074928], [88.45218658, 21.82053947], [88.45178986, 21.82024956], [88.45143127, 21.81990051], [88.45104218, 21.81952095], [88.45059204, 21.81919861], [88.4502182, 21.8188076], [88.44980621, 21.81851006], [88.44954681, 21.81814003], [88.44937897, 21.81772995], [88.44917297, 21.81735992], [88.44893646, 21.81699181], [88.44870758, 21.81661034], [88.44853973, 21.81615829], [88.44831848, 21.8157196], [88.44806671, 21.81528282], [88.44786835, 21.81478882], [88.44777679, 21.81418037], [88.44777679, 21.81400108], [88.44777679, 21.81351089], [88.44777679, 21.81282806], [88.44777679, 21.81217194], [88.44773102, 21.81157875], [88.44758606, 21.8110199], [88.44763184, 21.81040001], [88.44763947, 21.80969048], [88.4477005, 21.80900002], [88.44792938, 21.80841827], [88.44802094, 21.80781746], [88.4480896, 21.80732155], [88.44827271, 21.80698967], [88.44837189, 21.8066597], [88.44856262, 21.80640984], [88.44863892, 21.8060894], [88.44876862, 21.80581284], [88.44890594, 21.80553055], [88.44908905, 21.80529976], [88.44933319, 21.80508041], [88.44947052, 21.80474281], [88.44969177, 21.80444336], [88.4499588, 21.80416107], [88.45025635, 21.80386162], [88.45056152, 21.80356979], [88.45088196, 21.80328941], [88.45119476, 21.80306816], [88.45150757, 21.80285072], [88.45184326, 21.80260086], [88.45217896, 21.80227089], [88.45252991, 21.80192947], [88.45284271, 21.80157089], [88.45304108, 21.80117607], [88.45330048, 21.80088806], [88.45353699, 21.80057144], [88.45381927, 21.80029106], [88.45414734, 21.80005074], [88.45446777, 21.79975128], [88.45481873, 21.79945946], [88.45522308, 21.79919052], [88.45569611, 21.79896164], [88.45616913, 21.7986927], [88.45672607, 21.79857063], [88.45722961, 21.7983284], [88.45770264, 21.79805565], [88.45819855, 21.79776955], [88.45868683, 21.79744148], [88.45922852, 21.79715919], [88.45977783, 21.79693222], [88.46027374, 21.7966938], [88.46078491, 21.79656029], [88.46124268, 21.79636955], [88.46169281, 21.79615021], [88.46227264, 21.79609108], [88.46290588, 21.79603958], [88.46349335, 21.79582024], [88.46398926, 21.79550171], [88.46435547, 21.79504013], [88.46446991, 21.79437065], [88.46453094, 21.79371834], [88.4645462, 21.79311943], [88.46446991, 21.79257011], [88.46431732, 21.79207802], [88.46411133, 21.79161072], [88.46388245, 21.79114914], [88.46356201, 21.79071045], [88.46308136, 21.79036522], [88.46238708, 21.79013062], [88.46167755, 21.78985977], [88.4614563, 21.78981018], [88.4611969, 21.78993988], [88.46076965, 21.79009056], [88.46025848, 21.79033279], [88.4597168, 21.79063988], [88.45916748, 21.79101563], [88.45862579, 21.79144287], [88.45810699, 21.79187965], [88.45757294, 21.79225922], [88.45708466, 21.79263878], [88.45677185, 21.79288483], [88.45661163, 21.79301071], [88.45613098, 21.79336929], [88.45569611, 21.79375076], [88.45529938, 21.79418755], [88.45493317, 21.79463959], [88.45446777, 21.79504013], [88.45401764, 21.79542923], [88.45359039, 21.79582024], [88.45310211, 21.79617119], [88.45262909, 21.79652977], [88.45217133, 21.79688072], [88.45168304, 21.79721069], [88.45121002, 21.79756737], [88.45080566, 21.79801941], [88.45041656, 21.7984581], [88.44999695, 21.79887962], [88.44957733, 21.79926109], [88.4490509, 21.79965019], [88.44844055, 21.80000114], [88.44783783, 21.80035782], [88.44739532, 21.80067635], [88.44727325, 21.80076218], [88.44667053, 21.80110168], [88.44605255, 21.80139351], [88.44545746, 21.80166054], [88.44489288, 21.80187988], [88.44429779, 21.80198097], [88.44378662, 21.80218315], [88.44326019, 21.8022213], [88.44274139, 21.80221176], [88.44223022, 21.80212021], [88.44171906, 21.80200195], [88.44122314, 21.80195045], [88.44068909, 21.80188942], [88.44022369, 21.80167389], [88.43968964, 21.80145073], [88.43891907, 21.80138016], [88.43813324, 21.80132294], [88.43742371, 21.80117035], [88.43672943, 21.80112076], [88.43608093, 21.8010006], [88.43547821, 21.80072784], [88.43483734, 21.80064964], [88.43431091, 21.80050087], [88.43387604, 21.80027962], [88.43344879, 21.80008125], [88.43295288, 21.80001068], [88.43241119, 21.80002022], [88.4318924, 21.8000927], [88.43140411, 21.80021477], [88.43096924, 21.80031013], [88.43062592, 21.80048943], [88.43035889, 21.80070877], [88.43006134, 21.80090332], [88.4298172, 21.80113983], [88.42960358, 21.80143738], [88.42945862, 21.80179024], [88.42933655, 21.80220413], [88.42919159, 21.80265045], [88.42907715, 21.80311966], [88.42891693, 21.8035202], [88.42881775, 21.80389977], [88.4286499, 21.80418968], [88.42855072, 21.80450821], [88.42842865, 21.80482864], [88.42832184, 21.80520058], [88.42817688, 21.80559158], [88.42807007, 21.80603981], [88.42798615, 21.80653954], [88.42800903, 21.80707359], [88.42796326, 21.80755997], [88.42780304, 21.80796051], [88.42766571, 21.80832672], [88.42753601, 21.80867386], [88.42745972, 21.80903244], [88.42733765, 21.80934143], [88.42722321, 21.8096447], [88.42710114, 21.80997276], [88.42691803, 21.8103199], [88.42665863, 21.81070709], [88.42634583, 21.8111248], [88.42595673, 21.81151009], [88.42552185, 21.81184959], [88.42508698, 21.81212997], [88.42459106, 21.81231117], [88.42402649, 21.81240082], [88.42340851, 21.81241035], [88.42312622, 21.8123951], [88.4228363, 21.81238365], [88.42234802, 21.81234741], [88.42189789, 21.81235313], [88.42146301, 21.81235123], [88.42099762, 21.81236076], [88.42051697, 21.81235123], [88.4200058, 21.81225967], [88.41944122, 21.81216049], [88.41886139, 21.8119297], [88.4182663, 21.81161118], [88.41773224, 21.8111496], [88.41720581, 21.81070709], [88.4167099, 21.81028938], [88.41629791, 21.80982018], [88.41588593, 21.80941582], [88.4154892, 21.809021], [88.41508484, 21.80866241], [88.41474152, 21.80824089], [88.41442871, 21.80776024], [88.41409302, 21.80727959], [88.41372681, 21.80681038], [88.41335297, 21.80638695], [88.41300201, 21.80597115], [88.41261292, 21.80559158], [88.41215515, 21.80526924], [88.41168976, 21.80495071], [88.41126251, 21.80458069], [88.41085052, 21.80419922], [88.41040802, 21.80387688], [88.40997314, 21.80357742], [88.40956116, 21.80327988], [88.4091568, 21.80294991], [88.40874481, 21.80262756], [88.40834045, 21.8022995], [88.4079361, 21.80196953], [88.40751648, 21.80166054], [88.40710449, 21.80135155], [88.40670013, 21.8010006], [88.40631866, 21.80063057], [88.40592194, 21.80029106], [88.40554047, 21.79997063], [88.40518951, 21.79964066], [88.40484619, 21.79929924]]], [[[88.5199585, 21.85463715], [88.52054596, 21.85416985], [88.52083588, 21.85416985], [88.52139282, 21.8536129], [88.52166748, 21.8536129], [88.52194214, 21.8533287], [88.52222443, 21.85333252], [88.52249908, 21.85305595], [88.52278137, 21.85306168], [88.52500153, 21.85082817], [88.52500153, 21.85055542], [88.52583313, 21.84971809], [88.52583313, 21.84861183], [88.52610779, 21.84833336], [88.52610779, 21.84777832], [88.52638245, 21.84749985], [88.52638245, 21.84667015], [88.5266571, 21.84638977], [88.5266571, 21.84583092], [88.52639008, 21.84555435], [88.52638245, 21.84500122], [88.52694702, 21.84444046], [88.52694702, 21.84361076], [88.52722168, 21.84361076], [88.52749634, 21.84333038], [88.52722168, 21.84305573], [88.52722168, 21.84278107], [88.52749634, 21.84250069], [88.52749634, 21.84139061], [88.52777863, 21.84111023], [88.52777863, 21.83972168], [88.52694702, 21.83888817], [88.52694702, 21.8386116], [88.52666473, 21.83833313], [88.52666473, 21.83805466], [88.52639008, 21.83777809], [88.52638245, 21.83723068], [88.52610779, 21.83694077], [88.52610779, 21.83666611], [88.52583313, 21.83638954], [88.52583313, 21.83611107], [88.52568817, 21.83596611], [88.52500153, 21.83527565], [88.52443695, 21.83527946], [88.52416992, 21.83500099], [88.52305603, 21.83499718], [88.52304077, 21.83514214], [88.52272034, 21.83527946], [88.52238464, 21.83544731], [88.52199554, 21.83558273], [88.52159119, 21.83575058], [88.52115631, 21.83592033], [88.52072144, 21.83606529], [88.52025604, 21.83613968], [88.5197525, 21.83623123], [88.51912689, 21.83621025], [88.51876068, 21.83645058], [88.51830292, 21.83669281], [88.51777649, 21.83694077], [88.51694489, 21.83777809], [88.51694489, 21.83805466], [88.51667023, 21.83833313], [88.51667023, 21.8386116], [88.51583099, 21.83944511], [88.51583099, 21.84027863], [88.51599121, 21.84043884], [88.51611328, 21.84056282], [88.51638794, 21.84056282], [88.51693726, 21.84111023], [88.51694489, 21.84166718], [88.51750183, 21.84222221], [88.51750946, 21.84333038], [88.51805878, 21.84389114], [88.51972198, 21.84389114], [88.51991272, 21.84369659], [88.51999664, 21.84361076], [88.52222443, 21.84583282], [88.52222443, 21.8461113], [88.52138519, 21.84694672], [88.52166748, 21.84722137], [88.52166748, 21.84832954], [88.52083588, 21.84917068], [88.51889038, 21.84917068], [88.51847839, 21.84875298], [88.51805878, 21.84833336], [88.51750946, 21.8488903], [88.51750183, 21.84944534], [88.51721954, 21.84972191], [88.51750946, 21.85000038], [88.51750946, 21.85139084], [88.51777649, 21.8516674], [88.51777649, 21.85268021], [88.51777649, 21.8533287], [88.51805878, 21.8536129], [88.51805878, 21.85388947], [88.51833344, 21.85416603], [88.51833344, 21.8544445], [88.51860809, 21.85472107], [88.51895905, 21.85471535], [88.5194397, 21.85467148], [88.5199585, 21.85463715]]], [[[88.53800201, 21.85358238], [88.53713989, 21.85324669], [88.53656769, 21.8532505], [88.53649139, 21.8537178], [88.53813934, 21.85458946], [88.53885651, 21.85493279], [88.53929138, 21.85559845], [88.54020691, 21.8560009], [88.54057312, 21.85641098], [88.54129028, 21.85680962], [88.54161835, 21.85737991], [88.54180908, 21.85710526], [88.54190063, 21.85697174], [88.54172516, 21.85654068], [88.54143524, 21.85606956], [88.54079437, 21.85506248], [88.53978729, 21.85432243], [88.53855896, 21.85381317], [88.53800201, 21.85358238]]], [[[88.55944824, 21.82972145], [88.5597229, 21.82944489], [88.55999756, 21.82944489], [88.56027985, 21.82916641], [88.56027985, 21.82860947], [88.5605545, 21.8283329], [88.56027985, 21.82805634], [88.56027985, 21.82749939], [88.55999756, 21.82722282], [88.55999756, 21.82694435], [88.55986786, 21.82681274], [88.55916595, 21.82611084], [88.55860901, 21.82555962], [88.55860901, 21.82529259], [88.55805206, 21.82471848], [88.55802917, 21.82461548], [88.55780792, 21.82432175], [88.55755615, 21.82398224], [88.55722809, 21.82377434], [88.55683899, 21.82393074], [88.55664063, 21.8240242], [88.55648041, 21.82422829], [88.55632782, 21.82456017], [88.55615234, 21.82485962], [88.55600739, 21.82517052], [88.55583954, 21.82546043], [88.5557785, 21.82576942], [88.55610657, 21.82611084], [88.5561142, 21.82638931], [88.55666351, 21.82694435], [88.5569458, 21.82694244], [88.55750275, 21.82749939], [88.5577774, 21.82749939], [88.5578537, 21.82757568], [88.55860901, 21.8283329], [88.55860901, 21.82860947], [88.5588913, 21.82888985], [88.5588913, 21.82916641], [88.55916595, 21.82944489], [88.55916595, 21.82972145], [88.55944824, 21.82972145]]], [[[88.78916931, 21.87861061], [88.78943634, 21.87832832], [88.79027557, 21.87833405], [88.79055786, 21.87805557], [88.79083252, 21.87805939], [88.79139709, 21.87750053], [88.79138947, 21.87722206], [88.79166412, 21.87694359], [88.79166412, 21.87666893], [88.79194641, 21.87639809], [88.79194641, 21.87612915], [88.79218292, 21.8758812], [88.79219818, 21.87536049], [88.79222107, 21.8741684], [88.79250336, 21.87388992], [88.79222107, 21.87360954], [88.79222107, 21.8730545], [88.79194641, 21.87277985], [88.79194641, 21.87249947], [88.79110718, 21.87166977], [88.79083252, 21.87166977], [88.79064941, 21.87148476], [88.79027557, 21.87111092], [88.79000092, 21.87111092], [88.78971863, 21.87083054], [88.78944397, 21.87083244], [88.78888702, 21.8702774], [88.78861237, 21.8702774], [88.78778076, 21.86944389], [88.78749847, 21.86944389], [88.78694153, 21.86888885], [88.78666687, 21.86889076], [88.78610992, 21.86833191], [88.78610992, 21.86694527], [88.7858429, 21.86667252], [88.7858429, 21.86641121], [88.78583527, 21.86527824], [88.78594971, 21.8651638], [88.78722382, 21.86388969], [88.78749847, 21.86388969], [88.78778076, 21.86361122], [88.78833008, 21.86361122], [88.78861237, 21.86333084], [88.78943634, 21.86333084], [88.78971863, 21.86361122], [88.7902832, 21.86361122], [88.79055786, 21.86388969], [88.79083252, 21.86388969], [88.79110718, 21.86416817], [88.79139709, 21.86416817], [88.79360962, 21.86639023], [88.79360962, 21.86666679], [88.79416656, 21.86720848], [88.79416656, 21.86778069], [88.79444122, 21.86805534], [88.79444122, 21.86833191], [88.79499817, 21.86888885], [88.79499817, 21.86944389], [88.79528046, 21.86972046], [88.79528046, 21.87055588], [88.79555511, 21.87083244], [88.79556274, 21.87138939], [88.79582977, 21.87166405], [88.79582977, 21.87194443], [88.79611206, 21.87222099], [88.79611206, 21.87277985], [88.79666901, 21.87333298], [88.79666901, 21.87360954], [88.79693604, 21.87388992], [88.79693604, 21.8741703], [88.79722595, 21.87444687], [88.79722595, 21.87470055], [88.79750061, 21.875], [88.79750061, 21.87527847], [88.79833221, 21.87610817], [88.79833221, 21.87639809], [88.7986145, 21.87666893], [88.7986145, 21.87694359], [88.79888916, 21.87693977], [88.79944611, 21.87750053], [88.80005646, 21.87750053], [88.80055237, 21.87750053], [88.80055237, 21.87778091], [88.80064392, 21.87768745], [88.80082703, 21.87750053], [88.80082703, 21.87721825], [88.80055237, 21.87694359], [88.80055237, 21.87638664], [88.80027008, 21.87610817], [88.80027771, 21.87555695], [88.80000305, 21.87528038], [88.80000305, 21.87471962], [88.79972076, 21.87444687], [88.79972076, 21.87388992], [88.79944611, 21.87360954], [88.79944611, 21.8730545], [88.79915619, 21.87277985], [88.79915619, 21.87249947], [88.79888916, 21.87222099], [88.79888916, 21.87083244], [88.79916382, 21.87055588], [88.79915619, 21.87026978], [88.79972076, 21.86972237], [88.79972076, 21.86944389], [88.80027771, 21.86888885], [88.80055237, 21.86889076], [88.8013916, 21.86806107], [88.80166626, 21.86806107], [88.80194092, 21.86778069], [88.80249786, 21.86778069], [88.80304718, 21.86720848], [88.8033371, 21.86722183], [88.80361176, 21.86694527], [88.80444336, 21.8669529], [88.80473328, 21.86667252], [88.8069458, 21.86667252], [88.80722046, 21.8669529], [88.80833435, 21.86694527], [88.80851746, 21.86713028], [88.80860901, 21.86722183], [88.8088913, 21.86720848], [88.80916595, 21.86750031], [88.80944061, 21.86750031], [88.8097229, 21.86778069], [88.81027985, 21.86778069], [88.81054688, 21.86806107], [88.81083679, 21.86805534], [88.81100464, 21.8682251], [88.81111145, 21.86833382], [88.81138611, 21.86833191], [88.8116684, 21.86861038], [88.81194305, 21.86861038], [88.8125, 21.86917114], [88.81305695, 21.86916733], [88.8133316, 21.86944389], [88.81388855, 21.86944389], [88.81416321, 21.86972237], [88.81445313, 21.86972046], [88.81472015, 21.87000084], [88.81555176, 21.87000084], [88.81583405, 21.8702774], [88.81639099, 21.87026978], [88.81667328, 21.87055969], [88.8180542, 21.87055588], [88.81833649, 21.87083244], [88.81916809, 21.87083054], [88.81944275, 21.87111092], [88.8216629, 21.87111092], [88.82195282, 21.87083054], [88.82221985, 21.87083244], [88.82250214, 21.87055588], [88.82250214, 21.87026978], [88.82277679, 21.87000084], [88.82277679, 21.86944008], [88.82305908, 21.86916733], [88.82305908, 21.86852074], [88.82305908, 21.86833382], [88.82333374, 21.86805534], [88.82332611, 21.86778069], [88.8236084, 21.86750031], [88.8236084, 21.86720848], [88.82416534, 21.86666679], [88.82417297, 21.86639023], [88.82472229, 21.86583138], [88.82472229, 21.86555481], [88.82499695, 21.86527824], [88.82499695, 21.86499977], [88.82527924, 21.86471748], [88.82583618, 21.8647213], [88.82666779, 21.86388969], [88.82750702, 21.86388969], [88.82777405, 21.86361122], [88.82805634, 21.86361122], [88.82833099, 21.86333084], [88.82888794, 21.86333275], [88.82944489, 21.86277962], [88.82943726, 21.86250114], [88.82971954, 21.86222076], [88.82971954, 21.86111069], [88.82943726, 21.86083031], [88.82944489, 21.85972214], [88.82917023, 21.85944366], [88.82917023, 21.85916519], [88.82888794, 21.85889053], [88.82888794, 21.85832977], [88.82833099, 21.85777855], [88.82817841, 21.85750961], [88.82789612, 21.8572197], [88.82805634, 21.85666656], [88.82805634, 21.8555603], [88.82776642, 21.85527039], [88.82777405, 21.85499954], [88.82750702, 21.85472107], [88.82749939, 21.8544445], [88.82694244, 21.85388947], [88.82666779, 21.85388947], [88.82666779, 21.85306168], [88.82639313, 21.85277939], [88.82639313, 21.85220909], [88.82611084, 21.85194397], [88.82611084, 21.8516674], [88.82583618, 21.85139084], [88.82583618, 21.85082817], [88.82555389, 21.85055542], [88.82554626, 21.85000038], [88.82527924, 21.84971809], [88.82527924, 21.84944534], [88.82499695, 21.84917068], [88.82499695, 21.84860992], [88.82472229, 21.84833336], [88.82472229, 21.84749985], [88.82444, 21.84721947], [88.82444763, 21.84638977], [88.82417297, 21.84610939], [88.82416534, 21.84555435], [88.82389069, 21.84527969], [88.82389069, 21.84500122], [88.8236084, 21.84472084], [88.8236084, 21.84444427], [88.82333374, 21.8441658], [88.82332611, 21.84361076], [88.82305908, 21.84333038], [88.82305908, 21.84305573], [88.82277679, 21.84278107], [88.82277679, 21.84194183], [88.82250214, 21.84166718], [88.82250214, 21.84139061], [88.82195282, 21.84083176], [88.82194519, 21.84055519], [88.82112122, 21.83973122], [88.8208313, 21.83972168], [88.81999969, 21.84056282], [88.81999969, 21.84111023], [88.82027435, 21.8413887], [88.82026672, 21.84222031], [88.82055664, 21.84250069], [88.82055664, 21.84278107], [88.8208313, 21.84305573], [88.8208313, 21.84333038], [88.82110596, 21.84361076], [88.82110596, 21.84389114], [88.82138824, 21.8441658], [88.82138062, 21.84444046], [88.82195282, 21.84500122], [88.82194519, 21.84527779], [88.82250214, 21.84583282], [88.82250214, 21.84610939], [88.82277679, 21.84638977], [88.82277679, 21.84666443], [88.82305908, 21.84694672], [88.82305908, 21.84721947], [88.82333374, 21.84749985], [88.82333374, 21.84833336], [88.8236084, 21.84860992], [88.8236084, 21.85028076], [88.82277679, 21.85111046], [88.82250214, 21.85111046], [88.82195282, 21.85166931], [88.82138824, 21.8516674], [88.82111359, 21.85194397], [88.81916809, 21.85194397], [88.8188858, 21.8516674], [88.8188858, 21.85139084], [88.81916809, 21.85111046], [88.81916809, 21.85055923], [88.82110596, 21.85055923], [88.82138062, 21.85028076], [88.8216629, 21.85028076], [88.82221985, 21.84971809], [88.82221985, 21.84944534], [88.82250214, 21.84917068], [88.82250214, 21.84832954], [88.82221985, 21.84805679], [88.82221985, 21.84777832], [88.8216629, 21.84721947], [88.8216629, 21.84694672], [88.82138824, 21.84666443], [88.82138062, 21.84638977], [88.82055664, 21.84556007], [88.82055664, 21.84500122], [88.81999969, 21.84444046], [88.81999969, 21.84388924], [88.81973267, 21.84361076], [88.81972504, 21.84333229], [88.81944275, 21.84305573], [88.81944275, 21.84250069], [88.81916809, 21.84222031], [88.81916809, 21.8413887], [88.81861115, 21.84083176], [88.81861115, 21.84027863], [88.8188858, 21.84000015], [88.8188858, 21.83945274], [88.81916809, 21.83917046], [88.81916809, 21.8386116], [88.81972504, 21.83805466], [88.81972504, 21.83777809], [88.81944275, 21.83749962], [88.81944275, 21.83723068], [88.81973267, 21.83694077], [88.81972504, 21.83527565], [88.81999969, 21.83500099], [88.81999969, 21.83472061], [88.82027435, 21.83444595], [88.82027435, 21.8338871], [88.82055664, 21.83361053], [88.82055664, 21.83333015], [88.8208313, 21.8330574], [88.8208313, 21.83222008], [88.82111359, 21.83194351], [88.82111359, 21.82805634], [88.82138062, 21.82777977], [88.82138062, 21.82582855], [88.82111359, 21.8255558], [88.82110596, 21.82500076], [88.81999969, 21.82389069], [88.81999969, 21.82361031], [88.8188858, 21.82250023], [88.8188858, 21.82222748], [88.81833649, 21.82167053], [88.81833649, 21.82139015], [88.81749725, 21.82055092], [88.81749725, 21.82027626], [88.81694794, 21.81972122], [88.81694794, 21.81944656], [88.81661987, 21.81912041], [88.8161087, 21.81861115], [88.8161087, 21.81805992], [88.81582642, 21.81777954], [88.81582642, 21.81750107], [88.81555176, 21.81722069], [88.81555176, 21.81694221], [88.8152771, 21.81666756], [88.8152771, 21.8163929], [88.81500244, 21.81610107], [88.81500244, 21.81555557], [88.81472015, 21.81528282], [88.81472015, 21.81500053], [88.81416321, 21.81444168], [88.81416321, 21.81388855], [88.81360626, 21.8133316], [88.81361389, 21.81305504], [88.81305695, 21.81250191], [88.81305695, 21.81195259], [88.8125, 21.81138992], [88.8125, 21.81110764], [88.81222534, 21.81083298], [88.81222534, 21.81055641], [88.81194305, 21.81028938], [88.81194305, 21.80999947], [88.8116684, 21.80971909], [88.8116684, 21.80944443], [88.81111145, 21.80888939], [88.81083679, 21.80888939], [88.81083679, 21.80861092], [88.81083679, 21.80833244], [88.80944824, 21.8069458], [88.80944824, 21.80666542], [88.8041687, 21.80138969], [88.8041687, 21.80112076], [88.80027008, 21.79721832], [88.80027771, 21.79694366], [88.79833221, 21.79500008], [88.79805756, 21.79500008], [88.79805756, 21.7947216], [88.79722595, 21.79388618], [88.79722595, 21.79360962], [88.79638672, 21.79277611], [88.79638672, 21.79249954], [88.79582977, 21.79193115], [88.79555511, 21.79194641], [88.79499817, 21.79138947], [88.79471588, 21.79138947], [88.79444122, 21.79166985], [88.79389191, 21.79166412], [88.79360962, 21.79194641], [88.79333496, 21.79194641], [88.79305267, 21.79222488], [88.79277802, 21.79222107], [88.79250336, 21.79249954], [88.79222107, 21.79249954], [88.79167175, 21.79304123], [88.79138947, 21.79305458], [88.79111481, 21.79333305], [88.79083252, 21.79333115], [88.78971863, 21.79444695], [88.78971863, 21.7947197], [88.78916931, 21.79528046], [88.78916931, 21.79555511], [88.78888702, 21.79582977], [88.78888702, 21.79638863], [88.78971863, 21.79722214], [88.7902832, 21.79721832], [88.79055786, 21.79750061], [88.79083252, 21.79721832], [88.79222107, 21.79721832], [88.79250336, 21.79750061], [88.79277802, 21.79750061], [88.79472351, 21.7994442], [88.79471588, 21.79972076], [88.79499817, 21.80000114], [88.79499817, 21.80055618], [88.79528046, 21.80083275], [88.79528046, 21.80138969], [88.79556274, 21.80167007], [88.79555511, 21.80555344], [88.79528046, 21.80583572], [88.79528046, 21.80944443], [88.79499817, 21.80971909], [88.79499817, 21.81055641], [88.79471588, 21.81082916], [88.79471588, 21.81138992], [88.79444122, 21.8116703], [88.79444122, 21.81250191], [88.79360962, 21.81333351], [88.79332733, 21.8133316], [88.79277802, 21.81389046], [88.79250336, 21.81389046], [88.79222107, 21.81416702], [88.79222107, 21.81444359], [88.79194641, 21.81472015], [88.79194641, 21.81500053], [88.79055786, 21.8163929], [88.79055786, 21.81666756], [88.79027557, 21.81694221], [88.7902832, 21.81722069], [88.79000092, 21.81750107], [88.79000092, 21.81777763], [88.78944397, 21.81833267], [88.78944397, 21.82083321], [88.78971863, 21.82110977], [88.78971863, 21.82139015], [88.78943634, 21.82139015], [88.78888702, 21.82195091], [88.78861237, 21.82194519], [88.78806305, 21.82250023], [88.78806305, 21.82305908], [88.78555298, 21.82555962], [88.78527832, 21.8255558], [88.78500366, 21.82583427], [88.78444672, 21.82582855], [88.7841568, 21.82611084], [88.78305817, 21.82611084], [88.78277588, 21.82638931], [88.78250122, 21.82638931], [88.7822113, 21.82666969], [88.78166962, 21.82666969], [88.78138733, 21.82638931], [88.78056335, 21.82638931], [88.78028107, 21.82666969], [88.77666473, 21.82666588], [88.77639008, 21.82694435], [88.77361298, 21.82694435], [88.77346802, 21.82680321], [88.77333069, 21.82666588], [88.76944733, 21.82666588], [88.76916504, 21.82694435], [88.76833344, 21.82694435], [88.76805878, 21.82722282], [88.76750183, 21.82722282], [88.76722717, 21.82749939], [88.76693726, 21.82749939], [88.76638794, 21.82806015], [88.76611328, 21.82805634], [88.76611328, 21.82860947], [88.76583099, 21.82888985], [88.76583099, 21.83055305], [88.76611328, 21.83082962], [88.76611328, 21.83166695], [88.76638794, 21.8319397], [88.76638794, 21.83250046], [88.76667023, 21.83277512], [88.76667023, 21.83333015], [88.76693726, 21.83361053], [88.76693726, 21.83500099], [88.76721954, 21.83527565], [88.76722717, 21.83611107], [88.76750183, 21.83638954], [88.76750183, 21.83833313], [88.76777649, 21.8386116], [88.76777649, 21.84026909], [88.76805878, 21.84055519], [88.76805878, 21.84083176], [88.76833344, 21.84111023], [88.76833344, 21.84194374], [88.76860809, 21.84222031], [88.76860809, 21.84278107], [88.76889038, 21.84305573], [88.76889038, 21.84333229], [88.76917267, 21.84361076], [88.76917267, 21.84389114], [88.76944733, 21.8441658], [88.76944733, 21.84444427], [88.76972198, 21.84472084], [88.76972198, 21.84500122], [88.76999664, 21.84527969], [88.76999664, 21.84555435], [88.77054596, 21.84610939], [88.77055359, 21.84666443], [88.77083588, 21.84694672], [88.77083588, 21.85194397], [88.77111053, 21.85220909], [88.77111053, 21.85277939], [88.77138519, 21.85305595], [88.77139282, 21.8533287], [88.77166748, 21.8536129], [88.77194214, 21.8536129], [88.7722168, 21.85388947], [88.77249908, 21.85388947], [88.77278137, 21.85416985], [88.77333069, 21.85416603], [88.77361298, 21.8544445], [88.77444458, 21.8544445], [88.77462769, 21.85462952], [88.77471924, 21.85472107], [88.77527618, 21.85472107], [88.77610779, 21.85527802], [88.77638245, 21.85541916], [88.7766571, 21.8555603], [88.77694702, 21.85555649], [88.77713013, 21.8557415], [88.77722168, 21.85583115], [88.77805328, 21.85583115], [88.77833557, 21.85611153], [88.77861023, 21.85610962], [88.77874756, 21.85625076], [88.77889252, 21.85639], [88.77944183, 21.85639], [88.77971649, 21.85667038], [88.77999878, 21.85666656], [88.78166962, 21.85833359], [88.78166962, 21.85861015], [88.78194427, 21.85888863], [88.78194427, 21.85944366], [88.7822113, 21.85972023], [88.7822113, 21.86028099], [88.78193665, 21.86055946], [88.78193665, 21.86111069], [88.78166962, 21.8614006], [88.78166962, 21.86166763], [88.78111267, 21.86222267], [88.78083038, 21.86222076], [88.78028107, 21.86277962], [88.77999878, 21.86277962], [88.77944183, 21.86333275], [88.77916718, 21.86333275], [88.77900696, 21.86349487], [88.77889252, 21.86361122], [88.77861023, 21.86361122], [88.77694702, 21.86527824], [88.77694702, 21.86583328], [88.7766571, 21.86611176], [88.77694702, 21.86639023], [88.77694702, 21.8669529], [88.77749634, 21.86750031], [88.77749634, 21.86777687], [88.77805328, 21.86833382], [88.77861023, 21.86833191], [88.77889252, 21.86861038], [88.77916718, 21.86861038], [88.77971649, 21.86917114], [88.77999878, 21.86917114], [88.78138733, 21.87055588], [88.78138733, 21.87083054], [88.78221893, 21.87166405], [88.78221893, 21.87194443], [88.78388977, 21.87360954], [88.78388977, 21.87388992], [88.78555298, 21.87555695], [88.78555298, 21.8758297], [88.78569031, 21.87597275], [88.78610992, 21.87639809], [88.78639221, 21.87638664], [88.78768921, 21.87768745], [88.78775787, 21.87775612], [88.78806305, 21.87805939], [88.78833008, 21.87805557], [88.78861237, 21.87833405], [88.78888702, 21.87832832], [88.78916931, 21.87861061]]], [[[88.59749603, 21.86222076], [88.59777832, 21.86250114], [88.59777832, 21.86277962], [88.59805298, 21.86305618], [88.59805298, 21.86333084], [88.59860229, 21.86388969], [88.59860992, 21.86416626], [88.59889221, 21.86444092], [88.59889221, 21.86499977], [88.59916687, 21.86528015], [88.59916687, 21.86750031], [88.59944153, 21.86777687], [88.59944153, 21.86833191], [88.59971619, 21.86861038], [88.59972382, 21.86888885], [88.60147858, 21.87064552], [88.60166168, 21.87083054], [88.60166168, 21.87111092], [88.60194397, 21.87138939], [88.60194397, 21.87181091], [88.60194397, 21.87194443], [88.60221863, 21.87222099], [88.60221863, 21.87277985], [88.60250092, 21.87306023], [88.60250092, 21.87388992], [88.60305786, 21.87445068], [88.60305786, 21.875], [88.60333252, 21.87527847], [88.60333252, 21.87583351], [88.60360718, 21.87610817], [88.60360718, 21.87639809], [88.60388947, 21.87666893], [88.60388947, 21.87693977], [88.60444641, 21.87750053], [88.60444641, 21.87778091], [88.60472107, 21.87805557], [88.6047287, 21.87832832], [88.60500336, 21.87861061], [88.60500336, 21.87888908], [88.60527802, 21.87916756], [88.60527802, 21.8794384], [88.60582733, 21.88000107], [88.60583496, 21.88027763], [88.60639191, 21.88083267], [88.60639191, 21.88111115], [88.60749817, 21.88221169], [88.60749817, 21.88249969], [88.60805511, 21.88305473], [88.60805511, 21.88333321], [88.60832977, 21.88360977], [88.60832977, 21.88389015], [88.60861206, 21.88417053], [88.60861206, 21.88445091], [88.60916901, 21.88500023], [88.60916901, 21.88557053], [88.60972595, 21.88611031], [88.60972595, 21.88639069], [88.61000061, 21.88667107], [88.6100769, 21.88660812], [88.61042786, 21.88698959], [88.61073303, 21.88741112], [88.61106873, 21.88781166], [88.61138153, 21.88820839], [88.61165619, 21.8885994], [88.61194611, 21.88895988], [88.61222076, 21.88931656], [88.61250305, 21.8896904], [88.61277771, 21.89009285], [88.61306763, 21.89048958], [88.61335754, 21.89088631], [88.61361694, 21.8913002], [88.61388397, 21.89172745], [88.61412811, 21.89217186], [88.61444092, 21.89250183], [88.61444092, 21.8927784], [88.61528015, 21.89361191], [88.61554718, 21.89361191], [88.61611176, 21.89417267], [88.61638641, 21.89416695], [88.61723328, 21.89500046], [88.61723328, 21.89528275], [88.61805725, 21.89611053], [88.61833191, 21.89611053], [88.6194458, 21.89722252], [88.61972809, 21.89722061], [88.61985016, 21.89735031], [88.62000275, 21.89751053], [88.6202774, 21.89751053], [88.62055206, 21.89777946], [88.62166595, 21.89777946], [88.62194824, 21.89751053], [88.6222229, 21.89751053], [88.62249756, 21.89722061], [88.62277985, 21.89722252], [88.6230545, 21.89694214], [88.62333679, 21.89694214], [88.62361145, 21.89666748], [88.62361908, 21.89679718], [88.62402344, 21.89663315], [88.62442017, 21.89639091], [88.62486267, 21.89611053], [88.62532043, 21.89582825], [88.6256485, 21.89559174], [88.6257782, 21.89550018], [88.62615967, 21.89512062], [88.62645721, 21.89470863], [88.62666321, 21.89417267], [88.62695313, 21.89389038], [88.62695313, 21.89166832], [88.62722015, 21.89138031], [88.62722015, 21.89049911], [88.62722015, 21.88944435], [88.62750244, 21.88916779], [88.62722015, 21.88889122], [88.62722015, 21.88667107], [88.62750244, 21.88639069], [88.62750244, 21.88528061], [88.6277771, 21.88500023], [88.6277771, 21.88445091], [88.62805176, 21.88417053], [88.62805176, 21.88360977], [88.62833405, 21.88333321], [88.62833405, 21.88305473], [88.6286087, 21.88277817], [88.6286087, 21.88249969], [88.6297226, 21.88138962], [88.62999725, 21.88138962], [88.63041687, 21.88097191], [88.63056946, 21.88086128], [88.63089752, 21.88064003], [88.63140869, 21.88032913], [88.63195801, 21.88002014], [88.63253784, 21.87973022], [88.63314056, 21.8794384], [88.63376617, 21.87911034], [88.63432312, 21.87866974], [88.63461304, 21.8780098], [88.63470459, 21.87730026], [88.63464355, 21.876688], [88.63437653, 21.87629128], [88.63407898, 21.87599182], [88.63378906, 21.87572289], [88.63352203, 21.87544441], [88.63329315, 21.87509537], [88.63301849, 21.8747406], [88.63272095, 21.87436676], [88.63246918, 21.8739109], [88.6322403, 21.87347412], [88.63205719, 21.8730278], [88.63191986, 21.87257957], [88.63179016, 21.87213135], [88.63173676, 21.87165451], [88.63222504, 21.87111092], [88.63222504, 21.87083244], [88.6333313, 21.86972237], [88.63361359, 21.86972237], [88.63388824, 21.86944389], [88.6341629, 21.86944389], [88.63444519, 21.86916733], [88.63527679, 21.86916733], [88.63542175, 21.86930656], [88.63555908, 21.86944389], [88.6361084, 21.86944389], [88.63639069, 21.86972237], [88.63667297, 21.86972046], [88.63694763, 21.87000084], [88.63722229, 21.87000084], [88.63749695, 21.87026978], [88.63786316, 21.87063789], [88.63827515, 21.87103271], [88.63879395, 21.87136459], [88.63899994, 21.87145996], [88.63936615, 21.87162971], [88.64003754, 21.87178993], [88.64070892, 21.87187004], [88.64128876, 21.8719101], [88.6418457, 21.87182617], [88.64241028, 21.87174034], [88.64295959, 21.87166977], [88.64349365, 21.87160492], [88.64398956, 21.87146759], [88.64414978, 21.87145233], [88.64450073, 21.87141991], [88.64501953, 21.87138939], [88.64554596, 21.87134361], [88.64604187, 21.87116623], [88.6465683, 21.87109184], [88.64705658, 21.87098694], [88.64753723, 21.87083054], [88.64797974, 21.87066078], [88.6484375, 21.87051964], [88.64888, 21.87030029], [88.64944458, 21.8702774], [88.64971924, 21.87000084], [88.65110779, 21.87000084], [88.65139008, 21.86972046], [88.65139008, 21.86902428], [88.65166473, 21.86887932], [88.65284729, 21.86865807], [88.65328217, 21.86825943], [88.65344238, 21.86802101], [88.65351868, 21.86770821], [88.65344238, 21.86705971], [88.65329742, 21.86646271], [88.65307617, 21.86592293], [88.65284729, 21.86536026], [88.65261841, 21.86479759], [88.65245819, 21.86420059], [88.65229034, 21.86376953], [88.65224457, 21.86366081], [88.65222168, 21.86305809], [88.65194702, 21.86305809], [88.65139008, 21.86250114], [88.65055847, 21.86250114], [88.65055847, 21.86194038], [88.65139008, 21.86111069], [88.65083313, 21.86055946], [88.65083313, 21.86028099], [88.65055847, 21.86000061], [88.65055847, 21.85889053], [88.65027618, 21.85861015], [88.65027618, 21.85750008], [88.65000153, 21.8572197], [88.65000153, 21.85694313], [88.64971161, 21.85667038], [88.64971161, 21.8555603], [88.65000153, 21.85527039], [88.65000153, 21.85499954], [88.64943695, 21.8544426], [88.64944458, 21.85416603], [88.64888763, 21.8536129], [88.64888763, 21.8533287], [88.64916992, 21.85305595], [88.64916992, 21.85277939], [88.64936066, 21.85264969], [88.64940643, 21.85210991], [88.64936066, 21.85158157], [88.64944458, 21.85111046], [88.64943695, 21.85055923], [88.64971161, 21.85028076], [88.64971161, 21.85000038], [88.65000153, 21.84971809], [88.65000153, 21.84861183], [88.65027618, 21.84833336], [88.65027618, 21.84722137], [88.64971924, 21.84666443], [88.64971161, 21.84556007], [88.65027618, 21.84500122], [88.64971161, 21.84444046], [88.64971924, 21.84388924], [88.64943695, 21.84361076], [88.64943695, 21.84333038], [88.64933014, 21.84322166], [88.64916992, 21.84305573], [88.64916992, 21.84222031], [88.64924622, 21.8421402], [88.64944458, 21.84194374], [88.64944458, 21.84111023], [88.64916992, 21.84081841], [88.64916992, 21.83944511], [88.64943695, 21.83917046], [88.64943695, 21.83889008], [88.64916992, 21.8386116], [88.64916992, 21.83805466], [88.64888763, 21.83777809], [88.64888763, 21.83723068], [88.64875793, 21.83709526], [88.64861298, 21.83694458], [88.64833069, 21.83666611], [88.64805603, 21.83666992], [88.64749908, 21.83611107], [88.64805603, 21.83555984], [88.64833069, 21.83527946], [88.64855957, 21.83527946], [88.64916992, 21.83527946], [88.64943695, 21.83500099], [88.64943695, 21.83472061], [88.64916992, 21.83444595], [88.64916992, 21.83416748], [88.64932251, 21.83393288], [88.64938354, 21.83335686], [88.64920807, 21.83279037], [88.64916992, 21.83222198], [88.64888763, 21.83194351], [88.64888763, 21.83138847], [88.64861298, 21.83110046], [88.64861298, 21.83083344], [88.64833069, 21.83055305], [88.64833069, 21.82971954], [88.64805603, 21.82944489], [88.64805603, 21.82722282], [88.64722443, 21.82638931], [88.6472168, 21.82611084], [88.64679718, 21.82556534], [88.64662933, 21.82497215], [88.64644623, 21.82438469], [88.64633942, 21.82380104], [88.64614868, 21.82326126], [88.64595795, 21.82273293], [88.6457901, 21.8221817], [88.64566803, 21.82165527], [88.64572906, 21.82114983], [88.64582062, 21.82067108], [88.64588928, 21.82019997], [88.64599609, 21.81973076], [88.64589691, 21.81925964], [88.64570618, 21.81879044], [88.64546967, 21.81836128], [88.64521027, 21.8179493], [88.64496613, 21.81748962], [88.64472961, 21.8170414], [88.64452362, 21.81654358], [88.64452362, 21.81592751], [88.64470673, 21.81522942], [88.64485168, 21.81452751], [88.64480591, 21.81384087], [88.64447784, 21.81328011], [88.64408112, 21.81281853], [88.64360809, 21.81250191], [88.64305878, 21.81195259], [88.64305878, 21.80888939], [88.64332581, 21.80861092], [88.64332581, 21.80778122], [88.64277649, 21.80722046], [88.64247131, 21.80723953], [88.64239502, 21.80707932], [88.64231873, 21.80692482], [88.64225006, 21.80638695], [88.64235687, 21.80570984], [88.6424942, 21.80495834], [88.64272308, 21.80424118], [88.64289093, 21.80358124], [88.64305878, 21.80310059], [88.64315033, 21.80267906], [88.64317322, 21.80230904], [88.64303589, 21.80195045], [88.64285278, 21.80159187], [88.6428299, 21.80115128], [88.64291382, 21.80069733], [88.643013, 21.80021286], [88.64299011, 21.79968262], [88.64284515, 21.79912567], [88.64279175, 21.79852867], [88.64277649, 21.79791832], [88.64279175, 21.7972908], [88.64286041, 21.79663086], [88.64299011, 21.79597092], [88.64299011, 21.79529953], [88.64285278, 21.79463959], [88.64279175, 21.79393959], [88.64277649, 21.79325485], [88.64278412, 21.79260063], [88.64277649, 21.79201126], [88.64280701, 21.79146957], [88.64291382, 21.79100609], [88.643013, 21.79055977], [88.64305878, 21.79009819], [88.64305878, 21.79000092], [88.64305878, 21.78889084], [88.64277649, 21.78861046], [88.64250183, 21.78861046], [88.64193726, 21.78806114], [88.64167023, 21.78806114], [88.64135742, 21.78774452], [88.64083862, 21.78722191], [88.64083099, 21.78611183], [88.6397171, 21.78499985], [88.63916779, 21.78499985], [88.63889313, 21.78471756], [88.63861084, 21.78472137], [88.63821411, 21.7851162], [88.63805389, 21.78527832], [88.63784027, 21.78534317], [88.63710785, 21.78556442], [88.63639069, 21.78583336], [88.63471222, 21.78583145], [88.6341629, 21.7863903], [88.63388824, 21.7863903], [88.63276672, 21.78750038], [88.63249969, 21.78750038], [88.63223267, 21.78778267], [88.63166809, 21.78778267], [88.6313858, 21.78806114], [88.62916565, 21.78805542], [88.62889099, 21.78833389], [88.6286087, 21.78833389], [88.62833405, 21.78805542], [88.62805176, 21.78806114], [88.62750244, 21.78861046], [88.62722015, 21.78861046], [88.62702179, 21.78862953], [88.62680054, 21.78919983], [88.62640381, 21.78976059], [88.62582397, 21.79009247], [88.62562561, 21.79020309], [88.62534332, 21.79036522], [88.625, 21.7906208], [88.62471771, 21.7908783], [88.62440491, 21.79113388], [88.62414551, 21.79130554], [88.62401581, 21.79139328], [88.62358856, 21.79168129], [88.62317657, 21.79201126], [88.62285614, 21.79240799], [88.62254333, 21.79280281], [88.62223816, 21.79322052], [88.62194824, 21.79369736], [88.62166595, 21.79420471], [88.62140656, 21.79469109], [88.62121582, 21.79516983], [88.62104797, 21.79560089], [88.62082672, 21.79598045], [88.62063599, 21.79633141], [88.62047577, 21.79669952], [88.62020874, 21.79705048], [88.62001801, 21.79745293], [88.61988068, 21.79788017], [88.61965179, 21.79826736], [88.6193161, 21.79862976], [88.6190033, 21.7990799], [88.61873627, 21.79964638], [88.61862946, 21.80032921], [88.61860657, 21.80104637], [88.61860657, 21.80161095], [88.61860657, 21.80173111], [88.61860657, 21.80239105], [88.61860657, 21.80302811], [88.61860657, 21.80365944], [88.61862946, 21.80425072], [88.61868286, 21.80476952], [88.6186142, 21.80527687], [88.61860657, 21.80583], [88.61833191, 21.80611038], [88.61833191, 21.80639076], [88.61805725, 21.80666542], [88.61805725, 21.8069458], [88.61776733, 21.80722046], [88.61776733, 21.80750084], [88.61750031, 21.8077755], [88.61750031, 21.80833244], [88.61722565, 21.80861092], [88.61722565, 21.80944443], [88.61694336, 21.80971909], [88.61694336, 21.81027985], [88.61638641, 21.81083298], [88.61638641, 21.81110764], [88.61472321, 21.81278038], [88.61472321, 21.81305504], [88.6140213, 21.81376076], [88.6138916, 21.81389046], [88.6138916, 21.81416702], [88.61332703, 21.81472015], [88.61333466, 21.81500053], [88.61250305, 21.81583214], [88.61250305, 21.81610107], [88.61194611, 21.81666946], [88.61194611, 21.81750107], [88.61250305, 21.81805992], [88.61277771, 21.8180542], [88.61305237, 21.81833267], [88.61332703, 21.81833076], [88.61360168, 21.81861115], [88.6138916, 21.81861115], [88.61416626, 21.81888962], [88.61444092, 21.81888962], [88.61528015, 21.81972313], [88.61555481, 21.81972313], [88.6166687, 21.82083321], [88.61694336, 21.82083321], [88.61865997, 21.82254982], [88.6202774, 21.82416725], [88.6202774, 21.82444382], [88.62055206, 21.82471848], [88.62055206, 21.82500076], [88.62083435, 21.82527733], [88.62082672, 21.82582855], [88.62110901, 21.82611084], [88.62110901, 21.82638931], [88.6213913, 21.82666588], [88.6213913, 21.8283329], [88.62166595, 21.82860947], [88.62166595, 21.82916641], [88.62194824, 21.82944489], [88.62194824, 21.82971954], [88.62166595, 21.82999992], [88.62166595, 21.8302803], [88.6213913, 21.83055305], [88.6213913, 21.83083344], [88.62110901, 21.83110046], [88.62110901, 21.83139038], [88.61888885, 21.83361053], [88.61860657, 21.83361053], [88.61833191, 21.83389091], [88.61805725, 21.83389091], [88.61776733, 21.83416939], [88.61750031, 21.83416748], [88.61722565, 21.83444595], [88.61694336, 21.83444595], [88.6166687, 21.83472252], [88.61638641, 21.83472061], [88.61611176, 21.83500099], [88.61554718, 21.83500099], [88.61528015, 21.83527946], [88.61472321, 21.83527946], [88.61444092, 21.83555984], [88.61360931, 21.83555794], [88.61333466, 21.8358326], [88.61138916, 21.83583069], [88.6111145, 21.83611107], [88.61071777, 21.83611107], [88.6102829, 21.83611107], [88.61000061, 21.83638954], [88.60972595, 21.83638954], [88.60861206, 21.83749962], [88.60861206, 21.83777809], [88.60832977, 21.83805084], [88.60832977, 21.83917046], [88.60805511, 21.83944511], [88.60805511, 21.83994293], [88.60805511, 21.84055519], [88.60778046, 21.84083366], [88.60778809, 21.84111023], [88.60805511, 21.8413887], [88.60805511, 21.84194374], [88.60778046, 21.84222221], [88.60778046, 21.84267426], [88.60774231, 21.84276009], [88.60758209, 21.84312439], [88.60748291, 21.84354973], [88.6073761, 21.84392929], [88.60727692, 21.84426117], [88.60721588, 21.84472084], [88.60694122, 21.84500122], [88.60694122, 21.84527969], [88.60666656, 21.84555435], [88.60666656, 21.84583282], [88.60639191, 21.84610939], [88.60639191, 21.84638977], [88.60472107, 21.84805679], [88.60444641, 21.84805679], [88.60416412, 21.84833336], [88.60388947, 21.84833336], [88.60361481, 21.84861183], [88.60333252, 21.84860992], [88.60305786, 21.8488903], [88.60250092, 21.8488903], [88.60221863, 21.84917068], [88.60166168, 21.84917068], [88.60138702, 21.8494606], [88.60055542, 21.84944534], [88.60028076, 21.84972191], [88.59971619, 21.84971809], [88.59944153, 21.85000038], [88.59860229, 21.85000038], [88.5983429, 21.85028076], [88.59777832, 21.85028076], [88.59749603, 21.85055923], [88.59722137, 21.85055542], [88.59694672, 21.85083389], [88.5966568, 21.85082817], [88.59610748, 21.85139084], [88.59610748, 21.8516674], [88.59583282, 21.85194397], [88.59583282, 21.85220909], [88.59555817, 21.85250092], [88.59555817, 21.85277939], [88.59527588, 21.85305595], [88.59527588, 21.8533287], [88.59500122, 21.8536129], [88.59500122, 21.85416603], [88.59471893, 21.8544445], [88.59471893, 21.85610962], [88.59500122, 21.85639], [88.59500122, 21.85694313], [88.59527588, 21.8572197], [88.59527588, 21.85750008], [88.59583282, 21.85805321], [88.59583282, 21.85833359], [88.59610748, 21.85861015], [88.59610748, 21.85916519], [88.59638977, 21.85943985], [88.59638977, 21.86000061], [88.59694672, 21.86055756], [88.59694672, 21.86083031], [88.59722137, 21.86111069], [88.59722137, 21.86166763], [88.59750366, 21.8619442], [88.59749603, 21.86222076]]], [[[88.70861053, 21.81055641], [88.70833588, 21.81083298], [88.70804596, 21.81082916], [88.70749664, 21.81138992], [88.70749664, 21.8116703], [88.70722198, 21.81195259], [88.70722198, 21.81277847], [88.70667267, 21.8133316], [88.70666504, 21.81416702], [88.70610809, 21.81472015], [88.70610809, 21.81500053], [88.70555878, 21.81555557], [88.70555878, 21.81610107], [88.70500183, 21.81666756], [88.70500183, 21.81694221], [88.70471954, 21.81722069], [88.70471954, 21.81750107], [88.70443726, 21.81777954], [88.70444489, 21.8180542], [88.70417023, 21.81833267], [88.70417786, 21.81861115], [88.70388794, 21.81888962], [88.70388794, 21.81916428], [88.70361328, 21.81944084], [88.70362091, 21.82195091], [88.70388794, 21.82222748], [88.70388794, 21.82250023], [88.70417786, 21.82278061], [88.70417023, 21.82305527], [88.70443726, 21.82332993], [88.70443726, 21.82638931], [88.70471954, 21.82666588], [88.70471954, 21.82722282], [88.70500183, 21.82749939], [88.70500183, 21.82777977], [88.70527649, 21.82806015], [88.70555878, 21.82805634], [88.70583344, 21.8283329], [88.70639038, 21.8283329], [88.70666504, 21.82805634], [88.70722198, 21.82806015], [88.70777893, 21.82749939], [88.70804596, 21.82749939], [88.70833588, 21.82722282], [88.70861053, 21.82722282], [88.70888519, 21.82694435], [88.70916748, 21.82694435], [88.70944214, 21.82666588], [88.7097168, 21.82666969], [88.71028137, 21.82611084], [88.71083069, 21.82611084], [88.71111298, 21.82582855], [88.71138763, 21.82583427], [88.71166992, 21.8255558], [88.71221924, 21.82555962], [88.71250153, 21.82529259], [88.71333313, 21.82529259], [88.71360779, 21.82555962], [88.71472168, 21.8255558], [88.71485901, 21.82569504], [88.71499634, 21.82583427], [88.71527863, 21.82582855], [88.71555328, 21.82611084], [88.71666718, 21.82611084], [88.71778107, 21.82722282], [88.71778107, 21.82749939], [88.71917725, 21.82888985], [88.71916962, 21.82916641], [88.71943665, 21.82944107], [88.71943665, 21.8302803], [88.71916962, 21.83055305], [88.71916962, 21.83222198], [88.72027588, 21.83333588], [88.72055817, 21.83333588], [88.72092438, 21.83370399], [88.72110748, 21.83389091], [88.72138977, 21.83389091], [88.7216568, 21.83416939], [88.72250366, 21.83416748], [88.72277832, 21.83444595], [88.72333527, 21.83444595], [88.72360992, 21.83472252], [88.72389221, 21.83472061], [88.72416687, 21.83500099], [88.72444153, 21.83500099], [88.72499084, 21.83555984], [88.72583008, 21.83555794], [88.72611237, 21.8358326], [88.72666931, 21.83583069], [88.72693634, 21.83611107], [88.72750092, 21.83611107], [88.72777557, 21.83638954], [88.72805786, 21.83638954], [88.72833252, 21.83666611], [88.72833252, 21.83694077], [88.72805786, 21.83723068], [88.72805786, 21.83749962], [88.72777557, 21.83749962], [88.72750092, 21.83722305], [88.72666931, 21.83723068], [88.72647858, 21.83703613], [88.72638702, 21.83694458], [88.72528076, 21.83694458], [88.72499847, 21.83666611], [88.72471619, 21.83666992], [88.72444153, 21.83638954], [88.72416687, 21.83638954], [88.72389221, 21.83611107], [88.72360992, 21.83611107], [88.7233429, 21.83583069], [88.72305298, 21.8358326], [88.72277832, 21.83555794], [88.72249603, 21.83555984], [88.72222137, 21.83527946], [88.72194672, 21.83527946], [88.7216568, 21.83500099], [88.72083282, 21.83500099], [88.72055817, 21.83472061], [88.72027588, 21.83472252], [88.72000122, 21.83444595], [88.71971893, 21.83444595], [88.71916199, 21.8338871], [88.71833038, 21.8330574], [88.71806335, 21.83306122], [88.71806335, 21.83250046], [88.71778107, 21.83222198], [88.71778107, 21.8302784], [88.71749878, 21.82999992], [88.71749878, 21.82888985], [88.71611786, 21.82749939], [88.71583557, 21.82749939], [88.71527863, 21.82694435], [88.71333313, 21.82694435], [88.71305847, 21.82666588], [88.71250153, 21.82666588], [88.71221924, 21.82694435], [88.71166992, 21.82694435], [88.71138763, 21.82722282], [88.71111298, 21.82722282], [88.71055603, 21.82777977], [88.71028137, 21.82777977], [88.70999146, 21.82806015], [88.70972443, 21.82805634], [88.70944214, 21.8283329], [88.70916748, 21.8283329], [88.70888519, 21.82861137], [88.70861053, 21.82860947], [88.70833588, 21.82888985], [88.70804596, 21.82888985], [88.70777893, 21.82917023], [88.70749664, 21.82916641], [88.70694733, 21.82972145], [88.70500183, 21.82972145], [88.70471954, 21.82944489], [88.70444489, 21.82944489], [88.70388794, 21.82888794], [88.70361328, 21.82888985], [88.70361328, 21.82806015], [88.70333099, 21.82777977], [88.70333099, 21.82749939], [88.70305634, 21.82722282], [88.70305634, 21.82500076], [88.70276642, 21.82471848], [88.70277405, 21.82444382], [88.70249939, 21.82416916], [88.70166779, 21.82500076], [88.70152283, 21.82500076], [88.7013855, 21.82500076], [88.7013855, 21.82522964], [88.7013855, 21.82694435], [88.70111084, 21.82722282], [88.70139313, 21.82749939], [88.7013855, 21.82805634], [88.70111084, 21.8283329], [88.70111084, 21.82971954], [88.70083618, 21.82999992], [88.70083618, 21.83055305], [88.70055389, 21.83083344], [88.70054626, 21.8319397], [88.69999695, 21.83250046], [88.69999695, 21.83277512], [88.69944763, 21.83333015], [88.69944763, 21.83361053], [88.6986084, 21.83444023], [88.6986084, 21.83527565], [88.69805145, 21.83583069], [88.69805145, 21.83611107], [88.69750214, 21.83666992], [88.69750214, 21.83722305], [88.6966629, 21.83805466], [88.6966629, 21.83851051], [88.6966629, 21.83889008], [88.69638824, 21.83916664], [88.69638824, 21.84026909], [88.69611359, 21.84055519], [88.69610596, 21.84083176], [88.6958313, 21.84111023], [88.69611359, 21.8413887], [88.69610596, 21.84222031], [88.69638824, 21.84250069], [88.69638824, 21.84278107], [88.6966629, 21.84278107], [88.69777679, 21.84389114], [88.69805145, 21.84389114], [88.69917297, 21.84500122], [88.69917297, 21.84527969], [88.69944763, 21.84555435], [88.69944763, 21.84610939], [88.69972229, 21.84638977], [88.69972229, 21.84666443], [88.69999695, 21.84694672], [88.69999695, 21.84721947], [88.70027924, 21.84749985], [88.70027924, 21.84805679], [88.70055389, 21.84833336], [88.70055389, 21.84861946], [88.70054626, 21.84917068], [88.70083618, 21.84944534], [88.70083618, 21.85082817], [88.70111084, 21.85111046], [88.70111084, 21.8516674], [88.7013855, 21.85194397], [88.70139313, 21.85250092], [88.70166779, 21.85277939], [88.70166779, 21.8536129], [88.70194244, 21.85388947], [88.70194244, 21.85472107], [88.70333099, 21.85611153], [88.70417786, 21.85610962], [88.70443726, 21.85639], [88.70471954, 21.85639], [88.70500183, 21.85610962], [88.70610809, 21.85611153], [88.70639038, 21.85583115], [88.70694733, 21.85583115], [88.70749664, 21.85527802], [88.70777893, 21.85527802], [88.70805359, 21.85499954], [88.70833588, 21.85499954], [88.70861053, 21.85472107], [88.70888519, 21.85472107], [88.70916748, 21.8544445], [88.70944214, 21.8544445], [88.70972443, 21.85416603], [88.70999146, 21.85416985], [88.71028137, 21.85388947], [88.71055603, 21.85388947], [88.71083069, 21.8536129], [88.71111298, 21.8536129], [88.71138763, 21.8533287], [88.71166229, 21.85337639], [88.71193695, 21.8536129], [88.71360779, 21.8536129], [88.71389008, 21.85388947], [88.71444702, 21.85388947], [88.71472168, 21.85416985], [88.71527863, 21.85416603], [88.71555328, 21.8544445], [88.71583557, 21.8544445], [88.71611023, 21.85472107], [88.71639252, 21.85472107], [88.71694183, 21.85527802], [88.71721649, 21.85527039], [88.71749878, 21.85555649], [88.71749878, 21.85583115], [88.71721649, 21.85610962], [88.71721649, 21.85639], [88.71666718, 21.85639], [88.71652985, 21.85625076], [88.71639252, 21.85610962], [88.71611023, 21.85611153], [88.71583557, 21.85583115], [88.71555328, 21.85583115], [88.71527863, 21.85555649], [88.71499634, 21.8555603], [88.71490479, 21.85546494], [88.71472168, 21.85527802], [88.71444702, 21.85527802], [88.71416473, 21.85499954], [88.71360779, 21.85499954], [88.71333313, 21.85472107], [88.71221924, 21.85472107], [88.71193695, 21.85499954], [88.71083069, 21.85499954], [88.71055603, 21.85527802], [88.71028137, 21.85527039], [88.70999146, 21.8555603], [88.70972443, 21.85555649], [88.70916748, 21.85611153], [88.70861053, 21.85610962], [88.70804596, 21.85667038], [88.70777893, 21.85666656], [88.70722198, 21.8572216], [88.70694733, 21.8572216], [88.70667267, 21.85750008], [88.70500183, 21.85750008], [88.70471954, 21.85778046], [88.70417786, 21.85778046], [88.70388794, 21.85750008], [88.70305634, 21.85750008], [88.70276642, 21.8572197], [88.70249939, 21.8572216], [88.7013855, 21.85611153], [88.7013855, 21.85583115], [88.70083618, 21.85527802], [88.70083618, 21.85499954], [88.70027924, 21.8544426], [88.70027924, 21.85416603], [88.69999695, 21.85388947], [88.69999695, 21.8533287], [88.69972229, 21.85305595], [88.69972229, 21.85250092], [88.69944763, 21.85220909], [88.69944763, 21.85194397], [88.69916534, 21.8516674], [88.69917297, 21.85082817], [88.69889069, 21.85055542], [88.69889069, 21.8494606], [88.6986084, 21.84917068], [88.6986084, 21.8488903], [88.69844818, 21.84872818], [88.69805908, 21.84833336], [88.69721985, 21.84833336], [88.69694519, 21.84861183], [88.6971283, 21.84879684], [88.69721985, 21.8488903], [88.69695282, 21.84917068], [88.69695282, 21.85028076], [88.69721985, 21.85055923], [88.69721985, 21.85111046], [88.69750214, 21.85139084], [88.69750214, 21.85194397], [88.69777679, 21.85220909], [88.69777679, 21.85250092], [88.69805145, 21.85277939], [88.69805145, 21.8536129], [88.69833374, 21.85388947], [88.69832611, 21.8544426], [88.69889069, 21.85499954], [88.69889069, 21.85527039], [88.69917297, 21.8555603], [88.69917297, 21.85639], [88.6986084, 21.85694313], [88.6986084, 21.85861015], [88.69833374, 21.85888863], [88.69833374, 21.85925102], [88.69832611, 21.86000061], [88.6986084, 21.86028099], [88.6986084, 21.86055756], [88.69889069, 21.86083031], [88.69889069, 21.86111069], [88.69972229, 21.86194038], [88.69972229, 21.86250114], [88.70083618, 21.86361122], [88.70083618, 21.86388969], [88.70111084, 21.86416817], [88.70111084, 21.86499977], [88.7013855, 21.86499977], [88.70249939, 21.86611176], [88.70249939, 21.86639023], [88.70276642, 21.86667252], [88.70276642, 21.86750031], [88.70305634, 21.86777687], [88.70305634, 21.86833191], [88.70361328, 21.86889076], [88.70361328, 21.86916733], [88.70388794, 21.86944389], [88.70388794, 21.86972237], [88.70417023, 21.87000084], [88.70417786, 21.87111092], [88.70443726, 21.87138939], [88.70444489, 21.87166405], [88.70500183, 21.87222099], [88.70500183, 21.87249947], [88.70527649, 21.87277985], [88.70549774, 21.87277985], [88.70582581, 21.87277985], [88.70610809, 21.87306023], [88.70610809, 21.87333298], [88.70580292, 21.87364388], [88.70555878, 21.87388992], [88.70555878, 21.8741703], [88.70639038, 21.875], [88.70639038, 21.87528038], [88.70666504, 21.87555695], [88.70666504, 21.87583351], [88.70694733, 21.87610817], [88.70694733, 21.87639809], [88.70722198, 21.87666893], [88.70722198, 21.87694359], [88.70694733, 21.87721825], [88.70777893, 21.87805557], [88.70777893, 21.87832832], [88.70805359, 21.87861061], [88.70805359, 21.87944412], [88.70833588, 21.87972069], [88.70833588, 21.87999916], [88.70916748, 21.88083267], [88.70916748, 21.88111115], [88.71028137, 21.88221169], [88.71028137, 21.88249969], [88.71055603, 21.88277817], [88.71055603, 21.88305473], [88.71083069, 21.88333321], [88.71083069, 21.88360977], [88.71111298, 21.88388824], [88.71111298, 21.88471985], [88.71138763, 21.88500023], [88.71138763, 21.88528061], [88.71166992, 21.88528061], [88.71166992, 21.88555336], [88.71186066, 21.88574982], [88.71194458, 21.88583565], [88.71194458, 21.88610077], [88.71194458, 21.88638878], [88.71203613, 21.88648033], [88.71250153, 21.88694382], [88.71250153, 21.88846016], [88.71250153, 21.88861084], [88.71221924, 21.88889122], [88.71221924, 21.88916779], [88.71250153, 21.88944435], [88.71250153, 21.88972282], [88.7127533, 21.8899765], [88.71305084, 21.89027977], [88.71305847, 21.89166641], [88.71333313, 21.89194489], [88.71333313, 21.89222145], [88.71360779, 21.89250183], [88.71360779, 21.8927784], [88.7141571, 21.89333153], [88.7141571, 21.89389038], [88.71444702, 21.89417267], [88.71444702, 21.89500046], [88.71472168, 21.89528275], [88.71472168, 21.89639091], [88.7158432, 21.89751053], [88.71583557, 21.89777756], [88.71527863, 21.89833069], [88.71527863, 21.89861107], [88.71555328, 21.89888954], [88.71555328, 21.89923096], [88.71555328, 21.89972305], [88.7158432, 21.89999962], [88.7158432, 21.90139008], [88.71611786, 21.90167046], [88.71611786, 21.90306091], [88.71666718, 21.90360832], [88.71666718, 21.90611076], [88.71639252, 21.90638924], [88.71694183, 21.90638924], [88.71778107, 21.90722275], [88.71805573, 21.90722275], [88.71833038, 21.90694427], [88.71861267, 21.90694427], [88.71944427, 21.90611076], [88.71943665, 21.90582848], [88.72083282, 21.90444374], [88.72110748, 21.90444374], [88.72194672, 21.90360832], [88.72194672, 21.90332031], [88.72222137, 21.90305519], [88.72222137, 21.90278053], [88.72305298, 21.90195084], [88.72305298, 21.90167046], [88.72360992, 21.90167046], [88.72528076, 21.89999962], [88.72556305, 21.89999962], [88.72583008, 21.89972305], [88.72611237, 21.89972305], [88.72666931, 21.8991642], [88.72750092, 21.89916992], [88.7277832, 21.89888954], [88.72861481, 21.89888954], [88.72888947, 21.89861107], [88.73027802, 21.89861107], [88.73055267, 21.89833069], [88.73139191, 21.8983326], [88.73166656, 21.89805412], [88.73194122, 21.89805412], [88.73222351, 21.8983326], [88.73628998, 21.89833069], [88.73665619, 21.89833069], [88.73694611, 21.89861107], [88.7388916, 21.89861107], [88.73916626, 21.89888954], [88.74223328, 21.89888954], [88.74250031, 21.89861107], [88.74305725, 21.89861107], [88.74333191, 21.89833069], [88.74388885, 21.8983326], [88.74416351, 21.89805412], [88.74472046, 21.89805984], [88.74500275, 21.89777946], [88.7452774, 21.89777946], [88.74555206, 21.89751053], [88.74582672, 21.89751053], [88.74610138, 21.89722061], [88.7463913, 21.89722252], [88.74666595, 21.89694214], [88.74694824, 21.89694214], [88.7472229, 21.89666748], [88.74749756, 21.89666939], [88.74804687, 21.89611053], [88.74833679, 21.89611053], [88.74861145, 21.89583015], [88.74861145, 21.8955555], [88.74916077, 21.89500046], [88.74916077, 21.89472008], [88.74944305, 21.89444351], [88.74944305, 21.89423943], [88.74944305, 21.89305496], [88.74916077, 21.8927803], [88.74916077, 21.89193916], [88.74888611, 21.89166641], [88.74888611, 21.89110756], [88.74833679, 21.89055634], [88.74833679, 21.89027977], [88.74861145, 21.88999748], [88.74861145, 21.88944054], [88.74888611, 21.88916779], [88.74888611, 21.88889122], [88.74973297, 21.88805962], [88.75, 21.88805962], [88.75110626, 21.88694], [88.75138855, 21.88694382], [88.75166321, 21.88666534], [88.75222778, 21.88667107], [88.75250244, 21.88639069], [88.75332642, 21.88639069], [88.7536087, 21.88611031], [88.75461578, 21.88611031], [88.75527954, 21.88611031], [88.7555542, 21.88583565], [88.75583649, 21.88583565], [88.75666809, 21.88500023], [88.75666809, 21.88385963], [88.75666809, 21.88361168], [88.7563858, 21.88333321], [88.7563858, 21.88277817], [88.75611115, 21.88249969], [88.75611115, 21.88221169], [88.75583649, 21.88194466], [88.75583649, 21.88111115], [88.75611115, 21.88083267], [88.75611115, 21.88027763], [88.75749969, 21.87888908], [88.75776672, 21.87888908], [88.75805664, 21.87861061], [88.75888824, 21.87861061], [88.7591629, 21.87832832], [88.76000214, 21.87833405], [88.76027679, 21.87805557], [88.76110077, 21.87805939], [88.76139069, 21.87778091], [88.76249695, 21.87778091], [88.76277924, 21.87750053], [88.76333618, 21.87750053], [88.76361084, 21.87721825], [88.76444244, 21.87722206], [88.76472473, 21.87694359], [88.76557159, 21.87694359], [88.76667023, 21.87694359], [88.76694489, 21.87722206], [88.76750183, 21.87721825], [88.76777649, 21.87750053], [88.76805878, 21.87750053], [88.76832581, 21.87721825], [88.76889038, 21.87722206], [88.76916504, 21.87750053], [88.76944733, 21.87722206], [88.76999664, 21.87722206], [88.77008057, 21.87714005], [88.77055359, 21.87666893], [88.77083588, 21.87667084], [88.77111053, 21.87639809], [88.77139282, 21.87639809], [88.77166748, 21.87610817], [88.77166748, 21.87583351], [88.77222443, 21.87527847], [88.7722168, 21.87471962], [88.77249908, 21.87444687], [88.77249908, 21.8741703], [88.77278137, 21.87388992], [88.77278137, 21.87360954], [88.77305603, 21.87333298], [88.77305603, 21.87277985], [88.77333069, 21.87249947], [88.77333069, 21.87222099], [88.77361298, 21.87194443], [88.77361298, 21.87166405], [88.77388763, 21.87138939], [88.77388763, 21.87111092], [88.77443695, 21.87055969], [88.77443695, 21.87026978], [88.77471924, 21.87000084], [88.77471924, 21.86972046], [88.77527618, 21.86916733], [88.77527618, 21.86889076], [88.77500153, 21.86861038], [88.77500153, 21.86833191], [88.77471924, 21.86805534], [88.77471924, 21.86611176], [88.77482605, 21.86600685], [88.77500153, 21.86583328], [88.77500153, 21.86499977], [88.77722168, 21.86277962], [88.77749634, 21.86277962], [88.7783432, 21.86194038], [88.77861023, 21.8619442], [88.77972412, 21.86083412], [88.77972412, 21.86055756], [88.77999878, 21.86028099], [88.77999878, 21.86000061], [88.78056335, 21.85943985], [88.77999878, 21.85888863], [88.77971649, 21.85889053], [88.77944183, 21.85861015], [88.77916718, 21.85861206], [88.77889252, 21.85833359], [88.77833557, 21.85833359], [88.77805328, 21.85805321], [88.77777863, 21.85806084], [88.77749634, 21.85778046], [88.77722168, 21.85778046], [88.77694702, 21.85750008], [88.77639008, 21.85750008], [88.77610779, 21.8572197], [88.77444458, 21.8572216], [88.77416992, 21.85694313], [88.77361298, 21.85695076], [88.77333069, 21.85667038], [88.77305603, 21.85667038], [88.77278137, 21.85639], [88.77249908, 21.85639], [88.7722168, 21.85610962], [88.77166748, 21.85611153], [88.77166748, 21.85583115], [88.76916504, 21.85333252], [88.76916504, 21.85305595], [88.76860809, 21.85250092], [88.76860809, 21.85220909], [88.76889038, 21.85194397], [88.76860809, 21.8516674], [88.76860809, 21.85055923], [88.76832581, 21.85028076], [88.76832581, 21.84694099], [88.76805878, 21.84666443], [88.76805878, 21.84638977], [88.76777649, 21.84610939], [88.76777649, 21.84555435], [88.76750183, 21.84527969], [88.76750183, 21.84500122], [88.76722717, 21.84472084], [88.76721954, 21.84444427], [88.76694489, 21.8441658], [88.76693726, 21.84389114], [88.76667023, 21.84361076], [88.76667023, 21.84333038], [88.76638794, 21.84305573], [88.76638794, 21.84278107], [88.76583099, 21.84222031], [88.76583099, 21.84194374], [88.76555634, 21.84166718], [88.76583099, 21.84139061], [88.76583099, 21.84056282], [88.76555634, 21.84026909], [88.76555634, 21.83944511], [88.76526642, 21.83917046], [88.76526642, 21.83889008], [88.76499939, 21.8386116], [88.76499939, 21.83805466], [88.76472473, 21.83777809], [88.7647171, 21.83666992], [88.76444244, 21.83638954], [88.76444244, 21.83527946], [88.76416779, 21.83500099], [88.76416779, 21.83389091], [88.76389313, 21.83361053], [88.7638855, 21.82861137], [88.76416779, 21.82861137], [88.76444244, 21.8283329], [88.76444244, 21.82805634], [88.7647171, 21.82777977], [88.7647171, 21.82722282], [88.76499939, 21.82694435], [88.76499939, 21.82666588], [88.76555634, 21.82611084], [88.76583099, 21.82611084], [88.76611328, 21.82582855], [88.76638794, 21.82583427], [88.76667023, 21.8255558], [88.76693726, 21.82555962], [88.76722717, 21.82529259], [88.76750183, 21.82529259], [88.76805878, 21.82471848], [88.76860809, 21.82472229], [88.76889038, 21.82444382], [88.76944733, 21.82444382], [88.76972198, 21.82416725], [88.77083588, 21.82416916], [88.77111053, 21.82389069], [88.77388763, 21.82389069], [88.77416992, 21.82416916], [88.77471924, 21.82416916], [88.77500153, 21.82389069], [88.77583313, 21.82389069], [88.77610779, 21.82361031], [88.77639008, 21.82361031], [88.77722168, 21.82278061], [88.77722168, 21.82167053], [88.77555847, 21.81999969], [88.77555847, 21.81972122], [88.77527618, 21.81944656], [88.77527618, 21.81916428], [88.77500153, 21.81888962], [88.77500153, 21.81861115], [88.77471924, 21.81833076], [88.77471924, 21.81777763], [88.77443695, 21.81750107], [88.77443695, 21.81694031], [88.77416992, 21.81666756], [88.77416992, 21.8163929], [88.77388763, 21.81610107], [88.77388763, 21.81500053], [88.77416992, 21.81472015], [88.77416992, 21.81444359], [88.77444458, 21.81416702], [88.77443695, 21.81361008], [88.77471924, 21.81333351], [88.77471924, 21.81250191], [88.77500153, 21.81222153], [88.77500153, 21.81194496], [88.77527618, 21.8116703], [88.77527618, 21.81138992], [88.77500153, 21.81110764], [88.77500153, 21.80999947], [88.77471924, 21.80971909], [88.77471924, 21.80944443], [88.77416992, 21.80888939], [88.77416992, 21.80861092], [88.77333069, 21.80778122], [88.77333069, 21.80750084], [88.77305603, 21.80722046], [88.77305603, 21.8069458], [88.77111053, 21.80500031], [88.77083588, 21.80500031], [88.7702713, 21.80445099], [88.7702713, 21.80416107], [88.76860809, 21.80249977], [88.76860809, 21.80221939], [88.76805878, 21.80166626], [88.76805878, 21.80138969], [88.76777649, 21.80112076], [88.76777649, 21.80083275], [88.76750183, 21.80055618], [88.76750183, 21.80027962], [88.76722717, 21.80000114], [88.76722717, 21.79943848], [88.76694489, 21.79916573], [88.76693726, 21.7983284], [88.76667023, 21.79805565], [88.76667023, 21.79693985], [88.76638794, 21.7966671], [88.76638794, 21.79582977], [88.76611328, 21.79555511], [88.76611328, 21.79528046], [88.76638794, 21.79499054], [88.76638794, 21.79444695], [88.76611328, 21.79417038], [88.76611328, 21.79360962], [88.76583099, 21.79333305], [88.76583099, 21.79277611], [88.76555634, 21.79249954], [88.76555634, 21.79193115], [88.76527405, 21.79166412], [88.76526642, 21.79138947], [88.76499939, 21.79111099], [88.76499939, 21.79091072], [88.76499939, 21.79055405], [88.7647171, 21.79027939], [88.7647171, 21.78972054], [88.76416779, 21.7891674], [88.76444244, 21.78918076], [88.76444244, 21.78889084], [88.76416779, 21.78861046], [88.76416779, 21.78833008], [88.7638855, 21.78805542], [88.76389313, 21.78750038], [88.76277924, 21.7863884], [88.76277924, 21.78611946], [88.76167297, 21.78499985], [88.76166534, 21.78472137], [88.7583313, 21.78138924], [88.75805664, 21.78139114], [88.75776672, 21.78111076], [88.75694275, 21.78111076], [88.75666046, 21.78133583], [88.7563858, 21.78139114], [88.75611115, 21.78166771], [88.75611115, 21.78194427], [88.75583649, 21.78222084], [88.75583649, 21.78250122], [88.7555542, 21.78277969], [88.7555542, 21.78305626], [88.75527954, 21.78333282], [88.75528717, 21.78360748], [88.75499725, 21.78388977], [88.75499725, 21.78416634], [88.7547226, 21.78444481], [88.7547226, 21.78471756], [88.75444794, 21.78499985], [88.75444794, 21.78527832], [88.75416565, 21.78555489], [88.75417328, 21.78583145], [88.75389099, 21.78611946], [88.75389099, 21.7863903], [88.7536087, 21.78667259], [88.7536087, 21.78694534], [88.75332642, 21.78722191], [88.75332642, 21.78778267], [88.75305176, 21.78806114], [88.75305176, 21.78888893], [88.75250244, 21.78944016], [88.75250244, 21.79249954], [88.75222015, 21.79277611], [88.75222778, 21.79499054], [88.7519455, 21.79527855], [88.7519455, 21.79694366], [88.75166321, 21.79722214], [88.75166321, 21.7983284], [88.75138855, 21.79861069], [88.75138855, 21.7994442], [88.75110626, 21.79972076], [88.75110626, 21.80027962], [88.7508316, 21.8005619], [88.7508316, 21.80528069], [88.75110626, 21.80556107], [88.75111389, 21.80666542], [88.75138855, 21.80693054], [88.75138855, 21.80805779], [88.75166321, 21.80833054], [88.75166321, 21.80888939], [88.7519455, 21.80916786], [88.7519455, 21.80944443], [88.75222778, 21.80971909], [88.75222015, 21.81055641], [88.75250244, 21.81082916], [88.75250244, 21.8116703], [88.7527771, 21.81194496], [88.7527771, 21.81222153], [88.75250244, 21.81250191], [88.75250244, 21.81444168], [88.75166321, 21.81528282], [88.75111389, 21.8152771], [88.75027466, 21.81611061], [88.75, 21.81610107], [88.74973297, 21.8163929], [88.74888611, 21.81555939], [88.74888611, 21.81528282], [88.74833679, 21.81472015], [88.7480545, 21.81472206], [88.74694824, 21.81361008], [88.74666595, 21.81361008], [88.74666595, 21.81333351], [88.74333191, 21.80999947], [88.74305725, 21.80999947], [88.74194336, 21.80888939], [88.74194336, 21.80833054], [88.73999786, 21.80638885], [88.73999786, 21.80611038], [88.73944092, 21.80556107], [88.73944092, 21.80528069], [88.73832703, 21.80416107], [88.73833466, 21.80388832], [88.73805237, 21.80360985], [88.73805237, 21.80333328], [88.73777771, 21.80305481], [88.73777771, 21.8022213], [88.73750305, 21.80194473], [88.73750305, 21.80083275], [88.73722076, 21.80055618], [88.73722076, 21.80000114], [88.73694611, 21.79972076], [88.73694611, 21.79916573], [88.73583221, 21.79805946], [88.7352829, 21.79805946], [88.73500061, 21.79777908], [88.73139191, 21.79777908], [88.73130035, 21.79768753], [88.73111725, 21.79750061], [88.73082733, 21.79750061], [88.73054504, 21.79727173], [88.73000336, 21.79722214], [88.72972107, 21.79694366], [88.72944641, 21.79694366], [88.72916412, 21.7966671], [88.72888947, 21.79667091], [88.72851563, 21.79629517], [88.72833252, 21.79610825], [88.72805786, 21.79611206], [88.72694397, 21.79500008], [88.72666931, 21.79500008], [88.72638702, 21.7947216], [88.72611237, 21.7947216], [88.72583008, 21.79444695], [88.72528076, 21.79444695], [88.72499847, 21.7947216], [88.72444153, 21.7947216], [88.72416687, 21.79500008], [88.72389221, 21.79499054], [88.72333527, 21.79555511], [88.7233429, 21.79610825], [88.72305298, 21.79638863], [88.72305298, 21.79721832], [88.72277832, 21.79750061], [88.72277832, 21.80027962], [88.72249603, 21.8005619], [88.72249603, 21.80112076], [88.72222137, 21.80138969], [88.72222137, 21.80194473], [88.72194672, 21.80221939], [88.72194672, 21.80249977], [88.72166443, 21.80277824], [88.72166443, 21.80333328], [88.72138977, 21.80360985], [88.72138977, 21.80388832], [88.72110748, 21.80416107], [88.72110748, 21.80444336], [88.72083282, 21.80471992], [88.72083282, 21.80500031], [88.72000122, 21.80583], [88.72000122, 21.80611038], [88.71944427, 21.80666542], [88.71943665, 21.80693054], [88.71833038, 21.80805969], [88.71778107, 21.80805969], [88.71721649, 21.80861092], [88.71694183, 21.80861092], [88.71611023, 21.80944443], [88.71499634, 21.80944443], [88.71472168, 21.80971909], [88.71414948, 21.8100338], [88.71405029, 21.81008911], [88.71246338, 21.81054115], [88.71092224, 21.81038475], [88.71044159, 21.81033707], [88.7097168, 21.81028938], [88.70944214, 21.81028938], [88.70916748, 21.81055832], [88.70861053, 21.81055641]]], [[[88.83655548, 21.91789246], [88.84912872, 21.91178513], [88.85686493, 21.91070747], [88.86631775, 21.91366768], [88.86831665, 21.91501045], [88.87256622, 21.91679001], [88.87548065, 21.91749954], [88.87812042, 21.91737938], [88.88070679, 21.91655922], [88.88323212, 21.91542053], [88.88607788, 21.91501236], [88.88659668, 21.91445732], [88.8881073, 21.91451073], [88.89006805, 21.91465569], [88.89124298, 21.91527939], [88.8949585, 21.91689491], [88.90236664, 21.91888046], [88.90497589, 21.91957855], [88.90956879, 21.92308044], [88.91191864, 21.92618752], [88.91221619, 21.92657852], [88.91456604, 21.92811966], [88.91517639, 21.92818069], [88.91500092, 21.92795944], [88.91514587, 21.92789459], [88.91678619, 21.92717361], [88.9171524, 21.9270134], [88.91986847, 21.92606926], [88.92056274, 21.92583084], [88.92166901, 21.92472267], [88.92194366, 21.92472267], [88.92222595, 21.92444229], [88.92250061, 21.92444992], [88.9227829, 21.92416954], [88.92333221, 21.92416954], [88.92359924, 21.92389107], [88.92415619, 21.92389107], [88.92722321, 21.92083168], [88.92749786, 21.92083359], [88.92861176, 21.9197216], [88.92888641, 21.9197216], [88.93023682, 21.9183712], [88.93166351, 21.9169445], [88.93222046, 21.9169445], [88.93250275, 21.91666794], [88.93276978, 21.91666985], [88.93332672, 21.91611099], [88.93360901, 21.91611099], [88.9338913, 21.91583061], [88.93416595, 21.91583252], [88.93416595, 21.91555786], [88.93444824, 21.91527557], [88.9347229, 21.91527939], [88.93499756, 21.91500092], [88.93582916, 21.91500092], [88.93638611, 21.91444016], [88.9366684, 21.91444588], [88.93694305, 21.9141655], [88.93723297, 21.91417122], [88.9375, 21.91389084], [88.93805695, 21.91389084], [88.9383316, 21.91361046], [88.93860626, 21.91361046], [88.93889618, 21.91333008], [88.93916321, 21.9133358], [88.93972015, 21.91277695], [88.94000244, 21.91278076], [88.9402771, 21.91250992], [88.94055176, 21.91250992], [88.94082642, 21.91222], [88.9411087, 21.91222191], [88.94139099, 21.91194344], [88.94167328, 21.91195107], [88.9422226, 21.9113903], [88.94249725, 21.9113903], [88.94277954, 21.91110992], [88.94333649, 21.91111183], [88.94361115, 21.91083336], [88.9438858, 21.91083336], [88.94416809, 21.91055489], [88.94444275, 21.91055489], [88.94499969, 21.90999985], [88.9458313, 21.90999985], [88.94610596, 21.90971947], [88.94694519, 21.90972137], [88.94750214, 21.90916634], [88.94776917, 21.90917015], [88.94805908, 21.90888977], [88.94832611, 21.90888977], [88.9486084, 21.90860939], [88.94889069, 21.9086113], [88.94944763, 21.90805626], [88.95083618, 21.90806007], [88.95139313, 21.90750122], [88.9522171, 21.90750122], [88.95249939, 21.90722275], [88.95277405, 21.90722275], [88.95305634, 21.90694427], [88.95361328, 21.90694427], [88.95388794, 21.9066658], [88.95417023, 21.90666962], [88.95443726, 21.9063797], [88.95471954, 21.90638924], [88.95500183, 21.90611076], [88.95555878, 21.90611076], [88.95610809, 21.90555954], [88.95639038, 21.90555954], [88.95667267, 21.90527916], [88.95722198, 21.90527916], [88.95749664, 21.90500069], [88.95777893, 21.90500069], [88.95804596, 21.9047184], [88.95861053, 21.90472221], [88.95888519, 21.90444374], [88.95916748, 21.90444374], [88.95972443, 21.90389061], [88.96138763, 21.90389061], [88.96166992, 21.90360832], [88.96221924, 21.90360832], [88.96277618, 21.90306091], [88.96333313, 21.90306091], [88.96360779, 21.90278053], [88.96389008, 21.90278053], [88.9641571, 21.90250015], [88.96444702, 21.90250015], [88.96470642, 21.90223122], [88.96499634, 21.90221977], [88.96527863, 21.90194511], [88.96555328, 21.90195084], [88.9658432, 21.90167046], [88.96611023, 21.90167046], [88.96639252, 21.90139008], [88.96694183, 21.90139008], [88.96721649, 21.9011097], [88.96778107, 21.9011116], [88.96805573, 21.90083313], [88.96833038, 21.90083313], [88.96861267, 21.90055466], [88.96888733, 21.90055466], [88.96916962, 21.90027618], [88.96943665, 21.90028], [88.96971893, 21.89999962], [88.97000122, 21.89999962], [88.97027588, 21.89972115], [88.97055817, 21.89972305], [88.97083282, 21.89944649], [88.97110748, 21.89944649], [88.97138977, 21.8991642], [88.97164917, 21.89916992], [88.97222137, 21.89861107], [88.97249603, 21.89861107], [88.97277832, 21.89833069], [88.97305298, 21.8983326], [88.97360992, 21.89777756], [88.97389221, 21.89777946], [88.97471619, 21.89694023], [88.97360992, 21.89583206], [88.97277832, 21.89583206], [88.97250366, 21.8955555], [88.97164917, 21.89556122], [88.97138977, 21.89528275], [88.97000122, 21.89528275], [88.96971893, 21.89500046], [88.96916962, 21.89500046], [88.9688797, 21.89472008], [88.96861267, 21.89472008], [88.96833038, 21.89444351], [88.96805573, 21.89444351], [88.96749878, 21.89388847], [88.96721649, 21.89389038], [88.96666718, 21.89333153], [88.96666718, 21.89305496], [88.96639252, 21.8927803], [88.96639252, 21.89193916], [88.96611023, 21.89166641], [88.96611023, 21.89027977], [88.96639252, 21.88999748], [88.96639252, 21.88972092], [88.96666718, 21.88944435], [88.96666718, 21.88805771], [88.96694183, 21.88778114], [88.96694183, 21.88694], [88.96722412, 21.88666534], [88.96721649, 21.88611031], [88.96749878, 21.88582993], [88.96749878, 21.88555336], [88.96778107, 21.88528061], [88.96778107, 21.88500023], [88.96806335, 21.88471985], [88.96805573, 21.88444328], [88.96861267, 21.88389015], [88.96861267, 21.88360977], [88.96944427, 21.88277817], [88.96943665, 21.88249969], [88.96971893, 21.88221169], [88.96971893, 21.88194466], [88.97000122, 21.88166618], [88.97000122, 21.88111115], [88.97027588, 21.88083267], [88.97027588, 21.88055611], [88.97055817, 21.88027954], [88.97055817, 21.88000107], [88.97083282, 21.87972069], [88.97083282, 21.87944412], [88.97110748, 21.87916756], [88.97110748, 21.87888908], [88.97138977, 21.87861061], [88.97138977, 21.87832832], [88.97222137, 21.87750053], [88.97222137, 21.87721825], [88.97250366, 21.87694359], [88.97250366, 21.87638664], [88.97263336, 21.87610817], [88.97277832, 21.87583351], [88.97305298, 21.87555695], [88.97305298, 21.87528038], [88.9733429, 21.875], [88.97333527, 21.87472153], [88.97360992, 21.87444687], [88.97360992, 21.8741703], [88.97416687, 21.87360954], [88.97416687, 21.8730545], [88.97444153, 21.87277985], [88.97444153, 21.87249947], [88.97471619, 21.87222099], [88.97472382, 21.87194443], [88.97499847, 21.87166405], [88.97499847, 21.87138939], [88.97528076, 21.87111092], [88.97528076, 21.87083054], [88.97583008, 21.8702774], [88.97583008, 21.87000084], [88.97611237, 21.86972046], [88.97611237, 21.86944389], [88.97666931, 21.86888885], [88.97666931, 21.86750031], [88.97611237, 21.8669529], [88.97583008, 21.8669529], [88.97566986, 21.86678314], [88.97555542, 21.86666679], [88.97389221, 21.86667252], [88.97360992, 21.86639023], [88.97305298, 21.86639023], [88.97277832, 21.86611176], [88.97166443, 21.86611176], [88.97166443, 21.86583328], [88.97138977, 21.86555481], [88.97110748, 21.86583328], [88.97027588, 21.86583328], [88.97000122, 21.86555481], [88.96916962, 21.86555481], [88.96908569, 21.86547279], [88.96888733, 21.86527824], [88.96833038, 21.86528015], [88.96806335, 21.86499977], [88.96795654, 21.86499977], [88.96778107, 21.86499977], [88.96749878, 21.86471748], [88.96722412, 21.8647213], [88.96639252, 21.86388969], [88.96611023, 21.86388969], [88.9658432, 21.86361122], [88.96555328, 21.86361122], [88.96527863, 21.86333084], [88.96499634, 21.86333275], [88.96472168, 21.86305618], [88.96444702, 21.86305809], [88.96342468, 21.86203766], [88.96221924, 21.86083412], [88.96221924, 21.86055756], [88.96193695, 21.86028099], [88.96166992, 21.86028099], [88.96129608, 21.85990715], [88.96111298, 21.85972214], [88.96111298, 21.85944366], [88.96055603, 21.85888863], [88.96055603, 21.85861015], [88.95999908, 21.85805321], [88.95999908, 21.85778046], [88.95970917, 21.85750008], [88.95970917, 21.85695076], [88.95916748, 21.85639], [88.95916748, 21.85610962], [88.95694733, 21.85388947], [88.95666504, 21.85388947], [88.95639038, 21.8536129], [88.95610809, 21.8536129], [88.95582581, 21.85388947], [88.95555878, 21.85388947], [88.95500183, 21.8544426], [88.95498657, 21.85473061], [88.95471954, 21.85499954], [88.95471954, 21.85555649], [88.95444489, 21.85583115], [88.95444489, 21.85611153], [88.95333099, 21.8572197], [88.95333099, 21.85805321], [88.95305634, 21.85832977], [88.95305634, 21.85889053], [88.95276642, 21.85917091], [88.95276642, 21.86000061], [88.95249939, 21.86028099], [88.95249939, 21.86055756], [88.9522171, 21.86083031], [88.9522171, 21.8614006], [88.95194244, 21.86166954], [88.95194244, 21.86250114], [88.9522171, 21.86277962], [88.9522171, 21.86361122], [88.95249939, 21.86388969], [88.9522171, 21.86416817], [88.95194244, 21.86416626], [88.95222473, 21.86444473], [88.95249939, 21.86444092], [88.95305634, 21.86499977], [88.95333099, 21.86499977], [88.95388794, 21.86555481], [88.95417023, 21.86555481], [88.95444489, 21.86583328], [88.95471954, 21.86583328], [88.95500183, 21.86611176], [88.95527649, 21.86611176], [88.95555878, 21.86639023], [88.95582581, 21.86639023], [88.95610809, 21.86667252], [88.95639038, 21.86666679], [88.95657349, 21.86685181], [88.95667267, 21.8669529], [88.9569397, 21.8669529], [88.95749664, 21.86750031], [88.95777893, 21.86750031], [88.95804596, 21.86778069], [88.95833588, 21.86778069], [88.95861053, 21.86806107], [88.95861053, 21.86861038], [88.95888519, 21.86888885], [88.95888519, 21.86972237], [88.95833588, 21.87026978], [88.95833588, 21.87055969], [88.95249939, 21.87639809], [88.95249939, 21.87666893], [88.95194244, 21.87721825], [88.95194244, 21.87750053], [88.95166779, 21.8777771], [88.95166779, 21.87833405], [88.9513855, 21.87861061], [88.95139313, 21.88083267], [88.95111084, 21.88111115], [88.95111084, 21.88138962], [88.9513855, 21.88166618], [88.95139313, 21.88249969], [88.95111084, 21.88277817], [88.95111084, 21.88333321], [88.95083618, 21.88360977], [88.95083618, 21.88417053], [88.95055389, 21.88444328], [88.95054626, 21.88471985], [88.95027924, 21.88500023], [88.95027924, 21.8852787], [88.94972229, 21.88582993], [88.94972229, 21.88639069], [88.94944763, 21.88667107], [88.94889069, 21.88666534], [88.94889069, 21.88694382], [88.9486084, 21.88694382], [88.94833374, 21.88722229], [88.94777679, 21.88722229], [88.94721985, 21.88666534], [88.94695282, 21.88667107], [88.9466629, 21.88639069], [88.94638824, 21.88639069], [88.94610596, 21.88611031], [88.9458313, 21.88611031], [88.94555664, 21.88582993], [88.94527435, 21.88583565], [88.94472504, 21.8852787], [88.94444275, 21.88528061], [88.94416809, 21.88500023], [88.9438858, 21.88500023], [88.94361115, 21.88471985], [88.94333649, 21.88472176], [88.94194794, 21.88333321], [88.9422226, 21.88305473], [88.94249725, 21.88305473], [88.94277954, 21.88277817], [88.9430542, 21.88305473], [88.94333649, 21.88305473], [88.9438858, 21.88361168], [88.94416809, 21.88360977], [88.94473267, 21.88417053], [88.94499969, 21.88417053], [88.94526672, 21.88445091], [88.94555664, 21.88444328], [88.9458313, 21.88472176], [88.94610596, 21.88471985], [88.94638824, 21.88500023], [88.94721985, 21.88500023], [88.94750214, 21.88528061], [88.94776917, 21.88528061], [88.94805908, 21.88500023], [88.9486084, 21.88500023], [88.94944763, 21.88417053], [88.94944763, 21.88194275], [88.94972229, 21.88166618], [88.94972229, 21.88027954], [88.94999695, 21.88000107], [88.94999695, 21.87916946], [88.95027924, 21.87888908], [88.95027924, 21.87778091], [88.95054626, 21.87750053], [88.95054626, 21.87693977], [88.95083618, 21.87666893], [88.95083618, 21.87639809], [88.95111084, 21.87610817], [88.95111084, 21.87583351], [88.9513855, 21.87555695], [88.95139313, 21.87528038], [88.95166779, 21.875], [88.95166779, 21.87471962], [88.95249939, 21.87388611], [88.95276642, 21.87388992], [88.95443726, 21.87222099], [88.95471954, 21.87222481], [88.95666504, 21.8702774], [88.95666504, 21.87000084], [88.95694733, 21.86972237], [88.95666504, 21.86944389], [88.95666504, 21.86916733], [88.95582581, 21.86833191], [88.95555878, 21.86833382], [88.95444489, 21.86722183], [88.95417023, 21.86722183], [88.95388794, 21.86694527], [88.95361328, 21.8669529], [88.95305634, 21.86639023], [88.95276642, 21.86639023], [88.95111084, 21.86471748], [88.95083618, 21.8647213], [88.95027924, 21.86416626], [88.95027924, 21.86250114], [88.95054626, 21.86222076], [88.95055389, 21.86138916], [88.95083618, 21.86111069], [88.95083618, 21.86083031], [88.95111084, 21.86055756], [88.95111084, 21.85943985], [88.9513855, 21.85916519], [88.95139313, 21.85861015], [88.95166779, 21.85833359], [88.95166779, 21.85750008], [88.95188141, 21.85720825], [88.95194244, 21.85694313], [88.95222473, 21.85666656], [88.95222473, 21.85580063], [88.95222473, 21.85416603], [88.95249939, 21.85388947], [88.95249939, 21.85342026], [88.95276642, 21.85306168], [88.95276642, 21.85139084], [88.95249939, 21.85111046], [88.95249939, 21.85028076], [88.95139313, 21.84917068], [88.95139313, 21.8488903], [88.95111084, 21.84860992], [88.95111084, 21.84833336], [88.95083618, 21.84805679], [88.95083618, 21.84777832], [88.95054626, 21.84749985], [88.95054626, 21.84667015], [88.95027924, 21.84638977], [88.95027924, 21.84610939], [88.94972229, 21.84555435], [88.94972229, 21.84527969], [88.94944763, 21.84500122], [88.94944763, 21.84444046], [88.94916534, 21.8441658], [88.94917297, 21.84389114], [88.94889069, 21.84361076], [88.94889069, 21.84305954], [88.9486084, 21.84278107], [88.9486084, 21.84250069], [88.94832611, 21.84222031], [88.94833374, 21.84194374], [88.94805908, 21.84166718], [88.94805908, 21.84139061], [88.94721985, 21.84056282], [88.94638824, 21.84139061], [88.94638824, 21.84166718], [88.94611359, 21.84194374], [88.94610596, 21.84222031], [88.9458313, 21.84250069], [88.9458313, 21.84278107], [88.94555664, 21.84305573], [88.94555664, 21.84333229], [88.94536591, 21.84357071], [88.94526672, 21.84389114], [88.94499969, 21.8441658], [88.94499969, 21.84444046], [88.94444275, 21.84500122], [88.94444275, 21.84527779], [88.9438858, 21.84583282], [88.9438858, 21.84610939], [88.94361115, 21.84638977], [88.94361115, 21.84666443], [88.9422226, 21.84805679], [88.9422226, 21.84832954], [88.94139099, 21.84917068], [88.94139099, 21.84944534], [88.9411087, 21.84971809], [88.9411087, 21.85000038], [88.94082642, 21.85028076], [88.94083405, 21.8516674], [88.9402771, 21.85220909], [88.9402771, 21.85250092], [88.93916321, 21.8536129], [88.93889618, 21.8536129], [88.93860626, 21.85388947], [88.9366684, 21.85388947], [88.93638611, 21.8536129], [88.93250275, 21.8536129], [88.93222046, 21.8533287], [88.93138885, 21.85333252], [88.9311142, 21.85305595], [88.93028259, 21.85306168], [88.93009186, 21.85287094], [88.93000031, 21.85277748], [88.9291687, 21.85277939], [88.92888641, 21.85250092], [88.9283371, 21.85250092], [88.92804718, 21.85220909], [88.92694092, 21.85220909], [88.92666626, 21.85250092], [88.92610931, 21.85250092], [88.92582703, 21.85277939], [88.92555237, 21.85277939], [88.92472076, 21.8536129], [88.92472076, 21.85388947], [88.91944122, 21.85917091], [88.91916656, 21.85917091], [88.91777802, 21.86055756], [88.91779327, 21.86111069], [88.91750336, 21.8614006], [88.91750336, 21.86166763], [88.91694641, 21.86222267], [88.91694641, 21.86333084], [88.91722107, 21.86361122], [88.91722107, 21.86416626], [88.91694641, 21.86444473], [88.91694641, 21.86583328], [88.91666412, 21.86611176], [88.91665649, 21.86720848], [88.91638947, 21.86750031], [88.91638947, 21.86833191], [88.91665649, 21.86861038], [88.91666412, 21.86916733], [88.91638947, 21.86944389], [88.91638947, 21.86972046], [88.91610718, 21.87000084], [88.91611481, 21.87055588], [88.91583252, 21.87083244], [88.91583252, 21.87194443], [88.91555786, 21.87222481], [88.91555786, 21.87472153], [88.91527557, 21.875], [88.91527557, 21.87583351], [88.91555786, 21.87611198], [88.91555786, 21.87721825], [88.91611481, 21.8777771], [88.91555786, 21.87832832], [88.91555786, 21.87861061], [88.9152832, 21.87888908], [88.9152832, 21.88000107], [88.91555786, 21.88027763], [88.91500092, 21.88083267], [88.91471863, 21.88083267], [88.91444397, 21.88055611], [88.91388702, 21.88055611], [88.91361237, 21.88083267], [88.91083527, 21.88083267], [88.9106369, 21.88063812], [88.91055298, 21.88055611], [88.91027832, 21.88056183], [88.90999603, 21.88027954], [88.90972137, 21.88027954], [88.9091568, 21.87972069], [88.90888977, 21.8797226], [88.90860748, 21.87944412], [88.90833282, 21.87944412], [88.90814972, 21.87925911], [88.90805817, 21.87916756], [88.90750122, 21.87916946], [88.90721893, 21.87888908], [88.90693665, 21.87888908], [88.90693665, 21.87861061], [88.90721893, 21.87832832], [88.90721893, 21.87805557], [88.90777588, 21.87805557], [88.90791321, 21.8781929], [88.90805817, 21.87833405], [88.90888977, 21.87832832], [88.9091568, 21.87861061], [88.90972137, 21.87861061], [88.91027832, 21.87916946], [88.91059113, 21.87920952], [88.91083527, 21.87944412], [88.91166687, 21.87944412], [88.91194153, 21.8797226], [88.91333008, 21.8797226], [88.91388702, 21.87916756], [88.91388702, 21.87888908], [88.91416931, 21.87861061], [88.91416931, 21.87721825], [88.91388702, 21.87694359], [88.91416931, 21.87666893], [88.91416931, 21.87610817], [88.91388702, 21.87583351], [88.91388702, 21.87333298], [88.91416931, 21.87306023], [88.91416931, 21.87249947], [88.91443634, 21.87222099], [88.91444397, 21.86972237], [88.91471863, 21.86944389], [88.91471863, 21.86888885], [88.91500092, 21.86861038], [88.91500092, 21.86750031], [88.9152832, 21.86720848], [88.91527557, 21.86611176], [88.91555786, 21.86583328], [88.91555786, 21.86333275], [88.91583252, 21.86305618], [88.91583252, 21.86250114], [88.9152832, 21.86194038], [88.91500092, 21.8619442], [88.91490936, 21.86185265], [88.91444397, 21.86138916], [88.91472626, 21.86111069], [88.91527557, 21.86111069], [88.91833496, 21.85805321], [88.91860962, 21.85806084], [88.91999817, 21.85667038], [88.91999817, 21.85639], [88.92028046, 21.85610962], [88.92028046, 21.85555649], [88.92082977, 21.85499954], [88.92082977, 21.85472107], [88.92166901, 21.85388947], [88.92193604, 21.85388947], [88.92359924, 21.85220909], [88.92388916, 21.85222244], [88.92416382, 21.85194397], [88.92444611, 21.85194397], [88.92500305, 21.85139084], [88.92527771, 21.85139084], [88.92555237, 21.85111046], [88.92610931, 21.85111046], [88.9263916, 21.85082817], [88.92666626, 21.85082817], [88.92694092, 21.85111046], [88.92722321, 21.85111046], [88.92749786, 21.85082817], [88.92778015, 21.85083389], [88.92805481, 21.85055542], [88.9283371, 21.85055542], [88.92861176, 21.85083389], [88.92888641, 21.85083389], [88.9291687, 21.85055542], [88.93027496, 21.85055542], [88.93055725, 21.85083389], [88.93250275, 21.85083389], [88.9325943, 21.85092545], [88.93276978, 21.85111046], [88.93332672, 21.85111046], [88.93360901, 21.85139084], [88.93444824, 21.85139084], [88.9347229, 21.85166931], [88.93527985, 21.8516674], [88.9355545, 21.85194397], [88.9375, 21.85194397], [88.93777466, 21.8516674], [88.9383316, 21.85166931], [88.93889618, 21.85111046], [88.93888855, 21.85083389], [88.93916321, 21.85055542], [88.93916321, 21.85000038], [88.93889618, 21.84971809], [88.93888855, 21.84944534], [88.9383316, 21.8488903], [88.93805695, 21.8488903], [88.93776703, 21.84860992], [88.9375, 21.84861183], [88.93694305, 21.84805679], [88.9366684, 21.84805679], [88.93638611, 21.84777832], [88.93582916, 21.84778023], [88.93553925, 21.84749985], [88.93527985, 21.84749985], [88.93416595, 21.84638977], [88.9338913, 21.84638977], [88.93332672, 21.84583092], [88.93333435, 21.84555435], [88.93305206, 21.84527969], [88.93305206, 21.84444046], [88.9327774, 21.8441658], [88.93276978, 21.84305954], [88.93305206, 21.84278107], [88.93305206, 21.8416729], [88.93332672, 21.84139061], [88.93332672, 21.84083176], [88.93305206, 21.84055519], [88.93305206, 21.84026909], [88.9327774, 21.84000015], [88.93276978, 21.83889008], [88.93222046, 21.83832932], [88.9319458, 21.83833313], [88.93166351, 21.83805466], [88.93138885, 21.83805466], [88.9311142, 21.83777809], [88.93083191, 21.83777809], [88.93055725, 21.83805466], [88.93000031, 21.83805466], [88.92972565, 21.83833313], [88.9263916, 21.83833313], [88.92610931, 21.83805466], [88.92583466, 21.83805466], [88.92555237, 21.83777809], [88.92472076, 21.83777809], [88.92359924, 21.83666992], [88.92359924, 21.83638954], [88.9227829, 21.83555984], [88.9227829, 21.83306122], [88.92305756, 21.83278084], [88.92305756, 21.83222008], [88.92333221, 21.83194351], [88.92333221, 21.83166695], [88.92415619, 21.83082962], [88.92388916, 21.83055305], [88.92388916, 21.82860947], [88.92444611, 21.82805634], [88.92415619, 21.82777977], [88.92415619, 21.82582855], [88.92388916, 21.8255558], [88.92388916, 21.82529259], [88.92305756, 21.8244381], [88.92250061, 21.82444382], [88.92222595, 21.82416725], [88.92138672, 21.82416725], [88.92111206, 21.82444382], [88.92056274, 21.8244381], [88.91999817, 21.82500076], [88.91971588, 21.82500076], [88.91944122, 21.82529259], [88.91916656, 21.82529259], [88.91889191, 21.82555962], [88.91860962, 21.8255558], [88.91833496, 21.82583427], [88.91805267, 21.82582855], [88.91750336, 21.82638931], [88.91722107, 21.82638931], [88.91666412, 21.82694435], [88.91638947, 21.82694435], [88.91611481, 21.82722282], [88.91555786, 21.82722282], [88.9152832, 21.82749939], [88.91443634, 21.82749939], [88.91422272, 21.82727623], [88.91416931, 21.82722282], [88.91361237, 21.82722282], [88.91333008, 21.82694435], [88.91305542, 21.82694435], [88.91249847, 21.82638931], [88.91221619, 21.82638931], [88.91194153, 21.82611084], [88.91165924, 21.82611084], [88.91148376, 21.82592583], [88.91139221, 21.82583427], [88.91110992, 21.82583427], [88.91083527, 21.8255558], [88.91055298, 21.82555962], [88.90999603, 21.82500076], [88.90972137, 21.82472229], [88.90972137, 21.82444382], [88.90860748, 21.82333374], [88.90777588, 21.82333374], [88.90766907, 21.82322311], [88.90750122, 21.82305527], [88.90666962, 21.82305908], [88.90638733, 21.82278061], [88.90583038, 21.82278061], [88.90556335, 21.82250023], [88.90444183, 21.82250023], [88.90416718, 21.82222748], [88.9033432, 21.82222748], [88.90305328, 21.82195091], [88.90278625, 21.82195091], [88.90249634, 21.82167053], [88.90222168, 21.82167053], [88.9016571, 21.82110977], [88.90139008, 21.82111168], [88.90083313, 21.82055664], [88.90055847, 21.82055664], [88.89971924, 21.81972313], [88.89944458, 21.81972313], [88.89916992, 21.81944656], [88.89888763, 21.81944656], [88.89805603, 21.81861115], [88.89778137, 21.81861115], [88.89527893, 21.81610107], [88.89499664, 21.81611061], [88.89389038, 21.81500053], [88.89360809, 21.81500053], [88.89333344, 21.81472206], [88.89305878, 21.81472206], [88.89250183, 21.81416702], [88.89250183, 21.81389046], [88.89193726, 21.8133316], [88.89167023, 21.81333351], [88.89138794, 21.81305504], [88.89111328, 21.81306267], [88.89055634, 21.81250191], [88.89026642, 21.81250191], [88.88999939, 21.81222153], [88.88804626, 21.81222153], [88.88777924, 21.81250191], [88.88749695, 21.81250191], [88.88722229, 21.81278038], [88.88693237, 21.81278038], [88.88667297, 21.81278038], [88.88639069, 21.81306267], [88.8861084, 21.81306267], [88.88500214, 21.81416702], [88.88500214, 21.81472015], [88.88471985, 21.81500053], [88.88471985, 21.8152771], [88.8841629, 21.81583023], [88.8841629, 21.81638908], [88.88361359, 21.81694221], [88.88360596, 21.81722069], [88.88277435, 21.8180542], [88.88277435, 21.81833267], [88.88194275, 21.81916428], [88.88168335, 21.81916046], [88.8805542, 21.82027626], [88.8805542, 21.82083321], [88.88027954, 21.82110977], [88.88027954, 21.82222748], [88.88054657, 21.82222748], [88.88054657, 21.82278061], [88.88083649, 21.82305908], [88.88083649, 21.82389069], [88.88111115, 21.82416725], [88.88111115, 21.82471848], [88.8813858, 21.82500076], [88.8813858, 21.82529259], [88.88166809, 21.8255558], [88.88168335, 21.82611084], [88.88194275, 21.82638931], [88.88194275, 21.82666588], [88.88223267, 21.82694244], [88.88223267, 21.82777977], [88.88249969, 21.82805634], [88.88249969, 21.82972145], [88.88223267, 21.82999992], [88.88223267, 21.83056068], [88.8813858, 21.83138847], [88.8813858, 21.83194351], [88.88111115, 21.83222008], [88.88111115, 21.83250046], [88.88083649, 21.83278084], [88.88083649, 21.8330574], [88.88054657, 21.83333015], [88.88054657, 21.83361053], [88.88027954, 21.83389091], [88.88027954, 21.83416748], [88.87999725, 21.83444023], [88.87999725, 21.83500099], [88.8797226, 21.83527946], [88.8797226, 21.83555794], [88.87944794, 21.83583069], [88.87944794, 21.83889008], [88.87916565, 21.83916664], [88.87916565, 21.84000015], [88.87889099, 21.84027863], [88.87889099, 21.84083366], [88.87861633, 21.84111023], [88.87861633, 21.84278107], [88.87832642, 21.84305954], [88.87832642, 21.84361076], [88.87805176, 21.84388924], [88.87805176, 21.84444427], [88.8777771, 21.84472275], [88.8777771, 21.84555435], [88.87750244, 21.84583282], [88.87750244, 21.84610939], [88.87750244, 21.84666443], [88.8777771, 21.84694099], [88.8777771, 21.84749985], [88.87805176, 21.84777832], [88.87805176, 21.84833336], [88.87832642, 21.84860992], [88.87833405, 21.85055542], [88.8786087, 21.85083389], [88.8786087, 21.85194397], [88.87832642, 21.85220909], [88.87833405, 21.85305595], [88.87805176, 21.8533287], [88.87805176, 21.85388947], [88.8777771, 21.85416985], [88.87750244, 21.85416603], [88.87722015, 21.8544445], [88.8769455, 21.8544445], [88.87666321, 21.85472107], [88.87526703, 21.85472107], [88.875, 21.85499954], [88.8741684, 21.85499954], [88.87388611, 21.85472107], [88.87333679, 21.85472107], [88.8730545, 21.8544445], [88.8722229, 21.8544445], [88.87194824, 21.85416603], [88.86972046, 21.85416603], [88.8694458, 21.8544445], [88.86888885, 21.8544426], [88.86833191, 21.85499954], [88.86805725, 21.85499954], [88.86777496, 21.85527802], [88.86723328, 21.85527039], [88.86694336, 21.8555603], [88.86611176, 21.85555649], [88.8658371, 21.85583115], [88.86338806, 21.85583115], [88.8611145, 21.85583115], [88.86083221, 21.85611153], [88.86054993, 21.85610962], [88.8602829, 21.85639], [88.86000061, 21.85639], [88.85972595, 21.85667038], [88.85944366, 21.85666656], [88.85888672, 21.8572216], [88.85861206, 21.8572216], [88.85721588, 21.85861015], [88.85722351, 21.85916519], [88.85666656, 21.85972023], [88.85694122, 21.86000061], [88.85694122, 21.86027527], [88.85749054, 21.86083031], [88.85749054, 21.86111069], [88.85805511, 21.86166763], [88.85806274, 21.86194038], [88.85861206, 21.86250114], [88.85861206, 21.86277962], [88.85916901, 21.86333275], [88.85943604, 21.86333084], [88.85972595, 21.86361122], [88.86000061, 21.86361122], [88.86054993, 21.86416817], [88.86083221, 21.86416626], [88.8611145, 21.86444473], [88.8611145, 21.86499977], [88.86045074, 21.86566162], [88.86000061, 21.86611176], [88.85972595, 21.86611176], [88.85943604, 21.86639023], [88.85916901, 21.86639023], [88.85888672, 21.86667252], [88.85832977, 21.86667252], [88.85806274, 21.8669529], [88.85778046, 21.86694527], [88.85749817, 21.86722183], [88.85666656, 21.86722183], [88.85555267, 21.86833382], [88.85527802, 21.86833191], [88.85444641, 21.86916733], [88.85444641, 21.86944389], [88.85415649, 21.86972046], [88.85415649, 21.87306023], [88.85444641, 21.87334061], [88.85444641, 21.875], [88.85472107, 21.87528038], [88.85444641, 21.87556076], [88.85416412, 21.87555695], [88.85415649, 21.87832832], [88.85388947, 21.87861061], [88.85388947, 21.87916756], [88.85416412, 21.87944412], [88.85415649, 21.88348961], [88.85415649, 21.88389015], [88.85388947, 21.88417053], [88.85388947, 21.88555336], [88.85360718, 21.88582993], [88.85360718, 21.88639069], [88.85333252, 21.88667107], [88.85333252, 21.88778114], [88.85360718, 21.88805962], [88.85360718, 21.88861084], [88.85416412, 21.88916779], [88.85416412, 21.88944435], [88.85388947, 21.88972282], [88.85360718, 21.88972092], [88.85333252, 21.88999748], [88.85277557, 21.88999748], [88.85193634, 21.89082909], [88.85194397, 21.89166641], [88.85138702, 21.89222145], [88.85138702, 21.89250183], [88.85083008, 21.89305496], [88.85083008, 21.89333344], [88.85056305, 21.89361191], [88.85056305, 21.89389038], [88.85028076, 21.89416695], [88.85028076, 21.8944416], [88.84971619, 21.89500046], [88.84972382, 21.89527702], [88.84916687, 21.89583015], [88.84916687, 21.89611053], [88.84638977, 21.89888954], [88.84638977, 21.89944649], [88.84527588, 21.90055466], [88.84500122, 21.90055466], [88.84083557, 21.90472221], [88.84083557, 21.90500069], [88.83944702, 21.90638924], [88.83916473, 21.90638924], [88.83860779, 21.90694427], [88.83833313, 21.90694237], [88.83721924, 21.90806007], [88.83694458, 21.90805626], [88.83638763, 21.9086113], [88.83611298, 21.90860939], [88.83528137, 21.90945053], [88.83472443, 21.90944481], [88.83472443, 21.90972137], [88.83416748, 21.90972137], [88.83389282, 21.90999985], [88.83304596, 21.90999985], [88.83277893, 21.91028023], [88.83249664, 21.91027832], [88.83194733, 21.91083336], [88.83166504, 21.91083336], [88.83139038, 21.91111183], [88.83110809, 21.91110992], [88.83082581, 21.9113903], [88.82971954, 21.9113903], [88.82943726, 21.91167068], [88.82917023, 21.91167068], [88.82888794, 21.91195107], [88.82861328, 21.91194344], [88.82833099, 21.91222191], [88.82776642, 21.91222], [88.82750702, 21.91250992], [88.8272171, 21.91250992], [88.82694244, 21.91278076], [88.82666779, 21.91277695], [88.82611084, 21.9133358], [88.82583618, 21.9133358], [88.8236084, 21.91555786], [88.8236084, 21.91583061], [88.82305908, 21.91638947], [88.82305908, 21.91666794], [88.82277679, 21.9169445], [88.82277679, 21.91721916], [88.82221985, 21.91777992], [88.82221985, 21.91805649], [88.8216629, 21.91860771], [88.8216629, 21.91917038], [88.82138062, 21.91945267], [88.82138824, 21.92027855], [88.82111359, 21.92055511], [88.82111359, 21.92083359], [88.8208313, 21.92111015], [88.8208313, 21.92194366], [88.82055664, 21.92222214], [88.82055664, 21.92333031], [88.82026672, 21.92361069], [88.82027435, 21.92444229], [88.81999969, 21.92472267], [88.81999969, 21.9272213], [88.81973267, 21.92749023], [88.81973267, 21.92778015], [88.81961823, 21.92819977], [88.82050323, 21.92877007], [88.82124329, 21.92888451], [88.82199097, 21.92900085], [88.82367706, 21.92770958], [88.82594299, 21.92654991], [88.82621765, 21.92577171], [88.83369446, 21.91992378], [88.83516693, 21.91891479], [88.83655548, 21.91789246]]], [[[88.81694794, 21.9011116], [88.8172226, 21.90083313], [88.81777954, 21.90083313], [88.8180542, 21.90055466], [88.81833649, 21.90055466], [88.81861115, 21.90027618], [88.81916809, 21.90028], [88.81944275, 21.89999962], [88.82026672, 21.89999962], [88.82055664, 21.89972115], [88.8208313, 21.89972305], [88.82111359, 21.89944649], [88.82250214, 21.89944649], [88.82277679, 21.8991642], [88.8236084, 21.8991642], [88.82389069, 21.89944649], [88.8263855, 21.89944649], [88.82666779, 21.8991642], [88.82694244, 21.89916992], [88.8272171, 21.89888954], [88.82805634, 21.89888954], [88.82833099, 21.89861107], [88.82861328, 21.89861107], [88.82888794, 21.89833069], [88.82917023, 21.8983326], [88.82944489, 21.89805412], [88.82971954, 21.89805984], [88.83000183, 21.89777946], [88.83027649, 21.89777946], [88.83056641, 21.89751053], [88.83082581, 21.89751053], [88.83110809, 21.89722061], [88.83139038, 21.89722252], [88.83194733, 21.89666748], [88.83222198, 21.89666939], [88.83277893, 21.89611053], [88.83304596, 21.89611053], [88.83389282, 21.89528275], [88.83444214, 21.89528275], [88.83750153, 21.89222145], [88.83750153, 21.89194489], [88.83777618, 21.89166641], [88.83777618, 21.89138031], [88.83944702, 21.88972282], [88.83944702, 21.88944435], [88.83916473, 21.88916779], [88.83972168, 21.88861084], [88.83972168, 21.88833809], [88.84055328, 21.88750076], [88.84055328, 21.88722038], [88.84083557, 21.88694382], [88.84083557, 21.88611031], [88.84111023, 21.88583565], [88.84083557, 21.88555336], [88.8408432, 21.88500023], [88.84055328, 21.88472176], [88.84055328, 21.88249969], [88.84027863, 21.88221169], [88.84027863, 21.88138962], [88.83999634, 21.88111115], [88.83999634, 21.88056183], [88.83972168, 21.88027954], [88.83999634, 21.88000107], [88.83972168, 21.87972069], [88.83972168, 21.87861061], [88.83944702, 21.87832832], [88.83944702, 21.87750053], [88.83860779, 21.87667084], [88.83860779, 21.87639809], [88.83805847, 21.8758297], [88.83805847, 21.87555695], [88.83777618, 21.87527847], [88.83799744, 21.87506104], [88.83805847, 21.875], [88.83721924, 21.8741684], [88.83721924, 21.87360954], [88.83694458, 21.87333298], [88.83693695, 21.87306023], [88.83583069, 21.87194061], [88.83583069, 21.87166405], [88.83499908, 21.87083054], [88.83499908, 21.87055588], [88.83416748, 21.86972046], [88.83416748, 21.86944389], [88.83361053, 21.86888885], [88.83361053, 21.86861038], [88.83167267, 21.86667252], [88.83167267, 21.86639023], [88.83082581, 21.86554909], [88.83083344, 21.86527824], [88.83040619, 21.86527061], [88.83027649, 21.86528015], [88.83000946, 21.86501122], [88.82971954, 21.86499977], [88.82943726, 21.86471748], [88.82861328, 21.86471748], [88.82833099, 21.86499977], [88.82776642, 21.86499977], [88.82750702, 21.86528015], [88.82722473, 21.86527824], [88.82694244, 21.86555481], [88.82666779, 21.86554909], [88.82554626, 21.86667252], [88.82555389, 21.86694527], [88.82527924, 21.86720848], [88.82527924, 21.86750031], [88.82499695, 21.86778069], [88.82499695, 21.86805534], [88.82486725, 21.86818314], [88.82472229, 21.86833191], [88.82472229, 21.86916733], [88.82444, 21.86944008], [88.82444763, 21.87000084], [88.82417297, 21.87026978], [88.82416534, 21.87055588], [88.82277679, 21.87194443], [88.82250214, 21.87194443], [88.82221985, 21.87222481], [88.8216629, 21.87222099], [88.82138062, 21.87249947], [88.81944275, 21.87249947], [88.81916809, 21.87222099], [88.81833649, 21.87222481], [88.8180542, 21.87194443], [88.81694794, 21.87194443], [88.81666565, 21.87166405], [88.81555176, 21.87166977], [88.8152771, 21.87138939], [88.8144455, 21.87138939], [88.81416321, 21.87111092], [88.81360626, 21.87111092], [88.81338501, 21.87088776], [88.8133316, 21.87083054], [88.81305695, 21.87083244], [88.81277466, 21.87055588], [88.81223297, 21.87055969], [88.81138611, 21.86972046], [88.81111145, 21.86972237], [88.81102753, 21.86964035], [88.8105545, 21.86916733], [88.81027985, 21.86917114], [88.80999756, 21.86889076], [88.80944061, 21.86889076], [88.80916595, 21.86861038], [88.80860901, 21.86861038], [88.80832672, 21.86833191], [88.80805206, 21.86833382], [88.8077774, 21.86805534], [88.80665588, 21.86806107], [88.80639648, 21.86778069], [88.80610657, 21.86806107], [88.80578613, 21.86805534], [88.80472565, 21.86805534], [88.80444336, 21.86833382], [88.8041687, 21.86833191], [88.80388641, 21.86861038], [88.8033371, 21.86861038], [88.80304718, 21.86889076], [88.80278015, 21.86889076], [88.80249786, 21.86917114], [88.80222321, 21.86916733], [88.80194092, 21.86944389], [88.80166626, 21.86944389], [88.8013916, 21.86972237], [88.80110931, 21.86972046], [88.80027771, 21.87055588], [88.80027008, 21.87222099], [88.80055237, 21.87249947], [88.80055237, 21.87306023], [88.80082703, 21.87334061], [88.80082703, 21.87388992], [88.80110931, 21.8741703], [88.80110931, 21.87444687], [88.8013916, 21.87471962], [88.8013916, 21.87555695], [88.80194092, 21.87610817], [88.80194092, 21.87639809], [88.80222321, 21.87667084], [88.80222321, 21.87750053], [88.80249786, 21.8777771], [88.80249786, 21.87832832], [88.80278015, 21.87861061], [88.80444336, 21.87972069], [88.80473328, 21.88000107], [88.80500031, 21.88000107], [88.80526733, 21.88027954], [88.80583191, 21.88027954], [88.80610657, 21.88056183], [88.80638885, 21.88055611], [88.80666351, 21.88083267], [88.8069458, 21.88083267], [88.80750275, 21.88138962], [88.8077774, 21.88138962], [88.80860901, 21.88221169], [88.80860901, 21.88249969], [88.8088913, 21.88277817], [88.8088913, 21.88305473], [88.80916595, 21.88332939], [88.80916595, 21.88389015], [88.80944824, 21.88416672], [88.80944061, 21.88471985], [88.8097229, 21.88500023], [88.8097229, 21.88750076], [88.80944061, 21.88778114], [88.80944061, 21.88805962], [88.8097229, 21.88833809], [88.8097229, 21.88889122], [88.80999756, 21.88916779], [88.80999756, 21.89266014], [88.80999756, 21.89305496], [88.81027985, 21.89333344], [88.81027985, 21.89347267], [88.81027985, 21.89388847], [88.81047821, 21.89409065], [88.8105545, 21.89416695], [88.8105545, 21.89433098], [88.8105545, 21.89444351], [88.81083679, 21.89472008], [88.81083679, 21.89500046], [88.81111145, 21.89527702], [88.81111145, 21.89583015], [88.81138611, 21.89611053], [88.81138611, 21.89638901], [88.81156921, 21.89657211], [88.81194305, 21.89694214], [88.81222534, 21.89694214], [88.8125, 21.89722252], [88.81276703, 21.89722061], [88.81305695, 21.89751053], [88.8133316, 21.89751053], [88.81388855, 21.89805412], [88.81388855, 21.8983326], [88.81445313, 21.89888954], [88.8144455, 21.8991642], [88.81472015, 21.89944077], [88.81472015, 21.89999962], [88.8152771, 21.90055466], [88.81555176, 21.90055466], [88.8156662, 21.90066528], [88.81583405, 21.90083313], [88.81639099, 21.90083313], [88.81666565, 21.9011116], [88.81694794, 21.9011116]]], [[[88.56233978, 21.89746094], [88.5629425, 21.89740944], [88.56349945, 21.89750481], [88.56402588, 21.89764023], [88.56450653, 21.89776993], [88.56495667, 21.89789009], [88.56537628, 21.89808083], [88.56583405, 21.89831734], [88.56632996, 21.89858246], [88.56681824, 21.8989296], [88.56729889, 21.89934158], [88.56781769, 21.89974022], [88.56838989, 21.90011024], [88.56903839, 21.9004612], [88.56976318, 21.90086174], [88.57050323, 21.90119934], [88.57068634, 21.90111542], [88.57103729, 21.90094948], [88.57138062, 21.9004879], [88.57144165, 21.90036964], [88.57161713, 21.90000534], [88.57168579, 21.89941978], [88.57180786, 21.89882088], [88.57196808, 21.89836121], [88.57219696, 21.89794922], [88.5724411, 21.89751053], [88.5727005, 21.89703941], [88.57299805, 21.89659119], [88.5732193, 21.89607048], [88.57337952, 21.89554024], [88.57364655, 21.89514732], [88.57398224, 21.89485168], [88.57429504, 21.89439392], [88.57437134, 21.89355278], [88.57480621, 21.89312744], [88.57493591, 21.89266968], [88.57501984, 21.8922596], [88.57517242, 21.89192009], [88.57527161, 21.89156914], [88.57536316, 21.89118958], [88.57553101, 21.89081955], [88.57562256, 21.89039421], [88.57579803, 21.89001083], [88.57589722, 21.88960075], [88.57583618, 21.88944054], [88.57611084, 21.88916779], [88.57611084, 21.88889122], [88.57639313, 21.88861084], [88.57611084, 21.88833427], [88.57639313, 21.88805962], [88.57639313, 21.88778114], [88.57636261, 21.88717842], [88.57633972, 21.88672066], [88.57621765, 21.88631439], [88.5761261, 21.8859005], [88.57607269, 21.88544846], [88.57602692, 21.88495064], [88.57622528, 21.88428116], [88.57614899, 21.88386726], [88.57601166, 21.8834095], [88.57576752, 21.88284111], [88.57540131, 21.88234138], [88.57501221, 21.88195229], [88.57466888, 21.8815918], [88.57447052, 21.88119888], [88.57440186, 21.88080406], [88.57424927, 21.88049889], [88.5741806, 21.88017082], [88.57419586, 21.87977219], [88.57427979, 21.8792572], [88.57421112, 21.87875175], [88.57430267, 21.87821007], [88.57374573, 21.87662506], [88.57324219, 21.87393951], [88.57299042, 21.87236977], [88.57288361, 21.87171555], [88.57287598, 21.87157249], [88.57266998, 21.8676815], [88.57252502, 21.86351395], [88.57281494, 21.86297417], [88.57277679, 21.86166763], [88.57263184, 21.86066055], [88.57272339, 21.85989189], [88.57277679, 21.85944366], [88.57277679, 21.85916519], [88.57277679, 21.85881042], [88.57273865, 21.85836029], [88.57253265, 21.8579483], [88.57241821, 21.8574295], [88.57224274, 21.85690308], [88.57214355, 21.8563385], [88.57198334, 21.85582161], [88.57189941, 21.85527039], [88.57170105, 21.85482025], [88.57155609, 21.85435104], [88.57135773, 21.85396767], [88.57111359, 21.85364532], [88.57084656, 21.85334969], [88.57065582, 21.85300064], [88.57049561, 21.85258293], [88.57026672, 21.85215759], [88.57000732, 21.85172081], [88.56977081, 21.85123062], [88.56965637, 21.85069847], [88.56947327, 21.85024071], [88.5693512, 21.84979057], [88.56913757, 21.84941673], [88.5688858, 21.8490696], [88.5686264, 21.84872055], [88.5684433, 21.84831047], [88.56828308, 21.84787369], [88.56808472, 21.84747124], [88.56797791, 21.84702492], [88.56781006, 21.84661293], [88.56774139, 21.84616661], [88.56754303, 21.8458004], [88.56745911, 21.84535027], [88.56726074, 21.84495926], [88.5672226, 21.84453964], [88.5672226, 21.84410095], [88.56718445, 21.84366798], [88.56698608, 21.84324074], [88.56692505, 21.84270287], [88.56682587, 21.84210587], [88.56667328, 21.84148979], [88.56648254, 21.84087944], [88.56621552, 21.84034157], [88.56607819, 21.8397541], [88.5658493, 21.8392334], [88.56565094, 21.83871078], [88.56542969, 21.83818817], [88.56526184, 21.83764648], [88.56505585, 21.83711052], [88.56494904, 21.83653259], [88.56474304, 21.83599091], [88.56459045, 21.83542824], [88.56446075, 21.83488083], [88.56437683, 21.83431816], [88.56420135, 21.83380508], [88.56413269, 21.83325958], [88.56391144, 21.83279228], [88.56369781, 21.83230972], [88.56349945, 21.83184052], [88.5633316, 21.83136177], [88.56311798, 21.83093071], [88.56278229, 21.83060074], [88.56247711, 21.83031082], [88.56217957, 21.8300705], [88.56188202, 21.82991028], [88.56163788, 21.8297596], [88.56138611, 21.82971954], [88.56115723, 21.82973099], [88.56092834, 21.82984734], [88.56069183, 21.83008003], [88.56044006, 21.83026123], [88.56021881, 21.83033943], [88.56002808, 21.83024979], [88.55916595, 21.83063126], [88.55819702, 21.82930946], [88.55784607, 21.82909966], [88.55771637, 21.82888985], [88.55750275, 21.8283329], [88.55702972, 21.82814407], [88.55672455, 21.82792664], [88.55615997, 21.82760048], [88.55591583, 21.82746124], [88.55548096, 21.82744026], [88.55502319, 21.82735062], [88.55457306, 21.82752037], [88.5541153, 21.82781792], [88.55366516, 21.8282547], [88.5532608, 21.82879829], [88.55284119, 21.82932091], [88.55251312, 21.82979012], [88.55222321, 21.83017921], [88.55194855, 21.8304615], [88.55168915, 21.83069992], [88.55143738, 21.83097839], [88.55119324, 21.83136368], [88.55108643, 21.83173943], [88.55103302, 21.83191681], [88.55083466, 21.83194351], [88.55055237, 21.83166695], [88.55000305, 21.83167076], [88.55005646, 21.83118057], [88.55027771, 21.83075905], [88.55045319, 21.83044815], [88.55051422, 21.83034134], [88.55078125, 21.82995605], [88.55105591, 21.82955933], [88.55130005, 21.82914925], [88.55153656, 21.82874107], [88.55180359, 21.82836533], [88.55208588, 21.82801056], [88.55237579, 21.82765007], [88.5526886, 21.82731056], [88.5530014, 21.82697868], [88.5532608, 21.82661057], [88.55347443, 21.82622719], [88.5536499, 21.82582855], [88.55384827, 21.82546806], [88.55388641, 21.82500076], [88.5541687, 21.82471848], [88.5541687, 21.82416725], [88.55444336, 21.82389069], [88.55416107, 21.81949997], [88.5537262, 21.81902885], [88.55339813, 21.81867027], [88.55332947, 21.81833076], [88.55319214, 21.81818008], [88.55305481, 21.81777763], [88.55278015, 21.81750107], [88.55222321, 21.81750107], [88.55200195, 21.81733131], [88.5513382, 21.8173008], [88.55103302, 21.81729126], [88.55071259, 21.8174057], [88.55024719, 21.81748009], [88.54975891, 21.8175602], [88.54930878, 21.81776047], [88.54885864, 21.81795692], [88.5484314, 21.81817245], [88.54811859, 21.81848526], [88.5479126, 21.81886292], [88.54775238, 21.81921005], [88.54759216, 21.81950951], [88.54749298, 21.81980705], [88.54737091, 21.82012558], [88.54720306, 21.82045364], [88.54702759, 21.82080269], [88.54695129, 21.82120132], [88.54688263, 21.82159805], [88.54668427, 21.82193375], [88.54641724, 21.82229042], [88.54614258, 21.82270813], [88.54580688, 21.82313919], [88.54582977, 21.82359123], [88.54580688, 21.8239994], [88.54582977, 21.82416725], [88.54528046, 21.82472229], [88.54528046, 21.82582855], [88.54499817, 21.82611084], [88.54499817, 21.82638931], [88.54333496, 21.82805634], [88.54333496, 21.8283329], [88.54305267, 21.82860947], [88.54305267, 21.82888985], [88.54277802, 21.82917023], [88.54250336, 21.82916641], [88.54218292, 21.82944107], [88.54171753, 21.82982063], [88.5412674, 21.8302002], [88.54084778, 21.8304615], [88.54043579, 21.83078003], [88.53997803, 21.83110046], [88.53948212, 21.83138466], [88.53901672, 21.83166122], [88.53862762, 21.83195114], [88.53830719, 21.83222961], [88.53795624, 21.83241272], [88.53749847, 21.83250046], [88.53721619, 21.83278084], [88.53694153, 21.83278084], [88.53666687, 21.83306122], [88.53527832, 21.83306122], [88.53443146, 21.83389091], [88.53391266, 21.83377075], [88.53385162, 21.83413124], [88.53375244, 21.8343811], [88.53360748, 21.83472061], [88.53333282, 21.83500099], [88.53333282, 21.83527565], [88.53277588, 21.83583069], [88.53277588, 21.83611107], [88.53305817, 21.83638954], [88.53277588, 21.83666611], [88.53277588, 21.8386116], [88.53266144, 21.83872986], [88.53251648, 21.83920097], [88.53250885, 21.83977127], [88.53247833, 21.84038544], [88.53237152, 21.8409729], [88.53233337, 21.84147072], [88.53214264, 21.84176064], [88.53185272, 21.84205627], [88.53151703, 21.84247208], [88.53153229, 21.84325981], [88.53131866, 21.8438797], [88.53096771, 21.84443283], [88.53106689, 21.84495735], [88.53108978, 21.84551048], [88.53100586, 21.84608078], [88.53082275, 21.84662247], [88.5306015, 21.84714127], [88.53055573, 21.84777832], [88.53056335, 21.84831047], [88.53055573, 21.84916878], [88.53111267, 21.84972191], [88.53166962, 21.85028076], [88.53193665, 21.85028076], [88.53221893, 21.85055923], [88.53250885, 21.85055923], [88.53305817, 21.85111046], [88.53333282, 21.85111046], [88.53360748, 21.85139084], [88.5341568, 21.85139084], [88.53444672, 21.85166931], [88.53500366, 21.8516674], [88.53500366, 21.85194397], [88.53527832, 21.85194397], [88.53649139, 21.85210228], [88.53700256, 21.85231209], [88.53827667, 21.85283852], [88.53833008, 21.85305595], [88.53861237, 21.85333252], [88.53916931, 21.8533287], [88.53968048, 21.85355949], [88.54012299, 21.85373116], [88.54057312, 21.85391045], [88.54101563, 21.85414505], [88.54138947, 21.8544426], [88.54250336, 21.8555603], [88.54250336, 21.85639], [88.54277802, 21.85667038], [88.54277802, 21.85805321], [88.54305267, 21.85833359], [88.54305267, 21.85861015], [88.54332733, 21.85889053], [88.54305267, 21.85916519], [88.54305267, 21.8619442], [88.54301453, 21.86203957], [88.54281616, 21.8625927], [88.54277802, 21.86321259], [88.5427475, 21.86380959], [88.54261017, 21.86433983], [88.54248047, 21.86482048], [88.5422821, 21.86524963], [88.54216003, 21.86572075], [88.54196167, 21.86611938], [88.54183197, 21.86650085], [88.54168701, 21.86681175], [88.54160309, 21.86712074], [88.54143524, 21.86736679], [88.54132843, 21.86762047], [88.54109955, 21.8678112], [88.54084015, 21.86806107], [88.54064178, 21.86841583], [88.54059601, 21.86909294], [88.54042816, 21.86989021], [88.54050446, 21.87039948], [88.54081726, 21.87060165], [88.54111481, 21.87084961], [88.54139709, 21.87117958], [88.5417099, 21.87154007], [88.54210663, 21.87183571], [88.54222107, 21.87194061], [88.54277802, 21.87249947], [88.54305267, 21.87249947], [88.54332733, 21.87277985], [88.54360962, 21.87277985], [88.54389191, 21.87306023], [88.54416656, 21.87306023], [88.54499817, 21.87388992], [88.54528046, 21.87388992], [88.54528046, 21.87444687], [88.54555511, 21.87472153], [88.54611206, 21.87471962], [88.54638672, 21.875], [88.54666901, 21.875], [88.54703522, 21.87537575], [88.54746246, 21.87580109], [88.54795837, 21.87618828], [88.54833984, 21.87663078], [88.54868317, 21.87701988], [88.54891205, 21.87737083], [88.54911804, 21.87764931], [88.54923248, 21.87795067], [88.5493927, 21.87820435], [88.54946899, 21.87851143], [88.54960632, 21.87878418], [88.54971313, 21.87911034], [88.54980469, 21.87951088], [88.54999542, 21.87994385], [88.55015564, 21.88043976], [88.55026245, 21.88095856], [88.55024719, 21.88150024], [88.55013275, 21.88202286], [88.55010986, 21.88262177], [88.55004883, 21.88318253], [88.55000305, 21.88368797], [88.54994965, 21.88414383], [88.54978943, 21.88452339], [88.54969025, 21.88492012], [88.54957581, 21.88534927], [88.54946136, 21.88584137], [88.54936981, 21.88643837], [88.54920197, 21.88706207], [88.54915619, 21.88779068], [88.5491333, 21.88855934], [88.54915619, 21.88933945], [88.54915619, 21.89011002], [88.54916382, 21.89085579], [88.54911041, 21.8915596], [88.54886627, 21.8922081], [88.54850769, 21.89278984], [88.54814911, 21.89334106], [88.54774475, 21.89385986], [88.54727936, 21.89427376], [88.54685974, 21.89468002], [88.54644012, 21.89507294], [88.54602814, 21.89548111], [88.54553986, 21.89585114], [88.54499054, 21.8962307], [88.54439545, 21.89661789], [88.54379272, 21.89703941], [88.54319, 21.89745712], [88.54261017, 21.89785004], [88.54214478, 21.89831734], [88.54172516, 21.89876366], [88.54133606, 21.89915276], [88.541008, 21.89952087], [88.54080963, 21.89996147], [88.5406189, 21.90036964], [88.54057312, 21.90080261], [88.54060364, 21.90123749], [88.54074097, 21.90167236], [88.54091644, 21.9021225], [88.54116058, 21.90256119], [88.54147339, 21.90295982], [88.54183197, 21.90331078], [88.54220581, 21.90364075], [88.54258728, 21.90397072], [88.54308319, 21.90422821], [88.54363251, 21.90444946], [88.54421997, 21.90463066], [88.54486847, 21.90468025], [88.54499054, 21.90467262], [88.545578, 21.90462685], [88.54624176, 21.90443039], [88.54690552, 21.90420914], [88.54759216, 21.90400124], [88.54830933, 21.90381813], [88.54884338, 21.90353966], [88.54927826, 21.90321159], [88.54965973, 21.9028511], [88.55005646, 21.90251923], [88.55047607, 21.90223122], [88.55091095, 21.90195084], [88.55136108, 21.90168953], [88.55181122, 21.90139961], [88.55229187, 21.90112114], [88.55277252, 21.90084839], [88.55329895, 21.90063095], [88.55380249, 21.9004097], [88.55422974, 21.90013885], [88.55471039, 21.89999008], [88.55517578, 21.8998394], [88.55562592, 21.89974022], [88.55609894, 21.89967918], [88.55649567, 21.89951706], [88.55693054, 21.89941025], [88.55731964, 21.89917946], [88.55770874, 21.89896965], [88.55809784, 21.89873123], [88.55850983, 21.89855003], [88.5588913, 21.89836121], [88.55930328, 21.89821053], [88.55971527, 21.89807892], [88.56014252, 21.8979702], [88.56053925, 21.89782715], [88.56093597, 21.8977375], [88.56134033, 21.89759827], [88.56179047, 21.89751625], [88.56233978, 21.89746094]]], [[[88.58274841, 21.86554909], [88.58248901, 21.8654995], [88.58222961, 21.86551857], [88.58191681, 21.86559105], [88.58165741, 21.86608124], [88.58142853, 21.86662102], [88.58139038, 21.86718941], [88.58139038, 21.86770248], [88.58139038, 21.86816025], [88.58139038, 21.86861801], [88.58139038, 21.86910057], [88.58139038, 21.86960983], [88.58138275, 21.87010765], [88.58132935, 21.87058067], [88.58114624, 21.87104034], [88.58110809, 21.87153053], [88.58110809, 21.87203789], [88.58113861, 21.87252808], [88.5812912, 21.8729763], [88.5814209, 21.87345123], [88.58165741, 21.87389946], [88.58188629, 21.87437057], [88.58217621, 21.8747921], [88.58246613, 21.87522507], [88.58286285, 21.87555122], [88.58326721, 21.87586021], [88.58368683, 21.87618828], [88.58423615, 21.87659073], [88.58468628, 21.87659073], [88.58481598, 21.87652969], [88.5850296, 21.87635231], [88.58541107, 21.87597275], [88.58558655, 21.87554359], [88.58579254, 21.87507629], [88.58583832, 21.87455177], [88.58580017, 21.87399292], [88.58538818, 21.87347031], [88.58541107, 21.87309265], [88.58526611, 21.87233162], [88.58526611, 21.87187004], [88.585289, 21.87133026], [88.58525848, 21.87092972], [88.58505249, 21.87045288], [88.58493805, 21.87016296], [88.58485413, 21.8698597], [88.58481598, 21.86952972], [88.58467865, 21.869133], [88.58444214, 21.86873245], [88.58420563, 21.86827469], [88.58390045, 21.86780357], [88.58360291, 21.867239], [88.58361816, 21.86667252], [88.58325958, 21.86597443], [88.58274841, 21.86554909]]], [[[88.63999939, 21.92168045], [88.64026642, 21.92139053], [88.64083862, 21.92139053], [88.64111328, 21.92111015], [88.64159393, 21.92084122], [88.64221954, 21.92056274], [88.64250183, 21.92021179], [88.64305878, 21.92000008], [88.64389801, 21.91953278], [88.64472198, 21.91917038], [88.64499664, 21.91917038], [88.64527893, 21.91889191], [88.64554596, 21.91889191], [88.64583588, 21.91860771], [88.64596558, 21.91840935], [88.64639282, 21.91820145], [88.64672852, 21.91806412], [88.6472168, 21.91764259], [88.64770508, 21.91750908], [88.64784241, 21.91729927], [88.64832306, 21.91710281], [88.64866638, 21.91688919], [88.64929962, 21.91688919], [88.64951324, 21.91674042], [88.65006256, 21.91650963], [88.65116119, 21.91661072], [88.65207672, 21.91680908], [88.65242004, 21.9167614], [88.652565, 21.91674232], [88.65279388, 21.91674423], [88.65317535, 21.9169426], [88.6537323, 21.91688919], [88.65426636, 21.91666985], [88.65483856, 21.9164238], [88.65545654, 21.91624641], [88.65605927, 21.91609001], [88.65666199, 21.91583061], [88.65727997, 21.91555786], [88.65789795, 21.91530037], [88.65850067, 21.91513443], [88.65878296, 21.9148674], [88.65898895, 21.91489983], [88.65944672, 21.91472054], [88.66055298, 21.91472244], [88.66083527, 21.91444588], [88.66139221, 21.91444588], [88.66166687, 21.9141655], [88.66194153, 21.91417122], [88.66210938, 21.91415977], [88.66243744, 21.91418839], [88.66260529, 21.91413116], [88.66293335, 21.91401482], [88.66342926, 21.91389847], [88.6639328, 21.91382027], [88.66442871, 21.91365051], [88.6649704, 21.91358948], [88.66555786, 21.91361046], [88.66583252, 21.91361046], [88.66610718, 21.91333008], [88.66694641, 21.9133358], [88.66750336, 21.91277695], [88.66750336, 21.91167068], [88.66722107, 21.9113903], [88.66722107, 21.91028023], [88.66694641, 21.90999985], [88.66694641, 21.90945053], [88.66665649, 21.90917015], [88.66666412, 21.90870094], [88.66666412, 21.90833282], [88.66611481, 21.90777779], [88.66610718, 21.90750122], [88.66583252, 21.90722275], [88.66583252, 21.9066658], [88.66555786, 21.9063797], [88.66555786, 21.90555573], [88.6652832, 21.90527916], [88.6652832, 21.90500069], [88.66471863, 21.90444374], [88.66471863, 21.90416718], [88.66166687, 21.9011097], [88.66166687, 21.90083313], [88.66110992, 21.90027618], [88.66110992, 21.89972115], [88.66055298, 21.8991642], [88.66055298, 21.89888954], [88.66027832, 21.89861107], [88.66027832, 21.89833069], [88.66000366, 21.89805412], [88.65999603, 21.89777946], [88.65972137, 21.89751053], [88.65944672, 21.89722061], [88.65916443, 21.89694214], [88.65944672, 21.89666748], [88.65944672, 21.89556122], [88.65888214, 21.89500046], [88.65888214, 21.89389038], [88.65860748, 21.89361191], [88.65860748, 21.89333344], [88.65805817, 21.8927784], [88.65805817, 21.89166832], [88.65777588, 21.89138031], [88.65777588, 21.89111137], [88.65750122, 21.8908329], [88.65750122, 21.89055634], [88.65721893, 21.89027977], [88.6574707, 21.89001083], [88.65730286, 21.88946152], [88.65719604, 21.88890076], [88.65699005, 21.88838959], [88.65693665, 21.88778114], [88.65666962, 21.88750076], [88.65666962, 21.88722038], [88.65638733, 21.88694382], [88.65638733, 21.88638878], [88.65556335, 21.88557053], [88.65556335, 21.88528061], [88.65444183, 21.88417053], [88.65444183, 21.88305283], [88.65389252, 21.88249969], [88.65389252, 21.88221169], [88.65361023, 21.88194466], [88.65361023, 21.88166618], [88.6533432, 21.88138962], [88.65333557, 21.88111115], [88.65305328, 21.88083267], [88.65305328, 21.8777771], [88.6533432, 21.87750053], [88.65333557, 21.87666893], [88.65277863, 21.87610817], [88.65305328, 21.87583351], [88.65305328, 21.8741684], [88.65277863, 21.87388992], [88.65277863, 21.87355995], [88.65277863, 21.87333298], [88.65139008, 21.87194061], [88.64805603, 21.87194443], [88.64794159, 21.87205887], [88.64778137, 21.87222481], [88.6472168, 21.87222099], [88.64694214, 21.87249947], [88.64611053, 21.87249947], [88.64583588, 21.87277985], [88.64554596, 21.87277985], [88.64527893, 21.87306023], [88.64499664, 21.87306023], [88.64472198, 21.87334061], [88.64333344, 21.87333298], [88.64305878, 21.87361145], [88.64245605, 21.87360001], [88.64190674, 21.87363052], [88.64138794, 21.87360954], [88.64089203, 21.87359047], [88.64044952, 21.87348747], [88.6400528, 21.87334061], [88.63964844, 21.8731308], [88.63917542, 21.87295341], [88.63870239, 21.87271881], [88.63825989, 21.87244034], [88.63796234, 21.8722496], [88.63783264, 21.87216759], [88.63742828, 21.8718853], [88.63698578, 21.87163925], [88.6364975, 21.87137985], [88.63639069, 21.87138939], [88.6361084, 21.87111092], [88.63582611, 21.87111092], [88.63555908, 21.87083054], [88.63527679, 21.87083244], [88.63500214, 21.87055588], [88.63445282, 21.87055969], [88.63361359, 21.87138939], [88.63361359, 21.87194443], [88.6333313, 21.87222099], [88.6333313, 21.87249947], [88.63360596, 21.87277985], [88.63388824, 21.87331581], [88.63420105, 21.8737793], [88.63456726, 21.8741951], [88.63491058, 21.87461281], [88.63528442, 21.87498665], [88.63565826, 21.87531281], [88.63594055, 21.87569046], [88.63613892, 21.876091], [88.63638306, 21.87643814], [88.63646698, 21.87659645], [88.63656616, 21.87677956], [88.63660431, 21.8771553], [88.63643646, 21.87759209], [88.63633728, 21.87813187], [88.63613129, 21.87870026], [88.63591766, 21.87929726], [88.63552094, 21.87973022], [88.63503265, 21.88013077], [88.63452911, 21.88051414], [88.63395691, 21.8808403], [88.63339996, 21.88113976], [88.63285828, 21.8814106], [88.63237, 21.88167191], [88.63194275, 21.8819294], [88.6315155, 21.88210106], [88.63111877, 21.88229942], [88.63072968, 21.88253021], [88.63057709, 21.88265419], [88.63037872, 21.88281822], [88.63006592, 21.88316917], [88.62985992, 21.88357925], [88.6296463, 21.8839798], [88.62947083, 21.88442039], [88.62940979, 21.88492966], [88.62926483, 21.88548851], [88.62918091, 21.88611412], [88.62916565, 21.88675117], [88.62916565, 21.88722229], [88.62917328, 21.88861084], [88.62889099, 21.88888931], [88.62889862, 21.88972092], [88.6286087, 21.88999748], [88.62861633, 21.89057159], [88.6286087, 21.89112091], [88.6286087, 21.89166832], [88.6286087, 21.89222145], [88.62861633, 21.89276123], [88.6286087, 21.89331055], [88.62857819, 21.89386177], [88.62841034, 21.89439964], [88.6282959, 21.89500046], [88.6280899, 21.89557076], [88.62796021, 21.89616966], [88.62767792, 21.89665604], [88.62734222, 21.89709091], [88.62698364, 21.89750671], [88.62665558, 21.89792252], [88.62631989, 21.89829445], [88.62593842, 21.89860535], [88.62563324, 21.8988018], [88.62550354, 21.89888573], [88.62503052, 21.89917183], [88.62454987, 21.89949989], [88.62412262, 21.89992523], [88.623703, 21.90035057], [88.62345123, 21.90086937], [88.62338257, 21.90140915], [88.62361145, 21.90192032], [88.62402344, 21.90235519], [88.62449646, 21.90274048], [88.62496948, 21.90310669], [88.62539673, 21.90345573], [88.62576294, 21.90381241], [88.62612152, 21.90413094], [88.6264801, 21.90445518], [88.62683105, 21.90480042], [88.62717438, 21.90518188], [88.62753296, 21.90555954], [88.62792969, 21.90584564], [88.62828064, 21.90612221], [88.62857819, 21.9064045], [88.6288681, 21.90670967], [88.62915802, 21.90706825], [88.62944794, 21.90747833], [88.62973785, 21.90790939], [88.63005066, 21.90830994], [88.63037872, 21.90868759], [88.6307373, 21.90896988], [88.63101959, 21.90933037], [88.6312561, 21.90971184], [88.63149261, 21.91007042], [88.63168335, 21.91040993], [88.63189697, 21.91070938], [88.63202667, 21.91102982], [88.63220978, 21.91127777], [88.63236237, 21.91153145], [88.63249969, 21.91180038], [88.63262939, 21.91208076], [88.63277435, 21.91234589], [88.63291168, 21.9126339], [88.63304901, 21.91293716], [88.63315582, 21.91329956], [88.63334656, 21.91367912], [88.6335907, 21.91408348], [88.63378143, 21.91456223], [88.63395691, 21.91506958], [88.63417816, 21.91559029], [88.63443756, 21.91609955], [88.63468933, 21.91664505], [88.63491058, 21.91723061], [88.63510895, 21.91783714], [88.63530731, 21.91843033], [88.63555145, 21.91897011], [88.63581085, 21.91950035], [88.63609314, 21.92003059], [88.63640594, 21.92056274], [88.63683319, 21.92099953], [88.63722229, 21.92139053], [88.63861084, 21.92139053], [88.63889313, 21.92168045], [88.63999939, 21.92168045]]], [[[88.72360992, 21.93194389], [88.72416687, 21.93139076], [88.72444153, 21.93139076], [88.72444153, 21.93111038], [88.72499084, 21.93054962], [88.72499847, 21.93027878], [88.72528076, 21.93000031], [88.72528076, 21.92944908], [88.72556305, 21.92917061], [88.72556305, 21.92860985], [88.72611237, 21.92805481], [88.72611237, 21.92777634], [88.72638702, 21.92749023], [88.72638702, 21.9272213], [88.72666931, 21.92694664], [88.72666931, 21.92666435], [88.72693634, 21.92638969], [88.72693634, 21.92611122], [88.72721863, 21.92583084], [88.72721863, 21.92555428], [88.7277832, 21.92500114], [88.7277832, 21.92472076], [88.72833252, 21.92416573], [88.72833252, 21.92389107], [88.73055267, 21.92168045], [88.73055267, 21.92139053], [88.73221588, 21.9197216], [88.73249817, 21.9197216], [88.73278046, 21.91944504], [88.73306274, 21.91945267], [88.73332977, 21.91917038], [88.73361206, 21.91917038], [88.73388672, 21.91889191], [88.73416138, 21.91889191], [88.73443604, 21.91860771], [88.73500061, 21.91861153], [88.73527527, 21.91833305], [88.73583221, 21.91833305], [88.7361145, 21.91805649], [88.73777771, 21.9180584], [88.73805237, 21.91777992], [88.73880768, 21.91777992], [88.73972321, 21.91777992], [88.73999786, 21.9180584], [88.7408371, 21.91805649], [88.74111176, 21.91833305], [88.7416687, 21.91833305], [88.74194336, 21.91861153], [88.74276733, 21.91860771], [88.74305725, 21.91889191], [88.74360657, 21.91889191], [88.74388885, 21.91917038], [88.74416351, 21.91916656], [88.74472046, 21.9197216], [88.74500275, 21.9197216], [88.7452774, 21.92000008], [88.74555206, 21.92028046], [88.74583435, 21.92027855], [88.74771881, 21.92216492], [88.74888611, 21.92333221], [88.74916077, 21.92333031], [88.75, 21.92416954], [88.75027466, 21.92416573], [88.75074768, 21.92464066], [88.7508316, 21.92472267], [88.75110626, 21.92472076], [88.75166321, 21.92527962], [88.75195313, 21.92527962], [88.75222778, 21.92556], [88.75250244, 21.92555428], [88.7527771, 21.92583275], [88.75304413, 21.92587852], [88.75332642, 21.92611122], [88.7536087, 21.92611122], [88.75389099, 21.92638969], [88.75416565, 21.92638969], [88.75435638, 21.92657661], [88.75444794, 21.92667007], [88.7555542, 21.92666435], [88.75576019, 21.92687035], [88.75583649, 21.92694664], [88.75611115, 21.92694664], [88.7563858, 21.92666435], [88.75945282, 21.92667007], [88.75971985, 21.92638969], [88.76082611, 21.92638969], [88.76110077, 21.92611122], [88.76304626, 21.92611122], [88.76333618, 21.92583084], [88.76361084, 21.92611122], [88.76444244, 21.92611122], [88.7647171, 21.92583084], [88.76833344, 21.92583275], [88.76860809, 21.92555428], [88.76972198, 21.92556], [88.76999664, 21.92527962], [88.77054596, 21.92527962], [88.77083588, 21.92500114], [88.77111053, 21.92500114], [88.77139282, 21.92472076], [88.77388763, 21.92472267], [88.77416992, 21.92444229], [88.77500153, 21.92444992], [88.77583313, 21.92361069], [88.77610779, 21.92361069], [88.77694702, 21.9227829], [88.77749634, 21.9227829], [88.77777863, 21.92250061], [88.77749634, 21.92222023], [88.77805328, 21.92222214], [88.77861023, 21.9216671], [88.77889252, 21.92168045], [88.77971649, 21.92083168], [88.77999878, 21.92083359], [88.78083038, 21.92000008], [88.78111267, 21.92000008], [88.78138733, 21.9197216], [88.78166962, 21.9197216], [88.78194427, 21.91944504], [88.7822113, 21.91945267], [88.78250122, 21.91917038], [88.78305817, 21.91917038], [88.78333282, 21.91889191], [88.78360748, 21.91889191], [88.78388977, 21.91860771], [88.78472137, 21.91861153], [88.78500366, 21.91833305], [88.78527832, 21.91833305], [88.78555298, 21.91805649], [88.7858429, 21.9180584], [88.78610992, 21.91777992], [88.78666687, 21.91777992], [88.78694153, 21.91749954], [88.78888702, 21.91749954], [88.78916931, 21.91721916], [88.79250336, 21.91721916], [88.79277802, 21.91749954], [88.79332733, 21.91749954], [88.79360962, 21.91777992], [88.79416656, 21.91777992], [88.79444122, 21.9180584], [88.79499054, 21.9181118], [88.79528046, 21.91833305], [88.79555511, 21.91833305], [88.79582977, 21.91861153], [88.79638672, 21.91861153], [88.79652405, 21.91875076], [88.79666901, 21.91889191], [88.79693604, 21.91889191], [88.79722595, 21.91917038], [88.79750061, 21.91916656], [88.79805756, 21.9197216], [88.79944611, 21.9197216], [88.80000305, 21.91916656], [88.80000305, 21.91889191], [88.80027008, 21.91860771], [88.80027771, 21.91777992], [88.80055237, 21.91749954], [88.80082703, 21.91749954], [88.80110931, 21.91721916], [88.8013916, 21.91722298], [88.80166626, 21.9169445], [88.80194092, 21.9169445], [88.80278015, 21.91611099], [88.80249786, 21.91583061], [88.80278015, 21.91555786], [88.80305481, 21.91555786], [88.80388641, 21.91472244], [88.80388641, 21.91444588], [88.80500031, 21.9133358], [88.80500031, 21.91305733], [88.80526733, 21.91278076], [88.80526733, 21.91250992], [88.80555725, 21.91222], [88.80555725, 21.91194344], [88.80610657, 21.9113903], [88.80610657, 21.91110992], [88.80666351, 21.91055489], [88.80666351, 21.91027832], [88.80705261, 21.90988922], [88.8077774, 21.90916634], [88.8077774, 21.90888977], [88.80983734, 21.90682983], [88.81194305, 21.90472221], [88.81222534, 21.90472221], [88.81361389, 21.90333366], [88.8133316, 21.90305519], [88.81388855, 21.90306091], [88.81416321, 21.90278053], [88.81416321, 21.90250015], [88.81388855, 21.90221977], [88.81388855, 21.90194511], [88.81445313, 21.90139008], [88.81360626, 21.90055084], [88.81361389, 21.90027618], [88.81276703, 21.89944077], [88.8125, 21.89944649], [88.81222534, 21.8991642], [88.81223297, 21.89888954], [88.81098175, 21.89764214], [88.81027985, 21.89694214], [88.80999756, 21.89694214], [88.80999756, 21.89666748], [88.80860901, 21.89528275], [88.80860901, 21.89389038], [88.8088913, 21.89361191], [88.8088913, 21.89250183], [88.80860901, 21.89222145], [88.80860901, 21.89027977], [88.80832672, 21.88999748], [88.80832672, 21.88982964], [88.80833435, 21.88916779], [88.80860901, 21.88889122], [88.80860901, 21.88582993], [88.80833435, 21.88555336], [88.80832672, 21.88500023], [88.80805206, 21.88471985], [88.80805206, 21.88444328], [88.80750275, 21.88389015], [88.80750275, 21.88360977], [88.80666351, 21.88277817], [88.80639648, 21.88278008], [88.80602264, 21.88241005], [88.80527496, 21.88166618], [88.80500031, 21.88167191], [88.80473328, 21.88138962], [88.80444336, 21.88138962], [88.8041687, 21.88111115], [88.80388641, 21.88111115], [88.8033371, 21.88056183], [88.80304718, 21.88056183], [88.80194092, 21.8794384], [88.80166626, 21.87944412], [88.8013916, 21.87916756], [88.80110931, 21.87916946], [88.80082703, 21.87888908], [88.80027008, 21.87888908], [88.80000305, 21.87861061], [88.79915619, 21.87861061], [88.79888916, 21.87832832], [88.7986145, 21.87833405], [88.79777527, 21.87750053], [88.79750061, 21.87750053], [88.79666901, 21.87667084], [88.79666901, 21.87610817], [88.79638672, 21.87583351], [88.79638672, 21.87555695], [88.79611206, 21.87528038], [88.79611206, 21.875], [88.79582977, 21.87471962], [88.79582977, 21.87444687], [88.79556274, 21.8741703], [88.79555511, 21.87376022], [88.79555511, 21.87361145], [88.79528046, 21.87333298], [88.79528046, 21.87277985], [88.79499817, 21.87249947], [88.79499817, 21.87222099], [88.79472351, 21.87194443], [88.79472351, 21.87138939], [88.79416656, 21.87083054], [88.79416656, 21.87000084], [88.79389191, 21.86972046], [88.79389191, 21.86916733], [88.79360962, 21.86889076], [88.79360962, 21.86861038], [88.79332733, 21.86833191], [88.79333496, 21.86805534], [88.79277802, 21.86750031], [88.79277802, 21.86720848], [88.79083252, 21.86527824], [88.79055786, 21.86528015], [88.7902832, 21.86499977], [88.79000092, 21.86499977], [88.78971863, 21.86471748], [88.78806305, 21.86471748], [88.78778076, 21.86499977], [88.78749847, 21.86499977], [88.78694153, 21.86555481], [88.78694153, 21.86611176], [88.78721619, 21.86639023], [88.78722382, 21.86694527], [88.78749847, 21.86720848], [88.78749847, 21.86750031], [88.78778076, 21.86750031], [88.78971863, 21.86944389], [88.79000092, 21.86944389], [88.79027557, 21.86972237], [88.79055786, 21.86972046], [88.79083252, 21.87000084], [88.79110718, 21.87000084], [88.79250336, 21.87138939], [88.79250336, 21.87166405], [88.79277802, 21.87194443], [88.79277802, 21.87222099], [88.79332733, 21.87277985], [88.79333496, 21.87388611], [88.79360199, 21.87416077], [88.79360962, 21.87528038], [88.79332733, 21.87556076], [88.79332733, 21.87639809], [88.79305267, 21.87666893], [88.79305267, 21.87694359], [88.79277802, 21.87721825], [88.79277802, 21.87750053], [88.79250336, 21.87778091], [88.79250336, 21.87805939], [88.79194641, 21.87861061], [88.79165649, 21.87861061], [88.79139709, 21.87888908], [88.79110718, 21.87888908], [88.79083252, 21.87916946], [88.78944397, 21.87916756], [88.78916931, 21.87944412], [88.78833008, 21.87944412], [88.78805542, 21.87916756], [88.78749847, 21.87916946], [88.78721619, 21.87888908], [88.78694153, 21.87888908], [88.78666687, 21.87861061], [88.78639221, 21.87861061], [88.78527069, 21.87750053], [88.78527069, 21.87724113], [88.78472137, 21.87667084], [88.78444672, 21.87667084], [88.78444672, 21.87639809], [88.78388977, 21.8758297], [88.78388977, 21.87555695], [88.78360748, 21.87528038], [88.78360748, 21.875], [88.78305817, 21.87445068], [88.78277588, 21.87445068], [88.78277588, 21.8741703], [88.78193665, 21.87334061], [88.78193665, 21.87306023], [88.77916718, 21.87026978], [88.77889252, 21.8702774], [88.77833557, 21.86972237], [88.77777863, 21.86972237], [88.7775116, 21.86960983], [88.77694702, 21.8694706], [88.77639008, 21.86972237], [88.77610779, 21.86972046], [88.77583313, 21.87000084], [88.77583313, 21.87055588], [88.77555847, 21.87083054], [88.77555847, 21.87111092], [88.77500153, 21.87166405], [88.77500153, 21.87194443], [88.77471924, 21.87222099], [88.77471924, 21.87277985], [88.77444458, 21.8730545], [88.77443695, 21.87360954], [88.77416992, 21.87388992], [88.77416992, 21.87444687], [88.77388763, 21.87471962], [88.77388763, 21.87528038], [88.77361298, 21.87555695], [88.77361298, 21.87589073], [88.77361298, 21.87610817], [88.77305603, 21.87666893], [88.77305603, 21.87693977], [88.77194214, 21.87805939], [88.77111053, 21.87805557], [88.77083588, 21.87833405], [88.77054596, 21.87832832], [88.7702713, 21.87861061], [88.76972198, 21.87861061], [88.76944733, 21.87888908], [88.76917267, 21.87888908], [88.76889038, 21.87916946], [88.76833344, 21.87916756], [88.76805878, 21.87944412], [88.76777649, 21.87944412], [88.76667023, 21.87833405], [88.76638794, 21.87832832], [88.76611328, 21.87861061], [88.76444244, 21.87861061], [88.76416779, 21.87888908], [88.76361084, 21.87888908], [88.76333618, 21.87916946], [88.76265717, 21.87916756], [88.76194763, 21.87916756], [88.76166534, 21.87944412], [88.76083374, 21.87944412], [88.76055908, 21.8797226], [88.7591629, 21.87972069], [88.75888824, 21.88000107], [88.7583313, 21.88000107], [88.75805664, 21.88027763], [88.75805664, 21.88083267], [88.75777435, 21.88111115], [88.75777435, 21.88333321], [88.75805664, 21.88360977], [88.75805664, 21.88500023], [88.75776672, 21.88528061], [88.75777435, 21.88555336], [88.75749969, 21.88582993], [88.75749969, 21.88639069], [88.75722504, 21.88638878], [88.75666809, 21.88694382], [88.7563858, 21.88694382], [88.75611115, 21.88722229], [88.7555542, 21.88722229], [88.75528717, 21.88750076], [88.75499725, 21.88750076], [88.7547226, 21.88778114], [88.75417328, 21.88778114], [88.75389099, 21.88805962], [88.75314331, 21.88805771], [88.75250244, 21.88805962], [88.75222778, 21.88833809], [88.75166321, 21.88833809], [88.75138855, 21.88861084], [88.7508316, 21.88861084], [88.75055695, 21.88889122], [88.75055695, 21.88916779], [88.75026703, 21.88944054], [88.75026703, 21.89027977], [88.75, 21.89055634], [88.75, 21.89138031], [88.75027466, 21.89166641], [88.75026703, 21.89222145], [88.75055695, 21.89250183], [88.75055695, 21.89340019], [88.75055695, 21.89361191], [88.7508316, 21.89389038], [88.7508316, 21.89416695], [88.75055695, 21.8944416], [88.75055695, 21.8955555], [88.75026703, 21.89583015], [88.75026703, 21.89611053], [88.75, 21.89639091], [88.74972534, 21.89638901], [88.74888611, 21.89722252], [88.74861145, 21.89722061], [88.74833679, 21.89751053], [88.74804687, 21.89751053], [88.74749756, 21.89805984], [88.7472229, 21.89805412], [88.74694824, 21.8983326], [88.74666595, 21.89833069], [88.7463913, 21.89861107], [88.74610138, 21.89861107], [88.74582672, 21.89888954], [88.74555206, 21.89888954], [88.7452774, 21.89916992], [88.74500275, 21.8991642], [88.74472046, 21.89944649], [88.74416351, 21.89944649], [88.74388885, 21.89972305], [88.74333191, 21.89972115], [88.74305725, 21.89999962], [88.74194336, 21.89999962], [88.7416687, 21.90028], [88.74111176, 21.90027618], [88.7408371, 21.90055466], [88.74055481, 21.90055466], [88.74028015, 21.90027618], [88.73832703, 21.90028], [88.73805237, 21.89999962], [88.73527527, 21.89999962], [88.73500061, 21.89972305], [88.73443604, 21.89972115], [88.73416138, 21.89999962], [88.73332977, 21.89999962], [88.73320007, 21.89986992], [88.73305511, 21.89972305], [88.72915649, 21.89972115], [88.72888947, 21.89999962], [88.72860718, 21.89999962], [88.72833252, 21.90028], [88.72805786, 21.90027618], [88.72777557, 21.90055466], [88.72750092, 21.90055084], [88.72666931, 21.90139008], [88.72638702, 21.90139008], [88.72611237, 21.90167046], [88.72583008, 21.90167046], [88.72471619, 21.90278053], [88.72471619, 21.90306091], [88.72277832, 21.90500069], [88.72277832, 21.90527725], [88.72110748, 21.90694427], [88.72110748, 21.90722275], [88.71971893, 21.9086113], [88.71943665, 21.90860939], [88.71888733, 21.90916634], [88.71888733, 21.90989113], [88.71888733, 21.91027832], [88.71861267, 21.91055489], [88.71861267, 21.91083336], [88.71833038, 21.91111183], [88.71833038, 21.91222], [88.71778107, 21.91278076], [88.71778107, 21.91389084], [88.71749878, 21.9141655], [88.71749878, 21.91444588], [88.71721649, 21.91472054], [88.71721649, 21.91611099], [88.71694183, 21.91638947], [88.71694183, 21.91749954], [88.71666718, 21.91777992], [88.71694183, 21.91805649], [88.71694183, 21.91860771], [88.71722412, 21.91888809], [88.71721649, 21.91950035], [88.71721649, 21.9197216], [88.71749878, 21.92000008], [88.71749878, 21.92194366], [88.71778107, 21.92222023], [88.71778107, 21.9227829], [88.71806335, 21.92305946], [88.71805573, 21.92444229], [88.71833038, 21.92472076], [88.71833038, 21.92500114], [88.71861267, 21.92527962], [88.71861267, 21.92555428], [88.71888733, 21.92583084], [88.71888733, 21.92611122], [88.71916962, 21.92638969], [88.71916962, 21.92694664], [88.72027588, 21.92805481], [88.72027588, 21.92833328], [88.72055817, 21.92860985], [88.72055817, 21.92917061], [88.72083282, 21.92944527], [88.72083282, 21.92971992], [88.72110748, 21.93000031], [88.72110748, 21.93054962], [88.72174072, 21.93117905], [88.72194672, 21.93139076], [88.72277832, 21.93139076], [88.72305298, 21.93166924], [88.72333527, 21.93166733], [88.72360992, 21.93194389]]], [[[88.98610687, 22.10170364], [88.98631287, 22.10217094], [88.98645782, 22.10266113], [88.98667145, 22.10313225], [88.98690796, 22.10359001], [88.98713684, 22.10407066], [88.98742676, 22.10447121], [88.98770142, 22.1048584], [88.98783112, 22.1052494], [88.98786163, 22.1053524], [88.98806763, 22.10583305], [88.98828125, 22.10630417], [88.98841095, 22.10684013], [88.98860931, 22.10733795], [88.98880768, 22.10784149], [88.98896027, 22.10839081], [88.98916626, 22.10892296], [88.98944092, 22.10944557], [88.98967743, 22.10999489], [88.98980713, 22.11061287], [88.99002075, 22.11112022], [88.99025726, 22.11148834], [88.99043274, 22.11182976], [88.99057007, 22.11213684], [88.99072266, 22.11240005], [88.99079895, 22.1127224], [88.99087524, 22.11305046], [88.99105072, 22.1133213], [88.99114227, 22.11369324], [88.99128723, 22.1140995], [88.99141693, 22.11462975], [88.9916687, 22.11515236], [88.99194336, 22.1156826], [88.99220276, 22.11623192], [88.99237823, 22.11683273], [88.99252319, 22.11745262], [88.9927063, 22.11802864], [88.99298859, 22.11853981], [88.99330139, 22.11903191], [88.99355316, 22.11957932], [88.99378967, 22.12013626], [88.99394226, 22.12078476], [88.99416351, 22.12139702], [88.99442291, 22.12200165], [88.99465179, 22.12262154], [88.99479675, 22.12325287], [88.99497223, 22.12371826], [88.99500275, 22.12389374], [88.99500275, 22.1241703], [88.9952774, 22.12444305], [88.9952774, 22.12471962], [88.99555206, 22.12500191], [88.99555206, 22.12583351], [88.99581909, 22.12610054], [88.99583435, 22.12666512], [88.99610901, 22.12693977], [88.99610138, 22.1272831], [88.99610138, 22.12750053], [88.99610901, 22.12778282], [88.99616241, 22.12828255], [88.99633789, 22.12870026], [88.99639893, 22.12915993], [88.99646759, 22.12962914], [88.99662018, 22.13009262], [88.99671173, 22.1306324], [88.99682617, 22.13117027], [88.99687195, 22.13174248], [88.99671173, 22.13229942], [88.99666595, 22.13287163], [88.99668121, 22.13343239], [88.99677277, 22.1339817], [88.99690247, 22.13451958], [88.99694061, 22.13511658], [88.99694824, 22.13570976], [88.99694824, 22.13632011], [88.99694061, 22.13691139], [88.99694061, 22.13749123], [88.99694061, 22.13802719], [88.99690247, 22.13848305], [88.99672699, 22.1388607], [88.99666595, 22.13922119], [88.99663544, 22.13962746], [88.99661255, 22.14011955], [88.99643707, 22.14065933], [88.99633789, 22.14127159], [88.99610901, 22.14177132], [88.99594879, 22.14225006], [88.99582672, 22.14273262], [88.99569702, 22.14318275], [88.99555206, 22.14362144], [88.99537659, 22.14408302], [88.99524689, 22.14463234], [88.99504089, 22.14521217], [88.99491882, 22.14587975], [88.9947052, 22.14646339], [88.9944458, 22.14697075], [88.99424744, 22.14744186], [88.99411774, 22.14787102], [88.99394989, 22.1482048], [88.99385834, 22.14855003], [88.99369812, 22.14880943], [88.99353027, 22.14905357], [88.99337006, 22.14932251], [88.99323273, 22.14967155], [88.99302673, 22.15003014], [88.99279022, 22.15041351], [88.99256134, 22.15083885], [88.99233246, 22.15128136], [88.99214172, 22.15175056], [88.9919281, 22.15221977], [88.99166107, 22.15265465], [88.9913559, 22.15310478], [88.99108124, 22.1536274], [88.9907608, 22.15413475], [88.99040985, 22.15459251], [88.99006653, 22.15498161], [88.98977661, 22.1552906], [88.98954773, 22.15556145], [88.98935699, 22.15582085], [88.98916626, 22.15604973], [88.98899841, 22.15629768], [88.98883057, 22.15659142], [88.98860168, 22.15686989], [88.98833466, 22.15717888], [88.98806763, 22.15752029], [88.9878006, 22.15789032], [88.98754883, 22.15827179], [88.98726654, 22.15863228], [88.98696136, 22.15900993], [88.98664093, 22.15941048], [88.98625183, 22.15977287], [88.98590851, 22.16019249], [88.98548126, 22.16058159], [88.98506165, 22.16106224], [88.98458099, 22.16155052], [88.98407745, 22.1620388], [88.98356628, 22.16249275], [88.98310852, 22.16291046], [88.98277283, 22.1633625], [88.98240662, 22.16377068], [88.98203278, 22.16415977], [88.98159027, 22.16452217], [88.98110199, 22.16485977], [88.98060608, 22.1652317], [88.98015594, 22.16567039], [88.97970581, 22.1661129], [88.97918701, 22.16649055], [88.97871399, 22.16689873], [88.97824097, 22.16731071], [88.97779846, 22.16775131], [88.97737885, 22.16818047], [88.97701263, 22.16864967], [88.97670746, 22.1691227], [88.97642517, 22.16955757], [88.97621918, 22.17002678], [88.9760437, 22.1705246], [88.97584534, 22.17102051], [88.97569275, 22.17152977], [88.97556305, 22.17206764], [88.97544861, 22.17256927], [88.97522736, 22.17300224], [88.97501373, 22.1734333], [88.97483826, 22.17391205], [88.97471619, 22.17443275], [88.97459412, 22.17495918], [88.97441101, 22.17544365], [88.97424316, 22.1759243], [88.97415161, 22.1764431], [88.97402954, 22.17694473], [88.9739151, 22.17743683], [88.97389221, 22.17798042], [88.97386932, 22.1785717], [88.97379303, 22.17917442], [88.97373962, 22.17980385], [88.97383118, 22.18040466], [88.97374725, 22.18095207], [88.97358704, 22.18148232], [88.97342682, 22.1819725], [88.9733429, 22.18244934], [88.97332764, 22.18293953], [88.9733429, 22.18343353], [88.9733429, 22.18388748], [88.97333527, 22.18432808], [88.97333527, 22.18647957], [88.9733429, 22.18713951], [88.97333527, 22.18780518], [88.9733429, 22.18844032], [88.97328949, 22.18901634], [88.97312164, 22.18950081], [88.97306061, 22.18996811], [88.97305298, 22.19043159], [88.9730072, 22.19089127], [88.9728775, 22.1913147], [88.97279358, 22.19175148], [88.97277832, 22.19219971], [88.97277069, 22.19264221], [88.9727478, 22.19305229], [88.97268677, 22.19343758], [88.97296143, 22.19381142], [88.97309113, 22.19385719], [88.9734726, 22.19399071], [88.97409058, 22.19392014], [88.97475433, 22.19389534], [88.97544861, 22.19388771], [88.97612, 22.19384193], [88.97673035, 22.19367981], [88.9773407, 22.19374275], [88.97795105, 22.19386292], [88.97859192, 22.19389534], [88.97926331, 22.19395256], [88.97991943, 22.19407272], [88.98055267, 22.19416237], [88.98116302, 22.19426155], [88.98167419, 22.19442558], [88.98220062, 22.19456482], [88.98272705, 22.19473839], [88.98324585, 22.19496155], [88.98384857, 22.19511223], [88.98442841, 22.19532394], [88.98496246, 22.19556236], [88.98543549, 22.19580269], [88.98590088, 22.19592094], [88.98629761, 22.19608307], [88.98670959, 22.19618034], [88.98707581, 22.19637871], [88.98750305, 22.19656372], [88.98796844, 22.19675255], [88.98844147, 22.19695854], [88.98890686, 22.19721413], [88.98938751, 22.19745255], [88.98982239, 22.1977253], [88.99030304, 22.19791222], [88.9907608, 22.19808006], [88.99124146, 22.1982708], [88.99179077, 22.19838715], [88.99236298, 22.19857216], [88.99304199, 22.19865417], [88.99372864, 22.19885254], [88.99447632, 22.19893456], [88.99475861, 22.1989975], [88.99518585, 22.19908905], [88.99589539, 22.19897461], [88.99656677, 22.19912148], [88.99720764, 22.19916916], [88.99775696, 22.19921303], [88.99819946, 22.19932747], [88.99891663, 22.19937325], [88.99945831, 22.19927025], [89.0, 22.19916725], [89.00051117, 22.19935226], [89.00068665, 22.19936562], [89.0009079, 22.19938087], [89.00114441, 22.19930077], [89.00138092, 22.19922447], [89.00193024, 22.19917107], [89.00251007, 22.19916916], [89.00309753, 22.19916916], [89.00366974, 22.19913483], [89.00418854, 22.19892311], [89.00469971, 22.19876289], [89.00518036, 22.19862175], [89.00563812, 22.19851112], [89.00605774, 22.19835281], [89.00649261, 22.19822121], [89.00689697, 22.19807243], [89.00733948, 22.19794273], [89.00775146, 22.19778252], [89.00819397, 22.19764328], [89.0086441, 22.1974926], [89.00908661, 22.19731712], [89.00955963, 22.19719124], [89.00997162, 22.19698334], [89.01039886, 22.19681931], [89.01080322, 22.19664955], [89.01116943, 22.19643211], [89.01163483, 22.19634819], [89.01209259, 22.19614029], [89.01258087, 22.1960125], [89.01302338, 22.19582176], [89.01338959, 22.19554329], [89.01368713, 22.1951828], [89.01390076, 22.19473076], [89.01410675, 22.19426155], [89.01418304, 22.19370079], [89.01425934, 22.19313812], [89.01441193, 22.19263458], [89.01444244, 22.19214058], [89.01445007, 22.19168282], [89.01445007, 22.19123268], [89.01444244, 22.19079208], [89.01439667, 22.19035149], [89.01421356, 22.18995857], [89.01418304, 22.18951225], [89.01412964, 22.18906975], [89.01397705, 22.18868065], [89.01390076, 22.18829155], [89.0138855, 22.18787956], [89.0138855, 22.18742561], [89.01389313, 22.18693352], [89.0138855, 22.18642426], [89.01384735, 22.18593025], [89.01365662, 22.18549156], [89.01361084, 22.18499184], [89.01360321, 22.18448067], [89.01352692, 22.18399239], [89.0133667, 22.18354225], [89.01329041, 22.1830883], [89.01309967, 22.18268013], [89.01305389, 22.18220139], [89.01300812, 22.18168449], [89.01286316, 22.18118858], [89.01300049, 22.1807003], [89.01305389, 22.18024063], [89.01303864, 22.17980003], [89.01294708, 22.17935181], [89.01280975, 22.17884827], [89.01277924, 22.17833328], [89.01277924, 22.17638969], [89.01304626, 22.17611122], [89.01304626, 22.17556381], [89.01328278, 22.17529106], [89.01332855, 22.17479134], [89.01333618, 22.17424011], [89.0134201, 22.17369843], [89.01357269, 22.17319107], [89.01361084, 22.17270851], [89.01361847, 22.17226219], [89.01366425, 22.17186356], [89.01382446, 22.1715107], [89.01393127, 22.17107391], [89.01415253, 22.17062187], [89.01434326, 22.17006874], [89.01442719, 22.16938972], [89.01444244, 22.16866112], [89.0144577, 22.16794968], [89.01454163, 22.16731071], [89.01467896, 22.16679573], [89.01472473, 22.16666412], [89.0147171, 22.16639137], [89.01444244, 22.1661129], [89.01444244, 22.16444206], [89.01472473, 22.1641674], [89.0147171, 22.16361046], [89.01499939, 22.16333389], [89.01499939, 22.16250038], [89.01526642, 22.16220856], [89.01528931, 22.16165733], [89.01535797, 22.16121101], [89.01551819, 22.1607914], [89.01558685, 22.16033936], [89.01579285, 22.15995216], [89.01586914, 22.15950203], [89.01603699, 22.15908813], [89.01618958, 22.15865517], [89.0164032, 22.15821266], [89.01667023, 22.15775108], [89.01693726, 22.15727425], [89.0171814, 22.15678978], [89.01734161, 22.15629005], [89.01753235, 22.15587044], [89.0177536, 22.15554428], [89.01791382, 22.15514946], [89.01809692, 22.15472221], [89.01834869, 22.15427017], [89.01863098, 22.15381432], [89.0189743, 22.15337944], [89.01937866, 22.15298271], [89.0196991, 22.15253258], [89.02001953, 22.15207291], [89.02031708, 22.15166473], [89.02059174, 22.1512394], [89.02085114, 22.15081978], [89.02194214, 22.14972115], [89.02194214, 22.14916611], [89.0222168, 22.14888954], [89.0222168, 22.14861107], [89.02242279, 22.14836311], [89.02275848, 22.14821434], [89.02309418, 22.14806938], [89.02340698, 22.14796257], [89.02368164, 22.14777946], [89.02397156, 22.1475811], [89.02436066, 22.14743805], [89.02475739, 22.14720917], [89.025177, 22.14695168], [89.02561951, 22.14668274], [89.02606964, 22.14641571], [89.02651215, 22.14608955], [89.02694702, 22.14570236], [89.02744293, 22.14531136], [89.02800751, 22.14500237], [89.02861023, 22.14470673], [89.02916718, 22.14434242], [89.02971649, 22.14398384], [89.03025818, 22.14364052], [89.03082275, 22.14334297], [89.03137207, 22.14306068], [89.03190613, 22.14279938], [89.03238678, 22.14251137], [89.0328598, 22.14223289], [89.03329468, 22.14197159], [89.03371429, 22.14167976], [89.03417206, 22.14138985], [89.0346756, 22.14114571], [89.03518677, 22.14084053], [89.03572845, 22.14055443], [89.03627777, 22.14027977], [89.03682709, 22.1400013], [89.03736877, 22.13975334], [89.03791809, 22.13954735], [89.03839874, 22.13924217], [89.03890228, 22.13900185], [89.03940582, 22.13880539], [89.03988647, 22.13857079], [89.04033661, 22.1382885], [89.04080963, 22.13802147], [89.04128265, 22.13775063], [89.04173279, 22.13744164], [89.04220581, 22.13718033], [89.04266357, 22.13692284], [89.04307556, 22.13664818], [89.04345703, 22.13638115], [89.04383087, 22.13610268], [89.04418945, 22.1358223], [89.04456329, 22.13554955], [89.0449295, 22.13529015], [89.04533386, 22.1350975], [89.04577637, 22.13496971], [89.04619598, 22.13475227], [89.04664612, 22.13459969], [89.04709625, 22.13440132], [89.04751587, 22.13415527], [89.04792023, 22.13388252], [89.04831696, 22.13356972], [89.04870605, 22.1332531], [89.04911041, 22.13291931], [89.04943848, 22.1325016], [89.04972839, 22.13209343], [89.04999542, 22.13174629], [89.05021667, 22.13142967], [89.05034637, 22.13105011], [89.05047607, 22.1306324], [89.05031586, 22.13018227], [89.05012512, 22.12967873], [89.04995728, 22.12910843], [89.04972076, 22.12862206], [89.04946136, 22.12817955], [89.04924774, 22.12777519], [89.04904938, 22.12740135], [89.04878235, 22.12709618], [89.04854584, 22.1267128], [89.04824066, 22.126297], [89.04788971, 22.12581253], [89.04749298, 22.12526131], [89.04702759, 22.12469292], [89.04659271, 22.12410164], [89.04615784, 22.12354469], [89.04574585, 22.12298393], [89.04528809, 22.12248421], [89.0448761, 22.12196922], [89.04447937, 22.12151146], [89.04415894, 22.12104034], [89.04388428, 22.12064171], [89.04360962, 22.12029076], [89.04332733, 22.1199398], [89.04303741, 22.11956978], [89.04268646, 22.1192112], [89.04226685, 22.11888313], [89.04187775, 22.11852455], [89.04152679, 22.11808968], [89.04115295, 22.11770058], [89.04084015, 22.11732674], [89.04055786, 22.1169796], [89.04029083, 22.11666298], [89.04001617, 22.11634254], [89.03972626, 22.11597824], [89.0394516, 22.11556435], [89.03916931, 22.11513329], [89.03889465, 22.11473274], [89.03866577, 22.11438179], [89.03849792, 22.11405945], [89.03832245, 22.11379814], [89.03813934, 22.11356163], [89.03798676, 22.11328316], [89.03777313, 22.11301231], [89.0375061, 22.1127224], [89.03723145, 22.11235237], [89.03692627, 22.11194038], [89.03656006, 22.11156845], [89.03616333, 22.11127663], [89.0358429, 22.11095238], [89.03556061, 22.11066818], [89.03526306, 22.11047173], [89.03475952, 22.11046791], [89.03410339, 22.11074638], [89.03348541, 22.11094093], [89.03305054, 22.11087608], [89.03247833, 22.11087608], [89.03218842, 22.11094475], [89.0318985, 22.11087608], [89.03147125, 22.11088181], [89.03103638, 22.11108017], [89.03060913, 22.11121178], [89.0300293, 22.11114311], [89.02931213, 22.11114311], [89.02857971, 22.11124992], [89.02802277, 22.11122131], [89.02745056, 22.11134148], [89.02688599, 22.11141014], [89.02636719, 22.11139107], [89.02587128, 22.11136818], [89.025383, 22.11133003], [89.02485657, 22.11136055], [89.02435303, 22.11141014], [89.0238266, 22.11147118], [89.02333069, 22.11158943], [89.02287292, 22.11163712], [89.02243805, 22.11165047], [89.02201843, 22.11166382], [89.02158356, 22.11166954], [89.02110291, 22.1117115], [89.02060699, 22.11185265], [89.02005768, 22.11199188], [89.01953125, 22.11219025], [89.01899719, 22.11237144], [89.01844788, 22.1125412], [89.01789856, 22.11275291], [89.01734924, 22.11294937], [89.01686096, 22.11321831], [89.01654816, 22.11363411], [89.01629639, 22.11419296], [89.01637268, 22.11494255], [89.0170517, 22.11535072], [89.01743317, 22.11551094], [89.01807404, 22.11551094], [89.01856995, 22.11565971], [89.01901245, 22.11584282], [89.01943207, 22.11604118], [89.01989746, 22.11617088], [89.02035522, 22.11631012], [89.02081299, 22.11638069], [89.02125549, 22.11645889], [89.02165985, 22.11659431], [89.02206421, 22.11668396], [89.02245331, 22.11680031], [89.02282715, 22.11699104], [89.02322388, 22.11720657], [89.02365875, 22.11743927], [89.02411652, 22.11770058], [89.02462769, 22.1179142], [89.02519226, 22.11807251], [89.02574921, 22.11824226], [89.02628326, 22.11841774], [89.02680206, 22.11863136], [89.02735138, 22.11886024], [89.02794647, 22.11907005], [89.02858734, 22.11920738], [89.02919006, 22.11936378], [89.02970123, 22.11952019], [89.03006744, 22.1197567], [89.03029633, 22.12001228], [89.03048706, 22.12027168], [89.03061676, 22.12056351], [89.03077698, 22.12082672], [89.03089905, 22.12115288], [89.03098297, 22.12154961], [89.03088379, 22.12200737], [89.03055573, 22.12246895], [89.03012848, 22.12294197], [89.02942657, 22.12290382], [89.02935028, 22.12270164], [89.0296402, 22.12236977], [89.02993011, 22.12196159], [89.02978516, 22.1211586], [89.02935028, 22.12068939], [89.02885437, 22.12054634], [89.02842712, 22.12038994], [89.02799988, 22.12030411], [89.02751923, 22.12029076], [89.02697754, 22.12026024], [89.02632904, 22.12001801], [89.02559662, 22.11977959], [89.02484894, 22.1195507], [89.02410889, 22.11930275], [89.0234375, 22.11898232], [89.02279663, 22.11861229], [89.02214813, 22.11825752], [89.021492, 22.11794281], [89.02083588, 22.11770058], [89.02026367, 22.11745262], [89.01980591, 22.11721992], [89.01940918, 22.11704063], [89.01905823, 22.11693001], [89.01889038, 22.1169529], [89.01764679, 22.11661148], [89.01667023, 22.11610985], [89.01615143, 22.11574554], [89.01567078, 22.11541176], [89.01522827, 22.11498642], [89.0148468, 22.11452866], [89.01464844, 22.11400795], [89.01465607, 22.11351013], [89.01489258, 22.11310005], [89.01526642, 22.1127491], [89.01571655, 22.11238289], [89.01628876, 22.11207771], [89.01692963, 22.11182213], [89.01758575, 22.11157417], [89.01824951, 22.11130714], [89.01862335, 22.11124992], [89.01920319, 22.11118317], [89.0194931, 22.11112022], [89.01998901, 22.11098289], [89.0203476, 22.11085129], [89.02107239, 22.1108532], [89.02164459, 22.11058235], [89.0222168, 22.11044884], [89.02279663, 22.11045265], [89.02336884, 22.11032295], [89.02416229, 22.11025047], [89.02452087, 22.11025047], [89.02516174, 22.11032295], [89.02774811, 22.11032295], [89.02818298, 22.11011314], [89.02880096, 22.11012077], [89.02971649, 22.11018944], [89.03044128, 22.11018944], [89.03100586, 22.11012077], [89.0318985, 22.10993195], [89.03263092, 22.10969925], [89.03334808, 22.10965919], [89.03404999, 22.10960197], [89.0348587, 22.1097126], [89.03534698, 22.10959053], [89.03553009, 22.10929489], [89.03556061, 22.1089077], [89.03556061, 22.10848045], [89.03555298, 22.10804176], [89.03547668, 22.10760307], [89.03531647, 22.10717392], [89.03527832, 22.10673141], [89.03524017, 22.10629082], [89.03509521, 22.10591507], [89.03501129, 22.10553169], [89.03500366, 22.10512733], [89.0349884, 22.10469246], [89.03495789, 22.10422325], [89.034729, 22.10377121], [89.03447723, 22.10327911], [89.03425598, 22.10274124], [89.03410339, 22.10217094], [89.03388214, 22.1016407], [89.03366089, 22.10117149], [89.03361511, 22.10062981], [89.03356934, 22.10006905], [89.03340149, 22.09951973], [89.03329468, 22.09890175], [89.03305817, 22.09834099], [89.03282166, 22.09777451], [89.03272247, 22.09712029], [89.03277588, 22.09694481], [89.03250122, 22.09666634], [89.03250122, 22.09612083], [89.03221893, 22.09583282], [89.03221893, 22.09555626], [89.03192902, 22.09528351], [89.03192902, 22.09500122], [89.03166962, 22.09472275], [89.03166962, 22.09444427], [89.03111267, 22.09388924], [89.03111267, 22.09333229], [89.03138733, 22.09305573], [89.03138733, 22.09277916], [89.03161621, 22.09227943], [89.03166962, 22.09178352], [89.03166962, 22.0913372], [89.03170013, 22.09092331], [89.03183746, 22.09050941], [89.03192139, 22.09004021], [89.0318985, 22.08952141], [89.03173065, 22.08900452], [89.03166962, 22.08842278], [89.03166199, 22.08778954], [89.03166962, 22.08710289], [89.03172302, 22.08638191], [89.0318985, 22.0857029], [89.03192902, 22.08503151], [89.03194427, 22.08446312], [89.03192902, 22.08401108], [89.03196716, 22.08366013], [89.03206635, 22.08337212], [89.03212738, 22.08307076], [89.03223419, 22.08272362], [89.03239441, 22.08230019], [89.03248596, 22.08176994], [89.03250122, 22.08121681], [89.03250122, 22.0807209], [89.03253174, 22.08031273], [89.03263855, 22.07999229], [89.03275299, 22.07969093], [89.03277588, 22.0793457], [89.03282166, 22.07892609], [89.03302002, 22.07846832], [89.0331192, 22.0779438], [89.03333282, 22.07749748], [89.03356171, 22.07710266], [89.03372192, 22.07670021], [89.03388214, 22.07634163], [89.03401184, 22.07599068], [89.03414154, 22.07563972], [89.03423309, 22.07526207], [89.03440094, 22.07494164], [89.03443909, 22.07455254], [89.03444672, 22.07416534], [89.0344696, 22.0737896], [89.03460693, 22.07342911], [89.03470612, 22.07299805], [89.03475952, 22.07250786], [89.03491974, 22.0720005], [89.0349884, 22.07143974], [89.03510284, 22.07090378], [89.0352478, 22.07042122], [89.03527832, 22.06996727], [89.03531647, 22.06955147], [89.03548431, 22.06920242], [89.03557587, 22.06875801], [89.03573608, 22.06828117], [89.03585815, 22.06773949], [89.03607178, 22.06720161], [89.03614044, 22.0666256], [89.03626251, 22.06611061], [89.03638458, 22.0656929], [89.03649902, 22.06531525], [89.03663635, 22.06496239], [89.03666687, 22.06453133], [89.03675079, 22.0640316], [89.03690338, 22.06352425], [89.0369873, 22.06294441], [89.03717804, 22.06244087], [89.0372467, 22.06195831], [89.03742981, 22.06155968], [89.03752899, 22.06112099], [89.0377121, 22.06065941], [89.03781891, 22.06008911], [89.03806305, 22.05956268], [89.03829193, 22.05908966], [89.03846741, 22.05862808], [89.03858948, 22.05817986], [89.03862, 22.05769348], [89.03868866, 22.05716515], [89.03884888, 22.05661964], [89.03888702, 22.0560379], [89.03887177, 22.05545807], [89.03878784, 22.05490303], [89.03864288, 22.05437469], [89.0385437, 22.0538311], [89.03822327, 22.05339241], [89.03770447, 22.05310249], [89.03704834, 22.0530529], [89.03631592, 22.0530529], [89.03555298, 22.0530529], [89.03530121, 22.05305481], [89.03478241, 22.05306244], [89.03440857, 22.05305672], [89.03404236, 22.0530529], [89.03338623, 22.05301666], [89.03283691, 22.05286217], [89.03237915, 22.05278969], [89.03192902, 22.05278015], [89.03153229, 22.05278015], [89.03111267, 22.05278015], [89.03069305, 22.05278015], [89.03026581, 22.05278015], [89.02984619, 22.05278015], [89.02947235, 22.05278015], [89.02910614, 22.05282021], [89.02879333, 22.05297279], [89.02841187, 22.05307961], [89.0280304, 22.05326271], [89.02767181, 22.05352211], [89.02752686, 22.05410957], [89.02758026, 22.05480194], [89.02783203, 22.05540276], [89.02819061, 22.05586052], [89.02851868, 22.05628967], [89.02884674, 22.05668449], [89.02910614, 22.05713081], [89.02939606, 22.05759239], [89.02967072, 22.05809212], [89.02993011, 22.05862808], [89.02996826, 22.05912209], [89.02999115, 22.05979919], [89.02980804, 22.06040001], [89.02973175, 22.06105995], [89.02968597, 22.06170273], [89.02957153, 22.0622921], [89.02947235, 22.06286049], [89.02935791, 22.06339645], [89.02922821, 22.06388283], [89.02918243, 22.06434059], [89.02915955, 22.06476021], [89.02909088, 22.06515121], [89.02896118, 22.06553078], [89.02888489, 22.06601715], [89.02880096, 22.06658363], [89.02865601, 22.06718254], [89.02855682, 22.06781197], [89.02841187, 22.06837273], [89.02835846, 22.06891441], [89.02835083, 22.06942177], [89.02838135, 22.0699234], [89.02848816, 22.07045174], [89.02857208, 22.07104492], [89.02855682, 22.0716629], [89.02848053, 22.07225037], [89.02845001, 22.07281303], [89.02855682, 22.07336235], [89.02864838, 22.07394218], [89.02877045, 22.07452583], [89.02881622, 22.07513237], [89.02893066, 22.07569313], [89.02893066, 22.07621574], [89.02883148, 22.07673073], [89.02880096, 22.07713127], [89.02863312, 22.07761192], [89.02844238, 22.07804871], [89.02828979, 22.07859993], [89.02768707, 22.07915306], [89.0270462, 22.07930946], [89.02629852, 22.07916069], [89.02572632, 22.07894516], [89.02506256, 22.07886314], [89.02443695, 22.07878494], [89.02388, 22.078825], [89.02337646, 22.07878685], [89.02292633, 22.07863235], [89.02245331, 22.07852554], [89.02198792, 22.07837105], [89.02166748, 22.0783329], [89.02138519, 22.07805824], [89.02138519, 22.07777977], [89.0223465, 22.07770348], [89.02269745, 22.07784462], [89.02323151, 22.07776451], [89.02365112, 22.07777977], [89.02436829, 22.0779171], [89.02480316, 22.07798576], [89.02552032, 22.07798576], [89.0259552, 22.07805061], [89.02659607, 22.07805061], [89.02723694, 22.07792091], [89.02760315, 22.07777977], [89.02774811, 22.07744789], [89.02774811, 22.0769825], [89.02774811, 22.07604027], [89.02740479, 22.07557297], [89.02722931, 22.07504463], [89.02702332, 22.07452202], [89.02684784, 22.07401085], [89.02681732, 22.07349968], [89.02690887, 22.0730114], [89.02693939, 22.07248878], [89.02694702, 22.07190132], [89.02726746, 22.07115936], [89.02723694, 22.07055283], [89.02694702, 22.06982231], [89.02694702, 22.0690918], [89.02697754, 22.06837273], [89.02706146, 22.06770515], [89.02719116, 22.06711769], [89.02729797, 22.06658936], [89.02744293, 22.06612968], [89.0275116, 22.06567192], [89.02760315, 22.06522942], [89.02773285, 22.06480026], [89.02778625, 22.06432915], [89.02784729, 22.06382179], [89.02799225, 22.0633297], [89.02815247, 22.0630455], [89.02836609, 22.06264305], [89.02851105, 22.06224442], [89.02872467, 22.06184387], [89.02879333, 22.06150627], [89.02879333, 22.06097221], [89.02893829, 22.06050301], [89.02893829, 22.05956268], [89.02879333, 22.05916214], [89.02864838, 22.0588932], [89.02840424, 22.05866432], [89.0282135, 22.05809593], [89.02793121, 22.05755043], [89.02755737, 22.05702019], [89.0271759, 22.05643272], [89.02676392, 22.05589867], [89.02642059, 22.05529213], [89.02619934, 22.05464935], [89.02619171, 22.05399132], [89.02629089, 22.05336189], [89.02604675, 22.05293274], [89.0255661, 22.05265999], [89.02471161, 22.05273247], [89.02438354, 22.0527153], [89.02429199, 22.05271149], [89.02387238, 22.05271149], [89.02311707, 22.05257225], [89.02241516, 22.05245018], [89.02177429, 22.052248], [89.02111053, 22.05206108], [89.02056122, 22.05189514], [89.02011108, 22.05167961], [89.01970673, 22.05150986], [89.01931763, 22.05142021], [89.01892853, 22.05143166], [89.01854706, 22.05153084], [89.01820374, 22.05163002], [89.01789093, 22.05169487], [89.01763916, 22.05181313], [89.01741028, 22.05197716], [89.01721191, 22.05220413], [89.01700592, 22.05252457], [89.01687622, 22.05304146], [89.01673889, 22.05365944], [89.01669312, 22.05433083], [89.01673126, 22.05499077], [89.01687622, 22.0555706], [89.01695251, 22.05611229], [89.01699829, 22.05656242], [89.01713562, 22.05688667], [89.01725006, 22.05722237], [89.01738739, 22.05751991], [89.01750183, 22.05784798], [89.01761627, 22.05816078], [89.01774597, 22.05846977], [89.01781464, 22.05882072], [89.01792908, 22.05917168], [89.01802826, 22.05955315], [89.01805878, 22.05997276], [89.01805115, 22.0604229], [89.01802063, 22.06085777], [89.01790619, 22.06126213], [89.01779175, 22.06160545], [89.01769257, 22.06189156], [89.01755524, 22.06212807], [89.01742554, 22.06239128], [89.01724243, 22.06261253], [89.01700592, 22.06284142], [89.01679993, 22.06310081], [89.01657867, 22.06340218], [89.01628876, 22.06367493], [89.01590729, 22.06388283], [89.01552582, 22.06405258], [89.01526642, 22.06414223], [89.01519775, 22.06419945], [89.01499939, 22.06436729], [89.01472473, 22.06444359], [89.01429749, 22.06436729], [89.01418304, 22.06417274], [89.01389313, 22.06389046], [89.01364136, 22.06363106], [89.0133667, 22.0633049], [89.01304626, 22.06292152], [89.01265717, 22.06250191], [89.01226044, 22.06208229], [89.01190948, 22.06168175], [89.01161194, 22.06131935], [89.01138306, 22.06097984], [89.01119232, 22.06065941], [89.01106262, 22.06028175], [89.0109024, 22.05994225], [89.01081848, 22.05956459], [89.0107193, 22.05921364], [89.01059723, 22.05887794], [89.01049805, 22.05848122], [89.01035309, 22.05804062], [89.01023102, 22.05753708], [89.01008606, 22.0570507], [89.00998688, 22.0565815], [89.0098877, 22.05618286], [89.00977325, 22.05584145], [89.00970459, 22.05550957], [89.00961304, 22.05519295], [89.00948334, 22.05488014], [89.00933838, 22.05453491], [89.00915527, 22.05419731], [89.00895691, 22.05384254], [89.00879669, 22.05339241], [89.00860596, 22.05297279], [89.00836182, 22.05262184], [89.00799561, 22.05247116], [89.00762939, 22.05246162], [89.00731659, 22.05264091], [89.00710297, 22.05291939], [89.00691223, 22.05325127], [89.0067215, 22.0535717], [89.00654602, 22.05389977], [89.0063858, 22.05420876], [89.00621796, 22.05449295], [89.00602722, 22.05477905], [89.00579071, 22.05510139], [89.00556183, 22.05553818], [89.00530243, 22.05605125], [89.00498962, 22.05656242], [89.0046463, 22.05701447], [89.00437164, 22.05741119], [89.00418091, 22.05784035], [89.00393677, 22.05827141], [89.00363922, 22.0586853], [89.00331116, 22.05911446], [89.0029068, 22.05944443], [89.00248718, 22.05973244], [89.00209045, 22.05999947], [89.00170898, 22.06026459], [89.00106812, 22.06023598], [89.00070953, 22.0600338], [89.00056458, 22.05972099], [89.00026703, 22.05944252], [89.0, 22.05916405], [88.99961853, 22.05894279], [88.99919891, 22.0588398], [88.9987793, 22.05859947], [88.99835968, 22.05830193], [88.99797058, 22.05797005], [88.99758148, 22.05766106], [88.99707794, 22.0574398], [88.99658203, 22.05721283], [88.99608612, 22.05696297], [88.99562073, 22.05673027], [88.99520111, 22.05650711], [88.99474335, 22.0563488], [88.99424744, 22.05618286], [88.99365234, 22.05611992], [88.99301147, 22.05610275], [88.99250031, 22.05611229], [88.99238586, 22.05611229], [88.99111176, 22.05611229], [88.9908371, 22.05583191], [88.99028015, 22.05583191], [88.98988342, 22.05602837], [88.98949432, 22.05613518], [88.98913574, 22.05627632], [88.98878479, 22.05640221], [88.98844147, 22.05654335], [88.98806763, 22.05666351], [88.9876709, 22.05677986], [88.98722839, 22.05690193], [88.98674774, 22.05694771], [88.98625946, 22.05699158], [88.98578644, 22.0571003], [88.98529053, 22.05698204], [88.98483276, 22.0568409], [88.98447418, 22.05666733], [88.98419952, 22.05647087], [88.98400879, 22.05620766], [88.98387146, 22.05585289], [88.98369598, 22.05545807], [88.98358154, 22.05500031], [88.98345184, 22.0545311], [88.98355865, 22.05406761], [88.98361206, 22.05361176], [88.98365784, 22.05318832], [88.9838028, 22.05284309], [88.98387909, 22.05250168], [88.98396301, 22.05212975], [88.98410034, 22.05178261], [88.98421478, 22.05137634], [88.98439789, 22.05099106], [88.98449707, 22.05051994], [88.98465729, 22.0500679], [88.98470306, 22.04950142], [88.98468781, 22.04886818], [88.98462677, 22.04820061], [88.98464966, 22.04757881], [88.98455048, 22.04705048], [88.98445892, 22.04654121], [88.98438263, 22.04609108], [88.98417664, 22.04580498], [88.98394012, 22.04554367], [88.98371124, 22.04527855], [88.98351288, 22.04500008], [88.9833374, 22.0447464], [88.98314667, 22.0444622], [88.98288727, 22.04416275], [88.9825058, 22.04383278], [88.98204803, 22.04344368], [88.98155212, 22.04302979], [88.98105621, 22.04254913], [88.9805603, 22.04208374], [88.98007202, 22.04161644], [88.97962189, 22.04113388], [88.97918701, 22.04066277], [88.97881317, 22.04021263], [88.97840881, 22.03988075], [88.9779129, 22.03992271], [88.97741699, 22.04022026], [88.97689056, 22.04052162], [88.97634888, 22.04079056], [88.97576904, 22.04104042], [88.97512054, 22.04125023], [88.97442627, 22.04144859], [88.97380829, 22.04175186], [88.97319794, 22.04206276], [88.97257996, 22.04232979], [88.97207642, 22.04265785], [88.97161865, 22.04304123], [88.971138, 22.04341316], [88.97062683, 22.04379082], [88.97003937, 22.04413033], [88.96940613, 22.04448318], [88.96885681, 22.04495049], [88.9683075, 22.04542923], [88.96775055, 22.04587173], [88.96721649, 22.046381], [88.96666718, 22.0468502], [88.96613312, 22.04731178], [88.96556091, 22.04775047], [88.96496582, 22.04811478], [88.96443939, 22.0485096], [88.96395111, 22.04889107], [88.96350861, 22.04927444], [88.96311951, 22.04967499], [88.96277618, 22.05013084], [88.96243286, 22.05063057], [88.96214294, 22.05117226], [88.9620285, 22.05182266], [88.9622345, 22.05246162], [88.962677, 22.05294418], [88.9631958, 22.05331421], [88.96372223, 22.05359077], [88.96424103, 22.05385017], [88.96469879, 22.05404282], [88.96511078, 22.05428123], [88.96539307, 22.05460167], [88.96560669, 22.05505943], [88.9658432, 22.05550194], [88.96604156, 22.05597115], [88.96599579, 22.05648613], [88.96582794, 22.05699348], [88.96559143, 22.05745316], [88.96531677, 22.05785942], [88.96502686, 22.05828285], [88.9646759, 22.05859947], [88.96430206, 22.05888176], [88.96393585, 22.05912209], [88.96356964, 22.05933189], [88.96318817, 22.05950546], [88.96284485, 22.0597744], [88.96253967, 22.06011391], [88.96235657, 22.06048012], [88.96248627, 22.06081963], [88.9628067, 22.06113243], [88.96324158, 22.06139946], [88.96370697, 22.06168175], [88.96414948, 22.06196785], [88.96460724, 22.06223488], [88.965065, 22.06250191], [88.96554565, 22.06276512], [88.96602631, 22.06301117], [88.96643066, 22.06336021], [88.96692657, 22.06361771], [88.96743774, 22.06389046], [88.96791077, 22.06412125], [88.96833038, 22.06417274], [88.96916962, 22.06500053], [88.96922302, 22.06515121], [88.96965027, 22.06540108], [88.97003937, 22.0657177], [88.9704361, 22.06601143], [88.97080231, 22.06636238], [88.97116852, 22.06671906], [88.9715271, 22.06708527], [88.97187805, 22.06742287], [88.97220612, 22.06773186], [88.97251892, 22.06802177], [88.97288513, 22.06830978], [88.97332764, 22.06862068], [88.97379303, 22.06907082], [88.97428131, 22.06957817], [88.9747467, 22.07017136], [88.97519684, 22.07076073], [88.97557831, 22.07139015], [88.97595215, 22.07197571], [88.97638702, 22.07246208], [88.97686005, 22.07283211], [88.97717285, 22.07325172], [88.97743988, 22.07360268], [88.97753906, 22.07402992], [88.97768402, 22.07435989], [88.9777832, 22.07467079], [88.97789001, 22.07496262], [88.97805023, 22.07521248], [88.97821808, 22.0754528], [88.97834778, 22.07574272], [88.97852325, 22.07600975], [88.97868347, 22.07634735], [88.97889709, 22.07669258], [88.97912598, 22.07714272], [88.97933197, 22.07766342], [88.97955322, 22.07814789], [88.97982025, 22.07856941], [88.98011017, 22.07893944], [88.98036957, 22.07928276], [88.98054504, 22.07967949], [88.98066711, 22.08009148], [88.9807663, 22.08052254], [88.98081207, 22.08095932], [88.98087311, 22.08142281], [88.98101807, 22.08188057], [88.98110962, 22.08236122], [88.98118591, 22.08284378], [88.98134613, 22.08329201], [88.98142242, 22.08374977], [88.98151398, 22.08414078], [88.98164368, 22.08447456], [88.98171234, 22.0848217], [88.98187256, 22.08512115], [88.98195648, 22.08549309], [88.98208618, 22.08586311], [88.98220062, 22.08625984], [88.98227692, 22.0866909], [88.98245239, 22.08712578], [88.98249817, 22.08763313], [88.98254395, 22.08817673], [88.98277283, 22.08868217], [88.98296356, 22.08922005], [88.98308563, 22.08975029], [88.98324585, 22.09020042], [88.98326111, 22.09069824], [88.98330688, 22.09117317], [88.9833374, 22.09161949], [88.98336792, 22.09206963], [88.98345947, 22.0925045], [88.9835434, 22.09294319], [88.9835968, 22.09339523], [88.98365784, 22.09383965], [88.98384094, 22.09424019], [88.98388672, 22.09468269], [88.98389435, 22.09514236], [88.98391724, 22.09559441], [88.98403931, 22.09598351], [88.98416901, 22.09633446], [88.98430634, 22.09667587], [88.98445129, 22.09702492], [88.98460388, 22.09739494], [88.98474884, 22.09778595], [88.98497009, 22.09814262], [88.98512268, 22.09860039], [88.98529053, 22.09909248], [88.98549652, 22.09959221], [88.98561859, 22.10015297], [88.9858017, 22.10066605], [88.98593903, 22.1012001], [88.98610687, 22.10170364]]], [[[87.98972321, 22.21750069], [87.99028015, 22.21694183], [87.99055481, 22.21694374], [87.9908371, 22.21666718], [87.99138641, 22.2166729], [87.9916687, 22.21638107], [87.99194336, 22.2163887], [87.99222565, 22.21611023], [87.99277496, 22.21611023], [87.99305725, 22.21583176], [87.99333191, 22.21583366], [87.9936142, 22.21555519], [87.99388885, 22.21556282], [87.99500275, 22.21445274], [87.9952774, 22.21445274], [87.99666595, 22.21305084], [87.99666595, 22.21277809], [87.99555206, 22.21166992], [87.9952774, 22.21194458], [87.9936142, 22.21194458], [87.99333191, 22.21222305], [87.99276733, 22.21221924], [87.99223328, 22.21278191], [87.99194336, 22.21277809], [87.99111176, 22.2136116], [87.9908371, 22.2136116], [87.98943329, 22.21500778], [87.98805237, 22.21638107], [87.98805237, 22.21666718], [87.98777771, 22.21694374], [87.98779297, 22.21750069], [87.98805237, 22.21778107], [87.98805237, 22.21805573], [87.98832703, 22.21833038], [87.98832703, 22.21861076], [87.9888916, 22.21861076], [87.98923492, 22.21826744], [87.98972321, 22.21777725], [87.98972321, 22.21750069]]], [[[88.7223053, 22.09913445], [88.72229004, 22.09857368], [88.72144318, 22.09778023], [88.72090912, 22.09774208], [88.72088623, 22.09723091], [88.72039795, 22.09719849], [88.72006226, 22.09696579], [88.72002411, 22.09633446], [88.71976471, 22.09609413], [88.71926117, 22.09609413], [88.71894073, 22.09552956], [88.71846771, 22.09553909], [88.71811676, 22.09497833], [88.71731567, 22.09497833], [88.71730042, 22.0946846], [88.71646881, 22.09470177], [88.71649933, 22.09441948], [88.71595001, 22.09441948], [88.71565247, 22.09386826], [88.71510315, 22.09385109], [88.71477509, 22.09332848], [88.71372223, 22.09331894], [88.71335602, 22.09275246], [88.71287537, 22.09272766], [88.712883, 22.09246254], [88.71230316, 22.09250069], [88.71230316, 22.0921917], [88.71147919, 22.09221077], [88.71118164, 22.09166145], [88.71037292, 22.09163094], [88.71037292, 22.09135246], [88.70954132, 22.09136009], [88.7095108, 22.09108162], [88.70896912, 22.09111214], [88.70896912, 22.09082222], [88.70838928, 22.09079742], [88.70787811, 22.0905323], [88.70730591, 22.0897007], [88.70593262, 22.08969307], [88.7053833, 22.08913231], [88.7053299, 22.0885849], [88.70482635, 22.08831978], [88.70398712, 22.08830261], [88.70256805, 22.08665466], [88.70176697, 22.08664131], [88.70146179, 22.08579826], [88.7008667, 22.08527946], [88.70034027, 22.08522987], [88.6989212, 22.08359909], [88.69814301, 22.08357048], [88.69758606, 22.08272743], [88.6973114, 22.08189964], [88.69642639, 22.08109093], [88.69617462, 22.08055687], [88.69587708, 22.08028984], [88.69535828, 22.08022118], [88.69510651, 22.07967377], [88.69477844, 22.0791378], [88.69476318, 22.07859993], [88.69449615, 22.07833862], [88.6940155, 22.07831764], [88.6937027, 22.0777607], [88.69315338, 22.07774162], [88.69288635, 22.07807732], [88.69287109, 22.07916451], [88.69261169, 22.07914162], [88.69258118, 22.07996941], [88.69232178, 22.07998085], [88.69232178, 22.08053017], [88.69261169, 22.08054161], [88.69259644, 22.08111191], [88.69204712, 22.08109283], [88.69122314, 22.08196068], [88.69093323, 22.08249283], [88.6906662, 22.08304024], [88.6906662, 22.08414268], [88.69149017, 22.08414268], [88.69149017, 22.08498192], [88.69203186, 22.08551979], [88.69315338, 22.08552933], [88.69371796, 22.08664131], [88.69425201, 22.08666611], [88.69483948, 22.08747292], [88.69589996, 22.08747292], [88.6964798, 22.08778191], [88.69676208, 22.08830452], [88.69735718, 22.08856964], [88.69784546, 22.08885384], [88.69843292, 22.08885384], [88.69876099, 22.08944511], [88.69952393, 22.08941841], [88.70008087, 22.09026146], [88.70121765, 22.09026146], [88.70123291, 22.09051514], [88.70175171, 22.09053993], [88.70288849, 22.09190941], [88.70396423, 22.09192467], [88.70445251, 22.09275627], [88.7053833, 22.09275246], [88.70539093, 22.09304237], [88.70617676, 22.09303856], [88.70677948, 22.09357262], [88.70729828, 22.09358788], [88.70789337, 22.09440041], [88.70845032, 22.09445763], [88.70874023, 22.0949955], [88.7097702, 22.09497261], [88.71037292, 22.09581184], [88.71142578, 22.09581184], [88.7120285, 22.09667015], [88.71313477, 22.09667015], [88.71340942, 22.09720421], [88.71395874, 22.09719086], [88.71425629, 22.09775162], [88.71478271, 22.09777451], [88.71482086, 22.09803963], [88.71565247, 22.09805107], [88.71618652, 22.0982914], [88.71620941, 22.09860039], [88.71729279, 22.09857941], [88.71729279, 22.09886742], [88.71786499, 22.09889412], [88.71816254, 22.09940147], [88.71871185, 22.0994339], [88.71871185, 22.09970284], [88.71981812, 22.09971046], [88.72012329, 22.10025024], [88.72122192, 22.1002903], [88.7217865, 22.10055542], [88.72183228, 22.10082436], [88.72231293, 22.10084915], [88.7223053, 22.10108185], [88.7231369, 22.10110664], [88.7231369, 22.09972763], [88.7223053, 22.09913445]]], [[[88.81790161, 22.12302971], [88.81819916, 22.12293434], [88.81846619, 22.12294197], [88.81878662, 22.12303925], [88.81918335, 22.12306023], [88.81964874, 22.12306023], [88.82022858, 22.12306023], [88.8208313, 22.12306023], [88.82142639, 22.12306023], [88.82198334, 22.12306023], [88.8224411, 22.12308311], [88.82280731, 22.12320328], [88.82308197, 22.12331009], [88.82341766, 22.12333107], [88.82382965, 22.12335014], [88.82427216, 22.12344551], [88.82474518, 22.12358284], [88.82527161, 22.12362671], [88.82578278, 22.12371254], [88.82623291, 22.12386131], [88.82668304, 22.12392616], [88.82704926, 22.12409019], [88.82746124, 22.12416458], [88.82788849, 22.12420082], [88.82827759, 22.12437248], [88.82873535, 22.12444878], [88.82926941, 22.12455177], [88.82990265, 22.12470245], [88.83061218, 22.1247139], [88.83135223, 22.12461281], [88.83201599, 22.1244297], [88.83261108, 22.12421227], [88.83319855, 22.12416649], [88.83374786, 22.12412071], [88.83422852, 22.12392807], [88.83473206, 22.12388039], [88.83518219, 22.12381363], [88.83554077, 22.12364006], [88.8359375, 22.12350273], [88.83638, 22.12336159], [88.8368988, 22.12330055], [88.83743286, 22.12314606], [88.83805847, 22.12306023], [88.83867645, 22.12295914], [88.83924103, 22.12277031], [88.8397522, 22.12254143], [88.84033966, 22.12245369], [88.84088135, 22.12222862], [88.84142303, 22.12201118], [88.84195709, 22.12181473], [88.84250641, 22.12164116], [88.84295654, 22.12136269], [88.84335327, 22.12102318], [88.84375, 22.12070274], [88.84417725, 22.12040138], [88.84464264, 22.12009239], [88.84519196, 22.11980057], [88.84572601, 22.11942101], [88.84617615, 22.11890984], [88.84660339, 22.11838341], [88.84693909, 22.11782455], [88.84718323, 22.11725044], [88.84723663, 22.11661911], [88.84732819, 22.11602211], [88.84747314, 22.11545753], [88.84751892, 22.11488152], [88.84764099, 22.11430168], [88.84776306, 22.11366081], [88.84777832, 22.11296654], [88.84780884, 22.11225319], [88.84797668, 22.11153984], [88.84804535, 22.11082268], [88.84805298, 22.11011314], [88.84806061, 22.10943031], [88.84809113, 22.10880089], [88.84825134, 22.10824966], [88.84832001, 22.10768318], [88.8483429, 22.10711098], [88.84838104, 22.10656166], [88.84857178, 22.10609245], [88.84864044, 22.1056118], [88.84880066, 22.1052227], [88.84888458, 22.10485649], [88.84896851, 22.1045208], [88.84912872, 22.10425949], [88.84924316, 22.10397148], [88.84942627, 22.10372734], [88.84960938, 22.10344124], [88.849823, 22.10311317], [88.85012817, 22.1027813], [88.85050201, 22.10242271], [88.85089111, 22.1020031], [88.85131073, 22.10159683], [88.85167694, 22.10113716], [88.85206604, 22.1007328], [88.85250092, 22.10041237], [88.8529129, 22.10013008], [88.85323334, 22.09980965], [88.85350037, 22.09946442], [88.85382843, 22.099123], [88.85419464, 22.09873962], [88.85462952, 22.09834099], [88.85513306, 22.09793282], [88.85569, 22.09750938], [88.85624695, 22.09708214], [88.85678101, 22.096632], [88.85722351, 22.09612083], [88.85769653, 22.09564018], [88.85817719, 22.09517097], [88.85871124, 22.0947628], [88.85927582, 22.09440041], [88.85980225, 22.09397316], [88.86038971, 22.09360313], [88.86096191, 22.09321022], [88.86152649, 22.09278107], [88.86209106, 22.09236145], [88.8626709, 22.09196281], [88.86326599, 22.09158134], [88.86377716, 22.09114456], [88.86433411, 22.09077072], [88.8647995, 22.09035301], [88.86531067, 22.08999062], [88.86582184, 22.08962631], [88.86633301, 22.08924294], [88.86688995, 22.08887672], [88.86736298, 22.08844948], [88.8677063, 22.08795357], [88.86788177, 22.08741951], [88.86802673, 22.0869503], [88.86805725, 22.08645058], [88.86805725, 22.0859623], [88.86802673, 22.0854702], [88.86794281, 22.08502007], [88.8677597, 22.0846386], [88.86749268, 22.08436012], [88.86716461, 22.08423042], [88.86666107, 22.08435059], [88.86620331, 22.08441925], [88.86577606, 22.08451462], [88.86534882, 22.08462906], [88.86490631, 22.08468056], [88.86450195, 22.08472252], [88.86417389, 22.0848217], [88.86387634, 22.08496284], [88.86351776, 22.08508873], [88.86309814, 22.0852108], [88.86260986, 22.08526802], [88.86214447, 22.08532524], [88.86170959, 22.0854435], [88.86122131, 22.08551216], [88.86071777, 22.08555794], [88.86026001, 22.08563042], [88.85986328, 22.08577538], [88.85946655, 22.08588982], [88.85907745, 22.08603287], [88.85861206, 22.08615112], [88.85813904, 22.08630562], [88.85765076, 22.08638191], [88.85715485, 22.08645439], [88.85665894, 22.08661079], [88.85609436, 22.08675957], [88.85549927, 22.08691025], [88.85488892, 22.08706284], [88.85427856, 22.08723831], [88.85367584, 22.08741951], [88.8530426, 22.08758926], [88.8523407, 22.08763313], [88.85166931, 22.08774567], [88.85103607, 22.08789444], [88.85043335, 22.08805275], [88.84986115, 22.08823586], [88.84927368, 22.08841515], [88.84860992, 22.08856964], [88.8479538, 22.08875084], [88.84726715, 22.08887482], [88.84661865, 22.08901024], [88.84591675, 22.08910751], [88.84526062, 22.0891819], [88.84464264, 22.08927917], [88.84409332, 22.0894413], [88.84355927, 22.08965111], [88.84295654, 22.08987045], [88.84233093, 22.08995247], [88.84178162, 22.09003448], [88.841362, 22.09016991], [88.84120178, 22.0904026], [88.84119415, 22.09065056], [88.84127808, 22.09090233], [88.84137726, 22.09117317], [88.84150696, 22.09140587], [88.8416214, 22.09168053], [88.84178925, 22.09196281], [88.84197998, 22.0923214], [88.84217072, 22.09272575], [88.84236908, 22.09314156], [88.8425293, 22.09360504], [88.84274292, 22.09403038], [88.84297943, 22.09443665], [88.84324646, 22.09481239], [88.84350586, 22.09522057], [88.84377289, 22.09570313], [88.84402466, 22.09626579], [88.84416962, 22.09694481], [88.84414673, 22.0971508], [88.84407806, 22.09749031], [88.8440094, 22.09775734], [88.84393311, 22.09802055], [88.84371948, 22.09809303], [88.84356689, 22.09809303], [88.84342957, 22.09796143], [88.8433609, 22.09782028], [88.84329224, 22.09755516], [88.84314728, 22.09743309], [88.84310913, 22.09685135], [88.84292603, 22.09642982], [88.84278107, 22.0959301], [88.84256744, 22.09546661], [88.84230042, 22.09502983], [88.84195709, 22.09466934], [88.84160614, 22.09427071], [88.84140778, 22.0938015], [88.84121704, 22.09332085], [88.84104156, 22.09283257], [88.84088898, 22.09223175], [88.84075165, 22.0916729], [88.84054565, 22.09124565], [88.84033203, 22.09093475], [88.84011078, 22.09071159], [88.83982849, 22.09050941], [88.83946991, 22.0904026], [88.83911896, 22.0904789], [88.83895111, 22.09079361], [88.83880615, 22.09093475], [88.83866119, 22.09113121], [88.83830261, 22.09113121], [88.83830261, 22.09086037], [88.83844757, 22.09019279], [88.83866119, 22.08992195], [88.83872986, 22.08989716], [88.83900452, 22.08979988], [88.8391571, 22.08971977], [88.83943939, 22.08966255], [88.83982086, 22.0894413], [88.84018707, 22.08923531], [88.84059906, 22.08909035], [88.84098816, 22.08894157], [88.84139252, 22.08885193], [88.84178162, 22.08872032], [88.84217072, 22.08864594], [88.84259796, 22.0886097], [88.84304047, 22.08857536], [88.84348297, 22.08847237], [88.84397125, 22.08836365], [88.84451294, 22.0882473], [88.84507751, 22.08806038], [88.84568787, 22.08787155], [88.84636688, 22.08778954], [88.84700775, 22.08772087], [88.84764862, 22.0875721], [88.8482666, 22.08749199], [88.84886169, 22.08739281], [88.8494339, 22.08726692], [88.85002136, 22.08716011], [88.85057068, 22.08699989], [88.85111237, 22.08685112], [88.85159302, 22.08660316], [88.85212708, 22.08646202], [88.85280609, 22.08630371], [88.85352325, 22.0860939], [88.85421753, 22.08596992], [88.85486603, 22.08590508], [88.85547638, 22.08586311], [88.85604858, 22.08577156], [88.85655212, 22.08564568], [88.85707092, 22.08551979], [88.85751343, 22.0853672], [88.85798645, 22.08526039], [88.85845947, 22.08514977], [88.85891724, 22.08502007], [88.85939789, 22.08489037], [88.85980225, 22.08469009], [88.86022186, 22.08445168], [88.86064911, 22.08431053], [88.86108398, 22.08432198], [88.86152649, 22.08433342], [88.86195374, 22.08423233], [88.8624115, 22.08415794], [88.86284637, 22.0840683], [88.86325836, 22.08394241], [88.86333466, 22.0839386], [88.86472321, 22.08389091], [88.86499786, 22.08361244], [88.86611176, 22.08361244], [88.86638641, 22.08333015], [88.86694336, 22.08333206], [88.86750031, 22.08277702], [88.86750031, 22.08250237], [88.86723328, 22.08222008], [88.86701202, 22.08221245], [88.86670685, 22.08209038], [88.86643982, 22.08189964], [88.86617279, 22.08167267], [88.86585236, 22.08145523], [88.86540222, 22.08131027], [88.86494446, 22.0811348], [88.86447906, 22.08099174], [88.86402893, 22.0808506], [88.86357117, 22.0807476], [88.86316681, 22.08060265], [88.86269379, 22.08051682], [88.86221313, 22.08041191], [88.86168671, 22.08031845], [88.86112976, 22.08028984], [88.86057281, 22.0802803], [88.86000061, 22.0802803], [88.85943604, 22.0802803], [88.85887146, 22.0802803], [88.85829926, 22.08028984], [88.85772705, 22.0803318], [88.85714722, 22.08040047], [88.85689545, 22.08037567], [88.85652924, 22.08034325], [88.85588074, 22.08033562], [88.85523987, 22.08038139], [88.85469055, 22.08025169], [88.85417938, 22.0800724], [88.85365295, 22.07996178], [88.85315704, 22.07983208], [88.85266876, 22.07972908], [88.85217285, 22.0796299], [88.85168457, 22.07948685], [88.85118103, 22.07936287], [88.8507309, 22.07915878], [88.85031891, 22.07891464], [88.84992981, 22.07866096], [88.84954071, 22.07842064], [88.84915924, 22.07817268], [88.84874725, 22.07790184], [88.84828186, 22.07766914], [88.84783173, 22.07731247], [88.84741211, 22.07687378], [88.8469696, 22.07642365], [88.8465271, 22.07596779], [88.84607697, 22.07552147], [88.8456192, 22.07509422], [88.84511566, 22.07473183], [88.84460449, 22.07441139], [88.8441391, 22.07410812], [88.84371948, 22.07385063], [88.84329987, 22.07362175], [88.84281158, 22.07341957], [88.84222412, 22.07328415], [88.8416214, 22.07311821], [88.84094238, 22.07304382], [88.84026337, 22.07299232], [88.83995819, 22.07297134], [88.83963776, 22.07294846], [88.83922577, 22.07294846], [88.83882904, 22.07297325], [88.83846283, 22.0730114], [88.83808899, 22.07307816], [88.8377533, 22.07324219], [88.8374176, 22.07349205], [88.83704376, 22.07378578], [88.83666992, 22.07412148], [88.83628845, 22.07447243], [88.83599854, 22.07483292], [88.83578491, 22.07514954], [88.83558655, 22.07542229], [88.83541107, 22.07570457], [88.83525848, 22.0759716], [88.83506775, 22.07620239], [88.83493042, 22.07644844], [88.83476257, 22.07669258], [88.8346405, 22.07697487], [88.83447266, 22.07722282], [88.83432007, 22.07751274], [88.83415985, 22.0778389], [88.833992, 22.07822227], [88.83392334, 22.07870293], [88.83386993, 22.07923317], [88.83378601, 22.07974052], [88.83360291, 22.08016014], [88.83335876, 22.08054161], [88.83313751, 22.08090019], [88.83299255, 22.08130074], [88.832901, 22.08175087], [88.832901, 22.08226967], [88.83277893, 22.08281708], [88.83249664, 22.08322334], [88.83220673, 22.08361244], [88.83187866, 22.08402061], [88.83146667, 22.0844326], [88.83098602, 22.08485985], [88.83055878, 22.0853157], [88.83013153, 22.08577156], [88.82965088, 22.08617973], [88.82914734, 22.0865593], [88.82862854, 22.08691025], [88.82807922, 22.08723831], [88.82762909, 22.08760262], [88.82730103, 22.08806038], [88.82699585, 22.08854485], [88.8266449, 22.08899307], [88.82626343, 22.08941841], [88.82589722, 22.0898304], [88.82558441, 22.09027863], [88.82530975, 22.09074211], [88.82493591, 22.09112167], [88.82444763, 22.09139061], [88.82393646, 22.09165001], [88.82341766, 22.09190369], [88.82291412, 22.09210014], [88.8224411, 22.0923214], [88.82212067, 22.09266281], [88.82195282, 22.09304237], [88.82182312, 22.09344292], [88.82178497, 22.09386635], [88.82184601, 22.0943203], [88.82193756, 22.09476662], [88.82206726, 22.09523201], [88.82222748, 22.09574318], [88.82227325, 22.0962429], [88.82222748, 22.09669304], [88.82219696, 22.09714127], [88.8221817, 22.09761238], [88.82216644, 22.09808159], [88.82215881, 22.0985508], [88.82215118, 22.09900284], [88.82206726, 22.09943962], [88.82206726, 22.09986305], [88.82202911, 22.10023308], [88.82189178, 22.10065269], [88.82173157, 22.10116005], [88.82157135, 22.101614], [88.82141876, 22.10190392], [88.82126617, 22.10217094], [88.82113647, 22.10247993], [88.82103729, 22.10281563], [88.82090759, 22.10315132], [88.8207016, 22.10347176], [88.82041168, 22.10381126], [88.81999207, 22.10415077], [88.81933594, 22.10429192], [88.81920624, 22.10442162], [88.81899261, 22.10442162], [88.8187561, 22.10435295], [88.81884766, 22.10408783], [88.81899261, 22.10395241], [88.81913757, 22.10368156], [88.8192749, 22.10321426], [88.81941986, 22.10294533], [88.81955719, 22.10247993], [88.81977844, 22.10209084], [88.82009125, 22.10181808], [88.82024384, 22.10143471], [88.82039642, 22.10102463], [88.82058716, 22.10067368], [88.82079315, 22.10036278], [88.82095337, 22.09998131], [88.82105255, 22.09950256], [88.82109833, 22.09893608], [88.82109833, 22.09832382], [88.82106781, 22.09771347], [88.82096863, 22.0971508], [88.82083893, 22.09655952], [88.82073975, 22.0958004], [88.8207016, 22.09503937], [88.82067108, 22.09438133], [88.82065582, 22.09392357], [88.82072449, 22.09354973], [88.82081604, 22.09318924], [88.82090759, 22.09280205], [88.82106018, 22.09241295], [88.82118225, 22.09202194], [88.82135773, 22.09174156], [88.82162476, 22.09156418], [88.82196045, 22.09138298], [88.82237244, 22.0911808], [88.82289124, 22.09098244], [88.82343292, 22.09072685], [88.82397461, 22.09041405], [88.82445526, 22.08999443], [88.82489014, 22.08953094], [88.82518005, 22.08899117], [88.82541656, 22.08844376], [88.82549286, 22.08785057], [88.82525635, 22.08728981], [88.82479095, 22.08688545], [88.8242569, 22.08654213], [88.8236618, 22.08635139], [88.82315063, 22.08612251], [88.82269287, 22.08593178], [88.82218933, 22.08580017], [88.82171631, 22.08563423], [88.82125092, 22.08552933], [88.82080078, 22.08539009], [88.82035828, 22.08524132], [88.81997681, 22.08500099], [88.8196106, 22.08475304], [88.81922913, 22.08450127], [88.81887054, 22.08422279], [88.81850433, 22.08395576], [88.81806946, 22.0837307], [88.81764221, 22.08348274], [88.8172226, 22.08320045], [88.81679535, 22.08293152], [88.81634521, 22.08271408], [88.81591034, 22.08250618], [88.81548309, 22.08231926], [88.81504059, 22.08218193], [88.81465912, 22.08200264], [88.81420135, 22.08195305], [88.81373596, 22.08194351], [88.81328583, 22.08196068], [88.81286621, 22.08204079], [88.8125, 22.08222008], [88.81207275, 22.08243752], [88.81153107, 22.08262062], [88.81092834, 22.0827961], [88.81033325, 22.08299065], [88.80967712, 22.08310127], [88.80903625, 22.08327484], [88.80840302, 22.08342171], [88.80780792, 22.08363152], [88.80726624, 22.08389091], [88.80677032, 22.08417511], [88.80633545, 22.0844841], [88.80590057, 22.08475304], [88.80551147, 22.0850811], [88.80522156, 22.08549309], [88.8049469, 22.08589745], [88.8046875, 22.08632088], [88.8044281, 22.08674049], [88.80413818, 22.08713722], [88.80384827, 22.08753014], [88.8035965, 22.08798027], [88.8033905, 22.08847046], [88.80330658, 22.08901024], [88.8032608, 22.089571], [88.80330658, 22.09010124], [88.8033371, 22.09058952], [88.8033905, 22.09101486], [88.80352783, 22.09138298], [88.8035965, 22.09183311], [88.80361938, 22.09230614], [88.80366516, 22.09279442], [88.8037796, 22.09329033], [88.80374908, 22.09383965], [88.80358887, 22.09438515], [88.80332184, 22.09490395], [88.8030014, 22.0954113], [88.80259705, 22.09588051], [88.80221558, 22.09637642], [88.80176544, 22.09682274], [88.80124664, 22.09719849], [88.80072784, 22.09756279], [88.80031586, 22.09797287], [88.80001831, 22.09840393], [88.79982758, 22.09882164], [88.79982758, 22.09922981], [88.80001068, 22.09962273], [88.80021667, 22.10000038], [88.800354, 22.1004467], [88.80053711, 22.1008625], [88.80073547, 22.10127831], [88.80096436, 22.10164452], [88.8012085, 22.10198021], [88.8013916, 22.10235023], [88.80155945, 22.10270882], [88.80164337, 22.1031208], [88.80166626, 22.10360146], [88.80166626, 22.10413551], [88.80166626, 22.1047554], [88.80166626, 22.10541344], [88.80166626, 22.10605431], [88.80163574, 22.1066227], [88.80152893, 22.10707283], [88.8013916, 22.1074295], [88.8012619, 22.1077652], [88.80105591, 22.1081028], [88.80079651, 22.10847282], [88.80046082, 22.10883141], [88.80003357, 22.10915947], [88.79959106, 22.10947609], [88.79923248, 22.10981178], [88.79899597, 22.11017036], [88.79885864, 22.11055374], [88.7986908, 22.11092949], [88.79886627, 22.11137962], [88.79912567, 22.11187744], [88.79953766, 22.11231041], [88.80000305, 22.11276054], [88.80043793, 22.11323166], [88.80081177, 22.11374092], [88.80113983, 22.11425972], [88.80149078, 22.1147213], [88.80181885, 22.11520195], [88.80197144, 22.11584854], [88.80219269, 22.11652946], [88.80226135, 22.11728859], [88.80245209, 22.11804008], [88.80253601, 22.11881065], [88.80278015, 22.11945915], [88.80304718, 22.12004471], [88.8033371, 22.12059212], [88.80361176, 22.12112999], [88.80388641, 22.12166977], [88.8041687, 22.1222229], [88.80445099, 22.12278938], [88.80475616, 22.12333107], [88.8050766, 22.12385368], [88.80545044, 22.12434006], [88.8058548, 22.1248188], [88.80635834, 22.12523079], [88.80703735, 22.12552071], [88.80778503, 22.12560844], [88.80844116, 22.12581253], [88.80908203, 22.12597084], [88.80976105, 22.12584114], [88.8104248, 22.12566376], [88.81098175, 22.12540627], [88.81151581, 22.12514305], [88.81204987, 22.12490273], [88.81257629, 22.12470245], [88.81302643, 22.12446022], [88.81348419, 22.12429428], [88.81391144, 22.12412643], [88.81429291, 22.12392807], [88.81472778, 22.12384224], [88.81512451, 22.1236515], [88.81555176, 22.1235714], [88.81590271, 22.12338066], [88.81632233, 22.12333107], [88.81674957, 22.12328148], [88.81711578, 22.12311172], [88.81752014, 22.12306023], [88.81790161, 22.12302971]]], [[[88.7085495, 22.04668808], [88.70900726, 22.04654121], [88.70944977, 22.04636955], [88.70987701, 22.04615974], [88.71037292, 22.04600906], [88.71087646, 22.04582024], [88.71140289, 22.04557037], [88.71190643, 22.04535103], [88.71239471, 22.04512215], [88.71286774, 22.04495811], [88.71328735, 22.04475021], [88.7137146, 22.04460526], [88.71414185, 22.04442978], [88.7145462, 22.04420853], [88.71499634, 22.04404068], [88.71543884, 22.04387283], [88.71585083, 22.04365921], [88.71631622, 22.04356003], [88.7167511, 22.04335785], [88.71721649, 22.04319954], [88.71766663, 22.04302979], [88.71807098, 22.04279518], [88.71849823, 22.04260826], [88.71894073, 22.0424366], [88.71938324, 22.04222107], [88.71984863, 22.04200172], [88.72038269, 22.0418396], [88.72090912, 22.04165077], [88.72145081, 22.04138947], [88.72197723, 22.04113007], [88.72252655, 22.04094124], [88.72307587, 22.04080963], [88.72355652, 22.04063034], [88.72405243, 22.04051018], [88.7244873, 22.04030609], [88.72498322, 22.04016113], [88.72551727, 22.03996086], [88.72610474, 22.03971863], [88.72675323, 22.03943825], [88.72737122, 22.0391655], [88.72795105, 22.03887749], [88.72846985, 22.03866005], [88.72897339, 22.03851128], [88.72941589, 22.03832054], [88.72982788, 22.03807259], [88.73021698, 22.03782082], [88.73058319, 22.03753281], [88.73092651, 22.03723145], [88.73130035, 22.03695869], [88.73169708, 22.03672028], [88.73210144, 22.03650093], [88.73246765, 22.03622055], [88.73277283, 22.03582764], [88.733078, 22.03532982], [88.73342133, 22.03479958], [88.73384094, 22.03429985], [88.73420715, 22.03376007], [88.73462677, 22.03327942], [88.73497009, 22.03280449], [88.73527527, 22.03235245], [88.73553467, 22.03196335], [88.73574066, 22.0316143], [88.73587799, 22.03128052], [88.73603821, 22.03101921], [88.73615265, 22.0307312], [88.73631287, 22.03045845], [88.73638916, 22.03013992], [88.73647308, 22.02980995], [88.7366333, 22.02953529], [88.736763, 22.02920914], [88.73694611, 22.02889442], [88.73699951, 22.0287838], [88.73712921, 22.02853012], [88.73725891, 22.02807999], [88.73744965, 22.02762413], [88.7375412, 22.02706718], [88.73773193, 22.02654266], [88.73787689, 22.02602959], [88.73808289, 22.02560043], [88.73828888, 22.02523804], [88.73841858, 22.02482986], [88.73860931, 22.02448082], [88.73874664, 22.02421188], [88.73877716, 22.0241394], [88.73892212, 22.02380943], [88.73907471, 22.02352715], [88.73915863, 22.02318954], [88.73921967, 22.02280426], [88.73939514, 22.02240562], [88.73950195, 22.02190018], [88.73972321, 22.02140808], [88.7399826, 22.02090073], [88.74018097, 22.0203495], [88.74025726, 22.0197506], [88.74021912, 22.01917076], [88.74002075, 22.01865959], [88.73983765, 22.01815987], [88.7397995, 22.01805687], [88.73967743, 22.01769638], [88.73944092, 22.01729965], [88.73916626, 22.01691628], [88.73887634, 22.01651192], [88.73858643, 22.01608086], [88.73826599, 22.01567459], [88.73787689, 22.01535797], [88.7372818, 22.01520157], [88.73694611, 22.01520157], [88.73652649, 22.01541138], [88.73628235, 22.01534271], [88.73603058, 22.01526833], [88.73609924, 22.01486969], [88.73610687, 22.01444244], [88.7361145, 22.01388931], [88.73536682, 22.0128212], [88.73506165, 22.01239967], [88.73474884, 22.01198006], [88.73440552, 22.01157188], [88.7339859, 22.01120949], [88.73352051, 22.01086998], [88.73301697, 22.01057243], [88.73249817, 22.01032066], [88.73195648, 22.01004982], [88.73143005, 22.00976563], [88.730896, 22.00947189], [88.73033905, 22.00921822], [88.72981262, 22.00895119], [88.72930145, 22.00863075], [88.72879028, 22.00834846], [88.72825623, 22.00814056], [88.72770691, 22.00799751], [88.72727203, 22.00778008], [88.72683716, 22.00758743], [88.72635651, 22.00747108], [88.72590637, 22.0073185], [88.72545624, 22.00716972], [88.72503662, 22.00694084], [88.72463226, 22.00666046], [88.72422791, 22.00639153], [88.72381592, 22.00613594], [88.7233963, 22.00592995], [88.72290802, 22.00582886], [88.72241211, 22.00571823], [88.72189331, 22.00554276], [88.72132874, 22.00536156], [88.72104645, 22.00530052], [88.72077942, 22.00538063], [88.72041321, 22.00559616], [88.72003174, 22.00593376], [88.71961975, 22.00635147], [88.71916199, 22.00676918], [88.71866608, 22.00716019], [88.71820831, 22.00751495], [88.71781158, 22.00787163], [88.71747589, 22.00825119], [88.71717834, 22.00858116], [88.7168808, 22.00887108], [88.71656799, 22.00915909], [88.71620178, 22.00947189], [88.71578979, 22.00986099], [88.71530914, 22.01020813], [88.71479797, 22.01043701], [88.71444702, 22.01083374], [88.71360779, 22.0102787], [88.71444702, 22.00945091], [88.7141571, 22.00917053], [88.71399689, 22.00901985], [88.71366882, 22.00890923], [88.71327209, 22.00889969], [88.71283722, 22.00889969], [88.71240234, 22.00889969], [88.71195221, 22.00883865], [88.71152496, 22.00865555], [88.71108246, 22.00857162], [88.71069336, 22.00839996], [88.71024323, 22.00833893], [88.70979309, 22.00828934], [88.7093811, 22.00809288], [88.70894623, 22.00796127], [88.70855713, 22.00778008], [88.70816803, 22.00761986], [88.70774841, 22.00749016], [88.70733643, 22.00734329], [88.70692444, 22.00719452], [88.7065506, 22.00700188], [88.70614624, 22.00690079], [88.70580292, 22.00671959], [88.70536041, 22.00667], [88.70491791, 22.00666046], [88.70450592, 22.00666046], [88.70411682, 22.00667], [88.70372772, 22.00671959], [88.70332336, 22.00691032], [88.70281219, 22.00706673], [88.7022934, 22.00733185], [88.70183563, 22.00771713], [88.70135498, 22.00805473], [88.7009201, 22.0083847], [88.70058441, 22.0087471], [88.70028687, 22.00913048], [88.69996643, 22.00946617], [88.69956207, 22.0097599], [88.69914246, 22.01012611], [88.69866943, 22.01049423], [88.69818878, 22.01089096], [88.69778442, 22.01138878], [88.6973877, 22.01189423], [88.69692993, 22.01233292], [88.69644928, 22.01272964], [88.69600677, 22.01316071], [88.69555664, 22.01358032], [88.69502258, 22.01388931], [88.69450378, 22.01416397], [88.69400787, 22.01440048], [88.69351196, 22.01455688], [88.69306183, 22.01471138], [88.69263458, 22.01486015], [88.69221497, 22.0150013], [88.69178772, 22.01514053], [88.69136047, 22.01528931], [88.69091034, 22.0154686], [88.69042206, 22.01566887], [88.68984985, 22.01586342], [88.68922424, 22.01611137], [88.68856812, 22.01634026], [88.68785858, 22.01643944], [88.68723297, 22.01663971], [88.68656921, 22.01678085], [88.6860199, 22.01697159], [88.68556976, 22.01721191], [88.68518066, 22.01741982], [88.68478394, 22.01753616], [88.68444824, 22.01773071], [88.68405151, 22.01783943], [88.68370056, 22.01803017], [88.68332672, 22.01819038], [88.68296051, 22.01837158], [88.68264008, 22.01861572], [88.68235779, 22.01888084], [88.68250275, 22.01889038], [88.68138885, 22.02000046], [88.6811142, 22.02000046], [88.6809082, 22.02020264], [88.68052673, 22.02046013], [88.6800766, 22.02074051], [88.6795578, 22.02100182], [88.67902374, 22.02127266], [88.67855072, 22.02160454], [88.67807007, 22.0218811], [88.67765045, 22.02200508], [88.67727661, 22.02218437], [88.67688751, 22.02230072], [88.67652893, 22.02248001], [88.67614746, 22.02262115], [88.67565918, 22.02279091], [88.67518616, 22.0229702], [88.67472076, 22.02309036], [88.67427063, 22.02326965], [88.67375946, 22.02332878], [88.67321014, 22.0233345], [88.67262268, 22.0233326], [88.67199707, 22.02333069], [88.6713562, 22.02336121], [88.67073059, 22.02342033], [88.67019653, 22.02336121], [88.66964722, 22.02333832], [88.6690979, 22.02333069], [88.66854095, 22.0233326], [88.66798401, 22.0233326], [88.66744995, 22.02332306], [88.66692352, 22.0232811], [88.66641998, 22.02314186], [88.6659317, 22.02280045], [88.66545105, 22.02259254], [88.66496277, 22.0226593], [88.66458893, 22.02303314], [88.66430664, 22.02340126], [88.66403198, 22.02361107], [88.66377258, 22.02376175], [88.66358185, 22.02403069], [88.66339111, 22.0243969], [88.66333771, 22.02487183], [88.66333008, 22.02538681], [88.66333008, 22.02589035], [88.66333008, 22.02639008], [88.66330719, 22.02687645], [88.66318512, 22.02737236], [88.66306305, 22.0279007], [88.66293335, 22.02844048], [88.6628418, 22.02897835], [88.66290283, 22.02952003], [88.66279602, 22.0301075], [88.66277313, 22.03067017], [88.66268158, 22.03117943], [88.66253662, 22.03162956], [88.66249847, 22.03209686], [88.6624527, 22.03252029], [88.66230011, 22.03287125], [88.6621933, 22.03323174], [88.66203308, 22.03356934], [88.66195679, 22.03400993], [88.66194153, 22.03451157], [88.66190338, 22.03503036], [88.66172791, 22.0354805], [88.66166687, 22.03596115], [88.66166687, 22.03644943], [88.66166687, 22.03692055], [88.66162872, 22.03736115], [88.66149902, 22.03775978], [88.66130829, 22.03815079], [88.66120148, 22.03855896], [88.66133881, 22.03899956], [88.66137695, 22.03952026], [88.66135406, 22.04001999], [88.66120911, 22.04046822], [88.66116333, 22.04089928], [88.66127777, 22.04132652], [88.66126251, 22.04175949], [88.66116333, 22.04221153], [88.66123199, 22.0426712], [88.66135406, 22.04310608], [88.66137695, 22.04354286], [88.66139221, 22.04400063], [88.66139221, 22.0444603], [88.66137695, 22.04495811], [88.66137695, 22.04551125], [88.66137695, 22.04609108], [88.66140747, 22.04665756], [88.66150665, 22.04718399], [88.66168213, 22.04769135], [88.66187286, 22.04824066], [88.66188812, 22.0489006], [88.66172028, 22.04957962], [88.66169739, 22.05023956], [88.66176605, 22.0508194], [88.66171265, 22.05130005], [88.66166687, 22.05174065], [88.66160583, 22.0521698], [88.66140747, 22.05256081], [88.66118622, 22.05294037], [88.66100311, 22.05331039], [88.66083527, 22.05361557], [88.66069031, 22.05389214], [88.66057587, 22.05417061], [88.66056061, 22.05453682], [88.66055298, 22.05496407], [88.66055298, 22.05545425], [88.66055298, 22.05583191], [88.66055298, 22.05611038], [88.66035461, 22.05632019], [88.66027832, 22.0564003], [88.66027832, 22.05694389], [88.65999603, 22.05722046], [88.65999603, 22.05750084], [88.65972137, 22.05778122], [88.65972137, 22.05805588], [88.65944672, 22.05833054], [88.65944672, 22.05861092], [88.6591568, 22.05889511], [88.65891266, 22.05934143], [88.65874481, 22.05984306], [88.6587677, 22.06038094], [88.65862274, 22.06084824], [88.65846252, 22.06133842], [88.65827179, 22.06187057], [88.65805054, 22.06238174], [88.65779114, 22.06286049], [88.657547, 22.06329727], [88.65726471, 22.06363487], [88.6570282, 22.06397247], [88.65686798, 22.06438065], [88.65668488, 22.06479645], [88.65654755, 22.06525993], [88.65641785, 22.06574821], [88.6563797, 22.06627083], [88.65632629, 22.06676102], [88.65616608, 22.06718063], [88.65611267, 22.06760979], [88.65608978, 22.06801987], [88.65600586, 22.06841278], [88.65586853, 22.06888962], [88.65583801, 22.06940079], [88.65583038, 22.06991959], [88.65578461, 22.07043266], [88.65563202, 22.07094955], [88.65551758, 22.07150078], [88.65532684, 22.07201576], [88.65522766, 22.07261276], [88.6550293, 22.07316017], [88.65487671, 22.07372284], [88.65471649, 22.07418823], [88.65454102, 22.07464981], [88.65444183, 22.07518005], [88.65432739, 22.07570839], [88.65416718, 22.07620239], [88.65400696, 22.07666969], [88.65384674, 22.07711601], [88.65365601, 22.0775795], [88.65352631, 22.07810783], [88.65332031, 22.07860374], [88.65307617, 22.07910156], [88.65287018, 22.07964706], [88.6526947, 22.0802002], [88.65249634, 22.0806694], [88.65228271, 22.08106995], [88.65215302, 22.08143044], [88.65195465, 22.08168411], [88.65177155, 22.08189964], [88.65156555, 22.08207512], [88.65136719, 22.0823307], [88.65119934, 22.08261108], [88.65107727, 22.08300018], [88.65094757, 22.0834198], [88.65076447, 22.08386993], [88.65054321, 22.08432961], [88.65027618, 22.08481026], [88.65003967, 22.08527946], [88.64981079, 22.08574295], [88.64958954, 22.08616638], [88.6493454, 22.08658981], [88.64897919, 22.08693123], [88.64859772, 22.08723831], [88.64822388, 22.08750725], [88.64795685, 22.08778], [88.64776611, 22.0880394], [88.64758301, 22.08826065], [88.64740753, 22.08844948], [88.6471405, 22.08880043], [88.64688873, 22.08893013], [88.64657593, 22.08915138], [88.6462326, 22.08942986], [88.64587402, 22.08971786], [88.64551544, 22.08999634], [88.64516449, 22.09028625], [88.64483643, 22.09060097], [88.64453125, 22.09096909], [88.64424133, 22.09136963], [88.64391327, 22.09173584], [88.64359283, 22.09211159], [88.64326477, 22.09246254], [88.64291382, 22.09277153], [88.6425705, 22.09305954], [88.64225769, 22.09334183], [88.64196777, 22.09362984], [88.64168549, 22.09391212], [88.64139557, 22.09420013], [88.64111328, 22.09449768], [88.64083862, 22.09481812], [88.64057159, 22.09514236], [88.64034271, 22.09546852], [88.64003754, 22.09579086], [88.63973236, 22.09613609], [88.63944244, 22.09656143], [88.63912964, 22.09704018], [88.63873291, 22.09752083], [88.63832855, 22.09799957], [88.63792419, 22.09845924], [88.63756561, 22.09884071], [88.63748169, 22.09897232], [88.6373291, 22.09922028], [88.6371994, 22.09959984], [88.63702393, 22.09989357], [88.63674927, 22.10012054], [88.6364975, 22.10037994], [88.63632965, 22.10074043], [88.63610077, 22.10108185], [88.63588715, 22.10139084], [88.63568878, 22.10170937], [88.63556671, 22.10209084], [88.63548279, 22.10252762], [88.63527679, 22.10295105], [88.63504791, 22.10341072], [88.63492584, 22.10392952], [88.63472748, 22.10436821], [88.63454437, 22.10477638], [88.63443756, 22.1052227], [88.63432312, 22.1056881], [88.63418579, 22.10621071], [88.63417053, 22.10679817], [88.63420868, 22.10744286], [88.63434601, 22.10808945], [88.63434601, 22.10874939], [88.63440704, 22.10937881], [88.63434601, 22.10998154], [88.63430023, 22.11051941], [88.63461304, 22.11089897], [88.63471222, 22.1113205], [88.63472748, 22.11181068], [88.63477325, 22.11232948], [88.63491058, 22.11283112], [88.63498688, 22.11333084], [88.63500214, 22.11386108], [88.63500214, 22.11441994], [88.63504791, 22.11499977], [88.63523865, 22.11555099], [88.63535309, 22.1161499], [88.63553619, 22.11668015], [88.63569641, 22.1172123], [88.63585663, 22.11771011], [88.63606262, 22.11813354], [88.63613892, 22.1185894], [88.63626862, 22.11898804], [88.63638306, 22.11938095], [88.63647461, 22.11977959], [88.63665009, 22.12013435], [88.63679504, 22.12051392], [88.63696289, 22.12086105], [88.63716888, 22.12120056], [88.63734436, 22.12157822], [88.63755035, 22.12198067], [88.63778687, 22.12244034], [88.63806152, 22.12293053], [88.63838959, 22.12347031], [88.63878632, 22.12401009], [88.63909912, 22.12463188], [88.63947296, 22.12519264], [88.63986969, 22.12568283], [88.6402359, 22.12619019], [88.64055634, 22.12672997], [88.64086914, 22.12725067], [88.6411972, 22.12770081], [88.64154816, 22.12806129], [88.6418457, 22.12841415], [88.64206696, 22.12882042], [88.64232635, 22.12920189], [88.64253998, 22.12958908], [88.64276886, 22.12992096], [88.64299011, 22.13020325], [88.64320374, 22.13044357], [88.64337158, 22.13069916], [88.64354706, 22.13094902], [88.64366913, 22.13125038], [88.64385986, 22.13152122], [88.64402771, 22.13182259], [88.64417267, 22.13216591], [88.64431763, 22.13250351], [88.64447784, 22.1328392], [88.6446991, 22.13316917], [88.64492035, 22.1335392], [88.64505005, 22.13400078], [88.6452713, 22.13444519], [88.64547729, 22.13492393], [88.64569092, 22.13542557], [88.64585876, 22.13593102], [88.64606476, 22.13637924], [88.64620209, 22.13684845], [88.64640045, 22.13730049], [88.64663696, 22.13774109], [88.64687347, 22.1382103], [88.6470108, 22.13877106], [88.64720917, 22.13931847], [88.64736938, 22.13986588], [88.64751434, 22.1403904], [88.64766693, 22.14087105], [88.64778137, 22.14134789], [88.64788818, 22.14176941], [88.64801788, 22.14213943], [88.64817047, 22.14245415], [88.64834595, 22.14274025], [88.64852905, 22.14304924], [88.64855194, 22.14351082], [88.64868164, 22.14393234], [88.64891815, 22.14429474], [88.64917755, 22.14467049], [88.64942932, 22.14507484], [88.64963531, 22.14551544], [88.64982605, 22.14593124], [88.65000916, 22.14630508], [88.650177, 22.14663124], [88.65018463, 22.14712524], [88.65033722, 22.1475296], [88.65054321, 22.14796066], [88.65073395, 22.14839745], [88.65086365, 22.1489048], [88.65103149, 22.14939308], [88.65113068, 22.14990807], [88.65125275, 22.15041542], [88.65140533, 22.15090561], [88.65158081, 22.15133667], [88.6516571, 22.15174675], [88.65167236, 22.15216064], [88.65172577, 22.15258026], [88.65187836, 22.15295601], [88.65193939, 22.15339088], [88.6519928, 22.15383911], [88.6521759, 22.15425491], [88.65222168, 22.15468979], [88.65221405, 22.15513992], [88.65216827, 22.15559387], [88.65210724, 22.15604973], [88.65219879, 22.15649986], [88.6522522, 22.15694809], [88.65232849, 22.15738106], [88.65234375, 22.15781975], [88.65229797, 22.15825081], [88.65232849, 22.1586895], [88.65242767, 22.15911293], [88.65246582, 22.15954971], [88.6523819, 22.1599884], [88.65232849, 22.16040039], [88.65232849, 22.16078949], [88.65232849, 22.16119194], [88.65232849, 22.16160011], [88.65245819, 22.1619606], [88.65255737, 22.16232109], [88.65267181, 22.16267967], [88.65276337, 22.16303062], [88.65286255, 22.16339111], [88.65306091, 22.16364098], [88.65333557, 22.16388893], [88.65555573, 22.16611099], [88.65583801, 22.16611099], [88.65611267, 22.16638947], [88.65638733, 22.16638947], [88.65666962, 22.16666985], [88.65805817, 22.16666412], [88.65833282, 22.1669445], [88.65860748, 22.1669445], [88.65916443, 22.16749954], [88.66000366, 22.16833305], [88.66027832, 22.16833115], [88.66139221, 22.16945076], [88.66166687, 22.16945076], [88.66221619, 22.16999817], [88.66249847, 22.16999817], [88.66361237, 22.17111206], [88.66388702, 22.17110825], [88.66416931, 22.17140007], [88.66443634, 22.17140007], [88.66583252, 22.17277908], [88.66610718, 22.17277908], [88.66832733, 22.17500114], [88.66860962, 22.17500114], [88.67028046, 22.17667007], [88.67055511, 22.17666626], [88.67610931, 22.18222237], [88.6763916, 22.18222046], [88.67778015, 22.18361092], [88.67778015, 22.18388748], [88.67861176, 22.18471909], [88.67861176, 22.18499756], [88.67944336, 22.18583298], [88.67944336, 22.18611145], [88.68083191, 22.18750191], [88.68083191, 22.18778038], [88.6811142, 22.18805504], [88.68110657, 22.18861008], [88.68166351, 22.18916702], [88.68166351, 22.18972206], [88.6827774, 22.19083023], [88.6827774, 22.19138908], [88.68333435, 22.19194412], [88.68332672, 22.19221115], [88.68360901, 22.19249916], [88.68360901, 22.19333076], [88.6838913, 22.19361115], [88.6838913, 22.19444466], [88.68416595, 22.19472122], [88.68416595, 22.19499969], [88.68444824, 22.19527626], [88.68444824, 22.19610977], [88.6847229, 22.19639015], [88.6847229, 22.19694519], [88.68499756, 22.19722176], [88.68527985, 22.19721985], [88.68548584, 22.19800186], [88.68562317, 22.1986599], [88.68554688, 22.19922066], [88.68533325, 22.19967079], [88.68505096, 22.19997025], [88.68488312, 22.20022964], [88.68486023, 22.20063782], [88.68470764, 22.20112991], [88.68447876, 22.20168495], [88.68421936, 22.20224953], [88.68414307, 22.20285034], [88.68398285, 22.2034111], [88.68386078, 22.20398521], [88.68369293, 22.20453072], [88.68356323, 22.20508003], [88.68343353, 22.20556068], [88.68356323, 22.20603561], [88.68360901, 22.20651245], [88.68367004, 22.20695305], [88.68388367, 22.20724297], [88.68415833, 22.20747375], [88.68453979, 22.2075882], [88.6849823, 22.20767975], [88.68544769, 22.2076931], [88.6858902, 22.20754051], [88.68634033, 22.20750427], [88.6867981, 22.20751953], [88.6872406, 22.20757675], [88.68768311, 22.20763206], [88.68812561, 22.20767975], [88.68856812, 22.20772171], [88.68901825, 22.20775986], [88.68946838, 22.20777512], [88.68994141, 22.20779037], [88.6904068, 22.20788193], [88.69093323, 22.20799065], [88.6914978, 22.2080555], [88.69207001, 22.20813751], [88.69262695, 22.2082653], [88.69314575, 22.20841026], [88.69332886, 22.20844841], [88.6936264, 22.20850945], [88.69412231, 22.20858955], [88.69464874, 22.20861053], [88.69519043, 22.20861244], [88.69574738, 22.20861053], [88.69629669, 22.20861053], [88.69683838, 22.208601], [88.69736481, 22.20858383], [88.69788361, 22.20859337], [88.69839478, 22.20856857], [88.69888306, 22.20837021], [88.6993866, 22.20830345], [88.69991302, 22.20823288], [88.70040894, 22.20802116], [88.70094299, 22.20779037], [88.70153046, 22.2076149], [88.7021637, 22.20744705], [88.70279694, 22.20726013], [88.70346832, 22.20717049], [88.7040863, 22.2069397], [88.7046814, 22.20666695], [88.70523071, 22.2063694], [88.70569611, 22.20603943], [88.70619965, 22.20575714], [88.70671082, 22.20551109], [88.70722198, 22.20525169], [88.70767975, 22.20487022], [88.70809937, 22.20447922], [88.70855713, 22.20420837], [88.70899963, 22.20393944], [88.7094574, 22.2036705], [88.70994568, 22.20338631], [88.71042633, 22.20308113], [88.71095276, 22.20277977], [88.71141815, 22.20249176], [88.71185303, 22.20217514], [88.71225739, 22.20182037], [88.71269989, 22.20146942], [88.71315765, 22.20114326], [88.71360779, 22.20084381], [88.71401978, 22.20057106], [88.71440125, 22.2003212], [88.71476746, 22.2000885], [88.71515656, 22.19987106], [88.71559906, 22.19969749], [88.71602631, 22.19948959], [88.7164917, 22.19932556], [88.71691895, 22.19911194], [88.71734619, 22.1988678], [88.71776581, 22.19860077], [88.71818542, 22.19833374], [88.71856689, 22.19805908], [88.71893311, 22.19779968], [88.71930695, 22.19757843], [88.71977234, 22.19743538], [88.72025299, 22.19728088], [88.72075653, 22.19721031], [88.72128296, 22.1971302], [88.72177887, 22.19697189], [88.7223053, 22.19683647], [88.72281647, 22.19664955], [88.72333527, 22.19645119], [88.72389984, 22.19632339], [88.7244339, 22.19611359], [88.72496033, 22.19590569], [88.72550201, 22.19576073], [88.72602844, 22.19561005], [88.72654724, 22.19553947], [88.72704315, 22.19544029], [88.72749329, 22.19531441], [88.72795105, 22.19524193], [88.72836304, 22.19511986], [88.7287674, 22.19499779], [88.72915649, 22.19486809], [88.72956085, 22.19475174], [88.72996521, 22.194664], [88.73032379, 22.19451523], [88.73071289, 22.19444084], [88.73109436, 22.19435883], [88.73146057, 22.19413948], [88.73189545, 22.19399071], [88.73239899, 22.19400978], [88.73290253, 22.19413185], [88.7334137, 22.19423103], [88.73387146, 22.19439125], [88.73429871, 22.19450951], [88.73465729, 22.19470024], [88.73501587, 22.19485092], [88.73539734, 22.19503975], [88.73577881, 22.19529915], [88.73616028, 22.19558716], [88.73655701, 22.19584846], [88.73696899, 22.19614029], [88.73738861, 22.19640923], [88.73783875, 22.19670105], [88.7383728, 22.19693947], [88.73898315, 22.19713974], [88.73972321, 22.19720078], [88.74047852, 22.19720078], [88.74118805, 22.19711113], [88.74180603, 22.19692993], [88.74237823, 22.19673538], [88.74294281, 22.196661], [88.74345398, 22.19659615], [88.74391174, 22.19642067], [88.74434662, 22.19630051], [88.74471283, 22.19606972], [88.74505615, 22.19584084], [88.74545288, 22.19563103], [88.7459259, 22.19556427], [88.74643707, 22.19555092], [88.74669647, 22.19556236], [88.74697113, 22.19556808], [88.74752045, 22.19555092], [88.74806976, 22.19550133], [88.74858856, 22.19532967], [88.74915314, 22.19528008], [88.74970245, 22.19526863], [88.75023651, 22.19522285], [88.75074768, 22.19511986], [88.75124359, 22.1950264], [88.75174713, 22.1950016], [88.75226593, 22.19499016], [88.75274658, 22.19493294], [88.75321198, 22.19484138], [88.75366974, 22.19471931], [88.75411224, 22.19457054], [88.75455475, 22.19439125], [88.75498199, 22.1941967], [88.75547028, 22.19405556], [88.75593567, 22.19381905], [88.75643158, 22.19359779], [88.75697327, 22.19334984], [88.75752258, 22.19310951], [88.75811005, 22.19292068], [88.75871277, 22.19276237], [88.75932312, 22.19257164], [88.75997162, 22.1925106], [88.76065063, 22.19249916], [88.7613678, 22.19250488], [88.76210022, 22.19250488], [88.76286316, 22.19250488], [88.76360321, 22.19247246], [88.76432037, 22.19234657], [88.7649765, 22.19219971], [88.76552582, 22.19196129], [88.76595306, 22.19169044], [88.76626587, 22.19139481], [88.76650238, 22.19104385], [88.76663208, 22.1906414], [88.7666626, 22.19022942], [88.76663208, 22.18985176], [88.76648712, 22.18953514], [88.76634979, 22.18917656], [88.76637268, 22.18894577], [88.76638794, 22.18880081], [88.76637268, 22.18836021], [88.76629639, 22.18786049], [88.76615143, 22.18733788], [88.76615906, 22.18679047], [88.76635742, 22.18628311], [88.76661682, 22.18581009], [88.76687622, 22.18535233], [88.76711273, 22.18489647], [88.76719666, 22.1843605], [88.76722717, 22.18379974], [88.76728058, 22.18325806], [88.76745605, 22.18279076], [88.76759338, 22.18227005], [88.76779175, 22.18176079], [88.76805115, 22.18128967], [88.76832581, 22.18083954], [88.76860046, 22.18041611], [88.76889801, 22.18001938], [88.76927948, 22.17972755], [88.76970673, 22.17948151], [88.77023315, 22.17933083], [88.77072906, 22.17913055], [88.77119446, 22.17888641], [88.77165985, 22.17863083], [88.77216339, 22.17843819], [88.77251434, 22.17837715], [88.77287292, 22.17833138], [88.77326202, 22.17827606], [88.77363586, 22.17816925], [88.77404022, 22.17805481], [88.77444458, 22.17793083], [88.77488708, 22.17781258], [88.77539825, 22.17770958], [88.77588654, 22.17749214], [88.77635193, 22.17724419], [88.77683258, 22.1770649], [88.77732849, 22.17696762], [88.77781677, 22.17691994], [88.77823639, 22.17679024], [88.77861786, 22.17654228], [88.77898407, 22.17647743], [88.77961731, 22.1764698], [88.78018951, 22.17636299], [88.78065491, 22.17614937], [88.7811203, 22.17596245], [88.78156281, 22.17578316], [88.7819519, 22.17555046], [88.78233337, 22.17529106], [88.78270721, 22.17504311], [88.78305054, 22.17464256], [88.78344727, 22.17450142], [88.78385925, 22.17436409], [88.78472137, 22.17389107], [88.78527069, 22.17361259], [88.78778076, 22.17110825], [88.78778076, 22.17083359], [88.78916931, 22.16944885], [88.78916931, 22.16861153], [88.78864288, 22.16813469], [88.78806305, 22.16777992], [88.78778076, 22.16749954], [88.78721619, 22.16722107], [88.78722382, 22.1669445], [88.78694153, 22.16666412], [88.78694153, 22.16638947], [88.78666687, 22.16611099], [88.78499603, 22.16526985], [88.78416443, 22.16500092], [88.78138733, 22.16220856], [88.78083038, 22.16194534], [88.78056335, 22.16167068], [88.77999878, 22.1613903], [88.77971649, 22.16111183], [88.77916718, 22.16083336], [88.77916718, 22.16055489], [88.77749634, 22.15888977], [88.77694702, 22.15860748], [88.77610779, 22.15777969], [88.77555847, 22.15750122], [88.77471924, 22.15666962], [88.77416992, 22.15639114], [88.77361298, 22.15583038], [88.77305603, 22.15555763], [88.77305603, 22.15528107], [88.77278137, 22.15500069], [88.77278137, 22.15472031], [88.77083588, 22.15277863], [88.77063751, 22.15244102], [88.7702713, 22.15195084], [88.76992798, 22.15158272], [88.76959229, 22.15123177], [88.76924896, 22.15089035], [88.76891327, 22.15055275], [88.76856232, 22.15020943], [88.76822662, 22.14986038], [88.76792145, 22.14948082], [88.76766968, 22.14908409], [88.76747894, 22.14866447], [88.76733398, 22.14822769], [88.76722717, 22.14777946], [88.76690674, 22.14728928], [88.76663208, 22.1467495], [88.76638794, 22.14611053], [88.76593781, 22.14609909], [88.76550293, 22.14603043], [88.76503754, 22.14599609], [88.7645874, 22.14595985], [88.76413727, 22.14593124], [88.76368713, 22.14589119], [88.763237, 22.14586067], [88.76277924, 22.14586067], [88.76226044, 22.14595985], [88.76167297, 22.14622116], [88.76120758, 22.14620972], [88.76080322, 22.14612007], [88.76039886, 22.14603806], [88.76003265, 22.14587975], [88.7596283, 22.14585114], [88.7592392, 22.1459198], [88.7588501, 22.14602089], [88.75834656, 22.14587975], [88.75784302, 22.14574051], [88.75736237, 22.14566994], [88.75689697, 22.14563179], [88.75643921, 22.14560127], [88.75596619, 22.14555931], [88.75549316, 22.14550018], [88.75496674, 22.14538956], [88.75444794, 22.14523315], [88.75392914, 22.14501953], [88.753479, 22.14473152], [88.75302124, 22.1444397], [88.75258636, 22.14414978], [88.75218964, 22.14385033], [88.75183105, 22.14352989], [88.75139618, 22.14331055], [88.75099182, 22.14306259], [88.75061035, 22.14284706], [88.75025177, 22.14271927], [88.74997711, 22.14249992], [88.74973297, 22.14222908], [88.74954987, 22.14201736], [88.74942017, 22.14186668], [88.74897766, 22.1414814], [88.74840546, 22.14119911], [88.74787903, 22.14103508], [88.74746704, 22.14079094], [88.74711609, 22.14044952], [88.74672699, 22.14006042], [88.74629974, 22.13963127], [88.74584198, 22.1391983], [88.74530792, 22.13892937], [88.74481964, 22.13870049], [88.74442291, 22.1384697], [88.74402618, 22.13827515], [88.74365997, 22.13804054], [88.74328613, 22.13777733], [88.74285126, 22.13750076], [88.74233246, 22.13722038], [88.74172211, 22.13694572], [88.74108887, 22.13667107], [88.74048615, 22.13635826], [88.74001312, 22.13598061], [88.73954773, 22.13558006], [88.73908234, 22.13521957], [88.73853302, 22.13491058], [88.73805237, 22.13454056], [88.73760223, 22.13414001], [88.73721313, 22.1337204], [88.73687744, 22.13336945], [88.73657227, 22.13309097], [88.73628235, 22.13289642], [88.73602295, 22.13268089], [88.73577118, 22.13241386], [88.73551178, 22.13210106], [88.73525238, 22.13175964], [88.7349472, 22.13142967], [88.7346344, 22.1311264], [88.73429108, 22.13083076], [88.73395538, 22.13054085], [88.73363495, 22.13022995], [88.73332977, 22.12989998], [88.73303223, 22.12953949], [88.73271942, 22.12920952], [88.7325058, 22.12899971], [88.73239136, 22.12888527], [88.73207855, 22.12854004], [88.73181915, 22.12812042], [88.73149109, 22.12777519], [88.73116302, 22.12742996], [88.73082733, 22.12706757], [88.73049927, 22.1267128], [88.73015594, 22.12636185], [88.72984314, 22.12597084], [88.72948456, 22.12565994], [88.72917175, 22.12528038], [88.72886658, 22.1248703], [88.72853851, 22.12452126], [88.72815704, 22.12425041], [88.7278595, 22.12389946], [88.7276001, 22.12354279], [88.72741699, 22.12311172], [88.72720337, 22.12271309], [88.72693634, 22.12232971], [88.72664642, 22.12190056], [88.72638702, 22.12138176], [88.72614288, 22.12080956], [88.72592926, 22.1201992], [88.72579193, 22.1195507], [88.72557068, 22.11895943], [88.72535706, 22.11837006], [88.72515869, 22.11779785], [88.7249527, 22.11721992], [88.72473145, 22.11665916], [88.72453308, 22.1160717], [88.72432709, 22.11544037], [88.72413635, 22.11483383], [88.72388458, 22.11426544], [88.72358704, 22.11374092], [88.7232666, 22.11325073], [88.72289276, 22.11283112], [88.72251129, 22.11245918], [88.72212982, 22.11214066], [88.72171783, 22.11188126], [88.72133636, 22.11160088], [88.72099304, 22.11128044], [88.72063446, 22.11092949], [88.72027588, 22.11055946], [88.71990967, 22.1102066], [88.71949768, 22.10989952], [88.71912384, 22.10955811], [88.71871948, 22.1092701], [88.7183075, 22.10892105], [88.71788788, 22.10858536], [88.71750641, 22.10820961], [88.71711731, 22.10782814], [88.71666718, 22.10753059], [88.71618652, 22.10731125], [88.7156601, 22.10716057], [88.71515656, 22.10692978], [88.7146759, 22.10663986], [88.71412659, 22.10638046], [88.71353912, 22.1061306], [88.71289825, 22.10593987], [88.71228027, 22.10568428], [88.71166229, 22.1053791], [88.71105194, 22.1050396], [88.71047974, 22.10472679], [88.70995331, 22.10444069], [88.70947266, 22.10416412], [88.7090683, 22.10388947], [88.7086792, 22.10362053], [88.70833588, 22.10336113], [88.70797729, 22.10309029], [88.7075882, 22.1028614], [88.70721436, 22.10262489], [88.70683289, 22.10240746], [88.70648193, 22.10222054], [88.70613861, 22.10206032], [88.70579529, 22.10194206], [88.70542908, 22.10181618], [88.70510864, 22.10167122], [88.70500183, 22.10167122], [88.70443726, 22.10111046], [88.70443726, 22.10056114], [88.70417786, 22.10028076], [88.70417786, 22.10000038], [88.70361328, 22.09944344], [88.70336151, 22.09916115], [88.70294189, 22.09884834], [88.70252991, 22.09848976], [88.70211029, 22.09816933], [88.70167542, 22.09794426], [88.70124817, 22.09776306], [88.70082855, 22.09760094], [88.70037079, 22.09744072], [88.69991302, 22.09721947], [88.69940948, 22.09699059], [88.69889069, 22.09677124], [88.69834137, 22.09655952], [88.69782257, 22.09628105], [88.6973114, 22.09593964], [88.6967392, 22.09566307], [88.69608307, 22.09549713], [88.69551086, 22.09525108], [88.69503021, 22.09494019], [88.69461823, 22.0946312], [88.69420624, 22.09434128], [88.69381714, 22.09402084], [88.69338989, 22.09374046], [88.69298553, 22.09340477], [88.6925354, 22.09309196], [88.69204712, 22.09277916], [88.69155884, 22.09242821], [88.69113159, 22.09197044], [88.69068909, 22.09152031], [88.69024658, 22.09110069], [88.68978119, 22.09072113], [88.68936157, 22.09032249], [88.68897247, 22.08990479], [88.68868256, 22.08944511], [88.68842316, 22.08901024], [88.68813324, 22.08862305], [88.68782043, 22.08826065], [88.6875, 22.08785057], [88.68715668, 22.08739662], [88.68676758, 22.08691978], [88.68634033, 22.08643341], [88.68585968, 22.08598709], [88.68541718, 22.08555031], [88.68506622, 22.08512115], [88.68486786, 22.0846138], [88.68486786, 22.08403969], [88.68473053, 22.08360291], [88.68453979, 22.08316994], [88.68427277, 22.08279037], [88.68393707, 22.08240128], [88.68361664, 22.08192825], [88.68332672, 22.08139038], [88.68305206, 22.08083153], [88.68283081, 22.08023071], [88.68278503, 22.07962418], [88.68280029, 22.07903862], [88.68287659, 22.07849121], [88.68280029, 22.0779705], [88.6827774, 22.07747078], [88.6827774, 22.07702637], [88.6827774, 22.07661057], [88.6827774, 22.07615089], [88.6827774, 22.07569885], [88.6827774, 22.07523155], [88.6827774, 22.07477379], [88.68278503, 22.0743103], [88.68283081, 22.07383728], [88.68300629, 22.07334518], [88.68305206, 22.07280922], [88.68306732, 22.07228088], [88.68313599, 22.07177925], [88.68328857, 22.07133102], [88.68332672, 22.07088089], [88.68334198, 22.07045937], [88.68338776, 22.0701046], [88.68347168, 22.06977654], [88.68358612, 22.0694294], [88.68366241, 22.06899071], [88.683815, 22.06851959], [88.68393707, 22.06799126], [88.68412781, 22.06744957], [88.68424988, 22.06689644], [88.68444824, 22.06638908], [88.68464661, 22.06587982], [88.68483734, 22.06536293], [88.68506622, 22.06492043], [88.68531036, 22.06451035], [88.6855545, 22.06417656], [88.68580627, 22.06385994], [88.68604279, 22.06353951], [88.68621826, 22.06316948], [88.68641663, 22.06279945], [88.68667603, 22.06250191], [88.68695068, 22.06221008], [88.68717957, 22.06188965], [88.68730164, 22.06149292], [88.68747711, 22.06112099], [88.68767548, 22.06068993], [88.68803406, 22.0602684], [88.68840027, 22.05977058], [88.68889618, 22.05939102], [88.68930817, 22.05890083], [88.68973541, 22.05845833], [88.69016266, 22.05805016], [88.69052887, 22.05766106], [88.69083405, 22.05732346], [88.69111633, 22.05705261], [88.69139862, 22.05682182], [88.6917038, 22.0565815], [88.69204712, 22.05629921], [88.69241333, 22.05596161], [88.69280243, 22.05556107], [88.69320679, 22.05513954], [88.69367218, 22.05476952], [88.69415283, 22.0544529], [88.6946106, 22.05417061], [88.69500732, 22.05388069], [88.69538879, 22.05361366], [88.69573975, 22.05335045], [88.69610596, 22.05312157], [88.69631958, 22.0529995], [88.69649506, 22.05290031], [88.69690704, 22.05268288], [88.69729614, 22.05243492], [88.69769287, 22.05219078], [88.69804382, 22.05194283], [88.69838715, 22.05170441], [88.69876099, 22.05157089], [88.69904327, 22.05130959], [88.6995163, 22.05101967], [88.69998169, 22.05072021], [88.70041656, 22.05042076], [88.70083618, 22.0501194], [88.70128632, 22.04982185], [88.70173645, 22.04948997], [88.70226288, 22.04920959], [88.70284271, 22.04896927], [88.70343781, 22.04875946], [88.70401764, 22.04847908], [88.70456696, 22.04821205], [88.70510101, 22.04795647], [88.70561981, 22.04771042], [88.70613098, 22.04749107], [88.70659637, 22.04726982], [88.7071228, 22.04714966], [88.7075882, 22.04698181], [88.70809174, 22.04687119], [88.7085495, 22.04668808]]], [[[88.72927856, 22.11362076], [88.72894287, 22.11321831], [88.72850037, 22.1132412], [88.72807312, 22.11326981], [88.72734833, 22.11354065], [88.72725677, 22.11391068], [88.72741699, 22.11438942], [88.72751617, 22.11491966], [88.72769928, 22.11548805], [88.72785187, 22.1160717], [88.72801971, 22.11664963], [88.72805786, 22.11725998], [88.72809601, 22.11786652], [88.72828674, 22.11842346], [88.72834778, 22.11898994], [88.72843933, 22.11952972], [88.72861481, 22.11999321], [88.72875977, 22.12026978], [88.7288208, 22.12038994], [88.72888947, 22.12079048], [88.72897339, 22.12116814], [88.72913361, 22.12151146], [88.72920227, 22.12188721], [88.72939301, 22.12219048], [88.72947693, 22.12257957], [88.72969055, 22.12296867], [88.72985077, 22.12344933], [88.73010254, 22.12397003], [88.73047638, 22.12445068], [88.73088837, 22.12492943], [88.73135376, 22.12536621], [88.73155975, 22.12560272], [88.73177338, 22.12584114], [88.73216248, 22.12632942], [88.73257446, 22.12680817], [88.73310852, 22.12720108], [88.73363495, 22.12752914], [88.73407745, 22.12783432], [88.73444366, 22.12818336], [88.73480988, 22.12855339], [88.73526001, 22.12883186], [88.73580933, 22.12887573], [88.73627472, 22.12877655], [88.73651123, 22.12850189], [88.73664856, 22.12819099], [88.7366333, 22.12784958], [88.7364502, 22.12752914], [88.73634338, 22.12711143], [88.73615265, 22.12667084], [88.73607635, 22.12611961], [88.73590088, 22.12560272], [88.73583984, 22.12508011], [88.73582458, 22.12464905], [88.73575592, 22.12426949], [88.7355957, 22.1239624], [88.73551941, 22.12361908], [88.73530579, 22.12335014], [88.73512268, 22.12303925], [88.73497009, 22.12270164], [88.73475647, 22.12240982], [88.73458862, 22.12208176], [88.73446655, 22.12174034], [88.73439789, 22.12138939], [88.73417664, 22.12108994], [88.73400879, 22.12081146], [88.73387146, 22.12051773], [88.73374176, 22.1202507], [88.73361206, 22.1199398], [88.73350525, 22.11963654], [88.7333374, 22.11938095], [88.73314667, 22.11912537], [88.73298645, 22.11881828], [88.7327652, 22.11855888], [88.7325058, 22.11825752], [88.73226166, 22.11787033], [88.73207092, 22.11736107], [88.73179626, 22.11681557], [88.73142242, 22.11626053], [88.73104095, 22.11565971], [88.73055267, 22.1151104], [88.73002625, 22.1146183], [88.72957611, 22.11413193], [88.72927856, 22.11362076]]], [[[88.84053802, 22.12470245], [88.83992004, 22.12475204], [88.83927155, 22.12487984], [88.83862305, 22.12500191], [88.83797455, 22.12509918], [88.83737183, 22.12523079], [88.83679199, 22.12528038], [88.83625031, 22.12528038], [88.83574677, 22.12532234], [88.83531952, 22.12548256], [88.8348465, 22.12555122], [88.8343811, 22.12561226], [88.83397675, 22.12577248], [88.83348846, 22.12584114], [88.83299255, 22.12592125], [88.83251953, 22.12606812], [88.83203125, 22.12617493], [88.8316803, 22.12637138], [88.83135986, 22.12656975], [88.83106995, 22.12672997], [88.83085632, 22.12691116], [88.83069611, 22.12708092], [88.83058929, 22.12731934], [88.83056641, 22.1276226], [88.83061981, 22.12795258], [88.83076477, 22.12829781], [88.83091736, 22.12873268], [88.83111572, 22.12917519], [88.8313446, 22.12956429], [88.83156586, 22.12991142], [88.83182526, 22.13024712], [88.83218384, 22.13054276], [88.83270264, 22.1307621], [88.83332062, 22.13083076], [88.833992, 22.13080025], [88.83457184, 22.13065147], [88.83503723, 22.13041496], [88.83544159, 22.13055992], [88.83583069, 22.13079453], [88.83628845, 22.13086128], [88.83670807, 22.13101006], [88.8371582, 22.13113022], [88.83760834, 22.1313324], [88.8381424, 22.13149071], [88.83866119, 22.13171196], [88.83921814, 22.13195229], [88.83979797, 22.13223267], [88.84039307, 22.1325016], [88.84101105, 22.13277054], [88.8416214, 22.13300133], [88.84218597, 22.13317299], [88.84261322, 22.13335228], [88.84289551, 22.13355827], [88.84317017, 22.13372231], [88.84351349, 22.13391685], [88.84391785, 22.13419151], [88.84436798, 22.13451958], [88.84477997, 22.13494492], [88.84519196, 22.13535118], [88.84553528, 22.13581657], [88.84586334, 22.1362896], [88.84617615, 22.1367321], [88.8465271, 22.13709068], [88.8469162, 22.13739586], [88.84724426, 22.13772583], [88.84758759, 22.13802147], [88.84799194, 22.13824463], [88.848526, 22.13835907], [88.84907532, 22.13855553], [88.84970856, 22.13862038], [88.85037231, 22.13872147], [88.85102844, 22.1388607], [88.85169983, 22.13889122], [88.85235596, 22.13889122], [88.85299683, 22.13889122], [88.85359192, 22.13893318], [88.85412598, 22.13911819], [88.85470581, 22.13916969], [88.85527802, 22.13922119], [88.85578156, 22.13940239], [88.85630035, 22.1394825], [88.85675812, 22.13964653], [88.85723114, 22.13976479], [88.85762787, 22.13998222], [88.85804749, 22.14018059], [88.85845947, 22.14042091], [88.85879517, 22.14074326], [88.85910797, 22.1410923], [88.85942841, 22.14138985], [88.85970306, 22.14165306], [88.85991669, 22.14188957], [88.8600769, 22.14217186], [88.86024475, 22.14244843], [88.86032104, 22.14282036], [88.86049652, 22.14320946], [88.86058044, 22.14365387], [88.86073303, 22.1440773], [88.86081696, 22.14454079], [88.86083221, 22.14503479], [88.86083221, 22.14550018], [88.86083221, 22.14596939], [88.86083221, 22.14641571], [88.86080933, 22.14684105], [88.86069489, 22.14722252], [88.86054993, 22.14759254], [88.86038208, 22.14796829], [88.86023712, 22.14838219], [88.86000061, 22.14873314], [88.85971069, 22.14906883], [88.85939789, 22.14940453], [88.85904694, 22.14970016], [88.85865784, 22.1499424], [88.85822296, 22.15012169], [88.85780334, 22.15030098], [88.85739136, 22.15054512], [88.856987, 22.15077019], [88.85659027, 22.15094185], [88.85634613, 22.15116119], [88.85617828, 22.15134239], [88.85611725, 22.15160179], [88.85610962, 22.15188789], [88.85614777, 22.15224266], [88.85630035, 22.15262032], [88.85637665, 22.15314293], [88.85643768, 22.15378189], [88.85662079, 22.15446854], [88.85662079, 22.15514565], [88.85640717, 22.1557312], [88.85621643, 22.15629005], [88.8560791, 22.15685081], [88.85582733, 22.15733337], [88.8555069, 22.1577816], [88.85508728, 22.15813255], [88.85468292, 22.15850258], [88.85424805, 22.15878105], [88.85374451, 22.15894127], [88.85329437, 22.15917397], [88.85288239, 22.1594429], [88.85249329, 22.15971184], [88.85211945, 22.15998268], [88.85173798, 22.1602211], [88.85140228, 22.16048241], [88.85109711, 22.16074753], [88.85082245, 22.16103172], [88.85051727, 22.16132355], [88.85018158, 22.16161728], [88.84979248, 22.16191292], [88.84944153, 22.16234779], [88.84909821, 22.16285324], [88.84880066, 22.16344261], [88.84858704, 22.16410255], [88.84836578, 22.16473961], [88.84827423, 22.16535568], [88.84809875, 22.16589165], [88.84806061, 22.16642952], [88.8480835, 22.16692924], [88.8482132, 22.16737747], [88.84832001, 22.16781044], [88.84841156, 22.16823006], [88.84860992, 22.16858292], [88.84884644, 22.16888809], [88.84910583, 22.16917229], [88.84938812, 22.16942024], [88.84973907, 22.16960144], [88.8501358, 22.16975021], [88.85054779, 22.16995239], [88.85105133, 22.16999817], [88.85160065, 22.17004395], [88.85215759, 22.17018509], [88.85276031, 22.17026329], [88.8533783, 22.17023087], [88.85392761, 22.17004395], [88.85449982, 22.16995811], [88.85500336, 22.16977119], [88.85558319, 22.1697216], [88.85616302, 22.16964149], [88.8567276, 22.16946793], [88.85730743, 22.16934013], [88.85782623, 22.1691494], [88.85832214, 22.16893768], [88.85888672, 22.16885185], [88.85939789, 22.16864967], [88.85987854, 22.16853714], [88.86026001, 22.16835213], [88.860672, 22.1682148], [88.8610611, 22.16805077], [88.86144257, 22.16788292], [88.86184692, 22.16776085], [88.86223602, 22.16761971], [88.86263275, 22.16750145], [88.86300659, 22.16737747], [88.86347961, 22.16730881], [88.86392212, 22.16724205], [88.86434937, 22.16722298], [88.86473083, 22.16717339], [88.86514282, 22.16699028], [88.86566162, 22.16694069], [88.86628723, 22.16694069], [88.86694336, 22.16699028], [88.86753845, 22.1671772], [88.86813354, 22.16723251], [88.86868286, 22.16731071], [88.86915588, 22.16748238], [88.86965942, 22.167593], [88.87014008, 22.1677494], [88.87064362, 22.16783333], [88.87109375, 22.16801262], [88.87161255, 22.16805077], [88.87214661, 22.16806221], [88.87269592, 22.16806221], [88.8732605, 22.16805077], [88.87594604, 22.16805077], [88.8762207, 22.1680584], [88.87648773, 22.16806221], [88.87703705, 22.16806221], [88.87760162, 22.16805077], [88.87815094, 22.16801262], [88.87863922, 22.1678257], [88.87917328, 22.16777992], [88.87970734, 22.16774178], [88.88021088, 22.16758537], [88.88072968, 22.16747284], [88.88115692, 22.16723061], [88.8815918, 22.16702271], [88.88205719, 22.16682816], [88.88253021, 22.1666317], [88.88297272, 22.16637993], [88.88339996, 22.16611099], [88.88384247, 22.16583061], [88.88431549, 22.16555977], [88.88484955, 22.16530991], [88.88545227, 22.16509056], [88.88608551, 22.16482925], [88.8866272, 22.16445351], [88.88703156, 22.16394615], [88.88745117, 22.16344261], [88.88772583, 22.16283226], [88.88803101, 22.16225052], [88.88833618, 22.16170311], [88.88864899, 22.16119385], [88.88899994, 22.16072273], [88.88936615, 22.16026115], [88.88977814, 22.15979195], [88.89022827, 22.15936089], [88.89064789, 22.1589222], [88.89105225, 22.15852165], [88.89134979, 22.15810966], [88.8916626, 22.15780067], [88.89195251, 22.15749168], [88.89222717, 22.15715981], [88.89250183, 22.15677071], [88.89277649, 22.15633011], [88.89305878, 22.15586281], [88.89332581, 22.1554203], [88.89360809, 22.15504456], [88.89386749, 22.15473366], [88.8940506, 22.15442848], [88.89420319, 22.15413094], [88.89435577, 22.15388489], [88.89453125, 22.15364265], [88.89472198, 22.15340233], [88.89491272, 22.15313148], [88.89512634, 22.15280724], [88.89544678, 22.15247154], [88.89583588, 22.15207291], [88.89628601, 22.15163231], [88.89673615, 22.15114975], [88.8972168, 22.15069008], [88.89768219, 22.15025139], [88.89813995, 22.14980125], [88.89863586, 22.14940071], [88.89909363, 22.14896393], [88.89953613, 22.14852715], [88.89994049, 22.14809227], [88.900177, 22.14756966], [88.90026855, 22.14696312], [88.90032959, 22.14633751], [88.9005127, 22.14574242], [88.90055847, 22.14503479], [88.90062714, 22.14431953], [88.90078735, 22.14363289], [88.90083313, 22.14291954], [88.90083313, 22.14225006], [88.90087128, 22.14165306], [88.90104675, 22.14114189], [88.90112305, 22.1406498], [88.90122223, 22.14017105], [88.90137482, 22.13970184], [88.90148926, 22.13922119], [88.90167999, 22.13877296], [88.90190125, 22.13834572], [88.9020462, 22.1378231], [88.9022522, 22.13734245], [88.90249634, 22.13694382], [88.90271759, 22.13657188], [88.90287018, 22.1361351], [88.90307617, 22.1356926], [88.90335846, 22.13523293], [88.90363312, 22.13469124], [88.90390015, 22.13415527], [88.90416718, 22.1336422], [88.90444183, 22.13319397], [88.9046936, 22.1327877], [88.90486908, 22.13235283], [88.90504456, 22.13191223], [88.90528107, 22.13145256], [88.90556335, 22.13094139], [88.90583038, 22.13037109], [88.90611267, 22.12979317], [88.90643311, 22.12926292], [88.90674591, 22.12882042], [88.90705872, 22.12848091], [88.90727997, 22.12812233], [88.90752411, 22.12780952], [88.90777588, 22.12751961], [88.90802002, 22.12724113], [88.90822601, 22.12696266], [88.90847015, 22.1267128], [88.90876007, 22.12651443], [88.90904999, 22.12623024], [88.90939331, 22.12589073], [88.90979004, 22.12550163], [88.91027069, 22.1251049], [88.91075134, 22.12464142], [88.91118622, 22.12410927], [88.91165924, 22.12360954], [88.91217041, 22.12313461], [88.91272736, 22.12276268], [88.91319275, 22.12235451], [88.91356659, 22.12192726], [88.91390228, 22.12153053], [88.91425323, 22.12117958], [88.91464996, 22.12087631], [88.91499329, 22.12050056], [88.91472626, 22.12056351], [88.91665649, 22.11861229], [88.91665649, 22.11832809], [88.91700745, 22.11800575], [88.91736603, 22.11763191], [88.91771698, 22.11727333], [88.91798401, 22.11687279], [88.91815948, 22.11641502], [88.91835785, 22.11597824], [88.91860962, 22.11559105], [88.9188385, 22.11518478], [88.91901398, 22.11472893], [88.91921234, 22.11427116], [88.919487, 22.1138382], [88.91979218, 22.11342049], [88.9201889, 22.1130619], [88.92060852, 22.11269951], [88.92095184, 22.11223412], [88.9213028, 22.11175728], [88.92160797, 22.11129951], [88.92179871, 22.11086082], [88.92195892, 22.11050224], [88.92212677, 22.11022758], [88.92224884, 22.10993195], [88.92241669, 22.10965157], [88.92254639, 22.10929108], [88.92274475, 22.10895348], [88.92285919, 22.10854912], [88.92302704, 22.1081295], [88.92312622, 22.10758018], [88.92331696, 22.10698128], [88.92344666, 22.10628319], [88.92357635, 22.10555077], [88.9236145, 22.1048336], [88.92357635, 22.10415649], [88.92341614, 22.10355949], [88.92334747, 22.10301018], [88.92333221, 22.10252953], [88.92328644, 22.10210228], [88.92310333, 22.10172081], [88.9228363, 22.10133171], [88.92267609, 22.10081482], [88.9227829, 22.10000229], [88.92240906, 22.09947777], [88.92201233, 22.09905052], [88.92169189, 22.09864235], [88.92140961, 22.09827232], [88.92119598, 22.09787178], [88.92102814, 22.09743309], [88.92082214, 22.09698296], [88.92060089, 22.09656715], [88.92043304, 22.09612083], [88.92024994, 22.09568977], [88.91999817, 22.09531975], [88.91971588, 22.09496117], [88.91945648, 22.09457016], [88.91921234, 22.09414101], [88.91893768, 22.09369278], [88.91860962, 22.09331131], [88.91832733, 22.09290123], [88.91805267, 22.0925312], [88.91779327, 22.09221077], [88.91756439, 22.09188652], [88.91735077, 22.09153175], [88.91703033, 22.09120178], [88.91662598, 22.0908947], [88.91617584, 22.0906086], [88.9157486, 22.09029961], [88.91527557, 22.09004593], [88.914711, 22.08995247], [88.91420746, 22.08976173], [88.91371155, 22.08963966], [88.91324615, 22.0894413], [88.91282654, 22.08923149], [88.91239166, 22.08905983], [88.91194916, 22.08887482], [88.91156769, 22.08863258], [88.91111755, 22.08847618], [88.91068268, 22.08831215], [88.91028595, 22.08809471], [88.90986633, 22.0879879], [88.90957642, 22.08779907], [88.90930176, 22.08763313], [88.90904999, 22.08748055], [88.90879059, 22.08730125], [88.90844727, 22.08719254], [88.90808868, 22.08702278], [88.90764618, 22.08708], [88.90721893, 22.08723831], [88.9068222, 22.08749962], [88.90641022, 22.08777618], [88.90595245, 22.08805466], [88.90547943, 22.08833122], [88.90499878, 22.0886097], [88.90454102, 22.08889198], [88.90406799, 22.08917046], [88.90361023, 22.0894413], [88.90312958, 22.08967018], [88.90258789, 22.08976173], [88.90207672, 22.08996582], [88.90149689, 22.09007072], [88.90091705, 22.09024239], [88.90027618, 22.09028053], [88.89959717, 22.09028053], [88.89894104, 22.09027863], [88.89831543, 22.09028816], [88.8977356, 22.09035301], [88.89723206, 22.09050941], [88.8967514, 22.09058952], [88.89644623, 22.09079552], [88.89628601, 22.09115028], [88.89639282, 22.09176064], [88.89653015, 22.09238243], [88.89668274, 22.09300232], [88.89678955, 22.09358406], [88.89672852, 22.09415436], [88.89665985, 22.09472275], [88.89659882, 22.09531212], [88.89646149, 22.09591293], [88.89627838, 22.0965786], [88.89597321, 22.09723663], [88.89551544, 22.09775162], [88.8950119, 22.09813118], [88.89448547, 22.0981369], [88.89395142, 22.09819984], [88.89343262, 22.09836769], [88.89296722, 22.09860039], [88.89256287, 22.0988102], [88.89218903, 22.0989418], [88.89189148, 22.09908295], [88.89157867, 22.09922981], [88.89124298, 22.09950066], [88.89090729, 22.09991455], [88.89066315, 22.10046387], [88.89052582, 22.10104179], [88.8904953, 22.10164452], [88.89055634, 22.1022644], [88.89068604, 22.10282516], [88.89089966, 22.10337257], [88.89113617, 22.10390091], [88.89135742, 22.10440445], [88.89155579, 22.1049099], [88.89173889, 22.10547066], [88.89190674, 22.10609245], [88.89202118, 22.10676765], [88.8921051, 22.10748482], [88.89216614, 22.10819244], [88.89217377, 22.1088562], [88.89214325, 22.10951233], [88.89208221, 22.1101017], [88.89207458, 22.11061859], [88.89215851, 22.11114311], [88.89222717, 22.11174965], [88.89228821, 22.11230278], [88.89245605, 22.11288261], [88.89273834, 22.11350822], [88.89277649, 22.11416626], [88.89277649, 22.11444855], [88.89221954, 22.11444855], [88.89194489, 22.11416626], [88.89194489, 22.11361122], [88.89183044, 22.11343193], [88.89180756, 22.11283493], [88.89170074, 22.11229515], [88.89160156, 22.11178017], [88.89149475, 22.11128807], [88.89147949, 22.11078072], [88.89148712, 22.11026192], [88.89141083, 22.10979462], [88.89134216, 22.10931206], [88.89126587, 22.10881042], [88.8911438, 22.10832787], [88.89108276, 22.10783005], [88.89103699, 22.10732079], [88.89096832, 22.10682106], [88.89086914, 22.10630226], [88.89078522, 22.10581779], [88.89066315, 22.10532951], [88.89053345, 22.10480881], [88.89038086, 22.10428047], [88.8901825, 22.10376167], [88.88993835, 22.10330009], [88.8897171, 22.10284805], [88.88954163, 22.10242271], [88.88948822, 22.10197639], [88.88951111, 22.10151863], [88.88961029, 22.10104942], [88.88968658, 22.1005497], [88.88973999, 22.10000038], [88.88988495, 22.09947205], [88.89031219, 22.09898186], [88.89087677, 22.09858513], [88.89147186, 22.09824944], [88.8920517, 22.09796143], [88.89261627, 22.09770012], [88.89321899, 22.09748268], [88.89391327, 22.09729385], [88.89444733, 22.09711266], [88.89485168, 22.09682465], [88.89517975, 22.0964222], [88.89542389, 22.09590149], [88.89552307, 22.09530067], [88.89554596, 22.09468269], [88.89554596, 22.09404373], [88.89555359, 22.09339905], [88.89553833, 22.09275246], [88.89547729, 22.09213066], [88.8952713, 22.09166145], [88.89496613, 22.09122276], [88.89454651, 22.09085274], [88.89399719, 22.09059715], [88.89332581, 22.09050179], [88.89263153, 22.09033585], [88.89188385, 22.09023285], [88.89122772, 22.08999062], [88.89060974, 22.08972359], [88.89001465, 22.08944511], [88.88944244, 22.08917046], [88.88889313, 22.08889198], [88.88835144, 22.08860207], [88.88785553, 22.08826256], [88.88742065, 22.08785629], [88.88691711, 22.08753014], [88.88639832, 22.08723831], [88.8859024, 22.0869503], [88.88538361, 22.08671188], [88.88484955, 22.08654976], [88.88439941, 22.08630371], [88.88388062, 22.08609581], [88.88335419, 22.08588982], [88.88279724, 22.08579063], [88.88225555, 22.08563042], [88.8815918, 22.08556938], [88.88130188, 22.08556175], [88.88085938, 22.08556175], [88.88025665, 22.08561134], [88.87973022, 22.08578873], [88.87921143, 22.08585167], [88.87876129, 22.08596992], [88.87835693, 22.08612251], [88.87796021, 22.08630943], [88.87747955, 22.08644485], [88.87699127, 22.08662605], [88.8764801, 22.08671188], [88.8760376, 22.08690071], [88.87554169, 22.08697701], [88.87508392, 22.08712006], [88.87460327, 22.08721352], [88.87413025, 22.08729362], [88.87366486, 22.08746147], [88.87316132, 22.08753395], [88.87271881, 22.08768272], [88.87225342, 22.08780479], [88.87185669, 22.08802986], [88.87146759, 22.08826256], [88.87107086, 22.08849144], [88.8706131, 22.08867073], [88.87019348, 22.08889961], [88.86979675, 22.08916283], [88.86936951, 22.08943367], [88.86891174, 22.08970451], [88.86844635, 22.09000397], [88.86801147, 22.09033012], [88.86763763, 22.09069824], [88.86726379, 22.09103966], [88.86679077, 22.09126091], [88.86633301, 22.09146309], [88.86591339, 22.09168053], [88.8655014, 22.09193993], [88.86503601, 22.0921917], [88.86454773, 22.09249306], [88.86399841, 22.0927906], [88.86342621, 22.09313011], [88.8629303, 22.09355927], [88.86235809, 22.09394264], [88.86183167, 22.09438133], [88.8612442, 22.09474754], [88.86071014, 22.09514046], [88.86024475, 22.09559631], [88.85986328, 22.09607124], [88.85943604, 22.09647942], [88.85900116, 22.09683609], [88.8585434, 22.09718323], [88.85806274, 22.09750175], [88.85758209, 22.09785271], [88.85714722, 22.09824944], [88.85669708, 22.09861946], [88.85632324, 22.0990696], [88.85587311, 22.09946823], [88.85542297, 22.09986305], [88.85497284, 22.10024071], [88.85452271, 22.10062218], [88.85410309, 22.10107231], [88.85366058, 22.10147858], [88.85327148, 22.10193825], [88.85289001, 22.10239601], [88.85253906, 22.10285187], [88.85222626, 22.10331154], [88.85194397, 22.10372734], [88.85166168, 22.10407448], [88.85139465, 22.10437584], [88.8511734, 22.10467339], [88.85099792, 22.10499763], [88.85083771, 22.10533142], [88.85070801, 22.10567284], [88.85054779, 22.1060009], [88.85037231, 22.10631943], [88.85024261, 22.1066761], [88.85004425, 22.10697365], [88.84999084, 22.1073513], [88.84990692, 22.10771179], [88.84976196, 22.10803032], [88.84971619, 22.10839272], [88.84971619, 22.10878944], [88.84972382, 22.10920525], [88.84971619, 22.10963249], [88.84972382, 22.11007118], [88.84971619, 22.11051369], [88.84967804, 22.11095238], [88.84953308, 22.11137962], [88.84966278, 22.11180305], [88.84971619, 22.1122303], [88.84972382, 22.11267281], [88.84972382, 22.1131115], [88.84972382, 22.113554], [88.84972382, 22.11399651], [88.84967804, 22.11442375], [88.8494873, 22.1147747], [88.84944153, 22.11515617], [88.84939575, 22.11552048], [88.84924316, 22.11580276], [88.84915161, 22.11615944], [88.84903717, 22.11651039], [88.84889984, 22.11687279], [88.84881592, 22.11725044], [88.84864044, 22.11753464], [88.848526, 22.11783791], [88.84833527, 22.11807442], [88.84810638, 22.11834145], [88.84786224, 22.11865425], [88.84763336, 22.11905289], [88.84741974, 22.11952019], [88.84719086, 22.11998177], [88.84693909, 22.12043381], [88.84667969, 22.12086487], [88.84645844, 22.12130165], [88.84617615, 22.12165451], [88.84586334, 22.12196159], [88.84552002, 22.12226295], [88.84519958, 22.12257385], [88.84485626, 22.12289238], [88.84438324, 22.12312126], [88.84391785, 22.12334633], [88.84348297, 22.12360954], [88.84304047, 22.12386131], [88.8425293, 22.12401009], [88.84204865, 22.12419319], [88.84160614, 22.12442017], [88.84108734, 22.12458229], [88.84053802, 22.12470245]]], [[[88.76145172, 22.08918571], [88.76100159, 22.08905029], [88.76056671, 22.08889198], [88.76013947, 22.08874512], [88.75972748, 22.08860207], [88.75932312, 22.08841133], [88.75887299, 22.08831406], [88.75844574, 22.08816719], [88.75807953, 22.08799171], [88.75772095, 22.08777046], [88.75736237, 22.08753014], [88.75695801, 22.08733749], [88.75656128, 22.08712006], [88.75617218, 22.08690453], [88.7558136, 22.08664894], [88.75544739, 22.08638573], [88.75508118, 22.08611107], [88.75469208, 22.0858326], [88.75429535, 22.08555794], [88.75388336, 22.08527946], [88.75344086, 22.08498955], [88.75302124, 22.08467865], [88.75263977, 22.08431053], [88.75222778, 22.08396912], [88.7518158, 22.08361244], [88.7514267, 22.08324242], [88.75110626, 22.08284378], [88.75078583, 22.08246422], [88.75047302, 22.08212471], [88.75020599, 22.08173561], [88.74989319, 22.0813961], [88.74958801, 22.08105659], [88.74935913, 22.08064079], [88.74907684, 22.08027077], [88.74878693, 22.07989311], [88.74853516, 22.07948112], [88.7482605, 22.07908821], [88.74803925, 22.07867813], [88.74780273, 22.07832527], [88.74762726, 22.07792091], [88.74745941, 22.0775013], [88.74718475, 22.07715416], [88.74692535, 22.07668877], [88.74666595, 22.07621384], [88.74637604, 22.07574272], [88.74606323, 22.07530022], [88.74568176, 22.07484245], [88.74521637, 22.07437706], [88.74474335, 22.07385063], [88.74429321, 22.07328224], [88.74390411, 22.07267952], [88.74360657, 22.07208061], [88.74338531, 22.07154083], [88.74331665, 22.07092476], [88.74318695, 22.07033157], [88.74295044, 22.06980324], [88.74256897, 22.06936836], [88.74221802, 22.06889153], [88.74192047, 22.06833267], [88.74166107, 22.0677948], [88.7414093, 22.06728935], [88.74121094, 22.06678963], [88.74095917, 22.06638336], [88.74069977, 22.06593323], [88.74053192, 22.06530952], [88.74032593, 22.06467056], [88.74028778, 22.06396866], [88.74027252, 22.06333733], [88.74028778, 22.06279182], [88.74028015, 22.06232452], [88.74028015, 22.06189919], [88.74027252, 22.06146049], [88.74021912, 22.06099129], [88.74005127, 22.06051826], [88.73995972, 22.05999184], [88.73980713, 22.05951118], [88.73973846, 22.05903625], [88.73972321, 22.05857277], [88.7396698, 22.05811119], [88.73949432, 22.05769539], [88.73940277, 22.05727005], [88.73916626, 22.05699158], [88.73882294, 22.05685234], [88.7383728, 22.05670547], [88.73781586, 22.05667305], [88.73719788, 22.05664253], [88.73655701, 22.05653954], [88.73590851, 22.05645943], [88.73536682, 22.05656815], [88.73488617, 22.05664635], [88.73448181, 22.05666351], [88.73416138, 22.05667305], [88.73306274, 22.05667305], [88.73284912, 22.05666351], [88.73239899, 22.05656242], [88.7318573, 22.05643272], [88.73129272, 22.05639076], [88.73101807, 22.05639076], [88.73043823, 22.05639076], [88.73005676, 22.05639076], [88.72968292, 22.05639076], [88.72720337, 22.05639076], [88.72679901, 22.05639076], [88.72638702, 22.05639076], [88.72593689, 22.05639076], [88.72544861, 22.05642128], [88.7249527, 22.05656242], [88.72441864, 22.05666351], [88.72387695, 22.05667305], [88.7233963, 22.05669212], [88.72294617, 22.05677986], [88.7225647, 22.0569191], [88.7221756, 22.05702591], [88.7218399, 22.05721283], [88.72146606, 22.05739021], [88.72101593, 22.0574398], [88.72054291, 22.05751228], [88.7201004, 22.05759811], [88.71961212, 22.05757523], [88.71917725, 22.05761147], [88.71875, 22.05767822], [88.71833038, 22.05772209], [88.7179184, 22.05779076], [88.71749878, 22.05787086], [88.71708679, 22.05797005], [88.71666718, 22.0580616], [88.71624756, 22.05816078], [88.7158432, 22.05825233], [88.71541595, 22.05836678], [88.71499634, 22.05846977], [88.71457672, 22.05857849], [88.7141571, 22.05870247], [88.71375275, 22.05880928], [88.71333313, 22.05895233], [88.71292114, 22.05912209], [88.71248627, 22.05934143], [88.7120285, 22.05960274], [88.71157837, 22.05992317], [88.71111298, 22.06028175], [88.71055603, 22.0605545], [88.71028137, 22.06083298], [88.7097168, 22.06110954], [88.70944214, 22.06139183], [88.70889282, 22.0616703], [88.70861053, 22.06194687], [88.70804596, 22.06221962], [88.70777893, 22.06250191], [88.70722198, 22.06278038], [88.70694733, 22.06305695], [88.70639038, 22.06333351], [88.70549774, 22.06422424], [88.70471954, 22.06500053], [88.70471954, 22.06528282], [88.70439911, 22.06606293], [88.70430756, 22.06648064], [88.70425415, 22.06690788], [88.70409393, 22.06750488], [88.70378113, 22.06780052], [88.70349884, 22.0681076], [88.70332336, 22.06851006], [88.70316315, 22.06892204], [88.70307159, 22.06936073], [88.70300293, 22.06982994], [88.70282745, 22.07030296], [88.70278168, 22.07085228], [88.70276642, 22.07142067], [88.7027359, 22.07196808], [88.70258331, 22.07245064], [88.70248413, 22.0729084], [88.70236206, 22.07334328], [88.70224762, 22.07380295], [88.70222473, 22.07432747], [88.7022171, 22.07486153], [88.70223236, 22.07539368], [88.70230865, 22.07589149], [88.70244598, 22.07641029], [88.70249176, 22.07693863], [88.70249939, 22.07745552], [88.70253754, 22.07795143], [88.70271301, 22.07839012], [88.70292664, 22.07884026], [88.70326233, 22.0792408], [88.70359802, 22.0797081], [88.70396423, 22.0802002], [88.70437622, 22.08064079], [88.70471954, 22.08109665], [88.70510101, 22.08146286], [88.70555115, 22.08172989], [88.70601654, 22.08198166], [88.70646667, 22.08229065], [88.70691681, 22.08263016], [88.70733643, 22.08300781], [88.70777893, 22.08333015], [88.70819855, 22.08364296], [88.70858765, 22.08398819], [88.70895386, 22.08436775], [88.70936584, 22.08469963], [88.70986176, 22.08495522], [88.71038818, 22.08513069], [88.71089172, 22.08535194], [88.71137238, 22.08558846], [88.71183014, 22.08584595], [88.71225739, 22.08611488], [88.71264648, 22.08638191], [88.71304321, 22.08662224], [88.71350098, 22.08674049], [88.71392059, 22.0869503], [88.71434784, 22.08712006], [88.71477509, 22.0872879], [88.71517181, 22.08751106], [88.71555328, 22.08778191], [88.71592712, 22.08804131], [88.71633911, 22.08829117], [88.7167511, 22.08859062], [88.71721649, 22.08890915], [88.71774292, 22.08928108], [88.71824646, 22.08975029], [88.71877289, 22.09025002], [88.71932983, 22.09071159], [88.71989441, 22.09115791], [88.72042847, 22.09164238], [88.72100067, 22.09211159], [88.72158051, 22.09255981], [88.72206879, 22.09303474], [88.72251129, 22.09345055], [88.72293854, 22.09378242], [88.72332764, 22.09410667], [88.72370148, 22.09443474], [88.72408295, 22.09476471], [88.72444916, 22.09513283], [88.72480774, 22.09551048], [88.72518158, 22.09584236], [88.72551727, 22.09613609], [88.72580719, 22.09641075], [88.72608185, 22.09666824], [88.72637939, 22.09692955], [88.72673798, 22.09722328], [88.72717285, 22.0975399], [88.72761536, 22.09789085], [88.72807312, 22.09822273], [88.72850037, 22.09852028], [88.72886658, 22.09885216], [88.7292099, 22.09921265], [88.72956848, 22.09955406], [88.72997284, 22.09986305], [88.73035431, 22.10020447], [88.73078918, 22.10051155], [88.73118591, 22.10083199], [88.73156738, 22.10111618], [88.73189545, 22.10140038], [88.73219299, 22.10168266], [88.73248291, 22.10199165], [88.73278046, 22.10233116], [88.73312378, 22.10268211], [88.73352051, 22.10298347], [88.73387146, 22.10332298], [88.73420715, 22.10366249], [88.73455048, 22.10400963], [88.73485565, 22.1044426], [88.73517609, 22.10489082], [88.73552704, 22.10532951], [88.73583221, 22.10584259], [88.7361145, 22.10638618], [88.73638916, 22.10694313], [88.73665619, 22.10749245], [88.73694611, 22.1079998], [88.73722076, 22.10845947], [88.73750305, 22.10889435], [88.73773956, 22.10933113], [88.73789978, 22.1098423], [88.73808289, 22.11034393], [88.73832703, 22.11079216], [88.73860168, 22.1112175], [88.73884583, 22.11161995], [88.73906708, 22.1119709], [88.73925018, 22.11228752], [88.73944092, 22.11255455], [88.73963165, 22.1128521], [88.73979187, 22.11329079], [88.74001312, 22.11373329], [88.74028015, 22.11418152], [88.74054718, 22.11460304], [88.74077606, 22.11503029], [88.74088287, 22.11555862], [88.74108887, 22.11602974], [88.74127197, 22.11657143], [88.74141693, 22.1171627], [88.74164581, 22.11774254], [88.74183655, 22.11834526], [88.74201965, 22.11894035], [88.74224854, 22.1194706], [88.74250031, 22.11996269], [88.74278259, 22.12043953], [88.74304962, 22.12090492], [88.74328613, 22.12140465], [88.74339294, 22.12201118], [88.74357605, 22.12262154], [88.74369049, 22.12322617], [88.74385071, 22.12375259], [88.74394989, 22.1242466], [88.74415588, 22.12460136], [88.74436951, 22.12492943], [88.74459076, 22.12526894], [88.74484253, 22.12561226], [88.74503326, 22.12602043], [88.7452774, 22.12644005], [88.74552155, 22.12693977], [88.74563599, 22.12754059], [88.74542999, 22.12812233], [88.74513245, 22.12854195], [88.74516296, 22.1289196], [88.74524689, 22.12931824], [88.74530792, 22.12976456], [88.74543762, 22.13017273], [88.74559021, 22.1306076], [88.74581146, 22.13100243], [88.74600983, 22.13142967], [88.7461853, 22.13189125], [88.74640656, 22.13229942], [88.74666595, 22.13278008], [88.74777985, 22.13389015], [88.74804687, 22.13389015], [88.74916077, 22.13500023], [88.74944305, 22.13500023], [88.74973297, 22.13529015], [88.75, 22.13529015], [88.75026703, 22.1355629], [88.7508316, 22.13555717], [88.75111389, 22.13583565], [88.75166321, 22.13583565], [88.7519455, 22.13611031], [88.75250244, 22.13611031], [88.7527771, 22.1363945], [88.75305176, 22.1363945], [88.75332642, 22.13667107], [88.75416565, 22.13666725], [88.75444794, 22.13694572], [88.75527954, 22.13694572], [88.7555542, 22.13722229], [88.7563858, 22.13722038], [88.75666809, 22.13750458], [88.75749969, 22.13750458], [88.75776672, 22.13778114], [88.7583313, 22.13778114], [88.75860596, 22.13805962], [88.7591629, 22.1380558], [88.7592392, 22.13813019], [88.75944519, 22.13833427], [88.76000214, 22.13833046], [88.76018524, 22.13851929], [88.76027679, 22.13861275], [88.76110077, 22.13861275], [88.76139069, 22.13889122], [88.76167297, 22.13889122], [88.76194763, 22.13916969], [88.76249695, 22.13916588], [88.76263428, 22.13930321], [88.76277924, 22.13944435], [88.76333618, 22.13944435], [88.76361084, 22.13972282], [88.7647171, 22.13972282], [88.76499939, 22.1400013], [88.76526642, 22.1400013], [88.76583099, 22.14056206], [88.76638794, 22.14055824], [88.76667023, 22.1408329], [88.76722717, 22.1408329], [88.76860046, 22.14151955], [88.76888275, 22.14162827], [88.76917267, 22.1417408], [88.76969147, 22.14196014], [88.7701416, 22.14221001], [88.77058411, 22.14239693], [88.77104187, 22.14257431], [88.77146149, 22.14283943], [88.77190399, 22.1431179], [88.77233124, 22.14344215], [88.77278137, 22.14378357], [88.77324677, 22.14415169], [88.77379608, 22.14451027], [88.77432251, 22.14494514], [88.77445984, 22.14502144], [88.77494049, 22.14528847], [88.77553558, 22.14566994], [88.77609253, 22.14612007], [88.77655792, 22.14668274], [88.7769928, 22.14725494], [88.77745056, 22.14772987], [88.77787781, 22.14816284], [88.77823639, 22.148592], [88.77857208, 22.14899254], [88.778862, 22.14941978], [88.77913666, 22.14986992], [88.77935791, 22.15041924], [88.77948761, 22.15107155], [88.77972412, 22.15166092], [88.77999878, 22.15220261], [88.78027344, 22.15270996], [88.78053284, 22.15318108], [88.78073883, 22.15364838], [88.78089905, 22.15410042], [88.78112793, 22.15451241], [88.78141022, 22.15488243], [88.7817688, 22.15524292], [88.78222656, 22.15554619], [88.78276062, 22.15583229], [88.78334808, 22.15609932], [88.78395844, 22.1563015], [88.78463745, 22.1564312], [88.78523254, 22.15666962], [88.78579712, 22.15694237], [88.78633118, 22.15722084], [88.78681183, 22.15752792], [88.7872467, 22.15786171], [88.78772736, 22.15815163], [88.78817749, 22.1584301], [88.78868103, 22.15863228], [88.78916168, 22.15889168], [88.78959656, 22.15919495], [88.79000092, 22.1595211], [88.79039764, 22.159832], [88.79078674, 22.16010094], [88.79110718, 22.16043472], [88.79141235, 22.16077042], [88.79173279, 22.16109276], [88.79203796, 22.1613903], [88.79234314, 22.16169167], [88.79257202, 22.16201973], [88.7928009, 22.16233253], [88.79305267, 22.16250038], [88.79416656, 22.16361046], [88.79416656, 22.16388893], [88.79555511, 22.16527748], [88.79582977, 22.16526985], [88.79611206, 22.16555977], [88.79694366, 22.16555405], [88.79722595, 22.16583061], [88.79722595, 22.1661129], [88.79750061, 22.16639137], [88.79750061, 22.1669445], [88.7977829, 22.16722298], [88.7977829, 22.16777992], [88.79805756, 22.16806221], [88.79805756, 22.16888809], [88.79821777, 22.16888237], [88.79840851, 22.1694088], [88.79865265, 22.16988373], [88.79897308, 22.17028236], [88.79928589, 22.17069054], [88.79959869, 22.17109108], [88.79993439, 22.17145348], [88.80026245, 22.17181969], [88.80056, 22.17223167], [88.80084991, 22.17263985], [88.80119324, 22.17300987], [88.80157471, 22.17332649], [88.80197906, 22.17361259], [88.80237579, 22.17390442], [88.80272675, 22.17423058], [88.80306244, 22.17458916], [88.80337524, 22.17494392], [88.80370331, 22.17526054], [88.804039, 22.17556381], [88.80436707, 22.17585182], [88.8046875, 22.17617035], [88.80500793, 22.17652702], [88.805336, 22.17688942], [88.80571747, 22.17724037], [88.80610657, 22.17761993], [88.80649567, 22.17801094], [88.80696106, 22.17834282], [88.80747223, 22.17863274], [88.80800629, 22.17889977], [88.80857849, 22.17917061], [88.80919647, 22.17941093], [88.80990601, 22.17949295], [88.81058502, 22.17968559], [88.81123352, 22.17968178], [88.81180573, 22.1794529], [88.81231689, 22.17916679], [88.81281281, 22.17884254], [88.81324005, 22.17842102], [88.81369019, 22.17798042], [88.81417847, 22.17758179], [88.81467438, 22.17719078], [88.81516266, 22.17679024], [88.81561279, 22.17635155], [88.81607819, 22.17592049], [88.81647491, 22.17544365], [88.81678772, 22.17493629], [88.81723022, 22.17461967], [88.81768799, 22.17439079], [88.81807709, 22.17410278], [88.818367, 22.17369652], [88.81865692, 22.17328072], [88.81902313, 22.17295456], [88.81947327, 22.1727314], [88.81989288, 22.17245483], [88.82024384, 22.17210579], [88.82055664, 22.17171288], [88.82089233, 22.17134285], [88.82125854, 22.1709919], [88.82173157, 22.17075157], [88.82218933, 22.17042732], [88.82260895, 22.17001152], [88.82305145, 22.16960144], [88.82348633, 22.1692028], [88.8239975, 22.16887856], [88.82450104, 22.16855049], [88.82501221, 22.16823387], [88.82552338, 22.16793633], [88.82601929, 22.16759872], [88.82652283, 22.16725159], [88.82705688, 22.16694069], [88.82761383, 22.16661835], [88.82807922, 22.16621208], [88.82859039, 22.16584969], [88.82910156, 22.16555214], [88.82958984, 22.16529083], [88.83006287, 22.16509056], [88.830513, 22.16497231], [88.83090973, 22.1647625], [88.83141327, 22.16471672], [88.83197784, 22.1646595], [88.83260345, 22.16451836], [88.83326721, 22.16467094], [88.833992, 22.16476059], [88.83469391, 22.16494179], [88.83535767, 22.16503906], [88.83591461, 22.16525841], [88.83637238, 22.16543007], [88.83673096, 22.1656208], [88.8370285, 22.16584206], [88.83731079, 22.16610146], [88.83761597, 22.16637993], [88.83795929, 22.16668129], [88.83827209, 22.16703224], [88.83856201, 22.16744995], [88.83889008, 22.16789055], [88.83921814, 22.16838455], [88.83956146, 22.16887665], [88.83988953, 22.1693821], [88.84004974, 22.17002106], [88.84028625, 22.17062759], [88.84050751, 22.17123985], [88.84055328, 22.17197227], [88.84056091, 22.17276192], [88.84056091, 22.17353249], [88.84055328, 22.17427254], [88.84050751, 22.17494011], [88.84030914, 22.17548943], [88.84017944, 22.17605782], [88.83999634, 22.17657661], [88.83979797, 22.17706108], [88.83969116, 22.17756271], [88.83953094, 22.17799187], [88.8394165, 22.17835045], [88.83927917, 22.17865181], [88.8391571, 22.17897224], [88.83904266, 22.17928123], [88.83889008, 22.1795826], [88.83870697, 22.17990112], [88.83854675, 22.18022919], [88.83834076, 22.18055153], [88.83815002, 22.1808815], [88.8380127, 22.18123055], [88.83779907, 22.18152046], [88.83760071, 22.18185234], [88.83737946, 22.18224907], [88.83712006, 22.18274117], [88.83674622, 22.18326569], [88.83638, 22.18388748], [88.83601379, 22.18454552], [88.83564758, 22.18518257], [88.83529663, 22.18577194], [88.83500671, 22.18631554], [88.83475494, 22.18678474], [88.8345871, 22.18720055], [88.83442688, 22.18756866], [88.8342514, 22.18789101], [88.83413696, 22.18826866], [88.83395386, 22.1885643], [88.83377075, 22.18887138], [88.83355713, 22.18918037], [88.83332062, 22.18954849], [88.83304596, 22.1899395], [88.83278656, 22.19035149], [88.83254242, 22.19075012], [88.83239746, 22.19119072], [88.83222198, 22.19154167], [88.83204651, 22.19185257], [88.83193207, 22.19215393], [88.83177185, 22.19241142], [88.83164978, 22.19270134], [88.83149719, 22.19296265], [88.83137512, 22.19324875], [88.83120728, 22.1935215], [88.83107758, 22.19387245], [88.83085632, 22.19421959], [88.83067322, 22.19466209], [88.83036804, 22.19502068], [88.83003235, 22.19540405], [88.82971191, 22.19584084], [88.82937622, 22.19627953], [88.82894897, 22.1966114], [88.82849884, 22.19692612], [88.82802582, 22.19721031], [88.82753754, 22.19747925], [88.8270874, 22.19783974], [88.82676697, 22.19835854], [88.82668304, 22.19905472], [88.82659149, 22.19950676], [88.82649231, 22.19976234], [88.82640839, 22.19999123], [88.82639313, 22.2002449], [88.82639313, 22.20052147], [88.82635498, 22.20082664], [88.8262558, 22.20113182], [88.82614899, 22.20148277], [88.82611847, 22.20191002], [88.82611084, 22.2023716], [88.82611084, 22.20284653], [88.82611084, 22.2033329], [88.82611084, 22.20381927], [88.82611847, 22.20429039], [88.82616425, 22.20473289], [88.82629395, 22.20509148], [88.82640839, 22.2054348], [88.82656097, 22.20575905], [88.8266983, 22.20614052], [88.82689667, 22.20654106], [88.82710266, 22.20696068], [88.8273468, 22.20737267], [88.82769775, 22.20771217], [88.82805634, 22.20804024], [88.82845306, 22.20832253], [88.8289032, 22.20848274], [88.82939148, 22.20852852], [88.82987213, 22.20866394], [88.8303299, 22.20887184], [88.83081055, 22.20902061], [88.83132935, 22.20901489], [88.83178711, 22.20882225], [88.83229065, 22.20856285], [88.83280182, 22.20826149], [88.83336639, 22.2080822], [88.83398438, 22.20791054], [88.83454132, 22.20761108], [88.83503723, 22.20718956], [88.83547211, 22.20673561], [88.83581543, 22.20625114], [88.8360672, 22.20575142], [88.83623505, 22.20525169], [88.83634186, 22.20472145], [88.83641052, 22.20417976], [88.83650208, 22.20366287], [88.83657837, 22.20316124], [88.83661652, 22.20266151], [88.83666229, 22.2021637], [88.83672333, 22.20166969], [88.83681488, 22.2012043], [88.83687592, 22.2007618], [88.83694458, 22.2005558], [88.83693695, 22.20000267], [88.83753204, 22.19749832], [88.83769226, 22.19695091], [88.83782959, 22.19642067], [88.83797455, 22.19594574], [88.83811951, 22.19548988], [88.83826447, 22.19503212], [88.83841705, 22.19456673], [88.83862305, 22.19409752], [88.83886719, 22.19360161], [88.8391571, 22.19308281], [88.83952332, 22.19257164], [88.83990479, 22.19207954], [88.84028625, 22.19164085], [88.84069824, 22.19121933], [88.84114838, 22.19086266], [88.84165955, 22.19054031], [88.8421936, 22.19022179], [88.84272003, 22.1899128], [88.84321594, 22.18963051], [88.84378052, 22.18943024], [88.84427643, 22.18927193], [88.84474945, 22.18919182], [88.84516907, 22.18914986], [88.8455658, 22.18914986], [88.8459549, 22.18916893], [88.84633636, 22.18922615], [88.84670258, 22.18936348], [88.84714508, 22.18946266], [88.84763336, 22.18963242], [88.84810638, 22.18993378], [88.84863281, 22.19033241], [88.84914398, 22.19079971], [88.84960175, 22.19129372], [88.84996796, 22.19177055], [88.85025024, 22.19219971], [88.85045624, 22.19259071], [88.85059357, 22.19296455], [88.85076141, 22.19329262], [88.85090637, 22.1936512], [88.85109711, 22.19398308], [88.85128021, 22.19439125], [88.85138702, 22.19496346], [88.85138702, 22.19564247], [88.85134125, 22.19638252], [88.85122681, 22.19710159], [88.85114288, 22.19775963], [88.85112, 22.19836235], [88.85112, 22.19890594], [88.85114288, 22.19944954], [88.85118866, 22.2000103], [88.85132599, 22.20053291], [88.85144806, 22.20107079], [88.85160828, 22.20153999], [88.85173035, 22.20198822], [88.85189819, 22.20240211], [88.85209656, 22.20288277], [88.85241699, 22.2033596], [88.85279083, 22.20387077], [88.85324097, 22.20433235], [88.85374451, 22.20470238], [88.85427094, 22.20499611], [88.85480499, 22.20521355], [88.85540009, 22.20527077], [88.85601044, 22.20528221], [88.85662079, 22.20527077], [88.85727692, 22.20520973], [88.85793304, 22.20501137], [88.85855865, 22.20476913], [88.85912323, 22.20446777], [88.85961151, 22.20409966], [88.86004639, 22.20369339], [88.86048889, 22.20329475], [88.86086273, 22.20282936], [88.86122894, 22.20238495], [88.86154175, 22.20194244], [88.86181641, 22.20152092], [88.86207581, 22.20111275], [88.86234283, 22.20069313], [88.86255646, 22.20023155], [88.86280823, 22.19976234], [88.86306, 22.19932175], [88.86328888, 22.19889259], [88.86342621, 22.19841194], [88.86362457, 22.19798851], [88.86384583, 22.19761086], [88.86398315, 22.19715309], [88.86414337, 22.19667816], [88.86416626, 22.19619179], [88.86412048, 22.19572258], [88.86393738, 22.19528008], [88.8638916, 22.19480133], [88.86388397, 22.19429588], [88.8638916, 22.19376564], [88.8638916, 22.19320869], [88.8638916, 22.19262123], [88.8638916, 22.19199944], [88.8638916, 22.19135094], [88.8638916, 22.19067955], [88.86389923, 22.19001961], [88.86398315, 22.18939018], [88.86412811, 22.1888485], [88.86416626, 22.18835258], [88.86416626, 22.18791008], [88.86416626, 22.18754005], [88.86418152, 22.18720055], [88.86427307, 22.18685913], [88.86440277, 22.18650627], [88.86444855, 22.1860714], [88.86447906, 22.18559074], [88.86464691, 22.18513298], [88.86476135, 22.18458939], [88.86496735, 22.18408012], [88.86512756, 22.18346977], [88.86530304, 22.18286705], [88.86554718, 22.18229103], [88.86576843, 22.18170166], [88.86588287, 22.1810894], [88.86608124, 22.18061256], [88.8662262, 22.18018341], [88.86636353, 22.1798439], [88.86643219, 22.17950249], [88.86658478, 22.1792202], [88.86667633, 22.17888069], [88.86676788, 22.17852974], [88.86695099, 22.17823601], [88.86714172, 22.17790794], [88.86724854, 22.17746162], [88.86740112, 22.17702484], [88.86752319, 22.17658234], [88.86769867, 22.17617035], [88.86782837, 22.17571068], [88.86804199, 22.17530251], [88.86820984, 22.17482948], [88.86833191, 22.17426109], [88.86843872, 22.17364883], [88.86856079, 22.17303276], [88.86855316, 22.1723938], [88.86837769, 22.17179298], [88.86828613, 22.17118645], [88.86805725, 22.17071152], [88.86779785, 22.17030334], [88.86741638, 22.17000389], [88.86693573, 22.16981697], [88.86631012, 22.16995811], [88.86558533, 22.16999626], [88.86484528, 22.1699543], [88.86414337, 22.16979408], [88.86347961, 22.16986275], [88.86289978, 22.16999817], [88.86238861, 22.17012787], [88.86194611, 22.17025185], [88.86149597, 22.17031479], [88.86107635, 22.17044258], [88.86062622, 22.17058182], [88.86017609, 22.17080116], [88.85970306, 22.17099953], [88.85919189, 22.17118263], [88.85869598, 22.17140007], [88.85823822, 22.17167091], [88.85775757, 22.17192268], [88.85725403, 22.17207718], [88.85678101, 22.17226219], [88.8563385, 22.17250252], [88.85590363, 22.17272186], [88.85540009, 22.17282295], [88.85494995, 22.17300987], [88.85448456, 22.17306328], [88.85402679, 22.17312431], [88.85357666, 22.17329407], [88.85305786, 22.1733284], [88.85251617, 22.17337608], [88.85195923, 22.17356491], [88.85176086, 22.17358017], [88.85138702, 22.17361259], [88.85079193, 22.17356491], [88.85024261, 22.17338181], [88.84967804, 22.17329216], [88.84918976, 22.17310524], [88.84868622, 22.17297173], [88.84822083, 22.17276382], [88.84778595, 22.17250252], [88.84733582, 22.1722126], [88.84689331, 22.17189789], [88.84642029, 22.17152977], [88.84598541, 22.17109108], [88.84557343, 22.17060661], [88.84509277, 22.17025185], [88.84466553, 22.16991615], [88.8443985, 22.16953087], [88.84414673, 22.16922188], [88.84390259, 22.16891289], [88.84371948, 22.16855812], [88.84358215, 22.1681118], [88.84336853, 22.16768265], [88.84329987, 22.16717911], [88.84332275, 22.16668129], [88.84336853, 22.16615677], [88.84353638, 22.16558838], [88.84362793, 22.16492462], [88.84377289, 22.16422272], [88.84401703, 22.16362572], [88.84425354, 22.16309547], [88.84446716, 22.16267204], [88.84469604, 22.16236115], [88.84487152, 22.16208267], [88.84503937, 22.16179085], [88.84526062, 22.16151237], [88.84548187, 22.16119957], [88.84575653, 22.16090012], [88.84610748, 22.16061592], [88.84647369, 22.16030693], [88.84686279, 22.16000938], [88.84729004, 22.15972137], [88.84772491, 22.15944481], [88.84816742, 22.15916634], [88.84860992, 22.15886116], [88.84903717, 22.15846062], [88.84944916, 22.15805626], [88.84986115, 22.15764046], [88.85025787, 22.15719032], [88.85063934, 22.15676308], [88.85103607, 22.15644264], [88.85128021, 22.15607262], [88.85138702, 22.15570259], [88.85140991, 22.15538979], [88.85141754, 22.15513039], [88.85140991, 22.1549015], [88.85137177, 22.15467262], [88.85119629, 22.15442276], [88.85090637, 22.15416527], [88.85051727, 22.1539402], [88.84998322, 22.15383911], [88.84947968, 22.15367508], [88.84896088, 22.15356827], [88.84848022, 22.15337181], [88.84799194, 22.15324211], [88.84754944, 22.15303993], [88.84713745, 22.15282631], [88.84673309, 22.15260124], [88.84637451, 22.15229988], [88.84604645, 22.15197182], [88.84574127, 22.15163231], [88.84552002, 22.15122414], [88.84532166, 22.15081596], [88.84525299, 22.15032959], [88.84516144, 22.14986229], [88.8451767, 22.14946175], [88.84529114, 22.14907265], [88.84545898, 22.1486702], [88.84561157, 22.1482029], [88.84584808, 22.14776421], [88.846138, 22.1473484], [88.84648895, 22.14702034], [88.8469162, 22.1468029], [88.84733582, 22.14656258], [88.8478241, 22.14634323], [88.84837341, 22.14615059], [88.84897614, 22.14607048], [88.84950256, 22.14591599], [88.84999084, 22.1458416], [88.85045624, 22.14583015], [88.850914, 22.14583397], [88.85138702, 22.14583397], [88.85184479, 22.14583397], [88.85262299, 22.14583397], [88.85298157, 22.14583397], [88.85336304, 22.14582825], [88.85381317, 22.1458416], [88.85429382, 22.14590073], [88.85476685, 22.1460743], [88.85527039, 22.14607048], [88.85566711, 22.14586067], [88.85600281, 22.14563179], [88.85614777, 22.14529991], [88.85630035, 22.14500427], [88.85612488, 22.14472771], [88.85588837, 22.14445305], [88.85558319, 22.14418983], [88.85513306, 22.1440258], [88.85462952, 22.14388084], [88.85410309, 22.14365387], [88.85350037, 22.14360809], [88.85289001, 22.14357376], [88.85234833, 22.14339256], [88.85179138, 22.14330482], [88.85129547, 22.14313316], [88.8507843, 22.14303017], [88.85032654, 22.14286232], [88.84984589, 22.14273262], [88.84942627, 22.14251137], [88.84898376, 22.14232445], [88.84854889, 22.14215279], [88.8481369, 22.14194298], [88.8477478, 22.14170265], [88.84726715, 22.14157486], [88.84686279, 22.14137077], [88.84646606, 22.14111137], [88.84606171, 22.14086151], [88.84558868, 22.14072227], [88.84514618, 22.14053154], [88.8447113, 22.14028549], [88.84422302, 22.1400528], [88.84369659, 22.13979149], [88.84320068, 22.13946724], [88.84272003, 22.13916969], [88.84230804, 22.13887978], [88.84200287, 22.1386013], [88.84178162, 22.13833046], [88.84157562, 22.13809204], [88.84134674, 22.1378994], [88.84104156, 22.13775063], [88.84072113, 22.13752174], [88.84034729, 22.13730049], [88.84001923, 22.13705826], [88.83969879, 22.13683128], [88.8393631, 22.13665962], [88.83898926, 22.13650322], [88.83855438, 22.13640785], [88.83809662, 22.1363945], [88.83763123, 22.1363945], [88.83716583, 22.1363945], [88.83670807, 22.136343], [88.83623505, 22.13619995], [88.83577728, 22.13633156], [88.83554077, 22.13629913], [88.83531189, 22.13627052], [88.83483887, 22.13615417], [88.83434296, 22.13611794], [88.83383179, 22.13611031], [88.83331299, 22.13609314], [88.83282471, 22.13598061], [88.83241272, 22.13575172], [88.83197784, 22.13552284], [88.83156586, 22.13529015], [88.83114624, 22.13507271], [88.83068848, 22.1349678], [88.8302536, 22.13475227], [88.82977295, 22.13461113], [88.82927704, 22.13440323], [88.8288269, 22.13411903], [88.82835388, 22.13385773], [88.82789612, 22.13356972], [88.82750702, 22.13321114], [88.82713318, 22.13286018], [88.82668304, 22.13260078], [88.82623291, 22.13232994], [88.82585907, 22.1319828], [88.82546234, 22.13166809], [88.82507324, 22.13136101], [88.82470703, 22.1310215], [88.82433319, 22.13072014], [88.82393646, 22.13042259], [88.82362366, 22.13005257], [88.823349, 22.12964058], [88.82309723, 22.12922096], [88.82280731, 22.12882042], [88.82257843, 22.12841225], [88.82234192, 22.12805176], [88.82215118, 22.12771606], [88.82195282, 22.1274395], [88.8217392, 22.1272049], [88.8215332, 22.12698555], [88.82129669, 22.12683296], [88.82106018, 22.12669563], [88.82077026, 22.12667274], [88.82044983, 22.12667274], [88.82009888, 22.12675285], [88.81972504, 22.1269474], [88.8192749, 22.12716484], [88.81871033, 22.12729073], [88.81816864, 22.12751198], [88.81765747, 22.12779045], [88.81716156, 22.12812233], [88.81668854, 22.12848091], [88.8162384, 22.12885857], [88.81576538, 22.12916565], [88.8152771, 22.12943077], [88.81478119, 22.12963676], [88.81421661, 22.12974167], [88.81368256, 22.12991524], [88.81314087, 22.1300602], [88.81263733, 22.13028908], [88.81212616, 22.13054085], [88.8115387, 22.1307621], [88.81088257, 22.13087463], [88.81027222, 22.13107109], [88.80970001, 22.13111305], [88.8092041, 22.13111305], [88.80875397, 22.13111305], [88.80832672, 22.13111305], [88.80789948, 22.13111305], [88.80745697, 22.13111305], [88.80697632, 22.13108253], [88.80644226, 22.13092041], [88.80583191, 22.13083076], [88.80519104, 22.13073158], [88.80461121, 22.13054085], [88.80410767, 22.13028145], [88.8035965, 22.1300106], [88.80307007, 22.12973213], [88.8025589, 22.12936211], [88.80211639, 22.1289196], [88.80168915, 22.12850189], [88.80130768, 22.12809944], [88.80092621, 22.12775993], [88.80059052, 22.12742424], [88.80027008, 22.1270504], [88.7999115, 22.12667274], [88.79951477, 22.12629509], [88.79916382, 22.1258297], [88.79881287, 22.12536049], [88.7984314, 22.12495232], [88.79811096, 22.12450218], [88.79785919, 22.12405777], [88.79772949, 22.12354469], [88.79753113, 22.123106], [88.79738617, 22.12268257], [88.79722595, 22.1223011], [88.79708099, 22.12194252], [88.79692078, 22.1215992], [88.7967453, 22.12129402], [88.79663849, 22.12092781], [88.79646301, 22.12059975], [88.79637146, 22.12016106], [88.7962265, 22.1196785], [88.79612732, 22.11911011], [88.7960968, 22.11846924], [88.79601288, 22.11782265], [88.79586792, 22.11718941], [88.79579163, 22.11655045], [88.79560089, 22.11594963], [88.79545593, 22.11534691], [88.79524231, 22.11483383], [88.79497528, 22.11443901], [88.79464722, 22.11416054], [88.79426575, 22.11394882], [88.79374695, 22.11386108], [88.79317474, 22.11373711], [88.79258728, 22.11367989], [88.79205322, 22.1138382], [88.79152679, 22.11387062], [88.79099274, 22.11389542], [88.79042816, 22.11395454], [88.7898407, 22.11412239], [88.78919983, 22.11417961], [88.78856659, 22.11425209], [88.78794098, 22.11438179], [88.78734589, 22.11430168], [88.78675842, 22.11418915], [88.78614044, 22.11416435], [88.78547668, 22.11412239], [88.78479004, 22.11393356], [88.78406525, 22.11384392], [88.78340912, 22.11365128], [88.78274536, 22.11354256], [88.78221893, 22.11332893], [88.78173828, 22.11310005], [88.78122711, 22.1129818], [88.78083038, 22.11276245], [88.78045654, 22.11251259], [88.78005981, 22.11230278], [88.77958679, 22.11216927], [88.77916718, 22.11194038], [88.77870178, 22.11169624], [88.77818298, 22.11150169], [88.7776413, 22.11122131], [88.7771759, 22.11079407], [88.77670288, 22.11034393], [88.77614594, 22.10999489], [88.77565002, 22.10965538], [88.77534485, 22.10937119], [88.77527618, 22.10944366], [88.77281952, 22.10697937], [88.77249908, 22.10695267], [88.77194214, 22.10639191], [88.77194214, 22.10611153], [88.77169037, 22.1056385], [88.771492, 22.10509109], [88.7713623, 22.10455322], [88.77119446, 22.10407066], [88.77111816, 22.10355186], [88.77107239, 22.10302162], [88.77091217, 22.10254288], [88.77084351, 22.10206032], [88.77082825, 22.10157394], [88.77076721, 22.10110283], [88.77059937, 22.10070992], [88.77056122, 22.10025978], [88.77054596, 22.09978485], [88.77052307, 22.09929276], [88.77037048, 22.09881783], [88.77028656, 22.09832382], [88.77027893, 22.09781647], [88.7702713, 22.09731102], [88.7702713, 22.09681129], [88.7702713, 22.09629822], [88.77027893, 22.09579849], [88.7702713, 22.09530067], [88.7702713, 22.09481239], [88.77024841, 22.09431267], [88.77011108, 22.09383392], [88.76999664, 22.09331894], [88.76985168, 22.0927906], [88.76956177, 22.09229088], [88.76905823, 22.09194946], [88.76846313, 22.0916729], [88.76783752, 22.09139061], [88.76719666, 22.09111214], [88.76655579, 22.09087944], [88.76593781, 22.09078026], [88.76544189, 22.09055519], [88.76499939, 22.09031105], [88.76451874, 22.09019089], [88.76407623, 22.09004021], [88.7636261, 22.0899601], [88.76320648, 22.08976173], [88.76274872, 22.08967781], [88.76235199, 22.08950233], [88.7618866, 22.08937263], [88.76145172, 22.08918571]]], [[[88.93237305, 22.22500038], [88.93305206, 22.22480583], [88.93377686, 22.22491264], [88.93447876, 22.22476006], [88.93522644, 22.22468567], [88.9359436, 22.22452354], [88.93669128, 22.22445488], [88.93743896, 22.22439766], [88.93815613, 22.22419357], [88.93888092, 22.22403145], [88.93958282, 22.22385406], [88.94024658, 22.22361183], [88.94091034, 22.22337151], [88.94165039, 22.22329521], [88.94235229, 22.22311974], [88.94304657, 22.22302055], [88.94368744, 22.22282219], [88.94432831, 22.22278023], [88.94496155, 22.22278023], [88.9455719, 22.22278023], [88.94618225, 22.2227726], [88.94671631, 22.22271919], [88.94716644, 22.22255135], [88.9477005, 22.22250748], [88.94824219, 22.22249031], [88.94877625, 22.22242165], [88.9493103, 22.22223091], [88.9498291, 22.22211838], [88.95036316, 22.22224236], [88.95085907, 22.22245026], [88.95144653, 22.22250748], [88.95202637, 22.22250748], [88.9526062, 22.2224617], [88.95313263, 22.22223091], [88.95365906, 22.22195244], [88.95418549, 22.22160339], [88.95451355, 22.22102547], [88.95471191, 22.22034264], [88.95482635, 22.21964073], [88.95497131, 22.21899223], [88.95500183, 22.21840096], [88.95500183, 22.21788216], [88.95500183, 22.21742821], [88.95500183, 22.21699142], [88.95500183, 22.21656227], [88.95500183, 22.21614265], [88.95504761, 22.21576118], [88.9552002, 22.21546745], [88.95526886, 22.21513176], [88.95528412, 22.21477127], [88.95533752, 22.21442223], [88.95552063, 22.21414948], [88.95555878, 22.21383286], [88.95559692, 22.21350479], [88.95575714, 22.21323586], [88.95584869, 22.21292114], [88.95597839, 22.21263313], [88.95612335, 22.21235085], [88.95627594, 22.21204376], [88.95641327, 22.21162987], [88.95662689, 22.21117973], [88.95674896, 22.21063042], [88.9569397, 22.21006966], [88.95717621, 22.20948792], [88.95728302, 22.20882988], [88.95750427, 22.20822525], [88.95777893, 22.20763969], [88.95805359, 22.20711136], [88.9582901, 22.20662117], [88.95838165, 22.20614052], [88.95858002, 22.20577431], [88.95869446, 22.20537376], [88.95888519, 22.20501518], [88.95909119, 22.20465469], [88.95923615, 22.2042408], [88.9594574, 22.20383263], [88.95968628, 22.20340157], [88.95986938, 22.20290184], [88.96003723, 22.20239067], [88.96028137, 22.20192146], [88.96051025, 22.20145035], [88.96063232, 22.20095825], [88.96084595, 22.20059013], [88.9610672, 22.20027924], [88.96111298, 22.19986153], [88.96117401, 22.19941139], [88.96134949, 22.19893074], [88.96141052, 22.19839287], [88.96148682, 22.19781494], [88.961586, 22.19721031], [88.96144104, 22.19664383], [88.96138, 22.19606018], [88.96129608, 22.19548988], [88.96115112, 22.1949749], [88.96109772, 22.1944828], [88.96099091, 22.19405174], [88.96082306, 22.19368935], [88.96057892, 22.19336128], [88.96026611, 22.19301033], [88.95989227, 22.1926899], [88.95947266, 22.19244194], [88.95906067, 22.19220924], [88.95865631, 22.19199181], [88.95820618, 22.19190979], [88.95783234, 22.19174004], [88.95739746, 22.19168282], [88.9569397, 22.19167137], [88.95652008, 22.19167137], [88.95609283, 22.19164085], [88.95567322, 22.19151115], [88.9552536, 22.19140625], [88.95479584, 22.19139481], [88.95429993, 22.19139481], [88.9536972, 22.19139481], [88.95302582, 22.19135094], [88.95237732, 22.19118309], [88.95168304, 22.19123268], [88.95097351, 22.19135857], [88.95026398, 22.19143295], [88.949646, 22.19162178], [88.94906616, 22.19168282], [88.94853973, 22.1917572], [88.94803619, 22.1919117], [88.94747925, 22.19197273], [88.94690704, 22.19210815], [88.94631195, 22.19226265], [88.94574738, 22.19248009], [88.94512939, 22.1926403], [88.94448853, 22.19276237], [88.94381714, 22.19278145], [88.94315338, 22.19276237], [88.94249725, 22.19266319], [88.94190216, 22.19248009], [88.94140625, 22.19218826], [88.94110107, 22.19180107], [88.94081879, 22.19144249], [88.94056702, 22.19114113], [88.9404068, 22.19083977], [88.94029999, 22.19057274], [88.9402771, 22.19028664], [88.94029999, 22.19000053], [88.9404068, 22.18972206], [88.94052887, 22.18943787], [88.9405899, 22.18912315], [88.94075012, 22.18885994], [88.9409256, 22.18861961], [88.94114685, 22.18836784], [88.94139862, 22.18810081], [88.94169617, 22.1878109], [88.94204712, 22.18751717], [88.94245911, 22.18722153], [88.94290924, 22.18691063], [88.94333649, 22.18653107], [88.94380188, 22.18612289], [88.94425964, 22.18571854], [88.94455719, 22.18525124], [88.94468689, 22.18476486], [88.94458771, 22.18432808], [88.94433594, 22.18400002], [88.94391632, 22.1838131], [88.94345856, 22.1836319], [88.94296265, 22.18350029], [88.94249725, 22.18333817], [88.94207001, 22.18317986], [88.94164276, 22.18307495], [88.94123077, 22.1830616], [88.94078064, 22.18305016], [88.94037628, 22.1830101], [88.94002533, 22.18284416], [88.9395752, 22.18278313], [88.93908691, 22.18275261], [88.93860626, 22.18264198], [88.93811798, 22.18252182], [88.93758392, 22.18247223], [88.93704987, 22.18234062], [88.93649292, 22.18219948], [88.93596649, 22.18194008], [88.93546295, 22.18164444], [88.93503571, 22.18127251], [88.93467712, 22.1808567], [88.93434143, 22.1804409], [88.93406677, 22.17999077], [88.93380737, 22.1794529], [88.9335022, 22.17889214], [88.93313599, 22.17831039], [88.93279266, 22.17772102], [88.93238831, 22.17719078], [88.93180084, 22.17702484], [88.93148041, 22.17701149], [88.93128204, 22.17715454], [88.93097687, 22.17727089], [88.93069458, 22.17749977], [88.93035126, 22.17777443], [88.92996216, 22.17805481], [88.92955017, 22.17830467], [88.92906952, 22.17849159], [88.92858124, 22.17868996], [88.92806244, 22.17892075], [88.92751312, 22.17917061], [88.92693329, 22.17941093], [88.92630768, 22.17941093], [88.92575836, 22.17925072], [88.92523956, 22.17918205], [88.9247818, 22.17917061], [88.92434692, 22.17919922], [88.92398834, 22.17933655], [88.92365265, 22.1794529], [88.92334747, 22.17963028], [88.92307281, 22.17987823], [88.92284393, 22.18021774], [88.92262268, 22.18060112], [88.92240906, 22.1810627], [88.92208099, 22.18152428], [88.92164612, 22.18201256], [88.92115021, 22.18252182], [88.92063141, 22.18305016], [88.92008209, 22.18351173], [88.91947937, 22.18385887], [88.91893768, 22.18418121], [88.91851807, 22.18454361], [88.91815186, 22.18490028], [88.91780853, 22.18525124], [88.91750336, 22.18562126], [88.91722107, 22.18600655], [88.91693115, 22.1863842], [88.91661072, 22.18672371], [88.91628265, 22.18707085], [88.91594696, 22.18748283], [88.91558075, 22.18787193], [88.91520691, 22.18827438], [88.91481781, 22.1886425], [88.91443634, 22.1890316], [88.91407013, 22.1894207], [88.91366577, 22.18978119], [88.9132843, 22.19015694], [88.91285706, 22.19049263], [88.91247559, 22.19087982], [88.91213226, 22.19129944], [88.91172028, 22.19165039], [88.91127777, 22.19196892], [88.91088104, 22.19231606], [88.91052246, 22.19269371], [88.91015625, 22.19304085], [88.90979767, 22.19337273], [88.90946198, 22.19372559], [88.90917206, 22.19410133], [88.90888977, 22.19452095], [88.90859985, 22.19493294], [88.90834045, 22.19534111], [88.90813446, 22.19578743], [88.9080658, 22.19631004], [88.90809631, 22.19681931], [88.90828705, 22.1972599], [88.90837097, 22.19774055], [88.90857697, 22.19815445], [88.90880585, 22.19857979], [88.90911865, 22.19898033], [88.90943146, 22.19943047], [88.90975952, 22.19989395], [88.91015625, 22.2003231], [88.91051483, 22.20079422], [88.9108963, 22.20127487], [88.91135406, 22.20166969], [88.9118042, 22.20204163], [88.91220093, 22.20239067], [88.91252136, 22.20273781], [88.91279602, 22.20304108], [88.91306305, 22.20335197], [88.91333008, 22.20368004], [88.91362, 22.20407295], [88.91396332, 22.20449257], [88.91442108, 22.20487022], [88.91485596, 22.2053051], [88.9152298, 22.20578194], [88.91552734, 22.20623207], [88.91573334, 22.20666313], [88.91585541, 22.20704079], [88.91600037, 22.20735741], [88.91625977, 22.20759392], [88.91653442, 22.20786476], [88.91667175, 22.20826149], [88.91678619, 22.2087307], [88.91691589, 22.20926094], [88.91698456, 22.20983505], [88.91716003, 22.21042061], [88.91725922, 22.21103477], [88.91750336, 22.21155357], [88.91773224, 22.21204567], [88.91776276, 22.21255302], [88.91766357, 22.21303368], [88.91751862, 22.21351433], [88.91743469, 22.2140522], [88.91726685, 22.21463203], [88.91718292, 22.2152729], [88.91697693, 22.21584129], [88.91687012, 22.21643257], [88.91670227, 22.21696281], [88.91662598, 22.2175312], [88.91642761, 22.21807289], [88.91639709, 22.21863747], [88.91646576, 22.21921349], [88.91667938, 22.21973228], [88.91697693, 22.22024155], [88.91732025, 22.22073174], [88.91765594, 22.22123146], [88.91797638, 22.22178078], [88.91809845, 22.22242165], [88.91828918, 22.22301292], [88.91837311, 22.22358322], [88.91857147, 22.22409248], [88.91860962, 22.22462273], [88.91861725, 22.22514725], [88.91860962, 22.22567177], [88.91857147, 22.22617912], [88.91841125, 22.22661018], [88.91834259, 22.22704124], [88.91833496, 22.2274456], [88.91833496, 22.22786331], [88.91833496, 22.2283268], [88.91833496, 22.22885323], [88.91837311, 22.22941208], [88.91855621, 22.22992134], [88.91863251, 22.23042107], [88.91879272, 22.23080826], [88.9190979, 22.23105049], [88.91954803, 22.23106956], [88.92002869, 22.23089027], [88.92050171, 22.23067284], [88.92088318, 22.23034286], [88.92125702, 22.2300148], [88.92167664, 22.22969246], [88.92207336, 22.22932243], [88.92247772, 22.22898293], [88.9228363, 22.2286396], [88.92318726, 22.22835159], [88.9235611, 22.22809792], [88.92394257, 22.22783089], [88.92436218, 22.22756958], [88.92476654, 22.22728539], [88.92520142, 22.2270298], [88.92567444, 22.22681046], [88.92613983, 22.22657204], [88.92663574, 22.22642517], [88.92717743, 22.22634315], [88.92761993, 22.22610855], [88.92802429, 22.22590065], [88.92845917, 22.22580147], [88.92883301, 22.22564125], [88.92921448, 22.22556877], [88.92962646, 22.2255497], [88.93006134, 22.22554016], [88.93052673, 22.22546196], [88.93107605, 22.22531319], [88.93171692, 22.22522926], [88.93237305, 22.22500038]]], [[[88.81259918, 22.28339195], [88.8130722, 22.28331947], [88.81347656, 22.28321266], [88.81388855, 22.28307915], [88.81421661, 22.28281212], [88.81441498, 22.28238678], [88.81451416, 22.28183937], [88.81463623, 22.28129005], [88.81481171, 22.28082085], [88.81495667, 22.28036118], [88.81500244, 22.27986145], [88.8150177, 22.27934074], [88.81504822, 22.2788372], [88.81513977, 22.27836037], [88.81524658, 22.27787971], [88.81532288, 22.27739143], [88.81541443, 22.27687263], [88.81539154, 22.27636147], [88.81537628, 22.27584839], [88.81533051, 22.27531052], [88.81528473, 22.27478981], [88.8152771, 22.2742691], [88.8152771, 22.27375221], [88.8152771, 22.27323151], [88.8152771, 22.27272224], [88.81523895, 22.27223015], [88.81513977, 22.27177238], [88.81511688, 22.27130508], [88.81517029, 22.27083015], [88.8152771, 22.27036667], [88.81541443, 22.26990318], [88.81549072, 22.26942635], [88.81551361, 22.26892853], [88.81551361, 22.26841927], [88.81545258, 22.26794243], [88.8152771, 22.26755905], [88.81511688, 22.26719093], [88.81503296, 22.26679039], [88.81500244, 22.2663517], [88.81500244, 22.26588249], [88.8150177, 22.26537132], [88.81508636, 22.26485252], [88.8152771, 22.2644043], [88.81551361, 22.26398659], [88.81588745, 22.26371384], [88.81632996, 22.26349831], [88.81681061, 22.2632618], [88.81739044, 22.26319122], [88.81803131, 22.26331139], [88.8187027, 22.26344109], [88.81932068, 22.26358795], [88.81991577, 22.26370239], [88.82051849, 22.26389122], [88.82115936, 22.26409531], [88.82182312, 22.26428032], [88.82237244, 22.26449013], [88.82285309, 22.26468849], [88.82328033, 22.26484108], [88.82366943, 22.26501274], [88.82409668, 22.2652092], [88.824646, 22.26532173], [88.82525635, 22.26538467], [88.82546997, 22.26528168], [88.8258667, 22.26510048], [88.82624817, 22.26459312], [88.82640839, 22.26402092], [88.82653046, 22.2634716], [88.82663727, 22.26292992], [88.82668304, 22.26239014], [88.82675934, 22.26187325], [88.82684326, 22.26135826], [88.82670593, 22.26083183], [88.82672882, 22.26030159], [88.82680511, 22.25972176], [88.82691956, 22.25909996], [88.82699585, 22.25846291], [88.82714844, 22.2578907], [88.8273468, 22.25740242], [88.82762909, 22.25704002], [88.82772827, 22.25662041], [88.82766724, 22.25604057], [88.82748413, 22.25543022], [88.82727814, 22.25475121], [88.82731628, 22.25396156], [88.8273468, 22.25323296], [88.82720947, 22.25284386], [88.82697296, 22.25248146], [88.82679749, 22.2520237], [88.8266449, 22.25152397], [88.82646942, 22.25101662], [88.82636261, 22.25047874], [88.82623291, 22.24997139], [88.82613373, 22.24944687], [88.82611084, 22.2489109], [88.82605743, 22.24841118], [88.82588196, 22.24798012], [88.82583618, 22.24754143], [88.82583618, 22.24711418], [88.82588196, 22.24669456], [88.82606506, 22.24629021], [88.82607269, 22.24583244], [88.8259201, 22.24534035], [88.82583618, 22.2448597], [88.82582092, 22.24435234], [88.82582855, 22.24381256], [88.82583618, 22.24323082], [88.82584381, 22.2426281], [88.82581329, 22.24202156], [88.82567596, 22.24144173], [88.82541656, 22.24091148], [88.82504272, 22.24051094], [88.82463074, 22.24013519], [88.8241806, 22.23981476], [88.82356262, 22.23966026], [88.82298279, 22.23933983], [88.82247925, 22.23890114], [88.82196045, 22.23846817], [88.82150269, 22.23801231], [88.82112885, 22.23751259], [88.82080841, 22.23703575], [88.82045746, 22.23666954], [88.82012939, 22.23634911], [88.81987762, 22.23597145], [88.8196106, 22.23552704], [88.81938171, 22.23503113], [88.81913757, 22.23452187], [88.8188324, 22.23405266], [88.81852722, 22.23361015], [88.81825256, 22.23317337], [88.81801605, 22.23273277], [88.81772614, 22.2323513], [88.8174057, 22.23201942], [88.81706238, 22.2317028], [88.81668854, 22.23142052], [88.81629944, 22.23116684], [88.81587982, 22.23093987], [88.81547546, 22.23068428], [88.81510162, 22.23040581], [88.81468201, 22.23018456], [88.81425476, 22.22987938], [88.81371307, 22.22969246], [88.81318665, 22.22950172], [88.81269836, 22.22937965], [88.81224823, 22.22921181], [88.81173706, 22.2290802], [88.81121063, 22.22893906], [88.81059265, 22.22893333], [88.80992126, 22.229002], [88.80922699, 22.22891426], [88.80853271, 22.22881889], [88.80787659, 22.22867012], [88.80718994, 22.2286129], [88.80648804, 22.22860527], [88.80578613, 22.22855949], [88.80509949, 22.22841835], [88.8044281, 22.22824287], [88.80374908, 22.22810173], [88.80304718, 22.22805977], [88.80236053, 22.22805023], [88.80167389, 22.22804451], [88.80101013, 22.22800255], [88.80041504, 22.22787476], [88.79991913, 22.22769356], [88.79947662, 22.22747612], [88.79910278, 22.22719002], [88.79881287, 22.22683716], [88.79859924, 22.22641373], [88.79846954, 22.22597313], [88.79863739, 22.22553062], [88.79891968, 22.22512817], [88.79928589, 22.22478294], [88.79972076, 22.22451973], [88.80018616, 22.22427177], [88.80068207, 22.22401237], [88.80113983, 22.22369957], [88.8015976, 22.22339058], [88.80204773, 22.22303963], [88.80252075, 22.2226696], [88.80301666, 22.22229195], [88.8035202, 22.22192574], [88.80387878, 22.22142982], [88.80416107, 22.22097206], [88.80438232, 22.22057152], [88.80448914, 22.22015953], [88.80462646, 22.21977234], [88.80470276, 22.21930885], [88.80473328, 22.21874046], [88.80473328, 22.21811676], [88.80471039, 22.21748161], [88.80461884, 22.21692657], [88.80441284, 22.21653938], [88.80419922, 22.21617126], [88.80399323, 22.21584129], [88.80381012, 22.21542358], [88.80370331, 22.21500587], [88.80373383, 22.21463203], [88.80383301, 22.21425247], [88.80382538, 22.21381569], [88.80374908, 22.21331978], [88.80389404, 22.21277237], [88.80410004, 22.21218491], [88.80430603, 22.21156311], [88.80445099, 22.21093369], [88.80457306, 22.21035576], [88.80471039, 22.20989037], [88.80483246, 22.20951271], [88.80497742, 22.20921135], [88.80512238, 22.2089119], [88.80529785, 22.2086277], [88.80554199, 22.20835304], [88.80583954, 22.20805168], [88.80621338, 22.20773125], [88.80670166, 22.20746613], [88.80726624, 22.20720291], [88.80787659, 22.20698166], [88.80854797, 22.20682144], [88.80921173, 22.20663261], [88.80988312, 22.20650291], [88.81052399, 22.20661354], [88.8107605, 22.20663071], [88.81118011, 22.20666313], [88.81167603, 22.20664215], [88.8117981, 22.20664024], [88.81237793, 22.20656013], [88.81284332, 22.20631218], [88.81328583, 22.20614815], [88.81373596, 22.20606041], [88.81416321, 22.20588112], [88.81461334, 22.20570946], [88.81498718, 22.20541954], [88.81529236, 22.20508194], [88.81557465, 22.20474052], [88.81581116, 22.20439339], [88.81600952, 22.2040081], [88.81624603, 22.20361328], [88.81642914, 22.2031498], [88.81632996, 22.20257378], [88.81634521, 22.20198631], [88.81638336, 22.20138168], [88.81639099, 22.20076752], [88.81639862, 22.20016479], [88.81642151, 22.19957161], [88.81646729, 22.1989994], [88.81661987, 22.19846153], [88.81671906, 22.19792938], [88.81690216, 22.19745255], [88.81703186, 22.19693184], [88.81725311, 22.1965313], [88.81754303, 22.19617271], [88.81787109, 22.195858], [88.81822968, 22.19558907], [88.81864166, 22.19538116], [88.81907654, 22.19521141], [88.81957245, 22.19504356], [88.82016754, 22.1950016], [88.82080078, 22.19501305], [88.82144165, 22.19507027], [88.82199097, 22.19517136], [88.82246399, 22.19526672], [88.82289124, 22.19532967], [88.82328033, 22.19550705], [88.82370758, 22.19555092], [88.82419586, 22.19556808], [88.82468414, 22.19556618], [88.82519531, 22.19560051], [88.82572937, 22.19568443], [88.82628632, 22.19577599], [88.82678986, 22.19568443], [88.82718658, 22.1954155], [88.82749939, 22.19498634], [88.82776642, 22.19444084], [88.82802582, 22.19388008], [88.82832336, 22.19334221], [88.8285675, 22.19283485], [88.82871246, 22.19229507], [88.8289032, 22.19181252], [88.82913971, 22.19137764], [88.82932281, 22.19091225], [88.82948303, 22.19042015], [88.82970428, 22.18997765], [88.82990265, 22.18949318], [88.8300705, 22.18900108], [88.83030701, 22.18859291], [88.83056641, 22.18816948], [88.83085632, 22.18774605], [88.83112335, 22.18727303], [88.83133698, 22.18674278], [88.83148956, 22.1861763], [88.83168793, 22.18567085], [88.83194733, 22.18522263], [88.83222198, 22.18482971], [88.83249664, 22.18441963], [88.83277893, 22.18397141], [88.83307648, 22.18346977], [88.83341217, 22.18298149], [88.83377838, 22.1825161], [88.8341217, 22.18209648], [88.83436584, 22.18169594], [88.83457947, 22.18137169], [88.83473969, 22.1810627], [88.83491516, 22.18079185], [88.83507538, 22.18049431], [88.83526611, 22.18018913], [88.8354187, 22.17984962], [88.83557129, 22.17954254], [88.83583069, 22.17916679], [88.83611298, 22.17889214], [88.83611298, 22.17860985], [88.83666992, 22.17805481], [88.83666992, 22.17777824], [88.83750153, 22.17694473], [88.83750153, 22.17638969], [88.83777618, 22.17611122], [88.83777618, 22.17556381], [88.83805847, 22.17527962], [88.83805847, 22.17416954], [88.83811951, 22.17403984], [88.83813477, 22.17347336], [88.83807373, 22.17291832], [88.8380127, 22.17237282], [88.83782196, 22.1718502], [88.83771515, 22.1713047], [88.83750153, 22.17082405], [88.83728027, 22.17033195], [88.83706665, 22.16984367], [88.83686829, 22.16937447], [88.83668518, 22.16893959], [88.83654022, 22.16850853], [88.83631897, 22.16814232], [88.83597565, 22.16784859], [88.83555603, 22.1675396], [88.8350296, 22.16723061], [88.83439636, 22.16698265], [88.83405304, 22.16685295], [88.83374786, 22.16687202], [88.83338165, 22.16695213], [88.83296204, 22.16706467], [88.83248901, 22.16716194], [88.83197021, 22.1672802], [88.8315506, 22.16764259], [88.83109283, 22.16802025], [88.83058167, 22.16841316], [88.83010864, 22.16888809], [88.82965851, 22.16937065], [88.82917023, 22.16974068], [88.8286972, 22.17007256], [88.82833862, 22.17045021], [88.82798767, 22.17084312], [88.82762146, 22.17123413], [88.82723236, 22.17159081], [88.826828, 22.17193031], [88.82643127, 22.17222786], [88.82604218, 22.17250252], [88.82572174, 22.17277908], [88.82541656, 22.17303276], [88.82508087, 22.17326164], [88.82473755, 22.17353058], [88.82440186, 22.17386055], [88.8239975, 22.17418289], [88.82357025, 22.17447853], [88.82310486, 22.17478371], [88.82263184, 22.17514038], [88.8221283, 22.17551231], [88.82157898, 22.17584038], [88.82105255, 22.17618561], [88.82058716, 22.17653084], [88.82019043, 22.17690086], [88.81978607, 22.17721748], [88.81936646, 22.17750549], [88.81894684, 22.17778969], [88.81853485, 22.17814064], [88.81815338, 22.1785202], [88.81777191, 22.17888069], [88.81736755, 22.17919922], [88.81698608, 22.17952156], [88.81665039, 22.17989159], [88.81630707, 22.18024254], [88.81594086, 22.18055153], [88.81555939, 22.18084717], [88.81519318, 22.18116951], [88.8147583, 22.18140221], [88.81433105, 22.18160057], [88.81387329, 22.18172264], [88.81344604, 22.18194962], [88.81304932, 22.18219948], [88.8126297, 22.18238068], [88.81224823, 22.18254471], [88.81186676, 22.18272209], [88.81147003, 22.18285179], [88.81108093, 22.18301964], [88.81062317, 22.18309212], [88.81015015, 22.18327141], [88.80961609, 22.18333817], [88.80908203, 22.18333817], [88.80854797, 22.18329048], [88.80806732, 22.18311119], [88.80757141, 22.18305397], [88.80708313, 22.18298721], [88.80661011, 22.18280029], [88.80612183, 22.18264198], [88.80562592, 22.18244934], [88.80515289, 22.18220329], [88.8046875, 22.18192291], [88.80419159, 22.18166161], [88.80371857, 22.18139076], [88.80327606, 22.18111229], [88.80285645, 22.18083382], [88.80243683, 22.18055916], [88.80203247, 22.18027306], [88.80157471, 22.17999077], [88.80113983, 22.1796627], [88.80070496, 22.17929649], [88.80027008, 22.17892265], [88.79981232, 22.17856026], [88.7993927, 22.17813492], [88.79897308, 22.17772102], [88.79862213, 22.17729378], [88.79832458, 22.17687225], [88.79806519, 22.17649269], [88.79782867, 22.17614937], [88.79759979, 22.17584038], [88.79734802, 22.17551231], [88.79710388, 22.17512703], [88.79683685, 22.17469978], [88.79659271, 22.17424011], [88.79628754, 22.17383194], [88.79606628, 22.17339134], [88.79589081, 22.17296028], [88.79574585, 22.17255211], [88.79560089, 22.17217064], [88.79545593, 22.17181015], [88.79530334, 22.1714592], [88.79515076, 22.17108917], [88.79496002, 22.17078018], [88.79471588, 22.17058754], [88.79444122, 22.17051125], [88.79415131, 22.17057037], [88.79387665, 22.17082024], [88.79358673, 22.17121315], [88.7933197, 22.17174149], [88.79302216, 22.17233276], [88.79268646, 22.17288017], [88.79238892, 22.17344856], [88.79209137, 22.1739502], [88.79191589, 22.17439079], [88.79168701, 22.17470741], [88.79144287, 22.1750145], [88.79116058, 22.1753521], [88.79088593, 22.17577171], [88.79058075, 22.17622566], [88.7902832, 22.17675209], [88.78997803, 22.17728043], [88.78961945, 22.17771912], [88.78923035, 22.17805481], [88.78886414, 22.17835045], [88.78847504, 22.17860985], [88.78807831, 22.17884254], [88.78765106, 22.17902374], [88.78723907, 22.17918968], [88.78687286, 22.17943001], [88.78645325, 22.17965508], [88.78594971, 22.17986107], [88.78533173, 22.18003273], [88.78470612, 22.18022919], [88.78408051, 22.18029976], [88.78347778, 22.18041039], [88.78288269, 22.18055153], [88.78224945, 22.18066025], [88.78163147, 22.18079948], [88.78100586, 22.18087959], [88.78044891, 22.18107033], [88.77988434, 22.18110847], [88.77935791, 22.1811161], [88.77885437, 22.18115044], [88.77838898, 22.18130493], [88.77789307, 22.18138313], [88.77738953, 22.18144989], [88.77694702, 22.18163109], [88.77648163, 22.18175316], [88.77604675, 22.18192291], [88.77561951, 22.18204117], [88.77523804, 22.18223763], [88.77487946, 22.18248177], [88.77451324, 22.18271065], [88.77403259, 22.1829052], [88.7735672, 22.18308258], [88.77316284, 22.18333626], [88.77278137, 22.18361092], [88.7723999, 22.18389893], [88.77191162, 22.1841526], [88.77144623, 22.18441391], [88.77106476, 22.18474007], [88.7707901, 22.18511581], [88.77059937, 22.18548393], [88.77049255, 22.18589211], [88.77033997, 22.1862812], [88.77028656, 22.18670082], [88.7702713, 22.18716049], [88.7702713, 22.18766212], [88.7702713, 22.18816948], [88.77023315, 22.18867874], [88.77007294, 22.18913078], [88.76999664, 22.18963051], [88.7699585, 22.1901226], [88.76978302, 22.19053078], [88.76972198, 22.19083214], [88.76972198, 22.19111061], [88.76944733, 22.19138908], [88.76944733, 22.19194412], [88.76917267, 22.19221306], [88.76917267, 22.19250488], [88.76860809, 22.1930542], [88.76860809, 22.19333076], [88.76832581, 22.19361305], [88.76824951, 22.19356918], [88.76786804, 22.19390297], [88.7674408, 22.19421005], [88.76698303, 22.19447136], [88.76650238, 22.19472313], [88.76602936, 22.19492149], [88.76552582, 22.19501305], [88.76502991, 22.19508553], [88.76477051, 22.19510651], [88.76451874, 22.19512749], [88.76403809, 22.19502831], [88.76352692, 22.19496155], [88.76302338, 22.19479179], [88.76251221, 22.19462013], [88.7620163, 22.1944294], [88.76158142, 22.19419289], [88.76113892, 22.19403267], [88.76069641, 22.19389153], [88.76025391, 22.19381332], [88.75978851, 22.19384193], [88.7593689, 22.19402122], [88.75894928, 22.19427109], [88.75858307, 22.19458961], [88.7582016, 22.19488907], [88.75784302, 22.1951828], [88.75752258, 22.1955204], [88.75712585, 22.19577217], [88.75662994, 22.195961], [88.75608063, 22.19613075], [88.75553131, 22.19637108], [88.75498199, 22.19652939], [88.75444794, 22.19664383], [88.75392914, 22.19667816], [88.75343323, 22.19673729], [88.75291443, 22.19682503], [88.75235748, 22.1969223], [88.7517395, 22.19693947], [88.751091, 22.19695091], [88.75042725, 22.19693947], [88.74978638, 22.19694519], [88.74917603, 22.19697189], [88.74864197, 22.19709206], [88.74819183, 22.19727135], [88.74784851, 22.19752884], [88.74758911, 22.19784927], [88.74740601, 22.19825172], [88.74724579, 22.19862938], [88.74717712, 22.19901085], [88.74720001, 22.19936752], [88.74723053, 22.19973373], [88.74732208, 22.20006943], [88.7474823, 22.20041084], [88.74761963, 22.20078087], [88.74774933, 22.20111275], [88.74784088, 22.20146179], [88.74796295, 22.20182228], [88.74804687, 22.20218086], [88.7481308, 22.20258904], [88.74820709, 22.20305061], [88.7483139, 22.20356941], [88.74843597, 22.20407677], [88.74848175, 22.20458221], [88.74833679, 22.20512009], [88.74820709, 22.20564079], [88.74825287, 22.20623589], [88.74816132, 22.2067318], [88.74806976, 22.20702171], [88.74800873, 22.20728111], [88.74788666, 22.20755959], [88.74768066, 22.207901], [88.74748993, 22.2082901], [88.74731445, 22.20874786], [88.74723053, 22.20928574], [88.74721527, 22.20987129], [88.7472229, 22.21048164], [88.74727631, 22.21109962], [88.74747467, 22.21170235], [88.74772644, 22.21229935], [88.74794006, 22.21290016], [88.74813843, 22.21347618], [88.74835205, 22.21405792], [88.74861145, 22.21463203], [88.74888611, 22.21520233], [88.7492218, 22.21570015], [88.74964905, 22.21608543], [88.75015259, 22.21637154], [88.75065613, 22.21665192], [88.75093079, 22.21704292], [88.75112152, 22.21749306], [88.75131226, 22.21796227], [88.75151825, 22.21849251], [88.75167084, 22.21909142], [88.75177765, 22.2197094], [88.75189209, 22.22031021], [88.7518692, 22.22091866], [88.75178528, 22.22153282], [88.75180054, 22.22214317], [88.7518158, 22.22276115], [88.75195313, 22.22334671], [88.75203705, 22.22393227], [88.75200653, 22.22459221], [88.75184631, 22.22525978], [88.75170898, 22.2258873], [88.75166321, 22.22651482], [88.75161743, 22.22707939], [88.75144958, 22.2275238], [88.7514267, 22.22792625], [88.7515564, 22.22823143], [88.7516861, 22.22854042], [88.75190735, 22.2288723], [88.75209808, 22.22932243], [88.75216675, 22.22982216], [88.75218964, 22.23039055], [88.75258636, 22.23091316], [88.75293732, 22.23145294], [88.7532959, 22.23180389], [88.7536087, 22.23212242], [88.75391388, 22.23246574], [88.75427246, 22.23277473], [88.75463867, 22.23307991], [88.75495148, 22.23343086], [88.75520325, 22.23379898], [88.75549316, 22.23410988], [88.75579071, 22.23444176], [88.75609589, 22.23478508], [88.7563858, 22.23517036], [88.75666046, 22.23560143], [88.75695038, 22.2360611], [88.75727081, 22.23652077], [88.75765228, 22.23693275], [88.7580719, 22.23732376], [88.75850677, 22.23769188], [88.75891113, 22.23809433], [88.75927734, 22.23851395], [88.75969696, 22.23887825], [88.76013947, 22.23921013], [88.76055145, 22.23961067], [88.76097107, 22.24003029], [88.76132202, 22.24049759], [88.76167297, 22.24098015], [88.76204681, 22.24141693], [88.76251984, 22.2415638], [88.76300049, 22.24143982], [88.76345825, 22.24139977], [88.76391602, 22.24139023], [88.76436615, 22.24135017], [88.7647934, 22.24120522], [88.7652359, 22.24112129], [88.76566315, 22.24104881], [88.76602936, 22.24084282], [88.76637268, 22.24062538], [88.76670074, 22.24039268], [88.76706696, 22.24020958], [88.76746368, 22.24011612], [88.76786804, 22.2401104], [88.76832581, 22.24028015], [88.76876831, 22.24046516], [88.76912689, 22.2406559], [88.76943207, 22.24093056], [88.76970673, 22.24131012], [88.76994324, 22.24178123], [88.76999664, 22.24239159], [88.77000427, 22.24296761], [88.77004242, 22.24343491], [88.77015686, 22.24379158], [88.77025604, 22.24411774], [88.77033234, 22.24445152], [88.77051544, 22.24478722], [88.77065277, 22.24521255], [88.77083588, 22.24563026], [88.77108002, 22.24615288], [88.77126312, 22.24668312], [88.77142334, 22.24720955], [88.77159882, 22.24770164], [88.77168274, 22.24817085], [88.77179718, 22.24860954], [88.77198792, 22.2490406], [88.77223969, 22.24945259], [88.7725296, 22.24985313], [88.77284241, 22.25021172], [88.77316284, 22.25049782], [88.77352142, 22.25070953], [88.77391052, 22.25087166], [88.77429199, 22.25105095], [88.77470398, 22.25121307], [88.77511597, 22.2514019], [88.77552795, 22.25163078], [88.77594757, 22.25180244], [88.77638245, 22.25198174], [88.77677155, 22.2522316], [88.77716827, 22.25250053], [88.77758026, 22.25277138], [88.77803802, 22.2530365], [88.77854919, 22.2532711], [88.77909088, 22.25349998], [88.77968597, 22.25367165], [88.78025055, 22.25389671], [88.78079224, 22.25415611], [88.78130341, 22.2544117], [88.78172302, 22.25475693], [88.78212738, 22.2550602], [88.78251648, 22.25537491], [88.78289032, 22.25565529], [88.78328705, 22.2558918], [88.78370667, 22.25613022], [88.78411865, 22.25638008], [88.78451538, 22.25663567], [88.78492737, 22.25687981], [88.78528595, 22.25714111], [88.78565216, 22.2573719], [88.78604889, 22.25752068], [88.78647614, 22.25766182], [88.78695679, 22.25774765], [88.78748322, 22.2577858], [88.78801727, 22.25784111], [88.78852844, 22.25798225], [88.78903961, 22.25795174], [88.78955078, 22.25778008], [88.79009247, 22.25766182], [88.79063416, 22.25781631], [88.79113007, 22.25809288], [88.79156494, 22.2584362], [88.79189301, 22.25883293], [88.7921524, 22.25920677], [88.79229736, 22.25948906], [88.79234314, 22.2595768], [88.79251099, 22.25994301], [88.79265594, 22.26028252], [88.7928009, 22.26061058], [88.79296112, 22.26092911], [88.79309082, 22.26128578], [88.79323578, 22.2616024], [88.7933197, 22.26197243], [88.79338074, 22.26231766], [88.79347992, 22.26267052], [88.79351807, 22.26309776], [88.79344177, 22.26358986], [88.79344177, 22.2641201], [88.79356384, 22.26457977], [88.79364777, 22.26501274], [88.79374695, 22.26542091], [88.79386139, 22.26582146], [88.79397583, 22.26627159], [88.79412842, 22.26679039], [88.79425049, 22.26740074], [88.79440308, 22.26805115], [88.79449463, 22.26876831], [88.79445648, 22.26943016], [88.79436493, 22.27001572], [88.79421234, 22.2704525], [88.79412842, 22.27085304], [88.79402161, 22.27114296], [88.79391479, 22.27140999], [88.79389954, 22.27160072], [88.79389191, 22.27170372], [88.79387665, 22.27200127], [88.79389954, 22.27231026], [88.79395294, 22.27262115], [88.79408264, 22.27289009], [88.7942276, 22.27321053], [88.79441071, 22.2735424], [88.79457855, 22.27393532], [88.79469299, 22.27441978], [88.79471588, 22.2749424], [88.7947464, 22.27544975], [88.79483032, 22.275877], [88.79505157, 22.27607536], [88.79537201, 22.27611351], [88.79573059, 22.27611351], [88.79611969, 22.2761097], [88.79653931, 22.27611351], [88.79698944, 22.27614021], [88.79743958, 22.27625084], [88.79792023, 22.27635193], [88.79840851, 22.27637482], [88.79890442, 22.27638626], [88.7993927, 22.27640915], [88.79982758, 22.27653885], [88.80023193, 22.27665138], [88.80065155, 22.27675056], [88.80111694, 22.27699089], [88.80162048, 22.27725792], [88.80213165, 22.27757454], [88.80260468, 22.27798271], [88.8031311, 22.27833176], [88.80364227, 22.27870178], [88.80397797, 22.27924538], [88.80434418, 22.27968407], [88.80471039, 22.28001976], [88.80487061, 22.28021431], [88.80502319, 22.28040123], [88.80535126, 22.28078461], [88.80571747, 22.28119278], [88.80599976, 22.28168488], [88.80625916, 22.2822094], [88.8065567, 22.28268814], [88.80702972, 22.28300476], [88.80763245, 22.28313255], [88.80821228, 22.28328133], [88.80878448, 22.2833252], [88.80919647, 22.28333282], [88.8093338, 22.28333473], [88.8098526, 22.28333473], [88.81037903, 22.28333473], [88.81092834, 22.28333282], [88.81150055, 22.28334236], [88.8120575, 22.28336143], [88.81259918, 22.28339195]]], [[[88.98475647, 22.38243294], [88.98454285, 22.38192558], [88.98443604, 22.38195229], [88.98443604, 22.38139153], [88.98416901, 22.38111305], [88.98416901, 22.38055992], [88.98387909, 22.38028145], [88.98387909, 22.37944221], [88.98361206, 22.37916756], [88.98361206, 22.37889481], [88.98339081, 22.37871933], [88.98327637, 22.37831116], [88.98310089, 22.37786293], [88.98303223, 22.37734795], [88.98293304, 22.37684059], [88.98281097, 22.37635231], [88.9827652, 22.3758564], [88.9826889, 22.37537575], [88.98253632, 22.37492943], [88.98249817, 22.37445259], [88.98249817, 22.3739624], [88.9825058, 22.37346077], [88.98253632, 22.37298393], [88.98261261, 22.37254143], [88.98274994, 22.37213516], [88.98278809, 22.37173271], [88.98285675, 22.37134171], [88.98309326, 22.37109184], [88.9833374, 22.37080574], [88.98358917, 22.37050438], [88.98383331, 22.37018013], [88.98400879, 22.36980247], [88.98419189, 22.36944008], [88.98443604, 22.36915016], [88.98464966, 22.36882973], [88.98483276, 22.36850166], [88.98504639, 22.3681469], [88.98529053, 22.36779213], [88.98560333, 22.36747169], [88.98596191, 22.36717606], [88.98628235, 22.36678123], [88.98661804, 22.36637115], [88.98697662, 22.36594963], [88.98738861, 22.36557961], [88.98784637, 22.36526108], [88.9882431, 22.36489296], [88.98848724, 22.36438942], [88.9885788, 22.36387444], [88.98848724, 22.36339378], [88.98843384, 22.3632946], [88.98826599, 22.36297798], [88.98800659, 22.3625927], [88.98770142, 22.36229134], [88.98735809, 22.36203384], [88.9871521, 22.36160278], [88.98693848, 22.36111259], [88.98674011, 22.36061287], [88.98651886, 22.36012077], [88.98629761, 22.35963821], [88.98607635, 22.35917091], [88.98589325, 22.35868263], [88.98576355, 22.35815239], [88.9855957, 22.35767555], [88.98555756, 22.35749817], [88.98555756, 22.3572216], [88.98527527, 22.35694885], [88.9852829, 22.35583305], [88.98555756, 22.3555584], [88.98560333, 22.35489082], [88.98580933, 22.35436058], [88.98596191, 22.3537674], [88.98612976, 22.35318947], [88.98633575, 22.35270691], [88.98649597, 22.3522625], [88.98671722, 22.35189247], [88.98693085, 22.35153008], [88.98710632, 22.35112953], [88.98731995, 22.35072327], [88.98751831, 22.35022163], [88.98768616, 22.3496418], [88.98755646, 22.34893227], [88.98742676, 22.34818077], [88.98722076, 22.34754372], [88.98698425, 22.34697342], [88.98678589, 22.34641075], [88.9866333, 22.34581947], [88.98643494, 22.34528542], [88.98636627, 22.34476471], [88.98626709, 22.34434319], [88.98612213, 22.34399223], [88.98600769, 22.34361839], [88.98587036, 22.3431797], [88.98577881, 22.34263611], [88.98560333, 22.34208107], [88.98542786, 22.3415451], [88.98526764, 22.34106827], [88.98512268, 22.34065628], [88.98506165, 22.34023094], [88.98499298, 22.33982277], [88.98487091, 22.33946037], [88.98474884, 22.33910942], [88.98471832, 22.33871269], [88.98464966, 22.33828926], [88.98445129, 22.33790016], [88.98426056, 22.33741188], [88.98416138, 22.33681488], [88.98404694, 22.33617973], [88.98390198, 22.33562279], [88.98374939, 22.33513069], [88.98365784, 22.33468437], [88.98361969, 22.33426094], [88.98361206, 22.33384132], [88.98361206, 22.33341026], [88.98361206, 22.33297157], [88.98364258, 22.3325119], [88.98375702, 22.33205986], [88.98387146, 22.33161926], [88.98387146, 22.33117104], [88.98377228, 22.33073235], [88.98364258, 22.33031464], [88.98361206, 22.32986259], [88.98356628, 22.3293972], [88.98340607, 22.32892036], [88.98335266, 22.32835007], [88.98332977, 22.3277626], [88.98332977, 22.32718468], [88.98332977, 22.32667351], [88.9833374, 22.32625008], [88.98336792, 22.32590485], [88.98350525, 22.32564354], [88.98361206, 22.32533836], [88.98375702, 22.32502174], [88.98400116, 22.32471275], [88.98433685, 22.32441711], [88.98472595, 22.32407188], [88.98517609, 22.32370949], [88.98564148, 22.32333374], [88.98607635, 22.32295036], [88.98648834, 22.32254982], [88.98675537, 22.32236671], [88.98693848, 22.32224083], [88.98741913, 22.32201958], [88.98789215, 22.32183266], [88.9883728, 22.32167053], [88.98880768, 22.3215313], [88.98923492, 22.32141685], [88.98964691, 22.32130623], [88.99006653, 22.3211422], [88.9905777, 22.32111168], [88.99113464, 22.32111168], [88.99169159, 22.32111168], [88.99220276, 22.32111168], [88.99263, 22.32114983], [88.99300385, 22.32130623], [88.99343109, 22.32141495], [88.99391937, 22.32155037], [88.99446106, 22.32169151], [88.99501801, 22.32190132], [88.99563599, 22.32201195], [88.99619293, 22.32222366], [88.99672699, 22.32243347], [88.99729919, 22.32261086], [88.99778748, 22.32285118], [88.99824524, 22.32301521], [88.9988327, 22.32315636], [89.0, 22.32333565], [89.00027466, 22.32305717], [89.00035095, 22.32285118], [89.00071716, 22.32261086], [89.00093842, 22.32232094], [89.00112152, 22.3221283], [89.00152588, 22.32180023], [89.00164795, 22.32149506], [89.00203705, 22.32102013], [89.00219727, 22.32058334], [89.0025177, 22.32029152], [89.00283813, 22.32000542], [89.00315857, 22.31972313], [89.00345612, 22.31944084], [89.00378418, 22.31917191], [89.00414276, 22.31887817], [89.00454712, 22.31851006], [89.00492859, 22.31836128], [89.00548553, 22.31773567], [89.00591278, 22.31734276], [89.0063858, 22.31699181], [89.00688171, 22.3166523], [89.00733948, 22.31625748], [89.00777435, 22.31588936], [89.00820923, 22.31567383], [89.00875092, 22.31541252], [89.00900269, 22.3150444], [89.00948334, 22.31484032], [89.00984192, 22.31414223], [89.01027679, 22.31386185], [89.01065826, 22.3135128], [89.01099396, 22.31313515], [89.01122284, 22.31266975], [89.0114212, 22.31222725], [89.0116272, 22.31182289], [89.01179504, 22.31142807], [89.01200104, 22.31113243], [89.01220703, 22.31086731], [89.01235962, 22.31060219], [89.01252747, 22.31032944], [89.01274109, 22.31007385], [89.0129776, 22.30978012], [89.01313782, 22.30938148], [89.01333618, 22.30895042], [89.01357269, 22.30852509], [89.01378632, 22.30807495], [89.01402283, 22.30764008], [89.01428223, 22.30724144], [89.01456451, 22.30689812], [89.0147934, 22.30648232], [89.01511383, 22.30613136], [89.01548767, 22.30583382], [89.01586151, 22.30553627], [89.01621246, 22.30521011], [89.01656342, 22.30485916], [89.01695251, 22.30447388], [89.01729584, 22.30408287], [89.01756287, 22.30367088], [89.01783752, 22.30334282], [89.01809692, 22.3030529], [89.01838684, 22.30278969], [89.01869965, 22.30254364], [89.01906586, 22.30231285], [89.01940155, 22.30202293], [89.01976776, 22.30173302], [89.02015686, 22.30149269], [89.02046967, 22.3012085], [89.02076721, 22.30096245], [89.02097321, 22.30067444], [89.02119446, 22.30052185], [89.02140045, 22.3003521], [89.02163696, 22.30014229], [89.02189636, 22.29988289], [89.02217102, 22.29965019], [89.02242279, 22.29940224], [89.02258301, 22.29910088], [89.02269745, 22.29873276], [89.02278137, 22.29861259], [89.02297211, 22.29841995], [89.02305603, 22.29833221], [89.02305603, 22.29777718], [89.02333069, 22.29750252], [89.02326202, 22.29585075], [89.02222443, 22.29534531], [89.02126312, 22.29535294], [89.02083588, 22.29556274], [89.02027893, 22.29555511], [89.0201416, 22.29569435], [89.01999664, 22.29583549], [89.01976776, 22.29582024], [89.0194931, 22.29580879], [89.01904297, 22.29588127], [89.01862335, 22.29607773], [89.01815796, 22.29619026], [89.01773071, 22.29639244], [89.01728058, 22.29659271], [89.01678467, 22.29672813], [89.01637268, 22.29693031], [89.01596832, 22.29709053], [89.01552582, 22.29723167], [89.01512909, 22.29737282], [89.01474762, 22.29751015], [89.01439667, 22.29767036], [89.01399231, 22.29781151], [89.01358795, 22.29803085], [89.01309967, 22.29816437], [89.01264954, 22.29834938], [89.01223755, 22.29857063], [89.0117569, 22.29866028], [89.01135254, 22.29885292], [89.01091766, 22.29889107], [89.01046753, 22.29889107], [89.01000214, 22.29889107], [89.00952148, 22.29893112], [89.00904846, 22.29913139], [89.00853729, 22.29916954], [89.00802612, 22.29915047], [89.00752258, 22.29906082], [89.00701141, 22.29892159], [89.00647736, 22.29889107], [89.0059433, 22.29884148], [89.00547028, 22.29864883], [89.00493622, 22.29853439], [89.00444031, 22.29832649], [89.00391388, 22.29810143], [89.00331879, 22.29803276], [89.00273132, 22.29797173], [89.00225067, 22.29781151], [89.00179291, 22.29777718], [89.00138092, 22.29776955], [89.00098419, 22.29778862], [89.00061798, 22.29788399], [89.00028992, 22.29806328], [89.0, 22.29805565], [88.99923706, 22.29762268], [88.9990387, 22.29748154], [88.99868011, 22.29736137], [88.99825287, 22.29718971], [88.99781799, 22.29699707], [88.99738312, 22.29681969], [88.99701691, 22.29660988], [88.99668121, 22.2963829], [88.99636078, 22.29611015], [88.99599457, 22.29583549], [88.99556732, 22.29552269], [88.99521637, 22.29507828], [88.99482727, 22.29466057], [88.99454498, 22.29420471], [88.99433136, 22.29377937], [88.99415588, 22.29342079], [88.99396515, 22.29309845], [88.99385071, 22.29266357], [88.99365234, 22.29222298], [88.9936142, 22.29168892], [88.99360657, 22.29116249], [88.99360657, 22.29067039], [88.99365234, 22.29020119], [88.9937973, 22.28979111], [88.99384308, 22.28936195], [88.9936676, 22.28891182], [88.9936142, 22.28845787], [88.99360657, 22.28802109], [88.99362946, 22.28761292], [88.99373627, 22.28725243], [88.99386597, 22.28692055], [88.99388885, 22.28666687], [88.99388885, 22.28611183], [88.99416351, 22.28583336], [88.99416351, 22.28555489], [88.9944458, 22.28528023], [88.99449158, 22.28495979], [88.99472809, 22.28466225], [88.99500275, 22.28433037], [88.99529266, 22.28393936], [88.99562073, 22.28355026], [88.99603271, 22.28313255], [88.99643707, 22.28263283], [88.99695587, 22.28223228], [88.99754333, 22.28188324], [88.99767303, 22.28178978], [88.99806213, 22.28149605], [88.9985733, 22.28116035], [88.99901581, 22.28084183], [88.99944305, 22.28055573], [88.99973297, 22.28056335], [89.0, 22.28028107], [89.00026703, 22.28000069], [89.00041962, 22.27999306], [89.00077057, 22.27968025], [89.00133514, 22.27922058], [89.00185394, 22.27882576], [89.00226593, 22.27841187], [89.00269318, 22.27806282], [89.00309753, 22.27775002], [89.00350952, 22.27748299], [89.00390625, 22.2772007], [89.00431824, 22.27692986], [89.00467682, 22.27663994], [89.00501251, 22.27635193], [89.00535583, 22.27605247], [89.00576019, 22.27575111], [89.00614166, 22.27537346], [89.00654602, 22.27501488], [89.00696564, 22.27470589], [89.00737762, 22.27444267], [89.00775909, 22.27416039], [89.00814056, 22.27388954], [89.00850677, 22.27362251], [89.0089035, 22.27340126], [89.00930023, 22.2732029], [89.00969696, 22.27298164], [89.01008606, 22.27272224], [89.01048279, 22.27246857], [89.01088715, 22.27218056], [89.01135254, 22.27193642], [89.01185608, 22.27166939], [89.01241302, 22.27139091], [89.01296997, 22.27111244], [89.01355743, 22.27083778], [89.01416016, 22.27056313], [89.01477814, 22.27028084], [89.01542664, 22.26998138], [89.01608276, 22.2696209], [89.01670074, 22.26918221], [89.01730347, 22.26877975], [89.01774597, 22.26831245], [89.01799011, 22.26782036], [89.01802063, 22.26738167], [89.01790619, 22.26704979], [89.01779175, 22.26675224], [89.01766968, 22.26643944], [89.01745605, 22.26614952], [89.01715851, 22.26585388], [89.0167923, 22.26553535], [89.01642609, 22.26517487], [89.01609802, 22.2647419], [89.01573181, 22.26434135], [89.01535034, 22.26396942], [89.01496124, 22.26361847], [89.0145874, 22.26329994], [89.014328, 22.26293945], [89.01410675, 22.26257133], [89.01387024, 22.26229286], [89.01360321, 22.26202965], [89.01331329, 22.26173973], [89.01300049, 22.2614212], [89.01270294, 22.2610817], [89.01246643, 22.26066017], [89.01223755, 22.26025963], [89.01206207, 22.25984192], [89.01191711, 22.25942039], [89.01173401, 22.25904083], [89.0116272, 22.25862312], [89.01143646, 22.25825119], [89.01139069, 22.2578373], [89.01138306, 22.2574234], [89.01138306, 22.25700188], [89.01139069, 22.25658226], [89.01143646, 22.25617027], [89.01161957, 22.25583267], [89.01169586, 22.25544548], [89.01182556, 22.2551136], [89.01195526, 22.25481415], [89.01210022, 22.25455856], [89.01222992, 22.254282], [89.01237488, 22.25401115], [89.01252747, 22.25373268], [89.01272583, 22.25350571], [89.01285553, 22.25327492], [89.01301575, 22.25307274], [89.01316833, 22.25279045], [89.01342773, 22.25250435], [89.01380157, 22.25221825], [89.01419067, 22.2519207], [89.01454926, 22.25159836], [89.01494598, 22.25140953], [89.01535034, 22.25129128], [89.01571655, 22.2511425], [89.01609802, 22.25111198], [89.01651001, 22.25111198], [89.01695251, 22.25111198], [89.01737213, 22.25111198], [89.01777649, 22.25112152], [89.01818085, 22.25117111], [89.01838684, 22.25126076], [89.01856995, 22.25134277], [89.01900482, 22.25140572], [89.0194397, 22.25152016], [89.01986694, 22.25169373], [89.02028656, 22.25192833], [89.02074432, 22.25212479], [89.02125549, 22.25227356], [89.021698, 22.2524929], [89.02210999, 22.25278282], [89.02249908, 22.25306892], [89.0228653, 22.25340462], [89.02327728, 22.2537117], [89.02366638, 22.25407219], [89.02411652, 22.25438118], [89.02458191, 22.25462532], [89.02492523, 22.25492668], [89.02523804, 22.25523567], [89.02558136, 22.25552368], [89.02596283, 22.25580025], [89.02639008, 22.25604057], [89.02683258, 22.25627327], [89.0273056, 22.25647163], [89.02777863, 22.25668144], [89.02823639, 22.25694466], [89.02869415, 22.25720406], [89.02919006, 22.25738335], [89.02970123, 22.25748634], [89.03022766, 22.25753212], [89.03073883, 22.25766945], [89.03130341, 22.25774193], [89.03188324, 22.25762367], [89.03239441, 22.25729942], [89.0327301, 22.25681114], [89.03291321, 22.25626183], [89.03308105, 22.25576591], [89.03327942, 22.25536919], [89.03340149, 22.25494385], [89.03354645, 22.25452995], [89.03357697, 22.25405312], [89.03347015, 22.25355339], [89.03335571, 22.25318909], [89.03333282, 22.25285149], [89.0333786, 22.25252724], [89.03356171, 22.25222206], [89.03360748, 22.25187111], [89.03361511, 22.25152016], [89.03360748, 22.2511692], [89.03360748, 22.25081062], [89.03362274, 22.25043106], [89.03364563, 22.25003433], [89.03379822, 22.24964523], [89.03386688, 22.24920273], [89.03388977, 22.24872017], [89.03388977, 22.24821281], [89.03388977, 22.24770164], [89.03394318, 22.2471714], [89.03412628, 22.24668312], [89.0341568, 22.24617958], [89.03417206, 22.24570847], [89.0341568, 22.24527168], [89.0341568, 22.24483299], [89.03411102, 22.24440002], [89.03404999, 22.24397087], [89.03414154, 22.24353981], [89.03416443, 22.24309921], [89.03417206, 22.24266243], [89.03421021, 22.24224281], [89.03439331, 22.24186134], [89.03443909, 22.24144173], [89.03444672, 22.24101067], [89.03444672, 22.24057388], [89.03443909, 22.24012756], [89.03439331, 22.23967361], [89.03424835, 22.23925591], [89.03417969, 22.23884392], [89.03417969, 22.23841667], [89.03426361, 22.23797607], [89.0344162, 22.23755074], [89.03444672, 22.23714256], [89.03444672, 22.23672295], [89.03444672, 22.23628044], [89.03444672, 22.23578453], [89.03446198, 22.23522377], [89.03450012, 22.23464584], [89.03448486, 22.23409081], [89.03452301, 22.23359108], [89.03469086, 22.23316193], [89.03482056, 22.23270226], [89.03501129, 22.23229027], [89.0352478, 22.23192978], [89.03540802, 22.23155022], [89.03555298, 22.23120308], [89.03566742, 22.2308712], [89.03579712, 22.23056984], [89.03582764, 22.23020172], [89.0358429, 22.22980309], [89.03591156, 22.2293911], [89.03607941, 22.22899055], [89.03620148, 22.22854042], [89.03637695, 22.22809029], [89.03656006, 22.2276268], [89.03679657, 22.22719002], [89.03704834, 22.22671318], [89.03734589, 22.22626114], [89.03762817, 22.22584343], [89.03786469, 22.2254734], [89.03807068, 22.22515106], [89.03826904, 22.22488976], [89.03839111, 22.22459221], [89.03859711, 22.22435951], [89.03881073, 22.22411156], [89.03900146, 22.22380257], [89.03926849, 22.22351456], [89.03956604, 22.22319984], [89.03983307, 22.22282219], [89.04012299, 22.22247314], [89.0404129, 22.22213173], [89.040802, 22.22189522], [89.04125214, 22.22162056], [89.04170227, 22.22124481], [89.04218292, 22.22087288], [89.04265594, 22.22051048], [89.04304504, 22.22013092], [89.04340363, 22.21976089], [89.04377747, 22.21941948], [89.04413605, 22.21906662], [89.04447174, 22.21870232], [89.04482269, 22.21837044], [89.04521942, 22.2181015], [89.04559326, 22.2177906], [89.0460434, 22.21750069], [89.04653168, 22.21720314], [89.04701996, 22.21686172], [89.0474472, 22.21646309], [89.04789734, 22.21611977], [89.04834747, 22.21580315], [89.04875183, 22.21542358], [89.04915619, 22.21500969], [89.04956818, 22.21461487], [89.04995728, 22.21426392], [89.05028534, 22.21390152], [89.05060577, 22.21359825], [89.05090332, 22.21329308], [89.0512619, 22.21302223], [89.05162048, 22.21270943], [89.05198669, 22.21235085], [89.05240631, 22.21203613], [89.05284882, 22.21170235], [89.0533371, 22.21138191], [89.05383301, 22.21101189], [89.0542984, 22.21055031], [89.05475616, 22.21006203], [89.05526733, 22.20961189], [89.05576324, 22.20916939], [89.05623627, 22.20874977], [89.05673218, 22.20833206], [89.05725098, 22.20789909], [89.05780792, 22.2074585], [89.05835724, 22.20696068], [89.0589447, 22.20645905], [89.05956268, 22.2059803], [89.060112, 22.20541954], [89.06062317, 22.20480537], [89.061203, 22.20425987], [89.06183624, 22.20380974], [89.06243896, 22.20330429], [89.06301117, 22.20276833], [89.06358337, 22.20222282], [89.06416321, 22.20166969], [89.06471252, 22.20111275], [89.06521606, 22.20051003], [89.0656662, 22.19989395], [89.06612396, 22.19933319], [89.06655884, 22.19883537], [89.0667572, 22.19853592], [89.06690216, 22.19831467], [89.06716156, 22.19782829], [89.06735992, 22.19738007], [89.06755066, 22.19701195], [89.06774139, 22.19671059], [89.06783295, 22.19638252], [89.06800842, 22.19612312], [89.06812286, 22.19579124], [89.0683136, 22.19545364], [89.0684433, 22.19502068], [89.06859589, 22.19456482], [89.06873322, 22.19406319], [89.06886292, 22.19355202], [89.06893158, 22.19302177], [89.06908417, 22.19255638], [89.06915283, 22.19205284], [89.06916809, 22.19153023], [89.06916809, 22.19099808], [89.06916809, 22.19046783], [89.06912231, 22.18993378], [89.06893158, 22.18943024], [89.06887817, 22.18925095], [89.06876373, 22.18889236], [89.06858826, 22.18836594], [89.06833649, 22.18788528], [89.06806946, 22.18740273], [89.06785583, 22.18688393], [89.06770325, 22.18633461], [89.06749725, 22.18586159], [89.067276, 22.18546104], [89.06713104, 22.18509293], [89.06691742, 22.18482018], [89.06667328, 22.18460464], [89.06642151, 22.18433571], [89.06619263, 22.18397141], [89.06591797, 22.18354988], [89.06569672, 22.18305016], [89.06549835, 22.18254471], [89.06526947, 22.18206215], [89.06500244, 22.18161201], [89.06471252, 22.18116951], [89.06437683, 22.18077278], [89.06401062, 22.18040466], [89.06368256, 22.18004036], [89.06346893, 22.17956734], [89.06328583, 22.17904091], [89.06304932, 22.17850304], [89.06277466, 22.17796326], [89.0625, 22.17742729], [89.06223297, 22.17691231], [89.06197357, 22.17640114], [89.06181335, 22.17583275], [89.06165314, 22.17523003], [89.06143188, 22.17463493], [89.06137085, 22.17398262], [89.06125641, 22.17337227], [89.06112671, 22.17282295], [89.06111145, 22.17233849], [89.06111145, 22.1718998], [89.06109619, 22.17148018], [89.06103516, 22.17106628], [89.06086731, 22.17065048], [89.06083679, 22.17016792], [89.06082916, 22.16963005], [89.06082916, 22.1690731], [89.06082916, 22.16847038], [89.06082916, 22.16788483], [89.06083679, 22.16731071], [89.06086731, 22.1667614], [89.06104279, 22.16626167], [89.06111908, 22.16571808], [89.06122589, 22.16516304], [89.061409, 22.16462135], [89.06165314, 22.16408157], [89.0617981, 22.16348076], [89.06195068, 22.16286278], [89.06210327, 22.16222954], [89.06227112, 22.16163445], [89.06250763, 22.16110992], [89.06273651, 22.16064453], [89.06286621, 22.1601696], [89.06304169, 22.15976715], [89.06328583, 22.15942192], [89.06342316, 22.15895653], [89.06362915, 22.15850258], [89.06388092, 22.15802956], [89.06414032, 22.15752792], [89.06437683, 22.15701103], [89.06462097, 22.15649223], [89.06486511, 22.15597725], [89.06510925, 22.15543175], [89.06532288, 22.15480995], [89.06556702, 22.1541996], [89.06583405, 22.15361786], [89.06609344, 22.15306282], [89.06626129, 22.15250206], [89.06640625, 22.15195274], [89.06658173, 22.15145874], [89.06671906, 22.15097237], [89.06692505, 22.15056801], [89.06707001, 22.15015984], [89.06723785, 22.14977837], [89.06745148, 22.14941978], [89.06754303, 22.14898682], [89.06777191, 22.1486187], [89.06803131, 22.14825249], [89.06830597, 22.14780998], [89.06864166, 22.14736176], [89.06906128, 22.14692116], [89.06951141, 22.14647675], [89.07002258, 22.14612007], [89.07054901, 22.14582825], [89.07104492, 22.14557457], [89.07156372, 22.14537621], [89.07205963, 22.14517021], [89.07254791, 22.14497948], [89.07299042, 22.14478111], [89.07348633, 22.14471817], [89.07403564, 22.14469337], [89.07462311, 22.14456367], [89.07524109, 22.14451027], [89.07582092, 22.14467812], [89.0763855, 22.14471817], [89.07686615, 22.14476395], [89.0772934, 22.1449604], [89.0777359, 22.14503479], [89.07822418, 22.1451683], [89.07879639, 22.1453228], [89.07938385, 22.14555931], [89.07995605, 22.14583015], [89.080513, 22.14611244], [89.08102417, 22.14641953], [89.08149719, 22.14678001], [89.08194733, 22.14719772], [89.08248901, 22.14755058], [89.08303833, 22.14792061], [89.08354187, 22.14830971], [89.08403015, 22.14864159], [89.08441925, 22.14900398], [89.08474731, 22.14939308], [89.08505249, 22.14977074], [89.08537292, 22.15010262], [89.08569336, 22.15041351], [89.08599854, 22.15072823], [89.08629608, 22.15109253], [89.08661652, 22.15142822], [89.08693695, 22.15177917], [89.08722687, 22.15213013], [89.08751678, 22.15246391], [89.08779907, 22.15281105], [89.0880661, 22.15322304], [89.08840179, 22.1536808], [89.08877563, 22.15418625], [89.08920288, 22.15474129], [89.08966064, 22.15528297], [89.09011078, 22.15579605], [89.09052277, 22.15622139], [89.09085846, 22.15660667], [89.09117889, 22.15692329], [89.09153748, 22.15721321], [89.09200287, 22.15749168], [89.09255219, 22.15777016], [89.09320831, 22.15793037], [89.09388733, 22.15773964], [89.0944519, 22.15730095], [89.09497833, 22.15684319], [89.0954361, 22.15638161], [89.09580994, 22.15593529], [89.09609222, 22.15549278], [89.09626007, 22.15501213], [89.09636688, 22.15453148], [89.09634399, 22.15405083], [89.09612274, 22.15361977], [89.09585571, 22.15320396], [89.09576416, 22.15303802], [89.09560394, 22.15275955], [89.0953598, 22.15232658], [89.09506226, 22.15194893], [89.09474945, 22.15160179], [89.09443665, 22.15123177], [89.09414673, 22.15086746], [89.09384918, 22.15050316], [89.09361267, 22.15007973], [89.09335327, 22.14963913], [89.09313965, 22.14917755], [89.09288788, 22.14873314], [89.0925827, 22.14834023], [89.09224701, 22.14796257], [89.09195709, 22.14752007], [89.09168243, 22.14710808], [89.09142303, 22.14672279], [89.09111023, 22.14639091], [89.09075165, 22.14603806], [89.09029388, 22.14570236], [89.08979034, 22.14529991], [89.08921814, 22.14492226], [89.08866882, 22.14450645], [89.08811188, 22.14411163], [89.08757019, 22.1436882], [89.08695221, 22.14334488], [89.08631134, 22.14305305], [89.08570862, 22.14275169], [89.08516693, 22.1423912], [89.08470154, 22.14203072], [89.08423615, 22.14176178], [89.08374786, 22.1416111], [89.08332825, 22.14138985], [89.08294678, 22.14117241], [89.08251953, 22.14101982], [89.08207703, 22.14081192], [89.08165741, 22.14054108], [89.08122253, 22.14025116], [89.08080292, 22.13993263], [89.08031464, 22.13970375], [89.07985687, 22.13944435], [89.07942963, 22.13918114], [89.07897949, 22.13897133], [89.07854462, 22.13878822], [89.07816315, 22.13845253], [89.07772064, 22.13812256], [89.07718658, 22.13780975], [89.07662201, 22.13746071], [89.07609558, 22.13705826], [89.07555389, 22.13668251], [89.07501221, 22.13638306], [89.07453918, 22.13608932], [89.0741272, 22.13580132], [89.07373047, 22.13555336], [89.07337189, 22.1353054], [89.07306671, 22.13502312], [89.0727005, 22.13480377], [89.07228088, 22.13465118], [89.07184601, 22.13443184], [89.07144165, 22.13417053], [89.07102203, 22.13392067], [89.07059479, 22.13371086], [89.07022095, 22.13345146], [89.06980896, 22.13326073], [89.06945038, 22.13300133], [89.06909943, 22.13272667], [89.06871796, 22.13247681], [89.06835175, 22.13218307], [89.06797791, 22.13188362], [89.06757355, 22.13161087], [89.06716919, 22.13129234], [89.06674957, 22.13102531], [89.06639099, 22.13069344], [89.06603241, 22.13038254], [89.06561279, 22.13018227], [89.06522369, 22.12994957], [89.06481171, 22.12972069], [89.06439209, 22.12952232], [89.06394958, 22.12936783], [89.06356049, 22.12915993], [89.0632019, 22.1289196], [89.06285095, 22.12874031], [89.06250763, 22.12859344], [89.06218719, 22.12842941], [89.06186676, 22.12836075], [89.06156158, 22.12849236], [89.06128693, 22.1289196], [89.06114197, 22.12948036], [89.06111145, 22.13010216], [89.06111145, 22.13075066], [89.06105804, 22.13140678], [89.06083679, 22.13205528], [89.06062317, 22.13274574], [89.06051636, 22.13348389], [89.06031799, 22.13414955], [89.06022644, 22.13478279], [89.06005096, 22.13526917], [89.05999756, 22.1356926], [89.05993652, 22.13600731], [89.05979156, 22.13625145], [89.05973053, 22.13653564], [89.05967712, 22.13691139], [89.05944824, 22.13731956], [89.05918121, 22.13778114], [89.05893707, 22.13826942], [89.05867004, 22.13866615], [89.05844116, 22.13904381], [89.05815125, 22.13935661], [89.05784607, 22.13973236], [89.05745697, 22.14017105], [89.05700684, 22.14067841], [89.05658722, 22.14130974], [89.05609131, 22.14191628], [89.05555725, 22.14249229], [89.05500793, 22.14304543], [89.05444336, 22.14355278], [89.05387878, 22.14402962], [89.05332184, 22.14447594], [89.05280304, 22.14495277], [89.05220032, 22.1453228], [89.05166626, 22.14556313], [89.05055237, 22.14666939], [89.05027771, 22.14666939], [89.05000305, 22.14694405], [89.04966736, 22.14692116], [89.04927063, 22.14697838], [89.04882813, 22.14715385], [89.04836273, 22.14730263], [89.04792786, 22.14747047], [89.04750061, 22.14761162], [89.04707336, 22.14774513], [89.04660034, 22.14785385], [89.04612732, 22.14806366], [89.04566193, 22.14830971], [89.04515076, 22.14846611], [89.04466248, 22.14863586], [89.04420471, 22.1488533], [89.04370117, 22.14896393], [89.04325104, 22.14912987], [89.04273224, 22.14920807], [89.04224396, 22.14938927], [89.04176331, 22.14949226], [89.04129028, 22.149683], [89.04078674, 22.14977074], [89.04032135, 22.14996147], [89.03981018, 22.15010834], [89.03933716, 22.15036201], [89.03891754, 22.1505909], [89.03852844, 22.15082741], [89.03812408, 22.15105438], [89.03777313, 22.1512928], [89.03749847, 22.15139389], [89.03694153, 22.15167046], [89.03610992, 22.15250206], [89.0358429, 22.15250206], [89.03549194, 22.15275192], [89.0351944, 22.15286636], [89.03491974, 22.15310287], [89.03457642, 22.15332985], [89.03418732, 22.15361977], [89.03383636, 22.15403938], [89.03343964, 22.1544323], [89.03299713, 22.1547699], [89.03253174, 22.15510178], [89.03206635, 22.15545273], [89.0316925, 22.15585136], [89.03141022, 22.15628624], [89.0311203, 22.15668106], [89.03083801, 22.15708542], [89.03056335, 22.15748024], [89.03022003, 22.15784264], [89.02986908, 22.15818977], [89.02951813, 22.15854645], [89.02921295, 22.15895271], [89.02893066, 22.1593914], [89.02861786, 22.15979195], [89.02828979, 22.16019249], [89.02794647, 22.16054726], [89.02760315, 22.16089058], [89.02732849, 22.16127968], [89.02705383, 22.1616497], [89.02672577, 22.16196251], [89.02639008, 22.16226578], [89.02600861, 22.16251945], [89.02561951, 22.16276932], [89.02532196, 22.16316032], [89.02507019, 22.16358757], [89.02478027, 22.16397285], [89.02449799, 22.16436958], [89.02418518, 22.16470528], [89.02385712, 22.16502953], [89.02352905, 22.16538048], [89.02323914, 22.16579819], [89.02294922, 22.16626167], [89.02280426, 22.16685486], [89.022789, 22.16750145], [89.02288818, 22.16813087], [89.02310944, 22.16864967], [89.02333832, 22.16909981], [89.0235672, 22.16950226], [89.02365875, 22.16995239], [89.02388, 22.17033958], [89.02407837, 22.17075729], [89.02423096, 22.17123985], [89.02441406, 22.1717205], [89.02452087, 22.1722641], [89.02468872, 22.17278481], [89.02476501, 22.17335129], [89.02496338, 22.17389107], [89.02503967, 22.17450142], [89.02523041, 22.17508125], [89.02539825, 22.17567253], [89.02558899, 22.17622185], [89.02583313, 22.17671394], [89.02605438, 22.17721748], [89.02612305, 22.17781258], [89.02614594, 22.17843056], [89.02632141, 22.17901039], [89.02641296, 22.1795826], [89.02649689, 22.18008995], [89.02662659, 22.18054008], [89.02666473, 22.18102074], [89.02666473, 22.18151474], [89.02666473, 22.18200684], [89.02671051, 22.18248177], [89.02690125, 22.1829319], [89.02693939, 22.18342018], [89.02694702, 22.18393326], [89.02694702, 22.18447495], [89.02697754, 22.18499756], [89.0271759, 22.18546104], [89.02722168, 22.18590736], [89.02722168, 22.18632317], [89.02722168, 22.18669319], [89.02722168, 22.18701553], [89.02722168, 22.18734169], [89.02720642, 22.18771172], [89.02716064, 22.18808937], [89.02697754, 22.18850136], [89.02692413, 22.18896294], [89.02683258, 22.18940163], [89.02669525, 22.18982124], [89.02667236, 22.19028473], [89.0266571, 22.19080162], [89.02661896, 22.19136238], [89.02643585, 22.1919384], [89.02635193, 22.19257736], [89.02619171, 22.19315147], [89.02612305, 22.19371223], [89.02610779, 22.19424248], [89.02606201, 22.19472313], [89.02587891, 22.19513893], [89.02583313, 22.19555092], [89.02575684, 22.19589996], [89.0256424, 22.19616127], [89.02561951, 22.19641685], [89.0255661, 22.19663048], [89.02548218, 22.1968708], [89.02529907, 22.19715309], [89.02513123, 22.19749832], [89.02497101, 22.19787025], [89.02475739, 22.19820023], [89.02458954, 22.19859123], [89.02437592, 22.19895935], [89.02415466, 22.19935608], [89.02389526, 22.19978142], [89.02364349, 22.20026207], [89.02342224, 22.20079994], [89.02312469, 22.20132256], [89.02278137, 22.20181465], [89.02240753, 22.20230484], [89.02198029, 22.20275307], [89.02153778, 22.20319366], [89.02117157, 22.20364952], [89.02083588, 22.20408249], [89.02056122, 22.20444489], [89.02027893, 22.2047596], [89.02002716, 22.20506287], [89.0197525, 22.20538712], [89.01972198, 22.20555305], [89.01860809, 22.20667076], [89.01750183, 22.20666695], [89.01721954, 22.20694542], [89.01667023, 22.2069416], [89.01655579, 22.20705986], [89.01625824, 22.20724297], [89.01593781, 22.20747566], [89.01555634, 22.20767021], [89.01516724, 22.20788193], [89.01473236, 22.20807076], [89.01432037, 22.20829773], [89.01383209, 22.20841026], [89.01340485, 22.20861816], [89.01298523, 22.20887184], [89.01248932, 22.20906258], [89.01194763, 22.20926094], [89.01139069, 22.20946312], [89.01081085, 22.20968056], [89.01019287, 22.2097683], [89.00962067, 22.20996284], [89.00901794, 22.21016502], [89.00845337, 22.21043968], [89.00785828, 22.21068764], [89.00720978, 22.2107029], [89.00658417, 22.21080971], [89.0059967, 22.2108326], [89.00547791, 22.21083641], [89.00501251, 22.2108326], [89.00457764, 22.2108326], [89.00415802, 22.2108326], [89.00374603, 22.21088219], [89.00332642, 22.2110424], [89.0029068, 22.21096992], [89.00248718, 22.21089935], [89.00206757, 22.21104813], [89.0016098, 22.21113014], [89.00110626, 22.21115494], [89.00057983, 22.21120644], [89.00028992, 22.21157455], [89.0, 22.21194649], [88.99907684, 22.21123886], [88.99858856, 22.21086311], [88.9972229, 22.21024132], [88.99674988, 22.21003151], [88.99624634, 22.20985985], [88.99575043, 22.20968056], [88.9952774, 22.20944023], [88.99481201, 22.20920372], [88.9943161, 22.20903969], [88.9937973, 22.20885277], [88.99333191, 22.20860863], [88.99286652, 22.20833015], [88.99239349, 22.2080555], [88.99188995, 22.20778084], [88.99137115, 22.20750809], [88.99079132, 22.20729637], [88.99017334, 22.20713234], [88.98956299, 22.20702171], [88.98916626, 22.20681953], [88.98880005, 22.20659637], [88.98844147, 22.20637131], [88.98807526, 22.20615578], [88.98763275, 22.20604134], [88.98724365, 22.2058754], [88.98678589, 22.20577049], [88.98628235, 22.20560265], [88.98568726, 22.20556068], [88.9850769, 22.20556068], [88.98452759, 22.20557976], [88.98404694, 22.20568657], [88.98361206, 22.20581055], [88.98317719, 22.20591164], [88.98278809, 22.20609283], [88.98236084, 22.20618248], [88.98191833, 22.20620155], [88.98152161, 22.20634842], [88.98107147, 22.20643044], [88.98062897, 22.20660973], [88.9801178, 22.20671272], [88.97962189, 22.20689201], [88.97910309, 22.20704079], [88.97863007, 22.20724297], [88.97822571, 22.20748711], [88.97782898, 22.20770264], [88.97735596, 22.20779228], [88.97691345, 22.2079525], [88.97644806, 22.2080822], [88.97601318, 22.20829964], [88.97548676, 22.20843124], [88.97499084, 22.20863152], [88.97450256, 22.20884514], [88.97398376, 22.20897484], [88.97348785, 22.20918465], [88.97299957, 22.20944214], [88.97251892, 22.20971107], [88.9720993, 22.21002007], [88.97173309, 22.21031952], [88.97145081, 22.21063042], [88.97125244, 22.21095085], [88.97107697, 22.21116066], [88.97088623, 22.21133232], [88.97074127, 22.21148109], [88.9705658, 22.2116642], [88.97042084, 22.21185684], [88.97019958, 22.2121067], [88.96996307, 22.21246338], [88.96969604, 22.21278954], [88.96943665, 22.21313286], [88.96916962, 22.21349716], [88.9688797, 22.21389961], [88.96861267, 22.21431351], [88.96836853, 22.21469307], [88.96816254, 22.21504974], [88.96806335, 22.21541023], [88.96795654, 22.21575165], [88.96782684, 22.2160511], [88.96775818, 22.21642113], [88.96765137, 22.21677971], [88.96750641, 22.21717262], [88.96740723, 22.21759224], [88.96730042, 22.21795082], [88.96718597, 22.21825218], [88.9670105, 22.21859932], [88.96689606, 22.21910286], [88.96672058, 22.21964836], [88.96664429, 22.22027206], [88.96652985, 22.22088051], [88.96637726, 22.22147179], [88.96620178, 22.22203255], [88.96611023, 22.22260284], [88.96602631, 22.22315025], [88.96593475, 22.22368431], [88.96580505, 22.2241497], [88.96560669, 22.22456169], [88.96557617, 22.22501183], [88.96559143, 22.22547913], [88.96552277, 22.22596169], [88.96536255, 22.22641945], [88.96539307, 22.22691536], [88.96537781, 22.2273159], [88.96530914, 22.22759438], [88.96528625, 22.2278862], [88.96527863, 22.22821236], [88.96526337, 22.22855949], [88.96521759, 22.228899], [88.96504974, 22.22919273], [88.96499634, 22.22958946], [88.96499634, 22.23008919], [88.96496582, 22.23069954], [88.96485138, 22.23139763], [88.96466064, 22.23205376], [88.96453094, 22.23268127], [88.96445465, 22.23326111], [88.96443176, 22.23378181], [88.96437836, 22.23424721], [88.96430206, 22.23465157], [88.96421814, 22.23496246], [88.96414948, 22.23524666], [88.96403503, 22.23552132], [88.96391296, 22.23584938], [88.96379852, 22.23627281], [88.96369934, 22.23679543], [88.96353912, 22.23729134], [88.96331787, 22.23781395], [88.96305847, 22.23833847], [88.96279907, 22.23890114], [88.96261597, 22.23949814], [88.96251678, 22.24001122], [88.96244812, 22.2405529], [88.96222687, 22.2410717], [88.96198273, 22.24162865], [88.96170044, 22.24218559], [88.96139526, 22.24271393], [88.96111298, 22.24320221], [88.96083069, 22.24363136], [88.9605484, 22.24400139], [88.96026611, 22.24435234], [88.95996857, 22.24465752], [88.9596405, 22.2449398], [88.95926666, 22.24519348], [88.95896912, 22.24547768], [88.95861816, 22.24579811], [88.9582901, 22.24617958], [88.95802307, 22.24666023], [88.9576416, 22.24708748], [88.95717621, 22.24754143], [88.95671844, 22.24799538], [88.95623779, 22.24840164], [88.95581818, 22.24888039], [88.95539093, 22.24936104], [88.95501709, 22.24985313], [88.95452118, 22.25022316], [88.95401001, 22.25055122], [88.95349884, 22.25083923], [88.95303345, 22.25110817], [88.95259094, 22.25134468], [88.95213318, 22.25149345], [88.95169067, 22.25168037], [88.95124817, 22.25193787], [88.95078278, 22.25220299], [88.95027161, 22.25248146], [88.94976807, 22.25278282], [88.94972229, 22.25305748], [88.94833374, 22.25444603], [88.94805908, 22.25444031], [88.94750214, 22.25500107], [88.94750214, 22.25528145], [88.94721985, 22.25555992], [88.94721985, 22.25611115], [88.94750214, 22.25638962], [88.94750214, 22.25805283], [88.94749451, 22.2584095], [88.94764709, 22.25869179], [88.94779968, 22.25901222], [88.94800568, 22.25932884], [88.94820404, 22.25971222], [88.94844055, 22.2601223], [88.94864655, 22.26059914], [88.94888306, 22.2610836], [88.94914246, 22.26154137], [88.94936371, 22.26213646], [88.94957733, 22.26273537], [88.94972229, 22.26316452], [88.94984436, 22.26353264], [88.94992828, 22.26390266], [88.94998932, 22.26426125], [88.94999695, 22.26461983], [88.95004272, 22.26499748], [88.95020294, 22.26540947], [88.95030212, 22.2659626], [88.95046234, 22.26658058], [88.95059204, 22.26718903], [88.95079041, 22.2677803], [88.95089722, 22.26841545], [88.95111847, 22.26896286], [88.95136261, 22.26951027], [88.95153809, 22.27013016], [88.95173645, 22.27072906], [88.95178986, 22.27132797], [88.95198822, 22.27177238], [88.9520874, 22.27224159], [88.95218658, 22.27259827], [88.95222473, 22.27292061], [88.95226288, 22.27324486], [88.95240784, 22.27355385], [88.95252228, 22.27394485], [88.95269012, 22.27440071], [88.95276642, 22.27497292], [88.95288086, 22.27563286], [88.95301819, 22.27635193], [88.95307159, 22.27712059], [88.95314789, 22.2779274], [88.95320892, 22.27874756], [88.95330048, 22.27943993], [88.95333099, 22.28009987], [88.95330811, 22.28074074], [88.95320892, 22.28137398], [88.95320892, 22.28205299], [88.95327759, 22.28271294], [88.95332336, 22.2833004], [88.95333099, 22.28384972], [88.95333099, 22.2843132], [88.95333099, 22.28471375], [88.95333099, 22.28510094], [88.95333099, 22.28553009], [88.95330048, 22.2860508], [88.95320892, 22.28662109], [88.95321655, 22.28717232], [88.95330811, 22.28764725], [88.95333099, 22.2881031], [88.95333862, 22.28854179], [88.95333862, 22.28896141], [88.95333862, 22.28941154], [88.95333099, 22.28991127], [88.95327759, 22.29045486], [88.95305634, 22.29097176], [88.95285797, 22.29153061], [88.9527359, 22.2921505], [88.95256042, 22.29269218], [88.95246887, 22.29314995], [88.95233154, 22.29351807], [88.95223999, 22.29390144], [88.95220947, 22.29432106], [88.95214081, 22.29476738], [88.95195007, 22.29513168], [88.95173645, 22.29549217], [88.95159149, 22.29588127], [88.95140839, 22.29622078], [88.95134735, 22.29658318], [88.95121002, 22.29687119], [88.95111847, 22.2972126], [88.9510498, 22.29761505], [88.95088196, 22.29805946], [88.95083618, 22.29865074], [88.95082855, 22.29933357], [88.95083618, 22.30006981], [88.95088196, 22.30083275], [88.95105743, 22.30154228], [88.95110321, 22.30230141], [88.95111847, 22.30303001], [88.95115662, 22.30365944], [88.95133972, 22.30415726], [88.9513855, 22.30463028], [88.95140839, 22.30504036], [88.95147705, 22.30541992], [88.9514389, 22.30589104], [88.95147705, 22.30639076], [88.95162964, 22.30690384], [88.95176697, 22.3074398], [88.95175171, 22.30798531], [88.95173645, 22.30861473], [88.95189667, 22.30919075], [88.95194244, 22.30977058], [88.95194244, 22.31031609], [88.95194244, 22.31085587], [88.95194244, 22.31140327], [88.95194244, 22.31195259], [88.95191193, 22.3124752], [88.95179749, 22.31295967], [88.95178986, 22.31348228], [88.95189667, 22.31400108], [88.95195007, 22.31451988], [88.95198822, 22.31502914], [88.95211029, 22.31554222], [88.95198822, 22.31604195], [88.95194244, 22.31655121], [88.95189667, 22.31703758], [88.95173645, 22.31747246], [88.95168304, 22.3180027], [88.95162201, 22.31854057], [88.9514389, 22.31905365], [88.95139313, 22.31958961], [88.9513855, 22.32013512], [88.9513855, 22.32066154], [88.95137787, 22.32114983], [88.95140839, 22.32160187], [88.95153046, 22.32201195], [88.95158386, 22.32243347], [88.95155334, 22.32286263], [88.95147705, 22.32328033], [88.95160675, 22.32373238], [88.95160675, 22.32419968], [88.95144653, 22.32465172], [88.95140839, 22.32511139], [88.9515152, 22.32556534], [88.95162964, 22.32604027], [88.95166016, 22.32653236], [88.95166779, 22.32697868], [88.95168304, 22.32734489], [88.95176697, 22.32761383], [88.95202637, 22.32781029], [88.95209503, 22.32802963], [88.951828, 22.3282795], [88.95170593, 22.32854652], [88.95166779, 22.32883835], [88.95169067, 22.32920265], [88.95178986, 22.32958031], [88.95186615, 22.32999229], [88.95191956, 22.33042908], [88.95192719, 22.33088112], [88.95195007, 22.33133507], [88.95198822, 22.33179283], [88.95215607, 22.33221817], [88.9523468, 22.33266449], [88.95252228, 22.33316994], [88.9527359, 22.33365059], [88.95295715, 22.33414268], [88.95320129, 22.33460045], [88.95340729, 22.33506012], [88.95359802, 22.33548164], [88.95376587, 22.33586311], [88.95391846, 22.33621025], [88.9540863, 22.33652115], [88.95419312, 22.33684921], [88.95435333, 22.33716011], [88.95442963, 22.33756065], [88.95448303, 22.3379879], [88.95462799, 22.33839226], [88.95471954, 22.3388195], [88.95479584, 22.33919907], [88.95495605, 22.33951569], [88.95498657, 22.33984947], [88.95500183, 22.3401947], [88.95504761, 22.34052467], [88.95522308, 22.34081268], [88.95529938, 22.34119225], [88.95542145, 22.34156036], [88.955513, 22.3419838], [88.95558929, 22.34239006], [88.95575714, 22.34274292], [88.95582581, 22.34308815], [88.95587921, 22.34340286], [88.95600891, 22.34364128], [88.95609283, 22.34392548], [88.95612335, 22.34427071], [88.95614624, 22.34467506], [88.95618439, 22.34477615], [88.95630646, 22.34510422], [88.95637512, 22.34559441], [88.95639038, 22.3461132], [88.95639801, 22.34662056], [88.95644379, 22.34710884], [88.95643616, 22.3476181], [88.95661926, 22.34810066], [88.95665741, 22.34860611], [88.95667267, 22.34910011], [88.95666504, 22.34954643], [88.9566803, 22.3499012], [88.95667267, 22.35028458], [88.95639038, 22.35056114], [88.95639038, 22.35277748], [88.95614624, 22.35301399], [88.95600891, 22.35342216], [88.95581818, 22.35384941], [88.95555878, 22.35427284], [88.95527649, 22.35474205], [88.95501709, 22.35522842], [88.95481873, 22.35575485], [88.95466614, 22.35624886], [88.95448303, 22.35667229], [88.95436859, 22.35710144], [88.954216, 22.35746384], [88.95414734, 22.35788155], [88.95404816, 22.35832024], [88.95391846, 22.358778], [88.9539032, 22.35926247], [88.95391083, 22.35972786], [88.95402527, 22.36013603], [88.95418549, 22.36048317], [88.95440674, 22.36079407], [88.95469666, 22.36109924], [88.9550705, 22.36139107], [88.95550537, 22.36160851], [88.95600891, 22.36167145], [88.95651245, 22.36174011], [88.9569397, 22.36190987], [88.95742798, 22.36202621], [88.95789337, 22.36219215], [88.95839691, 22.36230659], [88.95887756, 22.36249161], [88.95934296, 22.36268044], [88.95968628, 22.36292076], [88.95996857, 22.36322212], [88.96018219, 22.36359024], [88.96047211, 22.36394119], [88.9608078, 22.36433983], [88.96118164, 22.36478996], [88.96154022, 22.36523628], [88.96198273, 22.36557961], [88.9624176, 22.36587143], [88.96283722, 22.36615944], [88.96334839, 22.36640549], [88.96385193, 22.36667061], [88.96431732, 22.36700058], [88.9646225, 22.36744118], [88.96471405, 22.36802864], [88.96478271, 22.36861992], [88.96495056, 22.36918068], [88.96505737, 22.36975288], [88.965271, 22.37022018], [88.96547699, 22.37066078], [88.96560669, 22.3711319], [88.96579742, 22.37155342], [88.96588898, 22.37202263], [88.96605682, 22.37246132], [88.96614838, 22.37301064], [88.96633911, 22.3735714], [88.96650696, 22.3741703], [88.96665955, 22.37477493], [88.96676636, 22.37536049], [88.96691132, 22.37590027], [88.96694183, 22.37635231], [88.96694946, 22.37671089], [88.96694183, 22.37703705], [88.96694183, 22.3774147], [88.96691895, 22.37790108], [88.96684265, 22.37849808], [88.96691132, 22.3791523], [88.96698761, 22.37978172], [88.96717834, 22.3802681], [88.96730804, 22.38075066], [88.96747589, 22.38118172], [88.96763611, 22.38158989], [88.96779633, 22.3819828], [88.9679718, 22.38232803], [88.96806335, 22.38272858], [88.9681778, 22.38318062], [88.96829987, 22.38371277], [88.96833038, 22.38428307], [88.96833801, 22.38484001], [88.96833801, 22.38537025], [88.96833038, 22.38585281], [88.96829987, 22.38626289], [88.96817017, 22.38656425], [88.96807861, 22.38688278], [88.96803284, 22.38724899], [88.96792603, 22.38760948], [88.96779633, 22.3879528], [88.96778107, 22.38828087], [88.96781921, 22.38858223], [88.96795654, 22.38883018], [88.96807861, 22.38909721], [88.96826172, 22.38934135], [88.96855164, 22.38955116], [88.96882629, 22.3898716], [88.96916199, 22.39025307], [88.96958923, 22.39055061], [88.97006226, 22.39080811], [88.97054291, 22.39098167], [88.97097778, 22.39114952], [88.97136688, 22.39138222], [88.97174835, 22.39159393], [88.97213745, 22.3917408], [88.97247314, 22.39195061], [88.97277832, 22.39219093], [88.97304535, 22.39245033], [88.9732666, 22.39273262], [88.97342682, 22.39304161], [88.97355652, 22.39334297], [88.97367096, 22.39364052], [88.97384644, 22.39391136], [88.97389221, 22.39416695], [88.97389221, 22.39472008], [88.97416687, 22.39500237], [88.97416687, 22.39666939], [88.97400665, 22.39671135], [88.97385406, 22.39712334], [88.97358704, 22.39756966], [88.97328186, 22.39806175], [88.97293091, 22.39857483], [88.97254944, 22.39902687], [88.972229, 22.39949226], [88.97193909, 22.39993477], [88.9716568, 22.40034294], [88.97135162, 22.40071678], [88.97100067, 22.40105057], [88.97064972, 22.40139008], [88.9703064, 22.40172386], [88.9699707, 22.40203476], [88.96962738, 22.40232086], [88.9692688, 22.40258217], [88.9688797, 22.40287209], [88.96848297, 22.40322304], [88.9681015, 22.40367699], [88.96775818, 22.40418434], [88.967453, 22.40468025], [88.96718597, 22.40514183], [88.96695709, 22.40555], [88.96681213, 22.40595245], [88.96669769, 22.40631866], [88.96669006, 22.4066906], [88.96679688, 22.40706062], [88.9670105, 22.40740585], [88.96736145, 22.40769005], [88.96786499, 22.40786743], [88.96840668, 22.40807152], [88.96893311, 22.40829277], [88.96948242, 22.40841103], [88.97000885, 22.40858269], [88.97054291, 22.40856934], [88.97107697, 22.40831947], [88.97157288, 22.40792274], [88.97190857, 22.40736961], [88.97212219, 22.40676308], [88.97225952, 22.40617943], [88.97248077, 22.4057579], [88.97267151, 22.40538216], [88.97288513, 22.40504265], [88.97318268, 22.40473747], [88.97357941, 22.40445137], [88.97403717, 22.4041748], [88.97455597, 22.40389061], [88.97483063, 22.40374374], [88.97511292, 22.40359306], [88.97560883, 22.40326118], [88.97599792, 22.40289116], [88.97632599, 22.40250969], [88.97664642, 22.40214157], [88.97698975, 22.40174294], [88.97741699, 22.40140152], [88.97788239, 22.40105057], [88.97827148, 22.40060806], [88.97860718, 22.40018272], [88.97892761, 22.39985657], [88.97921753, 22.39964104], [88.97945404, 22.39938354], [88.97970581, 22.39911461], [88.97999573, 22.39879417], [88.98033142, 22.3984127], [88.98075104, 22.39801979], [88.98117065, 22.39761353], [88.98159027, 22.39722824], [88.98203278, 22.39687157], [88.98252106, 22.39655113], [88.98306274, 22.39624786], [88.98363495, 22.39591026], [88.98420715, 22.39554024], [88.98474884, 22.39511108], [88.98530579, 22.39473152], [88.98587799, 22.39440918], [88.98644257, 22.39415169], [88.98692322, 22.39383125], [88.98733521, 22.39348984], [88.98770142, 22.3931179], [88.98800659, 22.39270973], [88.98828125, 22.39229012], [88.98858643, 22.39192009], [88.98886871, 22.3915596], [88.98908997, 22.39115906], [88.98915863, 22.3906498], [88.98916626, 22.39012909], [88.98915863, 22.38960075], [88.98907471, 22.38908958], [88.98887634, 22.38861275], [88.98861694, 22.3881588], [88.98848724, 22.38794518], [88.98833466, 22.38768959], [88.98805237, 22.38720131], [88.98774719, 22.38670158], [88.98743439, 22.3862133], [88.98703003, 22.38576698], [88.9866333, 22.38533974], [88.98623657, 22.3849411], [88.98591614, 22.38455009], [88.98564911, 22.3841629], [88.98542023, 22.38376045], [88.9852066, 22.38334084], [88.98499298, 22.38290215], [88.98475647, 22.38243294]]], [[[88.80544281, 22.21244049], [88.80532074, 22.21291161], [88.80528259, 22.21336555], [88.80527496, 22.21379471], [88.80531311, 22.21421242], [88.80539703, 22.21461487], [88.80555725, 22.21497726], [88.80574036, 22.21536064], [88.80587769, 22.21581078], [88.80606079, 22.2162571], [88.80618286, 22.21676064], [88.80631256, 22.21723747], [88.80632019, 22.21771049], [88.80623627, 22.21814156], [88.80615997, 22.21852112], [88.80610657, 22.21887016], [88.8060379, 22.21920013], [88.80591583, 22.21951103], [88.80586243, 22.21985054], [88.80583191, 22.22021294], [88.80576324, 22.2205925], [88.80561066, 22.2209549], [88.80548859, 22.22136116], [88.80529022, 22.22168159], [88.8050766, 22.22200584], [88.80487061, 22.22237206], [88.80464935, 22.22278023], [88.80426025, 22.22313118], [88.80369568, 22.22337914], [88.80312347, 22.22363472], [88.80260468, 22.22393227], [88.80213165, 22.22427177], [88.80168152, 22.22465324], [88.80119324, 22.22501183], [88.80076599, 22.22538948], [88.80056, 22.22584152], [88.80053711, 22.2262516], [88.80079651, 22.22656822], [88.80122375, 22.22673607], [88.80171967, 22.22675323], [88.80223846, 22.22664452], [88.80278015, 22.22654343], [88.80329132, 22.22664642], [88.80374908, 22.22678947], [88.80414581, 22.22691154], [88.80452728, 22.22699165], [88.80488586, 22.22709274], [88.80526733, 22.22717285], [88.8055954, 22.22714233], [88.80568695, 22.22714424], [88.80609894, 22.22715187], [88.80651093, 22.22719383], [88.80693054, 22.22721291], [88.80735016, 22.22723389], [88.80776978, 22.2272625], [88.80819702, 22.22731972], [88.80860138, 22.22723389], [88.809021, 22.22712135], [88.80943298, 22.22705269], [88.80987549, 22.22716522], [88.81034851, 22.22721863], [88.81082153, 22.22729111], [88.81125641, 22.22746086], [88.8117218, 22.22758865], [88.81215668, 22.22777176], [88.81259155, 22.22796059], [88.81302643, 22.22810173], [88.81343842, 22.22829247], [88.81385803, 22.22842979], [88.81427765, 22.22856331], [88.81471252, 22.22864342], [88.81515503, 22.22879982], [88.81561279, 22.22907066], [88.8161087, 22.22936058], [88.81661987, 22.22968292], [88.81716156, 22.22999191], [88.81768799, 22.23029137], [88.81816864, 22.23059654], [88.81855011, 22.23093987], [88.81884003, 22.23132133], [88.8191452, 22.23156548], [88.81942749, 22.23180962], [88.81967163, 22.23209763], [88.81987762, 22.23248291], [88.82009888, 22.23291588], [88.82034302, 22.23339462], [88.82064056, 22.23383522], [88.820961, 22.23429489], [88.82121277, 22.23479271], [88.82154083, 22.2352314], [88.82189178, 22.23566055], [88.82227325, 22.23611259], [88.82273865, 22.23646927], [88.82322693, 22.23684311], [88.82370758, 22.23718262], [88.82424164, 22.23747063], [88.82479095, 22.2376976], [88.82534027, 22.23787117], [88.82579041, 22.23818016], [88.82614136, 22.23854256], [88.82646942, 22.23889542], [88.82673645, 22.23924065], [88.82698059, 22.23962975], [88.8272171, 22.24000168], [88.82749939, 22.24027824], [88.82749939, 22.24055481], [88.82784271, 22.24090195], [88.82842255, 22.24190521], [88.82821655, 22.24322319], [88.82813263, 22.24380684], [88.82794952, 22.24446297], [88.82791901, 22.24522972], [88.82798004, 22.24601173], [88.82806396, 22.24672127], [88.82818604, 22.24732971], [88.82836914, 22.24782181], [88.82852936, 22.24823952], [88.82859802, 22.24863243], [88.82862854, 22.24901009], [88.8286972, 22.24936104], [88.82884216, 22.24971199], [88.82888794, 22.25015068], [88.82894135, 22.25068092], [88.82913971, 22.25127029], [88.8292923, 22.25193977], [88.829422, 22.2525425], [88.82949829, 22.25315666], [88.82956696, 22.25372124], [88.8295517, 22.25421906], [88.82952118, 22.25471306], [88.82946777, 22.25526237], [88.82944489, 22.25577164], [88.82942963, 22.25621223], [88.82939148, 22.25657845], [88.82933807, 22.25686264], [88.82930756, 22.25715065], [88.8292923, 22.25761223], [88.82923889, 22.25822258], [88.8291626, 22.25883293], [88.82898712, 22.25936127], [88.8290329, 22.25989342], [88.82894897, 22.26035881], [88.82885742, 22.26080513], [88.82870483, 22.26118851], [88.82860565, 22.26156425], [88.82849884, 22.26190186], [88.82834625, 22.26221275], [88.82824707, 22.26255226], [88.82807922, 22.2628727], [88.82800293, 22.26328087], [88.82783508, 22.26363945], [88.82777405, 22.26411438], [88.82771301, 22.2646122], [88.82751465, 22.26503372], [88.82730103, 22.26545143], [88.82704163, 22.26580238], [88.82675171, 22.26608658], [88.82642365, 22.26630211], [88.82598114, 22.26645088], [88.82541656, 22.26663017], [88.82478333, 22.26663017], [88.82417297, 22.26667023], [88.82332611, 22.26667023], [88.82305908, 22.26639175], [88.82277679, 22.26639175], [88.8216629, 22.26527977], [88.82055664, 22.26527977], [88.82027435, 22.26555824], [88.82027435, 22.2658329], [88.81999969, 22.26611137], [88.8208313, 22.26694107], [88.8208313, 22.26750183], [88.82055664, 22.2677784], [88.82055664, 22.26861191], [88.81999969, 22.26916695], [88.81999969, 22.26972008], [88.81944275, 22.27028084], [88.81916809, 22.27028084], [88.8188858, 22.27056313], [88.81804657, 22.27056313], [88.81694794, 22.27166939], [88.81664276, 22.27167892], [88.81667328, 22.27210045], [88.81667328, 22.27248955], [88.8167038, 22.27285767], [88.81681061, 22.27321053], [88.81691742, 22.27360725], [88.81694031, 22.27404213], [88.81694794, 22.27452278], [88.81694794, 22.27499962], [88.81694794, 22.27548027], [88.81694031, 22.2759552], [88.81691742, 22.27640915], [88.8168335, 22.27684593], [88.81668854, 22.27726173], [88.81658936, 22.27768135], [88.81647491, 22.27808952], [88.8164978, 22.27854156], [88.81651306, 22.27898979], [88.81642151, 22.27942085], [88.8163681, 22.27986145], [88.81626892, 22.28027153], [88.81613922, 22.2806797], [88.81606293, 22.28110313], [88.81590271, 22.28148079], [88.81581879, 22.28190041], [88.81572723, 22.28230286], [88.8155899, 22.28263283], [88.81545258, 22.28297234], [88.81520844, 22.28328514], [88.81484985, 22.28358269], [88.81437683, 22.28385925], [88.81380463, 22.28409386], [88.81326294, 22.28436279], [88.81259155, 22.28458977], [88.81183624, 22.28471947], [88.81105804, 22.28482819], [88.81027985, 22.28489113], [88.80951691, 22.28479958], [88.80879211, 22.28469276], [88.80810547, 22.28461456], [88.80753326, 22.28474808], [88.80710602, 22.2850399], [88.80680847, 22.28540993], [88.80652618, 22.28574944], [88.80638123, 22.28624153], [88.80623627, 22.28679085], [88.80607605, 22.28743935], [88.80589294, 22.28812981], [88.80584717, 22.2888813], [88.80587769, 22.28962135], [88.80577087, 22.29031944], [88.80558777, 22.29097557], [88.8054657, 22.29162216], [88.80527496, 22.29218483], [88.80523682, 22.29229164], [88.80509949, 22.29270744], [88.80506134, 22.29323006], [88.80519867, 22.29375267], [88.80513, 22.29421043], [88.80503082, 22.29466057], [88.80500031, 22.29514122], [88.80502319, 22.29560852], [88.80513, 22.29607201], [88.805336, 22.29652023], [88.80554962, 22.29695511], [88.80574799, 22.29742622], [88.80580902, 22.29763222], [88.80590057, 22.29792213], [88.80615234, 22.29840469], [88.80639648, 22.29897118], [88.80664063, 22.2995491], [88.80680847, 22.3001194], [88.80693817, 22.30052948], [88.80709839, 22.3008728], [88.80731201, 22.30124855], [88.80745697, 22.30173302], [88.80750275, 22.30227089], [88.80750275, 22.30281067], [88.80750275, 22.30336952], [88.80753326, 22.30397606], [88.80768585, 22.30463219], [88.80788422, 22.30534935], [88.80802917, 22.30606461], [88.80819702, 22.30672836], [88.80835724, 22.30732155], [88.80860901, 22.30783844], [88.80887604, 22.30833244], [88.80919647, 22.30877113], [88.80956268, 22.3091526], [88.80974579, 22.30961037], [88.81000519, 22.31002998], [88.81027222, 22.31045151], [88.81053925, 22.31088066], [88.81083679, 22.31139183], [88.81111145, 22.31166649], [88.81111145, 22.31221962], [88.81138611, 22.31250191], [88.81138611, 22.31278038], [88.81194305, 22.31333351], [88.81194305, 22.31361198], [88.81222534, 22.31388855], [88.81223297, 22.31583214], [88.81222534, 22.31591225], [88.81216431, 22.31648827], [88.8119812, 22.31703186], [88.81183624, 22.31762123], [88.81170654, 22.31823158], [88.8115387, 22.31873131], [88.81138611, 22.31916618], [88.8116684, 22.31944466], [88.8116684, 22.31972313], [88.81194305, 22.3200016], [88.81194305, 22.32055473], [88.81138611, 22.32111168], [88.81111145, 22.32111168], [88.81083679, 22.32139015], [88.8105545, 22.32139015], [88.8097229, 22.32222366], [88.80944061, 22.32222366], [88.8088913, 22.32278442], [88.80860901, 22.3227787], [88.80805206, 22.32333374], [88.80805206, 22.32361031], [88.8061142, 22.3255558], [88.80610657, 22.32583046], [88.80555725, 22.32639122], [88.80555725, 22.32666588], [88.80500031, 22.32722282], [88.80500031, 22.3275013], [88.80444336, 22.32805634], [88.80444336, 22.3283329], [88.8041687, 22.32861137], [88.8041687, 22.32957268], [88.8041687, 22.32972145], [88.80455017, 22.3300972], [88.80473328, 22.33028221], [88.80500031, 22.33028221], [88.80610657, 22.33139229], [88.8061142, 22.33166885], [88.80638885, 22.33194542], [88.80638885, 22.33222008], [88.80750275, 22.33332825], [88.80750275, 22.33361244], [88.8077774, 22.33389091], [88.8077774, 22.33472252], [88.80789948, 22.33485413], [88.80805206, 22.33502007], [88.80805206, 22.33555794], [88.80832672, 22.3358326], [88.80833435, 22.33638954], [88.8088913, 22.33694649], [88.8088913, 22.33722305], [88.80922699, 22.33756065], [88.8097229, 22.33805656], [88.8097229, 22.33833313], [88.80999756, 22.3386097], [88.80999756, 22.33889198], [88.81027985, 22.33917046], [88.81027985, 22.33944321], [88.81054688, 22.33971214], [88.81054688, 22.34000206], [88.81083679, 22.34028053], [88.81083679, 22.34055519], [88.81111145, 22.34082985], [88.81111145, 22.34111214], [88.81138611, 22.34139061], [88.81138611, 22.34194374], [88.8116684, 22.34222221], [88.8116684, 22.34278297], [88.81194305, 22.34306145], [88.81194305, 22.34389305], [88.81222534, 22.3441658], [88.81222534, 22.34480095], [88.81222534, 22.34583282], [88.8125, 22.3461113], [88.8125, 22.34666634], [88.81277466, 22.34694481], [88.81276703, 22.34721947], [88.81305695, 22.34750175], [88.81305695, 22.34805489], [88.8133316, 22.34833336], [88.8133316, 22.34861183], [88.81361389, 22.3488903], [88.81389618, 22.34887123], [88.8161087, 22.35111046], [88.8161087, 22.35139465], [88.81639099, 22.3516674], [88.81639099, 22.35194588], [88.81666565, 22.35222435], [88.81667328, 22.35250282], [88.81694794, 22.35277748], [88.81694794, 22.35333061], [88.8172226, 22.3536129], [88.8172226, 22.3544445], [88.81749725, 22.35472298], [88.81749725, 22.35670471], [88.81749725, 22.35749817], [88.81777954, 22.35778236], [88.81777954, 22.35805893], [88.8180542, 22.35833359], [88.81804657, 22.35860825], [88.81833649, 22.35889244], [88.81861115, 22.35889244], [88.8188858, 22.35917091], [88.8190918, 22.35917091], [88.81944275, 22.3591671], [88.81999969, 22.35972404], [88.8208313, 22.35972404], [88.82111359, 22.35944557], [88.82138824, 22.35944557], [88.8216629, 22.3591671], [88.82221985, 22.3591671], [88.82250214, 22.35944557], [88.8236084, 22.35944557], [88.82389069, 22.3591671], [88.82554626, 22.35917091], [88.82583618, 22.35889244], [88.82750702, 22.35889244], [88.82776642, 22.35860825], [88.82833099, 22.35861206], [88.82847595, 22.3587532], [88.82861328, 22.35889244], [88.82971954, 22.35889244], [88.83000183, 22.35860825], [88.83055878, 22.35861397], [88.83083344, 22.35833549], [88.83166504, 22.35833549], [88.83194733, 22.35805893], [88.83305359, 22.35805893], [88.83333588, 22.35833549], [88.83611298, 22.35833549], [88.83638763, 22.35861397], [88.83666992, 22.35860825], [88.83693695, 22.35889244], [88.83721924, 22.35889053], [88.83740234, 22.35907364], [88.83777618, 22.35944557], [88.83805847, 22.35944557], [88.83833313, 22.35972404], [88.83860779, 22.35971832], [88.83874512, 22.35986137], [88.83889008, 22.36000252], [88.8391571, 22.36000252], [88.83944702, 22.36027908], [88.84027863, 22.36027908], [88.84055328, 22.36055946], [88.84083557, 22.36055565], [88.84111023, 22.36083412], [88.84194183, 22.36082268], [88.84209442, 22.36098289], [88.84221649, 22.36111259], [88.84278107, 22.36111259], [88.84284973, 22.36117935], [88.84306335, 22.36139107], [88.84388733, 22.36139107], [88.84416962, 22.36166954], [88.84471893, 22.36166573], [88.84486389, 22.36180687], [88.84500122, 22.3619442], [88.84555817, 22.3619442], [88.84574127, 22.36213112], [88.84583282, 22.36222267], [88.84610748, 22.36222267], [88.84638977, 22.36250114], [88.84722137, 22.36250114], [88.84749603, 22.36277962], [88.84944153, 22.36277962], [88.84971619, 22.36306381], [88.84986115, 22.36291695], [88.84999847, 22.36277962], [88.85083008, 22.36277962], [88.85111237, 22.36250114], [88.85138702, 22.36250114], [88.85193634, 22.36194038], [88.85221863, 22.3619442], [88.85277557, 22.36139107], [88.85305786, 22.36139107], [88.85333252, 22.36111259], [88.85388947, 22.36111259], [88.85415649, 22.36082268], [88.85444641, 22.36083412], [88.85472107, 22.36055565], [88.85500336, 22.36055946], [88.85527802, 22.36027908], [88.85582733, 22.36027908], [88.85610962, 22.36000252], [88.85639191, 22.36000252], [88.85666656, 22.35971832], [88.85694122, 22.35972404], [88.85722351, 22.35944557], [88.85749817, 22.35972404], [88.85832977, 22.35972404], [88.85888672, 22.3591671], [88.85888672, 22.35860825], [88.85944366, 22.35805511], [88.85972595, 22.35805893], [88.86027527, 22.35861397], [88.86083221, 22.35861397], [88.8611145, 22.35833549], [88.86138916, 22.35833549], [88.86166382, 22.35805893], [88.86194611, 22.35807037], [88.86277771, 22.3572216], [88.86333466, 22.3572216], [88.86360931, 22.35694885], [88.86416626, 22.35695076], [88.86444092, 22.35667229], [88.86472321, 22.35667229], [88.86499786, 22.35695076], [88.86528015, 22.35694885], [88.86555481, 22.3572216], [88.86611176, 22.3572216], [88.86638641, 22.35749817], [88.86723328, 22.35749817], [88.86750031, 22.35778236], [88.86915588, 22.35778236], [88.8694458, 22.35807037], [88.86972046, 22.35807037], [88.87000275, 22.35778236], [88.87055206, 22.35778236], [88.87082672, 22.35749817], [88.87110901, 22.35749817], [88.87194824, 22.35667229], [88.8722229, 22.35667229], [88.87388611, 22.35500145], [88.8741684, 22.35500145], [88.87610626, 22.35305977], [88.87638855, 22.35305977], [88.87666321, 22.3527813], [88.87695313, 22.3527813], [88.87722015, 22.35250282], [88.87750244, 22.35250282], [88.8777771, 22.35222054], [88.87805176, 22.35222435], [88.87833405, 22.35194588], [88.8786087, 22.35194588], [88.87889099, 22.3516674], [88.87917328, 22.35167122], [88.8797226, 22.35111046], [88.87999725, 22.35111046], [88.88054657, 22.35056114], [88.88083649, 22.35056114], [88.88111115, 22.35028458], [88.88168335, 22.35028458], [88.88194275, 22.35000038], [88.88276672, 22.35000038], [88.88360596, 22.3491745], [88.88401031, 22.34909248], [88.88438416, 22.3488102], [88.88475037, 22.34844017], [88.88516998, 22.34807014], [88.88565063, 22.34769821], [88.88613892, 22.34726715], [88.8866806, 22.34682274], [88.88724518, 22.34637642], [88.88778687, 22.34589195], [88.88832855, 22.34544373], [88.88886261, 22.34504128], [88.88939667, 22.34472084], [88.88990784, 22.34443855], [88.89038849, 22.34412193], [88.89080048, 22.34373093], [88.89116669, 22.34334946], [88.89157104, 22.34308243], [88.89185333, 22.34266472], [88.89211273, 22.34215355], [88.89241791, 22.34162712], [88.89274597, 22.34108353], [88.89302063, 22.34047127], [88.89320374, 22.33986282], [88.89335632, 22.33941078], [88.89362335, 22.33903313], [88.89388275, 22.33863258], [88.89415741, 22.33818054], [88.89442444, 22.33771515], [88.89467621, 22.33727074], [88.89493561, 22.33687782], [88.89515686, 22.33648109], [88.89544678, 22.33613586], [88.89579773, 22.33581924], [88.8961792, 22.33550072], [88.89649963, 22.33505058], [88.89686584, 22.33467484], [88.89722443, 22.3342762], [88.8976059, 22.33389854], [88.89800262, 22.33354187], [88.89839172, 22.33318138], [88.89886475, 22.33289719], [88.89935303, 22.3325901], [88.89984131, 22.33218384], [88.9002533, 22.33168983], [88.90055084, 22.33115959], [88.90076447, 22.3306942], [88.9008255, 22.33026695], [88.90084076, 22.32991982], [88.90085602, 22.32962227], [88.90093231, 22.32935143], [88.90103912, 22.3290844], [88.90112305, 22.32876968], [88.90122986, 22.32842064], [88.90135193, 22.3280201], [88.90139008, 22.32756233], [88.90142822, 22.32712173], [88.90157318, 22.3267498], [88.9016571, 22.32636261], [88.9017334, 22.32596207], [88.90190125, 22.32558632], [88.90200806, 22.32514763], [88.90220642, 22.32478142], [88.90241241, 22.32442284], [88.90258026, 22.32409477], [88.90274811, 22.32380867], [88.90284729, 22.32344818], [88.90304565, 22.3230896], [88.90325165, 22.32268715], [88.90342712, 22.32225227], [88.90363312, 22.32182121], [88.90386963, 22.3214016], [88.90409088, 22.32094383], [88.90424347, 22.32038307], [88.90445709, 22.31985855], [88.90473938, 22.31936836], [88.90503693, 22.31890106], [88.9053421, 22.31839943], [88.90566254, 22.3179512], [88.90596771, 22.31754112], [88.90627289, 22.31716919], [88.90657043, 22.31678581], [88.90691376, 22.31640816], [88.90731812, 22.31604195], [88.9077301, 22.31567383], [88.90808105, 22.31522179], [88.9084549, 22.31479073], [88.90891266, 22.31441116], [88.90940094, 22.31397057], [88.90972137, 22.3133297], [88.91000366, 22.31333351], [88.91027832, 22.31305313], [88.91055298, 22.31306267], [88.91165924, 22.31195259], [88.91165924, 22.3116703], [88.91110992, 22.31110954], [88.91083527, 22.31111336], [88.91083527, 22.31083488], [88.91055298, 22.31055641], [88.91055298, 22.30917358], [88.9108429, 22.30888939], [88.91083527, 22.30861282], [88.91110992, 22.30833244], [88.91083527, 22.30805779], [88.9108429, 22.30750275], [88.91055298, 22.30722237], [88.91055298, 22.30639076], [88.91110992, 22.30582809], [88.91139221, 22.30583382], [88.91166687, 22.30555534], [88.91194153, 22.30583382], [88.91249847, 22.30583382], [88.91361237, 22.30694389], [88.91361237, 22.30722237], [88.91416931, 22.30777931], [88.91416931, 22.30833244], [88.91443634, 22.30861282], [88.91500092, 22.30861282], [88.9152832, 22.30833244], [88.91555786, 22.30833244], [88.91583252, 22.30944633], [88.91611481, 22.30944633], [88.91666412, 22.30888939], [88.91694641, 22.30888939], [88.91779327, 22.30806351], [88.91805267, 22.30806351], [88.91847229, 22.30776024], [88.91901398, 22.30742073], [88.91960907, 22.30706978], [88.92025757, 22.30677986], [88.92089844, 22.30648994], [88.92159271, 22.30627441], [88.92220306, 22.30593491], [88.92276001, 22.30558205], [88.92333984, 22.30533409], [88.92385101, 22.30514336], [88.92429352, 22.30496788], [88.92469025, 22.30478096], [88.92516327, 22.3047123], [88.92565155, 22.30461121], [88.92616272, 22.30443001], [88.92666626, 22.30417061], [88.92716217, 22.30389214], [88.92765045, 22.30360222], [88.92812347, 22.30338669], [88.9286499, 22.30333519], [88.92919922, 22.30333138], [88.92973328, 22.30328941], [88.93022919, 22.30313301], [88.93073273, 22.3030529], [88.93125153, 22.30303383], [88.93186951, 22.30303001], [88.93257904, 22.30301285], [88.93321228, 22.30291939], [88.93372345, 22.30278206], [88.93412781, 22.30265236], [88.93450165, 22.30244637], [88.93490601, 22.30214119], [88.93530273, 22.30174637], [88.93567657, 22.30135155], [88.93598938, 22.30094337], [88.93621826, 22.3005619], [88.936409, 22.30020523], [88.93660736, 22.29988289], [88.93675232, 22.29949188], [88.9369278, 22.29911232], [88.93707275, 22.2986927], [88.93721771, 22.29826164], [88.93734741, 22.29781151], [88.93746948, 22.297369], [88.93749237, 22.2968998], [88.93747711, 22.29645348], [88.93741608, 22.29601479], [88.93747711, 22.29556274], [88.9375, 22.29509163], [88.9375, 22.29461098], [88.9375, 22.29414177], [88.93747711, 22.29368019], [88.93739319, 22.29323006], [88.93724823, 22.29279137], [88.93722534, 22.29235268], [88.93721771, 22.29191589], [88.93717194, 22.29148674], [88.93698883, 22.29109764], [88.93694305, 22.29063225], [88.93688965, 22.29012108], [88.9367218, 22.28961182], [88.9366684, 22.28903961], [88.93665314, 22.28841972], [88.93654633, 22.28779984], [88.936409, 22.28717232], [88.93628693, 22.28653145], [88.9361496, 22.28590965], [88.93605804, 22.28531075], [88.93585205, 22.28480911], [88.93564606, 22.28427315], [88.93538666, 22.28373146], [88.93511963, 22.2831707], [88.93487549, 22.28260612], [88.93463135, 22.2820797], [88.93441772, 22.28152275], [88.93416595, 22.28103065], [88.93392181, 22.28057671], [88.93371582, 22.2800827], [88.93357849, 22.27946281], [88.9333725, 22.27882957], [88.93318939, 22.27819443], [88.93302917, 22.27762032], [88.93282318, 22.27713966], [88.93271637, 22.27665138], [88.93257904, 22.27621269], [88.93247986, 22.27578545], [88.93234253, 22.2753849], [88.93224335, 22.27497673], [88.93222046, 22.27456284], [88.93216705, 22.27417946], [88.93199158, 22.27386665], [88.9319458, 22.27351189], [88.9318924, 22.27311134], [88.93171692, 22.27270317], [88.93167114, 22.27219963], [88.93165588, 22.2716465], [88.93161774, 22.27108955], [88.93145752, 22.27060509], [88.93139648, 22.27017021], [88.93138885, 22.26972008], [88.93138123, 22.26926422], [88.93134308, 22.26880455], [88.93119812, 22.26839066], [88.93112183, 22.26794243], [88.93106079, 22.26745796], [88.93087769, 22.26696968], [88.93070221, 22.26643562], [88.93054199, 22.26590157], [88.93036652, 22.26534081], [88.93023682, 22.26477432], [88.93000793, 22.26423073], [88.92980957, 22.26365471], [88.92976379, 22.26301384], [88.92985535, 22.26233482], [88.92987061, 22.2616787], [88.92997742, 22.26124001], [88.93004608, 22.26083946], [88.93022156, 22.26046562], [88.93026733, 22.25997162], [88.930336, 22.25941277], [88.93054199, 22.25887108], [88.93073273, 22.25829887], [88.93091583, 22.25770187], [88.93118286, 22.25714684], [88.931427, 22.25663757], [88.93165588, 22.25623131], [88.93187714, 22.25586891], [88.93200684, 22.2555027], [88.93222046, 22.25522041], [88.93244171, 22.25489235], [88.93266296, 22.25447655], [88.93299866, 22.25407219], [88.93333435, 22.25362206], [88.93370819, 22.25321007], [88.93412781, 22.25283813], [88.93464661, 22.2525425], [88.93502045, 22.25225258], [88.93512726, 22.25213051], [88.93582916, 22.25139046], [88.93611145, 22.25139046], [88.93694305, 22.25056267], [88.93723297, 22.25056267], [88.93889618, 22.24889183], [88.93889618, 22.24860954], [88.9393158, 22.24844742], [88.93968201, 22.24812126], [88.94010925, 22.24782562], [88.94055939, 22.24761009], [88.94100189, 22.24744606], [88.94142914, 22.24727058], [88.94190979, 22.24722099], [88.94241333, 22.2471714], [88.94289398, 22.24699593], [88.94342804, 22.24695015], [88.94400024, 22.24693108], [88.94454956, 22.24687576], [88.9450531, 22.24670601], [88.94560242, 22.24663162], [88.94610596, 22.24649239], [88.94658661, 22.24633217], [88.94703674, 22.24615288], [88.9475708, 22.24608231], [88.94808197, 22.24593163], [88.94861603, 22.24575996], [88.94916534, 22.24552917], [88.949646, 22.2451458], [88.95000458, 22.24458122], [88.95033264, 22.24403381], [88.95068359, 22.24364662], [88.95095062, 22.24333191], [88.95114136, 22.24303627], [88.95134735, 22.24273109], [88.95146942, 22.24232292], [88.95162201, 22.24191284], [88.95166779, 22.24144173], [88.95166779, 22.240942], [88.95166779, 22.24041939], [88.95166779, 22.23990059], [88.95166779, 22.23940086], [88.9516983, 22.23890114], [88.95189667, 22.23843956], [88.95194244, 22.23793411], [88.95195007, 22.2373867], [88.95199585, 22.23681068], [88.95218658, 22.23626137], [88.9523468, 22.23569298], [88.95252228, 22.2351265], [88.95272064, 22.23460197], [88.95277405, 22.23407364], [88.95279694, 22.23359108], [88.95291901, 22.23320198], [88.95302582, 22.23286247], [88.95304871, 22.23252296], [88.95305634, 22.23217964], [88.95310974, 22.23185158], [88.95324707, 22.23155022], [88.95332336, 22.23121071], [88.95336151, 22.23085213], [88.95347595, 22.23053169], [88.95358276, 22.23018074], [88.95363617, 22.22977257], [88.95374298, 22.22936058], [88.95381927, 22.22895432], [88.95386505, 22.22853088], [88.9539032, 22.22810173], [88.95391846, 22.22766495], [88.9540329, 22.22721863], [88.95413971, 22.22671509], [88.95417023, 22.22619247], [88.95415497, 22.22569084], [88.95407867, 22.22524071], [88.95385742, 22.22493172], [88.95352936, 22.22472191], [88.95313263, 22.22455025], [88.95262909, 22.22443962], [88.95205688, 22.22434044], [88.95147705, 22.22441483], [88.95085907, 22.22443962], [88.95018768, 22.22442055], [88.94953156, 22.22431946], [88.94888306, 22.22421074], [88.94831848, 22.22423744], [88.94788361, 22.22440147], [88.94747162, 22.22443962], [88.94703674, 22.22444916], [88.94661713, 22.22444916], [88.94615936, 22.22443962], [88.94571686, 22.22444916], [88.94532013, 22.22447777], [88.94491577, 22.22459221], [88.94445038, 22.22470284], [88.94394684, 22.22471809], [88.94342041, 22.22472191], [88.94285583, 22.22474289], [88.942276, 22.22483253], [88.9417038, 22.22501183], [88.94112396, 22.22521019], [88.94048309, 22.22528267], [88.93987274, 22.22535706], [88.93934631, 22.22551155], [88.9388504, 22.22561073], [88.93841553, 22.22579765], [88.93791199, 22.22596169], [88.93733978, 22.22615242], [88.93672943, 22.22634315], [88.93608093, 22.22639275], [88.93547821, 22.22640038], [88.93494415, 22.22644615], [88.93447876, 22.22661018], [88.93396759, 22.22666931], [88.93341827, 22.2267189], [88.93286133, 22.22686195], [88.93222046, 22.22693634], [88.9315567, 22.22698021], [88.93096161, 22.22713089], [88.93044281, 22.22725105], [88.93002319, 22.22746086], [88.92959595, 22.22754097], [88.92919159, 22.22772026], [88.92871094, 22.22783089], [88.92825317, 22.2280407], [88.92778015, 22.22820282], [88.92732239, 22.22836113], [88.92688751, 22.22854042], [88.92645264, 22.22869492], [88.92607117, 22.22890472], [88.92572021, 22.22915077], [88.92536163, 22.22937965], [88.92494965, 22.22961617], [88.92449951, 22.22994041], [88.92398834, 22.23027992], [88.92344666, 22.23063087], [88.92295074, 22.23105049], [88.9223938, 22.23140144], [88.92188263, 22.23174095], [88.92144012, 22.23207474], [88.92108154, 22.23238754], [88.92070007, 22.23262978], [88.92016602, 22.23280907], [88.91960907, 22.23301506], [88.9189682, 22.23303223], [88.91874695, 22.23299408], [88.91831207, 22.23291588], [88.9176712, 22.23275185], [88.91710663, 22.23247147], [88.91668701, 22.23209953], [88.91638947, 22.23167992], [88.91615295, 22.23127174], [88.91597748, 22.23082733], [88.91586304, 22.2303524], [88.91583252, 22.22985268], [88.91584015, 22.22934723], [88.91589355, 22.22885895], [88.91599274, 22.22839165], [88.91609192, 22.22794151], [88.91616821, 22.22749138], [88.9162674, 22.22705269], [88.91638184, 22.22661018], [88.91648102, 22.22612953], [88.91655731, 22.2256031], [88.91658783, 22.22504234], [88.91644287, 22.22460175], [88.91635132, 22.22415924], [88.91616821, 22.22375298], [88.91606903, 22.2233181], [88.9158783, 22.22293282], [88.91571808, 22.22250748], [88.91552734, 22.22205353], [88.91533661, 22.22160149], [88.91523743, 22.22104073], [88.91503143, 22.22060585], [88.9147644, 22.22030067], [88.91448212, 22.22011185], [88.91417694, 22.21999168], [88.91387177, 22.21990395], [88.91352844, 22.21989059], [88.91307068, 22.21997261], [88.9126358, 22.22000313], [88.91223907, 22.22000313], [88.91182709, 22.21998024], [88.91137695, 22.22000313], [88.91085052, 22.22004509], [88.91030121, 22.22023582], [88.90966797, 22.2203331], [88.90910339, 22.22055244], [88.90853882, 22.22081375], [88.9079895, 22.22104073], [88.90744781, 22.22122192], [88.90698242, 22.2215023], [88.90641022, 22.22168922], [88.90589905, 22.22191048], [88.90542603, 22.22208977], [88.90500641, 22.2222805], [88.90458679, 22.22250748], [88.90415955, 22.22278023], [88.90370178, 22.22305489], [88.90323639, 22.22333336], [88.90276337, 22.22359276], [88.90223694, 22.22382164], [88.90177917, 22.22407532], [88.90135193, 22.22440147], [88.90091705, 22.22471428], [88.90045166, 22.22500038], [88.89996338, 22.22528267], [88.89946747, 22.22558212], [88.89898682, 22.22591019], [88.89853668, 22.22631264], [88.8980484, 22.2266407], [88.89754486, 22.22693634], [88.89702606, 22.22721863], [88.89653015, 22.22751999], [88.89604187, 22.22783089], [88.89552307, 22.22810173], [88.89504242, 22.22840118], [88.89459991, 22.22875023], [88.89417267, 22.2291317], [88.89367676, 22.22945213], [88.89315796, 22.22980309], [88.89265442, 22.23023605], [88.89212799, 22.23067284], [88.89160919, 22.23117065], [88.89107513, 22.23167229], [88.89054871, 22.23218346], [88.88999939, 22.23267365], [88.8894577, 22.23314095], [88.88896179, 22.23361015], [88.88848877, 22.23405075], [88.88817596, 22.2345047], [88.8879776, 22.23491096], [88.88780212, 22.2352314], [88.88764954, 22.23552132], [88.88747406, 22.23575783], [88.88726044, 22.23599434], [88.88704681, 22.23629951], [88.8868866, 22.23670769], [88.8866806, 22.23715401], [88.88650513, 22.23766136], [88.8864212, 22.23825264], [88.88639832, 22.23883247], [88.88639832, 22.23933411], [88.88640594, 22.23975945], [88.88646698, 22.24012756], [88.88661194, 22.24046516], [88.8867569, 22.24089622], [88.88698578, 22.24137306], [88.88729858, 22.24186134], [88.88764954, 22.24236107], [88.88802338, 22.24282265], [88.88835144, 22.24333191], [88.88871002, 22.24379921], [88.88910675, 22.24422264], [88.88947296, 22.24466133], [88.88982391, 22.24509621], [88.89015198, 22.24550056], [88.89051056, 22.24585533], [88.89084625, 22.24620819], [88.89118195, 22.24659157], [88.89155579, 22.24698257], [88.89195251, 22.2474308], [88.89235687, 22.24791527], [88.89274597, 22.24841118], [88.89311981, 22.24894142], [88.89348602, 22.24941063], [88.89386749, 22.24982262], [88.89421082, 22.25020027], [88.89451599, 22.25053215], [88.89480591, 22.2508297], [88.89505768, 22.25113106], [88.89523315, 22.25148964], [88.89533234, 22.25193977], [88.89547729, 22.25238991], [88.89544678, 22.25283623], [88.89528656, 22.25323296], [88.8951416, 22.25365257], [88.8950119, 22.25408936], [88.89486694, 22.25455284], [88.89465332, 22.2549305], [88.89433289, 22.25527191], [88.89395142, 22.25555038], [88.89353943, 22.25583267], [88.89309692, 22.25612068], [88.89265442, 22.25641632], [88.89218903, 22.25676155], [88.8916626, 22.2571125], [88.89115143, 22.25749016], [88.89071655, 22.25795174], [88.89048004, 22.25852013], [88.89027405, 22.25903511], [88.89007568, 22.2595005], [88.8899231, 22.25996017], [88.88973236, 22.26043129], [88.88956451, 22.26094437], [88.88947296, 22.26155281], [88.88938141, 22.26220131], [88.8891983, 22.2628231], [88.88905334, 22.26342964], [88.88884735, 22.26398277], [88.88860321, 22.2644825], [88.88832855, 22.26498985], [88.88800049, 22.26548195], [88.88761139, 22.26593208], [88.88712311, 22.26628685], [88.88655853, 22.26656151], [88.88593292, 22.26678276], [88.88523102, 22.26692963], [88.88454437, 22.26705933], [88.88387299, 22.26716042], [88.88321686, 22.2672596], [88.88265991, 22.26741982], [88.88210297, 22.26759148], [88.88162994, 22.26783943], [88.88123322, 22.26814461], [88.88090515, 22.26846504], [88.88066101, 22.26878166], [88.88047791, 22.26910973], [88.88031769, 22.26941109], [88.88018036, 22.2696991], [88.88004303, 22.26999283], [88.87992859, 22.27028847], [88.87976837, 22.27057076], [88.87967682, 22.27091026], [88.87954712, 22.27128029], [88.87937927, 22.27168083], [88.87917328, 22.27210045], [88.87896729, 22.27256966], [88.87877655, 22.27308083], [88.87848663, 22.27350044], [88.87812805, 22.27383995], [88.87773132, 22.27411842], [88.87728119, 22.27433014], [88.87677002, 22.27449226], [88.8762207, 22.27454948], [88.87567902, 22.27459908], [88.87516785, 22.27466011], [88.87465668, 22.27468681], [88.87415314, 22.2747345], [88.87380981, 22.27474403], [88.87364197, 22.27475166], [88.87312317, 22.27468109], [88.87261963, 22.27454948], [88.87211609, 22.27438164], [88.87162781, 22.27411079], [88.87107849, 22.27379036], [88.8706131, 22.27343178], [88.87011719, 22.27306938], [88.86965942, 22.27268028], [88.86920166, 22.27230263], [88.86876678, 22.27187157], [88.86831665, 22.27144051], [88.86785126, 22.27109337], [88.86736298, 22.27083206], [88.86682129, 22.27066612], [88.8662262, 22.27058983], [88.86563873, 22.27064514], [88.86509705, 22.27080917], [88.86463928, 22.27111244], [88.86425781, 22.27150536], [88.86398315, 22.27195358], [88.86380768, 22.27240944], [88.86371613, 22.27286911], [88.86370087, 22.27332687], [88.8637085, 22.27377129], [88.86370087, 22.2742157], [88.86370087, 22.27466011], [88.8636322, 22.27508926], [88.86355591, 22.27551079], [88.86341095, 22.27594757], [88.86315155, 22.27639961], [88.86276245, 22.27682304], [88.86226654, 22.27713966], [88.86173248, 22.27742195], [88.86115265, 22.27763748], [88.86057281, 22.27781105], [88.86000824, 22.27798271], [88.85943604, 22.27816582], [88.85883331, 22.27837944], [88.85822296, 22.27864456], [88.8576889, 22.2789669], [88.8572998, 22.27934074], [88.85701752, 22.27971077], [88.85682678, 22.28005028], [88.85668182, 22.28035164], [88.85656738, 22.28066063], [88.85643768, 22.28096008], [88.85624695, 22.28123856], [88.85601807, 22.28149986], [88.85573578, 22.28175163], [88.85540009, 22.28198051], [88.8549881, 22.28215981], [88.85456848, 22.28231239], [88.85417175, 22.28247261], [88.85381317, 22.28265381], [88.85344696, 22.28288078], [88.85309601, 22.28318024], [88.85277557, 22.28359222], [88.85247803, 22.28401184], [88.85221863, 22.28440285], [88.85202026, 22.28473854], [88.85189056, 22.2850647], [88.85177612, 22.2853775], [88.85164642, 22.28567123], [88.85153198, 22.28599739], [88.85138702, 22.28634071], [88.85122681, 22.28674126], [88.85103607, 22.28715324], [88.85082245, 22.28765297], [88.85058594, 22.28824043], [88.85037231, 22.28884315], [88.84996796, 22.28930855], [88.84947968, 22.28962135], [88.84893036, 22.28982735], [88.84829712, 22.28993034], [88.84764862, 22.29002953], [88.84694672, 22.29008293], [88.84626007, 22.29012108], [88.84610748, 22.2902813], [88.84416962, 22.2902813], [88.84388733, 22.29000282], [88.84361267, 22.29000282], [88.84333038, 22.28972054], [88.84361267, 22.28944397], [88.84388733, 22.28944778], [88.84416962, 22.2891655], [88.84444427, 22.2891655], [88.84471893, 22.28944778], [88.84557343, 22.28934669], [88.84632111, 22.28931808], [88.8470459, 22.28928947], [88.84771729, 22.28923225], [88.8483429, 22.28910255], [88.84889221, 22.28889275], [88.84934998, 22.28858948], [88.84970856, 22.2881794], [88.84996033, 22.28774071], [88.85009003, 22.28729057], [88.85015106, 22.28692627], [88.8502121, 22.28658295], [88.85031891, 22.28624153], [88.85044861, 22.28587532], [88.85060883, 22.28551292], [88.85076904, 22.28517914], [88.85092163, 22.28487206], [88.85105133, 22.28458214], [88.85116577, 22.28429031], [88.85129547, 22.28396034], [88.85148621, 22.28358841], [88.85172272, 22.28320122], [88.85202026, 22.28288269], [88.85238647, 22.28263283], [88.85279083, 22.28242111], [88.85325623, 22.28220558], [88.85372162, 22.28201294], [88.85415649, 22.28179932], [88.85456848, 22.28154373], [88.85494232, 22.28123283], [88.85529327, 22.28089905], [88.85556793, 22.2805481], [88.8557663, 22.28014946], [88.85597229, 22.27971077], [88.8562088, 22.27926254], [88.85652161, 22.27883339], [88.85691833, 22.2784214], [88.85735321, 22.27802849], [88.85780334, 22.27768135], [88.85825348, 22.27743912], [88.85869598, 22.27730942], [88.85912323, 22.27722931], [88.85955811, 22.27715111], [88.86009979, 22.27712059], [88.86068726, 22.27703285], [88.86128235, 22.27686119], [88.86181641, 22.27663994], [88.86225891, 22.27636909], [88.86254883, 22.27602959], [88.86270905, 22.27557945], [88.86275482, 22.27507782], [88.86274719, 22.27456284], [88.86271667, 22.27403069], [88.86271667, 22.27349281], [88.86276245, 22.27296257], [88.86284637, 22.27243996], [88.86303711, 22.27197075], [88.86332703, 22.27156067], [88.86367798, 22.27116966], [88.86408234, 22.27078438], [88.86447144, 22.2704258], [88.86486053, 22.27015114], [88.86530304, 22.26994133], [88.86582947, 22.26981544], [88.8664093, 22.2697506], [88.86696625, 22.2697506], [88.8674469, 22.26986122], [88.86788177, 22.27006531], [88.8682785, 22.27040291], [88.8686676, 22.27080917], [88.86909485, 22.27121735], [88.86954498, 22.27158356], [88.87003326, 22.27188492], [88.87050629, 22.27217293], [88.87101746, 22.27246284], [88.87149048, 22.27275276], [88.87192535, 22.27301598], [88.87233734, 22.27325249], [88.8727417, 22.27346992], [88.87313843, 22.27362251], [88.87354279, 22.27370262], [88.8739624, 22.27373123], [88.87438202, 22.27373123], [88.87481689, 22.27373123], [88.87528229, 22.27373123], [88.87571716, 22.27373123], [88.8761673, 22.27367973], [88.87665558, 22.27355003], [88.87711334, 22.27326012], [88.8775177, 22.27280807], [88.87785339, 22.27225304], [88.87814331, 22.27165031], [88.87839508, 22.27109528], [88.87861633, 22.2705822], [88.87882233, 22.27011299], [88.87896729, 22.26971245], [88.87911224, 22.26934242], [88.87928009, 22.2689724], [88.8794632, 22.26857948], [88.87970734, 22.26820946], [88.88005066, 22.26786232], [88.88040924, 22.26753044], [88.88080597, 22.2672596], [88.88117218, 22.26702118], [88.88153076, 22.26682281], [88.88185883, 22.26663017], [88.88219452, 22.26646233], [88.88259125, 22.26631927], [88.88304138, 22.26621056], [88.88353729, 22.26611137], [88.88405609, 22.26598167], [88.88459015, 22.2659111], [88.88511658, 22.26587677], [88.88564301, 22.2658329], [88.88614655, 22.2657299], [88.88657379, 22.26554489], [88.88693237, 22.26527214], [88.88723755, 22.26490974], [88.88749695, 22.26445007], [88.88771057, 22.26389122], [88.88786316, 22.26326752], [88.88799286, 22.26266289], [88.88804626, 22.26206017], [88.88809204, 22.26149178], [88.88820648, 22.26095772], [88.88831329, 22.26041985], [88.8884201, 22.25985146], [88.88858795, 22.25928116], [88.8887558, 22.25871086], [88.88900757, 22.2582283], [88.88929749, 22.25782013], [88.88962555, 22.25746918], [88.88994598, 22.25710106], [88.89025879, 22.25667953], [88.89057922, 22.25621986], [88.89095306, 22.25576973], [88.8914566, 22.2553997], [88.89203644, 22.25513458], [88.89258575, 22.25484657], [88.893013, 22.25440025], [88.89333344, 22.25388908], [88.89305878, 22.25361061], [88.89332581, 22.25333023], [88.89333344, 22.25194359], [88.89343262, 22.2515316], [88.8932724, 22.25104713], [88.89293671, 22.25061226], [88.89251709, 22.2501812], [88.89208221, 22.24969482], [88.89163208, 22.24913216], [88.89112091, 22.24859428], [88.89061737, 22.24804878], [88.89013672, 22.24749184], [88.88970184, 22.24695396], [88.8892746, 22.24650192], [88.88889313, 22.24611092], [88.8885498, 22.2457428], [88.88828278, 22.24534225], [88.88801575, 22.24495125], [88.88772583, 22.24454308], [88.88742828, 22.24415016], [88.88713074, 22.24374008], [88.88691711, 22.24327469], [88.88667297, 22.24282837], [88.88639832, 22.24242592], [88.88613892, 22.24203491], [88.8859024, 22.24162102], [88.88564301, 22.24120522], [88.88545227, 22.24071312], [88.88532257, 22.24012756], [88.88523102, 22.23949242], [88.88514709, 22.2388401], [88.88522339, 22.23816109], [88.88529968, 22.2374649], [88.88543701, 22.23679161], [88.88565826, 22.23621368], [88.88594055, 22.23572159], [88.88622284, 22.23526192], [88.88646698, 22.23480415], [88.88674164, 22.23437691], [88.8870163, 22.23397827], [88.88733673, 22.2336216], [88.88767242, 22.23326874], [88.88799286, 22.23286819], [88.88835907, 22.23244286], [88.88877106, 22.23195076], [88.88922882, 22.23143959], [88.88972473, 22.23098564], [88.89021301, 22.23058128], [88.89069366, 22.23023605], [88.89111328, 22.22986031], [88.89154816, 22.22947121], [88.89203644, 22.22907066], [88.89254761, 22.22864532], [88.89306641, 22.22821236], [88.89361572, 22.2277813], [88.89416504, 22.22737694], [88.89472198, 22.22701073], [88.89525604, 22.22668266], [88.89576721, 22.22639275], [88.89621735, 22.22610855], [88.89663696, 22.22583008], [88.89700317, 22.22554207], [88.8973465, 22.22520828], [88.89772034, 22.22487831], [88.89816284, 22.22455025], [88.89874268, 22.22426033], [88.89923859, 22.22379494], [88.89974976, 22.22328758], [88.90033722, 22.22285271], [88.90101624, 22.22250748], [88.90170288, 22.2221508], [88.90231323, 22.22172928], [88.90294647, 22.22140312], [88.90357971, 22.22113228], [88.90415192, 22.22084618], [88.90470123, 22.22055244], [88.90523529, 22.22027206], [88.9057312, 22.22000694], [88.90619659, 22.21978951], [88.90666962, 22.21969032], [88.90709686, 22.21953011], [88.9076004, 22.21943283], [88.9080658, 22.21928024], [88.90853882, 22.21916008], [88.90898895, 22.21897316], [88.90949249, 22.21884918], [88.90995026, 22.21865273], [88.9105072, 22.21852112], [88.91107178, 22.21839523], [88.91155243, 22.21814156], [88.9119339, 22.21782875], [88.91234589, 22.21763039], [88.91275024, 22.21742058], [88.91313171, 22.21714973], [88.91343689, 22.21682739], [88.91368103, 22.21643829], [88.91388702, 22.21610832], [88.91398621, 22.21577454], [88.91398621, 22.21541023], [88.91391754, 22.21503258], [88.91389465, 22.21466446], [88.91388702, 22.21430779], [88.91387939, 22.21395302], [88.91383362, 22.21358871], [88.91374969, 22.21318817], [88.91364288, 22.21273232], [88.91361237, 22.21222496], [88.91358948, 22.21172142], [88.91348267, 22.21129036], [88.9133606, 22.21088219], [88.91330719, 22.2104435], [88.91319275, 22.21002007], [88.91306305, 22.20959854], [88.91291046, 22.20916176], [88.91273499, 22.20871925], [88.91249847, 22.20829964], [88.91221619, 22.20788193], [88.91195679, 22.20745468], [88.91170502, 22.20699883], [88.91140747, 22.20655823], [88.91111755, 22.20609283], [88.91081238, 22.20560074], [88.91043854, 22.20510292], [88.90991211, 22.20467949], [88.9094162, 22.20416069], [88.90886688, 22.20364952], [88.90827942, 22.2031498], [88.90769958, 22.20264244], [88.90717316, 22.20206261], [88.90661621, 22.20156288], [88.90614319, 22.20112038], [88.90576172, 22.20072937], [88.90554047, 22.20034218], [88.90534973, 22.20004082], [88.90525055, 22.19970131], [88.90509033, 22.19938087], [88.904953, 22.19900894], [88.90476227, 22.1986084], [88.90457153, 22.19817162], [88.90445709, 22.19770813], [88.90448761, 22.19724274], [88.90466309, 22.19676018], [88.90479279, 22.19621277], [88.90500641, 22.19566154], [88.90522766, 22.19506264], [88.90532684, 22.19439125], [88.90554047, 22.19384384], [88.90577698, 22.19334221], [88.90600586, 22.19288063], [88.90625763, 22.19246483], [88.90647888, 22.19202995], [88.9067688, 22.19168282], [88.90710449, 22.19137192], [88.90742493, 22.19103432], [88.90769958, 22.1906414], [88.90805054, 22.19029045], [88.90843964, 22.18999481], [88.90880585, 22.18968773], [88.90914917, 22.18934059], [88.90947723, 22.18897247], [88.90984344, 22.1886158], [88.91021729, 22.18826294], [88.91054535, 22.18788147], [88.91083527, 22.18751717], [88.91113281, 22.18721008], [88.91138458, 22.18691635], [88.91160583, 22.18660164], [88.9118042, 22.1862545], [88.91201019, 22.1859417], [88.91230774, 22.18571281], [88.91262054, 22.18549156], [88.91285706, 22.18514061], [88.91311646, 22.18477631], [88.91345978, 22.18444252], [88.91382599, 22.18410301], [88.91417694, 22.1837101], [88.9145813, 22.18333054], [88.91499329, 22.18295288], [88.91539001, 22.18256187], [88.91583252, 22.18219948], [88.91621399, 22.18179512], [88.9165802, 22.18139076], [88.91694641, 22.18098831], [88.91732788, 22.18061256], [88.9177475, 22.18027687], [88.91808319, 22.17984962], [88.9184494, 22.1794529], [88.91880798, 22.17905807], [88.91915894, 22.17868233], [88.91947937, 22.17828178], [88.91973114, 22.17782402], [88.91999054, 22.17738152], [88.92022705, 22.17694473], [88.92047119, 22.17651176], [88.92072296, 22.17609215], [88.92092896, 22.17565536], [88.92114258, 22.17519188], [88.92134094, 22.1746769], [88.92138672, 22.1740303], [88.92136383, 22.17332649], [88.92124939, 22.17262077], [88.9210968, 22.17196274], [88.92092896, 22.17136192], [88.92082977, 22.17077065], [88.92080688, 22.17020226], [88.92077637, 22.1696682], [88.92059326, 22.1692028], [88.92045593, 22.16873932], [88.92034149, 22.16828918], [88.92022705, 22.16785812], [88.92005157, 22.1674881], [88.91996002, 22.16707039], [88.9197998, 22.16671371], [88.9196701, 22.16631126], [88.91943359, 22.16596222], [88.9190979, 22.16562843], [88.91860962, 22.16534996], [88.91792297, 22.16529274], [88.91757965, 22.16527939], [88.91725922, 22.16531944], [88.91689301, 22.16551018], [88.91641235, 22.16558266], [88.91593933, 22.16571808], [88.91546631, 22.16583824], [88.91501617, 22.16597176], [88.91458893, 22.16612625], [88.91422272, 22.16632271], [88.91381836, 22.1664753], [88.91343689, 22.16666222], [88.91301727, 22.16684151], [88.91256714, 22.16703224], [88.91216278, 22.16727448], [88.91175079, 22.16752052], [88.91137695, 22.16784096], [88.91098022, 22.16817474], [88.91044617, 22.16847038], [88.90994263, 22.1688385], [88.90943146, 22.1692028], [88.90901184, 22.16961288], [88.90866852, 22.17004967], [88.90838623, 22.17050552], [88.90809631, 22.17093277], [88.9078598, 22.17140007], [88.90758514, 22.17183685], [88.90721893, 22.17221832], [88.90685272, 22.17259026], [88.90654755, 22.17292976], [88.90633392, 22.17334938], [88.90602875, 22.1736927], [88.90569305, 22.1740303], [88.90535736, 22.17435837], [88.9050293, 22.17464256], [88.90473175, 22.17498207], [88.90441895, 22.17530823], [88.90408325, 22.1756115], [88.90364838, 22.1758709], [88.90325165, 22.17612267], [88.90287781, 22.17638969], [88.90249634, 22.17664528], [88.90207672, 22.17681313], [88.90161133, 22.1769619], [88.90116882, 22.17714882], [88.9006424, 22.17726135], [88.90013885, 22.17746162], [88.89958954, 22.17762947], [88.89894104, 22.17778206], [88.89822388, 22.17790794], [88.89746094, 22.17799187], [88.896698, 22.17784309], [88.89595032, 22.17773819], [88.89527893, 22.17754745], [88.8946228, 22.17745018], [88.89411163, 22.17724228], [88.89361572, 22.1770649], [88.89313507, 22.17687225], [88.89268494, 22.17658234], [88.89216614, 22.17628288], [88.89157867, 22.1760006], [88.8910675, 22.17559242], [88.89055634, 22.17517281], [88.8900528, 22.17477989], [88.88957977, 22.17440224], [88.8891983, 22.17397118], [88.88889313, 22.17352104], [88.88861084, 22.1731205], [88.88835144, 22.17276192], [88.8881073, 22.17242241], [88.88793945, 22.17202187], [88.88776398, 22.17157173], [88.88755798, 22.17114449], [88.88742828, 22.17069435], [88.88724518, 22.17030525], [88.88712311, 22.16991997], [88.88697052, 22.1695118], [88.88687897, 22.1690731], [88.88669586, 22.16867256], [88.88658142, 22.16828346], [88.88637543, 22.16797638], [88.88609314, 22.16771889], [88.88575745, 22.1675396], [88.88537598, 22.16753006], [88.88500214, 22.16767502], [88.88463593, 22.16785812], [88.88424683, 22.16806221], [88.88381958, 22.1682415], [88.88336182, 22.1683712], [88.8829422, 22.16859245], [88.88250732, 22.16875267], [88.88208771, 22.16891289], [88.88169861, 22.1690979], [88.8812561, 22.16917992], [88.88083649, 22.16930962], [88.88043213, 22.16943932], [88.87999725, 22.16956139], [88.87956238, 22.16969109], [88.87903595, 22.16974068], [88.87850189, 22.16983986], [88.87795258, 22.16996956], [88.87734985, 22.16999817], [88.87713623, 22.16998672], [88.87670898, 22.1699543], [88.87606812, 22.1697731], [88.87542725, 22.16979027], [88.87480164, 22.16997337], [88.87419128, 22.1701107], [88.87364197, 22.17028809], [88.87317657, 22.17051125], [88.8727951, 22.17075729], [88.87251282, 22.17105293], [88.87226868, 22.17136955], [88.87213898, 22.17176247], [88.87200928, 22.17214012], [88.87190247, 22.17247963], [88.87180328, 22.17279053], [88.87168121, 22.17310143], [88.87158203, 22.17345238], [88.87145233, 22.17385101], [88.87135315, 22.17435265], [88.8711319, 22.17490959], [88.87097168, 22.17559242], [88.87081909, 22.17625237], [88.87063599, 22.17688179], [88.87052155, 22.17749977], [88.87032318, 22.17803192], [88.87018585, 22.17854118], [88.87001038, 22.17899132], [88.86987305, 22.17943764], [88.86974335, 22.17987251], [88.86968231, 22.1803093], [88.86952209, 22.18067551], [88.86940765, 22.18110085], [88.86920166, 22.18150711], [88.86902618, 22.18195152], [88.8688736, 22.1824131], [88.86869049, 22.18283272], [88.8685379, 22.18325615], [88.86834717, 22.1836319], [88.86819458, 22.18404007], [88.86804962, 22.18448067], [88.86788177, 22.18492317], [88.86776733, 22.18532944], [88.86760712, 22.18573189], [88.86750793, 22.18617058], [88.86739349, 22.18661308], [88.86721802, 22.18703461], [88.86701202, 22.18745232], [88.86682892, 22.1878109], [88.86667633, 22.18824196], [88.86651611, 22.18876076], [88.8664093, 22.18936157], [88.86638641, 22.1900425], [88.86638641, 22.19070244], [88.86638641, 22.19131279], [88.86637115, 22.19185257], [88.86627197, 22.19236946], [88.86621094, 22.19291115], [88.86612701, 22.19350243], [88.86618042, 22.19414711], [88.86638641, 22.19483185], [88.86665344, 22.19550514], [88.86707306, 22.19604301], [88.86756134, 22.19645119], [88.86805725, 22.19681931], [88.86855316, 22.1971302], [88.86907959, 22.19732857], [88.86965179, 22.19745255], [88.87021637, 22.19746971], [88.87169647, 22.19746971], [88.87277222, 22.19733238], [88.87314606, 22.19745255], [88.87355042, 22.19748688], [88.87399292, 22.1974926], [88.87444305, 22.19751167], [88.87493134, 22.19753075], [88.87541962, 22.19749832], [88.87592316, 22.19748116], [88.87640381, 22.19752693], [88.87690735, 22.19753456], [88.87745667, 22.19759369], [88.87801361, 22.19771767], [88.87857819, 22.19783211], [88.87910461, 22.19800758], [88.8796463, 22.19815445], [88.8801651, 22.19833565], [88.88063812, 22.19852257], [88.88111877, 22.1986599], [88.88152313, 22.19889069], [88.88194275, 22.19914055], [88.88243866, 22.19938087], [88.88295746, 22.19965553], [88.88343811, 22.20005226], [88.88388062, 22.20055008], [88.8842926, 22.20105553], [88.88467407, 22.20149422], [88.88495636, 22.20187187], [88.88513947, 22.20222282], [88.88526917, 22.20253181], [88.88536835, 22.20285225], [88.88551331, 22.20321846], [88.88565063, 22.20365334], [88.885849, 22.2040844], [88.8860321, 22.20454979], [88.8860321, 22.20510292], [88.8860321, 22.2056694], [88.88607788, 22.20624733], [88.88608551, 22.20682335], [88.88604736, 22.20737267], [88.88591766, 22.20785522], [88.88578796, 22.20833015], [88.88561249, 22.20878029], [88.88549042, 22.20926094], [88.8853302, 22.20971107], [88.88522339, 22.2101593], [88.88504028, 22.21056938], [88.88485718, 22.21098137], [88.88459015, 22.21133804], [88.88424683, 22.21166039], [88.88389587, 22.21198082], [88.88350677, 22.21227074], [88.88308716, 22.21250153], [88.88265228, 22.21270943], [88.882164, 22.21289635], [88.88166809, 22.21307373], [88.88117218, 22.21323967], [88.88066101, 22.21331978], [88.88011932, 22.21339226], [88.87957764, 22.2135601], [88.87902069, 22.21371841], [88.87873077, 22.21375656], [88.87844086, 22.2137928], [88.87784576, 22.21378517], [88.87718201, 22.21371651], [88.87641907, 22.21375084], [88.87567902, 22.21364021], [88.87497711, 22.21352959], [88.8743515, 22.21339607], [88.87378693, 22.21331978], [88.87329865, 22.21323967], [88.87287903, 22.21310806], [88.87245941, 22.21302986], [88.87203217, 22.2129364], [88.87159729, 22.21281242], [88.87117767, 22.21270943], [88.8707962, 22.21254158], [88.87039185, 22.21241951], [88.87000275, 22.21227074], [88.86959076, 22.21217346], [88.8691864, 22.21203041], [88.86875153, 22.21194839], [88.86830902, 22.21186256], [88.86786652, 22.21170235], [88.86736298, 22.2115612], [88.8667984, 22.21145058], [88.86619568, 22.21139526], [88.86559296, 22.21135139], [88.86501312, 22.21125221], [88.86443329, 22.21115494], [88.8638382, 22.21110344], [88.8632431, 22.21104622], [88.86268616, 22.21095848], [88.8621521, 22.21099281], [88.86165619, 22.21092796], [88.8611908, 22.21099663], [88.86066437, 22.21105385], [88.8600769, 22.21103477], [88.85948181, 22.21093559], [88.85889435, 22.21086121], [88.85832214, 22.21089363], [88.85777283, 22.21101952], [88.85718536, 22.21106911], [88.85662079, 22.21108246], [88.85605621, 22.21109962], [88.85544586, 22.21115494], [88.85476685, 22.21112251], [88.85402679, 22.21115494], [88.85325623, 22.21121025], [88.8524704, 22.2113018], [88.85166931, 22.21128464], [88.85090637, 22.21136284], [88.85012817, 22.21138954], [88.84932709, 22.21139908], [88.84851837, 22.2114315], [88.84772491, 22.21154785], [88.84697723, 22.21166039], [88.84623718, 22.21177864], [88.84548187, 22.21191216], [88.84474945, 22.21202278], [88.84410858, 22.21218491], [88.84351349, 22.2123394], [88.84300232, 22.21255302], [88.84254456, 22.21280479], [88.84208679, 22.21307945], [88.84165955, 22.21339226], [88.84129333, 22.21378136], [88.84101105, 22.21426392], [88.84082794, 22.21480751], [88.84069824, 22.21536064], [88.84070587, 22.21595955], [88.84080505, 22.21648979], [88.84088135, 22.21696663], [88.84098053, 22.2173748], [88.84113312, 22.21772194], [88.84130096, 22.21810722], [88.84146118, 22.21854591], [88.84168243, 22.21898079], [88.84194946, 22.21941185], [88.8422699, 22.21977043], [88.8425827, 22.22011757], [88.84286499, 22.2204895], [88.84314728, 22.22084236], [88.84343719, 22.22120094], [88.84375763, 22.22154045], [88.84409332, 22.22187805], [88.84444427, 22.22221947], [88.84480286, 22.22255135], [88.84516144, 22.22285271], [88.84549713, 22.22315598], [88.84578705, 22.22347069], [88.84607697, 22.22380257], [88.84636688, 22.22414207], [88.8466568, 22.22450066], [88.84696198, 22.22486305], [88.84729767, 22.22519112], [88.84767914, 22.22549248], [88.84804535, 22.22582817], [88.84840393, 22.22618675], [88.84874725, 22.22654533], [88.84907532, 22.2269001], [88.84942627, 22.22721863], [88.84976196, 22.22758293], [88.85005188, 22.22798157], [88.85037231, 22.22837257], [88.85073853, 22.22870064], [88.85111237, 22.22906303], [88.85150909, 22.22941017], [88.85193634, 22.22976112], [88.85235596, 22.2301693], [88.85273743, 22.23065948], [88.85311127, 22.23119164], [88.85350037, 22.23175812], [88.85395813, 22.23231316], [88.85440063, 22.23289108], [88.85473633, 22.23356056], [88.85502625, 22.23423195], [88.85535431, 22.23481178], [88.85570526, 22.23526955], [88.85604095, 22.23566055], [88.85633087, 22.23604965], [88.85653687, 22.23645973], [88.85670471, 22.23689079], [88.8568573, 22.23730278], [88.85697174, 22.2377224], [88.85710144, 22.23813057], [88.8572998, 22.23846817], [88.85745239, 22.23890114], [88.85758209, 22.23940086], [88.85777283, 22.2399292], [88.85793304, 22.2404995], [88.85801697, 22.24110603], [88.85809326, 22.24173164], [88.85824585, 22.24236107], [88.8585434, 22.24298859], [88.85894775, 22.2435894], [88.85945129, 22.24414635], [88.86001587, 22.24464226], [88.86061096, 22.24505043], [88.86125946, 22.24538231], [88.86193085, 22.24561119], [88.86256409, 22.24577141], [88.86317444, 22.24597168], [88.86377716, 22.24620819], [88.86435699, 22.2464695], [88.86493683, 22.24671173], [88.86553192, 22.24693108], [88.86611938, 22.24712372], [88.86666107, 22.24735069], [88.86714935, 22.2475872], [88.86763763, 22.24781036], [88.86811829, 22.24802017], [88.86852264, 22.24828148], [88.86889648, 22.24854088], [88.86930847, 22.24877739], [88.86976624, 22.24897194], [88.87023163, 22.2491703], [88.87071228, 22.24934959], [88.87117767, 22.24955368], [88.87164307, 22.24979019], [88.87207031, 22.25006294], [88.87246704, 22.2503376], [88.87287903, 22.25059319], [88.87329102, 22.25085258], [88.873703, 22.25111198], [88.87413025, 22.25135994], [88.87456512, 22.25159645], [88.87503052, 22.25180817], [88.87548828, 22.25206947], [88.87587738, 22.25235748], [88.87604523, 22.25264931], [88.87583923, 22.2528038], [88.87541962, 22.25279427], [88.87496948, 22.25264549], [88.87452698, 22.2524395], [88.87412262, 22.25220299], [88.87365723, 22.25198364], [88.87314606, 22.25175285], [88.872612, 22.25149727], [88.8720932, 22.25123024], [88.87158966, 22.25097847], [88.87110901, 22.25072289], [88.87063599, 22.25041008], [88.87012482, 22.25012016], [88.86959839, 22.24983025], [88.8690567, 22.2495327], [88.86853027, 22.24923134], [88.86799622, 22.24889183], [88.86740875, 22.24858665], [88.86676788, 22.24833107], [88.86617279, 22.24808311], [88.86561584, 22.24785042], [88.86509705, 22.24757957], [88.86464691, 22.24734306], [88.86422729, 22.24715996], [88.86380005, 22.24701118], [88.86334991, 22.24683952], [88.86290741, 22.24666405], [88.86247253, 22.24652481], [88.8620224, 22.24641228], [88.86152649, 22.24623108], [88.86096191, 22.24596977], [88.86035156, 22.24569321], [88.85978699, 22.24542618], [88.85926819, 22.24513054], [88.85877228, 22.24481392], [88.85835266, 22.24444389], [88.85801697, 22.24408531], [88.85774994, 22.24372864], [88.85752869, 22.24345016], [88.85736084, 22.24319267], [88.85719299, 22.24287987], [88.85703278, 22.24253273], [88.85691071, 22.2420826], [88.85675812, 22.24157143], [88.85663605, 22.24097252], [88.85663605, 22.24035263], [88.85656738, 22.23983955], [88.8564682, 22.23944092], [88.85634613, 22.23913002], [88.85621643, 22.23888588], [88.85611725, 22.23861122], [88.85600281, 22.23835182], [88.85588837, 22.23800278], [88.85573578, 22.23765182], [88.85555267, 22.23727226], [88.85530853, 22.23690033], [88.85509491, 22.23654175], [88.85480499, 22.23623848], [88.85452271, 22.23600006], [88.85423279, 22.23593712], [88.85401917, 22.23579979], [88.85387421, 22.23566818], [88.85386658, 22.23513222], [88.85377502, 22.23435783], [88.85353088, 22.23384857], [88.85314178, 22.23339462], [88.8527298, 22.23285866], [88.85228729, 22.23233223], [88.85189056, 22.23181343], [88.85147095, 22.23135185], [88.85105133, 22.23090935], [88.85061646, 22.2304821], [88.85025024, 22.23002434], [88.84989929, 22.22966385], [88.84957123, 22.2294445], [88.84932709, 22.22932243], [88.84895325, 22.22916031], [88.84874725, 22.22890472], [88.84853363, 22.22852325], [88.84822845, 22.22812462], [88.84788513, 22.22774315], [88.84751892, 22.22734833], [88.84715271, 22.22694969], [88.84675598, 22.22657776], [88.84637451, 22.22619438], [88.84597778, 22.22583008], [88.8455658, 22.22547913], [88.84515381, 22.2251358], [88.84475708, 22.22476006], [88.84439087, 22.22436714], [88.84406281, 22.2239399], [88.84369659, 22.22353172], [88.84336853, 22.22310066], [88.84304047, 22.22268295], [88.84269714, 22.22229958], [88.84234619, 22.22195244], [88.84203339, 22.22162056], [88.84172058, 22.22126198], [88.84143066, 22.22086906], [88.84114838, 22.22047234], [88.84088135, 22.22004128], [88.84062195, 22.21962166], [88.8404007, 22.21921158], [88.84024811, 22.21879005], [88.84010315, 22.21842957], [88.83996582, 22.21807289], [88.83982849, 22.21775246], [88.83972931, 22.21738815], [88.83963013, 22.21704292], [88.83953857, 22.21661186], [88.83947754, 22.2161026], [88.83943176, 22.21552658], [88.83953094, 22.21492195], [88.83966827, 22.21435356], [88.83985138, 22.21389008], [88.84005737, 22.21358299], [88.84025574, 22.21332741], [88.84044647, 22.21302986], [88.84068298, 22.21267128], [88.84102631, 22.21232033], [88.84147644, 22.2120285], [88.84194946, 22.21174049], [88.84247589, 22.2115078], [88.84303284, 22.21135139], [88.84353638, 22.21119499], [88.84403229, 22.21106339], [88.84449768, 22.2109127], [88.84496307, 22.21080208], [88.84538269, 22.21066093], [88.84583282, 22.21054268], [88.84628296, 22.21041298], [88.84677887, 22.21029091], [88.84726715, 22.21020317], [88.84771729, 22.21022224], [88.84815216, 22.21017456], [88.848526, 22.21001244], [88.84895325, 22.20984077], [88.84946442, 22.20978928], [88.84996796, 22.20981026], [88.85043335, 22.20990944], [88.85089874, 22.20988274], [88.85137939, 22.20977974], [88.85186768, 22.20972824], [88.85236359, 22.2097187], [88.85282898, 22.20969963], [88.85331726, 22.20965004], [88.8538208, 22.20958138], [88.85428619, 22.20967293], [88.85479736, 22.20969963], [88.8550415, 22.20967484], [88.85527802, 22.20965385], [88.85575104, 22.20952225], [88.85623932, 22.20948792], [88.85674286, 22.20953178], [88.85721588, 22.20959282], [88.85769653, 22.20951271], [88.85816193, 22.20947266], [88.8585968, 22.20947266], [88.85900879, 22.20951271], [88.85942841, 22.20946312], [88.85988617, 22.2094326], [88.86038971, 22.20942307], [88.86094666, 22.20942116], [88.86151123, 22.20942116], [88.86209106, 22.20942116], [88.86264801, 22.20942116], [88.86316681, 22.20944023], [88.86367798, 22.20950127], [88.86416626, 22.20963097], [88.86469269, 22.20970345], [88.86528015, 22.20977974], [88.8658905, 22.20993233], [88.86651611, 22.21003151], [88.86712646, 22.2101593], [88.8677063, 22.21026039], [88.86824799, 22.21038246], [88.86875916, 22.21056938], [88.8692627, 22.21075249], [88.86979675, 22.21086121], [88.87034607, 22.21099091], [88.87088776, 22.211092], [88.87140656, 22.21118927], [88.87187958, 22.21133232], [88.87233734, 22.21141052], [88.87275696, 22.21151161], [88.87314606, 22.21162987], [88.87355804, 22.21171951], [88.8739624, 22.21186256], [88.87442017, 22.21191978], [88.87494659, 22.21192551], [88.8755188, 22.21193314], [88.87612915, 22.21196365], [88.87677765, 22.21204948], [88.87739563, 22.21213531], [88.87802124, 22.21217346], [88.87866211, 22.21217537], [88.87934875, 22.21212959], [88.88008881, 22.21199226], [88.88085938, 22.21191788], [88.88160706, 22.21182251], [88.88227844, 22.21159935], [88.88282776, 22.2113018], [88.88327789, 22.21092033], [88.88360596, 22.21051598], [88.88384247, 22.21007919], [88.88399506, 22.20963478], [88.88411713, 22.20920372], [88.88419342, 22.2087574], [88.88430023, 22.20832253], [88.88438416, 22.20788193], [88.88442993, 22.20740128], [88.88443756, 22.20689964], [88.88445282, 22.2063694], [88.88444519, 22.20582962], [88.88443756, 22.2052784], [88.88437653, 22.20473289], [88.8842392, 22.20422173], [88.88417816, 22.20371056], [88.88413239, 22.20322227], [88.88401794, 22.20277023], [88.88385773, 22.20233917], [88.88360596, 22.20195961], [88.88331604, 22.20160294], [88.88301849, 22.20128059], [88.8826828, 22.20102119], [88.88230896, 22.20079613], [88.88194275, 22.20055962], [88.88153839, 22.20033073], [88.88108063, 22.20016479], [88.88059235, 22.20003319], [88.88008118, 22.19995308], [88.87961578, 22.1997509], [88.87914276, 22.19960022], [88.87869263, 22.19944191], [88.87822723, 22.19926453], [88.87774658, 22.19920158], [88.87728119, 22.19913483], [88.87684631, 22.19895935], [88.87638092, 22.19902229], [88.87588501, 22.19911385], [88.8753891, 22.19911194], [88.87490082, 22.19907951], [88.87445831, 22.19899178], [88.87403107, 22.19892311], [88.87358093, 22.19889259], [88.87310791, 22.19889259], [88.87258148, 22.19889259], [88.87198639, 22.19889259], [88.87135315, 22.19889259], [88.87063599, 22.19889259], [88.86991119, 22.19889259], [88.86915588, 22.19892311], [88.8684082, 22.19895935], [88.86769867, 22.19885063], [88.86707306, 22.1986084], [88.86651611, 22.19835281], [88.86602783, 22.19815445], [88.86553955, 22.19808769], [88.86511993, 22.19820023], [88.86488342, 22.1985054], [88.86466217, 22.19885635], [88.8644104, 22.19922066], [88.86416626, 22.19964409], [88.86391449, 22.20006943], [88.86364746, 22.20049286], [88.8633728, 22.20089149], [88.8631134, 22.20134926], [88.86288452, 22.2018013], [88.86263275, 22.20219231], [88.86235046, 22.20256042], [88.86207581, 22.20293999], [88.86180115, 22.2033329], [88.86151123, 22.20373154], [88.86118317, 22.20409393], [88.86083221, 22.20446205], [88.860466, 22.20485115], [88.86004639, 22.20518112], [88.85958099, 22.20543098], [88.85907745, 22.20561218], [88.85858917, 22.20583153], [88.85806274, 22.20604134], [88.8574295, 22.2062397], [88.85671234, 22.20631981], [88.85597229, 22.20638084], [88.85518646, 22.20638084], [88.8544693, 22.206213], [88.85386658, 22.20599174], [88.85337067, 22.20573235], [88.85294342, 22.20544815], [88.85253906, 22.20516014], [88.85214996, 22.20488548], [88.85177612, 22.20458031], [88.85144043, 22.20423126], [88.85114288, 22.20384789], [88.8508606, 22.20341492], [88.85058594, 22.20296288], [88.85037231, 22.20247078], [88.85015106, 22.20194244], [88.85005951, 22.20134354], [88.84998322, 22.20075417], [88.8498764, 22.20018196], [88.8497467, 22.19959259], [88.849617, 22.19895935], [88.84953308, 22.19821167], [88.84954834, 22.19743156], [88.84963989, 22.19666862], [88.84963226, 22.1959095], [88.84954834, 22.19519043], [88.84950256, 22.19452095], [88.84945679, 22.19395447], [88.84938812, 22.1935215], [88.84925079, 22.19323349], [88.84908295, 22.19299126], [88.84889984, 22.19272041], [88.84873199, 22.19239235], [88.84855652, 22.19196129], [88.84831238, 22.19155121], [88.8480072, 22.19117355], [88.84765625, 22.19083977], [88.84731293, 22.19060135], [88.84693909, 22.19045067], [88.84660339, 22.1903019], [88.84621429, 22.19024658], [88.84580231, 22.19026184], [88.84538269, 22.19029045], [88.84498596, 22.19027138], [88.84461975, 22.19028473], [88.8442688, 22.19031715], [88.84396362, 22.19043541], [88.84361267, 22.19054031], [88.8432312, 22.19067192], [88.8428421, 22.19086266], [88.84247589, 22.19112206], [88.84211731, 22.19141197], [88.84177399, 22.19171715], [88.84145355, 22.19202232], [88.84115601, 22.19232941], [88.84088135, 22.19265938], [88.84065247, 22.1930027], [88.84047699, 22.19337273], [88.84030914, 22.19368935], [88.84015656, 22.19400215], [88.83998871, 22.19425392], [88.83979034, 22.19450188], [88.83959961, 22.19481087], [88.83942413, 22.19519234], [88.8392334, 22.19561195], [88.83909607, 22.19606972], [88.83893585, 22.19651985], [88.83882141, 22.19697189], [88.83869171, 22.19740105], [88.83863068, 22.19785309], [88.83860779, 22.19833946], [88.83859253, 22.19889259], [88.83857727, 22.19951057], [88.83860016, 22.20016479], [88.83857727, 22.20079994], [88.83834839, 22.20140648], [88.8381424, 22.20191383], [88.83804321, 22.2023716], [88.83796692, 22.20277977], [88.837883, 22.20316124], [88.83778381, 22.20352173], [88.83770752, 22.20394325], [88.83759308, 22.20441246], [88.83748627, 22.20491982], [88.83737183, 22.20537567], [88.83727264, 22.20575142], [88.83718109, 22.20607948], [88.83705902, 22.2063694], [88.83694458, 22.20670509], [88.83679199, 22.20705986], [88.83655548, 22.20738602], [88.83625031, 22.20767021], [88.83590698, 22.20798302], [88.83557129, 22.20829964], [88.83519745, 22.20858955], [88.83480072, 22.20885086], [88.83436584, 22.20907211], [88.83386993, 22.20923424], [88.83338928, 22.2094326], [88.832901, 22.20962334], [88.8323822, 22.20976067], [88.83178711, 22.20984077], [88.8309021, 22.21013069], [88.82990265, 22.21013069], [88.82917786, 22.20998955], [88.82824707, 22.20972252], [88.8272171, 22.20882225], [88.82691193, 22.20848846], [88.82657623, 22.20812035], [88.82624054, 22.2076931], [88.82595825, 22.20726967], [88.82571411, 22.20688057], [88.82550049, 22.20650291], [88.82530975, 22.20600319], [88.82509613, 22.2054348], [88.82485199, 22.20487595], [88.82461548, 22.20433617], [88.82453156, 22.20380974], [88.82456207, 22.2033329], [88.82469177, 22.20293999], [88.82479095, 22.20256042], [88.82491302, 22.20219994], [88.82499695, 22.20179939], [88.82505035, 22.20137978], [88.82512665, 22.20095825], [88.82525635, 22.20054054], [88.82537842, 22.20005989], [88.82553864, 22.19947243], [88.82563782, 22.19880104], [88.82546234, 22.1984005], [88.82513428, 22.19812202], [88.82467651, 22.19795036], [88.82417297, 22.19775963], [88.82366943, 22.19750595], [88.82316589, 22.19725227], [88.82262421, 22.19707298], [88.82206726, 22.19690132], [88.8215332, 22.196661], [88.82102203, 22.1964016], [88.82054901, 22.19621849], [88.82012939, 22.19616127], [88.81977081, 22.19628906], [88.81948853, 22.19635963], [88.81925201, 22.19645119], [88.81900787, 22.19666481], [88.81877136, 22.19695473], [88.81855011, 22.19728851], [88.81829834, 22.19766045], [88.81820679, 22.19821167], [88.81809235, 22.19880104], [88.81806183, 22.19941139], [88.81804657, 22.19999123], [88.81804657, 22.20052147], [88.81806183, 22.20099068], [88.81809998, 22.20141792], [88.81816864, 22.2018528], [88.81815338, 22.20229149], [88.81807709, 22.20264244], [88.8180542, 22.20299339], [88.81798553, 22.20335197], [88.81777191, 22.20371246], [88.81749725, 22.20414162], [88.8172226, 22.20469093], [88.81687927, 22.20530128], [88.8163681, 22.20584297], [88.81577301, 22.20631218], [88.81513977, 22.20672798], [88.81455231, 22.20715141], [88.81385803, 22.20750809], [88.8131485, 22.20778656], [88.81243134, 22.20804024], [88.8117218, 22.20824242], [88.81098938, 22.20831108], [88.81027222, 22.20828056], [88.80960083, 22.20815086], [88.80892944, 22.20812607], [88.8082962, 22.20827293], [88.80769348, 22.20839119], [88.80717468, 22.20862389], [88.80671692, 22.20895195], [88.80640411, 22.20943451], [88.80615997, 22.21002388], [88.80601501, 22.21068954], [88.80580139, 22.21132088], [88.80560303, 22.21190834], [88.80544281, 22.21244049]]], [[[88.86194611, 22.39888763], [88.86305237, 22.39777946], [88.86332703, 22.39806175], [88.86361694, 22.39806175], [88.86416626, 22.39860916], [88.86528015, 22.39860916], [88.86638641, 22.39749908], [88.86638641, 22.39722252], [88.8666687, 22.39694405], [88.86667633, 22.39611244], [88.86694336, 22.39583397], [88.8666687, 22.3955555], [88.86667633, 22.39418221], [88.86638641, 22.39389229], [88.86638641, 22.39361], [88.86611176, 22.39333344], [88.86611176, 22.3927784], [88.8658371, 22.39249992], [88.8658371, 22.39222145], [88.86555481, 22.39194679], [88.86555481, 22.39083481], [88.86499786, 22.39027977], [88.86499786, 22.38972282], [88.86444092, 22.38916588], [88.86444092, 22.38889122], [88.86416626, 22.38861275], [88.86416626, 22.38778114], [88.86528015, 22.38666916], [88.86528015, 22.38583183], [88.86554718, 22.38555908], [88.86638641, 22.38639069], [88.86638641, 22.3872242], [88.86667633, 22.38750267], [88.86667633, 22.38778114], [88.86777496, 22.38888931], [88.86776733, 22.38944054], [88.86833191, 22.3900013], [88.86860657, 22.38972282], [88.86888885, 22.38972282], [88.8694458, 22.38916588], [88.87000275, 22.38916969], [88.8702774, 22.38889122], [88.87055206, 22.38889122], [88.87082672, 22.38861275], [88.87110901, 22.38861275], [88.87194824, 22.38778114], [88.8722229, 22.38778114], [88.87248993, 22.38750267], [88.87277985, 22.38750267], [88.87304688, 22.38778114], [88.87333679, 22.38778114], [88.8741684, 22.38861275], [88.8741684, 22.38972282], [88.87361145, 22.39027977], [88.87361145, 22.39166832], [88.87388611, 22.39194679], [88.87361145, 22.39222145], [88.87361145, 22.39305687], [88.87333679, 22.39333344], [88.87333679, 22.39361191], [88.87444305, 22.39472008], [88.87444305, 22.39500237], [88.87388611, 22.3955555], [88.87388611, 22.39583015], [88.87361145, 22.39611244], [88.87361145, 22.39666939], [88.87388611, 22.39694405], [88.87361145, 22.39722252], [88.87361145, 22.39749908], [88.87333679, 22.39777946], [88.87333679, 22.39805984], [88.87304688, 22.3983326], [88.8730545, 22.39860916], [88.8722229, 22.39944267], [88.8722229, 22.40028191], [88.87304688, 22.40028191], [88.87333679, 22.39999199], [88.8741684, 22.40000153], [88.87472534, 22.39944649], [88.87472534, 22.39860916], [88.87527466, 22.39805984], [88.87555695, 22.3983326], [88.8758316, 22.3983326], [88.87610626, 22.39860916], [88.87666321, 22.39860916], [88.8769455, 22.39888763], [88.87750244, 22.39888763], [88.87833405, 22.39972496], [88.87861633, 22.39971924], [88.87916565, 22.40027809], [88.87889099, 22.40055275], [88.87889099, 22.40139008], [88.87916565, 22.40166664], [88.87917328, 22.40250206], [88.87889099, 22.40278053], [88.87889099, 22.40305519], [88.87916565, 22.40333366], [88.87917328, 22.40361214], [88.87861633, 22.4041748], [88.87915802, 22.40400124], [88.8795929, 22.40396309], [88.88012695, 22.40374947], [88.88057709, 22.40321159], [88.8807373, 22.40252686], [88.8806076, 22.40190315], [88.88041687, 22.40128136], [88.88020325, 22.40073967], [88.87998199, 22.40020561], [88.87975311, 22.39970207], [88.8795929, 22.39920425], [88.87944794, 22.39875603], [88.87930298, 22.39834785], [88.87919617, 22.39798164], [88.87911987, 22.39762306], [88.8789978, 22.39733315], [88.87890625, 22.39702034], [88.87888336, 22.39669037], [88.87882233, 22.39635277], [88.87865448, 22.39608383], [88.87856293, 22.39577293], [88.87843323, 22.39550209], [88.8782959, 22.39515114], [88.87811279, 22.39473152], [88.87799072, 22.39421272], [88.87773132, 22.3937912], [88.87745667, 22.39336205], [88.87718964, 22.39291954], [88.87689209, 22.39253044], [88.87663269, 22.39217186], [88.87641144, 22.39181328], [88.87628174, 22.39144707], [88.87612152, 22.39115906], [88.87596893, 22.39089012], [88.87580109, 22.39063072], [88.87561798, 22.39038658], [88.87554932, 22.39004326], [88.87548065, 22.38969231], [88.87530518, 22.38944435], [88.87518311, 22.38915825], [88.87507629, 22.38883018], [88.87500763, 22.38841057], [88.87494659, 22.38792038], [88.87478638, 22.38737106], [88.87484741, 22.38683128], [88.87502289, 22.38631821], [88.87525177, 22.38588142], [88.87539673, 22.38542938], [88.87557983, 22.38504219], [88.87581635, 22.38472939], [88.87601471, 22.38436317], [88.87614441, 22.38391113], [88.87638855, 22.38356018], [88.87664795, 22.38322258], [88.87689209, 22.38287544], [88.87716675, 22.38256264], [88.87748718, 22.38226128], [88.87776947, 22.38195229], [88.87798309, 22.38155174], [88.87809753, 22.38108253], [88.87832642, 22.38066292], [88.87856293, 22.38022041], [88.87879944, 22.37978172], [88.87914276, 22.37946892], [88.87942505, 22.37913322], [88.87966156, 22.3788166], [88.87982941, 22.37848091], [88.87999725, 22.37812233], [88.88020325, 22.37771034], [88.88039398, 22.37725449], [88.88064575, 22.37677193], [88.88102722, 22.37632942], [88.88137054, 22.37584114], [88.88166046, 22.37529945], [88.88189697, 22.37474251], [88.88198853, 22.37416267], [88.88222504, 22.37373543], [88.88250732, 22.37336159], [88.88284302, 22.37302208], [88.8832016, 22.37272263], [88.88347626, 22.37235069], [88.88375092, 22.37199211], [88.88407898, 22.37173271], [88.88440704, 22.37151146], [88.88471985, 22.37129021], [88.88500977, 22.3710804], [88.88529968, 22.3708725], [88.88568115, 22.37076759], [88.88604736, 22.3705616], [88.88646698, 22.37037086], [88.88696289, 22.37024117], [88.88749695, 22.37006187], [88.8881073, 22.37001228], [88.88880157, 22.37001228], [88.88951111, 22.37001228], [88.89022064, 22.37001228], [88.89087677, 22.36979103], [88.89151001, 22.36959267], [88.89208984, 22.36940193], [88.89257813, 22.36915588], [88.89299774, 22.36887169], [88.89340973, 22.36858368], [88.89382935, 22.36832237], [88.89420319, 22.36799049], [88.8944931, 22.36758614], [88.89483643, 22.36723137], [88.89522552, 22.36692047], [88.89556885, 22.36653328], [88.89592743, 22.36614037], [88.89631653, 22.36577034], [88.89663696, 22.3653698], [88.896698, 22.36530876], [88.89778137, 22.36417389], [88.89749908, 22.36417389], [88.89778137, 22.36388016], [88.89694214, 22.36305618], [88.89665985, 22.36306381], [88.89527893, 22.36166954], [88.89527893, 22.36139107], [88.89499664, 22.36111259], [88.89499664, 22.36055946], [88.89527893, 22.36027908], [88.89527893, 22.35860825], [88.89499664, 22.35833359], [88.89499664, 22.35777664], [88.89472198, 22.35749817], [88.89472198, 22.35611153], [88.89499664, 22.35583305], [88.89499664, 22.3555584], [88.89527893, 22.35527992], [88.89583588, 22.35527992], [88.89611053, 22.35500145], [88.89805603, 22.35694885], [88.89805603, 22.3572216], [88.89861298, 22.35778236], [88.89916992, 22.35778236], [88.89943695, 22.35749817], [88.89943695, 22.35667229], [88.89971924, 22.35638809], [88.89971924, 22.35556221], [88.90000153, 22.35527992], [88.90000153, 22.35444069], [88.90027618, 22.35416412], [88.90027618, 22.35389137], [88.90055847, 22.3536129], [88.90055847, 22.35333061], [88.90083313, 22.35305405], [88.90083313, 22.3527813], [88.90087891, 22.35223198], [88.90106201, 22.35186768], [88.90113068, 22.35147285], [88.90122986, 22.35114098], [88.90139008, 22.35083961], [88.90157318, 22.35050011], [88.90172577, 22.35007858], [88.90193176, 22.3496418], [88.90210724, 22.34916115], [88.90228271, 22.34867287], [88.90247345, 22.34821129], [88.90260315, 22.34769821], [88.90278625, 22.34720039], [88.90301514, 22.34669876], [88.90310669, 22.34607124], [88.90320587, 22.34539795], [88.90309143, 22.34469032], [88.90302277, 22.34395027], [88.90280151, 22.3432579], [88.90257263, 22.34260178], [88.90223694, 22.34208107], [88.90194702, 22.34160042], [88.9016571, 22.34115028], [88.90139008, 22.34074593], [88.90112305, 22.34038162], [88.90090179, 22.3400631], [88.90088654, 22.33998871], [88.90083313, 22.33971214], [88.90000153, 22.33888817], [88.90000153, 22.3386097], [88.89971924, 22.33833313], [88.89971924, 22.33805656], [88.89944458, 22.33777809], [88.89943695, 22.33749962], [88.89861298, 22.33667374], [88.89805603, 22.33722305], [88.89778137, 22.33722305], [88.89666748, 22.33833313], [88.89665985, 22.3386097], [88.89639282, 22.33889198], [88.89639282, 22.33945274], [88.89611816, 22.33987808], [88.89592743, 22.34029198], [88.89570618, 22.34071922], [88.89553833, 22.34126091], [88.89533997, 22.34182167], [88.89510345, 22.34229851], [88.89492798, 22.34283257], [88.89469147, 22.34336281], [88.89444733, 22.34387016], [88.89417267, 22.34430885], [88.89391327, 22.34470177], [88.8936615, 22.34506989], [88.89344788, 22.34544373], [88.89321899, 22.34577179], [88.89286041, 22.34605026], [88.89242554, 22.3464241], [88.89183044, 22.34671974], [88.89126587, 22.34711266], [88.89066315, 22.34740257], [88.8901062, 22.34766388], [88.88961029, 22.34791183], [88.88925171, 22.34826088], [88.88886261, 22.34859276], [88.8884201, 22.34882927], [88.88806152, 22.34911156], [88.88774872, 22.34942055], [88.88742828, 22.34972382], [88.88710022, 22.35000038], [88.88676453, 22.35025597], [88.88639832, 22.35044289], [88.88604736, 22.35062218], [88.88566589, 22.35083961], [88.88529968, 22.35110283], [88.88496399, 22.35139847], [88.88455963, 22.35160255], [88.8842392, 22.3518486], [88.88386536, 22.35199547], [88.88358307, 22.35222054], [88.88321686, 22.35240173], [88.88282776, 22.35270119], [88.88241577, 22.35297966], [88.88199615, 22.35318947], [88.88163757, 22.35346031], [88.88126373, 22.35373306], [88.88088226, 22.35404396], [88.88057709, 22.35450172], [88.88031006, 22.35503006], [88.88008118, 22.35556984], [88.87988281, 22.35609818], [88.87970734, 22.35659218], [88.8795166, 22.35707283], [88.87944794, 22.35757256], [88.87941742, 22.35806656], [88.87931061, 22.35851097], [88.87914276, 22.35894966], [88.87889099, 22.35938072], [88.87858582, 22.35981941], [88.8782196, 22.3602314], [88.87776947, 22.36060143], [88.87737274, 22.36107063], [88.87691498, 22.36148262], [88.87641907, 22.36183357], [88.87592316, 22.36214638], [88.87549591, 22.36248207], [88.87509155, 22.36281204], [88.87473297, 22.36314964], [88.87438202, 22.36349297], [88.87395477, 22.36367989], [88.87355804, 22.36388016], [88.87314606, 22.36406136], [88.87269592, 22.36424065], [88.87221527, 22.36440659], [88.87168121, 22.36444664], [88.87113953, 22.36444664], [88.87059784, 22.36444664], [88.87007141, 22.36446762], [88.86959076, 22.3645916], [88.869133, 22.36477089], [88.86872101, 22.36496925], [88.8682785, 22.36507225], [88.86781311, 22.36523819], [88.86736298, 22.36539268], [88.86695099, 22.36555481], [88.86656189, 22.36573219], [88.8662262, 22.36593246], [88.86582184, 22.36610985], [88.86535645, 22.36630821], [88.86490631, 22.36650276], [88.86459351, 22.36678123], [88.86422729, 22.36703873], [88.86385345, 22.36736679], [88.86341858, 22.36769485], [88.86296082, 22.36804008], [88.86250305, 22.36833], [88.86250305, 22.36861229], [88.86222076, 22.36889076], [88.86222076, 22.36917305], [88.86138916, 22.37001228], [88.86138916, 22.3702774], [88.86083221, 22.37083244], [88.86083221, 22.37111092], [88.86083221, 22.37125206], [88.86078644, 22.37170982], [88.86061096, 22.37211037], [88.86054993, 22.37250328], [88.86048126, 22.37285423], [88.86036682, 22.37321663], [88.86029053, 22.3736248], [88.8602829, 22.37407112], [88.8602829, 22.37457085], [88.86030579, 22.37508392], [88.86038208, 22.37558174], [88.8602829, 22.37613106], [88.86013031, 22.37664223], [88.85996246, 22.3772583], [88.85978699, 22.37790108], [88.85957336, 22.37860107], [88.85967255, 22.37927055], [88.85972595, 22.37972069], [88.85972595, 22.38000488], [88.85943604, 22.38028145], [88.85943604, 22.38111305], [88.85916901, 22.38139153], [88.85916901, 22.38222313], [88.85888672, 22.3825016], [88.85884857, 22.38239288], [88.85869598, 22.38271141], [88.85857391, 22.38305855], [88.85834503, 22.38342476], [88.858078, 22.38387489], [88.85781097, 22.38439178], [88.85749054, 22.38501167], [88.85694122, 22.38555908], [88.85666656, 22.38555908], [88.85610962, 22.3861084], [88.85610962, 22.38639069], [88.85558319, 22.38685608], [88.8555069, 22.38691711], [88.85540771, 22.38713264], [88.85533905, 22.38764191], [88.8554306, 22.38824272], [88.8556366, 22.38884163], [88.85566711, 22.38941956], [88.85569, 22.389925], [88.85579681, 22.39038467], [88.85581207, 22.39086914], [88.85569763, 22.39138985], [88.85557556, 22.39187622], [88.8555603, 22.39236259], [88.85560608, 22.39283562], [88.85578156, 22.39328957], [88.8557663, 22.39381218], [88.85559845, 22.39435005], [88.85566711, 22.39481163], [88.85583496, 22.39518356], [88.85604858, 22.39550209], [88.85624695, 22.3958416], [88.85652161, 22.39618111], [88.85684967, 22.39653206], [88.85723114, 22.39687157], [88.85762024, 22.39721107], [88.85797882, 22.39767456], [88.85830688, 22.39806175], [88.85852051, 22.39841652], [88.8587265, 22.39867973], [88.85890961, 22.39895058], [88.85902405, 22.39919472], [88.85922241, 22.39941216], [88.85929108, 22.39985847], [88.85942841, 22.40028191], [88.85955048, 22.40077019], [88.85968781, 22.40126991], [88.85975647, 22.40187263], [88.85992432, 22.4024601], [88.85998535, 22.40307236], [88.86000061, 22.40363121], [88.86000061, 22.40411949], [88.85997772, 22.40449142], [88.85991669, 22.40479088], [88.85984039, 22.40513802], [88.8598175, 22.40565681], [88.85987091, 22.40621948], [88.86000061, 22.4066658], [88.8602829, 22.40694237], [88.8602829, 22.40750313], [88.86055756, 22.40777779], [88.86055756, 22.40833473], [88.86083221, 22.4086132], [88.86083221, 22.40972328], [88.86166382, 22.41055489], [88.86222076, 22.41055489], [88.86250305, 22.41028023], [88.86250305, 22.40971947], [88.86222076, 22.40944481], [88.86222076, 22.40916634], [88.86194611, 22.40889168], [88.86194611, 22.40860939], [88.86166382, 22.40833282], [88.86166382, 22.40722656], [88.86138916, 22.40694427], [88.86138916, 22.40611076], [88.86110687, 22.40583229], [88.8611145, 22.40500069], [88.86138916, 22.40472221], [88.86138916, 22.40416908], [88.86165619, 22.40389061], [88.86165619, 22.40305138], [88.86194611, 22.40277863], [88.86194611, 22.40222168], [88.86222076, 22.40194511], [88.86222076, 22.4011116], [88.86194611, 22.40083313], [88.86194611, 22.40000153], [88.86166382, 22.39972496], [88.86166382, 22.39944649], [88.86194611, 22.39916992], [88.86194611, 22.39888763]]], [[[88.9102478, 22.33291817], [88.90982819, 22.33324242], [88.90942383, 22.33365631], [88.90897369, 22.33408165], [88.90853119, 22.33452034], [88.9081192, 22.33496284], [88.90777588, 22.33540154], [88.90733337, 22.33579063], [88.90703583, 22.33627129], [88.90682983, 22.33678246], [88.90661621, 22.33726311], [88.90644073, 22.33775139], [88.90635681, 22.33827019], [88.90625, 22.3387661], [88.90629578, 22.3393116], [88.90628052, 22.33986855], [88.9061203, 22.34045029], [88.90598297, 22.34106255], [88.90588379, 22.34171295], [88.90585327, 22.34230995], [88.90592194, 22.34280968], [88.90606689, 22.34315109], [88.90611267, 22.34346008], [88.90611267, 22.34376907], [88.90611267, 22.34412956], [88.90611267, 22.3445549], [88.90605927, 22.34502983], [88.90585327, 22.34555817], [88.90567017, 22.3461895], [88.90577698, 22.34691048], [88.90577698, 22.34763145], [88.9056015, 22.34823036], [88.90550232, 22.34875679], [88.90538025, 22.34917641], [88.90529633, 22.34954262], [88.90524292, 22.34991074], [88.90507507, 22.35023308], [88.90493011, 22.35062981], [88.90480042, 22.35102272], [88.90467834, 22.35128593], [88.9045105, 22.35150337], [88.90439606, 22.35178947], [88.90421295, 22.35205269], [88.90403748, 22.35237312], [88.90386963, 22.35276222], [88.90364838, 22.35313225], [88.90351868, 22.35357094], [88.90335846, 22.35398293], [88.90323639, 22.3543911], [88.90305328, 22.35475159], [88.9028244, 22.35512352], [88.90261841, 22.35557938], [88.90235901, 22.35611916], [88.90213013, 22.35685158], [88.90213776, 22.35766029], [88.9021759, 22.35838127], [88.90203857, 22.3589592], [88.90177917, 22.35940933], [88.90177155, 22.35992813], [88.90170288, 22.36041069], [88.90170288, 22.36086082], [88.90171051, 22.36133194], [88.90170288, 22.36185837], [88.90183258, 22.36241913], [88.9019165, 22.36296844], [88.90193176, 22.36348152], [88.90184021, 22.36392021], [88.90171814, 22.36430359], [88.9016571, 22.36469078], [88.90155792, 22.36509132], [88.90142059, 22.36556435], [88.90139008, 22.36609268], [88.90133667, 22.36663246], [88.90119171, 22.36712265], [88.90103149, 22.36758232], [88.90081787, 22.3680706], [88.90058136, 22.36858368], [88.90039063, 22.36912155], [88.90039063, 22.36972809], [88.90027618, 22.37023163], [88.90016937, 22.37077141], [88.90001678, 22.37132835], [88.89971924, 22.37182045], [88.89936066, 22.37232018], [88.89903259, 22.37286949], [88.89868164, 22.37336349], [88.89854431, 22.37391472], [88.89836884, 22.37440491], [88.89821625, 22.37485313], [88.89806366, 22.37526703], [88.89791107, 22.37566185], [88.89781952, 22.37603188], [88.89766693, 22.37631035], [88.89755249, 22.37661171], [88.89737701, 22.37689018], [88.89723206, 22.37726974], [88.89710999, 22.37766457], [88.89698792, 22.37803078], [88.89691162, 22.37844276], [88.89675903, 22.37883186], [88.89660645, 22.37933159], [88.89643097, 22.37982941], [88.89640808, 22.38038063], [88.89653015, 22.38091087], [88.896698, 22.38142967], [88.8970108, 22.38187218], [88.89739227, 22.3822422], [88.897789, 22.38259315], [88.89817047, 22.38290977], [88.89850616, 22.38323021], [88.89884186, 22.38355827], [88.89920044, 22.3839016], [88.89955139, 22.38425255], [88.89993286, 22.38449287], [88.90029907, 22.38474274], [88.90065002, 22.38501167], [88.90099335, 22.38528252], [88.90131378, 22.38554573], [88.90164948, 22.38578224], [88.9019928, 22.38599205], [88.90239716, 22.38614082], [88.90278625, 22.38638115], [88.90328217, 22.38661194], [88.90390015, 22.38676834], [88.90458679, 22.38696289], [88.90529633, 22.38721275], [88.90602112, 22.38746071], [88.90666962, 22.38778114], [88.90731049, 22.3881321], [88.90799713, 22.3884716], [88.90868378, 22.3888607], [88.9094162, 22.38920021], [88.91007233, 22.38964272], [88.9106369, 22.38998222], [88.91121674, 22.39016151], [88.91175079, 22.39014244], [88.91221619, 22.39033318], [88.9126358, 22.3906498], [88.91308594, 22.39088058], [88.91348267, 22.39111137], [88.91387939, 22.39134026], [88.91436005, 22.39142036], [88.91481781, 22.39158249], [88.91529083, 22.39187241], [88.91591644, 22.39194489], [88.91654205, 22.39195061], [88.91682434, 22.39194679], [88.91710663, 22.39194489], [88.91766357, 22.39190102], [88.91832733, 22.39167213], [88.91860962, 22.39167213], [88.91916656, 22.39111137], [88.91944122, 22.39111137], [88.91971588, 22.39138985], [88.91999817, 22.39111137], [88.92028046, 22.39111137], [88.92138672, 22.3900013], [88.92166901, 22.3900013], [88.92193604, 22.38972282], [88.92250061, 22.38972282], [88.92305756, 22.38916588], [88.92193604, 22.38805008], [88.92194366, 22.38777733], [88.92166901, 22.38750267], [88.92166901, 22.38666916], [88.92138672, 22.38639259], [88.92138672, 22.3861084], [88.92166901, 22.38583183], [88.92166901, 22.38444519], [88.92222595, 22.38388824], [88.9227829, 22.38445091], [88.92415619, 22.38445091], [88.92527771, 22.38555908], [88.92527771, 22.38666725], [88.92555237, 22.38694191], [88.92555237, 22.38750267], [88.9263916, 22.38833427], [88.92666626, 22.38833237], [88.92684937, 22.38851738], [88.92694092, 22.38861275], [88.92749786, 22.38861275], [88.92778015, 22.38889122], [88.92805481, 22.38889122], [88.92861176, 22.38944435], [88.9291687, 22.38944054], [88.93000031, 22.39027977], [88.93000031, 22.39138985], [88.92972565, 22.39166641], [88.92973328, 22.39194489], [88.92861176, 22.39306068], [88.9283371, 22.39305687], [88.92805481, 22.39333344], [88.92749786, 22.39333344], [88.92722321, 22.39305687], [88.92694092, 22.39306068], [88.92610931, 22.39222145], [88.92555237, 22.39222145], [88.92500305, 22.39278221], [88.92444611, 22.39222145], [88.92416382, 22.39222145], [88.92388916, 22.39194679], [88.92305756, 22.39194679], [88.92277527, 22.39166832], [88.92194366, 22.39166832], [88.92166901, 22.39194679], [88.92193604, 22.39222145], [88.92280579, 22.39286995], [88.92424011, 22.39352989], [88.92433929, 22.39380074], [88.92472839, 22.39395332], [88.92502594, 22.39418983], [88.92533112, 22.39444923], [88.92562866, 22.39471245], [88.92595673, 22.39497948], [88.9263382, 22.39524269], [88.92668152, 22.39557076], [88.92700195, 22.39590645], [88.92725372, 22.39631271], [88.92749786, 22.39672279], [88.92771912, 22.39717293], [88.9278183, 22.39774132], [88.92800903, 22.39830589], [88.92805481, 22.39891624], [88.92809296, 22.39954376], [88.92816162, 22.40017891], [88.92810059, 22.40078163], [88.92801666, 22.40136147], [88.9278717, 22.40186501], [88.92777252, 22.4023304], [88.9276886, 22.40271378], [88.92753601, 22.40300941], [88.92746735, 22.40332985], [88.92736816, 22.40361214], [88.92723846, 22.40387154], [88.92710876, 22.40411186], [88.92695618, 22.40442085], [88.92672729, 22.40470314], [88.92656708, 22.40507317], [88.92637634, 22.40541458], [88.92613983, 22.40580177], [88.9258194, 22.40623283], [88.92539978, 22.40668297], [88.92485809, 22.40719414], [88.92429352, 22.40765572], [88.92376709, 22.40807152], [88.92333221, 22.40850258], [88.92289734, 22.40894127], [88.92249298, 22.40940094], [88.92193604, 22.40971947], [88.92138672, 22.41002083], [88.92082977, 22.41028023], [88.92028046, 22.41083336], [88.91999817, 22.41082954], [88.91944122, 22.4113903], [88.91916656, 22.4113903], [88.91889191, 22.41167259], [88.91860962, 22.41167259], [88.91832733, 22.41194916], [88.91805267, 22.41194725], [88.91777802, 22.41222191], [88.91750336, 22.41222191], [88.91722107, 22.41249847], [88.91711426, 22.41260338], [88.91677856, 22.41253471], [88.91641998, 22.41251183], [88.91599274, 22.41254616], [88.91558075, 22.4126606], [88.91520691, 22.4127903], [88.91485596, 22.41291237], [88.91448975, 22.41303062], [88.91403198, 22.41311073], [88.91356659, 22.41329002], [88.91304779, 22.41335106], [88.91254425, 22.41345024], [88.91208649, 22.41358376], [88.91159821, 22.41369438], [88.91114044, 22.41388512], [88.91062927, 22.41407204], [88.90998077, 22.41424179], [88.90940094, 22.41457176], [88.90888977, 22.41472435], [88.90777588, 22.41583252], [88.90777588, 22.41694069], [88.90830994, 22.41750145], [88.90862274, 22.41777229], [88.90908051, 22.41798973], [88.90956116, 22.41827965], [88.91004944, 22.41853714], [88.91049194, 22.41888237], [88.91086578, 22.4192028], [88.91124725, 22.41941071], [88.91155243, 22.41966438], [88.91186523, 22.41986275], [88.91239929, 22.41979027], [88.91300964, 22.41960907], [88.91343689, 22.41981888], [88.91371155, 22.42039108], [88.91397858, 22.42071915], [88.91433716, 22.42075157], [88.91462708, 22.42080498], [88.91485596, 22.42094994], [88.91514587, 22.42107964], [88.91551971, 22.4211216], [88.91591644, 22.42111588], [88.91631317, 22.42115974], [88.91666412, 22.42134094], [88.91706848, 22.42144966], [88.9174881, 22.4216404], [88.91799164, 22.42179489], [88.91855621, 22.42201042], [88.91900635, 22.42239952], [88.91933441, 22.42296028], [88.91951752, 22.42363167], [88.91998291, 22.42414474], [88.9204483, 22.42468452], [88.92064667, 22.42531013], [88.92066956, 22.42588615], [88.92061615, 22.42630959], [88.92053986, 22.42669106], [88.92041779, 22.42706108], [88.9202652, 22.42739487], [88.92007446, 22.42770195], [88.91991425, 22.42802238], [88.91972351, 22.42833328], [88.91944122, 22.42861176], [88.91944122, 22.42889023], [88.91889191, 22.42944527], [88.91889191, 22.42972183], [88.91722107, 22.43139076], [88.91722107, 22.43167305], [88.91583252, 22.43305779], [88.91583252, 22.43333244], [88.91555786, 22.43361092], [88.91555786, 22.43388939], [88.91527557, 22.43416786], [88.91527557, 22.43444443], [88.91500092, 22.43472099], [88.91500092, 22.43499947], [88.91472626, 22.43528175], [88.91471863, 22.43555641], [88.91416931, 22.43610191], [88.91416931, 22.43639183], [88.91388702, 22.4366703], [88.91374969, 22.43674278], [88.91358185, 22.43704033], [88.91333771, 22.43734169], [88.91304779, 22.43768311], [88.91271973, 22.43806267], [88.91234589, 22.43848228], [88.91192627, 22.43889046], [88.91142273, 22.43928528], [88.91091919, 22.43974113], [88.91040039, 22.44022942], [88.90981293, 22.44063187], [88.9092865, 22.44108009], [88.90880585, 22.44148064], [88.90836334, 22.44191551], [88.90792847, 22.44234276], [88.90744781, 22.4427166], [88.90690613, 22.4430275], [88.90635681, 22.44333267], [88.90579987, 22.44363976], [88.90531158, 22.44405365], [88.90490723, 22.44452095], [88.90451813, 22.44493484], [88.90422821, 22.44532013], [88.90405273, 22.44569016], [88.90392303, 22.44615173], [88.90388489, 22.44660759], [88.90387726, 22.44701958], [88.90387726, 22.44742012], [88.90389252, 22.44783211], [88.90389252, 22.44825172], [88.90388489, 22.44867706], [88.90384674, 22.4491024], [88.90365601, 22.44951057], [88.90361023, 22.44993401], [88.90361023, 22.45036507], [88.90361023, 22.45079041], [88.90361023, 22.451231], [88.90358734, 22.45166969], [88.9034729, 22.45210266], [88.90335083, 22.45252037], [88.90333557, 22.45296288], [88.9033432, 22.4534111], [88.90332794, 22.45387459], [88.90328979, 22.45432472], [88.90313721, 22.45474052], [88.9031601, 22.45522881], [88.90298462, 22.45568275], [88.90289307, 22.45624352], [88.90270996, 22.45678139], [88.90255737, 22.45736122], [88.90229797, 22.45789146], [88.90210724, 22.45845032], [88.9019165, 22.45898819], [88.90167999, 22.45945168], [88.90148163, 22.45986938], [88.90120697, 22.46019363], [88.90101624, 22.46051598], [88.90084076, 22.46077156], [88.90068054, 22.46099281], [88.90055084, 22.46120262], [88.90040588, 22.46140099], [88.90023804, 22.46159744], [88.90003967, 22.46179008], [88.89987183, 22.46204948], [88.89962769, 22.4622612], [88.89925385, 22.4624424], [88.89888763, 22.4627533], [88.89846039, 22.46305275], [88.89801788, 22.46333694], [88.89763641, 22.46361923], [88.89749908, 22.46389198], [88.89694214, 22.46389198], [88.89472198, 22.46611214], [88.89472198, 22.46722221], [88.89666748, 22.46916771], [88.89666748, 22.46944427], [88.89694214, 22.46972275], [88.89694214, 22.47000122], [88.8972168, 22.4700222], [88.89723969, 22.47055054], [88.89737701, 22.4710083], [88.8975296, 22.47151375], [88.89775085, 22.4720211], [88.89792633, 22.47261238], [88.89807892, 22.47322845], [88.89825439, 22.4738121], [88.89834595, 22.4744339], [88.89848328, 22.47507286], [88.89865112, 22.47567368], [88.89874268, 22.47631264], [88.89881897, 22.47684479], [88.89865875, 22.47728729], [88.8985672, 22.47779274], [88.89839935, 22.47826195], [88.89824677, 22.4786911], [88.89804077, 22.47909927], [88.89778137, 22.47955513], [88.89751434, 22.48009491], [88.89729309, 22.48071289], [88.89701843, 22.48127747], [88.89679718, 22.48178291], [88.89659119, 22.48232079], [88.89642334, 22.48293114], [88.89618683, 22.48350906], [88.89630127, 22.48409843], [88.89641571, 22.48468971], [88.89660645, 22.48525238], [88.89673615, 22.48584938], [88.89700317, 22.48630714], [88.89731598, 22.48665047], [88.89762878, 22.48694611], [88.89789581, 22.48724174], [88.89817047, 22.48756218], [88.89846802, 22.48790169], [88.89884186, 22.48825645], [88.89933014, 22.48852921], [88.89980316, 22.48887062], [88.90026855, 22.48917198], [88.90071106, 22.48944855], [88.90087128, 22.48954582], [88.90111542, 22.4896946], [88.90139008, 22.4897213], [88.90194702, 22.4897213], [88.90277863, 22.49055862], [88.90305328, 22.49055862], [88.90361023, 22.49111176], [88.90348053, 22.49114037], [88.90379333, 22.49141121], [88.90403748, 22.49171257], [88.90428162, 22.49196815], [88.90449524, 22.49222946], [88.90479279, 22.49240494], [88.90503693, 22.49271011], [88.90529633, 22.49305153], [88.90560913, 22.49336815], [88.90585327, 22.49376106], [88.90611267, 22.49416161], [88.90637207, 22.49457932], [88.90656281, 22.49509239], [88.90672302, 22.49565315], [88.90696716, 22.49619865], [88.90705109, 22.49675941], [88.90709686, 22.49726486], [88.90718842, 22.4976902], [88.90721893, 22.49813271], [88.90725708, 22.4985981], [88.90737915, 22.49908638], [88.90735626, 22.49968529], [88.90733337, 22.50037193], [88.90724945, 22.50101089], [88.90722656, 22.50159264], [88.90721893, 22.50221062], [88.90721893, 22.50250053], [88.90693665, 22.50278282], [88.90693665, 22.50306129], [88.90888977, 22.50500298], [88.9091568, 22.50500298], [88.90972137, 22.50555611], [88.90972137, 22.50583076], [88.90944672, 22.50611305], [88.9091568, 22.50611305], [88.90888977, 22.50639153], [88.90777588, 22.50639153], [88.90750122, 22.50667191], [88.90721893, 22.50666618], [88.90694427, 22.50694466], [88.90666962, 22.50694466], [88.90638733, 22.50722313], [88.90611267, 22.50722313], [88.90611267, 22.5075016], [88.90583038, 22.50777817], [88.90583038, 22.50805092], [88.90611267, 22.50833321], [88.90611267, 22.50861168], [88.90666962, 22.50861168], [88.90750122, 22.50778008], [88.90805817, 22.50778008], [88.90833282, 22.5075016], [88.91139221, 22.5075016], [88.91165924, 22.50778008], [88.91222382, 22.50777817], [88.91241455, 22.50797272], [88.91249847, 22.50805473], [88.91306305, 22.50805092], [88.91416931, 22.50917435], [88.91416931, 22.51000023], [88.91443634, 22.51028252], [88.91444397, 22.51111031], [88.91416931, 22.51138115], [88.91444397, 22.51166725], [88.91444397, 22.51194382], [88.91416931, 22.51222038], [88.91416931, 22.51389122], [88.91388702, 22.51416588], [88.91388702, 22.51472282], [88.91221619, 22.51638985], [88.91222382, 22.51666641], [88.91194153, 22.5169487], [88.91194153, 22.51722145], [88.91166687, 22.51749992], [88.91166687, 22.51805496], [88.91139221, 22.51833153], [88.91139221, 22.51889229], [88.91110992, 22.51916885], [88.91110992, 22.5194416], [88.91055298, 22.52000237], [88.91027832, 22.51971817], [88.90972137, 22.51972389], [88.90944672, 22.51944542], [88.90916443, 22.51944542], [88.90888977, 22.51916885], [88.90859985, 22.51917076], [88.90833282, 22.51889229], [88.90805817, 22.51889229], [88.90750122, 22.51833153], [88.90721893, 22.51861382], [88.90693665, 22.51860809], [88.90638733, 22.51917076], [88.90750122, 22.52028084], [88.90805817, 22.52028084], [88.91027832, 22.5225029], [88.91027832, 22.52361107], [88.90999603, 22.52388954], [88.91000366, 22.52416611], [88.90944672, 22.52472115], [88.90944672, 22.52499962], [88.90888977, 22.52555656], [88.90860748, 22.52555656], [88.90805817, 22.52499962], [88.90805817, 22.52472115], [88.90777588, 22.52444458], [88.90777588, 22.5233326], [88.90750122, 22.52305794], [88.90750122, 22.52277946], [88.90721893, 22.5225029], [88.9069519, 22.52229118], [88.90682983, 22.52271271], [88.90663147, 22.52309227], [88.90640259, 22.52349663], [88.90618134, 22.52392006], [88.90596771, 22.52431488], [88.90582275, 22.52466011], [88.9056015, 22.52490616], [88.90541077, 22.52514076], [88.90512085, 22.5253334], [88.90480042, 22.52555847], [88.90447235, 22.52584267], [88.90422821, 22.52626228], [88.90416718, 22.52677536], [88.90412903, 22.52724838], [88.90401459, 22.52764893], [88.90392303, 22.52798271], [88.90390015, 22.52831078], [88.90389252, 22.52861214], [88.90387726, 22.52890968], [88.90383148, 22.52919006], [88.90367126, 22.5294323], [88.90358734, 22.52970314], [88.90349579, 22.52997017], [88.9033432, 22.53026009], [88.90319061, 22.53064537], [88.90310669, 22.53115463], [88.9031601, 22.53170395], [88.90337372, 22.53211975], [88.90363312, 22.53244972], [88.90387726, 22.53276253], [88.90474701, 22.53451157], [88.90460205, 22.53577995], [88.90393829, 22.53765488], [88.90376282, 22.53791237], [88.90328979, 22.5383625], [88.90284729, 22.53886223], [88.90249634, 22.53944206], [88.90220642, 22.5400219], [88.90200806, 22.54063225], [88.90202332, 22.54129028], [88.90219116, 22.54191017], [88.90241241, 22.54246712], [88.90244293, 22.54302025], [88.9022522, 22.54347992], [88.90209961, 22.54390144], [88.9019928, 22.54431915], [88.90193939, 22.54477119], [88.90187836, 22.54521751], [88.90190125, 22.54565239], [88.90192413, 22.54605675], [88.9018631, 22.54644203], [88.9016571, 22.54679298], [88.90139008, 22.54718208], [88.90106964, 22.54762077], [88.90067291, 22.54805946], [88.90023041, 22.54849052], [88.89975739, 22.54886055], [88.89933777, 22.54924965], [88.89907837, 22.54972267], [88.89890289, 22.55020523], [88.89879608, 22.55066109], [88.89866638, 22.55105019], [88.89863586, 22.55137253], [88.89810181, 22.55294991], [88.89772797, 22.55376816], [88.89749146, 22.55415916], [88.89723206, 22.5544796], [88.89697266, 22.5547924], [88.89669037, 22.55509377], [88.89639282, 22.55543137], [88.89607239, 22.55579185], [88.89569092, 22.55614281], [88.89531708, 22.55657005], [88.89499664, 22.55714226], [88.89476776, 22.55779076], [88.89476776, 22.55846977], [88.89493561, 22.55907059], [88.89504242, 22.55964088], [88.89528656, 22.56011009], [88.8956604, 22.5605011], [88.89614105, 22.56079483], [88.89676666, 22.56092453], [88.8973999, 22.56104279], [88.89797211, 22.56110191], [88.89853668, 22.5611515], [88.89910126, 22.56130028], [88.89966583, 22.56142235], [88.900177, 22.56165123], [88.9006958, 22.56181145], [88.90125275, 22.5619297], [88.90183258, 22.56202126], [88.90239716, 22.56218147], [88.90302277, 22.56225014], [88.90362549, 22.56236839], [88.90422821, 22.56248856], [88.90488434, 22.56261826], [88.90552521, 22.56279564], [88.90613556, 22.56299019], [88.9067688, 22.5629673], [88.90724945, 22.56303596], [88.9076767, 22.56307411], [88.9080658, 22.56320381], [88.90848541, 22.56344414], [88.9090271, 22.56359291], [88.90961456, 22.56369591], [88.91015625, 22.56385612], [88.91072083, 22.56397247], [88.91124725, 22.5641613], [88.91178894, 22.56434822], [88.91235352, 22.56443214], [88.91290283, 22.56450272], [88.91335297, 22.56467247], [88.91383362, 22.56471634], [88.91433716, 22.56472969], [88.91485596, 22.56480217], [88.91542816, 22.56495094], [88.91604614, 22.56500053], [88.91667175, 22.56506348], [88.91725922, 22.56524086], [88.91783142, 22.56528473], [88.91838837, 22.56527901], [88.91893768, 22.56529045], [88.919487, 22.565382], [88.92002106, 22.56542015], [88.92016602, 22.56530571], [88.92038727, 22.56513023], [88.92082977, 22.56497955], [88.92125702, 22.5648098], [88.9216156, 22.5644722], [88.92204285, 22.56417465], [88.92247772, 22.56387138], [88.92286682, 22.56352043], [88.92325592, 22.56314659], [88.92365265, 22.56280518], [88.92405701, 22.56248856], [88.92444611, 22.56221962], [88.92481232, 22.56194496], [88.92518616, 22.56166649], [88.92559814, 22.56139183], [88.92603302, 22.56110954], [88.92648315, 22.56083107], [88.92694092, 22.56055641], [88.92738342, 22.56028175], [88.9278183, 22.56002998], [88.92830658, 22.55977058], [88.92878723, 22.55952263], [88.92929077, 22.55919075], [88.92978668, 22.55888748], [88.93031311, 22.55859184], [88.93080902, 22.55830765], [88.93123627, 22.5579319], [88.93157959, 22.55758095], [88.93186951, 22.55724144], [88.93217468, 22.55694389], [88.9324646, 22.55666733], [88.93276215, 22.55643463], [88.93314362, 22.55628777], [88.9335022, 22.55611992], [88.93385315, 22.55599403], [88.93417358, 22.55586243], [88.93450928, 22.55583], [88.93483734, 22.55583], [88.93517303, 22.55584717], [88.9355011, 22.55593109], [88.93580627, 22.55611229], [88.93618011, 22.55629539], [88.93659973, 22.55643463], [88.93699646, 22.55665588], [88.93741608, 22.55682945], [88.93785095, 22.55690956], [88.93826294, 22.5568428], [88.93862915, 22.55664253], [88.93891144, 22.55636024], [88.93914795, 22.5560627], [88.9393692, 22.55577278], [88.93972778, 22.55558968], [88.94011688, 22.55542183], [88.94049072, 22.55521202], [88.94084167, 22.55495644], [88.94121552, 22.5547142], [88.94159698, 22.55449295], [88.94200897, 22.55438042], [88.94242096, 22.55425072], [88.94281769, 22.55410004], [88.9431076, 22.55379295], [88.94345093, 22.55355263], [88.94380951, 22.55337334], [88.94421387, 22.55327415], [88.94468689, 22.55312347], [88.94525909, 22.55306435], [88.94586945, 22.55300713], [88.94642639, 22.55278206], [88.94698334, 22.55255127], [88.94763947, 22.55247307], [88.94824982, 22.55232048], [88.94882202, 22.55223274], [88.94940948, 22.55214119], [88.94998932, 22.55204201], [88.95054626, 22.5519619], [88.95106506, 22.55194664], [88.95155334, 22.55194473], [88.95201874, 22.55190468], [88.95244598, 22.55174828], [88.95288849, 22.55167961], [88.95333862, 22.55166054], [88.95376587, 22.55161095], [88.954216, 22.55153465], [88.95472717, 22.55149841], [88.95530701, 22.55149269], [88.95594788, 22.55137253], [88.95658112, 22.55117035], [88.95719147, 22.55094147], [88.95775604, 22.55067635], [88.95827484, 22.55039406], [88.95876312, 22.55012321], [88.95913696, 22.54980469], [88.95944214, 22.54942131], [88.95970917, 22.54902077], [88.95996094, 22.54862022], [88.9601059, 22.54815102], [88.960289, 22.54780006], [88.96045685, 22.547472], [88.96060944, 22.54715157], [88.96089935, 22.5468998], [88.96109772, 22.54655457], [88.96121216, 22.54626656], [88.96125031, 22.546175], [88.96138763, 22.54583168], [88.9615097, 22.54548073], [88.96160889, 22.54510117], [88.96170807, 22.54466057], [88.96190643, 22.54421806], [88.9620285, 22.54368019], [88.96222687, 22.54317474], [88.96250153, 22.54268074], [88.96274567, 22.54218483], [88.96287537, 22.54162407], [88.9630127, 22.54107475], [88.96315765, 22.54055405], [88.96328735, 22.54006004], [88.96337891, 22.53957367], [88.96353149, 22.53913689], [88.96367645, 22.53868484], [88.96388245, 22.5382328], [88.96406555, 22.53776741], [88.96420288, 22.53730392], [88.96435547, 22.53691292], [88.96443939, 22.53653908], [88.96453857, 22.53616142], [88.96472168, 22.53577232], [88.96492767, 22.53531075], [88.96504211, 22.53471184], [88.96523285, 22.53408623], [88.96528625, 22.53339767], [88.96537781, 22.53271294], [88.96555328, 22.5320549], [88.96568298, 22.53141975], [88.96579742, 22.53085327], [88.96586609, 22.53030968], [88.96599579, 22.5298233], [88.96611023, 22.52931023], [88.96621704, 22.52880478], [88.96640015, 22.52833366], [88.96660614, 22.52786064], [88.96669769, 22.52729225], [88.96691132, 22.52676392], [88.96703339, 22.52618408], [88.96718597, 22.52561188], [88.9672699, 22.52498245], [88.967453, 22.52438927], [88.96749878, 22.52380943], [88.9675293, 22.5233326], [88.96762085, 22.52295876], [88.96774292, 22.5225811], [88.96775818, 22.52215195], [88.96776581, 22.52166939], [88.9677887, 22.52115059], [88.96785736, 22.52065086], [88.96800995, 22.52025032], [88.96806335, 22.51984215], [88.96805573, 22.51944923], [88.96805573, 22.51904869], [88.9681015, 22.51860809], [88.96827698, 22.51815224], [88.96835327, 22.51758957], [88.96848297, 22.5170002], [88.96864319, 22.51638985], [88.96879578, 22.51579094], [88.96891785, 22.51521111], [88.96903992, 22.51470375], [88.96915436, 22.51418114], [88.96923828, 22.51375008], [88.96939087, 22.51342201], [88.96944427, 22.5130825], [88.96947479, 22.51273537], [88.96961212, 22.51247025], [88.96972656, 22.51218987], [88.969841, 22.51190567], [88.96993256, 22.51157188], [88.96997833, 22.51116943], [88.97000122, 22.51068115], [88.97000122, 22.51013184], [88.9699707, 22.50955009], [88.969841, 22.50901222], [88.96977234, 22.50859833], [88.96971893, 22.50694466], [88.97000122, 22.50666618], [88.97000122, 22.50611305], [88.97027588, 22.50583076], [88.97027588, 22.50499725], [88.97055817, 22.50472069], [88.97055817, 22.50388718], [88.97083282, 22.50361061], [88.97083282, 22.50139046], [88.97110748, 22.50111198], [88.97110748, 22.50028038], [88.97138977, 22.50000191], [88.97138977, 22.49889183], [88.97164917, 22.49860954], [88.97166443, 22.49833488], [88.97194672, 22.49805641], [88.97193909, 22.49749947], [88.97222137, 22.4972229], [88.97222137, 22.49694443], [88.97250366, 22.49666786], [88.97249603, 22.49640083], [88.9733429, 22.49556351], [88.9733429, 22.49528122], [88.97360992, 22.49500275], [88.97360992, 22.49472237], [88.97416687, 22.49416924], [88.97416687, 22.49389076], [88.97444153, 22.49361229], [88.97444153, 22.49333954], [88.97499847, 22.49278069], [88.97499847, 22.49250221], [88.97528076, 22.49221992], [88.97528076, 22.49194527], [88.97583008, 22.49139214], [88.97583008, 22.49110985], [88.97611237, 22.49083328], [88.97611237, 22.49055862], [88.97666931, 22.48999977], [88.97666931, 22.48944283], [88.97694397, 22.48916626], [88.97693634, 22.4880619], [88.97721863, 22.48777962], [88.97721863, 22.48611259], [88.97750092, 22.48583031], [88.97750092, 22.48500061], [88.9777832, 22.48472023], [88.97777557, 22.48388863], [88.97807312, 22.48361015], [88.97805786, 22.48333359], [88.97833252, 22.48305702], [88.97833252, 22.48250008], [88.97860718, 22.4822197], [88.97861481, 22.48194695], [88.97888947, 22.48167038], [88.97888947, 22.48140144], [88.97944641, 22.48083305], [88.97944641, 22.4805584], [88.97972107, 22.48028183], [88.97972107, 22.48000145], [88.98000336, 22.47972298], [88.98000336, 22.4794445], [88.98055267, 22.47889137], [88.98055267, 22.4786129], [88.98194122, 22.47722054], [88.98222351, 22.47722435], [88.98305511, 22.47638893], [88.98332977, 22.47639275], [88.98361206, 22.47611046], [88.98416901, 22.47611046], [88.98443604, 22.47583199], [88.98472595, 22.47583771], [88.98500061, 22.47555542], [88.98660278, 22.47555542], [88.98722076, 22.47556114], [88.98750305, 22.47527122], [88.98777771, 22.47527885], [88.98891449, 22.47414207], [88.98945618, 22.47360039], [88.99111176, 22.47194481], [88.99111176, 22.47166634], [88.9916687, 22.47110939], [88.9916687, 22.47083473], [88.99277496, 22.46972466], [88.99305725, 22.46972466], [88.99500275, 22.46777916], [88.99500275, 22.46722221], [88.9952774, 22.46694374], [88.99500275, 22.46666908], [88.99500275, 22.46528053], [88.99472046, 22.46500206], [88.99472046, 22.46417046], [88.9944458, 22.46389198], [88.9944458, 22.46304131], [88.99416351, 22.46277618], [88.99415588, 22.46222115], [88.99388885, 22.46194458], [88.99388885, 22.46138954], [88.99360657, 22.46111107], [88.99360657, 22.46000099], [88.99333191, 22.45972252], [88.99333191, 22.45916939], [88.99307251, 22.45889091], [88.99307251, 22.45861244], [88.99333191, 22.45833206], [88.99333191, 22.4580555], [88.99307251, 22.45778084], [88.99307251, 22.45694351], [88.99333191, 22.45666695], [88.99333191, 22.45555115], [88.99305725, 22.4552784], [88.99307251, 22.45444107], [88.99277496, 22.45416641], [88.9927597, 22.45389175], [88.99250031, 22.45361137], [88.99250031, 22.4533329], [88.99194336, 22.45278168], [88.99194336, 22.4525013], [88.9916687, 22.45222282], [88.9916687, 22.45194435], [88.99111176, 22.45139122], [88.99111176, 22.45083046], [88.9908371, 22.4505558], [88.9908371, 22.45028114], [88.98972321, 22.44916534], [88.98860931, 22.44805527], [88.98860931, 22.44778252], [88.98832703, 22.44750023], [88.98832703, 22.44639015], [88.98805237, 22.44611168], [88.98805237, 22.44555473], [88.98833466, 22.44528008], [88.98832703, 22.44305992], [88.98860931, 22.44278145], [88.98860931, 22.44167137], [88.9888916, 22.4413929], [88.9888916, 22.44083023], [88.98916626, 22.44055557], [88.98916626, 22.44000053], [88.98944092, 22.43972015], [88.98916626, 22.43944359], [88.98999786, 22.43861198], [88.98999786, 22.43833351], [88.99028015, 22.43805504], [88.99028015, 22.43778038], [88.99415588, 22.43388939], [88.99429321, 22.43388939], [88.9944458, 22.43388939], [88.99555206, 22.43278313], [88.99581909, 22.43278313], [88.9963913, 22.43222237], [88.99666595, 22.43222237], [88.99694824, 22.43194389], [88.9972229, 22.43194389], [88.99777985, 22.43139076], [88.99804688, 22.43139076], [88.99804688, 22.43111229], [88.99833679, 22.43083191], [88.99833679, 22.43055534], [88.99861145, 22.43029213], [88.99861145, 22.42972183], [88.99833679, 22.42944527], [88.99833679, 22.42917061], [88.99804688, 22.42889023], [88.99777985, 22.42889023], [88.99758911, 22.42870331], [88.99749756, 22.42861176], [88.99694824, 22.42861366], [88.99666595, 22.42833519], [88.99610901, 22.42833519], [88.99583435, 22.42805672], [88.9952774, 22.42805672], [88.99500275, 22.42777824], [88.9944458, 22.42778015], [88.99430847, 22.42764282], [88.99417114, 22.42750168], [88.99388885, 22.42721939], [88.9936142, 22.42721939], [88.99333191, 22.42694664], [88.99305725, 22.42694664], [88.99278259, 22.42667389], [88.99250031, 22.4263916], [88.9920578, 22.4263916], [88.99194336, 22.4263916], [88.9916687, 22.42610931], [88.99137878, 22.42614174], [88.9908371, 22.4255619], [88.99069214, 22.42555809], [88.99054718, 22.4255619], [88.99001312, 22.42500114], [88.98972321, 22.42500114], [88.98916626, 22.42444038], [88.9888916, 22.4244442], [88.98833466, 22.42389107], [88.98805237, 22.42389107], [88.98583221, 22.42167091], [88.98583221, 22.42139244], [88.98472595, 22.42028236], [88.98472595, 22.42000008], [88.98166656, 22.41694069], [88.98139191, 22.4169445], [88.98110962, 22.41666603], [88.9808197, 22.41666985], [88.98055267, 22.41639137], [88.97915649, 22.41639137], [88.97888947, 22.4161129], [88.97805786, 22.4161129], [88.97777557, 22.41583443], [88.97666931, 22.41583443], [88.97657776, 22.41574287], [88.97638702, 22.41555595], [88.97611237, 22.41555595], [88.97583008, 22.41583443], [88.97555542, 22.41555595], [88.97528076, 22.41555977], [88.97499847, 22.4152813], [88.97471619, 22.4152813], [88.97444153, 22.41499138], [88.97416687, 22.41500282], [88.97389221, 22.41472435], [88.97360992, 22.41472435], [88.97333527, 22.41444588], [88.97277832, 22.41444588], [88.97250366, 22.4141674], [88.97222137, 22.41417122], [88.97193909, 22.41389275], [88.97110748, 22.41389275], [88.97083282, 22.41360855], [88.97027588, 22.41360855], [88.97000122, 22.41333008], [88.96971893, 22.4133358], [88.96944427, 22.41305733], [88.96916962, 22.41305923], [88.9688797, 22.41278267], [88.96861267, 22.41278267], [88.96806335, 22.41222191], [88.96778107, 22.41222191], [88.96722412, 22.41167068], [88.96694183, 22.41167259], [88.96639252, 22.41111183], [88.96611023, 22.41111183], [88.96569824, 22.41069984], [88.96527863, 22.41027641], [88.96499634, 22.41028023], [88.96472168, 22.41000175], [88.96472168, 22.40971947], [88.96416473, 22.40916634], [88.9641571, 22.40889168], [88.96389008, 22.40860939], [88.96389008, 22.40833282], [88.96360779, 22.40805435], [88.96360779, 22.4077816], [88.96333313, 22.40750313], [88.96333313, 22.40667152], [88.96305847, 22.40639305], [88.96305847, 22.40583229], [88.96333313, 22.40555573], [88.96333313, 22.40472221], [88.96389008, 22.40416908], [88.96389008, 22.40389061], [88.96360779, 22.40361214], [88.9641571, 22.40361214], [88.96749878, 22.40028191], [88.96749878, 22.39999199], [88.96778107, 22.39972305], [88.96778107, 22.39944649], [88.96805573, 22.39916992], [88.96806335, 22.39888763], [88.96833038, 22.39860916], [88.96833038, 22.3983326], [88.96861267, 22.39805984], [88.96861267, 22.39777946], [88.9688797, 22.39749908], [88.9688797, 22.39722252], [88.96916962, 22.39694405], [88.96916962, 22.39666939], [88.96943665, 22.39639091], [88.96943665, 22.39611244], [88.97000122, 22.39556313], [88.97000122, 22.39528084], [88.97027588, 22.39500237], [88.97027588, 22.39389229], [88.97000122, 22.39361], [88.97000122, 22.39333344], [88.96944427, 22.3927784], [88.9688797, 22.39278221], [88.96861267, 22.39249992], [88.96721649, 22.39249992], [88.96694183, 22.39222145], [88.96666718, 22.39222145], [88.96611023, 22.39166832], [88.96611023, 22.39138985], [88.96499634, 22.39027977], [88.96499634, 22.3900013], [88.96472168, 22.38972282], [88.96472168, 22.3880558], [88.96499634, 22.38777733], [88.96499634, 22.38721848], [88.96527863, 22.38694382], [88.96527863, 22.38666725], [88.96555328, 22.38639259], [88.96555328, 22.38555908], [88.9658432, 22.38528252], [88.96555328, 22.38501167], [88.96555328, 22.38417244], [88.96527863, 22.38388824], [88.96527863, 22.38195229], [88.96499634, 22.38167], [88.96499634, 22.38111305], [88.96472168, 22.38083076], [88.96472168, 22.38027763], [88.96444702, 22.38000488], [88.96444702, 22.37944221], [88.96416473, 22.37916756], [88.9641571, 22.37611389], [88.96444702, 22.37583351], [88.96444702, 22.37388992], [88.9641571, 22.37361145], [88.96416473, 22.37305641], [88.96389008, 22.37278175], [88.96389008, 22.37249756], [88.96360779, 22.37221909], [88.96360779, 22.37194443], [88.96333313, 22.37166977], [88.96333313, 22.37138748], [88.96250153, 22.3705616], [88.96250153, 22.37028313], [88.96193695, 22.36972237], [88.96194458, 22.36944389], [88.96166992, 22.36916924], [88.96166992, 22.36861229], [88.96138763, 22.36833], [88.96138763, 22.36805534], [88.95833588, 22.36499977], [88.95804596, 22.36499977], [88.95777893, 22.3647213], [88.95722198, 22.3647213], [88.9569397, 22.36499977], [88.95639038, 22.36499977], [88.95583344, 22.36555672], [88.95583344, 22.36583328], [88.95555878, 22.36610985], [88.95555878, 22.36639214], [88.9539032, 22.36806297], [88.95361328, 22.36805534], [88.95333099, 22.36833382], [88.95305634, 22.36833], [88.95276642, 22.36861229], [88.9522171, 22.36861229], [88.95194244, 22.36889076], [88.95083618, 22.36889076], [88.95054626, 22.36917305], [88.94972229, 22.36916924], [88.94944763, 22.36944389], [88.9486084, 22.36944389], [88.94833374, 22.36972237], [88.94805908, 22.36972237], [88.94776917, 22.37001228], [88.9474411, 22.37001038], [88.94721985, 22.37001228], [88.94695282, 22.37028313], [88.9466629, 22.37028313], [88.94555664, 22.37138748], [88.94555664, 22.37444496], [88.9458313, 22.37472153], [88.9458313, 22.37528038], [88.94611359, 22.37555504], [88.94610596, 22.37611389], [88.94638824, 22.37639046], [88.94638824, 22.37778473], [88.9466629, 22.37806129], [88.9466629, 22.37861061], [88.94695282, 22.37889481], [88.94694519, 22.3805542], [88.9466629, 22.38083076], [88.9466629, 22.38139153], [88.9458313, 22.38222313], [88.9458313, 22.3825016], [88.94555664, 22.38278008], [88.94527435, 22.38278008], [88.94472504, 22.38333321], [88.94444275, 22.38333321], [88.94416809, 22.38361168], [88.9438858, 22.38361168], [88.94361115, 22.38388824], [88.94333649, 22.38388824], [88.94304657, 22.38417244], [88.94251251, 22.38417244], [88.9422226, 22.38445091], [88.9419632, 22.38445091], [88.94139099, 22.38501167], [88.9411087, 22.38501167], [88.9394455, 22.38666725], [88.93945313, 22.38721848], [88.93916321, 22.38750267], [88.93916321, 22.38777733], [88.93945313, 22.38805008], [88.9394455, 22.39055824], [88.93916321, 22.39083481], [88.93916321, 22.39166832], [88.93888855, 22.39194489], [88.93889618, 22.39249992], [88.93723297, 22.39418221], [88.93694305, 22.39416695], [88.93527985, 22.39583015], [88.93527985, 22.39639091], [88.93611145, 22.39722252], [88.93638611, 22.39722252], [88.9366684, 22.39749908], [88.93694305, 22.39749908], [88.93723297, 22.39777946], [88.93781281, 22.39777946], [88.93805695, 22.39777946], [88.9383316, 22.39806175], [88.93861389, 22.39805984], [88.93888855, 22.3983326], [88.93972015, 22.3983326], [88.94000244, 22.39860916], [88.9402771, 22.39860916], [88.94055176, 22.39888763], [88.94083405, 22.39888763], [88.94166565, 22.39972305], [88.94167328, 22.39999199], [88.9419632, 22.40028191], [88.94194794, 22.40277863], [88.94167328, 22.40305138], [88.94167328, 22.40389061], [88.94139099, 22.40416908], [88.94139099, 22.40472221], [88.9411087, 22.40500069], [88.9411087, 22.40583229], [88.94082642, 22.40612221], [88.94082642, 22.40750313], [88.9411087, 22.4077816], [88.9411087, 22.40805435], [88.94082642, 22.40833092], [88.94082642, 22.41000175], [88.94055176, 22.41028023], [88.94055176, 22.41055489], [88.94083405, 22.41083336], [88.94055176, 22.41111183], [88.94055176, 22.41639137], [88.9402771, 22.41666985], [88.9402771, 22.41722488], [88.94020844, 22.4185009], [88.94049072, 22.41902733], [88.94055939, 22.41905403], [88.94065094, 22.41909218], [88.94094086, 22.41930389], [88.94123077, 22.41937065], [88.94164276, 22.41943359], [88.94293976, 22.41950035], [88.94380188, 22.41949654], [88.94451904, 22.4195652], [88.94573212, 22.41956139], [88.94631195, 22.41976547], [88.94660187, 22.42003059], [88.94660187, 22.42057228], [88.94631195, 22.42064095], [88.94451904, 22.42063713], [88.94380188, 22.42070198], [88.94300842, 22.42063713], [88.94207764, 22.42064095], [88.94167328, 22.42056084], [88.94136047, 22.42054939], [88.94088745, 22.42047119], [88.94043732, 22.42025948], [88.94001007, 22.41994286], [88.9397049, 22.41948509], [88.9394455, 22.41901016], [88.93923187, 22.41855049], [88.93911743, 22.41803169], [88.93896484, 22.41753578], [88.93894958, 22.41700172], [88.93906403, 22.41644859], [88.93908691, 22.41586113], [88.93901825, 22.41527176], [88.9391098, 22.41465187], [88.93916321, 22.41402245], [88.93916321, 22.41337013], [88.93916321, 22.41267967], [88.93916321, 22.41193199], [88.93916321, 22.41119766], [88.93917084, 22.41045952], [88.93917847, 22.40973091], [88.93924713, 22.4090023], [88.93939209, 22.40830421], [88.9394455, 22.40759087], [88.93950653, 22.40693474], [88.93967438, 22.40639305], [88.9397583, 22.40588188], [88.93991852, 22.40544319], [88.94004059, 22.40493965], [88.94022369, 22.4044342], [88.9402771, 22.40383339], [88.94031525, 22.40320206], [88.9404068, 22.40258217], [88.94036102, 22.40199089], [88.94024658, 22.40139008], [88.94000244, 22.40084648], [88.93965149, 22.40036964], [88.93920135, 22.39996147], [88.93874359, 22.39958382], [88.9382782, 22.39927864], [88.93776703, 22.3990612], [88.93740845, 22.3989315], [88.93723297, 22.39886856], [88.9367218, 22.3986721], [88.93615723, 22.39855194], [88.93576813, 22.3983326], [88.93547058, 22.3980999], [88.93523407, 22.39791298], [88.93500519, 22.39774132], [88.93476868, 22.39751244], [88.93448639, 22.39721107], [88.93421173, 22.39683342], [88.93404388, 22.39637566], [88.9341507, 22.39586258], [88.9343338, 22.39538383], [88.93450928, 22.39495659], [88.93473816, 22.39459038], [88.93499756, 22.39424706], [88.93528748, 22.39391136], [88.93564606, 22.39361], [88.93608093, 22.39332962], [88.93654633, 22.39302254], [88.93702698, 22.39265251], [88.93740845, 22.39214325], [88.93766785, 22.39153099], [88.93776703, 22.3908596], [88.93784332, 22.3902607], [88.93797302, 22.38977242], [88.93802643, 22.38931274], [88.93799591, 22.38886452], [88.93790436, 22.38841057], [88.93801117, 22.38792038], [88.93811798, 22.3873806], [88.93826294, 22.38689995], [88.93840027, 22.38642311], [88.93860626, 22.3860302], [88.93882751, 22.3856411], [88.93912506, 22.38531494], [88.93942261, 22.3849926], [88.93972778, 22.38467979], [88.94004822, 22.38440132], [88.94041443, 22.38414574], [88.94078064, 22.38386345], [88.94116211, 22.38358116], [88.94159698, 22.38332176], [88.94205475, 22.38305855], [88.94254303, 22.38279152], [88.9430542, 22.38252831], [88.94356537, 22.38223839], [88.94397736, 22.3818531], [88.94436646, 22.38144112], [88.94469452, 22.38096809], [88.94493103, 22.38043022], [88.94499207, 22.37982941], [88.94499969, 22.37920952], [88.94499207, 22.37857819], [88.94493866, 22.37793541], [88.94483185, 22.37751961], [88.94477081, 22.37729454], [88.94467163, 22.37658501], [88.94445801, 22.37592888], [88.94429016, 22.37529373], [88.94418335, 22.37469864], [88.94416046, 22.37413216], [88.94412994, 22.37360191], [88.94394684, 22.37315178], [88.94373322, 22.37276268], [88.9438324, 22.37250328], [88.94393158, 22.37215042], [88.94412994, 22.37173843], [88.94431305, 22.37125206], [88.94449615, 22.37080383], [88.9447403, 22.37042046], [88.94502258, 22.37008095], [88.94535828, 22.36978531], [88.94573212, 22.36952019], [88.9460907, 22.36919022], [88.9464798, 22.36889458], [88.94688416, 22.36861992], [88.9473114, 22.36841011], [88.94779968, 22.36827278], [88.94808197, 22.36815071], [88.94825745, 22.3680706], [88.9487381, 22.36792183], [88.94924164, 22.36779213], [88.94975281, 22.36770439], [88.9502182, 22.36751747], [88.95067596, 22.36736107], [88.95114899, 22.3672123], [88.95159912, 22.367033], [88.95209503, 22.36691093], [88.95252228, 22.36669922], [88.95294189, 22.36654091], [88.95320129, 22.36623955], [88.95336914, 22.36589241], [88.95347595, 22.36553192], [88.95345306, 22.36514091], [88.9532547, 22.3647728], [88.95297241, 22.36437225], [88.95262146, 22.36401558], [88.95223999, 22.3637104], [88.95189667, 22.36341476], [88.95155334, 22.36316299], [88.95122528, 22.36289978], [88.95089722, 22.36256981], [88.95058441, 22.36222458], [88.95037842, 22.36175728], [88.95034027, 22.36164284], [88.95020294, 22.36122894], [88.94992828, 22.36074829], [88.94970703, 22.36026192], [88.94953156, 22.35980415], [88.94940948, 22.35939598], [88.94924164, 22.35909081], [88.94917297, 22.35878372], [88.94913483, 22.35851669], [88.94898224, 22.35829163], [88.94889069, 22.35777664], [88.94889069, 22.35638809], [88.9486084, 22.35611153], [88.9486084, 22.35583305], [88.9486084, 22.35553169], [88.9486084, 22.35516167], [88.94862366, 22.35481453], [88.94870758, 22.35449219], [88.94883728, 22.3541851], [88.94882202, 22.35383034], [88.94884491, 22.35347748], [88.94895172, 22.35313225], [88.9491272, 22.3527813], [88.94917297, 22.35233307], [88.94923401, 22.35183525], [88.94940186, 22.35129929], [88.94944763, 22.35072136], [88.94947815, 22.3501091], [88.94960785, 22.34955978], [88.94973755, 22.34905052], [88.94986725, 22.34863091], [88.94999695, 22.34827232], [88.95011902, 22.34794044], [88.95024872, 22.3476162], [88.95027924, 22.34724236], [88.95027924, 22.34680939], [88.95027924, 22.34634209], [88.95031738, 22.34586143], [88.95049286, 22.34544373], [88.95058441, 22.34498024], [88.950737, 22.34453011], [88.95078278, 22.34404182], [88.95068359, 22.34350777], [88.95052338, 22.34291267], [88.95027161, 22.34229851], [88.94998932, 22.34169006], [88.94965363, 22.34115982], [88.94931793, 22.34070015], [88.94908142, 22.34024239], [88.9487915, 22.33987236], [88.94859314, 22.33934021], [88.948349, 22.3388195], [88.94815063, 22.33829117], [88.94798279, 22.33773232], [88.94776154, 22.33722115], [88.94753265, 22.33675957], [88.94735718, 22.33627129], [88.94721985, 22.3357296], [88.947052, 22.33518982], [88.9468689, 22.33465195], [88.9466629, 22.33415413], [88.94646454, 22.3336792], [88.94626617, 22.33321381], [88.94610596, 22.33276176], [88.94592285, 22.33230019], [88.94580841, 22.3318615], [88.94562531, 22.33142662], [88.94553375, 22.3309269], [88.94539642, 22.33045006], [88.94528961, 22.32999229], [88.94525146, 22.32954979], [88.94512939, 22.32917976], [88.94499969, 22.32883263], [88.94496918, 22.32845116], [88.94484711, 22.32809258], [88.94468689, 22.32764244], [88.94462585, 22.32707405], [88.94463348, 22.32641029], [88.94470215, 22.3257618], [88.94484711, 22.325243], [88.94497681, 22.32480049], [88.94509888, 22.32444954], [88.94523621, 22.32415009], [88.9453125, 22.3237896], [88.94546509, 22.32341957], [88.94563293, 22.32297325], [88.9458313, 22.32252312], [88.94606018, 22.32209206], [88.94617462, 22.32155609], [88.9463501, 22.32102013], [88.94641876, 22.32043457], [88.94651794, 22.31985283], [88.94642639, 22.31924248], [88.94638062, 22.31866646], [88.94632721, 22.31816483], [88.94618988, 22.31773186], [88.94611359, 22.31731033], [88.94602203, 22.31689262], [88.94584656, 22.3165226], [88.9457016, 22.31611061], [88.94554901, 22.31567955], [88.94538879, 22.31526566], [88.94525909, 22.31485939], [88.94509888, 22.31451988], [88.9449234, 22.31424522], [88.94476318, 22.31398201], [88.94467926, 22.31367493], [88.94455719, 22.31339073], [88.94439697, 22.31313133], [88.94420624, 22.31289291], [88.94409943, 22.31259918], [88.94393921, 22.31232834], [88.94387817, 22.31200218], [88.94377136, 22.31169319], [88.94361877, 22.31139183], [88.94346619, 22.31104088], [88.94326782, 22.31065178], [88.94290924, 22.31031227], [88.94242096, 22.31005287], [88.94216919, 22.30992126], [88.94194794, 22.30988121], [88.94167328, 22.30988121], [88.94129944, 22.31002235], [88.94094086, 22.31017113], [88.9405365, 22.31028366], [88.94013977, 22.31036949], [88.93969727, 22.31043053], [88.93927765, 22.31053925], [88.93887329, 22.31062126], [88.93852234, 22.31079292], [88.93811035, 22.31083107], [88.93767548, 22.31083488], [88.9372406, 22.31083488], [88.93681335, 22.31083488], [88.9355545, 22.31083488], [88.93513489, 22.31083488], [88.93471527, 22.31083488], [88.93429565, 22.31083488], [88.93386078, 22.31086159], [88.9334259, 22.31100273], [88.93296051, 22.31110382], [88.93247986, 22.31117058], [88.93209839, 22.31139183], [88.93173981, 22.3116703], [88.93138885, 22.31194115], [88.9310379, 22.31219292], [88.93064117, 22.31240273], [88.93023682, 22.31255913], [88.92985535, 22.31274223], [88.92942047, 22.31285286], [88.92906189, 22.31310844], [88.92867279, 22.31331062], [88.9283371, 22.31359291], [88.92805481, 22.31383514], [88.92778015, 22.31406975], [88.92751312, 22.3143425], [88.92727661, 22.31466103], [88.92700958, 22.31495094], [88.92680359, 22.31526566], [88.9265976, 22.31553459], [88.92637634, 22.3157711], [88.92611694, 22.31598854], [88.9258728, 22.31624031], [88.92565155, 22.31657028], [88.92542267, 22.31693077], [88.92511749, 22.31726265], [88.92469025, 22.31755257], [88.92428589, 22.31792259], [88.92388916, 22.31829453], [88.92352295, 22.31871986], [88.92317963, 22.3192749], [88.92285919, 22.31990242], [88.92247772, 22.32043457], [88.92218018, 22.32087135], [88.92184448, 22.32121849], [88.92153168, 22.32155418], [88.92133331, 22.32196426], [88.92105865, 22.32229042], [88.92081451, 22.32267952], [88.92051697, 22.32310295], [88.92019653, 22.32357979], [88.91983032, 22.32407379], [88.91950989, 22.32465172], [88.91919708, 22.32521248], [88.91884613, 22.32560158], [88.91844177, 22.32589149], [88.91810608, 22.32621956], [88.91783905, 22.32658958], [88.91750336, 22.32691193], [88.91713715, 22.32729149], [88.91673279, 22.32772255], [88.91628265, 22.32817459], [88.91578674, 22.3285923], [88.91529083, 22.32888985], [88.91487122, 22.32917213], [88.91452789, 22.32945442], [88.91421509, 22.32975006], [88.91387939, 22.33008385], [88.91349792, 22.33045006], [88.91301727, 22.33084297], [88.91252899, 22.33122063], [88.91213226, 22.33161163], [88.91172791, 22.33189964], [88.91139984, 22.33221245], [88.91105652, 22.33247185], [88.91062927, 22.33263206], [88.9102478, 22.33291817]]]]}}]}\",\"selected\":{\"id\":\"10747\"},\"selection_policy\":{\"id\":\"10748\"}},\"id\":\"10189\",\"type\":\"GeoJSONDataSource\"},{\"attributes\":{},\"id\":\"10744\",\"type\":\"AllLabels\"},{\"attributes\":{\"axis\":{\"id\":\"10247\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"10250\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"10745\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"axis\":{\"id\":\"10206\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"10209\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"10251\",\"type\":\"PanTool\"},{\"attributes\":{},\"id\":\"10212\",\"type\":\"ResetTool\"},{\"attributes\":{},\"id\":\"10252\",\"type\":\"WheelZoomTool\"},{\"attributes\":{},\"id\":\"10747\",\"type\":\"Selection\"},{\"attributes\":{\"callback\":null,\"point_policy\":\"follow_mouse\",\"tooltips\":[[\"Scenario\",\"BASELINE\"],[\"State\",\"@NAME_1\"],[\"Ambient PM\\u2082.\\u2085 concentration\",\"@apm25_popweighted \\u03bcg/m\\u00b3\"],[\"(Lon, Lat)\",\"($x, $y)\"]]},\"id\":\"10213\",\"type\":\"HoverTool\"},{\"attributes\":{\"active_multi\":null,\"logo\":null,\"tools\":[{\"id\":\"10210\"},{\"id\":\"10211\"},{\"id\":\"10212\"},{\"id\":\"10213\"},{\"id\":\"10214\"}]},\"id\":\"10215\",\"type\":\"Toolbar\"},{\"attributes\":{},\"id\":\"10748\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"10253\",\"type\":\"ResetTool\"},{\"attributes\":{},\"id\":\"10255\",\"type\":\"SaveTool\"},{\"attributes\":{},\"id\":\"10749\",\"type\":\"AllLabels\"},{\"attributes\":{\"source\":{\"id\":\"10188\"}},\"id\":\"10308\",\"type\":\"CDSView\"},{\"attributes\":{},\"id\":\"10750\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"active_multi\":null,\"logo\":null,\"tools\":[{\"id\":\"10292\"},{\"id\":\"10293\"},{\"id\":\"10294\"},{\"id\":\"10295\"},{\"id\":\"10296\"}]},\"id\":\"10297\",\"type\":\"Toolbar\"},{\"attributes\":{\"axis\":{\"id\":\"10243\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"10246\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"10752\",\"type\":\"AllLabels\"},{\"attributes\":{\"data_source\":{\"id\":\"10188\"},\"glyph\":{\"id\":\"10305\"},\"hover_glyph\":null,\"muted_glyph\":null,\"nonselection_glyph\":{\"id\":\"10306\"},\"view\":{\"id\":\"10308\"}},\"id\":\"10307\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"formatter\":{\"id\":\"10737\"},\"major_label_policy\":{\"id\":\"10736\"},\"ticker\":{\"id\":\"10207\"}},\"id\":\"10206\",\"type\":\"LinearAxis\"},{\"attributes\":{\"geojson\":\"{\\\"type\\\": \\\"FeatureCollection\\\", \\\"features\\\": [{\\\"id\\\": \\\"0\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.1_1\\\", \\\"HASC_1\\\": \\\"IN.AN\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Andaman and Nicobar\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": \\\"Andaman & Nicobar Islands|Andaman et Nicobar|Iihas de Andama e Nicobar|Inseln Andamanen und Nikobare\\\", \\\"apm25_popweighted\\\": 25.3, \\\"dalys_apm25_rate_6cod_mean_total\\\": 731.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1897.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2628.0, \\\"geo-id\\\": 0, \\\"hpm25_child_popweighted\\\": 260.0, \\\"hpm25_female_popweighted\\\": 299.0, \\\"hpm25_male_popweighted\\\": 215.0, \\\"location\\\": \\\"Andaman and Nicobar\\\", \\\"mort_apm25_6cod_mean_total\\\": 35.0, \\\"mort_hpm25_6cod_mean_total\\\": 85.0, \\\"mort_tpm25_6cod_mean_total\\\": 120.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[93.78772736, 6.85264015], [93.7884903, 6.85257101], [93.78904724, 6.85257101], [93.78904724, 6.85229111], [93.78967285, 6.85229111], [93.78987885, 6.85201311], [93.7901535, 6.85194492], [93.79064178, 6.85166693], [93.79077911, 6.85138893], [93.79091644, 6.85104179], [93.79050446, 6.85062504], [93.79029083, 6.85034704], [93.79000092, 6.85027885], [93.78948212, 6.84990311], [93.78900146, 6.84948492], [93.78837585, 6.84913683], [93.78801727, 6.84872007], [93.78778076, 6.84805584], [93.7875061, 6.84806108], [93.78721619, 6.84778118], [93.78639221, 6.84778118], [93.78610992, 6.84806108], [93.78527832, 6.84806108], [93.78443909, 6.84889984], [93.78444672, 6.84916592], [93.78549194, 6.84992981], [93.78625488, 6.85062504], [93.78676605, 6.85117197], [93.78694153, 6.85167122], [93.7873764, 6.85166693], [93.7873764, 6.85208416], [93.78730774, 6.85235882], [93.7873764, 6.85257101], [93.78772736, 6.85264015]]], [[[93.84874725, 7.28986883], [93.84867859, 7.28945684], [93.84784698, 7.28883219], [93.84694672, 7.28813887], [93.84666443, 7.28723717], [93.84632111, 7.28689003], [93.84625244, 7.28613091], [93.84590149, 7.28564119], [93.84500122, 7.28555489], [93.84471893, 7.28583288], [93.84471893, 7.28694487], [93.84415436, 7.28760815], [93.84415436, 7.28809404], [93.84422302, 7.28844023], [93.84432983, 7.28849316], [93.84464264, 7.28865004], [93.8449173, 7.28844023], [93.84554291, 7.28837204], [93.84583282, 7.28947878], [93.84630585, 7.28969097], [93.84700012, 7.28962088], [93.84720612, 7.28983021], [93.84755707, 7.29017878], [93.8483429, 7.29043007], [93.84874725, 7.28986883]]], [[[93.7195816, 7.20750093], [93.7195816, 7.20687008], [93.71930695, 7.20646], [93.71881866, 7.20639086], [93.71826172, 7.20653009], [93.71749878, 7.20695019], [93.71583557, 7.20694494], [93.71555328, 7.20722294], [93.71499634, 7.20722294], [93.71472168, 7.20694494], [93.71360779, 7.20694494], [93.71333313, 7.20722294], [93.71305847, 7.20722103], [93.71221924, 7.20805502], [93.71221924, 7.20888901], [93.71166992, 7.20944118], [93.71166992, 7.21527815], [93.71138763, 7.21555614], [93.71138763, 7.2158308], [93.71098328, 7.21702099], [93.71021271, 7.21813107], [93.7097168, 7.21889019], [93.70861053, 7.21999979], [93.70861053, 7.22249985], [93.70833588, 7.22277784], [93.70833588, 7.22360992], [93.70805359, 7.22388792], [93.70805359, 7.22416592], [93.70749664, 7.22472191], [93.70749664, 7.2249999], [93.70666504, 7.22583485], [93.70666504, 7.22610998], [93.70639038, 7.22638798], [93.70639038, 7.22694397], [93.70667267, 7.22722006], [93.70667267, 7.22750092], [93.70694733, 7.22777891], [93.70694733, 7.22805405], [93.70722198, 7.22833204], [93.70722198, 7.22861099], [93.70804596, 7.22944021], [93.70804596, 7.23000097], [93.70852661, 7.23090076], [93.70909119, 7.23124981], [93.7097168, 7.23124981], [93.71013641, 7.23062086], [93.71062469, 7.23041296], [93.71083069, 7.2299962], [93.71076202, 7.22923279], [93.71076202, 7.22840118], [93.71131897, 7.22770596], [93.71179962, 7.22729111], [93.7122879, 7.2270112], [93.7122879, 7.22659588], [93.71221924, 7.22617912], [93.71263885, 7.2257638], [93.71311951, 7.22534704], [93.71353912, 7.22486115], [93.71367645, 7.22382021], [93.71360779, 7.22194386], [93.71611023, 7.2194438], [93.71611023, 7.2191658], [93.71639252, 7.21888781], [93.71639252, 7.21832895], [93.71666718, 7.2180562], [93.71666718, 7.21777821], [93.71721649, 7.21721888], [93.71722412, 7.21694422], [93.71833038, 7.2158308], [93.71909332, 7.21569204], [93.71937561, 7.21534395], [93.71986389, 7.21458197], [93.72041321, 7.21409512], [93.72090149, 7.21402597], [93.72117615, 7.21360922], [93.7215271, 7.21312189], [93.72138977, 7.21270704], [93.72103882, 7.21222115], [93.72055817, 7.21166706], [93.72027588, 7.21138906], [93.72027588, 7.21110916], [93.72000122, 7.21083307], [93.72000122, 7.21027708], [93.71971893, 7.20999908], [93.71971893, 7.209167], [93.71971893, 7.20798397], [93.7195816, 7.20750093]]], [[[93.66369629, 7.38403177], [93.66373444, 7.38379717], [93.66410828, 7.38380098], [93.66423035, 7.38376713], [93.66426086, 7.38403177], [93.6653595, 7.38403177], [93.66534424, 7.38376713], [93.66622162, 7.38372612], [93.6661911, 7.38353014], [93.6656189, 7.38351917], [93.6656189, 7.38324118], [93.66538239, 7.38324118], [93.66537476, 7.38349104], [93.66526031, 7.38348913], [93.66424561, 7.38347816], [93.66424561, 7.38321304], [93.66409302, 7.38324118], [93.66370392, 7.38322687], [93.66370392, 7.38350487], [93.66342926, 7.38349104], [93.663414, 7.38321304], [93.66203308, 7.38321114], [93.66202545, 7.38347816], [93.66233063, 7.38351917], [93.66233063, 7.38378286], [93.66339874, 7.38378096], [93.66340637, 7.38404989], [93.66369629, 7.38403177]]], [[[93.76860809, 7.40221882], [93.77111053, 7.39972115], [93.77166748, 7.39972115], [93.77194214, 7.39944506], [93.77194214, 7.39888906], [93.77249908, 7.39833307], [93.77249908, 7.39805508], [93.77222443, 7.39777708], [93.7722168, 7.39750099], [93.77194214, 7.39722109], [93.77194214, 7.39611101], [93.77222443, 7.39583302], [93.77222443, 7.39527702], [93.77111053, 7.39416695], [93.77083588, 7.39416885], [93.77054596, 7.39389086], [93.77027893, 7.39389086], [93.76999664, 7.39362001], [93.76832581, 7.39362001], [93.76805878, 7.39389086], [93.76777649, 7.39389086], [93.76750183, 7.39416885], [93.76721954, 7.39416885], [93.76693726, 7.39389086], [93.76611328, 7.39388895], [93.76555634, 7.39444494], [93.76526642, 7.39444017], [93.7647171, 7.39500093], [93.76444244, 7.39500093], [93.76416779, 7.39528084], [93.7638855, 7.39527702], [93.76277924, 7.39638901], [93.76277924, 7.396667], [93.76249695, 7.39694118], [93.76249695, 7.39777708], [93.76222229, 7.39805508], [93.76249695, 7.39833307], [93.76249695, 7.39861107], [93.7664032, 7.4024992], [93.76638794, 7.40277815], [93.76667023, 7.40305614], [93.76667023, 7.4033308], [93.76721954, 7.40389013], [93.76777649, 7.40389013], [93.76832581, 7.4033308], [93.76833344, 7.40305614], [93.76860809, 7.40277815], [93.76860809, 7.40221882]]], [[[93.6894455, 7.40972185], [93.68972015, 7.40944386], [93.69000244, 7.40944386], [93.6902771, 7.40916586], [93.69055176, 7.40916586], [93.69083405, 7.40944386], [93.6911087, 7.40944386], [93.69139099, 7.40916586], [93.69139099, 7.40888786], [93.69167328, 7.40860081], [93.69194794, 7.40861177], [93.6922226, 7.40833378], [93.6922226, 7.40805578], [93.69166565, 7.40749979], [93.69167328, 7.40722179], [93.69139099, 7.4069438], [93.69139099, 7.40638781], [93.6911087, 7.40611219], [93.6911087, 7.40500021], [93.69139099, 7.40472221], [93.69139099, 7.40416813], [93.69166565, 7.40389013], [93.69167328, 7.4036088], [93.69249725, 7.40277815], [93.69277954, 7.40279102], [93.6938858, 7.40166998], [93.6938858, 7.40139008], [93.69416046, 7.40110922], [93.69416809, 7.40083313], [93.69444275, 7.40055513], [93.69444275, 7.40027714], [93.69473267, 7.39999914], [93.69472504, 7.39972115], [93.69499969, 7.39944506], [93.69499969, 7.39888906], [93.69416809, 7.39805508], [93.69361115, 7.39805984], [93.69333649, 7.39777899], [93.69277954, 7.39777899], [93.69249725, 7.39750099], [93.6922226, 7.39750099], [93.69194794, 7.39722109], [93.69166565, 7.39722109], [93.69139099, 7.396945], [93.6911087, 7.396945], [93.69083405, 7.396667], [93.6894455, 7.396667], [93.68916321, 7.396945], [93.68805695, 7.396945], [93.68777466, 7.39722109], [93.6875, 7.39722109], [93.68444824, 7.40027714], [93.68444824, 7.40055513], [93.68416595, 7.40083313], [93.68416595, 7.40111113], [93.6838913, 7.40139008], [93.6838913, 7.40194607], [93.68360901, 7.4022212], [93.68360901, 7.4036088], [93.68333435, 7.40389013], [93.68360901, 7.40416813], [93.68360901, 7.40472221], [93.68305206, 7.40527821], [93.68307495, 7.40613699], [93.68332672, 7.40639019], [93.68360901, 7.40638781], [93.68444824, 7.40722179], [93.6847229, 7.40722179], [93.68554688, 7.40806103], [93.68583679, 7.40805578], [93.68611145, 7.40833378], [93.6866684, 7.40832901], [93.6875, 7.40917015], [93.6883316, 7.40916586], [93.68888855, 7.40972185], [93.6894455, 7.40972185]]], [[[93.77706146, 6.88065004], [93.77781677, 6.88065004], [93.77813721, 6.88032913], [93.77841949, 6.88040209], [93.77870178, 6.88068008], [93.77916718, 6.88055515], [93.77923584, 6.88096905], [93.77937317, 6.88118076], [93.77972412, 6.8815279], [93.77965546, 6.88173485], [93.7795105, 6.88180399], [93.77972412, 6.88201284], [93.77972412, 6.88284683], [93.77993011, 6.88312483], [93.78013611, 6.8836112], [93.77993774, 6.88382101], [93.77971649, 6.88389111], [93.77944183, 6.88417196], [93.77805328, 6.88416719], [93.77777863, 6.88444519], [93.77749634, 6.88444519], [93.77722168, 6.88472319], [93.77722168, 6.88500118], [93.77833557, 6.88611078], [93.77833557, 6.88638878], [93.77999878, 6.88805485], [93.77999878, 6.88833094], [93.78055573, 6.88888884], [93.78055573, 6.88916683], [93.78083038, 6.88944292], [93.78083038, 6.89027691], [93.77999878, 6.89111185], [93.77971649, 6.89111185], [93.77944183, 6.89138985], [93.77916718, 6.89138985], [93.77896118, 6.89118004], [93.77888489, 6.89116383], [93.77861023, 6.89111185], [93.77833557, 6.89083385], [93.77805328, 6.89083385], [93.77785492, 6.8906312], [93.77777863, 6.8905549], [93.77694702, 6.8905549], [93.77666473, 6.89083385], [93.77639008, 6.89083385], [93.77500153, 6.89222097], [93.77471924, 6.89222097], [93.77388763, 6.89306021], [93.77305603, 6.89305592], [93.77249908, 6.89361191], [93.77166748, 6.89360905], [93.77138519, 6.8938899], [93.77138519, 6.89527798], [93.77173615, 6.89583397], [93.77166748, 6.89611006], [93.77166748, 6.89638996], [93.77111053, 6.8969512], [93.77027893, 6.8969512], [93.76953888, 6.89621878], [93.76940155, 6.89586115], [93.76912689, 6.89515877], [93.76850128, 6.89488602], [93.76808167, 6.89509487], [93.76794434, 6.89537096], [93.76787567, 6.89564896], [93.76787567, 6.89606619], [93.76759338, 6.89662313], [93.76759338, 6.89717913], [93.76731873, 6.89780283], [93.76711273, 6.89822006], [93.76689911, 6.89870787], [93.76689911, 6.89925909], [93.7669754, 6.8997488], [93.7671814, 6.90009594], [93.76745605, 6.90037394], [93.76766968, 6.90065193], [93.76805878, 6.90111017], [93.76805878, 6.90166616], [93.76777649, 6.90194416], [93.76777649, 6.90221977], [93.76721954, 6.90277815], [93.76708221, 6.90298605], [93.76694489, 6.90319586], [93.76667023, 6.90333223], [93.76638794, 6.90333223], [93.76611328, 6.90361023], [93.76583099, 6.90361023], [93.76555634, 6.90389109], [93.76499939, 6.90417099], [93.7647171, 6.90500116], [93.76472473, 6.90527916], [93.76444244, 6.90555716], [93.76423645, 6.90582991], [93.76416779, 6.90611982], [93.76361084, 6.90660095], [93.76277924, 6.90777922], [93.76361084, 6.90861082], [93.76444244, 6.90861082], [93.7647171, 6.9088912], [93.76527405, 6.90888882], [93.76555634, 6.90916681], [93.76555634, 6.90944481], [93.76583099, 6.9097209], [93.76583099, 6.91027689], [93.76611328, 6.91055489], [93.76611328, 6.91111088], [93.7664032, 6.91166878], [93.7664566, 6.91271114], [93.7664032, 6.91306019], [93.76638794, 6.91388893], [93.76611328, 6.91416693], [93.76611328, 6.91444492], [93.76583099, 6.91472292], [93.76583099, 6.91498995], [93.76444244, 6.91638899], [93.76277924, 6.91638899], [93.76261139, 6.91622305], [93.76222229, 6.91583109], [93.76194763, 6.915833], [93.75971985, 6.91361094], [93.7591629, 6.91361094], [93.75888824, 6.91333294], [93.7583313, 6.91333294], [93.75694275, 6.91194487], [93.75694275, 6.91138887], [93.75666809, 6.91111088], [93.75666809, 6.90972281], [93.7563858, 6.90944481], [93.7563858, 6.90916681], [93.75416565, 6.90694523], [93.75367737, 6.90708399], [93.7527771, 6.90722322], [93.75222015, 6.90742111], [93.75187683, 6.90758085], [93.75166321, 6.90778112], [93.75111389, 6.90805483], [93.75076294, 6.90812492], [93.75055695, 6.90832996], [93.75, 6.90888882], [93.75, 6.90916681], [93.74972534, 6.90944481], [93.74973297, 6.9097209], [93.74888611, 6.91055489], [93.74854279, 6.91152811], [93.74833679, 6.91222286], [93.74833679, 6.91277695], [93.74777985, 6.91333294], [93.74777985, 6.91361094], [93.74749756, 6.91388893], [93.74749756, 6.91444492], [93.7472229, 6.91472292], [93.74708557, 6.91534805], [93.74694824, 6.915833], [93.7472229, 6.91611099], [93.7472229, 6.91638899], [93.74694824, 6.91666985], [93.74694824, 6.91777706], [93.74666595, 6.91805601], [93.74666595, 6.91833401], [93.7444458, 6.92055607], [93.7444458, 6.92082882], [93.74388885, 6.92139006], [93.74388885, 6.92166615], [93.74333191, 6.92222214], [93.74333191, 6.92250013], [93.74277496, 6.92305613], [93.74276733, 6.92361021], [93.74250031, 6.92388821], [93.74250031, 6.9241662], [93.74222565, 6.9244442], [93.74222565, 6.92472219], [93.74194336, 6.92500019], [93.74194336, 6.92666578], [93.74187469, 6.92701483], [93.74190521, 6.92739296], [93.74195099, 6.92798805], [93.7425766, 6.92847109], [93.7427063, 6.9289608], [93.74305725, 6.92917109], [93.74333954, 6.92917109], [93.74375153, 6.92889118], [93.74410248, 6.9289608], [93.74430847, 6.92902994], [93.74460602, 6.92954922], [93.74495697, 6.92954922], [93.74565125, 6.9294219], [93.74607086, 6.92925978], [93.7468338, 6.92888784], [93.7472229, 6.92889118], [93.7480011, 6.92870092], [93.74820709, 6.92848921], [93.74848938, 6.92842102], [93.74917603, 6.92855978], [93.74980164, 6.92870092], [93.75028992, 6.9286952], [93.75064087, 6.92889977], [93.7507782, 6.92938995], [93.75125885, 6.92974091], [93.75138855, 6.92999983], [93.75138855, 6.93055391], [93.75110626, 6.93083], [93.75111389, 6.9313879], [93.75138855, 6.9316659], [93.75139618, 6.93221998], [93.75111389, 6.93250084], [93.75111389, 6.93277884], [93.75096893, 6.93347216], [93.75110626, 6.93449879], [93.75166321, 6.93527889], [93.75166321, 6.93638897], [93.75222015, 6.93694496], [93.75222015, 6.93888903], [93.75138855, 6.93972111], [93.75138855, 6.9399991], [93.74944305, 6.94194508], [93.74944305, 6.94222116], [93.74972534, 6.94249916], [93.74993134, 6.94284582], [93.75027466, 6.94319201], [93.75055695, 6.94381905], [93.75055695, 6.94444323], [93.75069427, 6.94492912], [93.75055695, 6.94611216], [93.75027466, 6.94639015], [93.75027466, 6.94722223], [93.74972534, 6.94777822], [93.74972534, 6.94861221], [93.74861145, 6.94972181], [93.74832916, 6.94971991], [93.74804688, 6.94999981], [93.74777985, 6.94999981], [93.74749756, 6.95028019], [93.7472229, 6.95027781], [93.74666595, 6.9508338], [93.74666595, 6.95166588], [93.7463913, 6.95194387], [93.7463913, 6.95222187], [93.74666595, 6.95249987], [93.74666595, 6.95333385], [93.74694824, 6.95360994], [93.74742889, 6.95401096], [93.74812317, 6.95436716], [93.74840546, 6.95464516], [93.74861145, 6.95520115], [93.74861145, 6.95562887], [93.74832916, 6.95686913], [93.74812317, 6.95700979], [93.7472229, 6.95722198], [93.74666595, 6.95777893], [93.74666595, 6.95833206], [93.7463913, 6.95861006], [93.7463913, 6.959445], [93.74610901, 6.95972013], [93.74610901, 6.96000099], [93.74583435, 6.96027613], [93.74583435, 6.96083307], [93.74555206, 6.96111107], [93.74555206, 6.96138906], [93.7452774, 6.96166706], [93.7452774, 6.96194506], [93.74472046, 6.96250105], [93.7444458, 6.96250105], [93.74388885, 6.96305895], [93.7436142, 6.96305513], [93.74333191, 6.96333313], [93.74250031, 6.96333313], [93.74222565, 6.96305513], [93.74194336, 6.96305895], [93.73916626, 6.96028996], [93.7388916, 6.96028996], [93.73860931, 6.96000099], [93.73860931, 6.95972013], [93.73805237, 6.959167], [93.73638916, 6.959167], [93.7361145, 6.959445], [93.73583221, 6.95944023], [93.7352829, 6.96000099], [93.73527527, 6.96027613], [93.73500061, 6.96055508], [93.73527527, 6.96083307], [93.73527527, 6.96111107], [93.73500061, 6.96235991], [93.73500061, 6.96292019], [93.73500061, 6.96388912], [93.73527527, 6.96416712], [93.7352829, 6.9658308], [93.73443604, 6.96666908], [93.73305511, 6.96666718], [93.73200989, 6.96763992], [93.7317276, 6.96820116], [93.73132324, 6.96917009], [93.73117065, 6.96955919], [93.73123932, 6.97108889], [93.73165894, 6.97164297], [93.73165894, 6.97199106], [93.73179626, 6.97254705], [93.73228455, 6.97303295], [93.73239136, 6.9742341], [93.73253632, 6.97448206], [93.73278046, 6.97472191], [93.73278046, 6.9749999], [93.73305511, 6.9752779], [93.73305511, 6.97583389], [93.73332977, 6.97611189], [93.73332977, 6.97694397], [93.73361206, 6.97722006], [93.73332977, 6.97749996], [93.73332977, 6.97777796], [93.73305511, 6.97805595], [93.73305511, 6.97833395], [93.73278046, 6.97861004], [93.73278046, 6.97916603], [93.7325592, 6.97972012], [93.73242188, 6.98006916], [93.73200989, 6.98048592], [93.7317276, 6.98069286], [93.73145294, 6.98103905], [93.73132324, 6.9813199], [93.73110199, 6.98188019], [93.73082733, 6.98236084], [93.73033905, 6.98250008], [93.73006439, 6.98291683], [93.72999573, 6.98361301], [93.72972107, 6.98423719], [93.72943878, 6.9845829], [93.72903442, 6.98497486], [93.72875977, 6.98539305], [93.72834015, 6.98552895], [93.72785187, 6.98595095], [93.72743988, 6.9860878], [93.72721863, 6.98666716], [93.72647858, 6.98770618], [93.72612762, 6.98805189], [93.72564697, 6.98860788], [93.72515869, 6.98902607], [93.72480774, 6.98943996], [93.72418976, 6.99006701], [93.72390747, 6.99076223], [93.72349548, 6.99117708], [93.7230072, 6.99194288], [93.72203827, 6.99194288], [93.72138977, 6.99222517], [93.72093201, 6.99254704], [93.7201004, 6.99289083], [93.71871185, 6.99324179], [93.71814728, 6.99351978], [93.71746063, 6.99380016], [93.71684265, 6.99387121], [93.71621704, 6.99380016], [93.71579742, 6.99359083], [93.71510315, 6.99339914], [93.71482086, 6.99312305], [93.71412659, 6.99277687], [93.71356964, 6.99249887], [93.71231842, 6.99277687], [93.71183777, 6.99298382], [93.71148682, 6.9929142], [93.71079254, 6.99228907], [93.71038055, 6.99187183], [93.71009827, 6.99117708], [93.70954895, 6.9908309], [93.70857239, 6.990345], [93.70822906, 6.99020576], [93.70746613, 6.98978901], [93.70670319, 6.98971796], [93.7062149, 6.9898572], [93.70526123, 6.9903698], [93.70463562, 6.99071884], [93.70373535, 6.99162102], [93.7033844, 6.99266291], [93.7033844, 6.99467802], [93.70374298, 6.9955802], [93.70407867, 6.99599695], [93.70456696, 6.99627495], [93.70506287, 6.9966898], [93.70568085, 6.99710989], [93.70588684, 6.99738503], [93.70602417, 6.99773407], [93.70602417, 6.99947119], [93.70609283, 6.99971914], [93.70639038, 7.0], [93.70610046, 7.0002799], [93.70555878, 7.00055981], [93.70555878, 7.00138998], [93.70527649, 7.00166607], [93.70527649, 7.00221014], [93.70500183, 7.00250006], [93.70500183, 7.00277805], [93.70471954, 7.00305605], [93.70471954, 7.00333405], [93.70443726, 7.00361013], [93.70444489, 7.00389004], [93.70417023, 7.00416613], [93.70417023, 7.00444412], [93.70388794, 7.00472212], [93.70388794, 7.00500011], [93.70361328, 7.00527811], [93.70361328, 7.00555611], [93.70333099, 7.0058341], [93.70333099, 7.00611019], [93.70305634, 7.00639009], [93.70305634, 7.00667095], [93.70166779, 7.00805616], [93.70166779, 7.00833416], [93.70139313, 7.00860977], [93.7013855, 7.00888777], [93.70111084, 7.00916576], [93.70111084, 7.00943995], [93.70054626, 7.01000023], [93.70027924, 7.01013899], [93.69958496, 7.01055717], [93.69958496, 7.01083183], [93.69958496, 7.01097107], [93.69930267, 7.01152706], [93.6986084, 7.01194382], [93.69833374, 7.01222277], [93.69805908, 7.012362], [93.69791412, 7.01250076], [93.69695282, 7.01332998], [93.69625092, 7.01361084], [93.69568634, 7.01389122], [93.69541931, 7.01389122], [93.69526672, 7.01417112], [93.69499969, 7.01416683], [93.69458008, 7.01472282], [93.69403076, 7.01471996], [93.6938858, 7.01514006], [93.69333649, 7.0152812], [93.6922226, 7.0155592], [93.6911087, 7.01617908], [93.68993378, 7.01645708], [93.68888855, 7.01722288], [93.6883316, 7.01722097], [93.68805695, 7.01750994], [93.68776703, 7.01750994], [93.6875, 7.01778078], [93.68694305, 7.01778078], [93.6866684, 7.01805878], [93.68638611, 7.01805496], [93.68611145, 7.01833296], [93.68583679, 7.01833296], [93.6855545, 7.01805496], [93.68444824, 7.01805878], [93.68305206, 7.01778078], [93.6819458, 7.01778078], [93.68165588, 7.01750994], [93.68110657, 7.01750994], [93.6808548, 7.01724815], [93.68027496, 7.01722288], [93.68011475, 7.01705885], [93.68000031, 7.01694489], [93.6791687, 7.01694489], [93.67861176, 7.01638889], [93.67749786, 7.0163908], [93.67694092, 7.01583004], [93.67666626, 7.01451492], [93.67666626, 7.01312685], [93.67646027, 7.01216078], [93.67582703, 7.01105118], [93.67547607, 7.00984097], [93.67492676, 7.00893784], [93.67458344, 7.007967], [93.6745224, 7.00719881], [93.67462921, 7.00532579], [93.67428589, 7.00442314], [93.67303467, 7.00345182], [93.67157745, 7.00303793], [93.66754913, 7.00303984], [93.66680145, 7.00339079], [93.66574097, 7.0039382], [93.66511536, 7.00421619], [93.66442108, 7.00470114], [93.66358948, 7.00588179], [93.66303253, 7.00664616], [93.66278076, 7.00750017], [93.66305542, 7.00777817], [93.66305542, 7.00860977], [93.66333008, 7.00888777], [93.66333008, 7.00971985], [93.66388702, 7.01027822], [93.66388702, 7.01055717], [93.66416931, 7.01083183], [93.66527557, 7.01083183], [93.66555786, 7.01110983], [93.66722107, 7.01110983], [93.66750336, 7.01138783], [93.66860962, 7.01166582], [93.66889191, 7.01194382], [93.66916656, 7.01194382], [93.67028046, 7.01305389], [93.67028046, 7.01471996], [93.66999817, 7.01500082], [93.66999817, 7.0155549], [93.67028046, 7.01583004], [93.67028046, 7.0163908], [93.67042542, 7.01778793], [93.67028809, 7.01869106], [93.66986847, 7.01945019], [93.67028046, 7.02000093], [93.67082977, 7.02057123], [93.67166901, 7.02055502], [93.67194366, 7.02083302], [93.67305756, 7.02083302], [93.67388916, 7.021667], [93.67388916, 7.021945], [93.67415619, 7.02222109], [93.67415619, 7.02388906], [93.6727829, 7.02528], [93.67250061, 7.02528], [93.67222595, 7.0255599], [93.67194366, 7.02555513], [93.67166901, 7.02583408], [93.67138672, 7.02583122], [93.66972351, 7.02750015], [93.66972351, 7.02805614], [93.66916656, 7.02861214], [93.66916656, 7.02944422], [93.66944122, 7.02972221], [93.66944122, 7.0305562], [93.66999817, 7.03111219], [93.67028046, 7.03146076], [93.6709671, 7.03174114], [93.67194366, 7.03229523], [93.6727066, 7.03340483], [93.67305756, 7.03493214], [93.67305756, 7.03632021], [93.67250061, 7.03722], [93.67082977, 7.03889084], [93.67056274, 7.03889084], [93.67028046, 7.03917122], [93.66999817, 7.03916597], [93.66972351, 7.03944492], [93.66944122, 7.03944492], [93.66916656, 7.03916597], [93.66860962, 7.03972292], [93.66805267, 7.03972006], [93.66777802, 7.04000092], [93.66750336, 7.04000092], [93.66722107, 7.04028082], [93.66694641, 7.04027891], [93.66527557, 7.04194498], [93.66527557, 7.04250097], [93.66472626, 7.04409218], [93.66493225, 7.04534101], [93.66479492, 7.04665995], [93.6644516, 7.04763079], [93.66437531, 7.04853392], [93.66514587, 7.04977989], [93.66578674, 7.05061007], [93.66617584, 7.05097914], [93.66629791, 7.05143976], [93.66664886, 7.05247402], [93.66720581, 7.05337715], [93.6676178, 7.05511093], [93.66748047, 7.05740213], [93.66750336, 7.05888796], [93.66750336, 7.05972004], [93.66722107, 7.05999994], [93.66722107, 7.06027794], [93.66750336, 7.06055593], [93.66750336, 7.06083393], [93.66777802, 7.06111002], [93.66777802, 7.06166601], [93.66805267, 7.06194401], [93.66805267, 7.06361008], [93.66833496, 7.06388807], [93.66858673, 7.06518078], [93.66858673, 7.06608486], [93.66833496, 7.06666708], [93.66805267, 7.06694508], [93.66333008, 7.06693983], [93.66249847, 7.06777906], [93.66249847, 7.06916714], [93.66222382, 7.06944513], [93.66222382, 7.06972313], [93.66249847, 7.07000113], [93.66249847, 7.07027721], [93.66278076, 7.07055521], [93.66278076, 7.07083321], [93.66305542, 7.0711112], [93.66305542, 7.07250118], [93.66388702, 7.07333279], [93.66388702, 7.07361078], [93.66500092, 7.07472277], [93.6652832, 7.07472086], [93.66583252, 7.07527685], [93.66583252, 7.07555485], [93.66611481, 7.07583284], [93.66611481, 7.07638884], [93.66664886, 7.07692719], [93.66722107, 7.07749891], [93.66750336, 7.07748985], [93.66805267, 7.07806015], [93.66832733, 7.07806015], [93.66916656, 7.07888985], [93.66916656, 7.07916784], [93.66971588, 7.07972097], [93.66972351, 7.07999897], [93.66999817, 7.08027792], [93.66999817, 7.08083391], [93.67028046, 7.08111191], [93.67028046, 7.08166599], [93.66999817, 7.08194399], [93.66999817, 7.08305597], [93.66972351, 7.08333397], [93.66972351, 7.08388996], [93.66777802, 7.08583403], [93.66750336, 7.08583021], [93.66694641, 7.08639002], [93.66666412, 7.08639002], [93.66638947, 7.08666611], [93.66583252, 7.08666611], [93.66555023, 7.08643293], [93.6652832, 7.08639002], [93.66500092, 7.08611012], [93.66471863, 7.08611202], [93.66444397, 7.08583403], [93.66416931, 7.08583403], [93.66388702, 7.08555603], [93.66361237, 7.0855608], [93.66333008, 7.08527994], [93.66306305, 7.08527994], [93.66280365, 7.08502483], [93.66139221, 7.08500004], [93.66055298, 7.08583403], [93.66055298, 7.08611202], [93.66027832, 7.08639002], [93.66014099, 7.0872221], [93.66014099, 7.08819103], [93.66000366, 7.09000015], [93.65919495, 7.09077787], [93.65865326, 7.09126091], [93.65828705, 7.0920949], [93.6578064, 7.09320688], [93.6576004, 7.09391785], [93.65719604, 7.09461117], [93.65719604, 7.09557676], [93.65744019, 7.09774494], [93.65727997, 7.09836006], [93.65721893, 7.09895992], [93.65727234, 7.09962082], [93.65750122, 7.10027695], [93.65750122, 7.10055494], [93.65777588, 7.10083294], [93.65777588, 7.10111094], [93.65833282, 7.10166693], [93.65860748, 7.10166693], [93.65916443, 7.10222292], [93.65944672, 7.10222101], [93.65966797, 7.10244417], [93.65972137, 7.10250092], [93.66194153, 7.10250092], [93.66221619, 7.10278177], [93.66249847, 7.10278177], [93.66278076, 7.10305977], [93.66333008, 7.103055], [93.66361237, 7.103333], [93.66388702, 7.103333], [93.66416931, 7.103055], [93.66443634, 7.10305977], [93.66471863, 7.10278177], [93.66555786, 7.102777], [93.66638947, 7.10361099], [93.66638947, 7.10416698], [93.66666412, 7.10444498], [93.66666412, 7.10472107], [93.66889191, 7.10694313], [93.66916656, 7.10694122], [93.66971588, 7.10750008], [93.66999054, 7.10750008], [93.67028046, 7.10779095], [93.67055511, 7.10777807], [93.67082977, 7.10805607], [93.67153168, 7.10832882], [93.67197418, 7.1085372], [93.67211151, 7.10860682], [93.67246246, 7.10888481], [93.67312622, 7.10916615], [93.67354584, 7.10965109], [93.67403412, 7.11027622], [93.67416382, 7.11055613], [93.67444611, 7.11083412], [93.67444611, 7.1116662], [93.67472076, 7.1119442], [93.67472076, 7.11250019], [93.67444611, 7.11277819], [93.67444611, 7.11305618], [93.67416382, 7.11333418], [93.67415619, 7.11360121], [93.6727829, 7.11499977], [93.67250061, 7.11499977], [93.67222595, 7.11528111], [93.67193604, 7.11528111], [93.67166901, 7.11556101], [93.67138672, 7.11527777], [93.67082977, 7.11583424], [93.67056274, 7.11582994], [93.66971588, 7.11667109], [93.66944122, 7.11666584], [93.66916656, 7.11694384], [93.66889191, 7.11694384], [93.66860962, 7.11722183], [93.66805267, 7.11721992], [93.66777802, 7.11749983], [93.66750336, 7.11749983], [93.66638947, 7.11638784], [93.66587067, 7.11507082], [93.6654129, 7.11486101], [93.66500092, 7.11465406], [93.66416931, 7.11361217], [93.66416931, 7.11305618], [93.66278076, 7.1116662], [93.66249847, 7.11167002], [93.66221619, 7.11139011], [93.66110992, 7.11139011], [93.6608429, 7.11167002], [93.66055298, 7.1116662], [93.66027832, 7.1119442], [93.65972137, 7.1119442], [93.65916443, 7.11180878], [93.65860748, 7.1119442], [93.65833282, 7.1119442], [93.65805817, 7.11222219], [93.65805817, 7.11305618], [93.65666962, 7.11444378], [93.65666962, 7.11472178], [93.65611267, 7.11527777], [93.65611267, 7.11555576], [93.65638733, 7.11583424], [93.65611267, 7.11610985], [93.65611267, 7.11638784], [93.65638733, 7.11666584], [93.65638733, 7.11721992], [93.65611267, 7.11749983], [93.65611267, 7.11972284], [93.65583038, 7.12000084], [93.65583038, 7.12111092], [93.65611267, 7.12138891], [93.65611267, 7.1222229], [93.65583038, 7.1225009], [93.65583038, 7.12472105], [93.65556335, 7.12500095], [93.65556335, 7.12528086], [93.65583038, 7.12555885], [93.65583038, 7.12638903], [93.65611267, 7.12666702], [93.65611267, 7.12694502], [93.65638733, 7.12722111], [93.65638733, 7.12750101], [93.65666962, 7.12778187], [93.65666962, 7.12806177], [93.65777588, 7.12916994], [93.65805817, 7.12916708], [93.65833282, 7.12944508], [93.65916443, 7.12944508], [93.6593399, 7.12961578], [93.65944672, 7.12972116], [93.66194153, 7.12972116], [93.66298676, 7.12985992], [93.66340637, 7.12985992], [93.66395569, 7.13007021], [93.66451263, 7.13069391], [93.66500092, 7.131248], [93.66555786, 7.13194323], [93.66596985, 7.13277483], [93.66638947, 7.13298512], [93.66680908, 7.1344409], [93.66708374, 7.13659286], [93.66708374, 7.13860512], [93.66750336, 7.13916111], [93.66838837, 7.13951015], [93.66916656, 7.13948011], [93.66966248, 7.13955116], [93.66972351, 7.13937616], [93.67010498, 7.13827705], [93.67077637, 7.13837004], [93.67182159, 7.13785982], [93.6727829, 7.13749981], [93.67305756, 7.13777781], [93.67333221, 7.13777113], [93.67360687, 7.13806009], [93.67388916, 7.1380558], [93.67527771, 7.13944387], [93.67527771, 7.13972187], [93.67582703, 7.13992882], [93.67590332, 7.14048481], [93.67630005, 7.14108896], [93.67685699, 7.14268017], [93.67694092, 7.143888], [93.67722321, 7.14416599], [93.67722321, 7.14472008], [93.67749786, 7.14499998], [93.67749786, 7.14528084], [93.67722321, 7.14527798], [93.67722321, 7.14555693], [93.67749786, 7.14583015], [93.67749786, 7.14638805], [93.67763519, 7.14659786], [93.67749786, 7.14687395], [93.67764282, 7.1470108], [93.67784882, 7.14750099], [93.67771149, 7.14874983], [93.67778015, 7.14916706], [93.67798615, 7.1496501], [93.67791748, 7.15021086], [93.67805481, 7.15055513], [93.67819214, 7.15124989], [93.67814636, 7.15166187], [93.67821503, 7.1523571], [93.67847443, 7.15277719], [93.6783371, 7.15472078], [93.6783371, 7.15527916], [93.67805481, 7.15555477], [93.67805481, 7.15583277], [93.67778015, 7.15611076], [93.67778015, 7.15694094], [93.67666626, 7.15806007], [93.6763916, 7.15805483], [93.67472076, 7.1597209], [93.67472076, 7.15999889], [93.67444611, 7.16028023], [93.67444611, 7.16055584], [93.67430878, 7.1618681], [93.67430878, 7.16339302], [93.67444611, 7.16555595], [93.67472076, 7.16582918], [93.67472076, 7.16750002], [93.67500305, 7.16777802], [93.67500305, 7.16805601], [93.67527771, 7.16833019], [93.67527771, 7.17055607], [93.67555237, 7.17083216], [93.67555237, 7.17111015], [93.67582703, 7.17139101], [93.67583466, 7.17277908], [93.67555237, 7.17305708], [93.67555237, 7.17361021], [93.67444611, 7.17472315], [93.67388916, 7.17472315], [93.67305756, 7.17555714], [93.67305756, 7.17583323], [93.67333221, 7.17582989], [93.67388916, 7.17638922], [93.67490387, 7.17649794], [93.67527771, 7.17694521], [93.67527771, 7.17722321], [93.6763916, 7.17833281], [93.6763916, 7.1788888], [93.67694092, 7.17944479], [93.67722321, 7.17944479], [93.67749786, 7.17972279], [93.67804718, 7.17972088], [93.67888641, 7.18056011], [93.67917633, 7.18056011], [93.68110657, 7.18250084], [93.68187714, 7.18277884], [93.68222046, 7.18277693], [93.68250275, 7.18284798], [93.68361664, 7.18347216], [93.68361664, 7.183887], [93.68360901, 7.1844449], [93.6838913, 7.18555498], [93.68416595, 7.18583298], [93.68416595, 7.18611097], [93.68444824, 7.18638992], [93.68444824, 7.18721914], [93.6847229, 7.18749905], [93.68444824, 7.187778], [93.6847229, 7.18805599], [93.6847229, 7.18833399], [93.68499756, 7.18861198], [93.68498993, 7.18888092], [93.68574524, 7.18963289], [93.68611145, 7.19000006], [93.68638611, 7.19000006], [93.68673706, 7.19013882], [93.68701172, 7.19027996], [93.68722534, 7.19027805], [93.68785095, 7.190485], [93.6883316, 7.190763], [93.6894455, 7.19083405], [93.68972015, 7.19069481], [93.69055176, 7.1908288], [93.69167328, 7.19139004], [93.69194794, 7.19188023], [93.69249725, 7.19166994], [93.69255829, 7.19131899], [93.69284821, 7.1909709], [93.6930542, 7.190485], [93.69333649, 7.19027805], [93.69381714, 7.19013882], [93.69526672, 7.19000006], [93.69555664, 7.18993092], [93.69604492, 7.18986082], [93.69645691, 7.18965101], [93.6966629, 7.18958282], [93.69694519, 7.18951416], [93.69728851, 7.18943214], [93.69779205, 7.18928385], [93.69911194, 7.18872786], [93.69988251, 7.188591], [93.70056915, 7.18866014], [93.70111084, 7.18860912], [93.7013855, 7.18861198], [93.70166779, 7.18888998], [93.70222473, 7.18888998], [93.70305634, 7.18972206], [93.70333099, 7.1897192], [93.70417023, 7.19055986], [93.70471954, 7.19055605], [93.70500183, 7.19083405], [93.70527649, 7.19083405], [93.70555878, 7.19111204], [93.70582581, 7.19111013], [93.70610046, 7.19139004], [93.70639038, 7.19145823], [93.70652771, 7.19156313], [93.70667267, 7.19166994], [93.70777893, 7.19166994], [93.70819092, 7.19159985], [93.70915985, 7.19139004], [93.70944214, 7.19131899], [93.7097168, 7.19139004], [93.70999908, 7.19139004], [93.71055603, 7.19139004], [93.71083069, 7.19166994], [93.71125031, 7.19187498], [93.71166992, 7.19194412], [93.71173859, 7.19208288], [93.71221924, 7.19222212], [93.71305847, 7.19222212], [93.71333313, 7.19215298], [93.71389008, 7.19194412], [93.7142334, 7.19187498], [93.71499634, 7.19166994], [93.71528625, 7.19139004], [93.7158432, 7.19139004], [93.71611023, 7.19111013], [93.71639252, 7.19111204], [93.71666718, 7.19083405], [93.71694183, 7.19083405], [93.71789551, 7.19044399], [93.71854401, 7.19000196], [93.71833038, 7.18888998], [93.71861267, 7.18861198], [93.71861267, 7.18833399], [93.71916962, 7.187778], [93.71943665, 7.1877799], [93.71971893, 7.18749905], [93.72000122, 7.1877799], [93.72138977, 7.1877799], [93.7216568, 7.18749905], [93.72222137, 7.18749905], [93.72249603, 7.18721914], [93.72277832, 7.18722105], [93.72305298, 7.18694305], [93.72333527, 7.18694305], [93.72360992, 7.18666792], [93.72389221, 7.18666983], [93.72416687, 7.18638992], [93.72471619, 7.18638992], [93.72499847, 7.18611097], [93.72528076, 7.18611097], [93.72555542, 7.18583298], [93.72611237, 7.18583298], [93.72638702, 7.18611097], [93.72693634, 7.18611097], [93.72722626, 7.18638992], [93.72750092, 7.18638992], [93.72805786, 7.18694305], [93.72833252, 7.18694115], [93.72888947, 7.18749905], [93.72944641, 7.18749905], [93.72972107, 7.18721914], [93.73027802, 7.18722105], [93.73055267, 7.18694305], [93.73222351, 7.18694305], [93.73249817, 7.18722105], [93.73361206, 7.18722105], [93.73388672, 7.18749905], [93.73486328, 7.18812418], [93.73562622, 7.18902588], [93.7363205, 7.18951178], [93.7371521, 7.19007015], [93.73860931, 7.19139004], [93.73972321, 7.19250011], [93.73972321, 7.19305611], [93.7408371, 7.19416618], [93.7408371, 7.19444418], [93.7444458, 7.19805622], [93.7444458, 7.19832993], [93.74500275, 7.19889116], [93.74500275, 7.19916582], [93.74610901, 7.20027924], [93.74654388, 7.20057297], [93.74772644, 7.20057011], [93.74793243, 7.20112896], [93.74862671, 7.20133591], [93.74918365, 7.20168304], [93.74946594, 7.2023778], [93.75001526, 7.20279217], [93.75092316, 7.20314121], [93.75119781, 7.20321178], [93.75196075, 7.20300007], [93.75231934, 7.20232296], [93.7527771, 7.20222282], [93.75305176, 7.20194483], [93.75332642, 7.20194006], [93.7538147, 7.2022891], [93.75444794, 7.2030549], [93.75416565, 7.20339394], [93.75444794, 7.2036109], [93.75376129, 7.20436478], [93.75337219, 7.20447016], [93.75263977, 7.20568895], [93.75166321, 7.20639086], [93.75166321, 7.20695019], [93.75222015, 7.20749903], [93.75222015, 7.20777702], [93.7527771, 7.20833302], [93.7527771, 7.20861101], [93.75389099, 7.20972109], [93.75389099, 7.20999002], [93.75417328, 7.21027899], [93.75417328, 7.21055984], [93.75499725, 7.21138906], [93.75583649, 7.21138906], [93.75611115, 7.21166992], [93.75666809, 7.21166706], [93.75749969, 7.21249914], [93.75888824, 7.21333313], [93.7591629, 7.21333122], [93.75952148, 7.21369123], [93.76000214, 7.21416998], [93.76027679, 7.21416807], [93.76042938, 7.21431589], [93.76055908, 7.21444607], [93.76139069, 7.21444607], [93.76166534, 7.21416807], [93.76194763, 7.21416998], [93.76222229, 7.21389008], [93.76249695, 7.21389008], [93.76277924, 7.21360922], [93.76305389, 7.21361208], [93.76333618, 7.21333313], [93.76416779, 7.21333313], [93.76444244, 7.21361208], [93.7647171, 7.21360922], [93.76499939, 7.21389008], [93.76555634, 7.21389008], [93.76583099, 7.21416998], [93.76611328, 7.21416998], [93.76667023, 7.21360922], [93.76582336, 7.21290684], [93.7647934, 7.21215296], [93.76472473, 7.21194506], [93.76444244, 7.21166706], [93.76423645, 7.21124983], [93.76423645, 7.2104888], [93.76451874, 7.20973015], [93.76513672, 7.20923996], [93.76590729, 7.20882082], [93.76667023, 7.20840597], [93.76722717, 7.20812798], [93.76819611, 7.20771122], [93.76882172, 7.20743513], [93.76951599, 7.20729589], [93.7701416, 7.2071619], [93.77139282, 7.20695019], [93.77305603, 7.20695019], [93.77333069, 7.20686102], [93.77397156, 7.20695019], [93.77444458, 7.20694494], [93.77493286, 7.20708418], [93.77527618, 7.20722103], [93.77583313, 7.20743084], [93.77749634, 7.20888901], [93.77749634, 7.209445], [93.77777863, 7.20972109], [93.77777863, 7.20999002], [93.77749634, 7.21027708], [93.77749634, 7.21055508], [93.77694702, 7.21111107], [93.77694702, 7.21138906], [93.77708435, 7.21194506], [93.77805328, 7.21194506], [93.77867889, 7.21208191], [93.77965546, 7.21221924], [93.78006744, 7.21229219], [93.78187561, 7.21235991], [93.78250122, 7.21249914], [93.78256989, 7.2126379], [93.78360748, 7.21333313], [93.78423309, 7.21346998], [93.78492737, 7.21326303], [93.78534698, 7.21235991], [93.78555298, 7.21194315], [93.78610992, 7.21159697], [93.78742981, 7.21097183], [93.78894806, 7.21110916], [93.78971863, 7.21138906], [93.790802, 7.21180582], [93.79156494, 7.21208191], [93.79219055, 7.21256781], [93.79260254, 7.21305323], [93.79322815, 7.2128458], [93.7935791, 7.21249914], [93.79379272, 7.21160984], [93.79392242, 7.21124983], [93.79427338, 7.21041584], [93.79515076, 7.2098918], [93.7957077, 7.20970106], [93.79676819, 7.20963383], [93.79725647, 7.20914888], [93.79774475, 7.20887089], [93.79795074, 7.20859098], [93.79808807, 7.20838499], [93.79857635, 7.207829], [93.79901123, 7.20683289], [93.79930115, 7.20655107], [93.79964447, 7.20634794], [93.80062103, 7.20627308], [93.8015213, 7.20613384], [93.80194092, 7.20592594], [93.80200958, 7.20571709], [93.80185699, 7.20482111], [93.80158997, 7.20405102], [93.80138397, 7.20349693], [93.8013916, 7.20277882], [93.8013916, 7.20250082], [93.80251312, 7.20139122], [93.80278015, 7.20166683], [93.80278015, 7.20194006], [93.8033371, 7.20250082], [93.8033371, 7.2030549], [93.80361176, 7.2033329], [93.80361176, 7.2036109], [93.80388641, 7.20388889], [93.80388641, 7.20416689], [93.8041687, 7.20444012], [93.8041687, 7.20527887], [93.80444336, 7.20555496], [93.80444336, 7.20722103], [93.8041687, 7.20750093], [93.8041687, 7.20777702], [93.80278015, 7.209167], [93.80256653, 7.20985985], [93.80271149, 7.21027708], [93.80249786, 7.21048689], [93.80249786, 7.21111107], [93.8033371, 7.21194506], [93.80361176, 7.21194506], [93.80388641, 7.21222115], [93.80500031, 7.21222115], [93.80555725, 7.21166706], [93.80555725, 7.21138906], [93.80606079, 7.21068096], [93.8069458, 7.20999002], [93.80722046, 7.20999908], [93.80805206, 7.21083307], [93.80784607, 7.21118021], [93.80805206, 7.21138906], [93.80819702, 7.21187496], [93.80860901, 7.21194506], [93.80882263, 7.2120142], [93.80944824, 7.21194506], [93.8097229, 7.21222115], [93.81027985, 7.21222115], [93.81054688, 7.21249914], [93.81083679, 7.21249914], [93.81159973, 7.21326303], [93.81163025, 7.21336794], [93.81194305, 7.21361208], [93.81149292, 7.21440887], [93.81083679, 7.2147212], [93.8105545, 7.2147212], [93.81027985, 7.21500015], [93.80860901, 7.2147212], [93.80805206, 7.2147212], [93.80770874, 7.21486092], [93.80750275, 7.21528006], [93.80735779, 7.21555996], [93.8069458, 7.21611214], [93.80659485, 7.21666622], [93.80666351, 7.21694422], [93.80659485, 7.21770716], [93.80632019, 7.2183342], [93.80638885, 7.21861219], [93.80596924, 7.21909714], [93.80626678, 7.21935701], [93.80652618, 7.21958303], [93.80750275, 7.2194438], [93.8077774, 7.2191658], [93.80805206, 7.21917915], [93.80854034, 7.21875095], [93.80930328, 7.21875095], [93.81005096, 7.21958113], [93.81041718, 7.21978998], [93.81027985, 7.22028017], [93.81025696, 7.22061777], [93.80999756, 7.22111177], [93.80999756, 7.22138786], [93.8097229, 7.22166586], [93.8097229, 7.22194386], [93.80944824, 7.22221994], [93.80916595, 7.22271013], [93.80895996, 7.22305584], [93.80882263, 7.22441912], [93.80874634, 7.22499084], [93.80854034, 7.2252779], [93.80847168, 7.22596884], [93.80867767, 7.22694397], [93.80902863, 7.22735882], [93.80916595, 7.22750092], [93.80922699, 7.22785187], [93.80899811, 7.22837114], [93.80831909, 7.2288909], [93.80750275, 7.2288909], [93.80665588, 7.22846889], [93.8061142, 7.22750092], [93.80590057, 7.22722292], [93.80548859, 7.22722292], [93.80527496, 7.2275691], [93.8052597, 7.22861099], [93.80583191, 7.2291708], [93.80583191, 7.23000097], [93.80554962, 7.23028088], [93.80555725, 7.23055506], [93.80565643, 7.23190784], [93.80593872, 7.23239422], [93.80638885, 7.23305511], [93.8069458, 7.23361111], [93.80722046, 7.23361111], [93.8077774, 7.23305511], [93.8077774, 7.23250103], [93.80847931, 7.23222113], [93.8088913, 7.23194504], [93.80916595, 7.23201323], [93.80944824, 7.23166704], [93.80979156, 7.23167086], [93.80999756, 7.23153019], [93.81021118, 7.23145914], [93.81048584, 7.23145914], [93.81083679, 7.23139095], [93.81104279, 7.23167086], [93.8116684, 7.23166704], [93.8125, 7.23173523], [93.81277466, 7.23194504], [93.8133316, 7.23235989], [93.81388855, 7.23256922], [93.8152771, 7.23250103], [93.81583405, 7.23250103], [93.816185, 7.23298597], [93.81639099, 7.23354006], [93.81624603, 7.2343812], [93.81639099, 7.23493099], [93.81681061, 7.2352109], [93.81729889, 7.23527718], [93.81777954, 7.23541594], [93.81841278, 7.23597002], [93.8189621, 7.23624802], [93.8197937, 7.23645496], [93.82111359, 7.23694515], [93.82221985, 7.23694515], [93.82250214, 7.23666716], [93.82305908, 7.23666716], [93.82333374, 7.23694515], [93.8236084, 7.23694515], [93.82389069, 7.23722076], [93.82444763, 7.23722076], [93.82472229, 7.23722076], [93.82514191, 7.23763418], [93.82611084, 7.23805094], [93.82707977, 7.2381258], [93.82777405, 7.23777723], [93.82944489, 7.23611116], [93.82971954, 7.23611116], [93.83013916, 7.23604107], [93.8309021, 7.23604107], [93.83139038, 7.23611116], [93.83207703, 7.23701096], [93.83249664, 7.23749924], [93.8328476, 7.23805523], [93.83354187, 7.23833323], [93.8345871, 7.23861122], [93.83535004, 7.23916483], [93.83597565, 7.23937321], [93.83694458, 7.23937321], [93.8373642, 7.23923588], [93.83805847, 7.23861122], [93.83833313, 7.23888922], [93.83833313, 7.23972082], [93.83777618, 7.24028015], [93.83750153, 7.24028015], [93.83721924, 7.24056005], [93.83694458, 7.24055481], [93.83638763, 7.24111223], [93.83638763, 7.24166822], [93.83694458, 7.24222183], [93.83721924, 7.24194288], [93.83777618, 7.24194288], [93.83805847, 7.24166822], [93.83833313, 7.24167013], [93.83862305, 7.24139023], [93.8391571, 7.24139023], [93.83944702, 7.24110889], [93.83972168, 7.24110889], [93.84041595, 7.24125099], [93.84057617, 7.24119806], [93.84104156, 7.24104118], [93.84222412, 7.23999882], [93.84249878, 7.23999882], [93.84278107, 7.23972082], [93.84333038, 7.23972082], [93.84352112, 7.23990822], [93.84361267, 7.23999882], [93.84471893, 7.23999882], [93.84500122, 7.24028015], [93.84519196, 7.24021578], [93.84616089, 7.2409091], [93.8467865, 7.24160385], [93.84692383, 7.24285316], [93.84687805, 7.24359989], [93.84722137, 7.24417019], [93.84777832, 7.24360991], [93.84777832, 7.24249983], [93.84805298, 7.24222183], [93.84805298, 7.24194288], [93.84833527, 7.24166822], [93.84833527, 7.24055481], [93.84805298, 7.24028015], [93.84805298, 7.23972082], [93.84777832, 7.23944283], [93.84777832, 7.23749924], [93.84750366, 7.23722076], [93.84750366, 7.23583317], [93.84777832, 7.23555517], [93.84777832, 7.23527718], [93.84805298, 7.23500109], [93.84805298, 7.2341671], [93.8483429, 7.23389101], [93.8483429, 7.23361111], [93.84805298, 7.23333311], [93.84805298, 7.23305511], [93.84750366, 7.23250103], [93.84722137, 7.23250103], [93.84716797, 7.23244381], [93.84694672, 7.23222113], [93.84638977, 7.23222303], [93.84610748, 7.23194504], [93.84583282, 7.23194504], [93.84527588, 7.23138905], [93.84500122, 7.23139095], [93.84479523, 7.23118401], [93.84305573, 7.22944498], [93.84305573, 7.22916698], [93.84249878, 7.22861099], [93.84249878, 7.22750092], [93.84278107, 7.22722292], [93.84278107, 7.22666597], [93.84305573, 7.22638798], [93.84306335, 7.22610998], [93.84333038, 7.22583485], [93.84333038, 7.2255559], [93.84305573, 7.2252779], [93.84333038, 7.22499084], [93.84333038, 7.22444391], [93.84361267, 7.22416592], [93.84361267, 7.22388792], [93.84388733, 7.22360992], [93.84388733, 7.22305584], [93.84416962, 7.22277784], [93.84416962, 7.22111177], [93.84471893, 7.22055578], [93.84471893, 7.22028017], [93.84527588, 7.21972179], [93.84527588, 7.2194438], [93.84555817, 7.2191658], [93.84555817, 7.21888781], [93.84610748, 7.21832895], [93.84610748, 7.2180562], [93.84805298, 7.21611214], [93.8483429, 7.2161212], [93.84889221, 7.21555996], [93.84916687, 7.21555996], [93.84999847, 7.21471882], [93.85028076, 7.2147212], [93.85083008, 7.21416807], [93.85111237, 7.21416998], [93.85138702, 7.21389008], [93.85221863, 7.21389008], [93.85250092, 7.21360922], [93.85415649, 7.21360922], [93.85444641, 7.21389008], [93.85610962, 7.21389008], [93.85639191, 7.21416998], [93.85666656, 7.21416807], [93.85694122, 7.21444607], [93.85722351, 7.21444607], [93.85749817, 7.2147212], [93.85778046, 7.21471882], [93.85832977, 7.21527815], [93.85832977, 7.21555614], [93.85861206, 7.2158308], [93.85861206, 7.2161212], [93.85888672, 7.21639013], [93.85888672, 7.21666622], [93.85863495, 7.21673393], [93.85916901, 7.21722221], [93.85972595, 7.21722221], [93.86027527, 7.21694422], [93.86076355, 7.21687508], [93.8611145, 7.21694422], [93.86222076, 7.21694422], [93.86250305, 7.21666622], [93.86279297, 7.21667004], [93.86305237, 7.21639013], [93.86333466, 7.21639013], [93.86443329, 7.21648121], [93.86521149, 7.21687508], [93.86566925, 7.21688414], [93.86631775, 7.21721888], [93.86728668, 7.21750021], [93.86840057, 7.21736097], [93.86916351, 7.21694422], [93.8702774, 7.21583414], [93.8702774, 7.21555614], [93.87055206, 7.21527815], [93.87055206, 7.21500015], [93.87083435, 7.2147212], [93.87083435, 7.21416807], [93.87110901, 7.21389008], [93.87110901, 7.21333122], [93.8713913, 7.21277714], [93.87194824, 7.21222115], [93.8741684, 7.21082878], [93.87444305, 7.21048212], [93.87471771, 7.20937014], [93.87548828, 7.20791388], [93.87596893, 7.20666504], [93.87618256, 7.20583105], [93.87631989, 7.20527697], [93.87652588, 7.20479107], [93.87687683, 7.20388889], [93.87770844, 7.203403], [93.87854004, 7.20326424], [93.87916565, 7.20326424], [93.88041687, 7.20347214], [93.88075256, 7.20369005], [93.88159943, 7.20423985], [93.88230133, 7.20410109], [93.88276672, 7.2036109], [93.88277435, 7.2033329], [93.88243103, 7.20257616], [93.8822937, 7.20160484], [93.88230133, 7.2008419], [93.88222504, 7.20035601], [93.88243103, 7.19938517], [93.88222504, 7.19876099], [93.88194275, 7.19751215], [93.88145447, 7.19577503], [93.88111115, 7.19522095], [93.8805542, 7.19444418], [93.88002014, 7.19344807], [93.88079071, 7.19268513], [93.8812027, 7.19212818], [93.88182831, 7.19136715], [93.88252258, 7.19060087], [93.8829422, 7.18970108], [93.88335419, 7.18914509], [93.88363647, 7.18845177], [93.88363647, 7.18810606], [93.88368225, 7.18714809], [93.88326263, 7.18626881], [93.88331604, 7.18507004], [93.88305664, 7.18472099], [93.88361359, 7.18375015], [93.8833313, 7.18250084], [93.8833313, 7.18166924], [93.88305664, 7.18139076], [93.88305664, 7.18083096], [93.88277435, 7.18055487], [93.88277435, 7.17972279], [93.88249969, 7.17944479], [93.88249969, 7.17916679], [93.88222504, 7.1788888], [93.88201141, 7.1786108], [93.88153076, 7.1781249], [93.88097382, 7.17784691], [93.88027954, 7.17639112], [93.88027954, 7.17500114], [93.87999725, 7.17472315], [93.87999725, 7.17277908], [93.88027954, 7.17250013], [93.88027954, 7.17194414], [93.8805542, 7.17166615], [93.88142395, 7.17065907], [93.88143158, 7.1694808], [93.88166809, 7.1686101], [93.88249969, 7.1686101], [93.88346863, 7.16819715], [93.8841095, 7.1670599], [93.8849411, 7.16664314], [93.88521576, 7.16608906], [93.88510132, 7.16518688], [93.88456726, 7.16400194], [93.88437653, 7.16368008], [93.88411713, 7.1632719], [93.88388062, 7.1626091], [93.88402557, 7.16194391], [93.8842392, 7.16130495], [93.88471985, 7.1606102], [93.88504791, 7.1595459], [93.88525391, 7.15815783], [93.88553619, 7.15739012], [93.88594818, 7.15718508], [93.88629913, 7.15593576], [93.88656616, 7.15511084], [93.88665009, 7.15380001], [93.88698578, 7.15309095], [93.88761902, 7.15218878], [93.88789368, 7.15114689], [93.8875885, 7.14959097], [93.88685608, 7.14809608], [93.88671875, 7.14622211], [93.88651276, 7.14546108], [93.88671875, 7.14456081], [93.88656616, 7.14345121], [93.88672638, 7.1425209], [93.88687134, 7.14189911], [93.88687134, 7.14120579], [93.88694763, 7.14027786], [93.88694763, 7.13972187], [93.88666534, 7.13944387], [93.88666534, 7.13861179], [93.88639069, 7.1383338], [93.88639069, 7.1380558], [93.8861084, 7.13777781], [93.8861084, 7.13749981], [93.88583374, 7.13722181], [93.88583374, 7.13694382], [93.88555908, 7.13666821], [93.88555908, 7.13639021], [93.88527679, 7.13610983], [93.88527679, 7.13583422], [93.88500214, 7.13555622], [93.88471985, 7.13478088], [93.88444519, 7.13443422], [93.88451385, 7.13401699], [93.88417053, 7.13270378], [93.88424683, 7.13145113], [93.88430786, 7.12977982], [93.88467407, 7.12888908], [93.88492584, 7.12825823], [93.88511658, 7.12728024], [93.88527679, 7.12673092], [93.88569641, 7.12582779], [93.88677979, 7.12524319], [93.88812256, 7.12478685], [93.88874817, 7.12437201], [93.88923645, 7.12423277], [93.88986206, 7.12388706], [93.89027405, 7.12333012], [93.89076233, 7.12284517], [93.89104462, 7.12222004], [93.89138794, 7.12111092], [93.89116669, 7.12007093], [93.89083099, 7.11972904], [93.89055634, 7.11757088], [93.89055634, 7.11721992], [93.89055634, 7.11666584], [93.89027405, 7.11638784], [93.89026642, 7.11610985], [93.8888855, 7.11472178], [93.8888855, 7.11416578], [93.88854218, 7.11333418], [93.88847351, 7.11215401], [93.88881683, 7.11152887], [93.88896179, 7.11082888], [93.88861084, 7.10972214], [93.88805389, 7.10916615], [93.88805389, 7.10889006], [93.88722229, 7.10805988], [93.88722229, 7.10779095], [93.88696289, 7.10750008], [93.88696289, 7.10721922], [93.88639069, 7.106668], [93.88639069, 7.10639], [93.8861084, 7.10610914], [93.8861084, 7.10583305], [93.88583374, 7.10555506], [93.88583374, 7.10527706], [93.88555908, 7.10500193], [93.88555908, 7.10416985], [93.88548279, 7.10255194], [93.88548279, 7.10088778], [93.88576508, 7.09991503], [93.8859024, 7.09922218], [93.88603973, 7.09859705], [93.88694763, 7.09748697], [93.88749695, 7.09644985], [93.88777924, 7.09528112], [93.88777924, 7.09360981], [93.88805389, 7.09333181], [93.88805389, 7.08833218], [93.88777924, 7.08805609], [93.88777924, 7.08639002], [93.88833618, 7.08583021], [93.88833618, 7.08555603], [93.88861084, 7.08527803], [93.88861084, 7.08472013], [93.88951111, 7.08367777], [93.88993073, 7.08298302], [93.89027405, 7.08207989], [93.89048767, 7.0809021], [93.89141083, 7.08031893], [93.89173126, 7.08006811], [93.89250183, 7.07944107], [93.8931427, 7.07877588], [93.89402771, 7.0785408], [93.89527893, 7.07902908], [93.8970108, 7.07909679], [93.89778137, 7.07888985], [93.89861298, 7.07888985], [93.89890289, 7.0786109], [93.89944458, 7.0786109], [93.89971924, 7.0783329], [93.90000153, 7.0783329], [93.90027618, 7.0780549], [93.90055847, 7.07806015], [93.90083313, 7.07777977], [93.90110779, 7.07777977], [93.90139008, 7.07748985], [93.90166473, 7.07749891], [93.90222168, 7.07694483], [93.90222168, 7.07638884], [93.90277863, 7.07583284], [93.90277863, 7.07555485], [93.90326691, 7.07485819], [93.90374756, 7.0741601], [93.90409851, 7.07340097], [93.90465546, 7.07277679], [93.90513611, 7.07180595], [93.90583038, 7.07083082], [93.90611267, 7.07055521], [93.90618134, 7.07027721], [93.90638733, 7.07000113], [93.90638733, 7.06965208], [93.90666962, 7.06777906], [93.90638733, 7.06750107], [93.90638733, 7.06666708], [93.90611267, 7.06639099], [93.90611267, 7.06472015], [93.90583038, 7.06444407], [93.90583038, 7.06416607], [93.90555573, 7.06388807], [93.90556335, 7.06278086], [93.90611267, 7.0622201], [93.90583038, 7.06194401], [93.90611267, 7.06166601], [93.90638733, 7.06167078], [93.90693665, 7.06111002], [93.90721893, 7.06111002], [93.90777588, 7.06055593], [93.90805817, 7.06055784], [93.90888977, 7.05972004], [93.90888977, 7.05944395], [93.90916443, 7.05916595], [93.9091568, 7.05889177], [93.90944672, 7.05860996], [93.90944672, 7.05833387], [93.91027832, 7.05749989], [93.91027832, 7.05722189], [93.91083527, 7.0566678], [93.91083527, 7.05638981], [93.91110992, 7.05610991], [93.91110992, 7.05583382], [93.91134644, 7.05498409], [93.9114151, 7.05345678], [93.91183472, 7.05248308], [93.91280365, 7.0518589], [93.91371155, 7.0515132], [93.91405487, 7.05102682], [93.91419983, 7.05019522], [93.91433716, 7.04957104], [93.91503143, 7.04929304], [93.91555786, 7.04916716], [93.91666412, 7.04840422], [93.91694641, 7.04729414], [93.91673279, 7.04583502], [93.91659546, 7.04465723], [93.91590118, 7.04374981], [93.91508484, 7.04353094], [93.91278076, 7.04138899], [93.91278076, 7.04111099], [93.91249847, 7.04111099], [93.91249847, 7.04055405], [93.91222382, 7.04027891], [93.91221619, 7.03917122], [93.91242981, 7.03889084], [93.91256714, 7.0384798], [93.91306305, 7.03806114], [93.91348267, 7.03792], [93.91396332, 7.0374999], [93.91430664, 7.03701019], [93.91416931, 7.03666592], [93.91416931, 7.03583384], [93.91374969, 7.03521013], [93.91372681, 7.03455782], [93.91416931, 7.03391504], [93.91471863, 7.03357077], [93.91483307, 7.03324986], [93.9152832, 7.03308105], [93.91625214, 7.03211308], [93.91666412, 7.0308342], [93.91666412, 7.02916622], [93.91611481, 7.02861214], [93.91596985, 7.02805614], [93.91583252, 7.02777815], [93.91555786, 7.02750015], [93.91583252, 7.02722216], [93.91583252, 7.02583408], [93.91611481, 7.02555513], [93.91611481, 7.02527714], [93.91750336, 7.02388906], [93.91777802, 7.02388906], [93.91832733, 7.0233202], [93.92055511, 7.02333307], [93.92082977, 7.02360916], [93.92151642, 7.02388906], [93.92193604, 7.02388906], [93.92229462, 7.02402782], [93.92277527, 7.02437496], [93.92333221, 7.02472115], [93.9236145, 7.02472115], [93.92388916, 7.02499914], [93.92415619, 7.02499914], [93.92472076, 7.0255599], [93.92500305, 7.02555513], [93.92583466, 7.02639008], [93.92610931, 7.02639008], [93.92666626, 7.02694082], [93.92727661, 7.02729177], [93.92811584, 7.02736092], [93.92868042, 7.02715111], [93.92896271, 7.02651978], [93.93090057, 7.02471924], [93.93132019, 7.02395582], [93.93173218, 7.02305079], [93.93235779, 7.02235985], [93.9329834, 7.02194309], [93.93395996, 7.02145815], [93.93444824, 7.02055502], [93.93444824, 7.02028179], [93.9347229, 7.02000093], [93.93492889, 7.01818895], [93.93499756, 7.01777697], [93.93499756, 7.01638889], [93.93527985, 7.0161109], [93.93527985, 7.0158329], [93.93548584, 7.01541615], [93.93583679, 7.01472282], [93.93624878, 7.01402807], [93.93653107, 7.01333189], [93.93805695, 7.01173496], [93.9383316, 7.01166582], [93.93888855, 7.01124907], [93.93916321, 7.01110983], [93.93972015, 7.01055717], [93.94000244, 7.01056099], [93.9402771, 7.01028109], [93.94139099, 7.01028109], [93.94167328, 7.01000023], [93.9430542, 7.01000023], [93.94403076, 7.00993013], [93.94548035, 7.0094099], [93.9457016, 7.00870991], [93.94619751, 7.0078721], [93.94625092, 7.00746584], [93.94659424, 7.00618315], [93.94667053, 7.00586796], [93.9469223, 7.0049839], [93.94695282, 7.00416994], [93.94721985, 7.00389004], [93.94721985, 7.0033288], [93.94750214, 7.00305605], [93.94750214, 7.00277805], [93.94777679, 7.00250006], [93.94777679, 7.0], [93.94766235, 6.99914885], [93.94780731, 6.99887419], [93.94773102, 6.99845695], [93.94766235, 6.99817896], [93.9471817, 6.99782991], [93.94696808, 6.99748278], [93.94676208, 6.99706602], [93.94662476, 6.99658108], [93.94648743, 6.99595594], [93.9462738, 6.99553919], [93.94618988, 6.99548912], [93.94557953, 6.99512005], [93.94537354, 6.9949832], [93.94496155, 6.99449778], [93.94481659, 6.99428797], [93.94472504, 6.99402618], [93.94457245, 6.99308014], [93.94422913, 6.99258995], [93.94374084, 6.99252176], [93.9431839, 6.99259186], [93.94291687, 6.99265385], [93.94256592, 6.99300003], [93.94243622, 6.99342012], [93.94219208, 6.99385023], [93.94204712, 6.99398899], [93.94184113, 6.99407196], [93.94163513, 6.99412823], [93.94139099, 6.99416685], [93.9411087, 6.99444103], [93.9411087, 6.99555492], [93.9411087, 6.99620914], [93.94090271, 6.99649], [93.94062805, 6.99676514], [93.94041443, 6.99683619], [93.94020844, 6.99694586], [93.94000244, 6.99722099], [93.93945313, 6.99777985], [93.93916321, 6.99777985], [93.93881989, 6.99791622], [93.93805695, 6.99805498], [93.93777466, 6.99833298], [93.9375, 6.99833298], [93.93722534, 6.99861193], [93.93694305, 6.99861193], [93.93638611, 6.99896002], [93.93554688, 6.99916983], [93.9347229, 7.0], [93.93373108, 7.00099087], [93.93296051, 7.00216913], [93.93247986, 7.00426197], [93.93151093, 7.00674582], [93.93039703, 7.00855112], [93.92956543, 7.01007605], [93.92845917, 7.01070023], [93.92727661, 7.01126099], [93.92603302, 7.01126099], [93.9249115, 7.01111889], [93.92344666, 7.01041079], [93.92205811, 7.00985718], [93.92108917, 7.00902319], [93.92024994, 7.0084691], [93.91921234, 7.00749779], [93.91671753, 7.00528908], [93.91559601, 7.00403976], [93.91475677, 7.00265884], [93.91390228, 7.0], [93.91390228, 6.99694109], [93.91394043, 6.9963212], [93.91408539, 6.99597216], [93.91408539, 6.99534798], [93.91436005, 6.99500084], [93.91436005, 6.99457979], [93.9146347, 6.99437523], [93.91498566, 6.99416685], [93.91519165, 6.99382114], [93.91561127, 6.99353981], [93.91595459, 6.99326515], [93.91635895, 6.99325991], [93.91722107, 6.99334002], [93.91832733, 6.99334002], [93.91860962, 6.99306011], [93.91916656, 6.99306011], [93.92111206, 6.9911108], [93.92141724, 6.99076414], [93.92162323, 6.99048615], [93.92197418, 6.99034691], [93.92196655, 6.9900012], [93.92266846, 6.98965216], [93.9232254, 6.98895884], [93.92384338, 6.98854208], [93.92460632, 6.98826408], [93.92523193, 6.98805523], [93.92565155, 6.98798609], [93.92585754, 6.98778105], [93.92666626, 6.98778105], [93.92804718, 6.98639107], [93.92804718, 6.98582983], [93.9283371, 6.98555708], [93.9283371, 6.98527908], [93.92861176, 6.98500109], [93.92861176, 6.98472214], [93.92944336, 6.98388815], [93.92944336, 6.98333216], [93.9291687, 6.98305607], [93.9291687, 6.98250008], [93.92944336, 6.98222017], [93.92944336, 6.98166609], [93.9291687, 6.98138809], [93.9291687, 6.9811101], [93.92861176, 6.98055601], [93.92861176, 6.98000002], [93.9283371, 6.97972012], [93.9283371, 6.97861004], [93.92805481, 6.97833395], [93.92805481, 6.97777796], [93.9283371, 6.97749996], [93.9283371, 6.9769392], [93.92805481, 6.97666597], [93.92805481, 6.9755559], [93.9283371, 6.97527122], [93.9283371, 6.97416782], [93.92861176, 6.97388983], [93.92861176, 6.97360897], [93.9291687, 6.97305584], [93.92944336, 6.97306013], [93.93083191, 6.97167015], [93.93110657, 6.97167015], [93.93164825, 6.97111082], [93.93208313, 6.97111082], [93.93250275, 6.97090197], [93.93291473, 6.97062588], [93.93312073, 6.97048521], [93.93327332, 6.96986008], [93.93333435, 6.96944284], [93.9338913, 6.96888924], [93.9338913, 6.96861076], [93.93444824, 6.96805477], [93.93444824, 6.96777678], [93.9347229, 6.96750116], [93.9347229, 6.96722317], [93.93499756, 6.96694517], [93.93499756, 6.96611118], [93.9347229, 6.96583319], [93.9347229, 6.96500111], [93.93497467, 6.96402121], [93.93497467, 6.96353579], [93.93524933, 6.96332598], [93.93560028, 6.96318722], [93.93601227, 6.96284103], [93.93622589, 6.96256208], [93.93656921, 6.96235514], [93.93722534, 6.96222305], [93.93805695, 6.96222305], [93.93888855, 6.96138906], [93.93945313, 6.96139097], [93.93972015, 6.96111107], [93.94000244, 6.96111107], [93.9402771, 6.96083307], [93.9411087, 6.96083307], [93.94139099, 6.96055508], [93.94167328, 6.9605608], [93.94194794, 6.96028996], [93.94246674, 6.95992994], [93.94288635, 6.95979118], [93.94410706, 6.95986414], [93.94418335, 6.95963097], [93.94445801, 6.95882177], [93.94473267, 6.95798779], [93.94487, 6.95722914], [93.94528961, 6.95653009], [93.94550323, 6.9558301], [93.94535828, 6.95451498], [93.94508362, 6.95395899], [93.94459534, 6.95333385], [93.94410706, 6.95298576], [93.9438324, 6.9526391], [93.9436264, 6.95181179], [93.94328308, 6.95117998], [93.94272614, 6.95069504], [93.94203186, 6.95034599], [93.94126129, 6.95035124], [93.94064331, 6.95049], [93.94008636, 6.95042181], [93.93925476, 6.95013905], [93.93883514, 6.9505558], [93.93835449, 6.95069504], [93.93744659, 6.95076323], [93.93688965, 6.95103884], [93.93662262, 6.95126009], [93.93592072, 6.95138788], [93.93544006, 6.95159817], [93.9347229, 6.95222187], [93.93444824, 6.95221996], [93.93416595, 6.95250177], [93.9338913, 6.95250177], [93.93360901, 6.95277977], [93.93332672, 6.95277977], [93.93305206, 6.9530611], [93.9327774, 6.95305586], [93.93250275, 6.95333385], [93.93222046, 6.95333385], [93.9319458, 6.95360994], [93.93164825, 6.95360994], [93.93138885, 6.95388985], [93.9311142, 6.95388794], [93.93055725, 6.95444393], [93.93026733, 6.95444012], [93.92973328, 6.95499992], [93.92778015, 6.95499992], [93.92749786, 6.95472002], [93.92722321, 6.95472193], [93.92694092, 6.95444393], [93.92666626, 6.95444393], [93.92583466, 6.95360994], [93.92583466, 6.95333385], [93.92555237, 6.95305586], [93.92555237, 6.95277786], [93.92415619, 6.95138979], [93.92388916, 6.95138979], [93.92360687, 6.95110083], [93.92333221, 6.95111179], [93.92277527, 6.9505558], [93.92250061, 6.95056105], [93.92222595, 6.95028019], [93.92166901, 6.95028019], [93.92138672, 6.94999981], [93.92111206, 6.94999981], [93.92028046, 6.94917011], [93.92028046, 6.94889021], [93.91970825, 6.94833183], [93.91944122, 6.94833422], [93.91914368, 6.94803095], [93.91889191, 6.94777822], [93.91889191, 6.94750023], [93.91860962, 6.94722223], [93.91833496, 6.94722223], [93.91816711, 6.94705486], [93.91805267, 6.94694424], [93.91833496, 6.94666815], [93.91833496, 6.94639015], [93.91805267, 6.94610882], [93.91764069, 6.94521093], [93.91722107, 6.94451618], [93.91708374, 6.94368219], [93.91707611, 6.94327021], [93.9173584, 6.94285011], [93.9173584, 6.94215107], [93.91750336, 6.94138908], [93.91777802, 6.94111109], [93.91777802, 6.94083309], [93.91750336, 6.9405551], [93.91750336, 6.93944502], [93.91722107, 6.93916702], [93.91722107, 6.93805504], [93.91694641, 6.93777704], [93.91722107, 6.93750095], [93.91722107, 6.93722105], [93.91750336, 6.93694496], [93.91750336, 6.93638897], [93.91722107, 6.93611097], [93.91722107, 6.9344449], [93.91750336, 6.93416691], [93.91723633, 6.93253708], [93.91705322, 6.93242979], [93.91628265, 6.93242979], [93.91551971, 6.93229103], [93.91510773, 6.93208122], [93.91479492, 6.93222284], [93.91464996, 6.93242979], [93.91438293, 6.93278122], [93.91403198, 6.93305922], [93.91333008, 6.93305922], [93.91320038, 6.93292713], [93.91305542, 6.93277884], [93.91278076, 6.93278122], [93.91249847, 6.93250084], [93.91221619, 6.93250084], [93.91194153, 6.93221998], [93.91166687, 6.93222284], [93.91139221, 6.93194485], [93.91110992, 6.93194485], [93.91083527, 6.9316659], [93.91083527, 6.9313879], [93.90999603, 6.93056107], [93.90999603, 6.93028116], [93.90972137, 6.92999983], [93.90972137, 6.92944002], [93.90944672, 6.92916584], [93.90944672, 6.92777777], [93.9091568, 6.92749977], [93.9091568, 6.92692995], [93.90944672, 6.92666578], [93.90944672, 6.92583418], [93.90972137, 6.92555618], [93.90972137, 6.92500019], [93.91000366, 6.92472219], [93.91000366, 6.9241662], [93.91027832, 6.92388821], [93.91027832, 6.92332888], [93.91055298, 6.92305613], [93.91055298, 6.92277813], [93.91110992, 6.9222188], [93.91110992, 6.92194414], [93.91194153, 6.92111206], [93.91194153, 6.92083406], [93.91305542, 6.91972208], [93.91305542, 6.91944313], [93.91333008, 6.91916513], [93.91361237, 6.9191699], [93.91443634, 6.91833115], [93.91471863, 6.91833401], [93.9150238, 6.91805792], [93.91564941, 6.91708708], [93.91564941, 6.91638899], [93.91571808, 6.91576719], [93.91599274, 6.91514015], [93.9160614, 6.91459084], [93.91633606, 6.91375017], [93.91648102, 6.91291809], [93.9161377, 6.9120841], [93.91571808, 6.91166878], [93.9152298, 6.91097021], [93.91481781, 6.91069603], [93.91412354, 6.91048622], [93.9133606, 6.9100008], [93.91294098, 6.90944481], [93.91280365, 6.90868092], [93.91280365, 6.90777922], [93.91252899, 6.90701485], [93.91204071, 6.90673685], [93.91162109, 6.906528], [93.91110992, 6.90611982], [93.91055298, 6.90556097], [93.90999603, 6.90556097], [93.90944672, 6.90500116], [93.9091568, 6.90500116], [93.90894318, 6.90477514], [93.90888977, 6.90471983], [93.90860748, 6.90472317], [93.90833282, 6.90500116], [93.90805817, 6.90500116], [93.90750122, 6.90556097], [93.90721893, 6.90556097], [93.90666962, 6.90611982], [93.90611267, 6.90611982], [93.90583038, 6.90639114], [93.90556335, 6.90639114], [93.90528107, 6.90667105], [93.90499878, 6.90666723], [93.90472412, 6.90694523], [93.90333557, 6.90694523], [93.90305328, 6.90722322], [93.90222168, 6.90722322], [93.90188599, 6.90688801], [93.90139008, 6.90638924], [93.90083313, 6.90639114], [93.90027618, 6.90582991], [93.89971924, 6.90556097], [93.89923859, 6.90521479], [93.8989563, 6.90452003], [93.89854431, 6.90403223], [93.89785004, 6.90347815], [93.89722443, 6.90215588], [93.89730072, 6.90167093], [93.89749908, 6.90097618], [93.89770508, 6.90035105], [93.89805603, 6.8994441], [93.89916992, 6.89833403], [93.89944458, 6.89833403], [93.90000153, 6.89777803], [93.90000153, 6.89750004], [93.90027618, 6.89722013], [93.90027618, 6.89583397], [93.89992523, 6.89507294], [93.89958191, 6.89472389], [93.8989563, 6.89437819], [93.89777374, 6.89396], [93.89686584, 6.89340019], [93.89646149, 6.89270878], [93.89646149, 6.89173794], [93.89666748, 6.89056015], [93.89694214, 6.89027977], [93.89694214, 6.89000177], [93.8972168, 6.88972092], [93.89722443, 6.88916683], [93.89749908, 6.88888884], [93.89749908, 6.88861084], [93.89833069, 6.88777685], [93.89833069, 6.88750076], [93.89861298, 6.88750076], [93.89890289, 6.88722086], [93.89963531, 6.88696623], [93.89984131, 6.88661718], [93.9001236, 6.88613176], [93.90026093, 6.88536596], [93.89990997, 6.88446283], [93.89977264, 6.88349199], [93.89984131, 6.883214], [93.9001236, 6.88272715], [93.90053558, 6.88203382], [93.90109253, 6.88161707], [93.90159607, 6.8810792], [93.90167236, 6.88025093], [93.9017334, 6.87954998], [93.90194702, 6.878057], [93.90194702, 6.87666607], [93.90183258, 6.87580013], [93.90183258, 6.87468815], [93.90155792, 6.87343884], [93.90113831, 6.87226105], [93.90085602, 6.87169981], [93.90010071, 6.87100697], [93.89898682, 6.87059021], [93.89739227, 6.8695488], [93.89694214, 6.8691659], [93.89666748, 6.86888981], [93.89639282, 6.86888981], [93.89611053, 6.86860991], [93.89583588, 6.86861181], [93.89555359, 6.86833382], [93.89527893, 6.86833382], [93.89472198, 6.86777782], [93.89444733, 6.86778021], [93.89412689, 6.86745596], [93.89360809, 6.86694098], [93.89360809, 6.86666822], [93.89333344, 6.86639023], [93.89332581, 6.8658309], [93.89305878, 6.86555576], [93.89305878, 6.86277723], [93.89325714, 6.86187887], [93.89347076, 6.8607688], [93.89360809, 6.85972118], [93.89389038, 6.8594451], [93.89389038, 6.85861111], [93.89416504, 6.85833311], [93.89416504, 6.85750103], [93.89444733, 6.85722303], [93.89444733, 6.85555506], [93.89472198, 6.85527897], [93.89472198, 6.85500097], [93.89444733, 6.85472107], [93.89444733, 6.85444498], [93.89416504, 6.85416698], [93.89416504, 6.853055], [93.89389038, 6.85278082], [93.89389038, 6.85194016], [93.89360809, 6.85166693], [93.89360809, 6.85083199], [93.89333344, 6.85055399], [93.89333344, 6.84888792], [93.89360809, 6.84860992], [93.89360809, 6.84694386], [93.89389038, 6.84666586], [93.89389038, 6.84583378], [93.89417267, 6.84556103], [93.89417267, 6.84528017], [93.89527893, 6.84417009], [93.89527893, 6.84306097], [93.89553833, 6.84277105], [93.89555359, 6.84222221], [93.89638519, 6.84138823], [93.89666748, 6.84139013], [93.89694214, 6.84111023], [93.89861298, 6.84111214], [93.89888763, 6.84083414], [93.90000153, 6.84083414], [93.90027618, 6.84055614], [93.90083313, 6.84055996], [93.90110779, 6.84028006], [93.90305328, 6.84028006], [93.9033432, 6.84055996], [93.90368652, 6.84042978], [93.90453339, 6.84042978], [93.90563202, 6.84022093], [93.90646362, 6.83987379], [93.90722656, 6.83959579], [93.90792084, 6.83897209], [93.90875244, 6.8382082], [93.90903473, 6.83779097], [93.90953064, 6.83695889], [93.90994263, 6.83625984], [93.91020966, 6.83563709], [93.91035461, 6.8348031], [93.91014099, 6.83355188], [93.91000366, 6.83216381], [93.909729, 6.83084393], [93.90930939, 6.82994223], [93.90875244, 6.82882977], [93.90778351, 6.82757807], [93.90660095, 6.82654095], [93.90576935, 6.82555914], [93.90472412, 6.82416677], [93.90472412, 6.82388783], [93.90416718, 6.82332993], [93.90416718, 6.82305717], [93.90361023, 6.82250023], [93.90336609, 6.82203102], [93.90267181, 6.82126713], [93.9021759, 6.82081604], [93.90159607, 6.82015991], [93.9015274, 6.81967878], [93.9015274, 6.81912279], [93.90166473, 6.8183589], [93.90200806, 6.81752491], [93.90234375, 6.81722879], [93.90268707, 6.81604815], [93.90268707, 6.81512117], [93.90242004, 6.81442499], [93.90220642, 6.81366014], [93.90213776, 6.81296682], [93.90110016, 6.81255007], [93.9005127, 6.81210089], [93.90009308, 6.81168079], [93.89984131, 6.81104612], [93.89942932, 6.81049204], [93.8990097, 6.80979681], [93.89880371, 6.80903292], [93.8981781, 6.80798912], [93.89790344, 6.80715704], [93.89724731, 6.8061409], [93.896698, 6.8054409], [93.8962326, 6.80486488], [93.89568329, 6.80444717], [93.89505768, 6.80416918], [93.89331818, 6.80367899], [93.89234924, 6.80361319], [93.89172363, 6.80368423], [93.89102936, 6.80361319], [93.88978577, 6.80389118], [93.88922882, 6.80389118], [93.8888092, 6.803545], [93.88853455, 6.8027792], [93.88846588, 6.80215502], [93.88846588, 6.80104017], [93.88811493, 6.79972506], [93.88809967, 6.79908514], [93.88788605, 6.79866791], [93.88761139, 6.79790401], [93.88705444, 6.79686022], [93.8862915, 6.79602814], [93.88566589, 6.79540205], [93.88513184, 6.79500008], [93.88409424, 6.79493189], [93.8833313, 6.79479122], [93.88284302, 6.79444408], [93.88270569, 6.79374886], [93.88291168, 6.7933321], [93.88291168, 6.79298592], [93.88256836, 6.79277802], [93.88194275, 6.79284716], [93.88159943, 6.7930541], [93.88111115, 6.79319477], [93.88062286, 6.79339981], [93.87999725, 6.79416609], [93.87985992, 6.7945261], [93.87979126, 6.79515123], [93.87979126, 6.79556799], [93.87958527, 6.79591417], [93.87930298, 6.79619217], [93.87909698, 6.79633093], [93.87909698, 6.79702711], [93.87902832, 6.79751205], [93.87902832, 6.79792023], [93.87882233, 6.79827785], [93.87882233, 6.79910994], [93.87889099, 6.79944515], [93.87889099, 6.80055523], [93.87916565, 6.80083323], [93.87916565, 6.80166721], [93.87889099, 6.80194521], [93.87889099, 6.80222082], [93.8786087, 6.80249882], [93.8786087, 6.80277681], [93.87805176, 6.80333281], [93.87805176, 6.8036108], [93.8769455, 6.80472279], [93.87666321, 6.80472088], [93.87638855, 6.80500078], [93.87611389, 6.80499887], [93.87527466, 6.80583286], [93.87527466, 6.80611086], [93.87277985, 6.80861092], [93.87277985, 6.80916786], [93.87249756, 6.809443], [93.87249756, 6.80972099], [93.8713913, 6.81083393], [93.87110901, 6.81083393], [93.86972046, 6.812222], [93.86972046, 6.8125], [93.8694458, 6.81277084], [93.8694458, 6.81305981], [93.86883545, 6.81365108], [93.86876678, 6.81399679], [93.86876678, 6.81434298], [93.86856079, 6.81462097], [93.8682785, 6.81503916], [93.86765289, 6.81510019], [93.86627197, 6.81539011], [93.86529541, 6.81538677], [93.86349487, 6.81559515], [93.86244965, 6.815804], [93.86190033, 6.81587315], [93.86058044, 6.815804], [93.85939789, 6.81573391], [93.85863495, 6.81573391], [93.85759735, 6.815804], [93.8562088, 6.81566477], [93.85583496, 6.81557894], [93.8548584, 6.81545591], [93.85430145, 6.81538486], [93.85402679, 6.81559515], [93.8537674, 6.81549692], [93.85346985, 6.81538486], [93.85320282, 6.81539011], [93.85311127, 6.81592989], [93.8527832, 6.81625795], [93.8529892, 6.81653595], [93.8527832, 6.8167429], [93.85236359, 6.81639719], [93.85118866, 6.8161869], [93.85090637, 6.81605101], [93.85043335, 6.81555986], [93.85042572, 6.81500721], [93.85105133, 6.81472921], [93.85138702, 6.81390095], [93.85125732, 6.81305981], [93.85083771, 6.8125062], [93.85035706, 6.81202078], [93.8500061, 6.81160402], [93.849617, 6.81087017], [93.84906006, 6.80954981], [93.84836578, 6.80802298], [93.84822845, 6.80691099], [93.84802246, 6.80580091], [93.84780884, 6.80441093], [93.84746552, 6.80309105], [93.84719086, 6.80225706], [93.84638977, 6.80111122], [93.84638977, 6.80083323], [93.84610748, 6.80055523], [93.84610748, 6.79944515], [93.84638977, 6.79916716], [93.84638977, 6.79888916], [93.84707642, 6.79840994], [93.84749603, 6.79784918], [93.84750366, 6.79708576], [93.84742737, 6.79618311], [93.84742737, 6.79521179], [93.84749603, 6.79438019], [93.84777832, 6.79389], [93.8483429, 6.79333019], [93.84833527, 6.79305601], [93.84860992, 6.79277802], [93.84860992, 6.79250002], [93.84889221, 6.79222012], [93.84889221, 6.79194403], [93.84895325, 6.79131985], [93.84874725, 6.7901392], [93.8484726, 6.78965378], [93.84798431, 6.78923607], [93.84757233, 6.78868008], [93.84729004, 6.78819513], [93.84694672, 6.78743076], [93.84687805, 6.78687477], [93.84694672, 6.78611183], [93.84666443, 6.78583384], [93.84666443, 6.78499985], [93.84711456, 6.78434086], [93.84725189, 6.78385496], [93.84738922, 6.78357697], [93.84741974, 6.78258085], [93.84749603, 6.78208923], [93.8474884, 6.78133011], [93.84735107, 6.78056717], [93.84728241, 6.77980089], [93.84679413, 6.778759], [93.84635162, 6.77808905], [93.84578705, 6.7774601], [93.84538269, 6.77642107], [93.84461975, 6.77572823], [93.8442688, 6.77523994], [93.84350586, 6.7745471], [93.84294891, 6.77419901], [93.84211731, 6.77364016], [93.84184265, 6.77336502], [93.8414917, 6.77295017], [93.8406601, 6.77212], [93.84002686, 6.77155876], [93.8397522, 6.77114916], [93.83905792, 6.77031088], [93.83878326, 6.76982689], [93.8387146, 6.76920319], [93.8387146, 6.7687149], [93.83856964, 6.76795197], [93.83836365, 6.76691008], [93.83808899, 6.76572895], [93.8379364, 6.76476097], [93.83746338, 6.7631588], [93.83732605, 6.76252985], [93.83711243, 6.76170015], [93.83683777, 6.76072693], [93.83666992, 6.75971889], [93.83666992, 6.75889015], [93.83638763, 6.75861216], [93.83638763, 6.75778008], [93.8358078, 6.75703001], [93.83531952, 6.75647783], [93.83490753, 6.75557613], [93.8338623, 6.75509024], [93.83324432, 6.75508785], [93.83248138, 6.75529814], [93.83185577, 6.75578308], [93.83109283, 6.75592184], [93.83060455, 6.75571489], [93.82997894, 6.75522709], [93.82914734, 6.75474215], [93.82831573, 6.75425577], [93.82692719, 6.75432491], [93.82602692, 6.75460005], [93.82483673, 6.75502014], [93.82415009, 6.75529814], [93.82331848, 6.7554369], [93.82213593, 6.75564384], [93.82039642, 6.75591993], [93.81902313, 6.75648117], [93.81721497, 6.75689602], [93.81575775, 6.75779819], [93.81485748, 6.7583499], [93.8135376, 6.75891018], [93.81263733, 6.75911808], [93.81151581, 6.75974178], [93.8107605, 6.76009083], [93.81020355, 6.76064682], [93.80999756, 6.761271], [93.80986023, 6.76168919], [93.8097229, 6.76210594], [93.80957794, 6.76217413], [93.80840302, 6.76245213], [93.8069458, 6.76245213], [93.80665588, 6.76251984], [93.80638885, 6.76277781], [93.8061142, 6.7630558], [93.80579376, 6.76342106], [93.80544281, 6.76397514], [93.80488586, 6.76453114], [93.80447388, 6.76564312], [93.80426788, 6.76626682], [93.80405426, 6.76716995], [93.8039856, 6.76786518], [93.80384827, 6.76848984], [93.80391693, 6.76911592], [93.80419159, 6.77001905], [93.80454254, 6.77064323], [93.80503082, 6.77133799], [93.80516815, 6.77196121], [93.80544281, 6.77237988], [93.80571747, 6.77286816], [93.80634308, 6.77342415], [93.80683136, 6.77397823], [93.80731964, 6.77404785], [93.80752563, 6.77404785], [93.80808258, 6.77411699], [93.80932617, 6.77501917], [93.80988312, 6.77572107], [93.81099701, 6.7766881], [93.81154633, 6.77703619], [93.8116684, 6.77722311], [93.8125, 6.77805519], [93.8125, 6.77833319], [93.81276703, 6.77861118], [93.81276703, 6.77888918], [93.81305695, 6.77916718], [93.81305695, 6.77999878], [93.81222534, 6.78083277], [93.81194305, 6.78083277], [93.8116684, 6.78111076], [93.81111145, 6.78111076], [93.81083679, 6.78138924], [93.80979156, 6.78164482], [93.80958557, 6.78185177], [93.80916595, 6.78261805], [93.80895996, 6.7830348], [93.80860901, 6.78352022], [93.80812836, 6.78359079], [93.80770874, 6.78388977], [93.80771637, 6.78436613], [93.80779266, 6.78554916], [93.80764771, 6.7863121], [93.80764771, 6.78700686], [93.80771637, 6.78749084], [93.80813599, 6.78790998], [93.80862427, 6.78825617], [93.80862427, 6.78867388], [93.80860901, 6.78972197], [93.80860901, 6.78999996], [93.80944824, 6.79083395], [93.8097229, 6.79083395], [93.80999756, 6.79111004], [93.8102951, 6.79112387], [93.81054688, 6.79138994], [93.81083679, 6.79138803], [93.81167603, 6.79222012], [93.81167603, 6.79278088], [93.81194305, 6.79305601], [93.81194305, 6.79416609], [93.81167603, 6.79443979], [93.81167603, 6.79472923], [93.81083679, 6.79556084], [93.8105545, 6.79555702], [93.81027985, 6.79583216], [93.80999756, 6.79583216], [93.8097229, 6.79611015], [93.80944824, 6.79611015], [93.80916595, 6.79639101], [93.8088913, 6.79638815], [93.8077774, 6.79750109], [93.8077774, 6.79861116], [93.80805206, 6.79888916], [93.80805206, 6.79944515], [93.80831909, 6.79971981], [93.80833435, 6.80027723], [93.80882263, 6.80124521], [93.80923462, 6.80284309], [93.80930328, 6.80367708], [93.80909729, 6.80402088], [93.80860901, 6.80500078], [93.80831909, 6.80527878], [93.80831909, 6.80638885], [93.80860901, 6.80667019], [93.8088913, 6.80666685], [93.80916595, 6.80694485], [93.80999756, 6.80694485], [93.81027985, 6.80666685], [93.81138611, 6.80666685], [93.8116684, 6.80694485], [93.81222534, 6.80694485], [93.8125, 6.80722284], [93.81276703, 6.80722094], [93.8133316, 6.80777693], [93.8133316, 6.80805492], [93.81361389, 6.80833292], [93.81361389, 6.80861092], [93.81416321, 6.80916786], [93.81416321, 6.809443], [93.8152771, 6.81055593], [93.8152771, 6.81083393], [93.81555176, 6.81111193], [93.81555176, 6.81138992], [93.81583405, 6.81166506], [93.81583405, 6.81361198], [93.81555176, 6.81388998], [93.81555176, 6.81611013], [93.8152771, 6.81639004], [93.8152771, 6.81666994], [93.81416321, 6.81778002], [93.81388855, 6.81778002], [93.81360626, 6.81806087], [93.81305695, 6.81805611], [93.81277466, 6.8183341], [93.81138611, 6.8183341], [93.81111145, 6.81805611], [93.81054688, 6.81806087], [93.80916595, 6.81666994], [93.80916595, 6.81639004], [93.8088913, 6.81611013], [93.8088913, 6.81583405], [93.80860901, 6.81555605], [93.80860901, 6.81500006], [93.80805206, 6.81443882], [93.80805206, 6.81416607], [93.80638885, 6.8125], [93.80610657, 6.8125], [93.80583191, 6.81221914], [93.80527496, 6.812222], [93.80500031, 6.81194401], [93.8041687, 6.81194401], [93.80388641, 6.812222], [93.80361176, 6.81221914], [93.8033371, 6.8125], [93.80305481, 6.8125], [93.80222321, 6.81333399], [93.80166626, 6.81333399], [93.8013916, 6.81361198], [93.80110931, 6.81361198], [93.7986145, 6.81611204], [93.7986145, 6.81639004], [93.79666901, 6.8183341], [93.79638672, 6.81847095], [93.79618073, 6.81902695], [93.79618073, 6.81986094], [93.79645538, 6.82041693], [93.79645538, 6.82090282], [93.79638672, 6.82139111], [93.7960434, 6.82201481], [93.79528046, 6.82277918], [93.79528046, 6.82333183], [93.79499817, 6.82360983], [93.79499817, 6.82389116], [93.7933197, 6.82555914], [93.79277802, 6.82555485], [93.79250336, 6.82583284], [93.79222107, 6.82583284], [93.79146576, 6.82660723], [93.7911911, 6.82702494], [93.79098511, 6.82737112], [93.79070282, 6.82785892], [93.79022217, 6.82834387], [93.78931427, 6.82862186], [93.78807068, 6.8290391], [93.78744507, 6.82973385], [93.78661346, 6.83098316], [93.78612518, 6.8323741], [93.78591919, 6.83383179], [93.7857132, 6.83584881], [93.78605652, 6.83717108], [93.78688812, 6.83855486], [93.78749847, 6.83916807], [93.78749847, 6.83944416], [93.78778076, 6.83971024], [93.78778076, 6.84027815], [93.78749847, 6.84055614], [93.7875061, 6.8408289], [93.78742981, 6.8412509], [93.78778076, 6.84166622], [93.78778076, 6.84194422], [93.78805542, 6.84222221], [93.78805542, 6.84277821], [93.78833008, 6.84306097], [93.78888702, 6.84306097], [93.78937531, 6.84298515], [93.78979492, 6.84312391], [93.79006958, 6.84326315], [93.79027557, 6.84361219], [93.79138947, 6.84472179], [93.79138947, 6.84499979], [93.79165649, 6.84528017], [93.79165649, 6.84556103], [93.79360962, 6.84749985], [93.79360962, 6.84777784], [93.79416656, 6.84833384], [93.79416656, 6.84860992], [93.79444122, 6.84889984], [93.79444122, 6.85027885], [93.79416656, 6.85055399], [93.79416656, 6.85083008], [93.79360962, 6.85139084], [93.79305267, 6.85139084], [93.79277802, 6.85167122], [93.79250336, 6.85166693], [93.79222107, 6.85194492], [93.79194641, 6.85194492], [93.79166412, 6.85222292], [93.79138947, 6.85222006], [93.79083252, 6.85277891], [93.79083252, 6.853055], [93.79055786, 6.853333], [93.79055786, 6.85444498], [93.7902832, 6.85472107], [93.7902832, 6.85528088], [93.78888702, 6.85666895], [93.78833008, 6.85666704], [93.78805542, 6.85694504], [93.78778076, 6.85694504], [93.78749847, 6.85666704], [93.78721619, 6.85666895], [93.78627777, 6.85571718], [93.7858429, 6.85528088], [93.78527832, 6.85528088], [93.78499603, 6.85500097], [93.78443909, 6.85500097], [93.7841568, 6.85472107], [93.78349304, 6.85463381], [93.78314209, 6.8545661], [93.78265381, 6.8545661], [93.78221893, 6.85444021], [93.7813797, 6.85528088], [93.78111267, 6.85527897], [93.78022003, 6.85624981], [93.7792511, 6.85729122], [93.77876282, 6.85798693], [93.77820587, 6.85868216], [93.77793121, 6.85923815], [93.77793121, 6.8599329], [93.77771759, 6.86048698], [93.7773056, 6.86097479], [93.77709961, 6.86124992], [93.77674866, 6.86160088], [93.77641296, 6.86174011], [93.77612305, 6.86215496], [93.77584839, 6.86278009], [93.77515411, 6.86333609], [93.77487946, 6.8634038], [93.77416992, 6.86389017], [93.77375031, 6.86409712], [93.77361298, 6.86472082], [93.77361298, 6.86499977], [93.77333069, 6.86527777], [93.77333069, 6.86583424], [93.77305603, 6.86610889], [93.77333069, 6.86639023], [93.77333069, 6.86666822], [93.77500153, 6.86833382], [93.77500153, 6.86861181], [93.77527618, 6.86888981], [93.77527618, 6.86944389], [93.7755661, 6.86971998], [93.77555847, 6.86999989], [93.77527618, 6.87027788], [93.77527618, 6.87083387], [93.7752533, 6.87141991], [93.77503204, 6.8716979], [93.77441406, 6.87211514], [93.77406311, 6.87274218], [93.77388763, 6.87333393], [93.77361298, 6.87361002], [93.77361298, 6.87388802], [93.77305603, 6.87444401], [93.77305603, 6.8747201], [93.77249908, 6.87528086], [93.77249908, 6.87556124], [93.77166748, 6.87638807], [93.77159882, 6.87673712], [93.77194977, 6.87721586], [93.77199554, 6.87727499], [93.7722168, 6.87750101], [93.77333069, 6.87750101], [93.77361298, 6.87778091], [93.77388763, 6.87777901], [93.77444458, 6.87833214], [93.77471924, 6.87833023], [93.7755661, 6.87917089], [93.77583313, 6.87916708], [93.77610779, 6.87944508], [93.77639008, 6.87944508], [93.77666473, 6.87972307], [93.77694702, 6.87972021], [93.77706146, 6.88065004]]], [[[93.71305847, 7.44361115], [93.71305847, 7.44262981], [93.71334076, 7.44179916], [93.71334076, 7.44089603], [93.71327209, 7.44026899], [93.71416473, 7.43888807], [93.71458435, 7.43784714], [93.71499634, 7.43638992], [93.71499634, 7.43611002], [93.71555328, 7.43555593], [93.71583557, 7.43416595], [93.71666718, 7.43360996], [93.71694183, 7.43333387], [93.71778107, 7.43333387], [93.71916962, 7.43194389], [93.71916962, 7.43138981], [93.71944427, 7.43111181], [93.72000122, 7.43048], [93.72034454, 7.42944098], [93.72034454, 7.42846823], [93.72041321, 7.42743111], [93.72075653, 7.42618179], [93.72075653, 7.42493105], [93.72055817, 7.4236002], [93.72055817, 7.42277718], [93.72222137, 7.42111111], [93.72222137, 7.42055511], [93.72194672, 7.42027712], [93.72194672, 7.42000103], [93.7216568, 7.41972113], [93.72166443, 7.41944504], [93.72138977, 7.41916704], [93.72138977, 7.41750097], [93.72109985, 7.41722012], [93.72110748, 7.41638899], [93.72138977, 7.41611004], [93.72138977, 7.41527891], [93.72166443, 7.41500092], [93.7216568, 7.41306114], [93.7215271, 7.41096878], [93.72118378, 7.40923405], [93.72138977, 7.40749979], [93.72138977, 7.40221882], [93.72222137, 7.40139008], [93.72222137, 7.40111113], [93.72277832, 7.40055513], [93.72277832, 7.39999914], [93.72333527, 7.39944506], [93.72333527, 7.39916706], [93.72389221, 7.39861107], [93.72389221, 7.39833307], [93.72472382, 7.39749908], [93.72472382, 7.39722109], [93.72611237, 7.39583302], [93.72638702, 7.39583302], [93.72750092, 7.39472294], [93.72833252, 7.39472294], [93.72861481, 7.39444494], [93.72888947, 7.39444494], [93.72916412, 7.39472294], [93.73000336, 7.39388895], [93.73000336, 7.39361095], [93.73139191, 7.39222097], [93.73166656, 7.39222288], [93.73332977, 7.3905549], [93.73361206, 7.3905592], [93.73443604, 7.38971996], [93.73472595, 7.38972282], [93.73500061, 7.38944483], [93.73527527, 7.38944483], [93.73555756, 7.38916683], [93.73583221, 7.38917112], [93.73610687, 7.38889122], [93.73638916, 7.38889122], [93.73665619, 7.38860989], [93.73694611, 7.38860989], [93.73916626, 7.38638783], [93.73944092, 7.38639116], [93.74111176, 7.38471985], [93.74138641, 7.38472223], [93.7416687, 7.38444424], [93.74194336, 7.38444424], [93.74222565, 7.38416576], [93.74276733, 7.38417101], [93.74360657, 7.38333178], [93.74388885, 7.38333416], [93.7444458, 7.38277817], [93.74472046, 7.38278008], [93.74500275, 7.38250017], [93.74610901, 7.38250017], [93.7463913, 7.38278008], [93.74666595, 7.38250017], [93.7472229, 7.38250017], [93.74749756, 7.38222218], [93.74777985, 7.38222218], [93.7480545, 7.38194418], [93.74833679, 7.38194418], [93.74972534, 7.38055611], [93.74972534, 7.38027811], [93.75, 7.38000011], [93.75, 7.37972212], [93.75027466, 7.37944412], [93.75027466, 7.37916613], [93.75055695, 7.37889004], [93.75055695, 7.3786211], [93.7508316, 7.3783288], [93.7508316, 7.37777805], [93.7519455, 7.37666512], [93.75340271, 7.37674093], [93.75389099, 7.37702084], [93.7544632, 7.37667179], [93.7544632, 7.37638998], [93.7547226, 7.37610912], [93.75583649, 7.37506294], [93.7564621, 7.37436819], [93.75624847, 7.37353611], [93.75631714, 7.37262917], [93.75653076, 7.37145519], [93.75653076, 7.37034321], [93.75701141, 7.36888695], [93.75722504, 7.36763811], [93.75701141, 7.36674023], [93.75666809, 7.3661108], [93.7563858, 7.36583281], [93.7563858, 7.36555481], [93.75583649, 7.3650012], [93.75583649, 7.36472082], [93.75527954, 7.36416721], [93.75527954, 7.36361122], [93.75499725, 7.36333323], [93.75499725, 7.36277914], [93.75527954, 7.36250114], [93.75527954, 7.36222315], [93.75553894, 7.36164618], [93.75567627, 7.36081409], [93.75574493, 7.35984278], [93.7555542, 7.35972214], [93.7547226, 7.35888815], [93.75417328, 7.35889006], [93.75389099, 7.35861015], [93.75333405, 7.35861015], [93.75305176, 7.35833216], [93.7527771, 7.35833216], [93.75250244, 7.35805607], [93.75222015, 7.35806084], [93.7520752, 7.35791016], [93.7519455, 7.35777807], [93.75166321, 7.35778093], [93.75139618, 7.35750914], [93.74973297, 7.35750914], [93.74952698, 7.3573041], [93.7491684, 7.35694408], [93.74888611, 7.35694408], [93.74861145, 7.35666609], [93.74861145, 7.35638809], [93.74832916, 7.3561101], [93.74833679, 7.35583401], [93.7480545, 7.35555601], [93.7480545, 7.35527802], [93.74777985, 7.35500002], [93.74777985, 7.35472012], [93.7480545, 7.35444403], [93.7480545, 7.35416603], [93.74832916, 7.35388994], [93.74832916, 7.35332918], [93.74861145, 7.35305595], [93.74861145, 7.35277796], [93.74888611, 7.35249996], [93.74888611, 7.3522191], [93.74749756, 7.35083389], [93.7472229, 7.35083389], [93.74694824, 7.3505559], [93.74666595, 7.35056019], [93.7463913, 7.35027981], [93.74582672, 7.35027981], [93.74524689, 7.34969187], [93.74500275, 7.34944296], [93.74472046, 7.34944296], [93.74277496, 7.34749889], [93.74277496, 7.3472209], [93.74222565, 7.34666681], [93.74222565, 7.34638882], [93.74194336, 7.34611082], [93.74194336, 7.34583282], [93.74138641, 7.34527683], [93.74138641, 7.34499884], [93.7408371, 7.34444094], [93.7408371, 7.34416723], [93.73999786, 7.34333277], [93.73999786, 7.34305477], [93.73972321, 7.34277678], [93.73972321, 7.34251022], [93.73916626, 7.34194088], [93.73916626, 7.34166718], [93.73860931, 7.34111118], [93.73860931, 7.34083319], [93.73805237, 7.34027719], [93.73805237, 7.34000111], [93.73777771, 7.33972311], [93.73777771, 7.33944511], [93.73750305, 7.33916712], [93.73750305, 7.33889103], [93.73722076, 7.33861113], [93.73722076, 7.33694506], [93.73694611, 7.33666706], [93.73694611, 7.33444405], [93.73666382, 7.33416605], [93.73666382, 7.33333492], [93.73638916, 7.33305597], [93.73638916, 7.33249998], [93.73610687, 7.33222008], [93.7361145, 7.33111], [93.73583221, 7.33083391], [93.73583221, 7.33027792], [93.73527527, 7.32972193], [93.73527527, 7.32833385], [93.73500061, 7.32805586], [93.73500061, 7.32777786], [93.73472595, 7.32751083], [93.73472595, 7.32694197], [93.73444366, 7.32666588], [93.73444366, 7.32638788], [93.73416901, 7.32611179], [93.73416901, 7.3258338], [93.73388672, 7.3255558], [93.73388672, 7.32527781], [93.73361206, 7.32499981], [93.73361206, 7.32471895], [93.73332977, 7.32444382], [93.73332977, 7.32416821], [93.73305511, 7.32389021], [93.73306274, 7.32360888], [93.73194122, 7.32250023], [93.73082733, 7.32250023], [93.73060608, 7.32227612], [93.73055267, 7.3222208], [93.73027802, 7.3222208], [93.72916412, 7.32111216], [93.72916412, 7.32083321], [93.72888947, 7.32055521], [93.72888947, 7.31999922], [93.72861481, 7.31972122], [93.72861481, 7.31888914], [93.72833252, 7.31861115], [93.72833252, 7.31833315], [93.72805786, 7.31805515], [93.72805786, 7.31777906], [93.7277832, 7.31749916], [93.72777557, 7.31722116], [93.72721863, 7.31666708], [93.72721863, 7.31638908], [93.72693634, 7.31611109], [93.72694397, 7.31583309], [93.72666931, 7.3155551], [93.72666931, 7.3152771], [93.72638702, 7.31500101], [93.72638702, 7.31443977], [93.72611237, 7.31416702], [93.72611237, 7.31361103], [93.72583008, 7.31333303], [93.72583008, 7.31250095], [93.72555542, 7.31222296], [93.72555542, 7.31166697], [93.72528076, 7.31138897], [93.72528076, 7.31083012], [93.72499847, 7.31055498], [93.72499847, 7.3100009], [93.7233429, 7.30833006], [93.72305298, 7.30833197], [93.72277832, 7.30805397], [93.72249603, 7.30806112], [93.72222137, 7.30778122], [93.72194672, 7.30778122], [93.7216568, 7.30750084], [93.72138977, 7.30750084], [93.72083282, 7.30694008], [93.72055817, 7.30694389], [93.71948242, 7.30587101], [93.71888733, 7.30527782], [93.71861267, 7.30528116], [93.71833038, 7.30499983], [93.71806335, 7.30499983], [93.71666718, 7.30639982], [93.71639252, 7.30639982], [93.71611023, 7.30667114], [93.71583557, 7.3066659], [93.71555328, 7.30694389], [93.71527863, 7.30694389], [93.71498871, 7.30671692], [93.71472168, 7.30667114], [93.71333313, 7.30528116], [93.71305847, 7.30528116], [93.71277618, 7.30499983], [93.71166992, 7.30499983], [93.71161652, 7.30494595], [93.71138763, 7.30471992], [93.71083069, 7.30472183], [93.71055603, 7.30444384], [93.71028137, 7.30444384], [93.70999908, 7.30416584], [93.70916748, 7.30416584], [93.70888519, 7.30444384], [93.70777893, 7.30444384], [93.70762634, 7.30429602], [93.70749664, 7.30416584], [93.70722198, 7.30417109], [93.70610046, 7.30306101], [93.70610046, 7.30222178], [93.70583344, 7.30194378], [93.70583344, 7.30027819], [93.70555878, 7.30000019], [93.70555878, 7.2994442], [93.70471954, 7.29861212], [93.70444489, 7.29861212], [93.70424652, 7.29841089], [93.70417023, 7.29833412], [93.70388794, 7.29833412], [93.70333099, 7.29777813], [93.70305634, 7.29778004], [93.70276642, 7.29750013], [93.70249939, 7.29750013], [93.70222473, 7.29722214], [93.70194244, 7.29722214], [93.69962311, 7.29490089], [93.69833374, 7.29361105], [93.69805908, 7.29361105], [93.69777679, 7.29333305], [93.69750214, 7.29333305], [93.6973877, 7.29321909], [93.69721985, 7.29305506], [93.6966629, 7.29305983], [93.69638824, 7.29277992], [93.69610596, 7.29277992], [93.6958313, 7.29250193], [93.69555664, 7.29250193], [93.69526672, 7.29277992], [93.69473267, 7.29277992], [93.69444275, 7.29305983], [93.69416046, 7.29305983], [93.6938858, 7.29277992], [93.69361115, 7.29277992], [93.69304657, 7.29222107], [93.69277954, 7.29222107], [93.69249725, 7.29194498], [93.6922226, 7.29194498], [93.69194794, 7.29166698], [93.69139099, 7.29166985], [93.69111633, 7.29140091], [93.69055176, 7.29140091], [93.69028473, 7.29112291], [93.68972015, 7.29111099], [93.6894455, 7.290833], [93.68722534, 7.290833], [93.68701935, 7.29062986], [93.68694305, 7.290555], [93.6866684, 7.29055977], [93.68638611, 7.29028177], [93.68611145, 7.29028177], [93.68554688, 7.28972101], [93.6855545, 7.28916693], [93.68527985, 7.28888893], [93.68527985, 7.28861094], [93.68499756, 7.28833294], [93.68499756, 7.28805494], [93.68416595, 7.28722286], [93.68416595, 7.28666687], [93.68333435, 7.28583288], [93.68250275, 7.28583288], [93.68222046, 7.28555489], [93.68165588, 7.28555918], [93.68148804, 7.28537893], [93.68138885, 7.28527021], [93.68083191, 7.2852788], [93.68055725, 7.2850008], [93.68000031, 7.2850008], [93.67973328, 7.2847209], [93.67944336, 7.28472281], [93.6783371, 7.28361082], [93.6783371, 7.28333282], [93.67805481, 7.28305721], [93.67805481, 7.28277922], [93.67778015, 7.28250122], [93.67778015, 7.28222895], [93.67749786, 7.28193998], [93.67749786, 7.28166723], [93.67722321, 7.28138781], [93.67722321, 7.28082991], [93.67694092, 7.28055716], [93.67722321, 7.28027916], [93.67722321, 7.27943993], [93.67749786, 7.27916622], [93.67749786, 7.27861023], [93.67778015, 7.27833223], [93.67778015, 7.27750015], [93.67722321, 7.27694416], [93.67694092, 7.27694416], [93.67666626, 7.27666616], [93.6763916, 7.27667093], [93.67527771, 7.27556086], [93.67527771, 7.27528], [93.67500305, 7.2750001], [93.67500305, 7.2747221], [93.67472076, 7.2744441], [93.67472076, 7.27389002], [93.67444611, 7.27361202], [93.67444611, 7.27305603], [93.67416382, 7.27277803], [93.67415619, 7.27222013], [93.67388916, 7.27194405], [93.67388916, 7.27166605], [93.6736145, 7.27138996], [93.67360687, 7.27111006], [93.67166901, 7.26916504], [93.67166901, 7.2688899], [93.67111206, 7.26832914], [93.67111206, 7.26777697], [93.67082977, 7.26749897], [93.67082977, 7.26583099], [93.67055511, 7.2655549], [93.67055511, 7.26499891], [93.67028046, 7.26472092], [93.67028046, 7.26277685], [93.66999817, 7.26249886], [93.66999054, 7.26138878], [93.66971588, 7.26109982], [93.66972351, 7.25972319], [93.66944122, 7.25944519], [93.66944122, 7.2588892], [93.66916656, 7.2586112], [93.66916656, 7.25833321], [93.66889191, 7.25805521], [93.66889191, 7.25777721], [93.66722107, 7.25611115], [93.66638947, 7.25611115], [93.66583252, 7.25555706], [93.66443634, 7.25556087], [93.66417694, 7.25529003], [93.66361237, 7.25529003], [93.66306305, 7.25472021], [93.66278076, 7.25472307], [93.66166687, 7.25361013], [93.66139221, 7.25361013], [93.66083527, 7.253057], [93.66055298, 7.25306082], [93.66027832, 7.25278091], [93.66027832, 7.25250006], [93.65972137, 7.25193977], [93.65972137, 7.25166607], [93.65944672, 7.25138807], [93.65944672, 7.25083017], [93.65777588, 7.24916601], [93.65666962, 7.24840307], [93.65590668, 7.24784613], [93.65528107, 7.24694395], [93.65451813, 7.24610996], [93.65354919, 7.24520683], [93.65292358, 7.24444389], [93.65083313, 7.24444389], [93.65000153, 7.24361181], [93.64971924, 7.24361181], [93.64897919, 7.2428689], [93.64861298, 7.24249983], [93.64833069, 7.24249983], [93.64778137, 7.24306011], [93.6472168, 7.24306011], [93.64638519, 7.24388981], [93.64638519, 7.2441678], [93.64583588, 7.24472189], [93.64554596, 7.24471903], [93.64527893, 7.24500179], [93.64499664, 7.24500179], [93.64360809, 7.24638796], [93.64360809, 7.24666595], [93.64333344, 7.24694395], [93.64333344, 7.24749994], [93.64221954, 7.24861002], [93.64167023, 7.24861002], [93.64055634, 7.2497201], [93.64055634, 7.25], [93.64026642, 7.25028086], [93.64026642, 7.25056124], [93.63999939, 7.25055599], [93.63972473, 7.25083399], [93.6397171, 7.25111008], [93.63944244, 7.25138998], [93.63944244, 7.25166607], [93.63805389, 7.253057], [93.63861084, 7.25361013], [93.63861084, 7.25444508], [93.63889313, 7.25472021], [93.63889313, 7.25529003], [93.63861084, 7.25555706], [93.63861084, 7.25666714], [93.63833618, 7.25694513], [93.63833618, 7.25722122], [93.63805389, 7.25750113], [93.63805389, 7.25777721], [93.63722229, 7.2586112], [93.63722229, 7.2588892], [93.63666534, 7.25944519], [93.63667297, 7.2597208], [93.63500214, 7.26138878], [93.63445282, 7.26138878], [93.6341629, 7.26166916], [93.63388824, 7.26166677], [93.63360596, 7.26194096], [93.63360596, 7.26277924], [93.63277435, 7.26361084], [93.6313858, 7.26361084], [93.63111115, 7.26333284], [93.63027954, 7.26333284], [93.62999725, 7.26361084], [93.62999725, 7.26416683], [93.6297226, 7.26416683], [93.62916565, 7.26472282], [93.62889862, 7.26577902], [93.62876129, 7.26730299], [93.62876129, 7.26855183], [93.62916565, 7.26972198], [93.63083649, 7.27138996], [93.63083649, 7.2719388], [93.6313324, 7.2724452], [93.63166809, 7.27277994], [93.63194275, 7.27277803], [93.63249969, 7.27333403], [93.63277435, 7.27333403], [93.63361359, 7.27416611], [93.63361359, 7.2744441], [93.63388062, 7.27472019], [93.63388062, 7.2750001], [93.6341629, 7.27528], [93.6341629, 7.27638817], [93.63388824, 7.27666616], [93.63388062, 7.27694178], [93.63276672, 7.27806091], [93.63223267, 7.27806091], [93.63194275, 7.27777815], [93.63111115, 7.27861023], [93.63111115, 7.28027916], [93.63194275, 7.28110981], [93.63223267, 7.28110981], [93.63388824, 7.28277922], [93.63388824, 7.28305721], [93.6341629, 7.28333282], [93.6341629, 7.28583288], [93.63444519, 7.28611088], [93.63444519, 7.28638887], [93.63388824, 7.28694487], [93.63388824, 7.28722286], [93.63361359, 7.28749895], [93.63360596, 7.28861094], [93.6333313, 7.28889084], [93.6333313, 7.29000092], [93.63305664, 7.290277], [93.63305664, 7.290555], [93.63277435, 7.290833], [93.63276672, 7.29111099], [93.63249969, 7.29138899], [93.63249969, 7.29166698], [93.63223267, 7.29194117], [93.63223267, 7.29250193], [93.63194275, 7.29277706], [93.63194275, 7.29305506], [93.63166809, 7.29333305], [93.63166809, 7.29361105], [93.6313858, 7.29389], [93.6313858, 7.29471922], [93.63111115, 7.29499912], [93.63111115, 7.29527998], [93.63083649, 7.29555607], [93.63083649, 7.29666615], [93.63054657, 7.2969408], [93.6305542, 7.29777813], [93.63027954, 7.29805613], [93.63027954, 7.29832888], [93.6297226, 7.29888821], [93.6297226, 7.2991662], [93.62944794, 7.2994442], [93.62944794, 7.30027103], [93.62916565, 7.30055618], [93.62909698, 7.30152893], [93.62921906, 7.30222178], [93.62923431, 7.30284882], [93.62875366, 7.3031249], [93.62805176, 7.30360985], [93.62805176, 7.30388784], [93.6277771, 7.30416584], [93.6277771, 7.30444384], [93.62638855, 7.30583382], [93.6230545, 7.30583382], [93.62277985, 7.30610991], [93.62249756, 7.30610991], [93.62166595, 7.30694389], [93.62166595, 7.30721998], [93.6213913, 7.30750084], [93.6213913, 7.30805397], [93.62110901, 7.30833197], [93.62110901, 7.3094449], [93.6213913, 7.3097229], [93.6213913, 7.31083012], [93.62194061, 7.31139088], [93.6222229, 7.31139088], [93.62249756, 7.31167078], [93.62333679, 7.31167078], [93.62361145, 7.31139088], [93.62472534, 7.31138897], [93.62527466, 7.31194496], [93.62555695, 7.31194496], [93.6269455, 7.31333303], [93.62750244, 7.31333303], [93.6277771, 7.31361103], [93.62832642, 7.31361103], [93.6286087, 7.31389093], [93.62889099, 7.31388903], [93.62898254, 7.31398201], [93.62917328, 7.31417179], [93.62944794, 7.31416702], [93.63027954, 7.31500101], [93.63027954, 7.31583309], [93.63166809, 7.31722116], [93.63222504, 7.31722116], [93.63279724, 7.31779814], [93.63305664, 7.31805992], [93.6333313, 7.31805992], [93.63555908, 7.32027721], [93.63555908, 7.32055521], [93.63583374, 7.32083321], [93.63583374, 7.32111216], [93.6361084, 7.32139015], [93.6361084, 7.32416821], [93.63639069, 7.32444096], [93.63639069, 7.32499981], [93.63667297, 7.32528019], [93.63667297, 7.32638979], [93.63639069, 7.32666588], [93.63639069, 7.32805586], [93.63666534, 7.32833385], [93.63666534, 7.32860994], [93.63639069, 7.32888794], [93.63639069, 7.33083391], [93.63666534, 7.33111], [93.63666534, 7.33194399], [93.63639069, 7.33222008], [93.63639069, 7.33249998], [93.6361084, 7.33278084], [93.6361084, 7.33306122], [93.63500214, 7.33417082], [93.63471985, 7.33416605], [93.63444519, 7.33444405], [93.6341629, 7.33444405], [93.63277435, 7.33583212], [93.63277435, 7.33611107], [93.63249969, 7.33638906], [93.63249969, 7.33694506], [93.63222504, 7.33722305], [93.63223267, 7.33750105], [93.63249969, 7.33778095], [93.63249969, 7.33916712], [93.63277435, 7.33944511], [93.63276672, 7.34111118], [93.63249969, 7.34138918], [93.63277435, 7.34499884], [93.63277435, 7.34555483], [93.63305664, 7.34583282], [93.63305664, 7.34638882], [93.63360596, 7.34694099], [93.63361359, 7.34777689], [93.6333313, 7.34805489], [93.6333313, 7.34832001], [93.63277435, 7.34888983], [93.63277435, 7.34916782], [93.63249969, 7.34944296], [93.63249969, 7.34972191], [93.63222504, 7.3499999], [93.63194275, 7.35139704], [93.63181305, 7.35298109], [93.63159943, 7.35680723], [93.63124847, 7.35909796], [93.63111115, 7.36055708], [93.63111115, 7.3616662], [93.6313858, 7.36194515], [93.6313858, 7.36250114], [93.63166809, 7.36277914], [93.63166809, 7.36333323], [93.63194275, 7.3661108], [93.63194275, 7.36694479], [93.63223267, 7.36722088], [93.63223267, 7.36777878], [93.63249969, 7.36805487], [93.63249969, 7.37055492], [93.63277435, 7.37083292], [93.63276672, 7.37111092], [93.63305664, 7.37139177], [93.63305664, 7.37166977], [93.6341629, 7.37277985], [93.63445282, 7.37277985], [93.63459015, 7.37292814], [93.63471985, 7.37306023], [93.63527679, 7.37305498], [93.63583374, 7.37361097], [93.63667297, 7.37361097], [93.63694763, 7.37388897], [93.63722229, 7.37388897], [93.63749695, 7.37361097], [93.63861084, 7.37361097], [93.63889313, 7.37388897], [93.6397171, 7.37388897], [93.64000702, 7.37361097], [93.64111328, 7.37361097], [93.64138794, 7.37333298], [93.64167023, 7.37333298], [93.64194489, 7.37305498], [93.64221954, 7.37306023], [93.64360809, 7.37166977], [93.64389038, 7.37166977], [93.64417267, 7.37139177], [93.64444733, 7.37139177], [93.64472198, 7.37111092], [93.64499664, 7.37111092], [93.64527893, 7.37083292], [93.64555359, 7.37083292], [93.64583588, 7.37055492], [93.64611053, 7.37056017], [93.64749908, 7.36916924], [93.64778137, 7.36916924], [93.64805603, 7.36889076], [93.64833069, 7.36889076], [93.64861298, 7.36861086], [93.64943695, 7.36861086], [93.64971924, 7.36889076], [93.65000153, 7.36889076], [93.65027618, 7.36916924], [93.65055847, 7.36916685], [93.65110779, 7.36972284], [93.65194702, 7.36972284], [93.65218353, 7.36995983], [93.65277863, 7.37056017], [93.65305328, 7.37056017], [93.65528107, 7.37277985], [93.65556335, 7.37277985], [93.65666962, 7.37388897], [93.65666962, 7.37416792], [93.65721893, 7.37471914], [93.65721893, 7.37499905], [93.65750122, 7.37527704], [93.65750122, 7.37555599], [93.65777588, 7.37583399], [93.65777588, 7.37611198], [93.65999603, 7.3783288], [93.65999603, 7.3786211], [93.66027832, 7.37889004], [93.66027832, 7.37916613], [93.66194153, 7.3808341], [93.66305542, 7.3808341], [93.66333008, 7.3811121], [93.66500092, 7.3811121], [93.66527557, 7.3808341], [93.66583252, 7.3808341], [93.66722107, 7.37944412], [93.66722107, 7.37889004], [93.66750336, 7.37861204], [93.66750336, 7.37805986], [93.66777802, 7.37777996], [93.66777802, 7.37750006], [93.67166901, 7.37361097], [93.67194366, 7.37361097], [93.67222595, 7.37333298], [93.67250061, 7.37333298], [93.67277527, 7.37305498], [93.67305756, 7.37333298], [93.67444611, 7.37333298], [93.67472076, 7.37361097], [93.67500305, 7.37361097], [93.67527771, 7.37388897], [93.67555237, 7.37388897], [93.67582703, 7.37416983], [93.67610931, 7.37416792], [93.67666626, 7.37472105], [93.67694092, 7.37471914], [93.67749786, 7.3752799], [93.67778015, 7.37527704], [93.67805481, 7.37555599], [93.6783371, 7.37555599], [93.67861176, 7.37583399], [93.6791687, 7.37583399], [93.67944336, 7.37611198], [93.67972565, 7.37611198], [93.68027496, 7.37666512], [93.68027496, 7.37694407], [93.68055725, 7.3772192], [93.68055725, 7.37750006], [93.68083191, 7.37777805], [93.68083191, 7.37805605], [93.6811142, 7.37833405], [93.6811142, 7.37944412], [93.68138885, 7.37972212], [93.68138885, 7.3808341], [93.68166351, 7.3811121], [93.68166351, 7.38416576], [93.6819458, 7.38444424], [93.6819458, 7.38472223], [93.68305206, 7.38583183], [93.68305206, 7.38610983], [93.68360901, 7.38666582], [93.68360901, 7.38694382], [93.68416595, 7.38749981], [93.6847229, 7.38749123], [93.68498993, 7.38778114], [93.68723297, 7.38778114], [93.6875, 7.38806105], [93.68777466, 7.38805389], [93.68805695, 7.38833189], [93.6883316, 7.38832998], [93.68860626, 7.38860989], [93.68888855, 7.38860989], [93.68916321, 7.38889122], [93.68945313, 7.38889122], [93.69055176, 7.39000082], [93.69167328, 7.39000082], [93.69187164, 7.39020109], [93.69194794, 7.3902812], [93.6922226, 7.3902812], [93.69249725, 7.39000082], [93.69304657, 7.39000082], [93.69333649, 7.38971996], [93.69361115, 7.38972282], [93.6958313, 7.39194489], [93.69611359, 7.39194489], [93.69628906, 7.39211988], [93.69638824, 7.39222288], [93.6966629, 7.39222097], [93.69689941, 7.39245319], [93.69805908, 7.39362001], [93.6986084, 7.39362001], [93.69889069, 7.39389086], [93.69917297, 7.39389086], [93.70054626, 7.39250088], [93.70194244, 7.39250088], [93.7022171, 7.39278078], [93.70361328, 7.39278078], [93.70388794, 7.39250088], [93.70417023, 7.39250088], [93.70443726, 7.39278078], [93.70500183, 7.39277887], [93.70555878, 7.39333296], [93.70610046, 7.3933301], [93.70639038, 7.39362001], [93.70694733, 7.39362001], [93.70722198, 7.39389086], [93.70749664, 7.39389086], [93.70777893, 7.39362001], [93.70804596, 7.39362001], [93.70889282, 7.39278078], [93.70944214, 7.39278078], [93.7097168, 7.39250088], [93.71333313, 7.39250088], [93.71360779, 7.39278078], [93.71389008, 7.39277887], [93.71444702, 7.39333296], [93.71444702, 7.39472103], [93.7141571, 7.39500093], [93.7141571, 7.39555883], [93.71263885, 7.39673996], [93.71166992, 7.3968792], [93.71092224, 7.39673996], [93.71028137, 7.39638901], [93.70944214, 7.39722109], [93.70888519, 7.39722109], [93.70833588, 7.39777708], [93.70833588, 7.39861107], [93.70861053, 7.39888906], [93.70861053, 7.39972115], [93.70833588, 7.39999914], [93.70749664, 7.39999914], [93.70722198, 7.40028], [93.70694733, 7.40028], [93.70667267, 7.4005599], [93.70500183, 7.40055513], [93.70471954, 7.40083313], [93.70444489, 7.40090418], [93.70375061, 7.40090418], [93.70333099, 7.40139008], [93.70333099, 7.4022212], [93.70582581, 7.40471888], [93.70582581, 7.40500021], [93.70610809, 7.40527821], [93.70610809, 7.4066658], [93.70639038, 7.40694094], [93.70639038, 7.40749979], [93.70666504, 7.40777779], [93.70666504, 7.40916586], [93.70694733, 7.40944386], [93.70694733, 7.40972185], [93.70666504, 7.40999985], [93.70666504, 7.41083384], [93.70610809, 7.41138792], [93.70610809, 7.41166592], [93.70652771, 7.41284704], [93.70694733, 7.41360998], [93.70722198, 7.41388798], [93.70722198, 7.41416597], [93.70749664, 7.41444016], [93.70749664, 7.41473198], [93.70777893, 7.41500092], [93.70777893, 7.41555405], [93.70869446, 7.41694689], [93.70903778, 7.41757107], [93.70910645, 7.41840315], [93.70896912, 7.41923523], [93.7086792, 7.4199419], [93.70861053, 7.42111111], [93.70861053, 7.4213891], [93.70888519, 7.4216671], [93.70888519, 7.42250109], [93.70916748, 7.42277718], [93.70916748, 7.42333317], [93.70944214, 7.4236002], [93.70916748, 7.42388916], [93.70944214, 7.42416716], [93.70916748, 7.42444515], [93.70915985, 7.42472076], [93.70861053, 7.42527914], [93.70833588, 7.42527723], [93.70666504, 7.42694283], [93.70666504, 7.42805481], [93.70639038, 7.42833281], [93.70639038, 7.42860889], [93.70694733, 7.42916822], [93.70694733, 7.43055582], [93.70722198, 7.43083096], [93.70722198, 7.43138981], [93.70749664, 7.4316678], [93.70722198, 7.43194389], [93.70722198, 7.43222189], [93.70749664, 7.43249989], [93.70722198, 7.43277788], [93.70722198, 7.43333387], [93.70694733, 7.43360996], [93.70694733, 7.43389177], [93.70667267, 7.43416977], [93.70667267, 7.43638992], [93.70694733, 7.43667078], [93.70694733, 7.437778], [93.70666504, 7.43805599], [93.70667267, 7.43833017], [93.70610809, 7.43888807], [93.70610809, 7.43916607], [93.70555878, 7.43972015], [93.70555878, 7.44000006], [93.70527649, 7.44027805], [93.70527649, 7.44055605], [93.70471954, 7.44111013], [93.70471954, 7.44305706], [93.70500183, 7.44332981], [93.70500183, 7.44417095], [93.70582581, 7.44500113], [93.70610046, 7.44500113], [93.70639038, 7.44471121], [93.70639038, 7.44444513], [93.70666504, 7.44416714], [93.70694733, 7.44417095], [93.70749664, 7.44361115], [93.70777893, 7.44361115], [93.70805359, 7.4433322], [93.70833588, 7.4433322], [93.70861053, 7.44361115], [93.70979309, 7.44424009], [93.71026611, 7.44479084], [93.71089935, 7.44506884], [93.71180725, 7.44514179], [93.71270752, 7.44471121], [93.71333313, 7.44388914], [93.71305847, 7.44361115]]], [[[93.64778137, 7.47666883], [93.64805603, 7.47639084], [93.64888763, 7.47639084], [93.64916992, 7.47611094], [93.65000153, 7.47611094], [93.65249634, 7.47361088], [93.65249634, 7.47305489], [93.65277863, 7.4727788], [93.65277863, 7.4725008], [93.65249634, 7.47221994], [93.65249634, 7.47138882], [93.65277863, 7.47111082], [93.65194702, 7.47027922], [93.6516571, 7.47028112], [93.65139008, 7.47000122], [93.65110779, 7.47028112], [93.65083313, 7.47028112], [93.65055847, 7.47000122], [93.64943695, 7.47000122], [93.64916992, 7.47028112], [93.64833069, 7.47028112], [93.64805603, 7.47056103], [93.64722443, 7.47055721], [93.64694214, 7.47083282], [93.64666748, 7.47083282], [93.64638519, 7.47111082], [93.64611053, 7.47111082], [93.64555359, 7.47055721], [93.64527893, 7.47056103], [93.64499664, 7.47028112], [93.64472198, 7.47027922], [93.64416504, 7.47083282], [93.64417267, 7.47111082], [93.64389038, 7.4713912], [93.64417267, 7.4716711], [93.64417267, 7.47278118], [93.64389038, 7.47305918], [93.64389038, 7.47388887], [93.64416504, 7.47416687], [93.64417267, 7.4744401], [93.64485931, 7.47514009], [93.64499664, 7.47528076], [93.64527893, 7.47528076], [93.64562225, 7.47562599], [93.64639282, 7.47639084], [93.64694214, 7.47639084], [93.6472168, 7.47666883], [93.64778137, 7.47666883]]], [[[93.63445282, 7.47778177], [93.63471985, 7.47750092], [93.63445282, 7.47722101], [93.63444519, 7.47666693], [93.63440704, 7.47593784], [93.63385773, 7.47558022], [93.63314819, 7.47552109], [93.6326828, 7.47580099], [93.63223267, 7.47639084], [93.63083649, 7.47778177], [93.6305542, 7.477777], [93.62999725, 7.478333], [93.62999725, 7.47861099], [93.63027954, 7.47888899], [93.63027954, 7.47972107], [93.63054657, 7.48000097], [93.63249969, 7.48000097], [93.63445282, 7.47807121], [93.63445282, 7.47778177]]], [[[93.54360199, 7.52500105], [93.54582977, 7.5227809], [93.54582977, 7.52250099], [93.54693604, 7.52139091], [93.54693604, 7.52111006], [93.54833221, 7.51972198], [93.5486145, 7.51972198], [93.54944611, 7.518888], [93.54944611, 7.51861], [93.55027771, 7.51777792], [93.55029297, 7.51702595], [93.5501709, 7.51612091], [93.54953003, 7.51528883], [93.54890442, 7.5142498], [93.54856873, 7.51306915], [93.54779053, 7.51210117], [93.54662323, 7.51133013], [93.54499817, 7.51055622], [93.54332733, 7.51056004], [93.54305267, 7.51028013], [93.54277802, 7.51028013], [93.54250336, 7.5099988], [93.54194641, 7.51055622], [93.54194641, 7.51221895], [93.54138947, 7.51278019], [93.54110718, 7.51278019], [93.54083252, 7.51306009], [93.54055786, 7.5130558], [93.54000092, 7.51361179], [93.54000092, 7.51388979], [93.5402832, 7.51417923], [93.54027557, 7.51499987], [93.54055786, 7.51527786], [93.54055786, 7.51582909], [93.54166412, 7.51694393], [93.54166412, 7.51777792], [93.54083252, 7.51861], [93.54055786, 7.51861], [93.53971863, 7.51944399], [93.53971863, 7.51999998], [93.54000092, 7.52027798], [93.54000092, 7.52083397], [93.5402832, 7.52111006], [93.5402832, 7.52139091], [93.54055786, 7.52167082], [93.54055786, 7.52250099], [93.54083252, 7.52277899], [93.54083252, 7.52305698], [93.54055786, 7.52333498], [93.54055786, 7.52388906], [93.54111481, 7.52444506], [93.54129028, 7.52462006], [93.54138947, 7.52472305], [93.54194641, 7.52416706], [93.54222107, 7.52416706], [93.54250336, 7.52444506], [93.54277802, 7.52443981], [93.54332733, 7.52500105], [93.54360199, 7.52500105]]], [[[93.33963013, 7.91114998], [93.33965302, 7.91087008], [93.34018707, 7.91087198], [93.3401947, 7.90973186], [93.34046173, 7.90973186], [93.34046173, 7.90951109], [93.3401947, 7.90946817], [93.34018707, 7.90894222], [93.33990479, 7.90892792], [93.33987427, 7.90864992], [93.33937836, 7.90864992], [93.3393631, 7.90892982], [93.33908844, 7.90892792], [93.33908844, 7.90917921], [93.33880615, 7.90919209], [93.33878326, 7.91058016], [93.33933258, 7.91059399], [93.3393631, 7.91112995], [93.33963013, 7.91114998]]], [[[93.34156036, 7.90645981], [93.34159851, 7.90592003], [93.34215546, 7.90594482], [93.3421402, 7.90562487], [93.34243011, 7.90559578], [93.34240723, 7.905056], [93.34269714, 7.90505981], [93.3427124, 7.90470886], [93.34243011, 7.90470886], [93.34243011, 7.90413904], [93.34211731, 7.90413904], [93.34208679, 7.90469599], [93.34043121, 7.90472078], [93.34043121, 7.90505981], [93.34069824, 7.90506887], [93.34069824, 7.90535021], [93.34070587, 7.90588999], [93.3409729, 7.90588999], [93.3409729, 7.90616083], [93.34126282, 7.90616989], [93.34127808, 7.90645981], [93.34156036, 7.90645981]]], [[[93.18805695, 8.19250011], [93.1875, 8.19306087], [93.18722534, 8.1930542], [93.1866684, 8.19361019], [93.1866684, 8.19388771], [93.18611145, 8.1944437], [93.18583679, 8.1944437], [93.1855545, 8.19472218], [93.1847229, 8.19472027], [93.18444824, 8.19500065], [93.18360901, 8.19500065], [93.18332672, 8.19528103], [93.1827774, 8.19528103], [93.18251038, 8.19556141], [93.18222046, 8.19555664], [93.1819458, 8.19583225], [93.18000031, 8.19583225], [93.17972565, 8.19610977], [93.17944336, 8.19610977], [93.1791687, 8.19583035], [93.17861176, 8.1963892], [93.17861176, 8.19722271], [93.17858124, 8.19760323], [93.1786499, 8.19780159], [93.17851257, 8.19815731], [93.17837524, 8.19829559], [93.17795563, 8.19843292], [93.1778183, 8.19836521], [93.17722321, 8.19806099], [93.17694092, 8.19805527], [93.1763916, 8.19861126], [93.17687225, 8.19895267], [93.17707825, 8.19915962], [93.17673492, 8.19950867], [93.17624664, 8.19971561], [93.17575836, 8.19997978], [93.1753006, 8.20024872], [93.17505646, 8.20048046], [93.17430115, 8.20034122], [93.17410278, 8.20028973], [93.1738205, 8.19972134], [93.17360687, 8.19923973], [93.17326355, 8.19889069], [93.1727066, 8.19923973], [93.17249298, 8.20014], [93.17251587, 8.20075989], [93.17246246, 8.2009697], [93.17217255, 8.20125008], [93.17175293, 8.20146179], [93.17160797, 8.20125008], [93.17086029, 8.2009697], [93.17057037, 8.20068932], [93.16925049, 8.20069218], [93.16889954, 8.20041561], [93.16847992, 8.20020771], [93.16806793, 8.20006943], [93.16751099, 8.19979095], [93.16722107, 8.19972324], [93.16638947, 8.19972324], [93.16611481, 8.20000076], [93.16555786, 8.19999886], [93.16500092, 8.20056152], [93.16444397, 8.20055485], [93.16416931, 8.20083332], [93.16333008, 8.20083332], [93.16305542, 8.20111084], [93.16194153, 8.20111084], [93.16166687, 8.20083332], [93.16110992, 8.20083332], [93.1608429, 8.20111084], [93.16088104, 8.20216179], [93.16068268, 8.20251274], [93.16018677, 8.20264721], [93.15969849, 8.20312977], [93.15976715, 8.20389366], [93.15962982, 8.20410061], [93.1594162, 8.20472622], [93.15949249, 8.20493317], [93.15914154, 8.20527935], [93.15879059, 8.20555687], [93.15816498, 8.20590401], [93.15768433, 8.20611095], [93.15712738, 8.20631886], [93.15657043, 8.20638943], [93.15608215, 8.20666981], [93.15538788, 8.20666981], [93.15476227, 8.20674038], [93.15455627, 8.20660114], [93.15406799, 8.20631886], [93.15329742, 8.20659733], [93.15288544, 8.20701408], [93.15267181, 8.20756817], [93.15274811, 8.20820141], [93.15274811, 8.20868683], [93.15288544, 8.20896244], [93.15267181, 8.20917225], [93.15232849, 8.20917225], [93.15190887, 8.20889378], [93.15156555, 8.20889378], [93.1512146, 8.20896244], [93.15079498, 8.20903301], [93.15045166, 8.20924091], [93.15010071, 8.2095871], [93.14961243, 8.20986462], [93.14933777, 8.21007156], [93.14891815, 8.21014118], [93.14821625, 8.21028042], [93.14766693, 8.21006966], [93.14710999, 8.21035004], [93.14648438, 8.21062565], [93.14592743, 8.21076488], [93.14572144, 8.21090412], [93.14499664, 8.21166801], [93.14472198, 8.21194363], [93.14444733, 8.21193886], [93.14409637, 8.21228981], [93.1434021, 8.21263885], [93.14221954, 8.21333408], [93.14167023, 8.21333408], [93.14138794, 8.2136097], [93.14111328, 8.2136097], [93.14083099, 8.21389008], [93.14083099, 8.21416569], [93.14055634, 8.21444416], [93.13999939, 8.21444416], [93.13972473, 8.21472168], [93.13944244, 8.21472168], [93.13916779, 8.21500015], [93.1388855, 8.21500015], [93.13861084, 8.21527767], [93.13722229, 8.21527767], [93.13694763, 8.21500015], [93.13666534, 8.21500015], [93.1361084, 8.21444416], [93.13527679, 8.215271], [93.13527679, 8.21667099], [93.13446045, 8.21749973], [93.13388824, 8.21749973], [93.1333313, 8.21806145], [93.13305664, 8.21805573], [93.13277435, 8.2183342], [93.13277435, 8.21860981], [93.13194275, 8.21944427], [93.12944794, 8.21944427], [93.12916565, 8.2191658], [93.12889099, 8.2191658], [93.12833405, 8.21972179], [93.12805176, 8.21972179], [93.1277771, 8.22000027], [93.12666321, 8.22000027], [93.12611389, 8.22055435], [93.12610626, 8.22082996], [93.12526703, 8.2216711], [93.125, 8.22140026], [93.12473297, 8.22140026], [93.12441254, 8.2210741], [93.1241684, 8.22082996], [93.12333679, 8.22083473], [93.12194824, 8.22222328], [93.12166595, 8.22222328], [93.1213913, 8.2225008], [93.12083435, 8.2225008], [93.11972046, 8.22361088], [93.11972046, 8.22416687], [93.1194458, 8.22444534], [93.11946106, 8.22472], [93.11860657, 8.22555923], [93.11833191, 8.22555923], [93.11815643, 8.22606087], [93.11760712, 8.22626972], [93.1173172, 8.2259903], [93.11677551, 8.22585106], [93.11656189, 8.22605801], [93.11611176, 8.22611141], [93.11528015, 8.22694492], [93.11528015, 8.2272234], [93.11499786, 8.22750092], [93.11499786, 8.22944069], [93.11555481, 8.22999859], [93.11577606, 8.23042965], [93.11605835, 8.23104954], [93.11612701, 8.2318182], [93.1157074, 8.23243999], [93.11521912, 8.23272038], [93.11487579, 8.23271847], [93.11425018, 8.23313522], [93.11389923, 8.23285675], [93.11333466, 8.23277664], [93.11303711, 8.23250103], [93.11194611, 8.23249912], [93.11027527, 8.2341671], [93.11027527, 8.23444557], [93.11000061, 8.23472118], [93.11000061, 8.2349987], [93.10944366, 8.2355547], [93.10943604, 8.23583126], [93.10888672, 8.2364006], [93.10861206, 8.23639011], [93.10749817, 8.23750019], [93.10701752, 8.2379303], [93.10666656, 8.23821068], [93.10624695, 8.23897171], [93.10597992, 8.23918247], [93.10507202, 8.24007988], [93.10444641, 8.24104977], [93.10410309, 8.24174118], [93.10361481, 8.24222946], [93.10347748, 8.24243641], [93.10325623, 8.24292183], [93.1029892, 8.24313068], [93.10292053, 8.24409962], [93.1027832, 8.24451923], [93.10222626, 8.24520969], [93.10187531, 8.24534893], [93.10138702, 8.24555588], [93.10138702, 8.24582958], [93.10111237, 8.24610996], [93.10111237, 8.24713993], [93.10090637, 8.24776268], [93.10090637, 8.24838734], [93.10069275, 8.2488718], [93.10062408, 8.24929047], [93.10034943, 8.24984264], [93.09999847, 8.25012112], [93.09999847, 8.25060463], [93.09972382, 8.25074577], [93.09972382, 8.25166702], [93.09999847, 8.25194454], [93.09999847, 8.25222015], [93.10028076, 8.25250053], [93.10028076, 8.25278091], [93.10054779, 8.25311184], [93.10047913, 8.25358963], [93.09999084, 8.25366116], [93.09942627, 8.25352192], [93.09900665, 8.25352192], [93.09896088, 8.25334167], [93.09854126, 8.2532711], [93.09806061, 8.25347614], [93.09770966, 8.25458622], [93.09694672, 8.25583267], [93.09694672, 8.25611115], [93.09638977, 8.25666714], [93.09638977, 8.25694466], [93.09610748, 8.25722122], [93.09610748, 8.25751019], [93.09583282, 8.25777912], [93.09583282, 8.25805473], [93.09555817, 8.25833321], [93.09555817, 8.25861073], [93.09527588, 8.2588892], [93.09527588, 8.25916672], [93.09373474, 8.26070786], [93.09313202, 8.26176834], [93.09278107, 8.26211357], [93.09229279, 8.26253128], [93.09208679, 8.26329327], [93.09194946, 8.26350021], [93.09166718, 8.26371002], [93.09146118, 8.26398468], [93.09126282, 8.26433182], [93.09126282, 8.26468086], [93.09111786, 8.26474857], [93.09076691, 8.26495647], [93.09027863, 8.26523018], [93.08994293, 8.26578999], [93.08972168, 8.26607132], [93.08958435, 8.2660656], [93.08937836, 8.26641273], [93.08909607, 8.26682663], [93.08860779, 8.26721859], [93.08833313, 8.26749992], [93.08833313, 8.2677784], [93.08805847, 8.26805592], [93.08805847, 8.26833153], [93.08750153, 8.26889038], [93.08750153, 8.26917267], [93.08721924, 8.26944447], [93.08721924, 8.27000046], [93.08694458, 8.27027798], [93.08694458, 8.27055645], [93.08666992, 8.27083206], [93.08666992, 8.27111244], [93.08638763, 8.27138805], [93.08638763, 8.27194405], [93.08609772, 8.27221966], [93.08609772, 8.27251244], [93.08583069, 8.27277756], [93.08583069, 8.27305603], [93.08555603, 8.27333355], [93.08555603, 8.27361012], [93.08528137, 8.27388763], [93.08528137, 8.2747221], [93.08506012, 8.27493668], [93.08493042, 8.27577305], [93.08493042, 8.27605057], [93.08478546, 8.27639771], [93.0847168, 8.27701092], [93.08486176, 8.27750778], [93.08493042, 8.27812958], [93.08479309, 8.27833939], [93.0845108, 8.27854729], [93.08444214, 8.27916718], [93.08416748, 8.27943993], [93.08416748, 8.28027916], [93.08388519, 8.28055477], [93.08388519, 8.28194523], [93.08361053, 8.28222084], [93.08361053, 8.28333282], [93.08381653, 8.28447723], [93.08388519, 8.28482437], [93.08429718, 8.28510189], [93.08444214, 8.28531075], [93.08465576, 8.28565502], [93.08486176, 8.28621197], [93.08486176, 8.28669739], [93.08479309, 8.28725147], [93.0845871, 8.28787136], [93.08444214, 8.28878021], [93.08436584, 8.28947067], [93.08409882, 8.28975105], [93.08416748, 8.29051018], [93.08381653, 8.2907896], [93.08388519, 8.2913866], [93.08388519, 8.29166794], [93.08361053, 8.29194355], [93.08361053, 8.29416561], [93.08333588, 8.29444408], [93.08333588, 8.29555607], [93.08361053, 8.29583359], [93.08378601, 8.29663944], [93.08406067, 8.29719162], [93.08413696, 8.29760933], [93.083992, 8.29809284], [93.08406067, 8.29843903], [93.083992, 8.29885578], [93.083992, 8.29913044], [93.08406067, 8.29989529], [93.08406067, 8.30044937], [93.08441162, 8.30079556], [93.0848999, 8.30121326], [93.08503723, 8.30211067], [93.08483124, 8.30245876], [93.0848999, 8.30273819], [93.0848999, 8.30301571], [93.08454895, 8.30336189], [93.08448029, 8.30363846], [93.08448029, 8.30412292], [93.08476257, 8.30467701], [93.0848999, 8.305233], [93.08461761, 8.30537224], [93.08472443, 8.30583286], [93.08499908, 8.30611134], [93.08499908, 8.30667114], [93.08528137, 8.30786991], [93.08563232, 8.30821419], [93.08583069, 8.30888939], [93.08609772, 8.30994034], [93.08708191, 8.31146717], [93.08735657, 8.31243801], [93.08784485, 8.31292343], [93.08853912, 8.31354523], [93.08874512, 8.31403065], [93.08895874, 8.31507206], [93.08972168, 8.31583309], [93.08999634, 8.31611156], [93.08999634, 8.31694317], [93.09027863, 8.31722355], [93.09027863, 8.31749916], [93.09083557, 8.31805611], [93.0908432, 8.31832886], [93.09166718, 8.31917], [93.09166718, 8.31999969], [93.09194183, 8.32027817], [93.09194183, 8.32083416], [93.09223175, 8.32110977], [93.09222412, 8.32139015], [93.09249878, 8.32166576], [93.09249878, 8.32194233], [93.09361267, 8.32306099], [93.09361267, 8.32361221], [93.09388733, 8.32388783], [93.09388733, 8.32444382], [93.09416962, 8.32472229], [93.09416962, 8.32527828], [93.09471893, 8.32583046], [93.09471893, 8.3288908], [93.09443665, 8.32917118], [93.09443665, 8.33000088], [93.09416962, 8.33027554], [93.09416962, 8.33166695], [93.09375763, 8.3330431], [93.09375763, 8.3338747], [93.09388733, 8.334445], [93.09388733, 8.3358326], [93.09416962, 8.33611107], [93.09416962, 8.33722115], [93.09444427, 8.33749866], [93.09444427, 8.33805466], [93.09471893, 8.33833313], [93.09471893, 8.33916664], [93.09500122, 8.33944511], [93.09500122, 8.33972263], [93.09527588, 8.3399992], [93.09527588, 8.34027672], [93.09564972, 8.34028625], [93.09604645, 8.34029293], [93.09660339, 8.34029293], [93.09689331, 8.3405714], [93.09736633, 8.34085178], [93.09771729, 8.34105682], [93.09819794, 8.34112453], [93.0991745, 8.34140301], [93.09938049, 8.34154224], [93.09945679, 8.34195709], [93.09993744, 8.34195709], [93.10021973, 8.34216404], [93.10049438, 8.34251308], [93.10083008, 8.34333324], [93.10083008, 8.34360886], [93.10109711, 8.34389019], [93.10111237, 8.34500027], [93.10083008, 8.34527779], [93.10250092, 8.34694576], [93.10277557, 8.34666634], [93.10388947, 8.34666634], [93.10472107, 8.34749985], [93.10472107, 8.34777832], [93.10500336, 8.34805584], [93.10500336, 8.34944153], [93.10582733, 8.35028267], [93.10666656, 8.35028267], [93.10694122, 8.35000038], [93.10736084, 8.3495903], [93.10861206, 8.34897041], [93.11026764, 8.34832859], [93.11055756, 8.34805584], [93.11055756, 8.34777832], [93.11083221, 8.34749985], [93.11166382, 8.34749985], [93.11194611, 8.34721947], [93.11277771, 8.34721947], [93.11360931, 8.34805965], [93.11416626, 8.34805584], [93.11472321, 8.34861183], [93.11499786, 8.34861183], [93.11528015, 8.3488903], [93.11528015, 8.34916592], [93.11444092, 8.35000038], [93.11444092, 8.3502779], [93.11499786, 8.35083199], [93.11528015, 8.35083199], [93.11604309, 8.35007095], [93.1166687, 8.34965611], [93.11743927, 8.34947109], [93.11764526, 8.34940147], [93.11791992, 8.34919262], [93.11813354, 8.34919262], [93.11847687, 8.34933186], [93.11902618, 8.34932995], [93.1193161, 8.34961033], [93.11965942, 8.34988594], [93.11987305, 8.35009098], [93.12000275, 8.35056114], [93.12050629, 8.35105991], [93.1210022, 8.35112095], [93.12149048, 8.35111713], [93.12197876, 8.35139275], [93.12197876, 8.35174084], [93.12176514, 8.35188007], [93.12190247, 8.35215569], [93.12218475, 8.35243416], [93.12239075, 8.35250473], [93.12260437, 8.35271168], [93.12281036, 8.3527813], [93.12281036, 8.35306072], [93.12287903, 8.35319805], [93.12315369, 8.353405], [93.12329865, 8.35368061], [93.12364197, 8.35368061], [93.12399292, 8.35381985], [93.12419891, 8.3540287], [93.12419891, 8.35437584], [93.1244812, 8.35458279], [93.12481689, 8.35451031], [93.12545013, 8.35529709], [93.12545013, 8.35564327], [93.12611389, 8.35582066], [93.12627411, 8.35586357], [93.12676239, 8.35565662], [93.12787628, 8.35566139], [93.12835693, 8.35531044], [93.12885284, 8.35489082], [93.12884521, 8.35447788], [93.12863922, 8.35406113], [93.12863922, 8.35288334], [93.12891388, 8.35212231], [93.12926483, 8.3517046], [93.12975311, 8.35156631], [93.1305542, 8.35083199], [93.13083649, 8.35055637], [93.13083649, 8.3502779], [93.13111115, 8.35000038], [93.13111115, 8.34916592], [93.13194275, 8.34832859], [93.13249969, 8.34832859], [93.13276672, 8.34861183], [93.13388824, 8.34861183], [93.13414764, 8.3488903], [93.13582611, 8.3488903], [93.1361084, 8.34861183], [93.13639069, 8.34861183], [93.13666534, 8.34833431], [93.13777924, 8.34833431], [93.13805389, 8.34805584], [93.13916779, 8.34805965], [93.13944244, 8.34779072], [93.14250183, 8.34779072], [93.14277649, 8.34727192], [93.14290619, 8.3470602], [93.14334106, 8.34671116], [93.1434021, 8.34650421], [93.14333344, 8.34555626], [93.14333344, 8.34444332], [93.14305878, 8.34416771], [93.14305878, 8.34111118], [93.14277649, 8.34083271], [93.14277649, 8.34055519], [93.14194489, 8.33972263], [93.14194489, 8.33944511], [93.14167023, 8.33916664], [93.14167023, 8.33888912], [93.14138794, 8.33860016], [93.14138794, 8.33833313], [93.14111328, 8.33805466], [93.14111328, 8.33749866], [93.14083099, 8.33722115], [93.14083099, 8.33638859], [93.14111328, 8.33611107], [93.14111328, 8.3358326], [93.14083099, 8.33555698], [93.14083099, 8.33500099], [93.14111328, 8.33472061], [93.14111328, 8.33388901], [93.14138794, 8.33361053], [93.14138794, 8.33055687], [93.14111328, 8.33027554], [93.14111328, 8.32943058], [93.14083099, 8.32916641], [93.14083099, 8.32888794], [93.14055634, 8.32861042], [93.14055634, 8.32805634], [93.14027405, 8.32777786], [93.14028168, 8.32750034], [93.13999939, 8.32722187], [93.13999939, 8.32666588], [93.13972473, 8.32639027], [93.13972473, 8.32610989], [93.13944244, 8.32583046], [93.13944244, 8.3255558], [93.13722229, 8.32333374], [93.13722229, 8.32305622], [93.13694763, 8.32277775], [93.13694763, 8.32250023], [93.13639069, 8.32194424], [93.13639069, 8.32166576], [93.1361084, 8.32139015], [93.1361084, 8.32110977], [93.13583374, 8.32083416], [93.13583374, 8.32055569], [93.13527679, 8.31999969], [93.13527679, 8.31971931], [93.13500214, 8.3194437], [93.13500214, 8.31916809], [93.13471985, 8.31888962], [93.13471985, 8.31860924], [93.1341629, 8.31805611], [93.1341629, 8.31777763], [93.13388824, 8.31748962], [93.13388824, 8.31694317], [93.1333313, 8.31639004], [93.1333313, 8.31555462], [93.13305664, 8.31528187], [93.13305664, 8.31442928], [93.13277435, 8.31416702], [93.13277435, 8.31333256], [93.13249969, 8.31305504], [93.13249969, 8.31249905], [93.13223267, 8.31222057], [93.1319809, 8.31135654], [93.13142395, 8.31024742], [93.13111115, 8.30977058], [93.1313858, 8.30921745], [93.1315918, 8.30914879], [93.13181305, 8.30810928], [93.13214874, 8.30755138], [93.13246918, 8.30698967], [93.13295746, 8.30669022], [93.13316345, 8.30620575], [93.13302612, 8.30585957], [93.13288879, 8.30558014], [93.13253784, 8.30498028], [93.13246918, 8.30414772], [93.13273621, 8.30332088], [93.13326263, 8.30244064], [93.13354492, 8.30230236], [93.13388824, 8.30166626], [93.13361359, 8.30138779], [93.13360596, 8.30111027], [93.13277435, 8.30027771], [93.13277435, 8.30000019], [93.13249969, 8.29972172], [93.13249969, 8.2994442], [93.13222504, 8.29916573], [93.13223267, 8.29833031], [93.13194275, 8.29805565], [93.13222504, 8.29777813], [93.13223267, 8.29722023], [93.13194275, 8.29694366], [93.13194275, 8.29666805], [93.13166809, 8.29638767], [93.13166809, 8.29583168], [93.1313858, 8.29555607], [93.1313858, 8.29500008], [93.13111115, 8.2947197], [93.13111115, 8.29416561], [93.13083649, 8.29389], [93.13083649, 8.2930603], [93.13054657, 8.29277992], [93.13083649, 8.29249954], [93.13083649, 8.29222202], [93.1305542, 8.29194355], [93.1305542, 8.29166794], [93.12999725, 8.29111195], [93.12999725, 8.29083443], [93.12944794, 8.29027653], [93.12944794, 8.28999901], [93.12889099, 8.28944111], [93.12889099, 8.28916836], [93.1286087, 8.28888988], [93.12737274, 8.28638935], [93.12695313, 8.28493118], [93.12638855, 8.28333282], [93.12638855, 8.28194523], [93.12611389, 8.28166676], [93.12611389, 8.28083324], [93.1258316, 8.28055477], [93.1258316, 8.27972317], [93.12611389, 8.27944469], [93.12611389, 8.27722263], [93.12638855, 8.27694511], [93.12638855, 8.27638817], [93.12666321, 8.2761097], [93.12666321, 8.27583218], [93.1269455, 8.27555656], [93.1269455, 8.27527905], [93.12805176, 8.27417088], [93.12805176, 8.27389145], [93.12832642, 8.27361012], [93.12832642, 8.27278137], [93.1286087, 8.27251244], [93.1286087, 8.27221966], [93.12889099, 8.27194405], [93.12889099, 8.27138805], [93.12944794, 8.27083206], [93.12944794, 8.27055645], [93.1297226, 8.27027798], [93.1297226, 8.27000046], [93.12999725, 8.26972198], [93.12999725, 8.26944447], [93.13027954, 8.26916599], [93.13027954, 8.26889038], [93.13054657, 8.26861191], [93.13054657, 8.26833153], [93.13083649, 8.26805592], [93.13083649, 8.2677784], [93.13140106, 8.26721859], [93.1313858, 8.26694584], [93.13194275, 8.26638985], [93.13194275, 8.26611233], [93.13249969, 8.26555634], [93.13249969, 8.26527786], [93.1333313, 8.26444054], [93.1333313, 8.26416779], [93.13583374, 8.26166534], [93.13582611, 8.26139164], [93.13667297, 8.26057053], [93.13667297, 8.26027966], [93.13804626, 8.2588892], [93.13833618, 8.2588892], [93.14138794, 8.2558279], [93.14167023, 8.25583267], [93.14250183, 8.25500107], [93.14345551, 8.25437737], [93.14428711, 8.25312996], [93.14483643, 8.25284004], [93.14498901, 8.2525053], [93.145401, 8.25174236], [93.14568329, 8.25153446], [93.14624023, 8.25125599], [93.14679718, 8.25098133], [93.14805603, 8.25000095], [93.14805603, 8.24971962], [93.14833069, 8.24944496], [93.14833069, 8.24916553], [93.14888763, 8.24860954], [93.14888763, 8.24833202], [93.14944458, 8.24777794], [93.14971924, 8.2477808], [93.15222168, 8.24528122], [93.15222168, 8.24499989], [93.1533432, 8.24389267], [93.15361023, 8.24389267], [93.15429688, 8.24304008], [93.15479279, 8.2427597], [93.15541077, 8.24234009], [93.15569305, 8.24206734], [93.15625, 8.24186039], [93.15625, 8.24172115], [93.15660095, 8.24144173], [93.1571579, 8.24137402], [93.15743256, 8.24116421], [93.15834045, 8.24095726], [93.15910339, 8.24089146], [93.15994263, 8.24061966], [93.16079712, 8.24038029], [93.16127777, 8.23988628], [93.16149139, 8.23967838], [93.16190338, 8.23968124], [93.16239166, 8.23939991], [93.16266632, 8.23939991], [93.16368103, 8.23896027], [93.16500092, 8.23806], [93.1652832, 8.23806], [93.16583252, 8.23750019], [93.16638947, 8.23750019], [93.16666412, 8.23722363], [93.16694641, 8.23722363], [93.16722107, 8.23694324], [93.16750336, 8.23694324], [93.16806793, 8.2367363], [93.16869354, 8.23652935], [93.16903687, 8.23645973], [93.16945648, 8.2364006], [93.16973114, 8.23611164], [93.17008209, 8.23590374], [93.17077637, 8.23562622], [93.17105865, 8.23507214], [93.17175293, 8.23486519], [93.17224121, 8.23458672], [93.17251587, 8.23466015], [93.17307281, 8.23438168], [93.17334747, 8.2343111], [93.17369843, 8.23423958], [93.17404938, 8.23389435], [93.17501831, 8.23341084], [93.17536926, 8.23306179], [93.17543793, 8.23285484], [93.17564392, 8.23264694], [93.17649841, 8.23221874], [93.17677307, 8.23180199], [93.17684174, 8.23131943], [93.17749786, 8.23111057], [93.17778015, 8.23111057], [93.1783371, 8.23055458], [93.17871857, 8.23016834], [93.17913818, 8.22989178], [93.17942047, 8.22996044], [93.18027496, 8.22972298], [93.18055725, 8.22972298], [93.18083191, 8.22944546], [93.1811142, 8.22944546], [93.18166351, 8.22888947], [93.1819458, 8.22889137], [93.18222046, 8.22861099], [93.18250275, 8.22861099], [93.1827774, 8.22833347], [93.18305206, 8.22833347], [93.18333435, 8.228055], [93.18416595, 8.22806168], [93.18444824, 8.2277813], [93.18596649, 8.22771072], [93.18631744, 8.22737122], [93.18666077, 8.22714996], [93.18721771, 8.22715473], [93.18763733, 8.22687721], [93.18791962, 8.22688103], [93.18902588, 8.22679043], [93.18972015, 8.22667122], [93.1902771, 8.22667122], [93.19055176, 8.22639084], [93.19082642, 8.22639084], [93.1911087, 8.22611141], [93.19166565, 8.22611141], [93.19194794, 8.22583294], [93.1922226, 8.22583294], [93.19249725, 8.22555542], [93.19348145, 8.22519684], [93.1937561, 8.2249918], [93.19431305, 8.2249918], [93.19465637, 8.22457027], [93.19499969, 8.22416687], [93.19555664, 8.22361088], [93.19555664, 8.22333241], [93.19638824, 8.2225008], [93.19638824, 8.22194386], [93.1966629, 8.22166634], [93.1966629, 8.22138786], [93.19695282, 8.22111034], [93.19694519, 8.22083473], [93.19805908, 8.21972179], [93.19833374, 8.21972179], [93.19889069, 8.2191658], [93.19917297, 8.21917057], [93.19972229, 8.21861172], [93.20027924, 8.21861172], [93.20054626, 8.21833038], [93.2013855, 8.2183342], [93.20166779, 8.21805573], [93.2022171, 8.21806145], [93.20471954, 8.21556091], [93.20471954, 8.21500015], [93.20500183, 8.21472168], [93.20500183, 8.21389008], [93.20555878, 8.21333408], [93.20555878, 8.21305561], [93.20500183, 8.21249962], [93.20527649, 8.21223068], [93.20527649, 8.21138954], [93.20471954, 8.21083069], [93.20471954, 8.21027756], [93.20444489, 8.21000004], [93.20443726, 8.20944118], [93.20417023, 8.20916843], [93.20417023, 8.20888996], [93.20388794, 8.20861244], [93.20417023, 8.20833302], [93.20417023, 8.20777702], [93.20388794, 8.20750237], [93.20388794, 8.20583344], [93.20417023, 8.20555496], [93.20417023, 8.20472336], [93.20388794, 8.20444489], [93.20388794, 8.2033329], [93.20361328, 8.20305538], [93.20361328, 8.20166683], [93.20333099, 8.20139122], [93.20333099, 8.20083141], [93.20305634, 8.20055485], [93.20305634, 8.19972324], [93.20277405, 8.19944477], [93.20277405, 8.19888878], [93.20249939, 8.19861126], [93.20249939, 8.19805527], [93.20222473, 8.1977787], [93.2022171, 8.19694042], [93.20194244, 8.19666672], [93.20194244, 8.1963892], [93.19944763, 8.19389057], [93.19916534, 8.19388771], [93.19876862, 8.19428539], [93.1986084, 8.1944437], [93.19833374, 8.19416618], [93.19694519, 8.19416618], [93.1966629, 8.19388771], [93.19638824, 8.19389057], [93.19555664, 8.19306087], [93.19527435, 8.1930542], [93.19499969, 8.19333363], [93.19472504, 8.19333363], [93.19444275, 8.19361019], [93.19333649, 8.19361019], [93.19304657, 8.19389057], [93.1911087, 8.19389057], [93.19082642, 8.19361019], [93.1902771, 8.19361019], [93.1894455, 8.19277763], [93.18916321, 8.19278145], [93.18888855, 8.19306087], [93.18860626, 8.19278145], [93.18831635, 8.19278145], [93.18805695, 8.19250011]]], [[[93.65249634, 8.39444542], [93.65305328, 8.39388943], [93.65305328, 8.39361095], [93.65333557, 8.39333344], [93.65333557, 8.39305496], [93.65361023, 8.39277744], [93.65361023, 8.39250088], [93.65471649, 8.39194107], [93.65528107, 8.39194489], [93.65583038, 8.39138889], [93.65638733, 8.39138889], [93.65666962, 8.39111137], [93.65694427, 8.39111137], [93.65721893, 8.3908329], [93.65694427, 8.39055538], [93.65694427, 8.3900013], [93.65638733, 8.38943958], [93.65528107, 8.3894453], [93.65499878, 8.38916683], [93.65471649, 8.38917065], [93.65374756, 8.38819122], [93.65333557, 8.38777733], [93.65305328, 8.38778114], [93.65277863, 8.38806152], [93.65249634, 8.38805485], [93.65194702, 8.38861084], [93.6516571, 8.38861084], [93.65139008, 8.38888931], [93.65139008, 8.38916683], [93.65110779, 8.3894453], [93.65110779, 8.38970947], [93.65055847, 8.39028072], [93.65000153, 8.39028072], [93.64971924, 8.3900013], [93.64916992, 8.3900013], [93.64888763, 8.38972092], [93.64861298, 8.38972092], [93.64833069, 8.3894453], [93.64742279, 8.38970947], [93.64707947, 8.38992977], [93.6470108, 8.39041996], [93.64680481, 8.3908987], [93.64638519, 8.39117718], [93.64624786, 8.39152145], [93.6461792, 8.39194107], [93.64604187, 8.39207745], [93.64575958, 8.39256287], [93.64533997, 8.39277267], [93.64444733, 8.39277935], [93.64402771, 8.39284992], [93.64367676, 8.39340401], [93.64367676, 8.39388943], [93.64395905, 8.39430618], [93.6442337, 8.39438438], [93.64444733, 8.39444542], [93.64499664, 8.39444542], [93.64527893, 8.39472103], [93.64583588, 8.39472103], [93.64611053, 8.39444542], [93.64638519, 8.39444542], [93.64666748, 8.39416695], [93.64805603, 8.39416695], [93.64833069, 8.39444542], [93.64888763, 8.39444542], [93.64916992, 8.39416695], [93.65055847, 8.39416695], [93.65080261, 8.39465141], [93.65171814, 8.39472103], [93.65249634, 8.39444542]]], [[[93.2352829, 8.26556015], [93.23583221, 8.26500034], [93.23638916, 8.26500034], [93.23750305, 8.26389027], [93.23750305, 8.26361179], [93.23805237, 8.2630558], [93.23805237, 8.26249886], [93.23944092, 8.26111126], [93.23944092, 8.26055527], [93.23972321, 8.26027679], [93.23972321, 8.25999928], [93.23999786, 8.2597208], [93.23999786, 8.25944519], [93.24028015, 8.25916672], [93.24028015, 8.2588892], [93.24054718, 8.25861073], [93.24054718, 8.25751019], [93.2408371, 8.25722122], [93.2408371, 8.25694466], [93.24111176, 8.25666714], [93.24111176, 8.25638866], [93.24138641, 8.25611115], [93.24138641, 8.25583267], [93.2416687, 8.25555515], [93.2416687, 8.25500107], [93.24194336, 8.25472069], [93.24194336, 8.25444508], [93.24277496, 8.25361061], [93.24277496, 8.25277901], [93.24305725, 8.25249863], [93.24305725, 8.25222015], [93.24333191, 8.25194454], [93.24333191, 8.25166702], [93.24416351, 8.2508316], [93.24416351, 8.25027561], [93.2444458, 8.25000095], [93.2444458, 8.24971962], [93.24583435, 8.24833202], [93.24583435, 8.24805737], [93.2463913, 8.24750042], [93.2463913, 8.24694443], [93.24666595, 8.24666595], [93.24666595, 8.24583435], [93.24694824, 8.24555588], [93.24694824, 8.24472237], [93.2472229, 8.24444389], [93.2472229, 8.24416637], [93.2480545, 8.24333191], [93.2480545, 8.24277782], [93.24833679, 8.24250031], [93.24833679, 8.24222183], [93.24944305, 8.24110985], [93.24965668, 8.24061108], [93.24942017, 8.23978329], [93.24942017, 8.2392292], [93.24977112, 8.23867607], [93.24957275, 8.23812199], [93.24928284, 8.23784065], [93.24900818, 8.23756599], [93.24907684, 8.23728848], [93.2493515, 8.23707962], [93.25, 8.23659229], [93.25055695, 8.23583412], [93.25111389, 8.23527718], [93.25111389, 8.23472118], [93.25138855, 8.23444557], [93.25138855, 8.23388863], [93.25170898, 8.23343372], [93.25156403, 8.23308659], [93.25093842, 8.2329483], [93.25060272, 8.23295021], [93.25060272, 8.23259926], [93.2508316, 8.23222256], [93.2508316, 8.23138905], [93.25111389, 8.23111057], [93.25111389, 8.23083305], [93.25138855, 8.23055458], [93.25138855, 8.22972298], [93.25166321, 8.22944546], [93.25166321, 8.22916698], [93.2519455, 8.22888947], [93.25166321, 8.22861099], [93.25166321, 8.228055], [93.25138855, 8.2277813], [93.25138855, 8.22694016], [93.2508316, 8.22638893], [93.25056458, 8.22583008], [93.25028229, 8.22533989], [93.24993896, 8.22534466], [93.24965668, 8.22555161], [93.24924469, 8.22555161], [93.24909973, 8.22520638], [93.24909973, 8.22451305], [93.24882507, 8.22416687], [93.24840546, 8.22402763], [93.24819946, 8.22402763], [93.24798584, 8.22444153], [93.24771118, 8.22458076], [93.24743652, 8.22416687], [93.24749756, 8.22388935], [93.24694824, 8.22389126], [93.24666595, 8.22361088], [93.2463913, 8.22361088], [93.24610901, 8.22333241], [93.24583435, 8.22333241], [93.24555206, 8.22305679], [93.24500275, 8.22306061], [93.24472046, 8.22278118], [93.24305725, 8.22278118], [93.24276733, 8.2225008], [93.24250031, 8.2225008], [93.24222565, 8.22277641], [93.24180603, 8.22299671], [93.2416687, 8.22327328], [93.24124908, 8.22327328], [93.24091339, 8.22340965], [93.24061584, 8.2237606], [93.24021149, 8.2237606], [93.23996735, 8.22362041], [93.23972321, 8.22348309], [93.23944092, 8.22292709], [93.23958588, 8.22244072], [93.23999786, 8.22188663], [93.23999786, 8.22138786], [93.23944092, 8.22082996], [93.2388916, 8.22083473], [93.23750305, 8.22222328], [93.23722076, 8.22222328], [93.23694611, 8.2225008], [93.23666382, 8.2225008], [93.23583221, 8.22333241], [93.23555756, 8.22333241], [93.23527527, 8.22361088], [93.23500061, 8.22361088], [93.23416901, 8.22444534], [93.23472595, 8.22500134], [93.23472595, 8.22555542], [93.23416901, 8.22611141], [93.23416901, 8.22638893], [93.2335968, 8.22694016], [93.23361206, 8.22750092], [93.23332977, 8.22777653], [93.23332977, 8.22833347], [93.23348236, 8.22945023], [93.23348236, 8.22993469], [93.23306274, 8.23034954], [93.23257446, 8.23083782], [93.23208618, 8.23139095], [93.23152924, 8.23173809], [93.23125458, 8.23208427], [93.23069763, 8.23215485], [93.23027802, 8.23236179], [93.23018646, 8.2324543], [93.23000336, 8.23264027], [93.22944641, 8.23250103], [93.22915649, 8.23250103], [93.22860718, 8.23306179], [93.22833252, 8.23306179], [93.22611237, 8.23528194], [93.22583008, 8.23528194], [93.22472382, 8.23639011], [93.22472382, 8.23666763], [93.22444153, 8.23694324], [93.22444153, 8.23722363], [93.22368622, 8.2382679], [93.22368622, 8.23875141], [93.2234726, 8.23938179], [93.22312927, 8.2399292], [93.22291565, 8.24041462], [93.22244263, 8.24075031], [93.22222137, 8.2413168], [93.22138977, 8.24166584], [93.22138977, 8.24222183], [93.22129822, 8.24263], [93.22123718, 8.24312019], [93.2208786, 8.24368095], [93.22052765, 8.24444199], [93.22012329, 8.24506187], [93.22012329, 8.24617195], [93.2199707, 8.24713802], [93.21990204, 8.24790192], [93.21990204, 8.2488699], [93.220047, 8.24943066], [93.22052765, 8.25032711], [93.22052765, 8.25095081], [93.22067261, 8.25171471], [93.22083282, 8.25277901], [93.22083282, 8.25361061], [93.22110748, 8.25388908], [93.22110748, 8.25444508], [93.22138977, 8.25472069], [93.22138977, 8.25500107], [93.22166443, 8.25527668], [93.2216568, 8.25694084], [93.22257233, 8.25766468], [93.22298431, 8.25849724], [93.22375488, 8.25905132], [93.22424316, 8.25953674], [93.22507477, 8.25988293], [93.22556305, 8.2601614], [93.22618866, 8.26050663], [93.22653198, 8.26113224], [93.22737122, 8.26147842], [93.22812653, 8.26181984], [93.22944641, 8.26244926], [93.23084259, 8.26334953], [93.23202515, 8.26348877], [93.23286438, 8.26376438], [93.23369598, 8.2640419], [93.23460388, 8.26444626], [93.23480988, 8.26472187], [93.23474121, 8.26514053], [93.23500061, 8.26556015], [93.2352829, 8.26556015]]], [[[93.04389191, 8.47333336], [93.04389191, 8.47305489], [93.04418182, 8.47305965], [93.04556274, 8.4716692], [93.04556274, 8.47139072], [93.04833221, 8.4686079], [93.0486145, 8.46861076], [93.04888916, 8.46833324], [93.04964447, 8.46769905], [93.05096436, 8.46679878], [93.05214691, 8.46576023], [93.05354309, 8.46437168], [93.05472565, 8.46333218], [93.05583191, 8.4622221], [93.05583191, 8.46194363], [93.0561142, 8.46166611], [93.0561142, 8.46138763], [93.05638885, 8.46111012], [93.05638885, 8.46083355], [93.05666351, 8.46055603], [93.05666351, 8.46027756], [93.0569458, 8.46000004], [93.0569458, 8.45944023], [93.05722046, 8.45916557], [93.05722046, 8.45805645], [93.05750275, 8.45778275], [93.05750275, 8.45583153], [93.0569458, 8.4552784], [93.0569458, 8.4547224], [93.05666351, 8.45444584], [93.05666351, 8.45361233], [93.05638885, 8.45333385], [93.05638885, 8.44999886], [93.05666351, 8.44972134], [93.05666351, 8.44888878], [93.05638885, 8.44861126], [93.05638885, 8.44805527], [93.05666351, 8.44777679], [93.05665588, 8.44749928], [93.0577774, 8.4463892], [93.05860901, 8.4463892], [93.0588913, 8.44611073], [93.0588913, 8.44583321], [93.0597229, 8.44499874], [93.0597229, 8.44444466], [93.05999756, 8.44416714], [93.05999756, 8.44388866], [93.06083679, 8.44306183], [93.06054688, 8.44278145], [93.06054688, 8.44250107], [93.0597229, 8.44167137], [93.0597229, 8.44139099], [93.05944824, 8.44111061], [93.05750275, 8.43916702], [93.05722046, 8.43916702], [93.0569458, 8.43944454], [93.05388641, 8.43944454], [93.05361176, 8.43916702], [93.0533371, 8.43917084], [93.05304718, 8.43889141], [93.05278015, 8.43889141], [93.05249786, 8.43861008], [93.05194092, 8.43861008], [93.05166626, 8.4383316], [93.0513916, 8.4383316], [93.05110931, 8.43861008], [93.05027771, 8.43861008], [93.04998779, 8.43889141], [93.04972076, 8.43889141], [93.04944611, 8.43917084], [93.04916382, 8.43916702], [93.04888916, 8.43944454], [93.04805756, 8.43944454], [93.04777527, 8.43972301], [93.04695129, 8.43972015], [93.04666901, 8.44000053], [93.04611206, 8.44000053], [93.04582977, 8.44028091], [93.04418182, 8.44028091], [93.04389191, 8.44056129], [93.04305267, 8.44055462], [93.04277802, 8.44083309], [93.04250336, 8.44083309], [93.04138947, 8.44194508], [93.04110718, 8.44194031], [93.04000092, 8.44306183], [93.03971863, 8.44306183], [93.03778076, 8.44499874], [93.03778076, 8.44555473], [93.03749847, 8.44583321], [93.03749847, 8.44611073], [93.03694153, 8.44666672], [93.03694153, 8.44694519], [93.03527832, 8.44861126], [93.03527832, 8.44944477], [93.03500366, 8.44972134], [93.03500366, 8.44999886], [93.03472137, 8.45027733], [93.03472137, 8.45083332], [93.03444672, 8.45111179], [93.03444672, 8.45277786], [93.03472137, 8.45305634], [93.03472137, 8.45555592], [93.03501129, 8.45583153], [93.03501129, 8.45612144], [93.03527832, 8.45638847], [93.03527832, 8.4566679], [93.03555298, 8.45694447], [93.03555298, 8.45722198], [93.03527832, 8.45750046], [93.03527832, 8.45805645], [93.03555298, 8.45833015], [93.03555298, 8.45888996], [93.0358429, 8.45918179], [93.0358429, 8.46000004], [93.03610992, 8.46027756], [93.03610992, 8.46055603], [93.03639221, 8.46083355], [93.03639221, 8.46111012], [93.03666687, 8.46138763], [93.03666687, 8.46194363], [93.03694153, 8.46222019], [93.03694153, 8.46249962], [93.03722382, 8.46277809], [93.03722382, 8.46333218], [93.03749847, 8.4636097], [93.03749847, 8.46416569], [93.03778076, 8.46444416], [93.03778076, 8.46472263], [93.03805542, 8.46500111], [93.03805542, 8.46555424], [93.03833008, 8.46583462], [93.03833008, 8.46611118], [93.03888702, 8.46666718], [93.03888702, 8.46694469], [93.03916931, 8.46722031], [93.03916931, 8.46777916], [93.03944397, 8.46805477], [93.03944397, 8.46833324], [93.03971863, 8.4686079], [93.03971863, 8.46888924], [93.04000092, 8.46916676], [93.04000092, 8.46944523], [93.04055786, 8.47000122], [93.04055786, 8.47028065], [93.04166412, 8.47138882], [93.04166412, 8.47166729], [93.04222107, 8.47222328], [93.04222107, 8.47249889], [93.04332733, 8.47361088], [93.04360962, 8.47361088], [93.04389191, 8.47333336]]], [[[93.61187744, 8.48454189], [93.61147308, 8.48447132], [93.61083221, 8.48499966], [93.61083221, 8.48527813], [93.6111145, 8.48555565], [93.6111145, 8.48583412], [93.61154175, 8.48605537], [93.61194611, 8.48633099], [93.61257935, 8.48641109], [93.61308289, 8.48633766], [93.61348724, 8.48605537], [93.61369324, 8.48556995], [93.61360931, 8.48527813], [93.61305237, 8.48499966], [93.61250305, 8.4847517], [93.61187744, 8.48454189]]], [[[93.61599731, 8.57362556], [93.61711121, 8.57244968], [93.61794281, 8.57113075], [93.61801147, 8.56946659], [93.61749268, 8.56799889], [93.61804962, 8.56735039], [93.61868286, 8.56735039], [93.61915588, 8.56728077], [93.61936951, 8.56672096], [93.61972046, 8.56589317], [93.6202774, 8.56485176], [93.62034607, 8.56409073], [93.6204834, 8.56311989], [93.62055206, 8.56215096], [93.6202774, 8.5616703], [93.62055206, 8.55944061], [93.62055206, 8.55888653], [93.62020874, 8.55708218], [93.62000275, 8.55583286], [93.61981201, 8.55557346], [93.61951447, 8.55533218], [93.61925507, 8.55506706], [93.61901855, 8.55472565], [93.61881256, 8.55436325], [93.61862946, 8.55397606], [93.61850739, 8.55352211], [93.61837006, 8.55305481], [93.61820984, 8.55197906], [93.61842346, 8.55177212], [93.61876678, 8.55135727], [93.61890411, 8.55093956], [93.61911774, 8.55066013], [93.61911774, 8.55017567], [93.6191864, 8.54983234], [93.61946106, 8.54927635], [93.62007141, 8.54913044], [93.62037659, 8.54866123], [93.62033081, 8.54817963], [93.62005615, 8.54775143], [93.61976624, 8.54735947], [93.61952209, 8.54701996], [93.61934662, 8.54672432], [93.61871338, 8.54630947], [93.61857605, 8.54610062], [93.61863708, 8.54574966], [93.61899567, 8.54554844], [93.61948395, 8.54547691], [93.61988831, 8.54521942], [93.62003326, 8.54474545], [93.61988831, 8.54426193], [93.61968231, 8.54377747], [93.61981964, 8.54314995], [93.61928558, 8.54278278], [93.61956787, 8.54250526], [93.61991119, 8.54236603], [93.6207962, 8.54247093], [93.62120819, 8.54190063], [93.62149048, 8.54114246], [93.62160492, 8.54038525], [93.62152863, 8.53964233], [93.621315, 8.53936672], [93.62117767, 8.53908825], [93.62117767, 8.5388813], [93.6213913, 8.53874207], [93.62194824, 8.5377779], [93.6222229, 8.53750038], [93.6222229, 8.53666592], [93.62194061, 8.5363903], [93.62194061, 8.53528023], [93.6222229, 8.53499985], [93.6222229, 8.53472233], [93.6230545, 8.53388977], [93.6230545, 8.53333378], [93.62333679, 8.53305626], [93.62277985, 8.53249931], [93.62249756, 8.53249931], [93.6222229, 8.53222084], [93.6222229, 8.53194332], [93.62194824, 8.53166771], [93.6222229, 8.53139019], [93.6222229, 8.53110886], [93.62249756, 8.53083324], [93.62249756, 8.53055477], [93.6230545, 8.52999878], [93.62304687, 8.52944088], [93.62333679, 8.52916527], [93.62388611, 8.52917194], [93.62473297, 8.5283308], [93.625, 8.52833271], [93.62611389, 8.52722263], [93.62638855, 8.52722263], [93.62666321, 8.52694511], [93.6269455, 8.52694511], [93.62722015, 8.52666664], [93.62889099, 8.52666855], [93.62917328, 8.52639103], [93.62944794, 8.52639103], [93.6297226, 8.52611065], [93.63027954, 8.52611065], [93.6305542, 8.52583313], [93.63111115, 8.52583313], [93.63166809, 8.52527905], [93.63166809, 8.52499866], [93.63194275, 8.52472305], [93.63194275, 8.52416706], [93.6322937, 8.52378178], [93.63285065, 8.52378178], [93.63326263, 8.52413273], [93.63381958, 8.52412796], [93.63471985, 8.52444458], [93.63527679, 8.52388859], [93.63527679, 8.52361107], [93.63555908, 8.5233326], [93.63555908, 8.52305698], [93.63583374, 8.5227766], [93.63582611, 8.52250099], [93.6361084, 8.52223015], [93.6361084, 8.52194023], [93.63527679, 8.52111053], [93.63500214, 8.52111053], [93.63382721, 8.51992798], [93.63347626, 8.5194416], [93.63340759, 8.51861], [93.63334656, 8.51816368], [93.63334656, 8.51760769], [93.63349152, 8.51739788], [93.63382721, 8.51684189], [93.63418579, 8.51670456], [93.63460541, 8.51663685], [93.63466644, 8.51643181], [93.63453674, 8.51594162], [93.63488007, 8.51546097], [93.63529205, 8.51476765], [93.63571167, 8.51442146], [93.63626862, 8.51400375], [93.6367569, 8.51338005], [93.63749695, 8.51222229], [93.63749695, 8.51194382], [93.63726807, 8.51054001], [93.63699341, 8.50991631], [93.63668823, 8.50976086], [93.63642883, 8.50950527], [93.63608551, 8.5092411], [93.63568878, 8.50898647], [93.63521576, 8.50890064], [93.63478851, 8.50888824], [93.6344223, 8.50887394], [93.63407135, 8.50881195], [93.63365173, 8.50863457], [93.63331604, 8.50830936], [93.63311005, 8.50796032], [93.6325531, 8.50692272], [93.63227844, 8.50643826], [93.63185883, 8.50595188], [93.63192749, 8.50525856], [93.63234711, 8.50470543], [93.63289642, 8.5040102], [93.6333847, 8.5033884], [93.63394165, 8.50262737], [93.63471222, 8.50179005], [93.63494873, 8.5009861], [93.63536072, 8.50029278], [93.63598633, 8.49918461], [93.6367569, 8.49786758], [93.63698578, 8.4971571], [93.63765717, 8.49200153], [93.63786316, 8.49075699], [93.63751984, 8.48978615], [93.63765717, 8.48886967], [93.63779449, 8.48742962], [93.63835144, 8.48590469], [93.63897705, 8.484519], [93.63939667, 8.48368454], [93.63947296, 8.48265266], [93.63947296, 8.48176956], [93.63905334, 8.4813509], [93.63883209, 8.48073101], [93.63857269, 8.48031044], [93.63912201, 8.47989464], [93.63925934, 8.47947979], [93.63973999, 8.47890282], [93.64029694, 8.47779274], [93.64089203, 8.47547817], [93.64109802, 8.47464561], [93.64109802, 8.47375011], [93.64138031, 8.47276974], [93.64138031, 8.47220707], [93.64121246, 8.47106075], [93.64142609, 8.47085285], [93.64142609, 8.47029972], [93.64183807, 8.47009182], [93.64183807, 8.46939945], [93.64234161, 8.4688406], [93.64242554, 8.46853638], [93.64242554, 8.4674263], [93.64205933, 8.46677399], [93.64212799, 8.46642685], [93.64177704, 8.46587372], [93.64150238, 8.46546078], [93.64122009, 8.46497059], [93.64128876, 8.46455574], [93.64027405, 8.46472263], [93.63972473, 8.46472263], [93.63944244, 8.46500111], [93.6388855, 8.46500111], [93.63805389, 8.46583462], [93.63804626, 8.46611118], [93.63777924, 8.4663887], [93.63777924, 8.46666718], [93.63749695, 8.46693993], [93.63749695, 8.46777916], [93.63722229, 8.46805477], [93.63722229, 8.46833324], [93.63583374, 8.46972084], [93.63555908, 8.46972084], [93.63527679, 8.46944523], [93.63500214, 8.46972084], [93.63471985, 8.46972084], [93.63388062, 8.47056198], [93.6333313, 8.47056198], [93.63305664, 8.47028065], [93.63276672, 8.47028065], [93.63249969, 8.47000122], [93.63111115, 8.47000122], [93.63083649, 8.46972084], [93.63027954, 8.46972084], [93.62999725, 8.46944523], [93.6297226, 8.46944523], [93.62944794, 8.46916676], [93.62917328, 8.46917057], [93.62867737, 8.46867943], [93.62805176, 8.46806145], [93.62750244, 8.46806145], [93.62689972, 8.46745968], [93.62666321, 8.46722031], [93.62666321, 8.46500111], [93.62638855, 8.46472263], [93.62638855, 8.46444416], [93.62611389, 8.46416569], [93.62611389, 8.46333218], [93.6258316, 8.46305561], [93.6258316, 8.46277809], [93.62555695, 8.46249962], [93.62555695, 8.46082973], [93.62527466, 8.46055603], [93.62527466, 8.46000004], [93.6258316, 8.45944023], [93.62555695, 8.45916557], [93.62555695, 8.45805645], [93.62526703, 8.45778275], [93.62526703, 8.45750046], [93.62500763, 8.45722198], [93.62527466, 8.45694447], [93.62527466, 8.4566679], [93.62555695, 8.45638847], [93.62555695, 8.45583153], [93.625, 8.4552784], [93.625, 8.4547224], [93.62472534, 8.45444584], [93.62472534, 8.45333385], [93.62444305, 8.45305634], [93.62444305, 8.45277786], [93.62388611, 8.45222092], [93.62388611, 8.4519434], [93.62333679, 8.45139027], [93.62324524, 8.45025921], [93.6230545, 8.44944477], [93.62277985, 8.44916534], [93.62277985, 8.44888878], [93.62304687, 8.44861126], [93.6230545, 8.44777679], [93.62333679, 8.44749928], [93.62333679, 8.4472208], [93.6241684, 8.4463892], [93.62388611, 8.44611073], [93.6241684, 8.44583321], [93.6241684, 8.44555473], [93.62444305, 8.44527912], [93.62444305, 8.44500065], [93.62500763, 8.44444084], [93.625, 8.44416714], [93.6258316, 8.44333267], [93.62631989, 8.44269943], [93.62750244, 8.44152069], [93.62750244, 8.44055462], [93.62722015, 8.44028091], [93.62666321, 8.44028091], [93.62638855, 8.44000053], [93.62638855, 8.43964958], [93.62666321, 8.43958092], [93.62687683, 8.43958092], [93.62728882, 8.43935966], [93.62743378, 8.43916416], [93.62750244, 8.43847084], [93.6277771, 8.43777943], [93.6277771, 8.43694019], [93.62750244, 8.43666553], [93.62750244, 8.43638802], [93.62722778, 8.43472004], [93.62715912, 8.4330492], [93.62709045, 8.43222046], [93.62709045, 8.43118095], [93.62652588, 8.43064022], [93.62639618, 8.42978954], [93.62639618, 8.4289608], [93.6258316, 8.42805576], [93.62555695, 8.42805958], [93.62526703, 8.42778015], [93.62526703, 8.42694092], [93.625, 8.42666626], [93.625, 8.4258337], [93.62472534, 8.42555618], [93.62472534, 8.42416763], [93.62444305, 8.42389202], [93.62341309, 8.4226017], [93.62285614, 8.42162037], [93.62243652, 8.42162037], [93.62181091, 8.42218018], [93.6213913, 8.42328835], [93.6213913, 8.4243269], [93.62159729, 8.42481327], [93.62174225, 8.42550468], [93.62152863, 8.42675018], [93.62132263, 8.42759132], [93.62083435, 8.42862606], [93.62062836, 8.42924786], [93.62020874, 8.42980194], [93.61958313, 8.43064022], [93.61958313, 8.43153572], [93.6194458, 8.43236828], [93.6185379, 8.43278503], [93.61743164, 8.43333912], [93.61672974, 8.43410015], [93.61638641, 8.43486404], [93.61701202, 8.43534946], [93.61784363, 8.43583393], [93.61888885, 8.43611336], [93.6194458, 8.43610954], [93.61972046, 8.43639088], [93.62006378, 8.4366188], [93.62021637, 8.43690777], [93.62030792, 8.43730545], [93.62043762, 8.43777943], [93.6205368, 8.43831158], [93.62057495, 8.43885708], [93.62018585, 8.44023132], [93.61976624, 8.44092846], [93.61916351, 8.4416666], [93.61888885, 8.44194508], [93.61888885, 8.4422226], [93.61833191, 8.44222069], [93.61805725, 8.44250107], [93.61750031, 8.44250107], [93.61694336, 8.44305515], [93.61694336, 8.44333267], [93.61722565, 8.44361115], [93.61722565, 8.44388866], [93.61805725, 8.44472313], [93.61833191, 8.44472313], [93.61916351, 8.44555473], [93.61985779, 8.44653034], [93.62000275, 8.44805527], [93.61980438, 8.4491396], [93.61965942, 8.44983292], [93.61980438, 8.45066547], [93.62036133, 8.45142841], [93.62049866, 8.45198154], [93.62042999, 8.45253563], [93.6194458, 8.45333385], [93.6194458, 8.45361233], [93.6186142, 8.45444584], [93.61833191, 8.45444584], [93.61805725, 8.4547224], [93.61776733, 8.45471859], [93.61750031, 8.45499992], [93.61723328, 8.45499992], [93.61694336, 8.4552803], [93.6166687, 8.4552803], [93.61638641, 8.45555973], [93.61611176, 8.45555973], [93.61554718, 8.45612144], [93.61555481, 8.45638847], [93.6158371, 8.4566679], [93.6158371, 8.45694447], [93.61694336, 8.45694447], [93.61750031, 8.45638847], [93.61776733, 8.45639038], [93.61805725, 8.45612144], [93.61888123, 8.45612144], [93.61915588, 8.45639038], [93.6194458, 8.45638847], [93.6194458, 8.4566679], [93.62000275, 8.45722198], [93.61972046, 8.45750046], [93.61972046, 8.45888805], [93.6202774, 8.45944405], [93.62110901, 8.45944405], [93.62277985, 8.46111012], [93.62249756, 8.46138763], [93.62249756, 8.46166611], [93.6222229, 8.46194363], [93.62249756, 8.46222019], [93.62249756, 8.46249962], [93.62277985, 8.46277809], [93.62277985, 8.4636097], [93.62249756, 8.46388817], [93.62249756, 8.46416569], [93.6222229, 8.46444416], [93.6222229, 8.46472263], [93.62166595, 8.46527863], [93.62166595, 8.46611118], [93.62110901, 8.46667099], [93.62110901, 8.46750069], [93.6213913, 8.46777916], [93.6213913, 8.46833324], [93.62083435, 8.46888924], [93.6202774, 8.46944523], [93.62032318, 8.46976852], [93.62082672, 8.47028065], [93.62110901, 8.47028065], [93.6213913, 8.47056198], [93.6222229, 8.47055531], [93.62249756, 8.47083092], [93.62249756, 8.4711113], [93.62277985, 8.47138882], [93.62271881, 8.47195435], [93.62291718, 8.47215939], [93.62291718, 8.47236919], [93.62278748, 8.47236919], [93.62258911, 8.47257042], [93.62223816, 8.47257042], [93.62216949, 8.47284794], [93.62203217, 8.47326469], [93.62174988, 8.47326469], [93.62161255, 8.47298717], [93.62111664, 8.47292137], [93.62055206, 8.47305965], [93.61972046, 8.47305965], [93.61915588, 8.47361088], [93.61888885, 8.47361088], [93.6186142, 8.47388935], [93.61890411, 8.47478294], [93.61932373, 8.47533607], [93.61959839, 8.47561455], [93.61994934, 8.47575378], [93.62036133, 8.47589016], [93.62029266, 8.47637558], [93.61994934, 8.47679329], [93.61994934, 8.4776926], [93.61973572, 8.47790146], [93.6194458, 8.47778034], [93.6186142, 8.47861195], [93.61888885, 8.47937965], [93.6185379, 8.47986126], [93.61840057, 8.48041916], [93.61888885, 8.48069477], [93.61923218, 8.48090172], [93.6194458, 8.48139], [93.61972046, 8.48167038], [93.62000275, 8.48166561], [93.62000275, 8.48194408], [93.62249756, 8.48194408], [93.62277985, 8.4822216], [93.62304687, 8.4822216], [93.62333679, 8.48250198], [93.62361145, 8.48250198], [93.62388611, 8.4822216], [93.62444305, 8.4822216], [93.625, 8.4827776], [93.625, 8.48305607], [93.62555695, 8.48361015], [93.62555695, 8.48416996], [93.62666321, 8.48528004], [93.6269455, 8.48527813], [93.62713623, 8.48546982], [93.62722015, 8.48556137], [93.62750244, 8.48555565], [93.6277771, 8.48583031], [93.6277771, 8.48639011], [93.62805176, 8.48666573], [93.62805176, 8.48750019], [93.62833405, 8.48777771], [93.62833405, 8.48861027], [93.6277771, 8.48915863], [93.62779999, 8.48965931], [93.62766266, 8.48986626], [93.62752533, 8.49000454], [93.62696838, 8.49042034], [93.62696838, 8.4908371], [93.62675476, 8.49118328], [93.62641144, 8.49139118], [93.62627411, 8.49173737], [93.62619781, 8.49194527], [93.62592316, 8.49215412], [93.62571716, 8.49229145], [93.6256485, 8.49263954], [93.62571716, 8.49304962], [93.62584686, 8.49346924], [93.6256485, 8.49388599], [93.62536621, 8.49395466], [93.62529755, 8.49423313], [93.62522888, 8.49457932], [93.62509155, 8.49505997], [93.62509155, 8.49555016], [93.62502289, 8.49589729], [93.62480927, 8.49617481], [93.6247406, 8.49644089], [93.62467194, 8.4967308], [93.62404633, 8.49679661], [93.62425232, 8.49749184], [93.62425232, 8.49797535], [93.62453461, 8.49832153], [93.62487793, 8.49860001], [93.62522888, 8.49908543], [93.62516022, 8.49950027], [93.62522888, 8.50005627], [93.62536621, 8.50047112], [93.62536621, 8.50123215], [93.62543488, 8.5016489], [93.6256485, 8.50206375], [93.6256485, 8.50261974], [93.62571716, 8.50323963], [93.62584686, 8.50359058], [93.62542725, 8.50345039], [93.62529755, 8.5034523], [93.62502289, 8.50352001], [93.62502289, 8.5040102], [93.62529755, 8.50400639], [93.62549591, 8.50434971], [93.62542725, 8.5048399], [93.62528992, 8.50519085], [93.62516785, 8.50539589], [93.62513733, 8.50595856], [93.62520599, 8.50679111], [93.62519836, 8.50731659], [93.62532806, 8.50859356], [93.62539673, 8.50956535], [93.62511444, 8.51053333], [93.62500763, 8.51111031], [93.62500763, 8.51138973], [93.62472534, 8.5116663], [93.62458801, 8.51223087], [93.62430573, 8.51313114], [93.62451172, 8.51362419], [93.62472534, 8.51390171], [93.62479401, 8.51418018], [93.62479401, 8.51466465], [93.62484741, 8.51486969], [93.62493134, 8.51514816], [93.62472534, 8.51549721], [93.62451172, 8.51577282], [93.6241684, 8.51605129], [93.62388611, 8.51633072], [93.62388611, 8.51743889], [93.62361145, 8.51749992], [93.62333679, 8.51777935], [93.62333679, 8.51833153], [93.62284088, 8.51910019], [93.62262726, 8.51938057], [93.62242889, 8.51958847], [93.62207794, 8.51986408], [93.62180328, 8.51993465], [93.6213913, 8.51972294], [93.62110901, 8.51972008], [93.6202774, 8.52055454], [93.6202774, 8.52138901], [93.62076569, 8.5218811], [93.62097931, 8.5218811], [93.62104797, 8.52215862], [93.62083435, 8.5224371], [93.6211853, 8.52292347], [93.62210083, 8.52291965], [93.62216187, 8.52327061], [93.62167358, 8.52354527], [93.62187958, 8.52409172], [93.62211609, 8.52466202], [93.62211609, 8.5250082], [93.62204742, 8.52542496], [93.62155914, 8.5256319], [93.62110901, 8.52556038], [93.62110901, 8.52602673], [93.62146759, 8.52658081], [93.62153625, 8.52692699], [93.62125397, 8.52734184], [93.62091064, 8.52741241], [93.62062836, 8.52748108], [93.62042236, 8.52762032], [93.62000275, 8.52762032], [93.61959076, 8.52734184], [93.61923981, 8.52741241], [93.61882019, 8.52741241], [93.61847687, 8.52762032], [93.6184082, 8.52789783], [93.61875153, 8.5281744], [93.61904144, 8.5282402], [93.61917114, 8.52873039], [93.61897278, 8.52893925], [93.61860657, 8.52880001], [93.61818695, 8.52873039], [93.61791992, 8.52915096], [93.61819458, 8.52995777], [93.61847687, 8.53037262], [93.61855316, 8.53065109], [93.6184082, 8.5309267], [93.61819458, 8.53120518], [93.61812592, 8.53141212], [93.61785126, 8.53168964], [93.61756897, 8.53176117], [93.61750031, 8.53224373], [93.61750031, 8.53259087], [93.61727905, 8.53266144], [93.61694336, 8.53259277], [93.61638641, 8.53277779], [93.61638641, 8.53333378], [93.61668396, 8.53363228], [93.61699677, 8.53349113], [93.61720276, 8.53339672], [93.61747742, 8.53339672], [93.61740875, 8.53395081], [93.61720276, 8.53402042], [93.61712646, 8.53457642], [93.61698914, 8.53512955], [93.61664581, 8.53582001], [93.61472321, 8.53778267], [93.6138916, 8.5377779], [93.61360931, 8.53805637], [93.61360931, 8.53833389], [93.61332703, 8.53861046], [93.61333466, 8.53888798], [93.61305237, 8.53916645], [93.61305237, 8.53944397], [93.61277771, 8.53972244], [93.61277771, 8.5402689], [93.61250305, 8.54055595], [93.61250305, 8.54111004], [93.61222076, 8.54139042], [93.61222076, 8.5416708], [93.61055756, 8.5433321], [93.61013794, 8.54432583], [93.6102829, 8.54481125], [93.61048126, 8.54502106], [93.61076355, 8.54515839], [93.61118317, 8.54529667], [93.61152649, 8.54571247], [93.61152649, 8.54619694], [93.61174011, 8.54654408], [93.61180878, 8.54675102], [93.61138916, 8.54722309], [93.61138916, 8.54944515], [93.6111145, 8.54972267], [93.6111145, 8.55027676], [93.6102829, 8.55111122], [93.61027527, 8.55138874], [93.61000061, 8.55166721], [93.61000061, 8.55194473], [93.60972595, 8.5522089], [93.60972595, 8.5527792], [93.61000061, 8.55305481], [93.61000061, 8.55360889], [93.61027527, 8.55388927], [93.61027527, 8.55416679], [93.61055756, 8.55444527], [93.61055756, 8.55472088], [93.61083221, 8.55500126], [93.61083221, 8.55527687], [93.61027527, 8.55583286], [93.61027527, 8.55611134], [93.61055756, 8.5570116], [93.61083221, 8.5575676], [93.61138916, 8.55798244], [93.61200714, 8.55852032], [93.61200714, 8.55900097], [93.61186981, 8.55949116], [93.61138153, 8.55948925], [93.6111145, 8.55972099], [93.61083221, 8.56000042], [93.61055756, 8.56000042], [93.61055756, 8.56056023], [93.61051941, 8.56073093], [93.61093903, 8.56100464], [93.61167145, 8.56104088], [93.61201477, 8.56138802], [93.61236572, 8.56145573], [93.61342621, 8.56228638], [93.61342621, 8.56311512], [93.61339569, 8.56391144], [93.61373901, 8.5643959], [93.61417389, 8.56446171], [93.61444855, 8.56453037], [93.61444855, 8.56494999], [93.61424255, 8.56516171], [93.61368561, 8.56515503], [93.61340332, 8.56536007], [93.61332703, 8.56578159], [93.61347198, 8.56591797], [93.61361694, 8.56619644], [93.61361694, 8.56640434], [93.61312866, 8.56633282], [93.61284637, 8.56633282], [93.61264038, 8.56647015], [93.61264038, 8.56695843], [93.61284637, 8.56723595], [93.61312866, 8.56729984], [93.61332703, 8.56772137], [93.61299133, 8.56807041], [93.61250305, 8.56806755], [93.61228943, 8.56855106], [93.61250305, 8.56890202], [93.61273193, 8.5696106], [93.61258698, 8.5698204], [93.61238098, 8.56996155], [93.61223602, 8.57044029], [93.61210632, 8.57072067], [93.61190796, 8.57092953], [93.61154938, 8.57106495], [93.6111145, 8.57166576], [93.61138916, 8.57194424], [93.61138916, 8.57250118], [93.61194611, 8.57306099], [93.61244202, 8.57286072], [93.61277771, 8.57268143], [93.61297607, 8.57268143], [93.61340332, 8.5731678], [93.61340332, 8.57351494], [93.61347198, 8.57393169], [93.61360931, 8.57434177], [93.61360931, 8.57450199], [93.61284637, 8.57462502], [93.61250305, 8.57527733], [93.61250305, 8.57583332], [93.61314392, 8.57612228], [93.61349487, 8.57591248], [93.61391449, 8.57549763], [93.61467743, 8.57494164], [93.61523438, 8.57459736], [93.61599731, 8.57362556]]], [[[93.63491821, 8.39464378], [93.63464355, 8.39464378], [93.63394928, 8.39492226], [93.63387299, 8.39561462], [93.63366699, 8.39616776], [93.63324738, 8.39665413], [93.63297272, 8.39727783], [93.63297272, 8.39783001], [93.63324738, 8.39804173], [93.63387299, 8.39804173], [93.63421631, 8.39797115], [93.63457489, 8.39762497], [93.63471222, 8.39734745], [93.63506317, 8.39699078], [93.63540649, 8.39679337], [93.63568115, 8.39610004], [93.63561249, 8.39547634], [93.63540649, 8.39498997], [93.63491821, 8.39464378]]], [[[93.60944366, 8.58166695], [93.60944366, 8.58138943], [93.60916901, 8.58111095], [93.60916901, 8.57999897], [93.60943604, 8.57972145], [93.60944366, 8.57944489], [93.60888672, 8.57888889], [93.60888672, 8.57861137], [93.60832977, 8.5780592], [93.60721588, 8.57916927], [93.60652161, 8.5796566], [93.60652161, 8.58090401], [93.60659027, 8.58125019], [93.60680389, 8.58146], [93.60694122, 8.58173561], [93.60729218, 8.58187485], [93.60756683, 8.58171654], [93.60777283, 8.58159733], [93.60832977, 8.58166695], [93.60874939, 8.58201408], [93.60916901, 8.58201408], [93.60944366, 8.58166695]]], [[[92.85916901, 8.8201313], [92.85888672, 8.81993008], [92.85832977, 8.81972313], [92.85736084, 8.81923485], [92.85687256, 8.8190279], [92.85650635, 8.81898022], [92.85595703, 8.81919193], [92.85546112, 8.81940174], [92.8549118, 8.81947041], [92.85415649, 8.81943989], [92.85360718, 8.82000065], [92.85333252, 8.81999874], [92.85277557, 8.82055473], [92.85243225, 8.82090378], [92.85201263, 8.82159615], [92.85194397, 8.8222208], [92.85221863, 8.82250118], [92.85221863, 8.82305527], [92.85250092, 8.82333279], [92.85250092, 8.82444477], [92.85277557, 8.82472324], [92.85277557, 8.82722092], [92.85250092, 8.82749939], [92.85250092, 8.82833385], [92.85277557, 8.82861233], [92.85277557, 8.83055592], [92.85305786, 8.83083439], [92.85305786, 8.83111191], [92.85333252, 8.83138847], [92.85333252, 8.83194065], [92.85361481, 8.83222198], [92.85361481, 8.83250046], [92.85444641, 8.83333397], [92.85444641, 8.83361244], [92.85527802, 8.83444405], [92.85541534, 8.83479023], [92.85778046, 8.83708286], [92.85805511, 8.8372221], [92.85861206, 8.83743191], [92.85944366, 8.83729267], [92.86006927, 8.83666611], [92.86027527, 8.83638763], [92.86194611, 8.83471966], [92.86194611, 8.83444405], [92.86222076, 8.83416557], [92.86222076, 8.83388996], [92.86242676, 8.83360958], [92.86250305, 8.83305645], [92.86250305, 8.83270741], [92.86250305, 8.83215141], [92.86284637, 8.83145809], [92.8629837, 8.83083439], [92.86319733, 8.8302784], [92.86326599, 8.82993126], [92.86326599, 8.82881927], [92.86312866, 8.82806015], [92.86305237, 8.82722092], [92.86305237, 8.8269434], [92.86305237, 8.82638931], [92.86305237, 8.82630539], [92.86306, 8.82588959], [92.86297607, 8.82513142], [92.86284637, 8.82451057], [92.86264038, 8.82380867], [92.86250305, 8.8229208], [92.86110687, 8.82186985], [92.8605423, 8.82173347], [92.86019135, 8.82124996], [92.86012268, 8.82048702], [92.85978699, 8.82034969], [92.85943604, 8.82028961], [92.85916901, 8.8201313]]], [[[92.47972107, 10.52056026], [92.47944641, 10.52056026], [92.47860718, 10.52139187], [92.47833252, 10.52139187], [92.47805786, 10.52167034], [92.47750092, 10.52166843], [92.47694397, 10.52222443], [92.47666931, 10.52222061], [92.47611237, 10.52278042], [92.47583008, 10.52278042], [92.47556305, 10.52305984], [92.47528076, 10.52305603], [92.47499847, 10.52333355], [92.47499847, 10.52361202], [92.47472382, 10.52361202], [92.47389221, 10.52444363], [92.47360992, 10.52444363], [92.47222137, 10.52555561], [92.47166443, 10.52583408], [92.47138977, 10.5261097], [92.47110748, 10.5261097], [92.47055817, 10.52666569], [92.47027588, 10.52673626], [92.46971893, 10.52729034], [92.46923828, 10.5277071], [92.46868134, 10.52821064], [92.46805573, 10.52909756], [92.46583557, 10.53111458], [92.46498871, 10.53234959], [92.46477509, 10.5327673], [92.46401215, 10.53352642], [92.46360779, 10.53444386], [92.46305847, 10.53499985], [92.46305847, 10.53527641], [92.46221924, 10.53610992], [92.46193695, 10.53610992], [92.46166992, 10.53639126], [92.46138763, 10.5363884], [92.46083069, 10.53694534], [92.46028137, 10.53694534], [92.45888519, 10.53833294], [92.45861053, 10.53833294], [92.45722198, 10.5397234], [92.45694733, 10.53972054], [92.45667267, 10.54000092], [92.45610809, 10.54000092], [92.45582581, 10.5402813], [92.45527649, 10.5402813], [92.45500183, 10.54056168], [92.45444489, 10.54055691], [92.45313263, 10.54139137], [92.45305634, 10.54277706], [92.45277405, 10.54305458], [92.45277405, 10.54333305], [92.45249939, 10.54361057], [92.45249939, 10.54416656], [92.45194244, 10.54472256], [92.45166779, 10.54472256], [92.45027924, 10.54333305], [92.44999695, 10.54333305], [92.44937134, 10.54347038], [92.44882202, 10.54382133], [92.44847107, 10.54389095], [92.44777679, 10.54402828], [92.44728851, 10.54409885], [92.4465332, 10.54437923], [92.44576263, 10.54445171], [92.44541931, 10.54437733], [92.44493103, 10.54465485], [92.44431305, 10.54471016], [92.44381714, 10.54486179], [92.44312286, 10.54506969], [92.44277954, 10.54521084], [92.44194794, 10.54521084], [92.44152832, 10.54535007], [92.44132233, 10.54549122], [92.44097137, 10.54563046], [92.44055176, 10.54569626], [92.44020844, 10.54583454], [92.43972015, 10.5460434], [92.4394455, 10.5462532], [92.4383316, 10.5466671], [92.43805695, 10.54694462], [92.43777466, 10.54694462], [92.4375, 10.54722118], [92.43723297, 10.54722118], [92.43694305, 10.54750156], [92.43638611, 10.5474987], [92.43611145, 10.54777718], [92.43554688, 10.54776955], [92.43527985, 10.54806042], [92.43499756, 10.5480547], [92.4347229, 10.54833317], [92.43416595, 10.54833317], [92.43318939, 10.54831505], [92.43249512, 10.54838562], [92.43158722, 10.54852486], [92.43081665, 10.54852009], [92.42928314, 10.54887104], [92.42774963, 10.54914856], [92.42698669, 10.54914856], [92.42642975, 10.54895115], [92.42572784, 10.54879189], [92.424263, 10.5487299], [92.42314911, 10.5487299], [92.42134094, 10.54824734], [92.42119598, 10.54824924], [92.41993713, 10.5479002], [92.41903687, 10.54755592], [92.41861725, 10.54720974], [92.41819763, 10.54645061], [92.41792297, 10.54582882], [92.41743469, 10.54534531], [92.41694641, 10.54472256], [92.41555786, 10.54333305], [92.41555786, 10.54305458], [92.41500092, 10.54249859], [92.41500854, 10.54222107], [92.41333008, 10.54055691], [92.41333008, 10.54027653], [92.41306305, 10.54000092], [92.41306305, 10.53972054], [92.41249847, 10.5391674], [92.41249847, 10.53888893], [92.40833282, 10.53472042], [92.40805817, 10.53472233], [92.40750122, 10.53416634], [92.40721893, 10.5341711], [92.40677643, 10.53372192], [92.40666962, 10.53361034], [92.40638733, 10.53361034], [92.40583038, 10.53305626], [92.40528107, 10.53306103], [92.40499878, 10.5327692], [92.40472412, 10.53277779], [92.40444183, 10.53250027], [92.40416718, 10.53250027], [92.40389252, 10.53222179], [92.40333557, 10.53222179], [92.40305328, 10.53194427], [92.40277863, 10.53194427], [92.40249634, 10.5316658], [92.40194702, 10.53167057], [92.4016571, 10.53139019], [92.40000916, 10.53139019], [92.39975739, 10.53114605], [92.39499664, 10.53111172], [92.39492798, 10.5310421], [92.39472198, 10.53083038], [92.39111328, 10.53083038], [92.39082336, 10.53111172], [92.3897171, 10.53111172], [92.38944244, 10.53139019], [92.38916779, 10.53139019], [92.38861084, 10.53152943], [92.38694763, 10.5316658], [92.38666534, 10.53194427], [92.38639069, 10.53194427], [92.3861084, 10.53222179], [92.38583374, 10.53222179], [92.38555908, 10.53229332], [92.38527679, 10.53222179], [92.38361359, 10.53388786], [92.38361359, 10.53444386], [92.3833313, 10.53472042], [92.3833313, 10.53527641], [92.38305664, 10.53555679], [92.38305664, 10.53582954], [92.38277435, 10.53610992], [92.38249969, 10.53610992], [92.3813858, 10.53722], [92.38131714, 10.53756905], [92.3813858, 10.53889084], [92.38159943, 10.53965187], [92.38194275, 10.54083347], [92.3822937, 10.54139137], [92.38298798, 10.54222298], [92.38305664, 10.54249859], [92.3841629, 10.54361057], [92.3841629, 10.54389095], [92.38527679, 10.54500103], [92.38555908, 10.54500103], [92.38582611, 10.54527855], [92.3861084, 10.54527664], [92.38666534, 10.54583263], [92.38694763, 10.54583263], [92.38944244, 10.54833317], [92.38944244, 10.54861069], [92.38972473, 10.54889011], [92.38972473, 10.54916763], [92.39026642, 10.54971886], [92.39026642, 10.54999924], [92.39083099, 10.55055618], [92.39083099, 10.5508337], [92.39360809, 10.55361176], [92.39360809, 10.55472183], [92.39305878, 10.55527973], [92.39305878, 10.5555563], [92.39221954, 10.5563879], [92.39214325, 10.55682278], [92.39212799, 10.55751228], [92.39248657, 10.55814266], [92.3927002, 10.5588274], [92.39311981, 10.55937958], [92.39332581, 10.56014156], [92.39367676, 10.56076431], [92.39381409, 10.56103992], [92.39472198, 10.56194401], [92.39472198, 10.56221962], [92.39499664, 10.56250095], [92.39499664, 10.56278133], [92.39527893, 10.56305695], [92.39527893, 10.56361008], [92.39583588, 10.56416702], [92.39583588, 10.56472015], [92.39607239, 10.56495953], [92.39666748, 10.56556129], [92.39694977, 10.56556129], [92.39888763, 10.56750107], [92.39888763, 10.56805515], [92.39916992, 10.5683279], [92.39916992, 10.56888866], [92.39944458, 10.56916714], [92.39944458, 10.56972313], [92.39971924, 10.56999874], [92.39971924, 10.5708313], [92.40027618, 10.5713892], [92.40027618, 10.57166672], [92.40055847, 10.57194519], [92.40055847, 10.57249928], [92.40222168, 10.57417202], [92.40249634, 10.57416725], [92.40333557, 10.57499886], [92.40361023, 10.57499886], [92.40367889, 10.57507038], [92.40389252, 10.57528019], [92.40416718, 10.57528019], [92.40499878, 10.57611179], [92.40499878, 10.57639027], [92.40528107, 10.57666779], [92.40528107, 10.57694054], [92.40575409, 10.57742023], [92.40611267, 10.57777977], [92.40638733, 10.57777786], [92.40638733, 10.57805634], [92.40666962, 10.57833385], [92.40666962, 10.57861233], [92.40721893, 10.57916641], [92.40721893, 10.57971859], [92.40750122, 10.57999992], [92.40750122, 10.5802803], [92.40777588, 10.58055592], [92.40777588, 10.58083439], [92.4091568, 10.58222198], [92.4091568, 10.58250046], [92.40944672, 10.58277798], [92.40944672, 10.58305645], [92.40972137, 10.58333397], [92.40944672, 10.58361244], [92.40944672, 10.58388138], [92.40972137, 10.5841713], [92.40972137, 10.58749962], [92.41000366, 10.58777809], [92.41000366, 10.58916569], [92.40972137, 10.58944416], [92.40972137, 10.59166718], [92.41000366, 10.59194469], [92.41000366, 10.59305477], [92.41027832, 10.59333324], [92.41027832, 10.59416676], [92.41055298, 10.59444523], [92.41055298, 10.59555531], [92.41083527, 10.59583282], [92.4108429, 10.5961113], [92.41110992, 10.59638882], [92.41110992, 10.59666729], [92.41166687, 10.59722328], [92.41166687, 10.59749889], [92.41222382, 10.59805489], [92.41222382, 10.60055542], [92.41249847, 10.60083103], [92.41249847, 10.60138893], [92.41278076, 10.6016674], [92.41278076, 10.60222054], [92.41305542, 10.60249901], [92.41306305, 10.60472202], [92.41278076, 10.60501099], [92.41278076, 10.6055603], [92.4127121, 10.60610962], [92.41333008, 10.60666561], [92.41333008, 10.60694408], [92.41444397, 10.60805607], [92.41443634, 10.60833168], [92.41500092, 10.60888767], [92.41500092, 10.60916805], [92.41527557, 10.60944366], [92.41546631, 10.60960102], [92.41553497, 10.60987854], [92.41602325, 10.61015511], [92.41637421, 10.61043262], [92.41769409, 10.61112404], [92.41832733, 10.61119366], [92.41923523, 10.61140156], [92.41964722, 10.61147022], [92.42006683, 10.61195278], [92.42028046, 10.61250019], [92.42028046, 10.6133337], [92.42055511, 10.61361027], [92.42056274, 10.61472034], [92.42028046, 10.61499977], [92.42007446, 10.61547947], [92.4199295, 10.61610126], [92.4199295, 10.61755085], [92.41979218, 10.61797047], [92.41971588, 10.61852169], [92.41944122, 10.61916733], [92.41931152, 10.61967468], [92.41889191, 10.62050533], [92.41868591, 10.62112713], [92.41854095, 10.62209129], [92.41854095, 10.62271786], [92.41847229, 10.62326908], [92.41833496, 10.62375546], [92.4182663, 10.62416935], [92.41805267, 10.62444305], [92.41805267, 10.62527657], [92.41757202, 10.62576294], [92.41742706, 10.62736034], [92.41736603, 10.62833309], [92.41694641, 10.62861061], [92.41666412, 10.62888908], [92.41666412, 10.62916756], [92.41638947, 10.62944126], [92.41638947, 10.63000202], [92.41611481, 10.63027668], [92.41611481, 10.63166809], [92.41583252, 10.6319437], [92.41583252, 10.63222218], [92.41521454, 10.63340378], [92.41493225, 10.63416576], [92.41464996, 10.63444424], [92.41444397, 10.63472176], [92.41396332, 10.63597298], [92.41340637, 10.63701534], [92.41305542, 10.63749981], [92.41306305, 10.63833046], [92.41278076, 10.63861179], [92.41278076, 10.63889027], [92.41249847, 10.63916588], [92.41249847, 10.63944435], [92.41221619, 10.63971996], [92.41221619, 10.64000034], [92.41194153, 10.64027786], [92.41194153, 10.64055634], [92.41166687, 10.64083004], [92.41166687, 10.64112186], [92.41139221, 10.64138794], [92.41139221, 10.64166641], [92.41110992, 10.64194393], [92.41110992, 10.64221954], [92.41083527, 10.64249992], [92.41083527, 10.64277935], [92.41056061, 10.64340305], [92.41027832, 10.64388847], [92.41027832, 10.64416695], [92.41027832, 10.64444542], [92.40999603, 10.64472008], [92.41000366, 10.64500141], [92.40972137, 10.64527893], [92.40972137, 10.64583302], [92.40944672, 10.64611053], [92.40944672, 10.64638901], [92.40916443, 10.64666653], [92.40916443, 10.646945], [92.40888977, 10.64722061], [92.40888977, 10.64750099], [92.40833282, 10.64805698], [92.40833282, 10.64861107], [92.40721893, 10.64972115], [92.40721893, 10.65000057], [92.40694427, 10.65027905], [92.40694427, 10.65055466], [92.40666962, 10.65083313], [92.40666962, 10.65111065], [92.40611267, 10.65166664], [92.40611267, 10.65222073], [92.40582275, 10.6524992], [92.40583038, 10.65277672], [92.40444183, 10.65416527], [92.40444183, 10.65444469], [92.40416718, 10.65472126], [92.40416718, 10.65499878], [92.40361023, 10.65555477], [92.40361023, 10.65583324], [92.40222168, 10.65722084], [92.40188599, 10.65792084], [92.40174103, 10.65819931], [92.40125275, 10.65888691], [92.40084076, 10.65944099], [92.40020752, 10.66006279], [92.39971924, 10.6607542], [92.39971924, 10.66111183], [92.39944458, 10.6613903], [92.39888763, 10.66166592], [92.39639282, 10.66471958], [92.39639282, 10.66499996], [92.39499664, 10.66639042], [92.39472198, 10.66639042], [92.39444733, 10.66611004], [92.39360809, 10.66611004], [92.39332581, 10.66639042], [92.39305878, 10.66639042], [92.39277649, 10.6666708], [92.39250183, 10.6666708], [92.39193726, 10.66611004], [92.391716, 10.66606045], [92.39122772, 10.66585732], [92.39066315, 10.66557884], [92.3901062, 10.66558075], [92.38912964, 10.66565037], [92.38829803, 10.66578579], [92.38725281, 10.66592503], [92.38641357, 10.66599369], [92.38585663, 10.66627026], [92.38536835, 10.66647911], [92.38425446, 10.66668701], [92.38362122, 10.66675472], [92.38334656, 10.66675472], [92.38264465, 10.66647911], [92.38208771, 10.66640854], [92.3813858, 10.6664114], [92.3812561, 10.66648197], [92.38097382, 10.66647911], [92.38083649, 10.66668701], [92.3805542, 10.66694355], [92.3805542, 10.66722202], [92.38027954, 10.66749954], [92.38027954, 10.6683321], [92.3805542, 10.66861343], [92.38083649, 10.66860962], [92.38083649, 10.66889095], [92.38111115, 10.66917133], [92.38194275, 10.66916561], [92.38222504, 10.66944408], [92.38223267, 10.6697197], [92.38249969, 10.67000103], [92.38249969, 10.67027855], [92.38277435, 10.67055416], [92.38277435, 10.67083454], [92.38305664, 10.67111015], [92.38305664, 10.67194462], [92.3833313, 10.67222309], [92.3833313, 10.67388916], [92.38361359, 10.67416668], [92.38361359, 10.67444515], [92.3833313, 10.67472267], [92.3833313, 10.67527676], [92.38308716, 10.67560291], [92.38246155, 10.67601681], [92.38224792, 10.67621994], [92.38179779, 10.67667389], [92.38169098, 10.67719078], [92.38154602, 10.67761135], [92.3812027, 10.67808914], [92.3812027, 10.67836666], [92.38149261, 10.67885017], [92.38175964, 10.67892075], [92.38217926, 10.67905807], [92.38217926, 10.67919731], [92.38222504, 10.67972088], [92.38222504, 10.68166733], [92.38194275, 10.68194485], [92.38194275, 10.68222141], [92.38166809, 10.68249893], [92.38166809, 10.6827774], [92.38111115, 10.68333054], [92.38083649, 10.68389034], [92.38083649, 10.68999958], [92.3805542, 10.69027805], [92.38062286, 10.69063091], [92.38050079, 10.69139004], [92.38050079, 10.69174099], [92.38018799, 10.69257069], [92.38006592, 10.69325924], [92.37979126, 10.69408894], [92.37985992, 10.69470882], [92.37999725, 10.69546986], [92.3805542, 10.69583225], [92.3805542, 10.69666576], [92.38083649, 10.69694042], [92.38083649, 10.69889069], [92.38111115, 10.69916725], [92.38111115, 10.70055676], [92.38083649, 10.70083046], [92.38083649, 10.70111084], [92.3805542, 10.70138931], [92.3805542, 10.70222282], [92.38046265, 10.70321178], [92.38039398, 10.70411015], [92.38018799, 10.70473194], [92.38018799, 10.70549393], [92.38004303, 10.70632267], [92.38027954, 10.70694065], [92.38027954, 10.70777702], [92.37999725, 10.70805454], [92.38027954, 10.70833302], [92.38027954, 10.7102766], [92.3805542, 10.71055508], [92.3805542, 10.7127018], [92.38051605, 10.71346378], [92.38051605, 10.71401501], [92.38065338, 10.71512127], [92.38100433, 10.71581268], [92.38121033, 10.71636486], [92.38137054, 10.71671104], [92.38162994, 10.71719456], [92.38169861, 10.71760941], [92.38191223, 10.71816063], [92.38194275, 10.71860981], [92.38222504, 10.71889019], [92.38222504, 10.71944427], [92.38249969, 10.71972179], [92.38249969, 10.72138119], [92.38212585, 10.72242069], [92.38183594, 10.72289944], [92.38176727, 10.72332096], [92.3817749, 10.72414589], [92.38163757, 10.72456074], [92.38163757, 10.72482967], [92.38143158, 10.7254591], [92.38135529, 10.72608089], [92.3809433, 10.72670269], [92.38083649, 10.72722054], [92.38054657, 10.72750092], [92.38054657, 10.7277813], [92.38027954, 10.72805691], [92.38027954, 10.72861099], [92.37999725, 10.72889137], [92.37999725, 10.73027897], [92.3797226, 10.73055458], [92.3797226, 10.73111057], [92.3795166, 10.73173523], [92.37916565, 10.7341671], [92.37917328, 10.7344408], [92.37869263, 10.73548889], [92.37847137, 10.73611069], [92.37832642, 10.73751068], [92.37805176, 10.73777962], [92.37805176, 10.73806], [92.37785339, 10.73888969], [92.37785339, 10.73951435], [92.37770844, 10.74007034], [92.37792206, 10.7407608], [92.37833405, 10.74111176], [92.37833405, 10.74166584], [92.3786087, 10.74194431], [92.3786087, 10.74250031], [92.37847137, 10.74270725], [92.37847137, 10.74319267], [92.37854004, 10.74361038], [92.3786087, 10.74500179], [92.37854004, 10.74528027], [92.37840271, 10.74631977], [92.37830353, 10.74679565], [92.37830353, 10.74755478], [92.37837219, 10.74783325], [92.37837219, 10.74838543], [92.37844086, 10.74935341], [92.37830353, 10.75004387], [92.37823486, 10.75032043], [92.37805176, 10.7508297], [92.37833405, 10.75111008], [92.37833405, 10.75285244], [92.3782196, 10.75347233], [92.37828827, 10.75395012], [92.37835693, 10.75457859], [92.3784256, 10.75485516], [92.3784256, 10.75520134], [92.37828827, 10.75575256], [92.37850189, 10.75623608], [92.37899017, 10.75672245], [92.3793335, 10.75727463], [92.37975311, 10.75768757], [92.3800354, 10.75810337], [92.38024139, 10.75858784], [92.38024139, 10.7597599], [92.38046265, 10.76031971], [92.38072968, 10.76073074], [92.3813858, 10.76139164], [92.38144684, 10.76192856], [92.38147736, 10.76217079], [92.38140106, 10.76237774], [92.38105774, 10.76327038], [92.38098907, 10.76390076], [92.38056946, 10.76466179], [92.38035583, 10.76500416], [92.37992096, 10.7652483], [92.37943268, 10.76559353], [92.37901306, 10.76648998], [92.37873077, 10.7669754], [92.37859344, 10.76759815], [92.37859344, 10.76801205], [92.37845612, 10.76856613], [92.37810516, 10.76891041], [92.3777771, 10.7691679], [92.37722015, 10.76972198], [92.37722015, 10.77055645], [92.3769455, 10.77083397], [92.3769455, 10.77166557], [92.37666321, 10.77194405], [92.37666321, 10.77221966], [92.37638855, 10.77250004], [92.37638855, 10.77278042], [92.37610626, 10.7730608], [92.37610626, 10.77334118], [92.37604523, 10.77388763], [92.37590027, 10.77451038], [92.3758316, 10.77527809], [92.3758316, 10.77555561], [92.37590027, 10.77590275], [92.3758316, 10.77618122], [92.37596893, 10.7765274], [92.37596893, 10.77701283], [92.3758316, 10.77882004], [92.37583923, 10.77943134], [92.37611389, 10.77999783], [92.37611389, 10.78166676], [92.37638855, 10.78194523], [92.37638855, 10.78222275], [92.37666321, 10.78249168], [92.37666321, 10.78277683], [92.3769455, 10.78305531], [92.37695313, 10.78333092], [92.37750244, 10.78389072], [92.37750244, 10.78416729], [92.38083649, 10.78750134], [92.38083649, 10.78777695], [92.3813858, 10.78833103], [92.3813858, 10.78862], [92.38305664, 10.79028034], [92.3833313, 10.79028034], [92.38360596, 10.79055977], [92.38388824, 10.790555], [92.3841629, 10.79083347], [92.38471985, 10.79083347], [92.38555908, 10.78999901], [92.38555908, 10.78972435], [92.38583374, 10.78944302], [92.38583374, 10.78909397], [92.3861084, 10.78833294], [92.38625336, 10.78805542], [92.38639069, 10.78777695], [92.38625336, 10.78695202], [92.3861084, 10.78583145], [92.38583374, 10.78555489], [92.38583374, 10.78472328], [92.38603973, 10.78421307], [92.38617706, 10.78379822], [92.38659668, 10.78317642], [92.38707733, 10.78297043], [92.38786316, 10.7825489], [92.38861847, 10.78234577], [92.38924408, 10.78207016], [92.3897171, 10.78167057], [92.39055634, 10.78167057], [92.39082336, 10.78139114], [92.39167023, 10.78139114], [92.39193726, 10.7811079], [92.39221954, 10.78111076], [92.39277649, 10.78055668], [92.39305878, 10.78056145], [92.39332581, 10.78028107], [92.39360809, 10.78028107], [92.39451599, 10.77962017], [92.39472961, 10.77913857], [92.39479828, 10.77851677], [92.39466095, 10.77796078], [92.39417267, 10.77748013], [92.39368439, 10.77720356], [92.3934021, 10.776721], [92.39291382, 10.77623558], [92.39277649, 10.77547741], [92.39291382, 10.77340317], [92.39298248, 10.77278042], [92.39305878, 10.77194405], [92.39326477, 10.76972198], [92.39333344, 10.7691679], [92.39332581, 10.76889038], [92.39360809, 10.76861191], [92.39360809, 10.76749992], [92.39388275, 10.7672224], [92.39402771, 10.76597023], [92.39416504, 10.76527786], [92.39437866, 10.76416779], [92.39444733, 10.76389027], [92.39444733, 10.76333141], [92.39472198, 10.76305485], [92.39472198, 10.76249886], [92.39499664, 10.76222134], [92.39499664, 10.76194477], [92.39527893, 10.76166725], [92.39527893, 10.76138878], [92.39554596, 10.76111126], [92.39555359, 10.76083279], [92.39611053, 10.76041603], [92.39659882, 10.76027679], [92.39694977, 10.76028156], [92.39722443, 10.76034832], [92.39749908, 10.76055527], [92.39771271, 10.76076031], [92.39839935, 10.76138878], [92.39861298, 10.76166725], [92.39901733, 10.76222134], [92.39916992, 10.76250172], [92.39944458, 10.76277733], [92.39937592, 10.76305485], [92.39902496, 10.7634716], [92.39854431, 10.76298714], [92.39833069, 10.76277733], [92.39756775, 10.76173592], [92.39680481, 10.76166725], [92.39659882, 10.76187706], [92.39638519, 10.76222134], [92.39583588, 10.76277733], [92.39583588, 10.76333141], [92.39554596, 10.76361084], [92.3953476, 10.76437664], [92.39527893, 10.76499939], [92.39499664, 10.76589108], [92.39499664, 10.76638985], [92.39479065, 10.76701641], [92.39472198, 10.76756954], [92.39465332, 10.76826286], [92.39444733, 10.76888847], [92.3942337, 10.77104378], [92.39389038, 10.77194405], [92.39409637, 10.77221966], [92.39479065, 10.77285099], [92.39499664, 10.7730608], [92.3951416, 10.77365971], [92.39527893, 10.77401066], [92.39527893, 10.77417088], [92.39527893, 10.77499962], [92.39555359, 10.77527809], [92.39555359, 10.77666569], [92.39639282, 10.77750111], [92.39639282, 10.77778053], [92.39666748, 10.77806091], [92.39666748, 10.77858543], [92.396698, 10.77907085], [92.39697266, 10.77941513], [92.39718628, 10.77982998], [92.39718628, 10.7803812], [92.39711761, 10.78079796], [92.39711761, 10.78093529], [92.39749908, 10.7811079], [92.39768982, 10.78129768], [92.39778137, 10.78139114], [92.39833069, 10.78138924], [92.39888763, 10.78194523], [92.39916992, 10.78194523], [92.39944458, 10.78201485], [92.39971924, 10.78201485], [92.40007019, 10.7820816], [92.40090179, 10.78222275], [92.40166473, 10.78222275], [92.4017868, 10.782341], [92.40194702, 10.78250122], [92.40277863, 10.78249168], [92.40339661, 10.78265095], [92.40416718, 10.78278065], [92.40444183, 10.78306198], [92.40499878, 10.78305531], [92.40528107, 10.78333282], [92.40555573, 10.78333282], [92.40583038, 10.7836113], [92.40611267, 10.7836113], [92.40666962, 10.7841692], [92.40694427, 10.78416729], [92.40777588, 10.78479385], [92.40805817, 10.78499889], [92.40888977, 10.78583336], [92.40916443, 10.78583336], [92.41166687, 10.78805733], [92.41194153, 10.78833294], [92.4126358, 10.78874969], [92.41305542, 10.78888893], [92.41333008, 10.7891674], [92.41333008, 10.78944111], [92.41388702, 10.79000187], [92.41416931, 10.78999901], [92.41416931, 10.79027653], [92.41471863, 10.79083347], [92.41471863, 10.79111195], [92.41610718, 10.79249954], [92.41610718, 10.79277992], [92.41722107, 10.79389191], [92.41722107, 10.79417038], [92.41833496, 10.7952776], [92.41833496, 10.79555607], [92.41860962, 10.79583359], [92.41860962, 10.79638767], [92.41971588, 10.79749107], [92.41972351, 10.79777813], [92.41999817, 10.79805565], [92.41999817, 10.79833412], [92.42028046, 10.79860973], [92.42028046, 10.79916573], [92.42055511, 10.7994442], [92.42066193, 10.79998589], [92.42066193, 10.80033112], [92.42094421, 10.80088425], [92.42128754, 10.80157661], [92.42163849, 10.80198956], [92.42194366, 10.80277824], [92.42222595, 10.80305576], [92.42222595, 10.80472279], [92.42250061, 10.80500126], [92.42250061, 10.80638885], [92.42222595, 10.8066597], [92.42211151, 10.80681705], [92.42218018, 10.80743885], [92.42233276, 10.80799103], [92.42266846, 10.80848122], [92.42295074, 10.80902958], [92.42343903, 10.80937672], [92.42399597, 10.80951309], [92.42444611, 10.80944538], [92.42492676, 10.80987835], [92.4254837, 10.81098557], [92.42582703, 10.81188107], [92.42590332, 10.81244183], [92.42610931, 10.81278229], [92.42610931, 10.81361103], [92.4263916, 10.81388855], [92.4263916, 10.81444454], [92.42666626, 10.81472111], [92.42666626, 10.8152771], [92.4263916, 10.81555462], [92.4263916, 10.81583118], [92.42694092, 10.81638908], [92.42694092, 10.8166666], [92.42722321, 10.81694126], [92.42722321, 10.81750202], [92.42714691, 10.81783199], [92.42722321, 10.81818104], [92.42729187, 10.81865692], [92.42722321, 10.81927872], [92.42714691, 10.81962109], [92.42687225, 10.82003784], [92.42666626, 10.82073116], [92.42666626, 10.82250023], [92.42688751, 10.82328415], [92.42771912, 10.82363033], [92.4282074, 10.8234911], [92.42884064, 10.82293987], [92.42967224, 10.82231712], [92.43036652, 10.82197094], [92.43106842, 10.82175922], [92.43281555, 10.82176399], [92.43357849, 10.82204247], [92.4342041, 10.82224655], [92.43490601, 10.8228693], [92.43560028, 10.82328415], [92.43671417, 10.82404518], [92.43741608, 10.82487488], [92.43804169, 10.82577324], [92.43852997, 10.82639503], [92.44139099, 10.82944393], [92.44139099, 10.82971954], [92.44167328, 10.82999992], [92.44167328, 10.83056068], [92.44249725, 10.83139133], [92.44256592, 10.83159828], [92.4438858, 10.83305359], [92.44403076, 10.83326435], [92.44451141, 10.83353996], [92.44472504, 10.83388901], [92.44499969, 10.83416653], [92.44499207, 10.83444023], [92.44555664, 10.83500099], [92.44555664, 10.83555698], [92.4458313, 10.8358326], [92.4458313, 10.83611107], [92.44721985, 10.83750057], [92.44777679, 10.83750057], [92.44805908, 10.83778095], [92.44916534, 10.83777905], [92.4493103, 10.83792019], [92.44944763, 10.83805943], [92.44999695, 10.83805943], [92.45027924, 10.83778095], [92.45054626, 10.83778095], [92.45083618, 10.83750057], [92.45388794, 10.83749866], [92.45432281, 10.8376379], [92.45500183, 10.83778095], [92.45527649, 10.83805943], [92.45573425, 10.83812332], [92.4562912, 10.83846664], [92.45664978, 10.83881187], [92.4569931, 10.83936977], [92.45741272, 10.83998966], [92.45775604, 10.84081936], [92.45777893, 10.8413887], [92.45805359, 10.84166718], [92.45804596, 10.84222126], [92.45855713, 10.8425312], [92.45856476, 10.84335804], [92.45888519, 10.84416771], [92.45888519, 10.84444332], [92.45916748, 10.84472084], [92.45916748, 10.84527683], [92.45944214, 10.84555626], [92.45944214, 10.84583378], [92.45972443, 10.84611225], [92.45986176, 10.84663105], [92.45993042, 10.84759998], [92.45999908, 10.84861183], [92.45999908, 10.85056019], [92.45999908, 10.85099125], [92.45999908, 10.85175037], [92.45986176, 10.85244083], [92.4597168, 10.85326958], [92.45972443, 10.85388756], [92.45944214, 10.85416603], [92.45944214, 10.85471058], [92.45916748, 10.85499954], [92.45916748, 10.85527802], [92.45888519, 10.85555553], [92.45888519, 10.8558321], [92.45861053, 10.85610962], [92.45861053, 10.85638809], [92.45833588, 10.85666561], [92.45833588, 10.85694408], [92.45722198, 10.85805416], [92.45722198, 10.85833454], [92.45666504, 10.85888767], [92.45667267, 10.85972023], [92.45639038, 10.86000061], [92.45639038, 10.86028099], [92.45667267, 10.86056137], [92.45666504, 10.86083317], [92.45694733, 10.86111069], [92.45694733, 10.86139107], [92.45861053, 10.8630619], [92.45888519, 10.86305523], [92.45916748, 10.86333275], [92.45972443, 10.86333275], [92.45999908, 10.86361122], [92.46193695, 10.86361122], [92.46221924, 10.86390018], [92.46277618, 10.86390018], [92.46305847, 10.86417103], [92.46333313, 10.86416721], [92.46348572, 10.8643198], [92.46360779, 10.86444473], [92.46389008, 10.86444473], [92.46416473, 10.86472321], [92.46444702, 10.8647213], [92.46458435, 10.86485958], [92.46472168, 10.86500072], [92.46499634, 10.86500072], [92.46555328, 10.86555862], [92.4658432, 10.86555862], [92.46646118, 10.86618423], [92.46666718, 10.86638927], [92.46694183, 10.86638927], [92.46721649, 10.86667156], [92.46778107, 10.86666679], [92.46805573, 10.86694527], [92.46833038, 10.86694527], [92.46944427, 10.86805534], [92.46944427, 10.86833286], [92.46971893, 10.86861134], [92.46971893, 10.86888885], [92.47000122, 10.86916733], [92.47000122, 10.86944485], [92.47027588, 10.86970997], [92.47027588, 10.87000179], [92.47000885, 10.87047958], [92.46994019, 10.87095928], [92.46994019, 10.8712368], [92.47014618, 10.87151337], [92.47037506, 10.87157917], [92.47062683, 10.87165165], [92.47104645, 10.87144184], [92.47154236, 10.8712368], [92.47194672, 10.87111092], [92.47222137, 10.8708334], [92.47389221, 10.8708334], [92.47416687, 10.87111092], [92.47497559, 10.8710804], [92.47573853, 10.87094307], [92.47629547, 10.87080383], [92.47748566, 10.87080383], [92.47797394, 10.8708744], [92.47831726, 10.87101078], [92.47859955, 10.87111092], [92.47888947, 10.87111092], [92.47915649, 10.87139034], [92.47944641, 10.87139034], [92.48027802, 10.87222099], [92.48027802, 10.87249947], [92.48306274, 10.87528038], [92.48306274, 10.87555981], [92.48332977, 10.87584114], [92.48332977, 10.8763876], [92.48361206, 10.87666798], [92.48361206, 10.87694359], [92.48388672, 10.87722206], [92.48388672, 10.87749958], [92.48610687, 10.87971973], [92.4861145, 10.88000011], [92.48666382, 10.88055611], [92.48665619, 10.88083172], [92.48722076, 10.88138771], [92.48764038, 10.88172531], [92.48792267, 10.88206959], [92.48826599, 10.88241577], [92.48861694, 10.88310909], [92.48874664, 10.88352108], [92.48883057, 10.88408184], [92.48910522, 10.88456059], [92.48916626, 10.88500118], [92.48944092, 10.8852787], [92.48944092, 10.88555431], [92.4908371, 10.88694477], [92.4908371, 10.88722038], [92.49138641, 10.88778114], [92.49138641, 10.88807106], [92.49250031, 10.88917065], [92.49277496, 10.88916683], [92.49305725, 10.8894453], [92.4936142, 10.8894453], [92.49388885, 10.88972282], [92.4944458, 10.88972282], [92.49514008, 10.88992977], [92.49694824, 10.8900013], [92.4972229, 10.89021111], [92.49749756, 10.89028072], [92.4980545, 10.89041805], [92.4991684, 10.89055538], [92.49951172, 10.89069366], [92.49973297, 10.8906889], [92.50006866, 10.89077091], [92.50035095, 10.89077091], [92.50055695, 10.89083958], [92.50138855, 10.8908329], [92.50164032, 10.89088345], [92.5017395, 10.89090347], [92.50228882, 10.89090347], [92.50250244, 10.8908329], [92.5027771, 10.89083958], [92.50305176, 10.8905592], [92.50332642, 10.8905592], [92.5036087, 10.89028072], [92.50389099, 10.89028072], [92.50499725, 10.88917065], [92.50499725, 10.88822079], [92.50502014, 10.88705158], [92.50508881, 10.88634968], [92.5052948, 10.88518143], [92.50543213, 10.88435078], [92.50583649, 10.88333035], [92.50583649, 10.88277817], [92.50611115, 10.88249969], [92.50611115, 10.88222027], [92.5063858, 10.8819437], [92.5063858, 10.88166618], [92.5083313, 10.87972164], [92.50861359, 10.87972164], [92.50888824, 10.87944412], [92.5091629, 10.87944412], [92.50971985, 10.87889004], [92.51000214, 10.87890244], [92.5111084, 10.87812042], [92.51145935, 10.87750435], [92.51145935, 10.87695122], [92.51139069, 10.87584496], [92.51132202, 10.87487698], [92.5112381, 10.8737011], [92.5111084, 10.87249947], [92.51083374, 10.87222099], [92.51083374, 10.87194347], [92.51079559, 10.87118435], [92.51037598, 10.87063122], [92.50975037, 10.87000847], [92.50891113, 10.86966419], [92.50821686, 10.86980057], [92.50744629, 10.87022018], [92.50688934, 10.87090874], [92.50577545, 10.87145996], [92.50473022, 10.87208176], [92.50395966, 10.87256622], [92.50308228, 10.87274075], [92.50256348, 10.87284374], [92.50270844, 10.87242889], [92.50333405, 10.87194347], [92.50444794, 10.8708334], [92.5047226, 10.8708334], [92.50499725, 10.87055492], [92.50527191, 10.87055969], [92.50583649, 10.87000179], [92.50611115, 10.87000179], [92.5063858, 10.86970997], [92.50666809, 10.86972332], [92.50694275, 10.86944485], [92.50722504, 10.86944485], [92.50777435, 10.86888885], [92.50805664, 10.86889172], [92.5083313, 10.86861134], [92.50945282, 10.86861134], [92.50971985, 10.86889172], [92.51000214, 10.86889172], [92.51027679, 10.86917019], [92.51055908, 10.86917019], [92.51139069, 10.86999893], [92.51139069, 10.8702774], [92.51167297, 10.87063122], [92.51187134, 10.87105179], [92.51222229, 10.8715992], [92.51222229, 10.87305641], [92.51249695, 10.87333393], [92.51249695, 10.8736124], [92.51277924, 10.87388992], [92.51277924, 10.87444401], [92.5128479, 10.87472153], [92.51277924, 10.87576294], [92.51277924, 10.87611198], [92.51256561, 10.87743187], [92.51222229, 10.87805557], [92.51194, 10.87833405], [92.51069641, 10.87965107], [92.51027679, 10.88000011], [92.50992584, 10.88014126], [92.50971985, 10.88027763], [92.5083313, 10.88166618], [92.5083313, 10.88222027], [92.50805664, 10.88249969], [92.50782776, 10.88285828], [92.50769043, 10.88341236], [92.50769043, 10.88396358], [92.50762177, 10.88486385], [92.50740814, 10.88555431], [92.50699615, 10.88652325], [92.50678253, 10.88748932], [92.50678253, 10.88942432], [92.50694275, 10.88972282], [92.50723267, 10.8900013], [92.50723267, 10.89028072], [92.50749969, 10.8905592], [92.50749969, 10.89083958], [92.50805664, 10.89138889], [92.50805664, 10.89166737], [92.5083313, 10.89194489], [92.5083313, 10.89222145], [92.50860596, 10.89250088], [92.50860596, 10.89277935], [92.50888824, 10.89305496], [92.50888824, 10.89361095], [92.5091629, 10.89388943], [92.5091629, 10.89416695], [92.50944519, 10.89444542], [92.50944519, 10.89472103], [92.50997925, 10.89526081], [92.51027679, 10.89556026], [92.51055908, 10.89556026], [92.51139832, 10.89639187], [92.51166534, 10.89638901], [92.51222229, 10.89694309], [92.51277924, 10.89694309], [92.51288605, 10.89705276], [92.51305389, 10.89722443], [92.51361084, 10.89722443], [92.51403046, 10.89743137], [92.51499939, 10.89750195], [92.51541901, 10.89770889], [92.51583099, 10.89764118], [92.51611328, 10.89750195], [92.51638794, 10.89750195], [92.51667023, 10.89722061], [92.52027893, 10.89722443], [92.52055359, 10.89694309], [92.52111053, 10.89694309], [92.52305603, 10.89500141], [92.52305603, 10.89472103], [92.52639008, 10.89138889], [92.5266571, 10.89138889], [92.52777863, 10.89028072], [92.52777863, 10.8900013], [92.52805328, 10.88972282], [92.52805328, 10.8894453], [92.52833557, 10.88916683], [92.52833557, 10.88888931], [92.52889252, 10.88833046], [92.52889252, 10.88805676], [92.52999878, 10.88694477], [92.52999878, 10.88666725], [92.53006744, 10.88632011], [92.53006744, 10.88597393], [92.52979279, 10.8852787], [92.52944183, 10.88500118], [92.52889252, 10.88444424], [92.52889252, 10.88388824], [92.52840424, 10.883214], [92.52832794, 10.88265991], [92.52832794, 10.88190079], [92.52889252, 10.88111019], [92.52889252, 10.88083363], [92.52916718, 10.88055611], [92.52916718, 10.88027763], [92.52944183, 10.88000011], [92.52944183, 10.87971973], [92.52999878, 10.87916565], [92.52999878, 10.87777805], [92.53028107, 10.87749958], [92.53028107, 10.87722015], [92.53166962, 10.87583447], [92.53197479, 10.87480831], [92.53196716, 10.87419128], [92.53161621, 10.87322044], [92.53099823, 10.87217999], [92.53044128, 10.871768], [92.52953339, 10.87100697], [92.52897644, 10.8703804], [92.52848816, 10.86927891], [92.52841949, 10.86858845], [92.52855682, 10.86776066], [92.52889252, 10.86694145], [92.52889252, 10.86666679], [92.53028107, 10.8652792], [92.53056335, 10.8652792], [92.53083038, 10.86500072], [92.53138733, 10.86500072], [92.53183746, 10.86474991], [92.53239441, 10.86475277], [92.53281403, 10.8646841], [92.53337097, 10.86482143], [92.53421021, 10.8652401], [92.5351181, 10.86531067], [92.53588104, 10.86531067], [92.53623199, 10.86516953], [92.53651428, 10.86530685], [92.5369339, 10.86565304], [92.53694916, 10.86610413], [92.53648376, 10.86619473], [92.53578949, 10.86619473], [92.5345993, 10.86612701], [92.53390503, 10.86584854], [92.53292847, 10.86571026], [92.53173828, 10.86578083], [92.53074646, 10.86619091], [92.53013611, 10.8667469], [92.52978516, 10.8675766], [92.52971649, 10.8684063], [92.52986145, 10.86902809], [92.52999878, 10.86944485], [92.53028107, 10.86970997], [92.53028107, 10.86999893], [92.53277588, 10.87249947], [92.53308868, 10.87311268], [92.53330231, 10.87387371], [92.53337097, 10.87456036], [92.53308105, 10.87512016], [92.5328064, 10.87574005], [92.53196716, 10.87718964], [92.53166962, 10.87749958], [92.53166962, 10.87777805], [92.53138733, 10.87805557], [92.53138733, 10.87833405], [92.53111267, 10.87861156], [92.53111267, 10.87916565], [92.53166962, 10.87972164], [92.53166962, 10.88111019], [92.53138733, 10.88138771], [92.53138733, 10.88166618], [92.53083038, 10.88222027], [92.53083038, 10.88249969], [92.53056335, 10.88278103], [92.53028107, 10.88278103], [92.52999878, 10.88306141], [92.52972412, 10.88305569], [92.52944183, 10.88333035], [92.52964783, 10.88395882], [92.52999878, 10.88416576], [92.53034973, 10.88458061], [92.53076172, 10.88465214], [92.53152466, 10.88493156], [92.53166962, 10.88500118], [92.53194427, 10.88500118], [92.53221893, 10.88471985], [92.53250122, 10.88472176], [92.53277588, 10.88444424], [92.53305817, 10.88444424], [92.53333282, 10.88416576], [92.5341568, 10.88417053], [92.53444672, 10.88389111], [92.53499603, 10.88389111], [92.53527832, 10.88360977], [92.53555298, 10.88360977], [92.53583527, 10.88333225], [92.53610992, 10.88333225], [92.53666687, 10.88277817], [92.53694153, 10.88278103], [92.53943634, 10.88027954], [92.53971863, 10.88027954], [92.54083252, 10.87917042], [92.54083252, 10.87890244], [92.54277802, 10.87694073], [92.54277802, 10.87666798], [92.54305267, 10.8763876], [92.54332733, 10.87639046], [92.54332733, 10.87611198], [92.54416656, 10.87528038], [92.54471588, 10.87528038], [92.54611206, 10.87389183], [92.54611206, 10.87360859], [92.54666901, 10.87305641], [92.54666901, 10.87277794], [92.54750824, 10.87194061], [92.54777527, 10.87194347], [92.54833221, 10.87139034], [92.54972076, 10.87139034], [92.55000305, 10.87111092], [92.55083466, 10.87111092], [92.55278015, 10.86917019], [92.55278015, 10.86889172], [92.55361176, 10.86806202], [92.55361176, 10.86778164], [92.5541687, 10.86722088], [92.55444336, 10.86722088], [92.55666351, 10.86499882], [92.55687714, 10.86479378], [92.5577774, 10.86382103], [92.55805206, 10.86361122], [92.55833435, 10.86333275], [92.55833435, 10.86305523], [92.55860901, 10.86277676], [92.55860901, 10.86250114], [92.5588913, 10.86222267], [92.5588913, 10.86166668], [92.55916595, 10.86138916], [92.55916595, 10.86111069], [92.55944824, 10.86083317], [92.55944824, 10.86028099], [92.5597229, 10.86000061], [92.5597229, 10.85917091], [92.55999756, 10.85889053], [92.55999756, 10.85861015], [92.5597229, 10.85833454], [92.5597229, 10.85750008], [92.55944824, 10.8572216], [92.55944824, 10.85694408], [92.55916595, 10.85666561], [92.55916595, 10.85638809], [92.55832672, 10.85556126], [92.55832672, 10.85528088], [92.5577774, 10.85471058], [92.5577774, 10.85444355], [92.55750275, 10.85416603], [92.55750275, 10.85111237], [92.55722046, 10.85083389], [92.55722046, 10.85055637], [92.5569458, 10.8502779], [92.5569458, 10.84972191], [92.55666351, 10.84944439], [92.55666351, 10.84916782], [92.55638885, 10.8488903], [92.55654144, 10.84527111], [92.55666351, 10.84409714], [92.5569458, 10.84388924], [92.5569458, 10.84333134], [92.55750275, 10.84277725], [92.55750275, 10.84222126], [92.5577774, 10.84194469], [92.5577774, 10.8413887], [92.55805206, 10.84111118], [92.55805206, 10.84000111], [92.55833435, 10.83972263], [92.55832672, 10.8394413], [92.55860901, 10.83916664], [92.55860901, 10.83888912], [92.5588913, 10.83861065], [92.5588913, 10.83833313], [92.55916595, 10.83805466], [92.55916595, 10.83777905], [92.55944824, 10.83750057], [92.55944824, 10.83667088], [92.5597229, 10.83639145], [92.5597229, 10.83611107], [92.55999756, 10.8358326], [92.55999756, 10.8352766], [92.56027985, 10.83500099], [92.56027985, 10.83444023], [92.5605545, 10.83416653], [92.5605545, 10.83277893], [92.56083679, 10.83250141], [92.56083679, 10.83194542], [92.56111145, 10.83166599], [92.56111145, 10.83138847], [92.56138611, 10.83111], [92.56138611, 10.83083153], [92.56194305, 10.8302784], [92.56194305, 10.82999992], [92.56305695, 10.82888985], [92.56305695, 10.82833195], [92.5633316, 10.82805634], [92.5633316, 10.82722187], [92.56305695, 10.82694435], [92.56305695, 10.82666588], [92.5625, 10.82610989], [92.56250763, 10.82583046], [92.56222534, 10.8255558], [92.56194305, 10.82527828], [92.56194305, 10.82473087], [92.56138611, 10.82417011], [92.56138611, 10.82361031], [92.56111145, 10.82333374], [92.56138611, 10.82305622], [92.56111145, 10.82277775], [92.56111145, 10.8208313], [92.56083679, 10.82055569], [92.56111145, 10.82027817], [92.56111145, 10.81917], [92.56138611, 10.81888962], [92.56138611, 10.81805992], [92.5616684, 10.81777954], [92.5616684, 10.81694126], [92.56194305, 10.8166666], [92.56194305, 10.81444454], [92.5616684, 10.81416702], [92.5616684, 10.81361103], [92.56138611, 10.81333256], [92.56138611, 10.81194496], [92.5616684, 10.81166744], [92.5616684, 10.81138897], [92.56194305, 10.81111145], [92.56194305, 10.81083298], [92.56222534, 10.81055546], [92.56222534, 10.81027889], [92.56276703, 10.80972099], [92.56277466, 10.80944538], [92.5644455, 10.8077774], [92.5644455, 10.80750084], [92.56472015, 10.80722046], [92.56472015, 10.80611134], [92.56361389, 10.80500126], [92.56288147, 10.80494785], [92.56273651, 10.80481052], [92.56253815, 10.80445957], [92.56176758, 10.80391121], [92.56121063, 10.80363464], [92.56059265, 10.80350113], [92.56030273, 10.80425835], [92.56023407, 10.80488014], [92.56016541, 10.8053627], [92.56009674, 10.80605412], [92.55981445, 10.80570889], [92.55967712, 10.80501747], [92.55974579, 10.80426025], [92.55995941, 10.8035717], [92.56022644, 10.80294037], [92.56023407, 10.80176926], [92.5603714, 10.80121708], [92.56051636, 10.8008709], [92.56079102, 10.80066109], [92.5610733, 10.80038548], [92.56134796, 10.8002491], [92.56169891, 10.80031681], [92.56183624, 10.80052376], [92.56176758, 10.8008709], [92.56183624, 10.80135441], [92.56176758, 10.80204678], [92.56163025, 10.80273724], [92.56162262, 10.80301094], [92.56183624, 10.80328941], [92.56204987, 10.80356693], [92.56268311, 10.80377197], [92.56315613, 10.80398178], [92.5637207, 10.80412102], [92.56420898, 10.80420113], [92.56449127, 10.80398178], [92.56500244, 10.80361938], [92.5652771, 10.80361938], [92.56555176, 10.80333042], [92.56583405, 10.80333233], [92.5661087, 10.80305576], [92.56667328, 10.80306053], [92.56694794, 10.80278111], [92.56833649, 10.80278111], [92.56861115, 10.80249977], [92.57026672, 10.80249977], [92.57055664, 10.80278111], [92.57195282, 10.80278111], [92.57332611, 10.80138969], [92.57332611, 10.80111027], [92.5736084, 10.8008337], [92.5736084, 10.80055618], [92.57389069, 10.80027771], [92.57389069, 10.79972172], [92.57416534, 10.7994442], [92.57416534, 10.79805565], [92.57444763, 10.79777813], [92.57444763, 10.79749107], [92.57472229, 10.79722214], [92.57479095, 10.79666805], [92.57861328, 10.79277802], [92.5790863, 10.79249954], [92.57937622, 10.79236317], [92.57965088, 10.79222393], [92.58000183, 10.79201412], [92.58034515, 10.79187679], [92.58110809, 10.79168129], [92.58132172, 10.79152203], [92.58166504, 10.79139042], [92.58187103, 10.79125118], [92.58222198, 10.79111195], [92.58257294, 10.79083347], [92.58305359, 10.790555], [92.58333588, 10.79055977], [92.58361816, 10.79028034], [92.58444214, 10.79028034], [92.5847168, 10.79000187], [92.58528137, 10.79000187], [92.58708191, 10.7881918], [92.58750153, 10.78750134], [92.58770752, 10.78694534], [92.58777618, 10.78638744], [92.58777618, 10.78583336], [92.58784485, 10.78555489], [92.58791351, 10.78534794], [92.58784485, 10.78513813], [92.58777618, 10.78472137], [92.58777618, 10.78166676], [92.58805847, 10.78138924], [92.58805847, 10.77943134], [92.58833313, 10.77916718], [92.58805847, 10.7788887], [92.58805847, 10.77806091], [92.58777618, 10.77778053], [92.58777618, 10.77721977], [92.58750153, 10.77694416], [92.58750153, 10.77555561], [92.58721924, 10.77527809], [92.58721924, 10.77444172], [92.58694458, 10.77416611], [92.58694458, 10.77305603], [92.58667755, 10.77278042], [92.58667755, 10.77055073], [92.58694458, 10.77027798], [92.58694458, 10.76944447], [92.58638763, 10.76888847], [92.58638763, 10.76833439], [92.58555603, 10.76749992], [92.58555603, 10.76638985], [92.58528137, 10.76610947], [92.58528137, 10.76472092], [92.58499908, 10.7644434], [92.58499908, 10.76361084], [92.5847168, 10.76333141], [92.58472443, 10.76305485], [92.58444214, 10.76277733], [92.58444214, 10.76250172], [92.58416748, 10.76222134], [92.58416748, 10.76194477], [92.58388519, 10.76166725], [92.58388519, 10.76055527], [92.58361816, 10.76028156], [92.58361816, 10.75916862], [92.58333588, 10.7588892], [92.58333588, 10.75778103], [92.58361816, 10.75750065], [92.58361816, 10.75639057], [92.58333588, 10.75611115], [92.58333588, 10.75583267], [92.58361053, 10.75555515], [92.58361053, 10.7547226], [92.58347321, 10.75437641], [92.58361053, 10.75235939], [92.58354187, 10.75194454], [92.58361053, 10.75166702], [92.58347321, 10.75124931], [92.58354187, 10.75035095], [92.58333588, 10.74840069], [92.58305359, 10.74750042], [92.5828476, 10.74660015], [92.58257294, 10.74549007], [92.58277893, 10.74250031], [92.58305359, 10.74222183], [92.58305359, 10.74194431], [92.58333588, 10.74166584], [92.58333588, 10.74111176], [92.58361053, 10.74083424], [92.58361053, 10.74055576], [92.58388519, 10.74027824], [92.58409882, 10.74014091], [92.5845108, 10.73971939], [92.58472443, 10.73944569], [92.58499908, 10.73916531], [92.58499908, 10.73888969], [92.58528137, 10.73860931], [92.58528137, 10.7383337], [92.58555603, 10.73805618], [92.58555603, 10.73777676], [92.58583069, 10.73751068], [92.58583069, 10.73721886], [92.58611298, 10.73694324], [92.58611298, 10.73638916], [92.58638763, 10.73611069], [92.58638763, 10.73583317], [92.58694458, 10.73527718], [92.58694458, 10.7349987], [92.58777618, 10.73417187], [92.58777618, 10.73389244], [92.58805847, 10.73361111], [92.58805847, 10.73249912], [92.58833313, 10.73194504], [92.58833313, 10.73166656], [92.58867645, 10.73055458], [92.58860779, 10.72861099], [92.58860779, 10.72806168], [92.58860779, 10.72527885], [92.58867645, 10.72472], [92.58889008, 10.72360992], [92.58916473, 10.72333241], [92.58916473, 10.72166634], [92.58944702, 10.72138786], [92.58944702, 10.72056103], [92.58972168, 10.72028065], [92.58972168, 10.71889019], [92.58999634, 10.71861172], [92.58999634, 10.71778011], [92.59027863, 10.71749973], [92.59027863, 10.71722031], [92.59194183, 10.71555614], [92.59194183, 10.71500015], [92.59222412, 10.71472168], [92.59222412, 10.71389008], [92.59249878, 10.7136097], [92.59249115, 10.71249962], [92.59278107, 10.71221924], [92.59278107, 10.71138954], [92.59333038, 10.71083355], [92.59401703, 10.70987415], [92.59450531, 10.70932198], [92.59548187, 10.708354], [92.59590912, 10.70796871], [92.59666443, 10.70728016], [92.59687805, 10.70700455], [92.59736633, 10.70631409], [92.597435, 10.70610714], [92.59757233, 10.70472527], [92.59799194, 10.703825], [92.5982666, 10.70313454], [92.5982666, 10.70237255], [92.59841156, 10.70140743], [92.59848022, 10.70036983], [92.59848022, 10.69982147], [92.5983429, 10.69899082], [92.59799194, 10.69781113], [92.59784698, 10.69715595], [92.59784698, 10.69639683], [92.59744263, 10.69522095], [92.59729004, 10.69449711], [92.5969162, 10.69414139], [92.59684753, 10.69365788], [92.59671021, 10.69283104], [92.5969162, 10.69234085], [92.59705353, 10.69158363], [92.59726715, 10.69089127], [92.59726715, 10.6893034], [92.59740448, 10.68847275], [92.59747314, 10.68758869], [92.59747314, 10.68586063], [92.59754181, 10.68482399], [92.5976181, 10.68309593], [92.5976181, 10.68205929], [92.59754181, 10.68144035], [92.59733582, 10.68094921], [92.59726715, 10.68019295], [92.59705353, 10.67950153], [92.5969162, 10.67887974], [92.59677887, 10.67832565], [92.59642029, 10.67776966], [92.59566498, 10.6772213], [92.59461975, 10.67687416], [92.59361267, 10.67694473], [92.59333038, 10.67706966], [92.59249115, 10.67723179], [92.59221649, 10.67750072], [92.59194183, 10.67750072], [92.59166718, 10.6777792], [92.59139252, 10.6777792], [92.59111023, 10.67784977], [92.59055328, 10.67805481], [92.58916473, 10.67909908], [92.58889008, 10.67944527], [92.58853912, 10.67951584], [92.58757019, 10.67957973], [92.58730316, 10.67959118], [92.58687592, 10.67959118], [92.58673859, 10.67951107], [92.58625031, 10.67944527], [92.58611298, 10.67944527], [92.58548737, 10.67923832], [92.58499908, 10.67916679], [92.5847168, 10.6791687], [92.58444214, 10.67888927], [92.58416748, 10.67888927], [92.58389282, 10.67860889], [92.58361053, 10.6786108], [92.58277893, 10.6777792], [92.58277893, 10.67749882], [92.58249664, 10.67723179], [92.58222198, 10.67723179], [92.58202362, 10.67702484], [92.58194733, 10.67694473], [92.58139038, 10.67694473], [92.58110809, 10.67666721], [92.58082581, 10.67667198], [92.57943726, 10.67528057], [92.57888794, 10.67528057], [92.57833099, 10.6747179], [92.57805634, 10.67472267], [92.57722473, 10.67388916], [92.57722473, 10.6730547], [92.57639313, 10.67222023], [92.5763855, 10.6716671], [92.57624817, 10.67129517], [92.57589722, 10.67080975], [92.57589722, 10.6703949], [92.57596588, 10.66963577], [92.57611084, 10.66894341], [92.5761795, 10.66832066], [92.57631683, 10.6678381], [92.57666779, 10.66721535], [92.57681274, 10.66625118], [92.57694244, 10.66582966], [92.57694244, 10.66527843], [92.57722473, 10.66499996], [92.5772171, 10.66471958], [92.57749939, 10.66444397], [92.57749939, 10.66416645], [92.57805634, 10.66361237], [92.57802582, 10.66290283], [92.57802582, 10.66262531], [92.57795715, 10.66193485], [92.57802582, 10.66137886], [92.57809448, 10.66048336], [92.57823181, 10.65999985], [92.5785141, 10.65944576], [92.57865143, 10.65876198], [92.57892609, 10.65819931], [92.57949066, 10.65820408], [92.57962799, 10.65827179], [92.58004761, 10.65868664], [92.58053589, 10.65882587], [92.5807724, 10.65895557], [92.5811615, 10.65917015], [92.58158112, 10.65910244], [92.58220673, 10.65882587], [92.58248901, 10.65861893], [92.58255768, 10.65841103], [92.5827713, 10.65785027], [92.58297729, 10.65737438], [92.58290863, 10.6570282], [92.58255768, 10.65689087], [92.58228302, 10.6568203], [92.58193207, 10.65696239], [92.58165741, 10.65689087], [92.58138275, 10.6568203], [92.58083344, 10.65645981], [92.58027649, 10.65583324], [92.58000183, 10.65583324], [92.57987976, 10.65571308], [92.57944489, 10.65527725], [92.57944489, 10.65499878], [92.57861328, 10.65417194], [92.57833099, 10.65417194], [92.57805634, 10.65389156], [92.57776642, 10.65389156], [92.57749176, 10.65361118], [92.57722473, 10.65361118], [92.57694244, 10.65333271], [92.57666779, 10.65333271], [92.5763855, 10.65305519], [92.57601929, 10.65284824], [92.57546997, 10.65285015], [92.57491302, 10.65271091], [92.57441711, 10.65278244], [92.57392883, 10.65292072], [92.57253265, 10.65291595], [92.57211304, 10.65312576], [92.57138824, 10.65305519], [92.57111359, 10.65277672], [92.57055664, 10.65278244], [92.57026672, 10.6524992], [92.56999969, 10.6524992], [92.56916809, 10.65166664], [92.5688858, 10.65166855], [92.56833649, 10.65111065], [92.56804657, 10.65111065], [92.56784821, 10.65090561], [92.56777954, 10.65083122], [92.56694794, 10.65083313], [92.56666565, 10.65055466], [92.56639099, 10.65056038], [92.56582642, 10.65000057], [92.56555176, 10.65000057], [92.56472015, 10.64917183], [92.56445313, 10.64917183], [92.56426239, 10.64898682], [92.56416321, 10.64889145], [92.56416321, 10.64861107], [92.56388855, 10.6483326], [92.56388855, 10.64805698], [92.56361389, 10.6477766], [92.5633316, 10.64778137], [92.56250763, 10.64693069], [92.56222534, 10.646945], [92.5616684, 10.64638901], [92.56138611, 10.64639091], [92.56083679, 10.64583015], [92.56083679, 10.64555454], [92.55944824, 10.64416695], [92.55916595, 10.64395905], [92.5579834, 10.64291477], [92.55764008, 10.64270782], [92.55708313, 10.64215183], [92.5569458, 10.64194393], [92.55583191, 10.64083195], [92.55388641, 10.63889027], [92.55361176, 10.63860989], [92.55271149, 10.63784885], [92.55249786, 10.63750172], [92.55194092, 10.63694191], [92.55194092, 10.6366663], [92.55110931, 10.63583374], [92.55110931, 10.63555622], [92.55027771, 10.63472176], [92.55027771, 10.63444424], [92.54972076, 10.63389015], [92.54972076, 10.63361168], [92.54916382, 10.63305569], [92.54915619, 10.63278008], [92.54860687, 10.63221931], [92.5486145, 10.6319437], [92.54805756, 10.63138962], [92.54805756, 10.6311121], [92.54777527, 10.63083363], [92.54777527, 10.63055611], [92.54722595, 10.62999916], [92.54722595, 10.62972069], [92.54694366, 10.62944317], [92.54694366, 10.62916756], [92.54666901, 10.62888908], [92.54666901, 10.62861061], [92.54611206, 10.62805462], [92.5460434, 10.6277771], [92.54582977, 10.62758064], [92.54556274, 10.62722111], [92.54555511, 10.62680626], [92.54534149, 10.62631893], [92.54506683, 10.62583065], [92.54444122, 10.62500381], [92.54423523, 10.62437534], [92.54416656, 10.62416744], [92.54416656, 10.62388897], [92.54360962, 10.62333107], [92.54360962, 10.62305546], [92.54333496, 10.62277699], [92.54333496, 10.62250137], [92.54305267, 10.62222099], [92.54305267, 10.62166691], [92.54277802, 10.62138939], [92.54277802, 10.62111092], [92.54250336, 10.6208334], [92.54250336, 10.61972332], [92.54222107, 10.61944485], [92.54222107, 10.61916733], [92.54194641, 10.61888885], [92.54194641, 10.61861134], [92.54138947, 10.61805439], [92.54138947, 10.61750126], [92.54110718, 10.61721992], [92.54111481, 10.61638832], [92.54083252, 10.61610985], [92.54083252, 10.61472225], [92.54055786, 10.61444378], [92.54055786, 10.61388779], [92.54027557, 10.61361027], [92.54027557, 10.61305618], [92.54000092, 10.61277771], [92.54000092, 10.61250019], [92.54006958, 10.61229134], [92.54006958, 10.61173439], [92.54000092, 10.61139011], [92.54000092, 10.61081791], [92.53979492, 10.61055565], [92.53993225, 10.60999966], [92.54000092, 10.60972023], [92.54000092, 10.60861206], [92.53985596, 10.60833359], [92.53985596, 10.6077776], [92.54000092, 10.60750008], [92.54000092, 10.60472202], [92.54027557, 10.6044426], [92.54027557, 10.60333443], [92.54055786, 10.603055], [92.54055786, 10.6016674], [92.54083252, 10.60139179], [92.54083252, 10.60056019], [92.54138184, 10.60000134], [92.54138184, 10.59944057], [92.54194641, 10.59888935], [92.54194641, 10.59861088], [92.54222107, 10.59833336], [92.54222107, 10.59805489], [92.54256439, 10.59715271], [92.54305267, 10.5961113], [92.54333496, 10.59583282], [92.54333496, 10.59555531], [92.54360962, 10.59527683], [92.54360962, 10.59500122], [92.54389191, 10.59472084], [92.54389191, 10.59444523], [92.54416656, 10.59416676], [92.54416656, 10.59388924], [92.54444122, 10.5936079], [92.54444122, 10.59333324], [92.54555511, 10.59222317], [92.54714966, 10.59201527], [92.54777527, 10.59194469], [92.54853821, 10.59166908], [92.54888916, 10.59167099], [92.54915619, 10.59167099], [92.54972076, 10.59111118], [92.55027771, 10.59111118], [92.55055237, 10.59083462], [92.55110931, 10.59083462], [92.5513916, 10.59055424], [92.55222321, 10.59056091], [92.55249786, 10.59028053], [92.55304718, 10.59028053], [92.5533371, 10.59000969], [92.55361176, 10.59000969], [92.55388641, 10.58971977], [92.5541687, 10.58972263], [92.55444336, 10.58944416], [92.55472565, 10.58944416], [92.55500031, 10.58916569], [92.55555725, 10.58917141], [92.55583191, 10.58889103], [92.55638123, 10.58882046], [92.55665588, 10.5886097], [92.55700684, 10.58854198], [92.55722046, 10.5886097], [92.55757141, 10.58868122], [92.55791473, 10.58868122], [92.55840302, 10.5886097], [92.55944824, 10.58826637], [92.55999756, 10.58806133], [92.56054688, 10.58806133], [92.56104279, 10.58778095], [92.5616684, 10.58749962], [92.56285095, 10.58722019], [92.5633316, 10.58694363], [92.56388855, 10.58687592], [92.56416321, 10.58666611], [92.56445313, 10.58631992], [92.5661087, 10.58443928], [92.56652832, 10.58430481], [92.56777954, 10.58291721], [92.56804657, 10.58250046], [92.56916809, 10.58139038], [92.56916809, 10.58111191], [92.56944275, 10.58083439], [92.56944275, 10.57888985], [92.56916809, 10.57860947], [92.56916809, 10.57833385], [92.5688858, 10.57805634], [92.5688858, 10.57750034], [92.56861115, 10.57722092], [92.56861115, 10.57666779], [92.56833649, 10.57639027], [92.56833649, 10.57611179], [92.5661087, 10.57389164], [92.5661087, 10.57361126], [92.56583405, 10.57333279], [92.56583405, 10.57305527], [92.5652771, 10.57249928], [92.5652771, 10.5722208], [92.56472015, 10.57166672], [92.56472015, 10.5713892], [92.56388855, 10.57056046], [92.56388855, 10.57028198], [92.56360626, 10.57000065], [92.56360626, 10.56972122], [92.56138611, 10.56750107], [92.56138611, 10.5672226], [92.56083679, 10.5666666], [92.55996704, 10.56476116], [92.55899048, 10.56337833], [92.55846405, 10.56198311], [92.55762482, 10.56136131], [92.55636597, 10.56053066], [92.55574036, 10.55976963], [92.55483246, 10.55908012], [92.55462646, 10.55852985], [92.55442047, 10.55796146], [92.55406952, 10.55714512], [92.55302429, 10.55624676], [92.55155945, 10.55576134], [92.55083466, 10.55527782], [92.55055237, 10.55500031], [92.55027771, 10.55500031], [92.55000305, 10.55472183], [92.5486145, 10.55472183], [92.54805756, 10.55416584], [92.5477829, 10.55416965], [92.54764557, 10.55403423], [92.54750061, 10.55389023], [92.54750824, 10.55360985], [92.54638672, 10.55249977], [92.54638672, 10.55222225], [92.54582977, 10.55166626], [92.54582977, 10.55138969], [92.54556274, 10.55110931], [92.54555511, 10.55055618], [92.54528046, 10.55027771], [92.54528046, 10.54971886], [92.54499817, 10.54944324], [92.54499817, 10.54777718], [92.54472351, 10.5474987], [92.54472351, 10.54583263], [92.54444122, 10.54555511], [92.54444122, 10.54444313], [92.54416656, 10.54416656], [92.54416656, 10.54339504], [92.54386139, 10.5430479], [92.54371643, 10.54201126], [92.54302216, 10.54055882], [92.54239655, 10.53952217], [92.54204559, 10.53876305], [92.54179382, 10.5380249], [92.5415802, 10.53754234], [92.54123688, 10.53664398], [92.54081726, 10.53595257], [92.54009247, 10.53558445], [92.53995514, 10.53544521], [92.53842163, 10.53516865], [92.53807068, 10.53503036], [92.5373764, 10.53427124], [92.53695679, 10.53364658], [92.53653717, 10.53261185], [92.53639984, 10.53205776], [92.53598022, 10.53130054], [92.53562927, 10.5304718], [92.53494263, 10.52991962], [92.5341568, 10.5296402], [92.53396606, 10.52896118], [92.53367615, 10.52806091], [92.53367615, 10.52764606], [92.53388977, 10.52674961], [92.53437042, 10.52610016], [92.53437042, 10.52560997], [92.53443909, 10.52505875], [92.53423309, 10.52443886], [92.53408813, 10.52340031], [92.53401184, 10.52299881], [92.53387451, 10.5225153], [92.53351593, 10.52203178], [92.53304291, 10.52133942], [92.53268433, 10.52071667], [92.53240967, 10.52030468], [92.53205872, 10.51981926], [92.53177643, 10.5189209], [92.53135681, 10.51844025], [92.53093719, 10.51816177], [92.53028107, 10.51779079], [92.52999878, 10.51779079], [92.52971649, 10.51750088], [92.52916718, 10.51750088], [92.52907562, 10.51740837], [92.52889252, 10.51722336], [92.52861023, 10.51722336], [92.52833557, 10.51694489], [92.52805328, 10.51694489], [92.52732086, 10.51721191], [92.52648163, 10.51721191], [92.52571869, 10.51700687], [92.52529907, 10.51686764], [92.5245285, 10.51631165], [92.52383423, 10.51583099], [92.52334595, 10.51555538], [92.52230072, 10.51513958], [92.52104187, 10.51465702], [92.52083588, 10.51443958], [92.5203476, 10.51409912], [92.51972198, 10.51417065], [92.51922607, 10.51375198], [92.51860809, 10.51361084], [92.51750183, 10.51361084], [92.51721191, 10.51333046], [92.51694489, 10.51333332], [92.51667023, 10.51305485], [92.51611328, 10.51306152], [92.51555634, 10.51249886], [92.51472473, 10.51250076], [92.51444244, 10.51222324], [92.51361084, 10.51222324], [92.51305389, 10.51166725], [92.51249695, 10.51166725], [92.51222229, 10.51194477], [92.51083374, 10.51194477], [92.51055908, 10.51222324], [92.50971985, 10.51222324], [92.50944519, 10.51250076], [92.5091629, 10.51222324], [92.50805664, 10.51222324], [92.50777435, 10.51194477], [92.50722504, 10.51194477], [92.50694275, 10.51166725], [92.5063858, 10.51166725], [92.50611115, 10.51138878], [92.50534821, 10.51139069], [92.50527191, 10.51111126], [92.50369263, 10.51090336], [92.50083923, 10.51090527], [92.49903107, 10.51118088], [92.49812317, 10.51187611], [92.49777985, 10.51222324], [92.49749756, 10.51250076], [92.4972229, 10.51249886], [92.49680328, 10.51264], [92.49610901, 10.51278114], [92.49582672, 10.51306152], [92.49555206, 10.51305485], [92.4952774, 10.51333046], [92.4952774, 10.51361084], [92.49500275, 10.51389122], [92.49500275, 10.51417065], [92.4944458, 10.51473045], [92.49416351, 10.51472092], [92.49388885, 10.5150013], [92.49360657, 10.5150013], [92.49305725, 10.5155592], [92.49250031, 10.5155592], [92.49223328, 10.5155592], [92.49124908, 10.51562977], [92.4908371, 10.5155592], [92.49055481, 10.51555538], [92.49028015, 10.5158329], [92.48916626, 10.5158329], [92.4888916, 10.51611137], [92.48832703, 10.51611137], [92.48805237, 10.51638889], [92.48665619, 10.51638889], [92.48638916, 10.51666927], [92.48583221, 10.51666737], [92.48555756, 10.51694489], [92.48500061, 10.51694489], [92.48472595, 10.51722336], [92.48443604, 10.51722145], [92.48416901, 10.51750088], [92.48361206, 10.51750088], [92.48332977, 10.51779079], [92.48306274, 10.51779079], [92.48278046, 10.51805973], [92.48249817, 10.51805496], [92.48222351, 10.51833344], [92.48139191, 10.51833344], [92.48000336, 10.51972103], [92.48000336, 10.52028179], [92.47972107, 10.52056026]]], [[[92.81416321, 9.12694359], [92.81416321, 9.1263876], [92.81445313, 9.12639046], [92.81445313, 9.12611198], [92.81472015, 9.12611198], [92.81472015, 9.12583447], [92.81388855, 9.12583447], [92.81388855, 9.12555599], [92.81360626, 9.1255579], [92.81360626, 9.12528038], [92.8133316, 9.12528038], [92.8133316, 9.12500191], [92.81276703, 9.12500191], [92.81276703, 9.12472057], [92.81201172, 9.12471676], [92.81201935, 9.12444115], [92.8116684, 9.12444115], [92.8116684, 9.1255579], [92.8125, 9.12555599], [92.8125, 9.12583447], [92.8133316, 9.12583065], [92.8133316, 9.12639046], [92.81361389, 9.1263876], [92.81361389, 9.12694359], [92.81416321, 9.12694359]]], [[[92.79332733, 9.11889076], [92.79332733, 9.11861134], [92.79444122, 9.11861134], [92.79444122, 9.11833286], [92.79582977, 9.11833286], [92.79582977, 9.11805534], [92.79638672, 9.11805534], [92.79638672, 9.11833286], [92.79666901, 9.11861134], [92.7986145, 9.11861134], [92.7986145, 9.11833286], [92.79833221, 9.11833286], [92.79833221, 9.11805534], [92.79696655, 9.11795521], [92.79666901, 9.11773968], [92.79222107, 9.11778164], [92.79222107, 9.11806202], [92.79250336, 9.11805534], [92.79250336, 9.11861134], [92.79305267, 9.11861134], [92.79305267, 9.11889076], [92.79332733, 9.11889076]]], [[[92.8041687, 9.1208334], [92.8041687, 9.1202774], [92.80444336, 9.12027931], [92.80444336, 9.12000084], [92.8041687, 9.12000084], [92.8041687, 9.11972141], [92.80374908, 9.11958885], [92.80361176, 9.11944485], [92.80305481, 9.119133], [92.80278015, 9.11917019], [92.80278015, 9.11889076], [92.80166626, 9.11889076], [92.80166626, 9.11861134], [92.8013916, 9.11861134], [92.80131531, 9.11865234], [92.80095673, 9.11886024], [92.80055237, 9.11865044], [92.79972076, 9.11861134], [92.79972076, 9.11889076], [92.80027008, 9.11889076], [92.80027008, 9.11917019], [92.80110931, 9.11916733], [92.80110931, 9.11944485], [92.8013916, 9.11944485], [92.8013916, 9.11916733], [92.80194092, 9.11923122], [92.80235291, 9.11954975], [92.80267334, 9.11952305], [92.80303955, 9.11972141], [92.80303955, 9.12000084], [92.80388641, 9.11999893], [92.80388641, 9.1208334], [92.8041687, 9.1208334]]], [[[92.78778076, 9.24416637], [92.78888702, 9.24305439], [92.78971863, 9.24306107], [92.7902832, 9.24250031], [92.79055786, 9.24250031], [92.79111481, 9.24194431], [92.79138947, 9.24194431], [92.79222107, 9.24110985], [92.79222107, 9.24083424], [92.79305267, 9.23999977], [92.79305267, 9.23972225], [92.79472351, 9.23805618], [92.79472351, 9.23777771], [92.79499817, 9.23750019], [92.79499817, 9.23722172], [92.79528046, 9.2369442], [92.79611206, 9.2367363], [92.79729462, 9.23555565], [92.79750061, 9.23499966], [92.79805756, 9.23444366], [92.79805756, 9.23416805], [92.79833221, 9.23388767], [92.79882813, 9.2336092], [92.79917908, 9.23334503], [92.79953003, 9.23306942], [92.80001831, 9.2325201], [92.80058289, 9.23168087], [92.80099487, 9.23112965], [92.80168915, 9.23050785], [92.80222321, 9.2300024], [92.80332947, 9.22888947], [92.80361176, 9.22888947], [92.80473328, 9.22777939], [92.80500031, 9.22777939], [92.80750275, 9.22528172], [92.8077774, 9.22528172], [92.8088913, 9.22417164], [92.80916595, 9.22417164], [92.8097229, 9.22361088], [92.80999756, 9.22361088], [92.81083679, 9.22277737], [92.81111145, 9.22278118], [92.8125, 9.22139072], [92.81276703, 9.22139072], [92.81388855, 9.22028065], [92.81388855, 9.22000122], [92.8144455, 9.21944523], [92.8144455, 9.21916676], [92.8152771, 9.21833229], [92.8152771, 9.21805668], [92.81583405, 9.21750069], [92.81667328, 9.21667099], [92.81667328, 9.21639061], [92.8172226, 9.21582985], [92.8172226, 9.21555424], [92.81749725, 9.21527767], [92.81832886, 9.21445084], [92.81861115, 9.21380234], [92.81916809, 9.21324062], [92.81944275, 9.21220589], [92.81964874, 9.21103001], [92.81999969, 9.21000004], [92.8208313, 9.20917034], [92.8208313, 9.20860958], [92.82055664, 9.20833397], [92.82055664, 9.20777798], [92.8208313, 9.20750046], [92.8208313, 9.20722198], [92.82118225, 9.2067337], [92.82145691, 9.20604324], [92.8216629, 9.2052784], [92.8216629, 9.20444584], [92.82194519, 9.20416546], [92.82194519, 9.20388985], [92.82221985, 9.20361137], [92.82221985, 9.20249939], [92.82250214, 9.20222092], [92.82277679, 9.20147419], [92.82326508, 9.20022678], [92.82333374, 9.19939709], [92.82367706, 9.19858074], [92.82430267, 9.19584179], [92.85436249, 9.2091589], [92.8544693, 9.20884895], [92.85686493, 9.20195866], [92.82553101, 9.19213104], [92.82588196, 9.19033337], [92.82601929, 9.18929577], [92.82637024, 9.18798065], [92.82650757, 9.18770313], [92.82623291, 9.18687439], [92.82601929, 9.18638802], [92.82601929, 9.1850729], [92.82567596, 9.18410397], [92.82553101, 9.18306541], [92.82567596, 9.18237209], [92.82581329, 9.18209553], [92.82588196, 9.1817503], [92.82518768, 9.18091965], [92.82553101, 9.1798811], [92.82553101, 9.17953491], [92.82567596, 9.1792593], [92.8264389, 9.17875957], [92.82713318, 9.17787266], [92.82846069, 9.17655754], [92.82880402, 9.17628193], [92.82894897, 9.17558956], [92.82888031, 9.17468929], [92.82901764, 9.1743412], [92.82950592, 9.17358208], [92.82971191, 9.17295933], [92.82984924, 9.17254543], [92.82984924, 9.17171288], [92.83033752, 9.17143726], [92.83047485, 9.17101955], [92.83082581, 9.17067146], [92.83082581, 9.17005062], [92.83089447, 9.16977501], [92.8310318, 9.16901207], [92.83110809, 9.16845989], [92.83152008, 9.16755104], [92.8317337, 9.16652107], [92.83152008, 9.16555214], [92.83166504, 9.16520596], [92.8317337, 9.16437626], [92.83187103, 9.16341019], [92.83174133, 9.16271019], [92.83166504, 9.16188335], [92.83131409, 9.1610527], [92.83110809, 9.16036034], [92.83096313, 9.15918446], [92.83096313, 9.15800571], [92.83068848, 9.15724468], [92.8302002, 9.15683174], [92.8302002, 9.15620995], [92.82956696, 9.15550995], [92.82936096, 9.1550293], [92.82901764, 9.1539917], [92.82888031, 9.15330029], [92.82874298, 9.15287971], [92.82859802, 9.1521244], [92.82824707, 9.15149879], [92.82817841, 9.15073967], [92.82810974, 9.14990997], [92.82832336, 9.1491518], [92.82832336, 9.14789104], [92.82839203, 9.14720726], [92.82817841, 9.14672375], [92.82859802, 9.14554596], [92.82873535, 9.14478493], [92.82888031, 9.14423084], [92.82888031, 9.14354038], [92.82880402, 9.14312267], [92.82894897, 9.14256859], [92.8290863, 9.14153194], [92.82915497, 9.14097881], [92.82964325, 9.14007759], [92.82984924, 9.13993931], [92.8302002, 9.13993931], [92.83068848, 9.13973045], [92.83068848, 9.13931656], [92.83055115, 9.13869476], [92.83013153, 9.13827801], [92.8290863, 9.13827991], [92.82817841, 9.13807011], [92.82784271, 9.13807011], [92.8274231, 9.13815022], [92.82657623, 9.13827991], [92.82581329, 9.13820934], [92.82518768, 9.13827991], [92.82414246, 9.13835144], [92.82302856, 9.13772202], [92.82233429, 9.13772392], [92.82156372, 9.13716984], [92.82066345, 9.13682365], [92.81996155, 9.13640881], [92.81926727, 9.13585472], [92.8184967, 9.13537025], [92.81759644, 9.13544273], [92.81746674, 9.13544273], [92.81682587, 9.1355114], [92.81648254, 9.13508034], [92.81606293, 9.13426208], [92.8157196, 9.13357067], [92.81529999, 9.13287926], [92.81494904, 9.13246441], [92.8143158, 9.13169956], [92.81369781, 9.13163185], [92.81349182, 9.13163185], [92.81300354, 9.13177109], [92.81216431, 9.13149548], [92.81188965, 9.13107967], [92.81195831, 9.13052559], [92.81195831, 9.12900162], [92.81216431, 9.12810135], [92.81223297, 9.12727165], [92.81223297, 9.12678623], [92.81195831, 9.12644005], [92.81160736, 9.12588787], [92.81138611, 9.1255579], [92.81083679, 9.1255579], [92.81083679, 9.12472057], [92.81111145, 9.12472057], [92.81111145, 9.12444305], [92.81138611, 9.12444305], [92.81138611, 9.1236124], [92.81111145, 9.1236124], [92.81111145, 9.12389183], [92.80999756, 9.12389183], [92.80999756, 9.1236124], [92.80860901, 9.1236124], [92.80860901, 9.12389183], [92.80833435, 9.12388992], [92.80833435, 9.12416458], [92.80805206, 9.12416458], [92.80805206, 9.1236124], [92.80722046, 9.1236124], [92.80673218, 9.12360191], [92.80632019, 9.12339497], [92.80561829, 9.12304878], [92.8052063, 9.12290955], [92.80471802, 9.12221909], [92.80451202, 9.12187004], [92.8042984, 9.121665], [92.80381012, 9.12111092], [92.80332184, 9.12076473], [92.80262756, 9.12055779], [92.80200195, 9.12034988], [92.80137634, 9.12042141], [92.80046844, 9.12042141], [92.79971313, 9.12014008], [92.79892731, 9.12035179], [92.79880524, 9.12015629], [92.79775238, 9.11986542], [92.79725647, 9.11986923], [92.7964325, 9.11966038], [92.79601288, 9.11966038], [92.79524994, 9.11952019], [92.79434204, 9.11959076], [92.79399109, 9.11966038], [92.79342651, 9.1192379], [92.79225159, 9.11931133], [92.79155731, 9.11924171], [92.79100037, 9.11924171], [92.79037476, 9.11910343], [92.78960419, 9.1189642], [92.78870392, 9.1189642], [92.78703308, 9.11931133], [92.78583527, 9.11944485], [92.78555298, 9.11944485], [92.78527832, 9.11972332], [92.78360748, 9.11972141], [92.78333282, 9.12000084], [92.78314209, 9.11995125], [92.78299713, 9.12022018], [92.78251648, 9.12019253], [92.78233337, 9.12018108], [92.78233337, 9.11991501], [92.78250122, 9.11984921], [92.78253174, 9.1196804], [92.78286743, 9.11918068], [92.78334045, 9.11912441], [92.78360748, 9.11861134], [92.78388977, 9.11861134], [92.78398895, 9.11884117], [92.7841568, 9.11889076], [92.7841568, 9.11861134], [92.78500366, 9.11861134], [92.78500366, 9.11805534], [92.78694153, 9.11806202], [92.78694153, 9.11778164], [92.78806305, 9.11778164], [92.78806305, 9.11806202], [92.78833008, 9.11806202], [92.78833008, 9.11778164], [92.78861237, 9.11778164], [92.78861237, 9.11750126], [92.78943634, 9.11750126], [92.78943634, 9.11778164], [92.79000092, 9.11778164], [92.79000092, 9.11750126], [92.79000092, 9.11722088], [92.78968048, 9.11702347], [92.78944397, 9.11694527], [92.78583527, 9.11694527], [92.78583527, 9.11722088], [92.78527832, 9.11722088], [92.78528595, 9.11750126], [92.7841568, 9.11750126], [92.7841568, 9.11778164], [92.78360748, 9.11777687], [92.78277588, 9.11861134], [92.78268433, 9.11863804], [92.78236389, 9.11873436], [92.78159332, 9.11923313], [92.78131866, 9.1193037], [92.78111267, 9.11972141], [92.78083038, 9.12000084], [92.77999878, 9.11999893], [92.77889252, 9.1208334], [92.77741241, 9.12110901], [92.7767868, 9.12159538], [92.77615356, 9.12221909], [92.77559662, 9.12277126], [92.77477264, 9.12339973], [92.77308655, 9.12478065], [92.7723999, 9.12505722], [92.77156067, 9.12553978], [92.77107239, 9.1260252], [92.77051544, 9.12651062], [92.7699585, 9.12720108], [92.7697525, 9.12741089], [92.76891327, 9.1276207], [92.76870728, 9.12727165], [92.76856995, 9.12651062], [92.76808167, 9.12553978], [92.76786804, 9.12540054], [92.76717377, 9.12561035], [92.76634216, 9.12595367], [92.76599121, 9.12609386], [92.76578522, 9.12567902], [92.76578522, 9.12526417], [92.7653656, 9.12491703], [92.7638855, 9.12388992], [92.76361084, 9.1236124], [92.76222229, 9.1236124], [92.76194763, 9.12389183], [92.76166534, 9.12388992], [92.76139069, 9.12416458], [92.7611084, 9.12416458], [92.76083374, 9.12444305], [92.76000214, 9.12444305], [92.75971985, 9.12472057], [92.75945282, 9.12500191], [92.7591629, 9.125], [92.75805664, 9.12611198], [92.75776672, 9.12611198], [92.75749969, 9.12639046], [92.75694275, 9.12639046], [92.75666809, 9.12667179], [92.75583649, 9.12667179], [92.75549316, 9.12679958], [92.75514221, 9.1266613], [92.75473022, 9.12638474], [92.75444794, 9.12596798], [92.753685, 9.12541676], [92.7527771, 9.12500191], [92.75110626, 9.12500191], [92.75020599, 9.12528038], [92.74846649, 9.1255579], [92.74777985, 9.12528038], [92.74749756, 9.12528038], [92.7472229, 9.12500191], [92.74666595, 9.12500191], [92.7463913, 9.12472057], [92.74611664, 9.12500191], [92.7444458, 9.12500191], [92.74415588, 9.12528038], [92.74388885, 9.12500191], [92.74333191, 9.12500191], [92.74304962, 9.12472057], [92.74250031, 9.12472057], [92.74222565, 9.12444305], [92.74118042, 9.12382984], [92.73986053, 9.12334538], [92.73887634, 9.12320995], [92.73658752, 9.12334538], [92.73583221, 9.1236124], [92.73555756, 9.1236124], [92.73527527, 9.12333298], [92.73500061, 9.1236124], [92.73472595, 9.1236124], [92.73438263, 9.12347031], [92.73332977, 9.12389183], [92.73305511, 9.12388992], [92.73222351, 9.12416458], [92.73166656, 9.12437725], [92.73139191, 9.12472057], [92.72833252, 9.12777805], [92.72833252, 9.12832928], [92.72750092, 9.12916565], [92.72692108, 9.12965775], [92.72657776, 9.13021183], [92.72629547, 9.13152695], [92.72622681, 9.13311958], [92.72644043, 9.13416195], [92.72650909, 9.13512993], [92.72622681, 9.13624001], [92.72580719, 9.13699722], [92.72553253, 9.13775826], [92.72540283, 9.13838005], [92.72490692, 9.13888168], [92.72413635, 9.1395607], [92.7227478, 9.14046097], [92.72261047, 9.14129066], [92.72225952, 9.14219093], [92.72222137, 9.14305496], [92.72027588, 9.14500141], [92.71972656, 9.14607239], [92.71952057, 9.14752674], [92.71952057, 9.14974213], [92.71944427, 9.15022469], [92.71916962, 9.15084934], [92.71881866, 9.15153122], [92.71847534, 9.15257931], [92.71833038, 9.15277767], [92.71833038, 9.15444088], [92.7183075, 9.15564728], [92.7183075, 9.1571703], [92.7181015, 9.15847969], [92.71817017, 9.15979958], [92.71844482, 9.16090679], [92.71872711, 9.16277599], [92.71900177, 9.16409111], [92.71927643, 9.16582108], [92.71949005, 9.16714096], [92.720047, 9.16879845], [92.72039795, 9.1704607], [92.72067261, 9.171772], [92.72081757, 9.17323112], [92.72081757, 9.17426968], [92.72094727, 9.17537975], [92.72116089, 9.17607021], [92.72110748, 9.17667198], [92.72110748, 9.17777729], [92.72083282, 9.17805576], [92.72083282, 9.17972183], [92.72110748, 9.18000031], [92.72110748, 9.18278027], [92.72083282, 9.18305588], [92.72083282, 9.18500042], [92.72055817, 9.18527794], [92.72055817, 9.1861124], [92.72027588, 9.18697166], [92.72013855, 9.1875906], [92.72006989, 9.18828678], [92.72006989, 9.18870068], [92.72000122, 9.18972206], [92.72000122, 9.19110966], [92.71971893, 9.19138813], [92.71971893, 9.19305515], [92.71944427, 9.19333267], [92.71943665, 9.19443989], [92.72055817, 9.19555473], [92.72055817, 9.19611073], [92.72110748, 9.19666672], [92.72110748, 9.19694519], [92.72138977, 9.1972208], [92.72138977, 9.19833279], [92.72110748, 9.19861126], [92.72110748, 9.19889069], [92.72083282, 9.19916725], [92.72083282, 9.19944477], [92.72055817, 9.19972134], [92.72055817, 9.19999886], [92.72027588, 9.20027733], [92.72027588, 9.20083141], [92.72020721, 9.20111084], [92.72027588, 9.20138931], [92.72027588, 9.20166683], [92.72055817, 9.2019453], [92.72055817, 9.2033329], [92.72042084, 9.20361137], [92.72042084, 9.20388985], [92.72055817, 9.20416546], [92.72055817, 9.20583439], [92.72027588, 9.20611191], [92.72027588, 9.20694447], [92.71971893, 9.20750046], [92.71971893, 9.20777798], [92.72027588, 9.20833397], [92.72027588, 9.20971966], [92.72055817, 9.21000004], [92.72055817, 9.21028042], [92.72083282, 9.2105608], [92.72083282, 9.21138954], [92.72055817, 9.21167088], [92.72055817, 9.21249962], [92.72083282, 9.21277809], [92.72083282, 9.2136097], [92.72110748, 9.21388817], [92.72110748, 9.21416569], [92.7216568, 9.21471977], [92.72166443, 9.21500015], [92.72194672, 9.21527767], [92.72250366, 9.21583366], [92.72249603, 9.21611023], [92.72277832, 9.21638775], [92.72277832, 9.21666622], [92.72305298, 9.21694374], [92.72305298, 9.21722221], [92.72393036, 9.21826553], [92.72455597, 9.21875191], [92.72497559, 9.21895885], [92.72566986, 9.21916676], [92.72646332, 9.21931744], [92.7271347, 9.21944523], [92.72777557, 9.21944523], [92.72805786, 9.21972275], [92.72944641, 9.21972275], [92.72972107, 9.21944523], [92.73000336, 9.21944523], [92.73027802, 9.21916676], [92.73055267, 9.21917057], [92.73110962, 9.2186079], [92.73166656, 9.21860981], [92.73194122, 9.21833229], [92.73305511, 9.21833229], [92.73332977, 9.21805668], [92.73361206, 9.21806145], [92.73388672, 9.21778107], [92.73443604, 9.21778107], [92.73501587, 9.21726131], [92.73509216, 9.21698284], [92.73543549, 9.21601486], [92.73571777, 9.21580696], [92.73592377, 9.21546078], [92.73626709, 9.2153101], [92.73722076, 9.21528053], [92.73750305, 9.21556091], [92.73805237, 9.21555424], [92.73833466, 9.21583366], [92.73860931, 9.21583366], [92.7388916, 9.21611023], [92.73944092, 9.21611023], [92.73972321, 9.21639061], [92.74028015, 9.21639061], [92.74054718, 9.21667099], [92.74194336, 9.21667099], [92.74223328, 9.21639061], [92.74250031, 9.21639061], [92.74276733, 9.21611023], [92.74305725, 9.21611023], [92.74333191, 9.21583366], [92.74416351, 9.21583366], [92.7452774, 9.21472168], [92.7452774, 9.21416569], [92.74555206, 9.21388817], [92.74555206, 9.2136097], [92.74610901, 9.21305561], [92.74611664, 9.21278], [92.74694824, 9.21194172], [92.74777985, 9.21194172], [92.74861145, 9.21278], [92.74861145, 9.21306133], [92.7491684, 9.21305561], [92.74944305, 9.21333218], [92.75, 9.21333027], [92.75055695, 9.21389008], [92.7508316, 9.21389008], [92.75138855, 9.21445084], [92.75166321, 9.21444416], [92.7519455, 9.21472168], [92.75222015, 9.21472168], [92.75250244, 9.21500015], [92.75498962, 9.21500015], [92.75527954, 9.21528053], [92.75611115, 9.21528053], [92.7563858, 9.21556091], [92.75723267, 9.21556091], [92.75749969, 9.21528053], [92.75805664, 9.21528053], [92.7583313, 9.21500015], [92.75888824, 9.21500015], [92.7591629, 9.21472168], [92.76527405, 9.21472168], [92.76555634, 9.21500015], [92.76583099, 9.21500015], [92.76611328, 9.21528053], [92.76667023, 9.21528053], [92.76692963, 9.21556091], [92.76721954, 9.21555424], [92.76777649, 9.21611023], [92.76805878, 9.21611023], [92.76860809, 9.21666622], [92.76860809, 9.21694374], [92.76916504, 9.21750069], [92.76916504, 9.21785164], [92.76950836, 9.21813011], [92.76985931, 9.21868324], [92.7703476, 9.21909809], [92.77069092, 9.21958447], [92.77111053, 9.22027874], [92.77111053, 9.22055531], [92.77166748, 9.2211113], [92.77166748, 9.22166729], [92.77138519, 9.22194481], [92.77138519, 9.22222328], [92.77111053, 9.2225008], [92.77111053, 9.22278118], [92.77083588, 9.22305489], [92.77046967, 9.22373581], [92.77053833, 9.22408295], [92.77083588, 9.22472095], [92.77083588, 9.22611141], [92.77111053, 9.22638893], [92.77111053, 9.22722054], [92.77139282, 9.22750092], [92.77139282, 9.22777939], [92.77153015, 9.22791767], [92.77166748, 9.22805977], [92.77222443, 9.228055], [92.77249908, 9.22833347], [92.77278137, 9.22833347], [92.77305603, 9.22861099], [92.77361298, 9.22861099], [92.77416992, 9.22916985], [92.77416992, 9.22945023], [92.77471924, 9.2300024], [92.77485657, 9.23092937], [92.77493286, 9.23113728], [92.77493286, 9.23141479], [92.77527618, 9.23194313], [92.77527618, 9.23305607], [92.77583313, 9.23361206], [92.77583313, 9.23416805], [92.77610779, 9.23444366], [92.77610016, 9.23471928], [92.77583313, 9.23499966], [92.77583313, 9.23527813], [92.77555847, 9.23555565], [92.77555847, 9.23610973], [92.77500153, 9.23666954], [92.77444458, 9.23666573], [92.77416992, 9.2369442], [92.77388763, 9.2369442], [92.77278137, 9.23805618], [92.77278137, 9.2383337], [92.77333069, 9.23888779], [92.77333069, 9.23944378], [92.77361298, 9.23972034], [92.77361298, 9.24027824], [92.77372742, 9.24061966], [92.77407074, 9.24069118], [92.77455902, 9.24069118], [92.77497864, 9.24041271], [92.77532196, 9.23985863], [92.77511597, 9.23930454], [92.77490997, 9.23910046], [92.77497864, 9.23888969], [92.77532196, 9.23882198], [92.77559662, 9.23882198], [92.77597046, 9.23888969], [92.7768631, 9.23924065], [92.77748108, 9.24020958], [92.7776947, 9.24089813], [92.77811432, 9.24165916], [92.77825165, 9.24228191], [92.77861023, 9.24333191], [92.77861023, 9.24416637], [92.77889252, 9.24443054], [92.77889252, 9.24528122], [92.77861023, 9.24555683], [92.77861023, 9.24611092], [92.77833557, 9.24638939], [92.77833557, 9.24666691], [92.77777863, 9.2472229], [92.77777863, 9.24750137], [92.77749634, 9.24777889], [92.77749634, 9.24833298], [92.77694702, 9.24888897], [92.77694702, 9.24972057], [92.7766571, 9.25000095], [92.7766571, 9.25028133], [92.77639008, 9.25055695], [92.77639008, 9.25111103], [92.77500153, 9.25250053], [92.77500153, 9.25388908], [92.77471924, 9.2541666], [92.77471924, 9.25444317], [92.77388763, 9.25527668], [92.77388763, 9.25611115], [92.77471924, 9.25694561], [92.77639008, 9.25694561], [92.77700806, 9.25684834], [92.77763367, 9.2567091], [92.77819061, 9.25636196], [92.77861023, 9.25580788], [92.77861023, 9.2547226], [92.77889252, 9.25444317], [92.77889252, 9.2541666], [92.77944183, 9.25361061], [92.77944183, 9.25333118], [92.78032684, 9.25272942], [92.7804718, 9.25231171], [92.7806778, 9.25196648], [92.78096008, 9.25148201], [92.78102875, 9.25092888], [92.78116608, 9.25023556], [92.78144073, 9.24982071], [92.78192902, 9.24912834], [92.78263092, 9.2484417], [92.78304291, 9.24802017], [92.78374481, 9.2478838], [92.78443909, 9.24760628], [92.78499603, 9.24705219], [92.78569031, 9.24663734], [92.78638458, 9.24608326], [92.78694153, 9.24555683], [92.78749847, 9.24500084], [92.78749847, 9.24472046], [92.78778076, 9.24444389], [92.78778076, 9.24416637]]], [[[93.54728699, 8.02805233], [93.54715729, 8.0277071], [93.54715729, 8.02722168], [93.54777527, 8.02666569], [93.5486145, 8.02666569], [93.54888916, 8.02694416], [93.54944611, 8.02694416], [93.54972076, 8.02722168], [93.55000305, 8.02722168], [93.55027771, 8.02750015], [93.55055237, 8.02722168], [93.55110931, 8.02722168], [93.5513916, 8.02694416], [93.55194092, 8.02694416], [93.55222321, 8.02666569], [93.55361176, 8.02667046], [93.55388641, 8.02639008], [93.55444336, 8.02639008], [93.55500031, 8.02582932], [93.55527496, 8.02583408], [93.55555725, 8.02555561], [93.55583191, 8.02556038], [93.55638885, 8.02499962], [93.55665588, 8.02499962], [93.5569458, 8.02471924], [93.5577774, 8.02471924], [93.55805206, 8.02499962], [93.55916595, 8.02499962], [93.55944824, 8.02471924], [93.56027985, 8.0247221], [93.5605545, 8.02444363], [93.5605545, 8.02416801], [93.56083679, 8.02388763], [93.56083679, 8.02361202], [93.56111145, 8.02333355], [93.56166077, 8.02333069], [93.56222534, 8.02388763], [93.56222534, 8.02416801], [93.5625, 8.02444363], [93.56254578, 8.02477169], [93.56276703, 8.02499962], [93.56305695, 8.02499962], [93.5633316, 8.02471924], [93.56361389, 8.0247221], [93.56472015, 8.02361202], [93.56472015, 8.02333355], [93.56500244, 8.02305603], [93.56500244, 8.02222157], [93.5652771, 8.02194309], [93.5652771, 8.02138996], [93.56555176, 8.02111244], [93.56555176, 8.02083397], [93.56583405, 8.02055454], [93.56583405, 8.02027702], [93.5661087, 8.01999855], [93.5661087, 8.01972103], [93.56639099, 8.01944637], [93.56639099, 8.01777744], [93.56694794, 8.01722336], [93.56694794, 8.01694489], [93.56666565, 8.01666737], [93.56666565, 8.01555538], [93.56833649, 8.01388931], [93.56833649, 8.01362038], [93.56973267, 8.01222134], [93.57027435, 8.01222324], [93.57055664, 8.01194477], [93.5708313, 8.01194477], [93.57111359, 8.01166725], [93.57138824, 8.01167107], [93.57174683, 8.01109886], [93.57175446, 8.01041126], [93.57182312, 8.00840092], [93.57250214, 8.00777912], [93.57250214, 8.00722313], [93.57416534, 8.0055542], [93.57416534, 8.00500011], [93.57444763, 8.00471973], [93.57444763, 8.00444412], [93.57472229, 8.00416565], [93.57472229, 8.00388813], [93.57527924, 8.00333023], [93.57527924, 8.00305557], [93.57555389, 8.00277805], [93.57554626, 8.00249958], [93.57583618, 8.00222015], [93.57583618, 8.00194359], [93.57624817, 8.00117779], [93.5763855, 8.00048542], [93.57666779, 8.0], [93.57639313, 7.9997201], [93.57805634, 7.99805593], [93.57833099, 7.99806023], [93.57917023, 7.99721909], [93.57951355, 7.99652719], [93.58000183, 7.99527788], [93.58000183, 7.99472094], [93.58027649, 7.99444294], [93.58027649, 7.9941678], [93.58110809, 7.99333286], [93.58110809, 7.99305487], [93.58139038, 7.99277687], [93.58167267, 7.99278021], [93.5827713, 7.99167013], [93.5827713, 7.9911108], [93.58249664, 7.99083281], [93.58249664, 7.99055481], [93.58222198, 7.99027681], [93.58222198, 7.98972082], [93.58194733, 7.98944521], [93.58194733, 7.98861122], [93.58166504, 7.98833323], [93.58166504, 7.98694515], [93.58194733, 7.98666716], [93.58194733, 7.98638916], [93.58167267, 7.98611116], [93.58166504, 7.98527718], [93.58305359, 7.9838891], [93.58304596, 7.98332977], [93.58083344, 7.9811101], [93.58055878, 7.9811101], [93.58027649, 7.9808321], [93.58027649, 7.98055696], [93.58000183, 7.98027897], [93.58000183, 7.98000097], [93.57972717, 7.9788909], [93.57972717, 7.97778082], [93.58000183, 7.97750902], [93.58000183, 7.97722006], [93.58139038, 7.97583389], [93.58194733, 7.97583389], [93.58222198, 7.9755559], [93.58222198, 7.97222185], [93.58305359, 7.97138977], [93.58305359, 7.97027779], [93.58255768, 7.96985197], [93.58200073, 7.96950102], [93.58213806, 7.96881008], [93.58213806, 7.96839094], [93.58164978, 7.96819019], [93.58082581, 7.96806002], [93.58000183, 7.96722078], [93.58000183, 7.96666813], [93.57971954, 7.96639013], [93.57972717, 7.9658308], [93.57944489, 7.96555519], [93.57944489, 7.96527719], [93.57978821, 7.96395111], [93.58034515, 7.96339893], [93.58125305, 7.96332884], [93.58187866, 7.96297979], [93.58187866, 7.96242619], [93.5817337, 7.96138716], [93.58159637, 7.96048021], [93.58139038, 7.9595108], [93.58139038, 7.95881796], [93.5817337, 7.95826387], [93.58139038, 7.95750093], [93.58027649, 7.95638895], [93.58027649, 7.95611095], [93.58000183, 7.95583296], [93.58000183, 7.95500088], [93.57971954, 7.95472288], [93.57971954, 7.95444489], [93.57982635, 7.95357418], [93.58052063, 7.9527421], [93.58100891, 7.95253515], [93.58166504, 7.95222187], [93.58166504, 7.95138788], [93.58194733, 7.95110989], [93.58194733, 7.94999981], [93.58139038, 7.94860983], [93.58139038, 7.94833422], [93.58110809, 7.94805622], [93.58110809, 7.94777822], [93.58082581, 7.94750881], [93.58082581, 7.94528008], [93.58110809, 7.94500017], [93.58110809, 7.94444418], [93.58055878, 7.94388819], [93.58055878, 7.94277811], [93.58027649, 7.94250011], [93.58027649, 7.94194412], [93.58055878, 7.94166517], [93.58055878, 7.94139004], [93.58083344, 7.94111204], [93.58083344, 7.9399991], [93.58110809, 7.93972111], [93.58110809, 7.93944597], [93.58139038, 7.93916798], [93.58139038, 7.93833303], [93.58082581, 7.9377799], [93.58055878, 7.9377799], [93.57943726, 7.93666983], [93.57943726, 7.93361092], [93.57888794, 7.93305492], [93.57805634, 7.93305922], [93.57776642, 7.93278122], [93.57749939, 7.93278122], [93.5772171, 7.93250084], [93.5772171, 7.93220901], [93.57666779, 7.93166685], [93.57666779, 7.93111086], [93.57694244, 7.93083286], [93.57694244, 7.93055487], [93.57749939, 7.93000078], [93.57776642, 7.93000078], [93.57833099, 7.92944002], [93.57777405, 7.9288888], [93.57777405, 7.9286108], [93.57749939, 7.92833281], [93.57722473, 7.92833281], [93.57694244, 7.9286108], [93.57666779, 7.9286108], [93.57611084, 7.92917109], [93.57583618, 7.92916679], [93.57555389, 7.92944479], [93.57472229, 7.92944479], [93.57416534, 7.9288888], [93.57389069, 7.92889118], [93.57250214, 7.93028116], [93.57221985, 7.93027878], [93.5688858, 7.93361092], [93.56861115, 7.93361092], [93.56777954, 7.9344449], [93.56749725, 7.93444109], [93.56667328, 7.93527889], [93.56639099, 7.93527889], [93.5661087, 7.93556023], [93.56583405, 7.93555498], [93.56555176, 7.93583298], [93.56500244, 7.93583298], [93.56472015, 7.93611097], [93.56445313, 7.93611097], [93.56388855, 7.93666983], [93.56361389, 7.93666697], [93.56305695, 7.93722105], [93.56276703, 7.93722105], [93.56223297, 7.9377799], [93.56222534, 7.93805504], [93.56194305, 7.93833303], [93.56223297, 7.93861103], [93.56222534, 7.93916798], [93.5588913, 7.94250011], [93.5588913, 7.94277811], [93.55722046, 7.94444418], [93.5569458, 7.94444418], [93.55638885, 7.94500017], [93.55583191, 7.94500017], [93.55555725, 7.94528008], [93.55500031, 7.94527817], [93.5533371, 7.94694424], [93.5533371, 7.94721985], [93.55278015, 7.94777822], [93.55278015, 7.94805622], [93.55249786, 7.94833422], [93.55249786, 7.94860983], [93.55194092, 7.94917107], [93.55166626, 7.94916582], [93.55023193, 7.94970179], [93.54968262, 7.94970179], [93.54884338, 7.95004988], [93.5486145, 7.9505558], [93.54805756, 7.95110989], [93.5477829, 7.95110989], [93.54722595, 7.95167112], [93.54666138, 7.95188093], [93.54633331, 7.95160007], [93.54555511, 7.95138788], [93.54499817, 7.95194006], [93.54499817, 7.95277882], [93.54472351, 7.95305395], [93.54471588, 7.95332098], [93.54277802, 7.95528078], [93.54250336, 7.95527887], [93.54194641, 7.95583296], [93.54166412, 7.95583296], [93.54138947, 7.95611095], [93.54111481, 7.95611095], [93.54083252, 7.95638895], [93.54027557, 7.95638895], [93.53971863, 7.95694494], [93.53944397, 7.95694494], [93.53805542, 7.95833302], [93.53805542, 7.959445], [93.53833008, 7.959723], [93.53805542, 7.96000099], [93.53806305, 7.96083117], [93.53749847, 7.96139097], [93.53749847, 7.96166706], [93.53639221, 7.96277714], [93.53555298, 7.96361113], [93.53527832, 7.96361113], [93.53499603, 7.96389198], [93.53472137, 7.96389198], [93.53444672, 7.96416998], [93.53416443, 7.96416712], [93.53388977, 7.96444511], [93.53193665, 7.96444082], [93.53083038, 7.96557093], [93.53055573, 7.96555519], [93.53028107, 7.96583319], [93.52999878, 7.96583319], [93.52861023, 7.96722078], [93.5283432, 7.96722078], [93.52777863, 7.96778011], [93.52639008, 7.96778011], [93.52610779, 7.96806002], [93.52527618, 7.9680562], [93.52500153, 7.9683342], [93.52471924, 7.96831989], [93.52416992, 7.96889019], [93.52416992, 7.96917009], [93.52500153, 7.96999979], [93.52471924, 7.97027779], [93.52471924, 7.97055578], [93.52444458, 7.97083378], [93.52416992, 7.97055578], [93.52388763, 7.97056007], [93.52361298, 7.97028017], [93.52278137, 7.97028017], [93.52249146, 7.97056007], [93.52194214, 7.97055578], [93.52166748, 7.97083378], [93.52138519, 7.97083378], [93.52111053, 7.97111177], [93.52083588, 7.97111177], [93.52027893, 7.97166586], [93.52027893, 7.97194386], [93.51833344, 7.97388792], [93.51673889, 7.97451496], [93.51611328, 7.97465086], [93.51583099, 7.9749999], [93.51667023, 7.97583389], [93.51694489, 7.97583389], [93.51721954, 7.97610998], [93.51694489, 7.97638798], [93.51694489, 7.97666597], [93.51667023, 7.97694397], [93.51667786, 7.97722006], [93.51638794, 7.97749996], [93.51638794, 7.97805595], [93.51611328, 7.97833395], [93.51611328, 7.97861004], [93.51555634, 7.9791708], [93.51527405, 7.97916603], [93.51499939, 7.97944403], [93.51472473, 7.97944403], [93.51444244, 7.97972202], [93.51389313, 7.97972012], [93.51333618, 7.98028088], [93.51304626, 7.98028088], [93.51194763, 7.98139095], [93.51166534, 7.98138905], [93.5111084, 7.98194504], [93.51082611, 7.98193979], [93.50888824, 7.98389101], [93.50805664, 7.9838891], [93.50723267, 7.98472118], [93.50722504, 7.98527718], [93.50749969, 7.98555517], [93.50749969, 7.98583317], [93.50777435, 7.98611116], [93.50777435, 7.98666716], [93.5083313, 7.98722315], [93.5083313, 7.98861122], [93.50805664, 7.98888922], [93.50805664, 7.98972082], [93.50776672, 7.9900012], [93.50777435, 7.99027681], [93.50749969, 7.99055481], [93.50749969, 7.99083281], [93.50722504, 7.9911108], [93.50722504, 7.9913888], [93.5063858, 7.99222088], [93.5063858, 7.99249887], [93.50527954, 7.99360895], [93.50527954, 7.99388981], [93.50666809, 7.99527788], [93.50666809, 7.99610901], [93.50723267, 7.99666977], [93.50776672, 7.99666977], [93.5083313, 7.99610901], [93.50861359, 7.99611187], [93.50971985, 7.99722195], [93.51027679, 7.99721909], [93.51055145, 7.99749994], [93.51082611, 7.99749994], [93.51139069, 7.99806023], [93.51167297, 7.99806023], [93.51249695, 7.99888992], [93.51333618, 7.99888992], [93.51412964, 7.99816084], [93.51448059, 7.99772978], [93.51454926, 7.99697781], [93.51448059, 7.99607515], [93.51461792, 7.99517298], [93.51538086, 7.99461699], [93.51600647, 7.9943409], [93.51698303, 7.99385118], [93.5175705, 7.99361181], [93.51763916, 7.9934721], [93.51791382, 7.993402], [93.51833344, 7.99312592], [93.51889038, 7.99361181], [93.51916504, 7.99361181], [93.51999664, 7.99444294], [93.51999664, 7.99472094], [93.52027893, 7.99499989], [93.52027893, 7.99555111], [93.5222168, 7.99749994], [93.5222168, 7.99777985], [93.52361298, 7.99916983], [93.52388763, 7.99916601], [93.52416992, 7.99944401], [93.52443695, 7.99943876], [93.52555847, 8.0], [93.52583313, 8.00055599], [93.52583313, 8.00111198], [93.52666473, 8.00194359], [93.5266571, 8.00222015], [93.52694702, 8.00249958], [93.52694702, 8.00305557], [93.52722168, 8.00333214], [93.52722168, 8.00416565], [93.52749634, 8.00444412], [93.52749634, 8.00472164], [93.52771759, 8.00494289], [93.52805328, 8.00528145], [93.52889252, 8.00528145], [93.52916718, 8.00556087], [93.52999878, 8.0055542], [93.53028107, 8.00583458], [93.53055573, 8.00583458], [93.53111267, 8.00638771], [93.53111267, 8.00750065], [93.53083038, 8.00777912], [93.53083038, 8.00833225], [93.53055573, 8.00861073], [93.53055573, 8.01222324], [93.53028107, 8.01249886], [93.53028107, 8.01555538], [93.52999878, 8.0158329], [93.52999878, 8.01611137], [93.52972412, 8.01638889], [93.52913666, 8.01733971], [93.52872467, 8.0178299], [93.52837372, 8.01824665], [93.52823639, 8.01873207], [93.52844238, 8.01928616], [93.52858734, 8.01984024], [93.52872467, 8.02032471], [93.52899933, 8.02094746], [93.52941895, 8.02136517], [93.52916718, 8.02194309], [93.52944183, 8.02222157], [93.52944183, 8.02250195], [93.52971649, 8.02279091], [93.52972412, 8.02305603], [93.53028107, 8.02361202], [93.53028107, 8.02388763], [93.53037262, 8.02398109], [93.53056335, 8.02416992], [93.53083038, 8.02416801], [93.53111267, 8.02444363], [93.53166962, 8.02444363], [93.53194427, 8.0247221], [93.53221893, 8.02471924], [93.53250122, 8.02499962], [93.53305817, 8.02499962], [93.53333282, 8.02471924], [93.53416443, 8.0247221], [93.53472137, 8.02416801], [93.53499603, 8.02416992], [93.53527832, 8.02388954], [93.53527832, 8.02361202], [93.53555298, 8.02333355], [93.53555298, 8.02277756], [93.53583527, 8.02250004], [93.5358429, 8.02222157], [93.53639221, 8.02166462], [93.53666687, 8.02167034], [93.53694153, 8.02139187], [93.53694153, 8.02028179], [93.53721619, 8.01999855], [93.53666687, 8.01943016], [93.53666687, 8.01916695], [93.53639221, 8.01888943], [93.53639221, 8.01861095], [93.53749847, 8.01749897], [93.53888702, 8.01750088], [93.53916931, 8.01722145], [93.53971863, 8.01722336], [93.54000092, 8.01694489], [93.54055786, 8.01694489], [93.54250336, 8.0150013], [93.54250336, 8.01472092], [93.54277802, 8.0144453], [93.54277802, 8.01361084], [93.54250336, 8.01333332], [93.54250336, 8.01305485], [93.54222107, 8.01277733], [93.54222107, 8.01249886], [93.54194641, 8.01222324], [93.54194641, 8.01111126], [93.54222107, 8.01083279], [93.54222107, 8.01055527], [93.54250336, 8.0102787], [93.54250336, 8.01000118], [93.54277802, 8.00972271], [93.54277802, 8.00944519], [93.54305267, 8.00916672], [93.54305267, 8.00805664], [93.54277802, 8.00778103], [93.54277802, 8.00722027], [93.54305267, 8.0069437], [93.54305267, 8.00638771], [93.54333496, 8.00611019], [93.54333496, 8.00583458], [93.54389191, 8.00527763], [93.54389191, 8.00500011], [93.54582977, 8.00306129], [93.54611206, 8.00306129], [93.54638672, 8.00277996], [93.54666138, 8.00277996], [93.5477829, 8.00168037], [93.5477829, 8.00139046], [93.54805756, 8.00111198], [93.54805756, 8.00083447], [93.54833221, 8.00055599], [93.54833221, 8.00027847], [93.54888916, 8.0], [93.54866791, 7.99864197], [93.54846191, 7.99850512], [93.54853821, 7.99768877], [93.54930115, 7.9973402], [93.54978943, 7.99713278], [93.55027771, 7.99678612], [93.55034637, 7.99643993], [93.55076599, 7.99623013], [93.55117798, 7.99699593], [93.55131531, 7.99775696], [93.55132294, 7.99866009], [93.55166626, 7.9991498], [93.55194092, 8.0], [93.55166626, 8.00027847], [93.55166626, 8.00111198], [93.5513916, 8.0013876], [93.5513916, 8.00222206], [93.55110931, 8.00249958], [93.55110931, 8.00333214], [93.55083466, 8.00361156], [93.55083466, 8.00416565], [93.55055237, 8.00444412], [93.55055237, 8.0055542], [93.55083466, 8.00583458], [93.55194092, 8.00695133], [93.55215454, 8.00715923], [93.55222321, 8.00778103], [93.55194092, 8.00806141], [93.55145264, 8.00806141], [93.55075836, 8.00840473], [93.55055237, 8.00861073], [93.55055237, 8.00916672], [93.55027771, 8.00944519], [93.55027771, 8.01000118], [93.55000305, 8.0102787], [93.55000305, 8.01111126], [93.54972076, 8.01138878], [93.54972076, 8.01194477], [93.54950714, 8.01242065], [93.5497818, 8.01269913], [93.55040741, 8.01297665], [93.55047607, 8.01353073], [93.55005646, 8.01366997], [93.54943848, 8.01353073], [93.54915619, 8.01416016], [93.54862976, 8.01415062], [93.54845428, 8.01507854], [93.54838562, 8.01542473], [93.54824066, 8.01577187], [93.54824066, 8.01611805], [93.54810333, 8.016325], [93.54789734, 8.01667404], [93.54777527, 8.01694489], [93.5483017, 8.01789093], [93.5483017, 8.01851082], [93.54843903, 8.01927662], [93.54864502, 8.01955509], [93.54892731, 8.01990128], [93.54892731, 8.02039146], [93.5483017, 8.0203867], [93.54781342, 8.02059364], [93.54733276, 8.02073097], [93.54676819, 8.02143097], [93.5464859, 8.02205086], [93.54582977, 8.02194309], [93.54389191, 8.02388763], [93.54389191, 8.02443886], [93.54332733, 8.02499962], [93.54333496, 8.02527809], [93.54472351, 8.02666569], [93.54471588, 8.02722168], [93.54479218, 8.02750015], [93.54479218, 8.02784634], [93.54506683, 8.02805424], [93.54576874, 8.02805424], [93.54590607, 8.02798462], [93.54624939, 8.02798462], [93.54646301, 8.02832985], [93.54653168, 8.02854156], [93.54688263, 8.02882195], [93.54722595, 8.02854156], [93.54728699, 8.02805233]]], [[[93.57861328, 8.12527943], [93.57940674, 8.12483978], [93.57981873, 8.12491322], [93.58030701, 8.12498283], [93.58030701, 8.12470531], [93.58058167, 8.12429047], [93.58080292, 8.12393856], [93.58065796, 8.12338829], [93.58079529, 8.12283421], [93.58110809, 8.12222099], [93.58139038, 8.12194538], [93.58139038, 8.12138939], [93.58194733, 8.12083054], [93.58194733, 8.12055492], [93.58277893, 8.11958408], [93.58354187, 8.11778069], [93.58486176, 8.11625862], [93.58514404, 8.11535835], [93.58611298, 8.11417103], [93.58666992, 8.11417103], [93.58721924, 8.11361027], [93.58721924, 8.11250019], [93.58750153, 8.11222172], [93.58750153, 8.1119442], [93.58777618, 8.11166573], [93.58786011, 8.11061096], [93.58786011, 8.11012459], [93.5881424, 8.11006165], [93.58821106, 8.10991955], [93.58873749, 8.10935116], [93.58868408, 8.10858917], [93.58889008, 8.1077776], [93.58889771, 8.10639], [93.5891571, 8.10610962], [93.58916473, 8.10499954], [93.59021759, 8.10208035], [93.59049225, 8.10027981], [93.59056854, 8.09889221], [93.59055328, 8.09694481], [93.59055328, 8.0961113], [93.58916473, 8.09472084], [93.58972168, 8.09416676], [93.59027863, 8.09417152], [93.59111023, 8.09333134], [93.59083557, 8.09305477], [93.59083557, 8.09277916], [93.59055328, 8.09250069], [93.59055328, 8.09193993], [93.59083557, 8.09166718], [93.59083557, 8.0913887], [93.59055328, 8.09111118], [93.59055328, 8.09055519], [93.59083557, 8.09027863], [93.5908432, 8.08971977], [93.59055328, 8.08944511], [93.59055328, 8.08916664], [93.59083557, 8.08888912], [93.5908432, 8.08833027], [93.59055328, 8.08805656], [93.59055328, 8.0872221], [93.59083557, 8.08694363], [93.59083557, 8.08611012], [93.59055328, 8.08583355], [93.59055328, 8.08305645], [93.5908432, 8.08278275], [93.5908432, 8.0819416], [93.59111023, 8.08166599], [93.59111023, 8.08111], [93.59139252, 8.08083439], [93.59139252, 8.08055592], [93.59194183, 8.07999992], [93.59194183, 8.07971001], [93.59222412, 8.07944393], [93.59222412, 8.07916641], [93.59249878, 8.07888985], [93.59249878, 8.07777977], [93.59278107, 8.07750034], [93.59278107, 8.07694435], [93.59305573, 8.07666779], [93.59305573, 8.07639027], [93.59278107, 8.07611179], [93.59278107, 8.0755558], [93.59249878, 8.07528019], [93.59249878, 8.07499886], [93.59222412, 8.07472134], [93.59222412, 8.07444572], [93.59194183, 8.07416534], [93.59194183, 8.07388973], [93.59166718, 8.07360935], [93.59166718, 8.07333279], [93.59139252, 8.07305527], [93.59139252, 8.07249928], [93.59111023, 8.0722208], [93.59111023, 8.07166672], [93.59083557, 8.0713892], [93.5908432, 8.07000065], [93.59055328, 8.06972122], [93.59083557, 8.06944466], [93.59083557, 8.06861115], [93.59111023, 8.06833267], [93.59111023, 8.0672226], [93.59139252, 8.06583309], [93.59166718, 8.06555462], [93.59166718, 8.06527901], [93.59194183, 8.06500053], [93.59194183, 8.06471062], [93.59333038, 8.06333256], [93.59361267, 8.06333256], [93.59388733, 8.06305695], [93.59416962, 8.06305885], [93.59443665, 8.06278133], [93.5947113, 8.06278133], [93.59527588, 8.06221962], [93.59527588, 8.06194496], [93.59555817, 8.06166744], [93.59555817, 8.06138802], [93.59583282, 8.06110954], [93.59583282, 8.06083202], [93.59610748, 8.06055737], [93.59610748, 8.06000042], [93.59638977, 8.06000042], [93.59750366, 8.05888844], [93.59749603, 8.05832958], [93.59777832, 8.05805588], [93.59777832, 8.05611229], [93.59860992, 8.05527782], [93.59860992, 8.05500031], [93.59889221, 8.05472183], [93.59860992, 8.05444431], [93.59889221, 8.05416584], [93.59889221, 8.05389023], [93.59916687, 8.05360985], [93.59944153, 8.05360985], [93.59999847, 8.05305576], [93.59999847, 8.05277824], [93.59972382, 8.05249977], [93.59972382, 8.05194378], [93.59944153, 8.05166626], [93.59944153, 8.05138779], [93.59971619, 8.05111027], [93.59972382, 8.0508337], [93.59999847, 8.05055618], [93.60056305, 8.05056], [93.60083771, 8.05027962], [93.60111237, 8.05027962], [93.60138702, 8.05000019], [93.60138702, 8.0494442], [93.60111237, 8.04916763], [93.60111237, 8.04833412], [93.60083008, 8.04805565], [93.60083008, 8.04722118], [93.60055542, 8.04694557], [93.60055542, 8.04555511], [93.60083008, 8.04527664], [93.60083771, 8.04472065], [93.60111237, 8.04444313], [93.60111237, 8.04416656], [93.59889221, 8.04194546], [93.59889221, 8.04166698], [93.59805298, 8.04083347], [93.59750366, 8.04083347], [93.59722137, 8.040555], [93.5966568, 8.04056168], [93.59500122, 8.03889084], [93.59500122, 8.03861141], [93.59471893, 8.03833294], [93.59388733, 8.03805733], [93.59346771, 8.0379858], [93.59278107, 8.0377903], [93.59249878, 8.03777885], [93.59166718, 8.03861141], [93.59166718, 8.03888893], [93.59139252, 8.0391674], [93.59139252, 8.0397234], [93.59055328, 8.040555], [93.59055328, 8.04083061], [93.58999634, 8.04139137], [93.58999634, 8.04166889], [93.58889008, 8.04277706], [93.58889008, 8.04305458], [93.58860779, 8.04333305], [93.58860779, 8.04444122], [93.58777618, 8.04528046], [93.58750153, 8.04527664], [93.58694458, 8.04583263], [93.58682251, 8.04679489], [93.58654785, 8.04728127], [93.5861969, 8.04762936], [93.58599091, 8.04797268], [93.58571625, 8.04831982], [93.5851593, 8.04915237], [93.58487701, 8.04935932], [93.58446503, 8.04929066], [93.58418274, 8.04915237], [93.58405304, 8.04935932], [93.58410645, 8.04978085], [93.58355713, 8.0496397], [93.58335114, 8.04908085], [93.58265686, 8.04901314], [93.58222198, 8.04944134], [93.58222198, 8.04972172], [93.58194733, 8.05000019], [93.58194733, 8.05027771], [93.58139038, 8.0508337], [93.58139038, 8.05111217], [93.58110809, 8.05138779], [93.58110809, 8.05194378], [93.58083344, 8.05222225], [93.58083344, 8.05305576], [93.58055878, 8.05333424], [93.58055878, 8.05360985], [93.58055115, 8.05389214], [93.58082581, 8.05430889], [93.58110046, 8.05486298], [93.58110046, 8.05514145], [93.58087921, 8.05527973], [93.5803833, 8.05545807], [93.57997131, 8.05552673], [93.57982635, 8.05601215], [93.58030701, 8.05616474], [93.58030701, 8.05651093], [93.58003235, 8.05692959], [93.5796814, 8.05692768], [93.57919312, 8.0569973], [93.57892609, 8.05788326], [93.57836914, 8.05809116], [93.57781219, 8.05788326], [93.57725525, 8.05753708], [93.57666779, 8.05778122], [93.57639313, 8.05778122], [93.57554626, 8.05860996], [93.57555389, 8.05888844], [93.57527924, 8.05916595], [93.57527924, 8.05972195], [93.57389069, 8.06110954], [93.57389069, 8.06166744], [93.5736084, 8.06194496], [93.57360077, 8.06221962], [93.57333374, 8.06250095], [93.57333374, 8.06277561], [93.57277679, 8.0633297], [93.57277679, 8.06388855], [93.57250214, 8.06416702], [93.57250214, 8.06471062], [93.57221985, 8.06499863], [93.57221985, 8.06555462], [93.57194519, 8.06583309], [93.57194519, 8.06611061], [93.5716629, 8.06638908], [93.5716629, 8.0672226], [93.57194519, 8.06750107], [93.57194519, 8.06777668], [93.57250214, 8.06916714], [93.57250214, 8.06944466], [93.57277679, 8.06972122], [93.57277679, 8.07000065], [93.57305908, 8.07027721], [93.57305908, 8.07055473], [93.57277679, 8.07083321], [93.57277679, 8.07111073], [93.57333374, 8.07166672], [93.57332611, 8.07194138], [93.57369995, 8.07231522], [93.57417297, 8.07277966], [93.57444763, 8.07277966], [93.57472229, 8.07306004], [93.57527924, 8.07305527], [93.57555389, 8.07333279], [93.57611084, 8.07333279], [93.5763855, 8.07361126], [93.57666779, 8.07360935], [93.57694244, 8.07390118], [93.57917023, 8.07390118], [93.57943726, 8.07360935], [93.57971954, 8.07361126], [93.58027649, 8.07305527], [93.58055878, 8.07306004], [93.58082581, 8.07277966], [93.58110809, 8.07277966], [93.58131409, 8.07305527], [93.58145142, 8.07354069], [93.58138275, 8.07416534], [93.58131409, 8.07492733], [93.58130646, 8.07527065], [93.58152008, 8.07603645], [93.58138275, 8.07652187], [93.58158875, 8.07713985], [93.58138275, 8.07790756], [93.5810318, 8.0780468], [93.58047485, 8.07818317], [93.58005524, 8.07818317], [93.57971954, 8.07833385], [93.58000183, 8.07861233], [93.58000183, 8.07944107], [93.58055878, 8.07999992], [93.58103943, 8.08020687], [93.58139038, 8.08041477], [93.58145905, 8.08069324], [93.58103943, 8.08069324], [93.58027649, 8.08083439], [93.57945251, 8.08208275], [93.57917023, 8.08236122], [93.57875824, 8.08256817], [93.57826996, 8.08277607], [93.57798767, 8.08326054], [93.57771301, 8.08346939], [93.57750702, 8.08374691], [93.57736206, 8.08409309], [93.5770874, 8.08430099], [93.57688141, 8.08478642], [93.57666779, 8.08499336], [93.5762558, 8.08533955], [93.57604218, 8.08575726], [93.57569885, 8.08596039], [93.57549286, 8.0865202], [93.57541656, 8.08673], [93.57492828, 8.08658886], [93.57444763, 8.0872221], [93.57416534, 8.08750057], [93.5737381, 8.08882046], [93.57346344, 8.08916664], [93.57318115, 8.08937645], [93.57297516, 8.08965206], [93.57276154, 8.09013653], [93.57269287, 8.09055519], [93.57248688, 8.09076214], [93.57213593, 8.09048367], [93.57206726, 8.09013653], [93.57206726, 8.08986187], [93.57110596, 8.08971977], [93.57055664, 8.09027863], [93.57055664, 8.09055519], [93.56999969, 8.09111118], [93.56999969, 8.0913887], [93.57027435, 8.09166718], [93.57027435, 8.09333324], [93.56999969, 8.09360886], [93.56999969, 8.09388924], [93.56972504, 8.09416676], [93.56972504, 8.09444523], [93.56944275, 8.09472084], [93.56944275, 8.09500122], [93.56916809, 8.09527683], [93.56916809, 8.0961113], [93.56944275, 8.09638882], [93.56944275, 8.09694481], [93.56972504, 8.09722328], [93.56972504, 8.09749889], [93.57055664, 8.09833336], [93.57055664, 8.09861088], [93.57111359, 8.09916687], [93.57111359, 8.09944534], [93.5716629, 8.09999943], [93.5716629, 8.10027695], [93.57194519, 8.10055542], [93.57195282, 8.10111237], [93.57221985, 8.10138988], [93.57221985, 8.10305595], [93.57250214, 8.10333443], [93.57250214, 8.10388756], [93.57277679, 8.10416794], [93.57277679, 8.10472202], [93.57305908, 8.10499954], [93.57305908, 8.10555553], [93.57333374, 8.10583401], [93.57333374, 8.10666561], [93.5736084, 8.10694408], [93.5736084, 8.10805607], [93.57367706, 8.10833168], [93.57402802, 8.10868073], [93.57485962, 8.10902691], [93.57514191, 8.10929966], [93.57514191, 8.10978985], [93.57493591, 8.10993195], [93.57460785, 8.1097517], [93.57417297, 8.10951042], [93.5736084, 8.10923386], [93.57250214, 8.10888767], [93.57221985, 8.10854244], [93.57194519, 8.1077776], [93.57195282, 8.10750008], [93.5716629, 8.1072197], [93.5716629, 8.10694408], [93.5708313, 8.10611153], [93.57055664, 8.10611153], [93.56833649, 8.10833359], [93.56833649, 8.10861015], [93.5680542, 8.10888767], [93.5680542, 8.10916615], [93.56777954, 8.10944366], [93.56778717, 8.10972023], [93.56749725, 8.11000919], [93.56749725, 8.11027813], [93.5672226, 8.11055565], [93.5672226, 8.11083221], [93.56555176, 8.11250019], [93.56555176, 8.11277771], [93.56500244, 8.11333466], [93.56500244, 8.11361027], [93.56416321, 8.11444378], [93.56388855, 8.11444378], [93.56361389, 8.11472321], [93.5633316, 8.11472034], [93.56305695, 8.11500072], [93.56277466, 8.11500072], [93.56222534, 8.11555672], [93.56222534, 8.11583233], [93.56194305, 8.1161108], [93.56194305, 8.11666679], [93.56166077, 8.11693954], [93.5616684, 8.11777878], [93.56138611, 8.11805534], [93.56138611, 8.11861134], [93.5616684, 8.11888885], [93.5616684, 8.11944485], [93.56194305, 8.11972332], [93.56194305, 8.12000084], [93.56277466, 8.1208334], [93.56361389, 8.1208334], [93.56388855, 8.12111092], [93.56416321, 8.12111092], [93.56445313, 8.1213913], [93.56555176, 8.1213913], [93.56582642, 8.12167168], [93.56749725, 8.12167168], [93.56778717, 8.12195015], [93.56833649, 8.12194538], [93.56861115, 8.12222099], [93.5688858, 8.12222099], [93.56916809, 8.12250137], [93.56944275, 8.12250137], [93.56973267, 8.12277889], [93.56999969, 8.12277889], [93.57026672, 8.12306023], [93.5708313, 8.12305546], [93.57111359, 8.12333298], [93.57138824, 8.12333298], [93.5716629, 8.12361145], [93.57194519, 8.12361145], [93.57238007, 8.12404633], [93.57250214, 8.1241703], [93.57555389, 8.12416744], [93.57575989, 8.12436962], [93.57583618, 8.12444305], [93.5763855, 8.12444305], [93.57666779, 8.12472343], [93.57696533, 8.12474823], [93.5772171, 8.12501144], [93.57749939, 8.12501144], [93.57776642, 8.12527943], [93.57861328, 8.12527943]]], [[[93.40555573, 7.90305519], [93.40528107, 7.90333319], [93.40444183, 7.90333319], [93.40416718, 7.90305519], [93.4016571, 7.90306091], [93.40139008, 7.90278101], [93.40000153, 7.90278101], [93.39971924, 7.90250111], [93.39861298, 7.90250111], [93.39833069, 7.90222311], [93.39805603, 7.90222979], [93.39778137, 7.90194178], [93.39749908, 7.90194511], [93.39638519, 7.90083218], [93.39638519, 7.90055704], [93.39527893, 7.8994441], [93.39527893, 7.89916611], [93.39499664, 7.89888811], [93.39499664, 7.89861012], [93.39472198, 7.89833498], [93.39472198, 7.89805603], [93.39444733, 7.89777803], [93.39444733, 7.89750004], [93.39417267, 7.89722013], [93.39416504, 7.89638805], [93.39389038, 7.89611006], [93.39389038, 7.89583397], [93.39360809, 7.89555597], [93.39360809, 7.89527798], [93.39332581, 7.89499998], [93.39332581, 7.89443922], [93.39305878, 7.89416599], [93.39305878, 7.89361], [93.39277649, 7.89333391], [93.39277649, 7.89305592], [93.39250183, 7.89277792], [93.39250183, 7.89249992], [93.39167023, 7.89167023], [93.39138794, 7.89167023], [93.39111328, 7.89138985], [93.39083099, 7.89138985], [93.39055634, 7.89110994], [93.39027405, 7.89111185], [93.38972473, 7.89055586], [93.38972473, 7.89027786], [93.38861084, 7.88917017], [93.38861084, 7.88888979], [93.38804626, 7.88833094], [93.38757324, 7.88798523], [93.38687897, 7.88743114], [93.3861084, 7.88694286], [93.38583374, 7.88694286], [93.38527679, 7.88639021], [93.38500214, 7.88639021], [93.38483429, 7.88622284], [93.38471985, 7.88610888], [93.38388824, 7.88611221], [93.38361359, 7.88583279], [93.38277435, 7.88583279], [93.38249969, 7.88555479], [93.38194275, 7.88556004], [93.38111877, 7.8847208], [93.38111115, 7.8836112], [93.38027954, 7.88277721], [93.38027954, 7.88249922], [93.37999725, 7.88222122], [93.3797226, 7.88249922], [93.37889099, 7.88249922], [93.37833405, 7.88194513], [93.37805176, 7.88194513], [93.3777771, 7.88166714], [93.37722015, 7.88166714], [93.3769455, 7.88194513], [93.37666321, 7.88194513], [93.37638855, 7.88222122], [93.37555695, 7.88222122], [93.37526703, 7.88249922], [93.37499237, 7.88249922], [93.37473297, 7.88277912], [93.37444305, 7.88277912], [93.3741684, 7.88305998], [93.37388611, 7.88305521], [93.37361145, 7.88333321], [93.3730545, 7.88333321], [93.37277985, 7.8836112], [93.37249756, 7.8836112], [93.37194824, 7.88416719], [93.37194824, 7.88444281], [93.37166595, 7.8847208], [93.37166595, 7.88610888], [93.37110901, 7.88667011], [93.37083435, 7.88666821], [93.37055206, 7.88694286], [93.3702774, 7.88666821], [93.3694458, 7.88667011], [93.36915588, 7.88639021], [93.36888885, 7.88639021], [93.36860657, 7.88610888], [93.36805725, 7.88611221], [93.36777496, 7.88583279], [93.36750031, 7.88583088], [93.36694336, 7.88639021], [93.36611938, 7.88639021], [93.3658371, 7.88667011], [93.36528015, 7.88667011], [93.36499786, 7.88639021], [93.36444092, 7.88639021], [93.36416626, 7.88667011], [93.3638916, 7.88667011], [93.36332703, 7.88723087], [93.36277771, 7.88723087], [93.36250305, 7.88749981], [93.36165619, 7.88749981], [93.36110687, 7.88792086], [93.36000061, 7.88791704], [93.35944366, 7.88847303], [93.35916901, 7.88847303], [93.35832977, 7.88861179], [93.35778046, 7.88888979], [93.35749817, 7.88888979], [93.35639191, 7.88888979], [93.35610962, 7.88917017], [93.35583496, 7.88916779], [93.35555267, 7.88944387], [93.35527802, 7.88944387], [93.35388947, 7.89083385], [93.35333252, 7.89083195], [93.3527832, 7.89138985], [93.35250092, 7.89138985], [93.35028076, 7.89361], [93.35028076, 7.893888], [93.34972382, 7.89444399], [93.34972382, 7.89555597], [93.34944153, 7.89583397], [93.34944153, 7.896101], [93.34916687, 7.89638805], [93.34916687, 7.89666605], [93.34889221, 7.89694023], [93.34889221, 7.89888811], [93.34777832, 7.90000105], [93.34638977, 7.90000105], [93.34610748, 7.90028095], [93.34583282, 7.90028095], [93.34443665, 7.90167093], [93.34443665, 7.90250111], [93.34416962, 7.90277719], [93.34444427, 7.90305519], [93.34444427, 7.90472317], [93.34416962, 7.90500116], [93.34416962, 7.90527678], [93.34388733, 7.90555477], [93.34388733, 7.90583277], [93.34361267, 7.90611076], [93.34361267, 7.90638924], [93.34416962, 7.90694523], [93.34471893, 7.90694523], [93.34500122, 7.90666723], [93.34583282, 7.90666914], [93.3466568, 7.90750122], [93.3466568, 7.90777922], [93.34694672, 7.90806007], [93.34694672, 7.9100008], [93.34666443, 7.91027689], [93.34666443, 7.91166687], [93.34638977, 7.91194296], [93.34638977, 7.91222095], [93.34610748, 7.91249895], [93.34610748, 7.91305494], [93.34583282, 7.91332912], [93.34583282, 7.91388988], [93.34555817, 7.91416502], [93.34555817, 7.91444302], [93.34527588, 7.91472197], [93.34527588, 7.91499996], [93.34500122, 7.91527796], [93.34500122, 7.91555595], [93.34443665, 7.91611004], [93.34443665, 7.91638994], [93.34333038, 7.91750002], [93.34263611, 7.91813087], [93.34263611, 7.91883087], [93.3429184, 7.91930723], [93.34326172, 7.92013884], [93.34361267, 7.92083406], [93.34361267, 7.92111206], [93.34471893, 7.92222214], [93.34471893, 7.92250013], [93.34777832, 7.92555714], [93.34777832, 7.92583179], [93.34805298, 7.92610979], [93.34805298, 7.92638779], [93.34833527, 7.92666578], [93.34833527, 7.92694521], [93.35083008, 7.92944479], [93.35083008, 7.92972088], [93.35111237, 7.93000078], [93.35111237, 7.93027878], [93.35138702, 7.93055487], [93.35138702, 7.93083286], [93.35166931, 7.93111086], [93.35166931, 7.93166685], [93.35154724, 7.93178797], [93.35111237, 7.93222284], [93.35083008, 7.93194485], [93.35083008, 7.93166685], [93.34944153, 7.93027878], [93.34944153, 7.93000078], [93.34722137, 7.92778111], [93.34694672, 7.92778111], [93.3466568, 7.9275012], [93.34638977, 7.9275012], [93.34629822, 7.92740917], [93.34610748, 7.92722321], [93.34555817, 7.92721987], [93.34527588, 7.9275012], [93.34500122, 7.9275012], [93.34500885, 7.9286108], [93.34471893, 7.92889118], [93.34471893, 7.93000078], [93.34500122, 7.93027878], [93.34500122, 7.93083286], [93.34638977, 7.93222284], [93.3466568, 7.93220901], [93.34687805, 7.93242979], [93.34694672, 7.93250084], [93.34722137, 7.93250084], [93.34749603, 7.93278122], [93.34777832, 7.93278122], [93.34805298, 7.93305922], [93.34860992, 7.93305492], [93.34916687, 7.93361092], [93.34945679, 7.93362188], [93.34971619, 7.93389082], [93.34999847, 7.93388891], [93.35055542, 7.9344449], [93.35083008, 7.93444109], [93.35193634, 7.93556023], [93.35221863, 7.93555498], [93.35250092, 7.93583298], [93.35250092, 7.93611097], [93.35388947, 7.93749905], [93.35388947, 7.93777704], [93.35555267, 7.93944597], [93.35555267, 7.9397192], [93.35639191, 7.94056177], [93.35694122, 7.94055605], [93.35805511, 7.94166517], [93.35758209, 7.9421401], [93.35749817, 7.94222212], [93.35722351, 7.94194412], [93.35694122, 7.94194412], [93.35639191, 7.94139004], [93.35583496, 7.94139004], [93.35527802, 7.94083405], [93.35472107, 7.94083405], [93.35444641, 7.94111204], [93.35416412, 7.94111204], [93.35388947, 7.94139004], [93.35361481, 7.94139004], [93.35250092, 7.94250011], [93.35193634, 7.94250011], [93.35166931, 7.94278002], [93.35138702, 7.94278002], [93.35111237, 7.94305992], [93.35083008, 7.94305611], [93.35083008, 7.94332886], [93.35028076, 7.94388819], [93.35028076, 7.94416618], [93.35083008, 7.94472218], [93.35083008, 7.94500017], [93.34944153, 7.94500017], [93.34777832, 7.9433341], [93.34750366, 7.9433341], [93.34694672, 7.94277811], [93.3466568, 7.94278002], [93.34555817, 7.94166994], [93.34555817, 7.94138098], [93.34471893, 7.94055605], [93.34443665, 7.94056177], [93.34416962, 7.94027996], [93.34388733, 7.94027996], [93.34306335, 7.9394412], [93.34305573, 7.93916798], [93.34361267, 7.93861103], [93.34471893, 7.93972111], [93.34500885, 7.9397192], [93.34527588, 7.9399991], [93.34555817, 7.9399991], [93.34610748, 7.94056177], [93.34805298, 7.94056177], [93.34860992, 7.9399991], [93.34860992, 7.9394412], [93.34805298, 7.93888903], [93.34805298, 7.93777704], [93.34815979, 7.9366312], [93.3477478, 7.93559217], [93.34663391, 7.93468904], [93.34583282, 7.9344449], [93.34555817, 7.9344449], [93.34416962, 7.93305492], [93.34416962, 7.93277693], [93.34305573, 7.93166685], [93.34139252, 7.93333292], [93.34139252, 7.93361092], [93.33999634, 7.9350009], [93.33972168, 7.9350009], [93.3391571, 7.93556023], [93.33860779, 7.93555498], [93.33833313, 7.93583298], [93.33805847, 7.93583298], [93.33777618, 7.93611097], [93.33721924, 7.93611097], [93.33693695, 7.93638897], [93.33528137, 7.93638897], [93.33499908, 7.93611097], [93.33472443, 7.93611097], [93.33453369, 7.93592215], [93.33444214, 7.93583298], [93.33388519, 7.93583298], [93.33305359, 7.93499899], [93.33291626, 7.93451118], [93.3326416, 7.93381596], [93.3326416, 7.93256712], [93.33215332, 7.93194294], [93.33152771, 7.9309721], [93.33152771, 7.93062496], [93.33139038, 7.93055487], [93.33110809, 7.93028116], [93.33110809, 7.93000078], [93.33082581, 7.92972088], [93.33083344, 7.92916679], [93.33055878, 7.9288888], [93.33055878, 7.92806101], [93.33194733, 7.92667103], [93.33194733, 7.92640018], [93.33222198, 7.92610979], [93.33298492, 7.92548609], [93.33277893, 7.92527819], [93.33222198, 7.92471981], [93.33222198, 7.9244442], [93.33139038, 7.92361021], [93.33110809, 7.92361021], [93.33083344, 7.92333221], [93.33027649, 7.9233408], [93.32971954, 7.92389011], [93.32917023, 7.92388821], [93.32805634, 7.92500019], [93.32666779, 7.92500019], [93.32583618, 7.92583179], [93.32555389, 7.92610979], [93.32527924, 7.92610979], [93.32499695, 7.92640018], [93.32305908, 7.92640018], [93.32277679, 7.92667103], [93.32250214, 7.92667103], [93.3216629, 7.9275012], [93.3216629, 7.92778111], [93.32138824, 7.92806101], [93.32138824, 7.92917109], [93.31999969, 7.93055916], [93.31972504, 7.93055487], [93.31944275, 7.93083286], [93.31944275, 7.93111086], [93.31916809, 7.93138885], [93.31916809, 7.93220901], [93.31861115, 7.93278122], [93.31833649, 7.93278122], [93.31804657, 7.93305922], [93.31777954, 7.93305492], [93.3172226, 7.93361092], [93.3172226, 7.9344449], [93.31749725, 7.9347229], [93.31777954, 7.93472099], [93.3180542, 7.93499899], [93.3180542, 7.93527699], [93.31861115, 7.93583298], [93.31861115, 7.93611097], [93.31916809, 7.93666983], [93.31916809, 7.9399991], [93.3188858, 7.9402771], [93.3188858, 7.94083405], [93.31861115, 7.94111204], [93.31861115, 7.94166517], [93.31833649, 7.94194412], [93.31833649, 7.94250011], [93.3180542, 7.94277811], [93.3180542, 7.94305611], [93.31639099, 7.94472218], [93.31639099, 7.94500017], [93.3152771, 7.94611216], [93.3152771, 7.94638777], [93.31472015, 7.94694424], [93.31472015, 7.94721985], [93.3144455, 7.94750023], [93.3144455, 7.94777822], [93.3125, 7.94971991], [93.3125, 7.94999981], [93.31194305, 7.9505558], [93.31194305, 7.95166588], [93.31222534, 7.95194387], [93.31223297, 7.95221996], [93.31194305, 7.95249987], [93.31194305, 7.9527812], [93.3116684, 7.9530611], [93.3116684, 7.9538908], [93.31138611, 7.95416689], [93.31138611, 7.95555496], [93.31111145, 7.9558301], [93.31111145, 7.95750093], [93.31083679, 7.95778084], [93.31083679, 7.96027708], [93.3105545, 7.96055508], [93.3105545, 7.96194506], [93.31083679, 7.96222115], [93.31083679, 7.96251011], [93.31111145, 7.96277905], [93.31229401, 7.9631958], [93.31298828, 7.96388912], [93.31388855, 7.96486282], [93.31472015, 7.96555519], [93.31500244, 7.96583319], [93.31500244, 7.96666813], [93.3152771, 7.96694279], [93.3152771, 7.96722078], [93.31583405, 7.96777821], [93.31583405, 7.9680562], [93.3161087, 7.9683342], [93.3161087, 7.96860886], [93.31639099, 7.96889019], [93.31639099, 7.96999979], [93.31694794, 7.97056007], [93.3172226, 7.97055578], [93.31777954, 7.97111177], [93.31804657, 7.97111177], [93.31833649, 7.97138977], [93.31861115, 7.97138977], [93.3188858, 7.97167015], [93.31916809, 7.97166586], [93.31944275, 7.97194386], [93.31972504, 7.97194386], [93.31999969, 7.97222185], [93.32055664, 7.97222185], [93.32064819, 7.97231293], [93.32110596, 7.97278023], [93.32138824, 7.97277784], [93.32305908, 7.97444391], [93.32305908, 7.97472], [93.3236084, 7.9752779], [93.3236084, 7.9755559], [93.32389069, 7.97583389], [93.32389069, 7.97666597], [93.32416534, 7.97694397], [93.32416534, 7.9808321], [93.32389069, 7.9811101], [93.32388306, 7.98222017], [93.3236084, 7.98250103], [93.3236084, 7.9841671], [93.32333374, 7.9844451], [93.32333374, 7.98555517], [93.32305908, 7.98583317], [93.32305908, 7.98972082], [93.32250214, 7.99027681], [93.32250214, 7.99055481], [93.32221985, 7.9908309], [93.32221985, 7.9913888], [93.32250214, 7.99167013], [93.32250214, 7.99306011], [93.32332611, 7.99388981], [93.3236084, 7.99388981], [93.32416534, 7.99444294], [93.32416534, 7.99472094], [93.32444763, 7.99499989], [93.32444763, 7.99611187], [93.32416534, 7.99638987], [93.32417297, 7.99721909], [93.32444763, 7.99749994], [93.32444763, 7.99777794], [93.32499695, 7.99832916], [93.32499695, 7.99861193], [93.32555389, 7.99916601], [93.32555389, 7.99944401], [93.32583618, 7.999722], [93.32583618, 8.0], [93.32583618, 8.00083447], [93.32611084, 8.00111198], [93.32611084, 8.0013876], [93.3263855, 8.00166607], [93.3263855, 8.00194359], [93.32666779, 8.00222015], [93.32666779, 8.00249958], [93.32695007, 8.00277996], [93.32818604, 8.00358009], [93.32950592, 8.00503922], [93.330513, 8.00634003], [93.33126068, 8.0068779], [93.33153534, 8.00701523], [93.33202362, 8.00750065], [93.33222961, 8.00784683], [93.33222961, 8.00826359], [93.33230591, 8.00861073], [93.33341217, 8.00981808], [93.33508301, 8.01078892], [93.33577728, 8.01113605], [93.33611298, 8.01194477], [93.33638763, 8.01222324], [93.33750153, 8.01222324], [93.33777618, 8.01194477], [93.33860779, 8.01194477], [93.33889008, 8.01166725], [93.34027863, 8.01167107], [93.34055328, 8.01139069], [93.34092712, 8.01056099], [93.34121704, 8.01049137], [93.34211731, 8.01062965], [93.34259796, 8.01062965], [93.34278107, 8.01139069], [93.34306335, 8.01139069], [93.34555817, 8.01388931], [93.34555817, 8.01416683], [93.34583282, 8.0144453], [93.34583282, 8.01472092], [93.34610748, 8.0150013], [93.34610748, 8.01527691], [93.34638977, 8.01555538], [93.34638977, 8.01583099], [93.34694672, 8.01638889], [93.34749603, 8.01638889], [93.34889221, 8.0150013], [93.34889221, 8.01472092], [93.34916687, 8.0144453], [93.34916687, 8.01416683], [93.34972382, 8.01361084], [93.34971619, 8.01306152], [93.34999847, 8.01277924], [93.34999847, 8.01167107], [93.34971619, 8.01139069], [93.34971619, 8.01056099], [93.34999847, 8.01028061], [93.34999847, 8.00971985], [93.35083008, 8.0088892], [93.35111237, 8.00889111], [93.35166931, 8.00833035], [93.35221863, 8.00833225], [93.35250092, 8.00805664], [93.35388947, 8.00806141], [93.35415649, 8.00778103], [93.35472107, 8.00778103], [93.35500336, 8.00806141], [93.35555267, 8.00805664], [93.35583496, 8.00833225], [93.35610962, 8.00833225], [93.35639191, 8.00861073], [93.35666656, 8.00861073], [93.35694885, 8.00889111], [93.35721588, 8.00889111], [93.35749817, 8.00917053], [93.35832977, 8.00916672], [93.35861206, 8.00944519], [93.35944366, 8.00944519], [93.35962677, 8.00962543], [93.35972595, 8.00972271], [93.36000061, 8.00972271], [93.36011505, 8.00983906], [93.36027527, 8.01000118], [93.36055756, 8.01000118], [93.36083221, 8.01028061], [93.3611145, 8.0102787], [93.36305237, 8.01222324], [93.36332703, 8.01222134], [93.3638916, 8.01277924], [93.36416626, 8.01277733], [93.36444092, 8.01305485], [93.36472321, 8.01333332], [93.36499786, 8.01333332], [93.36611176, 8.0144453], [93.36611938, 8.01472092], [93.3666687, 8.01527691], [93.3666687, 8.01555538], [93.36694336, 8.0158329], [93.36694336, 8.01611137], [93.36722565, 8.01638889], [93.36723328, 8.01665974], [93.3694458, 8.01888943], [93.3694458, 8.01916695], [93.36972046, 8.01944637], [93.36972046, 8.01972103], [93.37000275, 8.01999855], [93.37000275, 8.02027702], [93.3702774, 8.02055454], [93.3702774, 8.02083397], [93.37055206, 8.02111244], [93.37055206, 8.02138996], [93.3713913, 8.02222157], [93.37194824, 8.02222157], [93.37213135, 8.02240753], [93.3722229, 8.02250195], [93.37249756, 8.02222157], [93.37277985, 8.02250195], [93.37361145, 8.02250195], [93.37388611, 8.02279091], [93.3741684, 8.02279091], [93.37444305, 8.02250195], [93.37499237, 8.02250195], [93.37526703, 8.02279091], [93.37610626, 8.02279091], [93.37638855, 8.02305984], [93.3769455, 8.02305603], [93.37722015, 8.02333355], [93.37750244, 8.02333355], [93.3777771, 8.02361202], [93.37805176, 8.02361202], [93.37889099, 8.02444363], [93.37916565, 8.02444363], [93.37944794, 8.0247221], [93.37999725, 8.0247221], [93.38027954, 8.02444363], [93.3805542, 8.02444363], [93.38194275, 8.02305603], [93.38223267, 8.02305984], [93.38249969, 8.02279091], [93.38276672, 8.02279091], [93.38305664, 8.02250195], [93.38360596, 8.02250195], [93.38388824, 8.02222157], [93.3841629, 8.02222157], [93.38444519, 8.02194309], [93.38471985, 8.02194309], [93.38527679, 8.02138996], [93.38555908, 8.02139187], [93.38582611, 8.02111244], [93.38666534, 8.02111244], [93.38694763, 8.02083397], [93.38805389, 8.02083397], [93.38833618, 8.02055454], [93.38861084, 8.02056026], [93.38944244, 8.01972103], [93.38999939, 8.01972103], [93.39027405, 8.01944637], [93.39083099, 8.01944637], [93.39111328, 8.01972103], [93.39221954, 8.01972103], [93.39250183, 8.01944637], [93.39305878, 8.01944637], [93.39360809, 8.01888943], [93.39389038, 8.01888943], [93.39417267, 8.01861095], [93.39527893, 8.01861095], [93.39555359, 8.01833344], [93.39611053, 8.01833344], [93.39638519, 8.01805496], [93.39694214, 8.01805973], [93.3972168, 8.01777935], [93.39749908, 8.01777935], [93.39778137, 8.01750088], [93.39805603, 8.01750088], [93.39833069, 8.01722145], [93.39861298, 8.01722336], [93.40000153, 8.0158329], [93.40000153, 8.01555538], [93.40055847, 8.0150013], [93.40055847, 8.01472092], [93.40110779, 8.01416683], [93.40110779, 8.01388931], [93.40277863, 8.01222134], [93.40305328, 8.01222324], [93.40361023, 8.01166725], [93.40389252, 8.01167107], [93.40416718, 8.01139069], [93.40444183, 8.01139069], [93.40471649, 8.01111126], [93.40499878, 8.01111126], [93.40528107, 8.01083279], [93.40555573, 8.01083279], [93.40583038, 8.01055527], [93.40638733, 8.01056099], [93.40777588, 8.00917053], [93.40777588, 8.00889111], [93.4091568, 8.0074892], [93.40965271, 8.00708294], [93.40979004, 8.00659847], [93.40979004, 8.00597572], [93.40944672, 8.00528336], [93.4090271, 8.00521183], [93.40798187, 8.00500488], [93.40721893, 8.00500011], [93.40583038, 8.00361156], [93.40583038, 8.00333214], [93.40555573, 8.00305557], [93.40555573, 8.00249958], [93.4052887, 8.00222015], [93.40528107, 8.00194359], [93.40499878, 8.00166607], [93.40499878, 8.0013876], [93.40471649, 8.00111198], [93.40416718, 8.0], [93.40389252, 7.99832916], [93.40361023, 7.99805593], [93.40361023, 7.99555588], [93.40333557, 7.99527788], [93.40333557, 7.99472094], [93.40305328, 7.99444294], [93.40305328, 7.9913888], [93.40333557, 7.9911108], [93.40305328, 7.99083281], [93.40305328, 7.98999882], [93.40333557, 7.98972321], [93.40333557, 7.98888922], [93.40361023, 7.98861122], [93.40361023, 7.98722315], [93.40389252, 7.98694515], [93.40389252, 7.98638916], [93.40416718, 7.98611116], [93.40416718, 7.98527718], [93.40444183, 7.98500109], [93.40444183, 7.9844451], [93.40472412, 7.9841671], [93.40444183, 7.9838891], [93.40444183, 7.98193979], [93.40416718, 7.98166704], [93.40416718, 7.9811101], [93.40389252, 7.9808321], [93.40389252, 7.98055696], [93.40277863, 7.97944403], [93.40277863, 7.97916603], [93.40249634, 7.97888803], [93.40249634, 7.97861004], [93.40222168, 7.97833395], [93.40222168, 7.97638798], [93.40249634, 7.97610998], [93.40249634, 7.9755559], [93.40277863, 7.9752779], [93.40277863, 7.97445107], [93.40471649, 7.97249985], [93.40471649, 7.97221994], [93.40528107, 7.97166586], [93.40528107, 7.97138977], [93.40611267, 7.97056007], [93.40638733, 7.97056007], [93.40693665, 7.96999979], [93.40750122, 7.96999979], [93.40777588, 7.96972179], [93.40805817, 7.96972179], [93.40833282, 7.9694438], [93.40860748, 7.9694438], [93.41027832, 7.96777821], [93.41027832, 7.96722078], [93.41055298, 7.96694279], [93.41055298, 7.96583319], [93.41083527, 7.96555519], [93.41083527, 7.9649992], [93.41110992, 7.9647212], [93.41110992, 7.96444511], [93.41139221, 7.96416712], [93.41139221, 7.96361113], [93.41166687, 7.96333313], [93.41166687, 7.96305513], [93.41194153, 7.96277714], [93.41194153, 7.96251011], [93.41221619, 7.96222115], [93.41222382, 7.96194506], [93.41416931, 7.96000099], [93.41443634, 7.96000099], [93.41471863, 7.95972109], [93.41527557, 7.959723], [93.41555786, 7.959445], [93.41610718, 7.95944977], [93.41638947, 7.95917177], [93.42082977, 7.95917177], [93.42111206, 7.95944977], [93.42138672, 7.959445], [93.42166901, 7.959723], [93.42222595, 7.95972109], [93.4224472, 7.95994377], [93.42250061, 7.96000099], [93.42277527, 7.96000099], [93.42388916, 7.96111107], [93.42388916, 7.96138906], [93.42416382, 7.96166706], [93.42415619, 7.96194077], [93.42472076, 7.96249914], [93.42472076, 7.96277714], [93.42805481, 7.96611118], [93.4283371, 7.96611118], [93.42881012, 7.96658611], [93.43000031, 7.96778011], [93.4327774, 7.9649992], [93.4327774, 7.96444511], [93.43305206, 7.96416712], [93.43305206, 7.96388912], [93.43332672, 7.96361113], [93.43333435, 7.96305513], [93.43360901, 7.96277714], [93.43360901, 7.96222115], [93.4338913, 7.96194506], [93.4338913, 7.96111107], [93.43416595, 7.96083307], [93.43416595, 7.96027708], [93.43444824, 7.96000099], [93.43444824, 7.95917177], [93.4347229, 7.95889091], [93.4347229, 7.95833111], [93.43499756, 7.95805502], [93.43499756, 7.95777893], [93.43527222, 7.95750093], [93.43527222, 7.95722103], [93.43583679, 7.95666695], [93.43583679, 7.95638895], [93.43638611, 7.95583296], [93.4366684, 7.95583296], [93.43722534, 7.95527887], [93.43805695, 7.95528078], [93.4383316, 7.95500088], [93.43888855, 7.95500088], [93.43916321, 7.95472002], [93.4394455, 7.95472288], [93.43972015, 7.95444489], [93.44000244, 7.95444489], [93.44249725, 7.95194387], [93.44249725, 7.95166588], [93.44416809, 7.94999981], [93.44444275, 7.94999981], [93.44473267, 7.94971991], [93.44499969, 7.94972181], [93.44833374, 7.94638777], [93.4486084, 7.94639015], [93.44917297, 7.94583178], [93.44944763, 7.94583416], [93.45333099, 7.94194412], [93.45361328, 7.94194412], [93.45388794, 7.94166517], [93.45417023, 7.94166994], [93.45500183, 7.94083118], [93.45527649, 7.94083405], [93.45583344, 7.9402771], [93.45610809, 7.94027996], [93.45667267, 7.9397192], [93.45694733, 7.93972111], [93.45777893, 7.93888903], [93.45804596, 7.93888903], [93.45944214, 7.93750095], [93.4597168, 7.93750095], [93.46138763, 7.93583107], [93.46111298, 7.93583298], [93.46250153, 7.9344449], [93.46250153, 7.93416691], [93.46277618, 7.93388891], [93.46277618, 7.93361092], [93.46305847, 7.93333292], [93.46305847, 7.93305492], [93.46333313, 7.93277693], [93.46333313, 7.93250084], [93.46360779, 7.93220901], [93.46360779, 7.93194485], [93.46389008, 7.93166685], [93.46389008, 7.93138885], [93.4641571, 7.93111086], [93.46416473, 7.93083286], [93.46499634, 7.93000078], [93.46499634, 7.92972279], [93.46527863, 7.92944479], [93.46527863, 7.92916679], [93.46555328, 7.9288888], [93.46555328, 7.92806101], [93.4658432, 7.92778111], [93.4658432, 7.92610979], [93.46611023, 7.92583179], [93.46611023, 7.9241662], [93.46639252, 7.92388821], [93.46639252, 7.92250013], [93.46638489, 7.92089319], [93.46645355, 7.91992283], [93.4661026, 7.91888094], [93.46611023, 7.91777802], [93.46611023, 7.91750002], [93.4658432, 7.9172101], [93.46583557, 7.91694403], [93.46555328, 7.91666603], [93.46555328, 7.91611195], [93.46583557, 7.91583395], [93.46583557, 7.91499996], [93.46611023, 7.91472197], [93.46611023, 7.91444302], [93.46639252, 7.91416502], [93.46639252, 7.91388988], [93.46666718, 7.91361189], [93.46666718, 7.91333389], [93.46694183, 7.91305494], [93.46694183, 7.91277695], [93.46721649, 7.91249895], [93.46721649, 7.91222095], [93.46749878, 7.91194296], [93.46749878, 7.91138887], [93.46778107, 7.91111088], [93.46778107, 7.91027689], [93.46805573, 7.90999889], [93.46806335, 7.9097209], [93.46833038, 7.90944481], [93.46833038, 7.90916681], [93.46888733, 7.90861082], [93.46888733, 7.90833282], [93.46944427, 7.90777683], [93.46944427, 7.90694523], [93.46971893, 7.90666723], [93.46971893, 7.90583277], [93.47000122, 7.90555477], [93.47000122, 7.90472317], [93.47027588, 7.90444517], [93.47027588, 7.90361118], [93.47055817, 7.90333319], [93.47055817, 7.90222311], [93.47083282, 7.90194511], [93.47083282, 7.90138912], [93.47110748, 7.90111113], [93.47110748, 7.90083218], [93.47138977, 7.90055704], [93.47138977, 7.90027905], [93.47222137, 7.89943981], [93.47222137, 7.89916611], [93.47250366, 7.89888811], [93.47249603, 7.89833021], [93.47277832, 7.89805603], [93.47277832, 7.89777803], [93.47305298, 7.89750004], [93.47305298, 7.89722013], [93.47333527, 7.89694405], [93.47333527, 7.89666605], [93.47416687, 7.89583397], [93.47416687, 7.89444399], [93.47444153, 7.89416599], [93.47444153, 7.893888], [93.47471619, 7.89361], [93.47472382, 7.89249992], [93.47222137, 7.88999987], [93.47249603, 7.88971901], [93.47250366, 7.88944387], [93.47138977, 7.8883338], [93.47138977, 7.88777781], [93.47166443, 7.88749981], [93.4716568, 7.88694096], [93.47138977, 7.88666821], [93.47138977, 7.88639021], [93.47110748, 7.88610888], [93.47110748, 7.88555479], [93.47083282, 7.88527679], [93.47083282, 7.8836112], [93.47055817, 7.88333321], [93.47055817, 7.88305521], [93.47000122, 7.88249922], [93.46971893, 7.88249922], [93.46944427, 7.88222122], [93.46944427, 7.88194513], [93.46916962, 7.88166714], [93.46916962, 7.88138914], [93.46721649, 7.87944078], [93.46694183, 7.87944508], [93.46679688, 7.87929678], [93.46666718, 7.87916708], [93.46666718, 7.87888908], [93.46639252, 7.87861109], [93.46639252, 7.87750101], [93.46611023, 7.87722301], [93.46611023, 7.87694502], [93.46583557, 7.87666702], [93.46583557, 7.87638903], [93.46527863, 7.87583017], [93.46527863, 7.87555504], [93.46472168, 7.87500095], [93.46472168, 7.8747201], [93.46389008, 7.87388897], [93.46360779, 7.87389088], [93.46340179, 7.87368107], [93.46333313, 7.87361002], [93.46305847, 7.87361002], [93.46166992, 7.87222195], [93.46111298, 7.87222004], [93.46083069, 7.8725009], [93.46028137, 7.8725009], [93.45999908, 7.8727808], [93.4597168, 7.8727808], [93.45944214, 7.87306118], [93.45916748, 7.87305403], [93.45888519, 7.87333202], [93.45722198, 7.87333202], [93.45694733, 7.87361002], [93.45667267, 7.87361002], [93.45639801, 7.87389088], [93.45610809, 7.87389088], [93.45582581, 7.87417078], [93.45527649, 7.87416697], [93.45500183, 7.87444496], [93.45417023, 7.87444496], [93.45305634, 7.87555504], [93.45305634, 7.87583303], [93.45276642, 7.87611103], [93.45277405, 7.87638903], [93.45249939, 7.87666702], [93.45249939, 7.87694502], [93.4522171, 7.87722111], [93.4522171, 7.87778091], [93.45194244, 7.87806177], [93.45194244, 7.87888908], [93.45222473, 7.87916708], [93.45166779, 7.87972116], [93.45166779, 7.88027716], [93.4513855, 7.88055515], [93.45139313, 7.88110018], [93.45111084, 7.88138914], [93.45111084, 7.88249922], [93.4513855, 7.88277721], [93.4513855, 7.88333321], [93.45166779, 7.8836112], [93.45166779, 7.8838892], [93.4513855, 7.88416719], [93.4513855, 7.88444281], [93.45111084, 7.8847208], [93.45111084, 7.8849988], [93.44889069, 7.88723087], [93.44889069, 7.88749981], [93.44833374, 7.8880558], [93.44833374, 7.8883338], [93.44805908, 7.88861179], [93.44805908, 7.88888979], [93.44777679, 7.88916779], [93.44777679, 7.88971901], [93.44750214, 7.89000177], [93.44750214, 7.89028883], [93.44721222, 7.89056015], [93.44721985, 7.89138985], [93.44694519, 7.89166594], [93.44694519, 7.89222193], [93.44555664, 7.89361], [93.44555664, 7.893888], [93.44499969, 7.89444399], [93.44499969, 7.89472008], [93.44444275, 7.89527988], [93.44444275, 7.89555597], [93.44333649, 7.89666605], [93.44333649, 7.89694023], [93.44139862, 7.89889097], [93.4411087, 7.89888811], [93.44055176, 7.8994441], [93.4402771, 7.8994441], [93.43972015, 7.90000105], [93.43945313, 7.90000105], [93.43916321, 7.90028095], [93.43888855, 7.90028095], [93.43860626, 7.90056086], [93.43805695, 7.90055704], [93.43777466, 7.90083218], [93.4375, 7.90082979], [93.43694305, 7.90139103], [93.4366684, 7.90139103], [93.43638611, 7.90167093], [93.43611145, 7.90166712], [93.43583679, 7.90194511], [93.43554687, 7.90194178], [93.43527222, 7.90222979], [93.4347229, 7.90222311], [93.43444824, 7.90250111], [93.43416595, 7.90250111], [93.4338913, 7.90278101], [93.43333435, 7.90277719], [93.4327774, 7.90333319], [93.43250275, 7.90333319], [93.43222046, 7.90361118], [93.43165588, 7.90361118], [93.43138885, 7.90389109], [93.43083191, 7.90389109], [93.43055725, 7.90417099], [93.43027496, 7.90416718], [93.4291687, 7.90527678], [93.42888641, 7.9052701], [93.42861176, 7.90555906], [93.42778015, 7.90555477], [93.42749786, 7.90583277], [93.42722321, 7.90583277], [93.42694092, 7.90611076], [93.42610931, 7.90611076], [93.42582703, 7.90638924], [93.42415619, 7.90638924], [93.42388916, 7.90666914], [93.4236145, 7.90666723], [93.42333221, 7.90694523], [93.42277527, 7.90694523], [93.42250061, 7.90722322], [93.41999817, 7.90722322], [93.41972351, 7.90694523], [93.41860962, 7.90694523], [93.41833496, 7.90666723], [93.41638947, 7.90666914], [93.41610718, 7.90638924], [93.41555786, 7.90638924], [93.4152832, 7.90611076], [93.41444397, 7.90611076], [93.41388702, 7.90555477], [93.41333008, 7.90555906], [93.41326904, 7.90549088], [93.41306305, 7.9052701], [93.41278076, 7.90527678], [93.41249847, 7.90500116], [93.41221619, 7.90500116], [93.41027832, 7.90306091], [93.40999603, 7.90306091], [93.40972137, 7.90278101], [93.4091568, 7.90278101], [93.40888977, 7.90250111], [93.40860748, 7.90250111], [93.40805817, 7.90194511], [93.40721893, 7.90194178], [93.40638733, 7.90278101], [93.40611267, 7.90278101], [93.40583038, 7.90306091], [93.40555573, 7.90305519]]], [[[93.53250122, 8.04778194], [93.53138733, 8.04889202], [93.53056335, 8.04889202], [93.53029633, 8.04862976], [93.52971649, 8.04806042], [93.52971649, 8.04778194], [93.52944183, 8.04750156], [93.52944183, 8.04722118], [93.52861023, 8.04638863], [93.52861023, 8.04611111], [93.52833557, 8.04583263], [93.52833557, 8.04555511], [93.52805328, 8.04527664], [93.52805328, 8.04472065], [93.52833557, 8.04444313], [93.52833557, 8.04194546], [93.52861023, 8.04166698], [93.52861023, 8.040555], [93.5283432, 8.0402813], [93.5283432, 8.03972054], [93.52861023, 8.03944492], [93.52861023, 8.03888893], [93.52889252, 8.03861141], [93.52889252, 8.03833294], [93.52777863, 8.03722286], [93.52777863, 8.03694534], [93.52694702, 8.03611088], [93.52694702, 8.03583336], [93.52666473, 8.03555679], [93.52666473, 8.03416634], [93.52639008, 8.03389072], [93.52639008, 8.03306103], [93.52527618, 8.03194046], [93.52500153, 8.03194427], [93.52471924, 8.0316658], [93.52416992, 8.0316658], [93.52388763, 8.03194427], [93.52361298, 8.03194046], [93.52278137, 8.03278065], [93.52249908, 8.03277779], [93.52222443, 8.03305435], [93.5222168, 8.03332996], [93.52166748, 8.03388786], [93.52166748, 8.03416634], [93.52139282, 8.03444004], [93.52138519, 8.03472328], [93.52111053, 8.0350008], [93.52111053, 8.03555679], [93.52076721, 8.03694153], [93.52052307, 8.03704453], [93.52027893, 8.03715038], [93.52006531, 8.03708076], [93.51985931, 8.03701115], [93.51972198, 8.03638935], [93.51972198, 8.03611088], [93.51860809, 8.0350008], [93.51832581, 8.0350008], [93.51805878, 8.03473186], [93.51777649, 8.03473186], [93.51750183, 8.03444004], [93.51721954, 8.03444481], [93.51694489, 8.03416634], [93.51583099, 8.0341711], [93.51464844, 8.03409958], [93.51354218, 8.03403187], [93.512146, 8.03375244], [93.51145172, 8.03354168], [93.51083374, 8.03361034], [93.51000214, 8.03361034], [93.50971985, 8.03389072], [93.50944519, 8.03388786], [93.50888062, 8.03402328], [93.50839996, 8.03381538], [93.50791168, 8.03291512], [93.50777435, 8.03194427], [93.50777435, 8.03110981], [93.50791931, 8.03035069], [93.50750732, 8.02972889], [93.50688171, 8.0291729], [93.50653076, 8.02847958], [93.5062561, 8.02695465], [93.5062561, 8.02488136], [93.50611115, 8.02388954], [93.5063858, 8.02361202], [93.5063858, 8.02333355], [93.50666809, 8.02305603], [93.50666809, 8.02277756], [93.50723267, 8.02222157], [93.50722504, 8.02194309], [93.50805664, 8.02111244], [93.5083313, 8.02111244], [93.50888824, 8.02055454], [93.50971985, 8.02056026], [93.51027679, 8.01999855], [93.51027679, 8.01972103], [93.51055908, 8.01944637], [93.51055908, 8.01916695], [93.5111084, 8.01861095], [93.5111084, 8.01833344], [93.51139069, 8.01805496], [93.51139069, 8.01749897], [93.51194763, 8.01694107], [93.51194763, 8.01666737], [93.51055908, 8.01527691], [93.51027679, 8.01528168], [93.51000214, 8.0150013], [93.50971985, 8.0150013], [93.50945282, 8.01528168], [93.5091629, 8.01528168], [93.50888824, 8.01556015], [93.50861359, 8.01555538], [93.5083313, 8.0158329], [93.50805664, 8.0158329], [93.50694275, 8.01472092], [93.50694275, 8.0144453], [93.50666809, 8.01416683], [93.50666809, 8.01277733], [93.50776672, 8.01167107], [93.50805664, 8.01167107], [93.5083313, 8.01139069], [93.50860596, 8.01139069], [93.50945282, 8.01056099], [93.50945282, 8.01000118], [93.50861359, 8.00916672], [93.5083313, 8.00917053], [93.50805664, 8.00889111], [93.50776672, 8.00889111], [93.50694275, 8.00806141], [93.50694275, 8.00693989], [93.50722504, 8.00666618], [93.50722504, 8.00638771], [93.50749207, 8.00611019], [93.50749969, 8.00527763], [93.50722504, 8.00500011], [93.50723267, 8.00443268], [93.50694275, 8.00416565], [93.50694275, 8.00333214], [93.50666809, 8.00305557], [93.50666809, 8.00166607], [93.5063858, 8.00097084], [93.50605011, 8.00069141], [93.5055542, 8.0], [93.5055542, 7.99916601], [93.50499725, 7.99862099], [93.5047226, 7.99862099], [93.50417328, 7.99916983], [93.50389099, 7.99916601], [93.5036087, 7.99944401], [93.50333405, 7.99944401], [93.50305176, 8.0], [93.50313568, 8.00034618], [93.50285339, 8.00048542], [93.50251007, 8.00055408], [93.50188446, 8.00048542], [93.50146484, 8.00027847], [93.50138855, 8.0], [93.50166321, 7.99916983], [93.50215149, 7.99910021], [93.50235748, 7.99875116], [93.50242615, 7.99840021], [93.50228882, 7.99812412], [93.50180817, 7.99770689], [93.50166321, 7.99749994], [93.50138855, 7.99721909], [93.5008316, 7.99721909], [93.50026703, 7.99777985], [93.49972534, 7.99777794], [93.4991684, 7.99833393], [93.49888611, 7.99832916], [93.49861145, 7.99862099], [93.49833679, 7.99862099], [93.49777985, 7.99916983], [93.49749756, 7.99916983], [93.49666595, 8.0], [93.49656677, 8.00028038], [93.49630737, 8.00028038], [93.49603271, 8.00028038], [93.49575043, 8.00028038], [93.4954834, 8.00028038], [93.49518585, 8.00028038], [93.49491882, 8.00028038], [93.49472046, 8.0], [93.49388885, 7.99916983], [93.49360657, 7.99916983], [93.49333191, 7.99888992], [93.49305725, 7.99888992], [93.49194336, 8.0], [93.49223328, 8.00028038], [93.49222565, 8.00055599], [93.4916687, 8.00111198], [93.49138641, 8.00159454], [93.49138641, 8.00277805], [93.49054718, 8.00360966], [93.49055481, 8.00388813], [93.4908371, 8.00416565], [93.4908371, 8.00471973], [93.49055481, 8.00500011], [93.49055481, 8.0055542], [93.49028015, 8.00583458], [93.49028015, 8.00611019], [93.48999786, 8.00638771], [93.48999786, 8.00666618], [93.48972321, 8.00693989], [93.48972321, 8.00777912], [93.48944092, 8.00805664], [93.48944092, 8.00833225], [93.48916626, 8.00861073], [93.48916626, 8.0088892], [93.4888916, 8.00916672], [93.4888916, 8.00944519], [93.48860931, 8.00972271], [93.48860931, 8.01000118], [93.48833466, 8.0102787], [93.48833466, 8.01055527], [93.48805237, 8.01083279], [93.48805237, 8.01111126], [93.48777771, 8.01138878], [93.48777771, 8.01166725], [93.48750305, 8.01194477], [93.48750305, 8.01222324], [93.48722076, 8.01249886], [93.48722076, 8.01277924], [93.48694611, 8.01306152], [93.48694611, 8.01361084], [93.48666382, 8.01388931], [93.48666382, 8.0144453], [93.48638153, 8.01472092], [93.48638916, 8.0150013], [93.4861145, 8.01527691], [93.4861145, 8.0158329], [93.48583221, 8.01611137], [93.48583221, 8.01638889], [93.48555756, 8.01665974], [93.48555756, 8.01750088], [93.48527527, 8.01777744], [93.48555756, 8.01805496], [93.48555756, 8.01833344], [93.48583221, 8.01861095], [93.48583221, 8.01916695], [93.4861145, 8.01944637], [93.4861145, 8.01972103], [93.48527527, 8.02055454], [93.48527527, 8.02111244], [93.48555756, 8.02138996], [93.48555756, 8.02194118], [93.48472595, 8.02277756], [93.48583221, 8.02388763], [93.48583221, 8.02444363], [93.4861145, 8.0247221], [93.48583221, 8.02499962], [93.48583221, 8.02833366], [93.48555756, 8.02861214], [93.48555756, 8.02944374], [93.48527527, 8.02972221], [93.48527527, 8.03055573], [93.48555756, 8.03083038], [93.48555756, 8.03111172], [93.48583221, 8.03138828], [93.48583221, 8.03250027], [93.48555756, 8.03277779], [93.48555756, 8.03333473], [93.48527527, 8.03361034], [93.4852829, 8.0350008], [93.48555756, 8.03527641], [93.48555756, 8.03555679], [93.48583221, 8.03583336], [93.48583221, 8.03611088], [93.48638916, 8.03666687], [93.48638916, 8.0391674], [93.4861145, 8.03944492], [93.4861145, 8.04194546], [93.48583221, 8.04222107], [93.48583221, 8.04249859], [93.48527527, 8.04305458], [93.48527527, 8.04444313], [93.48555756, 8.04472256], [93.48555756, 8.04499912], [93.48638916, 8.04583263], [93.48694611, 8.04583263], [93.4872818, 8.04616833], [93.48750305, 8.04638863], [93.48805237, 8.04638863], [93.48832703, 8.0461092], [93.48916626, 8.04611111], [93.4892807, 8.04622459], [93.48972321, 8.04666996], [93.49028015, 8.04666996], [93.49223328, 8.04472065], [93.49222565, 8.04444313], [93.49250031, 8.04416656], [93.49250031, 8.04361057], [93.49305725, 8.04305458], [93.49360657, 8.0430603], [93.49388885, 8.04278183], [93.49472046, 8.04278183], [93.49500275, 8.04250145], [93.49555206, 8.04250145], [93.49582672, 8.04222107], [93.4963913, 8.04222107], [93.49666595, 8.04194546], [93.49694824, 8.04194546], [93.49749756, 8.04138947], [93.49777985, 8.04139137], [93.49861145, 8.04056168], [93.49861145, 8.0402813], [93.49944305, 8.03944016], [93.49972534, 8.03944492], [93.5, 8.0397234], [93.50027466, 8.0397234], [93.50138855, 8.04083347], [93.50138855, 8.04111099], [93.50166321, 8.04138947], [93.50166321, 8.04333305], [93.5019455, 8.04361057], [93.5019455, 8.04416656], [93.50222015, 8.04444313], [93.50222015, 8.04472256], [93.5027771, 8.04527664], [93.5027771, 8.04722118], [93.50305176, 8.04722118], [93.50327301, 8.0474453], [93.5036087, 8.04778194], [93.50389099, 8.04778194], [93.50444794, 8.04722118], [93.50444794, 8.04638863], [93.50416565, 8.04611111], [93.50416565, 8.04416656], [93.50444794, 8.04388905], [93.50444794, 8.0430603], [93.5047226, 8.04278183], [93.5047226, 8.04222107], [93.50499725, 8.04194546], [93.50499725, 8.04166698], [93.50534821, 8.04083538], [93.50562286, 8.04069614], [93.50604248, 8.04111099], [93.50611115, 8.04194069], [93.50611115, 8.04250145], [93.5063858, 8.04277706], [93.5063858, 8.04416656], [93.50666809, 8.04444313], [93.50666809, 8.04472065], [93.50694275, 8.04500103], [93.50694275, 8.04527664], [93.50722504, 8.04555511], [93.50722504, 8.04583263], [93.50749969, 8.04611111], [93.50749969, 8.04666805], [93.50777435, 8.04694557], [93.50777435, 8.04833412], [93.50805664, 8.04861164], [93.50805664, 8.04916763], [93.5083313, 8.04944134], [93.5083313, 8.04972172], [93.50888824, 8.05027771], [93.50888824, 8.05111217], [93.5083313, 8.05166626], [93.5083313, 8.05194378], [93.50805664, 8.05221939], [93.50805664, 8.05249977], [93.50749969, 8.05305576], [93.50749969, 8.05333424], [93.50722504, 8.05360985], [93.50694275, 8.05360985], [93.50666809, 8.05389023], [93.50611115, 8.05389023], [93.50583649, 8.05416965], [93.50499725, 8.05416584], [93.5047226, 8.05444431], [93.50417328, 8.05443859], [93.50333405, 8.05527782], [93.50333405, 8.0555563], [93.5036087, 8.05583191], [93.5036087, 8.05611038], [93.50389099, 8.05639267], [93.50417328, 8.05639267], [93.50444794, 8.05667114], [93.50499725, 8.05666637], [93.50527954, 8.05694389], [93.5055542, 8.05694389], [93.5057373, 8.05712414], [93.50583649, 8.05722237], [93.50611115, 8.05722046], [93.5063324, 8.05744553], [93.50666809, 8.05778122], [93.50723267, 8.05778122], [93.50776672, 8.05722046], [93.5083313, 8.05722046], [93.50888824, 8.05777836], [93.50888824, 8.05805588], [93.5091629, 8.05833435], [93.5091629, 8.05916595], [93.50888824, 8.05944443], [93.50888824, 8.05972004], [93.50861359, 8.06000042], [93.5091629, 8.06055737], [93.5091629, 8.06221962], [93.5083313, 8.06305695], [93.5083313, 8.06361103], [93.50861359, 8.06388855], [93.50860596, 8.06443977], [93.5091629, 8.06500053], [93.5091629, 8.06527901], [93.50944519, 8.06555462], [93.50944519, 8.06583309], [93.50971985, 8.06611061], [93.50971985, 8.06638908], [93.51000214, 8.0666666], [93.51000214, 8.06694508], [93.51027679, 8.0672226], [93.51027679, 8.06750107], [93.5111084, 8.06833267], [93.51222229, 8.06833267], [93.51249695, 8.06805515], [93.51249695, 8.06777668], [93.51277924, 8.06750107], [93.51277924, 8.0672226], [93.51305389, 8.06694508], [93.51305389, 8.0666666], [93.51333618, 8.06638908], [93.51333618, 8.06611061], [93.51361084, 8.06583309], [93.51361084, 8.06527901], [93.5138855, 8.06499863], [93.51389313, 8.06443977], [93.51416779, 8.06416702], [93.51416779, 8.06388855], [93.51444244, 8.06361103], [93.51444244, 8.06250095], [93.51416779, 8.06221962], [93.51416779, 8.06166744], [93.5138855, 8.06138802], [93.51389313, 8.0602808], [93.51444244, 8.05972004], [93.51444244, 8.05944443], [93.51527405, 8.05860996], [93.51527405, 8.05777836], [93.51555634, 8.05749989], [93.51555634, 8.05639267], [93.51526642, 8.05611038], [93.51527405, 8.05500031], [93.51499939, 8.05472183], [93.51499939, 8.05416584], [93.51472473, 8.05389023], [93.5147171, 8.05332947], [93.51444244, 8.05305576], [93.51444244, 8.05249977], [93.51416779, 8.05221939], [93.51416779, 8.05111217], [93.5138855, 8.0508337], [93.5138855, 8.05000019], [93.51416779, 8.04972172], [93.51416779, 8.0494442], [93.51472473, 8.04889011], [93.51499939, 8.04889202], [93.51526642, 8.04861164], [93.51583099, 8.04861164], [93.51611328, 8.04833412], [93.51638794, 8.04833412], [93.51777649, 8.04694557], [93.51805878, 8.04694557], [93.51944733, 8.04833412], [93.51944733, 8.04861164], [93.51972198, 8.04889011], [93.51972198, 8.04916763], [93.51999664, 8.0494442], [93.51999664, 8.04972172], [93.52138519, 8.05111217], [93.52166748, 8.05111217], [93.52175903, 8.05120277], [93.52194214, 8.05138969], [93.5222168, 8.05138969], [93.52249146, 8.05167007], [93.52416992, 8.05166626], [93.52527618, 8.05277824], [93.52527618, 8.05305576], [93.52555847, 8.05333424], [93.52555847, 8.05360985], [93.52583313, 8.05389023], [93.52583313, 8.05527782], [93.52555847, 8.0555563], [93.52555847, 8.05583191], [93.52471924, 8.05666637], [93.52471924, 8.05694389], [93.52443695, 8.05722046], [93.52444458, 8.05749989], [93.52416992, 8.05777836], [93.52416992, 8.06222343], [93.52388763, 8.06250095], [93.52388763, 8.06333256], [93.52416992, 8.06361103], [93.52416992, 8.06389141], [93.52443695, 8.06417084], [93.52471924, 8.06389141], [93.52527618, 8.06389141], [93.52583313, 8.0633297], [93.52694702, 8.06333256], [93.52722168, 8.06361103], [93.52749634, 8.06361103], [93.52777863, 8.06389141], [93.52805328, 8.06388855], [93.52861023, 8.06444454], [93.52889252, 8.06443977], [93.52944183, 8.06500053], [93.52944183, 8.06527901], [93.52972412, 8.06555462], [93.52972412, 8.06583309], [93.52999878, 8.06611061], [93.52999878, 8.06777668], [93.52944183, 8.06833267], [93.52805328, 8.06833267], [93.52777863, 8.06805515], [93.52749634, 8.06806183], [93.52736664, 8.06792736], [93.52722168, 8.06777668], [93.52694702, 8.06777668], [93.52583313, 8.0666666], [93.52527618, 8.0666666], [93.52500153, 8.06694508], [93.52500153, 8.06722069], [93.52471924, 8.06750107], [93.52471924, 8.06805515], [93.52443695, 8.06833076], [93.52444458, 8.06888866], [93.52416992, 8.06916714], [93.52416992, 8.06972122], [93.52388763, 8.07000065], [93.52416992, 8.07027721], [93.52416992, 8.07249928], [93.52388763, 8.07277679], [93.52388763, 8.07305527], [93.52361298, 8.07333279], [93.52361298, 8.07361126], [93.52394104, 8.07393742], [93.52464294, 8.07463932], [93.52555847, 8.07555962], [93.52583313, 8.0755558], [93.52639008, 8.07611179], [93.5266571, 8.07611179], [93.52694702, 8.07639027], [93.52722168, 8.07639027], [93.52861786, 8.07777977], [93.52889252, 8.07777977], [93.52916718, 8.07806015], [93.52944183, 8.07805634], [93.52971649, 8.07833195], [93.52986145, 8.07868004], [93.5295105, 8.07888985], [93.52861786, 8.07861042], [93.52805328, 8.07861233], [93.52777863, 8.07833385], [93.52722168, 8.07833385], [93.52714539, 8.07825375], [93.52694702, 8.07805634], [93.52555847, 8.07805634], [93.52527618, 8.07833385], [93.52444458, 8.07833385], [93.52361298, 8.07916641], [93.52361298, 8.08083439], [93.52388763, 8.08111], [93.52388763, 8.08166599], [93.52416992, 8.08194447], [93.52416992, 8.08222198], [93.52388763, 8.08250046], [93.52388763, 8.08305645], [93.52361298, 8.08333206], [93.52333069, 8.08333015], [93.52278137, 8.08388996], [93.52249146, 8.08388996], [93.5222168, 8.08360958], [93.52194214, 8.08361244], [93.51972198, 8.08138847], [93.51944733, 8.08139038], [93.51917267, 8.08167267], [93.51889038, 8.08166599], [93.51860809, 8.08194447], [93.51833344, 8.08194447], [93.51777649, 8.08250046], [93.51750183, 8.08250046], [93.51667023, 8.08333206], [93.51638794, 8.08333015], [93.51583099, 8.08388996], [93.51444244, 8.08388996], [93.51435852, 8.08380604], [93.5138855, 8.08333206], [93.5138855, 8.08277798], [93.51361084, 8.08250046], [93.51361084, 8.08194447], [93.51333618, 8.08166599], [93.51333618, 8.08138847], [93.51304626, 8.08111], [93.51304626, 8.07999992], [93.51333618, 8.07971001], [93.51333618, 8.07944393], [93.51361084, 8.07916641], [93.51361084, 8.07861233], [93.5138855, 8.07833385], [93.5138855, 8.07750034], [93.51361084, 8.07722187], [93.51312256, 8.07712078], [93.51277924, 8.07726002], [93.51257324, 8.07691193], [93.51257324, 8.07559013], [93.51264191, 8.07503796], [93.51277924, 8.07413769], [93.51230621, 8.0735817], [93.51154327, 8.07372093], [93.51027679, 8.07386017], [93.5099411, 8.07370853], [93.50965881, 8.0735817], [93.50861359, 8.07309914], [93.50785065, 8.07275009], [93.50695038, 8.07254314], [93.5064621, 8.07247353], [93.50611115, 8.07198906], [93.50563049, 8.07143497], [93.50563049, 8.06976891], [93.50548553, 8.06921673], [93.50479126, 8.06845379], [93.50416565, 8.06833267], [93.50417328, 8.06861115], [93.5036087, 8.06917191], [93.5027771, 8.06917191], [93.50242615, 8.06873608], [93.50216675, 8.06840992], [93.5019455, 8.06777668], [93.5008316, 8.0666666], [93.5008316, 8.06638908], [93.50055695, 8.06611061], [93.50055695, 8.06583309], [93.49972534, 8.06499863], [93.49944305, 8.06500053], [93.4991684, 8.06471062], [93.49804688, 8.06471062], [93.49777985, 8.06500053], [93.49749756, 8.06499863], [93.4963913, 8.06611061], [93.49610901, 8.06611061], [93.4952774, 8.06527901], [93.4952774, 8.06499863], [93.49500275, 8.06471062], [93.49500275, 8.06444454], [93.4936142, 8.06305695], [93.49333191, 8.06305885], [93.49305725, 8.06278133], [93.49276733, 8.06278133], [93.49260712, 8.06260967], [93.49250031, 8.06250095], [93.49223328, 8.06250095], [93.49194336, 8.06221962], [93.49194336, 8.06194496], [93.4916687, 8.06166744], [93.49194336, 8.06138802], [93.49194336, 8.06110954], [93.49250031, 8.06055737], [93.49276733, 8.06056118], [93.49305725, 8.0602808], [93.49388885, 8.0602808], [93.4944458, 8.05972004], [93.4944458, 8.05888844], [93.49388885, 8.05833435], [93.49388885, 8.05722237], [93.49416351, 8.05694389], [93.49416351, 8.05472183], [93.4944458, 8.05444431], [93.4944458, 8.05389023], [93.49416351, 8.05360985], [93.49416351, 8.05333424], [93.49388885, 8.05305576], [93.49312592, 8.05201721], [93.49256897, 8.0511713], [93.49166107, 8.05028534], [93.49069214, 8.04952145], [93.49006653, 8.04924297], [93.48944092, 8.04952145], [93.48944855, 8.05000019], [93.48916626, 8.05027962], [93.48916626, 8.05056], [93.48832703, 8.05138969], [93.48805237, 8.05138779], [93.48750305, 8.05194378], [93.48722076, 8.05194378], [93.4861145, 8.0508337], [93.48500061, 8.05194378], [93.48500061, 8.05222225], [93.48472595, 8.05249977], [93.48472595, 8.05444431], [93.48443604, 8.05472183], [93.48444366, 8.05500031], [93.48416901, 8.05527782], [93.48416901, 8.05583191], [93.48388672, 8.05611038], [93.48388672, 8.0563879], [93.48416901, 8.05666637], [93.48416901, 8.05694389], [93.48443604, 8.05722046], [93.48443604, 8.05778122], [93.48472595, 8.05805588], [93.48472595, 8.05916595], [93.48500061, 8.05944443], [93.48500061, 8.06000042], [93.48472595, 8.06027889], [93.48472595, 8.06055737], [93.48443604, 8.06083012], [93.48443604, 8.06139088], [93.48472595, 8.06167126], [93.48472595, 8.06388855], [93.48444366, 8.06416702], [93.48443604, 8.06443977], [93.48388672, 8.06500053], [93.48388672, 8.06527901], [93.48361206, 8.06555462], [93.48361206, 8.06694508], [93.48332214, 8.06722069], [93.48332977, 8.06750107], [93.48388672, 8.06805515], [93.48388672, 8.06861115], [93.48416901, 8.06888866], [93.48416901, 8.06916714], [93.48443604, 8.06944084], [93.48443604, 8.07028198], [93.48416901, 8.07055473], [93.48416901, 8.07166672], [93.48388672, 8.07194328], [93.48388672, 8.07333279], [93.48361206, 8.07360935], [93.48361206, 8.07390118], [93.48332214, 8.07417202], [93.48332977, 8.07750034], [93.48305511, 8.07777786], [93.48305511, 8.07833385], [93.48278046, 8.07861233], [93.48278046, 8.07944393], [93.48249817, 8.07971001], [93.48249817, 8.0802803], [93.48221588, 8.08056068], [93.48222351, 8.08111], [93.48194122, 8.08138847], [93.48194122, 8.08194447], [93.48166656, 8.08222198], [93.48166656, 8.08277798], [93.48110962, 8.08333206], [93.48110962, 8.08416557], [93.48055267, 8.08471966], [93.48055267, 8.08500004], [93.48082733, 8.08528137], [93.48055267, 8.08555603], [93.48055267, 8.08611012], [93.48110962, 8.08667088], [93.48139191, 8.08667088], [93.48166656, 8.08639145], [93.48194122, 8.08639145], [93.48249817, 8.08584118], [93.48332977, 8.08583355], [93.48388672, 8.08631992], [93.48395538, 8.08687592], [93.48420715, 8.08719254], [93.48425293, 8.08725357], [93.48471832, 8.08744144], [93.4852829, 8.08722019], [93.48638153, 8.08722019], [93.48665619, 8.08750057], [93.48722076, 8.08750057], [93.48860931, 8.08888912], [93.48860931, 8.08944511], [93.4888916, 8.08972263], [93.4888916, 8.09000111], [93.48916626, 8.09027863], [93.48916626, 8.09055519], [93.48944092, 8.09083271], [93.48938751, 8.09160519], [93.48917389, 8.09194946], [93.48854828, 8.09250641], [93.48820496, 8.0929203], [93.48709106, 8.09333706], [93.48667145, 8.09360886], [93.4861908, 8.09409904], [93.48500824, 8.09500122], [93.48458862, 8.09534836], [93.48382568, 8.09569359], [93.48298645, 8.09583092], [93.48249817, 8.09590054], [93.48208618, 8.0961113], [93.48152924, 8.09639072], [93.48138428, 8.09636593], [93.48104095, 8.09631634], [93.48083496, 8.09610939], [93.48110962, 8.09583092], [93.48110962, 8.09527683], [93.48082733, 8.09536076], [93.48055267, 8.09459972], [93.47970581, 8.09321022], [93.47950745, 8.09278965], [93.47915649, 8.09182167], [93.47915649, 8.09071445], [93.47908783, 8.09050655], [93.47825623, 8.09030247], [93.47714233, 8.09154606], [93.47631073, 8.09293175], [93.47602844, 8.09342194], [93.47505951, 8.09438992], [93.47416687, 8.09528065], [93.47416687, 8.09555531], [93.47166443, 8.09805489], [93.4716568, 8.09833145], [93.47138977, 8.09861088], [93.47138977, 8.09888935], [93.47083282, 8.09944534], [93.47083282, 8.09972095], [93.47027588, 8.10027981], [93.47027588, 8.10055542], [93.47000122, 8.10083294], [93.47000122, 8.10111237], [93.46971893, 8.10139179], [93.46971893, 8.10167027], [93.46861267, 8.10277843], [93.46861267, 8.10305595], [93.46833038, 8.10333443], [93.46833038, 8.10361195], [93.46805573, 8.10388756], [93.46805573, 8.10416794], [93.46778107, 8.10444355], [93.46778107, 8.10472202], [93.46722412, 8.10527802], [93.46722412, 8.10555553], [93.46694183, 8.10583401], [93.46694183, 8.10611153], [93.46666718, 8.10639], [93.46666718, 8.10694408], [93.46639252, 8.1072216], [93.46639252, 8.10805607], [93.46611023, 8.10833168], [93.46611023, 8.10888767], [93.46583557, 8.10916615], [93.46583557, 8.10944366], [93.46611023, 8.10972214], [93.46611023, 8.11055565], [93.46639252, 8.11083221], [93.46639252, 8.1119442], [93.46611023, 8.11222172], [93.46611023, 8.11250019], [93.46389008, 8.11472034], [93.46389008, 8.11500072], [93.46416473, 8.1152792], [93.4641571, 8.11582088], [93.46499634, 8.11667061], [93.46527863, 8.11666679], [93.46555328, 8.11694527], [93.4658432, 8.11693954], [93.46601868, 8.11717701], [93.46607971, 8.11726379], [93.46624756, 8.11737061], [93.46649933, 8.11767578], [93.46726227, 8.11781502], [93.46817017, 8.11795044], [93.4683075, 8.11830997], [93.4681015, 8.11851025], [93.46678162, 8.11850834], [93.46611023, 8.11861134], [93.46555328, 8.11861134], [93.46527863, 8.11888885], [93.46499634, 8.11888027], [93.46472168, 8.11916924], [93.46463776, 8.1190834], [93.46444702, 8.11888885], [93.46389008, 8.11888885], [93.46360779, 8.11861134], [93.46250153, 8.11861134], [93.46221924, 8.11833286], [93.46166992, 8.11833286], [93.46083069, 8.11916733], [93.46083069, 8.11972141], [93.46055603, 8.12000084], [93.46055603, 8.1202774], [93.46028137, 8.12055492], [93.46028137, 8.1208334], [93.45999908, 8.12111092], [93.45999908, 8.1213913], [93.45972443, 8.12166691], [93.45972443, 8.12194538], [93.45944214, 8.12222099], [93.45944214, 8.12277699], [93.45916748, 8.12305546], [93.45916748, 8.12361145], [93.45888519, 8.12388897], [93.45888519, 8.12444305], [93.45916748, 8.12472057], [93.45916748, 8.12501144], [93.4597168, 8.12555981], [93.4597168, 8.12611103], [93.45999908, 8.12638855], [93.45999908, 8.1277771], [93.45972443, 8.12805462], [93.45972443, 8.12889004], [93.45916748, 8.12944317], [93.45916748, 8.12972164], [93.45805359, 8.13083363], [93.45805359, 8.13222218], [93.45833588, 8.13249969], [93.45833588, 8.13444424], [93.45861053, 8.13472176], [93.45888519, 8.13472176], [93.45999908, 8.13583374], [93.45999908, 8.13611031], [93.46083069, 8.13695145], [93.46111298, 8.13695145], [93.46166992, 8.13750172], [93.46221924, 8.13750172], [93.46250153, 8.13778114], [93.46277618, 8.13778114], [93.46305847, 8.13806057], [93.46333313, 8.1380558], [93.46472168, 8.13944435], [93.46472168, 8.13972187], [93.46444702, 8.14000034], [93.46444702, 8.14055729], [93.46416473, 8.14083195], [93.4641571, 8.14111042], [93.46389008, 8.14138794], [93.46389008, 8.14166641], [93.46360779, 8.14194489], [93.46360779, 8.14222336], [93.46250153, 8.14333344], [93.46111298, 8.14333344], [93.46055603, 8.14277554], [93.46028137, 8.14278126], [93.46001434, 8.14251041], [93.45992279, 8.14242077], [93.45944214, 8.14194489], [93.45916748, 8.14194489], [93.45861053, 8.14138794], [93.45833588, 8.14138794], [93.45694733, 8.14277554], [93.45694733, 8.14305687], [93.45666504, 8.14333344], [93.45667267, 8.14361095], [93.45639038, 8.14388943], [93.45639038, 8.14416695], [93.45610809, 8.14444542], [93.45610809, 8.14472008], [93.45583344, 8.14500141], [93.45583344, 8.14555454], [93.45555878, 8.14583302], [93.45555878, 8.1483326], [93.45500183, 8.14888859], [93.45500183, 8.15083313], [93.45471954, 8.15111065], [93.45527649, 8.15166664], [93.45527649, 8.15194321], [93.45534515, 8.15305805], [93.45555878, 8.15444565], [93.45555878, 8.15472126], [93.45582581, 8.1549902], [93.45582581, 8.15639019], [93.45610809, 8.15666962], [93.45652771, 8.15724659], [93.45659637, 8.15787125], [93.45639038, 8.15888977], [93.45610809, 8.15916634], [93.45610809, 8.15944386], [93.45555878, 8.15999985], [93.45555878, 8.16055584], [93.45527649, 8.16083431], [93.45527649, 8.16194439], [93.45500183, 8.16222191], [93.45500183, 8.1627779], [93.45471954, 8.16305637], [93.45471954, 8.16361237], [93.45444489, 8.16388798], [93.45444489, 8.16444397], [93.45417023, 8.16471958], [93.45417023, 8.16527843], [93.45388794, 8.16555595], [93.45388794, 8.16583443], [93.45361328, 8.16611004], [93.45361328, 8.16833019], [93.45417023, 8.16889095], [93.45433044, 8.16870403], [93.45465088, 8.16833019], [93.45485687, 8.16840267], [93.45500183, 8.16874886], [93.45500183, 8.16944027], [93.45500183, 8.17000103], [93.45471954, 8.17028141], [93.45500183, 8.17056084], [93.45500183, 8.17138863], [93.45471954, 8.1716671], [93.45471954, 8.17222118], [93.45443726, 8.17250061], [93.45444489, 8.17277908], [93.45417023, 8.1730547], [93.45417023, 8.17333317], [93.45388794, 8.17361069], [93.45417023, 8.17388916], [93.45417023, 8.17444515], [93.45443726, 8.1747179], [93.45443726, 8.17500114], [93.45500183, 8.1755619], [93.45527649, 8.17555523], [93.45583344, 8.17611122], [93.45610809, 8.17609978], [93.45667267, 8.17667198], [93.45722198, 8.17666721], [93.45749664, 8.17694473], [93.45777893, 8.17694473], [93.45861053, 8.1777792], [93.45861053, 8.17833328], [93.45944214, 8.17916679], [93.45999908, 8.17916679], [93.46028137, 8.17944527], [93.46221924, 8.17944527], [93.46250153, 8.17972088], [93.46360779, 8.17972088], [93.46389008, 8.17999935], [93.46527863, 8.17999935], [93.46555328, 8.18027973], [93.46611023, 8.18027687], [93.46666718, 8.18083286], [93.46694183, 8.18083286], [93.46916962, 8.18111134], [93.46943665, 8.18111134], [93.47000122, 8.18167019], [93.47027588, 8.18166542], [93.47083282, 8.18222141], [93.47110748, 8.1819458], [93.47138214, 8.18194103], [93.47194672, 8.18250179], [93.47249603, 8.18250179], [93.47277832, 8.18278027], [93.47333527, 8.18277836], [93.47457123, 8.18342304], [93.47519684, 8.18390846], [93.47595978, 8.18425179], [93.47705841, 8.18516064], [93.47756195, 8.18591595], [93.47784424, 8.18675041], [93.47818756, 8.18730164], [93.4789505, 8.1881361], [93.47930145, 8.18869019], [93.4796524, 8.18910694], [93.48006439, 8.1897974], [93.48040771, 8.1904192], [93.48069, 8.191185], [93.48097229, 8.1920166], [93.48131561, 8.19250298], [93.48180389, 8.19257069], [93.48278046, 8.19361019], [93.48278046, 8.19388771], [93.48332977, 8.1944437], [93.48443604, 8.19472027], [93.4852829, 8.19556141], [93.48555756, 8.19555664], [93.48583221, 8.19583225], [93.48610687, 8.19583035], [93.48638153, 8.19610977], [93.48665619, 8.19610977], [93.48694611, 8.19639111], [93.48750305, 8.19639111], [93.48777771, 8.19667053], [93.48833466, 8.19666672], [93.49055481, 8.19888878], [93.49055481, 8.20222092], [93.49028015, 8.2025013], [93.49028015, 8.20388889], [93.49055481, 8.20416737], [93.49054718, 8.20444107], [93.49138641, 8.20527744], [93.49138641, 8.20555496], [93.4916687, 8.20583344], [93.4916687, 8.20611095], [93.49194336, 8.20638943], [93.49194336, 8.20694542], [93.49222565, 8.20722103], [93.49222565, 8.20805454], [93.49250031, 8.20833302], [93.49250031, 8.21055603], [93.49223328, 8.21083069], [93.49223328, 8.21223068], [93.49194336, 8.21249962], [93.49194336, 8.21277809], [93.4916687, 8.21305561], [93.4916687, 8.21527767], [93.49194336, 8.21555614], [93.4916687, 8.21583366], [93.4916687, 8.21666622], [93.49111176, 8.21722221], [93.49138641, 8.21749973], [93.49138641, 8.21833038], [93.4916687, 8.21861172], [93.4916687, 8.21888828], [93.49194336, 8.2191658], [93.49194336, 8.21944427], [93.49222565, 8.21972179], [93.49222565, 8.22027779], [93.49277496, 8.22083473], [93.49277496, 8.22111034], [93.49465179, 8.22277355], [93.49632263, 8.2235384], [93.49806976, 8.22427368], [93.49855804, 8.22448063], [93.49945831, 8.22469139], [93.50036621, 8.22482777], [93.50237274, 8.22533798], [93.50326538, 8.22550392], [93.50376892, 8.22560024], [93.50428772, 8.22572994], [93.50483704, 8.22588062], [93.50534821, 8.22605801], [93.5058136, 8.22626781], [93.50624847, 8.22651196], [93.50665283, 8.22681046], [93.50700378, 8.22714996], [93.50733948, 8.22751522], [93.50765991, 8.22787189], [93.50800323, 8.2281847], [93.50837708, 8.22843075], [93.50881958, 8.22861099], [93.50927734, 8.2286911], [93.50972748, 8.22868156], [93.51014709, 8.2285614], [93.51056671, 8.22838974], [93.51098633, 8.22821236], [93.51140594, 8.228055], [93.51181793, 8.22795868], [93.5121994, 8.22794056], [93.51255798, 8.22802544], [93.51290894, 8.22816181], [93.51326752, 8.22831154], [93.51364136, 8.22846127], [93.51403046, 8.22863102], [93.51441956, 8.22885036], [93.5147934, 8.22914028], [93.51513672, 8.2294817], [93.51548767, 8.22982597], [93.51583099, 8.23013592], [93.51617432, 8.23037338], [93.51650238, 8.23052311], [93.51665497, 8.23055267], [93.51680756, 8.23058033], [93.51715088, 8.2305603], [93.51750946, 8.23052311], [93.5178833, 8.2305603], [93.51824188, 8.23073959], [93.51857758, 8.23106766], [93.5189209, 8.23150063], [93.51931, 8.23196125], [93.51976013, 8.23239422], [93.52026367, 8.23275948], [93.5207901, 8.23303509], [93.52129364, 8.2332058], [93.52176666, 8.23328114], [93.52220154, 8.23327637], [93.52259064, 8.23321533], [93.52296448, 8.23312378], [93.52336121, 8.23302078], [93.52378082, 8.23290539], [93.5242157, 8.23275948], [93.52462769, 8.23256111], [93.52498627, 8.23231697], [93.52527618, 8.23204327], [93.52552032, 8.23178101], [93.52577972, 8.23155594], [93.52610016, 8.23138046], [93.52648926, 8.23127079], [93.52693939, 8.2312336], [93.52739716, 8.23127079], [93.52784729, 8.23136425], [93.52829742, 8.23147583], [93.52877045, 8.23156929], [93.52929688, 8.23163128], [93.52986145, 8.23163128], [93.53042603, 8.23156166], [93.53095245, 8.23141193], [93.53141785, 8.23119068], [93.53183746, 8.23093128], [93.53225708, 8.23067093], [93.53269196, 8.23043919], [93.53314972, 8.23024273], [93.53359985, 8.23005962], [93.53404236, 8.22990131], [93.53449249, 8.22977638], [93.5349884, 8.22967052], [93.53559875, 8.22959328], [93.53639984, 8.22955894], [93.53682709, 8.22956085], [93.53723907, 8.22957039], [93.5375061, 8.22945023], [93.53778076, 8.22916698], [93.53805542, 8.22888947], [93.53861237, 8.22889137], [93.53916931, 8.22833061], [93.53944397, 8.22833347], [93.54083252, 8.22694492], [93.54111481, 8.22694492], [93.54138947, 8.2266674], [93.54165649, 8.22667122], [93.54194641, 8.22639084], [93.54222107, 8.22639084], [93.54250336, 8.22611141], [93.54277802, 8.22611141], [93.54333496, 8.22555542], [93.54360199, 8.22555923], [93.54416656, 8.22500134], [93.54473877, 8.22325039], [93.54550171, 8.22110271], [93.54557037, 8.21936893], [93.54563141, 8.21722889], [93.54563141, 8.21536541], [93.54556274, 8.2139082], [93.54563141, 8.21273041], [93.54590607, 8.21155167], [93.54653168, 8.21085644], [93.54682159, 8.21016979], [93.54638672, 8.20778179], [93.54638672, 8.20750237], [93.54611206, 8.20722103], [93.54611206, 8.20444489], [93.54638672, 8.20416737], [93.54638672, 8.20277691], [93.54582977, 8.20222092], [93.54582977, 8.20083332], [93.54555511, 8.20055485], [93.54555511, 8.19916725], [93.54528046, 8.19889069], [93.54528046, 8.19778061], [93.54499817, 8.19750118], [93.54499817, 8.19722271], [93.54471588, 8.19694042], [93.54472351, 8.19610977], [93.54416656, 8.19555664], [93.54416656, 8.19528103], [93.54277802, 8.19389057], [93.54277802, 8.19361019], [93.54250336, 8.19333363], [93.54250336, 8.1930542], [93.54166412, 8.19222164], [93.54111481, 8.19222164], [93.54021454, 8.19214916], [93.53965759, 8.19200993], [93.53909302, 8.19187069], [93.53868103, 8.19126034], [93.53798676, 8.19048977], [93.53778076, 8.18972015], [93.53778076, 8.18861198], [93.53805542, 8.18833447], [93.53805542, 8.1875], [93.53778076, 8.18722153], [93.53778076, 8.18666553], [93.53805542, 8.18638992], [93.53806305, 8.18556023], [93.53778076, 8.18529129], [93.53778076, 8.18472195], [93.53666687, 8.18361187], [93.53666687, 8.18333435], [93.53639221, 8.18305588], [93.53639221, 8.18277836], [93.53610992, 8.18250179], [93.53610992, 8.18194103], [93.53583527, 8.18166542], [93.53583527, 8.18138981], [93.53555298, 8.18111134], [93.53555298, 8.18083286], [93.53500366, 8.18027687], [93.53500366, 8.17999935], [93.53305817, 8.17805958], [93.53277588, 8.17805958], [93.53193665, 8.1772213], [93.53166962, 8.17722321], [93.53055573, 8.17611122], [93.53028107, 8.17611122], [93.52749634, 8.17333317], [93.52722168, 8.17333317], [93.52605438, 8.17216587], [93.52527618, 8.17138863], [93.52500153, 8.17138863], [93.52416992, 8.17222118], [93.52416992, 8.17278099], [93.52388763, 8.1730547], [93.52388763, 8.17361069], [93.52444458, 8.17416668], [93.52443695, 8.17444038], [93.5266571, 8.17667198], [93.52694702, 8.17666721], [93.52722168, 8.17694473], [93.52861023, 8.17694473], [93.52889252, 8.17722321], [93.52944183, 8.17722321], [93.53277588, 8.18055534], [93.53305817, 8.18083286], [93.53305817, 8.18111134], [93.53360748, 8.18166542], [93.53360748, 8.1819458], [93.53388977, 8.18222141], [93.53388977, 8.18250179], [93.53395844, 8.182971], [93.5341568, 8.18352127], [93.53410339, 8.18373013], [93.53382111, 8.1838007], [93.53347015, 8.18365955], [93.53277588, 8.18333054], [93.53250122, 8.18305588], [93.53221893, 8.18305969], [93.53138733, 8.18222141], [93.53111267, 8.18222141], [93.53083038, 8.1819458], [93.53028107, 8.1819458], [93.52999878, 8.18166542], [93.52971649, 8.18167019], [93.52916718, 8.18111134], [93.52889252, 8.18111134], [93.52838135, 8.18060112], [93.52583313, 8.17805481], [93.52583313, 8.1777792], [93.52555847, 8.17750072], [93.52555847, 8.1772213], [93.52416992, 8.17583275], [93.52416992, 8.17555523], [93.52361298, 8.17500114], [93.52361298, 8.17416668], [93.52166748, 8.17222118], [93.52081299, 8.17243004], [93.52032471, 8.17277718], [93.51983643, 8.1729126], [93.51900482, 8.1729126], [93.51872253, 8.17277718], [93.51837921, 8.17278099], [93.51809692, 8.17263985], [93.51782227, 8.17256927], [93.51753998, 8.17228889], [93.51719666, 8.17180634], [93.51691437, 8.1714592], [93.51635742, 8.17097187], [93.51615143, 8.17062664], [93.51566315, 8.17007446], [93.51503754, 8.1698637], [93.51438141, 8.17007065], [93.51377106, 8.16979122], [93.51229095, 8.16944027], [93.51194763, 8.1691637], [93.51139069, 8.16867924], [93.51076508, 8.16826153], [93.51055908, 8.16749954], [93.51055908, 8.16722202], [93.51027679, 8.16694355], [93.51027679, 8.16666603], [93.51000214, 8.16638756], [93.51000214, 8.16611004], [93.50971985, 8.16583443], [93.50971985, 8.16416645], [93.51000214, 8.16388798], [93.51000214, 8.16361237], [93.51055908, 8.16305637], [93.5111084, 8.16306114], [93.51197052, 8.16300106], [93.51232147, 8.1630106], [93.51267242, 8.16273499], [93.51280975, 8.16211033], [93.51264191, 8.1612854], [93.51235962, 8.16073132], [93.51222229, 8.16017532], [93.5120163, 8.15962124], [93.51194763, 8.15927505], [93.51187134, 8.15886021], [93.5120163, 8.15837002], [93.51194763, 8.15775013], [93.51180267, 8.15747547], [93.51152802, 8.15719891], [93.51125336, 8.15684986], [93.51035309, 8.15622997], [93.50978851, 8.15617085], [93.50943756, 8.15609074], [93.50874329, 8.15609074], [93.50811768, 8.15601063], [93.50793457, 8.15523624], [93.50786591, 8.15482235], [93.50786591, 8.15377998], [93.50793457, 8.1532259], [93.50792694, 8.15287971], [93.50814819, 8.15274143], [93.50805664, 8.1524992], [93.50778961, 8.15226364], [93.50730133, 8.1515007], [93.50723267, 8.15101528], [93.50710297, 8.15067101], [93.50710297, 8.15045929], [93.50737, 8.14983654], [93.50737, 8.14935207], [93.50730133, 8.14921284], [93.50674438, 8.14893723], [93.50666809, 8.14861107], [93.50563049, 8.14852905], [93.50514221, 8.14859962], [93.5045166, 8.14866829], [93.50423431, 8.148736], [93.50389099, 8.148736], [93.5036087, 8.14866829], [93.50319672, 8.14853096], [93.50305176, 8.14818001], [93.50326538, 8.14804268], [93.50354004, 8.14735126], [93.5036087, 8.14722347], [93.50389099, 8.146945], [93.50389099, 8.14666653], [93.50416565, 8.14638901], [93.50417328, 8.14555931], [93.50428772, 8.14451981], [93.50435638, 8.14430141], [93.50491333, 8.14381599], [93.50526428, 8.14360809], [93.50547028, 8.14346886], [93.50588989, 8.14291477], [93.50609589, 8.14243031], [93.50652313, 8.14201069], [93.50722504, 8.14194489], [93.50749969, 8.14194489], [93.50777435, 8.14166641], [93.50805664, 8.14167118], [93.51082611, 8.13889027], [93.5111084, 8.13889027], [93.51167297, 8.13833046], [93.51194763, 8.13833427], [93.51249695, 8.13777828], [93.51277924, 8.13778114], [93.51361847, 8.13695145], [93.51361847, 8.13667107], [93.5147171, 8.13556099], [93.5147171, 8.13527966], [93.51499939, 8.13500023], [93.51499939, 8.13444424], [93.51527405, 8.13416576], [93.51527405, 8.13389015], [93.51555634, 8.13361168], [93.51555634, 8.13332939], [93.51583099, 8.13305569], [93.51583099, 8.13277817], [93.51638794, 8.13221931], [93.51638794, 8.1319437], [93.51805878, 8.13027763], [93.51832581, 8.13027954], [93.51931763, 8.12833977], [93.51980591, 8.12799168], [93.5202179, 8.12730122], [93.52043152, 8.12674522], [93.52056885, 8.12639904], [93.52063751, 8.12549782], [93.52056885, 8.12514019], [93.52077484, 8.12487411], [93.52133179, 8.12494373], [93.52209473, 8.12445927], [93.52300262, 8.12334919], [93.52416992, 8.12250137], [93.52388763, 8.12222099], [93.52388763, 8.12194538], [93.52416992, 8.12166691], [93.52416992, 8.12111092], [93.52583313, 8.11944485], [93.52583313, 8.11722279], [93.52610779, 8.11694527], [93.52610779, 8.11666679], [93.52694702, 8.11583233], [93.52694702, 8.11555672], [93.52722168, 8.1152792], [93.52722168, 8.11472034], [93.52749634, 8.11444378], [93.52749634, 8.11416626], [93.52777863, 8.11388779], [93.52777863, 8.11361027], [93.52805328, 8.11333466], [93.52840424, 8.11261368], [93.52861023, 8.11166573], [93.52861023, 8.11083221], [93.52889252, 8.11055565], [93.52889252, 8.11027813], [93.52897644, 8.11013889], [93.52999878, 8.10888767], [93.52999878, 8.10805607], [93.53111267, 8.10693932], [93.53111267, 8.10666561], [93.53138733, 8.10639], [93.53138733, 8.10610962], [93.53166962, 8.10583401], [93.53166962, 8.10555553], [93.53194427, 8.10527802], [93.53193665, 8.10499954], [93.53221893, 8.10472202], [93.53221893, 8.10444355], [93.53194427, 8.10416794], [93.53194427, 8.10333443], [93.53166962, 8.10305595], [93.53166962, 8.09972095], [93.53194427, 8.09944534], [93.53194427, 8.09916687], [93.53416443, 8.09694481], [93.53450012, 8.09640694], [93.53560638, 8.09619999], [93.53666687, 8.09500122], [93.53694153, 8.09500122], [93.53722382, 8.09472084], [93.53749847, 8.09472084], [93.53778076, 8.09444523], [93.53805542, 8.09444523], [93.53833008, 8.09416676], [93.53833008, 8.09388924], [93.53888702, 8.09333134], [93.53916931, 8.09333324], [93.53944397, 8.09305477], [93.53944397, 8.09277916], [93.54083252, 8.09139061], [93.54110718, 8.09139061], [93.54138947, 8.09111118], [93.54194641, 8.09111118], [93.54212952, 8.09091854], [93.54317474, 8.09070969], [93.54393768, 8.0905714], [93.54582977, 8.09055519], [93.54611206, 8.09056091], [93.54833221, 8.08833027], [93.54833221, 8.08694363], [93.5486145, 8.08666611], [93.5486145, 8.08472157], [93.54888916, 8.08444405], [93.54888916, 8.08416557], [93.54916382, 8.08388805], [93.54915619, 8.08360958], [93.54944611, 8.08333206], [93.54944611, 8.08305645], [93.54972076, 8.08277798], [93.54972076, 8.08250046], [93.55000305, 8.08222198], [93.55000305, 8.08194447], [93.55027771, 8.08166599], [93.55027771, 8.08138847], [93.55055237, 8.08111], [93.55055237, 8.08083439], [93.55083466, 8.08055592], [93.55083466, 8.0797224], [93.55055237, 8.07944393], [93.55055237, 8.07888985], [93.55027771, 8.07861233], [93.55027771, 8.07666779], [93.55055237, 8.07639027], [93.55055237, 8.07611179], [93.55194092, 8.07472134], [93.55194092, 8.07416534], [93.55222321, 8.07388973], [93.55222321, 8.07306004], [93.55249786, 8.07277966], [93.55222321, 8.07249928], [93.55222321, 8.07194328], [93.55194092, 8.07166672], [93.55194092, 8.07027721], [93.55222321, 8.07000065], [93.55222321, 8.06917191], [93.55249786, 8.06889057], [93.55249786, 8.06833076], [93.55278015, 8.06805515], [93.55278015, 8.0672226], [93.55305481, 8.06694508], [93.55305481, 8.06638908], [93.55278015, 8.06611061], [93.55229187, 8.06603813], [93.55187225, 8.06582832], [93.55152893, 8.06528091], [93.5515976, 8.06464958], [93.55083466, 8.06388855], [93.55082703, 8.06194019], [93.55055237, 8.06166744], [93.55055237, 8.06055737], [93.55027771, 8.0602808], [93.55027771, 8.05943966], [93.55000305, 8.05916595], [93.55000305, 8.05888844], [93.54972076, 8.05860996], [93.54972076, 8.05777836], [93.55000305, 8.05749989], [93.55000305, 8.05722046], [93.54944611, 8.05666637], [93.54915619, 8.05667114], [93.54860687, 8.05611038], [93.5486145, 8.05305576], [93.54916382, 8.05249977], [93.54915619, 8.05138969], [93.54888916, 8.05111027], [93.54888916, 8.05055618], [93.5486145, 8.05027771], [93.54860687, 8.05000019], [93.5477829, 8.04916954], [93.54750061, 8.0494442], [93.54693604, 8.04944134], [93.54666138, 8.04973125], [93.54611206, 8.04973125], [93.54582977, 8.04944134], [93.54555511, 8.0494442], [93.54534912, 8.0492363], [93.54533386, 8.04915619], [93.54528046, 8.04889202], [93.54722595, 8.0469389], [93.54722595, 8.04666805], [93.5486145, 8.04527664], [93.54860687, 8.04444122], [93.54916382, 8.04388905], [93.54916382, 8.04333305], [93.54944611, 8.04305458], [93.54944611, 8.04249859], [93.54972076, 8.04222107], [93.54972076, 8.04083347], [93.54944611, 8.040555], [93.54944611, 8.03888893], [93.54972076, 8.03861141], [93.54972076, 8.03777885], [93.55000305, 8.03750134], [93.55000305, 8.03666687], [93.55027771, 8.03639126], [93.55027771, 8.03611088], [93.55000305, 8.03583336], [93.55000305, 8.03555679], [93.54972076, 8.03527641], [93.54916382, 8.03527641], [93.5486145, 8.03583336], [93.54777527, 8.03583336], [93.54750061, 8.03611088], [93.54666138, 8.03611088], [93.54638672, 8.03639126], [93.54582977, 8.03639126], [93.54567719, 8.03681946], [93.54532623, 8.03689003], [93.54491425, 8.03688812], [93.54450226, 8.03722954], [93.54412079, 8.03731155], [93.54376984, 8.03738022], [93.54250336, 8.03750134], [93.54222107, 8.03722286], [93.54194641, 8.03750134], [93.54165649, 8.03750134], [93.5402832, 8.03889084], [93.54000092, 8.03889084], [93.53971863, 8.03916931], [93.53944397, 8.0391674], [93.53916931, 8.03944492], [93.53916931, 8.03972054], [93.53943634, 8.04000092], [93.53943634, 8.0402813], [93.53971863, 8.040555], [93.53971863, 8.04166698], [93.53944397, 8.04194546], [93.53944397, 8.04222107], [93.53805542, 8.04361057], [93.53694153, 8.04361057], [93.5358429, 8.04472065], [93.53583527, 8.04527664], [93.53610992, 8.04555511], [93.53610992, 8.04611111], [93.53617859, 8.04652596], [93.53590393, 8.04708195], [93.53527832, 8.04694557], [93.53416443, 8.04694557], [93.53388977, 8.04722118], [93.53360748, 8.04722118], [93.53333282, 8.04750156], [93.53305817, 8.04750156], [93.53277588, 8.04778194], [93.53250122, 8.04778194]]], [[[92.60888672, 10.93861008], [92.60916901, 10.93833542], [92.61000061, 10.93833542], [92.61027527, 10.93805695], [92.61076355, 10.93784904], [92.61222076, 10.93638992], [92.61292267, 10.93612194], [92.61360168, 10.93556118], [92.61458588, 10.93492985], [92.61576843, 10.93479061], [92.61666107, 10.93500042], [92.61704254, 10.93462563], [92.61723328, 10.93443966], [92.61750031, 10.93444443], [92.61805725, 10.93388844], [92.61833191, 10.93389034], [92.61902618, 10.93278027], [92.61923218, 10.93236065], [92.61999512, 10.93118286], [92.62034607, 10.93062687], [92.62090302, 10.92993355], [92.62000275, 10.92861176], [92.61937714, 10.92819691], [92.61854553, 10.92784405], [92.61763763, 10.92763615], [92.61722565, 10.92749691], [92.61694336, 10.92750168], [92.61682129, 10.92743111], [92.61631775, 10.92736053], [92.61569214, 10.92729187], [92.61507416, 10.92715454], [92.61444092, 10.92722225], [92.61416626, 10.92721939], [92.6138916, 10.92750168], [92.61332703, 10.92750168], [92.61277771, 10.92785072], [92.61222076, 10.92805576], [92.61118317, 10.92882061], [92.61083221, 10.92916775], [92.6102066, 10.92965317], [92.60972595, 10.92998791], [92.60943604, 10.93027973], [92.60909271, 10.93041706], [92.60832977, 10.93166637], [92.60798645, 10.93194199], [92.60778046, 10.93250179], [92.60778046, 10.93277836], [92.60639191, 10.93416595], [92.60639191, 10.93444443], [92.60610962, 10.93472195], [92.60610962, 10.93555641], [92.60583496, 10.93583202], [92.60582733, 10.93694019], [92.60694122, 10.93806076], [92.60778046, 10.93805695], [92.60805511, 10.93833542], [92.60832977, 10.93833542], [92.60861206, 10.93861008], [92.60888672, 10.93861008]]], [[[92.22673798, 10.98229027], [92.22736359, 10.9822216], [92.22777557, 10.9822216], [92.22805786, 10.9822216], [92.22833252, 10.98222446], [92.22861481, 10.9822216], [92.22861481, 10.98194408], [92.22888947, 10.98166466], [92.22888947, 10.98111153], [92.22916412, 10.98083401], [92.22916412, 10.98027802], [92.22868347, 10.97930431], [92.22860718, 10.97881889], [92.22860718, 10.9779892], [92.22846985, 10.97771072], [92.22792053, 10.97611141], [92.22743225, 10.97590446], [92.22694397, 10.97555542], [92.22645569, 10.97534847], [92.22611237, 10.97529125], [92.22583008, 10.97507191], [92.22471619, 10.97417164], [92.22409821, 10.97389126], [92.22333527, 10.97361088], [92.22298431, 10.97340393], [92.22222137, 10.97277737], [92.22181702, 10.97277927], [92.22084045, 10.97249889], [92.22014618, 10.97249889], [92.21930695, 10.97243023], [92.21888733, 10.97249889], [92.21861267, 10.97249889], [92.21833038, 10.97277927], [92.21806335, 10.9730587], [92.21778107, 10.97305489], [92.21749878, 10.97333336], [92.21749878, 10.97361088], [92.21639252, 10.97472095], [92.21640015, 10.97500134], [92.21611023, 10.97527695], [92.21611023, 10.97555542], [92.21583557, 10.97583294], [92.21583557, 10.97611141], [92.21499634, 10.97694302], [92.21499634, 10.9772234], [92.21472168, 10.97749901], [92.21472168, 10.97833347], [92.21499634, 10.97861099], [92.21499634, 10.97889042], [92.21602631, 10.97948933], [92.21727753, 10.98018169], [92.21839142, 10.98087215], [92.21916199, 10.98163128], [92.22006989, 10.9821167], [92.22090912, 10.98260021], [92.22138977, 10.98291874], [92.22222137, 10.98312569], [92.22250366, 10.98326302], [92.22312164, 10.9831934], [92.22360992, 10.98305321], [92.22423553, 10.98298454], [92.22451782, 10.9827776], [92.22479248, 10.98270035], [92.22499847, 10.98250008], [92.2260437, 10.98236084], [92.22673798, 10.98229027]]], [[[92.66335297, 10.98180008], [92.66194153, 10.98139191], [92.66166687, 10.98167038], [92.66139221, 10.98167038], [92.66110992, 10.98166466], [92.65972137, 10.98305607], [92.65972137, 10.98333359], [92.65944672, 10.98361206], [92.65944672, 10.98388767], [92.65916443, 10.98416805], [92.6591568, 10.98472023], [92.6588974, 10.98499966], [92.65888977, 10.98527813], [92.65860748, 10.98555565], [92.65844727, 10.98655033], [92.65846252, 10.98696709], [92.65866852, 10.98744965], [92.65873718, 10.9880724], [92.65873718, 10.98862076], [92.65895081, 10.98924637], [92.65901947, 10.98986816], [92.65936279, 10.99042225], [92.65950775, 10.99104404], [92.66020203, 10.99166584], [92.66083527, 10.99222183], [92.66110992, 10.99222183], [92.66139221, 10.99250126], [92.66166687, 10.99250126], [92.66194153, 10.99277878], [92.66284943, 10.99281025], [92.6635437, 10.99281025], [92.66487122, 10.99273968], [92.66563416, 10.9926033], [92.66647339, 10.99218845], [92.66772461, 10.99170494], [92.66861725, 10.99110126], [92.66929626, 10.99004078], [92.66951752, 10.98942089], [92.66979218, 10.98845291], [92.66979218, 10.98748398], [92.66951752, 10.98679447], [92.66916656, 10.98583412], [92.66916656, 10.98555565], [92.66777802, 10.98416805], [92.66750336, 10.98416805], [92.66721344, 10.98393822], [92.66694641, 10.98388958], [92.66638947, 10.98333168], [92.66600037, 10.98296928], [92.66474152, 10.98228073], [92.66335297, 10.98180008]]], [[[92.73194122, 11.14973068], [92.73249817, 11.14917088], [92.73278046, 11.14917088], [92.73332977, 11.14861202], [92.73339844, 11.14833641], [92.73423767, 11.14785099], [92.73443604, 11.14693928], [92.73472595, 11.14666557], [92.73472595, 11.14611244], [92.73500061, 11.14583397], [92.73500061, 11.14555645], [92.73444366, 11.14500046], [92.73416901, 11.14500046], [92.73388672, 11.14472198], [92.73361206, 11.14458466], [92.73319244, 11.14402866], [92.73256683, 11.14285278], [92.73139191, 11.14194584], [92.73110962, 11.14194584], [92.73083496, 11.14166546], [92.73027802, 11.14145756], [92.72944641, 11.14215279], [92.72916412, 11.14222145], [92.7277832, 11.14360046], [92.72777557, 11.14388847], [92.72750092, 11.1441679], [92.72750092, 11.14444447], [92.72721863, 11.14472198], [92.72721863, 11.14500046], [92.72694397, 11.14527798], [92.72694397, 11.14555645], [92.72721863, 11.14583397], [92.72721863, 11.14611244], [92.72846985, 11.14770985], [92.72902679, 11.14804935], [92.73110962, 11.14973068], [92.73194122, 11.14973068]]], [[[92.67694092, 11.18361092], [92.67749786, 11.18305683], [92.67804718, 11.18306065], [92.6783371, 11.18278122], [92.67888641, 11.18278122], [92.6791687, 11.18250275], [92.67944336, 11.18250275], [92.67973328, 11.18222046], [92.68000031, 11.18222332], [92.6811142, 11.18111038], [92.6811142, 11.18055439], [92.68055725, 11.18000031], [92.68026733, 11.18000031], [92.67804718, 11.17778111], [92.67804718, 11.17749977], [92.67749786, 11.17694187], [92.67722321, 11.17694187], [92.67666626, 11.17749977], [92.6763916, 11.17749977], [92.67610931, 11.17778111], [92.67583466, 11.17777824], [92.67555237, 11.17805576], [92.67555237, 11.17833424], [92.67610931, 11.17888832], [92.67610931, 11.17971134], [92.67555237, 11.18027782], [92.67555237, 11.18055439], [92.67500305, 11.18111038], [92.67527771, 11.1813879], [92.67500305, 11.18166637], [92.67500305, 11.18194485], [92.67472076, 11.18222046], [92.67472076, 11.18250275], [92.67444611, 11.18277645], [92.67444611, 11.18305683], [92.67415619, 11.18332958], [92.67416382, 11.18388939], [92.67388916, 11.18416691], [92.67388916, 11.18444538], [92.67333221, 11.18500137], [92.67333221, 11.18527889], [92.67305756, 11.18555546], [92.67305756, 11.18694019], [92.67360687, 11.18750095], [92.6736145, 11.18777657], [92.67388916, 11.18805504], [92.67389679, 11.18833065], [92.67416382, 11.18861103], [92.67416382, 11.18888855], [92.67472076, 11.18944454], [92.67555237, 11.18944454], [92.6763916, 11.18861103], [92.6763916, 11.18833256], [92.67666626, 11.18805504], [92.67666626, 11.18694496], [92.67694092, 11.18666744], [92.67694092, 11.18638897], [92.67666626, 11.18611145], [92.67666626, 11.18583298], [92.6763916, 11.18555546], [92.6763916, 11.18500137], [92.67666626, 11.1847229], [92.67666626, 11.18416691], [92.67694092, 11.18388939], [92.67694092, 11.18361092]]], [[[92.70597839, 11.28916645], [92.70639038, 11.28833008], [92.70659637, 11.28763676], [92.70694733, 11.28735924], [92.70694733, 11.28708076], [92.70722198, 11.28673458], [92.70722198, 11.28652668], [92.70722198, 11.28610992], [92.70722198, 11.28582954], [92.70694733, 11.28555584], [92.70694733, 11.28528976], [92.70687866, 11.28479099], [92.70687866, 11.28444195], [92.70749664, 11.28333378], [92.70749664, 11.28277779], [92.70722198, 11.28250027], [92.70722198, 11.28222179], [92.70659637, 11.28125095], [92.70659637, 11.28020859], [92.70667267, 11.27993107], [92.70667267, 11.27971935], [92.7069397, 11.27916622], [92.7069397, 11.27833366], [92.70666504, 11.27777767], [92.70667267, 11.27750015], [92.7059021, 11.27659702], [92.7059021, 11.27590179], [92.70610809, 11.27527714], [92.70610809, 11.27472115], [92.70639038, 11.27444553], [92.70639038, 11.2733326], [92.70666504, 11.27305508], [92.70667267, 11.27250099], [92.70639038, 11.27222061], [92.70639038, 11.27166653], [92.70582581, 11.27111053], [92.70583344, 11.27083302], [92.70555878, 11.27055454], [92.70555878, 11.27028179], [92.70527649, 11.27000141], [92.70527649, 11.26889133], [92.70555878, 11.26861095], [92.70555878, 11.26750088], [92.70639038, 11.26666927], [92.70639038, 11.2650013], [92.70610809, 11.26471996], [92.70583344, 11.26416683], [92.70583344, 11.26305676], [92.70388031, 11.26112175], [92.70361328, 11.26112175], [92.70305634, 11.26056099], [92.70305634, 11.26000023], [92.7022171, 11.25917053], [92.70139313, 11.25917053], [92.70110321, 11.25893402], [92.70083618, 11.25889015], [92.70069885, 11.25874901], [92.70027924, 11.25833035], [92.69999695, 11.25833416], [92.69916534, 11.25749969], [92.69902802, 11.25729275], [92.69880676, 11.25624657], [92.69832611, 11.25556087], [92.69721985, 11.25443935], [92.69694519, 11.25444412], [92.69472504, 11.25222206], [92.69472504, 11.25194359], [92.69451904, 11.25145817], [92.69444275, 11.25111198], [92.69444275, 11.25083065], [92.69472504, 11.25055599], [92.69473267, 11.25028038], [92.69444275, 11.25000191], [92.69444275, 11.24918079], [92.69500732, 11.2486124], [92.69499969, 11.24833298], [92.69527435, 11.24805546], [92.69526672, 11.24777985], [92.69473267, 11.24722099], [92.69472504, 11.24694538], [92.69444275, 11.24666691], [92.69444275, 11.24638939], [92.69416809, 11.24612045], [92.69416809, 11.24555969], [92.6938858, 11.24527931], [92.6938858, 11.24500084], [92.69361115, 11.24472141], [92.69361115, 11.24388885], [92.69333649, 11.24361134], [92.69333649, 11.24333286], [92.69277954, 11.24277687], [92.69249725, 11.24278164], [92.6922226, 11.24250126], [92.69139099, 11.24250126], [92.6911087, 11.24278164], [92.69055176, 11.24278164], [92.6902771, 11.24250126], [92.68972015, 11.24250126], [92.68945313, 11.24222088], [92.6883316, 11.24222088], [92.68736267, 11.24208164], [92.68722534, 11.24277687], [92.68723297, 11.24333096], [92.68776703, 11.24389076], [92.68777466, 11.24416733], [92.68805695, 11.24444103], [92.68805695, 11.24500084], [92.6875, 11.24555969], [92.6875, 11.24638939], [92.68972015, 11.2486124], [92.68972015, 11.24889183], [92.69000244, 11.24916458], [92.69000244, 11.24972057], [92.6902771, 11.25000191], [92.6902771, 11.25055599], [92.69055176, 11.25083065], [92.69055176, 11.25111198], [92.6911087, 11.25166798], [92.6911087, 11.25194359], [92.69139099, 11.2522192], [92.69139099, 11.25249958], [92.69194794, 11.25305557], [92.69194794, 11.25444412], [92.6922226, 11.25472164], [92.6922226, 11.25583363], [92.69361115, 11.25722218], [92.6938858, 11.25722027], [92.69416809, 11.25749969], [92.69444275, 11.25749969], [92.69473267, 11.25778103], [92.69472504, 11.25805569], [92.69499969, 11.25833416], [92.69500732, 11.25860977], [92.69526672, 11.25889015], [92.69527435, 11.25916576], [92.6958313, 11.25971985], [92.6958313, 11.26000023], [92.6966629, 11.26082993], [92.6966629, 11.26139069], [92.69694519, 11.2616663], [92.69694519, 11.26194382], [92.6966629, 11.26222324], [92.6966629, 11.2624979], [92.69638824, 11.26277637], [92.69638824, 11.26416683], [92.69610596, 11.26443958], [92.69610596, 11.2650013], [92.69555664, 11.26555538], [92.69555664, 11.2658329], [92.69526672, 11.26611137], [92.69526672, 11.26638889], [92.69500732, 11.26666927], [92.69499969, 11.26777744], [92.69444275, 11.26833057], [92.69444275, 11.26861095], [92.69361115, 11.26944542], [92.69361115, 11.26972103], [92.69333649, 11.27000141], [92.69333649, 11.27055454], [92.6930542, 11.27083302], [92.69304657, 11.27222061], [92.69333649, 11.27249908], [92.69333649, 11.27333069], [92.69361115, 11.27361107], [92.69381714, 11.27437496], [92.6938858, 11.27472115], [92.69381714, 11.27507019], [92.69361115, 11.27610016], [92.69322205, 11.27673244], [92.69322205, 11.27713871], [92.69301605, 11.27796936], [92.69307709, 11.27852058], [92.69287872, 11.27893543], [92.69277954, 11.27971935], [92.69277954, 11.27999973], [92.69249725, 11.28027821], [92.69249725, 11.2808342], [92.69277954, 11.28110981], [92.69277954, 11.28139019], [92.69444275, 11.28306103], [92.69444275, 11.2841711], [92.69526672, 11.28499985], [92.69610596, 11.28499985], [92.69638824, 11.28528976], [92.6966629, 11.28528976], [92.69695282, 11.28556061], [92.69721985, 11.28555584], [92.69750214, 11.28583431], [92.69777679, 11.28583431], [92.69805908, 11.28610992], [92.69832611, 11.28610992], [92.6986084, 11.2863903], [92.69889069, 11.2863903], [92.69917297, 11.28667068], [92.69972229, 11.28666592], [92.70027924, 11.28722191], [92.70055389, 11.28722191], [92.70166779, 11.28833199], [92.70194244, 11.28833199], [92.70222473, 11.28861046], [92.70252228, 11.28863335], [92.70276642, 11.28889084], [92.70333099, 11.28889084], [92.70361328, 11.28861046], [92.70417023, 11.28861046], [92.70443726, 11.28889084], [92.70471954, 11.28888798], [92.70527649, 11.28944492], [92.70555878, 11.28944492], [92.70597839, 11.28916645]]], [[[92.72566223, 11.14421844], [92.72576141, 11.14415932], [92.72589874, 11.14381504], [92.72589874, 11.1434679], [92.72583008, 11.14305592], [92.72583008, 11.14249992], [92.72556305, 11.14222145], [92.72555542, 11.14166546], [92.72528076, 11.14138985], [92.72528076, 11.14111233], [92.72444153, 11.14027691], [92.72416687, 11.14027977], [92.72389221, 11.14056015], [92.72360992, 11.14055538], [92.72277832, 11.14138985], [92.72277832, 11.14194584], [92.72249603, 11.14222145], [92.72250366, 11.14249992], [92.72277832, 11.1427784], [92.72277832, 11.14333057], [92.7233429, 11.14389038], [92.72444153, 11.14389038], [92.72471619, 11.14416981], [92.72499847, 11.1441679], [92.72528076, 11.14444447], [92.72566223, 11.14421844]]], [[[92.54833221, 11.39302921], [92.54801941, 11.392869], [92.54749298, 11.3931179], [92.54696655, 11.39356709], [92.5464859, 11.39395428], [92.54610443, 11.39437389], [92.54577637, 11.39484119], [92.54567719, 11.39538765], [92.54588318, 11.39592075], [92.54627991, 11.39636612], [92.54673004, 11.39671421], [92.54721832, 11.39695072], [92.54766846, 11.39715576], [92.54815674, 11.3972702], [92.54860687, 11.39744759], [92.54911804, 11.39749241], [92.54960632, 11.39745045], [92.55001831, 11.3972702], [92.55036926, 11.39717484], [92.5506134, 11.3970108], [92.55084229, 11.39680481], [92.55104828, 11.39651394], [92.55112457, 11.396101], [92.5511322, 11.39562702], [92.55091858, 11.39511204], [92.55073547, 11.39456272], [92.55037689, 11.39410686], [92.54992676, 11.39363098], [92.54888153, 11.39333153], [92.54858398, 11.39316273], [92.54833221, 11.39302921]]], [[[92.55757904, 11.39093685], [92.55724335, 11.39022064], [92.55683136, 11.39023018], [92.55564117, 11.39094067], [92.55567169, 11.39146137], [92.55583191, 11.39212036], [92.55606079, 11.39273262], [92.55613708, 11.39325047], [92.55621338, 11.39379692], [92.55622864, 11.39448071], [92.55640411, 11.39519596], [92.55696106, 11.3955946], [92.55734253, 11.39604187], [92.55780029, 11.39647961], [92.55831909, 11.39687157], [92.5589447, 11.39708614], [92.55939484, 11.39734554], [92.56003571, 11.39749241], [92.56074524, 11.39770985], [92.56130219, 11.39770794], [92.56181335, 11.39764023], [92.56237793, 11.39745045], [92.56274414, 11.39721775], [92.56302643, 11.39687157], [92.56342316, 11.39629459], [92.56356049, 11.39600086], [92.56368256, 11.39541531], [92.56347656, 11.39481068], [92.56304169, 11.39419079], [92.56267548, 11.39366341], [92.56220245, 11.39310932], [92.56189728, 11.39276028], [92.56150055, 11.39247131], [92.56079865, 11.39216137], [92.5603714, 11.39186192], [92.55999756, 11.39173031], [92.55973816, 11.39159107], [92.55921936, 11.3913517], [92.55906677, 11.39127159], [92.55871582, 11.39126873], [92.55800629, 11.391222], [92.55757904, 11.39093685]]], [[[92.70054626, 11.31138992], [92.70166779, 11.31027985], [92.70166779, 11.31000042], [92.70291901, 11.30867958], [92.70361328, 11.30860996], [92.70388031, 11.3085413], [92.70417023, 11.3085413], [92.70443726, 11.30860996], [92.70555878, 11.30860996], [92.70582581, 11.30832863], [92.70610809, 11.30833435], [92.70639038, 11.30805588], [92.70667267, 11.30806065], [92.70701599, 11.3080492], [92.7076416, 11.3080492], [92.70804596, 11.30806065], [92.70888519, 11.30805588], [92.70916748, 11.30833435], [92.70972443, 11.30833435], [92.70999908, 11.30860996], [92.71028137, 11.30860996], [92.71055603, 11.30832863], [92.71090698, 11.30812359], [92.71083069, 11.30777836], [92.71083069, 11.30722046], [92.71096802, 11.30694389], [92.71111298, 11.30666637], [92.71111298, 11.30638981], [92.71111298, 11.30611038], [92.71131897, 11.30472183], [92.71215057, 11.30354118], [92.7121582, 11.30312157], [92.71138763, 11.30250168], [92.71111298, 11.3022213], [92.71083069, 11.3022213], [92.71058655, 11.30197525], [92.70972443, 11.30111122], [92.70944214, 11.30110931], [92.70916748, 11.3013916], [92.70888519, 11.30138874], [92.70694733, 11.30333138], [92.70603943, 11.30360889], [92.70582581, 11.30416965], [92.70582581, 11.30500031], [92.70388794, 11.30680943], [92.70276642, 11.30722046], [92.70194244, 11.30806065], [92.70166779, 11.30805588], [92.7013855, 11.30833435], [92.69916534, 11.30833435], [92.69889069, 11.30805588], [92.69833374, 11.30805588], [92.69805908, 11.30833435], [92.69806671, 11.30860996], [92.69750214, 11.30916595], [92.69777679, 11.30944443], [92.69777679, 11.30972195], [92.69806671, 11.31000042], [92.69806671, 11.31027985], [92.69832611, 11.31056118], [92.6986084, 11.31055641], [92.69916534, 11.3111124], [92.69944763, 11.3111124], [92.69953918, 11.311203], [92.69972229, 11.31138992], [92.70054626, 11.31138992]]], [[[92.72305298, 11.31638813], [92.72277832, 11.31610966], [92.72277832, 11.31583214], [92.72138977, 11.31444359], [92.72083282, 11.31444359], [92.71994019, 11.31484985], [92.71903992, 11.31618118], [92.71861267, 11.31632042], [92.71847534, 11.31621838], [92.71833038, 11.31611347], [92.71778107, 11.31611347], [92.71729279, 11.31548595], [92.71721649, 11.31499958], [92.71721649, 11.31472015], [92.71670532, 11.31420135], [92.7166748, 11.31388569], [92.71646118, 11.31312943], [92.71666718, 11.31236076], [92.71646118, 11.31140232], [92.71646118, 11.31022835], [92.71598053, 11.30995178], [92.71583557, 11.30916595], [92.71472168, 11.30806065], [92.71444702, 11.30805588], [92.71416473, 11.30833435], [92.71360779, 11.30833435], [92.71283722, 11.30901146], [92.7122879, 11.30999756], [92.71235657, 11.31062508], [92.71257019, 11.3109026], [92.71277618, 11.31110954], [92.71305084, 11.31166553], [92.71333313, 11.31194019], [92.71333313, 11.31223106], [92.71360779, 11.31278133], [92.71389008, 11.31306076], [92.71389008, 11.31361008], [92.7141571, 11.31389141], [92.71416473, 11.31416607], [92.71444702, 11.31444359], [92.71444702, 11.31472015], [92.71472168, 11.31499958], [92.71472168, 11.3166666], [92.71499634, 11.31694508], [92.71499634, 11.3172226], [92.71492767, 11.31763268], [92.71478271, 11.31832314], [92.7141571, 11.31972122], [92.7141571, 11.32000065], [92.71389008, 11.32028103], [92.71389008, 11.32056236], [92.71430969, 11.32117939], [92.71507263, 11.32139969], [92.71611023, 11.32250118], [92.71639252, 11.32264042], [92.71687317, 11.32291603], [92.71721649, 11.32319164], [92.71756744, 11.32367897], [92.71778107, 11.32444096], [92.7179184, 11.32479191], [92.7179184, 11.32500076], [92.71833038, 11.32527924], [92.71833038, 11.32555485], [92.71826172, 11.32583141], [92.71833038, 11.32611084], [92.71805573, 11.32638931], [92.71777344, 11.32708359], [92.71763611, 11.32748985], [92.71736145, 11.32847691], [92.71784973, 11.32944584], [92.71805573, 11.32972145], [92.71833038, 11.33027077], [92.71861267, 11.33055592], [92.72000122, 11.33194447], [92.72042084, 11.33215141], [92.72110748, 11.33278179], [92.72138977, 11.33278179], [92.7216568, 11.33306026], [92.72274017, 11.33306026], [92.72302246, 11.33292103], [92.72344208, 11.33278179], [92.72371674, 11.33264065], [92.72399902, 11.33195019], [92.72399902, 11.33098412], [92.72410583, 11.32983112], [92.72396851, 11.32921124], [92.72354889, 11.32852268], [92.7232666, 11.32707977], [92.72312927, 11.32590199], [92.72277832, 11.32576942], [92.72249603, 11.32500076], [92.72252655, 11.32429028], [92.72253418, 11.32318878], [92.72289276, 11.3220787], [92.72281647, 11.32153225], [92.72323608, 11.32084179], [92.72344208, 11.32001495], [92.72393036, 11.31925964], [92.72386169, 11.31878185], [92.72399902, 11.31781101], [92.72379303, 11.3176012], [92.72344208, 11.31663036], [92.72305298, 11.31638813]]], [[[92.27179718, 11.51599121], [92.27068329, 11.51598835], [92.27053833, 11.51619053], [92.270401, 11.516469], [92.270401, 11.51688194], [92.27046967, 11.5170908], [92.27159119, 11.51771069], [92.27186584, 11.51805782], [92.27214813, 11.51833439], [92.27278137, 11.51819515], [92.27362061, 11.51750183], [92.27334595, 11.51653099], [92.27194214, 11.51605701], [92.27179718, 11.51599121]]], [[[92.2141571, 11.57568073], [92.21396637, 11.57594967], [92.21385193, 11.57629204], [92.21364594, 11.57654953], [92.21347046, 11.57682133], [92.21334076, 11.57712173], [92.21316528, 11.57739735], [92.21304321, 11.57769108], [92.21289063, 11.57795334], [92.21276093, 11.57823181], [92.2125473, 11.57849979], [92.21240234, 11.57886124], [92.21218109, 11.579216], [92.21192932, 11.57961273], [92.21163177, 11.58004093], [92.21129608, 11.58050156], [92.21086121, 11.5809164], [92.21038818, 11.58134937], [92.20983124, 11.58172989], [92.20929718, 11.58216953], [92.20871735, 11.58254147], [92.20816803, 11.58296108], [92.20770264, 11.58344173], [92.20739746, 11.58401108], [92.20723724, 11.58463955], [92.20726013, 11.58525085], [92.20757294, 11.5857296], [92.20799255, 11.58601856], [92.20848083, 11.5861063], [92.20894623, 11.58613968], [92.20936584, 11.5863018], [92.20975494, 11.58622742], [92.21014404, 11.58615208], [92.21091461, 11.58622169], [92.21127319, 11.58629131], [92.21237946, 11.5866394], [92.21321869, 11.58725929], [92.2138443, 11.58780766], [92.21412659, 11.58815479], [92.21510315, 11.58884144], [92.21566772, 11.58912086], [92.21607971, 11.58981037], [92.21631622, 11.59037018], [92.21650696, 11.59081745], [92.21669006, 11.59125042], [92.21690369, 11.59167576], [92.21704102, 11.59215164], [92.21704102, 11.59276962], [92.21669006, 11.59332561], [92.21585083, 11.59360027], [92.21550751, 11.59366989], [92.21536255, 11.59395123], [92.21550751, 11.59457111], [92.21591949, 11.59457111], [92.21746063, 11.59464073], [92.21781158, 11.59464073], [92.21814728, 11.59395123], [92.21800232, 11.59284973], [92.21825409, 11.59238529], [92.21893311, 11.5923233], [92.21906281, 11.59230328], [92.21934509, 11.5924921], [92.21988678, 11.59246159], [92.22039032, 11.59226227], [92.22090149, 11.59217072], [92.22132111, 11.59195232], [92.22170258, 11.59173489], [92.22206116, 11.59153938], [92.222435, 11.5913372], [92.22277069, 11.59108067], [92.22310638, 11.59076023], [92.22348022, 11.59041977], [92.22387695, 11.59007168], [92.22429657, 11.58974075], [92.22470093, 11.58945179], [92.22509003, 11.58922195], [92.22551727, 11.58907127], [92.22590637, 11.58889103], [92.2263031, 11.58872032], [92.22670746, 11.58859921], [92.22711945, 11.58845139], [92.22756958, 11.58830261], [92.2279892, 11.58805466], [92.22840881, 11.58778572], [92.22884369, 11.58757401], [92.22931671, 11.58750057], [92.22984314, 11.5874424], [92.2303772, 11.58728027], [92.23097229, 11.58724117], [92.23153687, 11.58731174], [92.231987, 11.58751202], [92.23230743, 11.58776283], [92.23255157, 11.58801365], [92.2327652, 11.58825302], [92.23297119, 11.58852196], [92.23323059, 11.58877945], [92.23351288, 11.58906746], [92.23383331, 11.5893898], [92.23412323, 11.58979988], [92.23439026, 11.59028053], [92.23467255, 11.59076691], [92.23504639, 11.59114265], [92.23548889, 11.59141159], [92.23600769, 11.59135342], [92.23641968, 11.59139061], [92.23684692, 11.59139061], [92.2374115, 11.59143734], [92.23788452, 11.5916214], [92.23841095, 11.59169197], [92.23900604, 11.59177017], [92.23958588, 11.59186077], [92.24021149, 11.59181118], [92.2408371, 11.59194088], [92.24150085, 11.59206963], [92.24217224, 11.59198189], [92.24288177, 11.59195042], [92.24359131, 11.59194088], [92.24424744, 11.59190369], [92.24479675, 11.59170628], [92.24533844, 11.5916214], [92.24581146, 11.59142971], [92.24627686, 11.591362], [92.24669647, 11.59115028], [92.24714661, 11.59111118], [92.24760437, 11.59111118], [92.2480545, 11.59090424], [92.24841309, 11.59086037], [92.24888611, 11.59073925], [92.24938202, 11.59062958], [92.24990845, 11.59059143], [92.25042725, 11.59062958], [92.25096893, 11.59049129], [92.25166321, 11.59037495], [92.25228119, 11.59031773], [92.2529068, 11.59029007], [92.25354004, 11.59034061], [92.25417328, 11.59029007], [92.25479126, 11.59028053], [92.25541687, 11.59031582], [92.25602722, 11.59050179], [92.25666809, 11.59055328], [92.2572403, 11.59043407], [92.25786591, 11.59027004], [92.25845337, 11.59029961], [92.25910187, 11.59010124], [92.25982666, 11.58982086], [92.26074219, 11.58969116], [92.26132965, 11.58964062], [92.26152039, 11.58967972], [92.26171875, 11.58972073], [92.26216888, 11.58965492], [92.26244354, 11.5897274], [92.26258087, 11.58976364], [92.26313019, 11.58967113], [92.26369476, 11.58947468], [92.26407623, 11.58923054], [92.26439667, 11.58889103], [92.26455688, 11.58783054], [92.26542664, 11.5873909], [92.26598358, 11.58743477], [92.26631927, 11.58728886], [92.26646423, 11.58722496], [92.26693726, 11.58694935], [92.26721954, 11.58672142], [92.26766968, 11.5863018], [92.26808929, 11.58588886], [92.26864624, 11.58551979], [92.26902771, 11.585495], [92.26937866, 11.58527184], [92.26990509, 11.58494377], [92.27031708, 11.58452034], [92.27072906, 11.58409119], [92.27096558, 11.58358955], [92.2710495, 11.5830698], [92.27102661, 11.58213139], [92.27088928, 11.58115101], [92.27088928, 11.57964516], [92.27061462, 11.5787468], [92.27054596, 11.57792187], [92.27060699, 11.57716274], [92.27076721, 11.57678032], [92.27076721, 11.57644939], [92.27054596, 11.57611179], [92.27047729, 11.57578087], [92.27031708, 11.57550335], [92.2702713, 11.57512283], [92.27021027, 11.57467842], [92.27002716, 11.57421112], [92.2699585, 11.57365322], [92.2697525, 11.57312393], [92.26963806, 11.57258224], [92.26943207, 11.5720892], [92.26917267, 11.57160187], [92.2689209, 11.57108402], [92.2687149, 11.57053471], [92.26856232, 11.56997204], [92.26835632, 11.56941128], [92.26833344, 11.56878662], [92.26837921, 11.56812096], [92.26860809, 11.56748486], [92.26860809, 11.56686497], [92.26879883, 11.56612015], [92.26916504, 11.56594944], [92.2694397, 11.56579018], [92.26965332, 11.56533241], [92.2696991, 11.56488037], [92.26959229, 11.56443977], [92.2694397, 11.56400108], [92.26925659, 11.5635519], [92.26912689, 11.56305027], [92.26893616, 11.56260109], [92.26889038, 11.56212044], [92.26883698, 11.56165981], [92.26869202, 11.56124306], [92.26880646, 11.56075478], [92.26864624, 11.56024456], [92.26861572, 11.55969524], [92.26866913, 11.5591507], [92.26885223, 11.55865097], [92.26889038, 11.55811977], [92.26889038, 11.55762386], [92.26889038, 11.55713844], [92.26889038, 11.55665016], [92.26889038, 11.55615807], [92.26889038, 11.5556612], [92.26889038, 11.55518723], [92.26892853, 11.55477047], [92.26912689, 11.55443954], [92.26917267, 11.55409145], [92.26916504, 11.55375576], [92.26919556, 11.55342102], [92.26935577, 11.55311108], [92.26946259, 11.55272102], [92.26961517, 11.55230904], [92.26972198, 11.55182076], [92.26982117, 11.551301], [92.26997375, 11.55080223], [92.26999664, 11.55027103], [92.26999664, 11.54973125], [92.27001953, 11.54921436], [92.27017975, 11.54874039], [92.2702179, 11.54804039], [92.27070618, 11.54756069], [92.27122498, 11.54754257], [92.2716217, 11.54725075], [92.2719574, 11.54690933], [92.27217865, 11.54648113], [92.27222443, 11.54593563], [92.27226257, 11.54535007], [92.27243805, 11.5448103], [92.27250671, 11.54428196], [92.27259064, 11.54382133], [92.27275085, 11.54339981], [92.27279663, 11.54293919], [92.27292633, 11.5425024], [92.27308655, 11.5420866], [92.27330017, 11.54173088], [92.27342224, 11.5413208], [92.27360535, 11.54093075], [92.27378845, 11.54051876], [92.27391815, 11.54008102], [92.27411652, 11.53969955], [92.27416229, 11.539258], [92.27416992, 11.53878021], [92.27420044, 11.53831196], [92.27435303, 11.53785706], [92.27448273, 11.53738022], [92.27468109, 11.53693771], [92.27472687, 11.53640938], [92.27472687, 11.53586864], [92.27471161, 11.53536129], [92.27464294, 11.53492069], [92.27445984, 11.53456116], [92.27430725, 11.53419018], [92.27410889, 11.5338316], [92.27390289, 11.53343964], [92.27371979, 11.53304291], [92.27357483, 11.53265953], [92.27337646, 11.53234959], [92.27325439, 11.53203297], [92.2730484, 11.53179359], [92.27284241, 11.53156185], [92.2727356, 11.53126526], [92.27256775, 11.53100967], [92.27246094, 11.53071594], [92.27229309, 11.53046989], [92.27218628, 11.53018093], [92.27201843, 11.52992058], [92.27191162, 11.52962685], [92.27173615, 11.52935791], [92.27165222, 11.52905178], [92.27155304, 11.52878094], [92.27142334, 11.52853012], [92.27139282, 11.52821064], [92.27133179, 11.5279007], [92.27115631, 11.52760124], [92.27107239, 11.52722931], [92.27086639, 11.52686024], [92.27083588, 11.52641964], [92.27082825, 11.52596188], [92.27076721, 11.52552032], [92.27059174, 11.52514839], [92.27054596, 11.52475166], [92.27054596, 11.52434063], [92.27055359, 11.52392864], [92.2705307, 11.52353001], [92.27039337, 11.52316093], [92.27016449, 11.5228138], [92.2698288, 11.52250671], [92.26869965, 11.52239037], [92.26772308, 11.5223217], [92.26688385, 11.52211475], [92.26667786, 11.52162933], [92.26646423, 11.52115059], [92.26634216, 11.52051926], [92.26595306, 11.52016068], [92.26544952, 11.52001762], [92.26493835, 11.51998138], [92.26449585, 11.51989746], [92.26412964, 11.51972198], [92.26378632, 11.51947117], [92.26339722, 11.51921272], [92.26279449, 11.51897621], [92.26222229, 11.51839066], [92.26203156, 11.51789093], [92.26145935, 11.51756954], [92.2611084, 11.51750183], [92.26081085, 11.51750183], [92.26040649, 11.51753998], [92.26000214, 11.51775932], [92.25952148, 11.51801014], [92.25911713, 11.51841068], [92.25885773, 11.51890564], [92.25859833, 11.51936054], [92.25831604, 11.51976013], [92.25809479, 11.5201273], [92.25793457, 11.52052402], [92.25775146, 11.52086067], [92.25746918, 11.52115059], [92.25720978, 11.52147198], [92.2569046, 11.52180004], [92.25650787, 11.52211189], [92.25613403, 11.52249527], [92.25575256, 11.52285957], [92.25541687, 11.52318954], [92.25505829, 11.5234108], [92.25479889, 11.52365112], [92.25460815, 11.52388096], [92.25439453, 11.52408409], [92.25409698, 11.52424335], [92.25373077, 11.52445126], [92.25328827, 11.52472019], [92.25271606, 11.52496147], [92.25206757, 11.52516174], [92.25141907, 11.52536011], [92.25081635, 11.52558136], [92.25031281, 11.52579975], [92.24981689, 11.52584076], [92.24937439, 11.52583408], [92.24901581, 11.52590275], [92.24848175, 11.52598], [92.24802399, 11.52604198], [92.24745178, 11.52608013], [92.24680328, 11.52605057], [92.24621582, 11.52595043], [92.24562836, 11.52592087], [92.24501038, 11.52568817], [92.24456787, 11.52537155], [92.24404907, 11.5251503], [92.24358368, 11.52509308], [92.24341583, 11.52513885], [92.24318695, 11.52521038], [92.2427063, 11.52507114], [92.24224091, 11.5251503], [92.24172211, 11.52509117], [92.24127197, 11.52525806], [92.24075317, 11.52537155], [92.24019623, 11.52552891], [92.23958588, 11.52556133], [92.23898315, 11.52556133], [92.23838806, 11.52556133], [92.23783112, 11.5255518], [92.23731232, 11.52548122], [92.23684692, 11.52531242], [92.23636627, 11.52523518], [92.23593903, 11.52505207], [92.23551178, 11.52502537], [92.23512268, 11.5251503], [92.23471069, 11.52525997], [92.23426056, 11.52532101], [92.23383331, 11.52552032], [92.23332977, 11.52558994], [92.23285675, 11.52574062], [92.23239899, 11.5258503], [92.23203278, 11.526021], [92.23162842, 11.52616692], [92.23126984, 11.52638054], [92.23091888, 11.52656555], [92.23057556, 11.52669144], [92.23030853, 11.52690125], [92.22998047, 11.52709007], [92.22960663, 11.5272541], [92.22924805, 11.52749062], [92.22885132, 11.52770138], [92.22838593, 11.5278511], [92.22792816, 11.52802658], [92.22740936, 11.52811146], [92.22696686, 11.52832985], [92.2265625, 11.52858067], [92.22614288, 11.52876091], [92.22576904, 11.52895927], [92.22543335, 11.52915859], [92.22509003, 11.5293417], [92.22466278, 11.52942753], [92.22416687, 11.52948284], [92.22370911, 11.52971554], [92.22323608, 11.52992058], [92.2227478, 11.52999592], [92.222229, 11.53000259], [92.22171783, 11.52996159], [92.22109985, 11.52995872], [92.2207489, 11.52969074], [92.22034454, 11.52943134], [92.2199707, 11.52917099], [92.21961975, 11.52905178], [92.21924591, 11.52896118], [92.21903992, 11.52866268], [92.21897125, 11.52853966], [92.21876526, 11.52813244], [92.21870422, 11.52762127], [92.21891785, 11.52700138], [92.21884918, 11.52652264], [92.21864319, 11.52638054], [92.21821594, 11.52651596], [92.21787262, 11.52672291], [92.217659, 11.52741146], [92.21752167, 11.5279007], [92.21752167, 11.52838039], [92.21787262, 11.52886105], [92.21794128, 11.52920723], [92.21779633, 11.52948093], [92.21763611, 11.52952194], [92.21753693, 11.52948284], [92.21725464, 11.52937603], [92.21703339, 11.52912998], [92.21685028, 11.52883053], [92.21621704, 11.52862167], [92.21550751, 11.52862167], [92.21517181, 11.52890015], [92.21489716, 11.52903557], [92.2145462, 11.52945137], [92.21440887, 11.52986622], [92.21440887, 11.53014183], [92.21460724, 11.53028107], [92.21463013, 11.53036499], [92.21472168, 11.53069973], [92.21517181, 11.53083515], [92.21524048, 11.53097057], [92.21524048, 11.53138828], [92.21475983, 11.53184891], [92.21463776, 11.53217697], [92.2144165, 11.53248024], [92.21414948, 11.53280163], [92.21388245, 11.5331707], [92.21360016, 11.53353977], [92.21331787, 11.53389072], [92.21305084, 11.53424644], [92.21277618, 11.53459072], [92.21257782, 11.53495979], [92.21251678, 11.53543186], [92.21244049, 11.53582096], [92.21238708, 11.53628159], [92.21224213, 11.53678513], [92.21218872, 11.53722095], [92.21212006, 11.53786087], [92.21212006, 11.53848553], [92.21195984, 11.53925133], [92.21174622, 11.53959084], [92.21127319, 11.5400219], [92.21109009, 11.54049969], [92.21100616, 11.54095173], [92.21089935, 11.54143047], [92.21089935, 11.54191971], [92.21096802, 11.5424099], [92.21077728, 11.54287148], [92.21081543, 11.54327011], [92.21061707, 11.54360008], [92.21031952, 11.54380703], [92.21025085, 11.54413319], [92.21007538, 11.54439259], [92.20999146, 11.54472065], [92.20990753, 11.5450201], [92.20987701, 11.54531193], [92.20972443, 11.54563522], [92.20934296, 11.54591274], [92.20903015, 11.54622269], [92.20874786, 11.5465107], [92.20845795, 11.54684067], [92.20826721, 11.54728127], [92.20809937, 11.54775047], [92.20804596, 11.54829121], [92.20804596, 11.54883957], [92.20805359, 11.54940701], [92.20804596, 11.54999065], [92.20804596, 11.55062199], [92.20809174, 11.55123997], [92.20822144, 11.5518322], [92.20820618, 11.55244064], [92.20822906, 11.5530901], [92.20822906, 11.55377197], [92.20822906, 11.55447197], [92.20831299, 11.55515957], [92.20832062, 11.55574989], [92.20849609, 11.55628967], [92.20864105, 11.55677986], [92.20883942, 11.55720425], [92.20909882, 11.55770111], [92.20912933, 11.5582304], [92.20896149, 11.55871105], [92.20896912, 11.55927086], [92.20907593, 11.55979061], [92.20932007, 11.5604496], [92.20963287, 11.56097794], [92.20999146, 11.56124115], [92.21022797, 11.56162071], [92.21087646, 11.56238174], [92.21096802, 11.56289101], [92.21111298, 11.56343842], [92.21138763, 11.5639801], [92.21165466, 11.5645113], [92.21186066, 11.56505966], [92.21198273, 11.56564236], [92.21222687, 11.56612015], [92.21248627, 11.56656933], [92.21272278, 11.5670414], [92.21286011, 11.56756973], [92.2130661, 11.5680666], [92.21334076, 11.56851101], [92.21353912, 11.56893921], [92.21367645, 11.56934071], [92.21387482, 11.56961632], [92.21403503, 11.56986332], [92.21417236, 11.57008076], [92.21431732, 11.57029057], [92.21443939, 11.57050991], [92.21453094, 11.57078075], [92.21468353, 11.57106781], [92.21472168, 11.57147217], [92.21472168, 11.57194996], [92.2147522, 11.57246971], [92.21489716, 11.5729599], [92.21498871, 11.57345009], [92.21495819, 11.57389736], [92.2147522, 11.57429123], [92.21460724, 11.57469177], [92.21444702, 11.57505035], [92.21431732, 11.57538891], [92.2141571, 11.57568073]]], [[[93.08297729, 11.77968025], [93.08244324, 11.7792902], [93.08181763, 11.77908039], [93.08145905, 11.77915955], [93.08120728, 11.77917576], [93.08090973, 11.77924919], [93.08060455, 11.77940941], [93.08024597, 11.77944279], [93.07984161, 11.77944279], [93.079422, 11.77944469], [93.07898712, 11.77947044], [93.07861328, 11.77969074], [93.07817078, 11.77983856], [93.07787323, 11.7801609], [93.07757568, 11.78053665], [93.07757568, 11.78100395], [93.07776642, 11.78143501], [93.07792664, 11.7818222], [93.07805634, 11.78221035], [93.07817841, 11.78261471], [93.07832336, 11.7830143], [93.07845306, 11.78343105], [93.07862854, 11.78379631], [93.07879639, 11.78416061], [93.07865143, 11.78462124], [93.07865143, 11.7850399], [93.07884979, 11.78537083], [93.07904816, 11.78573132], [93.079216, 11.78614807], [93.07945251, 11.78653336], [93.07971954, 11.78687954], [93.07997894, 11.78723145], [93.08014679, 11.78765202], [93.08036041, 11.78800488], [93.0806427, 11.7882843], [93.08099365, 11.78849316], [93.08133698, 11.78869057], [93.08166504, 11.78892899], [93.0819931, 11.78917027], [93.08233643, 11.78943729], [93.0827713, 11.78966713], [93.08336639, 11.78972244], [93.08407593, 11.78973103], [93.08479309, 11.78968143], [93.0854187, 11.78942108], [93.08589935, 11.78906059], [93.08615875, 11.78859997], [93.08642578, 11.78822041], [93.08641052, 11.78777122], [93.08639526, 11.78731728], [93.08638763, 11.78686142], [93.08638763, 11.78640079], [93.08634949, 11.78596306], [93.08617401, 11.78559875], [93.08603668, 11.78524113], [93.0858078, 11.78497028], [93.08555603, 11.78470993], [93.08529663, 11.78442001], [93.08506012, 11.78407192], [93.08487701, 11.7836113], [93.08466339, 11.78310966], [93.08434296, 11.78267002], [93.08405304, 11.78228855], [93.08374786, 11.78205013], [93.08359528, 11.78176308], [93.08347321, 11.78147793], [93.08355713, 11.78114128], [93.08356476, 11.78071022], [93.08335114, 11.78022003], [93.08297729, 11.77968025]]], [[[93.02083588, 11.84333134], [93.02111053, 11.84305573], [93.02166748, 11.84305954], [93.02249908, 11.84221935], [93.02278137, 11.84222221], [93.02305603, 11.84194565], [93.02388763, 11.84195042], [93.02416992, 11.84167004], [93.02610779, 11.84167004], [93.02639008, 11.84138966], [93.0266571, 11.84138966], [93.02694702, 11.84110928], [93.02722168, 11.84111214], [93.02749634, 11.84083366], [93.02777863, 11.84083366], [93.02833557, 11.84027672], [93.02865601, 11.84007931], [93.02886963, 11.83971214], [93.02909851, 11.83943367], [93.0294342, 11.83924294], [93.02993774, 11.83922005], [93.03038025, 11.8390398], [93.03056335, 11.83861065], [93.03055573, 11.83833313], [93.03111267, 11.83777714], [93.03138733, 11.83778191], [93.03250122, 11.83667183], [93.03305817, 11.83666706], [93.03333282, 11.83694458], [93.03360748, 11.83694458], [93.03416443, 11.83638859], [93.03444672, 11.8363924], [93.03472137, 11.83611107], [93.03555298, 11.83611107], [93.03610992, 11.83667183], [93.03666687, 11.83667183], [93.03694153, 11.8363924], [93.03749847, 11.8363924], [93.03778076, 11.83666706], [93.03800201, 11.83682919], [93.03845215, 11.83718014], [93.03896332, 11.83747196], [93.03955078, 11.83761501], [93.04016113, 11.83779144], [93.04071045, 11.83806705], [93.0411911, 11.83841991], [93.04162598, 11.83884239], [93.04209137, 11.83921528], [93.04247284, 11.83960533], [93.04276276, 11.83997154], [93.04304504, 11.84026432], [93.04332733, 11.84055138], [93.04363251, 11.84093189], [93.04403687, 11.8413868], [93.04453278, 11.84185886], [93.04509735, 11.84220123], [93.04566956, 11.84243584], [93.04628754, 11.84256554], [93.04688263, 11.84274101], [93.04749298, 11.84278202], [93.04812622, 11.84277821], [93.04873657, 11.84281635], [93.04929352, 11.84301472], [93.04989624, 11.84309006], [93.0504303, 11.84331799], [93.0510025, 11.8434906], [93.05161285, 11.84363174], [93.05216217, 11.84382057], [93.0526886, 11.84396076], [93.05311584, 11.84412003], [93.05347443, 11.84416103], [93.05355835, 11.84416962], [93.05397034, 11.84416962], [93.05435944, 11.84416962], [93.05475616, 11.84416962], [93.05516815, 11.84414959], [93.05555725, 11.84403133], [93.05594635, 11.84391022], [93.05635071, 11.84389019], [93.05674744, 11.84389019], [93.05712128, 11.84389019], [93.05745697, 11.84392166], [93.05770874, 11.84409046], [93.05802917, 11.84415913], [93.05835724, 11.84419346], [93.05863953, 11.84433174], [93.05893707, 11.8444643], [93.05918884, 11.8446722], [93.05947113, 11.84488964], [93.05974579, 11.84508896], [93.06011963, 11.84514809], [93.06072235, 11.84475136], [93.061203, 11.84434605], [93.06162262, 11.8441906], [93.06203461, 11.84423161], [93.06257629, 11.84447098], [93.06331635, 11.84475994], [93.063797, 11.84465122], [93.06395721, 11.84423161], [93.06417847, 11.84379005], [93.06445313, 11.84339142], [93.06471252, 11.84306526], [93.06498718, 11.8427906], [93.06531525, 11.84257507], [93.06568146, 11.84241104], [93.06606293, 11.8422718], [93.06639099, 11.84222221], [93.06667328, 11.84221935], [93.06694794, 11.84249973], [93.0672226, 11.84249973], [93.06777954, 11.84195042], [93.06806183, 11.84195042], [93.06806183, 11.84167004], [93.06835175, 11.84167004], [93.06944275, 11.84278202], [93.06977844, 11.84244537], [93.06999969, 11.84222221], [93.06999969, 11.84194565], [93.07026672, 11.84167004], [93.07026672, 11.84138966], [93.07055664, 11.84110928], [93.07055664, 11.84083366], [93.0708313, 11.84055519], [93.0708313, 11.84027958], [93.07112122, 11.8399992], [93.07111359, 11.83972359], [93.07142639, 11.83939266], [93.07168579, 11.83892822], [93.07187653, 11.83857346], [93.07199097, 11.83849335], [93.07221985, 11.83833313], [93.07221985, 11.83749866], [93.07195282, 11.83722115], [93.07194519, 11.83638859], [93.07221985, 11.83611107], [93.07221985, 11.83556175], [93.07195282, 11.83527946], [93.07195282, 11.83500099], [93.0716629, 11.83472061], [93.07168579, 11.83444691], [93.0716095, 11.83400059], [93.07141113, 11.83354855], [93.07115936, 11.83307076], [93.07089996, 11.83257198], [93.0705719, 11.83218193], [93.07026672, 11.83185101], [93.06997681, 11.83156013], [93.06971741, 11.83127499], [93.06945038, 11.83096027], [93.06920624, 11.83057976], [93.06903076, 11.83013058], [93.06885529, 11.82963753], [93.06861115, 11.82915115], [93.06835175, 11.82866096], [93.06803894, 11.82824135], [93.06772614, 11.82790184], [93.06745911, 11.82760143], [93.06720734, 11.82729053], [93.06693268, 11.826931], [93.0666275, 11.82653046], [93.06627655, 11.82616043], [93.06594086, 11.82584095], [93.06563568, 11.8255558], [93.0654068, 11.82526016], [93.06522369, 11.82495022], [93.06495667, 11.82469273], [93.06463623, 11.82446003], [93.06433105, 11.82421017], [93.0640564, 11.82393074], [93.06381989, 11.82364178], [93.06360626, 11.82335854], [93.06340027, 11.82311058], [93.06317139, 11.82289696], [93.06297302, 11.82269192], [93.0627594, 11.82242012], [93.0625, 11.82210064], [93.06227875, 11.82171154], [93.0622406, 11.82120132], [93.06233978, 11.82069969], [93.06254578, 11.82030964], [93.06282043, 11.81999969], [93.06304932, 11.81966019], [93.0632019, 11.8192358], [93.06308746, 11.81871891], [93.06277466, 11.81824303], [93.06243896, 11.81781006], [93.06212616, 11.81742001], [93.0617981, 11.81707096], [93.06141663, 11.8166914], [93.06099701, 11.81628513], [93.06053162, 11.81588364], [93.06005859, 11.81560135], [93.05967712, 11.81539154], [93.05937958, 11.81527138], [93.05912781, 11.81514072], [93.05918121, 11.81499958], [93.0588913, 11.81499958], [93.05860901, 11.8147192], [93.05833435, 11.81472111], [93.05805206, 11.81444263], [93.05750275, 11.81444263], [93.05722046, 11.81416798], [93.0569458, 11.81417179], [93.05665588, 11.81389046], [93.05638885, 11.81389046], [93.05612183, 11.81361198], [93.05555725, 11.81361198], [93.05526733, 11.81333065], [93.05500031, 11.81333256], [93.05472565, 11.81305504], [93.05444336, 11.81305981], [93.0541687, 11.81278038], [93.05304718, 11.81278038], [93.05278015, 11.81250191], [93.05166626, 11.81250191], [93.0513916, 11.81222057], [93.04998779, 11.81222057], [93.04972076, 11.81250191], [93.04944611, 11.81250191], [93.04915619, 11.81278038], [93.04860687, 11.81278038], [93.04833221, 11.81305981], [93.04805756, 11.81305504], [93.04777527, 11.81333256], [93.04722595, 11.81333256], [93.04695129, 11.81361198], [93.04638672, 11.81361198], [93.04611206, 11.81389046], [93.04533386, 11.81416321], [93.0446701, 11.81446171], [93.04404449, 11.81477642], [93.04350281, 11.81512928], [93.04306793, 11.81550121], [93.04268646, 11.81583786], [93.0423584, 11.81613922], [93.04208374, 11.81642628], [93.04182434, 11.81666565], [93.04152679, 11.81683159], [93.04138947, 11.81666565], [93.04111481, 11.81694412], [93.04055786, 11.81694412], [93.04027557, 11.81722164], [93.04000092, 11.81722164], [93.03971863, 11.81750202], [93.03943634, 11.81750202], [93.03888702, 11.81807041], [93.03861237, 11.81805611], [93.03805542, 11.8186121], [93.03778076, 11.81861019], [93.03749847, 11.81888962], [93.03666687, 11.81888962], [93.03639221, 11.81917], [93.03610992, 11.81916809], [93.03610992, 11.81972218], [93.03588867, 11.81994534], [93.03555298, 11.82028008], [93.03527832, 11.81999969], [93.0341568, 11.82111168], [93.03388977, 11.82111168], [93.03333282, 11.82167053], [93.03277588, 11.82166576], [93.03250122, 11.82194424], [93.03221893, 11.82220173], [93.03185272, 11.82249069], [93.03148651, 11.82273006], [93.03119659, 11.82299042], [93.03090668, 11.82334137], [93.03059387, 11.82381058], [93.03037262, 11.82439232], [93.03025055, 11.82486057], [93.03025055, 11.82525063], [93.03037262, 11.8256197], [93.03050995, 11.82597065], [93.03047943, 11.82639122], [93.03022003, 11.82635021], [93.02987671, 11.82621098], [93.02957153, 11.82616329], [93.02926636, 11.82621098], [93.02896881, 11.82626057], [93.02867889, 11.82621098], [93.02839661, 11.82611942], [93.0280838, 11.82607174], [93.02771759, 11.82619476], [93.02722168, 11.8255558], [93.0266571, 11.82611275], [93.02639008, 11.82611275], [93.02610779, 11.82639122], [93.02581787, 11.82639122], [93.02555847, 11.82667065], [93.02527618, 11.82666588], [93.02500153, 11.82694435], [93.02443695, 11.82693958], [93.02388763, 11.8275013], [93.02361298, 11.8275013], [93.02249908, 11.82861137], [93.02166748, 11.82861137], [93.02139282, 11.8288908], [93.02111053, 11.82888889], [93.02027893, 11.82972336], [93.02002716, 11.82973194], [93.0196991, 11.82974339], [93.01927948, 11.82984066], [93.01881409, 11.83014011], [93.01834869, 11.83045197], [93.01782227, 11.83068943], [93.01733398, 11.83074379], [93.01700592, 11.83049965], [93.01687622, 11.83008099], [93.01674652, 11.82977962], [93.0165863, 11.82954025], [93.01694489, 11.82916737], [93.01638794, 11.82861137], [93.01611328, 11.82861137], [93.01583099, 11.82833004], [93.01499939, 11.82917118], [93.01499939, 11.83001041], [93.01444244, 11.83055687], [93.01428223, 11.83094025], [93.01412201, 11.83139992], [93.01391602, 11.83185101], [93.01384735, 11.83225918], [93.01374817, 11.83263969], [93.0138092, 11.83294964], [93.01390076, 11.8332386], [93.0139389, 11.83350372], [93.01396179, 11.83378601], [93.01396942, 11.83415127], [93.01397705, 11.83461189], [93.01407623, 11.8350811], [93.01407623, 11.83549118], [93.01394653, 11.83580971], [93.01374817, 11.83606052], [93.01348877, 11.83629131], [93.01332092, 11.83660793], [93.01305389, 11.83694458], [93.01277924, 11.83722115], [93.01277924, 11.83750057], [93.01222229, 11.83805466], [93.01249695, 11.83833122], [93.01222229, 11.83861065], [93.01222229, 11.83887959], [93.01249695, 11.83916664], [93.01257324, 11.83974171], [93.01273346, 11.84023571], [93.01277161, 11.84067154], [93.01271057, 11.84107685], [93.01242828, 11.84147167], [93.0120163, 11.84189129], [93.01202393, 11.84227943], [93.01217651, 11.8426609], [93.01222229, 11.84305954], [93.01222992, 11.84344101], [93.01228333, 11.84383106], [93.01238251, 11.84423161], [93.0124588, 11.84463692], [93.01249695, 11.84504128], [93.01249695, 11.84543133], [93.01249695, 11.84582043], [93.01249695, 11.84620094], [93.01248932, 11.84656143], [93.01245117, 11.84689808], [93.01235962, 11.84720135], [93.01222229, 11.84748554], [93.01209259, 11.84777355], [93.01196289, 11.84808064], [93.01197052, 11.84849072], [93.0123291, 11.84902], [93.01282501, 11.84929562], [93.01320648, 11.8495512], [93.01346588, 11.84965229], [93.01380157, 11.84952164], [93.01416779, 11.84926033], [93.01454926, 11.8489399], [93.01490021, 11.84860992], [93.01519775, 11.84832287], [93.01542664, 11.84804916], [93.01564789, 11.8477602], [93.0158844, 11.84747028], [93.01612854, 11.8471241], [93.01639557, 11.84679317], [93.01667023, 11.84649277], [93.01692963, 11.84619904], [93.01719666, 11.84587955], [93.01751709, 11.84553146], [93.01789093, 11.845191], [93.01834869, 11.84490204], [93.01882935, 11.84464169], [93.01925659, 11.84437084], [93.0196991, 11.84412003], [93.0200882, 11.84381866], [93.02050018, 11.84354115], [93.02083588, 11.84333134]]], [[[92.56565857, 11.94977188], [92.56610107, 11.94956017], [92.56659698, 11.94960117], [92.5671463, 11.95002174], [92.56764984, 11.95027542], [92.56783295, 11.95017147], [92.56795502, 11.95010185], [92.56809998, 11.94967079], [92.56830597, 11.94929123], [92.56845856, 11.94890118], [92.5686264, 11.94851971], [92.56874847, 11.94820118], [92.56887054, 11.94784641], [92.56920624, 11.94743061], [92.56947327, 11.94694138], [92.56961823, 11.94647789], [92.56970978, 11.94599056], [92.56967926, 11.94546223], [92.56944275, 11.94491005], [92.56945038, 11.94451141], [92.56930542, 11.94430637], [92.56909943, 11.94403076], [92.56861115, 11.94367981], [92.56832886, 11.94368362], [92.56790924, 11.94382095], [92.56763458, 11.94396019], [92.56736755, 11.94469357], [92.5670929, 11.94486046], [92.56682587, 11.94510174], [92.56630707, 11.94524956], [92.56589508, 11.94531822], [92.56568909, 11.94559193], [92.56548309, 11.94594002], [92.5652771, 11.94645977], [92.56491852, 11.94673824], [92.56445313, 11.9469614], [92.5641098, 11.94714165], [92.56382751, 11.94692039], [92.56347656, 11.94686604], [92.56313324, 11.94692039], [92.56291962, 11.94734669], [92.56305695, 11.94776058], [92.56326294, 11.94808102], [92.56330872, 11.94822216], [92.56347656, 11.94872093], [92.56376648, 11.94919968], [92.56406403, 11.94968319], [92.56443787, 11.95008373], [92.56482697, 11.9504137], [92.56508636, 11.95017719], [92.56565857, 11.94977188]]], [[[92.6995697, 11.66445065], [92.69993591, 11.66423702], [92.70030975, 11.66401958], [92.70070648, 11.66384506], [92.70102692, 11.66359043], [92.70127869, 11.66326237], [92.70133972, 11.66286469], [92.70115662, 11.66240025], [92.70098877, 11.66191864], [92.70085907, 11.66141129], [92.70083618, 11.66087532], [92.70079041, 11.6603117], [92.70075226, 11.65943718], [92.70040131, 11.65937996], [92.70007324, 11.65932083], [92.69959259, 11.65934086], [92.69914246, 11.6596489], [92.69847107, 11.65961933], [92.69802856, 11.65944195], [92.69753265, 11.65944386], [92.697052, 11.65944195], [92.69654846, 11.65947819], [92.69600677, 11.65963078], [92.69538879, 11.65971088], [92.69470978, 11.65976524], [92.69407654, 11.65999985], [92.69352722, 11.66030788], [92.69283295, 11.66070175], [92.69264984, 11.66114044], [92.69278717, 11.66169071], [92.69309235, 11.66190147], [92.69332123, 11.66207027], [92.69381714, 11.66228771], [92.69416046, 11.66261196], [92.69433594, 11.66298103], [92.69470978, 11.66318417], [92.69510651, 11.66342068], [92.69557953, 11.66368103], [92.69610596, 11.66390038], [92.69661713, 11.66412067], [92.69709778, 11.66431046], [92.69756317, 11.66440964], [92.69811249, 11.66427135], [92.69863892, 11.66432095], [92.6991806, 11.6645813], [92.6995697, 11.66445065]]], [[[92.76225281, 11.66969967], [92.76177979, 11.66955185], [92.76104736, 11.66983891], [92.76112366, 11.6705389], [92.7611084, 11.67116642], [92.76111603, 11.67179012], [92.76107788, 11.67242146], [92.76100159, 11.6730299], [92.76094055, 11.67360878], [92.76094055, 11.67412186], [92.76084137, 11.67454815], [92.76072693, 11.67505074], [92.76039886, 11.67525673], [92.76019287, 11.67562103], [92.75985718, 11.67606068], [92.7598114, 11.6766901], [92.76003265, 11.67726231], [92.76043701, 11.67765427], [92.76101685, 11.67777061], [92.76165009, 11.67784595], [92.76226807, 11.6780386], [92.76290131, 11.67824173], [92.76342773, 11.67851067], [92.76383972, 11.67892075], [92.76413727, 11.67942142], [92.76438141, 11.67989922], [92.76467133, 11.68023872], [92.76488495, 11.6805439], [92.7651062, 11.68079853], [92.76539612, 11.68095016], [92.76593018, 11.68083096], [92.76615143, 11.68071079], [92.76639557, 11.68059731], [92.76673889, 11.68033886], [92.766922, 11.67976856], [92.76673126, 11.6790514], [92.76660919, 11.67838955], [92.76638031, 11.67789078], [92.76612854, 11.67751789], [92.76589203, 11.67720985], [92.76570129, 11.67693901], [92.76552582, 11.67667198], [92.76534271, 11.67642117], [92.76517487, 11.67616367], [92.7649765, 11.67592239], [92.76478577, 11.67566681], [92.76467896, 11.67535019], [92.76451874, 11.67503071], [92.76441193, 11.67463017], [92.7642746, 11.67424679], [92.76418304, 11.67383003], [92.76412964, 11.67341137], [92.76400757, 11.67306042], [92.76386261, 11.6727314], [92.76368713, 11.67242146], [92.76355743, 11.67208195], [92.76343536, 11.67174721], [92.76322174, 11.67134953], [92.76316833, 11.67090321], [92.76305389, 11.67041588], [92.76303101, 11.67013836], [92.76249695, 11.66976166], [92.76225281, 11.66969967]]], [[[92.72498322, 11.68912125], [92.72546387, 11.6887722], [92.7258606, 11.6888113], [92.72615051, 11.68848038], [92.72647858, 11.68822002], [92.72666168, 11.68793106], [92.7266922, 11.6876297], [92.72618103, 11.68726063], [92.72567749, 11.68695831], [92.72519684, 11.68670177], [92.72464752, 11.68657017], [92.7243576, 11.68665695], [92.72403717, 11.68675041], [92.72359467, 11.68688869], [92.72298431, 11.68699169], [92.72229004, 11.68723106], [92.72175598, 11.68772125], [92.72168732, 11.68834114], [92.72193146, 11.68884659], [92.72233582, 11.68922138], [92.72276306, 11.68962193], [92.72335815, 11.68953133], [92.72394562, 11.68927956], [92.72453308, 11.68920517], [92.72498322, 11.68912125]]], [[[92.55091858, 11.72124004], [92.55069733, 11.72124004], [92.55036163, 11.72143936], [92.55001068, 11.72185135], [92.55001068, 11.72198963], [92.54987335, 11.7222662], [92.54965973, 11.72261047], [92.54944611, 11.72350979], [92.54945374, 11.72426701], [92.54994202, 11.72474957], [92.55064392, 11.72495842], [92.55140686, 11.72530365], [92.55154419, 11.72513294], [92.55168915, 11.72495842], [92.55148315, 11.72441101], [92.55091858, 11.72412968], [92.55056763, 11.72365189], [92.55069733, 11.72323036], [92.55084991, 11.72254181], [92.55098724, 11.72206116], [92.5511322, 11.72178078], [92.55120087, 11.72136974], [92.55091858, 11.72124004]]], [[[92.59694672, 11.90528965], [92.59638977, 11.90528965], [92.59638977, 11.90556145], [92.59583282, 11.90611267], [92.59610748, 11.90639114], [92.59610748, 11.90889072], [92.59583282, 11.9091711], [92.59583282, 11.9100008], [92.59555817, 11.91027737], [92.59555817, 11.91109943], [92.59527588, 11.91139126], [92.59555817, 11.91167068], [92.59555817, 11.91500092], [92.59583282, 11.91527939], [92.59583282, 11.915555], [92.59610748, 11.91583061], [92.59610748, 11.91639137], [92.59666443, 11.91666698], [92.59694672, 11.91694069], [92.59694672, 11.91750145], [92.59999847, 11.91777706], [92.60056305, 11.91833115], [92.60056305, 11.91889191], [92.60111237, 11.91889191], [92.60167694, 11.91861057], [92.60221863, 11.91805458], [92.60221863, 11.91666985], [92.60167694, 11.91611099], [92.60166931, 11.91444492], [92.60138702, 11.9141674], [92.60138702, 11.91388893], [92.60083008, 11.91333103], [92.60028076, 11.91305542], [92.60028076, 11.91250134], [92.59999847, 11.91222095], [92.59999847, 11.91166687], [92.59889221, 11.91056061], [92.59944153, 11.91028118], [92.59999847, 11.90972042], [92.59999847, 11.90916729], [92.59971619, 11.90889072], [92.59971619, 11.90832996], [92.59944153, 11.90805435], [92.59944153, 11.90778065], [92.59916687, 11.90750122], [92.59916687, 11.90694046], [92.59889221, 11.9066658], [92.59889221, 11.90639114], [92.59749603, 11.90611267], [92.59694672, 11.90556145], [92.59694672, 11.90528965]]], [[[92.75013733, 11.96833992], [92.75048828, 11.96799088], [92.7507019, 11.96799088], [92.75196075, 11.96784973], [92.75349426, 11.96771336], [92.75405121, 11.96778107], [92.7543335, 11.96771336], [92.75475311, 11.96743679], [92.75537872, 11.96715927], [92.75614929, 11.96709347], [92.75635529, 11.96709347], [92.7567749, 11.96702194], [92.75718689, 11.96689034], [92.75810242, 11.9667511], [92.75978088, 11.9667511], [92.76082611, 11.96681499], [92.76159668, 11.96695423], [92.7620163, 11.96695423], [92.76250458, 11.96688557], [92.76304626, 11.96678066], [92.76308441, 11.96625233], [92.76350403, 11.96562958], [92.76357269, 11.96541119], [92.76399231, 11.96514702], [92.76434326, 11.96508121], [92.76539612, 11.96523952], [92.76560211, 11.96506023], [92.76577759, 11.9648304], [92.76586914, 11.96449947], [92.76608276, 11.96412086], [92.76583099, 11.96368122], [92.76583099, 11.96317959], [92.76563263, 11.96269035], [92.76566315, 11.96221066], [92.76570129, 11.96177101], [92.76576233, 11.96127701], [92.76579285, 11.96082973], [92.76599121, 11.96046066], [92.76644897, 11.95996189], [92.76657867, 11.95950413], [92.76663208, 11.95901394], [92.76664734, 11.9585104], [92.76670074, 11.95798111], [92.76670837, 11.95748711], [92.76696014, 11.95695972], [92.76719666, 11.95644283], [92.76713562, 11.95588398], [92.76696777, 11.955369], [92.766716, 11.95483971], [92.76663208, 11.95423889], [92.7664032, 11.95367146], [92.76613617, 11.95309925], [92.76579285, 11.95259953], [92.76537323, 11.95223999], [92.7649231, 11.95194054], [92.76448059, 11.9516201], [92.76406097, 11.95128727], [92.7636261, 11.95095921], [92.763237, 11.9505806], [92.7628479, 11.95020008], [92.76255035, 11.94974041], [92.76217651, 11.94934082], [92.76169586, 11.94904041], [92.76124573, 11.94876194], [92.76075745, 11.94854069], [92.76022339, 11.94835854], [92.75965118, 11.94820118], [92.75936127, 11.9483242], [92.75887299, 11.94832039], [92.7585907, 11.94860172], [92.75817871, 11.94887638], [92.7576828, 11.94908333], [92.75733948, 11.9491539], [92.75663757, 11.94922161], [92.75636292, 11.94908333], [92.7559433, 11.94880772], [92.75566101, 11.94826126], [92.75518036, 11.94762039], [92.75462341, 11.94746304], [92.75408173, 11.9472208], [92.75354767, 11.94694805], [92.75300598, 11.94666958], [92.75250244, 11.9463892], [92.75200653, 11.94611073], [92.7515564, 11.94604111], [92.75114441, 11.9459877], [92.75065613, 11.9458704], [92.75022888, 11.94577026], [92.74984741, 11.94561005], [92.74939728, 11.94553471], [92.74891663, 11.94547462], [92.74849701, 11.94532108], [92.7480011, 11.94521141], [92.74740601, 11.94504929], [92.74662018, 11.94493961], [92.74626923, 11.94476223], [92.74575806, 11.94479179], [92.74514771, 11.94504738], [92.74466705, 11.94546223], [92.74417114, 11.94584465], [92.74372864, 11.94626045], [92.74331665, 11.94666481], [92.74294281, 11.9470892], [92.74273682, 11.94764137], [92.74249268, 11.94810963], [92.74228668, 11.94847012], [92.74230194, 11.94876194], [92.74191284, 11.94960976], [92.7413559, 11.95030022], [92.74099731, 11.95084953], [92.74065399, 11.95112514], [92.74002838, 11.95133114], [92.73918915, 11.951581], [92.73866272, 11.95142174], [92.73813629, 11.95112991], [92.7375412, 11.9509201], [92.73686218, 11.95098019], [92.73641968, 11.95133972], [92.73616028, 11.95184326], [92.73610687, 11.95247936], [92.73615265, 11.95319939], [92.73636627, 11.95393085], [92.73661041, 11.95463753], [92.73693085, 11.95524216], [92.73718262, 11.95582008], [92.73729706, 11.95643997], [92.73750305, 11.95695972], [92.73771667, 11.95745945], [92.73786163, 11.95799923], [92.73806763, 11.95854187], [92.73832703, 11.95907116], [92.73860931, 11.95961761], [92.73887634, 11.96015072], [92.739151, 11.96063614], [92.7394104, 11.96105957], [92.73970032, 11.96138763], [92.73999786, 11.96168232], [92.74074554, 11.96172333], [92.74088287, 11.96158695], [92.74101257, 11.96152115], [92.74157715, 11.96166039], [92.74208832, 11.96233654], [92.74254608, 11.96249199], [92.74311829, 11.96267223], [92.74378967, 11.96278954], [92.74446869, 11.96294975], [92.74489594, 11.96278572], [92.74504089, 11.96273136], [92.74526215, 11.96226406], [92.74594116, 11.96182632], [92.746521, 11.9618206], [92.74703979, 11.96210194], [92.7474823, 11.96228218], [92.74788666, 11.96247101], [92.74839783, 11.96289921], [92.74888611, 11.9631319], [92.74925995, 11.96343136], [92.74959564, 11.96373081], [92.74974823, 11.96410275], [92.74975586, 11.96444035], [92.74973297, 11.9648304], [92.74971771, 11.96522045], [92.74964905, 11.96560478], [92.7494812, 11.96598339], [92.74931335, 11.96646023], [92.74922943, 11.96697044], [92.74948883, 11.9675436], [92.74957275, 11.96790028], [92.74980164, 11.96833992], [92.75013733, 11.96833992]]], [[[92.73243713, 11.95422268], [92.73219299, 11.95390129], [92.73188019, 11.95355034], [92.73152161, 11.95319939], [92.73114014, 11.9528904], [92.73082733, 11.95256996], [92.73055267, 11.95228958], [92.73033142, 11.95199203], [92.73026276, 11.95152855], [92.73015594, 11.95099068], [92.72997284, 11.95043278], [92.72972107, 11.94992733], [92.72949219, 11.94946194], [92.72944641, 11.94893074], [92.72943878, 11.94839954], [92.72946167, 11.94787788], [92.72956848, 11.94738102], [92.72975159, 11.94692039], [92.73005676, 11.94651508], [92.73047638, 11.94618034], [92.73092651, 11.94588089], [92.7313385, 11.94568729], [92.7315979, 11.94546032], [92.73174286, 11.94521999], [92.73191071, 11.94500065], [92.73191071, 11.94475079], [92.73175812, 11.94450855], [92.73165894, 11.94421101], [92.73152161, 11.94390965], [92.73127747, 11.94361973], [92.73093414, 11.94335365], [92.73046875, 11.94312096], [92.7298584, 11.94299984], [92.72935486, 11.9427948], [92.72894287, 11.94256973], [92.72852325, 11.94235992], [92.72812653, 11.9420414], [92.72764587, 11.94170094], [92.72702789, 11.94135475], [92.72677612, 11.94114304], [92.72638702, 11.94101524], [92.72593689, 11.94123173], [92.72561646, 11.94164181], [92.72551727, 11.9421711], [92.72538757, 11.94266796], [92.72527313, 11.94310284], [92.7251358, 11.94347], [92.72499847, 11.94381618], [92.72486115, 11.94417191], [92.72470093, 11.94454956], [92.72450256, 11.94493961], [92.72444916, 11.94544983], [92.72440338, 11.94599056], [92.72421265, 11.94650841], [92.72416687, 11.94702053], [92.72419739, 11.94751453], [92.72436523, 11.9479599], [92.72457886, 11.94839096], [92.72470093, 11.94890976], [92.72476959, 11.94949055], [92.72502899, 11.95005035], [92.72538757, 11.9505558], [92.72574615, 11.95103168], [92.72608185, 11.95150185], [92.72639465, 11.95201015], [92.72663116, 11.95259953], [92.72641754, 11.95274067], [92.72621155, 11.95274067], [92.72606659, 11.95247173], [92.72572327, 11.95205116], [92.72556305, 11.95166969], [92.7250061, 11.95166969], [92.72381592, 11.95076084], [92.7233429, 11.95063114], [92.72305298, 11.95111179], [92.72305298, 11.95222187], [92.72319031, 11.95250034], [92.72325897, 11.95291042], [92.72367859, 11.95353889], [92.72416687, 11.95417023], [92.72444153, 11.95416641], [92.72486115, 11.95430279], [92.72589874, 11.95409489], [92.72605896, 11.95465088], [92.7259903, 11.95514774], [92.72624207, 11.95551968], [92.72659302, 11.95584106], [92.72692871, 11.95618057], [92.72723389, 11.95653439], [92.72759247, 11.95686245], [92.72806549, 11.95708275], [92.72857666, 11.95727921], [92.72907257, 11.95751572], [92.72954559, 11.95778275], [92.73000336, 11.95805168], [92.73046112, 11.95829964], [92.73094177, 11.95845127], [92.73139954, 11.95862198], [92.7318573, 11.95879936], [92.73230743, 11.95898247], [92.73272705, 11.95918179], [92.73311615, 11.9593811], [92.7335434, 11.95919991], [92.73383331, 11.95862198], [92.73388672, 11.95791721], [92.73383331, 11.95720196], [92.73361206, 11.95657921], [92.73335266, 11.95603943], [92.73313141, 11.95557022], [92.73294067, 11.95517063], [92.73277283, 11.95483971], [92.73259735, 11.95454025], [92.73243713, 11.95422268]]], [[[92.59610748, 11.97610855], [92.59722137, 11.97499943], [92.59722137, 11.97444057], [92.59693909, 11.97416782], [92.59749603, 11.97388935], [92.59887695, 11.97249889], [92.59887695, 11.97194099], [92.59999847, 11.97166729], [92.60083008, 11.97138023], [92.60083008, 11.96861076], [92.60138702, 11.96833324], [92.60166168, 11.96805859], [92.60221863, 11.96778107], [92.6027832, 11.96722126], [92.60277557, 11.96694469], [92.60305023, 11.96666718], [92.60305023, 11.96639061], [92.60333252, 11.96611118], [92.60333252, 11.96583271], [92.60360718, 11.96555519], [92.60360718, 11.96500111], [92.60333252, 11.96472073], [92.60333252, 11.96444511], [92.60305023, 11.96416664], [92.60305023, 11.96389103], [92.60250092, 11.96333027], [92.60305023, 11.96277905], [92.60305023, 11.96250057], [92.60360718, 11.96193981], [92.60360718, 11.96166611], [92.60305023, 11.96111012], [92.60388947, 11.96028137], [92.60388947, 11.9591713], [92.60472107, 11.95833015], [92.60472107, 11.95611], [92.60500336, 11.95582962], [92.60499573, 11.95555592], [92.60527802, 11.9552803], [92.60527802, 11.95444202], [92.60499573, 11.95416641], [92.60582733, 11.95334053], [92.60582733, 11.95194054], [92.60694122, 11.95139027], [92.60721588, 11.95111179], [92.60721588, 11.94944096], [92.60666656, 11.94888973], [92.60694122, 11.94860935], [92.60694122, 11.94833374], [92.60722351, 11.94805527], [92.60721588, 11.94556046], [92.60666656, 11.94500065], [92.60721588, 11.94472122], [92.60805511, 11.94388866], [92.60861206, 11.94361115], [92.60944366, 11.94277668], [92.60943604, 11.94055939], [92.60888672, 11.94000053], [92.60777283, 11.93943977], [92.60777283, 11.93861103], [92.60749817, 11.9383297], [92.60749817, 11.93777657], [92.60637665, 11.93667126], [92.60527802, 11.93639088], [92.60325623, 11.9363203], [92.60360718, 11.93583012], [92.60305023, 11.93555355], [92.60305023, 11.93500137], [92.60221863, 11.93472004], [92.60221863, 11.93444443], [92.60166168, 11.93388844], [92.60166168, 11.93111038], [92.59999847, 11.92944431], [92.59999847, 11.92889023], [92.59944153, 11.92833042], [92.59888458, 11.92805576], [92.59887695, 11.92778015], [92.59860992, 11.92777824], [92.59860992, 11.92833424], [92.5983429, 11.92860985], [92.59833527, 11.92889023], [92.59777832, 11.92943954], [92.5966568, 11.93000031], [92.59666443, 11.9305563], [92.59638977, 11.93083191], [92.59693909, 11.93111229], [92.59693909, 11.93194199], [92.5966568, 11.93223095], [92.59722137, 11.93249989], [92.59638977, 11.93332958], [92.5966568, 11.93360996], [92.5966568, 11.9338913], [92.59693909, 11.93417072], [92.59693909, 11.93500137], [92.5966568, 11.93527031], [92.59666443, 11.93555355], [92.59638977, 11.93583202], [92.59638977, 11.93721962], [92.59583282, 11.93778133], [92.59610748, 11.93805695], [92.59749603, 11.9383297], [92.59749603, 11.94138908], [92.59638977, 11.94194126], [92.59638977, 11.94277668], [92.59693909, 11.94333076], [92.59693909, 11.94528198], [92.59666443, 11.94555473], [92.5966568, 11.9458313], [92.59610748, 11.9463892], [92.59610748, 11.94999981], [92.59722137, 11.95111179], [92.59722137, 11.95222187], [92.59638977, 11.95305634], [92.59693909, 11.95361042], [92.59693909, 11.95388794], [92.59638977, 11.95444202], [92.59638977, 11.95555592], [92.59610748, 11.95582962], [92.59610748, 11.95666599], [92.59583282, 11.95694447], [92.59610748, 11.95722198], [92.59610748, 11.95750046], [92.59638977, 11.95777798], [92.59638977, 11.96082973], [92.59555054, 11.96166611], [92.59583282, 11.96193981], [92.59583282, 11.96389103], [92.59555817, 11.96417141], [92.59555817, 11.96528053], [92.59527588, 11.96555519], [92.59555817, 11.96582985], [92.59555817, 11.96639061], [92.59527588, 11.96666718], [92.59527588, 11.96694469], [92.59500122, 11.96722126], [92.59500122, 11.96750069], [92.59471893, 11.96778107], [92.59471893, 11.96805859], [92.59388733, 11.96888924], [92.59194183, 11.96916676], [92.59194183, 11.96944141], [92.59166718, 11.96972084], [92.59166718, 11.9702816], [92.59138489, 11.97055531], [92.59138489, 11.9711113], [92.59111023, 11.97138023], [92.58889008, 11.97249889], [92.58916473, 11.97277737], [92.58916473, 11.97444344], [92.58889008, 11.97472095], [92.58889008, 11.97499943], [92.58860779, 11.97527981], [92.58889008, 11.97555637], [92.58889008, 11.97610855], [92.58999634, 11.97639179], [92.59111023, 11.97639179], [92.59111023, 11.97610855], [92.59166718, 11.97610855], [92.59166718, 11.97638988], [92.59222412, 11.97694397], [92.59388733, 11.97722244], [92.59527588, 11.97722244], [92.59583282, 11.97694397], [92.59610748, 11.97666454], [92.59610748, 11.97610855]]], [[[92.74308014, 11.96451092], [92.74277496, 11.96444893], [92.74233246, 11.96454716], [92.74169159, 11.96495342], [92.74173737, 11.96559334], [92.74196625, 11.96613979], [92.74228668, 11.96657085], [92.74272156, 11.96689034], [92.74320984, 11.96720886], [92.74376678, 11.96743965], [92.7443924, 11.96743965], [92.74491882, 11.96712017], [92.745224, 11.96663284], [92.74516296, 11.96605396], [92.74478149, 11.9655304], [92.7443161, 11.96505833], [92.74373627, 11.96473026], [92.74308014, 11.96451092]]], [[[92.58275604, 11.97598171], [92.5823822, 11.97572041], [92.58211517, 11.97594261], [92.58175659, 11.97630119], [92.58145142, 11.97679806], [92.58129883, 11.97742176], [92.58133698, 11.97808075], [92.58139038, 11.97874165], [92.5814743, 11.97938156], [92.58163452, 11.97999287], [92.58172607, 11.98058128], [92.58197784, 11.98105145], [92.5823288, 11.98149014], [92.58279419, 11.98195076], [92.58338165, 11.98239994], [92.58363342, 11.98252106], [92.58396149, 11.98268032], [92.58435059, 11.98248196], [92.58448029, 11.98190975], [92.58467865, 11.9813509], [92.58472443, 11.98077011], [92.5847168, 11.98019123], [92.58472443, 11.97962761], [92.5847168, 11.97908974], [92.5847702, 11.97859097], [92.5849762, 11.97815609], [92.58505249, 11.9777298], [92.5849762, 11.97733593], [92.58473969, 11.97697067], [92.58439636, 11.97663975], [92.58396912, 11.9763813], [92.58342743, 11.97612953], [92.58275604, 11.97598171]]], [[[92.77604675, 12.01770973], [92.77648926, 12.01714993], [92.77684784, 12.01667976], [92.77688599, 12.01621056], [92.77659607, 12.0157299], [92.77631378, 12.01567078], [92.77597046, 12.01533985], [92.77574921, 12.01479053], [92.77545929, 12.01422977], [92.77519989, 12.01382923], [92.77496338, 12.01312923], [92.77472687, 12.01280117], [92.77423859, 12.01266003], [92.77363586, 12.01286983], [92.77310181, 12.01338196], [92.7723999, 12.01337147], [92.77178955, 12.01351929], [92.7714386, 12.01390743], [92.77138519, 12.01436234], [92.77138519, 12.01480007], [92.77134705, 12.01521015], [92.7713623, 12.01575947], [92.77101898, 12.01610756], [92.77091217, 12.01662064], [92.77081299, 12.01734066], [92.77118683, 12.01778984], [92.77197266, 12.01775074], [92.77266693, 12.01746178], [92.77307892, 12.01721096], [92.77346802, 12.01717281], [92.77361298, 12.01721954], [92.77361298, 12.01778126], [92.77388763, 12.01805687], [92.77416992, 12.01826191], [92.77471924, 12.01861095], [92.77490234, 12.01850128], [92.77548981, 12.01832104], [92.77604675, 12.01770973]]], [[[92.96578979, 11.96675968], [92.96565247, 11.96704102], [92.96553802, 11.96732998], [92.96537781, 11.96759033], [92.965271, 11.96790028], [92.96511841, 11.96822071], [92.96491241, 11.96856499], [92.96459961, 11.96890259], [92.9642334, 11.9692812], [92.96391296, 11.96975136], [92.96363068, 11.97025204], [92.96343231, 11.9707489], [92.96330261, 11.97124958], [92.96309662, 11.97169018], [92.9630127, 11.97219563], [92.96282196, 11.97271347], [92.962677, 11.97333145], [92.96253204, 11.9739809], [92.96246338, 11.97461033], [92.96215057, 11.97511959], [92.9620285, 11.97558117], [92.96174622, 11.97589111], [92.96161652, 11.97630978], [92.9614563, 11.97679996], [92.96147156, 11.97721195], [92.96141815, 11.97760391], [92.96124268, 11.97800064], [92.96116638, 11.97836971], [92.96115112, 11.97867584], [92.96077728, 11.97901344], [92.96075439, 11.97933197], [92.96079254, 11.97973061], [92.96057129, 11.98010921], [92.96031189, 11.98051929], [92.95999146, 11.98093891], [92.95960236, 11.98133755], [92.95912933, 11.98166084], [92.95865631, 11.98195076], [92.95820618, 11.9822197], [92.95780182, 11.98244953], [92.95734406, 11.98256588], [92.95690918, 11.98273945], [92.95641327, 11.98282146], [92.95596313, 11.98300076], [92.95545959, 11.9831152], [92.95507813, 11.983325], [92.95468903, 11.98350143], [92.95422363, 11.98359585], [92.95366669, 11.98365116], [92.95307159, 11.98385239], [92.95244598, 11.98397923], [92.95181274, 11.98418045], [92.95121002, 11.98443985], [92.95059204, 11.98465157], [92.9499054, 11.98473835], [92.94921875, 11.98486137], [92.9486084, 11.98506927], [92.9479599, 11.98524189], [92.94724274, 11.98528099], [92.9464798, 11.98528099], [92.9457016, 11.98528099], [92.94493866, 11.98528099], [92.94420624, 11.98528099], [92.94351196, 11.98528099], [92.94286346, 11.98527813], [92.94226074, 11.9853096], [92.94174957, 11.98547173], [92.94130707, 11.98564053], [92.94095612, 11.9858408], [92.94062042, 11.98601913], [92.94025421, 11.98609447], [92.93983459, 11.98604012], [92.93927765, 11.98597145], [92.93878937, 11.98569965], [92.93851471, 11.98545837], [92.93815613, 11.98511887], [92.93769073, 11.98502064], [92.93718719, 11.98499966], [92.9367218, 11.98499966], [92.93623352, 11.98499966], [92.93577576, 11.98506355], [92.93531799, 11.98496246], [92.93454742, 11.98473358], [92.93386841, 11.98499298], [92.93361664, 11.98548985], [92.93340302, 11.9858408], [92.93300629, 11.98617935], [92.93268585, 11.98667145], [92.93232727, 11.98725033], [92.93206024, 11.98790169], [92.93215942, 11.98851013], [92.93209839, 11.98899078], [92.93196106, 11.98936939], [92.93183899, 11.98972511], [92.93170166, 11.99010086], [92.93160248, 11.99058628], [92.93138885, 11.99104691], [92.93112946, 11.99149132], [92.93088531, 11.99190426], [92.93070221, 11.99225044], [92.93054199, 11.99250984], [92.93029785, 11.99271965], [92.93000793, 11.99302101], [92.92937469, 11.99320507], [92.92903137, 11.99350071], [92.92854309, 11.99376583], [92.92807007, 11.9940424], [92.92765045, 11.9943037], [92.92706299, 11.99446964], [92.92640686, 11.99498653], [92.92595673, 11.9954319], [92.92553711, 11.99578953], [92.92542267, 11.99633026], [92.92512512, 11.99688816], [92.92502594, 11.99771118], [92.92545319, 11.99812126], [92.92617798, 11.99838066], [92.92656708, 11.99861145], [92.92700195, 11.99878883], [92.92745972, 11.99892998], [92.92788696, 11.99927044], [92.92827606, 11.99972057], [92.92804718, 12.00000191], [92.92851257, 12.00086117], [92.92864227, 12.00119114], [92.92888641, 12.00158978], [92.92912292, 12.00212097], [92.92926025, 12.00272274], [92.92939758, 12.00329018], [92.92948914, 12.00382996], [92.92970276, 12.0042448], [92.92990875, 12.00460052], [92.93019104, 12.0048399], [92.93041992, 12.00508881], [92.93058777, 12.00537109], [92.93084717, 12.00555611], [92.93113708, 12.0057106], [92.93148041, 12.00586128], [92.93183136, 12.0060463], [92.93221283, 12.00610065], [92.93256378, 12.0061264], [92.93300629, 12.00633144], [92.93347931, 12.00636005], [92.93393707, 12.00625992], [92.93438721, 12.00618267], [92.93480682, 12.00621891], [92.93521881, 12.00636673], [92.93564606, 12.00654316], [92.9361496, 12.00649261], [92.93667603, 12.00642872], [92.93720245, 12.00640106], [92.93769073, 12.00640965], [92.93815613, 12.00645828], [92.93863678, 12.00655174], [92.93916321, 12.00665188], [92.93972778, 12.00667858], [92.94033051, 12.0067091], [92.94091797, 12.00674343], [92.94140625, 12.0069437], [92.94187927, 12.00710106], [92.94232178, 12.00726128], [92.94268799, 12.00751591], [92.94303131, 12.00780106], [92.943367, 12.00809002], [92.94377899, 12.00828171], [92.94426727, 12.00838566], [92.94473267, 12.00861168], [92.94516754, 12.00888062], [92.94563293, 12.00911999], [92.94612122, 12.00931168], [92.94658661, 12.0094986], [92.94698334, 12.00974274], [92.94727325, 12.01005268], [92.94757843, 12.01032066], [92.94785309, 12.01060581], [92.94820404, 12.01083374], [92.94857788, 12.01107979], [92.94893646, 12.01138973], [92.94930267, 12.01173019], [92.94960022, 12.01211071], [92.9499588, 12.01246166], [92.95030975, 12.01280117], [92.95065308, 12.0131197], [92.95085907, 12.01350784], [92.9510498, 12.01390743], [92.95121765, 12.01433277], [92.95134735, 12.01488018], [92.95142365, 12.01548767], [92.95165253, 12.01605129], [92.95187378, 12.01659966], [92.9520874, 12.0170927], [92.95230103, 12.01754189], [92.95256042, 12.01790047], [92.95278931, 12.01824093], [92.95298767, 12.01861095], [92.95314026, 12.01903915], [92.95333099, 12.01946068], [92.95352173, 12.01993275], [92.95368958, 12.02044964], [92.95393372, 12.02085972], [92.95423889, 12.0211792], [92.9545517, 12.02149582], [92.95485687, 12.02180386], [92.95515442, 12.0221138], [92.955513, 12.02238941], [92.95573425, 12.0227747], [92.95597839, 12.02319431], [92.95625305, 12.02361107], [92.9565506, 12.02402973], [92.95691681, 12.02433968], [92.95729065, 12.02466202], [92.9577179, 12.02495098], [92.95813751, 12.0252037], [92.95835876, 12.02555275], [92.95860291, 12.02591133], [92.95878601, 12.02629089], [92.95902252, 12.02663994], [92.95932007, 12.0269413], [92.95963287, 12.02725124], [92.95990753, 12.02762032], [92.96008301, 12.02812195], [92.96031952, 12.02863216], [92.96066284, 12.02910233], [92.96103668, 12.02950954], [92.96138, 12.02993107], [92.9616394, 12.03031158], [92.96180725, 12.03068829], [92.96193695, 12.03104115], [92.96208954, 12.03141499], [92.96219635, 12.03188229], [92.96222687, 12.03249073], [92.96227264, 12.03318977], [92.96245575, 12.03390598], [92.96253967, 12.03463078], [92.96269989, 12.03529167], [92.96264648, 12.03590679], [92.96276855, 12.03644943], [92.9629364, 12.03693485], [92.96305084, 12.03722382], [92.96333313, 12.03749084], [92.96333313, 12.03889275], [92.96334076, 12.03934193], [92.96333313, 12.03969955], [92.96333313, 12.0402813], [92.96333313, 12.04055595], [92.96337128, 12.04136086], [92.96317291, 12.04190063], [92.96312714, 12.04239082], [92.96325684, 12.0428896], [92.96326447, 12.04338741], [92.96311951, 12.04389286], [92.96308136, 12.04438972], [92.96315002, 12.04486179], [92.96325684, 12.04531097], [92.96337128, 12.04576874], [92.96361542, 12.04618073], [92.96388245, 12.0466013], [92.96411133, 12.04706097], [92.9641571, 12.04750061], [92.96416473, 12.0480547], [92.96444702, 12.04833126], [92.96444702, 12.04916668], [92.96499634, 12.04972267], [92.96611023, 12.04861069], [92.96611023, 12.04805946], [92.96582794, 12.04778099], [92.96582794, 12.04582977], [92.96527863, 12.04527664], [92.96527863, 12.04417133], [92.96553802, 12.04389095], [92.96553802, 12.04278088], [92.96553802, 12.04257965], [92.96557617, 12.04216957], [92.96568298, 12.04183102], [92.96582794, 12.04152966], [92.96598816, 12.04121494], [92.9661026, 12.04080868], [92.96620178, 12.0403347], [92.96640015, 12.03983402], [92.96663666, 12.03929615], [92.96685028, 12.03870964], [92.96705627, 12.03813076], [92.96736908, 12.03763008], [92.96766663, 12.03713131], [92.96788025, 12.0365696], [92.96807098, 12.03611374], [92.9683075, 12.03571796], [92.96845245, 12.03529167], [92.96864319, 12.03485203], [92.96890259, 12.03442097], [92.96917725, 12.03398991], [92.96953583, 12.03367996], [92.96987915, 12.03361893], [92.97029114, 12.03366184], [92.97127533, 12.03455067], [92.97158813, 12.03494072], [92.97196198, 12.03541946], [92.97209167, 12.03562737], [92.97222137, 12.03581142], [92.97242737, 12.03608036], [92.97257996, 12.03641129], [92.97276306, 12.03668022], [92.9729538, 12.03680515], [92.97322845, 12.03680515], [92.97354126, 12.03668022], [92.97396851, 12.03649139], [92.97423553, 12.03665924], [92.97447968, 12.03683472], [92.97470093, 12.0370512], [92.97486115, 12.03737736], [92.97492981, 12.03772068], [92.9747467, 12.03806114], [92.97462463, 12.03839779], [92.97441101, 12.03864193], [92.97407532, 12.03926563], [92.97395325, 12.03979969], [92.97390747, 12.0402689], [92.97405243, 12.0407753], [92.97416687, 12.04129028], [92.97428131, 12.0416851], [92.97438812, 12.04197025], [92.97459412, 12.04216099], [92.97489166, 12.042243], [92.97528076, 12.04222298], [92.97750092, 12.04222298], [92.97777557, 12.04194355], [92.97857666, 12.04201126], [92.97902679, 12.04204941], [92.97949982, 12.04231071], [92.97997284, 12.04247093], [92.9803009, 12.04251194], [92.9806366, 12.04253006], [92.98107147, 12.04257107], [92.98139191, 12.04258919], [92.98174286, 12.04294014], [92.98176575, 12.04323006], [92.98178864, 12.04333019], [92.98192596, 12.04348087], [92.98214722, 12.04354], [92.98246002, 12.04354], [92.98277283, 12.04337978], [92.98304749, 12.04294014], [92.98335266, 12.04246426], [92.98361969, 12.04226112], [92.98389435, 12.04197598], [92.98416901, 12.04162121], [92.98441315, 12.04123783], [92.98458862, 12.04084969], [92.98473358, 12.04052544], [92.98487854, 12.04026222], [92.98501587, 12.04002094], [92.98519135, 12.03981113], [92.9854126, 12.03961086], [92.98570251, 12.03940964], [92.98604584, 12.03914833], [92.98645782, 12.03883076], [92.98693848, 12.03848934], [92.98742676, 12.03813076], [92.98792267, 12.03780079], [92.98840332, 12.03752136], [92.9888916, 12.03726101], [92.98937988, 12.03700638], [92.98987579, 12.03674126], [92.99047089, 12.03659058], [92.99106598, 12.03643131], [92.99172211, 12.0363903], [92.99240875, 12.03638554], [92.99304962, 12.03634167], [92.99355316, 12.03614044], [92.99401855, 12.03598022], [92.99443054, 12.03581142], [92.99478149, 12.03558064], [92.99517822, 12.03539181], [92.9956131, 12.0352459], [92.99584961, 12.03507137], [92.99606323, 12.03484535], [92.99623108, 12.03472042], [92.99643707, 12.03461742], [92.99675751, 12.03449154], [92.99707031, 12.03441238], [92.99723816, 12.03436947], [92.99777985, 12.03419971], [92.99856567, 12.03378296], [92.9988327, 12.03335857], [92.99900818, 12.03285122], [92.99925232, 12.03238106], [92.9994278, 12.03197098], [93.0, 12.03139019], [93.00055695, 12.03139019], [93.00110626, 12.03083134], [93.00138855, 12.0308342], [93.00222015, 12.02999973], [93.00250244, 12.03000164], [93.00332642, 12.02917004], [93.00332642, 12.02888966], [93.00389099, 12.0283289], [93.00389099, 12.02805519], [93.00417328, 12.02777958], [93.00417328, 12.0274992], [93.00444794, 12.02722359], [93.00444794, 12.02694321], [93.0047226, 12.02666664], [93.0047226, 12.02639198], [93.00554657, 12.02555275], [93.0055542, 12.02527714], [93.00611115, 12.02472115], [93.00611115, 12.02444458], [93.0063858, 12.02416706], [93.0063858, 12.02389145], [93.00666809, 12.02361107], [93.00666809, 12.02306175], [93.00694275, 12.02278233], [93.00694275, 12.02222061], [93.00722504, 12.021945], [93.00722504, 12.02166653], [93.00888824, 12.02000141], [93.00888824, 12.01972103], [93.0091629, 12.01944542], [93.0091629, 12.01916695], [93.00945282, 12.01889133], [93.00945282, 12.01832962], [93.00971985, 12.01805687], [93.00971985, 12.01750088], [93.01000214, 12.01721954], [93.01000214, 12.01360989], [93.0100708, 12.01306057], [93.00985718, 12.01278687], [93.00965118, 12.01224041], [93.00937653, 12.01169109], [93.00894928, 12.01107121], [93.00860596, 12.01027966], [93.00860596, 12.00943947], [93.0083313, 12.00916576], [93.0083313, 12.00861168], [93.0080719, 12.00833035], [93.00805664, 12.00805569], [93.00778198, 12.00778008], [93.00778198, 12.00722027], [93.00749969, 12.0069437], [93.00749969, 12.00555611], [93.00723267, 12.00527954], [93.00723267, 12.00472164], [93.00694275, 12.00444412], [93.00694275, 12.00167179], [93.00723267, 12.00139046], [93.00723267, 12.00028038], [93.00749969, 12.00028038], [93.00778198, 12.00000191], [93.0080719, 11.99889183], [93.0083313, 11.99861145], [93.0083313, 11.99805546], [93.00860596, 11.99777889], [93.00888062, 11.99747181], [93.0091095, 11.9971714], [93.00927734, 11.99682045], [93.0094223, 11.99642086], [93.00948334, 11.9959898], [93.00963593, 11.99562073], [93.00975037, 11.99525166], [93.00991821, 11.99493027], [93.01004791, 11.99460888], [93.01022339, 11.99431133], [93.01036072, 11.99394608], [93.01056671, 11.99356079], [93.01081848, 11.99314976], [93.01104736, 11.99271965], [93.01119995, 11.99229145], [93.01136017, 11.99192429], [93.01145172, 11.99154758], [93.01159668, 11.99122047], [93.01171875, 11.99084187], [93.01197052, 11.99051094], [93.01216125, 11.99011707], [93.01243591, 11.98976135], [93.01254272, 11.98925114], [93.01276398, 11.98878765], [93.01302338, 11.98830032], [93.01328278, 11.98778057], [93.01352692, 11.98727036], [93.0137558, 11.9867506], [93.01402283, 11.98637486], [93.0140686, 11.98596001], [93.01416779, 11.98561954], [93.01431274, 11.98526001], [93.0144577, 11.98484135], [93.0147171, 11.98439217], [93.01496124, 11.983881], [93.01520538, 11.98335743], [93.01547241, 11.98287201], [93.01573181, 11.98243618], [93.01580811, 11.98192978], [93.01587677, 11.98147011], [93.01608276, 11.98108006], [93.0161972, 11.98064041], [93.0164032, 11.98024082], [93.0166626, 11.97988129], [93.01686096, 11.9795208], [93.01705933, 11.97917938], [93.01728058, 11.97888088], [93.01763153, 11.97872829], [93.01790619, 11.97846127], [93.01809692, 11.97803974], [93.01824951, 11.97762012], [93.01847076, 11.97728062], [93.01858521, 11.97695923], [93.01872253, 11.97667027], [93.01891327, 11.9763813], [93.0191803, 11.97609138], [93.0194397, 11.97574043], [93.01967621, 11.97533035], [93.01980591, 11.97478104], [93.02001953, 11.97422695], [93.02030182, 11.97367096], [93.02057648, 11.9731102], [93.02086639, 11.97260189], [93.02114105, 11.97219181], [93.02138519, 11.97186089], [93.02159882, 11.97155094], [93.02174377, 11.97118378], [93.02194977, 11.97083092], [93.02216339, 11.97046185], [93.02231598, 11.9700489], [93.02250671, 11.96969128], [93.02272034, 11.96938133], [93.02288818, 11.96905136], [93.02308655, 11.96876812], [93.02333069, 11.96849537], [93.02359009, 11.9681797], [93.02384949, 11.96783638], [93.02414703, 11.96750069], [93.02442932, 11.96711636], [93.02469635, 11.96669197], [93.02494049, 11.96625423], [93.02510071, 11.96575546], [93.02528381, 11.96529293], [93.02548218, 11.96487999], [93.02559662, 11.96446133], [93.02577972, 11.96410084], [93.02577972, 11.96369934], [93.02561188, 11.96328163], [93.02560425, 11.96287441], [93.02578735, 11.96248913], [93.02587128, 11.96210194], [93.02598572, 11.96169567], [93.02590179, 11.96121979], [93.02562714, 11.96077061], [93.0255661, 11.96033955], [93.02565002, 11.95993042], [93.02580261, 11.95954037], [93.02588654, 11.95914078], [93.02607727, 11.95879936], [93.02619934, 11.95841026], [93.02635956, 11.95805168], [93.02645111, 11.95765114], [93.02661133, 11.95732021], [93.02671051, 11.95696926], [93.02688599, 11.95669079], [93.02700043, 11.95633125], [93.02715302, 11.95600986], [93.02722931, 11.95566082], [93.02732849, 11.9553299], [93.02746582, 11.9550209], [93.02754211, 11.95467186], [93.02768707, 11.95436192], [93.02778625, 11.95403957], [93.02792358, 11.95373726], [93.0280304, 11.95340919], [93.02805328, 11.95300961], [93.02805328, 11.95258045], [93.02805328, 11.95213985], [93.02809906, 11.95172024], [93.02831268, 11.95141029], [93.02851868, 11.95111942], [93.02877808, 11.95083141], [93.02905273, 11.95053673], [93.02923584, 11.95021152], [93.02946472, 11.9499197], [93.02971649, 11.94965076], [93.02999878, 11.94936085], [93.0302887, 11.94903564], [93.03061676, 11.94870472], [93.03100586, 11.94846058], [93.03141022, 11.94837475], [93.03177643, 11.94846058], [93.03213501, 11.94859791], [93.03244781, 11.94871235], [93.03270721, 11.94886017], [93.03299713, 11.94898129], [93.03328705, 11.94913101], [93.03365326, 11.94917011], [93.03398132, 11.94916344], [93.03447723, 11.94909859], [93.03491211, 11.94893074], [93.03540039, 11.94885826], [93.03588867, 11.94871044], [93.03639984, 11.94857121], [93.03682709, 11.94829273], [93.0371933, 11.94791031], [93.03743744, 11.94745159], [93.03749084, 11.94689274], [93.03744507, 11.94634247], [93.03727722, 11.94586086], [93.03722382, 11.94538879], [93.03723907, 11.94493103], [93.03734589, 11.94447041], [93.03749847, 11.94444466], [93.03778076, 11.94416714], [93.03778076, 11.94361115], [93.03805542, 11.94361115], [93.03861237, 11.94305515], [93.03833008, 11.9427824], [93.03888702, 11.94222069], [93.03888702, 11.94194508], [93.03916931, 11.9416666], [93.03916931, 11.94139957], [93.03971863, 11.94083118], [93.03971863, 11.94027901], [93.04000092, 11.94000053], [93.04000092, 11.93972111], [93.04027557, 11.93944454], [93.04027557, 11.93916702], [93.04055786, 11.93889141], [93.04055786, 11.93861103], [93.04083252, 11.9383297], [93.04083252, 11.93750095], [93.04110718, 11.93721962], [93.04111481, 11.93694496], [93.04149628, 11.936553], [93.04164124, 11.93612194], [93.04167175, 11.93569088], [93.04167175, 11.93527031], [93.04166412, 11.93487453], [93.04165649, 11.93447018], [93.04167938, 11.93408012], [93.04180145, 11.93373108], [93.04210663, 11.93343925], [93.04243469, 11.93314266], [93.04267883, 11.93277645], [93.04286957, 11.93245029], [93.04308319, 11.93208122], [93.04335022, 11.93166161], [93.04368591, 11.93123531], [93.04400635, 11.93077087], [93.04431152, 11.93032169], [93.04447174, 11.92991066], [93.04460144, 11.9296217], [93.04469299, 11.92936039], [93.0447464, 11.9290657], [93.04483032, 11.92873287], [93.04477692, 11.92837334], [93.04473114, 11.92799187], [93.04472351, 11.9276123], [93.04475403, 11.92724037], [93.04489136, 11.92689133], [93.04498291, 11.92653084], [93.04503632, 11.92615128], [93.04524994, 11.92585659], [93.04550934, 11.92556], [93.04579926, 11.92527103], [93.04608917, 11.92496967], [93.0463562, 11.92468834], [93.04654694, 11.9243803], [93.04665375, 11.92401695], [93.04663849, 11.92362118], [93.04658508, 11.92329025], [93.04640198, 11.92304039], [93.0462265, 11.92282104], [93.04611206, 11.92278004], [93.04582977, 11.92249966], [93.04528046, 11.9219389], [93.04611206, 11.92111206], [93.04638672, 11.9211092], [93.04666901, 11.92138958], [93.04695129, 11.92138958], [93.04724121, 11.9211092], [93.0474472, 11.92096329], [93.04775238, 11.92060089], [93.04792786, 11.92014122], [93.04784393, 11.91974926], [93.04779053, 11.91937923], [93.04774475, 11.9189806], [93.04759216, 11.91854095], [93.04746246, 11.91803741], [93.04727173, 11.9175396], [93.04724121, 11.91699982], [93.0473175, 11.91650105], [93.04738617, 11.91603088], [93.04747009, 11.91559601], [93.04753113, 11.91518974], [93.04766083, 11.91477966], [93.0477829, 11.91430092], [93.04789734, 11.91384602], [93.04808044, 11.91342163], [93.04833221, 11.91308022], [93.04865265, 11.91278076], [93.04901886, 11.91248703], [93.0493927, 11.91214085], [93.04962921, 11.91168022], [93.04946136, 11.91113281], [93.04922485, 11.91059113], [93.04915619, 11.91013145], [93.04916382, 11.90974998], [93.04915619, 11.90941048], [93.04915619, 11.90905857], [93.04921722, 11.90868092], [93.04944611, 11.90832615], [93.04972076, 11.90793991], [93.04998779, 11.90753937], [93.05028534, 11.90717888], [93.05055237, 11.90687847], [93.05078888, 11.90660858], [93.05098724, 11.90631962], [93.05136108, 11.90601921], [93.051651, 11.90558243], [93.05190277, 11.90512085], [93.05222321, 11.90487957], [93.05253601, 11.9047308], [93.05285645, 11.90462017], [93.05317688, 11.90442085], [93.05349731, 11.90413189], [93.05381775, 11.90371037], [93.05403137, 11.9031496], [93.05409241, 11.90254116], [93.05393982, 11.90193939], [93.05389404, 11.90139008], [93.05390167, 11.90092087], [93.05397797, 11.90048981], [93.05412292, 11.90010929], [93.05416107, 11.89966011], [93.0541687, 11.89913177], [93.0541687, 11.89854145], [93.05416107, 11.89791012], [93.0541153, 11.89729881], [93.05393982, 11.89674091], [93.05384064, 11.89616203], [93.05361938, 11.89563084], [93.05339813, 11.89507008], [93.05314636, 11.89452267], [93.05290985, 11.89401531], [93.05258942, 11.89368916], [93.05233765, 11.89342022], [93.05223846, 11.89311886], [93.05218506, 11.89281845], [93.05200958, 11.89253139], [93.05192566, 11.89222813], [93.05178833, 11.89192009], [93.05168152, 11.8915596], [93.05161285, 11.89115047], [93.05129242, 11.89085102], [93.05092621, 11.89056015], [93.05066681, 11.89021969], [93.05052948, 11.88982582], [93.05031586, 11.88948154], [93.05007172, 11.88918304], [93.04978943, 11.88892841], [93.04955292, 11.88869095], [93.04931641, 11.8884306], [93.04911041, 11.88811016], [93.04886627, 11.88771057], [93.04860687, 11.88724995], [93.04839325, 11.88670063], [93.04801178, 11.88640022], [93.04766083, 11.88614273], [93.04734039, 11.88591003], [93.04706573, 11.88566399], [93.04680634, 11.88540363], [93.04655457, 11.88513088], [93.04634857, 11.88479614], [93.04614258, 11.88444042], [93.04598236, 11.88400936], [93.04566193, 11.88376808], [93.04512024, 11.88374138], [93.04464722, 11.88363075], [93.04434967, 11.88350105], [93.04415131, 11.88337994], [93.04390717, 11.8833189], [93.04360199, 11.88319778], [93.04328918, 11.88292027], [93.04299927, 11.88252068], [93.0426712, 11.88226128], [93.042099, 11.88229084], [93.04180145, 11.88220882], [93.04160309, 11.8821497], [93.04107666, 11.88198566], [93.04055023, 11.88194656], [93.04007721, 11.8819418], [93.039711, 11.88193989], [93.03940582, 11.88190079], [93.03917694, 11.88175106], [93.03896332, 11.88157082], [93.03855133, 11.88160038], [93.03807068, 11.88165092], [93.03755188, 11.88167095], [93.03725433, 11.88166428], [93.0369873, 11.88166046], [93.03634644, 11.88158035], [93.03593445, 11.88165665], [93.0355072, 11.88173008], [93.03482819, 11.88189697], [93.03439331, 11.88216972], [93.03391266, 11.88234138], [93.03341675, 11.88254166], [93.03292847, 11.88280201], [93.03244019, 11.88309097], [93.03196716, 11.88335991], [93.03161621, 11.88369274], [93.03136444, 11.88405991], [93.03111267, 11.88436985], [93.03079224, 11.88461971], [93.03037262, 11.88479996], [93.02993011, 11.88507843], [93.02945709, 11.88542938], [93.0290451, 11.88580799], [93.02858734, 11.88611317], [93.02813721, 11.88639069], [93.02767944, 11.88667202], [93.02719879, 11.88694954], [93.02671051, 11.88723373], [93.02625275, 11.88753986], [93.02578735, 11.88787937], [93.0252533, 11.88821697], [93.02494049, 11.88887119], [93.02459717, 11.88953018], [93.02468872, 11.89011955], [93.02471161, 11.89057064], [93.02462006, 11.8909359], [93.0245285, 11.89127254], [93.02446747, 11.89163113], [93.02422333, 11.89194107], [93.02391815, 11.89233112], [93.02349091, 11.8927412], [93.0234375, 11.89328098], [93.02349091, 11.89396], [93.02348328, 11.89465141], [93.02340698, 11.89524555], [93.02336121, 11.89572239], [93.02334595, 11.89610481], [93.02327728, 11.89637375], [93.02309418, 11.89652443], [93.02287292, 11.89663124], [93.02259827, 11.89671993], [93.02236176, 11.89701939], [93.0222702, 11.89778519], [93.02225494, 11.89855289], [93.02231598, 11.89905167], [93.02245331, 11.89935017], [93.02249908, 11.89962196], [93.02249908, 11.89990044], [93.02250671, 11.90017986], [93.02249908, 11.90050983], [93.02246094, 11.9008522], [93.02230835, 11.90120125], [93.0220871, 11.90151119], [93.02186584, 11.90187073], [93.02156067, 11.90221119], [93.02118683, 11.90254116], [93.02086639, 11.90289021], [93.02060699, 11.90329075], [93.02039337, 11.90375805], [93.02012634, 11.904212], [93.01991272, 11.90472031], [93.01971436, 11.90521717], [93.01951599, 11.90567493], [93.01944733, 11.90613079], [93.01937103, 11.90654087], [93.01920319, 11.90685081], [93.01908112, 11.9071722], [93.01886749, 11.90746021], [93.01860046, 11.90780067], [93.01833344, 11.90820503], [93.01803589, 11.9085989], [93.01773071, 11.90893173], [93.01750946, 11.9092989], [93.01735687, 11.90966129], [93.01729584, 11.90997124], [93.01721954, 11.91025066], [93.01708221, 11.91052723], [93.01685333, 11.91076183], [93.0165329, 11.91097164], [93.01637268, 11.91132927], [93.01613617, 11.91165066], [93.01592255, 11.9119606], [93.01574707, 11.91226196], [93.01551819, 11.91253662], [93.01535034, 11.91288185], [93.01515961, 11.91321945], [93.01494598, 11.91356277], [93.01452637, 11.91380024], [93.01419067, 11.91415596], [93.01383209, 11.91451073], [93.0135498, 11.9148922], [93.01329803, 11.91522503], [93.01304626, 11.91548443], [93.01280975, 11.91571236], [93.01263428, 11.91598129], [93.01248932, 11.91627312], [93.01233673, 11.91657162], [93.01220703, 11.9169178], [93.01206207, 11.91723919], [93.01196289, 11.91755772], [93.01190186, 11.91786385], [93.0117569, 11.91809177], [93.01166534, 11.91835594], [93.01153564, 11.91861439], [93.01138306, 11.91890144], [93.0111618, 11.91922855], [93.01093292, 11.91962147], [93.01062775, 11.92004013], [93.01035309, 11.92047977], [93.01004028, 11.92090607], [93.00977325, 11.92136002], [93.00953674, 11.92186069], [93.00917816, 11.92224407], [93.00888824, 11.92268181], [93.00862122, 11.9231348], [93.00836945, 11.92362118], [93.00808716, 11.92414093], [93.00778198, 11.92467785], [93.00749969, 11.92525005], [93.0072403, 11.92583179], [93.00701904, 11.92638779], [93.00681305, 11.92689133], [93.00653076, 11.92727375], [93.00610352, 11.9275341], [93.00582886, 11.92786026], [93.00563812, 11.92815018], [93.00557709, 11.92843437], [93.00554657, 11.92860985], [93.0036087, 11.9305563], [93.0036087, 11.93083191], [93.00335693, 11.93105125], [93.00305176, 11.93128967], [93.00261688, 11.93146992], [93.00215912, 11.93175125], [93.00171661, 11.93209934], [93.00164795, 11.93223095], [93.0, 11.9338913], [92.99973297, 11.93391132], [92.99936676, 11.93391132], [92.99880219, 11.93390656], [92.99829865, 11.93404102], [92.99803925, 11.93460178], [92.99775696, 11.93501186], [92.99761963, 11.93549061], [92.99761963, 11.93605137], [92.99817657, 11.93667126], [92.9983902, 11.93715], [92.99852753, 11.93728924], [92.99845886, 11.9377718], [92.99810791, 11.93825054], [92.99771118, 11.93871784], [92.99733734, 11.938941], [92.99671173, 11.93956566], [92.99636078, 11.93977261], [92.9956665, 11.93949699], [92.99545288, 11.93949699], [92.99517059, 11.93962955], [92.99468231, 11.94004917], [92.99453735, 11.94066048], [92.99447632, 11.94164181], [92.99482727, 11.94196129], [92.99494171, 11.94219112], [92.99512482, 11.94242096], [92.99542236, 11.94258308], [92.99563599, 11.94283199], [92.99585724, 11.94315147], [92.9961319, 11.94349003], [92.99645233, 11.94389057], [92.99682617, 11.94432926], [92.99726868, 11.94476032], [92.99775696, 11.94514275], [92.99829865, 11.94550133], [92.9990387, 11.94578075], [92.99972534, 11.94555473], [93.0, 11.94583321], [93.00031281, 11.94614315], [93.00055695, 11.94642067], [93.00086212, 11.94670582], [93.00110626, 11.94699287], [93.0015564, 11.94720078], [93.00190735, 11.94762039], [93.00190735, 11.94803047], [93.00177002, 11.94837475], [93.0013504, 11.94837475], [93.00093079, 11.94865036], [93.00048065, 11.94968128], [93.0003891, 11.95020008], [93.00026703, 11.95014095], [93.0, 11.94999981], [92.99972534, 11.94883728], [92.99962616, 11.94857121], [92.99925995, 11.94828129], [92.998909, 11.94794178], [92.99855042, 11.94756985], [92.99809265, 11.94724178], [92.99733734, 11.94715977], [92.99698639, 11.94714165], [92.99651337, 11.94720078], [92.99604034, 11.94740105], [92.99537659, 11.94782066], [92.99513245, 11.94837475], [92.99479675, 11.94887066], [92.99433136, 11.94924736], [92.99397278, 11.94960117], [92.99355316, 11.95001602], [92.99307251, 11.95019341], [92.99254608, 11.95031166], [92.99209595, 11.95063305], [92.99167633, 11.95084953], [92.99110413, 11.95108223], [92.99085999, 11.95118046], [92.99028015, 11.95107079], [92.98977661, 11.95092869], [92.98929596, 11.95040131], [92.98883057, 11.95020866], [92.98844147, 11.94996071], [92.98813629, 11.94964218], [92.98787689, 11.9492588], [92.98753357, 11.94890785], [92.98721313, 11.94855022], [92.98693848, 11.94817162], [92.98654175, 11.9477911], [92.98618317, 11.94740963], [92.98599243, 11.9469614], [92.98599243, 11.94647598], [92.98635864, 11.94601059], [92.98619843, 11.94563961], [92.98599243, 11.94535923], [92.9858017, 11.94511986], [92.98487854, 11.94494438], [92.98403168, 11.94511986], [92.98340607, 11.94543362], [92.98287964, 11.94556427], [92.98240662, 11.94556046], [92.98163605, 11.94567204], [92.98117828, 11.94581127], [92.98071289, 11.94615173], [92.98027039, 11.94643974], [92.97985077, 11.94668579], [92.97941589, 11.94694138], [92.97897339, 11.94717121], [92.97845459, 11.94723988], [92.97793579, 11.94734001], [92.97744751, 11.94749928], [92.9769516, 11.94764519], [92.97650146, 11.94776058], [92.97609711, 11.94783878], [92.9757309, 11.94794369], [92.97541809, 11.94805145], [92.9749527, 11.94806004], [92.97438049, 11.94839096], [92.97386932, 11.94880104], [92.97336578, 11.94917011], [92.9730072, 11.9496212], [92.97264099, 11.95007038], [92.97235107, 11.95059013], [92.9719162, 11.95112133], [92.97154999, 11.95152187], [92.97144318, 11.9518137], [92.97118378, 11.95220375], [92.97103119, 11.95259094], [92.97071075, 11.953022], [92.97059631, 11.95335007], [92.97041321, 11.95372105], [92.97000885, 11.95407009], [92.96981812, 11.95451927], [92.96949768, 11.9549408], [92.96920776, 11.9553442], [92.96895599, 11.95575428], [92.96864319, 11.95613003], [92.96835327, 11.95652008], [92.96820068, 11.95692062], [92.9682312, 11.95731068], [92.96808624, 11.95767975], [92.96805573, 11.95809746], [92.96800995, 11.95853329], [92.96781921, 11.95891094], [92.96770477, 11.959342], [92.96749878, 11.95969486], [92.9672699, 11.96000004], [92.96713257, 11.96037197], [92.9670105, 11.96074963], [92.96686554, 11.96118641], [92.96650696, 11.96155262], [92.96630096, 11.96211815], [92.96627808, 11.96253014], [92.96628571, 11.9630661], [92.96631622, 11.9635601], [92.966362, 11.96407986], [92.96624756, 11.96459103], [92.96611786, 11.96510124], [92.96604156, 11.96559143], [92.96586609, 11.96601105], [92.96583557, 11.96640491], [92.96578979, 11.96675968]]], [[[92.63062286, 12.11791039], [92.63050842, 12.11791039], [92.63019562, 12.11799717], [92.63013458, 12.11822319], [92.63006592, 12.11848927], [92.63008881, 12.11875057], [92.63021851, 12.11889935], [92.63031769, 12.11919594], [92.63031769, 12.11946201], [92.63047028, 12.11973095], [92.6305542, 12.11991787], [92.6307373, 12.12010288], [92.63096619, 12.1202898], [92.63116455, 12.12045383], [92.63153839, 12.12045383], [92.63166809, 12.12022781], [92.63165283, 12.11979103], [92.6315155, 12.11938], [92.63141632, 12.11901093], [92.6312027, 12.11857986], [92.63101196, 12.11824131], [92.63082123, 12.1180582], [92.63062286, 12.11791039]]], [[[92.62884521, 12.11245632], [92.62821198, 12.11220074], [92.62800598, 12.11244011], [92.62802124, 12.11275005], [92.62812805, 12.11310101], [92.62828064, 12.11339092], [92.62847137, 12.11370087], [92.62863922, 12.11405182], [92.62867737, 12.1143589], [92.62867737, 12.11475086], [92.62872314, 12.11508179], [92.62896729, 12.11537075], [92.62922668, 12.11561775], [92.62956238, 12.1158638], [92.62985229, 12.11609173], [92.63002014, 12.11633968], [92.63018799, 12.11655045], [92.63037872, 12.11655045], [92.63041687, 12.11622238], [92.63041687, 12.1157589], [92.63037872, 12.1151638], [92.63033295, 12.11435699], [92.63031769, 12.11375999], [92.63031769, 12.11332035], [92.63018799, 12.11305618], [92.62982941, 12.11281013], [92.62934875, 12.11262035], [92.62884521, 12.11245632]]], [[[92.69890594, 12.24483776], [92.69860077, 12.24473095], [92.69824982, 12.24481487], [92.69777679, 12.24501133], [92.69732666, 12.24528408], [92.69692993, 12.24556923], [92.69660187, 12.24584103], [92.69633484, 12.24617767], [92.69610596, 12.24661064], [92.69593811, 12.24714184], [92.69586945, 12.24769974], [92.69605255, 12.24827003], [92.69610596, 12.2489109], [92.69618988, 12.24958706], [92.69657898, 12.25021362], [92.6969986, 12.25082493], [92.69743347, 12.25085163], [92.69769287, 12.25067234], [92.6978302, 12.25057888], [92.69822693, 12.25028038], [92.6986084, 12.24998379], [92.69889069, 12.24960995], [92.69911194, 12.24920177], [92.69921875, 12.24870968], [92.69940948, 12.24828053], [92.69948578, 12.24780273], [92.69967651, 12.24738979], [92.69972229, 12.2468996], [92.69972229, 12.24635124], [92.699646, 12.24577427], [92.6993866, 12.24524117], [92.69890594, 12.24483776]]], [[[92.90143585, 12.26215172], [92.90141296, 12.25907135], [92.9008255, 12.25855637], [92.90029907, 12.25861454], [92.89972687, 12.25915527], [92.89968872, 12.25965405], [92.89949036, 12.25961113], [92.89944458, 12.26079178], [92.89974976, 12.26081181], [92.89974976, 12.26158047], [92.90001678, 12.26163006], [92.90001678, 12.26246452], [92.90115356, 12.26244926], [92.90143585, 12.26215172]]], [[[92.88054657, 12.25], [92.88083649, 12.24971962], [92.88111115, 12.24972153], [92.88194275, 12.24888992], [92.88175201, 12.24632072], [92.88111115, 12.24527073], [92.88027954, 12.24611187], [92.88027954, 12.24666786], [92.87999725, 12.24694061], [92.87999725, 12.24777985], [92.8797226, 12.24777985], [92.87944794, 12.24805641], [92.87944794, 12.2486124], [92.8797226, 12.24860954], [92.87999725, 12.24888992], [92.87999725, 12.24971962], [92.88018799, 12.24990559], [92.88027954, 12.25], [92.88054657, 12.25]]], [[[93.02966309, 12.28017139], [93.02997589, 12.27981567], [93.03029633, 12.27965069], [93.03044128, 12.27928925], [93.03037262, 12.27844143], [93.03029633, 12.27791023], [93.0300827, 12.27749062], [93.02980042, 12.2772007], [93.02947235, 12.27706242], [93.02925873, 12.27699184], [93.02922058, 12.27671146], [93.02919006, 12.27639008], [93.02900696, 12.27600861], [93.02879333, 12.27554035], [93.02850342, 12.27501297], [93.02832794, 12.27476501], [93.02813721, 12.27458954], [93.02778625, 12.27427006], [93.02749634, 12.2740202], [93.02700043, 12.27353001], [93.0266037, 12.27342319], [93.02645874, 12.27346134], [93.02613831, 12.27334976], [93.02584839, 12.27338791], [93.02548981, 12.27356243], [93.0252533, 12.27359962], [93.02487946, 12.27367115], [93.0247345, 12.27402401], [93.0242691, 12.27395439], [93.02394867, 12.27398968], [93.02359009, 12.2740612], [93.02323151, 12.27423573], [93.02279663, 12.27440929], [93.02230072, 12.27458954], [93.02207947, 12.27476501], [93.02194214, 12.27501297], [93.0220108, 12.27522469], [93.02216339, 12.27540112], [93.02230072, 12.27582932], [93.02258301, 12.27618027], [93.02283478, 12.27639008], [93.02323151, 12.27667046], [93.02362823, 12.27699184], [93.02379608, 12.27731991], [93.02391052, 12.27755928], [93.02420044, 12.277771], [93.02448273, 12.27802181], [93.02462769, 12.27812004], [93.02502441, 12.27815628], [93.0253067, 12.27824116], [93.0256424, 12.27834797], [93.02585602, 12.27845001], [93.02613831, 12.27848911], [93.02649689, 12.27859402], [93.02703094, 12.27900028], [93.02746582, 12.27935696], [93.02761078, 12.27949047], [93.02803802, 12.28003025], [93.02832794, 12.27996063], [93.0284729, 12.27982044], [93.028862, 12.28003025], [93.02929688, 12.28017139], [93.02966309, 12.28017139]]], [[[92.73760986, 12.27133274], [92.73729706, 12.27073097], [92.73703766, 12.27073574], [92.73703766, 12.27045727], [92.736763, 12.27017021], [92.736763, 12.26990128], [92.73648071, 12.2696228], [92.73648071, 12.26934528], [92.73506927, 12.26935387], [92.73506927, 12.27047253], [92.73536682, 12.27046204], [92.73542023, 12.27106094], [92.73590088, 12.27106094], [92.73622894, 12.27133274], [92.73620605, 12.27184963], [92.73648834, 12.27184963], [92.73648834, 12.27243137], [92.73699951, 12.27243137], [92.73703766, 12.27435017], [92.73762512, 12.27466488], [92.73760986, 12.27524376], [92.73786926, 12.27552414], [92.73839569, 12.27550316], [92.73841858, 12.27522469], [92.73880005, 12.27504063], [92.7388916, 12.27479935], [92.73886871, 12.27458286], [92.73870087, 12.27440739], [92.73871613, 12.27299023], [92.73844147, 12.27293015], [92.73847961, 12.27243137], [92.73815155, 12.27243137], [92.73813629, 12.27133274], [92.73760986, 12.27133274]]], [[[93.12052917, 12.14834976], [93.12052917, 12.14800167], [93.12021637, 12.14800358], [93.12021637, 12.1477623], [93.12049103, 12.14762592], [93.12039185, 12.14558983], [93.11992645, 12.14563084], [93.11987305, 12.14528275], [93.11937714, 12.14528275], [93.11937714, 12.14462852], [93.11965179, 12.14459038], [93.11965179, 12.14421558], [93.11860657, 12.14422131], [93.11856842, 12.14439201], [93.11836243, 12.14439201], [93.11836243, 12.14387035], [93.11909485, 12.14383602], [93.119133, 12.14356041], [93.11940765, 12.14339066], [93.11972809, 12.14339066], [93.11979675, 12.14360142], [93.12018585, 12.14360142], [93.12024689, 12.14376926], [93.12049103, 12.14380074], [93.12081146, 12.14383984], [93.12081146, 12.14409065], [93.12049103, 12.14414501], [93.12052917, 12.14435291], [93.12136841, 12.14442062], [93.12140656, 12.14466953], [93.12161255, 12.14470196], [93.1216507, 12.14494133], [93.12188721, 12.14484119], [93.12191772, 12.14435101], [93.12220764, 12.1442852], [93.12217712, 12.14387226], [93.12188721, 12.14391136], [93.12188721, 12.14363003], [93.12161255, 12.14356041], [93.12161255, 12.1430397], [93.12133026, 12.14297581], [93.12136841, 12.14280128], [93.12161255, 12.14266586], [93.12161255, 12.14169979], [93.12133026, 12.14162922], [93.12136841, 12.14135647], [93.12161255, 12.14128971], [93.12161255, 12.14076996], [93.12185669, 12.14076996], [93.12188721, 12.14050102], [93.12238312, 12.14050102], [93.12242126, 12.14030075], [93.12266541, 12.14028931], [93.12269592, 12.14050102], [93.12361145, 12.14050102], [93.12361145, 12.14026165], [93.1232605, 12.14026165], [93.1232605, 12.13995171], [93.12290955, 12.1399107], [93.12290955, 12.13973999], [93.12272644, 12.13963985], [93.12267303, 12.13857079], [93.12185669, 12.13857079], [93.12185669, 12.13777065], [93.1216507, 12.13777542], [93.12158203, 12.13746452], [93.12133026, 12.13746452], [93.12129974, 12.1372242], [93.12101746, 12.1372242], [93.12101746, 12.13691425], [93.12028503, 12.13694763], [93.12025452, 12.13674068], [93.12029266, 12.13630104], [93.11992645, 12.13630104], [93.11992645, 12.13613033], [93.11962128, 12.13613033], [93.11965179, 12.13558006], [93.11936951, 12.13561153], [93.11930084, 12.13519955], [93.11878204, 12.13527107], [93.11881256, 12.13479042], [93.1181488, 12.13471889], [93.11821747, 12.13441086], [93.11856842, 12.13441086], [93.11856842, 12.13416958], [93.11801147, 12.13416958], [93.11801147, 12.13362026], [93.11772919, 12.13362026], [93.11772919, 12.13330078], [93.11737823, 12.13330555], [93.11737823, 12.13306427], [93.11724091, 12.13298893], [93.11720276, 12.13226032], [93.11664581, 12.13185215], [93.11664581, 12.1313343], [93.11636353, 12.1313343], [93.11640167, 12.13078308], [93.11605072, 12.13078308], [93.11608887, 12.12992096], [93.11556244, 12.12995052], [93.11546326, 12.13050938], [93.11499786, 12.13050938], [93.1149292, 12.13105869], [93.11437225, 12.13154221], [93.11437225, 12.13202], [93.11472321, 12.13237095], [93.11472321, 12.13284969], [93.11444092, 12.13298893], [93.11444092, 12.13315105], [93.11419678, 12.13340187], [93.11408997, 12.13430023], [93.11382294, 12.13461018], [93.11342621, 12.13464069], [93.11328888, 12.13529968], [93.11276245, 12.1353302], [93.11274719, 12.13550091], [93.11248016, 12.13553715], [93.11244965, 12.13581085], [93.11269379, 12.13581085], [93.11255646, 12.13622475], [93.11220551, 12.13653469], [93.11221313, 12.13722134], [93.11188507, 12.13725758], [93.11188507, 12.13749981], [93.11221313, 12.13749981], [93.11223602, 12.13805103], [93.11199188, 12.13808537], [93.11192322, 12.13853168], [93.11132813, 12.139081], [93.11102295, 12.13926125], [93.11107635, 12.13981056], [93.11052704, 12.13980579], [93.11052704, 12.14001274], [93.11017609, 12.14001083], [93.11017609, 12.14046001], [93.10964966, 12.14046001], [93.10971832, 12.14112091], [93.10996246, 12.14112091], [93.11000061, 12.14198017], [93.11027527, 12.14197636], [93.11027527, 12.14249325], [93.10940552, 12.14249325], [93.10933685, 12.14273167], [93.10909271, 12.1427803], [93.10909271, 12.14308071], [93.10936737, 12.1430788], [93.10936737, 12.14387035], [93.10946655, 12.14393997], [93.10975647, 12.14391136], [93.10975647, 12.14352989], [93.11077118, 12.14352989], [93.1108017, 12.14387226], [93.11161041, 12.14383602], [93.11161041, 12.14356041], [93.11269379, 12.14356041], [93.11269379, 12.14387226], [93.11300659, 12.14387226], [93.11300659, 12.14411068], [93.11437225, 12.14411068], [93.11444092, 12.14442062], [93.11503601, 12.14442062], [93.11503601, 12.14500713], [93.1153183, 12.14504147], [93.1153183, 12.14548969], [93.11582184, 12.14542198], [93.11582184, 12.14577007], [93.11608887, 12.14577007], [93.11608887, 12.14638996], [93.1163559, 12.14638996], [93.11633301, 12.14717674], [93.11660767, 12.14721107], [93.11664581, 12.14807224], [93.11720276, 12.14807224], [93.11720276, 12.14772797], [93.11752319, 12.14773273], [93.11749268, 12.14803791], [93.11881256, 12.14803791], [93.11881256, 12.14776039], [93.11972809, 12.1477623], [93.11975861, 12.14807034], [93.12000275, 12.14810658], [93.12004089, 12.14831448], [93.12025452, 12.14832973], [93.12052917, 12.14834976]]], [[[93.09793091, 12.13719177], [93.09799957, 12.13695335], [93.0982132, 12.13695335], [93.0982132, 12.13664341], [93.09856415, 12.13660622], [93.09855652, 12.13606071], [93.09874725, 12.13601971], [93.09875488, 12.13581467], [93.09851074, 12.13578129], [93.09851074, 12.13519096], [93.09829712, 12.13522911], [93.09836578, 12.13512707], [93.09835052, 12.13448048], [93.09799957, 12.13448048], [93.09799957, 12.134202], [93.09832001, 12.13409042], [93.09832001, 12.13388729], [93.09803772, 12.13385296], [93.09790039, 12.13350868], [93.09748077, 12.13357925], [93.09739685, 12.13392067], [93.09716034, 12.133955], [93.09706116, 12.134161], [93.09664154, 12.134202], [93.09664154, 12.13474941], [93.09632111, 12.13478279], [93.09638977, 12.13657188], [93.09688568, 12.13653755], [93.0969162, 12.13688183], [93.09739685, 12.13688183], [93.09748077, 12.13715839], [93.09793091, 12.13719177]]], [[[92.96982574, 12.06400681], [92.96974182, 12.06394482], [92.96951294, 12.06414986], [92.96953583, 12.0643568], [92.96959686, 12.06448078], [92.96951294, 12.06470776], [92.9694519, 12.06484985], [92.96946716, 12.06496143], [92.96954346, 12.064991], [92.96976471, 12.06507969], [92.96987152, 12.06520081], [92.9702301, 12.06527138], [92.97052002, 12.06529045], [92.97090149, 12.06529045], [92.97106934, 12.06520081], [92.97108459, 12.06425476], [92.97052002, 12.06423378], [92.97012329, 12.06423378], [92.96990967, 12.06414986], [92.96982574, 12.06400681]]], [[[92.94863129, 12.11584091], [92.94890594, 12.11526203], [92.9491272, 12.11526203], [92.94919586, 12.11444187], [92.94967651, 12.1144619], [92.95027161, 12.11388111], [92.95030975, 12.11330032], [92.95083618, 12.11330223], [92.95089722, 12.11272335], [92.95140839, 12.11274433], [92.95142365, 12.11226273], [92.9519577, 12.11220264], [92.95230103, 12.11164474], [92.95281219, 12.11166286], [92.95289612, 12.11075211], [92.95330048, 12.11056519], [92.95336151, 12.10985088], [92.95353699, 12.10958004], [92.95391083, 12.10945034], [92.95417786, 12.10916996], [92.954216, 12.10818958], [92.9550705, 12.10746098], [92.95517731, 12.10674858], [92.95529175, 12.1066103], [92.95585632, 12.10609055], [92.95598602, 12.10571003], [92.95641327, 12.10556889], [92.95651245, 12.10488129], [92.95667267, 12.10470963], [92.95685577, 12.10368156], [92.95695496, 12.10329247], [92.95708466, 12.10291767], [92.95723724, 12.10276985], [92.95741272, 12.10229778], [92.95748138, 12.10219097], [92.95750427, 12.10077572], [92.95752716, 12.10033131], [92.95757294, 12.10000134], [92.95782471, 12.0990572], [92.95781708, 12.09848118], [92.95768738, 12.09786129], [92.95746613, 12.09689045], [92.95729065, 12.09654999], [92.95717621, 12.09615135], [92.95696259, 12.09579086], [92.95664215, 12.0954113], [92.95627594, 12.09502125], [92.95584869, 12.09464931], [92.95540619, 12.09429836], [92.95497894, 12.09398174], [92.95456696, 12.09373093], [92.95417786, 12.09350109], [92.95276642, 12.09222031], [92.95249939, 12.09222221], [92.9513855, 12.09111214], [92.9513855, 12.09083366], [92.95111084, 12.09055614], [92.95111084, 12.0886097], [92.95139313, 12.08832932], [92.9513855, 12.08777809], [92.95166779, 12.08749962], [92.95166779, 12.08722019], [92.95194244, 12.08694363], [92.95194244, 12.08638763], [92.9522171, 12.08611202], [92.9522171, 12.08555984], [92.95249939, 12.08528042], [92.95249939, 12.08444118], [92.95194244, 12.08388996], [92.95166779, 12.08388996], [92.95111084, 12.08444405], [92.95111084, 12.08472157], [92.95082855, 12.08500195], [92.95082855, 12.08528042], [92.95053864, 12.08555984], [92.95053864, 12.08638954], [92.95027924, 12.08666992], [92.95027924, 12.08749962], [92.94999695, 12.08778], [92.94999695, 12.08805561], [92.94972229, 12.08832932], [92.94972229, 12.09138966], [92.94967651, 12.09177113], [92.94967651, 12.09224987], [92.9495163, 12.09274197], [92.94944763, 12.09329987], [92.94940186, 12.09388828], [92.94921112, 12.09440136], [92.94918823, 12.09492779], [92.9492569, 12.0954113], [92.94915771, 12.09581184], [92.9489975, 12.09615135], [92.94890594, 12.0965004], [92.94889069, 12.09691048], [92.94889069, 12.097332], [92.94889069, 12.0977993], [92.94889069, 12.09832096], [92.94892883, 12.09889126], [92.9491272, 12.0994606], [92.94916534, 12.10006046], [92.94917297, 12.10064983], [92.94916534, 12.10123825], [92.94917297, 12.1018219], [92.94917297, 12.10240078], [92.94917297, 12.1029501], [92.94919586, 12.10344028], [92.94937134, 12.10384083], [92.94944, 12.10419178], [92.94944763, 12.10451603], [92.94944763, 12.10484886], [92.94944, 12.10522938], [92.94944763, 12.10567093], [92.94949341, 12.10617065], [92.94967651, 12.10668087], [92.94975281, 12.10725975], [92.94996643, 12.10773945], [92.95007324, 12.11104107], [92.94966125, 12.11107063], [92.94974518, 12.1119051], [92.94921875, 12.11218262], [92.94919586, 12.11326122], [92.94832611, 12.11392021], [92.94834137, 12.11584091], [92.94863129, 12.11584091]]], [[[92.99136353, 12.10892773], [92.99154663, 12.10807133], [92.99214935, 12.10723495], [92.99256897, 12.10696125], [92.9930191, 12.10676098], [92.99362183, 12.10712147], [92.99373627, 12.10725117], [92.9940033, 12.10733128], [92.99414063, 12.10733128], [92.99447632, 12.10729027], [92.99479675, 12.10722065], [92.99504852, 12.10709953], [92.99544525, 12.1069746], [92.99578094, 12.10678959], [92.9961319, 12.10662174], [92.99693298, 12.10635471], [92.99730682, 12.10617065], [92.99732971, 12.10581017], [92.99783325, 12.10558891], [92.99840546, 12.10551357], [92.99908447, 12.10562134], [92.99965668, 12.10540676], [93.0, 12.10527706], [93.00055695, 12.10528183], [93.0008316, 12.1055603], [93.00138855, 12.10500145], [93.00166321, 12.10527706], [93.0018158, 12.10538387], [93.00209808, 12.10534477], [93.00273895, 12.1049509], [93.00305176, 12.10499001], [93.00314331, 12.10500145], [93.00332642, 12.10500145], [93.00389099, 12.10444069], [93.00416565, 12.10444546], [93.00499725, 12.10361099], [93.00499725, 12.103055], [93.00527954, 12.1027813], [93.00527954, 12.09917068], [93.00479126, 12.09868145], [93.00417328, 12.09806061], [93.00417328, 12.09776974], [93.00389099, 12.0975008], [93.00389099, 12.09722042], [93.0036087, 12.09694481], [93.0036087, 12.09472179], [93.00389099, 12.09444427], [93.0036087, 12.0941658], [93.0036087, 12.09389114], [93.00250244, 12.09278107], [93.00250244, 12.09249973], [93.00222015, 12.09222031], [93.00222015, 12.09166622], [93.00193787, 12.09138966], [93.00193787, 12.08943939], [93.00222015, 12.08916569], [93.00193787, 12.08890247], [93.00193787, 12.08832932], [93.00166321, 12.08805561], [93.00164795, 12.08778], [93.00138855, 12.08749962], [93.00138855, 12.08722019], [93.00111389, 12.08694363], [93.00111389, 12.08666801], [93.0008316, 12.08638954], [93.0008316, 12.08444118], [93.00055695, 12.08416462], [93.00055695, 12.08111095], [93.0008316, 12.08083057], [93.0008316, 12.07916737], [93.00055695, 12.07888889], [93.00055695, 12.0775013], [93.00026703, 12.0775013], [93.00026703, 12.07722092], [93.00027466, 12.0769453], [93.00166321, 12.07527733], [93.00164795, 12.07444], [93.00139618, 12.07402611], [93.00118256, 12.07376099], [93.0, 12.07417107], [92.99973297, 12.07374096], [92.99967194, 12.07353973], [92.99946594, 12.07328892], [92.99928284, 12.07303047], [92.99913788, 12.07269001], [92.99894714, 12.07232094], [92.99893188, 12.07188129], [92.99910736, 12.07146168], [92.99935913, 12.07108116], [92.9996109, 12.0707798], [92.99973297, 12.07049274], [93.0, 12.07027912], [93.00055695, 12.07000065], [93.00055695, 12.0694418], [93.00067902, 12.06849575], [93.00055695, 12.06806087], [93.00055695, 12.06721973], [93.00027466, 12.06722164], [93.0, 12.06694412], [92.99966431, 12.06663704], [92.99938965, 12.06659985], [92.99913788, 12.06642246], [92.99884796, 12.06632423], [92.99861908, 12.06613541], [92.99835205, 12.06592083], [92.9981308, 12.0656004], [92.99806213, 12.06517601], [92.99809265, 12.06476116], [92.99830627, 12.0644598], [92.99848175, 12.06421185], [92.998703, 12.06406116], [92.99889374, 12.06388092], [92.99926758, 12.06365967], [93.0, 12.06306076], [93.0008316, 12.06306076], [93.00164795, 12.06221962], [93.00166321, 12.06166553], [93.00138855, 12.06138992], [93.00138855, 12.06110954], [93.00111389, 12.06083393], [93.00111389, 12.06027794], [93.0008316, 12.06000042], [93.0008316, 12.05972195], [93.00055695, 12.05944443], [93.00027466, 12.05944061], [93.0, 12.05916786], [92.99958038, 12.05902195], [92.99944305, 12.05846977], [93.0, 12.05778027], [93.00026703, 12.05750179], [93.0, 12.05667019], [92.99973297, 12.05637074], [92.99973297, 12.05622101], [92.99950409, 12.05587482], [92.99928284, 12.05544376], [92.99919128, 12.05492401], [92.99919128, 12.05440044], [92.99928284, 12.05393028], [92.99941254, 12.05355358], [92.9994812, 12.05323124], [92.99952698, 12.05289555], [92.99967957, 12.05268764], [92.99973297, 12.05237198], [93.0, 12.05194473], [93.00111389, 12.05166721], [93.00110626, 12.05139065], [93.00138855, 12.05111122], [93.00138855, 12.05083275], [93.00111389, 12.05055523], [93.00110626, 12.05028152], [93.0008316, 12.05000114], [93.0008316, 12.04971886], [93.0, 12.04972267], [92.99972534, 12.04914665], [92.99973297, 12.04856968], [92.99958038, 12.04796124], [92.9993515, 12.04753113], [92.99915314, 12.04723167], [92.99894714, 12.04698086], [92.99879456, 12.04669189], [92.99858856, 12.04639053], [92.99833679, 12.04611301], [92.99806213, 12.0458374], [92.99780273, 12.04557133], [92.99753571, 12.04532909], [92.9972229, 12.04515076], [92.9969101, 12.04496193], [92.99659729, 12.0447197], [92.9962616, 12.04451466], [92.99584961, 12.04441261], [92.99546814, 12.04421043], [92.99497986, 12.04412079], [92.99449158, 12.04393578], [92.99391937, 12.04384995], [92.99334717, 12.0436697], [92.99277496, 12.04361725], [92.99221039, 12.04365158], [92.99169159, 12.04382896], [92.99119568, 12.04393196], [92.99079895, 12.0441227], [92.99041748, 12.04433537], [92.99006653, 12.04465389], [92.98970032, 12.04499245], [92.98932648, 12.04531097], [92.98905182, 12.04566193], [92.98879242, 12.04593086], [92.98855591, 12.04611969], [92.98834229, 12.04627037], [92.98832703, 12.04639053], [92.98805237, 12.04638863], [92.98777771, 12.0466671], [92.98750305, 12.0466671], [92.98694611, 12.04722309], [92.98664856, 12.04722118], [92.98638916, 12.04750061], [92.98638916, 12.04778099], [92.9861145, 12.0480547], [92.9861145, 12.04833317], [92.98500061, 12.04944515], [92.98472595, 12.04944515], [92.98444366, 12.04972267], [92.98416901, 12.04971886], [92.98361206, 12.05028152], [92.98194122, 12.05028152], [92.98166656, 12.05000114], [92.98110962, 12.05000114], [92.98027802, 12.05083275], [92.97982025, 12.05136204], [92.97976685, 12.05204105], [92.97994995, 12.05269527], [92.98000336, 12.05335236], [92.98000336, 12.05398273], [92.97989655, 12.05456161], [92.97955322, 12.05504036], [92.97917175, 12.05556011], [92.97878265, 12.05609989], [92.97834778, 12.05663109], [92.97787476, 12.05711174], [92.97740173, 12.05753136], [92.97702789, 12.057971], [92.97670746, 12.05836105], [92.97646332, 12.05871201], [92.97633362, 12.05906105], [92.97616577, 12.05933189], [92.97603607, 12.05962086], [92.97605896, 12.0601387], [92.97598267, 12.06057167], [92.97574615, 12.06086063], [92.97548676, 12.06097984], [92.97541809, 12.06087971], [92.9753418, 12.06078243], [92.97535706, 12.06041908], [92.97537994, 12.06001091], [92.97528076, 12.05978966], [92.97505951, 12.05964947], [92.974823, 12.0594511], [92.97454071, 12.0592804], [92.97422791, 12.05922699], [92.97386932, 12.0593996], [92.9734726, 12.0595417], [92.97318268, 12.05986118], [92.97307587, 12.06035137], [92.97315216, 12.06090927], [92.97329712, 12.06147385], [92.9733429, 12.06206226], [92.97341919, 12.0626297], [92.97368622, 12.06313133], [92.97399902, 12.06352997], [92.97440338, 12.06387043], [92.97473907, 12.06422138], [92.97499847, 12.06459904], [92.97519684, 12.064991], [92.97524261, 12.06538105], [92.97509003, 12.06571102], [92.97486877, 12.06580925], [92.97457886, 12.06563187], [92.97415161, 12.0652256], [92.97360229, 12.06468964], [92.97305298, 12.06455135], [92.97264862, 12.06483173], [92.97225952, 12.06517982], [92.97196198, 12.06559086], [92.97164154, 12.06602097], [92.97160339, 12.06623077], [92.97114563, 12.06686687], [92.97080994, 12.06707191], [92.97033691, 12.06735039], [92.96981812, 12.06765079], [92.96931458, 12.06787872], [92.9688797, 12.06808186], [92.96845245, 12.06812859], [92.96807861, 12.06812859], [92.96779633, 12.06808186], [92.96695709, 12.06821156], [92.96656799, 12.06827068], [92.96640015, 12.06827068], [92.96595764, 12.06812859], [92.96568298, 12.06804085], [92.96522522, 12.06812668], [92.96411133, 12.06858063], [92.96395111, 12.06902122], [92.96385956, 12.0693903], [92.96369171, 12.0694313], [92.96305847, 12.07137012], [92.9622879, 12.07186985], [92.96182251, 12.07220173], [92.96179962, 12.07281971], [92.96178436, 12.07349873], [92.96177673, 12.07395267], [92.96174622, 12.07433987], [92.96163177, 12.07495117], [92.96163177, 12.07532024], [92.96109009, 12.07620716], [92.96089935, 12.07651043], [92.96092224, 12.076931], [92.96116638, 12.07755089], [92.96117401, 12.07777691], [92.96112823, 12.07828999], [92.96111298, 12.07852173], [92.96070862, 12.07918072], [92.96047974, 12.07962132], [92.9604187, 12.08025742], [92.96050262, 12.08073139], [92.96039581, 12.08091831], [92.960289, 12.08138943], [92.96064758, 12.08264065], [92.96123505, 12.08304596], [92.96167755, 12.08327389], [92.96234894, 12.08390999], [92.9626236, 12.08407879], [92.96312714, 12.0841608], [92.96356201, 12.08437061], [92.96383667, 12.08447075], [92.96486664, 12.08499146], [92.96543121, 12.08520031], [92.96566772, 12.08520031], [92.96589661, 12.08522129], [92.96631622, 12.08525658], [92.96666718, 12.08543873], [92.96694183, 12.08553123], [92.96723938, 12.08561039], [92.96755219, 12.08569241], [92.9679718, 12.08571339], [92.96819305, 12.08573055], [92.96832275, 12.0858202], [92.96847534, 12.08592033], [92.96864319, 12.0860796], [92.96887207, 12.08623028], [92.96914673, 12.08623028], [92.96936035, 12.08615112], [92.96946716, 12.08586979], [92.9699173, 12.08605003], [92.97027588, 12.08631706], [92.9705658, 12.08663082], [92.97077942, 12.08701038], [92.97084808, 12.08745193], [92.97084045, 12.08789635], [92.97077942, 12.08829975], [92.97060394, 12.0886097], [92.97055054, 12.08895206], [92.9704895, 12.08927059], [92.9703598, 12.08953953], [92.97027588, 12.08981991], [92.97016907, 12.09008694], [92.96999359, 12.09029198], [92.96977997, 12.09050369], [92.96950531, 12.09072018], [92.96910858, 12.09080219], [92.96864319, 12.09072018], [92.96816254, 12.09053135], [92.96772003, 12.09027958], [92.96730042, 12.09002972], [92.96684265, 12.0898838], [92.96639252, 12.08974457], [92.96591949, 12.08973789], [92.96544647, 12.08990192], [92.96511841, 12.09041023], [92.96501923, 12.09101009], [92.96507263, 12.09152317], [92.96526337, 12.09188938], [92.96541595, 12.09225178], [92.96549988, 12.09261036], [92.96537018, 12.09296513], [92.96540833, 12.09340286], [92.96556091, 12.09375191], [92.96562195, 12.0941124], [92.96543121, 12.09429169], [92.96515656, 12.09429169], [92.96469879, 12.09412956], [92.96450806, 12.0941124], [92.96411133, 12.09417057], [92.96362305, 12.09417057], [92.96351624, 12.09412956], [92.9628067, 12.09368992], [92.96266174, 12.0934639], [92.96234894, 12.09307194], [92.96190643, 12.09274197], [92.96092224, 12.09309101], [92.96069336, 12.0935297], [92.96060181, 12.09381962], [92.96056366, 12.09420967], [92.96064758, 12.09460163], [92.96082306, 12.09491158], [92.96137238, 12.09504604], [92.96161652, 12.09515095], [92.96187592, 12.0959301], [92.96170044, 12.09651184], [92.96166229, 12.09705639], [92.96166229, 12.09755135], [92.96166992, 12.0980196], [92.96164703, 12.09849739], [92.96156311, 12.09899139], [92.96142578, 12.09949017], [92.96154022, 12.09999943], [92.96173096, 12.10037231], [92.96168518, 12.1009922], [92.96151733, 12.10132122], [92.96112061, 12.10184002], [92.96058655, 12.10185432], [92.96002197, 12.10369968], [92.96017456, 12.10408497], [92.96017456, 12.10433388], [92.96005249, 12.10459995], [92.95983887, 12.1048708], [92.95973206, 12.10555077], [92.95963287, 12.10608768], [92.95960999, 12.10648346], [92.95964813, 12.1068306], [92.95973206, 12.10718536], [92.96062469, 12.1076746], [92.96112823, 12.10790253], [92.96173096, 12.10792255], [92.96221924, 12.10777664], [92.96250153, 12.10750198], [92.96305847, 12.10750198], [92.96333313, 12.10722065], [92.96389008, 12.10722065], [92.9642334, 12.10733509], [92.96460724, 12.10752201], [92.96489716, 12.10789108], [92.9650116, 12.10807991], [92.96515656, 12.10837173], [92.96527863, 12.10867977], [92.96540833, 12.10894871], [92.9655304, 12.10915184], [92.96576691, 12.10931969], [92.96616364, 12.1094017], [92.96639252, 12.10931778], [92.96669769, 12.10915184], [92.96728516, 12.10844135], [92.96769714, 12.10801029], [92.96806335, 12.10757446], [92.96839905, 12.10714817], [92.96869659, 12.10674], [92.96910095, 12.10647964], [92.96929169, 12.10644245], [92.96955872, 12.10644245], [92.96989441, 12.10638046], [92.970047, 12.10601139], [92.970047, 12.10558891], [92.97001648, 12.10505581], [92.9702301, 12.10474396], [92.97038269, 12.10445213], [92.97058868, 12.10420132], [92.97116852, 12.10412598], [92.97138214, 12.10380173], [92.97175598, 12.10361099], [92.97226715, 12.10334015], [92.9727478, 12.10305023], [92.9731369, 12.10271072], [92.97345734, 12.10243034], [92.97374725, 12.10228729], [92.97403717, 12.10230064], [92.9743576, 12.10239601], [92.97476196, 12.1025238], [92.97522736, 12.10264492], [92.9757309, 12.10269928], [92.97621918, 12.10282516], [92.97666931, 12.1030407], [92.97703552, 12.10334396], [92.97720337, 12.10370445], [92.97712708, 12.10400963], [92.97686768, 12.10402107], [92.97648621, 12.10384083], [92.97602081, 12.10361958], [92.97550964, 12.10347652], [92.97489166, 12.10345173], [92.9741745, 12.1036377], [92.97373199, 12.10397339], [92.97355652, 12.10447025], [92.97351074, 12.10471916], [92.97373962, 12.10509014], [92.97387695, 12.10526085], [92.97399902, 12.10534096], [92.97438812, 12.10535908], [92.97470856, 12.10544109], [92.9748764, 12.10555077], [92.9750824, 12.10566902], [92.97525024, 12.10572624], [92.97536469, 12.10576344], [92.97564697, 12.10583973], [92.97589111, 12.1058197], [92.9763031, 12.10567093], [92.97663879, 12.10558891], [92.97711945, 12.10548019], [92.97764587, 12.10558701], [92.97783661, 12.10573101], [92.97801971, 12.10587692], [92.97828674, 12.10604095], [92.97854614, 12.10616589], [92.97885895, 12.10639191], [92.97917938, 12.10652161], [92.97960663, 12.10645962], [92.97988892, 12.10643005], [92.98020172, 12.10641384], [92.98052216, 12.10628891], [92.98117828, 12.10612011], [92.98156738, 12.10619259], [92.98192596, 12.10636425], [92.98233795, 12.10652161], [92.9825058, 12.10673809], [92.98266602, 12.10718918], [92.98288727, 12.1076107], [92.98309326, 12.10800076], [92.98342896, 12.10828972], [92.98391724, 12.10859776], [92.98457336, 12.10877991], [92.98509216, 12.10900974], [92.98562622, 12.1091404], [92.98606873, 12.1091814], [92.98654175, 12.10921955], [92.98678589, 12.10924053], [92.98725128, 12.10924053], [92.98777771, 12.1091404], [92.98796082, 12.10926056], [92.98819733, 12.10934067], [92.9884491, 12.10936069], [92.98859406, 12.10927868], [92.98918152, 12.10890961], [92.98945618, 12.10890961], [92.98969269, 12.10895061], [92.98987579, 12.10903072], [92.99008942, 12.10949135], [92.99027252, 12.1096096], [92.9905777, 12.1096096], [92.99069214, 12.10929966], [92.99085999, 12.10908985], [92.99105072, 12.10898972], [92.99136353, 12.10892773]]], [[[92.96231079, 12.12280083], [92.96212769, 12.12341022], [92.96192932, 12.12392044], [92.96168518, 12.12436295], [92.96147919, 12.12479115], [92.96134949, 12.12524033], [92.96115875, 12.12564564], [92.96109772, 12.12613297], [92.96101379, 12.1266098], [92.96086884, 12.1270504], [92.96082306, 12.12753105], [92.96073151, 12.12801075], [92.96059418, 12.12850571], [92.96055603, 12.12905121], [92.96050262, 12.12961102], [92.960289, 12.13012028], [92.96006012, 12.13064575], [92.95989227, 12.13119125], [92.9596405, 12.13161659], [92.95936584, 12.13195419], [92.95910645, 12.13228035], [92.95886993, 12.13263607], [92.95861053, 12.13297081], [92.95833588, 12.13330078], [92.95805359, 12.13362026], [92.95778656, 12.13395119], [92.95752716, 12.13452053], [92.95728302, 12.13512039], [92.95717621, 12.13549232], [92.95700836, 12.1359272], [92.95694733, 12.13646317], [92.95691681, 12.13677025], [92.95684052, 12.13719177], [92.95661163, 12.13751793], [92.95635986, 12.1380558], [92.9564209, 12.13859081], [92.9565506, 12.13936234], [92.95662689, 12.13975143], [92.9565506, 12.14025021], [92.95620728, 12.14087009], [92.95585632, 12.14134407], [92.95560455, 12.14219189], [92.95565033, 12.14289188], [92.9557724, 12.1438446], [92.95583344, 12.14472198], [92.95582581, 12.14610958], [92.95610809, 12.14638805], [92.95610809, 12.14694405], [92.95639038, 12.14721966], [92.95639038, 12.14750004], [92.95667267, 12.14750004], [92.95675659, 12.14788055], [92.95697784, 12.14814091], [92.95723724, 12.14835739], [92.9575119, 12.14858055], [92.95786285, 12.14877033], [92.95825195, 12.14893246], [92.95865631, 12.14912796], [92.95910645, 12.14927959], [92.95956421, 12.14941692], [92.95995331, 12.14960384], [92.96035004, 12.14976978], [92.96067047, 12.15000534], [92.96098328, 12.15023994], [92.9613266, 12.15044022], [92.96170044, 12.15052891], [92.96209717, 12.15056133], [92.96247864, 12.1505909], [92.962883, 12.15069103], [92.96330261, 12.15078545], [92.96376038, 12.1506958], [92.96429443, 12.15057278], [92.96490479, 12.15047741], [92.96547699, 12.15027046], [92.96601868, 12.15000057], [92.96649933, 12.14972019], [92.9669342, 12.14949226], [92.96737671, 12.14940262], [92.96775055, 12.1492281], [92.96816254, 12.14917088], [92.96859741, 12.1491642], [92.96904755, 12.14914131], [92.96946716, 12.14901066], [92.9699173, 12.14888191], [92.97038269, 12.14877415], [92.97086334, 12.14860058], [92.97135925, 12.14840126], [92.97192383, 12.14834118], [92.97249603, 12.14832973], [92.97306061, 12.14833164], [92.97357178, 12.14831161], [92.97400665, 12.14820004], [92.97441101, 12.14808178], [92.97483826, 12.1480608], [92.97531128, 12.14805031], [92.97585297, 12.14805031], [92.9764328, 12.14806557], [92.97698212, 12.14813232], [92.97744751, 12.14828682], [92.97770691, 12.14831161], [92.97789001, 12.14825153], [92.97814941, 12.1480341], [92.97837067, 12.14781857], [92.97860718, 12.14781857], [92.97890472, 12.14811802], [92.97929382, 12.14847374], [92.97966766, 12.1485424], [92.9800415, 12.14838219], [92.98045349, 12.14833546], [92.98083496, 12.14830303], [92.98090363, 12.14824963], [92.98108673, 12.14811134], [92.98136139, 12.14822292], [92.98150635, 12.14845276], [92.98194122, 12.14895439], [92.98213196, 12.1489954], [92.9824295, 12.1490593], [92.98329163, 12.14899063], [92.98397827, 12.14871979], [92.98443604, 12.14834118], [92.98498535, 12.14814091], [92.98539734, 12.14777184], [92.98583221, 12.14742088], [92.9862442, 12.14708138], [92.9866333, 12.1467104], [92.98699188, 12.14634037], [92.98737335, 12.14598179], [92.98771667, 12.14560032], [92.98805237, 12.14518929], [92.98838806, 12.14479733], [92.98873901, 12.14446926], [92.98911285, 12.14424992], [92.98948669, 12.14417267], [92.98986816, 12.14416599], [92.99025726, 12.14417267], [92.99069214, 12.14415932], [92.9911499, 12.14409065], [92.99154663, 12.14390182], [92.99192047, 12.14368057], [92.99220276, 12.14339256], [92.99241638, 12.14304543], [92.99259949, 12.14269066], [92.99278259, 12.14237022], [92.99292755, 12.14206028], [92.99304962, 12.1417141], [92.99315643, 12.14129734], [92.99330139, 12.14083195], [92.99333191, 12.14027977], [92.99328613, 12.13972378], [92.99308014, 12.13923645], [92.99291229, 12.13875103], [92.99279785, 12.13828754], [92.99278259, 12.13781166], [92.99278259, 12.13733959], [92.99277496, 12.13690186], [92.99278259, 12.13648319], [92.99284363, 12.13607502], [92.99304962, 12.13570976], [92.9932785, 12.1352911], [92.99359131, 12.13487911], [92.99391937, 12.13444138], [92.99427032, 12.13404179], [92.99450684, 12.13354969], [92.99474335, 12.13305092], [92.99494171, 12.13257885], [92.99495697, 12.13208389], [92.99481964, 12.13159943], [92.99474335, 12.13111115], [92.99476624, 12.13062954], [92.99494934, 12.13017178], [92.99508667, 12.12966156], [92.99529266, 12.12917233], [92.99555206, 12.12871838], [92.99555206, 12.12861061], [92.99583435, 12.12833309], [92.99583435, 12.12805462], [92.9963913, 12.12750053], [92.9963913, 12.12722111], [92.99666595, 12.12694454], [92.99666595, 12.12666702], [92.99694824, 12.12639141], [92.99694824, 12.12611103], [92.99777985, 12.12528133], [92.99777985, 12.12500095], [92.99887848, 12.12389088], [92.99887848, 12.12360954], [92.99945068, 12.12275791], [92.99973297, 12.12250137], [93.0, 12.1227808], [93.00026703, 12.12250137], [93.00026703, 12.12222004], [93.00027466, 12.12194443], [93.0008316, 12.12138844], [93.0008316, 12.12056065], [93.00110626, 12.12028122], [93.00110626, 12.11777973], [93.00164795, 12.11721992], [93.00250244, 12.11722183], [93.00305176, 12.11666584], [93.00305176, 12.11610985], [93.00333405, 12.11583424], [93.00332642, 12.11388969], [93.00389099, 12.11333179], [93.00416565, 12.1133337], [93.00428772, 12.11346054], [93.00465393, 12.11345673], [93.0046463, 12.11373043], [93.00492859, 12.11392879], [93.00492859, 12.11432076], [93.0052948, 12.11451912], [93.00528717, 12.11483097], [93.0056076, 12.11515045], [93.00537109, 12.11530495], [93.00556946, 12.11562157], [93.00556946, 12.11601353], [93.00521088, 12.11617088], [93.00521088, 12.11644745], [93.00553131, 12.11672115], [93.0052948, 12.11703682], [93.00528717, 12.11810017], [93.00497437, 12.11845493], [93.00497437, 12.11916447], [93.00476837, 12.11927986], [93.00481415, 12.11959743], [93.00440979, 12.11991119], [93.00444794, 12.12038136], [93.00413513, 12.12069988], [93.00414276, 12.12176037], [93.00389099, 12.12203979], [93.00389099, 12.12270641], [93.0036087, 12.12290192], [93.0036087, 12.12333679], [93.00341034, 12.12356853], [93.00337219, 12.12432194], [93.00292969, 12.12443829], [93.0027771, 12.12444019], [93.0027771, 12.12555695], [93.0027771, 12.12925053], [93.00254059, 12.12936974], [93.00250244, 12.1297226], [93.00245667, 12.13094044], [93.00229645, 12.13121796], [93.00229645, 12.13184738], [93.00197601, 12.13212109], [93.00193787, 12.13390064], [93.00254059, 12.13453197], [93.00254059, 12.13511562], [93.0027771, 12.13527107], [93.0027771, 12.13601971], [93.0027771, 12.13645554], [93.0027771, 12.13694572], [93.00332642, 12.13749981], [93.00332642, 12.13778019], [93.0036087, 12.1380558], [93.0036087, 12.13833141], [93.00389099, 12.13861179], [93.00409698, 12.13862133], [93.00409698, 12.13936806], [93.00417328, 12.13944054], [93.00444794, 12.13972569], [93.0047226, 12.14001083], [93.00492096, 12.14000034], [93.00495911, 12.14043045], [93.00520325, 12.14066982], [93.00520325, 12.14098358], [93.00556183, 12.14114189], [93.00552368, 12.14192772], [93.00588226, 12.14232159], [93.00588226, 12.14303112], [93.00604248, 12.14320183], [93.00608063, 12.14400005], [93.00659943, 12.14498425], [93.00668335, 12.1455307], [93.00668335, 12.14605141], [93.007164, 12.14671612], [93.0078125, 12.14747143], [93.0078125, 12.14783096], [93.00829315, 12.14799023], [93.00858307, 12.14831161], [93.00857544, 12.14865589], [93.00860596, 12.14888191], [93.01000214, 12.15028095], [93.01000214, 12.15055656], [93.01043701, 12.15098953], [93.0110321, 12.15111065], [93.01119232, 12.1514616], [93.01239777, 12.15174007], [93.01275635, 12.15213203], [93.01280975, 12.15219784], [93.01304626, 12.15250111], [93.01333618, 12.15250111], [93.01361084, 12.15278053], [93.01387787, 12.15278053], [93.01416779, 12.15306091], [93.01444244, 12.15305519], [93.01472473, 12.15333271], [93.01499939, 12.15333271], [93.01527405, 12.15361118], [93.01555634, 12.15361118], [93.01564789, 12.15370369], [93.01583099, 12.15389061], [93.01611328, 12.15389061], [93.01638794, 12.15417099], [93.01667023, 12.15416718], [93.01721954, 12.15472317], [93.01750183, 12.15472126], [93.01805878, 12.15528107], [93.01832581, 12.15528107], [93.01944733, 12.15639114], [93.01972198, 12.15638924], [93.02027893, 12.15694523], [93.02054596, 12.15694141], [93.02076721, 12.15716171], [93.02113342, 12.15716171], [93.02113342, 12.15759468], [93.02185059, 12.15830135], [93.02188873, 12.15881443], [93.02213287, 12.15889072], [93.02217102, 12.15928555], [93.02249146, 12.1594429], [93.02245331, 12.16038036], [93.02272797, 12.1605854], [93.02272797, 12.16192341], [93.02278137, 12.16222095], [93.02278137, 12.16277695], [93.02333069, 12.16333389], [93.02333069, 12.16361237], [93.02500153, 12.16527843], [93.02561951, 12.16549015], [93.02613831, 12.16576958], [93.02654266, 12.16581059], [93.02713013, 12.16631889], [93.0273819, 12.16648102], [93.02749634, 12.16666985], [93.0283432, 12.16583061], [93.02833557, 12.16555595], [93.02944183, 12.16444111], [93.02944183, 12.16416454], [93.02971649, 12.16389179], [93.02944183, 12.16361237], [93.02944183, 12.16333389], [93.02916718, 12.16305542], [93.02916718, 12.16249943], [93.02889252, 12.16222095], [93.02889252, 12.16166687], [93.02861023, 12.16138935], [93.02861023, 12.16111088], [93.0283432, 12.16082191], [93.02833557, 12.16027737], [93.02805328, 12.15999889], [93.02805328, 12.15944099], [93.02833557, 12.15916729], [93.0283432, 12.15804958], [93.02805328, 12.15777683], [93.02805328, 12.15722084], [93.02777863, 12.15694141], [93.02777863, 12.15638924], [93.02749634, 12.15610886], [93.02749634, 12.15527916], [93.02722168, 12.15501022], [93.02722168, 12.15195179], [93.02749634, 12.15167141], [93.02749634, 12.15056133], [93.02722168, 12.15028095], [93.02722168, 12.14888191], [93.02694702, 12.14861012], [93.02694702, 12.14778137], [93.02722168, 12.14750004], [93.02722168, 12.14694023], [93.02749634, 12.14666557], [93.02749634, 12.14610958], [93.02777863, 12.14583206], [93.02777863, 12.14555645], [93.0283432, 12.14500046], [93.02833557, 12.14444447], [93.02861023, 12.14416599], [93.02861023, 12.14361], [93.0283432, 12.14332962], [93.02833557, 12.14305592], [93.02778625, 12.14251995], [93.02758026, 12.14254093], [93.02752686, 12.14239693], [93.02749634, 12.14230156], [93.02685547, 12.1421442], [93.02688599, 12.14188004], [93.02610779, 12.14111233], [93.02610779, 12.13889027], [93.02639008, 12.13861179], [93.02639008, 12.13833141], [93.02722168, 12.13749981], [93.02749634, 12.13749981], [93.02777863, 12.13722134], [93.02805328, 12.13722134], [93.02805328, 12.13694572], [93.02916718, 12.13583279], [93.02944183, 12.13583279], [93.03055573, 12.1347208], [93.03055573, 12.1338892], [93.03083038, 12.13361073], [93.03083038, 12.13306046], [93.03111267, 12.13278198], [93.03111267, 12.13194084], [93.03138733, 12.13166714], [93.03138733, 12.13111115], [93.03166962, 12.13083267], [93.03166962, 12.13028145], [93.0319519, 12.13000107], [93.0319519, 12.12972069], [93.03221893, 12.12944508], [93.03221893, 12.1291666], [93.03250122, 12.12889099], [93.03250122, 12.12861061], [93.03277588, 12.12833309], [93.03277588, 12.12805462], [93.03305817, 12.12778091], [93.03305817, 12.12722111], [93.03333282, 12.12694454], [93.03360748, 12.12694454], [93.03388977, 12.12666702], [93.0341568, 12.12667084], [93.03501129, 12.1258297], [93.03500366, 12.12555695], [93.03527832, 12.12528133], [93.03527832, 12.12389088], [93.03388977, 12.12250137], [93.03388977, 12.12222004], [93.03360748, 12.12194443], [93.03360748, 12.12138844], [93.03333282, 12.12110996], [93.03333282, 12.12028122], [93.03305817, 12.12000275], [93.03305817, 12.11944199], [93.03221893, 12.11861229], [93.03221893, 12.11833191], [93.03194427, 12.1180563], [93.0319519, 12.11639023], [93.03166962, 12.11610985], [93.03194427, 12.11583424], [93.0319519, 12.11528015], [93.03221893, 12.11499977], [93.03221893, 12.11472034], [93.03194427, 12.11444378], [93.03194427, 12.11388779], [93.03166962, 12.11361027], [93.03166962, 12.11250019], [93.0319519, 12.11221886], [93.03194427, 12.11139011], [93.03166962, 12.11111164], [93.03166962, 12.11028194], [93.0319519, 12.11000156], [93.0319519, 12.1094389], [93.03221893, 12.10916805], [93.03221893, 12.1086092], [93.03250122, 12.10833263], [93.03250122, 12.10805511], [93.03277588, 12.10778046], [93.03277588, 12.10722065], [93.03305817, 12.10694313], [93.03305817, 12.10666656], [93.03333282, 12.10639191], [93.03333282, 12.10583115], [93.03360748, 12.10555458], [93.03360748, 12.10528183], [93.03388977, 12.10500145], [93.03388977, 12.10472107], [93.03416443, 12.10444546], [93.03416443, 12.10416698], [93.03472137, 12.10361099], [93.03472137, 12.10333061], [93.03527832, 12.10277653], [93.03501129, 12.10250092], [93.03501129, 12.10194016], [93.03472137, 12.1016674], [93.03472137, 12.10083961], [93.03444672, 12.10055923], [93.03444672, 12.10028076], [93.03472137, 12.10000134], [93.03472137, 12.09943962], [93.03500366, 12.09916687], [93.03501129, 12.09861088], [93.03555298, 12.09805679], [93.03555298, 12.09776974], [93.03833008, 12.09500027], [93.03833008, 12.0947113], [93.03888702, 12.0941658], [93.03888702, 12.09389114], [93.03916931, 12.09361172], [93.03916931, 12.09333038], [93.03944397, 12.09305573], [93.03943634, 12.09278107], [93.04083252, 12.09138966], [93.04083252, 12.09111023], [93.04111481, 12.09083366], [93.04111481, 12.09055614], [93.04138947, 12.09027958], [93.04138947, 12.09000015], [93.04165649, 12.08972168], [93.04166412, 12.08916569], [93.04222107, 12.0886097], [93.04222107, 12.08832932], [93.04333496, 12.0872221], [93.04360962, 12.0872221], [93.04389191, 12.08694363], [93.04416656, 12.08694363], [93.04416656, 12.08666801], [93.04499817, 12.08583164], [93.04499817, 12.08555603], [93.04638672, 12.08417034], [93.04666901, 12.08417034], [93.04695129, 12.08389187], [93.0477829, 12.08389187], [93.04805756, 12.08361244], [93.04888916, 12.08361244], [93.04944611, 12.08305645], [93.04944611, 12.0827713], [93.05000305, 12.08222103], [93.05000305, 12.08138943], [93.05027771, 12.08111095], [93.05027771, 12.08055973], [93.05110931, 12.07973003], [93.05110931, 12.07944107], [93.0513916, 12.07916737], [93.0513916, 12.07861137], [93.0533371, 12.07666683], [93.0533371, 12.07639122], [93.05361176, 12.07611084], [93.05361176, 12.07555866], [93.05278015, 12.07472134], [93.05222321, 12.07472324], [93.05194092, 12.07444477], [93.05166626, 12.07444477], [93.0513916, 12.07416725], [93.0513916, 12.07359886], [93.05110931, 12.07333279], [93.05110931, 12.07250118], [93.05166626, 12.07194042], [93.05166626, 12.0713892], [93.05278015, 12.07028103], [93.05278015, 12.06972027], [93.05305481, 12.06944466], [93.05305481, 12.06833458], [93.05278015, 12.0680542], [93.05278015, 12.06694031], [93.05305481, 12.06666565], [93.05304718, 12.06556129], [93.05278015, 12.06528091], [93.05278015, 12.06499958], [93.05249786, 12.06473064], [93.05249786, 12.06444168], [93.05222321, 12.06416607], [93.05222321, 12.06306076], [93.05249786, 12.06278038], [93.05249786, 12.0625], [93.05304718, 12.06193924], [93.05305481, 12.06166553], [93.0533371, 12.06138992], [93.0533371, 12.06056023], [93.05304718, 12.06027985], [93.05304718, 12.06000042], [93.05249786, 12.05944061], [93.05249786, 12.05916786], [93.05166626, 12.05833054], [93.05166626, 12.05805588], [93.0513916, 12.05778027], [93.0513916, 12.05722237], [93.05166626, 12.0569458], [93.05166626, 12.05666542], [93.05194092, 12.05638981], [93.05194092, 12.05610943], [93.05166626, 12.05583382], [93.05166626, 12.05555534], [93.0513916, 12.05527973], [93.0513916, 12.05499935], [93.05110931, 12.05472088], [93.05110931, 12.05444336], [93.05083466, 12.05416679], [93.05082703, 12.05360889], [93.05027771, 12.05305481], [93.05027771, 12.05279064], [93.04998779, 12.05250072], [93.04998779, 12.0522213], [93.04972076, 12.05194473], [93.04972076, 12.05111122], [93.04944611, 12.05083275], [93.04895782, 12.05001545], [93.04823303, 12.04891396], [93.04763794, 12.04824448], [93.04711914, 12.04792881], [93.04675293, 12.04789066], [93.04654694, 12.04738045], [93.04555511, 12.04638863], [93.04556274, 12.04582977], [93.0455246, 12.0453701], [93.04453278, 12.0453701], [93.0443573, 12.04553032], [93.04360962, 12.04560661], [93.04332733, 12.04580307], [93.04272461, 12.04572582], [93.04212952, 12.04577065], [93.04155731, 12.04572105], [93.04113007, 12.04607868], [93.04077148, 12.04655075], [93.04036713, 12.04761505], [93.04024506, 12.04828262], [93.04000092, 12.04833126], [93.03971863, 12.04861069], [93.03971863, 12.04916668], [93.03943634, 12.04971886], [93.03916931, 12.05000114], [93.03916931, 12.05027676], [93.03861237, 12.05083275], [93.03861237, 12.05111122], [93.03833008, 12.05139065], [93.03833008, 12.05166721], [93.03805542, 12.05194473], [93.03804779, 12.0522213], [93.03778076, 12.05250072], [93.03778076, 12.05277729], [93.03722382, 12.05333328], [93.03721619, 12.05360889], [93.03666687, 12.05416679], [93.03666687, 12.05444336], [93.03639221, 12.05472088], [93.03639221, 12.05499935], [93.03610992, 12.05527973], [93.03610992, 12.05555534], [93.03555298, 12.05610943], [93.03555298, 12.05778027], [93.03527832, 12.05805588], [93.03527832, 12.05860043], [93.03501129, 12.05889034], [93.03500366, 12.05916786], [93.03472137, 12.05944061], [93.03472137, 12.06000042], [93.03444672, 12.06027985], [93.03444672, 12.06055641], [93.03388977, 12.06110954], [93.03388977, 12.06138992], [93.03305817, 12.06222153], [93.03277588, 12.06222153], [93.02916718, 12.06583214], [93.02916718, 12.06610966], [93.02861023, 12.06666565], [93.02861023, 12.06694031], [93.02749634, 12.06806087], [93.02722168, 12.0680542], [93.02666473, 12.06861019], [93.02639008, 12.06861019], [93.02500153, 12.07000065], [93.02471924, 12.07000065], [93.02443695, 12.07028103], [93.02416992, 12.07028103], [93.02388763, 12.07056141], [93.02305603, 12.07055664], [93.02278137, 12.07083321], [93.02249908, 12.07083035], [93.0222168, 12.07111073], [93.02194214, 12.07111073], [93.02166748, 12.07139111], [93.02139282, 12.07139111], [93.02111053, 12.07167053], [93.02083588, 12.07166672], [93.02055359, 12.07194519], [93.01999664, 12.07194519], [93.01972198, 12.07222271], [93.01860809, 12.07222271], [93.01833344, 12.07194519], [93.01777649, 12.07194519], [93.01750183, 12.07222271], [93.01526642, 12.0722208], [93.01499939, 12.07250118], [93.01304626, 12.07250118], [93.01277924, 12.0722208], [93.01249695, 12.07222271], [93.01222229, 12.07194519], [93.01194763, 12.07194519], [93.01166534, 12.07166672], [93.01139069, 12.07167053], [93.0111084, 12.0713892], [93.01055908, 12.07194519], [93.01045227, 12.07238007], [93.00997925, 12.07254887], [93.00954437, 12.07286263], [93.00905609, 12.07357025], [93.00862122, 12.0740509], [93.00814056, 12.0745163], [93.00778198, 12.07475281], [93.00746155, 12.07530022], [93.00701904, 12.0757761], [93.00694275, 12.07608986], [93.00694275, 12.0769453], [93.00666809, 12.07722092], [93.00666809, 12.07805538], [93.0063858, 12.07833099], [93.0063858, 12.07888889], [93.00611115, 12.07916737], [93.00611115, 12.08333397], [93.0063858, 12.08361244], [93.0063858, 12.08444405], [93.00666809, 12.08472157], [93.00666809, 12.08666801], [93.00694275, 12.08694363], [93.00723267, 12.08718967], [93.00722504, 12.08974934], [93.00694275, 12.09010315], [93.0069809, 12.09139919], [93.00694275, 12.09195995], [93.00694275, 12.09361172], [93.00722504, 12.09388828], [93.00722504, 12.09444427], [93.00749969, 12.0947113], [93.00749969, 12.09500027], [93.00777435, 12.09527874], [93.00777435, 12.09583473], [93.0080719, 12.09611034], [93.00805664, 12.09666729], [93.0083313, 12.09694481], [93.0083313, 12.09832954], [93.00860596, 12.09861088], [93.00860596, 12.09995079], [93.00901031, 12.09995079], [93.00888824, 12.1012907], [93.00860596, 12.1012907], [93.00860596, 12.10166931], [93.00868988, 12.101861], [93.00863647, 12.10296059], [93.0083313, 12.10296059], [93.0083313, 12.10361099], [93.00830078, 12.10384083], [93.00830078, 12.10467052], [93.0080719, 12.10475063], [93.0080719, 12.10526085], [93.00773621, 12.10542107], [93.00773621, 12.10584927], [93.00749969, 12.10592747], [93.00737762, 12.10628223], [93.00721741, 12.10632133], [93.00726318, 12.10723019], [93.0069809, 12.10726738], [93.0069809, 12.10750198], [93.00669861, 12.10758114], [93.00669861, 12.10778046], [93.00610352, 12.10773945], [93.00610352, 12.10805321], [93.0044632, 12.10809231], [93.00430298, 12.10778046], [93.00354004, 12.10770035], [93.00354004, 12.10718918], [93.0032959, 12.10718918], [93.00305176, 12.10694122], [93.00166321, 12.10694313], [93.0014267, 12.1069088], [93.00111389, 12.10694313], [93.0008316, 12.10694313], [93.00055695, 12.10722256], [93.00055695, 12.1086092], [93.0008316, 12.10888958], [93.0008316, 12.1093502], [93.00086212, 12.10955048], [93.00066376, 12.10958862], [93.00066376, 12.11006069], [93.00093842, 12.11006069], [93.00093842, 12.11033726], [93.00065613, 12.11053085], [93.00063324, 12.11081123], [93.00042725, 12.11129856], [93.00026703, 12.11166954], [93.0, 12.11139202], [92.99968719, 12.11137199], [92.99944305, 12.1118412], [92.99919891, 12.11198044], [92.99894714, 12.11221886], [92.99865723, 12.11244011], [92.99846649, 12.11256123], [92.99830627, 12.11278152], [92.99810028, 12.11300087], [92.99716187, 12.11357975], [92.99680328, 12.11361027], [92.99658966, 12.11358738], [92.99638367, 12.11356354], [92.99602509, 12.11334991], [92.99565887, 12.11316967], [92.99526215, 12.1130724], [92.99485016, 12.11306], [92.9944458, 12.11310101], [92.9940567, 12.11329079], [92.99359131, 12.11333179], [92.99305725, 12.11329079], [92.99259949, 12.11306], [92.991539, 12.11303139], [92.9912262, 12.11294937], [92.99061584, 12.11270046], [92.99002838, 12.11288738], [92.98918915, 12.11301231], [92.98805237, 12.11305428], [92.98686218, 12.11311531], [92.98584747, 12.11307621], [92.985466, 12.11302185], [92.98517609, 12.1129303], [92.98456573, 12.11268425], [92.98429108, 12.1125412], [92.9838562, 12.11220074], [92.98297882, 12.11192989], [92.98243713, 12.11180878], [92.98197174, 12.11173153], [92.9815979, 12.11173153], [92.98073578, 12.11176968], [92.98052216, 12.11189079], [92.98031616, 12.11218071], [92.9801712, 12.1125927], [92.97980499, 12.11296463], [92.97968292, 12.11308956], [92.97933197, 12.11299038], [92.97881317, 12.1129303], [92.97796631, 12.11294365], [92.97705841, 12.11323071], [92.97670746, 12.11327457], [92.97628784, 12.11354065], [92.97607422, 12.11379242], [92.9759903, 12.11410236], [92.97612, 12.11476326], [92.97625732, 12.11509132], [92.97646332, 12.11557198], [92.97646332, 12.11606026], [92.97637177, 12.11631012], [92.97619629, 12.11658764], [92.97600555, 12.11691189], [92.97575378, 12.11720371], [92.97544098, 12.11744118], [92.97502136, 12.11760044], [92.97453308, 12.11777973], [92.97397614, 12.11795139], [92.9733963, 12.11800194], [92.97286224, 12.11780071], [92.97233582, 12.11763], [92.97181702, 12.11750031], [92.97130585, 12.11740017], [92.97083282, 12.11729717], [92.97036743, 12.11744976], [92.96984863, 12.11750031], [92.96930695, 12.1175499], [92.96881866, 12.11777115], [92.96826935, 12.11798954], [92.96765137, 12.1182003], [92.96703339, 12.11852074], [92.966362, 12.11889935], [92.96570587, 12.11935139], [92.96521759, 12.11993599], [92.96472931, 12.12043953], [92.96427155, 12.12090111], [92.96382904, 12.1213789], [92.96331787, 12.12181854], [92.9627533, 12.12226963], [92.96231079, 12.12280083]]], [[[93.08309174, 12.19578171], [93.08354187, 12.19572926], [93.08364868, 12.19525146], [93.08403015, 12.194911], [93.08441925, 12.194911], [93.08448792, 12.19522095], [93.08545685, 12.19522095], [93.08545685, 12.19384193], [93.08574677, 12.19380093], [93.08574677, 12.19304657], [93.08661652, 12.19305134], [93.08664703, 12.19270039], [93.08602905, 12.19274139], [93.08605957, 12.19229031], [93.0858078, 12.19207954], [93.08550262, 12.19194412], [93.08554077, 12.18946362], [93.08588409, 12.18943024], [93.08584595, 12.18787956], [93.08554077, 12.18787956], [93.08554077, 12.18691063], [93.08596039, 12.18691254], [93.08609772, 12.18656921], [93.08629608, 12.18650055], [93.08630371, 12.18543434], [93.08683014, 12.18536091], [93.08753204, 12.18470955], [93.08757019, 12.18436527], [93.08798981, 12.1843996], [93.08798981, 12.18302059], [93.08833313, 12.18298912], [93.08830261, 12.18271065], [93.08753204, 12.18216133], [93.08718109, 12.18216133], [93.08714294, 12.18195629], [93.0868988, 12.18192005], [93.08686829, 12.18161201], [93.086586, 12.18157959], [93.086586, 12.18075085], [93.08634186, 12.18075085], [93.08634186, 12.18030167], [93.08693695, 12.18013096], [93.08703613, 12.18033123], [93.08721924, 12.18041134], [93.08718109, 12.18103123], [93.08772278, 12.18107033], [93.08773804, 12.18020058], [93.08805847, 12.18020058], [93.08812714, 12.17989063], [93.08826447, 12.17995834], [93.08830261, 12.18054295], [93.08861542, 12.18054295], [93.08861542, 12.18016529], [93.08903503, 12.18019867], [93.08903503, 12.18054295], [93.08938599, 12.18054295], [93.08938599, 12.180336], [93.08969879, 12.180336], [93.08969879, 12.17995834], [93.08938599, 12.17992115], [93.08938599, 12.17971611], [93.08973694, 12.17968178], [93.08973694, 12.17944241], [93.08938599, 12.17940617], [93.08938599, 12.1791296], [93.08966827, 12.17913246], [93.08969879, 12.17889118], [93.08931732, 12.17881966], [93.08934784, 12.17778778], [93.08969879, 12.17768097], [93.08969879, 12.17720222], [93.08934784, 12.17724133], [93.08931732, 12.17682076], [93.08998108, 12.17685986], [93.08998108, 12.17445087], [93.08973694, 12.17445087], [93.08969879, 12.17366028], [93.08938599, 12.17361927], [93.08938599, 12.17306995], [93.08973694, 12.17304039], [93.08973694, 12.17276001], [93.08934784, 12.17268944], [93.08934784, 12.17251778], [93.08966827, 12.17252064], [93.08973694, 12.17190075], [93.0894165, 12.17185974], [93.08942413, 12.17076111], [93.0891037, 12.17076111], [93.08917236, 12.16914272], [93.08885956, 12.16921139], [93.08885956, 12.16835213], [93.08850861, 12.16835213], [93.08854675, 12.16749096], [93.08830261, 12.16742039], [93.08830261, 12.16697311], [93.08805847, 12.1669054], [93.08808899, 12.16583824], [93.08777618, 12.1658411], [93.08777618, 12.16462994], [93.08746338, 12.1646328], [93.0874939, 12.16404724], [93.08721924, 12.16408062], [93.08718109, 12.1644249], [93.08686829, 12.16445923], [93.08683014, 12.16414928], [93.08630371, 12.16418362], [93.08630371, 12.16387367], [93.08602905, 12.16387367], [93.08602905, 12.16325378], [93.0858078, 12.16329002], [93.08584595, 12.16222095], [93.08550262, 12.16222095], [93.08554077, 12.16084003], [93.08522034, 12.16080761], [93.08525848, 12.16004944], [93.08494568, 12.1599474], [93.08490753, 12.15915966], [93.08466339, 12.15912247], [93.08459473, 12.15832901], [93.08495331, 12.15828991], [93.0849762, 12.15750122], [93.08522034, 12.15750122], [93.08515167, 12.156847], [93.08483887, 12.15688133], [93.0845871, 12.15734196], [93.08413696, 12.15734196], [93.08418274, 12.15603065], [93.08444977, 12.15603065], [93.08441925, 12.15582085], [93.08381653, 12.15585136], [93.08381653, 12.15554142], [93.08399963, 12.15551186], [93.08403015, 12.15526104], [93.08435059, 12.15520191], [93.08441925, 12.15551186], [93.0845871, 12.15551186], [93.08468628, 12.15530014], [93.08495331, 12.15530014], [93.08500671, 12.1549902], [93.08473206, 12.1549511], [93.08469391, 12.15474796], [93.0849762, 12.15468025], [93.08512115, 12.15406036], [93.08557129, 12.15358067], [93.08605957, 12.15361118], [93.08605957, 12.15343761], [93.08587646, 12.15322971], [93.08588409, 12.15299129], [93.08609772, 12.15278339], [93.08609772, 12.15250778], [93.08574677, 12.15244198], [93.08577728, 12.1518507], [93.08605957, 12.15181923], [93.08609772, 12.15161037], [93.08679962, 12.15161419], [93.0869751, 12.15126991], [93.0874939, 12.15130424], [93.08753204, 12.15149975], [93.08822632, 12.15219975], [93.08837128, 12.15244198], [93.08889771, 12.15244198], [93.08899689, 12.15216064], [93.08931732, 12.15164757], [93.08994293, 12.15165997], [93.08994293, 12.15126991], [93.09050751, 12.15126991], [93.09046936, 12.15157986], [93.09075165, 12.15161419], [93.09076691, 12.15140724], [93.09078217, 12.15126991], [93.09113312, 12.15126991], [93.09113312, 12.1510601], [93.0907135, 12.15106297], [93.09075165, 12.15020084], [93.09099579, 12.15020084], [93.09148407, 12.14968395], [93.09179688, 12.14968395], [93.0920105, 12.14941025], [93.09243011, 12.14941025], [93.09246063, 12.14886093], [93.09348297, 12.14871979], [93.09355164, 12.14831161], [93.09403992, 12.14838028], [93.09410858, 12.14778996], [93.09442139, 12.14769173], [93.09442139, 12.14719963], [93.09407043, 12.1472044], [93.09407043, 12.14658356], [93.09442139, 12.14655018], [93.09442139, 12.14576054], [93.09470367, 12.14579296], [93.09474182, 12.14527607], [93.09435272, 12.14538097], [93.09449005, 12.14335918], [93.09468842, 12.14331055], [93.09463501, 12.14241791], [93.09500122, 12.14242172], [93.09494781, 12.14200115], [93.09417725, 12.14128113], [93.09414673, 12.1403513], [93.09355164, 12.13986969], [93.09355164, 12.13862991], [93.09306335, 12.1382494], [93.09302521, 12.13756084], [93.09278107, 12.13749313], [93.09274292, 12.13680363], [93.09223175, 12.13617992], [93.09221649, 12.13580608], [93.0916214, 12.13584042], [93.0916214, 12.1352911], [93.091362, 12.13521957], [93.09130859, 12.13498116], [93.09082031, 12.13501263], [93.09043884, 12.13432503], [93.08998108, 12.13436127], [93.08998108, 12.13364124], [93.08966827, 12.13350201], [93.08969879, 12.13307953], [93.08938599, 12.13301563], [93.08934784, 12.13276958], [93.08966827, 12.13274097], [93.08963013, 12.13250065], [93.08909607, 12.13243961], [93.08914185, 12.13173962], [93.08885956, 12.13171101], [93.08889771, 12.13085079], [93.08864594, 12.13080978], [93.08772278, 12.12998104], [93.08781433, 12.12960529], [93.08830261, 12.12926006], [93.08822632, 12.12881088], [93.08882904, 12.12881374], [93.08892822, 12.12853813], [93.0894165, 12.12851143], [93.08944702, 12.12825966], [93.08969879, 12.12822819], [93.08969879, 12.12750053], [93.08994293, 12.12743473], [93.08994293, 12.12718201], [93.08969879, 12.12712479], [93.08969879, 12.12585068], [93.08934784, 12.1258173], [93.08938599, 12.12492085], [93.08921051, 12.12496185], [93.08825684, 12.12389088], [93.0878067, 12.12385178], [93.08753204, 12.12364674], [93.08766937, 12.12306118], [93.08795166, 12.12306118], [93.08805847, 12.1232338], [93.08896637, 12.12330341], [93.08892822, 12.12354374], [93.09123993, 12.12351036], [93.09123993, 12.12330055], [93.09236145, 12.12330341], [93.09302521, 12.12268257], [93.09302521, 12.12120056], [93.09278107, 12.12099648], [93.09187317, 12.12020969], [93.09189606, 12.11917114], [93.09159088, 12.11914063], [93.0916214, 12.11878967], [93.09243011, 12.11883068], [93.09243011, 12.11841202], [93.09221649, 12.11834335], [93.09225464, 12.11779213], [93.09246063, 12.11758709], [93.09256744, 12.11697102], [93.09218597, 12.11693001], [93.09207916, 12.11662292], [93.09190369, 12.11658573], [93.09189606, 12.11631012], [93.09142303, 12.11634922], [93.09123993, 12.11659145], [93.09078217, 12.11659145], [93.09075165, 12.11584091], [93.08991241, 12.11584091], [93.08983612, 12.11524105], [93.09018707, 12.11524391], [93.09026337, 12.11469173], [93.09050751, 12.11469173], [93.09050751, 12.11414146], [93.09068298, 12.11410618], [93.09075165, 12.11383057], [93.09095764, 12.11379719], [93.0911026, 12.11358929], [93.09147644, 12.11363029], [93.09158325, 12.11340427], [93.0916214, 12.11331558], [93.09223175, 12.11325169], [93.09224701, 12.11275864], [93.09302521, 12.11276436], [93.09305573, 12.11252213], [93.0932312, 12.11252213], [93.0932312, 12.11228085], [93.09278107, 12.11193657], [93.09278107, 12.11163139], [93.0933075, 12.11166096], [93.0933075, 12.11111164], [93.09303284, 12.11108017], [93.09306335, 12.11077023], [93.0933075, 12.11077023], [93.0933075, 12.11053085], [93.09249878, 12.11056042], [93.09223175, 12.11101055], [93.09204102, 12.11111164], [93.09179688, 12.11094093], [93.09179688, 12.11049175], [93.09214783, 12.11039066], [93.09214783, 12.10953045], [93.09187317, 12.10949135], [93.09187317, 12.10921764], [93.09218597, 12.10921955], [93.09218597, 12.10894203], [93.09183502, 12.10894203], [93.09187317, 12.10863209], [93.09211731, 12.10842514], [93.09218597, 12.10766792], [93.09187317, 12.10766983], [93.09187317, 12.10738087], [93.09214783, 12.10739231], [93.09221649, 12.1069088], [93.09187317, 12.10694122], [93.09184265, 12.10722065], [93.09159088, 12.10722065], [93.09165955, 12.10670185], [93.09183502, 12.10656548], [93.09183502, 12.10618591], [93.09155273, 12.10604954], [93.09159088, 12.10557079], [93.09179688, 12.10545921], [93.09179688, 12.10463715], [93.091362, 12.10439968], [93.091362, 12.10419178], [93.09155273, 12.10419178], [93.09159088, 12.10384083], [93.09137726, 12.10380936], [93.091362, 12.10254002], [93.09078217, 12.10254002], [93.09078217, 12.10147095], [93.09050751, 12.10142994], [93.09046936, 12.10088253], [93.09011841, 12.10074425], [93.09015656, 12.10029697], [93.09082031, 12.10030174], [93.09082031, 12.0999918], [93.09046936, 12.09992123], [93.09050751, 12.09919167], [93.08998108, 12.09919357], [93.09011841, 12.09857368], [93.09011841, 12.09833336], [93.08973694, 12.0979538], [93.08966827, 12.09754181], [93.08892822, 12.09750843], [93.08773804, 12.09636974], [93.08777618, 12.09582138], [93.08711243, 12.09585285], [93.08711243, 12.09557724], [93.08683014, 12.09558201], [93.08686066, 12.09454536], [93.08686829, 12.09420013], [93.08662415, 12.0941658], [93.08661652, 12.09337139], [93.08605957, 12.0933733], [93.08605957, 12.09309959], [93.08545685, 12.09309959], [93.08545685, 12.09268856], [93.08599091, 12.09268856], [93.08599091, 12.09200096], [93.08624268, 12.09195995], [93.08627319, 12.09130764], [93.086586, 12.09131145], [93.086586, 12.09110069], [93.0861969, 12.09082985], [93.08518982, 12.09082985], [93.08518982, 12.0903101], [93.08554077, 12.09034443], [93.08554077, 12.08979321], [93.0853653, 12.08961868], [93.08486938, 12.08914089], [93.08413696, 12.08917332], [93.08417511, 12.08855343], [93.08385468, 12.08855343], [93.08382416, 12.08886337], [93.08329773, 12.08882904], [93.0831604, 12.08917332], [93.08280945, 12.08917332], [93.08280945, 12.08886337], [93.08238983, 12.08886337], [93.0822525, 12.08858681], [93.08138275, 12.08862114], [93.08133698, 12.08890247], [93.08088684, 12.08889675], [93.08084869, 12.08972168], [93.08053589, 12.08976078], [93.08053589, 12.08941174], [93.07965851, 12.08948326], [93.07965851, 12.08886337], [93.07945251, 12.08882904], [93.079422, 12.08837986], [93.07910156, 12.08834457], [93.07910156, 12.08804035], [93.07972717, 12.08800125], [93.07965851, 12.08748436], [93.07913208, 12.08748436], [93.07906342, 12.08693504], [93.07885742, 12.08686447], [93.07888794, 12.08665943], [93.07935333, 12.08628273], [93.07930756, 12.08604145], [93.07858276, 12.08545113], [93.0786438, 12.08465958], [93.07727814, 12.084692], [93.07685852, 12.08525944], [93.07650757, 12.08528042], [93.07616425, 12.08545303], [93.07553101, 12.08493614], [93.07546234, 12.08442116], [93.07493591, 12.08445263], [93.07497406, 12.08393764], [93.074646, 12.083951], [93.074646, 12.08362961], [93.07440948, 12.0836277], [93.07444763, 12.08521175], [93.0739212, 12.08576298], [93.07338715, 12.08583164], [93.07328796, 12.08617973], [93.0727005, 12.08614063], [93.07263184, 12.0865202], [93.07248688, 12.0865202], [93.07248688, 12.08693504], [93.07186127, 12.08693504], [93.07186127, 12.08717442], [93.07003784, 12.08717155], [93.06990051, 12.08742046], [93.0694809, 12.0874157], [93.06941223, 12.08769131], [93.06973267, 12.08769131], [93.06976318, 12.08831978], [93.07007599, 12.08837986], [93.07000732, 12.08921146], [93.06976318, 12.08921146], [93.06944275, 12.08963108], [93.07003784, 12.09017086], [93.07032013, 12.09017086], [93.07032013, 12.09054947], [93.06968689, 12.09054947], [93.06958771, 12.09020138], [93.0686264, 12.090271], [93.06859589, 12.09054947], [93.06832123, 12.09062004], [93.06832123, 12.09165192], [93.06859589, 12.09165001], [93.06842804, 12.09199715], [93.06772614, 12.09257984], [93.06776428, 12.09333897], [93.06745148, 12.09340096], [93.06748199, 12.09409809], [93.06720734, 12.0943737], [93.06661224, 12.09444237], [93.06668091, 12.09523296], [93.06632996, 12.09523106], [93.0663681, 12.09557724], [93.06668091, 12.09561062], [93.06668091, 12.09665108], [93.06632996, 12.09667969], [93.06632996, 12.09799099], [93.06580353, 12.0979538], [93.06580353, 12.09833336], [93.06520844, 12.09833336], [93.06520844, 12.09850597], [93.06503296, 12.09847832], [93.06472015, 12.09826374], [93.06482697, 12.09778118], [93.06450653, 12.09775066], [93.06450653, 12.09813023], [93.06419373, 12.09812737], [93.06419373, 12.09833336], [93.06339264, 12.09829807], [93.06332397, 12.09878159], [93.06293488, 12.09878159], [93.06292725, 12.09908009], [93.06332397, 12.09912586], [93.06331635, 12.09950161], [93.06304169, 12.09960747], [93.06307983, 12.10057259], [93.06272888, 12.10057068], [93.0627594, 12.10092163], [93.06304169, 12.10091686], [93.06300354, 12.10136414], [93.06248474, 12.10150337], [93.06248474, 12.10170841], [93.06220245, 12.10170078], [93.06215668, 12.10281086], [93.06140137, 12.10281086], [93.06140137, 12.10333061], [93.06101227, 12.10333061], [93.06101227, 12.10361099], [93.06078339, 12.10364056], [93.06080627, 12.10395145], [93.06051636, 12.10395145], [93.06051636, 12.10361099], [93.06017303, 12.10361099], [93.06017303, 12.1032896], [93.05967712, 12.1032896], [93.05967712, 12.10356998], [93.05919647, 12.10356808], [93.05919647, 12.10384083], [93.05886841, 12.10387993], [93.05886078, 12.10415077], [93.05885315, 12.10442924], [93.0580368, 12.10439968], [93.0580368, 12.10494709], [93.05779266, 12.1050148], [93.05779266, 12.10546398], [93.05758667, 12.10563469], [93.05738831, 12.10587692], [93.05728149, 12.10601139], [93.05719757, 12.10612011], [93.05674744, 12.10608387], [93.056427, 12.10645962], [93.05541229, 12.10729027], [93.05496216, 12.10776997], [93.05506897, 12.10885143], [93.05464935, 12.10885143], [93.05467987, 12.10914707], [93.05454254, 12.10942078], [93.05412292, 12.10993958], [93.05307007, 12.10997391], [93.05307007, 12.11131001], [93.05223083, 12.11142159], [93.05223083, 12.11187077], [93.05161285, 12.11242008], [93.05160522, 12.11293507], [93.05110931, 12.11338425], [93.05110931, 12.11406994], [93.05051422, 12.11452103], [93.05050659, 12.1149292], [93.05020142, 12.1149683], [93.05023956, 12.11555099], [93.05055237, 12.1155901], [93.05055237, 12.11607075], [93.05023956, 12.11620998], [93.05023956, 12.11638069], [93.05059052, 12.11638069], [93.05062103, 12.11748219], [93.05220032, 12.11748028], [93.05220032, 12.11800194], [93.0526886, 12.11800194], [93.05271912, 12.11862087], [93.05307007, 12.11862087], [93.05307007, 12.11937809], [93.05325317, 12.11948109], [93.05328369, 12.12078857], [93.05381012, 12.12082291], [93.05387878, 12.12136078], [93.05407715, 12.12141132], [93.05412292, 12.12189198], [93.05443573, 12.12199497], [93.05443573, 12.12244129], [93.05464935, 12.12244129], [93.05474854, 12.12266922], [93.05527496, 12.1227169], [93.05541229, 12.12299347], [93.05653381, 12.12295914], [93.05657196, 12.1232338], [93.05576324, 12.12322998], [93.05576324, 12.12351036], [93.05545044, 12.12354374], [93.05541229, 12.1232338], [93.05467987, 12.12327099], [93.05467987, 12.12303162], [93.05419159, 12.12303162], [93.05415344, 12.12286282], [93.05412292, 12.12275124], [93.05303955, 12.12279034], [93.05296326, 12.12234116], [93.0524826, 12.12203121], [93.05243683, 12.12136078], [93.05198669, 12.1213398], [93.05132294, 12.12058067], [93.0510788, 12.12058067], [93.05110931, 12.11996174], [93.05079651, 12.11996174], [93.0506897, 12.11968803], [93.05030823, 12.11972046], [93.05023956, 12.11999798], [93.04998779, 12.1200304], [93.04992676, 12.12030983], [93.04960632, 12.12030792], [93.04957581, 12.12058067], [93.04936218, 12.12061977], [93.04936218, 12.12030983], [93.04911804, 12.12030792], [93.04915619, 12.12113094], [93.04862976, 12.12117195], [93.04862976, 12.1220293], [93.04827881, 12.12244129], [93.04803467, 12.12264919], [93.04803467, 12.12299347], [93.04772186, 12.12299061], [93.04772186, 12.12334156], [93.04799652, 12.12340546], [93.04807281, 12.12360954], [93.04834747, 12.1237154], [93.04827881, 12.12423325], [93.04754639, 12.12423038], [93.04750824, 12.12444019], [93.04708099, 12.12451077], [93.04715729, 12.12496185], [93.04750824, 12.12498856], [93.04750824, 12.12516022], [93.04715729, 12.12550735], [93.04688263, 12.12564564], [93.04691315, 12.12664413], [93.04663086, 12.12660122], [93.04656219, 12.12774944], [93.0460434, 12.12774944], [93.04586792, 12.12743855], [93.04548645, 12.12743855], [93.04554749, 12.12807083], [93.04522705, 12.12809086], [93.04522705, 12.12830067], [93.0443573, 12.12830067], [93.04440308, 12.12799072], [93.04302979, 12.12809086], [93.04299927, 12.12774944], [93.0427475, 12.12774944], [93.04250336, 12.12743855], [93.0422287, 12.12694931], [93.04135132, 12.12688637], [93.04131317, 12.12653923], [93.03998566, 12.1266098], [93.03998566, 12.12695408], [93.039711, 12.12695408], [93.039711, 12.12740135], [93.03942871, 12.12750053], [93.03942871, 12.1301899], [93.03923035, 12.13043022], [93.03925323, 12.13078117], [93.03887177, 12.13088131], [93.03890228, 12.13132954], [93.03830719, 12.1315012], [93.03830719, 12.13212109], [93.03775024, 12.13228035], [93.0377121, 12.13249874], [93.03743744, 12.13253117], [93.03743744, 12.1333313], [93.03718567, 12.13336086], [93.03718567, 12.13353157], [93.03746796, 12.1335907], [93.03761292, 12.13387966], [93.03778076, 12.13395119], [93.03775024, 12.13436127], [93.03743744, 12.13449574], [93.03746796, 12.13501072], [93.0377121, 12.13506126], [93.03778076, 12.13607979], [93.03827667, 12.1361208], [93.03837585, 12.13667202], [93.03862, 12.13667202], [93.03865814, 12.13700962], [93.03830719, 12.13700962], [93.03830719, 12.1372509], [93.03798676, 12.13729], [93.03799438, 12.1382494], [93.03827667, 12.13828564], [93.03827667, 12.13934994], [93.03862, 12.13949108], [93.03858948, 12.14007854], [93.03890228, 12.14010906], [93.03890228, 12.14059162], [93.03918457, 12.14059162], [93.03923035, 12.14107132], [93.03945923, 12.14110661], [93.03949738, 12.14472198], [93.03977966, 12.14475918], [93.03974152, 12.14510536], [93.03942871, 12.14509106], [93.03942871, 12.14555168], [93.03967285, 12.14555168], [93.03967285, 12.14641953], [93.03996277, 12.14641953], [93.03996277, 12.14693069], [93.0402298, 12.14693069], [93.0402298, 12.14803123], [93.04051208, 12.14803123], [93.04051208, 12.14886093], [93.04082489, 12.14885902], [93.04079437, 12.14975357], [93.04110718, 12.14974976], [93.04106903, 12.15082073], [93.04138947, 12.15082073], [93.04138947, 12.15113068], [93.04110718, 12.15113068], [93.04110718, 12.15126991], [93.04170227, 12.15168285], [93.04170227, 12.15268135], [93.04194641, 12.1528492], [93.04190826, 12.15320015], [93.0422287, 12.15327072], [93.0422287, 12.15405655], [93.04281616, 12.15447044], [93.0427475, 12.15485096], [93.04309845, 12.15489197], [93.04320526, 12.15581512], [93.04297638, 12.15588093], [93.03647614, 12.15692043], [93.03690338, 12.15802097], [93.03752899, 12.15974236], [93.04095459, 12.15905285], [93.04324341, 12.15853596], [93.04359436, 12.15891361], [93.04366302, 12.15943241], [93.04411316, 12.15936279], [93.04412079, 12.15959644], [93.04415131, 12.16054153], [93.04470825, 12.16050053], [93.04470825, 12.16195011], [93.04495239, 12.16191101], [93.04499054, 12.16211891], [93.04522705, 12.16215134], [93.04527283, 12.16267014], [93.04579163, 12.16311932], [93.04576111, 12.16408062], [93.04607391, 12.16418362], [93.0460434, 12.16473484], [93.04634857, 12.16473103], [93.04638672, 12.16529083], [93.04663086, 12.16529083], [93.04666901, 12.16570187], [93.04628754, 12.16570187], [93.04628754, 12.16615105], [93.04691315, 12.16611195], [93.04691315, 12.16658974], [93.04715729, 12.16663074], [93.04715729, 12.16749096], [93.04754639, 12.16752529], [93.04754639, 12.16828156], [93.04831696, 12.16887188], [93.04831696, 12.16948891], [93.04862976, 12.16948891], [93.04862976, 12.16996956], [93.04891205, 12.17000484], [93.04891205, 12.17130089], [93.04921722, 12.17149067], [93.04964447, 12.17183018], [93.04965973, 12.17268944], [93.04967499, 12.17355061], [93.04995728, 12.17355061], [93.04995728, 12.17465401], [93.05027008, 12.17464924], [93.05027008, 12.17521], [93.05051422, 12.17523956], [93.05055237, 12.17658043], [93.05104065, 12.17692947], [93.05104065, 12.17768478], [93.05136108, 12.17768478], [93.05136108, 12.17830467], [93.05169678, 12.17829132], [93.05174255, 12.17854691], [93.05191803, 12.1786108], [93.05202484, 12.17988873], [93.05243683, 12.18023109], [93.05243683, 12.18113136], [93.05275726, 12.18112946], [93.05279541, 12.18164635], [93.05303955, 12.18171024], [93.0530014, 12.18212986], [93.05330658, 12.18220043], [93.05330658, 12.18251038], [93.0530014, 12.18253994], [93.0530014, 12.1832304], [93.05327606, 12.1832304], [93.05327606, 12.18408966], [93.0535965, 12.18413067], [93.05362701, 12.18553925], [93.0539093, 12.18553925], [93.05394745, 12.18577766], [93.05415344, 12.18581295], [93.05414581, 12.18629074], [93.05443573, 12.18632984], [93.05445099, 12.18673801], [93.05446625, 12.18715954], [93.05464935, 12.18709087], [93.05467987, 12.18739891], [93.05499268, 12.18746471], [93.05499268, 12.18829155], [93.05526733, 12.18828964], [93.05538177, 12.18857002], [93.05555725, 12.18857002], [93.05555725, 12.18918991], [93.05580139, 12.18918991], [93.05580139, 12.19026184], [93.05615234, 12.19026184], [93.05615234, 12.19081116], [93.05635834, 12.19081116], [93.05635834, 12.19136047], [93.05657196, 12.19143105], [93.05688477, 12.19173622], [93.05699158, 12.1921854], [93.05723572, 12.1921854], [93.05719757, 12.19301033], [93.05747986, 12.1930809], [93.05747986, 12.19352818], [93.05779266, 12.19363022], [93.05776215, 12.19411087], [93.0580368, 12.19415188], [93.0580368, 12.19494057], [93.05891418, 12.19552422], [93.05891418, 12.19604111], [93.05912781, 12.19604111], [93.05912781, 12.19651985], [93.05999756, 12.19724655], [93.05999756, 12.19769382], [93.06027985, 12.19775963], [93.0602417, 12.1980381], [93.06056213, 12.19806957], [93.06059265, 12.19828033], [93.06083679, 12.19831085], [93.06083679, 12.19848919], [93.06111908, 12.19856167], [93.06108093, 12.19911098], [93.06143188, 12.19917965], [93.06143188, 12.19996834], [93.06160736, 12.20000267], [93.06164551, 12.20024395], [93.06195831, 12.20024014], [93.06188965, 12.20066071], [93.06212616, 12.20073032], [93.06220245, 12.20097065], [93.06253052, 12.20092964], [93.06253052, 12.20159054], [93.0627594, 12.20159054], [93.0627594, 12.20190144], [93.06297302, 12.20190144], [93.06297302, 12.2024498], [93.06331635, 12.2024498], [93.06332397, 12.20323944], [93.06408691, 12.2038908], [93.06416321, 12.20496178], [93.06465149, 12.20499611], [93.06468964, 12.20551109], [93.06492615, 12.20555019], [93.06495667, 12.20658016], [93.06552887, 12.20696068], [93.06549072, 12.20816422], [93.06632996, 12.20892143], [93.06629944, 12.21015167], [93.06646729, 12.21019936], [93.06693268, 12.21019936], [93.06693268, 12.2105093], [93.06723785, 12.2105751], [93.06723785, 12.21102428], [93.06752014, 12.21102047], [93.06752014, 12.2112999], [93.06829071, 12.21129799], [93.06830597, 12.21140957], [93.06832123, 12.2115736], [93.06860352, 12.2115736], [93.06860352, 12.21133423], [93.07021332, 12.21126366], [93.07025146, 12.21098804], [93.07055664, 12.21081924], [93.07213593, 12.2107811], [93.07224274, 12.21016312], [93.07238007, 12.21016312], [93.07336426, 12.21020889], [93.07385254, 12.21023083], [93.07389069, 12.20988941], [93.07462311, 12.20992088], [93.07472992, 12.21023083], [93.07491302, 12.21023083], [93.07493591, 12.20992088], [93.07591248, 12.20988941], [93.07601929, 12.20971203], [93.07633972, 12.20957661], [93.07633972, 12.2086792], [93.07658386, 12.2086134], [93.07658386, 12.20758057], [93.07717896, 12.20711994], [93.07717896, 12.2067194], [93.076828, 12.2066803], [93.07685852, 12.20616817], [93.07717896, 12.20610142], [93.07717896, 12.20580959], [93.07685852, 12.20575523], [93.07685852, 12.205513], [93.07717896, 12.20534039], [93.07717896, 12.20496178], [93.07769775, 12.20496178], [93.07769775, 12.20475006], [93.07745361, 12.20451546], [93.07745361, 12.20434189], [93.07710266, 12.20416927], [93.07710266, 12.20383072], [93.07749176, 12.2037611], [93.07749176, 12.20352173], [93.07720947, 12.20352173], [93.07720947, 12.20303154], [93.07689667, 12.20289516], [93.07697296, 12.20269203], [93.07717896, 12.20262146], [93.07720947, 12.20217037], [93.07798004, 12.20217228], [93.07798004, 12.201931], [93.07829285, 12.20190144], [93.07821655, 12.20141125], [93.07850647, 12.20134544], [93.07850647, 12.20045185], [93.07905579, 12.20045185], [93.07913208, 12.20020962], [93.07965851, 12.20017147], [93.07983398, 12.1998291], [93.07997131, 12.19968987], [93.08022308, 12.19958782], [93.08029175, 12.19828033], [93.08133698, 12.19834995], [93.08158112, 12.19858932], [93.08183289, 12.19838047], [93.08190155, 12.19773006], [93.08242035, 12.19773006], [93.08242035, 12.19742012], [93.08270264, 12.19738197], [93.08270264, 12.19676399], [93.08294678, 12.19672966], [93.08294678, 12.19618034], [93.08309174, 12.19608021], [93.08309174, 12.19578171]]], [[[92.99388123, 12.10993958], [92.99305725, 12.10993958], [92.99246216, 12.11053085], [92.99249268, 12.11163998], [92.99337769, 12.11163998], [92.99389648, 12.11107063], [92.99388123, 12.10993958]]], [[[92.74285126, 12.11499977], [92.74286652, 12.11472034], [92.74315643, 12.11472034], [92.74315643, 12.11389923], [92.74254608, 12.11382198], [92.74256897, 12.11220074], [92.74204254, 12.11216545], [92.74204254, 12.11133003], [92.74176025, 12.11128044], [92.74178314, 12.11086082], [92.74143982, 12.11054039], [92.74092865, 12.11046028], [92.7409668, 12.10996056], [92.74072266, 12.10996056], [92.7407074, 12.10942078], [92.74042511, 12.10942268], [92.74032593, 12.10886192], [92.74015808, 12.10856438], [92.73985291, 12.10856438], [92.73979187, 12.1080637], [92.73957062, 12.1080637], [92.73959351, 12.10744667], [92.73928833, 12.10746956], [92.73925781, 12.10689068], [92.7387085, 12.10688591], [92.7387085, 12.10716438], [92.73842621, 12.10743999], [92.73842621, 12.10883045], [92.7387085, 12.10910797], [92.7387085, 12.10966396], [92.7389679, 12.10993958], [92.7389679, 12.11050129], [92.73950195, 12.11049175], [92.73977661, 12.11081123], [92.73980713, 12.11165047], [92.74008942, 12.11165047], [92.74009705, 12.11216545], [92.74061584, 12.11221027], [92.74067688, 12.11271191], [92.74095154, 12.11279106], [92.74091339, 12.11361027], [92.74121094, 12.11361027], [92.74120331, 12.11411095], [92.74173737, 12.11411953], [92.74228668, 12.11468124], [92.74230194, 12.11499977], [92.74285126, 12.11499977]]], [[[92.68302917, 12.21490097], [92.68287659, 12.21472073], [92.68219757, 12.21484184], [92.68179321, 12.21505165], [92.68138885, 12.21524811], [92.68113708, 12.21574497], [92.68103027, 12.21628475], [92.68083954, 12.21677017], [92.68065643, 12.2172308], [92.68051147, 12.2176609], [92.68031311, 12.21803474], [92.68023682, 12.21846962], [92.6800766, 12.21888065], [92.68017578, 12.21934986], [92.680336, 12.21988106], [92.6806488, 12.2203598], [92.6810379, 12.22077942], [92.68132782, 12.22126484], [92.68147278, 12.22183037], [92.681633, 12.22232437], [92.68165588, 12.22280979], [92.68165588, 12.22331142], [92.68171692, 12.22386074], [92.6820755, 12.22437763], [92.68281555, 12.22443295], [92.68330383, 12.22383499], [92.68353271, 12.22313118], [92.68338013, 12.22241116], [92.68332672, 12.22171974], [92.68332672, 12.22107124], [92.68332672, 12.22047138], [92.68332672, 12.21988106], [92.68333435, 12.21927738], [92.68332672, 12.21862125], [92.6833725, 12.21793461], [92.68350983, 12.2172718], [92.6833725, 12.21669006], [92.68331909, 12.21610928], [92.68321228, 12.21558475], [92.68305969, 12.21510887], [92.68302917, 12.21490097]]], [[[92.84584808, 12.14756203], [92.84552765, 12.14752102], [92.84501648, 12.1475687], [92.84443665, 12.14785099], [92.84401703, 12.14841938], [92.84402466, 12.1489954], [92.84417725, 12.14941025], [92.84440613, 12.14969063], [92.8446579, 12.14993], [92.8449707, 12.15015984], [92.84527588, 12.15045166], [92.84564209, 12.15075493], [92.84586334, 12.15086746], [92.84611511, 12.1509943], [92.84676361, 12.15097141], [92.84724426, 12.15074825], [92.84720612, 12.15044022], [92.84700775, 12.15010071], [92.84675598, 12.14974976], [92.84661865, 12.14933109], [92.84644318, 12.14887238], [92.84631348, 12.14831161], [92.84600067, 12.14780807], [92.84584808, 12.14756203]]], [[[92.75895691, 12.18131065], [92.75927734, 12.18080139], [92.76059723, 12.18082142], [92.7607193, 12.18060303], [92.76093292, 12.18023968], [92.7617569, 12.18026066], [92.76174927, 12.17993927], [92.76229858, 12.17996025], [92.76244354, 12.1796751], [92.7625885, 12.17938995], [92.76367188, 12.17937946], [92.7636795, 12.17685127], [92.76341248, 12.17688084], [92.76341248, 12.1760397], [92.76307678, 12.1760397], [92.76312256, 12.17523098], [92.76256561, 12.17521], [92.76255035, 12.17406082], [92.7623291, 12.17409134], [92.7623291, 12.17352962], [92.76203156, 12.17356205], [92.76204681, 12.17243862], [92.76172638, 12.17241955], [92.76176453, 12.17163181], [92.76119232, 12.17161369], [92.76117706, 12.17108727], [92.76088715, 12.17104244], [92.76089478, 12.17048836], [92.76062012, 12.17021179], [92.76062012, 12.16992855], [92.76035309, 12.16996956], [92.76034546, 12.16943932], [92.76033783, 12.1691227], [92.76008606, 12.1691227], [92.7600708, 12.16826344], [92.75978088, 12.16824722], [92.75978088, 12.16798115], [92.7594986, 12.16798306], [92.7594986, 12.16689587], [92.75923157, 12.16687965], [92.75923157, 12.16660023], [92.75894928, 12.16660023], [92.75894928, 12.16798973], [92.75865173, 12.16804695], [92.75871277, 12.16857147], [92.75921631, 12.16883755], [92.7592392, 12.17024231], [92.7594986, 12.17022133], [92.75953674, 12.17107105], [92.7592392, 12.17107105], [92.75925446, 12.17191029], [92.75949097, 12.17192078], [92.75953674, 12.17244053], [92.7592392, 12.17243576], [92.75923157, 12.17464924], [92.75894165, 12.17468071], [92.75895691, 12.17522144], [92.75924683, 12.17525101], [92.75923157, 12.17548847], [92.75923157, 12.17632198], [92.75921631, 12.17720222], [92.75950623, 12.17720222], [92.75948334, 12.17804527], [92.75923157, 12.17804527], [92.75921631, 12.17855358], [92.75842285, 12.17855072], [92.75839996, 12.17910099], [92.75784302, 12.1796608], [92.7567215, 12.17963791], [92.75675201, 12.18023968], [92.7564621, 12.18023968], [92.7564621, 12.18075085], [92.75679016, 12.18107033], [92.75785828, 12.18107891], [92.75788116, 12.18132973], [92.75895691, 12.18131065]]], [[[92.72029114, 12.18043804], [92.72000122, 12.1802702], [92.71987152, 12.18016911], [92.71982574, 12.18011284], [92.71968079, 12.17990971], [92.71961975, 12.17974091], [92.71955872, 12.17947197], [92.71949768, 12.17936039], [92.71941376, 12.17926025], [92.71928406, 12.17924023], [92.71917725, 12.17928123], [92.71909332, 12.17936039], [92.71903992, 12.17951107], [92.71897125, 12.17974091], [92.71884155, 12.18021107], [92.71886444, 12.180336], [92.7190094, 12.18031502], [92.71920013, 12.18031979], [92.71942902, 12.18039703], [92.7194519, 12.18062496], [92.7194519, 12.18087101], [92.71942902, 12.1811018], [92.71942902, 12.18129063], [92.71955872, 12.18140888], [92.71981049, 12.18157101], [92.72033691, 12.18202877], [92.72045898, 12.1821909], [92.72075653, 12.18229961], [92.72094727, 12.18232059], [92.72106171, 12.18223667], [92.72117615, 12.18215466], [92.72126007, 12.18190575], [92.72122192, 12.18170071], [92.72077179, 12.18132973], [92.7202301, 12.18122864], [92.7202301, 12.18091011], [92.7204361, 12.18075275], [92.72050476, 12.18068695], [92.72029114, 12.18043804]]], [[[92.73137665, 12.18758106], [92.73119354, 12.18743992], [92.73123932, 12.18662167], [92.7309494, 12.18662167], [92.73093414, 12.18604279], [92.73066711, 12.18606281], [92.73066711, 12.18550491], [92.73038483, 12.18548393], [92.73034668, 12.18442726], [92.73114777, 12.18490124], [92.73171234, 12.18444729], [92.7325058, 12.18235111], [92.73040009, 12.18235111], [92.72850037, 12.18157959], [92.72852325, 12.18382835], [92.72850037, 12.18498516], [92.72789764, 12.18496323], [92.72789764, 12.1846838], [92.72595215, 12.18467999], [92.72595215, 12.18524075], [92.72537994, 12.18553543], [92.72540283, 12.18607235], [92.72589111, 12.18611336], [92.72621155, 12.18661308], [92.72673798, 12.18661308], [92.72678375, 12.18746281], [92.72735596, 12.18745136], [92.7276001, 12.18795013], [92.72814941, 12.18803024], [92.72841644, 12.18826962], [92.72847748, 12.18887138], [92.72872925, 12.18913078], [92.73014832, 12.18915367], [92.73008728, 12.18940926], [92.73091888, 12.18940926], [92.73092651, 12.18917179], [92.73121643, 12.18913078], [92.73142242, 12.18875027], [92.73137665, 12.18758106]]], [[[93.01988983, 12.22515965], [93.02030945, 12.22494984], [93.02094269, 12.22502327], [93.02101135, 12.2247467], [93.02170563, 12.22495174], [93.02198792, 12.22419643], [93.02178192, 12.22392178], [93.02178192, 12.22363853], [93.02128601, 12.22316265], [93.02108002, 12.22316265], [93.02072906, 12.22288704], [93.02030945, 12.22282124], [93.01980591, 12.22264099], [93.01931763, 12.22270679], [93.0191803, 12.22290993], [93.01953125, 12.22311974], [93.01953125, 12.22394657], [93.01944733, 12.22416592], [93.01967621, 12.22440338], [93.01953888, 12.22495174], [93.01977539, 12.22509098], [93.01988983, 12.22515965]]], [[[92.9389801, 12.22386074], [92.93916321, 12.22332859], [92.93968964, 12.22278023], [92.93998718, 12.22238064], [92.9402771, 12.22194099], [92.9405365, 12.2214613], [92.94072723, 12.22096634], [92.9407959, 12.22050953], [92.94089508, 12.22023201], [92.94108582, 12.22002029], [92.94122314, 12.21969891], [92.94140625, 12.21926975], [92.94161987, 12.21872139], [92.94166565, 12.21804047], [92.94161987, 12.21735096], [92.94140625, 12.21673107], [92.94120026, 12.21618938], [92.94104767, 12.21567154], [92.94082642, 12.21520042], [92.94056702, 12.21472073], [92.94032288, 12.21417046], [92.94001007, 12.21362495], [92.93965149, 12.21313858], [92.93926239, 12.21276569], [92.93890381, 12.21240807], [92.93858337, 12.21207142], [92.9382019, 12.21183109], [92.93779755, 12.21165085], [92.93738556, 12.21146202], [92.93695068, 12.21165085], [92.93650818, 12.21185875], [92.93616486, 12.21222115], [92.93596649, 12.21271324], [92.93576813, 12.21301365], [92.93553925, 12.21310139], [92.93538666, 12.21295929], [92.93540955, 12.21249008], [92.93554688, 12.21194744], [92.93540955, 12.21173954], [92.93517303, 12.21152973], [92.93493652, 12.21118164], [92.93466949, 12.21080112], [92.93450928, 12.21037865], [92.93461609, 12.2099514], [92.9347229, 12.20947933], [92.93483734, 12.20906162], [92.93497467, 12.20869255], [92.93502045, 12.20829201], [92.93512726, 12.20791054], [92.93524933, 12.20747089], [92.93533325, 12.2069397], [92.93553925, 12.20645714], [92.93570709, 12.20595074], [92.93580627, 12.20546055], [92.93585205, 12.2049799], [92.93583679, 12.2045269], [92.93582916, 12.20407963], [92.93585205, 12.20362186], [92.93592834, 12.20314121], [92.93606567, 12.2026577], [92.93591309, 12.20201969], [92.93580627, 12.20139122], [92.93567657, 12.20083046], [92.93556213, 12.20030117], [92.93546295, 12.19979095], [92.93527222, 12.19933033], [92.93505859, 12.19885159], [92.93483734, 12.19833183], [92.93460083, 12.19777966], [92.93431854, 12.19721985], [92.93393707, 12.19664097], [92.9334259, 12.1961422], [92.9331665, 12.19585514], [92.93275452, 12.19612312], [92.93255615, 12.19671059], [92.93257141, 12.19729042], [92.93276978, 12.19769573], [92.93299103, 12.19800377], [92.93313599, 12.19826984], [92.93328857, 12.19850063], [92.93331146, 12.19873524], [92.93322754, 12.19899273], [92.93309021, 12.19928932], [92.93300629, 12.19968319], [92.93282318, 12.20010281], [92.93279266, 12.20065022], [92.93279266, 12.20123959], [92.93279266, 12.2018013], [92.93274689, 12.20229053], [92.93260956, 12.20266914], [92.93242645, 12.20295429], [92.93213654, 12.2031498], [92.93183136, 12.20343018], [92.93141937, 12.20366096], [92.93097687, 12.20390034], [92.93056488, 12.20416927], [92.93016815, 12.20444489], [92.92977905, 12.20471954], [92.92939758, 12.20500088], [92.92899323, 12.20527363], [92.92854309, 12.205513], [92.92803955, 12.20569134], [92.92751312, 12.2058506], [92.92697906, 12.20611954], [92.92645264, 12.20649147], [92.9259491, 12.20699501], [92.92552185, 12.20759201], [92.92514801, 12.2081604], [92.92510986, 12.2089119], [92.9252243, 12.20964622], [92.92520142, 12.21028137], [92.92498779, 12.21090126], [92.92488098, 12.2114706], [92.92504883, 12.2119503], [92.92529297, 12.21243095], [92.92550659, 12.21294117], [92.92556, 12.21350193], [92.92559814, 12.21405983], [92.92576599, 12.2145586], [92.92590332, 12.21505165], [92.92606354, 12.21551228], [92.92610931, 12.21598244], [92.92617035, 12.21641922], [92.92633057, 12.21679688], [92.92649078, 12.21720123], [92.92669678, 12.2176199], [92.92694855, 12.21802139], [92.92722321, 12.21843243], [92.92739105, 12.21885109], [92.92730713, 12.21927929], [92.92698669, 12.21973133], [92.92699432, 12.22012997], [92.92715454, 12.22054386], [92.92722321, 12.22108173], [92.92727661, 12.22165203], [92.92756653, 12.22211933], [92.92796326, 12.22248173], [92.92842102, 12.22272778], [92.92897797, 12.22278214], [92.92955017, 12.22283268], [92.93009949, 12.22299862], [92.93063354, 12.22305107], [92.93109131, 12.22311306], [92.93144226, 12.22335529], [92.93173218, 12.22372437], [92.93209839, 12.2241497], [92.93269348, 12.22444153], [92.93332672, 12.22472191], [92.93360901, 12.22500038], [92.9347229, 12.22500038], [92.93495941, 12.22501087], [92.93519592, 12.22484112], [92.93540955, 12.22472858], [92.93572998, 12.22446918], [92.93583679, 12.22416592], [92.93638611, 12.22360992], [92.9366684, 12.2238903], [92.93675232, 12.22362137], [92.93694305, 12.22360992], [92.93722534, 12.22360992], [92.93741608, 12.22401142], [92.93718719, 12.22461033], [92.93799591, 12.22518921], [92.9389801, 12.22386074]]], [[[93.07777405, 12.26194477], [93.07805634, 12.26166725], [93.07833099, 12.26167107], [93.07861328, 12.26139069], [93.07888794, 12.26139069], [93.07943726, 12.26082993], [93.07949829, 12.26038074], [93.08033752, 12.25934887], [93.08139038, 12.26031303], [93.08167267, 12.25989819], [93.08209229, 12.25942039], [93.08277893, 12.25944519], [93.08361053, 12.25861073], [93.08361053, 12.2569418], [93.08388519, 12.25666618], [93.08389282, 12.25611019], [93.08416748, 12.25583458], [93.08416748, 12.2555542], [93.08444214, 12.25528145], [93.08444214, 12.25417137], [93.0847168, 12.25389004], [93.0847168, 12.25360966], [93.08499908, 12.25333214], [93.08499908, 12.25277805], [93.08528137, 12.25249958], [93.08528137, 12.24971962], [93.08555603, 12.24944401], [93.08555603, 12.2486124], [93.08583069, 12.24833393], [93.08583069, 12.24638844], [93.08609772, 12.24611187], [93.08609772, 12.24583054], [93.08583069, 12.24555588], [93.08609772, 12.24527073], [93.08583069, 12.24499989], [93.08583069, 12.24444103], [93.08611298, 12.24416542], [93.08609772, 12.24306011], [93.08583069, 12.24277973], [93.08583069, 12.24166965], [93.08555603, 12.24138927], [93.08555603, 12.24055958], [93.08528137, 12.2402792], [93.08528137, 12.23944092], [93.08499908, 12.23916721], [93.08499908, 12.23861122], [93.08611298, 12.23750114], [93.08638763, 12.23750114], [93.08666992, 12.23721886], [93.08860779, 12.23721886], [93.08889008, 12.23750114], [93.08944702, 12.23750114], [93.08972168, 12.23778057], [93.09027863, 12.23778057], [93.09055328, 12.2380619], [93.09222412, 12.23805523], [93.09278107, 12.23861122], [93.09278107, 12.23889065], [93.09306335, 12.23917198], [93.09306335, 12.24000072], [93.09333038, 12.24000072], [93.09333038, 12.2402792], [93.09361267, 12.24055481], [93.09361267, 12.2411108], [93.09583282, 12.24333286], [93.09583282, 12.24361229], [93.09610748, 12.24388981], [93.09610748, 12.2444458], [93.09638977, 12.24472141], [93.09638977, 12.24499989], [93.09610748, 12.24527073], [93.09610748, 12.24611187], [93.09638977, 12.24638844], [93.09638977, 12.24694443], [93.09694672, 12.24750233], [93.09709167, 12.24765015], [93.09722137, 12.24777985], [93.09750366, 12.24777794], [93.09805298, 12.24833393], [93.09832764, 12.24833202], [93.09916687, 12.24916553], [93.09916687, 12.24944401], [93.09944153, 12.24971962], [93.09944153, 12.25028038], [93.09916687, 12.25056076], [93.09916687, 12.25111198], [93.09889221, 12.2514019], [93.09889221, 12.25249958], [93.09860992, 12.25277996], [93.09860992, 12.25389004], [93.09889221, 12.25417137], [93.09889221, 12.25500011], [93.09916687, 12.25528145], [93.09916687, 12.2555542], [93.09944153, 12.25583458], [93.09944153, 12.25611019], [93.09951019, 12.25623989], [93.09964752, 12.25623989], [93.09966278, 12.25788975], [93.09967804, 12.25858784], [93.10002899, 12.25899982], [93.10009766, 12.25935078], [93.10024261, 12.25942039], [93.10051727, 12.25941467], [93.10058594, 12.25961971], [93.10086823, 12.26003456], [93.10087585, 12.26031971], [93.10109711, 12.26056099], [93.10138702, 12.26055527], [93.10157776, 12.26074123], [93.10166931, 12.26083279], [93.10333252, 12.26083279], [93.10361481, 12.26055527], [93.10416412, 12.26111126], [93.10424042, 12.26092243], [93.10424042, 12.26078033], [93.10459137, 12.26078033], [93.1047287, 12.26106071], [93.10486603, 12.26105785], [93.10486603, 12.26096344], [93.10570526, 12.26075459], [93.10598755, 12.26020432], [93.10598755, 12.25958443], [93.10612488, 12.25896358], [93.1063385, 12.25841236], [93.10647583, 12.25779247], [93.1063385, 12.25689888], [93.10618591, 12.25538063], [93.1063385, 12.25428009], [93.10591888, 12.25428009], [93.10598755, 12.25373077], [93.1063385, 12.25332069], [93.10661316, 12.25275993], [93.10661316, 12.25214481], [93.10696411, 12.25159264], [93.10689545, 12.25069714], [93.10647583, 12.2500906], [93.1063385, 12.2493906], [93.10666656, 12.24888992], [93.10666656, 12.24833202], [93.10639191, 12.24805641], [93.10639191, 12.24417019], [93.10610962, 12.24389172], [93.10610962, 12.24194145], [93.10583496, 12.24166679], [93.10582733, 12.24138927], [93.10569763, 12.24103165], [93.10555267, 12.24083328], [93.10555267, 12.23999882], [93.10582733, 12.2397213], [93.10562897, 12.23941135], [93.10528564, 12.23906708], [93.10507202, 12.23803043], [93.10472107, 12.23755074], [93.10472107, 12.2366724], [93.10333252, 12.23528099], [93.10305786, 12.23528099], [93.10166931, 12.23389053], [93.10166931, 12.23332977], [93.10138702, 12.23305511], [93.10138702, 12.23278141], [93.10109711, 12.23250103], [93.10109711, 12.2322197], [93.10083008, 12.23194504], [93.10083008, 12.23166656], [93.10056305, 12.23139095], [93.10083008, 12.23110962], [93.10083008, 12.23027897], [93.10138702, 12.22972012], [93.10138702, 12.22944355], [93.10166931, 12.22916603], [93.10166931, 12.22861004], [93.10138702, 12.22832966], [93.10221863, 12.22749996], [93.10221863, 12.22611046], [93.10250092, 12.22583199], [93.10250092, 12.22500038], [93.1027832, 12.22472191], [93.10277557, 12.22444439], [93.10305786, 12.22416592], [93.10305786, 12.22333431], [93.10333252, 12.22305584], [93.10333252, 12.22194099], [93.10361481, 12.22166634], [93.10360718, 12.22056007], [93.10333252, 12.22027969], [93.10333252, 12.22000027], [93.10333252, 12.21860886], [93.10361481, 12.2183342], [93.10361481, 12.21611118], [93.10333252, 12.21583271], [93.10333252, 12.21472263], [93.10361481, 12.21444321], [93.10361481, 12.21361065], [93.10333252, 12.21333122], [93.10333252, 12.21277714], [93.10305786, 12.21250057], [93.10305786, 12.21111107], [93.10333252, 12.21083069], [93.10333252, 12.20972347], [93.10361481, 12.209445], [93.10355377, 12.20831871], [93.10328674, 12.20826721], [93.10307312, 12.20805931], [93.10293579, 12.20785046], [93.10272217, 12.20709515], [93.10272217, 12.20660973], [93.10250092, 12.20638943], [93.10250092, 12.20610142], [93.10166931, 12.20527554], [93.10166931, 12.20471954], [93.1009903, 12.20404816], [93.10074615, 12.20394135], [93.10018921, 12.20394325], [93.09998322, 12.20373821], [93.09941864, 12.20374012], [93.09941864, 12.20415115], [93.09893036, 12.20415115], [93.09893036, 12.20511532], [93.09857941, 12.20532227], [93.09830475, 12.20587444], [93.09830475, 12.20642281], [93.09803772, 12.20639133], [93.09777832, 12.20666695], [93.09777832, 12.20722103], [93.09749603, 12.20750141], [93.09750366, 12.20777893], [93.09733582, 12.20836926], [93.09706879, 12.20872021], [93.09664154, 12.20872021], [93.09606171, 12.2088213], [93.09564209, 12.20957947], [93.09514618, 12.20957947], [93.09472656, 12.20978928], [93.09416962, 12.20972061], [93.09416962, 12.21000099], [93.09388733, 12.2102766], [93.09388733, 12.2108326], [93.09249878, 12.21222115], [93.09249878, 12.21250057], [93.09222412, 12.21277714], [93.09223175, 12.21361065], [93.09194183, 12.21389198], [93.09194183, 12.21416664], [93.09166718, 12.21444321], [93.09166718, 12.21472073], [93.09139252, 12.2149992], [93.09139252, 12.21555519], [93.09111023, 12.21583271], [93.09111023, 12.21694565], [93.09139252, 12.21722126], [93.09139252, 12.21750164], [93.09166718, 12.21777821], [93.09166718, 12.2183342], [93.09278107, 12.21944141], [93.09278107, 12.21972179], [93.09306335, 12.22000027], [93.09319305, 12.22000694], [93.09333801, 12.22014332], [93.09333038, 12.22083378], [93.09333038, 12.22111225], [93.09352875, 12.22111225], [93.09353638, 12.22283268], [93.09338379, 12.22310829], [93.09362793, 12.22334957], [93.09348297, 12.22349072], [93.09340668, 12.22362995], [93.09320831, 12.22349072], [93.09299469, 12.22376728], [93.09307861, 12.22380829], [93.09350586, 12.22402191], [93.09308624, 12.22443485], [93.09266663, 12.22436619], [93.09217834, 12.22443485], [93.09169006, 12.22422695], [93.09155273, 12.22375107], [93.09113312, 12.22347069], [93.08994293, 12.22347069], [93.08944702, 12.2238903], [93.08916473, 12.22360992], [93.08860779, 12.22416592], [93.08638763, 12.22416592], [93.08611298, 12.2238903], [93.08583069, 12.2238903], [93.08569336, 12.22375107], [93.08528137, 12.22333431], [93.08499908, 12.22333431], [93.0847168, 12.22305393], [93.08444214, 12.22277832], [93.08444214, 12.22249985], [93.08416748, 12.22222042], [93.08277893, 12.22222042], [93.08249664, 12.22249985], [93.08194733, 12.22249985], [93.08167267, 12.22278023], [93.08110809, 12.22278023], [93.08082581, 12.22306061], [93.08055878, 12.22305584], [93.08029175, 12.22332859], [93.08013153, 12.22340012], [93.07985687, 12.22382164], [93.07943726, 12.22347069], [93.07943726, 12.22415924], [93.07832336, 12.22415924], [93.07776642, 12.22429562], [93.07727051, 12.22450066], [93.07670593, 12.22471142], [93.07615662, 12.22499084], [93.07559204, 12.22525978], [93.07538605, 12.22554016], [93.07509613, 12.22554016], [93.07462311, 12.22546959], [93.07348633, 12.22546959], [93.07277679, 12.22556114], [93.07221985, 12.22555637], [93.07194519, 12.22583199], [93.07138824, 12.22583199], [93.07111359, 12.22611237], [93.0708313, 12.22611046], [93.07055664, 12.22639275], [93.06999969, 12.22639275], [93.06973267, 12.22667122], [93.06916809, 12.22666645], [93.0688858, 12.22694397], [93.06835175, 12.22694016], [93.06806183, 12.22723103], [93.06555176, 12.22723103], [93.0652771, 12.22749996], [93.06498718, 12.22749996], [93.06472015, 12.2277813], [93.0644455, 12.22777843], [93.06388855, 12.22832966], [93.06388855, 12.22861004], [93.0633316, 12.22916603], [93.0633316, 12.22972012], [93.06319427, 12.22985935], [93.06305695, 12.23000145], [93.06327057, 12.23000145], [93.06333923, 12.23055172], [93.06318665, 12.2308979], [93.06277466, 12.2308321], [93.06276703, 12.2322197], [93.0625, 12.23250103], [93.0625, 12.23305511], [93.06277466, 12.23333263], [93.06276703, 12.23361111], [93.0625, 12.23389053], [93.06277466, 12.2341671], [93.06277466, 12.23444462], [93.06298065, 12.23465157], [93.06370544, 12.23537159], [93.06380463, 12.23527431], [93.06415558, 12.23527431], [93.06434631, 12.23567963], [93.06439972, 12.23580074], [93.06475067, 12.23580074], [93.06472015, 12.23639107], [93.06472015, 12.23666668], [93.06500244, 12.23694515], [93.06498718, 12.23721886], [93.0652771, 12.23750114], [93.0652771, 12.23805523], [93.06555176, 12.23833084], [93.06555176, 12.23889065], [93.06582642, 12.23917198], [93.06582642, 12.24000072], [93.0661087, 12.2402792], [93.0661087, 12.24138927], [93.06639099, 12.24166965], [93.06639099, 12.24222088], [93.06667328, 12.24249935], [93.06666565, 12.24499989], [93.06694794, 12.24527073], [93.0671463, 12.2455101], [93.0671463, 12.24605656], [93.06700134, 12.24619102], [93.06721497, 12.24640083], [93.06720734, 12.24687099], [93.067276, 12.24708939], [93.06742096, 12.24723053], [93.06742096, 12.24854088], [93.06749725, 12.24888992], [93.06749725, 12.2491703], [93.06835175, 12.25], [93.06861115, 12.25], [93.06964111, 12.25103474], [93.06971741, 12.25102329], [93.07006073, 12.25097084], [93.07012939, 12.25144863], [93.07027435, 12.25166607], [93.07027435, 12.25194359], [93.07044983, 12.2518568], [93.07086945, 12.2518568], [93.07093811, 12.25227165], [93.07135773, 12.25282192], [93.07138824, 12.25333023], [93.07133484, 12.25457001], [93.07132721, 12.25472164], [93.07132721, 12.25512123], [93.07141113, 12.25595093], [93.07125854, 12.25636101], [93.07083893, 12.25683975], [93.07068634, 12.25726128], [93.07055664, 12.25778103], [93.0716629, 12.2588892], [93.0718689, 12.25896358], [93.07215118, 12.25910091], [93.07235718, 12.25938129], [93.07248688, 12.2596817], [93.07285309, 12.25967026], [93.07348633, 12.26001358], [93.07361603, 12.26029015], [93.07467651, 12.26072121], [93.07522583, 12.26098061], [93.07593536, 12.26118565], [93.07670593, 12.26139069], [93.07754517, 12.26166916], [93.07767487, 12.26182556], [93.07777405, 12.26194477]]], [[[92.72397614, 12.18855], [92.72393799, 12.18884182], [92.72344208, 12.18884182], [92.72341156, 12.18969154], [92.72315216, 12.18965054], [92.72315216, 12.19050121], [92.7228241, 12.19049931], [92.7228775, 12.19104099], [92.72254944, 12.19106102], [92.7225647, 12.19243813], [92.72202301, 12.19274139], [92.7220459, 12.19550991], [92.7226181, 12.19579983], [92.7226181, 12.19636345], [92.72284698, 12.19635963], [92.72284698, 12.19744968], [92.72260284, 12.19746971], [92.72255707, 12.19856167], [92.72286987, 12.19863033], [92.72286987, 12.19909954], [92.72315216, 12.19913197], [92.72309875, 12.20104027], [92.72338867, 12.20104027], [92.72342682, 12.20195103], [92.72396088, 12.20191002], [92.72402191, 12.20293999], [92.72341156, 12.20300198], [92.72337341, 12.20328712], [92.7228775, 12.20330524], [92.72233582, 12.2038908], [92.72232819, 12.20412064], [92.72260284, 12.20411587], [92.72260284, 12.20491409], [92.7223053, 12.20491409], [92.7223053, 12.20551109], [92.72258759, 12.20580292], [92.72312164, 12.20577145], [92.72367859, 12.20635033], [92.72370911, 12.20687199], [92.72424316, 12.20690823], [92.72428131, 12.20743465], [92.72451782, 12.20745087], [92.72451782, 12.20802116], [92.72399139, 12.20830059], [92.72396851, 12.20883179], [92.72370911, 12.20886612], [92.72372437, 12.20997143], [92.72395325, 12.20997143], [92.72398376, 12.21049786], [92.72369385, 12.2107687], [92.72367096, 12.21136189], [92.72341156, 12.21133041], [92.72341156, 12.21189308], [92.72317505, 12.2119112], [92.72312927, 12.21246338], [92.7228775, 12.21243954], [92.7228775, 12.21384144], [92.72258759, 12.21384144], [92.7225647, 12.21465492], [92.72286224, 12.21469212], [92.7228775, 12.21576309], [92.72232819, 12.21603203], [92.72232819, 12.21658134], [92.72260284, 12.21658134], [92.72255707, 12.21828079], [92.72341156, 12.218297], [92.72341919, 12.21882057], [92.72367859, 12.21882057], [92.72367859, 12.21938038], [92.72396088, 12.21940708], [92.72396088, 12.21996117], [92.72506714, 12.22108173], [92.72506714, 12.221632], [92.72484589, 12.2216177], [92.72480774, 12.22243404], [92.72454834, 12.22243404], [92.72454834, 12.22301292], [92.72419739, 12.22328377], [92.72340393, 12.22330189], [92.72312927, 12.22357559], [92.72315216, 12.22495174], [92.72338867, 12.22492886], [92.72341156, 12.22552013], [92.72285461, 12.22607613], [92.72285461, 12.2277422], [92.72255707, 12.22772121], [92.72257996, 12.22826195], [92.72233582, 12.22827721], [92.72229767, 12.23047161], [92.72232056, 12.23134136], [92.72255707, 12.23134136], [92.72260284, 12.2327404], [92.72228241, 12.23273754], [92.72228241, 12.23328018], [92.72255707, 12.23330116], [92.72255707, 12.23379135], [92.72283173, 12.23409557], [92.72340393, 12.23413277], [92.72342682, 12.2344017], [92.72424316, 12.23440838], [92.72453308, 12.2346611], [92.72458649, 12.23523998], [92.72505188, 12.23549557], [92.72509003, 12.23609257], [92.72483063, 12.23608971], [92.72479248, 12.23664188], [92.72534943, 12.23660088], [92.72534943, 12.2380209], [92.72509766, 12.2380209], [92.72509766, 12.23888016], [92.72534943, 12.23885345], [92.72535706, 12.23926067], [92.72537231, 12.23967075], [92.72563171, 12.23967075], [92.72564697, 12.24023247], [92.72648621, 12.24024963], [92.72647858, 12.2399416], [92.72732544, 12.23997879], [92.72731781, 12.24023247], [92.7278595, 12.24024963], [92.72783661, 12.24050045], [92.72870636, 12.2405386], [92.72924042, 12.24107456], [92.72924042, 12.24134064], [92.72979736, 12.24190903], [92.72979736, 12.24245358], [92.73061371, 12.24245358], [92.73092651, 12.24189281], [92.73147583, 12.24189281], [92.73147583, 12.24164009], [92.73203278, 12.24162197], [92.73201752, 12.24171829], [92.73197937, 12.24191093], [92.73262024, 12.24189091], [92.73287201, 12.24160385], [92.73285675, 12.24107742], [92.73313141, 12.24105167], [92.73313141, 12.24020576], [92.73343658, 12.24021053], [92.73340607, 12.23970127], [92.73394012, 12.23965931], [92.73400116, 12.23939133], [92.73478699, 12.23941135], [92.73478699, 12.2380209], [92.7339859, 12.23744202], [92.73397064, 12.23583126], [92.73365784, 12.23553181], [92.73287964, 12.23550034], [92.73287964, 12.23521137], [92.73233032, 12.23519039], [92.73201752, 12.23491859], [92.73201752, 12.2341013], [92.73171997, 12.23408699], [92.73174286, 12.23271275], [92.73147583, 12.23271275], [92.7314682, 12.23218441], [92.7311554, 12.23219967], [92.73118591, 12.23079586], [92.73203278, 12.23019886], [92.73203278, 12.22970867], [92.73146057, 12.22971058], [92.73147583, 12.22940063], [92.7309494, 12.22942162], [92.73033905, 12.22886086], [92.73034668, 12.22831154], [92.73065186, 12.22825909], [92.73065186, 12.22773266], [92.73035431, 12.22773457], [92.73035431, 12.22550392], [92.7300415, 12.22550392], [92.73006439, 12.22498035], [92.73065186, 12.22465134], [92.73061371, 12.22356415], [92.73034668, 12.22357082], [92.73034668, 12.2221899], [92.73118591, 12.221632], [92.73118591, 12.22024059], [92.73146057, 12.22024059], [92.73147583, 12.21885967], [92.73117065, 12.21886158], [92.73122406, 12.21724892], [92.730896, 12.21720123], [92.730896, 12.21413136], [92.73118591, 12.21411514], [92.73118591, 12.21301937], [92.73149872, 12.21276093], [92.73229218, 12.21275043], [92.73233032, 12.21244717], [92.73287201, 12.21243095], [92.73284149, 12.21191978], [92.73223877, 12.21164894], [92.7322998, 12.21107006], [92.73286438, 12.21079731], [92.73288727, 12.21025181], [92.73330688, 12.21023083], [92.73369598, 12.21049118], [92.73368073, 12.21107006], [92.73395538, 12.21108627], [92.73397064, 12.21232796], [92.7339859, 12.21359062], [92.73425293, 12.21353054], [92.73423004, 12.21407604], [92.73455811, 12.21409035], [92.73452759, 12.21502018], [92.7350769, 12.21552086], [92.73509979, 12.21634197], [92.73474884, 12.21634197], [92.73482513, 12.21741104], [92.73535156, 12.21774101], [92.73535156, 12.22051907], [92.73537445, 12.22075367], [92.73618317, 12.22106171], [92.73728943, 12.22102833], [92.73755646, 12.22099113], [92.73757935, 12.22191429], [92.73789215, 12.22193241], [92.73791504, 12.22242165], [92.7381134, 12.22242165], [92.73813629, 12.22298145], [92.73872375, 12.22352791], [92.73925781, 12.22356415], [92.73927307, 12.2230196], [92.7397995, 12.2230196], [92.73977661, 12.22275066], [92.74034882, 12.22270012], [92.74042511, 12.22245693], [92.74091339, 12.22244072], [92.74088287, 12.2218914], [92.74143982, 12.22191238], [92.74201965, 12.22107506], [92.74260712, 12.22105026], [92.74259186, 12.22076321], [92.74312592, 12.22078133], [92.74316406, 12.22054672], [92.74391937, 12.22049046], [92.74425507, 12.22023869], [92.7442627, 12.21968079], [92.74395752, 12.21966171], [92.7440033, 12.2182579], [92.74368286, 12.21829891], [92.74368286, 12.21774101], [92.7434082, 12.21775532], [92.74344635, 12.21661282], [92.74312592, 12.21663094], [92.74312592, 12.21603203], [92.742836, 12.21603203], [92.74285126, 12.21437931], [92.74256134, 12.21438217], [92.7425766, 12.21356583], [92.742836, 12.21358395], [92.74285126, 12.21246338], [92.74313354, 12.21217346], [92.74368286, 12.21219063], [92.74368286, 12.21160984], [92.74397278, 12.21163082], [92.74397278, 12.21052074], [92.74423981, 12.21049976], [92.74423981, 12.21024036], [92.74423981, 12.20965004], [92.74453735, 12.20963192], [92.74453735, 12.21025181], [92.74476624, 12.2102108], [92.74479675, 12.21190929], [92.74423981, 12.21245956], [92.74423981, 12.21356964], [92.74341583, 12.21356964], [92.74341583, 12.21464062], [92.74368286, 12.21468925], [92.74368286, 12.21525002], [92.7440033, 12.2152319], [92.74394226, 12.21605015], [92.74423981, 12.21607971], [92.74423218, 12.21665192], [92.74452209, 12.21663094], [92.74449921, 12.21774101], [92.74479675, 12.21771812], [92.74481201, 12.21971226], [92.74510956, 12.21966171], [92.74510193, 12.22104073], [92.74481201, 12.22104073], [92.74476624, 12.22301006], [92.74453735, 12.22299194], [92.74455261, 12.22355461], [92.74396515, 12.22355461], [92.74396515, 12.22384453], [92.74288177, 12.22383118], [92.742836, 12.22408199], [92.74230957, 12.22411633], [92.74202728, 12.22463989], [92.74091339, 12.22469044], [92.7403717, 12.22518921], [92.74035645, 12.22579956], [92.74035645, 12.22607994], [92.7400589, 12.22604179], [92.7400589, 12.22652721], [92.73976135, 12.22687435], [92.73928833, 12.22685528], [92.73812866, 12.22803116], [92.73812866, 12.22910309], [92.73841858, 12.2290802], [92.73838043, 12.23108101], [92.73871613, 12.23104191], [92.73867798, 12.23160267], [92.73899078, 12.23158455], [92.7389679, 12.23327065], [92.73924255, 12.23330116], [92.73924255, 12.23384094], [92.73951721, 12.23385715], [92.73955536, 12.2344017], [92.73980713, 12.2344017], [92.73980713, 12.23577976], [92.74059296, 12.23572063], [92.74118805, 12.23496437], [92.74118805, 12.23412991], [92.74173737, 12.23357201], [92.74288177, 12.2335701], [92.74289703, 12.23326015], [92.74341583, 12.23326206], [92.74337006, 12.23275375], [92.74313354, 12.23268318], [92.74314117, 12.23243046], [92.74339294, 12.23237991], [92.7434082, 12.23163033], [92.74371338, 12.23133183], [92.74424744, 12.23129082], [92.74452209, 12.23104191], [92.74456024, 12.23050022], [92.74478149, 12.23047924], [92.74478149, 12.22718143], [92.74510193, 12.22716141], [92.74510956, 12.22663689], [92.74563599, 12.22659969], [92.74562836, 12.22801971], [92.74619293, 12.22857094], [92.74619293, 12.22994137], [92.74645996, 12.23022556], [92.74697876, 12.23024178], [92.74697876, 12.23052025], [92.74874115, 12.23050022], [92.74868774, 12.23023129], [92.7492218, 12.2302103], [92.74923706, 12.22994137], [92.74951935, 12.22994137], [92.74951935, 12.22940063], [92.74975586, 12.22941017], [92.75006866, 12.22908401], [92.75006866, 12.22858143], [92.75173187, 12.22856045], [92.75174713, 12.22883129], [92.75233459, 12.22881317], [92.75232697, 12.22939014], [92.75286865, 12.22990036], [92.753479, 12.22995472], [92.75366211, 12.23047924], [92.75418854, 12.23049068], [92.754776, 12.23050022], [92.75508118, 12.22994137], [92.75563049, 12.22994137], [92.75563049, 12.22939014], [92.75587463, 12.22941017], [92.75590515, 12.22856045], [92.75614929, 12.22860146], [92.75616455, 12.2290659], [92.75647736, 12.22939205], [92.7570343, 12.22939205], [92.75695801, 12.22966099], [92.75782013, 12.22972012], [92.75784302, 12.22995472], [92.75922394, 12.2299366], [92.75927734, 12.22939014], [92.75979614, 12.22939205], [92.76010895, 12.22886753], [92.76036072, 12.22887039], [92.76036072, 12.22914124], [92.76150513, 12.22913933], [92.76146698, 12.22937393], [92.76229858, 12.22937393], [92.7622757, 12.22408199], [92.7625885, 12.22408199], [92.7625885, 12.22355747], [92.76224518, 12.22357559], [92.76229858, 12.2230196], [92.7625885, 12.22301006], [92.76255798, 12.22244072], [92.76288605, 12.22244072], [92.76288605, 12.22104073], [92.7631073, 12.22102547], [92.76312256, 12.21992016], [92.7628479, 12.21996117], [92.7628479, 12.21885109], [92.76285553, 12.218297], [92.76261139, 12.21829891], [92.76261139, 12.21299076], [92.76228333, 12.21300316], [92.76229858, 12.21216869], [92.76262665, 12.21219063], [92.76255798, 12.20941067], [92.76283264, 12.20941067], [92.7628479, 12.20887089], [92.76313019, 12.20888233], [92.76313019, 12.20828533], [92.76339722, 12.20830059], [92.76339722, 12.20719147], [92.76395416, 12.20719337], [92.76400757, 12.20665073], [92.76452637, 12.20632267], [92.76451874, 12.20524216], [92.76535034, 12.20440769], [92.76535034, 12.20384979], [92.76590729, 12.20357609], [92.7664566, 12.2030201], [92.7664566, 12.20245934], [92.76701355, 12.2018919], [92.7678299, 12.2018919], [92.76786041, 12.20136547], [92.76811218, 12.20137024], [92.76815796, 12.19882202], [92.76784515, 12.1988287], [92.76786041, 12.19743443], [92.7676239, 12.19743156], [92.76758575, 12.19688892], [92.7670517, 12.19661999], [92.76703644, 12.19609165], [92.76647949, 12.19610977], [92.76644897, 12.19549179], [92.76616669, 12.1954937], [92.76618958, 12.19498634], [92.76590729, 12.19499111], [92.76590729, 12.19419098], [92.76567078, 12.19416142], [92.76565552, 12.19355488], [92.76530457, 12.19355488], [92.76535034, 12.19329739], [92.76535034, 12.19079685], [92.76593018, 12.19026184], [92.766716, 12.19022274], [92.76675415, 12.18942738], [92.7670517, 12.18939114], [92.76698303, 12.18856144], [92.7664566, 12.18828106], [92.76649475, 12.18634605], [92.76618958, 12.18608189], [92.76618958, 12.18496037], [92.76565552, 12.18493271], [92.76567078, 12.18442535], [92.76506042, 12.18385029], [92.76452637, 12.18385029], [92.76454926, 12.18330097], [92.76425171, 12.18332195], [92.76426697, 12.18274021], [92.7636795, 12.1821804], [92.76035309, 12.1821909], [92.7600708, 12.18245983], [92.75952148, 12.18248081], [92.75952148, 12.18273067], [92.75868988, 12.18276978], [92.75868988, 12.1830616], [92.75509644, 12.18302059], [92.75508118, 12.18327141], [92.7545929, 12.18330956], [92.75453186, 12.18275166], [92.75401306, 12.18275166], [92.75370026, 12.18248081], [92.7526474, 12.18242073], [92.75230408, 12.18271065], [92.75228119, 12.18329239], [92.75177002, 12.18327427], [92.75174713, 12.18385315], [92.75119781, 12.18387127], [92.75121307, 12.18363571], [92.75064087, 12.18360043], [92.75064087, 12.1833601], [92.75010681, 12.18330956], [92.7501297, 12.18297958], [92.74925995, 12.18302059], [92.74923706, 12.18245983], [92.74901581, 12.18241215], [92.74897766, 12.1816349], [92.74866486, 12.18161678], [92.74865723, 12.18104935], [92.74814606, 12.18050861], [92.74701691, 12.18047047], [92.74697876, 12.18080139], [92.74648285, 12.18104172], [92.74645233, 12.1816206], [92.74613953, 12.18191147], [92.74536896, 12.18188953], [92.7454071, 12.18216133], [92.74481201, 12.1821804], [92.74446869, 12.18274021], [92.74397278, 12.18274021], [92.74397278, 12.18330097], [92.74370575, 12.18325996], [92.74370575, 12.18382072], [92.74285889, 12.18382072], [92.74287415, 12.18413067], [92.74091339, 12.18413067], [92.74093628, 12.18441963], [92.73925018, 12.18441963], [92.73926544, 12.18467522], [92.73847961, 12.18467522], [92.73814392, 12.18413067], [92.7375946, 12.18413067], [92.73755646, 12.18440247], [92.73590088, 12.18469143], [92.73587799, 12.18521976], [92.73316193, 12.18521976], [92.7328949, 12.18552494], [92.73287964, 12.18634129], [92.73230743, 12.18634129], [92.73234558, 12.18715668], [92.73188782, 12.18745995], [92.73182678, 12.18797112], [92.73203278, 12.18801022], [92.73208618, 12.18855], [92.73181915, 12.18853188], [92.73174286, 12.18916798], [92.73159027, 12.18927479], [92.73165131, 12.19007015], [92.73174286, 12.19026184], [92.73178101, 12.19078064], [92.73201752, 12.19080162], [92.73201752, 12.19163132], [92.73175812, 12.19164944], [92.73178101, 12.19215965], [92.73147583, 12.19215965], [92.7314682, 12.19274139], [92.73118591, 12.19301033], [92.73008728, 12.19301033], [92.73008728, 12.19274139], [92.72926331, 12.19270039], [92.72898102, 12.19244862], [92.72897339, 12.19164944], [92.7284317, 12.19163418], [92.72647858, 12.1896944], [92.72649384, 12.18913078], [92.72592163, 12.18913078], [92.72594452, 12.18885994], [92.72457886, 12.18887997], [92.72454071, 12.188591], [92.72397614, 12.18855]]], [[[92.86646271, 12.23562145], [92.86621094, 12.23551083], [92.86565399, 12.23581219], [92.86508942, 12.23635006], [92.86468506, 12.23694706], [92.86430359, 12.23743343], [92.86392212, 12.23779964], [92.86354828, 12.23812103], [92.86321259, 12.23845577], [92.86293793, 12.23893929], [92.86279297, 12.23962975], [92.86261749, 12.24024105], [92.86250305, 12.24079037], [92.86231995, 12.24129963], [92.86208344, 12.24186993], [92.86165619, 12.24249935], [92.86146545, 12.24302769], [92.86156464, 12.24341297], [92.86165619, 12.24389172], [92.86170959, 12.24449062], [92.86167908, 12.24515438], [92.86170959, 12.24584103], [92.86192322, 12.24650097], [92.86207581, 12.24715137], [92.86224365, 12.24775696], [92.86251831, 12.24827003], [92.86291504, 12.2487278], [92.86339569, 12.24912167], [92.86396027, 12.24945259], [92.86450958, 12.24978256], [92.86506653, 12.25015926], [92.86564636, 12.25063992], [92.86601257, 12.250741], [92.86621857, 12.25058079], [92.86649323, 12.25035954], [92.86686707, 12.25020695], [92.86721802, 12.24999142], [92.86756134, 12.24973106], [92.86789703, 12.24949169], [92.86831665, 12.24929142], [92.86872864, 12.24902153], [92.8690033, 12.2485714], [92.86915588, 12.24800968], [92.86914825, 12.2474308], [92.86903381, 12.24691391], [92.86888123, 12.24646664], [92.86871338, 12.24609089], [92.86860657, 12.24573135], [92.86847687, 12.24535275], [92.86833954, 12.24484921], [92.86820221, 12.24427891], [92.86804199, 12.24375057], [92.86779785, 12.24320984], [92.8675766, 12.24264145], [92.8673172, 12.2422142], [92.86747742, 12.24178123], [92.86760712, 12.2412796], [92.86771393, 12.24078846], [92.86756134, 12.24029064], [92.86750031, 12.23983002], [92.86750031, 12.23941135], [92.86750031, 12.2390213], [92.86745453, 12.23865032], [92.86730194, 12.2383194], [92.86736298, 12.23784065], [92.86738586, 12.23731709], [92.86721039, 12.23685169], [92.86694336, 12.23637104], [92.86662292, 12.23586178], [92.86646271, 12.23562145]]], [[[92.90167236, 12.25584984], [92.90193939, 12.25552177], [92.90215302, 12.25515079], [92.90225983, 12.25471115], [92.90248108, 12.25430107], [92.90271759, 12.25390625], [92.9030304, 12.25354195], [92.90335846, 12.25319958], [92.90376282, 12.25294018], [92.90422821, 12.25275993], [92.90468597, 12.25252056], [92.90509796, 12.25220203], [92.90542603, 12.251791], [92.90569305, 12.25133991], [92.9058075, 12.25082016], [92.90583801, 12.25025082], [92.90589905, 12.24970055], [92.90605164, 12.24920177], [92.90598297, 12.24876881], [92.9058609, 12.24839115], [92.90583801, 12.24803829], [92.90587616, 12.24769974], [92.90610504, 12.24742889], [92.9063797, 12.24715996], [92.90667725, 12.24690533], [92.9070282, 12.24666977], [92.90742493, 12.24647427], [92.90783691, 12.24629879], [92.90813446, 12.24602318], [92.90834045, 12.24568558], [92.90851593, 12.24535275], [92.908638, 12.244977], [92.90880585, 12.24461174], [92.90891266, 12.24414921], [92.90899658, 12.24365044], [92.90917969, 12.24314022], [92.90937805, 12.24264336], [92.90943909, 12.24213505], [92.90944672, 12.24165821], [92.90947723, 12.24123192], [92.90963745, 12.24089336], [92.90975952, 12.24052811], [92.9099884, 12.24023247], [92.91025543, 12.2399416], [92.91052246, 12.2396183], [92.91075897, 12.23923111], [92.91094971, 12.23877525], [92.91116333, 12.23828506], [92.91139984, 12.23777008], [92.91168213, 12.23725986], [92.91192627, 12.23678112], [92.91213226, 12.23632145], [92.9122467, 12.23587608], [92.91240692, 12.2354908], [92.91249847, 12.23506927], [92.91260529, 12.23464108], [92.9128418, 12.23425102], [92.91314697, 12.23388195], [92.91345978, 12.23350143], [92.91374969, 12.23317146], [92.91390991, 12.23281097], [92.91409302, 12.23255062], [92.91416168, 12.23223019], [92.91423798, 12.23190975], [92.91440582, 12.2316103], [92.91442871, 12.23124886], [92.91442871, 12.23085117], [92.91444397, 12.230443], [92.91439819, 12.23004436], [92.91420746, 12.22971821], [92.91413879, 12.22937107], [92.91404724, 12.22907066], [92.91391754, 12.22883129], [92.91385651, 12.2285099], [92.91374969, 12.22818375], [92.91363525, 12.22779655], [92.91359711, 12.22732925], [92.91350555, 12.22685146], [92.91336823, 12.22637653], [92.91333771, 12.22584057], [92.91333008, 12.22528267], [92.91333008, 12.22473145], [92.91333771, 12.22419071], [92.91336823, 12.22367096], [92.91343689, 12.22319984], [92.91327667, 12.22280979], [92.91287994, 12.22267532], [92.91247559, 12.22253418], [92.91160583, 12.222682], [92.91136169, 12.22319031], [92.91165924, 12.22372055], [92.91184998, 12.22411633], [92.91179657, 12.22445488], [92.91171265, 12.22473145], [92.91168213, 12.22498608], [92.91168213, 12.22525978], [92.91160583, 12.22561455], [92.91147614, 12.22613335], [92.91146851, 12.22683525], [92.91162109, 12.22747135], [92.91162109, 12.22804737], [92.91143036, 12.22851467], [92.91134644, 12.22891998], [92.91117859, 12.22922134], [92.911026, 12.22951984], [92.91082001, 12.2298317], [92.91057587, 12.23015118], [92.91031647, 12.23049068], [92.90995026, 12.23074055], [92.90953827, 12.2309103], [92.90920258, 12.23113823], [92.90892029, 12.23134518], [92.90860748, 12.23141956], [92.9083252, 12.23151207], [92.90805817, 12.23148727], [92.9078064, 12.23139095], [92.90756989, 12.23125935], [92.90735626, 12.23099041], [92.90709686, 12.23071194], [92.9068222, 12.23040199], [92.90660095, 12.23001194], [92.90637207, 12.22957039], [92.90583038, 12.22919083], [92.90509796, 12.22920132], [92.90447998, 12.22933006], [92.90397644, 12.22923946], [92.90357971, 12.22896099], [92.90320587, 12.2286396], [92.90283966, 12.2283392], [92.9024353, 12.22808838], [92.9019928, 12.22796059], [92.90149689, 12.22781944], [92.90093994, 12.22785759], [92.90042877, 12.22809982], [92.90001678, 12.22825241], [92.89956665, 12.22842312], [92.8988266, 12.22873974], [92.89820099, 12.22918034], [92.89803314, 12.22966957], [92.89785767, 12.23008537], [92.89774323, 12.23044968], [92.89755249, 12.23067665], [92.89749908, 12.2308321], [92.89722443, 12.2308321], [92.89694214, 12.23110962], [92.89583588, 12.23110962], [92.89554596, 12.23139095], [92.89527893, 12.23139095], [92.89499664, 12.23167133], [92.89499664, 12.23278141], [92.89472198, 12.23278141], [92.89444733, 12.23306084], [92.89416504, 12.23305511], [92.89389038, 12.23333263], [92.89362335, 12.23332977], [92.89305878, 12.23389053], [92.89167023, 12.23389053], [92.89111328, 12.23332977], [92.89058685, 12.23316574], [92.89028168, 12.23275089], [92.88999176, 12.23230171], [92.8897171, 12.23185062], [92.88942719, 12.23141956], [92.88913727, 12.23099041], [92.88878632, 12.23059082], [92.88838196, 12.2302103], [92.88799286, 12.22980022], [92.88757324, 12.22943115], [92.88713837, 12.2290926], [92.88670349, 12.22881126], [92.8862915, 12.22852135], [92.88587952, 12.22824955], [92.88549042, 12.22789001], [92.88504791, 12.22756577], [92.88474274, 12.22709179], [92.88445282, 12.22653198], [92.8841629, 12.22596931], [92.88421631, 12.22530079], [92.88452911, 12.22494984], [92.88484192, 12.22463989], [92.88484192, 12.22445107], [92.88481903, 12.22426605], [92.88469696, 12.22406101], [92.884552, 12.22396088], [92.88427734, 12.2238903], [92.88400269, 12.2239151], [92.8837738, 12.224123], [92.8837204, 12.22441196], [92.88354492, 12.22465801], [92.8833313, 12.22480392], [92.88297272, 12.22462368], [92.88258362, 12.22422981], [92.8824234, 12.22387886], [92.88265228, 12.22359753], [92.88279724, 12.223382], [92.88307953, 12.2232132], [92.88349915, 12.22301006], [92.88397217, 12.22267056], [92.88432312, 12.22214031], [92.88419342, 12.2215023], [92.88373566, 12.22103691], [92.8833313, 12.22056866], [92.88294983, 12.22016144], [92.88261414, 12.21974373], [92.88224792, 12.21934795], [92.88191986, 12.21893978], [92.8815918, 12.21854973], [92.88127136, 12.21818066], [92.88109589, 12.21772957], [92.88092804, 12.21728992], [92.8809433, 12.21687031], [92.88109589, 12.21648121], [92.88127899, 12.21607018], [92.88144684, 12.2156353], [92.88168335, 12.21520042], [92.88185883, 12.21475315], [92.8817749, 12.21426964], [92.88162994, 12.21379089], [92.88143158, 12.21337891], [92.88134003, 12.21298695], [92.88117981, 12.21269035], [92.88105774, 12.21238136], [92.88090515, 12.2121048], [92.88084412, 12.21172428], [92.88079071, 12.21124077], [92.88057709, 12.21071911], [92.88027954, 12.21028137], [92.88027954, 12.21000099], [92.87999725, 12.20972061], [92.87953186, 12.20933342], [92.87944794, 12.20902348], [92.87940216, 12.20871067], [92.87934113, 12.20836163], [92.87923431, 12.2082777], [92.87917328, 12.20832443], [92.87892914, 12.20852184], [92.87889099, 12.20892143], [92.87880707, 12.20926857], [92.87870026, 12.20951557], [92.87850952, 12.20972061], [92.87786102, 12.21062088], [92.87763214, 12.21099472], [92.87751007, 12.21137333], [92.87741852, 12.21171284], [92.8772583, 12.21198177], [92.87718201, 12.21230125], [92.87700653, 12.2126112], [92.87692261, 12.21298885], [92.87677765, 12.21338081], [92.8766861, 12.21382141], [92.87663269, 12.21432495], [92.8764801, 12.21479034], [92.87635803, 12.21527958], [92.87617493, 12.21571541], [92.87610626, 12.21615696], [92.87602997, 12.21656322], [92.87587738, 12.21691132], [92.8757782, 12.21733093], [92.87558746, 12.21770859], [92.87545013, 12.21814919], [92.87528992, 12.21864128], [92.87513733, 12.21916962], [92.87496948, 12.21973133], [92.87477112, 12.22025871], [92.87473297, 12.22081089], [92.87471008, 12.22133064], [92.87464905, 12.22180939], [92.87448883, 12.22224045], [92.87445068, 12.22270012], [92.87444305, 12.22316074], [92.87444305, 12.2235918], [92.87439728, 12.22401142], [92.87423706, 12.22442627], [92.87419128, 12.22487926], [92.87425995, 12.22535133], [92.87441254, 12.225811], [92.87445831, 12.22628975], [92.87451172, 12.22676182], [92.87446594, 12.22723961], [92.87444305, 12.22774029], [92.87439728, 12.22828197], [92.87418365, 12.22878838], [92.87400055, 12.22932053], [92.87380219, 12.22980022], [92.87361145, 12.23017597], [92.87342072, 12.23047924], [92.8732605, 12.23078918], [92.87304688, 12.23108101], [92.87278748, 12.23137856], [92.87250519, 12.2317028], [92.8722229, 12.23204041], [92.87194061, 12.23237133], [92.87166595, 12.23267174], [92.87140656, 12.23294735], [92.87120819, 12.23325062], [92.87107849, 12.2335968], [92.87088013, 12.23388195], [92.87082672, 12.23423958], [92.87077332, 12.23458195], [92.8706131, 12.23487759], [92.8705368, 12.23522186], [92.8704071, 12.23555946], [92.87030029, 12.23589039], [92.87026978, 12.2362318], [92.87021637, 12.23653698], [92.87006378, 12.23681259], [92.86997223, 12.23717308], [92.86981964, 12.23758125], [92.86973572, 12.23806858], [92.86972046, 12.23860168], [92.86972046, 12.23913956], [92.86976624, 12.23965931], [92.86994934, 12.24013996], [92.87000275, 12.24063015], [92.87000275, 12.24112701], [92.87001038, 12.241642], [92.87008667, 12.24215126], [92.87023926, 12.24264145], [92.87032318, 12.24316502], [92.87051392, 12.24364281], [92.8706131, 12.24419308], [92.87084198, 12.24469185], [92.87110901, 12.24519062], [92.87138367, 12.2456789], [92.87166595, 12.24619102], [92.87197876, 12.24674129], [92.8723526, 12.24724007], [92.87277222, 12.24776173], [92.87322235, 12.24821091], [92.873703, 12.24856186], [92.87419891, 12.24880123], [92.87482452, 12.2488327], [92.87534332, 12.24884224], [92.87575531, 12.24870968], [92.87621307, 12.2485733], [92.87667084, 12.24837303], [92.87718201, 12.24829102], [92.87767029, 12.24810123], [92.87818146, 12.24806309], [92.8786087, 12.24805641], [92.8786087, 12.24722195], [92.87889099, 12.24694443], [92.87889099, 12.24666786], [92.87944794, 12.24611187], [92.87944794, 12.24361229], [92.8797226, 12.24333286], [92.87966156, 12.24304199], [92.87948608, 12.24268436], [92.87949371, 12.24228954], [92.87967682, 12.24187946], [92.87970734, 12.24143028], [92.8797226, 12.24099064], [92.8797226, 12.24055481], [92.87999725, 12.2402792], [92.87999725, 12.2397213], [92.88083649, 12.23888874], [92.88111115, 12.23889065], [92.8813858, 12.23916721], [92.8813858, 12.23944473], [92.88124847, 12.24001503], [92.881073, 12.24096107], [92.8811264, 12.24108887], [92.88136292, 12.2412138], [92.88152313, 12.24132061], [92.88162994, 12.24129105], [92.88173676, 12.2411499], [92.88183594, 12.24094009], [92.88196564, 12.24073792], [92.88208771, 12.24063015], [92.88227844, 12.24057102], [92.88253021, 12.24053001], [92.88272095, 12.24051189], [92.88292694, 12.24051189], [92.88310242, 12.24011135], [92.88312531, 12.23992634], [92.88324738, 12.2397604], [92.883461, 12.23978043], [92.88358307, 12.23990345], [92.88391876, 12.24028206], [92.88406372, 12.24007702], [92.8841095, 12.23983002], [92.8841095, 12.23962116], [92.88419342, 12.23935223], [92.88446045, 12.23924923], [92.88463593, 12.23954773], [92.88471222, 12.23999214], [92.88477325, 12.24055958], [92.88495636, 12.24117088], [92.88503265, 12.24175644], [92.88514709, 12.24221039], [92.88526154, 12.24257946], [92.88532257, 12.24291039], [92.88542175, 12.24320126], [92.88552856, 12.24349976], [92.88555908, 12.24386024], [92.88559723, 12.24424267], [92.88577271, 12.24460125], [92.88582611, 12.2449789], [92.88580322, 12.24537086], [92.88565063, 12.24577045], [92.88556671, 12.24621201], [92.88555145, 12.24669075], [92.88551331, 12.24720097], [92.88532257, 12.24770927], [92.88532257, 12.24829102], [92.88555908, 12.24888515], [92.88585663, 12.24948025], [92.88625336, 12.25001144], [92.88661957, 12.25053978], [92.88695526, 12.25110817], [92.88732147, 12.25160027], [92.88774872, 12.25199604], [92.88821411, 12.25233364], [92.88882446, 12.25252342], [92.88943481, 12.25269222], [92.8900528, 12.25259113], [92.89063263, 12.25274181], [92.89118195, 12.25280094], [92.89165497, 12.25291729], [92.89206696, 12.25306129], [92.89241028, 12.2532568], [92.89266205, 12.25351429], [92.89285278, 12.25383282], [92.8928299, 12.25454235], [92.89306641, 12.25504398], [92.89363098, 12.25519371], [92.89391327, 12.25536537], [92.89427948, 12.25528145], [92.89470673, 12.25555038], [92.89524078, 12.25577068], [92.89582825, 12.25583172], [92.89639282, 12.25584126], [92.89686584, 12.25584126], [92.89703369, 12.25583744], [92.89722443, 12.25583458], [92.89861298, 12.25583458], [92.8989563, 12.2561264], [92.89942169, 12.2562294], [92.89993286, 12.25636101], [92.90034485, 12.2563839], [92.90048218, 12.25639057], [92.90099335, 12.25634956], [92.90136719, 12.25613976], [92.90167236, 12.25584984]]], [[[92.67346191, 11.48752022], [92.673172, 11.48735619], [92.67259216, 11.48733044], [92.67193604, 11.48736], [92.67124176, 11.48728943], [92.67061615, 11.48756123], [92.67047882, 11.48790932], [92.67019653, 11.48880959], [92.67125702, 11.48890972], [92.67158508, 11.4890604], [92.67197418, 11.48911285], [92.67235565, 11.48898697], [92.67271423, 11.48868942], [92.67312622, 11.48828125], [92.67344666, 11.48775864], [92.67346191, 11.48752022]]], [[[92.61048889, 11.50405025], [92.61021423, 11.50392723], [92.60980988, 11.50407982], [92.60941315, 11.50423908], [92.60904694, 11.50475025], [92.60913086, 11.50521946], [92.60916901, 11.50562096], [92.60925293, 11.50597191], [92.60943604, 11.50627899], [92.60964203, 11.50660133], [92.60983276, 11.50701141], [92.6100769, 11.50732994], [92.61032104, 11.50774002], [92.61068726, 11.50804996], [92.61109924, 11.5083456], [92.61147308, 11.50866985], [92.61186981, 11.50896168], [92.61219788, 11.50933075], [92.61248016, 11.50977993], [92.61277771, 11.5102396], [92.61322021, 11.51062107], [92.61382294, 11.51085091], [92.61445618, 11.51111126], [92.61508942, 11.51139069], [92.61563873, 11.51160145], [92.61599731, 11.51149178], [92.61625671, 11.51129818], [92.61634827, 11.51101112], [92.61619568, 11.51066208], [92.61591339, 11.51026821], [92.61561584, 11.50987053], [92.61533356, 11.50951576], [92.61500549, 11.50922394], [92.61468506, 11.50892258], [92.61431885, 11.50861454], [92.61389923, 11.50828457], [92.61348724, 11.50791073], [92.61312103, 11.50750256], [92.6128006, 11.50710011], [92.61252594, 11.50670147], [92.61225891, 11.50631142], [92.61212158, 11.50584221], [92.61197662, 11.50534916], [92.61167908, 11.50494957], [92.61138153, 11.50458431], [92.61104584, 11.50424576], [92.61048889, 11.50405025]]], [[[92.64444733, 11.51303005], [92.6440506, 11.51303005], [92.64382172, 11.51316738], [92.64368439, 11.51330566], [92.64369202, 11.51372147], [92.64389038, 11.51418972], [92.6440506, 11.51447964], [92.64444733, 11.51502037], [92.64473724, 11.51516056], [92.64512634, 11.51557064], [92.64567566, 11.51539612], [92.64607239, 11.51494026], [92.64615631, 11.51453018], [92.64610291, 11.51428127], [92.6460495, 11.51405144], [92.64559937, 11.51379108], [92.64524078, 11.51357746], [92.6452179, 11.51344013], [92.6450119, 11.51316738], [92.64480591, 11.51310062], [92.64444733, 11.51303005]]], [[[92.62797546, 11.54216194], [92.62741852, 11.54216194], [92.62706757, 11.54271126], [92.62679291, 11.54326725], [92.62664795, 11.54402637], [92.62671661, 11.54478073], [92.6269989, 11.54540539], [92.62706757, 11.54630089], [92.62721252, 11.54747677], [92.62713623, 11.54837036], [92.62713623, 11.54858017], [92.62734985, 11.54899025], [92.6277771, 11.54916954], [92.62827301, 11.54924107], [92.62889099, 11.54896069], [92.62957764, 11.54854107], [92.6297226, 11.54749966], [92.6297226, 11.54721928], [92.6297226, 11.54666805], [92.62944794, 11.54638958], [92.62944794, 11.54361057], [92.62923431, 11.54278183], [92.62916565, 11.54257679], [92.62876129, 11.54230118], [92.62797546, 11.54216194]]], [[[92.6046524, 11.53458214], [92.6046524, 11.53430557], [92.60520935, 11.53430557], [92.60520935, 11.53458214], [92.60548401, 11.53485966], [92.60575867, 11.5348053], [92.60610962, 11.53452873], [92.60639191, 11.53446102], [92.60624695, 11.53399086], [92.60624695, 11.5335598], [92.60646057, 11.53321648], [92.60646057, 11.53100967], [92.6065979, 11.52997112], [92.60666656, 11.52893829], [92.60666656, 11.52832127], [92.60674286, 11.52811146], [92.60681152, 11.52783489], [92.60688019, 11.52707577], [92.60681152, 11.5261097], [92.60681152, 11.52396965], [92.6065979, 11.52349091], [92.6065979, 11.52307034], [92.60652924, 11.52238369], [92.60646057, 11.52190018], [92.60631561, 11.52190018], [92.60603333, 11.52208042], [92.60542297, 11.52259064], [92.60507202, 11.52279568], [92.6046524, 11.52313995], [92.60409546, 11.52348709], [92.60340118, 11.52362347], [92.60256195, 11.52383137], [92.60188293, 11.52429962], [92.60187531, 11.52680492], [92.60159302, 11.52708054], [92.60187531, 11.52735901], [92.60188293, 11.52930069], [92.60131836, 11.52986145], [92.60076141, 11.53013706], [92.60076141, 11.53097057], [92.60131836, 11.53125191], [92.60131836, 11.53236198], [92.60103607, 11.53263664], [92.60103607, 11.53319359], [92.60076141, 11.5334692], [92.60103607, 11.53374958], [92.60103607, 11.53458214], [92.60131836, 11.53485966], [92.60131836, 11.53569412], [92.60159302, 11.53597164], [92.60159302, 11.53707886], [92.60243225, 11.53791618], [92.60243225, 11.5381937], [92.60298157, 11.5381937], [92.60353851, 11.53763771], [92.60353851, 11.53736019], [92.6038208, 11.53707886], [92.6038208, 11.53680611], [92.60410309, 11.53652954], [92.60410309, 11.53625202], [92.60437012, 11.53597164], [92.60437012, 11.53485966], [92.6046524, 11.53458214]]], [[[92.61000061, 11.55888939], [92.6102066, 11.5587492], [92.61076355, 11.55937195], [92.61166382, 11.56069374], [92.61194611, 11.56097221], [92.61266327, 11.56097221], [92.61328888, 11.56075668], [92.61342621, 11.56033134], [92.61357117, 11.56027412], [92.61412811, 11.56020641], [92.61448669, 11.55972004], [92.61468506, 11.55923939], [92.61469269, 11.55807018], [92.61448669, 11.55751038], [92.61483002, 11.55716991], [92.61546326, 11.55709934], [92.61594391, 11.5568943], [92.61672974, 11.55665016], [92.61699677, 11.55707169], [92.61699677, 11.55724144], [92.61699677, 11.5577898], [92.61734009, 11.55799961], [92.61741638, 11.55862045], [92.61734009, 11.55903244], [92.61712646, 11.55910015], [92.61706543, 11.55944729], [92.61734009, 11.55958366], [92.61811066, 11.55979061], [92.61839294, 11.56007099], [92.61853027, 11.56007099], [92.61882019, 11.55985928], [92.61908722, 11.5595789], [92.61909485, 11.55930328], [92.61930847, 11.55888939], [92.62020874, 11.55764198], [92.62020874, 11.55733013], [92.6202774, 11.55609035], [92.6202774, 11.55416203], [92.62020874, 11.55360985], [92.62020874, 11.55278015], [92.62020874, 11.55179977], [92.61992645, 11.55152702], [92.61992645, 11.55097103], [92.61965179, 11.5506897], [92.61965179, 11.54986095], [92.61936951, 11.54958057], [92.61936951, 11.54902744], [92.6194458, 11.54891014], [92.61923218, 11.54822445], [92.61930084, 11.54739475], [92.61930084, 11.54635143], [92.61923218, 11.54580879], [92.61936951, 11.54520035], [92.61923218, 11.54380989], [92.61923218, 11.54325962], [92.61908722, 11.5425806], [92.61908722, 11.54236031], [92.6185379, 11.54207993], [92.6185379, 11.54069424], [92.61826324, 11.54041576], [92.6180191, 11.54020023], [92.61797333, 11.53985977], [92.61797333, 11.53903008], [92.61736298, 11.5381918], [92.6177063, 11.53763771], [92.6177063, 11.53681087], [92.61631775, 11.53542042], [92.61519623, 11.53485012], [92.61437225, 11.53458214], [92.61437225, 11.53430557], [92.61381531, 11.53374958], [92.61325836, 11.5334692], [92.61159515, 11.53319359], [92.61083221, 11.53208447], [92.61048126, 11.53180599], [92.6102066, 11.5318718], [92.6102066, 11.53264046], [92.60993195, 11.53291512], [92.60993195, 11.53319073], [92.60958099, 11.53374958], [92.60964966, 11.53402805], [92.60964966, 11.5342989], [92.6085434, 11.53541565], [92.6074295, 11.53597164], [92.6074295, 11.53625202], [92.60714722, 11.53652954], [92.60714722, 11.53680611], [92.60687256, 11.53707886], [92.60687256, 11.53736019], [92.60674286, 11.53771114], [92.60687256, 11.53791618], [92.60687256, 11.53847027], [92.6065979, 11.53874969], [92.6065979, 11.53902817], [92.60631561, 11.53930378], [92.60632324, 11.54207993], [92.60603333, 11.54236031], [92.60604095, 11.5429163], [92.60575867, 11.54319], [92.60575867, 11.5437479], [92.60547638, 11.54402161], [92.60548401, 11.54652596], [92.60575867, 11.54679108], [92.60575867, 11.54736137], [92.60603333, 11.5476408], [92.60603333, 11.54875088], [92.60575867, 11.54903126], [92.60575867, 11.54930496], [92.60547638, 11.54958057], [92.60548401, 11.54986095], [92.6046524, 11.55069256], [92.60410309, 11.55097103], [92.60409546, 11.55152702], [92.6038208, 11.55180454], [92.60243225, 11.55208111], [92.60243225, 11.55236053], [92.60214996, 11.55264091], [92.60214996, 11.55291462], [92.60159302, 11.55347061], [92.60188293, 11.55375099], [92.60188293, 11.5551424], [92.60230255, 11.55521011], [92.60299683, 11.55538082], [92.60353851, 11.5551424], [92.60492706, 11.55402946], [92.60507202, 11.55381966], [92.60547638, 11.55389023], [92.6057663, 11.55492973], [92.60679626, 11.55500031], [92.60714722, 11.55458069], [92.60714722, 11.55430508], [92.6074295, 11.55402946], [92.60778046, 11.55389023], [92.60887146, 11.55381966], [92.60993195, 11.55395889], [92.61000061, 11.55506039], [92.60993195, 11.55569267], [92.60909271, 11.5559597], [92.6085434, 11.55625153], [92.60826111, 11.55652714], [92.60770416, 11.55680466], [92.60769653, 11.55708122], [92.6074295, 11.55736065], [92.6074295, 11.55764198], [92.60714722, 11.55791473], [92.60714722, 11.55819321], [92.60687256, 11.55847073], [92.60714722, 11.5587492], [92.60714722, 11.559021], [92.60604095, 11.5601368], [92.60603333, 11.56096935], [92.60575867, 11.56124973], [92.60632324, 11.56180096], [92.60632324, 11.56209087], [92.60687256, 11.56264019], [92.60687256, 11.5629158], [92.60714722, 11.56319427], [92.60798645, 11.56319427], [92.60826111, 11.5629158], [92.60826111, 11.56264019], [92.6085434, 11.56235981], [92.6085434, 11.56124973], [92.60909271, 11.56096935], [92.60964966, 11.56041622], [92.60964966, 11.55985928], [92.60993195, 11.5595789], [92.61000061, 11.55888939]]], [[[92.59718323, 11.54166985], [92.59697723, 11.54127979], [92.59694672, 11.54085064], [92.59694672, 11.54042053], [92.59693909, 11.53998089], [92.59687042, 11.53952026], [92.59670258, 11.53900146], [92.59662628, 11.53840065], [92.59645844, 11.53781986], [92.5963974, 11.53724098], [92.59638214, 11.53670311], [92.59631348, 11.53622723], [92.59613037, 11.53585052], [92.59600067, 11.53543186], [92.59583282, 11.53499222], [92.59566498, 11.53455639], [92.59571075, 11.53353119], [92.59571075, 11.53312111], [92.5955658, 11.53284264], [92.59529114, 11.53263092], [92.59494781, 11.53270054], [92.59467316, 11.5329113], [92.59459686, 11.53345966], [92.59459686, 11.53394318], [92.59461212, 11.53429222], [92.59386444, 11.53448582], [92.59329224, 11.53479099], [92.59291077, 11.53514004], [92.59292603, 11.53560925], [92.59294128, 11.5360899], [92.59285736, 11.53623199], [92.5925827, 11.53629971], [92.59172821, 11.53573036], [92.59152985, 11.53559971], [92.59114838, 11.53543186], [92.59079742, 11.53523254], [92.59049988, 11.53499603], [92.59023285, 11.5347414], [92.58995819, 11.53468037], [92.58969116, 11.53448105], [92.58943176, 11.53410721], [92.58920288, 11.53379059], [92.58898926, 11.53367043], [92.58844757, 11.5334692], [92.58808899, 11.53348064], [92.58760071, 11.53349209], [92.58751678, 11.53417969], [92.58756256, 11.53485012], [92.58766937, 11.53528118], [92.58790588, 11.5357008], [92.58779907, 11.53627014], [92.5878067, 11.53661919], [92.58782196, 11.53715038], [92.58776855, 11.53764725], [92.58778381, 11.5381422], [92.58777618, 11.5385952], [92.58773041, 11.53898335], [92.58753204, 11.53928089], [92.58731079, 11.53963375], [92.58706665, 11.5400629], [92.58646393, 11.54089165], [92.58631897, 11.54103088], [92.58596802, 11.54103088], [92.58583069, 11.54089165], [92.58596802, 11.54041195], [92.58596802, 11.54000092], [92.58611298, 11.53944111], [92.58611298, 11.5391674], [92.58583069, 11.53889084], [92.58583069, 11.53861141], [92.58555603, 11.53833294], [92.58555603, 11.53777695], [92.58528137, 11.53750134], [92.58528137, 11.53693962], [92.58499908, 11.53666687], [92.58499908, 11.53639126], [92.5847168, 11.53611088], [92.58429718, 11.53507233], [92.58416748, 11.53444004], [92.58361816, 11.53444004], [92.58319855, 11.53534985], [92.58304596, 11.53611088], [92.58319092, 11.53707886], [92.58326721, 11.53944302], [92.58304596, 11.53972054], [92.58304596, 11.54000092], [92.58305359, 11.54027653], [92.58333588, 11.54083347], [92.58444214, 11.54194546], [92.58472443, 11.54194546], [92.58499908, 11.54166698], [92.58528137, 11.54194546], [92.58555603, 11.54194546], [92.58580017, 11.54156303], [92.58600616, 11.54163074], [92.58621979, 11.541852], [92.58628845, 11.54298019], [92.58634949, 11.54348183], [92.5861969, 11.54397202], [92.58615112, 11.54443932], [92.58609772, 11.54487228], [92.58599854, 11.54524136], [92.58584595, 11.54556179], [92.58579254, 11.54587936], [92.5856781, 11.54613018], [92.58557129, 11.54640293], [92.58551788, 11.54673195], [92.5853653, 11.54700279], [92.58525848, 11.54728127], [92.5851059, 11.54752922], [92.58496094, 11.54780102], [92.58474731, 11.54805088], [92.58455658, 11.54837894], [92.58441925, 11.54880142], [92.58421326, 11.54922962], [92.58416748, 11.54975128], [92.58422089, 11.55030537], [92.58439636, 11.55088043], [92.58447266, 11.55153561], [92.58467865, 11.55215073], [92.58500671, 11.55264091], [92.58540344, 11.55296707], [92.58584595, 11.55309963], [92.58620453, 11.55334091], [92.586586, 11.55350113], [92.58677673, 11.55401993], [92.58702087, 11.55443954], [92.58722687, 11.55483246], [92.58746338, 11.55515099], [92.58758545, 11.55549526], [92.58774567, 11.55581379], [92.58782196, 11.55618095], [92.58805847, 11.55654144], [92.58828735, 11.55702019], [92.5880127, 11.55751038], [92.58795166, 11.55797005], [92.58792877, 11.55847073], [92.58811951, 11.55896091], [92.58833313, 11.5593853], [92.58854675, 11.55979347], [92.58869934, 11.56010056], [92.58911133, 11.56058025], [92.58925629, 11.56101036], [92.58937836, 11.56140041], [92.58937836, 11.56175995], [92.58930206, 11.56216145], [92.58924103, 11.56240082], [92.58893585, 11.5626812], [92.58888245, 11.56304073], [92.58879852, 11.56340122], [92.58863831, 11.56371117], [92.58854675, 11.56406403], [92.58837128, 11.56437397], [92.58828735, 11.56472969], [92.58808899, 11.56503105], [92.58805847, 11.5654211], [92.58805847, 11.5658474], [92.5880127, 11.56630516], [92.587883, 11.56676483], [92.58791351, 11.56737137], [92.58798218, 11.56769466], [92.58798218, 11.56822205], [92.58798981, 11.56861115], [92.58795929, 11.56907177], [92.5880127, 11.56950474], [92.58805847, 11.56993294], [92.58807373, 11.57032299], [92.58816528, 11.57065296], [92.58830261, 11.570961], [92.58837128, 11.57137585], [92.58857727, 11.57173061], [92.58870697, 11.57217789], [92.58887482, 11.57260227], [92.58900452, 11.5730238], [92.58914185, 11.57339954], [92.5892334, 11.57377625], [92.58940125, 11.57408142], [92.5894928, 11.57444954], [92.58972168, 11.57473087], [92.58998108, 11.57505035], [92.590271, 11.57538891], [92.59055328, 11.57576084], [92.5908432, 11.57610989], [92.59115601, 11.57639027], [92.59146881, 11.57666969], [92.59179688, 11.57695103], [92.59213257, 11.5772171], [92.59243774, 11.57739258], [92.5925293, 11.57734966], [92.59268188, 11.57727718], [92.59288788, 11.57697105], [92.59303284, 11.57664108], [92.59310913, 11.57628059], [92.59327698, 11.57594109], [92.59336853, 11.57554245], [92.59354401, 11.57514286], [92.59360504, 11.57464027], [92.59364319, 11.57408619], [92.59379578, 11.57356167], [92.59393311, 11.57304192], [92.5941391, 11.57261086], [92.59425354, 11.57216358], [92.59442902, 11.57179546], [92.59456635, 11.57141018], [92.59469604, 11.57100201], [92.59468842, 11.57054424], [92.59451294, 11.57004547], [92.59435272, 11.56945038], [92.59414673, 11.56881046], [92.59388733, 11.56815529], [92.59333038, 11.567132], [92.59355927, 11.56662369], [92.59429932, 11.56618404], [92.59487915, 11.56580639], [92.59538269, 11.56544971], [92.59581757, 11.56509018], [92.59619141, 11.56471634], [92.59649658, 11.56431103], [92.59671021, 11.56386185], [92.59690857, 11.56343079], [92.59699249, 11.56298447], [92.59716797, 11.56260586], [92.59722137, 11.56219101], [92.59722137, 11.56175995], [92.59725189, 11.5613203], [92.59737396, 11.56089878], [92.59725189, 11.56052017], [92.59707642, 11.56013966], [92.59702301, 11.55977058], [92.59693909, 11.55939007], [92.59707642, 11.55891132], [92.59726715, 11.5584898], [92.59732056, 11.55796814], [92.59749603, 11.55731964], [92.59750366, 11.55663204], [92.5973587, 11.55594158], [92.59738922, 11.55527782], [92.59723663, 11.55468082], [92.5970993, 11.55405045], [92.59676361, 11.55343723], [92.59680176, 11.55278969], [92.59694672, 11.5521307], [92.59697723, 11.55150032], [92.59712219, 11.5509119], [92.59721375, 11.55034161], [92.59722137, 11.54980183], [92.59722137, 11.54930687], [92.59722137, 11.54885101], [92.59722137, 11.54841137], [92.59722137, 11.54796886], [92.59722137, 11.5475111], [92.59722137, 11.54704762], [92.59722137, 11.54658127], [92.59726715, 11.54613686], [92.59745789, 11.54576111], [92.59749603, 11.54535007], [92.59749603, 11.54493999], [92.59749603, 11.54452991], [92.59749603, 11.54413128], [92.59749603, 11.54371166], [92.59749603, 11.54329872], [92.59744263, 11.54290009], [92.59725952, 11.54251957], [92.59722137, 11.54209995], [92.59718323, 11.54166985]]], [[[92.5745163, 11.56257153], [92.57367706, 11.56257153], [92.57367706, 11.56284714], [92.5734024, 11.56312466], [92.5734024, 11.56340122], [92.57284546, 11.56395721], [92.57285309, 11.56562138], [92.57367706, 11.56645775], [92.57367706, 11.56701088], [92.57588959, 11.56923962], [92.57588959, 11.56952095], [92.57604218, 11.56999683], [92.5761795, 11.57090187], [92.57701111, 11.57090187], [92.57701111, 11.56895828], [92.57673645, 11.56867981], [92.57673645, 11.56840229], [92.57562256, 11.56729221], [92.57590485, 11.56701374], [92.57590485, 11.56673622], [92.57562256, 11.56645966], [92.57562256, 11.56617928], [92.5753479, 11.5658989], [92.57562256, 11.56562328], [92.57562256, 11.56479073], [92.5753479, 11.56451321], [92.5753479, 11.56423473], [92.57507324, 11.56396198], [92.57507324, 11.5636816], [92.57479095, 11.56340122], [92.57479095, 11.56312466], [92.5745163, 11.56284714], [92.5745163, 11.56257153]]], [[[92.62509918, 11.42097092], [92.62497711, 11.4215889], [92.62483978, 11.42210197], [92.62471771, 11.42247772], [92.62459564, 11.42276287], [92.62447357, 11.42302227], [92.62444305, 11.4233799], [92.62444305, 11.42381954], [92.62444305, 11.42431927], [92.62444305, 11.42485046], [92.62444305, 11.42541122], [92.6244278, 11.42595959], [92.62432861, 11.42650032], [92.62419128, 11.42704964], [92.62413788, 11.4276104], [92.62393951, 11.42811203], [92.62380981, 11.42859936], [92.62364197, 11.42908001], [92.62354279, 11.42961788], [92.62332916, 11.43007183], [92.62309265, 11.43046093], [92.62296295, 11.43078136], [92.62280273, 11.43097019], [92.62274933, 11.43109131], [92.62245178, 11.43146038], [92.62213898, 11.43146038], [92.62188721, 11.43124962], [92.62164307, 11.43109131], [92.62137604, 11.43094921], [92.6211319, 11.43074036], [92.62088776, 11.43052959], [92.6203537, 11.43013573], [92.61971283, 11.43041134], [92.61981964, 11.4315424], [92.62000275, 11.43212128], [92.62023163, 11.43266964], [92.62024689, 11.4335289], [92.62032318, 11.43395996], [92.62031555, 11.4340992], [92.61997223, 11.43457985], [92.61997223, 11.43500233], [92.62004089, 11.43554592], [92.62024689, 11.43575382], [92.62052917, 11.43582439], [92.62129974, 11.43582439], [92.62171173, 11.43568516], [92.62178802, 11.43556023], [92.62198639, 11.43506145], [92.62199402, 11.43465137], [92.62164307, 11.43444061], [92.62108612, 11.4340992], [92.62101746, 11.43375015], [92.62115479, 11.43360901], [92.62168884, 11.43343067], [92.62220764, 11.43346977], [92.62252808, 11.4335413], [92.62274933, 11.43366814], [92.62291718, 11.43387985], [92.62307739, 11.43414021], [92.62328339, 11.43441105], [92.62345886, 11.43470764], [92.62356567, 11.43500233], [92.6235199, 11.43527985], [92.62335205, 11.43556881], [92.62312317, 11.43591118], [92.62281799, 11.43636036], [92.62255859, 11.43694973], [92.62259674, 11.43758202], [92.62278748, 11.43819046], [92.62304688, 11.43873024], [92.62328339, 11.43922043], [92.62345123, 11.43968964], [92.62359619, 11.44009972], [92.62364197, 11.44046879], [92.62358856, 11.44078064], [92.62341309, 11.44102955], [92.62316895, 11.44127083], [92.62290955, 11.44153976], [92.622612, 11.44178677], [92.62226868, 11.44180489], [92.62190247, 11.4416914], [92.621521, 11.44166088], [92.62114716, 11.44166088], [92.62077332, 11.4417181], [92.6204834, 11.44198036], [92.62026978, 11.44240189], [92.62011719, 11.44283867], [92.62024689, 11.44331074], [92.62026215, 11.4437809], [92.62017059, 11.44419956], [92.62000275, 11.44458961], [92.61978912, 11.44494057], [92.61959076, 11.44528484], [92.61937714, 11.44559002], [92.61910248, 11.44587135], [92.61882782, 11.44618797], [92.61859894, 11.44658184], [92.61833954, 11.44697189], [92.61805725, 11.44731998], [92.61778259, 11.44765091], [92.61750031, 11.44798088], [92.61720276, 11.44832993], [92.61686707, 11.44868088], [92.61650848, 11.44906807], [92.61618042, 11.44954014], [92.61585999, 11.45007133], [92.61557007, 11.4506197], [92.61527252, 11.4511404], [92.61501312, 11.45158005], [92.61472321, 11.45194912], [92.61448669, 11.45227146], [92.61431885, 11.45261669], [92.61414337, 11.45294094], [92.61395264, 11.45324802], [92.61384583, 11.45359039], [92.61367035, 11.45387268], [92.61360168, 11.45416737], [92.61351013, 11.454422], [92.61338043, 11.45464993], [92.61328888, 11.4549284], [92.61312103, 11.45519924], [92.61297607, 11.45556164], [92.6128006, 11.45589447], [92.61260223, 11.45621109], [92.61235046, 11.45657063], [92.61207581, 11.4567194], [92.6115799, 11.45736027], [92.6113205, 11.45786572], [92.61106873, 11.45863247], [92.61139679, 11.45905972], [92.6114502, 11.45947933], [92.61161804, 11.46023178], [92.61167145, 11.46093082], [92.61168671, 11.46157169], [92.61174011, 11.46217632], [92.61194611, 11.46272945], [92.61218262, 11.4633112], [92.61231232, 11.46392059], [92.61251068, 11.46441078], [92.61271667, 11.46483994], [92.61277771, 11.4652977], [92.61283112, 11.46576977], [92.61296844, 11.46623039], [92.61303711, 11.46673203], [92.61310577, 11.46724033], [92.61325073, 11.46774101], [92.61331177, 11.46825027], [92.61334229, 11.46877098], [92.61335754, 11.46930027], [92.61340332, 11.46983624], [92.61335754, 11.47041035], [92.61334229, 11.47103024], [92.61334229, 11.47164059], [92.6133728, 11.47217178], [92.61353302, 11.47257996], [92.61360168, 11.47296143], [92.61360168, 11.47332954], [92.61360168, 11.47373104], [92.6136322, 11.47418022], [92.61373138, 11.47464657], [92.61387634, 11.4750824], [92.61398315, 11.47546291], [92.61412048, 11.47576237], [92.61416626, 11.47608089], [92.61421967, 11.47639275], [92.61437988, 11.47665024], [92.61447906, 11.47701263], [92.61457825, 11.47747993], [92.61461639, 11.47817135], [92.61473846, 11.47885036], [92.61490631, 11.47947025], [92.6150589, 11.48015118], [92.61515808, 11.48088074], [92.61524963, 11.48160076], [92.61539459, 11.48231602], [92.61559296, 11.48289967], [92.61586761, 11.48338985], [92.61588287, 11.48384094], [92.6160202, 11.48419857], [92.61617279, 11.48467064], [92.6162796, 11.48513985], [92.61670685, 11.48569202], [92.61723328, 11.48595238], [92.61750793, 11.48616123], [92.61785889, 11.48678112], [92.61792755, 11.48726177], [92.61792755, 11.4880867], [92.61807251, 11.48905087], [92.6182785, 11.48960972], [92.61841583, 11.49022675], [92.61849213, 11.49125957], [92.61862183, 11.49168968], [92.61891174, 11.49209785], [92.61914825, 11.49244022], [92.61933899, 11.49279118], [92.61953735, 11.4931612], [92.61980438, 11.49354553], [92.62008667, 11.49393272], [92.62026978, 11.4943552], [92.62037659, 11.49471855], [92.62052917, 11.4949789], [92.62057495, 11.49522781], [92.62056732, 11.4955101], [92.62056732, 11.49584103], [92.62055969, 11.49619198], [92.62056732, 11.49659061], [92.6206131, 11.49702072], [92.62078094, 11.49742699], [92.62098694, 11.49780083], [92.62117004, 11.4981966], [92.62139893, 11.49860096], [92.62166595, 11.49905014], [92.6219635, 11.49956894], [92.62230682, 11.50007057], [92.62266541, 11.50051975], [92.62303925, 11.50087261], [92.62341309, 11.50117397], [92.62387848, 11.50140381], [92.62436676, 11.50170326], [92.62484741, 11.50207424], [92.62532043, 11.50244999], [92.62577057, 11.50276947], [92.62614441, 11.50302219], [92.62647247, 11.50316429], [92.62664032, 11.5033102], [92.62709808, 11.50373077], [92.6271286, 11.50417137], [92.62724304, 11.50471973], [92.62750244, 11.50521946], [92.62771606, 11.50573921], [92.62800598, 11.50609016], [92.62841797, 11.50681496], [92.62874603, 11.50731182], [92.62888336, 11.50765133], [92.62909698, 11.50801563], [92.62915802, 11.50846863], [92.62919617, 11.50899124], [92.62934875, 11.50949097], [92.62948608, 11.51000977], [92.6297226, 11.51046753], [92.62999725, 11.51091003], [92.63027954, 11.51137066], [92.63056946, 11.51181126], [92.63150787, 11.51242065], [92.63178253, 11.51283169], [92.63178253, 11.51352024], [92.63170624, 11.51385975], [92.63179016, 11.51416016], [92.63198853, 11.51449108], [92.63241577, 11.51476669], [92.63275146, 11.51501274], [92.6330719, 11.51524067], [92.633461, 11.51540947], [92.63385773, 11.51557064], [92.63423157, 11.51578999], [92.63461304, 11.51601601], [92.63500214, 11.51635265], [92.63545227, 11.51682472], [92.63598633, 11.51728344], [92.63639832, 11.51718712], [92.63667297, 11.51686954], [92.63689423, 11.51649666], [92.63698578, 11.51606083], [92.63717651, 11.51570129], [92.6373291, 11.51533222], [92.63754272, 11.51503086], [92.63775635, 11.51475143], [92.63796234, 11.51445198], [92.63816071, 11.51414871], [92.63831329, 11.51379108], [92.63838196, 11.51336288], [92.63861084, 11.51299763], [92.63887787, 11.51264], [92.63912964, 11.51226044], [92.63929749, 11.51188374], [92.63970184, 11.51161003], [92.64015961, 11.51115036], [92.64063263, 11.51069164], [92.6410675, 11.51035023], [92.6414566, 11.51014042], [92.64185333, 11.51005077], [92.64222717, 11.51007175], [92.64261627, 11.51006889], [92.64295959, 11.51003075], [92.64319611, 11.5100193], [92.64344025, 11.51012039], [92.64367676, 11.51034069], [92.64389038, 11.5106163], [92.64405823, 11.51101971], [92.64440155, 11.51131821], [92.64487457, 11.51137257], [92.64530182, 11.51130486], [92.64566803, 11.51118565], [92.64594269, 11.51104927], [92.64601898, 11.5107851], [92.64595032, 11.51034737], [92.64586639, 11.50984192], [92.64585876, 11.50938988], [92.64588165, 11.50903034], [92.64591217, 11.5086813], [92.64594269, 11.5082798], [92.64595795, 11.50782204], [92.64594269, 11.50732136], [92.64588165, 11.50681019], [92.64576721, 11.50631142], [92.64566803, 11.50578022], [92.64559937, 11.50520992], [92.64554596, 11.50463104], [92.64550781, 11.50408745], [92.64541626, 11.50360966], [92.64537811, 11.50316143], [92.64533234, 11.50270081], [92.64530182, 11.50222015], [92.64530945, 11.50175953], [92.64537048, 11.50137711], [92.64549255, 11.50108147], [92.64565277, 11.50080013], [92.64589691, 11.50057697], [92.64621735, 11.50039005], [92.64660645, 11.50024033], [92.64698792, 11.50013161], [92.64731598, 11.50005531], [92.6476059, 11.4999361], [92.64789581, 11.49977016], [92.64821625, 11.49956036], [92.64861298, 11.49934196], [92.6490097, 11.49908161], [92.6493988, 11.49880791], [92.6497879, 11.49851036], [92.6502533, 11.4982996], [92.65066528, 11.49805832], [92.65101624, 11.49775124], [92.65120697, 11.49720097], [92.65164948, 11.49682999], [92.65211487, 11.49649906], [92.65261841, 11.49619198], [92.65312195, 11.49594116], [92.65355682, 11.4957428], [92.65390778, 11.49555111], [92.65421295, 11.49536037], [92.65455627, 11.49518204], [92.65505219, 11.49501991], [92.65551758, 11.49479008], [92.65584564, 11.49448872], [92.65605164, 11.49416065], [92.65628052, 11.49383068], [92.65661621, 11.49363041], [92.65692139, 11.49341965], [92.65719604, 11.49315071], [92.65753937, 11.49279976], [92.6579895, 11.49250221], [92.65846252, 11.49221516], [92.6588974, 11.49193192], [92.6592865, 11.49166107], [92.65963745, 11.49142647], [92.66001892, 11.49131203], [92.66044617, 11.49124146], [92.66091156, 11.49112988], [92.66142273, 11.49104118], [92.66194916, 11.49087906], [92.6624527, 11.49079037], [92.66287994, 11.49063969], [92.66327667, 11.49057102], [92.66364288, 11.49061012], [92.6639328, 11.49081993], [92.66422272, 11.49110889], [92.66452789, 11.49142647], [92.66496277, 11.49163055], [92.66545868, 11.4917202], [92.66602325, 11.49164009], [92.66658783, 11.49143982], [92.66710663, 11.49110031], [92.66762543, 11.49073315], [92.66817474, 11.49039555], [92.66858673, 11.48996067], [92.66877747, 11.48941612], [92.66876221, 11.48877144], [92.66893768, 11.48814869], [92.66924286, 11.4875927], [92.66953278, 11.48712063], [92.66985321, 11.48680401], [92.67009735, 11.48653126], [92.67030334, 11.4862318], [92.67043304, 11.48589039], [92.67043304, 11.48544979], [92.67038727, 11.484972], [92.67048645, 11.48447037], [92.670578, 11.48396015], [92.6707077, 11.48346138], [92.67081451, 11.48291111], [92.6708374, 11.48233032], [92.6708374, 11.48173141], [92.67080688, 11.48112202], [92.67067719, 11.48053646], [92.67060852, 11.47997093], [92.6708374, 11.47941017], [92.67108154, 11.47887325], [92.67134857, 11.47833729], [92.67162323, 11.4778204], [92.67185974, 11.47733402], [92.67218018, 11.47698307], [92.67249298, 11.47667122], [92.67277527, 11.47635555], [92.67302704, 11.47601891], [92.6732254, 11.47565365], [92.67337036, 11.47526932], [92.67360687, 11.47495937], [92.67385864, 11.47462654], [92.67411804, 11.47422791], [92.67447662, 11.47387028], [92.67492676, 11.47360992], [92.67533875, 11.47336197], [92.67572784, 11.47312927], [92.6760025, 11.47283077], [92.67629242, 11.47255039], [92.67649078, 11.4721899], [92.6769104, 11.47187996], [92.67729187, 11.47151089], [92.67740631, 11.4709301], [92.67726135, 11.47022057], [92.67713928, 11.46951199], [92.67701721, 11.46884727], [92.67698669, 11.46818066], [92.67676544, 11.46778011], [92.676651, 11.46741104], [92.67663574, 11.46694374], [92.67643738, 11.46646023], [92.67649078, 11.46592045], [92.67652893, 11.46539593], [92.67623901, 11.46488094], [92.6761322, 11.46434975], [92.67610931, 11.46380997], [92.67607117, 11.4633112], [92.67588806, 11.46289825], [92.67582703, 11.46250153], [92.6758728, 11.46210003], [92.67607117, 11.46171093], [92.6765213, 11.46138], [92.67698669, 11.46123028], [92.67751312, 11.46086121], [92.67767334, 11.46018124], [92.67764282, 11.45934963], [92.67747498, 11.45872974], [92.67801666, 11.45833111], [92.67839813, 11.45799065], [92.67853546, 11.45740128], [92.67890167, 11.45694256], [92.67935181, 11.45664406], [92.67971802, 11.45636368], [92.68001556, 11.45614719], [92.68013, 11.45599174], [92.68016052, 11.4556303], [92.68016052, 11.4550209], [92.6800766, 11.45471096], [92.67978668, 11.45433998], [92.6795578, 11.45399094], [92.67952728, 11.45363998], [92.67945862, 11.45321178], [92.67978668, 11.45279026], [92.68029022, 11.45223045], [92.68035126, 11.45173264], [92.68060303, 11.451231], [92.68079376, 11.45093727], [92.6810379, 11.45045185], [92.6809082, 11.4499979], [92.68107605, 11.44948959], [92.68136597, 11.44901085], [92.68157959, 11.44855976], [92.68158722, 11.44806576], [92.68180084, 11.44772053], [92.68190765, 11.44742966], [92.68186951, 11.44714928], [92.68177795, 11.44690323], [92.6815567, 11.4464817], [92.68173981, 11.44600105], [92.68229675, 11.44597054], [92.68274689, 11.44572735], [92.6831665, 11.44537163], [92.68341827, 11.44479275], [92.68370056, 11.44419956], [92.68402863, 11.44362068], [92.68434143, 11.44305134], [92.68456268, 11.4425106], [92.68466187, 11.44204617], [92.68447876, 11.44166088], [92.68430328, 11.44149017], [92.68386841, 11.44118881], [92.68386078, 11.44081974], [92.68409729, 11.44032097], [92.68440247, 11.44005203], [92.68469238, 11.4396944], [92.6847229, 11.43929958], [92.68504333, 11.43882084], [92.685112, 11.43839073], [92.68519592, 11.4379797], [92.6852951, 11.43760204], [92.68538666, 11.43733978], [92.68546295, 11.43712139], [92.68579102, 11.43661118], [92.68572998, 11.43611145], [92.68556976, 11.43552971], [92.68543243, 11.43490124], [92.68535614, 11.43436146], [92.68528748, 11.43388939], [92.68506622, 11.43325996], [92.68453217, 11.43282032], [92.68418121, 11.43246937], [92.68371582, 11.43221188], [92.68319702, 11.4321003], [92.68262482, 11.43190193], [92.68210602, 11.43184853], [92.6816864, 11.43172169], [92.68138885, 11.43155956], [92.68123627, 11.43129253], [92.68122864, 11.43088055], [92.68132782, 11.43039989], [92.68144226, 11.42996025], [92.68154907, 11.42958164], [92.68165588, 11.42925072], [92.68183899, 11.42895985], [92.68209839, 11.42872047], [92.68229675, 11.42851067], [92.68274689, 11.42813015], [92.68312836, 11.42784023], [92.68356323, 11.42765999], [92.68379211, 11.4273777], [92.68383789, 11.4270792], [92.68373871, 11.42680073], [92.68350983, 11.42649078], [92.68314362, 11.42623138], [92.68273926, 11.4260807], [92.68235779, 11.4260006], [92.68173981, 11.42558384], [92.68123627, 11.42577267], [92.68121338, 11.42634106], [92.68107605, 11.42720032], [92.68074799, 11.42746925], [92.68035889, 11.42784023], [92.68017578, 11.42807102], [92.68006134, 11.42822075], [92.67980957, 11.42817116], [92.67938995, 11.42809963], [92.67897797, 11.42792034], [92.6786499, 11.42778778], [92.67830658, 11.42772198], [92.67796326, 11.42753124], [92.67753601, 11.42741203], [92.67711639, 11.42723179], [92.67670441, 11.42708397], [92.67634583, 11.42689037], [92.67605591, 11.4267149], [92.67572021, 11.42679024], [92.6753006, 11.42694283], [92.67485046, 11.42709064], [92.67440033, 11.4272089], [92.67394257, 11.42723179], [92.67352295, 11.4272213], [92.67312622, 11.42714119], [92.67276001, 11.42693996], [92.67238617, 11.42671013], [92.67218018, 11.42640018], [92.67194366, 11.42613792], [92.67173767, 11.42588043], [92.67167664, 11.42558193], [92.67173004, 11.42523956], [92.67191315, 11.42485046], [92.67198944, 11.42439175], [92.67222595, 11.42397976], [92.67249298, 11.42359734], [92.6727829, 11.42323017], [92.67305756, 11.42287922], [92.67333984, 11.42254066], [92.67362976, 11.42221069], [92.67393494, 11.42193317], [92.67420197, 11.42163181], [92.67444611, 11.42131519], [92.6746521, 11.42097092], [92.67468262, 11.42056084], [92.67449188, 11.42013168], [92.67444611, 11.41967201], [92.67443085, 11.41923046], [92.67433929, 11.41878986], [92.67415619, 11.41834831], [92.67386627, 11.41785145], [92.67346191, 11.41734695], [92.67298889, 11.41687775], [92.67253113, 11.41643143], [92.67221069, 11.41598034], [92.67189789, 11.41574097], [92.67145538, 11.41568089], [92.67111969, 11.41543293], [92.67064667, 11.41533947], [92.67025757, 11.4151907], [92.6699295, 11.4151001], [92.66944122, 11.41496086], [92.66904449, 11.41487026], [92.66864014, 11.41471004], [92.6682663, 11.41453266], [92.6678009, 11.41441631], [92.66732788, 11.41421127], [92.66678619, 11.41412926], [92.66627502, 11.41394901], [92.66573334, 11.41384029], [92.66527557, 11.41364574], [92.66481781, 11.41357136], [92.6644516, 11.41337872], [92.66403198, 11.41329956], [92.66365814, 11.41312885], [92.66325378, 11.41302395], [92.66291046, 11.41284847], [92.6625824, 11.41267109], [92.66215515, 11.41257858], [92.66169739, 11.41251278], [92.66122437, 11.41250038], [92.66079712, 11.41245174], [92.66047668, 11.4121809], [92.66007233, 11.41197109], [92.65970612, 11.41187954], [92.6592865, 11.41172028], [92.65854645, 11.41176319], [92.65818787, 11.41163826], [92.65797424, 11.41156292], [92.65749359, 11.41124153], [92.65701294, 11.41092014], [92.65667725, 11.41073132], [92.65648651, 11.41047287], [92.65618896, 11.41036034], [92.65563965, 11.41010189], [92.6550827, 11.40966034], [92.65441895, 11.40972137], [92.65383911, 11.40968037], [92.65331268, 11.40958214], [92.65280914, 11.40944767], [92.65229797, 11.40929985], [92.65181732, 11.40908337], [92.65136719, 11.4087801], [92.65091705, 11.40841103], [92.65039063, 11.40807819], [92.64987946, 11.40777969], [92.64949036, 11.40751457], [92.6493454, 11.40724754], [92.64958954, 11.40696144], [92.64990997, 11.40692043], [92.6504364, 11.40692043], [92.65094757, 11.40727139], [92.65136719, 11.40725994], [92.65180969, 11.40722084], [92.65219116, 11.40722084], [92.65255737, 11.40722561], [92.6529007, 11.40724182], [92.65327454, 11.40727615], [92.65371704, 11.40734196], [92.65422058, 11.4076519], [92.65480804, 11.40777969], [92.6556015, 11.4076519], [92.65596008, 11.40738773], [92.65624237, 11.40717125], [92.65653992, 11.40694141], [92.65679169, 11.4069109], [92.65718842, 11.40680027], [92.65753937, 11.40680027], [92.65797424, 11.40681458], [92.65836334, 11.40682697], [92.65854645, 11.40683365], [92.65912628, 11.40676498], [92.6595993, 11.40666008], [92.65997314, 11.40665627], [92.66033936, 11.4063797], [92.66082764, 11.40612888], [92.66098022, 11.40563011], [92.66043091, 11.40528202], [92.66031647, 11.40431786], [92.66033173, 11.40380001], [92.66043091, 11.40334225], [92.66052246, 11.40299797], [92.66073608, 11.40273952], [92.66104126, 11.40253067], [92.66140747, 11.40236664], [92.66179657, 11.4022913], [92.66221619, 11.40225887], [92.66259766, 11.40223026], [92.66295624, 11.40216064], [92.66327667, 11.40203762], [92.66372681, 11.40207005], [92.66394806, 11.40186119], [92.66387939, 11.40147114], [92.66351318, 11.40105247], [92.66308594, 11.40065956], [92.66272736, 11.40032005], [92.66248322, 11.39992142], [92.662323, 11.39951992], [92.66221619, 11.39913177], [92.66216278, 11.39875031], [92.66220093, 11.39837074], [92.66227722, 11.39799118], [92.6623764, 11.39756203], [92.66246796, 11.39704037], [92.66266632, 11.39654064], [92.66294861, 11.39605999], [92.66330719, 11.39564323], [92.66369629, 11.39528084], [92.66414642, 11.39499092], [92.66470337, 11.39480019], [92.66526031, 11.39473057], [92.66582489, 11.39482498], [92.66641235, 11.39488411], [92.66685486, 11.39501381], [92.6672287, 11.39536953], [92.66760254, 11.39557934], [92.6678772, 11.39566135], [92.66851044, 11.39568043], [92.66913605, 11.39560223], [92.66970062, 11.39569283], [92.67007446, 11.39593315], [92.67056274, 11.39616108], [92.67119598, 11.39640903], [92.67164612, 11.39665985], [92.67201996, 11.39712048], [92.67222595, 11.39762783], [92.67198944, 11.39828014], [92.67177582, 11.39848995], [92.67178345, 11.39862728], [92.67198944, 11.3989706], [92.67240906, 11.39925098], [92.67269135, 11.39932156], [92.672966, 11.39932156], [92.67356873, 11.39898014], [92.67399597, 11.39903927], [92.67443085, 11.39910316], [92.67481232, 11.39914608], [92.67507935, 11.39912605], [92.67514801, 11.39910316], [92.6754303, 11.39901161], [92.67560577, 11.3987999], [92.6756897, 11.39855957], [92.6756897, 11.39829445], [92.67570496, 11.39797688], [92.67578888, 11.39763069], [92.67591095, 11.39727974], [92.67605591, 11.39695072], [92.6762085, 11.39663029], [92.67640686, 11.39629269], [92.676651, 11.39587975], [92.67682648, 11.39545155], [92.67691803, 11.39506245], [92.67712402, 11.39453316], [92.67741394, 11.39395428], [92.67774963, 11.39339066], [92.67811584, 11.39287186], [92.6784668, 11.39241791], [92.67896271, 11.39211273], [92.67948151, 11.39192104], [92.67996979, 11.39173031], [92.68045044, 11.39159107], [92.68089294, 11.39141273], [92.68132019, 11.39125824], [92.68165588, 11.39105129], [92.68196869, 11.39084053], [92.68225098, 11.39062023], [92.68254852, 11.3903904], [92.6829071, 11.39017105], [92.68336487, 11.39002991], [92.68389893, 11.39002991], [92.68447876, 11.39013386], [92.685112, 11.39024162], [92.68570709, 11.39028263], [92.6862793, 11.39033031], [92.68678284, 11.39048958], [92.68733978, 11.39064693], [92.68795776, 11.39082527], [92.68862152, 11.39116192], [92.68886566, 11.39088726], [92.68895721, 11.39040089], [92.68891907, 11.38992882], [92.68895721, 11.38945103], [92.68916321, 11.38901138], [92.68917084, 11.38860512], [92.68920135, 11.38822174], [92.68934631, 11.38785076], [92.6894989, 11.38742924], [92.68977356, 11.38713074], [92.69011688, 11.38698006], [92.69049835, 11.38699245], [92.69081879, 11.38716698], [92.69116974, 11.38726044], [92.69145203, 11.38744068], [92.69174957, 11.38759136], [92.69204712, 11.3877821], [92.69239044, 11.38793278], [92.69287872, 11.38781166], [92.69348145, 11.38741779], [92.69393921, 11.38695145], [92.69387054, 11.38656139], [92.6934433, 11.38654709], [92.69319153, 11.38628006], [92.69261169, 11.3860836], [92.69245911, 11.38566971], [92.69230652, 11.38518047], [92.69158173, 11.38509083], [92.69119263, 11.38483143], [92.69095612, 11.38414001], [92.69065094, 11.3836298], [92.69049835, 11.38298035], [92.69031525, 11.38232613], [92.69020844, 11.38162041], [92.69037628, 11.38092041], [92.69049835, 11.38023186], [92.69090271, 11.37967968], [92.69126129, 11.37915421], [92.69130707, 11.37844467], [92.69156647, 11.37782001], [92.69182587, 11.37730122], [92.69178772, 11.37687206], [92.69181061, 11.3765707], [92.69165039, 11.37630463], [92.69165039, 11.37593269], [92.69172668, 11.3754797], [92.6917572, 11.37495136], [92.69153595, 11.37447453], [92.69126892, 11.37403488], [92.69104004, 11.37361813], [92.69082642, 11.37321186], [92.69062805, 11.37280178], [92.69055176, 11.37232971], [92.6905365, 11.37183952], [92.69077301, 11.37132931], [92.69095612, 11.37084389], [92.69087219, 11.37034035], [92.69061279, 11.36990929], [92.69007111, 11.36965942], [92.68952942, 11.36942196], [92.68901825, 11.36917591], [92.68852997, 11.36894989], [92.68810272, 11.36883068], [92.68780518, 11.36862946], [92.68759918, 11.3684206], [92.68743896, 11.36822128], [92.68723297, 11.36803055], [92.68700409, 11.36779213], [92.68673706, 11.36749363], [92.68645477, 11.36714268], [92.6860199, 11.36693954], [92.68551636, 11.36680984], [92.68498993, 11.36670494], [92.68444824, 11.36648178], [92.68383789, 11.36636066], [92.68334961, 11.36656094], [92.68292999, 11.36675072], [92.68251801, 11.36678028], [92.68237305, 11.36669827], [92.68225098, 11.3666296], [92.68193817, 11.366436], [92.68167114, 11.3663702], [92.6812973, 11.36633301], [92.68077087, 11.3663168], [92.68045044, 11.36603928], [92.68022919, 11.36565018], [92.68015289, 11.3651619], [92.68048096, 11.36472893], [92.680336, 11.36431026], [92.67982483, 11.36397743], [92.67941284, 11.36361027], [92.67900848, 11.36324978], [92.6784668, 11.36298084], [92.6778717, 11.36276436], [92.67730713, 11.36255169], [92.67681122, 11.36241055], [92.67632294, 11.36239147], [92.67581177, 11.36240387], [92.67525482, 11.36226082], [92.67463684, 11.36216927], [92.67405701, 11.36213112], [92.67370605, 11.36258888], [92.67350006, 11.36300087], [92.67329407, 11.36306953], [92.67308044, 11.36314011], [92.67209625, 11.36293125], [92.67160797, 11.36293316], [92.67063141, 11.36272621], [92.66924286, 11.36216927], [92.66860962, 11.3620348], [92.66794586, 11.3612709], [92.66761017, 11.36108017], [92.66729736, 11.36083794], [92.66696167, 11.3608408], [92.66632843, 11.36038017], [92.66629791, 11.35973263], [92.66634369, 11.35926819], [92.6661377, 11.35888958], [92.6659317, 11.35854053], [92.66561127, 11.35815144], [92.66533661, 11.35789204], [92.66506958, 11.35742188], [92.66487885, 11.35694981], [92.66483307, 11.35623169], [92.664711, 11.35560131], [92.6648941, 11.35507011], [92.66483307, 11.35470963], [92.66487885, 11.35450459], [92.66483307, 11.35391045], [92.66490173, 11.3532238], [92.66490173, 11.35260391], [92.66448212, 11.35218906], [92.66433716, 11.35218906], [92.66399384, 11.35267162], [92.66371155, 11.3532896], [92.66371918, 11.35353565], [92.66329956, 11.35367966], [92.66278839, 11.3537302], [92.66253662, 11.35394859], [92.66226196, 11.35426998], [92.66197968, 11.35470963], [92.66160583, 11.3550396], [92.66130066, 11.35519123], [92.66075134, 11.35533905], [92.66031647, 11.35555458], [92.65981293, 11.35573101], [92.65922546, 11.35585594], [92.65864563, 11.35604954], [92.65804291, 11.35615921], [92.6574707, 11.35639191], [92.65688324, 11.35663986], [92.65621185, 11.35682869], [92.65545654, 11.35698032], [92.6546936, 11.35718727], [92.65390778, 11.35722446], [92.65315247, 11.35717773], [92.65248108, 11.35713005], [92.6517868, 11.3570118], [92.65112305, 11.35688019], [92.65036774, 11.35663986], [92.64981079, 11.35639191], [92.64924622, 11.3563509], [92.64884186, 11.35611153], [92.64848328, 11.35585403], [92.64810944, 11.35562229], [92.64774323, 11.35545063], [92.64740753, 11.35516071], [92.64684296, 11.35474396], [92.64640808, 11.35438633], [92.64594269, 11.35387993], [92.64543915, 11.35342884], [92.64494324, 11.35306931], [92.6444397, 11.35276985], [92.64398193, 11.3524189], [92.64360809, 11.351964], [92.64225006, 11.35130024], [92.64126587, 11.35068035], [92.64057159, 11.35013103], [92.63994598, 11.34965038], [92.63965607, 11.34902096], [92.6394577, 11.34840107], [92.63903809, 11.34798622], [92.63868713, 11.34729958], [92.63861847, 11.34703064], [92.63842773, 11.34652138], [92.63799286, 11.34627724], [92.63743591, 11.34622002], [92.63689423, 11.34646606], [92.63643646, 11.34687042], [92.63595581, 11.3472414], [92.63555908, 11.34759045], [92.63514709, 11.34790039], [92.63465881, 11.34807968], [92.6341629, 11.34829044], [92.63359833, 11.34834194], [92.63304138, 11.34838772], [92.63256073, 11.3485899], [92.63207245, 11.3487606], [92.63156891, 11.34889793], [92.63109589, 11.34905148], [92.63059998, 11.34915066], [92.63007355, 11.34916687], [92.62950134, 11.3492012], [92.62892914, 11.34938145], [92.6282959, 11.34943962], [92.6276474, 11.34945202], [92.6269989, 11.34941959], [92.62635803, 11.34926033], [92.62573242, 11.34904194], [92.62523651, 11.34865189], [92.62477875, 11.34823036], [92.62445068, 11.34779263], [92.62420654, 11.34755802], [92.62384033, 11.34745121], [92.62355804, 11.34737968], [92.62298584, 11.34724998], [92.62255859, 11.34725857], [92.62207031, 11.3472414], [92.62139893, 11.34784985], [92.62069702, 11.34839916], [92.62020874, 11.34887981], [92.61985779, 11.34908962], [92.61956787, 11.34916019], [92.61868286, 11.34916019], [92.61797333, 11.34908962], [92.61749268, 11.34908962], [92.61657715, 11.34895039], [92.61483002, 11.34861088], [92.6133728, 11.34840107], [92.61260223, 11.34834194], [92.61218262, 11.34778118], [92.61218262, 11.34743023], [92.61210632, 11.34701824], [92.61183167, 11.34681034], [92.61154938, 11.34667397], [92.61050415, 11.3466053], [92.61001587, 11.34619045], [92.60890961, 11.34579182], [92.60843658, 11.34583282], [92.60792542, 11.34583473], [92.60739899, 11.34583473], [92.60688782, 11.34582996], [92.60521698, 11.3461113], [92.60468292, 11.34624958], [92.60426331, 11.34624958], [92.60367584, 11.34618092], [92.60307312, 11.34622002], [92.60251617, 11.3463316], [92.60192108, 11.34613991], [92.60134888, 11.34630203], [92.60079193, 11.34640026], [92.60029602, 11.34652138], [92.59983063, 11.34665489], [92.59937286, 11.3467598], [92.5989151, 11.34693813], [92.59845734, 11.34711361], [92.59809113, 11.34733009], [92.59780884, 11.34756947], [92.59758759, 11.34779739], [92.59737396, 11.34802341], [92.59707642, 11.34817791], [92.59667969, 11.34834194], [92.59622192, 11.34848976], [92.59571838, 11.34855175], [92.59516144, 11.34859943], [92.59455872, 11.34865189], [92.59404755, 11.34916019], [92.59355164, 11.34954071], [92.59282684, 11.34982109], [92.59250641, 11.35032654], [92.59222412, 11.35075092], [92.59192657, 11.35109138], [92.59156036, 11.35140133], [92.59107208, 11.35170078], [92.59050751, 11.3524189], [92.58986664, 11.35311031], [92.58946228, 11.35352039], [92.58869171, 11.35409164], [92.58862305, 11.35453033], [92.58842468, 11.35507011], [92.58803558, 11.35543156], [92.58757782, 11.3557806], [92.58701324, 11.35676098], [92.58686066, 11.35723972], [92.58631134, 11.35766125], [92.58622742, 11.35821056], [92.5860672, 11.35896969], [92.58610535, 11.35942459], [92.58598328, 11.35979462], [92.58582306, 11.36013889], [92.58557892, 11.36046028], [92.58530426, 11.36079979], [92.5849762, 11.36116028], [92.58468628, 11.36161995], [92.58435059, 11.36205959], [92.58399963, 11.36250019], [92.58370972, 11.36290073], [92.58358765, 11.36326981], [92.5834198, 11.3635416], [92.58328247, 11.36379719], [92.58310699, 11.36402035], [92.58300018, 11.36431885], [92.58280945, 11.36457157], [92.5826416, 11.36486053], [92.58250427, 11.36514568], [92.58236694, 11.36538982], [92.58220673, 11.36557007], [92.58204651, 11.36575031], [92.58189392, 11.36602974], [92.58154297, 11.36626053], [92.58120728, 11.36667061], [92.58113861, 11.36748886], [92.58107758, 11.36824989], [92.58100891, 11.3689909], [92.58117676, 11.36968231], [92.58152771, 11.37026024], [92.58193207, 11.37080097], [92.58242798, 11.37127018], [92.58304596, 11.37166214], [92.58368683, 11.37203121], [92.58433533, 11.37240696], [92.58495331, 11.37281132], [92.58553314, 11.37324238], [92.58620453, 11.37333012], [92.58686829, 11.37337589], [92.58747864, 11.37357426], [92.58808136, 11.37366104], [92.58850861, 11.37389755], [92.58885193, 11.37415791], [92.58914185, 11.37443066], [92.5893631, 11.3747406], [92.58953094, 11.37508106], [92.58972168, 11.37541962], [92.58991241, 11.37575054], [92.59008789, 11.37609005], [92.59030151, 11.37640953], [92.59056091, 11.37673759], [92.59082794, 11.37711143], [92.59106445, 11.37755108], [92.59126282, 11.37802124], [92.59146881, 11.3784399], [92.59166718, 11.37884998], [92.59185028, 11.3792038], [92.59197998, 11.37954998], [92.59216309, 11.37984943], [92.59226227, 11.38021088], [92.59246063, 11.38057995], [92.59246063, 11.38099098], [92.59221649, 11.38140106], [92.59222412, 11.38238525], [92.59222412, 11.38321495], [92.59208679, 11.38390255], [92.59179688, 11.38452053], [92.59179688, 11.38501072], [92.59166718, 11.38556004], [92.59144592, 11.38666058], [92.59107971, 11.38718128], [92.59111023, 11.38772106], [92.59106445, 11.38814735], [92.59092712, 11.38848019], [92.59085846, 11.38882637], [92.59083557, 11.389184], [92.59080505, 11.38952446], [92.59072113, 11.38981056], [92.59060669, 11.39006233], [92.59056091, 11.39036179], [92.59049988, 11.39066982], [92.59037018, 11.39096165], [92.59030151, 11.39126492], [92.59028625, 11.39157486], [92.59027863, 11.39186859], [92.59024811, 11.39213085], [92.5901413, 11.39237022], [92.59003448, 11.39263916], [92.58998108, 11.39297199], [92.58986664, 11.39332962], [92.58975983, 11.3937006], [92.58966827, 11.39409065], [92.5894928, 11.39446926], [92.58940125, 11.3949213], [92.58924103, 11.39540577], [92.58912659, 11.39591026], [92.58894348, 11.39635944], [92.58882141, 11.39677429], [92.58868408, 11.39710236], [92.58861542, 11.39745045], [92.58852386, 11.39780426], [92.58827972, 11.39810467], [92.58796692, 11.39840126], [92.58761597, 11.3987112], [92.58730316, 11.3991394], [92.58706665, 11.39975929], [92.5871048, 11.40047932], [92.5874176, 11.40098953], [92.58785248, 11.40125179], [92.58837128, 11.40121078], [92.58891296, 11.40112019], [92.58947754, 11.40103054], [92.59007263, 11.40088272], [92.59069824, 11.40085125], [92.59130859, 11.40089035], [92.59184265, 11.40105247], [92.59230042, 11.40109921], [92.59252167, 11.40107155], [92.59269714, 11.40105247], [92.5930481, 11.40088081], [92.59342194, 11.40074158], [92.59384155, 11.40061188], [92.59430695, 11.40051079], [92.59477234, 11.40034008], [92.59520721, 11.40028095], [92.59562683, 11.40023994], [92.5960083, 11.40018082], [92.5963974, 11.40023994], [92.59680939, 11.40027046], [92.59723663, 11.40028095], [92.59767151, 11.40028095], [92.59807587, 11.40028095], [92.59846497, 11.40027714], [92.59884644, 11.40029335], [92.59922028, 11.40036106], [92.59958649, 11.4005909], [92.59989166, 11.40083027], [92.6003418, 11.40091896], [92.60076904, 11.40117168], [92.60147858, 11.40125179], [92.60202789, 11.40109921], [92.60243225, 11.40078926], [92.60295105, 11.40082073], [92.60356903, 11.4008007], [92.60421753, 11.40088081], [92.60475159, 11.40088463], [92.60527039, 11.40086174], [92.6057663, 11.40088081], [92.60623169, 11.40111065], [92.60669708, 11.40137959], [92.60720825, 11.40161037], [92.60787201, 11.40165997], [92.60853577, 11.40167809], [92.60917664, 11.40172386], [92.60968018, 11.401824], [92.60980988, 11.40185165], [92.61006165, 11.40176487], [92.61032104, 11.40168095], [92.61081696, 11.40147781], [92.61127472, 11.40122032], [92.61170197, 11.40095139], [92.61212921, 11.40077591], [92.61248016, 11.4005909], [92.612854, 11.40055466], [92.61321259, 11.40052032], [92.61354065, 11.40036964], [92.61387634, 11.40029907], [92.61425018, 11.40036964], [92.61467743, 11.40054989], [92.6151886, 11.4007206], [92.61577606, 11.40082073], [92.6164093, 11.40088654], [92.61691284, 11.40111065], [92.61734009, 11.401371], [92.6177597, 11.40152073], [92.61811829, 11.40168285], [92.61842346, 11.40187168], [92.61876678, 11.40199471], [92.61907196, 11.40219975], [92.61943817, 11.40242958], [92.61979675, 11.40273952], [92.62023163, 11.40304756], [92.62071991, 11.40333271], [92.62120056, 11.40361118], [92.62166595, 11.40389061], [92.62210083, 11.40419006], [92.62245941, 11.40454292], [92.62271881, 11.40493965], [92.62294769, 11.40533161], [92.62308502, 11.40573978], [92.62329102, 11.40609074], [92.6234436, 11.40649414], [92.62362671, 11.40690231], [92.62385559, 11.40727425], [92.62393188, 11.40768242], [92.62395477, 11.40798664], [92.62409973, 11.40843105], [92.62435913, 11.40895557], [92.6244812, 11.40942287], [92.62445831, 11.40981007], [92.6244278, 11.41019821], [92.6243515, 11.41058064], [92.62414551, 11.41102695], [92.62381744, 11.41152191], [92.62386322, 11.4119482], [92.62388611, 11.41240215], [92.62388611, 11.41287136], [92.62388611, 11.41332912], [92.62387848, 11.41376019], [92.62384033, 11.41416836], [92.62380981, 11.41455078], [92.623909, 11.41502857], [92.62412262, 11.41559887], [92.62431335, 11.41615963], [92.62445831, 11.4167366], [92.62454224, 11.41729927], [92.62508392, 11.41937828], [92.62525177, 11.41982174], [92.62525177, 11.42039013], [92.62509918, 11.42097092]]], [[[92.56035614, 11.53799057], [92.56051636, 11.53758144], [92.56054688, 11.53711128], [92.56054688, 11.53660965], [92.56054688, 11.53606129], [92.5605545, 11.53551769], [92.56060028, 11.53495979], [92.56057739, 11.5344038], [92.56050873, 11.53379345], [92.56079102, 11.53304958], [92.56125641, 11.53264046], [92.5615921, 11.53217697], [92.56189728, 11.5317297], [92.56230164, 11.53139114], [92.56273651, 11.5311079], [92.56318665, 11.53083038], [92.56369019, 11.53058434], [92.56425476, 11.53045177], [92.56481934, 11.53029919], [92.56536865, 11.53018093], [92.56577301, 11.52983189], [92.56598663, 11.52948093], [92.56632233, 11.52909088], [92.56680298, 11.52862167], [92.56735992, 11.52831173], [92.56783295, 11.52814102], [92.56830597, 11.52803993], [92.56873322, 11.52775574], [92.56906128, 11.5273819], [92.56915283, 11.52690506], [92.56912231, 11.52639866], [92.56893158, 11.52593708], [92.5688858, 11.52544022], [92.56880188, 11.52496147], [92.56873322, 11.52451038], [92.56858063, 11.52411079], [92.56852722, 11.52367783], [92.56838226, 11.52326965], [92.56835175, 11.52291012], [92.56819916, 11.52249146], [92.56804657, 11.52202129], [92.56791687, 11.52152157], [92.56778717, 11.52101612], [92.56770325, 11.52050114], [92.56754303, 11.51999092], [92.56750488, 11.51940918], [92.56745911, 11.51882076], [92.56723785, 11.51828098], [92.56703186, 11.51777077], [92.56681061, 11.51730061], [92.56643677, 11.51698875], [92.56595612, 11.51686954], [92.56541443, 11.51692295], [92.56522369, 11.51694298], [92.564888, 11.51698017], [92.56434631, 11.51695919], [92.563797, 11.51684284], [92.5630188, 11.51674271], [92.56259918, 11.51669884], [92.56186676, 11.51655102], [92.56149292, 11.51675034], [92.56149292, 11.51723003], [92.56138611, 11.51778698], [92.56131744, 11.51839066], [92.56082916, 11.51896], [92.56063843, 11.51946163], [92.5606308, 11.52008247], [92.5605545, 11.52057934], [92.56043243, 11.5209589], [92.56021881, 11.52128029], [92.5598526, 11.52151108], [92.55938721, 11.52171993], [92.55898285, 11.52203274], [92.55867004, 11.52234268], [92.55849457, 11.52260876], [92.55833435, 11.52283287], [92.55814362, 11.52303314], [92.55784607, 11.52324104], [92.55753326, 11.52364445], [92.55724335, 11.52416134], [92.55697632, 11.52466965], [92.5566864, 11.52507114], [92.55641174, 11.52543068], [92.55613708, 11.52579975], [92.55584717, 11.52620125], [92.55555725, 11.5266819], [92.55526733, 11.52723122], [92.5548172, 11.52773952], [92.55448151, 11.52837086], [92.55422974, 11.52887917], [92.55419159, 11.52929401], [92.55396271, 11.52962017], [92.55370331, 11.52994061], [92.55335999, 11.53035069], [92.55272675, 11.53098965], [92.55256653, 11.5317297], [92.55240631, 11.53232956], [92.5522995, 11.5329113], [92.55229187, 11.53339195], [92.55211639, 11.53391075], [92.55220795, 11.53432178], [92.55203247, 11.53473186], [92.55190277, 11.53537941], [92.55175018, 11.536026], [92.55161285, 11.5367012], [92.55171967, 11.53742123], [92.55198669, 11.53812981], [92.55245972, 11.53869057], [92.55300903, 11.5384903], [92.55361176, 11.53851318], [92.55415344, 11.53835106], [92.55449677, 11.53785038], [92.55508423, 11.53794956], [92.55548096, 11.53835964], [92.55577087, 11.5385704], [92.55601501, 11.53890514], [92.55626678, 11.53930378], [92.55659485, 11.53969383], [92.55684662, 11.54008961], [92.55737305, 11.5406599], [92.55771637, 11.54073143], [92.55806732, 11.5410614], [92.55845642, 11.5413208], [92.55886841, 11.54134083], [92.55921936, 11.54107857], [92.55947113, 11.5406599], [92.5597229, 11.54020023], [92.55995178, 11.53973866], [92.56004333, 11.53924179], [92.56022644, 11.53885937], [92.56028748, 11.53841972], [92.56035614, 11.53799057]]], [[[92.61102295, 11.5882597], [92.61139679, 11.58802032], [92.61170959, 11.58762169], [92.61178589, 11.58716965], [92.61209869, 11.58681679], [92.61250305, 11.58644104], [92.61304474, 11.58608818], [92.61332703, 11.58578014], [92.6135788, 11.58558178], [92.61406708, 11.58508015], [92.6145401, 11.58479309], [92.61485291, 11.58448792], [92.61496735, 11.58427143], [92.61534882, 11.58399963], [92.61546326, 11.58355141], [92.61595917, 11.58329105], [92.61630249, 11.58315659], [92.61662292, 11.582901], [92.61682892, 11.58258247], [92.61715698, 11.58248043], [92.6173172, 11.58226109], [92.61746979, 11.58198071], [92.61754608, 11.58161068], [92.6175766, 11.58123112], [92.61763763, 11.58080482], [92.617836, 11.58016205], [92.61777496, 11.57960129], [92.61798096, 11.57898998], [92.6184082, 11.57837105], [92.61863708, 11.57806969], [92.61889648, 11.57783985], [92.61902618, 11.57762146], [92.61921692, 11.57709026], [92.6192627, 11.57644939], [92.61927032, 11.57602978], [92.61921692, 11.5748806], [92.61914825, 11.57405186], [92.61897278, 11.57301903], [92.61868286, 11.57260036], [92.61856079, 11.5721283], [92.61852264, 11.57164001], [92.61857605, 11.57110023], [92.61850739, 11.57058716], [92.61828613, 11.57015038], [92.61810303, 11.56973934], [92.61789703, 11.56931114], [92.61769867, 11.56881046], [92.61750793, 11.56826019], [92.61734772, 11.56770039], [92.61730957, 11.56705189], [92.61726379, 11.56645298], [92.61714172, 11.56613159], [92.61694336, 11.56579018], [92.61666107, 11.565382], [92.61640167, 11.56492138], [92.61617279, 11.56448174], [92.61592865, 11.56414032], [92.61575317, 11.56382275], [92.61554718, 11.5635519], [92.61534882, 11.56326199], [92.61510468, 11.5629158], [92.61461639, 11.56269932], [92.6144104, 11.56280041], [92.61394501, 11.56305885], [92.61331177, 11.5633812], [92.61266327, 11.5636816], [92.6121521, 11.56412601], [92.61167908, 11.56455421], [92.61128998, 11.56500053], [92.61094666, 11.56544304], [92.610672, 11.56589031], [92.61052704, 11.56638908], [92.61031342, 11.56682205], [92.61025238, 11.56727123], [92.61010742, 11.56765175], [92.6099472, 11.56797123], [92.60971069, 11.56818962], [92.60943604, 11.56836128], [92.60916138, 11.56856823], [92.6089325, 11.56859493], [92.6088028, 11.56861115], [92.60839844, 11.5685997], [92.60795593, 11.56851101], [92.6075058, 11.56838131], [92.60707092, 11.56850243], [92.60669708, 11.56876183], [92.60639191, 11.56908131], [92.6062088, 11.56984901], [92.60607147, 11.57032967], [92.60600281, 11.57053947], [92.60578918, 11.57061005], [92.60543823, 11.57061005], [92.60528564, 11.57050514], [92.60516357, 11.57005596], [92.60508728, 11.56971169], [92.60488129, 11.56888008], [92.60443115, 11.56847], [92.60398102, 11.56807995], [92.603508, 11.56777859], [92.60305786, 11.56753063], [92.60251617, 11.56738091], [92.60195923, 11.56724644], [92.60135651, 11.56727791], [92.60089111, 11.56760788], [92.6006012, 11.56809425], [92.60055542, 11.56867313], [92.60053253, 11.56926346], [92.60042572, 11.56985092], [92.60050201, 11.57040024], [92.60048676, 11.5711298], [92.60048676, 11.57180023], [92.60048676, 11.57246971], [92.60048676, 11.57313061], [92.60045624, 11.57374191], [92.60049438, 11.57446384], [92.60041809, 11.57514095], [92.60047913, 11.57581139], [92.60050201, 11.57646275], [92.60055542, 11.57712555], [92.60069275, 11.57779217], [92.60072327, 11.57849979], [92.60069275, 11.57903194], [92.60102081, 11.57960796], [92.60101318, 11.58019161], [92.60106659, 11.58075047], [92.60111237, 11.58134937], [92.6013031, 11.58195782], [92.60131073, 11.58254147], [92.60115051, 11.58314133], [92.60107422, 11.58380222], [92.60088348, 11.58442211], [92.60092163, 11.58506203], [92.60115814, 11.58561993], [92.60154724, 11.5860014], [92.60199738, 11.5863018], [92.60249329, 11.58650017], [92.60298157, 11.58668518], [92.6034317, 11.58690071], [92.60394287, 11.5869379], [92.60443115, 11.58699036], [92.60486603, 11.58720875], [92.60533905, 11.58740044], [92.60587311, 11.58753014], [92.60639191, 11.58773994], [92.60695648, 11.58782196], [92.60747528, 11.58801556], [92.60800934, 11.58808422], [92.60831451, 11.58814621], [92.60852051, 11.58819103], [92.60901642, 11.5880909], [92.60945129, 11.58811188], [92.60980988, 11.58829212], [92.61019897, 11.58833504], [92.61060333, 11.58833027], [92.61102295, 11.5882597]]], [[[92.56751251, 11.57081795], [92.56772614, 11.57053947], [92.56765747, 11.57012653], [92.56751251, 11.56999016], [92.56738281, 11.56991959], [92.5670929, 11.56964397], [92.56716156, 11.5692997], [92.56716919, 11.56901932], [92.56702423, 11.56867695], [92.56646729, 11.56826019], [92.56625366, 11.56798935], [92.56577301, 11.56792068], [92.56549072, 11.56812954], [92.56520844, 11.56812572], [92.56500244, 11.56833076], [92.56500244, 11.56854057], [92.56513977, 11.56881618], [92.56520844, 11.56901932], [92.56542206, 11.5692997], [92.56535339, 11.56991959], [92.56549072, 11.57026577], [92.56555176, 11.5704689], [92.56555176, 11.57074928], [92.56584167, 11.5708313], [92.56632996, 11.57067204], [92.56660461, 11.57088566], [92.56681824, 11.57102489], [92.56723785, 11.57102489], [92.56751251, 11.57081795]]], [[[92.53975677, 11.60332012], [92.54003906, 11.60325623], [92.54091644, 11.60331345], [92.54132843, 11.60312939], [92.54171753, 11.60298061], [92.54202271, 11.60277081], [92.5428772, 11.602005], [92.54399109, 11.60179996], [92.54483032, 11.60172939], [92.54538727, 11.60172939], [92.54572296, 11.60186195], [92.5461731, 11.6019392], [92.54660034, 11.60162926], [92.54693604, 11.60128021], [92.54724884, 11.60095692], [92.54749298, 11.60063076], [92.54767609, 11.60029984], [92.54782867, 11.59996986], [92.54807281, 11.59967995], [92.54818726, 11.59946156], [92.54763794, 11.59894943], [92.54724121, 11.59887123], [92.54659271, 11.59869099], [92.54641724, 11.59801197], [92.54615784, 11.59760189], [92.54601288, 11.59720516], [92.54597473, 11.59669304], [92.54607391, 11.59613228], [92.5458374, 11.5955801], [92.54556274, 11.59499931], [92.54532623, 11.59434032], [92.54519653, 11.5936203], [92.54512024, 11.59293175], [92.54512787, 11.59237957], [92.54550934, 11.59178066], [92.54582214, 11.59169197], [92.54647064, 11.5916853], [92.54682922, 11.59166241], [92.54718018, 11.59170055], [92.54747772, 11.5919199], [92.54776001, 11.59206581], [92.54821777, 11.59241486], [92.54841614, 11.59261131], [92.54888916, 11.59283161], [92.54930115, 11.5930891], [92.54973602, 11.59329033], [92.55027771, 11.59333992], [92.55079651, 11.59333992], [92.55132294, 11.59329033], [92.55175781, 11.59307575], [92.55223083, 11.59290218], [92.55264282, 11.59252357], [92.55309296, 11.59236908], [92.55356598, 11.59229183], [92.55387115, 11.59198189], [92.5539856, 11.59179211], [92.55427551, 11.59127331], [92.55475616, 11.59125042], [92.55532074, 11.59132957], [92.55541992, 11.59130001], [92.55562592, 11.59123421], [92.55621338, 11.59119129], [92.55648041, 11.59125042], [92.55683136, 11.59125042], [92.55716705, 11.59140015], [92.55755615, 11.59147072], [92.55791473, 11.5916214], [92.55832672, 11.59165955], [92.55874634, 11.59167194], [92.55916595, 11.59171009], [92.55951691, 11.59184933], [92.55992889, 11.59192657], [92.56035614, 11.59196091], [92.56080627, 11.59205723], [92.5612793, 11.5921936], [92.56182861, 11.59227085], [92.56245422, 11.59241486], [92.5631485, 11.59229565], [92.56391144, 11.59222126], [92.56468201, 11.59212112], [92.56533051, 11.59181976], [92.56563568, 11.59195423], [92.56609344, 11.59217262], [92.5667038, 11.59212971], [92.56713104, 11.59183979], [92.56735229, 11.59141159], [92.56736755, 11.59045029], [92.56751251, 11.59017181], [92.56828308, 11.59017181], [92.56903839, 11.58996868], [92.56926727, 11.58969975], [92.56942749, 11.58934021], [92.56945801, 11.58889103], [92.56939697, 11.58842182], [92.56916046, 11.58804131], [92.5688324, 11.58773327], [92.56837463, 11.587533], [92.56780243, 11.58748531], [92.5672226, 11.58745289], [92.56674194, 11.58722496], [92.56627655, 11.58699036], [92.5657959, 11.58679199], [92.5652771, 11.5866394], [92.56477356, 11.5864048], [92.5642395, 11.58618069], [92.56371307, 11.58591747], [92.56321716, 11.58554077], [92.56276703, 11.58508015], [92.56239319, 11.58456993], [92.56221771, 11.58399487], [92.56207275, 11.58346367], [92.56195831, 11.58297443], [92.56194305, 11.58245945], [92.56194305, 11.58187962], [92.56196594, 11.58126259], [92.56208038, 11.58061314], [92.56223297, 11.57999611], [92.56241608, 11.57947063], [92.5626297, 11.57905197], [92.56276703, 11.57865143], [92.56291962, 11.57833004], [92.56310272, 11.57800961], [92.5632782, 11.57769966], [92.56358337, 11.57746124], [92.56380463, 11.57709408], [92.56402588, 11.57666111], [92.56430054, 11.57626247], [92.56454468, 11.57585907], [92.56476593, 11.57550144], [92.56499481, 11.57517529], [92.56516266, 11.57481956], [92.56529236, 11.57441425], [92.56539917, 11.57400799], [92.56535339, 11.57349968], [92.56507874, 11.57291889], [92.56443024, 11.57308292], [92.56388092, 11.57305336], [92.56338501, 11.57301903], [92.56299591, 11.5728302], [92.56262207, 11.57263184], [92.56225586, 11.5723896], [92.56188965, 11.5720892], [92.56143951, 11.57188892], [92.56099701, 11.571661], [92.56058502, 11.57143497], [92.56015015, 11.57125092], [92.55974579, 11.570961], [92.55937195, 11.57056904], [92.55895233, 11.5701704], [92.55858612, 11.56971359], [92.55820465, 11.56932735], [92.55779266, 11.56905079], [92.55742645, 11.56879997], [92.55712891, 11.56851959], [92.55685425, 11.56822586], [92.5566864, 11.5678606], [92.55659485, 11.56746292], [92.55644226, 11.56710339], [92.55651855, 11.56668282], [92.55661011, 11.56624126], [92.55644989, 11.56582165], [92.55619812, 11.565382], [92.55584717, 11.56495094], [92.55547333, 11.56449127], [92.55504608, 11.56405067], [92.55473328, 11.5635519], [92.55445862, 11.56305027], [92.55423737, 11.56258965], [92.55397034, 11.56222057], [92.55371094, 11.56194496], [92.55343628, 11.56172085], [92.55306244, 11.56165981], [92.55261993, 11.56162834], [92.55214691, 11.56157112], [92.55169678, 11.56139088], [92.55127716, 11.56118107], [92.5508194, 11.56109238], [92.55039978, 11.56095982], [92.54995728, 11.560853], [92.54947662, 11.56079197], [92.54902649, 11.56055927], [92.5485611, 11.56039047], [92.54802704, 11.56054115], [92.54750824, 11.56070995], [92.54702759, 11.56087971], [92.54662323, 11.56110191], [92.54620361, 11.56126785], [92.54576111, 11.56139278], [92.54530334, 11.56151199], [92.5447998, 11.56162643], [92.54434204, 11.56185055], [92.54387665, 11.56206989], [92.543396, 11.5622406], [92.54296875, 11.56243038], [92.54251099, 11.56250763], [92.54208374, 11.56257439], [92.54180145, 11.5625782], [92.54167175, 11.56258106], [92.54128265, 11.56253147], [92.5408783, 11.56247997], [92.54046631, 11.56234074], [92.54003143, 11.5622406], [92.53952789, 11.56218433], [92.53901672, 11.56200409], [92.53842926, 11.56186676], [92.53791046, 11.56161022], [92.5375061, 11.56122017], [92.5371933, 11.56080055], [92.5369339, 11.56039047], [92.53666687, 11.55999756], [92.53639221, 11.55960178], [92.53610229, 11.55918026], [92.53578186, 11.5587492], [92.53533936, 11.55840969], [92.53488159, 11.55808163], [92.53444672, 11.55778122], [92.53403473, 11.55752277], [92.533638, 11.55729485], [92.53330994, 11.55702019], [92.53296661, 11.55674171], [92.53262329, 11.55646992], [92.53231812, 11.55612373], [92.53198242, 11.55574608], [92.5316391, 11.55533981], [92.53149414, 11.55509377], [92.53118134, 11.55485725], [92.53074646, 11.55447197], [92.53045654, 11.55420017], [92.53018188, 11.55412674], [92.52997589, 11.5544014], [92.52997589, 11.55481625], [92.53018188, 11.55495453], [92.53032684, 11.55515957], [92.53040314, 11.55563164], [92.53035736, 11.55626965], [92.5303421, 11.55693054], [92.53045654, 11.55754185], [92.53060913, 11.55814648], [92.53082275, 11.55865097], [92.53104401, 11.55908012], [92.53125763, 11.55938053], [92.53147888, 11.5595789], [92.53166962, 11.55980015], [92.53183746, 11.56007099], [92.53183746, 11.56042004], [92.53206635, 11.56101704], [92.53248596, 11.56123066], [92.53279114, 11.56167126], [92.53312683, 11.56212044], [92.53328705, 11.56247139], [92.53399658, 11.56258774], [92.53444672, 11.56280041], [92.53483582, 11.56309795], [92.5351181, 11.56348991], [92.53526306, 11.56399059], [92.53527832, 11.56448174], [92.53527832, 11.56490803], [92.53527832, 11.56562996], [92.53513336, 11.56666946], [92.53466034, 11.56797123], [92.53447723, 11.56830978], [92.53439331, 11.56861782], [92.53423309, 11.56885147], [92.53414154, 11.56914043], [92.53404999, 11.56944084], [92.53375244, 11.56972122], [92.5333786, 11.56980324], [92.53312683, 11.56990147], [92.53296661, 11.57025719], [92.53277588, 11.57060337], [92.53255463, 11.57096577], [92.5324173, 11.57143974], [92.53225708, 11.57192516], [92.53224945, 11.57245445], [92.53238678, 11.57299042], [92.53248596, 11.5735302], [92.53256989, 11.57409859], [92.53279114, 11.57462978], [92.5330658, 11.57509136], [92.53335571, 11.5752573], [92.53369141, 11.57557201], [92.53401184, 11.57608032], [92.53418732, 11.57642174], [92.5341568, 11.57680035], [92.53424072, 11.57720089], [92.53430176, 11.57759953], [92.53420258, 11.57801723], [92.53425598, 11.57839966], [92.53440857, 11.57880592], [92.53447723, 11.57929134], [92.53465271, 11.57978058], [92.53477478, 11.58030987], [92.53497314, 11.58078194], [92.53504181, 11.58126736], [92.53524017, 11.58167076], [92.53527832, 11.58211136], [92.53527069, 11.58255005], [92.53518677, 11.58298969], [92.53501892, 11.58342075], [92.53488922, 11.58386326], [92.53473663, 11.58427143], [92.53469849, 11.58468056], [92.53452301, 11.58494568], [92.5344162, 11.58523083], [92.53426361, 11.58547878], [92.5341568, 11.58580112], [92.5340271, 11.58610058], [92.53391266, 11.58641148], [92.53380585, 11.58672142], [92.53363037, 11.58698082], [92.53349304, 11.58732986], [92.53330994, 11.58771515], [92.5330658, 11.58813], [92.5328064, 11.58862019], [92.532547, 11.58917618], [92.53244781, 11.58988476], [92.53231049, 11.59059143], [92.53223419, 11.59128189], [92.53222656, 11.59191322], [92.53221893, 11.5924511], [92.5321579, 11.59292126], [92.53198242, 11.5933466], [92.53201294, 11.59384441], [92.53215027, 11.59442043], [92.5319519, 11.59506512], [92.53217316, 11.5957098], [92.53251648, 11.59632111], [92.53270721, 11.5968914], [92.53285217, 11.59743595], [92.53308105, 11.59800053], [92.53338623, 11.59856129], [92.53357697, 11.59901047], [92.53369904, 11.59956169], [92.53376007, 11.60018444], [92.53362274, 11.60072041], [92.53360748, 11.60135078], [92.53379059, 11.60182953], [92.5341568, 11.60221004], [92.53446198, 11.60252666], [92.5346756, 11.60287952], [92.53475952, 11.60332012], [92.53491974, 11.60367107], [92.53504181, 11.604002], [92.53525543, 11.60424614], [92.5354538, 11.60452366], [92.53559113, 11.60492039], [92.53588104, 11.60537148], [92.53635406, 11.60577869], [92.53668213, 11.60592842], [92.53691864, 11.60603523], [92.53741455, 11.6058979], [92.53787994, 11.60569954], [92.53904724, 11.60464001], [92.53975677, 11.60332012]]], [[[92.57826233, 11.58180523], [92.57805634, 11.58166599], [92.57771301, 11.58319092], [92.57659912, 11.58485889], [92.5772171, 11.58528137], [92.57805634, 11.58528137], [92.57861328, 11.58500099], [92.57888794, 11.58471966], [92.57944489, 11.58444405], [92.57958221, 11.58382034], [92.57971954, 11.58306122], [92.57943726, 11.58278084], [92.57861328, 11.58250046], [92.57861328, 11.58222008], [92.57833099, 11.58194447], [92.57826233, 11.58180523]]], [[[92.77108765, 11.78885078], [92.77098846, 11.78822041], [92.77085876, 11.78759098], [92.77082062, 11.78696156], [92.77102661, 11.78633022], [92.77094269, 11.78576088], [92.77069855, 11.78524971], [92.77036285, 11.78480053], [92.77002716, 11.78434086], [92.76973724, 11.78386021], [92.7694931, 11.78335094], [92.76930237, 11.78277016], [92.76895905, 11.78215885], [92.76882172, 11.78175163], [92.76869202, 11.78126144], [92.76847076, 11.78112507], [92.76798248, 11.78071022], [92.76763153, 11.78043175], [92.76728058, 11.78001881], [92.76714325, 11.77940178], [92.76706696, 11.77871132], [92.76727295, 11.77807999], [92.76741028, 11.77761269], [92.76755524, 11.77716446], [92.76778412, 11.77675819], [92.76803589, 11.77637005], [92.76825714, 11.77598953], [92.7684021, 11.77567959], [92.76851654, 11.77544975], [92.76860809, 11.77523994], [92.76866913, 11.77499199], [92.76876831, 11.77471066], [92.76883698, 11.77439404], [92.76869202, 11.77338886], [92.76862335, 11.77235031], [92.7682724, 11.77145672], [92.76777649, 11.77015114], [92.7664566, 11.76904106], [92.76616669, 11.76871014], [92.76568604, 11.76798058], [92.76531219, 11.76753044], [92.76500702, 11.76710606], [92.76481628, 11.76670933], [92.76490021, 11.76634693], [92.76499176, 11.76599121], [92.76496124, 11.76567745], [92.76506042, 11.76546001], [92.76502991, 11.76512337], [92.76509857, 11.7648468], [92.76529694, 11.76456928], [92.76558685, 11.76429558], [92.76571655, 11.76373959], [92.76579285, 11.76339817], [92.76579285, 11.76271152], [92.76558685, 11.76194954], [92.76529694, 11.76140118], [92.76502991, 11.7609787], [92.764534, 11.76070595], [92.76405334, 11.76071072], [92.76397705, 11.76043034], [92.76377106, 11.75987911], [92.76390839, 11.75967979], [92.76399231, 11.75962257], [92.76412201, 11.75953388], [92.764534, 11.75939465], [92.76499176, 11.75890064], [92.76526642, 11.75854111], [92.76553345, 11.75823784], [92.76554108, 11.75800991], [92.76560211, 11.75791168], [92.76563263, 11.75769138], [92.76554871, 11.75738144], [92.7657547, 11.75682545], [92.76589203, 11.75627995], [92.76596832, 11.75583076], [92.76595306, 11.75540924], [92.76590729, 11.75505066], [92.76583862, 11.75470734], [92.76577759, 11.75433064], [92.76566315, 11.75389099], [92.76570892, 11.75339031], [92.76583862, 11.75286102], [92.76596069, 11.75235081], [92.76598358, 11.75188255], [92.76580811, 11.75146008], [92.76554871, 11.75104046], [92.76528168, 11.75059605], [92.76502991, 11.75010109], [92.76481628, 11.74956989], [92.76455688, 11.7490797], [92.76416016, 11.74868965], [92.7637558, 11.74834156], [92.76341248, 11.74799061], [92.76319885, 11.74750996], [92.76284027, 11.74671173], [92.76262665, 11.746562], [92.76235199, 11.74643612], [92.76200104, 11.74630165], [92.76130676, 11.7459507], [92.76109314, 11.74560738], [92.76081085, 11.74506187], [92.76081085, 11.74457169], [92.76095581, 11.7439518], [92.76102448, 11.74346924], [92.7611618, 11.74304962], [92.76130676, 11.7426424], [92.76158142, 11.74229527], [92.76180267, 11.74188042], [92.76193237, 11.74153614], [92.76193237, 11.74112129], [92.76179504, 11.7407093], [92.76151276, 11.74022102], [92.76123047, 11.73953533], [92.76109314, 11.7388401], [92.76108551, 11.73856926], [92.76055908, 11.7381897], [92.75974274, 11.73732853], [92.75918579, 11.73664093], [92.75904083, 11.73608017], [92.75883484, 11.73560429], [92.75869751, 11.73504734], [92.75866699, 11.73475075], [92.75881195, 11.73440933], [92.75891876, 11.73400116], [92.75900269, 11.73359108], [92.75917053, 11.73318958], [92.75920868, 11.73287106], [92.75920868, 11.73253632], [92.75927734, 11.73213005], [92.75891113, 11.73151016], [92.75891113, 11.73099995], [92.75910187, 11.73025036], [92.75919342, 11.72961903], [92.75911713, 11.72906017], [92.75891876, 11.72864056], [92.75862885, 11.72833061], [92.75835419, 11.72806358], [92.7580719, 11.7278204], [92.7576828, 11.72768116], [92.75740051, 11.72741032], [92.75712585, 11.72721195], [92.75688171, 11.72696114], [92.75665283, 11.72670078], [92.75643158, 11.72640038], [92.7562561, 11.7260313], [92.7561264, 11.72559071], [92.75614929, 11.72510147], [92.75631714, 11.72461128], [92.75643921, 11.72407341], [92.75662994, 11.7235651], [92.75666809, 11.723032], [92.75666809, 11.72248268], [92.75668335, 11.72192192], [92.75669861, 11.72137737], [92.75667572, 11.72083187], [92.75666809, 11.72027874], [92.75662994, 11.71972275], [92.75641632, 11.71920967], [92.75608063, 11.71879005], [92.75576019, 11.71840954], [92.75546265, 11.71813202], [92.75506592, 11.71819973], [92.7550354, 11.71806335], [92.75489807, 11.71744061], [92.75495148, 11.71699905], [92.75505066, 11.71663189], [92.75526428, 11.71622181], [92.75547791, 11.71578884], [92.75563049, 11.71535969], [92.75583649, 11.71500015], [92.75609589, 11.71466064], [92.7563324, 11.71427059], [92.7564621, 11.71377373], [92.7567215, 11.71336555], [92.75699615, 11.71298122], [92.75721741, 11.71253014], [92.75740051, 11.71207142], [92.75758362, 11.7116003], [92.75765991, 11.71037102], [92.75772858, 11.70954418], [92.75772858, 11.70809364], [92.75759125, 11.70767975], [92.75710297, 11.70677853], [92.75682068, 11.70616245], [92.75654602, 11.70547104], [92.75619507, 11.70416069], [92.75584412, 11.70319366], [92.75570679, 11.70236683], [92.75535583, 11.70181084], [92.75507355, 11.70105553], [92.75457001, 11.70118427], [92.75400543, 11.7015152], [92.75366974, 11.70188141], [92.75337219, 11.70228863], [92.75311279, 11.70271969], [92.75282288, 11.70314026], [92.75248718, 11.7035408], [92.75215149, 11.70388699], [92.75183868, 11.70421982], [92.75164032, 11.7046423], [92.7514267, 11.70501995], [92.75131226, 11.70546436], [92.75111389, 11.70583439], [92.7509079, 11.70615005], [92.75074768, 11.70645618], [92.75055695, 11.70671082], [92.75032043, 11.70697975], [92.75004578, 11.7072897], [92.74971771, 11.70765018], [92.7493515, 11.70804024], [92.74894714, 11.70842934], [92.74859619, 11.70888996], [92.74816895, 11.70931816], [92.74767303, 11.70975971], [92.74723053, 11.71032143], [92.74697876, 11.7109499], [92.74694061, 11.71153069], [92.74688721, 11.71194553], [92.74671173, 11.71219921], [92.74659729, 11.71298981], [92.74645996, 11.71334076], [92.74645996, 11.71375084], [92.7461853, 11.71402454], [92.74576569, 11.71416378], [92.74555206, 11.71416378], [92.74534607, 11.71409321], [92.74494934, 11.71357059], [92.74454498, 11.71342754], [92.74415588, 11.71321964], [92.74377441, 11.7130537], [92.74345398, 11.71284866], [92.74327087, 11.71247864], [92.74297333, 11.71215057], [92.74280548, 11.71169281], [92.74275208, 11.71112823], [92.74263, 11.71055984], [92.74249268, 11.71001625], [92.74236298, 11.70949173], [92.74224854, 11.70898056], [92.74221802, 11.70847034], [92.74221802, 11.70796204], [92.74224091, 11.70745182], [92.74234772, 11.70694065], [92.74247742, 11.70639038], [92.74253082, 11.70573139], [92.74265289, 11.70502663], [92.74278259, 11.70430183], [92.74295044, 11.70362282], [92.74311829, 11.70301628], [92.74333191, 11.70256138], [92.74352264, 11.70215034], [92.74364471, 11.70175171], [92.74363708, 11.70141697], [92.74372864, 11.70086002], [92.7437973, 11.70036125], [92.74391937, 11.69996929], [92.74391937, 11.69969082], [92.74394226, 11.6993742], [92.74397278, 11.69909191], [92.74407959, 11.69879055], [92.74407959, 11.6984396], [92.74401093, 11.69804573], [92.74391937, 11.69756031], [92.74402618, 11.69701099], [92.74415588, 11.696455], [92.74424744, 11.69594002], [92.74440765, 11.69554138], [92.74446106, 11.69515991], [92.7445755, 11.69487095], [92.74469757, 11.69460201], [92.74472809, 11.69429016], [92.74481201, 11.69397068], [92.74495697, 11.69364929], [92.74500275, 11.6932497], [92.74504089, 11.69283104], [92.74517822, 11.69244957], [92.74518585, 11.69208145], [92.74501038, 11.69173717], [92.74481201, 11.69141102], [92.74452209, 11.69113064], [92.74417114, 11.6909256], [92.74375153, 11.69074059], [92.74324799, 11.69057178], [92.74265289, 11.69043064], [92.74201965, 11.69025993], [92.74137878, 11.69007969], [92.7407074, 11.69013691], [92.74008942, 11.69029045], [92.73958588, 11.69049263], [92.73911285, 11.6906004], [92.73867798, 11.69080925], [92.73821259, 11.69097614], [92.73776245, 11.69126511], [92.73726654, 11.69160938], [92.73677063, 11.69200134], [92.73631287, 11.69244099], [92.73587799, 11.69282627], [92.73561859, 11.69327068], [92.73549652, 11.69373989], [92.7352829, 11.69408035], [92.73500824, 11.69437599], [92.73470306, 11.69471359], [92.73426056, 11.69500256], [92.73377991, 11.69531345], [92.73336792, 11.69571018], [92.73303223, 11.69614029], [92.73271179, 11.69649124], [92.73253632, 11.69686699], [92.73239136, 11.6970911], [92.73232269, 11.69724846], [92.73197937, 11.69758129], [92.73190308, 11.69803047], [92.73146057, 11.69840145], [92.73107147, 11.69815063], [92.73072052, 11.69819164], [92.73023224, 11.69804955], [92.7299118, 11.69791126], [92.72970581, 11.69736195], [92.72973633, 11.69724846], [92.72975159, 11.69696999], [92.72953033, 11.69672203], [92.72927856, 11.69626141], [92.72916412, 11.69600964], [92.72891998, 11.69566154], [92.72867584, 11.69530201], [92.72834015, 11.69503021], [92.72792816, 11.69494247], [92.72753143, 11.69527912], [92.72722626, 11.69578934], [92.72701263, 11.6962862], [92.72674561, 11.69661427], [92.72677612, 11.69740963], [92.72634125, 11.69746017], [92.72603607, 11.69742107], [92.72558594, 11.69736195], [92.72524261, 11.69723034], [92.72483826, 11.69725037], [92.72444916, 11.69731426], [92.72403717, 11.69738007], [92.72370148, 11.69745064], [92.72360992, 11.69747066], [92.72348022, 11.69746876], [92.72309875, 11.69746208], [92.72252655, 11.69742966], [92.72193909, 11.69796753], [92.72145844, 11.69848061], [92.72120667, 11.69896889], [92.72107697, 11.69946957], [92.72088623, 11.69999027], [92.72079468, 11.70056915], [92.72061157, 11.70108414], [92.72052765, 11.70157242], [92.72038269, 11.7019701], [92.72026825, 11.70232964], [92.72011566, 11.70268631], [92.72001648, 11.70310307], [92.71996307, 11.70355034], [92.71980286, 11.70392132], [92.71964264, 11.70423126], [92.71947479, 11.70445919], [92.71935272, 11.70471191], [92.71916199, 11.70493126], [92.71897888, 11.70525455], [92.71869659, 11.70549202], [92.7184906, 11.70573807], [92.71820068, 11.70599079], [92.71772003, 11.70577908], [92.71734619, 11.7056694], [92.71708679, 11.70558071], [92.7164917, 11.70544147], [92.71620941, 11.70482159], [92.71585083, 11.7044611], [92.71550751, 11.70410824], [92.71523285, 11.70397091], [92.71495056, 11.70382595], [92.71434784, 11.70367146], [92.71409607, 11.70320129], [92.71398163, 11.7027607], [92.71396637, 11.70240974], [92.71405029, 11.70186138], [92.71407318, 11.7014389], [92.71404266, 11.70096111], [92.71420288, 11.70048714], [92.71437836, 11.70005131], [92.71443176, 11.69961071], [92.71440125, 11.69922638], [92.71421814, 11.6989212], [92.71414948, 11.69861126], [92.7140274, 11.69832802], [92.71389008, 11.69802094], [92.71376038, 11.69764042], [92.71363068, 11.69723892], [92.71356201, 11.69678116], [92.71337891, 11.6963501], [92.71328735, 11.69584179], [92.71304321, 11.69543171], [92.71269989, 11.69513321], [92.71231079, 11.6950264], [92.71189117, 11.69511032], [92.71154022, 11.69544125], [92.71115875, 11.69569778], [92.71076202, 11.69608116], [92.71032715, 11.69649124], [92.7100296, 11.69699001], [92.70987701, 11.69745064], [92.70970154, 11.69779491], [92.70948029, 11.69807053], [92.70928955, 11.69841003], [92.70911407, 11.69880199], [92.70887756, 11.69917202], [92.70862579, 11.69953156], [92.70843506, 11.69991493], [92.70832062, 11.70033169], [92.70817566, 11.70071697], [92.70807648, 11.70106316], [92.7084198, 11.70169926], [92.70890808, 11.70197868], [92.70905304, 11.70259857], [92.70905304, 11.70300961], [92.70877075, 11.70351124], [92.70845795, 11.70346069], [92.70794678, 11.70326042], [92.70761108, 11.70325089], [92.70736694, 11.70345879], [92.70705414, 11.7037344], [92.70671082, 11.70410061], [92.70635223, 11.70448208], [92.7060318, 11.70485115], [92.70581055, 11.70524979], [92.70556641, 11.70556927], [92.70530701, 11.70585155], [92.70506287, 11.70606136], [92.70472717, 11.70617104], [92.70446014, 11.7063303], [92.70420074, 11.70643139], [92.70394897, 11.70658112], [92.70366669, 11.70671082], [92.70334625, 11.70692062], [92.70231628, 11.70718002], [92.70189667, 11.70713043], [92.70207214, 11.70662022], [92.70233154, 11.70610046], [92.70269012, 11.70566273], [92.70311737, 11.70534134], [92.70350647, 11.70506096], [92.70378876, 11.70476532], [92.70410919, 11.70450878], [92.70448303, 11.70427036], [92.70485687, 11.70401001], [92.70522308, 11.70364094], [92.70545197, 11.70320129], [92.70526123, 11.70281124], [92.70477295, 11.7025013], [92.70419312, 11.70222092], [92.70357513, 11.70199299], [92.70294189, 11.70196056], [92.7023468, 11.70202065], [92.70185852, 11.70194054], [92.70143127, 11.70183086], [92.7010498, 11.7017107], [92.70067596, 11.70167446], [92.70030212, 11.70167446], [92.69993591, 11.70171547], [92.69927216, 11.70163536], [92.69878387, 11.70170403], [92.69850159, 11.70177174], [92.69742584, 11.70140266], [92.69637299, 11.70112705], [92.69563293, 11.70055008], [92.69599152, 11.70018959], [92.69661713, 11.70026112], [92.69830322, 11.70054054], [92.69934082, 11.7007513], [92.7041626, 11.7007513], [92.70479584, 11.70072079], [92.70517731, 11.70055008], [92.70553589, 11.70033169], [92.70592499, 11.70022678], [92.70623016, 11.70003128], [92.70654297, 11.69982147], [92.7067337, 11.69953632], [92.70682526, 11.69918346], [92.70704651, 11.69907379], [92.70718384, 11.69859028], [92.70717621, 11.69776058], [92.70739746, 11.69714069], [92.70739746, 11.69693565], [92.7072525, 11.69672775], [92.70690918, 11.69672775], [92.70662689, 11.69714069], [92.7064209, 11.69741726], [92.70627594, 11.69789982], [92.7064209, 11.69845104], [92.70630646, 11.69882965], [92.70565796, 11.69853973], [92.70490265, 11.69834042], [92.70449829, 11.69791985], [92.70388031, 11.69764042], [92.7035675, 11.69729137], [92.70314789, 11.69689941], [92.70281219, 11.69650269], [92.70259094, 11.69602203], [92.70250702, 11.69546986], [92.70249176, 11.69492054], [92.70243835, 11.6944313], [92.70226288, 11.69402981], [92.7022171, 11.69363976], [92.7022171, 11.69326019], [92.70217896, 11.6928606], [92.70199585, 11.69244957], [92.70198059, 11.69200134], [92.70215607, 11.69154072], [92.70223236, 11.69104195], [92.7023468, 11.69057941], [92.70252228, 11.69018745], [92.70275879, 11.68983173], [92.70292664, 11.6894207], [92.70305634, 11.68894958], [92.70314026, 11.68844414], [92.70307159, 11.68785095], [92.70307159, 11.68721962], [92.70314789, 11.68659306], [92.70330048, 11.68599606], [92.70334625, 11.68541718], [92.70343781, 11.68492031], [92.70361328, 11.68447113], [92.70375824, 11.68401527], [92.70387268, 11.68353176], [92.70388031, 11.68302822], [92.70379639, 11.68256092], [92.70359802, 11.68217754], [92.70334625, 11.68187141], [92.70310974, 11.68158054], [92.70292664, 11.68122101], [92.70271301, 11.6807518], [92.70249176, 11.68028355], [92.70224762, 11.67988968], [92.70204163, 11.67953014], [92.70189667, 11.67912197], [92.70166779, 11.67871189], [92.70140839, 11.67824745], [92.70118713, 11.67764091], [92.70094299, 11.67696095], [92.70107269, 11.67627144], [92.70111084, 11.67560959], [92.70114899, 11.67506504], [92.7013092, 11.67463017], [92.70140839, 11.6742239], [92.70142365, 11.67386627], [92.7015686, 11.67352009], [92.70171356, 11.67328072], [92.70197296, 11.67294979], [92.70251465, 11.67261124], [92.70291138, 11.67270184], [92.70329285, 11.67265797], [92.70366669, 11.67251015], [92.70407104, 11.67228222], [92.70453644, 11.67191124], [92.7049408, 11.67185402], [92.70513153, 11.67191315], [92.70532227, 11.67197037], [92.70569611, 11.67193127], [92.70607758, 11.67192173], [92.70644379, 11.67193985], [92.70684052, 11.67193985], [92.70726013, 11.67195034], [92.70747375, 11.67194653], [92.70768738, 11.67194271], [92.70808411, 11.67190647], [92.70836639, 11.6717186], [92.70855713, 11.67151356], [92.70861053, 11.67121124], [92.70858002, 11.67086029], [92.70839691, 11.67050743], [92.70819855, 11.67011929], [92.70791626, 11.6698246], [92.70761871, 11.66953087], [92.70729828, 11.66922092], [92.70694733, 11.66893196], [92.70649719, 11.66877937], [92.70610809, 11.66864014], [92.70574188, 11.66858959], [92.70542908, 11.6684761], [92.70513153, 11.66830063], [92.70484161, 11.66805458], [92.7045517, 11.66779232], [92.70423889, 11.66757965], [92.70392609, 11.66740036], [92.70365143, 11.66718769], [92.70334625, 11.66694927], [92.70292664, 11.66675091], [92.70240784, 11.66666889], [92.70184326, 11.66666698], [92.70131683, 11.66666889], [92.7008667, 11.66666889], [92.70049286, 11.66665077], [92.70015717, 11.66654968], [92.69986725, 11.6664114], [92.69958496, 11.66632175], [92.69936371, 11.66613102], [92.69908905, 11.66590977], [92.6986618, 11.66569138], [92.69804382, 11.66566086], [92.69758606, 11.6658392], [92.69719696, 11.66609001], [92.69674683, 11.66632175], [92.69628143, 11.66663933], [92.69580078, 11.66694927], [92.69541168, 11.6672411], [92.69511414, 11.66751003], [92.69487, 11.66774464], [92.69459534, 11.6679039], [92.69432831, 11.66807079], [92.69406891, 11.66825962], [92.69377136, 11.66833019], [92.69346619, 11.66834164], [92.69328308, 11.66832256], [92.69317627, 11.66831207], [92.69293976, 11.66819572], [92.69276428, 11.66797924], [92.69258881, 11.66774178], [92.69245148, 11.66746426], [92.69232941, 11.66714478], [92.69243622, 11.66667843], [92.69255066, 11.6661396], [92.69256592, 11.66555023], [92.69246674, 11.66493034], [92.69212341, 11.66448116], [92.69158173, 11.66417122], [92.69107819, 11.66391087], [92.69056702, 11.6637516], [92.69010925, 11.66359043], [92.68972778, 11.66334057], [92.68930817, 11.66306973], [92.68881226, 11.66281033], [92.68824768, 11.66260147], [92.68763733, 11.66254139], [92.68707275, 11.66261196], [92.68663788, 11.66276932], [92.68604279, 11.66251183], [92.68564606, 11.66222191], [92.68541718, 11.66178703], [92.68519592, 11.66141129], [92.68501282, 11.66102123], [92.68486786, 11.66061115], [92.68466187, 11.66022968], [92.68453217, 11.65985203], [92.68435669, 11.6595974], [92.68421936, 11.65936184], [92.68421173, 11.65911579], [92.68408966, 11.65884018], [92.68419647, 11.65831089], [92.68448639, 11.65806961], [92.68495178, 11.65767097], [92.68540192, 11.65765476], [92.68572235, 11.65734005], [92.68609619, 11.65703011], [92.68649292, 11.65666962], [92.68671417, 11.65631485], [92.68667603, 11.65592289], [92.68668365, 11.65545845], [92.68654633, 11.65505886], [92.68622589, 11.6547308], [92.68588257, 11.65442085], [92.68559265, 11.6540699], [92.68534851, 11.65364075], [92.68521881, 11.65310097], [92.68493652, 11.65270042], [92.68466187, 11.65233517], [92.6844635, 11.65195656], [92.68431854, 11.65156269], [92.68411255, 11.65126038], [92.68386841, 11.6509819], [92.68350983, 11.65070343], [92.68295288, 11.65049171], [92.68237305, 11.6508007], [92.68186188, 11.65111065], [92.68138123, 11.651371], [92.68083954, 11.65155125], [92.6802597, 11.65169716], [92.67971039, 11.65190029], [92.67915344, 11.65199757], [92.6787262, 11.65221024], [92.67836761, 11.65244007], [92.67798615, 11.65254021], [92.67769623, 11.65271091], [92.67739868, 11.65277958], [92.67710114, 11.65283871], [92.67687225, 11.65297985], [92.67661285, 11.65305138], [92.67632294, 11.65305996], [92.67598724, 11.65308094], [92.67562866, 11.6531601], [92.67526245, 11.65329933], [92.67481232, 11.65334034], [92.67431641, 11.65339661], [92.67385101, 11.65357304], [92.67334747, 11.65362453], [92.67285156, 11.65361881], [92.67236328, 11.65360928], [92.67185974, 11.65361404], [92.67137909, 11.65365505], [92.6709671, 11.65382099], [92.67050934, 11.65388107], [92.66999817, 11.65388966], [92.66944885, 11.65388966], [92.66886902, 11.65388966], [92.66828918, 11.65388966], [92.66776276, 11.65386009], [92.66711426, 11.654109], [92.66641235, 11.654109], [92.66620636, 11.6539011], [92.66627502, 11.65328121], [92.66655731, 11.6527977], [92.66667175, 11.65234375], [92.66661835, 11.65180206], [92.66641235, 11.65127563], [92.6662674, 11.65071011], [92.66612244, 11.65013599], [92.66602325, 11.6495409], [92.66598511, 11.64892292], [92.66586304, 11.64836979], [92.66580963, 11.64783192], [92.6657486, 11.64731026], [92.66564941, 11.64678955], [92.66546631, 11.64627075], [92.6653595, 11.64570332], [92.66555786, 11.64513588], [92.66565704, 11.64440155], [92.66623688, 11.6439867], [92.66661835, 11.64371967], [92.66693115, 11.64354897], [92.66722107, 11.64324188], [92.66748047, 11.64292717], [92.66768646, 11.6425724], [92.66780853, 11.64218235], [92.6680069, 11.64182377], [92.66816711, 11.64141083], [92.66835022, 11.64101028], [92.66854095, 11.64058018], [92.66854095, 11.64015961], [92.66838074, 11.63978195], [92.66833496, 11.6394186], [92.66805267, 11.63902092], [92.66805267, 11.63619041], [92.66812897, 11.6356411], [92.66832733, 11.63494968], [92.66868591, 11.63321972], [92.66889191, 11.6328783], [92.66947937, 11.63239098], [92.6697998, 11.63204193], [92.67016602, 11.63177967], [92.6704483, 11.63153076], [92.6707077, 11.6314106], [92.67098236, 11.63141727], [92.67127228, 11.63153839], [92.67160034, 11.63160229], [92.67195892, 11.63142872], [92.67234802, 11.63132191], [92.67266083, 11.63112831], [92.67294312, 11.63092136], [92.67311859, 11.63064671], [92.67334747, 11.63039017], [92.67359161, 11.63012314], [92.67378998, 11.62980175], [92.67386627, 11.6294117], [92.67381287, 11.62903118], [92.67359161, 11.62871742], [92.67333221, 11.62842274], [92.6730423, 11.62820244], [92.6727829, 11.62751102], [92.67282104, 11.62691784], [92.67312622, 11.62628937], [92.67326355, 11.62570572], [92.67365265, 11.6252203], [92.67407227, 11.6248064], [92.67449951, 11.62457085], [92.67481232, 11.62472057], [92.67516327, 11.62475109], [92.6754837, 11.62492943], [92.6758194, 11.62520027], [92.67613983, 11.62559891], [92.6764679, 11.62609959], [92.67684937, 11.62664032], [92.67681122, 11.6272192], [92.67697144, 11.62775898], [92.67693329, 11.62849331], [92.67743683, 11.62862301], [92.67787933, 11.62858009], [92.6783905, 11.62865734], [92.67897034, 11.62884426], [92.67958069, 11.62893963], [92.68003845, 11.62926102], [92.68031311, 11.6297493], [92.68062592, 11.63018036], [92.68074799, 11.63074112], [92.68081665, 11.6312809], [92.68079376, 11.63183022], [92.68061829, 11.63235188], [92.68049622, 11.63288116], [92.68031311, 11.63334084], [92.68017578, 11.63381958], [92.67999268, 11.63427067], [92.6798172, 11.63471127], [92.68000031, 11.63512135], [92.68026733, 11.63550186], [92.68054962, 11.63588047], [92.68086243, 11.63631058], [92.68121338, 11.63678932], [92.68147278, 11.6374979], [92.68193817, 11.6374712], [92.6823349, 11.63742065], [92.68242645, 11.63708115], [92.68255615, 11.63675308], [92.68263245, 11.63611698], [92.68321991, 11.63566113], [92.68360901, 11.63544941], [92.68392944, 11.6350708], [92.68424988, 11.63473129], [92.68450165, 11.63440132], [92.68467712, 11.63404083], [92.68476105, 11.63367558], [92.68489838, 11.63344097], [92.68486023, 11.63328171], [92.68481445, 11.63293076], [92.68469238, 11.63221741], [92.68453217, 11.63162041], [92.68447876, 11.63116169], [92.68448639, 11.63104057], [92.6848526, 11.63085175], [92.68530273, 11.63121033], [92.6853714, 11.63183022], [92.6853714, 11.63238239], [92.68572235, 11.63280106], [92.68600464, 11.63321114], [92.68614197, 11.63369179], [92.68636322, 11.63438034], [92.68636322, 11.63480186], [92.68600464, 11.63521004], [92.68599701, 11.63569069], [92.6860733, 11.63632202], [92.68614197, 11.63673019], [92.68641663, 11.63694191], [92.68642426, 11.63742065], [92.68636322, 11.63845062], [92.68636322, 11.63969994], [92.68641663, 11.64011002], [92.68654633, 11.64024925], [92.68683624, 11.64024925], [92.68726349, 11.64038563], [92.68768311, 11.64059258], [92.68795776, 11.64045429], [92.68850708, 11.64003944], [92.68907928, 11.63949013], [92.68976593, 11.638731], [92.69005585, 11.63755989], [92.69019318, 11.63700962], [92.69033051, 11.63625145], [92.6905365, 11.63466072], [92.6905365, 11.63184071], [92.69048309, 11.63148975], [92.69026184, 11.63121033], [92.69005585, 11.63073063], [92.68984222, 11.63024139], [92.6897049, 11.62989712], [92.68963623, 11.62962055], [92.68994904, 11.62918377], [92.69023132, 11.62909985], [92.69050598, 11.62888145], [92.69085693, 11.62860012], [92.69129181, 11.62832928], [92.69173431, 11.62804413], [92.69211578, 11.62769127], [92.69235992, 11.62720108], [92.69254303, 11.6266489], [92.69277954, 11.62613392], [92.69303894, 11.62561893], [92.69326782, 11.6250906], [92.69356537, 11.62465763], [92.69386292, 11.62421131], [92.69411469, 11.62378025], [92.69432068, 11.62320995], [92.69457245, 11.6227293], [92.69484711, 11.62345409], [92.69484711, 11.62414169], [92.69476318, 11.62475109], [92.69472504, 11.6250267], [92.69471741, 11.6253233], [92.69473267, 11.62565136], [92.69477081, 11.62603188], [92.69495392, 11.62641907], [92.69499969, 11.62688446], [92.69497681, 11.62737179], [92.69493103, 11.62787056], [92.6949234, 11.62837029], [92.69476318, 11.62883091], [92.69470215, 11.62930012], [92.69458771, 11.62971497], [92.69445801, 11.63010025], [92.69435883, 11.63048077], [92.69419861, 11.63080406], [92.69412994, 11.6311636], [92.69396973, 11.63146973], [92.6938324, 11.63184071], [92.69361115, 11.63218975], [92.69335938, 11.63260937], [92.69313049, 11.63311768], [92.69296265, 11.63369179], [92.69278717, 11.63424969], [92.69269562, 11.63478756], [92.69264221, 11.63530254], [92.69275665, 11.63574314], [92.69286346, 11.63617229], [92.69303894, 11.63659286], [92.69316864, 11.63704014], [92.69335175, 11.63747787], [92.69361877, 11.63788986], [92.69393158, 11.63832092], [92.69425964, 11.63871765], [92.69462585, 11.63903427], [92.69515991, 11.63907146], [92.69563293, 11.63915062], [92.6960907, 11.63920975], [92.6965332, 11.63912106], [92.69697571, 11.63916683], [92.6974411, 11.63931179], [92.69789886, 11.63951492], [92.69831848, 11.63972855], [92.69873047, 11.63984966], [92.69915009, 11.64019203], [92.69950867, 11.64038086], [92.69973755, 11.6406498], [92.69994354, 11.64086914], [92.70011902, 11.64109516], [92.70027161, 11.64134312], [92.70030975, 11.64162064], [92.70028687, 11.641922], [92.70022583, 11.64224625], [92.70002747, 11.64259243], [92.69989777, 11.64303207], [92.69975281, 11.64351082], [92.699646, 11.64407063], [92.69954681, 11.64459991], [92.69967651, 11.6450901], [92.6998291, 11.64552498], [92.70011139, 11.64591026], [92.70021057, 11.64627075], [92.70027924, 11.64657593], [92.70027924, 11.64683437], [92.70014191, 11.64713383], [92.69998169, 11.64729214], [92.69988251, 11.64750957], [92.69975281, 11.64774704], [92.699646, 11.64803219], [92.69944, 11.64830971], [92.69917297, 11.64861107], [92.69879913, 11.6488924], [92.69831848, 11.64911938], [92.69770813, 11.64916706], [92.69707489, 11.64921474], [92.6965332, 11.64944077], [92.69606781, 11.64976883], [92.69574738, 11.65023232], [92.69538879, 11.65072155], [92.69503784, 11.65127087], [92.69480896, 11.65189457], [92.69480896, 11.6524992], [92.69509888, 11.65294647], [92.69550323, 11.65315437], [92.69586945, 11.65329933], [92.69628906, 11.65334034], [92.69668579, 11.65340042], [92.69708252, 11.65356827], [92.6975174, 11.65362072], [92.69796753, 11.65372086], [92.69841003, 11.65394878], [92.69894409, 11.6541748], [92.69953156, 11.65439796], [92.7002182, 11.65449142], [92.70085907, 11.65467358], [92.70147705, 11.65466499], [92.70199585, 11.65443707], [92.7024231, 11.65412045], [92.70275879, 11.65374756], [92.70302582, 11.65334034], [92.70333099, 11.65295792], [92.70365143, 11.65257931], [92.70401001, 11.65225792], [92.70437622, 11.6519804], [92.70462799, 11.65162182], [92.70478058, 11.6512394], [92.70498657, 11.65090179], [92.70520782, 11.65055275], [92.70547485, 11.65015888], [92.7057724, 11.64969158], [92.70609283, 11.64914227], [92.70631409, 11.64848614], [92.70638275, 11.6477499], [92.70643616, 11.64707088], [92.70664215, 11.6465807], [92.70677948, 11.64614964], [92.70691681, 11.64580059], [92.7069931, 11.64544964], [92.70715332, 11.64517021], [92.70726776, 11.64486885], [92.70729065, 11.64461994], [92.70733643, 11.64425087], [92.70757294, 11.64409447], [92.70770264, 11.64380741], [92.70800018, 11.64336014], [92.7086792, 11.64326191], [92.70918274, 11.6433897], [92.70957947, 11.64354038], [92.71000671, 11.64356995], [92.71041107, 11.64361095], [92.71091461, 11.6437521], [92.71102142, 11.64375401], [92.71127319, 11.64376068], [92.71180725, 11.64375019], [92.71215057, 11.64431953], [92.71218109, 11.64470005], [92.71218109, 11.64503956], [92.71218109, 11.64544106], [92.71199036, 11.64586926], [92.71189117, 11.64638042], [92.71168518, 11.64685917], [92.7115097, 11.64736462], [92.71131897, 11.64784527], [92.71109772, 11.64830112], [92.71083069, 11.64876175], [92.71054077, 11.64929008], [92.71019745, 11.64988136], [92.70981598, 11.65048695], [92.70983887, 11.65122986], [92.71021271, 11.65180016], [92.71060944, 11.65226936], [92.71100616, 11.65246964], [92.711586, 11.65260029], [92.71212006, 11.65284061], [92.71273804, 11.65305996], [92.71331787, 11.65305996], [92.71385956, 11.65310287], [92.7143631, 11.65328121], [92.71483612, 11.6533289], [92.71527863, 11.65315056], [92.71569061, 11.65308094], [92.71607971, 11.65295124], [92.71653748, 11.65285015], [92.71704865, 11.652812], [92.71761322, 11.65285969], [92.71819305, 11.65295124], [92.71877289, 11.65295124], [92.71929169, 11.65307236], [92.71974945, 11.65304184], [92.7201767, 11.65312195], [92.72053528, 11.65331459], [92.72089386, 11.65349293], [92.72119141, 11.65370274], [92.72144318, 11.65396309], [92.72158813, 11.65434074], [92.72180939, 11.65471172], [92.72205353, 11.65507317], [92.72242737, 11.65531445], [92.72278595, 11.65553093], [92.72319031, 11.65567875], [92.72360992, 11.65581322], [92.72408295, 11.6558733], [92.72454071, 11.65593433], [92.72493744, 11.65601158], [92.72528076, 11.65610027], [92.72563171, 11.65616035], [92.72598267, 11.65633965], [92.72638702, 11.65651989], [92.72679901, 11.65676594], [92.72712708, 11.65716934], [92.72767639, 11.65701675], [92.72789764, 11.65695667], [92.72831726, 11.65702629], [92.72881317, 11.65723133], [92.72901917, 11.65744114], [92.72926331, 11.65829754], [92.72946167, 11.6585598], [92.72968292, 11.65886974], [92.72984314, 11.65923023], [92.72996521, 11.65964222], [92.72997284, 11.66007137], [92.72979736, 11.66048145], [92.72979736, 11.66086197], [92.72966766, 11.66118145], [92.72949982, 11.66140175], [92.72928619, 11.66146088], [92.72873688, 11.66152], [92.72834015, 11.66164112], [92.72786713, 11.66167068], [92.72734833, 11.66167068], [92.72679138, 11.66167068], [92.72623444, 11.66171169], [92.72576141, 11.66192436], [92.72528076, 11.66208267], [92.724823, 11.66220188], [92.72436523, 11.6622591], [92.72395325, 11.66240025], [92.72351074, 11.66248894], [92.72303772, 11.66250038], [92.72253418, 11.66253662], [92.7220459, 11.66267967], [92.72149658, 11.66281033], [92.72103119, 11.66304016], [92.72052002, 11.66322136], [92.71998596, 11.66335011], [92.71952057, 11.66353512], [92.71910095, 11.66372013], [92.71882629, 11.66399956], [92.71849823, 11.66419125], [92.71813202, 11.66435146], [92.71769714, 11.66443062], [92.71725464, 11.66448784], [92.71694946, 11.66478157], [92.71613312, 11.66475201], [92.71614075, 11.6658802], [92.71627045, 11.66630173], [92.716362, 11.66666031], [92.71646118, 11.66704273], [92.71663666, 11.66742134], [92.71683502, 11.6678791], [92.71714783, 11.66827965], [92.717453, 11.66870022], [92.71768951, 11.6690979], [92.71776581, 11.66945171], [92.71779633, 11.66974068], [92.71782684, 11.66997147], [92.71788788, 11.67018986], [92.71792603, 11.67044067], [92.71782684, 11.67076015], [92.71752167, 11.67115021], [92.71729279, 11.67161179], [92.71723175, 11.67210007], [92.71721649, 11.67255974], [92.71720123, 11.67297745], [92.71707916, 11.67334366], [92.71691895, 11.67370224], [92.71672058, 11.67404366], [92.71658325, 11.6744318], [92.71637726, 11.67480755], [92.71613312, 11.67519093], [92.71586609, 11.67564011], [92.71557617, 11.67615891], [92.71537781, 11.67682934], [92.71535492, 11.67755413], [92.71557617, 11.67807102], [92.71614838, 11.67822647], [92.71671295, 11.67843437], [92.71684265, 11.67864132], [92.71684265, 11.67892075], [92.71679688, 11.67899418], [92.71650696, 11.67947102], [92.71636963, 11.67988968], [92.71629333, 11.68038177], [92.71642303, 11.68097019], [92.71666718, 11.68148994], [92.71697235, 11.68190861], [92.71761322, 11.68183041], [92.71790314, 11.68190002], [92.71817017, 11.68225098], [92.71843719, 11.68280125], [92.71858978, 11.68314457], [92.71872711, 11.68328094], [92.71922302, 11.6838398], [92.7199173, 11.68417931], [92.72013092, 11.68453026], [92.72035217, 11.68507957], [92.72117615, 11.68590546], [92.72138977, 11.68604088], [92.72145844, 11.6863203], [92.72193146, 11.68640232], [92.72225189, 11.68576336], [92.72229004, 11.68525124], [92.72185516, 11.6851778], [92.72186279, 11.6848402], [92.72212982, 11.68448925], [92.72263336, 11.68414116], [92.7226944, 11.68400574], [92.72309875, 11.68401146], [92.72350311, 11.684412], [92.72379303, 11.6843214], [92.72416687, 11.68413353], [92.72428894, 11.6829443], [92.72457123, 11.68231964], [92.72512817, 11.68163586], [92.72568512, 11.68080616], [92.72624207, 11.68025017], [92.72694397, 11.68004704], [92.72743225, 11.68012047], [92.72801971, 11.68027973], [92.72843933, 11.68033504], [92.72879791, 11.68029594], [92.72917938, 11.68027973], [92.72957611, 11.68025017], [92.72997284, 11.68008232], [92.7303009, 11.67976475], [92.73060608, 11.67938042], [92.73087311, 11.67893124], [92.73110962, 11.67846107], [92.73134613, 11.6780014], [92.73139191, 11.67754269], [92.73143005, 11.67712975], [92.73143005, 11.67657185], [92.73136139, 11.67595387], [92.73136139, 11.67450523], [92.73149872, 11.67361069], [92.7321167, 11.67345238], [92.73241425, 11.67315292], [92.73279572, 11.67300701], [92.73320007, 11.67292118], [92.73361206, 11.67294121], [92.73394012, 11.67309093], [92.73413086, 11.67336273], [92.73414612, 11.67370892], [92.73412323, 11.67403316], [92.73435211, 11.67432022], [92.73451233, 11.67449093], [92.73460388, 11.6748209], [92.73455048, 11.67530918], [92.73451996, 11.67607021], [92.73493195, 11.67650986], [92.73503876, 11.67677689], [92.73522186, 11.67697334], [92.73548889, 11.67720127], [92.73587799, 11.67739201], [92.73632813, 11.67754269], [92.73680878, 11.67756081], [92.73719025, 11.67772007], [92.73743439, 11.67766094], [92.73767853, 11.67760181], [92.73818207, 11.67766094], [92.73864746, 11.67789078], [92.73908997, 11.67779064], [92.73950195, 11.67771816], [92.73993683, 11.67744923], [92.74053955, 11.67743301], [92.74101257, 11.67727566], [92.74138641, 11.67698193], [92.74169922, 11.67679024], [92.74182892, 11.67643929], [92.74202728, 11.67623043], [92.74238586, 11.67609119], [92.74308777, 11.67602158], [92.74350739, 11.67595387], [92.74448395, 11.67560768], [92.74489594, 11.67554188], [92.74575043, 11.67604065], [92.7461319, 11.67616367], [92.74662781, 11.67638016], [92.7472229, 11.67661953], [92.74788666, 11.67663097], [92.74855042, 11.67640972], [92.74913025, 11.6759901], [92.74958801, 11.67546177], [92.74982452, 11.67493057], [92.74977875, 11.67444992], [92.74954987, 11.67400455], [92.74933624, 11.67361069], [92.74924469, 11.67333508], [92.74928284, 11.67323971], [92.74916077, 11.67286968], [92.74916077, 11.67255974], [92.74954224, 11.67180824], [92.74968719, 11.67167187], [92.74982452, 11.67125702], [92.74954224, 11.67119122], [92.74912262, 11.67119122], [92.74854279, 11.67165089], [92.74833679, 11.67206097], [92.74771118, 11.67178059], [92.74749756, 11.67157841], [92.74755859, 11.67088985], [92.74771118, 11.67039967], [92.74777985, 11.66978168], [92.7480545, 11.66895485], [92.74826813, 11.66840267], [92.74847412, 11.66812706], [92.7488327, 11.6677103], [92.74910736, 11.66750526], [92.74952698, 11.66730022], [92.75002289, 11.66688061], [92.75043488, 11.6668148], [92.75134277, 11.66661167], [92.7514801, 11.66661167], [92.75161743, 11.66722965], [92.7516861, 11.66744137], [92.7517395, 11.66765976], [92.75209045, 11.6678896], [92.75257111, 11.66779041], [92.75315857, 11.66741562], [92.753479, 11.66646099], [92.75431061, 11.66650677], [92.75482178, 11.66657066], [92.75530243, 11.66618824], [92.75578308, 11.6658802], [92.75624847, 11.66572094], [92.75652313, 11.66541958], [92.75665283, 11.66507053], [92.75668335, 11.66469955], [92.75668335, 11.66432953], [92.75634003, 11.66393185], [92.75605011, 11.66350079], [92.75587463, 11.66305161], [92.7559433, 11.66257095], [92.7562027, 11.66187954], [92.7562027, 11.66133118], [92.7558136, 11.660923], [92.75566101, 11.66040134], [92.75546265, 11.66000938], [92.75524139, 11.65968132], [92.75496674, 11.65937996], [92.75473022, 11.6590519], [92.75454712, 11.65867138], [92.7544632, 11.65829086], [92.75448608, 11.65790844], [92.7546463, 11.65758038], [92.75480652, 11.65732193], [92.75505829, 11.65715313], [92.75533295, 11.65698528], [92.75572205, 11.65694618], [92.75617981, 11.65694141], [92.75669098, 11.65690327], [92.75721741, 11.65671825], [92.75778198, 11.65659046], [92.75830841, 11.65616035], [92.75823212, 11.65531445], [92.75809479, 11.65483093], [92.75760651, 11.65427876], [92.7571106, 11.65393066], [92.75697327, 11.65345001], [92.75683594, 11.65248108], [92.75704193, 11.65179539], [92.75788116, 11.65111065], [92.75788116, 11.65097046], [92.7578125, 11.65055084], [92.75746155, 11.65041637], [92.75718689, 11.65034962], [92.75697327, 11.64993095], [92.75701904, 11.64920807], [92.75688171, 11.64878178], [92.75666809, 11.64836121], [92.75641632, 11.64786053], [92.75621796, 11.64726353], [92.75604248, 11.64693832], [92.75527191, 11.64680195], [92.75498962, 11.64665985], [92.75450897, 11.64666271], [92.75429535, 11.64645481], [92.75408936, 11.64631557], [92.75388336, 11.64590073], [92.75345612, 11.64528084], [92.75324249, 11.64480114], [92.7530365, 11.64438057], [92.75227356, 11.64417839], [92.75151062, 11.64404202], [92.75073242, 11.64410782], [92.74968719, 11.64445019], [92.74919891, 11.64466095], [92.74871063, 11.64459133], [92.74807739, 11.64459133], [92.74804688, 11.64448833], [92.74794006, 11.64417839], [92.74758911, 11.64356136], [92.74738312, 11.64328003], [92.74723816, 11.64245129], [92.74719238, 11.6412859], [92.74688721, 11.64103127], [92.74653625, 11.64081192], [92.74637604, 11.64041138], [92.74617004, 11.63999367], [92.74662018, 11.63982964], [92.74748993, 11.64027596], [92.74794769, 11.64023781], [92.74828339, 11.64001179], [92.74855804, 11.63978195], [92.74877167, 11.63948059], [92.74892426, 11.63909817], [92.74897003, 11.6386404], [92.7489624, 11.63793087], [92.7489624, 11.63758945], [92.7490387, 11.63731098], [92.74952698, 11.63724136], [92.75024414, 11.63722706], [92.75061798, 11.63698959], [92.75096893, 11.6367712], [92.75118256, 11.63643169], [92.75139618, 11.63607788], [92.75161743, 11.63567924], [92.75177002, 11.63518047], [92.75196075, 11.63463783], [92.75219727, 11.63408184], [92.75235748, 11.63348007], [92.75247955, 11.63288975], [92.75247955, 11.63233089], [92.75237274, 11.63182545], [92.75224304, 11.63134003], [92.75198364, 11.63093376], [92.75172424, 11.6305418], [92.75152588, 11.63015461], [92.75119781, 11.62984943], [92.75093079, 11.62944126], [92.75051117, 11.62896061], [92.7504425, 11.62860966], [92.7506485, 11.62819672], [92.75128174, 11.62827015], [92.75177002, 11.62827015], [92.75209808, 11.62813091], [92.75246429, 11.62764072], [92.75248718, 11.62695026], [92.75249481, 11.62405586], [92.75242615, 11.62350178], [92.7518692, 11.62259293], [92.75193787, 11.62239933], [92.75228882, 11.6214304], [92.75222015, 11.62108612], [92.75209045, 11.62088108], [92.75193024, 11.62047958], [92.75193024, 11.61971188], [92.75209045, 11.61943054], [92.7527771, 11.61929226], [92.75312805, 11.61929226], [92.75403595, 11.61903667], [92.75428772, 11.61884975], [92.75448608, 11.61859035], [92.75467682, 11.61828136], [92.75468445, 11.61788177], [92.75454712, 11.61742973], [92.75424194, 11.61693096], [92.75382233, 11.61686325], [92.75326538, 11.61686325], [92.7530365, 11.61676502], [92.7527771, 11.61665535], [92.7527771, 11.61265087], [92.75291443, 11.61023712], [92.75285339, 11.609622], [92.75221252, 11.60851002], [92.75137329, 11.60782242], [92.75061035, 11.60706329], [92.7502594, 11.60727024], [92.75004578, 11.60734081], [92.74970245, 11.60706043], [92.74872589, 11.6060276], [92.7486496, 11.60540962], [92.74868011, 11.60458088], [92.7485199, 11.60429287], [92.74845123, 11.60388088], [92.74830627, 11.60319042], [92.74858093, 11.60286045], [92.74897003, 11.60278034], [92.74916077, 11.60234547], [92.74915314, 11.60171127], [92.74890137, 11.60098171], [92.74841309, 11.60037136], [92.74788666, 11.60003757], [92.74738312, 11.59986973], [92.74692535, 11.59970284], [92.74652863, 11.5994978], [92.74619293, 11.5995121], [92.74591827, 11.59963322], [92.74570465, 11.5995636], [92.74521637, 11.59922028], [92.74459076, 11.59852982], [92.74417114, 11.59797955], [92.74368286, 11.59708023], [92.74326324, 11.59673119], [92.74284363, 11.59618187], [92.74249268, 11.59562969], [92.74236298, 11.59521961], [92.7423172, 11.59468174], [92.74202728, 11.59426975], [92.74169922, 11.59382057], [92.74092865, 11.5931921], [92.74072266, 11.59257221], [92.74079132, 11.59112167], [92.74107361, 11.59043217], [92.74121094, 11.59001923], [92.74176788, 11.58967113], [92.74225616, 11.58987999], [92.74260712, 11.58995056], [92.74357605, 11.58982086], [92.74391937, 11.58967113], [92.74417114, 11.58944702], [92.74436188, 11.58924198], [92.74452972, 11.58903027], [92.74463654, 11.58875179], [92.74466705, 11.58841038], [92.74465179, 11.58801079], [92.74448395, 11.5876379], [92.74440002, 11.58724117], [92.74420929, 11.5868597], [92.74417114, 11.5864048], [92.74415588, 11.58588886], [92.74416351, 11.58535385], [92.744133, 11.58482456], [92.74396515, 11.5843401], [92.74385834, 11.58384037], [92.74362946, 11.58335018], [92.74343109, 11.58280087], [92.74291992, 11.58220196], [92.74265289, 11.58172989], [92.74259186, 11.58112621], [92.74259186, 11.58056068], [92.74250031, 11.58010006], [92.74224854, 11.57971096], [92.74209595, 11.57933044], [92.74188232, 11.5789814], [92.74149323, 11.57868958], [92.7408371, 11.57857132], [92.74028015, 11.57862091], [92.74025726, 11.57895184], [92.73996735, 11.57909107], [92.73941803, 11.57915688], [92.73892975, 11.57936382], [92.73886108, 11.57984734], [92.73831177, 11.57973957], [92.73815918, 11.5797081], [92.73802185, 11.57860088], [92.73788452, 11.57791519], [92.73783112, 11.57644939], [92.73781586, 11.57586956], [92.73802948, 11.57522964], [92.73864746, 11.57477379], [92.73911285, 11.57438374], [92.73928833, 11.57310104], [92.73928833, 11.57186127], [92.739151, 11.5708313], [92.73902893, 11.5703907], [92.73888397, 11.57004738], [92.73867798, 11.56970119], [92.73860931, 11.56956387], [92.73825836, 11.56866646], [92.73789978, 11.56827164], [92.73761749, 11.56786823], [92.73737335, 11.56750107], [92.73716736, 11.56717777], [92.73693085, 11.56692028], [92.7366333, 11.56669044], [92.73625946, 11.56654167], [92.73589325, 11.56637096], [92.73557281, 11.56613159], [92.73523712, 11.565938], [92.73490906, 11.56579018], [92.73464966, 11.56552982], [92.73426819, 11.56526089], [92.73401642, 11.56483936], [92.7337265, 11.56443977], [92.7335434, 11.56378174], [92.73337555, 11.56321716], [92.73313904, 11.56288242], [92.7328186, 11.5621109], [92.73267365, 11.56171513], [92.73226929, 11.56140518], [92.73192596, 11.56111145], [92.73166656, 11.56083488], [92.73137665, 11.5607214], [92.73113251, 11.56060028], [92.7307663, 11.56016922], [92.73053741, 11.55982971], [92.7303772, 11.55947018], [92.73036957, 11.559021], [92.73017883, 11.55842113], [92.73014069, 11.55784035], [92.73023224, 11.55729103], [92.7304306, 11.55680084], [92.73046875, 11.55628109], [92.7307663, 11.55587101], [92.73112488, 11.55555153], [92.73149872, 11.55521679], [92.73200226, 11.55494118], [92.73252106, 11.55471325], [92.73300934, 11.55445099], [92.73349762, 11.55417061], [92.73400116, 11.55388355], [92.73445892, 11.55355072], [92.73472595, 11.55311108], [92.73483276, 11.55264091], [92.73474121, 11.55219173], [92.73462677, 11.55174065], [92.73446655, 11.55136681], [92.73430634, 11.55101013], [92.73419952, 11.55064011], [92.73412323, 11.5502758], [92.73394775, 11.55000401], [92.7338562, 11.54968452], [92.73361206, 11.54979038], [92.73319244, 11.54993153], [92.73304749, 11.54979038], [92.73277283, 11.54971981], [92.73270416, 11.54951382], [92.73277283, 11.54916763], [92.73297882, 11.54896069], [92.73363495, 11.54879189], [92.73361206, 11.54848194], [92.7335968, 11.54810143], [92.73351288, 11.54768181], [92.73308563, 11.54729462], [92.7323761, 11.54716492], [92.73184967, 11.54717445], [92.73138428, 11.54725361], [92.73103333, 11.54704571], [92.730896, 11.546422], [92.730896, 11.54559708], [92.73132324, 11.54524994], [92.73152161, 11.5450449], [92.73180389, 11.54435444], [92.73194122, 11.54345894], [92.73195648, 11.54321861], [92.73197174, 11.54295063], [92.73189545, 11.54245377], [92.73168945, 11.54204559], [92.73152161, 11.54166126], [92.73134613, 11.54127979], [92.73110199, 11.54095173], [92.73082733, 11.54064178], [92.73053741, 11.54034996], [92.73017883, 11.5404892], [92.72975922, 11.54042053], [92.7293396, 11.54014015], [92.72891998, 11.54000378], [92.72864532, 11.53952026], [92.72836304, 11.53869343], [92.72815704, 11.53834724], [92.72786713, 11.53780174], [92.72766113, 11.53745079], [92.72731781, 11.53676033], [92.72682953, 11.53642082], [92.72653198, 11.53617668], [92.72647095, 11.53559971], [92.72631836, 11.53513145], [92.72622681, 11.53470039], [92.72606659, 11.53428078], [92.72579956, 11.53384972], [92.72551727, 11.53341007], [92.72489929, 11.53309345], [92.72462463, 11.53264904], [92.72460175, 11.53224087], [92.72476959, 11.53189182], [92.72467804, 11.53145695], [92.72445679, 11.53100967], [92.72420502, 11.53050613], [92.72384644, 11.53001022], [92.72371674, 11.52933979], [92.72366333, 11.52879047], [92.72366333, 11.52825928], [92.72363281, 11.52773952], [92.72366333, 11.52723122], [92.72386169, 11.52674961], [92.72405243, 11.52627182], [92.7243576, 11.52586174], [92.72478485, 11.52554512], [92.72519684, 11.52518463], [92.72548676, 11.52473068], [92.72556305, 11.52418041], [92.72557831, 11.52367115], [92.72554779, 11.52320576], [92.72569275, 11.52272797], [92.72601318, 11.5222187], [92.72625732, 11.52168179], [92.72653198, 11.52118015], [92.72676849, 11.52071953], [92.72673798, 11.52029991], [92.72693634, 11.51993084], [92.72695923, 11.51961708], [92.72705841, 11.51935005], [92.72724915, 11.51902199], [92.72749329, 11.51865864], [92.72775269, 11.51820087], [92.72793579, 11.51759148], [92.72799683, 11.51692963], [92.72793579, 11.51622963], [92.72741699, 11.51568985], [92.72692871, 11.51533699], [92.72615814, 11.51495075], [92.72548676, 11.51466179], [92.72490692, 11.51433086], [92.72451019, 11.5139389], [92.72393036, 11.51352024], [92.72372437, 11.51338577], [92.72372437, 11.51283169], [92.72393036, 11.51228237], [92.72384644, 11.5119772], [92.72361755, 11.51150131], [92.72335815, 11.5109396], [92.72311401, 11.51030922], [92.72278595, 11.50973034], [92.72245026, 11.50920773], [92.72203827, 11.50884056], [92.72171783, 11.50848103], [92.72149658, 11.50809097], [92.72129822, 11.50778103], [92.72107697, 11.50745964], [92.72091675, 11.50709724], [92.7205658, 11.50683975], [92.72020721, 11.50658035], [92.71983337, 11.5062561], [92.71952057, 11.50582123], [92.71948242, 11.5053196], [92.71943665, 11.50477028], [92.71938324, 11.50415134], [92.71927643, 11.50353336], [92.71891785, 11.50321198], [92.71844482, 11.50302505], [92.71821594, 11.50280094], [92.71768951, 11.50231075], [92.71775818, 11.50185966], [92.71773529, 11.50136089], [92.71810913, 11.50084114], [92.71810913, 11.50041008], [92.71811676, 11.49993038], [92.71808624, 11.4995718], [92.71781921, 11.4992094], [92.71750641, 11.49880123], [92.71675873, 11.49831963], [92.71645355, 11.49783516], [92.71649933, 11.49713516], [92.7168808, 11.49681187], [92.71699524, 11.49641705], [92.71701813, 11.49594975], [92.71695709, 11.49532127], [92.71677399, 11.49464226], [92.71672821, 11.49399471], [92.71672058, 11.49343586], [92.71594238, 11.49317169], [92.71504211, 11.49302101], [92.7145462, 11.49247169], [92.71434784, 11.49177933], [92.71427917, 11.49109077], [92.7144928, 11.49037075], [92.71437836, 11.48987198], [92.71407318, 11.48943615], [92.71372986, 11.48903084], [92.71331024, 11.48874092], [92.71292114, 11.48854065], [92.71266174, 11.48828983], [92.7125473, 11.48805141], [92.71231079, 11.48784065], [92.71221161, 11.48758125], [92.71214294, 11.4873209], [92.71215057, 11.48700047], [92.7121048, 11.48664856], [92.7121582, 11.4862318], [92.71229553, 11.48577213], [92.71246338, 11.48529339], [92.71250153, 11.48474121], [92.71255493, 11.48417568], [92.71269989, 11.48361111], [92.71263123, 11.48307991], [92.71247101, 11.48258972], [92.71230316, 11.48209095], [92.71224213, 11.48157978], [92.71216583, 11.48106956], [92.71218872, 11.48065472], [92.71226501, 11.48043156], [92.71193695, 11.48015118], [92.71190643, 11.47932243], [92.71190643, 11.47787189], [92.71170044, 11.47766018], [92.71156311, 11.47745514], [92.71128082, 11.47731781], [92.71092987, 11.47752094], [92.71071625, 11.47787189], [92.71044159, 11.47821426], [92.71030426, 11.47890472], [92.71009064, 11.47966099], [92.70987701, 11.48012161], [92.70963287, 11.48036098], [92.7093811, 11.48060036], [92.70900726, 11.48084164], [92.70845032, 11.48108101], [92.70793152, 11.48163891], [92.7077713, 11.48225689], [92.70761108, 11.48269939], [92.70755768, 11.48304844], [92.7075882, 11.48333073], [92.7075882, 11.48361111], [92.7074585, 11.48392963], [92.70722961, 11.48437023], [92.70697784, 11.48490143], [92.70678711, 11.48554134], [92.70705414, 11.48609734], [92.7073288, 11.48661041], [92.70765686, 11.48703861], [92.70800018, 11.48742199], [92.7086792, 11.48757744], [92.70893097, 11.48780918], [92.70913696, 11.48832607], [92.70922089, 11.48874092], [92.70922852, 11.4891901], [92.70935822, 11.48960972], [92.70921326, 11.4900198], [92.70909882, 11.49044228], [92.70889282, 11.49081135], [92.70862579, 11.49115467], [92.70832825, 11.49146938], [92.70796967, 11.49174118], [92.70748901, 11.49190712], [92.70685577, 11.49194145], [92.70613861, 11.49199772], [92.70552063, 11.49230576], [92.70516205, 11.49280262], [92.70500183, 11.49328995], [92.70490265, 11.4936924], [92.70475006, 11.49398994], [92.70469666, 11.49429798], [92.70458221, 11.49458027], [92.70446014, 11.49488068], [92.70436096, 11.49520016], [92.70420074, 11.49547195], [92.70407867, 11.49579144], [92.70392609, 11.49609089], [92.7039032, 11.49644947], [92.70388794, 11.49681187], [92.70384979, 11.49716282], [92.70365906, 11.49750519], [92.70355225, 11.49793053], [92.70337677, 11.49835014], [92.70329285, 11.49875069], [92.70333862, 11.49917126], [92.70309448, 11.49938679], [92.70262909, 11.49958134], [92.70225525, 11.49992657], [92.7019577, 11.50026035], [92.70170593, 11.50054932], [92.70155334, 11.50084591], [92.70139313, 11.50112247], [92.70118713, 11.50142002], [92.70094299, 11.50175095], [92.70063782, 11.50218964], [92.70014954, 11.50265121], [92.69985199, 11.50334072], [92.70001984, 11.5039587], [92.70027924, 11.50443077], [92.70046997, 11.50487137], [92.70043945, 11.50524044], [92.70024109, 11.50558186], [92.69992828, 11.50590134], [92.69950867, 11.50620174], [92.69909668, 11.50652122], [92.69863129, 11.50673008], [92.69827271, 11.50704956], [92.69790649, 11.50716114], [92.69757843, 11.507061], [92.69723511, 11.50691128], [92.69690704, 11.50660515], [92.69656372, 11.50615215], [92.69613647, 11.5056963], [92.69557953, 11.50571156], [92.69509125, 11.50558186], [92.69448853, 11.50551319], [92.69386292, 11.50542927], [92.69341278, 11.50579071], [92.69307709, 11.5062809], [92.69284058, 11.50673485], [92.69267273, 11.50706959], [92.69255066, 11.50732517], [92.69233704, 11.50752068], [92.6919632, 11.50766945], [92.69149017, 11.507761], [92.69100952, 11.50778103], [92.69056702, 11.50778103], [92.69017792, 11.50778103], [92.68979645, 11.50778103], [92.68939972, 11.50777721], [92.6889267, 11.50778103], [92.68843079, 11.50786114], [92.68795013, 11.50809097], [92.68753815, 11.50844002], [92.68718719, 11.5088501], [92.68686676, 11.50927162], [92.68660736, 11.5097208], [92.68636322, 11.5101614], [92.68608093, 11.51053047], [92.68579865, 11.51081944], [92.68551636, 11.51103973], [92.68519592, 11.51119995], [92.68482971, 11.51141167], [92.68441772, 11.51162243], [92.68421173, 11.51163292], [92.68392944, 11.51165104], [92.68350983, 11.5115099], [92.68312073, 11.5112114], [92.68267059, 11.51100159], [92.68219757, 11.51079178], [92.68170166, 11.51059437], [92.68118286, 11.51055527], [92.68070984, 11.51056862], [92.68032837, 11.51066017], [92.68002319, 11.5108099], [92.67970276, 11.51089001], [92.67947388, 11.51104927], [92.67919922, 11.51114273], [92.67893219, 11.51132107], [92.67864227, 11.5113802], [92.67836761, 11.51135921], [92.67813873, 11.5112114], [92.67789459, 11.51110554], [92.67765045, 11.51097202], [92.67741394, 11.51081657], [92.67719269, 11.51060009], [92.67694092, 11.51039791], [92.67668152, 11.51021099], [92.67642975, 11.51000118], [92.67616272, 11.50977135], [92.67590332, 11.50945187], [92.67559814, 11.50912094], [92.6753006, 11.50873184], [92.67507172, 11.50828743], [92.67489624, 11.50781059], [92.67472839, 11.50736427], [92.67457581, 11.5069418], [92.67446136, 11.50651169], [92.67436981, 11.50606728], [92.67414856, 11.50568199], [92.67385101, 11.50533962], [92.67352295, 11.50505066], [92.673172, 11.50484085], [92.6728363, 11.5046587], [92.67251587, 11.50444031], [92.67222595, 11.50421429], [92.67192078, 11.50397968], [92.67156219, 11.50378799], [92.67115784, 11.5036602], [92.67067719, 11.50376129], [92.67017365, 11.5039196], [92.66970825, 11.50410271], [92.66931152, 11.50402737], [92.66890717, 11.50391102], [92.66850281, 11.50388813], [92.66808319, 11.50389099], [92.66764069, 11.50389099], [92.6672287, 11.503932], [92.66694641, 11.50414085], [92.66660309, 11.50424862], [92.66625214, 11.50446033], [92.66587067, 11.50475025], [92.66545868, 11.50510979], [92.66508484, 11.50552654], [92.66467285, 11.50590324], [92.66432953, 11.50631142], [92.6639328, 11.50663853], [92.66362, 11.50700378], [92.66333771, 11.50738239], [92.66305542, 11.50778103], [92.66278076, 11.50820732], [92.66249084, 11.50866127], [92.66217041, 11.50912762], [92.66179657, 11.50957012], [92.66139984, 11.50998974], [92.66120148, 11.51043034], [92.66088104, 11.51100159], [92.66056824, 11.51148701], [92.66015625, 11.51169014], [92.65987396, 11.51203918], [92.65960693, 11.51267242], [92.65931702, 11.51314163], [92.65896606, 11.51350021], [92.65851593, 11.51376247], [92.65802765, 11.51396179], [92.65743256, 11.51412201], [92.65670776, 11.51410294], [92.65596008, 11.51416969], [92.65528107, 11.51442719], [92.65466309, 11.51477432], [92.65403748, 11.51513386], [92.65351868, 11.51546192], [92.65332031, 11.51580143], [92.65313721, 11.51606083], [92.6530304, 11.51637077], [92.65287781, 11.5167017], [92.65273285, 11.51705456], [92.65252686, 11.51735973], [92.65235138, 11.51763821], [92.6521759, 11.51781178], [92.65193939, 11.51786041], [92.65159607, 11.51780033], [92.65117645, 11.51785278], [92.65075684, 11.5181694], [92.6505127, 11.51866627], [92.65036774, 11.51914024], [92.650177, 11.51955128], [92.64994812, 11.51993084], [92.64964294, 11.52023029], [92.64925385, 11.52045822], [92.64878082, 11.52065372], [92.64824677, 11.52085018], [92.64771271, 11.52116203], [92.64723969, 11.5215807], [92.64688873, 11.52202129], [92.646698, 11.5223999], [92.64661407, 11.52270508], [92.64646149, 11.52292442], [92.64633179, 11.52324104], [92.64615631, 11.5236187], [92.64611053, 11.5241127], [92.64611816, 11.52488422], [92.64631653, 11.52549934], [92.64646149, 11.52612591], [92.64668274, 11.52701855], [92.64667511, 11.52729988], [92.64665222, 11.52770138], [92.64666748, 11.52803993], [92.64662933, 11.52838039], [92.646492, 11.52866268], [92.64639282, 11.52893829], [92.6463089, 11.529212], [92.64614868, 11.5294466], [92.64607239, 11.52976131], [92.64594269, 11.53008938], [92.64583588, 11.53053188], [92.64578247, 11.53105068], [92.64560699, 11.53157139], [92.64553833, 11.53211975], [92.64544678, 11.53259182], [92.64530182, 11.53297043], [92.64521027, 11.53328896], [92.64502716, 11.53358269], [92.64478302, 11.53390026], [92.64472961, 11.53435802], [92.64478302, 11.53485012], [92.64498138, 11.53526974], [92.64512634, 11.53567123], [92.64525604, 11.53610611], [92.64520264, 11.53657055], [92.64502716, 11.53698826], [92.64486694, 11.53738022], [92.64471436, 11.53778076], [92.64447021, 11.53813934], [92.64426422, 11.53854656], [92.6441803, 11.53905964], [92.64405823, 11.53989029], [92.6439209, 11.54072189], [92.64413452, 11.54133701], [92.64454651, 11.54168129], [92.64503479, 11.54221439], [92.64559937, 11.5425024], [92.6461792, 11.54275894], [92.64672852, 11.54297638], [92.6470871, 11.54327202], [92.64730835, 11.54369831], [92.64746857, 11.54414463], [92.6476593, 11.54446793], [92.64794922, 11.54475594], [92.64850616, 11.54504967], [92.649086, 11.54572201], [92.64935303, 11.54626179], [92.64966583, 11.54677868], [92.64988708, 11.54728127], [92.6500473, 11.54770947], [92.65016937, 11.54810143], [92.65029144, 11.54850483], [92.6504364, 11.54891968], [92.65059662, 11.54931164], [92.65080261, 11.5496397], [92.65105438, 11.54997921], [92.65104675, 11.5503006], [92.65099335, 11.55113029], [92.65062714, 11.55182076], [92.65007782, 11.55237007], [92.64930725, 11.55298996], [92.64819336, 11.55360985], [92.64714813, 11.55443954], [92.6462326, 11.55513], [92.64560699, 11.55566978], [92.64525604, 11.55602646], [92.64434814, 11.55644131], [92.64385986, 11.55671597], [92.64326477, 11.55717468], [92.64308929, 11.55751228], [92.64299011, 11.55792046], [92.64282227, 11.55830669], [92.64273834, 11.55873585], [92.64254761, 11.55912971], [92.64238739, 11.55955601], [92.64222717, 11.55999184], [92.64216614, 11.56049061], [92.64247894, 11.56103802], [92.6427002, 11.56151199], [92.64277649, 11.56203079], [92.64277649, 11.56269932], [92.64274597, 11.56348991], [92.64296722, 11.56387138], [92.64330292, 11.56414032], [92.64369202, 11.56441116], [92.64411926, 11.56470013], [92.6444397, 11.56516838], [92.64472198, 11.56564236], [92.64495087, 11.56608391], [92.64504242, 11.56654167], [92.64523315, 11.56694126], [92.64531708, 11.5674057], [92.64547729, 11.56787968], [92.64549255, 11.56838989], [92.64537811, 11.56887054], [92.64547729, 11.56952095], [92.64572906, 11.56980324], [92.64630127, 11.57021141], [92.64666748, 11.57061005], [92.6469574, 11.57101059], [92.64719391, 11.57141018], [92.64736176, 11.57180023], [92.64739227, 11.57213306], [92.6472702, 11.5723629], [92.64707947, 11.57250023], [92.64682007, 11.57260036], [92.64642334, 11.57269764], [92.64587402, 11.57277298], [92.64515686, 11.57277298], [92.64434814, 11.57274055], [92.64383698, 11.57287979], [92.64356995, 11.57316971], [92.64325714, 11.57339954], [92.64294434, 11.57360935], [92.64259338, 11.57378292], [92.64218903, 11.57387161], [92.64174652, 11.57388973], [92.64129639, 11.57393074], [92.64083099, 11.57411957], [92.64025116, 11.57426071], [92.63956451, 11.57455063], [92.63900757, 11.57499123], [92.63864899, 11.57546043], [92.6383667, 11.57584953], [92.63812256, 11.5761919], [92.63791656, 11.57651138], [92.63764954, 11.57678032], [92.63729858, 11.57703018], [92.63696289, 11.57736111], [92.63660431, 11.57770729], [92.63616943, 11.5779829], [92.63567352, 11.57821274], [92.63516998, 11.57846165], [92.63470459, 11.5787878], [92.63424683, 11.57905197], [92.63379669, 11.57916069], [92.63343811, 11.57917118], [92.63315582, 11.5791502], [92.6329422, 11.57904053], [92.63276672, 11.57882023], [92.63259125, 11.57855129], [92.63245392, 11.57820415], [92.63227081, 11.57785988], [92.63223267, 11.57744122], [92.63221741, 11.57696438], [92.63222504, 11.57641506], [92.63221741, 11.57580662], [92.63218689, 11.57518196], [92.6320343, 11.5746603], [92.63191223, 11.57416058], [92.63172913, 11.57375526], [92.63169098, 11.57336998], [92.63176727, 11.57295132], [92.63186646, 11.57252884], [92.63166046, 11.57214165], [92.63137817, 11.57173061], [92.6309967, 11.57141018], [92.63057709, 11.57122135], [92.63014984, 11.57135963], [92.62973022, 11.5715313], [92.62934875, 11.5716486], [92.62901306, 11.5716486], [92.62876129, 11.5715313], [92.62853241, 11.57139015], [92.62832642, 11.57124138], [92.62812042, 11.57108021], [92.6279068, 11.57086086], [92.62763214, 11.57063293], [92.62741089, 11.57021809], [92.6269989, 11.56984043], [92.62669373, 11.56938171], [92.6264267, 11.56892109], [92.62612915, 11.5685606], [92.62587738, 11.56819439], [92.6255722, 11.56787491], [92.62528992, 11.56744194], [92.62496185, 11.56694984], [92.62446594, 11.56655979], [92.62399292, 11.56616974], [92.62361908, 11.56575108], [92.62333679, 11.56534958], [92.62307739, 11.56498146], [92.62284851, 11.56462955], [92.62269592, 11.56421947], [92.62245941, 11.56386185], [92.62213135, 11.56355572], [92.62190247, 11.56315041], [92.62164307, 11.56276131], [92.62137604, 11.56237125], [92.62110901, 11.56205177], [92.62084198, 11.56177616], [92.62056732, 11.56157112], [92.62032318, 11.56142139], [92.62000275, 11.56140041], [92.61964417, 11.56147957], [92.61923218, 11.56167126], [92.61875153, 11.56195164], [92.61823273, 11.56229115], [92.61785889, 11.56282043], [92.617836, 11.56347179], [92.61797333, 11.56413269], [92.61804199, 11.56482124], [92.61804199, 11.56552124], [92.61798859, 11.56622314], [92.61804962, 11.56732082], [92.61860657, 11.56773186], [92.61885834, 11.56839943], [92.61902618, 11.56903076], [92.61921692, 11.56956196], [92.61940765, 11.57010174], [92.61955261, 11.57063961], [92.61974335, 11.57115269], [92.61991882, 11.57163811], [92.62002563, 11.57217121], [92.62018585, 11.57268047], [92.62020874, 11.5731287], [92.6202774, 11.5736208], [92.62024689, 11.57411098], [92.62017059, 11.57468128], [92.62026978, 11.57511806], [92.6202774, 11.57569027], [92.62026215, 11.57611179], [92.62030029, 11.57663155], [92.62039948, 11.57705784], [92.62030029, 11.57751083], [92.62023163, 11.577981], [92.62008667, 11.57840919], [92.62001038, 11.57884026], [92.6199646, 11.57926178], [92.61981964, 11.57964516], [92.61969757, 11.58007145], [92.61951447, 11.58052921], [92.61945343, 11.58108521], [92.61940002, 11.58165932], [92.61921692, 11.58218956], [92.61911774, 11.58272076], [92.618927, 11.58316994], [92.61880493, 11.58366966], [92.61859894, 11.58412075], [92.6183548, 11.58454514], [92.61817932, 11.58497143], [92.61798859, 11.58533955], [92.6177597, 11.58561993], [92.61746216, 11.58580112], [92.61705017, 11.58587074], [92.61669159, 11.58609009], [92.61636353, 11.58637047], [92.61597443, 11.58659077], [92.61551666, 11.58678055], [92.61508179, 11.58701992], [92.61482239, 11.58745956], [92.61460114, 11.58789539], [92.61440277, 11.5882616], [92.61419678, 11.58855057], [92.61406708, 11.58886147], [92.61386871, 11.5891304], [92.61361694, 11.58942413], [92.61334229, 11.5897913], [92.61303711, 11.59018612], [92.61270142, 11.59054089], [92.6124115, 11.59086037], [92.61221313, 11.59119129], [92.61197662, 11.5914917], [92.61178589, 11.59183121], [92.61161041, 11.59220028], [92.61138153, 11.59256268], [92.61110687, 11.59289074], [92.61079407, 11.59317112], [92.61044312, 11.59340096], [92.61000824, 11.59360027], [92.60955048, 11.59374142], [92.60909271, 11.59381199], [92.60865021, 11.5937109], [92.60798645, 11.59363365], [92.60762787, 11.59419918], [92.6073761, 11.59477997], [92.60762787, 11.59535503], [92.60780334, 11.59583092], [92.60803223, 11.59630966], [92.6082077, 11.59681988], [92.60830688, 11.59735107], [92.60838318, 11.59792995], [92.6085434, 11.59847927], [92.60861206, 11.59905148], [92.60868073, 11.59957123], [92.6088028, 11.6000042], [92.60865021, 11.60037136], [92.6085434, 11.6007309], [92.60837555, 11.60100937], [92.60826874, 11.60130119], [92.60810852, 11.60156059], [92.60798645, 11.60188198], [92.60777283, 11.60218143], [92.6072998, 11.60236835], [92.60720062, 11.60289383], [92.60709381, 11.60334301], [92.60691071, 11.60378075], [92.60668945, 11.60416794], [92.60655212, 11.6045742], [92.60640717, 11.60499954], [92.60634613, 11.60551071], [92.60614777, 11.60599136], [92.60598755, 11.60650635], [92.60585785, 11.60701942], [92.60582733, 11.60759068], [92.60575867, 11.60819054], [92.60555267, 11.60883141], [92.60566711, 11.60948086], [92.60610199, 11.6100893], [92.60632324, 11.61069965], [92.60643005, 11.61133099], [92.60652924, 11.61190605], [92.60671997, 11.61240005], [92.60700226, 11.6128397], [92.60743713, 11.61314106], [92.60778809, 11.61352921], [92.60809326, 11.61404991], [92.60826111, 11.61439037], [92.60848999, 11.61485481], [92.60864258, 11.61529922], [92.60868073, 11.61569786], [92.60856628, 11.61629105], [92.60845184, 11.61688614], [92.60855103, 11.61745071], [92.60848236, 11.61796093], [92.60832214, 11.61833668], [92.60822296, 11.61893177], [92.60823059, 11.61972141], [92.60842133, 11.62020397], [92.60897827, 11.62096119], [92.60983276, 11.6214962], [92.60990143, 11.62154007], [92.61030579, 11.62165356], [92.6109314, 11.62165356], [92.61143494, 11.62134838], [92.61190033, 11.62142086], [92.61235046, 11.62141037], [92.61277008, 11.62145138], [92.61315155, 11.6215353], [92.61351776, 11.62163067], [92.61387634, 11.62166023], [92.61422729, 11.62167168], [92.61457825, 11.6216507], [92.61499786, 11.62163067], [92.61530304, 11.62174034], [92.61557007, 11.62164688], [92.61569977, 11.6216011], [92.61610413, 11.6216011], [92.61654663, 11.62147999], [92.61698151, 11.62138462], [92.61743927, 11.62115669], [92.61782074, 11.62114143], [92.61823273, 11.62094021], [92.61865234, 11.62080383], [92.61903381, 11.62061214], [92.61928558, 11.62048435], [92.62017822, 11.61943436], [92.62088013, 11.61901855], [92.62185669, 11.61895084], [92.62213135, 11.6185379], [92.62262726, 11.61826038], [92.6233902, 11.61798191], [92.62422943, 11.61756897], [92.62444305, 11.61756897], [92.62464905, 11.61770821], [92.62485504, 11.61798382], [92.62493134, 11.61874294], [92.62513733, 11.61943054], [92.62520599, 11.61970997], [92.62520599, 11.62019253], [92.62516022, 11.6204319], [92.62545013, 11.62093067], [92.62561035, 11.62150097], [92.62581635, 11.62199974], [92.62600708, 11.62247181], [92.62635803, 11.62292957], [92.62650299, 11.62323093], [92.62663269, 11.62345028], [92.62693024, 11.62383175], [92.62736511, 11.62457848], [92.62754059, 11.62524128], [92.62785339, 11.62579918], [92.62844849, 11.62570953], [92.62890625, 11.62555981], [92.62932587, 11.6252594], [92.62956238, 11.62465954], [92.62970734, 11.62403107], [92.62980652, 11.62341976], [92.62992859, 11.62284756], [92.62999725, 11.62228012], [92.63006592, 11.62171078], [92.63009644, 11.62114143], [92.63012695, 11.62055111], [92.63018036, 11.61998081], [92.63033295, 11.61946106], [92.63031006, 11.61896038], [92.63008881, 11.61804771], [92.62993622, 11.61750126], [92.62966919, 11.61722088], [92.62988281, 11.61680984], [92.63028717, 11.61674023], [92.63085175, 11.61667061], [92.63189697, 11.61680984], [92.6322403, 11.61680984], [92.63259888, 11.61674023], [92.63308716, 11.61667061], [92.63363647, 11.61660099], [92.6342392, 11.61662102], [92.63447571, 11.61604023], [92.63459015, 11.61575317], [92.63493347, 11.6154089], [92.63549805, 11.6154089], [92.63606262, 11.61555004], [92.63654327, 11.61588955], [92.63716888, 11.61637497], [92.63772583, 11.61713028], [92.63800812, 11.61747837], [92.63857269, 11.61789131], [92.63906097, 11.61830616], [92.63954926, 11.61913109], [92.63989258, 11.61940861], [92.64052582, 11.61982059], [92.64108276, 11.62045002], [92.64126587, 11.62078953], [92.64134979, 11.62117958], [92.64157867, 11.6215601], [92.64177704, 11.62191963], [92.64196777, 11.62227821], [92.64221191, 11.62259007], [92.64259338, 11.62287998], [92.64295197, 11.62316227], [92.64328003, 11.62338257], [92.64363098, 11.6236496], [92.64395142, 11.62399197], [92.6441803, 11.62438202], [92.64435577, 11.6248312], [92.64450836, 11.62531185], [92.64459229, 11.62582874], [92.64460754, 11.62636185], [92.6446228, 11.62686443], [92.64466858, 11.62731266], [92.64476776, 11.62772083], [92.6448822, 11.62814045], [92.64502716, 11.62857056], [92.64504242, 11.62901974], [92.64511108, 11.62955093], [92.64515686, 11.62987041], [92.64512634, 11.63026047], [92.6452179, 11.63091087], [92.64520264, 11.63123131], [92.64530182, 11.6315794], [92.64524841, 11.63199043], [92.64520264, 11.63229275], [92.64525604, 11.63272095], [92.64502716, 11.6332407], [92.64502716, 11.63383102], [92.64488983, 11.63452625], [92.64460754, 11.63495922], [92.64465332, 11.63541031], [92.64451599, 11.63585854], [92.64438629, 11.6362896], [92.64420319, 11.63662529], [92.64409637, 11.63698101], [92.64391327, 11.63729954], [92.64373016, 11.63766003], [92.64369202, 11.63808155], [92.64360046, 11.63836193], [92.64312744, 11.63891125], [92.64286804, 11.63901234], [92.64241028, 11.63916016], [92.64176178, 11.63896084], [92.6413269, 11.63847065], [92.64112091, 11.63809967], [92.64083099, 11.63767147], [92.64054108, 11.63723183], [92.64025116, 11.63678932], [92.63990784, 11.63635635], [92.63961029, 11.63587093], [92.63928986, 11.63539886], [92.63899994, 11.63495922], [92.63871765, 11.6348114], [92.63842773, 11.63464165], [92.63780975, 11.63449192], [92.63724518, 11.63429642], [92.6366272, 11.63442993], [92.63603973, 11.6342907], [92.6354599, 11.63436031], [92.63521576, 11.63438034], [92.63485718, 11.63453102], [92.63444519, 11.63475609], [92.63420105, 11.63521194], [92.63404083, 11.63579082], [92.6341095, 11.63639736], [92.63426208, 11.63689041], [92.63417816, 11.63742065], [92.63424683, 11.63792896], [92.63444519, 11.63840294], [92.63461304, 11.63891411], [92.63475037, 11.63945103], [92.63494873, 11.63997078], [92.63504791, 11.6405592], [92.63529205, 11.64110565], [92.63563538, 11.64158916], [92.63625336, 11.64165306], [92.63684082, 11.64241028], [92.63684082, 11.64278984], [92.63703918, 11.64316177], [92.63720703, 11.64351082], [92.63735962, 11.643857], [92.63762665, 11.64423084], [92.63775635, 11.64465904], [92.63791656, 11.64516258], [92.63791656, 11.64555931], [92.63775635, 11.64583969], [92.63777924, 11.6461134], [92.63767242, 11.64644241], [92.63748169, 11.64679909], [92.63683319, 11.64697933], [92.63648224, 11.64742184], [92.63613892, 11.64789963], [92.63582611, 11.64839935], [92.63555145, 11.64883041], [92.63536072, 11.64914036], [92.63523102, 11.64966869], [92.6350708, 11.64978313], [92.63482666, 11.64995384], [92.63446808, 11.64966011], [92.63410187, 11.64971733], [92.63373566, 11.64972305], [92.63337708, 11.64972115], [92.63305664, 11.64975071], [92.63275909, 11.64985085], [92.63253021, 11.65010166], [92.63217926, 11.65065098], [92.63204193, 11.65086079], [92.63175964, 11.65086079], [92.63127136, 11.65043926], [92.63127136, 11.64975262], [92.63085175, 11.64906311], [92.63071442, 11.64795685], [92.63092041, 11.64665127], [92.6311264, 11.64596081], [92.63162231, 11.64451122], [92.63189697, 11.64334202], [92.63204193, 11.64216137], [92.63217926, 11.6411953], [92.63231659, 11.64072132], [92.63246155, 11.6403017], [92.63265228, 11.64021015], [92.63276672, 11.63976097], [92.63278198, 11.63915062], [92.63277435, 11.63855076], [92.63273621, 11.63796139], [92.63254547, 11.63742065], [92.63249969, 11.63683033], [92.63249969, 11.63626957], [92.63249969, 11.6357708], [92.63228607, 11.63532162], [92.63228607, 11.63501358], [92.63223267, 11.63459682], [92.63220215, 11.63422775], [92.63212585, 11.63391972], [92.6317215, 11.63359165], [92.63171387, 11.63309479], [92.63166046, 11.63260937], [92.63166046, 11.63213062], [92.63166046, 11.63164997], [92.63170624, 11.63120079], [92.63175964, 11.63076973], [92.63170624, 11.63031197], [92.63162231, 11.62994289], [92.63153839, 11.62953854], [92.63188934, 11.62924099], [92.63157654, 11.62871933], [92.6309967, 11.62825203], [92.63050079, 11.62814045], [92.62996674, 11.62801933], [92.62956238, 11.62805271], [92.62918091, 11.62804699], [92.62883759, 11.6280489], [92.62851715, 11.62793922], [92.62822723, 11.62800121], [92.62805939, 11.62794876], [92.62786865, 11.62789154], [92.62741852, 11.62789154], [92.62689972, 11.6280489], [92.6263504, 11.62818623], [92.62581635, 11.62834072], [92.62516785, 11.62842941], [92.62478638, 11.62879562], [92.62444305, 11.62895107], [92.62409973, 11.62917042], [92.62384033, 11.62952137], [92.62335968, 11.62976074], [92.62291718, 11.63014793], [92.62257385, 11.63058567], [92.62230682, 11.63101196], [92.62210083, 11.63136005], [92.62189484, 11.63160896], [92.62168884, 11.63179111], [92.62151337, 11.63197136], [92.621315, 11.63215828], [92.62106323, 11.63229275], [92.62075806, 11.63247013], [92.6204071, 11.63257122], [92.62008667, 11.63274193], [92.61975861, 11.63277054], [92.61942291, 11.63272095], [92.61904907, 11.6325407], [92.61862183, 11.63249969], [92.6181488, 11.63249779], [92.61762238, 11.63252068], [92.6170578, 11.63267994], [92.61600494, 11.63350105], [92.615448, 11.63398075], [92.61474609, 11.63446712], [92.61390686, 11.63467216], [92.61341858, 11.6348114], [92.6129303, 11.63502121], [92.61244202, 11.63516045], [92.61152649, 11.63516045], [92.61125183, 11.63502121], [92.61097717, 11.63475037], [92.61083221, 11.63447094], [92.61062622, 11.63399124], [92.6102829, 11.63386059], [92.60990143, 11.63369179], [92.60941315, 11.63362122], [92.6088562, 11.6336813], [92.60839844, 11.63402939], [92.60810852, 11.63451004], [92.60806274, 11.63504124], [92.60805511, 11.63554478], [92.60805511, 11.63604164], [92.60805511, 11.63654137], [92.60806274, 11.63704014], [92.60800934, 11.63753033], [92.60783386, 11.6379652], [92.60771942, 11.63844395], [92.60752106, 11.63887501], [92.6073761, 11.63932133], [92.6072464, 11.63976097], [92.60720825, 11.6402216], [92.60710144, 11.64067078], [92.60692596, 11.64112186], [92.60666656, 11.64157772], [92.60637665, 11.6420908], [92.60608673, 11.64264202], [92.60573578, 11.64316177], [92.60546112, 11.6436882], [92.6051712, 11.64415073], [92.60488892, 11.64457035], [92.60462189, 11.64497566], [92.60427856, 11.64532185], [92.60392761, 11.64568043], [92.60391235, 11.64611053], [92.60384369, 11.64672184], [92.60338593, 11.64737129], [92.60310364, 11.64783573], [92.60267639, 11.64830971], [92.60247803, 11.64876175], [92.60221863, 11.64910984], [92.60190582, 11.64941978], [92.60144043, 11.64965057], [92.60101318, 11.64986038], [92.60040283, 11.65019512], [92.59964752, 11.65034962], [92.59906769, 11.65099144], [92.59879303, 11.65167046], [92.59896088, 11.6522398], [92.59912872, 11.65273857], [92.59916687, 11.65318966], [92.59918213, 11.65360737], [92.59924316, 11.65398121], [92.59932709, 11.65431118], [92.5994873, 11.65456867], [92.59954071, 11.65482044], [92.59970856, 11.65507698], [92.5997467, 11.65533161], [92.59980774, 11.65559006], [92.5999527, 11.65588188], [92.59983063, 11.65616035], [92.59965515, 11.65635586], [92.59925842, 11.65662003], [92.59897614, 11.65709877], [92.59885406, 11.65769577], [92.59863281, 11.65823078], [92.59844971, 11.65876007], [92.5982666, 11.65923023], [92.59805298, 11.65966702], [92.59784698, 11.66008377], [92.59768677, 11.66050053], [92.59747314, 11.66084957], [92.59719086, 11.66116238], [92.59693146, 11.66154099], [92.59667206, 11.66193962], [92.59642029, 11.66235447], [92.59620667, 11.66280079], [92.59601593, 11.66327953], [92.5957489, 11.66372204], [92.59554291, 11.66420269], [92.59529114, 11.66459942], [92.59525299, 11.66497993], [92.5951767, 11.66516018], [92.59500885, 11.66537666], [92.59479523, 11.66563225], [92.59464264, 11.66592121], [92.59428406, 11.66629982], [92.59424591, 11.66670132], [92.59388733, 11.66691017], [92.59361267, 11.66698074], [92.59319305, 11.66691017], [92.59298706, 11.66655922], [92.59268188, 11.6666851], [92.59253693, 11.66679382], [92.59224701, 11.66685963], [92.59204865, 11.66722012], [92.59183502, 11.6679678], [92.59137726, 11.66884995], [92.59140015, 11.66938972], [92.59146118, 11.6699028], [92.59153748, 11.67041111], [92.59169006, 11.67084217], [92.59197235, 11.67116261], [92.59236145, 11.67139053], [92.59275055, 11.67165089], [92.59311676, 11.67198563], [92.59359741, 11.67224121], [92.59390259, 11.67239189], [92.59410858, 11.67249203], [92.59495544, 11.67237568], [92.59538269, 11.67264938], [92.59565735, 11.67300034], [92.59572601, 11.67348099], [92.59574127, 11.6739006], [92.59609985, 11.67431068], [92.59642029, 11.67472076], [92.59671021, 11.67513084], [92.59696198, 11.67559242], [92.59719849, 11.67608166], [92.59749603, 11.67651653], [92.59777069, 11.67695522], [92.59796906, 11.67740822], [92.59819031, 11.67782307], [92.59835052, 11.6782608], [92.598526, 11.67871189], [92.59860229, 11.67918777], [92.59861755, 11.67968273], [92.59860992, 11.68017006], [92.59857941, 11.68063068], [92.59844971, 11.68110943], [92.59855652, 11.68171597], [92.59861755, 11.68229008], [92.59867859, 11.68281746], [92.59870911, 11.68331337], [92.59870148, 11.68379211], [92.59870148, 11.68424129], [92.59876251, 11.68474674], [92.59906006, 11.68517971], [92.59908295, 11.68565178], [92.59909058, 11.68614388], [92.59909821, 11.68657017], [92.59909821, 11.68716145], [92.59909821, 11.68765068], [92.59906006, 11.68811131], [92.59910583, 11.68844128], [92.59910583, 11.68894958], [92.59919739, 11.68945122], [92.59919739, 11.68989277], [92.59938049, 11.69024181], [92.59958649, 11.69054127], [92.59966278, 11.69084072], [92.59951019, 11.69110107], [92.59942627, 11.69145203], [92.59931183, 11.69178867], [92.59914398, 11.69209003], [92.59893036, 11.69237328], [92.59874725, 11.69270992], [92.59848022, 11.69297028], [92.5982132, 11.69319057], [92.59802246, 11.69345093], [92.59777069, 11.69368076], [92.59741211, 11.6939497], [92.59690857, 11.69423485], [92.59645844, 11.69470406], [92.59622955, 11.69527435], [92.59613037, 11.69578934], [92.59619904, 11.6962204], [92.59634399, 11.69653702], [92.5963974, 11.69685364], [92.59642029, 11.69717979], [92.59644318, 11.69753075], [92.59638977, 11.69789124], [92.59630585, 11.69825077], [92.59609985, 11.69854927], [92.59583282, 11.69884109], [92.59555817, 11.69917202], [92.59527588, 11.69953156], [92.595047, 11.69991016], [92.59490967, 11.70034504], [92.59472656, 11.70075321], [92.5945282, 11.70114994], [92.59436798, 11.7015667], [92.59406281, 11.70189095], [92.59331512, 11.70211601], [92.59303284, 11.70246029], [92.59289551, 11.70315075], [92.59295654, 11.70377064], [92.59303284, 11.70440006], [92.59312439, 11.70504665], [92.59344482, 11.70555115], [92.59374237, 11.70600033], [92.59391785, 11.7065506], [92.59412384, 11.7071104], [92.5941925, 11.7077322], [92.59430695, 11.70829964], [92.59449005, 11.70879173], [92.59468842, 11.70918179], [92.59475708, 11.70950699], [92.59487152, 11.70970058], [92.59474945, 11.71055126], [92.59456635, 11.71073055], [92.5943985, 11.71104145], [92.59416962, 11.71136284], [92.59393311, 11.71166992], [92.59366608, 11.71197128], [92.59336853, 11.71224022], [92.59304047, 11.71249104], [92.59266663, 11.71277618], [92.59223175, 11.71303272], [92.59173584, 11.71326256], [92.59121704, 11.71350956], [92.59079742, 11.71387196], [92.5904007, 11.71419144], [92.59004974, 11.71451473], [92.58972168, 11.71486568], [92.58938599, 11.71523476], [92.58901215, 11.71560192], [92.58867645, 11.7160511], [92.58840942, 11.71652031], [92.58811951, 11.71677971], [92.5880661, 11.71753693], [92.58813477, 11.71788311], [92.58792877, 11.71795177], [92.58764648, 11.71788311], [92.58737183, 11.71733189], [92.58722687, 11.71677971], [92.58709717, 11.71629047], [92.58696747, 11.7160511], [92.58683014, 11.71572018], [92.58669281, 11.71533298], [92.58660126, 11.71487522], [92.58638763, 11.71448708], [92.58612823, 11.71417141], [92.58580017, 11.71399975], [92.5854187, 11.71420193], [92.58503723, 11.71455956], [92.58466339, 11.71498203], [92.584198, 11.71527576], [92.58370209, 11.71554947], [92.58322144, 11.71584129], [92.58277893, 11.71611023], [92.58236694, 11.71632671], [92.58190918, 11.71640205], [92.58148956, 11.71660042], [92.58104706, 11.71667099], [92.58053589, 11.71660042], [92.57994843, 11.71649075], [92.57936859, 11.7164793], [92.57885742, 11.71654129], [92.57834625, 11.71638966], [92.57788849, 11.71632195], [92.57744598, 11.71638966], [92.57702637, 11.71611023], [92.57663727, 11.71609402], [92.57624817, 11.71599388], [92.57583618, 11.71582985], [92.57483673, 11.71594143], [92.57441711, 11.71558952], [92.57414246, 11.71490192], [92.57407379, 11.71428013], [92.57406616, 11.71380138], [92.57421112, 11.71318054], [92.57427979, 11.71269131], [92.57442474, 11.71234989], [92.57441711, 11.71200085], [92.57427979, 11.71110725], [92.57433319, 11.71020889], [92.57424927, 11.70990562], [92.57377625, 11.70942974], [92.57371521, 11.70888996], [92.57363892, 11.70806026], [92.57385254, 11.70771599], [92.57385254, 11.70730114], [92.57378387, 11.70702457], [92.5734024, 11.70599079], [92.57327271, 11.70575142], [92.57292938, 11.7052002], [92.57286072, 11.70472145], [92.57279205, 11.70416069], [92.57279205, 11.70022869], [92.57272339, 11.69974995], [92.57254028, 11.69915104], [92.57211304, 11.69874763], [92.5716629, 11.69847202], [92.57122803, 11.69826031], [92.57086182, 11.69803905], [92.57050323, 11.69779968], [92.57009125, 11.69754028], [92.56964874, 11.69724083], [92.56919098, 11.69693089], [92.56884003, 11.69653034], [92.568573, 11.69605064], [92.56829834, 11.69557095], [92.56798553, 11.69515133], [92.56756592, 11.69489574], [92.56719208, 11.6946907], [92.56685638, 11.69450188], [92.56655121, 11.69436932], [92.56624603, 11.69416046], [92.565979, 11.6938324], [92.56584167, 11.6933279], [92.56567383, 11.69288635], [92.56539154, 11.69201088], [92.56510925, 11.69201088], [92.56483459, 11.69214725], [92.56445313, 11.69258022], [92.56402588, 11.69268131], [92.56365204, 11.69287014], [92.56328583, 11.69305038], [92.56295013, 11.69321632], [92.56260681, 11.6933918], [92.56231689, 11.69367409], [92.56208801, 11.69405937], [92.56182098, 11.69446087], [92.56156158, 11.69484997], [92.5613327, 11.69524002], [92.56111145, 11.69559097], [92.56091309, 11.6959219], [92.56076813, 11.69629955], [92.56063843, 11.69670105], [92.56050873, 11.69713402], [92.56031036, 11.69756889], [92.56023407, 11.69804764], [92.56005096, 11.69843292], [92.55999756, 11.69882965], [92.55996704, 11.6991806], [92.5598526, 11.69946957], [92.55974579, 11.69977093], [92.55966949, 11.70011139], [92.55950928, 11.70045185], [92.55944824, 11.70089245], [92.55939484, 11.7013731], [92.55919647, 11.70181084], [92.55909729, 11.70223522], [92.55898285, 11.70256996], [92.55883026, 11.70285034], [92.55870819, 11.70317078], [92.55857849, 11.70349979], [92.55839539, 11.70392799], [92.55819702, 11.70448685], [92.5579834, 11.70511055], [92.55776215, 11.70573997], [92.55751801, 11.70634174], [92.55734253, 11.7069273], [92.55715942, 11.70746136], [92.55693054, 11.707901], [92.55670929, 11.70828056], [92.55659485, 11.70869827], [92.556427, 11.70912457], [92.55631256, 11.70960331], [92.55613708, 11.71010017], [92.55605316, 11.71066093], [92.55583191, 11.71117592], [92.5555191, 11.71173191], [92.55510712, 11.71234703], [92.55522919, 11.71297169], [92.55513, 11.71352959], [92.5548172, 11.71469021], [92.55441284, 11.71558094], [92.55436707, 11.71587086], [92.55415344, 11.71643829], [92.55390167, 11.71694183], [92.55370331, 11.71741199], [92.5535202, 11.71780109], [92.55338287, 11.71811962], [92.55330658, 11.71840954], [92.55323029, 11.71866035], [92.5531311, 11.71887684], [92.55296326, 11.7190733], [92.55274963, 11.7193327], [92.55260468, 11.71977329], [92.55250549, 11.72028065], [92.55241394, 11.72078514], [92.5522995, 11.72126961], [92.5522995, 11.72179031], [92.55239105, 11.72234821], [92.55246735, 11.72292042], [92.55249786, 11.72348118], [92.55249786, 11.72398663], [92.55246735, 11.72443104], [92.55256653, 11.72484779], [92.55263519, 11.72526264], [92.5524826, 11.72580147], [92.5525589, 11.72614956], [92.55261993, 11.72655106], [92.5525589, 11.72699833], [92.55251312, 11.72760201], [92.55251312, 11.72870922], [92.55233002, 11.72998142], [92.55246735, 11.73035526], [92.55249786, 11.73071861], [92.55249786, 11.73110008], [92.55249786, 11.73152161], [92.55249786, 11.73202991], [92.55249786, 11.73498058], [92.55249786, 11.73543262], [92.55249786, 11.73588753], [92.55249786, 11.73639202], [92.55253601, 11.73695087], [92.552742, 11.73748589], [92.55304718, 11.73797226], [92.55332184, 11.73841095], [92.5535965, 11.73882198], [92.55378723, 11.73923016], [92.55391693, 11.73972034], [92.5541153, 11.74026012], [92.5541687, 11.74090004], [92.55416107, 11.74158859], [92.55410004, 11.74223995], [92.55387878, 11.74279022], [92.55361176, 11.74324989], [92.55336761, 11.74370098], [92.55325317, 11.74422073], [92.55309296, 11.74471092], [92.55304718, 11.74523067], [92.55304718, 11.74576187], [92.55304718, 11.74629021], [92.55305481, 11.74681664], [92.55304718, 11.74734974], [92.55305481, 11.74788761], [92.55310059, 11.74841499], [92.55329132, 11.74889088], [92.55332184, 11.74943066], [92.55332184, 11.74997139], [92.55331421, 11.75049782], [92.55330658, 11.75091934], [92.55330658, 11.75144958], [92.55335236, 11.75187016], [92.5533371, 11.75225925], [92.5533371, 11.75268078], [92.55332184, 11.75316048], [92.55325317, 11.75366974], [92.55304718, 11.75415134], [92.55278778, 11.75461197], [92.55252075, 11.75511837], [92.5522995, 11.75569439], [92.55224609, 11.75632763], [92.55235291, 11.75691986], [92.55251312, 11.75747204], [92.55269623, 11.75802135], [92.55282593, 11.75864124], [92.55309296, 11.75918102], [92.55332184, 11.75969601], [92.55349731, 11.76014996], [92.55355835, 11.76047134], [92.55354309, 11.76105499], [92.55310822, 11.76130104], [92.55301666, 11.76149178], [92.55287933, 11.76203918], [92.55276489, 11.76274776], [92.55289459, 11.76341438], [92.55306244, 11.76389217], [92.55329895, 11.76430225], [92.55356598, 11.7646904], [92.55387878, 11.76502037], [92.55418396, 11.76537132], [92.55439758, 11.76577854], [92.55471802, 11.76612091], [92.55506897, 11.76643085], [92.55562592, 11.76657009], [92.55606079, 11.76682091], [92.55667877, 11.76719189], [92.55715942, 11.7675209], [92.55764008, 11.76782131], [92.55804443, 11.76817036], [92.55838776, 11.76855755], [92.55869293, 11.76895428], [92.55898285, 11.76932144], [92.55918884, 11.76970863], [92.55934143, 11.77012062], [92.55941772, 11.7705698], [92.55943298, 11.77104187], [92.55937958, 11.77149105], [92.55924988, 11.77191925], [92.55909729, 11.77229977], [92.55911255, 11.77273083], [92.55930328, 11.77313614], [92.55922699, 11.77340126], [92.55898285, 11.77353954], [92.55861664, 11.77340126], [92.55799866, 11.77305031], [92.55722809, 11.77305412], [92.55645752, 11.77277946], [92.55605316, 11.77268982], [92.55599213, 11.77361012], [92.55591583, 11.77413177], [92.55578613, 11.77462006], [92.55555725, 11.77509022], [92.55526733, 11.77559566], [92.55509949, 11.77621078], [92.55519867, 11.7768898], [92.5552597, 11.77750778], [92.5552063, 11.77807999], [92.55504608, 11.77861118], [92.55496216, 11.77912807], [92.55478668, 11.77959538], [92.55471802, 11.78007221], [92.55462646, 11.78049564], [92.55446625, 11.78083134], [92.55439758, 11.78114128], [92.5542984, 11.78140068], [92.55416107, 11.78166866], [92.55397797, 11.78194141], [92.55383301, 11.78225136], [92.55377197, 11.78277493], [92.55377197, 11.78297997], [92.55370331, 11.78327179], [92.55342102, 11.78339672], [92.552742, 11.78351116], [92.55241394, 11.78403473], [92.55229187, 11.78470516], [92.55246735, 11.78533173], [92.5526123, 11.78591061], [92.55282593, 11.78635788], [92.55303192, 11.78675175], [92.55316925, 11.78721714], [92.55325317, 11.7876997], [92.55309296, 11.78820801], [92.55296326, 11.78875065], [92.55272675, 11.78919125], [92.55260468, 11.78974915], [92.55273438, 11.79031372], [92.55275726, 11.79095173], [92.55290222, 11.79140091], [92.55326843, 11.79190063], [92.55356598, 11.79238129], [92.55378723, 11.79258442], [92.55391693, 11.79301262], [92.55388641, 11.7933588], [92.55383301, 11.79374027], [92.55363464, 11.79415035], [92.55350494, 11.79463291], [92.55342865, 11.79515266], [92.5533371, 11.79566097], [92.55329132, 11.79615116], [92.55310822, 11.79653168], [92.55298615, 11.79691029], [92.55282593, 11.79724979], [92.55261993, 11.79755974], [92.55242157, 11.79791069], [92.55242157, 11.79839134], [92.55224609, 11.79881954], [92.55208588, 11.79930115], [92.55188751, 11.7997818], [92.55165863, 11.80025578], [92.55145264, 11.80072975], [92.5513916, 11.80130196], [92.55137634, 11.80185986], [92.55134583, 11.80237961], [92.55115509, 11.80282402], [92.55105591, 11.80331039], [92.55090332, 11.80377007], [92.55097198, 11.80421925], [92.55105591, 11.80462933], [92.55110168, 11.80498981], [92.5512619, 11.80531311], [92.55126953, 11.80546093], [92.55142212, 11.8057394], [92.55149078, 11.80602169], [92.55149078, 11.80642986], [92.55127716, 11.8068428], [92.55072021, 11.80753136], [92.55002594, 11.80804062], [92.54979706, 11.80866146], [92.54969025, 11.80933094], [92.54969788, 11.81002426], [92.54987335, 11.81069183], [92.54998016, 11.81127834], [92.55000305, 11.81186104], [92.55000305, 11.81247044], [92.54995728, 11.81305981], [92.54977417, 11.81359768], [92.54968262, 11.81414318], [92.54949188, 11.81463337], [92.54937744, 11.81516361], [92.54918671, 11.81564045], [92.54904175, 11.8161087], [92.54888153, 11.81650066], [92.5486908, 11.81680012], [92.54856873, 11.81709194], [92.54833221, 11.81733131], [92.547966, 11.81758595], [92.54751587, 11.8178854], [92.54705811, 11.81820202], [92.54666138, 11.81851196], [92.54626465, 11.81873512], [92.54588318, 11.81893063], [92.54545593, 11.81909084], [92.5450058, 11.81893063], [92.54418182, 11.81914997], [92.54361725, 11.81914997], [92.54321289, 11.81888103], [92.54271698, 11.8187418], [92.54247284, 11.81855011], [92.54193115, 11.81839466], [92.54141235, 11.81849289], [92.54106903, 11.81883144], [92.54087067, 11.81926155], [92.54083252, 11.81975174], [92.54083252, 11.82026196], [92.54083252, 11.82075882], [92.54083252, 11.82126045], [92.54081726, 11.82177544], [92.54078674, 11.82229042], [92.54088593, 11.82278061], [92.54103088, 11.82321072], [92.5411911, 11.82356453], [92.54136658, 11.82385159], [92.54150391, 11.82414627], [92.54165649, 11.82443142], [92.54181671, 11.82475185], [92.54197693, 11.8251009], [92.54225159, 11.8253994], [92.54260254, 11.82565022], [92.54297638, 11.82589436], [92.54331207, 11.82618999], [92.54361725, 11.82652092], [92.54396057, 11.82683086], [92.54438019, 11.82707024], [92.54477692, 11.82738018], [92.5451889, 11.82769203], [92.54560089, 11.827981], [92.54588318, 11.82839203], [92.54614258, 11.82879066], [92.5463562, 11.8291893], [92.54651642, 11.82957935], [92.54662323, 11.82993031], [92.54664612, 11.83026981], [92.54666901, 11.83060741], [92.54666901, 11.83096886], [92.54666901, 11.83137131], [92.54664612, 11.83178139], [92.54650879, 11.83215046], [92.5463028, 11.83249187], [92.54640198, 11.83364964], [92.54640198, 11.83494663], [92.54632568, 11.83515358], [92.54605103, 11.8350172], [92.54576874, 11.83440018], [92.54563141, 11.83343124], [92.54532623, 11.83229065], [92.54501343, 11.83194733], [92.54473114, 11.83156013], [92.54447937, 11.83113098], [92.54426575, 11.83065701], [92.54406738, 11.83018112], [92.54384613, 11.82978153], [92.54361725, 11.82946968], [92.54338837, 11.82923031], [92.54312897, 11.82909107], [92.5429306, 11.82894993], [92.54263306, 11.82866096], [92.54216003, 11.82874012], [92.54216766, 11.82927132], [92.54208374, 11.82960892], [92.54219055, 11.83005333], [92.54222107, 11.83051109], [92.54222107, 11.83096886], [92.54222107, 11.83142281], [92.54222107, 11.83187199], [92.54222107, 11.83232117], [92.54217529, 11.83274937], [92.54199219, 11.83314133], [92.54191589, 11.83358955], [92.54180908, 11.83402061], [92.54168701, 11.83444118], [92.54165649, 11.83488274], [92.54162598, 11.83530426], [92.5414505, 11.83567142], [92.54129791, 11.83606625], [92.54106903, 11.8364296], [92.54081726, 11.83679867], [92.54051971, 11.83712101], [92.54013062, 11.83735561], [92.53969574, 11.83754539], [92.53926849, 11.83778191], [92.53883362, 11.83803463], [92.53830719, 11.83821011], [92.53774261, 11.83837032], [92.53720093, 11.83856964], [92.53697205, 11.83856773], [92.5366745, 11.83856583], [92.53623199, 11.8383379], [92.5358429, 11.83805084], [92.53547668, 11.83769131], [92.53517151, 11.83723927], [92.53482056, 11.83676147], [92.53443909, 11.83629608], [92.53407288, 11.83586025], [92.53371429, 11.83547306], [92.53350067, 11.83500385], [92.53331757, 11.83453178], [92.5330658, 11.83409214], [92.53281403, 11.83364964], [92.53246307, 11.83327961], [92.53214264, 11.83287525], [92.53178406, 11.83258343], [92.53140259, 11.83247089], [92.5311203, 11.83306599], [92.53104401, 11.83327389], [92.53070068, 11.83327389], [92.5304184, 11.83299828], [92.5304184, 11.83250999], [92.53035736, 11.83190632], [92.53013611, 11.83164024], [92.52990723, 11.83131123], [92.52960205, 11.83099174], [92.52919769, 11.83067131], [92.52881622, 11.83025169], [92.52848816, 11.82974052], [92.52810669, 11.82923031], [92.52773285, 11.82874012], [92.52725983, 11.8283577], [92.52680206, 11.82796955], [92.52633667, 11.82758045], [92.52583313, 11.82719994], [92.52535248, 11.82677078], [92.5249176, 11.82629871], [92.52472687, 11.8260603], [92.52432251, 11.82604885], [92.52390289, 11.82605076], [92.52355194, 11.82584095], [92.52296448, 11.82557487], [92.52230835, 11.82588196], [92.52186584, 11.82642937], [92.521492, 11.826931], [92.52114105, 11.82739067], [92.52083588, 11.82788086], [92.52055359, 11.82835484], [92.5202713, 11.82877922], [92.51999664, 11.8291893], [92.51972198, 11.82961082], [92.51944733, 11.8300581], [92.51920319, 11.83053398], [92.51906586, 11.83106327], [92.51887512, 11.83156204], [92.51862335, 11.83205032], [92.51834106, 11.83261013], [92.51805878, 11.83323002], [92.51774597, 11.83390045], [92.51763916, 11.83459759], [92.51767731, 11.83522034], [92.51803589, 11.83568954], [92.5182724, 11.83605194], [92.51846313, 11.83640099], [92.51863861, 11.83674526], [92.51882172, 11.83711243], [92.51909637, 11.83757687], [92.51909637, 11.83809185], [92.51909637, 11.83861065], [92.51888275, 11.83910084], [92.5187912, 11.83952141], [92.51864624, 11.83989239], [92.51860809, 11.84029102], [92.51856995, 11.8406992], [92.51847076, 11.84109116], [92.51824951, 11.84237194], [92.51818085, 11.84292126], [92.51789856, 11.8432703], [92.51754761, 11.84389019], [92.51727295, 11.84437084], [92.51719666, 11.84447098], [92.51703644, 11.84464169], [92.516922, 11.84492016], [92.51673889, 11.84517097], [92.51639557, 11.84530735], [92.51611328, 11.84555054], [92.51583099, 11.84582043], [92.51548004, 11.84603024], [92.51507568, 11.84614754], [92.51473236, 11.84638119], [92.51439667, 11.84667015], [92.51394653, 11.84692097], [92.51364899, 11.84738827], [92.51351929, 11.84800053], [92.51373291, 11.84868145], [92.5139389, 11.84932995], [92.51417542, 11.84989452], [92.51445007, 11.8503809], [92.51473236, 11.85082054], [92.51499939, 11.85122395], [92.5152359, 11.85157967], [92.51535797, 11.85195065], [92.51542664, 11.85229111], [92.51552582, 11.85262108], [92.51557159, 11.85299683], [92.51564026, 11.85340977], [92.51584625, 11.85381985], [92.51609802, 11.85426712], [92.5163269, 11.85474968], [92.51657867, 11.85522938], [92.51693726, 11.85559273], [92.51731873, 11.85577106], [92.51770782, 11.85591888], [92.51818085, 11.8565321], [92.51847076, 11.85689926], [92.51856995, 11.8572979], [92.51860809, 11.85775375], [92.51857758, 11.85823154], [92.51847839, 11.85874081], [92.51860046, 11.85928059], [92.51874542, 11.85982132], [92.51891327, 11.86023998], [92.51920319, 11.86061859], [92.51948547, 11.86100197], [92.51967621, 11.86135864], [92.5197525, 11.86179924], [92.5198822, 11.862257], [92.52002716, 11.8627634], [92.5202179, 11.86325073], [92.5202713, 11.86380959], [92.5202713, 11.8643589], [92.52030945, 11.86495781], [92.52048492, 11.86556244], [92.52059937, 11.86622334], [92.52086639, 11.86685181], [92.52127075, 11.86739922], [92.5214386, 11.8679781], [92.52169037, 11.86837196], [92.52184296, 11.86872959], [92.5220871, 11.86894894], [92.5222702, 11.86919308], [92.52245331, 11.86944103], [92.52268982, 11.86967087], [92.5230484, 11.86975956], [92.52339172, 11.86992741], [92.52375793, 11.87010384], [92.52419281, 11.87016106], [92.52436066, 11.87076092], [92.52468109, 11.87103939], [92.5248642, 11.87135983], [92.52494049, 11.87170029], [92.52485657, 11.87208652], [92.52472687, 11.87254333], [92.52459717, 11.87308121], [92.52448273, 11.8736763], [92.52449799, 11.87426567], [92.52466583, 11.87474918], [92.52490997, 11.8752737], [92.52471161, 11.87564087], [92.52465057, 11.87607956], [92.5245285, 11.87656975], [92.5246048, 11.87709045], [92.52462769, 11.87761021], [92.52461243, 11.87815857], [92.52474976, 11.87863064], [92.52505493, 11.87906837], [92.52527618, 11.87942219], [92.52549744, 11.87976074], [92.52568817, 11.88013268], [92.52588654, 11.88049126], [92.52613068, 11.88080025], [92.52635956, 11.88110065], [92.52648926, 11.8814497], [92.52658081, 11.8818264], [92.52675629, 11.88216114], [92.52687073, 11.88251019], [92.52688599, 11.88286781], [92.52672577, 11.88322258], [92.52664948, 11.88363075], [92.5265274, 11.88403034], [92.52641296, 11.88440228], [92.52636719, 11.88476181], [92.52629089, 11.88508129], [92.52617645, 11.8853817], [92.52575684, 11.88573933], [92.52577209, 11.88617897], [92.5258255, 11.88669205], [92.52585602, 11.88726044], [92.52583313, 11.88787937], [92.52583313, 11.88852024], [92.52583313, 11.88916874], [92.52583313, 11.88982105], [92.52587891, 11.8904686], [92.52606201, 11.89106083], [92.52610779, 11.89168072], [92.52613831, 11.89227962], [92.52625275, 11.89284134], [92.52633667, 11.8933897], [92.52638245, 11.89394665], [92.52639008, 11.89450264], [92.52642059, 11.89502239], [92.52658081, 11.89544201], [92.52681732, 11.89576054], [92.52702332, 11.89614964], [92.52713776, 11.89622593], [92.52728271, 11.8963213], [92.52767181, 11.89618015], [92.52812195, 11.89612103], [92.52858734, 11.89610004], [92.52902222, 11.89610481], [92.5294342, 11.89611244], [92.5298233, 11.89616203], [92.53013611, 11.89635563], [92.53047943, 11.89654922], [92.53078461, 11.89686203], [92.53124237, 11.89703178], [92.53159332, 11.89733124], [92.53188324, 11.89770031], [92.53230286, 11.89795971], [92.53275299, 11.89818954], [92.53318787, 11.8984499], [92.53369141, 11.89868259], [92.53425598, 11.89890099], [92.53481293, 11.89917946], [92.53533936, 11.89953518], [92.53578949, 11.89997005], [92.53608704, 11.90054035], [92.53639221, 11.90111923], [92.53671265, 11.90170002], [92.53704071, 11.90223789], [92.53730011, 11.90275955], [92.53751373, 11.90322685], [92.53774261, 11.90360069], [92.53783417, 11.90399837], [92.53800201, 11.9043417], [92.53806305, 11.9047308], [92.53801727, 11.90515137], [92.53784943, 11.90559101], [92.53765106, 11.90604019], [92.53756714, 11.9064703], [92.53734589, 11.90673733], [92.53717041, 11.90694427], [92.53695679, 11.90711975], [92.53672028, 11.90732956], [92.53643036, 11.90746021], [92.53617096, 11.90764046], [92.53583527, 11.90786457], [92.53547668, 11.9081707], [92.53525543, 11.90860844], [92.53502655, 11.9090004], [92.53489685, 11.90941048], [92.53475952, 11.90978909], [92.53468323, 11.91025066], [92.53449249, 11.91073036], [92.53444672, 11.91127014], [92.53447723, 11.91178131], [92.53468323, 11.91217709], [92.53491974, 11.9124918], [92.53518677, 11.91276836], [92.53549957, 11.91302967], [92.53581238, 11.91338539], [92.5361557, 11.91378021], [92.53659058, 11.91413975], [92.53704834, 11.91447735], [92.53747559, 11.91488266], [92.53785706, 11.91535187], [92.53824615, 11.91577244], [92.53876495, 11.91603374], [92.53931427, 11.9162817], [92.5398941, 11.91655254], [92.54048157, 11.91683102], [92.54090881, 11.91722107], [92.54122162, 11.91763115], [92.54141235, 11.91808033], [92.54160309, 11.91850567], [92.54165649, 11.91900063], [92.54167175, 11.91954136], [92.54171753, 11.92006969], [92.54189301, 11.92052078], [92.54193878, 11.92103195], [92.54199219, 11.92157173], [92.54219818, 11.9221096], [92.54238892, 11.92267036], [92.54260254, 11.92320156], [92.54297638, 11.92352104], [92.54347992, 11.92373943], [92.54405975, 11.92387199], [92.54470825, 11.92389202], [92.54535675, 11.92389202], [92.54595184, 11.9239397], [92.5464325, 11.92416954], [92.54688263, 11.92444134], [92.54736328, 11.92468452], [92.5479126, 11.92486095], [92.54847717, 11.92506599], [92.54899597, 11.92537117], [92.54955292, 11.92561054], [92.55001068, 11.92589092], [92.55047607, 11.92613029], [92.55088043, 11.92615986], [92.55119324, 11.92602062], [92.55193329, 11.92571068], [92.55239868, 11.92555618], [92.55296326, 11.9254694], [92.55348206, 11.92551041], [92.55377197, 11.92544174], [92.55429077, 11.92521191], [92.55479431, 11.92523193], [92.55499268, 11.92542076], [92.55497742, 11.92582893], [92.55503845, 11.92638969], [92.5552063, 11.92707062], [92.55528259, 11.92780113], [92.55536652, 11.92852592], [92.55558014, 11.92915154], [92.55590057, 11.9296608], [92.55626678, 11.93011189], [92.55651855, 11.93064976], [92.55690002, 11.93101025], [92.55721283, 11.93134022], [92.55744171, 11.93165493], [92.55757141, 11.932024], [92.55780792, 11.93229294], [92.55802155, 11.93257141], [92.55858612, 11.93307018], [92.55900574, 11.93382931], [92.55956268, 11.93438053], [92.56026459, 11.93527889], [92.56025696, 11.93600082], [92.56027985, 11.93626976], [92.5602417, 11.93663025], [92.56008911, 11.93705177], [92.55996704, 11.93757057], [92.55974579, 11.93805027], [92.55957031, 11.93843079], [92.55967712, 11.938941], [92.55960846, 11.93915081], [92.5594635, 11.93928528], [92.55918884, 11.93935394], [92.55870056, 11.93935394], [92.55834198, 11.93936253], [92.5581665, 11.93991375], [92.55838013, 11.94041443], [92.55873108, 11.94080067], [92.55909729, 11.94111061], [92.55943298, 11.94139957], [92.5597229, 11.94168091], [92.56001282, 11.94200039], [92.56027985, 11.9423418], [92.5605545, 11.94270897], [92.56082153, 11.94311047], [92.56101227, 11.9435606], [92.56103516, 11.94402599], [92.56109619, 11.94444084], [92.56118011, 11.94485569], [92.56139374, 11.94525242], [92.5616684, 11.94570255], [92.56198883, 11.94617271], [92.56240082, 11.94647408], [92.56288147, 11.94631004], [92.5630188, 11.94515038], [92.56321716, 11.94480133], [92.56350708, 11.94452477], [92.56378937, 11.9440403], [92.56441498, 11.94362926], [92.56490326, 11.94335079], [92.56537628, 11.94322395], [92.56554413, 11.94282913], [92.56565857, 11.94242096], [92.56582642, 11.9420414], [92.56598663, 11.94165611], [92.56614685, 11.94126129], [92.56635284, 11.94089031], [92.56648254, 11.94048023], [92.56664276, 11.9400692], [92.56671143, 11.93961143], [92.5668869, 11.93916035], [92.56698608, 11.93862915], [92.5672226, 11.93814754], [92.56745911, 11.93764019], [92.56763458, 11.93709087], [92.56781006, 11.9365406], [92.56806183, 11.93605137], [92.56832123, 11.93560028], [92.568573, 11.93518066], [92.5687561, 11.9347477], [92.56896973, 11.93435955], [92.56918335, 11.93396091], [92.56941223, 11.93356037], [92.56955719, 11.93307495], [92.56971741, 11.93257141], [92.56987, 11.93207645], [92.57003021, 11.93159962], [92.57028198, 11.93120575], [92.57055664, 11.93081188], [92.57083893, 11.93035984], [92.57116699, 11.92984962], [92.5716095, 11.92936039], [92.57202911, 11.92881012], [92.57245636, 11.92828178], [92.5728302, 11.92785645], [92.57315063, 11.92708969], [92.57343292, 11.92695141], [92.57454681, 11.92695141], [92.57524872, 11.92674065], [92.57629395, 11.92674065], [92.57653809, 11.92679977], [92.5769577, 11.9268074], [92.57738495, 11.92697334], [92.57776642, 11.92708969], [92.57811737, 11.92720127], [92.57840729, 11.92718124], [92.5786438, 11.92702389], [92.57887268, 11.92684078], [92.57907867, 11.92659092], [92.579216, 11.92623043], [92.579422, 11.92586803], [92.57956696, 11.92545128], [92.57975769, 11.92508411], [92.57997894, 11.92476654], [92.58014679, 11.92444134], [92.58027649, 11.92410183], [92.58042145, 11.92375088], [92.58053589, 11.92336082], [92.58061218, 11.92292976], [92.58078766, 11.92254734], [92.58082581, 11.92210102], [92.58088684, 11.92164898], [92.58101654, 11.92122078], [92.58087921, 11.92077732], [92.58082581, 11.92029095], [92.58080292, 11.91975975], [92.5806427, 11.91924], [92.58056641, 11.91869068], [92.58055878, 11.91811371], [92.58060455, 11.91753578], [92.58082581, 11.91706181], [92.58109283, 11.91663837], [92.58126831, 11.9162302], [92.58141327, 11.91587162], [92.58158875, 11.91561031], [92.58167267, 11.91532326], [92.58176422, 11.91504669], [92.58190918, 11.91477966], [92.58197021, 11.91441059], [92.58209991, 11.91399384], [92.5821991, 11.91350365], [92.58222198, 11.9129591], [92.58226776, 11.91240978], [92.58245087, 11.91190624], [92.58252716, 11.91135025], [92.58273315, 11.91081047], [92.58291626, 11.91025066], [92.58309174, 11.90966129], [92.58332825, 11.90912056], [92.58349609, 11.90858078], [92.58335876, 11.90804482], [92.58321381, 11.90748692], [92.58304596, 11.90695095], [92.58287048, 11.90642929], [92.5825882, 11.90598869], [92.58252716, 11.90558243], [92.5825882, 11.90518856], [92.58275604, 11.90483189], [92.58287811, 11.90445995], [92.58305359, 11.90410709], [92.58320618, 11.90373993], [92.58339691, 11.90338039], [92.58364105, 11.90303993], [92.58393097, 11.90272141], [92.58418274, 11.90234089], [92.58442688, 11.90197086], [92.58463287, 11.90159988], [92.58474731, 11.90117073], [92.58492279, 11.90072918], [92.58499146, 11.90022087], [92.58499908, 11.89969921], [92.58499908, 11.89920044], [92.58499908, 11.89873981], [92.58503723, 11.89827919], [92.58519745, 11.89782143], [92.58526611, 11.89731979], [92.58532715, 11.89682102], [92.58551788, 11.89639187], [92.58563995, 11.8959198], [92.58579254, 11.89546204], [92.5858078, 11.89496517], [92.58569336, 11.89445019], [92.58550262, 11.8939209], [92.58526611, 11.89338779], [92.58500671, 11.89284134], [92.58483887, 11.89227104], [92.58496094, 11.89171124], [92.58499908, 11.89118195], [92.58505249, 11.89074039], [92.58521271, 11.89038181], [92.58531952, 11.89000416], [92.58553314, 11.88968468], [92.58571625, 11.88929272], [92.58591461, 11.88888454], [92.58613586, 11.88848114], [92.58638, 11.88813496], [92.58660889, 11.88783169], [92.58677673, 11.88753986], [92.58698273, 11.88731194], [92.58720398, 11.88712692], [92.58743286, 11.88693142], [92.587677, 11.88673115], [92.58805847, 11.88663006], [92.58840942, 11.88642979], [92.58887482, 11.88634586], [92.58930206, 11.88615227], [92.58976746, 11.88611126], [92.59026337, 11.88614273], [92.59072876, 11.88630009], [92.59118652, 11.88640499], [92.59156036, 11.88656044], [92.59185028, 11.88673973], [92.59203339, 11.88701057], [92.59216309, 11.88741016], [92.59237671, 11.88789082], [92.59247589, 11.88846111], [92.59249878, 11.8891058], [92.59250641, 11.88976192], [92.59255219, 11.89037132], [92.59268951, 11.89089012], [92.59278107, 11.89140129], [92.59288788, 11.89191055], [92.59301758, 11.89243507], [92.59306335, 11.89303017], [92.59308624, 11.89364147], [92.59326172, 11.89411068], [92.59343719, 11.89444065], [92.59358215, 11.89473057], [92.59375, 11.89498806], [92.59382629, 11.89523029], [92.59379578, 11.89546204], [92.59390259, 11.89568996], [92.59371185, 11.89602089], [92.59333038, 11.89649868], [92.59321594, 11.8977232], [92.5933609, 11.89793015], [92.59364319, 11.89868927], [92.59378052, 11.89882755], [92.59399414, 11.89898586], [92.59438324, 11.89914131], [92.59481812, 11.89911556], [92.59519196, 11.89895439], [92.59547424, 11.89871693], [92.5957489, 11.89855003], [92.59597778, 11.8983202], [92.59733582, 11.89659023], [92.59783173, 11.89623928], [92.59817505, 11.89617252], [92.59838867, 11.89617252], [92.59858704, 11.89623928], [92.59880829, 11.896451], [92.59895325, 11.8966608], [92.59908295, 11.89710999], [92.59934235, 11.89727879], [92.59955597, 11.89748096], [92.59976959, 11.89768028], [92.60002136, 11.89782143], [92.60025024, 11.8979969], [92.60053253, 11.89805126], [92.60083771, 11.89801025], [92.60111237, 11.89778233], [92.60138702, 11.89749527], [92.60163879, 11.89715099], [92.60179901, 11.89668083], [92.60196686, 11.89619064], [92.6021347, 11.89569473], [92.60202026, 11.89512253], [92.60211182, 11.89454842], [92.60220337, 11.8939724], [92.60218048, 11.89341068], [92.6019516, 11.89290047], [92.60169983, 11.89242554], [92.60150146, 11.89191055], [92.60133362, 11.89135456], [92.60115814, 11.89080811], [92.6011734, 11.89025021], [92.60137939, 11.88973045], [92.60160828, 11.88922024], [92.60180664, 11.8887434], [92.60195923, 11.88827419], [92.60199738, 11.88783836], [92.60214233, 11.88737965], [92.6020813, 11.88691139], [92.60215759, 11.88645267], [92.60221863, 11.88601112], [92.60220337, 11.88560009], [92.60212708, 11.885252], [92.60206604, 11.88492107], [92.60192108, 11.8845911], [92.60173035, 11.88430595], [92.60164642, 11.88399124], [92.60150146, 11.88371468], [92.60140991, 11.88343143], [92.60138702, 11.88311195], [92.60138702, 11.88276958], [92.60138702, 11.8824234], [92.60138702, 11.88204861], [92.60138702, 11.88165665], [92.60138702, 11.88124943], [92.60137177, 11.8808279], [92.60125732, 11.88044262], [92.60114288, 11.88007069], [92.60111237, 11.87968826], [92.60112762, 11.87930107], [92.60124207, 11.87889957], [92.60138702, 11.87847137], [92.6015625, 11.87799931], [92.60164642, 11.87743187], [92.60167694, 11.87677956], [92.60171509, 11.87609196], [92.60189819, 11.87540054], [92.60193634, 11.87470055], [92.60191345, 11.87403107], [92.60176849, 11.87343025], [92.60167694, 11.87289047], [92.60166931, 11.87242222], [92.60165405, 11.87202835], [92.6015625, 11.87171078], [92.60137177, 11.87146282], [92.60116577, 11.8712244], [92.60105133, 11.87094116], [92.60089111, 11.87069035], [92.60080719, 11.87039185], [92.60070038, 11.87011147], [92.60057831, 11.86983109], [92.60047913, 11.86952114], [92.60031891, 11.86920929], [92.60028076, 11.86875057], [92.60027313, 11.86821079], [92.60028076, 11.86764145], [92.60031128, 11.86709595], [92.60045624, 11.86662197], [92.60054016, 11.86612129], [92.6006012, 11.86562061], [92.60079193, 11.86517906], [92.60090637, 11.86468029], [92.60112, 11.86423969], [92.60137177, 11.86382961], [92.60157776, 11.86341286], [92.60175323, 11.86297798], [92.60193634, 11.86258125], [92.60209656, 11.86221027], [92.60220337, 11.86186314], [92.60223389, 11.86150455], [92.60231781, 11.8611517], [92.60249329, 11.86079407], [92.60268402, 11.86036777], [92.60289001, 11.85990143], [92.60323334, 11.85948753], [92.60366058, 11.85921001], [92.60369873, 11.85850143], [92.60385132, 11.85836697], [92.60415649, 11.85818005], [92.60427094, 11.85816193], [92.60462189, 11.85829639], [92.60475922, 11.85871124], [92.60500336, 11.85915089], [92.60491943, 11.85943127], [92.60498047, 11.85974121], [92.60497284, 11.86013126], [92.6048584, 11.86055946], [92.60472107, 11.86099529], [92.60456085, 11.86141014], [92.60443115, 11.86183071], [92.60430908, 11.86221027], [92.60419464, 11.86256504], [92.60415649, 11.86294079], [92.60412598, 11.8633194], [92.60399628, 11.86367512], [92.60388184, 11.86410427], [92.60375977, 11.86457062], [92.6036377, 11.86506081], [92.60359955, 11.86555958], [92.60359955, 11.86606789], [92.60379028, 11.86657429], [92.60402679, 11.86707973], [92.60430145, 11.86758137], [92.60459137, 11.86795998], [92.60488129, 11.86828995], [92.6052475, 11.86856174], [92.60560608, 11.86888981], [92.60603333, 11.86918068], [92.60654449, 11.86947823], [92.60707092, 11.86981487], [92.60771942, 11.87004089], [92.60837555, 11.87028694], [92.6089859, 11.87034416], [92.60993195, 11.87022305], [92.61035156, 11.87029362], [92.61048889, 11.87036037], [92.61062622, 11.87063789], [92.61077118, 11.87105274], [92.61104584, 11.87125969], [92.61104584, 11.87181187], [92.61103821, 11.87263203], [92.61109924, 11.87317371], [92.6111145, 11.87373543], [92.61110687, 11.87426186], [92.61110687, 11.87473965], [92.6111145, 11.87518501], [92.61110687, 11.87561131], [92.61109924, 11.87602997], [92.61103821, 11.87646103], [92.61095428, 11.87689877], [92.61103058, 11.87737942], [92.61123657, 11.87784004], [92.61135864, 11.8782959], [92.61147308, 11.87870121], [92.61154175, 11.87907982], [92.61151123, 11.87938976], [92.61141205, 11.87971115], [92.61134338, 11.8801012], [92.61113739, 11.88048553], [92.6109848, 11.88096237], [92.6108551, 11.881464], [92.61083221, 11.88196087], [92.61083221, 11.88244057], [92.61062622, 11.88325119], [92.61048126, 11.88387012], [92.61039734, 11.88608074], [92.61013794, 11.88704967], [92.6102066, 11.88849926], [92.61054993, 11.88870525], [92.61052704, 11.88922024], [92.61044312, 11.88971043], [92.61024475, 11.88981915], [92.61010742, 11.8907814], [92.61010742, 11.89120007], [92.61026764, 11.89175415], [92.61026764, 11.89214134], [92.61016846, 11.89293003], [92.6100769, 11.89375114], [92.61011505, 11.8945303], [92.6102066, 11.89524555], [92.6102829, 11.89592934], [92.61039734, 11.89658833], [92.61060333, 11.89715958], [92.61035919, 11.89777088], [92.61031342, 11.89830875], [92.61035156, 11.89867115], [92.61042023, 11.89934444], [92.61042023, 11.90071964], [92.61048889, 11.90128136], [92.61052704, 11.90167141], [92.61065674, 11.90187073], [92.61067963, 11.90227032], [92.61068726, 11.90279865], [92.61080933, 11.90331364], [92.61096954, 11.90384007], [92.61100006, 11.90442085], [92.61096191, 11.90500927], [92.61093903, 11.90553093], [92.6108017, 11.90604877], [92.61055756, 11.90655041], [92.61035156, 11.90709019], [92.61044312, 11.90764618], [92.61062622, 11.9081707], [92.61081696, 11.90868092], [92.61097717, 11.90918922], [92.61128235, 11.90963554], [92.61132813, 11.91016483], [92.61125183, 11.91073036], [92.61136627, 11.91129112], [92.61144257, 11.91186142], [92.61149597, 11.91240978], [92.6116333, 11.91279697], [92.61166382, 11.91315269], [92.61164856, 11.91351128], [92.61154938, 11.91385937], [92.61135864, 11.91419029], [92.61109924, 11.91453171], [92.61078644, 11.91490841], [92.61039734, 11.91531086], [92.61005402, 11.91580582], [92.60982513, 11.91640282], [92.60965729, 11.9169817], [92.60945892, 11.91742611], [92.60926819, 11.91771984], [92.60912323, 11.91800976], [92.60896301, 11.91809177], [92.60856628, 11.91808033], [92.60809326, 11.91825104], [92.60756683, 11.91819191], [92.60713196, 11.91802979], [92.60639191, 11.91770935], [92.60600281, 11.91784763], [92.60599518, 11.91884232], [92.60611725, 11.91940022], [92.60632324, 11.91996956], [92.60645294, 11.92051697], [92.60648346, 11.92108154], [92.60634613, 11.92164326], [92.60616302, 11.92220974], [92.6060791, 11.92281628], [92.60600281, 11.92341328], [92.60620117, 11.92397022], [92.60642242, 11.92451191], [92.60665131, 11.92501068], [92.60687256, 11.92549038], [92.60719299, 11.92582035], [92.6075058, 11.92610073], [92.60782623, 11.92642021], [92.60807037, 11.92684078], [92.60832977, 11.92724037], [92.60852051, 11.92767143], [92.60871887, 11.92804241], [92.60890198, 11.92837143], [92.60907745, 11.9286871], [92.60915375, 11.92905426], [92.60916901, 11.92950344], [92.60916901, 11.93003178], [92.60920715, 11.93061066], [92.60940552, 11.93112755], [92.60949707, 11.93169117], [92.60970306, 11.93221092], [92.60983276, 11.93274403], [92.60996246, 11.93327141], [92.61000824, 11.93382168], [92.61009216, 11.93435097], [92.61029053, 11.93482971], [92.61049652, 11.93527031], [92.61051941, 11.93578243], [92.61048889, 11.93629074], [92.61049652, 11.93676853], [92.61068726, 11.93709087], [92.61074829, 11.93751717], [92.61075592, 11.93799973], [92.61083984, 11.93849945], [92.61096191, 11.93900013], [92.61110687, 11.93943977], [92.61129761, 11.93990993], [92.61149597, 11.94036102], [92.61155701, 11.9408989], [92.61142731, 11.94150829], [92.61138153, 11.94184017], [92.61159515, 11.94218922], [92.61160278, 11.94253063], [92.61138153, 11.94267178], [92.61123657, 11.94316006], [92.61096191, 11.94371128], [92.61048889, 11.94393921], [92.61009979, 11.94433975], [92.60964966, 11.94479179], [92.60919952, 11.9453001], [92.60889435, 11.9459362], [92.60865784, 11.94656277], [92.60856628, 11.94720078], [92.60837555, 11.94776821], [92.60836792, 11.94831276], [92.60852814, 11.94884396], [92.60864258, 11.94941235], [92.6088562, 11.94994926], [92.6089859, 11.95051003], [92.60913849, 11.95105934], [92.60916901, 11.95163059], [92.60917664, 11.95219898], [92.60923004, 11.95277309], [92.60930634, 11.95337009], [92.60936737, 11.95401096], [92.60920715, 11.95467186], [92.60907745, 11.95534039], [92.60900879, 11.95599079], [92.60925293, 11.95652008], [92.60971832, 11.95692635], [92.61024475, 11.9572134], [92.61103058, 11.95714188], [92.61116791, 11.95713997], [92.61151886, 11.95734978], [92.61193848, 11.95776463], [92.61221313, 11.957901], [92.6122818, 11.9581089], [92.6122818, 11.95839119], [92.6120224, 11.95852566], [92.61218262, 11.95885181], [92.6122818, 11.95929813], [92.6126709, 11.9597702], [92.61283112, 11.96028996], [92.61295319, 11.96070004], [92.61302185, 11.961092], [92.61300659, 11.96138763], [92.61305237, 11.96173], [92.61319733, 11.96210861], [92.6132431, 11.96248531], [92.61328888, 11.96281147], [92.61332703, 11.96321201], [92.61332703, 11.9636898], [92.61333466, 11.96424198], [92.61332703, 11.9648304], [92.61328125, 11.96542931], [92.61306763, 11.96588135], [92.61289215, 11.96629333], [92.6129303, 11.966712], [92.61302185, 11.96712971], [92.61305237, 11.96754932], [92.61294556, 11.96809101], [92.61264801, 11.96863365], [92.61251831, 11.96912193], [92.61241913, 11.96964836], [92.61251831, 11.9701128], [92.61260223, 11.97049999], [92.61264038, 11.97078991], [92.61270142, 11.97119999], [92.61270142, 11.97154045], [92.61271667, 11.9718504], [92.61258698, 11.97215652], [92.61250305, 11.97249222], [92.61239624, 11.97284126], [92.61222839, 11.97330761], [92.61207581, 11.97379112], [92.61222839, 11.97425175], [92.61228943, 11.97472095], [92.61231232, 11.97518158], [92.61234283, 11.9756403], [92.61247253, 11.97607517], [92.61267853, 11.97650433], [92.61261749, 11.97700119], [92.61258698, 11.97756577], [92.61257172, 11.97820377], [92.61264801, 11.97879028], [92.61264038, 11.97913074], [92.61250305, 11.97941875], [92.61234283, 11.97978115], [92.61222839, 11.9802103], [92.61212921, 11.9806242], [92.61197662, 11.98099136], [92.61194611, 11.9814291], [92.61194611, 11.98190975], [92.61194611, 11.98244953], [92.61194611, 11.98302174], [92.61196136, 11.98357964], [92.61206055, 11.98410034], [92.61222839, 11.98453999], [92.61241913, 11.98496246], [92.61252594, 11.98543072], [92.61268616, 11.98592567], [92.61275482, 11.98648357], [92.61278534, 11.9870224], [92.61283112, 11.9874754], [92.61299896, 11.9878006], [92.61305237, 11.98816586], [92.61306, 11.98853111], [92.61309814, 11.98889542], [92.61325836, 11.98920059], [92.61341095, 11.98952198], [92.61360168, 11.98984623], [92.61383057, 11.99020386], [92.61426544, 11.99035168], [92.61463928, 11.99044132], [92.6151123, 11.99049091], [92.61566925, 11.99055862], [92.61597443, 11.99056053], [92.61641693, 11.99059963], [92.6167984, 11.99084187], [92.61699677, 11.99121094], [92.61695862, 11.9914093], [92.6169281, 11.99168301], [92.61694336, 11.99202919], [92.61685944, 11.99242115], [92.61666107, 11.99276066], [92.61641693, 11.99304581], [92.61624908, 11.99334431], [92.61606598, 11.99363995], [92.61580658, 11.99392128], [92.61555481, 11.99422646], [92.61488342, 11.99468899], [92.61440277, 11.99510098], [92.61403656, 11.99545002], [92.6138382, 11.99606991], [92.6133728, 11.99759007], [92.61332703, 11.99785042], [92.61334229, 11.99814606], [92.61332703, 11.99831963], [92.61340332, 11.99889183], [92.61360931, 11.99999905], [92.61370087, 12.00055981], [92.61360931, 12.00111103], [92.61360168, 12.0022192], [92.61332703, 12.00249863], [92.6131897, 12.00300503], [92.61318207, 12.00360012], [92.61302185, 12.0041914], [92.61289978, 12.00470066], [92.61297607, 12.00526905], [92.61295319, 12.00596428], [92.61306, 12.00660038], [92.61329651, 12.00722027], [92.61348724, 12.00788116], [92.61380768, 12.00853539], [92.61412811, 12.00915241], [92.61436462, 12.00969219], [92.61451721, 12.01015091], [92.61467743, 12.01049709], [92.61476898, 12.01082325], [92.61493683, 12.01109886], [92.61509705, 12.01140594], [92.6151123, 12.01178932], [92.61502838, 12.01226139], [92.61496735, 12.01283073], [92.61487579, 12.01350117], [92.61486816, 12.01419067], [92.6151886, 12.01470661], [92.61550903, 12.01517105], [92.6157074, 12.01567078], [92.61573792, 12.01612186], [92.61576843, 12.01657104], [92.61592865, 12.01696968], [92.61604309, 12.01736164], [92.6159668, 12.01776981], [92.61592865, 12.01817989], [92.6160202, 12.01852608], [92.61608124, 12.01882935], [92.61611176, 12.01913738], [92.61612701, 12.01947212], [92.61621094, 12.01982975], [92.61638641, 12.0201807], [92.61660767, 12.02052975], [92.61678314, 12.02089024], [92.61695099, 12.0212698], [92.61712646, 12.02159023], [92.61720276, 12.02188969], [92.61717224, 12.02219105], [92.61698151, 12.02248955], [92.61683655, 12.02287006], [92.61670685, 12.02328968], [92.61666107, 12.0237999], [92.61666107, 12.02439976], [92.61672974, 12.02503967], [92.61694336, 12.02555466], [92.61722565, 12.02555466], [92.61750031, 12.02527714], [92.61805725, 12.02583313], [92.61833191, 12.02583313], [92.6186142, 12.02555466], [92.62055206, 12.02555466], [92.62194824, 12.02694321], [92.6222229, 12.02694321], [92.62249756, 12.02722073], [92.62249756, 12.0274992], [92.62277985, 12.02777672], [92.62278748, 12.0283289], [92.62249756, 12.02862072], [92.62249756, 12.02917004], [92.62233734, 12.02942085], [92.62214661, 12.02978992], [92.62190247, 12.03010178], [92.62159729, 12.03035069], [92.62120819, 12.03058147], [92.62081909, 12.03085041], [92.62043762, 12.03114986], [92.62017059, 12.03151989], [92.62001801, 12.03195286], [92.61991882, 12.03238964], [92.61976624, 12.03278923], [92.61972809, 12.03322506], [92.61978912, 12.03372097], [92.62111664, 12.0352211], [92.62166595, 12.03563118], [92.62188721, 12.03623104], [92.62194824, 12.03666592], [92.62194824, 12.03693867], [92.62149048, 12.03805161], [92.62089539, 12.03808784], [92.6202774, 12.03833199], [92.6202774, 12.03861046], [92.62000275, 12.03889275], [92.62000275, 12.03916645], [92.61972046, 12.03944397], [92.61972046, 12.03971958], [92.61984253, 12.03999996], [92.61988068, 12.04031944], [92.61973572, 12.04057693], [92.61968994, 12.04117203], [92.62010193, 12.04149055], [92.62055206, 12.04139137], [92.62166595, 12.04073048], [92.6222229, 12.04055595], [92.62277985, 12.04111004], [92.62314606, 12.04123974], [92.62333679, 12.04139137], [92.62403107, 12.04162979], [92.625, 12.04166603], [92.62527466, 12.04194355], [92.62555695, 12.04194355], [92.6258316, 12.04222012], [92.62610626, 12.04250145], [92.6269455, 12.04250145], [92.6277771, 12.04333019], [92.6277771, 12.04388905], [92.62770081, 12.04410458], [92.62750244, 12.04439926], [92.62750244, 12.04498005], [92.62750244, 12.04528141], [92.62741852, 12.04555511], [92.62750244, 12.04583263], [92.62750244, 12.0466671], [92.62722015, 12.04694462], [92.62722015, 12.04722118], [92.62695313, 12.04750061], [92.62695313, 12.04778099], [92.62610626, 12.04861069], [92.625, 12.04861069], [92.62473297, 12.04889107], [92.6241684, 12.04889107], [92.62388611, 12.04861069], [92.62333679, 12.04861069], [92.62304688, 12.04833126], [92.62249756, 12.04833126], [92.6222229, 12.04861069], [92.62166595, 12.04934025], [92.62133789, 12.05024147], [92.62166595, 12.05119133], [92.62156677, 12.05163097], [92.62164307, 12.05173969], [92.621521, 12.05202103], [92.62090302, 12.05245972], [92.62063599, 12.05285931], [92.62082672, 12.05362034], [92.6213913, 12.05416965], [92.62249756, 12.05416679], [92.62277985, 12.05444336], [92.6230545, 12.05444336], [92.62333679, 12.05472088], [92.62361145, 12.05472088], [92.62388611, 12.05499935], [92.62412262, 12.05485058], [92.62420654, 12.05526638], [92.62429047, 12.05576134], [92.62437439, 12.05626869], [92.62457275, 12.05646038], [92.62477875, 12.05672932], [92.62496948, 12.05707264], [92.62509155, 12.05751991], [92.62520599, 12.05799866], [92.62531281, 12.05844975], [92.62533569, 12.05891705], [92.62526703, 12.05944061], [92.62527466, 12.06055641], [92.62555695, 12.06083393], [92.62555695, 12.06193924], [92.62473297, 12.06278038], [92.62444305, 12.06278038], [92.6241684, 12.06306076], [92.62333679, 12.06306076], [92.62307739, 12.06297016], [92.62277985, 12.06304741], [92.6222229, 12.06333447], [92.62194824, 12.0633297], [92.6202774, 12.06499958], [92.62015533, 12.06548119], [92.6202774, 12.06694031], [92.6202774, 12.06750011], [92.62000275, 12.06779003], [92.62000275, 12.06787014], [92.62000275, 12.06833458], [92.61999512, 12.06882], [92.61994171, 12.06931019], [92.61975861, 12.06980896], [92.61963654, 12.07032204], [92.61952972, 12.07078457], [92.61959839, 12.0711813], [92.61968994, 12.07147121], [92.61972046, 12.07175827], [92.61972046, 12.07207203], [92.61972046, 12.07241154], [92.61974335, 12.07276058], [92.61979675, 12.07309055], [92.61995697, 12.07338142], [92.62004089, 12.07374954], [92.62011719, 12.07420063], [92.62034607, 12.07459068], [92.62050629, 12.07494164], [92.6206665, 12.0752306], [92.62078094, 12.07551193], [92.62082672, 12.0758009], [92.62082672, 12.07608986], [92.62078857, 12.0764389], [92.62069702, 12.07682037], [92.62069702, 12.07719135], [92.62077332, 12.07766056], [92.62084198, 12.07820129], [92.62090302, 12.07872963], [92.62107086, 12.07921124], [92.62119293, 12.07969189], [92.62135315, 12.08001995], [92.6213913, 12.08036423], [92.62140656, 12.08072186], [92.62166595, 12.08111095], [92.62166595, 12.08249855], [92.62194824, 12.0827713], [92.62194824, 12.08416462], [92.62166595, 12.08444118], [92.62166595, 12.08500195], [92.62194824, 12.08528042], [92.62194824, 12.08555603], [92.6222229, 12.08583164], [92.6222229, 12.08638954], [92.62194824, 12.08666801], [92.6222229, 12.08693886], [92.6222229, 12.08805561], [92.62194824, 12.08833408], [92.62194824, 12.08944416], [92.6222229, 12.08972168], [92.6222229, 12.09000015], [92.62249756, 12.09027958], [92.62249756, 12.09055614], [92.6230545, 12.09111214], [92.6230545, 12.09194374], [92.62333679, 12.09222031], [92.62304688, 12.09249973], [92.6230545, 12.09305573], [92.62278748, 12.09333038], [92.62277985, 12.0941658], [92.62304688, 12.09444046], [92.6230545, 12.09666729], [92.62333679, 12.09694004], [92.62333679, 12.09861088], [92.62361145, 12.09888935], [92.62361145, 12.09972095], [92.62388611, 12.10000134], [92.62388611, 12.10111141], [92.62361145, 12.10139084], [92.62361145, 12.1027813], [92.62388611, 12.103055], [92.62388611, 12.10333347], [92.6241684, 12.10363388], [92.62433624, 12.10407066], [92.62444305, 12.10451126], [92.62448883, 12.10496044], [92.62462616, 12.10539055], [92.62483978, 12.10581493], [92.62512207, 12.10632992], [92.62538147, 12.1068306], [92.6256485, 12.10717106], [92.62592316, 12.10750198], [92.62618256, 12.10794067], [92.62644958, 12.10844135], [92.62670135, 12.10886002], [92.62689972, 12.10916805], [92.62689209, 12.10962105], [92.62715149, 12.11002922], [92.62730408, 12.11029816], [92.62761688, 12.11050129], [92.62789154, 12.11058521], [92.62789154, 12.11075211], [92.62809753, 12.11112309], [92.62826538, 12.111413], [92.62876129, 12.11170197], [92.6291275, 12.11181068], [92.62958527, 12.11194992], [92.62983704, 12.11201191], [92.63012695, 12.11204243], [92.63034058, 12.11213684], [92.63062286, 12.11233139], [92.6309967, 12.11257267], [92.63143921, 12.11287975], [92.63166809, 12.1133337], [92.63194275, 12.11361027], [92.63194275, 12.11388969], [92.63222504, 12.11416626], [92.63223267, 12.11444187], [92.6324234, 12.11509132], [92.63250732, 12.11556053], [92.63262939, 12.11596203], [92.63250732, 12.11651802], [92.63282013, 12.11730194], [92.63290405, 12.1175909], [92.63301086, 12.11783981], [92.63309479, 12.11804485], [92.63323975, 12.11824989], [92.63340759, 12.11843872], [92.63365936, 12.11855984], [92.63391113, 12.11867237], [92.63405609, 12.11874866], [92.63437653, 12.11883068], [92.63463593, 12.11886978], [92.63485718, 12.11900043], [92.63521576, 12.11926556], [92.63536072, 12.11945057], [92.63542175, 12.11964035], [92.63546753, 12.11989117], [92.63552856, 12.12000942], [92.63569641, 12.12019634], [92.63587952, 12.12046146], [92.6359024, 12.12119007], [92.63580322, 12.12142944], [92.63566589, 12.12162971], [92.63553619, 12.12192154], [92.63522339, 12.12210178], [92.63477325, 12.12221146], [92.63427734, 12.12232018], [92.63387299, 12.12247086], [92.63342285, 12.12248039], [92.63292694, 12.12239075], [92.6324234, 12.12230015], [92.63191986, 12.12250137], [92.63153839, 12.12280846], [92.63166809, 12.12324429], [92.63188934, 12.12371063], [92.63195038, 12.12422085], [92.63196564, 12.12473011], [92.63197327, 12.12524033], [92.63205719, 12.125741], [92.63231659, 12.12621784], [92.63250732, 12.12684155], [92.63259125, 12.12742138], [92.63265991, 12.12789059], [92.63286591, 12.12832069], [92.63304901, 12.1288414], [92.63330841, 12.12938118], [92.63339996, 12.12997246], [92.63358307, 12.13034058], [92.63363647, 12.13062954], [92.63360596, 12.13114071], [92.63368225, 12.13171101], [92.63368225, 12.13211823], [92.63352203, 12.13261986], [92.6337204, 12.13306046], [92.63391113, 12.13344002], [92.63405609, 12.13375854], [92.63404846, 12.13411713], [92.63414764, 12.13450241], [92.63421631, 12.13490105], [92.6342926, 12.1353178], [92.6344223, 12.13566017], [92.6344223, 12.13601112], [92.6344986, 12.13637066], [92.63456726, 12.13670921], [92.63488007, 12.13716221], [92.63491821, 12.13739014], [92.63485718, 12.13778687], [92.6350174, 12.13798046], [92.63503265, 12.13833141], [92.63525391, 12.13899708], [92.63522339, 12.13933182], [92.63526154, 12.13978958], [92.63542938, 12.14038944], [92.63577271, 12.14079094], [92.63595581, 12.14120102], [92.63607025, 12.14162922], [92.63616943, 12.14202118], [92.63639069, 12.14229679], [92.63659668, 12.14247894], [92.63674927, 12.14266396], [92.63683319, 12.14293098], [92.63743591, 12.14307022], [92.63757324, 12.14358902], [92.63765717, 12.14406109], [92.63739777, 12.14437962], [92.63722992, 12.14477539], [92.63706207, 12.14517117], [92.63697052, 12.14566803], [92.63706207, 12.14620113], [92.63726044, 12.14668941], [92.63751221, 12.14708138], [92.63778687, 12.14743233], [92.63807678, 12.14781857], [92.63829041, 12.14832973], [92.63843536, 12.14891815], [92.63873291, 12.14939022], [92.63887787, 12.14977932], [92.63897705, 12.15019035], [92.63919067, 12.15063], [92.63957977, 12.1510601], [92.63977051, 12.15160275], [92.63996124, 12.15211105], [92.6398468, 12.15273952], [92.64003754, 12.1530571], [92.64026642, 12.15329361], [92.64044952, 12.15353107], [92.64054108, 12.15381622], [92.64057159, 12.1541214], [92.64066315, 12.15439892], [92.64080811, 12.15464115], [92.64091492, 12.15491676], [92.64105988, 12.15520191], [92.64111328, 12.15559101], [92.6411438, 12.15599537], [92.64126587, 12.15639114], [92.64137268, 12.15679741], [92.64139557, 12.15721416], [92.64144897, 12.15761089], [92.64161682, 12.15797138], [92.641716, 12.15833092], [92.64194489, 12.15862465], [92.64200592, 12.15896034], [92.64200592, 12.15933132], [92.64198303, 12.15972996], [92.64199829, 12.16024113], [92.64217377, 12.16078091], [92.64225006, 12.16134357], [92.6423645, 12.16187286], [92.64241028, 12.16234207], [92.64234924, 12.16283035], [92.64222717, 12.1633606], [92.64241028, 12.16392612], [92.64250183, 12.16453934], [92.64264679, 12.16514969], [92.64282227, 12.1657362], [92.64318085, 12.16617107], [92.64344788, 12.16658974], [92.64348602, 12.16711712], [92.64362335, 12.16764069], [92.64380646, 12.16819859], [92.64402008, 12.16877174], [92.64414215, 12.16937065], [92.64421082, 12.16996956], [92.64435577, 12.17053127], [92.6444397, 12.17108917], [92.6444931, 12.17164993], [92.64460754, 12.17219925], [92.64452362, 12.1727829], [92.64460754, 12.1733799], [92.6447525, 12.17389011], [92.64493561, 12.17433929], [92.64499664, 12.17479134], [92.64500427, 12.17526913], [92.64502716, 12.17579079], [92.64512634, 12.17636108], [92.64528656, 12.17695999], [92.64547729, 12.1776104], [92.64559174, 12.17837143], [92.64572906, 12.17916203], [92.64608765, 12.17969131], [92.64653778, 12.18013096], [92.64704132, 12.18052483], [92.64746857, 12.18099499], [92.647789, 12.18152142], [92.64807892, 12.18201637], [92.64836884, 12.18241215], [92.64865112, 12.18274021], [92.64892578, 12.18305016], [92.64920044, 12.1833601], [92.64948273, 12.18365192], [92.64968109, 12.18394089], [92.64972687, 12.18428993], [92.64972687, 12.18467999], [92.64971924, 12.18513775], [92.64977264, 12.18569183], [92.65001678, 12.18624973], [92.65029144, 12.18673801], [92.65057373, 12.18708229], [92.65080261, 12.18734169], [92.65098572, 12.18761063], [92.65124512, 12.18785477], [92.65141296, 12.18819046], [92.65158844, 12.18855], [92.65174866, 12.18896008], [92.65190887, 12.1894207], [92.6519928, 12.18997192], [92.6521759, 12.1905508], [92.65235901, 12.19119072], [92.65268707, 12.19170189], [92.65300751, 12.19218063], [92.65326691, 12.19268036], [92.65336609, 12.19325161], [92.65353394, 12.19376659], [92.65381622, 12.19415188], [92.65406036, 12.19447136], [92.65423584, 12.19476986], [92.65442657, 12.19503593], [92.65455627, 12.19539165], [92.6546936, 12.19583893], [92.65473175, 12.19641113], [92.65480042, 12.19708061], [92.65497589, 12.19775963], [92.65513611, 12.19843006], [92.65534973, 12.19895172], [92.65556335, 12.19937992], [92.65574646, 12.19976997], [92.6558609, 12.20015144], [92.65599823, 12.20044708], [92.65611267, 12.20071125], [92.65622711, 12.20096016], [92.6563797, 12.20120811], [92.65650177, 12.20148182], [92.65663147, 12.20177078], [92.65666199, 12.20216084], [92.65667725, 12.20263004], [92.65673828, 12.20316124], [92.65693665, 12.20366096], [92.65714264, 12.20414066], [92.65727234, 12.20464516], [92.65748596, 12.20507431], [92.65771484, 12.20548439], [92.6579361, 12.20586014], [92.65809631, 12.20621777], [92.65825653, 12.20649147], [92.6583786, 12.20676899], [92.65854645, 12.20701122], [92.65868378, 12.20727825], [92.65883636, 12.20753956], [92.6588974, 12.20788193], [92.65896606, 12.2082119], [92.65914917, 12.20850086], [92.65934753, 12.20877934], [92.65961456, 12.20904446], [92.65990448, 12.20929241], [92.66004944, 12.20963192], [92.66023254, 12.20997143], [92.66026306, 12.21040154], [92.66031647, 12.21108055], [92.6603241, 12.21164227], [92.66036987, 12.21170139], [92.66059875, 12.21199131], [92.66085052, 12.21238136], [92.66110229, 12.2127018], [92.66139984, 12.21310997], [92.66162872, 12.21341991], [92.66191864, 12.21385098], [92.66203308, 12.21439075], [92.66188049, 12.21488953], [92.6619873, 12.21550655], [92.66223907, 12.21592045], [92.66249084, 12.21631241], [92.66274261, 12.21658134], [92.66313934, 12.21687031], [92.66359711, 12.21724415], [92.66389465, 12.21750927], [92.66414642, 12.2176199], [92.66458893, 12.2176199], [92.66490173, 12.2175312], [92.66516113, 12.21730328], [92.66549683, 12.21709442], [92.66555786, 12.21670628], [92.6655426, 12.21629238], [92.66543579, 12.21586132], [92.66530609, 12.21544075], [92.66522217, 12.21498108], [92.66503143, 12.214571], [92.66493988, 12.21415138], [92.66475677, 12.21384144], [92.66467285, 12.21348953], [92.66451263, 12.21321487], [92.6644516, 12.21288204], [92.66442871, 12.21251965], [92.66435242, 12.21214294], [92.66418457, 12.21173954], [92.66403198, 12.21125031], [92.66387177, 12.21070957], [92.6636734, 12.21015167], [92.66353607, 12.20952034], [92.66336823, 12.20892143], [92.66333771, 12.20831013], [92.66333008, 12.20773602], [92.66329193, 12.20719147], [92.66309357, 12.2067194], [92.66279602, 12.2062912], [92.6625061, 12.20583534], [92.66221619, 12.20536137], [92.66194153, 12.20489597], [92.66169739, 12.20444012], [92.66156006, 12.20394135], [92.66137695, 12.20350075], [92.66117859, 12.20309067], [92.66110229, 12.2026186], [92.66100311, 12.20213127], [92.66086578, 12.20162106], [92.66078949, 12.20106888], [92.66057587, 12.20057011], [92.66033936, 12.20009136], [92.66004944, 12.19972038], [92.65981293, 12.1994009], [92.65962982, 12.19907856], [92.65940094, 12.19884491], [92.65918732, 12.19858456], [92.65904236, 12.19820881], [92.65888214, 12.19777107], [92.65870667, 12.1973114], [92.65859222, 12.19685459], [92.65841675, 12.19644928], [92.65830994, 12.19603539], [92.65815735, 12.19561958], [92.65801239, 12.19517326], [92.65779877, 12.19469929], [92.65763092, 12.19416142], [92.6574707, 12.19361019], [92.65722656, 12.19310093], [92.65705109, 12.19260216], [92.65690613, 12.19212437], [92.65670013, 12.19172859], [92.65657806, 12.19132137], [92.65638733, 12.19097519], [92.65618134, 12.19060135], [92.65605164, 12.19012737], [92.65583038, 12.18967056], [92.65561676, 12.18918133], [92.65556335, 12.18857956], [92.65550232, 12.18799114], [92.65530396, 12.18747902], [92.65516663, 12.18696976], [92.65502167, 12.18647957], [92.65493011, 12.18597031], [92.65471649, 12.18550968], [92.65448761, 12.18506145], [92.65437317, 12.18455029], [92.65420532, 12.18413258], [92.6541214, 12.18365383], [92.65393066, 12.18322086], [92.65389252, 12.18276978], [92.65396118, 12.18238258], [92.65418243, 12.18211079], [92.65445709, 12.18193054], [92.65475464, 12.18179703], [92.65512085, 12.18169022], [92.65548706, 12.18171024], [92.65582275, 12.18188953], [92.65618134, 12.18196106], [92.6565094, 12.18207455], [92.65681458, 12.1821928], [92.65712738, 12.18223], [92.65738678, 12.18229103], [92.65760803, 12.18244553], [92.65783691, 12.18256855], [92.65804291, 12.18274879], [92.65825653, 12.18292522], [92.65838623, 12.18321037], [92.65854645, 12.18349934], [92.65863037, 12.18384075], [92.65873718, 12.1841507], [92.65886688, 12.18445015], [92.65894318, 12.184762], [92.65898132, 12.18506718], [92.65891266, 12.1853838], [92.65882874, 12.18568039], [92.658638, 12.18591976], [92.65841675, 12.18618202], [92.65820313, 12.18651009], [92.65792847, 12.18682861], [92.6578064, 12.18719196], [92.65785217, 12.18754005], [92.65804291, 12.1878109], [92.65821075, 12.18805981], [92.65838623, 12.18828964], [92.658638, 12.18848801], [92.65892792, 12.18866158], [92.65917969, 12.18887997], [92.65944672, 12.18908119], [92.65972137, 12.1892767], [92.65998077, 12.18950462], [92.66021729, 12.18978119], [92.66040802, 12.19012928], [92.66059875, 12.19047642], [92.66082001, 12.19079304], [92.66098785, 12.1911211], [92.66113281, 12.19145775], [92.66130066, 12.19175243], [92.66137695, 12.19207954], [92.66143036, 12.19243145], [92.66156769, 12.19272137], [92.66166687, 12.1930809], [92.66174316, 12.19352055], [92.66191101, 12.19401073], [92.66201019, 12.19455147], [92.66217804, 12.19505024], [92.66226959, 12.19555092], [92.6624527, 12.19595718], [92.66259766, 12.19635963], [92.66275024, 12.19677067], [92.66282654, 12.19723606], [92.66299438, 12.19767094], [92.66311646, 12.19817162], [92.66333771, 12.19863319], [92.66356659, 12.19911098], [92.66371155, 12.19966125], [92.66391754, 12.20016193], [92.66416931, 12.2006197], [92.66443634, 12.20107079], [92.66468048, 12.20154762], [92.66487122, 12.2020607], [92.66506958, 12.20253658], [92.6654129, 12.20290184], [92.66578674, 12.203269], [92.66623688, 12.20353127], [92.66677856, 12.20366669], [92.66723633, 12.20389271], [92.66763306, 12.20415306], [92.66799927, 12.20440102], [92.66831207, 12.20469761], [92.66860962, 12.20498943], [92.66889954, 12.20528984], [92.66915894, 12.2055912], [92.66934967, 12.20590782], [92.66944885, 12.20627022], [92.66956329, 12.20663929], [92.66969299, 12.20704079], [92.66977692, 12.20753956], [92.66996765, 12.20807076], [92.67005157, 12.20864964], [92.67028046, 12.20913506], [92.67056274, 12.20957947], [92.67082977, 12.21003532], [92.67111206, 12.21052074], [92.67138672, 12.21103764], [92.67166901, 12.21152973], [92.67193604, 12.21197033], [92.67220306, 12.2123394], [92.67240906, 12.21269035], [92.67260742, 12.21307087], [92.67279053, 12.21348953], [92.67299652, 12.21395111], [92.67317963, 12.21445179], [92.67333984, 12.2149601], [92.67350769, 12.21546173], [92.67365265, 12.21596146], [92.67384338, 12.2164011], [92.67392731, 12.21689129], [92.67409515, 12.21738815], [92.67414856, 12.21798038], [92.67471313, 12.21841145], [92.67537689, 12.21860027], [92.67594147, 12.21848202], [92.67634583, 12.21816254], [92.67671204, 12.21774578], [92.67708588, 12.21734047], [92.6774292, 12.21687317], [92.67766571, 12.21630955], [92.67776489, 12.21566868], [92.67778015, 12.2149992], [92.67775726, 12.21431065], [92.67764282, 12.21363163], [92.67752075, 12.21295929], [92.67749786, 12.21228027], [92.67749786, 12.21165562], [92.67749786, 12.2111063], [92.67749786, 12.21064186], [92.67749786, 12.21019936], [92.67750549, 12.20975971], [92.6775589, 12.20928955], [92.67765808, 12.2088089], [92.67759705, 12.208251], [92.67756653, 12.20767021], [92.67752075, 12.20708179], [92.67745972, 12.20648193], [92.67733002, 12.20594025], [92.67724609, 12.20545197], [92.67723083, 12.20498943], [92.67726898, 12.20458126], [92.67749786, 12.20416737], [92.67778015, 12.20417118], [92.67804718, 12.2038908], [92.6783371, 12.20388794], [92.6791687, 12.20471954], [92.6791687, 12.20570946], [92.6791687, 12.20583344], [92.6791687, 12.20600128], [92.67916107, 12.20627022], [92.67913055, 12.20652294], [92.67923737, 12.20683098], [92.67942047, 12.20718575], [92.67944336, 12.20752144], [92.679245, 12.20790005], [92.6789856, 12.20839214], [92.67890167, 12.2088623], [92.67896271, 12.20930099], [92.67916107, 12.20972538], [92.67935944, 12.21023369], [92.67944336, 12.21084023], [92.67945099, 12.21148682], [92.67948151, 12.21208191], [92.67961884, 12.21252155], [92.67972565, 12.21288395], [92.67984772, 12.21317959], [92.67997742, 12.21347713], [92.68009949, 12.21382523], [92.68041992, 12.21414471], [92.68112183, 12.21419525], [92.68154907, 12.2141037], [92.68197632, 12.21401215], [92.68240356, 12.21397781], [92.68283081, 12.21395111], [92.68319702, 12.21372986], [92.68338776, 12.21341991], [92.68356323, 12.21312141], [92.68366241, 12.21277046], [92.68385315, 12.21247196], [92.6838913, 12.21212101], [92.6838913, 12.21177197], [92.6838913, 12.2114296], [92.6838913, 12.21109295], [92.68388367, 12.2107172], [92.68383789, 12.21028137], [92.68366241, 12.20980072], [92.6836319, 12.20925999], [92.68371582, 12.20876122], [92.68398285, 12.20841026], [92.68427277, 12.20822144], [92.68449402, 12.20815277], [92.68467712, 12.20831013], [92.68482208, 12.20853806], [92.68496704, 12.20874119], [92.685112, 12.20901203], [92.6852417, 12.20936108], [92.68527222, 12.20981026], [92.68531036, 12.21030426], [92.68544769, 12.21076012], [92.68572235, 12.21115017], [92.68599701, 12.21155071], [92.68624115, 12.21199131], [92.68641663, 12.21245098], [92.68662262, 12.21284962], [92.68669128, 12.21332169], [92.68682098, 12.21377087], [92.68694305, 12.21425629], [92.68701935, 12.21477127], [92.68696594, 12.2152977], [92.68694305, 12.21583271], [92.68692017, 12.21634197], [92.68681335, 12.21679974], [92.68664551, 12.21718693], [92.68641663, 12.21750164], [92.68630219, 12.21784115], [92.68612671, 12.21808147], [92.68597412, 12.2183342], [92.68577576, 12.21859264], [92.68548584, 12.21889019], [92.68516541, 12.21928883], [92.68502808, 12.21990204], [92.68501282, 12.22056866], [92.68502808, 12.22117996], [92.68517303, 12.22168159], [92.68530273, 12.2221489], [92.68546295, 12.22258186], [92.68554688, 12.22305107], [92.68560791, 12.22355747], [92.68578339, 12.22406101], [92.68585968, 12.22467041], [92.68596649, 12.22528267], [92.68612671, 12.22592068], [92.68634033, 12.22651958], [92.68651581, 12.22713089], [92.68681335, 12.22762108], [92.68714905, 12.22799015], [92.68746185, 12.22832108], [92.68773651, 12.22855091], [92.68798065, 12.22869015], [92.6881485, 12.22886086], [92.68828583, 12.22904778], [92.6883316, 12.22931194], [92.68834686, 12.22964001], [92.68834686, 12.23006725], [92.68834686, 12.23060036], [92.68834686, 12.23117733], [92.68833923, 12.23168468], [92.68833923, 12.23212242], [92.68833923, 12.23252106], [92.68840027, 12.23291969], [92.68856812, 12.23330975], [92.68865204, 12.23374462], [92.68884277, 12.23420143], [92.6889801, 12.23478889], [92.68939209, 12.23534966], [92.69008636, 12.2354908], [92.6906662, 12.23536968], [92.69108582, 12.23550034], [92.69139862, 12.23573875], [92.69167328, 12.23600101], [92.69192505, 12.23627472], [92.69211578, 12.23657131], [92.69224548, 12.23688793], [92.69242096, 12.23717117], [92.69252014, 12.23755074], [92.69268799, 12.23797131], [92.69287109, 12.23840809], [92.69314575, 12.23878193], [92.69355011, 12.23902416], [92.69415283, 12.23905087], [92.69471741, 12.2391901], [92.69522095, 12.23939133], [92.695755, 12.23944473], [92.69634247, 12.23949337], [92.69694519, 12.23966408], [92.69757843, 12.23965263], [92.69815063, 12.23949146], [92.69867706, 12.23946095], [92.69915009, 12.23940182], [92.69950867, 12.239151], [92.6998291, 12.2387619], [92.70007324, 12.23826218], [92.70028687, 12.23773575], [92.70050049, 12.23724079], [92.70059204, 12.23674202], [92.700737, 12.23634148], [92.70082092, 12.23596287], [92.7008667, 12.23560905], [92.70102692, 12.23533058], [92.7011261, 12.23500061], [92.70127869, 12.23468018], [92.70141602, 12.23431015], [92.70158386, 12.23396587], [92.70176697, 12.2336607], [92.70199585, 12.2334404], [92.70226288, 12.23331356], [92.7025528, 12.23315716], [92.70289612, 12.23302937], [92.70327759, 12.23286343], [92.70371246, 12.23275089], [92.70410156, 12.23254204], [92.70444489, 12.23224545], [92.70477295, 12.23190117], [92.70511627, 12.23153877], [92.70542908, 12.2311306], [92.70570374, 12.23073673], [92.70581818, 12.23029041], [92.70584869, 12.22982025], [92.70591736, 12.22939873], [92.70609283, 12.22904968], [92.70619202, 12.22870064], [92.7063446, 12.228405], [92.70639038, 12.22807026], [92.70639038, 12.22770786], [92.70633698, 12.22729969], [92.7061615, 12.22688484], [92.70615387, 12.22638416], [92.70632172, 12.22587109], [92.7064209, 12.22531891], [92.70656586, 12.22482872], [92.70655823, 12.22437096], [92.7064209, 12.22392178], [92.70639038, 12.22342968], [92.70642853, 12.2229557], [92.70662689, 12.22249985], [92.70679474, 12.22202587], [92.70706177, 12.22161961], [92.70727539, 12.22116375], [92.70749664, 12.22073078], [92.70765686, 12.2203207], [92.70751953, 12.21995163], [92.70745087, 12.21953011], [92.70726776, 12.21914959], [92.70722961, 12.21870136], [92.70728302, 12.21824932], [92.70748138, 12.21788025], [92.70769501, 12.21761131], [92.70796967, 12.21748066], [92.70822906, 12.21734047], [92.70854187, 12.21724033], [92.70892334, 12.21716022], [92.70926666, 12.21693039], [92.70955658, 12.21660137], [92.70970154, 12.21617126], [92.7097168, 12.21568966], [92.70972443, 12.21523571], [92.7097168, 12.21481037], [92.70972443, 12.21442509], [92.7097168, 12.21404934], [92.7097168, 12.21369076], [92.70976257, 12.2133007], [92.70992279, 12.21294117], [92.71002197, 12.21254539], [92.71018219, 12.21217537], [92.71026611, 12.21181107], [92.71028137, 12.21146202], [92.71028137, 12.21111965], [92.71028137, 12.21078491], [92.71028137, 12.21041965], [92.71028137, 12.21000957], [92.71028137, 12.20957279], [92.71028137, 12.20911694], [92.71026611, 12.20864964], [92.71021271, 12.20818043], [92.71003723, 12.2077198], [92.70993805, 12.20720005], [92.70974731, 12.20673275], [92.70965576, 12.20628643], [92.70950317, 12.20595074], [92.70944977, 12.20557976], [92.70942688, 12.20523071], [92.70935059, 12.20489597], [92.70928192, 12.20452023], [92.70918274, 12.20409393], [92.70913696, 12.2036171], [92.70900726, 12.20317078], [92.70890808, 12.20273972], [92.70889282, 12.20232964], [92.70889282, 12.20195103], [92.70886993, 12.20157146], [92.70876312, 12.2011652], [92.70862579, 12.20069981], [92.70848083, 12.20018005], [92.70823669, 12.19976997], [92.70792389, 12.19947147], [92.70758057, 12.19925022], [92.70726776, 12.19906139], [92.70701599, 12.19882202], [92.70685577, 12.1985302], [92.70678711, 12.19826126], [92.70691681, 12.19795132], [92.70703125, 12.19760036], [92.70722961, 12.19724941], [92.70750427, 12.19688034], [92.70778656, 12.19648075], [92.70807648, 12.19608021], [92.70836639, 12.19566059], [92.70870972, 12.19530106], [92.70907593, 12.19497013], [92.70942688, 12.19460106], [92.7097168, 12.19421959], [92.70999908, 12.19381714], [92.71026611, 12.19343185], [92.7105484, 12.19306946], [92.71083832, 12.19275856], [92.71113586, 12.19248104], [92.71144867, 12.19220066], [92.71175385, 12.19187069], [92.71205139, 12.19153118], [92.71224976, 12.19106102], [92.71244812, 12.19059181], [92.71248627, 12.19007206], [92.71242523, 12.18959141], [92.7122345, 12.1892271], [92.7120285, 12.18892097], [92.71173859, 12.1887207], [92.71142578, 12.18862724], [92.7110672, 12.18861103], [92.71072388, 12.18861103], [92.71037292, 12.1885891], [92.71000671, 12.18844986], [92.70959473, 12.18819904], [92.709198, 12.18781567], [92.70886993, 12.18725967], [92.70856476, 12.18664742], [92.70832062, 12.18600178], [92.70804596, 12.18540001], [92.70778656, 12.18487072], [92.7075882, 12.18437004], [92.70746613, 12.18387985], [92.70722961, 12.18347168], [92.70703125, 12.18307972], [92.70677948, 12.18272018], [92.70656586, 12.18227959], [92.70630646, 12.18185139], [92.70607758, 12.18135929], [92.70583344, 12.18084431], [92.70561218, 12.1803093], [92.70552063, 12.17969131], [92.70536041, 12.17910099], [92.70523071, 12.17854214], [92.70504761, 12.17806053], [92.70500183, 12.17755127], [92.70500183, 12.17703342], [92.70500183, 12.17649078], [92.70500183, 12.1759119], [92.70495605, 12.1753149], [92.70476532, 12.17476082], [92.70472717, 12.17420292], [92.70471954, 12.17369366], [92.70471954, 12.17324257], [92.70471954, 12.17281914], [92.70471954, 12.17239094], [92.70475006, 12.17195988], [92.70485687, 12.17153168], [92.70493317, 12.17113972], [92.70475006, 12.17079067], [92.70458984, 12.1704216], [92.70439911, 12.17008209], [92.7041626, 12.16975212], [92.7039032, 12.16938496], [92.70368958, 12.16893959], [92.70358276, 12.16839123], [92.70337677, 12.16786385], [92.70335388, 12.16732693], [92.70346832, 12.16679096], [92.70358276, 12.16629219], [92.70362091, 12.16582012], [92.70371246, 12.16543007], [92.70394897, 12.16520691], [92.70417023, 12.16503143], [92.70458984, 12.16504097], [92.70472717, 12.16522121], [92.70487976, 12.16543865], [92.70503235, 12.16572189], [92.70516205, 12.16608047], [92.70507813, 12.16660023], [92.70513916, 12.1669302], [92.70539093, 12.16719723], [92.70568085, 12.16740227], [92.70610046, 12.16769123], [92.70665741, 12.16837978], [92.70687103, 12.16897202], [92.70678711, 12.16958141], [92.70675659, 12.1700592], [92.70694733, 12.17037106], [92.70742798, 12.17070198], [92.70786285, 12.17103004], [92.70832825, 12.1713562], [92.7089386, 12.17175007], [92.70952606, 12.1721611], [92.70994568, 12.172575], [92.71044922, 12.17305183], [92.71118927, 12.17370796], [92.71147919, 12.1741457], [92.71179962, 12.17457199], [92.71196747, 12.17504597], [92.71214294, 12.17531013], [92.7123642, 12.17554092], [92.71274567, 12.17564297], [92.7130127, 12.17556095], [92.71318054, 12.17519188], [92.71299744, 12.17467022], [92.71305084, 12.17429638], [92.7130661, 12.17391109], [92.71305084, 12.17350292], [92.71300507, 12.17304325], [92.71282196, 12.17253208], [92.71282196, 12.1719532], [92.71302795, 12.1713562], [92.71335602, 12.17085934], [92.71349335, 12.17022324], [92.71304321, 12.16954613], [92.71259308, 12.16917038], [92.71218109, 12.1688509], [92.7119751, 12.16852283], [92.71194458, 12.16819], [92.71195984, 12.16787148], [92.71211243, 12.16770267], [92.71239471, 12.16743088], [92.71237183, 12.1669054], [92.71228027, 12.16633129], [92.71244812, 12.16594124], [92.71246338, 12.16549015], [92.71298218, 12.16498756], [92.71328735, 12.16509056], [92.7135849, 12.16525936], [92.71379852, 12.1656723], [92.71405792, 12.16625118], [92.71446991, 12.16647625], [92.71474457, 12.16688442], [92.7148819, 12.16725063], [92.71520996, 12.16787434], [92.71551514, 12.16832256], [92.71565247, 12.16896057], [92.7158432, 12.16957188], [92.71605682, 12.17010498], [92.71621704, 12.17064953], [92.71640015, 12.17116928], [92.71663666, 12.17163181], [92.71684265, 12.172122], [92.71704865, 12.17259979], [92.71724701, 12.1730814], [92.71750641, 12.17353725], [92.71772766, 12.17402267], [92.71776581, 12.17461109], [92.71778107, 12.17523479], [92.71784973, 12.17585278], [92.71813202, 12.1763134], [92.71852112, 12.17666435], [92.71891785, 12.17698097], [92.71928406, 12.17732525], [92.71967316, 12.17762375], [92.7199707, 12.1779747], [92.7201767, 12.17840481], [92.72026062, 12.1789093], [92.7203064, 12.17948055], [92.72051239, 12.18001938], [92.72115326, 12.18028069], [92.72161102, 12.18000126], [92.7219162, 12.17950153], [92.72223663, 12.17907143], [92.72254944, 12.17872047], [92.72289276, 12.17849922], [92.72323608, 12.17835999], [92.72360229, 12.17833042], [92.72396088, 12.17833328], [92.72431183, 12.1783638], [92.72464752, 12.17851257], [92.72503662, 12.17864037], [92.72540283, 12.17889118], [92.72556305, 12.17889118], [92.72583008, 12.17918015], [92.72611237, 12.17916679], [92.72666931, 12.17972279], [92.72693634, 12.17972088], [92.72721863, 12.18000126], [92.72777557, 12.18000126], [92.72789764, 12.18012238], [92.72805023, 12.18028069], [92.72833252, 12.18028069], [92.72860718, 12.18056202], [92.72916412, 12.18055534], [92.72944641, 12.18083286], [92.72972107, 12.18083286], [92.73000336, 12.18111134], [92.73110962, 12.18111134], [92.73139191, 12.18138885], [92.73221588, 12.18138885], [92.73249817, 12.18166924], [92.73332977, 12.18166733], [92.73361206, 12.18194485], [92.73527527, 12.18194485], [92.73555756, 12.18222332], [92.73666382, 12.18222332], [92.73694611, 12.18194485], [92.73722076, 12.18194485], [92.73777771, 12.18138885], [92.73805237, 12.18138885], [92.73832703, 12.18111134], [92.73860931, 12.18111134], [92.7388916, 12.18083286], [92.73972321, 12.18083286], [92.73999786, 12.18055534], [92.74333191, 12.18056202], [92.74360657, 12.18028069], [92.74388885, 12.18028069], [92.74611664, 12.17806053], [92.7463913, 12.17806053], [92.74666595, 12.17778111], [92.74694824, 12.17778111], [92.7472229, 12.17750072], [92.74749756, 12.17750072], [92.74777985, 12.17722034], [92.7480545, 12.17722321], [92.74833679, 12.17694473], [92.7491684, 12.17694473], [92.75055695, 12.17833328], [92.75055695, 12.1786108], [92.75097656, 12.17902756], [92.75222015, 12.18028069], [92.75250244, 12.18028069], [92.7527771, 12.18000126], [92.75305176, 12.18000126], [92.75389099, 12.17918015], [92.75417328, 12.17918015], [92.75498962, 12.17833042], [92.75527954, 12.17833328], [92.7555542, 12.17805672], [92.75583649, 12.17806053], [92.75611115, 12.17778111], [92.7563858, 12.17778111], [92.75723267, 12.17693996], [92.75722504, 12.17666626], [92.75749969, 12.17639065], [92.75749969, 12.17583179], [92.75722504, 12.17555428], [92.75723267, 12.17056084], [92.75749969, 12.17028046], [92.75749969, 12.16943932], [92.75722504, 12.16916561], [92.75720978, 12.16878986], [92.75701141, 12.16836071], [92.75699615, 12.16788006], [92.75717163, 12.16739273], [92.75722504, 12.16687775], [92.75727081, 12.16639042], [92.75745392, 12.16598225], [92.75753784, 12.16551495], [92.75769043, 12.16505909], [92.75775146, 12.16456032], [92.75765991, 12.16405773], [92.75746155, 12.16358185], [92.75723267, 12.16313076], [92.75699615, 12.16269112], [92.75683594, 12.16224194], [92.75666809, 12.16181087], [92.75652313, 12.16138458], [92.75634766, 12.16097927], [92.75611115, 12.16063023], [92.75588989, 12.16030025], [92.75582886, 12.15990067], [92.75580597, 12.1595211], [92.75576019, 12.15919018], [92.75572968, 12.1588707], [92.7557373, 12.15849018], [92.75556183, 12.15501881], [92.75550842, 12.15431023], [92.75533295, 12.15367889], [92.75526428, 12.15307713], [92.75517273, 12.15254021], [92.75500488, 12.15208435], [92.75483704, 12.15164757], [92.75466156, 12.15119934], [92.75439453, 12.15077114], [92.7541275, 12.15028095], [92.7538681, 12.1498003], [92.7536087, 12.14938068], [92.75337219, 12.14901066], [92.75319672, 12.1486311], [92.75298309, 12.14826393], [92.75276184, 12.14789486], [92.75253296, 12.14754105], [92.75240326, 12.14713097], [92.75223541, 12.14677334], [92.75209808, 12.14640617], [92.75195312, 12.14605999], [92.75182343, 12.14572525], [92.75169373, 12.14540386], [92.75164032, 12.14503384], [92.75149536, 12.14467239], [92.75136566, 12.14425278], [92.75115967, 12.14381313], [92.7509613, 12.14330673], [92.75078583, 12.14275074], [92.75055695, 12.14221001], [92.75038147, 12.1417017], [92.75046539, 12.14119244], [92.75054169, 12.14068127], [92.75051117, 12.14019108], [92.75032806, 12.13975143], [92.75020599, 12.13929081], [92.75, 12.13891029], [92.74977112, 12.13855457], [92.74957275, 12.13818073], [92.74942017, 12.13774967], [92.74921417, 12.13737583], [92.74906158, 12.13698006], [92.74888611, 12.13661098], [92.74865723, 12.13625717], [92.74849701, 12.13585186], [92.74830627, 12.13543034], [92.74809265, 12.13503075], [92.74791718, 12.1345892], [92.74776459, 12.13418102], [92.74758911, 12.13383484], [92.74745941, 12.13349533], [92.74726868, 12.13323116], [92.74711609, 12.13296604], [92.7469101, 12.13274097], [92.74669647, 12.13251019], [92.74651337, 12.1321907], [92.74635315, 12.13179016], [92.74611664, 12.1313982], [92.74590302, 12.13099003], [92.74577332, 12.13052082], [92.74559784, 12.13009167], [92.74550629, 12.12959957], [92.74532318, 12.12914181], [92.74523163, 12.12863064], [92.74504089, 12.12818241], [92.74494934, 12.1277113], [92.74478149, 12.12731171], [92.74472809, 12.12685108], [92.74469757, 12.1264019], [92.74459839, 12.12599182], [92.74446869, 12.12559795], [92.7444458, 12.12518978], [92.7444458, 12.12477684], [92.7444458, 12.12435055], [92.7444458, 12.12392044], [92.7444458, 12.12349033], [92.7444458, 12.12306976], [92.74442291, 12.1226511], [92.74433136, 12.12223244], [92.74420166, 12.12182617], [92.74414062, 12.12131977], [92.74401855, 12.12079144], [92.74386597, 12.12024021], [92.74360657, 12.11971092], [92.74333954, 12.11919117], [92.74301147, 12.11870956], [92.74263, 12.11828041], [92.7423172, 12.11779022], [92.74201965, 12.11730194], [92.74169922, 12.11684418], [92.7414093, 12.11634922], [92.7410965, 12.11584091], [92.74075317, 12.11533928], [92.7403183, 12.11491776], [92.73995209, 12.11450958], [92.73960876, 12.11418247], [92.73931885, 12.11388969], [92.73908234, 12.11362076], [92.7388382, 12.11334133], [92.73856354, 12.11304855], [92.73828125, 12.11270046], [92.73803711, 12.11225128], [92.73777771, 12.11179066], [92.7375412, 12.1113348], [92.73744202, 12.11081123], [92.73726654, 12.11035347], [92.73718262, 12.1098671], [92.73697662, 12.10945034], [92.73686981, 12.10898113], [92.73670959, 12.10857296], [92.73664093, 12.10807133], [92.73649597, 12.10758972], [92.73636627, 12.10709095], [92.73621368, 12.10660362], [92.73612976, 12.10604095], [92.7360611, 12.10540009], [92.73588562, 12.10476208], [92.73579407, 12.10407352], [92.73564911, 12.10344887], [92.73578644, 12.10291958], [92.73586273, 12.10242844], [92.73602295, 12.10202026], [92.73615265, 12.1015892], [92.73628998, 12.10114956], [92.73615265, 12.1006937], [92.73607635, 12.10020828], [92.7359314, 12.09979057], [92.73583984, 12.09937191], [92.73583221, 12.09895039], [92.73583221, 12.09850121], [92.73583221, 12.09806061], [92.73578644, 12.09764194], [92.73564148, 12.09727955], [92.7355423, 12.09685135], [92.73545074, 12.09640694], [92.73551941, 12.09589195], [92.73545837, 12.09533978], [92.73526764, 12.09480667], [92.73526001, 12.09427071], [92.73524475, 12.09375381], [92.73523712, 12.09311962], [92.73527527, 12.09261417], [92.7352829, 12.09214687], [92.7352829, 12.0916996], [92.7352829, 12.09125137], [92.7352829, 12.09080029], [92.73527527, 12.09035301], [92.7352829, 12.08989143], [92.7352829, 12.08939171], [92.7352829, 12.08883953], [92.73532867, 12.08824062], [92.73551178, 12.08763885], [92.73555756, 12.08697128], [92.73558807, 12.08630085], [92.73571014, 12.08567047], [92.73580933, 12.08507919], [92.73584747, 12.08450031], [92.7359314, 12.08396339], [92.73610687, 12.08347893], [92.73628998, 12.08302116], [92.73641968, 12.08256054], [92.7366333, 12.08218002], [92.73674774, 12.08176327], [92.73694611, 12.08137131], [92.73710632, 12.08092022], [92.73721313, 12.08039284], [92.73722076, 12.08027744], [92.73722076, 12.08000088], [92.73750305, 12.07973003], [92.73750305, 12.07944107], [92.73777771, 12.07916737], [92.73803711, 12.07883167], [92.73844147, 12.07855034], [92.73873138, 12.07831287], [92.73908997, 12.07802296], [92.73934174, 12.07773399], [92.73954773, 12.07742405], [92.73965454, 12.07713413], [92.73988342, 12.07672024], [92.74040985, 12.07608986], [92.74059296, 12.0756712], [92.74082947, 12.07506943], [92.74111176, 12.07472134], [92.74111176, 12.07416725], [92.7408371, 12.07389069], [92.7408371, 12.07250118], [92.74054718, 12.0722208], [92.74055481, 12.07194519], [92.73944092, 12.07083321], [92.73880005, 12.07075024], [92.73838043, 12.07090092], [92.73815155, 12.07094193], [92.73750305, 12.07083035], [92.73743439, 12.07067966], [92.73722076, 12.07028103], [92.7371521, 12.07014179], [92.73719788, 12.06984615], [92.73710632, 12.06941891], [92.73730469, 12.0688343], [92.73742676, 12.06854439], [92.73742676, 12.06817341], [92.73736572, 12.06794453], [92.73719788, 12.06763268], [92.73700714, 12.06742668], [92.73665619, 12.06721973], [92.73638916, 12.06722164], [92.73527527, 12.06611156], [92.73527527, 12.06527805], [92.73610687, 12.06444168], [92.7361145, 12.06416607], [92.73638916, 12.06389046], [92.73638916, 12.06361008], [92.73665619, 12.0633297], [92.73694611, 12.0633297], [92.73750305, 12.0638876], [92.73687744, 12.06429386], [92.73654175, 12.06464005], [92.73639679, 12.06499577], [92.73635101, 12.06530094], [92.73634338, 12.06562042], [92.73631287, 12.06576061], [92.73634338, 12.06593037], [92.73652649, 12.06627655], [92.73723602, 12.06706142], [92.73805237, 12.06711102], [92.73805237, 12.06721973], [92.73832703, 12.06750011], [92.73833466, 12.06777763], [92.73800659, 12.06855106], [92.73779297, 12.06902695], [92.73773193, 12.0694809], [92.73781586, 12.06985474], [92.73796082, 12.0701437], [92.7383194, 12.07016468], [92.73860931, 12.0701437], [92.7389679, 12.07018089], [92.73937225, 12.07023144], [92.73970032, 12.07031059], [92.74027252, 12.07054138], [92.74072266, 12.07091045], [92.74111176, 12.07111073], [92.7416687, 12.07166672], [92.7416687, 12.07194519], [92.74194336, 12.0722208], [92.74194336, 12.07305527], [92.74250031, 12.07359886], [92.74223328, 12.07389069], [92.74194336, 12.07389069], [92.7416687, 12.07416725], [92.74180603, 12.07430363], [92.74191284, 12.07441139], [92.74236298, 12.07439041], [92.74297333, 12.07428074], [92.74326324, 12.07415771], [92.74349976, 12.07392979], [92.74362183, 12.07374096], [92.74375153, 12.07364273], [92.7440033, 12.07349682], [92.74433899, 12.07332993], [92.74469757, 12.07299995], [92.74500275, 12.0722208], [92.7452774, 12.0722208], [92.74537659, 12.07246017], [92.7455368, 12.07252121], [92.74582672, 12.07250118], [92.74611664, 12.07239056], [92.74647522, 12.07225037], [92.74674988, 12.07211113], [92.74701691, 12.07192039], [92.74724579, 12.07185078], [92.747612, 12.07179737], [92.74794769, 12.07161045], [92.74859619, 12.07136059], [92.74871826, 12.07136059], [92.74893188, 12.07137966], [92.74908447, 12.07141399], [92.74916077, 12.07143021], [92.74941254, 12.07143021], [92.74989319, 12.07126141], [92.75039673, 12.07108974], [92.75083923, 12.07107162], [92.75111389, 12.07107162], [92.75159454, 12.07100964], [92.75184631, 12.07088947], [92.75226593, 12.07056141], [92.75250244, 12.07038975], [92.75302124, 12.07010078], [92.7532959, 12.06997967], [92.7536087, 12.06976986], [92.75372314, 12.069561], [92.75392914, 12.06927395], [92.75424194, 12.068964], [92.75470734, 12.06863308], [92.75499725, 12.06842804], [92.75546265, 12.06820011], [92.75580597, 12.06801128], [92.75623322, 12.06776524], [92.75646973, 12.06753922], [92.75681305, 12.06721115], [92.75691986, 12.06674099], [92.75726318, 12.06635189], [92.75750732, 12.06597996], [92.75773621, 12.0656662], [92.75788879, 12.06530094], [92.7580719, 12.0649004], [92.75827789, 12.06444645], [92.75829315, 12.06389046], [92.75808716, 12.06328869], [92.75791931, 12.06264973], [92.75772095, 12.06202984], [92.75743866, 12.06146145], [92.75708771, 12.06097984], [92.75674438, 12.06057644], [92.75641632, 12.06026173], [92.75614166, 12.05996132], [92.75591278, 12.05962086], [92.75576019, 12.05924511], [92.75554657, 12.05889034], [92.75528717, 12.05856609], [92.75498199, 12.05821133], [92.75461578, 12.05782986], [92.75413513, 12.05750942], [92.7536087, 12.05722237], [92.75311279, 12.0569458], [92.75267792, 12.05668354], [92.75229645, 12.05646038], [92.75196838, 12.05626678], [92.7517395, 12.0560503], [92.75166321, 12.05578995], [92.75165558, 12.05551434], [92.75171661, 12.05525017], [92.75193024, 12.05500793], [92.75222015, 12.05474186], [92.75260925, 12.05454063], [92.75306702, 12.05445004], [92.75356293, 12.05446625], [92.75401306, 12.05457115], [92.75441742, 12.05469608], [92.75483704, 12.05472088], [92.75525665, 12.05472374], [92.75567627, 12.05472374], [92.75609589, 12.05472088], [92.7565155, 12.05472088], [92.75691223, 12.05472088], [92.75720978, 12.05476475], [92.75744629, 12.05499935], [92.7576828, 12.05523014], [92.75784302, 12.05523014], [92.75839996, 12.05556679], [92.75972748, 12.05575371], [92.76032257, 12.05510426], [92.76055908, 12.05499935], [92.76111603, 12.05444145], [92.76117706, 12.05405426], [92.76142883, 12.05345631], [92.76156616, 12.05294991], [92.76143646, 12.05250359], [92.7614212, 12.05211353], [92.76154327, 12.05181313], [92.76172638, 12.05159855], [92.76190948, 12.05142117], [92.76210785, 12.05124092], [92.76236725, 12.05113411], [92.76272583, 12.051157], [92.76314545, 12.05138206], [92.76365662, 12.05163097], [92.7642746, 12.05185032], [92.76454163, 12.05186272], [92.76493073, 12.0518837], [92.76550293, 12.05160999], [92.76584625, 12.05109119], [92.76608276, 12.0505209], [92.76618195, 12.04996872], [92.76629639, 12.04950047], [92.76613617, 12.04912376], [92.76596832, 12.04875469], [92.76581573, 12.04842186], [92.76564789, 12.04812813], [92.76557159, 12.04781055], [92.76563263, 12.04747963], [92.76583862, 12.04718399], [92.7661438, 12.04688835], [92.76657104, 12.04665089], [92.76708984, 12.0464592], [92.76767731, 12.04657078], [92.76829529, 12.04674911], [92.76883698, 12.04695892], [92.76931763, 12.0472002], [92.76981354, 12.04738903], [92.77030945, 12.04741383], [92.77072906, 12.04721355], [92.77110291, 12.04697514], [92.771492, 12.04683113], [92.77184296, 12.04669189], [92.77220154, 12.0466671], [92.77256775, 12.04668713], [92.77289581, 12.04680061], [92.77327728, 12.04697037], [92.77363586, 12.04722118], [92.77407837, 12.04750061], [92.77453613, 12.04781055], [92.77495575, 12.04820538], [92.77527618, 12.04866123], [92.77555847, 12.0490799], [92.77581787, 12.04942703], [92.77607727, 12.04971886], [92.77638245, 12.0499897], [92.77677155, 12.05019283], [92.7772522, 12.05029964], [92.77774811, 12.05048943], [92.77829742, 12.05055046], [92.77884674, 12.0505619], [92.77941895, 12.05050945], [92.77993011, 12.05030727], [92.7804184, 12.05009174], [92.78079987, 12.04973507], [92.78108978, 12.04932022], [92.78134155, 12.04894066], [92.78193665, 12.04833126], [92.78277588, 12.04833317], [92.78360748, 12.0474987], [92.78360748, 12.04693985], [92.78333282, 12.0466671], [92.78333282, 12.04611111], [92.78304291, 12.04568005], [92.78276825, 12.04531097], [92.78253937, 12.04485703], [92.78233337, 12.04427147], [92.78206635, 12.04378128], [92.78185272, 12.04343987], [92.78194427, 12.0433321], [92.78138733, 12.04277897], [92.78138733, 12.04250145], [92.77999878, 12.04111004], [92.77971649, 12.04111004], [92.77944183, 12.04082966], [92.77916718, 12.04111004], [92.7783432, 12.04111004], [92.77805328, 12.04139137], [92.77749634, 12.04139137], [92.77722168, 12.04111004], [92.77694702, 12.04111004], [92.77694702, 12.04056072], [92.7766571, 12.0402813], [92.77694702, 12.03999996], [92.77694702, 12.03971958], [92.77722168, 12.03944397], [92.77639008, 12.03861237], [92.77639008, 12.0377779], [92.77657318, 12.03765106], [92.77658844, 12.03701019], [92.77639008, 12.03650188], [92.7762146, 12.0361166], [92.77612305, 12.03578186], [92.77610016, 12.03541946], [92.77610016, 12.03503036], [92.77607727, 12.03464222], [92.77593231, 12.03425026], [92.77584839, 12.0338192], [92.77578735, 12.0333786], [92.77560425, 12.03299046], [92.77555847, 12.03277969], [92.77555847, 12.03250027], [92.77583313, 12.03222179], [92.77565002, 12.03174973], [92.77562714, 12.03142166], [92.77565002, 12.03119183], [92.77568817, 12.03090191], [92.77572632, 12.03078079], [92.77587891, 12.03057194], [92.77623749, 12.03024101], [92.77654266, 12.0300293], [92.77709198, 12.02974415], [92.77749634, 12.02944565], [92.77749634, 12.02916527], [92.77722168, 12.02888966], [92.77722168, 12.02862072], [92.77745056, 12.0281601], [92.77749634, 12.02805996], [92.77749634, 12.02777958], [92.77777863, 12.0274992], [92.77805328, 12.0274992], [92.7783432, 12.02722073], [92.77861023, 12.02722359], [92.77889252, 12.02694321], [92.77889252, 12.02666664], [92.77915955, 12.02639198], [92.77915955, 12.02528191], [92.77889252, 12.02500057], [92.77889252, 12.02472115], [92.77861023, 12.02444458], [92.77861023, 12.02416706], [92.77805328, 12.02361107], [92.77749634, 12.02361107], [92.77722168, 12.02389145], [92.77694702, 12.02389145], [92.7766571, 12.02417183], [92.77632141, 12.02434731], [92.77590179, 12.02447033], [92.77580261, 12.0244894], [92.77542114, 12.02455044], [92.77478027, 12.02448177], [92.77427673, 12.02454567], [92.77416992, 12.02472115], [92.77388763, 12.02500057], [92.77361298, 12.02500057], [92.77333069, 12.02528191], [92.77278137, 12.02528191], [92.77249908, 12.02500057], [92.7722168, 12.02500057], [92.77199554, 12.02477074], [92.77194214, 12.02472115], [92.77166748, 12.02472115], [92.77139282, 12.02500057], [92.77111053, 12.02500057], [92.77083588, 12.02528191], [92.77054596, 12.02528191], [92.77008057, 12.02480793], [92.76999664, 12.02472115], [92.76972198, 12.02472115], [92.76944733, 12.02500057], [92.76944733, 12.02527714], [92.76889038, 12.02583313], [92.76777649, 12.02583313], [92.76734161, 12.02579689], [92.766922, 12.02582359], [92.76660156, 12.02548885], [92.76624298, 12.02534103], [92.76579285, 12.02539063], [92.76517487, 12.02550697], [92.76496887, 12.02589512], [92.76477051, 12.02587223], [92.76459503, 12.0256443], [92.76451874, 12.02529526], [92.76460266, 12.02488136], [92.76490784, 12.02441978], [92.76546478, 12.02402782], [92.76552582, 12.02373886], [92.76539612, 12.02344894], [92.7651825, 12.02310085], [92.76499939, 12.0227766], [92.76442719, 12.02238941], [92.76416016, 12.02222061], [92.76269531, 12.02139091], [92.76222229, 12.02083302], [92.76194763, 12.02055454], [92.76166534, 12.02055454], [92.76139069, 12.02083302], [92.7611084, 12.02083302], [92.76083374, 12.02111053], [92.76055908, 12.02111053], [92.76027679, 12.02139091], [92.75971985, 12.02139091], [92.75945282, 12.02166939], [92.75888824, 12.02166653], [92.75782776, 12.02233028], [92.75750732, 12.02270222], [92.75723267, 12.02313042], [92.75699615, 12.02359962], [92.75695801, 12.02413082], [92.75702667, 12.02460003], [92.75694275, 12.02472115], [92.75722504, 12.02499866], [92.75723267, 12.02583122], [92.75666809, 12.02639198], [92.75498962, 12.02639198], [92.75457001, 12.02646923], [92.75418854, 12.02668095], [92.75389862, 12.02700901], [92.75367737, 12.02738094], [92.75361633, 12.02783203], [92.7536087, 12.02826977], [92.75356293, 12.02869129], [92.75327301, 12.02906132], [92.75321198, 12.02950954], [92.75322723, 12.0299902], [92.75321198, 12.0306263], [92.75325775, 12.03125954], [92.75332642, 12.03139019], [92.7536087, 12.03168201], [92.7536087, 12.03222179], [92.75328827, 12.03283882], [92.75324249, 12.03301525], [92.75332642, 12.03333187], [92.75333405, 12.03416634], [92.75305176, 12.03444386], [92.75250244, 12.03388786], [92.75250244, 12.03333187], [92.7519455, 12.03277779], [92.75154114, 12.03253174], [92.75112152, 12.03232384], [92.75074005, 12.0321331], [92.75035858, 12.03197575], [92.74993896, 12.03197098], [92.74952698, 12.03207111], [92.7492218, 12.03236771], [92.74900055, 12.03281212], [92.74882507, 12.0333252], [92.74868774, 12.03384018], [92.7487793, 12.03433895], [92.74888611, 12.03472042], [92.74888611, 12.03481293], [92.74888611, 12.03555584], [92.7485733, 12.03621006], [92.74833679, 12.0363903], [92.74777985, 12.0363903], [92.7474823, 12.03621006], [92.7472229, 12.03610992], [92.74711609, 12.03587055], [92.74680328, 12.03541946], [92.74645233, 12.03499985], [92.74604797, 12.0346384], [92.7455368, 12.03446198], [92.74501038, 12.03447056], [92.74452209, 12.03463078], [92.74401855, 12.03475571], [92.74362183, 12.03499317], [92.74328613, 12.03528023], [92.74302673, 12.03559017], [92.74279022, 12.03590679], [92.74260712, 12.03628063], [92.74247742, 12.03671169], [92.74227905, 12.03711033], [92.74216461, 12.03751755], [92.74198914, 12.03781033], [92.74186707, 12.03806114], [92.74169922, 12.03821754], [92.74147797, 12.03838921], [92.74111176, 12.03889275], [92.7408371, 12.03889275], [92.74055481, 12.03916645], [92.74054718, 12.03971958], [92.74028015, 12.03999996], [92.74028015, 12.0402813], [92.74039459, 12.04092598], [92.74111938, 12.04144096], [92.74124908, 12.04169083], [92.7412262, 12.04209042], [92.7408371, 12.0421114], [92.74049377, 12.04190063], [92.74037933, 12.04183292], [92.73986816, 12.04148197], [92.73948669, 12.04117203], [92.73924255, 12.0409174], [92.73928833, 12.04061127], [92.73937988, 12.04014206], [92.73972321, 12.03967857], [92.74010468, 12.03908443], [92.74040222, 12.0384407], [92.74040222, 12.03816986], [92.74024963, 12.03785133], [92.74008179, 12.03746128], [92.74017334, 12.03703499], [92.74028015, 12.0365696], [92.74045563, 12.03632164], [92.74066162, 12.03610325], [92.7406311, 12.03514957], [92.74077606, 12.0346899], [92.7407608, 12.03425026], [92.74054718, 12.03398609], [92.74017334, 12.03401089], [92.7397995, 12.03427124], [92.73944092, 12.03464031], [92.73905182, 12.03512096], [92.73860168, 12.0352602], [92.73841858, 12.03514099], [92.73816681, 12.03460121], [92.73815918, 12.03392029], [92.73784637, 12.03385067], [92.73783112, 12.03309917], [92.73760986, 12.03306007], [92.73760986, 12.03250027], [92.73735809, 12.03238106], [92.73710632, 12.03197956], [92.73680115, 12.03162003], [92.73653412, 12.03124428], [92.73632813, 12.03090668], [92.73628998, 12.03058147], [92.73644257, 12.03022957], [92.73677826, 12.02991104], [92.73715973, 12.02962112], [92.73845673, 12.02971172], [92.73929596, 12.02968025], [92.73982239, 12.02988052], [92.74028015, 12.02987194], [92.74093628, 12.0302906], [92.74117279, 12.0302906], [92.74149323, 12.0299902], [92.74156952, 12.02897358], [92.74104309, 12.02863216], [92.74098206, 12.02827644], [92.74088287, 12.0278616], [92.7408371, 12.02739716], [92.74082184, 12.02687931], [92.74075317, 12.02634239], [92.74054718, 12.02583981], [92.740242, 12.02540016], [92.73986816, 12.02503109], [92.73943329, 12.02472115], [92.7389679, 12.02446079], [92.73845673, 12.02429295], [92.73795319, 12.02413464], [92.73745728, 12.0239296], [92.73690796, 12.0239048], [92.73636627, 12.02390957], [92.73583984, 12.02398014], [92.73535156, 12.02399158], [92.73493195, 12.02392101], [92.73457336, 12.02383041], [92.73433685, 12.02364063], [92.73414612, 12.02343082], [92.73396301, 12.02317142], [92.73384857, 12.02277184], [92.7336731, 12.02231693], [92.73361206, 12.02175999], [92.73360443, 12.02120209], [92.73364258, 12.02067757], [92.73378754, 12.02026081], [92.73403168, 12.02009201], [92.73431396, 12.01989365], [92.73462677, 12.01974964], [92.73532867, 12.02030182], [92.73561096, 12.02054596], [92.73586273, 12.02077103], [92.73604584, 12.0208807], [92.73628235, 12.0208807], [92.7365799, 12.02085972], [92.73697662, 12.02079201], [92.73735809, 12.02073288], [92.73769379, 12.0207119], [92.73815155, 12.02059078], [92.73854828, 12.0202198], [92.73915863, 12.01961994], [92.73999023, 12.01935101], [92.74022675, 12.01902103], [92.74030304, 12.01850128], [92.74044037, 12.01810932], [92.74030304, 12.01770973], [92.7401886, 12.01729107], [92.7399826, 12.01694202], [92.7396698, 12.01668262], [92.73926544, 12.01650906], [92.73877716, 12.01640034], [92.73829651, 12.01631069], [92.73790741, 12.01606274], [92.73742676, 12.01606274], [92.73681641, 12.01616096], [92.73662567, 12.01592064], [92.73725128, 12.01573658], [92.73758698, 12.01546097], [92.73779297, 12.01512623], [92.73800659, 12.01476955], [92.73830414, 12.01441479], [92.7386322, 12.01402283], [92.73901367, 12.01363754], [92.7394104, 12.01329994], [92.74006653, 12.01317024], [92.74028015, 12.01319122], [92.74054718, 12.01342106], [92.7408905, 12.01379013], [92.74098969, 12.01399994], [92.74120331, 12.01462173], [92.7414093, 12.01491165], [92.74173737, 12.01523972], [92.74221039, 12.01556587], [92.74259186, 12.01577091], [92.74355316, 12.01688957], [92.74362946, 12.01720047], [92.74378204, 12.01748943], [92.74398804, 12.0176506], [92.74415588, 12.01772022], [92.7444458, 12.01779938], [92.74478912, 12.01786137], [92.74507904, 12.01783085], [92.74539185, 12.01779938], [92.74594116, 12.0176506], [92.74627686, 12.01753044], [92.74690247, 12.01724052], [92.74726868, 12.01677132], [92.74754333, 12.01631069], [92.74774933, 12.01573181], [92.74797821, 12.01502323], [92.74836731, 12.01466846], [92.748703, 12.01431179], [92.7490387, 12.01423454], [92.74967194, 12.01419353], [92.75003052, 12.01411247], [92.75018311, 12.01388073], [92.75023651, 12.01342773], [92.75025177, 12.01287174], [92.75041962, 12.01247501], [92.75054932, 12.01200104], [92.7505722, 12.01148224], [92.7502594, 12.01097775], [92.74983215, 12.01056957], [92.74938965, 12.01023006], [92.74900055, 12.00995922], [92.74874115, 12.00966072], [92.74866486, 12.0093298], [92.74881744, 12.00898075], [92.74907684, 12.0086298], [92.74936676, 12.00831985], [92.74984741, 12.00809002], [92.75009918, 12.0079689], [92.75028992, 12.00769997], [92.75032806, 12.00749111], [92.75032806, 12.00720119], [92.75020599, 12.00691223], [92.74980927, 12.00542355], [92.74989319, 12.00509262], [92.74997711, 12.00482368], [92.75022888, 12.00455475], [92.75035095, 12.00443172], [92.75065613, 12.00422001], [92.75093842, 12.00399685], [92.75123596, 12.0037508], [92.7513504, 12.00362968], [92.75151062, 12.00336075], [92.75167847, 12.00307178], [92.75187683, 12.00286198], [92.75226593, 12.00262928], [92.75272369, 12.00248814], [92.75299835, 12.00249004], [92.75325012, 12.00267506], [92.75345612, 12.002985], [92.75356293, 12.00321102], [92.75365448, 12.00325394], [92.75383759, 12.00333977], [92.75440216, 12.00331974], [92.75482178, 12.00330162], [92.75527954, 12.00306034], [92.75569916, 12.00304031], [92.75608063, 12.00293922], [92.7564621, 12.00277996], [92.75686646, 12.00263214], [92.75724792, 12.00261116], [92.75753784, 12.00278378], [92.75776672, 12.002985], [92.75786591, 12.00325203], [92.75773621, 12.00368023], [92.75778961, 12.00413799], [92.75795746, 12.00456047], [92.75829315, 12.00487041], [92.75862885, 12.00522518], [92.75894165, 12.0056448], [92.75913239, 12.00621033], [92.75922394, 12.00686169], [92.7594986, 12.00741959], [92.75984955, 12.00788975], [92.76021576, 12.00827312], [92.76055908, 12.00865078], [92.76084137, 12.00912857], [92.76114655, 12.00966454], [92.76153564, 12.01010036], [92.76200104, 12.01033974], [92.76246643, 12.01056957], [92.76294708, 12.01084137], [92.76345062, 12.01115131], [92.76390839, 12.01154137], [92.76439667, 12.01185989], [92.76499176, 12.01191044], [92.76552582, 12.0117712], [92.76597595, 12.01156139], [92.76611328, 12.01138973], [92.76638794, 12.01111031], [92.76638794, 12.01083374], [92.76667023, 12.01055622], [92.76667023, 12.00944424], [92.76638794, 12.00916576], [92.76605225, 12.00885105], [92.76583099, 12.00833035], [92.76574707, 12.00767326], [92.76585388, 12.00652695], [92.76631927, 12.00540066], [92.76625824, 12.00341606], [92.76638794, 12.00306034], [92.76638794, 12.00277996], [92.76667023, 12.00249863], [92.76667023, 12.0022192], [92.76721954, 12.00166798], [92.76721954, 12.00139046], [92.76805878, 12.00055981], [92.76805878, 12.00028038], [92.76832581, 12.00000191], [92.76875305, 11.99903965], [92.76854706, 11.99871159], [92.76819611, 11.99831963], [92.76766968, 11.99811172], [92.76712036, 11.99800014], [92.76664734, 11.9978199], [92.76622009, 11.9977293], [92.76583099, 11.99756145], [92.76535797, 11.99752045], [92.76477051, 11.99755096], [92.76415253, 11.99764919], [92.76389313, 11.99790001], [92.76377106, 11.99825954], [92.76365662, 11.99838066], [92.76346588, 11.99855042], [92.76309204, 11.99854088], [92.76275635, 11.99859142], [92.76239777, 11.99849033], [92.76195526, 11.99847221], [92.76158905, 11.99829006], [92.76122284, 11.9980278], [92.7609024, 11.99775028], [92.76052094, 11.99750996], [92.76010132, 11.99734211], [92.75961304, 11.9972229], [92.75905609, 11.99710941], [92.75847626, 11.99698162], [92.75788116, 11.99694061], [92.75736237, 11.99688053], [92.75694275, 11.99670124], [92.75649261, 11.99658966], [92.75602722, 11.99651718], [92.75550842, 11.99644184], [92.75491333, 11.99636173], [92.75440216, 11.99634075], [92.75402069, 11.996521], [92.75356293, 11.99667168], [92.7531662, 11.9966011], [92.75276184, 11.9963913], [92.75232697, 11.99635029], [92.75193024, 11.99616146], [92.7514267, 11.99606991], [92.75099182, 11.9958601], [92.75052643, 11.99567127], [92.75003052, 11.99557114], [92.74952698, 11.99555492], [92.74904633, 11.99549103], [92.74858093, 11.99535179], [92.74801636, 11.99534988], [92.74772644, 11.99535179], [92.74733734, 11.99557114], [92.74700165, 11.99580574], [92.74693298, 11.99608135], [92.74680328, 11.99627972], [92.74643707, 11.99644184], [92.74616241, 11.99621964], [92.74616241, 11.99574184], [92.74581146, 11.99496937], [92.74542236, 11.99448586], [92.74521637, 11.99428082], [92.74458313, 11.99413967], [92.74395752, 11.99379539], [92.74318695, 11.99373245], [92.74304962, 11.99359035], [92.74298096, 11.99344921], [92.74291229, 11.99269199], [92.74291229, 11.99214077], [92.74304962, 11.99179363], [92.74311829, 11.99124336], [92.74318695, 11.9909668], [92.74298096, 11.98966122], [92.74291992, 11.98938084], [92.74291992, 11.98883057], [92.74304962, 11.98841], [92.74325562, 11.98834419], [92.74367523, 11.98848343], [92.74472809, 11.98848343], [92.74514771, 11.98910046], [92.74611664, 11.98960018], [92.74710083, 11.99020767], [92.74780273, 11.99069118], [92.74828339, 11.99110603], [92.74904633, 11.99131107], [92.74940491, 11.99158669], [92.74989319, 11.9920702], [92.75074005, 11.99215221], [92.75101471, 11.99215221], [92.75143433, 11.99229145], [92.75227356, 11.99229145], [92.75304413, 11.99208355], [92.75339508, 11.99194717], [92.75380707, 11.99145889], [92.75402069, 11.99118805], [92.75402069, 11.99084187], [92.75430298, 11.99035931], [92.75457764, 11.99008274], [92.75499725, 11.98973942], [92.75563049, 11.98939228], [92.75611877, 11.98911572], [92.75631714, 11.98891068], [92.75717163, 11.9883709], [92.75722504, 11.98789024], [92.75720978, 11.98738194], [92.75705719, 11.98688126], [92.75694275, 11.98659992], [92.75669098, 11.98633957], [92.75652313, 11.98627186], [92.75630188, 11.98627186], [92.75580597, 11.98606014], [92.7556076, 11.9855814], [92.75533295, 11.98524189], [92.75511932, 11.9847517], [92.75525665, 11.98440838], [92.75530243, 11.98361015], [92.75512695, 11.98304939], [92.75496674, 11.98250008], [92.7547226, 11.98203087], [92.75443268, 11.98164845], [92.7541275, 11.98136044], [92.75372314, 11.9813509], [92.7532196, 11.98116016], [92.75295258, 11.98093033], [92.75265503, 11.98054504], [92.75229645, 11.98021889], [92.75209045, 11.97964191], [92.75195312, 11.97917938], [92.7515564, 11.97881031], [92.75105286, 11.97854137], [92.75053406, 11.97829723], [92.75004578, 11.97803974], [92.74957275, 11.97782326], [92.74903107, 11.97779846], [92.7484436, 11.97756767], [92.74768829, 11.977561], [92.74715424, 11.97768879], [92.74653625, 11.97797108], [92.74645233, 11.97820759], [92.74610138, 11.97874165], [92.74588013, 11.97930241], [92.74582672, 11.97981071], [92.74583435, 11.98023033], [92.74582672, 11.98058128], [92.74584198, 11.98089123], [92.74585724, 11.98115063], [92.74588776, 11.98139], [92.74594116, 11.98169994], [92.74591064, 11.98207188], [92.7456665, 11.98238182], [92.74512482, 11.98241138], [92.74471283, 11.9824543], [92.74432373, 11.98234653], [92.7440033, 11.98221111], [92.74362946, 11.98186016], [92.74315643, 11.98155022], [92.74293518, 11.98120308], [92.74240112, 11.98064899], [92.74189758, 11.98024082], [92.74130249, 11.9799614], [92.74082184, 11.97965622], [92.74038696, 11.97942066], [92.74002838, 11.97933197], [92.73970032, 11.97910023], [92.73945618, 11.97903061], [92.73927307, 11.97889042], [92.73892212, 11.97863007], [92.73868561, 11.9784956], [92.73845673, 11.97825623], [92.73812103, 11.97779083], [92.73764801, 11.97750187], [92.73715973, 11.97722244], [92.73668671, 11.97694969], [92.73622131, 11.97671986], [92.73564148, 11.97668076], [92.7350769, 11.97679138], [92.73458862, 11.97709179], [92.73419189, 11.97749996], [92.73388672, 11.97801495], [92.73365784, 11.97858524], [92.73361206, 11.97924137], [92.73361206, 11.97991085], [92.73361969, 11.98054028], [92.73365021, 11.98109627], [92.73361969, 11.98161983], [92.73332977, 11.98217201], [92.73342133, 11.98313999], [92.73361969, 11.98338032], [92.73412323, 11.98359871], [92.73458862, 11.9838829], [92.73509979, 11.98411369], [92.73564911, 11.98407936], [92.73625946, 11.98427105], [92.73652649, 11.98485374], [92.73674011, 11.98533058], [92.7370224, 11.98576164], [92.73728943, 11.98620605], [92.73767853, 11.98656082], [92.73787689, 11.98703957], [92.73802948, 11.98754597], [92.73805237, 11.98808384], [92.73801422, 11.98858261], [92.7378006, 11.98895168], [92.73755646, 11.98929024], [92.73729706, 11.98977661], [92.73696136, 11.99038124], [92.7368927, 11.99100113], [92.73697662, 11.99145031], [92.73713684, 11.99175072], [92.73721313, 11.99202919], [92.73722076, 11.99233246], [92.73722076, 11.99266338], [92.73722839, 11.99304295], [92.73726654, 11.99347019], [92.73738861, 11.99392986], [92.73751068, 11.99438095], [92.73764801, 11.99475002], [92.73777008, 11.99506855], [92.73787689, 11.99534988], [92.73802185, 11.99557972], [92.73805237, 11.99586868], [92.73819733, 11.99615192], [92.73833466, 11.99642563], [92.73861694, 11.99660301], [92.73890686, 11.99686146], [92.73875427, 11.99733734], [92.73867035, 11.99750423], [92.73845673, 11.99746037], [92.73797607, 11.997262], [92.73770905, 11.99727631], [92.73742676, 11.99741173], [92.73706818, 11.99748802], [92.7366333, 11.99750137], [92.73612213, 11.99750137], [92.73558044, 11.99751472], [92.73505402, 11.99760246], [92.73457336, 11.99775028], [92.73408508, 11.99783039], [92.7336731, 11.99795341], [92.73344421, 11.99787331], [92.73329163, 11.99781799], [92.73291779, 11.99775028], [92.73259735, 11.99759007], [92.73229218, 11.99744415], [92.73200226, 11.997262], [92.73163605, 11.997159], [92.73129272, 11.99697018], [92.73088837, 11.99679947], [92.7305069, 11.99650955], [92.73008728, 11.99619961], [92.7296524, 11.99588108], [92.7292099, 11.99558926], [92.72883606, 11.99526119], [92.72828674, 11.99500084], [92.72808075, 11.99479103], [92.72793579, 11.99437904], [92.72786713, 11.9939003], [92.72786713, 11.99361992], [92.72793579, 11.99335098], [92.72821808, 11.99328041], [92.72856903, 11.99327564], [92.72877502, 11.99355221], [92.72940063, 11.99341488], [92.72982025, 11.99341488], [92.73001099, 11.99352932], [92.73033905, 11.99373245], [92.73062134, 11.9934597], [92.73066711, 11.9932394], [92.73049927, 11.99295044], [92.73014832, 11.99263096], [92.72964478, 11.99231625], [92.72926331, 11.99178123], [92.72924042, 11.99100113], [92.72917175, 11.99031067], [92.72916412, 11.98966122], [92.72895813, 11.98902988], [92.72886658, 11.98842144], [92.72865295, 11.98783779], [92.72853088, 11.9872818], [92.72853851, 11.98674202], [92.72827911, 11.98621273], [92.72789764, 11.98574066], [92.72751617, 11.98528099], [92.72689819, 11.98468113], [92.72651672, 11.98414135], [92.72653961, 11.98351192], [92.72698212, 11.98296261], [92.727005, 11.98241329], [92.72651672, 11.98198509], [92.72589874, 11.98168182], [92.72531128, 11.98143101], [92.72486115, 11.98130417], [92.72388458, 11.9810276], [92.72338867, 11.9808197], [92.72332764, 11.98040962], [92.72345734, 11.97999096], [92.72388458, 11.97978592], [92.72409821, 11.97903061], [92.72429657, 11.97881031], [92.72472382, 11.97835922], [92.72473145, 11.97798061], [92.72479248, 11.9776001], [92.7249527, 11.97718143], [92.7248764, 11.97679138], [92.72470093, 11.97646046], [92.72410583, 11.97601986], [92.72376251, 11.97546196], [92.72376251, 11.97498131], [92.72396851, 11.9746418], [92.72418213, 11.9744997], [92.72445679, 11.97429085], [92.72502136, 11.97422028], [92.7258606, 11.97422028], [92.72606659, 11.97435856], [92.72640991, 11.97465992], [92.72679901, 11.97483063], [92.72729492, 11.97511959], [92.72767639, 11.97542953], [92.72815704, 11.97566032], [92.72867584, 11.975811], [92.72923279, 11.975811], [92.72969055, 11.9756794], [92.73011017, 11.97545147], [92.73049927, 11.97519112], [92.7308197, 11.97483063], [92.73110962, 11.97439098], [92.73139191, 11.97388935], [92.73152924, 11.9733696], [92.73187256, 11.97284126], [92.73200226, 11.97234726], [92.73229218, 11.97179031], [92.73258209, 11.97135067], [92.73274231, 11.97087193], [92.73278046, 11.97032928], [92.73282623, 11.96978664], [92.73300934, 11.96926975], [92.73298645, 11.96876144], [92.7327652, 11.96833324], [92.73240662, 11.96800041], [92.73192596, 11.96786118], [92.73137665, 11.96805], [92.73087311, 11.9682579], [92.73044586, 11.96840096], [92.73019409, 11.96856308], [92.72994232, 11.96860886], [92.72969055, 11.96861267], [92.72945404, 11.96861267], [92.72920227, 11.96861267], [92.72891235, 11.96859264], [92.72859955, 11.96848774], [92.72824097, 11.96831036], [92.7278595, 11.96805668], [92.72744751, 11.9677906], [92.72701263, 11.96753979], [92.72644806, 11.96740532], [92.72602844, 11.96726608], [92.72574615, 11.96712971], [92.7253952, 11.96699333], [92.72531128, 11.96696091], [92.72518921, 11.9669199], [92.72505188, 11.96671009], [92.72505188, 11.96609306], [92.72532654, 11.96554089], [92.72548676, 11.96533108], [92.72537994, 11.96475029], [92.7250061, 11.96417141], [92.72466278, 11.9635601], [92.72424316, 11.96304989], [92.72381592, 11.96260071], [92.72332764, 11.96229076], [92.72276306, 11.96230221], [92.72228241, 11.96257973], [92.72174835, 11.96305656], [92.72146606, 11.96333313], [92.72126007, 11.96333313], [92.72076416, 11.96338654], [92.72062683, 11.96340275], [92.72035217, 11.96305656], [92.72006989, 11.96257114], [92.71985626, 11.96214962], [92.71945953, 11.96203995], [92.71924591, 11.96177101], [92.71897888, 11.96152973], [92.71890259, 11.96118832], [92.71877289, 11.96077061], [92.71891785, 11.96027565], [92.71888733, 11.95980167], [92.71893311, 11.95932961], [92.71903992, 11.95888138], [92.71910858, 11.9584713], [92.71911621, 11.9581089], [92.71909332, 11.9577713], [92.71903992, 11.95744801], [92.7190094, 11.9571104], [92.71889496, 11.9567709], [92.71875, 11.95636082], [92.71859741, 11.95602989], [92.71836853, 11.95567036], [92.71820831, 11.95518017], [92.71804047, 11.95460796], [92.7178421, 11.95399857], [92.71772766, 11.95335388], [92.71743011, 11.95287132], [92.71705627, 11.95254135], [92.71673584, 11.95226955], [92.71656799, 11.95200062], [92.71643066, 11.95178032], [92.71624756, 11.95156288], [92.71621704, 11.95149708], [92.71604156, 11.95116425], [92.71596527, 11.95081997], [92.71598053, 11.95020008], [92.71617889, 11.94999027], [92.71638489, 11.949646], [92.71708679, 11.94950962], [92.71750641, 11.94950962], [92.71806335, 11.94956017], [92.71833801, 11.94928169], [92.71856689, 11.94877148], [92.71856689, 11.94816017], [92.71833038, 11.94756126], [92.71802521, 11.9470253], [92.717659, 11.94680882], [92.71752167, 11.94676113], [92.71738434, 11.94648743], [92.71703339, 11.94614124], [92.71681976, 11.94586754], [92.71689606, 11.94511127], [92.71703339, 11.94393921], [92.717453, 11.94330978], [92.71787262, 11.94186497], [92.71801758, 11.94083118], [92.71821594, 11.93986416], [92.71851349, 11.93960857], [92.71861267, 11.93918133], [92.71852875, 11.93868065], [92.71832275, 11.9382], [92.71805573, 11.93772411], [92.71775055, 11.93721962], [92.7173233, 11.93676853], [92.71687317, 11.93634129], [92.71652222, 11.93640709], [92.71630859, 11.93654442], [92.7161026, 11.9366827], [92.71588898, 11.9366827], [92.71546936, 11.9364748], [92.71512604, 11.93626785], [92.71505737, 11.93571186], [92.71505737, 11.93516159], [92.71512604, 11.93488884], [92.71491241, 11.9344101], [92.71470642, 11.93412971], [92.71456146, 11.93399143], [92.71456146, 11.93343925], [92.7144928, 11.93316078], [92.71442413, 11.93295574], [92.7144165, 11.93260956], [92.71450043, 11.93255138], [92.71498108, 11.93219662], [92.71512604, 11.93192101], [92.71518707, 11.93136978], [92.7154007, 11.93089104], [92.71554565, 11.93088436], [92.71575165, 11.93116283], [92.71596527, 11.93185139], [92.71614838, 11.93283081], [92.71645355, 11.93309498], [92.71674347, 11.93345261], [92.71711731, 11.93371964], [92.71740723, 11.93405533], [92.71776581, 11.93435955], [92.71814728, 11.93438053], [92.71862793, 11.9344492], [92.71915436, 11.9344492], [92.71968079, 11.9345417], [92.72015381, 11.9344759], [92.72064209, 11.93433952], [92.72107697, 11.93416023], [92.72149658, 11.93391132], [92.72196198, 11.93361855], [92.72244263, 11.93327141], [92.72261047, 11.93283081], [92.72312927, 11.93221092], [92.72366333, 11.93180084], [92.72396088, 11.93129921], [92.72432709, 11.93098927], [92.72463226, 11.93057919], [92.72458649, 11.9302206], [92.72458649, 11.92992306], [92.72472382, 11.92964745], [92.72471619, 11.92938042], [92.72473145, 11.92910004], [92.72473145, 11.92883587], [92.7247467, 11.92859173], [92.72483063, 11.92827034], [92.72498322, 11.92800999], [92.72512817, 11.92772102], [92.72528076, 11.92739105], [92.72528076, 11.92702103], [92.72528076, 11.92661762], [92.72529602, 11.92618275], [92.72531891, 11.92572212], [92.72531128, 11.92526245], [92.72532654, 11.92487717], [92.72531128, 11.92434978], [92.72535706, 11.9239397], [92.72528076, 11.92345047], [92.72519684, 11.92292976], [92.72502899, 11.92241955], [92.72489929, 11.92186069], [92.7247467, 11.92127991], [92.72471619, 11.92065144], [92.72467804, 11.92002869], [92.72444916, 11.9195118], [92.72424316, 11.91905117], [92.72422028, 11.91858196], [92.7241745, 11.91812992], [92.72428894, 11.91769123], [92.72431183, 11.91725063], [92.72450256, 11.91681957], [92.72454071, 11.91643047], [92.7246933, 11.91596985], [92.72478485, 11.91553879], [92.72483063, 11.91508961], [92.72473907, 11.91458035], [92.7246933, 11.91404247], [92.72458649, 11.91353989], [92.72451019, 11.91309071], [92.7246933, 11.91270161], [92.72480011, 11.91230297], [92.72499084, 11.91192245], [92.72514343, 11.91152096], [92.72525787, 11.91109943], [92.72528076, 11.91069603], [92.72528076, 11.9102993], [92.72528076, 11.90988922], [92.72527313, 11.90945053], [92.72524261, 11.9089613], [92.72511292, 11.90845966], [92.7248764, 11.90802002], [92.72471619, 11.90756035], [92.72460175, 11.90711117], [92.72447205, 11.9066906], [92.72445679, 11.90623093], [92.72454834, 11.90574074], [92.72466278, 11.90525055], [92.72454071, 11.90482903], [92.72428131, 11.90448093], [92.72393036, 11.90419102], [92.72364044, 11.90388966], [92.72331238, 11.903615], [92.72290802, 11.90337753], [92.72248077, 11.90319061], [92.72231293, 11.90296268], [92.72245026, 11.9026804], [92.72289276, 11.90257072], [92.72342682, 11.90284729], [92.72398376, 11.90308094], [92.72422791, 11.90303326], [92.72451782, 11.90284443], [92.72480011, 11.90268517], [92.72506714, 11.90250015], [92.72530365, 11.902318], [92.72551727, 11.9021492], [92.72569275, 11.90193939], [92.72585297, 11.90167141], [92.72606659, 11.90139008], [92.72622681, 11.90100288], [92.7264328, 11.90057373], [92.72667694, 11.90009308], [92.72694397, 11.89956188], [92.72716522, 11.89898968], [92.72721863, 11.89836979], [92.72718811, 11.8978014], [92.72699738, 11.89734173], [92.72686768, 11.89689636], [92.72667694, 11.89651966], [92.72653961, 11.89612103], [92.72637177, 11.89573956], [92.72615814, 11.8953619], [92.72605896, 11.8948946], [92.72585297, 11.89445019], [92.72564697, 11.89398956], [92.72541809, 11.89358902], [92.72524261, 11.89319038], [92.72499084, 11.89285946], [92.72406769, 11.89188194], [92.72371674, 11.89161015], [92.72342682, 11.89133167], [92.72329712, 11.89105034], [92.72357941, 11.89091492], [92.72399902, 11.89098072], [92.72441101, 11.89125919], [92.72496033, 11.89115047], [92.72585297, 11.89098072], [92.72611237, 11.89062977], [92.72631836, 11.89025021], [92.72621155, 11.88979435], [92.72611237, 11.88924026], [92.72601318, 11.88866329], [92.72586823, 11.88811016], [92.72583771, 11.88756943], [92.72583008, 11.88704967], [92.72582245, 11.88654804], [92.72574615, 11.88604927], [92.72558594, 11.88554955], [92.72553253, 11.88498974], [92.72541046, 11.88444042], [92.72529602, 11.88387012], [92.72528076, 11.88330078], [92.72525787, 11.88275146], [92.72517395, 11.88227463], [92.72502899, 11.88187408], [92.72496796, 11.88150024], [92.72483063, 11.88121128], [92.72473907, 11.88091183], [92.7246933, 11.88057518], [92.72457123, 11.88025093], [92.72445679, 11.8798933], [92.72434998, 11.87950134], [92.72416687, 11.87915325], [92.72396851, 11.87881088], [92.72383118, 11.87843037], [92.72358704, 11.87819099], [92.72336578, 11.87782574], [92.72312164, 11.87739086], [92.72348785, 11.87686157], [92.7247467, 11.8767252], [92.72496033, 11.87643814], [92.72509766, 11.87601185], [92.72524261, 11.87552738], [92.72528076, 11.87494087], [92.7251358, 11.87429142], [92.72506714, 11.87361431], [92.72506714, 11.87293053], [92.72532654, 11.87226963], [92.72550201, 11.87174797], [92.72556305, 11.87125111], [92.72556305, 11.87082005], [92.72556305, 11.87045956], [92.72560883, 11.87014961], [92.72576141, 11.86988068], [92.72582245, 11.86958885], [92.72583771, 11.86929131], [92.72589874, 11.86900997], [92.72605133, 11.86872959], [92.72611237, 11.86836815], [92.72615814, 11.86792088], [92.72637939, 11.86744022], [92.72657013, 11.86686993], [92.72665405, 11.86625004], [92.72667694, 11.8656311], [92.72676086, 11.86507034], [92.72691345, 11.86458683], [92.72698975, 11.8640604], [92.72718811, 11.86351109], [92.72721863, 11.86289787], [92.72718811, 11.86225986], [92.72699738, 11.86165142], [92.72692108, 11.86102009], [92.72679138, 11.8604002], [92.72664642, 11.85975933], [92.7264328, 11.85912132], [92.72631836, 11.85846043], [92.72615051, 11.8578701], [92.72608948, 11.85730457], [92.72596741, 11.85678959], [92.72583008, 11.85630703], [92.72566986, 11.85580063], [92.72551727, 11.8552599], [92.72531128, 11.85474968], [92.72518921, 11.85423946], [92.72503662, 11.85377026], [92.72496796, 11.85329056], [92.72480774, 11.85284042], [92.72466278, 11.85231113], [92.72447968, 11.85180092], [92.72444153, 11.85129929], [92.72442627, 11.85085869], [92.7243042, 11.85051346], [92.72419739, 11.85026741], [92.72410583, 11.84997082], [92.72392273, 11.84971142], [92.72380829, 11.84932995], [92.72366333, 11.8488903], [92.72346497, 11.84844398], [92.72322845, 11.84800434], [92.72291565, 11.84770489], [92.72267914, 11.84726143], [92.7224884, 11.84682083], [92.72223663, 11.84639168], [92.72200775, 11.84589958], [92.72177887, 11.8453598], [92.72162628, 11.84475994], [92.72134399, 11.84425545], [92.72104645, 11.84377098], [92.72083282, 11.84320164], [92.72062683, 11.84263611], [92.72055817, 11.842062], [92.72051239, 11.84148979], [92.72032166, 11.84098244], [92.72023773, 11.84040546], [92.72005463, 11.83984947], [92.7199173, 11.83926964], [92.71972656, 11.83875275], [92.71952057, 11.83828831], [92.71933746, 11.83782959], [92.71909332, 11.83740997], [92.71885681, 11.83698177], [92.71861267, 11.83655071], [92.71833038, 11.83618641], [92.71808624, 11.83581924], [92.71798706, 11.83541393], [92.71781158, 11.83505058], [92.71768951, 11.83465481], [92.7175293, 11.8342514], [92.71743774, 11.83380032], [92.71723175, 11.83341026], [92.71704865, 11.8330183], [92.71688843, 11.83261013], [92.71665955, 11.83224964], [92.71640015, 11.83189011], [92.7162323, 11.83150005], [92.71608734, 11.83105087], [92.71591187, 11.83060741], [92.7158432, 11.83008957], [92.71581268, 11.8295517], [92.71569061, 11.82903004], [92.7155304, 11.82852173], [92.71527863, 11.8280201], [92.71501923, 11.82750511], [92.7148056, 11.82695103], [92.71461487, 11.82642746], [92.7144165, 11.82599163], [92.71420288, 11.82565022], [92.71405792, 11.82531929], [92.71391296, 11.82503891], [92.71378326, 11.82475185], [92.71362305, 11.82448101], [92.71347809, 11.82417107], [92.71329498, 11.82385159], [92.7130661, 11.82348919], [92.7128067, 11.82308578], [92.7125473, 11.8226757], [92.71234894, 11.82224941], [92.71215057, 11.82188034], [92.71193695, 11.8215704], [92.7117157, 11.82129669], [92.71154022, 11.82099056], [92.71135712, 11.82069111], [92.71111298, 11.82045078], [92.71086121, 11.82022095], [92.71061707, 11.81998158], [92.71039581, 11.81972027], [92.71018219, 11.81945133], [92.70992279, 11.81917], [92.70961761, 11.81886005], [92.70931244, 11.8184824], [92.708992, 11.81807423], [92.70863342, 11.81770515], [92.70827484, 11.8173542], [92.70783997, 11.81708717], [92.7074585, 11.81674099], [92.70704651, 11.81640053], [92.70658875, 11.8161087], [92.70613098, 11.81581116], [92.70570374, 11.81547356], [92.70521545, 11.81525707], [92.70475006, 11.81503105], [92.70423126, 11.81490421], [92.70375824, 11.81470776], [92.70332336, 11.81447124], [92.70281982, 11.81433868], [92.70230865, 11.8142004], [92.70173645, 11.81417179], [92.70115662, 11.81418991], [92.70056152, 11.81429958], [92.69996643, 11.81443024], [92.69937897, 11.81449986], [92.69877625, 11.8146801], [92.69848633, 11.81473064], [92.69793701, 11.81487179], [92.69765472, 11.81513596], [92.69723511, 11.81541157], [92.69689178, 11.81542301], [92.69675446, 11.81507683], [92.69682312, 11.81466007], [92.69709778, 11.8143177], [92.69724274, 11.81411076], [92.69698334, 11.81336975], [92.69663239, 11.81305122], [92.69628906, 11.81292629], [92.69594574, 11.81305981], [92.69560242, 11.81325817], [92.69520569, 11.81337166], [92.69484711, 11.81354141], [92.69447327, 11.81365013], [92.69351196, 11.81416988], [92.69281006, 11.8147192], [92.69225311, 11.81493092], [92.69140625, 11.81514072], [92.69071198, 11.81582928], [92.69033051, 11.81606197], [92.68995667, 11.81627083], [92.68956757, 11.81634045], [92.68902588, 11.81630993], [92.68875122, 11.81634045], [92.68828583, 11.81647015], [92.68782043, 11.81670189], [92.68733978, 11.81665039], [92.6869278, 11.81681061], [92.68643951, 11.81694126], [92.68572998, 11.81735802], [92.68516541, 11.81758213], [92.68475342, 11.81791878], [92.6844101, 11.81826115], [92.684021, 11.81843185], [92.68358612, 11.81858921], [92.68315887, 11.81868267], [92.68276215, 11.81881714], [92.68238068, 11.81893063], [92.68200684, 11.81906986], [92.68164825, 11.81910038], [92.68135071, 11.81905556], [92.68029785, 11.81941223], [92.68001556, 11.81947994], [92.67991638, 11.81913757], [92.6799469, 11.81880093], [92.6800766, 11.81857967], [92.68022919, 11.81851387], [92.68043518, 11.81844616], [92.68093109, 11.81836128], [92.68109131, 11.81816101], [92.68154907, 11.81795979], [92.68206024, 11.81769085], [92.68247223, 11.81732178], [92.68296051, 11.8172102], [92.6834259, 11.81711197], [92.68383789, 11.81692982], [92.68421936, 11.81668186], [92.68466187, 11.81643963], [92.68507385, 11.81619167], [92.68551636, 11.8160162], [92.68592072, 11.81581974], [92.6862793, 11.81556034], [92.68665314, 11.8152914], [92.6870575, 11.81499958], [92.6875, 11.81473541], [92.68799591, 11.81452847], [92.68850708, 11.81439972], [92.68897247, 11.81421089], [92.68939972, 11.8142004], [92.69008636, 11.81417179], [92.69065857, 11.81437969], [92.69113922, 11.81437016], [92.69217682, 11.8141613], [92.69274139, 11.81360912], [92.69303131, 11.81313992], [92.69303131, 11.81127071], [92.69302368, 11.81002045], [92.69246674, 11.80966187], [92.69190979, 11.80902958], [92.69197845, 11.80883026], [92.69246674, 11.8087616], [92.69267273, 11.80910969], [92.69351959, 11.80951786], [92.69415283, 11.80979156], [92.69462585, 11.80988979], [92.69503784, 11.81004715], [92.69542694, 11.81027889], [92.69582367, 11.81056881], [92.69619751, 11.81090164], [92.69659424, 11.81120491], [92.69695282, 11.81155968], [92.69731903, 11.81191063], [92.69773865, 11.81222057], [92.69819641, 11.81250191], [92.69869995, 11.81273174], [92.6992569, 11.81273174], [92.69976044, 11.81252193], [92.70024872, 11.81234932], [92.70062256, 11.81215096], [92.70083618, 11.81184959], [92.70124054, 11.81176758], [92.70156097, 11.81190205], [92.70182037, 11.81195927], [92.70211029, 11.81210041], [92.70243835, 11.81241512], [92.70295715, 11.81264973], [92.70363617, 11.81273174], [92.70437622, 11.81277084], [92.70510864, 11.81282997], [92.70574951, 11.81303024], [92.70635223, 11.81318092], [92.70685577, 11.81335163], [92.70730591, 11.8135252], [92.70775604, 11.81359959], [92.70820618, 11.81366158], [92.70861053, 11.81385136], [92.70903778, 11.81396008], [92.70941162, 11.81416321], [92.70979309, 11.81436062], [92.71018219, 11.81451607], [92.71047211, 11.81474209], [92.71070099, 11.81500912], [92.71086884, 11.81530952], [92.71102905, 11.81568146], [92.71133423, 11.81593895], [92.711586, 11.81629181], [92.71167755, 11.8168211], [92.71177673, 11.81736088], [92.71198273, 11.81783867], [92.71220398, 11.81831264], [92.71250153, 11.81875992], [92.71282196, 11.81924057], [92.71312714, 11.81975174], [92.71363068, 11.8200798], [92.71399689, 11.82056713], [92.71432495, 11.82126331], [92.71475983, 11.82174969], [92.71512604, 11.82213116], [92.71546936, 11.82241058], [92.71588135, 11.82254791], [92.71620941, 11.82278061], [92.71655273, 11.82304859], [92.71692657, 11.82332134], [92.7173233, 11.82362175], [92.717659, 11.82393074], [92.7179184, 11.8242712], [92.71819305, 11.82452202], [92.71833038, 11.82482719], [92.71844482, 11.82512283], [92.71858215, 11.82541275], [92.71862793, 11.82572079], [92.7186203, 11.82604408], [92.7186203, 11.82638168], [92.71868896, 11.82677078], [92.71882629, 11.82721138], [92.71891785, 11.82774925], [92.71910858, 11.82830143], [92.7192688, 11.82883167], [92.71936798, 11.82936859], [92.71932983, 11.82993507], [92.71957397, 11.83035183], [92.71970367, 11.83076191], [92.71971893, 11.83116531], [92.71972656, 11.83155346], [92.71974945, 11.83191967], [92.71995544, 11.83221626], [92.72013092, 11.83253956], [92.72032928, 11.83284092], [92.72045898, 11.83320999], [92.72064972, 11.83349037], [92.72079468, 11.83383656], [92.72104645, 11.83411217], [92.72117615, 11.83449078], [92.7213974, 11.83484936], [92.72161865, 11.8352108], [92.72177887, 11.83563328], [92.72210693, 11.83595371], [92.72231293, 11.83637142], [92.72250366, 11.83680153], [92.72270203, 11.83723259], [92.72289276, 11.83768082], [92.72309113, 11.83820057], [92.72336578, 11.83871174], [92.72372437, 11.83922863], [92.72405243, 11.83983994], [92.72453308, 11.8404417], [92.72489929, 11.8409996], [92.72525787, 11.84143543], [92.72556305, 11.84183025], [92.7257843, 11.84221935], [92.72587585, 11.84268188], [92.7259903, 11.84312916], [92.72621918, 11.84354782], [92.72635651, 11.84409046], [92.72641754, 11.84464169], [92.72653961, 11.84509087], [92.72664642, 11.84539032], [92.7266922, 11.84566975], [92.72680664, 11.84597492], [92.72692108, 11.84633064], [92.72694397, 11.84676647], [92.72698212, 11.84722042], [92.72714233, 11.84764957], [92.72715759, 11.84811974], [92.72718811, 11.8485508], [92.7273407, 11.84890175], [92.72749329, 11.84924984], [92.72763062, 11.84963131], [92.72775269, 11.85006428], [92.72782898, 11.85057926], [92.72805023, 11.85105991], [92.72834015, 11.85154057], [92.72868347, 11.85199738], [92.72909546, 11.85241413], [92.72968292, 11.85255146], [92.73008728, 11.85291958], [92.73033905, 11.85335064], [92.7306366, 11.85371113], [92.73082733, 11.85418034], [92.73096466, 11.8546133], [92.73110199, 11.85497284], [92.73121643, 11.8553009], [92.73133087, 11.85556126], [92.73139191, 11.85585976], [92.73147583, 11.85623646], [92.73165894, 11.85663891], [92.73181152, 11.85714054], [92.73174286, 11.85745144], [92.73163605, 11.85782909], [92.73139191, 11.85819435], [92.73112488, 11.85855198], [92.73088837, 11.85892296], [92.73069, 11.85931969], [92.73036957, 11.85974979], [92.73020172, 11.86014938], [92.73020172, 11.86088085], [92.73020172, 11.8612566], [92.73012543, 11.86191273], [92.73027039, 11.86242199], [92.7305603, 11.86292076], [92.73060608, 11.86338997], [92.73078156, 11.8637619], [92.73088074, 11.86415958], [92.73114777, 11.86448193], [92.73134613, 11.864851], [92.73139191, 11.86530876], [92.73139191, 11.86583138], [92.73134613, 11.86638737], [92.7311554, 11.86693192], [92.73110962, 11.86752033], [92.73110962, 11.86811924], [92.7310791, 11.86870098], [92.73097992, 11.86927891], [92.73110199, 11.86991119], [92.73124695, 11.87052155], [92.73136902, 11.87115097], [92.73143005, 11.87180042], [92.73161316, 11.87242889], [92.73175049, 11.87311745], [92.73203278, 11.87368011], [92.73239899, 11.87408161], [92.7325058, 11.87449169], [92.73259735, 11.87482929], [92.73264313, 11.87513924], [92.73252869, 11.8755703], [92.7325058, 11.87600517], [92.7325058, 11.87643433], [92.73246765, 11.87687111], [92.73231506, 11.87730694], [92.73216248, 11.87773037], [92.73194122, 11.87830257], [92.73187256, 11.87874222], [92.73190308, 11.87907982], [92.73195648, 11.8794899], [92.73182678, 11.87952042], [92.73182678, 11.87974072], [92.73180389, 11.88012981], [92.73168945, 11.88052177], [92.73166656, 11.88098145], [92.73166656, 11.88144112], [92.73166656, 11.88190556], [92.73162079, 11.88237095], [92.73147583, 11.88283062], [92.73137665, 11.88328934], [92.73137665, 11.88375187], [92.73139191, 11.88422108], [92.73139954, 11.8846817], [92.73150635, 11.88511467], [92.7315979, 11.88554096], [92.73165131, 11.88598061], [92.73166656, 11.88642502], [92.73167419, 11.88688087], [92.7317276, 11.88732147], [92.73188782, 11.88771057], [92.73197937, 11.88812065], [92.73210907, 11.8885107], [92.73220062, 11.88891411], [92.73221588, 11.88936138], [92.73226166, 11.88982964], [92.73243713, 11.89025021], [92.73252869, 11.89067841], [92.73269653, 11.89105034], [92.73277283, 11.8914299], [92.73278046, 11.8918314], [92.73277283, 11.89225769], [92.7326889, 11.8927002], [92.7325058, 11.89316177], [92.73232269, 11.89365482], [92.73214722, 11.89424515], [92.73195648, 11.89491081], [92.73179626, 11.89565086], [92.73168182, 11.89637184], [92.73170471, 11.89701653], [92.7318573, 11.89751053], [92.73194885, 11.89787579], [92.73195648, 11.89813995], [92.73190308, 11.89837933], [92.73178101, 11.89868927], [92.73171997, 11.89914989], [92.73188019, 11.89964008], [92.73215485, 11.90007114], [92.7322464, 11.9005537], [92.73239136, 11.9009819], [92.73252106, 11.90137196], [92.73269653, 11.90177059], [92.73277283, 11.90221119], [92.73278046, 11.90267563], [92.73280334, 11.9031496], [92.73288727, 11.90360069], [92.73300171, 11.90404129], [92.733078, 11.90448093], [92.73316193, 11.90492344], [92.73330688, 11.90536022], [92.73343658, 11.90584087], [92.73361969, 11.90626144], [92.73387146, 11.90665722], [92.7341156, 11.90706062], [92.73431396, 11.90753174], [92.73446655, 11.908041], [92.73467255, 11.90853119], [92.73474884, 11.90905857], [92.73487091, 11.90955162], [92.73499298, 11.9100008], [92.7351532, 11.91046143], [92.735466, 11.91087055], [92.73560333, 11.91143036], [92.73579407, 11.91196823], [92.7359314, 11.91255093], [92.73612213, 11.91307831], [92.73636627, 11.91351986], [92.73656464, 11.91394806], [92.73667908, 11.91440201], [92.73681641, 11.9148674], [92.73700714, 11.91532898], [92.73726654, 11.91576004], [92.73758698, 11.91622066], [92.73788452, 11.916749], [92.73825073, 11.91725254], [92.73861694, 11.91774082], [92.73900604, 11.91817093], [92.7394104, 11.91854095], [92.73977661, 11.91893005], [92.74018097, 11.91925621], [92.7405014, 11.91965294], [92.74082184, 11.919981], [92.74108887, 11.92030716], [92.74131775, 11.92061043], [92.74150848, 11.92096138], [92.74170685, 11.92132759], [92.7419281, 11.92171955], [92.74208832, 11.92218018], [92.74219513, 11.92268562], [92.74221802, 11.92324924], [92.74225616, 11.9238596], [92.74246216, 11.92446041], [92.74259186, 11.92506123], [92.74279022, 11.92554379], [92.7430191, 11.92592144], [92.74323273, 11.92628956], [92.74346161, 11.92669296], [92.74372101, 11.92716026], [92.74410248, 11.92762756], [92.74443817, 11.92818356], [92.74472809, 11.92872238], [92.74500275, 11.92919064], [92.74520111, 11.92955971], [92.74526978, 11.92991066], [92.74529266, 11.93026924], [92.74532318, 11.93065739], [92.7455368, 11.93105125], [92.74588013, 11.93144131], [92.74625397, 11.93182087], [92.74664307, 11.93211269], [92.74711609, 11.93218994], [92.74750519, 11.93232727], [92.74798584, 11.93245316], [92.74847412, 11.93244839], [92.74891663, 11.93223095], [92.7493515, 11.9320097], [92.74984741, 11.93195057], [92.75032043, 11.93190098], [92.7507019, 11.93173027], [92.75108337, 11.93163013], [92.75137329, 11.9315176], [92.75163269, 11.93141079], [92.75192261, 11.93139267], [92.7522583, 11.93139267], [92.75263214, 11.93131256], [92.75315857, 11.9313612], [92.75350952, 11.93159962], [92.75382233, 11.93188953], [92.75418091, 11.93231106], [92.75434113, 11.93260956], [92.754776, 11.93270969], [92.75524902, 11.93305588], [92.75579071, 11.93354416], [92.75605774, 11.9338932], [92.7563858, 11.93418026], [92.75683594, 11.93446732], [92.75728607, 11.93478203], [92.75776672, 11.93505955], [92.75820923, 11.93530083], [92.75853729, 11.93554115], [92.75880432, 11.93573666], [92.75908661, 11.93588924], [92.7592926, 11.93609905], [92.75952911, 11.93631554], [92.75984955, 11.93647957], [92.76022339, 11.93663025], [92.76085663, 11.93618965], [92.76135254, 11.93632507], [92.76219177, 11.9368763], [92.76239777, 11.93729115], [92.76239777, 11.93757057], [92.76213837, 11.93794823], [92.76242828, 11.93825054], [92.76274109, 11.93858147], [92.76303864, 11.93889141], [92.76334381, 11.93918133], [92.7636795, 11.93945408], [92.76405334, 11.93972301], [92.7644577, 11.93992138], [92.76488495, 11.93980026], [92.76506042, 11.93937016], [92.76547241, 11.93905067], [92.76583862, 11.93875694], [92.76624298, 11.93850136], [92.76683807, 11.9383297], [92.76728058, 11.93824387], [92.76774597, 11.93828297], [92.76811218, 11.93859291], [92.76824188, 11.93863964], [92.76850891, 11.93874073], [92.76877594, 11.93888187], [92.769104, 11.93902969], [92.76948547, 11.93923283], [92.76992035, 11.93948364], [92.77039337, 11.93974972], [92.7706604, 11.93985462], [92.77092743, 11.93995953], [92.77168274, 11.93933964], [92.7720871, 11.93920135], [92.77250671, 11.9390707], [92.77426147, 11.9390707], [92.77496338, 11.93879128], [92.77565765, 11.93865204], [92.7771225, 11.93844032], [92.77761078, 11.93809605], [92.77831268, 11.93782043], [92.77870941, 11.93761921], [92.77934265, 11.93693066], [92.77968597, 11.93651772], [92.77996826, 11.93637943], [92.78113556, 11.93643188], [92.78161621, 11.93638611], [92.78203583, 11.93605137], [92.78218079, 11.93605423], [92.78288269, 11.93612194], [92.78372192, 11.93626118], [92.78399658, 11.93626118], [92.78449249, 11.93605137], [92.78476715, 11.93577766], [92.78476715, 11.93515968], [92.78504944, 11.93488026], [92.78555298, 11.93484974], [92.78544617, 11.93443966], [92.78491211, 11.93413925], [92.78434753, 11.93385601], [92.78383636, 11.93354034], [92.78343201, 11.93315029], [92.78308868, 11.93270111], [92.78285217, 11.93220043], [92.78266907, 11.93167114], [92.78252411, 11.9311533], [92.78233337, 11.93062019], [92.78249359, 11.93009758], [92.7828598, 11.92947102], [92.78341675, 11.92897034], [92.78386688, 11.92849064], [92.78424072, 11.92798996], [92.78444672, 11.92753029], [92.78483582, 11.92695141], [92.78542328, 11.92669964], [92.78578186, 11.92635059], [92.78650665, 11.9261694], [92.78714752, 11.92603016], [92.78768158, 11.92556286], [92.78781891, 11.92503834], [92.78791046, 11.92432976], [92.78762054, 11.92383099], [92.78753662, 11.92349052], [92.78740692, 11.92266083], [92.78762054, 11.92162037], [92.7878952, 11.9206562], [92.7881012, 11.92032146], [92.78817749, 11.91980076], [92.78811646, 11.91929722], [92.78793335, 11.91893959], [92.78785706, 11.91843987], [92.78778076, 11.91798019], [92.7876358, 11.91763973], [92.78753662, 11.91740131], [92.78727722, 11.91691113], [92.78717804, 11.91643715], [92.78697968, 11.91595173], [92.78686523, 11.91537285], [92.78666687, 11.91479397], [92.7864151, 11.91420078], [92.78612518, 11.91363144], [92.78583527, 11.91309834], [92.78556061, 11.91260147], [92.78536224, 11.91214275], [92.7853241, 11.91170311], [92.78522491, 11.91126823], [92.78527069, 11.91081047], [92.78541565, 11.91040039], [92.78556061, 11.91000462], [92.78554535, 11.90961838], [92.78547668, 11.90924168], [92.78531647, 11.90889072], [92.78515625, 11.90853119], [92.78499603, 11.90814972], [92.78475952, 11.90778542], [92.7844696, 11.90740681], [92.78417206, 11.90697193], [92.78367615, 11.90649128], [92.78342438, 11.90604877], [92.78327942, 11.90544033], [92.78328705, 11.90487957], [92.78340912, 11.90435123], [92.78366089, 11.90399075], [92.78399658, 11.90352058], [92.78437042, 11.90334129], [92.78482819, 11.90305233], [92.78498077, 11.90303802], [92.78542328, 11.90279198], [92.78557587, 11.90255928], [92.7855072, 11.90221119], [92.78557587, 11.90179825], [92.78578949, 11.9014492], [92.78620911, 11.90145397], [92.78662872, 11.90138626], [92.78697205, 11.90145397], [92.78739166, 11.9015913], [92.78791046, 11.90186024], [92.78835297, 11.9015913], [92.78855133, 11.90121937], [92.78824615, 11.90087128], [92.78785706, 11.90056133], [92.78782654, 11.90005016], [92.78766632, 11.89960957], [92.78731537, 11.8995533], [92.78675842, 11.89963055], [92.78637695, 11.89974022], [92.78591919, 11.8997612], [92.78566742, 11.89968109], [92.78536987, 11.89922047], [92.78522491, 11.89863014], [92.78460693, 11.89843178], [92.78392792, 11.8985939], [92.78347778, 11.89857483], [92.78333282, 11.89857101], [92.78286743, 11.89834118], [92.78244019, 11.89806938], [92.78202057, 11.89784241], [92.78164673, 11.89754963], [92.78130341, 11.8972702], [92.78092194, 11.89702129], [92.78059387, 11.89671993], [92.78040314, 11.89630127], [92.78018188, 11.89591312], [92.77999878, 11.89554024], [92.77977753, 11.89507008], [92.77957916, 11.89457798], [92.77944183, 11.89402199], [92.77936554, 11.89393997], [92.77922821, 11.89352036], [92.77908325, 11.89255905], [92.77894592, 11.89214134], [92.77894592, 11.89152431], [92.77922821, 11.8910408], [92.77992249, 11.89042091], [92.78026581, 11.89021111], [92.78095245, 11.89015388], [92.78128815, 11.88982105], [92.78156281, 11.88951969], [92.78170776, 11.88916016], [92.78190613, 11.88887119], [92.78205109, 11.88852024], [92.78222656, 11.88817978], [92.7824173, 11.88784981], [92.7826004, 11.8875103], [92.78285217, 11.88718033], [92.78325653, 11.88691998], [92.78369904, 11.88666534], [92.7841568, 11.88641167], [92.78460693, 11.88619137], [92.78495026, 11.88588715], [92.78530121, 11.88559055], [92.78566742, 11.88529015], [92.78604889, 11.88500118], [92.78643799, 11.88473034], [92.78690338, 11.88451958], [92.78740692, 11.88445187], [92.78785706, 11.88434887], [92.78811646, 11.8838501], [92.78791046, 11.88313389], [92.78743744, 11.88305855], [92.78688812, 11.88266945], [92.78639984, 11.88226128], [92.78614044, 11.88180065], [92.78618622, 11.88136578], [92.78607178, 11.8808918], [92.78587341, 11.88044739], [92.7858429, 11.88000965], [92.7858963, 11.87955093], [92.78586578, 11.87909985], [92.78594208, 11.87863064], [92.78600311, 11.87830544], [92.78636932, 11.87768269], [92.78659058, 11.87767792], [92.78665924, 11.87737274], [92.78665924, 11.87703991], [92.78662109, 11.87672138], [92.78652191, 11.87642479], [92.78640747, 11.87613678], [92.78617859, 11.87589073], [92.78583527, 11.87547874], [92.7858429, 11.8745079], [92.78625488, 11.87389183], [92.78617859, 11.87368488], [92.78666687, 11.87292385], [92.78689575, 11.87232399], [92.78694153, 11.87172985], [92.7868042, 11.87164974], [92.78642273, 11.87137222], [92.78635406, 11.87089062], [92.78621674, 11.87020016], [92.78565979, 11.86902046], [92.78544617, 11.86826706], [92.78559113, 11.86771107], [92.78572845, 11.86744022], [92.78588104, 11.86723042], [92.78610992, 11.86667919], [92.78630829, 11.86619091], [92.78620148, 11.86566925], [92.78598022, 11.86493969], [92.7858963, 11.86446953], [92.78560638, 11.86395073], [92.78551483, 11.86341095], [92.78533173, 11.86295033], [92.7852478, 11.86248779], [92.78508759, 11.86206055], [92.78496552, 11.86167431], [92.78473663, 11.86139107], [92.78450012, 11.86114311], [92.78429413, 11.86091518], [92.7841568, 11.86064625], [92.78398895, 11.86034966], [92.78383636, 11.85999203], [92.78366852, 11.8595953], [92.78362274, 11.8591404], [92.78365326, 11.85867691], [92.78363037, 11.85824203], [92.78353882, 11.85788059], [92.78373718, 11.85736179], [92.78387451, 11.85709667], [92.78418732, 11.8565712], [92.78458405, 11.85638905], [92.78492737, 11.85642147], [92.78526306, 11.85624123], [92.78557587, 11.85601044], [92.78586578, 11.85568047], [92.78611755, 11.85523129], [92.78594971, 11.85468197], [92.78586578, 11.85405922], [92.78559875, 11.85349941], [92.78556061, 11.85287189], [92.78539276, 11.85231972], [92.78521729, 11.85181904], [92.78482056, 11.85139275], [92.78440857, 11.85103989], [92.78394318, 11.85085869], [92.78341675, 11.85084057], [92.78289795, 11.85090733], [92.7824173, 11.85107422], [92.78192902, 11.85110092], [92.78151703, 11.85103035], [92.78116608, 11.85087109], [92.78093719, 11.85069084], [92.78083038, 11.85013008], [92.78083801, 11.8496666], [92.78064728, 11.84904957], [92.78057861, 11.8485527], [92.7804184, 11.84792423], [92.78028107, 11.84729004], [92.78018188, 11.84669971], [92.78014374, 11.84618473], [92.78029633, 11.84572029], [92.78055573, 11.84532261], [92.7808075, 11.84491062], [92.78096008, 11.84445953], [92.78105164, 11.84401131], [92.78108978, 11.84357262], [92.78096008, 11.84313297], [92.78060913, 11.8427248], [92.78022003, 11.84230995], [92.77979279, 11.84196186], [92.77935791, 11.84166145], [92.77896118, 11.84135532], [92.77861786, 11.84097481], [92.77830505, 11.84050846], [92.77809143, 11.83994007], [92.77789307, 11.83931065], [92.7780304, 11.83867741], [92.77825928, 11.83813], [92.77845001, 11.83764267], [92.7786026, 11.8372736], [92.77852631, 11.83688831], [92.77832031, 11.83657169], [92.77802277, 11.83622074], [92.77762604, 11.83581924], [92.77723694, 11.83532047], [92.7769165, 11.83477116], [92.77664948, 11.83428955], [92.77639008, 11.83388042], [92.77617645, 11.83347034], [92.77616119, 11.83298016], [92.77617645, 11.8324604], [92.77644348, 11.83174038], [92.77674866, 11.83132267], [92.77707672, 11.83094025], [92.77735138, 11.83071041], [92.77754211, 11.83036137], [92.777771, 11.8300209], [92.77797699, 11.82962513], [92.77804565, 11.82913876], [92.77791595, 11.8286314], [92.77791595, 11.82812977], [92.77784729, 11.82766914], [92.77787018, 11.82721138], [92.77780151, 11.82674408], [92.77760315, 11.82622433], [92.77725983, 11.82582474], [92.77687073, 11.82548141], [92.77645874, 11.82527161], [92.77612305, 11.8250618], [92.77587128, 11.82479095], [92.77575684, 11.82439899], [92.7756424, 11.82396126], [92.77557373, 11.82355976], [92.77554321, 11.82291985], [92.77568054, 11.82223129], [92.77588654, 11.82180977], [92.77615356, 11.82143974], [92.77620697, 11.82096195], [92.77614594, 11.82063961], [92.77586365, 11.81974506], [92.77565002, 11.81940079], [92.7754364, 11.81898975], [92.7754364, 11.81885147], [92.77513885, 11.81844997], [92.77507782, 11.81802177], [92.77488708, 11.81781197], [92.77474213, 11.81732941], [92.77433014, 11.81684971], [92.77411652, 11.81581116], [92.77425385, 11.81470776], [92.77433014, 11.81408978], [92.77446747, 11.81353188], [92.77467346, 11.81325817], [92.7747345, 11.81284618], [92.77462769, 11.81217957], [92.77446747, 11.81159019], [92.77435303, 11.8109951], [92.77420807, 11.81042957], [92.77384186, 11.81001091], [92.7734375, 11.80966187], [92.77308655, 11.80932045], [92.77284241, 11.80904579], [92.77266693, 11.80879974], [92.77253723, 11.80858135], [92.77278137, 11.80817795], [92.77298737, 11.80735111], [92.77298737, 11.80659199], [92.77271271, 11.80618191], [92.77229309, 11.80566025], [92.7723465, 11.80539131], [92.77226257, 11.80508137], [92.77179718, 11.80473042], [92.77163696, 11.80431747], [92.77133179, 11.80402088], [92.77105713, 11.80355072], [92.77091217, 11.80281067], [92.77084351, 11.80204487], [92.77079773, 11.80136585], [92.77065277, 11.80083179], [92.77063751, 11.80023098], [92.77015686, 11.79988194], [92.76976776, 11.79953098], [92.76950073, 11.7991209], [92.7693634, 11.79860783], [92.76953888, 11.79806137], [92.76991272, 11.79760075], [92.77015686, 11.79724979], [92.77023315, 11.79687119], [92.77022552, 11.7964716], [92.7702713, 11.79611683], [92.77031708, 11.79576969], [92.770401, 11.79544926], [92.77046204, 11.79515076], [92.77033997, 11.79482937], [92.77011871, 11.79453278], [92.76994324, 11.79422474], [92.76979828, 11.79391479], [92.7697525, 11.7935276], [92.76978302, 11.79312038], [92.76991272, 11.79276657], [92.77001953, 11.79243183], [92.7701416, 11.79215622], [92.7702713, 11.79187107], [92.77039337, 11.79159069], [92.77050018, 11.79128075], [92.77060699, 11.79091072], [92.77081299, 11.79052162], [92.77095795, 11.79001999], [92.77108765, 11.7894659], [92.77108765, 11.78885078]]], [[[92.7024231, 12.63786983], [92.70204163, 12.63783073], [92.70160675, 12.63809109], [92.70121765, 12.63853073], [92.70094299, 12.63910961], [92.70090485, 12.63972759], [92.70118713, 12.64020157], [92.7016449, 12.64054585], [92.7021637, 12.64074421], [92.70269012, 12.64054585], [92.70307159, 12.63998985], [92.70336914, 12.63935566], [92.70336914, 12.63873196], [92.70294189, 12.638237], [92.7026825, 12.63803196], [92.7024231, 12.63786983]]], [[[92.87503052, 12.44508266], [92.87538147, 12.44481087], [92.87565613, 12.44481087], [92.87586975, 12.44474125], [92.87586975, 12.4443903], [92.87545013, 12.44404793], [92.87474823, 12.44411755], [92.87425995, 12.44453144], [92.87425995, 12.44481087], [92.87452698, 12.44528961], [92.87474823, 12.44528961], [92.87503052, 12.44508266]]], [[[92.67945862, 12.54112816], [92.67988586, 12.54111195], [92.68032074, 12.54111195], [92.68073273, 12.54111195], [92.68114471, 12.54111195], [92.68154907, 12.54111195], [92.68195343, 12.54109573], [92.68232727, 12.54099274], [92.68268585, 12.54083633], [92.68305969, 12.54065132], [92.68347168, 12.54039097], [92.68388367, 12.54002476], [92.68432617, 12.53966713], [92.68460083, 12.53924274], [92.68457031, 12.53878021], [92.68432617, 12.538311], [92.68411255, 12.53783035], [92.68387604, 12.53739166], [92.68366241, 12.53697014], [92.68354797, 12.53652573], [92.68334961, 12.53617001], [92.68318939, 12.53582382], [92.68307495, 12.53544807], [92.6830368, 12.53502178], [92.68292999, 12.5346117], [92.68274689, 12.53427029], [92.68251801, 12.53399181], [92.68232727, 12.53371143], [92.68215942, 12.53341007], [92.6819458, 12.53313923], [92.68174744, 12.53283596], [92.681633, 12.53240108], [92.68138885, 12.5319519], [92.68115997, 12.53144073], [92.68106842, 12.53086662], [92.68089294, 12.53036976], [92.68080139, 12.52985668], [92.68061829, 12.52939034], [92.68045044, 12.52889061], [92.68026733, 12.52839184], [92.68006897, 12.52794266], [92.67996979, 12.52749157], [92.67980957, 12.52716255], [92.67971039, 12.52683735], [92.67958069, 12.52652073], [92.67946625, 12.52616501], [92.67944336, 12.52571201], [92.67940521, 12.52523136], [92.67925262, 12.52475929], [92.6792984, 12.5243206], [92.67942047, 12.52395439], [92.67944336, 12.52363777], [92.67941284, 12.52334976], [92.67920685, 12.52309132], [92.67894745, 12.52278137], [92.67856598, 12.52245045], [92.67842102, 12.52224731], [92.67811584, 12.52221966], [92.67767334, 12.52229118], [92.67720795, 12.52258015], [92.67670441, 12.52294922], [92.67627716, 12.52342129], [92.67579651, 12.52380562], [92.67529297, 12.52408886], [92.67482758, 12.52434635], [92.67446136, 12.52460194], [92.67415619, 12.52484131], [92.67385864, 12.52504063], [92.67360687, 12.52528954], [92.67331696, 12.52557945], [92.67299652, 12.52590084], [92.67268372, 12.52632904], [92.67229462, 12.52671432], [92.67195129, 12.52711964], [92.67163849, 12.52752113], [92.67131805, 12.52786827], [92.67105865, 12.52826023], [92.67074585, 12.52861977], [92.6704483, 12.52898884], [92.67010498, 12.52934361], [92.6697998, 12.52977085], [92.66958618, 12.53027725], [92.66938782, 12.53077984], [92.66915894, 12.53126144], [92.66893005, 12.53171921], [92.66887665, 12.53223896], [92.66879272, 12.53272247], [92.66864014, 12.53314781], [92.66860962, 12.5336628], [92.66860962, 12.53423119], [92.66866302, 12.53483868], [92.66886902, 12.53539753], [92.66902161, 12.53596306], [92.66918182, 12.53647137], [92.66942596, 12.53694057], [92.66972351, 12.53736019], [92.6700058, 12.53779984], [92.67028046, 12.53826046], [92.67054749, 12.53864098], [92.67079163, 12.53898144], [92.67095947, 12.5392952], [92.67111969, 12.53962994], [92.67131805, 12.53994942], [92.67140961, 12.54032993], [92.67163086, 12.54067898], [92.67183685, 12.54106236], [92.67224121, 12.54139042], [92.67276764, 12.54166985], [92.67337799, 12.54195023], [92.67404938, 12.54217625], [92.67475891, 12.54222393], [92.67544556, 12.54219437], [92.67602539, 12.54203701], [92.67655182, 12.5418911], [92.67698669, 12.54168129], [92.67737579, 12.54150105], [92.67780304, 12.54140568], [92.67823029, 12.5413866], [92.67865753, 12.5413599], [92.67905426, 12.54123497], [92.67945862, 12.54112816]]], [[[92.65584564, 12.76895905], [92.65564728, 12.7688818], [92.65537262, 12.76893616], [92.65503693, 12.76931], [92.65473175, 12.76999187], [92.65444183, 12.7707119], [92.65426636, 12.77139759], [92.65454865, 12.77195168], [92.65490723, 12.77250767], [92.65528107, 12.77307129], [92.6556778, 12.77361774], [92.65612793, 12.77405262], [92.6567688, 12.77399445], [92.65724945, 12.77359486], [92.65753937, 12.77317619], [92.65730286, 12.77268124], [92.65686798, 12.77217674], [92.6566391, 12.77165985], [92.65644836, 12.77118969], [92.65643311, 12.77067089], [92.6565094, 12.77012062], [92.65628052, 12.76949024], [92.65584564, 12.76895905]]], [[[92.73144531, 12.70312405], [92.73145294, 12.70259094], [92.73087311, 12.70259094], [92.73088074, 12.70293045], [92.73116302, 12.7029171], [92.73116302, 12.70452118], [92.73143768, 12.70452118], [92.73170471, 12.70420933], [92.7317276, 12.70398998], [92.73226929, 12.70396709], [92.73229218, 12.70344067], [92.73253632, 12.7034111], [92.73254395, 12.70313263], [92.73144531, 12.70312405]]], [[[92.72425842, 12.73672962], [92.72425079, 12.73589134], [92.72621918, 12.73590946], [92.72615814, 12.73621178], [92.72701263, 12.73621178], [92.72705078, 12.73532963], [92.72766113, 12.73507309], [92.72757721, 12.73371506], [92.72814941, 12.73335361], [92.72812653, 12.73257732], [92.72870636, 12.7325592], [92.72870636, 12.73174095], [92.72926331, 12.73147202], [92.72926331, 12.73089123], [92.72957611, 12.73089123], [92.72953796, 12.72866154], [92.72901154, 12.72870255], [92.72870636, 12.72840405], [92.72872162, 12.72782516], [92.72843933, 12.72784424], [92.72840118, 12.72730637], [92.72786713, 12.7267313], [92.72704315, 12.72672653], [92.72697449, 12.72729206], [92.72670746, 12.72731209], [92.7266922, 12.72787094], [92.72618103, 12.72784996], [92.72619629, 12.72955132], [92.72589874, 12.72957993], [92.72589874, 12.73063087], [92.7256546, 12.73064709], [92.72561646, 12.73230362], [92.72510529, 12.73232365], [92.72512817, 12.732584], [92.72541046, 12.73284435], [92.72592163, 12.73286438], [92.72592926, 12.73339272], [92.72537231, 12.73339272], [92.72537231, 12.7331152], [92.72481537, 12.7331152], [92.72480774, 12.73369217], [92.72454834, 12.73367119], [92.72454834, 12.7339716], [92.72399139, 12.73393059], [92.72399902, 12.73510933], [92.7234726, 12.73507118], [92.72289276, 12.73561096], [92.72290039, 12.73593044], [92.72370911, 12.73672962], [92.72425842, 12.73672962]]], [[[92.72669983, 12.75137997], [92.72653198, 12.75137997], [92.72623444, 12.75146675], [92.72598267, 12.75168991], [92.72572327, 12.7518816], [92.72554779, 12.75217056], [92.72541809, 12.75248146], [92.72540283, 12.75281143], [92.72537994, 12.75326538], [92.72537994, 12.75351143], [92.72541809, 12.75367832], [92.7257309, 12.75382328], [92.72623444, 12.75380325], [92.72648621, 12.75367832], [92.72667694, 12.7533493], [92.72680664, 12.75292969], [92.72684479, 12.75254345], [92.72680664, 12.75219154], [92.72680664, 12.75157166], [92.72682953, 12.75142097], [92.72669983, 12.75137997]]], [[[92.71707916, 12.77478027], [92.71624756, 12.77478027], [92.7162323, 12.77531147], [92.71562958, 12.77565098], [92.71563721, 12.77701092], [92.71618652, 12.77699089], [92.71617126, 12.77674007], [92.71707916, 12.77672577], [92.71763611, 12.77616119], [92.71763611, 12.77561569], [92.71707916, 12.7750597], [92.71707916, 12.77478027]]], [[[92.91278076, 12.33166599], [92.91222382, 12.33166599], [92.91166687, 12.33222198], [92.91168213, 12.33249092], [92.91139221, 12.33278275], [92.91139221, 12.33305645], [92.91110992, 12.33333206], [92.91110992, 12.33471966], [92.91130066, 12.33490658], [92.91139221, 12.33500004], [92.91168213, 12.33500004], [92.91194153, 12.33528137], [92.91278076, 12.33444023], [92.91278076, 12.33416557], [92.91306305, 12.33388996], [92.91306305, 12.33360958], [92.91361237, 12.33305645], [92.91361237, 12.33278275], [92.91333008, 12.33249092], [92.91333008, 12.33222198], [92.91278076, 12.33166599]]], [[[92.90593719, 12.33850765], [92.90573883, 12.33835125], [92.90546417, 12.33845329], [92.90507507, 12.33876133], [92.90473938, 12.33930111], [92.90453339, 12.33997059], [92.90468597, 12.34068012], [92.90537262, 12.34114265], [92.90555573, 12.34106731], [92.90602112, 12.34087563], [92.90638733, 12.34037018], [92.90660858, 12.33985043], [92.90654755, 12.33933067], [92.90633392, 12.33884144], [92.90593719, 12.33850765]]], [[[92.91173553, 12.33795166], [92.91104889, 12.33769417], [92.91072083, 12.33773136], [92.91040039, 12.33788109], [92.91014099, 12.3382206], [92.90997314, 12.33868122], [92.909729, 12.33908939], [92.90950775, 12.33947182], [92.90930939, 12.33986187], [92.90908813, 12.34023094], [92.90882111, 12.3405571], [92.90857697, 12.34086037], [92.9083786, 12.34113598], [92.90842438, 12.3414526], [92.90865326, 12.34181023], [92.90898132, 12.34219074], [92.90937042, 12.342556], [92.90969086, 12.34295177], [92.90990448, 12.34338284], [92.91003418, 12.34383202], [92.91023254, 12.34423065], [92.91027832, 12.34466171], [92.9102478, 12.34507942], [92.91011047, 12.3454504], [92.90997314, 12.34579659], [92.90979004, 12.34608078], [92.90970612, 12.34643936], [92.90962219, 12.34681129], [92.90948486, 12.34720993], [92.90944672, 12.34767532], [92.90944672, 12.34817791], [92.9095459, 12.34869957], [92.90973663, 12.34916973], [92.90995026, 12.34961033], [92.91005707, 12.35007], [92.91023254, 12.35046196], [92.91034698, 12.35088062], [92.91056061, 12.3512001], [92.91078949, 12.35145092], [92.91101837, 12.35169029], [92.91121674, 12.35195923], [92.91143799, 12.35228062], [92.91168213, 12.35266781], [92.91197205, 12.35308075], [92.9122467, 12.35352516], [92.91255951, 12.35395145], [92.91290283, 12.35437965], [92.9133606, 12.35475063], [92.9139328, 12.35509968], [92.91449738, 12.35547066], [92.91504669, 12.35548115], [92.91558075, 12.35529137], [92.91609955, 12.35510921], [92.9165802, 12.35491085], [92.9169693, 12.35464001], [92.91738129, 12.35439968], [92.91773224, 12.35408115], [92.9180069, 12.35365963], [92.91832733, 12.35323143], [92.91860962, 12.35277081], [92.9188385, 12.35229874], [92.91889191, 12.3517704], [92.91889191, 12.35122967], [92.91888428, 12.35070992], [92.91880798, 12.35021973], [92.91858673, 12.34980106], [92.91832733, 12.34939957], [92.91805267, 12.34898663], [92.91777802, 12.34854126], [92.91750336, 12.34805107], [92.91720581, 12.34754944], [92.91689301, 12.34704971], [92.91652679, 12.34659672], [92.91628265, 12.34612179], [92.91609192, 12.34565067], [92.91584778, 12.34524727], [92.91562653, 12.34482098], [92.91536713, 12.34442043], [92.91509247, 12.34401035], [92.91477203, 12.34358978], [92.91445923, 12.3431797], [92.91416931, 12.34274006], [92.91387177, 12.34231186], [92.91352844, 12.34196091], [92.91317749, 12.34169197], [92.91285706, 12.34145927], [92.91262054, 12.34121132], [92.91243744, 12.34090137], [92.91221619, 12.34056091], [92.91203308, 12.34016037], [92.91197968, 12.33965015], [92.91204834, 12.33907127], [92.91208649, 12.33845997], [92.91173553, 12.33795166]]], [[[92.85290527, 12.40883064], [92.853302, 12.4087534], [92.85405731, 12.40888119], [92.85463715, 12.40878963], [92.85514832, 12.40859985], [92.85562134, 12.40838242], [92.85614014, 12.4083128], [92.85665131, 12.40819931], [92.85714722, 12.40804195], [92.85765839, 12.40785122], [92.85817719, 12.40773201], [92.85858917, 12.40751076], [92.85891724, 12.40723991], [92.85928345, 12.40699959], [92.85970306, 12.40683174], [92.86013031, 12.40664005], [92.86058044, 12.40639019], [92.86107635, 12.40610886], [92.86161804, 12.40583992], [92.86219025, 12.40558147], [92.86274719, 12.40530014], [92.86326599, 12.40501976], [92.86376953, 12.40471172], [92.86421967, 12.40444279], [92.86464691, 12.40417004], [92.86505127, 12.40391922], [92.86542511, 12.40374565], [92.86575317, 12.4036684], [92.86606598, 12.40380478], [92.86637878, 12.40387058], [92.86675262, 12.40389156], [92.86717224, 12.40389156], [92.86762238, 12.40389156], [92.86807251, 12.403862], [92.86847687, 12.40374088], [92.86884308, 12.40367985], [92.8691864, 12.40384197], [92.86955261, 12.40389156], [92.86995697, 12.4039402], [92.87034607, 12.40416145], [92.87078857, 12.40441132], [92.87126923, 12.40470982], [92.87181854, 12.40500164], [92.87241364, 12.40528202], [92.87303162, 12.40550137], [92.87368011, 12.40543461], [92.87408447, 12.40501308], [92.8741684, 12.40445042], [92.87421417, 12.40396023], [92.87442017, 12.40359116], [92.87458801, 12.4032011], [92.87477875, 12.40282059], [92.87502289, 12.40248299], [92.87527466, 12.40216637], [92.8755188, 12.40184975], [92.87571716, 12.4015007], [92.87594604, 12.40114975], [92.87625885, 12.40084171], [92.87661743, 12.40055275], [92.87702179, 12.40027714], [92.87748718, 12.40000057], [92.87800598, 12.39972115], [92.87856293, 12.39942932], [92.87909698, 12.39915085], [92.87960052, 12.39887142], [92.88006592, 12.3986063], [92.88054657, 12.39838123], [92.8811264, 12.39833546], [92.8817215, 12.39837646], [92.88224792, 12.39856052], [92.88278198, 12.39866066], [92.88321686, 12.39889622], [92.88362885, 12.39920998], [92.88394165, 12.39965725], [92.88424683, 12.40010357], [92.88441467, 12.40059376], [92.88445282, 12.40110016], [92.88445282, 12.40159035], [92.88437653, 12.40204144], [92.88421631, 12.40240955], [92.88418579, 12.40279961], [92.88432312, 12.4032011], [92.88457489, 12.40357494], [92.88491821, 12.40390968], [92.88524628, 12.40429115], [92.88548279, 12.40468025], [92.88562012, 12.40514088], [92.88581085, 12.40554047], [92.8859787, 12.40597725], [92.88616943, 12.4064436], [92.88643646, 12.40692139], [92.88684845, 12.40739918], [92.88748932, 12.40775013], [92.888237, 12.40793037], [92.88878632, 12.4076004], [92.88916016, 12.40699959], [92.88939667, 12.40639019], [92.88939667, 12.40583992], [92.88920593, 12.40537071], [92.88916779, 12.40493107], [92.88916779, 12.40448189], [92.88916779, 12.40400124], [92.88916779, 12.40344048], [92.88916779, 12.40287971], [92.88920593, 12.40233135], [92.88941956, 12.40183067], [92.88964081, 12.40135002], [92.88986969, 12.40089512], [92.89025116, 12.40056038], [92.89073944, 12.40032005], [92.89138031, 12.40030193], [92.8920517, 12.40040016], [92.8927002, 12.40052986], [92.89331055, 12.40055275], [92.89380646, 12.40040016], [92.89408875, 12.39976597], [92.89415741, 12.39901447], [92.89411163, 12.39835072], [92.89392853, 12.39776993], [92.89380646, 12.39716816], [92.89369202, 12.39655113], [92.8934021, 12.39610386], [92.89307404, 12.3956728], [92.89276886, 12.39518547], [92.8924408, 12.39468575], [92.89203644, 12.39425087], [92.89167786, 12.39382458], [92.89138794, 12.39340115], [92.89113617, 12.39301968], [92.89096069, 12.39264202], [92.89079285, 12.39227962], [92.89054871, 12.39195824], [92.89025116, 12.39164066], [92.88989258, 12.39133072], [92.88941956, 12.39110088], [92.88893127, 12.39091015], [92.8884201, 12.39083004], [92.88793945, 12.39076614], [92.88755035, 12.3905611], [92.88717651, 12.39033985], [92.88680267, 12.39013004], [92.88639069, 12.38992977], [92.88600159, 12.38971138], [92.88564301, 12.38945103], [92.88529968, 12.38918018], [92.88498688, 12.38889027], [92.88469696, 12.3886013], [92.88440704, 12.38833046], [92.88420868, 12.38806057], [92.8841629, 12.38773918], [92.88409424, 12.38747311], [92.88394165, 12.38724518], [92.8839035, 12.38700771], [92.88395691, 12.38675022], [92.88411713, 12.38647461], [92.8841629, 12.3861599], [92.88417053, 12.38581085], [92.88417053, 12.38543129], [92.8841629, 12.38502026], [92.88417053, 12.38458729], [92.88420868, 12.384161], [92.88437653, 12.38379192], [92.884552, 12.38338184], [92.88481903, 12.38296032], [92.88514709, 12.38251114], [92.88549042, 12.38204193], [92.88571167, 12.38149166], [92.88581848, 12.38093853], [92.88582611, 12.3804512], [92.88583374, 12.38003063], [92.88586426, 12.37964153], [92.88600159, 12.37925434], [92.88606262, 12.37886238], [92.88593292, 12.37847042], [92.88565826, 12.37812233], [92.88555145, 12.37777328], [92.88547516, 12.3774538], [92.88537598, 12.37716389], [92.88542938, 12.37680435], [92.88549805, 12.37636662], [92.88537598, 12.37591076], [92.88506317, 12.37545967], [92.8846817, 12.37493134], [92.88418579, 12.37442017], [92.88398743, 12.374156], [92.88374329, 12.37399197], [92.88329315, 12.37391186], [92.88275909, 12.37395096], [92.88223267, 12.37415123], [92.88173676, 12.37444115], [92.8814621, 12.37488079], [92.88149261, 12.37537098], [92.88165283, 12.37586498], [92.88179779, 12.37638474], [92.88196564, 12.37690353], [92.88217163, 12.37740421], [92.88217926, 12.3779211], [92.88201904, 12.37848186], [92.88195038, 12.37905788], [92.88194275, 12.37966537], [92.88194275, 12.38024998], [92.88189697, 12.38076973], [92.88169098, 12.38115978], [92.88152313, 12.3815403], [92.88134003, 12.38189983], [92.88109589, 12.38225079], [92.88080597, 12.38261127], [92.88041687, 12.38294029], [92.88005066, 12.38330173], [92.87963104, 12.38352108], [92.87921143, 12.38354969], [92.87885284, 12.38334084], [92.87848663, 12.38305092], [92.87806702, 12.38272095], [92.87760162, 12.3824091], [92.87708282, 12.38238144], [92.87657166, 12.38252926], [92.87612152, 12.38278008], [92.87573242, 12.38305092], [92.87536621, 12.38331985], [92.87496948, 12.38349819], [92.87452698, 12.38363934], [92.87416077, 12.38387012], [92.87375641, 12.38402462], [92.87352753, 12.3840704], [92.8733902, 12.38410187], [92.87306213, 12.38389015], [92.87270355, 12.38366032], [92.87230682, 12.38341141], [92.87195587, 12.38305092], [92.87164307, 12.38258171], [92.87126923, 12.38210773], [92.8708725, 12.38164139], [92.87049866, 12.38118935], [92.87014771, 12.38081074], [92.86989594, 12.38045979], [92.86969757, 12.38014984], [92.86949158, 12.37989044], [92.86933136, 12.37962055], [92.86915588, 12.37938404], [92.868927, 12.37917042], [92.86868286, 12.37893963], [92.86849213, 12.37863731], [92.86826324, 12.3783493], [92.86798096, 12.37810993], [92.86765289, 12.3779211], [92.86727905, 12.37780476], [92.86688232, 12.37782955], [92.8664856, 12.37804413], [92.86605835, 12.37827396], [92.86561584, 12.37847042], [92.865242, 12.37873173], [92.86483765, 12.37893105], [92.86444855, 12.37917042], [92.86399078, 12.37939072], [92.86342621, 12.37949085], [92.86284637, 12.37974167], [92.86229706, 12.38009071], [92.86183929, 12.38053703], [92.86141205, 12.38097954], [92.8610611, 12.38145065], [92.86078644, 12.38194084], [92.8605423, 12.382411], [92.86027527, 12.38285828], [92.86003113, 12.38329124], [92.85992432, 12.38376904], [92.86001587, 12.38422298], [92.8602066, 12.38464355], [92.86043549, 12.38504124], [92.86061859, 12.385499], [92.86083221, 12.38597965], [92.86099243, 12.38653183], [92.8609314, 12.38710976], [92.86078644, 12.38764095], [92.86057281, 12.38801956], [92.86030579, 12.38828945], [92.85999298, 12.38847065], [92.8596344, 12.38863659], [92.8592453, 12.38882446], [92.85879517, 12.38882446], [92.85832214, 12.3886652], [92.8578949, 12.38861942], [92.85749054, 12.38861942], [92.85710144, 12.3886404], [92.85668182, 12.38861942], [92.8562088, 12.38858986], [92.85571289, 12.38850117], [92.85520172, 12.38849163], [92.8547287, 12.38878059], [92.85427856, 12.38921356], [92.85385895, 12.38973427], [92.85338593, 12.39022064], [92.8529129, 12.39069843], [92.85243225, 12.39117622], [92.85196686, 12.39164352], [92.85151672, 12.39208126], [92.85105896, 12.39246559], [92.85061646, 12.39280128], [92.85022736, 12.3931179], [92.84989929, 12.39344025], [92.84957886, 12.39372921], [92.84916687, 12.39391613], [92.84880829, 12.39415264], [92.84842682, 12.39433098], [92.84803009, 12.39443111], [92.8476181, 12.39444923], [92.84727478, 12.39442635], [92.84680939, 12.39430809], [92.84642792, 12.39420128], [92.84609222, 12.39418507], [92.84576416, 12.39426231], [92.84545135, 12.39441109], [92.8451004, 12.39451122], [92.84474945, 12.39469147], [92.84435272, 12.39495087], [92.84421539, 12.39572811], [92.84391785, 12.39650536], [92.84397888, 12.39702034], [92.84413147, 12.39748096], [92.84416199, 12.39791965], [92.84411621, 12.39835644], [92.84393311, 12.39883232], [92.84384155, 12.3994112], [92.84365082, 12.40001011], [92.84365845, 12.40062141], [92.84385681, 12.40113926], [92.84397888, 12.40158081], [92.84413147, 12.40191269], [92.84416962, 12.40223312], [92.84416962, 12.40255165], [92.84416199, 12.40289116], [92.84417725, 12.40327168], [92.84426117, 12.40367985], [92.84449005, 12.4040699], [92.84480286, 12.40441418], [92.84512329, 12.40471172], [92.84544373, 12.40498066], [92.84575653, 12.40519142], [92.84607697, 12.40538025], [92.84638977, 12.40561008], [92.84670258, 12.40587902], [92.84703827, 12.40617847], [92.8474884, 12.40640068], [92.84793091, 12.40666962], [92.84838104, 12.40694141], [92.84886932, 12.40717602], [92.8494339, 12.40733147], [92.84999847, 12.4075222], [92.85048676, 12.40781021], [92.85092163, 12.4081583], [92.85132599, 12.40854073], [92.85179138, 12.40888119], [92.85250092, 12.40891266], [92.85290527, 12.40883064]]], [[[92.95536041, 12.41469002], [92.95501709, 12.41419125], [92.95472717, 12.41369915], [92.95443726, 12.41324139], [92.9541626, 12.4128418], [92.95391846, 12.41244984], [92.95380402, 12.41202354], [92.9536438, 12.41161346], [92.95357513, 12.41116905], [92.95340729, 12.41075039], [92.95334625, 12.41032124], [92.95333099, 12.40988064], [92.95333099, 12.40944099], [92.95326996, 12.40904045], [92.95305634, 12.40869236], [92.95278168, 12.40836143], [92.95240021, 12.40806484], [92.9519577, 12.40777969], [92.95150757, 12.40754986], [92.95104218, 12.40750027], [92.95059967, 12.40748405], [92.95019531, 12.40739918], [92.94978333, 12.40725136], [92.94932556, 12.40718079], [92.94890594, 12.40699959], [92.94846344, 12.40694809], [92.94802856, 12.40694141], [92.94761658, 12.40695], [92.9471817, 12.40695], [92.94668579, 12.40691185], [92.94616699, 12.40666103], [92.94565582, 12.40630054], [92.94527435, 12.40583611], [92.94497681, 12.40539074], [92.94473267, 12.4050312], [92.94451141, 12.40475845], [92.94444275, 12.4044199], [92.94443512, 12.40406704], [92.94454193, 12.40364075], [92.94428253, 12.40348053], [92.94397736, 12.40343094], [92.94386292, 12.40321922], [92.94367218, 12.40290928], [92.94352722, 12.40241718], [92.94332123, 12.40182018], [92.94306183, 12.40118027], [92.94285583, 12.40049076], [92.94284058, 12.39978886], [92.94302368, 12.39915562], [92.94313812, 12.39856052], [92.94330597, 12.39806557], [92.94333649, 12.39757156], [92.94333649, 12.39706135], [92.94333649, 12.39653015], [92.94332886, 12.3960104], [92.94328308, 12.39554119], [92.94309235, 12.39517879], [92.94304657, 12.39481163], [92.94304657, 12.3944397], [92.94301605, 12.39404106], [92.94284058, 12.39363956], [92.94274139, 12.39310932], [92.94258118, 12.39254379], [92.94273376, 12.39191723], [92.94281006, 12.39124012], [92.94294739, 12.39059544], [92.94281006, 12.3899641], [92.94271851, 12.38935089], [92.94252777, 12.38883972], [92.94252777, 12.38837147], [92.94270325, 12.3879509], [92.94281006, 12.38750172], [92.94299316, 12.38705063], [92.9430542, 12.38650894], [92.94306183, 12.38591194], [92.94304657, 12.38525963], [92.94300842, 12.38460827], [92.94278717, 12.38401985], [92.94260406, 12.38342476], [92.94247437, 12.38281727], [92.9422226, 12.3822813], [92.94194031, 12.38179779], [92.94161987, 12.38136005], [92.94126129, 12.38097], [92.94093323, 12.38058758], [92.94056702, 12.38027096], [92.94021606, 12.37996101], [92.93984222, 12.37970066], [92.93949127, 12.37943745], [92.93916321, 12.37917042], [92.93884277, 12.37890053], [92.93851471, 12.3786478], [92.93815613, 12.37842178], [92.93786621, 12.37813091], [92.93763733, 12.3777504], [92.93744659, 12.37731171], [92.93724823, 12.37689114], [92.93712616, 12.37644577], [92.93696594, 12.3760519], [92.93686676, 12.37564182], [92.93669891, 12.37524986], [92.93662262, 12.37477112], [92.936409, 12.37431335], [92.93624878, 12.37373447], [92.93613434, 12.37308216], [92.93611145, 12.37241745], [92.93611145, 12.37178135], [92.9360733, 12.37118244], [92.93583679, 12.37068462], [92.93562317, 12.37018967], [92.93546295, 12.3696413], [92.93531036, 12.36910057], [92.93527985, 12.36854172], [92.93522644, 12.36800003], [92.93505096, 12.36750984], [92.93495941, 12.36707687], [92.93479156, 12.36670113], [92.93473053, 12.36629963], [92.9347229, 12.3658514], [92.93467712, 12.36534023], [92.93457031, 12.36476135], [92.93464661, 12.36405468], [92.93437195, 12.36364174], [92.93401337, 12.36328888], [92.93371582, 12.36287022], [92.93350983, 12.36239624], [92.93335724, 12.36193085], [92.93331909, 12.3615036], [92.93322754, 12.36116028], [92.93308258, 12.3608799], [92.93296814, 12.36058998], [92.93278503, 12.36030769], [92.93258667, 12.35992336], [92.93234253, 12.35944939], [92.93197632, 12.35898972], [92.9313736, 12.35878468], [92.93107605, 12.35879898], [92.9307785, 12.35898972], [92.93054199, 12.35942078], [92.93028259, 12.35991764], [92.93000031, 12.36043072], [92.92970276, 12.36091423], [92.92935944, 12.36131954], [92.92896271, 12.36168003], [92.92856598, 12.36198997], [92.92814636, 12.36225033], [92.92775726, 12.36250019], [92.92736053, 12.36268044], [92.92690277, 12.36271], [92.92674255, 12.36266422], [92.9263916, 12.36257553], [92.92588806, 12.36256027], [92.92546082, 12.36278534], [92.92505646, 12.36304092], [92.92461395, 12.36323738], [92.92405701, 12.3632412], [92.92352295, 12.36339092], [92.92301941, 12.36367035], [92.92249298, 12.36392021], [92.92198181, 12.36417103], [92.9214859, 12.36438274], [92.92097473, 12.36443996], [92.92044067, 12.36444187], [92.91989136, 12.36446285], [92.91933441, 12.36461544], [92.91889954, 12.36502075], [92.91860962, 12.36556053], [92.91835785, 12.36614037], [92.91823578, 12.36672974], [92.91804504, 12.36726761], [92.91783905, 12.36776066], [92.91780853, 12.36828041], [92.91777802, 12.36876965], [92.91779327, 12.36923981], [92.9178772, 12.3696804], [92.91806793, 12.37010956], [92.91828918, 12.37057304], [92.91838074, 12.37111473], [92.91851044, 12.3716526], [92.91838837, 12.37224102], [92.91834259, 12.37285423], [92.91837311, 12.37346268], [92.91854858, 12.37401009], [92.91866302, 12.37452698], [92.91884613, 12.37495995], [92.91893768, 12.37543201], [92.91915894, 12.37586308], [92.91938019, 12.37632084], [92.91960144, 12.37683201], [92.91985321, 12.37731934], [92.92022705, 12.37774467], [92.92059326, 12.37819004], [92.92098236, 12.3786211], [92.9213562, 12.37903976], [92.92167664, 12.37945938], [92.92195129, 12.37983131], [92.92221832, 12.38011646], [92.92246246, 12.38038921], [92.92266846, 12.38072014], [92.92289734, 12.38105011], [92.9232254, 12.38129902], [92.92350769, 12.38156128], [92.92373657, 12.3817997], [92.92397308, 12.38205147], [92.92414093, 12.38236141], [92.92434692, 12.38266182], [92.92446136, 12.38299179], [92.92462158, 12.38325405], [92.92475128, 12.38354969], [92.92495728, 12.38387585], [92.92515564, 12.38430023], [92.92549133, 12.38474464], [92.92590332, 12.38521385], [92.92636108, 12.38564968], [92.9267807, 12.38606167], [92.92714691, 12.38634014], [92.92736816, 12.38661098], [92.92759705, 12.38677979], [92.92774963, 12.38700104], [92.92778015, 12.38731956], [92.92778015, 12.3876667], [92.927742, 12.38799191], [92.92758942, 12.38826084], [92.92743683, 12.38853741], [92.92723083, 12.38876057], [92.92701721, 12.38896084], [92.92684174, 12.38916874], [92.92665863, 12.38936234], [92.92642212, 12.38953972], [92.92617035, 12.38974953], [92.92584229, 12.38995934], [92.92534637, 12.39013004], [92.92485046, 12.39046955], [92.92450714, 12.39099026], [92.9245224, 12.39155006], [92.92471313, 12.39206123], [92.92488861, 12.39253044], [92.92498779, 12.393013], [92.92500305, 12.39350796], [92.92500305, 12.39399147], [92.92499542, 12.39446831], [92.92500305, 12.39493179], [92.92504883, 12.39540005], [92.92523193, 12.39585114], [92.92529297, 12.3964119], [92.92536926, 12.3970089], [92.92551422, 12.3976078], [92.92555237, 12.39821243], [92.92556763, 12.39879131], [92.92563629, 12.39931965], [92.92579651, 12.39978027], [92.92583466, 12.40025711], [92.92582703, 12.4007206], [92.92583466, 12.40117741], [92.92583466, 12.40163326], [92.92585754, 12.40209961], [92.92592621, 12.40258121], [92.92601013, 12.40308475], [92.92592621, 12.40362072], [92.92611694, 12.40415192], [92.92636871, 12.40467072], [92.92666626, 12.4051857], [92.92693329, 12.40568066], [92.9271698, 12.40617085], [92.92733765, 12.40664864], [92.92746735, 12.40711021], [92.9275589, 12.40759087], [92.92773438, 12.40801716], [92.92784119, 12.40849304], [92.92801666, 12.40897179], [92.92810059, 12.40952969], [92.92832947, 12.41002274], [92.92856598, 12.41055107], [92.92868805, 12.41116047], [92.92890167, 12.41172123], [92.92916107, 12.41224003], [92.92941284, 12.41275978], [92.92961121, 12.41328907], [92.92986298, 12.41374016], [92.93013, 12.41419792], [92.930336, 12.41468143], [92.93057251, 12.41518021], [92.93083191, 12.41567516], [92.93110657, 12.41617393], [92.93138123, 12.41664791], [92.93165588, 12.4171114], [92.9319458, 12.41755962], [92.93223572, 12.41803074], [92.93254089, 12.41852188], [92.93291473, 12.4189682], [92.9334259, 12.41926003], [92.93395996, 12.41951275], [92.93448639, 12.41973591], [92.93493652, 12.41999245], [92.93532562, 12.42022419], [92.93569946, 12.4204216], [92.9360733, 12.42066193], [92.93643188, 12.4210062], [92.93689728, 12.42135429], [92.93747711, 12.42160511], [92.93811798, 12.42171001], [92.9387207, 12.42189693], [92.93934631, 12.42194462], [92.93997955, 12.42194462], [92.94059753, 12.42189026], [92.94111633, 12.42168045], [92.94159698, 12.42142963], [92.94203186, 12.42112923], [92.94243622, 12.42083931], [92.94284058, 12.42056084], [92.9432373, 12.42031956], [92.94371033, 12.42017174], [92.94416809, 12.41998005], [92.94460297, 12.41972256], [92.9450531, 12.41943455], [92.94548035, 12.41910267], [92.94584656, 12.41871071], [92.94621277, 12.41834641], [92.94654083, 12.41798973], [92.9467392, 12.41759586], [92.94698334, 12.41729069], [92.94721222, 12.41701031], [92.94742584, 12.41670704], [92.9475708, 12.41631126], [92.94776154, 12.41596889], [92.94793701, 12.41561127], [92.9480896, 12.41515064], [92.94820404, 12.41465187], [92.94841766, 12.41436386], [92.94872284, 12.41438007], [92.9490509, 12.41463089], [92.94935608, 12.41497993], [92.94957733, 12.4154129], [92.94954681, 12.41587067], [92.94921875, 12.41630554], [92.94877625, 12.41683006], [92.94843292, 12.4174118], [92.948349, 12.41794682], [92.94834137, 12.41843891], [92.94832611, 12.41891098], [92.94832611, 12.41936016], [92.94832611, 12.41982079], [92.94833374, 12.42032433], [92.94837952, 12.42087078], [92.94856262, 12.42142963], [92.94856262, 12.42203999], [92.94843292, 12.42271137], [92.94857025, 12.42341042], [92.9486618, 12.42416], [92.94886017, 12.42483044], [92.94902039, 12.42545223], [92.94926453, 12.42593575], [92.94946289, 12.42634964], [92.94967651, 12.42673111], [92.94967651, 12.42714977], [92.94948578, 12.42757034], [92.94940186, 12.42807102], [92.94924164, 12.42857933], [92.94927216, 12.42912197], [92.94969177, 12.42959118], [92.95030212, 12.42978954], [92.95082092, 12.42996025], [92.95128632, 12.42999935], [92.95172119, 12.4300108], [92.95207977, 12.43006992], [92.95236969, 12.43025208], [92.95262146, 12.43040943], [92.95282745, 12.43059921], [92.95302582, 12.43085194], [92.95319366, 12.43126869], [92.95332336, 12.43182945], [92.95334625, 12.43248558], [92.95346832, 12.43312168], [92.95381927, 12.43362141], [92.95419312, 12.43406963], [92.95461273, 12.43451023], [92.95509338, 12.43502045], [92.95575714, 12.43545055], [92.95625305, 12.43548965], [92.95638275, 12.43525028], [92.95639038, 12.4349041], [92.95642853, 12.4345026], [92.95657349, 12.4340992], [92.95667267, 12.43365955], [92.95667267, 12.43319035], [92.95667267, 12.43271065], [92.95662689, 12.43224907], [92.95645905, 12.43182945], [92.95638275, 12.43138027], [92.95622253, 12.43094063], [92.95612335, 12.43045044], [92.95602417, 12.42993259], [92.95591736, 12.42942715], [92.95606995, 12.42895126], [92.95614624, 12.42849255], [92.95629883, 12.42812634], [92.95638275, 12.42776108], [92.95643616, 12.42740059], [92.95661926, 12.42708015], [92.95674896, 12.4267168], [92.95696259, 12.42634964], [92.95717621, 12.4259491], [92.95733643, 12.42544079], [92.95752716, 12.42490959], [92.95780945, 12.42443562], [92.95818329, 12.42404175], [92.95855713, 12.4236927], [92.95902252, 12.42346287], [92.95948029, 12.42321873], [92.9599762, 12.42303181], [92.96041107, 12.42277241], [92.96074677, 12.42243004], [92.96076202, 12.42175102], [92.96057129, 12.42121506], [92.96044159, 12.42076015], [92.96057129, 12.42031479], [92.96071625, 12.41983891], [92.96055603, 12.41932106], [92.96031952, 12.41876125], [92.96007538, 12.41819096], [92.95969391, 12.41774178], [92.95928955, 12.41734314], [92.95892334, 12.41697884], [92.95857239, 12.41664791], [92.95820618, 12.41639137], [92.95781708, 12.41618061], [92.95741272, 12.41607094], [92.9569931, 12.41591358], [92.95652771, 12.41576576], [92.95609283, 12.41551113], [92.95569611, 12.4151392], [92.95536041, 12.41469002]]], [[[92.89693451, 12.39207745], [92.89671326, 12.39196968], [92.89639282, 12.39204025], [92.8959198, 12.39233017], [92.89541626, 12.39279747], [92.89550781, 12.39331436], [92.89554596, 12.3938818], [92.89558411, 12.39443111], [92.89581299, 12.39492321], [92.89618683, 12.3951807], [92.89686584, 12.39516926], [92.89743042, 12.39484119], [92.897789, 12.39431858], [92.89774323, 12.39366055], [92.89753723, 12.39299107], [92.89731598, 12.39240932], [92.89693451, 12.39207745]]], [[[92.89916992, 12.40750027], [92.89861298, 12.40750027], [92.89861298, 12.40777111], [92.89749908, 12.40888977], [92.89749908, 12.41110992], [92.89805603, 12.4113903], [92.89916992, 12.4113903], [92.89916992, 12.40777111], [92.89916992, 12.40750027]]], [[[92.88935089, 12.41285133], [92.88913727, 12.41257095], [92.88899994, 12.41271019], [92.88878632, 12.41298771], [92.88844299, 12.41312027], [92.88829803, 12.41333199], [92.88829803, 12.41381073], [92.88858032, 12.41416168], [92.88899994, 12.41423035], [92.88935089, 12.41416168], [92.88948822, 12.41395187], [92.88948822, 12.41354179], [92.88935089, 12.41285133]]], [[[92.8317337, 12.42682171], [92.83277893, 12.42666721], [92.83361053, 12.42667198], [92.83389282, 12.42639065], [92.8347168, 12.42639065], [92.83499908, 12.42611122], [92.83528137, 12.42611122], [92.83555603, 12.42583275], [92.83640289, 12.42584038], [92.83666992, 12.4255619], [92.83721924, 12.4255619], [92.83777618, 12.42500114], [92.83805847, 12.42500114], [92.84055328, 12.42250061], [92.84111023, 12.42222118], [92.84139252, 12.42194462], [92.84194183, 12.42111111], [92.84222412, 12.42083263], [92.84249878, 12.42083263], [92.84278107, 12.42055416], [92.84278107, 12.42028141], [92.84333038, 12.41971111], [92.84361267, 12.41972256], [92.84416962, 12.41916561], [92.84443665, 12.41917133], [92.84583282, 12.41778088], [92.84583282, 12.41749954], [92.8466568, 12.4166708], [92.8466568, 12.41639137], [92.84694672, 12.41611004], [92.84694672, 12.41582966], [92.84638977, 12.41527843], [92.84638977, 12.41499996], [92.84610748, 12.41471958], [92.84583282, 12.41472244], [92.84555817, 12.41444397], [92.84471893, 12.41444397], [92.84444427, 12.41472244], [92.84416962, 12.41471958], [92.84388733, 12.41499996], [92.84361267, 12.41499996], [92.84333038, 12.4152813], [92.8408432, 12.4152813], [92.84055328, 12.41499996], [92.83889008, 12.41499996], [92.83860779, 12.4152813], [92.83833313, 12.4152813], [92.83805847, 12.41556072], [92.83750153, 12.41555595], [92.83721924, 12.41583443], [92.83666992, 12.41583443], [92.83640289, 12.41611004], [92.83611298, 12.41611004], [92.83528137, 12.41694355], [92.83499908, 12.41694355], [92.83472443, 12.41722202], [92.83444214, 12.41722012], [92.83416748, 12.41749954], [92.83389282, 12.41749954], [92.83333588, 12.41806126], [92.83110809, 12.42028141], [92.83083344, 12.42027855], [92.83000183, 12.42111111], [92.83000183, 12.42139053], [92.82971954, 12.4216671], [92.82971954, 12.42194462], [92.82943726, 12.42222118], [92.82944489, 12.4230547], [92.82917023, 12.42333031], [92.82917023, 12.42361069], [92.82944489, 12.42388916], [92.82943726, 12.4247179], [92.82971954, 12.42500114], [92.82971954, 12.4255619], [92.83055878, 12.42639065], [92.83093262, 12.4267168], [92.83141327, 12.42677879], [92.8317337, 12.42682171]]], [[[92.90323639, 12.42018986], [92.90288544, 12.42008018], [92.90248108, 12.4202404], [92.90200043, 12.42037201], [92.90151978, 12.42054081], [92.90100861, 12.42067146], [92.90048218, 12.42080975], [92.89995575, 12.42095566], [92.89962769, 12.42142963], [92.89946747, 12.42201996], [92.89948273, 12.42259026], [92.89959717, 12.42309093], [92.89969635, 12.42358971], [92.89975739, 12.42413044], [92.89990997, 12.42466068], [92.8999939, 12.42519474], [92.90008545, 12.42568493], [92.90042114, 12.42602158], [92.90091705, 12.42612934], [92.90164948, 12.42601109], [92.90223694, 12.42577076], [92.90270996, 12.42547131], [92.90309143, 12.42513561], [92.90348053, 12.42475033], [92.90392303, 12.4242897], [92.90442657, 12.4237318], [92.90485382, 12.42313004], [92.9048233, 12.42273998], [92.90468597, 12.42235661], [92.90444946, 12.42198086], [92.90422058, 12.42152977], [92.90402222, 12.4210062], [92.90364838, 12.42056084], [92.90348816, 12.42031956], [92.90323639, 12.42018986]]], [[[92.86587524, 12.42100334], [92.86589813, 12.42068672], [92.86751556, 12.42072296], [92.86754608, 12.42045021], [92.86808014, 12.42045021], [92.86891937, 12.41964054], [92.86895752, 12.41574574], [92.8691864, 12.41573048], [92.86921692, 12.41378117], [92.86839294, 12.41379929], [92.86810303, 12.41322041], [92.86750793, 12.41320038], [92.86750793, 12.41292191], [92.86727142, 12.41265965], [92.86584473, 12.41264057], [92.8658371, 12.41236115], [92.8653183, 12.4123497], [92.86532593, 12.41265011], [92.86226654, 12.4126482], [92.86226654, 12.41291332], [92.86171722, 12.41298294], [92.86167908, 12.41347313], [92.86060333, 12.41349125], [92.86058807, 12.41405201], [92.86009216, 12.41407013], [92.85890198, 12.41541958], [92.85890198, 12.41680813], [92.8595047, 12.41737461], [92.86006165, 12.4173727], [92.86000824, 12.41792202], [92.86061859, 12.41794014], [92.86061859, 12.41822147], [92.86115265, 12.41822147], [92.86113739, 12.4185009], [92.86172485, 12.4185009], [92.86171722, 12.41878128], [92.86252594, 12.41880035], [92.86367035, 12.42016029], [92.86421967, 12.42018795], [92.86420441, 12.42043114], [92.86476898, 12.42042923], [92.86474609, 12.42076015], [92.86532593, 12.42073917], [92.86532593, 12.42100334], [92.86587524, 12.42100334]]], [[[92.66895294, 12.95335007], [92.66895294, 12.95306969], [92.66945648, 12.9531002], [92.66979218, 12.95280075], [92.66983795, 12.95221806], [92.66916656, 12.95167065], [92.66868591, 12.95162964], [92.66870117, 12.95278072], [92.6681366, 12.95275974], [92.66812134, 12.95361042], [92.66868591, 12.95360088], [92.66895294, 12.95335007]]], [[[92.67150879, 12.94834137], [92.67008972, 12.94830036], [92.67006683, 12.94948006], [92.67230225, 12.94943047], [92.67260742, 12.94919968], [92.67263794, 12.94888115], [92.67177582, 12.94886971], [92.67177582, 12.9486208], [92.67150879, 12.94834137]]], [[[92.72499847, 12.7616663], [92.72444153, 12.7616663], [92.72444153, 12.76194191], [92.72277832, 12.76361179], [92.72277832, 12.76389027], [92.72110748, 12.7655611], [92.72110748, 12.76666641], [92.72083282, 12.76694393], [92.72083282, 12.76721954], [92.72000122, 12.76805687], [92.72000122, 12.76833153], [92.71888733, 12.7694397], [92.71888733, 12.77028084], [92.71778107, 12.77139091], [92.71805573, 12.77166653], [92.71806335, 12.77333069], [92.71888733, 12.77416706], [92.71888733, 12.77444458], [92.71861267, 12.77472115], [92.71888733, 12.77501011], [92.71888733, 12.77555466], [92.71916962, 12.77583122], [92.71916962, 12.77639103], [92.71971893, 12.77666664], [92.72000122, 12.7769413], [92.72000122, 12.77777672], [92.71944427, 12.77805519], [92.71527863, 12.77833271], [92.71527863, 12.77944469], [92.71555328, 12.77972126], [92.71555328, 12.78111076], [92.71721649, 12.78194141], [92.71778107, 12.78249931], [92.71778107, 12.78388977], [92.71749878, 12.78416634], [92.71749878, 12.78471947], [92.71721649, 12.78499985], [92.71749878, 12.78527832], [92.71749878, 12.78583241], [92.71721649, 12.78611183], [92.71721649, 12.7863903], [92.71666718, 12.78695107], [92.71721649, 12.78750038], [92.71721649, 12.78777981], [92.71833038, 12.78777981], [92.71833038, 12.78722191], [92.71888733, 12.78694439], [92.71943665, 12.7863903], [92.71943665, 12.78611183], [92.71971893, 12.78583241], [92.71971893, 12.78555584], [92.72000122, 12.78528023], [92.72000122, 12.78499985], [92.72027588, 12.78471947], [92.72027588, 12.78444576], [92.72055817, 12.78416634], [92.72055817, 12.78249931], [92.72083282, 12.78222084], [92.72083282, 12.78194141], [92.72110748, 12.78166771], [92.72110748, 12.78139019], [92.72138977, 12.78110886], [92.72138977, 12.77972126], [92.72194672, 12.77916527], [92.72194672, 12.77889156], [92.72222137, 12.77861118], [92.72222137, 12.77666664], [92.72249603, 12.77639103], [92.72249603, 12.7744379], [92.72277832, 12.77416706], [92.72277832, 12.77389145], [92.72305298, 12.77361107], [92.72305298, 12.77305889], [92.72277832, 12.77278137], [92.7233429, 12.77222061], [92.72333527, 12.771945], [92.72360992, 12.7716713], [92.72360992, 12.77139091], [92.7233429, 12.77111053], [92.72360992, 12.77083302], [92.72360992, 12.77027893], [92.72389221, 12.77000141], [92.72389221, 12.7694397], [92.72416687, 12.76916695], [92.72416687, 12.76861], [92.72444153, 12.76832962], [92.72444153, 12.76777935], [92.72416687, 12.76749992], [92.72444153, 12.76721954], [92.72444153, 12.76694393], [92.72472382, 12.76666641], [92.72471619, 12.76361179], [92.7250061, 12.76333046], [92.72499847, 12.7630558], [92.72528076, 12.76278019], [92.72528076, 12.76222038], [92.72499847, 12.76194382], [92.72499847, 12.7616663]]], [[[92.72763062, 12.83647156], [92.72763062, 12.83588791], [92.72786713, 12.8359108], [92.72788239, 12.83533001], [92.7273407, 12.83507919], [92.72730255, 12.83393955], [92.72677612, 12.83393955], [92.72673798, 12.83342171], [92.72566986, 12.83230114], [92.7253952, 12.83230305], [92.72506714, 12.83257198], [92.72503662, 12.83309174], [92.724823, 12.83307076], [92.72479248, 12.83393002], [92.72506714, 12.83393002], [92.72512054, 12.83449078], [92.72540283, 12.83455944], [92.72541809, 12.83563137], [92.72592926, 12.83562565], [92.72595215, 12.83702564], [92.72644043, 12.83751774], [92.72705841, 12.83813953], [92.72789001, 12.83813953], [92.72792053, 12.83647156], [92.72763062, 12.83647156]]], [[[92.69777679, 12.79068184], [92.69748688, 12.79107094], [92.69713593, 12.79146099], [92.6967926, 12.79182816], [92.69654083, 12.79223442], [92.6963501, 12.79264164], [92.69612122, 12.79296112], [92.69593048, 12.79325008], [92.69578552, 12.79350758], [92.69561005, 12.79370117], [92.69548798, 12.79394054], [92.6953125, 12.7942009], [92.69523621, 12.79459], [92.69506836, 12.79496193], [92.69499207, 12.79540157], [92.69487762, 12.79582977], [92.69474792, 12.79624653], [92.69469452, 12.79671383], [92.69454193, 12.79714298], [92.69451904, 12.79754162], [92.69468689, 12.79796124], [92.69476318, 12.79845142], [92.69495392, 12.7988863], [92.69504547, 12.79948139], [92.69532013, 12.80003071], [92.69567871, 12.8005209], [92.6960907, 12.800951], [92.69651031, 12.80133438], [92.6969986, 12.80157375], [92.69749451, 12.80163479], [92.69794464, 12.80148697], [92.69830322, 12.80126095], [92.69857788, 12.80104256], [92.69880676, 12.80084419], [92.6990509, 12.80068016], [92.69930267, 12.80051136], [92.69957733, 12.80031776], [92.69987488, 12.80023766], [92.70017242, 12.80043411], [92.70057678, 12.80060863], [92.70054626, 12.8008213], [92.70033264, 12.8010807], [92.70012665, 12.80139637], [92.69994354, 12.80170345], [92.69975281, 12.80196953], [92.699646, 12.8022604], [92.69947815, 12.80253124], [92.69941711, 12.80286121], [92.69930267, 12.80320454], [92.6991806, 12.80359268], [92.69909668, 12.80402088], [92.6989212, 12.80439091], [92.69882965, 12.80475807], [92.69871521, 12.80504227], [92.69888306, 12.80532265], [92.69908142, 12.80562973], [92.69921875, 12.80598068], [92.69944, 12.80621243], [92.69960785, 12.80640125], [92.69973755, 12.80661011], [92.69986725, 12.80683231], [92.69998169, 12.80711174], [92.69999695, 12.8074007], [92.70000458, 12.80775928], [92.7000351, 12.80822372], [92.70021057, 12.80873203], [92.70033264, 12.80930042], [92.70055389, 12.80980396], [92.70079803, 12.81023026], [92.70102692, 12.81058979], [92.70119476, 12.81089687], [92.70134735, 12.81114101], [92.70143127, 12.81147194], [92.70159912, 12.81178188], [92.70166016, 12.81215954], [92.70166779, 12.81257725], [92.70166779, 12.81301022], [92.70166779, 12.81344318], [92.70170593, 12.81383991], [92.70189667, 12.8141613], [92.70204163, 12.81453705], [92.70224762, 12.81493187], [92.7026062, 12.81527138], [92.70305634, 12.81555557], [92.70349121, 12.81578159], [92.70391846, 12.81583023], [92.7042923, 12.81583881], [92.70461273, 12.81589985], [92.70484924, 12.8161211], [92.7050705, 12.81639004], [92.70529938, 12.81668186], [92.70552826, 12.81697083], [92.70567322, 12.81734085], [92.70584869, 12.81770134], [92.70606995, 12.81805897], [92.70614624, 12.81856918], [92.70636749, 12.81906128], [92.70652008, 12.81957626], [92.70664978, 12.82008171], [92.70667267, 12.820611], [92.70666504, 12.82114887], [92.70667267, 12.82167053], [92.70667267, 12.82217026], [92.70667267, 12.82262135], [92.70666504, 12.82300854], [92.70666504, 12.82336044], [92.70671082, 12.82368088], [92.70687103, 12.82398033], [92.70693207, 12.82432175], [92.70694733, 12.82469082], [92.70697784, 12.82503986], [92.70713043, 12.82533073], [92.70720673, 12.82563019], [92.70722198, 12.8259716], [92.70722198, 12.82631111], [92.70722961, 12.82667065], [92.7073288, 12.82704067], [92.70746613, 12.82742977], [92.70749664, 12.82787037], [92.70749664, 12.8283596], [92.70751953, 12.82886791], [92.70770264, 12.82934856], [92.7080307, 12.82971191], [92.70847321, 12.82995987], [92.70868683, 12.82996464], [92.70900726, 12.82997417], [92.70946503, 12.82981873], [92.70987701, 12.82967091], [92.71016693, 12.82946301], [92.71043396, 12.82929707], [92.71070099, 12.82915974], [92.71096802, 12.82903004], [92.71121979, 12.8289299], [92.71152496, 12.82901859], [92.71192932, 12.82918262], [92.71238708, 12.82941532], [92.71292114, 12.82954121], [92.71302795, 12.82952499], [92.71342468, 12.82946587], [92.71391296, 12.82938957], [92.71421814, 12.82916927], [92.71448517, 12.82892799], [92.71472931, 12.82870197], [92.71494293, 12.82842159], [92.71504974, 12.82796097], [92.71524811, 12.82743931], [92.71526337, 12.82685757], [92.71515656, 12.82628155], [92.71498108, 12.82573891], [92.71476746, 12.82527924], [92.7146759, 12.82474995], [92.71447754, 12.8243103], [92.7143631, 12.82382011], [92.71420288, 12.82335281], [92.71413422, 12.82286453], [92.71398163, 12.82243919], [92.71385956, 12.82199001], [92.71364594, 12.82155037], [92.71355438, 12.82100964], [92.71335602, 12.82046127], [92.71326447, 12.8198204], [92.71308899, 12.81915665], [92.7130127, 12.81842136], [92.7128067, 12.81770134], [92.71277618, 12.81695461], [92.71277618, 12.8162384], [92.71277618, 12.81559944], [92.71279144, 12.81507111], [92.71289063, 12.81463146], [92.71302795, 12.81423187], [92.71305847, 12.81379032], [92.71305847, 12.81330204], [92.7130127, 12.81278706], [92.71286011, 12.81227016], [92.7130127, 12.81174088], [92.71296692, 12.81118011], [92.7128067, 12.81058121], [92.71277618, 12.80992031], [92.71277618, 12.80921078], [92.71277618, 12.80850029], [92.71277618, 12.80777073], [92.71277618, 12.80704117], [92.71274567, 12.8063097], [92.71257019, 12.80560303], [92.71250916, 12.80489445], [92.71253967, 12.8042078], [92.71273041, 12.80358791], [92.71277618, 12.80299282], [92.71277618, 12.8024416], [92.71277618, 12.80194283], [92.71277618, 12.80148029], [92.71277618, 12.8010397], [92.71277618, 12.79644108], [92.71277618, 12.79587078], [92.71277618, 12.79536057], [92.71277618, 12.79484081], [92.71283722, 12.79428291], [92.71302795, 12.79367161], [92.71315002, 12.79297161], [92.71330261, 12.79227543], [92.71337891, 12.79160881], [92.71356964, 12.79109192], [92.71362305, 12.79061127], [92.71369171, 12.79022789], [92.71385193, 12.78991985], [92.71389008, 12.78955078], [92.71389008, 12.78911972], [92.71389008, 12.78866005], [92.71389008, 12.78816128], [92.71387482, 12.78765488], [92.71383667, 12.78714657], [92.71386719, 12.78664112], [92.71380615, 12.78619862], [92.71364594, 12.78581142], [92.71360779, 12.78542995], [92.71360779, 12.78507042], [92.71360779, 12.78474236], [92.71356201, 12.78443718], [92.71337891, 12.78418064], [92.71333313, 12.78386021], [92.7133255, 12.78351402], [92.71325684, 12.78314686], [92.71309662, 12.78276157], [92.71305847, 12.78229046], [92.71303558, 12.78177929], [92.71292877, 12.78127956], [92.7128067, 12.7807703], [92.71277618, 12.78024483], [92.71273804, 12.7797327], [92.71253967, 12.77928352], [92.71245575, 12.77876186], [92.71225739, 12.77823734], [92.71222687, 12.77764034], [92.7122879, 12.77705479], [92.71247101, 12.77654171], [92.71256256, 12.77608776], [92.7127533, 12.77578068], [92.71279144, 12.77545929], [92.71289063, 12.77517033], [92.71302795, 12.77485275], [92.71309662, 12.77441311], [92.71328735, 12.77398014], [92.71338654, 12.77348137], [92.71361542, 12.7730751], [92.71389771, 12.77273083], [92.71421814, 12.77245522], [92.7145462, 12.77219486], [92.71481323, 12.77186966], [92.71508789, 12.77155972], [92.71531677, 12.77118969], [92.71559143, 12.77086735], [92.71588135, 12.7705698], [92.71617889, 12.77028084], [92.71646881, 12.76999187], [92.71672058, 12.76966095], [92.71695709, 12.76931], [92.71721649, 12.76898193], [92.717453, 12.76866531], [92.71769714, 12.76839638], [92.71785736, 12.76809978], [92.71807861, 12.76786137], [92.71831512, 12.76767445], [92.71852112, 12.76743031], [92.71865845, 12.76708317], [92.7188797, 12.7667551], [92.71910095, 12.76638126], [92.71930695, 12.76595974], [92.71951294, 12.76548958], [92.71975708, 12.76506901], [92.72003937, 12.76467037], [92.72029114, 12.76425266], [92.72055817, 12.76385212], [92.72080994, 12.76346397], [92.72100067, 12.7630682], [92.72119141, 12.76270962], [92.72141266, 12.76237011], [92.72164154, 12.76204681], [92.72181702, 12.76165009], [92.72198486, 12.76124001], [92.72219086, 12.76084995], [92.72229004, 12.760396], [92.72247314, 12.75996971], [92.72259521, 12.75949764], [92.72277069, 12.75906086], [92.72293091, 12.75858021], [92.7230835, 12.75807858], [92.7233429, 12.75764084], [92.72358704, 12.75723457], [92.72374725, 12.75680923], [92.72389984, 12.75641918], [92.72406769, 12.75607967], [92.72419739, 12.75575161], [92.72437286, 12.75545979], [92.7250061, 12.75440884], [92.72486115, 12.75393009], [92.72475433, 12.75337696], [92.724823, 12.75300121], [92.72489929, 12.7526722], [92.72475433, 12.75205231], [92.72475433, 12.75149632], [92.7246933, 12.75113201], [92.7246933, 12.75067139], [92.72471619, 12.75000095], [92.7250061, 12.74972057], [92.72528839, 12.74924946], [92.72550201, 12.74870014], [92.72554016, 12.74807072], [92.72544861, 12.74740982], [92.72525787, 12.74680805], [92.7250061, 12.74628162], [92.72473145, 12.74580097], [92.72453308, 12.74534035], [92.72445679, 12.74487114], [92.72444153, 12.74440098], [92.72441101, 12.74398041], [92.72424316, 12.74364853], [92.72413635, 12.7432909], [92.72396851, 12.74300194], [92.72380829, 12.74271297], [92.72361755, 12.74253273], [92.7233429, 12.74253464], [92.72303772, 12.74276257], [92.72270966, 12.74309063], [92.72246552, 12.74354362], [92.72221375, 12.74398899], [92.7219696, 12.74440098], [92.72180939, 12.74484825], [92.72167206, 12.74526978], [92.72154236, 12.74567127], [92.72141266, 12.74604034], [92.72138977, 12.74647141], [92.72138977, 12.74691105], [92.72138977, 12.74736023], [92.72135925, 12.74778843], [92.72118378, 12.74816227], [92.72107697, 12.74854469], [92.72088623, 12.74887085], [92.72083282, 12.7492218], [92.72083282, 12.74959087], [92.72080231, 12.74993992], [92.72064209, 12.75023079], [92.72052765, 12.75057793], [92.72034454, 12.75091076], [92.72019196, 12.75124073], [92.72003937, 12.75128365], [92.719841, 12.75134087], [92.71955872, 12.7511797], [92.71936035, 12.75100613], [92.71914673, 12.75069046], [92.71894836, 12.7503109], [92.71888733, 12.74984169], [92.71888733, 12.74934864], [92.71888733, 12.74885941], [92.71888733, 12.74836922], [92.71888733, 12.74789333], [92.71888733, 12.74742794], [92.71888733, 12.74697018], [92.71888733, 12.74652576], [92.71888733, 12.74606991], [92.71888733, 12.74559975], [92.71882629, 12.74513531], [92.71865082, 12.74470043], [92.71856689, 12.74420071], [92.71834564, 12.74380398], [92.71816254, 12.74343109], [92.71806335, 12.74309063], [92.71807098, 12.74279022], [92.71817017, 12.74253941], [92.7183075, 12.74227047], [92.71833801, 12.74195385], [92.71841431, 12.7416048], [92.71857452, 12.74124336], [92.71861267, 12.74077988], [92.71861267, 12.74030113], [92.71859741, 12.73984146], [92.71846771, 12.73944378], [92.71835327, 12.73905945], [92.71833038, 12.73863125], [92.71833038, 12.73818398], [92.71833038, 12.73772812], [92.71833038, 12.73727226], [92.71833038, 12.73682594], [92.71833038, 12.73639011], [92.71833801, 12.73597336], [92.71831512, 12.73556519], [92.71821594, 12.7351799], [92.71808624, 12.73482037], [92.71806335, 12.73437119], [92.71805573, 12.73391342], [92.71812439, 12.73344612], [92.71835327, 12.7330513], [92.71859741, 12.7326889], [92.71877289, 12.73233128], [92.71887207, 12.73200989], [92.71888733, 12.73171139], [92.71888733, 12.73143101], [92.71884918, 12.73113918], [92.71871185, 12.73087025], [92.71872711, 12.73062897], [92.71879578, 12.73042107], [92.71891785, 12.73019123], [92.71914673, 12.729949], [92.71940613, 12.72964191], [92.71959686, 12.72926998], [92.71968842, 12.72887135], [92.71958923, 12.72848606], [92.71945953, 12.72811031], [92.71944427, 12.72774601], [92.71943665, 12.72735119], [92.71943665, 12.7269001], [92.71943665, 12.72636032], [92.71949005, 12.72580147], [92.71968079, 12.72523785], [92.71971893, 12.72466183], [92.71972656, 12.72412205], [92.71972656, 12.72362041], [92.71972656, 12.72314167], [92.71970367, 12.72267914], [92.71959686, 12.72225094], [92.71942139, 12.7218399], [92.71922302, 12.72141171], [92.71914673, 12.72083473], [92.71900177, 12.72020245], [92.71872711, 12.71959114], [92.71826172, 12.71910954], [92.71803284, 12.71889973], [92.71772766, 12.71889114], [92.71734619, 12.71892834], [92.71694946, 12.71912956], [92.71653748, 12.71935558], [92.71627808, 12.7198143], [92.71598053, 12.72021961], [92.71560669, 12.72047138], [92.71546173, 12.72044754], [92.71516418, 12.72039986], [92.71463776, 12.72012901], [92.71405029, 12.71989155], [92.71354675, 12.71953201], [92.71308899, 12.71948147], [92.712677, 12.71967983], [92.71227264, 12.71976185], [92.71193695, 12.7199707], [92.71156311, 12.72000122], [92.71115112, 12.72001743], [92.71073914, 12.72010136], [92.71034241, 12.72026062], [92.70992279, 12.72028065], [92.7095108, 12.72026062], [92.7091217, 12.72010136], [92.70876312, 12.71995068], [92.70845032, 12.71975327], [92.70818329, 12.71963024], [92.70796967, 12.71979141], [92.7078476, 12.72040939], [92.70796967, 12.72093964], [92.70833588, 12.72121811], [92.70874786, 12.72148037], [92.70907593, 12.72186089], [92.70941162, 12.72218704], [92.70968628, 12.7225132], [92.7098465, 12.72292137], [92.71002197, 12.7233696], [92.71025848, 12.72377968], [92.71044922, 12.72418308], [92.71054077, 12.72456169], [92.71055603, 12.72491932], [92.71055603, 12.72523785], [92.71051025, 12.72556019], [92.71031952, 12.7259016], [92.71025848, 12.72630692], [92.71025085, 12.72671986], [92.71083069, 12.72720146], [92.7111969, 12.72760582], [92.71134949, 12.72795963], [92.71134186, 12.72828102], [92.7111969, 12.72849083], [92.71096802, 12.72859097], [92.71070862, 12.72859573], [92.71047974, 12.72847462], [92.71026611, 12.72810841], [92.71000671, 12.72750187], [92.70974731, 12.72725105], [92.70952606, 12.72729015], [92.70925903, 12.72757721], [92.70902252, 12.72810268], [92.70910645, 12.72888088], [92.70907593, 12.72957993], [92.70883179, 12.73007679], [92.70865631, 12.73049164], [92.70867157, 12.73085022], [92.7088623, 12.73118019], [92.70888519, 12.73139], [92.70944214, 12.73194408], [92.70944214, 12.7322216], [92.71028137, 12.73305607], [92.71028137, 12.73333359], [92.71055603, 12.73361206], [92.71055603, 12.7344389], [92.71111298, 12.73499966], [92.71111298, 12.73527813], [92.71138763, 12.7355814], [92.71160126, 12.7358799], [92.71179199, 12.73623085], [92.71201324, 12.73659992], [92.71225739, 12.73691177], [92.71248627, 12.73723602], [92.71264648, 12.73765278], [92.71276093, 12.73816967], [92.71277618, 12.73876953], [92.71277618, 12.7393961], [92.71277618, 12.74002075], [92.71277618, 12.74061108], [92.71276855, 12.74113083], [92.71269989, 12.74158192], [92.71253204, 12.74193954], [92.71246338, 12.74237537], [92.7122879, 12.74273109], [92.71221161, 12.74312115], [92.71208954, 12.7434597], [92.71195984, 12.74382019], [92.71189117, 12.7442646], [92.71170807, 12.7446909], [92.71164703, 12.74518108], [92.71157837, 12.74562073], [92.71141815, 12.74596024], [92.71138763, 12.74629784], [92.71138, 12.74662971], [92.71131897, 12.74698639], [92.71116638, 12.74733925], [92.71124268, 12.74775887], [92.71136475, 12.74815655], [92.71135712, 12.74851131], [92.71128082, 12.74882984], [92.71127319, 12.74916935], [92.7113266, 12.74963188], [92.7111969, 12.75020027], [92.71112061, 12.75088978], [92.71115112, 12.7516098], [92.71138763, 12.75226021], [92.71161652, 12.75284958], [92.71166992, 12.75342941], [92.71166992, 12.75393963], [92.71161652, 12.75439072], [92.71142578, 12.75473976], [92.71138763, 12.75514984], [92.71138763, 12.75561047], [92.71134949, 12.75615025], [92.71115112, 12.75677013], [92.71111298, 12.75748062], [92.71111298, 12.75820637], [92.71111298, 12.75889015], [92.71111298, 12.75953007], [92.7110672, 12.76014137], [92.71087646, 12.76077461], [92.71080017, 12.76145554], [92.71061707, 12.76208115], [92.71051788, 12.76272583], [92.71031952, 12.76329136], [92.71025085, 12.76384926], [92.71012115, 12.76432991], [92.70998383, 12.76479053], [92.70980835, 12.76520061], [92.70968628, 12.76564121], [92.70949554, 12.76601696], [92.70941162, 12.76646996], [92.70923615, 12.76690102], [92.70916748, 12.76739788], [92.70910645, 12.76791096], [92.70892334, 12.76839638], [92.70889282, 12.76891136], [92.70888519, 12.76945782], [92.70894623, 12.77002335], [92.70916748, 12.7705431], [92.70939636, 12.77105999], [92.70948792, 12.77166653], [92.7096405, 12.77220154], [92.70948792, 12.77271461], [92.70944977, 12.77315044], [92.70944214, 12.77352047], [92.70943451, 12.77381611], [92.7093811, 12.77407074], [92.70922852, 12.77428055], [92.70918274, 12.77459145], [92.70915222, 12.77493954], [92.70905304, 12.77527046], [92.70891571, 12.77558899], [92.70886993, 12.77593994], [92.70876312, 12.77625179], [92.70860291, 12.77655983], [92.70837402, 12.77690411], [92.70806885, 12.77731037], [92.70775604, 12.77779961], [92.7074585, 12.7783308], [92.70719147, 12.77884102], [92.7069397, 12.77926826], [92.70670319, 12.77961445], [92.7065506, 12.77996063], [92.70635223, 12.78026104], [92.70610046, 12.78055954], [92.70580292, 12.78088093], [92.70543671, 12.78122997], [92.70503998, 12.78160095], [92.7045517, 12.78186131], [92.70414734, 12.78217983], [92.70379639, 12.78248978], [92.70348358, 12.78277969], [92.70322418, 12.78306484], [92.70302582, 12.7833519], [92.70278931, 12.78359985], [92.70250702, 12.78378677], [92.7022171, 12.78404045], [92.70194244, 12.78434563], [92.7016449, 12.78466511], [92.7013092, 12.78495026], [92.70092773, 12.78520012], [92.70059967, 12.78550816], [92.70024109, 12.78584099], [92.69987488, 12.78622818], [92.69948578, 12.78664112], [92.69921112, 12.78716946], [92.69911194, 12.78778267], [92.69892883, 12.78827], [92.6988678, 12.78870106], [92.69876099, 12.789011], [92.69863129, 12.78927994], [92.69859314, 12.78959179], [92.6984787, 12.78986073], [92.69831085, 12.7901001], [92.69806671, 12.79035091], [92.69777679, 12.79068184]]], [[[92.71618652, 12.79729271], [92.71620941, 12.79673481], [92.71651459, 12.79673481], [92.71651459, 12.79589558], [92.71620941, 12.7959013], [92.71617126, 12.79536057], [92.71589661, 12.79506016], [92.71511078, 12.79504776], [92.71508789, 12.79620171], [92.71533966, 12.79615593], [92.7154007, 12.79695415], [92.7156601, 12.79731369], [92.71618652, 12.79729271]]], [[[92.71676636, 12.80059147], [92.71676636, 12.80007172], [92.71704102, 12.80007172], [92.71704102, 12.7986927], [92.71673584, 12.79839039], [92.71620941, 12.7983923], [92.71620941, 12.7989502], [92.71562195, 12.7992506], [92.71563721, 12.80059147], [92.71570587, 12.8006506], [92.71598053, 12.80088997], [92.71650696, 12.80088997], [92.71676636, 12.80059147]]], [[[92.71760559, 12.80310345], [92.71704102, 12.80255985], [92.71596527, 12.80258465], [92.71590424, 12.80312347], [92.71618652, 12.80310345], [92.71620941, 12.80394173], [92.7164917, 12.80428123], [92.7173233, 12.80424213], [92.71759033, 12.80396175], [92.71760559, 12.80310345]]], [[[92.72861481, 12.86444569], [92.72861481, 12.86277676], [92.72888947, 12.86277676], [92.72888947, 12.8633337], [92.72944641, 12.8633337], [92.72972107, 12.86305618], [92.72972107, 12.86277962], [92.73000336, 12.86249924], [92.73000336, 12.86111069], [92.72915649, 12.86028194], [92.72860718, 12.86000061], [92.72860718, 12.85889244], [92.72721863, 12.85750103], [92.72721863, 12.85666943], [92.72638702, 12.85639095], [92.72638702, 12.85555935], [92.72583008, 12.85500145], [92.72528076, 12.85472107], [92.72528076, 12.85416698], [92.7250061, 12.85389137], [92.7250061, 12.85332966], [92.72472382, 12.85305691], [92.72556305, 12.85222054], [92.72555542, 12.85111141], [92.72499847, 12.85055447], [92.72444153, 12.8502903], [92.72471619, 12.85000134], [92.72416687, 12.84943962], [92.72416687, 12.84833241], [92.72389221, 12.84805679], [92.72389221, 12.84778118], [92.72360992, 12.84749985], [92.72360992, 12.84723091], [92.7233429, 12.84694195], [92.72333527, 12.84666634], [92.72277832, 12.84611034], [92.72277832, 12.84583378], [92.72250366, 12.84555626], [92.72249603, 12.84528065], [92.72194672, 12.84472179], [92.72194672, 12.84306145], [92.7216568, 12.84278011], [92.72110748, 12.84249973], [92.72110748, 12.84167004], [92.72055817, 12.84110069], [92.72055817, 12.83972168], [92.72000122, 12.83944416], [92.72000122, 12.83805561], [92.71971893, 12.83778], [92.71971893, 12.83749962], [92.71943665, 12.83721924], [92.71944427, 12.83694267], [92.71916962, 12.83666801], [92.71916962, 12.83638954], [92.71888733, 12.83611202], [92.71888733, 12.83583069], [92.71861267, 12.83555508], [92.71861267, 12.83529091], [92.71806335, 12.83472061], [92.71749878, 12.83444309], [92.71749878, 12.83361053], [92.71583557, 12.83277702], [92.7158432, 12.83250141], [92.71499634, 12.83250141], [92.71499634, 12.83305454], [92.7130661, 12.83333111], [92.71305847, 12.83416653], [92.71277618, 12.83444309], [92.71111298, 12.83444309], [92.71111298, 12.83361053], [92.70999908, 12.83361053], [92.70999908, 12.83444309], [92.7097168, 12.83472061], [92.70889282, 12.83500195], [92.70889282, 12.83529091], [92.70804596, 12.83611202], [92.70861053, 12.83666801], [92.70777893, 12.83694267], [92.70805359, 12.8372221], [92.70804596, 12.83832932], [92.70861053, 12.8386116], [92.70916748, 12.83916569], [92.70916748, 12.83944416], [92.70944214, 12.83972168], [92.70944214, 12.84000015], [92.7097168, 12.84027958], [92.70972443, 12.84055614], [92.70999908, 12.84083366], [92.71000671, 12.84110069], [92.71028137, 12.84138966], [92.71028137, 12.84166622], [92.71055603, 12.84194374], [92.71055603, 12.84222031], [92.71083069, 12.84249973], [92.71083069, 12.84278011], [92.71111298, 12.84305573], [92.71111298, 12.84333038], [92.71138763, 12.84361172], [92.71138763, 12.84389019], [92.71277618, 12.84389019], [92.7130661, 12.84361172], [92.7130661, 12.84333038], [92.71333313, 12.84333038], [92.71333313, 12.8441658], [92.71305847, 12.84444427], [92.7130661, 12.84500027], [92.71277618, 12.84528065], [92.7130661, 12.84556103], [92.71305847, 12.84666634], [92.71333313, 12.84694386], [92.71333313, 12.84832954], [92.7141571, 12.84917068], [92.71416473, 12.85027885], [92.71472168, 12.85083294], [92.71472168, 12.85222054], [92.71527863, 12.85250092], [92.71555328, 12.85277653], [92.71555328, 12.85332966], [92.71611023, 12.85361099], [92.71666718, 12.85416889], [92.71666718, 12.85555458], [92.71722412, 12.85583305], [92.71749878, 12.85611057], [92.71749878, 12.85750103], [92.71806335, 12.85750103], [92.71833038, 12.85722065], [92.71833038, 12.85694504], [92.71861267, 12.85694122], [92.71861267, 12.85750103], [92.71833038, 12.85778236], [92.71778107, 12.85805511], [92.71778107, 12.85861111], [92.71749878, 12.85889244], [92.71806335, 12.85917187], [92.71888733, 12.85917187], [92.71943665, 12.85889244], [92.71943665, 12.85861111], [92.72000122, 12.85861111], [92.72000122, 12.85944462], [92.72083282, 12.85972118], [92.72138977, 12.8599987], [92.72055817, 12.86083126], [92.72000122, 12.86111069], [92.72027588, 12.86139202], [92.72027588, 12.8622303], [92.71971893, 12.86249924], [92.72000122, 12.86277676], [92.72000122, 12.8633337], [92.72027588, 12.86361217], [92.72027588, 12.86444569], [92.72277832, 12.86444569], [92.72305298, 12.86416531], [92.72360992, 12.86388969], [92.72360992, 12.86360931], [92.72444153, 12.86360931], [92.72444153, 12.86388969], [92.72583008, 12.86527824], [92.72750092, 12.86527824], [92.72721863, 12.86499977], [92.72833252, 12.86471939], [92.72861481, 12.86444569]]], [[[92.73178101, 12.85643005], [92.73178101, 12.85586929], [92.73147583, 12.85588074], [92.73147583, 12.85531998], [92.73092651, 12.85531998], [92.73066711, 12.8550396], [92.73066711, 12.85475922], [92.72956085, 12.85475922], [92.72956085, 12.85490513], [92.72956848, 12.85534096], [92.72924042, 12.85531616], [92.72927856, 12.85586929], [92.72984314, 12.85643005], [92.73178101, 12.85643005]]], [[[92.76547241, 12.85472107], [92.76506042, 12.85464096], [92.76452637, 12.85480976], [92.76403046, 12.85505104], [92.7636795, 12.85534954], [92.76345062, 12.85571384], [92.76333618, 12.85624123], [92.76327515, 12.85682678], [92.76317596, 12.85737991], [92.76307678, 12.85792065], [92.76296997, 12.85845757], [92.76271057, 12.85901546], [92.76235199, 12.85954094], [92.76241302, 12.85982132], [92.76254272, 12.86016083], [92.76275635, 12.86055088], [92.76293945, 12.86101055], [92.76303864, 12.86153126], [92.76305389, 12.86206627], [92.76303864, 12.86260891], [92.76294708, 12.86316013], [92.76280975, 12.86372089], [92.76274872, 12.86431122], [92.76261902, 12.86487198], [92.76241302, 12.86536026], [92.76220703, 12.86580181], [92.76194, 12.86620522], [92.76167297, 12.86664963], [92.76139069, 12.86718082], [92.76119995, 12.86773014], [92.76135254, 12.86828804], [92.7614975, 12.8688097], [92.76171112, 12.86919975], [92.76194763, 12.8694849], [92.76219177, 12.86972427], [92.7624588, 12.86992931], [92.76283264, 12.87007141], [92.76317596, 12.87026024], [92.76357269, 12.87038517], [92.76391602, 12.87057018], [92.76419067, 12.870821], [92.76444244, 12.87106895], [92.76464844, 12.87133121], [92.76481628, 12.87164974], [92.7650528, 12.8719902], [92.76532745, 12.87235737], [92.76576233, 12.87261391], [92.76634979, 12.87247658], [92.76677704, 12.87210083], [92.76687622, 12.87164974], [92.766716, 12.87120819], [92.76664734, 12.87074089], [92.76654816, 12.87032127], [92.76637268, 12.86992931], [92.76615143, 12.86959743], [92.76595306, 12.86919117], [92.76573181, 12.86878109], [92.76558685, 12.86830044], [92.76555634, 12.86781025], [92.76555634, 12.8673811], [92.76555634, 12.86700344], [92.76555634, 12.86663818], [92.76555634, 12.86496067], [92.76555634, 12.86457062], [92.76555634, 12.8642292], [92.76555634, 12.8639307], [92.76558685, 12.86365032], [92.76573944, 12.86340046], [92.76584625, 12.86309719], [92.76602173, 12.86276245], [92.76624298, 12.86236], [92.76646423, 12.86192989], [92.76667786, 12.86145115], [92.76689911, 12.86100006], [92.76692963, 12.86048889], [92.76692963, 12.859972], [92.76692963, 12.85946083], [92.76699066, 12.85892963], [92.76716614, 12.8584404], [92.76718903, 12.85794067], [92.76705933, 12.85746002], [92.76696777, 12.85696983], [92.766922, 12.85645962], [92.76676178, 12.85595798], [92.76635742, 12.8554678], [92.76574707, 12.85497093], [92.76547241, 12.85472107]]], [[[92.77856445, 12.86475754], [92.77842712, 12.86466026], [92.77809906, 12.86465454], [92.77793884, 12.86467361], [92.77774048, 12.86469555], [92.77739716, 12.86466026], [92.77719879, 12.86474037], [92.7768631, 12.86481953], [92.77628326, 12.86497021], [92.77606201, 12.86514091], [92.77606201, 12.86536026], [92.77597809, 12.86564732], [92.77593994, 12.86583233], [92.77593994, 12.86604118], [92.77631378, 12.8662672], [92.77658844, 12.86639214], [92.77687836, 12.86643124], [92.77706909, 12.86651993], [92.77725983, 12.86663818], [92.77748871, 12.86670208], [92.77761841, 12.86667919], [92.77774048, 12.86666107], [92.77802277, 12.86645126], [92.77822113, 12.86616421], [92.77851868, 12.86591625], [92.77863312, 12.8655014], [92.77870941, 12.86523438], [92.77864838, 12.86498642], [92.77856445, 12.86475754]]], [[[92.71916962, 13.09889126], [92.72027588, 13.09777927], [92.72055817, 13.09749889], [92.72110748, 13.09639072], [92.72112274, 13.0961113], [92.72111511, 13.09555531], [92.72083282, 13.09514046], [92.719841, 13.09420967], [92.71969604, 13.09379101], [92.7191391, 13.09317493], [92.7182312, 13.09296989], [92.71704102, 13.09263134], [92.71598816, 13.09242058], [92.71514893, 13.09193993], [92.71444702, 13.09139061], [92.71360779, 13.09124947], [92.71347046, 13.09111023], [92.71305847, 13.09097385], [92.71193695, 13.09000015], [92.71166992, 13.09000015], [92.71138763, 13.08971977], [92.71111298, 13.08972168], [92.70999908, 13.0886097], [92.70999908, 13.08833218], [92.70944214, 13.08777809], [92.70916748, 13.08778095], [92.70804596, 13.08667088], [92.70804596, 13.08638954], [92.70777893, 13.08638954], [92.70749664, 13.08611012], [92.70749664, 13.0855608], [92.70722198, 13.08528042], [92.70722198, 13.08501053], [92.70694733, 13.08471966], [92.70694733, 13.08416557], [92.70527649, 13.08222198], [92.70513916, 13.08152866], [92.70527649, 13.08139038], [92.70527649, 13.08111191], [92.70417023, 13.07958889], [92.70388031, 13.07806015], [92.70417023, 13.07777977], [92.70417023, 13.07694054], [92.70444489, 13.07666779], [92.70443726, 13.07638931], [92.70500183, 13.07582188], [92.70500183, 13.07555485], [92.70527649, 13.07528019], [92.70542145, 13.07472134], [92.70583344, 13.07416725], [92.70597076, 13.07389164], [92.70610809, 13.07361126], [92.70625305, 13.07374954], [92.70652771, 13.07319164], [92.70667267, 13.07236195], [92.70666504, 13.0722208], [92.70666504, 13.0713892], [92.70667267, 13.07111073], [92.70652771, 13.0708313], [92.70611572, 13.07013988], [92.70513916, 13.06987095], [92.70443726, 13.06972122], [92.70417023, 13.07001019], [92.70361328, 13.07001019], [92.70333099, 13.07028103], [92.70249939, 13.07028103], [92.7022171, 13.07055855], [92.70194244, 13.07055473], [92.70166779, 13.07083321], [92.70111084, 13.0708313], [92.70027924, 13.07167244], [92.70027924, 13.07250118], [92.69999695, 13.07277679], [92.69999695, 13.07361126], [92.69972229, 13.07388878], [92.69972229, 13.07472134], [92.69944763, 13.07500076], [92.69944763, 13.07528019], [92.69916534, 13.07555485], [92.69917297, 13.07582188], [92.69889069, 13.07611084], [92.69889069, 13.07749939], [92.6986084, 13.07777977], [92.6986084, 13.07805538], [92.69889069, 13.07833385], [92.69889069, 13.07861233], [92.69916534, 13.07888985], [92.69916534, 13.07944584], [92.69889069, 13.0797224], [92.69889069, 13.0802784], [92.69832611, 13.08083057], [92.69832611, 13.08139038], [92.69805908, 13.0816679], [92.69806671, 13.08250046], [92.69777679, 13.08278179], [92.69777679, 13.08305645], [92.69750214, 13.0833292], [92.69750214, 13.08388996], [92.69721985, 13.08417034], [92.69721985, 13.08501053], [92.69694519, 13.08527756], [92.69695282, 13.08611012], [92.6966629, 13.08638954], [92.6966629, 13.08777809], [92.69638824, 13.0880518], [92.69638824, 13.08889103], [92.69611359, 13.08916569], [92.69611359, 13.08944416], [92.6958313, 13.08971977], [92.6958313, 13.09028053], [92.69555664, 13.09055424], [92.69555664, 13.09083462], [92.6958313, 13.09111023], [92.6958313, 13.09194469], [92.69610596, 13.09222031], [92.6958313, 13.09250069], [92.6958313, 13.0936079], [92.69610596, 13.09389114], [92.6958313, 13.09416676], [92.6958313, 13.09444046], [92.69610596, 13.09472275], [92.69610596, 13.09500122], [92.6966629, 13.09556198], [92.69695282, 13.09597015], [92.69916534, 13.09777737], [92.69944, 13.09805012], [92.69999695, 13.0980587], [92.70139313, 13.0980587], [92.70166779, 13.09805012], [92.70194244, 13.09777737], [92.7022171, 13.09776974], [92.70249939, 13.09722328], [92.70291901, 13.0969429], [92.70305634, 13.0966692], [92.70417023, 13.09556198], [92.70443726, 13.09556198], [92.70500183, 13.09500122], [92.70582581, 13.09500122], [92.70610809, 13.09472275], [92.70819092, 13.09500122], [92.70861053, 13.09500122], [92.70944214, 13.09514046], [92.7097168, 13.09528065], [92.71013641, 13.09528065], [92.71111298, 13.09528065], [92.71166992, 13.09556198], [92.71221924, 13.09555531], [92.71250153, 13.09582996], [92.71333313, 13.09610939], [92.71360779, 13.0961113], [92.71389008, 13.09652138], [92.71472168, 13.09694958], [92.71499634, 13.09694958], [92.71555328, 13.09749889], [92.71583557, 13.09749889], [92.71666718, 13.09833336], [92.71721649, 13.09833145], [92.71749878, 13.09861088], [92.71806335, 13.09861088], [92.71833038, 13.09889126], [92.71916962, 13.09889126]]], [[[93.06138611, 13.22138786], [93.06096649, 13.22069073], [93.05990601, 13.22097111], [93.05970001, 13.22104168], [93.05934906, 13.22166157], [93.05906677, 13.22192955], [93.05877686, 13.22247982], [93.05877686, 13.22358131], [93.05836487, 13.22412968], [93.05808258, 13.22453976], [93.05806732, 13.2248106], [93.05764771, 13.22549725], [93.05757904, 13.22611523], [93.05792999, 13.22666359], [93.0586319, 13.22666359], [93.05925751, 13.22659588], [93.05947113, 13.22618103], [93.05999756, 13.22555447], [93.05999756, 13.22528076], [93.06027985, 13.22500038], [93.06027985, 13.22472], [93.0605545, 13.22444439], [93.0605545, 13.22305584], [93.06083679, 13.22278118], [93.06083679, 13.22249985], [93.06138611, 13.22194195], [93.06138611, 13.22138786]]], [[[92.79499817, 13.17111015], [92.79528046, 13.17083454], [92.79582977, 13.17083454], [92.79611206, 13.17055416], [92.79638672, 13.17056084], [92.79763794, 13.16930103], [92.79750061, 13.16833687], [92.79680634, 13.16764069], [92.79611206, 13.16764069], [92.79582977, 13.16749954], [92.79499817, 13.16749954], [92.79471588, 13.16778088], [92.79444122, 13.16777802], [92.79360962, 13.16860962], [92.79360962, 13.16889], [92.79333496, 13.16916561], [92.79332733, 13.16944027], [92.79333496, 13.16999817], [92.79444122, 13.17111015], [92.79499817, 13.17111015]]], [[[93.01667023, 13.28416729], [93.01583099, 13.28332996], [93.01519775, 13.28333282], [93.01491547, 13.28347206], [93.01470947, 13.28381062], [93.01444244, 13.28402138], [93.01431274, 13.28436089], [93.01437378, 13.28463936], [93.0147934, 13.28477764], [93.01500702, 13.2849102], [93.01542664, 13.28499889], [93.01611328, 13.28499889], [93.01667023, 13.28444004], [93.01667023, 13.28416729]]], [[[93.07450867, 13.30333424], [93.07499695, 13.30305576], [93.07554626, 13.30306053], [93.07611084, 13.30249977], [93.07666779, 13.30249977], [93.07692719, 13.30222034], [93.07749939, 13.30222225], [93.07777405, 13.30194378], [93.07868195, 13.3018074], [93.07910156, 13.30125141], [93.07888794, 13.30000019], [93.07861328, 13.29971981], [93.07791901, 13.29889011], [93.07749939, 13.29860115], [93.07722473, 13.29860973], [93.07680511, 13.29853916], [93.07554626, 13.29832935], [93.07527924, 13.29805565], [93.07499695, 13.29806042], [93.07472229, 13.29778004], [93.07305908, 13.29778004], [93.07277679, 13.29806042], [93.07250214, 13.29805565], [93.07111359, 13.2994442], [93.07103729, 13.29979038], [93.07111359, 13.30054855], [93.07290649, 13.30222034], [93.0734024, 13.30270481], [93.07367706, 13.30333424], [93.07450867, 13.30333424]]], [[[93.01867676, 13.32963085], [93.01868439, 13.3293457], [93.01888275, 13.32935143], [93.01889038, 13.32907963], [93.01942444, 13.3290844], [93.01941681, 13.32937431], [93.02005005, 13.32937431], [93.02024841, 13.32936001], [93.02086639, 13.32942963], [93.02157593, 13.32942963], [93.02200317, 13.32929134], [93.02220917, 13.32915211], [93.02277374, 13.32915211], [93.02346802, 13.32894707], [93.02346802, 13.32874203], [93.02381897, 13.32853889], [93.02472687, 13.32839966], [93.02509308, 13.32833195], [93.02501678, 13.3278513], [93.02501678, 13.32661057], [93.02514648, 13.32640171], [93.02515411, 13.32612801], [93.02480316, 13.3260603], [93.02438354, 13.32612801], [93.02419281, 13.32618332], [93.02390289, 13.32628059], [93.02311707, 13.32599068], [93.02284241, 13.3260603], [93.02262878, 13.32612801], [93.0223465, 13.3260603], [93.02220917, 13.32572174], [93.02227783, 13.32551003], [93.02262878, 13.32551003], [93.02269745, 13.32537079], [93.02284241, 13.3249588], [93.02287292, 13.32487392], [93.02297974, 13.32454872], [93.02256012, 13.32441044], [93.02227783, 13.32434082], [93.02192688, 13.3242712], [93.02185822, 13.32399654], [93.02200317, 13.32372093], [93.02192688, 13.32324028], [93.02178955, 13.3228302], [93.02150726, 13.32262039], [93.0214386, 13.32234669], [93.0214386, 13.321661], [93.02136993, 13.32111168], [93.02115631, 13.32084274], [93.02115631, 13.32015038], [93.02121735, 13.31912041], [93.02121735, 13.31836128], [93.02136993, 13.31781101], [93.0214386, 13.31740093], [93.0214386, 13.3172617], [93.02108765, 13.31733131], [93.02095032, 13.31739902], [93.02088165, 13.31767178], [93.02059937, 13.31774139], [93.0205307, 13.31746674], [93.02024841, 13.31733131], [93.0198288, 13.31718922], [93.01989746, 13.31698418], [93.01989746, 13.31671143], [93.01967621, 13.31644154], [93.01996613, 13.31609058], [93.02059937, 13.31560993], [93.02095032, 13.31540012], [93.02130127, 13.31506062], [93.0214386, 13.31479168], [93.02157593, 13.31437016], [93.0214386, 13.31416702], [93.02121735, 13.31417179], [93.02086639, 13.31424046], [93.02059937, 13.3145113], [93.02031708, 13.31472111], [93.02017975, 13.31472111], [93.02009583, 13.31444073], [93.02031708, 13.31402969], [93.02086639, 13.31376076], [93.02130127, 13.31340981], [93.02130127, 13.3127203], [93.0214386, 13.31258488], [93.02192688, 13.31258488], [93.02200317, 13.31244946], [93.02192688, 13.31217098], [93.02192688, 13.31189728], [93.0223465, 13.31126976], [93.02249146, 13.31100368], [93.02249146, 13.31004238], [93.02269745, 13.30976772], [93.0230484, 13.30956078], [93.02346802, 13.3091507], [93.02353668, 13.30887032], [93.02339935, 13.30853081], [93.02339935, 13.3081913], [93.02361298, 13.30791092], [93.02361298, 13.30743027], [93.02346802, 13.3060627], [93.02368164, 13.30537033], [93.02368164, 13.30523109], [93.02353668, 13.30501175], [93.02312469, 13.30481815], [93.02275848, 13.30427074], [93.02284241, 13.30391979], [93.02256012, 13.30351162], [93.02172089, 13.30296135], [93.02130127, 13.30337143], [93.02121735, 13.30365086], [93.02122498, 13.30406094], [93.02066803, 13.30461121], [93.02044678, 13.30501175], [93.02031708, 13.30536747], [93.02017975, 13.30550385], [93.02002716, 13.30571175], [93.02003479, 13.30605602], [93.01996613, 13.30632019], [93.0197525, 13.30660534], [93.01954651, 13.30674171], [93.01947784, 13.30708981], [93.01933289, 13.30743027], [93.01898956, 13.30757141], [93.01842499, 13.30770588], [93.01835632, 13.30784321], [93.01828766, 13.30832291], [93.01793671, 13.30839157], [93.0174408, 13.30839157], [93.01709747, 13.30846024], [93.01682281, 13.30873966], [93.01568604, 13.30873966], [93.01499939, 13.30881119], [93.01500702, 13.30935097], [93.01386261, 13.3088913], [93.01293182, 13.3091011], [93.0099411, 13.31073666], [93.00942993, 13.31096935], [93.00957489, 13.31214809], [93.01014709, 13.31686115], [93.01576233, 13.31589031], [93.01576233, 13.31637955], [93.01568604, 13.31671143], [93.01561737, 13.31739902], [93.01561737, 13.31774139], [93.01589966, 13.31815147], [93.01589966, 13.31842899], [93.01589966, 13.31925201], [93.01611328, 13.31960106], [93.01611328, 13.32001972], [93.01625061, 13.32049179], [93.01625061, 13.32083607], [93.01603699, 13.32118034], [93.01589966, 13.32145405], [93.01596832, 13.32159042], [93.01596832, 13.32207108], [93.01611328, 13.32331085], [93.01625061, 13.32372093], [93.01638794, 13.32406998], [93.01638794, 13.32455063], [93.01646423, 13.32509804], [93.0165329, 13.32537365], [93.0165329, 13.32578373], [93.01682281, 13.32647038], [93.01695251, 13.32688522], [93.01722717, 13.32750034], [93.01721954, 13.32822037], [93.01612854, 13.32822037], [93.01463318, 13.33012104], [93.01483917, 13.33046055], [93.01631165, 13.33155918], [93.01867676, 13.32963085]]], [[[92.98805237, 12.99805069], [92.98807526, 12.99779797], [92.9875412, 12.99779797], [92.9875412, 12.99805069], [92.98664856, 12.99805069], [92.98638916, 13.00000191], [92.98664856, 13.00028038], [92.98693848, 13.00028038], [92.98750305, 13.00028038], [92.98860931, 13.00055981], [92.98944092, 13.00055981], [92.98970795, 13.00028038], [92.98916626, 13.00000191], [92.98916626, 12.99920177], [92.98887634, 12.99914265], [92.98886108, 12.99838066], [92.98861694, 12.99805069], [92.98805237, 12.99805069]]], [[[92.91249847, 13.00249958], [92.91168213, 13.00249958], [92.91166687, 13.00277805], [92.9108429, 13.00360107], [92.9108429, 13.00500011], [92.91110992, 13.00527954], [92.91139221, 13.00527954], [92.91168213, 13.00500011], [92.91168213, 13.00471973], [92.91222382, 13.00416565], [92.91221619, 13.00389004], [92.91278076, 13.00332928], [92.91278076, 13.00305557], [92.91249847, 13.00277996], [92.91249847, 13.00249958]]], [[[92.94972229, 13.02111053], [92.9486084, 13.02111053], [92.9486084, 13.02166653], [92.94805908, 13.02222061], [92.94805908, 13.02250195], [92.94750214, 13.02306175], [92.94750214, 13.02361202], [92.94721985, 13.02388954], [92.94721985, 13.02444553], [92.94695282, 13.0247097], [92.94526672, 13.02499866], [92.94526672, 13.02528], [92.9458313, 13.02555561], [92.94694519, 13.02583408], [92.94721985, 13.02583408], [92.94721985, 13.02555561], [92.94889069, 13.02499866], [92.94944763, 13.0247097], [92.94944763, 13.02444553], [92.94972229, 13.02416801], [92.94944763, 13.02388954], [92.94944763, 13.02361202], [92.94972229, 13.02333069], [92.94972229, 13.02305508], [92.94999695, 13.02278042], [92.94999695, 13.02250195], [92.94972229, 13.02222061], [92.94972229, 13.02138901], [92.94972229, 13.02111053]]], [[[92.91860962, 13.04000092], [92.91665649, 13.04000092], [92.91500092, 13.04166698], [92.91486359, 13.04194546], [92.91458893, 13.04222107], [92.91451263, 13.04250145], [92.91444397, 13.04277897], [92.91430664, 13.04354], [92.91438293, 13.04410076], [92.91451263, 13.04500103], [92.91478729, 13.04542065], [92.91500092, 13.04584026], [92.91513824, 13.04618168], [92.91527557, 13.04638863], [92.91575623, 13.04714966], [92.91610718, 13.04750061], [92.91660309, 13.04736042], [92.91722107, 13.04722118], [92.91777802, 13.0466671], [92.91777802, 13.04639053], [92.91805267, 13.04611111], [92.91805267, 13.04555511], [92.91832733, 13.04528236], [92.91832733, 13.04444122], [92.91860962, 13.04416656], [92.91860962, 13.04389095], [92.91889191, 13.04361057], [92.91889191, 13.04222298], [92.91916656, 13.04194546], [92.91916656, 13.04138947], [92.91944122, 13.04111099], [92.91944122, 13.04082966], [92.91860962, 13.04000092]]], [[[92.93360901, 13.04944324], [92.93333435, 13.04944324], [92.93305206, 13.04972363], [92.93291473, 13.04986286], [92.93249512, 13.05000401], [92.93208313, 13.05110931], [92.93193817, 13.05166531], [92.93180084, 13.05194092], [92.93180084, 13.05236053], [92.93193817, 13.05264091], [92.93222046, 13.05278015], [92.93305206, 13.05278015], [92.93444824, 13.05138969], [92.93416595, 13.05097008], [92.9338913, 13.04999924], [92.93360901, 13.04972076], [92.93360901, 13.04944324]]], [[[92.91681671, 13.05789185], [92.91613007, 13.05789185], [92.91599274, 13.05810165], [92.91584778, 13.05850983], [92.91549683, 13.0586462], [92.91520691, 13.05878067], [92.91485596, 13.05920029], [92.91465759, 13.05968094], [92.91465759, 13.06023026], [92.91458893, 13.06077957], [92.91437531, 13.06091404], [92.91416168, 13.06097126], [92.91381073, 13.06118965], [92.91353607, 13.06125832], [92.91324615, 13.06153202], [92.91324615, 13.06180954], [92.91310883, 13.06235886], [92.91304016, 13.06270123], [92.91304016, 13.06345844], [92.91310883, 13.06428337], [92.91310883, 13.0658617], [92.91318512, 13.06620884], [92.91345978, 13.06655025], [92.91345978, 13.0668993], [92.91388702, 13.0668993], [92.91409302, 13.06668854], [92.91423035, 13.06634998], [92.91438293, 13.0658617], [92.91444397, 13.06538391], [92.91451263, 13.06497097], [92.91478729, 13.06463146], [92.91507721, 13.06456089], [92.9152832, 13.06421185], [92.91549683, 13.06366539], [92.91562653, 13.06346035], [92.91613007, 13.06298065], [92.91647339, 13.06284046], [92.91681671, 13.06256199], [92.9169693, 13.06201458], [92.91710663, 13.06167126], [92.91717529, 13.06118965], [92.91725159, 13.06077671], [92.91738892, 13.06049919], [92.91738892, 13.05933475], [92.91745758, 13.0588541], [92.91745758, 13.05837059], [92.91738892, 13.05809689], [92.91718292, 13.05795956], [92.91681671, 13.05789185]]], [[[92.73055267, 13.09569073], [92.73069, 13.09554958], [92.73110962, 13.09556198], [92.73166656, 13.09500122], [92.73179626, 13.09430122], [92.73152924, 13.09375191], [92.73139191, 13.09334183], [92.73139191, 13.09319973], [92.73110962, 13.0929203], [92.73097992, 13.09278107], [92.73082733, 13.0923624], [92.73069763, 13.09208584], [92.73027802, 13.09180832], [92.73027802, 13.09167099], [92.72888947, 13.09028053], [92.72833252, 13.09027863], [92.7277832, 13.09082127], [92.7277832, 13.09139061], [92.72805023, 13.09167099], [92.72805023, 13.09278107], [92.72833252, 13.09305668], [92.72833252, 13.09333038], [92.7298584, 13.0951376], [92.73014069, 13.0954113], [92.73055267, 13.09569073]]], [[[94.27333069, 13.46444416], [94.27333069, 13.46416569], [94.27361298, 13.46389008], [94.27361298, 13.46306133], [94.27355194, 13.46286011], [94.27361298, 13.46257114], [94.27388763, 13.46249962], [94.27416992, 13.46222019], [94.27444458, 13.4622221], [94.27471924, 13.46194363], [94.27555847, 13.46194363], [94.27597046, 13.46215439], [94.2765274, 13.46228981], [94.2775116, 13.46229267], [94.27777863, 13.46180534], [94.27757263, 13.46145153], [94.27722168, 13.46055603], [94.27694702, 13.46035099], [94.27661133, 13.46007061], [94.27639008, 13.46000004], [94.27604675, 13.45937061], [94.27555847, 13.45888996], [94.27542114, 13.45860958], [94.27527618, 13.45833397], [94.27514648, 13.45784569], [94.27500916, 13.45750046], [94.27500153, 13.45555592], [94.27507019, 13.45529079], [94.27513885, 13.45493126], [94.27520752, 13.45472145], [94.27520752, 13.45437527], [94.27561951, 13.45410061], [94.27617645, 13.45374966], [94.2767334, 13.45319939], [94.27702332, 13.45244026], [94.27694702, 13.44889069], [94.27687836, 13.44861126], [94.27666473, 13.44833279], [94.27610779, 13.44777679], [94.27610779, 13.44750118], [94.27583313, 13.4472208], [94.27583313, 13.44694519], [94.27555847, 13.44666672], [94.27555847, 13.4458313], [94.27527618, 13.44555473], [94.27527618, 13.44528103], [94.27555847, 13.44500065], [94.27555847, 13.44194031], [94.27527618, 13.4416666], [94.27527618, 13.44139099], [94.27500916, 13.44110966], [94.27500153, 13.44055653], [94.27443695, 13.43999958], [94.27443695, 13.43972015], [94.27416992, 13.43944359], [94.27416992, 13.43916607], [94.27361298, 13.43861008], [94.27361298, 13.4383297], [94.27305603, 13.43777847], [94.27305603, 13.4375], [94.27278137, 13.43721962], [94.27243042, 13.43694592], [94.27207947, 13.43638992], [94.27047729, 13.43508434], [94.26944733, 13.43444157], [94.26902771, 13.43465424], [94.26889038, 13.43472195], [94.26874542, 13.43474293], [94.26832581, 13.43479919], [94.26763153, 13.43465996], [94.26638794, 13.43360996], [94.26582336, 13.43360996], [94.26555634, 13.43332863], [94.26542664, 13.43287563], [94.26486969, 13.43240166], [94.26416779, 13.43198013], [94.26395416, 13.431777], [94.2636795, 13.43109131], [94.26332855, 13.43047142], [94.26317596, 13.43006134], [94.26291656, 13.42998791], [94.26270294, 13.42998791], [94.26248932, 13.43006134], [94.2622757, 13.43019581], [94.26206207, 13.43026447], [94.26192474, 13.43019581], [94.26156616, 13.43013191], [94.26109314, 13.4299202], [94.26080322, 13.4299202], [94.26074219, 13.43013191], [94.26045227, 13.43019962], [94.26003265, 13.4299202], [94.2596817, 13.42978287], [94.25954437, 13.42978287], [94.25919342, 13.42943859], [94.25869751, 13.42943859], [94.25862885, 13.42971516], [94.25862885, 13.4299221], [94.25849152, 13.43026161], [94.25834656, 13.43054199], [94.25820923, 13.4306097], [94.25814056, 13.43074703], [94.25785828, 13.43088436], [94.25767517, 13.43083191], [94.25737, 13.43074703], [94.25681305, 13.4306097], [94.25659943, 13.4306097], [94.25631714, 13.43054199], [94.25575256, 13.43026161], [94.25561523, 13.43047142], [94.2555542, 13.43094063], [94.25552368, 13.43101215], [94.25540161, 13.43130112], [94.25519562, 13.43164062], [94.25512695, 13.43190956], [94.254776, 13.43240166], [94.25421143, 13.4328804], [94.25379181, 13.43316078], [94.25332642, 13.43360996], [94.25305176, 13.43360996], [94.2527771, 13.43388844], [94.2527771, 13.43416595], [94.25222015, 13.43472195], [94.25222778, 13.43486118], [94.25222778, 13.43527985], [94.25222015, 13.43555641], [94.25222015, 13.43610954], [94.2519455, 13.43638802], [94.25195313, 13.43721962], [94.25055695, 13.43861008], [94.25055695, 13.43889141], [94.25027466, 13.43916607], [94.25026703, 13.43972015], [94.25, 13.43999958], [94.24986267, 13.44021034], [94.24931335, 13.44083023], [94.24916077, 13.4416666], [94.24938202, 13.44208145], [94.24926758, 13.44311619], [94.24916077, 13.44361115], [94.24916077, 13.44389057], [94.24901581, 13.44423962], [94.24909973, 13.44527912], [94.24916077, 13.44562054], [94.24944305, 13.44624996], [94.24973297, 13.44639111], [94.25055695, 13.44653034], [94.25077057, 13.44659615], [94.25137329, 13.44677162], [94.25147247, 13.44680119], [94.25161743, 13.44679928], [94.25189209, 13.44715023], [94.25250244, 13.44778061], [94.25263977, 13.44930553], [94.2527771, 13.44972134], [94.2527771, 13.45000076], [94.25332642, 13.45055962], [94.25332642, 13.45111084], [94.2536087, 13.45138931], [94.2536087, 13.45166683], [94.25389099, 13.4519453], [94.25388336, 13.45222092], [94.25506592, 13.45369053], [94.25527954, 13.45388985], [94.25576019, 13.45444584], [94.25686646, 13.45673847], [94.25721741, 13.45722198], [94.25776672, 13.45778179], [94.25777435, 13.45798683], [94.25805664, 13.45833397], [94.2583313, 13.45861244], [94.25971985, 13.45861244], [94.26082611, 13.45971966], [94.26083374, 13.46027756], [94.26126099, 13.46097088], [94.26161194, 13.46146107], [94.26174164, 13.46187782], [94.26194763, 13.46222019], [94.26242828, 13.46305561], [94.26262665, 13.46333027], [94.26277924, 13.46395397], [94.26333618, 13.46444416], [94.26361084, 13.46444416], [94.26409912, 13.46416569], [94.2647171, 13.46326065], [94.26583099, 13.46305561], [94.2664566, 13.46278], [94.26694489, 13.46249962], [94.26805878, 13.46249962], [94.26832581, 13.46278], [94.26860809, 13.46278], [94.26889038, 13.46305561], [94.26889038, 13.46333408], [94.26917267, 13.4636097], [94.26951599, 13.46410179], [94.26979065, 13.46430969], [94.26999664, 13.46444416], [94.27027893, 13.46444035], [94.27062225, 13.4646492], [94.27069855, 13.46470642], [94.27090454, 13.4648571], [94.27131653, 13.46513462], [94.27186584, 13.46520138], [94.27249908, 13.46528053], [94.27278137, 13.46528053], [94.27305603, 13.46500015], [94.27305603, 13.46471977], [94.27333069, 13.46444416]]], [[[93.09902191, 13.43576145], [93.09957886, 13.43548965], [93.10056305, 13.43562508], [93.10166931, 13.43555641], [93.10193634, 13.43527985], [93.10250092, 13.43527985], [93.10305786, 13.43472195], [93.10305786, 13.43305588], [93.10333252, 13.43278027], [93.10333252, 13.43222046], [93.10361481, 13.43194389], [93.10361481, 13.43166637], [93.10388947, 13.43138981], [93.10388947, 13.43112087], [93.10417175, 13.43083191], [93.10424805, 13.42992878], [93.10334015, 13.42986107], [93.10250092, 13.43000031], [93.10221863, 13.43000031], [93.10166168, 13.43006992], [93.09929657, 13.43027973], [93.09889221, 13.4305563], [93.09867859, 13.43083382], [93.09777832, 13.43194389], [93.09777832, 13.43222046], [93.09757233, 13.43272114], [93.09729004, 13.43306065], [93.09666443, 13.43388844], [93.09666443, 13.43416595], [93.09638977, 13.43444443], [93.09638977, 13.43583202], [93.0966568, 13.43610954], [93.09666443, 13.43666553], [93.09694672, 13.43694401], [93.09694672, 13.43721962], [93.09715271, 13.43743229], [93.09777832, 13.43806076], [93.09860992, 13.43806076], [93.09887695, 13.4375], [93.09881592, 13.43736076], [93.09860992, 13.4369297], [93.09889221, 13.43638802], [93.09902191, 13.43576145]]], [[[92.96806335, 13.33250046], [92.96749878, 13.33250046], [92.96749878, 13.33278084], [92.96722412, 13.3330574], [92.96722412, 13.33333206], [92.96694183, 13.33360958], [92.96694183, 13.33444023], [92.96611023, 13.33528137], [92.96611023, 13.33555698], [92.96639252, 13.33582973], [92.96639252, 13.33639145], [92.96666718, 13.33666706], [92.96666718, 13.33694458], [92.96694183, 13.33722115], [92.96749878, 13.33749866], [92.96778107, 13.33777905], [92.96944427, 13.33833313], [92.96971893, 13.33833313], [92.96971893, 13.33805466], [92.96943665, 13.33777046], [92.96944427, 13.33749866], [92.96916962, 13.33722115], [92.96861267, 13.33694458], [92.96861267, 13.33638859], [92.96833038, 13.33611107], [92.96833038, 13.33555889], [92.96778107, 13.33528137], [92.96778107, 13.33471107], [92.96833038, 13.33416653], [92.96833038, 13.33389091], [92.96806335, 13.33360958], [92.96833038, 13.33333206], [92.96833038, 13.3330574], [92.96806335, 13.33278084], [92.96806335, 13.33250046]]], [[[93.01611328, 13.33908939], [93.01611328, 13.33833981], [93.01612091, 13.33793163], [93.01580048, 13.33793163], [93.01526642, 13.33793163], [93.01526642, 13.33771133], [93.01390839, 13.33770847], [93.01390839, 13.33879089], [93.01404572, 13.33881378], [93.0144577, 13.33880711], [93.01444244, 13.33905125], [93.01441956, 13.33928967], [93.01442719, 13.34038639], [93.01504517, 13.3405304], [93.01560974, 13.34043026], [93.01558685, 13.33910084], [93.01611328, 13.33908939]]], [[[93.03749847, 13.34056187], [93.03694153, 13.34056187], [93.03688049, 13.34084034], [93.0368042, 13.34166718], [93.03666687, 13.34194088], [93.03660583, 13.34250069], [93.03666687, 13.34278202], [93.03701782, 13.3432579], [93.03721619, 13.34367085], [93.03771973, 13.3438797], [93.03804779, 13.34390068], [93.03861237, 13.34333134], [93.03861237, 13.34249878], [93.03833008, 13.34222126], [93.03826141, 13.3413887], [93.03749847, 13.34056187]]], [[[93.07723999, 13.36481571], [93.0772934, 13.36472511], [93.07785797, 13.36472511], [93.07814026, 13.36451817], [93.07840729, 13.36423969], [93.0786972, 13.36410522], [93.0786972, 13.36382866], [93.07805634, 13.36382866], [93.0779953, 13.36376095], [93.07814026, 13.36356068], [93.07820892, 13.3632803], [93.07805634, 13.36314106], [93.07778931, 13.36314106], [93.07758331, 13.36342239], [93.07692719, 13.36356068], [93.07652283, 13.36348534], [93.07610321, 13.36369038], [93.07603455, 13.36390018], [93.07596588, 13.3642416], [93.07498169, 13.36423969], [93.07448578, 13.36438084], [93.07441711, 13.36443806], [93.07414246, 13.36466122], [93.07400513, 13.36486244], [93.07386017, 13.36534119], [93.07386017, 13.36575508], [93.07414246, 13.36582375], [93.07456207, 13.36582375], [93.07491302, 13.36589241], [93.07540131, 13.36643887], [93.07546997, 13.36664867], [93.07558441, 13.36671734], [93.07582092, 13.36685371], [93.07617188, 13.366786], [93.07631683, 13.36637115], [93.07631683, 13.36610031], [93.07624817, 13.36582088], [93.07652283, 13.36548042], [93.07673645, 13.36506939], [93.07723999, 13.36481571]]], [[[93.08257294, 13.36687183], [93.08222198, 13.36687183], [93.08167267, 13.36722088], [93.08097076, 13.36805534], [93.08104706, 13.36861134], [93.08117676, 13.36896038], [93.08132172, 13.36923981], [93.08194733, 13.37000084], [93.08249664, 13.37000084], [93.08283997, 13.36944103], [93.08347321, 13.36882114], [93.08353424, 13.36833477], [93.08352661, 13.36799145], [93.08306122, 13.36715031], [93.08277893, 13.36694527], [93.08257294, 13.36687183]]], [[[93.06231689, 13.38329792], [93.06217194, 13.3830204], [93.06196594, 13.38309002], [93.06175232, 13.38322735], [93.06162262, 13.38357067], [93.06140137, 13.38391972], [93.0613327, 13.38419056], [93.0615387, 13.38447189], [93.06161499, 13.38501644], [93.06162262, 13.38529015], [93.06217194, 13.38556576], [93.06238556, 13.38570213], [93.06252289, 13.38611507], [93.06280518, 13.38632202], [93.06308746, 13.38673019], [93.0631485, 13.38679409], [93.06328583, 13.38694], [93.06358337, 13.38680077], [93.06385803, 13.38632202], [93.06399536, 13.3857708], [93.06399536, 13.38542938], [93.06378937, 13.38508034], [93.06357574, 13.38480854], [93.06322479, 13.38453293], [93.06308746, 13.38405228], [93.06238556, 13.38357067], [93.06231689, 13.38329792]]], [[[92.81305695, 13.41972256], [92.81361389, 13.41916656], [92.81388855, 13.41918087], [92.81416321, 13.41889095], [92.81526947, 13.41889095], [92.81639099, 13.41778088], [92.81694794, 13.41778088], [92.8172226, 13.41750145], [92.81749725, 13.41750145], [92.81804657, 13.41693974], [92.81833649, 13.41694546], [92.8188858, 13.41638947], [92.8188858, 13.41582966], [92.8180542, 13.41500092], [92.81804657, 13.41471958], [92.81777954, 13.41444492], [92.81777954, 13.41388798], [92.81804657, 13.41361046], [92.8180542, 13.41194439], [92.81819153, 13.41166592], [92.81749725, 13.41082954], [92.81749725, 13.40999985], [92.81681824, 13.4077301], [92.81594849, 13.40649033], [92.81611633, 13.40580654], [92.81611633, 13.40429115], [92.81500244, 13.40305614], [92.81445313, 13.40305996], [92.81360626, 13.40388966], [92.81360626, 13.40418243], [92.81275177, 13.4050293], [92.81192017, 13.40587044], [92.81208038, 13.40670013], [92.81236267, 13.40739059], [92.8126297, 13.40848923], [92.8133316, 13.41040993], [92.8134079, 13.41206074], [92.81355286, 13.41356945], [92.8134079, 13.41480923], [92.81305695, 13.41639137], [92.81277466, 13.41666698], [92.81277466, 13.41694546], [92.8125, 13.41722107], [92.8125, 13.41750145], [92.81223297, 13.41778088], [92.81222534, 13.41805458], [92.81194305, 13.41833305], [92.81194305, 13.41861057], [92.8116684, 13.41889095], [92.8116684, 13.41918087], [92.81222534, 13.41916656], [92.81277466, 13.41972256], [92.81305695, 13.41972256]]], [[[92.87444305, 13.51220989], [92.87444305, 13.51194382], [92.8730545, 13.51055622], [92.87319946, 13.51041889], [92.87304688, 13.51027966], [92.87304688, 13.50971889], [92.87333679, 13.50944328], [92.87333679, 13.50916767], [92.87361145, 13.50889015], [92.87361145, 13.5083313], [92.87388611, 13.50805473], [92.87388611, 13.50778198], [92.87444305, 13.50722122], [92.87444305, 13.50694561], [92.87472534, 13.50666714], [92.87473297, 13.50444126], [92.87277985, 13.50249863], [92.87251282, 13.50250053], [92.8722229, 13.50222111], [92.87194824, 13.50222301], [92.87166595, 13.50194454], [92.8713913, 13.50194454], [92.87110901, 13.50194454], [92.87083435, 13.50222301], [92.87055206, 13.50222301], [92.86958313, 13.50264263], [92.8694458, 13.50306034], [92.8686142, 13.50388908], [92.86860657, 13.50444126], [92.86805725, 13.50500107], [92.86750031, 13.50500107], [92.86723328, 13.50527859], [92.86722565, 13.50555515], [92.86694336, 13.50583267], [92.86694336, 13.50610924], [92.8666687, 13.50640106], [92.8666687, 13.5075016], [92.8666687, 13.50778198], [92.86638641, 13.50805473], [92.8666687, 13.5083313], [92.8666687, 13.50916767], [92.86694336, 13.50944328], [92.86694336, 13.50957966], [92.86722565, 13.50958729], [92.86778259, 13.51000023], [92.8686142, 13.5116663], [92.86860657, 13.51194096], [92.8694458, 13.51278019], [92.86972046, 13.51278019], [92.87000275, 13.51305962], [92.87110901, 13.51305962], [92.8713913, 13.51278019], [92.87194824, 13.51278019], [92.87251282, 13.51220989], [92.87277985, 13.51249981], [92.87333679, 13.51249981], [92.87388611, 13.51305962], [92.8741684, 13.51305962], [92.87473297, 13.51249981], [92.87444305, 13.51220989]]], [[[92.91889191, 13.51556969], [92.91916656, 13.51528263], [92.91944122, 13.51528263], [92.91971588, 13.51500034], [92.92028046, 13.51500034], [92.92138672, 13.51389027], [92.92138672, 13.51278019], [92.91916656, 13.51056004], [92.91916656, 13.51027966], [92.91860962, 13.50971889], [92.91860962, 13.50944328], [92.91833496, 13.50916767], [92.91832733, 13.50889015], [92.91805267, 13.50861168], [92.91805267, 13.5083313], [92.91694641, 13.50722122], [92.91666412, 13.50722122], [92.91638947, 13.50694561], [92.91611481, 13.50694561], [92.91583252, 13.50666714], [92.91555786, 13.50694561], [92.91500092, 13.50694084], [92.91442871, 13.5075016], [92.91388702, 13.5075016], [92.91333008, 13.50805473], [92.91333008, 13.5083313], [92.91361237, 13.50861168], [92.91361237, 13.50889015], [92.91416931, 13.50944328], [92.91416931, 13.50971889], [92.91471863, 13.51027966], [92.91471863, 13.5116663], [92.91500092, 13.51194096], [92.91500092, 13.5130558], [92.9152832, 13.51332855], [92.9152832, 13.51361179], [92.91665649, 13.51500034], [92.91694641, 13.51500034], [92.91722107, 13.51528263], [92.91750336, 13.51528263], [92.91777802, 13.51556969], [92.91832733, 13.51556969], [92.91889191, 13.51556969]]], [[[93.09449005, 13.41763115], [93.09462738, 13.41755962], [93.09490967, 13.41755962], [93.09519196, 13.41777039], [93.09532928, 13.41763115], [93.09532928, 13.41722107], [93.095047, 13.41708088], [93.095047, 13.41680145], [93.09519196, 13.41652775], [93.09526062, 13.41625023], [93.09519196, 13.41570473], [93.09511566, 13.41549683], [93.09468842, 13.41557026], [93.09442139, 13.41590977], [93.09442139, 13.41646194], [93.09398651, 13.41646194], [93.09371948, 13.41611958], [93.09356689, 13.41569996], [93.09308624, 13.41522217], [93.09308624, 13.41501713], [93.09301758, 13.41474056], [93.09300995, 13.41466618], [93.09294891, 13.41412258], [93.09287262, 13.41377926], [93.09259796, 13.41363144], [93.09252167, 13.41350269], [93.09252167, 13.41288567], [93.092453, 13.41261196], [93.09217834, 13.41226959], [93.09217834, 13.41185093], [93.09182739, 13.41158009], [93.0917511, 13.41151142], [93.09168243, 13.41123104], [93.09168243, 13.41075516], [93.09147644, 13.41034222], [93.09119415, 13.41027355], [93.09077454, 13.40999794], [93.09062958, 13.40993023], [93.09027863, 13.4097929], [93.08992767, 13.40999794], [93.08978271, 13.41005707], [93.08957672, 13.41015053], [93.0891571, 13.41007137], [93.08901978, 13.40999794], [93.08860016, 13.41020298], [93.08853149, 13.41075039], [93.08818054, 13.41151142], [93.08747864, 13.41206074], [93.08732605, 13.41220188], [93.08732605, 13.41261196], [93.08747864, 13.41281509], [93.0875473, 13.41357231], [93.08761597, 13.41412258], [93.08712006, 13.41508007], [93.08705902, 13.41563416], [93.08705902, 13.41577053], [93.087677, 13.41611958], [93.08818054, 13.41660118], [93.08895111, 13.41722107], [93.08950806, 13.41783619], [93.08965302, 13.41852188], [93.0901413, 13.41914177], [93.0908432, 13.41961956], [93.09196472, 13.41989613], [93.092453, 13.42017174], [93.09266663, 13.42017174], [93.09294891, 13.42003536], [93.09336853, 13.41989613], [93.09407043, 13.41954994], [93.09427643, 13.41921043], [93.09420776, 13.41880035], [93.09420776, 13.41825104], [93.09449005, 13.41784], [93.09449005, 13.41763115]]], [[[92.8658371, 13.41361046], [92.86611176, 13.41333199], [92.86638641, 13.41333199], [92.8666687, 13.41305733], [92.86694336, 13.41305733], [92.86750031, 13.41250038], [92.86752319, 13.41201019], [92.86751556, 13.41160202], [92.86709595, 13.41146088], [92.86667633, 13.41132736], [92.86611176, 13.41133118], [92.86582947, 13.41139507], [92.86499786, 13.41193962], [92.86499786, 13.41250038], [92.86528015, 13.4127779], [92.86528015, 13.41305733], [92.8658371, 13.41361046]]], [[[92.84333038, 13.44083214], [92.84333038, 13.43999958], [92.84361267, 13.43972015], [92.84361267, 13.43833447], [92.84388733, 13.43805599], [92.84388733, 13.4375], [92.84443665, 13.4369297], [92.84444427, 13.43666553], [92.84471893, 13.43638992], [92.84471893, 13.43472195], [92.84485626, 13.43444443], [92.84514618, 13.43347454], [92.84485626, 13.43360996], [92.84583282, 13.43222046], [92.84583282, 13.43194389], [92.84610748, 13.43166637], [92.84610748, 13.43112087], [92.84638977, 13.43083191], [92.84555817, 13.43000031], [92.84527588, 13.43000031], [92.84361267, 13.42833138], [92.84361267, 13.42805576], [92.84278107, 13.4272213], [92.84278107, 13.42694569], [92.84249878, 13.42666531], [92.84249878, 13.4263916], [92.84194183, 13.42583084], [92.84166718, 13.42583275], [92.84139252, 13.42555523], [92.84055328, 13.42556], [92.84027863, 13.42527962], [92.83972168, 13.42527962], [92.83889008, 13.42444134], [92.83889008, 13.42416668], [92.83499908, 13.42028141], [92.8347168, 13.42028141], [92.83444214, 13.42000103], [92.83389282, 13.42000103], [92.83361053, 13.41972065], [92.83333588, 13.41972256], [92.83305359, 13.41944504], [92.83277893, 13.41944504], [92.83194733, 13.41861057], [92.83139038, 13.41861057], [92.83082581, 13.41918087], [92.83055878, 13.41916656], [92.83027649, 13.41944504], [92.83000183, 13.41944027], [92.82888794, 13.42056179], [92.82833099, 13.42055511], [92.82805634, 13.42083263], [92.82749939, 13.42083263], [92.82722473, 13.42111111], [92.82692719, 13.42105389], [92.82652283, 13.42097378], [92.8263855, 13.42083263], [92.82583618, 13.42083263], [92.82555389, 13.42055511], [92.82472229, 13.42000961], [92.82446289, 13.42028141], [92.82402802, 13.41987133], [92.82332611, 13.41972065], [92.82250214, 13.42056179], [92.82221985, 13.42055511], [92.82195282, 13.42083073], [92.82195282, 13.42250061], [92.8216629, 13.42277718], [92.8215332, 13.42403126], [92.82148743, 13.42415619], [92.82124329, 13.4249897], [92.82110596, 13.42527962], [92.82111359, 13.42555523], [92.82069397, 13.42625046], [92.82055664, 13.42694569], [92.82055664, 13.42833424], [92.8208313, 13.42860889], [92.8208313, 13.42889023], [92.82111359, 13.42916775], [92.82111359, 13.42944431], [92.82138824, 13.42972183], [92.82138824, 13.43000031], [92.82180023, 13.43083191], [92.82195282, 13.43112087], [92.82194519, 13.43166637], [92.82221985, 13.43194103], [92.82221985, 13.43305588], [92.82250214, 13.43333435], [92.82250214, 13.43444443], [92.82221985, 13.43472195], [92.82221985, 13.43500042], [92.82139587, 13.43583202], [92.82139587, 13.43638992], [92.8216629, 13.43667126], [92.82277679, 13.43667126], [92.82305908, 13.43638992], [92.82333374, 13.43638802], [92.82417297, 13.43721962], [92.82416534, 13.43749809], [92.82457733, 13.43805027], [92.82485962, 13.43847084], [92.82527924, 13.43889141], [92.82554626, 13.43917084], [92.82611084, 13.43917084], [92.82624817, 13.43902969], [92.82666779, 13.43889141], [92.82720947, 13.4383297], [92.82749939, 13.43833447], [92.82777405, 13.43805599], [92.83110809, 13.43805599], [92.83139038, 13.4383297], [92.8319397, 13.43874931], [92.83249664, 13.43889141], [92.83499908, 13.43861008], [92.83528137, 13.43889141], [92.83555603, 13.4388876], [92.83611298, 13.43944359], [92.83638763, 13.43944359], [92.83666992, 13.43944168], [92.83721924, 13.43972206], [92.83750153, 13.43972015], [92.83833313, 13.44056129], [92.83860779, 13.44055653], [92.83889008, 13.44083214], [92.83944702, 13.44083214], [92.83972168, 13.44055653], [92.83999634, 13.44056129], [92.84027863, 13.44028091], [92.84139252, 13.44138813], [92.84139252, 13.44194508], [92.84166718, 13.4422226], [92.84166718, 13.44361115], [92.84194183, 13.44389057], [92.84194183, 13.44416714], [92.84249878, 13.44472313], [92.84259033, 13.44455624], [92.84267426, 13.44451332], [92.84333038, 13.44416714], [92.84333038, 13.4433279], [92.84305573, 13.44305515], [92.84306335, 13.44110966], [92.84333038, 13.44083214]]], [[[93.072052, 13.42608166], [93.07198334, 13.42580795], [93.07163239, 13.42581081], [93.07150269, 13.42567158], [93.07128143, 13.42512226], [93.07121277, 13.42471027], [93.07100677, 13.42443371], [93.07086182, 13.4234724], [93.07057953, 13.42312813], [93.07051086, 13.42284966], [93.07065582, 13.42250824], [93.07065582, 13.42210007], [93.07079315, 13.42181969], [93.07093048, 13.42134094], [93.07086182, 13.42100239], [93.07071686, 13.42078972], [93.07071686, 13.42045021], [93.07086182, 13.42003059], [93.07086182, 13.41969109], [93.07093048, 13.41942024], [93.07108307, 13.41913986], [93.07107544, 13.41886616], [93.07100677, 13.41858101], [93.07107544, 13.4181776], [93.07121277, 13.41784], [93.0713501, 13.41763115], [93.0713501, 13.41742992], [93.07121277, 13.41701126], [93.07113647, 13.41672993], [93.0711441, 13.41577339], [93.07121277, 13.41542912], [93.0713501, 13.41508007], [93.0713501, 13.4146719], [93.07156372, 13.41432762], [93.07184601, 13.41399097], [93.07190704, 13.41363144], [93.0713501, 13.41343498], [93.07113647, 13.41344166], [93.07051086, 13.41329956], [93.06896973, 13.41329956], [93.06896973, 13.41384983], [93.06890106, 13.41439724], [93.06841278, 13.41474056], [93.06819153, 13.4148798], [93.06819153, 13.4153614], [93.06841278, 13.41549683], [93.06896973, 13.41569996], [93.06910706, 13.41619015], [93.06910706, 13.41660118], [93.0687561, 13.41701126], [93.06868744, 13.41769695], [93.06855011, 13.4179697], [93.06841278, 13.41831684], [93.06833649, 13.41866112], [93.06835175, 13.41900063], [93.06841278, 13.41948605], [93.06826782, 13.41961956], [93.06799316, 13.41976166], [93.06784821, 13.42031097], [93.06784821, 13.42057991], [93.06762695, 13.42093086], [93.06756592, 13.42161465], [93.06754303, 13.42169666], [93.06735992, 13.42230129], [93.06771088, 13.42264938], [93.06762695, 13.42368031], [93.06762695, 13.42416], [93.06806183, 13.42429733], [93.06835175, 13.4244318], [93.06868744, 13.42477989], [93.06896973, 13.42539787], [93.06918335, 13.42615032], [93.06918335, 13.42642784], [93.06945801, 13.42732239], [93.07009888, 13.42780018], [93.07051086, 13.42821503], [93.07079315, 13.42896938], [93.07093048, 13.42924786], [93.07121277, 13.42986488], [93.07149506, 13.43014145], [93.07156372, 13.43055344], [93.07184601, 13.43096066], [93.07233429, 13.43110275], [93.07268524, 13.43110275], [93.07296753, 13.43096638], [93.07324982, 13.43068981], [93.07324982, 13.43020916], [93.07303619, 13.42958927], [93.07269287, 13.42924976], [93.07247162, 13.42877102], [93.07261658, 13.42828083], [93.07254791, 13.42793941], [93.07213593, 13.42753124], [93.07199097, 13.42712116], [93.07199097, 13.42650127], [93.072052, 13.42608166]]], [[[93.06388855, 13.65416622], [93.06472015, 13.65332985], [93.06576538, 13.65312672], [93.06749725, 13.65146065], [93.06749725, 13.65062046], [93.0672226, 13.65027809], [93.06694794, 13.64999962], [93.06624603, 13.64924145], [93.06535339, 13.64777756], [93.06500244, 13.64750004], [93.06472015, 13.6472187], [93.06416321, 13.6472187], [93.06388855, 13.64750195], [93.06361389, 13.64750004], [93.0633316, 13.64756966], [93.06256866, 13.64764118], [93.06221771, 13.64750195], [93.06173706, 13.6473608], [93.06111145, 13.64722157], [93.06076813, 13.64701653], [93.06027985, 13.64693928], [93.05986023, 13.64680672], [93.05944824, 13.64667034], [93.05895996, 13.64646053], [93.05832672, 13.64610958], [93.05812836, 13.64590359], [93.05764008, 13.64548683], [93.05750275, 13.64528179], [93.05665588, 13.64444065], [93.05638885, 13.64406681], [93.05583191, 13.64337921], [93.05539703, 13.64275932], [93.05526733, 13.64194107], [93.05527496, 13.64055538], [93.05500031, 13.64028168], [93.05500031, 13.63722134], [93.05500031, 13.63673782], [93.05473328, 13.63583088], [93.05458832, 13.63555527], [93.05444336, 13.63528061], [93.0541687, 13.63500118], [93.0541687, 13.6347208], [93.05403137, 13.63444519], [93.05403137, 13.63416672], [93.05396271, 13.63389111], [93.05361176, 13.63333035], [93.05361176, 13.63305473], [93.05362701, 13.63276958], [93.05314636, 13.63209534], [93.05272675, 13.63134098], [93.05249786, 13.63111115], [93.05249786, 13.63083267], [93.05222321, 13.6305542], [93.05222321, 13.63028145], [93.05194092, 13.63000107], [93.05194092, 13.62972927], [93.05166626, 13.62944031], [93.05166626, 13.62907791], [93.05148315, 13.62873077], [93.05099487, 13.62797737], [93.05050659, 13.62714863], [93.04972076, 13.62611008], [93.04972076, 13.6258297], [93.04916382, 13.62527847], [93.04915619, 13.62471962], [93.0486145, 13.62416553], [93.04860687, 13.62388992], [93.04833221, 13.62360096], [93.04833221, 13.62333202], [93.04888916, 13.62277794], [93.04888916, 13.62250042], [93.04915619, 13.62222195], [93.04916382, 13.62194443], [93.04888916, 13.62166595], [93.04860687, 13.62167263], [93.04833221, 13.62139034], [93.04805756, 13.62139034], [93.0477829, 13.62111187], [93.04750061, 13.62111187], [93.04724121, 13.62083244], [93.04695129, 13.62083244], [93.04638672, 13.62138844], [93.04638672, 13.62194443], [93.04695129, 13.62250042], [93.04694366, 13.62277794], [93.04672241, 13.62298965], [93.04611969, 13.62339973], [93.04556274, 13.62417126], [93.04576874, 13.62553978], [93.0458374, 13.62618065], [93.04582977, 13.62680054], [93.04562378, 13.62771034], [93.04541779, 13.62860966], [93.04541779, 13.62889099], [93.04528046, 13.62917137], [93.04528046, 13.62972927], [93.04499817, 13.63000107], [93.04499817, 13.63028145], [93.04472351, 13.6305542], [93.04472351, 13.63083267], [93.04444122, 13.63111115], [93.04444122, 13.63166714], [93.04416656, 13.63194466], [93.04418182, 13.63222027], [93.04389191, 13.63250065], [93.04389191, 13.63276958], [93.04360962, 13.63305473], [93.04360962, 13.63333035], [93.04305267, 13.6338892], [93.04305267, 13.63444519], [93.04277802, 13.6347208], [93.04277802, 13.63555527], [93.04250336, 13.63583279], [93.04250336, 13.63694477], [93.04499817, 13.6394453], [93.04499817, 13.63972092], [93.04556274, 13.64028168], [93.04555511, 13.64055538], [93.04582977, 13.6408329], [93.04582977, 13.64111137], [93.04638672, 13.64166832], [93.04660034, 13.64194107], [93.04777527, 13.64277744], [93.04798889, 13.64297962], [93.04833221, 13.64305973], [93.0486145, 13.64333057], [93.05027771, 13.64470959], [93.05027771, 13.64500046], [93.05110931, 13.64583397], [93.05132294, 13.64589977], [93.05200958, 13.64666557], [93.05222321, 13.64694405], [93.05249786, 13.6472187], [93.05249786, 13.64805603], [93.05278015, 13.64833164], [93.05278015, 13.64888954], [93.05304718, 13.64916992], [93.05304718, 13.64999962], [93.0533371, 13.65028], [93.0533371, 13.65055561], [93.05379486, 13.65135193], [93.05414581, 13.65176392], [93.05470276, 13.65176392], [93.05504608, 13.65190125], [93.05526733, 13.65210819], [93.055336, 13.65244961], [93.05526733, 13.65278053], [93.05555725, 13.65305424], [93.05555725, 13.65333366], [93.05595398, 13.65370083], [93.05645752, 13.65417099], [93.06082916, 13.65416622], [93.06138611, 13.65444374], [93.06222534, 13.65444374], [93.06263733, 13.65458584], [93.06319427, 13.65465355], [93.06368256, 13.65444183], [93.06388855, 13.65416622]]], [[[93.22442627, 14.01583099], [93.22666931, 14.01388454], [93.22708893, 14.0132618], [93.22715759, 14.01207924], [93.22694397, 14.01138878], [93.22666931, 14.01111126], [93.22666931, 14.01083279], [93.22639465, 14.01027679], [93.22638702, 14.00992966], [93.22653198, 14.00951099], [93.22673798, 14.00930309], [93.22687531, 14.00881958], [93.22666931, 14.00722313], [93.22638702, 14.00694466], [93.22638702, 14.00666714], [93.22631836, 14.00618076], [93.22611237, 14.00500011], [93.22556305, 14.00444031], [93.22555542, 14.00416565], [93.22499847, 14.00360966], [93.22499847, 14.00166607], [93.22528076, 14.00139046], [93.22528076, 14.00111008], [93.22556305, 14.0008297], [93.22555542, 14.00055599], [93.22611237, 14.00001144], [93.22638702, 13.99971962], [93.22638702, 13.99944401], [93.22666931, 13.99916553], [93.22666931, 13.99888992], [93.22721863, 13.99833202], [93.22721863, 13.99805641], [93.22750092, 13.99777985], [93.22750092, 13.99750042], [93.2277832, 13.99722195], [93.22777557, 13.99694443], [93.22805786, 13.99666786], [93.22805786, 13.99555969], [93.22833252, 13.99528027], [93.22833252, 13.99472237], [93.22895813, 13.99388981], [93.22930908, 13.99249935], [93.22944641, 13.99222088], [93.22944641, 13.99166775], [93.22972107, 13.99138927], [93.22986603, 13.99055958], [93.23000336, 13.99028015], [93.23000336, 13.99000072], [93.23027802, 13.9897213], [93.23027802, 13.98944473], [93.23055267, 13.98916721], [93.2305603, 13.9888916], [93.23110962, 13.98807144], [93.23139191, 13.98750114], [93.23145294, 13.98722076], [93.23166656, 13.98666668], [93.23166656, 13.98631191], [93.23173523, 13.98590374], [93.23165894, 13.98569584], [93.23179626, 13.98534966], [93.23194122, 13.98465919], [93.23236847, 13.98353958], [93.2324295, 13.98326397], [93.23236084, 13.98222065], [93.23216248, 13.98167133], [93.23194122, 13.98111057], [93.23166656, 13.98083305], [93.23166656, 13.98027897], [93.23139191, 13.98000145], [93.23139191, 13.97943974], [93.23110962, 13.97916603], [93.23110962, 13.9786396], [93.23078918, 13.97788143], [93.23078918, 13.97732925], [93.23085785, 13.97692204], [93.23085785, 13.97623062], [93.23114014, 13.9756794], [93.23114014, 13.97526932], [93.23107147, 13.9748497], [93.23043823, 13.97437286], [93.22953033, 13.97402859], [93.22889709, 13.97375107], [93.22777557, 13.97313595], [93.227211, 13.97266197], [93.22659302, 13.9725914], [93.22611237, 13.97249985], [93.22548676, 13.97250175], [93.22506714, 13.97236347], [93.22472382, 13.97236347], [93.22444153, 13.9721508], [93.22416687, 13.97194386], [93.22382355, 13.97166824], [93.22305298, 13.97159958], [93.22249603, 13.97174072], [93.22244263, 13.97244072], [93.22202301, 13.97299004], [93.22055817, 13.97360992], [93.22027588, 13.97360992], [93.22000122, 13.9738903], [93.21971893, 13.9738903], [93.21943665, 13.97417068], [93.21916962, 13.97416592], [93.21888733, 13.97444439], [93.21888733, 13.97472191], [93.2186203, 13.97500038], [93.2186203, 13.97528267], [93.21833038, 13.97555637], [93.21833038, 13.97611046], [93.21833038, 13.97680092], [93.2186203, 13.97806072], [93.21881866, 13.97874928], [93.21902466, 13.9795742], [93.21930695, 13.98081207], [93.21958923, 13.98184204], [93.2196579, 13.98294067], [93.21986389, 13.98383617], [93.22000122, 13.98444462], [93.22000122, 13.98583317], [93.22006989, 13.98631763], [93.22027588, 13.98694515], [93.22055817, 13.98722076], [93.22055817, 13.98807144], [93.22055054, 13.98847008], [93.22083282, 13.9897213], [93.22083282, 13.99360943], [93.22097778, 13.99402618], [93.22110748, 13.9944458], [93.22110748, 13.99583244], [93.22117615, 13.99617958], [93.22117615, 13.99812698], [93.22110748, 13.9986124], [93.22110748, 13.99944401], [93.22083282, 13.99971962], [93.22083282, 14.00001144], [93.22055817, 14.00028038], [93.22033691, 14.00123978], [93.22027588, 14.00278091], [93.22013855, 14.00305557], [93.22013855, 14.00360966], [93.22027588, 14.00389099], [93.22027588, 14.00416565], [93.22055817, 14.00444031], [93.22055817, 14.00528145], [93.22083282, 14.0055542], [93.22083282, 14.00694466], [93.22055817, 14.00722027], [93.22055817, 14.00805664], [93.22027588, 14.00833321], [93.22027588, 14.00887966], [93.22000122, 14.00916672], [93.22000122, 14.00944519], [93.21971893, 14.00972271], [93.21971893, 14.01083279], [93.21943665, 14.01111126], [93.21944427, 14.01166725], [93.21951294, 14.01242447], [93.21971893, 14.0144453], [93.22000122, 14.01472092], [93.22000122, 14.01528168], [93.22027588, 14.01556015], [93.22055817, 14.01555538], [93.22083282, 14.0158329], [93.22138977, 14.01583099], [93.22161102, 14.01605415], [93.22194672, 14.01639175], [93.22249603, 14.01639175], [93.22277832, 14.01667023], [93.2233429, 14.01667023], [93.22360992, 14.01639175], [93.22381592, 14.01632118], [93.22389221, 14.0160408], [93.22442627, 14.01583099]]], [[[93.01583099, 13.67611217], [93.01638794, 13.67555618], [93.01667023, 13.67556095], [93.01695251, 13.67527962], [93.01750183, 13.67527962], [93.01777649, 13.67500019], [93.01805878, 13.67500019], [93.01889038, 13.67416954], [93.01889038, 13.67389011], [93.01917267, 13.67360973], [93.01916504, 13.67305565], [93.01944733, 13.67278004], [93.01944733, 13.67249966], [93.02027893, 13.67166996], [93.02081299, 13.67148113], [93.02108765, 13.67100239], [93.02129364, 13.67065811], [93.02157593, 13.67045116], [93.02185822, 13.67045307], [93.0221405, 13.67038155], [93.02227783, 13.67031384], [93.0223465, 13.66976547], [93.0223465, 13.6694212], [93.02205658, 13.66901016], [93.02194214, 13.66861057], [93.02194214, 13.66722107], [93.02249908, 13.66666698], [93.02249908, 13.66638947], [93.02278137, 13.66611099], [93.02278137, 13.66527939], [93.02307129, 13.66500092], [93.02307129, 13.66472054], [93.02333069, 13.66444302], [93.02333069, 13.66388893], [93.02361298, 13.66361141], [93.02361298, 13.66333294], [93.02444458, 13.66250134], [93.02443695, 13.66222095], [93.02500153, 13.66166687], [93.02500153, 13.66139126], [93.02555847, 13.66082954], [93.02555847, 13.65944481], [93.02500153, 13.65888882], [93.02500153, 13.6586113], [93.02444458, 13.65805435], [93.02443695, 13.65722275], [93.02500153, 13.65667057], [93.02500153, 13.65639114], [93.02527618, 13.65610981], [93.02527618, 13.65583038], [93.02555847, 13.65555668], [93.02555847, 13.65499973], [93.02581787, 13.65472031], [93.02583313, 13.65416622], [93.02610779, 13.65390015], [93.02610779, 13.65361023], [93.02583313, 13.65333366], [93.02583313, 13.65222168], [93.02555847, 13.65194416], [93.02555847, 13.6497221], [93.02527618, 13.64944363], [93.02527618, 13.64833355], [93.02555847, 13.64805603], [93.02555847, 13.64777088], [93.02583313, 13.64750004], [93.02581787, 13.64693928], [93.02610779, 13.64666557], [93.02610779, 13.64638996], [93.02639008, 13.64610958], [93.02639008, 13.64583397], [93.02694702, 13.64527798], [93.02694702, 13.64500046], [93.02722168, 13.64470959], [93.02722168, 13.64444447], [93.02777863, 13.64388657], [93.02777863, 13.64361191], [93.0283432, 13.64305973], [93.0283432, 13.6427803], [93.02861023, 13.64250183], [93.02861023, 13.64222145], [93.02889252, 13.64194584], [93.02889252, 13.64138889], [93.02916718, 13.64111137], [93.02916718, 13.64055538], [93.02944183, 13.64028168], [93.02944183, 13.63890076], [93.02971649, 13.63861084], [93.02971649, 13.63694096], [93.02999878, 13.63666725], [93.02999878, 13.63639069], [93.0319519, 13.63444042], [93.03194427, 13.63416672], [93.03221893, 13.63389111], [93.03221893, 13.63333035], [93.03194427, 13.63305473], [93.0319519, 13.63222027], [93.03166962, 13.63194466], [93.03166962, 13.63000107], [93.03145599, 13.62924194], [93.03125, 13.62896061], [93.03034973, 13.62799263], [93.02986145, 13.62778091], [93.02944183, 13.62778091], [93.02903748, 13.62757111], [93.02861023, 13.62749958], [93.0284729, 13.62716103], [93.02777863, 13.62693977], [93.02694702, 13.62694359], [93.02666473, 13.62722206], [93.02610779, 13.62722206], [93.02583313, 13.62694359], [93.02527618, 13.62694359], [93.02500153, 13.62722206], [93.02443695, 13.62722015], [93.02416992, 13.62749958], [93.02388763, 13.62749958], [93.01972198, 13.63167095], [93.01944733, 13.63166714], [93.01916504, 13.63194466], [93.01889038, 13.6319418], [93.01832581, 13.63250065], [93.01805878, 13.63250065], [93.01777649, 13.63276958], [93.01777649, 13.63305473], [93.01750183, 13.63333035], [93.01750183, 13.63528061], [93.01721954, 13.63555527], [93.01721954, 13.63583088], [93.01555634, 13.63750076], [93.01555634, 13.63777924], [93.01526642, 13.63805962], [93.01526642, 13.63861084], [93.01499939, 13.63888931], [93.01499939, 13.64111137], [93.01526642, 13.64139175], [93.01527405, 13.64166832], [93.01555634, 13.64194107], [93.01555634, 13.64305973], [93.0147171, 13.64389038], [93.01167297, 13.64389038], [93.01139069, 13.64416981], [93.01083374, 13.6441679], [93.01055908, 13.64444447], [93.01027679, 13.64444447], [93.00888824, 13.64583397], [93.0083313, 13.64583397], [93.00805664, 13.64611244], [93.00749969, 13.64610958], [93.00723267, 13.64638996], [93.00666809, 13.64638996], [93.0063858, 13.64667034], [93.00583649, 13.64666557], [93.0055542, 13.64694405], [93.00333405, 13.64694405], [93.00250244, 13.64777088], [93.00250244, 13.64805603], [93.00111389, 13.64944363], [93.0008316, 13.64944363], [93.00066376, 13.64927769], [93.00055695, 13.64916801], [93.00026703, 13.64916992], [93.0, 13.64888954], [92.99973297, 13.64861202], [92.99972534, 13.64833355], [92.9991684, 13.64777756], [92.9991684, 13.64750004], [92.99887848, 13.6472187], [92.99861145, 13.64722157], [92.9980545, 13.64666557], [92.99694824, 13.64667034], [92.99666595, 13.64638996], [92.9963913, 13.64638996], [92.9952774, 13.64528179], [92.9952774, 13.64500046], [92.9944458, 13.64416981], [92.99416351, 13.64444447], [92.99388885, 13.64444447], [92.9936142, 13.64472198], [92.99333191, 13.64470959], [92.99305725, 13.64500046], [92.99194336, 13.64500046], [92.9916687, 13.64470959], [92.9908371, 13.64472198], [92.99055481, 13.64444447], [92.98944092, 13.64444447], [92.98805237, 13.64305592], [92.98777771, 13.64305973], [92.98750305, 13.6427803], [92.98638916, 13.6427803], [92.98610687, 13.64305973], [92.98583221, 13.64305592], [92.98555756, 13.64333439], [92.98500061, 13.64333057], [92.98472595, 13.64361191], [92.98443604, 13.64361191], [92.98388672, 13.6441679], [92.98390198, 13.64444065], [92.98444366, 13.64500046], [92.98444366, 13.64583397], [92.98472595, 13.64610958], [92.98472595, 13.64638996], [92.98444366, 13.64666557], [92.98444366, 13.64694405], [92.98416901, 13.6472187], [92.98416901, 13.64750004], [92.98390198, 13.64777088], [92.98388672, 13.64805603], [92.98361206, 13.64833164], [92.98361206, 13.64861202], [92.98166656, 13.65056133], [92.98166656, 13.65084076], [92.98084259, 13.65167141], [92.98055267, 13.65166569], [92.98027802, 13.65194416], [92.98000336, 13.65194416], [92.97972107, 13.65222168], [92.97944641, 13.65221977], [92.97888947, 13.65278053], [92.97861481, 13.65277767], [92.97805786, 13.65333366], [92.97776794, 13.65332985], [92.97721863, 13.65390015], [92.97721863, 13.65416622], [92.97694397, 13.65444374], [92.97693634, 13.65472031], [92.97666931, 13.65499973], [92.97666931, 13.65639114], [92.97694397, 13.65666676], [92.97693634, 13.65694046], [92.97721863, 13.65722275], [92.97750092, 13.65722275], [92.97776794, 13.65750122], [92.97805786, 13.65750122], [92.97833252, 13.65722275], [92.97860718, 13.65750122], [92.97915649, 13.65750122], [92.98083496, 13.65916729], [92.98084259, 13.65971088], [92.98110962, 13.6600008], [92.98110962, 13.66028118], [92.98139191, 13.66056156], [92.98139191, 13.66139126], [92.98110962, 13.66166687], [92.98110962, 13.66222286], [92.98000336, 13.66333294], [92.98000336, 13.66361141], [92.98042297, 13.66403008], [92.98166656, 13.66527939], [92.98194122, 13.66527939], [92.98221588, 13.66555977], [92.98278046, 13.66555977], [92.98306274, 13.66584015], [92.98390198, 13.66584015], [92.98416901, 13.66611099], [92.98443604, 13.66611099], [92.98472595, 13.66638947], [92.98500061, 13.66638947], [92.9852829, 13.66611099], [92.98555756, 13.66611099], [92.98583221, 13.66584015], [92.98722076, 13.66584015], [92.98750305, 13.66611099], [92.98777771, 13.66584015], [92.98805237, 13.66584015], [92.98832703, 13.66611099], [92.9888916, 13.66611099], [92.98916626, 13.66638947], [92.98944092, 13.66638947], [92.98970795, 13.66667175], [92.99055481, 13.66666698], [92.9908371, 13.66694546], [92.99138641, 13.66694546], [92.9916687, 13.66722107], [92.99223328, 13.66722107], [92.99250031, 13.6675024], [92.99305725, 13.6675024], [92.99333191, 13.66778183], [92.99360657, 13.66778183], [92.99388885, 13.6680603], [92.99500275, 13.6680603], [92.9952774, 13.66778183], [92.99584198, 13.66778183], [92.99610901, 13.6680603], [92.9972229, 13.6680603], [92.99749756, 13.66778183], [92.99777985, 13.6680603], [92.9991684, 13.6680603], [93.0, 13.66890144], [93.00049591, 13.66895962], [93.00055695, 13.66916847], [93.0008316, 13.66944313], [93.00111389, 13.66944313], [93.001297, 13.66963005], [93.00138855, 13.66972446], [93.00164795, 13.66972065], [93.00222015, 13.67028046], [93.00250244, 13.67028046], [93.0029068, 13.67056179], [93.00389099, 13.67056179], [93.0047226, 13.66972065], [93.0047226, 13.66889], [93.00501251, 13.66861057], [93.00499725, 13.66833305], [93.00527954, 13.66805458], [93.00527954, 13.66778183], [93.00554657, 13.6675024], [93.0063858, 13.6675024], [93.00666809, 13.66778183], [93.00701904, 13.66791916], [93.00722504, 13.66861057], [93.00722504, 13.66944313], [93.00701141, 13.66972446], [93.00708771, 13.67096996], [93.00723267, 13.67138958], [93.00722504, 13.67166805], [93.00778198, 13.67221928], [93.00778198, 13.67249966], [93.0080719, 13.67278004], [93.0080719, 13.67306042], [93.00837708, 13.67337894], [93.00860596, 13.67360973], [93.00888824, 13.67360973], [93.00945282, 13.67416954], [93.00971985, 13.67416573], [93.01000214, 13.6744442], [93.01055908, 13.6744442], [93.01083374, 13.67472172], [93.01194763, 13.67472172], [93.01222229, 13.6744442], [93.01277924, 13.67444134], [93.01294708, 13.67445278], [93.01315308, 13.6744709], [93.01338196, 13.6742363], [93.01384735, 13.67405415], [93.0141983, 13.67391491], [93.01454926, 13.67391491], [93.01454926, 13.67412186], [93.0142746, 13.6745348], [93.01377869, 13.67466927], [93.01371002, 13.67509079], [93.01416779, 13.67527962], [93.01444244, 13.67556095], [93.01472473, 13.67555618], [93.01527405, 13.67611217], [93.01583099, 13.67611217]]], [[[93.02361298, 13.67086124], [93.02311707, 13.67086124], [93.0229187, 13.67127991], [93.02311707, 13.67162037], [93.02339935, 13.67196369], [93.02346802, 13.67224026], [93.02326202, 13.67258167], [93.02291107, 13.67292595], [93.02275848, 13.67320156], [93.02284241, 13.6734066], [93.02284241, 13.67354107], [93.02256012, 13.6738224], [93.02269745, 13.67430019], [93.02318573, 13.67389011], [93.02339935, 13.6738224], [93.0239563, 13.67354107], [93.02403259, 13.67327023], [93.02403259, 13.67300129], [93.02423859, 13.6725111], [93.02423859, 13.67217064], [93.02403259, 13.67169094], [93.02381897, 13.67135143], [93.02361298, 13.67086124]]], [[[93.3666687, 14.04749966], [93.36611938, 14.0469389], [93.36611176, 14.04666805], [93.3658371, 14.04666996], [93.36541748, 14.04666138], [93.36444092, 14.04749966], [93.36416626, 14.04749966], [93.36354065, 14.04806042], [93.36360931, 14.04861164], [93.36360931, 14.04889202], [93.3638916, 14.04916573], [93.3638916, 14.0494442], [93.36360931, 14.04971886], [93.36360931, 14.05027962], [93.36464691, 14.05138969], [93.36486053, 14.05280781], [93.36472321, 14.05356026], [93.36450958, 14.05376911], [93.36444092, 14.05416584], [93.36444092, 14.05444431], [93.36416626, 14.05471992], [93.36416626, 14.05527973], [93.36402893, 14.05631065], [93.36424255, 14.05686188], [93.36499786, 14.05694389], [93.36528015, 14.05666637], [93.36528015, 14.05639267], [93.36554718, 14.05611038], [93.36555481, 14.05583191], [93.36603546, 14.05534172], [93.36610413, 14.05478764], [93.36633301, 14.05416107], [93.36638641, 14.05389023], [93.36638641, 14.05360985], [93.3666687, 14.05333424], [93.3666687, 14.05277824], [93.36694336, 14.05249977], [93.36694336, 14.05222034], [93.3666687, 14.05194759], [93.36646271, 14.05180931], [93.36638641, 14.05167007], [93.36638641, 14.05146122], [93.36618042, 14.05104065], [93.36604309, 14.05027962], [93.36611938, 14.05000019], [93.36632538, 14.04937267], [93.36638641, 14.04889011], [93.36638641, 14.04861164], [93.3666687, 14.04833126], [93.3666687, 14.04749966]]], [[[93.38360596, 14.12777996], [93.38360596, 14.12736034], [93.38319397, 14.12707806], [93.38223267, 14.1272192], [93.38194275, 14.12736034], [93.38166809, 14.12749863], [93.3813858, 14.12749863], [93.38083649, 14.12805557], [93.38083649, 14.12833118], [93.38131714, 14.12910175], [93.38166809, 14.12930679], [93.38222504, 14.12944412], [93.3833313, 14.12833405], [93.3833313, 14.12805557], [93.38360596, 14.12777996]]], [[[93.36624908, 14.15638065], [93.36638641, 14.15611172], [93.36694336, 14.15555954], [93.36694336, 14.15528202], [93.3666687, 14.15500164], [93.3666687, 14.15388966], [93.36694336, 14.15360928], [93.36694336, 14.15166664], [93.36750031, 14.15111065], [93.36750031, 14.15057087], [93.36776733, 14.15028191], [93.36776733, 14.14889145], [93.36833191, 14.14833069], [93.3694458, 14.1483326], [93.37000275, 14.1477766], [93.3702774, 14.14778137], [93.37055206, 14.14806175], [93.37083435, 14.14805508], [93.37110901, 14.1483326], [93.37304688, 14.14833069], [93.37333679, 14.14861107], [93.37695313, 14.14861107], [93.37722015, 14.1483326], [93.3777771, 14.1483326], [93.37805176, 14.14805508], [93.37832642, 14.14806175], [93.3786087, 14.14778137], [93.3786087, 14.14722061], [93.37750244, 14.14611053], [93.37722015, 14.14611053], [93.3769455, 14.14583302], [93.37638855, 14.14583302], [93.37610626, 14.14555931], [93.37555695, 14.14555931], [93.37526703, 14.14528084], [93.37499237, 14.14555931], [93.37388611, 14.14555931], [93.37361145, 14.14528084], [93.37333679, 14.14527893], [93.37277985, 14.14583302], [93.37166595, 14.14583302], [93.37110901, 14.14527893], [93.37055206, 14.14528084], [93.37055206, 14.14500141], [93.3702774, 14.14472103], [93.3702774, 14.14416695], [93.37000275, 14.14389133], [93.37000275, 14.14332962], [93.36972046, 14.14305687], [93.36972046, 14.14137936], [93.3694458, 14.14111042], [93.3694458, 14.14055443], [93.36972046, 14.14028072], [93.36972046, 14.13971996], [93.37000275, 14.13944435], [93.37000275, 14.13888836], [93.36972046, 14.13861275], [93.37000275, 14.13834095], [93.37000275, 14.13611031], [93.3702774, 14.13583374], [93.37021637, 14.1351366], [93.3702774, 14.13464928], [93.37034607, 14.13416958], [93.37055206, 14.13360977], [93.37055206, 14.13167], [93.37082672, 14.13138962], [93.37082672, 14.13111019], [93.37110901, 14.13083363], [93.37110901, 14.13027763], [93.3713913, 14.13000202], [93.3713913, 14.12972164], [93.37194824, 14.12916565], [93.37194824, 14.12889194], [93.37249756, 14.12833118], [93.37249756, 14.12805557], [93.37304688, 14.12749863], [93.37304688, 14.1272192], [93.37472534, 14.12555504], [93.37473297, 14.12528038], [93.37596893, 14.12389183], [93.37610626, 14.12333965], [93.37673187, 14.12284088], [93.37784576, 14.12270641], [93.37805939, 14.12222099], [93.37805176, 14.1208334], [93.3777771, 14.12055492], [93.3777771, 14.12026978], [93.37750244, 14.11999893], [93.37750244, 14.11972141], [93.37722015, 14.11944485], [93.37722015, 14.11916733], [93.37695313, 14.11889076], [93.37695313, 14.11778069], [93.37722015, 14.11750126], [93.37722015, 14.11721134], [93.37666321, 14.11666679], [93.37666321, 14.11583042], [93.37638855, 14.11555672], [93.37638855, 14.11528111], [93.37610626, 14.11500072], [93.37610626, 14.11443996], [93.37555695, 14.11388779], [93.37555695, 14.11306095], [93.37526703, 14.11278057], [93.37526703, 14.11194038], [93.375, 14.11166573], [93.37499237, 14.11110973], [93.37473297, 14.11083031], [93.37472534, 14.11055565], [93.37499237, 14.11028099], [93.37499237, 14.10917091], [93.37555695, 14.10861015], [93.37555695, 14.10805607], [93.3758316, 14.10778046], [93.3758316, 14.10750008], [93.37610626, 14.1072197], [93.37611389, 14.10583401], [93.3758316, 14.10555553], [93.3758316, 14.10527134], [93.375, 14.10444355], [93.375, 14.10305595], [93.37473297, 14.10278034], [93.37473297, 14.10223103], [93.37444305, 14.10194111], [93.37444305, 14.10138988], [93.37499237, 14.10083103], [93.375, 14.10027695], [93.37526703, 14.09999943], [93.37526703, 14.09833145], [93.37555695, 14.09805489], [93.37555695, 14.09639168], [93.37526703, 14.0961113], [93.37527466, 14.09583282], [93.375, 14.09555531], [93.37499237, 14.09388924], [93.37473297, 14.09361076], [93.37472534, 14.09249878], [93.37464905, 14.09222126], [93.37409973, 14.09145737], [93.37388611, 14.09139061], [93.37333679, 14.09082985], [93.3730545, 14.09083271], [93.37249756, 14.09027672], [93.37249756, 14.09000111], [93.37304688, 14.08944035], [93.3730545, 14.08888912], [93.37166595, 14.08750057], [93.37166595, 14.08723164], [93.3713913, 14.08694172], [93.3713913, 14.08666611], [93.37110901, 14.08639145], [93.37110901, 14.08611012], [93.37082672, 14.08582973], [93.37110901, 14.08555698], [93.37110901, 14.0841713], [93.37082672, 14.08388996], [93.37082672, 14.08278275], [93.37055206, 14.08250046], [93.37055206, 14.0819397], [93.3702774, 14.08166599], [93.3702774, 14.08110142], [93.37000275, 14.08083439], [93.37000275, 14.08055592], [93.36972046, 14.0802803], [93.36972046, 14.07999992], [93.37000275, 14.07971954], [93.37000275, 14.07916641], [93.36972046, 14.07888985], [93.36972046, 14.07861042], [93.36916351, 14.07805634], [93.36915588, 14.07750034], [93.36888885, 14.07722187], [93.36916351, 14.07694435], [93.36916351, 14.07639027], [93.3694458, 14.07611179], [93.3694458, 14.07555962], [93.36972046, 14.07529068], [93.36972046, 14.07500172], [93.3694458, 14.07471943], [93.3694458, 14.07444572], [93.36916351, 14.07416534], [93.3694458, 14.07388973], [93.3694458, 14.07360935], [93.36916351, 14.07333374], [93.36916351, 14.07249928], [93.3694458, 14.07221889], [93.36972046, 14.0722208], [93.37000275, 14.07194328], [93.3694458, 14.0713892], [93.36860657, 14.0713892], [93.36833191, 14.07111073], [93.36805725, 14.07111073], [93.36723328, 14.07028198], [93.36723328, 14.07000065], [93.3666687, 14.06944084], [93.3666687, 14.06916714], [93.36638641, 14.06888866], [93.36638641, 14.06666946], [93.3666687, 14.06639099], [93.3666687, 14.06583118], [93.36694336, 14.06555462], [93.36694336, 14.06500053], [93.36750031, 14.06443977], [93.36750031, 14.06416702], [93.36753845, 14.06374073], [93.36704254, 14.06306076], [93.36685181, 14.06257057], [93.3664093, 14.06202221], [93.36592102, 14.06133842], [93.36535645, 14.06051064], [93.36507416, 14.0595541], [93.36493683, 14.05886841], [93.36430359, 14.05873108], [93.36367035, 14.05907345], [93.36346436, 14.0595541], [93.36360168, 14.06002998], [93.3640213, 14.06031132], [93.36444092, 14.06072998], [93.36451721, 14.06133842], [93.36451721, 14.06209087], [93.36444092, 14.06278133], [93.36444092, 14.06305695], [93.36416626, 14.0633297], [93.36416626, 14.06361103], [93.3638916, 14.06389141], [93.3638916, 14.06416702], [93.36341095, 14.0650034], [93.36284637, 14.06555271], [93.36236572, 14.06597424], [93.36165619, 14.06610203], [93.3611145, 14.0666666], [93.3611145, 14.06916714], [93.36083221, 14.06944466], [93.36083221, 14.06972122], [93.3602829, 14.07028198], [93.3602829, 14.07056046], [93.35943604, 14.0713892], [93.35916901, 14.0713892], [93.35861206, 14.07194328], [93.35778809, 14.07201385], [93.35666656, 14.0722208], [93.35582733, 14.07221889], [93.35555267, 14.07249928], [93.35472107, 14.07249928], [93.35458374, 14.07277679], [93.35424042, 14.07291031], [93.35402679, 14.07318974], [93.35388947, 14.0734024], [93.35360718, 14.07444096], [93.35312653, 14.07521152], [93.35277557, 14.0755558], [93.35263824, 14.07583141], [93.35250092, 14.07666779], [93.35229492, 14.07694435], [93.35228729, 14.07722187], [93.35250092, 14.07750034], [93.35250092, 14.07777786], [93.35305786, 14.07833385], [93.35333252, 14.07833195], [93.35388947, 14.07888985], [93.3542099, 14.07918167], [93.35462952, 14.07951927], [93.3549118, 14.07965565], [93.3549118, 14.08082294], [93.35476685, 14.08123112], [93.35456085, 14.0815773], [93.35444641, 14.08222198], [93.35444641, 14.08250046], [93.35472107, 14.08278275], [93.35500336, 14.08277798], [93.35555267, 14.08333206], [93.35639191, 14.08333206], [93.35666656, 14.08305645], [93.35749817, 14.08305645], [93.35778046, 14.08333206], [93.35805511, 14.08333206], [93.35832977, 14.08360958], [93.35832977, 14.08388996], [93.35861206, 14.08416557], [93.35861206, 14.08444405], [93.35888672, 14.08471966], [93.35888672, 14.08500004], [93.35938263, 14.08582973], [93.35943604, 14.08778095], [93.35972595, 14.08806133], [93.35972595, 14.08889103], [93.36138916, 14.09055519], [93.36138916, 14.09083271], [93.36165619, 14.09111118], [93.36166382, 14.09166718], [93.36222076, 14.09222126], [93.36222076, 14.09278107], [93.36250305, 14.09305477], [93.36250305, 14.09333134], [93.36277771, 14.09361076], [93.36277771, 14.09388924], [93.36305237, 14.09417152], [93.36305237, 14.09500122], [93.36333466, 14.09527683], [93.36332703, 14.0961113], [93.36360931, 14.09639168], [93.36360931, 14.09666729], [93.36374664, 14.09701061], [93.3638916, 14.09749889], [93.3638916, 14.09785938], [93.36382294, 14.09825993], [93.36361694, 14.09860897], [93.36332703, 14.09972095], [93.36312866, 14.10007], [93.36305237, 14.10139179], [93.36333466, 14.10166454], [93.36332703, 14.10194111], [93.36340332, 14.10223103], [93.36340332, 14.10320187], [93.36332703, 14.10361195], [93.36333466, 14.10416794], [93.36305237, 14.10444069], [93.36305237, 14.10499954], [93.36277771, 14.10527802], [93.36277771, 14.10583401], [93.36250305, 14.10610962], [93.36250305, 14.10639], [93.36228943, 14.10667038], [93.36228943, 14.10771179], [93.36235809, 14.10820198], [93.36235809, 14.10888958], [93.36222076, 14.10916615], [93.36222076, 14.10972214], [93.36187744, 14.11041069], [93.36180115, 14.11250687], [93.36166382, 14.11333466], [93.36165619, 14.11361027], [93.36138916, 14.11388779], [93.36138916, 14.11444473], [93.36165619, 14.11472034], [93.36166382, 14.11555672], [93.36138916, 14.11583328], [93.36138916, 14.1161108], [93.36055756, 14.11693954], [93.36055756, 14.11805534], [93.36027527, 14.11833286], [93.3602829, 14.11861134], [93.36000061, 14.11888885], [93.35999298, 14.11972141], [93.35972595, 14.11999893], [93.35972595, 14.1202774], [93.36027527, 14.1208334], [93.3602829, 14.12111092], [93.36055756, 14.12138939], [93.36055756, 14.12194538], [93.36027527, 14.12222099], [93.3602829, 14.12250137], [93.36000061, 14.12277699], [93.36000061, 14.12361145], [93.35972595, 14.12361145], [93.35972595, 14.12416744], [93.35943604, 14.12444115], [93.35943604, 14.12500191], [93.35916901, 14.12527657], [93.35916901, 14.12694645], [93.35888672, 14.1272192], [93.35888672, 14.12749863], [93.35861206, 14.12777996], [93.35861206, 14.12889194], [93.35860443, 14.12916565], [93.35868073, 14.12944412], [93.35861206, 14.12972164], [93.35839844, 14.13006783], [93.35749817, 14.13111019], [93.35749817, 14.13138962], [93.35722351, 14.13166809], [93.35721588, 14.13220978], [93.35694122, 14.13249969], [93.35694885, 14.13332939], [93.35721588, 14.13360977], [93.35721588, 14.13389015], [93.35694885, 14.13416958], [93.35694885, 14.13527966], [93.35666656, 14.13555622], [93.35666656, 14.13583183], [93.35582733, 14.13667107], [93.35582733, 14.13750267], [93.35555267, 14.13778114], [93.35548401, 14.14069557], [93.35534668, 14.14137936], [93.35500336, 14.14166737], [93.35479736, 14.14221954], [93.35444641, 14.14277744], [93.35388947, 14.14332962], [93.35388947, 14.14361095], [93.35360718, 14.14389133], [93.35360718, 14.14417076], [93.35333252, 14.14471817], [93.35333252, 14.14583111], [93.35346985, 14.14679718], [93.35360718, 14.14833069], [93.35374451, 14.14950657], [93.35416412, 14.14972115], [93.35639191, 14.14972115], [93.35666656, 14.15000057], [93.35721588, 14.15000057], [93.35749817, 14.15028191], [93.35778046, 14.15027714], [93.35944366, 14.15194321], [93.35972595, 14.1519413], [93.36332703, 14.15555954], [93.36360931, 14.15555954], [93.36416626, 14.15611172], [93.36444092, 14.15611172], [93.36472321, 14.15639019], [93.36499786, 14.15638065], [93.36519623, 14.15658092], [93.36528015, 14.15666962], [93.3658371, 14.15659046], [93.36604309, 14.1564579], [93.36624908, 14.15638065]]], [[[93.55055237, 14.78392029], [93.55013275, 14.78392029], [93.5497818, 14.784132], [93.54928589, 14.78508854], [93.5493927, 14.78583908], [93.54940796, 14.78592777], [93.54956818, 14.78625584], [93.54963684, 14.78680134], [93.54971313, 14.78763103], [93.5497818, 14.78817844], [93.55033875, 14.78838253], [93.55055237, 14.78824615], [93.55090332, 14.78770065], [93.55090332, 14.78516006], [93.55069733, 14.78427124], [93.55055237, 14.78392029]]], [[[93.3702774, 14.19333458], [93.37055206, 14.1930542], [93.37110901, 14.19306087], [93.37194824, 14.19221973], [93.37194824, 14.19194412], [93.3722229, 14.19166565], [93.3722229, 14.19110966], [93.37277985, 14.19055557], [93.37277985, 14.18972015], [93.37249756, 14.18944359], [93.37249756, 14.1888876], [93.3722229, 14.18861008], [93.3722229, 14.1883297], [93.37194824, 14.18805599], [93.37194824, 14.1875], [93.37166595, 14.18721962], [93.37166595, 14.18694401], [93.37110901, 14.18638992], [93.37110901, 14.18610954], [93.37083435, 14.18583393], [93.37083435, 14.18500042], [93.37055206, 14.18472195], [93.37055206, 14.18444443], [93.3702774, 14.18416786], [93.3702774, 14.18389034], [93.37000275, 14.18361187], [93.37000275, 14.18333054], [93.36972046, 14.18305588], [93.36972046, 14.18278027], [93.3694458, 14.18250179], [93.3694458, 14.18167019], [93.36915588, 14.18138981], [93.36915588, 14.18083096], [93.36722565, 14.17888927], [93.36694336, 14.17888927], [93.3666687, 14.17916679], [93.36611176, 14.17972088], [93.36611176, 14.17999935], [93.36555481, 14.18055534], [93.36554718, 14.18083096], [93.36472321, 14.18167019], [93.36333466, 14.18166542], [93.36305237, 14.1819458], [93.36090088, 14.18194103], [93.36042023, 14.18264103], [93.36055756, 14.18305588], [93.36055756, 14.18583393], [93.3602829, 14.18610954], [93.3602829, 14.18638992], [93.36000061, 14.18666553], [93.36000061, 14.18694401], [93.35972595, 14.18721962], [93.3600769, 14.18804932], [93.36125183, 14.18889046], [93.36340332, 14.18868065], [93.36416626, 14.18917274], [93.36402893, 14.18996143], [93.36416626, 14.19056129], [93.36431885, 14.19126129], [93.36486053, 14.19139004], [93.36528778, 14.19132042], [93.36776733, 14.19118118], [93.36901855, 14.19237137], [93.36978912, 14.19319344], [93.3702774, 14.19333458]]], [[[93.35694122, 14.19250011], [93.35722351, 14.19222164], [93.35749817, 14.19222164], [93.35813141, 14.19208145], [93.35888672, 14.19214916], [93.35916901, 14.19222164], [93.35943604, 14.19221973], [93.35972595, 14.19229126], [93.3601532, 14.19236088], [93.3602829, 14.19221973], [93.36055756, 14.19222164], [93.3611145, 14.19166565], [93.36110687, 14.19110966], [93.36083221, 14.19083214], [93.36083221, 14.19055557], [93.3602829, 14.18999958], [93.35943604, 14.18999958], [93.35921478, 14.18976974], [93.35888672, 14.18972206], [93.35861206, 14.18944359], [93.35832977, 14.18944359], [93.35778046, 14.1888876], [93.35749817, 14.1888876], [93.35694122, 14.18944359], [93.35694885, 14.18972015], [93.35639191, 14.19028091], [93.35582733, 14.19028091], [93.35555267, 14.18999958], [93.35527802, 14.18999958], [93.35472107, 14.19055557], [93.35500336, 14.19083023], [93.35500336, 14.19138813], [93.35541534, 14.19194412], [93.35555267, 14.19221973], [93.35590363, 14.19242668], [93.35610962, 14.19250011], [93.35694122, 14.19250011]]], [[[93.57274628, 14.87036133], [93.57315826, 14.86987972], [93.57315826, 14.86850071], [93.57274628, 14.86815929], [93.57246399, 14.86815929], [93.57221985, 14.86833286], [93.57194519, 14.86861134], [93.5716629, 14.86861134], [93.57110596, 14.86917114], [93.5708313, 14.86916733], [93.57055664, 14.86944485], [93.57026672, 14.86944008], [93.56999969, 14.8697319], [93.56944275, 14.8697319], [93.56916809, 14.87000084], [93.5688858, 14.87000084], [93.56861115, 14.87028122], [93.56833649, 14.87028122], [93.56804657, 14.8705616], [93.56804657, 14.87111092], [93.56874847, 14.87194729], [93.56944275, 14.87215233], [93.5696106, 14.87209988], [93.56976318, 14.8720293], [93.57017517, 14.87168694], [93.57067108, 14.87147999], [93.57122803, 14.87127686], [93.57206726, 14.87100124], [93.57239532, 14.87069798], [93.57274628, 14.87036133]]], [[[93.64840698, 14.93486977], [93.64916992, 14.93444061], [93.64944458, 14.93444347], [93.65034485, 14.93402386], [93.65076447, 14.93367958], [93.65194702, 14.93270016], [93.65194702, 14.93166733], [93.65159607, 14.93104076], [93.65139008, 14.93055534], [93.65112305, 14.92993069], [93.65083313, 14.92972088], [93.65013123, 14.92978859], [93.64952087, 14.93083954], [93.64916992, 14.93138885], [93.64805603, 14.93243122], [93.64805603, 14.93278027], [93.64833069, 14.93305492], [93.64833069, 14.93333054], [93.64749908, 14.93416977], [93.64639282, 14.93437958], [93.64611053, 14.93500042], [93.64611053, 14.93527794], [93.64666748, 14.93583393], [93.64722443, 14.93583393], [93.64749908, 14.93555641], [93.64771271, 14.93535042], [93.6479187, 14.93528175], [93.64840698, 14.93486977]]], [[[93.64138794, 14.9024992], [93.64250183, 14.90139103], [93.64250183, 14.90111065], [93.64306641, 14.90055943], [93.64306641, 14.89889145], [93.64332581, 14.89861107], [93.64332581, 14.89806175], [93.64306641, 14.89778137], [93.64306641, 14.89750099], [93.64277649, 14.89722061], [93.64250183, 14.89722347], [93.64221954, 14.896945], [93.64194489, 14.896945], [93.64167023, 14.89666653], [93.64138794, 14.8966713], [93.63804626, 14.89332962], [93.63805389, 14.89305687], [93.63777924, 14.89278126], [93.63777924, 14.89221954], [93.63749695, 14.89194393], [93.63749695, 14.89166641], [93.63722229, 14.89139271], [93.63722229, 14.8905611], [93.63694763, 14.89028072], [93.63694763, 14.88971996], [93.63666534, 14.88944435], [93.63666534, 14.88916588], [93.63694763, 14.88889027], [93.63694763, 14.88806057], [93.63722229, 14.88777065], [93.63722229, 14.88694382], [93.63694763, 14.8866663], [93.63694763, 14.88611031], [93.63666534, 14.88583374], [93.63666534, 14.88555622], [93.63639069, 14.88527966], [93.63639069, 14.88361168], [93.6361084, 14.88332939], [93.6361084, 14.88249969], [93.63582611, 14.88221931], [93.63583374, 14.88138962], [93.6361084, 14.88110924], [93.6361084, 14.88027668], [93.63639069, 14.88000202], [93.63639069, 14.87972069], [93.6361084, 14.87944317], [93.6361084, 14.87888908], [93.63582611, 14.87861061], [93.63583374, 14.87805462], [93.63555908, 14.87778187], [93.63555908, 14.87694073], [93.63527679, 14.87666702], [93.63527679, 14.87611103], [93.63565063, 14.87547112], [93.63591766, 14.87512016], [93.63635254, 14.87464333], [93.6364212, 14.87429905], [93.63613892, 14.87389088], [93.6357193, 14.87374973], [93.63514709, 14.87382126], [93.63507843, 14.87387753], [93.63488007, 14.87403011], [93.63404083, 14.87403011], [93.6333313, 14.87389088], [93.63305664, 14.87361145], [93.63277435, 14.87361145], [93.63194275, 14.87277699], [93.63166809, 14.87277699], [93.6313858, 14.87250137], [93.63111115, 14.87250137], [93.63054657, 14.87193966], [93.63027954, 14.87194538], [93.62916565, 14.8708334], [93.62889099, 14.8708334], [93.6286087, 14.87055683], [93.62832642, 14.8705616], [93.6277771, 14.87000084], [93.62750244, 14.87000084], [93.6258316, 14.86833], [93.62555695, 14.86833286], [93.62472534, 14.86750126], [93.62444305, 14.86750126], [93.62333679, 14.86639118], [93.62333679, 14.86611271], [93.62249756, 14.86528111], [93.62249756, 14.86472034], [93.6222229, 14.86444378], [93.6222229, 14.86416626], [93.62194061, 14.86388969], [93.62194061, 14.86333179], [93.62166595, 14.86305618], [93.62166595, 14.86250019], [93.6213913, 14.86222172], [93.6213913, 14.8619442], [93.62110901, 14.86166573], [93.62110901, 14.86139011], [93.6194458, 14.85972023], [93.6194458, 14.85944366], [93.61888885, 14.85888767], [93.61888123, 14.85861015], [93.6186142, 14.85833359], [93.6186142, 14.8577776], [93.61833191, 14.85750198], [93.61833191, 14.85694122], [93.61805725, 14.85666561], [93.61805725, 14.85527992], [93.61776733, 14.85499954], [93.61776733, 14.85444069], [93.61722565, 14.85389042], [93.61723328, 14.85361195], [93.61694336, 14.85333443], [93.61694336, 14.853055], [93.61638641, 14.85250187], [93.61638641, 14.85222054], [93.6158371, 14.8516674], [93.6158371, 14.85138893], [93.61554718, 14.85111141], [93.61555481, 14.85083294], [93.61416626, 14.84944534], [93.61416626, 14.84916687], [93.6138916, 14.84888935], [93.6138916, 14.84860039], [93.61277771, 14.84749889], [93.61277771, 14.84722137], [93.61250305, 14.84694481], [93.61250305, 14.84666729], [93.61194611, 14.8461113], [93.61194611, 14.84555531], [93.61165619, 14.84528065], [93.61165619, 14.84417057], [93.61138916, 14.84389114], [93.61138916, 14.84333038], [93.61166382, 14.84305477], [93.61165619, 14.84250069], [93.61222076, 14.84193993], [93.61222076, 14.84166718], [93.61250305, 14.84139061], [93.61250305, 14.84056091], [93.61222076, 14.84028053], [93.61222076, 14.83971977], [93.61194611, 14.83944416], [93.61194611, 14.83805561], [93.61193848, 14.83778095], [93.61207581, 14.83729076], [93.61249542, 14.83694363], [93.61277771, 14.83666611], [93.61291504, 14.83638763], [93.61290741, 14.83582973], [93.61264038, 14.83562469], [93.61194611, 14.8355608], [93.61138916, 14.83611012], [93.6111145, 14.83611012], [93.61055756, 14.83666611], [93.61055756, 14.83694172], [93.61048889, 14.83743191], [93.60999298, 14.83819962], [93.61000061, 14.83888817], [93.60971069, 14.83944035], [93.60943604, 14.84000111], [93.60943604, 14.84139061], [93.60916901, 14.84167099], [93.60916901, 14.84250069], [93.60889435, 14.8429184], [93.60874939, 14.84333038], [93.60874939, 14.84375191], [93.60874939, 14.84430981], [93.60861206, 14.84472084], [93.60861206, 14.84639072], [93.60888672, 14.84666729], [93.60888672, 14.84722137], [93.60916901, 14.84749889], [93.60916901, 14.84805489], [93.60943604, 14.84833145], [93.60943604, 14.84888935], [93.60972595, 14.84917164], [93.60972595, 14.85055542], [93.61000061, 14.85083294], [93.61000061, 14.8516674], [93.6102829, 14.85222054], [93.61048889, 14.85250187], [93.61068726, 14.85284996], [93.61069489, 14.85326099], [93.61096954, 14.85374069], [93.61103821, 14.85408783], [93.61118317, 14.85478973], [93.61125183, 14.85639], [93.61125183, 14.85666561], [93.61118317, 14.85694122], [93.6113205, 14.85742664], [93.61154175, 14.85826969], [93.61167908, 14.85929966], [93.611763, 14.86032963], [93.61174774, 14.86190796], [93.61182404, 14.86259365], [93.61194611, 14.8633337], [93.61194611, 14.86472034], [93.61222076, 14.86499977], [93.61222076, 14.86693954], [93.61207581, 14.8677597], [93.61208344, 14.86878586], [93.61228943, 14.86954021], [93.61228943, 14.87022591], [93.61279297, 14.87084198], [93.612854, 14.87173462], [93.61299133, 14.87242126], [93.61290741, 14.87325096], [93.61292267, 14.87365723], [93.61341858, 14.87434292], [93.61360931, 14.87444305], [93.61638641, 14.87722111], [93.61638641, 14.87750053], [93.61694336, 14.87805462], [93.61694336, 14.87833309], [93.61723328, 14.87861061], [93.61723328, 14.87890053], [93.61750031, 14.87916756], [93.61750031, 14.87944126], [93.61805725, 14.88000202], [93.61805725, 14.88027668], [93.6186142, 14.88083363], [93.61860657, 14.88110924], [93.61916351, 14.88166809], [93.61916351, 14.88194561], [93.6194458, 14.88221931], [93.6194458, 14.88249969], [93.61972046, 14.88278008], [93.61972046, 14.88305569], [93.62000275, 14.88332939], [93.62000275, 14.88361168], [93.62055206, 14.88416576], [93.62055206, 14.88471031], [93.62082672, 14.88500023], [93.62082672, 14.88527966], [93.62110901, 14.88555622], [93.62110901, 14.88611031], [93.6213913, 14.88638973], [93.6213913, 14.8866663], [93.62166595, 14.88694382], [93.62166595, 14.88722038], [93.62194824, 14.88749981], [93.62194061, 14.88777065], [93.6222229, 14.8880558], [93.6222229, 14.88833046], [93.62249756, 14.88861179], [93.62249756, 14.88916588], [93.62277985, 14.88944435], [93.62277985, 14.88971996], [93.62304687, 14.89000034], [93.62304687, 14.8905611], [93.62333679, 14.89084053], [93.62333679, 14.89166641], [93.62361145, 14.89194393], [93.62389374, 14.89323425], [93.6239624, 14.89419174], [93.62438202, 14.89495087], [93.62460327, 14.8955698], [93.62500763, 14.8966713], [93.62500763, 14.89750099], [93.62526703, 14.89778137], [93.62527466, 14.89805698], [93.62805176, 14.90083313], [93.6286087, 14.90083122], [93.62889099, 14.90111065], [93.6297226, 14.90111065], [93.62999725, 14.90083122], [93.63027954, 14.90083313], [93.6305542, 14.90055466], [93.63111115, 14.90055943], [93.6313858, 14.90028095], [93.63222504, 14.90027905], [93.63241577, 14.90046787], [93.63249969, 14.90055943], [93.63305664, 14.90055466], [93.6333313, 14.90083313], [93.63360596, 14.90083122], [93.63388062, 14.90111065], [93.63639069, 14.90111065], [93.63667297, 14.90139103], [93.63694763, 14.90139103], [93.63722229, 14.90166855], [93.63749695, 14.90166664], [93.63777924, 14.90194511], [93.63805389, 14.90194511], [93.63833618, 14.90222263], [93.63861084, 14.90222263], [93.6388855, 14.9024992], [93.63916779, 14.9024992], [93.63944244, 14.90278244], [93.64000702, 14.90278244], [93.64070129, 14.90264034], [93.64138794, 14.9024992]]], [[[93.5708313, 14.84632111], [93.57055664, 14.84618187], [93.57021332, 14.846241], [93.56986237, 14.84665775], [93.56965637, 14.84714127], [93.56944275, 14.84777927], [93.56916809, 14.84805489], [93.56916809, 14.84833336], [93.5689621, 14.84860039], [93.5689621, 14.84888935], [93.56964874, 14.84952068], [93.56993103, 14.84945202], [93.57026672, 14.84944057], [93.5708313, 14.84916973], [93.57158661, 14.84860039], [93.5716629, 14.84833336], [93.57194519, 14.84805489], [93.57195282, 14.84722137], [93.5716629, 14.84694481], [93.5716629, 14.84680367], [93.57138824, 14.84666729], [93.5708313, 14.84632111]]], [[[93.57221985, 14.85944366], [93.5716629, 14.85888767], [93.57110596, 14.85888958], [93.5708313, 14.85916996], [93.57055664, 14.85916805], [93.56999969, 14.85972023], [93.56999969, 14.85999966], [93.56973267, 14.86028004], [93.56972504, 14.86055565], [93.56972504, 14.86083412], [93.56999969, 14.86118126], [93.57131958, 14.86131954], [93.57250214, 14.86028004], [93.57250214, 14.85972023], [93.57221985, 14.85944366]]], [[[92.91000366, 13.53722191], [92.91194153, 13.53527737], [92.91194153, 13.53499889], [92.91249847, 13.53444099], [92.91249847, 13.53416538], [92.91278076, 13.53389168], [92.91249847, 13.5336113], [92.91249847, 13.53333282], [92.91166687, 13.53249931], [92.91110992, 13.53249931], [92.9108429, 13.53222084], [92.91055298, 13.53222084], [92.90999603, 13.53166962], [92.90972137, 13.53166962], [92.9091568, 13.53111076], [92.90888977, 13.53111076], [92.90833282, 13.53057098], [92.90805817, 13.53057098], [92.90777588, 13.53028202], [92.90611267, 13.53027916], [92.90556335, 13.53083134], [92.90556335, 13.53111076], [92.90528107, 13.53138924], [92.90528107, 13.53222084], [92.90499878, 13.53249931], [92.90499878, 13.53333282], [92.90471649, 13.5336113], [92.90472412, 13.53388882], [92.90556335, 13.53472137], [92.90555573, 13.53527737], [92.90611267, 13.53583145], [92.90611267, 13.53611183], [92.90694427, 13.53694439], [92.90777588, 13.53694439], [92.90805817, 13.53666782], [92.90833282, 13.53666782], [92.90877533, 13.53711033], [92.90888977, 13.53722191], [92.91000366, 13.53722191]]], [[[92.875, 13.54083443], [92.87638855, 13.53944397], [92.87695313, 13.53945065], [92.8786087, 13.53777981], [92.8786087, 13.53722191], [92.87805176, 13.53666782], [92.87722015, 13.53666973], [92.87666321, 13.53611183], [92.87666321, 13.53583145], [92.87638855, 13.53555584], [92.87638855, 13.53528023], [92.8758316, 13.53472137], [92.87555695, 13.53472137], [92.87444305, 13.53583145], [92.87444305, 13.53611183], [92.87388611, 13.53666782], [92.87388611, 13.53722191], [92.8741684, 13.53750038], [92.8741684, 13.54056263], [92.87444305, 13.54055595], [92.87454987, 13.54065895], [92.87472534, 13.54083443], [92.875, 13.54083443]]], [[[93.05734253, 13.5662508], [93.05734253, 13.56590939], [93.05747986, 13.56557178], [93.05741119, 13.5652914], [93.05719757, 13.56481075], [93.05692291, 13.56439972], [93.05670929, 13.56398106], [93.05670929, 13.56350231], [93.05679321, 13.56345654], [93.05706024, 13.56329727], [93.05719757, 13.56315994], [93.05741119, 13.56282139], [93.05741119, 13.56239891], [93.05699158, 13.56192303], [93.05649567, 13.56192303], [93.05610657, 13.56181622], [93.05580139, 13.56157875], [93.05565643, 13.56116581], [93.05536652, 13.56068134], [93.05488586, 13.56020355], [93.0548172, 13.5599966], [93.05444336, 13.55972099], [93.05388641, 13.55972099], [93.05361176, 13.56000233], [93.05361176, 13.56083298], [93.0534668, 13.56111145], [93.0534668, 13.56139183], [93.05207825, 13.56305599], [93.05222321, 13.5646534], [93.0533371, 13.56583405], [93.05361176, 13.56583405], [93.05388641, 13.56611156], [93.0541687, 13.56610966], [93.05444336, 13.56639004], [93.05612183, 13.56639004], [93.05665588, 13.56668186], [93.05697632, 13.56668186], [93.05713654, 13.56668186], [93.05734253, 13.5662508]]], [[[92.89694214, 13.60167122], [92.8972168, 13.60139275], [92.89778137, 13.60139275], [92.89833069, 13.60083008], [92.89888763, 13.60083199], [92.89916992, 13.60111046], [92.90083313, 13.60111046], [92.90110779, 13.60083199], [92.90166473, 13.60083199], [92.90194702, 13.60055637], [92.90222168, 13.60056114], [92.90361023, 13.59917068], [92.90361023, 13.59860992], [92.90389252, 13.59832954], [92.90389252, 13.59805584], [92.90361023, 13.59778023], [92.90389252, 13.59749985], [92.90361023, 13.59722042], [92.90361023, 13.59638786], [92.9033432, 13.59611034], [92.90333557, 13.59583378], [92.90139008, 13.59389019], [92.90139008, 13.59362125], [92.90027618, 13.59249973], [92.90027618, 13.59221935], [92.90000153, 13.59194374], [92.89971924, 13.59194374], [92.89805603, 13.59027767], [92.89778137, 13.59027958], [92.89749908, 13.59000015], [92.8972168, 13.59000015], [92.89668274, 13.5894413], [92.89638519, 13.58944321], [92.89499664, 13.58805466], [92.89472198, 13.58806038], [92.89444733, 13.58778191], [92.89417267, 13.58778191], [92.89250183, 13.58611107], [92.89250183, 13.58556175], [92.89221954, 13.58527946], [92.89221954, 13.58472061], [92.89194489, 13.58444309], [92.89194489, 13.58388901], [92.89138794, 13.58333111], [92.89138794, 13.58305454], [92.88999939, 13.58168125], [92.88999939, 13.58111095], [92.8897171, 13.58083057], [92.88972473, 13.57972336], [92.88944244, 13.57944489], [92.88944244, 13.57861137], [92.88916779, 13.57833004], [92.88916779, 13.57805538], [92.88889313, 13.57778072], [92.88889313, 13.57693958], [92.88861084, 13.57666683], [92.88833618, 13.57667065], [92.8881073, 13.57622719], [92.88804626, 13.57611275], [92.88722229, 13.57541847], [92.88694763, 13.57528114], [92.8861084, 13.57444], [92.88583374, 13.57444382], [92.88555908, 13.5741663], [92.88527679, 13.57417107], [92.88445282, 13.57500076], [92.88445282, 13.57528114], [92.88360596, 13.57611275], [92.88360596, 13.57639122], [92.8833313, 13.57666683], [92.8833313, 13.5769453], [92.88305664, 13.57721996], [92.88305664, 13.5775013], [92.88277435, 13.57777882], [92.88276672, 13.57833004], [92.88249969, 13.57861137], [92.88249969, 13.57944489], [92.88222504, 13.57972336], [92.88223267, 13.58083057], [92.88194275, 13.58111095], [92.88194275, 13.58139133], [92.88166809, 13.58166695], [92.88168335, 13.58222103], [92.8813858, 13.58250141], [92.8813858, 13.58277702], [92.88146973, 13.58285713], [92.88168335, 13.58306026], [92.88194275, 13.58306026], [92.88249969, 13.58209133], [92.88305664, 13.58250141], [92.88361359, 13.58305454], [92.88361359, 13.58333302], [92.88388824, 13.58361053], [92.88388824, 13.58500099], [92.8841629, 13.58527946], [92.8841629, 13.58555508], [92.88445282, 13.58583069], [92.88445282, 13.58638859], [92.88471985, 13.58667183], [92.88500214, 13.58681107], [92.88555908, 13.58778191], [92.88555908, 13.58805466], [92.88582611, 13.58833122], [92.88582611, 13.5886116], [92.88639069, 13.58916759], [92.88639069, 13.58972359], [92.88666534, 13.59000015], [92.88667297, 13.59221935], [92.88639069, 13.59249973], [92.88639069, 13.59277821], [92.88804626, 13.59444237], [92.88805389, 13.59527779], [92.88944244, 13.59666634], [92.88972473, 13.59666634], [92.89027405, 13.59722233], [92.89054871, 13.59722042], [92.89138794, 13.59806061], [92.89167023, 13.59806061], [92.89250183, 13.5988903], [92.89277649, 13.5988903], [92.89444733, 13.60056114], [92.89472198, 13.60055637], [92.89527893, 13.60111046], [92.89554596, 13.60111046], [92.89583588, 13.60139275], [92.89639282, 13.60139275], [92.89668274, 13.60167122], [92.89694214, 13.60167122]]], [[[93.00785828, 13.5553627], [93.00758362, 13.55529499], [93.00723267, 13.55529976], [93.00681305, 13.55522919], [93.0063858, 13.55522728], [93.00631714, 13.55543232], [93.00610352, 13.5558424], [93.00604248, 13.55611134], [93.00583649, 13.55666733], [93.0055542, 13.55694485], [93.0055542, 13.55749893], [93.00541687, 13.55797958], [93.00541687, 13.55825806], [93.00520325, 13.55860043], [93.00554657, 13.55895138], [93.00583649, 13.55895138], [93.00597382, 13.55942726], [93.00604248, 13.55970287], [93.00618744, 13.55997562], [93.0064621, 13.55997562], [93.00660706, 13.55956554], [93.00681305, 13.55936146], [93.00681305, 13.5583992], [93.00715637, 13.55785179], [93.00730896, 13.55743122], [93.00737762, 13.55722809], [93.00749969, 13.55666924], [93.00778198, 13.55639076], [93.00778198, 13.55583096], [93.00785828, 13.5553627]]], [[[93.00673676, 12.9968996], [93.00673676, 12.99614143], [93.00645447, 12.99586773], [93.00652313, 12.99524975], [93.00589752, 12.99532127], [93.00589752, 12.99435043], [93.00526428, 12.99359512], [93.00491333, 12.99359512], [93.00414276, 12.99297523], [93.00414276, 12.99276829], [93.00393677, 12.99248981], [93.00393677, 12.99221611], [93.00337982, 12.99160099], [93.0032959, 12.99110889], [93.00309753, 12.99110889], [93.00287628, 12.99139118], [93.00267029, 12.99117947], [93.00274658, 12.99097729], [93.00197601, 12.99029064], [93.00163269, 12.99022007], [93.0015564, 12.99008083], [93.00108337, 12.99001026], [93.00106812, 12.98953247], [93.00084686, 12.98953247], [93.00084686, 12.98912144], [93.00071716, 12.98891163], [93.00042725, 12.98864269], [93.0, 12.98889065], [92.9991684, 12.9880619], [92.9988327, 12.98777199], [92.99804688, 12.98695755], [92.9972229, 12.98698139], [92.99726105, 12.98663044], [92.99666595, 12.98668957], [92.99637604, 12.98606968], [92.99421692, 12.98614025], [92.99414825, 12.98582077], [92.99279022, 12.9857893], [92.99253082, 12.98550034], [92.99254608, 12.98502064], [92.99221802, 12.98502064], [92.99223328, 12.98389053], [92.99199677, 12.98389053], [92.99195862, 12.98335075], [92.99172211, 12.98335075], [92.99167633, 12.9822607], [92.9910965, 12.98195076], [92.99112701, 12.98057175], [92.99056244, 12.98055172], [92.9905777, 12.97969913], [92.98999786, 12.97945976], [92.99002075, 12.97891998], [92.98922729, 12.97888088], [92.98917389, 12.97835732], [92.98887634, 12.9783411], [92.98887634, 12.97752094], [92.98863983, 12.97723103], [92.98805237, 12.97723103], [92.98781586, 12.97694206], [92.9878006, 12.97557354], [92.98720551, 12.97556496], [92.98720551, 12.97500229], [92.98673248, 12.97498226], [92.98673248, 12.97445679], [92.98532104, 12.9733696], [92.98532104, 12.97252178], [92.98474884, 12.97254086], [92.98472595, 12.97192097], [92.98417664, 12.97193432], [92.98419189, 12.97168446], [92.98334503, 12.97168446], [92.98336792, 12.97112083], [92.98277283, 12.97056007], [92.98221588, 12.97056007], [92.98221588, 12.9694109], [92.98194885, 12.9694109], [92.98194885, 12.96892834], [92.98087311, 12.96887112], [92.98084259, 12.96832657], [92.98060608, 12.96834946], [92.98056793, 12.9677496], [92.98055267, 12.96754932], [92.98001862, 12.9675312], [92.97999573, 12.96694469], [92.97946167, 12.96697044], [92.97944641, 12.96615028], [92.97975922, 12.9661293], [92.97979736, 12.9655304], [92.97944641, 12.9655714], [92.97943115, 12.96416855], [92.97970581, 12.96418953], [92.97969055, 12.96248055], [92.98000336, 12.96248055], [92.98002625, 12.96143436], [92.97976685, 12.96143436], [92.97973633, 12.96048641], [92.9797287, 12.96024895], [92.98108673, 12.95914173], [92.98107147, 12.95862007], [92.98165894, 12.95866108], [92.98170471, 12.95836926], [92.98221588, 12.95837116], [92.98223114, 12.95804119], [92.98282623, 12.95804119], [92.98280334, 12.957551], [92.98310089, 12.95722485], [92.98416901, 12.95722294], [92.98421478, 12.95697594], [92.98596954, 12.95710182], [92.98652649, 12.95681], [92.98776245, 12.95675087], [92.98789215, 12.95580673], [92.98812103, 12.95555019], [92.98803711, 12.95393085], [92.98731995, 12.95362186], [92.98677826, 12.95339108], [92.98586273, 12.95221996], [92.98526001, 12.95224285], [92.9850235, 12.95164108], [92.98445129, 12.95166111], [92.98445129, 12.95139027], [92.98335266, 12.95139027], [92.98335266, 12.9511404], [92.98284149, 12.95116043], [92.98265839, 12.95082283], [92.98252106, 12.95057392], [92.98167419, 12.95057392], [92.98169708, 12.94999313], [92.98086548, 12.94999313], [92.98082733, 12.94943047], [92.98060608, 12.94947147], [92.98056793, 12.9485817], [92.98029327, 12.9485817], [92.98026276, 12.94806957], [92.98001862, 12.94807243], [92.98000336, 12.94639015], [92.98001099, 12.94530964], [92.98034668, 12.94530964], [92.98033142, 12.94451046], [92.98003387, 12.94447327], [92.97999573, 12.94224167], [92.98062897, 12.94169712], [92.98114014, 12.94166088], [92.98110199, 12.94086075], [92.98141479, 12.94088268], [92.98141479, 12.94029999], [92.98168945, 12.94026089], [92.98168945, 12.93917561], [92.98249817, 12.93865204], [92.98249817, 12.93808937], [92.98280334, 12.93807125], [92.98282623, 12.93448067], [92.98165131, 12.93334198], [92.98060608, 12.93335533], [92.98060608, 12.93310165], [92.98001099, 12.93306446], [92.98001099, 12.93275356], [92.97918701, 12.93277168], [92.97912598, 12.93335342], [92.97749329, 12.93330097], [92.97749329, 12.93417072], [92.97618866, 12.93416882], [92.97605133, 12.93506336], [92.97556305, 12.93504238], [92.9755249, 12.93533421], [92.97392273, 12.93529034], [92.97392273, 12.93583965], [92.97364807, 12.93583679], [92.97360992, 12.93725491], [92.97336578, 12.93725014], [92.9733429, 12.93777943], [92.97141266, 12.93780041], [92.97115326, 12.93806171], [92.97113037, 12.93867016], [92.97226715, 12.93975067], [92.97306061, 12.93972969], [92.97306061, 12.94029331], [92.97254181, 12.94031143], [92.9724884, 12.94083977], [92.97167206, 12.94083977], [92.97171783, 12.94167042], [92.97226715, 12.94198036], [92.97225189, 12.94309044], [92.97171783, 12.94309044], [92.97138977, 12.94363022], [92.97055817, 12.94359112], [92.97058105, 12.94386196], [92.96949768, 12.94386196], [92.96949768, 12.94446373], [92.96805573, 12.94444561], [92.96805573, 12.94388962], [92.96724701, 12.94388103], [92.96723175, 12.94360924], [92.96528625, 12.94363022], [92.96528625, 12.94332886], [92.96308899, 12.9433403], [92.96308899, 12.94307137], [92.96250153, 12.94308472], [92.96245575, 12.94275475], [92.95804596, 12.94281387], [92.9569397, 12.9416666], [92.95696259, 12.94114971], [92.95641327, 12.94112968], [92.95614624, 12.94083118], [92.95606995, 12.94027042], [92.95420074, 12.9402914], [92.95420074, 12.93999863], [92.95333099, 12.94000053], [92.95333099, 12.94028187], [92.95256042, 12.94026566], [92.9524765, 12.9405756], [92.95195007, 12.94053936], [92.95198822, 12.94112015], [92.95226288, 12.94141006], [92.95249939, 12.94139194], [92.95474243, 12.94143963], [92.95478058, 12.94196129], [92.95500183, 12.94193554], [92.95502472, 12.94261265], [92.95503998, 12.94306183], [92.95556641, 12.94302082], [92.95558929, 12.94391918], [92.95527649, 12.94387817], [92.95533752, 12.94473076], [92.95582581, 12.94470978], [92.95578766, 12.94525528], [92.9561615, 12.94527054], [92.95614624, 12.94642162], [92.95670319, 12.94640064], [92.95729065, 12.94696236], [92.95720673, 12.94754505], [92.95780182, 12.94751072], [92.95781708, 12.94780064], [92.95837402, 12.94781685], [92.959198, 12.94888306], [92.95973206, 12.94894028], [92.95999908, 12.94917011], [92.96003723, 12.94945145], [92.96057129, 12.94948864], [92.96057129, 12.94916058], [92.9625473, 12.94916058], [92.96251678, 12.9486208], [92.96308136, 12.9486351], [92.96308136, 12.9483614], [92.96363068, 12.9483614], [92.96421814, 12.94749069], [92.96586609, 12.94751072], [92.96586609, 12.94721889], [92.96753693, 12.94725609], [92.96785736, 12.94671345], [92.96832275, 12.94671059], [92.96832275, 12.94640064], [92.96918488, 12.94642162], [92.96948242, 12.94585896], [92.9703064, 12.94586086], [92.97032928, 12.94559002], [92.97086334, 12.94561005], [92.971138, 12.94532967], [92.971138, 12.94473267], [92.97143555, 12.94471455], [92.97145081, 12.94418812], [92.97254181, 12.94418812], [92.97254181, 12.94473267], [92.97303009, 12.94473267], [92.97306824, 12.9450407], [92.97389984, 12.94508171], [92.97392273, 12.94532108], [92.97424316, 12.94532967], [92.97415161, 12.94668579], [92.97306824, 12.94781017], [92.97312927, 12.94861031], [92.9733963, 12.94865131], [92.97338867, 12.94919109], [92.97306824, 12.94920921], [92.97309113, 12.94975185], [92.97278595, 12.94971085], [92.97278595, 12.95053101], [92.97305298, 12.95053101], [92.97306824, 12.95111179], [92.97249603, 12.95141983], [92.97251892, 12.9522562], [92.97281647, 12.95226955], [92.97284698, 12.95476055], [92.9723053, 12.95473766], [92.97193146, 12.95528316], [92.971138, 12.95528316], [92.971138, 12.95501041], [92.97058868, 12.95501041], [92.9705658, 12.95471954], [92.96891022, 12.95470047], [92.96891022, 12.95448971], [92.96695709, 12.95445061], [92.96697998, 12.95420265], [92.96556091, 12.95420265], [92.96559906, 12.95448971], [92.96443939, 12.95445061], [92.96444702, 12.95471954], [92.96170044, 12.95468998], [92.96170044, 12.95504093], [92.96112823, 12.95503712], [92.96110535, 12.95554066], [92.96059418, 12.95556068], [92.96061707, 12.95532894], [92.9597702, 12.95528984], [92.95917511, 12.95614243], [92.95862579, 12.95616341], [92.95861816, 12.9563179], [92.95858765, 12.95670986], [92.95786285, 12.95667076], [92.95778656, 12.95695972], [92.95724487, 12.95695782], [92.95635986, 12.95808411], [92.95582581, 12.95804119], [92.95584869, 12.95946121], [92.95531464, 12.95948124], [92.95471954, 12.960042], [92.95474243, 12.96169186], [92.95419312, 12.9619627], [92.95417023, 12.96365166], [92.95391083, 12.96363068], [92.95391083, 12.96418095], [92.95417786, 12.96415997], [92.95417786, 12.96503067], [92.95389557, 12.96498966], [92.95389557, 12.96555328], [92.95423126, 12.96559238], [92.95422363, 12.96572781], [92.95420837, 12.96614075], [92.95443726, 12.96611118], [92.95445251, 12.96665955], [92.95388031, 12.96698856], [92.95388031, 12.9674921], [92.95446777, 12.96811199], [92.95474243, 12.96805477], [92.95472717, 12.96691132], [92.95529938, 12.96695042], [92.95529938, 12.96673965], [92.95584869, 12.96673965], [92.95584869, 12.96695042], [92.95667267, 12.96695042], [92.95670319, 12.96642971], [92.95719147, 12.9661293], [92.95724487, 12.96555328], [92.95754242, 12.96529961], [92.95803833, 12.96531963], [92.95804596, 12.96469975], [92.95889282, 12.96467972], [92.95892334, 12.96500969], [92.96060181, 12.96500969], [92.96055603, 12.96529961], [92.96111298, 12.96527672], [92.96112061, 12.96599293], [92.96112823, 12.96694469], [92.96170044, 12.96694088], [92.96168518, 12.96752739], [92.96167755, 12.96782112], [92.96227264, 12.96778202], [92.96222687, 12.96805096], [92.96278381, 12.9680891], [92.96311951, 12.96833992], [92.96309662, 12.96972084], [92.96250916, 12.97004986], [92.96250916, 12.9705534], [92.96217346, 12.97088432], [92.96063232, 12.97082424], [92.96059418, 12.97113705], [92.96002197, 12.97111607], [92.96004486, 12.97249508], [92.96059418, 12.9725132], [92.96057129, 12.97445297], [92.95974731, 12.97447109], [92.95974731, 12.97473145], [92.95921326, 12.97471046], [92.9588623, 12.97531033], [92.95833588, 12.97528934], [92.95831299, 12.97558117], [92.95726013, 12.97552204], [92.95722198, 12.97610283], [92.95643616, 12.97610283], [92.95641327, 12.97639465], [92.95505524, 12.97639465], [92.95503235, 12.97610283], [92.95475769, 12.97608471], [92.95475769, 12.97695065], [92.95446777, 12.97698021], [92.95446777, 12.97754955], [92.95420837, 12.97752094], [92.95420837, 12.97859192], [92.95388794, 12.97888088], [92.95337677, 12.97889709], [92.95252991, 12.97971344], [92.95251465, 12.98031235], [92.95333862, 12.9803009], [92.95363617, 12.98059082], [92.95365906, 12.9811306], [92.95397186, 12.98139954], [92.95475769, 12.98136139], [92.95469666, 12.98227024], [92.95503235, 12.98250961], [92.95558929, 12.98250008], [92.95558929, 12.98280144], [92.95609283, 12.98281956], [92.95613861, 12.98250961], [92.95668793, 12.98250961], [92.95697021, 12.98307037], [92.95783234, 12.98310661], [92.95780182, 12.98363304], [92.95806122, 12.98365116], [92.95807648, 12.9841938], [92.95833588, 12.98419189], [92.95833588, 12.98476124], [92.95867157, 12.98476124], [92.95864868, 12.98612022], [92.95922089, 12.9864502], [92.95918274, 12.98808193], [92.95974731, 12.98835087], [92.95974731, 12.98891163], [92.96032715, 12.98889065], [92.96034241, 12.98949337], [92.96060181, 12.98974419], [92.96113586, 12.98974419], [92.96195984, 12.98887062], [92.96198273, 12.98830986], [92.96279144, 12.98830986], [92.96282959, 12.9872179], [92.96331787, 12.98696995], [92.96337891, 12.98639107], [92.96363831, 12.98639107], [92.96363831, 12.98585129], [92.96448517, 12.98586369], [92.96446228, 12.98559093], [92.96503448, 12.98555183], [92.96502686, 12.98501015], [92.96553802, 12.98501015], [92.96640778, 12.9839201], [92.96694946, 12.98388386], [92.96696472, 12.98338032], [92.96730042, 12.98305035], [92.9686203, 12.98307037], [92.96864319, 12.98252964], [92.96917725, 12.98252964], [92.96917725, 12.98084068], [92.96808624, 12.98084068], [92.96807098, 12.98055172], [92.96721649, 12.98055172], [92.96723938, 12.97999954], [92.96694946, 12.97973442], [92.96588135, 12.97973442], [92.96586609, 12.97944164], [92.96530914, 12.97944164], [92.96530914, 12.97918892], [92.96450043, 12.97914791], [92.96446228, 12.97779179], [92.96502686, 12.97749996], [92.96501923, 12.9769392], [92.96560669, 12.97695827], [92.96615601, 12.97610283], [92.96747589, 12.97614384], [92.9680481, 12.97556019], [92.96808624, 12.97502041], [92.96865845, 12.97500038], [92.96946716, 12.97416115], [92.96946716, 12.97363853], [92.96864319, 12.97303963], [92.96865845, 12.97224045], [92.96894073, 12.97224236], [92.96889496, 12.97140789], [92.96942902, 12.97113037], [92.9694519, 12.97059441], [92.96974945, 12.9703207], [92.97031403, 12.9703207], [92.97029877, 12.97001076], [92.97083282, 12.97001076], [92.97145844, 12.96915627], [92.97220612, 12.96914005], [92.97220612, 12.96947098], [92.97277832, 12.96944141], [92.97305298, 12.96972084], [92.97305298, 12.96999931], [92.97360992, 12.97055626], [92.97360992, 12.97083378], [92.97362518, 12.97104836], [92.97364807, 12.97141171], [92.97422028, 12.97140789], [92.97418213, 12.97224236], [92.97475433, 12.972785], [92.97527313, 12.97282124], [92.97528839, 12.97362137], [92.97555542, 12.97361183], [92.97638702, 12.97444439], [92.97637177, 12.9747448], [92.97695923, 12.9747448], [92.97695923, 12.97447109], [92.97808838, 12.97443008], [92.97805023, 12.97476101], [92.9786377, 12.97476101], [92.97862244, 12.97448921], [92.97918701, 12.97445965], [92.97917938, 12.97472191], [92.97945404, 12.97471714], [92.97945404, 12.97555065], [92.97975159, 12.97555065], [92.97975159, 12.97611427], [92.9800415, 12.97612953], [92.98001862, 12.97634506], [92.9799881, 12.97669983], [92.97975159, 12.97667694], [92.97978973, 12.97804928], [92.97917938, 12.97836399], [92.97917938, 12.979743], [92.98033905, 12.979743], [92.98032379, 12.98005295], [92.98110962, 12.98005009], [92.98197937, 12.98116016], [92.98282623, 12.98112202], [92.98282623, 12.98085022], [92.98390961, 12.98083019], [92.98475647, 12.98195267], [92.98500824, 12.98195076], [92.98503113, 12.98252106], [92.9855423, 12.98278999], [92.98558044, 12.98335075], [92.98470306, 12.98358059], [92.98503113, 12.98447609], [92.98551941, 12.9847002], [92.98583984, 12.98500061], [92.98613739, 12.98500061], [92.98647308, 12.98446274], [92.98891449, 12.98445606], [92.98887634, 12.98558235], [92.98861694, 12.98558235], [92.9885788, 12.98650265], [92.98808289, 12.98666859], [92.98804474, 12.98692226], [92.98753357, 12.98696136], [92.98749542, 12.98750305], [92.98723602, 12.98750305], [92.98722076, 12.98833275], [92.98670197, 12.98863125], [92.98667908, 12.98913479], [92.98639679, 12.98917103], [92.98638153, 12.9897213], [92.98667908, 12.98974133], [92.98670197, 12.9902401], [92.98612976, 12.9903183], [92.98612976, 12.9905529], [92.98555756, 12.9905529], [92.9852829, 12.99083996], [92.98529816, 12.9925127], [92.98545074, 12.99274731], [92.98560333, 12.9930706], [92.98578644, 12.99325562], [92.98587799, 12.99335098], [92.98693848, 12.99333096], [92.98726654, 12.99282265], [92.98890686, 12.99278164], [92.98886871, 12.99253082], [92.9905777, 12.9925127], [92.99115753, 12.9916811], [92.99169159, 12.99166012], [92.99170685, 12.99142075], [92.99221802, 12.99138546], [92.99252319, 12.99088097], [92.993927, 12.99083996], [92.99446869, 12.99169922], [92.9952774, 12.991642], [92.9952774, 12.9921999], [92.9956131, 12.99253082], [92.99666595, 12.99248981], [92.99804688, 12.99389172], [93.0, 12.99388885], [93.00063324, 12.99437046], [93.00110626, 12.99444103], [93.00108337, 12.99455929], [93.00108337, 12.99518204], [93.0015564, 12.99565983], [93.0013504, 12.99601078], [93.0016861, 12.99635124], [93.00203705, 12.99606991], [93.00283051, 12.99648952], [93.00302887, 12.9968996], [93.00344849, 12.9968996], [93.00364685, 12.99676991], [93.00364685, 12.99627972], [93.00400543, 12.99641895], [93.00400543, 12.99669266], [93.00456238, 12.9966898], [93.00533295, 12.99752045], [93.00723267, 12.99752045], [93.00722504, 12.9968996], [93.00673676, 12.9968996]]], [[[92.89277649, 12.93722057], [92.8928299, 12.93642139], [92.89170074, 12.9364233], [92.89141083, 12.93560982], [92.89061737, 12.93557072], [92.89060211, 12.93531132], [92.89006805, 12.9353199], [92.89006805, 12.93502808], [92.88949585, 12.93504715], [92.88947296, 12.93642139], [92.89002991, 12.9367218], [92.89002991, 12.9372406], [92.89060211, 12.9372406], [92.89061737, 12.93753147], [92.89141083, 12.93753147], [92.89141083, 12.93725967], [92.89277649, 12.93722057]]], [[[92.90142822, 12.94114971], [92.90168762, 12.94083977], [92.90225983, 12.94089031], [92.90228271, 12.9402914], [92.90255737, 12.94031143], [92.90255737, 12.93975067], [92.90280914, 12.9397707], [92.90283966, 12.9391098], [92.90284729, 12.93889141], [92.90312195, 12.93891239], [92.90306854, 12.93834877], [92.90280914, 12.93834877], [92.90252686, 12.93887138], [92.90200043, 12.93895054], [92.90145111, 12.93951416], [92.90145111, 12.94055462], [92.90058136, 12.94056225], [92.9005661, 12.94087219], [92.89975739, 12.94085407], [92.89978027, 12.94111061], [92.90033722, 12.94167042], [92.90145111, 12.94167042], [92.90142822, 12.94114971]]], [[[92.75959778, 12.87759018], [92.76010132, 12.8775692], [92.76004028, 12.87781143], [92.76032257, 12.87779045], [92.76042938, 12.87724972], [92.76006317, 12.87694931], [92.75895691, 12.87699032], [92.75894928, 12.8764286], [92.75871277, 12.87613106], [92.75705719, 12.87613106], [92.75705719, 12.87808037], [92.75699615, 12.87843132], [92.75757599, 12.87839031], [92.75757599, 12.8781004], [92.75843811, 12.87807274], [92.75847626, 12.87786961], [92.75959778, 12.87783146], [92.75959778, 12.87759018]]], [[[92.78555298, 12.89333439], [92.78583527, 12.89305592], [92.78639221, 12.89305973], [92.78666687, 12.8927803], [92.78716278, 12.89306927], [92.78740692, 12.89319038], [92.78801727, 12.89319038], [92.78820038, 12.89317036], [92.78837585, 12.89308834], [92.78868866, 12.89298534], [92.78896332, 12.89298534], [92.78988647, 12.89265156], [92.79017639, 12.89243126], [92.79087067, 12.89197063], [92.79116058, 12.89176369], [92.79164886, 12.89128876], [92.7917099, 12.89096069], [92.79154968, 12.89052105], [92.79135132, 12.89035988], [92.79116058, 12.8901701], [92.79090881, 12.88996792], [92.79088593, 12.88976002], [92.79078674, 12.88907623], [92.79062653, 12.88849068], [92.79055786, 12.88816929], [92.7905426, 12.88797092], [92.7904892, 12.8876543], [92.79040527, 12.88728046], [92.7903595, 12.88691998], [92.7902832, 12.88556194], [92.79055786, 12.88528156], [92.79055786, 12.8847208], [92.79000092, 12.88416672], [92.79000092, 12.8838892], [92.78916931, 12.88305855], [92.78861237, 12.88305855], [92.78833008, 12.88278103], [92.78749847, 12.88278103], [92.78721619, 12.88250065], [92.78666687, 12.88250065], [92.78639221, 12.88222122], [92.78610992, 12.88222313], [92.78583527, 12.88194466], [92.78555298, 12.88194466], [92.78527832, 12.88222313], [92.78499603, 12.88222122], [92.78472137, 12.88250065], [92.78444672, 12.88250065], [92.7841568, 12.88278103], [92.78388977, 12.88278103], [92.78360748, 12.88305855], [92.78333282, 12.88305473], [92.78193665, 12.88444138], [92.78193665, 12.88500118], [92.78166962, 12.88527679], [92.78166962, 12.88583279], [92.78193665, 12.88611126], [92.78194427, 12.88638878], [92.78250122, 12.88694096], [92.78250122, 12.88861084], [92.78221893, 12.88889027], [92.78221893, 12.8894434], [92.78194427, 12.88972092], [92.78194427, 12.89083385], [92.78166962, 12.89110947], [92.78166962, 12.89138985], [92.78194427, 12.89166641], [92.78193665, 12.89194107], [92.78250122, 12.89250183], [92.78277588, 12.89250183], [92.78333282, 12.89305592], [92.78359985, 12.89311028], [92.78366852, 12.89313793], [92.78395081, 12.89323997], [92.78423309, 12.89325047], [92.78555298, 12.89333439]]], [[[92.89370728, 12.89856434], [92.89380646, 12.8985014], [92.89393616, 12.8985033], [92.89391327, 12.89825439], [92.89389801, 12.89799023], [92.8937912, 12.89776039], [92.8936615, 12.89754963], [92.89353943, 12.89745045], [92.89328766, 12.89741135], [92.89305115, 12.89735031], [92.89276123, 12.89735031], [92.89245605, 12.89732933], [92.89231873, 12.89730167], [92.89206696, 12.89728069], [92.89169312, 12.89740181], [92.89156342, 12.89757347], [92.89151764, 12.89785957], [92.89151764, 12.8983593], [92.89154053, 12.89847088], [92.89162445, 12.89869022], [92.89173126, 12.89879036], [92.89176941, 12.8989563], [92.89176941, 12.89912319], [92.89167023, 12.89938927], [92.89203644, 12.89982891], [92.89227295, 12.89991093], [92.89263153, 12.89986992], [92.89282227, 12.89977932], [92.89292908, 12.89962006], [92.8931427, 12.89960098], [92.89325714, 12.89949036], [92.89330292, 12.89939213], [92.89330292, 12.89926624], [92.89346313, 12.89912128], [92.89363861, 12.89908218], [92.89368439, 12.89897919], [92.89367676, 12.89879036], [92.89370728, 12.89856434]]], [[[92.75508118, 12.91281128], [92.75505829, 12.91225338], [92.75538635, 12.91225338], [92.75540161, 12.91141415], [92.75566864, 12.91139412], [92.75566864, 12.91059589], [92.75591278, 12.91060066], [92.75595093, 12.91002178], [92.75617218, 12.91002178], [92.75617218, 12.90922165], [92.7564621, 12.90922165], [92.75647736, 12.90864086], [92.75727081, 12.90864086], [92.75728607, 12.90784073], [92.7575531, 12.90784073], [92.75759125, 12.90477085], [92.75731659, 12.90477085], [92.75730896, 12.90309143], [92.75704956, 12.90311146], [92.75701904, 12.90004063], [92.75699615, 12.89810181], [92.75669861, 12.89810181], [92.75675201, 12.89447975], [92.75645447, 12.89448261], [92.75645447, 12.8928051], [92.75591278, 12.89253235], [92.75592804, 12.89141273], [92.75512695, 12.89115047], [92.75479126, 12.89089108], [92.75480652, 12.89006996], [92.7545166, 12.88977242], [92.7539978, 12.88975143], [92.75397491, 12.88947296], [92.75341034, 12.88948441], [92.75341034, 12.88920593], [92.75312805, 12.8892107], [92.75311279, 12.8900404], [92.75284576, 12.89002514], [92.75286865, 12.89142418], [92.75231934, 12.89146328], [92.75175476, 12.89056492], [92.75092316, 12.89060307], [92.75090027, 12.89034367], [92.7503891, 12.89032459], [92.75032806, 12.89058304], [92.74982452, 12.89060307], [92.74978638, 12.89112282], [92.74923706, 12.89116192], [92.74923706, 12.89198017], [92.74894714, 12.89200974], [92.74893951, 12.89261055], [92.74840546, 12.8928051], [92.74840546, 12.89337254], [92.74871063, 12.89336109], [92.748703, 12.89504147], [92.74897766, 12.89505672], [92.74895477, 12.89615345], [92.74925995, 12.89619446], [92.7492218, 12.89671421], [92.74980927, 12.89671421], [92.74980927, 12.89701176], [92.75039673, 12.89697361], [92.75037384, 12.89675331], [92.75175476, 12.89669323], [92.75173187, 12.8953352], [92.75202179, 12.89534187], [92.75205994, 12.89422035], [92.75228119, 12.89398098], [92.75285339, 12.89392185], [92.75341797, 12.89339066], [92.75341034, 12.89310074], [92.75341034, 12.89282131], [92.75367737, 12.89282131], [92.75367737, 12.89312172], [92.75396729, 12.89310074], [92.75399017, 12.89364243], [92.75366211, 12.89365959], [92.75370789, 12.89500046], [92.75337982, 12.89501572], [92.7534256, 12.89561462], [92.75312042, 12.89561462], [92.75312805, 12.89587307], [92.75370026, 12.89639187], [92.75422668, 12.89643097], [92.75426483, 12.89695072], [92.75450897, 12.89697075], [92.75454712, 12.89754295], [92.75479889, 12.89754105], [92.75479889, 12.89810181], [92.75534821, 12.8980608], [92.75538635, 12.90087986], [92.75504303, 12.90087986], [92.75508118, 12.90118122], [92.75454712, 12.90116024], [92.75453186, 12.90067005], [92.75422668, 12.90060043], [92.7542572, 12.90034008], [92.75367737, 12.90034008], [92.75367737, 12.90111923], [92.75340271, 12.90114021], [92.75341797, 12.90174198], [92.75366211, 12.90169621], [92.753685, 12.90337276], [92.75396729, 12.90337276], [92.75396729, 12.90476131], [92.75337219, 12.90502071], [92.75341797, 12.90532207], [92.75370026, 12.90534019], [92.75367737, 12.90837193], [92.7542572, 12.9086504], [92.75422668, 12.90891171], [92.75390625, 12.90891171], [92.75401306, 12.9105711], [92.75455475, 12.91085625], [92.75453186, 12.91169453], [92.75396729, 12.91197014], [92.75396729, 12.91310978], [92.75479889, 12.91309166], [92.75508118, 12.91281128]]], [[[92.86476135, 12.91248131], [92.86421204, 12.91248131], [92.86421204, 12.91276073], [92.86307526, 12.91364765], [92.86309814, 12.9144249], [92.86420441, 12.9144249], [92.86476135, 12.91414738], [92.86503601, 12.9138689], [92.86503601, 12.91302967], [92.86476135, 12.91275883], [92.86476135, 12.91248131]]], [[[92.69565582, 12.99195862], [92.69563293, 12.99141598], [92.69618988, 12.99142075], [92.69650269, 12.9910717], [92.69651031, 12.99001026], [92.6967392, 12.989748], [92.6973114, 12.98969078], [92.6973114, 12.98918533], [92.69838715, 12.98920059], [92.69843292, 12.98891163], [92.70011139, 12.98891163], [92.7000885, 12.98834038], [92.70040894, 12.98834419], [92.70038605, 12.98801804], [92.70172119, 12.98805046], [92.70227814, 12.98891163], [92.70318604, 12.98891163], [92.70343781, 12.98857021], [92.70342255, 12.98726177], [92.70452118, 12.98722458], [92.70454407, 12.98752403], [92.70648193, 12.98750496], [92.70643616, 12.98612022], [92.70700073, 12.98612022], [92.70701599, 12.98585129], [92.7081604, 12.98583031], [92.70844269, 12.98609924], [92.7084198, 12.98696136], [92.70900726, 12.98694038], [92.70900726, 12.98668003], [92.7095108, 12.9866581], [92.70954895, 12.98718166], [92.70870972, 12.98777199], [92.70870972, 12.98837185], [92.71037292, 12.98833275], [92.71037292, 12.98810005], [92.71092224, 12.9880476], [92.71103668, 12.98750973], [92.71066284, 12.98749161], [92.71063232, 12.98556995], [92.71118927, 12.9855566], [92.71118927, 12.98473167], [92.71234131, 12.98469067], [92.7122879, 12.98418045], [92.71283722, 12.98414135], [92.71282196, 12.98448086], [92.7145462, 12.98441029], [92.7145462, 12.98301983], [92.71341705, 12.98311138], [92.71341705, 12.98258018], [92.71395874, 12.98252773], [92.71395874, 12.98227024], [92.7145462, 12.98222923], [92.71453094, 12.98255062], [92.71504211, 12.98250961], [92.71508789, 12.98167992], [92.7157135, 12.98110294], [92.71677399, 12.98107433], [92.71677399, 12.98023987], [92.71704865, 12.98024178], [92.71704865, 12.98079967], [92.71788788, 12.98079967], [92.71927643, 12.97941017], [92.71929169, 12.97919083], [92.71872711, 12.97919083], [92.71871948, 12.97865963], [92.71901703, 12.97840023], [92.71988678, 12.97835922], [92.719841, 12.97751808], [92.71927643, 12.97746086], [92.71923828, 12.97613335], [92.72003174, 12.97611427], [92.72041321, 12.97579479], [92.72038269, 12.97528934], [92.72003937, 12.97531033], [92.72006989, 12.97391987], [92.71959686, 12.97360039], [92.71953583, 12.9722147], [92.71929169, 12.9722147], [92.71925354, 12.97142601], [92.71955872, 12.97114563], [92.72009277, 12.97113037], [92.72009277, 12.97058105], [92.71952057, 12.97058296], [92.71925354, 12.97030258], [92.71927643, 12.96972084], [92.71983337, 12.96942043], [92.7197876, 12.96863365], [92.72013092, 12.96863365], [92.72009277, 12.96751118], [92.71980286, 12.96751118], [92.719841, 12.96695042], [92.71959686, 12.96692944], [92.71953583, 12.96614075], [92.71982574, 12.96614075], [92.71982574, 12.96559811], [92.71924591, 12.96562099], [92.71923828, 12.96529961], [92.71980286, 12.96528244], [92.719841, 12.96500969], [92.71925354, 12.96477318], [92.71925354, 12.96415615], [92.71893311, 12.96417427], [92.71894836, 12.96331024], [92.71982574, 12.9627676], [92.71985626, 12.96222115], [92.71931458, 12.96226215], [92.71927643, 12.96166229], [92.71957397, 12.96166229], [92.71957397, 12.96111774], [92.71901703, 12.96111965], [92.71871948, 12.96079159], [92.71872711, 12.95974064], [92.71811676, 12.95974064], [92.71814728, 12.95915985], [92.71843719, 12.95887947], [92.71843719, 12.95835114], [92.71815491, 12.95835304], [92.71813965, 12.95782948], [92.71844482, 12.95788574], [92.71844482, 12.95728397], [92.71813965, 12.95724964], [92.71814728, 12.95667076], [92.71785736, 12.95639992], [92.71788788, 12.95610428], [92.71811676, 12.95610428], [92.71815491, 12.9552784], [92.7175827, 12.95528126], [92.7175827, 12.95499992], [92.71707153, 12.9550209], [92.71704102, 12.95459461], [92.7170105, 12.95417118], [92.71754456, 12.95385647], [92.71761322, 12.95252132], [92.71730042, 12.95254326], [92.71731567, 12.95136261], [92.71704865, 12.95135212], [92.71704865, 12.95079517], [92.71761322, 12.95023918], [92.71760559, 12.94996357], [92.71704865, 12.94940662], [92.71733093, 12.94913197], [92.71733093, 12.94885063], [92.71621704, 12.94774055], [92.71621704, 12.94691181], [92.71598053, 12.94639015], [92.71511078, 12.94581985], [92.71509552, 12.94529819], [92.71482849, 12.9453001], [92.71479797, 12.94473076], [92.71448517, 12.94469643], [92.71457672, 12.94365025], [92.7148819, 12.94363022], [92.71482849, 12.94310093], [92.71452332, 12.94280529], [92.71453857, 12.94225979], [92.71508789, 12.94224167], [92.71511078, 12.94198036], [92.71570587, 12.94196129], [92.71566772, 12.94222355], [92.71617889, 12.94224167], [92.71620178, 12.94254303], [92.7167511, 12.94254303], [92.71676636, 12.94228077], [92.7173233, 12.94224167], [92.71733856, 12.94254303], [92.71785736, 12.94254017], [92.71790314, 12.94307137], [92.71840668, 12.94309044], [92.71842957, 12.94363022], [92.71895599, 12.94394875], [92.71901703, 12.94449139], [92.71926117, 12.94449139], [92.71926117, 12.94535255], [92.71955109, 12.94532108], [92.7195282, 12.94584274], [92.71977997, 12.94586086], [92.71981812, 12.94648075], [92.72011566, 12.94645786], [92.72007751, 12.94698238], [92.72064972, 12.94698238], [92.72064972, 12.94643974], [92.72122192, 12.94645977], [92.72122192, 12.94556046], [92.72146606, 12.94556046], [92.72148895, 12.94498062], [92.72181702, 12.94499969], [92.7217865, 12.94447136], [92.72122192, 12.94390965], [92.72124481, 12.94362831], [92.72145081, 12.94363022], [92.72146606, 12.9430809], [92.72093964, 12.94301891], [92.72088623, 12.94083977], [92.72146606, 12.94086266], [92.72144318, 12.94003963], [92.72177124, 12.94000053], [92.72174835, 12.93897057], [92.72094727, 12.93890095], [92.72093964, 12.93691063], [92.72093964, 12.93580055], [92.7206955, 12.9358511], [92.72065735, 12.93393898], [92.72041321, 12.93390179], [92.72035217, 12.93171024], [92.72064209, 12.93168926], [92.7206192, 12.93114662], [92.72093964, 12.93115234], [92.72097778, 12.92971992], [92.7206192, 12.92976093], [92.7206192, 12.92897034], [92.72088623, 12.92895412], [92.72093964, 12.92811108], [92.7206192, 12.92811108], [92.72064209, 12.92778969], [92.72148895, 12.92784023], [92.72154999, 12.92697239], [92.72097778, 12.92673016], [92.72093964, 12.92530632], [92.72064972, 12.92525959], [92.72061157, 12.92420006], [92.7201004, 12.92420006], [92.7201004, 12.92390156], [92.71956635, 12.92391968], [92.7195282, 12.92362118], [92.71898651, 12.9236393], [92.71894073, 12.9233408], [92.71842194, 12.92339134], [92.71842194, 12.92361927], [92.71756744, 12.92369366], [92.71762848, 12.92333889], [92.71649933, 12.92337513], [92.71646118, 12.92307663], [92.71566772, 12.92308998], [92.71566772, 12.92253017], [92.71640015, 12.92257118], [92.71676636, 12.92198944], [92.71779633, 12.92197132], [92.71871185, 12.92087936], [92.71951294, 12.92086411], [92.71951294, 12.92032146], [92.71982574, 12.92024136], [92.71981049, 12.91754055], [92.72009277, 12.91754055], [92.72009277, 12.916399], [92.71983337, 12.91642094], [92.71981049, 12.91501141], [92.72001648, 12.91501141], [92.72007751, 12.91420555], [92.71981049, 12.91422367], [92.71982574, 12.91334248], [92.72007751, 12.91338062], [92.72009277, 12.91279984], [92.71983337, 12.91281986], [92.71983337, 12.91222095], [92.72009277, 12.91226196], [92.72012329, 12.91141033], [92.71982574, 12.9111681], [92.71981049, 12.91058922], [92.72032166, 12.91031075], [92.72035217, 12.90892124], [92.72064209, 12.90894985], [92.72065735, 12.90723038], [92.72093201, 12.90723038], [92.72094727, 12.90671921], [92.72149658, 12.90616131], [92.72228241, 12.90616131], [92.72232056, 12.90531063], [92.72264862, 12.90533066], [92.72261047, 12.90138054], [92.72232819, 12.90141296], [92.7223053, 12.90034389], [92.72177124, 12.90034389], [92.72171783, 12.89980221], [92.72122192, 12.89976311], [92.72119904, 12.89923859], [92.72171783, 12.89924145], [92.72177124, 12.89860058], [92.72200012, 12.8986311], [92.72200012, 12.8978014], [92.72232819, 12.8978014], [92.72231293, 12.89697075], [92.72180939, 12.89669132], [92.72177124, 12.89587116], [92.72207642, 12.89587116], [92.72203827, 12.89532089], [92.72173309, 12.89532089], [92.72175598, 12.89339066], [92.72149658, 12.89341068], [92.72149658, 12.89281178], [92.72173309, 12.89281178], [92.72174835, 12.89198017], [92.72148132, 12.89196396], [92.72149658, 12.88834476], [92.72094727, 12.88834858], [92.72094727, 12.88673115], [92.72033691, 12.88673306], [92.72045135, 12.88309765], [92.71981812, 12.88307953], [92.71980286, 12.88256931], [92.71952057, 12.88253498], [92.71956635, 12.88171005], [92.71895599, 12.88113976], [92.71818542, 12.88114738], [92.71785736, 12.88062286], [92.71593475, 12.88058662], [92.71534729, 12.88141155], [92.71479797, 12.8814497], [92.7145462, 12.88171005], [92.71450806, 12.88224125], [92.71399689, 12.88253975], [92.71399689, 12.88301754], [92.71343231, 12.8831234], [92.71343231, 12.88331032], [92.71202087, 12.88336658], [92.71205139, 12.88361073], [92.71154785, 12.88364983], [92.7115097, 12.88339043], [92.71012115, 12.88340092], [92.71003723, 12.88364983], [92.70952606, 12.88366795], [92.70948792, 12.88391209], [92.70868683, 12.88391209], [92.70870972, 12.88334942], [92.70955658, 12.88339043], [92.70955658, 12.88309097], [92.71009827, 12.88309097], [92.71008301, 12.88282013], [92.71143341, 12.8828249], [92.71181488, 12.88226223], [92.71232605, 12.88228035], [92.71227264, 12.88112736], [92.71257782, 12.88111973], [92.7125473, 12.87947178], [92.71286011, 12.87947178], [92.71286011, 12.87894058], [92.71316528, 12.87892532], [92.71317291, 12.87755966], [92.71733093, 12.87754154], [92.7173233, 12.87786102], [92.71785736, 12.87786102], [92.71807861, 12.87782192], [92.71895599, 12.8769989], [92.71897125, 12.8758707], [92.71927643, 12.8758297], [92.71929169, 12.87478447], [92.71955872, 12.87478447], [92.71952057, 12.87422085], [92.71898651, 12.87420273], [92.71897125, 12.87335873], [92.71869659, 12.87336159], [92.71869659, 12.87280083], [92.71842194, 12.87282181], [92.71843719, 12.8719902], [92.71790314, 12.87169075], [92.71785736, 12.87117195], [92.71729279, 12.87115097], [92.7173233, 12.87061977], [92.71704865, 12.87060356], [92.71702576, 12.87005901], [92.71647644, 12.8695097], [92.71591949, 12.86948013], [92.71591949, 12.86753178], [92.71563721, 12.8675499], [92.71569061, 12.86670017], [92.71510315, 12.86670208], [92.71510315, 12.86612129], [92.71483612, 12.86614132], [92.71479797, 12.86502934], [92.71451569, 12.8650341], [92.71453094, 12.86280346], [92.71395874, 12.86282063], [92.7137146, 12.862463], [92.71372986, 12.86170197], [92.71340179, 12.86172009], [92.71341705, 12.86115932], [92.71259308, 12.86058044], [92.71259308, 12.86003113], [92.71228027, 12.85976887], [92.71173859, 12.8597393], [92.7117691, 12.85950661], [92.71121216, 12.85951138], [92.7111969, 12.85889244], [92.71038055, 12.85885143], [92.71038055, 12.85811234], [92.71009827, 12.85779285], [92.70925903, 12.8578701], [92.708992, 12.85755062], [92.708992, 12.85616112], [92.70868683, 12.85616112], [92.70844269, 12.85586262], [92.70844269, 12.85531807], [92.70732117, 12.85531998], [92.70732117, 12.85449123], [92.70703125, 12.85419369], [92.70619202, 12.85421944], [92.70590973, 12.853652], [92.7053833, 12.8536911], [92.70482635, 12.85281086], [92.70343781, 12.85284519], [92.70343781, 12.85228157], [92.70313263, 12.85228157], [92.70314026, 12.85189533], [92.70314789, 12.85170078], [92.70285797, 12.8517189], [92.70288086, 12.8511219], [92.70259857, 12.85087967], [92.70263672, 12.84838009], [92.70230865, 12.84838486], [92.70230865, 12.84782219], [92.70288086, 12.84727669], [92.70339966, 12.84729958], [92.70343781, 12.8467207], [92.70372009, 12.84669971], [92.70375824, 12.845891], [92.70340729, 12.845891], [92.70343781, 12.8448019], [92.70314789, 12.84480381], [92.70314789, 12.8442049], [92.70257568, 12.8442049], [92.70256042, 12.84337997], [92.70230865, 12.84338188], [92.70230865, 12.84286022], [92.70173645, 12.84255028], [92.70178223, 12.84200954], [92.70123291, 12.84171104], [92.70122528, 12.84120464], [92.70037079, 12.84116745], [92.70040131, 12.84032059], [92.6995697, 12.84034157], [92.6995697, 12.83974171], [92.69898224, 12.83976269], [92.69896698, 12.83963108], [92.69895935, 12.83949757], [92.69841003, 12.8394804], [92.69844818, 12.83922005], [92.6975708, 12.83924103], [92.69676971, 12.83810997], [92.69623566, 12.83809376], [92.69623566, 12.8377943], [92.69454193, 12.83781242], [92.69456482, 12.83753109], [92.69393158, 12.83753109], [92.69393158, 12.83698654], [92.69429779, 12.83701038], [92.69425964, 12.83643055], [92.69400787, 12.83615017], [92.69345856, 12.83614254], [92.69343567, 12.83558273], [92.69315338, 12.83531761], [92.69204712, 12.83532143], [92.69204712, 12.83502197], [92.69036865, 12.83504009], [92.69037628, 12.83552074], [92.68982697, 12.83552074], [92.68982697, 12.83449078], [92.68871307, 12.8345089], [92.68868256, 12.83476925], [92.68735504, 12.83478737], [92.68702698, 12.83531189], [92.68596649, 12.83533001], [92.6859436, 12.83557415], [92.68539429, 12.8356123], [92.6853714, 12.83589268], [92.68479919, 12.83589268], [92.68482208, 12.83559418], [92.68373871, 12.8356123], [92.6834259, 12.83586121], [92.6834259, 12.83642197], [92.68287659, 12.83644199], [92.68257141, 12.83668137], [92.6825943, 12.83728123], [92.68228912, 12.83751965], [92.68177795, 12.83756065], [92.6817627, 12.83782101], [92.68122101, 12.83786201], [92.68120575, 12.83810425], [92.68016052, 12.83808994], [92.68013763, 12.83837032], [92.67926788, 12.83840179], [92.67926788, 12.83810139], [92.67874908, 12.83810139], [92.67871094, 12.83787823], [92.67791748, 12.83784103], [92.6776123, 12.83730125], [92.67713165, 12.83730125], [92.67713165, 12.8370409], [92.67620087, 12.83702087], [92.67623138, 12.8359108], [92.67539978, 12.83588791], [92.67538452, 12.83534622], [92.6765213, 12.83421993], [92.67730713, 12.8341856], [92.67732239, 12.83365917], [92.67758942, 12.83364105], [92.67758942, 12.83313274], [92.67787933, 12.83313465], [92.67791748, 12.83148479], [92.67758942, 12.83143044], [92.6776123, 12.83094025], [92.6765213, 12.83088589], [92.67648315, 12.83034134], [92.6770401, 12.83006001], [92.67707825, 12.82920074], [92.67736053, 12.82924175], [92.67735291, 12.82866955], [92.67701721, 12.82865429], [92.6770401, 12.82782936], [92.67739868, 12.82785034], [92.67732239, 12.82734108], [92.6770401, 12.82707882], [92.67701721, 12.825881], [92.67675018, 12.825881], [92.67677307, 12.8251009], [92.67627716, 12.82476139], [92.67624664, 12.82423019], [92.67597198, 12.82426929], [92.67597198, 12.82341003], [92.67650604, 12.82338715], [92.67648315, 12.82421207], [92.6770401, 12.82479286], [92.67785645, 12.82479095], [92.67784119, 12.82505989], [92.67897797, 12.82505989], [92.67897797, 12.82533646], [92.67951202, 12.82536983], [92.6798172, 12.82566166], [92.67983246, 12.82676029], [92.680336, 12.82671928], [92.68062592, 12.82726192], [92.68118286, 12.82731628], [92.68148804, 12.82756042], [92.68152618, 12.82814121], [92.68202209, 12.82814121], [92.68229675, 12.82842159], [92.68229675, 12.82897091], [92.68308258, 12.82896614], [92.68341064, 12.82949066], [92.68479919, 12.82949066], [92.68565369, 12.82865047], [92.68564606, 12.82811165], [92.68595886, 12.82811165], [92.68596649, 12.82748985], [92.68622589, 12.82730007], [92.68678284, 12.82728004], [92.68725586, 12.82670116], [92.68727112, 12.82616138], [92.6867981, 12.82616138], [92.6867981, 12.82563019], [92.68649292, 12.82569122], [92.68644714, 12.82452202], [92.68595886, 12.82448769], [92.68593597, 12.82395935], [92.68621063, 12.82366276], [92.68673706, 12.82371998], [92.68673706, 12.82199001], [92.68706512, 12.82199478], [92.68704987, 12.82002544], [92.68813324, 12.82005119], [92.68842316, 12.81976128], [92.68843842, 12.81869698], [92.68868256, 12.8186903], [92.68868256, 12.81813145], [92.68897247, 12.81809711], [92.68901062, 12.81672955], [92.68843842, 12.81671238], [92.68843842, 12.81643105], [92.68763733, 12.81647015], [92.68759918, 12.81620121], [92.68786621, 12.81592083], [92.68788147, 12.81530285], [92.68813324, 12.81534195], [92.68817139, 12.81476116], [92.68843079, 12.81474018], [92.68842316, 12.81421089], [92.68791962, 12.81423187], [92.68788147, 12.81395245], [92.68739319, 12.81395245], [92.68734741, 12.81282139], [92.68708038, 12.81280518], [92.68681335, 12.8131237], [92.68624878, 12.81314182], [92.68592072, 12.81284237], [92.6859436, 12.81227875], [92.68344879, 12.81226254], [92.68344879, 12.81033039], [92.68310547, 12.81033039], [92.68312073, 12.80978966], [92.68314362, 12.8092432], [92.68257141, 12.80922508], [92.68258667, 12.80894184], [92.68038177, 12.80894375], [92.68038177, 12.8092432], [92.67914581, 12.80923557], [92.67708588, 12.80922508], [92.67649841, 12.80869961], [92.67648315, 12.80812168], [92.67594147, 12.80812168], [92.67591095, 12.80782318], [92.67536163, 12.8078413], [92.67536163, 12.80728054], [92.67513275, 12.80725956], [92.67508698, 12.80673122], [92.67539978, 12.80673122], [92.67539978, 12.80476379], [92.67514801, 12.80476379], [92.67513275, 12.80427742], [92.67487335, 12.80428123], [92.67484283, 12.80255127], [92.67429352, 12.80230713], [92.674263, 12.80087185], [92.6737442, 12.80090332], [92.67368317, 12.80004025], [92.67314911, 12.79975891], [92.67314911, 12.79920101], [92.67259216, 12.79897118], [92.67263794, 12.79841042], [92.673172, 12.79841042], [92.67314911, 12.79755116], [92.67262268, 12.79755116], [92.67263794, 12.79618073], [92.67234802, 12.79618073], [92.67233276, 12.79505062], [92.67204285, 12.79505539], [92.67204285, 12.79430485], [92.67206573, 12.79419136], [92.67177582, 12.79415512], [92.67177582, 12.79309273], [92.67198944, 12.79311085], [92.67202759, 12.79227924], [92.67177582, 12.79230022], [92.67176056, 12.79172134], [92.67153168, 12.79174137], [92.6714859, 12.79112053], [92.67094421, 12.79117393], [92.67095947, 12.79061794], [92.6706543, 12.79061317], [92.67063904, 12.7889452], [92.67009735, 12.78899956], [92.67015839, 12.78839111], [92.66983795, 12.78838158], [92.66983795, 12.78729534], [92.66957092, 12.78730202], [92.66957092, 12.78532791], [92.66927338, 12.78530979], [92.66929626, 12.78391933], [92.66896057, 12.7839222], [92.66899872, 12.78335857], [92.66867828, 12.78338146], [92.66867828, 12.78253078], [92.66815948, 12.78257179], [92.66789246, 12.78283024], [92.66789246, 12.78336143], [92.66758728, 12.78338146], [92.66761017, 12.78396034], [92.66741943, 12.78400135], [92.66730499, 12.78757477], [92.66757202, 12.78761196], [92.66761017, 12.78893089], [92.66781616, 12.7889061], [92.66791534, 12.79001141], [92.66761017, 12.79001141], [92.66758728, 12.79057407], [92.66731262, 12.79063129], [92.66732788, 12.7911396], [92.66703796, 12.7914381], [92.66649628, 12.79146957], [92.66649628, 12.79172134], [92.66594696, 12.79172134], [92.66591644, 12.79201698], [92.66538239, 12.79203129], [92.66532898, 12.79230022], [92.66452789, 12.79230022], [92.66454315, 12.79254436], [92.66339874, 12.79369545], [92.66288757, 12.79366016], [92.66285706, 12.79396057], [92.66233063, 12.79396057], [92.66227722, 12.79428005], [92.66094208, 12.79423714], [92.66094208, 12.7947607], [92.66176605, 12.7947998], [92.66179657, 12.79508018], [92.66098022, 12.79510117], [92.66065979, 12.79564285], [92.66013336, 12.79561138], [92.66013336, 12.79673004], [92.66094208, 12.79675102], [92.66094208, 12.79619026], [92.66127014, 12.7958889], [92.66174316, 12.79592419], [92.66175842, 12.79578209], [92.66178131, 12.79560661], [92.66313171, 12.79561138], [92.66343689, 12.79591179], [92.66345978, 12.79647064], [92.66374207, 12.79673004], [92.66429138, 12.79671001], [92.66429138, 12.79754162], [92.6645813, 12.79754162], [92.6645813, 12.79810047], [92.66512299, 12.79808044], [92.66509247, 12.79979134], [92.66568756, 12.80008507], [92.66565704, 12.80087185], [92.6659317, 12.80091], [92.6659317, 12.80144119], [92.66622162, 12.80144119], [92.66623688, 12.80314159], [92.66673279, 12.80312061], [92.66677094, 12.8042469], [92.66649628, 12.80426121], [92.66649628, 12.80579662], [92.66649628, 12.80607033], [92.66620636, 12.80615902], [92.66620636, 12.80893326], [92.66565704, 12.80921268], [92.66565704, 12.80983067], [92.66596222, 12.80979443], [92.66590881, 12.81086254], [92.66573334, 12.81086063], [92.66567993, 12.81224918], [92.66426849, 12.81339264], [92.66428375, 12.81401062], [92.66401672, 12.81398964], [92.66397858, 12.81447983], [92.66368866, 12.81478119], [92.66316223, 12.81479931], [92.66230774, 12.81561089], [92.66234589, 12.81618977], [92.66177368, 12.81644726], [92.66172028, 12.81699181], [92.66150665, 12.81697083], [92.66149139, 12.81782246], [92.66122437, 12.81783485], [92.66120148, 12.81843472], [92.66091919, 12.81843472], [92.66093445, 12.8195219], [92.66122437, 12.81954002], [92.66122437, 12.82087135], [92.66150665, 12.82086182], [92.66149139, 12.82170105], [92.66118622, 12.82170105], [92.66123199, 12.8258009], [92.66091156, 12.82588959], [92.66092682, 12.82701588], [92.66064453, 12.827034], [92.66064453, 12.8275404], [92.66010284, 12.8278017], [92.66011047, 12.8289299], [92.65982819, 12.8289299], [92.65982819, 12.82946968], [92.65927124, 12.82983017], [92.65927124, 12.83030033], [92.65872192, 12.83029461], [92.65872192, 12.83063316], [92.65812683, 12.83065128], [92.65814972, 12.83116055], [92.6576004, 12.83116055], [92.6576004, 12.83144188], [92.65648651, 12.8314209], [92.65647888, 12.83172035], [92.65679932, 12.83177662], [92.65676117, 12.83258343], [92.65645599, 12.83253098], [92.65648651, 12.83330059], [92.65625, 12.83337021], [92.65621185, 12.83393002], [92.6556778, 12.833951], [92.65538788, 12.83426952], [92.65533447, 12.83479404], [92.6550827, 12.83477592], [92.65510559, 12.83588123], [92.65480804, 12.83586121], [92.65480804, 12.83640957], [92.65426636, 12.83668995], [92.65426636, 12.83755016], [92.65367889, 12.83782768], [92.65377045, 12.83923244], [92.65345001, 12.83924961], [92.65346527, 12.84003925], [92.65313721, 12.84008026], [92.65319824, 12.84142685], [92.65286255, 12.8414402], [92.65287781, 12.84198856], [92.65259552, 12.84202576], [92.65259552, 12.84309483], [92.65206146, 12.8434124], [92.65202332, 12.84476089], [92.65148926, 12.84502983], [92.6515274, 12.84556961], [92.65118408, 12.84582996], [92.65119934, 12.84671211], [92.65096283, 12.84671021], [92.65097809, 12.84808159], [92.65119934, 12.84807873], [92.65116882, 12.84864044], [92.65091705, 12.84866047], [92.65091705, 12.84976959], [92.65122223, 12.84976959], [92.65119934, 12.85227966], [92.65091705, 12.8522768], [92.6509552, 12.85394573], [92.65065765, 12.85396194], [92.65065765, 12.85447025], [92.65036774, 12.85449123], [92.650383, 12.85523987], [92.65010071, 12.85531139], [92.65011597, 12.85614109], [92.64981079, 12.85617924], [92.64982605, 12.85674], [92.65011597, 12.85674], [92.65013885, 12.85726357], [92.64981079, 12.85726166], [92.64982605, 12.85811043], [92.64956665, 12.85808945], [92.64956665, 12.85948181], [92.64923859, 12.85946083], [92.64926147, 12.86060143], [92.64846039, 12.86058044], [92.64844513, 12.86116219], [92.64816284, 12.86115932], [92.64821625, 12.86171055], [92.6509552, 12.86166763], [92.65120697, 12.86204147], [92.65126801, 12.86364079], [92.65148163, 12.86364079], [92.65151978, 12.8644619], [92.6512146, 12.86449814], [92.65122986, 12.86697102], [92.65122986, 12.86782074], [92.6517868, 12.86782074], [92.65181732, 12.86697102], [92.65205383, 12.866992], [92.65209198, 12.86671066], [92.65290833, 12.86674786], [92.65292358, 12.866992], [92.65401459, 12.86703014], [92.65401459, 12.8672924], [92.65444946, 12.86728096], [92.65645599, 12.86919117], [92.65648651, 12.86973953], [92.65679169, 12.87002087], [92.65733337, 12.87004089], [92.65814209, 12.87089825], [92.65816498, 12.87142467], [92.65843201, 12.87141991], [92.65844727, 12.87198544], [92.65899658, 12.87226105], [92.65901947, 12.87274933], [92.65901947, 12.87283134], [92.65926361, 12.87282753], [92.65932465, 12.87335491], [92.6600647, 12.87337303], [92.6600647, 12.87395382], [92.66035461, 12.87391567], [92.66036987, 12.87532234], [92.66094208, 12.87561131], [92.66094208, 12.8764267], [92.66123199, 12.87650013], [92.66123199, 12.87691021], [92.66317749, 12.87868118], [92.66316223, 12.87914181], [92.66075134, 12.87880421], [92.65894318, 12.87855434], [92.65772247, 12.87895012], [92.62985229, 12.8807869], [92.62988281, 12.88273144], [92.65854645, 12.88077068], [92.65968323, 12.88016987], [92.6607132, 12.88056183], [92.66265869, 12.88080978], [92.66372681, 12.88057995], [92.66454315, 12.88059998], [92.66454315, 12.88169193], [92.6651001, 12.88171005], [92.66512299, 12.88201141], [92.66454315, 12.88201141], [92.66454315, 12.88281059], [92.6651001, 12.88280869], [92.6651001, 12.88365173], [92.66539001, 12.88363171], [92.66536713, 12.88529968], [92.66593933, 12.88531971], [92.66593933, 12.88669014], [92.66645813, 12.88698196], [92.66652679, 12.88836098], [92.66593933, 12.88834], [92.66597748, 12.88864136], [92.66653442, 12.88889885], [92.66657257, 12.89110947], [92.66620636, 12.89119053], [92.66622925, 12.89171124], [92.66591644, 12.89172935], [92.66593933, 12.89339066], [92.66563416, 12.8933773], [92.6656723, 12.89390373], [92.66593933, 12.89420223], [92.66649628, 12.89420223], [92.66674042, 12.89446354], [92.66676331, 12.89508438], [92.66706085, 12.89501095], [92.66706085, 12.89558983], [92.66732788, 12.89555073], [92.66731262, 12.89587116], [92.6676178, 12.89585018], [92.6676178, 12.89640236], [92.66735077, 12.89668179], [92.66680145, 12.89669991], [92.66677094, 12.89801979], [92.66619873, 12.8980608], [92.66619873, 12.8986311], [92.66588593, 12.89863968], [92.6659317, 12.89921188], [92.66623688, 12.89918232], [92.66621399, 12.89976311], [92.6659317, 12.8997612], [92.6659317, 12.9005909], [92.66570282, 12.90061092], [92.66570282, 12.90252113], [92.66620636, 12.90256023], [92.66628265, 12.90340137], [92.66760254, 12.90338039], [92.66762543, 12.90390396], [92.6681366, 12.90392017], [92.66819763, 12.90449047], [92.67009735, 12.9044857], [92.67038727, 12.90480042], [92.67038727, 12.90531063], [92.67064667, 12.90531063], [92.67064667, 12.90585327], [92.67095184, 12.90585136], [92.67095184, 12.90642071], [92.67119598, 12.90639973], [92.67121887, 12.90699959], [92.6709137, 12.90699673], [92.67097473, 12.90754223], [92.67124176, 12.90752125], [92.67121887, 12.90810299], [92.67090607, 12.90808201], [92.67089844, 12.9105711], [92.67063141, 12.91061401], [92.67059326, 12.91186523], [92.670578, 12.91228294], [92.66860962, 12.91145515], [92.63659668, 12.91329002], [92.63687134, 12.91953945], [92.66816711, 12.91862965], [92.67012024, 12.91803741], [92.67006683, 12.91972446], [92.67041016, 12.9197216], [92.67037201, 12.92165661], [92.67067719, 12.92169094], [92.67067719, 12.92307854], [92.67094421, 12.9233799], [92.67204285, 12.92336082], [92.67230988, 12.92669964], [92.67288208, 12.92669964], [92.67345428, 12.92729759], [92.67345428, 12.92838478], [92.67427063, 12.92834568], [92.67425537, 12.92975235], [92.67398834, 12.92972946], [92.67397308, 12.93085098], [92.67370605, 12.93085957], [92.67372131, 12.93139076], [92.67398834, 12.93171883], [92.67401123, 12.9322319], [92.67372131, 12.9322319], [92.67370605, 12.93278122], [92.67427063, 12.93338108], [92.67484283, 12.93338108], [92.67484283, 12.93396187], [92.67568207, 12.93392086], [92.67568207, 12.93418312], [92.6765213, 12.93416023], [92.6765213, 12.93557072], [92.67593384, 12.93558884], [92.67568207, 12.93583107], [92.67565918, 12.93690586], [92.67646027, 12.93694115], [92.67733765, 12.93780708], [92.67731476, 12.93889427], [92.67784882, 12.93891239], [92.67783356, 12.9391737], [92.67730713, 12.93918991], [92.67703247, 12.93944073], [92.67707062, 12.94029999], [92.67761993, 12.94029999], [92.67819214, 12.94112492], [92.67978668, 12.94111061], [92.67980957, 12.94281197], [92.67871094, 12.94281197], [92.67871094, 12.94364071], [92.67926025, 12.94364071], [92.67983246, 12.94421768], [92.67980957, 12.94472408], [92.67926025, 12.9450407], [92.67926788, 12.94552135], [92.6795578, 12.94556046], [92.6795578, 12.94614124], [92.67984772, 12.94611645], [92.67984772, 12.94694138], [92.68013, 12.94696236], [92.68036652, 12.94724178], [92.68039703, 12.94805145], [92.6795578, 12.94806957], [92.67957306, 12.94792843], [92.67958069, 12.94782257], [92.67900848, 12.94782257], [92.67870331, 12.94724178], [92.67787933, 12.94724178], [92.67788696, 12.94802189], [92.67759705, 12.9483614], [92.6767807, 12.9483614], [92.6767807, 12.94889927], [92.67704773, 12.94888115], [92.67706299, 12.94999981], [92.67590332, 12.95003033], [92.67565918, 12.95055199], [92.67376709, 12.95059013], [92.6734314, 12.95003033], [92.67288208, 12.95003033], [92.67289734, 12.94974041], [92.67230225, 12.94974041], [92.67232513, 12.9500227], [92.67154694, 12.95003891], [92.67150879, 12.95059013], [92.67095184, 12.95057201], [92.67093658, 12.94974041], [92.67063141, 12.94974232], [92.67066956, 12.94999981], [92.66954803, 12.95003033], [92.66925812, 12.95053101], [92.66868591, 12.95053101], [92.66871643, 12.95107269], [92.66908264, 12.95130062], [92.66954041, 12.95143127], [92.66967773, 12.95158386], [92.67009735, 12.95167065], [92.67021179, 12.95223141], [92.67034912, 12.95252132], [92.67038727, 12.9536314], [92.66983795, 12.95360565], [92.66983795, 12.95529366], [92.67009735, 12.95527172], [92.67010498, 12.95579624], [92.66925049, 12.95587063], [92.66927338, 12.95611858], [92.66982269, 12.9563818], [92.66982269, 12.95696259], [92.67009735, 12.95695972], [92.67008972, 12.95837116], [92.66953278, 12.95834827], [92.66953278, 12.95919228], [92.66983795, 12.95919228], [92.6697998, 12.96084213], [92.66956329, 12.96084023], [92.66956329, 12.96168137], [92.66982269, 12.96170139], [92.66983795, 12.96249199], [92.67063904, 12.96247101], [92.67098236, 12.96278954], [92.67095947, 12.96335316], [92.67067719, 12.96335125], [92.67066193, 12.96412754], [92.67150879, 12.96415329], [92.67149353, 12.9644537], [92.67316437, 12.96447182], [92.67316437, 12.96501732], [92.67373657, 12.96499729], [92.67372131, 12.96612263], [92.67427063, 12.96610355], [92.67427063, 12.96670055], [92.67484283, 12.96695042], [92.67482758, 12.96802139], [92.67455292, 12.9683609], [92.67398834, 12.9683609], [92.67398834, 12.96867085], [92.67431641, 12.96863556], [92.674263, 12.96944141], [92.67462158, 12.96979046], [92.67485046, 12.97001076], [92.67537689, 12.97001076], [92.67533875, 12.97056007], [92.67623901, 12.97116566], [92.67620087, 12.97165394], [92.67733002, 12.97246075], [92.67733002, 12.97329521], [92.67785645, 12.97331333], [92.67818451, 12.97359371], [92.67814636, 12.97417545], [92.67843628, 12.97416973], [92.6784668, 12.97474003], [92.67897797, 12.97500038], [92.67896271, 12.97587967], [92.67926788, 12.97587967], [92.67958069, 12.97639179], [92.67958069, 12.97695065], [92.67987823, 12.97694778], [92.6798172, 12.97809315], [92.68010712, 12.97809029], [92.68010712, 12.9786396], [92.68092346, 12.97859859], [92.68092346, 12.97942448], [92.68121338, 12.9794302], [92.68122864, 12.98080921], [92.68177795, 12.98139095], [92.68235016, 12.98135376], [92.6823349, 12.98169136], [92.68286133, 12.98165035], [92.68289948, 12.98280144], [92.6831665, 12.98280144], [92.68315125, 12.98363972], [92.68341827, 12.98363972], [92.68341827, 12.98531055], [92.68370056, 12.98531055], [92.68371582, 12.98580074], [92.68427277, 12.98582077], [92.68427277, 12.98691273], [92.68478394, 12.98692703], [92.685112, 12.98726368], [92.68510437, 12.98773956], [92.68566132, 12.98773956], [92.68595123, 12.98751926], [92.68592834, 12.98693085], [92.68704987, 12.98693085], [92.68704987, 12.98830128], [92.68760681, 12.98830128], [92.68788147, 12.9880209], [92.68788147, 12.98773956], [92.68843842, 12.98773956], [92.68840027, 12.98915958], [92.68899536, 12.98945904], [92.68900299, 12.98995972], [92.68900299, 12.99029064], [92.68927765, 12.9902792], [92.68926239, 12.99080563], [92.69065094, 12.99083996], [92.69120789, 12.99163055], [92.69203949, 12.99168968], [92.69203949, 12.99197006], [92.6934433, 12.99191093], [92.6934433, 12.99163055], [92.69454956, 12.99163055], [92.69454956, 12.99218464], [92.69538116, 12.99218464], [92.69565582, 12.99195862]]], [[[92.93531799, 12.91808987], [92.93534088, 12.91779995], [92.93585205, 12.91779995], [92.93638611, 12.91728973], [92.93638611, 12.91671085], [92.93666077, 12.91669273], [92.93669891, 12.91504002], [92.93586731, 12.91448021], [92.93585205, 12.91392136], [92.93559265, 12.91393471], [92.9355545, 12.91335392], [92.93527985, 12.91331291], [92.93527985, 12.9130373], [92.93416595, 12.9130373], [92.93416595, 12.91331291], [92.93391418, 12.91337204], [92.9338913, 12.91556454], [92.93335724, 12.91555977], [92.93335724, 12.91615009], [92.93197632, 12.91613197], [92.9316864, 12.91641903], [92.9316864, 12.91725254], [92.931427, 12.91725063], [92.93141937, 12.91867065], [92.9327774, 12.91868877], [92.9327774, 12.91893959], [92.93336487, 12.91892242], [92.93334961, 12.91866875], [92.93392181, 12.91862965], [92.93422699, 12.91810989], [92.93531799, 12.91808987]]], [[[92.91307831, 12.91728973], [92.91200256, 12.91641045], [92.91200256, 12.91418076], [92.91230011, 12.91418076], [92.91226196, 12.9136591], [92.91143036, 12.91364098], [92.91136932, 12.91339016], [92.9108963, 12.91335106], [92.9108963, 12.91307259], [92.90999603, 12.91306019], [92.9099884, 12.91331005], [92.90947723, 12.91335106], [92.90947723, 12.91364098], [92.90860748, 12.91359997], [92.90865326, 12.91447067], [92.90900421, 12.9144907], [92.90895081, 12.91473866], [92.90947723, 12.91477108], [92.90947723, 12.91504002], [92.91027832, 12.91509724], [92.91059875, 12.91536903], [92.91056061, 12.91583347], [92.91086578, 12.91583061], [92.9108963, 12.91640091], [92.91114807, 12.91646004], [92.91120911, 12.91675186], [92.91142273, 12.91674519], [92.91142273, 12.91749954], [92.91172791, 12.91751957], [92.91311646, 12.91751957], [92.91307831, 12.91728973]]], [[[92.77420044, 12.93113327], [92.77456665, 12.93057346], [92.77560425, 12.93057346], [92.7756424, 12.92863846], [92.77591705, 12.92860985], [92.77590179, 12.92612076], [92.77560425, 12.92610073], [92.77561951, 12.92476082], [92.77533722, 12.9247427], [92.77536011, 12.92310619], [92.77507019, 12.92311096], [92.77513123, 12.92253017], [92.7747879, 12.92254066], [92.7747879, 12.92114162], [92.77452087, 12.92115116], [92.77452087, 12.92029381], [92.77425385, 12.92029381], [92.77429962, 12.91947269], [92.77368927, 12.91948509], [92.77368927, 12.91864586], [92.77338409, 12.91864586], [92.77339935, 12.91812611], [92.77308655, 12.91779137], [92.77205658, 12.91784954], [92.77205658, 12.91837025], [92.77178192, 12.91838646], [92.77173615, 12.91892433], [92.77143097, 12.91893959], [92.771492, 12.91944981], [92.77120972, 12.91944408], [92.77119446, 12.92086124], [92.77089691, 12.92086124], [92.77089691, 12.92140102], [92.77059937, 12.92167854], [92.77007294, 12.92166138], [92.77009583, 12.92224026], [92.76976776, 12.92224026], [92.76976776, 12.92278004], [92.76953125, 12.92280102], [92.76951599, 12.92309475], [92.7700882, 12.92331791], [92.7700882, 12.9239397], [92.76980591, 12.92390156], [92.76979828, 12.92532158], [92.77065277, 12.92529202], [92.77065277, 12.9258709], [92.77091217, 12.92585945], [92.77094269, 12.92725182], [92.77062988, 12.92726994], [92.77062988, 12.92778969], [92.77005768, 12.92807007], [92.77008057, 12.92895031], [92.77059174, 12.92889977], [92.77062988, 12.92919064], [92.77121735, 12.9294672], [92.77119446, 12.93056393], [92.77139282, 12.93079376], [92.77146149, 12.93087292], [92.77253723, 12.93087292], [92.77253723, 12.93115234], [92.77420044, 12.93113327]]], [[[92.79498291, 12.9112587], [92.79524994, 12.91084003], [92.79556274, 12.91044331], [92.79592133, 12.91003799], [92.7963028, 12.90962982], [92.79654694, 12.90910053], [92.79669952, 12.90849018], [92.79690552, 12.90790939], [92.79693604, 12.90732956], [92.79693604, 12.90675068], [92.79694366, 12.9062252], [92.79694366, 12.90577126], [92.79695129, 12.90540028], [92.79701996, 12.90510082], [92.79715729, 12.90485859], [92.79722595, 12.90456104], [92.79722595, 12.9042387], [92.7973175, 12.90393639], [92.79747009, 12.90361023], [92.79753876, 12.90319061], [92.79773712, 12.90273094], [92.79780579, 12.90218639], [92.79794312, 12.90165043], [92.79808044, 12.90112782], [92.79833221, 12.90069103], [92.79859924, 12.90028667], [92.79888153, 12.89988041], [92.79916382, 12.89944935], [92.79950714, 12.89901066], [92.79995728, 12.89861012], [92.80027008, 12.89807034], [92.80047607, 12.89752102], [92.80033875, 12.89703655], [92.80001831, 12.89662933], [92.79972076, 12.89621925], [92.79944611, 12.8958292], [92.79924011, 12.89543056], [92.79910278, 12.89496994], [92.79872894, 12.8945713], [92.79825592, 12.89422035], [92.79772949, 12.89391041], [92.79714203, 12.89365101], [92.79650116, 12.89344978], [92.7958374, 12.89326096], [92.79525757, 12.89301014], [92.79476166, 12.89274788], [92.79434204, 12.89250183], [92.79396057, 12.89232635], [92.79360199, 12.89221001], [92.79325867, 12.89211369], [92.79289246, 12.89177036], [92.79250336, 12.89187145], [92.79194641, 12.89221001], [92.79165649, 12.89250183], [92.79138947, 12.89250183], [92.79111481, 12.8927784], [92.79013824, 12.89315414], [92.78946686, 12.89345932], [92.78901672, 12.89360046], [92.78861237, 12.89376545], [92.78831482, 12.89377403], [92.7875824, 12.89381504], [92.7872467, 12.89374447], [92.78702545, 12.89368343], [92.78682709, 12.89369202], [92.78653717, 12.89364243], [92.78639221, 12.89366245], [92.78614807, 12.8937006], [92.78444672, 12.89388847], [92.78360748, 12.89472198], [92.78333282, 12.89509964], [92.7830658, 12.89554691], [92.78285217, 12.89607334], [92.78286743, 12.89666367], [92.78326416, 12.89713097], [92.78385162, 12.89748192], [92.78452301, 12.89772987], [92.78527069, 12.89782429], [92.7858963, 12.89804935], [92.78643799, 12.89829636], [92.78688812, 12.89853001], [92.78720856, 12.89887047], [92.78753662, 12.89918041], [92.78782654, 12.89952183], [92.78808594, 12.89988899], [92.78834534, 12.90023518], [92.78859711, 12.90056992], [92.78878784, 12.90095997], [92.7890625, 12.90128136], [92.78922272, 12.901721], [92.78935242, 12.90213966], [92.78952789, 12.90249062], [92.78962708, 12.90280819], [92.78948975, 12.90310001], [92.78943634, 12.9034214], [92.78939056, 12.90372944], [92.78923035, 12.90400028], [92.7890625, 12.90436935], [92.78876495, 12.90468788], [92.78836823, 12.90495968], [92.7879715, 12.90523148], [92.78749084, 12.90528965], [92.7869873, 12.90524006], [92.78653717, 12.90501022], [92.78607178, 12.90475178], [92.78560638, 12.90449047], [92.78523254, 12.90419197], [92.7848587, 12.90386963], [92.78449249, 12.90352154], [92.78414917, 12.90311623], [92.78370667, 12.90278053], [92.78325653, 12.90249062], [92.78282166, 12.90222931], [92.78238678, 12.90201092], [92.78192139, 12.90190792], [92.78153229, 12.90172958], [92.78111267, 12.90167141], [92.78069305, 12.90167141], [92.78023529, 12.90173531], [92.77979279, 12.90190125], [92.77925873, 12.90198994], [92.77879333, 12.90221977], [92.7783432, 12.9024868], [92.77789307, 12.90273952], [92.77735138, 12.90291786], [92.77677917, 12.9030838], [92.77622223, 12.90337086], [92.77568054, 12.90376091], [92.77514648, 12.90423012], [92.77474213, 12.90481758], [92.77443695, 12.90545177], [92.77423859, 12.90602875], [92.77430725, 12.90651417], [92.77444458, 12.90690231], [92.77456665, 12.90719986], [92.77469635, 12.907444], [92.77475739, 12.90771484], [92.77490234, 12.90798187], [92.77496338, 12.90823936], [92.77485657, 12.90847588], [92.77472687, 12.9087286], [92.77458191, 12.90903854], [92.77442169, 12.90944004], [92.77423096, 12.9098959], [92.77416992, 12.91041088], [92.77420044, 12.91094017], [92.77438354, 12.91140079], [92.77462006, 12.91182041], [92.77494049, 12.91211605], [92.77539825, 12.91221428], [92.77590179, 12.91222286], [92.77641296, 12.91217995], [92.77693939, 12.9119997], [92.77752686, 12.91193199], [92.77812195, 12.91184998], [92.77864075, 12.91168118], [92.77910614, 12.91155815], [92.77944946, 12.91139126], [92.77973938, 12.9112196], [92.78005219, 12.91113186], [92.78034973, 12.91111088], [92.78068542, 12.91110897], [92.78102875, 12.91111088], [92.78137207, 12.91116142], [92.78167725, 12.91135025], [92.78209686, 12.91145992], [92.782547, 12.91164684], [92.78303528, 12.91178322], [92.78354645, 12.91191101], [92.78410339, 12.91195202], [92.78466797, 12.91199112], [92.78518677, 12.91217995], [92.7857132, 12.91222095], [92.78617859, 12.91222954], [92.78659821, 12.91227055], [92.78694153, 12.91245079], [92.7873764, 12.91250992], [92.7878418, 12.91259003], [92.78827667, 12.91279125], [92.78868103, 12.91300964], [92.78903961, 12.9131012], [92.78925323, 12.91325569], [92.78940582, 12.91343117], [92.78948975, 12.91368198], [92.78959656, 12.91401005], [92.78971863, 12.91441059], [92.7898407, 12.91483974], [92.79001617, 12.91530037], [92.7902832, 12.91574001], [92.7906189, 12.91614056], [92.79110718, 12.91640282], [92.79162598, 12.91659164], [92.79212952, 12.9164238], [92.7924881, 12.91594505], [92.79277802, 12.91542339], [92.79301453, 12.9149313], [92.79312134, 12.91442966], [92.79334259, 12.91405106], [92.79359436, 12.91372776], [92.79382324, 12.91337204], [92.79395294, 12.91289997], [92.79416656, 12.91249943], [92.79444122, 12.91209126], [92.79471588, 12.91167355], [92.79498291, 12.9112587]]], [[[92.76815033, 12.91754055], [92.76815033, 12.91641903], [92.76756287, 12.91642094], [92.76753998, 12.91674995], [92.76727295, 12.9169836], [92.76707458, 12.91722584], [92.76669312, 12.91723061], [92.76670837, 12.91782093], [92.76786041, 12.91782093], [92.76815033, 12.91754055]]], [[[92.76702118, 12.92470169], [92.76698303, 12.92391968], [92.76729584, 12.92391968], [92.76735687, 12.92339993], [92.76706696, 12.92336082], [92.76700592, 12.92251968], [92.76731873, 12.92254066], [92.76731873, 12.92171955], [92.76703644, 12.92176056], [92.76703644, 12.92112064], [92.76725769, 12.92114162], [92.76728058, 12.92034245], [92.76677704, 12.92004108], [92.76674652, 12.9194603], [92.7661972, 12.91944981], [92.76587677, 12.91913128], [92.76587677, 12.91858196], [92.76534271, 12.91801929], [92.76477814, 12.91774082], [92.76477814, 12.9174614], [92.76422119, 12.9174614], [92.76422119, 12.91801453], [92.76365662, 12.91829014], [92.76365662, 12.91913128], [92.76333618, 12.91947079], [92.76287079, 12.91947079], [92.76254272, 12.91991138], [92.76262665, 12.92085171], [92.76226044, 12.92088604], [92.7622757, 12.92190456], [92.76314545, 12.92196369], [92.7636795, 12.92256355], [92.76369476, 12.92310238], [92.76422119, 12.92310238], [92.76452637, 12.92366219], [92.765625, 12.92368126], [92.76590729, 12.92394924], [92.76590729, 12.92476082], [92.76702118, 12.92470169]]], [[[92.87702179, 12.9320612], [92.87722778, 12.93167114], [92.87747192, 12.93135357], [92.87773132, 12.93104172], [92.87799072, 12.93072128], [92.8782959, 12.93061066], [92.8786087, 12.9307003], [92.87896729, 12.93081188], [92.87937164, 12.93082142], [92.87982178, 12.9307909], [92.8802948, 12.93062305], [92.88078308, 12.93043423], [92.88109589, 12.92984772], [92.88156891, 12.92980003], [92.88195801, 12.92988205], [92.88233185, 12.92986202], [92.88275146, 12.92997074], [92.8832016, 12.93029022], [92.8837204, 12.92997074], [92.88411713, 12.92982674], [92.88440704, 12.9295702], [92.88461304, 12.92926025], [92.88470459, 12.92887688], [92.884758, 12.92839146], [92.88490295, 12.92785358], [92.88503265, 12.92722034], [92.88527679, 12.92663193], [92.88555145, 12.92607975], [92.88581085, 12.9255743], [92.88600922, 12.92507839], [92.8861084, 12.92455101], [92.88617706, 12.92406559], [92.88627625, 12.92361355], [92.88608551, 12.92298508], [92.88535309, 12.92278004], [92.88473511, 12.92277813], [92.88417816, 12.92250919], [92.88363647, 12.92223072], [92.88311005, 12.92202091], [92.88259888, 12.92191029], [92.88226318, 12.92198277], [92.88198853, 12.9218502], [92.88168335, 12.92130089], [92.88142395, 12.92107105], [92.88114929, 12.92083168], [92.88092804, 12.9205513], [92.88046265, 12.92080021], [92.88030243, 12.92174625], [92.88012695, 12.92236996], [92.87997437, 12.92293072], [92.87973785, 12.92337132], [92.87950134, 12.92381954], [92.87908936, 12.92416096], [92.87857056, 12.92451], [92.87805176, 12.92495918], [92.87754059, 12.92543125], [92.87712097, 12.9259119], [92.87674713, 12.92635155], [92.87632751, 12.92662144], [92.87583923, 12.92667103], [92.87563324, 12.92665005], [92.87534332, 12.92662144], [92.87490845, 12.9263792], [92.87451172, 12.92605114], [92.87419128, 12.92566109], [92.87394714, 12.92526245], [92.87377167, 12.92488575], [92.87362671, 12.92455101], [92.87361145, 12.92420006], [92.87361908, 12.92387676], [92.873703, 12.92355061], [92.87387848, 12.92323589], [92.87404633, 12.92287064], [92.87419891, 12.92243576], [92.87439728, 12.92200089], [92.87444305, 12.92144012], [92.87445068, 12.92083168], [92.87444305, 12.92020035], [92.87438202, 12.91960144], [92.87420654, 12.91903973], [92.87413025, 12.91846085], [92.87394714, 12.91790104], [92.87385559, 12.91733074], [92.87362671, 12.91683197], [92.8733139, 12.91636372], [92.8728714, 12.91599083], [92.87264252, 12.91584015], [92.87230682, 12.91583061], [92.87182617, 12.91585159], [92.87129974, 12.91593647], [92.87081146, 12.91612053], [92.87033844, 12.91634178], [92.86981201, 12.91644192], [92.86929321, 12.91656971], [92.86872864, 12.91670036], [92.86837769, 12.91658115], [92.86759949, 12.91670418], [92.86706543, 12.91666794], [92.86660767, 12.91666126], [92.8663559, 12.91667175], [92.86588287, 12.91671085], [92.8655777, 12.91659164], [92.86503601, 12.91673374], [92.86496735, 12.91737175], [92.86472321, 12.91774082], [92.86445618, 12.91810131], [92.86429596, 12.91848564], [92.86418152, 12.91887188], [92.86411285, 12.91926098], [92.86395264, 12.91958046], [92.86386108, 12.91993141], [92.86369324, 12.92022991], [92.86357117, 12.92055988], [92.8633728, 12.92083168], [92.86322784, 12.92120075], [92.86301422, 12.92156982], [92.86269379, 12.92195511], [92.86234283, 12.9223814], [92.86197662, 12.92285061], [92.86164093, 12.92333603], [92.86123657, 12.92376328], [92.86083221, 12.92419147], [92.86052704, 12.92468071], [92.86019135, 12.925107], [92.85974121, 12.92549229], [92.85927582, 12.92594147], [92.85904694, 12.92626953], [92.85883331, 12.92682076], [92.85887146, 12.92724514], [92.85874176, 12.92767429], [92.85865784, 12.92823029], [92.85840607, 12.92911911], [92.8585434, 12.92965031], [92.85876465, 12.93007755], [92.85887146, 12.93057346], [92.85900116, 12.93099022], [92.85913849, 12.93133831], [92.85926056, 12.93170071], [92.85940552, 12.93203831], [92.85955048, 12.93241024], [92.85979462, 12.9327383], [92.86003876, 12.93310928], [92.86038208, 12.933424], [92.86074066, 12.93362045], [92.86126709, 12.93367004], [92.86190796, 12.93359947], [92.86252594, 12.93352032], [92.86310577, 12.93340969], [92.86368561, 12.93336678], [92.8642807, 12.93334198], [92.86490631, 12.93330097], [92.86553955, 12.93326187], [92.86631012, 12.93338966], [92.86647797, 12.93337059], [92.86680603, 12.93332958], [92.86706543, 12.93307686], [92.86743164, 12.93278122], [92.86790466, 12.93250847], [92.86843109, 12.93229103], [92.868927, 12.93215179], [92.86936951, 12.93198109], [92.86979675, 12.93194008], [92.870224, 12.93198586], [92.87059021, 12.9321909], [92.87094879, 12.93235016], [92.87124634, 12.9325304], [92.87149811, 12.9327898], [92.87172699, 12.93314075], [92.87195587, 12.93353081], [92.87224579, 12.93390179], [92.87268066, 12.93417072], [92.87317657, 12.93437004], [92.87338257, 12.93438339], [92.87378693, 12.93441296], [92.8744278, 12.93429375], [92.87503815, 12.93410492], [92.8755188, 12.93383026], [92.87593079, 12.93353081], [92.87632751, 12.93325138], [92.87664795, 12.93290424], [92.87689972, 12.93251228], [92.87702179, 12.9320612]]], [[[92.76561737, 12.93252373], [92.76566315, 12.93142509], [92.76590729, 12.93142986], [92.76595306, 12.92975044], [92.7661972, 12.92972946], [92.76618958, 12.92919064], [92.76647186, 12.92919064], [92.76648712, 12.92807007], [92.76563263, 12.92805195], [92.76486969, 12.9272337], [92.76486969, 12.92669392], [92.7645874, 12.92667294], [92.76456451, 12.92613506], [92.76422119, 12.92613506], [92.76428223, 12.92555618], [92.76316833, 12.92555618], [92.76316833, 12.92611027], [92.7623291, 12.92610073], [92.7623291, 12.92672253], [92.76203918, 12.92675972], [92.76206207, 12.92778111], [92.76147461, 12.92813873], [92.76143646, 12.92866039], [92.76114655, 12.92864037], [92.76114655, 12.92950058], [92.76091003, 12.92949677], [92.76094818, 12.93083191], [92.76117706, 12.9308424], [92.76119995, 12.93142033], [92.76148224, 12.93142033], [92.76151276, 12.93199921], [92.76117706, 12.93198109], [92.76117706, 12.93254185], [92.76148224, 12.93255997], [92.76150513, 12.9327774], [92.76151276, 12.93332958], [92.76177979, 12.93361092], [92.76177979, 12.93416691], [92.76232147, 12.93418121], [92.76230621, 12.93470001], [92.76261902, 12.93500137], [92.76374054, 12.93500137], [92.76369476, 12.93448067], [92.76397705, 12.93424034], [92.76452637, 12.93420124], [92.76454926, 12.93336201], [92.76478577, 12.93334198], [92.76561737, 12.93252373]]], [[[92.9263916, 13.02416801], [92.9263916, 13.02333069], [92.92694092, 13.02333069], [92.92694092, 13.02361202], [92.92722321, 13.02361202], [92.92749786, 13.02333069], [92.92749786, 13.02305508], [92.92888641, 13.02305508], [92.92888641, 13.0233326], [92.9291687, 13.0233326], [92.9291687, 13.02305508], [92.92944336, 13.02305508], [92.92944336, 13.02333069], [92.93000031, 13.02361202], [92.9319458, 13.02388954], [92.93250275, 13.02416801], [92.93360901, 13.02444553], [92.93444824, 13.02472115], [92.9347229, 13.02472115], [92.9347229, 13.02444553], [92.93499756, 13.02444553], [92.93499756, 13.0247097], [92.93583679, 13.02555561], [92.9366684, 13.02583122], [92.93694305, 13.0261116], [92.93805695, 13.0261116], [92.9383316, 13.02583122], [92.93888855, 13.02555561], [92.94000244, 13.02528], [92.94000244, 13.0247097], [92.9402771, 13.02444553], [92.9402771, 13.02388954], [92.93972015, 13.02361202], [92.93888855, 13.02333069], [92.9383316, 13.02305508], [92.93805695, 13.02278042], [92.93805695, 13.02167034], [92.9383316, 13.02139187], [92.9383316, 13.02083111], [92.93888855, 13.02055454], [92.93972015, 13.02028179], [92.9402771, 13.02000141], [92.9402771, 13.01972103], [92.94082642, 13.01972103], [92.94082642, 13.02000141], [92.9411087, 13.02000141], [92.9411087, 13.01972103], [92.94194794, 13.01944542], [92.94249725, 13.01916695], [92.94249725, 13.01833057], [92.94277954, 13.01805496], [92.94249725, 13.01777935], [92.94194794, 13.01750088], [92.94194794, 13.01666927], [92.9422226, 13.01638889], [92.9422226, 13.01611137], [92.94166565, 13.01555538], [92.94165802, 13.01443958], [92.94139099, 13.01416683], [92.9402771, 13.01389122], [92.9402771, 13.0127697], [92.93972015, 13.01222324], [92.93972015, 13.01166725], [92.93945312, 13.01139069], [92.93945312, 13.00944042], [92.93972015, 13.00916576], [92.93972015, 13.00889111], [92.94000244, 13.00860977], [92.94000244, 13.00833035], [92.9402771, 13.00805569], [92.9402771, 13.0069418], [92.94055176, 13.00666618], [92.94055176, 13.00611019], [92.94083405, 13.00583363], [92.94083405, 13.00555611], [92.94055176, 13.00527954], [92.94055176, 13.00471973], [92.94083405, 13.00444412], [92.94083405, 13.00389004], [92.9411087, 13.00360107], [92.94083405, 13.00333405], [92.94139099, 13.00277805], [92.94139099, 13.00249958], [92.94165802, 13.00222015], [92.94277954, 13.00194359], [92.94249725, 13.00166798], [92.94304657, 13.00139046], [92.94304657, 13.00111198], [92.94333649, 13.0008316], [92.94333649, 13.0], [92.943367, 12.99889183], [92.9436264, 12.99890995], [92.9436264, 12.99808121], [92.94387054, 12.99806023], [92.94394684, 12.99749947], [92.94418335, 12.99749947], [92.94418335, 12.99697113], [92.94359589, 12.99695492], [92.94332123, 12.99635315], [92.94252777, 12.99637127], [92.94251251, 12.99612141], [92.94197845, 12.99612141], [92.94197845, 12.99562073], [92.94165802, 12.99532127], [92.9411087, 12.99532127], [92.94113159, 12.99583054], [92.94003296, 12.99583054], [92.94004822, 12.99555969], [92.93810272, 12.99555969], [92.93805695, 12.99526978], [92.93746948, 12.99530029], [92.93746948, 12.9955759], [92.9367218, 12.99559021], [92.9367218, 12.99581146], [92.93615723, 12.99583054], [92.93586731, 12.99612141], [92.93582916, 12.99746132], [92.93504333, 12.99752045], [92.9347229, 12.99806023], [92.93360138, 12.99814034], [92.93332672, 12.99833107], [92.93332672, 12.99889183], [92.93254089, 12.99943733], [92.93250275, 12.99972153], [92.93027496, 12.99972153], [92.93001556, 12.99947453], [92.9291687, 12.99946022], [92.92920685, 12.9991703], [92.92727661, 12.99918079], [92.92723846, 12.99950123], [92.92585754, 12.99945736], [92.92558289, 12.99972153], [92.92555237, 13.00000191], [92.92582703, 13.00028038], [92.92555237, 13.00027847], [92.92555237, 13.0008316], [92.92527771, 13.00111198], [92.92444611, 13.00139046], [92.92415619, 13.00139046], [92.92415619, 13.00111198], [92.92388916, 13.00111198], [92.92388916, 13.00139046], [92.9227829, 13.00139046], [92.92250061, 13.00111198], [92.92250061, 13.00055981], [92.92222595, 13.00028038], [92.92193604, 13.00028038], [92.92138672, 13.00055981], [92.92082977, 13.00111198], [92.92082977, 13.00249958], [92.92056274, 13.00277996], [92.92055511, 13.00305557], [92.92082977, 13.00333405], [92.92055511, 13.00361156], [92.92055511, 13.00444412], [92.92028046, 13.00471973], [92.92028046, 13.00500011], [92.91999817, 13.00527954], [92.91944122, 13.00555611], [92.91889191, 13.00611019], [92.91889191, 13.00638771], [92.91833496, 13.0069437], [92.91860962, 13.00722027], [92.91805267, 13.00749969], [92.91805267, 13.00777817], [92.91750336, 13.00833035], [92.91750336, 13.00860977], [92.91722107, 13.00888824], [92.91722107, 13.00944042], [92.91694641, 13.00972939], [92.91694641, 13.01000118], [92.91638947, 13.01056099], [92.91638947, 13.01139069], [92.91611481, 13.01166725], [92.91611481, 13.01194477], [92.91583252, 13.01222038], [92.91583252, 13.01250076], [92.91610718, 13.0127697], [92.91583252, 13.01305676], [92.91583252, 13.01472092], [92.91610718, 13.0150013], [92.91610718, 13.0155592], [92.91694641, 13.01638889], [92.91694641, 13.01722145], [92.91777802, 13.01805496], [92.91832733, 13.01833057], [92.91889191, 13.01890087], [92.91944122, 13.01917171], [92.91999817, 13.01917171], [92.91999817, 13.01890087], [92.92056274, 13.01890087], [92.92055511, 13.01916695], [92.92111206, 13.01944542], [92.92138672, 13.01972103], [92.92138672, 13.02000141], [92.92194366, 13.02055454], [92.92193604, 13.02083111], [92.92250061, 13.02139187], [92.92250061, 13.02166653], [92.9227829, 13.02194118], [92.9227829, 13.02250195], [92.92222595, 13.02278042], [92.92194366, 13.02305508], [92.92193604, 13.02333069], [92.92138672, 13.02361202], [92.92111206, 13.02388954], [92.92166901, 13.02444553], [92.92138672, 13.02472115], [92.92138672, 13.02583122], [92.92166901, 13.0261116], [92.92166901, 13.02777767], [92.92250061, 13.02861214], [92.92388916, 13.02861214], [92.92416382, 13.02833366], [92.92527771, 13.02805614], [92.92555237, 13.027771], [92.92555237, 13.02750015], [92.92582703, 13.02722168], [92.92583466, 13.02666569], [92.92610931, 13.02639198], [92.92610931, 13.0261116], [92.9263916, 13.02583122], [92.92610931, 13.02555561], [92.92610931, 13.02443886], [92.9263916, 13.02416801]]], [[[92.83000183, 13.17193985], [92.83027649, 13.17194366], [92.83055878, 13.17166615], [92.83082581, 13.17167091], [92.83110809, 13.17139053], [92.83139038, 13.17139053], [92.83167267, 13.17111015], [92.83222198, 13.17111015], [92.83249664, 13.17083454], [92.83389282, 13.17082977], [92.83444214, 13.17139053], [92.83444214, 13.17166615], [92.8347168, 13.17193985], [92.8347168, 13.17223167], [92.83499908, 13.17250061], [92.83499908, 13.17278099], [92.83528137, 13.17306137], [92.83528137, 13.17361069], [92.83555603, 13.17389107], [92.83528137, 13.17416668], [92.83528137, 13.1747179], [92.83444214, 13.17556095], [92.83416748, 13.17556095], [92.83333588, 13.17639065], [92.83305359, 13.17638874], [92.83249664, 13.17694473], [92.83222198, 13.17694473], [92.83194733, 13.17722321], [92.83167267, 13.1772213], [92.83139038, 13.17750072], [92.83110809, 13.17750072], [92.83055878, 13.17805862], [92.83027649, 13.17805481], [92.83000183, 13.17833328], [92.82971954, 13.17805481], [92.82944489, 13.17833328], [92.82943726, 13.1786108], [92.82749939, 13.18056202], [92.82722473, 13.18055534], [92.82666779, 13.18111134], [92.82611084, 13.18111134], [92.82555389, 13.18055534], [92.82554626, 13.18028164], [92.82499695, 13.17972088], [92.82499695, 13.17944527], [92.82472229, 13.17916679], [92.82446289, 13.17917156], [92.82417297, 13.17889118], [92.82389069, 13.17888927], [92.82333374, 13.17944527], [92.82333374, 13.17972088], [92.82195282, 13.18111134], [92.82195282, 13.18140125], [92.8216629, 13.18166733], [92.8216629, 13.18194103], [92.8208313, 13.18278027], [92.81999969, 13.18278027], [92.8188858, 13.18388939], [92.8188858, 13.18416691], [92.81916809, 13.18444824], [92.81972504, 13.18499947], [92.81986237, 13.18500233], [92.81999969, 13.18499947], [92.82026672, 13.18528175], [92.82055664, 13.18528175], [92.8208313, 13.18556023], [92.82110596, 13.18556023], [92.82195282, 13.18639183], [92.82194519, 13.18666458], [92.82221985, 13.18694305], [92.82221985, 13.18721008], [92.82250214, 13.18750191], [92.82250214, 13.18805599], [92.82277679, 13.18833447], [92.82277679, 13.18944359], [92.82305908, 13.1897192], [92.82305908, 13.18999958], [92.82389069, 13.19083405], [92.82389069, 13.19110966], [92.82417297, 13.19139004], [92.82417297, 13.19306087], [92.82305908, 13.19417095], [92.82277679, 13.19416618], [92.82250214, 13.1944437], [92.82221985, 13.1944437], [92.82194519, 13.19472218], [92.82055664, 13.19458485], [92.82027435, 13.1944437], [92.81972504, 13.1944437], [92.81944275, 13.19431019], [92.81902313, 13.19445133], [92.8188858, 13.1944437], [92.81861115, 13.19472027], [92.81861115, 13.19499969], [92.81916809, 13.19555569], [92.81916809, 13.19583035], [92.81999969, 13.19666576], [92.81999969, 13.19694424], [92.82026672, 13.19721985], [92.82026672, 13.19778061], [92.81999969, 13.19805431], [92.81999969, 13.19832993], [92.81916809, 13.19917107], [92.81861115, 13.19930553], [92.81832886, 13.19972038], [92.81806183, 13.20028114], [92.8180542, 13.20055676], [92.81832886, 13.20139122], [92.81833649, 13.20166683], [92.81861115, 13.2019453], [92.8188858, 13.20193958], [92.81944275, 13.20236206], [92.82138824, 13.2025013], [92.82221985, 13.2033329], [92.82221985, 13.20361137], [92.82250214, 13.20388889], [92.82250214, 13.20472145], [92.8225708, 13.20478916], [92.82332611, 13.20557117], [92.8236084, 13.20555496], [92.82417297, 13.20611095], [92.82430267, 13.20639133], [92.82472229, 13.20666695], [92.82472229, 13.20694065], [92.82518768, 13.20740795], [92.82611084, 13.20833969], [92.82639313, 13.20833969], [92.82694244, 13.20778179], [92.82720947, 13.20778179], [92.82777405, 13.20763588], [92.82917023, 13.20861053], [92.82917023, 13.20889187], [92.82943726, 13.20917034], [92.82972717, 13.21055508], [92.83083344, 13.21194553], [92.83082581, 13.21221924], [92.83110809, 13.21250153], [92.83110809, 13.21277714], [92.83167267, 13.21333122], [92.83167267, 13.21389198], [92.83055878, 13.21500015], [92.82943726, 13.21500015], [92.82917023, 13.21500015], [92.82888794, 13.21500015], [92.82861328, 13.21500015], [92.82805634, 13.21555996], [92.82777405, 13.21555614], [92.82722473, 13.21611214], [92.82639313, 13.21611023], [92.82611084, 13.21638966], [92.82499695, 13.21638966], [92.82472229, 13.21666622], [92.82472229, 13.21694374], [92.82446289, 13.21722031], [92.82444763, 13.21749973], [92.82554626, 13.21860981], [92.82555389, 13.21889019], [92.82611084, 13.21943855], [92.82611084, 13.21972179], [92.82749939, 13.22111225], [92.82776642, 13.22111034], [92.82833099, 13.2216711], [92.82861328, 13.22166634], [92.82917023, 13.22222042], [92.82888794, 13.22249985], [92.82888794, 13.22278118], [92.82917023, 13.22305584], [92.82917023, 13.22332096], [92.82943726, 13.22360992], [92.82946014, 13.2240963], [92.82932281, 13.22430134], [92.82897186, 13.22437096], [92.82847595, 13.22422791], [92.82805634, 13.2238884], [92.82776642, 13.22360992], [92.82720947, 13.22360992], [92.82694244, 13.22332096], [92.82666779, 13.22332096], [92.82583618, 13.22417068], [92.82583618, 13.22500038], [92.82611084, 13.22528076], [92.82611084, 13.22555447], [92.82749939, 13.22694016], [92.82749939, 13.22750092], [92.82776642, 13.2277813], [92.82776642, 13.23000145], [92.82805634, 13.23027897], [92.82805634, 13.23111057], [92.82777405, 13.23138905], [92.82777405, 13.23194504], [92.82805634, 13.23222256], [92.82805634, 13.23361111], [92.82776642, 13.23389053], [92.82777405, 13.2341671], [92.82749939, 13.23444462], [92.82749939, 13.23583126], [92.82776642, 13.23611069], [92.82777405, 13.23666668], [92.82833099, 13.23722076], [92.82833099, 13.23749924], [92.82861328, 13.23749924], [92.83000183, 13.23888969], [92.83000183, 13.23916531], [92.83027649, 13.23944569], [92.83026886, 13.2397213], [92.83055878, 13.24000168], [92.83055878, 13.24055576], [92.83082581, 13.24083138], [92.83083344, 13.24166775], [92.83110809, 13.24194431], [92.83110809, 13.24222183], [92.83167267, 13.24277973], [92.83194733, 13.24277973], [92.83222198, 13.24306011], [92.83249664, 13.24277973], [92.83304596, 13.24277973], [92.83333588, 13.24250031], [92.8347168, 13.24250031], [92.83499908, 13.24277973], [92.83528137, 13.24277782], [92.83583069, 13.24333382], [92.83611298, 13.24333382], [92.83638763, 13.24361229], [92.83666992, 13.24361229], [92.83721924, 13.2430563], [92.83750153, 13.24333382], [92.83833313, 13.24333382], [92.83860779, 13.2430563], [92.83889008, 13.24306011], [92.83914948, 13.24277973], [92.83943939, 13.24277973], [92.83999634, 13.24222183], [92.83999634, 13.24194431], [92.84083557, 13.24111176], [92.84083557, 13.24083424], [92.84166718, 13.23999882], [92.84166718, 13.23917198], [92.84194183, 13.23888969], [92.84194183, 13.23860931], [92.84222412, 13.23833275], [92.84249878, 13.23833275], [92.84333038, 13.23749924], [92.84361267, 13.23749924], [92.84416962, 13.23694134], [92.84444427, 13.23694324], [92.84471893, 13.23722267], [92.84500122, 13.23722076], [92.84527588, 13.23749924], [92.8455658, 13.23749924], [92.8458786, 13.23782063], [92.84610748, 13.23806], [92.84638977, 13.23805523], [92.84666443, 13.23833275], [92.84805298, 13.23833275], [92.84833527, 13.23861122], [92.84860992, 13.23860931], [92.84870148, 13.23870277], [92.84889221, 13.23888969], [92.84916687, 13.23888969], [92.84944153, 13.23917198], [92.84972382, 13.23916531], [92.84999847, 13.23944569], [92.84999847, 13.2397213], [92.85056305, 13.24028015], [92.85055542, 13.24139023], [92.84999847, 13.24194431], [92.84999847, 13.24222183], [92.84971619, 13.24250031], [92.84999847, 13.24277782], [92.84999847, 13.24361038], [92.85028076, 13.24388981], [92.85028076, 13.24417019], [92.85055542, 13.24444389], [92.85056305, 13.24472046], [92.85083008, 13.24500179], [92.85083008, 13.24528027], [92.85111237, 13.24556065], [92.85111237, 13.24610996], [92.85137939, 13.24639034], [92.85138702, 13.24666595], [92.85166931, 13.24694443], [92.85166931, 13.24722195], [92.85193634, 13.24749088], [92.85194397, 13.24805641], [92.85221863, 13.24833202], [92.85221863, 13.24860954], [92.85250092, 13.24888802], [92.85250092, 13.24944401], [92.8527832, 13.24971962], [92.85277557, 13.25027847], [92.85305786, 13.25055027], [92.85305786, 13.25139141], [92.85333252, 13.25166607], [92.85333252, 13.25333214], [92.85360718, 13.25360966], [92.85360718, 13.25528145], [92.85388947, 13.25555515], [92.85388947, 13.25583267], [92.85416412, 13.25611115], [92.85416412, 13.25694466], [92.85443878, 13.25722122], [92.85444641, 13.25777912], [92.85277557, 13.25944519], [92.85166931, 13.25944519], [92.85138702, 13.2597208], [92.85111237, 13.2597208], [92.85056305, 13.26028156], [92.85028076, 13.26028156], [92.84916687, 13.26139069], [92.84889221, 13.26138878], [92.84805298, 13.26222324], [92.84777832, 13.26222324], [92.84750366, 13.26249886], [92.84583282, 13.26249886], [92.84555817, 13.26222324], [92.84527588, 13.26222324], [92.84471893, 13.26166725], [92.84333038, 13.26167202], [92.84320831, 13.26154423], [92.84305573, 13.26138878], [92.84249878, 13.26139069], [92.84227753, 13.26116753], [92.84194183, 13.26083279], [92.84083557, 13.26083279], [92.83999634, 13.26000118], [92.83999634, 13.2597208], [92.83972168, 13.25944519], [92.83944702, 13.25944519], [92.83889008, 13.2588892], [92.83860779, 13.25916672], [92.83860779, 13.2597208], [92.83833313, 13.26000118], [92.83833313, 13.26028156], [92.83805847, 13.26055527], [92.83777618, 13.26111126], [92.83750153, 13.26166725], [92.8374939, 13.26194477], [92.83750153, 13.26222324], [92.83721924, 13.26249027], [92.83708191, 13.26305485], [92.83721924, 13.26333141], [92.83693695, 13.26361084], [92.83693695, 13.26388931], [92.83666992, 13.26416683], [92.83666992, 13.26444054], [92.83611298, 13.26499939], [92.83611298, 13.2658329], [92.83583069, 13.26611233], [92.83583069, 13.26666546], [92.83555603, 13.26694584], [92.83555603, 13.26722145], [92.83486938, 13.26813126], [92.8345108, 13.26846123], [92.83403015, 13.26862144], [92.83389282, 13.26862144], [92.83361053, 13.26889038], [92.83333588, 13.26889038], [92.83304596, 13.26916981], [92.83222198, 13.26916981], [92.83208466, 13.26916599], [92.83194733, 13.26916122], [92.83167267, 13.26889038], [92.83139038, 13.26916981], [92.83069611, 13.26916981], [92.83000183, 13.26862144], [92.82958221, 13.26846123], [92.82944489, 13.26833439], [92.82833099, 13.26722145], [92.82833099, 13.26666546], [92.82749939, 13.26583099], [92.82694244, 13.26583099], [92.82695007, 13.26638985], [92.8270874, 13.26681137], [92.82763672, 13.26805973], [92.82749939, 13.26861191], [92.82666779, 13.26944447], [92.82666779, 13.26972198], [92.82527924, 13.27110958], [92.82527924, 13.27138996], [92.82472229, 13.27193928], [92.82472229, 13.27416611], [92.82446289, 13.27443027], [92.82444763, 13.27527809], [92.82250214, 13.27722168], [92.82250214, 13.27832985], [92.82309723, 13.27912521], [92.82406616, 13.27966976], [92.82492065, 13.28023148], [92.82534027, 13.28133202], [92.82527924, 13.28250122], [92.82554626, 13.28278065], [92.82554626, 13.28362179], [92.82527924, 13.28416729], [92.82527924, 13.28444004], [92.82527924, 13.28499889], [92.82499695, 13.28528118], [92.82499695, 13.28555489], [92.82472229, 13.28583145], [92.82472229, 13.28638935], [92.82444763, 13.28666687], [92.82444763, 13.28722095], [92.82417297, 13.28750134], [92.82416534, 13.28805542], [92.82472229, 13.28861141], [92.82499695, 13.28861141], [92.82527924, 13.28833294], [92.82611084, 13.28833294], [92.8263855, 13.28861141], [92.82666779, 13.28833294], [92.82888794, 13.28833294], [92.83055878, 13.28666687], [92.83083344, 13.28666687], [92.83139038, 13.28611088], [92.83167267, 13.28611088], [92.83194733, 13.28583336], [92.83222198, 13.28583336], [92.83277893, 13.28527737], [92.83389282, 13.28528118], [92.83416748, 13.28556156], [92.83444214, 13.28556156], [92.83499908, 13.28611088], [92.83555603, 13.28611088], [92.83583069, 13.28583145], [92.83693695, 13.28583145], [92.83721924, 13.28611088], [92.83750153, 13.28611088], [92.83777618, 13.28639126], [92.83805847, 13.28638935], [92.83860779, 13.28694534], [92.83860779, 13.28833103], [92.83805847, 13.28889179], [92.83805847, 13.28917027], [92.83693695, 13.29027939], [92.83694458, 13.29111099], [92.83583069, 13.29222107], [92.83583069, 13.29249859], [92.83555603, 13.29279137], [92.83555603, 13.29305458], [92.83583069, 13.29333401], [92.83555603, 13.29361153], [92.83555603, 13.29416847], [92.83583069, 13.29444122], [92.83583069, 13.29500198], [92.83611298, 13.2952776], [92.83611298, 13.29583073], [92.83833313, 13.29806042], [92.83860779, 13.29805565], [92.83889008, 13.29833412], [92.83916473, 13.29833412], [92.84194183, 13.30111217], [92.84194183, 13.30166626], [92.84222412, 13.30194378], [92.84194183, 13.30222225], [92.84194183, 13.30333424], [92.84166718, 13.30360985], [92.84166718, 13.30389023], [92.84139252, 13.30416584], [92.84139252, 13.30443954], [92.83943939, 13.30639076], [92.83914948, 13.30639076], [92.83889008, 13.30667114], [92.83721924, 13.30667114], [92.83693695, 13.30639076], [92.83666992, 13.30639076], [92.83640289, 13.30611038], [92.83611298, 13.30611038], [92.83472443, 13.30472183], [92.83389282, 13.30473137], [92.83304596, 13.30556107], [92.83249664, 13.30555439], [92.83222198, 13.30583191], [92.82971954, 13.30583191], [92.82944489, 13.30611038], [92.82917023, 13.30611038], [92.82861328, 13.30667114], [92.82666779, 13.30666637], [92.8263855, 13.30694485], [92.82611084, 13.30694485], [92.82472229, 13.3083334], [92.82444763, 13.3083334], [92.82417297, 13.30861092], [92.82250214, 13.30861092], [92.82194519, 13.30916691], [92.82194519, 13.30944538], [92.8216629, 13.30972099], [92.8216629, 13.31000137], [92.82195282, 13.31027889], [92.82194519, 13.31055546], [92.82221985, 13.31083298], [92.82250214, 13.31083298], [92.82277679, 13.31111145], [92.82308197, 13.31113625], [92.82332611, 13.31139088], [92.82417297, 13.31139088], [92.82446289, 13.31166935], [92.82749939, 13.31166744], [92.82777405, 13.31194496], [92.82917023, 13.31194496], [92.83055878, 13.31333256], [92.83055878, 13.31359959], [92.83083344, 13.31388855], [92.83083344, 13.31444454], [92.83110809, 13.31472111], [92.83110809, 13.31528187], [92.83139038, 13.31555462], [92.83139038, 13.31611061], [92.83082581, 13.31667042], [92.83027649, 13.3166666], [92.83000183, 13.31694317], [92.82971954, 13.31694317], [92.82944489, 13.3172226], [92.82917023, 13.31722069], [92.82888794, 13.31750107], [92.82861328, 13.31749916], [92.82749939, 13.31860924], [92.82749939, 13.31916809], [92.82720947, 13.31944084], [92.82720947, 13.3197298], [92.82694244, 13.3200016], [92.82694244, 13.32111168], [92.82720947, 13.32139015], [92.82722473, 13.32166767], [92.82749939, 13.32194138], [92.82749939, 13.32305622], [92.82720947, 13.32333183], [92.82720947, 13.32388973], [92.82694244, 13.32417011], [92.82694244, 13.32528019], [92.82666779, 13.3255558], [92.82666779, 13.32582855], [92.8263855, 13.32610989], [92.82639313, 13.32722187], [92.82666779, 13.32750034], [92.82666779, 13.32861042], [92.82694244, 13.32889938], [92.82694244, 13.32916641], [92.82722473, 13.32944393], [92.82722473, 13.3297224], [92.82833099, 13.33082962], [92.82833099, 13.33111], [92.82917023, 13.33194447], [92.82917023, 13.33222008], [92.83000183, 13.33306122], [92.83027649, 13.3330574], [92.83100128, 13.33377934], [92.83166504, 13.334445], [92.83194733, 13.33444023], [92.83277893, 13.33528137], [92.83277893, 13.33555698], [92.83304596, 13.33582973], [92.83304596, 13.33611107], [92.83333588, 13.33639145], [92.83361053, 13.33638859], [92.83444214, 13.33722305], [92.83444214, 13.33777046], [92.83472443, 13.33805466], [92.8347168, 13.33833122], [92.83444214, 13.33861065], [92.83444214, 13.33916664], [92.83416748, 13.33944511], [92.83416748, 13.33972263], [92.83389282, 13.34000111], [92.83388519, 13.34027672], [92.83363342, 13.34110165], [92.83444214, 13.34194469], [92.83444214, 13.34222126], [92.8347168, 13.34250069], [92.83472443, 13.34305477], [92.83499908, 13.34333134], [92.83499908, 13.34361076], [92.83528137, 13.34388924], [92.83528137, 13.3461113], [92.83555603, 13.34638977], [92.83555603, 13.34722137], [92.83528137, 13.34749889], [92.83528137, 13.34778023], [92.83499908, 13.34805584], [92.83499908, 13.34833145], [92.83444214, 13.3488903], [92.83444214, 13.34916782], [92.83389282, 13.34971046], [92.83389282, 13.35027981], [92.83361053, 13.35055637], [92.83361053, 13.35221958], [92.83388519, 13.35249996], [92.83389282, 13.35332966], [92.83416748, 13.35361195], [92.83416748, 13.35416603], [92.83444214, 13.35444355], [92.83444214, 13.35472202], [92.83528137, 13.35556126], [92.83528137, 13.3558321], [92.83555603, 13.35610962], [92.83555603, 13.35639], [92.83583069, 13.35666561], [92.83583069, 13.3572197], [92.83611298, 13.35750008], [92.83611298, 13.36000061], [92.83640289, 13.36028099], [92.83640289, 13.36139107], [92.83666992, 13.36166668], [92.83666992, 13.36194515], [92.83640289, 13.3622179], [92.83638763, 13.36305523], [92.83611298, 13.36333275], [92.83611298, 13.3661108], [92.83638763, 13.36638927], [92.83640289, 13.36694145], [92.83833313, 13.36889076], [92.83833313, 13.36916733], [92.83860779, 13.36944103], [92.83860779, 13.37000084], [92.83889008, 13.37027931], [92.83889008, 13.37138939], [92.83916473, 13.37166691], [92.83916473, 13.3736124], [92.83944702, 13.37388992], [92.83943939, 13.37472057], [92.83999634, 13.37528038], [92.83999634, 13.37555599], [92.84027863, 13.37583065], [92.84027863, 13.37611198], [92.84194183, 13.37777996], [92.84306335, 13.37777996], [92.84333038, 13.37749958], [92.84388733, 13.37749958], [92.84416962, 13.3772192], [92.84471893, 13.37722206], [92.84500122, 13.37694359], [92.84527588, 13.37694359], [92.84555817, 13.37666798], [92.8455658, 13.37639046], [92.84638977, 13.37555981], [92.84638977, 13.37528038], [92.8466568, 13.37500191], [92.8466568, 13.37472057], [92.84750366, 13.37388992], [92.84750366, 13.3736124], [92.84777832, 13.37333298], [92.84777832, 13.37277699], [92.84805298, 13.37249947], [92.84805298, 13.37222099], [92.84916687, 13.37111092], [92.84944153, 13.37111092], [92.84971619, 13.37084007], [92.85056305, 13.37084007], [92.85083008, 13.37111092], [92.85111237, 13.37111092], [92.85137939, 13.37138939], [92.85138702, 13.37166691], [92.85166931, 13.37194538], [92.85166931, 13.3736124], [92.85194397, 13.37388992], [92.85194397, 13.37444305], [92.85221863, 13.37472057], [92.85221863, 13.37528038], [92.85250092, 13.37555599], [92.85250092, 13.37583447], [92.85527802, 13.37861156], [92.85557556, 13.37863731], [92.85582733, 13.37889004], [92.85722351, 13.37889004], [92.85778046, 13.37944412], [92.85916901, 13.37944412], [92.85944366, 13.37972164], [92.86000061, 13.37972164], [92.86011505, 13.37983799], [92.8602829, 13.3800106], [92.86057281, 13.3800106], [92.86074066, 13.38018227], [92.86083221, 13.38027954], [92.86110687, 13.38027954], [92.86138916, 13.38056087], [92.86194611, 13.38055611], [92.86222076, 13.38083363], [92.86360931, 13.38083363], [92.86360931, 13.3811121], [92.86472321, 13.38111019], [92.86499786, 13.38138962], [92.86528015, 13.38138962], [92.86555481, 13.38166809], [92.86555481, 13.3819437], [92.8658371, 13.38222027], [92.8658371, 13.38360977], [92.86638641, 13.38416576], [92.86638641, 13.38444424], [92.8666687, 13.38471985], [92.8666687, 13.38528061], [92.86694336, 13.38556099], [92.86694336, 13.3866663], [92.8666687, 13.38694382], [92.8666687, 13.38722038], [92.8658371, 13.38805676], [92.86611176, 13.38833237], [92.86499786, 13.3894453], [92.86472321, 13.3894453], [92.86402893, 13.38971424], [92.86347198, 13.38916397], [92.86305237, 13.38874722], [92.86263275, 13.38861275], [92.86057281, 13.38582134], [92.86027527, 13.38583469], [92.86000061, 13.38555431], [92.85972595, 13.38556099], [92.85943604, 13.38528061], [92.85916901, 13.38527775], [92.85861206, 13.38583469], [92.85832977, 13.38583469], [92.85805511, 13.38611031], [92.8575058, 13.38611031], [92.85721588, 13.38639069], [92.85694122, 13.38639069], [92.85666656, 13.38667107], [92.85361481, 13.3866663], [92.85333252, 13.38694382], [92.85277557, 13.38694382], [92.85083008, 13.38888931], [92.85056305, 13.38888168], [92.85028076, 13.38917065], [92.84999847, 13.38916683], [92.84972382, 13.3894453], [92.84944153, 13.3894453], [92.84916687, 13.38972282], [92.84889221, 13.38971996], [92.84860992, 13.3900013], [92.84749603, 13.3900013], [92.84722137, 13.39028072], [92.84666443, 13.39027882], [92.84610748, 13.39083004], [92.84610748, 13.39166927], [92.84527588, 13.39250088], [92.84443665, 13.39250088], [92.84388733, 13.39306164], [92.84361267, 13.39305496], [92.84333038, 13.39333057], [92.84333038, 13.39361095], [92.84305573, 13.39388943], [92.84249878, 13.39444065], [92.84249878, 13.39500999], [92.84278107, 13.39528179], [92.84278107, 13.39638901], [92.84221649, 13.39694118], [92.84221649, 13.39750099], [92.84208679, 13.39819717], [92.84249878, 13.39944553], [92.84249878, 13.39972115], [92.84278107, 13.40000153], [92.84278107, 13.40027714], [92.84333038, 13.40081978], [92.84333038, 13.40166759], [92.84305573, 13.40194321], [92.84306335, 13.40222168], [92.84333038, 13.40250015], [92.84333038, 13.40277958], [92.84361267, 13.40305614], [92.84361267, 13.40333366], [92.84500122, 13.40471935], [92.84500122, 13.40499973], [92.84471893, 13.40528011], [92.84443665, 13.40528011], [92.84416962, 13.40555573], [92.84416962, 13.4058342], [92.84443665, 13.40610981], [92.84443665, 13.40666962], [92.84471893, 13.40695095], [92.84471893, 13.40722179], [92.84500122, 13.40750027], [92.84500122, 13.40805626], [92.84527588, 13.40833378], [92.84527588, 13.40861225], [92.8456955, 13.40902901], [92.84615326, 13.40948963], [92.84694672, 13.41028118], [92.84722137, 13.41028118], [92.84749603, 13.41056061], [92.84777832, 13.41055584], [92.84805298, 13.41083431], [92.84889221, 13.41083431], [92.84933472, 13.41127872], [92.84944153, 13.4113903], [92.84971619, 13.4113903], [92.84999847, 13.41167068], [92.85137939, 13.41167068], [92.85166931, 13.4113903], [92.85221863, 13.4113903], [92.85250092, 13.41110992], [92.85250092, 13.41082954], [92.85277557, 13.41055584], [92.85250092, 13.41028118], [92.85250092, 13.40944195], [92.85305786, 13.40888786], [92.85333252, 13.40888977], [92.85360718, 13.40861034], [92.85443878, 13.40861034], [92.85472107, 13.40888977], [92.85555267, 13.40888786], [92.85573578, 13.40907288], [92.85610962, 13.40944386], [92.85639191, 13.40944386], [92.85694122, 13.40888786], [92.85806274, 13.40888977], [92.85832977, 13.4091711], [92.85861206, 13.40888977], [92.85916901, 13.40888977], [92.86000061, 13.40806103], [92.86000061, 13.40666962], [92.86057281, 13.40610981], [92.86055756, 13.4058342], [92.86027527, 13.40555573], [92.8602829, 13.40528011], [92.86057281, 13.40499973], [92.86057281, 13.40444088], [92.86083221, 13.40416622], [92.86110687, 13.40418243], [92.86138916, 13.40388966], [92.86194611, 13.40388966], [92.86222076, 13.40361023], [92.86250305, 13.40361214], [92.86360931, 13.40250015], [92.8638916, 13.40250015], [92.86444092, 13.4019413], [92.86472321, 13.40194321], [92.86499786, 13.40166759], [92.86528015, 13.40167046], [92.86554718, 13.40139198], [92.8658371, 13.40139198], [92.86611176, 13.40167046], [92.86638641, 13.40166759], [92.86659241, 13.40187073], [92.8666687, 13.40194321], [92.86722565, 13.40194321], [92.86750031, 13.40222168], [92.86777496, 13.40222168], [92.86888885, 13.4033289], [92.86888885, 13.40388966], [92.86916351, 13.40416622], [92.86916351, 13.40444374], [92.8694458, 13.40471935], [92.8694458, 13.40499973], [92.86972046, 13.40528011], [92.86972046, 13.40695095], [92.8694458, 13.40722179], [92.8694458, 13.40833378], [92.86972046, 13.40861034], [92.86972046, 13.40916634], [92.87000275, 13.40944386], [92.87000275, 13.40972233], [92.87110901, 13.41082954], [92.87110901, 13.41110992], [92.87194824, 13.41194439], [92.8722229, 13.41194439], [92.87249756, 13.41166592], [92.87291718, 13.41000938], [92.87306976, 13.4093256], [92.87335205, 13.40850067], [92.87348938, 13.4078207], [92.87398529, 13.40786457], [92.87425995, 13.4078598], [92.87452698, 13.40800095], [92.87432861, 13.40864182], [92.87419128, 13.4095993], [92.873909, 13.41056061], [92.873909, 13.41084099], [92.87361145, 13.41166592], [92.87388611, 13.41194439], [92.87361145, 13.41222], [92.87361145, 13.41250038], [92.87333679, 13.41278076], [92.87333679, 13.41416645], [92.8730545, 13.41444492], [92.87304688, 13.41471958], [92.8722229, 13.41556072], [92.87166595, 13.41555691], [92.8713913, 13.41583347], [92.87055206, 13.41582966], [92.8702774, 13.41611958], [92.87000275, 13.41611958], [92.86972046, 13.41639137], [92.8694458, 13.41638947], [92.86915588, 13.41652107], [92.86917114, 13.41693974], [92.86888885, 13.41777897], [92.86847687, 13.41846943], [92.86833191, 13.41889095], [92.86847687, 13.41918087], [92.86972046, 13.42055511], [92.86972046, 13.42083263], [92.87000275, 13.42111111], [92.87000275, 13.42138863], [92.8694458, 13.42192936], [92.8694458, 13.42250061], [92.86972046, 13.42278194], [92.86972046, 13.4230547], [92.87000275, 13.42333126], [92.87000275, 13.42389202], [92.8702774, 13.42416668], [92.87032318, 13.4247694], [92.87082672, 13.42527962], [92.87110901, 13.42527962], [92.8713913, 13.42556], [92.8722229, 13.42555523], [92.87249756, 13.42583275], [92.87277985, 13.42583275], [92.87444305, 13.42416668], [92.87444305, 13.42361069], [92.875, 13.42306042], [92.8752594, 13.42333126], [92.8752594, 13.42361069], [92.87555695, 13.42388916], [92.87555695, 13.42444324], [92.87610626, 13.4249897], [92.87611389, 13.42527676], [92.87666321, 13.42583275], [92.87666321, 13.42610931], [92.87722015, 13.42666531], [92.87722015, 13.42694569], [92.87750244, 13.42694092], [92.87805176, 13.42750168], [92.87831879, 13.42750168], [92.8786087, 13.42778015], [92.87917328, 13.42778015], [92.87931824, 13.42793179], [92.87944794, 13.42805958], [92.87999725, 13.42805576], [92.88027954, 13.42833424], [92.88083649, 13.42833424], [92.88111115, 13.42861176], [92.8813858, 13.42860889], [92.88168335, 13.42889023], [92.88194275, 13.42889023], [92.88249969, 13.42944431], [92.88277435, 13.42916775], [92.88305664, 13.42916965], [92.8833313, 13.42889023], [92.8841629, 13.42972183], [92.8841629, 13.43027973], [92.88445282, 13.43056011], [92.88444519, 13.43166637], [92.8841629, 13.43194389], [92.8841629, 13.43222046], [92.88388824, 13.43249989], [92.88388824, 13.43332863], [92.88361359, 13.43360996], [92.88360596, 13.43472195], [92.8833313, 13.43500042], [92.8833313, 13.43527985], [92.88305664, 13.43555641], [92.88305664, 13.43583202], [92.88249969, 13.43638802], [92.88249969, 13.4369297], [92.88194275, 13.4375], [92.88194275, 13.43805599], [92.88222504, 13.43833447], [92.88223267, 13.43861008], [92.88249969, 13.43889141], [92.88249969, 13.43916607], [92.88276672, 13.43943977], [92.88276672, 13.43999958], [92.88222504, 13.44055653], [92.88222504, 13.44083214], [92.88194275, 13.44110966], [92.88194275, 13.44138813], [92.8813858, 13.44194508], [92.8813858, 13.44221973], [92.88111115, 13.44250107], [92.88111115, 13.44305515], [92.88083649, 13.4433279], [92.88083649, 13.44388866], [92.87999725, 13.44472313], [92.87944794, 13.44472313], [92.87916565, 13.44444466], [92.87889099, 13.44444466], [92.8786087, 13.44416714], [92.87831879, 13.44417095], [92.87805176, 13.44389057], [92.8777771, 13.44389057], [92.87759399, 13.44370365], [92.87750244, 13.44361115], [92.87666321, 13.44361115], [92.87638855, 13.44389057], [92.87611389, 13.44388866], [92.87527466, 13.44472313], [92.875, 13.44472122], [92.87473297, 13.44500065], [92.87473297, 13.44528103], [92.87361145, 13.4463892], [92.87361145, 13.44694519], [92.87333679, 13.4472208], [92.87333679, 13.44750118], [92.87304688, 13.44778061], [92.8730545, 13.44805527], [92.87361145, 13.44861126], [92.87361145, 13.44916725], [92.8741684, 13.44972134], [92.8741684, 13.45055485], [92.87388611, 13.45083141], [92.87388611, 13.45111084], [92.8741684, 13.45138931], [92.8741684, 13.45277977], [92.87444305, 13.45305538], [92.87444305, 13.45361137], [92.87473297, 13.45388985], [92.87472534, 13.45416546], [92.875, 13.45444107], [92.875, 13.45500183], [92.8752594, 13.45529079], [92.8752594, 13.45639038], [92.87554932, 13.45666981], [92.87555695, 13.45805645], [92.8758316, 13.4583292], [92.8758316, 13.45888996], [92.87610626, 13.45917034], [92.87610626, 13.46028042], [92.87473297, 13.46166992], [92.8741684, 13.46166611], [92.87388611, 13.46194363], [92.87333679, 13.46193886], [92.8722229, 13.46305561], [92.8722229, 13.46333027], [92.87194824, 13.4636097], [92.87194824, 13.46388817], [92.87110901, 13.46471977], [92.87110901, 13.46500015], [92.87083435, 13.46527767], [92.8713913, 13.46583366], [92.8713913, 13.46611023], [92.87166595, 13.46639061], [92.87166595, 13.46666622], [92.87194824, 13.46693993], [92.87194824, 13.46750069], [92.8722229, 13.46778107], [92.8722229, 13.47000122], [92.87194824, 13.47027874], [92.87194824, 13.4711113], [92.87166595, 13.47139072], [92.87277985, 13.4725008], [92.87388611, 13.47139072], [92.8741684, 13.47139072], [92.87444305, 13.4711113], [92.87472534, 13.4711113], [92.87527466, 13.47055531], [92.87555695, 13.47083473], [92.87611389, 13.47083473], [92.87638855, 13.4711113], [92.87638855, 13.47138882], [92.8769455, 13.47194481], [92.87695313, 13.47222137], [92.87722015, 13.4725008], [92.87722015, 13.47305489], [92.8769455, 13.47333336], [92.87695313, 13.47361088], [92.87666321, 13.47389126], [92.87666321, 13.47500134], [92.87695313, 13.47528076], [92.8777771, 13.47528076], [92.87805176, 13.47556019], [92.87833405, 13.47555542], [92.8786087, 13.47583294], [92.87889099, 13.47583294], [92.87916565, 13.47611141], [92.87944031, 13.47616577], [92.8795166, 13.47618198], [92.8797226, 13.47639084], [92.87999725, 13.47639084], [92.88027954, 13.47611141], [92.88054657, 13.47611141], [92.88083649, 13.47639084], [92.88111115, 13.47611141], [92.8841629, 13.47611141], [92.88500214, 13.47694302], [92.88527679, 13.47694302], [92.88555908, 13.4772234], [92.88582611, 13.47722054], [92.8861084, 13.47750092], [92.88643646, 13.47754669], [92.88667297, 13.47777939], [92.88861084, 13.47777939], [92.88889313, 13.47750092], [92.89193726, 13.47750092], [92.89221954, 13.47722054], [92.89250183, 13.4772234], [92.89472198, 13.47500134], [92.89611053, 13.47500134], [92.89639282, 13.47528076], [92.89694214, 13.47528076], [92.8972168, 13.47556019], [92.89749908, 13.47555542], [92.89778137, 13.47583294], [92.89833069, 13.47583294], [92.89861298, 13.47611141], [92.89888763, 13.47611141], [92.90055847, 13.47777939], [92.90055847, 13.478055], [92.90083313, 13.47833061], [92.90083313, 13.47861099], [92.90110779, 13.47888947], [92.90110779, 13.4800024], [92.90139008, 13.48027706], [92.90139008, 13.48083305], [92.9016571, 13.48111153], [92.9016571, 13.48167038], [92.90222168, 13.48223114], [92.90222168, 13.48250198], [92.90248871, 13.48278046], [92.90249634, 13.48305607], [92.90305328, 13.4836092], [92.90305328, 13.48388958], [92.90333557, 13.48416805], [92.90333557, 13.48444366], [92.90361023, 13.48471928], [92.90361023, 13.48750019], [92.90389252, 13.48777771], [92.90389252, 13.48861027], [92.90416718, 13.48888969], [92.90416718, 13.48916626], [92.90444183, 13.48944378], [92.90444183, 13.48972034], [92.90472412, 13.48999977], [92.90457916, 13.49221992], [92.90416718, 13.49278069], [92.90444183, 13.4930563], [92.90416718, 13.49333191], [92.90416718, 13.49361038], [92.90389252, 13.49389076], [92.90389252, 13.49416637], [92.90361023, 13.49444008], [92.90361023, 13.49528122], [92.90341949, 13.49587631], [92.90341949, 13.49670124], [92.90370178, 13.4972496], [92.90426636, 13.49752998], [92.90496063, 13.49793816], [92.90583038, 13.49833298], [92.90638733, 13.49833298], [92.90666962, 13.49861145], [92.90944672, 13.49861145], [92.90972137, 13.49833298], [92.91055298, 13.49833298], [92.91083527, 13.49805546], [92.91194153, 13.49805927], [92.91221619, 13.49777889], [92.91306305, 13.49777889], [92.91333008, 13.49750137], [92.91361237, 13.49750137], [92.91388702, 13.49777889], [92.91416931, 13.49777889], [92.91444397, 13.49805546], [92.91442871, 13.49833012], [92.91500092, 13.49889088], [92.91500092, 13.49916744], [92.91527557, 13.49944496], [92.91542053, 13.49972057], [92.91558075, 13.49998283], [92.91597748, 13.50027657], [92.91722107, 13.5002718], [92.91750336, 13.50056171], [92.91971588, 13.50056171], [92.92028046, 13.50000095], [92.92028046, 13.49972057], [92.92082977, 13.49916744], [92.92082977, 13.49805927], [92.92111206, 13.49777889], [92.92111206, 13.49667072], [92.92138672, 13.4963913], [92.92138672, 13.49611092], [92.92193604, 13.49556065], [92.9227829, 13.49556065], [92.92305756, 13.49555874], [92.92333221, 13.49583244], [92.92359924, 13.49570274], [92.92472076, 13.49611092], [92.92527771, 13.49666691], [92.92527771, 13.49694538], [92.92555237, 13.49721146], [92.92582703, 13.49763966], [92.92582703, 13.49777889], [92.92610931, 13.49805927], [92.9263916, 13.49805546], [92.92666626, 13.49833298], [92.92665863, 13.49861145], [92.92722321, 13.49916744], [92.92722321, 13.50027657], [92.92778015, 13.50083256], [92.9283371, 13.50083065], [92.92861176, 13.50111103], [92.92888641, 13.50111103], [92.92944336, 13.50166702], [92.92944336, 13.50194454], [92.92971802, 13.50222111], [92.92971802, 13.50250053], [92.92944336, 13.50278187], [92.92944336, 13.50305462], [92.92805481, 13.50444317], [92.92778015, 13.50444317], [92.92749786, 13.5047226], [92.92722321, 13.50472069], [92.92665863, 13.50527859], [92.92694092, 13.50555515], [92.92665863, 13.50583076], [92.92666626, 13.50638866], [92.92582703, 13.50722122], [92.92582703, 13.5075016], [92.92527771, 13.50805473], [92.92527771, 13.5083313], [92.92500305, 13.50861168], [92.92500305, 13.50889015], [92.92527771, 13.50916958], [92.92527771, 13.51027775], [92.92333221, 13.51220989], [92.92333221, 13.51249981], [92.92305756, 13.51278019], [92.92305756, 13.5130558], [92.92333221, 13.51332855], [92.92333221, 13.51361179], [92.92359924, 13.51389027], [92.92388916, 13.51389027], [92.9240036, 13.51400185], [92.92444611, 13.51444435], [92.92472076, 13.51444435], [92.92500305, 13.51472187], [92.92555237, 13.51472187], [92.92582703, 13.51500034], [92.92610931, 13.51500034], [92.92694092, 13.51583195], [92.92694092, 13.51666641], [92.92722321, 13.51694202], [92.92722321, 13.51749992], [92.92749786, 13.51778126], [92.92749786, 13.51861], [92.92778015, 13.51889038], [92.92778015, 13.52027798], [92.92666626, 13.52138805], [92.92610931, 13.52138805], [92.92583466, 13.52110958], [92.92555237, 13.52110958], [92.92527771, 13.52083206], [92.92500305, 13.52083206], [92.92472076, 13.5205574], [92.92444611, 13.52056122], [92.92416382, 13.52055168], [92.9236145, 13.52083206], [92.92277527, 13.52083206], [92.92222595, 13.52055168], [92.92193604, 13.52056122], [92.92166901, 13.5205574], [92.92138672, 13.52083206], [92.92111206, 13.52083206], [92.92082977, 13.52110958], [92.92055511, 13.52110958], [92.92028046, 13.52138805], [92.91999817, 13.52137947], [92.91971588, 13.5216713], [92.91944122, 13.52166557], [92.91916656, 13.521945], [92.91860962, 13.521945], [92.91833496, 13.52166557], [92.91805267, 13.521945], [92.91777802, 13.52194023], [92.91610718, 13.52361107], [92.91610718, 13.52389145], [92.91471863, 13.52528095], [92.91471863, 13.52556229], [92.91416931, 13.52611065], [92.91416931, 13.52833271], [92.91388702, 13.52861118], [92.91388702, 13.52916718], [92.91416931, 13.52944469], [92.91388702, 13.52972126], [92.91388702, 13.53111076], [92.91416931, 13.53138924], [92.91416931, 13.53166676], [92.91442871, 13.53194141], [92.91442871, 13.53249931], [92.91471863, 13.53277969], [92.91471863, 13.53306198], [92.91694641, 13.53528023], [92.91694641, 13.53555584], [92.91722107, 13.53583145], [92.91722107, 13.53611183], [92.91750336, 13.5363903], [92.91777802, 13.53638268], [92.91805267, 13.53666973], [92.91833496, 13.53666782], [92.91860962, 13.53694439], [92.91916656, 13.53694439], [92.91944122, 13.53722191], [92.91971588, 13.53722191], [92.91999817, 13.53750038], [92.92056274, 13.53750038], [92.92082977, 13.53722191], [92.92111206, 13.53722191], [92.92166901, 13.53666782], [92.92444611, 13.53666782], [92.9263916, 13.53861237], [92.92665863, 13.53861046], [92.92694092, 13.53889179], [92.92722321, 13.53889179], [92.92749786, 13.53917027], [92.92804718, 13.53917027], [92.9283371, 13.53889179], [92.93000031, 13.53889179], [92.93026733, 13.53861046], [92.93055725, 13.53889179], [92.93110657, 13.53889179], [92.93138885, 13.53917027], [92.93165588, 13.53917027], [92.9319458, 13.53945065], [92.93279266, 13.53945065], [92.93279266, 13.53917027], [92.93638611, 13.53917027], [92.9366684, 13.53945065], [92.93776703, 13.53945065], [92.93859863, 13.53861046], [92.93861389, 13.53833389], [92.93888855, 13.53805637], [92.93888855, 13.53750038], [92.93945312, 13.53694057], [92.9402771, 13.53694439], [92.94055176, 13.53666782], [92.94194794, 13.53666973], [92.9422226, 13.53638268], [92.94249725, 13.53638268], [92.94277954, 13.53666973], [92.94333649, 13.53666782], [92.94361115, 13.53694439], [92.94416809, 13.53694439], [92.94444275, 13.53666782], [92.94527435, 13.53666782], [92.9458313, 13.53722191], [92.94611359, 13.53722191], [92.94638824, 13.53694439], [92.94721985, 13.53694439], [92.94750214, 13.53722191], [92.94777679, 13.53722191], [92.94917297, 13.53861046], [92.94917297, 13.53889179], [92.94972229, 13.53944397], [92.94972229, 13.53971863], [92.94999695, 13.53999996], [92.94999695, 13.54111195], [92.95053864, 13.54166985], [92.95053864, 13.54251099], [92.95082855, 13.54277992], [92.95111084, 13.54277992], [92.95139313, 13.54306126], [92.95305634, 13.54306126], [92.95417023, 13.54417133], [92.95610809, 13.54417133], [92.95639038, 13.54389], [92.95667267, 13.54389], [92.95749664, 13.54306126], [92.95777893, 13.54306126], [92.95916748, 13.54166985], [92.96055603, 13.54166985], [92.96194458, 13.54305553], [92.96193695, 13.54333019], [92.96250153, 13.54389], [92.96305847, 13.54389], [92.96333313, 13.54417133], [92.96360779, 13.54417133], [92.96389008, 13.54389], [92.9641571, 13.54417133], [92.96444702, 13.54416561], [92.96458435, 13.54430485], [92.96472168, 13.54444408], [92.96499634, 13.54416561], [92.96527863, 13.54417133], [92.96553802, 13.54389], [92.96582794, 13.54389], [92.96639252, 13.54333019], [92.96694183, 13.5433321], [92.96749878, 13.54277802], [92.96763611, 13.54292202], [92.96833038, 13.54251099], [92.96861267, 13.54251099], [92.96916962, 13.54194164], [92.96916962, 13.54083443], [92.96888733, 13.54055595], [92.96890259, 13.53971863], [92.96916962, 13.53944397], [92.96916962, 13.53917027], [92.96971893, 13.53861046], [92.97000122, 13.53861046], [92.97006989, 13.53868008], [92.97027588, 13.53889179], [92.97055817, 13.53889179], [92.97083282, 13.53917027], [92.97138977, 13.53917027], [92.97222137, 13.53833199], [92.97222137, 13.53750038], [92.97360992, 13.53611183], [92.97360992, 13.53583145], [92.97389221, 13.53555584], [92.97389221, 13.53444099], [92.97416687, 13.53416538], [92.97416687, 13.5336113], [92.97444153, 13.53333282], [92.97444153, 13.53305531], [92.97470856, 13.53277969], [92.97470856, 13.53194141], [92.97499847, 13.53166676], [92.97499847, 13.52944088], [92.97528076, 13.52916718], [92.97528076, 13.52889061], [92.97638702, 13.52778053], [92.97693634, 13.52778053], [92.97721863, 13.52750969], [92.97805786, 13.52750969], [92.97833252, 13.52778053], [92.97860718, 13.52778053], [92.97888947, 13.52764034], [92.97915649, 13.52778053], [92.97944641, 13.52778053], [92.97972107, 13.52778053], [92.98000336, 13.52750969], [92.98027802, 13.52750969], [92.98055267, 13.52722073], [92.98110962, 13.52722263], [92.98139191, 13.52694511], [92.98222351, 13.52694511], [92.98249817, 13.52666664], [92.98332977, 13.52667141], [92.98361206, 13.52639103], [92.98390198, 13.52667141], [92.98500061, 13.52666664], [92.98527527, 13.52694511], [92.98583221, 13.52694035], [92.98638916, 13.52750969], [92.98805237, 13.52750969], [92.98832703, 13.52778053], [92.9888916, 13.52777672], [92.98944092, 13.52833271], [92.98944092, 13.52861118], [92.98999786, 13.52916718], [92.98999786, 13.52972126], [92.98970795, 13.53000069], [92.98970795, 13.53028202], [92.98944092, 13.53055477], [92.98944092, 13.53083134], [92.98970795, 13.53111076], [92.98970795, 13.53138924], [92.98999786, 13.53166962], [92.98999786, 13.53222084], [92.99028015, 13.53249931], [92.99028015, 13.53277969], [92.99055481, 13.53305531], [92.99055481, 13.53333282], [92.9908371, 13.5336113], [92.9908371, 13.53388882], [92.9916687, 13.53472137], [92.9916687, 13.53499889], [92.99194336, 13.53528023], [92.99194336, 13.53555584], [92.99222565, 13.53583431], [92.99223328, 13.53611183], [92.99194336, 13.53611183], [92.99194336, 13.53638268], [92.9916687, 13.53666973], [92.99028015, 13.53666973], [92.98999786, 13.53638268], [92.98972321, 13.53666782], [92.98972321, 13.53694439], [92.98944092, 13.53722191], [92.98944092, 13.53750038], [92.98916626, 13.53777981], [92.98916626, 13.53805637], [92.9888916, 13.53833389], [92.9888916, 13.53861237], [92.98777771, 13.53971863], [92.98777771, 13.53999996], [92.98722076, 13.54056263], [92.98722076, 13.54139042], [92.98693848, 13.54166985], [92.98694611, 13.54416561], [92.98664856, 13.54444027], [92.98664856, 13.54500008], [92.98638916, 13.54528141], [92.98555756, 13.54528141], [92.98527527, 13.54500008], [92.98194122, 13.54832077], [92.98194122, 13.54860973], [92.98166656, 13.54888821], [92.98166656, 13.54944515], [92.98139191, 13.54972267], [92.98139191, 13.55083466], [92.98110962, 13.55111122], [92.98110962, 13.55194473], [92.98084259, 13.5522213], [92.98084259, 13.55278111], [92.98110962, 13.55305481], [92.98110962, 13.55333328], [92.9814682, 13.55369091], [92.98162079, 13.55384254], [92.98194122, 13.55417061], [92.98222351, 13.55416679], [92.98361206, 13.55486202], [92.98388672, 13.55527687], [92.98472595, 13.55611134], [92.98472595, 13.55639076], [92.98500061, 13.55666733], [92.98500061, 13.55694485], [92.9852829, 13.55722141], [92.98527527, 13.55805492], [92.98513794, 13.55833054], [92.98513794, 13.55916691], [92.98486328, 13.55944538], [92.98500061, 13.55972099], [92.98472595, 13.56000233], [92.98472595, 13.56055546], [92.98443604, 13.56083107], [92.98444366, 13.5616684], [92.98472595, 13.56194305], [92.98472595, 13.56222057], [92.98555756, 13.56305981], [92.98583221, 13.56305599], [92.98750305, 13.5647192], [92.98750305, 13.56527996], [92.98777771, 13.56555557], [92.98777771, 13.56583405], [92.98805237, 13.56610966], [92.98805237, 13.56666565], [92.98832703, 13.56693935], [92.98832703, 13.56806087], [92.98838806, 13.56885147], [92.98838806, 13.56981087], [92.98804474, 13.56987858], [92.98776245, 13.56946659], [92.98726654, 13.56919098], [92.98694611, 13.5694437], [92.98693848, 13.57083035], [92.98722076, 13.57110977], [92.98722076, 13.57166576], [92.98750305, 13.57194424], [92.98750305, 13.57249069], [92.98777771, 13.57278061], [92.98777771, 13.57306099], [92.98860931, 13.57389069], [92.9888916, 13.57389069], [92.98916626, 13.57417107], [92.99028015, 13.57417107], [92.9908371, 13.57361031], [92.9908371, 13.57305431], [92.99138641, 13.57249069], [92.9916687, 13.57250023], [92.99305725, 13.57110977], [92.99360657, 13.57056141], [92.99333191, 13.57028008], [92.99360657, 13.56999969], [92.99360657, 13.56972027], [92.99388885, 13.5694437], [92.99388885, 13.56916809], [92.99415588, 13.56888962], [92.99415588, 13.56861019], [92.99388885, 13.56833363], [92.99388885, 13.56805611], [92.99360657, 13.56777954], [92.99360657, 13.56750202], [92.99305725, 13.56693935], [92.99305725, 13.56611156], [92.99388885, 13.56527805], [92.99415588, 13.56527996], [92.9944458, 13.56499958], [92.99472046, 13.56499958], [92.99500275, 13.5647192], [92.99610901, 13.56472206], [92.9963913, 13.56444359], [92.99666595, 13.56416798], [92.99694824, 13.56417179], [92.99777985, 13.56333065], [92.99944305, 13.5616684], [92.99944305, 13.56139183], [92.99973297, 13.56111145], [93.0, 13.56139183], [93.00110626, 13.56139183], [93.00138855, 13.5616703], [93.00164795, 13.5616703], [93.00193787, 13.56139183], [93.00222015, 13.56139183], [93.0027771, 13.56083107], [93.0027771, 13.56055546], [93.00305176, 13.56027699], [93.00305176, 13.56000233], [93.00332642, 13.55972099], [93.00333405, 13.55916691], [93.0036087, 13.55888939], [93.00374603, 13.55833054], [93.00415802, 13.55749702], [93.0047226, 13.55708218], [93.00518799, 13.55643463], [93.00556183, 13.55556202], [93.00602722, 13.55445194], [93.00624847, 13.55306244], [93.00630951, 13.55278111], [93.0063858, 13.55250072], [93.0063858, 13.55111122], [93.00666809, 13.55083466], [93.00666809, 13.55000114], [93.00694275, 13.5497179], [93.00694275, 13.54916668], [93.00723267, 13.54889107], [93.00723267, 13.54860973], [93.00749969, 13.54833221], [93.00749969, 13.5480566], [93.00771332, 13.54778099], [93.00771332, 13.54743195], [93.00771332, 13.54667091], [93.00778198, 13.54639053], [93.00772858, 13.5461216], [93.00765991, 13.54571056], [93.00752258, 13.54522991], [93.00737762, 13.5446806], [93.00744629, 13.54433918], [93.00772858, 13.54433727], [93.00801086, 13.54461098], [93.00829315, 13.54496193], [93.00871277, 13.54522991], [93.00913239, 13.54522991], [93.00948334, 13.54502106], [93.00971985, 13.5447216], [93.00971985, 13.54444408], [93.00944519, 13.54416561], [93.00945282, 13.54389], [93.00850677, 13.54375076], [93.00836945, 13.54327011], [93.00850677, 13.54292202], [93.0087204, 13.54230404], [93.00900269, 13.54216957], [93.00969696, 13.54203129], [93.01011658, 13.54195976], [93.01026154, 13.54203129], [93.0103302, 13.54223633], [93.01011658, 13.54244137], [93.00991058, 13.54257965], [93.00984192, 13.54292202], [93.00984192, 13.5432682], [93.01004791, 13.54354382], [93.01052856, 13.54380417], [93.01068878, 13.54389], [93.01158905, 13.54388618], [93.01187134, 13.5439539], [93.01229095, 13.54409313], [93.01276398, 13.54407883], [93.01304626, 13.54401112], [93.01332092, 13.54366684], [93.01360321, 13.5434618], [93.01436615, 13.5434618], [93.01444244, 13.54359913], [93.01444244, 13.54386997], [93.01423645, 13.54415035], [93.01409149, 13.54456043], [93.01381683, 13.54476833], [93.01352692, 13.54504108], [93.01346588, 13.54532242], [93.01352692, 13.54580021], [93.01381683, 13.54628086], [93.01381683, 13.54649067], [93.01374817, 13.54682827], [93.01369476, 13.54732513], [93.01405334, 13.54780102], [93.014328, 13.54801083], [93.01461029, 13.54849243], [93.01495361, 13.5490427], [93.01529694, 13.54945087], [93.01551819, 13.54987144], [93.01551819, 13.55049133], [93.0152359, 13.55097198], [93.01502991, 13.5515871], [93.01481628, 13.5522728], [93.01467896, 13.55282211], [93.01467896, 13.55399132], [93.01461029, 13.55447006], [93.0147171, 13.55500126], [93.01444244, 13.55527687], [93.01444244, 13.55611134], [93.01416779, 13.55638885], [93.01416779, 13.55694485], [93.01448822, 13.55710506], [93.01462555, 13.55724144], [93.01483917, 13.55724144], [93.01504517, 13.55717278], [93.01547241, 13.55689716], [93.01596069, 13.55696964], [93.01602936, 13.55731201], [93.01624298, 13.55786133], [93.01638031, 13.55820274], [93.01659393, 13.55875492], [93.0166626, 13.55944061], [93.01694489, 13.55999184], [93.01694489, 13.56054211], [93.01686859, 13.5610199], [93.01673126, 13.56171131], [93.01686859, 13.5623312], [93.01715088, 13.56253624], [93.01715088, 13.56322193], [93.01701355, 13.56356621], [93.0166626, 13.56363392], [93.01624298, 13.56336117], [93.01609802, 13.56308079], [93.01624298, 13.562397], [93.01602936, 13.56163979], [93.01582336, 13.56067753], [93.01596069, 13.56019974], [93.01574707, 13.55950928], [93.01560974, 13.55869102], [93.01539612, 13.55834007], [93.0149765, 13.55841064], [93.01477051, 13.55862045], [93.01477051, 13.55950928], [93.01462555, 13.55971718], [93.01441956, 13.5598526], [93.01441956, 13.56047058], [93.01435089, 13.56115913], [93.01444244, 13.56194115], [93.01444244, 13.56250191], [93.0147171, 13.56278038], [93.0147171, 13.56361198], [93.01499939, 13.56389046], [93.01499939, 13.56416798], [93.01527405, 13.56444359], [93.01526642, 13.5647192], [93.01555634, 13.56499958], [93.01555634, 13.56527996], [93.01583099, 13.56556034], [93.01583099, 13.56639004], [93.01611328, 13.56666565], [93.01611328, 13.56722164], [93.01659393, 13.56777763], [93.01667023, 13.5694437], [93.01638794, 13.56972027], [93.01638794, 13.56999969], [93.01611328, 13.57028008], [93.01611328, 13.57056141], [93.01721954, 13.57167053], [93.01750183, 13.57166576], [93.01805878, 13.57222176], [93.01805878, 13.57250023], [93.01916504, 13.57361031], [93.01944733, 13.57361031], [93.01972198, 13.57333374], [93.01999664, 13.57333374], [93.02027893, 13.57305431], [93.02054596, 13.57306099], [93.02083588, 13.57278061], [93.02333069, 13.57278061], [93.02443695, 13.57389069], [93.02444458, 13.57500076], [93.02500153, 13.57555199], [93.02500153, 13.57638931], [93.02555847, 13.5769453], [93.02555847, 13.57721996], [93.02610779, 13.57777882], [93.02610779, 13.57833004], [93.02639008, 13.57861137], [93.02694702, 13.57917118], [93.02722168, 13.57917118], [93.02805328, 13.57833004], [93.02805328, 13.57805538], [93.02861023, 13.5775013], [93.02861023, 13.57721996], [93.02889252, 13.5769453], [93.02889252, 13.57666683], [93.02916718, 13.57639122], [93.02916718, 13.57611275], [93.02944183, 13.57583046], [93.02944183, 13.5741663], [93.02916718, 13.57389069], [93.02916718, 13.57361031], [93.02944183, 13.57333374], [93.02944183, 13.57250023], [93.02972412, 13.57222176], [93.02972412, 13.57166576], [93.02999878, 13.57139015], [93.02999878, 13.57083035], [93.03028107, 13.57055569], [93.03028107, 13.57028008], [93.03056335, 13.56999969], [93.03056335, 13.56943035], [93.03083038, 13.56916809], [93.03083038, 13.56888962], [93.03111267, 13.56861019], [93.03111267, 13.56833363], [93.03138733, 13.56805611], [93.03138733, 13.56777954], [93.03166962, 13.56750202], [93.03166962, 13.56722164], [93.03194427, 13.56694412], [93.03194427, 13.56666565], [93.03250122, 13.56610966], [93.03250122, 13.56583405], [93.03305817, 13.56527805], [93.03305817, 13.5647192], [93.03333282, 13.56444359], [93.03333282, 13.56416798], [93.03360748, 13.56389046], [93.03360748, 13.56305981], [93.03388977, 13.56278038], [93.03388977, 13.5616703], [93.0341568, 13.56139183], [93.0341568, 13.56083107], [93.03444672, 13.56055546], [93.03444672, 13.56000233], [93.03472137, 13.55972099], [93.03472137, 13.55888939], [93.03501129, 13.55861092], [93.03500366, 13.5577774], [93.03527832, 13.55749035], [93.03527832, 13.55694485], [93.03555298, 13.55666733], [93.03555298, 13.55583096], [93.03583527, 13.55555534], [93.0358429, 13.55500126], [93.03610992, 13.55472088], [93.03610992, 13.55444527], [93.03639221, 13.55417061], [93.03639221, 13.5536108], [93.03666687, 13.55333328], [93.03666687, 13.55305481], [93.03694153, 13.55278111], [93.03694153, 13.55250072], [93.03833008, 13.55111122], [93.03833008, 13.55083466], [93.03861237, 13.55055523], [93.03861237, 13.55028057], [93.03888702, 13.55000114], [93.03888702, 13.54944038], [93.03916931, 13.54916668], [93.03916931, 13.54860973], [93.03943634, 13.54832077], [93.03944397, 13.54749966], [93.03971863, 13.54722023], [93.03971863, 13.54555416], [93.03944397, 13.5452776], [93.03943634, 13.5447197], [93.03971863, 13.54444408], [93.03971863, 13.54388809], [93.04000092, 13.54360962], [93.04000092, 13.54305553], [93.0402832, 13.54277992], [93.0402832, 13.54222202], [93.04055786, 13.54194355], [93.04055786, 13.54111195], [93.04083252, 13.54083157], [93.04125214, 13.53770161], [93.04138947, 13.53666782], [93.04138947, 13.53583145], [93.04166412, 13.53555584], [93.04165649, 13.53417015], [93.04194641, 13.53389168], [93.04194641, 13.5336113], [93.04222107, 13.53333282], [93.04222107, 13.53305531], [93.04250336, 13.53277969], [93.04250336, 13.53249931], [93.04389191, 13.53111076], [93.04389191, 13.53083134], [93.04444122, 13.53027916], [93.04444122, 13.52972126], [93.04472351, 13.52944469], [93.04472351, 13.52611065], [93.04499817, 13.52583027], [93.04499817, 13.52527905], [93.04471588, 13.52500057], [93.04471588, 13.52472115], [93.04444122, 13.52444458], [93.04444122, 13.52416706], [93.04418182, 13.52389145], [93.04418182, 13.52361107], [93.04389191, 13.5233326], [93.04389191, 13.52277946], [93.04360962, 13.52250099], [93.04360962, 13.52221966], [93.04277802, 13.52138805], [93.04277802, 13.52110958], [93.04305267, 13.52083206], [93.04305267, 13.5205574], [93.04250336, 13.52000046], [93.04250336, 13.51861], [93.04277802, 13.51834106], [93.04277802, 13.51721954], [93.04305267, 13.51694393], [93.04305267, 13.51611233], [93.04333496, 13.51583195], [93.04333496, 13.51527786], [93.04360962, 13.51500034], [93.04360962, 13.51249981], [93.04332733, 13.51220989], [93.04333496, 13.51111221], [93.04305267, 13.51083374], [93.04305267, 13.50805473], [93.04332733, 13.50778198], [93.04332733, 13.50694084], [93.04360962, 13.50666714], [93.04360962, 13.50527859], [93.04305267, 13.50472069], [93.04305267, 13.5041666], [93.04277802, 13.50389099], [93.04277802, 13.50333977], [93.04222107, 13.50278187], [93.04222107, 13.50250053], [93.04194641, 13.50222111], [93.04194641, 13.50194454], [93.04138947, 13.50138855], [93.04138947, 13.50111103], [93.04083252, 13.50056171], [93.04083252, 13.5002718], [93.04027557, 13.49972343], [93.04027557, 13.49916744], [93.04000092, 13.49889088], [93.04000092, 13.49528122], [93.0402832, 13.49500275], [93.0402832, 13.49472046], [93.04055786, 13.49444389], [93.04055786, 13.49416637], [93.04083252, 13.49389076], [93.04083252, 13.49361038], [93.04111481, 13.49333191], [93.04111481, 13.4930563], [93.04138947, 13.49278069], [93.04110718, 13.49250031], [93.04110718, 13.49193954], [93.04083252, 13.49166584], [93.04083252, 13.49110985], [93.04055786, 13.49083424], [93.04055786, 13.49027824], [93.0402832, 13.48999977], [93.0402832, 13.48972034], [93.04000092, 13.48944378], [93.04000092, 13.48750019], [93.03971863, 13.48721981], [93.03971863, 13.48666573], [93.03888702, 13.48582935], [93.03861237, 13.48583412], [93.03805542, 13.48527813], [93.03778076, 13.48527813], [93.03749847, 13.48499966], [93.03721619, 13.48499966], [93.03659058, 13.48468971], [93.03617096, 13.48456001], [93.03582001, 13.48456001], [93.03568268, 13.48442078], [93.03555298, 13.48416805], [93.03527832, 13.48388958], [93.03527832, 13.4836092], [93.03500366, 13.48333359], [93.03500366, 13.4827776], [93.03527832, 13.48250198], [93.03527832, 13.48194122], [93.03583527, 13.48139], [93.03666687, 13.48139191], [93.03743744, 13.48108196], [93.0375824, 13.48108196], [93.03785706, 13.48094463], [93.03793335, 13.48073959], [93.03785706, 13.48019123], [93.03785706, 13.47970963], [93.0375824, 13.47929955], [93.03723145, 13.47900963], [93.03666687, 13.47833347], [93.03639221, 13.47833347], [93.03527832, 13.4772234], [93.03527832, 13.47694302], [93.03500366, 13.4766674], [93.03501129, 13.47639084], [93.03472137, 13.47611141], [93.03472137, 13.47416687], [93.03501129, 13.47389126], [93.03501129, 13.47333145], [93.03527832, 13.47305489], [93.03527832, 13.47194004], [93.03555298, 13.47166729], [93.03555298, 13.47056103], [93.03501129, 13.47000122], [93.03500366, 13.46972275], [93.03444672, 13.46916676], [93.03444672, 13.46723175], [93.0341568, 13.46693993], [93.03416443, 13.46638775], [93.03360748, 13.46582985], [93.03333282, 13.46583366], [93.03194427, 13.46444416], [93.03166962, 13.46444416], [93.03138733, 13.46472168], [93.03111267, 13.46444416], [93.03083038, 13.46444416], [93.03055573, 13.46472168], [93.02999878, 13.46471977], [93.02916718, 13.46556091], [93.02889252, 13.46555424], [93.02861023, 13.46583366], [93.02777863, 13.46583366], [93.02749634, 13.46611023], [93.02722168, 13.46611023], [93.02694702, 13.46639061], [93.02639008, 13.46639061], [93.02610779, 13.46667099], [93.02583313, 13.46666622], [93.02555847, 13.46694374], [93.02527618, 13.46693993], [93.02500153, 13.46723175], [93.02471924, 13.46723175], [93.02443695, 13.46750069], [93.02388763, 13.46750069], [93.02361298, 13.46723175], [93.02278137, 13.46723175], [93.02249908, 13.46693993], [93.02194214, 13.46694374], [93.02166748, 13.46666622], [93.02083588, 13.46667099], [93.02054596, 13.46639061], [93.02027893, 13.46639061], [93.0200119, 13.46611023], [93.01944733, 13.46611023], [93.01889038, 13.46555424], [93.01889038, 13.46500015], [93.01860809, 13.46471977], [93.01860809, 13.46388817], [93.01917267, 13.46333027], [93.02055359, 13.46333408], [93.02083588, 13.46305561], [93.02139282, 13.46306133], [93.02166748, 13.46278], [93.0222168, 13.46278], [93.02249908, 13.46249962], [93.02278137, 13.46249962], [93.02307129, 13.46222019], [93.02333069, 13.4622221], [93.02361298, 13.46194363], [93.02388763, 13.46194363], [93.02416992, 13.46166611], [93.02471924, 13.46166992], [93.02500153, 13.46138954], [93.0266571, 13.46138954], [93.02694702, 13.46166992], [93.02749634, 13.46166992], [93.02777863, 13.46138954], [93.02805328, 13.46138954], [93.02861023, 13.46083164], [93.02919006, 13.46073818], [93.02967072, 13.4605608], [93.02999115, 13.46018028], [93.03040314, 13.45983124], [93.03073883, 13.45939445], [93.03108215, 13.45894909], [93.03098297, 13.45870972], [93.03098297, 13.45829105], [93.03111267, 13.45815563], [93.03166962, 13.45823097], [93.03188324, 13.45823097], [93.03217316, 13.45835018], [93.03264618, 13.45808315], [93.03273773, 13.4580307], [93.03324127, 13.45759964], [93.03359985, 13.45695019], [93.03388977, 13.45625973], [93.03411865, 13.45558071], [93.03424072, 13.45488071], [93.03463745, 13.45427036], [93.03542328, 13.45328999], [93.03569031, 13.45259953], [93.0359726, 13.45218945], [93.03569031, 13.45137119], [93.03542328, 13.45102024], [93.03520203, 13.45102024], [93.03491974, 13.4514904], [93.03485107, 13.45239735], [93.03463745, 13.4527998], [93.03414917, 13.45296192], [93.03392792, 13.45286369], [93.03379822, 13.45280933], [93.03344727, 13.45205307], [93.0333786, 13.45170784], [93.03344727, 13.45109081], [93.03394318, 13.45068073], [93.03443146, 13.45040035], [93.03472137, 13.44999886], [93.03472137, 13.44889069], [93.03501129, 13.44861126], [93.03500366, 13.44833279], [93.03516388, 13.44782734], [93.03515625, 13.44658947], [93.03530121, 13.44604015], [93.03543091, 13.44501019], [93.03588104, 13.44417953], [93.03593445, 13.44342613], [93.0358429, 13.44278145], [93.0358429, 13.44250107], [93.03555298, 13.44221973], [93.03555298, 13.44194508], [93.03527832, 13.4416666], [93.03527832, 13.44139099], [93.03501129, 13.44110966], [93.03500366, 13.44083214], [93.03472137, 13.44055653], [93.03472137, 13.43999958], [93.03444672, 13.43972015], [93.03444672, 13.4375], [93.03472137, 13.43721962], [93.03472137, 13.43527794], [93.0341568, 13.43472195], [93.03416443, 13.43444443], [93.03305817, 13.43333435], [93.03305817, 13.43305588], [93.03277588, 13.43278027], [93.03250122, 13.43278027], [93.03221893, 13.43250179], [93.03166962, 13.43250179], [93.03111267, 13.43306065], [93.03083038, 13.43305588], [93.03055573, 13.43333435], [93.02999878, 13.43332863], [93.02971649, 13.43360996], [93.02889252, 13.43360996], [93.02861023, 13.43389034], [93.0266571, 13.43389034], [93.02639008, 13.43360996], [93.02555847, 13.43360996], [93.02527618, 13.43332863], [93.02416992, 13.43333435], [93.02406311, 13.43322945], [93.02388763, 13.43305588], [93.02278137, 13.43306065], [93.0222168, 13.43278027], [93.02111053, 13.43167019], [93.02111053, 13.43112087], [93.02166748, 13.43056011], [93.02194214, 13.43056011], [93.0222168, 13.43027973], [93.02278137, 13.43027973], [93.02307129, 13.43000031], [93.02333069, 13.43000031], [93.02361298, 13.42972183], [93.02388763, 13.42972183], [93.02416992, 13.42944431], [93.02471924, 13.42944431], [93.02500153, 13.42916775], [93.02527618, 13.42916965], [93.02555847, 13.42889023], [93.02581787, 13.42889023], [93.02610779, 13.42860889], [93.02639008, 13.42861176], [93.02666473, 13.42833424], [93.02722168, 13.42833424], [93.02749634, 13.42805576], [93.02916718, 13.42805958], [93.02944183, 13.42778015], [93.03028107, 13.42778015], [93.03166962, 13.4263916], [93.03166962, 13.42583084], [93.03277588, 13.42472267], [93.03416443, 13.42472267], [93.03444672, 13.42499924], [93.03472137, 13.42499924], [93.03555298, 13.42583275], [93.0358429, 13.42583084], [93.03666687, 13.42667198], [93.03694153, 13.42666531], [93.03722382, 13.42694569], [93.03833008, 13.42694092], [93.03873444, 13.42694569], [93.03903198, 13.42695045], [93.03913879, 13.42688179], [93.0395813, 13.42660427], [93.03993225, 13.42653847], [93.04042053, 13.42654037], [93.04070282, 13.4263916], [93.04083252, 13.42583275], [93.04055786, 13.42555523], [93.04055786, 13.42472076], [93.04027557, 13.42444324], [93.04027557, 13.42388916], [93.04000092, 13.42361069], [93.04000092, 13.42333126], [93.03916931, 13.4224987], [93.03888702, 13.42250061], [93.03833008, 13.42192936], [93.03805542, 13.42194462], [93.03778076, 13.4216671], [93.03778076, 13.42139053], [93.03749847, 13.42111111], [93.03749847, 13.42083263], [93.03722382, 13.42055511], [93.03721619, 13.42028141], [93.03694153, 13.42000103], [93.03694153, 13.41972065], [93.03666687, 13.41944504], [93.03666687, 13.41861057], [93.03639221, 13.41833305], [93.03639221, 13.41666698], [93.03778076, 13.4152813], [93.04000092, 13.4152813], [93.04083252, 13.41444016], [93.04083252, 13.41416645], [93.04165649, 13.41333008], [93.04194641, 13.41333199], [93.04333496, 13.41194439], [93.04360962, 13.41194439], [93.04499817, 13.41055584], [93.04499817, 13.41028118], [93.04528046, 13.40999126], [93.04528046, 13.40888786], [93.04499817, 13.40861034], [93.04499817, 13.40833378], [93.04472351, 13.40805626], [93.04471588, 13.40777969], [93.04418182, 13.40722179], [93.04416656, 13.4058342], [93.04444122, 13.40555573], [93.04444122, 13.40471935], [93.04528046, 13.40388775], [93.04695129, 13.40388966], [93.04724121, 13.40418243], [93.04777527, 13.40416622], [93.04805756, 13.40444374], [93.0486145, 13.40444374], [93.04888916, 13.40472221], [93.04915619, 13.40471935], [93.04944611, 13.40499973], [93.04972076, 13.40499973], [93.04998779, 13.40528011], [93.05027771, 13.40528011], [93.05055237, 13.40555954], [93.05082703, 13.40555954], [93.05222321, 13.40695095], [93.05222321, 13.40722179], [93.05278015, 13.40777969], [93.05278015, 13.40805626], [93.05305481, 13.40833378], [93.05304718, 13.40861034], [93.0533371, 13.40888786], [93.0533371, 13.40944386], [93.05361176, 13.40972233], [93.05361176, 13.40999985], [93.05444336, 13.41083431], [93.05473328, 13.41082954], [93.05500031, 13.41110992], [93.05555725, 13.41110992], [93.05583191, 13.4113903], [93.0561142, 13.4113903], [93.0569458, 13.41222], [93.0569458, 13.41250038], [93.05750275, 13.41305733], [93.05750275, 13.41333199], [93.0577774, 13.41361046], [93.0577774, 13.41389084], [93.05805206, 13.41417122], [93.05805206, 13.41555691], [93.05832672, 13.41582966], [93.05833435, 13.41638947], [93.0588913, 13.41694546], [93.0588913, 13.41722107], [93.05918121, 13.41750145], [93.05916595, 13.41805458], [93.05944824, 13.41833305], [93.05944824, 13.41861057], [93.0597229, 13.41888905], [93.0597229, 13.41944027], [93.06054688, 13.42028141], [93.06062317, 13.42049122], [93.06083679, 13.42089939], [93.06138611, 13.42111111], [93.06152344, 13.42107677], [93.0616684, 13.42103958], [93.06212616, 13.42076015], [93.06253052, 13.42035198], [93.06271362, 13.41985703], [93.06263733, 13.41930103], [93.0625, 13.41805935], [93.0625, 13.41778088], [93.06236267, 13.41742992], [93.06221771, 13.41666889], [93.06221771, 13.41639137], [93.06221771, 13.41611958], [93.06208801, 13.41582966], [93.06194305, 13.41555691], [93.06181335, 13.4152813], [93.06138611, 13.41471958], [93.06138611, 13.41416645], [93.06124878, 13.4137516], [93.06111145, 13.41083431], [93.06083679, 13.41055584], [93.06083679, 13.40944195], [93.0605545, 13.40916634], [93.06054688, 13.40833187], [93.06027985, 13.40805626], [93.06027985, 13.40722179], [93.05999756, 13.40695095], [93.05999756, 13.40582943], [93.06027985, 13.40555573], [93.06027985, 13.40528011], [93.06054688, 13.40499973], [93.06054688, 13.40388966], [93.05918121, 13.40250015], [93.05916595, 13.40222168], [93.0588913, 13.40194321], [93.0588913, 13.40083408], [93.05944824, 13.40027714], [93.05944824, 13.39972115], [93.0597229, 13.39944553], [93.0597229, 13.39916706], [93.06027985, 13.39861107], [93.06054688, 13.39861107], [93.06083679, 13.39888859], [93.06111145, 13.39888859], [93.06221771, 13.40000153], [93.06221771, 13.40056038], [93.06276703, 13.4011116], [93.06277466, 13.40166759], [93.0633316, 13.40222168], [93.0633316, 13.40250015], [93.06388855, 13.40305614], [93.06388855, 13.4033289], [93.06582642, 13.40528011], [93.06639099, 13.40528011], [93.06666565, 13.40555573], [93.06694794, 13.4058342], [93.06749725, 13.4058342], [93.06777954, 13.40610981], [93.06835175, 13.40610981], [93.06916809, 13.40695095], [93.06944275, 13.40695095], [93.06999969, 13.40750027], [93.07026672, 13.40750027], [93.07055664, 13.40722179], [93.07055664, 13.40695095], [93.0708313, 13.40666962], [93.0708313, 13.40610981], [93.07027435, 13.40555573], [93.07026672, 13.40499973], [93.06999969, 13.40471935], [93.06999969, 13.40388775], [93.06973267, 13.40361023], [93.06972504, 13.40333366], [93.06916809, 13.40277767], [93.06916809, 13.40250015], [93.0688858, 13.40222168], [93.0688858, 13.40194321], [93.06861115, 13.40166759], [93.0688858, 13.40139198], [93.06859589, 13.40063953], [93.0688858, 13.4001627], [93.06881714, 13.39954376], [93.06846619, 13.39919853], [93.06832886, 13.39878178], [93.06846619, 13.39837742], [93.06902313, 13.39817142], [93.06909943, 13.39789104], [93.06916809, 13.39749908], [93.0688858, 13.3968792], [93.06832886, 13.396451], [93.06809235, 13.396492], [93.06796265, 13.39622116], [93.06754303, 13.3958807], [93.06732178, 13.39531994], [93.06690216, 13.39511108], [93.06641388, 13.39497757], [93.06556702, 13.39490986], [93.06479645, 13.39442921], [93.0642395, 13.39395142], [93.06395721, 13.3933897], [93.06388855, 13.39277744], [93.0625, 13.39138889], [93.06173706, 13.39140511], [93.06144714, 13.39147091], [93.06124878, 13.39167786], [93.06096649, 13.39202023], [93.06075287, 13.39229965], [93.05983734, 13.39229965], [93.05948639, 13.39207935], [93.0592804, 13.39181709], [93.05879211, 13.39181709], [93.05850983, 13.39188576], [93.0583725, 13.39195156], [93.05815887, 13.39229965], [93.05795288, 13.39264011], [93.05773926, 13.39278126], [93.05738831, 13.39299107], [93.05634308, 13.39299107], [93.05623627, 13.39290714], [93.05599213, 13.39271069], [93.05591583, 13.39250088], [93.05564117, 13.3920908], [93.05555725, 13.39166737], [93.05555725, 13.39111137], [93.05527496, 13.3908329], [93.05527496, 13.39055538], [93.05473328, 13.3900013], [93.05388641, 13.3900013], [93.05354309, 13.39037037], [93.05339813, 13.39072132], [93.05311584, 13.39106274], [93.05291748, 13.3911314], [93.0525589, 13.3911314], [93.05249023, 13.39058018], [93.05249023, 13.38982105], [93.05235291, 13.38954735], [93.05232239, 13.38907146], [93.05194092, 13.38861275], [93.05194092, 13.38778114], [93.05166626, 13.38750076], [93.05166626, 13.38694], [93.0513916, 13.3866663], [93.0513916, 13.38556099], [93.05110931, 13.38528061], [93.05110931, 13.38444042], [93.05083466, 13.38416576], [93.05082703, 13.38360977], [93.05110931, 13.38333035], [93.05110931, 13.38277817], [93.05082703, 13.38249969], [93.05082703, 13.38138962], [93.05055237, 13.38111019], [93.05055237, 13.38055611], [93.05027771, 13.38027954], [93.05027771, 13.3800106], [93.04998779, 13.37971973], [93.05000305, 13.37944412], [93.04972076, 13.37916565], [93.04972076, 13.37889004], [93.04944611, 13.37860966], [93.04944611, 13.37833405], [93.04916382, 13.37805557], [93.04915619, 13.37749958], [93.04895782, 13.3772192], [93.04902649, 13.3763876], [93.04902649, 13.37611198], [93.04910278, 13.37569046], [93.04902649, 13.37527847], [93.04888916, 13.37472057], [93.0486145, 13.37441444], [93.04826355, 13.37441444], [93.04805756, 13.37448215], [93.0477066, 13.37460995], [93.04742432, 13.37516975], [93.04721832, 13.37558079], [93.04679108, 13.37633991], [93.0462265, 13.37667942], [93.04580688, 13.37689114], [93.04524994, 13.37703037], [93.04483032, 13.37703037], [93.04434204, 13.37689114], [93.04377747, 13.37655163], [93.04328918, 13.37655163], [93.04266357, 13.37623882], [93.04244995, 13.37613201], [93.04230499, 13.37572002], [93.04189301, 13.37537956], [93.04174805, 13.37516975], [93.0412674, 13.37489891], [93.04006195, 13.3748951], [93.03901672, 13.37510204], [93.03837585, 13.37510014], [93.03768158, 13.37524128], [93.03704834, 13.37524128], [93.03627777, 13.37544632], [93.03543854, 13.3755827], [93.03431702, 13.37551498], [93.03368378, 13.37544632], [93.03256226, 13.37524128], [93.03144073, 13.37476921], [93.03003693, 13.37413979], [93.0289917, 13.37386036], [93.02877808, 13.37358856], [93.02828979, 13.37318134], [93.02864075, 13.37310791], [93.02906036, 13.37310791], [93.03011322, 13.3735199], [93.03277588, 13.37434483], [93.03466797, 13.37455082], [93.03592682, 13.37469196], [93.03704834, 13.37469196], [93.03775024, 13.37434959], [93.03852081, 13.37400055], [93.03957367, 13.37379646], [93.04020691, 13.37380123], [93.04132843, 13.37359142], [93.04238129, 13.37366199], [93.04322052, 13.37379646], [93.04412842, 13.37400055], [93.04489899, 13.37434483], [93.04511261, 13.37460995], [93.04560089, 13.37516975], [93.04588318, 13.37516975], [93.0461731, 13.37489891], [93.0463028, 13.37469196], [93.04707336, 13.37421131], [93.0477066, 13.37400055], [93.04798889, 13.37386513], [93.04840851, 13.3737278], [93.04911041, 13.37393093], [93.04916382, 13.37416458], [93.04972076, 13.37472057], [93.05007172, 13.37666798], [93.05117798, 13.37785339], [93.05166626, 13.37833405], [93.05194092, 13.37860966], [93.05194092, 13.37889004], [93.05222321, 13.37916565], [93.05222321, 13.37943935], [93.05278015, 13.3800106], [93.05278015, 13.38027763], [93.0533371, 13.38083363], [93.0533371, 13.3811121], [93.0541687, 13.3819437], [93.05444336, 13.3819437], [93.05472565, 13.38222218], [93.05527496, 13.38222218], [93.05583191, 13.38166809], [93.05583191, 13.38138962], [93.05612183, 13.38111019], [93.0561142, 13.38083363], [93.05638885, 13.38055611], [93.05638885, 13.38027954], [93.05722046, 13.37943935], [93.05722046, 13.37889004], [93.05750275, 13.37860966], [93.05750275, 13.37833405], [93.0577774, 13.37805557], [93.0577774, 13.37777996], [93.05805206, 13.37749958], [93.05805206, 13.3772192], [93.05833435, 13.37694359], [93.05833435, 13.3763876], [93.05860901, 13.37611198], [93.05860901, 13.37583065], [93.0588913, 13.37555599], [93.0588913, 13.37528038], [93.05918121, 13.37500191], [93.05918121, 13.37472057], [93.05944824, 13.37444305], [93.05944824, 13.37416458], [93.0597229, 13.37388039], [93.0597229, 13.37194538], [93.05999756, 13.37166691], [93.05999756, 13.37084007], [93.06027985, 13.37055969], [93.06027985, 13.36972141], [93.0605545, 13.36944485], [93.0605545, 13.36916733], [93.06083679, 13.36889076], [93.06083679, 13.36861134], [93.06138611, 13.36805534], [93.06138611, 13.36750126], [93.0619278, 13.36694145], [93.06194305, 13.36555481], [93.06221771, 13.36528111], [93.06221771, 13.36250114], [93.0625, 13.3622179], [93.0625, 13.36166668], [93.06276703, 13.36139107], [93.06276703, 13.36083031], [93.06305695, 13.3605566], [93.0633316, 13.36056137], [93.06360626, 13.36028099], [93.06388855, 13.36028099], [93.06416321, 13.36000061], [93.06472015, 13.36000061], [93.06555176, 13.35917091], [93.06555176, 13.35890198], [93.06582642, 13.35861015], [93.06583405, 13.35833359], [93.0661087, 13.35805416], [93.0661087, 13.35778141], [93.06639099, 13.35750008], [93.06639099, 13.35694027], [93.06666565, 13.35666561], [93.06667328, 13.35639], [93.06694794, 13.35610962], [93.06694794, 13.3558321], [93.06749725, 13.35527992], [93.06749725, 13.35499954], [93.06806183, 13.35444164], [93.0680542, 13.35388756], [93.06835175, 13.35361195], [93.06833649, 13.35333443], [93.06861115, 13.35305595], [93.06861115, 13.35278034], [93.0688858, 13.35249996], [93.0688858, 13.35221958], [93.06916809, 13.35194397], [93.06916809, 13.35166645], [93.06973267, 13.35111046], [93.06972504, 13.35083389], [93.06999969, 13.35083389], [93.0708313, 13.35000038], [93.0708313, 13.34971046], [93.07111359, 13.34944439], [93.07111359, 13.3488903], [93.07138824, 13.34861183], [93.07138824, 13.34833145], [93.0716629, 13.34805584], [93.0716629, 13.34749889], [93.07213593, 13.34723091], [93.07248688, 13.34722614], [93.07298279, 13.34743118], [93.0736084, 13.34749889], [93.07389069, 13.34722137], [93.07416534, 13.34722137], [93.07472229, 13.34666538], [93.07499695, 13.34666538], [93.07527924, 13.34694576], [93.07583618, 13.34694099], [93.0759964, 13.34710979], [93.07658386, 13.3477726], [93.07720947, 13.34811687], [93.07770538, 13.34839344], [93.07833099, 13.34833431], [93.07888794, 13.34777832], [93.07888794, 13.34749889], [93.07861328, 13.34722137], [93.07861328, 13.34694576], [93.07805634, 13.34638977], [93.07805634, 13.3461113], [93.07777405, 13.34583282], [93.07777405, 13.34555531], [93.07749939, 13.34527969], [93.07749939, 13.34305954], [93.07776642, 13.34278202], [93.07776642, 13.34250069], [93.07861328, 13.34167194], [93.07888794, 13.34167194], [93.07917023, 13.34139061], [93.08416748, 13.34139061], [93.08444214, 13.34167194], [93.08472443, 13.34166718], [93.08499908, 13.34194469], [93.08499908, 13.34222126], [93.08555603, 13.34278202], [93.08555603, 13.34305477], [93.08583069, 13.34333324], [93.08609772, 13.34333134], [93.08638763, 13.34361076], [93.08666992, 13.34361076], [93.08693695, 13.34333134], [93.08761597, 13.34344864], [93.08802032, 13.34313869], [93.08837128, 13.3427906], [93.08864594, 13.3425169], [93.08872223, 13.34190178], [93.08872223, 13.34121132], [93.08885956, 13.34052277], [93.08899689, 13.3399744], [93.0894165, 13.3394928], [93.08984375, 13.33901215], [93.08998108, 13.33818722], [93.09004974, 13.33722115], [93.09026337, 13.33660507], [93.09059143, 13.33593273], [93.09017181, 13.3351717], [93.08953857, 13.33462048], [93.08891296, 13.33428955], [93.0880661, 13.33366108], [93.08722687, 13.33290195], [93.08560944, 13.33227921], [93.08358002, 13.33138847], [93.08055878, 13.33139133], [93.08029175, 13.33111], [93.07971954, 13.33111], [93.07943726, 13.33082962], [93.07888794, 13.33083439], [93.07861328, 13.33055592], [93.07805634, 13.33056068], [93.07749939, 13.32999992], [93.0772171, 13.32999992], [93.07692719, 13.32971954], [93.07666779, 13.3297224], [93.07611084, 13.32916641], [93.07611084, 13.32889938], [93.07554626, 13.32833195], [93.07555389, 13.32777786], [93.07527924, 13.32750034], [93.07527924, 13.32722187], [93.07305908, 13.32499981], [93.07305908, 13.32472038], [93.07277679, 13.32444382], [93.07277679, 13.3241663], [93.07250214, 13.32388973], [93.07250214, 13.32361031], [93.07221985, 13.32333374], [93.07221985, 13.32305622], [93.07195282, 13.32277107], [93.07194519, 13.32111168], [93.07221985, 13.32083416], [93.07221985, 13.31944561], [93.07250214, 13.31916809], [93.07250214, 13.31694126], [93.07221985, 13.3166666], [93.07221985, 13.31583118], [93.07194519, 13.31555462], [93.07195282, 13.31500053], [93.0716629, 13.31472111], [93.0716629, 13.31444454], [93.07138824, 13.31416702], [93.07138824, 13.31389141], [93.0708313, 13.31333065], [93.07111359, 13.31305504], [93.0708313, 13.31278133], [93.0708313, 13.31000137], [93.07055664, 13.30972099], [93.07055664, 13.30694485], [93.06999969, 13.3063879], [93.0688858, 13.30639076], [93.0687027, 13.30620384], [93.06861115, 13.30611038], [93.0680542, 13.30611038], [93.06777954, 13.30583191], [93.06749725, 13.30583191], [93.0672226, 13.30555439], [93.06694794, 13.30556107], [93.06667328, 13.30528069], [93.06667328, 13.30473137], [93.06639099, 13.30443954], [93.06639099, 13.30388832], [93.0661087, 13.30360985], [93.0661087, 13.30333424], [93.06583405, 13.30305576], [93.06534576, 13.30326366], [93.06492615, 13.30427074], [93.06458282, 13.30510139], [93.06416321, 13.30557919], [93.0636673, 13.30585098], [93.06305695, 13.30639076], [93.06291199, 13.30680561], [93.06276703, 13.30722046], [93.06276703, 13.30750275], [93.0633316, 13.30805683], [93.0633316, 13.30832958], [93.06361389, 13.30861092], [93.06360626, 13.30972099], [93.0633316, 13.31000137], [93.0633316, 13.31027889], [93.06270599, 13.31111145], [93.0625, 13.31138897], [93.06222534, 13.31201267], [93.0619278, 13.31228924], [93.06181335, 13.31256866], [93.0616684, 13.31278133], [93.0614624, 13.31354046], [93.06138611, 13.31555462], [93.06111145, 13.31611061], [93.06111145, 13.31639194], [93.06083679, 13.31667042], [93.06083679, 13.3197298], [93.06096649, 13.31993103], [93.06083679, 13.32028198], [93.06111145, 13.32056046], [93.06111145, 13.32139015], [93.06138611, 13.32166767], [93.06138611, 13.32221889], [93.0616684, 13.32250023], [93.0616684, 13.32444382], [93.06138611, 13.32472038], [93.06138611, 13.3255558], [93.06111145, 13.32583427], [93.06111145, 13.32694435], [93.06083679, 13.32722187], [93.06083679, 13.32805634], [93.0605545, 13.32833195], [93.06054688, 13.32861042], [93.05999756, 13.32917118], [93.0597229, 13.32916641], [93.05944824, 13.32944393], [93.05722046, 13.32944393], [93.0569458, 13.32916641], [93.05638885, 13.32917118], [93.05612183, 13.32889938], [93.05526733, 13.32889938], [93.05500031, 13.32861042], [93.05472565, 13.32861233], [93.05444336, 13.32833195], [93.0541687, 13.32833195], [93.05394745, 13.32811069], [93.05361176, 13.32777786], [93.0533371, 13.32777977], [93.05278015, 13.32722187], [93.05249786, 13.32722187], [93.05207825, 13.32680321], [93.05166626, 13.32639027], [93.05166626, 13.32611179], [93.05110931, 13.32556057], [93.05110931, 13.32528019], [93.05055237, 13.32472038], [93.05055237, 13.32444382], [93.05027771, 13.3241663], [93.05027771, 13.32388973], [93.04915619, 13.32277107], [93.04888916, 13.32277775], [93.04777527, 13.32166767], [93.04750061, 13.32166958], [93.04695129, 13.32111168], [93.04666901, 13.32111168], [93.04638672, 13.3208313], [93.04611206, 13.32083416], [93.04520416, 13.32069206], [93.04333496, 13.32062435], [93.04277802, 13.32083416], [93.04250336, 13.3208313], [93.04222107, 13.32111168], [93.04194641, 13.32111168], [93.04165649, 13.32139015], [93.04138947, 13.32139015], [93.04110718, 13.32166958], [93.04083252, 13.32166767], [93.04055786, 13.32194424], [93.0402832, 13.32221889], [93.03985596, 13.32298088], [93.03971863, 13.3255558], [93.04000092, 13.32582855], [93.04000092, 13.32666588], [93.0402832, 13.32694244], [93.0402832, 13.32777977], [93.04055786, 13.32805634], [93.04055786, 13.32944393], [93.04083252, 13.32971954], [93.04083252, 13.33055592], [93.04110718, 13.33082962], [93.04110718, 13.33250046], [93.04138947, 13.33277893], [93.04138947, 13.33360958], [93.04110718, 13.33389091], [93.04111481, 13.33416653], [93.04138947, 13.334445], [93.04138947, 13.33833122], [93.04165649, 13.33861065], [93.04166412, 13.33916664], [93.04444122, 13.34194088], [93.04444122, 13.34250069], [93.04472351, 13.34277725], [93.04471588, 13.34333134], [93.04499817, 13.34361076], [93.04499817, 13.34416676], [93.04528046, 13.34444141], [93.04528046, 13.34499931], [93.04555511, 13.34527683], [93.04555511, 13.34583282], [93.04582977, 13.3461113], [93.04582977, 13.34722137], [93.04556274, 13.34749889], [93.04555511, 13.34805584], [93.04528046, 13.34833145], [93.04528046, 13.3488903], [93.04499817, 13.34916973], [93.04499817, 13.35055637], [93.04471588, 13.35083199], [93.04471588, 13.35139179], [93.04444122, 13.35166645], [93.04444122, 13.35221958], [93.04418182, 13.35249996], [93.04418182, 13.35278034], [93.04389191, 13.35306072], [93.04389191, 13.35361195], [93.04360962, 13.35388756], [93.04360962, 13.35472202], [93.04332733, 13.35499954], [93.04332733, 13.35527992], [93.04305267, 13.35556126], [93.04305267, 13.3558321], [93.04194641, 13.35694408], [93.04194641, 13.3572197], [93.04111481, 13.35805416], [93.04110718, 13.35832977], [93.04027557, 13.35916615], [93.0402832, 13.35943985], [93.03971863, 13.36000061], [93.03971863, 13.36028099], [93.03943634, 13.36056137], [93.03943634, 13.36110973], [93.03916931, 13.36139107], [93.03916931, 13.36166668], [93.03943634, 13.36194038], [93.03943634, 13.36278057], [93.03971863, 13.36305523], [93.03971863, 13.36361122], [93.04027557, 13.36416721], [93.04027557, 13.36444473], [93.04055786, 13.3647213], [93.04055786, 13.36500072], [93.04083252, 13.36528111], [93.04083252, 13.36555481], [93.04110718, 13.36583138], [93.04111481, 13.36638927], [93.04166412, 13.36694527], [93.04166412, 13.36722088], [93.04083252, 13.36722088], [93.04055786, 13.36694527], [93.04000092, 13.36694527], [93.03971863, 13.36666679], [93.03943634, 13.36667156], [93.03905487, 13.3662796], [93.0389328, 13.36615181], [93.03861237, 13.3661108], [93.03805542, 13.36555481], [93.03778076, 13.36556244], [93.03749847, 13.36528111], [93.03749847, 13.36500072], [93.03721619, 13.3647213], [93.03722382, 13.36388874], [93.03694153, 13.36361122], [93.03694153, 13.36333275], [93.03666687, 13.36305523], [93.03608704, 13.36312103], [93.03581238, 13.36312103], [93.03530884, 13.36292458], [93.03504181, 13.36248875], [93.03517914, 13.36201096], [93.03497314, 13.36146069], [93.03482819, 13.36118126], [93.03475952, 13.36083889], [93.03460693, 13.36063194], [93.0345459, 13.36049461], [93.03504181, 13.36063194], [93.03539276, 13.36077118], [93.03573608, 13.36083889], [93.03573608, 13.36118126], [93.03594971, 13.3615303], [93.03623199, 13.36180973], [93.03665161, 13.36208057], [93.03833008, 13.36028099], [93.03833008, 13.35972023], [93.03971863, 13.35833359], [93.03971863, 13.35805416], [93.04055786, 13.3572197], [93.04055786, 13.35694408], [93.04083252, 13.35666561], [93.04083252, 13.35639], [93.04110718, 13.35610962], [93.04111481, 13.3558321], [93.04138947, 13.35556126], [93.04138947, 13.35472202], [93.04166412, 13.35444355], [93.04166412, 13.35361195], [93.04138947, 13.35332966], [93.04138947, 13.35277843], [93.04110718, 13.35249996], [93.04110718, 13.3519392], [93.04083252, 13.35166645], [93.04083252, 13.35139179], [93.04000092, 13.35056019], [93.03971863, 13.35056019], [93.03943634, 13.35027981], [93.03861237, 13.35027981], [93.03833008, 13.35000038], [93.03804779, 13.35000038], [93.03794098, 13.34988308], [93.03778076, 13.34971046], [93.03694153, 13.34972191], [93.03666687, 13.34944439], [93.03500366, 13.34944439], [93.03472137, 13.34916782], [93.03444672, 13.34916973], [93.03396606, 13.34869099], [93.03360748, 13.34833145], [93.03360748, 13.34805584], [93.03320313, 13.34743118], [93.0331955, 13.34583282], [93.03278351, 13.34527493], [93.03202057, 13.3451376], [93.03083038, 13.34583282], [93.03055573, 13.34583282], [93.03028107, 13.3461113], [93.02916718, 13.3461113], [93.02889252, 13.34583282], [93.02861023, 13.34583282], [93.02805328, 13.34527683], [93.02777863, 13.34527969], [93.02749634, 13.34514141], [93.02722168, 13.34527493], [93.02639008, 13.34583282], [93.02639008, 13.3461113], [93.02610779, 13.34639168], [93.02610779, 13.34666538], [93.02583313, 13.34694576], [93.02581787, 13.34722137], [93.02500153, 13.34805965], [93.02471924, 13.34805584], [93.02443695, 13.34833145], [93.02416992, 13.34861183], [93.02388763, 13.34861183], [93.02361298, 13.3488903], [93.02249908, 13.3488903], [93.0222168, 13.34916973], [93.02166748, 13.34916782], [93.02138519, 13.34944439], [93.02083588, 13.34944439], [93.02055359, 13.34972191], [93.02027893, 13.34972191], [93.0200119, 13.35000038], [93.01944733, 13.35000038], [93.01917267, 13.35027981], [93.01889038, 13.35027981], [93.01860809, 13.35056019], [93.01832581, 13.35027981], [93.01805878, 13.35027981], [93.01750183, 13.34971046], [93.01721954, 13.34972191], [93.01694489, 13.34944439], [93.01583099, 13.34944057], [93.01499939, 13.35027981], [93.01499939, 13.35056019], [93.01416779, 13.35139179], [93.01387787, 13.35139179], [93.01361084, 13.35167027], [93.01333618, 13.35167027], [93.01249695, 13.35249996], [93.01194763, 13.35249996], [93.01167297, 13.35278034], [93.01081848, 13.35278034], [93.01055908, 13.35306072], [93.00749969, 13.35305595], [93.00722504, 13.35333443], [93.00554657, 13.35332966], [93.00527954, 13.35361195], [93.00501251, 13.35332966], [93.0047226, 13.35332966], [93.00444794, 13.35361195], [93.00416565, 13.35361195], [93.00389099, 13.35333443], [93.00333405, 13.35333443], [93.00250244, 13.35249996], [93.00250244, 13.35221958], [93.0019455, 13.35166645], [93.00164795, 13.35167027], [93.00138855, 13.35139179], [93.00110626, 13.35139179], [93.0008316, 13.35111046], [93.00055695, 13.35111237], [93.00027466, 13.35083389], [93.0, 13.35083389], [92.99848175, 13.34971714], [92.99828339, 13.34950066], [92.99804688, 13.34930038], [92.99777985, 13.34916782], [92.99666595, 13.34805965], [92.99666595, 13.34778023], [92.99500275, 13.3461113], [92.99472046, 13.3461113], [92.9944458, 13.34583282], [92.99416351, 13.34583282], [92.99305725, 13.34472084], [92.99262238, 13.34457111], [92.99225616, 13.34437275], [92.99196625, 13.34414005], [92.99173737, 13.34390068], [92.99156189, 13.34367085], [92.99140167, 13.34339046], [92.99107361, 13.34328079], [92.99079895, 13.34302998], [92.99046326, 13.34276962], [92.9901123, 13.3424511], [92.98983002, 13.34204102], [92.98960114, 13.34155464], [92.98937988, 13.34111309], [92.98917389, 13.34069633], [92.9890213, 13.34028053], [92.98889923, 13.3398962], [92.98880005, 13.3395319], [92.98863983, 13.33920956], [92.98861694, 13.338871], [92.98871613, 13.33851528], [92.98886108, 13.33810043], [92.98886108, 13.33764935], [92.98871613, 13.33720016], [92.98862457, 13.33677387], [92.98860931, 13.33636761], [92.98860931, 13.33597183], [92.98864746, 13.33557701], [92.98884583, 13.33518982], [92.9888916, 13.33477497], [92.9888916, 13.33437157], [92.9888916, 13.33400726], [92.9888916, 13.33368111], [92.98887634, 13.33335972], [92.9888916, 13.33303165], [92.98895264, 13.33265972], [92.98912048, 13.33226967], [92.98919678, 13.33175087], [92.98934937, 13.33119011], [92.98940277, 13.33065033], [92.98915863, 13.33018017], [92.98880768, 13.32977676], [92.98834991, 13.32947159], [92.98779297, 13.3293066], [92.98725891, 13.32916164], [92.98677826, 13.32901096], [92.9863205, 13.32889938], [92.98586273, 13.32889938], [92.98540497, 13.32892895], [92.98501587, 13.32914066], [92.98470306, 13.32934189], [92.98438263, 13.32944202], [92.98409271, 13.32954025], [92.98387909, 13.32976055], [92.98365784, 13.33000946], [92.98339844, 13.33028126], [92.98309326, 13.33056068], [92.98274994, 13.33088017], [92.98246002, 13.33128262], [92.98213196, 13.3316412], [92.98178864, 13.33195972], [92.98149109, 13.33226585], [92.98127747, 13.33262062], [92.98106384, 13.33297729], [92.98083496, 13.33333206], [92.98084259, 13.33360958], [92.98027802, 13.33416653], [92.98000336, 13.334445], [92.97972107, 13.33471107], [92.97972107, 13.33528137], [92.97944641, 13.33555698], [92.97944641, 13.33694458], [92.97956085, 13.33740139], [92.97961426, 13.33791637], [92.97966003, 13.33832073], [92.97949219, 13.33862019], [92.97941589, 13.3390007], [92.97924042, 13.33936977], [92.97897339, 13.33976173], [92.97866058, 13.34023094], [92.97834015, 13.3407402], [92.97803497, 13.34123611], [92.97767639, 13.34164047], [92.97730255, 13.34197903], [92.97696686, 13.34234047], [92.97672272, 13.34276104], [92.97666931, 13.343297], [92.97666168, 13.34383202], [92.9766922, 13.34432507], [92.97681427, 13.34472275], [92.97692871, 13.34508419], [92.97701263, 13.34543228], [92.97717285, 13.34570122], [92.97724152, 13.34599113], [92.97735596, 13.34623909], [92.97747803, 13.34645081], [92.97750092, 13.34669018], [92.97744751, 13.34697056], [92.97725677, 13.34729004], [92.97714996, 13.3476696], [92.97695923, 13.34801006], [92.97679901, 13.34833431], [92.97663116, 13.34863377], [92.97638702, 13.3488903], [92.9761734, 13.34916973], [92.97598267, 13.34942055], [92.9757843, 13.34963512], [92.97556305, 13.34975147], [92.97531128, 13.34989929], [92.97486877, 13.34982014], [92.97441101, 13.34983063], [92.97415924, 13.34972572], [92.97389221, 13.3495779], [92.97363281, 13.34934998], [92.97338104, 13.34908104], [92.97319031, 13.34874439], [92.97296143, 13.34838581], [92.97264862, 13.34809017], [92.97231293, 13.34791183], [92.9720459, 13.34799194], [92.97184753, 13.34828091], [92.97164154, 13.34854126], [92.97144318, 13.34880066], [92.97133636, 13.3491497], [92.97115326, 13.34943676], [92.97112274, 13.34976006], [92.97113037, 13.35004997], [92.97122955, 13.35027122], [92.97137451, 13.35046005], [92.97150421, 13.35066128], [92.97167206, 13.3508606], [92.9717865, 13.35111046], [92.97193146, 13.35139179], [92.97203064, 13.35174084], [92.97219086, 13.35210133], [92.97222137, 13.35249138], [92.97220612, 13.35286045], [92.97210693, 13.35321999], [92.97200012, 13.35354137], [92.97186279, 13.35384178], [92.9716568, 13.3540659], [92.97141266, 13.35424995], [92.97113037, 13.35445499], [92.97080231, 13.3546896], [92.9703598, 13.35487175], [92.9699707, 13.35523701], [92.96963501, 13.35569954], [92.96959686, 13.35620975], [92.96982574, 13.35668659], [92.97000122, 13.357131], [92.97014618, 13.35750008], [92.97029114, 13.35781002], [92.9704361, 13.35808182], [92.97054291, 13.35837555], [92.97058105, 13.35869503], [92.97058105, 13.3590107], [92.97061157, 13.35930061], [92.97068024, 13.35953999], [92.97062683, 13.35977268], [92.97046661, 13.35998917], [92.97018433, 13.3601923], [92.96980286, 13.3603096], [92.96942902, 13.36052036], [92.96904755, 13.36056137], [92.96868896, 13.36056137], [92.96833038, 13.36056995], [92.9679718, 13.36062717], [92.96759033, 13.36069298], [92.96724701, 13.36077118], [92.96692657, 13.36068439], [92.96657562, 13.36057472], [92.96617126, 13.36053181], [92.96578979, 13.36038113], [92.96539307, 13.36026001], [92.96507263, 13.36007977], [92.96473694, 13.35992146], [92.9644165, 13.3597002], [92.96411896, 13.35940075], [92.96379089, 13.3590498], [92.96356964, 13.35859203], [92.96333313, 13.35806084], [92.96305847, 13.35778141], [92.96305847, 13.35750008], [92.96276855, 13.3572197], [92.96277618, 13.35638809], [92.96250153, 13.35610962], [92.96250153, 13.3558321], [92.96193695, 13.35527992], [92.96166992, 13.35527992], [92.96138763, 13.35499954], [92.96083069, 13.35499954], [92.96072388, 13.35488796], [92.96028137, 13.35444164], [92.96028137, 13.35388756], [92.95999908, 13.35361195], [92.95992279, 13.35311127], [92.95975494, 13.35274792], [92.95967865, 13.3523016], [92.95947266, 13.3519392], [92.95923615, 13.35158062], [92.95907593, 13.35115147], [92.95886993, 13.35073757], [92.95854187, 13.35032845], [92.9581604, 13.34989929], [92.957901, 13.34931087], [92.95759583, 13.34883308], [92.95741272, 13.3483839], [92.95722198, 13.34803295], [92.95703888, 13.3477211], [92.95688629, 13.34735107], [92.95664978, 13.34701633], [92.95633698, 13.34668064], [92.95604706, 13.34632111], [92.95581055, 13.34589958], [92.95555115, 13.34547138], [92.95529175, 13.34499931], [92.95504761, 13.34447956], [92.95464325, 13.34411335], [92.95417023, 13.3439436], [92.95374298, 13.34405994], [92.95334625, 13.34427929], [92.95305634, 13.34444332], [92.95276642, 13.34444141], [92.95249939, 13.34472084], [92.9522171, 13.34472084], [92.95166779, 13.34527969], [92.95139313, 13.34527969], [92.95111084, 13.34499931], [92.95111084, 13.34472084], [92.95082855, 13.34444141], [92.95083618, 13.34416676], [92.95053864, 13.34390068], [92.95059204, 13.34359074], [92.95078278, 13.34322166], [92.95089722, 13.34288406], [92.95105743, 13.34263611], [92.95111084, 13.34239197], [92.95128632, 13.34204102], [92.95144653, 13.34187889], [92.95166779, 13.34167194], [92.95191956, 13.34142971], [92.95223999, 13.3412199], [92.95256805, 13.34103107], [92.95284271, 13.34077072], [92.95305634, 13.34044838], [92.95324707, 13.34006023], [92.95336914, 13.33957863], [92.9535675, 13.33917236], [92.95361328, 13.3387413], [92.95359802, 13.33835125], [92.95361328, 13.33798218], [92.95361328, 13.33759022], [92.95359039, 13.33714104], [92.95349884, 13.33665085], [92.95359039, 13.33611107], [92.95359039, 13.33550358], [92.95346069, 13.3348484], [92.95334625, 13.33418179], [92.95337677, 13.33355999], [92.9535675, 13.3331089], [92.95378113, 13.33278084], [92.95401001, 13.3325367], [92.95430756, 13.33236599], [92.95468903, 13.33221054], [92.95509338, 13.33199024], [92.95549774, 13.33180141], [92.95582581, 13.33150864], [92.95612335, 13.33119011], [92.95643616, 13.33087063], [92.95680237, 13.33055019], [92.95716858, 13.33020115], [92.95751953, 13.32982159], [92.95788574, 13.32946491], [92.95825958, 13.32913208], [92.95858002, 13.32877159], [92.95888519, 13.32833195], [92.95888519, 13.32805634], [92.95916748, 13.32777977], [92.95944214, 13.32777977], [92.95973206, 13.32750034], [92.95999908, 13.32777977], [92.96028137, 13.32777977], [92.96055603, 13.3280611], [92.96083069, 13.3280611], [92.96111298, 13.32777977], [92.96147919, 13.327981], [92.96196747, 13.32772636], [92.96225739, 13.32727242], [92.96247101, 13.32683182], [92.96253967, 13.32642174], [92.96272278, 13.32614613], [92.962883, 13.32586098], [92.96309662, 13.3255806], [92.96338654, 13.32530117], [92.96372986, 13.32505035], [92.96412659, 13.32489014], [92.9644928, 13.32470989], [92.96478271, 13.32452106], [92.96509552, 13.32445145], [92.96544647, 13.32444096], [92.96582794, 13.32449245], [92.96626282, 13.32468128], [92.96673584, 13.32463074], [92.96720123, 13.32453346], [92.96765137, 13.32439995], [92.96807861, 13.32419968], [92.96855927, 13.32414532], [92.96900177, 13.3240242], [92.96942139, 13.32388115], [92.96981049, 13.32368946], [92.97020721, 13.3236208], [92.97061157, 13.32361031], [92.97100067, 13.32361031], [92.97138214, 13.32361031], [92.9717865, 13.3236208], [92.97219849, 13.32371044], [92.9726181, 13.32384014], [92.97305298, 13.32388973], [92.97348022, 13.32388973], [92.97389984, 13.32388973], [92.97431946, 13.32388973], [92.97472382, 13.32392406], [92.97507477, 13.32407475], [92.9754715, 13.32415199], [92.97592163, 13.32417011], [92.97636414, 13.32417011], [92.97679138, 13.32419968], [92.97720337, 13.32434082], [92.97759247, 13.32421112], [92.97802734, 13.32415199], [92.97845459, 13.32403088], [92.97883606, 13.32380962], [92.97915649, 13.32344055], [92.97944641, 13.32297802], [92.97973633, 13.32247925], [92.98002625, 13.32204628], [92.98033142, 13.321702], [92.98062897, 13.32146931], [92.98095703, 13.32134438], [92.98122406, 13.32115746], [92.98152161, 13.32099056], [92.98178101, 13.32079029], [92.98206329, 13.32058144], [92.9823761, 13.32040119], [92.98273468, 13.32029343], [92.98312378, 13.32027721], [92.98351288, 13.32028198], [92.9838562, 13.32024097], [92.98416901, 13.32003975], [92.98448944, 13.3200016], [92.98480225, 13.31999683], [92.9850769, 13.31996059], [92.98532104, 13.31976032], [92.98556519, 13.31949806], [92.98578644, 13.31915188], [92.98583221, 13.31870937], [92.98583984, 13.31826019], [92.98591614, 13.31787968], [92.98612213, 13.31762695], [92.98639679, 13.31742191], [92.98670959, 13.31723022], [92.98694611, 13.3172226], [92.98860931, 13.3172226], [92.9888916, 13.31694317], [92.98916626, 13.31694317], [92.98944092, 13.3172226], [92.98972321, 13.3172226], [92.98999786, 13.31694317], [92.99055481, 13.31694317], [92.9908371, 13.3166666], [92.99138641, 13.31667042], [92.99191284, 13.31655979], [92.99230194, 13.31637955], [92.99266052, 13.31616974], [92.99305725, 13.31609058], [92.99339294, 13.31592178], [92.99370575, 13.31584167], [92.99402618, 13.31583309], [92.99433899, 13.31583309], [92.99464417, 13.31583309], [92.99495697, 13.31583309], [92.99528503, 13.31583309], [92.99562836, 13.31583309], [92.99595642, 13.31583118], [92.99632263, 13.31583977], [92.99669647, 13.31583118], [92.99717712, 13.31575108], [92.99767303, 13.31554127], [92.99812317, 13.31525421], [92.99845123, 13.31485844], [92.99858856, 13.31438065], [92.99862671, 13.31393242], [92.99860382, 13.31351757], [92.99852753, 13.31312084], [92.99833679, 13.31274033], [92.99813843, 13.31228924], [92.99784851, 13.31215], [92.99782562, 13.31201267], [92.99953461, 13.31071186], [92.99973297, 13.31139088], [93.0, 13.31166744], [93.00055695, 13.31222057], [93.0008316, 13.31250095], [93.0008316, 13.31278133], [93.00111389, 13.31305504], [93.00111389, 13.31333256], [93.00138855, 13.31359959], [93.00138855, 13.31389141], [93.00166321, 13.31416702], [93.00164795, 13.31444073], [93.00222015, 13.31500053], [93.00222015, 13.3152771], [93.0027771, 13.31583309], [93.0027771, 13.31611061], [93.00305176, 13.31639194], [93.00305176, 13.3166666], [93.00333405, 13.31694317], [93.00332642, 13.31722069], [93.00583649, 13.3197298], [93.00611115, 13.3197298], [93.0063858, 13.3200016], [93.00666809, 13.3200016], [93.00694275, 13.32028198], [93.00749969, 13.32027721], [93.0076828, 13.32046413], [93.00778198, 13.32056046], [93.00888824, 13.32056046], [93.00945282, 13.3200016], [93.00945282, 13.31694126], [93.0091629, 13.3166666], [93.0091629, 13.31611061], [93.00888824, 13.31583309], [93.00888824, 13.31555462], [93.0091629, 13.31528187], [93.00888824, 13.31500053], [93.00888824, 13.31472111], [93.00861359, 13.31444454], [93.00861359, 13.31361103], [93.0083313, 13.31333256], [93.0083313, 13.31305504], [93.0080719, 13.31278133], [93.0080719, 13.31250095], [93.00749969, 13.31194019], [93.00749969, 13.31166744], [93.00694275, 13.31111145], [93.0067749, 13.31006718], [93.00676727, 13.30930996], [93.00698853, 13.30902958], [93.00712585, 13.30902958], [93.00733948, 13.30937862], [93.00778198, 13.30972099], [93.00826263, 13.31000137], [93.00888824, 13.31000137], [93.0091629, 13.31000137], [93.00945282, 13.31000137], [93.00986481, 13.30992794], [93.01027679, 13.30972099], [93.01166534, 13.3083334], [93.01194763, 13.3083334], [93.01333618, 13.30694485], [93.01340485, 13.30666637], [93.01354218, 13.30639076], [93.01361084, 13.30590057], [93.01361084, 13.30555439], [93.01374817, 13.30500031], [93.01387787, 13.30473137], [93.01387787, 13.30443954], [93.01416779, 13.30416584], [93.01416779, 13.30389023], [93.01409912, 13.30368137], [93.01416779, 13.30340004], [93.01416779, 13.30305576], [93.01374817, 13.30229092], [93.01361084, 13.30194378], [93.01305389, 13.30138779], [93.01304626, 13.30027962], [93.01361084, 13.29971981], [93.01361084, 13.2994442], [93.0138855, 13.29916573], [93.01387787, 13.29889011], [93.01416779, 13.29860115], [93.01493835, 13.29830933], [93.01567841, 13.29796886], [93.01638794, 13.29777813], [93.01772308, 13.29780102], [93.01799011, 13.29758167], [93.01792145, 13.29676819], [93.01806641, 13.29656124], [93.0182724, 13.29656124], [93.01853943, 13.2967701], [93.01869965, 13.29684067], [93.01925659, 13.29691029], [93.01960754, 13.29697609], [93.0200119, 13.29721928], [93.02027893, 13.29749966], [93.02036285, 13.29758358], [93.02062225, 13.29784393], [93.02138519, 13.29777813], [93.02153015, 13.29749966], [93.02166748, 13.29728985], [93.02166748, 13.29694366], [93.02173615, 13.29666805], [93.02166748, 13.29638958], [93.02166748, 13.29611015], [93.02166748, 13.29555607], [93.02194214, 13.29528046], [93.02194214, 13.29444122], [93.02111053, 13.29361153], [93.02027893, 13.29354095], [93.01972198, 13.29333401], [93.01777649, 13.29333401], [93.01743317, 13.29354095], [93.01721954, 13.29361153], [93.01703644, 13.29394722], [93.01654816, 13.29421997], [93.01605988, 13.29457092], [93.01542664, 13.29483986], [93.01451111, 13.29511642], [93.01409149, 13.29532146], [93.01338959, 13.29545975], [93.01270294, 13.29539204], [93.01255035, 13.29518032], [93.01255035, 13.29483986], [93.01261902, 13.29457092], [93.01290131, 13.2941494], [93.01332092, 13.29373932], [93.01367188, 13.29326057], [93.01387787, 13.29298019], [93.01444244, 13.29277706], [93.01499939, 13.29222107], [93.01555634, 13.29222107], [93.01638794, 13.29138947], [93.01638794, 13.29111099], [93.01667023, 13.29083061], [93.01667023, 13.2897234], [93.01611328, 13.2891674], [93.01611328, 13.28889179], [93.01555634, 13.28833103], [93.01555634, 13.28805542], [93.01526642, 13.28778172], [93.01526642, 13.28750134], [93.01499939, 13.28722095], [93.01499939, 13.28694534], [93.01472473, 13.28666687], [93.01472473, 13.28638935], [93.01416779, 13.28583145], [93.01416779, 13.28555489], [93.01409912, 13.28528118], [93.01387787, 13.28499889], [93.01381683, 13.2841692], [93.01333618, 13.28382015], [93.01249695, 13.28306103], [93.01222229, 13.28306103], [93.01194763, 13.28278065], [93.01167297, 13.28278065], [93.01139069, 13.28250122], [93.0111084, 13.28250122], [93.01081848, 13.28222275], [93.01081848, 13.28056145], [93.0111084, 13.28028107], [93.0111084, 13.27943993], [93.01139069, 13.27916622], [93.01139069, 13.27861023], [93.01166534, 13.27833462], [93.01166534, 13.27750015], [93.01249695, 13.27666569], [93.01304626, 13.27667141], [93.01333618, 13.27639008], [93.01361084, 13.27639008], [93.01387787, 13.27667141], [93.01472473, 13.27666569], [93.01499939, 13.27694416], [93.01526642, 13.27694035], [93.01611328, 13.27778053], [93.01638794, 13.27777767], [93.01694489, 13.27833462], [93.01721954, 13.27833462], [93.01777649, 13.27777767], [93.01832581, 13.27778053], [93.01860809, 13.27749062], [93.0200119, 13.27749062], [93.02035522, 13.27785969], [93.02054596, 13.27806091], [93.02083588, 13.27805424], [93.02111053, 13.27833462], [93.02166748, 13.27833462], [93.02194214, 13.27861023], [93.0222168, 13.27861023], [93.02416992, 13.28055668], [93.02416992, 13.28083229], [93.02443695, 13.2811079], [93.02443695, 13.28139114], [93.02471924, 13.28166676], [93.02471924, 13.28194523], [93.02487946, 13.28264046], [93.02502441, 13.28314972], [93.0252533, 13.28349018], [93.02593994, 13.2837019], [93.02622223, 13.28363132], [93.02635956, 13.28349495], [93.02635956, 13.28301144], [93.02622223, 13.28273773], [93.02635956, 13.28225708], [93.02664185, 13.28198147], [93.02761841, 13.28198147], [93.02796936, 13.28205204], [93.02839661, 13.28205204], [93.02909088, 13.2817812], [93.0302124, 13.2806797], [93.03063965, 13.27992058], [93.03083038, 13.27972031], [93.03083038, 13.27888775], [93.03111267, 13.27861023], [93.03111267, 13.27805424], [93.03138733, 13.27778053], [93.03138733, 13.27721977], [93.03221893, 13.27638817], [93.03250122, 13.27639008], [93.03277588, 13.2761097], [93.03388977, 13.2761097], [93.0341568, 13.27639008], [93.03444672, 13.27639008], [93.03444672, 13.27666569], [93.03472137, 13.27694416], [93.03472137, 13.27721977], [93.03778076, 13.28028107], [93.03804779, 13.28028107], [93.03833008, 13.28056145], [93.03861237, 13.28056145], [93.03916168, 13.28062057], [93.03954315, 13.28059101], [93.03974915, 13.28066158], [93.04009247, 13.28052044], [93.04051971, 13.28059101], [93.04083252, 13.28028107], [93.04110718, 13.28028107], [93.04138947, 13.28000069], [93.04165649, 13.28000069], [93.04194641, 13.27972031], [93.04222107, 13.27972317], [93.04250336, 13.27944374], [93.04360962, 13.27943993], [93.04418182, 13.28000069], [93.04418182, 13.28028107], [93.04444122, 13.28055668], [93.04444122, 13.28083038], [93.04528046, 13.28167057], [93.04555511, 13.28166676], [93.04582977, 13.28194523], [93.04611206, 13.28194523], [93.04722595, 13.28083229], [93.04722595, 13.28055668], [93.04728699, 13.28020954], [93.04724121, 13.27972031], [93.04722595, 13.27944374], [93.04722595, 13.27805424], [93.04695129, 13.27778053], [93.04695129, 13.27721977], [93.04666901, 13.27694416], [93.04666901, 13.27666569], [93.04611206, 13.2761097], [93.04611206, 13.27583027], [93.04250336, 13.27222157], [93.04222107, 13.27222157], [93.04138947, 13.27138996], [93.04110718, 13.27138996], [93.04055786, 13.2708292], [93.04055786, 13.27055645], [93.0402832, 13.27028179], [93.0402832, 13.26944065], [93.04083252, 13.26888847], [93.04083252, 13.26833057], [93.04166412, 13.26749992], [93.04165649, 13.26722145], [93.04250336, 13.26638985], [93.04250336, 13.26611233], [93.04277802, 13.2658329], [93.04277802, 13.26555538], [93.04305267, 13.26527691], [93.04277802, 13.26499939], [93.04305267, 13.26472092], [93.04305267, 13.26333332], [93.04333496, 13.26305485], [93.04332733, 13.26222134], [93.04360962, 13.26194477], [93.04360962, 13.26166725], [93.04471588, 13.26056194], [93.04471588, 13.26028156], [93.04582977, 13.25917244], [93.04611206, 13.25917244], [93.04724121, 13.26028156], [93.04750061, 13.26028156], [93.04860687, 13.26139069], [93.04888916, 13.26139069], [93.04915619, 13.26167202], [93.04944611, 13.26166725], [93.04972076, 13.26194477], [93.05055237, 13.26194477], [93.05083466, 13.26222324], [93.05166626, 13.26222324], [93.05194092, 13.26249886], [93.05249786, 13.26249027], [93.05304718, 13.26305962], [93.0533371, 13.26305485], [93.05351257, 13.26323128], [93.05361176, 13.26333332], [93.05388641, 13.26333332], [93.0542984, 13.26374626], [93.05527496, 13.26472092], [93.05555725, 13.26472092], [93.05638885, 13.26555538], [93.05666351, 13.26555538], [93.05833435, 13.26722145], [93.05860901, 13.26722145], [93.0588913, 13.26750183], [93.05918121, 13.26750183], [93.05944824, 13.2677803], [93.0597229, 13.2677803], [93.05999756, 13.26805973], [93.06027985, 13.26805973], [93.06083679, 13.26862144], [93.06111145, 13.26862144], [93.0625, 13.27000046], [93.06276703, 13.27000046], [93.0633316, 13.27056026], [93.06361389, 13.27055645], [93.06416321, 13.27110958], [93.06416321, 13.27138996], [93.06582642, 13.2730608], [93.0661087, 13.2730608], [93.06667328, 13.27250004], [93.06639099, 13.27221966], [93.06639099, 13.27194405], [93.0661087, 13.27166557], [93.0661087, 13.27056026], [93.06582642, 13.27028179], [93.06582642, 13.26916981], [93.06555176, 13.26889038], [93.06555176, 13.26694107], [93.0652771, 13.26666546], [93.0652771, 13.26583099], [93.06500244, 13.26555538], [93.06500244, 13.26499939], [93.06492615, 13.26472092], [93.06478882, 13.26416969], [93.0642395, 13.2634697], [93.06298828, 13.2634697], [93.0625, 13.26361084], [93.06159973, 13.26257038], [93.06111145, 13.26249027], [93.05999756, 13.26138878], [93.05999756, 13.26111126], [93.05944824, 13.26055527], [93.05944824, 13.26028156], [93.0588913, 13.2597208], [93.0588913, 13.25916672], [93.05860901, 13.25889111], [93.05860901, 13.25861073], [93.05832672, 13.2583313], [93.05833435, 13.25777912], [93.05805206, 13.25750065], [93.05805206, 13.25722122], [93.0577774, 13.25694466], [93.0577774, 13.25666714], [93.05750275, 13.25639057], [93.05750275, 13.2558279], [93.05770111, 13.25490475], [93.05770111, 13.25456142], [93.05791473, 13.25401211], [93.05805206, 13.25353146], [93.05818939, 13.25297928], [93.05827332, 13.25264168], [93.05827332, 13.25235939], [93.05791473, 13.25126076], [93.0579834, 13.25071144], [93.0577774, 13.24972153], [93.0577774, 13.24833202], [93.05750275, 13.24805641], [93.05750275, 13.24722195], [93.05722046, 13.24694443], [93.05722046, 13.24638844], [93.05555725, 13.24472046], [93.05555725, 13.24444389], [93.05526733, 13.24417019], [93.05526733, 13.24388981], [93.05555725, 13.24361038], [93.05555725, 13.24222183], [93.05583191, 13.24194431], [93.05583191, 13.24166775], [93.05612183, 13.24139023], [93.05612183, 13.24028015], [93.05638885, 13.24000168], [93.05638885, 13.23944092], [93.05666351, 13.23916531], [93.05665588, 13.23832035], [93.0569458, 13.23805523], [93.0569458, 13.23666954], [93.05665588, 13.23639202], [93.05665588, 13.23472118], [93.05638885, 13.23444462], [93.05638885, 13.23388863], [93.05612183, 13.23361111], [93.0561142, 13.23277664], [93.05526733, 13.23194027], [93.05500031, 13.23194504], [93.05472565, 13.23166656], [93.05444336, 13.23166943], [93.05278015, 13.23000145], [93.05278015, 13.22972107], [93.05249786, 13.22944546], [93.05249786, 13.22889137], [93.05222321, 13.22861099], [93.05222321, 13.22832966], [93.05083466, 13.22694492], [93.05055237, 13.22694492], [93.05034637, 13.22673702], [93.05000305, 13.22638798], [93.04972076, 13.22638798], [93.04888916, 13.22555447], [93.04860687, 13.22556114], [93.04833221, 13.22528076], [93.04805756, 13.22528076], [93.04798126, 13.22520256], [93.0477829, 13.22500038], [93.04750061, 13.22500038], [93.04724121, 13.22472], [93.04694366, 13.22472191], [93.04666901, 13.22444439], [93.04638672, 13.22444439], [93.04611206, 13.22416592], [93.04556274, 13.22417068], [93.04528046, 13.22389126], [93.04499817, 13.22389126], [93.04471588, 13.22360992], [93.04444122, 13.22360992], [93.04389191, 13.22306061], [93.04332733, 13.22306061], [93.04302979, 13.22288132], [93.04296112, 13.22253036], [93.04296112, 13.22205067], [93.04316711, 13.2215004], [93.04359436, 13.22081375], [93.04386902, 13.21998882], [93.04380035, 13.21881008], [93.04410553, 13.21738052], [93.04438782, 13.21696663], [93.04453278, 13.21628094], [93.04453278, 13.21449089], [93.04494476, 13.21332359], [93.04508209, 13.21201897], [93.04515839, 13.21119118], [93.04550934, 13.21112537], [93.045784, 13.21112537], [93.04587555, 13.21061707], [93.04612732, 13.2101202], [93.04589081, 13.20977974], [93.04543304, 13.20946121], [93.04476929, 13.20936966], [93.04416656, 13.20916653], [93.04389191, 13.20889187], [93.04360962, 13.20889187], [93.04250336, 13.20778179], [93.04250336, 13.20750141], [93.04222107, 13.20722103], [93.04222107, 13.20694542], [93.04194641, 13.20666695], [93.04194641, 13.20639133], [93.04165649, 13.20611095], [93.04165649, 13.20557117], [93.04138947, 13.20528126], [93.04138947, 13.20472145], [93.04111481, 13.20444489], [93.04111481, 13.20361137], [93.04083252, 13.2033329], [93.04083252, 13.20055676], [93.04055786, 13.20028114], [93.04055786, 13.20000076], [93.03943634, 13.19889069], [93.03916931, 13.19889069], [93.03861237, 13.19832993], [93.03861237, 13.19805431], [93.03833008, 13.19778061], [93.03833008, 13.19750023], [93.03804779, 13.19721985], [93.03805542, 13.19694424], [93.03749847, 13.19638824], [93.03749847, 13.19610977], [93.03721619, 13.19583035], [93.03722382, 13.19555569], [93.03694153, 13.19528103], [93.03694153, 13.19472027], [93.03666687, 13.1944437], [93.03666687, 13.19277763], [93.03639221, 13.19250011], [93.03639221, 13.19221973], [93.03610992, 13.19194412], [93.03610992, 13.19166565], [93.0358429, 13.19139004], [93.0358429, 13.19110966], [93.03555298, 13.19083405], [93.03555298, 13.19027805], [93.03527832, 13.18999958], [93.03527832, 13.18805981], [93.03501129, 13.18778038], [93.03501129, 13.18750191], [93.03472137, 13.18721008], [93.03472137, 13.18666458], [93.03444672, 13.18639183], [93.03444672, 13.18583107], [93.03416443, 13.18555546], [93.0341568, 13.18528175], [93.03388977, 13.18499947], [93.03388977, 13.18472099], [93.03360748, 13.18444633], [93.03360748, 13.18416691], [93.03333282, 13.18388939], [93.03333282, 13.18222141], [93.03305817, 13.18194485], [93.03305817, 13.18083286], [93.03277588, 13.18055534], [93.03277588, 13.18000126], [93.03250122, 13.17972088], [93.03250122, 13.17916679], [93.03221893, 13.17889118], [93.03221893, 13.17805862], [93.03250122, 13.1777792], [93.0326767, 13.17742062], [93.03316498, 13.17700863], [93.03366089, 13.17673969], [93.03421783, 13.17632008], [93.03501129, 13.17527199], [93.03500366, 13.17500114], [93.03666687, 13.17333221], [93.03666687, 13.17250061], [93.03694153, 13.17223167], [93.03694153, 13.17111015], [93.03722382, 13.17083454], [93.03722382, 13.17000008], [93.03694153, 13.1697197], [93.03694153, 13.16944408], [93.03666687, 13.16916561], [93.03666687, 13.16889], [93.0358429, 13.16806126], [93.0358429, 13.16778088], [93.03527832, 13.16722202], [93.03527832, 13.16694355], [93.03500366, 13.16666603], [93.03501129, 13.16639042], [93.03472137, 13.16611004], [93.03472137, 13.16528034], [93.03444672, 13.16499996], [93.03444672, 13.16471958], [93.03416443, 13.16444397], [93.03416443, 13.16250038], [93.03444672, 13.16222191], [93.03444672, 13.16194439], [93.03427887, 13.16144943], [93.03438568, 13.16126442], [93.03424835, 13.16037083], [93.03424835, 13.15989017], [93.03431702, 13.15939999], [93.03424835, 13.15851593], [93.03424835, 13.15680027], [93.03453064, 13.15625], [93.03481293, 13.15522003], [93.03536987, 13.15445042], [93.03607178, 13.15272236], [93.03610992, 13.15211105], [93.03610992, 13.15149593], [93.03610992, 13.15090084], [93.03614807, 13.15033054], [93.03633118, 13.14982796], [93.03637695, 13.14929199], [93.03639984, 13.1487608], [93.03649139, 13.14825058], [93.03666687, 13.14805889], [93.03666687, 13.14721107], [93.0366745, 13.14529037], [93.03653717, 13.14398193], [93.03653717, 13.14219475], [93.03674316, 13.14129925], [93.03722382, 13.14083195], [93.03722382, 13.14027786], [93.03734589, 13.13958073], [93.03740692, 13.13887215], [93.03713226, 13.13827896], [93.03668976, 13.13787079], [93.03626251, 13.13750362], [93.03588104, 13.13715267], [93.03559113, 13.13675022], [93.03542328, 13.13625145], [93.03526306, 13.13574696], [93.03505707, 13.13525009], [93.03486633, 13.13473129], [93.03462982, 13.13421059], [93.03430939, 13.13375759], [93.03395081, 13.13330173], [93.03362274, 13.13284111], [93.03331757, 13.13237], [93.0329895, 13.13193035], [93.03269958, 13.13147163], [93.032341, 13.131073], [93.0320282, 13.13065147], [93.03194427, 13.13055515], [93.03153229, 13.12993145], [93.03138733, 13.12972355], [93.03131866, 13.12923813], [93.03096771, 13.12799072], [93.03083038, 13.12778187], [93.03098297, 13.12646198], [93.03111267, 13.12611103], [93.03145599, 13.12535], [93.03166962, 13.12500095], [93.03188324, 13.12465], [93.03194427, 13.12416744], [93.03222656, 13.12367725], [93.03250122, 13.12312126], [93.03243256, 13.12291622], [93.03250122, 13.12250137], [93.03250122, 13.12193966], [93.03236389, 13.12166691], [93.03243256, 13.12112045], [93.03250122, 13.12082958], [93.03250122, 13.12023544], [93.03250122, 13.11975002], [93.03246307, 13.11927128], [93.03225708, 13.11883163], [93.03224182, 13.1183424], [93.03221893, 13.11783791], [93.03221893, 13.11736107], [93.0319519, 13.11667061], [93.03186798, 13.11611938], [93.03172302, 13.11557007], [93.03172302, 13.11481094], [93.03200531, 13.11446857], [93.03221893, 13.11399078], [93.03250122, 13.11308956], [93.032547, 13.11250019], [93.0327301, 13.11190987], [93.03277588, 13.11125565], [93.0327301, 13.11056328], [93.03253937, 13.10988426], [93.03251648, 13.10918808], [93.03263855, 13.10853195], [93.03299713, 13.10796928], [93.03331757, 13.10741138], [93.03356171, 13.10684109], [93.03362274, 13.10620975], [93.03361511, 13.1055994], [93.03362274, 13.10501099], [93.03363037, 13.10444069], [93.03373718, 13.10387993], [93.03382111, 13.10333824], [93.03369904, 13.10278034], [93.03354645, 13.10272026], [93.03354645, 13.10217094], [93.03404236, 13.10134125], [93.03473663, 13.10044956], [93.03524017, 13.09976196], [93.03544617, 13.09879971], [93.0355072, 13.09797096], [93.03551483, 13.09721565], [93.03524017, 13.09612179], [93.03495789, 13.09536076], [93.03456116, 13.09496021], [93.03427887, 13.09451962], [93.03418732, 13.09364891], [93.03425598, 13.09324074], [93.03440094, 13.09262085], [93.03460693, 13.09241199], [93.03495789, 13.09213066], [93.0354538, 13.09179211], [93.03596497, 13.09115791], [93.0358963, 13.09050179], [93.03600311, 13.08984089], [93.03604889, 13.08919144], [93.0358429, 13.08863258], [93.03562164, 13.08810425], [93.03544617, 13.08757973], [93.03520966, 13.08713818], [93.03502655, 13.08668041], [93.03501129, 13.08615971], [93.03504181, 13.0856657], [93.03523254, 13.08517838], [93.03527832, 13.08461857], [93.03527832, 13.08401966], [93.03526306, 13.08342075], [93.03517914, 13.0828104], [93.03503418, 13.08221722], [93.03501129, 13.0815897], [93.03488159, 13.08099079], [93.0344696, 13.08056927], [93.03390503, 13.08031368], [93.03325653, 13.0802803], [93.03258514, 13.08035469], [93.03199768, 13.08056259], [93.03181458, 13.08063316], [93.03145599, 13.08076954], [93.03117371, 13.08073997], [93.03089142, 13.08071136], [93.03032684, 13.08061695], [93.02980804, 13.08036041], [93.02931213, 13.08018589], [93.02899933, 13.07983971], [93.02866364, 13.07949066], [93.0283432, 13.0791111], [93.02804565, 13.0787096], [93.027771, 13.07831097], [93.02754974, 13.07786179], [93.02723694, 13.07749939], [93.02700043, 13.07708931], [93.02687073, 13.07661724], [93.0266571, 13.07619095], [93.02646637, 13.0757513], [93.02639771, 13.07524109], [93.02633667, 13.07470989], [93.02614594, 13.07417202], [93.02610779, 13.07359123], [93.02610016, 13.07298946], [93.02609253, 13.07237053], [93.02614594, 13.07178116], [93.02657318, 13.07132053], [93.0271225, 13.07116127], [93.02746582, 13.07089424], [93.02796936, 13.07048225], [93.02859497, 13.07041359], [93.0295105, 13.07006931], [93.02979279, 13.07006931], [93.02999878, 13.07001019], [93.03028107, 13.06972122], [93.03028107, 13.06944466], [93.03055573, 13.06916714], [93.03056335, 13.06889057], [93.0302124, 13.06799126], [93.02971649, 13.06694031], [93.02944183, 13.0666666], [93.02923584, 13.06597233], [93.02833557, 13.06500053], [93.0283432, 13.06417084], [93.02805328, 13.06388187], [93.02805328, 13.06361008], [93.02777863, 13.0633297], [93.02777863, 13.06277847], [93.02749634, 13.0625], [93.02749634, 13.06221962], [93.02694702, 13.06166553], [93.02694702, 13.06138992], [93.02527618, 13.05972195], [93.02527618, 13.05944443], [93.02500153, 13.05916595], [93.02500153, 13.05889034], [93.02416992, 13.05807018], [93.02416992, 13.05750179], [93.02388763, 13.05722046], [93.02388763, 13.05694389], [93.02361298, 13.05611229], [93.02361298, 13.0555563], [93.02333069, 13.05527973], [93.02333069, 13.05472183], [93.02249908, 13.05389023], [93.02249908, 13.05360889], [93.02132416, 13.05228996], [93.02111053, 13.05194092], [93.02104187, 13.05152893], [93.02083588, 13.05083084], [93.02083588, 13.05055523], [93.02076721, 13.04999924], [93.01999664, 13.04972363], [93.01917267, 13.04972076], [93.01833344, 13.04999924], [93.01770782, 13.05034256], [93.01701355, 13.05048466], [93.01576233, 13.05048466], [93.01555634, 13.05034256], [93.01499939, 13.04999924], [93.0147171, 13.04972076], [93.01444244, 13.04972363], [93.0138855, 13.04916668], [93.01342773, 13.0489006], [93.01298523, 13.04860497], [93.01261139, 13.04828072], [93.01235199, 13.04784966], [93.01204681, 13.04734039], [93.01207733, 13.04675198], [93.01216125, 13.04628658], [93.01232147, 13.04596996], [93.01267242, 13.04566002], [93.01294708, 13.04559135], [93.013237, 13.04545021], [93.01351929, 13.04531574], [93.0139389, 13.04497242], [93.0141449, 13.04455853], [93.01413727, 13.04401016], [93.01378632, 13.04373169], [93.01351929, 13.04366589], [93.01316833, 13.04366589], [93.01295471, 13.0437336], [93.01267242, 13.04380035], [93.01225281, 13.04408264], [93.01183319, 13.04415131], [93.0114212, 13.04422188], [93.01098633, 13.04415131], [93.01022339, 13.04408264], [93.00984192, 13.04380035], [93.00946045, 13.04335117], [93.00928497, 13.04285717], [93.00943756, 13.04266071], [93.00943756, 13.04218197], [93.00958252, 13.04183102], [93.01000214, 13.04141808], [93.01037598, 13.04127026], [93.01066589, 13.04106712], [93.01080322, 13.04066181], [93.01074982, 13.04022026], [93.010849, 13.0395813], [93.01068878, 13.03921032], [93.01035309, 13.03894997], [93.0100174, 13.03861046], [93.00971985, 13.03818035], [93.00945282, 13.03773117], [93.00927734, 13.03729057], [93.00949097, 13.03688145], [93.00959015, 13.03646755], [93.00948334, 13.0362606], [93.00934601, 13.03577995], [93.00879669, 13.03489113], [93.00850677, 13.03434181], [93.00808716, 13.03365135], [93.00763702, 13.03265095], [93.00726318, 13.03224277], [93.00695038, 13.03177547], [93.00666046, 13.03129005], [93.00634003, 13.03081131], [93.0059433, 13.0303812], [93.00549316, 13.02995014], [93.00501251, 13.02952957], [93.00447083, 13.02907944], [93.00389862, 13.02858925], [93.00331116, 13.02822018], [93.00305176, 13.0283289], [93.00250244, 13.02888775], [93.00250244, 13.02972031], [93.0027771, 13.02999973], [93.0027771, 13.0308342], [93.00270844, 13.03107262], [93.00242615, 13.03148079], [93.00193787, 13.03182983], [93.00158691, 13.03196716], [93.00088501, 13.03210354], [93.00026703, 13.03193855], [93.0, 13.03222179], [92.99973297, 13.03199196], [92.99948883, 13.03190517], [92.9991684, 13.03172112], [92.99882507, 13.03174305], [92.9985199, 13.03194427], [92.99819946, 13.0321722], [92.99781799, 13.03232479], [92.99746704, 13.03254128], [92.99715424, 13.03285599], [92.99690247, 13.0332613], [92.99662018, 13.03365993], [92.99637604, 13.03404808], [92.9961319, 13.03437996], [92.99597168, 13.03470039], [92.99578094, 13.03494072], [92.9955368, 13.03510475], [92.99526215, 13.03520966], [92.99494934, 13.0352602], [92.99465942, 13.03518963], [92.99433136, 13.03504086], [92.99396515, 13.03498173], [92.99360657, 13.0348568], [92.99324036, 13.03470039], [92.99289703, 13.03448105], [92.99249268, 13.03431034], [92.99208069, 13.034132], [92.99172211, 13.03385162], [92.99139404, 13.03350067], [92.99105835, 13.03312016], [92.99069977, 13.03275967], [92.99043274, 13.03234959], [92.99024963, 13.03184795], [92.98999786, 13.03134918], [92.98983002, 13.03080368], [92.98973083, 13.03021431], [92.98972321, 13.02961159], [92.98973846, 13.02903557], [92.98985291, 13.0284996], [92.99007416, 13.02805138], [92.99028778, 13.02759075], [92.99051666, 13.02712059], [92.99048615, 13.02661991], [92.99019623, 13.02620983], [92.98976135, 13.02595234], [92.98934174, 13.0257473], [92.98896027, 13.02560139], [92.9885788, 13.02555084], [92.98819733, 13.02555275], [92.9878006, 13.02555084], [92.98739624, 13.02556038], [92.98700714, 13.02560139], [92.98668671, 13.02577019], [92.98628235, 13.02583122], [92.9858551, 13.02584743], [92.98545074, 13.0259037], [92.9850769, 13.0259037], [92.98497772, 13.02588177], [92.98474121, 13.02582455], [92.98445892, 13.02569008], [92.98420715, 13.02550983], [92.98401642, 13.02528], [92.9838028, 13.02506065], [92.98351288, 13.02486706], [92.98327637, 13.02453041], [92.98300934, 13.02423096], [92.98271179, 13.02402878], [92.98242188, 13.02404213], [92.98216248, 13.02442074], [92.98197937, 13.02487183], [92.98191833, 13.02527142], [92.98179626, 13.02557182], [92.98163605, 13.0258503], [92.98139954, 13.02611923], [92.98118591, 13.02645969], [92.98101807, 13.02686596], [92.98075104, 13.02715969], [92.98044586, 13.02734947], [92.98014832, 13.02748108], [92.97980499, 13.02753639], [92.97947693, 13.02772141], [92.97911835, 13.0278511], [92.97881317, 13.02802181], [92.97846985, 13.02805996], [92.97820282, 13.02810097], [92.97799683, 13.0282402], [92.97777557, 13.02832031], [92.97749329, 13.02837276], [92.97723389, 13.02856445], [92.97690582, 13.02862072], [92.97657776, 13.02871895], [92.97628021, 13.02886009], [92.97592926, 13.02888966], [92.97553253, 13.02888966], [92.97512054, 13.02888966], [92.9746933, 13.02889919], [92.97425842, 13.028965], [92.97384644, 13.02913189], [92.9733963, 13.0291996], [92.97299957, 13.02936172], [92.97263336, 13.02944183], [92.97225952, 13.02945137], [92.97203064, 13.02944374], [92.97189331, 13.02944183], [92.97150421, 13.02944374], [92.971138, 13.0294714], [92.97083282, 13.0296402], [92.9705658, 13.02986813], [92.97034454, 13.03016186], [92.97026062, 13.03056145], [92.97014618, 13.03094959], [92.97001648, 13.03129005], [92.96998596, 13.03161621], [92.96990204, 13.03189182], [92.96972656, 13.03211021], [92.96953583, 13.0323267], [92.96917725, 13.03252125], [92.9688797, 13.0328722], [92.96856689, 13.03324986], [92.9682312, 13.03361034], [92.96788788, 13.03393078], [92.96763611, 13.03431034], [92.96740723, 13.03467941], [92.9671402, 13.03497982], [92.96685028, 13.03523064], [92.96653748, 13.03536034], [92.96629333, 13.03537178], [92.96604919, 13.03520966], [92.96582794, 13.03499985], [92.96562195, 13.03475189], [92.9655838, 13.03441906], [92.96569824, 13.03401089], [92.96585846, 13.03351402], [92.96607208, 13.03301144], [92.9661026, 13.03250027], [92.96603394, 13.03205776], [92.96586609, 13.03172112], [92.96582794, 13.03140163], [92.96582794, 13.03110981], [92.96583557, 13.03084087], [92.96582794, 13.03057194], [92.96582794, 13.02965069], [92.96583557, 13.02928734], [92.96582794, 13.02888966], [92.96583557, 13.02849102], [92.9658432, 13.02810383], [92.96591187, 13.02772808], [92.96607208, 13.02736092], [92.96611023, 13.02696037], [92.96611023, 13.02654934], [92.96614838, 13.02616405], [92.96633911, 13.0258503], [92.96647644, 13.02550125], [92.96672821, 13.02523041], [92.96705627, 13.02499008], [92.96739197, 13.0247097], [92.96768188, 13.02440453], [92.96790314, 13.02404022], [92.96807098, 13.02363873], [92.96829224, 13.02326965], [92.96837616, 13.02285004], [92.96858215, 13.02248955], [92.96869659, 13.0220089], [92.9688797, 13.02153111], [92.96901703, 13.02103806], [92.96909332, 13.02056026], [92.96890259, 13.02019119], [92.96866608, 13.01980114], [92.96839142, 13.0194788], [92.96836853, 13.01908302], [92.96855927, 13.01863766], [92.96869659, 13.01814175], [92.96894073, 13.01772022], [92.96917725, 13.01731014], [92.9694519, 13.01694965], [92.96974182, 13.01665115], [92.96998596, 13.01636791], [92.97021484, 13.01612186], [92.97048187, 13.01593304], [92.97083282, 13.0158329], [92.97119141, 13.01573277], [92.97151184, 13.01558018], [92.97181702, 13.01549053], [92.97206879, 13.01534081], [92.97233582, 13.01527023], [92.97261047, 13.01515961], [92.97284698, 13.01503086], [92.97310638, 13.0150013], [92.97338867, 13.01501179], [92.97364807, 13.0150671], [92.97386169, 13.01523113], [92.97408295, 13.01538181], [92.97424316, 13.01562119], [92.97442627, 13.0158577], [92.97460938, 13.01620007], [92.97477722, 13.0163517], [92.97506714, 13.01625919], [92.97543335, 13.01585102], [92.9757843, 13.01542282], [92.97602081, 13.01494598], [92.97605896, 13.01448059], [92.97585297, 13.01405144], [92.97558594, 13.01364899], [92.97531891, 13.0133419], [92.97499847, 13.01307964], [92.974617, 13.01286125], [92.97414398, 13.01287937], [92.97368622, 13.01288128], [92.97327423, 13.01283264], [92.97289276, 13.01281261], [92.97251129, 13.01283073], [92.97210693, 13.01279926], [92.97170258, 13.01275063], [92.97130585, 13.01257992], [92.97091675, 13.0125103], [92.97052765, 13.01253033], [92.97015381, 13.01269913], [92.96974945, 13.01278305], [92.96933746, 13.01288128], [92.96900177, 13.01302528], [92.96864319, 13.01305008], [92.96826172, 13.01307964], [92.96788788, 13.01321411], [92.96749878, 13.01333332], [92.96708679, 13.01346016], [92.96669006, 13.01363087], [92.96633911, 13.0138998], [92.96604156, 13.01423073], [92.96580505, 13.01461792], [92.96553802, 13.01492119], [92.96527863, 13.01516724], [92.9650116, 13.01538181], [92.96475983, 13.0156002], [92.96453857, 13.01584625], [92.96434021, 13.01609039], [92.96411896, 13.01629066], [92.96383667, 13.01640701], [92.96356964, 13.01656437], [92.96325684, 13.01665115], [92.96290588, 13.01666927], [92.9625473, 13.01666927], [92.96221161, 13.01663971], [92.96193695, 13.01648045], [92.96169281, 13.0163002], [92.9614563, 13.01608086], [92.96128082, 13.01582432], [92.96109009, 13.01552963], [92.96083832, 13.01523972], [92.96060181, 13.01484108], [92.9602356, 13.01480484], [92.9598465, 13.01505089], [92.95951843, 13.01546955], [92.95918274, 13.015872], [92.95890045, 13.01626587], [92.95864105, 13.01662064], [92.95836639, 13.01691055], [92.95809937, 13.01718044], [92.95780182, 13.01744556], [92.95739746, 13.01761055], [92.95693207, 13.01780033], [92.95648956, 13.01803017], [92.95601654, 13.01811028], [92.9556427, 13.01831341], [92.95530701, 13.0184927], [92.9550705, 13.01874065], [92.95500183, 13.01907063], [92.95498657, 13.01939106], [92.95491028, 13.01967144], [92.95477295, 13.01990795], [92.95471191, 13.02021122], [92.95461273, 13.02054214], [92.9544754, 13.02088261], [92.95446777, 13.02124977], [92.95459747, 13.02163982], [92.95470428, 13.0220499], [92.95469666, 13.02248096], [92.95458221, 13.02292061], [92.95440674, 13.02335167], [92.95417023, 13.02373886], [92.95391846, 13.02413082], [92.95368195, 13.02452087], [92.95353699, 13.02492237], [92.95333099, 13.02526188], [92.95311737, 13.02559185], [92.95292664, 13.0258503], [92.9527359, 13.02609062], [92.95249176, 13.02630997], [92.9522171, 13.02657413], [92.95194244, 13.02688217], [92.95172119, 13.02721024], [92.95166779, 13.02761078], [92.95166016, 13.02801037], [92.95157623, 13.02839088], [92.95140076, 13.02873039], [92.95121002, 13.02905178], [92.95096588, 13.02929974], [92.95072937, 13.02954197], [92.95041656, 13.02975082], [92.95009613, 13.02997875], [92.94972992, 13.03016186], [92.9493866, 13.03035069], [92.94908905, 13.03054047], [92.94878387, 13.03067207], [92.94850922, 13.03082275], [92.94824982, 13.03093433], [92.94799805, 13.03108025], [92.94768524, 13.03115463], [92.94735718, 13.03131962], [92.94696045, 13.03139019], [92.94655609, 13.03144932], [92.94625854, 13.03161621], [92.94599152, 13.03170013], [92.94577789, 13.03186035], [92.94551086, 13.03197098], [92.94521332, 13.03213501], [92.94483948, 13.03227234], [92.94448853, 13.03250027], [92.94415283, 13.0327549], [92.94374084, 13.03293133], [92.94332886, 13.03317928], [92.94290161, 13.03349209], [92.94246674, 13.03385162], [92.9420166, 13.0342207], [92.94161224, 13.03463078], [92.94117737, 13.03495026], [92.9407959, 13.03527164], [92.9404068, 13.03556061], [92.94007111, 13.03586197], [92.93974304, 13.03619003], [92.93945312, 13.03654957], [92.93914032, 13.03690147], [92.938797, 13.0372324], [92.93842316, 13.03756046], [92.93804932, 13.03794479], [92.93767548, 13.03831387], [92.93728638, 13.03865242], [92.93695831, 13.03903198], [92.9367218, 13.03945065], [92.93662262, 13.03995132], [92.93638611, 13.0402813], [92.9366684, 13.04056072], [92.93611145, 13.04111099], [92.93611145, 13.04139137], [92.93585205, 13.04166889], [92.93548584, 13.04194927], [92.93508911, 13.04230022], [92.93477631, 13.04280186], [92.93465424, 13.04346466], [92.93445587, 13.04408264], [92.93432617, 13.04466248], [92.93419647, 13.04510117], [92.93416595, 13.04549122], [92.93416595, 13.04585075], [92.93416595, 13.04621124], [92.9341507, 13.04658699], [92.93405151, 13.04699135], [92.93369293, 13.04742241], [92.93367004, 13.04782963], [92.93386841, 13.04819393], [92.93409729, 13.04854107], [92.93438721, 13.04884243], [92.93466949, 13.04914665], [92.9348526, 13.04959965], [92.93499756, 13.05017853], [92.93515778, 13.05079937], [92.93541718, 13.05131912], [92.93582153, 13.05163097], [92.93631744, 13.05176067], [92.93678284, 13.05189991], [92.93724823, 13.05194092], [92.93769836, 13.05189991], [92.93807983, 13.05170631], [92.93843079, 13.05167007], [92.93875885, 13.05165195], [92.9390564, 13.05166531], [92.93937683, 13.05169964], [92.93971252, 13.05189991], [92.94007874, 13.0519886], [92.94036865, 13.05218029], [92.9406662, 13.05236053], [92.94093323, 13.05259132], [92.941185, 13.05281639], [92.94142914, 13.05304241], [92.94168854, 13.05326271], [92.94197083, 13.05346107], [92.942276, 13.05364132], [92.94249725, 13.05389023], [92.94249725, 13.05416775], [92.94304657, 13.05472183], [92.9430542, 13.05500031], [92.94282532, 13.0552597], [92.94271088, 13.05558586], [92.94249725, 13.05586147], [92.94223022, 13.05618], [92.94194794, 13.05654716], [92.94165802, 13.05694199], [92.94143677, 13.05737019], [92.94128418, 13.05783463], [92.94111633, 13.05827045], [92.94095612, 13.05868053], [92.94093323, 13.05911064], [92.94093323, 13.05955982], [92.94094086, 13.06005478], [92.94106293, 13.06058121], [92.94114685, 13.06115341], [92.94135284, 13.06166363], [92.94165802, 13.06221962], [92.94165802, 13.0625], [92.94194794, 13.06278133], [92.94194794, 13.06305695], [92.9422226, 13.0633297], [92.94194794, 13.06361008], [92.94194794, 13.06417084], [92.94146729, 13.06449032], [92.94114685, 13.06476974], [92.94085693, 13.06510544], [92.94058228, 13.06554127], [92.94032288, 13.06608105], [92.94001007, 13.06662083], [92.93971252, 13.06717014], [92.93943787, 13.06767368], [92.93917084, 13.06812477], [92.93894958, 13.06856537], [92.93878174, 13.06904411], [92.93863678, 13.06954098], [92.93856049, 13.07008076], [92.93830872, 13.07057953], [92.93817902, 13.07108593], [92.93817902, 13.07165146], [92.93817902, 13.07219982], [92.93815613, 13.07269001], [92.93818665, 13.07314587], [92.93830872, 13.07359982], [92.93842316, 13.07409191], [92.93852234, 13.0746212], [92.93858337, 13.07516766], [92.93860626, 13.07570267], [92.93859863, 13.07619095], [92.93862915, 13.0766058], [92.93872833, 13.07693386], [92.93881226, 13.07721233], [92.9388504, 13.07746983], [92.938797, 13.07773018], [92.93867493, 13.07795715], [92.93852234, 13.07818127], [92.93844604, 13.07846069], [92.93844604, 13.07877064], [92.93841553, 13.07905579], [92.93824005, 13.07929993], [92.93819427, 13.07998562], [92.9380188, 13.08045101], [92.93776703, 13.08115101], [92.93763733, 13.08162022], [92.93762207, 13.08220577], [92.93750763, 13.08316517], [92.9373703, 13.08359241], [92.93709564, 13.08443928], [92.93667603, 13.08471298], [92.93605804, 13.08455753], [92.93585205, 13.08388996], [92.93585205, 13.08355045], [92.93582916, 13.08316135], [92.93585205, 13.0828104], [92.93587494, 13.08251095], [92.93605804, 13.0822401], [92.93611145, 13.08189964], [92.93611145, 13.08154488], [92.93611145, 13.08117771], [92.9361496, 13.08081055], [92.93630981, 13.08045101], [92.93637848, 13.08003235], [92.93638611, 13.07958889], [92.93643188, 13.07917023], [92.93657684, 13.07880974], [92.93666077, 13.07841969], [92.9366684, 13.07802105], [92.9366684, 13.07761097], [92.9366684, 13.07717991], [92.9366684, 13.07673073], [92.9366684, 13.0757103], [92.9366684, 13.07516956], [92.9366684, 13.07462978], [92.9366684, 13.07409191], [92.93662262, 13.07355404], [92.93643188, 13.07302284], [92.93638611, 13.07242393], [92.93638611, 13.07181072], [92.93638611, 13.07121086], [92.93634796, 13.07064056], [92.9361496, 13.07014179], [92.93611145, 13.06965923], [92.93611145, 13.06922245], [92.93611145, 13.06879997], [92.93611145, 13.06836033], [92.93611145, 13.0666256], [92.93611145, 13.06621075], [92.93611145, 13.06575012], [92.93611145, 13.06525135], [92.9360733, 13.06472015], [92.93586731, 13.06421185], [92.93579865, 13.06365967], [92.93560791, 13.06317043], [92.9355011, 13.06266403], [92.93530273, 13.06221104], [92.93515778, 13.06172085], [92.93492889, 13.06131268], [92.93467712, 13.06096363], [92.93435669, 13.06074333], [92.934021, 13.06058407], [92.93364716, 13.06058979], [92.93327332, 13.06076145], [92.93284607, 13.06092072], [92.93250275, 13.06115627], [92.93221283, 13.06138134], [92.93190002, 13.06157112], [92.93157196, 13.06168175], [92.93125916, 13.0617981], [92.93091583, 13.06191921], [92.93054199, 13.06200123], [92.93022919, 13.06218815], [92.92985535, 13.06228828], [92.92949677, 13.06245327], [92.92913055, 13.06243038], [92.9287796, 13.06226063], [92.92842102, 13.06221104], [92.92810059, 13.06212044], [92.92781067, 13.06195641], [92.92752075, 13.06182098], [92.92722321, 13.06167126], [92.9263916, 13.06084061], [92.9263916, 13.06056118], [92.92624664, 13.06028271], [92.9263916, 13.06000042], [92.92624664, 13.0595808], [92.92610168, 13.05906582], [92.92589569, 13.05852985], [92.92572784, 13.05799007], [92.92542267, 13.057621], [92.92515564, 13.05725574], [92.92482758, 13.0569706], [92.92440796, 13.05677986], [92.92391968, 13.05665016], [92.9234314, 13.05649853], [92.922966, 13.05643845], [92.92254639, 13.05659103], [92.92212677, 13.05670929], [92.92182922, 13.05692959], [92.92153168, 13.05714893], [92.9212265, 13.05737019], [92.92093658, 13.0576086], [92.92076111, 13.05799484], [92.92055511, 13.05840015], [92.92034149, 13.05884933], [92.92019653, 13.05938911], [92.91998291, 13.05990028], [92.91966248, 13.06036854], [92.91942596, 13.06089973], [92.91918945, 13.06138992], [92.91900635, 13.06185341], [92.91880798, 13.06228161], [92.91866302, 13.06275558], [92.91867065, 13.06327057], [92.91854095, 13.06371975], [92.91851807, 13.06422997], [92.9182663, 13.06459045], [92.91823578, 13.06504631], [92.91806793, 13.06535244], [92.91805267, 13.06555367], [92.91777802, 13.06583214], [92.91777802, 13.06611061], [92.91750336, 13.06639099], [92.91750336, 13.0666666], [92.91694641, 13.06721973], [92.91694641, 13.06750107], [92.91665649, 13.06778145], [92.91666412, 13.06805515], [92.91638947, 13.06833267], [92.91638947, 13.06861115], [92.91555786, 13.06944466], [92.9154129, 13.06965542], [92.91519928, 13.06995106], [92.91490936, 13.07034969], [92.9136734, 13.07003117], [92.91336823, 13.06995106], [92.9131546, 13.06982327], [92.91287231, 13.06975746], [92.91287994, 13.06965542], [92.91306305, 13.06771088], [92.91306305, 13.06721973], [92.91291809, 13.06652546], [92.91278076, 13.06611061], [92.9126358, 13.06583214], [92.91249847, 13.06555367], [92.91207886, 13.06423855], [92.91152954, 13.0633297], [92.91138458, 13.06312466], [92.91139221, 13.06277847], [92.91139221, 13.0625], [92.91123962, 13.06208134], [92.91110992, 13.06179237], [92.9109726, 13.06155014], [92.9107666, 13.0613308], [92.91049194, 13.06115055], [92.91010284, 13.0610714], [92.90973663, 13.06088161], [92.90934753, 13.06083393], [92.90898132, 13.0607996], [92.90866852, 13.06064129], [92.90828705, 13.06053066], [92.9079361, 13.06035137], [92.907547, 13.0602417], [92.90726471, 13.06007099], [92.90693665, 13.06000042], [92.90660858, 13.05992031], [92.90628815, 13.05976105], [92.90590668, 13.05972195], [92.90552521, 13.05968571], [92.90518188, 13.05951023], [92.90472412, 13.05944443], [92.90361023, 13.05944443], [92.90333557, 13.05972195], [92.90249634, 13.05972195], [92.90222168, 13.05944443], [92.90194702, 13.05972195], [92.90000153, 13.05972195], [92.89971924, 13.05944443], [92.89861298, 13.05944443], [92.89833069, 13.05916595], [92.89778137, 13.05917072], [92.89749908, 13.05889034], [92.8972168, 13.05889034], [92.89694214, 13.05860996], [92.89666748, 13.05860996], [92.89583588, 13.05777836], [92.89554596, 13.05778027], [92.89444733, 13.05667019], [92.89431, 13.05653095], [92.89417267, 13.05611038], [92.89360809, 13.0555563], [92.89362335, 13.05527973], [92.88999939, 13.05167007], [92.88999939, 13.05138969], [92.8897171, 13.05110931], [92.88972473, 13.0508337], [92.88944244, 13.05055523], [92.88944244, 13.05027962], [92.88880157, 13.04899025], [92.88838196, 13.04817104], [92.88817596, 13.047472], [92.88790131, 13.04651165], [92.88790131, 13.04568672], [92.88818359, 13.04555035], [92.88846588, 13.04555035], [92.88874054, 13.04582405], [92.88895416, 13.04589462], [92.88910675, 13.04611111], [92.88931274, 13.04618168], [92.88944244, 13.04638863], [92.88999939, 13.04694462], [92.88999939, 13.04722118], [92.89025879, 13.04750061], [92.89015961, 13.04889202], [92.89029694, 13.04930401], [92.89043427, 13.05040264], [92.8914566, 13.05146027], [92.89167023, 13.05167007], [92.89193726, 13.05167007], [92.89305878, 13.05277824], [92.89333344, 13.0530529], [92.89499664, 13.05444431], [92.89499664, 13.05472183], [92.89583588, 13.0555563], [92.89599609, 13.05613041], [92.89614868, 13.05654716], [92.8965683, 13.05723095], [92.89749908, 13.05778027], [92.89805603, 13.0580492], [92.89861298, 13.0580492], [92.89916992, 13.0581913], [92.89942932, 13.05807018], [92.90083313, 13.05832958], [92.90110779, 13.05833435], [92.90249634, 13.05833435], [92.90297699, 13.05821323], [92.90499878, 13.05805588], [92.90538788, 13.05780983], [92.90574646, 13.05773926], [92.90608215, 13.05756378], [92.90644836, 13.05750465], [92.90682983, 13.05746365], [92.90718079, 13.05729485], [92.90760803, 13.05722427], [92.90808868, 13.05716038], [92.90854645, 13.05698013], [92.90908051, 13.0569191], [92.90960693, 13.05677986], [92.9101181, 13.05662918], [92.91053772, 13.05638981], [92.91094971, 13.05615139], [92.91140747, 13.05607128], [92.91179657, 13.05587006], [92.91220856, 13.05572033], [92.91261292, 13.05555058], [92.91298676, 13.05536175], [92.91339111, 13.05528927], [92.91375732, 13.05527973], [92.91407776, 13.05527973], [92.91439056, 13.05527973], [92.914711, 13.05525017], [92.91505432, 13.05510712], [92.91545105, 13.05497932], [92.91580963, 13.05473995], [92.91610718, 13.05445957], [92.91629028, 13.05414963], [92.91615295, 13.0537796], [92.91610718, 13.05338192], [92.91604614, 13.0530014], [92.91591644, 13.05261993], [92.91584778, 13.05220795], [92.91587067, 13.05174065], [92.91603088, 13.05123043], [92.91587067, 13.05076122], [92.91578674, 13.05027103], [92.91555786, 13.04972076], [92.91555786, 13.04916668], [92.9152832, 13.0489006], [92.9152832, 13.04806042], [92.91500092, 13.04778194], [92.91500092, 13.04750061], [92.91442871, 13.0469408], [92.91444397, 13.0466671], [92.91416931, 13.04639053], [92.91416931, 13.04584026], [92.91388702, 13.04556179], [92.91388702, 13.04528236], [92.91361237, 13.04500103], [92.91361237, 13.04472065], [92.91305542, 13.04416656], [92.91306305, 13.04389095], [92.91249847, 13.04333115], [92.91249847, 13.04305458], [92.91221619, 13.04278088], [92.91221619, 13.04250145], [92.91194153, 13.04222107], [92.91194153, 13.04194546], [92.91166687, 13.04166698], [92.91168213, 13.04139137], [92.91172791, 13.04118061], [92.91190338, 13.04082108], [92.91194153, 13.04039955], [92.91188049, 13.03995991], [92.91165924, 13.03959656], [92.91139221, 13.03924179], [92.91114807, 13.03884983], [92.91092682, 13.03843021], [92.91070557, 13.03806591], [92.91049957, 13.03773975], [92.91030884, 13.03746223], [92.91022491, 13.03711319], [92.9100647, 13.03681469], [92.90996552, 13.03644753], [92.90975952, 13.03610134], [92.90972137, 13.03571129], [92.90972137, 13.03534031], [92.90976715, 13.03499985], [92.90995026, 13.03468132], [92.90990448, 13.03435802], [92.90973663, 13.03397942], [92.90962219, 13.03353024], [92.90943146, 13.03311062], [92.90917969, 13.03272057], [92.90895081, 13.0323019], [92.90869904, 13.03192139], [92.90847778, 13.03154087], [92.90827942, 13.03117085], [92.90803528, 13.0308609], [92.90777588, 13.03056717], [92.90750885, 13.03029156], [92.90724182, 13.03001118], [92.90705109, 13.0296917], [92.90689087, 13.02934074], [92.90661621, 13.02908134], [92.90637207, 13.02878475], [92.9061203, 13.02850342], [92.90589142, 13.02821064], [92.90574646, 13.02784157], [92.90556335, 13.02748394], [92.90541077, 13.02707386], [92.90524292, 13.02665234], [92.90503693, 13.02624226], [92.90494537, 13.02574158], [92.90476227, 13.02531624], [92.90466309, 13.02488995], [92.90450287, 13.02453041], [92.90444946, 13.02413273], [92.90444183, 13.02371407], [92.90439606, 13.02330208], [92.90416718, 13.02305508], [92.90416718, 13.02278042], [92.90389252, 13.02250195], [92.90389252, 13.02222061], [92.90361023, 13.02194309], [92.90297699, 13.02229023], [92.90248871, 13.02250195], [92.90207672, 13.02243137], [92.90194702, 13.02222061], [92.90166473, 13.02180386], [92.90249634, 13.02166653], [92.90277863, 13.02153111], [92.90305328, 13.02139187], [92.9033432, 13.02083111], [92.90346527, 13.02042294], [92.90359497, 13.02013111], [92.90367126, 13.01985073], [92.90383911, 13.01963043], [92.9039917, 13.01935196], [92.90422821, 13.01910114], [92.9045105, 13.01882458], [92.90480804, 13.01853085], [92.90511322, 13.01818943], [92.90532684, 13.01774025], [92.90551758, 13.01727104], [92.90555573, 13.01677418], [92.90550995, 13.01631355], [92.90531921, 13.01595783], [92.90516663, 13.0156002], [92.9050293, 13.01528072], [92.90503693, 13.0150032], [92.90519714, 13.01477528], [92.90529633, 13.01450157], [92.90545654, 13.01425266], [92.9056015, 13.013978], [92.90579987, 13.01371098], [92.90592957, 13.01338482], [92.90611267, 13.01307964], [92.90626526, 13.01275444], [92.90637207, 13.01238155], [92.90638733, 13.01197433], [92.90633392, 13.01156616], [92.90615845, 13.01120186], [92.90611267, 13.01085091], [92.9061203, 13.01051998], [92.90619659, 13.01021004], [92.9063797, 13.00991154], [92.90651703, 13.00959015], [92.90667725, 13.00927067], [92.90688324, 13.00895023], [92.90708923, 13.0085783], [92.90727997, 13.00816059], [92.90756226, 13.00778103], [92.90785217, 13.0074091], [92.90802002, 13.0069418], [92.90802002, 13.00642014], [92.90783691, 13.00596237], [92.90773773, 13.00549507], [92.90750122, 13.00527763], [92.90750122, 13.00360107], [92.90777588, 13.00333405], [92.90777588, 13.00305557], [92.90805817, 13.00277996], [92.90827179, 13.00238132], [92.90840149, 13.00191021], [92.90857697, 13.00152397], [92.90860748, 13.00114441], [92.90860748, 13.00082493], [92.90862274, 13.00054359], [92.90805817, 13.0], [92.90865326, 12.99972153], [92.90892029, 12.99970627], [92.90936279, 12.99944115], [92.909729, 12.9991684], [92.91004944, 12.99890137], [92.91034698, 12.9986496], [92.91069794, 12.99847317], [92.91114044, 12.99829674], [92.91160583, 12.9981308], [92.91181183, 12.99810791], [92.91207123, 12.99827671], [92.9124527, 12.99842167], [92.9128418, 12.99868011], [92.91311646, 12.99910164], [92.91327667, 12.99951172], [92.91388702, 13.00000191], [92.91339111, 13.00049877], [92.91342926, 13.0010004], [92.91357422, 13.00135994], [92.91384125, 13.00156498], [92.91417694, 13.00148964], [92.91445923, 13.00163174], [92.91477966, 13.00161076], [92.91506195, 13.00138092], [92.91536713, 13.00104141], [92.91598511, 13.00055122], [92.91583252, 13.0], [92.91603088, 12.99952126], [92.91609192, 12.99915218], [92.91631317, 12.99861622], [92.91616821, 12.9980011], [92.91615295, 12.99742413], [92.91605377, 12.99679661], [92.91590118, 12.99622059], [92.91590118, 12.99563122], [92.91584015, 12.99506092], [92.91584015, 12.99452972], [92.91590118, 12.99409199], [92.91604614, 12.99376202], [92.91613007, 12.9934473], [92.91609955, 12.9929409], [92.91616058, 12.99278164], [92.91651154, 12.99219799], [92.91696167, 12.99191093], [92.91734314, 12.99147129], [92.91772461, 12.99123859], [92.91861725, 12.99072075], [92.91844177, 12.99010086], [92.91771698, 12.98995113], [92.91749573, 12.98958874], [92.91732788, 12.98925114], [92.91720581, 12.98892975], [92.91732788, 12.98854923], [92.91773224, 12.98825836], [92.91793823, 12.98789978], [92.91819763, 12.98753071], [92.91851807, 12.98722076], [92.91882324, 12.98694038], [92.91912079, 12.98671913], [92.91947937, 12.98663712], [92.91980743, 12.98650932], [92.92015076, 12.98641396], [92.92053986, 12.98638916], [92.92095947, 12.98639107], [92.92138672, 12.98639107], [92.92180634, 12.98643017], [92.92217255, 12.98659229], [92.92255402, 12.98671532], [92.92285156, 12.98698139], [92.92313385, 12.98733902], [92.92357635, 12.98755074], [92.92405701, 12.98776054], [92.92453003, 12.98794079], [92.92492676, 12.98808193], [92.92521667, 12.98827076], [92.92551422, 12.98842812], [92.92576599, 12.98861122], [92.92602539, 12.98878193], [92.92633057, 12.98891163], [92.92664337, 12.98910999], [92.92701721, 12.98925114], [92.92742157, 12.98938084], [92.92779541, 12.98929501], [92.92827606, 12.98929501], [92.92867279, 12.98941326], [92.92909241, 12.98945045], [92.92948914, 12.98952007], [92.92984009, 12.9896822], [92.9302597, 12.9897213], [92.93073273, 12.989748], [92.93126678, 12.98986244], [92.93187714, 12.98993301], [92.93251801, 12.98971176], [92.93309784, 12.9893446], [92.93338776, 12.98877907], [92.93335724, 12.98820114], [92.93334198, 12.98763084], [92.93331909, 12.98709106], [92.9332428, 12.98660469], [92.93305206, 12.9861927], [92.93280029, 12.98583508], [92.93251038, 12.98551083], [92.93221283, 12.98521042], [92.93190002, 12.98495102], [92.931633, 12.98466969], [92.93138885, 12.98438072], [92.93119049, 12.98407078], [92.93094635, 12.98376083], [92.93097687, 12.98309994], [92.93106079, 12.98252106], [92.93088531, 12.98195267], [92.93087006, 12.98139954], [92.93090057, 12.9808979], [92.93103027, 12.98033142], [92.93148804, 12.98016739], [92.93180084, 12.9802742], [92.93215942, 12.98027134], [92.93257904, 12.98035431], [92.93306732, 12.98046303], [92.93360138, 12.98062229], [92.93414307, 12.98085022], [92.93470001, 12.98112202], [92.93527985, 12.98139286], [92.93590546, 12.98159313], [92.93651581, 12.98148155], [92.9369812, 12.98111916], [92.93733978, 12.98067856], [92.93754578, 12.98014164], [92.93773651, 12.97962189], [92.93774414, 12.97910213], [92.9376297, 12.97861671], [92.93756866, 12.97816086], [92.93777466, 12.97776413], [92.93804932, 12.97737503], [92.93830109, 12.97696686], [92.93847656, 12.976511], [92.938591, 12.97602463], [92.93856812, 12.97554016], [92.93840027, 12.97513866], [92.93828583, 12.97471046], [92.93805695, 12.97439098], [92.93786621, 12.97410011], [92.93786621, 12.97373009], [92.93776703, 12.97345924], [92.93780518, 12.97317028], [92.93789673, 12.97255039], [92.93810272, 12.97216225], [92.93835449, 12.97176266], [92.93852234, 12.97127628], [92.93834686, 12.9708519], [92.93817902, 12.97039127], [92.93802643, 12.96994209], [92.9377594, 12.96955967], [92.93744659, 12.96921062], [92.93715668, 12.96888924], [92.93690491, 12.96857262], [92.93677521, 12.96821022], [92.93656921, 12.96790028], [92.93636322, 12.9676199], [92.93609619, 12.96735954], [92.93580627, 12.96709061], [92.93544769, 12.96685028], [92.93501282, 12.96665096], [92.9345932, 12.96643925], [92.93414307, 12.96645069], [92.93373108, 12.96663094], [92.93331146, 12.96667194], [92.9329071, 12.96665096], [92.93253326, 12.96655273], [92.9322052, 12.9663868], [92.93193817, 12.96619129], [92.93171692, 12.96600246], [92.93157959, 12.965765], [92.93141937, 12.96551037], [92.93136597, 12.96514034], [92.93138123, 12.96464062], [92.93138885, 12.96402836], [92.93138885, 12.96336269], [92.93138123, 12.9627018], [92.93132782, 12.96209145], [92.93110657, 12.96158504], [92.93080902, 12.96110153], [92.93038177, 12.96066856], [92.92984772, 12.96026993], [92.92932129, 12.95985031], [92.92892456, 12.9593401], [92.92861938, 12.95880032], [92.92835236, 12.9582777], [92.92803955, 12.95782185], [92.92755127, 12.95757103], [92.92694092, 12.95755959], [92.92643738, 12.95782661], [92.9260788, 12.95823002], [92.92562866, 12.95841885], [92.92523956, 12.95886135], [92.9249115, 12.95936966], [92.92440796, 12.95969963], [92.92388916, 12.96000099], [92.9234314, 12.96028137], [92.9230423, 12.96049976], [92.92266083, 12.96058178], [92.92233276, 12.96066189], [92.92208099, 12.96064091], [92.92182922, 12.96055031], [92.92154694, 12.96043205], [92.92124176, 12.9602766], [92.92093658, 12.96010971], [92.92055511, 12.96000099], [92.92028046, 12.96000099], [92.91999817, 12.95971966], [92.91971588, 12.96000099], [92.91889191, 12.96000099], [92.9188385, 12.95952034], [92.91893768, 12.9592514], [92.91915131, 12.95894146], [92.91892242, 12.9582119], [92.91832733, 12.95722008], [92.91802216, 12.95696259], [92.91763306, 12.95689201], [92.91705322, 12.95710182], [92.91662598, 12.95724106], [92.9167099, 12.95695972], [92.91699219, 12.95653152], [92.91697693, 12.95631123], [92.91687775, 12.95605087], [92.9167099, 12.95571136], [92.91665649, 12.95517063], [92.91662598, 12.95453072], [92.91644287, 12.95390606], [92.91633606, 12.95326138], [92.91609955, 12.95271015], [92.91580963, 12.95220184], [92.91546631, 12.95169067], [92.91512299, 12.951231], [92.91477966, 12.95084953], [92.91464233, 12.95037079], [92.91445923, 12.94995022], [92.91429901, 12.94954586], [92.91413879, 12.94917011], [92.9139328, 12.94886684], [92.91387177, 12.94846153], [92.91374207, 12.94803143], [92.91356659, 12.94755745], [92.91330719, 12.94707108], [92.91300201, 12.94664955], [92.91268158, 12.94645119], [92.91234589, 12.94651985], [92.91194916, 12.94684982], [92.91144562, 12.94703674], [92.91092682, 12.94725132], [92.91044617, 12.94756126], [92.90999603, 12.9479599], [92.90956116, 12.94839096], [92.90920258, 12.94886971], [92.90891266, 12.9494009], [92.90867615, 12.94994831], [92.90822601, 12.95059013], [92.90791321, 12.95115089], [92.90782928, 12.9518528], [92.90791321, 12.95251179], [92.90814209, 12.95290756], [92.90833282, 12.95327473], [92.90836334, 12.95355129], [92.90848541, 12.95377445], [92.90859222, 12.95397472], [92.90862274, 12.95420265], [92.90862274, 12.95446014], [92.90861511, 12.95473766], [92.90862274, 12.95504093], [92.90820313, 12.95600986], [92.90809631, 12.95652962], [92.9081192, 12.95749569], [92.90821838, 12.95788956], [92.90843201, 12.9586544], [92.90844727, 12.95923042], [92.90907288, 12.96033764], [92.90920258, 12.96079159], [92.90940857, 12.96117878], [92.90953827, 12.96159172], [92.90968323, 12.96197033], [92.90969849, 12.96231937], [92.90959167, 12.96262169], [92.90944672, 12.96290398], [92.9092865, 12.96319199], [92.90904236, 12.96343994], [92.90872955, 12.96364975], [92.90841675, 12.96391201], [92.90811157, 12.96419907], [92.90782928, 12.96452045], [92.90761566, 12.9648962], [92.90727234, 12.96540928], [92.90702057, 12.96585083], [92.90682983, 12.96624088], [92.90673065, 12.96660995], [92.90662384, 12.96710491], [92.90647888, 12.96778202], [92.90639496, 12.96865463], [92.90641785, 12.96919537], [92.90647888, 12.96964169], [92.90670776, 12.97001076], [92.90692902, 12.97036171], [92.90703583, 12.97083092], [92.90711975, 12.97127056], [92.90720367, 12.97164917], [92.90716553, 12.97204399], [92.90696716, 12.9724474], [92.90679169, 12.97294426], [92.90661621, 12.97350502], [92.90638733, 12.97406101], [92.90603638, 12.9744072], [92.9058075, 12.9752512], [92.90618896, 12.97587967], [92.90639496, 12.976367], [92.90664673, 12.97677994], [92.9068985, 12.97718143], [92.90711212, 12.97756767], [92.9072113, 12.97799206], [92.9072113, 12.97842312], [92.90711975, 12.97882175], [92.90692902, 12.9791708], [92.90667725, 12.97949028], [92.90623474, 12.97967911], [92.90612793, 12.98056126], [92.90641785, 12.98125076], [92.90663147, 12.98153019], [92.90676117, 12.98188114], [92.9069519, 12.98250008], [92.90709686, 12.98275566], [92.90725708, 12.98299026], [92.90744019, 12.98330975], [92.90750122, 12.98362446], [92.90749359, 12.9839344], [92.9074173, 12.98422146], [92.90725708, 12.98448563], [92.90714264, 12.98476982], [92.90693665, 12.98502827], [92.9066391, 12.98528957], [92.90625, 12.98555946], [92.9058075, 12.98583031], [92.9053421, 12.98606014], [92.90484619, 12.98611069], [92.90438843, 12.98611546], [92.90393829, 12.98611069], [92.9034729, 12.98606968], [92.90296936, 12.9858799], [92.90239716, 12.98585129], [92.90180206, 12.98586369], [92.90162659, 12.98590469], [92.90125275, 12.98599243], [92.90068054, 12.9859581], [92.90011597, 12.98590088], [92.89962769, 12.98596001], [92.89901733, 12.98620892], [92.89850616, 12.9865818], [92.89833069, 12.98708153], [92.89813995, 12.98753071], [92.89817047, 12.98816013], [92.89837646, 12.98884106], [92.89834595, 12.98933125], [92.89837646, 12.98993969], [92.89845276, 12.99048042], [92.89840698, 12.99094868], [92.89884186, 12.99151039], [92.89853668, 12.99201107], [92.89863586, 12.99266148], [92.89914703, 12.99299622], [92.89939117, 12.99330139], [92.89940643, 12.99367142], [92.89930725, 12.99398041], [92.89903259, 12.99419689], [92.89875793, 12.99442005], [92.8984375, 12.99461555], [92.89806366, 12.99480057], [92.89768219, 12.99496269], [92.89730072, 12.99500179], [92.89720917, 12.99499702], [92.89697266, 12.9949789], [92.89671326, 12.99489212], [92.89652252, 12.99472141], [92.89634705, 12.99452114], [92.89614868, 12.99432182], [92.89598846, 12.99404716], [92.89581299, 12.99374104], [92.89554596, 12.99341965], [92.89530182, 12.99305058], [92.89509583, 12.99261475], [92.89484406, 12.99224758], [92.89453888, 12.99194527], [92.89421844, 12.99166012], [92.89389038, 12.99136162], [92.89354706, 12.99103832], [92.89319611, 12.99068928], [92.89285278, 12.99034977], [92.8924942, 12.99012184], [92.89218903, 12.98995113], [92.89196014, 12.98974133], [92.89176178, 12.98954296], [92.89156342, 12.98933792], [92.89138794, 12.98910522], [92.89122009, 12.98885536], [92.89109039, 12.98857021], [92.89092255, 12.98830128], [92.89076233, 12.98799992], [92.89054871, 12.98768139], [92.89035797, 12.98729134], [92.89015961, 12.98686028], [92.88994598, 12.98636055], [92.88970947, 12.98583031], [92.88944244, 12.98531532], [92.88916779, 12.98481178], [92.88889313, 12.98433113], [92.88861084, 12.98386574], [92.88833618, 12.98341179], [92.88806152, 12.98297024], [92.88794708, 12.98253918], [92.88777924, 12.98250008], [92.88748932, 12.98228168], [92.88722229, 12.98278999], [92.88694763, 12.98306084], [92.88666534, 12.98305416], [92.8861084, 12.98361015], [92.88583374, 12.98361015], [92.88563538, 12.98341179], [92.88555908, 12.98333454], [92.88471985, 12.98333454], [92.8842392, 12.98333454], [92.88370514, 12.98332787], [92.88317871, 12.9832592], [92.88270569, 12.98304272], [92.88230133, 12.98272419], [92.8819809, 12.98232746], [92.88182831, 12.98188114], [92.88189697, 12.98148155], [92.88212585, 12.98112202], [92.88239288, 12.98085308], [92.88271332, 12.98061562], [92.8830719, 12.98029423], [92.88342285, 12.97985363], [92.88358307, 12.97923946], [92.88356018, 12.97861004], [92.88336945, 12.97808075], [92.88323975, 12.97756767], [92.88304901, 12.97711945], [92.8828125, 12.97671127], [92.88253784, 12.97633076], [92.88228607, 12.97592068], [92.88198853, 12.97554016], [92.88168335, 12.97515011], [92.8813858, 12.97472191], [92.88110352, 12.97430038], [92.88080597, 12.97391033], [92.88049316, 12.97355938], [92.88011169, 12.97336102], [92.87976074, 12.97321129], [92.87953949, 12.97298145], [92.87947845, 12.972682], [92.87961578, 12.97233295], [92.87984467, 12.97194767], [92.88011169, 12.97158146], [92.88043976, 12.97122955], [92.88076782, 12.970891], [92.88109589, 12.97050953], [92.8813858, 12.97009087], [92.88160706, 12.96964169], [92.88159943, 12.96914005], [92.8813858, 12.96869087], [92.88111115, 12.96829033], [92.88092041, 12.96749687], [92.88031006, 12.96739674], [92.87975311, 12.96726036], [92.87927246, 12.96724606], [92.87892151, 12.96720982], [92.87856293, 12.96700191], [92.87820435, 12.96681309], [92.87783813, 12.96660328], [92.87749481, 12.96631908], [92.87711334, 12.96601105], [92.87667084, 12.96570969], [92.87623596, 12.96539116], [92.87584686, 12.965065], [92.87552643, 12.96472073], [92.8752594, 12.96436119], [92.87505341, 12.96397114], [92.87501526, 12.96349716], [92.87507629, 12.96299076], [92.87528992, 12.96253777], [92.87552643, 12.96214962], [92.87573242, 12.96179008], [92.87599182, 12.96152115], [92.87638855, 12.96136379], [92.87676239, 12.9611063], [92.87712097, 12.96079159], [92.87741089, 12.96039104], [92.87748718, 12.95983028], [92.87750244, 12.9592514], [92.87749481, 12.95868778], [92.87741852, 12.95815945], [92.87721252, 12.9576807], [92.87692261, 12.95722485], [92.87654114, 12.95683098], [92.87615204, 12.95646954], [92.8757782, 12.95605087], [92.87548065, 12.9555912], [92.87515259, 12.95516014], [92.87477875, 12.95483398], [92.87452698, 12.95446873], [92.87431335, 12.9541502], [92.87414551, 12.95384026], [92.87397766, 12.95353699], [92.87393951, 12.95321083], [92.87406921, 12.95283985], [92.87413025, 12.9524641], [92.87401581, 12.95209217], [92.87382507, 12.95173168], [92.87354279, 12.95138264], [92.87322998, 12.95101643], [92.87291718, 12.95066071], [92.8727951, 12.95028305], [92.87277985, 12.94993591], [92.87281036, 12.94964027], [92.87296295, 12.94937134], [92.87309265, 12.94908619], [92.8731308, 12.94877243], [92.87332153, 12.9485817], [92.87355042, 12.94856167], [92.87384033, 12.94841766], [92.8742981, 12.94829273], [92.87483978, 12.94810104], [92.87542725, 12.94803143], [92.87597656, 12.94787121], [92.87637329, 12.94756603], [92.87666321, 12.94721031], [92.87690735, 12.9468708], [92.87708282, 12.94651985], [92.87719727, 12.94614124], [92.87722015, 12.94571686], [92.87718964, 12.94527054], [92.87700653, 12.94486141], [92.87712097, 12.94439316], [92.87680817, 12.94399357], [92.87605286, 12.94383907], [92.87567902, 12.94355011], [92.8753891, 12.94316864], [92.87509918, 12.94273186], [92.87482452, 12.94221401], [92.87449646, 12.94167042], [92.87411499, 12.94115162], [92.87359619, 12.94079494], [92.87319183, 12.94038391], [92.87294769, 12.93989372], [92.87275696, 12.93941975], [92.87254333, 12.93903065], [92.87239075, 12.93863201], [92.87223816, 12.93825054], [92.87211609, 12.93785], [92.87187958, 12.93749046], [92.87159729, 12.93712521], [92.87133026, 12.93663979], [92.8709259, 12.93622017], [92.8704834, 12.93583107], [92.87005615, 12.93544102], [92.86972046, 12.93502617], [92.86937714, 12.93466091], [92.86889648, 12.93443775], [92.86837769, 12.93425083], [92.86782074, 12.93412971], [92.86733246, 12.93396187], [92.86699677, 12.93390179], [92.86669159, 12.93396187], [92.8660965, 12.9341011], [92.86572266, 12.93408012], [92.86519623, 12.93420124], [92.86472321, 12.93418121], [92.86414337, 12.93428993], [92.86377716, 12.93438053], [92.86325836, 12.93440247], [92.86281586, 12.93436146], [92.86232758, 12.93433094], [92.86187744, 12.93433094], [92.86154175, 12.93429661], [92.86112976, 12.93435383], [92.8607254, 12.93420601], [92.86004639, 12.93405056], [92.85980225, 12.93417645], [92.85955048, 12.93432045], [92.85926819, 12.93456554], [92.85897827, 12.93484116], [92.85869598, 12.93497086], [92.85839081, 12.93500805], [92.85782623, 12.93504238], [92.85716248, 12.93430996], [92.85735321, 12.93306065], [92.85772705, 12.93279934], [92.85778046, 12.93232059], [92.8577652, 12.93181038], [92.85765839, 12.93133163], [92.85739136, 12.93100071], [92.85714722, 12.9307003], [92.85684204, 12.93055153], [92.85654449, 12.9304266], [92.85624695, 12.93028069], [92.85595703, 12.93013], [92.85569763, 12.92996025], [92.85546112, 12.92971134], [92.85523987, 12.92940331], [92.85501862, 12.92904091], [92.8548584, 12.92861938], [92.85470581, 12.9282074], [92.85452271, 12.9278307], [92.85443878, 12.92743015], [92.85443878, 12.9270401], [92.85443878, 12.92669106], [92.85443878, 12.92636967], [92.85443878, 12.92605972], [92.85441589, 12.92572021], [92.85430908, 12.92535114], [92.85441589, 12.92492867], [92.85443878, 12.92446041], [92.85443878, 12.92394924], [92.85444641, 12.92342281], [92.85444641, 12.92286491], [92.85443878, 12.92226982], [92.85444641, 12.92166328], [92.85449219, 12.92107964], [92.85466003, 12.92060089], [92.85470581, 12.92015934], [92.85472107, 12.91975975], [92.85472107, 12.91935921], [92.85472107, 12.91893101], [92.85468292, 12.91847038], [92.85448456, 12.9180603], [92.85437775, 12.91762924], [92.8542099, 12.91729927], [92.85412598, 12.91695023], [92.85398102, 12.91665173], [92.85413361, 12.91636372], [92.85421753, 12.91612053], [92.85427856, 12.91570091], [92.85455322, 12.91578102], [92.85486603, 12.91565132], [92.85523987, 12.91534996], [92.85555267, 12.91472054], [92.85555267, 12.9141674], [92.85569, 12.91392994], [92.8557663, 12.9137907], [92.85579681, 12.91349125], [92.85581207, 12.91289997], [92.85596466, 12.91270638], [92.85632324, 12.9129343], [92.85722351, 12.91333294], [92.85778046, 12.91333294], [92.85836029, 12.91334248], [92.85900879, 12.91315842], [92.85943604, 12.91274071], [92.85962677, 12.91220093], [92.85943604, 12.91164017], [92.85913849, 12.91107178], [92.85874176, 12.9105711], [92.85830688, 12.91014004], [92.8578949, 12.90983486], [92.85753632, 12.90959072], [92.85730743, 12.9093399], [92.85723114, 12.90902138], [92.85721588, 12.90866089], [92.85721588, 12.90827084], [92.85722351, 12.90789318], [92.85723877, 12.90753746], [92.85733795, 12.90724087], [92.85748291, 12.90696144], [92.85755157, 12.90665531], [92.85772705, 12.90639973], [92.85780334, 12.90604019], [92.85792542, 12.9056797], [92.85803986, 12.90527725], [92.85813141, 12.90484142], [92.85832977, 12.90446091], [92.8585434, 12.90408039], [92.85869598, 12.90368271], [92.85892487, 12.90336895], [92.85919189, 12.9031496], [92.85948181, 12.90302944], [92.85971069, 12.90289879], [92.85996246, 12.90278053], [92.86029816, 12.90265083], [92.86076355, 12.9025116], [92.86138153, 12.90239811], [92.86206818, 12.90227032], [92.8628006, 12.90219975], [92.8635025, 12.90207195], [92.86415863, 12.90198135], [92.86474609, 12.90201092], [92.8651886, 12.90221119], [92.86548615, 12.90240002], [92.86582947, 12.90262127], [92.86586761, 12.90288067], [92.86591339, 12.90318871], [92.8658371, 12.90371132], [92.8658371, 12.90428066], [92.86591339, 12.90480042], [92.86617279, 12.90513992], [92.86644745, 12.90540886], [92.86672211, 12.90568447], [92.86701202, 12.90602016], [92.86741638, 12.90635014], [92.86786652, 12.90668964], [92.86828613, 12.90709972], [92.86864471, 12.90759182], [92.8690567, 12.90802956], [92.86952209, 12.90841007], [92.87002563, 12.90874958], [92.87056732, 12.90903854], [92.87116241, 12.9092989], [92.87181091, 12.90946102], [92.87242889, 12.90964127], [92.87303925, 12.90971184], [92.87361908, 12.90970039], [92.87414551, 12.90960026], [92.87462616, 12.9094696], [92.87509155, 12.90939045], [92.87547302, 12.9091692], [92.87578583, 12.90893173], [92.87605286, 12.90865612], [92.87625885, 12.90829182], [92.87641144, 12.90781975], [92.87661743, 12.90729141], [92.87666321, 12.90665054], [92.87663269, 12.90600109], [92.87638855, 12.9054203], [92.87610626, 12.90492344], [92.8757782, 12.90450764], [92.87541962, 12.90417957], [92.87502289, 12.90389061], [92.87465668, 12.90358067], [92.87433624, 12.90320492], [92.87394714, 12.90283108], [92.87359619, 12.90248013], [92.87332153, 12.90209007], [92.87304688, 12.90170956], [92.8727951, 12.90133953], [92.872612, 12.90092087], [92.87245178, 12.90051079], [92.87226868, 12.90013504], [92.8722229, 12.89968109], [92.87218475, 12.8992281], [92.87203979, 12.89883137], [92.87195587, 12.89843178], [92.87188721, 12.89804935], [92.87171173, 12.89773941], [92.87165833, 12.89740658], [92.87158966, 12.89705086], [92.87143707, 12.89671612], [92.87137604, 12.89630127], [92.87126923, 12.89585018], [92.8711319, 12.89540958], [92.87100983, 12.89492035], [92.87081909, 12.89442062], [92.87060547, 12.89391518], [92.87050629, 12.89333153], [92.87030792, 12.89282131], [92.87018585, 12.8923111], [92.87003326, 12.8918457], [92.86995697, 12.89135075], [92.86978149, 12.89085197], [92.86974335, 12.89031887], [92.86981201, 12.88980961], [92.86995697, 12.88936996], [92.87001801, 12.88893986], [92.87010956, 12.88854122], [92.87023163, 12.88818073], [92.87030792, 12.88773155], [92.87047577, 12.88729858], [92.8706665, 12.88689137], [92.87097168, 12.88653088], [92.87132263, 12.88615704], [92.87171936, 12.88574028], [92.87219238, 12.8853302], [92.87269592, 12.88493061], [92.87299347, 12.88448238], [92.8730545, 12.88400269], [92.87303925, 12.88357735], [92.87293243, 12.88323021], [92.8727417, 12.88294983], [92.87245941, 12.88273144], [92.87211609, 12.88253975], [92.87166595, 12.88245106], [92.87123108, 12.88228512], [92.87075806, 12.88221169], [92.87029266, 12.88209057], [92.86985016, 12.88197231], [92.86942291, 12.8819313], [92.8690567, 12.88184547], [92.86875916, 12.88162422], [92.8682785, 12.88156414], [92.86786652, 12.88146877], [92.86721802, 12.88155079], [92.8666687, 12.88152122], [92.86615753, 12.88142109], [92.86565399, 12.88132668], [92.86522675, 12.88117027], [92.86479187, 12.88110447], [92.86435699, 12.88107681], [92.86392975, 12.88109016], [92.86377716, 12.88109016], [92.86347961, 12.88108826], [92.86302185, 12.88107014], [92.86258698, 12.88094044], [92.86212921, 12.8808279], [92.86167145, 12.88069057], [92.8612442, 12.88053226], [92.86084747, 12.88031769], [92.8604126, 12.8801403], [92.85999298, 12.87983036], [92.85951233, 12.87953377], [92.85899353, 12.87927246], [92.85848236, 12.87903023], [92.85800934, 12.8788414], [92.85755157, 12.87871075], [92.85701752, 12.87870026], [92.85652161, 12.87866783], [92.85605621, 12.87852192], [92.85557556, 12.87830544], [92.85519409, 12.87834167], [92.85482788, 12.87844181], [92.85443878, 12.8785696], [92.85401917, 12.87860775], [92.85359955, 12.87861347], [92.85318756, 12.87861061], [92.85277557, 12.87861061], [92.85236359, 12.87861061], [92.85194397, 12.87861061], [92.85150909, 12.87861347], [92.85105896, 12.87861061], [92.85058594, 12.8785696], [92.85015869, 12.87839031], [92.84966278, 12.8783102], [92.84916687, 12.87819386], [92.84867096, 12.87805462], [92.84818268, 12.87790203], [92.84771729, 12.87774944], [92.84729004, 12.8775301], [92.84681702, 12.87737083], [92.84630585, 12.87721062], [92.84583282, 12.87704945], [92.84533691, 12.87689018], [92.84488678, 12.87670135], [92.84440613, 12.87656593], [92.84390259, 12.87644958], [92.84340668, 12.8763504], [92.8429718, 12.87629986], [92.84243774, 12.87652302], [92.84201813, 12.87658024], [92.84171295, 12.87662983], [92.84134674, 12.87693501], [92.84126282, 12.87718201], [92.84123993, 12.8776207], [92.84123993, 12.87801075], [92.84130859, 12.87851048], [92.84139252, 12.8791666], [92.84139252, 12.87944508], [92.84166718, 12.87972069], [92.84166718, 12.88055515], [92.84194183, 12.8808279], [92.84194183, 12.88139057], [92.84222412, 12.88166714], [92.84222412, 12.88194466], [92.84249878, 12.88222122], [92.84249878, 12.88250065], [92.84288788, 12.88314247], [92.84306335, 12.88334179], [92.84306335, 12.88361073], [92.84333038, 12.8838892], [92.84333038, 12.88444519], [92.84361267, 12.8847208], [92.84361267, 12.88528156], [92.84388733, 12.88556194], [92.84388733, 12.88640118], [92.84388733, 12.88671112], [92.84393311, 12.88776588], [92.84388733, 12.88833141], [92.84368134, 12.88936138], [92.84361267, 12.89027977], [92.84346771, 12.89099121], [92.84311676, 12.89155197], [92.84278107, 12.89187145], [92.84233856, 12.8920393], [92.84194183, 12.8921814], [92.84156799, 12.89229012], [92.83891296, 12.89185047], [92.83839417, 12.891716], [92.83782196, 12.89144039], [92.83718109, 12.89112091], [92.83653259, 12.89075184], [92.83600616, 12.89027119], [92.83553314, 12.88973713], [92.83505249, 12.88924122], [92.83467865, 12.88868046], [92.83416748, 12.88827038], [92.83365631, 12.8879118], [92.83322144, 12.88753986], [92.83280945, 12.8872509], [92.83246613, 12.88698196], [92.83216095, 12.88676071], [92.83144379, 12.88624573], [92.83100128, 12.88618183], [92.83049774, 12.88618183], [92.82997131, 12.88619995], [92.82965851, 12.88643265], [92.82917786, 12.8866396], [92.82884216, 12.88689137], [92.82849884, 12.88723946], [92.82771301, 12.88819027], [92.82762146, 12.88847733], [92.82759857, 12.88886929], [92.82758331, 12.88926125], [92.82736969, 12.89040089], [92.82723999, 12.89091969], [92.82722473, 12.89130783], [92.82714081, 12.89177036], [92.82705688, 12.89228058], [92.8265686, 12.89404011], [92.82644653, 12.89472198], [92.8264389, 12.89521027], [92.82615662, 12.89554024], [92.82579041, 12.89584064], [92.82538605, 12.89614201], [92.82499695, 12.89648056], [92.8245697, 12.89675903], [92.82406616, 12.89693928], [92.82353973, 12.89708996], [92.8229599, 12.89718628], [92.82236481, 12.89723301], [92.82205963, 12.89725876], [92.82180023, 12.89728069], [92.82125854, 12.89723969], [92.82077026, 12.89723301], [92.82032013, 12.89727211], [92.81990814, 12.8973999], [92.81947327, 12.89748192], [92.81900024, 12.89749813], [92.81851959, 12.89750195], [92.81803131, 12.89754581], [92.81755829, 12.89772129], [92.81703186, 12.89782143], [92.81655884, 12.89804268], [92.81611633, 12.89826965], [92.81565857, 12.89849758], [92.81516266, 12.89869022], [92.81456757, 12.89882183], [92.8140564, 12.89914131], [92.81350708, 12.89936447], [92.81289673, 12.89948082], [92.81230927, 12.89968109], [92.81167603, 12.89972019], [92.81099701, 12.89973068], [92.81031036, 12.8997612], [92.80961609, 12.89992142], [92.80890656, 12.9000206], [92.80818939, 12.90011024], [92.80745697, 12.9000597], [92.80675507, 12.90000534], [92.80607605, 12.89994144], [92.80554199, 12.89972019], [92.80512238, 12.89946175], [92.80480194, 12.89923], [92.80449677, 12.89907742], [92.80426025, 12.89892006], [92.80397797, 12.89881134], [92.80367279, 12.89865971], [92.80329132, 12.89863968], [92.80288696, 12.89879036], [92.80253601, 12.89904976], [92.80229187, 12.89940071], [92.80216217, 12.89983559], [92.80194092, 12.90017414], [92.80170441, 12.9004631], [92.80148315, 12.90075016], [92.80134583, 12.9011507], [92.80130768, 12.90156174], [92.8013382, 12.90195084], [92.80120087, 12.90227032], [92.80106354, 12.90264893], [92.80091095, 12.90311432], [92.80075836, 12.90367889], [92.80053711, 12.9042902], [92.8003006, 12.90489101], [92.8000946, 12.90544987], [92.79989624, 12.90592384], [92.79969025, 12.90629101], [92.79946899, 12.90659809], [92.79930878, 12.9069519], [92.79914093, 12.90732288], [92.79891968, 12.90767193], [92.79875946, 12.908041], [92.79859924, 12.90837193], [92.79842377, 12.90869713], [92.79831696, 12.90907097], [92.79817963, 12.909482], [92.79802704, 12.90994358], [92.7977829, 12.9104023], [92.79750061, 12.91088104], [92.79719543, 12.91137505], [92.79679871, 12.91181278], [92.79638672, 12.91222095], [92.79599762, 12.91258144], [92.79557037, 12.91281128], [92.79551697, 12.9129982], [92.79463959, 12.91349125], [92.79438782, 12.91382599], [92.79419708, 12.91438198], [92.79430389, 12.91522884], [92.79493713, 12.91575432], [92.79502869, 12.91631889], [92.7951889, 12.91687965], [92.7952652, 12.91746521], [92.79522705, 12.91807175], [92.79505157, 12.91866016], [92.7950058, 12.91928196], [92.79506683, 12.9198494], [92.79522705, 12.92034245], [92.79527283, 12.92084122], [92.79528046, 12.92132187], [92.79512024, 12.92208672], [92.79503632, 12.92227364], [92.79515839, 12.92313957], [92.7952652, 12.92345047], [92.79538727, 12.92383957], [92.79543304, 12.92405033], [92.79547119, 12.92467022], [92.79548645, 12.92525959], [92.7953186, 12.92605972], [92.79506683, 12.92644119], [92.79477692, 12.92688274], [92.79447937, 12.92735004], [92.79389191, 12.92801952], [92.79380798, 12.92851925], [92.79366302, 12.92892933], [92.7935791, 12.92923927], [92.7935791, 12.92971325], [92.79361725, 12.92996025], [92.79374695, 12.93035603], [92.79385376, 12.93064308], [92.79405975, 12.93089199], [92.7942276, 12.93100071], [92.79476166, 12.93093967], [92.79502869, 12.93082142], [92.79528046, 12.93057919], [92.79554749, 12.9304018], [92.79586029, 12.93030071], [92.79624176, 12.93028069], [92.79667664, 12.93028069], [92.79712677, 12.93028069], [92.79753113, 12.9302702], [92.79785156, 12.93029022], [92.79811096, 12.93035793], [92.79833984, 12.93052006], [92.79857635, 12.93062973], [92.79873657, 12.93081188], [92.79886627, 12.93104172], [92.79892731, 12.9314003], [92.79911804, 12.93185997], [92.79917908, 12.93242073], [92.79928589, 12.93298912], [92.79947662, 12.93350124], [92.79972076, 12.93396854], [92.79997253, 12.93439198], [92.80031586, 12.93465042], [92.80053711, 12.93496704], [92.80078888, 12.93521118], [92.80094147, 12.93552971], [92.8010788, 12.93586922], [92.80110931, 12.93629074], [92.80111694, 12.93677044], [92.80117035, 12.93728161], [92.80136108, 12.93772221], [92.80151367, 12.93817139], [92.80164337, 12.93858242], [92.80164337, 12.9389801], [92.80149078, 12.93937016], [92.80134583, 12.93982124], [92.80108643, 12.94031143], [92.80072784, 12.94078064], [92.80027008, 12.94120026], [92.79981232, 12.94161034], [92.79951477, 12.94213676], [92.79944611, 12.94276428], [92.79949951, 12.94335175], [92.79972076, 12.94380474], [92.79998016, 12.94419956], [92.80021667, 12.94460106], [92.80034637, 12.94510746], [92.80051422, 12.94564247], [92.80055237, 12.9461689], [92.80055237, 12.94639015], [92.80055237, 12.94666576], [92.80027008, 12.94694138], [92.80027008, 12.94750023], [92.80000305, 12.94777966], [92.80000305, 12.94805622], [92.79972076, 12.94833183], [92.79950714, 12.94852066], [92.79921722, 12.94868946], [92.79895782, 12.94888973], [92.79869843, 12.94906139], [92.79837799, 12.94914055], [92.79795837, 12.94917011], [92.7974472, 12.94916821], [92.79688263, 12.94920921], [92.79634094, 12.94941044], [92.79579926, 12.94952106], [92.79541779, 12.94974041], [92.79514313, 12.94999981], [92.7949295, 12.95023918], [92.79469299, 12.95043087], [92.79441833, 12.95060158], [92.79412079, 12.95083046], [92.79376221, 12.95107079], [92.79332733, 12.95125961], [92.7928772, 12.95147038], [92.79277802, 12.95167065], [92.79265594, 12.95229053], [92.79269409, 12.95253658], [92.79268646, 12.95368958], [92.79263306, 12.95390034], [92.79269409, 12.95421028], [92.79273987, 12.95462036], [92.79263306, 12.95505524], [92.79244232, 12.95530128], [92.79210663, 12.95543957], [92.79190063, 12.95569134], [92.79177094, 12.95608139], [92.79173279, 12.95631123], [92.79173279, 12.95672131], [92.7918396, 12.95707035], [92.79196167, 12.95728016], [92.79216766, 12.95762825], [92.79250336, 12.95833015], [92.79250336, 12.9591713], [92.79194641, 12.96028137], [92.79263306, 12.9604454], [92.7928009, 12.96079159], [92.79277802, 12.96150112], [92.79273987, 12.96168137], [92.79224396, 12.96144581], [92.7921524, 12.96140003], [92.7918396, 12.9613409], [92.79161072, 12.96155071], [92.79158783, 12.9618988], [92.79167175, 12.96229362], [92.79194641, 12.9644289], [92.79219055, 12.96472073], [92.79222107, 12.96521759], [92.79227448, 12.96576214], [92.79224396, 12.96591282], [92.79231262, 12.96626186], [92.79243469, 12.9664917], [92.79248047, 12.96690369], [92.79248047, 12.96714973], [92.79266357, 12.96737766], [92.79279327, 12.96745968], [92.79298401, 12.9676466], [92.79321289, 12.96779346], [92.79347992, 12.96784973], [92.79393005, 12.96794128], [92.79411316, 12.9677906], [92.79433441, 12.96761322], [92.79471588, 12.9671936], [92.7950592, 12.96675205], [92.79543304, 12.966362], [92.79574585, 12.96594048], [92.79598236, 12.96543026], [92.79618073, 12.96500111], [92.79640961, 12.96471024], [92.79663086, 12.96454144], [92.79683685, 12.96459579], [92.79701996, 12.96478462], [92.79715729, 12.96501541], [92.79714203, 12.96536446], [92.79693604, 12.9657917], [92.79655457, 12.96628857], [92.79647064, 12.96669006], [92.79660034, 12.96707058], [92.79670715, 12.9675312], [92.79695129, 12.96799564], [92.79722595, 12.96846104], [92.79760742, 12.97071743], [92.79754639, 12.97120953], [92.79727173, 12.97166824], [92.79710388, 12.97183418], [92.79614258, 12.97272968], [92.79589081, 12.97313976], [92.79556274, 12.97362137], [92.79555511, 12.9738903], [92.79499817, 12.97444057], [92.7943573, 12.97523022], [92.79413605, 12.97556019], [92.79385376, 12.97654724], [92.79385376, 12.97704411], [92.79347229, 12.97890186], [92.79328156, 12.97928047], [92.79315186, 12.9796114], [92.79294586, 12.97998047], [92.7929306, 12.98033142], [92.79301453, 12.98092842], [92.79302979, 12.98134041], [92.79310608, 12.98178005], [92.79329681, 12.98215199], [92.79390717, 12.98291969], [92.79383087, 12.98329067], [92.79395294, 12.98343945], [92.79418945, 12.98397541], [92.79416656, 12.98449039], [92.79408264, 12.985322], [92.79413605, 12.98561096], [92.79427338, 12.98569107], [92.79447937, 12.98575115], [92.79458618, 12.98598099], [92.79464722, 12.98631096], [92.7946701, 12.98647976], [92.79486084, 12.98711586], [92.79502869, 12.98734093], [92.79511261, 12.98742962], [92.79528046, 12.98750973], [92.79543304, 12.98750973], [92.79756927, 12.98928547], [92.79842377, 12.98982334], [92.79873657, 12.9901104], [92.79892731, 12.99053001], [92.79899597, 12.99082184], [92.79910278, 12.99119091], [92.79915619, 12.99131203], [92.79930878, 12.99145508], [92.79968262, 12.99166298], [92.79995728, 12.99158096], [92.80053711, 12.9911499], [92.8009491, 12.99083996], [92.8014679, 12.99042034], [92.80165863, 12.98990536], [92.80197144, 12.98953247], [92.80229187, 12.98895454], [92.80246735, 12.98851967], [92.8025589, 12.98814964], [92.80259705, 12.98767185], [92.80274963, 12.98732281], [92.80310822, 12.98684692], [92.80342102, 12.98629093], [92.80355072, 12.9857893], [92.80361176, 12.98527908], [92.80361176, 12.98500061], [92.80444336, 12.98417091], [92.80473328, 12.98417091], [92.80500031, 12.98389053], [92.80526733, 12.98389053], [92.80583191, 12.98332977], [92.8061142, 12.98333454], [92.80638885, 12.98305416], [92.80805206, 12.98305416], [92.80833435, 12.98333454], [92.8088913, 12.98333454], [92.80932617, 12.98338032], [92.80973053, 12.98360062], [92.81017303, 12.98378086], [92.81056976, 12.98391056], [92.81080627, 12.98425102], [92.81128693, 12.98420143], [92.81167603, 12.98384953], [92.81200409, 12.98361492], [92.81228638, 12.9833889], [92.81259155, 12.98322964], [92.81285858, 12.98307037], [92.81317902, 12.98306084], [92.81355286, 12.98313427], [92.81398773, 12.98336697], [92.81440735, 12.98374939], [92.81479645, 12.98425961], [92.81510162, 12.98484993], [92.81500244, 12.98535156], [92.81502533, 12.98567963], [92.81507111, 12.98598957], [92.81521606, 12.98628235], [92.81542206, 12.9865694], [92.81564331, 12.98673058], [92.81597137, 12.98681927], [92.81645203, 12.98681927], [92.81668854, 12.98673058], [92.81700134, 12.98669434], [92.81712341, 12.98667145], [92.81788635, 12.98667145], [92.81826019, 12.98678112], [92.818367, 12.98720932], [92.8188858, 12.98778057], [92.81916809, 12.98805523], [92.81890106, 12.98860168], [92.81884003, 12.98897076], [92.8187561, 12.98919201], [92.818367, 12.98946095], [92.81820679, 12.98968887], [92.81815338, 12.98983002], [92.81749725, 12.99053669], [92.81703186, 12.99075985], [92.81663513, 12.99090767], [92.81613159, 12.99105358], [92.81466675, 12.99086666], [92.81408691, 12.99090958], [92.81332397, 12.99126053], [92.81302643, 12.99168968], [92.81285095, 12.99215031], [92.81260681, 12.99255085], [92.81242371, 12.9929657], [92.81218719, 12.99330139], [92.81192017, 12.99357033], [92.81161499, 12.99377823], [92.81126404, 12.99387264], [92.81086731, 12.99388027], [92.81047821, 12.99390125], [92.81028748, 12.99387074], [92.81003571, 12.99368858], [92.80869293, 12.99362946], [92.80840302, 12.99403954], [92.80844116, 12.99424744], [92.8086319, 12.99441147], [92.80877686, 12.99446964], [92.80893707, 12.99455929], [92.80908966, 12.9946413], [92.80914307, 12.99495125], [92.80908966, 12.99578094], [92.80905151, 12.99611092], [92.80898285, 12.9965601], [92.80900574, 12.99695206], [92.80900574, 12.99724197], [92.80882263, 12.99744034], [92.80873108, 12.99760723], [92.80869293, 12.99777126], [92.80890656, 12.99801922], [92.80903625, 12.9980402], [92.80930328, 12.9980402], [92.80990601, 12.99808979], [92.81008148, 12.99808979], [92.81066132, 12.99844456], [92.81130981, 12.99875069], [92.81147766, 12.99875832], [92.81199646, 12.99878025], [92.81222534, 12.99868679], [92.81255341, 12.99855232], [92.81283569, 12.99824047], [92.81327057, 12.99799156], [92.81363678, 12.99808121], [92.8139267, 12.9981308], [92.8141861, 12.99829865], [92.81442261, 12.9985714], [92.81490326, 12.99855042], [92.81510925, 12.99860001], [92.8154068, 12.99867058], [92.81598663, 12.99864101], [92.81624603, 12.9988327], [92.81639099, 12.99889183], [92.81671143, 12.99894047], [92.81697083, 12.99914265], [92.81777954, 13.00000191], [92.81832886, 13.00028038], [92.8188858, 13.00055981], [92.8188858, 13.00111198], [92.81916809, 13.0013876], [92.81916809, 13.00222015], [92.81944275, 13.00249958], [92.81944275, 13.00333405], [92.81973267, 13.00360107], [92.81972504, 13.00416565], [92.81999969, 13.00444412], [92.81999969, 13.00472164], [92.82020569, 13.00492859], [92.8208313, 13.00556087], [92.82111359, 13.00555611], [92.82138824, 13.00583363], [92.82250214, 13.00583363], [92.82277679, 13.00611019], [92.82305908, 13.00611019], [92.82333374, 13.00638771], [92.82333374, 13.0069437], [92.8236084, 13.00722027], [92.8236084, 13.00889111], [92.82389069, 13.00916576], [92.82389069, 13.00944042], [92.82417297, 13.00972939], [92.82416534, 13.0102787], [92.82472229, 13.01083469], [92.82472229, 13.01111031], [92.82499695, 13.01139069], [92.82499695, 13.01166725], [92.82527924, 13.01194], [92.82506561, 13.01270771], [92.82478333, 13.01298428], [92.82450104, 13.01298428], [92.8236084, 13.01277637], [92.82305908, 13.01222324], [92.82277679, 13.01222324], [92.82250214, 13.01194477], [92.82221985, 13.01194477], [92.82184601, 13.01157284], [92.8216629, 13.01138878], [92.82139587, 13.01167107], [92.82110596, 13.01139069], [92.8208313, 13.01167107], [92.81973267, 13.01167107], [92.81944275, 13.01139069], [92.81861115, 13.01139069], [92.81832886, 13.01111031], [92.8180542, 13.01111031], [92.81777954, 13.01083469], [92.81749725, 13.01083469], [92.8172226, 13.01055431], [92.81667328, 13.01056099], [92.8161087, 13.01000118], [92.8161087, 13.00972939], [92.81582642, 13.00944042], [92.81583405, 13.00888824], [92.81555176, 13.00860977], [92.81555176, 13.00806141], [92.81526947, 13.00778103], [92.81526947, 13.00749969], [92.81500244, 13.00722027], [92.81472015, 13.00722027], [92.81305695, 13.00889111], [92.81276703, 13.00889111], [92.8125, 13.00917053], [92.81083679, 13.00917053], [92.81054688, 13.00889111], [92.80999756, 13.00889111], [92.8097229, 13.00860977], [92.80944824, 13.00860977], [92.80916595, 13.00833225], [92.8088913, 13.00833225], [92.80860901, 13.00805569], [92.80832672, 13.00806141], [92.80742645, 13.0071516], [92.80722046, 13.0069418], [92.80666351, 13.0069437], [92.80638885, 13.00666618], [92.8061142, 13.0069437], [92.80583191, 13.0069418], [92.80500031, 13.00778103], [92.80500031, 13.00916576], [92.80526733, 13.00944042], [92.80526733, 13.01028061], [92.80555725, 13.01055431], [92.80555725, 13.01111031], [92.80472565, 13.01194477], [92.80444336, 13.01194477], [92.8041687, 13.01222324], [92.80361176, 13.01222324], [92.8035202, 13.01212883], [92.8033371, 13.01194477], [92.80305481, 13.01194477], [92.80194092, 13.01083469], [92.80194092, 13.01055431], [92.80110931, 13.00972939], [92.80000305, 13.00972939], [92.79980469, 13.00953102], [92.79972076, 13.00944424], [92.79888916, 13.00944042], [92.79860687, 13.00972939], [92.79833221, 13.00972176], [92.79722595, 13.01083469], [92.79694366, 13.01083469], [92.79666901, 13.01111031], [92.79638672, 13.01111031], [92.79611206, 13.01139069], [92.79389191, 13.01139069], [92.79360962, 13.01111031], [92.79277802, 13.01111031], [92.79250336, 13.01139069], [92.79222107, 13.01139069], [92.79138947, 13.01195145], [92.79111481, 13.01194477], [92.79083252, 13.01222324], [92.79096985, 13.01277637], [92.79068756, 13.01318359], [92.79083252, 13.01333046], [92.79055023, 13.01389122], [92.78943634, 13.0150013], [92.78943634, 13.01528072], [92.78958893, 13.01555538], [92.78944397, 13.0158329], [92.78916931, 13.01611137], [92.78916931, 13.01638889], [92.78888702, 13.01666737], [92.78888702, 13.01694489], [92.78861237, 13.01722145], [92.78861237, 13.01805496], [92.78833008, 13.01833057], [92.78833008, 13.01917171], [92.78943634, 13.02028179], [92.78944397, 13.02055454], [92.78971863, 13.02083111], [92.78971863, 13.02166653], [92.79000092, 13.02194118], [92.79000092, 13.02250195], [92.7902832, 13.02278042], [92.79027557, 13.02416801], [92.79055786, 13.02444553], [92.79055786, 13.0247097], [92.79138947, 13.02556038], [92.79166412, 13.02555561], [92.79194641, 13.02583408], [92.79222107, 13.02583408], [92.79332733, 13.0269413], [92.79333496, 13.02750015], [92.79360962, 13.02777767], [92.79360962, 13.02944183], [92.79416656, 13.02999973], [92.79416656, 13.03028011], [92.79471588, 13.03084087], [92.79472351, 13.03139019], [92.79416656, 13.03193855], [92.79416656, 13.03222179], [92.79360962, 13.03277969], [92.79360962, 13.03306103], [92.79277802, 13.03390026], [92.79277802, 13.03416634], [92.79264069, 13.03444386], [92.79277802, 13.03472233], [92.79277802, 13.03582954], [92.79305267, 13.03610992], [92.79305267, 13.03694439], [92.79332733, 13.03722], [92.79332733, 13.03750134], [92.79360962, 13.03777885], [92.79360962, 13.03833008], [92.79528046, 13.04000092], [92.79528046, 13.0402813], [92.79555511, 13.04055691], [92.79556274, 13.04111099], [92.79528046, 13.04139137], [92.79528046, 13.04166698], [92.79499817, 13.04194546], [92.79499817, 13.04222107], [92.79471588, 13.04250145], [92.79472351, 13.04305458], [92.79444122, 13.04333115], [92.79444122, 13.04556179], [92.79472351, 13.04583263], [92.79471588, 13.04611111], [92.79444122, 13.04639053], [92.79444122, 13.04667187], [92.79332733, 13.04778194], [92.79333496, 13.0480547], [92.79360962, 13.04833317], [92.79499817, 13.04833126], [92.79582977, 13.04916954], [92.79582977, 13.05027962], [92.79555511, 13.05055523], [92.79556274, 13.05110931], [92.79528046, 13.05138969], [92.79528046, 13.05167007], [92.79444122, 13.05249977], [92.79444122, 13.05333424], [92.79333496, 13.05444431], [92.79305267, 13.05444145], [92.79250336, 13.05500031], [92.79250336, 13.05583382], [92.79277802, 13.05611038], [92.79277802, 13.05666637], [92.79305267, 13.05694199], [92.79305267, 13.05860996], [92.79332733, 13.05889034], [92.79333496, 13.05916595], [92.79360962, 13.05943966], [92.79360962, 13.06305695], [92.79528046, 13.06472015], [92.79528046, 13.06527901], [92.79582977, 13.06583214], [92.79582977, 13.06611061], [92.79611206, 13.06639099], [92.79611206, 13.0666666], [92.79638672, 13.06694031], [92.79638672, 13.06750107], [92.79694366, 13.06805515], [92.79666901, 13.0683279], [92.79666901, 13.06916714], [92.79638672, 13.06944275], [92.79638672, 13.07028103], [92.79611206, 13.07055473], [92.79611206, 13.07194519], [92.79638672, 13.0722208], [92.79638672, 13.07250118], [92.79693604, 13.07307053], [92.79693604, 13.07389164], [92.79666901, 13.07416725], [92.79666901, 13.07472134], [92.79611206, 13.07528019], [92.79611206, 13.07555485], [92.79582977, 13.07582188], [92.79582977, 13.07638931], [92.79666901, 13.07722092], [92.79666901, 13.07749939], [92.79694366, 13.07777691], [92.79694366, 13.07861233], [92.79722595, 13.07888126], [92.79722595, 13.08166981], [92.79693604, 13.08195114], [92.79693604, 13.08278179], [92.79666901, 13.08305645], [92.79666901, 13.0833292], [92.79611206, 13.08388996], [92.79611206, 13.08416557], [92.7958374, 13.08472157], [92.79569244, 13.08499146], [92.79582977, 13.08528042], [92.79693604, 13.08638954], [92.79694366, 13.08777809], [92.79666901, 13.0880518], [92.79666901, 13.0886097], [92.79680634, 13.08875084], [92.79666138, 13.08916569], [92.79666901, 13.08944035], [92.79750061, 13.09000015], [92.79777527, 13.09041309], [92.79860687, 13.09082127], [92.79888916, 13.09097958], [92.79972076, 13.09139061], [92.80000305, 13.09138775], [92.80027771, 13.09139061], [92.80055237, 13.09138775], [92.80055237, 13.09111023], [92.80083466, 13.09083462], [92.80083466, 13.09000015], [92.80110931, 13.08971977], [92.80110931, 13.08944416], [92.8013916, 13.08916569], [92.8013916, 13.08889103], [92.80194092, 13.08833027], [92.80194092, 13.08805561], [92.80222321, 13.08777809], [92.80222321, 13.08749962], [92.80194092, 13.08722019], [92.80194092, 13.08666611], [92.80166626, 13.08638954], [92.80166626, 13.08443928], [92.8013916, 13.08416557], [92.8013916, 13.08388996], [92.80082703, 13.0833292], [92.80083466, 13.08305645], [92.80055237, 13.08278179], [92.80055237, 13.08250046], [92.80166626, 13.08139038], [92.80194092, 13.08139038], [92.80194092, 13.08111191], [92.80249786, 13.08055973], [92.80249786, 13.0802803], [92.80278015, 13.08000183], [92.80278015, 13.07944107], [92.80305481, 13.07916546], [92.80303955, 13.07777977], [92.80332947, 13.07749939], [92.80332947, 13.07722092], [92.80500031, 13.07555485], [92.80526733, 13.07555962], [92.80583191, 13.07500076], [92.8069458, 13.07500076], [92.80722046, 13.07528019], [92.8077774, 13.07528019], [92.80805206, 13.07555962], [92.80860901, 13.07555485], [92.8088913, 13.07583332], [92.80944824, 13.07583332], [92.80999756, 13.07527733], [92.81027985, 13.07528019], [92.81054688, 13.07555962], [92.81083679, 13.07555485], [92.81111145, 13.07582188], [92.81111145, 13.07611084], [92.81138611, 13.07638931], [92.81138611, 13.0769434], [92.8116684, 13.07722092], [92.8116684, 13.07749939], [92.81138611, 13.07777977], [92.8112793, 13.07888126], [92.8105545, 13.07944584], [92.80944824, 13.07944584], [92.80916595, 13.0797224], [92.8088913, 13.07972431], [92.80805969, 13.07973099], [92.80750275, 13.0797224], [92.80722046, 13.08000183], [92.80722046, 13.08055973], [92.80832672, 13.08166981], [92.80832672, 13.08195114], [92.8088913, 13.08250046], [92.8088913, 13.0833292], [92.80805206, 13.08417034], [92.8077774, 13.08416557], [92.80750275, 13.08444405], [92.80722046, 13.08444405], [92.8069458, 13.08472157], [92.80638885, 13.08471966], [92.80555725, 13.0855608], [92.80555725, 13.08611012], [92.80527496, 13.08638763], [92.80527496, 13.08805561], [92.80555725, 13.08833027], [92.80555725, 13.0886097], [92.80583191, 13.08889103], [92.80583191, 13.08916569], [92.8061142, 13.08944416], [92.80610657, 13.08971977], [92.80638885, 13.09000015], [92.80638885, 13.09083462], [92.80665588, 13.09111023], [92.80665588, 13.09139061], [92.8069458, 13.09166622], [92.8069458, 13.09222031], [92.80722046, 13.09250069], [92.80722046, 13.09305668], [92.8077774, 13.09361076], [92.8077774, 13.09583282], [92.80750275, 13.0961113], [92.80750275, 13.09722137], [92.8077774, 13.09749889], [92.8077774, 13.09944534], [92.80827332, 13.0999403], [92.8088913, 13.10056019], [92.80945587, 13.10056019], [92.81027985, 13.10139179], [92.81027985, 13.1016674], [92.8105545, 13.10194302], [92.8105545, 13.1022234], [92.8116684, 13.10333347], [92.8125, 13.10333061], [92.81256866, 13.10340595], [92.81276703, 13.10361099], [92.81388855, 13.10361099], [92.81472015, 13.10278034], [92.81472015, 13.10250187], [92.81500244, 13.10222054], [92.81500244, 13.1016674], [92.81526947, 13.10139179], [92.81526947, 13.10111141], [92.8161087, 13.10027695], [92.81639099, 13.10028172], [92.81667328, 13.09998989], [92.81694794, 13.10000134], [92.81749725, 13.09944534], [92.8180542, 13.09944534], [92.81944275, 13.09805489], [92.81944275, 13.09777927], [92.81999969, 13.09722137], [92.81999969, 13.09694481], [92.82026672, 13.0966692], [92.82026672, 13.0961113], [92.82111359, 13.09527683], [92.82138824, 13.09527683], [92.82194519, 13.09583282], [92.82195282, 13.0961113], [92.82221985, 13.09639072], [92.82221985, 13.09694481], [92.82195282, 13.09722137], [92.82195282, 13.09777927], [92.8216629, 13.09805489], [92.8216629, 13.09833336], [92.82139587, 13.09861088], [92.82139587, 13.09889126], [92.82111359, 13.09916687], [92.82111359, 13.09944534], [92.8208313, 13.09972095], [92.8208313, 13.09998989], [92.82027435, 13.10055542], [92.82027435, 13.10083294], [92.81999969, 13.10111141], [92.81999969, 13.10249901], [92.8208313, 13.10333061], [92.8208313, 13.10361099], [92.82110596, 13.10389042], [92.82111359, 13.10416794], [92.82138824, 13.10444641], [92.82139587, 13.10472107], [92.82110596, 13.10499859], [92.82110596, 13.1055603], [92.82055664, 13.10612106], [92.82055664, 13.10778046], [92.8208313, 13.10805607], [92.8208313, 13.10833168], [92.82138824, 13.10888767], [92.82138824, 13.10944366], [92.8216629, 13.10972023], [92.8216629, 13.10999966], [92.82194519, 13.11027813], [92.82195282, 13.11082935], [92.82221985, 13.11110973], [92.82221985, 13.11192989], [92.82277679, 13.11250019], [92.8236084, 13.11250019], [92.82389069, 13.11277962], [92.82416534, 13.11277771], [92.82499695, 13.11361027], [92.82499695, 13.11388969], [92.82527924, 13.11416626], [92.82527924, 13.11444187], [92.82417297, 13.11556053], [92.82332611, 13.11556053], [92.82305908, 13.11528111], [92.82221985, 13.11528111], [92.82195282, 13.11499119], [92.82111359, 13.11499977], [92.8208313, 13.11472225], [92.81999969, 13.11472225], [92.81972504, 13.11499977], [92.81861115, 13.11499977], [92.81843567, 13.11482334], [92.81833649, 13.11472225], [92.8180542, 13.11472225], [92.81788635, 13.11455441], [92.81777954, 13.11444378], [92.81749725, 13.11444378], [92.8172226, 13.11472225], [92.81694794, 13.11472225], [92.81666565, 13.11499977], [92.81639099, 13.11499119], [92.8161087, 13.11528111], [92.8161087, 13.11555576], [92.81583405, 13.11583233], [92.81582642, 13.11610985], [92.81555176, 13.11638832], [92.81555176, 13.11694431], [92.81526947, 13.11721992], [92.81526947, 13.11750031], [92.81500244, 13.11778069], [92.81500244, 13.11805439], [92.81472015, 13.11833191], [92.81472015, 13.11861038], [92.81445313, 13.11889076], [92.8144455, 13.11916733], [92.81416321, 13.11944485], [92.81416321, 13.11972046], [92.81388855, 13.12000084], [92.81388855, 13.12028122], [92.81276703, 13.1213913], [92.8125, 13.1213913], [92.81138611, 13.12250137], [92.81138611, 13.12472057], [92.81111145, 13.12500095], [92.81111145, 13.12528133], [92.80999756, 13.12638855], [92.80999756, 13.12692928], [92.81054688, 13.12750053], [92.81083679, 13.12750053], [92.81111145, 13.12722111], [92.81445313, 13.12722111], [92.81472015, 13.12750053], [92.81555176, 13.12750053], [92.81582642, 13.12778187], [92.81861115, 13.1277771], [92.81944275, 13.12861061], [92.81944275, 13.12889194], [92.81972504, 13.1291666], [92.81972504, 13.12944317], [92.81999969, 13.12972069], [92.81999969, 13.13055515], [92.81973267, 13.13083076], [92.81973267, 13.13138962], [92.81999969, 13.13166809], [92.81999969, 13.13194561], [92.82041931, 13.13236523], [92.8208313, 13.13278198], [92.82111359, 13.13277817], [92.82139587, 13.13306046], [92.82221985, 13.13306046], [92.82277679, 13.13361168], [92.82446289, 13.13361168], [92.82527924, 13.13277817], [92.82527924, 13.1325016], [92.82554626, 13.13221931], [92.82555389, 13.13166809], [92.82583618, 13.13138962], [92.82583618, 13.13110924], [92.82666779, 13.13027668], [92.82749939, 13.13027668], [92.82805634, 13.13083267], [92.82805634, 13.13110924], [92.82861328, 13.13167], [92.82888794, 13.13166809], [92.82944489, 13.13222122], [92.82971954, 13.13222122], [92.83027649, 13.13166809], [92.83026886, 13.12972069], [92.83055878, 13.12944317], [92.83055878, 13.12888908], [92.83110809, 13.12833118], [92.83110809, 13.12805462], [92.83167267, 13.12750053], [92.83167267, 13.12722111], [92.83194733, 13.12694454], [92.83180237, 13.12611294], [92.83139038, 13.12583256], [92.83139038, 13.12555504], [92.83167267, 13.12528133], [92.83249664, 13.12472343], [92.83333588, 13.12472057], [92.83416748, 13.12555504], [92.83416748, 13.12583065], [92.83444214, 13.12611103], [92.83444214, 13.12638855], [92.83486176, 13.12692928], [92.8347168, 13.12708378], [92.83472443, 13.12722111], [92.83472443, 13.12833309], [92.83444214, 13.12861061], [92.83444214, 13.12972069], [92.8347168, 13.13000202], [92.83499908, 13.13000202], [92.83528137, 13.13027954], [92.83611298, 13.13027954], [92.83640289, 13.13000202], [92.83666992, 13.13000202], [92.83721924, 13.12944126], [92.83721924, 13.1291666], [92.83833313, 13.12806034], [92.83860779, 13.12806034], [92.83889008, 13.12778187], [92.83914948, 13.12778187], [92.83943939, 13.12750053], [92.83972168, 13.12750053], [92.83999634, 13.12722111], [92.8408432, 13.12722111], [92.84111023, 13.12750053], [92.84222412, 13.12749863], [92.84306335, 13.12833118], [92.84306335, 13.12889194], [92.84333038, 13.12917042], [92.84333038, 13.13138962], [92.84278107, 13.13194084], [92.84278107, 13.13278198], [92.84194183, 13.13361168], [92.84139252, 13.13361168], [92.84111023, 13.13389015], [92.84055328, 13.13389015], [92.83999634, 13.13444138], [92.83999634, 13.13527966], [92.83972168, 13.13556004], [92.83972168, 13.13638783], [92.84055328, 13.13722038], [92.84055328, 13.13749981], [92.84166718, 13.13861179], [92.84194183, 13.13861179], [92.84221649, 13.13889027], [92.84249878, 13.13889027], [92.84278107, 13.13916588], [92.84388733, 13.13916588], [92.84416962, 13.13889027], [92.84500122, 13.13889027], [92.84527588, 13.13861179], [92.8455658, 13.13861179], [92.84583282, 13.13833046], [92.84666443, 13.13833427], [92.84749603, 13.1391592], [92.84750366, 13.14027786], [92.84666443, 13.14111233], [92.84638977, 13.14111042], [92.84610748, 13.14138985], [92.84555817, 13.14138794], [92.84471893, 13.14221954], [92.84471893, 13.14249992], [92.84416962, 13.14305592], [92.84416962, 13.14332962], [92.84361267, 13.14388847], [92.84361267, 13.14444447], [92.84333038, 13.14472008], [92.84333038, 13.14527893], [92.84278107, 13.14583206], [92.84249878, 13.14583206], [92.84222412, 13.14610958], [92.84194183, 13.14610958], [92.84166718, 13.14583206], [92.84111023, 13.14583206], [92.84083557, 13.14555359], [92.84027863, 13.14556122], [92.83999634, 13.14529037], [92.83860779, 13.14529037], [92.83833313, 13.14556122], [92.83805847, 13.14555359], [92.83777618, 13.14583206], [92.83583069, 13.14583206], [92.83528137, 13.14527893], [92.83499908, 13.14529037], [92.8347168, 13.14500141], [92.83333588, 13.14500141], [92.83333588, 13.14529037], [92.83305359, 13.14555359], [92.83305359, 13.14583206], [92.83277893, 13.14610958], [92.83277893, 13.146945], [92.83304596, 13.14721966], [92.83304596, 13.14778137], [92.83194733, 13.14889145], [92.82943726, 13.14889145], [92.82917023, 13.14861107], [92.82861328, 13.14861107], [92.82833099, 13.14832973], [92.82805634, 13.1483326], [92.82777405, 13.14805698], [92.82749939, 13.14805889], [92.82720947, 13.14778137], [92.82694244, 13.14778137], [92.82666779, 13.14750099], [92.82639313, 13.14750099], [92.82554626, 13.1466713], [92.82527924, 13.1466713], [92.82499695, 13.14639091], [92.82472229, 13.14639091], [92.82446289, 13.14610958], [92.82416534, 13.14610958], [92.82389069, 13.14583206], [92.8236084, 13.14583206], [92.82333374, 13.14555359], [92.82277679, 13.14556122], [92.82250214, 13.14529037], [92.82221985, 13.14529037], [92.822052, 13.14511013], [92.82194519, 13.14500141], [92.8216629, 13.14500141], [92.82111359, 13.14555359], [92.82111359, 13.14583206], [92.8208313, 13.14610958], [92.8208313, 13.14638901], [92.82097626, 13.14721966], [92.82080841, 13.14823532], [92.81708527, 13.15013981], [92.81694794, 13.15000057], [92.81667328, 13.15028095], [92.81639099, 13.15027905], [92.81555176, 13.15111065], [92.8152771, 13.15111065], [92.81416321, 13.15222263], [92.8125, 13.15222263], [92.81222534, 13.15194511], [92.81111145, 13.15194511], [92.81083679, 13.15222263], [92.81054688, 13.15222073], [92.8097229, 13.15305519], [92.8097229, 13.15361118], [92.80999756, 13.15389061], [92.80999756, 13.15416718], [92.81027985, 13.15444469], [92.81027985, 13.15472126], [92.81222534, 13.15666676], [92.81223297, 13.15694141], [92.8125, 13.15723038], [92.8125, 13.15749931], [92.81277466, 13.15777683], [92.81277466, 13.15833282], [92.81305695, 13.15861225], [92.81305695, 13.16083145], [92.81276703, 13.16111183], [92.81276703, 13.1613903], [92.8125, 13.16166782], [92.8125, 13.16222191], [92.81276703, 13.16250038], [92.81276703, 13.16277981], [92.81305695, 13.16305637], [92.81305695, 13.16444397], [92.8133316, 13.16472244], [92.8133316, 13.16582966], [92.81360626, 13.16611004], [92.81361389, 13.16666603], [92.81388855, 13.16694164], [92.81388855, 13.16749954], [92.81582642, 13.16944027], [92.81582642, 13.17000008], [92.8161087, 13.1702776], [92.8161087, 13.17083454], [92.81582642, 13.17111015], [92.81583405, 13.17138767], [92.8152771, 13.17194366], [92.81500244, 13.17193985], [92.81416321, 13.17278099], [92.81416321, 13.1730566], [92.8144455, 13.17333221], [92.8144455, 13.17361069], [92.8152771, 13.17444515], [92.81583405, 13.17444515], [92.81777954, 13.17250061], [92.81804657, 13.17250061], [92.81832886, 13.17250061], [92.81861115, 13.17250061], [92.8188858, 13.17250061], [92.81916809, 13.17250061], [92.8208313, 13.17278099], [92.82110596, 13.17278099], [92.82139587, 13.17278099], [92.8216629, 13.17277908], [92.8221283, 13.17263985], [92.82277679, 13.17361069], [92.82332611, 13.17417145], [92.82389069, 13.17417145], [92.82499695, 13.17306137], [92.82611084, 13.17306137], [92.82694244, 13.17389107], [92.82776642, 13.17389107], [92.82805634, 13.1740303], [92.82826233, 13.17385387], [92.82888794, 13.17333031], [92.82888794, 13.1730566], [92.83000183, 13.17193985]]], [[[93.83969879, 12.32081985], [93.85774994, 12.29312992], [93.8603363, 12.29471016], [93.86160278, 12.29553699], [93.86174011, 12.29574203], [93.86211395, 12.29593372], [93.8626709, 12.29593372], [93.86333466, 12.29527664], [93.86553955, 12.29528046], [93.86585236, 12.29556179], [93.86723328, 12.29556179], [93.86888885, 12.29389191], [93.86915588, 12.29389191], [93.8694458, 12.29361057], [93.86972046, 12.29361057], [93.87000275, 12.29333305], [93.87083435, 12.29277706], [93.87082672, 12.29250145], [93.87361145, 12.28972054], [93.87361145, 12.28944492], [93.87388611, 12.2891674], [93.8741684, 12.28916931], [93.87526703, 12.28805923], [93.87526703, 12.28693962], [93.87555695, 12.28666687], [93.87555695, 12.28611088], [93.87526703, 12.28582954], [93.87527466, 12.28555679], [93.875, 12.28528118], [93.875, 12.2850008], [93.87526703, 12.28472042], [93.87527466, 12.28361034], [93.87611389, 12.28277779], [93.87666321, 12.28278065], [93.87695313, 12.28250027], [93.87750244, 12.28250027], [93.87779236, 12.28222179], [93.8777771, 12.28194427], [93.87805176, 12.2816658], [93.87805176, 12.27917099], [93.87779236, 12.27888966], [93.87779236, 12.27834129], [93.87750244, 12.27806091], [93.87750244, 12.27750015], [93.87722015, 12.27721977], [93.87722015, 12.27694416], [93.8769455, 12.27666569], [93.87695313, 12.27416992], [93.87666321, 12.27388954], [93.87666321, 12.27305984], [93.87638855, 12.27278042], [93.87638855, 12.27083111], [93.8741684, 12.26861095], [93.87361145, 12.26847172], [93.87243652, 12.26777935], [93.8730011, 12.26585102], [93.87594604, 12.25538063], [93.88069916, 12.23664188], [93.87034607, 12.23347378], [93.86810303, 12.23355579], [93.86811829, 12.23378372], [93.86250305, 12.2658329], [93.86250305, 12.26604271], [93.86231232, 12.2659626], [93.86201477, 12.26583958], [93.86174011, 12.26570129], [93.86096954, 12.26562786], [93.86090088, 12.26542091], [93.86062622, 12.26521111], [93.86042023, 12.26487064], [93.85993195, 12.26486206], [93.85971832, 12.2650013], [93.85926056, 12.26517391], [93.85916901, 12.26521111], [93.85888672, 12.2650013], [93.86167908, 12.23377037], [93.85103607, 12.23416042], [93.84053802, 12.23692036], [93.83200836, 12.24124146], [93.83338165, 12.24245071], [93.8520813, 12.26743984], [93.85166168, 12.26834011], [93.85138702, 12.26868725], [93.8511734, 12.26882267], [93.85020447, 12.26944256], [93.84964752, 12.26864338], [93.82668304, 12.2448597], [93.81549072, 12.27081108], [93.81520844, 12.27755928], [93.81478882, 12.28526974], [93.81871033, 12.30035973], [93.82128906, 12.30461502], [93.82415009, 12.30747509], [93.84819031, 12.2856226], [93.8483963, 12.28575039], [93.84902954, 12.28611088], [93.84916687, 12.28611088], [93.84944153, 12.28639126], [93.84972382, 12.28652763], [93.85012054, 12.28682423], [93.85028076, 12.28694534], [93.85056305, 12.28693962], [93.85083008, 12.28729057], [93.82901001, 12.31233025], [93.8311615, 12.31448078], [93.83969879, 12.32081985]]], [[[92.75008392, 12.28769493], [92.75006104, 12.28687572], [92.74983978, 12.28688145], [92.74981689, 12.28604031], [92.74899292, 12.28546143], [92.74897003, 12.2849617], [92.74929047, 12.28494072], [92.74925232, 12.28380203], [92.74898529, 12.28380203], [92.74897003, 12.28324127], [92.74868774, 12.28321648], [92.748703, 12.28216076], [92.74842072, 12.28211117], [92.7484436, 12.28106022], [92.74788666, 12.28106022], [92.7478714, 12.28049946], [92.74755859, 12.28044033], [92.74759674, 12.27938938], [92.74788666, 12.27937317], [92.74786377, 12.27881527], [92.74760437, 12.27883339], [92.74760437, 12.27827454], [92.74726868, 12.2782793], [92.74733734, 12.27716255], [92.74701691, 12.27710056], [92.74701691, 12.27571487], [92.74674225, 12.27522087], [92.74676514, 12.27408409], [92.74641418, 12.27404499], [92.74649811, 12.27188873], [92.74617004, 12.27187061], [92.74621582, 12.2707901], [92.74563599, 12.27021122], [92.74568939, 12.26967144], [92.74588776, 12.26963234], [92.74588776, 12.26889229], [92.74647522, 12.26859283], [92.74647522, 12.26769543], [92.74621582, 12.26769543], [92.7461853, 12.26682663], [92.7461853, 12.26654911], [92.7456665, 12.26634121], [92.74562073, 12.26572132], [92.74532318, 12.26570129], [92.74534607, 12.26493073], [92.74510956, 12.26491928], [92.74510956, 12.26439953], [92.74482727, 12.26436138], [92.74481201, 12.26382065], [92.74430084, 12.26358128], [92.7442627, 12.26134491], [92.7440033, 12.26131058], [92.74401855, 12.25990963], [92.74368286, 12.25988007], [92.74371338, 12.25882912], [92.7434082, 12.258811], [92.74341583, 12.25799274], [92.74314117, 12.25796986], [92.74288177, 12.25773335], [92.74285889, 12.25661373], [92.7425766, 12.25663376], [92.74259186, 12.25575542], [92.74288177, 12.25580025], [92.74285889, 12.25524044], [92.74150085, 12.25384045], [92.74035645, 12.25386143], [92.74034119, 12.25354195], [92.73896027, 12.25349236], [92.73871613, 12.25301456], [92.7381897, 12.25298119], [92.73813629, 12.25271034], [92.73755646, 12.25271034], [92.73757935, 12.25242043], [92.73706818, 12.25244141], [92.736763, 12.25214005], [92.73671722, 12.25157928], [92.73647308, 12.25160027], [92.73647308, 12.250741], [92.73619843, 12.25076103], [92.73618317, 12.24934959], [92.73535156, 12.24877071], [92.73535156, 12.24849129], [92.73478699, 12.24849129], [92.73478699, 12.25516033], [92.73501587, 12.25522137], [92.73512268, 12.25632], [92.73538208, 12.25632], [92.73535156, 12.25794029], [92.73509216, 12.25797653], [92.73509216, 12.25823021], [92.73567963, 12.25855637], [92.73561859, 12.25959969], [92.73703766, 12.2607708], [92.7370224, 12.26131058], [92.73754883, 12.26134968], [92.73754883, 12.26157093], [92.73677826, 12.26158047], [92.736763, 12.26213169], [92.73647308, 12.26213169], [92.73647308, 12.26385021], [92.73671722, 12.26385021], [92.73673248, 12.26463032], [92.73813629, 12.26463032], [92.73896027, 12.26572132], [92.73896027, 12.26766109], [92.73922729, 12.2677412], [92.73925018, 12.26939964], [92.73953247, 12.26941776], [92.73951721, 12.27056694], [92.73950958, 12.27133274], [92.7397995, 12.27130985], [92.7397995, 12.27273178], [92.74008179, 12.27270889], [92.74009705, 12.27408791], [92.73983765, 12.2741003], [92.73983765, 12.27491093], [92.73964691, 12.27497005], [92.73940277, 12.27525043], [92.73945618, 12.27547169], [92.73974609, 12.27553082], [92.74032593, 12.27602482], [92.74034119, 12.27710342], [92.73981476, 12.27736282], [92.73983765, 12.27856159], [92.73953247, 12.27850056], [92.73948669, 12.27962017], [92.73980713, 12.27962017], [92.73986053, 12.28022957], [92.73949432, 12.28021908], [92.73951721, 12.28210354], [92.73976135, 12.28216457], [92.73986053, 12.28268337], [92.74067688, 12.28268337], [92.74063873, 12.28188515], [92.74089813, 12.28189182], [92.74093628, 12.28100967], [92.74064636, 12.28100967], [92.7406311, 12.28065205], [92.74059296, 12.27997112], [92.74085999, 12.27997112], [92.74088287, 12.27885246], [92.74117279, 12.27883053], [92.74125671, 12.27909088], [92.74202728, 12.27911091], [92.74207306, 12.27967167], [92.74228668, 12.27959919], [92.74228668, 12.28016186], [92.7425766, 12.28020096], [92.7425766, 12.28131962], [92.74285126, 12.28127193], [92.74285126, 12.28210354], [92.74368286, 12.28214455], [92.74372864, 12.28246403], [92.74427032, 12.28248215], [92.74427032, 12.28298378], [92.74481201, 12.28324127], [92.74484253, 12.28380203], [92.74534607, 12.28414059], [92.74537659, 12.28464127], [92.74562836, 12.28467941], [92.74562836, 12.28546143], [92.74617767, 12.28572083], [92.74617767, 12.28631973], [92.74648285, 12.28635693], [92.74646759, 12.28738213], [92.74758148, 12.28742123], [92.74845123, 12.28826046], [92.74842834, 12.28854179], [92.74894714, 12.28854179], [92.74897766, 12.28824234], [92.74917603, 12.28820133], [92.74919891, 12.28778076], [92.75008392, 12.28769493]]], [[[92.76673889, 12.27032089], [92.76661682, 12.26988125], [92.76639557, 12.26950455], [92.76618958, 12.26913643], [92.76600647, 12.26877975], [92.76583099, 12.26844025], [92.76567078, 12.26811886], [92.76552582, 12.26776791], [92.76535797, 12.26741886], [92.76519775, 12.26699066], [92.7650528, 12.26655102], [92.76476288, 12.26616955], [92.76416016, 12.26610184], [92.76387787, 12.26610374], [92.76345062, 12.26620007], [92.76301575, 12.26648045], [92.76277161, 12.26691055], [92.76255798, 12.26739025], [92.76248169, 12.26793003], [92.76236725, 12.26845169], [92.76222229, 12.26891041], [92.76209259, 12.26928616], [92.76196289, 12.26955891], [92.76183319, 12.26976013], [92.76165771, 12.26992035], [92.76140594, 12.26998138], [92.76111603, 12.26988125], [92.76081085, 12.26971245], [92.76042938, 12.26947975], [92.75992584, 12.26931095], [92.75938416, 12.26931572], [92.75893402, 12.26964378], [92.75861359, 12.2700634], [92.75834656, 12.27046204], [92.75813293, 12.27088642], [92.75791931, 12.27131367], [92.7575531, 12.27164936], [92.75705719, 12.27194977], [92.75653076, 12.27230072], [92.75608826, 12.27278709], [92.7557373, 12.2733202], [92.75541687, 12.27383137], [92.75502014, 12.27426147], [92.7545929, 12.27468109], [92.7541275, 12.27507305], [92.75379944, 12.27558136], [92.7536087, 12.27612972], [92.75346375, 12.27663803], [92.75330353, 12.27710342], [92.75311279, 12.27751064], [92.75311279, 12.2779398], [92.75328827, 12.27834129], [92.75340271, 12.27875137], [92.75356293, 12.27911091], [92.7536087, 12.27949047], [92.75364685, 12.27987003], [92.75379181, 12.28020954], [92.75389862, 12.2806406], [92.75402069, 12.28111935], [92.75418854, 12.28162098], [92.75442505, 12.28207874], [92.75460052, 12.28251171], [92.75473022, 12.28291512], [92.75491333, 12.28324986], [92.75522614, 12.28353119], [92.75559235, 12.28380203], [92.75598145, 12.2840414], [92.75631714, 12.28431034], [92.75650787, 12.28466797], [92.75671387, 12.28496361], [92.75694275, 12.28523064], [92.75717163, 12.28549671], [92.75740814, 12.28574371], [92.75766754, 12.28599167], [92.75794983, 12.28623104], [92.75820923, 12.28647995], [92.75831604, 12.2868309], [92.75836945, 12.28721142], [92.75856781, 12.28748035], [92.75872803, 12.28777027], [92.75886536, 12.28812122], [92.75893402, 12.28856468], [92.75911713, 12.28902054], [92.75930023, 12.28955173], [92.75961304, 12.29000092], [92.75994873, 12.29045677], [92.7602005, 12.29103088], [92.76045227, 12.29168797], [92.76072693, 12.2923708], [92.7611084, 12.29302502], [92.76164246, 12.29354954], [92.76226807, 12.29389191], [92.76287842, 12.29412174], [92.76346588, 12.29408073], [92.76396179, 12.29382133], [92.76439667, 12.29356289], [92.76474762, 12.29328537], [92.76500702, 12.29292965], [92.76528168, 12.29259014], [92.76550293, 12.29223919], [92.76554871, 12.291852], [92.7654953, 12.29147339], [92.76531982, 12.2911129], [92.76509857, 12.29074383], [92.76496887, 12.29029655], [92.76477051, 12.28990078], [92.76477051, 12.2894907], [92.76494598, 12.28910065], [92.76500702, 12.28867722], [92.76509857, 12.28825092], [92.76528931, 12.28786087], [92.76556396, 12.28751183], [92.76593781, 12.28722286], [92.76634216, 12.28694153], [92.76670837, 12.28666687], [92.76700592, 12.28639126], [92.76721954, 12.28611088], [92.76743317, 12.28587055], [92.76753998, 12.28555202], [92.76773071, 12.28528309], [92.7678299, 12.2848959], [92.768013, 12.28450108], [92.76805115, 12.28401089], [92.768013, 12.28350067], [92.76782227, 12.28302002], [92.76776886, 12.28251171], [92.76768494, 12.28202438], [92.76753235, 12.28158188], [92.76750183, 12.28108978], [92.7674942, 12.28061771], [92.76745605, 12.28014088], [92.76727295, 12.27973366], [92.76721954, 12.27933502], [92.7672348, 12.27896786], [92.76732635, 12.27863026], [92.76748657, 12.27826118], [92.76759338, 12.27782059], [92.76773071, 12.27736092], [92.76777649, 12.27687073], [92.76777649, 12.27641296], [92.76773071, 12.27597523], [92.76754761, 12.27556515], [92.76750183, 12.2751503], [92.76750183, 12.2747097], [92.76750183, 12.27421093], [92.76750183, 12.27364445], [92.76744843, 12.27301025], [92.76724243, 12.27241135], [92.76708984, 12.27181053], [92.76696777, 12.27126408], [92.76690674, 12.27075386], [92.76673889, 12.27032089]]], [[[92.73706055, 12.28518105], [92.73680115, 12.28489971], [92.736763, 12.28185081], [92.73622894, 12.28184605], [92.73622894, 12.28157139], [92.73594666, 12.28157139], [92.73561859, 12.28188038], [92.735672, 12.28295612], [92.73593903, 12.28302479], [92.73592377, 12.28352356], [92.7362442, 12.28354359], [92.73622894, 12.28401089], [92.73620605, 12.28494072], [92.73587799, 12.28492069], [92.73590088, 12.28663921], [92.73538971, 12.28712463], [92.73538971, 12.28851032], [92.73565674, 12.2887907], [92.7361908, 12.28883171], [92.73622894, 12.28993034], [92.73652649, 12.28995132], [92.7365036, 12.29073524], [92.73674774, 12.29075527], [92.736763, 12.29135323], [92.73700714, 12.29137325], [92.73705292, 12.29189301], [92.73761749, 12.29240322], [92.73817444, 12.29240322], [92.73815918, 12.2918539], [92.737854, 12.2918539], [92.73791504, 12.28937912], [92.73757172, 12.289361], [92.73763275, 12.28826046], [92.73728943, 12.28824234], [92.73734283, 12.28629112], [92.73706055, 12.28601265], [92.73706055, 12.28518105]]], [[[92.71141815, 12.2960701], [92.71205139, 12.29598141], [92.71272278, 12.29603195], [92.71333313, 12.29585171], [92.71386719, 12.295681], [92.71434784, 12.29553032], [92.71472931, 12.29533195], [92.71508789, 12.29537964], [92.71544647, 12.29554367], [92.71582031, 12.29570103], [92.71620178, 12.29592037], [92.7166214, 12.29620934], [92.71711731, 12.29658985], [92.7177887, 12.29679966], [92.71837616, 12.29654026], [92.71871185, 12.29603195], [92.71900177, 12.29560757], [92.71930695, 12.29528046], [92.71962738, 12.29500771], [92.71994019, 12.29480076], [92.72029114, 12.29472828], [92.72064972, 12.29470062], [92.72101593, 12.29463005], [92.72132874, 12.29471016], [92.72164154, 12.29496956], [92.72200012, 12.29526138], [92.72236633, 12.29548931], [92.72278595, 12.29552078], [92.72299957, 12.2954073], [92.7231369, 12.29533386], [92.72344208, 12.29513073], [92.72358704, 12.29475975], [92.72360992, 12.29429531], [92.72357178, 12.29380322], [92.72340393, 12.29334545], [92.72348022, 12.29290485], [92.72360229, 12.29246521], [92.72367859, 12.29205036], [92.72385406, 12.29171276], [92.72386169, 12.29137993], [92.72370911, 12.29103088], [92.72357178, 12.29061413], [92.72329712, 12.29023075], [92.72301483, 12.289814], [92.72272491, 12.28942871], [92.72252655, 12.28901196], [92.72249603, 12.28850079], [92.72249603, 12.28796101], [92.72245789, 12.2874012], [92.72225952, 12.28688145], [92.72213745, 12.28632927], [92.72197723, 12.28581047], [92.72190094, 12.28528118], [92.72167969, 12.28486156], [92.72145081, 12.28447247], [92.72114563, 12.2841692], [92.72084808, 12.28389072], [92.72054291, 12.2835989], [92.72024536, 12.28328419], [92.72003937, 12.28288078], [92.72003937, 12.28236103], [92.72026825, 12.28182602], [92.72050476, 12.28124905], [92.72064972, 12.28061962], [92.72080994, 12.28005314], [92.72085571, 12.27950096], [92.72076416, 12.27900219], [92.72058105, 12.27861023], [92.7204361, 12.27823162], [92.72027588, 12.27792168], [92.72012329, 12.27761173], [92.71997833, 12.27721977], [92.71980286, 12.27684116], [92.71968842, 12.27644157], [92.71949005, 12.27611923], [92.71943665, 12.27576065], [92.71943665, 12.27538967], [92.71944427, 12.27502728], [92.71943665, 12.27463055], [92.71942139, 12.27417183], [92.71929169, 12.27366161], [92.71898651, 12.2731514], [92.71863556, 12.27258587], [92.71837616, 12.27190018], [92.71833038, 12.27114105], [92.7183075, 12.27043247], [92.71817017, 12.26984882], [92.71798706, 12.26939964], [92.71779633, 12.26907158], [92.71765137, 12.2687664], [92.71750641, 12.26847172], [92.71743011, 12.26815605], [92.7172699, 12.26788044], [92.71720886, 12.26755238], [92.71708679, 12.26723003], [92.71692657, 12.26691055], [92.7167511, 12.266572], [92.71663666, 12.26615047], [92.71656036, 12.26575089], [92.71669769, 12.26539803], [92.71692657, 12.26515198], [92.71714783, 12.26495075], [92.71739197, 12.26473045], [92.71774292, 12.26451969], [92.71819305, 12.2643404], [92.71858215, 12.26395988], [92.71884155, 12.26345062], [92.71884918, 12.26286983], [92.71864319, 12.26232338], [92.71839905, 12.26178074], [92.71794891, 12.26142979], [92.71740723, 12.26126957], [92.71694183, 12.26134491], [92.71656799, 12.26130676], [92.71627045, 12.26120186], [92.71600342, 12.26107407], [92.71578217, 12.26085758], [92.71553802, 12.26058197], [92.71527863, 12.2602787], [92.71527863, 12.25972271], [92.71611023, 12.2588892], [92.71666718, 12.25889111], [92.71694183, 12.25917053], [92.71722412, 12.25916672], [92.71749878, 12.25944519], [92.71778107, 12.25944519], [92.71805573, 12.25972271], [92.71861267, 12.25972271], [92.71916962, 12.25916672], [92.71916962, 12.25889111], [92.71888733, 12.25861073], [92.71888733, 12.25833035], [92.71861267, 12.25805664], [92.71861267, 12.25778103], [92.71833038, 12.25750065], [92.71833038, 12.2569418], [92.71722412, 12.25583458], [92.71639252, 12.25583458], [92.71607208, 12.25554085], [92.71582031, 12.25533962], [92.71555328, 12.2550602], [92.71527863, 12.25471115], [92.71502686, 12.25432587], [92.71482086, 12.25389957], [92.71459961, 12.25347996], [92.71437836, 12.25306988], [92.7141571, 12.25267124], [92.71396637, 12.25226116], [92.71389771, 12.2518158], [92.71389008, 12.25133133], [92.71383667, 12.25082016], [92.71364594, 12.25029182], [92.71353149, 12.24967194], [92.71333313, 12.24905014], [92.71310425, 12.24845028], [92.7130127, 12.24779129], [92.71277618, 12.24722195], [92.7125473, 12.24667454], [92.71250153, 12.24607086], [92.71246338, 12.245471], [92.71230316, 12.24491119], [92.7122345, 12.24435234], [92.71221924, 12.24377346], [92.71221924, 12.24317646], [92.71221924, 12.24256134], [92.71219635, 12.24192047], [92.71214294, 12.24131012], [92.71209717, 12.24071026], [92.71219635, 12.24009037], [92.71221924, 12.23946095], [92.71221924, 12.23882103], [92.7122345, 12.2381916], [92.71231079, 12.23756981], [92.71246338, 12.23695183], [92.71250153, 12.23631096], [92.71248627, 12.23567295], [92.71239471, 12.23504734], [92.71219635, 12.23446083], [92.71193695, 12.23390007], [92.7117157, 12.2333231], [92.71166992, 12.23263741], [92.71161652, 12.23194027], [92.71138, 12.23129082], [92.71105957, 12.23071194], [92.71092224, 12.23038101], [92.71069336, 12.23032856], [92.71035767, 12.23051071], [92.71002197, 12.23088741], [92.70977783, 12.23129082], [92.70972443, 12.2317009], [92.7097168, 12.23206139], [92.7097168, 12.23239136], [92.70970917, 12.23269939], [92.70962524, 12.23301411], [92.70948029, 12.23335457], [92.70939636, 12.23376083], [92.70921326, 12.23416042], [92.7091217, 12.23462677], [92.7089386, 12.23508072], [92.70889282, 12.2356596], [92.7088089, 12.23630047], [92.70864868, 12.23698425], [92.70855713, 12.23769855], [92.70836639, 12.2383604], [92.70823669, 12.23895073], [92.70807648, 12.23940182], [92.70797729, 12.2397604], [92.70782471, 12.239995], [92.70777893, 12.2402792], [92.70773315, 12.24057961], [92.70755768, 12.24079895], [92.70741272, 12.24106979], [92.7071991, 12.24134064], [92.7069397, 12.24160576], [92.70662689, 12.24190044], [92.7062912, 12.24223042], [92.70590973, 12.24254704], [92.70555878, 12.24293232], [92.70523071, 12.24336338], [92.70498657, 12.24388504], [92.70476532, 12.24443245], [92.70471954, 12.24506092], [92.70471954, 12.24571133], [92.7046814, 12.24637794], [92.70452881, 12.24702072], [92.70445251, 12.24772072], [92.70446014, 12.24841976], [92.70453644, 12.24909973], [92.70466614, 12.24973965], [92.70461273, 12.25039196], [92.70451355, 12.25104618], [92.70462799, 12.2517004], [92.70446014, 12.25231075], [92.70435333, 12.25291538], [92.70437622, 12.25353336], [92.70439148, 12.25413418], [92.70423889, 12.25467396], [92.70417023, 12.25517082], [92.70411682, 12.25562859], [92.7039566, 12.25597954], [92.70387268, 12.25633144], [92.70372009, 12.25667095], [92.70349884, 12.25705242], [92.70337677, 12.25758934], [92.70337677, 12.25820923], [92.70350647, 12.25878143], [92.70359039, 12.25928974], [92.70353699, 12.25976086], [92.70336151, 12.26019001], [92.70323181, 12.2606411], [92.70302582, 12.26103115], [92.70276642, 12.26140022], [92.70249939, 12.26179028], [92.70223999, 12.2622118], [92.70205688, 12.26268101], [92.70191956, 12.26320076], [92.70175934, 12.26374054], [92.70172119, 12.26432037], [92.70184326, 12.26490974], [92.70188141, 12.26549816], [92.7016983, 12.26607227], [92.70155334, 12.26669025], [92.70147705, 12.26736927], [92.70172119, 12.26811028], [92.7020874, 12.2688303], [92.7022934, 12.26960278], [92.70265961, 12.26999855], [92.70301819, 12.27033043], [92.70332336, 12.2706604], [92.70355225, 12.27104092], [92.70361328, 12.27147198], [92.7035675, 12.27186775], [92.70339203, 12.2721796], [92.70323181, 12.27248096], [92.70304871, 12.27273655], [92.70285034, 12.2729826], [92.70262146, 12.27323055], [92.70243073, 12.27358913], [92.70220947, 12.27398109], [92.7019577, 12.27442074], [92.70181274, 12.27492046], [92.70189667, 12.27548981], [92.70240021, 12.27606201], [92.70264435, 12.27666569], [92.70263672, 12.27733994], [92.70284271, 12.27771187], [92.70307922, 12.27799034], [92.70333099, 12.27826977], [92.70353699, 12.27858925], [92.70362091, 12.2789793], [92.70370483, 12.27935123], [92.70384979, 12.27969265], [92.70388031, 12.28007126], [92.70388031, 12.2805109], [92.70385742, 12.28096199], [92.7036972, 12.28139973], [92.7035141, 12.28181744], [92.70355225, 12.2822504], [92.70404053, 12.28278828], [92.70436096, 12.2833004], [92.70436859, 12.28381062], [92.70413971, 12.28429031], [92.7038269, 12.28477955], [92.70365143, 12.28531075], [92.7035675, 12.28585052], [92.70342255, 12.28634834], [92.70331573, 12.28688335], [92.70314789, 12.28739071], [92.70297241, 12.28786469], [92.7026825, 12.28836918], [92.70244598, 12.28905106], [92.70246887, 12.28971195], [92.70279694, 12.29023075], [92.70327759, 12.29066944], [92.70365143, 12.29110241], [92.7039032, 12.29158974], [92.70375824, 12.29230118], [92.70387268, 12.29273605], [92.70405579, 12.2930603], [92.70423126, 12.29339695], [92.70440674, 12.29375935], [92.70443726, 12.29424], [92.70443726, 12.29475975], [92.70443726, 12.29529953], [92.70444489, 12.29583645], [92.70444489, 12.29637432], [92.70443726, 12.29691982], [92.70446014, 12.29750156], [92.70461273, 12.29809189], [92.70527649, 12.29854107], [92.70571899, 12.29864979], [92.7061615, 12.2987709], [92.70668793, 12.29878044], [92.70694733, 12.29858017], [92.70715332, 12.2983036], [92.70737457, 12.29798889], [92.70754242, 12.29765034], [92.70774078, 12.29740143], [92.70792389, 12.29721165], [92.70811462, 12.29703236], [92.70838165, 12.29688168], [92.70869446, 12.29669476], [92.70909119, 12.29658127], [92.70947266, 12.29642963], [92.70992279, 12.29638004], [92.71037292, 12.2963438], [92.71084595, 12.29615211], [92.71141815, 12.2960701]]], [[[92.77657318, 12.3102808], [92.77684784, 12.31011868], [92.77700806, 12.31014442], [92.77870178, 12.31010342], [92.77946472, 12.31011391], [92.77972412, 12.31011391], [92.77999878, 12.31006241], [92.78050995, 12.3101387], [92.78083038, 12.3102808], [92.78111267, 12.3102808], [92.78164673, 12.31075001], [92.78231812, 12.31093025], [92.7829361, 12.31096172], [92.78341675, 12.31096172], [92.78395081, 12.31103992], [92.78456879, 12.31097126], [92.78513336, 12.310812], [92.78559875, 12.31054974], [92.78598785, 12.31029034], [92.78633118, 12.31005955], [92.78665924, 12.30987072], [92.78696442, 12.30968571], [92.7872467, 12.3094511], [92.7875824, 12.30925655], [92.78801727, 12.30912971], [92.78846741, 12.30891991], [92.78897858, 12.30878067], [92.78944397, 12.30858135], [92.78978729, 12.30825043], [92.79013062, 12.30792618], [92.7904129, 12.30762959], [92.79057312, 12.30729103], [92.79074097, 12.3070097], [92.79081726, 12.30671597], [92.79086304, 12.30641079], [92.79094696, 12.30613041], [92.79109955, 12.30586243], [92.79122162, 12.30558777], [92.79138184, 12.30535126], [92.79155731, 12.30513], [92.79176331, 12.30491066], [92.79200745, 12.30473995], [92.79231262, 12.3046217], [92.7926178, 12.3044796], [92.79299164, 12.30445099], [92.793396, 12.30443001], [92.79380798, 12.30436039], [92.79421234, 12.30421066], [92.79463959, 12.30416107], [92.79502869, 12.30408192], [92.7953949, 12.30392742], [92.79573822, 12.30389023], [92.79608154, 12.303895], [92.79644012, 12.30394936], [92.79679871, 12.30416965], [92.79721069, 12.30443001], [92.79767609, 12.30472183], [92.79819489, 12.3049984], [92.79869843, 12.30528259], [92.79915619, 12.30558109], [92.79956055, 12.30589962], [92.79982758, 12.30632019], [92.80014038, 12.30666161], [92.80045319, 12.30696011], [92.8007431, 12.30726814], [92.80095673, 12.30763531], [92.8011322, 12.30805397], [92.80136871, 12.30845547], [92.80153656, 12.30891323], [92.80169678, 12.30942154], [92.80194092, 12.30992126], [92.80223083, 12.31044006], [92.80258942, 12.31093502], [92.80314636, 12.31131077], [92.80380249, 12.31156445], [92.80449677, 12.31173515], [92.80516052, 12.31190109], [92.80580139, 12.31195068], [92.80638885, 12.31198978], [92.80684662, 12.31217003], [92.80729675, 12.31227016], [92.80768585, 12.31245136], [92.80812836, 12.31254196], [92.80854797, 12.31274033], [92.80901337, 12.31282043], [92.80947876, 12.31283092], [92.80995941, 12.31276035], [92.81045532, 12.31261539], [92.81096649, 12.31246185], [92.81144714, 12.31221962], [92.81195068, 12.31199932], [92.81252289, 12.31194019], [92.81303406, 12.31189442], [92.81345367, 12.31169415], [92.81386566, 12.3115406], [92.81425476, 12.31137466], [92.8146286, 12.31123066], [92.8150177, 12.3113308], [92.81539917, 12.31119919], [92.81581116, 12.31087303], [92.81622314, 12.31058407], [92.81661987, 12.31031513], [92.81703949, 12.31004143], [92.81748962, 12.30976963], [92.81803131, 12.30952168], [92.81861115, 12.30922985], [92.8192215, 12.30890179], [92.81987, 12.30859184], [92.82047272, 12.30821991], [92.82095337, 12.30777836], [92.82142639, 12.30731964], [92.82196808, 12.30690956], [92.8225174, 12.30649662], [92.82306671, 12.3060894], [92.82361603, 12.30568123], [92.82416534, 12.30527115], [92.82468414, 12.30483055], [92.82512665, 12.30432129], [92.82552338, 12.3038063], [92.8258667, 12.30331135], [92.8262558, 12.30293274], [92.82672119, 12.30270958], [92.82715607, 12.30248165], [92.82753754, 12.30219364], [92.82792664, 12.30193043], [92.82827759, 12.30164146], [92.82859802, 12.30133724], [92.82891846, 12.30104637], [92.8292923, 12.3008337], [92.82964325, 12.3006258], [92.82995605, 12.30037117], [92.83032227, 12.30027962], [92.8307724, 12.30027771], [92.83130646, 12.30031013], [92.83188629, 12.30048275], [92.8325119, 12.30054188], [92.83307648, 12.30048275], [92.83357239, 12.30031872], [92.83399963, 12.30027771], [92.83434296, 12.30027103], [92.83463287, 12.30027485], [92.8348999, 12.30027962], [92.83516693, 12.30035114], [92.83542633, 12.30054188], [92.83573914, 12.30076122], [92.83600616, 12.30103016], [92.83621979, 12.30135059], [92.83638763, 12.30167866], [92.83653259, 12.30202579], [92.83674622, 12.30232239], [92.83693695, 12.30264091], [92.83716583, 12.30298996], [92.8374939, 12.30326557], [92.8380127, 12.30337048], [92.83854675, 12.30357075], [92.83912659, 12.30360985], [92.83970642, 12.30360985], [92.840271, 12.30365753], [92.84081268, 12.30383968], [92.841362, 12.30389023], [92.84192657, 12.30389023], [92.84244537, 12.30388832], [92.84290314, 12.30389023], [92.84327698, 12.3038969], [92.84355164, 12.30396271], [92.84444427, 12.30444431], [92.84610748, 12.30444431], [92.84638977, 12.30416584], [92.84750366, 12.30444431], [92.84777832, 12.30416584], [92.84805298, 12.30416965], [92.84860992, 12.30360985], [92.84860992, 12.30333424], [92.84889221, 12.30305576], [92.84889221, 12.30278015], [92.84944153, 12.30221939], [92.85028076, 12.30221939], [92.85056305, 12.30251122], [92.85111237, 12.30249977], [92.85148621, 12.30274105], [92.85201263, 12.30282974], [92.85248566, 12.30305767], [92.85299683, 12.30332947], [92.85353851, 12.30362129], [92.8540802, 12.30393791], [92.85456848, 12.30429077], [92.85504913, 12.30460072], [92.85555267, 12.30482006], [92.8560791, 12.30500889], [92.85662842, 12.30521202], [92.85723114, 12.30534363], [92.85787201, 12.30543137], [92.85845184, 12.30517292], [92.85887146, 12.30475426], [92.85922241, 12.30440521], [92.85957336, 12.30416965], [92.86000061, 12.30389023], [92.86165619, 12.30389023], [92.86194611, 12.30360985], [92.86277771, 12.30360985], [92.86305237, 12.30333424], [92.86333466, 12.30333424], [92.86387634, 12.30431175], [92.8640213, 12.30470371], [92.86502838, 12.30539227], [92.8653183, 12.30548096], [92.86582184, 12.30555153], [92.86637878, 12.30561066], [92.86676788, 12.30498886], [92.86670685, 12.3043499], [92.8666687, 12.30389023], [92.86637878, 12.30360985], [92.86638641, 12.30333424], [92.8658371, 12.30277824], [92.86544037, 12.30231094], [92.86575317, 12.3011694], [92.86723328, 12.30111027], [92.86777496, 12.30111217], [92.86842346, 12.30097103], [92.86894989, 12.30087852], [92.8694458, 12.30083084], [92.86972046, 12.3008337], [92.87000275, 12.30111217], [92.87082672, 12.30111027], [92.87100983, 12.30112076], [92.87130737, 12.30112076], [92.87166595, 12.30111027], [92.87194824, 12.30138779], [92.87242889, 12.30159283], [92.87298584, 12.30154037], [92.8732605, 12.30123043], [92.87336731, 12.30097961], [92.87346649, 12.30067158], [92.87345123, 12.30027962], [92.87328339, 12.29996967], [92.87290192, 12.29970074], [92.87254333, 12.29954243], [92.8720932, 12.29934978], [92.87178802, 12.29903984], [92.87162018, 12.29875088], [92.87151337, 12.2983017], [92.87155914, 12.29798031], [92.87168884, 12.2975111], [92.87187195, 12.29718018], [92.87210846, 12.29695034], [92.87229156, 12.2967062], [92.8724823, 12.29629135], [92.872612, 12.29585838], [92.87262726, 12.29558945], [92.87245178, 12.29523182], [92.87223816, 12.29496002], [92.87207794, 12.29469395], [92.87193298, 12.29442024], [92.87176514, 12.29416275], [92.87158203, 12.29388714], [92.87133026, 12.29356956], [92.87110901, 12.29333305], [92.8702774, 12.29333305], [92.87000275, 12.29305458], [92.86972046, 12.2930603], [92.86902618, 12.29236221], [92.86888885, 12.29222107], [92.86888885, 12.29138947], [92.86915588, 12.29111099], [92.86915588, 12.29083061], [92.86972046, 12.29027653], [92.8702774, 12.29057121], [92.87055206, 12.290555], [92.87194824, 12.29194546], [92.8730545, 12.29083347], [92.8730545, 12.29027653], [92.87304688, 12.2899189], [92.87309265, 12.28944016], [92.87322235, 12.28905106], [92.87332916, 12.28871059], [92.87342072, 12.28841019], [92.87358093, 12.28818035], [92.87374115, 12.28794289], [92.87397766, 12.28776073], [92.87421417, 12.28758526], [92.87446594, 12.28743935], [92.87472534, 12.28725719], [92.87503815, 12.28722], [92.87536621, 12.28726768], [92.87567139, 12.28743458], [92.87600708, 12.28756046], [92.8763504, 12.28777027], [92.8767395, 12.28794956], [92.87715912, 12.28803921], [92.87755585, 12.28805161], [92.87789154, 12.28805161], [92.87820435, 12.28805542], [92.87851715, 12.28807068], [92.87886047, 12.28817081], [92.87918091, 12.28831673], [92.87947083, 12.28838062], [92.87971497, 12.28827286], [92.88002014, 12.28777027], [92.88043976, 12.28743172], [92.88056946, 12.28768063], [92.8805542, 12.28805542], [92.88054657, 12.28861141], [92.88083649, 12.28888893], [92.88083649, 12.28944016], [92.8813858, 12.29000092], [92.88194275, 12.29000092], [92.88249969, 12.28944016], [92.88249969, 12.2891674], [92.88276672, 12.28889084], [92.8833313, 12.28889084], [92.88360596, 12.28861141], [92.88388824, 12.28861141], [92.8841629, 12.28833294], [92.88471985, 12.28833294], [92.88555908, 12.28750134], [92.88582611, 12.28750992], [92.88667297, 12.28667068], [92.88667297, 12.28611088], [92.88694763, 12.28583336], [92.88694763, 12.28527641], [92.8861084, 12.28444004], [92.8861084, 12.28416634], [92.88582611, 12.28389072], [92.88582611, 12.28361034], [92.88555908, 12.28333473], [92.88555908, 12.28277779], [92.88527679, 12.28250027], [92.88527679, 12.28222179], [92.88445282, 12.28138065], [92.88388824, 12.28138065], [92.88360596, 12.28167057], [92.88314819, 12.28166199], [92.88269806, 12.28162098], [92.88237762, 12.28142929], [92.88215637, 12.28120136], [92.88208771, 12.28086567], [92.88183594, 12.28048134], [92.8813324, 12.28020287], [92.88085175, 12.27988625], [92.88047028, 12.27953053], [92.88011169, 12.27923203], [92.87999725, 12.27888966], [92.8797226, 12.27861023], [92.8797226, 12.27777767], [92.87999725, 12.27750015], [92.87999725, 12.27693939], [92.8805542, 12.27639008], [92.88054657, 12.2761097], [92.88168335, 12.27499962], [92.88168335, 12.27471924], [92.88194275, 12.27444363], [92.88194275, 12.27416801], [92.88223267, 12.27388954], [92.88220215, 12.27016068], [92.88221741, 12.2696209], [92.88223267, 12.26906013], [92.88222504, 12.26851559], [92.88223267, 12.26797104], [92.88222504, 12.26741886], [92.8822403, 12.26684666], [92.88234711, 12.26627064], [92.88246918, 12.26571655], [92.88249969, 12.265172], [92.88253021, 12.26465034], [92.88266754, 12.26418972], [92.88289642, 12.26377964], [92.88314056, 12.26344013], [92.88343048, 12.26323032], [92.88363647, 12.26306152], [92.88401031, 12.2631712], [92.88417816, 12.26335812], [92.8843689, 12.26364136], [92.88455963, 12.26401043], [92.88477325, 12.26439953], [92.88499451, 12.26479626], [92.88520813, 12.26521969], [92.88533783, 12.26568985], [92.88554382, 12.26605415], [92.8857193, 12.26642323], [92.88589478, 12.26682663], [92.88623047, 12.26718235], [92.88671112, 12.26744366], [92.88732147, 12.26745415], [92.88757324, 12.26735592], [92.88790131, 12.26722813], [92.88848877, 12.26694107], [92.88905334, 12.26653099], [92.88931274, 12.26594162], [92.88909149, 12.26540947], [92.8886261, 12.26498127], [92.88820648, 12.26459122], [92.88777161, 12.26444054], [92.88741302, 12.26433086], [92.88719177, 12.26414204], [92.88700867, 12.26393032], [92.88686371, 12.26366138], [92.88671112, 12.26338482], [92.88661957, 12.26306152], [92.88643646, 12.26277161], [92.88645172, 12.26247597], [92.88664246, 12.26216125], [92.88682556, 12.26177597], [92.88703156, 12.26134968], [92.88739777, 12.26103115], [92.88772583, 12.26061153], [92.88799286, 12.26015091], [92.88802338, 12.25963593], [92.88787079, 12.25918007], [92.88764954, 12.25879955], [92.88730621, 12.25857162], [92.88697815, 12.25834179], [92.88661194, 12.25816154], [92.88617706, 12.25806999], [92.88577271, 12.25801086], [92.88536072, 12.25783062], [92.88492584, 12.25773144], [92.88453674, 12.25750065], [92.88417053, 12.25723171], [92.88381958, 12.2569313], [92.88353729, 12.25658226], [92.88333893, 12.25620079], [92.88316345, 12.2558136], [92.88300323, 12.25542355], [92.88275146, 12.25509644], [92.8824234, 12.25479126], [92.88201141, 12.25450134], [92.88158417, 12.25419807], [92.88114166, 12.25393105], [92.88067627, 12.25370979], [92.8802948, 12.25343037], [92.87996674, 12.2531004], [92.87963867, 12.25279045], [92.87930298, 12.25247955], [92.87895966, 12.25213146], [92.8786087, 12.25177956], [92.87825012, 12.25144005], [92.87783051, 12.25119019], [92.87734985, 12.25105095], [92.87691498, 12.25087261], [92.8764267, 12.25078869], [92.87599182, 12.25054932], [92.87555695, 12.25032997], [92.87502289, 12.25030994], [92.8744278, 12.25039196], [92.87426758, 12.25034904], [92.87378693, 12.25022125], [92.87336731, 12.25034428], [92.87297821, 12.25051022], [92.87251282, 12.25058079], [92.87203217, 12.25073242], [92.87165833, 12.25081635], [92.87158203, 12.25081635], [92.8694458, 12.2508297], [92.86915588, 12.25111198], [92.86860657, 12.25111198], [92.86833191, 12.2514019], [92.86782074, 12.25141144], [92.86741638, 12.25156116], [92.86694336, 12.25169086], [92.86649323, 12.25171185], [92.86607361, 12.25162697], [92.86569977, 12.25146961], [92.86515045, 12.25143433], [92.8646698, 12.25134468], [92.86424255, 12.25115967], [92.86382294, 12.25089073], [92.8638916, 12.25111198], [92.86250305, 12.24971962], [92.86222076, 12.24972153], [92.8611145, 12.2486124], [92.8611145, 12.24833393], [92.86027527, 12.24750042], [92.86000061, 12.24750042], [92.85943604, 12.24694061], [92.85944366, 12.24666786], [92.85916901, 12.24639034], [92.85916901, 12.24611187], [92.85888672, 12.24583054], [92.85916901, 12.24555588], [92.85916901, 12.24500179], [92.85916901, 12.24470997], [92.85921478, 12.24425697], [92.85941315, 12.24383926], [92.85958099, 12.24341106], [92.85984039, 12.24310112], [92.86016846, 12.24289131], [92.86049652, 12.24272919], [92.8608017, 12.2425518], [92.86106873, 12.2423811], [92.86123657, 12.24163055], [92.86134338, 12.24090195], [92.86141205, 12.24033642], [92.86147308, 12.23979187], [92.86158752, 12.23926258], [92.86173248, 12.23876572], [92.86192322, 12.2383194], [92.86209869, 12.23789978], [92.86226654, 12.23747158], [92.86248016, 12.23706055], [92.86266327, 12.2366209], [92.86281586, 12.23617172], [92.86308289, 12.23581886], [92.86338043, 12.23553181], [92.8637085, 12.23528099], [92.86406708, 12.23508072], [92.86451721, 12.23495102], [92.86502075, 12.23475933], [92.86556244, 12.23456955], [92.86582947, 12.23429203], [92.86603546, 12.23397064], [92.86625671, 12.23363304], [92.86650848, 12.23331356], [92.866745, 12.23298836], [92.86701965, 12.23271275], [92.86730194, 12.23246193], [92.86752319, 12.23214054], [92.86769104, 12.23182201], [92.86776733, 12.23145676], [92.86781311, 12.23106861], [92.86791229, 12.23069286], [92.86803436, 12.23027897], [92.86814117, 12.2298317], [92.86834717, 12.22942162], [92.86862946, 12.22902966], [92.86895752, 12.22869015], [92.86933899, 12.2284317], [92.8697052, 12.22817039], [92.87006378, 12.22790146], [92.87049103, 12.22768879], [92.87094116, 12.22739124], [92.87140656, 12.22706032], [92.87188721, 12.22667122], [92.87220001, 12.22613144], [92.87245178, 12.2255106], [92.87251282, 12.22479725], [92.87256622, 12.22413158], [92.87264252, 12.22354126], [92.87256622, 12.22301006], [92.87272644, 12.22252274], [92.87281799, 12.2220602], [92.87298584, 12.22170925], [92.87309265, 12.22135067], [92.87323761, 12.22104645], [92.87332153, 12.22072029], [92.87333679, 12.2203598], [92.87333679, 12.21997929], [92.87333679, 12.21955109], [92.87332153, 12.21907425], [92.87325287, 12.21855736], [92.87313843, 12.21807194], [92.87328339, 12.21764088], [92.87336731, 12.21720123], [92.87354279, 12.2168293], [92.87360382, 12.21645069], [92.87361145, 12.21607304], [92.87365723, 12.21568775], [92.8738327, 12.21529102], [92.87387848, 12.21480083], [92.87388611, 12.21426487], [92.87388611, 12.21371174], [92.87388611, 12.21317959], [92.87388611, 12.21269035], [92.87387848, 12.21225071], [92.87380219, 12.2118969], [92.8736496, 12.21166039], [92.87366486, 12.21142292], [92.87381744, 12.21112537], [92.87377167, 12.21084881], [92.87364197, 12.21049976], [92.8736496, 12.21014023], [92.87379456, 12.20979595], [92.87386322, 12.2094202], [92.87375641, 12.20900059], [92.87362671, 12.20852184], [92.87361145, 12.20798016], [92.87361145, 12.20740128], [92.8736496, 12.20681], [92.87381744, 12.20625019], [92.873909, 12.20572758], [92.87403107, 12.20531082], [92.87419891, 12.2049799], [92.87440491, 12.20474339], [92.87454987, 12.20449162], [92.87474823, 12.20430279], [92.87500763, 12.20415974], [92.87532806, 12.20401192], [92.87571716, 12.20390034], [92.87619019, 12.20376968], [92.87665558, 12.20351696], [92.87709808, 12.20317078], [92.87747955, 12.20278072], [92.87776184, 12.20234966], [92.87800598, 12.20197868], [92.87827301, 12.20172119], [92.87853241, 12.20149136], [92.87884521, 12.2013998], [92.87921143, 12.20139122], [92.87963104, 12.20141125], [92.88015747, 12.20151138], [92.88080597, 12.20148182], [92.88131714, 12.20092964], [92.88160706, 12.20038128], [92.88168335, 12.19988155], [92.88168335, 12.1994009], [92.88172913, 12.19895363], [92.88195801, 12.19850731], [92.88185883, 12.19798088], [92.88163757, 12.19742012], [92.88132477, 12.1968956], [92.88098907, 12.19633961], [92.8807373, 12.19573116], [92.88050842, 12.19513702], [92.88020325, 12.19467163], [92.87982941, 12.19437122], [92.87947845, 12.19413376], [92.87911987, 12.19392872], [92.87866211, 12.19384193], [92.8782196, 12.19368935], [92.87769318, 12.19356155], [92.87718964, 12.19336128], [92.87666321, 12.19320202], [92.87612915, 12.19308758], [92.87561035, 12.19306946], [92.87510681, 12.19312191], [92.87465668, 12.19332027], [92.87422943, 12.19357109], [92.87382507, 12.19384003], [92.87342834, 12.19408989], [92.8731308, 12.19437122], [92.87285614, 12.19463062], [92.87254333, 12.19485188], [92.8722229, 12.19515038], [92.87184906, 12.19549179], [92.87140656, 12.19575691], [92.87097931, 12.19596386], [92.87055969, 12.1961441], [92.87014771, 12.19639206], [92.86967468, 12.19661331], [92.86914063, 12.19662476], [92.8686142, 12.19653606], [92.86815643, 12.1967802], [92.86772156, 12.19692135], [92.86727142, 12.19695091], [92.86680603, 12.19698048], [92.86637115, 12.19710827], [92.86589813, 12.19720364], [92.86540222, 12.19722366], [92.86490631, 12.19722366], [92.86443329, 12.19721699], [92.86396027, 12.19717026], [92.86348724, 12.19703102], [92.86299896, 12.19726753], [92.86260986, 12.19775295], [92.86255646, 12.19842052], [92.86277771, 12.19908619], [92.86296082, 12.19968987], [92.86280823, 12.20015812], [92.8626709, 12.20038128], [92.86245728, 12.20044041], [92.86221313, 12.20042419], [92.86200714, 12.20051098], [92.86177826, 12.20064068], [92.86152649, 12.20084572], [92.86117554, 12.20105267], [92.86068726, 12.20115089], [92.86019135, 12.20134735], [92.85966492, 12.20144081], [92.85926056, 12.20164108], [92.85886383, 12.20179844], [92.85850525, 12.20188999], [92.85812378, 12.20190144], [92.85773468, 12.20177269], [92.85728455, 12.20168686], [92.85679626, 12.20175076], [92.85634613, 12.20200062], [92.85591125, 12.20234966], [92.85553741, 12.20278072], [92.8551712, 12.20312691], [92.85489655, 12.20339203], [92.85469818, 12.20356941], [92.85441589, 12.20362186], [92.85411072, 12.20370197], [92.85378265, 12.20384979], [92.85343933, 12.20382023], [92.85311127, 12.20361042], [92.85279083, 12.20335102], [92.85246277, 12.20313358], [92.85214996, 12.20296955], [92.85189056, 12.20278072], [92.85164642, 12.20258045], [92.85137939, 12.2023983], [92.85108948, 12.20221138], [92.85085297, 12.20197201], [92.8506012, 12.20170021], [92.85034943, 12.20139503], [92.85006714, 12.20108128], [92.84979248, 12.20073891], [92.84955597, 12.20037174], [92.84921265, 12.20016193], [92.84896851, 12.19994068], [92.84881592, 12.19974709], [92.84660339, 12.19768047], [92.84651947, 12.19742012], [92.84650421, 12.19717407], [92.84659576, 12.19693661], [92.84677124, 12.19673729], [92.84703064, 12.19656086], [92.84729004, 12.19628143], [92.84764862, 12.19592953], [92.8478775, 12.19540119], [92.84798431, 12.19476318], [92.84803772, 12.19408989], [92.8480072, 12.19342041], [92.84780884, 12.19283009], [92.84749603, 12.19235134], [92.84716797, 12.19192123], [92.8469162, 12.19143963], [92.84671021, 12.19094753], [92.84670258, 12.19042969], [92.84687805, 12.18999004], [92.84707642, 12.18962097], [92.84738922, 12.18940544], [92.84768677, 12.18921089], [92.84801483, 12.18916798], [92.84835052, 12.1891613], [92.84870911, 12.18917656], [92.84910583, 12.18925381], [92.84952545, 12.18943214], [92.85002136, 12.18959141], [92.85053253, 12.18975067], [92.85098267, 12.18999863], [92.85137939, 12.19028187], [92.85183716, 12.19061947], [92.85235596, 12.191082], [92.85299683, 12.19148064], [92.85359955, 12.19137096], [92.85404205, 12.1911211], [92.85437775, 12.19083118], [92.85462952, 12.19052124], [92.85481262, 12.19019127], [92.8549881, 12.18985558], [92.85511017, 12.18946171], [92.85523987, 12.18900108], [92.8552475, 12.1884203], [92.85514069, 12.18780041], [92.85501862, 12.18720055], [92.85505676, 12.18666744], [92.85518646, 12.18622971], [92.85508728, 12.18590355], [92.85499573, 12.18558502], [92.85488892, 12.18527889], [92.85472107, 12.18500137], [92.85450745, 12.18471909], [92.85421753, 12.18445015], [92.85383606, 12.18420982], [92.85340118, 12.18413067], [92.85302734, 12.18401718], [92.85256195, 12.1841507], [92.85217285, 12.18395519], [92.85237885, 12.18364143], [92.85238647, 12.18323326], [92.85237122, 12.18286324], [92.85260773, 12.18268967], [92.8529129, 12.18258095], [92.85302734, 12.18237114], [92.85305786, 12.18207264], [92.85303497, 12.18168545], [92.85293579, 12.18127918], [92.8527832, 12.18091011], [92.85264587, 12.18056202], [92.85249329, 12.18022633], [92.85231781, 12.17986202], [92.8521347, 12.17945385], [92.85192108, 12.17902279], [92.85166168, 12.17860413], [92.85138702, 12.17818928], [92.85111237, 12.17778111], [92.85111237, 12.17722034], [92.85083008, 12.17694473], [92.85083008, 12.17666626], [92.85221863, 12.17528057], [92.85221863, 12.17472172], [92.85305786, 12.17388821], [92.85305786, 12.17360973], [92.85388947, 12.17278099], [92.85388947, 12.17249966], [92.85415649, 12.17222023], [92.85444641, 12.17222214], [92.85500336, 12.17166615], [92.85500336, 12.17138958], [92.85527802, 12.17111015], [92.85388947, 12.1697216], [92.85361481, 12.17000008], [92.85333252, 12.1697216], [92.85305786, 12.1697216], [92.85194397, 12.16861153], [92.85194397, 12.16833401], [92.85055542, 12.16694355], [92.85056305, 12.16666985], [92.85028076, 12.16639042], [92.85028076, 12.16528034], [92.85002136, 12.16500187], [92.8499527, 12.16465092], [92.84976196, 12.16431141], [92.84960175, 12.16396046], [92.84940338, 12.16364956], [92.84916687, 12.16335201], [92.84899902, 12.16304016], [92.84884644, 12.16273022], [92.84870911, 12.1624403], [92.84864807, 12.16215706], [92.84871674, 12.16187], [92.84887695, 12.16156864], [92.84908295, 12.16124439], [92.84940338, 12.16095924], [92.84970856, 12.16063976], [92.84998322, 12.16030025], [92.85018921, 12.15993118], [92.85034943, 12.15954781], [92.85051727, 12.15919018], [92.85064697, 12.15882111], [92.85079193, 12.15848064], [92.85083008, 12.15810108], [92.85079193, 12.15769863], [92.85058594, 12.15732098], [92.85015869, 12.15707302], [92.84963226, 12.15696144], [92.84909821, 12.15688133], [92.84860229, 12.15667629], [92.84809875, 12.15650082], [92.84758759, 12.15654373], [92.84712219, 12.15677357], [92.84680176, 12.1570816], [92.84657288, 12.15747166], [92.84648132, 12.15796185], [92.84654236, 12.15846062], [92.84662628, 12.15899181], [92.84661102, 12.15946102], [92.84646606, 12.15980053], [92.84632111, 12.1600647], [92.84606934, 12.16031075], [92.8456955, 12.16055775], [92.84521484, 12.16074371], [92.84465027, 12.16082382], [92.84406281, 12.16083336], [92.84346771, 12.16078758], [92.84285736, 12.1606102], [92.84212494, 12.16042519], [92.84168243, 12.16044998], [92.84123993, 12.16047764], [92.84047699, 12.1607008], [92.8398819, 12.16107464], [92.8394928, 12.16158485], [92.8392334, 12.16206169], [92.83918762, 12.1624403], [92.83922577, 12.16267014], [92.8394928, 12.16289139], [92.83950806, 12.16311932], [92.8394165, 12.16349125], [92.83917236, 12.16394043], [92.83888245, 12.16445732], [92.83859253, 12.16501999], [92.83824921, 12.16553116], [92.83789825, 12.16595173], [92.8375473, 12.16627121], [92.83724976, 12.16649532], [92.83699036, 12.16664124], [92.83686066, 12.16687107], [92.83670044, 12.16703033], [92.83650208, 12.1671896], [92.8361969, 12.16729736], [92.83583832, 12.1674633], [92.83538055, 12.1675024], [92.83521271, 12.16749954], [92.83486938, 12.16749668], [92.83435822, 12.16744137], [92.83389282, 12.16721916], [92.83347321, 12.16699791], [92.83296967, 12.16695118], [92.83245087, 12.16695118], [92.83196259, 12.16689968], [92.83149719, 12.16672039], [92.83104706, 12.16660023], [92.83072662, 12.16630077], [92.83045197, 12.16605854], [92.83023071, 12.1657877], [92.82998657, 12.16549015], [92.82978058, 12.16506577], [92.82946014, 12.16470814], [92.82894135, 12.1644001], [92.82784271, 12.16441631], [92.82778931, 12.16467094], [92.82736206, 12.16473961], [92.82697296, 12.16477203], [92.82663727, 12.16500187], [92.82637024, 12.16528893], [92.8261261, 12.16555119], [92.82595825, 12.16582012], [92.82579803, 12.16602707], [92.82563019, 12.16619205], [92.82552338, 12.16640377], [92.82540131, 12.16666985], [92.82485199, 12.16684055], [92.82463074, 12.16672707], [92.82452393, 12.16667461], [92.82402039, 12.16656494], [92.82348633, 12.16625118], [92.82299805, 12.16584969], [92.82258606, 12.16545296], [92.82234192, 12.16499996], [92.82216644, 12.16456032], [92.82196045, 12.16416836], [92.82177734, 12.16372108], [92.82160187, 12.1632309], [92.82142639, 12.16268158], [92.82128906, 12.16212082], [92.82083893, 12.16176319], [92.8205719, 12.16121578], [92.82025909, 12.16109085], [92.81997681, 12.16110039], [92.81977844, 12.1612711], [92.81939697, 12.16088963], [92.8192215, 12.16065121], [92.81905365, 12.16029453], [92.8188858, 12.15970516], [92.81871796, 12.15900135], [92.81864929, 12.1583147], [92.81877899, 12.15764713], [92.81906891, 12.15703201], [92.81937408, 12.15648174], [92.81971741, 12.15602875], [92.82006836, 12.1556406], [92.82047272, 12.15536118], [92.82086182, 12.15512943], [92.82128906, 12.1549511], [92.82170868, 12.15474987], [92.82219696, 12.15463161], [92.82270813, 12.15448093], [92.82315063, 12.15422153], [92.82356262, 12.15418053], [92.82395935, 12.15425968], [92.82433319, 12.154459], [92.8247757, 12.15467453], [92.82535553, 12.15465164], [92.82589722, 12.15430355], [92.82610321, 12.15375233], [92.82587433, 12.15326214], [92.82559967, 12.15282726], [92.82528687, 12.15245056], [92.82498932, 12.15208054], [92.82466888, 12.15175819], [92.82427979, 12.15152073], [92.82386017, 12.15134144], [92.82348633, 12.15113831], [92.82311249, 12.15100956], [92.82277679, 12.15086174], [92.82244873, 12.15075016], [92.82218933, 12.15056133], [92.82192993, 12.15036964], [92.8216629, 12.15018082], [92.82138062, 12.14998531], [92.82115173, 12.14970016], [92.82102203, 12.14927101], [92.82080078, 12.14893246], [92.82050323, 12.14869022], [92.82026672, 12.14832973], [92.81999207, 12.14797401], [92.81970978, 12.14760685], [92.81951141, 12.14724064], [92.81938171, 12.14680099], [92.81918335, 12.14633083], [92.81900024, 12.14579964], [92.81886292, 12.14523888], [92.81865692, 12.14472198], [92.81855774, 12.14415932], [92.81832886, 12.1437397], [92.81804657, 12.14337063], [92.81778717, 12.14304924], [92.81754303, 12.14275074], [92.81735229, 12.14247894], [92.81721497, 12.14220619], [92.8170929, 12.14195061], [92.8170166, 12.14169121], [92.81717682, 12.14137554], [92.81720734, 12.14098167], [92.81717682, 12.14050961], [92.81703186, 12.14001083], [92.81682587, 12.13952065], [92.81654358, 12.13915157], [92.81628418, 12.13878727], [92.81598663, 12.13843155], [92.81571198, 12.13807201], [92.8152771, 12.13777828], [92.81472015, 12.13583088], [92.81486511, 12.13459396], [92.81513977, 12.13404179], [92.81520081, 12.13318062], [92.81503296, 12.13279057], [92.81484985, 12.13239193], [92.81446838, 12.13217545], [92.81413269, 12.13192463], [92.81387329, 12.13165092], [92.81362915, 12.13142109], [92.81336975, 12.13126755], [92.8131485, 12.13108444], [92.81296539, 12.13086033], [92.81276703, 12.13064384], [92.81255341, 12.13040924], [92.81236267, 12.13009167], [92.81196594, 12.12985134], [92.81147766, 12.12957954], [92.81086731, 12.12951088], [92.81027985, 12.12978172], [92.80992126, 12.13026142], [92.80960846, 12.13072586], [92.80919647, 12.1310606], [92.80874634, 12.13138008], [92.80825043, 12.13167191], [92.807724, 12.13197708], [92.80724335, 12.13236046], [92.80680084, 12.13274765], [92.80636597, 12.13305092], [92.80595398, 12.13327885], [92.8055191, 12.13335419], [92.80509949, 12.13331509], [92.80471039, 12.13316154], [92.80435181, 12.13294125], [92.80394745, 12.13278389], [92.80351257, 12.13264465], [92.80310822, 12.13236046], [92.80274963, 12.13191986], [92.80245972, 12.13137054], [92.80226135, 12.13079166], [92.80222321, 12.1302309], [92.80227661, 12.12969971], [92.80246735, 12.12921047], [92.80258179, 12.12871075], [92.802742, 12.12829018], [92.8028183, 12.1278429], [92.80300903, 12.12743282], [92.80305481, 12.12696075], [92.80310059, 12.12644958], [92.80329132, 12.12596035], [92.80348969, 12.12545395], [92.80393982, 12.12514687], [92.80459595, 12.12489986], [92.805336, 12.12475014], [92.80605316, 12.12468243], [92.806633, 12.12446117], [92.80712891, 12.12427139], [92.80755615, 12.12415695], [92.80789948, 12.12403202], [92.80815125, 12.12387276], [92.8097229, 12.12083435], [92.80999756, 12.12055588], [92.8116684, 12.11750031], [92.81194305, 12.11556053], [92.8116684, 12.11528015], [92.8116684, 12.11472034], [92.81151581, 12.1141634], [92.81141663, 12.11359119], [92.81143188, 12.11303997], [92.8115921, 12.11257267], [92.81175995, 12.11215115], [92.81195831, 12.11182976], [92.81218719, 12.11158085], [92.81240082, 12.1113596], [92.81257629, 12.11114979], [92.81276703, 12.11098194], [92.8129425, 12.11077023], [92.81302643, 12.11045074], [92.81305695, 12.11000156], [92.81302643, 12.10951614], [92.81291199, 12.10901928], [92.81277466, 12.10888958], [92.81276703, 12.10750198], [92.8125, 12.10722065], [92.8125, 12.10694313], [92.8105545, 12.10499859], [92.8097229, 12.10500145], [92.80945587, 12.10472107], [92.80916595, 12.10472107], [92.80860901, 12.10528183], [92.80832672, 12.10528183], [92.80805206, 12.1055603], [92.80750275, 12.10555458], [92.80722046, 12.10583305], [92.8069458, 12.10583115], [92.80635834, 12.10589695], [92.80588531, 12.10610199], [92.80541229, 12.10628414], [92.8049469, 12.10645103], [92.80451202, 12.10665131], [92.80401611, 12.10681057], [92.80349731, 12.10696125], [92.80297089, 12.10715961], [92.80242157, 12.10733509], [92.80197144, 12.10764122], [92.80155182, 12.10800076], [92.80104065, 12.10826969], [92.80045319, 12.10843754], [92.79982758, 12.10857964], [92.79918671, 12.1086092], [92.79859161, 12.10856056], [92.79815674, 12.1083107], [92.79780579, 12.10797977], [92.79746246, 12.1076107], [92.79707336, 12.10725117], [92.79659271, 12.10694313], [92.7960968, 12.10665417], [92.79563904, 12.10638714], [92.79524231, 12.10615921], [92.79482269, 12.10607338], [92.79450226, 12.10589218], [92.79421234, 12.10565758], [92.7939682, 12.10531139], [92.79360962, 12.10500145], [92.79319763, 12.10472107], [92.79277802, 12.10446072], [92.79233551, 12.1042881], [92.79189301, 12.10414886], [92.79144287, 12.10397339], [92.79096222, 12.10385323], [92.79053497, 12.1036272], [92.7901001, 12.10343075], [92.78966522, 12.10326481], [92.78927612, 12.10305309], [92.78894043, 12.10283566], [92.78865051, 12.10266972], [92.78843689, 12.10249043], [92.7882843, 12.10230064], [92.7881012, 12.10210037], [92.78796387, 12.101861], [92.78787231, 12.10163975], [92.78800201, 12.10140038], [92.78808594, 12.10111809], [92.78827667, 12.10088062], [92.78852844, 12.10066891], [92.78887939, 12.10052109], [92.78918457, 12.10027885], [92.78946686, 12.10000992], [92.78974915, 12.0997324], [92.78999329, 12.09942436], [92.79020691, 12.09907055], [92.79036713, 12.09863091], [92.79057312, 12.09819126], [92.79083252, 12.09778595], [92.79112244, 12.09743023], [92.79147339, 12.09716129], [92.7918396, 12.09698105], [92.7922821, 12.09694004], [92.79271698, 12.09694481], [92.79316711, 12.09692574], [92.79358673, 12.09683132], [92.79392242, 12.09665966], [92.79418945, 12.09642029], [92.79441833, 12.09613514], [92.79456329, 12.09571171], [92.79464722, 12.09521008], [92.79469299, 12.09463978], [92.79457855, 12.09407139], [92.79441071, 12.09358978], [92.79425049, 12.09317493], [92.79437256, 12.09280968], [92.79443359, 12.09249115], [92.79444122, 12.09219933], [92.79440308, 12.09194183], [92.79425049, 12.09171867], [92.79416656, 12.09143066], [92.79412079, 12.09107113], [92.79395294, 12.09068203], [92.79381561, 12.09023857], [92.79353333, 12.08994102], [92.79332733, 12.08956909], [92.79308319, 12.08924961], [92.79268646, 12.0890789], [92.79236603, 12.08872128], [92.79210663, 12.08824062], [92.79177094, 12.08788967], [92.79162598, 12.08749962], [92.79142761, 12.08719158], [92.79138947, 12.08687115], [92.79138947, 12.08654022], [92.79144287, 12.08620071], [92.79161072, 12.08584976], [92.79173279, 12.08543873], [92.79195404, 12.08505917], [92.79222107, 12.08460999], [92.79250336, 12.08407688], [92.79277802, 12.08347034], [92.79298401, 12.08282471], [92.79294586, 12.08213902], [92.79280853, 12.08153057], [92.79271698, 12.08105373], [92.79247284, 12.08078289], [92.79206085, 12.08061695], [92.79144287, 12.08088112], [92.79100037, 12.0813303], [92.7905426, 12.08166313], [92.79004669, 12.08189487], [92.78952026, 12.08191395], [92.7890625, 12.08177662], [92.78872681, 12.08163071], [92.78851318, 12.08143044], [92.78830719, 12.08123016], [92.78810883, 12.08100033], [92.78798676, 12.08070087], [92.78778076, 12.08047962], [92.78755188, 12.08027267], [92.78726196, 12.08006763], [92.78687286, 12.07991028], [92.78642273, 12.07972813], [92.78595734, 12.07956791], [92.78549957, 12.07946396], [92.78502655, 12.07944298], [92.78453827, 12.07944107], [92.78404236, 12.07949066], [92.78356934, 12.07968044], [92.78305817, 12.07977104], [92.78263855, 12.07995605], [92.78224945, 12.07997227], [92.78191376, 12.07984638], [92.78160095, 12.07969189], [92.78134918, 12.07945728], [92.78111267, 12.07919025], [92.78089142, 12.07890511], [92.7808075, 12.07853603], [92.78067017, 12.07815075], [92.78053284, 12.07771778], [92.78031158, 12.07724094], [92.78005219, 12.07674026], [92.77971649, 12.07627964], [92.77935028, 12.0758419], [92.77901459, 12.07544804], [92.77870941, 12.0751009], [92.77835846, 12.07485104], [92.77805328, 12.07469559], [92.77776337, 12.07444954], [92.7773819, 12.07420063], [92.77693176, 12.07400131], [92.77639008, 12.07389069], [92.77583313, 12.07332993], [92.77471924, 12.07333279], [92.77416992, 12.07277679], [92.77416992, 12.07250118], [92.77388763, 12.0722208], [92.77388763, 12.07194519], [92.77361298, 12.07166672], [92.77361298, 12.07139111], [92.77305603, 12.07083035], [92.77305603, 12.07055664], [92.77278137, 12.07028103], [92.77278137, 12.0694418], [92.77222443, 12.06888771], [92.77166748, 12.06889057], [92.77139282, 12.06917095], [92.77028656, 12.06917095], [92.77009583, 12.06898594], [92.76999664, 12.06889057], [92.76972198, 12.06889057], [92.76944733, 12.06861019], [92.76860809, 12.06861019], [92.76833344, 12.06833458], [92.76805878, 12.06833458], [92.76777649, 12.0680542], [92.76750183, 12.06806087], [92.76750183, 12.06779003], [92.76692963, 12.06721973], [92.76694489, 12.06694412], [92.76638794, 12.06638813], [92.76638794, 12.06610966], [92.76583099, 12.06555557], [92.76583099, 12.06528091], [92.76587677, 12.06515121], [92.76595306, 12.06470203], [92.76593781, 12.0646286], [92.76583099, 12.06416607], [92.76499939, 12.0633297], [92.76467896, 12.06332016], [92.76403046, 12.06368065], [92.76345825, 12.06393147], [92.76293945, 12.06430054], [92.76252747, 12.06479073], [92.76226807, 12.06536674], [92.762146, 12.06597137], [92.76195526, 12.06648445], [92.76176453, 12.06697369], [92.76158905, 12.06746387], [92.7613678, 12.06791973], [92.76110077, 12.06834793], [92.76080322, 12.06874943], [92.76045227, 12.06911182], [92.76005554, 12.06941032], [92.759758, 12.06983185], [92.75940704, 12.0702486], [92.75905609, 12.07067299], [92.75874329, 12.07115173], [92.75849152, 12.07169914], [92.75830078, 12.07226181], [92.75804901, 12.07274723], [92.75776672, 12.07316017], [92.75745392, 12.07349682], [92.75712585, 12.07374096], [92.75688171, 12.0740509], [92.7566452, 12.0743084], [92.7562561, 12.0743494], [92.75591278, 12.07448769], [92.75553131, 12.07450199], [92.75513458, 12.07439709], [92.754776, 12.07417107], [92.75447083, 12.0739727], [92.75415802, 12.07411003], [92.75385284, 12.07417107], [92.75354767, 12.07422161], [92.75325775, 12.07436085], [92.7529068, 12.07443142], [92.75251007, 12.07449055], [92.75214386, 12.074687], [92.75177765, 12.07479382], [92.75147247, 12.07491398], [92.75125122, 12.07487297], [92.7511673, 12.07487106], [92.75080872, 12.07485962], [92.75045013, 12.07482147], [92.75006104, 12.07471848], [92.74962616, 12.07460022], [92.74928284, 12.07461071], [92.74894714, 12.07449055], [92.74855804, 12.07444954], [92.74812317, 12.07445908], [92.74768829, 12.07454967], [92.74726868, 12.07472992], [92.74685669, 12.0749464], [92.74640656, 12.07511044], [92.7459259, 12.0752697], [92.74544525, 12.07539845], [92.74497223, 12.07554054], [92.74447632, 12.07566929], [92.74398804, 12.07588291], [92.74352264, 12.07621098], [92.74304199, 12.07662201], [92.74258423, 12.07701588], [92.74223328, 12.07741928], [92.74194336, 12.07778645], [92.74167633, 12.07810116], [92.74143219, 12.07841969], [92.7412262, 12.07878017], [92.74108124, 12.0792017], [92.74088287, 12.0795908], [92.74069977, 12.08002186], [92.74053192, 12.08047962], [92.74028778, 12.0809269], [92.7400589, 12.08141232], [92.73986053, 12.08193016], [92.73969269, 12.08249855], [92.73950958, 12.08302784], [92.73944855, 12.08357143], [92.73940277, 12.08410168], [92.73928833, 12.08463955], [92.7392807, 12.08525944], [92.73935699, 12.08586597], [92.73942566, 12.08654308], [92.73938751, 12.08726978], [92.73924255, 12.08806133], [92.73933411, 12.08879662], [92.73940277, 12.08941174], [92.73944092, 12.09004974], [92.73943329, 12.09072018], [92.73935699, 12.09141064], [92.73928833, 12.09212875], [92.73928833, 12.09288311], [92.73919678, 12.09350109], [92.73916626, 12.09412956], [92.73916626, 12.0947504], [92.73923492, 12.09529686], [92.73940277, 12.09573174], [92.73944092, 12.09612179], [92.73944855, 12.0965004], [92.73944092, 12.09692192], [92.73944092, 12.09739113], [92.73944092, 12.09789467], [92.73944855, 12.09841919], [92.73947906, 12.09895039], [92.73958588, 12.09941101], [92.73973083, 12.09987068], [92.73988342, 12.10029888], [92.74001312, 12.10072994], [92.74015045, 12.10114002], [92.74028015, 12.10157108], [92.74032593, 12.10222054], [92.74054718, 12.10279274], [92.74080658, 12.10332203], [92.74102783, 12.10380936], [92.7412262, 12.10420132], [92.74137878, 12.10463047], [92.74150085, 12.10510826], [92.74164581, 12.10566044], [92.74182129, 12.10625935], [92.7420578, 12.10674], [92.7423172, 12.10712147], [92.74254608, 12.10751057], [92.74294281, 12.10781097], [92.74308777, 12.10829926], [92.74331665, 12.10875034], [92.74353027, 12.1092062], [92.74371338, 12.10969162], [92.74391937, 12.11015415], [92.74420166, 12.11060143], [92.74445343, 12.11110497], [92.74472046, 12.11160183], [92.74495697, 12.11212063], [92.74504089, 12.11268044], [92.74511719, 12.11316967], [92.74530029, 12.11357784], [92.74545288, 12.1139307], [92.7455368, 12.11427498], [92.74558258, 12.11460972], [92.74572754, 12.11491966], [92.74585724, 12.11530113], [92.74604797, 12.11572933], [92.74613953, 12.11625957], [92.74624634, 12.11678028], [92.74640656, 12.11721134], [92.74652863, 12.1175909], [92.74665833, 12.11793518], [92.74677277, 12.11833382], [92.74685669, 12.11882019], [92.74692535, 12.11927795], [92.74694061, 12.11974525], [92.74694061, 12.12020969], [92.74694824, 12.12067032], [92.74697876, 12.12111855], [92.74710846, 12.121562], [92.74720001, 12.12203121], [92.7472229, 12.12253475], [92.7472229, 12.12304115], [92.7472229, 12.12351513], [92.74726105, 12.12392044], [92.74740601, 12.12422752], [92.74754333, 12.12455177], [92.74775696, 12.12485313], [92.74797821, 12.12520123], [92.74819183, 12.12558174], [92.74838257, 12.12600136], [92.74861145, 12.12637043], [92.74884796, 12.12673092], [92.74904633, 12.12712002], [92.74919891, 12.12755108], [92.74938202, 12.12794113], [92.7494812, 12.12835979], [92.74964142, 12.12870884], [92.74973297, 12.12911224], [92.74983215, 12.1295414], [92.74997711, 12.12999439], [92.75005341, 12.13051224], [92.75012207, 12.13103962], [92.75017548, 12.13157558], [92.75032806, 12.13204098], [92.75051117, 12.13250065], [92.7506485, 12.13302135], [92.75083923, 12.13351059], [92.75106812, 12.13406944], [92.75118256, 12.13525009], [92.7513504, 12.13552094], [92.7515564, 12.13585186], [92.75187683, 12.13644886], [92.75226593, 12.13717079], [92.75266266, 12.13782978], [92.75300598, 12.13836956], [92.75330353, 12.13875961], [92.7535553, 12.13915157], [92.75382996, 12.13954353], [92.75409698, 12.14012146], [92.75441742, 12.14114189], [92.7543869, 12.14182091], [92.75439453, 12.14233398], [92.75432587, 12.14295101], [92.75431061, 12.14365959], [92.75431061, 12.14533138], [92.75435638, 12.1460743], [92.75453949, 12.1466713], [92.75483704, 12.14711094], [92.75531769, 12.14777184], [92.75559235, 12.14838886], [92.75567627, 12.14870071], [92.75582123, 12.14904118], [92.75598907, 12.14929581], [92.75614166, 12.14950371], [92.75653839, 12.14981365], [92.75691223, 12.15008259], [92.75757599, 12.15074062], [92.75760651, 12.15123558], [92.75760651, 12.15183067], [92.75771332, 12.15240955], [92.75795746, 12.15291786], [92.75804901, 12.15343475], [92.75808716, 12.15397072], [92.75823975, 12.15449047], [92.7583847, 12.15502834], [92.75860596, 12.15552139], [92.75884247, 12.15603065], [92.75897217, 12.15660954], [92.75913239, 12.15718174], [92.75920868, 12.15779114], [92.7594223, 12.15835953], [92.75958252, 12.15892124], [92.75966644, 12.1595211], [92.75972748, 12.16010857], [92.75978851, 12.16066933], [92.75995636, 12.16117954], [92.76006317, 12.16168118], [92.76023102, 12.16209602], [92.76027679, 12.16255188], [92.76029968, 12.16299152], [92.76036835, 12.16337872], [92.76043701, 12.16372967], [92.76055145, 12.16401958], [92.76065826, 12.16431808], [92.76077271, 12.16462994], [92.76100922, 12.16491127], [92.76109314, 12.16530037], [92.76111603, 12.16583061], [92.76113892, 12.16645145], [92.76127625, 12.16707993], [92.76146698, 12.16770935], [92.76169586, 12.16827011], [92.76194, 12.16880131], [92.762146, 12.16931152], [92.7623291, 12.16980171], [92.76246643, 12.17022133], [92.76274872, 12.17045116], [92.76299286, 12.17069054], [92.76313782, 12.17103481], [92.76331329, 12.17141056], [92.76341248, 12.17190075], [92.7641449, 12.17302895], [92.76425171, 12.17407322], [92.76431274, 12.17440319], [92.76439667, 12.17469311], [92.76454163, 12.17502117], [92.76468658, 12.17521], [92.76493835, 12.17543602], [92.76538849, 12.1765213], [92.76538849, 12.1769762], [92.76525879, 12.17846012], [92.76509094, 12.1789999], [92.76500702, 12.17947197], [92.76509094, 12.18010139], [92.76512909, 12.18082809], [92.76508331, 12.18161392], [92.76522827, 12.18225002], [92.76539612, 12.18250084], [92.76586151, 12.18274879], [92.76634216, 12.18320084], [92.76689148, 12.18384075], [92.76714325, 12.18428135], [92.76728058, 12.18478012], [92.76743317, 12.18524075], [92.76750183, 12.18570995], [92.76758575, 12.18616772], [92.76773834, 12.18659019], [92.76773834, 12.18705654], [92.76763916, 12.18756104], [92.76779938, 12.18808937], [92.76797485, 12.188591], [92.76791382, 12.18911266], [92.76802063, 12.1895504], [92.76802063, 12.18994045], [92.76789093, 12.19032097], [92.76771545, 12.19074917], [92.76744843, 12.19116211], [92.76715088, 12.19160175], [92.76687622, 12.19207096], [92.76689911, 12.19279957], [92.76690674, 12.19352055], [92.76716614, 12.19399929], [92.76735687, 12.19448853], [92.76761627, 12.19497013], [92.76794434, 12.19542789], [92.76819611, 12.19589329], [92.7685318, 12.19629192], [92.76870728, 12.19675922], [92.76889038, 12.19718075], [92.76906586, 12.19755936], [92.76920319, 12.19794178], [92.7693634, 12.19828415], [92.76943207, 12.19869041], [92.76944733, 12.19916153], [92.76948547, 12.19965553], [92.76966095, 12.20016193], [92.76967621, 12.20069122], [92.76950836, 12.20120144], [92.76935577, 12.20173931], [92.76914978, 12.20222187], [92.76889038, 12.20263004], [92.76862335, 12.20298958], [92.76835632, 12.20330048], [92.76811218, 12.20356941], [92.76792145, 12.20388603], [92.76770782, 12.20423317], [92.76744843, 12.20462036], [92.76706696, 12.20503044], [92.76669312, 12.20549965], [92.76638794, 12.20603848], [92.76609039, 12.20654106], [92.76580811, 12.2069788], [92.76555634, 12.20738029], [92.76532745, 12.20776844], [92.76506042, 12.20814991], [92.76480103, 12.20856953], [92.7647171, 12.20917606], [92.76462555, 12.20978165], [92.76442719, 12.21030045], [92.76422119, 12.2107811], [92.76419067, 12.21128178], [92.76429749, 12.21180153], [92.76443481, 12.21232986], [92.76456451, 12.21284294], [92.76469421, 12.21331024], [92.76482391, 12.21373177], [92.76493073, 12.21412182], [92.76502991, 12.21452332], [92.76511383, 12.21502209], [92.76525879, 12.2155304], [92.76538849, 12.21606064], [92.76557922, 12.21641922], [92.76574707, 12.21671963], [92.76586914, 12.21702099], [92.76602173, 12.21728992], [92.76609802, 12.21760368], [92.76611328, 12.21797371], [92.76612091, 12.21838093], [92.7661972, 12.21881008], [92.76635742, 12.21923161], [92.76644897, 12.21975136], [92.76663208, 12.22028923], [92.76674652, 12.2208786], [92.76695251, 12.22140598], [92.76721954, 12.22188473], [92.76744843, 12.22236061], [92.76754761, 12.22293091], [92.76774597, 12.22344971], [92.7678833, 12.22396088], [92.76806641, 12.22439194], [92.76828766, 12.22478104], [92.76833344, 12.22524929], [92.76831055, 12.22574139], [92.76822662, 12.22624874], [92.76824951, 12.22676182], [92.76831818, 12.22723961], [92.76841736, 12.22772121], [92.76857758, 12.22817039], [92.76876831, 12.22862244], [92.76899719, 12.2290802], [92.76935577, 12.22943974], [92.76974487, 12.22977543], [92.77005768, 12.23021221], [92.7703476, 12.23065472], [92.77049255, 12.23112202], [92.7703476, 12.23157978], [92.77011108, 12.23200226], [92.76992798, 12.23243237], [92.76970673, 12.23278999], [92.76943207, 12.23309994], [92.76933289, 12.2335062], [92.76937103, 12.23399067], [92.76938629, 12.23444939], [92.76930237, 12.23487091], [92.76941681, 12.23526764], [92.76951599, 12.23570347], [92.7696991, 12.23609543], [92.7698288, 12.23649406], [92.76986694, 12.23685169], [92.76972198, 12.23722839], [92.76953888, 12.23758125], [92.76938629, 12.23782921], [92.76915741, 12.23805046], [92.76882172, 12.23822594], [92.76851654, 12.23829365], [92.76818848, 12.23818493], [92.76786041, 12.23800945], [92.76756287, 12.23776817], [92.76724243, 12.23750114], [92.76690674, 12.23721886], [92.76661682, 12.23701096], [92.76629639, 12.23713398], [92.7660141, 12.23744202], [92.76582336, 12.23730278], [92.76573944, 12.23670292], [92.7654953, 12.23621559], [92.76502991, 12.23601055], [92.76460266, 12.23577118], [92.76429749, 12.23541069], [92.76407623, 12.23501015], [92.76390076, 12.23463154], [92.7637558, 12.23423958], [92.76360321, 12.23381424], [92.76343536, 12.23339367], [92.76329803, 12.23298645], [92.76304626, 12.23271275], [92.76275635, 12.23250103], [92.76246643, 12.23233032], [92.76212311, 12.23224068], [92.76171875, 12.2322197], [92.7612915, 12.23224068], [92.76087189, 12.23233032], [92.76048279, 12.23252106], [92.76010132, 12.23278141], [92.75972748, 12.23309803], [92.75952911, 12.23350143], [92.75949097, 12.23390007], [92.75977325, 12.23427773], [92.76035309, 12.23464775], [92.76072693, 12.23505116], [92.76098633, 12.23542023], [92.76117706, 12.23575115], [92.7612381, 12.23604012], [92.76111603, 12.23626137], [92.76084137, 12.23639107], [92.76048279, 12.23626137], [92.76007843, 12.23591042], [92.75969696, 12.23546124], [92.75934601, 12.23505974], [92.7590332, 12.23475933], [92.75874329, 12.23457718], [92.75842285, 12.23443985], [92.75805664, 12.23429203], [92.75777435, 12.23417759], [92.7574234, 12.23406029], [92.75701904, 12.23387718], [92.75654602, 12.23364925], [92.75597382, 12.23356533], [92.75539398, 12.23334408], [92.75480652, 12.23314953], [92.75428009, 12.23301983], [92.75388336, 12.232831], [92.75347137, 12.23275089], [92.75312042, 12.23268127], [92.75282288, 12.23254204], [92.75247955, 12.23250103], [92.7521286, 12.23250103], [92.75177765, 12.23249626], [92.7514267, 12.23254204], [92.75112152, 12.23273087], [92.75078583, 12.2328701], [92.7508316, 12.23306084], [92.74973297, 12.23417091], [92.74944305, 12.2341671], [92.7491684, 12.23444462], [92.74861145, 12.23443985], [92.74804688, 12.23500061], [92.7480545, 12.2355547], [92.74781799, 12.23592186], [92.74777985, 12.2364254], [92.74777985, 12.23691273], [92.74783325, 12.23733044], [92.7480011, 12.23764038], [92.74812317, 12.23795891], [92.74828339, 12.23828125], [92.74834442, 12.23867893], [92.74842834, 12.23910999], [92.74858093, 12.23958015], [92.7486496, 12.24015045], [92.74878693, 12.24075985], [92.74881744, 12.24140072], [92.74861145, 12.24199963], [92.74833679, 12.24254704], [92.74806213, 12.24304199], [92.7477951, 12.24347687], [92.74755859, 12.2438736], [92.74729919, 12.24419498], [92.74703217, 12.24448013], [92.74674988, 12.24476719], [92.74641418, 12.24501514], [92.74602509, 12.24518871], [92.7455368, 12.24506092], [92.74507141, 12.24502945], [92.74465179, 12.24507236], [92.74429321, 12.24505901], [92.74397278, 12.24484921], [92.74357605, 12.24467087], [92.74317169, 12.24448872], [92.7427063, 12.24453926], [92.74234009, 12.24493122], [92.74228668, 12.24553967], [92.74249268, 12.24601555], [92.74274445, 12.2464056], [92.74297333, 12.24675179], [92.74308777, 12.24714184], [92.74327087, 12.2474699], [92.74336243, 12.24785995], [92.74349976, 12.24824047], [92.74359131, 12.2486372], [92.74360657, 12.24907017], [92.74360657, 12.24955082], [92.74360657, 12.25004959], [92.74362946, 12.25058079], [92.7437973, 12.25108719], [92.74397278, 12.25161076], [92.74419403, 12.25210953], [92.7444458, 12.25255871], [92.74472046, 12.25296974], [92.74500275, 12.25337124], [92.74526978, 12.25374889], [92.74549103, 12.25412273], [92.74565125, 12.25451946], [92.74582672, 12.25486088], [92.74598694, 12.25517082], [92.74610138, 12.25552177], [92.74619293, 12.25588703], [92.74637604, 12.2562151], [92.74654388, 12.25656414], [92.7466507, 12.2569809], [92.74671173, 12.25742817], [92.74690247, 12.25783062], [92.74697876, 12.25826168], [92.74718475, 12.25859928], [92.74732971, 12.25898361], [92.74749756, 12.25936031], [92.74767303, 12.25975513], [92.74783325, 12.26017189], [92.74803162, 12.26055908], [92.74819946, 12.26097393], [92.74846649, 12.26129055], [92.74859619, 12.26173306], [92.74867249, 12.26224995], [92.74880981, 12.26278114], [92.74868774, 12.26327991], [92.74855804, 12.26375008], [92.74836731, 12.26413059], [92.74823761, 12.26451969], [92.74809265, 12.26488018], [92.74809265, 12.26527691], [92.74825287, 12.26567078], [92.74837494, 12.26610374], [92.74861145, 12.26643944], [92.74888611, 12.26678085], [92.74914551, 12.26713657], [92.74935913, 12.26753998], [92.74948883, 12.26806736], [92.74971771, 12.26852226], [92.74989319, 12.2689333], [92.74977875, 12.26934147], [92.74971008, 12.26980114], [92.74960327, 12.27026367], [92.74948883, 12.27072239], [92.74953461, 12.27117252], [92.74968719, 12.27159023], [92.7497406, 12.27199078], [92.74983978, 12.27232647], [92.74996948, 12.27264309], [92.75004578, 12.27302074], [92.75019836, 12.27338791], [92.75035858, 12.27377796], [92.7506485, 12.2740736], [92.751091, 12.27427292], [92.75154114, 12.27447319], [92.75196838, 12.27465343], [92.752388, 12.27453041], [92.75274658, 12.27424145], [92.75300598, 12.27383137], [92.75313568, 12.27328587], [92.75337982, 12.27273178], [92.75364685, 12.27215958], [92.75409698, 12.27171135], [92.7546463, 12.27139187], [92.75521088, 12.27109146], [92.75572968, 12.270751], [92.75611115, 12.27035046], [92.75643921, 12.26993084], [92.75668335, 12.2694912], [92.75691223, 12.26909733], [92.75704193, 12.26869106], [92.75722504, 12.26837444], [92.7574234, 12.26810837], [92.75757599, 12.26786232], [92.75777435, 12.26777267], [92.75801849, 12.26777267], [92.75831604, 12.26777935], [92.75872803, 12.26777935], [92.75920868, 12.2677412], [92.75971222, 12.26755238], [92.76017761, 12.26729202], [92.76052094, 12.26692009], [92.76082611, 12.2665596], [92.76114655, 12.26624107], [92.76154327, 12.26599026], [92.76198578, 12.26579189], [92.7624588, 12.26544571], [92.76288605, 12.2650013], [92.76328278, 12.26459122], [92.76360321, 12.26425076], [92.76389313, 12.26400089], [92.76420593, 12.26385021], [92.764534, 12.26379585], [92.76490021, 12.26394367], [92.76528168, 12.26421261], [92.76568604, 12.26455021], [92.76609802, 12.26494694], [92.76629639, 12.26543045], [92.76637268, 12.26596069], [92.76641083, 12.26645088], [92.76647186, 12.26690197], [92.76659393, 12.26728535], [92.76670837, 12.26766968], [92.76685333, 12.26805973], [92.76703644, 12.26847172], [92.76732635, 12.26877117], [92.76767731, 12.26898098], [92.76803589, 12.26929092], [92.76835632, 12.26965141], [92.76869202, 12.27000618], [92.76898193, 12.27037144], [92.76921844, 12.27074909], [92.76948547, 12.2710638], [92.76978302, 12.2713213], [92.77012634, 12.27151012], [92.77050018, 12.27169037], [92.77082825, 12.27193928], [92.77114105, 12.27221203], [92.7714386, 12.27250195], [92.77171326, 12.27283001], [92.77194214, 12.27318287], [92.77213287, 12.27352524], [92.77230835, 12.27384186], [92.77248383, 12.27411842], [92.77262115, 12.27439117], [92.77274323, 12.27466011], [92.77281952, 12.27499104], [92.77291107, 12.27532959], [92.77309418, 12.27576256], [92.77332306, 12.27622128], [92.77350616, 12.276721], [92.77362061, 12.27728558], [92.77377319, 12.27783489], [92.77404785, 12.27821064], [92.77420807, 12.27871704], [92.77445221, 12.279212], [92.77474213, 12.27965641], [92.77509308, 12.27994537], [92.77548981, 12.27995491], [92.77583313, 12.27972221], [92.77666473, 12.27888775], [92.77694702, 12.27888966], [92.7771759, 12.27863026], [92.7775116, 12.27866936], [92.77778625, 12.27888107], [92.77805328, 12.27910042], [92.77829742, 12.27929974], [92.77855682, 12.27952194], [92.77870941, 12.2798996], [92.77892303, 12.28034019], [92.77913666, 12.28083038], [92.77937317, 12.28133106], [92.77960205, 12.28175545], [92.77973938, 12.28222179], [92.77999115, 12.28265762], [92.78022766, 12.28310394], [92.7804718, 12.28355122], [92.78082275, 12.28390026], [92.78111267, 12.28431034], [92.78139496, 12.28470898], [92.78172302, 12.28507996], [92.78183746, 12.28549099], [92.7817688, 12.28586197], [92.78166199, 12.28623104], [92.78147125, 12.28656864], [92.78105164, 12.28677368], [92.78073883, 12.28717041], [92.78032684, 12.28747272], [92.77996063, 12.28785038], [92.77971649, 12.28832817], [92.77954102, 12.28880024], [92.77945709, 12.28928757], [92.77942657, 12.28975868], [92.77935028, 12.29021072], [92.77915955, 12.29061031], [92.77887726, 12.29096699], [92.77852631, 12.29127979], [92.7780838, 12.29147625], [92.77760315, 12.29163074], [92.77703857, 12.29169941], [92.77646637, 12.29186058], [92.77588654, 12.29207039], [92.77541351, 12.29239178], [92.7750473, 12.29281139], [92.77481079, 12.29326916], [92.77472687, 12.29378033], [92.77476501, 12.29427719], [92.77497864, 12.29468155], [92.77539825, 12.2949543], [92.77593231, 12.29506969], [92.77639771, 12.29529953], [92.7767334, 12.2955389], [92.77693939, 12.2957468], [92.77707672, 12.29596996], [92.77719879, 12.29624844], [92.77722168, 12.29658127], [92.77719116, 12.2969389], [92.77703094, 12.29725075], [92.7768631, 12.29758072], [92.77667236, 12.29793453], [92.776474, 12.29833126], [92.77626038, 12.29875278], [92.77604675, 12.29921055], [92.77583313, 12.29966927], [92.77562714, 12.30010891], [92.77552032, 12.30054188], [92.77533722, 12.30086136], [92.77510834, 12.30112076], [92.77481079, 12.30133057], [92.77439117, 12.30138779], [92.77394867, 12.3013916], [92.77352905, 12.30138302], [92.77316284, 12.30130768], [92.77288055, 12.30109119], [92.77263641, 12.30077171], [92.7724762, 12.30031013], [92.77222443, 12.29986286], [92.77194214, 12.29941559], [92.77168274, 12.29899025], [92.771492, 12.29858685], [92.77133942, 12.29821014], [92.77112579, 12.29796219], [92.77091217, 12.29773903], [92.77072906, 12.2975111], [92.77047729, 12.29731941], [92.77017975, 12.29722977], [92.7698288, 12.29722118], [92.76945496, 12.29722118], [92.76907349, 12.29722118], [92.76868439, 12.29722404], [92.76828766, 12.29727077], [92.76792908, 12.29747868], [92.76760864, 12.29773045], [92.76754761, 12.29812241], [92.76767731, 12.29854965], [92.76778412, 12.29903984], [92.76789093, 12.29954433], [92.76802063, 12.30004978], [92.76805115, 12.30065823], [92.76808929, 12.30130959], [92.76824951, 12.3019762], [92.76843262, 12.30259991], [92.76874542, 12.30303764], [92.76904297, 12.30339146], [92.76921844, 12.3037672], [92.76940155, 12.30409145], [92.76950073, 12.30445957], [92.76967621, 12.30478954], [92.76972198, 12.30517578], [92.76972198, 12.30558109], [92.76972198, 12.30598927], [92.76972198, 12.30644035], [92.76972198, 12.30692959], [92.76972198, 12.30750275], [92.76972198, 12.30814838], [92.76973724, 12.30883121], [92.76969147, 12.30952168], [92.76999664, 12.31026936], [92.77044678, 12.310812], [92.77059937, 12.31133556], [92.77082825, 12.31186008], [92.77110291, 12.31213093], [92.77128601, 12.31285191], [92.7718811, 12.31291103], [92.77249908, 12.31245136], [92.77289581, 12.31225204], [92.77333069, 12.31203556], [92.77375793, 12.31179047], [92.77420044, 12.3115387], [92.77469635, 12.3113308], [92.77516937, 12.31110096], [92.77558899, 12.31083679], [92.77597046, 12.31060886], [92.77630615, 12.31046963], [92.77657318, 12.3102808]]], [[[92.94139862, 12.28080177], [92.94165802, 12.28033066], [92.94193268, 12.27989101], [92.9421463, 12.2794714], [92.94244385, 12.27910233], [92.94262695, 12.27865982], [92.94248962, 12.27805233], [92.94236755, 12.27748203], [92.94245911, 12.27703953], [92.94249725, 12.27662945], [92.94249725, 12.27618027], [92.94248962, 12.27565193], [92.94241333, 12.27509117], [92.94219971, 12.27459621], [92.94193268, 12.27416992], [92.94165802, 12.27377605], [92.94139099, 12.27338791], [92.94114685, 12.27296925], [92.94094086, 12.27251816], [92.9406662, 12.27208042], [92.94033813, 12.27170372], [92.94004059, 12.27128696], [92.93978119, 12.27081966], [92.9394989, 12.27035046], [92.93913269, 12.26999283], [92.9386673, 12.26973724], [92.9381485, 12.26954079], [92.93766022, 12.26936054], [92.93727112, 12.2690506], [92.93695068, 12.26867104], [92.9366684, 12.26828957], [92.93643188, 12.26792145], [92.93626404, 12.26752567], [92.93608856, 12.26714993], [92.93588257, 12.26674938], [92.93575287, 12.26624107], [92.93548584, 12.26577187], [92.93518066, 12.2652998], [92.93487549, 12.26487446], [92.93462372, 12.26444054], [92.9344101, 12.26402092], [92.93417358, 12.26368237], [92.93393707, 12.26338768], [92.93370819, 12.26315975], [92.9335022, 12.26294136], [92.93333435, 12.26272202], [92.93318939, 12.26249409], [92.9330368, 12.26225853], [92.93286896, 12.2620306], [92.93271637, 12.26175117], [92.93253326, 12.26148033], [92.93239594, 12.26116085], [92.93218231, 12.26088142], [92.93190002, 12.2606411], [92.9315567, 12.26044655], [92.93121338, 12.2602396], [92.93093109, 12.25999832], [92.93071747, 12.25974083], [92.93055725, 12.25947189], [92.93032074, 12.25932598], [92.93013763, 12.25916195], [92.93000031, 12.25896072], [92.92987823, 12.2587204], [92.92971039, 12.25829124], [92.92951202, 12.25778961], [92.9294281, 12.25720024], [92.92931366, 12.25661373], [92.92916107, 12.25610828], [92.92899323, 12.25561142], [92.92882538, 12.25515842], [92.92862701, 12.25471973], [92.92845917, 12.25426865], [92.92830658, 12.25386143], [92.92817688, 12.25349236], [92.92797089, 12.253232], [92.92781067, 12.25298977], [92.92778015, 12.25273705], [92.92778015, 12.25244141], [92.92775726, 12.25213146], [92.92765808, 12.25184059], [92.92752838, 12.25156116], [92.92749786, 12.25123978], [92.92749786, 12.25089264], [92.92749786, 12.25044441], [92.92750549, 12.24991322], [92.92758942, 12.24939823], [92.92785645, 12.24905014], [92.92808533, 12.24873257], [92.92832947, 12.24844074], [92.92858124, 12.24808979], [92.92884064, 12.24767971], [92.92901611, 12.24720097], [92.92910004, 12.24667931], [92.92893982, 12.2461319], [92.92890167, 12.24558067], [92.92888641, 12.24507046], [92.92888641, 12.24460125], [92.92892456, 12.24418354], [92.92907715, 12.24379635], [92.92914581, 12.24337006], [92.9291687, 12.24291039], [92.9291687, 12.2424612], [92.92919922, 12.24206161], [92.92933655, 12.24175167], [92.92943573, 12.24151516], [92.92945862, 12.24129963], [92.92938995, 12.24103165], [92.92922974, 12.24071026], [92.92914581, 12.24039078], [92.92914581, 12.24002171], [92.92914581, 12.23957062], [92.92905426, 12.23907375], [92.92888641, 12.23853397], [92.92866516, 12.2379427], [92.92841339, 12.23730278], [92.92799377, 12.23672867], [92.92752075, 12.23620033], [92.92708588, 12.23569202], [92.92674255, 12.23520184], [92.92649078, 12.2347002], [92.92627716, 12.23418045], [92.92607117, 12.23366547], [92.92582703, 12.23316193], [92.92555237, 12.23269939], [92.92527771, 12.2322607], [92.92495728, 12.23182774], [92.92450714, 12.23139095], [92.92392731, 12.23097134], [92.92362213, 12.23085117], [92.92321014, 12.23083687], [92.92263794, 12.23085117], [92.92208862, 12.23095131], [92.92170715, 12.23118973], [92.92147827, 12.23148441], [92.92133331, 12.23184013], [92.92110443, 12.23215866], [92.92085266, 12.23248005], [92.92058563, 12.23283768], [92.91853333, 12.23877144], [92.91880798, 12.24207973], [92.91853333, 12.24400997], [92.91916656, 12.24555969], [92.91916656, 12.24611187], [92.91944122, 12.24638844], [92.91944122, 12.24722195], [92.91972351, 12.24750042], [92.91972351, 12.24833393], [92.91999817, 12.24860954], [92.91999817, 12.25027847], [92.9200058, 12.25068092], [92.92007446, 12.25109577], [92.92016602, 12.25157928], [92.92030334, 12.25213146], [92.92047119, 12.25264645], [92.92064667, 12.25313091], [92.92084503, 12.25351906], [92.92108154, 12.25381088], [92.92140961, 12.25401592], [92.92176056, 12.25425053], [92.92180634, 12.25475597], [92.92183685, 12.25517559], [92.92195892, 12.25548077], [92.92214203, 12.25579262], [92.92221069, 12.25626087], [92.92225647, 12.25680065], [92.92236328, 12.25731087], [92.9225235, 12.2577219], [92.92267609, 12.25806999], [92.92276001, 12.25838947], [92.9227829, 12.2586813], [92.9227829, 12.25895023], [92.9227829, 12.25922108], [92.92272949, 12.25953102], [92.92256165, 12.25983047], [92.92238617, 12.2602396], [92.92212677, 12.26065922], [92.92205811, 12.26117039], [92.92216492, 12.26169872], [92.92215729, 12.26212025], [92.92199707, 12.26249027], [92.92190552, 12.26290703], [92.92173767, 12.2633009], [92.92163086, 12.26371956], [92.92147064, 12.26412106], [92.92138672, 12.26454067], [92.92132568, 12.26488972], [92.9210968, 12.26510143], [92.92085266, 12.26537037], [92.92066956, 12.26556396], [92.92041779, 12.26563263], [92.92015076, 12.26567364], [92.92003632, 12.2656641], [92.91983795, 12.26564598], [92.91950226, 12.26539135], [92.91925812, 12.26485062], [92.91911316, 12.26412106], [92.91877747, 12.26341915], [92.91829681, 12.26289082], [92.91777039, 12.26291084], [92.9172287, 12.26307106], [92.91668701, 12.26336002], [92.91623688, 12.26382732], [92.91616821, 12.26451111], [92.91641235, 12.26519012], [92.91677856, 12.26579189], [92.91713715, 12.26632118], [92.9174118, 12.26679039], [92.91751099, 12.26718044], [92.91739655, 12.26743126], [92.91720581, 12.26752186], [92.91697693, 12.26745129], [92.91673279, 12.2672596], [92.9164505, 12.2670002], [92.91616058, 12.26671124], [92.91586304, 12.26641178], [92.9155426, 12.26611996], [92.91525269, 12.26588631], [92.91500854, 12.26568031], [92.91482544, 12.26548195], [92.91468048, 12.2651968], [92.91440582, 12.26493073], [92.91416168, 12.26456642], [92.91388702, 12.26410961], [92.91361237, 12.26360035], [92.91335297, 12.26311016], [92.91295624, 12.26296139], [92.91256714, 12.26310253], [92.91223145, 12.26353264], [92.91203308, 12.2640419], [92.912117, 12.26462078], [92.91227722, 12.26521111], [92.9125061, 12.26573658], [92.91278076, 12.26622105], [92.91306305, 12.26672173], [92.91331482, 12.26721668], [92.91351318, 12.26769257], [92.91365051, 12.2681303], [92.91381836, 12.26858902], [92.91384125, 12.26912212], [92.91378021, 12.26970959], [92.91404724, 12.27038002], [92.91419983, 12.27103043], [92.91433716, 12.27157021], [92.91439056, 12.27202129], [92.91429901, 12.27237225], [92.91417694, 12.27263165], [92.91398621, 12.27283001], [92.91364288, 12.27300072], [92.91304016, 12.27304935], [92.912323, 12.27305984], [92.91160583, 12.27312183], [92.91100311, 12.27334118], [92.91044617, 12.27357101], [92.90989685, 12.27367973], [92.90945435, 12.27388763], [92.90899658, 12.2741003], [92.90853119, 12.27429962], [92.90804291, 12.27440929], [92.9076004, 12.27439117], [92.90722656, 12.27406979], [92.90692902, 12.27367973], [92.90661621, 12.27326107], [92.90634155, 12.27281189], [92.90602875, 12.27232647], [92.90558624, 12.27188015], [92.90516663, 12.27144718], [92.90471649, 12.27112103], [92.90428162, 12.27089024], [92.90380096, 12.27083111], [92.90332031, 12.27083969], [92.90283203, 12.27092934], [92.90235901, 12.27109146], [92.9018631, 12.27121639], [92.90145874, 12.27147198], [92.90117645, 12.27188015], [92.90112305, 12.27243996], [92.90115356, 12.27301025], [92.9013443, 12.27350521], [92.90146637, 12.2740612], [92.90170288, 12.27455997], [92.9020462, 12.27496147], [92.90248108, 12.27528], [92.90283966, 12.27562046], [92.90312958, 12.27592087], [92.90333557, 12.27618885], [92.90351105, 12.27643585], [92.90364075, 12.276721], [92.90380859, 12.27705765], [92.90387726, 12.27744961], [92.90383911, 12.27785969], [92.90366364, 12.27817726], [92.9034729, 12.27846432], [92.90320587, 12.27872372], [92.90284729, 12.27896976], [92.90252686, 12.27929974], [92.90222931, 12.27965069], [92.90194702, 12.27999115], [92.90171814, 12.28035831], [92.90158844, 12.28076363], [92.9018631, 12.28130245], [92.90213776, 12.28178692], [92.90221405, 12.28227234], [92.90222931, 12.28269196], [92.90228271, 12.2830677], [92.90245819, 12.28338242], [92.90249634, 12.28372383], [92.90250397, 12.28407288], [92.90248871, 12.28443146], [92.90238953, 12.284832], [92.90219879, 12.28528118], [92.90202332, 12.2857914], [92.90194702, 12.28635025], [92.9019165, 12.28689003], [92.90177917, 12.28737068], [92.90157318, 12.2877903], [92.90146637, 12.28822136], [92.90184784, 12.28877926], [92.9021759, 12.289361], [92.90242004, 12.2899189], [92.90278625, 12.29032707], [92.90320587, 12.29066181], [92.90376282, 12.29090118], [92.90429688, 12.29119968], [92.90484619, 12.29158974], [92.90544128, 12.29184341], [92.90604401, 12.29171276], [92.90663147, 12.2917099], [92.90717316, 12.29188633], [92.9076767, 12.29189014], [92.90815735, 12.29195023], [92.90859985, 12.29206085], [92.9090271, 12.29223728], [92.90943909, 12.2924509], [92.90992737, 12.29259014], [92.91034698, 12.29279137], [92.91074371, 12.29300022], [92.91118622, 12.2930479], [92.91163635, 12.2930603], [92.91213226, 12.2930603], [92.91266632, 12.29302979], [92.91324615, 12.29286098], [92.91382599, 12.29261112], [92.91430664, 12.29220009], [92.914711, 12.29175377], [92.91509247, 12.29132462], [92.91552734, 12.29099178], [92.91598511, 12.29067326], [92.91640472, 12.29032707], [92.91681671, 12.29000092], [92.91718292, 12.28971195], [92.91750336, 12.28946114], [92.91780853, 12.28928089], [92.91816711, 12.28916931], [92.91857147, 12.28907108], [92.91896057, 12.28887081], [92.91928101, 12.28855228], [92.91942596, 12.2881279], [92.91944122, 12.28765965], [92.91938782, 12.28720188], [92.91921234, 12.28678513], [92.91916656, 12.28628063], [92.91916656, 12.28573036], [92.91916656, 12.28516006], [92.91916656, 12.28461075], [92.91916656, 12.28412056], [92.91919708, 12.28372192], [92.91933441, 12.28342628], [92.91944122, 12.28317738], [92.91956329, 12.2830019], [92.91971588, 12.28286266], [92.91983032, 12.2824297], [92.9200058, 12.2822504], [92.92021942, 12.28227043], [92.92040253, 12.28249073], [92.92066956, 12.28283978], [92.92095947, 12.28329086], [92.92134857, 12.2837019], [92.92181396, 12.28412819], [92.92243958, 12.28439236], [92.9230957, 12.28436184], [92.92359161, 12.28397465], [92.92395782, 12.28353119], [92.92420197, 12.28308201], [92.92440796, 12.28271008], [92.92453003, 12.28231144], [92.92472076, 12.28195953], [92.92492676, 12.2816], [92.92506409, 12.28123093], [92.92529297, 12.28096199], [92.92552185, 12.28074074], [92.92572784, 12.28055191], [92.92592621, 12.2804203], [92.92617798, 12.28038979], [92.92643738, 12.28046989], [92.92673492, 12.28058147], [92.92700958, 12.28080654], [92.9272995, 12.28103924], [92.92765045, 12.28125095], [92.92798615, 12.28151131], [92.92835236, 12.28183937], [92.92873383, 12.28218842], [92.92914581, 12.28250027], [92.92944336, 12.28287029], [92.92969513, 12.28318882], [92.92987823, 12.28347969], [92.92999268, 12.28378105], [92.9300766, 12.284091], [92.93023682, 12.28439045], [92.93032837, 12.28477955], [92.93050385, 12.28519726], [92.93054962, 12.28569317], [92.93055725, 12.28623104], [92.93055725, 12.28678989], [92.93054199, 12.28734112], [92.93045807, 12.28785038], [92.93026733, 12.28830147], [92.93003845, 12.28867531], [92.92991638, 12.28907967], [92.92972565, 12.2894268], [92.92952728, 12.28977966], [92.92938232, 12.29018974], [92.92914581, 12.29057121], [92.92888641, 12.29098797], [92.92868042, 12.29147053], [92.9287796, 12.29206085], [92.92910004, 12.29259014], [92.92936707, 12.29309177], [92.92954254, 12.29355621], [92.9296875, 12.29399395], [92.92974091, 12.29443169], [92.92980957, 12.29483986], [92.92993927, 12.29520226], [92.92999268, 12.29561043], [92.93000031, 12.29605675], [92.93000793, 12.29655075], [92.93006897, 12.29709816], [92.93028259, 12.29765224], [92.93048096, 12.29823112], [92.93048096, 12.29887104], [92.93026733, 12.2994709], [92.93004608, 12.30010033], [92.93000031, 12.30072021], [92.9299469, 12.30124187], [92.92978668, 12.30164146], [92.92970276, 12.30202103], [92.92958832, 12.30234909], [92.92946625, 12.3026619], [92.92942047, 12.30299664], [92.92931366, 12.30335236], [92.92922211, 12.30377388], [92.92933655, 12.30428886], [92.92965698, 12.30484009], [92.92991638, 12.30536938], [92.93010712, 12.30586815], [92.93039703, 12.30620098], [92.93074799, 12.30644035], [92.93102264, 12.30666161], [92.93127441, 12.30686855], [92.93158722, 12.30703068], [92.93190765, 12.30727673], [92.93221283, 12.307621], [92.93251801, 12.30806828], [92.93282318, 12.30857372], [92.9331665, 12.30902004], [92.93344879, 12.30950069], [92.93367767, 12.31000042], [92.93403625, 12.31038094], [92.93421936, 12.31046104], [92.93444824, 12.31056118], [92.9347229, 12.3102808], [92.9347229, 12.30943966], [92.93444824, 12.30916595], [92.93444824, 12.3088913], [92.93416595, 12.30860996], [92.93416595, 12.308321], [92.93444824, 12.30805588], [92.93444824, 12.30694199], [92.9347229, 12.30666637], [92.9347229, 12.30639267], [92.93499756, 12.30611038], [92.93499756, 12.30583191], [92.93527985, 12.3055563], [92.9347229, 12.30500031], [92.9347229, 12.30443859], [92.93499756, 12.30416584], [92.93499756, 12.30389023], [92.93553925, 12.30332947], [92.9355545, 12.30277824], [92.93585205, 12.30251122], [92.93585205, 12.30221939], [92.93598175, 12.30180454], [92.9361496, 12.30144215], [92.9363327, 12.30103683], [92.93638611, 12.30055141], [92.93644714, 12.30001068], [92.93660736, 12.2994709], [92.93666077, 12.29895973], [92.9366684, 12.29849052], [92.93663788, 12.29809666], [92.93653107, 12.29778194], [92.93638611, 12.2974968], [92.93622589, 12.29720974], [92.93606567, 12.29691601], [92.93585968, 12.2966404], [92.93570709, 12.29629135], [92.93544769, 12.29602337], [92.93508911, 12.29581738], [92.93473053, 12.29556179], [92.93438721, 12.29526997], [92.93341064, 12.29403973], [92.93299103, 12.29321003], [92.93299103, 12.29183578], [92.93326569, 12.2903204], [92.93327332, 12.28894138], [92.9336853, 12.28742599], [92.93424988, 12.28604031], [92.9353714, 12.28508282], [92.93759155, 12.28362179], [92.93803406, 12.28305435], [92.93847656, 12.28254128], [92.93897247, 12.28214931], [92.93947601, 12.28190804], [92.93997955, 12.28167057], [92.94050598, 12.28144073], [92.94100952, 12.28118515], [92.94139862, 12.28080177]]], [[[92.75444794, 12.29472256], [92.7547226, 12.29444313], [92.75499725, 12.29444313], [92.75499725, 12.29361057], [92.75333405, 12.29194546], [92.75305176, 12.29194546], [92.7527771, 12.29222107], [92.75222015, 12.29278183], [92.75250244, 12.29305458], [92.75250244, 12.29333305], [92.7527771, 12.29361057], [92.7527771, 12.29416656], [92.75333405, 12.29472256], [92.75444794, 12.29472256]]], [[[92.77118683, 12.29492378], [92.77120972, 12.29350567], [92.771492, 12.29354954], [92.7714386, 12.29295921], [92.77060699, 12.29212093], [92.77060699, 12.29101276], [92.77033234, 12.29073524], [92.77033234, 12.29046059], [92.76950073, 12.2896204], [92.76894379, 12.28934669], [92.76893616, 12.2887907], [92.76893616, 12.28851032], [92.76838684, 12.28851318], [92.7684021, 12.2887907], [92.76811218, 12.28907108], [92.76673126, 12.2890892], [92.76667023, 12.28991032], [92.76700592, 12.28988934], [92.76699829, 12.29045677], [92.76756287, 12.29075146], [92.76757813, 12.29133034], [92.76815033, 12.29130936], [92.76818848, 12.29214954], [92.76837158, 12.29213047], [92.76838684, 12.29295731], [92.76894379, 12.29323483], [92.76950073, 12.29378891], [92.76950073, 12.29406929], [92.76977539, 12.29434681], [92.76977539, 12.29462528], [92.77033234, 12.29464436], [92.77035522, 12.29494381], [92.77118683, 12.29492378]]], [[[93.07256317, 12.31904411], [93.07259369, 12.31831932], [93.07287598, 12.31815147], [93.07318878, 12.31790924], [93.0734024, 12.31762886], [93.07382202, 12.31732082], [93.07375336, 12.31701088], [93.07389069, 12.31670094], [93.07364655, 12.31648922], [93.07343292, 12.31618404], [93.07350159, 12.31573677], [93.07293701, 12.31539059], [93.07263184, 12.31542683], [93.07234955, 12.3157711], [93.07203674, 12.3157711], [93.07171631, 12.31591034], [93.07147217, 12.31608105], [93.07084656, 12.31584167], [93.07042694, 12.31584167], [93.06978607, 12.31591034], [93.06960297, 12.31617928], [93.06954956, 12.31648922], [93.06919861, 12.31620026], [93.06829071, 12.31620026], [93.06800842, 12.31606102], [93.06758881, 12.31585979], [93.06710052, 12.31613064], [93.0669632, 12.31599045], [93.06632996, 12.31603146], [93.06614685, 12.31620026], [93.06601715, 12.31609726], [93.06562805, 12.3163023], [93.06531525, 12.3163023], [93.06520844, 12.31616592], [93.06490326, 12.31616974], [93.06458282, 12.31627274], [93.06394958, 12.31606102], [93.06363678, 12.31592178], [93.06339264, 12.31571674], [93.06301117, 12.31592178], [93.06301117, 12.31616592], [93.06321716, 12.31633186], [93.06349945, 12.31657791], [93.06352997, 12.31678104], [93.06381226, 12.31696129], [93.0640564, 12.31707001], [93.06433868, 12.31703186], [93.06478882, 12.31707001], [93.06520844, 12.3173027], [93.06542206, 12.31737137], [93.06591034, 12.31747055], [93.0663681, 12.31775188], [93.06671906, 12.31799126], [93.06698608, 12.31816196], [93.06748962, 12.31850624], [93.06793976, 12.31884956], [93.06825256, 12.31884956], [93.06852722, 12.31906033], [93.06867218, 12.31895065], [93.06934357, 12.31888676], [93.06949615, 12.31871128], [93.06972504, 12.31861115], [93.07053375, 12.31861115], [93.07063293, 12.31842041], [93.07112885, 12.31887054], [93.07141113, 12.31879997], [93.07170105, 12.31908131], [93.07186127, 12.31918144], [93.0723877, 12.31935406], [93.07256317, 12.31904411]]], [[[92.87805939, 12.29364967], [92.87774658, 12.29364109], [92.87732697, 12.29382992], [92.87696075, 12.29424], [92.87670898, 12.29476357], [92.87670898, 12.29535007], [92.87697601, 12.29589939], [92.87742615, 12.29636192], [92.87798309, 12.29676056], [92.87853241, 12.29717636], [92.87915802, 12.29755878], [92.87967682, 12.29787064], [92.88021088, 12.29784966], [92.88066864, 12.29746056], [92.88098907, 12.29689503], [92.880867, 12.29614067], [92.88059998, 12.29541588], [92.88008881, 12.29493999], [92.87956238, 12.29450035], [92.87895203, 12.29417038], [92.87831879, 12.29388046], [92.87805939, 12.29364967]]], [[[92.76590729, 12.29907036], [92.76593018, 12.29852009], [92.765625, 12.29854107], [92.76566315, 12.2980032], [92.76590729, 12.2980032], [92.76593018, 12.29744244], [92.76534271, 12.29688358], [92.7647934, 12.29684544], [92.7647934, 12.29657173], [92.76368713, 12.29656982], [92.76368713, 12.29714394], [92.7634201, 12.29714394], [92.76346588, 12.2977047], [92.76371002, 12.29771996], [92.76368713, 12.29823589], [92.76396942, 12.29852295], [92.7647934, 12.29854107], [92.76508331, 12.29907036], [92.76590729, 12.29907036]]], [[[92.78022766, 12.62918186], [92.78038025, 12.62890911], [92.78054047, 12.62861919], [92.78072357, 12.6283226], [92.78095245, 12.62801743], [92.78128815, 12.62777138], [92.78164673, 12.6275177], [92.78203583, 12.62726116], [92.7824707, 12.62700081], [92.78292084, 12.62676811], [92.78337097, 12.62648964], [92.78382111, 12.6261797], [92.78431702, 12.62589455], [92.78479767, 12.62560368], [92.78521729, 12.62531853], [92.78553772, 12.62504101], [92.78578949, 12.62479019], [92.78586578, 12.62427044], [92.7857132, 12.62396145], [92.7855072, 12.62356186], [92.78530884, 12.62304878], [92.78502655, 12.62253094], [92.7846756, 12.62203693], [92.78440094, 12.62158108], [92.78400421, 12.62102509], [92.78383636, 12.62052059], [92.78378296, 12.61970139], [92.78360748, 12.61899853], [92.78353882, 12.61851978], [92.78383636, 12.61823463], [92.78392029, 12.61832047], [92.78427887, 12.61865044], [92.78473663, 12.61900139], [92.78543091, 12.61924744], [92.78591156, 12.61972427], [92.78620911, 12.62028217], [92.78629303, 12.62090015], [92.78648376, 12.62170601], [92.78662872, 12.62257004], [92.78671265, 12.62325573], [92.78662872, 12.6243906], [92.78653717, 12.62460136], [92.78624725, 12.62572002], [92.786026, 12.62599087], [92.78556824, 12.62617588], [92.7852478, 12.62652493], [92.78464508, 12.62694168], [92.78434753, 12.62714005], [92.78398132, 12.62764072], [92.78318787, 12.62816143], [92.78263855, 12.62845039], [92.78199005, 12.62878132], [92.78159332, 12.62905025], [92.78110504, 12.62941933], [92.78074646, 12.62985039], [92.7804718, 12.63022995], [92.7802887, 12.6307106], [92.78026581, 12.63123798], [92.78031158, 12.63173008], [92.78056335, 12.63222885], [92.78092194, 12.63350964], [92.78105164, 12.63389778], [92.78114319, 12.63416195], [92.78129578, 12.6343689], [92.78145599, 12.63464069], [92.78157806, 12.63493919], [92.78168488, 12.63522243], [92.78182983, 12.63549137], [92.78192139, 12.6358099], [92.78199005, 12.63621998], [92.78217316, 12.63671017], [92.78218842, 12.63724995], [92.78208923, 12.63778973], [92.7821579, 12.63827991], [92.78206635, 12.63871956], [92.78207397, 12.63916683], [92.78215027, 12.6396637], [92.78198242, 12.64016056], [92.78179932, 12.64074039], [92.78179169, 12.64143944], [92.78183746, 12.64208031], [92.78192139, 12.64265156], [92.78193665, 12.64321041], [92.78193665, 12.64376163], [92.78193665, 12.64428139], [92.7819519, 12.64476204], [92.78148651, 12.64568996], [92.78121948, 12.64612103], [92.78113556, 12.64645576], [92.78081512, 12.64753056], [92.78063202, 12.64816856], [92.7804184, 12.6490202], [92.78038025, 12.64966011], [92.78038025, 12.65067196], [92.78047943, 12.65125084], [92.78045654, 12.65195274], [92.78038025, 12.65275955], [92.78040314, 12.65346241], [92.7804718, 12.6539402], [92.78063202, 12.65428734], [92.78096771, 12.65439224], [92.78119659, 12.65439224], [92.78199768, 12.65434361], [92.78219604, 12.65391541], [92.78246307, 12.65329075], [92.78273773, 12.65296936], [92.78291321, 12.65316105], [92.7829361, 12.65375996], [92.78287506, 12.65441895], [92.78305817, 12.65482235], [92.7832489, 12.65502453], [92.78346252, 12.65533066], [92.78363037, 12.65579128], [92.78379059, 12.65630817], [92.78391266, 12.65692139], [92.78401947, 12.65756035], [92.78414154, 12.65806961], [92.78421021, 12.6585989], [92.78439331, 12.65908718], [92.78443909, 12.65956306], [92.78440094, 12.65997982], [92.78420258, 12.66034889], [92.78407288, 12.66076565], [92.78388214, 12.66118145], [92.78367615, 12.66163731], [92.78362274, 12.66219139], [92.78360748, 12.66276073], [92.783638, 12.66330814], [92.78373718, 12.66381264], [92.78374481, 12.66438293], [92.7838974, 12.66495991], [92.78411865, 12.66555691], [92.78429413, 12.66615391], [92.7845459, 12.66662121], [92.78481293, 12.66702938], [92.78499603, 12.66750145], [92.78520203, 12.66795921], [92.78553772, 12.6682806], [92.78586578, 12.66860199], [92.78614807, 12.66894245], [92.78634644, 12.66941071], [92.78653717, 12.66990089], [92.78677368, 12.67033195], [92.78701782, 12.67072201], [92.78721619, 12.67115021], [92.78743744, 12.67165089], [92.78761292, 12.67220783], [92.78785706, 12.67269993], [92.78813934, 12.673172], [92.78842926, 12.67359638], [92.78858948, 12.67403984], [92.78864288, 12.67448044], [92.78859711, 12.67488956], [92.78848267, 12.67525005], [92.78833008, 12.6755867], [92.78814697, 12.67589283], [92.78801727, 12.6762352], [92.78782654, 12.67656136], [92.78771973, 12.67697144], [92.78754425, 12.6773653], [92.78746033, 12.67783928], [92.78729248, 12.6782999], [92.7871933, 12.6788311], [92.7869873, 12.6793499], [92.78691101, 12.67988777], [92.78681183, 12.68042183], [92.78691101, 12.68095684], [92.78694153, 12.68146133], [92.78690338, 12.68195057], [92.78671265, 12.68240166], [92.78666687, 12.68288136], [92.78666687, 12.68336201], [92.78666687, 12.68386078], [92.78662109, 12.68432999], [92.78643799, 12.68477726], [92.78639221, 12.6852417], [92.78643799, 12.68569088], [92.78662109, 12.68612194], [92.78666687, 12.68658733], [92.78666687, 12.68709946], [92.78666687, 12.687644], [92.78666687, 12.68818188], [92.78666687, 12.68867016], [92.78666687, 12.68908024], [92.78666687, 12.68942165], [92.78666687, 12.68972301], [92.78665924, 12.69001198], [92.78665924, 12.69031525], [92.78666687, 12.69064999], [92.78671265, 12.69103146], [92.78672791, 12.69136143], [92.78672791, 12.69164181], [92.78679657, 12.69186687], [92.78691101, 12.69210434], [92.78694153, 12.69241047], [92.78694153, 12.69279957], [92.78694153, 12.6932373], [92.78694153, 12.69370174], [92.78694153, 12.69417381], [92.78694916, 12.69464111], [92.78694153, 12.69511986], [92.78690338, 12.69560146], [92.78672791, 12.6960907], [92.7866745, 12.69659901], [92.78668213, 12.69717121], [92.78675842, 12.69780922], [92.78681946, 12.69849491], [92.78684235, 12.69919014], [92.78684235, 12.69985104], [92.78692627, 12.70040035], [92.78700256, 12.70086956], [92.7872467, 12.70119095], [92.78734589, 12.70162201], [92.78747559, 12.70211887], [92.7875061, 12.70259953], [92.78749847, 12.70303726], [92.78746033, 12.7033844], [92.78733063, 12.70359135], [92.7871933, 12.70374203], [92.78716278, 12.70411968], [92.78721619, 12.70484924], [92.78726196, 12.7055397], [92.787323, 12.70614815], [92.78740692, 12.70667934], [92.78739166, 12.70720959], [92.78721619, 12.70768929], [92.7869873, 12.70815182], [92.78671265, 12.70857143], [92.78636169, 12.70892906], [92.78598022, 12.70926189], [92.78556061, 12.70954037], [92.78513336, 12.7097559], [92.78370667, 12.71020126], [92.7827301, 12.71041012], [92.78147125, 12.71123791], [92.77993774, 12.71275139], [92.77915955, 12.71310043], [92.77886963, 12.7129612], [92.77894592, 12.71241093], [92.77937317, 12.71151066], [92.78035736, 12.71068573], [92.78189087, 12.70979023], [92.78298187, 12.7091589], [92.78343964, 12.70889854], [92.78391266, 12.70864201], [92.78440094, 12.70839119], [92.78486633, 12.70809937], [92.78524017, 12.70772076], [92.78552246, 12.70731068], [92.78572845, 12.70689106], [92.78585052, 12.70646095], [92.78594208, 12.70604992], [92.78605652, 12.70568085], [92.78617859, 12.705266], [92.78610229, 12.70328999], [92.78594208, 12.70294571], [92.7858429, 12.70261097], [92.7857666, 12.70217133], [92.78555298, 12.7017498], [92.78531647, 12.70129204], [92.78523254, 12.70076275], [92.78505707, 12.70029068], [92.78500366, 12.69977093], [92.78499603, 12.69920158], [92.78499603, 12.6985817], [92.78495789, 12.6979208], [92.78476715, 12.69727135], [92.78456879, 12.69660091], [92.78449249, 12.69590092], [92.78457642, 12.69520187], [92.7844696, 12.69451141], [92.78436279, 12.69384098], [92.78418732, 12.69323921], [92.78405762, 12.69268799], [92.78386688, 12.69224072], [92.78362274, 12.69185066], [92.78333282, 12.69146633], [92.78302765, 12.69105053], [92.78263855, 12.69068909], [92.78225708, 12.69031143], [92.78186798, 12.68992996], [92.78148651, 12.68954945], [92.78118134, 12.68918324], [92.78087616, 12.6888628], [92.78063202, 12.68856335], [92.78046417, 12.6882534], [92.78025055, 12.68798065], [92.77996826, 12.68772221], [92.77967072, 12.68734646], [92.77923584, 12.68695068], [92.77876282, 12.6864996], [92.7783432, 12.68593025], [92.77796936, 12.68536472], [92.77758789, 12.68490696], [92.77733612, 12.68443966], [92.7771759, 12.68402004], [92.7769928, 12.68369198], [92.77684021, 12.68337059], [92.77670288, 12.68307018], [92.77658844, 12.68273258], [92.77641296, 12.68240738], [92.77628326, 12.6819706], [92.77612305, 12.68149471], [92.77596283, 12.68098354], [92.77580261, 12.68049431], [92.77555847, 12.6800909], [92.77529907, 12.67972183], [92.77500153, 12.67937088], [92.77466583, 12.67903996], [92.77424622, 12.678792], [92.77392578, 12.67847061], [92.77364349, 12.67810822], [92.7733078, 12.67780113], [92.77294159, 12.6774931], [92.77257538, 12.67714596], [92.7722702, 12.6767292], [92.77193451, 12.6763649], [92.77165985, 12.67597294], [92.77138519, 12.6755743], [92.77111053, 12.67514515], [92.77083588, 12.67467117], [92.77056122, 12.67414856], [92.77028656, 12.67362118], [92.76995087, 12.67315578], [92.76957703, 12.67279053], [92.76921082, 12.67245102], [92.76888275, 12.67212105], [92.76850128, 12.6718502], [92.76805878, 12.67164707], [92.76763916, 12.67140102], [92.76719666, 12.67122078], [92.76674652, 12.67111969], [92.76634216, 12.67108154], [92.76592255, 12.67097664], [92.76534271, 12.67095184], [92.76470184, 12.6710701], [92.76444244, 12.67106819], [92.76405334, 12.67106342], [92.76344299, 12.67089462], [92.76281738, 12.67085075], [92.7621994, 12.67089939], [92.76165009, 12.6710701], [92.76111603, 12.67111111], [92.76062775, 12.67111969], [92.76013947, 12.67119122], [92.75966644, 12.67138004], [92.75911713, 12.67155075], [92.75853729, 12.67166996], [92.7579422, 12.67179012], [92.75741577, 12.67195892], [92.7569809, 12.67217064], [92.75657654, 12.67232609], [92.75624084, 12.67248058], [92.75589752, 12.67261124], [92.75563049, 12.67281246], [92.75540161, 12.67306042], [92.75515747, 12.6733427], [92.75489044, 12.67360687], [92.75457764, 12.67385483], [92.75419617, 12.67403984], [92.75386047, 12.67427731], [92.753479, 12.67447472], [92.75305176, 12.67467594], [92.75250244, 12.67472076], [92.75233459, 12.67471504], [92.75192261, 12.67469597], [92.75138092, 12.67457104], [92.75086212, 12.67442131], [92.75042725, 12.67416096], [92.75004578, 12.6738596], [92.74965668, 12.67355919], [92.74926758, 12.6733017], [92.74891663, 12.67301178], [92.7485733, 12.67269993], [92.7481308, 12.67247391], [92.74762726, 12.67226696], [92.74703217, 12.67222118], [92.74643707, 12.67217636], [92.74595642, 12.6719408], [92.74550629, 12.67165089], [92.74504089, 12.67138195], [92.74452209, 12.67116642], [92.74397278, 12.6711607], [92.7434845, 12.67138863], [92.74304962, 12.67167187], [92.74263763, 12.67195034], [92.74223328, 12.67222977], [92.74182892, 12.67246056], [92.74137115, 12.67250156], [92.74092865, 12.67241001], [92.74053192, 12.67222118], [92.74013519, 12.67214584], [92.73969269, 12.67233086], [92.73918152, 12.67251968], [92.73868561, 12.67272854], [92.73818207, 12.67273235], [92.73773956, 12.67251301], [92.73730469, 12.67229366], [92.73690033, 12.67209053], [92.73651123, 12.67205048], [92.73607635, 12.67243099], [92.73561096, 12.67276096], [92.7352829, 12.67309189], [92.73497009, 12.67336082], [92.7346344, 12.67356777], [92.73418427, 12.67365932], [92.73374176, 12.67385292], [92.73332977, 12.6739397], [92.73305511, 12.6741581], [92.73288727, 12.67441082], [92.73301697, 12.67473698], [92.73313141, 12.67519093], [92.7333374, 12.67566013], [92.7335968, 12.67609978], [92.73390961, 12.67645836], [92.73420715, 12.67674065], [92.73443604, 12.6770916], [92.73461914, 12.67742729], [92.73472595, 12.67783928], [92.7348175, 12.67832947], [92.73491669, 12.67889023], [92.73505402, 12.6794796], [92.73529816, 12.6799612], [92.73557281, 12.68031025], [92.73578644, 12.68063068], [92.73593903, 12.68096161], [92.73612213, 12.68126011], [92.73625183, 12.68161964], [92.73628235, 12.68204212], [92.73622894, 12.6824913], [92.73613739, 12.68293095], [92.73609161, 12.68336201], [92.7359848, 12.68372154], [92.73586273, 12.68403244], [92.73583221, 12.68435097], [92.73578644, 12.68467045], [92.73561859, 12.68498039], [92.73551941, 12.68539047], [92.7352829, 12.68584061], [92.73501587, 12.6863699], [92.73472595, 12.68693066], [92.73443604, 12.68750095], [92.73416901, 12.68805885], [92.73387909, 12.68859482], [92.73353577, 12.68908215], [92.73310852, 12.6894989], [92.73269653, 12.68992996], [92.7322464, 12.69027042], [92.73082733, 12.69139099], [92.73027802, 12.69139099], [92.73000336, 12.69167137], [92.72972107, 12.69167137], [92.72888947, 12.69083023], [92.72861481, 12.69083309], [92.72808838, 12.69127274], [92.72782135, 12.69165993], [92.72782135, 12.69201088], [92.7279892, 12.69237137], [92.72805023, 12.69276142], [92.72811127, 12.69313908], [92.72826385, 12.69347191], [92.72836304, 12.69388199], [92.72850037, 12.69434929], [92.72865295, 12.69487095], [92.72888184, 12.69538021], [92.72908783, 12.69588089], [92.72919464, 12.69644833], [92.72930908, 12.69699955], [92.7294693, 12.69744873], [92.72973633, 12.69779968], [92.73005676, 12.69808006], [92.73053741, 12.69817066], [92.73107147, 12.69812965], [92.73153687, 12.69830132], [92.73200989, 12.69845009], [92.7325058, 12.6985836], [92.73297882, 12.69861126], [92.73337555, 12.69861126], [92.73369598, 12.69860935], [92.7339859, 12.69861126], [92.73432922, 12.69863033], [92.73474121, 12.69874096], [92.73833466, 12.69916725], [92.73860931, 12.69944477], [92.73916626, 12.69944096], [92.73944092, 12.69972992], [92.73972321, 12.69972992], [92.73999023, 12.70000172], [92.7408371, 12.70000172], [92.74111176, 12.70028019], [92.74223328, 12.69917202], [92.74250031, 12.69916725], [92.74277496, 12.69944477], [92.74304962, 12.69944096], [92.74305725, 12.69972134], [92.74194336, 12.70083141], [92.74194336, 12.70111179], [92.74137878, 12.701581], [92.74095154, 12.70205975], [92.74069214, 12.70265865], [92.7405014, 12.70334339], [92.74044037, 12.7039814], [92.74061584, 12.70437145], [92.74076843, 12.70471001], [92.74082947, 12.70508003], [92.7408371, 12.70548534], [92.74079895, 12.70591068], [92.74066162, 12.70633125], [92.74057007, 12.70672035], [92.7405014, 12.70705128], [92.74048615, 12.7073307], [92.74042511, 12.707757], [92.74030304, 12.70795059], [92.74012756, 12.70814037], [92.74002838, 12.70842075], [92.73999023, 12.70880127], [92.7399292, 12.70919991], [92.73976135, 12.70954895], [92.73972321, 12.70993423], [92.73972321, 12.71031189], [92.73968506, 12.71068382], [92.7395401, 12.71103859], [92.73943329, 12.71143055], [92.73932648, 12.71182632], [92.73950195, 12.71224976], [92.73963928, 12.71265793], [92.73966217, 12.71302509], [92.73957825, 12.71337128], [92.73951721, 12.71373081], [92.73964691, 12.71412086], [92.73977661, 12.71458435], [92.73972321, 12.71471119], [92.73999023, 12.71500111], [92.73999786, 12.71555424], [92.74028015, 12.71582985], [92.74028015, 12.71666718], [92.74055481, 12.71694469], [92.74028015, 12.71722031], [92.74028015, 12.71805477], [92.74055481, 12.71833324], [92.74054718, 12.71944046], [92.7408371, 12.71972084], [92.7408371, 12.72028065], [92.74111176, 12.72056198], [92.74111176, 12.72084045], [92.7416687, 12.72139072], [92.74388885, 12.72138882], [92.74412537, 12.72162628], [92.7444458, 12.72194481], [92.74583435, 12.72194481], [92.74610901, 12.72222328], [92.74611664, 12.72249889], [92.74582672, 12.72277927], [92.74555206, 12.72277927], [92.74504089, 12.72263622], [92.74481201, 12.72277927], [92.74472046, 12.72361088], [92.7444458, 12.7239027], [92.74416351, 12.72388935], [92.7436142, 12.72444534], [92.74305725, 12.72444534], [92.74263, 12.72437], [92.74223328, 12.72422886], [92.74147797, 12.72447968], [92.74124146, 12.72528553], [92.7409668, 12.72614288], [92.74089813, 12.72722054], [92.7408371, 12.72787094], [92.74057007, 12.72837925], [92.74030304, 12.7288599], [92.73996735, 12.72918129], [92.73977661, 12.72957993], [92.73995972, 12.73022747], [92.7400589, 12.73069477], [92.74021149, 12.73110008], [92.74015808, 12.7314806], [92.73999786, 12.73166561], [92.73972321, 12.73194122], [92.73972321, 12.73250008], [92.73944092, 12.73357105], [92.73954773, 12.73393059], [92.73954773, 12.73440075], [92.73944092, 12.73499966], [92.7388916, 12.73499966], [92.73873138, 12.73464203], [92.73861694, 12.73419094], [92.73867035, 12.73359108], [92.73867798, 12.73318958], [92.73869324, 12.73269844], [92.73858643, 12.73246956], [92.7383728, 12.73249054], [92.73797607, 12.73316956], [92.73806, 12.73359108], [92.73816681, 12.73397923], [92.73825836, 12.73438931], [92.73828888, 12.73486996], [92.73832703, 12.73556137], [92.73832703, 12.7358408], [92.73860931, 12.73610973], [92.73860931, 12.7369442], [92.7388916, 12.73722172], [92.7388916, 12.73750019], [92.73860931, 12.73778057], [92.73860931, 12.73805618], [92.73805237, 12.73861027], [92.73777771, 12.73861027], [92.73750305, 12.7383337], [92.73694611, 12.7383337], [92.73638916, 12.73816967], [92.73571014, 12.73838043], [92.7351532, 12.73876095], [92.73477173, 12.73912811], [92.73452759, 12.73944187], [92.73429108, 12.73973083], [92.73401642, 12.74003887], [92.7337265, 12.7404108], [92.73339844, 12.74079132], [92.73307037, 12.74117565], [92.73274994, 12.74157143], [92.73240662, 12.74191856], [92.73207092, 12.74221992], [92.73175049, 12.74250984], [92.73145294, 12.7428112], [92.73120117, 12.74317074], [92.73106384, 12.74363136], [92.73086548, 12.74405956], [92.73073578, 12.74451065], [92.73059082, 12.74493694], [92.73055267, 12.74540043], [92.73049164, 12.7458601], [92.73031616, 12.74629116], [92.73021698, 12.74678135], [92.7300415, 12.74722958], [92.73002625, 12.74767017], [92.73013306, 12.74804974], [92.73023224, 12.7483902], [92.73027039, 12.74874115], [92.73027802, 12.74912167], [92.7303009, 12.74953938], [92.7303772, 12.74999046], [92.73048401, 12.75047779], [92.73055267, 12.75094891], [92.73060608, 12.75142956], [92.73069, 12.75189114], [92.73085785, 12.75226021], [92.73103333, 12.75260162], [92.73112488, 12.75295734], [92.73121643, 12.75330067], [92.73129272, 12.75365925], [92.73110199, 12.75399685], [92.73085022, 12.75434113], [92.73062897, 12.75473022], [92.7304306, 12.7551384], [92.73026276, 12.75561047], [92.7300415, 12.75607967], [92.72992706, 12.75654697], [92.72972107, 12.75694084], [92.72947693, 12.75730133], [92.72930908, 12.75764084], [92.72915649, 12.7579689], [92.72901154, 12.75821972], [92.72888184, 12.75848198], [92.72875214, 12.75875092], [92.72860718, 12.7590704], [92.72846985, 12.75946045], [92.72832489, 12.75989723], [92.72814178, 12.76038265], [92.72802734, 12.76097775], [92.7278595, 12.76159954], [92.7277298, 12.76231766], [92.72753906, 12.76299477], [92.72741699, 12.76366043], [92.727211, 12.76424122], [92.72693634, 12.76476097], [92.72666168, 12.76529026], [92.72639465, 12.76585484], [92.72619629, 12.76646996], [92.72612, 12.76712036], [92.72611237, 12.76773071], [92.72609711, 12.76825047], [92.72600555, 12.76869488], [92.72587585, 12.76910019], [92.72582245, 12.76952171], [92.72575378, 12.76990032], [92.7256012, 12.77022171], [92.72554016, 12.77054119], [92.72543335, 12.77082062], [92.72528076, 12.77108955], [92.72512817, 12.77143002], [92.72499084, 12.7718811], [92.724823, 12.77242088], [92.7246933, 12.77305031], [92.7244873, 12.77365017], [92.72441101, 12.77423954], [92.72428894, 12.77471638], [92.72418976, 12.7751236], [92.72416687, 12.7755003], [92.72415161, 12.77585983], [92.72406006, 12.77620697], [92.72392273, 12.77655983], [92.72386932, 12.77696133], [92.72377777, 12.77731037], [92.72363281, 12.77758121], [92.72354889, 12.77780437], [92.7234726, 12.77804089], [92.72354889, 12.77845192], [92.72342682, 12.77880955], [92.72315979, 12.77916145], [92.72323608, 12.77975082], [92.72310638, 12.78026772], [92.72306061, 12.78079033], [92.72305298, 12.78126907], [92.72299194, 12.78166294], [92.72274017, 12.78197956], [92.72257233, 12.78238106], [92.72252655, 12.78291035], [92.72262573, 12.78348637], [92.72249603, 12.78393078], [92.72232819, 12.78434753], [92.72218323, 12.78474045], [92.72198486, 12.78505898], [92.7219162, 12.78540993], [92.7217865, 12.78571129], [92.72168732, 12.78600025], [92.72162628, 12.7863102], [92.72149658, 12.78656101], [92.72141266, 12.78682995], [92.72138977, 12.78713989], [92.72134399, 12.78744984], [92.72117615, 12.78774071], [92.72112274, 12.7881403], [92.72110748, 12.78862095], [92.72110748, 12.78919125], [92.72112274, 12.78981972], [92.72119904, 12.79045582], [92.72136688, 12.79099178], [92.72154999, 12.79145908], [92.72180939, 12.79174137], [92.72196198, 12.79208088], [92.72212219, 12.79241085], [92.72229767, 12.79275131], [92.72253418, 12.79309082], [92.72278595, 12.79345989], [92.72305298, 12.79384041], [92.7232666, 12.79421043], [92.72344208, 12.79492092], [92.72364807, 12.7953558], [92.72377777, 12.79560375], [92.72386169, 12.79585075], [92.72383118, 12.79610062], [92.72381592, 12.79628563], [92.72364807, 12.79647064], [92.7233963, 12.79638863], [92.72322845, 12.79623985], [92.72289276, 12.79607868], [92.72255707, 12.79592991], [92.72219849, 12.79587078], [92.72167969, 12.79597569], [92.72148895, 12.79620171], [92.72123718, 12.79662132], [92.72106934, 12.79702854], [92.72096252, 12.79744053], [92.72079468, 12.79942703], [92.72093201, 12.79994202], [92.7210083, 12.80059814], [92.72107697, 12.80134964], [92.72110748, 12.80211067], [92.72106171, 12.80286598], [92.72087097, 12.80358791], [92.72038269, 12.80549812], [92.72049713, 12.80599117], [92.72075653, 12.80644894], [92.72075653, 12.80723], [92.72081757, 12.80802059], [92.72086334, 12.80836964], [92.72098541, 12.80872059], [92.72104645, 12.80908966], [92.72117615, 12.80947113], [92.72128296, 12.80978107], [92.72155762, 12.8100996], [92.72194672, 12.81100178], [92.72197723, 12.81169987], [92.72203064, 12.81227016], [92.72202301, 12.81265736], [92.72211456, 12.8129921], [92.72215271, 12.8132906], [92.72207642, 12.81360054], [92.7219696, 12.81391144], [92.72190094, 12.81431389], [92.72171021, 12.81474209], [92.7216568, 12.81527138], [92.72166443, 12.81579971], [92.72170258, 12.81626034], [92.72186279, 12.81660175], [92.72193909, 12.81692791], [92.72200012, 12.81723976], [92.7221756, 12.8174963], [92.72225189, 12.81780815], [92.72238159, 12.8180809], [92.7224884, 12.81838036], [92.72255707, 12.81872559], [92.72271729, 12.81904984], [92.72277069, 12.81948471], [92.72280884, 12.81997108], [92.72302246, 12.82038784], [92.72315979, 12.82082272], [92.72329712, 12.82121277], [92.72333527, 12.82156181], [92.72332001, 12.82188129], [92.72323608, 12.82219982], [92.72309113, 12.82250977], [92.72306061, 12.82290173], [92.72309113, 12.82332134], [92.72325897, 12.82373142], [92.72335815, 12.82418728], [92.72350311, 12.82463169], [92.72358704, 12.8251009], [92.72364044, 12.82557106], [92.72377014, 12.82598972], [92.72386932, 12.82637119], [92.72389221, 12.82674408], [92.7239151, 12.82708359], [92.72402191, 12.82738018], [92.72416687, 12.82767868], [92.72438049, 12.82797146], [92.72477722, 12.82817078], [92.72524261, 12.8283596], [92.72570801, 12.82856083], [92.72618866, 12.82865906], [92.72657013, 12.82884121], [92.72690582, 12.82898045], [92.72717285, 12.82918072], [92.72737885, 12.82944107], [92.72759247, 12.82975101], [92.72779846, 12.83011055], [92.72805023, 12.83049965], [92.72833252, 12.8309269], [92.72860718, 12.83140087], [92.72888947, 12.83191109], [92.72917175, 12.83243084], [92.72943878, 12.83296204], [92.72966766, 12.83350945], [92.72975922, 12.83409214], [92.72989655, 12.8346014], [92.7302475, 12.83489513], [92.73062134, 12.83520889], [92.73108673, 12.83544159], [92.73129272, 12.83537483], [92.73165131, 12.83525944], [92.73206329, 12.83493996], [92.73223877, 12.83457088], [92.73239899, 12.83425045], [92.73249817, 12.8338604], [92.73265076, 12.8333807], [92.73293304, 12.83285046], [92.73303986, 12.83217144], [92.73306274, 12.8314209], [92.73306274, 12.8306303], [92.73310089, 12.82985115], [92.73331451, 12.82914925], [92.73348999, 12.82844925], [92.73364258, 12.8277607], [92.73383331, 12.82711983], [92.73388672, 12.82637119], [92.73394012, 12.82562065], [92.73416138, 12.82495117], [92.73439026, 12.8243103], [92.73451996, 12.82372189], [92.73468781, 12.82322502], [92.73477173, 12.82273102], [92.73497009, 12.82234097], [92.7351532, 12.82196045], [92.73535156, 12.82160854], [92.73563385, 12.82131481], [92.7359314, 12.82100105], [92.73616791, 12.82056999], [92.73640442, 12.82012081], [92.73661041, 12.81964016], [92.73658752, 12.81912136], [92.73638153, 12.81862068], [92.73612213, 12.81813145], [92.73595428, 12.8176136], [92.73606873, 12.81707382], [92.73610687, 12.81648064], [92.73610687, 12.81586075], [92.73618317, 12.81524181], [92.73634338, 12.81466866], [92.73638916, 12.8141613], [92.73638916, 12.81333447], [92.73686218, 12.81237698], [92.73742676, 12.81223106], [92.73815918, 12.81223297], [92.73822021, 12.81156254], [92.7372818, 12.81122589], [92.73722076, 12.81056023], [92.73750305, 12.81027985], [92.73777771, 12.81027985], [92.73860931, 12.81112099], [92.73860931, 12.8116703], [92.73890686, 12.81210136], [92.7388916, 12.81250191], [92.73889923, 12.81276035], [92.73905182, 12.81309891], [92.73916626, 12.81348038], [92.7390213, 12.8137579], [92.73908234, 12.81427288], [92.73893738, 12.81472015], [92.73923492, 12.8155241], [92.73929596, 12.815732], [92.73921204, 12.81607056], [92.73931885, 12.81649017], [92.73920441, 12.81716728], [92.73940277, 12.81751156], [92.7395401, 12.81803131], [92.73934174, 12.81857967], [92.73948669, 12.81906128], [92.73929596, 12.81954002], [92.73919678, 12.81987], [92.73893738, 12.82030106], [92.73889923, 12.82068634], [92.73890686, 12.82096004], [92.73867035, 12.82128143], [92.73851013, 12.8214407], [92.73848724, 12.82185078], [92.73853302, 12.82216072], [92.7383728, 12.82250118], [92.73833466, 12.82293606], [92.73815155, 12.82329082], [92.73792267, 12.8237114], [92.73786926, 12.82423973], [92.73810577, 12.82482147], [92.73826599, 12.82526112], [92.7383194, 12.8257103], [92.73828888, 12.82616138], [92.7381134, 12.82648659], [92.7381134, 12.82719326], [92.73792267, 12.82771969], [92.73797607, 12.82831001], [92.73803711, 12.82890511], [92.73810577, 12.82949066], [92.73831177, 12.83002853], [92.7385025, 12.83052063], [92.7387085, 12.83093071], [92.73892212, 12.83128357], [92.73914337, 12.83160114], [92.73932648, 12.83196068], [92.73947906, 12.83234024], [92.7396698, 12.83269978], [92.73976898, 12.83311653], [92.73993683, 12.83351135], [92.73999023, 12.83398056], [92.74001312, 12.83453178], [92.74008179, 12.8351469], [92.74035645, 12.83579159], [92.74074554, 12.83636189], [92.74108124, 12.83635521], [92.74138641, 12.83600044], [92.74166107, 12.83554173], [92.74188995, 12.83507919], [92.74194336, 12.83461189], [92.74195099, 12.83417034], [92.74201202, 12.83374977], [92.7421875, 12.83334923], [92.74223328, 12.83284092], [92.74226379, 12.83227444], [92.74238586, 12.8316946], [92.74225616, 12.83110046], [92.74224854, 12.83054066], [92.74234009, 12.83002186], [92.74236298, 12.8295126], [92.74246979, 12.82901192], [92.74250031, 12.82845402], [92.74250031, 12.82785702], [92.74250031, 12.82725525], [92.74250031, 12.82666683], [92.7425766, 12.82546997], [92.74269104, 12.82503033], [92.74279785, 12.82492065], [92.74291992, 12.82470036], [92.74346161, 12.82448101], [92.74388885, 12.82555676], [92.74388885, 12.8260994], [92.74419403, 12.82681274], [92.7441864, 12.82730961], [92.74415588, 12.82778072], [92.74416351, 12.82805538], [92.7444458, 12.8283329], [92.74450684, 12.82882118], [92.74449921, 12.8292923], [92.7444458, 12.82977962], [92.7444458, 12.83027935], [92.7444458, 12.83075142], [92.74443054, 12.83117962], [92.74433899, 12.83151913], [92.74407196, 12.83180237], [92.74391937, 12.8322258], [92.74391174, 12.83271313], [92.74391174, 12.83321285], [92.74398804, 12.83370304], [92.74410248, 12.83417225], [92.74406433, 12.83462334], [92.74414062, 12.83510208], [92.74414062, 12.83559418], [92.74414062, 12.83615303], [92.74415588, 12.83679485], [92.74416351, 12.83750439], [92.74420929, 12.83821964], [92.74442291, 12.83887196], [92.74471283, 12.83946037], [92.74498749, 12.84001064], [92.74526978, 12.84055138], [92.74556732, 12.84108925], [92.74598694, 12.84152031], [92.74652863, 12.84178734], [92.74679565, 12.84185028], [92.74707031, 12.84191418], [92.74752808, 12.84188938], [92.7478714, 12.84182072], [92.7481308, 12.84192562], [92.74839783, 12.84208298], [92.74858856, 12.84245205], [92.74890137, 12.84277058], [92.74929047, 12.84305382], [92.74968719, 12.84333038], [92.75007629, 12.8436327], [92.75041199, 12.84394741], [92.7508316, 12.84401131], [92.75112152, 12.84405041], [92.751091, 12.84427071], [92.75100708, 12.84459019], [92.75118256, 12.84485722], [92.75160217, 12.84502983], [92.75202942, 12.84532166], [92.75271606, 12.84535122], [92.75292969, 12.84519768], [92.75345612, 12.84543991], [92.75352478, 12.84565926], [92.75305176, 12.84611225], [92.75305176, 12.84694386], [92.75327301, 12.84760094], [92.75365448, 12.84797668], [92.75434875, 12.84805393], [92.75485229, 12.84774685], [92.75537109, 12.84749985], [92.75585175, 12.8472271], [92.75627136, 12.84700108], [92.75668335, 12.84692192], [92.75704193, 12.84694195], [92.75733948, 12.84696007], [92.75757599, 12.84705067], [92.75779724, 12.8471899], [92.75807953, 12.84730721], [92.75823212, 12.84763527], [92.75845337, 12.84794331], [92.75860596, 12.84826183], [92.75874329, 12.84857178], [92.75894928, 12.84881783], [92.75911713, 12.8491087], [92.75912476, 12.84947586], [92.75896454, 12.84986401], [92.75887299, 12.85031128], [92.7587204, 12.85073662], [92.75862885, 12.85116959], [92.75861359, 12.85163021], [92.75860596, 12.85211086], [92.75860596, 12.85262203], [92.75865173, 12.85311604], [92.75881958, 12.85355186], [92.75898743, 12.85398674], [92.75913239, 12.85441113], [92.75917053, 12.8548851], [92.75915527, 12.85538387], [92.75908661, 12.85588074], [92.75891876, 12.85634995], [92.75891876, 12.85676956], [92.75905609, 12.85714054], [92.75913239, 12.85749722], [92.75919342, 12.85783195], [92.75931549, 12.85811234], [92.75946045, 12.85838127], [92.75965118, 12.85862923], [92.75989532, 12.85887623], [92.76055908, 12.85944462], [92.76083374, 12.85944462], [92.7611084, 12.8591671], [92.76139069, 12.85917187], [92.76194763, 12.85861111], [92.76194763, 12.85694504], [92.76219177, 12.85496235], [92.76275635, 12.85379124], [92.76289368, 12.85317135], [92.76333618, 12.85250092], [92.76333618, 12.85222054], [92.76472473, 12.85083294], [92.76514435, 12.85042], [92.76570129, 12.85000992], [92.7664032, 12.84925079], [92.76667786, 12.84877014], [92.76689148, 12.84822273], [92.76786804, 12.84739113], [92.76843262, 12.84691048], [92.76918793, 12.84669971], [92.76943207, 12.84633064], [92.76965332, 12.8460207], [92.76982117, 12.84573936], [92.76999664, 12.84547043], [92.77021027, 12.84521198], [92.77046967, 12.84492302], [92.77077484, 12.84459496], [92.77110291, 12.8442297], [92.77147675, 12.84386063], [92.7719574, 12.8435421], [92.7724762, 12.84320927], [92.77300262, 12.8428297], [92.77347565, 12.84241104], [92.77388, 12.84193039], [92.77416992, 12.84143066], [92.77436829, 12.84093189], [92.77442932, 12.84043121], [92.77440643, 12.83994675], [92.77432251, 12.83949184], [92.77420044, 12.83906078], [92.77410889, 12.8386116], [92.7739563, 12.83816147], [92.77387238, 12.83764076], [92.77377319, 12.83707142], [92.77360535, 12.83648777], [92.77342224, 12.83586121], [92.77328491, 12.8352356], [92.77313995, 12.83463001], [92.77303314, 12.83403969], [92.77292633, 12.83348083], [92.77301788, 12.83297062], [92.77310944, 12.8324852], [92.77324677, 12.83204079], [92.77334595, 12.83160114], [92.77346039, 12.83119106], [92.77359772, 12.83082199], [92.77372742, 12.83047104], [92.77387238, 12.83018398], [92.7740097, 12.82989597], [92.77414703, 12.82963181], [92.77428436, 12.82935619], [92.77446747, 12.82911015], [92.77469635, 12.82885933], [92.77497864, 12.82859039], [92.77529907, 12.82830143], [92.77568054, 12.82799053], [92.77610779, 12.82772923], [92.77654266, 12.82747078], [92.77698517, 12.82721424], [92.7774353, 12.82698631], [92.77790833, 12.82678986], [92.77838898, 12.82657146], [92.77882385, 12.82631111], [92.77922821, 12.82604027], [92.77958679, 12.82573891], [92.77986145, 12.82541084], [92.78005219, 12.82507133], [92.78018188, 12.82476139], [92.78025818, 12.82445621], [92.78028107, 12.82413006], [92.78029633, 12.82376099], [92.7803421, 12.82337093], [92.78044891, 12.82299137], [92.78051758, 12.82261658], [92.78056335, 12.82224083], [92.78059387, 12.82188511], [92.78068542, 12.82153702], [92.78077698, 12.82119179], [92.78082275, 12.82082081], [92.78083038, 12.82041073], [92.7808609, 12.81997299], [92.78094482, 12.81950378], [92.78109741, 12.81901073], [92.78122711, 12.81851387], [92.78134918, 12.81806278], [92.78138733, 12.81763172], [92.78140259, 12.81724739], [92.78143311, 12.81690979], [92.78147888, 12.81657028], [92.78147125, 12.81617641], [92.78161621, 12.81575203], [92.78166199, 12.81525135], [92.78166962, 12.81472015], [92.78166962, 12.8141613], [92.78166962, 12.81361198], [92.78166962, 12.81305408], [92.78166962, 12.81248569], [92.78166962, 12.81191158], [92.78167725, 12.8113327], [92.78173065, 12.81076145], [92.78188324, 12.81025028], [92.78194427, 12.80971527], [92.78194427, 12.80916786], [92.78166962, 12.80889034], [92.78166962, 12.80833054], [92.78166199, 12.8080759], [92.78177643, 12.80764103], [92.78194427, 12.80749893], [92.78221893, 12.80749893], [92.78305817, 12.8083334], [92.78333282, 12.80833054], [92.78388977, 12.80889034], [92.78444672, 12.80889034], [92.78472137, 12.80916977], [92.78498077, 12.80931091], [92.78521729, 12.80952835], [92.78526306, 12.8096714], [92.78555298, 12.80972099], [92.78610992, 12.81027985], [92.78618622, 12.81083107], [92.78591156, 12.81101131], [92.78528595, 12.81083107], [92.78388977, 12.80944347], [92.78333282, 12.80944347], [92.78333282, 12.80972099], [92.78305817, 12.81000042], [92.78305817, 12.81194401], [92.78333282, 12.81222153], [92.78333282, 12.8133316], [92.78330231, 12.81402016], [92.78320313, 12.81459236], [92.78309631, 12.81515312], [92.78305817, 12.81571102], [92.78305817, 12.81639004], [92.78305817, 12.81666565], [92.78277588, 12.81692791], [92.78277588, 12.81750011], [92.78250122, 12.81777763], [92.78250122, 12.81861019], [92.78221893, 12.81888771], [92.78222656, 12.81972027], [92.78193665, 12.81999969], [92.78194427, 12.82055569], [92.78166962, 12.82083035], [92.78166962, 12.82139111], [92.78138733, 12.82166576], [92.78138733, 12.82361126], [92.78193665, 12.82417107], [92.78222656, 12.82389069], [92.78305817, 12.82389069], [92.78363037, 12.82421017], [92.78380585, 12.82448959], [92.78354645, 12.82466793], [92.78312683, 12.82483196], [92.78266144, 12.82497597], [92.78216553, 12.82510281], [92.78173065, 12.82531071], [92.78137207, 12.82557487], [92.78111267, 12.82583332], [92.78083038, 12.82583046], [92.78028107, 12.82639122], [92.78028107, 12.82667065], [92.77944183, 12.8275013], [92.7783432, 12.8275013], [92.77777863, 12.8280592], [92.77749634, 12.82805538], [92.77722168, 12.8283329], [92.77694702, 12.8283329], [92.77666473, 12.82861137], [92.77639008, 12.82861137], [92.77583313, 12.82916737], [92.77555847, 12.82915974], [92.77471924, 12.83000088], [92.77471924, 12.83027935], [92.77443695, 12.83055973], [92.77443695, 12.83111095], [92.77416992, 12.83139133], [92.77416992, 12.83250141], [92.77388763, 12.83278179], [92.77388763, 12.83529091], [92.77416992, 12.83555508], [92.77416992, 12.83583069], [92.77443695, 12.83611202], [92.77444458, 12.83666801], [92.77471924, 12.83694267], [92.77471924, 12.83721924], [92.77500153, 12.83749962], [92.77500153, 12.8386116], [92.77527618, 12.83889008], [92.77527618, 12.83972168], [92.77555847, 12.84000015], [92.77555847, 12.84138966], [92.77527618, 12.84166622], [92.77527618, 12.84222031], [92.77500153, 12.84249973], [92.77500153, 12.84277821], [92.77443695, 12.84333038], [92.77416992, 12.84361172], [92.77388763, 12.84361172], [92.77361298, 12.84389019], [92.77333069, 12.84389019], [92.77305603, 12.84417057], [92.77249908, 12.84417057], [92.77194214, 12.84472179], [92.77166748, 12.84472179], [92.77111053, 12.84528065], [92.77111053, 12.84555626], [92.77054596, 12.84611034], [92.77054596, 12.84638977], [92.77027893, 12.84666634], [92.77028656, 12.84694195], [92.77004242, 12.84752083], [92.76978302, 12.84799004], [92.76950836, 12.8484602], [92.76938629, 12.84899139], [92.76915741, 12.84950638], [92.76889801, 12.85000324], [92.76869202, 12.85050201], [92.76876831, 12.85112], [92.76883698, 12.85173035], [92.76879883, 12.85230923], [92.76899719, 12.85281086], [92.76916504, 12.85328484], [92.76931, 12.85375023], [92.76943207, 12.85424709], [92.76951599, 12.8547802], [92.76957703, 12.85534096], [92.76969147, 12.85589886], [92.76976013, 12.85645103], [92.76996613, 12.85692024], [92.77023315, 12.85731888], [92.77036285, 12.85776138], [92.77036285, 12.85821724], [92.77028656, 12.8586607], [92.77018738, 12.8591013], [92.76999664, 12.85946083], [92.76981354, 12.85980511], [92.76972961, 12.86019325], [92.76965332, 12.86058044], [92.76948547, 12.86091995], [92.7694397, 12.86129093], [92.76946259, 12.86167431], [92.76958466, 12.86209106], [92.76979065, 12.86257172], [92.77025604, 12.86294842], [92.77081299, 12.86330414], [92.77105713, 12.86336994], [92.77142334, 12.86347008], [92.77194214, 12.86318111], [92.77242279, 12.86284447], [92.7729187, 12.86255169], [92.77345276, 12.86236668], [92.77392578, 12.86216927], [92.77427673, 12.86198044], [92.77458191, 12.86192131], [92.77482605, 12.8618412], [92.77506256, 12.86177921], [92.77539063, 12.86190891], [92.77574921, 12.86203003], [92.77610016, 12.86224174], [92.77641296, 12.86254025], [92.77667236, 12.86294174], [92.77694702, 12.86340046], [92.77729797, 12.86382771], [92.77791595, 12.86409855], [92.77861023, 12.86417007], [92.78028107, 12.86249924], [92.78028107, 12.8622303], [92.78083038, 12.86166954], [92.78083038, 12.86083126], [92.78111267, 12.8605547], [92.78111267, 12.85833073], [92.78119659, 12.8580761], [92.78111267, 12.85778236], [92.78111267, 12.85639095], [92.78083038, 12.85611057], [92.78083038, 12.85333347], [92.78074646, 12.85309792], [92.78083038, 12.8527813], [92.78083038, 12.85111141], [92.78105164, 12.85058403], [92.78098297, 12.84925079], [92.78083038, 12.84889126], [92.78083038, 12.84832954], [92.78111267, 12.84805679], [92.78144836, 12.84812927], [92.78150177, 12.84841728], [92.78153992, 12.84867191], [92.78159332, 12.85058022], [92.78138733, 12.85139084], [92.78138733, 12.85361099], [92.78166962, 12.85388947], [92.78166962, 12.85472107], [92.78194427, 12.85499859], [92.78193665, 12.85611057], [92.78222656, 12.85639095], [92.78222656, 12.85806179], [92.78212738, 12.85865021], [92.78222656, 12.85911274], [92.78235626, 12.85962963], [92.78259277, 12.86012745], [92.78294373, 12.86049366], [92.78330994, 12.86081123], [92.78370667, 12.86110878], [92.7841568, 12.86139202], [92.78466797, 12.86166954], [92.78527069, 12.86190033], [92.7859726, 12.86194992], [92.78666687, 12.86194134], [92.78722382, 12.86194324], [92.78749847, 12.86166763], [92.78778076, 12.86166954], [92.78806305, 12.86139202], [92.78916931, 12.86139202], [92.78943634, 12.86166954], [92.78971863, 12.86166763], [92.79033661, 12.86196423], [92.79080963, 12.86217117], [92.79132843, 12.8622303], [92.79183197, 12.86226654], [92.79225922, 12.86248112], [92.79260254, 12.86271095], [92.79286957, 12.86283016], [92.79316711, 12.86297131], [92.79323578, 12.86322021], [92.79322052, 12.86355019], [92.79308319, 12.86390114], [92.7929306, 12.86427021], [92.7926712, 12.86467648], [92.79264069, 12.86530972], [92.79278564, 12.86598015], [92.79294586, 12.86662006], [92.79281616, 12.86713982], [92.79270172, 12.86766243], [92.79254913, 12.86815166], [92.79257202, 12.8686552], [92.79277039, 12.86914253], [92.7930069, 12.86964035], [92.79335785, 12.87003899], [92.79358673, 12.8704834], [92.79371643, 12.87094116], [92.79386139, 12.87136459], [92.79389191, 12.87185097], [92.79384613, 12.87244129], [92.79361725, 12.87302017], [92.79338837, 12.87359047], [92.79329681, 12.87415028], [92.79309845, 12.87454891], [92.7930603, 12.87492085], [92.79305267, 12.87525272], [92.79304504, 12.87558174], [92.79305267, 12.87593937], [92.79310608, 12.8763504], [92.7933197, 12.87666035], [92.79355621, 12.87697029], [92.7935791, 12.87732983], [92.79341888, 12.8776989], [92.79325867, 12.87811756], [92.7930603, 12.87852192], [92.7928772, 12.87896156], [92.79279327, 12.87943077], [92.7928009, 12.87992096], [92.79290771, 12.8803997], [92.79308319, 12.88087559], [92.79335785, 12.88134956], [92.7937088, 12.88183975], [92.79394531, 12.88237762], [92.79337311, 12.88282013], [92.79315186, 12.88293171], [92.79298401, 12.88323021], [92.79276276, 12.88351059], [92.79249573, 12.88380909], [92.79222107, 12.88415146], [92.7919693, 12.88455009], [92.79176331, 12.88495064], [92.79154968, 12.88524055], [92.79136658, 12.88544846], [92.79131317, 12.8859129], [92.79128265, 12.8865633], [92.79123688, 12.8871212], [92.79125977, 12.88773155], [92.79117584, 12.88824654], [92.79131317, 12.88902187], [92.79168701, 12.88952065], [92.79190826, 12.88985443], [92.79217529, 12.89009094], [92.7924118, 12.8901701], [92.79283142, 12.89032841], [92.79321289, 12.89055061], [92.79358673, 12.89075184], [92.79402924, 12.89083576], [92.794487, 12.89092255], [92.79494476, 12.89107323], [92.79544067, 12.89119053], [92.79597473, 12.89138699], [92.79651642, 12.89160156], [92.79696655, 12.89191246], [92.79742432, 12.89223957], [92.79786682, 12.89258194], [92.79836273, 12.89295101], [92.79886627, 12.89339066], [92.79933167, 12.89395809], [92.79973602, 12.89466286], [92.80007935, 12.89478111], [92.80042267, 12.89492035], [92.80076599, 12.89514828], [92.80111694, 12.89544201], [92.80148315, 12.89576054], [92.80193329, 12.8960104], [92.80236053, 12.89626026], [92.80276489, 12.89655685], [92.80316162, 12.89687347], [92.80365753, 12.89708996], [92.80419922, 12.89720154], [92.80434418, 12.89719009], [92.80474091, 12.8971653], [92.80522156, 12.89698696], [92.80570984, 12.89695072], [92.80621338, 12.89693928], [92.80670929, 12.89695072], [92.80718994, 12.89699173], [92.80763245, 12.89718056], [92.80810547, 12.89721966], [92.80857086, 12.89721966], [92.80901337, 12.8972311], [92.80947876, 12.89728832], [92.80993652, 12.89745045], [92.81043243, 12.89750004], [92.81069946, 12.89747715], [92.81095886, 12.89745235], [92.81145477, 12.89723969], [92.8119812, 12.89705086], [92.81253815, 12.89690971], [92.81305695, 12.89667034], [92.81357574, 12.89645863], [92.81414795, 12.89635086], [92.81468201, 12.89618301], [92.81520844, 12.89611912], [92.8157196, 12.89610958], [92.81620789, 12.89610958], [92.81668091, 12.89610958], [92.81715393, 12.89611244], [92.81761932, 12.89611244], [92.81808472, 12.89611244], [92.81855011, 12.89611244], [92.81902313, 12.89611244], [92.81948853, 12.89610767], [92.81996155, 12.89608002], [92.82042694, 12.8959589], [92.82089233, 12.89582729], [92.8213501, 12.89571953], [92.82182312, 12.89578247], [92.82231903, 12.89581108], [92.82280731, 12.89577007], [92.82331848, 12.89563084], [92.82385254, 12.89552402], [92.82434845, 12.89534187], [92.82470703, 12.89501095], [92.82499695, 12.89460087], [92.82522583, 12.89416313], [92.82532501, 12.89366436], [92.82550812, 12.89325619], [92.82554626, 12.89281178], [92.82554626, 12.89237022], [92.82554626, 12.89194965], [92.82554626, 12.89155197], [92.82557678, 12.89118004], [92.82567596, 12.89085579], [92.82581329, 12.89054203], [92.82585907, 12.89018631], [92.82598877, 12.88984203], [92.82610321, 12.88947964], [92.82618713, 12.88910103], [92.82637024, 12.88875008], [92.82649994, 12.88836098], [92.82668304, 12.88796043], [92.82691193, 12.88753986], [92.82720184, 12.88710022], [92.82749939, 12.88658142], [92.82785797, 12.88604736], [92.82832336, 12.88560104], [92.82891083, 12.88528156], [92.82952118, 12.88503456], [92.83010101, 12.88490105], [92.83059692, 12.88470745], [92.83109283, 12.88467121], [92.8316803, 12.88500118], [92.83214569, 12.8852129], [92.83244324, 12.88510418], [92.83279419, 12.88502026], [92.83322144, 12.88505077], [92.83366394, 12.8852663], [92.83409882, 12.88552094], [92.83442688, 12.88589001], [92.83467102, 12.88629627], [92.83483887, 12.88664246], [92.83502197, 12.88694096], [92.83535767, 12.88717842], [92.83586121, 12.88733292], [92.83630371, 12.88749218], [92.83664703, 12.88763142], [92.83689117, 12.88778019], [92.83709717, 12.88792992], [92.83731842, 12.88807106], [92.83751678, 12.88824463], [92.83769226, 12.88844299], [92.83777618, 12.88873005], [92.837883, 12.88903999], [92.8380661, 12.88938046], [92.83831787, 12.88971233], [92.83863068, 12.89002037], [92.83898163, 12.89032078], [92.83921051, 12.89075184], [92.83943939, 12.89109993], [92.83969879, 12.89129162], [92.84033966, 12.89132977], [92.84122467, 12.89133263], [92.84149933, 12.89129162], [92.84196472, 12.89114761], [92.84224701, 12.89103889], [92.84249878, 12.89055634], [92.84278107, 12.89019108], [92.84282684, 12.88963032], [92.84284973, 12.88896179], [92.84291077, 12.88823128], [92.84300995, 12.88749027], [92.8430481, 12.88673115], [92.84305573, 12.88599491], [92.84299469, 12.88541794], [92.84285736, 12.88465023], [92.84266663, 12.88411236], [92.84246063, 12.88362026], [92.84208679, 12.88317966], [92.84172058, 12.88274956], [92.84144592, 12.88232136], [92.84130096, 12.8818903], [92.84115601, 12.88156414], [92.84107208, 12.88125038], [92.8409729, 12.88096046], [92.84085846, 12.88060856], [92.84075165, 12.8801899], [92.84056091, 12.8797617], [92.84037781, 12.87928963], [92.84026337, 12.87877178], [92.84018707, 12.8782711], [92.84020996, 12.87779522], [92.84028625, 12.87734795], [92.84041595, 12.87693977], [92.84059906, 12.87654114], [92.84088898, 12.87617016], [92.84125519, 12.87585068], [92.84172821, 12.87560654], [92.8423996, 12.87551975], [92.84311676, 12.87549019], [92.84348297, 12.87528992], [92.84387207, 12.87509155], [92.8443222, 12.87502766], [92.8447876, 12.87506199], [92.84519958, 12.87520313], [92.84558105, 12.8752737], [92.84591675, 12.87532043], [92.84619141, 12.87548065], [92.84651947, 12.87555027], [92.84689331, 12.87561131], [92.84728241, 12.8757], [92.84768677, 12.87581444], [92.84810638, 12.87590122], [92.84850311, 12.87607193], [92.84893799, 12.87611008], [92.84941101, 12.87613964], [92.8498764, 12.87627029], [92.85038757, 12.87637901], [92.85089874, 12.87648201], [92.85132599, 12.87667084], [92.85173798, 12.87685108], [92.85215759, 12.87693977], [92.85258484, 12.87701511], [92.85299683, 12.8771019], [92.85341644, 12.87720203], [92.85386658, 12.8772316], [92.85401154, 12.87722492], [92.85427094, 12.87721062], [92.854599, 12.87713814], [92.85660553, 12.87741184], [92.85716248, 12.87749195], [92.85771179, 12.87755108], [92.85822296, 12.87767601], [92.85871124, 12.87782192], [92.85917664, 12.87800026], [92.85968018, 12.8781004], [92.86016846, 12.87822056], [92.86064911, 12.87834167], [92.86113739, 12.87848282], [92.86164093, 12.87863064], [92.86213684, 12.87887001], [92.86268616, 12.87907124], [92.86322784, 12.87924194], [92.86368561, 12.87945843], [92.86405182, 12.87970924], [92.8644104, 12.87993526], [92.86485291, 12.8800602], [92.86547852, 12.8801012], [92.86608887, 12.88019466], [92.86675262, 12.88025188], [92.86740112, 12.88031101], [92.86808014, 12.88042927], [92.8687439, 12.88052654], [92.8693924, 12.88055229], [92.87002563, 12.88056183], [92.87062073, 12.88060856], [92.87114716, 12.88078499], [92.87166595, 12.88083267], [92.87214661, 12.88086891], [92.87260437, 12.88102627], [92.87309265, 12.88110161], [92.87354279, 12.88116074], [92.87393188, 12.88138676], [92.87431335, 12.88165092], [92.87467957, 12.88192654], [92.87496948, 12.88229084], [92.87518311, 12.88270855], [92.87531281, 12.88317108], [92.87549591, 12.88357925], [92.87555695, 12.88416672], [92.87527466, 12.88444519], [92.8752594, 12.8847208], [92.87473297, 12.88528156], [92.87444305, 12.88556194], [92.87388611, 12.88555527], [92.87361145, 12.88583279], [92.87333679, 12.88583279], [92.8730545, 12.88611126], [92.87277985, 12.88611126], [92.8713913, 12.88750172], [92.8713913, 12.88778019], [92.87110901, 12.88805485], [92.87110901, 12.88972092], [92.8713913, 12.88999939], [92.8713913, 12.89083099], [92.87194824, 12.89138985], [92.87218475, 12.89200115], [92.87243652, 12.8924427], [92.87285614, 12.89271164], [92.87329102, 12.89293671], [92.87367249, 12.89322376], [92.87402344, 12.89350033], [92.87439728, 12.89375305], [92.87486267, 12.89390087], [92.87530518, 12.89407158], [92.87574005, 12.89422035], [92.87615204, 12.89443016], [92.87654114, 12.89460087], [92.87696075, 12.89476109], [92.87735748, 12.89496136], [92.87779236, 12.89501953], [92.87817383, 12.89512539], [92.87854004, 12.89525318], [92.87898254, 12.89532089], [92.87914276, 12.89537144], [92.87947083, 12.89547157], [92.88005066, 12.89532089], [92.88069916, 12.89521027], [92.88128662, 12.89500904], [92.8818512, 12.8948307], [92.88237, 12.894701], [92.88279724, 12.89447975], [92.88326263, 12.89435863], [92.88369751, 12.89420033], [92.8841629, 12.89413166], [92.88453674, 12.89396954], [92.88492584, 12.89390087], [92.8853302, 12.89389038], [92.88575745, 12.89389038], [92.88622284, 12.89389038], [92.88667297, 12.89393139], [92.88704681, 12.89409065], [92.8874588, 12.89419079], [92.8878479, 12.89435005], [92.88828278, 12.89447975], [92.88868713, 12.89473057], [92.88911438, 12.89502716], [92.88957214, 12.89537144], [92.8902359, 12.89548111], [92.89089203, 12.89558125], [92.89131165, 12.89545345], [92.89147949, 12.895401], [92.89176941, 12.89538002], [92.89202118, 12.89558792], [92.89234161, 12.8959589], [92.89250946, 12.89620972], [92.89263153, 12.89646053], [92.89278412, 12.89649963], [92.89290619, 12.8967247], [92.89311981, 12.89695263], [92.89330292, 12.89695072], [92.89388275, 12.89704037], [92.89418793, 12.89720154], [92.89446259, 12.89742947], [92.89497375, 12.89778709], [92.89537048, 12.89814472], [92.89567566, 12.89849377], [92.89597321, 12.89883995], [92.89605713, 12.8993597], [92.89627838, 12.89980888], [92.89641571, 12.90031338], [92.89653778, 12.90079975], [92.89670563, 12.90124893], [92.89694977, 12.90160465], [92.89717865, 12.90191936], [92.89733124, 12.9022913], [92.89743042, 12.90271854], [92.89759064, 12.90317059], [92.89780426, 12.90356922], [92.89807892, 12.90388393], [92.89829254, 12.90416241], [92.89833069, 12.90445423], [92.89830017, 12.90473175], [92.89819336, 12.90504169], [92.89808655, 12.90543556], [92.89800262, 12.90592098], [92.89782715, 12.90642738], [92.89778137, 12.90703583], [92.89778137, 12.90760994], [92.89782715, 12.90816021], [92.89797974, 12.90864468], [92.89808655, 12.90912056], [92.89825439, 12.90953159], [92.89829254, 12.90992355], [92.89816284, 12.91030407], [92.89801788, 12.91068459], [92.897789, 12.91103077], [92.89755249, 12.91142082], [92.89729309, 12.91186142], [92.89698029, 12.91232967], [92.89672852, 12.91285038], [92.89669037, 12.91343975], [92.89673615, 12.91397381], [92.89660645, 12.91438198], [92.89640045, 12.91471195], [92.89618683, 12.91500187], [92.89595795, 12.91528416], [92.89569855, 12.91558456], [92.89546204, 12.91594505], [92.89528656, 12.91637993], [92.89520264, 12.91686821], [92.8952179, 12.91738319], [92.89552307, 12.91779137], [92.89582825, 12.9182291], [92.89611053, 12.91870117], [92.89640045, 12.91921997], [92.89672089, 12.91971016], [92.89713287, 12.92001057], [92.89748383, 12.92026901], [92.89774323, 12.9205513], [92.89785004, 12.92094135], [92.89791107, 12.92140102], [92.89807892, 12.92180347], [92.89820862, 12.92219925], [92.89824677, 12.92260933], [92.89819336, 12.92299175], [92.89805603, 12.92331791], [92.89792633, 12.92359161], [92.89779663, 12.92382622], [92.89768219, 12.9240818], [92.89745331, 12.92430019], [92.89710999, 12.9245491], [92.89684296, 12.92505264], [92.89671326, 12.92566109], [92.89681244, 12.92622852], [92.89707184, 12.92665291], [92.89737701, 12.92702198], [92.89778137, 12.92741108], [92.89839935, 12.92744064], [92.89897919, 12.92718124], [92.89945221, 12.92677975], [92.89987183, 12.9263792], [92.9002533, 12.92597961], [92.90055084, 12.92556477], [92.90077209, 12.92510986], [92.90087128, 12.92457199], [92.90106201, 12.92407036], [92.90112305, 12.92354107], [92.90116119, 12.92306519], [92.90130615, 12.92266178], [92.90117645, 12.92226124], [92.90112305, 12.92179966], [92.90109253, 12.92131901], [92.90100098, 12.92087936], [92.90084076, 12.92049026], [92.9006958, 12.92013931], [92.90055847, 12.91979027], [92.90041351, 12.91942978], [92.90026093, 12.91903114], [92.9000473, 12.91862488], [92.89990997, 12.91812611], [92.89969635, 12.91764069], [92.89949036, 12.91716003], [92.89945221, 12.91662025], [92.89916992, 12.91639042], [92.89916992, 12.91611195], [92.89888763, 12.91583061], [92.89916992, 12.915555], [92.89942932, 12.91555977], [92.90000153, 12.91500187], [92.90027618, 12.91528034], [92.90055847, 12.91527653], [92.90077209, 12.91535854], [92.90112305, 12.91559029], [92.90151215, 12.91592026], [92.90202332, 12.91603947], [92.90261078, 12.91605473], [92.90322876, 12.91587734], [92.90384674, 12.9157896], [92.90435791, 12.9155798], [92.90485382, 12.9154253], [92.90537262, 12.91526127], [92.90590668, 12.91499043], [92.90649414, 12.91465473], [92.90699768, 12.91417408], [92.90740204, 12.9136982], [92.9076767, 12.91324043], [92.90784454, 12.91279984], [92.90804291, 12.91246891], [92.90820313, 12.91219139], [92.90830994, 12.91193199], [92.90833282, 12.91164017], [92.90828705, 12.91129971], [92.9080658, 12.91082191], [92.9079895, 12.91044998], [92.90833282, 12.91026115], [92.90875244, 12.91015434], [92.90895844, 12.90993309], [92.90914154, 12.90965176], [92.90927124, 12.90932369], [92.9095459, 12.90913296], [92.90982819, 12.90892506], [92.9101181, 12.90876102], [92.91040802, 12.90863609], [92.91072845, 12.9086113], [92.91107178, 12.9086113], [92.91143799, 12.90865612], [92.91182709, 12.90882111], [92.91226196, 12.90889072], [92.91268921, 12.90897083], [92.91306305, 12.90912056], [92.91345215, 12.90920067], [92.91378021, 12.90932655], [92.91410065, 12.90942478], [92.91446686, 12.90946102], [92.9148407, 12.90956974], [92.91523743, 12.90972996], [92.91565704, 12.90991879], [92.91613007, 12.91002178], [92.9165802, 12.9101696], [92.91705322, 12.91031075], [92.91750336, 12.91058731], [92.91793823, 12.91098976], [92.91845703, 12.91142082], [92.91899109, 12.91187191], [92.91956329, 12.91222954], [92.92005157, 12.91255188], [92.92050171, 12.91279125], [92.92089081, 12.91297054], [92.92137146, 12.91281986], [92.92192078, 12.91222954], [92.92204285, 12.91179943], [92.92193604, 12.91155148], [92.92176056, 12.91133404], [92.92160034, 12.91105556], [92.92137146, 12.91078091], [92.92108154, 12.91051865], [92.92076111, 12.91023064], [92.92037201, 12.90999031], [92.91999054, 12.90968037], [92.91963959, 12.90936756], [92.91929626, 12.90902138], [92.91899109, 12.90863132], [92.91864777, 12.90827847], [92.91829681, 12.90792274], [92.91790009, 12.90762234], [92.91751862, 12.90733242], [92.91716003, 12.90705681], [92.91674805, 12.90688133], [92.91636658, 12.90665054], [92.91597748, 12.90639973], [92.91549683, 12.90621758], [92.91493988, 12.9061079], [92.91435242, 12.90598488], [92.9138031, 12.90572071], [92.91320801, 12.90545654], [92.91262817, 12.90526104], [92.91210175, 12.90501022], [92.91156769, 12.90477085], [92.91100311, 12.90458107], [92.91052246, 12.90426922], [92.91010284, 12.90392017], [92.90990448, 12.90339565], [92.90969086, 12.90289021], [92.90947723, 12.90239143], [92.90944672, 12.90186501], [92.90948486, 12.90137482], [92.90964508, 12.90097809], [92.909729, 12.90056992], [92.90983582, 12.90015984], [92.90999603, 12.89973068], [92.91017151, 12.89925003], [92.91026306, 12.89874458], [92.91027832, 12.89824963], [92.91027832, 12.89777088], [92.91024017, 12.89730167], [92.91007996, 12.89682961], [92.90996552, 12.89632607], [92.90976715, 12.89585018], [92.90959167, 12.89541245], [92.9094162, 12.89495945], [92.9091568, 12.8945713], [92.90888977, 12.89419079], [92.90862274, 12.89379025], [92.9083786, 12.89338207], [92.90812683, 12.89298058], [92.90792084, 12.89253235], [92.9076767, 12.8921032], [92.90746307, 12.89164543], [92.9072113, 12.89125061], [92.90695953, 12.89089108], [92.9067688, 12.89050961], [92.9066391, 12.89008236], [92.90641022, 12.88967133], [92.90625, 12.8892107], [92.90603638, 12.8888073], [92.90583038, 12.88840199], [92.90564728, 12.88801193], [92.90553284, 12.88763142], [92.90538788, 12.88732433], [92.90529633, 12.8870182], [92.90524292, 12.8867197], [92.90511322, 12.88647079], [92.90501404, 12.88619804], [92.90499878, 12.88585091], [92.90500641, 12.88543034], [92.9050827, 12.88495064], [92.90529633, 12.88449287], [92.90557098, 12.88404942], [92.90590668, 12.88366127], [92.90627289, 12.88336468], [92.9066925, 12.88317108], [92.90711212, 12.88307095], [92.90753174, 12.88305473], [92.90792084, 12.88305283], [92.90828705, 12.88304996], [92.90867615, 12.88305855], [92.90904236, 12.88308907], [92.9093399, 12.88322353], [92.90963745, 12.88331223], [92.90995026, 12.88335133], [92.91026306, 12.88345242], [92.9106369, 12.88363171], [92.91104126, 12.8838501], [92.91148376, 12.88400078], [92.91188049, 12.88420963], [92.91226196, 12.88446999], [92.91266632, 12.8847208], [92.9131012, 12.88490105], [92.91353607, 12.88500118], [92.91442871, 12.88500118], [92.91471863, 12.88528156], [92.9152832, 12.88528156], [92.91555786, 12.88556194], [92.91750336, 12.88556194], [92.91833496, 12.88638878], [92.91845703, 12.88686275], [92.91880798, 12.8872118], [92.91925812, 12.8875494], [92.91981506, 12.88772869], [92.92034149, 12.8876543], [92.92079163, 12.88737202], [92.92112732, 12.88703728], [92.92141724, 12.88676071], [92.92175293, 12.8865633], [92.92201996, 12.88632298], [92.92230225, 12.88610172], [92.92256927, 12.88591099], [92.92285156, 12.88583088], [92.92310333, 12.88576031], [92.9233017, 12.8856144], [92.92353821, 12.88556194], [92.92379761, 12.88555527], [92.92408752, 12.88555145], [92.92442322, 12.88556194], [92.92485809, 12.88556194], [92.92539215, 12.88556194], [92.92601776, 12.88551044], [92.92662048, 12.8853302], [92.92708588, 12.88498116], [92.92746735, 12.8845911], [92.92778015, 12.88416862], [92.92804718, 12.88376141], [92.92828369, 12.88333511], [92.92832947, 12.88282013], [92.9283371, 12.88231182], [92.92832947, 12.88183975], [92.9283371, 12.88141155], [92.92842102, 12.88101101], [92.92856598, 12.88056183], [92.9285965, 12.88010788], [92.92852783, 12.87967014], [92.92836761, 12.87927246], [92.9283371, 12.87887001], [92.92832947, 12.87847614], [92.92832947, 12.87807274], [92.9283371, 12.87763977], [92.92832947, 12.87719059], [92.92830658, 12.87676239], [92.92819977, 12.87639523], [92.92806244, 12.87605953], [92.92793274, 12.87569141], [92.92775726, 12.87534046], [92.92751312, 12.8749094], [92.92731476, 12.87434196], [92.92727661, 12.87365627], [92.92742157, 12.87295246], [92.92750549, 12.87229538], [92.92760468, 12.87173176], [92.92776489, 12.87127018], [92.92791748, 12.87084103], [92.92804718, 12.87041855], [92.92817688, 12.87001133], [92.92830658, 12.86963081], [92.92835236, 12.86924076], [92.92845917, 12.86891079], [92.92858124, 12.86865997], [92.92861176, 12.86837006], [92.92861176, 12.86803055], [92.92861938, 12.86763], [92.92870331, 12.86715126], [92.92887878, 12.86658096], [92.92906189, 12.86592007], [92.92920685, 12.86520004], [92.92939758, 12.86450005], [92.92944336, 12.86377144], [92.92939758, 12.86310101], [92.92920685, 12.86249924], [92.9291687, 12.86198425], [92.92916107, 12.86154366], [92.9291687, 12.86116791], [92.9291687, 12.86082745], [92.92917633, 12.86048031], [92.92923737, 12.8601017], [92.92941284, 12.85970974], [92.92952728, 12.85923958], [92.92971802, 12.85876179], [92.93000793, 12.85828114], [92.93036652, 12.85785007], [92.93080902, 12.85753059], [92.93128204, 12.85727978], [92.9318161, 12.85715008], [92.93235016, 12.85694504], [92.93289185, 12.85673141], [92.93347931, 12.85658264], [92.93395996, 12.85631371], [92.93435669, 12.85601807], [92.93461609, 12.85566044], [92.93488312, 12.8553772], [92.93507385, 12.85505581], [92.93531799, 12.85476589], [92.93562317, 12.85451126], [92.93596649, 12.85431004], [92.93630981, 12.85418987], [92.93663788, 12.85421944], [92.9369278, 12.85441113], [92.9372406, 12.85458565], [92.93756866, 12.85474396], [92.93788147, 12.8549366], [92.93823242, 12.85507202], [92.93852234, 12.85526085], [92.9388504, 12.85536957], [92.93953705, 12.85601997], [92.93995667, 12.85623169], [92.94043732, 12.85623169], [92.94100189, 12.85582161], [92.94135284, 12.85505962], [92.94124603, 12.8546114], [92.94108582, 12.8540802], [92.94087219, 12.85357189], [92.94074249, 12.8529911], [92.94046021, 12.85253334], [92.94025421, 12.85193634], [92.94000244, 12.85140038], [92.9397583, 12.85088921], [92.93958282, 12.85040188], [92.93937683, 12.84998035], [92.93916321, 12.84951973], [92.93894958, 12.84899998], [92.93888855, 12.84838009], [92.93888855, 12.84774399], [92.93888855, 12.84708309], [92.93890381, 12.84641838], [92.9389801, 12.8457613], [92.93908691, 12.8451004], [92.93897247, 12.84444618], [92.9391098, 12.84380054], [92.93916321, 12.84317017], [92.93921661, 12.84262085], [92.93939972, 12.84222031], [92.93945312, 12.84183025], [92.93951416, 12.8415184], [92.93965149, 12.84127235], [92.93972015, 12.84098911], [92.93978119, 12.8406992], [92.93972015, 12.84055996], [92.94000244, 12.84027958], [92.94000244, 12.84000015], [92.9402771, 12.83972168], [92.9402771, 12.83944416], [92.94055176, 12.83916569], [92.94055176, 12.83778], [92.94082642, 12.83749962], [92.94082642, 12.83693886], [92.94139099, 12.83638954], [92.94161987, 12.83617973], [92.9419632, 12.83608723], [92.94229126, 12.83609104], [92.94258118, 12.83617115], [92.9427948, 12.83640099], [92.94304657, 12.83666134], [92.94334412, 12.83697128], [92.94365692, 12.83735371], [92.94412231, 12.83767128], [92.94436646, 12.83770657], [92.94478607, 12.83777142], [92.94550323, 12.83773041], [92.94612885, 12.83753586], [92.94674683, 12.83739853], [92.94728851, 12.8372097], [92.94779205, 12.83692074], [92.94814301, 12.83652878], [92.94827271, 12.8360796], [92.94806671, 12.83565331], [92.94776154, 12.83519459], [92.94740295, 12.83475971], [92.9469986, 12.83434963], [92.94667053, 12.83392429], [92.94638824, 12.83349133], [92.94610596, 12.83305073], [92.94583893, 12.83259869], [92.94561005, 12.83210945], [92.94545746, 12.83158112], [92.94529724, 12.83105183], [92.94527435, 12.83050728], [92.94522858, 12.82999039], [92.94502258, 12.82953358], [92.94487, 12.82904243], [92.94471741, 12.82854271], [92.94456482, 12.82804108], [92.94441223, 12.82755089], [92.94420624, 12.82711983], [92.94419098, 12.82673264], [92.94431305, 12.82637978], [92.94441986, 12.82603073], [92.94445801, 12.82566166], [92.94455719, 12.82528973], [92.94474792, 12.82492828], [92.94502258, 12.8245697], [92.94532776, 12.82422066], [92.94566345, 12.82390213], [92.94599152, 12.8236084], [92.94628906, 12.82331181], [92.9465332, 12.8229723], [92.94662476, 12.82256222], [92.94654846, 12.82211781], [92.94638824, 12.82167053], [92.94621277, 12.82119179], [92.94612122, 12.82067966], [92.94613647, 12.82020092], [92.94629669, 12.81979847], [92.94641876, 12.81941891], [92.94658661, 12.81904984], [92.94670868, 12.8186264], [92.94692993, 12.81824112], [92.94715881, 12.81785297], [92.94741058, 12.81747055], [92.94766235, 12.81709003], [92.94802856, 12.81680012], [92.94839478, 12.81647205], [92.94883728, 12.8161602], [92.94930267, 12.81579971], [92.94972229, 12.81534195], [92.95014191, 12.81485367], [92.95053864, 12.81434631], [92.95089722, 12.81383133], [92.95127106, 12.81332016], [92.95163727, 12.81279755], [92.95194244, 12.81223965], [92.9522171, 12.81171131], [92.95249176, 12.8112669], [92.95271301, 12.81088161], [92.95279694, 12.81048012], [92.95292664, 12.81011963], [92.95307922, 12.80975342], [92.95329285, 12.80941582], [92.95340729, 12.80900097], [92.95359039, 12.80862141], [92.95374298, 12.80822182], [92.95388794, 12.8078413], [92.95405579, 12.80746269], [92.95414734, 12.80704117], [92.95417023, 12.80659008], [92.95413971, 12.80611992], [92.95401001, 12.80566883], [92.95391083, 12.80521965], [92.95388794, 12.80476189], [92.95384979, 12.8043108], [92.95367432, 12.80390739], [92.95359802, 12.80345154], [92.95355225, 12.80297279], [92.95331573, 12.80257225], [92.95294189, 12.80223179], [92.95248413, 12.80192947], [92.95201111, 12.80160999], [92.95150757, 12.80122852], [92.95100403, 12.80086899], [92.95049286, 12.80054092], [92.95004272, 12.80013084], [92.94972229, 12.7996521], [92.94948578, 12.79915524], [92.94944, 12.79861069], [92.94944, 12.79808044], [92.94945526, 12.79760647], [92.9495163, 12.79717541], [92.94967651, 12.79680061], [92.94976807, 12.79638577], [92.94995117, 12.7959919], [92.94999695, 12.79553223], [92.9499588, 12.79506016], [92.94976807, 12.794631], [92.94967651, 12.7941618], [92.94946289, 12.79374027], [92.9492569, 12.79330921], [92.94906616, 12.79286957], [92.94877625, 12.79252148], [92.94843292, 12.79222012], [92.94805908, 12.79198837], [92.94763184, 12.79191017], [92.94728088, 12.79174137], [92.94690704, 12.79165936], [92.94655609, 12.79154968], [92.94619751, 12.79139042], [92.94579315, 12.79121017], [92.94530487, 12.79103279], [92.94480133, 12.79077721], [92.94433594, 12.79045105], [92.94386292, 12.79015064], [92.94338989, 12.78991985], [92.94299316, 12.78965092], [92.94268799, 12.78936005], [92.94241333, 12.78906059], [92.94219208, 12.78871918], [92.94193268, 12.78839111], [92.94165802, 12.78805065], [92.94135284, 12.78773022], [92.94100952, 12.78741646], [92.94062805, 12.78713131], [92.94029236, 12.78672028], [92.94000244, 12.78622055], [92.93972015, 12.78567028], [92.93942261, 12.78514099], [92.9391098, 12.7846508], [92.9388504, 12.78413963], [92.93859863, 12.78369141], [92.93834686, 12.78334045], [92.93811035, 12.78304195], [92.93785095, 12.78277969], [92.93750763, 12.7825613], [92.93699646, 12.78249931], [92.93650055, 12.78245354], [92.93610382, 12.78226471], [92.93573761, 12.78217125], [92.93541718, 12.78201199], [92.93505859, 12.7819109], [92.93477631, 12.78172874], [92.93453979, 12.78155994], [92.93440247, 12.78127956], [92.93422699, 12.78103161], [92.93413544, 12.78074932], [92.93396759, 12.78046036], [92.93389893, 12.78011322], [92.93388367, 12.77971172], [92.93385315, 12.7792902], [92.93366241, 12.7789011], [92.93361664, 12.77847004], [92.93360901, 12.77802086], [92.93360901, 12.7775507], [92.93360901, 12.77706814], [92.93361664, 12.77655983], [92.93370819, 12.77603054], [92.93385315, 12.7755003], [92.93392181, 12.77493954], [92.93406677, 12.77439022], [92.93419647, 12.77382088], [92.93444824, 12.77330112], [92.93473053, 12.77283573], [92.93504333, 12.7724514], [92.93530273, 12.77208233], [92.93556213, 12.7717762], [92.93585968, 12.77147102], [92.93623352, 12.7711544], [92.93674469, 12.77084637], [92.93728638, 12.77050018], [92.93772125, 12.77002811], [92.93792725, 12.76946068], [92.9380722, 12.76897526], [92.93821716, 12.76863098], [92.93839264, 12.76839161], [92.93859863, 12.76820946], [92.93881226, 12.76801968], [92.93904877, 12.76781273], [92.93930054, 12.76774025], [92.93962097, 12.76784515], [92.93981934, 12.76795197], [92.94001007, 12.7681179], [92.94025421, 12.76832104], [92.94062805, 12.76850128], [92.94113159, 12.76865101], [92.94165802, 12.7688818], [92.94223022, 12.76911926], [92.94285583, 12.76917076], [92.94342804, 12.76928043], [92.94391632, 12.76946068], [92.94438171, 12.76971817], [92.94486237, 12.7699604], [92.94541168, 12.77013493], [92.94593811, 12.77025127], [92.94648743, 12.77028084], [92.94706726, 12.77028084], [92.94764709, 12.77028084], [92.94821167, 12.77028084], [92.94877625, 12.77025127], [92.94934845, 12.77007961], [92.94982147, 12.76978588], [92.94989014, 12.76937199], [92.94976044, 12.76893425], [92.94972992, 12.76849365], [92.94972229, 12.76809311], [92.94971466, 12.76772213], [92.94966125, 12.76736069], [92.94948578, 12.76699924], [92.94941711, 12.76655006], [92.9493103, 12.76611233], [92.94917297, 12.7656517], [92.94904327, 12.76515961], [92.9488678, 12.7646904], [92.94866943, 12.7642498], [92.94861603, 12.76380062], [92.9486084, 12.76338673], [92.94861603, 12.76300144], [92.94867706, 12.76260853], [92.94889069, 12.76220131], [92.94917297, 12.76173019], [92.9495163, 12.76124191], [92.94998932, 12.76084137], [92.95046234, 12.7604847], [92.95082855, 12.76008892], [92.95111847, 12.75973129], [92.95139313, 12.75938034], [92.95161438, 12.75903797], [92.95176697, 12.75863934], [92.95194244, 12.75826073], [92.95211029, 12.75788689], [92.95230103, 12.75755024], [92.95256042, 12.75729179], [92.95291138, 12.75710106], [92.95332336, 12.75692081], [92.9537735, 12.75671101], [92.95432281, 12.75663376], [92.95493317, 12.75650978], [92.95556641, 12.75650406], [92.95611572, 12.75638294], [92.95662689, 12.75620461], [92.95709229, 12.75597], [92.9575882, 12.75579929], [92.9580307, 12.75559044], [92.95851135, 12.755476], [92.95897675, 12.75531197], [92.95951843, 12.75519085], [92.96006012, 12.75498104], [92.96057129, 12.75469875], [92.96103668, 12.75436974], [92.96139526, 12.75399399], [92.96170044, 12.75364971], [92.9619751, 12.75336838], [92.96222687, 12.75312138], [92.96247864, 12.75286198], [92.96269226, 12.75254726], [92.96276855, 12.75209999], [92.96277618, 12.75161934], [92.96273804, 12.75114059], [92.96257782, 12.75069046], [92.96256256, 12.75023079], [92.96259308, 12.74975967], [92.96248627, 12.74929237], [92.96231079, 12.74881363], [92.96224213, 12.74828529], [92.96229553, 12.74773788], [92.96247864, 12.74722099], [92.9627533, 12.74671936], [92.96308136, 12.74627018], [92.96350098, 12.74587059], [92.96399689, 12.74551105], [92.9644165, 12.74505138], [92.96478271, 12.74450874], [92.96517944, 12.74400043], [92.96560669, 12.7435627], [92.96601868, 12.74315929], [92.96644592, 12.74283123], [92.96688843, 12.74255085], [92.9673233, 12.7421999], [92.96773529, 12.74177074], [92.96805573, 12.74121284], [92.96833801, 12.74059486], [92.96856689, 12.73996162], [92.96858215, 12.73927116], [92.96841431, 12.73863983], [92.9681778, 12.73811054], [92.96787262, 12.7377367], [92.967659, 12.73738194], [92.96746826, 12.73705959], [92.96728516, 12.73679447], [92.9671936, 12.73647213], [92.96704865, 12.73619747], [92.96695709, 12.73589134], [92.96691132, 12.73555183], [92.96675873, 12.73521042], [92.96668243, 12.73482037], [92.96666718, 12.73435974], [92.9666214, 12.73391056], [92.96643066, 12.73355007], [92.96631622, 12.733181], [92.96612549, 12.73290539], [92.96593475, 12.7325964], [92.96572876, 12.73224926], [92.9654541, 12.73190498], [92.96523285, 12.7314806], [92.96496582, 12.73106194], [92.96475983, 12.73057175], [92.9646759, 12.73002529], [92.9644928, 12.72955513], [92.96444702, 12.72906971], [92.96443939, 12.72861195], [92.96444702, 12.72820091], [92.96443939, 12.72784138], [92.96444702, 12.72751141], [92.96447754, 12.72719193], [92.96460724, 12.72691441], [92.96469879, 12.72661495], [92.96472168, 12.72628021], [92.96472168, 12.72593975], [92.96475983, 12.7256012], [92.96491241, 12.72534275], [92.9650116, 12.72503567], [92.9651413, 12.72471046], [92.96528625, 12.72434044], [92.96547699, 12.7239418], [92.96560669, 12.72345161], [92.96583557, 12.72297955], [92.96611023, 12.72246933], [92.96637726, 12.72193432], [92.96664429, 12.72139072], [92.96691132, 12.72088146], [92.96720886, 12.7204771], [92.96749878, 12.72014046], [92.96781158, 12.71987057], [92.9681778, 12.71970463], [92.96856689, 12.71952248], [92.96903229, 12.7194519], [92.96956635, 12.71944332], [92.97012329, 12.71946526], [92.97068024, 12.71957016], [92.97120667, 12.71969986], [92.97170258, 12.71972084], [92.97214508, 12.71972275], [92.97255707, 12.71972275], [92.97298431, 12.71972466], [92.97345734, 12.71972275], [92.97399139, 12.71967506], [92.97447968, 12.71944046], [92.9749527, 12.71916866], [92.97541809, 12.71889114], [92.97589111, 12.71863079], [92.97638702, 12.71843147], [92.97689056, 12.71817112], [92.97730255, 12.71774673], [92.97762299, 12.71720028], [92.97785187, 12.71659088], [92.97808075, 12.71597099], [92.97833252, 12.71540928], [92.97854614, 12.71487141], [92.9786377, 12.71428871], [92.97883606, 12.71374035], [92.97892761, 12.71316814], [92.97912598, 12.71264172], [92.97928619, 12.71211147], [92.97953033, 12.71161175], [92.97978973, 12.71115112], [92.98010254, 12.71071053], [92.98033905, 12.71022129], [92.98051453, 12.70972919], [92.9805069, 12.70922089], [92.98027802, 12.70877171], [92.9799881, 12.70833874], [92.97960663, 12.70796013], [92.97914124, 12.70769119], [92.97866821, 12.70757961], [92.9782486, 12.7077713], [92.97789001, 12.70798111], [92.97750092, 12.70805645], [92.97583008, 12.70944405], [92.97473907, 12.7105751], [92.97441864, 12.71084976], [92.97409821, 12.71115971], [92.97368622, 12.71138096], [92.97323608, 12.71150017], [92.97281647, 12.71164131], [92.97245789, 12.71167088], [92.97219086, 12.71161175], [92.9719696, 12.71144962], [92.97166443, 12.71135235], [92.97134399, 12.71114731], [92.97091675, 12.71099186], [92.97054291, 12.71067715], [92.9701004, 12.71029186], [92.96959686, 12.70987034], [92.96907806, 12.70943928], [92.9686203, 12.70901108], [92.9682312, 12.70864201], [92.96790314, 12.70833015], [92.96759033, 12.70804691], [92.96730042, 12.70775986], [92.96697998, 12.70746136], [92.96668243, 12.70713997], [92.96643066, 12.70683861], [92.96624756, 12.70652008], [92.96607208, 12.70622826], [92.96586609, 12.70599079], [92.96570587, 12.70571995], [92.96553802, 12.70545959], [92.96536255, 12.7052002], [92.96523285, 12.70487022], [92.965065, 12.70457554], [92.96499634, 12.70425034], [92.96499634, 12.70393085], [92.96499634, 12.70363045], [92.9650116, 12.70331955], [92.965065, 12.70300102], [92.96512604, 12.7026701], [92.96499634, 12.70230961], [92.96477509, 12.70191765], [92.96453857, 12.7014904], [92.96425629, 12.70106125], [92.96401215, 12.70057964], [92.96376038, 12.70011806], [92.96357727, 12.69957066], [92.96334076, 12.69904041], [92.96312714, 12.69847012], [92.96305847, 12.69781971], [92.9630127, 12.69710922], [92.96292877, 12.69678116], [92.96270752, 12.6958313], [92.96292877, 12.69486046], [92.96305847, 12.69452], [92.96362305, 12.69423962], [92.96459961, 12.6938324], [92.96515656, 12.69369316], [92.96550751, 12.69334888], [92.96565247, 12.69314098], [92.96522522, 12.69286633], [92.96501923, 12.69155979], [92.96465302, 12.68995953], [92.96448517, 12.6895237], [92.96444702, 12.68900871], [92.96444702, 12.68844032], [92.96440125, 12.68783092], [92.96417236, 12.6872406], [92.96392059, 12.68665028], [92.96368408, 12.68606186], [92.96350098, 12.68545246], [92.96337128, 12.68486118], [92.96337891, 12.6842804], [92.96360016, 12.68378639], [92.96382141, 12.68330002], [92.96404266, 12.68280983], [92.96431732, 12.68236065], [92.96466064, 12.68192959], [92.96498108, 12.68148136], [92.96520996, 12.68097115], [92.965271, 12.68037128], [92.96523285, 12.67976093], [92.96505737, 12.67917919], [92.96498108, 12.6785593], [92.96485901, 12.67795086], [92.96473694, 12.67733097], [92.96472168, 12.67672253], [92.96470642, 12.67613888], [92.96463013, 12.67563057], [92.96444702, 12.67520046], [92.9642868, 12.6747694], [92.96406555, 12.67436123], [92.96372986, 12.67407036], [92.96350098, 12.67366791], [92.96329498, 12.6731596], [92.96305847, 12.67266083], [92.96286011, 12.67214108], [92.96274567, 12.67157841], [92.96259308, 12.671031], [92.96245575, 12.6704731], [92.9622345, 12.66995335], [92.96206665, 12.66942501], [92.96196747, 12.66887474], [92.96194458, 12.66829681], [92.96193695, 12.66771984], [92.96193695, 12.66714096], [92.96198273, 12.66657066], [92.9621582, 12.66603088], [92.96233368, 12.66544533], [92.96253204, 12.66480923], [92.96273041, 12.66413021], [92.96276855, 12.66337967], [92.96277618, 12.66260147], [92.96277618, 12.66180325], [92.96277618, 12.66100788], [92.96276855, 12.66024017], [92.96276855, 12.65950966], [92.96273041, 12.65886784], [92.96250916, 12.65832996], [92.96228027, 12.65781879], [92.96212769, 12.65727043], [92.96192169, 12.65674114], [92.96166229, 12.65623093], [92.96141052, 12.65572929], [92.96118927, 12.65524387], [92.96102142, 12.65475845], [92.96082306, 12.65429974], [92.96060181, 12.65384007], [92.96051025, 12.65326118], [92.96030426, 12.6527071], [92.96015167, 12.65210056], [92.96002197, 12.65148067], [92.9599762, 12.65086079], [92.95987701, 12.65030956], [92.95974731, 12.64983559], [92.95967102, 12.64938927], [92.9595108, 12.64903069], [92.95944977, 12.64868546], [92.95943451, 12.64833355], [92.95935822, 12.64799404], [92.95920563, 12.64766598], [92.9591217, 12.64725971], [92.9589386, 12.64686108], [92.95890045, 12.64640808], [92.95893097, 12.64592171], [92.95887756, 12.64544964], [92.95876312, 12.64500141], [92.95863342, 12.64456558], [92.95857239, 12.64414024], [92.95848083, 12.64377308], [92.95835876, 12.64345932], [92.95826721, 12.64315987], [92.95810699, 12.64286995], [92.95806885, 12.64252186], [92.95807648, 12.6420908], [92.95809174, 12.64160061], [92.95820618, 12.64104939], [92.9582901, 12.64044094], [92.95832825, 12.63985252], [92.95832825, 12.63927174], [92.95828247, 12.63869476], [92.95809937, 12.63810921], [92.95806122, 12.63749599], [92.95809937, 12.63688087], [92.95828247, 12.63630867], [92.95833588, 12.63571167], [92.95833588, 12.63513088], [92.95831299, 12.63456059], [92.95818329, 12.63400936], [92.95807648, 12.63349915], [92.95806122, 12.6330204], [92.95810699, 12.63258171], [92.95828247, 12.63216972], [92.95828247, 12.63176918], [92.95810699, 12.63134861], [92.95806122, 12.63085938], [92.95802307, 12.63033962], [92.95786285, 12.62982178], [92.95778656, 12.62928009], [92.95777893, 12.62872791], [92.95777893, 12.62818146], [92.95781708, 12.62763023], [92.95793915, 12.62709904], [92.95804596, 12.62694168], [92.95805359, 12.62444401], [92.95722198, 12.62360954], [92.95749664, 12.62333393], [92.95694733, 12.62277794], [92.95722198, 12.62250042], [92.95722198, 12.62194061], [92.95805359, 12.62111187], [92.95804596, 12.62083054], [92.95833588, 12.62055492], [92.95833588, 12.61972141], [92.95840454, 12.6194067], [92.95857239, 12.61908054], [92.95859528, 12.61874104], [92.95851898, 12.61836529], [92.95839691, 12.61795044], [92.95829773, 12.61750126], [92.95808411, 12.61710739], [92.95793915, 12.61669922], [92.95780182, 12.61634064], [92.95773315, 12.61598969], [92.95758057, 12.61572838], [92.9575119, 12.6154213], [92.9574585, 12.61505127], [92.95726776, 12.61470032], [92.95717621, 12.61421871], [92.95700073, 12.61369133], [92.95696259, 12.61309147], [92.95696259, 12.61247063], [92.95696259, 12.61188984], [92.95693207, 12.61138153], [92.95687103, 12.6109581], [92.95671082, 12.61062145], [92.95663452, 12.61025238], [92.9564743, 12.60991859], [92.95639038, 12.6095314], [92.95632172, 12.60908031], [92.95622253, 12.60860062], [92.95613861, 12.60808182], [92.95614624, 12.60750961], [92.95633698, 12.60689735], [92.95639038, 12.60624886], [92.95643616, 12.60559082], [92.95656586, 12.60499573], [92.95643616, 12.60437965], [92.95633698, 12.60369015], [92.95615387, 12.60300636], [92.95612335, 12.60229969], [92.95614624, 12.60167503], [92.95630646, 12.60115147], [92.95652771, 12.60069275], [92.95667267, 12.60021019], [92.95685577, 12.59976959], [92.95716095, 12.59941196], [92.95748901, 12.59902], [92.95778656, 12.59858036], [92.95801544, 12.59809017], [92.95801544, 12.59754753], [92.95781708, 12.59700966], [92.95779419, 12.59645844], [92.9577713, 12.59591103], [92.95770264, 12.59540272], [92.95753479, 12.59494305], [92.95745087, 12.59444141], [92.95729065, 12.59396267], [92.95739746, 12.59346962], [92.95754242, 12.59304428], [92.95777893, 12.59263611], [92.95800781, 12.59220123], [92.95809174, 12.59166145], [92.95825195, 12.59120178], [92.95844269, 12.59082603], [92.95861816, 12.59046173], [92.95878601, 12.59009266], [92.95894623, 12.58967972], [92.95913696, 12.58928108], [92.9592514, 12.58884144], [92.95941925, 12.58848953], [92.95952606, 12.5881424], [92.95968628, 12.58787346], [92.95980072, 12.58757877], [92.95996857, 12.58732128], [92.96008301, 12.58702946], [92.96024323, 12.58678055], [92.96034241, 12.58650684], [92.96051025, 12.5862999], [92.96066284, 12.58603096], [92.9608078, 12.58572102], [92.96124268, 12.58549118], [92.96163177, 12.58511543], [92.96193695, 12.58459473], [92.96216583, 12.58397961], [92.96216583, 12.58331203], [92.96194458, 12.58271694], [92.96170044, 12.58218193], [92.96160126, 12.58165264], [92.96162415, 12.5811491], [92.96166229, 12.58065033], [92.96166229, 12.58012104], [92.96165466, 12.57956505], [92.96163177, 12.57899094], [92.96160889, 12.57841873], [92.96160126, 12.57783985], [92.96165466, 12.57728767], [92.96172333, 12.57671165], [92.96194458, 12.57621002], [92.96218872, 12.57575035], [92.96240234, 12.57531929], [92.96268463, 12.57500172], [92.96299744, 12.57472229], [92.96338654, 12.57444191], [92.96385193, 12.57410908], [92.96427155, 12.57359791], [92.96457672, 12.57304859], [92.96443939, 12.57247925], [92.9642334, 12.57197571], [92.96421051, 12.57151985], [92.96438599, 12.57112312], [92.96446228, 12.57069492], [92.96456909, 12.57029629], [92.96473694, 12.56993961], [92.96501923, 12.56965065], [92.9653244, 12.56937695], [92.96552277, 12.56896019], [92.96563721, 12.56850719], [92.96559143, 12.56805992], [92.96562195, 12.56765938], [92.96581268, 12.56727791], [92.96595001, 12.56683636], [92.96611786, 12.56640053], [92.96637726, 12.56604099], [92.96663666, 12.56571007], [92.96684265, 12.56536198], [92.96700287, 12.56496143], [92.96723175, 12.56457806], [92.96749878, 12.56418991], [92.96777344, 12.56378937], [92.96806335, 12.56335068], [92.9683609, 12.56287956], [92.96871185, 12.56239891], [92.96907806, 12.56191635], [92.96939087, 12.56141186], [92.96968079, 12.56091976], [92.96994781, 12.56044102], [92.9701004, 12.55992985], [92.9703064, 12.5595293], [92.97051239, 12.55920315], [92.97059631, 12.55883408], [92.97075653, 12.55850124], [92.97084045, 12.55810261], [92.97093964, 12.55768776], [92.97106934, 12.55727959], [92.97112274, 12.55683994], [92.97115326, 12.55642128], [92.97135162, 12.55607891], [92.97144318, 12.55573463], [92.97159576, 12.55544472], [92.9716568, 12.55511475], [92.97168732, 12.55477524], [92.97177887, 12.55447006], [92.97190857, 12.55417061], [92.97196198, 12.55378056], [92.97199249, 12.5533638], [92.97219086, 12.55296993], [92.97233582, 12.55253029], [92.97251892, 12.55211544], [92.97277832, 12.5517416], [92.97303772, 12.55139542], [92.97328186, 12.55109024], [92.97348022, 12.55080891], [92.97360229, 12.55051994], [92.97367859, 12.55022144], [92.97375488, 12.54993629], [92.97364044, 12.54963112], [92.97367859, 12.54939175], [92.97415924, 12.54660416], [92.9743042, 12.54623699], [92.97444153, 12.54584122], [92.97455597, 12.54540062], [92.97466278, 12.54493141], [92.97476196, 12.54442978], [92.97496796, 12.54400158], [92.9751358, 12.54352093], [92.97528839, 12.54300594], [92.97544098, 12.54246998], [92.97550964, 12.54189968], [92.97543335, 12.54133034], [92.97541046, 12.54076672], [92.97531128, 12.54027081], [92.97528076, 12.53975964], [92.97522736, 12.53928185], [92.97502899, 12.53888512], [92.97489166, 12.53848171], [92.97476196, 12.53807068], [92.97463226, 12.53767014], [92.97451782, 12.53726006], [92.97441864, 12.53687], [92.9743576, 12.53650093], [92.97434998, 12.53604984], [92.97442627, 12.53560066], [92.9744339, 12.53519344], [92.97441864, 12.53482056], [92.97444916, 12.53443241], [92.97451782, 12.53398037], [92.97467804, 12.53347874], [92.97470856, 12.53289127], [92.97470856, 12.53229141], [92.97467041, 12.53176022], [92.97445679, 12.5313797], [92.97426605, 12.5310812], [92.97416687, 12.53080082], [92.97410583, 12.53053188], [92.97403717, 12.53026104], [92.97396851, 12.52997971], [92.97389221, 12.52968884], [92.97380829, 12.52939034], [92.97364807, 12.52911186], [92.97358704, 12.52877045], [92.97345734, 12.52845097], [92.97332764, 12.52810001], [92.97317505, 12.52774715], [92.97303009, 12.52735043], [92.97281647, 12.52694035], [92.9727478, 12.52643204], [92.97260284, 12.52591038], [92.97247314, 12.52533817], [92.97226715, 12.52473164], [92.97218323, 12.5240202], [92.97193909, 12.52332115], [92.97163391, 12.52269554], [92.97128296, 12.52221107], [92.97099304, 12.52178192], [92.97071075, 12.52135372], [92.97052002, 12.52092075], [92.9703598, 12.52051067], [92.97026825, 12.52009106], [92.97018433, 12.51967621], [92.97010803, 12.51924133], [92.97003174, 12.51878071], [92.97000122, 12.51831055], [92.96998596, 12.51787758], [92.96988678, 12.51751995], [92.9697113, 12.51721001], [92.96946716, 12.5169096], [92.96916962, 12.51656055], [92.96834564, 12.5159893], [92.96775818, 12.51541042], [92.96720886, 12.51504135], [92.96691895, 12.51483059], [92.96630859, 12.51412868], [92.96620178, 12.51357079], [92.96602631, 12.51243973], [92.96591187, 12.51082039], [92.96546936, 12.50887966], [92.96553802, 12.50861073], [92.96553802, 12.50472069], [92.96583557, 12.50444508], [92.96583557, 12.50388908], [92.96611023, 12.50361061], [92.96611023, 12.50305462], [92.96639252, 12.50278091], [92.96639252, 12.50193977], [92.96666718, 12.50166702], [92.96666718, 12.50139141], [92.96694183, 12.50111961], [92.96694183, 12.5008297], [92.96722412, 12.50055695], [92.96721649, 12.50028133], [92.96749878, 12.50000095], [92.96749878, 12.49971962], [92.96746063, 12.49892044], [92.96766663, 12.49806976], [92.96797943, 12.49747276], [92.96821594, 12.4971199], [92.96842194, 12.49666882], [92.96827698, 12.4963789], [92.96740723, 12.49562931], [92.96707916, 12.4949522], [92.96653748, 12.49464226], [92.96495819, 12.49402237], [92.96451569, 12.49375343], [92.96417999, 12.49334145], [92.96386719, 12.4926796], [92.96375275, 12.49189091], [92.96366119, 12.49096394], [92.96391296, 12.48993111], [92.96405792, 12.48927021], [92.96404266, 12.48857975], [92.96376038, 12.48815441], [92.96337128, 12.48771191], [92.96231842, 12.48718262], [92.96164703, 12.4871006], [92.96083069, 12.48666954], [92.95999908, 12.48666954], [92.95905304, 12.48668766], [92.95852661, 12.48691368], [92.95800018, 12.48722363], [92.95755768, 12.48751259], [92.95684814, 12.48838234], [92.95671844, 12.48888969], [92.95683289, 12.48944092], [92.9569931, 12.48983097], [92.95705414, 12.49015903], [92.95674133, 12.49061108], [92.95632172, 12.49104977], [92.95582581, 12.49166965], [92.95555878, 12.49166584], [92.95527649, 12.49193001], [92.95509338, 12.4919796], [92.95466614, 12.49213314], [92.9541626, 12.49226475], [92.95363617, 12.49253178], [92.95316315, 12.49291897], [92.95287323, 12.49341202], [92.95253754, 12.49378967], [92.95217896, 12.49413013], [92.95172119, 12.49437141], [92.95128632, 12.49473953], [92.95088959, 12.49517059], [92.95063019, 12.49564075], [92.95046234, 12.49606037], [92.95024872, 12.49640179], [92.94999695, 12.49673462], [92.94973755, 12.4971199], [92.9495163, 12.49759197], [92.94937134, 12.49810028], [92.94911957, 12.49851036], [92.94877625, 12.4988203], [92.94837189, 12.4989996], [92.94789124, 12.49914074], [92.94744873, 12.49912071], [92.94705963, 12.49895], [92.94664764, 12.49883842], [92.94631195, 12.49860954], [92.94602203, 12.49834061], [92.94576263, 12.49808598], [92.94552612, 12.49785995], [92.94534302, 12.49763012], [92.94528198, 12.49734306], [92.94527435, 12.4969883], [92.94529724, 12.49659061], [92.9454422, 12.49620819], [92.94554138, 12.49579144], [92.94555664, 12.49533081], [92.94550323, 12.49485397], [92.94526672, 12.49442101], [92.94494629, 12.49399281], [92.94455719, 12.49361897], [92.94419861, 12.4932909], [92.94391632, 12.49301529], [92.94372559, 12.49276924], [92.94361877, 12.4925108], [92.94352722, 12.49216938], [92.94333649, 12.49177074], [92.94313049, 12.49127197], [92.94303131, 12.49068069], [92.94291687, 12.49014091], [92.94277954, 12.48968124], [92.94262695, 12.48927689], [92.94242859, 12.48894024], [92.94220734, 12.48856163], [92.94194031, 12.48817158], [92.94169617, 12.48778439], [92.94154358, 12.48740387], [92.94126892, 12.48721027], [92.94113159, 12.48698711], [92.9411087, 12.48668957], [92.9411087, 12.48636913], [92.94111633, 12.48602867], [92.9411087, 12.48565102], [92.94106293, 12.48525047], [92.94085693, 12.48487186], [92.94062042, 12.48446083], [92.94033051, 12.48407173], [92.94007874, 12.48363018], [92.93978119, 12.48324013], [92.93955231, 12.48283195], [92.93926239, 12.48251057], [92.93897247, 12.48224163], [92.93868256, 12.48201084], [92.93840027, 12.48176098], [92.93801117, 12.4816103], [92.93757629, 12.48143005], [92.93704987, 12.48139095], [92.93647766, 12.48140144], [92.93589783, 12.48147964], [92.93535614, 12.48166275], [92.9348526, 12.48182011], [92.93440247, 12.48190022], [92.93405151, 12.48179722], [92.93358612, 12.48168087], [92.93318176, 12.48159027], [92.93282318, 12.4813776], [92.93247986, 12.48109055], [92.93213654, 12.48072147], [92.93192291, 12.48031807], [92.93180084, 12.47994041], [92.93173218, 12.47970867], [92.93178558, 12.47944069], [92.93193817, 12.47923088], [92.93218994, 12.47897053], [92.93242645, 12.47868443], [92.9324646, 12.47834682], [92.93231201, 12.47797966], [92.93212128, 12.4775486], [92.93184662, 12.4771204], [92.93160248, 12.47669601], [92.931427, 12.47630024], [92.931427, 12.47593689], [92.93157959, 12.47562122], [92.93173218, 12.47533131], [92.93193817, 12.47506237], [92.93218994, 12.47476101], [92.93255615, 12.47447014], [92.93305206, 12.47423458], [92.93357086, 12.47395039], [92.93403625, 12.47352791], [92.93438721, 12.4730196], [92.93450928, 12.47249126], [92.93470001, 12.47208118], [92.93483734, 12.47167778], [92.93499756, 12.47126961], [92.93515015, 12.4708004], [92.93525696, 12.47029209], [92.93526459, 12.4697504], [92.9347229, 12.46833038], [92.93360901, 12.46722221], [92.9327774, 12.46722221], [92.93250275, 12.46694374], [92.93166351, 12.46694374], [92.93138885, 12.46666622], [92.93110657, 12.46667099], [92.93083191, 12.46638966], [92.93083191, 12.46611023], [92.9311142, 12.46583366], [92.93360901, 12.46583366], [92.9338913, 12.46611214], [92.93416595, 12.46611214], [92.93425751, 12.46620274], [92.93444824, 12.46638966], [92.9347229, 12.46638966], [92.93515015, 12.46652889], [92.93549347, 12.4666729], [92.93588257, 12.46685123], [92.93630981, 12.46705055], [92.9367218, 12.46736145], [92.93717957, 12.46765137], [92.93760681, 12.46798992], [92.93808746, 12.46824074], [92.93858337, 12.46842098], [92.9390564, 12.46858025], [92.93961334, 12.46861172], [92.94019318, 12.46858025], [92.94077301, 12.46842098], [92.94135284, 12.46830177], [92.94187164, 12.46813583], [92.94233704, 12.46819115], [92.94270325, 12.46829796], [92.94299316, 12.46836376], [92.94326019, 12.46851444], [92.943573, 12.46861935], [92.94387054, 12.46879673], [92.94415283, 12.46909142], [92.94435883, 12.46951866], [92.94449615, 12.47004986], [92.94471741, 12.47054672], [92.94493866, 12.47102356], [92.94500732, 12.4715023], [92.94503784, 12.47194386], [92.94503784, 12.47236156], [92.94512939, 12.47274685], [92.94533539, 12.47310543], [92.94563293, 12.47340965], [92.94605255, 12.47355843], [92.94651794, 12.47370243], [92.94697571, 12.47391796], [92.94744873, 12.47418022], [92.94790649, 12.47451115], [92.94837952, 12.47488022], [92.9489212, 12.47521973], [92.94948578, 12.4755497], [92.95010376, 12.47582817], [92.95069885, 12.47604179], [92.95130157, 12.47610569], [92.95186615, 12.47613144], [92.95239258, 12.47622013], [92.95289612, 12.4762907], [92.95336914, 12.47614861], [92.95387268, 12.47611141], [92.95435333, 12.47606277], [92.95476532, 12.47585964], [92.95521545, 12.47570992], [92.95574951, 12.4755497], [92.95630646, 12.47536087], [92.95684814, 12.47514915], [92.95728302, 12.47478199], [92.95768738, 12.47441959], [92.95800781, 12.47406578], [92.95826721, 12.47370243], [92.95854187, 12.47341919], [92.95881653, 12.47320938], [92.95892334, 12.47291088], [92.95867157, 12.47239113], [92.95838165, 12.47182083], [92.95820618, 12.47128963], [92.95807648, 12.47078037], [92.95797729, 12.47024632], [92.95778656, 12.46969032], [92.9577179, 12.4690609], [92.95800781, 12.46833706], [92.95793915, 12.46770954], [92.95765686, 12.4671402], [92.95724487, 12.46668911], [92.95683289, 12.46632195], [92.95635223, 12.46610069], [92.95588684, 12.4659214], [92.95540619, 12.46580029], [92.95500946, 12.46564484], [92.95466614, 12.4654789], [92.95439148, 12.465271], [92.95413971, 12.46505547], [92.95384979, 12.46483135], [92.95349121, 12.46463108], [92.95306396, 12.46453953], [92.95259857, 12.46469021], [92.95213318, 12.46483994], [92.95172119, 12.46501064], [92.95128632, 12.4651413], [92.9510498, 12.46506405], [92.95080566, 12.46498394], [92.95027161, 12.46472168], [92.94972992, 12.46440506], [92.94927216, 12.46399021], [92.94888306, 12.46356201], [92.94857788, 12.46311665], [92.94831848, 12.4627409], [92.94808197, 12.46246147], [92.94787598, 12.4622097], [92.9477005, 12.46196175], [92.94753265, 12.4616909], [92.94731903, 12.46140099], [92.94702911, 12.46111202], [92.94667816, 12.46083641], [92.94629669, 12.46062183], [92.94577026, 12.46076107], [92.94529724, 12.46085167], [92.94487762, 12.46093178], [92.94454193, 12.46093178], [92.94429779, 12.46075153], [92.94415283, 12.46055984], [92.94416046, 12.46034145], [92.94432831, 12.46011066], [92.94469452, 12.45989895], [92.94515228, 12.45967102], [92.94558716, 12.45938015], [92.94579315, 12.45904732], [92.94583893, 12.45868015], [92.94589996, 12.45831966], [92.94610596, 12.45800114], [92.94629669, 12.45759964], [92.9462204, 12.45705891], [92.94590759, 12.45647144], [92.94567871, 12.45582199], [92.94539642, 12.45532036], [92.9450531, 12.45491028], [92.94474792, 12.45445442], [92.94445801, 12.4539547], [92.94402313, 12.45361137], [92.94358063, 12.45330143], [92.9432373, 12.45302963], [92.94300842, 12.45273972], [92.94281006, 12.45247173], [92.94271851, 12.45209122], [92.94254303, 12.45168304], [92.94250488, 12.45115185], [92.94244385, 12.45056152], [92.94217682, 12.44999027], [92.9417572, 12.44952011], [92.9412384, 12.44917965], [92.94069672, 12.44889069], [92.94017029, 12.44861126], [92.93963623, 12.44832993], [92.93910217, 12.44805527], [92.938591, 12.44778061], [92.93811798, 12.44750118], [92.93763733, 12.44726086], [92.93711853, 12.44721985], [92.93660736, 12.44723606], [92.93612671, 12.44733429], [92.93564606, 12.4474411], [92.93511963, 12.44735909], [92.93450165, 12.44728184], [92.93383026, 12.44737053], [92.93328094, 12.44760132], [92.93286133, 12.44795036], [92.93247986, 12.44823933], [92.93212128, 12.44843483], [92.93196106, 12.44850826], [92.93183136, 12.44856453], [92.9315567, 12.44849682], [92.93125916, 12.4483099], [92.93093109, 12.44802856], [92.93058014, 12.4476881], [92.9302063, 12.44729137], [92.92980957, 12.44693089], [92.92944336, 12.44659996], [92.92910767, 12.446311], [92.92888641, 12.44594193], [92.9286499, 12.44559956], [92.9283371, 12.44532204], [92.92799377, 12.44502831], [92.92759705, 12.44473171], [92.92715454, 12.44445419], [92.92668152, 12.44418716], [92.92617798, 12.44394112], [92.92572021, 12.44363117], [92.92524719, 12.44338036], [92.92473602, 12.44328022], [92.92433167, 12.44308376], [92.92392731, 12.44294167], [92.92353058, 12.44275761], [92.92312622, 12.4425602], [92.92267609, 12.44254971], [92.92221832, 12.44278145], [92.9217453, 12.44308567], [92.92128754, 12.44341183], [92.92079926, 12.44365978], [92.92037201, 12.44380188], [92.91999817, 12.44359016], [92.91968536, 12.44329643], [92.91938019, 12.44303989], [92.91912842, 12.44278145], [92.91890717, 12.4425602], [92.91870117, 12.44246197], [92.91816711, 12.44271946], [92.91762543, 12.44311142], [92.91716003, 12.44347954], [92.91671753, 12.44374943], [92.91631317, 12.44394112], [92.91590881, 12.44400024], [92.9156723, 12.44393158], [92.91557312, 12.44390202], [92.91532135, 12.44371128], [92.91517639, 12.44346046], [92.91506958, 12.44314957], [92.91491699, 12.44279861], [92.91468811, 12.44236088], [92.9145813, 12.44186401], [92.914711, 12.44139004], [92.91504669, 12.44110966], [92.91555786, 12.4409914], [92.91616058, 12.44100094], [92.91674805, 12.44102955], [92.91744232, 12.44110966], [92.91823578, 12.44124889], [92.91899872, 12.4414196], [92.9193573, 12.44121933], [92.91951752, 12.44079113], [92.91969299, 12.44034195], [92.9197464, 12.43980026], [92.91964722, 12.43921089], [92.91950226, 12.43864155], [92.91946411, 12.4381361], [92.91957092, 12.43772125], [92.91989136, 12.43741989], [92.92015076, 12.43717194], [92.92041016, 12.43699837], [92.9207077, 12.43695068], [92.92102814, 12.43693924], [92.92138672, 12.43697071], [92.92179108, 12.43707085], [92.92221069, 12.43715096], [92.92263031, 12.43695068], [92.9230423, 12.43669128], [92.92339325, 12.43636036], [92.92357635, 12.43595028], [92.92359924, 12.43548489], [92.92350006, 12.43504143], [92.92330933, 12.43463039], [92.92310333, 12.43426991], [92.92280579, 12.43395996], [92.92238617, 12.43382072], [92.92205048, 12.4335928], [92.92178345, 12.43330383], [92.92157745, 12.43296432], [92.92140961, 12.43258095], [92.92128754, 12.43214417], [92.9210968, 12.43171978], [92.92085266, 12.4313097], [92.92059326, 12.43088055], [92.92034912, 12.43050098], [92.92011261, 12.4300518], [92.91976929, 12.42974567], [92.91945648, 12.42939091], [92.91942596, 12.42887974], [92.919487, 12.4283514], [92.91971588, 12.42792702], [92.91996002, 12.42752171], [92.92014313, 12.42708015], [92.92028809, 12.42663097], [92.92043304, 12.42623043], [92.92050171, 12.42590141], [92.92035675, 12.42560959], [92.92028809, 12.42529106], [92.92024231, 12.42494202], [92.92014313, 12.42459106], [92.92022705, 12.42410088], [92.92015076, 12.42361069], [92.91997528, 12.42316628], [92.91971588, 12.42272186], [92.91944122, 12.42222977], [92.91911316, 12.42172432], [92.91871643, 12.42122459], [92.91827393, 12.42074108], [92.91792297, 12.42018127], [92.91783905, 12.41953087], [92.91799164, 12.41887856], [92.91793823, 12.41822147], [92.9177475, 12.41760254], [92.91750336, 12.41703796], [92.91725922, 12.41652012], [92.91709137, 12.41599178], [92.91694641, 12.41550159], [92.9168396, 12.41505718], [92.91666412, 12.41469479], [92.91646576, 12.41436005], [92.9163208, 12.41396999], [92.91613007, 12.41363335], [92.91595459, 12.41327477], [92.91567993, 12.41295433], [92.91552734, 12.41252136], [92.91532135, 12.41205788], [92.9152832, 12.41150188], [92.9152832, 12.41091061], [92.91527557, 12.41036892], [92.9152832, 12.40989971], [92.9152832, 12.40948009], [92.91527557, 12.40909958], [92.9152832, 12.40870285], [92.91535187, 12.40828419], [92.91551971, 12.40785503], [92.91555786, 12.40739155], [92.91551971, 12.4069643], [92.91532898, 12.40664864], [92.9151001, 12.40638065], [92.9148407, 12.40610886], [92.91452789, 12.40589333], [92.91413116, 12.40583801], [92.91369629, 12.40583134], [92.91326141, 12.40581131], [92.9128418, 12.4057312], [92.91239929, 12.40572643], [92.91204834, 12.40562153], [92.91165924, 12.40557098], [92.91123962, 12.40555096], [92.91079712, 12.40555286], [92.91033936, 12.40556526], [92.9098587, 12.40563107], [92.90940857, 12.40583992], [92.90894318, 12.40609074], [92.90841675, 12.40631008], [92.90782166, 12.40654182], [92.90731049, 12.40684986], [92.90686798, 12.40721035], [92.9065094, 12.40764141], [92.90640259, 12.40819931], [92.90643311, 12.40884209], [92.90666962, 12.40946198], [92.90692902, 12.41005039], [92.90711975, 12.41060162], [92.90725708, 12.41112137], [92.90747833, 12.41154957], [92.9076767, 12.41196728], [92.90784454, 12.41238403], [92.90805817, 12.41272259], [92.90827942, 12.41308975], [92.90838623, 12.41362095], [92.90862274, 12.41415024], [92.90883636, 12.41466141], [92.90892792, 12.4151392], [92.90907288, 12.41551971], [92.90905762, 12.41593933], [92.90925598, 12.41631126], [92.90940857, 12.41676044], [92.90943909, 12.41726112], [92.90944672, 12.41776943], [92.90948486, 12.41827774], [92.90963745, 12.41875172], [92.90966034, 12.41923046], [92.90959167, 12.41969967], [92.90943909, 12.42016029], [92.90923309, 12.42059994], [92.90898895, 12.42107201], [92.90859985, 12.42147064], [92.90815735, 12.42183971], [92.90769958, 12.42219543], [92.90724182, 12.42250347], [92.90679932, 12.42278099], [92.90640259, 12.42304134], [92.90602875, 12.42320728], [92.90571594, 12.42325115], [92.90544891, 12.42350388], [92.90533447, 12.42391396], [92.90522003, 12.42432022], [92.90489197, 12.42498684], [92.90442657, 12.42547131], [92.90390015, 12.42591], [92.90335846, 12.42631626], [92.90277863, 12.42665958], [92.9021759, 12.42694092], [92.90149689, 12.42709064], [92.90071869, 12.42711163], [92.90027618, 12.4272604], [92.89997864, 12.42752171], [92.8996582, 12.4277792], [92.89930725, 12.42803478], [92.89891052, 12.42827225], [92.89853668, 12.42854977], [92.89815521, 12.4287796], [92.89774323, 12.42895985], [92.89740753, 12.42925167], [92.89702606, 12.42950916], [92.89668274, 12.429842], [92.89634705, 12.43024063], [92.89601135, 12.43066883], [92.89569092, 12.43117523], [92.89546967, 12.4317503], [92.89524078, 12.43232155], [92.89496613, 12.43282986], [92.8946991, 12.43327045], [92.89444733, 12.43365288], [92.89418793, 12.43398094], [92.89398193, 12.43435001], [92.89370728, 12.43470097], [92.89335632, 12.43505192], [92.89302063, 12.43549919], [92.89255524, 12.43583393], [92.89225006, 12.43631172], [92.89187622, 12.43665886], [92.89151001, 12.43694115], [92.89113617, 12.43719387], [92.89070892, 12.43739986], [92.89034271, 12.43775082], [92.88990784, 12.43804932], [92.88942719, 12.43832874], [92.88890076, 12.43861389], [92.88838959, 12.43898964], [92.88781738, 12.43937969], [92.88722992, 12.43978119], [92.8866806, 12.44017982], [92.88622284, 12.44053078], [92.88588715, 12.44079971], [92.8850174, 12.44190788], [92.88478851, 12.44212437], [92.88442993, 12.44231319], [92.8840332, 12.44252968], [92.88362885, 12.44282818], [92.88323212, 12.4431324], [92.88276672, 12.44336033], [92.88232422, 12.44358253], [92.88187408, 12.44371128], [92.88149261, 12.44386101], [92.88108063, 12.44392014], [92.88065338, 12.44396973], [92.88020325, 12.44404125], [92.87981415, 12.44419765], [92.87899017, 12.44435978], [92.87869263, 12.44444656], [92.87825012, 12.44466972], [92.87808228, 12.44508934], [92.87811279, 12.44544029], [92.87872314, 12.44577122], [92.87934875, 12.44616127], [92.8799057, 12.44653225], [92.88033295, 12.44678974], [92.88085175, 12.44699669], [92.88132477, 12.44723892], [92.88175964, 12.44752121], [92.88215637, 12.44787025], [92.88247681, 12.44824791], [92.88273621, 12.44864273], [92.88291931, 12.44902134], [92.88311005, 12.44931316], [92.88329315, 12.44956112], [92.883461, 12.44982147], [92.88365173, 12.450037], [92.88387299, 12.45024014], [92.88414764, 12.45045662], [92.88443756, 12.45074368], [92.88474274, 12.45111084], [92.88504028, 12.45152092], [92.88535309, 12.45190907], [92.88559723, 12.45227146], [92.88582611, 12.45261097], [92.88600159, 12.45293045], [92.88589478, 12.45350933], [92.88575745, 12.45399189], [92.8855896, 12.45415974], [92.88529968, 12.45374107], [92.88498688, 12.45331001], [92.88465118, 12.45289135], [92.88426971, 12.45253086], [92.88385773, 12.45225334], [92.88342285, 12.45206642], [92.88301849, 12.45191097], [92.8826828, 12.45170116], [92.88219452, 12.45072269], [92.88221741, 12.45051384], [92.88219452, 12.4502697], [92.88210297, 12.4500103], [92.88194275, 12.44972134], [92.88170624, 12.44941139], [92.88137054, 12.44906616], [92.88092041, 12.44870186], [92.88034058, 12.44833946], [92.87975311, 12.44802856], [92.87918854, 12.44777203], [92.87873077, 12.44755077], [92.8783493, 12.44746017], [92.87811279, 12.44729137], [92.87785339, 12.44722271], [92.87760925, 12.44715691], [92.87738037, 12.44700241], [92.87705994, 12.44688511], [92.87667084, 12.44672966], [92.87621307, 12.44684029], [92.87567902, 12.4469862], [92.87518311, 12.44719124], [92.87462616, 12.44729137], [92.87404633, 12.44733047], [92.87343597, 12.44733047], [92.87285614, 12.44733047], [92.87194824, 12.44721985], [92.8713913, 12.44694519], [92.87104797, 12.44659138], [92.87071991, 12.44639969], [92.87033844, 12.44628143], [92.86998749, 12.44614029], [92.86960602, 12.44613075], [92.8691864, 12.44626141], [92.86875153, 12.44653702], [92.86828613, 12.44692039], [92.86777496, 12.44734764], [92.86724854, 12.44779015], [92.86675262, 12.44824791], [92.86631012, 12.44879818], [92.8658371, 12.44927216], [92.86534119, 12.44972134], [92.86485291, 12.45014], [92.86433411, 12.45053864], [92.86384583, 12.45090103], [92.86347961, 12.45133018], [92.86304474, 12.45170593], [92.86267853, 12.45216179], [92.8622818, 12.45260143], [92.86194611, 12.45308018], [92.86160278, 12.45353127], [92.86120605, 12.45388889], [92.86080933, 12.45419025], [92.86042023, 12.45441818], [92.85999298, 12.45458031], [92.85957336, 12.45491028], [92.85913086, 12.45527935], [92.8585968, 12.45556927], [92.85806274, 12.4558506], [92.85758972, 12.45612717], [92.85720062, 12.45638943], [92.85688019, 12.45664692], [92.85656738, 12.45685196], [92.85620117, 12.45696068], [92.85591125, 12.4571104], [92.85572052, 12.45728683], [92.8549881, 12.45761299], [92.85460663, 12.4575901], [92.85423279, 12.45772934], [92.85389709, 12.45804882], [92.85359955, 12.45842934], [92.85327148, 12.45878029], [92.8528595, 12.45903969], [92.85244751, 12.45931816], [92.85209656, 12.45972061], [92.85173035, 12.46018028], [92.85128784, 12.46067047], [92.85095978, 12.46128941], [92.85045624, 12.46177006], [92.8500061, 12.46224022], [92.84966278, 12.4627409], [92.84944153, 12.46278], [92.84944153, 12.46306038], [92.84749603, 12.46501064], [92.84750366, 12.46527767], [92.8466568, 12.46611023], [92.8466568, 12.46638966], [92.84638977, 12.46666622], [92.84638977, 12.46694374], [92.84610748, 12.46722031], [92.84610748, 12.46749973], [92.84555817, 12.46805573], [92.84555817, 12.4683342], [92.84443665, 12.46944046], [92.84443665, 12.46972179], [92.84416962, 12.47000027], [92.84388733, 12.47064972], [92.84377289, 12.47105122], [92.84379578, 12.47221088], [92.84361267, 12.47278118], [92.84368134, 12.47318172], [92.84369659, 12.47531796], [92.84361267, 12.47611141], [92.84416962, 12.47667122], [92.84416962, 12.47916889], [92.8443222, 12.47929859], [92.84416962, 12.47972298], [92.84416962, 12.47999191], [92.84444427, 12.48027706], [92.84444427, 12.48083305], [92.84416962, 12.48111057], [92.84416962, 12.48139095], [92.84388733, 12.48166656], [92.84388733, 12.48194122], [92.84306335, 12.48277855], [92.84278107, 12.48277664], [92.84249878, 12.48305511], [92.84139252, 12.48305511], [92.84055328, 12.48361111], [92.84027863, 12.4836092], [92.83999634, 12.48389244], [92.83972168, 12.48389244], [92.83943939, 12.48417187], [92.83914948, 12.48417187], [92.83833313, 12.4849987], [92.83822632, 12.48517513], [92.83792877, 12.48551178], [92.83778381, 12.48573112], [92.83766937, 12.48612976], [92.83777618, 12.48666763], [92.83777618, 12.48692131], [92.8378067, 12.48720074], [92.83789063, 12.4879303], [92.83833313, 12.48916626], [92.83860016, 12.48986053], [92.83868408, 12.49031925], [92.83876801, 12.49075031], [92.83889771, 12.49125099], [92.83885956, 12.49164104], [92.83889771, 12.491889], [92.83879089, 12.49236965], [92.83840942, 12.49248886], [92.83840942, 12.491992], [92.83839417, 12.49166107], [92.83804321, 12.49151993], [92.83763885, 12.49160004], [92.83666992, 12.49261189], [92.83618927, 12.49290085], [92.83589172, 12.49329281], [92.83586884, 12.49368668], [92.83561707, 12.49393368], [92.83511353, 12.49453259], [92.83467865, 12.49478054], [92.83397675, 12.49497128], [92.83384705, 12.49500942], [92.83280945, 12.49538136], [92.83228302, 12.49557018], [92.83152771, 12.49583435], [92.83088684, 12.49600983], [92.83037567, 12.49620819], [92.82988739, 12.49637222], [92.82915497, 12.49643421], [92.82923889, 12.4961853], [92.8296814, 12.49584103], [92.83116913, 12.49512959], [92.83180237, 12.49478054], [92.83303833, 12.49387169], [92.83362579, 12.49343872], [92.83400726, 12.49324131], [92.83446503, 12.49316978], [92.83490753, 12.49311066], [92.83528137, 12.49300098], [92.83561707, 12.49267292], [92.83614349, 12.49246788], [92.83661652, 12.49189091], [92.83701324, 12.49151993], [92.83728027, 12.49102116], [92.83759308, 12.49057198], [92.83757019, 12.49011135], [92.83721924, 12.48916626], [92.83721924, 12.48888969], [92.83693695, 12.48860931], [92.83694458, 12.48805618], [92.83666992, 12.48777962], [92.83647919, 12.48701191], [92.83640289, 12.48666954], [92.83640289, 12.48639202], [92.83611298, 12.48612118], [92.83611298, 12.48583126], [92.83641815, 12.48527718], [92.83666992, 12.48500156], [92.83860779, 12.4830513], [92.83889008, 12.48305511], [92.83916473, 12.48277664], [92.83943939, 12.48277855], [92.83972168, 12.48250103], [92.83999634, 12.48250103], [92.84027863, 12.48222065], [92.84030151, 12.48184299], [92.84033966, 12.48155308], [92.84042358, 12.48140717], [92.84059143, 12.48124123], [92.84086609, 12.48112011], [92.84105682, 12.48106098], [92.84130859, 12.48101139], [92.84152222, 12.48099518], [92.8417511, 12.4809494], [92.84195709, 12.48085117], [92.84218597, 12.48069191], [92.8423233, 12.48048019], [92.842453, 12.48014927], [92.84262848, 12.47980118], [92.84333038, 12.47916889], [92.84333038, 12.47833061], [92.84305573, 12.47805691], [92.84306335, 12.47639084], [92.84249878, 12.47583008], [92.84249878, 12.47555542], [92.84221649, 12.47528076], [92.84221649, 12.47418022], [92.84194183, 12.47389126], [92.84194183, 12.47332954], [92.84166718, 12.47305679], [92.84166718, 12.47056103], [92.84361267, 12.46861172], [92.84361267, 12.46833038], [92.84388733, 12.46805573], [92.84388733, 12.46749973], [92.84416962, 12.46722031], [92.84416962, 12.46666622], [92.84443665, 12.46638966], [92.84443665, 12.46611023], [92.84500122, 12.46555614], [92.84500122, 12.46527958], [92.84583282, 12.46443939], [92.84583282, 12.46416569], [92.84638977, 12.4636097], [92.84638977, 12.46332932], [92.84666443, 12.46305561], [92.8466568, 12.46278], [92.84694672, 12.46249962], [92.84694672, 12.4619503], [92.84722137, 12.46166992], [92.84725189, 12.46143055], [92.84744263, 12.46115971], [92.84764099, 12.46081066], [92.84781647, 12.46043015], [92.84803009, 12.4601202], [92.84822845, 12.4598217], [92.8483963, 12.45950031], [92.84859467, 12.45920944], [92.84879303, 12.45890141], [92.84900665, 12.45861435], [92.84928131, 12.45833588], [92.849617, 12.45805073], [92.8500061, 12.45773602], [92.85031128, 12.45730114], [92.85063934, 12.45687008], [92.85101318, 12.45648098], [92.85135651, 12.45611572], [92.85173798, 12.45577621], [92.85215759, 12.45547104], [92.85256195, 12.45511055], [92.85295868, 12.45480824], [92.85337067, 12.45451355], [92.85379791, 12.45424938], [92.85423279, 12.45399189], [92.85470581, 12.45378017], [92.85517883, 12.45357895], [92.85562134, 12.45333958], [92.85601807, 12.45315456], [92.85640717, 12.45302963], [92.85674286, 12.45282936], [92.85707092, 12.45265388], [92.85744476, 12.45246029], [92.85782623, 12.45222092], [92.85824585, 12.45195198], [92.85871887, 12.45166016], [92.85920715, 12.45132065], [92.85968018, 12.45089722], [92.86022186, 12.45049953], [92.86074829, 12.45009232], [92.86122894, 12.44971371], [92.86164093, 12.44934177], [92.86197662, 12.44895935], [92.86228943, 12.44863319], [92.86257935, 12.44834232], [92.86283112, 12.44806767], [92.86309052, 12.44780159], [92.86338043, 12.44750977], [92.8637085, 12.44717026], [92.86400604, 12.44673538], [92.86437225, 12.44635201], [92.86472321, 12.44595146], [92.86506653, 12.44559479], [92.86543274, 12.4452877], [92.8658371, 12.44499969], [92.86625671, 12.4446907], [92.86669922, 12.44430065], [92.86720276, 12.4439106], [92.86775208, 12.44351006], [92.86830902, 12.44310665], [92.868927, 12.44278145], [92.86956787, 12.44249821], [92.87018585, 12.44221973], [92.87077332, 12.44194412], [92.87130737, 12.44166565], [92.8717804, 12.44139862], [92.87217712, 12.44118118], [92.87256622, 12.44102955], [92.87290955, 12.44084072], [92.87325287, 12.44066143], [92.87359619, 12.44058418], [92.87394714, 12.44065189], [92.87432861, 12.44079971], [92.87470245, 12.44087791], [92.87499237, 12.44108295], [92.8752594, 12.44126034], [92.87554932, 12.44151115], [92.8758316, 12.44185829], [92.87615204, 12.44227886], [92.87654114, 12.44260979], [92.87703705, 12.44241142], [92.87751007, 12.44194031], [92.87798309, 12.44147682], [92.87844086, 12.44107056], [92.87883759, 12.44062042], [92.87924957, 12.44020653], [92.8797226, 12.43983078], [92.88025665, 12.43946934], [92.88088989, 12.43919086], [92.88156891, 12.43895245], [92.88220215, 12.43860054], [92.88272095, 12.43813992], [92.88326263, 12.43775082], [92.88374329, 12.43738079], [92.8841629, 12.43707085], [92.88453674, 12.43684292], [92.88484955, 12.43664455], [92.88510895, 12.43642902], [92.88542175, 12.43625069], [92.88577271, 12.43606186], [92.88611603, 12.43583202], [92.88647461, 12.43558502], [92.88685608, 12.43535709], [92.8871994, 12.43509102], [92.88755798, 12.43480587], [92.88793182, 12.43456173], [92.88829803, 12.43430042], [92.88860321, 12.43400097], [92.88889313, 12.43367958], [92.88916779, 12.43338776], [92.88944244, 12.43312168], [92.88969421, 12.43287754], [92.88990784, 12.43260193], [92.89015961, 12.43233967], [92.89042664, 12.43204975], [92.89068604, 12.43169022], [92.89099121, 12.43134785], [92.89126587, 12.43099117], [92.8915863, 12.43071938], [92.89185333, 12.43037128], [92.89208984, 12.42999935], [92.89231873, 12.4296093], [92.89253998, 12.42922211], [92.89278412, 12.42884827], [92.89303589, 12.42848969], [92.89325714, 12.42813015], [92.89346313, 12.42780018], [92.89367676, 12.42752171], [92.89389801, 12.42725086], [92.89414978, 12.42695045], [92.89441681, 12.42658138], [92.8946991, 12.42614079], [92.89500427, 12.42572784], [92.89531708, 12.4253912], [92.8956604, 12.42513084], [92.89585876, 12.42475033], [92.89605713, 12.42432022], [92.89614105, 12.42374992], [92.89628601, 12.4231596], [92.89644623, 12.42259026], [92.89667511, 12.42210007], [92.89694214, 12.42166042], [92.8972168, 12.42123127], [92.89749908, 12.42079163], [92.89778137, 12.42034721], [92.89805603, 12.41987991], [92.89832306, 12.4193716], [92.89853668, 12.41882896], [92.8986969, 12.41827106], [92.89891815, 12.4177599], [92.89916229, 12.41730022], [92.89936066, 12.41685104], [92.89942169, 12.41638088], [92.89933014, 12.41593933], [92.89901733, 12.41562939], [92.89852142, 12.41546059], [92.89794922, 12.41526508], [92.89731598, 12.41505909], [92.89660645, 12.41504955], [92.89599609, 12.41534042], [92.89552307, 12.41574955], [92.89509583, 12.4161377], [92.89473724, 12.41653442], [92.89441681, 12.41695976], [92.89409637, 12.41742992], [92.89369202, 12.41788101], [92.89324188, 12.41834068], [92.89266968, 12.41866112], [92.89215088, 12.41896057], [92.89173126, 12.41926003], [92.89134979, 12.41956997], [92.89089966, 12.41980934], [92.89031982, 12.42002106], [92.88970947, 12.42027187], [92.88907623, 12.42048168], [92.88844299, 12.42063046], [92.88788605, 12.42088318], [92.88750458, 12.42131329], [92.88717651, 12.42175102], [92.88681793, 12.42213154], [92.88651276, 12.42261028], [92.88626099, 12.4229908], [92.88606262, 12.42314053], [92.885849, 12.42300034], [92.88559723, 12.4231596], [92.88535309, 12.42306232], [92.88500214, 12.42270756], [92.88463593, 12.42228031], [92.88428497, 12.42190647], [92.88401031, 12.42152977], [92.88367462, 12.42125225], [92.88339996, 12.42091942], [92.88305664, 12.42064095], [92.88273621, 12.42037201], [92.8824234, 12.42018986], [92.8819809, 12.42002964], [92.88179016, 12.41977024], [92.88154602, 12.41959], [92.88109589, 12.41948128], [92.88054657, 12.41941929], [92.8800354, 12.41930103], [92.87958527, 12.41912842], [92.87921906, 12.41889095], [92.87889862, 12.41862202], [92.87858582, 12.41834068], [92.87828064, 12.41805172], [92.87799835, 12.41769886], [92.87778473, 12.41725159], [92.87756348, 12.41674137], [92.87724304, 12.41629028], [92.87695313, 12.41578197], [92.87667084, 12.41523266], [92.87639618, 12.41468811], [92.87610626, 12.41419125], [92.87577057, 12.41379929], [92.87536621, 12.41364193], [92.87496948, 12.41372204], [92.87471771, 12.41410732], [92.87451172, 12.41457367], [92.87439728, 12.41508007], [92.8742218, 12.41553974], [92.87417603, 12.41602993], [92.8741684, 12.4165411], [92.87411499, 12.41706467], [92.87390137, 12.41757107], [92.87361908, 12.41810036], [92.87330627, 12.4186306], [92.87294006, 12.4191246], [92.87255096, 12.41955185], [92.87223816, 12.41998005], [92.87194824, 12.420331], [92.87165833, 12.42061138], [92.87135315, 12.42083931], [92.8710022, 12.42105961], [92.87056732, 12.42121983], [92.87013245, 12.42142105], [92.86972046, 12.42168045], [92.86929321, 12.42194462], [92.86886597, 12.42222118], [92.86844635, 12.42252064], [92.86806488, 12.42284966], [92.86772156, 12.42324162], [92.86736298, 12.42358112], [92.86698151, 12.42387962], [92.86672211, 12.42422199], [92.86653137, 12.42455673], [92.86628723, 12.4248209], [92.8660965, 12.42508125], [92.86585236, 12.4252882], [92.86559296, 12.42549992], [92.86528015, 12.4255619], [92.86499786, 12.42584038], [92.86305237, 12.42584038], [92.86277771, 12.4255619], [92.86165619, 12.4255619], [92.8611908, 12.42531109], [92.86077881, 12.42523098], [92.86013794, 12.42459965], [92.85996246, 12.42438984], [92.85975647, 12.4240799], [92.85962677, 12.42370892], [92.85938263, 12.42338085], [92.85901642, 12.42306232], [92.85858154, 12.4227972], [92.858078, 12.42255116], [92.85753632, 12.42240143], [92.85701752, 12.42230034], [92.85655212, 12.42242813], [92.85609436, 12.42253494], [92.85566711, 12.4227314], [92.85517883, 12.42289066], [92.85463715, 12.42308044], [92.85412598, 12.42333984], [92.85368347, 12.42362022], [92.85253906, 12.4243536], [92.85241699, 12.42417622], [92.85212708, 12.42413044], [92.85173798, 12.4239893], [92.85127258, 12.42389965], [92.8507843, 12.42388725], [92.85031891, 12.42384148], [92.84990692, 12.42365646], [92.84944916, 12.42361069], [92.84898376, 12.42361069], [92.84851074, 12.42361069], [92.84806824, 12.42361069], [92.84766388, 12.42361069], [92.84729004, 12.42358971], [92.84690857, 12.42348957], [92.84648895, 12.423419], [92.84613037, 12.42361069], [92.84577942, 12.42398453], [92.84537506, 12.42434502], [92.84507751, 12.4246912], [92.84486389, 12.4249258], [92.84464264, 12.42506886], [92.84429169, 12.42525578], [92.84391785, 12.4255209], [92.84352112, 12.42580605], [92.84313965, 12.4260807], [92.84307861, 12.42613602], [92.84278107, 12.42639065], [92.84249878, 12.42639065], [92.84221649, 12.42667198], [92.84194183, 12.42666721], [92.84139252, 12.42722321], [92.8408432, 12.4272213], [92.84027863, 12.4277792], [92.83999634, 12.4277792], [92.83944702, 12.42833328], [92.83889008, 12.42833328], [92.83860779, 12.42860889], [92.83860779, 12.42916679], [92.83833313, 12.42944527], [92.83833313, 12.42972088], [92.83805847, 12.42999935], [92.83750153, 12.43056202], [92.83750153, 12.43139172], [92.83693695, 12.43139172], [92.83583069, 12.43027973], [92.83444214, 12.43027973], [92.83416748, 12.43055534], [92.83384705, 12.43056393], [92.83347321, 12.43070126], [92.83309174, 12.43082047], [92.83269501, 12.43088627], [92.8323288, 12.4310503], [92.83188629, 12.43116188], [92.83142853, 12.43135071], [92.83090973, 12.43146896], [92.8303833, 12.43163109], [92.82981873, 12.43166828], [92.82929993, 12.43170166], [92.82884979, 12.4318409], [92.82840729, 12.43192959], [92.82795715, 12.43194771], [92.82750702, 12.43198395], [92.82711792, 12.4321394], [92.8266983, 12.43223095], [92.82628632, 12.43233109], [92.82589722, 12.43247032], [92.82546234, 12.43255043], [92.82506561, 12.43274593], [92.82463074, 12.4328804], [92.82420349, 12.43304634], [92.82375336, 12.43319225], [92.8236084, 12.43333435], [92.82333374, 12.43333435], [92.82195282, 12.43472195], [92.8216629, 12.43503189], [92.82178497, 12.4356699], [92.82167816, 12.43602085], [92.82131958, 12.43638992], [92.82080078, 12.43659973], [92.82006073, 12.43729496], [92.81955719, 12.43754101], [92.81890106, 12.43723106], [92.8184433, 12.4367981], [92.81822968, 12.43653107], [92.81846619, 12.43622112], [92.81906891, 12.43647194], [92.81942749, 12.43653107], [92.81984711, 12.43647194], [92.82073212, 12.43607998], [92.82080078, 12.43558788], [92.82055664, 12.43500042], [92.81999969, 12.43444061], [92.81868744, 12.43444443], [92.81865692, 12.43432999], [92.81861115, 12.43413353], [92.81865692, 12.43398094], [92.81867218, 12.43390083], [92.81869507, 12.4338026], [92.81842804, 12.43377972], [92.81793976, 12.43391037], [92.81777954, 12.43416977], [92.81723785, 12.43429089], [92.81673431, 12.434412], [92.81625366, 12.43444443], [92.81577301, 12.43444443], [92.81526947, 12.43444061], [92.81476593, 12.43446159], [92.8142395, 12.43453693], [92.81374359, 12.43473339], [92.81326294, 12.43498135], [92.81275177, 12.43516636], [92.81223297, 12.43529129], [92.81173706, 12.43546009], [92.81127167, 12.43555069], [92.81082916, 12.43560791], [92.81046295, 12.43579674], [92.81006622, 12.43592262], [92.80964661, 12.43615055], [92.80922699, 12.43653965], [92.80878448, 12.43706036], [92.80834961, 12.43762112], [92.80796051, 12.43813992], [92.80764771, 12.43855953], [92.80736542, 12.43889046], [92.8070755, 12.43918228], [92.8067627, 12.4394598], [92.80640411, 12.43972397], [92.80605316, 12.43994999], [92.80567932, 12.44011593], [92.80522919, 12.44015026], [92.80480194, 12.44024181], [92.80439758, 12.44040108], [92.80400848, 12.44030952], [92.80356598, 12.44020081], [92.80311584, 12.43999958], [92.80265808, 12.43976116], [92.80221558, 12.43955803], [92.80182648, 12.4393301], [92.80148315, 12.43901062], [92.8010025, 12.43875122], [92.80041504, 12.43859768], [92.79981995, 12.4384594], [92.79927063, 12.43834114], [92.79875183, 12.43823147], [92.7983017, 12.43805599], [92.79788208, 12.43790054], [92.7974472, 12.43782997], [92.79698944, 12.43787956], [92.79650879, 12.43795967], [92.79620361, 12.43825245], [92.7960968, 12.43873978], [92.79597473, 12.43932533], [92.79585266, 12.43995667], [92.79568481, 12.44059277], [92.79572296, 12.44124031], [92.79580688, 12.44175529], [92.79582977, 12.44223118], [92.79582977, 12.44272995], [92.79579926, 12.4432106], [92.79569244, 12.44371986], [92.79579163, 12.44428921], [92.79582977, 12.44487667], [92.79587555, 12.44546318], [92.79605103, 12.44602203], [92.7960968, 12.44666195], [92.79666901, 12.4477787], [92.79666901, 12.44833469], [92.79693604, 12.44861126], [92.79693604, 12.44889069], [92.79722595, 12.44916725], [92.79722595, 12.44944477], [92.79750061, 12.44972134], [92.79750061, 12.4500103], [92.7977829, 12.45028114], [92.79777527, 12.45055485], [92.79805756, 12.45083141], [92.79805756, 12.45111084], [92.79833221, 12.45139122], [92.79833221, 12.45166683], [92.7986145, 12.4519453], [92.79860687, 12.45222092], [92.79888916, 12.4525013], [92.7990799, 12.45351124], [92.79927063, 12.45399189], [92.79949188, 12.45437908], [92.79968262, 12.45477962], [92.79966736, 12.4552002], [92.79949951, 12.45557976], [92.7993927, 12.45601082], [92.79917908, 12.45637989], [92.79892731, 12.45676994], [92.7986908, 12.45723724], [92.79853821, 12.45790291], [92.79837799, 12.45851994], [92.79831696, 12.4590807], [92.79825592, 12.459548], [92.79811096, 12.45994854], [92.79798889, 12.46030045], [92.79786682, 12.46063995], [92.79785919, 12.46100044], [92.79799652, 12.46128941], [92.79846954, 12.46175003], [92.79889679, 12.4622097], [92.79944611, 12.46277809], [92.80000305, 12.46332932], [92.80000305, 12.4636097], [92.80027771, 12.46389008], [92.80027771, 12.46444416], [92.79888916, 12.46583366], [92.79833221, 12.46583366], [92.79805756, 12.46611214], [92.79750061, 12.46611023], [92.79722595, 12.46638966], [92.79666901, 12.46638966], [92.79638672, 12.46667099], [92.79611206, 12.46667099], [92.79442596, 12.46814728], [92.79416656, 12.46833038], [92.79364777, 12.46853924], [92.79310608, 12.46895027], [92.7926178, 12.46932125], [92.79225922, 12.46973133], [92.79165649, 12.47028065], [92.79109955, 12.46972179], [92.79109955, 12.46917057], [92.79138947, 12.46889019], [92.79138947, 12.46861172], [92.79165649, 12.46833038], [92.79250336, 12.4683342], [92.79277802, 12.46805573], [92.79305267, 12.46805573], [92.79360962, 12.46749973], [92.79383087, 12.46741104], [92.79421997, 12.46699047], [92.7946167, 12.46661091], [92.79508209, 12.46632195], [92.79556274, 12.46605968], [92.79602051, 12.46581841], [92.79646301, 12.46556091], [92.79689789, 12.46530342], [92.79732513, 12.46503162], [92.79776001, 12.46477032], [92.79817963, 12.46452141], [92.79846954, 12.46420002], [92.79846191, 12.46380138], [92.79824829, 12.46336079], [92.7979126, 12.46289158], [92.79756165, 12.46236134], [92.79722595, 12.46179104], [92.79693604, 12.46124172], [92.79666901, 12.46068954], [92.79650116, 12.46012497], [92.79663086, 12.45953178], [92.79677582, 12.45893097], [92.79697418, 12.45841789], [92.79720306, 12.45800114], [92.79738617, 12.45757008], [92.79750061, 12.4570961], [92.79759979, 12.45660114], [92.79773712, 12.45609283], [92.79777527, 12.45558453], [92.7977829, 12.45508957], [92.7977829, 12.45463657], [92.7978363, 12.45423985], [92.79805756, 12.45388889], [92.79805756, 12.45361137], [92.79750061, 12.45305538], [92.79750061, 12.4525013], [92.79722595, 12.45222092], [92.79722595, 12.45166683], [92.79666901, 12.45111084], [92.79666901, 12.45083141], [92.79638672, 12.45055485], [92.79638672, 12.45028114], [92.79611206, 12.4500103], [92.79611206, 12.44972134], [92.79582977, 12.44944477], [92.79582977, 12.44888878], [92.79556274, 12.44861126], [92.79555511, 12.44805527], [92.79444122, 12.44694042], [92.79444122, 12.44666672], [92.79416656, 12.44639111], [92.79416656, 12.44610977], [92.79416656, 12.44553185], [92.79416656, 12.44492054], [92.79412079, 12.4443512], [92.79393768, 12.44390202], [92.79389191, 12.44346046], [92.79387665, 12.44297886], [92.79386902, 12.44248676], [92.79377747, 12.44198132], [92.79364014, 12.44146061], [92.79360962, 12.44093704], [92.79360962, 12.4404192], [92.79360962, 12.43991089], [92.79366302, 12.43941021], [92.79386139, 12.43895245], [92.79400635, 12.43851185], [92.79419708, 12.43818092], [92.79441833, 12.43791008], [92.79463959, 12.43762112], [92.79499054, 12.43741131], [92.7953949, 12.43717575], [92.79579926, 12.43684959], [92.79623413, 12.43654537], [92.79677582, 12.43637943], [92.79734802, 12.43638134], [92.7979126, 12.43644238], [92.79840088, 12.43660355], [92.79881287, 12.43666553], [92.79917145, 12.43671989], [92.79949188, 12.4368906], [92.79991913, 12.43698025], [92.80039215, 12.43708706], [92.8008728, 12.43727016], [92.80134583, 12.4374609], [92.80185699, 12.43757057], [92.80232239, 12.43776035], [92.8028183, 12.43793106], [92.80335236, 12.43809891], [92.80388641, 12.43834114], [92.80446625, 12.43857956], [92.80509186, 12.4386692], [92.8057785, 12.43839073], [92.80632782, 12.43802166], [92.8066864, 12.43760681], [92.80696869, 12.43718147], [92.80729675, 12.4367609], [92.80770111, 12.43631172], [92.80817413, 12.43587875], [92.80869293, 12.43545341], [92.80914307, 12.43500423], [92.80950165, 12.43455505], [92.80989838, 12.43417931], [92.81030273, 12.43386936], [92.81072235, 12.43361187], [92.81112671, 12.43338108], [92.81163025, 12.43328953], [92.8121109, 12.4331007], [92.81260681, 12.4330101], [92.81310272, 12.43282986], [92.81363678, 12.43278027], [92.81420135, 12.43278027], [92.81476593, 12.43277073], [92.81532288, 12.43272972], [92.81581116, 12.43256092], [92.81630707, 12.43250942], [92.81680298, 12.43250179], [92.81729126, 12.43244934], [92.81777191, 12.43227196], [92.81830597, 12.4321804], [92.81886292, 12.43198013], [92.81946564, 12.43180943], [92.82009888, 12.43169022], [92.82074738, 12.43167019], [92.82137299, 12.43164921], [92.82195282, 12.43161488], [92.82245636, 12.43142414], [92.82296753, 12.43130302], [92.8234024, 12.43109989], [92.82380676, 12.43087196], [92.82427216, 12.43071938], [92.82470703, 12.43054199], [92.82514191, 12.43033409], [92.8256073, 12.43021107], [92.8259964, 12.42999172], [92.82637787, 12.42977142], [92.82678986, 12.42959976], [92.82720184, 12.42943192], [92.82758331, 12.42919922], [92.82800293, 12.42906857], [92.82836914, 12.42891026], [92.82888794, 12.42888927], [92.82917023, 12.42860889], [92.82944489, 12.4286108], [92.83027649, 12.4277792], [92.83026886, 12.42750072], [92.82888794, 12.42611122], [92.82888794, 12.42555523], [92.82861328, 12.42528057], [92.82861328, 12.42306232], [92.82888794, 12.42278099], [92.82888794, 12.42167091], [92.82917023, 12.42139053], [92.82917023, 12.42082977], [92.82944489, 12.42055416], [92.82943726, 12.42000103], [92.82994843, 12.4196701], [92.83053589, 12.4193306], [92.83084869, 12.41908741], [92.83123016, 12.41868973], [92.83198547, 12.41813564], [92.83242798, 12.41783142], [92.83286285, 12.4174118], [92.83305359, 12.41666603], [92.83304596, 12.41639137], [92.83333588, 12.41611004], [92.83333588, 12.41556072], [92.83361053, 12.4152813], [92.83361053, 12.41471958], [92.83388519, 12.41444397], [92.83388519, 12.41333199], [92.83416748, 12.41305637], [92.83416748, 12.41222191], [92.83444214, 12.41194439], [92.83444214, 12.4113903], [92.8347168, 12.41110992], [92.8347168, 12.41055965], [92.83389282, 12.40971947], [92.83388519, 12.40916634], [92.83416748, 12.40888977], [92.83472443, 12.40944386], [92.83555603, 12.40944386], [92.83583069, 12.40916634], [92.83640289, 12.40914059], [92.83692932, 12.40893841], [92.83751678, 12.40885067], [92.83807373, 12.40867805], [92.83864594, 12.40847969], [92.83925629, 12.4083004], [92.83982086, 12.40802193], [92.84030914, 12.40764141], [92.84076691, 12.40725994], [92.8411026, 12.40683174], [92.84137726, 12.40639019], [92.84159851, 12.40594769], [92.84166718, 12.40543938], [92.84172058, 12.40492439], [92.84185028, 12.40441799], [92.84168243, 12.40387058], [92.84146881, 12.4033289], [92.84125519, 12.40284348], [92.84096527, 12.4024744], [92.84055328, 12.4024992], [92.84055328, 12.4019413], [92.83999634, 12.40138912], [92.83999634, 12.40111065], [92.83972168, 12.40083122], [92.83972168, 12.40055466], [92.83943939, 12.40028191], [92.83943939, 12.40000057], [92.83889008, 12.3994379], [92.83889008, 12.39916706], [92.83833313, 12.39861107], [92.83833313, 12.39833069], [92.83805847, 12.39805698], [92.83833313, 12.39778137], [92.83833313, 12.39722061], [92.83860779, 12.396945], [92.83860779, 12.39638901], [92.83833313, 12.39611053], [92.83833313, 12.39583302], [92.83860779, 12.39555454], [92.83860779, 12.39500141], [92.83889008, 12.39472008], [92.83889008, 12.39444542], [92.83972168, 12.39361095], [92.83972168, 12.39332962], [92.84027863, 12.39277554], [92.84055328, 12.39277554], [92.84139252, 12.39194393], [92.84166718, 12.39194393], [92.84194183, 12.39166641], [92.84249878, 12.39167118], [92.84278107, 12.3913908], [92.84302521, 12.39140224], [92.84339905, 12.39134121], [92.84378815, 12.3911562], [92.84426117, 12.39100075], [92.8446579, 12.39073944], [92.84500122, 12.39036274], [92.84535217, 12.38995266], [92.84577179, 12.38961983], [92.846138, 12.38922977], [92.84648895, 12.38883972], [92.84671021, 12.38841915], [92.8469162, 12.3880024], [92.84706116, 12.38752079], [92.84723663, 12.38704014], [92.84748077, 12.38661766], [92.84767914, 12.38624001], [92.84790802, 12.38598919], [92.8481369, 12.38582039], [92.84838104, 12.38564491], [92.84866333, 12.38549042], [92.84893799, 12.38527107], [92.84921265, 12.38500023], [92.84947968, 12.3846693], [92.84970856, 12.3842411], [92.84984589, 12.38370132], [92.84978485, 12.38310814], [92.84977722, 12.38251972], [92.84997559, 12.38201237], [92.85012817, 12.38154316], [92.85029602, 12.38111877], [92.85051727, 12.38073063], [92.85071564, 12.38031864], [92.85098267, 12.37994003], [92.85118866, 12.37950993], [92.85144043, 12.37909889], [92.85167694, 12.37866402], [92.85193634, 12.37823963], [92.85223389, 12.37782955], [92.85256958, 12.37745094], [92.85296631, 12.37712097], [92.85331726, 12.37671471], [92.85372925, 12.37637329], [92.85413361, 12.3760128], [92.85450745, 12.37561703], [92.85489655, 12.37524986], [92.85527802, 12.37486172], [92.85564423, 12.37448597], [92.85604095, 12.37416267], [92.85642242, 12.37386036], [92.85677338, 12.37359142], [92.856987, 12.37331009], [92.8571167, 12.37307072], [92.85726166, 12.37289333], [92.85756683, 12.37294102], [92.85791779, 12.37291145], [92.85832214, 12.37275887], [92.85877228, 12.37248993], [92.85926056, 12.37213039], [92.85968781, 12.3716917], [92.86000824, 12.3710947], [92.86023712, 12.37042904], [92.86022949, 12.36971188], [92.86000061, 12.36905956], [92.85968018, 12.36849022], [92.85927582, 12.36806107], [92.85916901, 12.36806107], [92.85832977, 12.36721992], [92.85832977, 12.36694527], [92.85805511, 12.36666679], [92.85806274, 12.36639118], [92.85832977, 12.36610985], [92.85832977, 12.36583233], [92.85861206, 12.36555672], [92.85865021, 12.36515999], [92.8588562, 12.36470222], [92.8589859, 12.36422062], [92.85916138, 12.36377907], [92.85935974, 12.36334133], [92.85957336, 12.36292744], [92.85980225, 12.36254978], [92.86006927, 12.36224079], [92.86036682, 12.36198521], [92.86070251, 12.36179161], [92.86105347, 12.3616066], [92.86139679, 12.36141109], [92.86178589, 12.36127186], [92.86221313, 12.36118984], [92.86267853, 12.36135197], [92.86319733, 12.36145687], [92.86367798, 12.36162281], [92.86418152, 12.36166191], [92.8646698, 12.36169147], [92.86511993, 12.36180115], [92.86557007, 12.36192131], [92.86602783, 12.36194897], [92.86649323, 12.36200142], [92.86692047, 12.36216068], [92.86738586, 12.3621397], [92.86777496, 12.36220932], [92.86786652, 12.36221313], [92.86815643, 12.36222172], [92.86833191, 12.36222172], [92.8686142, 12.3619442], [92.86888885, 12.3619442], [92.86972046, 12.36110973], [92.86972046, 12.36083031], [92.87000275, 12.36055565], [92.87000275, 12.35888958], [92.86972046, 12.35861015], [92.86972046, 12.35750008], [92.87000275, 12.3572197], [92.87021637, 12.35687542], [92.87038422, 12.35656548], [92.87056732, 12.35627079], [92.87082672, 12.35595036], [92.87111664, 12.35553074], [92.87140656, 12.35505199], [92.87168121, 12.35458946], [92.87197113, 12.35422039], [92.87223816, 12.35392189], [92.87250519, 12.35369396], [92.87275696, 12.35351372], [92.87302399, 12.35336781], [92.87333679, 12.35333061], [92.873703, 12.35333061], [92.87404633, 12.35334969], [92.87442017, 12.35343933], [92.87479401, 12.35359955], [92.87523651, 12.35378265], [92.87571716, 12.35404205], [92.87621307, 12.35436153], [92.87677765, 12.3545208], [92.87718201, 12.35481071], [92.87745667, 12.35516167], [92.87766266, 12.35557175], [92.87782288, 12.35602093], [92.87800598, 12.35653114], [92.87812805, 12.35712242], [92.87851715, 12.35764122], [92.87918854, 12.35791016], [92.87973785, 12.35780525], [92.87991333, 12.35777092], [92.88046265, 12.35739136], [92.88082886, 12.35696888], [92.88111115, 12.35658073], [92.8813858, 12.35627365], [92.88166046, 12.35603428], [92.88194275, 12.3558569], [92.88224792, 12.3557806], [92.88260651, 12.35570908], [92.88301086, 12.35586071], [92.88349152, 12.35604095], [92.88401031, 12.35593033], [92.88446045, 12.35561085], [92.88485718, 12.35527992], [92.88520813, 12.3549614], [92.88548279, 12.35462093], [92.88564301, 12.35423183], [92.88580322, 12.35386944], [92.88583374, 12.35348034], [92.88582611, 12.35305977], [92.88582611, 12.35263157], [92.88587189, 12.35224724], [92.88607025, 12.35195923], [92.88629913, 12.35171127], [92.88637543, 12.35140991], [92.88650513, 12.3511343], [92.88673401, 12.3509407], [92.8870163, 12.35088062], [92.88733673, 12.35096073], [92.88771057, 12.35108185], [92.88813019, 12.35111237], [92.88860321, 12.35111237], [92.88912201, 12.35109138], [92.88961792, 12.35095024], [92.8899765, 12.35037994], [92.89025879, 12.34988976], [92.89045715, 12.3494997], [92.89045715, 12.34913063], [92.89029694, 12.3487711], [92.89015198, 12.34838963], [92.8899765, 12.34804153], [92.88986969, 12.34773827], [92.88999176, 12.34743118], [92.89019012, 12.34713173], [92.89041901, 12.34678078], [92.89077759, 12.34649563], [92.89103699, 12.34614086], [92.89111328, 12.34570122], [92.89115143, 12.34523106], [92.89131165, 12.34476376], [92.89142609, 12.34423542], [92.89138794, 12.34388924], [92.89193726, 12.3430624], [92.89193726, 12.34222126], [92.89221954, 12.34194469], [92.89305878, 12.34083271], [92.89499664, 12.33888912], [92.89499664, 12.33806133], [92.89527893, 12.33778095], [92.89527893, 12.33750057], [92.89554596, 12.33722019], [92.89555359, 12.33694363], [92.89583588, 12.33666611], [92.89583588, 12.33639145], [92.89611053, 12.33582973], [92.89555359, 12.33527756], [92.89499664, 12.33527756], [92.89444733, 12.33583355], [92.89417267, 12.33582973], [92.89305878, 12.33805656], [92.89277649, 12.33833027], [92.89277649, 12.33889103], [92.89250183, 12.33916664], [92.89250183, 12.33944035], [92.89167023, 12.34027863], [92.89141083, 12.34049511], [92.89103699, 12.34055042], [92.89058685, 12.34061241], [92.8901062, 12.34083462], [92.88960266, 12.34111118], [92.88912201, 12.34142113], [92.88874054, 12.34176922], [92.88851166, 12.34220028], [92.88832855, 12.34261036], [92.88813019, 12.34296131], [92.88792419, 12.34322834], [92.88777924, 12.34360886], [92.88748932, 12.34389114], [92.88582611, 12.34389114], [92.88560486, 12.3436594], [92.88527679, 12.34361076], [92.88500214, 12.34333324], [92.88475037, 12.34330273], [92.88409424, 12.34307766], [92.88366699, 12.34329033], [92.88333893, 12.34363842], [92.88301849, 12.34396362], [92.88262939, 12.34418488], [92.88246918, 12.34426308], [92.88223267, 12.34438133], [92.88182831, 12.34431267], [92.88144684, 12.34410954], [92.88116455, 12.34387779], [92.8809433, 12.34364986], [92.8807373, 12.34340954], [92.88070679, 12.34297276], [92.88058472, 12.34253502], [92.88054657, 12.34210014], [92.8805542, 12.341712], [92.8805542, 12.34134483], [92.88050079, 12.34101868], [92.88037109, 12.34075069], [92.88025665, 12.34043789], [92.88011932, 12.34010983], [92.88008118, 12.33975029], [92.88024139, 12.3393507], [92.88041687, 12.33885193], [92.88058472, 12.33831882], [92.88078308, 12.33778954], [92.88082886, 12.33716965], [92.88080597, 12.33652973], [92.88065338, 12.33590984], [92.88056946, 12.33528137], [92.88046265, 12.33468628], [92.88008118, 12.33420944], [92.87969208, 12.33383083], [92.87969208, 12.33353043], [92.87998199, 12.3334074], [92.88040161, 12.33348179], [92.88085938, 12.33370113], [92.88131714, 12.33393955], [92.88181305, 12.33404064], [92.88235474, 12.33410454], [92.88286591, 12.33399487], [92.88321686, 12.33368969], [92.88345337, 12.33343506], [92.88329315, 12.33308983], [92.88278961, 12.33271027], [92.88202667, 12.33248043], [92.8813858, 12.33222198], [92.88111115, 12.33222198], [92.88111115, 12.33166599], [92.88168335, 12.33111191], [92.88194275, 12.33111191], [92.8829422, 12.33154106], [92.88349915, 12.33193016], [92.88404083, 12.33218956], [92.88436127, 12.33205795], [92.88449097, 12.33200264], [92.88500977, 12.33194923], [92.88556671, 12.3319416], [92.88614655, 12.33195114], [92.88671875, 12.3319416], [92.88726044, 12.33187103], [92.88772583, 12.33166599], [92.88815308, 12.33141136], [92.88854218, 12.33113861], [92.88873291, 12.33068085], [92.88873291, 12.33003044], [92.8887558, 12.32941914], [92.88852692, 12.32909012], [92.88822174, 12.32885075], [92.88792419, 12.32861233], [92.88761139, 12.32835197], [92.88730621, 12.32808113], [92.88724518, 12.32769585], [92.88733673, 12.32730103], [92.88759613, 12.32694054], [92.88789368, 12.32655811], [92.88815308, 12.32602978], [92.88851166, 12.32560062], [92.88900757, 12.32529259], [92.889534, 12.32505608], [92.8900528, 12.32491112], [92.89048004, 12.32481861], [92.89081573, 12.32492733], [92.89115906, 12.32498074], [92.89154053, 12.32506084], [92.89196014, 12.32526398], [92.89245605, 12.32546043], [92.89307404, 12.32554626], [92.89367676, 12.32556152], [92.89422607, 12.32561016], [92.89472198, 12.32581997], [92.89521027, 12.32613182], [92.89572906, 12.32646275], [92.89631653, 12.32653999], [92.89679718, 12.32629204], [92.89700317, 12.32578087], [92.89694977, 12.32537079], [92.89676666, 12.32506084], [92.8965683, 12.32473087], [92.89636993, 12.32440186], [92.89622498, 12.32403088], [92.89611816, 12.32363033], [92.89599609, 12.32324696], [92.89581299, 12.3229208], [92.89563751, 12.32259274], [92.89556885, 12.32218933], [92.89554596, 12.32173061], [92.89552307, 12.32122993], [92.89539337, 12.32074165], [92.89511871, 12.32034492], [92.89476013, 12.32008076], [92.89432526, 12.32001495], [92.89386749, 12.32004166], [92.89342499, 12.32016087], [92.89293671, 12.320261], [92.89245605, 12.3203907], [92.89206696, 12.32063007], [92.89176941, 12.32091141], [92.89149475, 12.32116795], [92.8911972, 12.32118416], [92.89093781, 12.32110691], [92.89080811, 12.32106781], [92.89035034, 12.32088089], [92.88981628, 12.32080078], [92.88932037, 12.3209486], [92.88891602, 12.32125854], [92.88852692, 12.32165146], [92.88812256, 12.32205868], [92.88775635, 12.32248116], [92.88732147, 12.32279968], [92.88690948, 12.32308292], [92.88651276, 12.32329178], [92.88610077, 12.32333088], [92.88575745, 12.32322216], [92.88538361, 12.32302761], [92.88508606, 12.3227911], [92.8848114, 12.32256508], [92.88462067, 12.32224178], [92.88439941, 12.32189846], [92.8841629, 12.32148266], [92.88388062, 12.32098103], [92.88352203, 12.3204298], [92.88300323, 12.31995773], [92.88247681, 12.31957054], [92.88201904, 12.31923962], [92.88168335, 12.31889057], [92.88140869, 12.31849003], [92.88117981, 12.31805897], [92.8809433, 12.31760979], [92.88069153, 12.317173], [92.88051605, 12.31668091], [92.88037109, 12.31614971], [92.88012695, 12.3156004], [92.87979126, 12.31509876], [92.87934113, 12.31462002], [92.87888336, 12.31416035], [92.87845612, 12.31363106], [92.87812805, 12.3131752], [92.87787628, 12.31322098], [92.87756348, 12.31341934], [92.87722015, 12.31375027], [92.87683868, 12.31412983], [92.87637329, 12.31446075], [92.8758316, 12.31471062], [92.87523651, 12.31490993], [92.87464905, 12.31512356], [92.87423706, 12.31554985], [92.87390137, 12.31601143], [92.8736496, 12.31643677], [92.87354279, 12.31682014], [92.87336731, 12.31707859], [92.87323761, 12.31731033], [92.87303925, 12.31751919], [92.87277222, 12.317729], [92.87241364, 12.31776333], [92.87201691, 12.31767654], [92.87164307, 12.31747055], [92.87127686, 12.31719971], [92.87097931, 12.31689262], [92.87078094, 12.3164854], [92.87055206, 12.31608105], [92.87031555, 12.31565666], [92.87016296, 12.31516266], [92.86995697, 12.31466103], [92.86968994, 12.31427383], [92.86936188, 12.31399632], [92.86897278, 12.31388187], [92.86860657, 12.31377029], [92.86827087, 12.31371975], [92.86791229, 12.31386757], [92.86751556, 12.31400299], [92.86710358, 12.31418037], [92.86668396, 12.31441116], [92.86623383, 12.31458569], [92.86582184, 12.31464481], [92.86547852, 12.3144722], [92.86518097, 12.31433105], [92.86499023, 12.31416035], [92.86480713, 12.31396198], [92.86464691, 12.31374073], [92.86440277, 12.31359005], [92.86414337, 12.31341171], [92.86384583, 12.313241], [92.86348724, 12.31313229], [92.86307526, 12.31317997], [92.86271667, 12.31337357], [92.8622818, 12.31355953], [92.86190796, 12.31382656], [92.86146545, 12.31388378], [92.86101532, 12.31384468], [92.86060333, 12.31370163], [92.86011505, 12.31368446], [92.85958099, 12.31385231], [92.85909271, 12.31399059], [92.85862732, 12.31412792], [92.85818481, 12.31418514], [92.8577652, 12.31424427], [92.85739136, 12.31434441], [92.85701752, 12.31421947], [92.8565979, 12.31392956], [92.85609436, 12.31352901], [92.8555069, 12.31320858], [92.85492706, 12.31329155], [92.85473633, 12.31329441], [92.85437775, 12.31330109], [92.85388184, 12.31317997], [92.85346985, 12.31306076], [92.85312653, 12.31295872], [92.85286713, 12.31278992], [92.85262299, 12.31260967], [92.85234833, 12.31237125], [92.85198212, 12.31213093], [92.8515625, 12.31182766], [92.8511734, 12.31146145], [92.85077667, 12.31110096], [92.8504715, 12.31076622], [92.85015869, 12.31052017], [92.8499527, 12.31023121], [92.84973907, 12.30994129], [92.84959412, 12.30960178], [92.8494339, 12.30926704], [92.84924316, 12.30896091], [92.84905243, 12.30865097], [92.84879303, 12.30838013], [92.84841919, 12.30816078], [92.84793854, 12.30795193], [92.84736633, 12.30780792], [92.84671021, 12.30778122], [92.84599304, 12.30772972], [92.84529114, 12.30755043], [92.84451294, 12.30750275], [92.84373474, 12.30749798], [92.84298706, 12.30747128], [92.84233856, 12.30734062], [92.84173584, 12.30723953], [92.84118652, 12.30718613], [92.84073639, 12.30703068], [92.84030151, 12.30692101], [92.83989716, 12.30674076], [92.83946228, 12.30663872], [92.83904266, 12.30646133], [92.83857727, 12.30635166], [92.83815002, 12.30611038], [92.83768463, 12.30583191], [92.83719635, 12.3054924], [92.83678436, 12.30502319], [92.8363266, 12.30459023], [92.83580017, 12.30430889], [92.83526611, 12.30414963], [92.83477783, 12.30397034], [92.83430481, 12.3038578], [92.83390808, 12.30365086], [92.83361053, 12.30342102], [92.83332062, 12.30320644], [92.83302307, 12.30298996], [92.83272552, 12.30273724], [92.83242798, 12.3025589], [92.8320694, 12.30267525], [92.83168793, 12.30298328], [92.83132935, 12.30337048], [92.83094025, 12.30378056], [92.83053589, 12.30414772], [92.83008575, 12.30444431], [92.82965851, 12.30472183], [92.82926178, 12.3049984], [92.82887268, 12.3052597], [92.82846832, 12.30555153], [92.82801819, 12.30582142], [92.82752991, 12.30608654], [92.82706451, 12.30638123], [92.82660675, 12.30666161], [92.8261795, 12.30691528], [92.825737, 12.30709457], [92.82530975, 12.30728054], [92.82489777, 12.30750275], [92.82447052, 12.30773735], [92.82402802, 12.30792046], [92.82364655, 12.30812931], [92.82330322, 12.30836201], [92.82298279, 12.30860996], [92.82263184, 12.30883121], [92.82217407, 12.3089571], [92.82170105, 12.30914116], [92.82121277, 12.30927277], [92.82074738, 12.30951023], [92.82032776, 12.3097496], [92.81998444, 12.30999374], [92.819664, 12.31020641], [92.81929016, 12.31036091], [92.81887054, 12.31060028], [92.81842041, 12.31085968], [92.81794739, 12.31114006], [92.81742859, 12.31140041], [92.81684113, 12.31163502], [92.81616974, 12.31183147], [92.8156662, 12.31212044], [92.81552124, 12.31244087], [92.81533813, 12.31270123], [92.81504059, 12.31287003], [92.81472015, 12.31306076], [92.81433868, 12.31326199], [92.8138504, 12.31338692], [92.81331635, 12.31355953], [92.81272888, 12.31366539], [92.81220245, 12.31389332], [92.8117218, 12.31416416], [92.81125641, 12.31442165], [92.81078339, 12.31462002], [92.81022644, 12.31474113], [92.80969238, 12.31487083], [92.80914307, 12.31492138], [92.80861664, 12.3147707], [92.80809021, 12.31468201], [92.80762482, 12.31450558], [92.80715179, 12.31440067], [92.8067627, 12.31419182], [92.80635834, 12.31400013], [92.80591583, 12.31386375], [92.80545807, 12.31365585], [92.80490112, 12.31355953], [92.80434418, 12.31340981], [92.80374908, 12.31329155], [92.80323029, 12.31305695], [92.80271149, 12.3127718], [92.80222321, 12.31243229], [92.80185699, 12.31192207], [92.80139923, 12.31161594], [92.80094147, 12.31134129], [92.80054474, 12.31102371], [92.80018616, 12.31070042], [92.79995728, 12.31025791], [92.79971313, 12.30985165], [92.79944611, 12.30946541], [92.79915619, 12.30908203], [92.79885101, 12.30870056], [92.79850006, 12.30834961], [92.79811859, 12.30801964], [92.79775238, 12.30770111], [92.79734039, 12.30746078], [92.79696655, 12.30718136], [92.79659271, 12.30688858], [92.79618073, 12.30664063], [92.79579926, 12.30639267], [92.7954483, 12.30618095], [92.79509735, 12.30614376], [92.79476166, 12.30629158], [92.79444885, 12.30659103], [92.79418945, 12.30695057], [92.79403687, 12.30735016], [92.79389191, 12.30772114], [92.79373932, 12.30806065], [92.79358673, 12.30838013], [92.79341888, 12.30869007], [92.79328156, 12.30906105], [92.79306793, 12.30939198], [92.79286194, 12.3097496], [92.79263306, 12.3101387], [92.7923584, 12.31052017], [92.79199982, 12.31083012], [92.79160309, 12.31110096], [92.79117584, 12.3113308], [92.79083252, 12.31162071], [92.79042053, 12.31179047], [92.79003906, 12.31198978], [92.78965759, 12.31218243], [92.78919983, 12.31221962], [92.78874207, 12.31222343], [92.78827667, 12.31223202], [92.78784943, 12.31231785], [92.7874527, 12.31250954], [92.78707123, 12.31276703], [92.78665924, 12.31300354], [92.78620911, 12.31320858], [92.78566742, 12.31336021], [92.78509521, 12.31350613], [92.78450775, 12.31359482], [92.78390503, 12.31361294], [92.78329468, 12.31361294], [92.78272247, 12.31358814], [92.78222656, 12.31347179], [92.78177643, 12.3133297], [92.78139496, 12.31319618], [92.78100586, 12.31308174], [92.78057098, 12.31302929], [92.78011322, 12.31297684], [92.77958679, 12.31311131], [92.77909851, 12.31343079], [92.77867889, 12.3138504], [92.77822876, 12.31425953], [92.77773285, 12.31457043], [92.77719116, 12.3147707], [92.77671051, 12.31499863], [92.77627563, 12.31520367], [92.77581024, 12.31531143], [92.77540588, 12.31555939], [92.77490997, 12.3158102], [92.77429199, 12.31601143], [92.77374268, 12.31629086], [92.77339172, 12.31667137], [92.77327728, 12.31707859], [92.77320862, 12.31740093], [92.77333069, 12.31769943], [92.77345276, 12.31799126], [92.77334595, 12.31820107], [92.77310181, 12.31840134], [92.77277374, 12.31840801], [92.7724762, 12.31859112], [92.77220917, 12.31917191], [92.77189636, 12.31958199], [92.77152252, 12.3196907], [92.77114868, 12.319561], [92.7709198, 12.31937027], [92.77099609, 12.31916046], [92.77128601, 12.31885719], [92.77172852, 12.31844044], [92.77189636, 12.31807137], [92.7718811, 12.31775188], [92.77169037, 12.31747055], [92.77152252, 12.31707001], [92.77133179, 12.31662369], [92.7710495, 12.3161974], [92.7706604, 12.31582069], [92.77025604, 12.31544113], [92.76984406, 12.31511497], [92.76947021, 12.31480026], [92.76917267, 12.3144474], [92.76895905, 12.31404972], [92.76883698, 12.31359005], [92.76863098, 12.3132], [92.76850128, 12.31274891], [92.76838684, 12.31226635], [92.76825714, 12.31175137], [92.76808167, 12.31125164], [92.76792145, 12.31073189], [92.76764679, 12.31029034], [92.76734924, 12.30991173], [92.7671814, 12.3094511], [92.76703644, 12.3089571], [92.76692963, 12.30842972], [92.76677704, 12.30788136], [92.76663971, 12.30735207], [92.76643372, 12.30682278], [92.76638794, 12.30620098], [92.76638794, 12.30556965], [92.76634216, 12.30494118], [92.7661438, 12.30443287], [92.76598358, 12.30398083], [92.76582336, 12.30359173], [92.76560211, 12.30325031], [92.76541138, 12.30291939], [92.7652359, 12.30262089], [92.7650528, 12.30237007], [92.7648468, 12.30208969], [92.76463318, 12.3018589], [92.76435852, 12.3017292], [92.76403046, 12.30188179], [92.76370239, 12.30235195], [92.76361847, 12.3029604], [92.76357269, 12.30351162], [92.76345062, 12.30393124], [92.76335144, 12.30428886], [92.76332855, 12.30463982], [92.76329041, 12.30500031], [92.76313782, 12.30539036], [92.7631073, 12.30583191], [92.76326752, 12.30631065], [92.76332855, 12.30685139], [92.76338196, 12.30738163], [92.76358032, 12.30782795], [92.76370239, 12.30833435], [92.76379395, 12.30889511], [92.76387024, 12.30951023], [92.76394653, 12.31015968], [92.76418304, 12.31074142], [92.76442719, 12.31122017], [92.76461792, 12.31155014], [92.7645874, 12.31177998], [92.76442719, 12.31198788], [92.76420593, 12.31219101], [92.76393127, 12.31234074], [92.76364136, 12.31221962], [92.7633667, 12.31190109], [92.76315308, 12.31140709], [92.76304626, 12.31074142], [92.76283264, 12.31054974], [92.76255798, 12.31039047], [92.76229095, 12.31005955], [92.7620163, 12.30960178], [92.7617569, 12.30909061], [92.76158905, 12.30855083], [92.76138306, 12.30808067], [92.76117706, 12.30767822], [92.76101685, 12.30726147], [92.76081085, 12.30688], [92.76052094, 12.3064909], [92.76018524, 12.30614376], [92.7598114, 12.30583191], [92.75940704, 12.30552197], [92.75901794, 12.3052187], [92.75869751, 12.30482006], [92.75834656, 12.30441189], [92.75805664, 12.30394268], [92.75776672, 12.30346203], [92.7575531, 12.3030014], [92.75749969, 12.30246067], [92.75749969, 12.30194092], [92.75749969, 12.30142021], [92.75751495, 12.30088615], [92.75759125, 12.30035114], [92.75776672, 12.29983997], [92.75790405, 12.2993269], [92.75801086, 12.29887104], [92.75792694, 12.29840183], [92.75769806, 12.2979784], [92.7574234, 12.29757023], [92.75702667, 12.2972374], [92.75656128, 12.2969389], [92.75605011, 12.29663754], [92.75553894, 12.29626179], [92.75495148, 12.29593563], [92.75476837, 12.295681], [92.75418091, 12.29588127], [92.75353241, 12.29588127], [92.75322723, 12.2961092], [92.75300598, 12.2963829], [92.75276184, 12.29666996], [92.75244141, 12.2970047], [92.75203705, 12.29738998], [92.75160217, 12.29777527], [92.7512207, 12.29810143], [92.7509613, 12.29836082], [92.75076294, 12.29854965], [92.75052643, 12.29865932], [92.75032043, 12.29882145], [92.75006104, 12.29891014], [92.74982452, 12.29904938], [92.74957275, 12.29916954], [92.74928284, 12.29933167], [92.74897766, 12.2994957], [92.74868011, 12.29970646], [92.74832916, 12.29986095], [92.74794769, 12.29997921], [92.74751282, 12.29997921], [92.7470932, 12.29985142], [92.74668884, 12.29962063], [92.74635315, 12.2993412], [92.74591827, 12.29921055], [92.74545288, 12.29932022], [92.74500275, 12.2996006], [92.74453735, 12.29991531], [92.74411774, 12.30027103], [92.74369049, 12.30063057], [92.74331665, 12.30099106], [92.74294281, 12.30123711], [92.74256134, 12.30137157], [92.74217987, 12.30145359], [92.74185944, 12.30162239], [92.74156952, 12.30162239], [92.74128723, 12.30146122], [92.74091339, 12.30132198], [92.74051666, 12.30111027], [92.74009705, 12.30091095], [92.73963928, 12.30088234], [92.73919678, 12.30104256], [92.73876953, 12.30106354], [92.73836517, 12.30090714], [92.73792267, 12.30084133], [92.73745728, 12.30078125], [92.7370224, 12.30060959], [92.73651123, 12.30058098], [92.73596954, 12.30076122], [92.73557281, 12.30120087], [92.73527527, 12.30166626], [92.7352829, 12.30221939], [92.73500061, 12.30251122], [92.73500061, 12.30278015], [92.73555756, 12.30527973], [92.73640442, 12.30693531], [92.73639679, 12.30831242], [92.73597717, 12.30873108], [92.73557281, 12.30859184], [92.7352829, 12.30666161], [92.73472595, 12.30583191], [92.73444366, 12.3055563], [92.73443604, 12.30443859], [92.73416901, 12.30416584], [92.73417664, 12.30360985], [92.73249817, 12.30194378], [92.73213196, 12.30194092], [92.73171997, 12.30204868], [92.7313385, 12.30224037], [92.73139191, 12.30251122], [92.73110962, 12.30251122], [92.73082733, 12.30278015], [92.72915649, 12.30278015], [92.72888947, 12.30251122], [92.72860718, 12.30251122], [92.72833252, 12.30278015], [92.72750092, 12.30194092], [92.72638702, 12.30194378], [92.72568512, 12.30185318], [92.72480011, 12.30173588], [92.72389221, 12.30167007], [92.7233429, 12.30111027], [92.72305298, 12.30111217], [92.72277832, 12.3008337], [92.72250366, 12.3008337], [92.72222137, 12.30055618], [92.72194672, 12.30056], [92.7216568, 12.30027962], [92.72110748, 12.30027771], [92.7204361, 12.30031013], [92.71980286, 12.30056], [92.7191391, 12.3008976], [92.71871185, 12.3014698], [92.71866608, 12.30221939], [92.71887207, 12.30278015], [92.71904755, 12.30321503], [92.71916199, 12.30355072], [92.7191925, 12.30388069], [92.71910095, 12.30422115], [92.71888733, 12.30455112], [92.71861267, 12.30486965], [92.71833801, 12.30520058], [92.7181015, 12.30558109], [92.71800995, 12.30606937], [92.71781921, 12.30649281], [92.71773529, 12.30690289], [92.71755981, 12.30718136], [92.71740723, 12.30747128], [92.71720886, 12.3077507], [92.71695709, 12.30805016], [92.71675873, 12.30842113], [92.71663666, 12.30884266], [92.71640778, 12.30914593], [92.71617889, 12.3094101], [92.71604919, 12.3097496], [92.71586609, 12.31005096], [92.71583557, 12.31042671], [92.71578217, 12.31079102], [92.71561432, 12.31108761], [92.71554565, 12.31139469], [92.71546173, 12.31164074], [92.71529388, 12.31182098], [92.71508026, 12.31200218], [92.71482086, 12.31221962], [92.71450043, 12.31242085], [92.71411896, 12.31249237], [92.71373749, 12.31243038], [92.71338654, 12.31221771], [92.71305084, 12.31191921], [92.71276093, 12.31152058], [92.71250153, 12.31112003], [92.71222687, 12.3107214], [92.71201324, 12.31032181], [92.71187592, 12.30992126], [92.71166992, 12.30965614], [92.71140289, 12.30952168], [92.71089935, 12.30997086], [92.71038818, 12.31056118], [92.71015167, 12.31111526], [92.70999146, 12.31153393], [92.70981598, 12.31183147], [92.70974731, 12.31214714], [92.70967102, 12.31246376], [92.7095108, 12.31274223], [92.7094574, 12.31306076], [92.70942688, 12.31340122], [92.7093277, 12.31372929], [92.70916748, 12.31410122], [92.708992, 12.3144989], [92.70883942, 12.31488705], [92.70863342, 12.31518269], [92.70842743, 12.31544971], [92.7081604, 12.31572056], [92.70778656, 12.31605244], [92.70738983, 12.31655121], [92.70726013, 12.31731033], [92.7072525, 12.31806183], [92.7073288, 12.31869125], [92.7074585, 12.31921959], [92.70743561, 12.31973743], [92.70728302, 12.32031059], [92.70729828, 12.3209219], [92.7074585, 12.32150078], [92.70749664, 12.32207108], [92.70749664, 12.3226614], [92.70749664, 12.32329178], [92.70751953, 12.32394886], [92.70768738, 12.32460976], [92.70796967, 12.32520008], [92.70835876, 12.32563114], [92.70863342, 12.32612133], [92.70889282, 12.326581], [92.70908356, 12.32703018], [92.70915222, 12.32746124], [92.7091217, 12.32783031], [92.70895386, 12.32813644], [92.7088089, 12.32839108], [92.70862579, 12.32859993], [92.70841217, 12.32883072], [92.70804596, 12.32914066], [92.70753479, 12.3294096], [92.70694733, 12.32972431], [92.70632935, 12.33006096], [92.70571899, 12.33036518], [92.70514679, 12.33048534], [92.70492554, 12.33040142], [92.70464325, 12.33029556], [92.70414734, 12.33007145], [92.70372009, 12.32978058], [92.70346832, 12.32929993], [92.70330811, 12.32870102], [92.70305634, 12.32818127], [92.70278168, 12.32774067], [92.70249176, 12.32735157], [92.70217896, 12.32700729], [92.70178986, 12.32670021], [92.70128632, 12.32648754], [92.70069122, 12.32643127], [92.70011902, 12.32662201], [92.69975281, 12.32713032], [92.69950867, 12.32779121], [92.69944763, 12.3284874], [92.69944, 12.3291111], [92.69944763, 12.32968998], [92.69947815, 12.33025074], [92.69962311, 12.33076096], [92.69976807, 12.33125114], [92.69997406, 12.33165932], [92.70016479, 12.33203316], [92.70031738, 12.33241272], [92.70046234, 12.33281231], [92.70053101, 12.33327961], [92.70054626, 12.33383083], [92.70056152, 12.33441925], [92.7006073, 12.33502102], [92.70079041, 12.33557892], [92.70082092, 12.33615971], [92.70083618, 12.33675957], [92.70083618, 12.33735466], [92.70083618, 12.3379631], [92.70083618, 12.33980179], [92.70083618, 12.34041595], [92.70083618, 12.34101868], [92.70083618, 12.34162998], [92.70082855, 12.34222698], [92.70078278, 12.34282017], [92.7006073, 12.34340096], [92.70055389, 12.34403896], [92.70054626, 12.34469986], [92.70066071, 12.34535027], [92.70089722, 12.34593105], [92.70108032, 12.34650135], [92.70111084, 12.34709263], [92.70111084, 12.34769058], [92.70111084, 12.34830093], [92.70105743, 12.34890079], [92.70088196, 12.34947968], [92.70083618, 12.35009003], [92.70083618, 12.35068989], [92.70082855, 12.35127258], [92.70079041, 12.35181999], [92.70062256, 12.35232162], [92.70049286, 12.35282993], [92.70032501, 12.3533287], [92.70033264, 12.3538599], [92.7004776, 12.35435009], [92.70069885, 12.35479546], [92.7008667, 12.35527134], [92.70110321, 12.35568142], [92.70132446, 12.35608482], [92.70143127, 12.35654259], [92.70162201, 12.3570013], [92.70166016, 12.3575201], [92.70162201, 12.35806274], [92.70144653, 12.35860062], [92.70142365, 12.35915947], [92.70152283, 12.35972881], [92.70157623, 12.36030293], [92.70139313, 12.36085033], [92.70110321, 12.36139965], [92.70079803, 12.36195087], [92.70052338, 12.36250019], [92.70027161, 12.36304092], [92.70005035, 12.36360073], [92.69999695, 12.36425114], [92.69999695, 12.36492062], [92.70001221, 12.36557007], [92.7000885, 12.36616993], [92.70027161, 12.36668015], [92.70048523, 12.3671484], [92.70075226, 12.36759377], [92.70102692, 12.36802006], [92.70137024, 12.36839199], [92.70170593, 12.36870193], [92.70211029, 12.36885166], [92.70256805, 12.36881065], [92.70304871, 12.36864853], [92.70355988, 12.36861992], [92.70402527, 12.36868572], [92.70437622, 12.36888027], [92.70465851, 12.36909199], [92.70491791, 12.36923504], [92.70510864, 12.36942196], [92.70529175, 12.36961079], [92.70546722, 12.36979961], [92.70553589, 12.37004185], [92.70555878, 12.37029266], [92.70555878, 12.37055016], [92.70552063, 12.3707962], [92.70535278, 12.37101269], [92.70504761, 12.37122726], [92.70471191, 12.3715353], [92.70433044, 12.37189484], [92.70391083, 12.37224579], [92.70362091, 12.37268639], [92.70341492, 12.37317371], [92.70329285, 12.37374115], [92.70310211, 12.37434483], [92.70305634, 12.37506104], [92.70310974, 12.37578964], [92.70333099, 12.37638474], [92.70353699, 12.37690163], [92.70361328, 12.37737179], [92.70355988, 12.37777996], [92.70334625, 12.37809181], [92.70313263, 12.37839985], [92.70291901, 12.37872791], [92.70261383, 12.3790102], [92.70223236, 12.37914467], [92.70181274, 12.37914467], [92.70139313, 12.37903118], [92.70095825, 12.37886047], [92.70050812, 12.37865925], [92.70001221, 12.37867069], [92.69957733, 12.37898064], [92.69933319, 12.37948036], [92.69918823, 12.38004112], [92.69916534, 12.38061333], [92.69921112, 12.3811512], [92.69937897, 12.3816309], [92.69944, 12.38210106], [92.69944763, 12.38256073], [92.69944763, 12.38300991], [92.69944763, 12.38346386], [92.69944763, 12.38391972], [92.69941711, 12.3843708], [92.69928741, 12.38474655], [92.69917297, 12.38500023], [92.69916534, 12.38555622], [92.69889069, 12.38583374], [92.69889069, 12.38694382], [92.6986084, 12.38722038], [92.6986084, 12.38778114], [92.69832611, 12.38806057], [92.69832611, 12.38861179], [92.69806671, 12.38889027], [92.69805908, 12.38916588], [92.69777679, 12.38943958], [92.69777679, 12.39000034], [92.69805908, 12.39027786], [92.69806671, 12.39083004], [92.69832611, 12.39167118], [92.69828033, 12.39184856], [92.69832611, 12.39240932], [92.69832611, 12.39299107], [92.69833374, 12.39359665], [92.69832611, 12.39426041], [92.69832611, 12.39497089], [92.69833374, 12.39985085], [92.69833374, 12.40031338], [92.69832611, 12.40073967], [92.69833374, 12.40112877], [92.69835663, 12.40147114], [92.69844055, 12.40175629], [92.69857788, 12.40202522], [92.6986084, 12.40234184], [92.69861603, 12.40270424], [92.69863892, 12.40310097], [92.69877625, 12.40351772], [92.69888306, 12.40398121], [92.69894409, 12.40448856], [92.69917297, 12.40497017], [92.69944, 12.40549183], [92.69972229, 12.40602016], [92.69999695, 12.40651703], [92.70025635, 12.40695], [92.70043182, 12.40738106], [92.70053101, 12.40781021], [92.70056152, 12.40825939], [92.70055389, 12.40872288], [92.70052338, 12.40916061], [92.70033264, 12.40950489], [92.70015717, 12.40981102], [92.69999695, 12.41012096], [92.69985199, 12.41044044], [92.69972229, 12.41081142], [92.69960022, 12.41123104], [92.69947815, 12.41168022], [92.69941711, 12.41217041], [92.69930267, 12.41264057], [92.69919586, 12.41309929], [92.69917297, 12.41357994], [92.69916534, 12.41404819], [92.69916534, 12.41450977], [92.69916534, 12.41496372], [92.69917297, 12.41540146], [92.69915009, 12.41582108], [92.69905853, 12.41620064], [92.69892883, 12.4165802], [92.69889069, 12.41699028], [92.69888306, 12.4174118], [92.69880676, 12.41783142], [92.69863892, 12.41818047], [92.69850922, 12.41855812], [92.69837189, 12.41891098], [92.69832611, 12.41928959], [92.69832611, 12.41966057], [92.69833374, 12.41998672], [92.69831848, 12.4202919], [92.69823456, 12.42060471], [92.6980896, 12.42098999], [92.69812012, 12.42141819], [92.69835663, 12.42185974], [92.69848633, 12.42239094], [92.69851685, 12.4229908], [92.69880676, 12.42357922], [92.69888306, 12.42410278], [92.6988678, 12.42451286], [92.69877625, 12.42484188], [92.69871521, 12.42520809], [92.69869232, 12.4256506], [92.69882965, 12.42607021], [92.69896698, 12.42646027], [92.6991806, 12.42674923], [92.69944, 12.42699337], [92.69970703, 12.42725086], [92.69995117, 12.42757034], [92.70011139, 12.42792988], [92.70031738, 12.42820072], [92.70042419, 12.42849731], [92.70053101, 12.42877102], [92.70059967, 12.42910957], [92.70059204, 12.42956161], [92.70061493, 12.43010044], [92.70083618, 12.43063068], [92.70110321, 12.43119144], [92.70136261, 12.43172455], [92.70159149, 12.43225098], [92.70178223, 12.43275928], [92.70197296, 12.43321705], [92.70217896, 12.43362141], [92.70236206, 12.43399906], [92.7024765, 12.43435001], [92.70256805, 12.43470097], [92.70269775, 12.43504143], [92.70279694, 12.43540096], [92.70291138, 12.43574905], [92.70300293, 12.43609142], [92.70304108, 12.43642902], [92.70304871, 12.43676376], [92.70305634, 12.43710995], [92.70313263, 12.43748379], [92.70321655, 12.43789196], [92.70327759, 12.43833447], [92.70329285, 12.43878269], [92.70326233, 12.4392004], [92.70308685, 12.43955994], [92.70302582, 12.43991089], [92.70298004, 12.44021702], [92.70289612, 12.44048977], [92.70279694, 12.44074535], [92.70272827, 12.44101048], [92.70262909, 12.4412899], [92.70250702, 12.44159126], [92.70238495, 12.44192791], [92.70223999, 12.44229126], [92.70209503, 12.44268036], [92.70197296, 12.44309139], [92.70194244, 12.44355965], [92.70194244, 12.44401073], [92.70194244, 12.44445133], [92.70192719, 12.44489956], [92.70194244, 12.44540596], [92.70198822, 12.44599247], [92.70222473, 12.44659424], [92.70256042, 12.44720173], [92.70310974, 12.4475832], [92.7039032, 12.44738674], [92.70439911, 12.44750118], [92.70468903, 12.44779015], [92.70484924, 12.44822788], [92.70497894, 12.44878387], [92.70527649, 12.44912148], [92.7056427, 12.44944], [92.70594788, 12.44974136], [92.70617676, 12.45005131], [92.70632935, 12.45036793], [92.70641327, 12.45068932], [92.70652771, 12.45101547], [92.70659637, 12.45135021], [92.70661163, 12.45168972], [92.70654297, 12.45201111], [92.70641327, 12.45230961], [92.70627594, 12.452631], [92.70611572, 12.45295525], [92.70596313, 12.4532814], [92.70578003, 12.45359135], [92.70553589, 12.45388889], [92.70522308, 12.45430183], [92.70497894, 12.45503139], [92.70510864, 12.45570087], [92.70532227, 12.45618629], [92.70539093, 12.4565897], [92.7053299, 12.4569664], [92.70516968, 12.4573307], [92.70491791, 12.45767021], [92.70456696, 12.45795059], [92.7041626, 12.45817184], [92.70372009, 12.45836067], [92.70330811, 12.45862484], [92.70297241, 12.45900059], [92.70279694, 12.45953178], [92.70276642, 12.46011829], [92.70276642, 12.46071529], [92.70275879, 12.46130085], [92.70271301, 12.46184063], [92.70262146, 12.46230125], [92.70250702, 12.46267986], [92.70243835, 12.46299171], [92.70233917, 12.46327686], [92.70223236, 12.46355534], [92.70213318, 12.46385956], [92.70202637, 12.46419144], [92.70192719, 12.46452141], [92.70182037, 12.46481991], [92.70168304, 12.46509838], [92.7015152, 12.46539402], [92.7012558, 12.46570015], [92.7009201, 12.46603012], [92.70049286, 12.46632195], [92.7000351, 12.46662045], [92.69970703, 12.46703529], [92.69950867, 12.46747017], [92.69963837, 12.46798134], [92.69982147, 12.46850967], [92.70011902, 12.46888828], [92.70043182, 12.4692297], [92.70069122, 12.46959019], [92.70085907, 12.46995926], [92.7009964, 12.47033119], [92.70111847, 12.47071838], [92.70123291, 12.47111034], [92.70131683, 12.4715414], [92.70140076, 12.47193146], [92.70152283, 12.47227001], [92.70159912, 12.47257805], [92.70163727, 12.4728899], [92.70166016, 12.47322083], [92.70170593, 12.4735508], [92.70186615, 12.47383785], [92.70192719, 12.47412968], [92.70194244, 12.4744606], [92.70194244, 12.47482109], [92.70194244, 12.47523594], [92.70198059, 12.47570038], [92.70218658, 12.47620201], [92.70233154, 12.47676945], [92.70250702, 12.47733021], [92.70272064, 12.47786999], [92.70290375, 12.47842216], [92.70305634, 12.47896385], [92.70318604, 12.47945023], [92.70326233, 12.47988033], [92.70329285, 12.48023796], [92.70329285, 12.48054981], [92.70329285, 12.48083115], [92.70329285, 12.48110008], [92.70330811, 12.48137093], [92.70332336, 12.48168087], [92.70333099, 12.48204994], [92.70333099, 12.48253059], [92.70333099, 12.48312092], [92.70336151, 12.48379421], [92.70353699, 12.48447132], [92.70376587, 12.48515034], [92.70410919, 12.48573971], [92.70456696, 12.4861908], [92.70502472, 12.48659706], [92.70545959, 12.48698235], [92.70582581, 12.48739243], [92.70614624, 12.48782063], [92.70641327, 12.48827171], [92.70666504, 12.4886961], [92.70688629, 12.48909855], [92.70709991, 12.48950958], [92.70726776, 12.48990917], [92.70750427, 12.49025345], [92.70772552, 12.49058533], [92.70791626, 12.49091053], [92.70809174, 12.4912672], [92.70829773, 12.49157238], [92.70842743, 12.49193001], [92.70853424, 12.49230862], [92.70860291, 12.49269104], [92.70861816, 12.49308109], [92.70857239, 12.49344635], [92.70845795, 12.49378967], [92.70823669, 12.49413013], [92.70793915, 12.49444199], [92.70758057, 12.49476147], [92.70722961, 12.49515057], [92.70689392, 12.49556541], [92.70661163, 12.49602985], [92.70633698, 12.49652004], [92.70609283, 12.49701023], [92.70582581, 12.49748039], [92.70555115, 12.49788094], [92.70524597, 12.49821091], [92.70491791, 12.49843025], [92.70456696, 12.49853134], [92.704216, 12.49853134], [92.70384979, 12.49850082], [92.70346832, 12.49850082], [92.70310211, 12.49862194], [92.70276642, 12.4988699], [92.7024765, 12.49918938], [92.70214844, 12.49946499], [92.70188141, 12.49978161], [92.70163727, 12.50012398], [92.70143127, 12.50053215], [92.7013855, 12.50108337], [92.70139313, 12.50166035], [92.70137787, 12.50222015], [92.70134735, 12.50275612], [92.7012558, 12.50328922], [92.70115662, 12.50387096], [92.7011261, 12.50447178], [92.70124817, 12.50506496], [92.70136261, 12.50564098], [92.70140839, 12.50619793], [92.70153809, 12.50668335], [92.70166016, 12.5071497], [92.70173645, 12.50764275], [92.70175934, 12.50815105], [92.70170593, 12.50868034], [92.70163727, 12.50918961], [92.70156097, 12.50964832], [92.7014389, 12.51004028], [92.7013092, 12.5104208], [92.7011261, 12.51076984], [92.70082092, 12.51109123], [92.70044708, 12.51136875], [92.69998932, 12.51160431], [92.69946289, 12.51177025], [92.69883728, 12.51187038], [92.69815063, 12.51191998], [92.69740295, 12.51198196], [92.69664001, 12.51222992], [92.69592285, 12.51260185], [92.69535828, 12.51314735], [92.69496155, 12.51379395], [92.69455719, 12.5142107], [92.69426727, 12.51475811], [92.6942215, 12.51566124], [92.69461823, 12.51615334], [92.69476318, 12.516572], [92.6949234, 12.5169096], [92.69503784, 12.51723099], [92.69521332, 12.51756096], [92.69477081, 12.51825619], [92.69468689, 12.51906109], [92.69468689, 12.51954174], [92.69475555, 12.51992893], [92.69496155, 12.52007103], [92.69576263, 12.52049541], [92.69615936, 12.52078247], [92.69651031, 12.52101421], [92.6966629, 12.52110958], [92.69721985, 12.52166557], [92.69721985, 12.52221966], [92.69727325, 12.52311134], [92.69745636, 12.52369022], [92.69766998, 12.52432823], [92.69773102, 12.52482033], [92.69768524, 12.52519608], [92.69756317, 12.52571201], [92.69758606, 12.52628994], [92.69761658, 12.52656174], [92.69783783, 12.52683067], [92.69818878, 12.52711964], [92.6986084, 12.52750111], [92.69889069, 12.52778053], [92.69889069, 12.52805424], [92.69916534, 12.52833271], [92.69917297, 12.52861118], [92.69944763, 12.52889061], [92.69944763, 12.53000069], [92.69972229, 12.53028107], [92.6996994, 12.53273582], [92.69992828, 12.53321171], [92.70009613, 12.53379059], [92.70007324, 12.53451443], [92.69995117, 12.53477955], [92.69972229, 12.53490067], [92.69935608, 12.53482056], [92.69900513, 12.5349493], [92.69900513, 12.5354023], [92.69892883, 12.53600025], [92.69895172, 12.53633022], [92.69890594, 12.53695011], [92.6988678, 12.53755188], [92.69892883, 12.53856087], [92.69896698, 12.53918076], [92.69901276, 12.53973961], [92.69914246, 12.54014111], [92.69933319, 12.54045963], [92.69950104, 12.54076958], [92.69970703, 12.54117966], [92.69983673, 12.54163837], [92.69999695, 12.5420208], [92.70021057, 12.54253197], [92.70027924, 12.54285717], [92.70029449, 12.54329109], [92.70036316, 12.54370308], [92.70049286, 12.54395103], [92.700737, 12.54421997], [92.70082092, 12.54461479], [92.70102692, 12.54517078], [92.70130157, 12.54568768], [92.70152283, 12.54586983], [92.70191193, 12.54602146], [92.70235443, 12.54628754], [92.70281219, 12.54644489], [92.70348358, 12.54607296], [92.70407104, 12.54579544], [92.70449066, 12.54580021], [92.70480347, 12.54585934], [92.70506287, 12.54598045], [92.70526123, 12.54614162], [92.70543671, 12.54633999], [92.7056427, 12.54656124], [92.70585632, 12.54680538], [92.70612335, 12.54708958], [92.70648193, 12.54736996], [92.70675659, 12.54766178], [92.70667267, 12.54802036], [92.70630646, 12.54790974], [92.70584106, 12.54773045], [92.70535278, 12.54754066], [92.70493317, 12.54731083], [92.70449829, 12.54713345], [92.70391083, 12.54705334], [92.70346069, 12.54722023], [92.70339203, 12.54747963], [92.70360565, 12.54784393], [92.70378113, 12.54886055], [92.70384216, 12.54908943], [92.7039032, 12.54927063], [92.70409393, 12.54946041], [92.70448303, 12.54977036], [92.70464325, 12.55023003], [92.70497894, 12.55053997], [92.705513, 12.55089092], [92.70572662, 12.55153179], [92.70594025, 12.55208588], [92.70606995, 12.55239582], [92.70623779, 12.55262089], [92.70644379, 12.55284882], [92.70659637, 12.55296993], [92.70684814, 12.55305672], [92.7069931, 12.5532589], [92.70736694, 12.55379963], [92.70761871, 12.55422974], [92.70783234, 12.55469131], [92.70797729, 12.55506039], [92.70820618, 12.55543137], [92.70863342, 12.55579185], [92.70884705, 12.55624104], [92.70889282, 12.55674171], [92.70889282, 12.5572319], [92.70889282, 12.55771065], [92.70889282, 12.55815029], [92.70889282, 12.55875015], [92.70870209, 12.55908012], [92.70847321, 12.55936527], [92.70822144, 12.55963421], [92.70793152, 12.55992413], [92.70774078, 12.56021976], [92.70767975, 12.56072998], [92.70778656, 12.5610199], [92.70774841, 12.56166935], [92.7074585, 12.56199074], [92.70716095, 12.56225967], [92.70683289, 12.56250095], [92.70646667, 12.56270885], [92.70613098, 12.56296158], [92.70584106, 12.56325054], [92.70559692, 12.56352901], [92.70543671, 12.56383038], [92.70526886, 12.56407166], [92.70506287, 12.5642786], [92.70490265, 12.56462097], [92.70482635, 12.56534958], [92.70481873, 12.56580639], [92.70481873, 12.56626225], [92.70495605, 12.56689072], [92.70513916, 12.56738091], [92.7052536, 12.56788921], [92.70529175, 12.56844139], [92.7053833, 12.56896687], [92.70555878, 12.56944084], [92.70667267, 12.57056046], [92.70694733, 12.57056046], [92.70777893, 12.57139015], [92.70777893, 12.57166576], [92.70804596, 12.57194233], [92.70804596, 12.57250023], [92.70833588, 12.57277966], [92.70833588, 12.57333374], [92.70805359, 12.57361221], [92.70804596, 12.57472038], [92.70833588, 12.57500172], [92.70833588, 12.57528019], [92.70861053, 12.57556057], [92.70861053, 12.57610989], [92.70777893, 12.57694435], [92.70742035, 12.5771904], [92.70701599, 12.57731056], [92.70658875, 12.5774889], [92.7061615, 12.57767963], [92.70584106, 12.57800198], [92.70555115, 12.57818031], [92.70519257, 12.57871056], [92.70523834, 12.57956123], [92.70527649, 12.58029461], [92.70591736, 12.58062267], [92.70607758, 12.58086014], [92.70619202, 12.5812912], [92.70639038, 12.58169174], [92.70658875, 12.58206081], [92.70665741, 12.5824604], [92.70667267, 12.58286953], [92.70671844, 12.58328915], [92.70690155, 12.58371067], [92.7069397, 12.58413696], [92.70693207, 12.58451271], [92.70684052, 12.58481026], [92.70670319, 12.58506012], [92.70659637, 12.58532047], [92.7064209, 12.58552742], [92.70623016, 12.58570099], [92.70597839, 12.58580971], [92.70565033, 12.58583069], [92.70527649, 12.58585072], [92.70491028, 12.58596039], [92.70461273, 12.58627033], [92.704422, 12.58674717], [92.70420837, 12.58726025], [92.7041626, 12.58781147], [92.7041626, 12.58835125], [92.70420837, 12.58889771], [92.70442963, 12.58945179], [92.70475006, 12.59002018], [92.70516205, 12.59051609], [92.70561981, 12.59092045], [92.70597076, 12.59135056], [92.70583344, 12.5913887], [92.70639038, 12.59194088], [92.70639038, 12.59250164], [92.70694733, 12.59305954], [92.70694733, 12.59500027], [92.70667267, 12.59527969], [92.70667267, 12.59556007], [92.70749664, 12.59638977], [92.70749664, 12.59694576], [92.70722198, 12.59722233], [92.70666504, 12.59722233], [92.70610809, 12.59666634], [92.70527649, 12.59667015], [92.70500183, 12.59638977], [92.70444489, 12.59694576], [92.70417023, 12.59694576], [92.70388031, 12.59721947], [92.70362091, 12.59756088], [92.70347595, 12.59788036], [92.70346832, 12.59819031], [92.70334625, 12.59840012], [92.70308685, 12.59852123], [92.70282745, 12.59867954], [92.7025528, 12.59892178], [92.70220184, 12.59919071], [92.70176697, 12.59945107], [92.70126343, 12.59967422], [92.70069122, 12.59972191], [92.70012665, 12.59976959], [92.69970703, 12.59991074], [92.69927216, 12.59981346], [92.6989212, 12.59992027], [92.69854736, 12.59999084], [92.69814301, 12.60000038], [92.69772339, 12.60000038], [92.69728851, 12.60000038], [92.69684601, 12.60000038], [92.69642639, 12.60002041], [92.69605255, 12.60012054], [92.6958313, 12.60028267], [92.69561768, 12.6003809], [92.69538879, 12.60043144], [92.69512939, 12.60040092], [92.69487, 12.60031033], [92.69460297, 12.60029888], [92.69433594, 12.60039043], [92.69407654, 12.60056973], [92.69377136, 12.60076141], [92.693367, 12.600811], [92.69283295, 12.60077], [92.69248199, 12.60105991], [92.69223022, 12.60135078], [92.69184875, 12.60159969], [92.69132233, 12.60169983], [92.6910553, 12.60175896], [92.69050598, 12.60190105], [92.69002533, 12.60204887], [92.68946075, 12.60215378], [92.68888855, 12.60213089], [92.68844604, 12.60192585], [92.68785858, 12.60157013], [92.68710327, 12.60114193], [92.68669891, 12.60123062], [92.68637085, 12.6014204], [92.68608093, 12.60169792], [92.68578339, 12.60200977], [92.68548584, 12.60241985], [92.68512726, 12.60280991], [92.68482971, 12.60328865], [92.68467712, 12.60391998], [92.68453217, 12.60462189], [92.68453217, 12.60536003], [92.68456268, 12.60608482], [92.68447113, 12.60678959], [92.68445587, 12.60748005], [92.68448639, 12.60814095], [92.68461609, 12.60879135], [92.68495178, 12.60929012], [92.68505096, 12.60977077], [92.68522644, 12.61018085], [92.68540192, 12.61057091], [92.68545532, 12.61177444], [92.68545532, 12.61231041], [92.68560028, 12.61305523], [92.68592072, 12.61388206], [92.68583679, 12.6147213], [92.6866684, 12.61557102], [92.68694305, 12.61557102], [92.68721771, 12.61503983], [92.68719482, 12.61454773], [92.68710327, 12.614151], [92.68702698, 12.61357689], [92.68712616, 12.61267185], [92.6875, 12.61167145], [92.68776703, 12.61139107], [92.68795013, 12.61124992], [92.68855286, 12.61077976], [92.68915558, 12.61026096], [92.68969727, 12.6096611], [92.69016266, 12.60904121], [92.69062805, 12.60863113], [92.69104767, 12.60832119], [92.69142151, 12.60806084], [92.69181061, 12.60785198], [92.69230652, 12.60778522], [92.69288635, 12.60777187], [92.69348907, 12.60768986], [92.69402313, 12.60752773], [92.69447327, 12.60742092], [92.69478607, 12.60726357], [92.69508362, 12.60727501], [92.69539642, 12.60747337], [92.69576263, 12.60771275], [92.69609833, 12.60804081], [92.69639587, 12.60841179], [92.69670105, 12.60875034], [92.69706726, 12.60902119], [92.69747925, 12.60936737], [92.69801331, 12.60956097], [92.69850922, 12.60984135], [92.6988678, 12.6102562], [92.69917297, 12.61067104], [92.69945526, 12.61101532], [92.69972992, 12.61126995], [92.69998169, 12.6114912], [92.70020294, 12.61170101], [92.70040131, 12.61195183], [92.70063019, 12.61219978], [92.7009201, 12.61240959], [92.70131683, 12.61252785], [92.70169067, 12.6127224], [92.70207977, 12.61290359], [92.70243835, 12.61299133], [92.70276642, 12.61279964], [92.70305634, 12.6124897], [92.70331573, 12.61215878], [92.70347595, 12.61178112], [92.70359039, 12.61142063], [92.70361328, 12.611022], [92.70360565, 12.61058903], [92.7035675, 12.61011028], [92.70346069, 12.60963154], [92.70335388, 12.6091671], [92.70336914, 12.60873127], [92.70333099, 12.60861111], [92.70333099, 12.60833168], [92.70361328, 12.60805416], [92.70361328, 12.60778141], [92.70388031, 12.60750103], [92.70417023, 12.60750103], [92.70471954, 12.60805416], [92.70506287, 12.60842133], [92.70524597, 12.60884094], [92.7053833, 12.60931683], [92.70565796, 12.60969067], [92.7059021, 12.61008072], [92.70612335, 12.6105547], [92.70633698, 12.61111069], [92.70648956, 12.61175823], [92.70665741, 12.6124506], [92.70683289, 12.6131506], [92.70701599, 12.61379814], [92.70729828, 12.61433125], [92.7077179, 12.61473179], [92.70816803, 12.61509037], [92.70865631, 12.61534119], [92.70907593, 12.61557961], [92.70938873, 12.61582184], [92.70960999, 12.61603069], [92.70973206, 12.61631203], [92.7098465, 12.61665058], [92.7099762, 12.61704063], [92.71000671, 12.61749172], [92.71002197, 12.61802101], [92.71006775, 12.61861134], [92.71022797, 12.61913109], [92.71032715, 12.61959076], [92.71045685, 12.6199789], [92.71060181, 12.62041187], [92.71086121, 12.62083054], [92.7111969, 12.62121582], [92.71147919, 12.62168121], [92.71172333, 12.62221527], [92.71195221, 12.62280464], [92.71217346, 12.62343216], [92.71221924, 12.62404919], [92.71222687, 12.62462139], [92.71221161, 12.62508202], [92.71215057, 12.62543964], [92.71199036, 12.62571812], [92.71186066, 12.62603474], [92.71172333, 12.62637424], [92.71179199, 12.62676239], [92.71201324, 12.62716961], [92.71230316, 12.62757111], [92.71253967, 12.62790108], [92.7127533, 12.62821102], [92.71284485, 12.62859917], [92.7130127, 12.62895203], [92.7130127, 12.62942791], [92.71289825, 12.62994957], [92.71305084, 12.63049698], [92.71325684, 12.63107395], [92.71340942, 12.63168526], [92.71369934, 12.6321516], [92.71396637, 12.63258934], [92.71413422, 12.63299656], [92.71418762, 12.63342094], [92.71430206, 12.6337862], [92.71444702, 12.63407993], [92.7146225, 12.63440132], [92.71473694, 12.63476086], [92.71486664, 12.63516045], [92.71498108, 12.63559055], [92.71504974, 12.63603973], [92.71522522, 12.63642979], [92.71524811, 12.63687038], [92.71520233, 12.63735676], [92.7154007, 12.63783073], [92.7155304, 12.63836002], [92.71555328, 12.63889122], [92.7155304, 12.63941097], [92.71543121, 12.63990116], [92.71517181, 12.64035034], [92.71501923, 12.64091969], [92.71494293, 12.64158344], [92.71489716, 12.64229202], [92.71504974, 12.64296246], [92.7154007, 12.64345169], [92.71586609, 12.6437912], [92.71644592, 12.64374065], [92.71704102, 12.64359093], [92.71746826, 12.6433897], [92.71782684, 12.64333534], [92.7181778, 12.64333057], [92.71855164, 12.64338779], [92.71891022, 12.64362335], [92.71932983, 12.64375496], [92.71973419, 12.64330578], [92.71996307, 12.64270878], [92.71994781, 12.6421299], [92.71976471, 12.64163113], [92.71972656, 12.64116096], [92.71969604, 12.6407299], [92.71956635, 12.64039326], [92.71946716, 12.6400671], [92.71943665, 12.63969994], [92.71944427, 12.63932037], [92.71943665, 12.63893032], [92.71943665, 12.63854027], [92.7194519, 12.63817787], [92.71953583, 12.63783073], [92.71970367, 12.63749409], [92.71987152, 12.63707542], [92.72007751, 12.63662148], [92.72040558, 12.63622856], [92.72064209, 12.63574123], [92.72080231, 12.63519192], [92.72083282, 12.63461971], [92.72084045, 12.63407993], [92.7208786, 12.63361931], [92.72106171, 12.63326836], [92.721138, 12.63292027], [92.72125244, 12.63264179], [92.72136688, 12.63237095], [92.72145081, 12.63208294], [92.72160339, 12.6318388], [92.72171021, 12.63154984], [92.72187805, 12.63126087], [92.72198486, 12.63089371], [92.7221756, 12.63052368], [92.72228241, 12.62996578], [92.72245789, 12.62933922], [92.72254181, 12.62867069], [92.72274017, 12.62807178], [92.72296906, 12.62756157], [92.72328186, 12.62722015], [92.72357178, 12.62695122], [92.72383118, 12.62674141], [92.72410583, 12.62667274], [92.72440338, 12.6266613], [92.72470093, 12.6267004], [92.72492981, 12.62687969], [92.72509766, 12.62716961], [92.72521973, 12.62773705], [92.72537994, 12.62833023], [92.72554016, 12.62878132], [92.72569275, 12.6292572], [92.72583008, 12.62944031], [92.72583008, 12.63000011], [92.72611237, 12.63027763], [92.72611237, 12.6319437], [92.72638702, 12.63222027], [92.72638702, 12.63306141], [92.72693634, 12.63360977], [92.72693634, 12.63417053], [92.72805023, 12.63528061], [92.72861481, 12.6352787], [92.72916412, 12.63583469], [92.73055267, 12.63583469], [92.73083496, 12.63611126], [92.73110962, 12.63611126], [92.73139191, 12.63639069], [92.73166656, 12.63639069], [92.73194122, 12.63667965], [92.73222351, 12.63666725], [92.73249817, 12.63694477], [92.73278046, 12.63694477], [92.73305511, 12.63722324], [92.73332977, 12.63722324], [92.73361206, 12.63750076], [92.73388672, 12.63749886], [92.73417664, 12.63778114], [92.73443604, 12.63778114], [92.73555756, 12.63888931], [92.73555756, 12.639431], [92.73583221, 12.63951969], [92.7360611, 12.64003086], [92.7360611, 12.64052105], [92.73589325, 12.64096069], [92.73571014, 12.64138889], [92.73552704, 12.64179707], [92.73532867, 12.64219093], [92.73529816, 12.64265156], [92.73536682, 12.64310074], [92.73543549, 12.64352703], [92.73544312, 12.64394188], [92.73538208, 12.64435005], [92.73527527, 12.64474392], [92.7351532, 12.64511108], [92.73497009, 12.64542103], [92.73469543, 12.64568329], [92.73434448, 12.6459837], [92.73405457, 12.64648342], [92.73391724, 12.64711189], [92.73384094, 12.64777088], [92.7336731, 12.648386], [92.73368835, 12.6490097], [92.73361206, 12.64964199], [92.73351288, 12.65020943], [92.73336792, 12.65070248], [92.73331451, 12.65115547], [92.73320007, 12.65151119], [92.733078, 12.65182972], [92.73306274, 12.65215111], [92.73304749, 12.65248585], [92.73305511, 12.65286922], [92.73310852, 12.65332031], [92.73332977, 12.65378094], [92.73356628, 12.65432072], [92.73374176, 12.65494537], [92.73394012, 12.65554237], [92.73412323, 12.65616226], [92.73432159, 12.65680122], [92.7348175, 12.65728092], [92.73544312, 12.65746593], [92.73604584, 12.65747261], [92.73657227, 12.65752983], [92.73697662, 12.65772057], [92.73737335, 12.65793991], [92.73777771, 12.65820026], [92.7381897, 12.6585207], [92.73862457, 12.65886116], [92.73908997, 12.65916443], [92.73953247, 12.65945053], [92.73992157, 12.65977001], [92.74025726, 12.66010761], [92.74055481, 12.66047192], [92.7408371, 12.66087055], [92.74111176, 12.66134071], [92.74138641, 12.66187763], [92.74167633, 12.6624918], [92.74205017, 12.66310024], [92.7424469, 12.66358089], [92.74286652, 12.66399097], [92.74310303, 12.66451073], [92.74331665, 12.66497612], [92.74356842, 12.66535187], [92.74375153, 12.66576672], [92.74386597, 12.66620445], [92.74388885, 12.66667175], [92.74391937, 12.66709995], [92.74407196, 12.66746044], [92.74433899, 12.66768074], [92.74472046, 12.66771984], [92.74517822, 12.66759682], [92.74563599, 12.66773129], [92.74611664, 12.66778088], [92.74659729, 12.66778088], [92.74675751, 12.66777039], [92.74707031, 12.66775036], [92.74745941, 12.66759872], [92.74774933, 12.66733932], [92.74795532, 12.66703415], [92.7481308, 12.66670132], [92.74835205, 12.66638184], [92.74865723, 12.6661129], [92.74900055, 12.66588306], [92.74937439, 12.66574192], [92.74969482, 12.66558933], [92.75004578, 12.66556168], [92.75036621, 12.6655798], [92.75068665, 12.66570663], [92.75096893, 12.66595078], [92.75125885, 12.66621971], [92.75141907, 12.66664028], [92.7515564, 12.66709995], [92.75170135, 12.6675787], [92.75184631, 12.6680479], [92.75171661, 12.6686697], [92.75180054, 12.66925144], [92.75202942, 12.66967773], [92.75218964, 12.669981], [92.75234985, 12.67024136], [92.75256348, 12.67047787], [92.75289917, 12.67066002], [92.75332642, 12.67078114], [92.7538681, 12.67065144], [92.75444031, 12.67036438], [92.75501251, 12.6700058], [92.75556946, 12.66967297], [92.75610352, 12.66942883], [92.75653076, 12.66916943], [92.75689697, 12.66894245], [92.75728607, 12.66884136], [92.75763702, 12.66867924], [92.75802612, 12.66860199], [92.75841522, 12.66851139], [92.75878143, 12.66836452], [92.75917816, 12.66833115], [92.75959778, 12.66833305], [92.76003265, 12.66833305], [92.76046753, 12.66833305], [92.76089478, 12.66832447], [92.76128387, 12.66825581], [92.7616272, 12.66808891], [92.76198578, 12.66797066], [92.76234436, 12.66781616], [92.76277924, 12.66778088], [92.76325226, 12.66778088], [92.76374054, 12.66778088], [92.76425171, 12.66778088], [92.76477814, 12.66782188], [92.76528168, 12.66796398], [92.76580048, 12.66781998], [92.7663269, 12.66778088], [92.76686096, 12.66778088], [92.76737976, 12.66778088], [92.76789856, 12.66778088], [92.7684021, 12.66777897], [92.76885986, 12.66781998], [92.76924896, 12.6680088], [92.76965332, 12.66807079], [92.7700119, 12.66819191], [92.770401, 12.66835976], [92.77085114, 12.66862011], [92.77136993, 12.66889095], [92.77191162, 12.66918468], [92.77243805, 12.66946125], [92.77292633, 12.66967964], [92.77311707, 12.66969585], [92.77345276, 12.66972065], [92.77392578, 12.66965008], [92.7743988, 12.66946125], [92.77487946, 12.66926956], [92.77529907, 12.66898918], [92.77571869, 12.6687088], [92.77610016, 12.66833115], [92.77642822, 12.66789532], [92.77677155, 12.66749191], [92.77706909, 12.66708183], [92.77728271, 12.66662121], [92.77745819, 12.66618633], [92.77754211, 12.66571045], [92.77771759, 12.66530895], [92.77780151, 12.66490078], [92.77794647, 12.66453075], [92.77809143, 12.66411018], [92.77829742, 12.663661], [92.77842712, 12.66311169], [92.77861023, 12.66257095], [92.77877808, 12.66203976], [92.77886963, 12.66149139], [92.77890778, 12.66093922], [92.77902985, 12.66043091], [92.77913666, 12.65993881], [92.77915955, 12.65940094], [92.77921295, 12.65881348], [92.77935791, 12.65819836], [92.77925873, 12.65752125], [92.77931213, 12.65680122], [92.77935028, 12.65607643], [92.77921295, 12.6553812], [92.77921295, 12.65472698], [92.77934265, 12.65416145], [92.77919006, 12.65368271], [92.77906036, 12.65324974], [92.77892303, 12.6528511], [92.77887726, 12.65242004], [92.77881622, 12.65200138], [92.77873993, 12.65159035], [92.77882385, 12.65113926], [92.77871704, 12.65067196], [92.77863312, 12.6502018], [92.77865601, 12.64972401], [92.77883148, 12.64925003], [92.77883911, 12.64878273], [92.77865601, 12.64831066], [92.77861023, 12.64782143], [92.77861023, 12.64734173], [92.77861023, 12.64686966], [92.77861023, 12.6464119], [92.77861023, 12.64596558], [92.77861023, 12.64550972], [92.77861023, 12.64504528], [92.77864075, 12.64456844], [92.77879333, 12.64413071], [92.77890778, 12.64367008], [92.77908325, 12.64324188], [92.77919006, 12.64276123], [92.77935791, 12.64228916], [92.77942657, 12.64179039], [92.77940369, 12.6413002], [92.77922058, 12.64085579], [92.77910614, 12.64043045], [92.77892303, 12.64008999], [92.77877808, 12.63974953], [92.77838898, 12.63949966], [92.77805328, 12.63927555], [92.77770233, 12.63905144], [92.77725983, 12.63871956], [92.77683258, 12.63833046], [92.77657318, 12.63791084], [92.77645874, 12.63743687], [92.77643585, 12.63685989], [92.7765274, 12.63630199], [92.77700806, 12.63544273], [92.7771225, 12.63492107], [92.77722168, 12.63450623], [92.77729034, 12.63411045], [92.77729797, 12.63368988], [92.77728271, 12.63323021], [92.77754211, 12.63246155], [92.77779388, 12.63262558], [92.77791595, 12.63319969], [92.7779007, 12.63388634], [92.77784729, 12.63441944], [92.77774811, 12.63491917], [92.77762604, 12.63539505], [92.77739716, 12.63593102], [92.77728271, 12.63647079], [92.77722931, 12.63700581], [92.77726746, 12.63748264], [92.77745819, 12.63785172], [92.777771, 12.63801956], [92.77820587, 12.63814068], [92.77865601, 12.6384306], [92.77875519, 12.63835812], [92.77894592, 12.63822079], [92.77926636, 12.63802719], [92.77953339, 12.63776112], [92.77973938, 12.63742065], [92.77993774, 12.63706303], [92.7800293, 12.63662148], [92.78013611, 12.63617039], [92.78003693, 12.6357193], [92.77999878, 12.63527203], [92.78002167, 12.63484097], [92.780159, 12.63450623], [92.78024292, 12.63420963], [92.7802124, 12.63389778], [92.78019714, 12.63350964], [92.78002167, 12.63288116], [92.77976227, 12.63225746], [92.77958679, 12.63167953], [92.77951813, 12.63113976], [92.77951813, 12.63064957], [92.77957916, 12.63024902], [92.77973175, 12.62994957], [92.7798996, 12.62969017], [92.78005219, 12.62942791], [92.78022766, 12.62918186]]]]}}, {\\\"id\\\": \\\"1\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.2_1\\\", \\\"HASC_1\\\": \\\"IN.AP\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Andhra Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 56.7, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1449.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1186.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2635.0, \\\"geo-id\\\": 1, \\\"hpm25_child_popweighted\\\": 122.9, \\\"hpm25_female_popweighted\\\": 141.2, \\\"hpm25_male_popweighted\\\": 101.7, \\\"location\\\": \\\"Andhra Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 22747.0, \\\"mort_hpm25_6cod_mean_total\\\": 18526.0, \\\"mort_tpm25_6cod_mean_total\\\": 41272.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[80.19264221, 13.52069569], [80.19264221, 13.52041531], [80.19374847, 13.52042198], [80.19374847, 13.5201416], [80.19403076, 13.5201416], [80.19403076, 13.51958084], [80.19430542, 13.51958275], [80.19430542, 13.51930523], [80.19458008, 13.51931], [80.19458008, 13.51874924], [80.19486237, 13.51874924], [80.19486237, 13.51847076], [80.19513702, 13.51847267], [80.19513702, 13.51819324], [80.19541931, 13.51819324], [80.19541931, 13.51763916], [80.19568634, 13.51764202], [80.19568634, 13.51653194], [80.19596863, 13.51653194], [80.19596863, 13.51514053], [80.19625092, 13.51514053], [80.19625092, 13.51486111], [80.19652557, 13.51486111], [80.19652557, 13.51430511], [80.19680786, 13.51431179], [80.19680786, 13.51375103], [80.19708252, 13.51375103], [80.19708252, 13.51292133], [80.19596863, 13.51291656], [80.19596863, 13.51319504], [80.19541931, 13.51319504], [80.19541931, 13.51347256], [80.19291687, 13.51347065], [80.19291687, 13.51375103], [80.1920929, 13.51375103], [80.1920929, 13.51403141], [80.19124603, 13.51403141], [80.19124603, 13.51431179], [80.19069672, 13.51430511], [80.19069672, 13.51458263], [80.18985748, 13.51458263], [80.18985748, 13.51486111], [80.18930817, 13.51486111], [80.18930817, 13.51514053], [80.18846893, 13.51514053], [80.18846893, 13.51625061], [80.18819427, 13.5162487], [80.18819427, 13.51708317], [80.18791962, 13.51708317], [80.18791962, 13.51819324], [80.18763733, 13.5181818], [80.18763733, 13.51931], [80.18791962, 13.51931], [80.18791962, 13.5201416], [80.18985748, 13.5201416], [80.18985748, 13.52042198], [80.19180298, 13.52041531], [80.19180298, 13.52069569], [80.19264221, 13.52069569]]], [[[80.18486023, 13.53542137], [80.18486023, 13.53514099], [80.18514252, 13.53514099], [80.18514252, 13.53458023], [80.18541718, 13.53458214], [80.18541718, 13.53430653], [80.18514252, 13.53431129], [80.18514252, 13.53403091], [80.18486023, 13.53403091], [80.18486023, 13.5334816], [80.1845932, 13.5334816], [80.1845932, 13.53318977], [80.18430328, 13.53319359], [80.18430328, 13.53291607], [80.18374634, 13.53292084], [80.18374634, 13.53264141], [80.18068695, 13.53264141], [80.18068695, 13.53292084], [80.18041992, 13.53291607], [80.18041992, 13.53319359], [80.18013763, 13.53318977], [80.18013763, 13.5334816], [80.17986298, 13.5334816], [80.17986298, 13.53403091], [80.18152618, 13.53403091], [80.18152618, 13.53431129], [80.18180847, 13.53430653], [80.18180847, 13.53458214], [80.18319702, 13.53458214], [80.18319702, 13.53486347], [80.18374634, 13.53485966], [80.18374634, 13.53514099], [80.18402863, 13.53514099], [80.18402863, 13.53542137], [80.18486023, 13.53542137]]], [[[80.14902496, 13.61847305], [80.14902496, 13.61819458], [80.14930725, 13.61819458], [80.14930725, 13.61652946], [80.14958191, 13.61653137], [80.14958191, 13.61485958], [80.14930725, 13.6148634], [80.14930725, 13.61430645], [80.14901733, 13.61431122], [80.14901733, 13.61375046], [80.14875031, 13.61375046], [80.14875031, 13.6131897], [80.14847565, 13.61319447], [80.14847565, 13.61291599], [80.14819336, 13.61292076], [80.14819336, 13.61236], [80.1479187, 13.61236], [80.1479187, 13.61207962], [80.14763641, 13.61208439], [80.14763641, 13.61180592], [80.1473465, 13.61182022], [80.1473465, 13.61124992], [80.1470871, 13.61124992], [80.1470871, 13.61096954], [80.14653015, 13.6109724], [80.14653015, 13.61069393], [80.14680481, 13.61069393], [80.14680481, 13.61041641], [80.14763641, 13.61041641], [80.14763641, 13.61069393], [80.14819336, 13.61069393], [80.14819336, 13.6109724], [80.14848328, 13.61096954], [80.14848328, 13.61124992], [80.14875031, 13.61124992], [80.14875031, 13.61153126], [80.14901733, 13.61153126], [80.14901733, 13.61182022], [80.1506958, 13.61182022], [80.1506958, 13.61153126], [80.15097046, 13.61153126], [80.15097046, 13.61124992], [80.15125275, 13.61124992], [80.15125275, 13.61096954], [80.1515274, 13.6109724], [80.1515274, 13.61069393], [80.15208435, 13.61069393], [80.15208435, 13.61041641], [80.15235901, 13.61042118], [80.15235901, 13.61013985], [80.1526413, 13.61013985], [80.1526413, 13.60986042], [80.15291595, 13.60986233], [80.15291595, 13.60958195], [80.1534729, 13.60958195], [80.1534729, 13.60930634], [80.15374756, 13.6093111], [80.15374756, 13.60903263], [80.15429687, 13.60903263], [80.15429687, 13.60876083], [80.15458679, 13.60876083], [80.15458679, 13.60847187], [80.15513611, 13.60847187], [80.15513611, 13.60819435], [80.1554184, 13.60819435], [80.1554184, 13.60791588], [80.15598297, 13.60791969], [80.15598297, 13.60764027], [80.1592865, 13.60764027], [80.15930939, 13.60736179], [80.16042328, 13.60736179], [80.16042328, 13.60707855], [80.16124725, 13.60708427], [80.16124725, 13.6068058], [80.16152954, 13.60680962], [80.16152954, 13.60624981], [80.16179657, 13.60624981], [80.16179657, 13.60569096], [80.16208649, 13.60569382], [80.16208649, 13.6054163], [80.16234589, 13.60542011], [80.16234589, 13.60485935], [80.1626358, 13.60486221], [80.1626358, 13.60236168], [80.16234589, 13.60236168], [80.16234589, 13.5995903], [80.16208649, 13.5995903], [80.16208649, 13.59930992], [80.16152954, 13.59930992], [80.16152954, 13.59625053], [80.16179657, 13.59625053], [80.16179657, 13.59569073], [80.16208649, 13.59569454], [80.16208649, 13.59541702], [80.16234589, 13.59542179], [80.16234589, 13.59486103], [80.1626358, 13.59486103], [80.1626358, 13.59458065], [80.16291809, 13.59458256], [80.16291809, 13.59402657], [80.16319275, 13.59403133], [80.16319275, 13.59375095], [80.16348267, 13.59375095], [80.16348267, 13.59319019], [80.16374969, 13.59319496], [80.16374969, 13.59291744], [80.16401672, 13.59292126], [80.16401672, 13.59236145], [80.16625214, 13.59236145], [80.16625214, 13.59208298], [80.16708374, 13.59208298], [80.16708374, 13.59152889], [80.1673584, 13.59152889], [80.1673584, 13.59097004], [80.16764069, 13.5909729], [80.16764069, 13.58985996], [80.1673584, 13.58985996], [80.1673584, 13.58875275], [80.16707611, 13.58875275], [80.16707611, 13.5876503], [80.16680908, 13.5876503], [80.16680908, 13.58708], [80.16652679, 13.58708191], [80.16652679, 13.58652782], [80.16625214, 13.58653069], [80.16625214, 13.58596992], [80.16596985, 13.58597183], [80.16596985, 13.58541584], [80.16570282, 13.58542061], [80.16570282, 13.58485985], [80.1654129, 13.58485985], [80.1654129, 13.58430576], [80.16513824, 13.58431053], [80.16513824, 13.58403015], [80.16348267, 13.58403015], [80.16348267, 13.58375168], [80.16319275, 13.58375168], [80.16319275, 13.58347034], [80.16291809, 13.58347225], [80.16291809, 13.58319378], [80.1626358, 13.58319378], [80.1626358, 13.58291626], [80.16208649, 13.58292103], [80.16208649, 13.58263969], [80.16179657, 13.58263969], [80.16179657, 13.58236027], [80.16152954, 13.58236217], [80.16152954, 13.5820837], [80.16124725, 13.5820837], [80.16124725, 13.58180618], [80.1609726, 13.58181095], [80.1609726, 13.58152103], [80.16041565, 13.58152771], [80.16041565, 13.58125019], [80.16014099, 13.58125019], [80.16014099, 13.57931042], [80.16042328, 13.57931042], [80.16042328, 13.57845974], [80.16069794, 13.57847214], [80.16069794, 13.57791805], [80.16042328, 13.57791996], [80.16042328, 13.5773592], [80.16014099, 13.57736206], [80.16014099, 13.57708359], [80.1598587, 13.57708359], [80.1598587, 13.57624912], [80.15957642, 13.57625198], [80.15957642, 13.57458115], [80.15930939, 13.57458305], [80.15930939, 13.57347107], [80.15958405, 13.57347107], [80.15958405, 13.57263947], [80.1598587, 13.57265091], [80.1598587, 13.57180977], [80.16014099, 13.57180977], [80.16014099, 13.57125092], [80.1598587, 13.57125092], [80.1598587, 13.57069111], [80.15958405, 13.57069302], [80.15958405, 13.57013893], [80.15930939, 13.57014084], [80.1592865, 13.56958103], [80.1590271, 13.56958294], [80.1590271, 13.56902695], [80.15875244, 13.56903076], [80.15875244, 13.56818962], [80.15847015, 13.56819534], [80.15847015, 13.56763935], [80.15820313, 13.56764126], [80.15820313, 13.56708145], [80.15791321, 13.56708336], [80.15791321, 13.5662508], [80.15763855, 13.5662508], [80.15763855, 13.56569004], [80.15736389, 13.56569481], [80.15736389, 13.56458473], [80.1570816, 13.56458473], [80.1570816, 13.56347275], [80.15680695, 13.56347275], [80.15680695, 13.56235981], [80.15651703, 13.56235981], [80.15651703, 13.56124973], [80.15625, 13.56124973], [80.15625, 13.56014061], [80.15598297, 13.56014061], [80.15598297, 13.55957985], [80.15569305, 13.55958366], [80.15569305, 13.55902767], [80.1554184, 13.55903053], [80.1554184, 13.55846977], [80.15513611, 13.55847168], [80.15513611, 13.55791569], [80.15486145, 13.55792141], [80.15486145, 13.5573597], [80.15458679, 13.5573597], [80.15458679, 13.55681133], [80.15429687, 13.55681133], [80.15429687, 13.55624962], [80.15402985, 13.55624962], [80.15402985, 13.55568886], [80.15374756, 13.55569363], [80.15374756, 13.55541801], [80.15348053, 13.55541992], [80.15348053, 13.55486202], [80.15319824, 13.55486202], [80.15319824, 13.55458164], [80.15291595, 13.55458355], [80.15291595, 13.55402756], [80.1526413, 13.55403042], [80.1526413, 13.55346966], [80.15235901, 13.55347157], [80.15235901, 13.55319405], [80.15208435, 13.55319405], [80.15208435, 13.55263996], [80.15180206, 13.55263996], [80.15180206, 13.55235958], [80.1515274, 13.55236244], [80.1515274, 13.55180645], [80.15125275, 13.55181026], [80.15125275, 13.55125046], [80.15097046, 13.55125046], [80.15097046, 13.55097198], [80.1506958, 13.55097198], [80.1506958, 13.55069447], [80.15041351, 13.55069447], [80.15041351, 13.5504179], [80.15013885, 13.55041981], [80.15013885, 13.55014038], [80.14985657, 13.55014038], [80.14985657, 13.54986191], [80.14958191, 13.54986191], [80.14958191, 13.54958057], [80.14930725, 13.54958439], [80.14930725, 13.54930592], [80.14901733, 13.54930973], [80.14901733, 13.5490303], [80.14875031, 13.5490303], [80.14875031, 13.54875183], [80.14848328, 13.54875183], [80.14848328, 13.54848003], [80.14819336, 13.54848003], [80.14819336, 13.54819107], [80.1479187, 13.54819584], [80.1479187, 13.54791832], [80.14763641, 13.54792023], [80.14763641, 13.54764175], [80.1473465, 13.54764175], [80.1473465, 13.54736137], [80.1470871, 13.54736137], [80.1470871, 13.5470829], [80.14680481, 13.5470829], [80.14680481, 13.54680538], [80.14653015, 13.54681015], [80.14653015, 13.54653168], [80.14624786, 13.54653168], [80.14624786, 13.54624939], [80.14569092, 13.54624939], [80.14569092, 13.54597092], [80.1451416, 13.54597092], [80.1451416, 13.5456953], [80.14485931, 13.5456953], [80.14485931, 13.54541683], [80.14431, 13.54541969], [80.14431, 13.54513931], [80.14375305, 13.54513931], [80.14375305, 13.54486084], [80.14180756, 13.54486084], [80.14180756, 13.54513931], [80.14125061, 13.54513931], [80.14125061, 13.54541969], [80.14097595, 13.54541683], [80.14097595, 13.54597092], [80.14068604, 13.54597092], [80.14068604, 13.54653168], [80.14041901, 13.54652691], [80.14041901, 13.5470829], [80.14013672, 13.5470829], [80.14013672, 13.54819584], [80.13986206, 13.54819584], [80.13986206, 13.54958439], [80.14013672, 13.54958057], [80.14013672, 13.55014038], [80.13986206, 13.55014038], [80.13986206, 13.55041981], [80.13957977, 13.5504179], [80.13957977, 13.55097198], [80.13931274, 13.55097198], [80.13931274, 13.55125046], [80.13903046, 13.55125046], [80.13903046, 13.55152798], [80.13874817, 13.55152798], [80.13874817, 13.55208397], [80.13847351, 13.55208397], [80.13847351, 13.55236244], [80.13817596, 13.55235958], [80.13817596, 13.55263996], [80.13791656, 13.55263996], [80.13791656, 13.55319405], [80.13764191, 13.55319405], [80.13764191, 13.55347157], [80.13735962, 13.55347157], [80.13735962, 13.55819416], [80.13708496, 13.55819416], [80.13708496, 13.56069374], [80.13819122, 13.56069374], [80.13819122, 13.56097221], [80.13903046, 13.56097031], [80.13903046, 13.56124973], [80.13931274, 13.56124973], [80.13931274, 13.56181145], [80.13957977, 13.56181145], [80.13957977, 13.56235981], [80.13986206, 13.56235981], [80.13986206, 13.56292057], [80.14013672, 13.56292057], [80.14013672, 13.56403065], [80.14041901, 13.56402874], [80.14041901, 13.56569481], [80.14013672, 13.56569004], [80.14013672, 13.5662508], [80.13986206, 13.5662508], [80.13986206, 13.56708336], [80.13957977, 13.56708145], [80.13957977, 13.56764126], [80.13930511, 13.56763935], [80.13930511, 13.56819534], [80.13903046, 13.56818962], [80.13903046, 13.56875134], [80.13874817, 13.56875134], [80.13874817, 13.56931019], [80.13847351, 13.56930542], [80.13847351, 13.56958294], [80.13817596, 13.56958103], [80.13817596, 13.57014084], [80.13791656, 13.57013893], [80.13791656, 13.57069302], [80.13764191, 13.57069111], [80.13764191, 13.57125092], [80.13735962, 13.57125092], [80.13735962, 13.57180977], [80.13708496, 13.571805], [80.13708496, 13.57208347], [80.13680267, 13.57208061], [80.13680267, 13.57236099], [80.13652802, 13.57236099], [80.13652802, 13.57265091], [80.13625336, 13.57265091], [80.13625336, 13.57292175], [80.13597107, 13.57291698], [80.13597107, 13.57347107], [80.13569641, 13.57347107], [80.13569641, 13.5737524], [80.13540649, 13.5737524], [80.13540649, 13.57403183], [80.13513947, 13.57403183], [80.13513947, 13.5743103], [80.13486481, 13.57430458], [80.13486481, 13.57458305], [80.13346863, 13.57458305], [80.13346863, 13.57486057], [80.13318634, 13.57486057], [80.13318634, 13.57514191], [80.13263702, 13.57514191], [80.13263702, 13.57542038], [80.13236237, 13.57541847], [80.13236237, 13.57569313], [80.13208008, 13.57569313], [80.13208008, 13.57597065], [80.13181305, 13.57597065], [80.13181305, 13.57625198], [80.13124847, 13.57625198], [80.13124847, 13.57653046], [80.13096619, 13.57653046], [80.13096619, 13.57681179], [80.13041687, 13.57680607], [80.13041687, 13.57708359], [80.13014221, 13.57708359], [80.13014221, 13.57736206], [80.12960052, 13.5773592], [80.12960052, 13.57763958], [80.12902832, 13.57763958], [80.12902832, 13.57791996], [80.12875366, 13.57791805], [80.12875366, 13.57819366], [80.12819672, 13.57819366], [80.12819672, 13.57847214], [80.1279068, 13.57845974], [80.1279068, 13.57903004], [80.12763977, 13.57902813], [80.12763977, 13.57958412], [80.12735748, 13.57957935], [80.12735748, 13.58014011], [80.12708282, 13.58014011], [80.12708282, 13.5806942], [80.12680817, 13.5806942], [80.12680817, 13.58220863], [80.12680817, 13.58263969], [80.12652588, 13.58263779], [80.12652588, 13.58485985], [80.12680817, 13.58485985], [80.12680817, 13.58542061], [80.12708282, 13.58542061], [80.12708282, 13.58625031], [80.12735748, 13.58625031], [80.12735748, 13.58681107], [80.12847137, 13.5868063], [80.12847137, 13.58708191], [80.12958527, 13.58708382], [80.12958527, 13.58736038], [80.12985992, 13.58736038], [80.12985992, 13.5876503], [80.13041687, 13.5876503], [80.13041687, 13.58792114], [80.13069153, 13.58791637], [80.13069153, 13.58819389], [80.13124847, 13.58819389], [80.13124847, 13.58847237], [80.13236237, 13.58847237], [80.13236237, 13.58819389], [80.13263702, 13.58819389], [80.13263702, 13.58791637], [80.13346863, 13.58791637], [80.13346863, 13.58819389], [80.13402557, 13.58819389], [80.13402557, 13.58847237], [80.13458252, 13.58847046], [80.13458252, 13.58875275], [80.13513947, 13.58875275], [80.13513947, 13.58903122], [80.13569641, 13.58903122], [80.13569641, 13.58931065], [80.1359024, 13.58930874], [80.13625336, 13.58930683], [80.13625336, 13.58958244], [80.13652802, 13.58957958], [80.13652802, 13.58985996], [80.13707733, 13.58985996], [80.13707733, 13.5901413], [80.13735962, 13.5901413], [80.13735962, 13.59042072], [80.13791656, 13.59041691], [80.13791656, 13.59069538], [80.13817596, 13.59068966], [80.13817596, 13.59125137], [80.14013672, 13.59125137], [80.14013672, 13.59097004], [80.14125061, 13.5909729], [80.14125061, 13.59069538], [80.14180756, 13.59069538], [80.14180756, 13.5909729], [80.14263916, 13.59097004], [80.14263916, 13.59125137], [80.14653015, 13.59125137], [80.14653015, 13.59097004], [80.14819336, 13.5909729], [80.14819336, 13.59069538], [80.1498642, 13.59069538], [80.1498642, 13.59041691], [80.15116882, 13.59041882], [80.1515274, 13.59042072], [80.1515274, 13.5901413], [80.15319824, 13.5901413], [80.15319824, 13.58985996], [80.15513611, 13.58985996], [80.15513611, 13.58957958], [80.15569305, 13.58958244], [80.15569305, 13.58930683], [80.15651703, 13.58931065], [80.15651703, 13.58903122], [80.15735626, 13.58903122], [80.15735626, 13.58931065], [80.15791321, 13.58931065], [80.15791321, 13.5901413], [80.1581955, 13.59013939], [80.1581955, 13.5909729], [80.15791321, 13.59097004], [80.15791321, 13.59152889], [80.15763855, 13.59152889], [80.15763855, 13.59180927], [80.15680695, 13.59180927], [80.15680695, 13.59152889], [80.15651703, 13.59152889], [80.15651703, 13.59125137], [80.15625, 13.59125137], [80.15625, 13.59097004], [80.1554184, 13.59097004], [80.1554184, 13.59125137], [80.15348053, 13.59125137], [80.15348053, 13.59152889], [80.15180206, 13.59152889], [80.15180206, 13.59180927], [80.1505127, 13.59180546], [80.15013885, 13.59180546], [80.15013885, 13.59208298], [80.14902496, 13.59208298], [80.14902496, 13.59236145], [80.14763641, 13.59236145], [80.14763641, 13.59264088], [80.1470871, 13.59264088], [80.1470871, 13.59292126], [80.14680481, 13.59291744], [80.14680481, 13.59319496], [80.14624786, 13.59319496], [80.14624786, 13.59347343], [80.14541626, 13.59346199], [80.14541626, 13.59403133], [80.1451416, 13.59403133], [80.1451416, 13.59514141], [80.14485931, 13.59513855], [80.14485931, 13.59597301], [80.14457703, 13.59597111], [80.14457703, 13.59625053], [80.14431, 13.59625053], [80.14431, 13.59653187], [80.14347076, 13.59653187], [80.14347076, 13.59682083], [80.1423645, 13.59680462], [80.1423645, 13.59708309], [80.14152527, 13.59708309], [80.14152527, 13.59736061], [80.13874817, 13.59736061], [80.13874817, 13.59764099], [80.13764191, 13.59764099], [80.13764191, 13.59792042], [80.13680267, 13.5979166], [80.13680267, 13.59819317], [80.13625336, 13.59819317], [80.13625336, 13.5984726], [80.13569641, 13.59847069], [80.13569641, 13.59875107], [80.13540649, 13.59875107], [80.13540649, 13.59902859], [80.13485718, 13.59902859], [80.13485718, 13.59930992], [80.1340332, 13.59930992], [80.1340332, 13.5995903], [80.13319397, 13.59958267], [80.13319397, 13.59986115], [80.12763977, 13.59986115], [80.12763977, 13.60014153], [80.12735748, 13.60014153], [80.12735748, 13.60042191], [80.12680817, 13.60041714], [80.12680817, 13.60069466], [80.12625122, 13.60069466], [80.12625122, 13.60097122], [80.12596893, 13.60097122], [80.12596893, 13.6012516], [80.12541962, 13.6012516], [80.12541962, 13.60153198], [80.12486267, 13.60153198], [80.12486267, 13.60069084], [80.12513733, 13.60069466], [80.12513733, 13.59986115], [80.12541962, 13.59986115], [80.12541962, 13.59958267], [80.12596893, 13.5995903], [80.12596893, 13.59930992], [80.12623596, 13.59930992], [80.12623596, 13.59902859], [80.12847137, 13.59902859], [80.12847137, 13.59875107], [80.12874603, 13.59875107], [80.12874603, 13.59819126], [80.12902832, 13.59819317], [80.12902832, 13.5979166], [80.12931061, 13.59792042], [80.12931061, 13.59764099], [80.12960052, 13.59764099], [80.12960052, 13.59736061], [80.12902832, 13.59736061], [80.12902832, 13.59597111], [80.12930298, 13.59597301], [80.12930298, 13.59569454], [80.12958527, 13.59569454], [80.12958527, 13.59513855], [80.12985992, 13.59514141], [80.12985992, 13.59486103], [80.13014221, 13.59486103], [80.13014221, 13.59458065], [80.13041687, 13.59458256], [80.13041687, 13.59319496], [80.13014221, 13.59319496], [80.13014221, 13.59291744], [80.12985992, 13.59292126], [80.12985992, 13.59264088], [80.12960052, 13.59264088], [80.12960052, 13.59180927], [80.12931061, 13.59180927], [80.12931061, 13.59125137], [80.12958527, 13.59125137], [80.12958527, 13.5909729], [80.12985992, 13.5909729], [80.12985992, 13.59069538], [80.13014221, 13.59069538], [80.13014221, 13.59013939], [80.13041687, 13.5901413], [80.13041687, 13.58990192], [80.13041687, 13.58958244], [80.13069153, 13.58958244], [80.13069153, 13.58930683], [80.12985992, 13.58931065], [80.12985992, 13.58903122], [80.12902832, 13.58903122], [80.12902832, 13.58875275], [80.12819672, 13.58875275], [80.12819672, 13.58847046], [80.12652588, 13.58847237], [80.12652588, 13.58859062], [80.12652588, 13.58903122], [80.12623596, 13.58903122], [80.12623596, 13.58985996], [80.12596893, 13.58985996], [80.12596893, 13.59069538], [80.12568665, 13.59068966], [80.12568665, 13.59125137], [80.12541962, 13.59125137], [80.12541962, 13.59180927], [80.12513733, 13.59180546], [80.12513733, 13.59236145], [80.12486267, 13.59236145], [80.12486267, 13.59292126], [80.12458038, 13.59291744], [80.12458038, 13.59347343], [80.12486267, 13.59346199], [80.12486267, 13.59431171], [80.12458038, 13.59431171], [80.12458038, 13.59514141], [80.12430573, 13.59513855], [80.12430573, 13.59569454], [80.12374878, 13.59569454], [80.12374878, 13.59597301], [80.12346649, 13.59597111], [80.12346649, 13.59653187], [80.12319183, 13.5965271], [80.12319183, 13.59708309], [80.12291718, 13.59708118], [80.12291718, 13.59764099], [80.12264252, 13.59763908], [80.12264252, 13.5984726], [80.12236023, 13.59847069], [80.12236023, 13.5995903], [80.12208557, 13.59958267], [80.12208557, 13.60069466], [80.12180328, 13.60069466], [80.12180328, 13.60115147], [80.12180328, 13.60153198], [80.12152863, 13.60153198], [80.12152863, 13.60181046], [80.12124634, 13.60181046], [80.12124634, 13.60236168], [80.12097168, 13.60236168], [80.12097168, 13.60264015], [80.12069702, 13.60262966], [80.12069702, 13.60402966], [80.12041473, 13.60402775], [80.12041473, 13.60569382], [80.12069702, 13.60569096], [80.12069702, 13.60624981], [80.12097168, 13.60624981], [80.12097168, 13.60680962], [80.12124634, 13.6068058], [80.12124634, 13.60708427], [80.12291718, 13.60708427], [80.12291718, 13.6068058], [80.12403107, 13.60680962], [80.12403107, 13.60653019], [80.12374878, 13.60653019], [80.12374878, 13.60624981], [80.12346649, 13.60624981], [80.12346649, 13.60596943], [80.12319183, 13.60597229], [80.12319183, 13.6054163], [80.12374878, 13.60542011], [80.12374878, 13.60513973], [80.12431335, 13.60513973], [80.12431335, 13.6050396], [80.12430573, 13.60486221], [80.12486267, 13.60486221], [80.12486267, 13.60458374], [80.12625122, 13.60458374], [80.12625122, 13.60486221], [80.12652588, 13.60485935], [80.12652588, 13.60513973], [80.12708282, 13.60513973], [80.12708282, 13.60542011], [80.12735748, 13.6054163], [80.12735748, 13.60569382], [80.12763977, 13.60569382], [80.12763977, 13.60597229], [80.13124847, 13.60596943], [80.13124847, 13.60624981], [80.13680267, 13.60624981], [80.13680267, 13.60653019], [80.13764191, 13.60653019], [80.13764191, 13.60680962], [80.13780975, 13.60680771], [80.13819122, 13.6068058], [80.13819122, 13.60708427], [80.13903046, 13.60707855], [80.13903046, 13.60736179], [80.13931274, 13.60736179], [80.13931274, 13.60764027], [80.13986206, 13.60764027], [80.13986206, 13.60791969], [80.14013672, 13.60791588], [80.14013672, 13.60819435], [80.14069366, 13.60819435], [80.14069366, 13.60847187], [80.14097595, 13.60847187], [80.14097595, 13.60876083], [80.14154053, 13.60876083], [80.14154053, 13.60903263], [80.14180756, 13.60903263], [80.14180756, 13.6093111], [80.14208221, 13.60930634], [80.14208221, 13.60958195], [80.14263916, 13.60958195], [80.14263916, 13.60986233], [80.14290619, 13.60986042], [80.14290619, 13.61013985], [80.14347076, 13.61013985], [80.14347076, 13.61042118], [80.14375305, 13.61041641], [80.14375305, 13.61069393], [80.14402771, 13.61069393], [80.14402771, 13.6109724], [80.14457703, 13.61096954], [80.14457703, 13.61124992], [80.14485931, 13.61124992], [80.14485931, 13.61153126], [80.14541626, 13.61153126], [80.14541626, 13.61182022], [80.14569092, 13.61182022], [80.14569092, 13.61236], [80.14597321, 13.61236], [80.14597321, 13.61292076], [80.14624786, 13.61291599], [80.14624786, 13.61347198], [80.14653015, 13.61347008], [80.14653015, 13.61431122], [80.14680481, 13.61430645], [80.14680481, 13.6148634], [80.1470871, 13.61485958], [80.1470871, 13.6154213], [80.1473465, 13.6154213], [80.1473465, 13.61625099], [80.14763641, 13.61625099], [80.14763641, 13.6168108], [80.1479187, 13.6168108], [80.1479187, 13.61736107], [80.14819336, 13.61736107], [80.14819336, 13.61792088], [80.14847565, 13.61791706], [80.14847565, 13.61847305], [80.14902496, 13.61847305]]], [[[80.0534668, 13.58931065], [80.0534668, 13.58903122], [80.05403137, 13.58903122], [80.05403137, 13.58875275], [80.05596924, 13.58875275], [80.05596924, 13.58847046], [80.05625153, 13.58847237], [80.05625153, 13.58819389], [80.05652618, 13.58819389], [80.05652618, 13.58736038], [80.05680847, 13.58736038], [80.05680847, 13.5868063], [80.05652618, 13.58681107], [80.05652618, 13.58653069], [80.05458069, 13.58653069], [80.05458069, 13.58681107], [80.05430603, 13.5868063], [80.05430603, 13.58708191], [80.05403137, 13.58708191], [80.05403137, 13.58736038], [80.05374908, 13.58736038], [80.05374908, 13.5876503], [80.0534668, 13.5876503], [80.0534668, 13.58792114], [80.05291748, 13.58791637], [80.05291748, 13.58819389], [80.05236053, 13.58819199], [80.05236053, 13.58875275], [80.05264282, 13.58875275], [80.05264282, 13.58903122], [80.05291748, 13.58903122], [80.05291748, 13.58931065], [80.0534668, 13.58931065]]], [[[80.09707642, 13.64153099], [80.09707642, 13.64124966], [80.0973587, 13.64124966], [80.0973587, 13.64013958], [80.09707642, 13.64013958], [80.09707642, 13.63874054], [80.09680939, 13.63875008], [80.09680176, 13.63819408], [80.0965271, 13.63819408], [80.0965271, 13.63763809], [80.09626007, 13.63764], [80.09626007, 13.63735962], [80.09597015, 13.63736153], [80.09597015, 13.63708401], [80.09541321, 13.63708401], [80.09541321, 13.63680553], [80.09430695, 13.63681126], [80.09430695, 13.63652992], [80.0929184, 13.63652992], [80.0929184, 13.63624954], [80.09152985, 13.63624954], [80.09152985, 13.63681126], [80.09124756, 13.63680553], [80.09124756, 13.63694096], [80.09124756, 13.63736153], [80.09152985, 13.63735962], [80.09152985, 13.63792133], [80.0918045, 13.63791561], [80.0918045, 13.63819408], [80.09208679, 13.63819408], [80.09208679, 13.6384716], [80.09236145, 13.6384716], [80.09236145, 13.63875008], [80.09263611, 13.63874054], [80.09263611, 13.63931084], [80.0929184, 13.63930416], [80.0929184, 13.63958359], [80.09319305, 13.63958359], [80.09319305, 13.63986015], [80.0934906, 13.63986015], [80.0934906, 13.64013958], [80.09401703, 13.64013958], [80.09401703, 13.64042091], [80.09430695, 13.64041615], [80.09430695, 13.64069366], [80.0945816, 13.64069366], [80.0945816, 13.64097214], [80.09485626, 13.64097023], [80.09485626, 13.64124966], [80.09533691, 13.64124966], [80.09597015, 13.64124966], [80.09597015, 13.64153099], [80.09707642, 13.64153099]]], [[[80.10652924, 13.65291977], [80.10652924, 13.65208054], [80.10624695, 13.6520834], [80.10624695, 13.6515274], [80.10652924, 13.65152931], [80.10652924, 13.65125084], [80.10708618, 13.65125084], [80.10708618, 13.65097141], [80.10736084, 13.65097332], [80.10736084, 13.65013885], [80.10764313, 13.65014076], [80.10764313, 13.64931202], [80.10791779, 13.64931202], [80.10791779, 13.64847088], [80.10819244, 13.64847088], [80.10819244, 13.64680481], [80.10791779, 13.64681244], [80.10791779, 13.64625072], [80.10764313, 13.64625072], [80.10764313, 13.6459713], [80.10680389, 13.64597321], [80.10680389, 13.64569473], [80.10652924, 13.64569473], [80.10652924, 13.64541721], [80.10624695, 13.64542103], [80.10624695, 13.64514065], [80.10597229, 13.64514065], [80.10597229, 13.64431095], [80.10569763, 13.64431095], [80.10569763, 13.64319038], [80.10541534, 13.64319515], [80.10541534, 13.64235973], [80.10514069, 13.64235973], [80.10514069, 13.64153099], [80.1048584, 13.64153099], [80.1048584, 13.64068985], [80.10458374, 13.64069366], [80.10458374, 13.63958359], [80.10430908, 13.63958359], [80.10430908, 13.63875008], [80.10402679, 13.63875008], [80.10402679, 13.63791561], [80.10375214, 13.63792133], [80.10375214, 13.63735962], [80.10346985, 13.63736153], [80.10346985, 13.6372509], [80.10346985, 13.63708401], [80.1029129, 13.63708401], [80.1029129, 13.63680553], [80.10124969, 13.63680553], [80.10124969, 13.63708401], [80.10097504, 13.63708401], [80.10097504, 13.63736153], [80.10069275, 13.63735962], [80.10069275, 13.63764], [80.10041809, 13.63763809], [80.10041809, 13.6384716], [80.1001358, 13.6384697], [80.1001358, 13.63931084], [80.10041809, 13.63930416], [80.10041809, 13.63986015], [80.10069275, 13.63986015], [80.10069275, 13.64011097], [80.10069275, 13.64042091], [80.10097504, 13.64041615], [80.10097504, 13.64097214], [80.10124969, 13.64097023], [80.10124969, 13.64153099], [80.10152435, 13.64152813], [80.10152435, 13.6418066], [80.10180664, 13.64180183], [80.10180664, 13.64235973], [80.1020813, 13.64235973], [80.1020813, 13.64292145], [80.10236359, 13.64291573], [80.10236359, 13.64347267], [80.10263824, 13.6434679], [80.10263824, 13.64403057], [80.1029129, 13.64402866], [80.1029129, 13.64458466], [80.10320282, 13.64458275], [80.10320282, 13.6448698], [80.10346985, 13.6448698], [80.10346985, 13.64542103], [80.10375214, 13.64542103], [80.10375214, 13.64625072], [80.10402679, 13.64625072], [80.10402679, 13.64681244], [80.10430908, 13.64680481], [80.10430908, 13.64708328], [80.10458374, 13.64708328], [80.10458374, 13.6473608], [80.1048584, 13.6473608], [80.1048584, 13.64819527], [80.10514069, 13.64818954], [80.10514069, 13.64903069], [80.1054306, 13.64903069], [80.1054306, 13.65014076], [80.10569763, 13.65014076], [80.10569763, 13.65125084], [80.10597229, 13.65125084], [80.10597229, 13.65263939], [80.10624695, 13.65263939], [80.10624695, 13.65291977], [80.10652924, 13.65291977]]], [[[80.10263824, 13.67764091], [80.10263824, 13.67736053], [80.10402679, 13.67736053], [80.10402679, 13.67708302], [80.10541534, 13.67708302], [80.10541534, 13.67680454], [80.10624695, 13.67681026], [80.10624695, 13.6756897], [80.10597229, 13.67569542], [80.10597229, 13.67541695], [80.10569763, 13.67542171], [80.10569763, 13.67486954], [80.1054306, 13.67486954], [80.1054306, 13.67347145], [80.10569763, 13.67347336], [80.10569763, 13.67152882], [80.1054306, 13.67153072], [80.1054306, 13.66986275], [80.10514069, 13.66986275], [80.10514069, 13.66874981], [80.1048584, 13.66874981], [80.1048584, 13.66847038], [80.10430908, 13.66847229], [80.10430908, 13.66819382], [80.10402679, 13.66819191], [80.10402679, 13.66903114], [80.10375214, 13.66902637], [80.10375214, 13.6706953], [80.10402679, 13.67068958], [80.10402679, 13.6718092], [80.10375214, 13.67180538], [80.10375214, 13.67236137], [80.10346985, 13.67236137], [80.10346985, 13.67292118], [80.10320282, 13.67292118], [80.10320282, 13.67403126], [80.1029129, 13.67403126], [80.1029129, 13.67514133], [80.10263824, 13.67513943], [80.10263824, 13.67597294], [80.10235596, 13.67597103], [80.10235596, 13.67681026], [80.1020813, 13.67681026], [80.1020813, 13.67764091], [80.10263824, 13.67764091]]], [[[81.02791595, 15.76569366], [81.02791595, 15.76541615], [81.02874756, 15.76542091], [81.02874756, 15.76513958], [81.02958679, 15.76513958], [81.02958679, 15.76486015], [81.02986145, 15.76486015], [81.02986145, 15.76458359], [81.02958679, 15.76458359], [81.02958679, 15.76430416], [81.02929688, 15.76431084], [81.02929688, 15.76375008], [81.02902985, 15.76375008], [81.02902985, 15.76319027], [81.02874756, 15.76319408], [81.02874756, 15.76291561], [81.0284729, 15.76292133], [81.0284729, 15.76264], [81.02819824, 15.76264], [81.02819824, 15.76235962], [81.02791595, 15.76236153], [81.02791595, 15.76208401], [81.0276413, 15.76208401], [81.0276413, 15.76180553], [81.02735901, 15.76181126], [81.02735901, 15.76152992], [81.02707672, 15.76152992], [81.02707672, 15.76124954], [81.02680206, 15.76124954], [81.02680206, 15.76097202], [81.0265274, 15.76097202], [81.0265274, 15.76069355], [81.02625275, 15.76069355], [81.02625275, 15.76041794], [81.02597046, 15.76041985], [81.02597046, 15.76014042], [81.0256958, 15.76014042], [81.0256958, 15.75986195], [81.02540588, 15.75986195], [81.02540588, 15.75958157], [81.02513885, 15.75958443], [81.02513885, 15.75930595], [81.02485657, 15.75930977], [81.02485657, 15.75903034], [81.02458191, 15.75903034], [81.02458191, 15.75874996], [81.02430725, 15.75874996], [81.02430725, 15.75846863], [81.02402496, 15.75847244], [81.02402496, 15.75819397], [81.02375031, 15.75819397], [81.02375031, 15.75791645], [81.0229187, 15.75792027], [81.0229187, 15.75765133], [81.02179718, 15.75765133], [81.02179718, 15.75736046], [81.02097321, 15.75736046], [81.02097321, 15.75765133], [81.02041626, 15.75765133], [81.02041626, 15.75792027], [81.0201416, 15.75791645], [81.0201416, 15.7581892], [81.02041626, 15.75819588], [81.02041626, 15.75847244], [81.02097321, 15.75846863], [81.02097321, 15.75874996], [81.02124786, 15.75874996], [81.02124786, 15.75903034], [81.02179718, 15.75903034], [81.02179718, 15.75930977], [81.02236176, 15.75930595], [81.02236176, 15.75958443], [81.0229187, 15.75958157], [81.0229187, 15.75986195], [81.02320099, 15.75986195], [81.02320099, 15.76014042], [81.02375031, 15.76014042], [81.02375031, 15.76041985], [81.02430725, 15.76041794], [81.02430725, 15.76069355], [81.0248642, 15.76069355], [81.0248642, 15.76097202], [81.02513885, 15.76097202], [81.02513885, 15.76124954], [81.0256958, 15.76124954], [81.0256958, 15.76181126], [81.02597046, 15.76180553], [81.02597046, 15.76236153], [81.02626038, 15.76235962], [81.02626038, 15.76292133], [81.0265274, 15.76291561], [81.0265274, 15.7634716], [81.02680206, 15.7634697], [81.02680206, 15.76403141], [81.02708435, 15.7640276], [81.02708435, 15.76458359], [81.02735901, 15.76457977], [81.02735901, 15.76513958], [81.0276413, 15.76513767], [81.0276413, 15.76569366], [81.02791595, 15.76569366]]], [[[80.78291321, 15.83763981], [80.78291321, 15.83708096], [80.7831955, 15.83708382], [80.7831955, 15.8368063], [80.78347015, 15.83681011], [80.78347015, 15.83652973], [80.7840271, 15.83652973], [80.7840271, 15.83625031], [80.78430176, 15.83625031], [80.78430939, 15.83597088], [80.78458405, 15.83597088], [80.78458405, 15.83569336], [80.7848587, 15.83569336], [80.7848587, 15.83541775], [80.78542328, 15.83541965], [80.78542328, 15.83514023], [80.7859726, 15.83514023], [80.7859726, 15.83486176], [80.78624725, 15.83486176], [80.78624725, 15.83458138], [80.7868042, 15.83458328], [80.7868042, 15.83430481], [80.78708649, 15.83430958], [80.78708649, 15.83403015], [80.78736115, 15.83403015], [80.78736115, 15.83375168], [80.7876358, 15.83375168], [80.7876358, 15.8334713], [80.78847504, 15.8334713], [80.78847504, 15.83319473], [80.78930664, 15.83319473], [80.78930664, 15.83291531], [80.7895813, 15.83293056], [80.7895813, 15.8326416], [80.78985596, 15.8326416], [80.78985596, 15.83236122], [80.79013824, 15.83236122], [80.79013824, 15.83208275], [80.7904129, 15.83208275], [80.7904129, 15.83152676], [80.79070282, 15.83153152], [80.79070282, 15.83124924], [80.79096985, 15.83124924], [80.79096985, 15.83069134], [80.79125214, 15.83069515], [80.79125214, 15.83013916], [80.79151917, 15.83014107], [80.79151917, 15.82958126], [80.79180908, 15.82958317], [80.79180908, 15.82763863], [80.79207611, 15.82764053], [80.79207611, 15.82736111], [80.7923584, 15.82736111], [80.7923584, 15.82708263], [80.79319763, 15.82708263], [80.79319763, 15.82680511], [80.79347229, 15.82681179], [80.79347229, 15.82653141], [80.79374695, 15.82653141], [80.79374695, 15.82625103], [80.79319763, 15.82625103], [80.79319763, 15.82597065], [80.79264069, 15.82597256], [80.79264069, 15.82569504], [80.79208374, 15.82569504], [80.79208374, 15.82513905], [80.79180908, 15.82514095], [80.79180908, 15.82431126], [80.79151917, 15.82431126], [80.79151917, 15.82403088], [80.79096985, 15.82403088], [80.79096985, 15.82374191], [80.7904129, 15.82374191], [80.7904129, 15.82403088], [80.78985596, 15.82403088], [80.78985596, 15.82431126], [80.78930664, 15.82430458], [80.78930664, 15.82486057], [80.78901672, 15.82486057], [80.78901672, 15.82542133], [80.78874969, 15.82541656], [80.78874969, 15.82597256], [80.78848267, 15.82597065], [80.78848267, 15.82653141], [80.78819275, 15.82652664], [80.78819275, 15.82708263], [80.78791809, 15.82708073], [80.78791809, 15.82764053], [80.7876358, 15.82763863], [80.7876358, 15.82819462], [80.78736115, 15.82819462], [80.78736115, 15.82847309], [80.78708649, 15.82847118], [80.78708649, 15.82903099], [80.78679657, 15.82903099], [80.78679657, 15.82931042], [80.78652954, 15.8293047], [80.78652954, 15.82958317], [80.78624725, 15.82958126], [80.78624725, 15.82987022], [80.7859726, 15.82987022], [80.7859726, 15.83097076], [80.78569794, 15.83097076], [80.78569794, 15.83153152], [80.78541565, 15.83152676], [80.78541565, 15.83208275], [80.78514099, 15.83208275], [80.78514099, 15.83236122], [80.7848587, 15.83236122], [80.7848587, 15.83293056], [80.78458405, 15.83291531], [80.78458405, 15.8334713], [80.78430176, 15.8334713], [80.78430176, 15.83375168], [80.7840271, 15.83375168], [80.7840271, 15.83403015], [80.78375244, 15.83402729], [80.78375244, 15.83458328], [80.78347015, 15.83458138], [80.78347015, 15.83486176], [80.78320313, 15.83486176], [80.78320313, 15.83514023], [80.78291321, 15.83514023], [80.78291321, 15.83569336], [80.78263855, 15.83568192], [80.78263855, 15.83625031], [80.78234863, 15.83625031], [80.78234863, 15.83681011], [80.7820816, 15.83681011], [80.7820816, 15.83763981], [80.78291321, 15.83763981]]], [[[80.78791809, 15.84319401], [80.78791809, 15.84291553], [80.78848267, 15.84292126], [80.78848267, 15.84263992], [80.78901672, 15.84263992], [80.78901672, 15.84235954], [80.78930664, 15.8423624], [80.78930664, 15.84208393], [80.78986359, 15.84208393], [80.78986359, 15.84180641], [80.7904129, 15.84181118], [80.7904129, 15.84069157], [80.79013824, 15.84069443], [80.79013824, 15.84041595], [80.78985596, 15.84041977], [80.78985596, 15.84014034], [80.7895813, 15.84014034], [80.7895813, 15.83986187], [80.78930664, 15.83986187], [80.78930664, 15.83958244], [80.78902435, 15.83958435], [80.78902435, 15.8381958], [80.78874969, 15.8381958], [80.78874969, 15.83763981], [80.78791809, 15.83763981], [80.78791809, 15.83792019], [80.7876358, 15.83791637], [80.7876358, 15.8381958], [80.78736115, 15.83819103], [80.78736115, 15.84014034], [80.78708649, 15.84013844], [80.78708649, 15.84097195], [80.78679657, 15.84097195], [80.78679657, 15.84125042], [80.78652954, 15.84125042], [80.78652954, 15.84152985], [80.78624725, 15.84152985], [80.78624725, 15.84263992], [80.78652954, 15.84263992], [80.78652954, 15.84292126], [80.7868042, 15.84291553], [80.7868042, 15.84319401], [80.78791809, 15.84319401]]], [[[80.7859726, 15.85652924], [80.7859726, 15.85625076], [80.78624725, 15.85625076], [80.78624725, 15.85597134], [80.7868042, 15.85597324], [80.7868042, 15.85569477], [80.78708649, 15.85569477], [80.78708649, 15.85541725], [80.78736115, 15.85542202], [80.78736115, 15.85514069], [80.7876358, 15.85514069], [80.7876358, 15.85458088], [80.78791809, 15.85458279], [80.78791809, 15.85180473], [80.7876358, 15.85181141], [80.7876358, 15.85097027], [80.78791809, 15.85097313], [80.78791809, 15.8493042], [80.78819275, 15.84931087], [80.78819275, 15.84597015], [80.78791809, 15.84597206], [80.78791809, 15.84569359], [80.7876358, 15.84569359], [80.7876358, 15.84486008], [80.78708649, 15.84485054], [80.78708649, 15.84514046], [80.78652954, 15.84514046], [80.78652954, 15.84542084], [80.78624725, 15.84541607], [80.78624725, 15.84569359], [80.7859726, 15.84568977], [80.7859726, 15.84624958], [80.78569794, 15.84624958], [80.78569794, 15.84653091], [80.78541565, 15.84652805], [80.78541565, 15.84735966], [80.78514099, 15.84736347], [80.78514099, 15.84791565], [80.7848587, 15.84791565], [80.7848587, 15.8484726], [80.78457642, 15.84846973], [80.78457642, 15.85042095], [80.78430176, 15.85042095], [80.78430176, 15.85153103], [80.7840271, 15.85152912], [80.7840271, 15.85208321], [80.78375244, 15.85208321], [80.78375244, 15.85458279], [80.7840271, 15.85458088], [80.7840271, 15.85514069], [80.78430176, 15.85514069], [80.78430176, 15.85542202], [80.7848587, 15.85541725], [80.7848587, 15.85569477], [80.78514099, 15.85569477], [80.78514099, 15.85597324], [80.78542328, 15.85597134], [80.78542328, 15.85625076], [80.78569794, 15.85625076], [80.78569794, 15.85652924], [80.7859726, 15.85652924]]], [[[80.77348328, 15.86180973], [80.77348328, 15.86125183], [80.77375031, 15.86125183], [80.77375031, 15.86097145], [80.77402496, 15.86097145], [80.77402496, 15.86013889], [80.77430725, 15.86014175], [80.77430725, 15.85958099], [80.77458191, 15.8595829], [80.77458191, 15.85902691], [80.77485657, 15.85903168], [80.77485657, 15.8587513], [80.77540588, 15.8587513], [80.77540588, 15.85819054], [80.7756958, 15.8581953], [80.7756958, 15.85791683], [80.77597046, 15.85791969], [80.77597046, 15.85569096], [80.77625275, 15.85569477], [80.77625275, 15.85541725], [80.77654266, 15.85542202], [80.77654266, 15.85514069], [80.77680206, 15.85514069], [80.77680206, 15.85404015], [80.77707672, 15.85404015], [80.77707672, 15.85153103], [80.7776413, 15.85153103], [80.7776413, 15.85125065], [80.77791595, 15.85125065], [80.77791595, 15.85097027], [80.77874756, 15.85097313], [80.77874756, 15.85041714], [80.77902985, 15.85042095], [80.77902985, 15.85014057], [80.77928925, 15.85014057], [80.77928925, 15.84875107], [80.77960205, 15.84875107], [80.77960205, 15.84846973], [80.77986145, 15.8484726], [80.77986145, 15.84791565], [80.78013611, 15.84791565], [80.78013611, 15.84708214], [80.7804184, 15.84708214], [80.7804184, 15.84624958], [80.78069305, 15.84624958], [80.78069305, 15.84485054], [80.7804184, 15.84486008], [80.7804184, 15.84367275], [80.7804184, 15.84347153], [80.77986145, 15.84346962], [80.77986145, 15.84375], [80.77958679, 15.84375], [80.77958679, 15.84429932], [80.77958679, 15.84458447], [80.77928925, 15.8445797], [80.77928925, 15.84514046], [80.77902985, 15.8451376], [80.77902985, 15.84597206], [80.77874756, 15.84597015], [80.77874756, 15.84624958], [80.7784729, 15.84624958], [80.7784729, 15.84681129], [80.77819824, 15.84680557], [80.77819061, 15.84708214], [80.77791595, 15.84708023], [80.77791595, 15.84735966], [80.7776413, 15.84736347], [80.7776413, 15.84791565], [80.77735901, 15.84791565], [80.77735901, 15.8484726], [80.77707672, 15.84846973], [80.77707672, 15.84875107], [80.77680206, 15.84875107], [80.77680206, 15.84903145], [80.7765274, 15.84902859], [80.7765274, 15.84958458], [80.77625275, 15.84958458], [80.77625275, 15.84986115], [80.77597046, 15.84986115], [80.77597046, 15.85014057], [80.7756958, 15.85014057], [80.7756958, 15.85042095], [80.77541351, 15.85041714], [80.77541351, 15.85097313], [80.77513885, 15.85097027], [80.77513885, 15.85153103], [80.7748642, 15.85152912], [80.7748642, 15.85208321], [80.77458191, 15.85208035], [80.77458191, 15.85264111], [80.77430725, 15.85264111], [80.77430725, 15.85292053], [80.77402496, 15.85291672], [80.77402496, 15.85319519], [80.77375031, 15.85319519], [80.77375031, 15.8534708], [80.77347565, 15.8534708], [80.77348328, 15.85375118], [80.77319336, 15.85375118], [80.77319336, 15.85404015], [80.7729187, 15.85402679], [80.7729187, 15.85486126], [80.77263641, 15.85486126], [80.77263641, 15.85542202], [80.77236176, 15.85541725], [80.77236176, 15.85569477], [80.7720871, 15.85569477], [80.7720871, 15.85597324], [80.77179718, 15.85597134], [80.77179718, 15.85736084], [80.77153015, 15.85736084], [80.77153015, 15.8587513], [80.77179718, 15.8587513], [80.77179718, 15.86014175], [80.7720871, 15.86014175], [80.7720871, 15.86042023], [80.77236176, 15.86041737], [80.77236176, 15.86097145], [80.77263641, 15.86097145], [80.77263641, 15.8615303], [80.7729187, 15.8615303], [80.7729187, 15.86180973], [80.77348328, 15.86180973]]], [[[80.05986023, 15.19986153], [80.05986023, 15.1995821], [80.06041718, 15.1995821], [80.06041718, 15.19930553], [80.06069183, 15.19931126], [80.06069183, 15.19874954], [80.06124878, 15.19874954], [80.06124878, 15.19847202], [80.06153107, 15.19847202], [80.06153107, 15.19819355], [80.06180573, 15.19819355], [80.06180573, 15.19791603], [80.06208038, 15.19793034], [80.06208038, 15.19764042], [80.06236267, 15.19764042], [80.06236267, 15.19707966], [80.06124878, 15.19707966], [80.06124878, 15.19736004], [80.06096649, 15.19736004], [80.06096649, 15.19764042], [80.06069183, 15.19764042], [80.06069183, 15.19793034], [80.06041718, 15.19791603], [80.06041718, 15.19819355], [80.06014252, 15.19819355], [80.06014252, 15.19847202], [80.05986023, 15.19847202], [80.05986023, 15.19874954], [80.0595932, 15.19874954], [80.0595932, 15.19903088], [80.05930328, 15.19902802], [80.05930328, 15.1995821], [80.05958557, 15.1995821], [80.05958557, 15.19986153], [80.05986023, 15.19986153]]], [[[80.21069336, 15.50153065], [80.21069336, 15.50125122], [80.21098328, 15.50125122], [80.21097565, 15.50069523], [80.21125031, 15.50069523], [80.21125031, 15.50041676], [80.21153259, 15.50042057], [80.21153259, 15.49985981], [80.21180725, 15.49985981], [80.21180725, 15.49931145], [80.21153259, 15.49931145], [80.21153259, 15.49903107], [80.2095871, 15.49903107], [80.2095871, 15.49931145], [80.20929718, 15.49931145], [80.20929718, 15.49985981], [80.20903015, 15.49985981], [80.20903015, 15.50042057], [80.20929718, 15.50042057], [80.20929718, 15.50097275], [80.2095871, 15.50097275], [80.2095871, 15.50125122], [80.20986176, 15.50125122], [80.20986176, 15.50153065], [80.21069336, 15.50153065]]], [[[82.31735229, 16.57653046], [82.31735229, 16.57457924], [82.31708527, 16.57458115], [82.31708527, 16.57402992], [82.31680298, 16.57403183], [82.31680298, 16.57374954], [82.31652832, 16.57374954], [82.31652832, 16.57346916], [82.3154068, 16.57346916], [82.3154068, 16.57374954], [82.31485748, 16.57374954], [82.31485748, 16.57485962], [82.31513977, 16.57485962], [82.31513977, 16.57542038], [82.31541443, 16.57541656], [82.31541443, 16.57597351], [82.31597137, 16.5759697], [82.31597137, 16.57625961], [82.31624603, 16.57625961], [82.31624603, 16.57653046], [82.31735229, 16.57653046]]], [[[83.31208038, 17.68486023], [83.31208038, 17.68403053], [83.31124878, 17.68403053], [83.31124878, 17.68374062], [83.31014252, 17.68375015], [83.31014252, 17.68347168], [83.30986023, 17.68347168], [83.30986023, 17.68319511], [83.30902863, 17.68320274], [83.30902863, 17.68292046], [83.30847168, 17.68292046], [83.30847168, 17.68264008], [83.30764771, 17.68264008], [83.30764771, 17.6823616], [83.30680847, 17.6823616], [83.30680847, 17.68208313], [83.30652618, 17.68208313], [83.30652618, 17.68180466], [83.30569458, 17.68180466], [83.30569458, 17.68152809], [83.30513763, 17.68152809], [83.30513763, 17.68124962], [83.30430603, 17.68124962], [83.30430603, 17.68097115], [83.30403137, 17.68097305], [83.30403137, 17.68069458], [83.30291748, 17.68069458], [83.30291748, 17.68041611], [83.30236053, 17.68041992], [83.30236053, 17.68013954], [83.30179596, 17.68013954], [83.30179596, 17.67986107], [83.30069733, 17.67986107], [83.30069733, 17.67958069], [83.30014038, 17.6795826], [83.30014038, 17.67930794], [83.29930878, 17.67930984], [83.29930878, 17.67902946], [83.29818726, 17.67902946], [83.29818726, 17.67930984], [83.29792023, 17.67930794], [83.29792023, 17.6795826], [83.29902649, 17.67958069], [83.29902649, 17.67986107], [83.29985809, 17.67986107], [83.29985809, 17.68013954], [83.30042267, 17.68013954], [83.30042267, 17.68041992], [83.30152893, 17.68041611], [83.30152893, 17.68069458], [83.30180359, 17.68069458], [83.30180359, 17.68097305], [83.30263519, 17.68097305], [83.30263519, 17.68124962], [83.3034668, 17.68124962], [83.3034668, 17.68152809], [83.30403137, 17.68152809], [83.30403137, 17.68180466], [83.30486298, 17.68180466], [83.30486298, 17.68208313], [83.30541992, 17.68208313], [83.30541992, 17.6823616], [83.30596924, 17.6823616], [83.30596924, 17.68264008], [83.30652618, 17.68264008], [83.30652618, 17.68292046], [83.30735779, 17.68292046], [83.30735779, 17.68320274], [83.30791473, 17.68319511], [83.30791473, 17.68347168], [83.30874634, 17.68347168], [83.30874634, 17.68375015], [83.30930328, 17.68374062], [83.30930328, 17.68403053], [83.30986023, 17.68403053], [83.30986023, 17.68431282], [83.31069183, 17.68430519], [83.31069183, 17.68458366], [83.31124878, 17.68458176], [83.31124878, 17.68486023], [83.31208038, 17.68486023]]], [[[83.30569458, 17.68458366], [83.30569458, 17.68347168], [83.30541992, 17.68347168], [83.30541992, 17.68319511], [83.30458832, 17.68320274], [83.30458832, 17.68292046], [83.30430603, 17.68292046], [83.30430603, 17.68264008], [83.30403137, 17.68264008], [83.30403137, 17.6823616], [83.30319214, 17.6823616], [83.30319214, 17.68264008], [83.30291748, 17.68264008], [83.30291748, 17.68320274], [83.30319214, 17.68319511], [83.30319214, 17.68347168], [83.30347443, 17.68347168], [83.30347443, 17.68375015], [83.30374908, 17.68374062], [83.30374908, 17.68403053], [83.30430603, 17.68403053], [83.30430603, 17.68431282], [83.30513763, 17.68430519], [83.30513763, 17.68458366], [83.30569458, 17.68458366]]], [[[83.17207336, 17.56903076], [83.17207336, 17.56875038], [83.17236328, 17.56875038], [83.17236328, 17.56680107], [83.17208099, 17.56680489], [83.17208099, 17.56652832], [83.17180634, 17.56653976], [83.17180634, 17.56624985], [83.17124939, 17.56624985], [83.17124939, 17.56596947], [83.17069244, 17.56596947], [83.17069244, 17.56624985], [83.17041779, 17.56624985], [83.17041779, 17.56680489], [83.17069244, 17.56680489], [83.17069244, 17.56708336], [83.17097473, 17.56708336], [83.17097473, 17.56736183], [83.17124939, 17.56735992], [83.17124939, 17.56875038], [83.17151642, 17.56875038], [83.17151642, 17.56903076], [83.17207336, 17.56903076]]], [[[83.26985931, 17.70874977], [83.26985931, 17.70819092], [83.26875305, 17.70819473], [83.26875305, 17.7084713], [83.26847076, 17.7084713], [83.26847076, 17.70986176], [83.26875305, 17.70986176], [83.26875305, 17.71014023], [83.2701416, 17.71014023], [83.2701416, 17.70874977], [83.26985931, 17.70874977]]], [[[82.33207703, 16.72486115], [82.33207703, 16.72513962], [82.33180237, 16.72513962], [82.33180237, 16.72542], [82.33152771, 16.72541618], [82.33152771, 16.72597313], [82.33125305, 16.72597122], [82.33125305, 16.72624969], [82.33152771, 16.72624969], [82.33152771, 16.72653008], [82.33180237, 16.72652817], [82.33180237, 16.72708321], [82.33152771, 16.72707939], [82.33152771, 16.72764015], [82.33180237, 16.72764015], [82.33180237, 16.72820091], [82.33235168, 16.72820091], [82.33235168, 16.72792053], [82.3326416, 16.72792053], [82.3326416, 16.72764015], [82.33319092, 16.72764015], [82.33319092, 16.72707939], [82.33347321, 16.72708321], [82.33347321, 16.72652817], [82.33319092, 16.72653008], [82.33319092, 16.72624969], [82.33347321, 16.72624969], [82.33347321, 16.72597122], [82.33374786, 16.72597313], [82.33374786, 16.72513962], [82.33319092, 16.72513962], [82.33319092, 16.72486115], [82.33207703, 16.72486115]]], [[[82.35430908, 16.71403122], [82.35457611, 16.71403122], [82.35457611, 16.71375084], [82.3548584, 16.71375084], [82.3548584, 16.71292114], [82.35514069, 16.71292114], [82.35514069, 16.71264076], [82.35542297, 16.71264076], [82.35542297, 16.71236038], [82.35819244, 16.71236038], [82.35819244, 16.71208], [82.35874939, 16.71208], [82.35874939, 16.71236038], [82.35901642, 16.71236038], [82.35901642, 16.71292114], [82.35930634, 16.71291733], [82.35930634, 16.7131958], [82.35986328, 16.7131958], [82.35986328, 16.71347237], [82.36042023, 16.71347046], [82.36042023, 16.71375084], [82.36068726, 16.71375084], [82.36068726, 16.71430969], [82.36096954, 16.71430588], [82.36096954, 16.71458244], [82.36125183, 16.714571], [82.36125183, 16.71486092], [82.36152649, 16.71486092], [82.36152649, 16.71513939], [82.36207581, 16.71513939], [82.36207581, 16.71541977], [82.36264038, 16.71541786], [82.36264038, 16.71569443], [82.36291504, 16.71569443], [82.36291504, 16.71624947], [82.36319733, 16.71624947], [82.36319733, 16.71652985], [82.36347198, 16.71652794], [82.36347198, 16.71708298], [82.36374664, 16.71708298], [82.36374664, 16.71736145], [82.36430359, 16.71736145], [82.36430359, 16.71763992], [82.36458588, 16.71763039], [82.36458588, 16.7179184], [82.36486053, 16.7179184], [82.36486053, 16.71902847], [82.36458588, 16.71902847], [82.36458588, 16.72070122], [82.36486053, 16.72070122], [82.36486053, 16.72153282], [82.36458588, 16.72153282], [82.36458588, 16.72291946], [82.36430359, 16.72291756], [82.36430359, 16.7234745], [82.36402893, 16.72347069], [82.36402893, 16.7237606], [82.36374664, 16.7237606], [82.36374664, 16.72486115], [82.36347198, 16.72486115], [82.36347198, 16.72542], [82.36319733, 16.72541618], [82.36319733, 16.72569466], [82.36208344, 16.72569466], [82.36208344, 16.72541618], [82.35986328, 16.72541618], [82.35986328, 16.72597313], [82.35958099, 16.72597122], [82.35958099, 16.72624969], [82.35901642, 16.72624969], [82.35901642, 16.72653008], [82.35874939, 16.72652817], [82.35874939, 16.72680664], [82.35819244, 16.72680664], [82.35819244, 16.72708321], [82.35791779, 16.72707939], [82.35791779, 16.72764015], [82.3584671, 16.72764015], [82.3584671, 16.72792053], [82.35901642, 16.72792053], [82.35901642, 16.72820091], [82.35930634, 16.72819519], [82.35930634, 16.72847176], [82.36042023, 16.72847176], [82.36042023, 16.72819519], [82.36068726, 16.72820091], [82.36068726, 16.72764015], [82.36125183, 16.72764015], [82.36125183, 16.72735977], [82.36152649, 16.72736168], [82.36152649, 16.72708321], [82.36458588, 16.72708321], [82.36458588, 16.72624969], [82.36486053, 16.72624969], [82.36486053, 16.72597122], [82.36541748, 16.72597313], [82.36541748, 16.72569466], [82.36597443, 16.72569466], [82.36597443, 16.72513962], [82.36653137, 16.72513962], [82.36653137, 16.72402954], [82.36708069, 16.72402954], [82.36708069, 16.72430992], [82.36763763, 16.72430992], [82.36763763, 16.72402954], [82.36818695, 16.72402954], [82.36818695, 16.72291946], [82.36791992, 16.72291946], [82.36791992, 16.72236252], [82.36763763, 16.72236252], [82.36763763, 16.72180939], [82.36736298, 16.72180939], [82.36736298, 16.72125244], [82.36708069, 16.72125244], [82.36708069, 16.72070122], [82.36736298, 16.72070122], [82.36736298, 16.72042274], [82.36763763, 16.72042274], [82.36763763, 16.71985817], [82.36736298, 16.71986008], [82.36736298, 16.71930504], [82.36708069, 16.71931076], [82.36708069, 16.71846962], [82.36680603, 16.71847153], [82.36680603, 16.71819496], [82.36624908, 16.71820068], [82.36624908, 16.71763039], [82.36597443, 16.71763992], [82.36597443, 16.71708298], [82.36569214, 16.71708298], [82.36569214, 16.71652794], [82.36541748, 16.71652985], [82.36541748, 16.71597099], [82.36513519, 16.7159729], [82.36513519, 16.71541786], [82.36486053, 16.71541977], [82.36486053, 16.71486092], [82.36458588, 16.71486092], [82.36458588, 16.71430969], [82.36429596, 16.71430969], [82.36429596, 16.71403122], [82.36402893, 16.71403122], [82.36402893, 16.71375084], [82.36374664, 16.71375084], [82.36374664, 16.71319008], [82.36347198, 16.7131958], [82.36347198, 16.71291733], [82.36319733, 16.71292114], [82.36319733, 16.71264076], [82.36292267, 16.71264076], [82.36292267, 16.71208], [82.36264038, 16.71208572], [82.36264038, 16.71180534], [82.36235809, 16.7118206], [82.36235809, 16.71153069], [82.36207581, 16.71153069], [82.36207581, 16.71096992], [82.36180878, 16.71097374], [82.36180878, 16.71069527], [82.36152649, 16.71070099], [82.36152649, 16.71042061], [82.36125183, 16.71042061], [82.36125183, 16.71014023], [82.36096954, 16.71014023], [82.36096954, 16.70985985], [82.36069489, 16.70986366], [82.36069489, 16.70958138], [82.36042023, 16.70958138], [82.36042023, 16.70930481], [82.36013794, 16.70930481], [82.36013794, 16.70902824], [82.35986328, 16.70903015], [82.35986328, 16.70846939], [82.35958099, 16.70846939], [82.35958099, 16.70819473], [82.35930634, 16.70819473], [82.35930634, 16.7076416], [82.35901642, 16.7076416], [82.35901642, 16.70735931], [82.35874939, 16.70735931], [82.35874939, 16.7068119], [82.3584671, 16.7068119], [82.3584671, 16.70653152], [82.35819244, 16.70653152], [82.35819244, 16.70597076], [82.35791779, 16.70597267], [82.35791779, 16.7056942], [82.3576355, 16.7056942], [82.3576355, 16.70513725], [82.35679626, 16.70513916], [82.35679626, 16.70430756], [82.35652161, 16.70430756], [82.35652161, 16.70402908], [82.35624695, 16.70402908], [82.35624695, 16.70375061], [82.35597229, 16.70375061], [82.35597229, 16.70347023], [82.35514069, 16.70347214], [82.35514069, 16.70319366], [82.35430908, 16.70319366], [82.35430908, 16.70236206], [82.35402679, 16.70236015], [82.35402679, 16.70153046], [82.35375214, 16.70153046], [82.35375214, 16.70125008], [82.35346222, 16.70125008], [82.35346222, 16.7009697], [82.35319519, 16.7009716], [82.35319519, 16.70069695], [82.3529129, 16.70070076], [82.3529129, 16.70042038], [82.35263824, 16.70042038], [82.35263824, 16.69985962], [82.35236359, 16.69986153], [82.35236359, 16.69958305], [82.3520813, 16.69959068], [82.3520813, 16.6993103], [82.35180664, 16.69930077], [82.35180664, 16.69874954], [82.35151672, 16.69874954], [82.35151672, 16.69847107], [82.35124969, 16.69847488], [82.35124969, 16.6981945], [82.35097504, 16.6981945], [82.35097504, 16.69791603], [82.35069275, 16.69791985], [82.35069275, 16.69763947], [82.35041809, 16.69763947], [82.35041809, 16.6973629], [82.3501358, 16.6973629], [82.3501358, 16.69708061], [82.34986115, 16.69708443], [82.34986115, 16.69680595], [82.34958649, 16.69682121], [82.34958649, 16.69652939], [82.34929657, 16.69652939], [82.34929657, 16.69625282], [82.34902954, 16.69625282], [82.34902954, 16.69597054], [82.34874725, 16.69597054], [82.34874725, 16.6954174], [82.3484726, 16.69542122], [82.3484726, 16.69514275], [82.34819794, 16.69514275], [82.34819794, 16.69458008], [82.34791565, 16.69458389], [82.34791565, 16.69430542], [82.34764099, 16.69431114], [82.34764099, 16.69403267], [82.3473587, 16.69403267], [82.3473587, 16.69375229], [82.34707642, 16.69375229], [82.34707642, 16.69346809], [82.34680939, 16.69347191], [82.34680176, 16.69319534], [82.34625244, 16.69319916], [82.34625244, 16.69292068], [82.34597015, 16.69292068], [82.34597015, 16.6926384], [82.34570313, 16.6926384], [82.34570313, 16.69235992], [82.34541321, 16.69236183], [82.34541321, 16.69208336], [82.34513855, 16.69208336], [82.34513855, 16.69180489], [82.34486389, 16.69180489], [82.34486389, 16.69124985], [82.3445816, 16.69124985], [82.3445816, 16.69069099], [82.34430695, 16.69069481], [82.34430695, 16.69013977], [82.34401703, 16.69013977], [82.34401703, 16.68958092], [82.3429184, 16.68958282], [82.3429184, 16.68930626], [82.34263611, 16.68930817], [82.34263611, 16.68902969], [82.34236145, 16.68902969], [82.34236145, 16.68847084], [82.34208679, 16.68847275], [82.34208679, 16.68819427], [82.3418045, 16.68819427], [82.3418045, 16.68791771], [82.34152222, 16.68791962], [82.34152222, 16.68765068], [82.34124756, 16.68765068], [82.34124756, 16.68736076], [82.3409729, 16.68736076], [82.3409729, 16.68708038], [82.34069824, 16.6870842], [82.34069824, 16.68652725], [82.34041595, 16.68653107], [82.34041595, 16.68625069], [82.3401413, 16.68625069], [82.3401413, 16.68597031], [82.33985901, 16.68597221], [82.33985901, 16.68541718], [82.33930206, 16.68542099], [82.33930206, 16.68486023], [82.3390274, 16.68486023], [82.3390274, 16.68458939], [82.33875275, 16.68458939], [82.33875275, 16.68431091], [82.33847809, 16.68431091], [82.33847809, 16.68403053], [82.3381958, 16.68403053], [82.3381958, 16.68346977], [82.33791351, 16.68347359], [82.33791351, 16.68319511], [82.33763885, 16.68320084], [82.33763885, 16.68264008], [82.33735657, 16.68264008], [82.33735657, 16.6823597], [82.33708191, 16.68236351], [82.33708191, 16.68180466], [82.33680725, 16.68180466], [82.33680725, 16.68152809], [82.33651733, 16.68153191], [82.33651733, 16.68124962], [82.33625031, 16.68124962], [82.33625031, 16.68096924], [82.33569336, 16.68097115], [82.33569336, 16.68069458], [82.3354187, 16.68069458], [82.3354187, 16.68041611], [82.33513641, 16.68042183], [82.33513641, 16.68014145], [82.33486176, 16.68014145], [82.33486176, 16.67985916], [82.33429718, 16.67985916], [82.33429718, 16.67958069], [82.33403015, 16.6795826], [82.33403015, 16.67874718], [82.33374786, 16.67874908], [82.33374786, 16.67846107], [82.33347321, 16.67847252], [82.33347321, 16.67791748], [82.33319092, 16.67791748], [82.33319092, 16.67764091], [82.33291626, 16.67764091], [82.33291626, 16.67736053], [82.3326416, 16.67736053], [82.3326416, 16.67681122], [82.33235168, 16.67681122], [82.33235168, 16.67653084], [82.33207703, 16.67653084], [82.33207703, 16.67625046], [82.33180237, 16.67625046], [82.33180237, 16.6756897], [82.33152771, 16.67569351], [82.33152771, 16.67541695], [82.33125305, 16.67542076], [82.33125305, 16.67514038], [82.33097076, 16.67514038], [82.33097076, 16.67457962], [82.33069611, 16.67458344], [82.33069611, 16.67430687], [82.33040619, 16.67431068], [82.33040619, 16.67374992], [82.33013916, 16.67374992], [82.33013916, 16.67319107], [82.3298645, 16.67319679], [82.3298645, 16.67263794], [82.32958221, 16.67264938], [82.32958221, 16.67208099], [82.32930756, 16.67208481], [82.32930756, 16.67180634], [82.3290329, 16.67181015], [82.3290329, 16.67124939], [82.32875061, 16.67124939], [82.32875061, 16.67069054], [82.32847595, 16.67069435], [82.32847595, 16.67013931], [82.32818604, 16.67014122], [82.32818604, 16.66958046], [82.32791901, 16.66958046], [82.32791901, 16.6693058], [82.32763672, 16.66930962], [82.32763672, 16.66903114], [82.32736206, 16.66903114], [82.32736206, 16.66875267], [82.32680511, 16.66875267], [82.32680511, 16.66791725], [82.32653809, 16.66792107], [82.32653809, 16.66764259], [82.32624817, 16.66764259], [82.32624817, 16.66707993], [82.32597351, 16.66708374], [82.32597351, 16.66653061], [82.32569122, 16.66653061], [82.32569122, 16.66597176], [82.32541656, 16.66597176], [82.32541656, 16.66402626], [82.32514191, 16.66402817], [82.32514191, 16.66345978], [82.32485962, 16.66347313], [82.32485962, 16.66319466], [82.32458496, 16.66319466], [82.32458496, 16.66236115], [82.32430267, 16.66236115], [82.32430267, 16.66180992], [82.32402802, 16.66180992], [82.32402802, 16.66125107], [82.32375336, 16.66125107], [82.32375336, 16.66041946], [82.32319641, 16.66041946], [82.32319641, 16.65958023], [82.32291412, 16.65958595], [82.32291412, 16.6581955], [82.32236481, 16.6581955], [82.32236481, 16.65763855], [82.32208252, 16.65764046], [82.32208252, 16.65736008], [82.32236481, 16.65736389], [82.32236481, 16.65597343], [82.32208252, 16.65597343], [82.32208252, 16.65569496], [82.32180786, 16.65570068], [82.32180786, 16.6554203], [82.3215332, 16.6554203], [82.3215332, 16.65514183], [82.32125092, 16.65514183], [82.32125092, 16.65457916], [82.32096863, 16.65458107], [82.32096863, 16.65402794], [82.32068634, 16.65403175], [82.32068634, 16.65346909], [82.32041931, 16.6534729], [82.32041931, 16.65319443], [82.32069397, 16.65319443], [82.32069397, 16.65263939], [82.31930542, 16.65263939], [82.31930542, 16.65236092], [82.31874847, 16.65236092], [82.31874847, 16.65125084], [82.31846619, 16.65125084], [82.31846619, 16.65097046], [82.31903076, 16.65097237], [82.31903076, 16.65041733], [82.31931305, 16.65042114], [82.31931305, 16.65014076], [82.31958008, 16.65014076], [82.31958008, 16.64958], [82.31930542, 16.64958382], [82.31930542, 16.64791679], [82.31903076, 16.64792061], [82.31903076, 16.64764023], [82.31931305, 16.64764023], [82.31931305, 16.64747047], [82.31930542, 16.64652824], [82.31958008, 16.64653015], [82.31958008, 16.64596939], [82.31930542, 16.6459713], [82.31930542, 16.64486122], [82.31958008, 16.64486122], [82.31958008, 16.64347267], [82.31930542, 16.64347458], [82.31930542, 16.64319229], [82.31903076, 16.64319229], [82.31903076, 16.64291573], [82.31874847, 16.64291954], [82.31874847, 16.64264107], [82.31791687, 16.64264107], [82.31791687, 16.64208031], [82.31819153, 16.64208412], [82.31819153, 16.64180565], [82.31846619, 16.64180946], [82.31846619, 16.64097023], [82.31874847, 16.64097023], [82.31874847, 16.6404171], [82.31846619, 16.64042282], [82.31846619, 16.63874817], [82.31819153, 16.63874817], [82.31819153, 16.63792038], [82.31791687, 16.63792038], [82.31791687, 16.63763809], [82.31819153, 16.63763809], [82.31819153, 16.63735962], [82.31791687, 16.63736153], [82.31791687, 16.63430405], [82.31764221, 16.63430977], [82.31764221, 16.63402939], [82.31791687, 16.63402939], [82.31791687, 16.63292122], [82.31764221, 16.63292122], [82.31764221, 16.63181114], [82.31735229, 16.63181114], [82.31735229, 16.63142967], [82.31735992, 16.62986374], [82.31764221, 16.62986374], [82.31764221, 16.62958145], [82.31791687, 16.62958145], [82.31791687, 16.62930489], [82.31847382, 16.62930489], [82.31847382, 16.62875175], [82.31735229, 16.62875175], [82.31735229, 16.62903023], [82.31708527, 16.62902832], [82.31708527, 16.62958145], [82.31680298, 16.62957954], [82.31680298, 16.6301403], [82.31652832, 16.6301403], [82.31652832, 16.63070107], [82.31624603, 16.63070107], [82.31624603, 16.63125038], [82.31597137, 16.63125038], [82.31597137, 16.6320858], [82.31569672, 16.63208008], [82.31569672, 16.63292122], [82.31541443, 16.6329174], [82.31541443, 16.63329124], [82.31541443, 16.63597298], [82.31513977, 16.63597107], [82.31513977, 16.63624954], [82.31485748, 16.63624954], [82.31485748, 16.63680077], [82.31458282, 16.63680649], [82.31458282, 16.63708305], [82.31417084, 16.63708305], [82.31402588, 16.63708305], [82.31402588, 16.63736153], [82.31346893, 16.63735962], [82.31346893, 16.63763809], [82.31318665, 16.63763809], [82.31318665, 16.63820076], [82.31263733, 16.63819504], [82.31263733, 16.6384716], [82.31236267, 16.6384697], [82.31236267, 16.64180946], [82.31208038, 16.64180946], [82.31208038, 16.64264107], [82.31236267, 16.64263916], [82.31236267, 16.64319229], [82.31263733, 16.64319038], [82.31263733, 16.64375114], [82.31291962, 16.64375114], [82.31291962, 16.64431], [82.31319427, 16.64430618], [82.31319427, 16.64458466], [82.31346893, 16.64458084], [82.31346893, 16.64486122], [82.31375122, 16.64486122], [82.31375122, 16.64542007], [82.31402588, 16.64541626], [82.31402588, 16.6459713], [82.31430817, 16.64596939], [82.31430817, 16.64624977], [82.31458282, 16.64624977], [82.31458282, 16.64764023], [82.31430817, 16.64764023], [82.31430817, 16.64792061], [82.31402588, 16.64792061], [82.31402588, 16.64820099], [82.31375122, 16.64820099], [82.31375122, 16.64847946], [82.31346893, 16.64847946], [82.31346893, 16.64875031], [82.31318665, 16.64875031], [82.31318665, 16.64903069], [82.31291962, 16.64903069], [82.31291962, 16.64931107], [82.31263733, 16.64930534], [82.31263733, 16.64958382], [82.31236267, 16.64958], [82.31236267, 16.64986038], [82.31208038, 16.64986038], [82.31208038, 16.65014076], [82.31180573, 16.65013885], [82.31180573, 16.65069389], [82.31153107, 16.65069389], [82.31153107, 16.65125084], [82.30958557, 16.65125084], [82.30958557, 16.64958382], [82.30986023, 16.64958382], [82.30986023, 16.64652824], [82.31014252, 16.64653015], [82.31014252, 16.64542007], [82.31041718, 16.64542007], [82.31041718, 16.64431], [82.31069183, 16.64431], [82.31069183, 16.64402962], [82.31096649, 16.64402962], [82.31096649, 16.64375114], [82.31124878, 16.64375114], [82.31124878, 16.64264107], [82.31096649, 16.64264107], [82.31096649, 16.64234924], [82.31069183, 16.64236259], [82.31069183, 16.64208412], [82.31041718, 16.64208412], [82.31041718, 16.64097023], [82.31014252, 16.64097023], [82.31014252, 16.63986015], [82.31041718, 16.63986015], [82.31041718, 16.63958359], [82.31069183, 16.63958359], [82.31069183, 16.63930511], [82.31096649, 16.63931084], [82.31096649, 16.6384697], [82.31124878, 16.6384716], [82.31124878, 16.63763809], [82.3115387, 16.63763809], [82.3115387, 16.63735962], [82.31180573, 16.63736153], [82.31180573, 16.63680649], [82.31208038, 16.6368103], [82.31208038, 16.63653755], [82.31236267, 16.63653755], [82.31236267, 16.63624954], [82.31263733, 16.63624954], [82.31263733, 16.63597107], [82.31291962, 16.63597298], [82.31291962, 16.6356945], [82.31319427, 16.6356945], [82.31319427, 16.63541794], [82.31346893, 16.63541985], [82.31346893, 16.63513947], [82.31375122, 16.63513947], [82.31375122, 16.63458061], [82.31402588, 16.63458252], [82.31402588, 16.63402748], [82.31430817, 16.63402939], [82.31430817, 16.63348007], [82.31458282, 16.63348007], [82.31458282, 16.63292122], [82.31485748, 16.63292122], [82.31485748, 16.63208008], [82.31513977, 16.6320858], [82.31513977, 16.63097382], [82.31541443, 16.63097382], [82.31541443, 16.62875175], [82.31569672, 16.62875175], [82.31569672, 16.62818909], [82.31625366, 16.62819481], [82.31625366, 16.62791634], [82.31652832, 16.62792015], [82.31652832, 16.62734985], [82.31680298, 16.62735939], [82.31680298, 16.62708282], [82.31708527, 16.62708282], [82.31708527, 16.62680626], [82.31735229, 16.62681007], [82.31735229, 16.6265316], [82.31764221, 16.6265316], [82.31764221, 16.62597084], [82.31791687, 16.62597275], [82.31791687, 16.62513733], [82.31819153, 16.62513924], [82.31819153, 16.62402916], [82.31791687, 16.62402916], [82.31791687, 16.62347031], [82.31764221, 16.62347221], [82.31764221, 16.62208366], [82.31791687, 16.62208366], [82.31791687, 16.62180519], [82.31874847, 16.62181091], [82.31874847, 16.62125015], [82.31903076, 16.62125015], [82.31903076, 16.62070084], [82.31931305, 16.62070084], [82.31931305, 16.6198597], [82.31903076, 16.6198616], [82.31903076, 16.61819458], [82.31874847, 16.61819458], [82.31874847, 16.61680603], [82.31846619, 16.61680984], [82.31846619, 16.61597061], [82.31819153, 16.61597061], [82.31819153, 16.61541748], [82.31791687, 16.61541748], [82.31791687, 16.61486244], [82.31764221, 16.61486244], [82.31764221, 16.61403275], [82.31735229, 16.61403275], [82.31735229, 16.61292076], [82.3170929, 16.61292076], [82.3170929, 16.61236954], [82.31680298, 16.61236954], [82.31680298, 16.61181068], [82.31652832, 16.61181068], [82.31652832, 16.61124992], [82.31624603, 16.61124992], [82.31624603, 16.61096954], [82.31569672, 16.61097145], [82.31569672, 16.61069489], [82.31541443, 16.61069489], [82.31541443, 16.61041641], [82.31569672, 16.61041832], [82.31569672, 16.60958099], [82.31541443, 16.6095829], [82.31541443, 16.60902786], [82.31513977, 16.60902977], [82.31513977, 16.60819054], [82.31485748, 16.60819435], [82.31485748, 16.60791779], [82.31458282, 16.60791969], [82.31458282, 16.60736084], [82.31430817, 16.60736084], [82.31430817, 16.60708046], [82.31402588, 16.60708237], [82.31402588, 16.6068058], [82.31375122, 16.60680962], [82.31375122, 16.60624123], [82.31346893, 16.60625076], [82.31346893, 16.60541725], [82.31318665, 16.60542107], [82.31318665, 16.60457993], [82.31291962, 16.60458374], [82.31291962, 16.6040287], [82.31263733, 16.60403061], [82.31263733, 16.60346985], [82.31236267, 16.60347366], [82.31236267, 16.60291672], [82.31208038, 16.60292053], [82.31208038, 16.60235977], [82.31069183, 16.60235977], [82.31069183, 16.60264015], [82.31014252, 16.60264015], [82.31014252, 16.60292053], [82.30930328, 16.60292053], [82.30930328, 16.60320091], [82.30874634, 16.60319519], [82.30874634, 16.60347366], [82.30847168, 16.60346985], [82.30847168, 16.60375023], [82.3079071, 16.60375023], [82.3079071, 16.60403061], [82.30764008, 16.60403061], [82.30764008, 16.60431099], [82.30708313, 16.60430527], [82.30708313, 16.60458374], [82.30652618, 16.60457993], [82.30652618, 16.60486031], [82.30625153, 16.60486031], [82.30625153, 16.60514069], [82.30568695, 16.60514069], [82.30568695, 16.60542107], [82.30541992, 16.60541725], [82.30541992, 16.60569572], [82.30486298, 16.60569572], [82.30486298, 16.60597229], [82.30458069, 16.60597229], [82.30458069, 16.60625076], [82.30403137, 16.60624123], [82.30403137, 16.60653114], [82.30374908, 16.60653114], [82.30374908, 16.60680962], [82.3033905, 16.6068058], [82.30319214, 16.6068058], [82.30319214, 16.60708237], [82.30264282, 16.60708046], [82.30264282, 16.60764122], [82.30236816, 16.60764122], [82.30236816, 16.60791969], [82.30208588, 16.60791779], [82.30208588, 16.60819435], [82.30152893, 16.60819435], [82.30152893, 16.60847282], [82.30124664, 16.60847092], [82.30124664, 16.60874939], [82.30097198, 16.60874939], [82.30097198, 16.60931015], [82.30069733, 16.60930634], [82.30069733, 16.60986137], [82.30042267, 16.60985947], [82.30042267, 16.61013985], [82.30014038, 16.61013985], [82.30014038, 16.61041832], [82.29985809, 16.61041641], [82.29985809, 16.61069489], [82.29958344, 16.61069489], [82.29958344, 16.61097145], [82.29930878, 16.61096954], [82.29930878, 16.61124992], [82.29902649, 16.61124992], [82.29902649, 16.6115284], [82.29875183, 16.6115284], [82.29875183, 16.61181068], [82.29846954, 16.61180496], [82.29846954, 16.61208344], [82.29818726, 16.61207962], [82.29818726, 16.61263847], [82.29792023, 16.61263847], [82.29792023, 16.61292076], [82.29736328, 16.61291695], [82.29736328, 16.61347008], [82.29708099, 16.61346817], [82.29708099, 16.61403275], [82.29680634, 16.61402702], [82.29680634, 16.61458206], [82.29651642, 16.61458015], [82.29651642, 16.61514282], [82.29624939, 16.61514091], [82.29624939, 16.61541748], [82.2959671, 16.61541176], [82.2959671, 16.6162529], [82.29569244, 16.6162529], [82.29569244, 16.61652946], [82.29541779, 16.61652946], [82.29541779, 16.61736107], [82.2951355, 16.61736107], [82.2951355, 16.61819458], [82.29458618, 16.61818123], [82.29458618, 16.61874962], [82.29430389, 16.61874962], [82.29430389, 16.61958313], [82.29402924, 16.61958122], [82.29402924, 16.62014008], [82.29374695, 16.62014008], [82.29374695, 16.62042046], [82.29347229, 16.62042046], [82.29347229, 16.62153816], [82.29319763, 16.62152863], [82.29319763, 16.62208366], [82.29292297, 16.62207985], [82.29292297, 16.62264061], [82.29264069, 16.6226387], [82.29264069, 16.62347221], [82.2923584, 16.62347031], [82.2923584, 16.62375069], [82.29207611, 16.62375069], [82.29207611, 16.62430954], [82.29180908, 16.62430954], [82.29180908, 16.62486076], [82.29152679, 16.62486076], [82.29152679, 16.62513924], [82.29125214, 16.62513924], [82.29125214, 16.62624931], [82.29096985, 16.62624931], [82.29096985, 16.62708282], [82.29070282, 16.62708092], [82.29070282, 16.62792015], [82.29013824, 16.62792015], [82.29013824, 16.62903023], [82.28986359, 16.62902832], [82.28986359, 16.62930489], [82.2895813, 16.62930489], [82.2895813, 16.63041687], [82.28930664, 16.63041687], [82.28930664, 16.63097382], [82.28901672, 16.63097], [82.28901672, 16.63181114], [82.28874969, 16.63181114], [82.28874969, 16.63236046], [82.28848267, 16.63236046], [82.28848267, 16.63292122], [82.28791809, 16.6329174], [82.28791809, 16.63319588], [82.2876358, 16.63319016], [82.2876358, 16.63375092], [82.28736877, 16.63375092], [82.28736877, 16.63402939], [82.28708649, 16.63402939], [82.28708649, 16.63430977], [82.28652954, 16.63430977], [82.28652954, 16.63486099], [82.28624725, 16.63486099], [82.28624725, 16.63624954], [82.2859726, 16.63624954], [82.2859726, 16.63680077], [82.28569794, 16.6368103], [82.28569794, 16.63820076], [82.28542328, 16.63820076], [82.28542328, 16.63902855], [82.2848587, 16.63902855], [82.2848587, 16.63931084], [82.28457642, 16.63931084], [82.28457642, 16.64013863], [82.28430176, 16.64013863], [82.28430176, 16.64042282], [82.2840271, 16.64042282], [82.2840271, 16.6415329], [82.28430176, 16.64152718], [82.28430176, 16.64208412], [82.2840271, 16.64208412], [82.2840271, 16.64236259], [82.28375244, 16.64234924], [82.28375244, 16.64264107], [82.28320313, 16.64264107], [82.28320313, 16.64234924], [82.28291321, 16.64234924], [82.28291321, 16.64264107], [82.28235626, 16.64264107], [82.28235626, 16.64234924], [82.27485657, 16.64234924], [82.27485657, 16.64264107], [82.27375031, 16.64264107], [82.27375031, 16.64291954], [82.27319336, 16.64291573], [82.27319336, 16.64319229], [82.2729187, 16.64319229], [82.2729187, 16.64347458], [82.27236176, 16.64347267], [82.27236176, 16.64375114], [82.2701416, 16.64375114], [82.2701416, 16.64402962], [82.26930237, 16.64402962], [82.26930237, 16.64375114], [82.26875305, 16.64375114], [82.26875305, 16.64319038], [82.26763916, 16.64319229], [82.26763916, 16.64347458], [82.26708221, 16.64347267], [82.26708221, 16.64375114], [82.26680756, 16.64375114], [82.26680756, 16.64402962], [82.26625824, 16.64402962], [82.26625824, 16.64431], [82.26569366, 16.64430618], [82.26569366, 16.64458466], [82.26513672, 16.64458084], [82.26513672, 16.64486122], [82.26486206, 16.64486122], [82.26486206, 16.64513969], [82.26431274, 16.64513969], [82.26431274, 16.64542007], [82.26374817, 16.64541626], [82.26374817, 16.64569473], [82.26291656, 16.64569473], [82.26291656, 16.6459713], [82.26264191, 16.6459713], [82.26264191, 16.64569473], [82.26235962, 16.64569473], [82.26235962, 16.6459713], [82.26180267, 16.64596939], [82.26180267, 16.64624977], [82.26125336, 16.64624977], [82.26125336, 16.64653015], [82.26069641, 16.64652824], [82.26069641, 16.64680672], [82.26040649, 16.64680099], [82.26040649, 16.64764023], [82.25985718, 16.64764023], [82.25985718, 16.64792061], [82.25958252, 16.64792061], [82.25958252, 16.64847946], [82.25930786, 16.64847946], [82.25930786, 16.64875031], [82.25875092, 16.64875031], [82.25875092, 16.64931107], [82.25846863, 16.64930534], [82.25846863, 16.64958382], [82.25818634, 16.64958], [82.25818634, 16.65014076], [82.25791931, 16.65014076], [82.25791931, 16.65042114], [82.25763702, 16.65041733], [82.25763702, 16.65097237], [82.25736237, 16.65097046], [82.25736237, 16.65125084], [82.25707245, 16.65125084], [82.25707245, 16.65180969], [82.25680542, 16.65180588], [82.25681305, 16.65236092], [82.25653076, 16.65236092], [82.25653076, 16.65292168], [82.25624847, 16.65292168], [82.25624847, 16.65374947], [82.25596619, 16.65374947], [82.25596619, 16.6554203], [82.25569153, 16.6554203], [82.25569153, 16.65625191], [82.25596619, 16.65625191], [82.25596619, 16.65764046], [82.25624847, 16.65763855], [82.25624847, 16.6581955], [82.25653076, 16.65818977], [82.25653076, 16.65875053], [82.25681305, 16.65875053], [82.25681305, 16.65930939], [82.25708008, 16.65930557], [82.25708008, 16.65958595], [82.25763702, 16.65958023], [82.25763702, 16.65986061], [82.25791931, 16.65986061], [82.25791931, 16.6609726], [82.25818634, 16.66097069], [82.25818634, 16.66125107], [82.25846863, 16.66125107], [82.25846863, 16.66152954], [82.25875092, 16.66152763], [82.25875092, 16.66208267], [82.25902557, 16.66208267], [82.25902557, 16.66236115], [82.25958252, 16.66236115], [82.25958252, 16.66263962], [82.25985718, 16.66263962], [82.25985718, 16.66291809], [82.26013947, 16.66291618], [82.26013947, 16.66347313], [82.26040649, 16.66345978], [82.26040649, 16.66374969], [82.26069641, 16.66374969], [82.26069641, 16.66430473], [82.26097107, 16.66430473], [82.26097107, 16.66458321], [82.26125336, 16.66458321], [82.26125336, 16.66486168], [82.26152802, 16.66485977], [82.26152802, 16.66513824], [82.26180267, 16.66513824], [82.26180267, 16.66542053], [82.26207733, 16.66542053], [82.26207733, 16.66570091], [82.26235962, 16.66569519], [82.26235962, 16.66597176], [82.26291656, 16.66596985], [82.26291656, 16.66624832], [82.26319122, 16.66624832], [82.26319122, 16.66653061], [82.26346588, 16.66651917], [82.26346588, 16.66736031], [82.26374817, 16.66736031], [82.26374817, 16.66792107], [82.26403046, 16.66791725], [82.26403046, 16.66819382], [82.26457977, 16.66819191], [82.26457977, 16.66875267], [82.26486206, 16.66875267], [82.26486206, 16.66903114], [82.26513672, 16.66902733], [82.26513672, 16.67097473], [82.26541901, 16.67097282], [82.26541901, 16.67124939], [82.26568604, 16.67124939], [82.26568604, 16.67152977], [82.26597595, 16.67152977], [82.26597595, 16.67431068], [82.26569366, 16.67430687], [82.26569366, 16.67458344], [82.26541901, 16.67457962], [82.26541901, 16.67514038], [82.26513672, 16.67514038], [82.26513672, 16.67653084], [82.26486206, 16.67652893], [82.26486206, 16.67708397], [82.26457977, 16.67708015], [82.26457977, 16.67736053], [82.26431274, 16.67736053], [82.26431274, 16.67791748], [82.26403046, 16.67791748], [82.26403046, 16.67819405], [82.26430511, 16.67819405], [82.26430511, 16.67847252], [82.26403046, 16.67846107], [82.26403046, 16.67874908], [82.26374817, 16.67874718], [82.26374817, 16.6795826], [82.26346588, 16.67958069], [82.26347351, 16.68014145], [82.26319885, 16.68014145], [82.26319885, 16.68042183], [82.26291656, 16.68042183], [82.26291656, 16.68153191], [82.26264191, 16.68152809], [82.26264191, 16.68236351], [82.26235962, 16.6823597], [82.26235962, 16.68292046], [82.26264191, 16.68292046], [82.26264191, 16.68320084], [82.26235962, 16.68320084], [82.26235962, 16.68458939], [82.26208496, 16.68458366], [82.26208496, 16.68569565], [82.26180267, 16.68568993], [82.26180267, 16.68625069], [82.26152802, 16.68625069], [82.26152802, 16.68653107], [82.26125336, 16.68653107], [82.26125336, 16.68680954], [82.26097107, 16.68680954], [82.26097107, 16.68736076], [82.26069641, 16.68736076], [82.26069641, 16.68791962], [82.26041412, 16.68791771], [82.26041412, 16.68847275], [82.25985718, 16.68847084], [82.25985718, 16.68875122], [82.25958252, 16.68875122], [82.25958252, 16.68930817], [82.25930786, 16.68930626], [82.25930786, 16.68958282], [82.25902557, 16.68958282], [82.25902557, 16.6898613], [82.25875092, 16.6898613], [82.25875092, 16.69011116], [82.26467133, 16.69053078], [82.27633667, 16.69310951], [82.28515625, 16.6974411], [82.28539276, 16.69763947], [82.2876358, 16.69763947], [82.2876358, 16.6973629], [82.2895813, 16.6973629], [82.2895813, 16.69708061], [82.29013824, 16.69708443], [82.29013824, 16.69680595], [82.29096985, 16.69682121], [82.29096985, 16.69652939], [82.29207611, 16.69652939], [82.29207611, 16.69682121], [82.2923584, 16.69680595], [82.2923584, 16.69708443], [82.29264069, 16.69708061], [82.29264069, 16.69763947], [82.29292297, 16.69763947], [82.29292297, 16.69791985], [82.29319763, 16.69791603], [82.29319763, 16.6981945], [82.29458618, 16.6981945], [82.29458618, 16.69847488], [82.2959671, 16.69847107], [82.2959671, 16.69874954], [82.29708099, 16.69874954], [82.29708099, 16.69902992], [82.30374908, 16.69902992], [82.30374908, 16.6993103], [82.30430603, 16.6993103], [82.30430603, 16.69959068], [82.30596924, 16.69958305], [82.30596924, 16.69986153], [82.30652618, 16.69985962], [82.30652618, 16.70014], [82.30680847, 16.70014], [82.30680847, 16.70042038], [82.30735779, 16.70042038], [82.30735779, 16.70070076], [82.30791473, 16.70069695], [82.30791473, 16.7009716], [82.30847168, 16.7009697], [82.30847168, 16.70125008], [82.30902863, 16.70125008], [82.30902863, 16.70153046], [82.3095932, 16.70153046], [82.3095932, 16.70125008], [82.31041718, 16.70125008], [82.31041718, 16.70181084], [82.31069183, 16.70180511], [82.31069183, 16.70208359], [82.31153107, 16.70208359], [82.31153107, 16.70236206], [82.31208038, 16.70236206], [82.31208038, 16.70263863], [82.31236267, 16.702631], [82.31236267, 16.70292091], [82.31319427, 16.7029171], [82.31319427, 16.70347214], [82.31430817, 16.70347023], [82.31430817, 16.70375061], [82.31458282, 16.70375061], [82.31458282, 16.70402908], [82.3154068, 16.70402908], [82.3154068, 16.70430756], [82.31569672, 16.70430565], [82.31569672, 16.70458412], [82.31652832, 16.70458031], [82.31652832, 16.70486069], [82.31680298, 16.70486069], [82.31680298, 16.70513916], [82.3171463, 16.70513916], [82.31735229, 16.70513916], [82.31735229, 16.70541763], [82.31764221, 16.70541763], [82.31764221, 16.70597267], [82.31819153, 16.70597076], [82.31819153, 16.70624924], [82.31846619, 16.70624924], [82.31846619, 16.70653152], [82.31931305, 16.70653152], [82.31931305, 16.7068119], [82.31986237, 16.70680618], [82.31986237, 16.70708275], [82.32013702, 16.70708084], [82.32013702, 16.70735931], [82.32041168, 16.70735931], [82.32041168, 16.7076416], [82.32069397, 16.7076416], [82.32069397, 16.70819473], [82.32125092, 16.70819473], [82.32125092, 16.70846939], [82.3215332, 16.70846939], [82.3215332, 16.70903015], [82.32180786, 16.70902824], [82.32180786, 16.70958138], [82.32235718, 16.70957947], [82.32235718, 16.71014023], [82.32263947, 16.71014023], [82.32263947, 16.71070099], [82.32290649, 16.71070099], [82.32290649, 16.71125031], [82.32319641, 16.71125031], [82.32319641, 16.71153069], [82.32347107, 16.71152687], [82.32347107, 16.71208572], [82.32375336, 16.71208], [82.32375336, 16.71236038], [82.32402802, 16.71236038], [82.32402802, 16.71264076], [82.32430267, 16.71264076], [82.32430267, 16.71292114], [82.32458496, 16.71291733], [82.32458496, 16.71347237], [82.32514191, 16.71347046], [82.32514191, 16.71403122], [82.32569122, 16.71403122], [82.32569122, 16.71430969], [82.32662201, 16.71430779], [82.32763672, 16.71430969], [82.32763672, 16.71403122], [82.32818604, 16.71403122], [82.32818604, 16.71430969], [82.32902527, 16.71430588], [82.32902527, 16.71486092], [82.32930756, 16.71486092], [82.32930756, 16.71513939], [82.32902527, 16.71513939], [82.32902527, 16.71569443], [82.32875061, 16.71569443], [82.32875061, 16.7159729], [82.32818604, 16.71597099], [82.32818604, 16.71624947], [82.32791901, 16.71624947], [82.32791901, 16.71652985], [82.32736206, 16.71652985], [82.32736206, 16.71681023], [82.32653046, 16.71680641], [82.32653046, 16.71736145], [82.32624817, 16.71735954], [82.32624817, 16.7179184], [82.32653046, 16.71791649], [82.32653046, 16.71847153], [82.32624817, 16.71846962], [82.32624817, 16.71874809], [82.32653046, 16.71874809], [82.32653046, 16.71986008], [82.32681274, 16.71985817], [82.32681274, 16.72180939], [82.32707977, 16.72180939], [82.32707977, 16.7226429], [82.32736206, 16.72263908], [82.32736206, 16.7234745], [82.32763672, 16.7234745], [82.32763672, 16.72458458], [82.32791901, 16.72458076], [82.32791901, 16.72486115], [82.32875061, 16.72486115], [82.32875061, 16.72542], [82.32930756, 16.72542], [82.32930756, 16.72513962], [82.32958221, 16.72513962], [82.32958221, 16.72486115], [82.33207703, 16.72486115], [82.33207703, 16.72458076], [82.33180237, 16.72458458], [82.33180237, 16.72430611], [82.33235168, 16.72430992], [82.33235168, 16.7226429], [82.3326416, 16.7226429], [82.3326416, 16.72208023], [82.33291626, 16.72208214], [82.33291626, 16.72125244], [82.33319092, 16.72125244], [82.33319092, 16.72070122], [82.33347321, 16.72070122], [82.33347321, 16.72042274], [82.33374786, 16.72042274], [82.33374786, 16.72013855], [82.33429718, 16.72013855], [82.33429718, 16.71985817], [82.3345871, 16.71986008], [82.3345871, 16.71958351], [82.33625031, 16.71958351], [82.33625031, 16.71986008], [82.33651733, 16.71985817], [82.33651733, 16.72013855], [82.33680725, 16.72013855], [82.33680725, 16.71985817], [82.33763885, 16.71986008], [82.33763885, 16.71958351], [82.3373642, 16.71958351], [82.3373642, 16.71874809], [82.33708191, 16.71874809], [82.33708191, 16.7179184], [82.33680725, 16.7179184], [82.33680725, 16.71708107], [82.33625031, 16.71708298], [82.33625031, 16.71680641], [82.33598328, 16.71681023], [82.33598328, 16.71652985], [82.33569336, 16.71652985], [82.33569336, 16.71624947], [82.33598328, 16.71624947], [82.33597565, 16.7159729], [82.3354187, 16.7159729], [82.3354187, 16.71569443], [82.33597565, 16.71569443], [82.33597565, 16.71541786], [82.33651733, 16.71541977], [82.33651733, 16.71513939], [82.33708191, 16.71513939], [82.33708191, 16.71541977], [82.33735657, 16.71541977], [82.33735657, 16.71513939], [82.33790588, 16.71513939], [82.33790588, 16.71486092], [82.33847809, 16.71486092], [82.33847046, 16.71458244], [82.3390274, 16.71458244], [82.3390274, 16.7140274], [82.33930206, 16.71403122], [82.33930206, 16.71292114], [82.33957672, 16.71292114], [82.33957672, 16.71236038], [82.33985901, 16.71236038], [82.33985901, 16.7118206], [82.3401413, 16.7118206], [82.3401413, 16.71153069], [82.34041595, 16.71153069], [82.34041595, 16.71096992], [82.34069824, 16.71097374], [82.34069824, 16.71041679], [82.3409729, 16.71040154], [82.3409729, 16.71013832], [82.34124756, 16.71014023], [82.34124756, 16.70957947], [82.34152985, 16.70958138], [82.34152985, 16.70902824], [82.34179688, 16.70903015], [82.34179688, 16.70846939], [82.34208679, 16.70846939], [82.34208679, 16.70819473], [82.34319305, 16.70819473], [82.34319305, 16.70791626], [82.34348297, 16.70792007], [82.34348297, 16.7076416], [82.34402466, 16.7076416], [82.34401703, 16.70735931], [82.34430695, 16.70735931], [82.34430695, 16.70597076], [82.3445816, 16.70597267], [82.3445816, 16.70513725], [82.34485626, 16.70513916], [82.34485626, 16.70430756], [82.3445816, 16.70430756], [82.3445816, 16.70375061], [82.34319305, 16.70375061], [82.34319305, 16.70402908], [82.34263611, 16.70402908], [82.34263611, 16.70430756], [82.34208679, 16.70430565], [82.34208679, 16.70458412], [82.3418045, 16.70458412], [82.3418045, 16.70430565], [82.34124756, 16.70430756], [82.34124756, 16.70402908], [82.3409729, 16.70402908], [82.3409729, 16.70375061], [82.34041595, 16.70375061], [82.34041595, 16.70318985], [82.3401413, 16.70319366], [82.3401413, 16.7029171], [82.33985901, 16.70292091], [82.33985901, 16.702631], [82.33958435, 16.70263863], [82.33958435, 16.70236206], [82.33930206, 16.70236015], [82.33930206, 16.70207977], [82.3390274, 16.70208359], [82.3390274, 16.70180511], [82.33875275, 16.70181084], [82.33875275, 16.70153046], [82.3381958, 16.70153046], [82.3381958, 16.70125008], [82.33790588, 16.70125008], [82.33790588, 16.7009697], [82.33763885, 16.7009716], [82.33763885, 16.70069695], [82.33735657, 16.70070076], [82.33735657, 16.70042038], [82.33651733, 16.70042038], [82.33651733, 16.69985962], [82.33625031, 16.69986153], [82.33625031, 16.69930649], [82.33598328, 16.69930077], [82.33597565, 16.69902802], [82.33569336, 16.69902992], [82.33569336, 16.69874954], [82.33513641, 16.69874954], [82.33513641, 16.69819069], [82.33486176, 16.6981945], [82.33486176, 16.69763947], [82.3345871, 16.69763947], [82.3345871, 16.69652939], [82.33429718, 16.69652939], [82.33429718, 16.69542122], [82.3345871, 16.69542122], [82.3345871, 16.69486046], [82.33486176, 16.69486046], [82.33486176, 16.69375229], [82.33513641, 16.69375229], [82.33513641, 16.69319916], [82.3354187, 16.69319916], [82.3354187, 16.6926384], [82.33569336, 16.6926384], [82.33569336, 16.69180107], [82.33597565, 16.69180489], [82.33597565, 16.69152832], [82.33625031, 16.69152832], [82.33625031, 16.69124985], [82.33708191, 16.69124985], [82.33708191, 16.69152832], [82.33763885, 16.69152832], [82.33763885, 16.69180489], [82.33791351, 16.69180489], [82.33791351, 16.69208336], [82.33847046, 16.69208336], [82.33847046, 16.69236183], [82.33875275, 16.69235992], [82.33875275, 16.6926384], [82.3390274, 16.6926384], [82.3390274, 16.69292068], [82.33930206, 16.69292068], [82.33930206, 16.69319916], [82.33985901, 16.69319534], [82.33985901, 16.69347191], [82.3401413, 16.69346809], [82.3401413, 16.69403267], [82.34041595, 16.69403267], [82.34041595, 16.69431114], [82.3409729, 16.69430542], [82.3409729, 16.69458389], [82.34124756, 16.69458008], [82.34124756, 16.69486046], [82.34152222, 16.69486046], [82.34152222, 16.69542122], [82.34208679, 16.6954174], [82.34208679, 16.69569206], [82.34263611, 16.69569016], [82.34263611, 16.69625282], [82.3429184, 16.69625282], [82.3429184, 16.69708443], [82.34319305, 16.69708061], [82.34319305, 16.69763947], [82.34348297, 16.69763947], [82.34348297, 16.69791985], [82.34375, 16.69791603], [82.34375, 16.69847488], [82.34430695, 16.69847107], [82.34430695, 16.69874954], [82.34513855, 16.69874954], [82.34513855, 16.69902992], [82.34541321, 16.69902992], [82.34541321, 16.6993103], [82.34597015, 16.6993103], [82.34597015, 16.69959068], [82.34625244, 16.69958305], [82.34625244, 16.69986153], [82.3465271, 16.69985962], [82.3465271, 16.70014], [82.34680176, 16.70014], [82.34680176, 16.70042038], [82.34707642, 16.70042038], [82.34707642, 16.70070076], [82.34764099, 16.70069695], [82.34764099, 16.7009716], [82.34819794, 16.7009697], [82.34819794, 16.70125008], [82.3484726, 16.70125008], [82.3484726, 16.70181084], [82.34874725, 16.70181084], [82.34874725, 16.70292091], [82.34902954, 16.7029171], [82.34902954, 16.70347214], [82.34929657, 16.70347023], [82.34929657, 16.70402908], [82.34958649, 16.70402908], [82.34958649, 16.70430756], [82.35041809, 16.70430565], [82.35041809, 16.70458412], [82.35097504, 16.70458412], [82.35097504, 16.70486069], [82.35124969, 16.70486069], [82.35124969, 16.70513916], [82.35151672, 16.70513916], [82.35151672, 16.70541763], [82.3520813, 16.70541763], [82.3520813, 16.7056942], [82.35236359, 16.7056942], [82.35236359, 16.70597267], [82.35263824, 16.70597076], [82.35263824, 16.7068119], [82.3529129, 16.7068119], [82.3529129, 16.70735931], [82.35263824, 16.70735931], [82.35263824, 16.70846939], [82.3529129, 16.70846939], [82.3529129, 16.70986366], [82.35235596, 16.70985985], [82.35235596, 16.71014023], [82.35069275, 16.71014023], [82.35069275, 16.70985985], [82.34792328, 16.70985985], [82.34792328, 16.71042061], [82.34764099, 16.71041679], [82.34764099, 16.71097374], [82.34791565, 16.71097374], [82.34792328, 16.71236038], [82.34707642, 16.71236038], [82.34707642, 16.71208], [82.34625244, 16.71208572], [82.34625244, 16.71180534], [82.34597015, 16.71180534], [82.34597015, 16.71208572], [82.3445816, 16.71208572], [82.3445816, 16.71180534], [82.34430695, 16.7118206], [82.34430695, 16.71153069], [82.34401703, 16.71153069], [82.34401703, 16.71125031], [82.34347534, 16.71125031], [82.34347534, 16.71069527], [82.34319305, 16.71070099], [82.34319305, 16.71042061], [82.3429184, 16.71042061], [82.3429184, 16.71070099], [82.34263611, 16.71069527], [82.34263611, 16.71097374], [82.34236145, 16.71096992], [82.34236145, 16.7118206], [82.34208679, 16.7118206], [82.34208679, 16.71236038], [82.3418045, 16.71236038], [82.3418045, 16.7131958], [82.34159088, 16.71319008], [82.34152222, 16.71403122], [82.34124756, 16.7140274], [82.34124756, 16.71458244], [82.3409729, 16.714571], [82.3409729, 16.71513939], [82.34069824, 16.71513939], [82.34069061, 16.71569443], [82.3401413, 16.71569443], [82.3401413, 16.7159729], [82.34041595, 16.71597099], [82.34041595, 16.71624947], [82.3401413, 16.71624947], [82.3401413, 16.71708298], [82.33958435, 16.71708298], [82.33958435, 16.71736145], [82.33985901, 16.71735954], [82.33985901, 16.71820068], [82.34041595, 16.71819496], [82.34041595, 16.71847153], [82.34069824, 16.71847153], [82.34069824, 16.71819496], [82.3412323, 16.7181797], [82.34124756, 16.71791649], [82.34179688, 16.7179184], [82.34179688, 16.71763039], [82.34347534, 16.71763992], [82.34347534, 16.71736145], [82.34402466, 16.71736145], [82.34402466, 16.71708298], [82.34597015, 16.71708298], [82.34597015, 16.71652794], [82.34680176, 16.71652985], [82.34680939, 16.71597099], [82.3473587, 16.7159729], [82.3473587, 16.71569443], [82.3484726, 16.71569443], [82.3484726, 16.71541786], [82.34902954, 16.71541977], [82.34902954, 16.71513939], [82.35180664, 16.71513939], [82.35180664, 16.71541977], [82.3520813, 16.71541786], [82.3520813, 16.71569443], [82.35236359, 16.71569443], [82.35236359, 16.71513939], [82.35263824, 16.71513939], [82.35263824, 16.714571], [82.35346985, 16.71458244], [82.35346985, 16.71430588], [82.35430908, 16.71430969], [82.35430908, 16.71403122]]], [[[82.26235962, 16.67791748], [82.26235962, 16.67764091], [82.26264191, 16.67764091], [82.26264191, 16.67736053], [82.26291656, 16.67736053], [82.26291656, 16.67542076], [82.26319885, 16.67542076], [82.26319885, 16.67486], [82.26347351, 16.67486191], [82.26347351, 16.67458344], [82.26319122, 16.67458344], [82.26319122, 16.67430687], [82.26346588, 16.67431068], [82.26346588, 16.67346954], [82.26319122, 16.67347145], [82.26319122, 16.67180634], [82.26291656, 16.67181015], [82.26291656, 16.66986275], [82.26264191, 16.66986275], [82.26264191, 16.66958046], [82.26235962, 16.66958046], [82.26235962, 16.66986275], [82.26207733, 16.66986275], [82.26207733, 16.67014122], [82.26180267, 16.67013931], [82.26180267, 16.67069435], [82.26152802, 16.67069054], [82.26152802, 16.67264938], [82.26125336, 16.67263794], [82.26125336, 16.67347145], [82.26097107, 16.67347145], [82.26097107, 16.67597198], [82.26069641, 16.67597008], [82.26069641, 16.67625046], [82.26097107, 16.67625046], [82.26097107, 16.67736053], [82.26125336, 16.67736053], [82.26125336, 16.67764091], [82.26152802, 16.67764091], [82.26152802, 16.67791748], [82.26235962, 16.67791748]]], [[[82.31485748, 16.72597313], [82.31485748, 16.72486115], [82.31458282, 16.72486115], [82.31458282, 16.72347069], [82.31430817, 16.7234745], [82.31430817, 16.72263908], [82.31402588, 16.7226429], [82.31402588, 16.7195797], [82.31375122, 16.71958351], [82.31375122, 16.71986008], [82.31346893, 16.71986008], [82.31346893, 16.71958351], [82.31236267, 16.71958351], [82.31236267, 16.71930504], [82.31181335, 16.71931076], [82.31181335, 16.71902847], [82.31124878, 16.71902847], [82.31124878, 16.71874809], [82.30986023, 16.71874809], [82.30986023, 16.71902847], [82.3095932, 16.71902847], [82.3095932, 16.71931076], [82.30930328, 16.71930504], [82.30930328, 16.71958351], [82.30902863, 16.71958351], [82.30902863, 16.71986008], [82.30930328, 16.71985817], [82.30930328, 16.72042274], [82.3095932, 16.72042274], [82.3095932, 16.72070122], [82.30986023, 16.72070122], [82.30986023, 16.72125244], [82.31014252, 16.72125244], [82.31014252, 16.72153282], [82.31041718, 16.72153282], [82.31041718, 16.72180939], [82.31069183, 16.72180557], [82.31069183, 16.72208214], [82.31096649, 16.72208023], [82.31096649, 16.7226429], [82.31124878, 16.7226429], [82.31124878, 16.72291946], [82.31153107, 16.72291756], [82.31153107, 16.72319221], [82.31181335, 16.72319031], [82.31181335, 16.7237606], [82.31208038, 16.7237606], [82.31208038, 16.72402954], [82.31236267, 16.72402954], [82.31236267, 16.72430992], [82.31263733, 16.72430611], [82.31263733, 16.72458458], [82.31291962, 16.72458076], [82.31291962, 16.72486115], [82.31318665, 16.72486115], [82.31318665, 16.72513962], [82.31346893, 16.72513962], [82.31346893, 16.72542], [82.31375122, 16.72541618], [82.31375122, 16.72569466], [82.31402588, 16.72569466], [82.31402588, 16.72597313], [82.31485748, 16.72597313]]], [[[82.3079071, 16.71652985], [82.3079071, 16.71624947], [82.30819702, 16.71624947], [82.30819702, 16.71597099], [82.30902863, 16.7159729], [82.30902863, 16.71430588], [82.30819702, 16.71430969], [82.30819702, 16.71403122], [82.3079071, 16.71403122], [82.3079071, 16.71375084], [82.30764008, 16.71375084], [82.30764008, 16.71347046], [82.30735779, 16.71347237], [82.30735779, 16.7131958], [82.30708313, 16.7131958], [82.30708313, 16.71291733], [82.30596924, 16.71292114], [82.30596924, 16.71264076], [82.30486298, 16.71264076], [82.30486298, 16.71236038], [82.30374908, 16.71236038], [82.30374908, 16.71208], [82.30319214, 16.71208572], [82.30319214, 16.71180534], [82.30236816, 16.7118206], [82.30236816, 16.71153069], [82.30179596, 16.71153069], [82.30179596, 16.71125031], [82.30152893, 16.71125031], [82.30152893, 16.71096992], [82.30041504, 16.71097374], [82.30042267, 16.71125031], [82.30014038, 16.71125031], [82.30014038, 16.71236038], [82.30042267, 16.71236038], [82.30042267, 16.71264076], [82.30014038, 16.71264076], [82.30014038, 16.71292114], [82.30069733, 16.71291733], [82.30069733, 16.7131958], [82.30097198, 16.7131958], [82.30097198, 16.71347237], [82.30124664, 16.71347046], [82.30124664, 16.71375084], [82.30152893, 16.71375084], [82.30152893, 16.71403122], [82.30208588, 16.71403122], [82.30208588, 16.71430969], [82.30291748, 16.71430588], [82.30291748, 16.71458244], [82.30319214, 16.714571], [82.30319214, 16.71486092], [82.30374908, 16.71486092], [82.30374908, 16.71513939], [82.30430603, 16.71513939], [82.30430603, 16.71541977], [82.30458069, 16.71541786], [82.30458069, 16.71569443], [82.30486298, 16.71569443], [82.30486298, 16.7159729], [82.30513763, 16.71597099], [82.30513763, 16.71624947], [82.30708313, 16.71624947], [82.30708313, 16.71652985], [82.3079071, 16.71652985]]], [[[82.29951477, 16.71433258], [82.29957581, 16.71403122], [82.29938507, 16.71402931], [82.29943848, 16.71412849], [82.29951477, 16.71433258]]], [[[78.46292877, 12.63537025], [78.4618988, 12.6322794], [78.45907593, 12.63152027], [78.46008301, 12.62045956], [78.45961761, 12.61740971], [78.45478058, 12.61201954], [78.45140076, 12.61575127], [78.44744873, 12.61650085], [78.43943787, 12.61692047], [78.42489624, 12.61490059], [78.41834259, 12.62064171], [78.41233063, 12.61831093], [78.40711212, 12.61752033], [78.39980316, 12.6133194], [78.39955902, 12.61335087], [78.3975296, 12.61359024], [78.38613892, 12.61387062], [78.37420654, 12.61309147], [78.36833954, 12.61184025], [78.36054993, 12.61511135], [78.34835815, 12.62364101], [78.33883667, 12.63190079], [78.32939911, 12.6384306], [78.32235718, 12.63720036], [78.30876923, 12.64999962], [78.29496765, 12.65424061], [78.29045868, 12.65292072], [78.28885651, 12.6565609], [78.28700256, 12.65814972], [78.28418732, 12.66761971], [78.26722717, 12.68743038], [78.26442719, 12.69184017], [78.23906708, 12.69239235], [78.23265839, 12.69376087], [78.22744751, 12.68928146], [78.22664642, 12.68014145], [78.22808075, 12.67385101], [78.21398926, 12.67475128], [78.20011139, 12.67564201], [78.19683838, 12.67859077], [78.1953125, 12.67996979], [78.18984985, 12.6813097], [78.18946075, 12.68355083], [78.19877625, 12.68871117], [78.19934082, 12.68997955], [78.19473267, 12.69526958], [78.19608307, 12.69668961], [78.19999695, 12.69622135], [78.20324707, 12.6990099], [78.20980835, 12.69926071], [78.21382141, 12.70236015], [78.22032928, 12.70328999], [78.22722626, 12.71517181], [78.22886658, 12.72020245], [78.21927643, 12.7470293], [78.2199173, 12.74962139], [78.22064972, 12.75259018], [78.22512054, 12.75493145], [78.22949982, 12.76200962], [78.23542786, 12.78757954], [78.24021912, 12.80314159], [78.24186707, 12.8123312], [78.2410965, 12.84742069], [78.24465942, 12.85110092], [78.24874878, 12.8498497], [78.25382233, 12.8495903], [78.25814819, 12.85562992], [78.26262665, 12.85659027], [78.27056885, 12.8505497], [78.27568817, 12.84916019], [78.30310059, 12.84720039], [78.30622101, 12.85647106], [78.30409241, 12.8657608], [78.31105042, 12.86537075], [78.32158661, 12.86285019], [78.32271576, 12.86785126], [78.32749176, 12.8740406], [78.32271576, 12.87619019], [78.32141876, 12.87165928], [78.31617737, 12.87220192], [78.31093597, 12.8738308], [78.30996704, 12.87648201], [78.31328583, 12.87977123], [78.31240845, 12.88330078], [78.31347656, 12.88862133], [78.31645966, 12.89261055], [78.32216644, 12.88960075], [78.32718658, 12.88923073], [78.33833313, 12.90649986], [78.33773041, 12.91312122], [78.33827209, 12.91575146], [78.34398651, 12.91809177], [78.34041595, 12.92198944], [78.34076691, 12.92492008], [78.34542847, 12.92806053], [78.36097717, 12.91161919], [78.36868286, 12.90178013], [78.37834167, 12.89519119], [78.38337708, 12.89540958], [78.38508606, 12.89625072], [78.38839722, 12.90552044], [78.39953613, 12.89620113], [78.40291595, 12.89132118], [78.41152954, 12.89089966], [78.41734314, 12.88903141], [78.42465973, 12.89341068], [78.42489624, 12.89817047], [78.42640686, 12.90206146], [78.43582916, 12.90067005], [78.43570709, 12.88885975], [78.43830109, 12.88624096], [78.43849182, 12.87974072], [78.44644165, 12.87473202], [78.45266724, 12.86549187], [78.45211792, 12.85572147], [78.45423889, 12.85316181], [78.45694733, 12.8660593], [78.45833588, 12.87972069], [78.45613098, 12.89275265], [78.4490509, 12.8966589], [78.44290161, 12.90411186], [78.4412384, 12.90563202], [78.43447113, 12.90827084], [78.4259491, 12.91713047], [78.4213562, 12.92352962], [78.42035675, 12.92895889], [78.42328644, 12.93379974], [78.42459106, 12.93820953], [78.41977692, 12.94668198], [78.420578, 12.94764996], [78.42735291, 12.95053101], [78.42384338, 12.95440102], [78.42282104, 12.95773125], [78.42191315, 12.96274853], [78.4226532, 12.96860027], [78.42565155, 12.96977139], [78.43358612, 12.96877956], [78.457901, 12.96324158], [78.45759583, 12.97066021], [78.45939636, 12.97575188], [78.46142578, 12.97912025], [78.45542145, 12.99009037], [78.45231628, 13.00376034], [78.45263672, 13.00858116], [78.45036316, 13.01487064], [78.44991302, 13.0258112], [78.4506073, 13.0282402], [78.45157623, 13.03153229], [78.45500946, 13.03259087], [78.46105194, 13.03201008], [78.46472168, 13.03489971], [78.46704865, 13.04137135], [78.47107697, 13.04385853], [78.47738647, 13.04322147], [78.48108673, 13.04438972], [78.48750305, 13.04939079], [78.48792267, 13.04972076], [78.50457764, 13.05276203], [78.50479889, 13.05937958], [78.4985733, 13.06979084], [78.49958038, 13.07582188], [78.50192261, 13.08166122], [78.50681305, 13.08419132], [78.5138092, 13.08468056], [78.51480865, 13.09111023], [78.52796173, 13.09735966], [78.52237701, 13.09966183], [78.5161972, 13.10081959], [78.51113892, 13.10632992], [78.50869751, 13.11326981], [78.50875092, 13.11958981], [78.51291656, 13.12023067], [78.52143097, 13.12905121], [78.53544617, 13.13074017], [78.53669739, 13.13693047], [78.53269958, 13.14209175], [78.53369904, 13.14610958], [78.53878021, 13.15157127], [78.54685974, 13.15343094], [78.55805969, 13.15234184], [78.56125641, 13.15570068], [78.56536865, 13.15681076], [78.56907654, 13.1564827], [78.56568146, 13.17175102], [78.56472778, 13.17404079], [78.56333923, 13.17740059], [78.55940247, 13.17980099], [78.55647278, 13.179842], [78.55349731, 13.17987061], [78.54688263, 13.17862034], [78.54247284, 13.18017006], [78.54094696, 13.18725109], [78.5532608, 13.18924141], [78.5583725, 13.19218063], [78.56012726, 13.19820023], [78.56588745, 13.20088959], [78.56867981, 13.20426273], [78.56433105, 13.20805073], [78.55719757, 13.21202087], [78.55887604, 13.22713089], [78.5594101, 13.23038197], [78.55989075, 13.23337173], [78.56321716, 13.23841095], [78.56854248, 13.24353027], [78.57215118, 13.24860096], [78.57746887, 13.26204967], [78.57611084, 13.2671299], [78.56716919, 13.27177143], [78.56443787, 13.28341007], [78.56156158, 13.28803921], [78.56009674, 13.29334927], [78.55565643, 13.29942989], [78.55413818, 13.2983017], [78.55323029, 13.28462029], [78.55060577, 13.27602959], [78.54717255, 13.27267075], [78.54361725, 13.27323246], [78.53557587, 13.27608013], [78.53327179, 13.27600098], [78.52876282, 13.27586174], [78.52561951, 13.26929092], [78.52377319, 13.26062107], [78.52229309, 13.25811195], [78.52079773, 13.25559139], [78.51550293, 13.2571497], [78.51197052, 13.25995064], [78.5083313, 13.26947117], [78.50392914, 13.27245045], [78.50115967, 13.27721119], [78.49521637, 13.279212], [78.48352814, 13.28808022], [78.47255707, 13.29113197], [78.4701767, 13.29390144], [78.47174835, 13.30792046], [78.46640015, 13.31012154], [78.46053314, 13.30792046], [78.45417786, 13.30414963], [78.44790649, 13.30281925], [78.44507599, 13.30139923], [78.44130707, 13.29950142], [78.43785858, 13.29876041], [78.43598175, 13.29835033], [78.43031311, 13.3078289], [78.42906952, 13.31711197], [78.42682648, 13.31807995], [78.42446899, 13.31910133], [78.42077637, 13.3190918], [78.41526031, 13.31713009], [78.40706635, 13.31009197], [78.40206146, 13.30737972], [78.39125061, 13.30370998], [78.38291168, 13.3140707], [78.37914276, 13.31687927], [78.37512207, 13.31859112], [78.36699677, 13.32003975], [78.36791229, 13.3284893], [78.37129211, 13.33240891], [78.37754059, 13.33131981], [78.3753891, 13.32640171], [78.37899017, 13.32452106], [78.38456726, 13.32354069], [78.38838959, 13.31845188], [78.39125061, 13.32371044], [78.39523315, 13.32256985], [78.39737701, 13.33233166], [78.39253235, 13.33554077], [78.38491058, 13.33820057], [78.38366699, 13.34235096], [78.37477112, 13.3464098], [78.36818695, 13.34831142], [78.3640213, 13.34830189], [78.36051178, 13.34696198], [78.35839844, 13.34684086], [78.35640717, 13.34671974], [78.35515594, 13.35507107], [78.3598175, 13.36432171], [78.36444855, 13.37049103], [78.36871338, 13.37981129], [78.37127686, 13.39100075], [78.37127686, 13.3971796], [78.36946106, 13.40894985], [78.3673172, 13.41500092], [78.36531067, 13.42439079], [78.36702728, 13.4312706], [78.36463165, 13.43685055], [78.36416626, 13.43791103], [78.36419678, 13.44561195], [78.36255646, 13.45207119], [78.3635788, 13.45924091], [78.36728668, 13.46685123], [78.3674469, 13.48197079], [78.36828613, 13.48976994], [78.36728668, 13.49517155], [78.36958313, 13.49993038], [78.37419128, 13.50551033], [78.37309265, 13.5122509], [78.38546753, 13.53166962], [78.38600922, 13.54395199], [78.39775848, 13.56619167], [78.39389801, 13.57065201], [78.39076233, 13.5781002], [78.38031769, 13.58130932], [78.36709595, 13.58030033], [78.36139679, 13.57887268], [78.34366608, 13.57778072], [78.3228302, 13.58299065], [78.31247711, 13.58350182], [78.2918396, 13.57882023], [78.28058624, 13.577672], [78.26539612, 13.57822132], [78.25827026, 13.57530975], [78.24967957, 13.57430077], [78.23655701, 13.58449078], [78.22769165, 13.58722115], [78.22261047, 13.57709026], [78.21840668, 13.57800198], [78.21479034, 13.58010101], [78.20849609, 13.58188057], [78.20240021, 13.56796932], [78.19583893, 13.56068134], [78.18900299, 13.55638027], [78.18327332, 13.55638027], [78.18161011, 13.5591507], [78.18012238, 13.56417179], [78.18105316, 13.5737009], [78.17946625, 13.57894135], [78.18856812, 13.58840179], [78.19374084, 13.59490204], [78.19536591, 13.6015501], [78.19393921, 13.61615944], [78.18583679, 13.62117958], [78.16555786, 13.62097073], [78.16053772, 13.62343025], [78.15899658, 13.64517117], [78.15576172, 13.64871025], [78.14617157, 13.64966011], [78.12908936, 13.64826965], [78.12322998, 13.64890099], [78.1158905, 13.64563084], [78.10736084, 13.64709187], [78.09390259, 13.6402607], [78.09060669, 13.63300037], [78.08634949, 13.63350105], [78.08072662, 13.63534069], [78.07965851, 13.64454174], [78.07998657, 13.65038967], [78.07280731, 13.65517139], [78.06585693, 13.6644907], [78.05834198, 13.66697025], [78.06092072, 13.6717701], [78.06408691, 13.67455959], [78.06537628, 13.68006039], [78.06260681, 13.68560028], [78.0640564, 13.68817997], [78.08515167, 13.68063164], [78.09986877, 13.68256187], [78.1053772, 13.68440056], [78.10721588, 13.69835186], [78.10988617, 13.70395184], [78.10938263, 13.71023083], [78.1055069, 13.71463203], [78.10044098, 13.71801186], [78.09738922, 13.72315121], [78.09327698, 13.72762108], [78.08492279, 13.7334919], [78.08927155, 13.74304962], [78.09532166, 13.75028038], [78.10119629, 13.75298977], [78.10649872, 13.75679111], [78.11100769, 13.76175117], [78.11823273, 13.77690029], [78.11517334, 13.78767967], [78.10900116, 13.79836273], [78.10765839, 13.80360031], [78.11725616, 13.82177162], [78.11353302, 13.84089088], [78.10604095, 13.85354137], [78.09736633, 13.85276127], [78.08837891, 13.85491943], [78.07491302, 13.85491943], [78.07092285, 13.87195969], [78.06796265, 13.8745203], [78.06034851, 13.87678146], [78.05471039, 13.87935162], [78.04831696, 13.88453007], [78.04115295, 13.88672924], [78.04270172, 13.87337971], [78.04292297, 13.86378098], [78.04133606, 13.8580513], [78.03782654, 13.85284996], [78.01558685, 13.85438156], [78.01033783, 13.85649014], [78.004776, 13.86171055], [77.99149323, 13.86241055], [77.98516083, 13.86166954], [77.98226929, 13.85680199], [77.98123932, 13.84879971], [77.97038269, 13.82664204], [77.96578217, 13.82015991], [77.94458008, 13.81997108], [77.94814301, 13.82480145], [77.94805145, 13.82936096], [77.94571686, 13.83980179], [77.94184113, 13.87105083], [77.94246674, 13.8802309], [77.9495163, 13.88447094], [77.97161865, 13.88858891], [77.97802734, 13.89334965], [77.97466278, 13.90533161], [77.97460175, 13.91225147], [77.97336578, 13.91988182], [77.97351074, 13.92422962], [77.97795105, 13.93762016], [77.97857666, 13.94765091], [77.96643066, 13.95055199], [77.96127319, 13.9499712], [77.95532227, 13.94190025], [77.95426941, 13.93704987], [77.95075989, 13.92792034], [77.9490509, 13.92673969], [77.94602203, 13.92843056], [77.93885803, 13.92461967], [77.93564606, 13.91790962], [77.92973328, 13.90880966], [77.91980743, 13.89870167], [77.91160583, 13.89724064], [77.90593719, 13.89945126], [77.90045166, 13.90234089], [77.89570618, 13.90771961], [77.88968658, 13.9113512], [77.88732147, 13.91774082], [77.88786316, 13.92772198], [77.88698578, 13.93118191], [77.86242676, 13.92680073], [77.85407257, 13.9270792], [77.84600067, 13.92832088], [77.83011627, 13.92715168], [77.82158661, 13.93054104], [77.81829071, 13.93488121], [77.81423187, 13.93100166], [77.80848694, 13.9225893], [77.80635071, 13.91755009], [77.80635834, 13.90864086], [77.80737305, 13.90322971], [77.81108093, 13.89470196], [77.81468964, 13.89111042], [77.82099152, 13.88923168], [77.82504272, 13.87990093], [77.82724762, 13.87160015], [77.81920624, 13.86602116], [77.82772064, 13.86061954], [77.81080627, 13.85211182], [77.80784607, 13.8466711], [77.80278015, 13.84066963], [77.79453278, 13.84095955], [77.78637695, 13.83992004], [77.77603912, 13.8359108], [77.77410126, 13.83173084], [77.77742767, 13.82406044], [77.78026581, 13.82002068], [77.78044128, 13.8166914], [77.77848816, 13.81289196], [77.76921082, 13.8085413], [77.75533295, 13.80754089], [77.74817657, 13.80620956], [77.74102783, 13.803792], [77.7335968, 13.80344105], [77.72841644, 13.80173969], [77.71849823, 13.79272175], [77.71286011, 13.79051971], [77.71512604, 13.78327179], [77.7127533, 13.7747097], [77.71420288, 13.76079082], [77.7131424, 13.75074005], [77.71346283, 13.74615002], [77.71100616, 13.73771], [77.70874786, 13.73273945], [77.70736694, 13.73418045], [77.70218658, 13.73099136], [77.69552612, 13.76143169], [77.68467712, 13.75862122], [77.67881775, 13.75568104], [77.66850281, 13.75228119], [77.66371155, 13.75226021], [77.66979218, 13.76255989], [77.67176819, 13.77013111], [77.67022705, 13.7774992], [77.66401672, 13.77587032], [77.65659332, 13.77666092], [77.649086, 13.77583981], [77.61434937, 13.76031017], [77.610466, 13.75543976], [77.61264801, 13.74687004], [77.63375092, 13.74129105], [77.63674927, 13.73524189], [77.63356018, 13.73283958], [77.62851715, 13.72994137], [77.62124634, 13.72740173], [77.61564636, 13.72836113], [77.60427094, 13.74255085], [77.59559631, 13.74357891], [77.5868988, 13.7367897], [77.58154297, 13.73057175], [77.57363129, 13.72665024], [77.56661987, 13.72938919], [77.55607605, 13.71646023], [77.54814148, 13.72040939], [77.54514313, 13.72818089], [77.54155731, 13.73493195], [77.53951263, 13.74372005], [77.52950287, 13.74585056], [77.51966858, 13.74384975], [77.51512146, 13.73703957], [77.52268982, 13.73107147], [77.52659607, 13.72525024], [77.52754211, 13.71903038], [77.52783966, 13.70703125], [77.5255661, 13.69721031], [77.52152252, 13.68787003], [77.5123291, 13.68568039], [77.50797272, 13.68879986], [77.50691986, 13.69266129], [77.50679016, 13.70047092], [77.50276947, 13.7044096], [77.48734283, 13.70679188], [77.47972107, 13.70321083], [77.48239899, 13.6988306], [77.48352051, 13.69170094], [77.48513794, 13.68669033], [77.48294067, 13.67970181], [77.47648621, 13.67759991], [77.44975281, 13.67579079], [77.44481659, 13.69576073], [77.44600677, 13.70063972], [77.45340729, 13.70409966], [77.45684814, 13.71263981], [77.45806885, 13.72303867], [77.45809937, 13.73033047], [77.46006012, 13.73388958], [77.46261597, 13.74357891], [77.46212006, 13.74905109], [77.4587326, 13.74981022], [77.4539566, 13.77804184], [77.45240021, 13.78040123], [77.45079041, 13.78553104], [77.4527359, 13.79131985], [77.45745087, 13.79705048], [77.45559692, 13.79981041], [77.44676971, 13.80202961], [77.44056702, 13.80229187], [77.43546295, 13.79923058], [77.42865753, 13.78798962], [77.4200592, 13.78896141], [77.41689301, 13.79094028], [77.41954041, 13.79580116], [77.41925812, 13.79971027], [77.41470337, 13.80019093], [77.41158295, 13.79889107], [77.40866089, 13.79925156], [77.40820313, 13.80247021], [77.41368103, 13.80738068], [77.41275787, 13.81175041], [77.41506195, 13.81536007], [77.42472076, 13.82668972], [77.42624664, 13.82973003], [77.42453003, 13.83512974], [77.41873932, 13.83353043], [77.40393066, 13.83142185], [77.39920044, 13.83242035], [77.38983917, 13.83292961], [77.38111115, 13.83125114], [77.37285614, 13.83128929], [77.3731308, 13.83819103], [77.36753845, 13.84320927], [77.35946655, 13.8456707], [77.35220337, 13.84438133], [77.34697723, 13.83958054], [77.3398819, 13.83484936], [77.33468628, 13.82942009], [77.32724762, 13.82479191], [77.32000732, 13.8257513], [77.31616211, 13.83973122], [77.31088257, 13.85113144], [77.30693054, 13.85723972], [77.29602814, 13.8535614], [77.28970337, 13.85002232], [77.28552246, 13.84603119], [77.28292847, 13.84097958], [77.27514648, 13.84280109], [77.25595093, 13.83945084], [77.2504425, 13.83947086], [77.2530365, 13.85612106], [77.24373627, 13.86029053], [77.24073792, 13.86588192], [77.23925018, 13.87359047], [77.23882294, 13.88150978], [77.24156189, 13.88885117], [77.24009705, 13.89408016], [77.23384094, 13.89493179], [77.22547913, 13.89546967], [77.22189331, 13.88883114], [77.22093201, 13.8817606], [77.21700287, 13.86926174], [77.2115097, 13.86141872], [77.20812225, 13.86040115], [77.20884705, 13.87843132], [77.2049408, 13.88116074], [77.20256805, 13.87484074], [77.20095825, 13.86651993], [77.19689178, 13.85953045], [77.19271088, 13.8562212], [77.17880249, 13.85984039], [77.17513275, 13.8614006], [77.17822266, 13.8713913], [77.17959595, 13.87833118], [77.17920685, 13.88328075], [77.18134308, 13.89118958], [77.18221283, 13.90130043], [77.18161774, 13.91077042], [77.17703247, 13.91740036], [77.17006683, 13.91634178], [77.15956116, 13.90846062], [77.15593719, 13.89981174], [77.15702057, 13.89130116], [77.16171265, 13.88243103], [77.1623764, 13.87629128], [77.16491699, 13.86621857], [77.16249084, 13.85698032], [77.14821625, 13.85980129], [77.13938904, 13.85904026], [77.13015747, 13.84993935], [77.12388611, 13.84939003], [77.12526703, 13.8430109], [77.14045715, 13.83788967], [77.14576721, 13.83493996], [77.14789581, 13.82885075], [77.15791321, 13.82547092], [77.1622467, 13.8207407], [77.16194153, 13.81546116], [77.15619659, 13.81134033], [77.15537262, 13.80739021], [77.15632629, 13.80375957], [77.15409851, 13.8005619], [77.15573883, 13.79814243], [77.15599823, 13.79331017], [77.15849304, 13.78710079], [77.16407013, 13.78035069], [77.16918945, 13.77556038], [77.17134094, 13.7720499], [77.16964722, 13.76136971], [77.1665802, 13.75466919], [77.15815735, 13.75493145], [77.14673615, 13.75475121], [77.13751984, 13.75565243], [77.1341095, 13.75303078], [77.1235199, 13.75089073], [77.11094666, 13.75462055], [77.09526825, 13.76088047], [77.08577728, 13.758111], [77.08521271, 13.75455093], [77.08036041, 13.75342274], [77.07927704, 13.74602032], [77.08058929, 13.73739147], [77.07148743, 13.73875046], [77.06004333, 13.73886108], [77.05474854, 13.74450016], [77.04734802, 13.75607967], [77.03518677, 13.76928139], [77.02636719, 13.77144146], [77.01986694, 13.76986027], [77.01844025, 13.76169968], [77.01384735, 13.74747181], [77.0114212, 13.73272133], [77.00193787, 13.73666191], [76.993927, 13.74151039], [76.99259186, 13.74255085], [76.99167633, 13.7453413], [76.99212646, 13.74950886], [76.99012756, 13.7530899], [76.98898315, 13.76018047], [76.98634338, 13.76652145], [76.98435974, 13.77657032], [76.98123169, 13.78579998], [76.98484802, 13.78870106], [76.98577881, 13.79300022], [76.98371887, 13.80418968], [76.98002625, 13.80719185], [76.96882629, 13.8102417], [76.96839142, 13.81439018], [76.97155762, 13.81886101], [76.97653961, 13.82136059], [76.9839859, 13.82774067], [76.98625946, 13.83922958], [76.9899292, 13.83950996], [76.994133, 13.83897018], [77.00598907, 13.85009003], [77.00711823, 13.85417175], [77.00802612, 13.86290073], [77.01230621, 13.86409092], [77.01259613, 13.86723995], [77.01169586, 13.87144089], [77.01661682, 13.88772964], [77.01728058, 13.89337063], [77.02780914, 13.89717007], [77.04128265, 13.8973999], [77.0358429, 13.92559147], [77.01860046, 13.93479156], [77.01397705, 13.93948174], [77.00810242, 13.94736958], [76.99942017, 13.95044041], [76.99505615, 13.9527216], [76.99433136, 13.95337963], [76.98899841, 13.95669174], [76.99019623, 13.97027969], [76.99133301, 13.97581196], [76.99437714, 13.98149109], [76.98501587, 13.98752022], [76.97734833, 13.99387074], [76.97764587, 13.99386024], [76.97518158, 13.99658966], [76.96420288, 14.00224018], [76.94857025, 14.00677967], [76.9447403, 14.0106802], [76.94232941, 14.01548004], [76.94078064, 14.02060127], [76.93109894, 14.02273178], [76.93371582, 14.04067135], [76.93797302, 14.04759979], [76.94328308, 14.04721928], [76.94972992, 14.04784107], [76.9715271, 14.05239105], [76.97421265, 14.05770969], [76.9750061, 14.06527042], [76.97225189, 14.06840134], [76.97184753, 14.07571125], [76.96808624, 14.07973957], [76.96012115, 14.08296967], [76.95143127, 14.08537197], [76.94629669, 14.08526039], [76.94854736, 14.09141159], [76.94822693, 14.09658146], [76.94658661, 14.10297108], [76.94291687, 14.11190128], [76.93739319, 14.11515141], [76.92697906, 14.12720966], [76.92241669, 14.12903976], [76.91712952, 14.12448025], [76.9125061, 14.12210941], [76.89846802, 14.12687969], [76.89090729, 14.127841], [76.88368225, 14.13103199], [76.88691711, 14.13624001], [76.88919067, 14.15087891], [76.89142609, 14.15899944], [76.89675903, 14.16190147], [76.91718292, 14.15767097], [76.922966, 14.1633997], [76.9369812, 14.16589165], [76.93924713, 14.1677103], [76.94153595, 14.17803001], [76.9392395, 14.18680859], [76.94164276, 14.18931198], [76.94404602, 14.18832016], [76.94908142, 14.18381023], [76.95378113, 14.18103027], [76.95849609, 14.17550945], [76.96568298, 14.17432022], [76.97276306, 14.1742897], [76.97818756, 14.17292023], [76.98626709, 14.17253113], [76.9943924, 14.17374992], [77.00605011, 14.17485142], [77.01403809, 14.17304134], [77.0198288, 14.17270184], [77.02133942, 14.16839886], [77.02105713, 14.16432953], [77.01600647, 14.15269089], [77.01493835, 14.13218117], [77.01380157, 14.12740135], [77.01920319, 14.12529087], [77.0202713, 14.12232113], [77.01635742, 14.11752129], [77.01703644, 14.11195087], [77.0165863, 14.10609245], [77.00831604, 14.09813118], [77.01043701, 14.0920496], [77.01470947, 14.08869934], [77.02398682, 14.08337116], [77.02453613, 14.07716942], [77.02024078, 14.06144142], [77.0236969, 14.0532589], [77.02848053, 14.05198002], [77.0348587, 14.05144024], [77.04322052, 14.05167007], [77.05120087, 14.04959202], [77.06903076, 14.04718971], [77.06952667, 14.03944111], [77.07649231, 14.0380497], [77.09075928, 14.03826046], [77.0966568, 14.04070091], [77.10396576, 14.04057121], [77.1101532, 14.04204082], [77.12110138, 14.04218006], [77.12468719, 14.0347414], [77.12783051, 14.01865005], [77.1340332, 14.00967026], [77.13288116, 14.00421047], [77.13434601, 13.9981308], [77.13949585, 13.99719048], [77.14437103, 13.99351978], [77.14459991, 13.99351978], [77.14733887, 13.99162197], [77.15444183, 13.99061012], [77.15836334, 13.99351978], [77.15815735, 13.99351978], [77.16278076, 13.99775982], [77.16168976, 14.00624943], [77.17138672, 14.00859928], [77.19455719, 14.00286007], [77.20767975, 14.00487137], [77.21884918, 14.00791073], [77.22727203, 14.00795174], [77.24256897, 14.00631142], [77.25575256, 14.0209589], [77.26451874, 14.02652931], [77.27150726, 14.02810192], [77.27420807, 14.01618195], [77.2726059, 14.0080204], [77.27851105, 14.00690079], [77.28518677, 14.01152992], [77.2922821, 14.01449966], [77.29802704, 14.02303123], [77.30355835, 14.02672958], [77.31349182, 14.02482033], [77.31648254, 14.02145958], [77.31700897, 14.01532269], [77.32022095, 14.00925064], [77.32409668, 14.00531006], [77.33011627, 13.99488068], [77.32966614, 13.99335194], [77.32977295, 13.99335194], [77.3303299, 13.99035931], [77.33347321, 13.98805141], [77.34567261, 13.98558044], [77.35378265, 13.98232079], [77.35338593, 13.97628975], [77.34693909, 13.96058941], [77.34720612, 13.95535183], [77.34374237, 13.95089245], [77.36200714, 13.9454689], [77.36260986, 13.9423008], [77.35263824, 13.92845058], [77.34261322, 13.91224194], [77.34350586, 13.90598106], [77.34590149, 13.9033308], [77.3483429, 13.89654064], [77.35884857, 13.89556122], [77.39041901, 13.89768982], [77.39186096, 13.87989044], [77.39626312, 13.88044071], [77.39705658, 13.88054085], [77.4085083, 13.88881016], [77.4189682, 13.89490891], [77.42562866, 13.90205193], [77.42740631, 13.90921974], [77.42250061, 13.91195011], [77.41015625, 13.91460133], [77.40843964, 13.92161083], [77.40770721, 13.93610001], [77.4225769, 13.93900108], [77.42870331, 13.94334126], [77.42904663, 13.9563818], [77.43090057, 13.96199131], [77.43064117, 13.96877956], [77.42661285, 13.97328186], [77.42050171, 13.97687054], [77.41018677, 13.97692204], [77.38651276, 13.97400188], [77.37565613, 13.96911144], [77.37269592, 13.9755106], [77.37320709, 13.98171043], [77.37988281, 13.99328136], [77.38336182, 14.00735855], [77.37507629, 14.01210022], [77.36232758, 14.01599026], [77.35009766, 14.01645088], [77.34406281, 14.01906013], [77.32618713, 14.02293968], [77.33126068, 14.03984165], [77.33454895, 14.04779053], [77.33796692, 14.0538311], [77.35012054, 14.05338192], [77.35855865, 14.05892944], [77.36136627, 14.06595135], [77.37238312, 14.07185173], [77.37966156, 14.09039116], [77.38568115, 14.09346104], [77.39544678, 14.10344124], [77.39643097, 14.11056995], [77.39444733, 14.11464119], [77.38973999, 14.11857033], [77.38035583, 14.1166296], [77.37325287, 14.1125803], [77.3589325, 14.10872173], [77.35246277, 14.10535145], [77.34851074, 14.09926128], [77.34453583, 14.09601116], [77.34651184, 14.11044025], [77.34651184, 14.1178503], [77.34773254, 14.12434101], [77.3548584, 14.12374973], [77.36501312, 14.12710953], [77.3766861, 14.12960052], [77.37873077, 14.13827991], [77.38262177, 14.14772034], [77.38955688, 14.15354061], [77.3897171, 14.16526031], [77.39745331, 14.16650009], [77.40972137, 14.1697197], [77.41631317, 14.16930103], [77.42347717, 14.16508007], [77.45392609, 14.16298103], [77.46333313, 14.16423035], [77.48854065, 14.15307999], [77.5004425, 14.15096092], [77.50267029, 14.1571207], [77.50679016, 14.16424084], [77.51035309, 14.17201996], [77.5094223, 14.17695045], [77.50414276, 14.18066025], [77.50108337, 14.19322109], [77.49971008, 14.20446968], [77.49308777, 14.21397018], [77.49285126, 14.22006035], [77.49008179, 14.22763062], [77.49627686, 14.24040985], [77.49878693, 14.24954033], [77.49936676, 14.26051044], [77.4962616, 14.2717514], [77.49214172, 14.27128124], [77.48439026, 14.27525997], [77.47934723, 14.28477097], [77.47912598, 14.283741], [77.46842957, 14.27943993], [77.45469666, 14.27219009], [77.4436264, 14.2775507], [77.44243622, 14.29091072], [77.44233704, 14.30975056], [77.42752838, 14.30484962], [77.4258728, 14.32081127], [77.42072296, 14.32199192], [77.4092865, 14.32710171], [77.39488983, 14.32915974], [77.38565826, 14.32487011], [77.37882233, 14.31707954], [77.37386322, 14.30510998], [77.37500763, 14.2951889], [77.3812027, 14.28299141], [77.38504791, 14.27245045], [77.38433838, 14.26561069], [77.38986969, 14.26138973], [77.40101624, 14.26041031], [77.40479279, 14.24860096], [77.40618134, 14.23671055], [77.40905762, 14.22358131], [77.41470337, 14.21706009], [77.41570282, 14.21196175], [77.41487885, 14.20322132], [77.39122009, 14.19088173], [77.38378906, 14.1918211], [77.38011169, 14.20255089], [77.38162231, 14.21018028], [77.37661743, 14.216712], [77.36431122, 14.22331047], [77.35540771, 14.2300396], [77.35923767, 14.24360085], [77.35826874, 14.26032066], [77.35926056, 14.26933002], [77.35340881, 14.27067947], [77.34336853, 14.27052021], [77.32058716, 14.27345085], [77.30748749, 14.27383995], [77.29545593, 14.27647114], [77.28549957, 14.27474976], [77.27958679, 14.27608967], [77.28189087, 14.29045963], [77.2826767, 14.30228043], [77.28114319, 14.33111095], [77.2733078, 14.33175087], [77.26732635, 14.32701015], [77.25785065, 14.32570171], [77.251297, 14.32060242], [77.24508667, 14.31453037], [77.23195648, 14.31107044], [77.22292328, 14.31498146], [77.20979309, 14.31301022], [77.19635773, 14.31429958], [77.17951202, 14.32637024], [77.17674255, 14.32629013], [77.17188263, 14.33023071], [77.16422272, 14.33046055], [77.15975952, 14.33623886], [77.15215302, 14.3377409], [77.14644623, 14.33219147], [77.14054108, 14.33611107], [77.13553619, 14.33401203], [77.13191986, 14.3305912], [77.13262939, 14.32404995], [77.13092804, 14.31381035], [77.12577057, 14.30153179], [77.11730957, 14.29141045], [77.11192322, 14.2875309], [77.1105423, 14.27493], [77.10692596, 14.26176071], [77.11551666, 14.25681973], [77.1115799, 14.24846172], [77.11299896, 14.23991966], [77.110466, 14.23198032], [77.1099472, 14.22148037], [77.10507965, 14.21328163], [77.09522247, 14.20948029], [77.08486938, 14.20845032], [77.07534027, 14.20934963], [77.06761932, 14.21786022], [77.06022644, 14.22416019], [77.05532074, 14.23230076], [77.04962921, 14.23954201], [77.04064941, 14.2407589], [77.03304291, 14.24048996], [77.02458954, 14.23668098], [77.01251221, 14.23509121], [77.00411987, 14.23156929], [76.99456024, 14.23556042], [76.99279022, 14.23298931], [76.98937988, 14.2364006], [76.98248291, 14.23815155], [76.97560883, 14.23742008], [76.96971893, 14.23521137], [76.96157074, 14.23590183], [76.95139313, 14.23415184], [76.94346619, 14.23631001], [76.93784332, 14.24012089], [76.93598938, 14.24877167], [76.9336319, 14.25350094], [76.92582703, 14.26439953], [76.92485809, 14.27218056], [76.93548584, 14.27664185], [76.9437561, 14.28168106], [76.9487381, 14.28676128], [76.95011139, 14.29402924], [76.94670105, 14.30044937], [76.94293976, 14.30537891], [76.93656158, 14.30840969], [76.92314911, 14.30965042], [76.91680908, 14.31225967], [76.90615845, 14.315341], [76.89897156, 14.31924057], [76.88536072, 14.33959103], [76.87909698, 14.34638977], [76.87861633, 14.35139275], [76.88314056, 14.39029121], [76.88677979, 14.39245129], [76.89232635, 14.3928709], [76.89663696, 14.39447975], [76.90116119, 14.3983202], [76.9131012, 14.41355228], [76.9189682, 14.41145039], [76.93678284, 14.40130997], [76.94156647, 14.39954185], [76.94359589, 14.40326118], [76.94467926, 14.40892029], [76.94432068, 14.42523193], [76.94271088, 14.43984127], [76.94378662, 14.44510174], [76.95858765, 14.4453907], [76.96437073, 14.45174122], [76.97419739, 14.47036076], [76.9733963, 14.47828102], [76.96909332, 14.47908974], [76.95580292, 14.47958946], [76.94541168, 14.48215103], [76.90651703, 14.48416138], [76.89427185, 14.48075199], [76.88549042, 14.4759407], [76.88030243, 14.47052956], [76.87020111, 14.46844006], [76.86380768, 14.47467136], [76.86044312, 14.48713112], [76.85421753, 14.49888039], [76.84393311, 14.50914955], [76.83207703, 14.51507092], [76.82842255, 14.52224064], [76.82758331, 14.52305889], [76.81973267, 14.52033997], [76.81089783, 14.5237999], [76.80509186, 14.52487087], [76.79972839, 14.5277319], [76.79469299, 14.54073048], [76.78617096, 14.55305958], [76.78405762, 14.56198025], [76.77815247, 14.5793314], [76.77628326, 14.59033012], [76.77435303, 14.59057045], [76.77275085, 14.58720112], [76.76091003, 14.59628105], [76.76017761, 14.60201073], [76.7629776, 14.61192131], [76.76950836, 14.65631104], [76.77127838, 14.67383957], [76.78108215, 14.6904707], [76.78553772, 14.70709133], [76.79807281, 14.73459053], [76.79502869, 14.74113178], [76.78813934, 14.75184059], [76.78642273, 14.76191139], [76.78128815, 14.77433014], [76.78034973, 14.77926159], [76.81096649, 14.7814312], [76.81671143, 14.78249073], [76.81735229, 14.78544044], [76.82073212, 14.78660965], [76.82641602, 14.78698063], [76.83136749, 14.78411198], [76.83377075, 14.78490925], [76.83496857, 14.8001318], [76.83721161, 14.80414104], [76.8469162, 14.80231094], [76.84873962, 14.80403137], [76.84960175, 14.81180954], [76.84854126, 14.81425095], [76.8444519, 14.81559086], [76.84298706, 14.82430172], [76.84026337, 14.82807159], [76.84008789, 14.83004093], [76.84436035, 14.83325195], [76.84938812, 14.83869934], [76.85411835, 14.86137199], [76.85167694, 14.86252117], [76.85087585, 14.87285042], [76.84905243, 14.87993145], [76.84326172, 14.88147163], [76.84377289, 14.88642025], [76.846138, 14.89033127], [76.86030579, 14.89118958], [76.86271667, 14.90176964], [76.86389923, 14.91174126], [76.86348724, 14.91564274], [76.86547852, 14.93760014], [76.86367035, 14.95521069], [76.86445618, 14.96401978], [76.84115601, 14.96117115], [76.83587646, 14.9590807], [76.83255005, 14.95348072], [76.82789612, 14.95100975], [76.82364655, 14.95361137], [76.82028198, 14.95917034], [76.81545258, 14.96380997], [76.79688263, 14.96292114], [76.7720871, 14.96864033], [76.76377106, 14.96986961], [76.76185608, 14.97528076], [76.75863647, 14.97946072], [76.75698853, 14.98297119], [76.7592392, 14.98507023], [76.76235962, 14.9894619], [76.7651825, 14.98906136], [76.76622009, 14.99081135], [76.76805878, 14.9956398], [76.76953125, 15.00058174], [76.77974701, 15.00588989], [76.78457642, 15.01667023], [76.78179169, 15.02332973], [76.78079224, 15.03423977], [76.77501678, 15.04395962], [76.77112579, 15.05409145], [76.77082062, 15.05828857], [76.77256012, 15.06511974], [76.77574158, 15.06916142], [76.77422333, 15.07138062], [76.77636719, 15.07329273], [76.7786026, 15.0715704], [76.78391266, 15.07567024], [76.78224945, 15.07882023], [76.78423309, 15.08078003], [76.78756714, 15.08043957], [76.79693604, 15.09076023], [76.81188202, 15.08023071], [76.82126617, 15.07485199], [76.82943726, 15.07429123], [76.83740997, 15.07246971], [76.84320831, 15.06615925], [76.86057281, 15.05671024], [76.86406708, 15.05000019], [76.86975098, 15.0440197], [76.87670135, 15.02867889], [76.88868713, 15.03175068], [76.89620972, 15.03188133], [76.90544128, 15.0292902], [76.91352081, 15.03095055], [76.9193573, 15.02852154], [76.93167114, 15.02631092], [76.94274902, 15.02703094], [76.95066833, 15.02443123], [76.96679688, 15.01316929], [76.98178101, 15.01036072], [76.98351288, 15.02042198], [76.99565125, 15.02368069], [76.99862671, 15.02706146], [77.00067902, 15.02958965], [77.0092926, 15.02958107], [77.02295685, 15.02765083], [77.0374527, 15.02757072], [77.04688263, 15.029212], [77.04878998, 15.02386093], [77.04638672, 15.01601791], [77.041008, 15.00548172], [77.05092621, 15.00428963], [77.06147003, 15.00154972], [77.06858826, 15.00111008], [77.07881927, 15.00000954], [77.08049774, 15.00791073], [77.0820694, 15.02229023], [77.08825684, 15.02303791], [77.09078217, 15.02772236], [77.10167694, 15.02734089], [77.10957336, 15.02856922], [77.11161041, 15.03812981], [77.11606598, 15.04010201], [77.11839294, 15.05063057], [77.12091064, 15.05507088], [77.12552643, 15.06820965], [77.12760925, 15.09364128], [77.13938904, 15.09988117], [77.14771271, 15.10733032], [77.15403748, 15.12052059], [77.15276337, 15.13162136], [77.13536072, 15.13601017], [77.13208008, 15.14268112], [77.13697052, 15.14925194], [77.14549255, 15.15070057], [77.15305328, 15.14882088], [77.15770721, 15.14895058], [77.1592865, 15.15212059], [77.15879059, 15.15786934], [77.16320038, 15.16133118], [77.16448212, 15.16847038], [77.16153717, 15.18221092], [77.15815735, 15.19382], [77.15577698, 15.19433975], [77.14996338, 15.207901], [77.14707947, 15.20880985], [77.14138031, 15.21813202], [77.12090302, 15.221241], [77.12345886, 15.23332024], [77.13265991, 15.2346096], [77.14025116, 15.25155067], [77.14668274, 15.25029087], [77.1579361, 15.2513504], [77.16525269, 15.25097179], [77.16414642, 15.2590704], [77.15766907, 15.26037979], [77.14985657, 15.26693058], [77.14517212, 15.26605129], [77.14491272, 15.26928043], [77.14803314, 15.27095127], [77.14872742, 15.27785015], [77.14791107, 15.28567028], [77.13883972, 15.28547955], [77.12374878, 15.28757], [77.11541748, 15.28985023], [77.11342621, 15.31912041], [77.11023712, 15.32073021], [77.10968781, 15.32728195], [77.09929657, 15.32662106], [77.0690918, 15.31947136], [77.06157684, 15.32186031], [77.0631485, 15.32808018], [77.06289673, 15.3379097], [77.05784607, 15.34319019], [77.04260254, 15.35224056], [77.03803253, 15.35878181], [77.04228973, 15.37479973], [77.04382324, 15.38374138], [77.041008, 15.39151001], [77.03325653, 15.39626026], [77.02854156, 15.40130234], [77.0268631, 15.40775204], [77.03100586, 15.41833973], [77.03048706, 15.42633057], [77.02739716, 15.43518066], [77.02384186, 15.43856144], [77.01528168, 15.4410696], [77.00609589, 15.44823074], [77.00203705, 15.45538139], [77.00074005, 15.46170139], [76.9960022, 15.46745968], [76.98898315, 15.47315121], [76.97608185, 15.48201275], [76.97039032, 15.49092197], [76.97013855, 15.49495125], [76.97189331, 15.50633144], [76.98165131, 15.50477028], [76.99085236, 15.50107098], [76.99603271, 15.49973106], [77.00543213, 15.50277138], [77.02659607, 15.49999046], [77.02874756, 15.50856018], [77.028862, 15.52512169], [77.02371216, 15.57638168], [77.02443695, 15.58436203], [77.02889252, 15.59825993], [77.02839661, 15.60684967], [77.02710724, 15.62934971], [77.02928162, 15.63383865], [77.03266144, 15.63200855], [77.03601074, 15.6323719], [77.06887054, 15.64090919], [77.08143616, 15.65284061], [77.08889771, 15.64752102], [77.09593201, 15.64414978], [77.10056305, 15.63916111], [77.10389709, 15.63393116], [77.11620331, 15.62510967], [77.1209259, 15.63720131], [77.12497711, 15.65905094], [77.1190567, 15.66208935], [77.110466, 15.67126274], [77.10083771, 15.67887974], [77.07592773, 15.69087887], [77.07792664, 15.69336128], [77.08164978, 15.69533062], [77.08436584, 15.70895958], [77.0762558, 15.71037102], [77.07627106, 15.72141075], [77.06299591, 15.72367191], [77.04708862, 15.72501183], [77.04724884, 15.73317146], [77.04322815, 15.73448181], [77.04669189, 15.75133133], [77.05171967, 15.7501297], [77.05316925, 15.75887966], [77.04850769, 15.76076031], [77.04972076, 15.76410103], [77.0537262, 15.76364994], [77.05660248, 15.77228069], [77.05976868, 15.77884007], [77.06247711, 15.77839088], [77.06723785, 15.79605007], [77.06151581, 15.79792118], [77.06388855, 15.82316971], [77.05226135, 15.82433891], [77.04991913, 15.82014275], [77.04154205, 15.821661], [77.03836823, 15.82551003], [77.03388214, 15.82439995], [77.02815247, 15.82559013], [77.02442169, 15.82948971], [77.0222702, 15.83178043], [77.02902985, 15.84490108], [77.03318787, 15.85308075], [77.04104614, 15.86395931], [77.05245209, 15.87628269], [77.05821228, 15.88716125], [77.06595612, 15.89931107], [77.07679749, 15.90974045], [77.09005737, 15.91786957], [77.10460663, 15.92453194], [77.12065887, 15.92882061], [77.12993622, 15.93039131], [77.13677216, 15.93621922], [77.14343262, 15.9406004], [77.15712738, 15.9444809], [77.17070007, 15.94554996], [77.18062592, 15.95006275], [77.18782806, 15.9507103], [77.20295715, 15.94987965], [77.21866608, 15.95164204], [77.22711945, 15.95160961], [77.23609161, 15.95271111], [77.2440567, 15.95676136], [77.24891663, 15.95774078], [77.25813293, 15.95397091], [77.26317596, 15.95138931], [77.28244781, 15.94736195], [77.29178619, 15.94996929], [77.30021667, 15.95049953], [77.31478882, 15.94519043], [77.33516693, 15.94327068], [77.35360718, 15.94370174], [77.35987091, 15.94155025], [77.36814117, 15.93604088], [77.3762207, 15.93325043], [77.38559723, 15.9344511], [77.3927002, 15.93676186], [77.40003204, 15.93546009], [77.40763092, 15.93565178], [77.41644287, 15.93796062], [77.42193604, 15.94129944], [77.42642212, 15.94227886], [77.43647766, 15.9390316], [77.45250702, 15.93152046], [77.46697998, 15.92758083], [77.48332214, 15.92805958], [77.49732208, 15.92630005], [77.50945282, 15.92086029], [77.53173828, 15.91611958], [77.54884338, 15.91366863], [77.57163239, 15.91232014], [77.58010101, 15.91020966], [77.58841705, 15.90699196], [77.59868622, 15.90874195], [77.60637665, 15.91172981], [77.61384583, 15.90783024], [77.61882019, 15.90375137], [77.62570953, 15.89913082], [77.63204956, 15.89180088], [77.63960266, 15.88313103], [77.64821625, 15.87893963], [77.65894318, 15.87652016], [77.68353271, 15.87389183], [77.69249725, 15.87532139], [77.69944763, 15.88043976], [77.70730591, 15.88409996], [77.71611786, 15.88657093], [77.72486115, 15.88479137], [77.73195648, 15.88221073], [77.73883057, 15.87852097], [77.74964142, 15.87587929], [77.76004791, 15.876791], [77.77020264, 15.87327194], [77.77889252, 15.8693018], [77.78978729, 15.86658859], [77.79918671, 15.86532021], [77.80921936, 15.86702919], [77.81772614, 15.86949062], [77.8253479, 15.87379074], [77.83384705, 15.87551022], [77.83976746, 15.87394047], [77.85011292, 15.87382126], [77.85565186, 15.87576103], [77.86694336, 15.8923893], [77.87638092, 15.89600182], [77.88768005, 15.89592171], [77.90756226, 15.88489056], [77.92829895, 15.87650967], [77.94402313, 15.87491035], [77.96308136, 15.87590027], [77.9728775, 15.87411976], [77.99360657, 15.86098003], [78.0018692, 15.85923004], [78.00660706, 15.87197018], [78.01473236, 15.88881111], [78.01696777, 15.89514923], [78.02423859, 15.89858246], [78.02879333, 15.90269089], [78.03629303, 15.90209103], [78.03981781, 15.89810085], [78.04071808, 15.87220097], [78.04886627, 15.87075138], [78.05847168, 15.85041046], [78.0636673, 15.84456158], [78.10114288, 15.82792187], [78.10958099, 15.82718086], [78.11978912, 15.83026886], [78.12687683, 15.83492088], [78.1258316, 15.84893131], [78.13791656, 15.85024071], [78.14840698, 15.84996986], [78.15093231, 15.84904003], [78.16467285, 15.84899044], [78.16867065, 15.85317039], [78.17066193, 15.86643887], [78.17384338, 15.87252045], [78.17907715, 15.87977886], [78.18148804, 15.88765144], [78.17919159, 15.89494038], [78.18003082, 15.90044975], [78.19667053, 15.91224003], [78.20539856, 15.91706085], [78.22786713, 15.92348099], [78.23796844, 15.9290514], [78.24286652, 15.93704891], [78.24401093, 15.9469614], [78.2473526, 15.96004963], [78.24835968, 15.9683094], [78.25110626, 15.97083855], [78.25293732, 15.97844028], [78.25974274, 15.99473095], [78.25868225, 16.00508118], [78.25138092, 16.02568054], [78.25666809, 16.03129959], [78.26815796, 16.03475952], [78.28105927, 16.03209114], [78.29218292, 16.02849007], [78.31620789, 16.02915192], [78.32356262, 16.03724289], [78.33114624, 16.04709053], [78.34041595, 16.05277061], [78.35311127, 16.05451012], [78.37003326, 16.05984116], [78.38424683, 16.07183075], [78.40566254, 16.08094978], [78.42095184, 16.0828495], [78.45101166, 16.0810318], [78.49559784, 16.0730896], [78.52083588, 16.0650692], [78.5328598, 16.06232262], [78.54689789, 16.05620003], [78.55912781, 16.05637169], [78.56711578, 16.06187057], [78.57643127, 16.07034111], [78.59256744, 16.08723068], [78.60350037, 16.09643936], [78.61701202, 16.09890938], [78.63648987, 16.09144974], [78.646698, 16.08273125], [78.65776062, 16.07143974], [78.66837311, 16.05579948], [78.67498016, 16.0490303], [78.68656158, 16.04038048], [78.71366882, 16.02666092], [78.72596741, 16.02304077], [78.73898315, 16.02114105], [78.75393677, 16.02100945], [78.7750473, 16.02360916], [78.79001617, 16.03269958], [78.80799866, 16.04619026], [78.81376648, 16.05219078], [78.82155609, 16.06220055], [78.83650208, 16.08737755], [78.83937836, 16.09424019], [78.84028625, 16.10283089], [78.83808899, 16.11086082], [78.83394623, 16.12014008], [78.83127594, 16.13297844], [78.83049774, 16.14215088], [78.83213043, 16.15176964], [78.83783722, 16.15673828], [78.84628296, 16.15954018], [78.85645294, 16.15859985], [78.86293793, 16.15308952], [78.86633301, 16.14385986], [78.86802673, 16.13526154], [78.86942291, 16.12162971], [78.87267303, 16.11017036], [78.8890686, 16.09856033], [78.90117645, 16.09762192], [78.91047668, 16.1052227], [78.91335297, 16.10884094], [78.91726685, 16.11351967], [78.92186737, 16.12187195], [78.92086029, 16.13367081], [78.90558624, 16.16492081], [78.90545654, 16.18186951], [78.90808105, 16.19104004], [78.92549896, 16.20233917], [78.94108582, 16.20981026], [78.95900726, 16.21722031], [78.97805786, 16.22307014], [78.99243164, 16.22830009], [79.01017761, 16.24044991], [79.0201416, 16.24427032], [79.03093719, 16.2457428], [79.04252625, 16.24495125], [79.05407715, 16.24255943], [79.06859589, 16.23814011], [79.12300873, 16.23791122], [79.13317871, 16.23637962], [79.14248657, 16.22925949], [79.15117645, 16.22462082], [79.16272736, 16.2202282], [79.17658234, 16.21713066], [79.19198608, 16.22271919], [79.2075119, 16.23067093], [79.21868896, 16.23964119], [79.22505951, 16.25007057], [79.22982025, 16.30022049], [79.22785187, 16.33681107], [79.22323608, 16.35036087], [79.21147156, 16.36281013], [79.21330261, 16.37438965], [79.21260071, 16.39376068], [79.21501923, 16.41576195], [79.21906281, 16.43816948], [79.22635651, 16.45253944], [79.23618317, 16.45853996], [79.23513031, 16.47068977], [79.23091125, 16.48167038], [79.22410583, 16.49213982], [79.22527313, 16.50822067], [79.23044586, 16.51929092], [79.26077271, 16.54642105], [79.26611328, 16.56147003], [79.28237915, 16.56544113], [79.29512024, 16.56735039], [79.31977844, 16.57587051], [79.33333588, 16.57852173], [79.34552765, 16.57956123], [79.40270996, 16.58044052], [79.42658997, 16.58252144], [79.43450165, 16.58566093], [79.44315338, 16.59370041], [79.45059204, 16.60914993], [79.47009277, 16.61874962], [79.49717712, 16.63051033], [79.51212311, 16.63365173], [79.53671265, 16.63156128], [79.55399323, 16.63459015], [79.56359863, 16.63806915], [79.57402039, 16.64359093], [79.58558655, 16.65135002], [79.59990692, 16.66327095], [79.61680603, 16.66464043], [79.63329315, 16.6608696], [79.64803314, 16.66200066], [79.65550232, 16.67408943], [79.66864014, 16.68400955], [79.6830368, 16.6903801], [79.72274017, 16.69260979], [79.7338028, 16.69802094], [79.75048065, 16.72011948], [79.76309204, 16.7271328], [79.77490234, 16.7295208], [79.7833786, 16.72484016], [79.81025696, 16.69049072], [79.8259201, 16.69146919], [79.84456635, 16.69646072], [79.86183929, 16.69822121], [79.87330627, 16.68869972], [79.88065338, 16.67617035], [79.89092255, 16.64956093], [79.90207672, 16.63784981], [79.91382599, 16.63313103], [79.92366791, 16.63073921], [79.94256592, 16.63262939], [79.95815277, 16.64204979], [79.97302246, 16.6595211], [79.99151611, 16.69255066], [79.99368286, 16.69444084], [80.002388, 16.70294952], [80.01667786, 16.71183014], [80.0233078, 16.71847916], [80.03276062, 16.73178101], [80.04335022, 16.73970032], [80.04789734, 16.74515152], [80.05158997, 16.77128983], [80.05767059, 16.78187943], [80.06492615, 16.80251122], [80.06967163, 16.81360817], [80.0418396, 16.82606125], [80.03666687, 16.83238983], [80.03439331, 16.83912277], [80.03436279, 16.84776115], [80.03309631, 16.85244942], [80.01383209, 16.85293961], [79.994133, 16.86218071], [79.99167633, 16.86325073], [79.99505615, 16.87731171], [80.0027771, 16.89146805], [80.009552, 16.90726089], [80.01860046, 16.91880989], [80.02849579, 16.92741013], [80.03705597, 16.93647003], [80.04588318, 16.96529961], [80.08423615, 16.96319008], [80.08394623, 16.9776783], [80.08769226, 16.98744011], [80.09947205, 16.98280144], [80.10578918, 16.98131943], [80.11279297, 16.98232079], [80.11467743, 16.98587036], [80.12014771, 16.98681068], [80.12689972, 16.98533058], [80.13385773, 16.98535919], [80.14057159, 16.99328995], [80.14247131, 17.0014801], [80.14911652, 17.00805092], [80.16718292, 17.02362061], [80.17053223, 17.03041267], [80.18212891, 17.04494095], [80.19426727, 17.04251289], [80.19610596, 17.02568817], [80.19554901, 17.01804161], [80.2012558, 17.01313972], [80.21321869, 17.0191803], [80.2178421, 17.0196209], [80.23223877, 17.0049305], [80.23574829, 17.00233078], [80.2411499, 17.00280952], [80.25026703, 17.00737953], [80.26217651, 17.01062965], [80.27617645, 16.99324989], [80.28898621, 16.97680283], [80.30137634, 16.95586014], [80.30396271, 16.93947029], [80.30784607, 16.92381287], [80.31537628, 16.91238976], [80.31328583, 16.91200256], [80.31613159, 16.89466286], [80.31600189, 16.88400078], [80.3184433, 16.87743759], [80.3192215, 16.87094116], [80.32731628, 16.87101936], [80.33731079, 16.86708069], [80.33495331, 16.85573959], [80.35090637, 16.85330009], [80.35862732, 16.8549099], [80.36120605, 16.85038185], [80.36472321, 16.83890152], [80.36711121, 16.82676125], [80.37293243, 16.81110001], [80.37587738, 16.8106308], [80.37784576, 16.81248093], [80.3793869, 16.81953049], [80.39422607, 16.82516289], [80.39914703, 16.83158112], [80.400177, 16.83704948], [80.39971161, 16.84973907], [80.41867065, 16.84231949], [80.42140961, 16.83712006], [80.4228363, 16.82930946], [80.43210602, 16.82718086], [80.43183136, 16.82385063], [80.44476318, 16.81939125], [80.4526062, 16.81529045], [80.45507813, 16.80648041], [80.45639801, 16.79002953], [80.47101593, 16.78832054], [80.47905731, 16.78495026], [80.48464966, 16.78131104], [80.48953247, 16.77585983], [80.51098633, 16.76993752], [80.51806641, 16.76876831], [80.53005981, 16.77005959], [80.54650879, 16.76765823], [80.56281281, 16.76283073], [80.56933594, 16.77075005], [80.59751892, 16.78508949], [80.60410309, 16.78775978], [80.59777832, 16.79203033], [80.59364319, 16.79791832], [80.58584595, 16.8066597], [80.57176971, 16.81209946], [80.56700897, 16.81710052], [80.56124878, 16.81712914], [80.55602264, 16.81841087], [80.55458069, 16.82478905], [80.56243134, 16.83632088], [80.56400299, 16.84256172], [80.56482697, 16.84991074], [80.56497192, 16.86903954], [80.57650757, 16.87310028], [80.58674622, 16.87393951], [80.58577728, 16.88716125], [80.58335876, 16.89060974], [80.58123779, 16.89677811], [80.5821228, 16.90310287], [80.58587646, 16.90432167], [80.5893631, 16.9071312], [80.59030914, 16.91163063], [80.58914185, 16.91666985], [80.58419037, 16.92651939], [80.56948853, 16.92688942], [80.53173828, 16.95017815], [80.52069092, 16.93639946], [80.509758, 16.94243813], [80.49130249, 16.94818115], [80.48693848, 16.93685913], [80.48558807, 16.92703819], [80.48781586, 16.91744041], [80.47688293, 16.92117119], [80.46985626, 16.92651176], [80.46324921, 16.93021011], [80.45308685, 16.9383297], [80.44254303, 16.94494057], [80.41234589, 16.95417023], [80.39762115, 16.95701027], [80.38080597, 16.96251106], [80.36042023, 16.97050095], [80.35824585, 16.97063065], [80.36106873, 16.9744606], [80.36972046, 16.98295021], [80.37161255, 16.98711967], [80.37120056, 16.99315071], [80.37119293, 16.99584007], [80.38197327, 17.00004005], [80.3864975, 17.00294113], [80.38790894, 17.00729942], [80.38871765, 17.01406097], [80.38376617, 17.01975822], [80.37789154, 17.02334023], [80.37722015, 17.02787018], [80.37838745, 17.03412056], [80.37162018, 17.04752922], [80.36775208, 17.05269814], [80.36699677, 17.05656815], [80.37416077, 17.06311035], [80.37905884, 17.06615067], [80.39012146, 17.07620049], [80.39319611, 17.07781029], [80.3950882, 17.07756805], [80.3973465, 17.07389069], [80.39977264, 17.0652504], [80.39890289, 17.05978966], [80.40087128, 17.05418968], [80.41429138, 17.0417881], [80.41777802, 17.02861023], [80.42053986, 17.02486038], [80.43266296, 17.02178192], [80.44624329, 17.01702118], [80.45288849, 17.03704262], [80.46422577, 17.03718185], [80.47174835, 17.0381012], [80.47506714, 17.04281044], [80.48220062, 17.05027008], [80.48465729, 17.05631065], [80.48462677, 17.06759071], [80.48678589, 17.08289909], [80.48873138, 17.08733177], [80.49240112, 17.09244156], [80.49653625, 17.10129166], [80.49611664, 17.10786057], [80.51172638, 17.10621071], [80.51941681, 17.10815048], [80.52916718, 17.11364937], [80.53542328, 17.11978912], [80.54165649, 17.12041092], [80.54907227, 17.12362289], [80.56017303, 17.1380291], [80.57348633, 17.13529015], [80.58026123, 17.13095093], [80.59510803, 17.11956024], [80.60388184, 17.11551094], [80.61292267, 17.11664009], [80.61654663, 17.11569977], [80.62391663, 17.11188126], [80.62975311, 17.11001968], [80.62523651, 17.10173988], [80.63640594, 17.09699059], [80.64626312, 17.09445953], [80.65664673, 17.08776283], [80.65541077, 17.08397102], [80.64438629, 17.07710075], [80.63775635, 17.07193947], [80.6377182, 17.06561089], [80.63392639, 17.05887985], [80.63960266, 17.05512047], [80.64919281, 17.05458069], [80.66059875, 17.05672073], [80.66777039, 17.05992126], [80.67563629, 17.0612793], [80.68139648, 17.06430054], [80.68399811, 17.06874084], [80.69516754, 17.06834984], [80.71261597, 17.06546021], [80.7257309, 17.06460953], [80.74659729, 17.05491829], [80.76609802, 17.0503006], [80.78019714, 17.04879951], [80.78528595, 17.04762268], [80.79284668, 17.04303932], [80.80322266, 17.0425396], [80.82322693, 17.03778076], [80.82930756, 17.0323391], [80.83246613, 17.02571106], [80.84487915, 17.03284073], [80.85053253, 17.0401516], [80.85489655, 17.04404068], [80.85884857, 17.05085182], [80.85646057, 17.06851959], [80.86254883, 17.08152962], [80.86239624, 17.08563042], [80.86421204, 17.09581757], [80.85504913, 17.11141014], [80.86347198, 17.11799812], [80.8667984, 17.12462044], [80.87030792, 17.14630127], [80.87676239, 17.14520073], [80.88886261, 17.14105034], [80.89615631, 17.1407795], [80.90397644, 17.14114952], [80.90939331, 17.14245033], [80.91330719, 17.14595032], [80.9121933, 17.15350914], [80.91400146, 17.16077042], [80.91487122, 17.16983986], [80.91301727, 17.17378044], [80.90847778, 17.17803955], [80.90699005, 17.18384171], [80.90763855, 17.19285965], [80.90534973, 17.20129013], [80.91384888, 17.20525932], [80.92064667, 17.20582962], [80.9306488, 17.20503044], [80.93904877, 17.20038033], [80.94773102, 17.19333076], [80.95598602, 17.18820953], [80.96633148, 17.1845417], [80.98516083, 17.17938995], [80.99125671, 17.17970276], [80.99771881, 17.18201065], [81.00540161, 17.18444824], [81.02617645, 17.1866684], [81.03145599, 17.19235039], [81.03485107, 17.1972599], [81.03996277, 17.19994164], [81.04386139, 17.20454025], [81.04654694, 17.2138176], [81.05384064, 17.21014023], [81.06221008, 17.20409966], [81.08450317, 17.21364021], [81.11817932, 17.2245903], [81.14554596, 17.23166275], [81.16278839, 17.23258018], [81.16799927, 17.24232101], [81.18055725, 17.25460052], [81.17463684, 17.26037025], [81.17114258, 17.26666069], [81.17061615, 17.29646111], [81.17195892, 17.30545044], [81.17822266, 17.31451035], [81.18154144, 17.32222939], [81.19030762, 17.32736969], [81.21875, 17.3217392], [81.23429108, 17.32282066], [81.25752258, 17.32266045], [81.26222229, 17.32194138], [81.26716614, 17.31999969], [81.28179932, 17.3297596], [81.28916931, 17.33754921], [81.29881287, 17.35214043], [81.30162048, 17.35972977], [81.31162262, 17.37478065], [81.32247162, 17.38915062], [81.3246994, 17.3906498], [81.33035278, 17.39209938], [81.33734894, 17.38999939], [81.34292603, 17.38541031], [81.34329987, 17.37572098], [81.34983826, 17.36852264], [81.36395264, 17.36026001], [81.37180328, 17.3571682], [81.37864685, 17.35612106], [81.38522339, 17.35513115], [81.40644836, 17.36141014], [81.41564941, 17.36162949], [81.41831207, 17.36638069], [81.42011261, 17.37218285], [81.43364716, 17.37494278], [81.44151306, 17.38171005], [81.44608307, 17.39069176], [81.45155334, 17.39833069], [81.45726013, 17.40539932], [81.47223663, 17.41953087], [81.481987, 17.43220139], [81.49341583, 17.44882011], [81.49536133, 17.45380974], [81.49585724, 17.46037102], [81.49373627, 17.4659996], [81.49360657, 17.47702026], [81.49816132, 17.48999977], [81.49951172, 17.50154114], [81.49803162, 17.51007271], [81.49946594, 17.53153992], [81.5014267, 17.53936005], [81.50907898, 17.54932022], [81.51374054, 17.55726051], [81.52030945, 17.56460953], [81.52371979, 17.56970978], [81.52390289, 17.57261086], [81.52089691, 17.57574081], [81.51267242, 17.58296013], [81.50292969, 17.58987999], [81.50789642, 17.59532166], [81.50926971, 17.59832954], [81.50927734, 17.60355949], [81.51187897, 17.60988045], [81.51895905, 17.61878967], [81.53414917, 17.63042259], [81.54432678, 17.64529991], [81.54608917, 17.65069962], [81.5536499, 17.66638947], [81.56018066, 17.67665291], [81.56819153, 17.68283081], [81.57116699, 17.68786812], [81.57108307, 17.70289993], [81.57198334, 17.71183014], [81.5729599, 17.71866989], [81.57662201, 17.72609138], [81.58194733, 17.73065948], [81.60919952, 17.7436409], [81.61281586, 17.74693108], [81.61859131, 17.75858116], [81.62306213, 17.76279068], [81.64189911, 17.76564026], [81.65299988, 17.76561165], [81.67469025, 17.76711082], [81.68477631, 17.77056122], [81.69138336, 17.77570152], [81.69824219, 17.78449059], [81.70398712, 17.79956055], [81.70951843, 17.80511093], [81.72342682, 17.81522179], [81.72959137, 17.8192997], [81.7388916, 17.8216095], [81.75293732, 17.81830978], [81.76393127, 17.82992935], [81.78235626, 17.83195114], [81.78784943, 17.83924103], [81.79440308, 17.84415054], [81.79277039, 17.8525219], [81.78753662, 17.86251068], [81.78144073, 17.87071991], [81.76885986, 17.87869835], [81.7634201, 17.88540077], [81.75829315, 17.89336014], [81.76222229, 17.89658928], [81.77574921, 17.9047699], [81.7824173, 17.90974045], [81.78601074, 17.91361046], [81.7893219, 17.92136955], [81.79405212, 17.9296608], [81.80104065, 17.93608093], [81.81980133, 17.94546127], [81.83333588, 17.95103073], [81.83969879, 17.95006943], [81.84681702, 17.95079994], [81.87413788, 17.95984077], [81.88507843, 17.96583939], [81.89927673, 17.96854973], [81.90454865, 17.97347069], [81.91369629, 17.97989082], [81.92471313, 17.98088074], [81.93609619, 17.98409081], [81.95176697, 17.99209976], [81.95713043, 17.99707031], [81.96404266, 17.99986839], [81.97305298, 18.00567055], [81.98046112, 18.01128006], [81.98587799, 18.01427078], [81.98886108, 18.02034187], [81.99147797, 18.02182007], [82.0016861, 18.02366066], [82.00211334, 18.0282402], [82.00473022, 18.03430939], [82.00157928, 18.04481125], [82.00663757, 18.04919815], [82.01677704, 18.0551281], [82.0246582, 18.0578804], [82.02986145, 18.05653191], [82.03263855, 18.05171013], [82.04516602, 18.04558945], [82.05085754, 18.0444603], [82.0597229, 18.04511833], [82.06564331, 18.04891968], [82.06546783, 18.05130005], [82.06098938, 18.05398178], [82.05898285, 18.0584507], [82.06440735, 18.05837059], [82.06989288, 18.06043053], [82.07221222, 18.06563759], [82.08006287, 18.0604496], [82.0891571, 18.05741119], [82.09236145, 18.05276108], [82.10797882, 18.05401993], [82.11058807, 18.05766106], [82.11326599, 18.05782127], [82.1193161, 18.05120087], [82.12708282, 18.0510006], [82.12924194, 18.04866982], [82.13041687, 18.04090118], [82.13237, 18.03561974], [82.14229584, 18.04356956], [82.14730835, 18.04042053], [82.16034698, 18.04359818], [82.16374969, 18.04162025], [82.17314911, 18.0255928], [82.17694092, 18.02089119], [82.17424774, 18.01550293], [82.17740631, 18.01057053], [82.18508911, 18.00735283], [82.19101715, 18.00895119], [82.1969223, 18.00868988], [82.20775604, 18.00070953], [82.2181778, 17.99419022], [82.22297668, 17.99287987], [82.23079681, 17.99370956], [82.23699188, 17.99201012], [82.2383194, 17.98390007], [82.24170685, 17.97976112], [82.25318909, 17.98019028], [82.26107788, 17.98240089], [82.26725006, 17.98644066], [82.26885223, 17.99198914], [82.27052307, 17.9977417], [82.27081299, 18.01066971], [82.26893616, 18.01993942], [82.26624298, 18.02569008], [82.25815582, 18.03487015], [82.26220703, 18.03630066], [82.26460266, 18.039011], [82.2651062, 18.0430603], [82.26695251, 18.04827118], [82.27894592, 18.05492973], [82.28302765, 18.05577087], [82.28505707, 18.0594101], [82.28777313, 18.06056023], [82.29789734, 18.06196022], [82.29640198, 18.05755806], [82.29280853, 18.05433273], [82.2964859, 18.04614067], [82.30105591, 18.04404068], [82.30634308, 18.04499054], [82.30441284, 18.03961945], [82.30552673, 18.03780937], [82.30961609, 18.03842926], [82.31320953, 18.03475761], [82.3169632, 18.03602028], [82.31299591, 18.04519081], [82.31572723, 18.04668045], [82.31730652, 18.04853058], [82.31964874, 18.04857063], [82.32182312, 18.05018044], [82.3261795, 18.0465107], [82.32491302, 18.04269028], [82.32977295, 18.040411], [82.33634949, 18.04726028], [82.33692932, 18.04910088], [82.3431778, 18.0678196], [82.34194183, 18.07130051], [82.34362793, 18.07499123], [82.34316254, 18.08247948], [82.34055328, 18.08708954], [82.33466339, 18.08988762], [82.33216095, 18.09412193], [82.33248901, 18.10704994], [82.33030701, 18.11899948], [82.33535767, 18.1272583], [82.33336639, 18.14237976], [82.33825684, 18.13796043], [82.34487152, 18.13462067], [82.35756683, 18.12510109], [82.361763, 18.12919807], [82.36429596, 18.13485909], [82.36515808, 18.13966942], [82.35897827, 18.1491394], [82.34873199, 18.16183281], [82.34160614, 18.16343117], [82.33302307, 18.16341972], [82.32479095, 18.16641998], [82.31931305, 18.17143059], [82.31030273, 18.17460251], [82.30821991, 18.18128014], [82.30943298, 18.18938065], [82.30609894, 18.19565964], [82.31973267, 18.20104027], [82.33281708, 18.21578979], [82.32673645, 18.21623039], [82.32131958, 18.22245979], [82.32253265, 18.22812843], [82.33022308, 18.23134041], [82.33100891, 18.23336029], [82.33203888, 18.24012947], [82.33180237, 18.24679184], [82.33390045, 18.25229073], [82.3368988, 18.26624107], [82.34365082, 18.27165031], [82.3670578, 18.27094078], [82.37187958, 18.27410126], [82.3822403, 18.28429031], [82.38540649, 18.28909111], [82.38735199, 18.30062294], [82.393013, 18.30644035], [82.38842773, 18.3112011], [82.3843689, 18.31870079], [82.38049316, 18.31931114], [82.37510681, 18.31800079], [82.3691864, 18.31775284], [82.36524963, 18.31642914], [82.35797119, 18.30824089], [82.35456085, 18.309021], [82.34874725, 18.30615044], [82.34290314, 18.30734062], [82.34101105, 18.31065941], [82.33444214, 18.31713295], [82.33641815, 18.32011986], [82.34542084, 18.32181931], [82.35021973, 18.32891083], [82.35656738, 18.33357048], [82.36013794, 18.34370041], [82.36947632, 18.35036278], [82.3763504, 18.35326958], [82.37970734, 18.3574295], [82.37879944, 18.3616581], [82.38109589, 18.36668968], [82.38442993, 18.36911011], [82.38443756, 18.37240982], [82.37841034, 18.37813187], [82.37523651, 18.38306046], [82.37490845, 18.39281082], [82.37251282, 18.39809036], [82.36599731, 18.40335274], [82.36128998, 18.4099102], [82.36599731, 18.41301155], [82.36702728, 18.41716957], [82.37174225, 18.42016983], [82.37760162, 18.42198944], [82.38065338, 18.42642975], [82.38227081, 18.43169975], [82.39737701, 18.45160103], [82.41220093, 18.46467018], [82.42032623, 18.46988106], [82.42687225, 18.47699165], [82.42913818, 18.48514175], [82.43712616, 18.4973011], [82.44993591, 18.5114212], [82.45342255, 18.51702118], [82.47400665, 18.53683281], [82.48161316, 18.53845978], [82.48532104, 18.53370094], [82.48191833, 18.53271103], [82.47783661, 18.53153038], [82.47573853, 18.5294075], [82.48145294, 18.51506042], [82.49820709, 18.50604057], [82.49880981, 18.5032711], [82.49915314, 18.50175095], [82.50202179, 18.50173187], [82.50418091, 18.50549126], [82.50740814, 18.50807953], [82.51426697, 18.50363922], [82.51751709, 18.50563812], [82.52313232, 18.50392914], [82.52390289, 18.49929047], [82.52202606, 18.4969902], [82.52321625, 18.4935112], [82.52449799, 18.48978043], [82.52005768, 18.48726082], [82.51979065, 18.48488998], [82.51951599, 18.48251152], [82.52448273, 18.48284912], [82.52752686, 18.47772026], [82.52101135, 18.47237015], [82.52572632, 18.470541], [82.5275116, 18.46821976], [82.52176666, 18.46175957], [82.51774597, 18.45928955], [82.51676178, 18.45721054], [82.51613617, 18.45588112], [82.52319336, 18.45277977], [82.52043915, 18.45053291], [82.52120209, 18.44711113], [82.52316284, 18.44577026], [82.52670288, 18.44730949], [82.5293808, 18.44293976], [82.52879333, 18.44034004], [82.53015137, 18.43431091], [82.53308105, 18.43406105], [82.53560638, 18.43665123], [82.53900909, 18.43808937], [82.5383606, 18.44318008], [82.54421234, 18.44129944], [82.54772949, 18.44178963], [82.55011749, 18.43889046], [82.55377197, 18.43765068], [82.55107117, 18.43390083], [82.55021667, 18.42650032], [82.54605865, 18.42414284], [82.54512024, 18.41724968], [82.53968048, 18.41686821], [82.5376358, 18.41222954], [82.53591156, 18.40831947], [82.53697968, 18.4041996], [82.53968811, 18.40362167], [82.54057312, 18.40343094], [82.54032135, 18.40187073], [82.5326004, 18.39682007], [82.53230286, 18.39344978], [82.53515625, 18.3895607], [82.54234314, 18.38904953], [82.54944611, 18.38351059], [82.55172729, 18.38708115], [82.55603027, 18.38850975], [82.56521606, 18.38398933], [82.57060242, 18.38418961], [82.57556152, 18.37986946], [82.57733154, 18.37732124], [82.58080292, 18.37885094], [82.58917236, 18.37713814], [82.59364319, 18.37049103], [82.59902191, 18.37161827], [82.60050964, 18.36870956], [82.60087585, 18.36605072], [82.59768677, 18.3625927], [82.59931183, 18.35997009], [82.5976181, 18.35621834], [82.59857941, 18.35401154], [82.60566711, 18.35280991], [82.60865784, 18.35123062], [82.61128235, 18.34646034], [82.60787964, 18.34167099], [82.59915161, 18.34242058], [82.59783173, 18.34164047], [82.59651184, 18.3408699], [82.59757996, 18.33361816], [82.60031891, 18.33076096], [82.60382843, 18.32037163], [82.60214233, 18.31726074], [82.59568787, 18.3159008], [82.59229279, 18.31792068], [82.58966827, 18.3194828], [82.58863831, 18.31847954], [82.58596039, 18.3159008], [82.58325195, 18.3114109], [82.57805634, 18.30935097], [82.5764389, 18.30681038], [82.57978058, 18.30104065], [82.58107758, 18.30093956], [82.58270264, 18.30080032], [82.58783722, 18.3020401], [82.59095001, 18.29195976], [82.59031677, 18.28778076], [82.58757782, 18.2847805], [82.58558655, 18.28096008], [82.58722687, 18.27943993], [82.58840179, 18.27833939], [82.58846283, 18.27504921], [82.58428192, 18.27322006], [82.58074188, 18.27009964], [82.58318329, 18.26655006], [82.58547211, 18.26612091], [82.58724976, 18.2657795], [82.58866882, 18.26211929], [82.58920288, 18.25672913], [82.5982666, 18.25447273], [82.60076904, 18.25201988], [82.60948181, 18.24925041], [82.61181641, 18.24651146], [82.61103058, 18.24384117], [82.61341858, 18.23942947], [82.6164093, 18.23812103], [82.62039185, 18.23637009], [82.62687683, 18.22874069], [82.6288681, 18.22866058], [82.63165283, 18.22853088], [82.63716888, 18.23493004], [82.64530945, 18.24044991], [82.64758301, 18.2447319], [82.64485931, 18.25707817], [82.64910889, 18.26383972], [82.65222931, 18.2721405], [82.65648651, 18.27880096], [82.65883636, 18.28660965], [82.66493988, 18.2906208], [82.6725769, 18.29220009], [82.67539978, 18.29236984], [82.68177795, 18.29277992], [82.69032288, 18.29706955], [82.69374084, 18.29733086], [82.69809723, 18.29627037], [82.70050049, 18.29978943], [82.70169067, 18.30484009], [82.7025528, 18.30846977], [82.70670319, 18.31063271], [82.71090698, 18.31282043], [82.71726227, 18.31482124], [82.72531128, 18.31157112], [82.73432922, 18.3132515], [82.73280334, 18.3178997], [82.73781586, 18.31990051], [82.74642944, 18.31985092], [82.7506485, 18.32329941], [82.7510376, 18.3283329], [82.7544632, 18.32982063], [82.75849915, 18.32718086], [82.76184845, 18.32781029], [82.7670517, 18.33107948], [82.7714386, 18.33967972], [82.78421783, 18.35415077], [82.77790833, 18.37092018], [82.78096771, 18.37252045], [82.78761292, 18.37816048], [82.78675842, 18.38458061], [82.78748322, 18.3902092], [82.79329681, 18.39496994], [82.78739166, 18.39982033], [82.78118134, 18.3994503], [82.78160858, 18.4042511], [82.77845764, 18.40947914], [82.77620697, 18.41551971], [82.77622223, 18.41969109], [82.78710938, 18.42674065], [82.79197693, 18.4331398], [82.79917145, 18.43940163], [82.81835938, 18.43852997], [82.81874847, 18.43337059], [82.82417297, 18.4299202], [82.83014679, 18.42612076], [82.83576965, 18.42423058], [82.83634186, 18.41954041], [82.83698273, 18.4142704], [82.83978271, 18.41177177], [82.84490967, 18.40977287], [82.84863281, 18.41500854], [82.85597992, 18.41080093], [82.86296844, 18.40792084], [82.87001038, 18.40620041], [82.87706757, 18.4118309], [82.87935638, 18.41464043], [82.88461304, 18.41275978], [82.88835907, 18.40625954], [82.89077759, 18.39859962], [82.89095306, 18.39221954], [82.88490295, 18.37862015], [82.89186096, 18.36688042], [82.89852142, 18.35930061], [82.90274811, 18.35591125], [82.90838623, 18.35943031], [82.91166687, 18.35737991], [82.91513062, 18.35639954], [82.9200592, 18.3597393], [82.9276123, 18.36098862], [82.93268585, 18.35136986], [82.94550323, 18.35046959], [82.94816589, 18.35206032], [82.95204926, 18.35434914], [82.95597076, 18.35581017], [82.95979309, 18.35724068], [82.96878052, 18.35758018], [82.97644806, 18.3549118], [82.9784317, 18.36098862], [82.9812088, 18.36581993], [82.98610687, 18.36590195], [82.98761749, 18.36950111], [82.99196625, 18.37499809], [82.99286652, 18.37482071], [82.99711609, 18.37486076], [83.00348663, 18.3769207], [83.01161194, 18.37821007], [83.0171814, 18.3845005], [83.02005005, 18.38348007], [83.02375793, 18.37644958], [83.03188324, 18.3732605], [83.03697968, 18.36984253], [83.03952026, 18.37008095], [83.0533905, 18.37529945], [83.05619812, 18.37726021], [83.06582642, 18.38940048], [83.0664978, 18.3922596], [83.06582642, 18.39315987], [83.06373596, 18.39570999], [83.05903625, 18.3990097], [83.05581665, 18.40436935], [83.05531311, 18.40811157], [83.06035614, 18.41337967], [83.06046295, 18.41348839], [83.06062317, 18.41924286], [83.06208801, 18.42088127], [83.061203, 18.42394066], [83.05982971, 18.42863274], [83.05825806, 18.42905998], [83.0485611, 18.42486], [83.04261017, 18.41829109], [83.03743744, 18.41894913], [83.03555298, 18.42007065], [83.03330231, 18.42333984], [83.03819275, 18.42671013], [83.03900909, 18.43204117], [83.037323, 18.43482971], [83.032341, 18.43618965], [83.02484131, 18.43666077], [83.01803589, 18.44040108], [83.01541138, 18.4444294], [83.01644897, 18.44767952], [83.02455902, 18.45369911], [83.02672577, 18.45692062], [83.03414917, 18.46076965], [83.03701782, 18.46313095], [83.04384613, 18.47211075], [83.05179596, 18.47748947], [83.05517578, 18.48812294], [83.06035614, 18.49442101], [83.06511688, 18.4975605], [83.06881714, 18.50202942], [83.07315826, 18.51473999], [83.08230591, 18.52717018], [83.08850861, 18.53276062], [83.08933258, 18.53791046], [83.08705139, 18.54105949], [83.0714798, 18.54249191], [83.05735779, 18.53469086], [83.05414581, 18.53479958], [83.05117798, 18.5349102], [83.04509735, 18.53932953], [83.04023743, 18.54489136], [83.03247833, 18.54788971], [83.03370667, 18.55829048], [83.02545929, 18.56430054], [83.0268631, 18.56796074], [83.03114319, 18.5717907], [83.03376007, 18.57571983], [83.03650665, 18.57757187], [83.04171753, 18.5773201], [83.04203796, 18.57730293], [83.0447464, 18.57817078], [83.0511322, 18.58307076], [83.05394745, 18.58646965], [83.05297852, 18.58993912], [83.05208588, 18.59305954], [83.04946899, 18.59486961], [83.04891968, 18.59526253], [83.04110718, 18.59673119], [83.04065704, 18.59526253], [83.03970337, 18.59207916], [83.03781891, 18.58871269], [83.03114319, 18.58358955], [83.02770233, 18.58227158], [83.01586914, 18.58477974], [83.00804138, 18.58842087], [83.00948334, 18.5914402], [83.02030182, 18.60541153], [83.02126312, 18.61045074], [83.01737976, 18.62339973], [83.01461029, 18.62626076], [83.01132202, 18.62771034], [83.00934601, 18.63148117], [83.00948334, 18.63354111], [83.0096817, 18.63652992], [83.01154327, 18.63903046], [83.0226059, 18.64435959], [83.03616333, 18.64768982], [83.05097198, 18.65415955], [83.05146027, 18.6632309], [83.05584717, 18.66714096], [83.07080841, 18.68930054], [83.06987762, 18.69188118], [83.0690918, 18.69405174], [83.07073212, 18.69719124], [83.07788086, 18.70533943], [83.08574677, 18.70998001], [83.0880661, 18.71240044], [83.08960724, 18.71627045], [83.09079742, 18.71925926], [83.09259033, 18.7217617], [83.09546661, 18.72309113], [83.09921265, 18.72689056], [83.10600281, 18.73849106], [83.11650085, 18.74797058], [83.11752319, 18.75048065], [83.11219025, 18.7582798], [83.11580658, 18.76208115], [83.13295746, 18.77244949], [83.13884735, 18.77113914], [83.14491272, 18.76690102], [83.14686584, 18.76317978], [83.15083313, 18.75868988], [83.15622711, 18.75731087], [83.16854858, 18.75906944], [83.17394257, 18.75676918], [83.17701721, 18.75440979], [83.18080139, 18.74825096], [83.1853714, 18.74414253], [83.19181824, 18.74178123], [83.20170593, 18.74222946], [83.20342255, 18.74035263], [83.20188904, 18.73613167], [83.2024231, 18.73254967], [83.20626068, 18.7287426], [83.20633698, 18.72803116], [83.20641327, 18.72742081], [83.20366669, 18.72350121], [83.20332336, 18.7195797], [83.20506287, 18.71586037], [83.20677948, 18.71749115], [83.20918274, 18.72454071], [83.2125473, 18.7344799], [83.21363831, 18.73602104], [83.21446228, 18.73719978], [83.22033691, 18.74204826], [83.22235107, 18.74505043], [83.2230072, 18.74798012], [83.22268677, 18.74861908], [83.22189331, 18.75202179], [83.21733093, 18.75895119], [83.21707916, 18.76356125], [83.21939087, 18.76581955], [83.22103119, 18.76587105], [83.22271729, 18.76593018], [83.22651672, 18.76490021], [83.22931671, 18.76414108], [83.23956299, 18.75878143], [83.24508667, 18.75808907], [83.25541687, 18.75881958], [83.2593689, 18.75760078], [83.26609802, 18.75700951], [83.26991272, 18.75980949], [83.27171326, 18.76317978], [83.27124786, 18.76732063], [83.26914978, 18.77075958], [83.26992035, 18.77528763], [83.2752533, 18.78536987], [83.27950287, 18.78960037], [83.29210663, 18.79253006], [83.30036926, 18.79791069], [83.30422211, 18.79887009], [83.31404114, 18.79580116], [83.31826019, 18.79584122], [83.32302094, 18.79828072], [83.32614136, 18.79482079], [83.32978821, 18.79372978], [83.33333588, 18.7926712], [83.33587646, 18.79321289], [83.33687592, 18.79465294], [83.33761597, 18.79570007], [83.33812714, 18.80035019], [83.33927917, 18.80309105], [83.34073639, 18.8035202], [83.34429169, 18.80293083], [83.34780884, 18.80125809], [83.3524704, 18.80018997], [83.35629272, 18.8001194], [83.35848236, 18.80179977], [83.36022949, 18.80447006], [83.35999298, 18.80735016], [83.35011292, 18.82163811], [83.35349274, 18.82748985], [83.35887909, 18.83200073], [83.36032104, 18.83204079], [83.36226654, 18.83210945], [83.37283325, 18.82121086], [83.3763504, 18.82195091], [83.38313293, 18.82607079], [83.38648987, 18.82576942], [83.39630127, 18.83070946], [83.39871216, 18.83352852], [83.39694214, 18.84921074], [83.39787292, 18.85259056], [83.39985657, 18.85365105], [83.40680695, 18.85367966], [83.40875244, 18.85445023], [83.41073608, 18.85676193], [83.41133881, 18.85934067], [83.40585327, 18.86532974], [83.40432739, 18.86598015], [83.40177917, 18.86707115], [83.39425659, 18.8682003], [83.38780975, 18.87103081], [83.38539124, 18.87326241], [83.38568115, 18.87549019], [83.37890625, 18.88027954], [83.37390137, 18.88591194], [83.37248993, 18.88983917], [83.37444305, 18.89194107], [83.38326263, 18.89723969], [83.38391113, 18.89969063], [83.3809967, 18.90182114], [83.37684631, 18.90246964], [83.36715698, 18.90036011], [83.36631012, 18.9004612], [83.36052704, 18.90117073], [83.35777283, 18.9036808], [83.35649872, 18.90480995], [83.35016632, 18.91592979], [83.34768677, 18.92098808], [83.34661102, 18.92687035], [83.34792328, 18.93214035], [83.34902954, 18.9338398], [83.35523987, 18.93303108], [83.36276245, 18.93007088], [83.36406708, 18.92278862], [83.3710022, 18.91708946], [83.37384033, 18.91679192], [83.37634277, 18.91777039], [83.37966156, 18.92152023], [83.38022614, 18.92328262], [83.36741638, 18.93349075], [83.36389923, 18.93793106], [83.36084747, 18.94811058], [83.36106873, 18.95340157], [83.36022949, 18.95389938], [83.35890198, 18.95471191], [83.35440826, 18.95445061], [83.34903717, 18.95609093], [83.34575653, 18.95709991], [83.34501648, 18.95630074], [83.34480286, 18.94524956], [83.34326172, 18.93516159], [83.33983612, 18.93321991], [83.33972931, 18.93275261], [83.33952332, 18.93191147], [83.33953857, 18.9294796], [83.33957672, 18.92620087], [83.34136963, 18.91839981], [83.33905792, 18.91620064], [83.33454132, 18.91582108], [83.32901001, 18.91690826], [83.32202911, 18.9232502], [83.31991577, 18.92581749], [83.31887817, 18.92843819], [83.3184967, 18.93362045], [83.32119751, 18.93602943], [83.33113098, 18.93763924], [83.33302307, 18.93931961], [83.3324585, 18.94337082], [83.33104706, 18.94581032], [83.32888794, 18.94682121], [83.32704163, 18.94790077], [83.32601166, 18.95016289], [83.32565308, 18.95292282], [83.32691956, 18.95734024], [83.32556152, 18.95897102], [83.32055664, 18.96103096], [83.31980896, 18.96133041], [83.31334686, 18.96663094], [83.30961609, 18.9768219], [83.30914307, 18.98035049], [83.30774689, 18.98324966], [83.30432892, 18.98698997], [83.30526733, 18.98968124], [83.30783844, 18.99094963], [83.31643677, 18.99040031], [83.32537842, 18.98880959], [83.32917786, 18.98818016], [83.33120728, 18.99007034], [83.33075714, 18.99257088], [83.33010101, 18.99695969], [83.33067322, 18.99842834], [83.33271027, 18.99983978], [83.3349762, 19.00671959], [83.34091187, 19.0091629], [83.34633636, 19.0098896], [83.35498047, 19.00938988], [83.35800934, 19.00613976], [83.36232758, 18.99473], [83.36747742, 18.99361992], [83.37719727, 18.99472046], [83.38471985, 18.99727249], [83.3887558, 19.00001907], [83.39295959, 18.99912834], [83.39605713, 18.99583054], [83.40142059, 18.99638176], [83.40231323, 18.99516106], [83.4046402, 18.99320984], [83.4068985, 18.99508095], [83.40885162, 18.99619102], [83.41057587, 18.99261093], [83.41142273, 18.98871994], [83.40878296, 18.97989082], [83.4148407, 18.97787285], [83.43292236, 18.96139908], [83.43647766, 18.95787811], [83.44001007, 18.95022011], [83.44267273, 18.94774055], [83.44684601, 18.94564819], [83.45120239, 18.94445992], [83.45548248, 18.94557953], [83.46227264, 18.95922089], [83.46224213, 18.96359062], [83.46147156, 18.9679203], [83.45894623, 18.97044945], [83.45831299, 18.97247124], [83.46029663, 18.98077965], [83.4577179, 18.98250008], [83.45022583, 18.98242188], [83.44908905, 18.99261093], [83.44822693, 18.99594116], [83.44851685, 18.99963188], [83.45017242, 19.00188828], [83.45327759, 19.00246048], [83.45848083, 19.00209808], [83.46750641, 18.99891853], [83.4718399, 18.99897957], [83.47460175, 19.00031281], [83.47663879, 19.00407028], [83.47511292, 19.01152992], [83.47796631, 19.02119064], [83.47735596, 19.02551842], [83.46543884, 19.03619003], [83.46279907, 19.04395103], [83.46327209, 19.05260086], [83.45670319, 19.05611038], [83.45736694, 19.0598011], [83.45913696, 19.06348991], [83.45826721, 19.06713295], [83.45939636, 19.06967163], [83.46382904, 19.0714016], [83.46746826, 19.06987953], [83.47027588, 19.07032013], [83.47202301, 19.07274055], [83.47323608, 19.0777626], [83.47698975, 19.07533073], [83.47817993, 19.07022095], [83.48043823, 19.06648064], [83.49249268, 19.05495071], [83.49362946, 19.05308914], [83.49633026, 19.05550957], [83.50036621, 19.06208038], [83.50287628, 19.06466103], [83.50538635, 19.06477165], [83.50617981, 19.05430984], [83.50847626, 19.0499115], [83.51074982, 19.04800034], [83.50979614, 19.04008102], [83.51008606, 19.03617287], [83.51322937, 19.03032112], [83.51367188, 19.02478027], [83.50817871, 19.02197075], [83.50392914, 19.02620125], [83.49931335, 19.02708054], [83.49355316, 19.02680016], [83.49263, 19.02398109], [83.49292755, 19.01803017], [83.49539948, 19.01109123], [83.50460052, 19.01009941], [83.51529694, 19.00490952], [83.53138733, 19.00542068], [83.53311157, 19.01246071], [83.53309631, 19.01938248], [83.53482819, 19.02861977], [83.53578949, 19.03034973], [83.54277802, 19.03684044], [83.54772949, 19.04496956], [83.5522995, 19.04718971], [83.55148315, 19.05038071], [83.54486847, 19.06208038], [83.54485321, 19.06940269], [83.5464325, 19.07382965], [83.55149078, 19.07785034], [83.55497742, 19.07813072], [83.56067657, 19.06622124], [83.56038666, 19.06396103], [83.55710602, 19.05998993], [83.556427, 19.05583954], [83.55766296, 19.05138016], [83.56105042, 19.05038834], [83.56735992, 19.05225945], [83.57876587, 19.04978943], [83.58078003, 19.05514908], [83.58178711, 19.06277275], [83.5821991, 19.07563972], [83.58444977, 19.07973099], [83.58763123, 19.08307076], [83.59320831, 19.08489037], [83.59986115, 19.08480263], [83.60441589, 19.08818054], [83.60440063, 19.09287071], [83.59677887, 19.10519981], [83.59429932, 19.11058044], [83.59365082, 19.11548996], [83.59429932, 19.12033081], [83.60051727, 19.12770081], [83.60521698, 19.13103294], [83.61060333, 19.13093758], [83.61408997, 19.13381958], [83.619133, 19.14188194], [83.62271881, 19.14468765], [83.62023926, 19.14862823], [83.62116241, 19.15192032], [83.62328339, 19.15363121], [83.62850952, 19.14974022], [83.63018799, 19.14479065], [83.62844086, 19.13150024], [83.62983704, 19.12699127], [83.63331604, 19.1244297], [83.64556122, 19.12310028], [83.64943695, 19.12187958], [83.65072632, 19.11840057], [83.64974976, 19.11482048], [83.64627075, 19.11449814], [83.64472961, 19.11329079], [83.64588165, 19.10873032], [83.647789, 19.10594177], [83.6479187, 19.10225105], [83.65026855, 19.10009956], [83.65748596, 19.08777237], [83.65809631, 19.08210945], [83.65685272, 19.07493973], [83.65969849, 19.0697403], [83.66261292, 19.06649017], [83.66673279, 19.06446075], [83.67637634, 19.05245018], [83.68438721, 19.04393005], [83.69415283, 19.02114105], [83.69702148, 19.01647949], [83.69983673, 19.01503181], [83.71682739, 19.01444817], [83.72128296, 19.0134182], [83.72325134, 19.01189995], [83.71984863, 19.00428963], [83.71478271, 19.00213051], [83.70941925, 19.00195122], [83.70500183, 18.99946976], [83.70436096, 18.99530983], [83.70469666, 18.99248123], [83.70484924, 18.99200821], [83.70574188, 18.98524094], [83.70880127, 18.9838028], [83.71140289, 18.98495102], [83.71689606, 18.98253822], [83.7263031, 18.97556114], [83.72746277, 18.96607971], [83.73002625, 18.9601593], [83.73649597, 18.93897057], [83.73992157, 18.93406105], [83.74140167, 18.93029022], [83.74214935, 18.92313957], [83.74582672, 18.91817284], [83.75614929, 18.91669083], [83.7628479, 18.90653992], [83.76750183, 18.90236282], [83.77050018, 18.90159035], [83.77127075, 18.90130043], [83.77739716, 18.90439987], [83.78006744, 18.90772057], [83.77715302, 18.9190712], [83.76986694, 18.93297005], [83.76525116, 18.93642044], [83.76148224, 18.94460106], [83.75520325, 18.94202995], [83.75036621, 18.94437027], [83.74836731, 18.95137024], [83.74900055, 18.95844078], [83.74597168, 18.9632206], [83.74172211, 18.96705818], [83.73956299, 18.97844124], [83.74108124, 18.98389053], [83.74923706, 18.99067116], [83.75061798, 18.99241829], [83.75128174, 18.99328041], [83.75242615, 18.99333191], [83.75354767, 18.99316978], [83.75469208, 18.99337006], [83.75582886, 18.99361038], [83.75695801, 18.99390984], [83.75778961, 18.99455833], [83.75845337, 18.99547005], [83.75946808, 18.99605942], [83.76056671, 18.9964695], [83.76171112, 18.99677849], [83.76288605, 18.99705124], [83.76405334, 18.99731064], [83.7652359, 18.99760056], [83.7664032, 18.99795914], [83.76747894, 18.99842834], [83.76850128, 18.99908066], [83.76941681, 18.99977112], [83.77021027, 19.00059128], [83.7706604, 19.0016098], [83.77111816, 19.00263977], [83.7715683, 19.00366974], [83.77204895, 19.0046711], [83.77259827, 19.00566101], [83.77320099, 19.00658989], [83.77392578, 19.00745964], [83.77474213, 19.00824928], [83.77565002, 19.00896072], [83.77664948, 19.00951958], [83.77774048, 19.00988007], [83.77887726, 19.01000977], [83.78037262, 19.0099411], [83.78148651, 19.00979042], [83.78263855, 19.00957108], [83.78375244, 19.00933075], [83.78486633, 19.00909042], [83.7859726, 19.00878906], [83.78704071, 19.00836945], [83.78830719, 19.00781059], [83.78894806, 18.99833107], [83.79116821, 18.99235916], [83.80253601, 18.98180962], [83.80809021, 18.96840286], [83.81063843, 18.9648304], [83.81476593, 18.95317841], [83.81606293, 18.9486599], [83.8134079, 18.9335804], [83.814888, 18.93003845], [83.81890106, 18.92609978], [83.82116699, 18.92196083], [83.81693268, 18.90940285], [83.81845093, 18.90711975], [83.82305145, 18.90546036], [83.83487701, 18.90929985], [83.83772278, 18.90860939], [83.840271, 18.90406036], [83.84163666, 18.89763069], [83.8423233, 18.88824081], [83.83669281, 18.87272072], [83.83600616, 18.8691082], [83.83709717, 18.86470985], [83.84366608, 18.85140038], [83.84797668, 18.8476181], [83.85906982, 18.84301186], [83.86434174, 18.83904076], [83.86686707, 18.82345009], [83.87017822, 18.81842995], [83.87391663, 18.8177681], [83.88323975, 18.8196907], [83.88463593, 18.8178196], [83.88535309, 18.81004143], [83.88687897, 18.80540848], [83.89064026, 18.80686951], [83.89547729, 18.81487846], [83.89855194, 18.81644058], [83.90197754, 18.81692123], [83.90775299, 18.81638908], [83.92059326, 18.81157112], [83.9226532, 18.80853271], [83.9263916, 18.80656052], [83.93358612, 18.80685806], [83.93572235, 18.8031292], [83.93657684, 18.79920006], [83.93978882, 18.79660034], [83.94368744, 18.79628754], [83.94902039, 18.79704094], [83.95121002, 18.8000412], [83.95561218, 18.80306053], [83.9640274, 18.80410957], [83.96938324, 18.80382919], [83.98232269, 18.80001068], [83.991539, 18.8046627], [83.99997711, 18.8047905], [84.00739288, 18.80421066], [84.01249695, 18.80063057], [84.01586914, 18.80141068], [84.01966095, 18.79762268], [84.02231598, 18.79862976], [84.02372742, 18.80115128], [84.02706146, 18.80220032], [84.03071594, 18.80027962], [84.03077698, 18.79544067], [84.0342865, 18.79012108], [84.03871918, 18.78742981], [84.04794312, 18.78347969], [84.04760742, 18.77987289], [84.04972076, 18.77730942], [84.04804993, 18.77440262], [84.04920197, 18.77065086], [84.05355835, 18.76836967], [84.05860901, 18.76810074], [84.06046295, 18.76267052], [84.06577301, 18.75169945], [84.06989288, 18.74975967], [84.07788086, 18.74888039], [84.07933044, 18.74611092], [84.08177948, 18.74464035], [84.08557892, 18.74518013], [84.08878326, 18.74711037], [84.09163666, 18.74523926], [84.10072327, 18.75267982], [84.10758972, 18.7548008], [84.11406708, 18.7551403], [84.118927, 18.75303078], [84.12294006, 18.74826813], [84.12948608, 18.75286293], [84.12793732, 18.76126862], [84.13136292, 18.76480293], [84.13497925, 18.76678848], [84.14042664, 18.76769066], [84.14811707, 18.77176094], [84.15136719, 18.77576065], [84.15493011, 18.77601051], [84.15934753, 18.77503967], [84.16027069, 18.77231979], [84.15818787, 18.76918983], [84.16262817, 18.76856995], [84.16703033, 18.77013969], [84.1798172, 18.76897049], [84.18151093, 18.77752113], [84.18651581, 18.77960014], [84.19033813, 18.77673912], [84.2038269, 18.78264046], [84.21671295, 18.78728104], [84.22145844, 18.78647995], [84.22429657, 18.78426933], [84.22698975, 18.78716087], [84.23069, 18.78564072], [84.23116302, 18.78012085], [84.24603271, 18.7734108], [84.25218964, 18.77248192], [84.25888824, 18.77482986], [84.26422119, 18.78051949], [84.26818848, 18.78030968], [84.27321625, 18.78248978], [84.27533722, 18.78718185], [84.27854919, 18.78968048], [84.28392029, 18.79082108], [84.30036926, 18.78174019], [84.30432129, 18.78071976], [84.30716705, 18.78166008], [84.30885315, 18.77841949], [84.31249237, 18.77919006], [84.31292725, 18.78218079], [84.3157196, 18.78617096], [84.3269577, 18.78967285], [84.33222198, 18.79202271], [84.33358765, 18.79505157], [84.32952881, 18.8045311], [84.32932281, 18.80899811], [84.34410095, 18.81194115], [84.34075928, 18.81825066], [84.34243011, 18.82150841], [84.3442688, 18.8227005], [84.34516907, 18.82678032], [84.34435272, 18.8327198], [84.3380661, 18.83621979], [84.33598328, 18.84142113], [84.33413696, 18.85156059], [84.33413696, 18.85799026], [84.33442688, 18.86384964], [84.33602142, 18.86671066], [84.33979034, 18.86592102], [84.34438324, 18.86276245], [84.3469696, 18.85997963], [84.35146332, 18.85090065], [84.35411835, 18.85149956], [84.35521698, 18.85264015], [84.3583374, 18.85134125], [84.3624115, 18.85106087], [84.36933899, 18.85897064], [84.37146759, 18.86338234], [84.37156677, 18.86721992], [84.36624908, 18.87170982], [84.3613205, 18.87268066], [84.35962677, 18.87190056], [84.35382843, 18.87506294], [84.35183716, 18.87779045], [84.35144806, 18.88319969], [84.35473633, 18.88293076], [84.37135315, 18.8754406], [84.37406921, 18.87649918], [84.37808228, 18.87409973], [84.38323212, 18.86927986], [84.38622284, 18.87170982], [84.38762665, 18.87766838], [84.38609314, 18.88302994], [84.37903595, 18.88546944], [84.37422943, 18.8888607], [84.36767578, 18.88932991], [84.36490631, 18.8932209], [84.3653183, 18.89625931], [84.36976624, 18.89581108], [84.37406921, 18.89402962], [84.37845612, 18.89324188], [84.38687134, 18.88986969], [84.39396667, 18.88586998], [84.39782715, 18.88611984], [84.40981293, 18.89063072], [84.41208649, 18.89393997], [84.41072083, 18.89825821], [84.40769958, 18.90112114], [84.40615082, 18.9061203], [84.40956879, 18.90810013], [84.41796875, 18.90065956], [84.42032623, 18.90487099], [84.42938995, 18.91368294], [84.41998291, 18.92971039], [84.41713715, 18.93330193], [84.41559601, 18.93803978], [84.42030334, 18.94935989], [84.43454742, 18.96315956], [84.43772888, 18.96570969], [84.44064331, 18.96693039], [84.4347229, 18.97682953], [84.42796326, 18.98264122], [84.42640686, 18.98397064], [84.42555237, 18.989151], [84.42610931, 18.99176979], [84.42526245, 18.99534035], [84.42003632, 19.00084114], [84.41803741, 19.00498962], [84.4154129, 19.00813293], [84.41464996, 19.01235962], [84.41513062, 19.0138607], [84.42002106, 19.01251984], [84.42218781, 19.00853157], [84.42980194, 19.00118065], [84.43297577, 19.00185966], [84.43739319, 18.99745941], [84.44406128, 18.99455833], [84.44815063, 18.99173927], [84.45218658, 18.98833084], [84.46282959, 18.98328972], [84.4716568, 18.98122025], [84.47306061, 18.98264122], [84.47569275, 18.99173927], [84.47551727, 18.99603271], [84.47782898, 19.0078907], [84.48206329, 19.00990868], [84.48938751, 19.02095032], [84.49777985, 19.02487946], [84.5030899, 19.02926254], [84.5071106, 19.03544807], [84.50991821, 19.03746033], [84.52715302, 19.03871918], [84.53147125, 19.0441494], [84.53481293, 19.04536057], [84.54772186, 19.04609108], [84.5535965, 19.04740906], [84.5597229, 19.05956078], [84.56613922, 19.06503868], [84.56797028, 19.06347084], [84.56852722, 19.06064034], [84.57060242, 19.06041145], [84.57644653, 19.06456184], [84.57811737, 19.06212807], [84.57509613, 19.03753853], [84.57364655, 19.03511047], [84.57531738, 19.02719116], [84.57813263, 19.01890182], [84.58769226, 19.01299095], [84.59011841, 19.01338005], [84.59697723, 19.01974106], [84.60048676, 19.03293037], [84.60756683, 19.04540825], [84.60946655, 19.04673958], [84.61418915, 19.0467205], [84.61235809, 19.04973984], [84.61152649, 19.05373001], [84.61271667, 19.05483055], [84.62329102, 19.05566025], [84.62541199, 19.05278015], [84.62608337, 19.05029106], [84.63005829, 19.04959106], [84.63437653, 19.05554008], [84.63683319, 19.05714989], [84.64772797, 19.0560894], [84.65453339, 19.05231094], [84.65901184, 19.06364822], [84.66320038, 19.06445122], [84.66458893, 19.06629181], [84.65962219, 19.07093048], [84.65416718, 19.08101273], [84.64871216, 19.08419991], [84.64460754, 19.08445168], [84.63474274, 19.07868958], [84.63360596, 19.07463837], [84.63144684, 19.07262039], [84.62444305, 19.07442093], [84.61982727, 19.07650948], [84.61656952, 19.08520126], [84.61678314, 19.09000015], [84.6144104, 19.09231758], [84.60962677, 19.09089279], [84.6055603, 19.09263039], [84.60293579, 19.09657097], [84.59577179, 19.11520958], [84.59168243, 19.12112045], [84.59184265, 19.12384033], [84.59464264, 19.12354851], [84.60939789, 19.11745071], [84.62554932, 19.11827087], [84.62931824, 19.12070084], [84.64037323, 19.12223816], [84.64170837, 19.12478828], [84.64729309, 19.12037086], [84.65342712, 19.12290955], [84.65731812, 19.12138939], [84.66117096, 19.1218605], [84.66451263, 19.12815094], [84.66590118, 19.13527107], [84.6654129, 19.14470291], [84.66326904, 19.14748001], [84.66501617, 19.15673065], [84.66929626, 19.15568161], [84.67333221, 19.15689087], [84.67807007, 19.15346909], [84.68141174, 19.14974976], [84.69213867, 19.15170097], [84.69756317, 19.15029144], [84.7020874, 19.15114975], [84.70522308, 19.1490097], [84.70648193, 19.14356041], [84.69731903, 19.1251297], [84.69391632, 19.12155151], [84.69381714, 19.11952019], [84.69776917, 19.1156311], [84.69832611, 19.1103096], [84.69754791, 19.10881805], [84.71185303, 19.1000309], [84.71903229, 19.09584427], [84.71902466, 19.09513855], [84.72022247, 19.09513855], [84.72041321, 19.09513855], [84.72041321, 19.09505844], [84.72041321, 19.09486198], [84.7206955, 19.09486198], [84.7206955, 19.09430695], [84.72097015, 19.09431076], [84.72097015, 19.09375], [84.7206955, 19.09375], [84.7206955, 19.09291649], [84.72097015, 19.0929203], [84.72097015, 19.09208107], [84.72125244, 19.09208488], [84.72125244, 19.09180641], [84.7215271, 19.09181023], [84.7215271, 19.09152985], [84.72180176, 19.09152985], [84.72180176, 19.09124947], [84.7223587, 19.09124947], [84.7223587, 19.09097099], [84.72264099, 19.09097481], [84.72264099, 19.09041405], [84.7223587, 19.09041977], [84.7223587, 19.08986282], [84.72264099, 19.08986282], [84.72264099, 19.08958054], [84.72319794, 19.08958054], [84.72319794, 19.08986282], [84.7234726, 19.08986282], [84.7234726, 19.09013939], [84.72374725, 19.09013939], [84.72374725, 19.09041977], [84.72402954, 19.09041405], [84.72402954, 19.09069252], [84.7243042, 19.09069252], [84.7243042, 19.09041405], [84.72486115, 19.09041977], [84.72486115, 19.09013939], [84.72541809, 19.09013939], [84.72541809, 19.08986282], [84.72569275, 19.08986282], [84.72569275, 19.09013939], [84.72624969, 19.09013939], [84.72624969, 19.08986282], [84.72820282, 19.08986282], [84.72819519, 19.08958244], [84.72973633, 19.08958244], [84.7298584, 19.08958244], [84.7298584, 19.08930588], [84.73021698, 19.08930588], [84.76101685, 19.07131195], [84.76097107, 19.07097054], [84.76069641, 19.07097244], [84.76069641, 19.07069397], [84.76041412, 19.07069397], [84.76041412, 19.0704174], [84.76013947, 19.07042122], [84.76013947, 19.06986046], [84.75985718, 19.06986046], [84.75985718, 19.06958008], [84.75958252, 19.06958389], [84.75958252, 19.06930542], [84.75930786, 19.06931114], [84.75930786, 19.06875038], [84.75902557, 19.06875038], [84.75902557, 19.06847191], [84.75875092, 19.06847191], [84.75875092, 19.06819534], [84.75846863, 19.06820107], [84.75846863, 19.0676403], [84.7582016, 19.0676403], [84.7582016, 19.06680107], [84.75791931, 19.06680679], [84.75791931, 19.06597137], [84.75763702, 19.06597137], [84.75763702, 19.06569672], [84.75736237, 19.06569672], [84.75736237, 19.06541634], [84.75708008, 19.06542969], [84.75708008, 19.06513977], [84.75680542, 19.06513977], [84.75680542, 19.0648613], [84.75624847, 19.0648613], [84.75624847, 19.06458473], [84.75597382, 19.06458473], [84.75597382, 19.06402779], [84.75569153, 19.06402969], [84.75569153, 19.06375122], [84.75543213, 19.06375122], [84.75543213, 19.06347084], [84.75514221, 19.06347466], [84.75514221, 19.06263924], [84.75485992, 19.06264114], [84.75485992, 19.06153107], [84.7545929, 19.06153107], [84.7545929, 19.06125259], [84.75430298, 19.06125259], [84.75430298, 19.06097031], [84.75402832, 19.06097031], [84.75402832, 19.06069374], [84.75375366, 19.06069374], [84.75375366, 19.05986023], [84.75347137, 19.05986023], [84.75347137, 19.05958176], [84.75319672, 19.05958366], [84.75319672, 19.05930519], [84.75291443, 19.05930519], [84.75291443, 19.05902863], [84.75263977, 19.05903244], [84.75263977, 19.05874825], [84.75235748, 19.05874825], [84.75235748, 19.05846977], [84.75208282, 19.05847168], [84.75208282, 19.05791664], [84.75180817, 19.05791855], [84.75180817, 19.05763817], [84.75125122, 19.05763817], [84.75125122, 19.05708122], [84.75096893, 19.05708313], [84.75096893, 19.05680466], [84.75069427, 19.05680466], [84.75069427, 19.05624962], [84.75041962, 19.05625916], [84.75041962, 19.05541992], [84.75013733, 19.05541992], [84.75013733, 19.05513954], [84.74986267, 19.05513954], [84.74986267, 19.05486107], [84.74958038, 19.05486107], [84.74958038, 19.05430984], [84.7492981, 19.05430984], [84.7492981, 19.05402946], [84.74903107, 19.05402946], [84.74903107, 19.05375099], [84.74874878, 19.05375099], [84.74874878, 19.05319977], [84.74846649, 19.05319977], [84.74846649, 19.05291939], [84.74791718, 19.05291939], [84.74791718, 19.05264091], [84.74764252, 19.05264091], [84.74764252, 19.05236053], [84.74736023, 19.05236053], [84.74736023, 19.05181122], [84.7470932, 19.05181122], [84.7470932, 19.05125046], [84.74680328, 19.05125046], [84.74680328, 19.05070114], [84.74652863, 19.0506897], [84.74652863, 19.04958153], [84.74624634, 19.04958153], [84.74624634, 19.04847145], [84.74597168, 19.04847145], [84.74597168, 19.04819489], [84.74541473, 19.04819489], [84.74541473, 19.04791641], [84.74514008, 19.04792023], [84.74514008, 19.04764175], [84.74485779, 19.04764175], [84.74485779, 19.04735947], [84.74430847, 19.04736137], [84.74430847, 19.0470829], [84.74402618, 19.0470829], [84.74402618, 19.04680634], [84.74346924, 19.04681015], [84.74346924, 19.04624939], [84.74319458, 19.04624939], [84.74319458, 19.04541588], [84.74236298, 19.0454216], [84.74236298, 19.04458046], [84.74208069, 19.04458427], [84.74208069, 19.0443058], [84.74180603, 19.04432106], [84.74180603, 19.04375076], [84.74124908, 19.04375076], [84.74124908, 19.04347038], [84.74097443, 19.04347229], [84.74097443, 19.04319382], [84.74069214, 19.04319382], [84.74069214, 19.04291725], [84.74041748, 19.04291916], [84.74041748, 19.04207993], [84.74013519, 19.04208374], [84.74013519, 19.04125023], [84.73986053, 19.04125977], [84.73986053, 19.04042053], [84.73958588, 19.04042053], [84.73958588, 19.03985977], [84.73930359, 19.03986168], [84.73930359, 19.03930664], [84.73902893, 19.03930664], [84.73902893, 19.03902817], [84.73847198, 19.03903008], [84.73847198, 19.03874969], [84.73821259, 19.03874969], [84.73791504, 19.03874969], [84.73791504, 19.03847313], [84.73764038, 19.03847313], [84.73764038, 19.03791428], [84.73706818, 19.03792], [84.73706818, 19.03763962], [84.73652649, 19.03763962], [84.73652649, 19.03736115], [84.73625183, 19.03736115], [84.73625183, 19.03680992], [84.73596954, 19.03680992], [84.73596954, 19.03652954], [84.73568726, 19.03652954], [84.73568726, 19.03625107], [84.73542023, 19.03625107], [84.73542023, 19.03569031], [84.73513794, 19.03569221], [84.73513794, 19.03513908], [84.73486328, 19.03513908], [84.73486328, 19.03486061], [84.73430634, 19.03486061], [84.73430634, 19.0340271], [84.73400879, 19.03403282], [84.73400879, 19.03347015], [84.73347473, 19.03347015], [84.73347473, 19.03319359], [84.73319244, 19.03319359], [84.73319244, 19.03291702], [84.73291779, 19.03292274], [84.73291779, 19.03264236], [84.73264313, 19.03264236], [84.73264313, 19.03235817], [84.73236084, 19.03236008], [84.73236084, 19.03124809], [84.73208618, 19.03124809], [84.73208618, 19.03096962], [84.73180389, 19.03097153], [84.73180389, 19.03069496], [84.73152924, 19.03070068], [84.73152924, 19.0304184], [84.73126221, 19.0304184], [84.73126221, 19.03013992], [84.73069763, 19.03013992], [84.73069763, 19.02985954], [84.73041534, 19.02986145], [84.73041534, 19.02930641], [84.73014069, 19.02932167], [84.73014069, 19.02902985], [84.7298584, 19.02902985], [84.7298584, 19.02874947], [84.72957611, 19.02874947], [84.72957611, 19.02847099], [84.72930908, 19.0284729], [84.72930908, 19.02791786], [84.72875214, 19.02791977], [84.72875214, 19.02680969], [84.72820282, 19.02680969], [84.72820282, 19.02626038], [84.7279129, 19.02626038], [84.7279129, 19.02597046], [84.72763824, 19.02597237], [84.72763824, 19.0256958], [84.72736359, 19.0256958], [84.72736359, 19.02513885], [84.72680664, 19.02514076], [84.72680664, 19.02486038], [84.72651672, 19.02486038], [84.72651672, 19.02458], [84.72624969, 19.02458572], [84.72624969, 19.02430344], [84.72598267, 19.02431107], [84.72598267, 19.02375031], [84.72569275, 19.02375031], [84.72569275, 19.02346039], [84.72569275, 19.02291679], [84.72558594, 19.0229187], [84.72541809, 19.02292061], [84.72541809, 19.02264023], [84.72512817, 19.02264023], [84.72512817, 19.02235985], [84.72486115, 19.02236366], [84.72486115, 19.02180481], [84.7243042, 19.02180481], [84.7243042, 19.02152824], [84.72402954, 19.02153015], [84.72402954, 19.02069283], [84.72374725, 19.02069473], [84.72374725, 19.02041626], [84.7234726, 19.02042007], [84.7234726, 19.02025986], [84.7234726, 19.02013969], [84.72303009, 19.02013969], [84.72291565, 19.02013969], [84.72291565, 19.01985931], [84.72264099, 19.01985931], [84.72264099, 19.0193119], [84.7223587, 19.0193119], [84.7223587, 19.01874924], [84.72206879, 19.01874924], [84.72206879, 19.01847076], [84.72180176, 19.01847267], [84.72180176, 19.0181942], [84.7215271, 19.0181942], [84.7215271, 19.01763916], [84.72125244, 19.01763916], [84.72125244, 19.01736069], [84.72097015, 19.01736069], [84.72097015, 19.01680756], [84.72070313, 19.01680756], [84.72070313, 19.01652908], [84.72041321, 19.01652908], [84.72041321, 19.01625061], [84.71985626, 19.01625061], [84.71985626, 19.01597023], [84.7195816, 19.01597214], [84.7195816, 19.01458359], [84.71930695, 19.01458359], [84.71930695, 19.01430511], [84.71875, 19.01432037], [84.71875, 19.01403046], [84.71819305, 19.01403046], [84.71819305, 19.01375008], [84.7179184, 19.01375008], [84.7179184, 19.01320076], [84.71763611, 19.01320076], [84.71763611, 19.01264], [84.71736145, 19.01264], [84.71736145, 19.01235962], [84.71708679, 19.01236153], [84.71708679, 19.01208305], [84.7168045, 19.01208305], [84.7168045, 19.01180649], [84.7159729, 19.0118103], [84.7159729, 19.01124954], [84.71569824, 19.01124954], [84.71569061, 19.01069069], [84.71541595, 19.0106926], [84.71541595, 19.01041412], [84.71485901, 19.01041985], [84.71485901, 19.01013947], [84.71457672, 19.01013947], [84.71457672, 19.00958061], [84.71430206, 19.00958443], [84.71430206, 19.00930405], [84.7140274, 19.00930977], [84.7140274, 19.00847054], [84.71375275, 19.00847054], [84.71375275, 19.00819206], [84.71347046, 19.00819206], [84.71347046, 19.0079174], [84.71318817, 19.00792122], [84.71318817, 19.00764275], [84.71289825, 19.00764275], [84.71289825, 19.00736046], [84.71263885, 19.00736046], [84.71263885, 19.00681114], [84.71235657, 19.00681114], [84.71235657, 19.00653267], [84.71208191, 19.00653267], [84.71208191, 19.00597191], [84.71180725, 19.00597191], [84.71180725, 19.00569534], [84.71151733, 19.00570107], [84.71151733, 19.00542068], [84.71098328, 19.00542068], [84.71098328, 19.00515175], [84.71069336, 19.00515175], [84.71069336, 19.00485992], [84.71013641, 19.00486183], [84.71013641, 19.00402832], [84.70986176, 19.00402832], [84.70986176, 19.00346947], [84.70930481, 19.00347137], [84.70930481, 19.00319481], [84.70903015, 19.00319481], [84.70903015, 19.00263977], [84.70874786, 19.00263977], [84.70874786, 19.00209045], [84.70847321, 19.00209045], [84.70847321, 19.00152969], [84.70819092, 19.00152969], [84.70819092, 19.00041962], [84.70791626, 19.00041962], [84.70791626, 19.00014114], [84.70791626, 18.99986076], [84.70791626, 18.99958038], [84.7076416, 18.9995842], [84.7076416, 18.99930573], [84.70735931, 18.99930954], [84.70735931, 18.99875069], [84.70708466, 18.99875069], [84.70708466, 18.99847221], [84.70680237, 18.99847221], [84.70680237, 18.99819565], [84.70652771, 18.99819565], [84.70652771, 18.9976387], [84.70625305, 18.99764061], [84.70625305, 18.99736023], [84.70597076, 18.99736023], [84.70597076, 18.99707985], [84.70569611, 18.99708557], [84.70569611, 18.99652863], [84.70540619, 18.99653053], [84.70540619, 18.99625015], [84.70513916, 18.99625015], [84.70513916, 18.99596024], [84.7048645, 18.99597359], [84.7048645, 18.99541664], [84.70458221, 18.99542046], [84.70458221, 18.99514008], [84.70430756, 18.99514008], [84.70430756, 18.9948597], [84.70402527, 18.99486351], [84.70402527, 18.99430466], [84.70375061, 18.99430466], [84.70375061, 18.99402809], [84.70347595, 18.99403191], [84.70347595, 18.99346924], [84.70319366, 18.99347115], [84.70319366, 18.99319458], [84.70291901, 18.99319458], [84.70291901, 18.99263954], [84.70263672, 18.99263954], [84.70263672, 18.99235916], [84.70236206, 18.99235916], [84.70236206, 18.99208069], [84.70207977, 18.9920826], [84.70207977, 18.99152756], [84.70181274, 18.99153137], [84.70181274, 18.99124908], [84.70153046, 18.99124908], [84.70153046, 18.99097061], [84.70124817, 18.99097252], [84.70124817, 18.99041748], [84.70095825, 18.99041748], [84.70095825, 18.99014854], [84.70069122, 18.99014854], [84.70069122, 18.98986053], [84.70041656, 18.98986053], [84.70041656, 18.98958015], [84.70014191, 18.98958397], [84.70014191, 18.98902893], [84.69985962, 18.98903084], [84.69985962, 18.98875046], [84.69957733, 18.98875046], [84.69957733, 18.98847008], [84.69930267, 18.98847198], [84.69930267, 18.98819542], [84.69902802, 18.9881897], [84.69902802, 18.98791885], [84.69875336, 18.98792076], [84.69875336, 18.98736], [84.69847107, 18.98736191], [84.69847107, 18.98708344], [84.69819641, 18.98708344], [84.69819641, 18.98680687], [84.69789886, 18.98681068], [84.69789886, 18.9865303], [84.69763947, 18.9865303], [84.69763947, 18.98596954], [84.69736481, 18.98597145], [84.69736481, 18.98569679], [84.69708252, 18.98569679], [84.69708252, 18.98541641], [84.69680786, 18.98542023], [84.69680786, 18.98513985], [84.6965332, 18.98513985], [84.6965332, 18.98458099], [84.69625092, 18.98458481], [84.69625092, 18.98430634], [84.69596863, 18.98431015], [84.69596863, 18.98402023], [84.69569397, 18.98402786], [84.69569397, 18.98374939], [84.69541931, 18.98374939], [84.69541931, 18.98319054], [84.69513702, 18.98319244], [84.69513702, 18.98291588], [84.69486237, 18.98291969], [84.69486237, 18.98264122], [84.69458008, 18.98264122], [84.69458008, 18.98208046], [84.69430542, 18.98208237], [84.69430542, 18.9818058], [84.69403076, 18.98180962], [84.69403076, 18.98153114], [84.69374847, 18.98153114], [84.69374847, 18.98125267], [84.69346619, 18.98125267], [84.69346619, 18.98069191], [84.69319153, 18.98069382], [84.69319153, 18.98041725], [84.69291687, 18.98042107], [84.69291687, 18.98014259], [84.69264221, 18.98014259], [84.69264221, 18.97986031], [84.69235992, 18.97986031], [84.69235992, 18.9793129], [84.6920929, 18.9793129], [84.6920929, 18.97903252], [84.69180298, 18.97903252], [84.69180298, 18.97874832], [84.69152832, 18.97874832], [84.69152832, 18.97821045], [84.69124603, 18.97821045], [84.69124603, 18.97792053], [84.69097137, 18.97792053], [84.69097137, 18.97763824], [84.69069672, 18.97763824], [84.69069672, 18.97707939], [84.69041443, 18.97708321], [84.69041443, 18.97680473], [84.69013977, 18.97680473], [84.69013977, 18.97624969], [84.68985748, 18.97624969], [84.68985748, 18.97597122], [84.68958282, 18.97597313], [84.68958282, 18.97541618], [84.68930817, 18.97541809], [84.68930817, 18.97513962], [84.68901825, 18.97513962], [84.68901825, 18.9748497], [84.68875122, 18.97486115], [84.68875122, 18.97430611], [84.68846893, 18.97430992], [84.68846893, 18.97375107], [84.68818665, 18.97375107], [84.68818665, 18.97319031], [84.68791962, 18.97319412], [84.68791962, 18.97291756], [84.68763733, 18.97291946], [84.68763733, 18.97236061], [84.68736267, 18.97236061], [84.68736267, 18.97264099], [84.68708038, 18.97264099], [84.68708038, 18.97236061], [84.68680573, 18.97236061], [84.68680573, 18.97180557], [84.68653107, 18.97180557], [84.68653107, 18.97208595], [84.68597412, 18.97208595], [84.68597412, 18.97180557], [84.68569183, 18.97180939], [84.68569183, 18.97153091], [84.68541718, 18.97153091], [84.68541718, 18.97097015], [84.68486023, 18.97097206], [84.68486023, 18.9706955], [84.68458557, 18.9706955], [84.68458557, 18.97041702], [84.68430328, 18.97042084], [84.68430328, 18.97014046], [84.68402863, 18.97014046], [84.68402863, 18.96986008], [84.68374634, 18.96986389], [84.68374634, 18.9695816], [84.68347168, 18.9695816], [84.68347168, 18.96930313], [84.68319702, 18.96930313], [84.68319702, 18.9695816], [84.67485809, 18.9695816], [84.67485809, 18.96986389], [84.67401886, 18.96986008], [84.67401886, 18.97014046], [84.67318726, 18.97014046], [84.67318726, 18.97042084], [84.67263794, 18.97041702], [84.67263794, 18.9706955], [84.67236328, 18.9706955], [84.67236328, 18.97041702], [84.67041779, 18.97042084], [84.67041779, 18.97014046], [84.66986084, 18.97014046], [84.66986084, 18.96986008], [84.66958618, 18.96986389], [84.66958618, 18.9695816], [84.66874695, 18.9695816], [84.66874695, 18.96930313], [84.66847229, 18.96931076], [84.66847229, 18.96903992], [84.66792297, 18.96903992], [84.66792297, 18.96875191], [84.66764069, 18.96875191], [84.66764069, 18.96820068], [84.6673584, 18.96820068], [84.6673584, 18.9679203], [84.66707611, 18.9679203], [84.66707611, 18.96764183], [84.66680908, 18.96764183], [84.66680908, 18.96735954], [84.66652679, 18.96736336], [84.66652679, 18.96708107], [84.66625214, 18.96708107], [84.66625214, 18.96680641], [84.66596985, 18.96681023], [84.66596985, 18.96653175], [84.6654129, 18.96653175], [84.6654129, 18.96624947], [84.66513824, 18.96624947], [84.66513824, 18.96598053], [84.66484833, 18.96598053], [84.66484833, 18.96569061], [84.6645813, 18.96569443], [84.6645813, 18.96430588], [84.66430664, 18.9643116], [84.66430664, 18.96375084], [84.66401672, 18.96375084], [84.66401672, 18.96181107], [84.66374969, 18.96181107], [84.66374969, 18.96153069], [84.66401672, 18.96153069], [84.66401672, 18.96125031], [84.6645813, 18.96125031], [84.6645813, 18.96153069], [84.66484833, 18.96153069], [84.66484833, 18.96181107], [84.66570282, 18.96181107], [84.66570282, 18.96125031], [84.66596985, 18.96125031], [84.66596985, 18.95792007], [84.66625214, 18.95792007], [84.66625214, 18.95763969], [84.66652679, 18.95763969], [84.66652679, 18.95736122], [84.6673584, 18.95736122], [84.6673584, 18.95708084], [84.66791534, 18.95708466], [84.66791534, 18.95736122], [84.66874695, 18.95736122], [84.66874695, 18.95763969], [84.66929626, 18.95763969], [84.66929626, 18.95792007], [84.66958618, 18.95791626], [84.66958618, 18.95819664], [84.66986084, 18.95819664], [84.66986084, 18.9584713], [84.6701355, 18.9584713], [84.6701355, 18.95874977], [84.67041779, 18.95874977], [84.67041779, 18.95903015], [84.67069244, 18.95902824], [84.67069244, 18.95930672], [84.67097473, 18.95930672], [84.67097473, 18.95958328], [84.67124939, 18.95958328], [84.67124939, 18.95986176], [84.67151642, 18.95985031], [84.67151642, 18.96014023], [84.67180634, 18.96014023], [84.67180634, 18.96042061], [84.67208099, 18.96042061], [84.67208099, 18.96070099], [84.67236328, 18.96069527], [84.67236328, 18.96097183], [84.67263794, 18.96096992], [84.67263794, 18.96125031], [84.67292023, 18.96125031], [84.67292023, 18.96181107], [84.67346954, 18.96180534], [84.67346954, 18.96208382], [84.67375183, 18.96208382], [84.67375183, 18.96319389], [84.67402649, 18.96319389], [84.67402649, 18.96347237], [84.67430878, 18.96347046], [84.67430878, 18.96375084], [84.67457581, 18.96375084], [84.67457581, 18.96402931], [84.67542267, 18.96402931], [84.67542267, 18.9643116], [84.67569733, 18.96430588], [84.67569733, 18.96458244], [84.67597198, 18.96458054], [84.67597198, 18.96542168], [84.67624664, 18.96541595], [84.67624664, 18.96569443], [84.67652893, 18.96569061], [84.67652893, 18.96598053], [84.67678833, 18.96598053], [84.67678833, 18.96624947], [84.67707825, 18.96624947], [84.67707825, 18.96653175], [84.67764282, 18.96653175], [84.67764282, 18.96681023], [84.67791748, 18.96680641], [84.67791748, 18.96708107], [84.67819214, 18.96708107], [84.67819214, 18.96736336], [84.67930603, 18.96735954], [84.67930603, 18.96764183], [84.67986298, 18.96764183], [84.67986298, 18.9679203], [84.68015289, 18.9679203], [84.68015289, 18.96820068], [84.67986298, 18.96819305], [84.67986298, 18.96847153], [84.68013763, 18.96847153], [84.68013763, 18.96875191], [84.68180847, 18.96875191], [84.68180847, 18.96846962], [84.68208313, 18.96847153], [84.68208313, 18.96819305], [84.68264008, 18.96820068], [84.68264008, 18.9679203], [84.68292236, 18.9679203], [84.68292236, 18.96764183], [84.68321228, 18.96764183], [84.68321228, 18.96681023], [84.68292236, 18.96681023], [84.68292236, 18.96653175], [84.68264008, 18.96653175], [84.68264008, 18.96624947], [84.68235779, 18.96624947], [84.68235779, 18.96598053], [84.68208313, 18.96598053], [84.68208313, 18.96569061], [84.68180847, 18.96569443], [84.68180847, 18.96541595], [84.68152618, 18.96542168], [84.68152618, 18.96513939], [84.68125153, 18.96513939], [84.68125153, 18.96486092], [84.68096924, 18.96486092], [84.68096924, 18.96458054], [84.68069458, 18.96458244], [84.68069458, 18.96430588], [84.68041992, 18.9643116], [84.68041992, 18.96402931], [84.68015289, 18.96402931], [84.68015289, 18.96375084], [84.67986298, 18.96375084], [84.67986298, 18.96347046], [84.67958069, 18.96347237], [84.67958069, 18.96319389], [84.67930603, 18.96319389], [84.67930603, 18.96291733], [84.67903137, 18.96291733], [84.67903137, 18.96263885], [84.67874908, 18.96264076], [84.67874908, 18.96208], [84.67847443, 18.96208382], [84.67847443, 18.96180534], [84.67819214, 18.96181107], [84.67819214, 18.96153069], [84.67791748, 18.96153069], [84.67791748, 18.96125031], [84.67763519, 18.96125031], [84.67763519, 18.96097183], [84.67736053, 18.96097183], [84.67736053, 18.96069527], [84.67707825, 18.96070099], [84.67707825, 18.96042061], [84.67678833, 18.96042061], [84.67678833, 18.96014023], [84.67652893, 18.96014023], [84.67652893, 18.95985031], [84.67624664, 18.95986176], [84.67624664, 18.95958328], [84.67597198, 18.95958328], [84.67597198, 18.95930672], [84.67569733, 18.95930672], [84.67569733, 18.95902824], [84.67514038, 18.95903015], [84.67514038, 18.95874977], [84.67457581, 18.95874977], [84.67457581, 18.95846939], [84.67430878, 18.9584713], [84.67430878, 18.95819664], [84.67402649, 18.95819664], [84.67402649, 18.95763969], [84.67375183, 18.95763969], [84.67375183, 18.95708084], [84.67346954, 18.95708466], [84.67346954, 18.95680618], [84.67318726, 18.95681], [84.67318726, 18.95625114], [84.67208099, 18.95625114], [84.67208099, 18.95597076], [84.67152405, 18.95597458], [84.67152405, 18.95569229], [84.67124939, 18.95569229], [84.67124939, 18.95541763], [84.67098236, 18.95541954], [84.67098236, 18.95486069], [84.67069244, 18.95486069], [84.67069244, 18.95430946], [84.67041779, 18.95430946], [84.67041779, 18.95375252], [84.6701355, 18.95375252], [84.6701355, 18.95319366], [84.66986084, 18.95319366], [84.66986084, 18.95263863], [84.66958618, 18.95264244], [84.66958618, 18.95207977], [84.66930389, 18.95208359], [84.66930389, 18.95152855], [84.66902924, 18.95152855], [84.66902924, 18.95124817], [84.66874695, 18.95124817], [84.66874695, 18.9509697], [84.66847229, 18.9509716], [84.66847229, 18.95069504], [84.66792297, 18.95070076], [84.66792297, 18.95041847], [84.66764069, 18.95041847], [84.66764069, 18.95013809], [84.6673584, 18.95013809], [84.6673584, 18.94985962], [84.66708374, 18.94986153], [84.66708374, 18.94958305], [84.66680908, 18.94958305], [84.66680908, 18.94930649], [84.66625214, 18.9493103], [84.66625214, 18.94902992], [84.66596985, 18.94902992], [84.66596985, 18.94874954], [84.66569519, 18.94874954], [84.66569519, 18.94847298], [84.6654129, 18.94847298], [84.6654129, 18.9481945], [84.66513824, 18.9481945], [84.66513824, 18.94791794], [84.6645813, 18.94791794], [84.6645813, 18.94763947], [84.66430664, 18.94763947], [84.66430664, 18.94736099], [84.66401672, 18.94736099], [84.66401672, 18.94708061], [84.66374969, 18.94708252], [84.66374969, 18.94680786], [84.66348267, 18.94680977], [84.66348267, 18.94652939], [84.66291809, 18.94652939], [84.66291809, 18.94625092], [84.6626358, 18.94625092], [84.6626358, 18.94597054], [84.66236115, 18.94597244], [84.66236115, 18.94569588], [84.66208649, 18.94569588], [84.66208649, 18.9454174], [84.66178894, 18.94542122], [84.66178894, 18.94514084], [84.66124725, 18.94514084], [84.66124725, 18.94485283], [84.6609726, 18.94486046], [84.6609726, 18.9445858], [84.66069794, 18.9445858], [84.66069794, 18.94430542], [84.66042328, 18.94431114], [84.66042328, 18.94403076], [84.66014099, 18.94403076], [84.66014099, 18.94375038], [84.6598587, 18.94375038], [84.6598587, 18.94347], [84.65958405, 18.94347382], [84.65958405, 18.94319534], [84.65930176, 18.94320107], [84.65930176, 18.94292068], [84.65875244, 18.94292068], [84.65875244, 18.9426403], [84.65847015, 18.9426403], [84.65847015, 18.94235992], [84.6581955, 18.94236374], [84.6581955, 18.94208145], [84.65791321, 18.94208145], [84.65791321, 18.94180489], [84.65763855, 18.94181061], [84.65763855, 18.94153023], [84.65735626, 18.94153023], [84.65735626, 18.94124985], [84.6570816, 18.94124985], [84.6570816, 18.94096947], [84.65680695, 18.94097137], [84.65680695, 18.94069481], [84.65652466, 18.94069481], [84.65652466, 18.94041634], [84.65598297, 18.94042015], [84.65598297, 18.94014168], [84.65569305, 18.94014168], [84.65569305, 18.93985939], [84.6554184, 18.93985939], [84.6554184, 18.93958282], [84.65513611, 18.93958282], [84.65513611, 18.93930626], [84.65486145, 18.93931007], [84.65486145, 18.9390316], [84.65458679, 18.9390316], [84.65458679, 18.93874931], [84.65429688, 18.93874931], [84.65429688, 18.93847084], [84.65402985, 18.93847275], [84.65402985, 18.93819427], [84.65374756, 18.93819427], [84.65374756, 18.9379158], [84.6534729, 18.93792152], [84.6534729, 18.93763924], [84.65290833, 18.93763924], [84.65290833, 18.93736076], [84.6526413, 18.93736076], [84.6526413, 18.93708038], [84.65235901, 18.9370842], [84.65235901, 18.93680573], [84.65207672, 18.93680763], [84.65207672, 18.93652916], [84.65180206, 18.93652916], [84.65180206, 18.93625069], [84.6515274, 18.93625069], [84.6515274, 18.93597031], [84.65125275, 18.93597221], [84.65125275, 18.93569374], [84.65097046, 18.93569374], [84.65097046, 18.93541718], [84.6506958, 18.93541908], [84.6506958, 18.93514061], [84.65040588, 18.93514061], [84.65040588, 18.93486023], [84.65013885, 18.93486023], [84.65013885, 18.93457985], [84.64958191, 18.93458366], [84.64958191, 18.93430519], [84.64930725, 18.93431091], [84.64930725, 18.93403053], [84.64901733, 18.93403053], [84.64901733, 18.93375015], [84.64875031, 18.93375015], [84.64875031, 18.93346977], [84.64847565, 18.93347168], [84.64847565, 18.93319511], [84.64819336, 18.93320084], [84.64819336, 18.93291092], [84.6479187, 18.93291664], [84.6479187, 18.93263817], [84.64763641, 18.93264008], [84.64763641, 18.9323597], [84.64736176, 18.9323616], [84.64736176, 18.93208313], [84.6470871, 18.93208313], [84.6470871, 18.93180656], [84.64680481, 18.93180656], [84.64680481, 18.93152809], [84.64653015, 18.93153], [84.64653015, 18.93124962], [84.64597321, 18.93124962], [84.64597321, 18.93097115], [84.64569092, 18.93097305], [84.64569092, 18.93069458], [84.64541626, 18.93069458], [84.64541626, 18.9304142], [84.6451416, 18.93041992], [84.6451416, 18.93013954], [84.64485931, 18.93013954], [84.64485931, 18.92987061], [84.64457703, 18.92987061], [84.64457703, 18.92958069], [84.64430237, 18.9295845], [84.64430237, 18.92930603], [84.64404297, 18.92930984], [84.64404297, 18.92902946], [84.64375305, 18.92902946], [84.64375305, 18.9287529], [84.64347076, 18.9287529], [84.64347076, 18.92847061], [84.64319611, 18.92847061], [84.64319611, 18.92819214], [84.64291382, 18.92819214], [84.64291382, 18.92791748], [84.64263916, 18.92791939], [84.64263916, 18.92764282], [84.64208221, 18.92764282], [84.64208221, 18.92736053], [84.64180756, 18.92736053], [84.64180756, 18.92708015], [84.64152527, 18.92708206], [84.64152527, 18.9268055], [84.64125061, 18.92681122], [84.64125061, 18.92653275], [84.64096832, 18.92653275], [84.64096832, 18.92625237], [84.64068604, 18.92625237], [84.64068604, 18.92597008], [84.64041901, 18.92597008], [84.64041901, 18.92569542], [84.64013672, 18.9256897], [84.64013672, 18.92541695], [84.63986206, 18.92542267], [84.63986206, 18.92525101], [84.63986206, 18.92513847], [84.63957977, 18.92513847], [84.63957977, 18.92485809], [84.63874817, 18.92486191], [84.63874817, 18.92458344], [84.63847351, 18.92458344], [84.63847351, 18.92430496], [84.63819122, 18.92431068], [84.63819122, 18.9240284], [84.63790894, 18.9240284], [84.63790894, 18.92346954], [84.63764191, 18.92347145], [84.63764191, 18.92319489], [84.63735962, 18.92319489], [84.63735962, 18.92291641], [84.63707733, 18.92291832], [84.63707733, 18.92263985], [84.63680267, 18.92263985], [84.63680267, 18.92235947], [84.63652802, 18.92236137], [84.63652802, 18.9220829], [84.63625336, 18.9220829], [84.63625336, 18.92180634], [84.63597107, 18.92180824], [84.63597107, 18.92152977], [84.63569641, 18.92152977], [84.63569641, 18.92124939], [84.63540649, 18.92124939], [84.63540649, 18.92097092], [84.63513947, 18.92097282], [84.63513947, 18.92069435], [84.63458252, 18.92069435], [84.63458252, 18.92041779], [84.63430786, 18.92041969], [84.63430786, 18.92014122], [84.6340332, 18.92014122], [84.6340332, 18.91986084], [84.63375092, 18.91986084], [84.63375092, 18.91958046], [84.63346863, 18.91958046], [84.63346863, 18.91986084], [84.63318634, 18.91986084], [84.63318634, 18.91958046], [84.63291931, 18.91958427], [84.63291931, 18.91875076], [84.63263702, 18.91875076], [84.63263702, 18.91819], [84.63236237, 18.91819572], [84.63236237, 18.91791725], [84.63208008, 18.9179306], [84.63208008, 18.91764069], [84.63181305, 18.91764069], [84.63181305, 18.91707993], [84.63153076, 18.91708565], [84.63153076, 18.91680336], [84.63124847, 18.91681099], [84.63124847, 18.91653061], [84.63096619, 18.91653061], [84.63096619, 18.91625023], [84.63014221, 18.91625023], [84.63014221, 18.91596985], [84.62958527, 18.91597366], [84.62958527, 18.91569519], [84.62902832, 18.91570091], [84.62902832, 18.91542053], [84.62874603, 18.91542053], [84.62874603, 18.91514015], [84.62819672, 18.91514015], [84.62819672, 18.91487122], [84.6279068, 18.91487122], [84.6279068, 18.91457939], [84.62763977, 18.9145813], [84.62763977, 18.91430473], [84.62735748, 18.91430473], [84.62735748, 18.91402817], [84.62708282, 18.91403008], [84.62708282, 18.91374969], [84.62680817, 18.91374969], [84.62680817, 18.91346931], [84.62652588, 18.91347122], [84.62652588, 18.91291618], [84.62625122, 18.91292191], [84.62625122, 18.91264153], [84.62596893, 18.91264153], [84.62596893, 18.91208076], [84.62569427, 18.91208267], [84.62569427, 18.91180611], [84.62541962, 18.91180611], [84.62541962, 18.91152763], [84.62513733, 18.91153145], [84.62513733, 18.91124916], [84.62486267, 18.91124916], [84.62486267, 18.91097069], [84.62458038, 18.9109726], [84.62458038, 18.91069412], [84.62374878, 18.91069412], [84.62374878, 18.91041756], [84.62346649, 18.91041756], [84.62346649, 18.91013908], [84.62319183, 18.91013908], [84.62319183, 18.90958023], [84.62291718, 18.90958405], [84.62291718, 18.90930557], [84.62264252, 18.90930748], [84.62264252, 18.90903091], [84.62236023, 18.90903091], [84.62236023, 18.908741], [84.62180328, 18.90875053], [84.62180328, 18.90847206], [84.62152863, 18.90847206], [84.62152863, 18.90819359], [84.62124634, 18.90819359], [84.62124634, 18.90791893], [84.62097168, 18.90792084], [84.62097168, 18.90736008], [84.62069702, 18.90736198], [84.62069702, 18.90708351], [84.62041473, 18.90708351], [84.62041473, 18.90680695], [84.62014008, 18.90681076], [84.62014008, 18.90653038], [84.61987305, 18.90653038], [84.61987305, 18.90625], [84.61958313, 18.90625], [84.61958313, 18.90596962], [84.61930847, 18.90597153], [84.61930847, 18.90569687], [84.61902618, 18.90570068], [84.61902618, 18.9054203], [84.61875153, 18.9054203], [84.61875153, 18.90513992], [84.61846924, 18.90513992], [84.61846924, 18.90485954], [84.61819458, 18.90486145], [84.61819458, 18.90458488], [84.61791992, 18.90458488], [84.61791992, 18.90430641], [84.61763763, 18.90431023], [84.61763763, 18.90402985], [84.61708069, 18.90402985], [84.61708069, 18.90374947], [84.61653137, 18.90374947], [84.61653137, 18.9034729], [84.61624908, 18.90347481], [84.61624908, 18.90319252], [84.61569214, 18.90319252], [84.61569214, 18.90291405], [84.61541748, 18.90293121], [84.61541748, 18.90263939], [84.61513519, 18.90263939], [84.61513519, 18.90236282], [84.61458588, 18.90236282], [84.61458588, 18.90208054], [84.61430359, 18.90208435], [84.61430359, 18.90180588], [84.61402893, 18.90180969], [84.61402893, 18.90153122], [84.61373901, 18.90153122], [84.61373901, 18.90125275], [84.61347198, 18.90125275], [84.61347198, 18.90097046], [84.61319733, 18.90097046], [84.61319733, 18.90069389], [84.61291504, 18.90069389], [84.61291504, 18.90041733], [84.61264038, 18.90042114], [84.61264038, 18.90014267], [84.61235809, 18.90014267], [84.61235809, 18.89986038], [84.61180878, 18.89986038], [84.61180878, 18.89957047], [84.61152649, 18.89958382], [84.61152649, 18.89930534], [84.61180878, 18.89931107], [84.61180878, 18.8987484], [84.61152649, 18.8987484], [84.61152649, 18.89846992], [84.61125183, 18.89847183], [84.61125183, 18.89819527], [84.61067963, 18.89819908], [84.61067963, 18.89792061], [84.61042023, 18.89792061], [84.61042023, 18.89763832], [84.61013794, 18.89763832], [84.61013794, 18.89707947], [84.60986328, 18.89708328], [84.60986328, 18.89680481], [84.60930634, 18.89680481], [84.60930634, 18.89652824], [84.60901642, 18.89652824], [84.60901642, 18.89624977], [84.60874939, 18.89624977], [84.60874939, 18.89569092], [84.60847473, 18.89569473], [84.60847473, 18.89541626], [84.60819244, 18.89541817], [84.60819244, 18.89513969], [84.60791779, 18.89513969], [84.60791779, 18.89486122], [84.6076355, 18.89486122], [84.6076355, 18.89458275], [84.60736084, 18.89458275], [84.60736084, 18.89402771], [84.60708618, 18.89402962], [84.60708618, 18.89430809], [84.60679626, 18.89430809], [84.60679626, 18.89402962], [84.60652924, 18.89402962], [84.60652924, 18.89291954], [84.60624695, 18.89291954], [84.60624695, 18.89208031], [84.60597229, 18.89208412], [84.60597229, 18.89180565], [84.60542297, 18.89180946], [84.60542297, 18.89153099], [84.60514069, 18.89153099], [84.60514069, 18.89125061], [84.6048584, 18.89125061], [84.6048584, 18.89069557], [84.60457611, 18.89069939], [84.60457611, 18.89014053], [84.60430908, 18.89014053], [84.60430908, 18.88986015], [84.60402679, 18.88986206], [84.60402679, 18.88958168], [84.60375214, 18.88958168], [84.60375214, 18.88930321], [84.60346985, 18.88931084], [84.60346985, 18.88903046], [84.6029129, 18.88903046], [84.6029129, 18.88875008], [84.60263824, 18.88875008], [84.60263824, 18.8884697], [84.60236359, 18.88847351], [84.60236359, 18.88819313], [84.6020813, 18.88820076], [84.6020813, 18.88792038], [84.60179901, 18.88792038], [84.60179901, 18.88735962], [84.6020813, 18.88736343], [84.6020813, 18.88680649], [84.60180664, 18.88680649], [84.60180664, 18.88708115], [84.60152435, 18.88708115], [84.60152435, 18.88680649], [84.60124969, 18.8868103], [84.60124969, 18.88653183], [84.60098267, 18.88653183], [84.60098267, 18.88596916], [84.60069275, 18.88597107], [84.60069275, 18.8856945], [84.60041809, 18.8856945], [84.60041809, 18.88513947], [84.6001358, 18.88513947], [84.6001358, 18.88485909], [84.59986115, 18.88485909], [84.59986115, 18.88457108], [84.59958649, 18.88458252], [84.59958649, 18.88430595], [84.59929657, 18.88431168], [84.59929657, 18.8840313], [84.59902954, 18.8840313], [84.59902954, 18.88319016], [84.59874725, 18.88319397], [84.59874725, 18.88263893], [84.5984726, 18.88264084], [84.5984726, 18.88208008], [84.59819794, 18.88208389], [84.59819794, 18.88180542], [84.59764099, 18.88182068], [84.59764099, 18.88153076], [84.5973587, 18.88153076], [84.5973587, 18.88125038], [84.59707642, 18.88125038], [84.59707642, 18.88097], [84.5965271, 18.88097191], [84.5965271, 18.88069534], [84.59625244, 18.88070107], [84.59625244, 18.88042068], [84.59597015, 18.88042068], [84.59597015, 18.87985992], [84.5956955, 18.87986183], [84.5956955, 18.87958336], [84.59541321, 18.87958336], [84.59541321, 18.87930679], [84.59513855, 18.87930679], [84.59513855, 18.87902832], [84.59485626, 18.87903023], [84.59485626, 18.87875938], [84.5945816, 18.87875938], [84.5945816, 18.87846947], [84.59430695, 18.87847137], [84.59430695, 18.87819672], [84.59402466, 18.87819672], [84.59402466, 18.87763977], [84.59375, 18.87763977], [84.59375, 18.87735939], [84.59347534, 18.8773613], [84.59347534, 18.87708473], [84.59319305, 18.87708473], [84.59319305, 18.87652779], [84.59292603, 18.87652969], [84.59292603, 18.87625122], [84.59263611, 18.87625122], [84.59263611, 18.87597084], [84.59236145, 18.87597466], [84.59236145, 18.87569237], [84.59208679, 18.87569237], [84.59208679, 18.8754158], [84.59179688, 18.87541962], [84.59179688, 18.87514114], [84.59152985, 18.87514114], [84.59152985, 18.87486267], [84.59124756, 18.87486267], [84.59124756, 18.87458038], [84.59069824, 18.87458229], [84.59069061, 18.87430573], [84.59041595, 18.87430954], [84.59041595, 18.87375259], [84.5901413, 18.87375259], [84.5901413, 18.87347031], [84.58985901, 18.87347031], [84.58985901, 18.87319374], [84.58958435, 18.87319374], [84.58958435, 18.87291718], [84.5890274, 18.8729229], [84.5890274, 18.87262917], [84.58847046, 18.87262917], [84.58847046, 18.8729229], [84.58680725, 18.87291718], [84.58680725, 18.87319374], [84.58625031, 18.87319374], [84.58625031, 18.87347031], [84.58569336, 18.87347031], [84.58569336, 18.87375259], [84.5854187, 18.87375259], [84.5854187, 18.87403107], [84.58513641, 18.87403107], [84.58513641, 18.87430954], [84.5845871, 18.87430954], [84.5845871, 18.87486267], [84.58429718, 18.87486267], [84.58429718, 18.87514114], [84.58403015, 18.87514114], [84.58403015, 18.87541962], [84.58374786, 18.8754158], [84.58374786, 18.87569237], [84.58347321, 18.87569046], [84.58347321, 18.87625122], [84.58319092, 18.87625122], [84.58319092, 18.87652969], [84.58291626, 18.87652969], [84.58291626, 18.87625122], [84.5826416, 18.87625122], [84.5826416, 18.87569046], [84.58291626, 18.87569237], [84.58291626, 18.87513924], [84.58319092, 18.87514114], [84.58319092, 18.87486267], [84.58347321, 18.87486267], [84.58347321, 18.87458038], [84.58374786, 18.87458229], [84.58374786, 18.87430573], [84.58403015, 18.87430954], [84.58403015, 18.87403107], [84.58429718, 18.87403107], [84.58429718, 18.87375259], [84.5845871, 18.87375259], [84.5845871, 18.87319183], [84.58486176, 18.87319374], [84.58486176, 18.87291718], [84.5854187, 18.8729229], [84.5854187, 18.87262917], [84.58597565, 18.8726387], [84.58597565, 18.87236023], [84.58625031, 18.87236023], [84.58625031, 18.87207985], [84.58652496, 18.87208366], [84.58652496, 18.87041664], [84.58625031, 18.87042046], [84.58625031, 18.8698597], [84.58597565, 18.8698616], [84.58597565, 18.86819458], [84.58569336, 18.86819458], [84.58569336, 18.86791611], [84.5854187, 18.86791992], [84.5854187, 18.86736107], [84.58513641, 18.86736107], [84.58513641, 18.86681747], [84.58486176, 18.86681747], [84.58486176, 18.86569023], [84.5845871, 18.86569595], [84.5845871, 18.86513901], [84.58429718, 18.86514091], [84.58429718, 18.86458015], [84.58403015, 18.86458588], [84.58403015, 18.8643055], [84.58376312, 18.86431122], [84.58376312, 18.86403084], [84.5826416, 18.86403084], [84.5826416, 18.86375046], [84.58207703, 18.86375046], [84.58207703, 18.86347008], [84.58180237, 18.86347389], [84.58180237, 18.8631916], [84.58208466, 18.8631916], [84.58208466, 18.86291695], [84.58180237, 18.86292076], [84.58180237, 18.86264038], [84.58152771, 18.86264038], [84.58152771, 18.8624897], [84.58152771, 18.86236382], [84.58125305, 18.86236382], [84.58125305, 18.85985947], [84.58097076, 18.85985947], [84.58097076, 18.85819435], [84.58069611, 18.85819435], [84.58069611, 18.85763931], [84.58040619, 18.85765266], [84.58040619, 18.85736084], [84.58013916, 18.85736084], [84.58013916, 18.85708046], [84.5798645, 18.85708427], [84.5798645, 18.85652733], [84.57958221, 18.85652924], [84.57958221, 18.85625076], [84.57930756, 18.85625076], [84.57930756, 18.85514069], [84.5790329, 18.85514069], [84.5790329, 18.85431099], [84.57875061, 18.85431099], [84.57875061, 18.85346985], [84.57847595, 18.85347176], [84.57847595, 18.85263824], [84.57818604, 18.85264015], [84.57818604, 18.85207939], [84.57791901, 18.85208321], [84.57791901, 18.85180664], [84.57763672, 18.85180664], [84.57763672, 18.85124969], [84.57736206, 18.85124969], [84.57736206, 18.85097122], [84.57707977, 18.85097313], [84.57707977, 18.85041618], [84.57681274, 18.85042], [84.57681274, 18.84986115], [84.57653046, 18.84986115], [84.57653046, 18.84930992], [84.57624817, 18.84930992], [84.57624817, 18.84875107], [84.57596588, 18.84875107], [84.57596588, 18.84736252], [84.57569122, 18.84736252], [84.57569122, 18.8429184], [84.57596588, 18.8429184], [84.57596588, 18.84235954], [84.57569122, 18.84236145], [84.57569122, 18.84013939], [84.57596588, 18.84013939], [84.57596588, 18.83930969], [84.57624817, 18.83930969], [84.57624817, 18.83903122], [84.57653046, 18.83903122], [84.57653046, 18.83875084], [84.57681274, 18.83875084], [84.57680511, 18.8381958], [84.57653046, 18.8381958], [84.57653046, 18.83708572], [84.57624817, 18.83708572], [84.57624817, 18.83680534], [84.57569122, 18.83681107], [84.57569122, 18.83652115], [84.57514191, 18.83652687], [84.57514191, 18.83625031], [84.57485962, 18.83625031], [84.57485962, 18.83596992], [84.57458496, 18.83597374], [84.57458496, 18.83569527], [84.57402802, 18.83570099], [84.57402802, 18.83542061], [84.57375336, 18.83542061], [84.57375336, 18.83514023], [84.57347107, 18.83514023], [84.57347107, 18.83485985], [84.57277679, 18.83486366], [84.57263947, 18.83486366], [84.57263947, 18.83458138], [84.57208252, 18.83458138], [84.57208252, 18.83430481], [84.57180786, 18.83430481], [84.57180786, 18.83402824], [84.5715332, 18.83403015], [84.5715332, 18.83375168], [84.57125092, 18.83375168], [84.57125092, 18.83319092], [84.57096863, 18.83319473], [84.57096863, 18.83291626], [84.57041931, 18.83292007], [84.57041931, 18.8326416], [84.57013702, 18.8326416], [84.57013702, 18.83235931], [84.56986237, 18.83235931], [84.56986237, 18.83208084], [84.56958008, 18.83208275], [84.56958008, 18.83180618], [84.56931305, 18.8318119], [84.56931305, 18.83153152], [84.56903076, 18.83153152], [84.56903076, 18.83124924], [84.5687561, 18.83124924], [84.5687561, 18.83097076], [84.56847382, 18.83097267], [84.56847382, 18.8306942], [84.568367, 18.8306942], [84.56819153, 18.8306942], [84.56819153, 18.83055115], [84.56819153, 18.83041763], [84.56799316, 18.83041573], [84.56791687, 18.83041573], [84.56791687, 18.83013916], [84.56759644, 18.83013916], [84.56735992, 18.83013916], [84.56735992, 18.82998085], [84.56735992, 18.82986069], [84.56720734, 18.82986069], [84.56680298, 18.82986069], [84.56680298, 18.82958031], [84.56652832, 18.82958412], [84.56652832, 18.8293705], [84.56652832, 18.82902718], [84.56624603, 18.82902908], [84.56624603, 18.82875061], [84.56568909, 18.82875061], [84.56568909, 18.82847023], [84.56541443, 18.82847214], [84.56541443, 18.82819366], [84.56511688, 18.82819366], [84.56485748, 18.82819366], [84.56485748, 18.8279171], [84.56458282, 18.82792091], [84.56456757, 18.82766151], [84.56430817, 18.82764053], [84.56430817, 18.82740021], [84.56430817, 18.82708359], [84.56402588, 18.82708359], [84.56402588, 18.82652855], [84.56387329, 18.82653046], [84.56375122, 18.82653046], [84.56375122, 18.82625008], [84.56346893, 18.82625008], [84.56346893, 18.8259697], [84.56319427, 18.8259716], [84.56319427, 18.82569695], [84.56291962, 18.82570076], [84.56291962, 18.82514], [84.56318665, 18.82514], [84.56318665, 18.82485962], [84.56291962, 18.82486153], [84.56291962, 18.82458305], [84.56263733, 18.82458305], [84.56263733, 18.82430649], [84.56236267, 18.8243103], [84.56236267, 18.82402992], [84.56208038, 18.82402992], [84.56208038, 18.82374954], [84.56180573, 18.82374954], [84.56180573, 18.8231945], [84.56153107, 18.8231945], [84.56153107, 18.82291412], [84.56124878, 18.82291985], [84.56124878, 18.82263947], [84.56096649, 18.82263947], [84.56096649, 18.8223629], [84.56069183, 18.8223629], [84.56069183, 18.82208061], [84.56041718, 18.82208443], [84.56041718, 18.82180595], [84.56014252, 18.82180977], [84.56014252, 18.82125282], [84.55986023, 18.82125282], [84.55986023, 18.82097054], [84.55958557, 18.82097054], [84.55958557, 18.82069206], [84.55930328, 18.82069206], [84.55930328, 18.8204174], [84.55902863, 18.82042122], [84.55902863, 18.81986046], [84.55874634, 18.81986046], [84.55874634, 18.81931114], [84.55847168, 18.81931114], [84.55847168, 18.81875229], [84.55819702, 18.81875229], [84.55819702, 18.81847954], [84.5579071, 18.81847954], [84.5579071, 18.81792068], [84.55764008, 18.81792068], [84.55764008, 18.8176384], [84.55735779, 18.8176384], [84.55735779, 18.81735992], [84.55708313, 18.81736183], [84.55708313, 18.81597137], [84.55680847, 18.81597137], [84.55680847, 18.81513977], [84.55652618, 18.81513977], [84.55652618, 18.81264114], [84.55625153, 18.81264114], [84.55625153, 18.81068993], [84.55596924, 18.81069565], [84.55596924, 18.80958366], [84.55569458, 18.80958366], [84.55569458, 18.80930328], [84.55541992, 18.80931091], [84.55541992, 18.80846977], [84.55569458, 18.80847359], [84.55569458, 18.80736351], [84.55541992, 18.80736351], [84.55541992, 18.80680466], [84.55513763, 18.80680466], [84.55513763, 18.80541611], [84.55486298, 18.80542183], [84.55486298, 18.80514145], [84.55458069, 18.80514145], [84.55458069, 18.80458069], [84.55430603, 18.8045826], [84.55430603, 18.80402756], [84.55403137, 18.80403137], [84.55403137, 18.80291748], [84.55374908, 18.80291748], [84.55374908, 18.80236053], [84.55403137, 18.80236053], [84.55403137, 18.80010033], [84.55403137, 18.79847145], [84.55430603, 18.79847145], [84.55430603, 18.79791641], [84.55458069, 18.79792023], [84.55458069, 18.79597282], [84.55403137, 18.79597473], [84.55403137, 18.79569244], [84.55374908, 18.79569244], [84.55374908, 18.79541588], [84.5534668, 18.79541969], [84.5534668, 18.79514122], [84.55319214, 18.79514122], [84.55319214, 18.79486275], [84.55291748, 18.79486275], [84.55291748, 18.79458046], [84.55319214, 18.79458046], [84.55319214, 18.7943058], [84.5534668, 18.79430962], [84.5534668, 18.79403114], [84.55374908, 18.79403114], [84.55374908, 18.79292107], [84.55403137, 18.79292107], [84.55403137, 18.79264259], [84.55374908, 18.79264259], [84.55374908, 18.79236031], [84.5534668, 18.79236031], [84.5534668, 18.79180908], [84.55319214, 18.79180908], [84.55319214, 18.79154015], [84.55291748, 18.79154015], [84.55291748, 18.79236031], [84.55264282, 18.79236031], [84.55264282, 18.79264259], [84.55236053, 18.79264259], [84.55236053, 18.79292107], [84.55152893, 18.79292107], [84.55152893, 18.79264259], [84.55124664, 18.79264259], [84.55124664, 18.79124832], [84.5506897, 18.79124832], [84.5506897, 18.79096985], [84.55014038, 18.79097176], [84.55014038, 18.79069519], [84.54930878, 18.79070091], [84.54930878, 18.79124832], [84.54917908, 18.79124832], [84.54902649, 18.79124832], [84.54902649, 18.79096985], [84.54846954, 18.79097176], [84.54846954, 18.79069519], [84.54818726, 18.79070091], [84.54818726, 18.79013824], [84.54905701, 18.79013824], [84.54930878, 18.79013824], [84.54930878, 18.78985977], [84.54902649, 18.78986168], [84.54902649, 18.78972816], [84.54902649, 18.78930473], [84.54875183, 18.78930473], [84.54875183, 18.78874969], [84.54846954, 18.78874969], [84.54846954, 18.78847122], [84.54819489, 18.78847313], [84.54819489, 18.78819466], [84.54792023, 18.78819466], [84.54792023, 18.78791618], [84.5476532, 18.78791809], [84.5476532, 18.78763962], [84.54651642, 18.78763962], [84.54651642, 18.78680992], [84.54624939, 18.78680992], [84.54624939, 18.78625107], [84.5459671, 18.78625107], [84.5459671, 18.78569031], [84.54569244, 18.78569412], [84.54569244, 18.78541756], [84.5451355, 18.78541756], [84.5451355, 18.78513908], [84.54458618, 18.78514099], [84.54458618, 18.78486061], [84.54429626, 18.78486061], [84.54429626, 18.78458023], [84.54402924, 18.78458595], [84.54402924, 18.78430557], [84.54374695, 18.78430939], [84.54374695, 18.78403091], [84.54319763, 18.78403091], [84.54319763, 18.78375053], [84.54291534, 18.78375053], [84.54291534, 18.78347206], [84.54264069, 18.78347206], [84.54264069, 18.7831955], [84.5423584, 18.7831955], [84.5423584, 18.78263855], [84.54207611, 18.78264046], [84.54207611, 18.78236961], [84.54151917, 18.78236961], [84.54151917, 18.78181076], [84.54125214, 18.78181076], [84.54125214, 18.78153038], [84.54096985, 18.78153038], [84.54096985, 18.78125191], [84.54013824, 18.78125191], [84.54013824, 18.78096962], [84.53986359, 18.78097343], [84.53986359, 18.78041649], [84.5395813, 18.7804203], [84.5395813, 18.78014183], [84.53901672, 18.78014183], [84.53901672, 18.77957916], [84.53874969, 18.77958107], [84.53874969, 18.77930641], [84.53848267, 18.77931023], [84.53848267, 18.77903175], [84.53791809, 18.77903175], [84.53791809, 18.77874947], [84.53708649, 18.77874947], [84.53708649, 18.77792168], [84.53679657, 18.77792168], [84.53679657, 18.77736092], [84.53652954, 18.77736092], [84.53652954, 18.77653122], [84.5359726, 18.77653122], [84.5359726, 18.7762394], [84.53569794, 18.77625084], [84.53569794, 18.77597237], [84.53541565, 18.77597237], [84.53541565, 18.77569389], [84.53514099, 18.77569389], [84.53514099, 18.77541733], [84.53457642, 18.77542114], [84.53457642, 18.77514076], [84.53430176, 18.77514076], [84.53430176, 18.77486038], [84.5340271, 18.77486038], [84.5340271, 18.77458], [84.53375244, 18.77458382], [84.53375244, 18.77430534], [84.53320313, 18.77431107], [84.53320313, 18.77375031], [84.53263855, 18.77375031], [84.53263855, 18.77347183], [84.53236389, 18.77347183], [84.53236389, 18.77319527], [84.5320816, 18.77320099], [84.5320816, 18.77292061], [84.53180695, 18.77292061], [84.53180695, 18.77235985], [84.53152466, 18.77236176], [84.53152466, 18.77208328], [84.53069305, 18.77208328], [84.53069305, 18.77180672], [84.53013611, 18.77180672], [84.53013611, 18.77152824], [84.52957916, 18.77153015], [84.52957916, 18.77069092], [84.5293045, 18.77069473], [84.5293045, 18.77041626], [84.52902985, 18.77042961], [84.52902985, 18.77013969], [84.52819824, 18.77013969], [84.52819061, 18.76986122], [84.5276413, 18.76986122], [84.5276413, 18.76958084], [84.52735901, 18.76958466], [84.52735901, 18.76930618], [84.52651978, 18.76931], [84.52651978, 18.76902962], [84.52625275, 18.76902962], [84.52625275, 18.76737022], [84.52401733, 18.76737022], [84.52401733, 18.76708031], [84.52375031, 18.76708412], [84.52375031, 18.76680565], [84.52348328, 18.76680946], [84.52348328, 18.7665329], [84.52319336, 18.7665329], [84.52319336, 18.76625252], [84.52263641, 18.76625252], [84.52263641, 18.76597023], [84.5220871, 18.76597023], [84.5220871, 18.76569366], [84.52153015, 18.76569366], [84.52153015, 18.7654171], [84.52124786, 18.76542282], [84.52124786, 18.76485825], [84.52097321, 18.76486015], [84.52097321, 18.76458359], [84.52041626, 18.76458359], [84.52041626, 18.76430511], [84.51985931, 18.76430511], [84.51985931, 18.76402855], [84.51957703, 18.76402855], [84.51957703, 18.7634697], [84.51875305, 18.7634716], [84.51875305, 18.76319504], [84.51847076, 18.76320076], [84.51847076, 18.76263809], [84.51819611, 18.76263809], [84.51819611, 18.76235962], [84.51763916, 18.76236153], [84.51763916, 18.76208305], [84.51708221, 18.76208305], [84.51708221, 18.76180649], [84.5165329, 18.7618103], [84.5165329, 18.76152992], [84.51625061, 18.76152992], [84.51625061, 18.76124001], [84.51597595, 18.76124954], [84.51597595, 18.76097298], [84.51569366, 18.76097298], [84.51569366, 18.7606945], [84.51541901, 18.7606945], [84.51541901, 18.76041794], [84.51486206, 18.76041985], [84.51486206, 18.76013947], [84.51457977, 18.76013947], [84.51457977, 18.75986099], [84.51374817, 18.75986099], [84.51374817, 18.75958061], [84.51347351, 18.75958252], [84.51347351, 18.75930405], [84.51291656, 18.75930977], [84.51291656, 18.75875092], [84.51235962, 18.75875092], [84.51235962, 18.75847054], [84.51180267, 18.75847244], [84.51180267, 18.75819588], [84.51125336, 18.75819588], [84.51125336, 18.7579174], [84.51097107, 18.75792122], [84.51097107, 18.75764084], [84.51040649, 18.75764084], [84.51040649, 18.75736046], [84.51013947, 18.75736046], [84.51013947, 18.75708008], [84.50986481, 18.7570858], [84.50986481, 18.75680542], [84.50958252, 18.75681114], [84.50958252, 18.75653076], [84.50930786, 18.75653076], [84.50930786, 18.75625038], [84.50875092, 18.75625038], [84.50875092, 18.75570107], [84.50847626, 18.75570107], [84.50847626, 18.75543022], [84.50818634, 18.75543022], [84.50818634, 18.7551403], [84.50791931, 18.7551403], [84.50791931, 18.75486183], [84.50736237, 18.75486374], [84.50736237, 18.75458145], [84.50708008, 18.75458145], [84.50708008, 18.75430489], [84.50680542, 18.75430489], [84.50680542, 18.75402832], [84.50653076, 18.75403023], [84.50653076, 18.75375175], [84.50596619, 18.75375175], [84.50596619, 18.75346947], [84.50541687, 18.75347328], [84.50541687, 18.75319481], [84.50514221, 18.75319481], [84.50514221, 18.75291634], [84.50485992, 18.75292015], [84.50485992, 18.75264168], [84.50458527, 18.75264168], [84.50458527, 18.75235939], [84.50430298, 18.75235939], [84.50430298, 18.75208282], [84.50402832, 18.75208282], [84.50402832, 18.75152779], [84.50347137, 18.7515316], [84.50347137, 18.75124931], [84.50319672, 18.75124931], [84.50319672, 18.75097084], [84.50208282, 18.75097275], [84.50208282, 18.7504158], [84.50180817, 18.75042152], [84.50180817, 18.75013924], [84.50152588, 18.75013924], [84.50152588, 18.74986076], [84.50125122, 18.74986076], [84.50125122, 18.74958038], [84.50096893, 18.7495842], [84.50096893, 18.74930573], [84.50069427, 18.74930573], [84.50069427, 18.74902725], [84.50041962, 18.74902916], [84.50041962, 18.74818993], [84.50013733, 18.74819374], [84.50013733, 18.74791718], [84.49931335, 18.74792099], [84.49931335, 18.74736023], [84.49874878, 18.74736023], [84.49874878, 18.74707985], [84.49847412, 18.74708366], [84.49847412, 18.74680519], [84.49819183, 18.74681091], [84.49819183, 18.74653053], [84.49791718, 18.74653053], [84.49791718, 18.74625969], [84.49764252, 18.74625969], [84.49764252, 18.74596977], [84.49736023, 18.74597168], [84.49736023, 18.74569511], [84.49653625, 18.74570084], [84.49653625, 18.74542046], [84.49597168, 18.74542046], [84.49597168, 18.7448597], [84.49569702, 18.7448616], [84.49569702, 18.74430466], [84.49541473, 18.74430466], [84.49541473, 18.74402809], [84.49514008, 18.74403], [84.49514008, 18.74374962], [84.49485779, 18.74374962], [84.49485779, 18.74347115], [84.49458313, 18.74347305], [84.49458313, 18.74291611], [84.49430847, 18.74291992], [84.49430847, 18.74263954], [84.49402618, 18.74263954], [84.49402618, 18.74236107], [84.49346924, 18.74236107], [84.49346924, 18.7420845], [84.49319458, 18.7420845], [84.49319458, 18.74180603], [84.49263763, 18.74180984], [84.49263763, 18.74152946], [84.49236298, 18.74152946], [84.49236298, 18.7412529], [84.49208069, 18.7412529], [84.49208069, 18.74097061], [84.49180603, 18.74097061], [84.49180603, 18.74069214], [84.49153137, 18.74069214], [84.49153137, 18.74041748], [84.49124908, 18.74041939], [84.49124908, 18.74014282], [84.4909668, 18.74014282], [84.4909668, 18.73986244], [84.49069214, 18.73986244], [84.49069214, 18.73958015], [84.49041748, 18.73958206], [84.49041748, 18.7393055], [84.49014282, 18.73931122], [84.49014282, 18.73875237], [84.48986053, 18.73875237], [84.48986053, 18.73846817], [84.48958588, 18.73847008], [84.48958588, 18.73791695], [84.48929596, 18.73792076], [84.48929596, 18.73735809], [84.48902893, 18.73736191], [84.48902893, 18.73708344], [84.48874664, 18.73708344], [84.48874664, 18.73680496], [84.48847198, 18.73681068], [84.48847198, 18.7365284], [84.48819733, 18.7365284], [84.48819733, 18.73624992], [84.48791504, 18.73624992], [84.48791504, 18.73597145], [84.48764038, 18.73597145], [84.48764038, 18.73569489], [84.48735809, 18.73569489], [84.48735809, 18.73430634], [84.48707581, 18.73431969], [84.48707581, 18.73374939], [84.48680878, 18.73374939], [84.48680878, 18.73319054], [84.48652649, 18.73319435], [84.48652649, 18.73263931], [84.48625183, 18.73264122], [84.48625183, 18.73236084], [84.48568726, 18.73236084], [84.48568726, 18.73208046], [84.48542023, 18.73208427], [84.48542023, 18.7318058], [84.48513794, 18.73180962], [84.48513794, 18.73097038], [84.48486328, 18.73097229], [84.48486328, 18.73041725], [84.48458099, 18.73042107], [84.48458099, 18.72986031], [84.48401642, 18.72986031], [84.48401642, 18.72957993], [84.48374939, 18.72958374], [84.48374939, 18.72930527], [84.4834671, 18.72931099], [84.4834671, 18.72903061], [84.48319244, 18.72903061], [84.48319244, 18.72875023], [84.48291779, 18.72875023], [84.48291779, 18.72820091], [84.48264313, 18.72820091], [84.48264313, 18.72792053], [84.48236084, 18.72792053], [84.48236084, 18.72764015], [84.48208618, 18.72764015], [84.48208618, 18.72735977], [84.48180389, 18.72736359], [84.48180389, 18.7270813], [84.48124695, 18.7270813], [84.48124695, 18.72680473], [84.48097229, 18.72680473], [84.48097229, 18.72652817], [84.48042297, 18.72653008], [84.48042297, 18.7262516], [84.48014069, 18.7262516], [84.48014069, 18.72596931], [84.4798584, 18.72597122], [84.4798584, 18.72569466], [84.47958374, 18.72569466], [84.47958374, 18.72541618], [84.47902679, 18.72542191], [84.47902679, 18.72485924], [84.47875214, 18.72485924], [84.47875214, 18.72458076], [84.47819519, 18.72458267], [84.47819519, 18.72430611], [84.47763824, 18.72431183], [84.47763824, 18.72403145], [84.47735596, 18.72403145], [84.47735596, 18.72374916], [84.47680664, 18.72374916], [84.47680664, 18.72291756], [84.47651672, 18.72291756], [84.47651672, 18.72263908], [84.47569275, 18.72263908], [84.47569275, 18.72236061], [84.47541046, 18.72236061], [84.47541046, 18.72207069], [84.4751358, 18.72208405], [84.4751358, 18.7215271], [84.47486115, 18.72153091], [84.47486115, 18.72125053], [84.47458649, 18.72125053], [84.47458649, 18.72097015], [84.4743042, 18.72097206], [84.4743042, 18.72069359], [84.47374725, 18.72069359], [84.47374725, 18.72041512], [84.4734726, 18.72042084], [84.4734726, 18.72014046], [84.47319794, 18.72014046], [84.47319794, 18.71986008], [84.47291565, 18.71986198], [84.47291565, 18.71958351], [84.47264099, 18.71958351], [84.47264099, 18.71930695], [84.47236633, 18.7193203], [84.47236633, 18.71903038], [84.47207642, 18.71903038], [84.47207642, 18.71875], [84.47180176, 18.71875], [84.47180176, 18.71846962], [84.4715271, 18.71847153], [84.4715271, 18.71791649], [84.47125244, 18.7179203], [84.47125244, 18.71763992], [84.47097015, 18.71763992], [84.47097015, 18.71708107], [84.4706955, 18.71708488], [84.4706955, 18.71652794], [84.47041321, 18.71652985], [84.47041321, 18.71626091], [84.47013855, 18.71626091], [84.47013855, 18.7159729], [84.46986389, 18.71597481], [84.46986389, 18.71569443], [84.46930695, 18.71569443], [84.46930695, 18.71513939], [84.46901703, 18.71513939], [84.46901703, 18.71486282], [84.46875, 18.71486282], [84.46875, 18.71430969], [84.46848297, 18.71430969], [84.46848297, 18.71403122], [84.46819305, 18.71403122], [84.46819305, 18.71375275], [84.4679184, 18.71375275], [84.4679184, 18.71347046], [84.46763611, 18.71347046], [84.46763611, 18.71319389], [84.4659729, 18.71319389], [84.4659729, 18.71291733], [84.46569824, 18.71292114], [84.46569061, 18.71153069], [84.46541595, 18.71153069], [84.46541595, 18.71096992], [84.4651413, 18.71097183], [84.4651413, 18.71069527], [84.46485901, 18.71069908], [84.46485901, 18.71013069], [84.46458435, 18.71013832], [84.46458435, 18.70986176], [84.46430206, 18.70986176], [84.46430206, 18.70958328], [84.4640274, 18.70958328], [84.4640274, 18.70930481], [84.46375275, 18.70930481], [84.46375275, 18.70874977], [84.46347046, 18.70874977], [84.46347046, 18.70846939], [84.46291351, 18.7084713], [84.46291351, 18.70819473], [84.46263885, 18.70819473], [84.46263885, 18.70791626], [84.46235657, 18.70791817], [84.46235657, 18.70736122], [84.46208191, 18.70736122], [84.46208191, 18.70652962], [84.46180725, 18.70652962], [84.46180725, 18.70597076], [84.46152496, 18.70597267], [84.46152496, 18.70513916], [84.46125031, 18.70514107], [84.46125031, 18.70486069], [84.46097565, 18.70486069], [84.46097565, 18.70458412], [84.46069336, 18.70458412], [84.46069336, 18.70347214], [84.4604187, 18.70347214], [84.4604187, 18.70319557], [84.46013641, 18.70319557], [84.46013641, 18.70263863], [84.45986176, 18.70264053], [84.45986176, 18.70207977], [84.4595871, 18.70208359], [84.4595871, 18.70180511], [84.45847321, 18.70181084], [84.45847321, 18.70125008], [84.45819092, 18.70125008], [84.45819092, 18.70096016], [84.45791626, 18.70097351], [84.45791626, 18.70069504], [84.4576416, 18.70070076], [84.4576416, 18.70014191], [84.45736694, 18.70014191], [84.45736694, 18.69957924], [84.45708466, 18.69958115], [84.45708466, 18.69902992], [84.45680237, 18.69903183], [84.45680237, 18.69819069], [84.45652771, 18.6981945], [84.45652771, 18.69791603], [84.45625305, 18.69792175], [84.45625305, 18.69764137], [84.45597076, 18.69764137], [84.45597076, 18.69735909], [84.45569611, 18.69735909], [84.45569611, 18.69680977], [84.45485687, 18.69680977], [84.45485687, 18.69652748], [84.45458221, 18.69652748], [84.45458221, 18.69625092], [84.45429993, 18.69625092], [84.45429993, 18.69597054], [84.45402527, 18.69597244], [84.45402527, 18.6954174], [84.45375061, 18.69542122], [84.45375061, 18.69514847], [84.45347595, 18.69514847], [84.45347595, 18.69486046], [84.45318604, 18.69486046], [84.45318604, 18.69431114], [84.45291901, 18.69431114], [84.45291901, 18.69403076], [84.45263672, 18.69403076], [84.45263672, 18.69375038], [84.45236206, 18.69375038], [84.45236206, 18.69347], [84.45207977, 18.69347191], [84.45207977, 18.69291687], [84.45181274, 18.69292068], [84.45181274, 18.69235992], [84.45124817, 18.69236183], [84.45124817, 18.69208336], [84.45096588, 18.69209099], [84.45096588, 18.69153023], [84.45069122, 18.69153023], [84.45069122, 18.69124985], [84.45041656, 18.69124985], [84.45041656, 18.69096947], [84.45014191, 18.69097137], [84.45014191, 18.69069481], [84.44985962, 18.69069481], [84.44985962, 18.69041634], [84.44957733, 18.69042015], [84.44957733, 18.69013977], [84.44930267, 18.69013977], [84.44930267, 18.68985939], [84.44902802, 18.6898613], [84.44902802, 18.68958473], [84.44875336, 18.68958473], [84.44875336, 18.68902779], [84.44847107, 18.68902779], [84.44847107, 18.68874931], [84.44819641, 18.68875122], [84.44819641, 18.68847275], [84.44791412, 18.68847466], [84.44791412, 18.68819427], [84.44763947, 18.68819427], [84.44763947, 18.6879158], [84.44735718, 18.68791962], [84.44735718, 18.68736267], [84.44708252, 18.68736267], [84.44708252, 18.68708038], [84.44680786, 18.6870842], [84.44680786, 18.68680573], [84.4465332, 18.68680954], [84.4465332, 18.68625259], [84.44625092, 18.68625259], [84.44625092, 18.68596077], [84.44596863, 18.68597031], [84.44596863, 18.68569374], [84.44569397, 18.68569374], [84.44569397, 18.6851387], [84.44542694, 18.68514252], [84.44542694, 18.68457985], [84.44513702, 18.68458366], [84.44513702, 18.68430519], [84.44486237, 18.68431091], [84.44486237, 18.68403053], [84.44458008, 18.68403053], [84.44458008, 18.68374825], [84.44430542, 18.68374825], [84.44430542, 18.68347168], [84.44403076, 18.68347168], [84.44403076, 18.68319511], [84.44374847, 18.68321037], [84.44374847, 18.68292046], [84.44346619, 18.68292046], [84.44346619, 18.68263817], [84.44319153, 18.68263817], [84.44319153, 18.6823597], [84.44291687, 18.6823616], [84.44291687, 18.68208313], [84.44235992, 18.68208313], [84.44235992, 18.68180466], [84.44208527, 18.68180466], [84.44208527, 18.68124962], [84.44180298, 18.68124962], [84.44180298, 18.68041992], [84.44124603, 18.68041992], [84.44124603, 18.68014908], [84.44097137, 18.68014908], [84.44097137, 18.67930984], [84.44069672, 18.67930984], [84.44069672, 18.67847061], [84.44097137, 18.67847252], [84.44097137, 18.67819595], [84.44125366, 18.67819595], [84.44125366, 18.67791748], [84.44152832, 18.67791939], [84.44152832, 18.67597008], [84.44125366, 18.67597389], [84.44125366, 18.67486382], [84.44097137, 18.67486382], [84.44097137, 18.67375183], [84.44069672, 18.67375183], [84.44069672, 18.67235947], [84.44041443, 18.67235947], [84.44041443, 18.67180634], [84.44013977, 18.67181015], [84.44013977, 18.66847038], [84.44041443, 18.66847229], [84.44041443, 18.66763878], [84.44069672, 18.66764069], [84.44069672, 18.6672802], [84.44069672, 18.6665287], [84.4404068, 18.66653061], [84.4404068, 18.66570091], [84.44069672, 18.66570091], [84.44069672, 18.66403008], [84.43985748, 18.66402817], [84.43985748, 18.66430473], [84.43902588, 18.66430473], [84.43902588, 18.66402817], [84.43875122, 18.66403008], [84.43875122, 18.66319084], [84.43846893, 18.66319466], [84.43846893, 18.66291618], [84.43818665, 18.66292], [84.43818665, 18.66236115], [84.43791962, 18.66236115], [84.43791962, 18.66180992], [84.43736267, 18.66180992], [84.43736267, 18.66152954], [84.43708038, 18.66152954], [84.43708038, 18.66125107], [84.43681335, 18.66125107], [84.43681335, 18.66152954], [84.43653107, 18.66152954], [84.43653107, 18.66125107], [84.43625641, 18.66125107], [84.43625641, 18.6609726], [84.43597412, 18.6609726], [84.43597412, 18.66069221], [84.43569183, 18.66069221], [84.43569183, 18.66013908], [84.43541718, 18.6601429], [84.43541718, 18.65958023], [84.43514252, 18.65958405], [84.43514252, 18.65847015], [84.43486023, 18.65847015], [84.43486023, 18.65763855], [84.4345932, 18.65763855], [84.4345932, 18.65735817], [84.43430328, 18.65736008], [84.43430328, 18.65708351], [84.43402863, 18.65708351], [84.43402863, 18.65680504], [84.43374634, 18.65681076], [84.43374634, 18.65652847], [84.43347168, 18.65652847], [84.43347168, 18.65624809], [84.43319702, 18.65624809], [84.43319702, 18.65597916], [84.4329071, 18.65597916], [84.4329071, 18.6554203], [84.43264008, 18.6554203], [84.43264008, 18.65513992], [84.43235779, 18.65513992], [84.43235779, 18.65485954], [84.43208313, 18.65486145], [84.43208313, 18.65430641], [84.43152618, 18.65431023], [84.43152618, 18.65402985], [84.43131256, 18.65402985], [84.43096924, 18.65402985], [84.43096924, 18.65374947], [84.43068695, 18.65374947], [84.43068695, 18.65347099], [84.43041992, 18.6534729], [84.43041992, 18.65291786], [84.42986298, 18.65291786], [84.42986298, 18.65263939], [84.42903137, 18.65263939], [84.42903137, 18.65236092], [84.42874908, 18.65236092], [84.42874908, 18.65208054], [84.42763519, 18.65208244], [84.42763519, 18.65180588], [84.42791748, 18.65180969], [84.42791748, 18.65153122], [84.42764282, 18.65153122], [84.42764282, 18.65125084], [84.42708588, 18.65125084], [84.42708588, 18.65069008], [84.42680359, 18.6506958], [84.42680359, 18.65041733], [84.42652893, 18.65042114], [84.42652893, 18.65014076], [84.42624664, 18.65014076], [84.42624664, 18.64985275], [84.42597198, 18.64986038], [84.42597198, 18.64958572], [84.42569733, 18.64958572], [84.42569733, 18.64930534], [84.42542267, 18.64931107], [84.42542267, 18.64903069], [84.42514038, 18.64903069], [84.42514038, 18.64875031], [84.42485809, 18.64875031], [84.42485809, 18.6482029], [84.42457581, 18.6482029], [84.42457581, 18.64792061], [84.42431641, 18.64792061], [84.42431641, 18.64764023], [84.42402649, 18.64764023], [84.42402649, 18.64736176], [84.42375183, 18.64736366], [84.42375183, 18.64708138], [84.42346954, 18.64708138], [84.42346954, 18.64680481], [84.42319489, 18.64680481], [84.42319489, 18.64652824], [84.42292023, 18.64653015], [84.42292023, 18.64596939], [84.42263794, 18.64596939], [84.42263794, 18.64569473], [84.42236328, 18.64569473], [84.42236328, 18.64541626], [84.42180634, 18.64542007], [84.42180634, 18.6451416], [84.42124939, 18.6451416], [84.42124939, 18.64430618], [84.4209671, 18.6443119], [84.4209671, 18.64404106], [84.42069244, 18.64404106], [84.42069244, 18.64374924], [84.41958618, 18.64374924], [84.41958618, 18.64347076], [84.41902924, 18.64347267], [84.41902924, 18.6431942], [84.41874695, 18.6431942], [84.41874695, 18.64291763], [84.41847229, 18.64291763], [84.41847229, 18.64236069], [84.41819763, 18.64236069], [84.41819763, 18.64208031], [84.41791534, 18.64208412], [84.41791534, 18.64180565], [84.41764069, 18.64180946], [84.41764069, 18.64152908], [84.4173584, 18.64152908], [84.4173584, 18.64125061], [84.41707611, 18.64125061], [84.41707611, 18.64068985], [84.41680908, 18.64069366], [84.41680908, 18.64041519], [84.41652679, 18.64042091], [84.41652679, 18.64014053], [84.4154129, 18.64014053], [84.4154129, 18.63986015], [84.4145813, 18.63986206], [84.4145813, 18.63930511], [84.41430664, 18.63931084], [84.41430664, 18.63903046], [84.41401672, 18.63903046], [84.41401672, 18.63875008], [84.41374969, 18.63875008], [84.41374969, 18.6384697], [84.41347504, 18.6384716], [84.41347504, 18.63819695], [84.41319275, 18.63820076], [84.41319275, 18.63791084], [84.41291809, 18.63791656], [84.41291809, 18.63763809], [84.4126358, 18.63764], [84.4126358, 18.63735962], [84.41236115, 18.63736153], [84.41236115, 18.63708305], [84.41208649, 18.63708305], [84.41208649, 18.63680649], [84.41179657, 18.6368103], [84.41179657, 18.63652992], [84.41152954, 18.63652992], [84.41152954, 18.63624954], [84.41124725, 18.63624954], [84.41124725, 18.63597107], [84.4109726, 18.63597488], [84.4109726, 18.6356945], [84.41041565, 18.6356945], [84.41041565, 18.63541603], [84.41014099, 18.63541985], [84.41014099, 18.63513947], [84.4098587, 18.63513947], [84.4098587, 18.63484955], [84.40958405, 18.6348629], [84.40958405, 18.63458061], [84.40930176, 18.63458061], [84.40930176, 18.63430595], [84.4090271, 18.63430977], [84.4090271, 18.63402939], [84.40875244, 18.63402939], [84.40875244, 18.63375282], [84.4081955, 18.63375282], [84.4081955, 18.63347054], [84.40791321, 18.63347054], [84.40791321, 18.63319206], [84.40763855, 18.63319206], [84.40763855, 18.6329174], [84.40735626, 18.63292122], [84.40735626, 18.63264275], [84.4070816, 18.63264275], [84.4070816, 18.63236237], [84.40680695, 18.63236237], [84.40680695, 18.63208008], [84.40625, 18.63208389], [84.40625, 18.63180542], [84.40598297, 18.63181114], [84.40598297, 18.63153076], [84.40569305, 18.63153076], [84.40569305, 18.63124847], [84.4054184, 18.63124847], [84.4054184, 18.63096809], [84.40513611, 18.63097191], [84.40513611, 18.63069534], [84.40486145, 18.63069916], [84.40486145, 18.63042068], [84.40458679, 18.63042068], [84.40458679, 18.6301384], [84.40429688, 18.6301384], [84.40429688, 18.62985992], [84.40374756, 18.62986183], [84.40374756, 18.62958336], [84.4034729, 18.62958336], [84.4034729, 18.62930489], [84.40319824, 18.62930489], [84.40319061, 18.62902832], [84.4026413, 18.62902832], [84.4026413, 18.62874985], [84.40235901, 18.62874985], [84.40235901, 18.62846947], [84.40208435, 18.62847137], [84.40208435, 18.62819481], [84.40180206, 18.62819481], [84.40180206, 18.62791634], [84.40125275, 18.62791824], [84.40125275, 18.62763977], [84.40097046, 18.62763977], [84.40097046, 18.62735939], [84.4006958, 18.6273613], [84.4006958, 18.62680626], [84.40040588, 18.62681007], [84.40040588, 18.62625122], [84.40013123, 18.62625122], [84.40013123, 18.62597084], [84.3998642, 18.62597275], [84.3998642, 18.62569427], [84.39958191, 18.62569427], [84.39958191, 18.6254158], [84.39930725, 18.62541962], [84.39930725, 18.62514114], [84.39875031, 18.62514114], [84.39875031, 18.62486076], [84.39847565, 18.62486076], [84.39847565, 18.6245842], [84.3979187, 18.6245842], [84.3979187, 18.62430573], [84.39763641, 18.62430954], [84.39763641, 18.62403107], [84.39736176, 18.62403107], [84.39736176, 18.62375069], [84.3970871, 18.62375069], [84.3970871, 18.62347031], [84.39680481, 18.62347221], [84.39680481, 18.62291718], [84.39653015, 18.62291718], [84.39653015, 18.6226387], [84.39624786, 18.62264061], [84.39624786, 18.62236023], [84.39597321, 18.62236023], [84.39597321, 18.62207985], [84.39569092, 18.62208366], [84.39569092, 18.62180519], [84.39541626, 18.62181091], [84.39541626, 18.62153053], [84.3951416, 18.62153053], [84.3951416, 18.62125015], [84.39485931, 18.62125015], [84.39485931, 18.62096977], [84.39430237, 18.62097359], [84.39430237, 18.62069511], [84.39402771, 18.62070084], [84.39402771, 18.62042046], [84.39375305, 18.62042046], [84.39375305, 18.61987114], [84.39319611, 18.61987114], [84.39319611, 18.61957932], [84.39291382, 18.61958122], [84.39291382, 18.61930466], [84.39263916, 18.61930466], [84.39263916, 18.61902809], [84.39235687, 18.61903191], [84.39235687, 18.61875153], [84.39180756, 18.61875153], [84.39180756, 18.61846924], [84.39125061, 18.61847115], [84.39125061, 18.61819458], [84.39097595, 18.61819458], [84.39097595, 18.61791611], [84.39068604, 18.61792183], [84.39068604, 18.61735916], [84.39041901, 18.61735916], [84.39041901, 18.61708069], [84.39013672, 18.6170826], [84.39013672, 18.61680603], [84.38986206, 18.61681175], [84.38986206, 18.61652756], [84.38957977, 18.61652756], [84.38957977, 18.61624908], [84.38931274, 18.61624908], [84.38931274, 18.61597061], [84.38847351, 18.61597252], [84.38847351, 18.61569405], [84.38764191, 18.61569405], [84.38764191, 18.61458397], [84.38735962, 18.61458397], [84.38735962, 18.6143055], [84.38707733, 18.61431122], [84.38707733, 18.61403084], [84.38680267, 18.61403084], [84.38680267, 18.61374092], [84.38652802, 18.61375046], [84.38652802, 18.61347198], [84.38625336, 18.61347198], [84.38625336, 18.61291695], [84.38597107, 18.61292076], [84.38597107, 18.61264038], [84.38540649, 18.61264038], [84.38540649, 18.61236], [84.38513947, 18.61236191], [84.38513947, 18.61208344], [84.38486481, 18.61208344], [84.38486481, 18.61180687], [84.3840332, 18.61181068], [84.3840332, 18.6115303], [84.38346863, 18.6115303], [84.38346863, 18.61124992], [84.38318634, 18.61124992], [84.38318634, 18.61067963], [84.38291931, 18.61069489], [84.38291931, 18.61041641], [84.38263702, 18.61042023], [84.38263702, 18.61013985], [84.38236237, 18.61013985], [84.38236237, 18.6095829], [84.38208008, 18.60958481], [84.38208008, 18.60930634], [84.38153076, 18.60931015], [84.38153076, 18.60902977], [84.38124847, 18.60902977], [84.38124847, 18.60874939], [84.38096619, 18.60874939], [84.38096619, 18.60819054], [84.38041687, 18.60819435], [84.38041687, 18.60791588], [84.37985992, 18.60793114], [84.37985992, 18.60736275], [84.37958527, 18.60736275], [84.37958527, 18.60708427], [84.37875366, 18.60708427], [84.37875366, 18.6068058], [84.37847137, 18.60680962], [84.37847137, 18.60653114], [84.37819672, 18.60653114], [84.37819672, 18.60625267], [84.3779068, 18.60625267], [84.3779068, 18.60597038], [84.37763977, 18.60597038], [84.37763977, 18.60541725], [84.37735748, 18.60542107], [84.37735748, 18.60514259], [84.37708282, 18.60514259], [84.37708282, 18.60487175], [84.37680817, 18.60487175], [84.37680817, 18.60457993], [84.37652588, 18.60458374], [84.37652588, 18.60430527], [84.37625122, 18.60430908], [84.37625122, 18.60346985], [84.37596893, 18.60347176], [84.37596893, 18.60319519], [84.37568665, 18.60320091], [84.37568665, 18.60263824], [84.37541962, 18.60263824], [84.37541962, 18.60235977], [84.37513733, 18.60236168], [84.37513733, 18.60208321], [84.37486267, 18.60208321], [84.37486267, 18.60180473], [84.37430573, 18.60180473], [84.37430573, 18.60152626], [84.37403107, 18.60152817], [84.37403107, 18.60124969], [84.37346649, 18.60124969], [84.37346649, 18.60097122], [84.37319183, 18.60097313], [84.37319183, 18.60069466], [84.37291718, 18.60069466], [84.37291718, 18.60013962], [84.37264252, 18.60013962], [84.37264252, 18.59986115], [84.37236023, 18.59986115], [84.37236023, 18.59958076], [84.37208557, 18.59958267], [84.37208557, 18.59930611], [84.37180328, 18.59930992], [84.37180328, 18.59902954], [84.37152863, 18.59902954], [84.37152863, 18.59847069], [84.37124634, 18.5984726], [84.37124634, 18.59819412], [84.37097168, 18.59819412], [84.37097168, 18.59791756], [84.37069702, 18.59791946], [84.37069702, 18.59764099], [84.3704071, 18.59764099], [84.3704071, 18.59708023], [84.37014008, 18.59708595], [84.37014008, 18.59680557], [84.36985779, 18.59680939], [84.36985779, 18.59653091], [84.36958313, 18.59653091], [84.36958313, 18.59625053], [84.36930847, 18.59625053], [84.36930847, 18.59570122], [84.36902618, 18.59570122], [84.36902618, 18.59542084], [84.36875153, 18.59542084], [84.36875153, 18.59514046], [84.36846924, 18.59514046], [84.36846924, 18.59486008], [84.36819458, 18.59486389], [84.36819458, 18.59458351], [84.36791992, 18.59458351], [84.36791992, 18.59402847], [84.36763763, 18.59403038], [84.36763763, 18.59375191], [84.36736298, 18.59375191], [84.36736298, 18.59346962], [84.36708069, 18.59347343], [84.36708069, 18.59319496], [84.36680603, 18.59320068], [84.36680603, 18.59264183], [84.36653137, 18.59264183], [84.36653137, 18.59235954], [84.36624908, 18.59235954], [84.36624908, 18.59208107], [84.36597443, 18.59208107], [84.36597443, 18.59180641], [84.36569214, 18.59181023], [84.36569214, 18.59124947], [84.36541748, 18.59124947], [84.36541748, 18.59096909], [84.36513519, 18.5909729], [84.36513519, 18.59069443], [84.36486053, 18.59069443], [84.36486053, 18.59041595], [84.36458588, 18.59042168], [84.36458588, 18.59013748], [84.36429596, 18.59013748], [84.36429596, 18.589571], [84.36402893, 18.58958244], [84.36402893, 18.58930588], [84.36374664, 18.58930969], [84.36374664, 18.58903122], [84.36347198, 18.58903122], [84.36347198, 18.58875084], [84.36319733, 18.58875084], [84.36319733, 18.58847046], [84.36291504, 18.58847237], [84.36291504, 18.58763885], [84.36264038, 18.58764076], [84.36264038, 18.58736038], [84.36235809, 18.58736038], [84.36235809, 18.58708], [84.36208344, 18.58708382], [84.36208344, 18.58680534], [84.36180878, 18.58680534], [84.36180878, 18.58625031], [84.36152649, 18.58625031], [84.36152649, 18.58485985], [84.36125183, 18.58486176], [84.36125183, 18.58430672], [84.36096954, 18.58430672], [84.36096954, 18.58402824], [84.36068726, 18.58403015], [84.36068726, 18.58346939], [84.36042023, 18.5834713], [84.36042023, 18.58208466], [84.36013794, 18.58208466], [84.36013794, 18.58180618], [84.35986328, 18.58181], [84.35986328, 18.58152962], [84.35958099, 18.58152962], [84.35958099, 18.58125114], [84.35930634, 18.58125114], [84.35930634, 18.58097267], [84.35902405, 18.58097267], [84.35902405, 18.5806942], [84.35874939, 18.58069992], [84.35874939, 18.58014107], [84.3584671, 18.58014107], [84.3584671, 18.57986259], [84.35819244, 18.57986259], [84.35819244, 18.57958031], [84.35791779, 18.57958412], [84.35791779, 18.57875252], [84.3576355, 18.57875252], [84.3576355, 18.57708359], [84.35736084, 18.57708359], [84.35736084, 18.57680511], [84.35708618, 18.57681084], [84.35708618, 18.57653046], [84.35679626, 18.57653046], [84.35679626, 18.57624817], [84.35652924, 18.57624817], [84.35652924, 18.5759697], [84.35624695, 18.5759716], [84.35624695, 18.57569504], [84.35597229, 18.57570076], [84.35597229, 18.57485962], [84.35569763, 18.57486153], [84.35569763, 18.5695858], [84.35597229, 18.5695858], [84.35597229, 18.56875038], [84.35569763, 18.56875992], [84.35569763, 18.56847191], [84.35541534, 18.56847382], [84.35541534, 18.56736374], [84.35514069, 18.56736374], [84.35514069, 18.56693077], [84.35514069, 18.56569481], [84.3548584, 18.56569481], [84.3548584, 18.56430626], [84.35457611, 18.56431007], [84.35457611, 18.5640316], [84.35430908, 18.5640316], [84.35430908, 18.56374931], [84.35402679, 18.56374931], [84.35402679, 18.56319046], [84.3536377, 18.56319237], [84.35319519, 18.56319427], [84.35319519, 18.5629158], [84.35180664, 18.56291962], [84.35180664, 18.5626297], [84.35069275, 18.56263733], [84.35069275, 18.56236076], [84.3501358, 18.56236076], [84.3501358, 18.56263733], [84.3493042, 18.56263733], [84.3493042, 18.56236076], [84.34819794, 18.56236076], [84.34819794, 18.56208038], [84.3465271, 18.56208038], [84.3465271, 18.56236076], [84.34625244, 18.56236076], [84.34625244, 18.56208038], [84.34597015, 18.5620842], [84.34597015, 18.56180573], [84.34513855, 18.56180954], [84.34513855, 18.56153107], [84.34430695, 18.56153107], [84.34430695, 18.56125069], [84.34401703, 18.56125069], [84.34401703, 18.56097031], [84.34375, 18.56097221], [84.34375, 18.56069374], [84.34347534, 18.56069374], [84.34347534, 18.5601387], [84.34319305, 18.56014061], [84.34319305, 18.55986023], [84.34291077, 18.55986023], [84.34291077, 18.55958939], [84.34263611, 18.55958939], [84.34263611, 18.55931091], [84.34236145, 18.55931091], [84.34236145, 18.55903053], [84.34208679, 18.55903053], [84.34208679, 18.55875015], [84.34179688, 18.55875015], [84.34179688, 18.55820084], [84.34152985, 18.55820084], [84.34152985, 18.55792046], [84.34124756, 18.55792046], [84.34124756, 18.55764008], [84.3409729, 18.55764008], [84.3409729, 18.55708122], [84.34081268, 18.55708313], [84.34069824, 18.55708313], [84.34069061, 18.55624962], [84.34041595, 18.55624962], [84.34041595, 18.55569077], [84.3401413, 18.55569458], [84.3401413, 18.55513954], [84.33985138, 18.55513954], [84.33985138, 18.55458069], [84.3401413, 18.55458069], [84.3401413, 18.55374908], [84.34041595, 18.5537529], [84.34041595, 18.55319023], [84.34069061, 18.55319214], [84.34069061, 18.55264091], [84.34041595, 18.55264282], [84.34041595, 18.55236244], [84.3401413, 18.55236244], [84.3401413, 18.55208015], [84.33985901, 18.55208397], [84.33985901, 18.5518055], [84.33957672, 18.55181122], [84.33957672, 18.55153275], [84.33930206, 18.55153275], [84.33930206, 18.55096817], [84.3390274, 18.55097008], [84.3390274, 18.55069351], [84.33985901, 18.55069351], [84.33985901, 18.55097008], [84.34041595, 18.55096817], [84.34041595, 18.55124855], [84.34124756, 18.55124855], [84.34124756, 18.55153275], [84.34152985, 18.55153275], [84.34152985, 18.55181122], [84.34179688, 18.55181122], [84.34179688, 18.55264282], [84.34152985, 18.55264091], [84.34152985, 18.55474091], [84.34152985, 18.55597305], [84.34179688, 18.55597115], [84.34179688, 18.55624962], [84.34208679, 18.55624962], [84.34208679, 18.55653], [84.34263611, 18.55652809], [84.34263611, 18.55680466], [84.3429184, 18.55680466], [84.3429184, 18.55708313], [84.34319305, 18.55708122], [84.34319305, 18.55764008], [84.34348297, 18.55764008], [84.34348297, 18.55792046], [84.34401703, 18.55792046], [84.34401703, 18.55820084], [84.34430695, 18.55819511], [84.34430695, 18.55847168], [84.3445816, 18.55846977], [84.3445816, 18.55875015], [84.34485626, 18.55875015], [84.34485626, 18.55903053], [84.34541321, 18.55903053], [84.34541321, 18.55931091], [84.34570312, 18.55931091], [84.34570312, 18.55958939], [84.3473587, 18.55958939], [84.3473587, 18.55986023], [84.3484726, 18.55986023], [84.3484726, 18.56014061], [84.34958649, 18.56014061], [84.34958649, 18.56042099], [84.35041809, 18.56041527], [84.35041809, 18.56069374], [84.35124969, 18.56069374], [84.35124969, 18.56097221], [84.35263824, 18.56097031], [84.35263824, 18.56125069], [84.3529129, 18.56125069], [84.3529129, 18.56153107], [84.35305786, 18.56153107], [84.35320282, 18.56153107], [84.35320282, 18.56180954], [84.35346985, 18.56180573], [84.35346985, 18.5620842], [84.35430908, 18.56208038], [84.35430908, 18.56236076], [84.35458374, 18.56236076], [84.35458374, 18.56263733], [84.35514069, 18.5626297], [84.35514069, 18.56291962], [84.35569763, 18.5629158], [84.35569763, 18.56319427], [84.35652924, 18.56319427], [84.35652924, 18.56125069], [84.35624695, 18.56125069], [84.35624695, 18.56068993], [84.35597229, 18.56069374], [84.35597229, 18.55986023], [84.35569763, 18.55986023], [84.35569763, 18.55958939], [84.35542297, 18.55958939], [84.35542297, 18.55846977], [84.35569763, 18.55847168], [84.35569763, 18.55819511], [84.35597229, 18.55820084], [84.35597229, 18.5573597], [84.35624695, 18.5573616], [84.35624695, 18.55680466], [84.35597229, 18.55680466], [84.35597229, 18.55652809], [84.35569763, 18.55653], [84.35569763, 18.55624962], [84.35514069, 18.55624962], [84.35514069, 18.55597115], [84.35430908, 18.55597305], [84.35430908, 18.55569458], [84.35375214, 18.55569458], [84.35375214, 18.55541611], [84.35346985, 18.55541992], [84.35346985, 18.55513954], [84.3529129, 18.55513954], [84.3529129, 18.55486107], [84.35263824, 18.55486107], [84.35263824, 18.55458069], [84.35236359, 18.55458069], [84.35236359, 18.55430603], [84.3520813, 18.55430984], [84.3520813, 18.55402946], [84.35180664, 18.55402946], [84.35180664, 18.5537529], [84.35124969, 18.5537529], [84.35124969, 18.55347252], [84.35097504, 18.55347252], [84.35097504, 18.55319214], [84.35069275, 18.55319214], [84.35069275, 18.55291748], [84.35041809, 18.55291939], [84.35041809, 18.55264282], [84.34986115, 18.55264282], [84.34986115, 18.55236244], [84.34958649, 18.55236244], [84.34958649, 18.55208015], [84.3493042, 18.55208397], [84.3493042, 18.5518055], [84.34903717, 18.55181122], [84.34903717, 18.55153275], [84.34874725, 18.55153275], [84.34874725, 18.55124855], [84.34819794, 18.55124855], [84.34819794, 18.55096817], [84.34791565, 18.55097008], [84.34791565, 18.55069542], [84.34764099, 18.55069351], [84.34764099, 18.55041695], [84.3473587, 18.55042076], [84.3473587, 18.55013847], [84.34680176, 18.55013847], [84.34680176, 18.54985809], [84.3465271, 18.54986191], [84.3465271, 18.54958344], [84.34625244, 18.54958344], [84.34625244, 18.54930496], [84.34597778, 18.54931068], [84.34597778, 18.5490284], [84.34570312, 18.5490284], [84.34570312, 18.54874992], [84.34513855, 18.54874992], [84.34513855, 18.54846954], [84.34486389, 18.54847145], [84.34486389, 18.54819489], [84.3445816, 18.54819489], [84.3445816, 18.54791641], [84.34430695, 18.54792023], [84.34430695, 18.54764748], [84.34375, 18.54764748], [84.34375, 18.54735947], [84.34347534, 18.54736137], [84.34347534, 18.5470829], [84.34319305, 18.5470829], [84.34319305, 18.54680634], [84.34291077, 18.54681015], [84.34291077, 18.54652977], [84.34236145, 18.54652977], [84.34236145, 18.54624939], [84.34208679, 18.54624939], [84.34208679, 18.54597092], [84.3418045, 18.54597282], [84.3418045, 18.54569435], [84.34152985, 18.54569435], [84.34152985, 18.54541588], [84.34124756, 18.54541969], [84.34124756, 18.54514122], [84.34069824, 18.54514122], [84.34069061, 18.54486084], [84.34041595, 18.54486084], [84.34041595, 18.54459], [84.3401413, 18.54459], [84.3401413, 18.54430962], [84.33985138, 18.54430962], [84.33985138, 18.54403114], [84.33930206, 18.54403114], [84.33930206, 18.54375076], [84.3390274, 18.54375076], [84.3390274, 18.54347038], [84.33875275, 18.54347229], [84.33875275, 18.54319572], [84.33847046, 18.54319572], [84.33847046, 18.54291725], [84.3381958, 18.54292107], [84.3381958, 18.54264069], [84.33766174, 18.54264069], [84.33763885, 18.54236031], [84.3373642, 18.54236031], [84.3373642, 18.54208374], [84.33719635, 18.54208374], [84.33708191, 18.54208374], [84.33708191, 18.54195023], [84.33708191, 18.54180527], [84.33693695, 18.54180527], [84.33680725, 18.54181099], [84.33680725, 18.54164124], [84.33680725, 18.5415287], [84.3366394, 18.5415287], [84.33625031, 18.54153061], [84.33625031, 18.54125977], [84.33598328, 18.54125023], [84.33597565, 18.54097366], [84.33583069, 18.54097366], [84.33569336, 18.54097366], [84.33569336, 18.54069519], [84.33542633, 18.54070282], [84.3354187, 18.54042053], [84.33513641, 18.54042053], [84.33513641, 18.54014015], [84.33460236, 18.54014015], [84.3345871, 18.53986168], [84.33430481, 18.53986359], [84.33430481, 18.5395813], [84.33403015, 18.5395813], [84.33403015, 18.53930473], [84.33374786, 18.53930473], [84.33374786, 18.53902817], [84.33319092, 18.53903008], [84.33319092, 18.5387516], [84.33291626, 18.5387516], [84.33291626, 18.53845978], [84.3326416, 18.53847313], [84.3326416, 18.53819466], [84.33235931, 18.53819466], [84.33235931, 18.53791618], [84.33207703, 18.53792191], [84.33207703, 18.53764153], [84.33152771, 18.53764153], [84.33152771, 18.53735924], [84.33125305, 18.53735924], [84.33125305, 18.53708076], [84.33097076, 18.53708267], [84.33097076, 18.53680611], [84.33069611, 18.53681183], [84.33069611, 18.53652763], [84.33013916, 18.53652763], [84.33013916, 18.53624916], [84.32985687, 18.53624916], [84.32985687, 18.53597069], [84.32958221, 18.5359726], [84.32958221, 18.53569412], [84.32930756, 18.53569412], [84.32930756, 18.53541756], [84.3290329, 18.53541756], [84.3290329, 18.53513908], [84.32847595, 18.53513908], [84.32847595, 18.53486061], [84.32818604, 18.53486061], [84.32818604, 18.53458023], [84.32791901, 18.53458405], [84.32791901, 18.53430557], [84.32763672, 18.53430939], [84.32763672, 18.53403091], [84.32707977, 18.53403091], [84.32707977, 18.53375053], [84.32680511, 18.53375053], [84.32680511, 18.53347206], [84.32653046, 18.53347206], [84.32653046, 18.53319359], [84.32624817, 18.53319359], [84.32624817, 18.53291512], [84.32596588, 18.53292084], [84.32596588, 18.53264809], [84.32541656, 18.53264809], [84.32541656, 18.53236008], [84.32514191, 18.53236198], [84.32514191, 18.53208351], [84.32485962, 18.53208351], [84.32485962, 18.53180695], [84.32457733, 18.53181076], [84.32457733, 18.53153038], [84.32402802, 18.53153038], [84.32402802, 18.53125], [84.32375336, 18.53125], [84.32375336, 18.53096962], [84.32347107, 18.53097153], [84.32347107, 18.53069305], [84.32319641, 18.53070068], [84.32319641, 18.5304203], [84.32263947, 18.5304203], [84.32263947, 18.53013992], [84.32235718, 18.53013992], [84.32235718, 18.52985954], [84.32208252, 18.52986145], [84.32208252, 18.52958488], [84.32180786, 18.52959061], [84.32180786, 18.52931023], [84.3215332, 18.52931023], [84.3215332, 18.52902985], [84.32096863, 18.52902985], [84.32096863, 18.52874947], [84.32068634, 18.52874947], [84.32068634, 18.5284729], [84.32041931, 18.52847481], [84.32041931, 18.52819443], [84.32013702, 18.52819443], [84.32013702, 18.52791595], [84.31958008, 18.52791977], [84.31958008, 18.52763939], [84.31930542, 18.52763939], [84.31930542, 18.52736282], [84.31903076, 18.52736282], [84.31903076, 18.52708054], [84.31874847, 18.52708054], [84.31874847, 18.52680588], [84.31846619, 18.52680969], [84.31846619, 18.52652168], [84.31791687, 18.5265274], [84.31791687, 18.52625275], [84.31764221, 18.52625275], [84.31764221, 18.52597046], [84.31735992, 18.52597046], [84.31735992, 18.52569389], [84.31708527, 18.52569389], [84.31708527, 18.52541733], [84.31652832, 18.52542114], [84.31652832, 18.52514267], [84.31624603, 18.52514267], [84.31624603, 18.52485847], [84.31597137, 18.52485847], [84.31597137, 18.52457809], [84.31569672, 18.52458382], [84.31569672, 18.52430534], [84.3154068, 18.52430916], [84.3154068, 18.52403069], [84.31485748, 18.52403069], [84.31485748, 18.5237484], [84.31458282, 18.5237484], [84.31458282, 18.52346039], [84.31430817, 18.52347183], [84.31430817, 18.52319527], [84.31402588, 18.52319908], [84.31402588, 18.52292061], [84.31346893, 18.52292061], [84.31346893, 18.52263832], [84.31318665, 18.52263832], [84.31318665, 18.52235985], [84.31291962, 18.52236176], [84.31291962, 18.52208328], [84.31236267, 18.52208328], [84.31236267, 18.52180481], [84.31208038, 18.52180481], [84.31208038, 18.52152634], [84.31181335, 18.52152824], [84.31181335, 18.52124977], [84.31124878, 18.52124977], [84.31124878, 18.52096939], [84.31097412, 18.5209713], [84.31097412, 18.52069473], [84.31069183, 18.52069473], [84.31069183, 18.52041626], [84.31041718, 18.52041817], [84.31041718, 18.52013969], [84.30986023, 18.52013969], [84.30986023, 18.51986122], [84.30958557, 18.51986122], [84.30958557, 18.51958275], [84.30930328, 18.51958275], [84.30930328, 18.51930618], [84.30874634, 18.51931], [84.30874634, 18.51902962], [84.30847168, 18.51902962], [84.30847168, 18.51875114], [84.30819702, 18.51875114], [84.30819702, 18.51847076], [84.30764008, 18.51847267], [84.30764008, 18.5181942], [84.30735779, 18.5181942], [84.30735779, 18.51791763], [84.30708313, 18.51791954], [84.30708313, 18.51764107], [84.30652618, 18.51764107], [84.30652618, 18.51736069], [84.30625153, 18.51736069], [84.30625153, 18.51708031], [84.30596924, 18.51708412], [84.30596924, 18.51680565], [84.30568695, 18.51680946], [84.30568695, 18.51653099], [84.30513763, 18.51653099], [84.30513763, 18.51625061], [84.30486298, 18.51625061], [84.30486298, 18.51597023], [84.30458069, 18.51597214], [84.30458069, 18.51569366], [84.30403137, 18.51569366], [84.30403137, 18.5154171], [84.30374146, 18.51542091], [84.30374146, 18.51514053], [84.3034668, 18.51514053], [84.3034668, 18.51486015], [84.30291748, 18.51486206], [84.30291748, 18.51458359], [84.30263519, 18.51458359], [84.30263519, 18.51430511], [84.30236053, 18.51431084], [84.30236053, 18.51403046], [84.30208588, 18.51403046], [84.30208588, 18.51375008], [84.30152893, 18.51375008], [84.30152893, 18.5134697], [84.30124664, 18.51347351], [84.30124664, 18.51319504], [84.30097198, 18.51320076], [84.30097198, 18.51292038], [84.30042267, 18.51292038], [84.30042267, 18.51264191], [84.30014038, 18.51264191], [84.30014038, 18.51235962], [84.29985809, 18.51235962], [84.29985809, 18.51208115], [84.29930878, 18.51208115], [84.29930878, 18.51180649], [84.29902649, 18.5118103], [84.29902649, 18.51151848], [84.29875183, 18.51152992], [84.29875183, 18.51125145], [84.29846954, 18.51125145], [84.29846954, 18.51096916], [84.29792023, 18.51097107], [84.29792023, 18.5106945], [84.29763794, 18.5106945], [84.29763794, 18.51041603], [84.29736328, 18.51042175], [84.29736328, 18.51014137], [84.29708099, 18.51014137], [84.29708099, 18.50985909], [84.29651642, 18.50985909], [84.29651642, 18.50958061], [84.29624939, 18.50958252], [84.29624939, 18.50930595], [84.2959671, 18.50930977], [84.2959671, 18.50902748], [84.29541779, 18.50902748], [84.29541779, 18.50875092], [84.2951355, 18.50875092], [84.2951355, 18.50847244], [84.29486847, 18.50847816], [84.29486847, 18.50819016], [84.29458618, 18.50819397], [84.29458618, 18.5079174], [84.29402924, 18.50792122], [84.29402924, 18.50764084], [84.29374695, 18.50764084], [84.29374695, 18.50736046], [84.29347229, 18.50736046], [84.29347229, 18.50708008], [84.29319763, 18.50708389], [84.29319763, 18.50680542], [84.29264069, 18.50681114], [84.29264069, 18.50653076], [84.2923584, 18.50653076], [84.2923584, 18.50625038], [84.29207611, 18.50625038], [84.29207611, 18.50597], [84.29180908, 18.50597191], [84.29180908, 18.50569534], [84.29125214, 18.50570107], [84.29125214, 18.50542068], [84.29096985, 18.50542068], [84.29096985, 18.5051403], [84.29070282, 18.5051403], [84.29070282, 18.50485992], [84.2904129, 18.50486183], [84.2904129, 18.50458336], [84.28986359, 18.50458336], [84.28986359, 18.50430679], [84.2895813, 18.50430679], [84.2895813, 18.50402832], [84.28930664, 18.50403023], [84.28930664, 18.50374985], [84.28874207, 18.50374985], [84.28874207, 18.50346947], [84.28847504, 18.50347137], [84.28847504, 18.50319481], [84.28819275, 18.50319481], [84.28819275, 18.50291634], [84.28791809, 18.50292015], [84.28791809, 18.50263977], [84.28736115, 18.50263977], [84.28736115, 18.50235176], [84.28708649, 18.5023613], [84.28708649, 18.50208473], [84.2868042, 18.50208473], [84.2868042, 18.50180626], [84.28652954, 18.50181007], [84.28652954, 18.50152969], [84.2859726, 18.50152969], [84.2859726, 18.50125122], [84.28569794, 18.50125122], [84.28569794, 18.50097275], [84.28541565, 18.50097275], [84.28541565, 18.50069427], [84.28514099, 18.50069427], [84.28514099, 18.5004158], [84.2848587, 18.50041962], [84.2848587, 18.50014114], [84.28430176, 18.50014114], [84.28430176, 18.49986267], [84.2840271, 18.49986267], [84.2840271, 18.49958038], [84.28375244, 18.4995842], [84.28375244, 18.49930573], [84.28347015, 18.49930954], [84.28347015, 18.49903107], [84.28320313, 18.49903107], [84.28320313, 18.49875259], [84.28291321, 18.49875259], [84.28291321, 18.49847031], [84.28263855, 18.49847031], [84.28263855, 18.49819374], [84.2820816, 18.49819374], [84.2820816, 18.49791718], [84.28180695, 18.49791908], [84.28180695, 18.49764061], [84.28151703, 18.49764061], [84.28151703, 18.49735832], [84.28125, 18.49735832], [84.28125, 18.49707985], [84.28097534, 18.49708366], [84.28097534, 18.49680519], [84.28069305, 18.49681091], [84.28069305, 18.49654007], [84.28013611, 18.49654007], [84.28013611, 18.49624825], [84.27986145, 18.49624825], [84.27986145, 18.49596977], [84.27958679, 18.49597168], [84.27958679, 18.49569511], [84.27929688, 18.49570084], [84.27929688, 18.49542046], [84.27902985, 18.49542046], [84.27902985, 18.49513817], [84.27874756, 18.49513817], [84.27874756, 18.4948597], [84.27819824, 18.4948616], [84.27819061, 18.49458313], [84.27791595, 18.49458313], [84.27791595, 18.49430466], [84.2776413, 18.49430466], [84.2776413, 18.49402618], [84.27735901, 18.49402809], [84.27735901, 18.49374962], [84.27707672, 18.49374962], [84.27707672, 18.49348068], [84.27680206, 18.49348068], [84.27680206, 18.49319077], [84.2765274, 18.49319458], [84.2765274, 18.49291611], [84.27597046, 18.49291992], [84.27597046, 18.49274254], [84.27597046, 18.49263954], [84.2756958, 18.49263954], [84.2756958, 18.49236107], [84.27540588, 18.49236107], [84.27540588, 18.49208069], [84.27513885, 18.4920826], [84.27513885, 18.49180412], [84.27485657, 18.49180984], [84.27485657, 18.49152946], [84.27458191, 18.49152946], [84.27458191, 18.49125099], [84.27403259, 18.49125099], [84.27403259, 18.49097061], [84.27375031, 18.49097252], [84.27375031, 18.49069595], [84.27347565, 18.49069595], [84.27347565, 18.49041748], [84.27319336, 18.49041748], [84.27319336, 18.49013901], [84.2729187, 18.49014091], [84.2729187, 18.48986053], [84.27263641, 18.48986053], [84.27263641, 18.48958015], [84.2720871, 18.48958588], [84.2720871, 18.4893055], [84.27179718, 18.48931122], [84.27179718, 18.48903084], [84.27153015, 18.48903084], [84.27153015, 18.48875046], [84.27124786, 18.48875046], [84.27124786, 18.48847008], [84.27097321, 18.48847389], [84.27097321, 18.48819542], [84.27069855, 18.4881897], [84.27069092, 18.48791695], [84.27041626, 18.48792076], [84.27041626, 18.48764038], [84.26985931, 18.48764038], [84.26985931, 18.48735237], [84.26958466, 18.48736382], [84.26958466, 18.48708344], [84.26930237, 18.48708344], [84.26930237, 18.48680496], [84.26902771, 18.48681068], [84.26902771, 18.4865303], [84.26875305, 18.4865303], [84.26875305, 18.48625183], [84.26847076, 18.48625183], [84.26847076, 18.48596954], [84.26791382, 18.48596954], [84.26791382, 18.48569489], [84.26763916, 18.48569489], [84.26763916, 18.48541641], [84.26735687, 18.48542023], [84.26735687, 18.48514175], [84.26708221, 18.48514175], [84.26708221, 18.48485947], [84.26680756, 18.48485947], [84.26680756, 18.4845829], [84.26652527, 18.4845829], [84.26652527, 18.48430634], [84.26625061, 18.48431015], [84.26625061, 18.48403168], [84.26568604, 18.48403168], [84.26568604, 18.48374939], [84.26541901, 18.48374939], [84.26541901, 18.48347092], [84.26513672, 18.48347282], [84.26513672, 18.48319435], [84.26486206, 18.48319435], [84.26486206, 18.48291588], [84.26457214, 18.48291969], [84.26457214, 18.48264122], [84.26431274, 18.48264122], [84.26431274, 18.48236084], [84.26374817, 18.48236084], [84.26374817, 18.48208046], [84.26347351, 18.48208427], [84.26347351, 18.4818058], [84.26319122, 18.48180962], [84.26319122, 18.48154068], [84.26291656, 18.48154068], [84.26291656, 18.48125076], [84.26264191, 18.48125076], [84.26264191, 18.48097038], [84.26235962, 18.48097229], [84.26235962, 18.48069382], [84.26180267, 18.48069382], [84.26180267, 18.48041725], [84.26152802, 18.48042107], [84.26152802, 18.48014069], [84.26125336, 18.48014069], [84.26125336, 18.47986031], [84.26097107, 18.47986031], [84.26097107, 18.47957993], [84.26069641, 18.47958374], [84.26069641, 18.47930527], [84.26040649, 18.47931099], [84.26040649, 18.47903061], [84.26013947, 18.47903061], [84.26013947, 18.47875023], [84.25958252, 18.47875023], [84.25958252, 18.47846985], [84.25930786, 18.47847176], [84.25930786, 18.47819519], [84.2590332, 18.47820091], [84.2590332, 18.47792053], [84.25875854, 18.47792053], [84.25875854, 18.47764015], [84.25846863, 18.47764015], [84.25846863, 18.47735977], [84.25819397, 18.47736168], [84.25819397, 18.47708321], [84.25763702, 18.47708321], [84.25763702, 18.47680473], [84.25736237, 18.47680473], [84.25736237, 18.47652817], [84.25708008, 18.47653008], [84.25708008, 18.47624969], [84.25680542, 18.47624969], [84.25680542, 18.47597313], [84.25653076, 18.47597313], [84.25653076, 18.47569466], [84.25624847, 18.47569466], [84.25624847, 18.47541618], [84.25569153, 18.47541618], [84.25569153, 18.47513962], [84.25541687, 18.47513962], [84.25541687, 18.47486115], [84.25514221, 18.47486115], [84.25514221, 18.47458267], [84.25485992, 18.47458458], [84.25485992, 18.47430611], [84.2545929, 18.47430992], [84.2545929, 18.47402954], [84.25430298, 18.47402954], [84.25430298, 18.47375107], [84.25402832, 18.47375107], [84.25402832, 18.4734726], [84.25347137, 18.4734726], [84.25347137, 18.47319412], [84.25319672, 18.47319412], [84.25319672, 18.47291756], [84.2529068, 18.47291946], [84.2529068, 18.4726429], [84.25263214, 18.4726429], [84.25263214, 18.47237015], [84.25235748, 18.47237015], [84.25235748, 18.47208023], [84.25208282, 18.47208405], [84.25208282, 18.47180557], [84.25180817, 18.47180939], [84.25180817, 18.47153282], [84.25152588, 18.47153282], [84.25152588, 18.47124863], [84.25125122, 18.47124863], [84.25125122, 18.47096825], [84.25069427, 18.47097015], [84.25069427, 18.47069359], [84.25041962, 18.47069359], [84.25041962, 18.47041893], [84.25013733, 18.47042084], [84.25013733, 18.47013855], [84.24986267, 18.47013855], [84.24986267, 18.46985817], [84.24958038, 18.46986008], [84.24958038, 18.46958351], [84.24930573, 18.46958351], [84.24930573, 18.46930504], [84.24903107, 18.46931076], [84.24903107, 18.46903038], [84.24874878, 18.46903038], [84.24874878, 18.46874809], [84.24846649, 18.46874809], [84.24846649, 18.46846962], [84.24819183, 18.46847153], [84.24819183, 18.46819496], [84.24791718, 18.46820068], [84.24791718, 18.4679203], [84.24736023, 18.4679203], [84.24736023, 18.46763992], [84.2470932, 18.46763992], [84.2470932, 18.46735954], [84.24680328, 18.46736145], [84.24680328, 18.46708298], [84.24652863, 18.46708298], [84.24652863, 18.46680641], [84.24624634, 18.46681023], [84.24624634, 18.46652985], [84.24597168, 18.46652985], [84.24597168, 18.46623993], [84.24569702, 18.46624947], [84.24569702, 18.4659729], [84.24541473, 18.4659729], [84.24541473, 18.46569443], [84.24514008, 18.46569443], [84.24514008, 18.46541405], [84.24485779, 18.46541977], [84.24485779, 18.46513939], [84.24458313, 18.46513939], [84.24458313, 18.46486092], [84.24402618, 18.46486092], [84.24402618, 18.46458054], [84.24375153, 18.46458244], [84.24375153, 18.46430588], [84.24346924, 18.46430969], [84.24346924, 18.46403122], [84.24318695, 18.46403122], [84.24318695, 18.46375084], [84.24291992, 18.46375084], [84.24291992, 18.46347046], [84.24263763, 18.46347237], [84.24263763, 18.4631958], [84.24236298, 18.4631958], [84.24236298, 18.46291733], [84.24208069, 18.46292114], [84.24208069, 18.46264076], [84.24180603, 18.46264076], [84.24180603, 18.46236038], [84.24153137, 18.46236038], [84.24153137, 18.46208], [84.24124908, 18.46208382], [84.24124908, 18.46180534], [84.24069214, 18.46181107], [84.24069214, 18.46153069], [84.24041748, 18.46153069], [84.24041748, 18.46125031], [84.24013519, 18.46125031], [84.24013519, 18.46097374], [84.23986053, 18.46097374], [84.23986053, 18.46069527], [84.23958588, 18.4607029], [84.23958588, 18.46043015], [84.23929596, 18.46043015], [84.23929596, 18.46014023], [84.23902893, 18.46014023], [84.23902893, 18.45986176], [84.23874664, 18.45986366], [84.23874664, 18.45958328], [84.23847198, 18.45958328], [84.23847198, 18.45930481], [84.23819733, 18.45930481], [84.23819733, 18.45902824], [84.23792267, 18.45903015], [84.23792267, 18.45875168], [84.23735809, 18.45875168], [84.23735809, 18.45846939], [84.23708344, 18.45846939], [84.23708344, 18.45819473], [84.23680878, 18.45819473], [84.23680878, 18.45791626], [84.23652649, 18.45792007], [84.23652649, 18.4576416], [84.23625183, 18.4576416], [84.23625183, 18.45737267], [84.23596954, 18.45737267], [84.23596954, 18.45708084], [84.23569489, 18.45708275], [84.23569489, 18.45680618], [84.23542023, 18.4568119], [84.23542023, 18.45652771], [84.23513794, 18.45652771], [84.23513794, 18.45624924], [84.23486328, 18.45624924], [84.23486328, 18.45597076], [84.23458099, 18.45597267], [84.23458099, 18.4556942], [84.23402405, 18.4556942], [84.23402405, 18.45541954], [84.23374939, 18.45541954], [84.23374939, 18.45513916], [84.2334671, 18.45513916], [84.2334671, 18.45486069], [84.23319244, 18.45486069], [84.23319244, 18.45458031], [84.23291779, 18.45458412], [84.23291779, 18.45430565], [84.2326355, 18.45430565], [84.2326355, 18.45402718], [84.23236084, 18.45403099], [84.23236084, 18.45375061], [84.23208618, 18.45375061], [84.23208618, 18.45347023], [84.23180389, 18.45347214], [84.23180389, 18.45319366], [84.23152924, 18.45319366], [84.23152924, 18.45291519], [84.23124695, 18.45292091], [84.23124695, 18.45264053], [84.23069763, 18.45264053], [84.23069763, 18.45236015], [84.23041534, 18.45236206], [84.23041534, 18.45208359], [84.23014069, 18.45208359], [84.23014069, 18.45180511], [84.2298584, 18.45181084], [84.2298584, 18.45153046], [84.22957611, 18.45153046], [84.22957611, 18.45124054], [84.22930908, 18.45125008], [84.22930908, 18.4509716], [84.22902679, 18.4509716], [84.22902679, 18.45069695], [84.22875214, 18.45070076], [84.22875214, 18.45042038], [84.22846222, 18.45042038], [84.22846222, 18.45014], [84.22820282, 18.45014], [84.22820282, 18.44985962], [84.2279129, 18.44986153], [84.2279129, 18.44958305], [84.22763824, 18.44958305], [84.22763824, 18.44930649], [84.22735596, 18.4493103], [84.22735596, 18.44902992], [84.22680664, 18.44902992], [84.22680664, 18.44874954], [84.22651672, 18.44874954], [84.22651672, 18.44847107], [84.22624969, 18.44847488], [84.22624969, 18.4481945], [84.22597504, 18.4481945], [84.22597504, 18.44791603], [84.22569275, 18.44791985], [84.22569275, 18.44763947], [84.22541809, 18.44763947], [84.22541809, 18.4473629], [84.2251358, 18.4473629], [84.2251358, 18.44708061], [84.22486115, 18.44708061], [84.22486115, 18.44680595], [84.22458649, 18.44680977], [84.22458649, 18.44652939], [84.22429657, 18.44652939], [84.22429657, 18.44625282], [84.22402954, 18.44625282], [84.22402954, 18.44597244], [84.22374725, 18.44597244], [84.22374725, 18.44569206], [84.2234726, 18.44569206], [84.2234726, 18.4454174], [84.22292328, 18.44543076], [84.22292328, 18.44514275], [84.22264862, 18.44514275], [84.22264862, 18.44486237], [84.2223587, 18.44486237], [84.2223587, 18.44457817], [84.22208405, 18.44458389], [84.22208405, 18.44430542], [84.22180176, 18.44430923], [84.22180176, 18.44403076], [84.2215271, 18.44403076], [84.2215271, 18.44374847], [84.22125244, 18.44374847], [84.22125244, 18.44346809], [84.22097015, 18.44347191], [84.22097015, 18.44319534], [84.22070313, 18.44319916], [84.22070313, 18.44292068], [84.22041321, 18.44292068], [84.22041321, 18.4426384], [84.22013855, 18.4426384], [84.22013855, 18.44235992], [84.21986389, 18.44236183], [84.21986389, 18.44208336], [84.2195816, 18.44208336], [84.2195816, 18.44180489], [84.21902466, 18.44180489], [84.21902466, 18.44152641], [84.21875, 18.44152832], [84.21875, 18.44124985], [84.21847534, 18.44124985], [84.21847534, 18.44097137], [84.21819305, 18.44097137], [84.21819305, 18.44069481], [84.2179184, 18.44069481], [84.2179184, 18.44041634], [84.21763611, 18.44042015], [84.21763611, 18.44013977], [84.21736145, 18.44013977], [84.21736145, 18.43985939], [84.21708679, 18.4398613], [84.21708679, 18.43958282], [84.2168045, 18.43958282], [84.2168045, 18.43930626], [84.21652985, 18.43930626], [84.21652985, 18.43902779], [84.21624756, 18.43902969], [84.21624756, 18.43875122], [84.2159729, 18.43875122], [84.2159729, 18.43847084], [84.21569824, 18.43847275], [84.21569061, 18.43819427], [84.21541595, 18.43819427], [84.21541595, 18.4379158], [84.2151413, 18.43791962], [84.2151413, 18.43764114], [84.21485901, 18.43764114], [84.21485901, 18.43736076], [84.21457672, 18.43736076], [84.21457672, 18.43708038], [84.21430206, 18.4370842], [84.21430206, 18.43680573], [84.2140274, 18.43680954], [84.2140274, 18.43653107], [84.21346283, 18.43653107], [84.21346283, 18.43626022], [84.2131958, 18.43626022], [84.2131958, 18.43597031], [84.21291351, 18.43597221], [84.21291351, 18.43569374], [84.21263885, 18.43569374], [84.21263885, 18.43541718], [84.21235657, 18.43542099], [84.21235657, 18.43514061], [84.21208191, 18.43514061], [84.21208191, 18.43486023], [84.21180725, 18.43486023], [84.21180725, 18.43457985], [84.21152496, 18.43458366], [84.21152496, 18.43430519], [84.21125031, 18.43431091], [84.21125031, 18.43403053], [84.21098328, 18.43403053], [84.21098328, 18.43375015], [84.21069336, 18.43375015], [84.21069336, 18.43346977], [84.2104187, 18.43347359], [84.2104187, 18.43319511], [84.21013641, 18.43320274], [84.21013641, 18.43292046], [84.20986176, 18.43292046], [84.20986176, 18.4323616], [84.2095871, 18.4323616], [84.2095871, 18.43208122], [84.20930481, 18.43208122], [84.20930481, 18.43180466], [84.20903015, 18.43180466], [84.20903015, 18.43152809], [84.20874786, 18.43153191], [84.20874786, 18.43125153], [84.20847321, 18.43125153], [84.20847321, 18.43096924], [84.20819092, 18.43097305], [84.20819092, 18.43069458], [84.20791626, 18.43069458], [84.20791626, 18.43041611], [84.2076416, 18.43042183], [84.2076416, 18.43014145], [84.20707703, 18.43014145], [84.20707703, 18.42985916], [84.20680237, 18.42985916], [84.20680237, 18.42958069], [84.20652771, 18.4295826], [84.20652771, 18.42930603], [84.20625305, 18.42930984], [84.20625305, 18.42902756], [84.20597076, 18.42902756], [84.20597076, 18.42874908], [84.20569611, 18.42874908], [84.20569611, 18.42847061], [84.20541382, 18.42847252], [84.20541382, 18.42819405], [84.20513916, 18.42819405], [84.20513916, 18.42791748], [84.20485687, 18.42791748], [84.20485687, 18.42764091], [84.2040329, 18.42764091], [84.2040329, 18.42736053], [84.20375061, 18.42736053], [84.20375061, 18.42707062], [84.20319366, 18.42708397], [84.20319366, 18.4268055], [84.20291901, 18.42681122], [84.20291901, 18.42653084], [84.20263672, 18.42653084], [84.20263672, 18.42625046], [84.20207977, 18.42625046], [84.20207977, 18.42570114], [84.20181274, 18.4256897], [84.20180511, 18.42541695], [84.20207977, 18.42542076], [84.20207977, 18.42514038], [84.20181274, 18.42514038], [84.20181274, 18.42486], [84.20153046, 18.42486191], [84.20153046, 18.42458344], [84.20097351, 18.42458344], [84.20097351, 18.42430687], [84.20069122, 18.42432022], [84.20069122, 18.4240303], [84.20041656, 18.4240303], [84.20041656, 18.42374992], [84.20014191, 18.42374992], [84.20014191, 18.42346954], [84.19985962, 18.42347145], [84.19985962, 18.42319489], [84.19958496, 18.42319489], [84.19958496, 18.42291641], [84.19902802, 18.42292023], [84.19902802, 18.42263985], [84.19875336, 18.42263985], [84.19875336, 18.42235947], [84.19847107, 18.42236137], [84.19847107, 18.42208481], [84.19819641, 18.42208481], [84.19819641, 18.42180634], [84.19790649, 18.42181015], [84.19790649, 18.42152977], [84.19763947, 18.42152977], [84.19763947, 18.42126083], [84.19708252, 18.42126083], [84.19708252, 18.42097282], [84.19680786, 18.42097282], [84.19680786, 18.42069435], [84.19652557, 18.42069435], [84.19652557, 18.42041588], [84.19596863, 18.42041969], [84.19596863, 18.42014122], [84.19568634, 18.42014122], [84.19568634, 18.41958046], [84.19541931, 18.41958427], [84.19541931, 18.41902733], [84.19513702, 18.41903114], [84.19513702, 18.41875267], [84.19486237, 18.41875267], [84.19486237, 18.41792107], [84.19431305, 18.41792107], [84.19431305, 18.41764069], [84.19403076, 18.41764069], [84.19403076, 18.4173584], [84.19374847, 18.4173584], [84.19374847, 18.41707993], [84.19347382, 18.41708374], [84.19347382, 18.41680527], [84.19319153, 18.41680908], [84.19319153, 18.41653061], [84.19291687, 18.41653061], [84.19291687, 18.41624832], [84.19264221, 18.41624832], [84.19264221, 18.41596985], [84.19208527, 18.41597176], [84.19208527, 18.41569519], [84.19180298, 18.41570091], [84.19180298, 18.41542053], [84.19097137, 18.41542053], [84.19097137, 18.41513062], [84.19041443, 18.41513824], [84.19041443, 18.41486168], [84.19013977, 18.41486168], [84.19013977, 18.41458321], [84.18985748, 18.41458321], [84.18985748, 18.41402626], [84.18930817, 18.41402817], [84.18930817, 18.41374969], [84.18902588, 18.41374969], [84.18902588, 18.41347122], [84.18875122, 18.41347313], [84.18875122, 18.41319466], [84.18846893, 18.41319466], [84.18846893, 18.41236115], [84.18818665, 18.41236115], [84.18818665, 18.41207123], [84.18791962, 18.41208267], [84.18791962, 18.4118042], [84.18763733, 18.41180992], [84.18763733, 18.41152954], [84.18736267, 18.41152954], [84.18736267, 18.41125107], [84.18708038, 18.41125107], [84.18708038, 18.41097069], [84.18680573, 18.4109726], [84.18680573, 18.41069412], [84.18653107, 18.41069412], [84.18653107, 18.41041756], [84.18624878, 18.41041946], [84.18624878, 18.41014099], [84.18596649, 18.41014099], [84.18596649, 18.40958023], [84.18569183, 18.40958595], [84.18569183, 18.40930557], [84.18541718, 18.40932083], [84.18541718, 18.40903091], [84.18514252, 18.40903091], [84.18514252, 18.40875053], [84.18486023, 18.40875053], [84.18486023, 18.40847015], [84.18458557, 18.40847206], [84.18458557, 18.40819359], [84.18430328, 18.40819359], [84.18430328, 18.40791702], [84.18402863, 18.40792084], [84.18402863, 18.40764046], [84.18374634, 18.40764046], [84.18374634, 18.40736008], [84.18347168, 18.40736389], [84.18347168, 18.40708351], [84.18319702, 18.40708351], [84.18319702, 18.40680504], [84.1829071, 18.40681076], [84.1829071, 18.40653038], [84.18264008, 18.40653038], [84.18264008, 18.40625954], [84.18235779, 18.40625954], [84.18235779, 18.40596962], [84.18208313, 18.40596962], [84.18208313, 18.40569496], [84.18180847, 18.40570068], [84.18180847, 18.4054203], [84.18152618, 18.4054203], [84.18152618, 18.40514183], [84.18125153, 18.40514183], [84.18125153, 18.40485954], [84.18096924, 18.40485954], [84.18096924, 18.40458107], [84.18069458, 18.40458107], [84.18069458, 18.40430641], [84.18041229, 18.40431023], [84.18041229, 18.40403175], [84.17986298, 18.40403175], [84.17986298, 18.40375137], [84.17958069, 18.40375137], [84.17958069, 18.40346909], [84.17930603, 18.4034729], [84.17930603, 18.40319443], [84.17903137, 18.40319443], [84.17903137, 18.40291595], [84.17874908, 18.40291977], [84.17874908, 18.40263748], [84.1784668, 18.40263748], [84.1784668, 18.40236092], [84.17819214, 18.40236092], [84.17819214, 18.40208054], [84.17791748, 18.40208244], [84.17791748, 18.40180588], [84.17764282, 18.40180969], [84.17764282, 18.40153122], [84.17735291, 18.40153122], [84.17735291, 18.40125084], [84.17708588, 18.40125084], [84.17708588, 18.40097046], [84.17680359, 18.40097237], [84.17680359, 18.40069389], [84.17652893, 18.40069389], [84.17652893, 18.40041733], [84.17624664, 18.40042114], [84.17624664, 18.40013123], [84.17597198, 18.40013885], [84.17597198, 18.39986038], [84.17569733, 18.39986038], [84.17569733, 18.39958], [84.17541504, 18.39958382], [84.17541504, 18.39930534], [84.17514038, 18.39931107], [84.17514038, 18.39875031], [84.17485809, 18.39875031], [84.17485809, 18.39846992], [84.17458344, 18.39847183], [84.17458344, 18.39819527], [84.17430878, 18.39820099], [84.17430878, 18.39792061], [84.17402649, 18.39792061], [84.17402649, 18.39764023], [84.17375183, 18.39764023], [84.17375183, 18.39735985], [84.17346954, 18.39736176], [84.17346954, 18.39708328], [84.17318726, 18.39709091], [84.17318726, 18.39680099], [84.17292023, 18.39680481], [84.17292023, 18.39652824], [84.17263794, 18.39653015], [84.17263794, 18.39624977], [84.17236328, 18.39624977], [84.17236328, 18.39596939], [84.17208099, 18.3959713], [84.17208099, 18.39569473], [84.17180634, 18.39569473], [84.17180634, 18.39541626], [84.17151642, 18.39542007], [84.17151642, 18.39486122], [84.17124939, 18.39486122], [84.17124939, 18.39458275], [84.17097473, 18.39458466], [84.17097473, 18.39430618], [84.17069244, 18.39431953], [84.17069244, 18.39402962], [84.17041779, 18.39402962], [84.17041779, 18.39375114], [84.17014313, 18.39375114], [84.17014313, 18.39347267], [84.16986084, 18.39347267], [84.16986084, 18.3931942], [84.16958618, 18.3931942], [84.16958618, 18.39291763], [84.16929626, 18.39291954], [84.16929626, 18.39264107], [84.16902924, 18.39264107], [84.16902924, 18.39236259], [84.16874695, 18.39236259], [84.16874695, 18.39208031], [84.16847229, 18.39208412], [84.16847229, 18.39180565], [84.16819763, 18.39180946], [84.16819763, 18.3915329], [84.16792297, 18.3915329], [84.16792297, 18.3912487], [84.16764069, 18.3912487], [84.16764069, 18.39096069], [84.1673584, 18.39097023], [84.1673584, 18.39069366], [84.16708374, 18.39069366], [84.16708374, 18.3904171], [84.16680908, 18.39042091], [84.16680908, 18.39014053], [84.16652679, 18.39014053], [84.16652679, 18.38985825], [84.16625214, 18.38986015], [84.16625214, 18.38958359], [84.16596985, 18.38958359], [84.16596985, 18.38930511], [84.16570282, 18.38931084], [84.16570282, 18.38874817], [84.1654129, 18.38874817], [84.1654129, 18.3884697], [84.16513824, 18.3884716], [84.16513824, 18.38819504], [84.16486359, 18.38819504], [84.16486359, 18.38791656], [84.1645813, 18.38792038], [84.1645813, 18.38763809], [84.16430664, 18.38763809], [84.16430664, 18.38735962], [84.16402435, 18.38736153], [84.16402435, 18.38708305], [84.16374969, 18.38708305], [84.16374969, 18.38680649], [84.16348267, 18.3868103], [84.16348267, 18.38652992], [84.16319275, 18.38652992], [84.16319275, 18.38624954], [84.16291809, 18.38624954], [84.16291809, 18.38597107], [84.1626358, 18.38597298], [84.1626358, 18.3856945], [84.16236115, 18.3856945], [84.16236115, 18.38541412], [84.16208649, 18.38541985], [84.16208649, 18.38515091], [84.16179657, 18.38515091], [84.16179657, 18.38486099], [84.16152954, 18.38486099], [84.16152954, 18.38458061], [84.16124725, 18.38458252], [84.16124725, 18.38430405], [84.1609726, 18.38430977], [84.1609726, 18.38402939], [84.16069794, 18.38402939], [84.16069794, 18.38375092], [84.16041565, 18.38375092], [84.16041565, 18.38347244], [84.16014099, 18.38347244], [84.16014099, 18.38319588], [84.1598587, 18.38319588], [84.1598587, 18.3829174], [84.15957642, 18.38292122], [84.15957642, 18.38264084], [84.15930939, 18.38264084], [84.15930939, 18.38236046], [84.1590271, 18.38236046], [84.1590271, 18.38208961], [84.15875244, 18.38208961], [84.15875244, 18.38181114], [84.15847015, 18.38181114], [84.15847015, 18.38153076], [84.15820312, 18.38153076], [84.15820312, 18.38125038], [84.15791321, 18.38125038], [84.15791321, 18.38097191], [84.15763855, 18.38097382], [84.15763855, 18.38069534], [84.15735626, 18.38070107], [84.15735626, 18.38042068], [84.1570816, 18.38042068], [84.1570816, 18.3801403], [84.15680695, 18.3801403], [84.15680695, 18.37986183], [84.15652466, 18.37986374], [84.15652466, 18.37958336], [84.15625, 18.37958336], [84.15625, 18.37930489], [84.15597534, 18.37930489], [84.15597534, 18.37902832], [84.15569305, 18.37902832], [84.15569305, 18.37875175], [84.1554184, 18.37875175], [84.1554184, 18.37846947], [84.15513611, 18.37846947], [84.15513611, 18.37819481], [84.15486145, 18.37819481], [84.15486145, 18.37791634], [84.15458679, 18.37792015], [84.15458679, 18.37764168], [84.15429688, 18.37764168], [84.15429688, 18.37735939], [84.15402985, 18.37735939], [84.15402985, 18.37708282], [84.15374756, 18.37708282], [84.15374756, 18.37680626], [84.1534729, 18.37681007], [84.1534729, 18.3765316], [84.15319824, 18.3765316], [84.15318298, 18.3759594], [84.15291595, 18.37597275], [84.15291595, 18.37569427], [84.1526413, 18.37569427], [84.1526413, 18.3754158], [84.15235901, 18.37541962], [84.15235901, 18.37514114], [84.15207672, 18.37514114], [84.15207672, 18.37486076], [84.15180206, 18.37486076], [84.15180206, 18.37458038], [84.1515274, 18.3745842], [84.1515274, 18.37430573], [84.15125275, 18.37430954], [84.15125275, 18.37403107], [84.15097046, 18.37403107], [84.15097046, 18.37375069], [84.1506958, 18.37375069], [84.1506958, 18.37347031], [84.15041351, 18.37347221], [84.15041351, 18.37291527], [84.15013885, 18.37292099], [84.15013885, 18.37236023], [84.14958191, 18.37236023], [84.14958191, 18.37207985], [84.14930725, 18.37208366], [84.14930725, 18.37180519], [84.14903259, 18.37181091], [84.14903259, 18.37125015], [84.14875031, 18.37125015], [84.14875031, 18.37042046], [84.14848328, 18.37042046], [84.14848328, 18.3698597], [84.14819336, 18.3698616], [84.14819336, 18.36930466], [84.1479187, 18.36930466], [84.1479187, 18.36874962], [84.14763641, 18.36874962], [84.14763641, 18.36847115], [84.14736176, 18.36847305], [84.14736176, 18.36819458], [84.1470871, 18.36819458], [84.1470871, 18.36736107], [84.14679718, 18.36736107], [84.14679718, 18.36652946], [84.14653015, 18.36652946], [84.14653015, 18.36597252], [84.14624786, 18.36597252], [84.14624786, 18.36569405], [84.14597321, 18.36569405], [84.14597321, 18.36402702], [84.14569092, 18.36402702], [84.14569092, 18.36374855], [84.14541626, 18.36374855], [84.14541626, 18.36319923], [84.1451416, 18.3631897], [84.1451416, 18.36263847], [84.14485931, 18.36263847], [84.14485931, 18.36235809], [84.14430237, 18.36236191], [84.14430237, 18.36208344], [84.14402771, 18.36208344], [84.14402771, 18.36124992], [84.14375305, 18.36124992], [84.14375305, 18.36086273], [84.14375305, 18.36069489], [84.14347076, 18.36069489], [84.14347076, 18.36013985], [84.14319611, 18.36013985], [84.14319611, 18.35985947], [84.14291382, 18.35986137], [84.14291382, 18.35930634], [84.14263916, 18.35931015], [84.14263916, 18.35874939], [84.14235687, 18.35874939], [84.14235687, 18.35847092], [84.14208221, 18.35847282], [84.14208221, 18.35819435], [84.14180756, 18.35819435], [84.14180756, 18.35791588], [84.1415329, 18.35791969], [84.1415329, 18.35764122], [84.14124298, 18.35764122], [84.14124298, 18.35680962], [84.14097595, 18.35680962], [84.14097595, 18.35625076], [84.14068604, 18.35625076], [84.14068604, 18.35597038], [84.14041901, 18.35597229], [84.14041901, 18.35569382], [84.14013672, 18.35569382], [84.14013672, 18.35541725], [84.13986206, 18.35542107], [84.13986206, 18.35485268], [84.13957977, 18.35486031], [84.13957977, 18.35458374], [84.13930511, 18.35458374], [84.13930511, 18.3540287], [84.13903046, 18.35403061], [84.13903046, 18.35375023], [84.13874817, 18.35375023], [84.13874817, 18.35320282], [84.13846588, 18.35320282], [84.13846588, 18.35264015], [84.13819885, 18.35264015], [84.13819885, 18.35178947], [84.13791656, 18.35180473], [84.13791656, 18.3512516], [84.13764191, 18.3512516], [84.13764191, 18.35069084], [84.13735962, 18.35069466], [84.13735962, 18.34985924], [84.13708496, 18.34985924], [84.13708496, 18.34930611], [84.13652802, 18.34930992], [84.13652802, 18.34903908], [84.13597107, 18.34903908], [84.13597107, 18.34874916], [84.13569641, 18.34874916], [84.13569641, 18.34847069], [84.13541412, 18.3484726], [84.13541412, 18.34819412], [84.13513947, 18.34819412], [84.13513947, 18.34791946], [84.13485718, 18.34791946], [84.13485718, 18.34763908], [84.13458252, 18.34763908], [84.13458252, 18.34736061], [84.13430786, 18.34736061], [84.13430786, 18.34708405], [84.13319397, 18.34708405], [84.13319397, 18.34680557], [84.13208008, 18.34680939], [84.13208008, 18.34736061], [84.13180542, 18.34736061], [84.13180542, 18.3484726], [84.13124847, 18.34847069], [84.13124847, 18.34930992], [84.13041687, 18.34930611], [84.13041687, 18.34958267], [84.12985992, 18.34958076], [84.12985992, 18.34985924], [84.12930298, 18.34985924], [84.12930298, 18.35014153], [84.12902832, 18.35014153], [84.12902832, 18.35042191], [84.12847137, 18.35041618], [84.12847137, 18.35069466], [84.12819672, 18.35069466], [84.12819672, 18.35097313], [84.1279068, 18.35096931], [84.1279068, 18.3512516], [84.12708282, 18.3512516], [84.12708282, 18.35153008], [84.12652588, 18.35152817], [84.12652588, 18.35180473], [84.12596893, 18.35180473], [84.12596893, 18.35152817], [84.12568665, 18.35153008], [84.12568665, 18.3512516], [84.12596893, 18.3512516], [84.12596893, 18.35096931], [84.12625122, 18.35097313], [84.12625122, 18.35069466], [84.12680817, 18.35069466], [84.12680817, 18.35014153], [84.12708282, 18.35014153], [84.12708282, 18.34958076], [84.12735748, 18.34958267], [84.12735748, 18.34930611], [84.12763977, 18.34930992], [84.12763977, 18.34903908], [84.12735748, 18.34903908], [84.12735748, 18.34819031], [84.12708282, 18.34819412], [84.12708282, 18.34680557], [84.12735748, 18.34680939], [84.12735748, 18.34653091], [84.1279068, 18.34653091], [84.1279068, 18.34680939], [84.12819672, 18.34680557], [84.12819672, 18.34708405], [84.1279068, 18.34708023], [84.1279068, 18.34791946], [84.12819672, 18.34791946], [84.12819672, 18.34763908], [84.12847137, 18.34763908], [84.12847137, 18.34736061], [84.12874603, 18.34736061], [84.12874603, 18.34708023], [84.12902832, 18.34708405], [84.12902832, 18.34597206], [84.12847137, 18.34597969], [84.12847137, 18.34568977], [84.12819672, 18.34569359], [84.12819672, 18.34541512], [84.1279068, 18.34542084], [84.1279068, 18.34514046], [84.12819672, 18.34514046], [84.12819672, 18.34486008], [84.12875366, 18.34486198], [84.12875366, 18.34458351], [84.12902832, 18.34458351], [84.12902832, 18.34430695], [84.12930298, 18.34431076], [84.12930298, 18.34320068], [84.12847137, 18.34320068], [84.12847137, 18.34291077], [84.12625885, 18.34291077], [84.12625885, 18.34320068], [84.12569427, 18.34319305], [84.12569427, 18.34347153], [84.12486267, 18.34347153], [84.12486267, 18.34319305], [84.12431335, 18.34320068], [84.12431335, 18.34291077], [84.12486267, 18.34291649], [84.12486267, 18.34263802], [84.12513733, 18.34263992], [84.12513733, 18.34235954], [84.12569427, 18.34236145], [84.12569427, 18.34208488], [84.12596893, 18.34208488], [84.12596893, 18.34152794], [84.12625885, 18.34152985], [84.12625885, 18.34124947], [84.12680817, 18.34124947], [84.12680817, 18.3409729], [84.12735748, 18.34097481], [84.12735748, 18.34041595], [84.12708282, 18.34041977], [84.12708282, 18.33992195], [84.12680817, 18.33987045], [84.12680817, 18.33903122], [84.12652588, 18.33903122], [84.12652588, 18.33847237], [84.12680817, 18.33847237], [84.12680817, 18.33708382], [84.12708282, 18.33708382], [84.12708282, 18.33680534], [84.12735748, 18.33680916], [84.12735748, 18.3362484], [84.12708282, 18.3362484], [84.12708282, 18.33513832], [84.12680817, 18.33513832], [84.12680817, 18.33403969], [84.12652588, 18.33403969], [84.12652588, 18.33292007], [84.12625885, 18.33292007], [84.12625885, 18.33181], [84.12596893, 18.33181], [84.12596893, 18.33014107], [84.12568665, 18.33014107], [84.12568665, 18.32875061], [84.12541962, 18.32875061], [84.12541962, 18.32818985], [84.12486267, 18.32819366], [84.12486267, 18.32847214], [84.12458038, 18.32847023], [84.12458038, 18.32875061], [84.12346649, 18.32875061], [84.12346649, 18.32707977], [84.12374878, 18.32708359], [84.12374878, 18.32652855], [84.12403107, 18.32653046], [84.12403107, 18.32570267], [84.12431335, 18.32570267], [84.12431335, 18.32542038], [84.12458038, 18.32542038], [84.12458038, 18.32514191], [84.12486267, 18.32514191], [84.12486267, 18.32484818], [84.12513733, 18.32486153], [84.12513733, 18.32458115], [84.12596893, 18.32457924], [84.12596893, 18.32570267], [84.12625122, 18.32569504], [84.12625122, 18.32625008], [84.12680817, 18.32625008], [84.12680817, 18.32653046], [84.12708282, 18.32653046], [84.12708282, 18.32625008], [84.12735748, 18.32625008], [84.12735748, 18.32484818], [84.12763977, 18.32486153], [84.12763977, 18.32291603], [84.1279068, 18.32291985], [84.1279068, 18.32069016], [84.12819672, 18.32069397], [84.12819672, 18.31958389], [84.12847137, 18.31958389], [84.12847137, 18.31902695], [84.12874603, 18.31903076], [84.12874603, 18.31847], [84.12902832, 18.31847191], [84.12902832, 18.31819534], [84.12930298, 18.31820107], [84.12930298, 18.3176403], [84.1295929, 18.3176403], [84.1295929, 18.31680107], [84.12930298, 18.31680489], [84.12930298, 18.31597137], [84.12958527, 18.31597137], [84.12958527, 18.31569481], [84.12985992, 18.31569481], [84.12985992, 18.31513977], [84.12958527, 18.31513977], [84.12958527, 18.31430626], [84.12902832, 18.31431007], [84.12902832, 18.31402969], [84.12847137, 18.31402969], [84.12847137, 18.31375122], [84.12819672, 18.31375122], [84.12819672, 18.31347275], [84.12763977, 18.31347275], [84.12763977, 18.31319427], [84.12735748, 18.31319427], [84.12735748, 18.3129158], [84.12708282, 18.3129158], [84.12708282, 18.3120842], [84.12680817, 18.3120842], [84.12680817, 18.31152725], [84.12652588, 18.31153107], [84.12652588, 18.31125259], [84.12596893, 18.31125259], [84.12596893, 18.3109684], [84.12569427, 18.31097031], [84.12569427, 18.31041718], [84.12541962, 18.31041908], [84.12541962, 18.31014061], [84.12513733, 18.31014061], [84.12513733, 18.30987167], [84.12486267, 18.30987167], [84.12486267, 18.30957985], [84.12458038, 18.30958366], [84.12458038, 18.30930519], [84.12403107, 18.30931091], [84.12403107, 18.30903053], [84.12346649, 18.30903053], [84.12346649, 18.30874825], [84.12291718, 18.30874825], [84.12291718, 18.30846977], [84.12264252, 18.30847168], [84.12264252, 18.30819511], [84.1220932, 18.30820084], [84.1220932, 18.30792046], [84.12097168, 18.30792046], [84.12097168, 18.30820084], [84.12014008, 18.30820084], [84.12014008, 18.30792046], [84.11985779, 18.30792046], [84.11985779, 18.30763817], [84.11958313, 18.30763817], [84.11958313, 18.3073597], [84.11902618, 18.3073616], [84.11902618, 18.30708313], [84.11875153, 18.30708313], [84.11875153, 18.30680466], [84.11859894, 18.30680847], [84.11846924, 18.30681038], [84.11846924, 18.30652809], [84.11818695, 18.30652809], [84.11818695, 18.30624962], [84.11763763, 18.30624962], [84.11763763, 18.30597115], [84.11708069, 18.30597305], [84.11708069, 18.30569458], [84.11680603, 18.30569458], [84.11680603, 18.30541611], [84.11624908, 18.30541992], [84.11624908, 18.30513954], [84.11569214, 18.30513954], [84.11569214, 18.30486107], [84.11541748, 18.30486107], [84.11541748, 18.30458069], [84.11486053, 18.3045826], [84.11486053, 18.30430412], [84.11429596, 18.30430984], [84.11429596, 18.30402946], [84.11402893, 18.30402946], [84.11402893, 18.30373955], [84.11347198, 18.30374908], [84.11347198, 18.30347252], [84.11319733, 18.30347252], [84.11319733, 18.30319595], [84.11264038, 18.30319595], [84.11264038, 18.30291748], [84.11207581, 18.30291939], [84.11207581, 18.30264091], [84.11180878, 18.30264091], [84.11180878, 18.30236053], [84.11125183, 18.30236053], [84.11125183, 18.30208206], [84.11069489, 18.30208206], [84.11069489, 18.3018055], [84.11042023, 18.30181122], [84.11042023, 18.30153084], [84.10986328, 18.30153084], [84.10986328, 18.30125046], [84.10930634, 18.30125046], [84.10930634, 18.30097008], [84.10902405, 18.30097389], [84.10902405, 18.30069542], [84.1084671, 18.30068016], [84.10847473, 18.30041695], [84.10791779, 18.30042076], [84.10791779, 18.30014038], [84.10764313, 18.30014038], [84.10764313, 18.29986191], [84.10708618, 18.29986382], [84.10708618, 18.29958344], [84.10652924, 18.29958344], [84.10652924, 18.29930496], [84.10624695, 18.29931068], [84.10624695, 18.2990303], [84.10569763, 18.2990303], [84.10569763, 18.29875183], [84.10513306, 18.29875183], [84.10513306, 18.29846954], [84.1048584, 18.29846954], [84.1048584, 18.29819489], [84.10430908, 18.29819489], [84.10430908, 18.29791641], [84.10375214, 18.29792976], [84.10375214, 18.29764175], [84.10346985, 18.29764175], [84.10346985, 18.29735947], [84.1029129, 18.29735947], [84.1029129, 18.2970829], [84.10263824, 18.2970829], [84.10263824, 18.29680634], [84.10206604, 18.29681015], [84.10206604, 18.29653168], [84.10151672, 18.29653168], [84.10151672, 18.29624748], [84.10124969, 18.29624748], [84.10124969, 18.29597092], [84.10069275, 18.29597282], [84.10069275, 18.29569435], [84.1001358, 18.29569435], [84.1001358, 18.29541588], [84.09986115, 18.29541969], [84.09986115, 18.29514122], [84.09929657, 18.29514122], [84.09929657, 18.29486847], [84.09874725, 18.29486847], [84.09874725, 18.29458046], [84.0984726, 18.29458427], [84.0984726, 18.2943058], [84.09792328, 18.29430962], [84.09792328, 18.29403114], [84.0973587, 18.29403114], [84.0973587, 18.29375076], [84.09680176, 18.29375076], [84.09680176, 18.29347038], [84.0965271, 18.29347229], [84.0965271, 18.29319382], [84.09597015, 18.29319382], [84.09597015, 18.29291534], [84.09541321, 18.29292107], [84.09541321, 18.29264069], [84.09485626, 18.29264069], [84.09485626, 18.29236031], [84.0945816, 18.29236031], [84.0945816, 18.29207993], [84.09402466, 18.29208374], [84.09402466, 18.29180527], [84.09347534, 18.29180527], [84.09347534, 18.2915287], [84.0929184, 18.29153061], [84.0929184, 18.29125023], [84.09263611, 18.29125023], [84.09263611, 18.29096985], [84.09208679, 18.29097176], [84.09208679, 18.29069519], [84.09152985, 18.29070091], [84.09152985, 18.29042053], [84.09124756, 18.29042053], [84.09124756, 18.29014015], [84.09069824, 18.29014015], [84.09069061, 18.28985977], [84.0901413, 18.28986168], [84.0901413, 18.28958321], [84.08958435, 18.28958321], [84.08958435, 18.28930473], [84.08930206, 18.28930473], [84.08930206, 18.28902817], [84.08875275, 18.28903008], [84.08875275, 18.28874016], [84.08847046, 18.28874016], [84.08847046, 18.28903008], [84.08790588, 18.28903008], [84.08790588, 18.28874016], [84.08763885, 18.28874969], [84.08763885, 18.28819466], [84.0873642, 18.28819466], [84.0873642, 18.28791618], [84.08598328, 18.28792], [84.08598328, 18.28763962], [84.08569336, 18.28763962], [84.08569336, 18.28541946], [84.0854187, 18.28541946], [84.0854187, 18.2851429], [84.08513641, 18.2851429], [84.08513641, 18.28486252], [84.08486176, 18.28486252], [84.08486176, 18.28457832], [84.08430481, 18.28458405], [84.08430481, 18.28430557], [84.08403015, 18.28430939], [84.08403015, 18.28403091], [84.08374786, 18.28403091], [84.08374786, 18.28374863], [84.08403015, 18.28374863], [84.08403015, 18.28346825], [84.08291626, 18.28347015], [84.08291626, 18.28319359], [84.08208466, 18.28319359], [84.08208466, 18.28291893], [84.08180237, 18.28293037], [84.08180237, 18.28264046], [84.08152771, 18.28264046], [84.08152771, 18.28235817], [84.08097076, 18.28236008], [84.08097076, 18.28208351], [84.08069611, 18.28208351], [84.08069611, 18.28153038], [84.07985687, 18.28153038], [84.07985687, 18.28124809], [84.07958221, 18.28124809], [84.07958221, 18.28096962], [84.07930756, 18.28097153], [84.07930756, 18.28069496], [84.07847595, 18.28070068], [84.07847595, 18.2804203], [84.07818604, 18.2804203], [84.07818604, 18.28013992], [84.07763672, 18.28013992], [84.07763672, 18.27985954], [84.07736206, 18.27986145], [84.07736206, 18.27958298], [84.07707977, 18.27958298], [84.07707977, 18.27902794], [84.07681274, 18.27902985], [84.07681274, 18.27874947], [84.07653046, 18.27874947], [84.07653046, 18.27819061], [84.07624817, 18.27819443], [84.07624817, 18.27791405], [84.07596588, 18.27791977], [84.07596588, 18.27763939], [84.07541656, 18.27763939], [84.07541656, 18.27736092], [84.07457733, 18.27736092], [84.07457733, 18.27708054], [84.07402802, 18.27708244], [84.07402802, 18.27680588], [84.07375336, 18.27680588], [84.07375336, 18.2765274], [84.07209015, 18.27653122], [84.07209015, 18.27625084], [84.07041931, 18.27625084], [84.07041931, 18.27597046], [84.06958008, 18.27597237], [84.06958008, 18.2756958], [84.06903076, 18.2756958], [84.06903076, 18.27541733], [84.06846619, 18.27542114], [84.06846619, 18.27514076], [84.06791687, 18.27514076], [84.06791687, 18.27486038], [84.06735992, 18.27486038], [84.06735992, 18.27458191], [84.06680298, 18.27458382], [84.06680298, 18.27430534], [84.06624603, 18.27431107], [84.06624603, 18.27403069], [84.06569672, 18.27403069], [84.06569672, 18.27375984], [84.06485748, 18.27375984], [84.06485748, 18.27347183], [84.06430817, 18.27347374], [84.06430817, 18.27319527], [84.06375122, 18.2732029], [84.06375122, 18.27292061], [84.06318665, 18.27292061], [84.06318665, 18.27264023], [84.06263733, 18.27264023], [84.06263733, 18.27236176], [84.06208038, 18.27236176], [84.06208038, 18.27208328], [84.06153107, 18.27208328], [84.06153107, 18.27180481], [84.06097412, 18.27180481], [84.06097412, 18.27152824], [84.06015015, 18.27153015], [84.06015015, 18.27125168], [84.05958557, 18.27125168], [84.05958557, 18.27096939], [84.05902863, 18.27096939], [84.05902863, 18.27069473], [84.05847168, 18.27070045], [84.05847168, 18.27042007], [84.0579071, 18.27042007], [84.0579071, 18.2701416], [84.05735779, 18.2701416], [84.05735779, 18.26985931], [84.05680847, 18.26985931], [84.05680847, 18.26958084], [84.05596924, 18.26958275], [84.05596924, 18.26930618], [84.05541992, 18.26930809], [84.05541992, 18.26902962], [84.05486298, 18.26902962], [84.05486298, 18.26874924], [84.05430603, 18.26874924], [84.05430603, 18.26847076], [84.05374908, 18.26847267], [84.05374908, 18.2681942], [84.05319214, 18.2681942], [84.05319214, 18.26791954], [84.05264282, 18.26791954], [84.05264282, 18.26762962], [84.05208588, 18.26763725], [84.05208588, 18.26736069], [84.05124664, 18.26736069], [84.05124664, 18.26708031], [84.05069733, 18.26708412], [84.05069733, 18.26680565], [84.05014038, 18.26680946], [84.05014038, 18.26653099], [84.04957581, 18.26653099], [84.04957581, 18.26625061], [84.04902649, 18.26625061], [84.04902649, 18.26597023], [84.04846954, 18.26597214], [84.04846954, 18.26569366], [84.04792023, 18.26569366], [84.04792023, 18.26541519], [84.04736328, 18.26542091], [84.04736328, 18.26514053], [84.04651642, 18.26514053], [84.04651642, 18.26486015], [84.04597473, 18.26486206], [84.04597473, 18.26458359], [84.04541779, 18.26458359], [84.04541779, 18.26430511], [84.04485321, 18.26431084], [84.04485321, 18.26403046], [84.04429626, 18.26403046], [84.04429626, 18.26375008], [84.04374695, 18.26375008], [84.04374695, 18.2634697], [84.04291534, 18.2634716], [84.04291534, 18.26319313], [84.0423584, 18.26320076], [84.0423584, 18.26292038], [84.04180908, 18.26292038], [84.04180908, 18.26264], [84.04125214, 18.26264], [84.04125214, 18.26235962], [84.04013824, 18.26236153], [84.04013824, 18.26208305], [84.03930664, 18.26208305], [84.03930664, 18.26180649], [84.03901672, 18.26181984], [84.03901672, 18.26152992], [84.03874969, 18.26152992], [84.03874969, 18.26124954], [84.03819275, 18.26124954], [84.03819275, 18.26097107], [84.0376358, 18.26097488], [84.0376358, 18.2606945], [84.03708649, 18.2606945], [84.03708649, 18.26041603], [84.03652954, 18.26041985], [84.03652954, 18.26013947], [84.03569794, 18.26013947], [84.03569794, 18.2598629], [84.03514099, 18.2598629], [84.03514099, 18.25958252], [84.03458405, 18.25958252], [84.03458405, 18.25930595], [84.0340271, 18.25930977], [84.0340271, 18.25902939], [84.03347015, 18.25902939], [84.03347015, 18.25876045], [84.03291321, 18.25876045], [84.03291321, 18.25847244], [84.0320816, 18.25847244], [84.0320816, 18.25819397], [84.03152466, 18.25819397], [84.03152466, 18.2579174], [84.03098297, 18.25792122], [84.03098297, 18.25764084], [84.0304184, 18.25764084], [84.0304184, 18.25735855], [84.02984619, 18.25735855], [84.02984619, 18.25707817], [84.0293045, 18.25708389], [84.0293045, 18.25680542], [84.0284729, 18.25680923], [84.0284729, 18.25653076], [84.02791595, 18.25653076], [84.02791595, 18.25624847], [84.02735901, 18.25624847], [84.02735901, 18.25596809], [84.02680206, 18.25597191], [84.02680206, 18.25569534], [84.02625275, 18.25569534], [84.02625275, 18.25541878], [84.0256958, 18.25542068], [84.0256958, 18.2551384], [84.02485657, 18.2551384], [84.02485657, 18.25485992], [84.02430725, 18.25486183], [84.02430725, 18.25458336], [84.02375031, 18.25458336], [84.02375031, 18.25430489], [84.02319336, 18.25430489], [84.02319336, 18.25402641], [84.02263641, 18.25403023], [84.02263641, 18.25374985], [84.0220871, 18.25374985], [84.0220871, 18.25346947], [84.02153015, 18.25347137], [84.02153015, 18.25319481], [84.02097321, 18.25319481], [84.02097321, 18.25291634], [84.02041626, 18.25292015], [84.02041626, 18.25263023], [84.01985931, 18.25263977], [84.01985931, 18.2523613], [84.01930237, 18.2523613], [84.01930237, 18.25208282], [84.01875305, 18.25208282], [84.01875305, 18.25180435], [84.01819611, 18.25181007], [84.01819611, 18.25152969], [84.01763916, 18.25152969], [84.01763916, 18.25125122], [84.01708221, 18.25125122], [84.01708221, 18.25097084], [84.01652527, 18.25097275], [84.01652527, 18.25069427], [84.01597595, 18.25069427], [84.01597595, 18.25097275], [84.01513672, 18.25097275], [84.01513672, 18.25069427], [84.01403046, 18.25069427], [84.01403046, 18.2504158], [84.01264191, 18.25041962], [84.01264191, 18.25014114], [84.0118103, 18.25014114], [84.0118103, 18.24986076], [84.01125336, 18.24986076], [84.01125336, 18.24958992], [84.01097107, 18.24958992], [84.01097107, 18.24930954], [84.01069641, 18.24930954], [84.01069641, 18.24903107], [84.01040649, 18.24903107], [84.01040649, 18.24818993], [84.01013947, 18.24819374], [84.01013947, 18.24791718], [84.00985718, 18.24792099], [84.00985718, 18.24764061], [84.00958252, 18.24764061], [84.00958252, 18.24792099], [84.0090332, 18.24792099], [84.0090332, 18.24764061], [84.00875092, 18.24764061], [84.00875092, 18.24736023], [84.00846863, 18.24736023], [84.00846863, 18.24707985], [84.00791931, 18.24708366], [84.00791931, 18.24680519], [84.00763702, 18.24682045], [84.00763702, 18.24653053], [84.00736237, 18.24653053], [84.00736237, 18.24625015], [84.00680542, 18.24625015], [84.00680542, 18.24597359], [84.00597382, 18.24597359], [84.00597382, 18.24569511], [84.00541687, 18.24570274], [84.00541687, 18.24542046], [84.00485992, 18.24541664], [84.00485992, 18.24597359], [84.00458527, 18.24597359], [84.0045929, 18.24625015], [84.00402832, 18.24625015], [84.00402832, 18.24597168], [84.00375366, 18.24597359], [84.00375366, 18.24569511], [84.00347137, 18.24570274], [84.00347137, 18.24542046], [84.00319672, 18.24542046], [84.00319672, 18.2448616], [84.00291443, 18.2448616], [84.00291443, 18.24402809], [84.00235748, 18.24403191], [84.00235748, 18.24375153], [84.00180817, 18.24375153], [84.00180817, 18.24346924], [84.00125122, 18.24347305], [84.00125122, 18.24319458], [84.00069427, 18.24319458], [84.00069427, 18.24291611], [83.9998703, 18.24292183], [83.99903107, 18.24292183], [83.99903107, 18.24263763], [83.99846649, 18.24263763], [83.99846649, 18.24235916], [83.99819183, 18.24235916], [83.99819183, 18.24208069], [83.99764252, 18.2420826], [83.99764252, 18.24180794], [83.99736023, 18.24180984], [83.99736023, 18.24152756], [83.99652863, 18.24152756], [83.99652863, 18.24124908], [83.99624634, 18.24124908], [83.99624634, 18.24097061], [83.99569702, 18.24097252], [83.99569702, 18.24069405], [83.99541473, 18.24069405], [83.99541473, 18.24041939], [83.99485779, 18.24041939], [83.99485779, 18.24014091], [83.99430847, 18.24014091], [83.99430847, 18.23986053], [83.99373627, 18.23986053], [83.99373627, 18.23958015], [83.99319458, 18.23958397], [83.99319458, 18.2393055], [83.99263763, 18.23931122], [83.99263763, 18.23903084], [83.99208069, 18.23903084], [83.99208069, 18.23875046], [83.99124908, 18.23875046], [83.99124908, 18.23847008], [83.99069214, 18.23847198], [83.99069214, 18.23819542], [83.99014282, 18.2381897], [83.99013519, 18.23791695], [83.98958588, 18.23792076], [83.98958588, 18.23764992], [83.98902893, 18.23764992], [83.98902893, 18.23736], [83.98847198, 18.23736191], [83.98847198, 18.23708344], [83.98791504, 18.23708344], [83.98791504, 18.23680305], [83.98735809, 18.23681068], [83.98735809, 18.2365303], [83.98680878, 18.2365303], [83.98680878, 18.23624992], [83.98625183, 18.23624992], [83.98625183, 18.23596954], [83.98569489, 18.23597145], [83.98569489, 18.23569489], [83.98513794, 18.23569489], [83.98513794, 18.23541641], [83.98430634, 18.23542023], [83.98430634, 18.23513985], [83.98401642, 18.23513985], [83.98401642, 18.23485947], [83.98347473, 18.23486137], [83.98347473, 18.23458481], [83.98264313, 18.23459053], [83.98264313, 18.23431015], [83.98208618, 18.23431015], [83.98208618, 18.23402977], [83.98152924, 18.23402977], [83.98152924, 18.23374939], [83.98097229, 18.23374939], [83.98097229, 18.23347282], [83.98041534, 18.23347282], [83.98041534, 18.23319435], [83.98014069, 18.23319435], [83.98014069, 18.23291588], [83.97957611, 18.23291969], [83.97957611, 18.23264122], [83.97846985, 18.23264122], [83.97846985, 18.23236275], [83.97819519, 18.23236275], [83.97819519, 18.23208427], [83.97763824, 18.23208427], [83.97763824, 18.2318058], [83.9770813, 18.23180962], [83.9770813, 18.23153114], [83.97651672, 18.23153114], [83.97651672, 18.23125267], [83.97597504, 18.23125267], [83.97597504, 18.23097229], [83.97569275, 18.23097229], [83.97569275, 18.23069382], [83.97541809, 18.23069382], [83.97541809, 18.23041725], [83.97458649, 18.23041916], [83.97458649, 18.23014069], [83.97402954, 18.23014069], [83.97402954, 18.2298584], [83.9734726, 18.2298584], [83.9734726, 18.22957993], [83.97264099, 18.22958374], [83.97264099, 18.22930527], [83.9723587, 18.22930908], [83.9723587, 18.22903061], [83.97207642, 18.22903061], [83.97207642, 18.22874832], [83.97041321, 18.22874832], [83.97041321, 18.22820091], [83.97013855, 18.22820091], [83.97013855, 18.22792053], [83.96985626, 18.22792053], [83.96985626, 18.22763824], [83.96956635, 18.22763824], [83.96956635, 18.22735977], [83.96930695, 18.22736168], [83.96930695, 18.22708321], [83.96875, 18.22708321], [83.96875, 18.22680473], [83.96819305, 18.22680473], [83.96819305, 18.22652626], [83.96763611, 18.22653008], [83.96763611, 18.22624969], [83.96708679, 18.22624969], [83.96708679, 18.22597122], [83.9668045, 18.22597313], [83.9668045, 18.22569466], [83.96624756, 18.22569466], [83.96624756, 18.22541618], [83.96541595, 18.22542], [83.96541595, 18.22513962], [83.96457672, 18.22513962], [83.96457672, 18.22486115], [83.96430206, 18.22486115], [83.96430206, 18.22458076], [83.9640274, 18.22458267], [83.9640274, 18.2243042], [83.96376038, 18.22430992], [83.96376038, 18.22402954], [83.96235657, 18.22402954], [83.96235657, 18.22375107], [83.96208191, 18.22375107], [83.96208191, 18.22347069], [83.96152496, 18.2234726], [83.96152496, 18.22319412], [83.96125031, 18.22319412], [83.96125031, 18.22291756], [83.96099091, 18.22291946], [83.96099091, 18.22265053], [83.9604187, 18.22265053], [83.9604187, 18.22236061], [83.96013641, 18.22236061], [83.96013641, 18.22208023], [83.95903015, 18.22208214], [83.95903015, 18.22180557], [83.95874786, 18.22180939], [83.95874786, 18.22153091], [83.95847321, 18.22153091], [83.95847321, 18.22125053], [83.95819092, 18.22125053], [83.95819092, 18.22097015], [83.95680237, 18.22097206], [83.95680237, 18.22069359], [83.95652771, 18.22069359], [83.95652771, 18.22041702], [83.95597076, 18.22042084], [83.95597076, 18.22014046], [83.95540619, 18.22014046], [83.95540619, 18.21986008], [83.9548645, 18.21986389], [83.9548645, 18.21958351], [83.95456696, 18.21959114], [83.95456696, 18.21931076], [83.95430756, 18.21931076], [83.95430756, 18.21903038], [83.95347595, 18.21903038], [83.95347595, 18.21875191], [83.95291901, 18.21875191], [83.95291901, 18.21846962], [83.95236206, 18.21846962], [83.95236206, 18.21819496], [83.95182037, 18.21820259], [83.95182037, 18.2179203], [83.95153046, 18.2179203], [83.95153046, 18.21764183], [83.95124817, 18.21764183], [83.95124817, 18.21736145], [83.95097351, 18.21736145], [83.95097351, 18.21708107], [83.95069122, 18.21708107], [83.95069122, 18.21680641], [83.94958496, 18.21680641], [83.94958496, 18.21708107], [83.94902802, 18.21708107], [83.94902802, 18.21680641], [83.94876099, 18.21681023], [83.94876099, 18.21624756], [83.94819641, 18.21624756], [83.94819641, 18.21596909], [83.94708252, 18.2159729], [83.94708252, 18.21569443], [83.94625092, 18.21569443], [83.94625092, 18.21541595], [83.94486237, 18.21541977], [83.94486237, 18.21513748], [83.94458008, 18.21513748], [83.94458008, 18.21486092], [83.94403076, 18.21486092], [83.94403076, 18.21458054], [83.94319153, 18.21458244], [83.94319153, 18.21430779], [83.94235992, 18.21430969], [83.94235992, 18.21403122], [83.93875122, 18.21403122], [83.93875122, 18.21430969], [83.93653107, 18.21430969], [83.93653107, 18.21403122], [83.93569183, 18.21403122], [83.93569183, 18.21430969], [83.93430328, 18.21430969], [83.93430328, 18.21375084], [83.9345932, 18.21375084], [83.93458557, 18.21291542], [83.93486023, 18.21292114], [83.93486023, 18.21264076], [83.93514252, 18.21264076], [83.93514252, 18.21236038], [83.93541718, 18.21236038], [83.93541718, 18.21208], [83.93624878, 18.21208382], [83.93624878, 18.21180534], [83.93653107, 18.21181107], [83.93653107, 18.21153069], [83.93682098, 18.21153069], [83.93682098, 18.21125031], [83.93708038, 18.21125031], [83.93708038, 18.21071053], [83.93596649, 18.21071053], [83.93596649, 18.21042061], [83.93430328, 18.21042061], [83.93430328, 18.21014023], [83.93402863, 18.21014023], [83.93402863, 18.20985985], [83.93291473, 18.20986176], [83.93291473, 18.20958328], [83.93235779, 18.20958328], [83.93235779, 18.20902824], [83.93208313, 18.20903015], [83.93208313, 18.20874977], [83.93102264, 18.20874977], [83.92903137, 18.20874977], [83.92903137, 18.20846939], [83.92763519, 18.2084713], [83.92763519, 18.20819473], [83.92708588, 18.20819473], [83.92708588, 18.20791626], [83.92624664, 18.20792007], [83.92624664, 18.20763969], [83.92346954, 18.20763969], [83.92346954, 18.20736122], [83.92236328, 18.20736122], [83.92236328, 18.20708275], [83.92152405, 18.20708275], [83.92152405, 18.20680618], [83.92069244, 18.20681], [83.92069244, 18.20652962], [83.92041779, 18.20652962], [83.92041779, 18.20625114], [83.91929626, 18.20625114], [83.91929626, 18.20652962], [83.91897583, 18.20652771], [83.91819763, 18.20652962], [83.91819763, 18.20625114], [83.91764069, 18.20625114], [83.91764069, 18.20597267], [83.91708374, 18.20597267], [83.91708374, 18.2056942], [83.91625214, 18.2056942], [83.91625214, 18.20541763], [83.91539764, 18.20541954], [83.91539764, 18.20514107], [83.9145813, 18.20514107], [83.9145813, 18.20486259], [83.91374969, 18.20486259], [83.91374969, 18.20458031], [83.91291809, 18.20458412], [83.91291809, 18.20430565], [83.91179657, 18.20430946], [83.91179657, 18.20402908], [83.91124725, 18.20402908], [83.91124725, 18.20375061], [83.90957642, 18.20375061], [83.90957642, 18.20346832], [83.9081955, 18.20347023], [83.9081955, 18.20319366], [83.90763855, 18.20319366], [83.90763855, 18.2029171], [83.9070816, 18.20292091], [83.9070816, 18.20264053], [83.90680695, 18.20264053], [83.90680695, 18.20235825], [83.90652466, 18.20236206], [83.90652466, 18.20208359], [83.9054184, 18.20208359], [83.9054184, 18.20180511], [83.90429688, 18.20181084], [83.90429688, 18.20152092], [83.9034729, 18.20153046], [83.9034729, 18.20124817], [83.90319824, 18.20124817], [83.90319824, 18.20153046], [83.90235901, 18.20153046], [83.90235901, 18.20124817], [83.90125275, 18.20124817], [83.90125275, 18.2009697], [83.90097046, 18.2009716], [83.90097046, 18.20069695], [83.90042114, 18.20070076], [83.90042114, 18.20042038], [83.89901733, 18.20042038], [83.89901733, 18.20013809], [83.89848328, 18.20013809], [83.89848328, 18.19985962], [83.89819336, 18.19986153], [83.89819336, 18.19958305], [83.89763641, 18.19958305], [83.89763641, 18.1993084], [83.89653015, 18.1993103], [83.89653015, 18.19902992], [83.89597321, 18.19902992], [83.89597321, 18.19874954], [83.89541626, 18.19874954], [83.89541626, 18.19848061], [83.89457703, 18.19848061], [83.89457703, 18.19819069], [83.89263916, 18.1981945], [83.89263916, 18.19791412], [83.89208221, 18.19791985], [83.89208221, 18.19763947], [83.89180756, 18.19763947], [83.89180756, 18.19736099], [83.89125061, 18.19736099], [83.89125061, 18.19708061], [83.89069366, 18.19708252], [83.89069366, 18.19680405], [83.88931274, 18.19680977], [83.88931274, 18.19625092], [83.88874817, 18.19625092], [83.88874817, 18.19597054], [83.88847351, 18.19597244], [83.88847351, 18.19569588], [83.88819122, 18.19569588], [83.88819122, 18.1954174], [83.88791656, 18.19542122], [83.88791656, 18.19514084], [83.88707733, 18.19514084], [83.88707733, 18.19542122], [83.88625336, 18.19542122], [83.88625336, 18.19514084], [83.88597107, 18.19514084], [83.88597107, 18.19486046], [83.88569641, 18.19486046], [83.88569641, 18.19458008], [83.88486481, 18.19458389], [83.88486481, 18.19402695], [83.88458252, 18.19403076], [83.88458252, 18.19375038], [83.88430786, 18.19375038], [83.88430786, 18.19347191], [83.88375092, 18.19347382], [83.88375092, 18.19319534], [83.88263702, 18.19320107], [83.88263702, 18.19292068], [83.88234711, 18.19292068], [83.88234711, 18.1926403], [83.88181305, 18.1926403], [83.88181305, 18.19234848], [83.88124847, 18.19236183], [83.88124847, 18.19208336], [83.88014221, 18.19208336], [83.88014221, 18.19152832], [83.87985992, 18.19153023], [83.87985992, 18.19125175], [83.87957764, 18.19125175], [83.87957764, 18.19096947], [83.87875366, 18.19096947], [83.87875366, 18.19069481], [83.87847137, 18.19069481], [83.87847137, 18.19041634], [83.8779068, 18.19042015], [83.8779068, 18.19014168], [83.87735748, 18.19014168], [83.87735748, 18.18985939], [83.87708282, 18.18985939], [83.87708282, 18.18958282], [83.87680817, 18.18958282], [83.87680817, 18.18930626], [83.87654114, 18.18930817], [83.87654114, 18.18902969], [83.87625122, 18.18902969], [83.87625122, 18.18819046], [83.87569427, 18.18819427], [83.87569427, 18.1879158], [83.87486267, 18.18791962], [83.87486267, 18.18764114], [83.87458038, 18.18764114], [83.87458038, 18.18625069], [83.87430573, 18.18625069], [83.87430573, 18.18597221], [83.87403107, 18.18597221], [83.87403107, 18.18486023], [83.87431335, 18.18486023], [83.87430573, 18.18430519], [83.87403107, 18.18431091], [83.87403107, 18.18403053], [83.87374878, 18.18403053], [83.87374878, 18.18375015], [83.87347412, 18.18375015], [83.87347412, 18.18347168], [83.87319183, 18.18348122], [83.87319183, 18.18320084], [83.87291718, 18.18320084], [83.87291718, 18.18292046], [83.87264252, 18.18292046], [83.87264252, 18.18264008], [83.87236023, 18.18264008], [83.87236023, 18.1823597], [83.87208557, 18.1823616], [83.87208557, 18.18208313], [83.87152863, 18.18208313], [83.87152863, 18.18180466], [83.87124634, 18.18180466], [83.87124634, 18.18152809], [83.87097168, 18.18153], [83.87097168, 18.18124962], [83.87069702, 18.18124962], [83.87069702, 18.18069267], [83.87041473, 18.18069458], [83.87041473, 18.18041611], [83.87014008, 18.18041611], [83.87014008, 18.18013954], [83.86985779, 18.18013954], [83.86985779, 18.17986107], [83.86958313, 18.17986107], [83.86958313, 18.1795826], [83.86819458, 18.1795826], [83.86819458, 18.17930603], [83.86734772, 18.17930984], [83.86734772, 18.17902946], [83.86708069, 18.17902946], [83.86708069, 18.1787529], [83.86624908, 18.1787529], [83.86624908, 18.17847252], [83.86569214, 18.17847252], [83.86569214, 18.17819405], [83.86541748, 18.17819405], [83.86541748, 18.17791748], [83.86514282, 18.17791939], [83.86514282, 18.17764282], [83.86460114, 18.17764282], [83.86460114, 18.17734909], [83.86430359, 18.17735863], [83.86430359, 18.17708397], [83.86347198, 18.17708397], [83.86347198, 18.1768055], [83.86319733, 18.17680931], [83.86319733, 18.17624855], [83.86291504, 18.17624855], [83.86291504, 18.17597008], [83.86264038, 18.17597008], [83.86264038, 18.17569542], [83.86125183, 18.1756897], [83.86125183, 18.17541885], [83.86068726, 18.17542076], [83.86068726, 18.17514038], [83.86042023, 18.17514038], [83.86042023, 18.17485809], [83.85986328, 18.17486191], [83.85986328, 18.17458344], [83.85874939, 18.17458344], [83.85874939, 18.17430496], [83.85817719, 18.17431068], [83.85817719, 18.1740303], [83.85791779, 18.1740303], [83.85791779, 18.17374992], [83.8576355, 18.17374992], [83.8576355, 18.17347145], [83.85708618, 18.17347145], [83.85708618, 18.17319489], [83.85652924, 18.17319489], [83.85652924, 18.17291641], [83.85597229, 18.17292023], [83.85597229, 18.17263985], [83.85430908, 18.17263985], [83.85430908, 18.17235947], [83.85346985, 18.17235947], [83.85346985, 18.17263985], [83.85320282, 18.17263985], [83.85320282, 18.17235947], [83.85097504, 18.17236137], [83.85097504, 18.17180634], [83.85124969, 18.17181015], [83.85124969, 18.17154121], [83.85041809, 18.17154121], [83.85041809, 18.17124939], [83.84958649, 18.17124939], [83.84958649, 18.17097282], [83.84874725, 18.17097282], [83.84874725, 18.17069435], [83.84819794, 18.17069435], [83.84819794, 18.17041588], [83.8473587, 18.17041969], [83.8473587, 18.17014122], [83.8465271, 18.17014122], [83.8465271, 18.16986084], [83.8456955, 18.16986084], [83.8456955, 18.16958427], [83.84486389, 18.16958427], [83.84486389, 18.1693058], [83.84401703, 18.16930962], [83.84401703, 18.16903114], [83.8431778, 18.16903114], [83.8431778, 18.16875076], [83.84236145, 18.16875076], [83.84236145, 18.16847038], [83.8418045, 18.16847229], [83.8418045, 18.16819382], [83.8409729, 18.16819382], [83.8409729, 18.16791725], [83.8401413, 18.16792107], [83.8401413, 18.16764069], [83.83930206, 18.16764069], [83.83930206, 18.16736031], [83.83790588, 18.16736031], [83.83790588, 18.16764069], [83.83763885, 18.16764069], [83.83763885, 18.16736031], [83.8373642, 18.16736031], [83.8373642, 18.16708374], [83.83680725, 18.16708374], [83.83680725, 18.16680527], [83.83625031, 18.1668129], [83.83625031, 18.16653061], [83.83569336, 18.16653061], [83.83569336, 18.16625023], [83.8354187, 18.16625023], [83.8354187, 18.16597176], [83.83486176, 18.16597366], [83.83486176, 18.16569519], [83.83403015, 18.16570282], [83.83403015, 18.16540909], [83.83319092, 18.16541672], [83.83319092, 18.16513824], [83.83180237, 18.16514015], [83.83180237, 18.16486168], [83.82958221, 18.16486168], [83.82958221, 18.16458321], [83.82930756, 18.16458321], [83.82930756, 18.16402817], [83.82849121, 18.16403008], [83.82849121, 18.1637516], [83.82791901, 18.1637516], [83.82791901, 18.16346931], [83.82707977, 18.16347313], [83.82707977, 18.16319466], [83.82653046, 18.16319466], [83.82653046, 18.16291618], [83.82569122, 18.16292191], [83.82569122, 18.16263771], [83.82514191, 18.16263771], [83.82514191, 18.16237068], [83.82457733, 18.16237068], [83.82457733, 18.16208076], [83.82375336, 18.16208267], [83.82375336, 18.16180611], [83.82319641, 18.16180992], [83.82319641, 18.16152954], [83.82235718, 18.16152954], [83.82235718, 18.16125107], [83.82180786, 18.16125107], [83.82180786, 18.16097069], [83.82125092, 18.1609726], [83.82125092, 18.16069412], [83.82041931, 18.16069412], [83.82041931, 18.16041946], [83.81986237, 18.16041946], [83.81986237, 18.16014099], [83.81903076, 18.16014099], [83.81903076, 18.15986061], [83.81846619, 18.15986061], [83.81846619, 18.15958023], [83.81764221, 18.15958405], [83.81764221, 18.15930557], [83.8170929, 18.15930939], [83.8170929, 18.15903091], [83.81626129, 18.15903091], [83.81626129, 18.15875053], [83.81569672, 18.15875053], [83.81569672, 18.15847015], [83.81485748, 18.15847206], [83.81485748, 18.15819359], [83.81430817, 18.15819359], [83.81430817, 18.15791512], [83.81346893, 18.15792084], [83.81346893, 18.15764046], [83.81263733, 18.15764046], [83.81263733, 18.15736008], [83.81180573, 18.15736198], [83.81180573, 18.15708351], [83.81124878, 18.15708351], [83.81124878, 18.15680313], [83.81041718, 18.15681076], [83.81041718, 18.15653038], [83.80819702, 18.15653038], [83.80819702, 18.15624046], [83.80791473, 18.15625], [83.80791473, 18.15597153], [83.80764008, 18.15597153], [83.80764008, 18.15569305], [83.80735779, 18.15570068], [83.80735779, 18.1554203], [83.80680847, 18.1554203], [83.80680847, 18.15513992], [83.80652618, 18.15513992], [83.80652618, 18.15485954], [83.80625153, 18.15486145], [83.80625153, 18.15458488], [83.80541992, 18.15458488], [83.80541992, 18.15430641], [83.80486298, 18.15431023], [83.80486298, 18.15402985], [83.80403137, 18.15402985], [83.80403137, 18.15374947], [83.80319214, 18.15374947], [83.80319214, 18.1534729], [83.80263519, 18.1534729], [83.80263519, 18.15319443], [83.80180359, 18.15319443], [83.80180359, 18.15291595], [83.8012619, 18.15291977], [83.8012619, 18.15263939], [83.80041504, 18.15263939], [83.80041504, 18.15236282], [83.79957581, 18.15236282], [83.79957581, 18.15208244], [83.79902649, 18.15208244], [83.79902649, 18.15180588], [83.79820251, 18.15180969], [83.79820251, 18.15153122], [83.79736328, 18.15153122], [83.79736328, 18.15125275], [83.79680634, 18.15125275], [83.79680634, 18.15096855], [83.79597473, 18.15097237], [83.79597473, 18.15069389], [83.79402924, 18.15069389], [83.79402924, 18.15097237], [83.79347229, 18.15097237], [83.79347229, 18.15041733], [83.79292297, 18.15043068], [83.79292297, 18.14985847], [83.79264069, 18.14985847], [83.79264069, 18.14957809], [83.7923584, 18.14958382], [83.7923584, 18.14930534], [83.79180908, 18.14930916], [83.79180908, 18.14903069], [83.79152679, 18.14903069], [83.79152679, 18.1487484], [83.79096985, 18.1487484], [83.79096985, 18.14846992], [83.79069519, 18.14847183], [83.79069519, 18.14819527], [83.78985596, 18.14819908], [83.78985596, 18.14792061], [83.78819275, 18.14792061], [83.78819275, 18.14764023], [83.78736115, 18.14764023], [83.78736115, 18.14736748], [83.78457642, 18.14736748], [83.78457642, 18.14707947], [83.78430176, 18.14708328], [83.78430176, 18.14680481], [83.78375244, 18.14680481], [83.78375244, 18.14652634], [83.78318787, 18.14653015], [83.78318787, 18.14624977], [83.78263855, 18.14624977], [83.78263855, 18.14596939], [83.7820816, 18.1459713], [83.7820816, 18.14569473], [83.78180695, 18.14569473], [83.78180695, 18.14541626], [83.78125, 18.14542007], [83.78125, 18.14513969], [83.78097534, 18.14513969], [83.78097534, 18.14486122], [83.7804184, 18.14486122], [83.7804184, 18.14458084], [83.77986145, 18.14458275], [83.77986145, 18.14430428], [83.77958679, 18.14430428], [83.77958679, 18.14402771], [83.77902985, 18.14402962], [83.77902985, 18.14375114], [83.7784729, 18.14375114], [83.7784729, 18.14347076], [83.77791595, 18.14347267], [83.77791595, 18.1431942], [83.7776413, 18.1431942], [83.7776413, 18.14291763], [83.77709198, 18.14291954], [83.77709198, 18.14264107], [83.7765274, 18.14264107], [83.7765274, 18.14208031], [83.77513885, 18.14208412], [83.77513885, 18.14180565], [83.77430725, 18.14180946], [83.77430725, 18.14153099], [83.77403259, 18.14153099], [83.77403259, 18.14124107], [83.77375031, 18.14125061], [83.77375031, 18.14097214], [83.77347565, 18.14097214], [83.77347565, 18.14069366], [83.77319336, 18.14069366], [83.77319336, 18.1404171], [83.7729187, 18.14042091], [83.7729187, 18.14014053], [83.77236176, 18.14014053], [83.77236176, 18.13986015], [83.77153015, 18.13986206], [83.77153015, 18.13958359], [83.77041626, 18.13958359], [83.77041626, 18.13930511], [83.76957703, 18.13931274], [83.76957703, 18.13903046], [83.76875305, 18.13903046], [83.76875305, 18.13875008], [83.76763916, 18.13875008], [83.76763916, 18.1384716], [83.76680756, 18.1384716], [83.76680756, 18.13791656], [83.7665329, 18.13792038], [83.7665329, 18.13764191], [83.76625061, 18.13764191], [83.76625061, 18.13736153], [83.76569366, 18.13736153], [83.76569366, 18.13708305], [83.76513672, 18.13708305], [83.76513672, 18.13680649], [83.76457977, 18.1368103], [83.76457977, 18.13596916], [83.76430511, 18.13597298], [83.76430511, 18.1356945], [83.76264191, 18.1356945], [83.76264191, 18.13541794], [83.76180267, 18.13542938], [83.76180267, 18.13513756], [83.76069641, 18.13513756], [83.76069641, 18.13485909], [83.76013947, 18.13485909], [83.76013947, 18.13458061], [83.75958252, 18.13458252], [83.75958252, 18.13430786], [83.75901794, 18.13430977], [83.75901794, 18.13402939], [83.75875092, 18.13402939], [83.75875092, 18.13375092], [83.75846863, 18.13375092], [83.75846863, 18.13347054], [83.75791931, 18.13347244], [83.75791931, 18.13319397], [83.75708008, 18.13319397], [83.75708008, 18.1329155], [83.75653076, 18.13292122], [83.75653076, 18.13264084], [83.75595856, 18.13264084], [83.75595856, 18.13236046], [83.75541687, 18.13236046], [83.75541687, 18.13208008], [83.75485992, 18.13208389], [83.75485992, 18.13180542], [83.75430298, 18.13181114], [83.75430298, 18.13125038], [83.75347137, 18.13125038], [83.75347137, 18.13097], [83.75263977, 18.13097191], [83.75263977, 18.13069534], [83.75208282, 18.13070107], [83.75208282, 18.13042068], [83.75152588, 18.13042068], [83.75152588, 18.1301403], [83.75125122, 18.1301403], [83.75125122, 18.12985992], [83.75041962, 18.12986183], [83.75041962, 18.12958336], [83.74986267, 18.12958336], [83.74986267, 18.12930489], [83.74958038, 18.12930489], [83.74958038, 18.12902832], [83.74903107, 18.12903023], [83.74903107, 18.12874985], [83.74846649, 18.12874985], [83.74846649, 18.12846947], [83.74819183, 18.12847137], [83.74819183, 18.12819481], [83.74764252, 18.12819481], [83.74764252, 18.12791634], [83.74707794, 18.12792015], [83.74707794, 18.12763977], [83.74678802, 18.12763977], [83.74678802, 18.12735939], [83.74624634, 18.1273613], [83.74624634, 18.12708282], [83.74569702, 18.12708282], [83.74569702, 18.12680626], [83.7454071, 18.12681007], [83.7454071, 18.12652969], [83.74485779, 18.12652969], [83.74485779, 18.12626076], [83.74430847, 18.12626076], [83.74430847, 18.12597275], [83.74402618, 18.12597275], [83.74402618, 18.12569427], [83.74346924, 18.12569427], [83.74346924, 18.1254158], [83.74263763, 18.12541962], [83.74263763, 18.12514114], [83.74236298, 18.12514114], [83.74236298, 18.12486267], [83.74153137, 18.12486267], [83.74153137, 18.12458038], [83.74069214, 18.1245842], [83.74069214, 18.12430573], [83.74014282, 18.12430954], [83.74014282, 18.12402916], [83.73958588, 18.12402916], [83.73958588, 18.12375069], [83.73902893, 18.12375069], [83.73902893, 18.1234684], [83.73847198, 18.12347221], [83.73847198, 18.12319374], [83.73792267, 18.12319946], [83.73792267, 18.12291908], [83.73735809, 18.12291908], [83.73735809, 18.12264061], [83.73680878, 18.12264061], [83.73680878, 18.12235832], [83.73625183, 18.12235832], [83.73625183, 18.12207985], [83.73569489, 18.12208366], [83.73569489, 18.12180519], [83.73513794, 18.12181091], [83.73513794, 18.12153053], [83.73458099, 18.12153053], [83.73458099, 18.12124825], [83.73401642, 18.12124825], [83.73401642, 18.12096977], [83.73347473, 18.12097168], [83.73347473, 18.12069511], [83.73291779, 18.12070084], [83.73291779, 18.12042046], [83.73236084, 18.12042046], [83.73236084, 18.12013817], [83.73207855, 18.12013817], [83.73207855, 18.1198597], [83.73152924, 18.1198616], [83.73152924, 18.11958313], [83.73097229, 18.11958313], [83.73097229, 18.11930466], [83.73041534, 18.11930466], [83.73041534, 18.11902618], [83.7298584, 18.11903], [83.7298584, 18.11874962], [83.72930908, 18.11874962], [83.72930908, 18.11847115], [83.72875214, 18.11847305], [83.72875214, 18.11819458], [83.72819519, 18.11819458], [83.72819519, 18.1179142], [83.72846985, 18.11791992], [83.72846985, 18.11763954], [83.72819519, 18.11763954], [83.72819519, 18.11736107], [83.72763824, 18.11736107], [83.72763824, 18.11707115], [83.72624969, 18.1170826], [83.72624969, 18.11680412], [83.72598267, 18.11680984], [83.72598267, 18.11652946], [83.72541809, 18.11652946], [83.72541809, 18.11625099], [83.7251358, 18.11625099], [83.7251358, 18.11597061], [83.72458649, 18.11597252], [83.72458649, 18.11569595], [83.72402954, 18.11569595], [83.72402954, 18.11541748], [83.72374725, 18.11541939], [83.72374725, 18.11514091], [83.72319794, 18.11514091], [83.72319794, 18.11486053], [83.7223587, 18.11486053], [83.7223587, 18.11458015], [83.72125244, 18.11458206], [83.72125244, 18.1143055], [83.72097015, 18.11432076], [83.72097015, 18.11375046], [83.71930695, 18.11375046], [83.71930695, 18.11347008], [83.71875, 18.11347389], [83.71875, 18.11291695], [83.71848297, 18.11292076], [83.71848297, 18.11264038], [83.7179184, 18.11264038], [83.7179184, 18.11236191], [83.71763611, 18.11236382], [83.71763611, 18.11208344], [83.71708679, 18.11208344], [83.71708679, 18.11180496], [83.71678925, 18.11181068], [83.71678925, 18.1115303], [83.71624756, 18.1115303], [83.71624756, 18.11125946], [83.71541595, 18.11125946], [83.71541595, 18.11096954], [83.71430206, 18.11096954], [83.71430206, 18.11069489], [83.71347046, 18.11069489], [83.71347046, 18.11041641], [83.7131958, 18.11042023], [83.7131958, 18.11014175], [83.71263885, 18.11014175], [83.71263885, 18.10986137], [83.71208191, 18.10986137], [83.71208191, 18.1095829], [83.71152496, 18.1095829], [83.71152496, 18.10930634], [83.71096802, 18.10931015], [83.71096802, 18.10902977], [83.71069336, 18.10902977], [83.71069336, 18.10847092], [83.7104187, 18.10847282], [83.7104187, 18.10819435], [83.71013641, 18.10819817], [83.71013641, 18.10791969], [83.7095871, 18.10791969], [83.7095871, 18.10764122], [83.70903015, 18.10764122], [83.70903015, 18.10736084], [83.70874786, 18.10736084], [83.70874786, 18.10708046], [83.70847321, 18.10708427], [83.70847321, 18.10680771], [83.7076416, 18.10680962], [83.7076416, 18.10653114], [83.70735931, 18.10653114], [83.70735931, 18.10625076], [83.70707703, 18.10625076], [83.70707703, 18.10597038], [83.70680237, 18.10597229], [83.70680237, 18.10569382], [83.70541382, 18.10569382], [83.70541382, 18.10541534], [83.70513916, 18.10542107], [83.70513916, 18.10513115], [83.7048645, 18.10513878], [83.7048645, 18.10486031], [83.70430756, 18.10486031], [83.70430756, 18.10457993], [83.70402527, 18.10458374], [83.70402527, 18.10430527], [83.70375061, 18.10431099], [83.70375061, 18.10403061], [83.70318604, 18.10403061], [83.70318604, 18.10375023], [83.70207977, 18.10375023], [83.70207977, 18.10346985], [83.70153046, 18.10347176], [83.70153046, 18.10319328], [83.70124817, 18.10320091], [83.70124817, 18.10292053], [83.70069122, 18.10292053], [83.70069122, 18.10264015], [83.70014191, 18.10264015], [83.70014191, 18.10235977], [83.69958496, 18.10236168], [83.69958496, 18.10208321], [83.69902802, 18.10208321], [83.69902802, 18.10180473], [83.69847107, 18.10180473], [83.69847107, 18.10152817], [83.69819641, 18.10153008], [83.69819641, 18.10124969], [83.69790649, 18.10124969], [83.69790649, 18.10069275], [83.69736481, 18.10069466], [83.69736481, 18.10041618], [83.6965332, 18.10042], [83.6965332, 18.10013962], [83.69567871, 18.10013962], [83.69567871, 18.09986115], [83.69513702, 18.09986115], [83.69513702, 18.09958267], [83.69486237, 18.09958267], [83.69486237, 18.09930611], [83.69431305, 18.09931946], [83.69431305, 18.09902954], [83.69403076, 18.09902954], [83.69403076, 18.09875107], [83.69374847, 18.09875107], [83.69374847, 18.0984726], [83.69347382, 18.0984726], [83.69347382, 18.09819412], [83.69291687, 18.09819412], [83.69291687, 18.09791756], [83.69235992, 18.09791946], [83.69235992, 18.0976429], [83.69180298, 18.0976429], [83.69180298, 18.0973587], [83.69124603, 18.0973587], [83.69124603, 18.09707832], [83.69097137, 18.09708405], [83.69097137, 18.09680557], [83.6904068, 18.09680939], [83.6904068, 18.09653091], [83.68987274, 18.09653091], [83.68987274, 18.09626007], [83.68930817, 18.09626007], [83.68930817, 18.09596825], [83.68902588, 18.09597206], [83.68902588, 18.09569359], [83.68875122, 18.09569359], [83.68875122, 18.09541893], [83.68818665, 18.09542084], [83.68818665, 18.09514046], [83.68791962, 18.09514046], [83.68791962, 18.09485817], [83.68763733, 18.09486198], [83.68763733, 18.09458351], [83.68736267, 18.09458351], [83.68736267, 18.09430504], [83.68596649, 18.09431076], [83.68596649, 18.09403038], [83.68541718, 18.09403038], [83.68541718, 18.09374809], [83.68514252, 18.09374809], [83.68514252, 18.09346962], [83.68486023, 18.09347153], [83.68486023, 18.09319687], [83.68430328, 18.09319687], [83.68430328, 18.09291649], [83.68402863, 18.0929203], [83.68402863, 18.09263992], [83.68347168, 18.09263992], [83.68347168, 18.09235954], [83.68319702, 18.09236145], [83.68319702, 18.09208298], [83.68264008, 18.09208298], [83.68264008, 18.09180832], [83.68208313, 18.09181023], [83.68208313, 18.09152985], [83.68180847, 18.09152985], [83.68180847, 18.09124947], [83.68125153, 18.09124947], [83.68125153, 18.09097099], [83.68069458, 18.0909729], [83.68069458, 18.09069443], [83.68041992, 18.09069443], [83.68041992, 18.09041405], [83.67986298, 18.09041977], [83.67986298, 18.09012985], [83.67958069, 18.09013939], [83.67958069, 18.08986092], [83.6784668, 18.08986092], [83.6784668, 18.08930969], [83.67819214, 18.08930969], [83.67819214, 18.08903122], [83.67764282, 18.08903122], [83.67764282, 18.08875084], [83.67708588, 18.08875084], [83.67708588, 18.08847046], [83.67680359, 18.08847237], [83.67680359, 18.08819389], [83.67624664, 18.08819389], [83.67624664, 18.08791733], [83.67597198, 18.08791733], [83.67597198, 18.08819389], [83.67541504, 18.08819389], [83.67541504, 18.08791733], [83.67514038, 18.08792114], [83.67514038, 18.08736038], [83.67485809, 18.08736038], [83.67485809, 18.08708382], [83.67457581, 18.08708954], [83.67457581, 18.08681107], [83.67318726, 18.08681107], [83.67318726, 18.08653069], [83.67292023, 18.08653069], [83.67292023, 18.08625031], [83.67263794, 18.08625031], [83.67263794, 18.08597183], [83.67208099, 18.08597374], [83.67208099, 18.08569527], [83.67179871, 18.0857029], [83.67179871, 18.08542061], [83.67124939, 18.08542061], [83.67124939, 18.08514023], [83.6709671, 18.08514023], [83.6709671, 18.08457947], [83.67069244, 18.08458328], [83.67069244, 18.08430481], [83.6701355, 18.08430481], [83.6701355, 18.08402824], [83.66958618, 18.08403015], [83.66958618, 18.08375168], [83.66929626, 18.08375168], [83.66929626, 18.08346939], [83.66902924, 18.08346939], [83.66902924, 18.08319473], [83.66874695, 18.08319473], [83.66874695, 18.08291626], [83.66847229, 18.08292007], [83.66847229, 18.08263969], [83.66819763, 18.08263969], [83.66819763, 18.08236122], [83.66791534, 18.08236122], [83.66791534, 18.08208275], [83.66764069, 18.08208275], [83.66764069, 18.08180618], [83.6673584, 18.08180809], [83.6673584, 18.08152962], [83.66680908, 18.08152962], [83.66680908, 18.08125114], [83.66652679, 18.08125114], [83.66652679, 18.08096123], [83.66625214, 18.08097267], [83.66625214, 18.0806942], [83.66596985, 18.0806942], [83.66596985, 18.08013725], [83.66570282, 18.08014107], [83.66570282, 18.07958031], [83.6654129, 18.07958412], [83.6654129, 18.07930565], [83.66485596, 18.07930946], [83.66485596, 18.07903099], [83.6645813, 18.07903099], [83.6645813, 18.07875061], [83.66401672, 18.07875061], [83.66401672, 18.07847023], [83.66374969, 18.07847214], [83.66374969, 18.07819366], [83.66319275, 18.07819366], [83.66319275, 18.07791519], [83.66293335, 18.07792091], [83.66293335, 18.07764053], [83.66236115, 18.07764053], [83.66236115, 18.07736015], [83.66208649, 18.07736206], [83.66208649, 18.07708359], [83.6618042, 18.07708359], [83.6618042, 18.07680511], [83.66152954, 18.07681084], [83.66152954, 18.07653046], [83.6609726, 18.07653046], [83.6609726, 18.07625008], [83.66069794, 18.07625008], [83.66069794, 18.0759697], [83.66014099, 18.0759716], [83.66014099, 18.07569313], [83.65956879, 18.07570076], [83.65958405, 18.07550049], [83.65958405, 18.07541656], [83.65875244, 18.07542038], [83.65875244, 18.07514954], [83.65820313, 18.07514954], [83.65820313, 18.07485962], [83.65791321, 18.07486153], [83.65791321, 18.07458305], [83.65763855, 18.07458305], [83.65763855, 18.07430649], [83.65735626, 18.0743103], [83.65735626, 18.07402992], [83.6565094, 18.07402992], [83.6565094, 18.07291985], [83.65679932, 18.07291985], [83.65679932, 18.0723629], [83.6565094, 18.0723629], [83.6565094, 18.07152939], [83.65569305, 18.07152939], [83.65569305, 18.07125282], [83.65513611, 18.07125282], [83.65513611, 18.07097244], [83.65458679, 18.07097244], [83.65458679, 18.07069397], [83.6543045, 18.07069397], [83.6543045, 18.07014084], [83.65402985, 18.07014084], [83.65402985, 18.06985855], [83.6534729, 18.06985855], [83.6534729, 18.06957817], [83.6526413, 18.06958389], [83.6526413, 18.06930542], [83.65235901, 18.06930923], [83.65235901, 18.06902122], [83.65180206, 18.06902885], [83.65180206, 18.06875038], [83.6515274, 18.06875038], [83.6515274, 18.06846809], [83.65097046, 18.06847191], [83.65097046, 18.06819534], [83.64985657, 18.06819916], [83.64985657, 18.06792068], [83.64958191, 18.06792068], [83.64958191, 18.0676403], [83.64819336, 18.0676403], [83.64819336, 18.06735992], [83.6479187, 18.06736183], [83.6479187, 18.06680489], [83.64736176, 18.06680489], [83.64736176, 18.06652641], [83.6470871, 18.06653023], [83.6470871, 18.06624985], [83.64679718, 18.06624985], [83.64679718, 18.06595993], [83.64653015, 18.06597137], [83.64653015, 18.06569481], [83.64624786, 18.06569481], [83.64624786, 18.06513977], [83.64597321, 18.06513977], [83.64597321, 18.06485939], [83.64569092, 18.0648613], [83.64569092, 18.06458282], [83.6451416, 18.06458282], [83.6451416, 18.06430435], [83.64485931, 18.06431007], [83.64485931, 18.06402969], [83.6445694, 18.06402969], [83.6445694, 18.06319046], [83.64430237, 18.06319427], [83.64430237, 18.0629158], [83.64402771, 18.06291962], [83.64402771, 18.06208038], [83.64375305, 18.0620842], [83.64375305, 18.06180573], [83.64235687, 18.06180954], [83.64235687, 18.06153107], [83.6415329, 18.06153107], [83.6415329, 18.06125069], [83.64097595, 18.06125069], [83.64097595, 18.06097031], [83.64041901, 18.06097221], [83.64041901, 18.06069374], [83.63986206, 18.06069374], [83.63986206, 18.06041718], [83.63903046, 18.0604229], [83.63903046, 18.06015015], [83.63846588, 18.06015015], [83.63846588, 18.05986023], [83.63791656, 18.05986023], [83.63791656, 18.05958176], [83.63764191, 18.05958366], [83.63764191, 18.05930519], [83.63735962, 18.05931282], [83.63735962, 18.05903053], [83.63680267, 18.05903053], [83.63680267, 18.05875015], [83.63652802, 18.05875015], [83.63652802, 18.05847168], [83.63597107, 18.05847168], [83.63597107, 18.05819511], [83.63513947, 18.05820274], [83.63513947, 18.05792046], [83.63485718, 18.05792046], [83.63485718, 18.05764008], [83.63458252, 18.05764008], [83.63458252, 18.05707932], [83.63430786, 18.05708313], [83.63430786, 18.05680466], [83.63402557, 18.05680466], [83.63402557, 18.05625153], [83.63346863, 18.05625153], [83.63346863, 18.05596924], [83.63291931, 18.05597305], [83.63291931, 18.05569458], [83.63263702, 18.05569458], [83.63263702, 18.05541611], [83.63236237, 18.05541992], [83.63236237, 18.05485916], [83.63208008, 18.05485916], [83.63208008, 18.05458069], [83.63180542, 18.0545826], [83.63180542, 18.05430794], [83.63124847, 18.05430984], [83.63124847, 18.05401993], [83.63069153, 18.05402946], [83.63069153, 18.05374718], [83.63041687, 18.05375099], [83.63041687, 18.05347061], [83.62985992, 18.05347252], [83.62985992, 18.05319405], [83.62958527, 18.05319405], [83.62958527, 18.05291557], [83.62874603, 18.05291939], [83.62874603, 18.05264091], [83.62847137, 18.05264091], [83.62847137, 18.05236053], [83.62625122, 18.05236053], [83.62625122, 18.05208015], [83.62596893, 18.05208397], [83.62596893, 18.05125046], [83.62568665, 18.05125046], [83.62568665, 18.05097961], [83.62513733, 18.05097961], [83.62513733, 18.05070114], [83.62458038, 18.0506897], [83.62458038, 18.05041695], [83.62431335, 18.05042076], [83.62431335, 18.04986], [83.62347412, 18.04986191], [83.62347412, 18.04958344], [83.62291718, 18.04958344], [83.62291718, 18.04930305], [83.62264252, 18.04931068], [83.62264252, 18.0490303], [83.6220932, 18.0490303], [83.6220932, 18.04874992], [83.62180328, 18.04874992], [83.62180328, 18.04846954], [83.62124634, 18.04847145], [83.62124634, 18.04819489], [83.62097168, 18.04819489], [83.62097168, 18.04791641], [83.62039948, 18.04792023], [83.62039948, 18.04763985], [83.62014008, 18.04763985], [83.62014008, 18.04735947], [83.61958313, 18.04736137], [83.61958313, 18.0470829], [83.61930847, 18.0470829], [83.61930847, 18.04680634], [83.61846924, 18.04681015], [83.61846924, 18.04652977], [83.61818695, 18.04652977], [83.61818695, 18.04624939], [83.61791992, 18.04624939], [83.61791992, 18.04597282], [83.61736298, 18.04597282], [83.61736298, 18.04569435], [83.61708069, 18.04569435], [83.61708069, 18.04541588], [83.61653137, 18.04541969], [83.61653137, 18.04514122], [83.6159668, 18.04514122], [83.6159668, 18.0448494], [83.61569214, 18.04486275], [83.61569214, 18.04458427], [83.61486053, 18.04458427], [83.61486053, 18.0443058], [83.61429596, 18.04430962], [83.61429596, 18.04403114], [83.61402893, 18.04403114], [83.61402893, 18.04375076], [83.61347198, 18.04375076], [83.61347198, 18.04346848], [83.61264038, 18.04347229], [83.61264038, 18.04319382], [83.61208344, 18.04319382], [83.61208344, 18.04291725], [83.61180878, 18.04291916], [83.61180878, 18.04264069], [83.61068726, 18.04264069], [83.61068726, 18.0423584], [83.61042023, 18.0423584], [83.61042023, 18.04207993], [83.61013794, 18.04208374], [83.61013794, 18.04180527], [83.60986328, 18.04180908], [83.60986328, 18.04153061], [83.60958099, 18.04153061], [83.60958099, 18.04124832], [83.60901642, 18.04124832], [83.60901642, 18.04096985], [83.60847473, 18.04097176], [83.60847473, 18.04069519], [83.60819244, 18.04070091], [83.60819244, 18.04042053], [83.60791779, 18.04042053], [83.60791779, 18.03957939], [83.6076355, 18.03958321], [83.6076355, 18.03902626], [83.60708618, 18.03903961], [83.60708618, 18.03874969], [83.60597229, 18.03874969], [83.60597229, 18.03847122], [83.60541534, 18.03847313], [83.60541534, 18.03819466], [83.60514069, 18.03819466], [83.60514069, 18.03791428], [83.6048584, 18.03792], [83.6048584, 18.03763962], [83.60430908, 18.03763962], [83.60430908, 18.03736115], [83.60402679, 18.03736115], [83.60402679, 18.03708076], [83.60346985, 18.03708267], [83.60346985, 18.0368042], [83.60320282, 18.03680992], [83.60320282, 18.03625107], [83.6029129, 18.03625107], [83.6029129, 18.03598022], [83.60264587, 18.03598022], [83.60264587, 18.03569031], [83.60236359, 18.03569412], [83.60236359, 18.03513908], [83.6020813, 18.03514099], [83.6020813, 18.03486061], [83.60151672, 18.03486061], [83.60151672, 18.03458023], [83.60097504, 18.03458214], [83.60097504, 18.03430557], [83.60069275, 18.03430939], [83.60069275, 18.03403091], [83.6001358, 18.03403091], [83.6001358, 18.03375053], [83.59986115, 18.03375053], [83.59986115, 18.03347015], [83.59958649, 18.03347206], [83.59958649, 18.03319359], [83.5993042, 18.03319359], [83.5993042, 18.03291702], [83.59902954, 18.03291702], [83.59902954, 18.03263855], [83.59874725, 18.03264046], [83.59874725, 18.03236008], [83.59819794, 18.03236389], [83.59819794, 18.03208351], [83.59764099, 18.03208351], [83.59764099, 18.03180504], [83.5973587, 18.03181267], [83.5973587, 18.03153038], [83.59707642, 18.03153038], [83.59707642, 18.03125191], [83.59680176, 18.03125191], [83.59680176, 18.03097153], [83.5965271, 18.03097153], [83.5965271, 18.03069496], [83.59625244, 18.03070259], [83.59625244, 18.0304203], [83.59597015, 18.0304203], [83.59597015, 18.03014183], [83.59570313, 18.03014183], [83.59570313, 18.0298481], [83.59541321, 18.02986145], [83.59541321, 18.02958298], [83.59513855, 18.02958298], [83.59513855, 18.02930641], [83.5945816, 18.02931023], [83.5945816, 18.02902985], [83.59430695, 18.02902985], [83.59430695, 18.02874756], [83.59375, 18.02874756], [83.59375, 18.02846909], [83.59347534, 18.0284729], [83.59347534, 18.02819443], [83.59319305, 18.02819443], [83.59319305, 18.02791786], [83.5929184, 18.02791977], [83.5929184, 18.02763748], [83.59236145, 18.02763748], [83.59236145, 18.02736092], [83.59208679, 18.02736092], [83.59208679, 18.02708054], [83.5918045, 18.02708244], [83.5918045, 18.02680779], [83.59152985, 18.02680969], [83.59152985, 18.02653122], [83.59124756, 18.02653122], [83.59124756, 18.02625084], [83.59069824, 18.02625084], [83.59069061, 18.02597237], [83.59041595, 18.02597237], [83.59041595, 18.02569389], [83.5901413, 18.02569389], [83.5901413, 18.02541542], [83.58985901, 18.02542114], [83.58985901, 18.02514076], [83.58957672, 18.02514076], [83.58957672, 18.02486038], [83.58847046, 18.02486038], [83.58847046, 18.02458], [83.5881958, 18.02458382], [83.5881958, 18.02430534], [83.58790588, 18.02431107], [83.58790588, 18.02404022], [83.58763885, 18.02404022], [83.58763885, 18.02375031], [83.58708191, 18.02375031], [83.58708191, 18.02346992], [83.58680725, 18.02347183], [83.58680725, 18.02319336], [83.58651733, 18.02320099], [83.58651733, 18.02292061], [83.58598328, 18.02292061], [83.58598328, 18.02264023], [83.58569336, 18.02264023], [83.58569336, 18.02207947], [83.5854187, 18.02208328], [83.5854187, 18.02180481], [83.58513641, 18.02180481], [83.58513641, 18.02152824], [83.58486176, 18.02153015], [83.58486176, 18.02124977], [83.58403015, 18.02124977], [83.58403015, 18.02153015], [83.58319092, 18.02153015], [83.58319092, 18.02124977], [83.58291626, 18.02124977], [83.58291626, 18.02096939], [83.5826416, 18.0209713], [83.5826416, 18.02069473], [83.58235931, 18.02069473], [83.58235931, 18.02013969], [83.58207703, 18.02013969], [83.58207703, 18.01986122], [83.58180237, 18.01986122], [83.58180237, 18.01958275], [83.58152771, 18.01958275], [83.58152771, 18.01930618], [83.58125305, 18.01930618], [83.58125305, 18.01958275], [83.58041382, 18.01958275], [83.58041382, 18.01930618], [83.58013916, 18.01931], [83.58013916, 18.01902962], [83.57985687, 18.01902962], [83.57985687, 18.01847267], [83.57958221, 18.01847267], [83.57958221, 18.0181942], [83.57875061, 18.0181942], [83.57875061, 18.01791763], [83.57791901, 18.01791573], [83.57791901, 18.01763916], [83.57763672, 18.01764107], [83.57763672, 18.01736069], [83.57736206, 18.01736069], [83.57736206, 18.0170784], [83.57680511, 18.01708412], [83.57680511, 18.01680565], [83.57569122, 18.01680946], [83.57569122, 18.01652908], [83.57514191, 18.01652908], [83.57514191, 18.01625061], [83.57430267, 18.01625061], [83.57430267, 18.01708412], [83.57402802, 18.01708412], [83.57402802, 18.01791573], [83.57347107, 18.01791763], [83.57347107, 18.0181942], [83.57263947, 18.0181942], [83.57263947, 18.01763916], [83.57234955, 18.01764107], [83.57234955, 18.0170784], [83.57208252, 18.01708412], [83.57208252, 18.01625061], [83.57290649, 18.01625061], [83.57290649, 18.01568985], [83.57319641, 18.01569366], [83.57319641, 18.0154171], [83.57290649, 18.01542091], [83.57290649, 18.01485062], [83.57263947, 18.01486206], [83.57263947, 18.01458359], [83.57152557, 18.01458359], [83.57152557, 18.01430511], [83.57041931, 18.01431084], [83.57041931, 18.01374817], [83.57013702, 18.01374817], [83.57013702, 18.01320076], [83.56986237, 18.01320076], [83.56986237, 18.01292038], [83.56931305, 18.01292038], [83.56931305, 18.01263809], [83.56846619, 18.01263809], [83.56846619, 18.01235962], [83.56819153, 18.01236153], [83.56819153, 18.0118084], [83.56735992, 18.0118103], [83.56735992, 18.01152992], [83.5670929, 18.01152992], [83.5670929, 18.01124954], [83.56485748, 18.01124954], [83.56485748, 18.01097107], [83.56458282, 18.01097298], [83.56458282, 18.01013947], [83.56485748, 18.01013947], [83.56485748, 18.00986099], [83.56569672, 18.00986099], [83.56569672, 18.00875092], [83.56597137, 18.00875092], [83.56597137, 18.00847054], [83.56625366, 18.00847244], [83.56625366, 18.00763893], [83.56597137, 18.00764084], [83.56597137, 18.00736046], [83.56569672, 18.00736046], [83.56569672, 18.00681114], [83.5654068, 18.00681114], [83.5654068, 18.00653076], [83.56513977, 18.00653076], [83.56513977, 18.00625038], [83.56485748, 18.00625038], [83.56485748, 18.00570107], [83.56458282, 18.00570107], [83.56458282, 18.00542068], [83.56430817, 18.00542068], [83.56430817, 18.0051403], [83.56458282, 18.0051403], [83.56458282, 18.00486183], [83.56430817, 18.00486183], [83.56430817, 18.00451088], [83.56430817, 18.00430489], [83.56402588, 18.00430489], [83.56402588, 18.00402832], [83.56375122, 18.00403023], [83.56375122, 18.00318909], [83.56346893, 18.00319481], [83.56346893, 18.00291634], [83.56291962, 18.00291634], [83.56291962, 18.00264168], [83.56124878, 18.00264168], [83.56124878, 18.00235748], [83.56097412, 18.0023613], [83.56097412, 18.00180626], [83.56040955, 18.00180817], [83.56040955, 18.00041962], [83.56014252, 18.00041962], [83.56014252, 18.00014114], [83.55986023, 18.00014114], [83.55986023, 17.99986839], [83.55986023, 17.99958038], [83.55958557, 17.9995842], [83.55958557, 17.99902534], [83.55930328, 17.99903107], [83.55930328, 17.99707985], [83.55902863, 17.99708366], [83.55902863, 17.99680519], [83.55874634, 17.99681091], [83.55874634, 17.99291992], [83.55902863, 17.99291992], [83.55902863, 17.99152946], [83.55930328, 17.99152946], [83.55930328, 17.99041939], [83.5595932, 17.99041939], [83.5595932, 17.98986053], [83.55986023, 17.98986053], [83.55986023, 17.98957825], [83.56014252, 17.98958397], [83.56014252, 17.9893055], [83.56040955, 17.98930931], [83.56040955, 17.9879303], [83.56014252, 17.9879303], [83.56014252, 17.98735809], [83.55986023, 17.98736191], [83.55986023, 17.98680496], [83.5595932, 17.98681068], [83.5595932, 17.98624992], [83.55930328, 17.98624992], [83.55930328, 17.98569107], [83.55902863, 17.98569679], [83.55902863, 17.98347282], [83.55874634, 17.98347282], [83.55874634, 17.98319435], [83.55847168, 17.98319435], [83.55847168, 17.98291588], [83.55819702, 17.98291969], [83.55819702, 17.98264122], [83.5579071, 17.98264122], [83.5579071, 17.98236084], [83.55764008, 17.98236084], [83.55764008, 17.98208046], [83.55735779, 17.98208427], [83.55735779, 17.98152733], [83.55708313, 17.98153114], [83.55708313, 17.98125076], [83.55680847, 17.98125076], [83.55680847, 17.98097038], [83.55652618, 17.98097229], [83.55652618, 17.98041725], [83.55625153, 17.98042107], [83.55625153, 17.98014069], [83.55596924, 17.98014069], [83.55596924, 17.97986031], [83.55568695, 17.97986031], [83.55568695, 17.97958183], [83.55513763, 17.97958374], [83.55513763, 17.97930527], [83.55486298, 17.9793129], [83.55486298, 17.97903061], [83.55458069, 17.97903061], [83.55458069, 17.97874069], [83.55430603, 17.97875023], [83.55430603, 17.97847176], [83.55403137, 17.97847176], [83.55403137, 17.97819519], [83.5534668, 17.97820282], [83.5534668, 17.97792053], [83.55319214, 17.97792053], [83.55319214, 17.97764015], [83.55291748, 17.97764015], [83.55291748, 17.97736168], [83.55263519, 17.97736168], [83.55263519, 17.97708321], [83.55236053, 17.97708321], [83.55236053, 17.97680473], [83.55208588, 17.97680473], [83.55208588, 17.97652817], [83.55153656, 17.97653008], [83.55153656, 17.9762516], [83.55124664, 17.9762516], [83.55124664, 17.97596931], [83.55097198, 17.97597313], [83.55097198, 17.97569466], [83.55069733, 17.97570229], [83.55069733, 17.97541809], [83.55042267, 17.97541809], [83.55042267, 17.97486115], [83.55014038, 17.97486115], [83.55014038, 17.97458076], [83.54985809, 17.97458267], [83.54985809, 17.97430611], [83.54957581, 17.97430992], [83.54957581, 17.97375107], [83.54930878, 17.97375107], [83.54930878, 17.97347069], [83.54902649, 17.9734726], [83.54902649, 17.97319412], [83.54875183, 17.97319412], [83.54875183, 17.97263718], [83.54846954, 17.97264099], [83.54846954, 17.97236061], [83.54817963, 17.97236061], [83.54817963, 17.97208023], [83.54792023, 17.97208595], [83.54792023, 17.97180557], [83.54763794, 17.97180939], [83.54763794, 17.97153091], [83.54736328, 17.97153091], [83.54736328, 17.97125053], [83.54708099, 17.97125053], [83.54708099, 17.97097015], [83.54680634, 17.97097206], [83.54680634, 17.97013855], [83.54651642, 17.97014046], [83.54651642, 17.96903038], [83.54624939, 17.96903038], [83.54624939, 17.9679203], [83.5459671, 17.9679203], [83.5459671, 17.96708107], [83.54569244, 17.96708488], [83.54569244, 17.96652794], [83.54541016, 17.96652985], [83.54541016, 17.9659729], [83.5451355, 17.9659729], [83.5451355, 17.96569443], [83.54486084, 17.96569443], [83.54486084, 17.96513939], [83.54458618, 17.96513939], [83.54458618, 17.96458244], [83.54430389, 17.96458244], [83.54430389, 17.9640274], [83.54402924, 17.96403122], [83.54402924, 17.96346855], [83.54374695, 17.96347237], [83.54374695, 17.96319389], [83.54347229, 17.96319389], [83.54347229, 17.96291733], [83.54319763, 17.96291924], [83.54319763, 17.96264076], [83.54292297, 17.96264076], [83.54292297, 17.96235847], [83.54264069, 17.96235847], [83.54264069, 17.96207809], [83.54208374, 17.96208382], [83.54208374, 17.96180534], [83.54180908, 17.96180916], [83.54180908, 17.96153069], [83.54152679, 17.96153069], [83.54152679, 17.96125031], [83.54125214, 17.96125031], [83.54125214, 17.96096992], [83.54096985, 17.96097183], [83.54096985, 17.96069527], [83.54070282, 17.96069908], [83.54070282, 17.96042061], [83.5404129, 17.96042061], [83.5404129, 17.96014023], [83.53985596, 17.96014023], [83.53985596, 17.95985985], [83.5395813, 17.95986176], [83.5395813, 17.95958328], [83.53930664, 17.95958328], [83.53930664, 17.95930481], [83.53902435, 17.95930481], [83.53902435, 17.95902634], [83.53848267, 17.95903015], [83.53848267, 17.95874977], [83.53819275, 17.95874977], [83.53819275, 17.95846939], [83.53791809, 17.9584713], [83.53791809, 17.95819473], [83.5376358, 17.95819473], [83.5376358, 17.95791435], [83.53708649, 17.95792007], [83.53708649, 17.95763016], [83.5368042, 17.95763969], [83.5368042, 17.95736122], [83.53652954, 17.95736122], [83.53652954, 17.95708084], [83.53624725, 17.95708275], [83.53624725, 17.95680428], [83.5359726, 17.95681], [83.5359726, 17.95652962], [83.53569794, 17.95652962], [83.53569794, 17.95625114], [83.53514099, 17.95625114], [83.53514099, 17.95597076], [83.5348587, 17.95597267], [83.5348587, 17.9556942], [83.53458405, 17.9556942], [83.53458405, 17.95541763], [83.53430176, 17.95541954], [83.53430176, 17.95514107], [83.5340271, 17.95514107], [83.5340271, 17.95486069], [83.53375244, 17.95486069], [83.53375244, 17.95430946], [83.53347015, 17.95430946], [83.53347015, 17.95403099], [83.53320313, 17.95403099], [83.53320313, 17.95347023], [83.53291321, 17.95347214], [83.53291321, 17.95319366], [83.53263855, 17.95319366], [83.53263855, 17.9529171], [83.53235626, 17.95292282], [83.53235626, 17.95236015], [83.5320816, 17.95236206], [83.5320816, 17.95208359], [83.53180695, 17.95208359], [83.53180695, 17.95180511], [83.53151703, 17.95182037], [83.53151703, 17.95153046], [83.53125, 17.95153046], [83.53125, 17.95125008], [83.53097534, 17.95125008], [83.53097534, 17.95069504], [83.53069305, 17.95070267], [83.53069305, 17.95042038], [83.53042603, 17.95042038], [83.53042603, 17.95014191], [83.53013611, 17.95014191], [83.53013611, 17.94986153], [83.52986145, 17.94986153], [83.52986145, 17.94958305], [83.52958679, 17.94958305], [83.52958679, 17.94930649], [83.52874756, 17.9493103], [83.52874756, 17.94902992], [83.52819824, 17.94902992], [83.52819061, 17.94875908], [83.52736664, 17.94875908], [83.52736664, 17.94846916], [83.52680206, 17.94847298], [83.52680206, 17.9481945], [83.52597046, 17.9481945], [83.52597046, 17.94791794], [83.52540588, 17.94791985], [83.52540588, 17.94763947], [83.52485657, 17.94763947], [83.52485657, 17.94735909], [83.52429962, 17.94735909], [83.52429962, 17.94708061], [83.52375031, 17.94708252], [83.52375031, 17.94680786], [83.52319336, 17.94680977], [83.52319336, 17.94652939], [83.52263641, 17.94652939], [83.52263641, 17.94625092], [83.5220871, 17.94625092], [83.5220871, 17.94597054], [83.52153015, 17.94597244], [83.52153015, 17.94569397], [83.52097321, 17.94569397], [83.52097321, 17.9454155], [83.52041626, 17.94542122], [83.52041626, 17.94514084], [83.5201416, 17.94514084], [83.5201416, 17.94486046], [83.51957703, 17.94486046], [83.51957703, 17.94458008], [83.51930237, 17.94458389], [83.51930237, 17.94430542], [83.51875305, 17.94431114], [83.51875305, 17.94403076], [83.51847076, 17.94403076], [83.51847076, 17.94375038], [83.51790619, 17.94375038], [83.51790619, 17.94347], [83.51763916, 17.94347191], [83.51763916, 17.94319534], [83.51708221, 17.94320107], [83.51708221, 17.94292068], [83.51680756, 17.94292068], [83.51680756, 17.94263077], [83.51625061, 17.9426384], [83.51625061, 17.94236183], [83.51597595, 17.94236183], [83.51597595, 17.94208336], [83.51569366, 17.94208336], [83.51569366, 17.94180489], [83.51513672, 17.94180489], [83.51513672, 17.94152832], [83.51486206, 17.94153023], [83.51486206, 17.94124985], [83.51430511, 17.94124985], [83.51430511, 17.94097137], [83.51403046, 17.94097137], [83.51403046, 17.94069481], [83.51374817, 17.94069481], [83.51374817, 17.94013977], [83.51346588, 17.94013977], [83.51346588, 17.93985939], [83.51319122, 17.9398613], [83.51319122, 17.93958282], [83.51291656, 17.93959045], [83.51291656, 17.93931007], [83.51264191, 17.93931007], [83.51264191, 17.93875122], [83.51235962, 17.93875122], [83.51235962, 17.93847275], [83.51208496, 17.93847275], [83.51208496, 17.93819427], [83.51180267, 17.93819427], [83.51180267, 17.9379158], [83.51125336, 17.93791962], [83.51125336, 17.93764114], [83.51097107, 17.93764114], [83.51097107, 17.93736267], [83.51040649, 17.93736267], [83.51040649, 17.93707848], [83.50986481, 17.9370842], [83.50986481, 17.93680573], [83.50958252, 17.93682289], [83.50958252, 17.93652916], [83.5090332, 17.93652916], [83.5090332, 17.93625069], [83.50846863, 17.93625069], [83.50846863, 17.9359684], [83.50791931, 17.93597221], [83.50791931, 17.93569374], [83.50763702, 17.93569374], [83.50763702, 17.93541718], [83.50708008, 17.93541908], [83.50708008, 17.93514061], [83.50653076, 17.93514061], [83.50653076, 17.93485832], [83.50596619, 17.93485832], [83.50596619, 17.93457985], [83.50541687, 17.93458366], [83.50541687, 17.93430519], [83.50485992, 17.93431091], [83.50485992, 17.93403053], [83.50430298, 17.93403053], [83.50430298, 17.93374825], [83.50374603, 17.93374825], [83.50374603, 17.93346977], [83.50319672, 17.93347168], [83.50319672, 17.93319511], [83.50263977, 17.93320084], [83.50263977, 17.93292046], [83.50208282, 17.93292046], [83.50208282, 17.93264008], [83.50152588, 17.93264008], [83.50152588, 17.9323597], [83.50096893, 17.9323616], [83.50096893, 17.93208313], [83.50041962, 17.93208313], [83.50041962, 17.93180466], [83.49986267, 17.93180466], [83.49986267, 17.93152618], [83.49903107, 17.93153], [83.49903107, 17.93124962], [83.49846649, 17.93124962], [83.49846649, 17.93097115], [83.49791718, 17.93097305], [83.49791718, 17.93069458], [83.49736023, 17.93069458], [83.49736023, 17.9304142], [83.49680328, 17.93041992], [83.49680328, 17.93013954], [83.49652863, 17.93013954], [83.49652863, 17.92986107], [83.49597168, 17.92986107], [83.49597168, 17.92958069], [83.49541473, 17.9295826], [83.49541473, 17.92930412], [83.49485779, 17.92930984], [83.49485779, 17.92902946], [83.4943161, 17.92902946], [83.4943161, 17.92875099], [83.49402618, 17.92875099], [83.49402618, 17.92847061], [83.49346924, 17.92847252], [83.49346924, 17.92819214], [83.49319458, 17.92819214], [83.49319458, 17.92791748], [83.49291992, 17.92791939], [83.49291992, 17.92765045], [83.49236298, 17.92765045], [83.49236298, 17.92736053], [83.49208069, 17.92736053], [83.49208069, 17.92708015], [83.49180603, 17.92708206], [83.49180603, 17.9268055], [83.49125671, 17.92681122], [83.49125671, 17.92653084], [83.49041748, 17.92653084], [83.49041748, 17.92625046], [83.48986053, 17.92625046], [83.48986053, 17.92597008], [83.48902893, 17.92597389], [83.48902893, 17.92569542], [83.48792267, 17.9256897], [83.48791504, 17.92541695], [83.48764038, 17.92542267], [83.48764038, 17.92514038], [83.48735809, 17.92514038], [83.48735809, 17.92486191], [83.48708344, 17.92486191], [83.48708344, 17.92430496], [83.48680878, 17.92431259], [83.48680878, 17.9240303], [83.48652649, 17.9240303], [83.48652649, 17.92375183], [83.48625183, 17.92375183], [83.48625183, 17.92347145], [83.48569489, 17.92347145], [83.48569489, 17.92319489], [83.48542023, 17.92319489], [83.48542023, 17.92291641], [83.48486328, 17.92292023], [83.48486328, 17.92264175], [83.48430634, 17.92264175], [83.48430634, 17.92235756], [83.48402405, 17.92236137], [83.48402405, 17.9220829], [83.48347473, 17.9220829], [83.48347473, 17.92180634], [83.48291779, 17.92180824], [83.48291779, 17.92152977], [83.48236084, 17.92152977], [83.48236084, 17.92124748], [83.48208618, 17.92124748], [83.48208618, 17.92097092], [83.48152924, 17.92097282], [83.48152924, 17.92069435], [83.48097229, 17.92069435], [83.48097229, 17.92041779], [83.48069763, 17.92041969], [83.48069763, 17.92014122], [83.48014069, 17.92014122], [83.48014069, 17.91986084], [83.47957611, 17.91986084], [83.47957611, 17.91958046], [83.47930908, 17.91958427], [83.47930908, 17.91930771], [83.47875214, 17.91930962], [83.47875214, 17.91903114], [83.47820282, 17.91903114], [83.47820282, 17.91875076], [83.47763824, 17.91875076], [83.47763824, 17.91846085], [83.47744751, 17.91846085], [83.47736359, 17.91819382], [83.47680664, 17.91819382], [83.47680664, 17.91791534], [83.47651672, 17.91792107], [83.47651672, 17.91764069], [83.47598267, 17.91764069], [83.47598267, 17.91736031], [83.47569275, 17.91736031], [83.47569275, 17.91707993], [83.4751358, 17.91708374], [83.4751358, 17.91680527], [83.47486115, 17.91681099], [83.47486115, 17.91653061], [83.47429657, 17.91653061], [83.47429657, 17.91625023], [83.47402954, 17.91625023], [83.47402954, 17.91596985], [83.4734726, 17.91597176], [83.4734726, 17.91569328], [83.47319031, 17.91571045], [83.47319031, 17.91542053], [83.4723587, 17.91542053], [83.4723587, 17.91514015], [83.47180176, 17.91514015], [83.47180176, 17.91485977], [83.4706955, 17.91486168], [83.4706955, 17.91458321], [83.47013855, 17.91458321], [83.47013855, 17.91430473], [83.46986389, 17.91430473], [83.46986389, 17.91402817], [83.4695816, 17.91403008], [83.4695816, 17.91374969], [83.46930695, 17.91374969], [83.46930695, 17.91347122], [83.46902466, 17.91347122], [83.46902466, 17.91319466], [83.46875, 17.91319466], [83.46875, 17.91291618], [83.46848297, 17.91292], [83.46848297, 17.91265106], [83.46819305, 17.91265106], [83.46819305, 17.91236115], [83.4679184, 17.91236115], [83.4679184, 17.91208267], [83.46763611, 17.91208267], [83.46763611, 17.91180611], [83.46736145, 17.91181183], [83.46736145, 17.91152954], [83.46708679, 17.91152954], [83.46708679, 17.91125107], [83.46679687, 17.91125107], [83.46679687, 17.91069031], [83.46652985, 17.91069412], [83.46652985, 17.91041756], [83.46624756, 17.91041946], [83.46624756, 17.91013908], [83.4659729, 17.91013908], [83.4659729, 17.90986061], [83.46569824, 17.90986061], [83.46569061, 17.90957832], [83.46541595, 17.90958405], [83.46541595, 17.90930557], [83.4651413, 17.90930939], [83.4651413, 17.90903091], [83.46485901, 17.90903091], [83.46485901, 17.90875053], [83.46457672, 17.90875053], [83.46457672, 17.90846825], [83.46430206, 17.90847206], [83.46430206, 17.90819359], [83.4640274, 17.90819359], [83.4640274, 17.90791893], [83.46375275, 17.90792084], [83.46375275, 17.90764046], [83.4631958, 17.90764046], [83.4631958, 17.90735817], [83.46291351, 17.90736198], [83.46291351, 17.90708351], [83.46263885, 17.90708351], [83.46263885, 17.90680695], [83.46235657, 17.90681076], [83.46235657, 17.90652084], [83.46208191, 17.90652657], [83.46208191, 17.90624809], [83.46180725, 17.90624809], [83.46180725, 17.90596962], [83.46152496, 17.90597153], [83.46152496, 17.90569687], [83.46125031, 17.90570068], [83.46125031, 17.9054203], [83.46098328, 17.9054203], [83.46098328, 17.90513992], [83.46069336, 17.90513992], [83.46069336, 17.90485954], [83.4604187, 17.90486145], [83.4604187, 17.90458298], [83.46013641, 17.90458107], [83.46013641, 17.9054203], [83.4604187, 17.9054184], [83.4604187, 17.90597153], [83.46069336, 17.90597153], [83.46069336, 17.90708351], [83.4604187, 17.9070797], [83.4604187, 17.90764046], [83.46013641, 17.90764046], [83.46013641, 17.90875053], [83.45986176, 17.90875053], [83.45986176, 17.91236115], [83.4595871, 17.91236115], [83.4595871, 17.91458321], [83.45930481, 17.91458321], [83.45930481, 17.91847229], [83.4595871, 17.91846085], [83.4595871, 17.92014122], [83.45903015, 17.92014122], [83.45903015, 17.92041969], [83.45874786, 17.92041779], [83.45874786, 17.92097282], [83.45847321, 17.92097092], [83.45847321, 17.92124748], [83.45791626, 17.92124748], [83.45791626, 17.92097092], [83.4576416, 17.92097282], [83.4576416, 17.92069435], [83.45735931, 17.92069435], [83.45735931, 17.91902542], [83.4576416, 17.91903114], [83.4576416, 17.91875076], [83.45791626, 17.91875076], [83.45791626, 17.91846085], [83.45819092, 17.91847229], [83.45819092, 17.91208267], [83.45847321, 17.91208267], [83.45847321, 17.9109726], [83.45874786, 17.9109726], [83.45874786, 17.90847206], [83.45903015, 17.90847206], [83.45903015, 17.90569687], [83.45874786, 17.90570068], [83.45874786, 17.9054203], [83.45847321, 17.9054203], [83.45847321, 17.90513992], [83.45819092, 17.90513992], [83.45819092, 17.90485954], [83.4576416, 17.90486145], [83.4576416, 17.90458298], [83.45708466, 17.90458298], [83.45708466, 17.9043045], [83.45680237, 17.90431023], [83.45680237, 17.90402985], [83.45625305, 17.90402985], [83.45625305, 17.90374947], [83.45597076, 17.90374947], [83.45597076, 17.90345955], [83.45569611, 17.9034729], [83.45569611, 17.90319443], [83.45402527, 17.90319443], [83.45402527, 17.90291405], [83.45347595, 17.90291977], [83.45347595, 17.90263939], [83.45318604, 17.90263939], [83.45318604, 17.90180969], [83.45263672, 17.90180969], [83.45263672, 17.90125084], [83.45236206, 17.90125084], [83.45236206, 17.90097046], [83.45207977, 17.90097237], [83.45207977, 17.90069389], [83.45180511, 17.90069389], [83.45180511, 17.90013885], [83.45153046, 17.90014076], [83.45153046, 17.89653015], [83.45181274, 17.89653015], [83.45181274, 17.89569092], [83.45207977, 17.89569473], [83.45207977, 17.89513969], [83.45236206, 17.89513969], [83.45236206, 17.89458084], [83.45263672, 17.89458275], [83.45263672, 17.89430618], [83.45291901, 17.89430809], [83.45291901, 17.89402962], [83.45347595, 17.89402962], [83.45347595, 17.89375114], [83.4540329, 17.89375114], [83.4540329, 17.89347076], [83.45430756, 17.89347267], [83.45430756, 17.8931942], [83.45458221, 17.8931942], [83.45458221, 17.89263725], [83.45485687, 17.89264107], [83.45485687, 17.89236069], [83.45514679, 17.89236069], [83.45513916, 17.89208412], [83.45541382, 17.89208412], [83.45541382, 17.89041519], [83.45514679, 17.89042091], [83.45514679, 17.88903046], [83.45485687, 17.88903046], [83.45485687, 17.88820076], [83.45458221, 17.88820076], [83.45458221, 17.88764], [83.45430756, 17.88764], [83.45430756, 17.88735962], [83.45402527, 17.88736153], [83.45402527, 17.88680649], [83.45375061, 17.8868103], [83.45375061, 17.88652992], [83.45347595, 17.88652992], [83.45347595, 17.88624954], [83.45291901, 17.88624954], [83.45291901, 17.88597107], [83.45263672, 17.88597107], [83.45263672, 17.8856945], [83.45236206, 17.8856945], [83.45236206, 17.88541603], [83.45181274, 17.88541985], [83.45181274, 17.88513947], [83.45124817, 17.88513947], [83.45124817, 17.8848629], [83.45096588, 17.8848629], [83.45096588, 17.88458252], [83.45069122, 17.88458252], [83.45069122, 17.88430595], [83.45041656, 17.88430977], [83.45041656, 17.88402939], [83.45014191, 17.88402939], [83.45014191, 17.88375092], [83.44957733, 17.88375092], [83.44957733, 17.88346863], [83.44930267, 17.88347244], [83.44930267, 17.88319397], [83.44902802, 17.88319397], [83.44902802, 17.8829174], [83.44875336, 17.88291931], [83.44875336, 17.88264084], [83.44847107, 17.88264084], [83.44847107, 17.88235092], [83.44819641, 17.88236046], [83.44819641, 17.88208389], [83.44791412, 17.88208389], [83.44791412, 17.88180542], [83.44763947, 17.88180923], [83.44763947, 17.88153076], [83.44735718, 17.88153076], [83.44735718, 17.88125038], [83.44708252, 17.88125038], [83.44708252, 17.88096809], [83.44680786, 17.88097191], [83.44680786, 17.88069534], [83.4465332, 17.88069916], [83.4465332, 17.8801403], [83.44638824, 17.8801403], [83.44625092, 17.8801403], [83.44625092, 17.87957954], [83.44596863, 17.87958336], [83.44596863, 17.87902641], [83.44568634, 17.87903023], [83.44568634, 17.87846947], [83.44541931, 17.87847137], [83.44541931, 17.87791443], [83.44513702, 17.87792015], [83.44513702, 17.87735939], [83.44486237, 17.8773613], [83.44486237, 17.87680435], [83.44458008, 17.87681007], [83.44458008, 17.87514114], [83.44431305, 17.87514114], [83.44431305, 17.87319183], [83.44403076, 17.87319374], [83.44403076, 17.8726387], [83.44374847, 17.87264061], [83.44374847, 17.87236023], [83.44291687, 17.87236023], [83.44291687, 17.87208176], [83.44235992, 17.87208366], [83.44235992, 17.87180519], [83.44152832, 17.87181282], [83.44152832, 17.87153053], [83.44069672, 17.87153053], [83.44069672, 17.87125015], [83.43958282, 17.87125015], [83.43958282, 17.87097168], [83.43902588, 17.87097168], [83.43902588, 17.87069511], [83.43875122, 17.87070274], [83.43875122, 17.87041092], [83.43819427, 17.87041664], [83.43819427, 17.87013817], [83.43791962, 17.87014008], [83.43791962, 17.8698616], [83.43736267, 17.8698616], [83.43736267, 17.86958313], [83.43708038, 17.86958313], [83.43708038, 17.86930466], [83.43653107, 17.86930466], [83.43653107, 17.86902809], [83.43624878, 17.86903191], [83.43624878, 17.86874962], [83.43569183, 17.86874962], [83.43569183, 17.86846924], [83.43541718, 17.86847305], [83.43541718, 17.86819458], [83.43486023, 17.86819458], [83.43486023, 17.86791611], [83.43430328, 17.86791992], [83.43430328, 17.86763954], [83.43374634, 17.86763954], [83.43374634, 17.86734962], [83.43347168, 17.86736107], [83.43347168, 17.8670826], [83.43319702, 17.8670826], [83.43319702, 17.86680794], [83.43264008, 17.86680984], [83.43264008, 17.86652946], [83.43208313, 17.86652946], [83.43208313, 17.86625099], [83.43180847, 17.86625099], [83.43180847, 17.86597061], [83.43125153, 17.86597252], [83.43125153, 17.86569405], [83.43096924, 17.86569405], [83.43096924, 17.86541557], [83.43041992, 17.86541939], [83.43041992, 17.86514091], [83.42986298, 17.86514091], [83.42986298, 17.86486053], [83.42958069, 17.86486053], [83.42958069, 17.86458015], [83.42903137, 17.86458588], [83.42903137, 17.8643055], [83.42874908, 17.86431122], [83.42874908, 17.86403084], [83.42819214, 17.86403084], [83.42819214, 17.86375046], [83.42791748, 17.86375046], [83.42791748, 17.86347008], [83.42736053, 17.86347198], [83.42736053, 17.86319733], [83.42708588, 17.8631897], [83.42708588, 17.86291695], [83.42679596, 17.86292076], [83.42679596, 17.86264038], [83.42624664, 17.86264038], [83.42624664, 17.86236], [83.42597198, 17.86236191], [83.42597198, 17.86208344], [83.42569733, 17.86208344], [83.42569733, 17.86180305], [83.42514038, 17.86181068], [83.42514038, 17.86153984], [83.42485046, 17.86153984], [83.42485046, 17.86124992], [83.42457581, 17.86124992], [83.42457581, 17.86096954], [83.42402649, 17.86097145], [83.42402649, 17.86069489], [83.42375183, 17.86069489], [83.42375183, 17.86041641], [83.42346954, 17.86042023], [83.42346954, 17.86013985], [83.42318726, 17.86013985], [83.42318726, 17.85985947], [83.42263794, 17.85986137], [83.42263794, 17.8595829], [83.42236328, 17.8595829], [83.42236328, 17.85930634], [83.42208099, 17.85931015], [83.42208099, 17.85902977], [83.42151642, 17.85902977], [83.42151642, 17.85874939], [83.42124939, 17.85874939], [83.42124939, 17.85847282], [83.42069244, 17.85847282], [83.42069244, 17.85819435], [83.42041779, 17.85819435], [83.42041779, 17.85791588], [83.42014313, 17.85791969], [83.42014313, 17.85764122], [83.41986084, 17.85764122], [83.41986084, 17.85736275], [83.41929626, 17.85736275], [83.41929626, 17.85707855], [83.41902924, 17.85708427], [83.41902924, 17.8568058], [83.41874695, 17.85680962], [83.41874695, 17.85625076], [83.41847229, 17.85625076], [83.41847229, 17.85596848], [83.41819763, 17.85597229], [83.41819763, 17.85569382], [83.41791534, 17.85569382], [83.41791534, 17.85514069], [83.41764069, 17.85514069], [83.41764069, 17.8548584], [83.41707611, 17.8548584], [83.41707611, 17.85457993], [83.41680908, 17.85458374], [83.41680908, 17.85375023], [83.41652679, 17.85375023], [83.41652679, 17.85346985], [83.41625214, 17.85347176], [83.41625214, 17.85291862], [83.41597748, 17.85292053], [83.41597748, 17.85264015], [83.41570282, 17.85264015], [83.41570282, 17.85237122], [83.41513824, 17.85237122], [83.41513824, 17.85207939], [83.41486359, 17.85208321], [83.41486359, 17.85180473], [83.4145813, 17.85180473], [83.4145813, 17.85124969], [83.41430664, 17.85124969], [83.41430664, 17.85097122], [83.41402435, 17.85097313], [83.41402435, 17.84986115], [83.41374969, 17.84986115], [83.41374969, 17.84958076], [83.41347504, 17.84958267], [83.41347504, 17.84902763], [83.41319275, 17.84902954], [83.41319275, 17.84875107], [83.41291046, 17.84875107], [83.41291046, 17.84819031], [83.4126358, 17.84819221], [83.4126358, 17.84791756], [83.41236115, 17.84791946], [83.41236115, 17.84764099], [83.41208649, 17.84764099], [83.41208649, 17.84708023], [83.4118042, 17.84708214], [83.4118042, 17.84625053], [83.41152954, 17.84625053], [83.41152954, 17.84597206], [83.41124725, 17.84597206], [83.41124725, 17.84541702], [83.4109726, 17.84542274], [83.4109726, 17.84486008], [83.41069794, 17.84486008], [83.41069794, 17.84430504], [83.41042328, 17.84431267], [83.41042328, 17.84375191], [83.41014099, 17.84375191], [83.41014099, 17.84347153], [83.4098587, 17.84347153], [83.4098587, 17.83986092], [83.41014099, 17.83986092], [83.41014099, 17.83903122], [83.41042328, 17.83903122], [83.41042328, 17.83847046], [83.41069794, 17.83847237], [83.41069794, 17.83763885], [83.4109726, 17.83764076], [83.4109726, 17.83708], [83.41124725, 17.83708382], [83.41124725, 17.83680534], [83.41152954, 17.83681107], [83.41152954, 17.83653069], [83.41179657, 17.83653069], [83.41179657, 17.83625031], [83.41236115, 17.83625031], [83.41236115, 17.83596992], [83.4126358, 17.83597183], [83.4126358, 17.83569336], [83.41291046, 17.83570099], [83.41291046, 17.83542061], [83.4154129, 17.83542061], [83.4154129, 17.83514023], [83.41570282, 17.83514023], [83.41570282, 17.83374977], [83.41596985, 17.83374977], [83.41596985, 17.83013916], [83.41570282, 17.83013916], [83.41570282, 17.82319069], [83.4154129, 17.8231945], [83.4154129, 17.82263947], [83.41513824, 17.82263947], [83.41513824, 17.82180977], [83.41485596, 17.82180977], [83.41485596, 17.82097054], [83.4145813, 17.82097244], [83.4145813, 17.8204174], [83.41430664, 17.82042122], [83.41430664, 17.81986046], [83.41401672, 17.81986046], [83.41401672, 17.8192997], [83.41374969, 17.81930542], [83.41374969, 17.81902695], [83.41348267, 17.81903076], [83.41348267, 17.81875038], [83.41319275, 17.81875038], [83.41319275, 17.81820107], [83.41291046, 17.81820107], [83.41291046, 17.81792259], [83.4126358, 17.81792259], [83.4126358, 17.81736183], [83.41236115, 17.81736183], [83.41236115, 17.81680489], [83.41208649, 17.81680489], [83.41208649, 17.81625175], [83.41179657, 17.81625938], [83.41179657, 17.81568909], [83.41152954, 17.81569481], [83.41152954, 17.81513977], [83.41124725, 17.81513977], [83.41124725, 17.81430817], [83.4109726, 17.81430817], [83.4109726, 17.81375122], [83.41069794, 17.81375122], [83.41069794, 17.81208038], [83.41041565, 17.8120842], [83.41041565, 17.81180763], [83.41014099, 17.81180954], [83.41014099, 17.81042099], [83.40985107, 17.81042099], [83.40985107, 17.81014061], [83.40930176, 17.81014061], [83.40930176, 17.80986023], [83.4090271, 17.80986023], [83.4090271, 17.80957985], [83.40875244, 17.80958366], [83.40875244, 17.80930328], [83.40847015, 17.80931091], [83.40847015, 17.80903053], [83.40791321, 17.80903053], [83.40791321, 17.80875015], [83.40763855, 17.80875015], [83.40763855, 17.80846977], [83.40736389, 17.80847168], [83.40736389, 17.80819321], [83.4070816, 17.80820084], [83.4070816, 17.80792046], [83.40651703, 17.80792046], [83.40651703, 17.8073597], [83.40625, 17.8073616], [83.40625, 17.80708313], [83.40597534, 17.80708313], [83.40597534, 17.80680466], [83.40569305, 17.80680466], [83.40569305, 17.80652809], [83.4054184, 17.80653], [83.4054184, 17.80624962], [83.40513611, 17.80624962], [83.40513611, 17.80597115], [83.40486145, 17.80597115], [83.40486145, 17.80569458], [83.40458679, 17.80569458], [83.40458679, 17.80541611], [83.40429688, 17.80541992], [83.40429688, 17.80513954], [83.40402985, 17.80513954], [83.40402985, 17.80486107], [83.40374756, 17.80486107], [83.40374756, 17.8045826], [83.4034729, 17.8045826], [83.4034729, 17.80430603], [83.40319824, 17.80431938], [83.40319061, 17.80402946], [83.40291595, 17.80402946], [83.40291595, 17.8037529], [83.40235901, 17.8037529], [83.40235901, 17.80347061], [83.40208435, 17.80347252], [83.40208435, 17.80319405], [83.4015274, 17.80319405], [83.4015274, 17.80264091], [83.40097046, 17.80264091], [83.40097046, 17.80236053], [83.4006958, 17.80236053], [83.4006958, 17.80207825], [83.40013885, 17.80208397], [83.40013885, 17.8018055], [83.39985657, 17.80180931], [83.39985657, 17.80153084], [83.39930725, 17.80153084], [83.39930725, 17.8012619], [83.39875031, 17.8012619], [83.39875031, 17.80069923], [83.39848328, 17.8006897], [83.39847565, 17.80013657], [83.39819336, 17.80014038], [83.39819336, 17.79957962], [83.3979187, 17.79958344], [83.3979187, 17.79902649], [83.39763641, 17.7990303], [83.39763641, 17.79846954], [83.39736176, 17.79847145], [83.39736176, 17.79791832], [83.3970871, 17.79792023], [83.3970871, 17.79763985], [83.39653015, 17.79763985], [83.39653015, 17.79735947], [83.39611053, 17.79736137], [83.39569092, 17.79736137], [83.39569092, 17.79680443], [83.39541626, 17.79681015], [83.39541626, 17.79652977], [83.39485168, 17.79652977], [83.39485168, 17.79624939], [83.39430237, 17.79624939], [83.39430237, 17.79597092], [83.39402771, 17.79597282], [83.39402771, 17.79569435], [83.39375305, 17.79569435], [83.39375305, 17.79541588], [83.39319611, 17.79541969], [83.39319611, 17.79512978], [83.39291382, 17.79513931], [83.39291382, 17.79486084], [83.39235687, 17.79486084], [83.39235687, 17.79458046], [83.39208221, 17.79458237], [83.39208221, 17.7943058], [83.39180756, 17.79430962], [83.39180756, 17.79403114], [83.3915329, 17.79403114], [83.3915329, 17.79375076], [83.39125061, 17.79375076], [83.39125061, 17.79292107], [83.39097595, 17.79292107], [83.39097595, 17.79264069], [83.39068604, 17.79264069], [83.39068604, 17.79206848], [83.39041901, 17.79208374], [83.39041901, 17.79125023], [83.39013672, 17.79125023], [83.39013672, 17.79070282], [83.38986206, 17.79070282], [83.38986206, 17.79042053], [83.38957977, 17.79042053], [83.38957977, 17.79014015], [83.38931274, 17.79014015], [83.38931274, 17.78986168], [83.38903046, 17.78986168], [83.38903046, 17.78958321], [83.38819122, 17.78958321], [83.38819122, 17.78874969], [83.38791656, 17.78874969], [83.38791656, 17.78847122], [83.38764191, 17.78847313], [83.38764191, 17.78819466], [83.38735962, 17.78819466], [83.38735962, 17.78791618], [83.38707733, 17.78791809], [83.38707733, 17.78763962], [83.38680267, 17.78763962], [83.38680267, 17.78680992], [83.38652802, 17.78680992], [83.38652802, 17.7862606], [83.38625336, 17.7862606], [83.38625336, 17.78597069], [83.38597107, 17.7859726], [83.38597107, 17.78541565], [83.38569641, 17.78541946], [83.38569641, 17.78486061], [83.38540649, 17.78486061], [83.38540649, 17.78430939], [83.38513947, 17.78430939], [83.38513947, 17.78375053], [83.38485718, 17.78375053], [83.38485718, 17.78236008], [83.38513947, 17.78236198], [83.38513947, 17.78125], [83.38540649, 17.78125], [83.38540649, 17.78096962], [83.38569641, 17.78097153], [83.38569641, 17.78013802], [83.38597107, 17.78013802], [83.38597107, 17.77902794], [83.38569641, 17.77902985], [83.38569641, 17.7784729], [83.38541412, 17.7784729], [83.38541412, 17.77791595], [83.38513947, 17.77791977], [83.38513947, 17.77763939], [83.38485718, 17.77763939], [83.38485718, 17.77736282], [83.38458252, 17.77736282], [83.38458252, 17.77709007], [83.3840332, 17.77709007], [83.3840332, 17.77680969], [83.38375092, 17.77680969], [83.38375092, 17.77652931], [83.38346863, 17.77652931], [83.38346863, 17.77625084], [83.38318634, 17.77625084], [83.38318634, 17.77596855], [83.38263702, 17.77597237], [83.38263702, 17.77569389], [83.38208008, 17.77569389], [83.38208008, 17.77541733], [83.38153076, 17.77541924], [83.38153076, 17.77514076], [83.38096619, 17.77514076], [83.38096619, 17.77486038], [83.38069153, 17.77486038], [83.38069153, 17.77457809], [83.38014221, 17.77458382], [83.38014221, 17.77430534], [83.37986755, 17.77432251], [83.37986755, 17.77403069], [83.3795929, 17.77403069], [83.3795929, 17.77375031], [83.37902832, 17.77375031], [83.37902832, 17.77346992], [83.37875366, 17.77347183], [83.37875366, 17.77319527], [83.37847137, 17.77319908], [83.37847137, 17.77292061], [83.3779068, 17.77292061], [83.3779068, 17.77264023], [83.37763977, 17.77264023], [83.37763977, 17.77235985], [83.37735748, 17.77236176], [83.37735748, 17.77208328], [83.37680817, 17.77208328], [83.37680817, 17.77180481], [83.37652588, 17.77180481], [83.37652588, 17.77152634], [83.37596893, 17.77153015], [83.37596893, 17.77124977], [83.37568665, 17.77124977], [83.37568665, 17.77095985], [83.37541962, 17.7709713], [83.37541962, 17.77069664], [83.37486267, 17.77069664], [83.37486267, 17.77041435], [83.37458038, 17.77042007], [83.37458038, 17.77013969], [83.37430573, 17.77013969], [83.37430573, 17.76986122], [83.37374115, 17.76986122], [83.37374115, 17.76958084], [83.37347412, 17.76958275], [83.37347412, 17.76930428], [83.37291718, 17.76931], [83.37291718, 17.76902962], [83.37236023, 17.76902962], [83.37236023, 17.76875114], [83.37180328, 17.76875114], [83.37180328, 17.76847076], [83.37152863, 17.76847267], [83.37152863, 17.7681942], [83.37097168, 17.7681942], [83.37097168, 17.76791763], [83.3704071, 17.76791954], [83.3704071, 17.76764107], [83.36985779, 17.76764107], [83.36985779, 17.76736069], [83.36930847, 17.76736069], [83.36930847, 17.76708031], [83.36875153, 17.76708221], [83.36875153, 17.76680565], [83.36818695, 17.76680946], [83.36818695, 17.7665329], [83.36763763, 17.7665329], [83.36763763, 17.76625061], [83.36736298, 17.76625061], [83.36736298, 17.76597023], [83.36680603, 17.76597214], [83.36680603, 17.76569366], [83.36624908, 17.76569366], [83.36624908, 17.7654171], [83.36569214, 17.76542282], [83.36569214, 17.76515007], [83.36458588, 17.76515007], [83.36458588, 17.76486015], [83.36402893, 17.76486015], [83.36402893, 17.76458359], [83.36374664, 17.76458359], [83.36374664, 17.76430511], [83.36347198, 17.76431274], [83.36347198, 17.76403046], [83.36319733, 17.76403046], [83.36319733, 17.76375008], [83.36264038, 17.76375008], [83.36264038, 17.7634716], [83.36235809, 17.7634716], [83.36235809, 17.76319504], [83.36207581, 17.76320267], [83.36207581, 17.76292038], [83.36152649, 17.76292038], [83.36152649, 17.76264191], [83.36125183, 17.76264191], [83.36125183, 17.76236153], [83.36096954, 17.76236153], [83.36096954, 17.76208305], [83.36068726, 17.76209259], [83.36068726, 17.7618084], [83.36042023, 17.7618084], [83.36042023, 17.76152992], [83.35986328, 17.76152992], [83.35986328, 17.76124954], [83.35901642, 17.76124954], [83.35901642, 17.76096916], [83.35874939, 17.76097298], [83.35874939, 17.7606945], [83.35819244, 17.7606945], [83.35819244, 17.76041794], [83.35791779, 17.76041985], [83.35791779, 17.76013947], [83.3576355, 17.76013947], [83.3576355, 17.75986099], [83.35708618, 17.75986099], [83.35708618, 17.75958061], [83.35680389, 17.75958252], [83.35680389, 17.75930786], [83.35652924, 17.75930977], [83.35652924, 17.75901985], [83.35624695, 17.75902557], [83.35624695, 17.75875092], [83.35597229, 17.75875092], [83.35597229, 17.75847054], [83.35569763, 17.75847244], [83.35569763, 17.75819397], [83.35541534, 17.75819397], [83.35541534, 17.7579155], [83.35514069, 17.75792122], [83.35514069, 17.75764084], [83.3548584, 17.75764084], [83.3548584, 17.75736046], [83.35457611, 17.75736046], [83.35457611, 17.75708008], [83.35430908, 17.7570858], [83.35430908, 17.75597191], [83.35402679, 17.75597191], [83.35402679, 17.75569344], [83.35375214, 17.75570107], [83.35375214, 17.75542068], [83.35346985, 17.75542068], [83.35346985, 17.75485992], [83.35319519, 17.75486183], [83.35319519, 17.75430489], [83.3529129, 17.75430489], [83.3529129, 17.75402832], [83.35263824, 17.75403023], [83.35263824, 17.75346947], [83.35236359, 17.75347137], [83.35236359, 17.75319481], [83.3520813, 17.75319481], [83.3520813, 17.75263977], [83.35180664, 17.75263977], [83.35180664, 17.75235939], [83.35152435, 17.7523613], [83.35152435, 17.75208282], [83.35124969, 17.75208282], [83.35124969, 17.75180626], [83.35098267, 17.75181007], [83.35098267, 17.75152969], [83.35069275, 17.75152969], [83.35069275, 17.75125122], [83.35041809, 17.75125122], [83.35041809, 17.75097275], [83.34986115, 17.75097275], [83.34986115, 17.75069427], [83.34902954, 17.75069427], [83.34902954, 17.7504158], [83.34929657, 17.75041962], [83.34929657, 17.74986076], [83.34958649, 17.74986076], [83.34958649, 17.74957848], [83.34986115, 17.7495842], [83.34986115, 17.74930573], [83.35041809, 17.74930954], [83.35041809, 17.74875069], [83.35069275, 17.74875069], [83.35069275, 17.74818993], [83.35097504, 17.74819374], [83.35097504, 17.74764061], [83.35069275, 17.74764061], [83.35069275, 17.74707985], [83.35041809, 17.74708366], [83.35041809, 17.74652863], [83.3501358, 17.74653053], [83.3501358, 17.74625015], [83.34986115, 17.74625015], [83.34986115, 17.74596977], [83.34958649, 17.74597168], [83.34958649, 17.74569511], [83.34929657, 17.74570084], [83.34929657, 17.74542046], [83.34902954, 17.74542046], [83.34902954, 17.74514008], [83.34874725, 17.74514008], [83.34874725, 17.7448597], [83.3473587, 17.7448616], [83.3473587, 17.74458313], [83.3465271, 17.74458313], [83.3465271, 17.74430466], [83.34625244, 17.74430466], [83.34625244, 17.74374962], [83.34597015, 17.74374962], [83.34597015, 17.74319077], [83.3456955, 17.74319458], [83.3456955, 17.74263954], [83.34541321, 17.74263954], [83.34541321, 17.74236107], [83.34513855, 17.74236107], [83.34513855, 17.74180984], [83.34485626, 17.74180984], [83.34485626, 17.74125099], [83.3445816, 17.74125099], [83.3445816, 17.74069023], [83.34430695, 17.74069214], [83.34430695, 17.74013901], [83.34401703, 17.74014091], [83.34401703, 17.73958015], [83.34375, 17.73958206], [83.34375, 17.73902702], [83.34348297, 17.73903275], [83.34348297, 17.73847008], [83.34319305, 17.73847389], [83.34319305, 17.73791695], [83.3429184, 17.73792267], [83.3429184, 17.73736191], [83.34263611, 17.73736191], [83.34263611, 17.73541641], [83.3429184, 17.73542023], [83.3429184, 17.73389053], [83.3429184, 17.73347282], [83.34319305, 17.73347282], [83.34319305, 17.73263931], [83.34348297, 17.73264122], [83.34348297, 17.73153114], [83.34375763, 17.73153114], [83.34375763, 17.73125076], [83.34402466, 17.73125076], [83.34401703, 17.73042107], [83.34430695, 17.73042107], [83.34430695, 17.72986031], [83.3445816, 17.72986031], [83.3445816, 17.72957993], [83.34513855, 17.72958374], [83.34513855, 17.72930336], [83.34570313, 17.72931099], [83.34570313, 17.72820091], [83.34541321, 17.72820091], [83.34541321, 17.72735977], [83.34513855, 17.72736168], [83.34513855, 17.72652817], [83.34485626, 17.72653008], [83.34485626, 17.72569275], [83.3445816, 17.72569466], [83.3445816, 17.72513962], [83.34430695, 17.72513962], [83.34430695, 17.72486115], [83.34375, 17.72486115], [83.34375, 17.72458267], [83.34319305, 17.72458267], [83.34319305, 17.72402763], [83.3429184, 17.72402954], [83.3429184, 17.72375107], [83.34263611, 17.72375107], [83.34263611, 17.72347069], [83.34208679, 17.7234726], [83.34208679, 17.72319412], [83.3418045, 17.72319412], [83.3418045, 17.72291756], [83.34124756, 17.72291756], [83.34124756, 17.72263908], [83.34069824, 17.72263908], [83.34069824, 17.72236061], [83.34041595, 17.72236061], [83.34041595, 17.72207832], [83.33985901, 17.72208405], [83.33985901, 17.72180557], [83.33930206, 17.72180939], [83.33930206, 17.72153091], [83.33875275, 17.72153091], [83.33875275, 17.72125053], [83.33850098, 17.72125053], [83.3381958, 17.72125053], [83.3381958, 17.72096825], [83.3373642, 17.72097206], [83.3373642, 17.72069359], [83.33680725, 17.72069359], [83.33680725, 17.72041893], [83.33625031, 17.72042084], [83.33625031, 17.72014046], [83.33569336, 17.72014046], [83.33569336, 17.71985054], [83.33513641, 17.71986198], [83.33513641, 17.71958351], [83.3345871, 17.71958351], [83.3345871, 17.71930695], [83.33374786, 17.71931076], [83.33374786, 17.71903038], [83.33319092, 17.71903038], [83.33319092, 17.71874809], [83.3326416, 17.71874809], [83.3326416, 17.71846962], [83.33208466, 17.71847153], [83.33208466, 17.71819687], [83.33152771, 17.71820068], [83.33152771, 17.7179203], [83.33097076, 17.7179203], [83.33097076, 17.71763992], [83.33040619, 17.71763992], [83.33040619, 17.71735954], [83.3298645, 17.71736145], [83.3298645, 17.71708298], [83.32930756, 17.71708298], [83.32930756, 17.7168045], [83.32875824, 17.71681023], [83.32875824, 17.71652985], [83.32818604, 17.71652985], [83.32818604, 17.71624947], [83.32763672, 17.71624947], [83.32763672, 17.71597099], [83.32707977, 17.7159729], [83.32707977, 17.71569443], [83.32653046, 17.71569443], [83.32653046, 17.71541405], [83.32596588, 17.71541977], [83.32596588, 17.71513939], [83.32541656, 17.71513939], [83.32541656, 17.71486092], [83.32485962, 17.71486092], [83.32485962, 17.71458054], [83.32430267, 17.71458244], [83.32430267, 17.71430588], [83.32375336, 17.71430969], [83.32375336, 17.71404076], [83.32319641, 17.71404076], [83.32319641, 17.71375084], [83.32290649, 17.71375084], [83.32290649, 17.71347046], [83.32236481, 17.71347237], [83.32236481, 17.71319389], [83.32180786, 17.71319389], [83.32180786, 17.71291733], [83.32125092, 17.71292114], [83.32125092, 17.71264076], [83.32096863, 17.71264076], [83.32096863, 17.71236038], [83.32041931, 17.71236038], [83.32041931, 17.71208191], [83.31986237, 17.71208382], [83.31986237, 17.71180534], [83.31931305, 17.71181107], [83.31931305, 17.71153069], [83.31903076, 17.71153069], [83.31903076, 17.71125031], [83.31846619, 17.71125031], [83.31846619, 17.71097183], [83.31791687, 17.71097183], [83.31791687, 17.71069527], [83.31735992, 17.7107029], [83.31735992, 17.71042252], [83.3170929, 17.71042252], [83.3170929, 17.71014023], [83.31652832, 17.71014023], [83.31652832, 17.70986176], [83.31625366, 17.70986176], [83.31625366, 17.70958328], [83.31597137, 17.70958328], [83.31597137, 17.70930481], [83.31541443, 17.70930481], [83.31541443, 17.70902824], [83.31513977, 17.70903015], [83.31513977, 17.70874977], [83.31485748, 17.70874977], [83.31485748, 17.70846748], [83.31458282, 17.7084713], [83.31458282, 17.70819473], [83.31430817, 17.70819473], [83.31430817, 17.70791626], [83.31402588, 17.70791626], [83.31402588, 17.70763969], [83.31346893, 17.70763969], [83.31346893, 17.70736122], [83.31318665, 17.70736122], [83.31318665, 17.70708084], [83.31291962, 17.70708275], [83.31291962, 17.70680618], [83.31263733, 17.70680809], [83.31263733, 17.70652962], [83.31236267, 17.70652962], [83.31236267, 17.70625114], [83.31208038, 17.70625114], [83.31208038, 17.70597076], [83.31153107, 17.70597267], [83.31153107, 17.7056942], [83.31124878, 17.7056942], [83.31124878, 17.70541763], [83.31096649, 17.70541954], [83.31096649, 17.70514107], [83.31069183, 17.70514107], [83.31069183, 17.70485115], [83.31014252, 17.70486069], [83.31014252, 17.70458412], [83.30986023, 17.70458412], [83.30986023, 17.70430756], [83.3095932, 17.70430946], [83.3095932, 17.70403099], [83.30902863, 17.70403099], [83.30902863, 17.70375061], [83.30874634, 17.70375061], [83.30874634, 17.70347023], [83.30847168, 17.70347214], [83.30847168, 17.70319366], [83.30819702, 17.70319366], [83.30819702, 17.70291519], [83.30764771, 17.70292091], [83.30764771, 17.70264053], [83.30735779, 17.70264053], [83.30735779, 17.70236015], [83.30708313, 17.70236206], [83.30708313, 17.70208359], [83.30652618, 17.70208359], [83.30652618, 17.70180321], [83.30625153, 17.70181084], [83.30625153, 17.70125008], [83.30596924, 17.70125008], [83.30596924, 17.70042038], [83.30568695, 17.70042038], [83.30568695, 17.6981926], [83.30596924, 17.6981945], [83.30596924, 17.69791603], [83.30625153, 17.69791985], [83.30625153, 17.6973629], [83.30513763, 17.6973629], [83.30513763, 17.69763947], [83.30486298, 17.69763947], [83.30486298, 17.69791985], [83.30458069, 17.69791603], [83.30458069, 17.6981945], [83.30319214, 17.6981945], [83.30319214, 17.69791603], [83.30264282, 17.69791985], [83.30264282, 17.69763947], [83.30236053, 17.69763947], [83.30236053, 17.69681168], [83.30264282, 17.69681168], [83.30264282, 17.69652939], [83.30291748, 17.69652939], [83.30291748, 17.69625092], [83.30319214, 17.69625092], [83.30319214, 17.69597054], [83.30347443, 17.69597244], [83.30347443, 17.69569397], [83.30374908, 17.69569397], [83.30374908, 17.6954174], [83.30403137, 17.69541931], [83.30403137, 17.69514084], [83.30541992, 17.69514084], [83.30541992, 17.69541931], [83.30569458, 17.6954174], [83.30569458, 17.69597244], [83.30596924, 17.69597054], [83.30596924, 17.69625092], [83.30625153, 17.69625092], [83.30625153, 17.69652939], [83.30652618, 17.69652939], [83.30652618, 17.69681168], [83.30680847, 17.69680595], [83.30680847, 17.69708252], [83.30735779, 17.69708252], [83.30735779, 17.6973629], [83.30764008, 17.6973629], [83.30764008, 17.69763947], [83.30819702, 17.69763947], [83.30819702, 17.69681168], [83.30764771, 17.69681168], [83.30764771, 17.69652939], [83.30735779, 17.69652939], [83.30735779, 17.69625092], [83.30708313, 17.69625092], [83.30708313, 17.69568062], [83.30680847, 17.69569397], [83.30680847, 17.69514084], [83.30652618, 17.69514084], [83.30652618, 17.6914711], [83.30652618, 17.69124985], [83.30680847, 17.69124985], [83.30680847, 17.68931007], [83.30652618, 17.68931007], [83.30652618, 17.68819046], [83.30596924, 17.68819046], [83.30596924, 17.68931007], [83.30625153, 17.68930435], [83.30625153, 17.69097137], [83.30596924, 17.69097137], [83.30596924, 17.69123077], [83.30596924, 17.69291878], [83.30568695, 17.69291115], [83.30568695, 17.69319916], [83.30236053, 17.69319916], [83.30236053, 17.69375038], [83.30208588, 17.69375038], [83.30208588, 17.69430923], [83.30179596, 17.69430923], [83.30179596, 17.69486046], [83.3015213, 17.69486046], [83.3015213, 17.69541931], [83.30124664, 17.6954174], [83.30124664, 17.69597244], [83.30014038, 17.69597244], [83.30014038, 17.69569397], [83.29985809, 17.69569397], [83.29985809, 17.6954174], [83.29930878, 17.69541931], [83.29930878, 17.69514084], [83.29957581, 17.69514084], [83.29957581, 17.69486046], [83.29985809, 17.69486046], [83.29985809, 17.69457817], [83.30014038, 17.69458389], [83.30014038, 17.69430542], [83.30042267, 17.69430923], [83.30042267, 17.69403076], [83.30069733, 17.69403076], [83.30069733, 17.69375038], [83.30124664, 17.69375038], [83.30124664, 17.69346809], [83.30152893, 17.69347191], [83.30152893, 17.69319534], [83.30179596, 17.69319916], [83.30179596, 17.69291115], [83.30152893, 17.69291878], [83.30152893, 17.69263649], [83.30124664, 17.6926403], [83.30124664, 17.69207954], [83.30097198, 17.69208336], [83.30097198, 17.69236183], [83.30069733, 17.69235992], [83.30069733, 17.6926403], [83.30041504, 17.69263649], [83.30041504, 17.69291878], [83.29985809, 17.69291115], [83.29985809, 17.69319916], [83.29958344, 17.69319534], [83.29958344, 17.69347191], [83.29902649, 17.69346809], [83.29902649, 17.69375038], [83.29875183, 17.69375038], [83.29875183, 17.69403076], [83.29846191, 17.69403076], [83.29846191, 17.69430923], [83.29763794, 17.69430923], [83.29763794, 17.69403076], [83.29736328, 17.69403076], [83.29736328, 17.69375038], [83.29708099, 17.69375038], [83.29708099, 17.69319916], [83.29736328, 17.69319916], [83.29736328, 17.69291115], [83.29763794, 17.69291878], [83.29763794, 17.69263649], [83.29818726, 17.6926403], [83.29818726, 17.69235992], [83.29875183, 17.69236183], [83.29875183, 17.69208336], [83.29902649, 17.69208336], [83.29902649, 17.69180679], [83.29930878, 17.69180679], [83.29930878, 17.69152641], [83.29957581, 17.69153023], [83.29957581, 17.69042015], [83.29875183, 17.69041443], [83.29875183, 17.69069672], [83.29818726, 17.69069099], [83.29818726, 17.69124985], [83.29792023, 17.69124985], [83.29792023, 17.69153023], [83.29763794, 17.69152641], [83.29763794, 17.69180679], [83.29708099, 17.69180679], [83.29708099, 17.69152641], [83.29680634, 17.69153023], [83.29680634, 17.69124985], [83.29651642, 17.69124985], [83.29651642, 17.69096947], [83.29624939, 17.69097137], [83.29624939, 17.69069672], [83.29597473, 17.69069672], [83.29597473, 17.69041443], [83.29569244, 17.69042015], [83.29569244, 17.69013977], [83.29541779, 17.69013977], [83.29541779, 17.68987083], [83.29514313, 17.68987083], [83.29514313, 17.68958092], [83.29486084, 17.68958282], [83.29486084, 17.68930435], [83.29402924, 17.68931007], [83.29402924, 17.68902969], [83.29319763, 17.68902969], [83.29319763, 17.68875122], [83.29096985, 17.68875122], [83.29096985, 17.68847084], [83.2895813, 17.68847275], [83.2895813, 17.68819427], [83.28791809, 17.68819427], [83.28791809, 17.6879158], [83.28624725, 17.6879158], [83.28624725, 17.68819427], [83.2859726, 17.68819427], [83.2859726, 17.68847275], [83.28430939, 17.68847084], [83.28430176, 17.68875122], [83.2840271, 17.68875122], [83.2840271, 17.68902969], [83.28346252, 17.68902969], [83.28346252, 17.68931007], [83.28235626, 17.68931007], [83.28235626, 17.69013977], [83.2820816, 17.69013977], [83.2820816, 17.69236183], [83.28235626, 17.69235992], [83.28235626, 17.69375038], [83.2820816, 17.69375038], [83.2820816, 17.69458389], [83.28180695, 17.69457817], [83.28180695, 17.69486046], [83.2804184, 17.69486046], [83.2804184, 17.69457817], [83.27986145, 17.69457817], [83.27986145, 17.69486046], [83.27958679, 17.69486046], [83.27958679, 17.69541931], [83.2793045, 17.6954174], [83.2793045, 17.69597244], [83.27902985, 17.69597054], [83.27902985, 17.69681168], [83.27874756, 17.69681168], [83.27874756, 17.6993103], [83.2784729, 17.6993103], [83.2784729, 17.70014], [83.27819824, 17.70014], [83.27819824, 17.70042038], [83.27791595, 17.70042038], [83.27791595, 17.70070076], [83.2776413, 17.70069313], [83.2776413, 17.7009716], [83.27735901, 17.7009697], [83.27735901, 17.70125008], [83.27680206, 17.70125008], [83.27680206, 17.70208359], [83.2765274, 17.70208359], [83.2765274, 17.70236206], [83.27625275, 17.70236015], [83.27625275, 17.70292091], [83.27597046, 17.70291519], [83.27597046, 17.70319366], [83.2756958, 17.70319366], [83.2756958, 17.70347214], [83.27540588, 17.70347023], [83.27540588, 17.70375061], [83.27513885, 17.70375061], [83.27513885, 17.70403099], [83.27458191, 17.70403099], [83.27458191, 17.70430946], [83.27430725, 17.70430756], [83.27430725, 17.70486069], [83.27401733, 17.70485115], [83.27401733, 17.70514107], [83.27375031, 17.70514107], [83.27375031, 17.70541954], [83.27347565, 17.70541763], [83.27347565, 17.70597267], [83.27319336, 17.70597076], [83.27319336, 17.70652962], [83.2729187, 17.70652962], [83.2729187, 17.70708275], [83.27263641, 17.70708084], [83.27263641, 17.70903015], [83.2729187, 17.70902824], [83.2729187, 17.70930481], [83.27319336, 17.70929909], [83.27319336, 17.7107029], [83.2729187, 17.7107029], [83.2729187, 17.71125031], [83.27263641, 17.71125031], [83.27263641, 17.71181107], [83.27236176, 17.71180534], [83.27236176, 17.71208382], [83.2720871, 17.71208191], [83.2720871, 17.71236038], [83.27179718, 17.71236038], [83.27179718, 17.71264076], [83.27069092, 17.71264076], [83.27069092, 17.71292114], [83.2701416, 17.71292114], [83.2701416, 17.71264076], [83.26957703, 17.71264076], [83.26957703, 17.71236038], [83.26930237, 17.71236038], [83.26930237, 17.71208191], [83.26902771, 17.71208382], [83.26902771, 17.71180534], [83.26847839, 17.71181107], [83.26847839, 17.71153069], [83.26819611, 17.71153069], [83.26819611, 17.71125031], [83.26790619, 17.71125031], [83.26790619, 17.71097183], [83.26763916, 17.71097183], [83.26763916, 17.71069527], [83.26735687, 17.7107029], [83.26735687, 17.71014023], [83.26680756, 17.71014023], [83.26680756, 17.71042252], [83.26625061, 17.71042252], [83.26625061, 17.7107029], [83.26569366, 17.71069527], [83.26569366, 17.71097183], [83.26541901, 17.71097183], [83.26541901, 17.71125031], [83.26374817, 17.71125031], [83.26374817, 17.71097183], [83.26347351, 17.71097183], [83.26347351, 17.70958328], [83.26374817, 17.70958328], [83.26374817, 17.70902824], [83.26403046, 17.70903015], [83.26403046, 17.70874977], [83.26457977, 17.70874977], [83.26457977, 17.70846748], [83.26486206, 17.7084713], [83.26486206, 17.70819473], [83.26513672, 17.70819473], [83.26513672, 17.70791626], [83.26625061, 17.70791626], [83.26625061, 17.70597267], [83.26597595, 17.70597267], [83.26597595, 17.7056942], [83.26457977, 17.7056942], [83.26457977, 17.70541763], [83.26346588, 17.70541954], [83.26346588, 17.70514107], [83.26319122, 17.70514107], [83.26319122, 17.70430946], [83.26346588, 17.70430946], [83.26346588, 17.70403099], [83.26431274, 17.70403099], [83.26431274, 17.70430946], [83.26541901, 17.70430756], [83.26541901, 17.70458412], [83.26597595, 17.70458412], [83.26597595, 17.70486069], [83.26930237, 17.70485115], [83.26930237, 17.70514107], [83.27179718, 17.70514107], [83.27179718, 17.70458031], [83.2720871, 17.70458412], [83.2720871, 17.70430756], [83.27236176, 17.70430946], [83.27236176, 17.70318985], [83.27263641, 17.70319366], [83.27263641, 17.70291519], [83.2729187, 17.70292091], [83.2729187, 17.70236015], [83.27319336, 17.70236015], [83.27319336, 17.70207977], [83.27347565, 17.70208359], [83.27347565, 17.70180321], [83.27375031, 17.70181084], [83.27375031, 17.70125008], [83.27401733, 17.70125008], [83.27401733, 17.70042038], [83.27430725, 17.70042038], [83.27430725, 17.70014], [83.27458191, 17.70014], [83.27458191, 17.69958115], [83.2748642, 17.69958115], [83.2748642, 17.69930649], [83.27513885, 17.69930267], [83.27513885, 17.69902802], [83.27540588, 17.69902992], [83.27540588, 17.69874954], [83.2756958, 17.69874954], [83.2756958, 17.69847107], [83.27597046, 17.69847107], [83.27597046, 17.6981945], [83.27625275, 17.6981945], [83.27625275, 17.69791603], [83.2765274, 17.69791985], [83.2765274, 17.69763947], [83.27680206, 17.69763947], [83.27680206, 17.6973629], [83.27735901, 17.6973629], [83.27735901, 17.69708252], [83.2776413, 17.69708252], [83.2776413, 17.69652748], [83.27791595, 17.69652939], [83.27791595, 17.69597054], [83.27819061, 17.69597244], [83.27819824, 17.6954174], [83.2784729, 17.69541931], [83.2784729, 17.69486046], [83.27874756, 17.69486046], [83.27874756, 17.69430923], [83.27902985, 17.69430923], [83.27902985, 17.69403076], [83.2784729, 17.69403076], [83.2784729, 17.69291115], [83.27874756, 17.69291878], [83.27874756, 17.69236183], [83.27902985, 17.69236183], [83.27902985, 17.69180679], [83.2793045, 17.69180679], [83.2793045, 17.69152641], [83.27958679, 17.69153023], [83.27958679, 17.69124985], [83.27986145, 17.69124985], [83.27986145, 17.69096947], [83.28013611, 17.69097137], [83.28013611, 17.69069672], [83.28069305, 17.69069672], [83.28069305, 17.69041443], [83.28098297, 17.69042015], [83.28098297, 17.69013977], [83.28125, 17.69013977], [83.28125, 17.68958092], [83.28152466, 17.68958282], [83.28152466, 17.68874931], [83.28180695, 17.68875122], [83.28180695, 17.68819046], [83.2820816, 17.68819427], [83.2820816, 17.6879158], [83.28235626, 17.68791962], [83.28235626, 17.68764114], [83.28346252, 17.68764114], [83.28346252, 17.68736076], [83.2848587, 17.68736076], [83.2848587, 17.68764114], [83.28569794, 17.68764114], [83.28569794, 17.68736076], [83.2859726, 17.68736076], [83.2859726, 17.68708038], [83.28819275, 17.68708038], [83.28819275, 17.68736076], [83.2904129, 17.68736076], [83.2904129, 17.68764114], [83.29125214, 17.68764114], [83.29125214, 17.68791962], [83.2923584, 17.68791962], [83.2923584, 17.68764114], [83.29319763, 17.68764114], [83.29319763, 17.68736076], [83.29347229, 17.68736076], [83.29347229, 17.68708038], [83.29374695, 17.68708229], [83.29374695, 17.68680573], [83.29402924, 17.68680954], [83.29402924, 17.68653107], [83.29429626, 17.68653107], [83.29429626, 17.68597031], [83.29458618, 17.68597221], [83.29458618, 17.68569374], [83.29541779, 17.68569374], [83.29541779, 17.68597221], [83.2959671, 17.68597031], [83.2959671, 17.68625069], [83.29624939, 17.68625069], [83.29624939, 17.68653107], [83.29708099, 17.68653107], [83.29708099, 17.68680954], [83.29763794, 17.68680954], [83.29763794, 17.68653107], [83.2980423, 17.68652916], [83.29818726, 17.68653107], [83.29818726, 17.6854229], [83.29680634, 17.6854229], [83.29680634, 17.68514061], [83.29572296, 17.68514061], [83.29569244, 17.68486023], [83.29547882, 17.68486023], [83.29458618, 17.68486023], [83.29458618, 17.68394089], [83.29458618, 17.68347168], [83.29430389, 17.68347168], [83.29430389, 17.6823616], [83.29486084, 17.6823616], [83.29486084, 17.68152809], [83.29514313, 17.68152809], [83.29514313, 17.68124962], [83.29569244, 17.68124962], [83.29569244, 17.68097115], [83.29597473, 17.68097305], [83.29597473, 17.67930794], [83.29569244, 17.67930984], [83.29569244, 17.67847061], [83.29541779, 17.67847252], [83.29541779, 17.67513847], [83.29514313, 17.67514038], [83.29514313, 17.67486954], [83.29486084, 17.67486954], [83.29486084, 17.67431068], [83.29458618, 17.67431068], [83.29458618, 17.6740303], [83.29429626, 17.6740303], [83.29429626, 17.67374992], [83.29402924, 17.67374992], [83.29402924, 17.67319107], [83.29374695, 17.67319489], [83.29374695, 17.67291641], [83.29347229, 17.67292023], [83.29347229, 17.67235947], [83.29291534, 17.67236137], [83.29291534, 17.6720829], [83.29264069, 17.6720829], [83.29264069, 17.67180634], [83.29208374, 17.67180634], [83.29208374, 17.67152786], [83.29180908, 17.67152977], [83.29180908, 17.67124939], [83.29125214, 17.67124939], [83.29125214, 17.67097282], [83.29096985, 17.67097282], [83.29096985, 17.67069435], [83.2904129, 17.67069435], [83.2904129, 17.67041588], [83.29013824, 17.67041969], [83.29013824, 17.66986084], [83.28985596, 17.66986084], [83.28985596, 17.66957855], [83.28930664, 17.66958427], [83.28930664, 17.6693058], [83.28901672, 17.66930962], [83.28901672, 17.66902924], [83.28874969, 17.66902924], [83.28874969, 17.66874123], [83.28819275, 17.66875076], [83.28819275, 17.66847229], [83.28806305, 17.66847229], [83.28791809, 17.66847229], [83.28791809, 17.66819382], [83.2876358, 17.66819382], [83.2876358, 17.66791725], [83.28736115, 17.66791916], [83.28736115, 17.66764069], [83.28679657, 17.66764069], [83.28679657, 17.66736031], [83.28652191, 17.66736031], [83.28652191, 17.66707993], [83.28624725, 17.66708374], [83.28624725, 17.66680527], [83.2859726, 17.66680908], [83.2859726, 17.66653061], [83.28542328, 17.66653061], [83.28542328, 17.66625023], [83.28514099, 17.66625023], [83.28514099, 17.66570091], [83.28457642, 17.66570091], [83.28457642, 17.66542053], [83.28430176, 17.66542053], [83.28430176, 17.66514015], [83.2840271, 17.66514015], [83.2840271, 17.66485977], [83.28375244, 17.66486168], [83.28375244, 17.66458321], [83.28347015, 17.66458321], [83.28347015, 17.66374969], [83.28375244, 17.66374969], [83.28375244, 17.66347122], [83.2840271, 17.66347313], [83.2840271, 17.66319656], [83.28375244, 17.66319656], [83.28375244, 17.66263962], [83.28346252, 17.66263962], [83.28346252, 17.66180992], [83.28320313, 17.66180992], [83.28320313, 17.66125107], [83.28291321, 17.66125107], [83.28291321, 17.66069031], [83.28263855, 17.66069221], [83.28263855, 17.66013908], [83.28235626, 17.6601429], [83.28235626, 17.65986061], [83.28125, 17.65986061], [83.28125, 17.6595726], [83.28013611, 17.65958214], [83.28013611, 17.65930557], [83.27902985, 17.65930939], [83.27902985, 17.65903282], [83.2776413, 17.65903282], [83.2776413, 17.65875053], [83.27735901, 17.65875053], [83.27735901, 17.65847015], [83.2765274, 17.65847206], [83.2765274, 17.65791702], [83.27625275, 17.65792274], [83.27625275, 17.65764046], [83.2756958, 17.65764046], [83.2756958, 17.65736008], [83.2748642, 17.65736008], [83.2748642, 17.65708351], [83.27430725, 17.65708351], [83.27430725, 17.65680504], [83.27347565, 17.65680504], [83.27347565, 17.65652847], [83.2729187, 17.65653038], [83.2729187, 17.65625191], [83.27236176, 17.65625191], [83.27236176, 17.65597153], [83.27180481, 17.65597153], [83.27180481, 17.65569496], [83.27124786, 17.65570259], [83.27124786, 17.6554203], [83.27069092, 17.6554203], [83.27069092, 17.65513992], [83.2701416, 17.65513992], [83.2701416, 17.65485764], [83.26958466, 17.65486145], [83.26958466, 17.65458298], [83.26902771, 17.65458298], [83.26902771, 17.65430641], [83.26875305, 17.65430832], [83.26875305, 17.65402985], [83.26819611, 17.65402985], [83.26819611, 17.65376091], [83.26763916, 17.65376091], [83.26763916, 17.65346909], [83.26708221, 17.6534729], [83.26708221, 17.65319443], [83.26652527, 17.65319443], [83.26652527, 17.65291786], [83.26597595, 17.65291977], [83.26597595, 17.65263939], [83.26541901, 17.65263939], [83.26541901, 17.65236092], [83.26486206, 17.65236092], [83.26486206, 17.65208054], [83.26430511, 17.65208244], [83.26430511, 17.65180779], [83.26374817, 17.65180969], [83.26374817, 17.65153122], [83.26319122, 17.65153122], [83.26319122, 17.65125084], [83.26264191, 17.65125084], [83.26264191, 17.65097046], [83.26180267, 17.65097237], [83.26180267, 17.65069389], [83.26152802, 17.65069962], [83.26152802, 17.65042114], [83.26125336, 17.65042114], [83.26125336, 17.65014076], [83.26069641, 17.65014076], [83.26069641, 17.64903069], [83.26097107, 17.64903069], [83.26097107, 17.64875031], [83.26125336, 17.64875031], [83.26125336, 17.64763069], [83.26097107, 17.64763832], [83.26097107, 17.64736176], [83.26069641, 17.64736176], [83.26069641, 17.64708328], [83.26013947, 17.64708328], [83.26013947, 17.64680481], [83.25986481, 17.64680481], [83.25986481, 17.6459713], [83.26013947, 17.6459713], [83.26013947, 17.64569473], [83.26041412, 17.64569473], [83.26041412, 17.64541626], [83.26013947, 17.64542007], [83.26013947, 17.64402962], [83.25985718, 17.64402962], [83.25985718, 17.64375114], [83.25930786, 17.64375114], [83.25930786, 17.64347076], [83.25902557, 17.64347267], [83.25902557, 17.6431942], [83.25875092, 17.6431942], [83.25875092, 17.64291763], [83.25791931, 17.64291954], [83.25791931, 17.64263916], [83.25736237, 17.64263916], [83.25736237, 17.64236069], [83.25680542, 17.64236069], [83.25680542, 17.64208412], [83.25653076, 17.64208412], [83.25653076, 17.64180565], [83.25569153, 17.64182281], [83.25569153, 17.64152908], [83.25485992, 17.64152908], [83.25485992, 17.64125061], [83.25458527, 17.64125061], [83.25458527, 17.64097214], [83.25402832, 17.64097214], [83.25402832, 17.64069366], [83.25375366, 17.64069366], [83.25375366, 17.6404171], [83.25319672, 17.64042091], [83.25319672, 17.64014053], [83.25263977, 17.64014053], [83.25263977, 17.63985825], [83.25208282, 17.63986206], [83.25208282, 17.63958359], [83.25180817, 17.63958359], [83.25180817, 17.63930511], [83.25068665, 17.63931084], [83.25068665, 17.63903046], [83.25013733, 17.63903046], [83.25013733, 17.63875961], [83.24958038, 17.63875961], [83.24958038, 17.6384697], [83.24903107, 17.6384716], [83.24903107, 17.63819695], [83.24819183, 17.63820076], [83.24819183, 17.63792038], [83.24764252, 17.63792038], [83.24764252, 17.63764], [83.2473526, 17.63764], [83.2473526, 17.63735962], [83.24680328, 17.63736153], [83.24680328, 17.63708305], [83.24624634, 17.63708305], [83.24624634, 17.63680458], [83.24597168, 17.6368103], [83.24597168, 17.63652992], [83.2454071, 17.63652992], [83.2454071, 17.63624954], [83.24485779, 17.63624954], [83.24485779, 17.63597107], [83.24458313, 17.63597488], [83.24458313, 17.6356945], [83.24402618, 17.6356945], [83.24402618, 17.63541412], [83.24291992, 17.63541985], [83.24291992, 17.63513947], [83.24263763, 17.63513947], [83.24263763, 17.63486099], [83.24236298, 17.63486099], [83.24236298, 17.63458061], [83.24180603, 17.63458252], [83.24180603, 17.63430405], [83.24124908, 17.63430977], [83.24124908, 17.63402939], [83.2409668, 17.63402939], [83.2409668, 17.63375092], [83.24069214, 17.63375092], [83.24069214, 17.63347054], [83.24013519, 17.63347244], [83.24013519, 17.63319206], [83.23986053, 17.63319206], [83.23986053, 17.63263893], [83.23958588, 17.63263893], [83.23958588, 17.63236046], [83.23929596, 17.63236046], [83.23929596, 17.63208008], [83.23874664, 17.63208389], [83.23874664, 17.63180542], [83.23847198, 17.63181114], [83.23847198, 17.63153267], [83.23819733, 17.63153267], [83.23819733, 17.63125038], [83.23791504, 17.63125038], [83.23791504, 17.63097191], [83.23764038, 17.63097191], [83.23764038, 17.63069534], [83.23735809, 17.63070107], [83.23735809, 17.63042259], [83.23707581, 17.63042259], [83.23707581, 17.6301403], [83.23680878, 17.6301403], [83.23680878, 17.62986183], [83.23625183, 17.62986183], [83.23625183, 17.62958336], [83.23596954, 17.6295929], [83.23596954, 17.62929916], [83.23569489, 17.62930489], [83.23569489, 17.62902832], [83.2354126, 17.62903023], [83.2354126, 17.62846756], [83.23513794, 17.62847137], [83.23513794, 17.62819481], [83.23486328, 17.62819481], [83.23486328, 17.62763977], [83.23458099, 17.62763977], [83.23458099, 17.62735748], [83.23430634, 17.6273613], [83.23430634, 17.62680626], [83.23401642, 17.62682152], [83.23401642, 17.62652969], [83.23374939, 17.62652969], [83.23374939, 17.62597084], [83.23347473, 17.62597275], [83.23347473, 17.62569427], [83.23319244, 17.62569427], [83.23319244, 17.62513924], [83.23291779, 17.62514114], [83.23291779, 17.62430954], [83.23264313, 17.62430954], [83.23264313, 17.62264061], [83.23236847, 17.62264061], [83.23236847, 17.61930275], [83.2326355, 17.61930466], [83.2326355, 17.61902809], [83.2334671, 17.61903], [83.2334671, 17.61874962], [83.23374939, 17.61874962], [83.23374939, 17.61736107], [83.2334671, 17.61736107], [83.2334671, 17.6170826], [83.23319244, 17.6170826], [83.23319244, 17.61680603], [83.23291779, 17.61681175], [83.23291779, 17.61652946], [83.23264313, 17.61652946], [83.23264313, 17.61568832], [83.23291779, 17.61569405], [83.23291779, 17.61514091], [83.233078, 17.61514091], [83.23319244, 17.61514091], [83.23319244, 17.6145916], [83.2334671, 17.6145916], [83.2334671, 17.61403084], [83.23374939, 17.61403084], [83.23374939, 17.61375046], [83.23401642, 17.61375046], [83.23401642, 17.61346817], [83.23430634, 17.61347198], [83.23430634, 17.61319351], [83.23486328, 17.61319351], [83.23486328, 17.61291885], [83.23513794, 17.61292076], [83.23513794, 17.61264038], [83.23596954, 17.61264038], [83.23596954, 17.61292076], [83.23652649, 17.61291885], [83.23652649, 17.61319351], [83.23680878, 17.61319351], [83.23680878, 17.61347198], [83.23764038, 17.61346817], [83.23764038, 17.61375046], [83.23819733, 17.61375046], [83.23819733, 17.61346817], [83.23847198, 17.61347198], [83.23847198, 17.61263657], [83.23819733, 17.61264038], [83.23819733, 17.61181068], [83.23792267, 17.61181068], [83.23792267, 17.6115303], [83.23735809, 17.6115303], [83.23735809, 17.61124992], [83.23680878, 17.61124992], [83.23680878, 17.61096954], [83.23596954, 17.61096954], [83.23596954, 17.61124992], [83.23568726, 17.61124992], [83.23568726, 17.61096954], [83.23542023, 17.61097145], [83.23542023, 17.61069679], [83.23486328, 17.61069679], [83.23486328, 17.61041451], [83.23458099, 17.61042023], [83.23458099, 17.61013985], [83.23430634, 17.61013985], [83.23430634, 17.60985947], [83.23402405, 17.60986137], [83.23402405, 17.6095829], [83.23347473, 17.6095829], [83.23347473, 17.60930443], [83.23319244, 17.60931015], [83.23319244, 17.60902977], [83.23291779, 17.60902977], [83.23291779, 17.60874939], [83.23236084, 17.60874939], [83.23236084, 17.60847473], [83.23208618, 17.60847473], [83.23208618, 17.60819435], [83.23180389, 17.60819435], [83.23180389, 17.60791588], [83.23152924, 17.60791969], [83.23152924, 17.60764122], [83.23124695, 17.60764122], [83.23124695, 17.60736084], [83.23097229, 17.60736084], [83.23097229, 17.60708046], [83.23041534, 17.60708237], [83.23041534, 17.6068058], [83.2298584, 17.60680962], [83.2298584, 17.60653114], [83.22957611, 17.60653114], [83.22957611, 17.60625076], [83.22875214, 17.60625076], [83.22875214, 17.60597038], [83.22763824, 17.60597229], [83.22763824, 17.60569382], [83.2270813, 17.60569382], [83.2270813, 17.60541725], [83.22680664, 17.60542107], [83.22680664, 17.60514069], [83.22651672, 17.60514069], [83.22651672, 17.60486031], [83.22597504, 17.60486031], [83.22597504, 17.60458374], [83.22541809, 17.60458374], [83.22541809, 17.60430527], [83.2251358, 17.6043129], [83.2251358, 17.60403061], [83.22486115, 17.60403061], [83.22486115, 17.60375023], [83.22458649, 17.60375023], [83.22458649, 17.60347176], [83.22402954, 17.60347176], [83.22402954, 17.60319519], [83.2234726, 17.60320282], [83.2234726, 17.60292244], [83.22319794, 17.60292244], [83.22319794, 17.60264969], [83.22292328, 17.60264969], [83.22289276, 17.60236168], [83.2223587, 17.60236168], [83.2223587, 17.60208321], [83.22180176, 17.60208321], [83.22180176, 17.60180473], [83.22097015, 17.60180473], [83.22097015, 17.60152817], [83.22070313, 17.60152817], [83.22070313, 17.60124969], [83.2195816, 17.60124969], [83.2195816, 17.60097122], [83.21902466, 17.60097313], [83.21902466, 17.60069466], [83.21875, 17.60069466], [83.21875, 17.60041618], [83.21848297, 17.60041809], [83.21848297, 17.60013962], [83.2179184, 17.60013962], [83.2179184, 17.59986115], [83.21763611, 17.59986115], [83.21763611, 17.59958076], [83.21736145, 17.59958267], [83.21736145, 17.59930611], [83.21679688, 17.59930992], [83.21679688, 17.59902954], [83.21652985, 17.59902954], [83.21652985, 17.59875107], [83.21624756, 17.59875107], [83.21624756, 17.59847069], [83.2159729, 17.5984726], [83.2159729, 17.59819412], [83.21569824, 17.59819412], [83.21569061, 17.59791756], [83.21541595, 17.59791946], [83.21541595, 17.59680939], [83.21569061, 17.59680939], [83.21569824, 17.59651947], [83.2159729, 17.59652519], [83.2159729, 17.59541512], [83.21569824, 17.59542084], [83.21569061, 17.59403038], [83.2151413, 17.59403038], [83.2151413, 17.59375], [83.21485901, 17.59375], [83.21485901, 17.59320068], [83.21457672, 17.59320068], [83.21457672, 17.5929203], [83.21430206, 17.5929203], [83.21430206, 17.59263992], [83.2140274, 17.59263992], [83.2140274, 17.59152985], [83.21375275, 17.59152985], [83.21375275, 17.59124947], [83.21347046, 17.59124947], [83.21347046, 17.5909729], [83.21291351, 17.5909729], [83.21291351, 17.59069443], [83.21180725, 17.59069443], [83.21180725, 17.59041595], [83.20791626, 17.59041977], [83.20791626, 17.59013939], [83.20735931, 17.59013939], [83.20735931, 17.58986092], [83.20680237, 17.58986092], [83.20680237, 17.58957863], [83.20625305, 17.58958244], [83.20625305, 17.58930588], [83.20569611, 17.5893116], [83.20569611, 17.58902931], [83.20485687, 17.58902931], [83.20485687, 17.58875084], [83.20458221, 17.58875084], [83.20458221, 17.58847046], [83.20347595, 17.58847237], [83.20347595, 17.58819389], [83.20319366, 17.58819389], [83.20319366, 17.58791733], [83.20291901, 17.58791924], [83.20291901, 17.58764076], [83.20263672, 17.58764076], [83.20263672, 17.58736038], [83.20207977, 17.58736038], [83.20207977, 17.58707809], [83.20097351, 17.58708382], [83.20097351, 17.58680534], [83.20041656, 17.58680916], [83.20041656, 17.58653069], [83.19985962, 17.58653069], [83.19985962, 17.58625031], [83.19902802, 17.58625031], [83.19902802, 17.58596992], [83.19875336, 17.58597183], [83.19875336, 17.58569527], [83.19790649, 17.58569908], [83.19790649, 17.58542061], [83.19735718, 17.58542061], [83.19735718, 17.58514023], [83.19708252, 17.58514023], [83.19708252, 17.58485985], [83.19680786, 17.58486176], [83.19680786, 17.58458328], [83.19652557, 17.58458328], [83.19652557, 17.58430672], [83.19596863, 17.58430672], [83.19596863, 17.58402634], [83.19513702, 17.58403015], [83.19513702, 17.58374977], [83.19430542, 17.58374977], [83.19430542, 17.5834713], [83.19374847, 17.5834713], [83.19374847, 17.58319664], [83.19264221, 17.58319664], [83.19264221, 17.58291435], [83.1920929, 17.58292007], [83.1920929, 17.58263969], [83.19180298, 17.58263969], [83.19180298, 17.58236122], [83.19097137, 17.58236122], [83.19097137, 17.58208084], [83.19013977, 17.58208275], [83.19013977, 17.58180428], [83.18958282, 17.58181], [83.18958282, 17.58152008], [83.18875122, 17.58152771], [83.18875122, 17.58124924], [83.18818665, 17.58125114], [83.18818665, 17.58097076], [83.18736267, 17.58097267], [83.18736267, 17.58069229], [83.18680573, 17.58069229], [83.18680573, 17.58041763], [83.18624878, 17.58041954], [83.18624878, 17.58014107], [83.18569183, 17.58014107], [83.18569183, 17.57986069], [83.18514252, 17.57986069], [83.18514252, 17.57958031], [83.18430328, 17.57958221], [83.18430328, 17.57930565], [83.18374634, 17.57930946], [83.18374634, 17.5790329], [83.18319702, 17.5790329], [83.18319702, 17.57875061], [83.18264008, 17.57875061], [83.18264008, 17.57847977], [83.18208313, 17.57847977], [83.18208313, 17.57819176], [83.18152618, 17.57819366], [83.18152618, 17.5779171], [83.18096924, 17.57792282], [83.18096924, 17.57764053], [83.18041992, 17.57764053], [83.18041992, 17.57736015], [83.17958069, 17.57736015], [83.17958069, 17.57708359], [83.17903137, 17.57708359], [83.17903137, 17.57680511], [83.1784668, 17.57681274], [83.1784668, 17.57653046], [83.17791748, 17.57653046], [83.17791748, 17.57625008], [83.17736053, 17.57625008], [83.17736053, 17.5759716], [83.17680359, 17.5759716], [83.17680359, 17.57569504], [83.17624664, 17.57570267], [83.17624664, 17.57542038], [83.17569733, 17.57542038], [83.17569733, 17.57513809], [83.17542267, 17.57513809], [83.17542267, 17.57485962], [83.17514038, 17.57486153], [83.17514038, 17.57458305], [83.17430878, 17.57458305], [83.17430878, 17.57430649], [83.17402649, 17.5743084], [83.17402649, 17.57402992], [83.17346954, 17.57402992], [83.17346954, 17.57374954], [83.17292023, 17.57374954], [83.17292023, 17.57347107], [83.17236328, 17.57347298], [83.17236328, 17.5731945], [83.17208099, 17.5731945], [83.17208099, 17.57291794], [83.17180634, 17.57291985], [83.17180634, 17.57263947], [83.17124939, 17.57263947], [83.17124939, 17.57234955], [83.17097473, 17.57236099], [83.17097473, 17.57180786], [83.17069244, 17.57180977], [83.17069244, 17.57152939], [83.17041779, 17.57152939], [83.17041779, 17.57125092], [83.1701355, 17.57125092], [83.1701355, 17.57069588], [83.16986084, 17.57069588], [83.16986084, 17.57013893], [83.16958618, 17.57014084], [83.16958618, 17.56735992], [83.16930389, 17.56736183], [83.16930389, 17.56680489], [83.16902924, 17.56680489], [83.16902924, 17.56624985], [83.16874695, 17.56624985], [83.16874695, 17.56596947], [83.16847229, 17.56597137], [83.16847229, 17.56569481], [83.16819763, 17.56569481], [83.16819763, 17.56541634], [83.16764069, 17.56542015], [83.16764069, 17.56513977], [83.1673584, 17.56513977], [83.1673584, 17.56485939], [83.16708374, 17.5648613], [83.16708374, 17.56458282], [83.16680908, 17.56458282], [83.16680908, 17.56402779], [83.16652679, 17.56402969], [83.16652679, 17.56375122], [83.16596985, 17.56375122], [83.16596985, 17.56348038], [83.16570282, 17.56348038], [83.16570282, 17.56318855], [83.16513824, 17.56319427], [83.16513824, 17.5629158], [83.16485596, 17.56291962], [83.16485596, 17.56263924], [83.16430664, 17.56263924], [83.16430664, 17.56236076], [83.16374969, 17.56236076], [83.16374969, 17.56207848], [83.16347504, 17.5620842], [83.16347504, 17.56180573], [83.16291809, 17.56180954], [83.16291809, 17.56152916], [83.16236115, 17.56152916], [83.16236115, 17.56125069], [83.16152954, 17.56125069], [83.16152954, 17.5609684], [83.1609726, 17.56097221], [83.1609726, 17.56069374], [83.1598587, 17.56069374], [83.1598587, 17.56041718], [83.15930176, 17.56041718], [83.15930176, 17.5601387], [83.1590271, 17.56014061], [83.1590271, 17.55986023], [83.15763855, 17.55986023], [83.15763855, 17.55957985], [83.1570816, 17.55958366], [83.1570816, 17.55930519], [83.15651703, 17.55931091], [83.15651703, 17.55903053], [83.15513611, 17.55903053], [83.15513611, 17.55875015], [83.15429688, 17.55875015], [83.15429688, 17.55846977], [83.15319824, 17.55847168], [83.15319061, 17.55819511], [83.15235901, 17.55820084], [83.15235901, 17.55792046], [83.1506958, 17.55792046], [83.1506958, 17.55764008], [83.14985657, 17.55764008], [83.14985657, 17.55735016], [83.14847565, 17.5573616], [83.14847565, 17.55708313], [83.1479187, 17.55708313], [83.1479187, 17.55680466], [83.1470871, 17.55680466], [83.1470871, 17.55652618], [83.14679718, 17.55653], [83.14679718, 17.55624962], [83.14541626, 17.55624962], [83.14541626, 17.55597115], [83.14485931, 17.55597305], [83.14485931, 17.55569649], [83.14430237, 17.55569649], [83.14430237, 17.55597305], [83.14375305, 17.55597305], [83.14375305, 17.55569649], [83.14263916, 17.55569649], [83.14263916, 17.5554142], [83.14180756, 17.55541992], [83.14180756, 17.55513954], [83.14068604, 17.55513954], [83.14068604, 17.55486107], [83.14013672, 17.55486107], [83.14013672, 17.55458069], [83.13874817, 17.5545826], [83.13874817, 17.55430412], [83.13735962, 17.55430984], [83.13735962, 17.55402946], [83.13652802, 17.55402946], [83.13652802, 17.55375099], [83.13540649, 17.55375099], [83.13540649, 17.55347061], [83.13458252, 17.55347252], [83.13458252, 17.55319214], [83.13375092, 17.55319214], [83.13375092, 17.55291748], [83.13291931, 17.55291939], [83.13291931, 17.55264282], [83.13263702, 17.55264282], [83.13263702, 17.55236053], [83.13236237, 17.55236053], [83.13236237, 17.55208015], [83.13208008, 17.55208015], [83.13208008, 17.55236053], [83.13096619, 17.55236053], [83.13096619, 17.55208015], [83.12958527, 17.55208206], [83.12958527, 17.5518055], [83.12874603, 17.55181122], [83.12874603, 17.55154037], [83.12763977, 17.55154037], [83.12763977, 17.55125046], [83.12652588, 17.55125046], [83.12652588, 17.55097008], [83.12541962, 17.55097008], [83.12541962, 17.55069542], [83.12431335, 17.5506916], [83.12430573, 17.55041695], [83.12346649, 17.55042267], [83.12346649, 17.55014038], [83.12264252, 17.55014038], [83.12264252, 17.54986191], [83.12180328, 17.54986191], [83.12180328, 17.54958344], [83.12124634, 17.54958344], [83.12124634, 17.54930496], [83.1204071, 17.54931259], [83.1204071, 17.5490303], [83.11875153, 17.5490303], [83.11875153, 17.54875183], [83.11763763, 17.54875183], [83.11763763, 17.54846764], [83.11653137, 17.54847145], [83.11653137, 17.54819489], [83.11569214, 17.54819489], [83.11569214, 17.54791641], [83.11485291, 17.54791832], [83.11485291, 17.54763985], [83.11374664, 17.54763985], [83.11374664, 17.54735756], [83.11291504, 17.54736137], [83.11291504, 17.5470829], [83.11208344, 17.5470829], [83.11208344, 17.54680634], [83.11152649, 17.54680824], [83.11152649, 17.54652977], [83.11099243, 17.54652977], [83.11068726, 17.54652977], [83.11068726, 17.54624939], [83.10986328, 17.54624939], [83.10986328, 17.54597092], [83.10930634, 17.54597282], [83.10930634, 17.54569435], [83.10847473, 17.54569435], [83.10847473, 17.54541779], [83.10791779, 17.54541779], [83.10791779, 17.54513931], [83.10708618, 17.54514122], [83.10708618, 17.54486084], [83.10652924, 17.54486084], [83.10652924, 17.54458046], [83.10569763, 17.54458427], [83.10569763, 17.54430771], [83.10514069, 17.54430962], [83.10514069, 17.54403114], [83.10430908, 17.54403114], [83.10430908, 17.54375076], [83.10375214, 17.54375076], [83.10375214, 17.54347038], [83.10319519, 17.54347229], [83.10319519, 17.54319382], [83.10263824, 17.54319382], [83.10263824, 17.54291534], [83.10180664, 17.54292107], [83.10180664, 17.54264069], [83.10124969, 17.54264069], [83.10124969, 17.54236984], [83.10069275, 17.54236984], [83.10069275, 17.54207993], [83.1001358, 17.54208565], [83.1001358, 17.54180336], [83.09929657, 17.54181099], [83.09929657, 17.54153061], [83.09874725, 17.54153061], [83.09874725, 17.54125023], [83.09819794, 17.54125023], [83.09819794, 17.54096985], [83.09764099, 17.54097176], [83.09764099, 17.54069328], [83.0967865, 17.54070091], [83.0967865, 17.54042053], [83.09625244, 17.54042053], [83.09625244, 17.54014015], [83.09570313, 17.54014015], [83.09570313, 17.53985977], [83.09513855, 17.53986168], [83.09513855, 17.53958321], [83.09430695, 17.53958321], [83.09430695, 17.53930473], [83.09152985, 17.53931046], [83.09152985, 17.53903008], [83.09124756, 17.53903008], [83.09124756, 17.53819275], [83.09152985, 17.53819466], [83.09152985, 17.53763962], [83.09124756, 17.53763962], [83.09124756, 17.53736115], [83.0909729, 17.53736115], [83.0909729, 17.53708267], [83.09069824, 17.53708267], [83.09069061, 17.53652763], [83.09059143, 17.53652763], [83.09041595, 17.53652954], [83.09041595, 17.53633118], [83.09041595, 17.53624916], [83.0901413, 17.53624916], [83.0901413, 17.53603935], [83.0901413, 17.53569412], [83.08985901, 17.53569412], [83.08985901, 17.53513908], [83.08957672, 17.53513908], [83.08957672, 17.53486061], [83.08930206, 17.53486061], [83.08930206, 17.53430939], [83.0890274, 17.53430939], [83.0890274, 17.53403091], [83.08875275, 17.53403091], [83.08875275, 17.53375053], [83.08847046, 17.53375053], [83.08847046, 17.53346825], [83.08777618, 17.53347206], [83.08763885, 17.53347206], [83.08763885, 17.53319359], [83.08708191, 17.53319359], [83.08708191, 17.53291893], [83.08625031, 17.53292084], [83.08625031, 17.53264046], [83.0854187, 17.53264046], [83.0854187, 17.53235817], [83.08374786, 17.53236198], [83.08374786, 17.53208351], [83.08291626, 17.53208351], [83.08291626, 17.53180695], [83.08097076, 17.53181076], [83.08097076, 17.53153038], [83.08069611, 17.53153038], [83.08069611, 17.53125], [83.07985687, 17.53125], [83.07985687, 17.53096962], [83.07902527, 17.53097153], [83.07902527, 17.53069687], [83.07736206, 17.53070068], [83.07736206, 17.53042984], [83.07681274, 17.53042984], [83.07681274, 17.53013992], [83.07624817, 17.53013992], [83.07624817, 17.52985954], [83.07485962, 17.52986145], [83.07485962, 17.52958298], [83.07430267, 17.52958298], [83.07430267, 17.5293045], [83.07208252, 17.52931023], [83.07208252, 17.52902985], [83.07180786, 17.52902985], [83.07180786, 17.52874947], [83.07125092, 17.52874947], [83.07125092, 17.52847099], [83.07096863, 17.52847481], [83.07096863, 17.52819633], [83.07069397, 17.52819633], [83.07069397, 17.52791405], [83.06987, 17.52791977], [83.06987, 17.52763939], [83.06958008, 17.52763939], [83.06958008, 17.52737045], [83.06874847, 17.52737045], [83.06874847, 17.52708054], [83.06791687, 17.52708244], [83.06791687, 17.52680588], [83.06735992, 17.52680969], [83.06735992, 17.52653122], [83.0670929, 17.52653122], [83.0670929, 17.52625084], [83.06680298, 17.52625084], [83.06680298, 17.52486038], [83.06652832, 17.52486038], [83.06652832, 17.52458191], [83.06597137, 17.52458191], [83.06597137, 17.52486038], [83.06569672, 17.52486038], [83.06569672, 17.52514076], [83.0654068, 17.52514076], [83.0654068, 17.52542114], [83.06513977, 17.52541733], [83.06513977, 17.52569389], [83.06430817, 17.52569389], [83.06430817, 17.52541733], [83.06346893, 17.52542114], [83.06346893, 17.52514076], [83.06208038, 17.52514076], [83.06208038, 17.52486038], [83.05930328, 17.52486038], [83.05930328, 17.52458191], [83.05902863, 17.52458382], [83.05902863, 17.52430534], [83.05847168, 17.52430534], [83.05847168, 17.52402687], [83.0579071, 17.52403259], [83.0579071, 17.52347183], [83.05764008, 17.52347183], [83.05764008, 17.52319527], [83.05680847, 17.5232029], [83.05680847, 17.52264023], [83.05652618, 17.52264023], [83.05652618, 17.52236176], [83.05625153, 17.52236176], [83.05625153, 17.52208328], [83.05569458, 17.52208328], [83.05569458, 17.52180481], [83.05486298, 17.52180481], [83.05486298, 17.52152824], [83.05403137, 17.52152824], [83.05403137, 17.52124023], [83.05319214, 17.52124977], [83.05319214, 17.5209713], [83.05263519, 17.5209713], [83.05263519, 17.52069473], [83.05180359, 17.52069473], [83.05180359, 17.52041626], [83.05124664, 17.52041817], [83.05124664, 17.52013969], [83.05041504, 17.52013969], [83.05041504, 17.51986122], [83.04957581, 17.51986122], [83.04957581, 17.51958084], [83.04902649, 17.51958275], [83.04902649, 17.51930618], [83.04818726, 17.51930809], [83.04818726, 17.51902962], [83.04736328, 17.51902962], [83.04736328, 17.51875114], [83.04680634, 17.51875114], [83.04680634, 17.51847076], [83.04597473, 17.51847267], [83.04597473, 17.5181942], [83.04514313, 17.51819992], [83.04514313, 17.51791954], [83.04458618, 17.51791954], [83.04458618, 17.51764107], [83.04374695, 17.51764107], [83.04374695, 17.51736069], [83.04291534, 17.51736069], [83.04291534, 17.51708412], [83.0423584, 17.51708412], [83.0423584, 17.51680756], [83.04152679, 17.51680946], [83.04152679, 17.51653099], [83.04096985, 17.51653099], [83.04096985, 17.51625061], [83.04069519, 17.51625061], [83.04069519, 17.51597214], [83.03930664, 17.51597214], [83.03930664, 17.51569366], [83.03874969, 17.51569366], [83.03874969, 17.51541519], [83.03791809, 17.51543045], [83.03791809, 17.51514053], [83.03736115, 17.51514053], [83.03736115, 17.51486015], [83.0368042, 17.51486206], [83.0368042, 17.51458549], [83.0359726, 17.51458549], [83.0359726, 17.51430321], [83.03514099, 17.51431084], [83.03514099, 17.51403046], [83.03430176, 17.51403046], [83.03430176, 17.51375008], [83.03347015, 17.51375008], [83.03347015, 17.5134697], [83.03291321, 17.5134716], [83.03291321, 17.51319313], [83.03263855, 17.51320076], [83.03263855, 17.51292038], [83.0320816, 17.51292038], [83.0320816, 17.51264], [83.03125, 17.51264], [83.03125, 17.51235962], [83.03069305, 17.51236153], [83.03069305, 17.51208115], [83.03013611, 17.51208115], [83.03013611, 17.51180649], [83.02958679, 17.5118103], [83.02958679, 17.51152992], [83.02902985, 17.51152992], [83.02902985, 17.51124954], [83.0284729, 17.51124954], [83.0284729, 17.51097107], [83.02819824, 17.51097107], [83.02819061, 17.5106945], [83.0276413, 17.5106945], [83.0276413, 17.51041603], [83.02707672, 17.51042175], [83.02707672, 17.51013947], [83.0265274, 17.51013947], [83.0265274, 17.50985909], [83.02597046, 17.50985909], [83.02597046, 17.50958061], [83.02541351, 17.50958252], [83.02541351, 17.50930595], [83.0248642, 17.50930595], [83.0248642, 17.50902748], [83.02430725, 17.50902939], [83.02430725, 17.50875092], [83.02375031, 17.50875092], [83.02375031, 17.50847054], [83.02319336, 17.50847244], [83.02319336, 17.50819397], [83.02263641, 17.50819397], [83.02263641, 17.5079174], [83.0220871, 17.50791931], [83.0220871, 17.50764084], [83.02153015, 17.50764084], [83.02153015, 17.50736046], [83.02097321, 17.50736046], [83.02097321, 17.50707817], [83.02041626, 17.50708389], [83.02041626, 17.50680542], [83.01985931, 17.50680923], [83.01985931, 17.50653076], [83.01930237, 17.50653076], [83.01930237, 17.50625992], [83.01876068, 17.50625992], [83.01876068, 17.50596809], [83.01819611, 17.50597191], [83.01819611, 17.50569534], [83.01790619, 17.50569916], [83.01790619, 17.50542068], [83.01735687, 17.50542068], [83.01735687, 17.5051403], [83.01680756, 17.5051403], [83.01680756, 17.50485992], [83.01625061, 17.50486183], [83.01625061, 17.50458336], [83.01569366, 17.50458336], [83.01569366, 17.50430679], [83.01513672, 17.50430679], [83.01513672, 17.50402832], [83.01457977, 17.50403023], [83.01457977, 17.50374985], [83.01403046, 17.50374985], [83.01403046, 17.50346947], [83.01347351, 17.50347137], [83.01347351, 17.50319672], [83.01291656, 17.50320053], [83.01291656, 17.50292015], [83.01262665, 17.50292015], [83.01262665, 17.50263977], [83.01207733, 17.50263977], [83.01207733, 17.50235939], [83.01180267, 17.5023613], [83.01180267, 17.50208282], [83.01152802, 17.50208282], [83.01152802, 17.50180435], [83.01125336, 17.50181007], [83.01125336, 17.50152969], [83.01069641, 17.50152969], [83.01069641, 17.50125122], [83.01040649, 17.50125122], [83.01040649, 17.50097084], [83.01013947, 17.50097466], [83.01013947, 17.50069237], [83.00986481, 17.50069237], [83.00986481, 17.5004158], [83.00930786, 17.50041962], [83.00930786, 17.50014114], [83.0090332, 17.50014114], [83.0090332, 17.49986076], [83.00875092, 17.49986076], [83.00875092, 17.49958038], [83.00819397, 17.49958229], [83.00819397, 17.49930573], [83.00791931, 17.49930954], [83.00791931, 17.49903107], [83.00763702, 17.49903107], [83.00763702, 17.49875069], [83.00736237, 17.49875069], [83.00736237, 17.49847031], [83.00708008, 17.49847221], [83.00708008, 17.49819374], [83.00680542, 17.49819374], [83.00680542, 17.4976387], [83.00653076, 17.49764061], [83.00653076, 17.49736023], [83.00624847, 17.49736023], [83.00624847, 17.49706841], [83.00597382, 17.49708366], [83.00597382, 17.49652863], [83.00569153, 17.49653053], [83.00569153, 17.49625015], [83.00541687, 17.49625015], [83.00541687, 17.49597168], [83.00514221, 17.49597168], [83.00514221, 17.49569511], [83.00485992, 17.49570274], [83.00485992, 17.4948597], [83.00458527, 17.4948616], [83.00458527, 17.49402809], [83.00430298, 17.49402809], [83.00430298, 17.49347115], [83.00402832, 17.49347305], [83.00402832, 17.49263954], [83.00374603, 17.49263954], [83.00374603, 17.49014091], [83.00402832, 17.49014091], [83.00402832, 17.48958015], [83.00430298, 17.48958588], [83.00430298, 17.4893074], [83.00444031, 17.4893074], [83.0045929, 17.48931122], [83.0045929, 17.48903084], [83.00485992, 17.48903084], [83.00485992, 17.48875046], [83.00514221, 17.48875046], [83.00514221, 17.48847008], [83.00541687, 17.48847198], [83.00541687, 17.48791695], [83.00514221, 17.48792076], [83.00514221, 17.48764038], [83.0045929, 17.48764038], [83.0045929, 17.48736], [83.00402832, 17.48736382], [83.00402832, 17.48708344], [83.00347137, 17.48708344], [83.00347137, 17.48680305], [83.0029068, 17.48681068], [83.0029068, 17.4865303], [83.00263977, 17.4865303], [83.00263977, 17.48624992], [83.00235748, 17.48624992], [83.00235748, 17.48596954], [83.00208282, 17.48597145], [83.00208282, 17.48569489], [83.00180817, 17.48569489], [83.00180817, 17.48541641], [83.00152588, 17.48542023], [83.00152588, 17.48513031], [83.00125122, 17.48513794], [83.00125122, 17.48486137], [83.00069427, 17.48486137], [83.00069427, 17.4845829], [83.00041962, 17.4845829], [83.00041962, 17.48430634], [83.00013733, 17.48431015], [83.00013733, 17.48402977], [82.99986267, 17.48402977], [82.99986267, 17.48374939], [82.99958038, 17.48374939], [82.99958038, 17.48347282], [82.99930573, 17.48347282], [82.99930573, 17.48319435], [82.99903107, 17.48319435], [82.99903107, 17.48291588], [82.99874878, 17.48291969], [82.99874878, 17.48263931], [82.99846649, 17.48263931], [82.99846649, 17.48236084], [82.99791718, 17.48236084], [82.99791718, 17.48207092], [82.99736023, 17.48208427], [82.99736023, 17.4818058], [82.9970932, 17.48181152], [82.9970932, 17.48152924], [82.99682617, 17.48152924], [82.99652863, 17.48152924], [82.99652863, 17.48125076], [82.99597168, 17.48125076], [82.99597168, 17.48097038], [82.99569702, 17.48097229], [82.99569702, 17.48069382], [82.99514008, 17.48069382], [82.99514008, 17.48041725], [82.99485779, 17.48041916], [82.99485779, 17.48014069], [82.99459076, 17.48014069], [82.99459076, 17.47986031], [82.99402618, 17.47986031], [82.99402618, 17.47957993], [82.99375153, 17.47958374], [82.99375153, 17.47736168], [82.99402618, 17.47736168], [82.99402618, 17.47708321], [82.99458313, 17.47708321], [82.99458313, 17.47680664], [82.99485779, 17.47680664], [82.99485779, 17.47652626], [82.99514008, 17.47653008], [82.99514008, 17.47597122], [82.99541473, 17.47597313], [82.99541473, 17.47541428], [82.99514008, 17.47542], [82.99514008, 17.47486115], [82.99485779, 17.47486115], [82.99485779, 17.47458076], [82.99430847, 17.47458267], [82.99430847, 17.4743042], [82.99375153, 17.47430992], [82.99375153, 17.47402954], [82.99291992, 17.47402954], [82.99291992, 17.47375107], [82.99263763, 17.47375107], [82.99263763, 17.47347069], [82.99153137, 17.4734726], [82.99153137, 17.47319221], [82.99124908, 17.47319221], [82.99124908, 17.47291756], [82.9909668, 17.47291946], [82.9909668, 17.4726429], [82.99069214, 17.4726429], [82.99069214, 17.47236061], [82.99013519, 17.47236061], [82.99013519, 17.47208214], [82.98930359, 17.47208214], [82.98930359, 17.47180557], [82.98874664, 17.47180939], [82.98874664, 17.47153282], [82.98819733, 17.47153282], [82.98819733, 17.47125053], [82.98764038, 17.47125053], [82.98764038, 17.47097015], [82.98708344, 17.47097015], [82.98708344, 17.47069359], [82.98652649, 17.47069359], [82.98652649, 17.47041702], [82.98568726, 17.47042274], [82.98568726, 17.47013092], [82.98513794, 17.47013855], [82.98513794, 17.46986008], [82.98430634, 17.46986008], [82.98430634, 17.46958351], [82.98347473, 17.46958351], [82.98347473, 17.46930504], [82.98291779, 17.46931267], [82.98291779, 17.46903038], [82.98208618, 17.46903038], [82.98208618, 17.46875191], [82.98124695, 17.46875191], [82.98124695, 17.46847153], [82.98041534, 17.46847153], [82.98041534, 17.46819496], [82.9798584, 17.46820259], [82.9798584, 17.4679184], [82.97902679, 17.4679184], [82.97902679, 17.46763992], [82.97820282, 17.46763992], [82.97820282, 17.46735954], [82.97763824, 17.46736145], [82.97763824, 17.46708298], [82.97680664, 17.46709061], [82.97680664, 17.46680832], [82.97598267, 17.46680832], [82.97598267, 17.46652985], [82.97541809, 17.46652985], [82.97541809, 17.46624947], [82.97458649, 17.46624947], [82.97458649, 17.46597099], [82.97374725, 17.4659729], [82.97374725, 17.46569443], [82.97291565, 17.46569443], [82.97291565, 17.46541786], [82.9723587, 17.46541977], [82.9723587, 17.46513939], [82.9715271, 17.46513939], [82.9715271, 17.46486092], [82.9706955, 17.46486092], [82.9706955, 17.46458244], [82.9695816, 17.46458244], [82.9695816, 17.46430779], [82.96875, 17.46431923], [82.96875, 17.46403122], [82.96763611, 17.46403122], [82.96763611, 17.46375084], [82.96679688, 17.46375084], [82.96679688, 17.46347046], [82.96569824, 17.46347237], [82.96569061, 17.4631958], [82.96485901, 17.4631958], [82.96485901, 17.46291733], [82.96375275, 17.46292114], [82.96375275, 17.46264076], [82.96290588, 17.46264076], [82.96290588, 17.46236038], [82.96151733, 17.46236038], [82.96151733, 17.46208], [82.96125031, 17.46208572], [82.96125031, 17.46180344], [82.96069336, 17.46181107], [82.96069336, 17.46153069], [82.9604187, 17.46153069], [82.9604187, 17.46125031], [82.96013641, 17.46125031], [82.96013641, 17.46096039], [82.95903015, 17.46097183], [82.95903015, 17.46069336], [82.95791626, 17.46070099], [82.95791626, 17.46042061], [82.95597076, 17.46042061], [82.95597076, 17.46014023], [82.95513916, 17.46014023], [82.95513916, 17.45985985], [82.95402527, 17.45986176], [82.95402527, 17.45958328], [82.95347595, 17.45958328], [82.95347595, 17.45930481], [82.95291901, 17.45930481], [82.95291901, 17.45902824], [82.95263672, 17.45903015], [82.95263672, 17.45874977], [82.9523468, 17.45874977], [82.9523468, 17.45846939], [82.95097351, 17.4584713], [82.95097351, 17.45819473], [82.95069122, 17.45819473], [82.95069122, 17.45791626], [82.95041656, 17.45792007], [82.95041656, 17.45763969], [82.95014191, 17.45763969], [82.95014191, 17.45708275], [82.94985962, 17.45708275], [82.94985962, 17.45597267], [82.95014191, 17.45597267], [82.95014191, 17.45486069], [82.94985962, 17.45486069], [82.94985962, 17.4545784], [82.94958496, 17.45458412], [82.94958496, 17.45430565], [82.94902802, 17.45430946], [82.94902802, 17.45402908], [82.94875336, 17.45402908], [82.94875336, 17.45375061], [82.94847107, 17.45375061], [82.94847107, 17.45318985], [82.94819641, 17.45319366], [82.94819641, 17.4529171], [82.94790649, 17.45292091], [82.94790649, 17.45264053], [82.94763947, 17.45264053], [82.94763947, 17.45236015], [82.94708252, 17.45236206], [82.94708252, 17.45208359], [82.94654083, 17.45209122], [82.94654083, 17.45181084], [82.94596863, 17.45181084], [82.94596863, 17.45153046], [82.94541931, 17.45153046], [82.94541931, 17.45125008], [82.94291687, 17.45125008], [82.94291687, 17.45153046], [82.9420929, 17.45153046], [82.9420929, 17.45125008], [82.94152832, 17.45125008], [82.94152832, 17.4509697], [82.94097137, 17.4509716], [82.94097137, 17.45069695], [82.94069672, 17.45070076], [82.94069672, 17.45042038], [82.93985748, 17.45042038], [82.93985748, 17.45014], [82.93902588, 17.45014], [82.93902588, 17.44985962], [82.93846893, 17.44986153], [82.93846893, 17.44958305], [82.93791962, 17.44958305], [82.93791962, 17.44930649], [82.93734741, 17.4493103], [82.93734741, 17.44902039], [82.93680573, 17.44902611], [82.93680573, 17.44874954], [82.93624878, 17.44874954], [82.93624878, 17.44847107], [82.93569183, 17.44847488], [82.93569183, 17.44819641], [82.93514252, 17.44819641], [82.93514252, 17.44791412], [82.93431091, 17.44791985], [82.93431091, 17.44763947], [82.93374634, 17.44763947], [82.93374634, 17.44736099], [82.93319702, 17.44736099], [82.93319702, 17.44708061], [82.93264008, 17.44708252], [82.93264008, 17.44680405], [82.93208313, 17.44680977], [82.93208313, 17.44652939], [82.93154144, 17.44652939], [82.93154144, 17.44625092], [82.93096924, 17.44625092], [82.93096924, 17.44596291], [82.93041992, 17.44597244], [82.93041992, 17.44569206], [82.92986298, 17.44569206], [82.92986298, 17.4454174], [82.92958069, 17.44542122], [82.92958069, 17.44514275], [82.92903137, 17.44514275], [82.92903137, 17.44486046], [82.9284668, 17.44486046], [82.9284668, 17.44458008], [82.92791748, 17.44458389], [82.92791748, 17.44430542], [82.92736053, 17.44431114], [82.92736053, 17.44403267], [82.92679596, 17.44403267], [82.92679596, 17.44375038], [82.92624664, 17.44375038], [82.92624664, 17.44347191], [82.92541504, 17.44347191], [82.92541504, 17.44319534], [82.92402649, 17.4432106], [82.92402649, 17.44292259], [82.92318726, 17.44292259], [82.92318726, 17.4426403], [82.92208099, 17.4426403], [82.92208099, 17.44236183], [82.92180634, 17.44236183], [82.92180634, 17.44208336], [82.92069244, 17.44208336], [82.92069244, 17.44180489], [82.9201355, 17.44180489], [82.9201355, 17.44152832], [82.91931152, 17.44152832], [82.91931152, 17.44124985], [82.91847229, 17.44124985], [82.91847229, 17.44096756], [82.91764069, 17.44097137], [82.91764069, 17.44069481], [82.91708374, 17.44069481], [82.91708374, 17.44041634], [82.91623688, 17.44041824], [82.91623688, 17.44014931], [82.91570282, 17.44014931], [82.91570282, 17.43985748], [82.91486359, 17.4398613], [82.91486359, 17.43958282], [82.91430664, 17.43958282], [82.91430664, 17.43930626], [82.91346741, 17.43930817], [82.91346741, 17.43902969], [82.91291809, 17.43902969], [82.91291809, 17.43875122], [82.91208649, 17.43875122], [82.91208649, 17.43847084], [82.91152954, 17.43847275], [82.91152954, 17.43819427], [82.91069794, 17.43819427], [82.91069794, 17.43791771], [82.91014099, 17.43791962], [82.91014099, 17.43764114], [82.90930176, 17.43764114], [82.90930176, 17.43736076], [82.90847015, 17.43736076], [82.90847015, 17.43708038], [82.90791321, 17.4370842], [82.90791321, 17.43680763], [82.9070816, 17.43680954], [82.9070816, 17.43653107], [82.90680695, 17.43653107], [82.90680695, 17.43625069], [82.90625, 17.43625069], [82.90625, 17.43597031], [82.90569305, 17.43597221], [82.90569305, 17.43569565], [82.90513611, 17.43569565], [82.90513611, 17.43541527], [82.90429688, 17.43542099], [82.90429688, 17.43514061], [82.90374756, 17.43514061], [82.90374756, 17.43486023], [82.9034729, 17.43486023], [82.9034729, 17.43457985], [82.90291595, 17.43458557], [82.90291595, 17.43430328], [82.90235901, 17.43431091], [82.90235901, 17.4340229], [82.90180206, 17.43402863], [82.90180206, 17.43375015], [82.90123749, 17.43375015], [82.90123749, 17.43346977], [82.9006958, 17.43347168], [82.9006958, 17.43319321], [82.89985657, 17.43320084], [82.89985657, 17.43292046], [82.89930725, 17.43292046], [82.89930725, 17.43264008], [82.89875031, 17.43264008], [82.89875031, 17.4323597], [82.8979187, 17.4323616], [82.8979187, 17.43208122], [82.89736176, 17.43208122], [82.89736176, 17.43180466], [82.89680481, 17.43180466], [82.89680481, 17.43152809], [82.89597321, 17.43153191], [82.89597321, 17.43124962], [82.89541626, 17.43124962], [82.89541626, 17.43097115], [82.89485931, 17.43098068], [82.89485931, 17.43069267], [82.89402771, 17.43069458], [82.89402771, 17.43041611], [82.89347076, 17.43042183], [82.89347076, 17.43013954], [82.89290619, 17.43013954], [82.89290619, 17.42986107], [82.89208221, 17.42986107], [82.89208221, 17.42958069], [82.89152527, 17.4295826], [82.89152527, 17.42930603], [82.89068604, 17.42931175], [82.89068604, 17.42902946], [82.89013672, 17.42902946], [82.89013672, 17.42874908], [82.88929749, 17.42874908], [82.88929749, 17.42847061], [82.88874817, 17.42847252], [82.88874817, 17.42819405], [82.88791656, 17.42819405], [82.88791656, 17.42791748], [82.88735962, 17.42791939], [82.88735962, 17.42764091], [82.88652802, 17.42764091], [82.88652802, 17.42736053], [82.88569641, 17.42736053], [82.88569641, 17.42707825], [82.88486481, 17.42708397], [82.88486481, 17.4268055], [82.88458252, 17.42680931], [82.88458252, 17.42653084], [82.8840332, 17.42653084], [82.8840332, 17.42625046], [82.88346863, 17.42625046], [82.88346863, 17.42596817], [82.88319397, 17.42597198], [82.88319397, 17.42569542], [82.88291931, 17.4256897], [82.88291931, 17.42541885], [82.88236237, 17.42542076], [82.88236237, 17.42514038], [82.88208008, 17.42514038], [82.88208008, 17.42457962], [82.88180542, 17.42458344], [82.88180542, 17.42430687], [82.88153076, 17.42431068], [82.88153076, 17.42374992], [82.88124847, 17.42374992], [82.88124847, 17.42346954], [82.88097382, 17.42347145], [82.88097382, 17.42319679], [82.88069153, 17.42319679], [82.88069153, 17.42291451], [82.88041687, 17.42292023], [82.88041687, 17.42263985], [82.88014221, 17.42263985], [82.88014221, 17.42235947], [82.87985992, 17.42236137], [82.87985992, 17.42208481], [82.87958527, 17.42208481], [82.87958527, 17.42152786], [82.87930298, 17.42152977], [82.87930298, 17.42124939], [82.87902832, 17.42124939], [82.87902832, 17.42097092], [82.87875366, 17.42097473], [82.87875366, 17.42069244], [82.87847137, 17.42069244], [82.87847137, 17.42041588], [82.8779068, 17.42041969], [82.8779068, 17.42014122], [82.87486267, 17.42014122], [82.87486267, 17.42041969], [82.87430573, 17.42041588], [82.87430573, 17.42069244], [82.87374878, 17.42069244], [82.87374878, 17.42097473], [82.87346649, 17.42097092], [82.87346649, 17.42152977], [82.87319183, 17.42152786], [82.87319183, 17.42208481], [82.87291718, 17.42208099], [82.87291718, 17.42292023], [82.87264252, 17.42291451], [82.87264252, 17.42347145], [82.87291718, 17.42347145], [82.87291718, 17.42486191], [82.87319183, 17.42486191], [82.87319183, 17.42569351], [82.87346649, 17.4256897], [82.87346649, 17.42736053], [82.87319183, 17.42736053], [82.87319183, 17.42847252], [82.87346649, 17.42847061], [82.87346649, 17.42902946], [82.87374878, 17.42902946], [82.87374878, 17.42931175], [82.87403107, 17.42930603], [82.87403107, 17.4295826], [82.87430573, 17.4295826], [82.87430573, 17.42986107], [82.87486267, 17.42986107], [82.87486267, 17.43013954], [82.87513733, 17.43013954], [82.87513733, 17.43042183], [82.87596893, 17.43041611], [82.87596893, 17.43069458], [82.87625122, 17.43069267], [82.87625122, 17.43098068], [82.87680817, 17.43098068], [82.87680817, 17.43124962], [82.87735748, 17.43124962], [82.87735748, 17.43153191], [82.87763977, 17.43152809], [82.87763977, 17.43208122], [82.87791443, 17.43208122], [82.87791443, 17.4323616], [82.87819672, 17.4323597], [82.87819672, 17.43292046], [82.87847137, 17.43292046], [82.87847137, 17.43320084], [82.87875366, 17.43319321], [82.87875366, 17.43347168], [82.87902832, 17.43346977], [82.87902832, 17.43375015], [82.87930298, 17.43375015], [82.87930298, 17.43431091], [82.87958527, 17.43430328], [82.87958527, 17.43458557], [82.87985992, 17.43457985], [82.87985992, 17.43486023], [82.88014221, 17.43486023], [82.88014221, 17.43542099], [82.88041687, 17.43542099], [82.88041687, 17.43625069], [82.87958527, 17.43625069], [82.87958527, 17.43597221], [82.87930298, 17.43597221], [82.87930298, 17.4351387], [82.87902832, 17.43514061], [82.87902832, 17.43486023], [82.87874603, 17.43486023], [82.87874603, 17.43457985], [82.87847137, 17.43458557], [82.87847137, 17.43430328], [82.87819672, 17.43431091], [82.87819672, 17.4340229], [82.87791443, 17.43402863], [82.87791443, 17.43375015], [82.87763977, 17.43375015], [82.87763977, 17.43346977], [82.87708282, 17.43347168], [82.87708282, 17.43319321], [82.87652588, 17.43320084], [82.87652588, 17.43292046], [82.87625122, 17.43292046], [82.87625122, 17.43264008], [82.87568665, 17.43264008], [82.87568665, 17.4323597], [82.87541962, 17.4323616], [82.87541962, 17.43208122], [82.87374878, 17.43208122], [82.87374878, 17.43180466], [82.87347412, 17.43180466], [82.87347412, 17.43152809], [82.87319183, 17.43153191], [82.87319183, 17.43124962], [82.87291718, 17.43124962], [82.87291718, 17.43069267], [82.87264252, 17.43069458], [82.87264252, 17.43041611], [82.87236023, 17.43042183], [82.87236023, 17.42986107], [82.87208557, 17.42986107], [82.87208557, 17.42930603], [82.87180328, 17.42931175], [82.87180328, 17.42847061], [82.87152863, 17.42847252], [82.87152863, 17.42597198], [82.87124634, 17.42597198], [82.87124634, 17.42541885], [82.87069702, 17.42542076], [82.87069702, 17.42514038], [82.8704071, 17.42514038], [82.8704071, 17.42485046], [82.87014008, 17.42486191], [82.87014008, 17.42347145], [82.86985779, 17.42347145], [82.86985779, 17.42291451], [82.86958313, 17.42292023], [82.86958313, 17.42263985], [82.86902618, 17.42263985], [82.86902618, 17.42235947], [82.86875153, 17.42236137], [82.86875153, 17.42180443], [82.86820221, 17.42181015], [82.86820221, 17.42069054], [82.86791992, 17.42069244], [82.86791992, 17.41902733], [82.86820221, 17.41904068], [82.86820221, 17.41875076], [82.86846924, 17.41875076], [82.86846924, 17.41847038], [82.86902618, 17.41847229], [82.86902618, 17.41819382], [82.87014008, 17.41819382], [82.87014008, 17.41791725], [82.87069702, 17.41792107], [82.87069702, 17.41764069], [82.87097168, 17.41764069], [82.87097168, 17.41736031], [82.8712616, 17.41736031], [82.87124634, 17.4165287], [82.87069702, 17.41653252], [82.87069702, 17.41625023], [82.87014008, 17.41625023], [82.87014008, 17.41597939], [82.86985779, 17.41597939], [82.86985779, 17.41570282], [82.86930847, 17.41570282], [82.86930847, 17.41542244], [82.86791992, 17.41542244], [82.86791992, 17.41514015], [82.86708069, 17.41514015], [82.86708069, 17.41485977], [82.86653137, 17.41486168], [82.86653137, 17.41458321], [82.86569214, 17.41458321], [82.86569214, 17.41430473], [82.86486053, 17.41430473], [82.86486053, 17.41402817], [82.86429596, 17.41402817], [82.86429596, 17.41374969], [82.86291504, 17.41374969], [82.86291504, 17.41347313], [82.86125183, 17.41347313], [82.86125183, 17.41319466], [82.85958099, 17.41319466], [82.85958099, 17.41291618], [82.85874939, 17.41291618], [82.85874939, 17.41263962], [82.85791779, 17.41263962], [82.85791779, 17.41236115], [82.85708618, 17.41236115], [82.85708618, 17.41208076], [82.85652924, 17.41208267], [82.85652924, 17.41180611], [82.85569763, 17.41180992], [82.85569763, 17.41152954], [82.8548584, 17.41152954], [82.8548584, 17.41125107], [82.85402679, 17.41125107], [82.85402679, 17.41097069], [82.85319519, 17.4109726], [82.85319519, 17.41069412], [82.85236359, 17.41069412], [82.85236359, 17.41041756], [82.85180664, 17.41041946], [82.85180664, 17.41014099], [82.85098267, 17.41014099], [82.85098267, 17.40985107], [82.8501358, 17.40986061], [82.8501358, 17.40958595], [82.8493042, 17.40958595], [82.8493042, 17.40930748], [82.8484726, 17.40930939], [82.8484726, 17.40903091], [82.84764099, 17.40903091], [82.84764099, 17.40875053], [82.84708405, 17.40875053], [82.84708405, 17.40847206], [82.84625244, 17.40847206], [82.84625244, 17.40819359], [82.84541321, 17.40819359], [82.84541321, 17.40791512], [82.8445816, 17.40792084], [82.8445816, 17.40764046], [82.84430695, 17.40764046], [82.84430695, 17.40736008], [82.84347534, 17.40736389], [82.84347534, 17.40708542], [82.84263611, 17.40708542], [82.84263611, 17.40680313], [82.84152985, 17.40681076], [82.84152985, 17.40653038], [82.84069824, 17.40653038], [82.84069061, 17.40625], [82.83957672, 17.40625], [82.83957672, 17.40596962], [82.8390274, 17.40597153], [82.8390274, 17.40569305], [82.83818817, 17.40570068], [82.83818817, 17.4054203], [82.83763885, 17.4054203], [82.83763885, 17.40513992], [82.83708191, 17.40513992], [82.83708191, 17.40485954], [82.83625031, 17.40486145], [82.83625031, 17.40458107], [82.83569336, 17.40458107], [82.83569336, 17.40430641], [82.83515167, 17.40431023], [82.83515167, 17.40403938], [82.8345871, 17.40403938], [82.8345871, 17.40374947], [82.83374786, 17.40374947], [82.83374786, 17.4034729], [82.83319092, 17.4034729], [82.83319092, 17.40319443], [82.8326416, 17.40319443], [82.8326416, 17.40291595], [82.83180237, 17.40292168], [82.83180237, 17.40263939], [82.83125305, 17.40263939], [82.83125305, 17.40236092], [82.83069611, 17.40236092], [82.83069611, 17.40208054], [82.8298645, 17.40208244], [82.8298645, 17.40180588], [82.82930756, 17.4018116], [82.82930756, 17.40152931], [82.82875061, 17.40152931], [82.82875061, 17.40125084], [82.82791901, 17.40125084], [82.82791901, 17.40097046], [82.82736206, 17.40097237], [82.82736206, 17.40069389], [82.82680511, 17.40069389], [82.82680511, 17.40041733], [82.82595825, 17.40041924], [82.82595825, 17.40014076], [82.82541656, 17.40014076], [82.82541656, 17.39986038], [82.82485962, 17.39986038], [82.82485962, 17.39957809], [82.82430267, 17.39958382], [82.82430267, 17.39930534], [82.82347107, 17.39930916], [82.82347107, 17.39903069], [82.82292175, 17.39903069], [82.82292175, 17.39875031], [82.82235718, 17.39875031], [82.82235718, 17.39846992], [82.82152557, 17.39847183], [82.82152557, 17.39819527], [82.82096863, 17.39819908], [82.82096863, 17.39791107], [82.82041931, 17.3979187], [82.82041931, 17.39763641], [82.81986237, 17.39764023], [82.81986237, 17.39735985], [82.81958008, 17.39736176], [82.81958008, 17.39708328], [82.81874847, 17.39708328], [82.81874847, 17.39680672], [82.81819153, 17.39680672], [82.81819153, 17.39652824], [82.81791687, 17.39653015], [82.81791687, 17.39624977], [82.81735992, 17.39624977], [82.81735992, 17.39596939], [82.81680298, 17.3959713], [82.81680298, 17.39569664], [82.81625366, 17.39569664], [82.81625366, 17.39541435], [82.81569672, 17.39542007], [82.81569672, 17.39513969], [82.81485748, 17.39513969], [82.81485748, 17.39484978], [82.81430817, 17.39486122], [82.81430817, 17.39458275], [82.81375122, 17.39458275], [82.81375122, 17.39430428], [82.81318665, 17.39431], [82.81318665, 17.39402962], [82.81236267, 17.39402962], [82.81236267, 17.39375114], [82.81181335, 17.39375114], [82.81181335, 17.39347076], [82.81124878, 17.39347458], [82.81124878, 17.39319229], [82.81069183, 17.39319229], [82.81069183, 17.39291763], [82.81014252, 17.39291954], [82.81014252, 17.39264107], [82.80930328, 17.39264107], [82.80930328, 17.39236069], [82.80874634, 17.39236069], [82.80874634, 17.39208031], [82.80819702, 17.39208221], [82.80819702, 17.39180565], [82.80764008, 17.39180946], [82.80764008, 17.3915329], [82.80708313, 17.3915329], [82.80708313, 17.39125061], [82.80625153, 17.39125061], [82.80625153, 17.39097023], [82.80569458, 17.39097023], [82.80569458, 17.39069366], [82.80513763, 17.39069366], [82.80513763, 17.3904171], [82.80458069, 17.39042282], [82.80458069, 17.39014053], [82.80374908, 17.39014053], [82.80374908, 17.38986015], [82.80319214, 17.38986015], [82.80319214, 17.38958359], [82.80263519, 17.38958359], [82.80263519, 17.38930511], [82.80207825, 17.38931274], [82.80207825, 17.38903046], [82.80152893, 17.38903046], [82.80152893, 17.38875008], [82.80069733, 17.38875008], [82.80069733, 17.3884716], [82.80014038, 17.3884716], [82.80014038, 17.38819504], [82.79957581, 17.38820267], [82.79957581, 17.38791847], [82.79904175, 17.38791847], [82.79904175, 17.38763809], [82.79818726, 17.38763809], [82.79818726, 17.38735962], [82.79763794, 17.38736153], [82.79763794, 17.38708305], [82.79708099, 17.38708305], [82.79708099, 17.38680649], [82.79651642, 17.3868084], [82.79651642, 17.38652992], [82.79569244, 17.38652992], [82.79569244, 17.38624954], [82.7951355, 17.38624954], [82.7951355, 17.38597298], [82.79458618, 17.38597298], [82.79458618, 17.3856945], [82.79374695, 17.3856945], [82.79374695, 17.38541794], [82.79319763, 17.38541985], [82.79319763, 17.38513947], [82.79264069, 17.38513947], [82.79264069, 17.38486099], [82.79180908, 17.38486099], [82.79180908, 17.38458061], [82.79125214, 17.38458252], [82.79125214, 17.38430786], [82.79070282, 17.38430977], [82.79070282, 17.38402939], [82.78984833, 17.38402939], [82.78984833, 17.38375092], [82.78930664, 17.38375092], [82.78930664, 17.38347054], [82.78874969, 17.38347244], [82.78874969, 17.38319588], [82.78819275, 17.38319588], [82.78819275, 17.3829174], [82.78736115, 17.3829174], [82.78736115, 17.38263893], [82.78678894, 17.38264084], [82.78678894, 17.38236046], [82.78624725, 17.38236046], [82.78624725, 17.38208008], [82.78541565, 17.3820858], [82.78541565, 17.38180351], [82.7848587, 17.38181114], [82.7848587, 17.38153076], [82.78430176, 17.38153076], [82.78430176, 17.38125038], [82.78347015, 17.38125038], [82.78347015, 17.38097], [82.78291321, 17.38097191], [82.78291321, 17.38069344], [82.78235626, 17.38070107], [82.78235626, 17.38042068], [82.78151703, 17.38042068], [82.78151703, 17.3801403], [82.78096771, 17.3801403], [82.78096771, 17.37986946], [82.7804184, 17.37986946], [82.7804184, 17.37957954], [82.77958679, 17.37958336], [82.77958679, 17.37930489], [82.77902985, 17.37930489], [82.77902985, 17.37902832], [82.7784729, 17.37903023], [82.7784729, 17.37874985], [82.7776413, 17.37874985], [82.7776413, 17.37846947], [82.77708435, 17.37847137], [82.77708435, 17.37819481], [82.7765274, 17.37819481], [82.7765274, 17.37791634], [82.77597046, 17.37792015], [82.77597046, 17.37763977], [82.77513885, 17.37763977], [82.77513885, 17.37735939], [82.77458191, 17.3773613], [82.77458191, 17.37708282], [82.77402496, 17.37708282], [82.77402496, 17.37680626], [82.77319336, 17.37681007], [82.77319336, 17.37652969], [82.77263641, 17.37652969], [82.77263641, 17.37624931], [82.77210236, 17.37624931], [82.77210236, 17.37597084], [82.77153015, 17.37597275], [82.77153015, 17.37569427], [82.77069092, 17.37569427], [82.77069092, 17.3754158], [82.7701416, 17.37541962], [82.7701416, 17.37513924], [82.76957703, 17.37513924], [82.76957703, 17.37486076], [82.76902771, 17.37486076], [82.76902771, 17.37457848], [82.76819611, 17.3745842], [82.76819611, 17.37430573], [82.76763916, 17.37431145], [82.76763916, 17.37402916], [82.76708221, 17.37402916], [82.76708221, 17.37374115], [82.76625061, 17.37375069], [82.76625061, 17.37347221], [82.76569366, 17.37347221], [82.76569366, 17.37319374], [82.76513672, 17.37319374], [82.76513672, 17.37291718], [82.76431274, 17.37291908], [82.76431274, 17.37264061], [82.76374817, 17.37264061], [82.76374817, 17.37236023], [82.76319122, 17.37236023], [82.76319122, 17.37207985], [82.76264191, 17.37208366], [82.76264191, 17.37180519], [82.76180267, 17.37181091], [82.76180267, 17.37153053], [82.76125336, 17.37153053], [82.76125336, 17.37125015], [82.76069641, 17.37125015], [82.76069641, 17.37096977], [82.76013947, 17.37097168], [82.76013947, 17.37069511], [82.75930786, 17.37070084], [82.75930786, 17.37042046], [82.75875092, 17.37042046], [82.75875092, 17.37014008], [82.75791931, 17.37014008], [82.75791931, 17.3698597], [82.75736237, 17.3698616], [82.75736237, 17.36958313], [82.75680542, 17.36958313], [82.75680542, 17.36930656], [82.75624847, 17.36930656], [82.75624847, 17.36902809], [82.75569153, 17.36903], [82.75569153, 17.36874962], [82.75514221, 17.36874962], [82.75514221, 17.36847115], [82.75458527, 17.36847305], [82.75458527, 17.36819649], [82.75402832, 17.36819649], [82.75402832, 17.3679142], [82.7537384, 17.36792946], [82.7537384, 17.36763954], [82.75319672, 17.36763954], [82.75319672, 17.36736107], [82.75263977, 17.36736107], [82.75263977, 17.36708069], [82.75208282, 17.3670826], [82.75208282, 17.36680412], [82.75152588, 17.36680984], [82.75152588, 17.36652946], [82.75096893, 17.36652946], [82.75096893, 17.3662529], [82.75041962, 17.3662529], [82.75041962, 17.36597061], [82.75013733, 17.36597252], [82.75013733, 17.36569214], [82.74958038, 17.36569214], [82.74958038, 17.36541748], [82.74903107, 17.36541939], [82.74903107, 17.36514282], [82.74846649, 17.36514282], [82.74846649, 17.36487007], [82.74819183, 17.36487007], [82.74819183, 17.36458015], [82.74764252, 17.36458206], [82.74764252, 17.3643055], [82.7470932, 17.36431122], [82.7470932, 17.36403275], [82.74624634, 17.36403275], [82.74624634, 17.36375046], [82.7454071, 17.36375046], [82.7454071, 17.36347008], [82.74485779, 17.36347008], [82.74485779, 17.36319542], [82.74430847, 17.3631916], [82.74430847, 17.36291695], [82.74346924, 17.36292267], [82.74346924, 17.36264038], [82.74291992, 17.36264038], [82.74291992, 17.36236191], [82.74208069, 17.36236191], [82.74208069, 17.36208344], [82.74153137, 17.36208344], [82.74153137, 17.36180496], [82.74097443, 17.36180496], [82.74097443, 17.3615284], [82.74014282, 17.3615303], [82.74014282, 17.36124992], [82.73986053, 17.36124992], [82.73986053, 17.36096764], [82.73874664, 17.36097145], [82.73874664, 17.36069489], [82.73847198, 17.36069489], [82.73847198, 17.36041641], [82.73764038, 17.36041832], [82.73764038, 17.36013985], [82.73735809, 17.36013985], [82.73735809, 17.35985947], [82.73708344, 17.35986137], [82.73708344, 17.3595829], [82.73680878, 17.3595829], [82.73680878, 17.35930634], [82.73542023, 17.35930824], [82.73542023, 17.35902977], [82.73486328, 17.35902977], [82.73486328, 17.35873985], [82.73430634, 17.35874939], [82.73430634, 17.35847282], [82.73374939, 17.35847282], [82.73374939, 17.35819435], [82.73347473, 17.35819435], [82.73347473, 17.35791779], [82.73293304, 17.35791969], [82.73293304, 17.35764122], [82.73236084, 17.35764122], [82.73236084, 17.35736084], [82.73179626, 17.35736084], [82.73179626, 17.35708046], [82.73124695, 17.35708427], [82.73124695, 17.35680771], [82.73069763, 17.35680962], [82.73069763, 17.35653114], [82.73014069, 17.35653114], [82.73014069, 17.35625076], [82.72956848, 17.35625076], [82.72956848, 17.35597038], [82.72902679, 17.35597229], [82.72902679, 17.35569572], [82.72846985, 17.35569954], [82.72846985, 17.35542107], [82.7279129, 17.35542107], [82.7279129, 17.35514069], [82.72735596, 17.35514069], [82.72735596, 17.35486031], [82.72679901, 17.35486031], [82.72679901, 17.35457993], [82.72624969, 17.35458565], [82.72624969, 17.35430336], [82.72569275, 17.35431099], [82.72569275, 17.35403061], [82.7251358, 17.35403061], [82.7251358, 17.35375023], [82.72458649, 17.35375023], [82.72458649, 17.35346985], [82.72374725, 17.35347176], [82.72374725, 17.35319328], [82.72319794, 17.35320091], [82.72319794, 17.35293007], [82.72264099, 17.35293007], [82.72264099, 17.35264015], [82.72207642, 17.35264015], [82.72207642, 17.35235977], [82.7215271, 17.35236168], [82.7215271, 17.3520813], [82.72097015, 17.3520813], [82.72097015, 17.35180473], [82.72041321, 17.35180473], [82.72041321, 17.35152817], [82.71985626, 17.35153008], [82.71985626, 17.35124969], [82.71930695, 17.35124969], [82.71930695, 17.35097122], [82.71875, 17.35097122], [82.71875, 17.35069466], [82.71819305, 17.35069466], [82.71819305, 17.35041618], [82.71762848, 17.35042191], [82.71762848, 17.35013962], [82.71708679, 17.35013962], [82.71708679, 17.34986115], [82.71652985, 17.34986115], [82.71652985, 17.34957123], [82.7159729, 17.34958267], [82.7159729, 17.34930611], [82.71541595, 17.34931183], [82.71541595, 17.34902954], [82.7151413, 17.34902954], [82.7151413, 17.34874916], [82.71456909, 17.34874916], [82.71456909, 17.34847069], [82.7140274, 17.3484726], [82.7140274, 17.34819412], [82.71347046, 17.34819412], [82.71347046, 17.34791756], [82.71290588, 17.34791946], [82.71290588, 17.34763908], [82.71235657, 17.34763908], [82.71235657, 17.34736061], [82.71180725, 17.34736061], [82.71180725, 17.34708405], [82.71125031, 17.34708405], [82.71125031, 17.34680557], [82.71069336, 17.34680557], [82.71069336, 17.3465271], [82.71013641, 17.34653091], [82.71013641, 17.34625053], [82.7095871, 17.34625053], [82.7095871, 17.34596825], [82.70903015, 17.34597206], [82.70903015, 17.34569359], [82.70847321, 17.34569359], [82.70847321, 17.34541893], [82.70791626, 17.34542084], [82.70791626, 17.34514046], [82.70735931, 17.34514046], [82.70735931, 17.34486008], [82.70652771, 17.34486198], [82.70652771, 17.34458351], [82.70625305, 17.34458351], [82.70625305, 17.34430695], [82.70597076, 17.34431076], [82.70597076, 17.34403038], [82.70568848, 17.34403038], [82.70568848, 17.34375954], [82.70347595, 17.34375954], [82.70347595, 17.34346962], [82.70291901, 17.34347153], [82.70291901, 17.34319687], [82.70236206, 17.34320068], [82.70236206, 17.3429203], [82.70207977, 17.3429203], [82.70207977, 17.34263992], [82.70153046, 17.34263992], [82.70153046, 17.34235954], [82.70097351, 17.34236145], [82.70097351, 17.34208488], [82.70041656, 17.34208488], [82.70041656, 17.34180641], [82.69985962, 17.34181023], [82.69985962, 17.34152985], [82.69930267, 17.34152985], [82.69930267, 17.34124947], [82.69902802, 17.34124947], [82.69902802, 17.34097099], [82.69847107, 17.34097481], [82.69847107, 17.34069252], [82.69790649, 17.34070015], [82.69790649, 17.34041977], [82.69735718, 17.34041977], [82.69735718, 17.34013939], [82.69680786, 17.34013939], [82.69680786, 17.33986092], [82.69625092, 17.33986092], [82.69625092, 17.33958054], [82.69569397, 17.33958244], [82.69569397, 17.33930588], [82.69513702, 17.33930969], [82.69513702, 17.33903122], [82.69458008, 17.33903122], [82.69458008, 17.33875084], [82.69403076, 17.33875084], [82.69403076, 17.33847046], [82.69347382, 17.33847237], [82.69347382, 17.33819389], [82.69291687, 17.33819389], [82.69291687, 17.33791733], [82.69264221, 17.33792114], [82.69264221, 17.33762932], [82.69208527, 17.33763885], [82.69208527, 17.33736038], [82.69152832, 17.33736038], [82.69152832, 17.33708191], [82.69097137, 17.33708382], [82.69097137, 17.33680534], [82.69039917, 17.33681107], [82.69039917, 17.33653259], [82.68985748, 17.33653259], [82.68985748, 17.33625031], [82.68930817, 17.33625031], [82.68930817, 17.33597183], [82.68875122, 17.33597183], [82.68875122, 17.33569527], [82.68818665, 17.3357029], [82.68818665, 17.33542252], [82.68765259, 17.33542252], [82.68765259, 17.33514023], [82.68708038, 17.33514023], [82.68708038, 17.33486176], [82.68653107, 17.33486176], [82.68653107, 17.33458328], [82.68597412, 17.33458328], [82.68597412, 17.33430481], [82.68569183, 17.33430481], [82.68569183, 17.33402824], [82.68514252, 17.33402824], [82.68514252, 17.33374977], [82.68458557, 17.33374977], [82.68458557, 17.3334713], [82.68402863, 17.3334713], [82.68402863, 17.33319473], [82.68347168, 17.33319473], [82.68347168, 17.33291626], [82.6829071, 17.33291817], [82.6829071, 17.33263969], [82.68264008, 17.33263969], [82.68264008, 17.33236122], [82.68208313, 17.33236122], [82.68208313, 17.33208084], [82.68152618, 17.33208275], [82.68152618, 17.33180618], [82.68096924, 17.33182144], [82.68096924, 17.33152962], [82.68041992, 17.33152962], [82.68041992, 17.33125114], [82.67986298, 17.33125114], [82.67986298, 17.33097076], [82.67958069, 17.33097267], [82.67958069, 17.3306942], [82.67903137, 17.3306942], [82.67903137, 17.33041763], [82.67845917, 17.33041954], [82.67845917, 17.33014107], [82.67791748, 17.33014107], [82.67791748, 17.32986069], [82.67736053, 17.32986069], [82.67736053, 17.32958031], [82.67680359, 17.32958412], [82.67680359, 17.32930756], [82.67652893, 17.32930946], [82.67652893, 17.32903099], [82.67597198, 17.32903099], [82.67597198, 17.32876015], [82.67542267, 17.32876015], [82.67542267, 17.32847023], [82.67485809, 17.32847214], [82.67485809, 17.32819557], [82.67430878, 17.32819557], [82.67430878, 17.32791519], [82.67375183, 17.32792091], [82.67375183, 17.32764053], [82.67346954, 17.32764053], [82.67346954, 17.32736015], [82.67292023, 17.32736206], [82.67292023, 17.32708549], [82.67236328, 17.32708549], [82.67236328, 17.32680321], [82.67180634, 17.32681084], [82.67180634, 17.32653046], [82.67151642, 17.32653046], [82.67151642, 17.32625008], [82.6709671, 17.32625008], [82.6709671, 17.3259697], [82.67041779, 17.3259716], [82.67041779, 17.32569313], [82.66986084, 17.32569313], [82.66986084, 17.32541656], [82.66957855, 17.32542038], [82.66957855, 17.32514], [82.66902924, 17.32514], [82.66902924, 17.32485962], [82.66847229, 17.32486153], [82.66847229, 17.32458115], [82.66791534, 17.32458115], [82.66791534, 17.32430649], [82.6673584, 17.3243103], [82.6673584, 17.32403183], [82.66707611, 17.32403183], [82.66707611, 17.32374954], [82.66651917, 17.32374954], [82.66651917, 17.32347107], [82.66596985, 17.32347107], [82.66596985, 17.3231945], [82.6654129, 17.3231945], [82.6654129, 17.32291603], [82.66513824, 17.32292175], [82.66513824, 17.32262993], [82.6645813, 17.32263947], [82.6645813, 17.32235909], [82.66401672, 17.32235909], [82.66401672, 17.32208061], [82.66347504, 17.32208252], [82.66347504, 17.32180595], [82.66319275, 17.32181168], [82.66319275, 17.32152939], [82.6626358, 17.32152939], [82.6626358, 17.32125092], [82.66208649, 17.32125092], [82.66208649, 17.32097054], [82.66152954, 17.32097244], [82.66152954, 17.32069397], [82.66124725, 17.32069397], [82.66124725, 17.3204174], [82.6607132, 17.32041931], [82.6607132, 17.32014084], [82.66042328, 17.32014084], [82.66042328, 17.31986046], [82.66014099, 17.31986046], [82.66014099, 17.31958771], [82.6598587, 17.31958771], [82.6598587, 17.31930923], [82.65930176, 17.31930923], [82.65930176, 17.31903076], [82.65875244, 17.31903076], [82.65875244, 17.31875038], [82.6581955, 17.31875038], [82.6581955, 17.31847191], [82.65791321, 17.31847191], [82.65791321, 17.31819534], [82.65735626, 17.31820107], [82.65735626, 17.31792068], [82.6570816, 17.31792068], [82.6570816, 17.3176403], [82.65651703, 17.3176403], [82.65651703, 17.31735992], [82.65597534, 17.31736183], [82.65597534, 17.31708336], [82.65513611, 17.31708336], [82.65513611, 17.31680679], [82.65458679, 17.31680679], [82.65458679, 17.31652832], [82.65428925, 17.31653023], [82.65428925, 17.31624985], [82.65402985, 17.31624985], [82.65402985, 17.31596947], [82.6534729, 17.31597137], [82.6534729, 17.31569672], [82.65291595, 17.31569672], [82.65291595, 17.31541443], [82.6526413, 17.31542015], [82.6526413, 17.31513977], [82.65207672, 17.31513977], [82.65207672, 17.31485939], [82.6515274, 17.3148613], [82.6515274, 17.31458473], [82.6506958, 17.31458473], [82.6506958, 17.31430435], [82.65013885, 17.31431007], [82.65013885, 17.31402969], [82.64985657, 17.31402969], [82.64985657, 17.31375122], [82.64958191, 17.31375122], [82.64958191, 17.31347084], [82.64902496, 17.31347466], [82.64902496, 17.31319237], [82.64875031, 17.31319237], [82.64875031, 17.3129158], [82.64819336, 17.31291962], [82.64819336, 17.31264114], [82.64736176, 17.31264114], [82.64736176, 17.31236076], [82.64653015, 17.31236076], [82.64653015, 17.31208038], [82.64624786, 17.31208229], [82.64624786, 17.31180573], [82.64597321, 17.31180954], [82.64597321, 17.31153107], [82.64569092, 17.31153107], [82.64569092, 17.31125069], [82.64457703, 17.31125069], [82.64457703, 17.31097031], [82.64347076, 17.31097031], [82.64347076, 17.31069374], [82.64319611, 17.31069374], [82.64319611, 17.31041718], [82.64263916, 17.3104229], [82.64263916, 17.31014061], [82.64234924, 17.31014061], [82.64234924, 17.30986023], [82.64152527, 17.30986023], [82.64152527, 17.30958366], [82.64097595, 17.30958366], [82.64097595, 17.30930519], [82.64041901, 17.30931282], [82.64041901, 17.30903244], [82.63931274, 17.30903244], [82.63931274, 17.30875015], [82.63874817, 17.30875015], [82.63874817, 17.30847168], [82.63847351, 17.30847168], [82.63847351, 17.30819511], [82.63819122, 17.30820274], [82.63819122, 17.30791855], [82.63791656, 17.30791855], [82.63791656, 17.30764961], [82.63764191, 17.30764961], [82.63764191, 17.3073597], [82.63708496, 17.3073616], [82.63708496, 17.30708313], [82.63680267, 17.30708313], [82.63680267, 17.30652809], [82.63654327, 17.30652809], [82.63654327, 17.30624962], [82.63597107, 17.30624962], [82.63597107, 17.30597115], [82.63569641, 17.30597305], [82.63569641, 17.30569458], [82.63513947, 17.30569458], [82.63513947, 17.30541611], [82.63485718, 17.30541992], [82.63485718, 17.30513954], [82.63458252, 17.30513954], [82.63458252, 17.30486107], [82.63402557, 17.30486107], [82.63402557, 17.3045826], [82.63375092, 17.30459023], [82.63375092, 17.30430984], [82.63291931, 17.30430984], [82.63291931, 17.30402946], [82.63263702, 17.30402946], [82.63263702, 17.30375099], [82.63181305, 17.30375099], [82.63181305, 17.30347061], [82.63124847, 17.30347252], [82.63124847, 17.30319595], [82.63097382, 17.30319595], [82.63097382, 17.30291748], [82.63040924, 17.30291939], [82.63040924, 17.30264091], [82.63014221, 17.30264091], [82.63014221, 17.30236053], [82.62985992, 17.30236053], [82.62985992, 17.30208015], [82.62958527, 17.30208588], [82.62958527, 17.30180359], [82.62847137, 17.30181122], [82.62847137, 17.30153084], [82.6279068, 17.30153084], [82.6279068, 17.30125046], [82.62763977, 17.30125046], [82.62763977, 17.30097008], [82.62735748, 17.30097389], [82.62735748, 17.30069351], [82.62596893, 17.3006897], [82.62596893, 17.30041695], [82.62541962, 17.30042076], [82.62541962, 17.30014038], [82.62458038, 17.30014038], [82.62458038, 17.29986], [82.62430573, 17.29986382], [82.62430573, 17.29958534], [82.62374878, 17.29958534], [82.62374878, 17.29930305], [82.62319183, 17.29931068], [82.62319183, 17.2990303], [82.62291718, 17.2990303], [82.62291718, 17.29874992], [82.62264252, 17.29874992], [82.62264252, 17.29846191], [82.62208557, 17.29847145], [82.62208557, 17.29819489], [82.62180328, 17.29819489], [82.62180328, 17.29791641], [82.62124634, 17.29792023], [82.62124634, 17.29763985], [82.62069702, 17.29763985], [82.62069702, 17.29735947], [82.62041473, 17.29736137], [82.62041473, 17.2970829], [82.62014008, 17.2970829], [82.62014008, 17.29680634], [82.61930847, 17.29681015], [82.61930847, 17.29652977], [82.61902618, 17.29652977], [82.61902618, 17.29624939], [82.61875153, 17.29624939], [82.61875153, 17.29597092], [82.61819458, 17.29597282], [82.61819458, 17.29569435], [82.61791992, 17.29569435], [82.61791992, 17.29541588], [82.61708069, 17.2954216], [82.61708069, 17.29513931], [82.61680603, 17.29513931], [82.61680603, 17.29486084], [82.61653137, 17.29486084], [82.61653137, 17.29458046], [82.61624908, 17.29458427], [82.61624908, 17.2943058], [82.6159668, 17.29431152], [82.6159668, 17.29402924], [82.61540985, 17.29402924], [82.61540985, 17.29375076], [82.61513519, 17.29375076], [82.61513519, 17.29347229], [82.61458588, 17.29347229], [82.61458588, 17.29319382], [82.61374664, 17.29319382], [82.61374664, 17.29291725], [82.61347198, 17.29291916], [82.61347198, 17.29264832], [82.61264038, 17.29264832], [82.61264038, 17.29236031], [82.61235809, 17.29236031], [82.61235809, 17.29208374], [82.61152649, 17.29207993], [82.61152649, 17.29236031], [82.61125183, 17.29236031], [82.61125183, 17.29375076], [82.61096954, 17.29375076], [82.61096954, 17.29402924], [82.61042023, 17.29402924], [82.61042023, 17.29431152], [82.61013794, 17.2943058], [82.61013794, 17.29458427], [82.60986328, 17.29458046], [82.60986328, 17.29486084], [82.60958099, 17.29486084], [82.60958099, 17.29513931], [82.60930634, 17.29513931], [82.60930634, 17.2954216], [82.60874939, 17.29541588], [82.60874939, 17.29597282], [82.6084671, 17.29597092], [82.60847473, 17.29624939], [82.6076355, 17.29624939], [82.6076355, 17.29541588], [82.60791779, 17.2954216], [82.60791779, 17.29513931], [82.60819244, 17.29513931], [82.60819244, 17.29458046], [82.60847473, 17.29458237], [82.60847473, 17.29347229], [82.60902405, 17.29347229], [82.60902405, 17.29319382], [82.60930634, 17.29319382], [82.60930634, 17.29263878], [82.60958099, 17.29264832], [82.60958099, 17.29180908], [82.60986328, 17.29180908], [82.60986328, 17.29042053], [82.60958099, 17.29042053], [82.60958099, 17.29014015], [82.60930634, 17.29014015], [82.60930634, 17.28985977], [82.60874939, 17.28986168], [82.60874939, 17.28958321], [82.60847473, 17.28958321], [82.60847473, 17.28930664], [82.60791779, 17.28930664], [82.60791779, 17.28902817], [82.60708618, 17.28903008], [82.60708618, 17.28874969], [82.60623932, 17.28874969], [82.60623932, 17.28847122], [82.60597229, 17.28847313], [82.60597229, 17.28819656], [82.60569763, 17.28819656], [82.60569763, 17.28791428], [82.60514069, 17.28792], [82.60514069, 17.28763962], [82.60430908, 17.28763962], [82.60430908, 17.28736115], [82.60346985, 17.28736115], [82.60346985, 17.28708076], [82.60236359, 17.28708267], [82.60236359, 17.2868042], [82.60151672, 17.28680992], [82.60151672, 17.28652191], [82.60097504, 17.28652763], [82.60097504, 17.28624916], [82.59929657, 17.28625107], [82.59929657, 17.28597069], [82.59764099, 17.28597069], [82.59764099, 17.28625107], [82.59570312, 17.28625107], [82.59570312, 17.28597069], [82.59541321, 17.2859745], [82.59541321, 17.28541756], [82.59570312, 17.28541946], [82.59570312, 17.2851429], [82.59625244, 17.2851429], [82.59625244, 17.28486061], [82.5965271, 17.28486061], [82.5965271, 17.28458023], [82.59680176, 17.28458214], [82.59680176, 17.28430557], [82.59707642, 17.28430939], [82.59707642, 17.28403282], [82.59736633, 17.28403282], [82.59736633, 17.28375053], [82.59680176, 17.28375053], [82.59680176, 17.28346062], [82.5965271, 17.28347015], [82.5965271, 17.28319359], [82.59625244, 17.28319359], [82.59625244, 17.28291702], [82.59597015, 17.28292274], [82.59597015, 17.28264046], [82.59541321, 17.28264046], [82.59541321, 17.28236008], [82.59430695, 17.28236008], [82.59430695, 17.28180504], [82.59401703, 17.28181267], [82.59401703, 17.28153038], [82.59348297, 17.28153038], [82.59348297, 17.28124809], [82.59319305, 17.28124809], [82.59319305, 17.28096962], [82.59263611, 17.28097153], [82.59263611, 17.28069496], [82.59236145, 17.28071022], [82.59236145, 17.2804184], [82.59179688, 17.2804184], [82.59179688, 17.28013992], [82.59123993, 17.28013992], [82.59123993, 17.27985954], [82.59069824, 17.27986145], [82.59069061, 17.27958298], [82.5901413, 17.27958298], [82.5901413, 17.27930641], [82.58957672, 17.27930832], [82.58957672, 17.27902985], [82.58930206, 17.27902985], [82.58930206, 17.27874947], [82.58875275, 17.27874947], [82.58875275, 17.27847099], [82.5881958, 17.2784729], [82.5881958, 17.27791786], [82.58763885, 17.27791977], [82.58763885, 17.27763939], [82.58651733, 17.27763939], [82.58651733, 17.27736092], [82.58597565, 17.27736092], [82.58597565, 17.27708244], [82.58569336, 17.27708244], [82.58569336, 17.27680779], [82.58542633, 17.27680969], [82.58542633, 17.27653122], [82.58486176, 17.27653122], [82.58486176, 17.27625084], [82.58429718, 17.27625084], [82.58429718, 17.27597046], [82.58374786, 17.27597237], [82.58374786, 17.2756958], [82.58347321, 17.2756958], [82.58347321, 17.27541733], [82.58319092, 17.27542114], [82.58319092, 17.27514076], [82.58235931, 17.27514076], [82.58235931, 17.27486038], [82.58207703, 17.27486038], [82.58207703, 17.27458], [82.58152771, 17.27458572], [82.58152771, 17.27430344], [82.58125305, 17.27431107], [82.58125305, 17.27403069], [82.58097076, 17.27403069], [82.58097076, 17.27375031], [82.57985687, 17.27375031], [82.57985687, 17.27346992], [82.57958221, 17.27347183], [82.57958221, 17.27319336], [82.5790329, 17.27320099], [82.5790329, 17.27292061], [82.57847595, 17.27292061], [82.57847595, 17.27235985], [82.57819366, 17.27236366], [82.57819366, 17.27208138], [82.57791901, 17.27208138], [82.57791901, 17.27180481], [82.57736206, 17.27180481], [82.57736206, 17.27152824], [82.57680511, 17.27152824], [82.57680511, 17.27124977], [82.57653046, 17.27124977], [82.57653046, 17.27096939], [82.57624817, 17.2709713], [82.57624817, 17.27069473], [82.57569122, 17.27069473], [82.57569122, 17.27041626], [82.57485962, 17.27042007], [82.57485962, 17.27013969], [82.57430267, 17.27013969], [82.57430267, 17.26986122], [82.57402802, 17.26986122], [82.57402802, 17.26958084], [82.57375336, 17.26958275], [82.57375336, 17.26930618], [82.57319641, 17.2693119], [82.57319641, 17.26902962], [82.57290649, 17.26902962], [82.57290649, 17.26874924], [82.57263947, 17.26874924], [82.57263947, 17.2684803], [82.57180786, 17.2684803], [82.57180786, 17.26818848], [82.57125092, 17.2681942], [82.57125092, 17.26791763], [82.57096863, 17.26791954], [82.57096863, 17.26763916], [82.57068634, 17.26763916], [82.57068634, 17.26736069], [82.57041931, 17.26736069], [82.57041931, 17.2670784], [82.56986237, 17.26708412], [82.56986237, 17.26680565], [82.56958008, 17.26681137], [82.56958008, 17.26625061], [82.56930542, 17.26625061], [82.56930542, 17.26597214], [82.56791687, 17.26597214], [82.56791687, 17.26569366], [82.56764221, 17.26569366], [82.56764221, 17.2654171], [82.5670929, 17.26542091], [82.5670929, 17.26514053], [82.56680298, 17.26514053], [82.56680298, 17.26486015], [82.56652832, 17.26486206], [82.56652832, 17.26458359], [82.56625366, 17.26458359], [82.56625366, 17.26430511], [82.56597137, 17.26431084], [82.56597137, 17.26403046], [82.56485748, 17.26403046], [82.56485748, 17.26375008], [82.56430817, 17.26375008], [82.56430817, 17.2634716], [82.56375122, 17.2634716], [82.56375122, 17.26319695], [82.56291962, 17.26320076], [82.56291962, 17.26292038], [82.56263733, 17.26292038], [82.56263733, 17.26264], [82.56208038, 17.26264], [82.56208038, 17.26235008], [82.56180573, 17.26236153], [82.56180573, 17.26208305], [82.56153107, 17.26208305], [82.56153107, 17.26180649], [82.56096649, 17.2618103], [82.56096649, 17.26152992], [82.56069183, 17.26152992], [82.56069183, 17.26124954], [82.56041718, 17.26124954], [82.56041718, 17.26097107], [82.55986023, 17.26097488], [82.55986023, 17.26069641], [82.55958557, 17.26069641], [82.55958557, 17.26041412], [82.55902863, 17.26041985], [82.55902863, 17.26013947], [82.55847168, 17.26013947], [82.55847168, 17.25986099], [82.55819702, 17.25986099], [82.55819702, 17.25958061], [82.55791473, 17.25958252], [82.55791473, 17.25930405], [82.55735779, 17.25930977], [82.55735779, 17.25902939], [82.55708313, 17.25902939], [82.55708313, 17.25875282], [82.55625153, 17.25875282], [82.55625153, 17.25847054], [82.55569458, 17.25847244], [82.55569458, 17.25819206], [82.55513763, 17.25819206], [82.55513763, 17.2579174], [82.55486298, 17.25792122], [82.55486298, 17.25764275], [82.55458069, 17.25764275], [82.55458069, 17.25736046], [82.55374908, 17.25736046], [82.55374908, 17.25708008], [82.55319214, 17.25708389], [82.55319214, 17.25680542], [82.55291748, 17.25681114], [82.55291748, 17.2565403], [82.55236053, 17.2565403], [82.55236053, 17.25625038], [82.55179596, 17.25625038], [82.55179596, 17.25570107], [82.55124664, 17.25570107], [82.55124664, 17.25542259], [82.55097198, 17.25542259], [82.55097198, 17.2551403], [82.55014038, 17.2551403], [82.55014038, 17.25486183], [82.54985809, 17.25486183], [82.54985809, 17.25458336], [82.54958344, 17.25458336], [82.54958344, 17.25430489], [82.54902649, 17.25430489], [82.54902649, 17.25374985], [82.54846954, 17.25374985], [82.54846954, 17.25348091], [82.54818726, 17.25348091], [82.54818726, 17.25318909], [82.54763794, 17.25319481], [82.54763794, 17.25291634], [82.54736328, 17.25291824], [82.54736328, 17.25263977], [82.54708099, 17.25263977], [82.54708099, 17.25235939], [82.54680634, 17.2523613], [82.54680634, 17.25208282], [82.54652405, 17.25208282], [82.54652405, 17.25180626], [82.54569244, 17.25180817], [82.54569244, 17.25152969], [82.54514313, 17.25152969], [82.54514313, 17.25125122], [82.54458618, 17.25125122], [82.54458618, 17.25097084], [82.54430389, 17.25097275], [82.54430389, 17.25041771], [82.54374695, 17.25041771], [82.54374695, 17.25013924], [82.54292297, 17.25014114], [82.54292297, 17.24986076], [82.54264069, 17.24986076], [82.54264069, 17.24958038], [82.54180908, 17.2495842], [82.54180908, 17.24930763], [82.54152679, 17.24930954], [82.54152679, 17.24903107], [82.54125214, 17.24903107], [82.54125214, 17.24875069], [82.54096985, 17.24875069], [82.54096985, 17.24818993], [82.54069519, 17.24819565], [82.54069519, 17.24791718], [82.54013062, 17.24792099], [82.54013062, 17.24764061], [82.53985596, 17.24764061], [82.53985596, 17.24735069], [82.53930664, 17.24736023], [82.53930664, 17.24708557], [82.53847504, 17.24708557], [82.53847504, 17.24680328], [82.53819275, 17.24681091], [82.53819275, 17.24653053], [82.53791809, 17.24653053], [82.53791809, 17.24625015], [82.53756714, 17.24625015], [82.53736115, 17.24625015], [82.53736115, 17.24596977], [82.5368042, 17.24597168], [82.5368042, 17.24569321], [82.53624725, 17.24570084], [82.53624725, 17.24542046], [82.5359726, 17.24542046], [82.5359726, 17.24514008], [82.53569794, 17.24514008], [82.53569794, 17.2448597], [82.5348587, 17.2448616], [82.5348587, 17.24458122], [82.53430176, 17.24458122], [82.53430176, 17.24430466], [82.53375244, 17.24431038], [82.53375244, 17.24403191], [82.53347015, 17.24403191], [82.53347015, 17.24374962], [82.53291321, 17.24374962], [82.53291321, 17.24347115], [82.53236389, 17.24347115], [82.53236389, 17.24319458], [82.5320816, 17.24319458], [82.5320816, 17.24291611], [82.53151703, 17.24292183], [82.53151703, 17.24263954], [82.53125, 17.24263954], [82.53125, 17.24235916], [82.53097534, 17.24235916], [82.53097534, 17.2420826], [82.53069305, 17.2420826], [82.53069305, 17.24180603], [82.5304184, 17.24181175], [82.5304184, 17.24154282], [82.53013611, 17.24154282], [82.53013611, 17.24124908], [82.52986145, 17.24124908], [82.52986145, 17.24068832], [82.52958679, 17.24069405], [82.52958679, 17.24041748], [82.52929688, 17.24041939], [82.52929688, 17.24014091], [82.52902985, 17.24014091], [82.52902985, 17.23986053], [82.5284729, 17.23986053], [82.5284729, 17.23957825], [82.52791595, 17.23958397], [82.52791595, 17.2393055], [82.52707672, 17.23931122], [82.52707672, 17.23903084], [82.5265274, 17.23903084], [82.5265274, 17.23875046], [82.52625275, 17.23875046], [82.52625275, 17.23820114], [82.52597046, 17.23818016], [82.52597046, 17.23791885], [82.52540588, 17.23792076], [82.52540588, 17.23764038], [82.52485657, 17.23764038], [82.52485657, 17.23736], [82.52430725, 17.23736191], [82.52430725, 17.23708344], [82.52402496, 17.23708344], [82.52402496, 17.23680687], [82.52375031, 17.23681068], [82.52375031, 17.2365303], [82.52348328, 17.2365303], [82.52348328, 17.23624992], [82.52319336, 17.23624992], [82.52319336, 17.23596954], [82.52263641, 17.23597145], [82.52263641, 17.23569679], [82.52236176, 17.23569679], [82.52236176, 17.23541451], [82.52180481, 17.23541451], [82.52180481, 17.23513985], [82.52124786, 17.23513985], [82.52124786, 17.23485947], [82.52069092, 17.23486137], [82.52069092, 17.23458481], [82.51985931, 17.23458481], [82.51985931, 17.23430634], [82.51930237, 17.23431015], [82.51930237, 17.23402977], [82.51902008, 17.23402977], [82.51902008, 17.23374939], [82.51875305, 17.23374939], [82.51875305, 17.23347092], [82.51847076, 17.23347473], [82.51847076, 17.23319244], [82.51819611, 17.23319244], [82.51819611, 17.23291588], [82.51763916, 17.23291969], [82.51763916, 17.23264122], [82.51735687, 17.23264122], [82.51735687, 17.23208046], [82.51708221, 17.23208237], [82.51708221, 17.2318058], [82.51680756, 17.23180962], [82.51680756, 17.23153114], [82.5165329, 17.23153114], [82.5165329, 17.23125076], [82.51568604, 17.23125076], [82.51568604, 17.23097038], [82.51541901, 17.23097229], [82.51541901, 17.23069382], [82.51457977, 17.23069382], [82.51457977, 17.23041725], [82.51431274, 17.23042107], [82.51431274, 17.23014259], [82.51403046, 17.23014259], [82.51403046, 17.22986031], [82.51374817, 17.22986031], [82.51374817, 17.2293129], [82.51346588, 17.2293129], [82.51346588, 17.22875023], [82.51235962, 17.22875023], [82.51235962, 17.22847176], [82.51180267, 17.22847176], [82.51180267, 17.22819519], [82.51152802, 17.22820282], [82.51152802, 17.22792244], [82.51125336, 17.22792244], [82.51125336, 17.22763824], [82.51097107, 17.22763824], [82.51097107, 17.22735977], [82.51041412, 17.22736168], [82.51041412, 17.22708321], [82.51013947, 17.22708321], [82.51013947, 17.22680473], [82.50986481, 17.22680473], [82.50986481, 17.22652817], [82.50930786, 17.22652817], [82.50930786, 17.22624016], [82.50819397, 17.22624969], [82.50819397, 17.22597313], [82.50791931, 17.22597313], [82.50791931, 17.22569466], [82.50763702, 17.22569466], [82.50763702, 17.22541618], [82.50736237, 17.22541809], [82.50736237, 17.22513962], [82.50680542, 17.22513962], [82.50680542, 17.22486115], [82.50653076, 17.22486115], [82.50653076, 17.22458076], [82.50624847, 17.22458267], [82.50624847, 17.22430611], [82.50596619, 17.22430992], [82.50596619, 17.22402954], [82.50514221, 17.22402954], [82.50514221, 17.22375107], [82.50485992, 17.22375107], [82.50485992, 17.22347069], [82.50430298, 17.2234726], [82.50430298, 17.22319412], [82.50402832, 17.22319412], [82.50402832, 17.22291756], [82.50347137, 17.22291946], [82.50347137, 17.22264099], [82.5029068, 17.22264099], [82.5029068, 17.22236061], [82.50263977, 17.22236061], [82.50263977, 17.22208023], [82.50208282, 17.22208595], [82.50208282, 17.22180367], [82.50180817, 17.22180939], [82.50180817, 17.22153091], [82.50125122, 17.22153091], [82.50125122, 17.22125053], [82.50096893, 17.22125053], [82.50096893, 17.22097206], [82.50041962, 17.22097206], [82.50041962, 17.22041512], [82.50013733, 17.22043037], [82.50013733, 17.21986008], [82.49958038, 17.21986389], [82.49958038, 17.21958542], [82.49874878, 17.21958542], [82.49874878, 17.21930313], [82.49846649, 17.21931076], [82.49846649, 17.21903038], [82.49791718, 17.21903038], [82.49791718, 17.21875], [82.49764252, 17.21875], [82.49764252, 17.21846962], [82.49708557, 17.21847153], [82.49708557, 17.21819305], [82.49652863, 17.21820068], [82.49652863, 17.2179203], [82.49624634, 17.2179203], [82.49624634, 17.21763992], [82.49597168, 17.21763992], [82.49597168, 17.21737289], [82.49569702, 17.21737289], [82.49569702, 17.21708107], [82.49514008, 17.21708107], [82.49514008, 17.21680641], [82.49458313, 17.21681023], [82.49458313, 17.21653175], [82.49430847, 17.21653175], [82.49430847, 17.21624947], [82.49402618, 17.21624947], [82.49402618, 17.21596909], [82.49346924, 17.2159729], [82.49346924, 17.21569443], [82.49319458, 17.21569443], [82.49319458, 17.21541595], [82.49263763, 17.21542168], [82.49263763, 17.21513939], [82.49208069, 17.21513939], [82.49208069, 17.21486092], [82.49180603, 17.21486092], [82.49180603, 17.21458054], [82.49153137, 17.21458244], [82.49153137, 17.21430588], [82.49097443, 17.21430588], [82.49097443, 17.2140274], [82.49014282, 17.21402931], [82.49014282, 17.21375084], [82.48986053, 17.21375084], [82.48986053, 17.21347046], [82.48958588, 17.21347237], [82.48958588, 17.21319389], [82.48930359, 17.21319389], [82.48930359, 17.21291733], [82.48903656, 17.21291924], [82.48903656, 17.21264076], [82.48874664, 17.21264076], [82.48874664, 17.21236038], [82.48819733, 17.21236038], [82.48819733, 17.21180916], [82.48792267, 17.21180916], [82.48792267, 17.21153069], [82.48764038, 17.21153069], [82.48764038, 17.21124077], [82.48708344, 17.21125031], [82.48708344, 17.21097183], [82.48652649, 17.21097183], [82.48652649, 17.21069527], [82.48625183, 17.21070099], [82.48625183, 17.21014023], [82.48597717, 17.21014023], [82.48597717, 17.20985985], [82.48542023, 17.20986176], [82.48542023, 17.20958328], [82.48486328, 17.20958328], [82.48486328, 17.20930672], [82.48430634, 17.20930672], [82.48430634, 17.20902824], [82.48401642, 17.20903015], [82.48401642, 17.20874977], [82.4834671, 17.20874977], [82.4834671, 17.20846939], [82.48319244, 17.2084713], [82.48319244, 17.20819664], [82.48291016, 17.20820045], [82.48291016, 17.20792007], [82.48236084, 17.20792007], [82.48236084, 17.20763969], [82.48208618, 17.20763969], [82.48208618, 17.20736122], [82.48179626, 17.20736122], [82.48179626, 17.20708084], [82.48124695, 17.20708466], [82.48124695, 17.20680428], [82.48097229, 17.20681], [82.48097229, 17.20652962], [82.48042297, 17.20652962], [82.48042297, 17.20625114], [82.48014069, 17.20625114], [82.48014069, 17.20597076], [82.47958374, 17.20597458], [82.47958374, 17.20569229], [82.47930908, 17.20569229], [82.47930908, 17.20541763], [82.47875214, 17.20543098], [82.47875214, 17.20514107], [82.47846985, 17.20514107], [82.47846985, 17.20486069], [82.47763824, 17.20486069], [82.47763824, 17.20458031], [82.47736359, 17.20458221], [82.47736359, 17.20430565], [82.4770813, 17.20430946], [82.4770813, 17.2040329], [82.47680664, 17.2040329], [82.47680664, 17.20375061], [82.47651672, 17.20375061], [82.47651672, 17.20319176], [82.47597504, 17.20319366], [82.47597504, 17.20263863], [82.47569275, 17.20264053], [82.47569275, 17.20236015], [82.47541809, 17.20236015], [82.47541809, 17.20208359], [82.4751358, 17.20208359], [82.4751358, 17.20180511], [82.47486115, 17.20181274], [82.47486115, 17.20153236], [82.47458649, 17.20153236], [82.47458649, 17.20125008], [82.47429657, 17.20125008], [82.47429657, 17.2009697], [82.47402954, 17.2009716], [82.47402954, 17.20069504], [82.4734726, 17.20070076], [82.4734726, 17.20041847], [82.47319794, 17.20041847], [82.47319794, 17.20013809], [82.47292328, 17.20013809], [82.47292328, 17.19985962], [82.47264099, 17.19986153], [82.47264099, 17.19958305], [82.4723587, 17.19958305], [82.4723587, 17.19930649], [82.47208405, 17.19930649], [82.47208405, 17.19902992], [82.4715271, 17.19902992], [82.4715271, 17.19874954], [82.47125244, 17.19874954], [82.47125244, 17.19847107], [82.47097015, 17.19847298], [82.47097015, 17.1981945], [82.4706955, 17.1981945], [82.4706955, 17.19791794], [82.47013855, 17.19791985], [82.47013855, 17.19763947], [82.46985626, 17.19763947], [82.46985626, 17.19736099], [82.4695816, 17.19736099], [82.4695816, 17.19708061], [82.46930695, 17.19708252], [82.46930695, 17.19680786], [82.46875, 17.19680977], [82.46875, 17.19652939], [82.46848297, 17.19652939], [82.46848297, 17.19626045], [82.46819305, 17.19626045], [82.46819305, 17.19597054], [82.4679184, 17.19597244], [82.4679184, 17.19569588], [82.46736145, 17.19569588], [82.46736145, 17.1954174], [82.46708679, 17.19542122], [82.46708679, 17.19514084], [82.46679688, 17.19514084], [82.46679688, 17.19486046], [82.46652985, 17.19486046], [82.46652985, 17.19458008], [82.4659729, 17.1945858], [82.4659729, 17.19430351], [82.46569824, 17.19431114], [82.46569061, 17.19403076], [82.46541595, 17.19403076], [82.46541595, 17.19375038], [82.4651413, 17.19375038], [82.4651413, 17.19347], [82.46458435, 17.19347382], [82.46458435, 17.19319344], [82.46430206, 17.19320107], [82.46430206, 17.19292068], [82.4640274, 17.19292068], [82.4640274, 17.1926403], [82.46375275, 17.1926403], [82.46375275, 17.19235992], [82.4631958, 17.19236374], [82.4631958, 17.19208145], [82.46291351, 17.19208145], [82.46291351, 17.19180489], [82.46263885, 17.19180489], [82.46263885, 17.19152832], [82.46235657, 17.19153023], [82.46235657, 17.19124985], [82.46180725, 17.19124985], [82.46180725, 17.19096947], [82.46152496, 17.19097137], [82.46152496, 17.19069481], [82.46125031, 17.19069481], [82.46125031, 17.19041634], [82.46098328, 17.19042015], [82.46098328, 17.19013977], [82.46069336, 17.19013977], [82.46069336, 17.18985939], [82.46013641, 17.1898613], [82.46013641, 17.18958282], [82.45986176, 17.18958282], [82.45986176, 17.18930626], [82.4595871, 17.18931007], [82.4595871, 17.18902969], [82.45929718, 17.18902969], [82.45929718, 17.18874931], [82.45903015, 17.18874931], [82.45903015, 17.18847084], [82.45874786, 17.18847275], [82.45874786, 17.18819427], [82.45819092, 17.18819427], [82.45819092, 17.1879158], [82.45791626, 17.18792152], [82.45791626, 17.18763924], [82.4576416, 17.18763924], [82.4576416, 17.18736076], [82.45735931, 17.18736076], [82.45735931, 17.18707085], [82.45708466, 17.1870842], [82.45708466, 17.18680573], [82.45652771, 17.18681145], [82.45652771, 17.18652916], [82.45625305, 17.18652916], [82.45625305, 17.18625069], [82.45597076, 17.18625069], [82.45597076, 17.18597031], [82.45569611, 17.18597221], [82.45569611, 17.18569374], [82.45541382, 17.18569374], [82.45541382, 17.18541718], [82.45513916, 17.18541908], [82.45513916, 17.18514061], [82.45485687, 17.18514061], [82.45485687, 17.18486023], [82.45430756, 17.18486023], [82.45430756, 17.18457985], [82.45402527, 17.18458366], [82.45402527, 17.18430519], [82.45375061, 17.18432045], [82.45375061, 17.18403053], [82.45347595, 17.18403053], [82.45347595, 17.18375015], [82.45318604, 17.18375015], [82.45318604, 17.18346977], [82.45263672, 17.18347168], [82.45263672, 17.18319511], [82.45236206, 17.18320084], [82.45236206, 17.18292046], [82.45181274, 17.18292046], [82.45181274, 17.18264008], [82.45153046, 17.18264008], [82.45153046, 17.1823597], [82.45097351, 17.1823616], [82.45097351, 17.18208313], [82.45069122, 17.18208313], [82.45069122, 17.18180656], [82.45014191, 17.18180656], [82.45014191, 17.18152809], [82.44986725, 17.18153], [82.44986725, 17.18126106], [82.44930267, 17.18126106], [82.44930267, 17.18097115], [82.44902802, 17.18097305], [82.44902802, 17.18069649], [82.44847107, 17.18069649], [82.44847107, 17.1804142], [82.44819641, 17.18041992], [82.44819641, 17.18013954], [82.44790649, 17.18013954], [82.44790649, 17.17986107], [82.44763947, 17.17986107], [82.44763947, 17.17958069], [82.44736481, 17.1795826], [82.44736481, 17.17930412], [82.44708252, 17.17930984], [82.44708252, 17.17902946], [82.4465332, 17.17902946], [82.4465332, 17.1787529], [82.44625092, 17.1787529], [82.44625092, 17.17847061], [82.44596863, 17.17847443], [82.44596863, 17.17819214], [82.44568634, 17.17819977], [82.44568634, 17.17791939], [82.44541931, 17.17791939], [82.44541931, 17.17764282], [82.44513702, 17.17764282], [82.44513702, 17.17736053], [82.44486237, 17.17736053], [82.44486237, 17.17708015], [82.44458008, 17.17708206], [82.44458008, 17.1768055], [82.44431305, 17.17681122], [82.44431305, 17.17653275], [82.44374084, 17.17653275], [82.44374084, 17.17625046], [82.44346619, 17.17625046], [82.44346619, 17.17597008], [82.44319153, 17.17597008], [82.44319153, 17.17569542], [82.44291687, 17.1756916], [82.44291687, 17.17541695], [82.44264221, 17.17542267], [82.44264221, 17.17513084], [82.44235992, 17.17513847], [82.44235992, 17.17486191], [82.44180298, 17.17486191], [82.44180298, 17.17458344], [82.44152832, 17.17458344], [82.44152832, 17.17430496], [82.44124603, 17.17431068], [82.44124603, 17.1740284], [82.44069672, 17.1740284], [82.44069672, 17.17374992], [82.44013977, 17.17374992], [82.44013977, 17.17346954], [82.43985748, 17.17347145], [82.43985748, 17.17319489], [82.43958282, 17.17319489], [82.43958282, 17.17291641], [82.43930817, 17.17291832], [82.43930817, 17.17263985], [82.43902588, 17.17263985], [82.43902588, 17.17206955], [82.43875122, 17.1720829], [82.43875122, 17.17152786], [82.43846893, 17.17152977], [82.43846893, 17.17124939], [82.43791962, 17.17124939], [82.43791962, 17.17097282], [82.43763733, 17.17097282], [82.43763733, 17.17041779], [82.43736267, 17.17041969], [82.43736267, 17.16958046], [82.43708038, 17.16958427], [82.43708038, 17.16930771], [82.43681335, 17.16932106], [82.43681335, 17.16903114], [82.43653107, 17.16903114], [82.43653107, 17.16875076], [82.43596649, 17.16875076], [82.43596649, 17.16847038], [82.43569183, 17.16847229], [82.43569183, 17.16819572], [82.43514252, 17.16819572], [82.43514252, 17.16791725], [82.4345932, 17.16792107], [82.4345932, 17.16764069], [82.43430328, 17.16764069], [82.43430328, 17.16736031], [82.43402863, 17.16736031], [82.43402863, 17.16707993], [82.43374634, 17.16708565], [82.43374634, 17.16680336], [82.43347168, 17.16681099], [82.43347168, 17.16653061], [82.43264008, 17.16653061], [82.43264008, 17.16625977], [82.43235779, 17.16625977], [82.43235779, 17.16596985], [82.43208313, 17.16597176], [82.43208313, 17.16569328], [82.43152618, 17.16570091], [82.43152618, 17.16542053], [82.43125153, 17.16542053], [82.43125153, 17.16514015], [82.43096924, 17.16514015], [82.43096924, 17.16457939], [82.43069458, 17.1645813], [82.43069458, 17.16430473], [82.43041992, 17.16430473], [82.43041992, 17.16402817], [82.42986298, 17.16403008], [82.42986298, 17.16374969], [82.42958069, 17.16374969], [82.42958069, 17.16347122], [82.42903137, 17.16347122], [82.42903137, 17.16319466], [82.42874908, 17.16319466], [82.42874908, 17.16291618], [82.4284668, 17.16292191], [82.4284668, 17.16263962], [82.42819214, 17.16263962], [82.42819214, 17.16208076], [82.42763519, 17.16208267], [82.42763519, 17.16180611], [82.42736053, 17.16181183], [82.42736053, 17.16152954], [82.42708588, 17.16152954], [82.42708588, 17.16124916], [82.42679596, 17.16124916], [82.42679596, 17.16097069], [82.42652893, 17.1609726], [82.42652893, 17.16069412], [82.42624664, 17.16069412], [82.42624664, 17.16041756], [82.42597198, 17.16042137], [82.42597198, 17.16012955], [82.42569733, 17.16013908], [82.42569733, 17.15986061], [82.42541504, 17.15986061], [82.42541504, 17.15958405], [82.42485809, 17.15958405], [82.42485809, 17.15930557], [82.42457581, 17.15930748], [82.42457581, 17.15903091], [82.42430878, 17.15903091], [82.42430878, 17.15875053], [82.42402649, 17.15875053], [82.42402649, 17.15847015], [82.42375183, 17.15847206], [82.42375183, 17.15819359], [82.42346954, 17.15819359], [82.42346954, 17.15791893], [82.42318726, 17.15792084], [82.42318726, 17.15764046], [82.42292786, 17.15764046], [82.42292786, 17.15736008], [82.42263794, 17.15736198], [82.42263794, 17.15708351], [82.42236328, 17.15709114], [82.42236328, 17.15681076], [82.42208099, 17.15681076], [82.42208099, 17.15653038], [82.42180634, 17.15653038], [82.42180634, 17.15625], [82.42151642, 17.15625], [82.42151642, 17.15596962], [82.42097473, 17.15597153], [82.42097473, 17.15541649], [82.42069244, 17.1554203], [82.42069244, 17.15513992], [82.42041779, 17.15513992], [82.42041779, 17.15485954], [82.4201355, 17.15486145], [82.4201355, 17.15458488], [82.41986084, 17.15458488], [82.41986084, 17.15430641], [82.41958618, 17.15431976], [82.41958618, 17.15402985], [82.41902924, 17.15402985], [82.41902924, 17.15347099], [82.41874695, 17.15347481], [82.41874695, 17.15319252], [82.41847229, 17.15319252], [82.41847229, 17.15263939], [82.41819763, 17.15263939], [82.41819763, 17.15236092], [82.41791534, 17.15236092], [82.41791534, 17.15208244], [82.4173584, 17.15208244], [82.4173584, 17.15180588], [82.41680145, 17.15180969], [82.41680145, 17.15153122], [82.41652679, 17.15153122], [82.41652679, 17.15125275], [82.41625214, 17.15125275], [82.41625214, 17.15096092], [82.41596985, 17.15097237], [82.41596985, 17.15069389], [82.41569519, 17.15069389], [82.41569519, 17.15041733], [82.4154129, 17.15042114], [82.4154129, 17.15014267], [82.41513824, 17.15014267], [82.41513824, 17.14986038], [82.41485596, 17.14986038], [82.41485596, 17.14958191], [82.41402435, 17.14958382], [82.41402435, 17.14902687], [82.41356659, 17.14902687], [82.41319275, 17.14903259], [82.41319275, 17.14875031], [82.41291809, 17.14875031], [82.41291809, 17.14847183], [82.4126358, 17.14847183], [82.4126358, 17.14819527], [82.41236115, 17.14819527], [82.41236115, 17.14791679], [82.41208649, 17.14792252], [82.41208649, 17.14763832], [82.41179657, 17.14763832], [82.41179657, 17.14735985], [82.41152954, 17.14736176], [82.41152954, 17.14708328], [82.41124725, 17.14708328], [82.41124725, 17.14680481], [82.4109726, 17.14680481], [82.4109726, 17.14652824], [82.41069794, 17.14652824], [82.41069794, 17.14624977], [82.41041565, 17.14624977], [82.41041565, 17.1459713], [82.41014099, 17.1459713], [82.41014099, 17.14569473], [82.4098587, 17.14569473], [82.4098587, 17.14541626], [82.40957642, 17.14541817], [82.40957642, 17.14514923], [82.40930176, 17.14514923], [82.40930176, 17.14486122], [82.4090271, 17.14486122], [82.4090271, 17.14458084], [82.40875244, 17.14458275], [82.40875244, 17.14430618], [82.40847015, 17.14430809], [82.40847015, 17.14402962], [82.40820313, 17.14402962], [82.40820313, 17.14375114], [82.40791321, 17.14375114], [82.40791321, 17.14347076], [82.40763855, 17.14347267], [82.40763855, 17.1431942], [82.4070816, 17.1431942], [82.4070816, 17.14291763], [82.40680695, 17.14291954], [82.40680695, 17.14264107], [82.40651703, 17.14264107], [82.40651703, 17.14236069], [82.40625, 17.14236069], [82.40625, 17.14180946], [82.40598297, 17.14180946], [82.40598297, 17.14153099], [82.40569305, 17.14153099], [82.40569305, 17.14125061], [82.4054184, 17.14125061], [82.4054184, 17.14097023], [82.40513611, 17.14097214], [82.40513611, 17.14069557], [82.40486145, 17.14069557], [82.40486145, 17.14013863], [82.40458679, 17.14014053], [82.40458679, 17.13986015], [82.4043045, 17.13986206], [82.4043045, 17.13958549], [82.40374756, 17.13958549], [82.40374756, 17.13930321], [82.4034729, 17.13931084], [82.4034729, 17.13902283], [82.40291595, 17.13902855], [82.40291595, 17.13875008], [82.4026413, 17.13875008], [82.4026413, 17.1384697], [82.40208435, 17.1384716], [82.40208435, 17.13819313], [82.40180206, 17.13820076], [82.40180206, 17.13792038], [82.40125275, 17.13792038], [82.40125275, 17.13764191], [82.40097046, 17.13764191], [82.40097046, 17.13735962], [82.40041351, 17.13736153], [82.40041351, 17.13708115], [82.40013885, 17.13708115], [82.40013885, 17.13680649], [82.39958191, 17.1368103], [82.39958191, 17.13653183], [82.39930725, 17.13653183], [82.39930725, 17.13624954], [82.39901733, 17.13624954], [82.39901733, 17.13569069], [82.39875031, 17.1356945], [82.39875031, 17.13541603], [82.39848328, 17.13542175], [82.39848328, 17.13513947], [82.39819336, 17.13513947], [82.39819336, 17.13485909], [82.3979187, 17.13485909], [82.3979187, 17.13431168], [82.39763641, 17.13431168], [82.39763641, 17.13402939], [82.39736176, 17.13402939], [82.39736176, 17.13375092], [82.3970871, 17.13375092], [82.3970871, 17.13347054], [82.39680481, 17.13347244], [82.39680481, 17.1329174], [82.39653015, 17.13291931], [82.39653015, 17.13264084], [82.39624786, 17.13264084], [82.39624786, 17.13236046], [82.39597321, 17.13236046], [82.39597321, 17.13207817], [82.39569092, 17.13208389], [82.39569092, 17.13180542], [82.39541626, 17.13181114], [82.39541626, 17.13153076], [82.3951416, 17.13153076], [82.3951416, 17.13125038], [82.39485931, 17.13125038], [82.39485931, 17.13097], [82.39430237, 17.13097191], [82.39430237, 17.13069534], [82.39402771, 17.13070107], [82.39402771, 17.13042068], [82.39375305, 17.13042068], [82.39375305, 17.13014984], [82.39347076, 17.13014984], [82.39347076, 17.12985992], [82.39319611, 17.12986183], [82.39319611, 17.12958336], [82.39291382, 17.12958336], [82.39291382, 17.12930679], [82.39263916, 17.12930679], [82.39263916, 17.12902832], [82.39235687, 17.12903023], [82.39235687, 17.12874985], [82.39208221, 17.12874985], [82.39208221, 17.12846947], [82.39180756, 17.12847137], [82.39180756, 17.12819672], [82.39152527, 17.12819672], [82.39152527, 17.12791443], [82.39125061, 17.12792015], [82.39125061, 17.12763977], [82.39097595, 17.12763977], [82.39097595, 17.12735939], [82.39069366, 17.1273613], [82.39069366, 17.12708473], [82.39041901, 17.12708473], [82.39041901, 17.12652779], [82.39013672, 17.12652969], [82.39013672, 17.12625122], [82.38986206, 17.12625122], [82.38986206, 17.12569046], [82.38930511, 17.12569237], [82.38930511, 17.1254158], [82.38903046, 17.12541962], [82.38903046, 17.12514114], [82.38874817, 17.12514114], [82.38874817, 17.12486076], [82.38846588, 17.12486076], [82.38846588, 17.12458038], [82.38819122, 17.12458229], [82.38819122, 17.12430573], [82.38764191, 17.12430954], [82.38764191, 17.12401962], [82.38735962, 17.12402725], [82.38735962, 17.12375069], [82.38707733, 17.12375069], [82.38707733, 17.12347031], [82.38680267, 17.12347031], [82.38680267, 17.12319374], [82.38652802, 17.12319374], [82.38652802, 17.12291718], [82.38625336, 17.1229229], [82.38625336, 17.12264252], [82.38597107, 17.12264252], [82.38597107, 17.12236023], [82.38540649, 17.12236023], [82.38540649, 17.12208176], [82.38513947, 17.12208366], [82.38513947, 17.12180519], [82.38485718, 17.12181282], [82.38485718, 17.12153244], [82.38458252, 17.12153244], [82.38458252, 17.12125015], [82.38430786, 17.12125015], [82.38430786, 17.12098122], [82.3840332, 17.12098122], [82.3840332, 17.12070084], [82.38375092, 17.12070084], [82.38375092, 17.12041855], [82.383461, 17.12041855], [82.383461, 17.12013817], [82.38318634, 17.12013817], [82.38318634, 17.1198597], [82.38291931, 17.1198616], [82.38291931, 17.11958313], [82.38263702, 17.11958313], [82.38263702, 17.11930466], [82.38208008, 17.11930466], [82.38208008, 17.11902809], [82.38181305, 17.11902809], [82.38181305, 17.11874962], [82.38153076, 17.11874962], [82.38153076, 17.11847115], [82.38124847, 17.11847305], [82.38124847, 17.11819458], [82.38097382, 17.11819458], [82.38097382, 17.11791611], [82.38069153, 17.11791992], [82.38069153, 17.11763954], [82.38041687, 17.11763954], [82.38041687, 17.11736107], [82.38014221, 17.11736107], [82.38014221, 17.11708069], [82.37985992, 17.1170826], [82.37985992, 17.11680794], [82.3795929, 17.11680984], [82.3795929, 17.11652946], [82.37930298, 17.11652946], [82.37930298, 17.11597061], [82.37902832, 17.11597252], [82.37902832, 17.11569595], [82.37875366, 17.11569595], [82.37875366, 17.11541748], [82.37847137, 17.11541939], [82.37847137, 17.11514091], [82.37819672, 17.11514091], [82.37819672, 17.114851], [82.37791443, 17.11486053], [82.37791443, 17.11458588], [82.37735748, 17.11458588], [82.37735748, 17.11430359], [82.37708282, 17.11431122], [82.37708282, 17.11403084], [82.37680817, 17.11403084], [82.37680817, 17.11375046], [82.37652588, 17.11375046], [82.37652588, 17.11347008], [82.37625122, 17.11347389], [82.37625122, 17.11319542], [82.37596893, 17.1131897], [82.37596893, 17.11291695], [82.37568665, 17.11292076], [82.37568665, 17.11264038], [82.37541962, 17.11264038], [82.37541962, 17.11236], [82.37513733, 17.11236382], [82.37513733, 17.11208153], [82.37486267, 17.11208153], [82.37486267, 17.11180305], [82.37458801, 17.11181068], [82.37458801, 17.1115303], [82.37431335, 17.1115303], [82.37431335, 17.11124992], [82.37403107, 17.11124992], [82.37403107, 17.11096954], [82.37374878, 17.11097145], [82.37374878, 17.11069489], [82.37319183, 17.11069489], [82.37319183, 17.11041641], [82.37291718, 17.11042023], [82.37291718, 17.11013985], [82.37264252, 17.11013985], [82.37264252, 17.10985947], [82.37236023, 17.10986137], [82.37236023, 17.1095829], [82.37208557, 17.1095829], [82.37208557, 17.10930634], [82.37180328, 17.10931015], [82.37180328, 17.10874939], [82.371521, 17.10874939], [82.371521, 17.10847092], [82.37097168, 17.10847282], [82.37097168, 17.10819435], [82.37041473, 17.10819435], [82.37041473, 17.10791588], [82.37014008, 17.1079216], [82.37014008, 17.10736084], [82.36985779, 17.10736084], [82.36985779, 17.10708046], [82.36958313, 17.10708427], [82.36958313, 17.1068058], [82.36902618, 17.10681152], [82.36902618, 17.10652924], [82.36875153, 17.10652924], [82.36875153, 17.10625076], [82.36763763, 17.10625076], [82.36763763, 17.10597992], [82.36736298, 17.10597992], [82.36736298, 17.10625076], [82.36708069, 17.10625076], [82.36708069, 17.10652924], [82.36653137, 17.10652924], [82.36653137, 17.10681152], [82.36624908, 17.1068058], [82.36624908, 17.10708427], [82.3659668, 17.10708046], [82.3659668, 17.10763931], [82.36569214, 17.10763931], [82.36569214, 17.10819435], [82.36541748, 17.10819435], [82.36541748, 17.10847282], [82.36514282, 17.10847092], [82.36514282, 17.11013985], [82.36541748, 17.11013985], [82.36541748, 17.11042023], [82.36597443, 17.11041641], [82.36597443, 17.11069489], [82.36624908, 17.11069489], [82.36624908, 17.11097145], [82.36653137, 17.11096954], [82.36653137, 17.11124992], [82.36680603, 17.11124992], [82.36680603, 17.1115303], [82.36708069, 17.1115303], [82.36708069, 17.11181068], [82.36736298, 17.11180305], [82.36736298, 17.11208153], [82.36763763, 17.11208153], [82.36763763, 17.11236382], [82.36791992, 17.11236], [82.36791992, 17.11292076], [82.36819458, 17.11291695], [82.36819458, 17.11347389], [82.36846161, 17.11347008], [82.36846161, 17.11736107], [82.36875153, 17.11736107], [82.36875153, 17.11791992], [82.36902618, 17.11791992], [82.36902618, 17.11874962], [82.36846161, 17.11874962], [82.36846161, 17.11847115], [82.36819458, 17.11847305], [82.36819458, 17.11819458], [82.36791992, 17.11819458], [82.36791992, 17.11736107], [82.36763763, 17.11736107], [82.36763763, 17.11375046], [82.36736298, 17.11375046], [82.36736298, 17.11347008], [82.36708069, 17.11347389], [82.36708069, 17.11319542], [82.36680603, 17.1131897], [82.36680603, 17.11263847], [82.36653137, 17.11264038], [82.36653137, 17.11236], [82.36624908, 17.11236382], [82.36624908, 17.11208153], [82.36541748, 17.11208153], [82.36541748, 17.11180305], [82.36514282, 17.11181068], [82.36514282, 17.1115303], [82.36486053, 17.1115303], [82.36486053, 17.11124992], [82.36458588, 17.11124992], [82.36458588, 17.11096954], [82.36430359, 17.11097145], [82.36430359, 17.11069489], [82.36402893, 17.11069489], [82.36402893, 17.11041641], [82.36374664, 17.11042023], [82.36374664, 17.10985947], [82.36347198, 17.10986137], [82.36347198, 17.10930634], [82.36319733, 17.10931015], [82.36319733, 17.10763931], [82.36347198, 17.10763931], [82.36347198, 17.10736084], [82.36402893, 17.10736084], [82.36402893, 17.10708046], [82.36430359, 17.10708237], [82.36430359, 17.1068058], [82.36458588, 17.10681152], [82.36458588, 17.10652924], [82.36486053, 17.10652924], [82.36486053, 17.10625076], [82.36514282, 17.10625076], [82.36513519, 17.10597229], [82.36541748, 17.10597992], [82.36541748, 17.1056881], [82.36569214, 17.10569382], [82.36569214, 17.10458374], [82.36541748, 17.10458374], [82.36541748, 17.10430527], [82.36514282, 17.10430908], [82.36514282, 17.10403061], [82.36486053, 17.10403061], [82.36486053, 17.10375023], [82.36458588, 17.10375023], [82.36458588, 17.10346985], [82.36430359, 17.10347176], [82.36430359, 17.10319519], [82.36374664, 17.10320091], [82.36374664, 17.102911], [82.36347198, 17.10291672], [82.36347198, 17.10263824], [82.36292267, 17.10264015], [82.36292267, 17.10235977], [82.36264038, 17.10236168], [82.36264038, 17.10180664], [82.36235809, 17.10180664], [82.36235809, 17.10152817], [82.36207581, 17.10153008], [82.36207581, 17.10124969], [82.36180878, 17.10124969], [82.36180878, 17.10097122], [82.36152649, 17.10097313], [82.36152649, 17.10069656], [82.36096954, 17.10069656], [82.36096954, 17.10041428], [82.36068726, 17.10042], [82.36068726, 17.0998497], [82.36042023, 17.09986115], [82.36042023, 17.0993042], [82.36013794, 17.09930992], [82.36013794, 17.09902954], [82.35986328, 17.09902954], [82.35986328, 17.09875107], [82.35958099, 17.09875107], [82.35958099, 17.09847069], [82.35930634, 17.0984745], [82.35930634, 17.09819221], [82.35902405, 17.09819221], [82.35902405, 17.09791756], [82.35874939, 17.09791946], [82.35874939, 17.09708023], [82.35847473, 17.09708214], [82.35847473, 17.09680557], [82.35819244, 17.09680939], [82.35819244, 17.09653282], [82.35791779, 17.09653282], [82.35791779, 17.09625053], [82.3576355, 17.09625053], [82.3576355, 17.09597015], [82.35736084, 17.09597015], [82.35736084, 17.09569359], [82.35708618, 17.09569359], [82.35708618, 17.09541702], [82.35679626, 17.09542274], [82.35679626, 17.09514046], [82.35652161, 17.09514046], [82.35652161, 17.09486008], [82.35624695, 17.09486008], [82.35624695, 17.09458351], [82.35597229, 17.09458351], [82.35597229, 17.09430504], [82.35541534, 17.09430504], [82.35541534, 17.09458351], [82.35514069, 17.09458351], [82.35514069, 17.09486008], [82.3548584, 17.09486008], [82.3548584, 17.09569359], [82.35457611, 17.09569168], [82.35457611, 17.09625053], [82.35430908, 17.09625053], [82.35430908, 17.09653282], [82.35402679, 17.09653282], [82.35402679, 17.09680939], [82.35375214, 17.09680557], [82.35375214, 17.09708214], [82.35346222, 17.09708023], [82.35346222, 17.0976429], [82.35320282, 17.0976429], [82.35320282, 17.09791946], [82.3529129, 17.09791756], [82.3529129, 17.09819221], [82.35152435, 17.09819221], [82.35152435, 17.09791756], [82.35124969, 17.09791946], [82.35124969, 17.09736061], [82.35151672, 17.09736061], [82.35151672, 17.09708023], [82.3520813, 17.09708214], [82.3520813, 17.09680557], [82.35235596, 17.09680939], [82.35235596, 17.09653282], [82.35263824, 17.09653282], [82.35263824, 17.09625053], [82.3529129, 17.09625053], [82.3529129, 17.09569168], [82.35319519, 17.09569359], [82.35319519, 17.09374809], [82.3529129, 17.09374809], [82.3529129, 17.09320068], [82.35263824, 17.09320068], [82.35263824, 17.09263992], [82.35235596, 17.09263992], [82.35235596, 17.09235954], [82.3520813, 17.09236145], [82.3520813, 17.09208298], [82.35180664, 17.09208298], [82.35180664, 17.09152985], [82.35151672, 17.09152985], [82.35151672, 17.09124947], [82.35124969, 17.09124947], [82.35124969, 17.09069061], [82.35097504, 17.09069443], [82.35097504, 17.09013939], [82.35069275, 17.09013939], [82.35069275, 17.08986092], [82.3501358, 17.08986092], [82.3501358, 17.08958054], [82.34986115, 17.08958244], [82.34986115, 17.08930779], [82.34958649, 17.08930969], [82.34958649, 17.08903122], [82.34929657, 17.08903122], [82.34929657, 17.08875084], [82.34902954, 17.08875084], [82.34902954, 17.08847046], [82.34874725, 17.08847237], [82.34874725, 17.0881958], [82.34819794, 17.0881958], [82.34819794, 17.08791733], [82.34791565, 17.08791733], [82.34791565, 17.08763885], [82.34764099, 17.08764076], [82.34764099, 17.08736038], [82.3473587, 17.08736038], [82.3473587, 17.08708], [82.34708405, 17.08708572], [82.34708405, 17.08680344], [82.34680176, 17.08681107], [82.34680176, 17.08653069], [82.3465271, 17.08653069], [82.3465271, 17.08625031], [82.34625244, 17.08625031], [82.34625244, 17.08596992], [82.34597015, 17.08597374], [82.34597015, 17.08569336], [82.34541321, 17.08570099], [82.34541321, 17.08542061], [82.34513855, 17.08542061], [82.34513855, 17.08514023], [82.34485626, 17.08514023], [82.34485626, 17.08485031], [82.3445816, 17.08486366], [82.3445816, 17.08458138], [82.34430695, 17.08458138], [82.34430695, 17.08430481], [82.34402466, 17.08430481], [82.34402466, 17.08402824], [82.34375, 17.08403015], [82.34375, 17.08374977], [82.34347534, 17.08374977], [82.34347534, 17.0834713], [82.34319305, 17.0834713], [82.34319305, 17.08319473], [82.3429184, 17.08319473], [82.3429184, 17.08291626], [82.34263611, 17.08292007], [82.34263611, 17.08263969], [82.34236145, 17.08263969], [82.34236145, 17.08235931], [82.34208679, 17.08235931], [82.34208679, 17.08208084], [82.3418045, 17.08208275], [82.3418045, 17.08180618], [82.34152222, 17.0818119], [82.34152222, 17.08152962], [82.34124756, 17.08152962], [82.34124756, 17.08124924], [82.3409729, 17.08124924], [82.3409729, 17.08097076], [82.34069824, 17.08097267], [82.34069061, 17.0806942], [82.34041595, 17.0806942], [82.34041595, 17.08041763], [82.3401413, 17.08042145], [82.3401413, 17.08013916], [82.33985901, 17.08013916], [82.33985901, 17.07986069], [82.33957672, 17.07986069], [82.33957672, 17.07958031], [82.33930206, 17.07958412], [82.33930206, 17.07930565], [82.3390274, 17.07930756], [82.3390274, 17.07902908], [82.33875275, 17.07902908], [82.33875275, 17.07875061], [82.33847046, 17.07875061], [82.33847046, 17.07847214], [82.3381958, 17.07847214], [82.3381958, 17.07819366], [82.33791351, 17.07819366], [82.33791351, 17.0779171], [82.33763885, 17.07792091], [82.33763885, 17.07764053], [82.33735657, 17.07764053], [82.33735657, 17.07736015], [82.33708191, 17.07736206], [82.33708191, 17.07708359], [82.33652496, 17.07708359], [82.33652496, 17.07680511], [82.33625031, 17.07681084], [82.33625031, 17.07653046], [82.33598328, 17.07653046], [82.33598328, 17.07625008], [82.33569336, 17.07625008], [82.33569336, 17.0759697], [82.3354187, 17.0759716], [82.3354187, 17.07569695], [82.33513641, 17.07570076], [82.33513641, 17.07542038], [82.33486176, 17.07542038], [82.33486176, 17.07485962], [82.3345871, 17.07486153], [82.3345871, 17.07458305], [82.33430481, 17.07458305], [82.33430481, 17.07430649], [82.33403015, 17.0743103], [82.33403015, 17.07402992], [82.33374786, 17.07402992], [82.33374786, 17.07374954], [82.33319092, 17.07374954], [82.33319092, 17.07347107], [82.33291626, 17.07347488], [82.33291626, 17.0731926], [82.3326416, 17.0731926], [82.3326416, 17.07291412], [82.33235931, 17.07291412], [82.33235931, 17.07263947], [82.33180237, 17.07263947], [82.33180237, 17.0723629], [82.33152771, 17.0723629], [82.33152771, 17.07180977], [82.33125305, 17.07180977], [82.33125305, 17.07152939], [82.33097076, 17.07152939], [82.33097076, 17.07125282], [82.33069611, 17.07125282], [82.33069611, 17.07097054], [82.33041382, 17.07097435], [82.33041382, 17.07069206], [82.33013916, 17.07069206], [82.33013916, 17.0704174], [82.32985687, 17.07042122], [82.32985687, 17.07014275], [82.32958221, 17.07014275], [82.32958221, 17.06987], [82.32930756, 17.06987], [82.32930756, 17.06958008], [82.32902527, 17.06958389], [82.32902527, 17.06930542], [82.32875061, 17.06931114], [82.32875061, 17.06903267], [82.32847595, 17.06903267], [82.32847595, 17.06875038], [82.32818604, 17.06875038], [82.32818604, 17.06847191], [82.32791901, 17.06847191], [82.32791901, 17.06819534], [82.32763672, 17.06820107], [82.32763672, 17.06792259], [82.32736206, 17.06792259], [82.32736206, 17.0676384], [82.32707977, 17.0676384], [82.32707977, 17.06735992], [82.32680511, 17.06736183], [82.32680511, 17.06708336], [82.32653046, 17.06708336], [82.32653046, 17.06680489], [82.32624817, 17.06681061], [82.32624817, 17.06652832], [82.32596588, 17.06652832], [82.32596588, 17.06624985], [82.32569122, 17.06624985], [82.32569122, 17.06596947], [82.32541656, 17.06597137], [82.32541656, 17.06569481], [82.32514191, 17.06569481], [82.32514191, 17.06541634], [82.32485962, 17.06541824], [82.32485962, 17.06513977], [82.32457733, 17.06513977], [82.32457733, 17.06485939], [82.32430267, 17.0648613], [82.32430267, 17.06458282], [82.32402802, 17.06458282], [82.32402802, 17.06430626], [82.32375336, 17.06430817], [82.32375336, 17.06402969], [82.3234787, 17.06402969], [82.3234787, 17.06373978], [82.32319641, 17.06374931], [82.32319641, 17.06347275], [82.32291412, 17.06347275], [82.32291412, 17.06291771], [82.32263947, 17.06291962], [82.32263947, 17.06264114], [82.32235718, 17.06264114], [82.32235718, 17.06236076], [82.32208252, 17.06236076], [82.32208252, 17.06208038], [82.32180786, 17.0620842], [82.32180786, 17.06180763], [82.3215332, 17.06180954], [82.3215332, 17.06153107], [82.32125092, 17.06153107], [82.32125092, 17.06125069], [82.32096863, 17.06125069], [82.32096863, 17.06097031], [82.32069397, 17.06097221], [82.32069397, 17.06069565], [82.32041931, 17.06069565], [82.32041931, 17.06041718], [82.32013702, 17.06042099], [82.32013702, 17.06014061], [82.31986237, 17.06014061], [82.31986237, 17.05986023], [82.31958008, 17.05986023], [82.31958008, 17.05957985], [82.31930542, 17.05958557], [82.31930542, 17.05930328], [82.31903076, 17.05931091], [82.31903076, 17.05875015], [82.31874847, 17.05875015], [82.31874847, 17.05846977], [82.31847382, 17.05847168], [82.31847382, 17.05819321], [82.31819153, 17.05820084], [82.31819153, 17.05792999], [82.31791687, 17.05792999], [82.31791687, 17.05764008], [82.31764221, 17.05764008], [82.31764221, 17.0573597], [82.31735992, 17.05736351], [82.31735992, 17.05708122], [82.31708527, 17.05708122], [82.31708527, 17.05680466], [82.31680298, 17.05680466], [82.31680298, 17.05652809], [82.31652832, 17.05653191], [82.31652832, 17.05624962], [82.31624603, 17.05624962], [82.31624603, 17.05597115], [82.31597137, 17.05597115], [82.31597137, 17.05569458], [82.31569672, 17.05569458], [82.31569672, 17.05513954], [82.3154068, 17.05513954], [82.3154068, 17.05487061], [82.31513977, 17.05487061], [82.31513977, 17.05458069], [82.31485748, 17.0545826], [82.31485748, 17.05430603], [82.31458282, 17.05431175], [82.31458282, 17.05402946], [82.31430817, 17.05402946], [82.31430817, 17.05374908], [82.31402588, 17.05374908], [82.31402588, 17.05347061], [82.31375122, 17.05347252], [82.31375122, 17.05319405], [82.31346893, 17.05319405], [82.31346893, 17.05291748], [82.31318665, 17.0529213], [82.31318665, 17.05236053], [82.31291962, 17.05236053], [82.31291962, 17.05208015], [82.31263733, 17.05208397], [82.31263733, 17.0518055], [82.31236267, 17.0518055], [82.31236267, 17.05152893], [82.31208038, 17.05153084], [82.31208038, 17.05125046], [82.31180573, 17.05125046], [82.31180573, 17.05097198], [82.31153107, 17.05097198], [82.31153107, 17.05069542], [82.31124878, 17.0506897], [82.31124878, 17.05041885], [82.31096649, 17.05042076], [82.31096649, 17.05014038], [82.31069183, 17.05014038], [82.31069183, 17.04957962], [82.31041718, 17.04958344], [82.31041718, 17.04930687], [82.31014252, 17.04931068], [82.31014252, 17.0490303], [82.30986023, 17.0490303], [82.30986023, 17.04874039], [82.30958557, 17.04874992], [82.30958557, 17.04847145], [82.30930328, 17.04847145], [82.30930328, 17.04819679], [82.30902863, 17.04819679], [82.30902863, 17.04791641], [82.30874634, 17.04792023], [82.30874634, 17.04763985], [82.30847168, 17.04763985], [82.30847168, 17.04708099], [82.30819702, 17.04708481], [82.30819702, 17.04680634], [82.3079071, 17.04681015], [82.3079071, 17.04652977], [82.30764008, 17.04652977], [82.30764008, 17.04624939], [82.30735779, 17.04624939], [82.30735779, 17.04597092], [82.30708313, 17.04597473], [82.30708313, 17.04569244], [82.30680847, 17.04570007], [82.30680847, 17.04514122], [82.30652618, 17.04514122], [82.30652618, 17.04486084], [82.30625153, 17.04486084], [82.30625153, 17.04458046], [82.30596924, 17.04458237], [82.30596924, 17.0443058], [82.30568695, 17.04430962], [82.30568695, 17.04403114], [82.30541229, 17.04403114], [82.30541229, 17.04347038], [82.30513763, 17.04347038], [82.30513763, 17.04319382], [82.30486298, 17.04319382], [82.30486298, 17.04291725], [82.30458069, 17.0429306], [82.30458069, 17.04264259], [82.30430603, 17.04264259], [82.30430603, 17.04236031], [82.30403137, 17.04236031], [82.30403137, 17.04208183], [82.30374908, 17.04208374], [82.30374908, 17.0415287], [82.3034668, 17.04153252], [82.3034668, 17.04125023], [82.30319214, 17.04125023], [82.30319214, 17.04096985], [82.30291748, 17.04097176], [82.30291748, 17.04069519], [82.30264282, 17.04070091], [82.30264282, 17.04013824], [82.30236816, 17.04013824], [82.30236816, 17.03985977], [82.30208588, 17.03986168], [82.30208588, 17.03930473], [82.30180359, 17.03930473], [82.30180359, 17.03874969], [82.30152893, 17.03874969], [82.30152893, 17.03847122], [82.30124664, 17.03847313], [82.30124664, 17.03791618], [82.30097198, 17.03791809], [82.30097198, 17.03763962], [82.30069733, 17.03763962], [82.30069733, 17.03708076], [82.30041504, 17.03708267], [82.30041504, 17.03652763], [82.30014038, 17.03652954], [82.30014038, 17.03625107], [82.29985809, 17.03625107], [82.29985809, 17.03569031], [82.29958344, 17.03569412], [82.29958344, 17.03541756], [82.29930878, 17.03541946], [82.29930878, 17.03486061], [82.29902649, 17.03486061], [82.29902649, 17.03430939], [82.29875183, 17.03430939], [82.29875183, 17.03403091], [82.29846954, 17.03403091], [82.29846954, 17.03347015], [82.29819489, 17.03347206], [82.29819489, 17.0331955], [82.29792023, 17.0331955], [82.29792023, 17.03291702], [82.29763794, 17.03292084], [82.29763794, 17.03265953], [82.29763794, 17.03236389], [82.29736328, 17.03236389], [82.29736328, 17.03180313], [82.29708099, 17.03181076], [82.29708099, 17.03125], [82.29680634, 17.03125], [82.29680634, 17.03096962], [82.29652405, 17.03097153], [82.29652405, 17.03041649], [82.29624176, 17.0304203], [82.29624176, 17.02985954], [82.29597473, 17.02986145], [82.29597473, 17.02958107], [82.29569244, 17.02958107], [82.29569244, 17.02902794], [82.29541779, 17.02903175], [82.29541779, 17.02874947], [82.2951355, 17.02874947], [82.2951355, 17.02819443], [82.29486084, 17.02819443], [82.29486084, 17.02763939], [82.29458618, 17.02763939], [82.29458618, 17.02736092], [82.29429626, 17.02736092], [82.29429626, 17.0268116], [82.29402924, 17.0268116], [82.29402924, 17.02625084], [82.29374695, 17.02625084], [82.29374695, 17.02568817], [82.29347229, 17.02569389], [82.29347229, 17.02513885], [82.29319763, 17.02514076], [82.29319763, 17.02431107], [82.29292297, 17.02431107], [82.29292297, 17.02375031], [82.29264069, 17.02375031], [82.29264069, 17.02292061], [82.2923584, 17.02292061], [82.2923584, 17.02235985], [82.29208374, 17.02236176], [82.29208374, 17.02180672], [82.29180908, 17.02180672], [82.29180908, 17.0209713], [82.29152679, 17.0209713], [82.29152679, 17.02041435], [82.29125214, 17.02042007], [82.29125214, 17.01986122], [82.29096985, 17.01986122], [82.29096985, 17.01931], [82.29070282, 17.01931], [82.29070282, 17.01847076], [82.2904129, 17.01847458], [82.2904129, 17.01791763], [82.29013824, 17.01791954], [82.29013824, 17.01764107], [82.28985596, 17.01764107], [82.28985596, 17.01708031], [82.2895813, 17.01708221], [82.2895813, 17.01652718], [82.28930664, 17.0165329], [82.28930664, 17.01597023], [82.28902435, 17.01597023], [82.28902435, 17.0154171], [82.28874969, 17.01542282], [82.28874969, 17.01486015], [82.28847504, 17.01486015], [82.28847504, 17.01458359], [82.28819275, 17.01458359], [82.28819275, 17.01402855], [82.28791809, 17.01402855], [82.28791809, 17.01374817], [82.2876358, 17.01374817], [82.2876358, 17.0134697], [82.28736115, 17.0134716], [82.28736115, 17.01263809], [82.28708649, 17.01263809], [82.28708649, 17.01208305], [82.2868042, 17.01208305], [82.2868042, 17.01152992], [82.28652954, 17.01152992], [82.28652954, 17.01097107], [82.28624725, 17.01097298], [82.28624725, 17.01041794], [82.2859726, 17.01041985], [82.2859726, 17.00986099], [82.28569794, 17.00986099], [82.28569794, 17.00902939], [82.28542328, 17.00902939], [82.28542328, 17.00819016], [82.28514099, 17.00819588], [82.28514099, 17.00736046], [82.2848587, 17.00736046], [82.2848587, 17.00653076], [82.28457642, 17.00653076], [82.28457642, 17.00570107], [82.28430176, 17.00570107], [82.28430176, 17.00457954], [82.2840271, 17.00458145], [82.2840271, 17.00374985], [82.28375244, 17.00374985], [82.28375244, 17.00292015], [82.28347015, 17.00292015], [82.28347015, 17.00235939], [82.2831955, 17.00235939], [82.2831955, 17.00124931], [82.28291321, 17.00124931], [82.28291321, 17.00042152], [82.28263855, 17.00042152], [82.28263855, 17.00013924], [82.28235626, 17.00013924], [82.28235626, 16.99986076], [82.28235626, 16.99958038], [82.2820816, 16.9995842], [82.2820816, 16.99930573], [82.28180695, 16.99930763], [82.28180695, 16.99902916], [82.28151703, 16.99902916], [82.28151703, 16.99875069], [82.28124237, 16.99875069], [82.28124237, 16.99847031], [82.28097534, 16.99847221], [82.28097534, 16.99819374], [82.28069305, 16.99819374], [82.28069305, 16.99791718], [82.2804184, 16.99791908], [82.2804184, 16.99764824], [82.28013611, 16.99764824], [82.28013611, 16.99736023], [82.27986145, 16.99736023], [82.27986145, 16.99625015], [82.27958679, 16.99625015], [82.27958679, 16.99514008], [82.27929688, 16.99514008], [82.27929688, 16.99459076], [82.27902985, 16.99459076], [82.27902985, 16.99403], [82.27874756, 16.99403], [82.27874756, 16.99319077], [82.2784729, 16.99319267], [82.2784729, 16.9920845], [82.27819824, 16.9920845], [82.27819824, 16.99093056], [82.27819824, 16.99041748], [82.2784729, 16.99041939], [82.2784729, 16.98931122], [82.27874756, 16.98931122], [82.27874756, 16.98903275], [82.27929688, 16.98903275], [82.27929688, 16.9881916], [82.27958679, 16.98819351], [82.27958679, 16.98791695], [82.27986145, 16.98792267], [82.27986145, 16.98707962], [82.28013611, 16.98708344], [82.28013611, 16.9865284], [82.2804184, 16.9865284], [82.2804184, 16.98624992], [82.28098297, 16.98624992], [82.28097534, 16.98597145], [82.28125, 16.98597145], [82.28125, 16.98513985], [82.28151703, 16.98513985], [82.28151703, 16.98485947], [82.28263855, 16.98486137], [82.28263855, 16.9845829], [82.28347015, 16.9845829], [82.28347015, 16.98430634], [82.28430176, 16.98430634], [82.28430939, 16.9845829], [82.28514099, 16.9845829], [82.28514099, 16.98430634], [82.28542328, 16.98430824], [82.28542328, 16.98402977], [82.28569794, 16.98402977], [82.28569794, 16.98319054], [82.28541565, 16.98319435], [82.28541565, 16.98291779], [82.28514099, 16.98291969], [82.28514099, 16.98265076], [82.28457642, 16.98265076], [82.28457642, 16.98236084], [82.28375244, 16.98236084], [82.28375244, 16.98265076], [82.28291321, 16.98265076], [82.28291321, 16.98291969], [82.28151703, 16.98291969], [82.28151703, 16.98265076], [82.28124237, 16.98265076], [82.28124237, 16.98291969], [82.28069305, 16.98291779], [82.28069305, 16.98347282], [82.27958679, 16.98347092], [82.27958679, 16.98374939], [82.27819824, 16.98374939], [82.27819824, 16.98347092], [82.2776413, 16.98347282], [82.2776413, 16.98319435], [82.27735901, 16.98319435], [82.27735901, 16.98291779], [82.27707672, 16.98291969], [82.27707672, 16.98265076], [82.27680206, 16.98265076], [82.27680206, 16.98236084], [82.2765274, 16.98236084], [82.2765274, 16.98180962], [82.27625275, 16.98180962], [82.27625275, 16.98069], [82.27597046, 16.98069572], [82.27597046, 16.97958565], [82.2756958, 16.97958565], [82.2756958, 16.9770813], [82.27597046, 16.9770813], [82.27597046, 16.97680473], [82.27708435, 16.97680473], [82.27708435, 16.97652817], [82.27958679, 16.97652817], [82.27958679, 16.97680473], [82.28013611, 16.97680473], [82.28013611, 16.9770813], [82.28069305, 16.9770813], [82.28069305, 16.97736359], [82.28263855, 16.97736359], [82.28263855, 16.9770813], [82.28375244, 16.9770813], [82.28375244, 16.97680473], [82.2840271, 16.97680473], [82.2840271, 16.97652817], [82.28375244, 16.97652817], [82.28375244, 16.97569466], [82.2840271, 16.97569466], [82.2840271, 16.97402763], [82.28375244, 16.97403145], [82.28375244, 16.97346115], [82.2831955, 16.9734726], [82.2831955, 16.97319412], [82.28347015, 16.97319412], [82.28347015, 16.97263718], [82.28375244, 16.97263908], [82.28375244, 16.97153091], [82.28347015, 16.97153091], [82.28347015, 16.97125053], [82.2831955, 16.97125053], [82.2831955, 16.97097206], [82.27986145, 16.97097015], [82.27986145, 16.97125053], [82.27819824, 16.97125053], [82.27819824, 16.97097015], [82.27680206, 16.97097015], [82.27680206, 16.97125053], [82.27540588, 16.97125053], [82.27540588, 16.97068977], [82.27513885, 16.97069359], [82.27513885, 16.97041893], [82.27485657, 16.97042084], [82.27485657, 16.97014046], [82.27458191, 16.97014046], [82.27458191, 16.9695797], [82.27430725, 16.96958351], [82.27430725, 16.96930695], [82.27401733, 16.96931076], [82.27401733, 16.96903038], [82.27375031, 16.96903038], [82.27375031, 16.96846962], [82.27347565, 16.96847153], [82.27347565, 16.96791649], [82.27319336, 16.9679203], [82.27319336, 16.96735954], [82.2729187, 16.96736145], [82.2729187, 16.96680641], [82.27263641, 16.96681023], [82.27263641, 16.96624947], [82.27236176, 16.96624947], [82.27236176, 16.96458054], [82.2720871, 16.96458244], [82.2720871, 16.96375275], [82.27179718, 16.96375275], [82.27179718, 16.96292114], [82.27153015, 16.96292114], [82.27153015, 16.96236038], [82.27124786, 16.96236038], [82.27124786, 16.96208191], [82.27097321, 16.96208382], [82.27097321, 16.96180534], [82.27069092, 16.96181107], [82.27069092, 16.96125031], [82.27041626, 16.96125031], [82.27041626, 16.96013832], [82.2701416, 16.96013832], [82.2701416, 16.95902824], [82.26985931, 16.95902824], [82.26985931, 16.95652962], [82.26957703, 16.95652962], [82.26957703, 16.95597076], [82.26930237, 16.95597267], [82.26930237, 16.95430565], [82.26957703, 16.95430946], [82.26957703, 16.95318985], [82.26930237, 16.95319557], [82.26930237, 16.95180321], [82.26902771, 16.95181084], [82.26902771, 16.9509697], [82.26930237, 16.9509716], [82.26930237, 16.95069313], [82.26957703, 16.95070076], [82.26957703, 16.95014191], [82.26985931, 16.95014191], [82.26985931, 16.94958115], [82.2701416, 16.94958115], [82.2701416, 16.94930649], [82.27041626, 16.94928932], [82.27041626, 16.94902802], [82.27069092, 16.94903183], [82.27069092, 16.94874954], [82.27097321, 16.94874954], [82.27097321, 16.94846916], [82.27347565, 16.94847107], [82.27347565, 16.94791603], [82.27375031, 16.94792175], [82.27375031, 16.94763947], [82.27319336, 16.94763947], [82.27319336, 16.94735909], [82.2729187, 16.94735909], [82.2729187, 16.94708061], [82.27263641, 16.94708252], [82.27263641, 16.94680595], [82.27236176, 16.94681168], [82.27236176, 16.94568825], [82.2720871, 16.94569397], [82.2720871, 16.94486046], [82.27179718, 16.94486046], [82.27179718, 16.94403076], [82.27153015, 16.94403076], [82.27153015, 16.94153023], [82.27179718, 16.94153023], [82.27179718, 16.94096947], [82.27153015, 16.94097137], [82.27153015, 16.94041634], [82.27069092, 16.94041634], [82.27069092, 16.94069672], [82.26958466, 16.94069672], [82.26958466, 16.94041634], [82.26930237, 16.94041634], [82.26930237, 16.94013977], [82.26902771, 16.94013977], [82.26902771, 16.93985939], [82.26875305, 16.9398613], [82.26875305, 16.93958473], [82.26847076, 16.93958473], [82.26847076, 16.93930626], [82.26819611, 16.93931007], [82.26819611, 16.93902969], [82.26374817, 16.93902969], [82.26374817, 16.93875122], [82.26346588, 16.93875122], [82.26346588, 16.93847084], [82.26319122, 16.93847466], [82.26319122, 16.93819237], [82.26291656, 16.93819237], [82.26291656, 16.9379158], [82.26264191, 16.93791962], [82.26264191, 16.9378109], [82.26264191, 16.93763924], [82.26207733, 16.93764114], [82.26207733, 16.93734932], [82.26180267, 16.93736076], [82.26180267, 16.93708229], [82.26125336, 16.93708229], [82.26125336, 16.93680573], [82.2590332, 16.93680954], [82.2590332, 16.93653107], [82.25875092, 16.93653107], [82.25875092, 16.93680954], [82.25485992, 16.93680954], [82.25485992, 16.93653107], [82.25402832, 16.93653107], [82.25402832, 16.93625259], [82.25347137, 16.93625259], [82.25347137, 16.93597031], [82.25291443, 16.93597031], [82.25291443, 16.93569374], [82.25235748, 16.93569374], [82.25235748, 16.93541718], [82.25180817, 16.9354229], [82.25180817, 16.93514252], [82.25152588, 16.93514252], [82.25152588, 16.93486023], [82.25096893, 16.93486023], [82.25096893, 16.93458176], [82.25069427, 16.93458366], [82.25069427, 16.93402863], [82.25041962, 16.93402863], [82.25041962, 16.93320084], [82.25013733, 16.93320084], [82.25013733, 16.93208122], [82.24986267, 16.93208313], [82.24986267, 16.93097305], [82.24958038, 16.93097305], [82.24958038, 16.93041611], [82.24903107, 16.93041992], [82.24903107, 16.92958069], [82.24930573, 16.9295826], [82.24930573, 16.92902756], [82.24903107, 16.92902946], [82.24903107, 16.92847061], [82.24930573, 16.92847252], [82.24930573, 16.92791748], [82.24958038, 16.92791939], [82.24958038, 16.92736053], [82.24930573, 16.92736053], [82.24930573, 16.92430305], [82.24958038, 16.92431068], [82.24958038, 16.92346954], [82.24930573, 16.92347145], [82.24930573, 16.92319489], [82.24958038, 16.92319489], [82.24958038, 16.92263794], [82.24986267, 16.92264175], [82.24986267, 16.92226982], [82.24986267, 16.9220829], [82.25013733, 16.9220829], [82.25013733, 16.91875076], [82.24986267, 16.91875076], [82.24986267, 16.91764069], [82.24958038, 16.91764069], [82.24958038, 16.91542053], [82.24986267, 16.91542053], [82.24986267, 16.91485977], [82.25013733, 16.91486168], [82.25013733, 16.91430664], [82.25041962, 16.91430664], [82.25041962, 16.91374969], [82.25068665, 16.91374969], [82.25068665, 16.90930939], [82.25041962, 16.90930939], [82.25041962, 16.90903282], [82.25013733, 16.90903282], [82.25013733, 16.90875244], [82.24986267, 16.90875244], [82.24986267, 16.90819168], [82.24958038, 16.90819359], [82.24958038, 16.90763855], [82.24931335, 16.90764236], [82.24931335, 16.90736961], [82.25013733, 16.90736961], [82.25013733, 16.9070797], [82.25041962, 16.90708351], [82.25041962, 16.90652847], [82.25068665, 16.90652847], [82.25068665, 16.90596962], [82.25096893, 16.90597153], [82.25096893, 16.90569496], [82.25152588, 16.90570068], [82.25152588, 16.9054184], [82.25208282, 16.9054184], [82.25208282, 16.90513992], [82.25263977, 16.90513992], [82.25263977, 16.90485954], [82.25319672, 16.90486145], [82.25319672, 16.90458298], [82.25347137, 16.90458298], [82.25347137, 16.90430641], [82.25375366, 16.90430641], [82.25375366, 16.90402794], [82.25402832, 16.90402985], [82.25402832, 16.90374947], [82.25430298, 16.90374947], [82.25430298, 16.90347099], [82.25458527, 16.9034729], [82.25458527, 16.90319443], [82.25485992, 16.90319443], [82.25485992, 16.90236092], [82.25514221, 16.90236092], [82.25514221, 16.90153122], [82.25541687, 16.90153122], [82.25541687, 16.90069008], [82.25569153, 16.9006958], [82.25569153, 16.90013885], [82.25596619, 16.90014076], [82.25596619, 16.89875031], [82.25624847, 16.89875031], [82.25624847, 16.89792061], [82.25653076, 16.89792061], [82.25653076, 16.89707947], [82.25680542, 16.89708138], [82.25680542, 16.89624977], [82.25708008, 16.89624977], [82.25707245, 16.8951416], [82.25736237, 16.8951416], [82.25736237, 16.89263916], [82.25763702, 16.89263916], [82.25763702, 16.89236069], [82.25736237, 16.89236069], [82.25736237, 16.89180756], [82.25707245, 16.89180756], [82.25707245, 16.89125061], [82.25680542, 16.89125061], [82.25680542, 16.88902855], [82.25707245, 16.88903046], [82.25707245, 16.88820076], [82.25681305, 16.88820076], [82.25681305, 16.88764], [82.25653076, 16.88764], [82.25653076, 16.88735962], [82.25624847, 16.88736153], [82.25624847, 16.88652802], [82.25680542, 16.88652802], [82.25681305, 16.88680077], [82.25736237, 16.88680649], [82.25736237, 16.88708305], [82.25763702, 16.88708305], [82.25763702, 16.88736153], [82.25791931, 16.88735962], [82.25791931, 16.88764], [82.25818634, 16.88764], [82.25818634, 16.88792038], [82.25846863, 16.88792038], [82.25846863, 16.88820076], [82.25958252, 16.88819695], [82.25958252, 16.8884716], [82.26013947, 16.8884716], [82.26013947, 16.88819695], [82.26040649, 16.88820076], [82.26040649, 16.88764], [82.26069641, 16.88764], [82.26069641, 16.88735962], [82.26097107, 16.88736153], [82.26097107, 16.88708305], [82.26152802, 16.88708305], [82.26152802, 16.88680649], [82.26207733, 16.88680077], [82.26208496, 16.88652802], [82.26291656, 16.88652992], [82.26291656, 16.88626099], [82.26346588, 16.88626099], [82.26346588, 16.88597107], [82.26403046, 16.88597488], [82.26403046, 16.8856926], [82.26486206, 16.8856926], [82.26486206, 16.88541412], [82.26541901, 16.88541985], [82.26541901, 16.88513947], [82.26568604, 16.88513947], [82.26568604, 16.8848629], [82.26597595, 16.8848629], [82.26597595, 16.88458061], [82.26625061, 16.88458443], [82.26625061, 16.88430405], [82.2665329, 16.88430977], [82.2665329, 16.88375282], [82.26680756, 16.88375282], [82.26680756, 16.88347054], [82.26708221, 16.88347054], [82.26708221, 16.88319206], [82.26735687, 16.88319969], [82.26735687, 16.88264275], [82.26763916, 16.88264275], [82.26763916, 16.88236046], [82.26790619, 16.88236046], [82.26790619, 16.88208008], [82.26819611, 16.88208389], [82.26819611, 16.88152695], [82.26847076, 16.88153267], [82.26847076, 16.88097191], [82.26875305, 16.88097191], [82.26875305, 16.88041687], [82.26902771, 16.88042068], [82.26902771, 16.87985992], [82.26930237, 16.87986183], [82.26930237, 16.87902832], [82.26957703, 16.87902832], [82.26957703, 16.87791824], [82.26985931, 16.87791824], [82.26985931, 16.87569046], [82.27069092, 16.87569427], [82.27069092, 16.87541771], [82.27236176, 16.87541771], [82.27236176, 16.87569427], [82.27263641, 16.87569427], [82.27263641, 16.87541771], [82.27375031, 16.87541771], [82.27375031, 16.87569427], [82.27430725, 16.87569427], [82.27430725, 16.87597275], [82.27513885, 16.87597084], [82.27513885, 16.87625122], [82.2756958, 16.87625122], [82.2756958, 16.87652969], [82.27625275, 16.87652969], [82.27625275, 16.87680817], [82.27680206, 16.87680626], [82.27680206, 16.87708282], [82.2776413, 16.87708282], [82.2776413, 16.8773613], [82.27819824, 16.87735939], [82.27819824, 16.87763977], [82.28180695, 16.87763977], [82.28180695, 16.87735939], [82.2820816, 16.8773613], [82.2820816, 16.87680626], [82.28235626, 16.87680817], [82.28235626, 16.87652969], [82.28263855, 16.87652969], [82.28263855, 16.87625122], [82.28291321, 16.87625122], [82.28291321, 16.87597084], [82.2831955, 16.87597275], [82.2831955, 16.87569427], [82.28347015, 16.87569427], [82.28347015, 16.87541771], [82.28375244, 16.87541962], [82.28375244, 16.87514114], [82.2840271, 16.87514114], [82.2840271, 16.87486076], [82.28430176, 16.87486076], [82.28430176, 16.87458038], [82.2848587, 16.8745842], [82.2848587, 16.87402725], [82.28514099, 16.87403107], [82.28514099, 16.87347031], [82.28541565, 16.87347221], [82.28541565, 16.87208557], [82.28514099, 16.87208557], [82.28514099, 16.87152863], [82.2848587, 16.87153053], [82.2848587, 16.86903191], [82.28457642, 16.86903191], [82.28457642, 16.86846924], [82.28430176, 16.86847115], [82.28430176, 16.86791611], [82.2840271, 16.86792183], [82.2840271, 16.86735916], [82.28375244, 16.86735916], [82.28375244, 16.86708069], [82.28347015, 16.8670826], [82.28347015, 16.86680603], [82.28320313, 16.86681175], [82.28320313, 16.86624908], [82.28291321, 16.86624908], [82.28291321, 16.86597061], [82.28263855, 16.86597252], [82.28263855, 16.86541748], [82.28235626, 16.86541748], [82.28235626, 16.86512947], [82.28320313, 16.86512947], [82.28320313, 16.86541748], [82.28347015, 16.86541748], [82.28347015, 16.86569405], [82.28375244, 16.86569023], [82.28375244, 16.86624908], [82.2840271, 16.86624908], [82.2840271, 16.86653137], [82.28430176, 16.86653137], [82.28430176, 16.86681175], [82.28457642, 16.86681175], [82.28457642, 16.86735916], [82.2848587, 16.86735916], [82.2848587, 16.86792183], [82.28514099, 16.86791611], [82.28514099, 16.86847115], [82.28541565, 16.86847115], [82.28541565, 16.86930466], [82.28569794, 16.86930466], [82.28569794, 16.86986351], [82.2859726, 16.8698597], [82.2859726, 16.87042046], [82.28624725, 16.87041664], [82.28624725, 16.87097359], [82.28652954, 16.87096977], [82.28652954, 16.87153053], [82.28679657, 16.87153053], [82.28679657, 16.87264061], [82.28652954, 16.87264061], [82.28652954, 16.87403107], [82.28624725, 16.87403107], [82.28624725, 16.87486076], [82.2859726, 16.87486076], [82.2859726, 16.87514114], [82.28569794, 16.87514114], [82.28569794, 16.87680817], [82.28624725, 16.87680626], [82.28624725, 16.87708282], [82.28652954, 16.87708282], [82.28652954, 16.87680626], [82.28679657, 16.87680817], [82.28679657, 16.87597084], [82.28708649, 16.87597275], [82.28708649, 16.87569427], [82.2876358, 16.87569427], [82.2876358, 16.87541771], [82.28848267, 16.87541962], [82.28848267, 16.87375069], [82.28874969, 16.87375069], [82.28874969, 16.87264061], [82.28901672, 16.87264061], [82.28901672, 16.87236023], [82.2895813, 16.87236023], [82.2895813, 16.87207985], [82.28986359, 16.87208557], [82.28986359, 16.87180328], [82.2904129, 16.87181091], [82.2904129, 16.87153053], [82.29152679, 16.87153053], [82.29152679, 16.87125969], [82.29180908, 16.87125969], [82.29180908, 16.87096977], [82.29208374, 16.87097359], [82.29208374, 16.87069321], [82.2923584, 16.87070084], [82.2923584, 16.87042046], [82.29264069, 16.87042046], [82.29264069, 16.87014008], [82.29292297, 16.87014008], [82.29292297, 16.8698597], [82.29319763, 16.86986351], [82.29319763, 16.86958122], [82.29374695, 16.86958122], [82.29374695, 16.86930466], [82.29402924, 16.86930466], [82.29402924, 16.86902809], [82.29569244, 16.86903191], [82.29569244, 16.86874962], [82.2959671, 16.86874962], [82.2959671, 16.86846924], [82.29624939, 16.86847115], [82.29624939, 16.86819458], [82.29680634, 16.8682003], [82.29680634, 16.86792183], [82.29708099, 16.86792183], [82.29708099, 16.86763954], [82.29736328, 16.86763954], [82.29736328, 16.86735916], [82.29792023, 16.86735916], [82.29792023, 16.86708069], [82.29819489, 16.8670826], [82.29819489, 16.86680603], [82.29875183, 16.86681175], [82.29875183, 16.86653137], [82.29957581, 16.86653137], [82.29957581, 16.86624908], [82.29985809, 16.86624908], [82.29985809, 16.86569023], [82.30014038, 16.86569405], [82.30014038, 16.86541748], [82.30097198, 16.86541748], [82.30097198, 16.86512947], [82.30124664, 16.8651371], [82.30124664, 16.86486053], [82.30152893, 16.86486053], [82.30152893, 16.86458015], [82.30180359, 16.86458397], [82.30180359, 16.8643055], [82.30264282, 16.86431122], [82.30264282, 16.86375046], [82.30291748, 16.86375046], [82.30291748, 16.86347008], [82.30319214, 16.86347198], [82.30319214, 16.86319351], [82.30374908, 16.86319351], [82.30374908, 16.86291885], [82.30403137, 16.86292076], [82.30403137, 16.86264038], [82.30430603, 16.86264038], [82.30430603, 16.86236], [82.30458069, 16.86236191], [82.30458069, 16.86180687], [82.30486298, 16.86181068], [82.30486298, 16.8615303], [82.30513763, 16.8615303], [82.30513763, 16.86096954], [82.30541992, 16.86097145], [82.30541992, 16.86069679], [82.30596924, 16.86069679], [82.30596924, 16.86041641], [82.30652618, 16.86042023], [82.30652618, 16.86013985], [82.30680847, 16.86013985], [82.30680847, 16.85958099], [82.30708313, 16.85958481], [82.30708313, 16.85930634], [82.30735779, 16.85931969], [82.30735779, 16.85902977], [82.30764008, 16.85902977], [82.30764008, 16.85847092], [82.30791473, 16.85847473], [82.30791473, 16.85819244], [82.30819702, 16.85819244], [82.30819702, 16.85791588], [82.30847168, 16.85791969], [82.30847168, 16.85764122], [82.30902863, 16.85764122], [82.30902863, 16.85736275], [82.30930328, 16.85736275], [82.30930328, 16.85708046], [82.30958557, 16.85708237], [82.30958557, 16.8568058], [82.30986023, 16.85680962], [82.30986023, 16.85653114], [82.31014252, 16.85653114], [82.31014252, 16.85597038], [82.31041718, 16.85597038], [82.31041718, 16.85569382], [82.31069183, 16.85569382], [82.31069183, 16.85541725], [82.31096649, 16.85542107], [82.31096649, 16.85514259], [82.31124878, 16.85514259], [82.31124878, 16.85486031], [82.3115387, 16.85486031], [82.31153107, 16.85430527], [82.31181335, 16.8543129], [82.31181335, 16.85403252], [82.31208038, 16.85403252], [82.31208038, 16.85346985], [82.31236267, 16.85347176], [82.31236267, 16.85291672], [82.31263733, 16.85292053], [82.31263733, 16.85235977], [82.31291962, 16.85236168], [82.31291962, 16.85180473], [82.31319427, 16.85180473], [82.31319427, 16.85097313], [82.31346893, 16.85097313], [82.31346893, 16.84986115], [82.31375122, 16.84986115], [82.31375122, 16.84902954], [82.31402588, 16.84902954], [82.31402588, 16.84791946], [82.31430817, 16.84791946], [82.31430817, 16.84680939], [82.31458282, 16.84680939], [82.31458282, 16.8445797], [82.31430817, 16.8445816], [82.31430817, 16.84347153], [82.31402588, 16.84347153], [82.31402588, 16.84291649], [82.31375122, 16.8429203], [82.31375122, 16.84264183], [82.31346893, 16.84264183], [82.31346893, 16.84235954], [82.31319427, 16.84236336], [82.31319427, 16.84180641], [82.31291962, 16.84181023], [82.31291962, 16.84153175], [82.31263733, 16.84153175], [82.31263733, 16.84124947], [82.31236267, 16.84124947], [82.31236267, 16.84095955], [82.31208038, 16.8409729], [82.31208038, 16.84069443], [82.31180573, 16.84069443], [82.31180573, 16.84013939], [82.31263733, 16.84013939], [82.31263733, 16.84042168], [82.31291962, 16.84041595], [82.31291962, 16.84069443], [82.31346893, 16.84069443], [82.31346893, 16.8409729], [82.31375122, 16.84095955], [82.31375122, 16.84124947], [82.31402588, 16.84124947], [82.31402588, 16.84181023], [82.31430817, 16.84180641], [82.31430817, 16.84208107], [82.31458282, 16.84208107], [82.31458282, 16.84236336], [82.31485748, 16.84235954], [82.31485748, 16.84264183], [82.31513977, 16.84264183], [82.31513977, 16.8429203], [82.31541443, 16.84291649], [82.31541443, 16.84347153], [82.31569672, 16.84346962], [82.31569672, 16.84375191], [82.31597137, 16.84375191], [82.31597137, 16.84403038], [82.31624603, 16.84403038], [82.31624603, 16.84431076], [82.31680298, 16.84430313], [82.31680298, 16.8456955], [82.31708527, 16.8456955], [82.31708527, 16.84625053], [82.31735229, 16.84625053], [82.31735229, 16.84708977], [82.31764221, 16.84708595], [82.31764221, 16.84819412], [82.31791687, 16.84819412], [82.31791687, 16.84958267], [82.31819153, 16.84958267], [82.31819153, 16.85013962], [82.31846619, 16.85013008], [82.31846619, 16.85041809], [82.31874847, 16.85041618], [82.31874847, 16.85069466], [82.31903076, 16.85069084], [82.31903076, 16.85124969], [82.31931305, 16.85124969], [82.31931305, 16.85152817], [82.31958008, 16.85152817], [82.31958008, 16.85180473], [82.31986237, 16.85180473], [82.31986237, 16.85208321], [82.32013702, 16.85208321], [82.32013702, 16.85236168], [82.32041168, 16.85235977], [82.32041168, 16.85263824], [82.32096863, 16.85263824], [82.32096863, 16.85292053], [82.32125092, 16.85291672], [82.32125092, 16.85319519], [82.32152557, 16.85319519], [82.32152557, 16.85347176], [82.32180786, 16.85346985], [82.32180786, 16.85374832], [82.32208252, 16.85374832], [82.32208252, 16.85403252], [82.32319641, 16.85403252], [82.32319641, 16.8543129], [82.32402802, 16.85430527], [82.32402802, 16.85458374], [82.32514191, 16.85458183], [82.32514191, 16.85486031], [82.32541656, 16.85486031], [82.32541656, 16.85514259], [82.32569122, 16.85514259], [82.32569122, 16.85542107], [82.33152771, 16.85541725], [82.33152771, 16.85569382], [82.33208466, 16.85569382], [82.33208466, 16.85597038], [82.33235168, 16.85597038], [82.33235168, 16.8562603], [82.33403015, 16.8562603], [82.33403015, 16.85653114], [82.3345871, 16.85653114], [82.3345871, 16.85680962], [82.33598328, 16.85680962], [82.33598328, 16.85653114], [82.33763885, 16.85653114], [82.33763885, 16.8562603], [82.3381958, 16.8562603], [82.3381958, 16.85597038], [82.33875275, 16.85597038], [82.33875275, 16.85569382], [82.33930206, 16.85569382], [82.33930206, 16.85541725], [82.33957672, 16.85542107], [82.33957672, 16.85514259], [82.33985901, 16.85514259], [82.33985901, 16.85486031], [82.3401413, 16.85486031], [82.3401413, 16.85458183], [82.3409729, 16.85458374], [82.3409729, 16.85430527], [82.34179688, 16.8543129], [82.34179688, 16.85403252], [82.34236145, 16.85403252], [82.34236145, 16.85374832], [82.3429184, 16.85374832], [82.3429184, 16.85346985], [82.34375, 16.85347176], [82.34375, 16.85319519], [82.34513855, 16.85319519], [82.34513855, 16.85291672], [82.34570313, 16.85292053], [82.34570313, 16.85263824], [82.34625244, 16.85263824], [82.34625244, 16.85235977], [82.34680176, 16.85236168], [82.34680176, 16.85208321], [82.3473587, 16.85208321], [82.3473587, 16.85180473], [82.34791565, 16.85180473], [82.34791565, 16.85152817], [82.3484726, 16.85152817], [82.3484726, 16.85124969], [82.34874725, 16.85124969], [82.34874725, 16.85097122], [82.34958649, 16.85097122], [82.34958649, 16.85124969], [82.3501358, 16.85124969], [82.3501358, 16.85152817], [82.35069275, 16.85152817], [82.35069275, 16.85180473], [82.35236359, 16.85180473], [82.35236359, 16.85152817], [82.35430908, 16.85152817], [82.35430908, 16.85180473], [82.3548584, 16.85180473], [82.3548584, 16.85208321], [82.35514069, 16.85207939], [82.35514069, 16.85263824], [82.35541534, 16.85263824], [82.35541534, 16.85319519], [82.35569763, 16.85318756], [82.35569763, 16.85374832], [82.35597229, 16.85374832], [82.35597229, 16.85458374], [82.35569763, 16.85458183], [82.35569763, 16.85486031], [82.35542297, 16.85486031], [82.35542297, 16.85542107], [82.35514069, 16.85541725], [82.35514069, 16.85569382], [82.3548584, 16.85569191], [82.3548584, 16.8562603], [82.35514069, 16.8562603], [82.35514069, 16.85736275], [82.35541534, 16.85736275], [82.35541534, 16.85847473], [82.35569763, 16.85847092], [82.35569763, 16.85902977], [82.35597229, 16.85902786], [82.35597229, 16.85986137], [82.35624695, 16.85985947], [82.35624695, 16.86042023], [82.35597229, 16.86042023], [82.35597229, 16.86124992], [82.35569763, 16.86124992], [82.35569763, 16.86375046], [82.35541534, 16.86375046], [82.35541534, 16.86458397], [82.35514069, 16.86458397], [82.35514069, 16.86569405], [82.35542297, 16.86569023], [82.35542297, 16.86653137], [82.35597229, 16.86653137], [82.35597229, 16.86874962], [82.35624695, 16.86874962], [82.35624695, 16.86903191], [82.35652924, 16.86902809], [82.35652924, 16.86958122], [82.35679626, 16.86958122], [82.35679626, 16.87153053], [82.35708618, 16.87152863], [82.35708618, 16.87208557], [82.35736084, 16.87207985], [82.35736084, 16.87236023], [82.35753632, 16.87236023], [82.35764313, 16.87236023], [82.35764313, 16.87264061], [82.35791779, 16.87264061], [82.35791779, 16.87292099], [82.35819244, 16.87291718], [82.35819244, 16.87319565], [82.35847473, 16.87319565], [82.35847473, 16.87347221], [82.35874939, 16.87347031], [82.35874939, 16.87403107], [82.35901642, 16.87403107], [82.35901642, 16.87486076], [82.35874939, 16.87486076], [82.35874939, 16.87514114], [82.35847473, 16.87513924], [82.35847473, 16.87569427], [82.35819244, 16.87569046], [82.35819244, 16.87652969], [82.35847473, 16.87652779], [82.35847473, 16.8773613], [82.35874939, 16.87735939], [82.35874939, 16.87791824], [82.35902405, 16.87791634], [82.35902405, 16.87847137], [82.35930634, 16.87846947], [82.35930634, 16.87874985], [82.35986328, 16.87874985], [82.35986328, 16.87902832], [82.36013794, 16.87902832], [82.36013794, 16.87958336], [82.36042023, 16.87958336], [82.36042023, 16.87986183], [82.36068726, 16.87985992], [82.36068726, 16.88070107], [82.36096954, 16.88070107], [82.36096954, 16.88181114], [82.36125183, 16.88180542], [82.36125183, 16.88347054], [82.36152649, 16.88347054], [82.36152649, 16.88541985], [82.36125183, 16.88541985], [82.36125183, 16.88652992], [82.36152649, 16.88652802], [82.36152649, 16.88736153], [82.36180878, 16.88735962], [82.36180878, 16.88792038], [82.36208344, 16.88791656], [82.36208344, 16.8931942], [82.36180878, 16.89319038], [82.36180878, 16.89374924], [82.36152649, 16.89374924], [82.36152649, 16.89736366], [82.36180878, 16.89736366], [82.36180878, 16.90097237], [82.36208344, 16.90097237], [82.36208344, 16.90208244], [82.36235809, 16.90208054], [82.36235809, 16.90263939], [82.36208344, 16.90263939], [82.36208344, 16.90319443], [82.36235809, 16.90319443], [82.36235809, 16.90486145], [82.36264038, 16.90486145], [82.36264038, 16.90597153], [82.36292267, 16.90596962], [82.36295319, 16.90681076], [82.36319733, 16.90680504], [82.36319733, 16.90708351], [82.36293793, 16.9070797], [82.36292267, 16.90764236], [82.36319733, 16.90764236], [82.36319733, 16.90903282], [82.36347198, 16.90903282], [82.36347198, 16.9101429], [82.36319733, 16.91013908], [82.36319733, 16.9109745], [82.36291504, 16.9109745], [82.36291504, 16.91236115], [82.36264801, 16.91236115], [82.36264801, 16.91403008], [82.36235809, 16.91403008], [82.36235809, 16.91736031], [82.36207581, 16.91736031], [82.36207581, 16.92292023], [82.36180878, 16.92292023], [82.36180878, 16.92514038], [82.36152649, 16.92514038], [82.36152649, 16.92736053], [82.36125183, 16.92736053], [82.36125183, 16.92930984], [82.36096954, 16.92930984], [82.36096954, 16.93124962], [82.36069489, 16.93124962], [82.36069489, 16.93347168], [82.36042023, 16.93347168], [82.36042023, 16.93597031], [82.36013794, 16.93597031], [82.36013794, 16.93680954], [82.35986328, 16.93680573], [82.35986328, 16.93847466], [82.35958099, 16.93847466], [82.35958099, 16.94041634], [82.35930634, 16.94041061], [82.35930634, 16.94124985], [82.35901642, 16.94124985], [82.35901642, 16.94403076], [82.35930634, 16.94403076], [82.35930634, 16.94431114], [82.35874939, 16.94430542], [82.35874939, 16.94458389], [82.3584671, 16.94458008], [82.3584671, 16.94681168], [82.35819244, 16.94680595], [82.35819244, 16.94708252], [82.35791779, 16.94708061], [82.35791779, 16.9493103], [82.3576355, 16.94930649], [82.3576355, 16.9509716], [82.35736084, 16.9509697], [82.35736084, 16.95153046], [82.35708618, 16.95152855], [82.35708618, 16.95208549], [82.35680389, 16.95208549], [82.35680389, 16.95319557], [82.35652161, 16.95318985], [82.35652161, 16.95375061], [82.35624695, 16.95375061], [82.35624695, 16.95430946], [82.35597229, 16.95430946], [82.35597229, 16.95486069], [82.35569763, 16.95486069], [82.35569763, 16.95514107], [82.35541534, 16.95513916], [82.35541534, 16.9556942], [82.35514069, 16.95569038], [82.35514069, 16.95625114], [82.3548584, 16.95625114], [82.3548584, 16.95652962], [82.35402679, 16.95652962], [82.35402679, 16.95680809], [82.35375214, 16.95680618], [82.35375214, 16.95708275], [82.35346222, 16.95708084], [82.35346985, 16.95736122], [82.35320282, 16.95736122], [82.35320282, 16.95791817], [82.3529129, 16.95791626], [82.3529129, 16.95819473], [82.35263824, 16.95819092], [82.35263824, 16.95848083], [82.35235596, 16.95848083], [82.35235596, 16.95874977], [82.35180664, 16.95874977], [82.35180664, 16.95902824], [82.35152435, 16.95902824], [82.35152435, 16.95930481], [82.35097504, 16.95930481], [82.35097504, 16.95958328], [82.35069275, 16.95958328], [82.35069275, 16.95986176], [82.3501358, 16.95985985], [82.3501358, 16.96013832], [82.34986115, 16.96013832], [82.34986115, 16.96042061], [82.34958649, 16.96041679], [82.34958649, 16.96097183], [82.34929657, 16.96097183], [82.34929657, 16.96125031], [82.34902954, 16.96125031], [82.34902954, 16.96152687], [82.3484726, 16.96151924], [82.3484726, 16.96181107], [82.3465271, 16.96180534], [82.3465271, 16.96208382], [82.34625244, 16.96208191], [82.34625244, 16.96236038], [82.34597015, 16.96236038], [82.34597015, 16.96264267], [82.34541321, 16.96264267], [82.34541321, 16.96292114], [82.34513855, 16.96291733], [82.34513855, 16.96319389], [82.34485626, 16.96319008], [82.34485626, 16.96375275], [82.3445816, 16.96375275], [82.3445816, 16.96403122], [82.34401703, 16.96403122], [82.34401703, 16.96430969], [82.34347534, 16.96430588], [82.34347534, 16.96458244], [82.34319305, 16.96458054], [82.34319305, 16.96486282], [82.34263611, 16.96486282], [82.34263611, 16.96513939], [82.34208679, 16.96513939], [82.34208679, 16.96541977], [82.3409729, 16.96541405], [82.3409729, 16.96569252], [82.34041595, 16.96569061], [82.34041595, 16.96624947], [82.3401413, 16.96624947], [82.3401413, 16.96708488], [82.33930206, 16.96708107], [82.33930206, 16.96763992], [82.3390274, 16.96763992], [82.3390274, 16.96903038], [82.33875275, 16.96902847], [82.33875275, 16.96958351], [82.33847809, 16.9695797], [82.33847809, 16.97042084], [82.3381958, 16.97041893], [82.3381958, 16.97097206], [82.33790588, 16.97097015], [82.33790588, 16.97125053], [82.33763885, 16.97125053], [82.33763885, 16.97180748], [82.3373642, 16.97180557], [82.3373642, 16.97208405], [82.33708191, 16.97208023], [82.33708191, 16.97236061], [82.33680725, 16.97236061], [82.33680725, 16.97263908], [82.33652496, 16.97263718], [82.33652496, 16.97319412], [82.33625031, 16.97319412], [82.33625031, 16.9734726], [82.33597565, 16.9734726], [82.33598328, 16.97485924], [82.33569336, 16.97485924], [82.33569336, 16.97569466], [82.3354187, 16.97569466], [82.3354187, 16.97652817], [82.33513641, 16.97652817], [82.33513641, 16.97680473], [82.33486176, 16.97680473], [82.33486176, 16.9770813], [82.3345871, 16.9770813], [82.3345871, 16.97736359], [82.33429718, 16.97735977], [82.33429718, 16.97764015], [82.33403015, 16.97764015], [82.33403015, 16.97792053], [82.33374786, 16.97791672], [82.33374786, 16.97847366], [82.33347321, 16.97846985], [82.33347321, 16.97903061], [82.33319092, 16.97903061], [82.33319092, 16.97986031], [82.33291626, 16.97986031], [82.33291626, 16.98014069], [82.3326416, 16.98014069], [82.3326416, 16.98042107], [82.33235931, 16.98041725], [82.33235931, 16.98069572], [82.33207703, 16.98069], [82.33207703, 16.98125076], [82.33180237, 16.98125076], [82.33180237, 16.98153114], [82.32958221, 16.98153114], [82.32958221, 16.98180962], [82.32902527, 16.98180771], [82.32902527, 16.98208427], [82.32875061, 16.98208046], [82.32875061, 16.98236084], [82.32847595, 16.98236084], [82.32847595, 16.98265076], [82.32791901, 16.98265076], [82.32791901, 16.98291969], [82.32763672, 16.98291779], [82.32763672, 16.98319435], [82.32736206, 16.98319435], [82.32736206, 16.98347282], [82.32707977, 16.98347092], [82.32707977, 16.98430824], [82.32680511, 16.98430634], [82.32680511, 16.98486137], [82.32653809, 16.98485947], [82.32653809, 16.98513985], [82.32624817, 16.98513985], [82.32624817, 16.98569489], [82.32597351, 16.98569489], [82.32597351, 16.98597145], [82.32569122, 16.98596954], [82.32569122, 16.98624992], [82.32541656, 16.98624992], [82.32541656, 16.98681068], [82.32514191, 16.98680496], [82.32514191, 16.98708344], [82.32485962, 16.98707962], [82.32485962, 16.98764229], [82.32458496, 16.98763847], [82.32457733, 16.9881916], [82.32430267, 16.98820114], [82.32430267, 16.98875046], [82.32457733, 16.98875046], [82.32457733, 16.98903275], [82.32485962, 16.98903275], [82.32485962, 16.98931122], [82.32514191, 16.9893055], [82.32514191, 16.98958206], [82.32541656, 16.98958015], [82.32541656, 16.99014282], [82.32569122, 16.99014282], [82.32569122, 16.99041939], [82.32597351, 16.99041748], [82.32597351, 16.99069214], [82.32624817, 16.99069214], [82.32624817, 16.99097443], [82.32791901, 16.99097443], [82.32791901, 16.99069214], [82.32847595, 16.99069214], [82.32847595, 16.99097443], [82.32930756, 16.99097061], [82.32930756, 16.9912529], [82.32958221, 16.9912529], [82.32958221, 16.99097061], [82.33152771, 16.99097443], [82.33152771, 16.99069214], [82.33208466, 16.99069214], [82.33208466, 16.99041748], [82.3326416, 16.99041939], [82.3326416, 16.99014282], [82.33347321, 16.99014282], [82.33347321, 16.98986053], [82.33403015, 16.98986053], [82.33403015, 16.98958015], [82.3345871, 16.98958206], [82.3345871, 16.9893055], [82.3354187, 16.98931122], [82.3354187, 16.98903275], [82.33569336, 16.98903275], [82.33569336, 16.98875046], [82.33625031, 16.98875046], [82.33625031, 16.98846054], [82.33652496, 16.98847008], [82.33652496, 16.98819351], [82.33708191, 16.98819351], [82.33708191, 16.98791695], [82.33735657, 16.98792267], [82.33735657, 16.98764229], [82.33790588, 16.98764229], [82.33790588, 16.98735809], [82.3381958, 16.98736191], [82.3381958, 16.98708344], [82.33875275, 16.98708344], [82.33875275, 16.98680496], [82.3390274, 16.98681068], [82.3390274, 16.9865284], [82.33957672, 16.9865284], [82.33957672, 16.98624992], [82.33985901, 16.98624992], [82.33985901, 16.98596954], [82.34041595, 16.98597145], [82.34041595, 16.98569489], [82.34069061, 16.98569489], [82.34069824, 16.98541641], [82.34124756, 16.98541832], [82.34124756, 16.98513985], [82.34152222, 16.98513985], [82.34152222, 16.98485947], [82.3418045, 16.98486137], [82.3418045, 16.9845829], [82.34236145, 16.9845829], [82.34236145, 16.98430634], [82.34263611, 16.98430824], [82.34263611, 16.98402977], [82.3429184, 16.98402977], [82.3429184, 16.98374939], [82.34319305, 16.98374939], [82.34319305, 16.98347092], [82.34375, 16.98347282], [82.34375, 16.98319435], [82.34402466, 16.98319435], [82.34402466, 16.98291779], [82.34430695, 16.98291969], [82.34430695, 16.98265076], [82.34485626, 16.98265076], [82.34485626, 16.98236084], [82.34513855, 16.98236084], [82.34513855, 16.98208046], [82.34541321, 16.98208237], [82.34541321, 16.98180771], [82.34570313, 16.98180962], [82.34570313, 16.98153114], [82.34625244, 16.98153114], [82.34625244, 16.98125076], [82.3465271, 16.98125076], [82.3465271, 16.98097038], [82.34680176, 16.98097229], [82.34680176, 16.98069572], [82.34708405, 16.98069572], [82.34708405, 16.98041725], [82.3473587, 16.98042107], [82.3473587, 16.98014069], [82.34764099, 16.98014069], [82.34764099, 16.97957993], [82.34791565, 16.97958565], [82.34791565, 16.97930336], [82.34819794, 16.97931099], [82.34819794, 16.97903061], [82.3484726, 16.97903061], [82.3484726, 16.97875023], [82.34874725, 16.97875023], [82.34874725, 16.97846985], [82.34902954, 16.97847366], [82.34902954, 16.97791672], [82.34929657, 16.97792053], [82.34929657, 16.97735977], [82.34958649, 16.97736359], [82.34958649, 16.9770813], [82.34986115, 16.9770813], [82.34986115, 16.97652817], [82.3501358, 16.97652817], [82.3501358, 16.97624969], [82.35041809, 16.97624969], [82.35041809, 16.97569084], [82.35069275, 16.97569466], [82.35069275, 16.97513962], [82.35098267, 16.97513962], [82.35097504, 16.97485924], [82.35124969, 16.97485924], [82.35124969, 16.97431183], [82.35151672, 16.97431183], [82.35151672, 16.97374916], [82.35180664, 16.97374916], [82.35180664, 16.97346115], [82.3520813, 16.9734726], [82.3520813, 16.97291756], [82.35235596, 16.97292137], [82.35235596, 16.97236061], [82.35263824, 16.97236061], [82.35263824, 16.97208023], [82.3529129, 16.97208405], [82.3529129, 16.9715271], [82.35320282, 16.97153091], [82.35320282, 16.97125053], [82.35346985, 16.97125053], [82.35346222, 16.97068977], [82.35375214, 16.97069359], [82.35375214, 16.97013855], [82.35402679, 16.97014046], [82.35402679, 16.96986008], [82.35430908, 16.96986198], [82.35430908, 16.96930695], [82.35457611, 16.96931076], [82.35457611, 16.96903038], [82.3548584, 16.96903038], [82.3548584, 16.96846962], [82.35514069, 16.96847153], [82.35514069, 16.96819687], [82.35542297, 16.96820068], [82.35542297, 16.96763992], [82.35569763, 16.96763992], [82.35569763, 16.96708107], [82.35597229, 16.96708488], [82.35597229, 16.96680641], [82.35624695, 16.96681023], [82.35624695, 16.96624947], [82.35652161, 16.96624947], [82.35652161, 16.96597099], [82.35680389, 16.96597481], [82.35680389, 16.96541405], [82.35708618, 16.96541977], [82.35708618, 16.96513939], [82.35736084, 16.96513939], [82.35736084, 16.96458054], [82.3576355, 16.96458244], [82.3576355, 16.96375275], [82.35791779, 16.96375275], [82.35791779, 16.96264267], [82.35819244, 16.96264267], [82.35819244, 16.96125031], [82.3584671, 16.96125031], [82.3584671, 16.96013832], [82.35874939, 16.96013832], [82.35874939, 16.95819092], [82.35902405, 16.95819473], [82.35902405, 16.95708275], [82.35930634, 16.95708275], [82.35930634, 16.95597267], [82.35958099, 16.95597267], [82.35958099, 16.95486069], [82.35986328, 16.95486069], [82.35986328, 16.95375061], [82.36013794, 16.95375061], [82.36013794, 16.95014191], [82.36042023, 16.95014191], [82.36042023, 16.94681168], [82.36068726, 16.94681168], [82.36068726, 16.94568825], [82.36096954, 16.94569397], [82.36096954, 16.94458389], [82.36125183, 16.94458389], [82.36125183, 16.94347191], [82.36152649, 16.94347954], [82.36152649, 16.94207954], [82.36180878, 16.94208336], [82.36180878, 16.94041634], [82.36208344, 16.94041634], [82.36208344, 16.93874931], [82.36235809, 16.93875122], [82.36235809, 16.93708038], [82.36264038, 16.93708229], [82.36264038, 16.93652725], [82.36235809, 16.93653107], [82.36235809, 16.93625259], [82.36264801, 16.93625259], [82.36264038, 16.9323616], [82.36291504, 16.9323616], [82.36291504, 16.92986107], [82.36319733, 16.92986107], [82.36319733, 16.92818069], [82.36347198, 16.92819595], [82.36347198, 16.9268055], [82.36374664, 16.92681122], [82.36374664, 16.92514038], [82.36402893, 16.92514038], [82.36402893, 16.92292023], [82.36429596, 16.92292023], [82.36429596, 16.92013931], [82.36458588, 16.92013931], [82.36458588, 16.91902924], [82.36486053, 16.91902924], [82.36486053, 16.91681099], [82.36514282, 16.91681099], [82.36514282, 16.91542053], [82.36541748, 16.91542053], [82.36541748, 16.90624809], [82.36569214, 16.90624809], [82.36569214, 16.90208054], [82.36541748, 16.90208244], [82.36541748, 16.89958572], [82.36513519, 16.89958572], [82.36513519, 16.89680481], [82.36486053, 16.89680481], [82.36486053, 16.89430618], [82.36458588, 16.8943119], [82.36458588, 16.89180756], [82.36429596, 16.89180756], [82.36429596, 16.88929939], [82.36402893, 16.88930511], [82.36402893, 16.88680649], [82.36374664, 16.8868103], [82.36374664, 16.88430977], [82.36347198, 16.88430977], [82.36347198, 16.8848629], [82.36319733, 16.8848629], [82.36319733, 16.88541985], [82.36264801, 16.88541985], [82.36264801, 16.8848629], [82.36235809, 16.8848629], [82.36235809, 16.88430977], [82.36207581, 16.88430977], [82.36207581, 16.88264275], [82.36180878, 16.88264275], [82.36180878, 16.88125038], [82.36152649, 16.88125038], [82.36152649, 16.88070107], [82.36125183, 16.88070107], [82.36125183, 16.87846947], [82.36096954, 16.87847137], [82.36096954, 16.87791634], [82.36068726, 16.87791824], [82.36068726, 16.87763977], [82.36042023, 16.87763977], [82.36042023, 16.87706947], [82.36013794, 16.87708282], [82.36013794, 16.87430573], [82.35986328, 16.87432098], [82.35986328, 16.87264061], [82.35958099, 16.87264061], [82.35958099, 16.87181091], [82.35930634, 16.87181091], [82.35930634, 16.87096977], [82.35902405, 16.87097359], [82.35902405, 16.87013817], [82.35874939, 16.87014008], [82.35874939, 16.86846924], [82.35902405, 16.86847115], [82.35902405, 16.86680603], [82.35874939, 16.86681175], [82.35874939, 16.86624908], [82.3584671, 16.86624908], [82.3584671, 16.86569023], [82.35819244, 16.86569405], [82.35819244, 16.8651371], [82.35791779, 16.8651371], [82.35791779, 16.85958481], [82.3576355, 16.85958481], [82.3576355, 16.85652733], [82.35745239, 16.85652733], [82.35736084, 16.85652733], [82.35736084, 16.85545731], [82.35736084, 16.85430527], [82.35764313, 16.8543129], [82.35764313, 16.85318756], [82.35791779, 16.85318756], [82.35791779, 16.85374832], [82.35819244, 16.85374832], [82.35819244, 16.85403252], [82.3584671, 16.85403252], [82.3584671, 16.85374832], [82.35874939, 16.85374832], [82.35874939, 16.85263824], [82.35901642, 16.85263824], [82.35901642, 16.85124969], [82.35874939, 16.85124969], [82.35874939, 16.85069084], [82.35847473, 16.85069466], [82.35847473, 16.85041618], [82.35874939, 16.85041809], [82.35874939, 16.84986115], [82.35901642, 16.84986115], [82.35901642, 16.84875107], [82.35874939, 16.84875107], [82.35874939, 16.84847069], [82.35847473, 16.8484726], [82.35847473, 16.84819412], [82.35819244, 16.84819412], [82.35819244, 16.84708595], [82.35791779, 16.84708977], [82.35791779, 16.84625053], [82.3576355, 16.84625053], [82.3576355, 16.8456955], [82.35791779, 16.8456955], [82.35791779, 16.84541702], [82.35819244, 16.84542084], [82.35819244, 16.8445797], [82.35847473, 16.8445816], [82.35847473, 16.84430313], [82.35819244, 16.84431076], [82.35819244, 16.84320068], [82.35791779, 16.84320068], [82.35791779, 16.84264183], [82.35764313, 16.84264183], [82.35764313, 16.84235954], [82.35736084, 16.84236336], [82.35736084, 16.84152794], [82.35708618, 16.84153175], [82.35708618, 16.84124947], [82.35679626, 16.84124947], [82.35679626, 16.84095955], [82.35652924, 16.8409729], [82.35652924, 16.84041595], [82.35624695, 16.84042168], [82.35624695, 16.83847046], [82.35597229, 16.83847237], [82.35597229, 16.83763885], [82.35542297, 16.83764076], [82.35542297, 16.83736038], [82.35514069, 16.83736038], [82.35514069, 16.83681107], [82.3548584, 16.83681107], [82.3548584, 16.83570099], [82.35457611, 16.83570099], [82.35457611, 16.83374977], [82.35430908, 16.83374977], [82.35430908, 16.83263969], [82.35402679, 16.83263969], [82.35402679, 16.83209038], [82.35375214, 16.83209038], [82.35375214, 16.83181], [82.35346222, 16.83181], [82.35346222, 16.83069038], [82.35319519, 16.83069229], [82.35319519, 16.82763863], [82.35346222, 16.82764244], [82.35346222, 16.82652855], [82.35320282, 16.82652855], [82.35320282, 16.82624817], [82.3529129, 16.82624817], [82.3529129, 16.8243103], [82.35263824, 16.8243103], [82.35263824, 16.82347107], [82.3529129, 16.82347298], [82.3529129, 16.82291794], [82.35320282, 16.82291985], [82.35320282, 16.82236099], [82.3529129, 16.82236099], [82.3529129, 16.82208061], [82.3520813, 16.82208252], [82.3520813, 16.82180786], [82.35180664, 16.82180977], [82.35180664, 16.82097054], [82.3520813, 16.82097244], [82.3520813, 16.8204174], [82.35235596, 16.82042122], [82.35235596, 16.81931114], [82.3520813, 16.81931114], [82.3520813, 16.81820107], [82.35180664, 16.81820107], [82.35180664, 16.81792068], [82.35151672, 16.81792068], [82.35151672, 16.8176403], [82.35124969, 16.8176403], [82.35124969, 16.81679153], [82.35097504, 16.81680489], [82.35097504, 16.81597137], [82.35069275, 16.81597137], [82.35069275, 16.81514168], [82.35041809, 16.81514168], [82.35041809, 16.81458092], [82.3501358, 16.81458282], [82.3501358, 16.81402779], [82.34986115, 16.81402779], [82.34986115, 16.81374931], [82.34958649, 16.81374931], [82.34958649, 16.81319046], [82.3493042, 16.81319427], [82.3493042, 16.81236076], [82.34902954, 16.81236076], [82.34902954, 16.81180763], [82.34929657, 16.81180763], [82.34929657, 16.81041908], [82.34902954, 16.81041908], [82.34902954, 16.80957985], [82.34874725, 16.80958366], [82.34874725, 16.80930519], [82.3484726, 16.80931091], [82.3484726, 16.80846977], [82.34819794, 16.80847168], [82.34819794, 16.80819511], [82.3484726, 16.80821037], [82.3484726, 16.80792046], [82.34874725, 16.80792046], [82.34877014, 16.80821037], [82.34902954, 16.80819511], [82.34902954, 16.80847168], [82.34929657, 16.80846977], [82.34929657, 16.80931091], [82.34958649, 16.80931091], [82.34958649, 16.80986023], [82.34929657, 16.80986023], [82.34929657, 16.81014061], [82.34958649, 16.81014061], [82.34958649, 16.81041908], [82.34986115, 16.81041718], [82.34986115, 16.81069374], [82.35041809, 16.81068993], [82.35041809, 16.81125069], [82.35069275, 16.81125069], [82.35069275, 16.8120842], [82.35098267, 16.81208038], [82.35098267, 16.81263924], [82.35124969, 16.81263924], [82.35124969, 16.81374931], [82.35180664, 16.81374931], [82.35180664, 16.81402779], [82.35151672, 16.81401825], [82.35151672, 16.81431007], [82.35180664, 16.81431007], [82.35180664, 16.81542015], [82.3520813, 16.81541634], [82.3520813, 16.81597137], [82.35235596, 16.81596947], [82.35235596, 16.81653023], [82.35263824, 16.81652832], [82.35263824, 16.81708145], [82.3529129, 16.81707954], [82.3529129, 16.81792068], [82.35320282, 16.81792068], [82.35320282, 16.81820107], [82.35346985, 16.81819534], [82.35346985, 16.81847382], [82.35458374, 16.81847382], [82.35458374, 16.81819534], [82.3548584, 16.81820107], [82.3548584, 16.8176403], [82.35514069, 16.8176403], [82.35514069, 16.81707954], [82.35541534, 16.81708145], [82.35541534, 16.8163681], [82.35541534, 16.81625175], [82.35569763, 16.81625175], [82.35569763, 16.81514168], [82.35597229, 16.81514168], [82.35597229, 16.81458092], [82.35569763, 16.81458282], [82.35569763, 16.8120842], [82.35541534, 16.8120842], [82.35541534, 16.81097221], [82.35514069, 16.81097984], [82.35514069, 16.81014061], [82.3548584, 16.81014061], [82.3548584, 16.80821037], [82.35457611, 16.80821037], [82.35457611, 16.80708122], [82.35430908, 16.80708313], [82.35430908, 16.80652809], [82.35402679, 16.80653], [82.35402679, 16.80624962], [82.35375214, 16.80624962], [82.35375214, 16.80569077], [82.35346985, 16.80569458], [82.35346985, 16.8045845], [82.35319519, 16.8045845], [82.35319519, 16.80402756], [82.35346222, 16.80402946], [82.35346222, 16.80347061], [82.35319519, 16.80347061], [82.35319519, 16.80236053], [82.3529129, 16.80236053], [82.3529129, 16.80153275], [82.35263824, 16.80153275], [82.35263824, 16.80070114], [82.35235596, 16.8006897], [82.35236359, 16.80013847], [82.3520813, 16.80013847], [82.3520813, 16.79957962], [82.35180664, 16.79958344], [82.35180664, 16.79763985], [82.35151672, 16.79763985], [82.35151672, 16.79652977], [82.35124969, 16.79652977], [82.35124969, 16.79569054], [82.35152435, 16.79569435], [82.35152435, 16.79263878], [82.35124969, 16.79264069], [82.35124969, 16.79125023], [82.35097504, 16.79125023], [82.35097504, 16.79013824], [82.35069275, 16.79014015], [82.35069275, 16.78957939], [82.35041809, 16.7895813], [82.35041809, 16.78930473], [82.3501358, 16.78930473], [82.3501358, 16.78847122], [82.34986115, 16.78847122], [82.34986115, 16.78764153], [82.34958649, 16.78764153], [82.34958649, 16.78735924], [82.34929657, 16.78735924], [82.34929657, 16.78708076], [82.34902954, 16.78708267], [82.34902954, 16.78624916], [82.34929657, 16.78624916], [82.34929657, 16.78597069], [82.34958649, 16.7859726], [82.34958649, 16.78458405], [82.34902954, 16.78458405], [82.34902954, 16.78430557], [82.3473587, 16.78430748], [82.3473587, 16.78375053], [82.34707642, 16.78375053], [82.34707642, 16.78181076], [82.34680176, 16.78181076], [82.34680176, 16.78125], [82.3465271, 16.78125], [82.3465271, 16.7804203], [82.34625244, 16.7804203], [82.34625244, 16.77931023], [82.34597015, 16.77931023], [82.34597015, 16.77819061], [82.3456955, 16.77819252], [82.3456955, 16.77708435], [82.34541321, 16.77708435], [82.34541321, 16.77541733], [82.34513855, 16.77542114], [82.34513855, 16.77319908], [82.34485626, 16.77319908], [82.34485626, 16.77152824], [82.3445816, 16.77152824], [82.3445816, 16.77041817], [82.34430695, 16.77041817], [82.34430695, 16.76736069], [82.3445816, 16.76736069], [82.3445816, 16.76708031], [82.34430695, 16.76708412], [82.34430695, 16.76680565], [82.34401703, 16.76680946], [82.34401703, 16.76653099], [82.34375, 16.76653099], [82.34375, 16.76625061], [82.3429184, 16.76625061], [82.3429184, 16.76514053], [82.34263611, 16.76514053], [82.34263611, 16.76431084], [82.3429184, 16.76431084], [82.3429184, 16.76403046], [82.34348297, 16.76403046], [82.34348297, 16.76375008], [82.34375, 16.76375008], [82.34375, 16.76320076], [82.34348297, 16.76320076], [82.34348297, 16.76291275], [82.34319305, 16.76291656], [82.34319305, 16.76263809], [82.3429184, 16.76264191], [82.3429184, 16.76207924], [82.34319305, 16.76208115], [82.34319305, 16.76124954], [82.34348297, 16.76124954], [82.34347534, 16.76013947], [82.34319305, 16.76013947], [82.34319305, 16.75875092], [82.3429184, 16.75875092], [82.3429184, 16.75792122], [82.34263611, 16.75792122], [82.34263611, 16.75736046], [82.34236145, 16.75736046], [82.34236145, 16.75570107], [82.34208679, 16.75570107], [82.34208679, 16.75542068], [82.34179688, 16.75542068], [82.34179688, 16.75457954], [82.34152985, 16.75458336], [82.34152985, 16.75347137], [82.34124756, 16.75347137], [82.34124756, 16.75208473], [82.34152985, 16.75208473], [82.34152985, 16.75069237], [82.34124756, 16.75069237], [82.34124756, 16.75013924], [82.3409729, 16.75014114], [82.3409729, 16.74986267], [82.34124756, 16.74986267], [82.34124756, 16.74819183], [82.34152985, 16.74819374], [82.34152985, 16.74624825], [82.34124756, 16.74624825], [82.34124756, 16.74596977], [82.3409729, 16.74597168], [82.3409729, 16.7448616], [82.34124756, 16.74486923], [82.34124756, 16.74458122], [82.34152985, 16.74458313], [82.34152985, 16.74430466], [82.3418045, 16.74430466], [82.3418045, 16.74319458], [82.34208679, 16.74319458], [82.34208679, 16.74041748], [82.34236145, 16.74041939], [82.34236145, 16.73931122], [82.34263611, 16.73931122], [82.34263611, 16.7381897], [82.3429184, 16.7381916], [82.3429184, 16.73791695], [82.34263611, 16.73792076], [82.34263611, 16.73764038], [82.34236145, 16.73764038], [82.34236145, 16.73736191], [82.34208679, 16.73736382], [82.34208679, 16.73680305], [82.34179688, 16.73681068], [82.34179688, 16.73625183], [82.34152222, 16.73625183], [82.34152222, 16.73596954], [82.33921051, 16.73596954], [82.33625031, 16.73597336], [82.33625031, 16.73569489], [82.3354187, 16.73570061], [82.3354187, 16.73542023], [82.33429718, 16.73542023], [82.33429718, 16.73514175], [82.3326416, 16.73514175], [82.3326416, 16.73485947], [82.33235168, 16.73485947], [82.33235168, 16.73514175], [82.32985687, 16.73514175], [82.32985687, 16.73485947], [82.32763672, 16.73485947], [82.32763672, 16.7345829], [82.32791901, 16.7345829], [82.32791901, 16.73430634], [82.32736206, 16.73431015], [82.32736206, 16.73403168], [82.32681274, 16.73403168], [82.32681274, 16.73374939], [82.32624817, 16.73374939], [82.32624817, 16.73347092], [82.32569122, 16.73347092], [82.32569122, 16.73374939], [82.32541656, 16.73374939], [82.32541656, 16.7345829], [82.32514191, 16.73457909], [82.32514191, 16.73542023], [82.32457733, 16.73542023], [82.32457733, 16.73570061], [82.32402802, 16.73570061], [82.32402802, 16.73542023], [82.32319641, 16.73542023], [82.32319641, 16.73514175], [82.32263947, 16.73514175], [82.32263947, 16.73485947], [82.32236481, 16.73485947], [82.32236481, 16.7345829], [82.32180786, 16.7345829], [82.32180786, 16.73430634], [82.32068634, 16.73431015], [82.32068634, 16.73403168], [82.31986237, 16.73403168], [82.31986237, 16.73374939], [82.31970215, 16.73374939], [82.31874847, 16.73374939], [82.31874847, 16.73347092], [82.31791687, 16.73347282], [82.31791687, 16.73319435], [82.31764221, 16.73319435], [82.31764221, 16.73291588], [82.31735229, 16.73293114], [82.31735229, 16.73263931], [82.31652832, 16.73263931], [82.31652832, 16.73208046], [82.31625366, 16.73208427], [82.31625366, 16.7318058], [82.31485748, 16.7318058], [82.31485748, 16.73208427], [82.31430817, 16.73208046], [82.31430817, 16.73236084], [82.31402588, 16.73236084], [82.31402588, 16.73263931], [82.31291962, 16.73263931], [82.31291962, 16.73319435], [82.31263733, 16.73319435], [82.31263733, 16.73347282], [82.31180573, 16.73347282], [82.31180573, 16.73291588], [82.3115387, 16.73293114], [82.3115387, 16.73180962], [82.31124878, 16.73180962], [82.31124878, 16.7306881], [82.31097412, 16.73069382], [82.31097412, 16.72986031], [82.31124878, 16.72986031], [82.31124878, 16.72957039], [82.31153107, 16.72958374], [82.31153107, 16.7290287], [82.31181335, 16.72903061], [82.31181335, 16.72875023], [82.31208038, 16.72875023], [82.31208038, 16.72820091], [82.31236267, 16.72820091], [82.31236267, 16.72735977], [82.31263733, 16.72736168], [82.31263733, 16.72652817], [82.31236267, 16.72653008], [82.31236267, 16.72624969], [82.31208038, 16.72624969], [82.31208038, 16.72569084], [82.31180573, 16.72569466], [82.31180573, 16.72513962], [82.31153107, 16.72513962], [82.31153107, 16.72486115], [82.31124878, 16.72486115], [82.31124878, 16.72458076], [82.31097412, 16.72458458], [82.31097412, 16.72430611], [82.31069183, 16.72430992], [82.31069183, 16.7237606], [82.31041718, 16.7237606], [82.31041718, 16.72347069], [82.31014252, 16.7234745], [82.31014252, 16.72319221], [82.30986023, 16.72319221], [82.30986023, 16.72291756], [82.3095932, 16.72291946], [82.3095932, 16.72236252], [82.30930328, 16.72236252], [82.30930328, 16.72208023], [82.30902863, 16.72208214], [82.30902863, 16.7215271], [82.30874634, 16.72153282], [82.30874634, 16.72097015], [82.30847168, 16.72097015], [82.30847168, 16.72069359], [82.30819702, 16.72070122], [82.30819702, 16.72042274], [82.3079071, 16.72042274], [82.3079071, 16.71985817], [82.30764008, 16.71986008], [82.30764008, 16.71930504], [82.30735779, 16.71931076], [82.30735779, 16.71902847], [82.30652618, 16.71902847], [82.30652618, 16.71846962], [82.30596924, 16.71847153], [82.30596924, 16.71819496], [82.30568695, 16.71820068], [82.30568695, 16.71763039], [82.30541992, 16.71763992], [82.30541992, 16.71736145], [82.30513763, 16.71736145], [82.30513763, 16.71708298], [82.30486298, 16.71708298], [82.30486298, 16.71652794], [82.30430603, 16.71652985], [82.30430603, 16.71624947], [82.30403137, 16.71624947], [82.30403137, 16.71597099], [82.30347443, 16.7159729], [82.30347443, 16.71569443], [82.30291748, 16.71569443], [82.30291748, 16.71541786], [82.30264282, 16.71541977], [82.30264282, 16.71513939], [82.30152893, 16.71513939], [82.30152893, 16.71486092], [82.30041504, 16.71486092], [82.30041504, 16.71458244], [82.29985809, 16.71458244], [82.29985809, 16.71430588], [82.29951477, 16.71433258], [82.30282593, 16.72283936], [82.30105591, 16.73333931], [82.29773712, 16.74037933], [82.29370117, 16.74304008], [82.28909302, 16.74098969], [82.28507996, 16.73450851], [82.28070068, 16.72274971], [82.26370239, 16.71936989], [82.24494934, 16.71895981], [82.22704315, 16.71718025], [82.22042084, 16.7183094], [82.21478271, 16.72520065], [82.21096802, 16.72793961], [82.2100296, 16.73127174], [82.2197876, 16.74486923], [82.22181702, 16.75035286], [82.21768188, 16.75168991], [82.21113586, 16.74822044], [82.20722961, 16.74370956], [82.19677734, 16.73647118], [82.18875122, 16.72721291], [82.18032074, 16.72809982], [82.17463684, 16.7251091], [82.17907715, 16.71630096], [82.19358063, 16.70845032], [82.20252991, 16.70769119], [82.21543884, 16.70976067], [82.22740936, 16.70465088], [82.24653625, 16.69144058], [82.25344849, 16.68972015], [82.25763702, 16.69011307], [82.25791931, 16.69013977], [82.25791931, 16.68985939], [82.25846863, 16.6898613], [82.25846863, 16.68874931], [82.25875092, 16.68875122], [82.25875092, 16.68708038], [82.25902557, 16.6870842], [82.25902557, 16.6851387], [82.25875092, 16.68514061], [82.25875092, 16.68403053], [82.2590332, 16.68403053], [82.2590332, 16.68153191], [82.25930786, 16.68153191], [82.25930786, 16.68069077], [82.25958252, 16.68069458], [82.25958252, 16.68041611], [82.25930786, 16.68042183], [82.25930786, 16.68014145], [82.25958252, 16.68014145], [82.25958252, 16.67985916], [82.25985718, 16.67985916], [82.25985718, 16.67846107], [82.26013947, 16.67847252], [82.26013947, 16.67819405], [82.25986481, 16.67819405], [82.25986481, 16.6768055], [82.26013947, 16.67681122], [82.26013947, 16.67625046], [82.25985718, 16.67625046], [82.25985718, 16.67514038], [82.26040649, 16.67514038], [82.26040649, 16.67486], [82.26013947, 16.67486191], [82.26013947, 16.67458344], [82.25986481, 16.67458344], [82.25986481, 16.67430687], [82.25958252, 16.67431068], [82.25958252, 16.67374992], [82.25985718, 16.67374992], [82.25985718, 16.67292023], [82.26013947, 16.67292023], [82.26013947, 16.67235947], [82.26041412, 16.67236137], [82.26041412, 16.67208481], [82.26069641, 16.67208481], [82.26069641, 16.67152786], [82.26097107, 16.67152977], [82.26097107, 16.66930962], [82.26069641, 16.66930962], [82.26069641, 16.66903114], [82.26097107, 16.66903114], [82.26097107, 16.66847038], [82.26152802, 16.66847038], [82.26152802, 16.66819382], [82.26125336, 16.66819382], [82.26125336, 16.66653061], [82.26097107, 16.66653061], [82.26097107, 16.66624832], [82.26069641, 16.66624832], [82.26069641, 16.66596985], [82.26041412, 16.66597176], [82.26041412, 16.66569519], [82.26013947, 16.66570091], [82.26013947, 16.66513824], [82.25985718, 16.66513824], [82.25985718, 16.66485977], [82.25958252, 16.66486168], [82.25958252, 16.66430473], [82.25902557, 16.66430473], [82.25902557, 16.66402626], [82.25875092, 16.66402817], [82.25875092, 16.66374969], [82.25846863, 16.66374969], [82.25846863, 16.66345978], [82.25819397, 16.66347313], [82.25819397, 16.66319466], [82.25791931, 16.66319466], [82.25791931, 16.66291618], [82.25736237, 16.66291809], [82.25736237, 16.66236115], [82.25707245, 16.66236115], [82.25707245, 16.66208076], [82.25680542, 16.66208267], [82.25680542, 16.66180611], [82.25653076, 16.66180992], [82.25653076, 16.66152954], [82.25624847, 16.66152954], [82.25624847, 16.66097069], [82.25569153, 16.6609726], [82.25569153, 16.66069412], [82.25541687, 16.66069412], [82.25541687, 16.66013908], [82.25514221, 16.66014099], [82.25514221, 16.65903091], [82.25485992, 16.65903091], [82.25485992, 16.65875053], [82.25569153, 16.65875053], [82.25569153, 16.65847015], [82.25485992, 16.65847206], [82.25485992, 16.65791702], [82.2545929, 16.65792084], [82.2545929, 16.65736008], [82.25430298, 16.65736389], [82.25430298, 16.65680313], [82.25402832, 16.65681076], [82.25402832, 16.65570068], [82.25430298, 16.65570068], [82.25430298, 16.65514183], [82.25402832, 16.65514183], [82.25402832, 16.65431023], [82.25374603, 16.65431023], [82.25374603, 16.65263939], [82.25402832, 16.65263939], [82.25402832, 16.65208054], [82.25430298, 16.65208244], [82.25430298, 16.65125084], [82.2545929, 16.65125084], [82.25458527, 16.65069389], [82.25485992, 16.65069389], [82.25485992, 16.65013885], [82.25514221, 16.65014076], [82.25514221, 16.64958], [82.25541687, 16.64958382], [82.25541687, 16.64902687], [82.25569153, 16.64903069], [82.25569153, 16.64875031], [82.25596619, 16.64875031], [82.25596619, 16.64847946], [82.25624847, 16.64847946], [82.25624847, 16.64792061], [82.25653076, 16.64792061], [82.25653076, 16.64764023], [82.25681305, 16.64764023], [82.25681305, 16.64735985], [82.25708008, 16.64736176], [82.25708008, 16.64680672], [82.25736237, 16.64680672], [82.25736237, 16.64652824], [82.25763702, 16.64653015], [82.25763702, 16.64624977], [82.25791931, 16.64624977], [82.25791931, 16.64569092], [82.25819397, 16.64569473], [82.25819397, 16.64541626], [82.25875092, 16.64542007], [82.25875092, 16.64347267], [82.25818634, 16.64347267], [82.25818634, 16.64431], [82.25791931, 16.64431], [82.25791931, 16.64402962], [82.25681305, 16.64402962], [82.25681305, 16.64431], [82.25708008, 16.64430618], [82.25708008, 16.64458466], [82.25653076, 16.64458466], [82.25653076, 16.64263916], [82.25681305, 16.64264107], [82.25681305, 16.64208031], [82.25846863, 16.64208412], [82.25846863, 16.64180565], [82.25930786, 16.64180946], [82.25930786, 16.6415329], [82.25985718, 16.6415329], [82.25985718, 16.64125252], [82.26180267, 16.64125252], [82.26180267, 16.6415329], [82.26207733, 16.6415329], [82.26207733, 16.64180946], [82.26264191, 16.64180565], [82.26264191, 16.64208412], [82.26291656, 16.64208412], [82.26291656, 16.64236259], [82.26569366, 16.64236259], [82.26569366, 16.64208412], [82.26652527, 16.64208412], [82.26652527, 16.64180565], [82.26735687, 16.64180946], [82.26735687, 16.6415329], [82.26819611, 16.6415329], [82.26819611, 16.64125252], [82.26902771, 16.64125252], [82.26902771, 16.64097023], [82.26985931, 16.64097023], [82.26985931, 16.64069366], [82.27041626, 16.64069366], [82.27041626, 16.6404171], [82.27124786, 16.64042282], [82.27124786, 16.64013863], [82.27179718, 16.64013863], [82.27179718, 16.63985825], [82.2720871, 16.63985825], [82.2720871, 16.63957977], [82.27263641, 16.63958359], [82.27263641, 16.63930511], [82.27319336, 16.63931084], [82.27319336, 16.63902855], [82.27348328, 16.63902855], [82.27348328, 16.63874817], [82.27402496, 16.63874817], [82.27401733, 16.6384697], [82.27430725, 16.6384716], [82.27430725, 16.63819504], [82.27485657, 16.63820076], [82.27485657, 16.63792038], [82.27540588, 16.63792038], [82.27540588, 16.63763809], [82.2756958, 16.63763809], [82.2756958, 16.63735962], [82.27625275, 16.63736153], [82.27625275, 16.63708305], [82.27680206, 16.63708305], [82.27680206, 16.63680649], [82.27707672, 16.63680077], [82.27708435, 16.63652611], [82.27735901, 16.63653755], [82.27735901, 16.63624954], [82.27819824, 16.63624954], [82.27819824, 16.63597298], [82.2784729, 16.63597298], [82.2784729, 16.6356945], [82.27874756, 16.6356945], [82.27874756, 16.63513947], [82.27902985, 16.63513947], [82.27902985, 16.63430977], [82.27929688, 16.63430977], [82.27929688, 16.63402939], [82.27958679, 16.63402939], [82.27958679, 16.63375092], [82.27986145, 16.63375092], [82.27986145, 16.63348007], [82.2804184, 16.63348007], [82.2804184, 16.63319016], [82.28069305, 16.63319588], [82.28069305, 16.6329174], [82.28098297, 16.63292122], [82.28098297, 16.63264084], [82.28124237, 16.63264084], [82.28124237, 16.63208008], [82.28152466, 16.6320858], [82.28152466, 16.63152695], [82.28180695, 16.63153076], [82.28180695, 16.63070107], [82.2820816, 16.63070107], [82.2820816, 16.6301403], [82.28235626, 16.6301403], [82.28235626, 16.62957954], [82.28263855, 16.62958145], [82.28263855, 16.62930489], [82.28291321, 16.62930489], [82.28291321, 16.62902832], [82.28320313, 16.62903023], [82.28320313, 16.62846947], [82.28347015, 16.62846947], [82.28347015, 16.62791634], [82.28375244, 16.62792015], [82.28375244, 16.62734985], [82.2840271, 16.62735939], [82.2840271, 16.62680626], [82.28430176, 16.62681007], [82.28430176, 16.62624931], [82.28457642, 16.62624931], [82.28457642, 16.62513924], [82.2848587, 16.62513924], [82.2848587, 16.62430954], [82.28514099, 16.62430954], [82.28514099, 16.62347031], [82.28541565, 16.62347221], [82.28541565, 16.62291718], [82.28569794, 16.62292099], [82.28569794, 16.62207985], [82.2859726, 16.62208366], [82.2859726, 16.62152863], [82.28624725, 16.62153816], [82.28624725, 16.62070084], [82.28652954, 16.62070084], [82.28652954, 16.62014008], [82.28679657, 16.62014008], [82.28679657, 16.61958122], [82.28708649, 16.61958313], [82.28708649, 16.61902809], [82.28736877, 16.61903], [82.28736877, 16.61847115], [82.2876358, 16.61847305], [82.2876358, 16.61791611], [82.28791809, 16.61791992], [82.28791809, 16.61763954], [82.28819275, 16.61763954], [82.28819275, 16.61708069], [82.28847504, 16.6170845], [82.28847504, 16.61652756], [82.28874969, 16.61652946], [82.28874969, 16.6162529], [82.28901672, 16.6162529], [82.28901672, 16.61569023], [82.28930664, 16.61569214], [82.28930664, 16.61458206], [82.2895813, 16.61458206], [82.2895813, 16.61263847], [82.28985596, 16.61263847], [82.28985596, 16.61096954], [82.29013824, 16.61097145], [82.29013824, 16.61041641], [82.2904129, 16.61041832], [82.2904129, 16.61013985], [82.29070282, 16.61013985], [82.29070282, 16.60985947], [82.29096985, 16.60986137], [82.29096985, 16.6095829], [82.29180908, 16.6095829], [82.29180908, 16.60930634], [82.29207611, 16.60931015], [82.29207611, 16.60874939], [82.2923584, 16.60874939], [82.2923584, 16.60764122], [82.29207611, 16.60764122], [82.29207611, 16.60653114], [82.29180908, 16.60653114], [82.29180908, 16.60597038], [82.29152679, 16.60597229], [82.29152679, 16.60569572], [82.29125214, 16.60569572], [82.29125214, 16.60541725], [82.29096985, 16.60542107], [82.29096985, 16.60514069], [82.2904129, 16.60514069], [82.2904129, 16.60486031], [82.29013824, 16.60486031], [82.29013824, 16.60457993], [82.28986359, 16.60458374], [82.28986359, 16.60430527], [82.2895813, 16.60431099], [82.2895813, 16.60403061], [82.28901672, 16.60403061], [82.28901672, 16.60375023], [82.28874969, 16.60375023], [82.28874969, 16.60346985], [82.28819275, 16.60347366], [82.28819275, 16.60319519], [82.28791809, 16.60320091], [82.28791809, 16.60292053], [82.28736877, 16.60292053], [82.28736877, 16.60235977], [82.28708649, 16.60236359], [82.28708649, 16.60190964], [82.28708649, 16.60180473], [82.2868042, 16.60180473], [82.2868042, 16.6012516], [82.2848587, 16.6012516], [82.2848587, 16.60153008], [82.28375244, 16.60153008], [82.28375244, 16.6012516], [82.28347015, 16.6012516], [82.28347015, 16.60096931], [82.28263855, 16.60097122], [82.28263855, 16.60069466], [82.28152466, 16.60069466], [82.28152466, 16.60041618], [82.28125, 16.60041618], [82.28125, 16.60069466], [82.28069305, 16.60069466], [82.28069305, 16.60097122], [82.28013611, 16.60097122], [82.28013611, 16.60069466], [82.27986145, 16.60069466], [82.27986145, 16.60041618], [82.27903748, 16.60041618], [82.27874756, 16.60042953], [82.27874756, 16.60014153], [82.27819824, 16.60014153], [82.27819824, 16.59958076], [82.27680206, 16.59958267], [82.27680206, 16.59930611], [82.2765274, 16.59931183], [82.2765274, 16.59903145], [82.27625275, 16.59903145], [82.27625275, 16.59874916], [82.2756958, 16.59874916], [82.2756958, 16.59847069], [82.27430725, 16.5984726], [82.27430725, 16.59819412], [82.27097321, 16.59819412], [82.27097321, 16.59791756], [82.26819611, 16.59791756], [82.26819611, 16.59763908], [82.26597595, 16.59763908], [82.26597595, 16.59736824], [82.26568604, 16.59736824], [82.26568604, 16.59653091], [82.26541901, 16.59653091], [82.26541901, 16.59542084], [82.26513672, 16.59542084], [82.26513672, 16.59430122], [82.26486206, 16.59430695], [82.26486206, 16.59375], [82.26457977, 16.59375], [82.26457977, 16.59320068], [82.26431274, 16.59320068], [82.26431274, 16.59263992], [82.26403046, 16.59263992], [82.26403046, 16.59208107], [82.26374817, 16.59208488], [82.26374817, 16.59152794], [82.26346588, 16.59152985], [82.26346588, 16.5909729], [82.26319122, 16.59097481], [82.26319122, 16.59041595], [82.26291656, 16.59041977], [82.26291656, 16.58986282], [82.26264191, 16.58986282], [82.26264191, 16.58930969], [82.26235962, 16.58930969], [82.26235962, 16.58903122], [82.26207733, 16.58903122], [82.26207733, 16.58875275], [82.26180267, 16.58875275], [82.26180267, 16.58847046], [82.26152802, 16.58847046], [82.26152802, 16.58819389], [82.26125336, 16.58819962], [82.26125336, 16.58792114], [82.26097107, 16.58792114], [82.26097107, 16.58764267], [82.26069641, 16.58764267], [82.26069641, 16.58736038], [82.26013947, 16.58736038], [82.26013947, 16.58708191], [82.25986481, 16.58708382], [82.25986481, 16.58680534], [82.26125336, 16.58680534], [82.26125336, 16.58708382], [82.26152802, 16.58708191], [82.26152802, 16.58736038], [82.26180267, 16.58736038], [82.26180267, 16.58764267], [82.26235962, 16.58764267], [82.26235962, 16.58792114], [82.26264191, 16.58792114], [82.26264191, 16.58819962], [82.26291656, 16.58819389], [82.26291656, 16.58847046], [82.26319122, 16.58847046], [82.26319122, 16.58958054], [82.26374817, 16.58958054], [82.26374817, 16.58986282], [82.26403046, 16.58986282], [82.26403046, 16.59041977], [82.26430511, 16.59041595], [82.26430511, 16.59097481], [82.26457977, 16.5909729], [82.26457977, 16.59152985], [82.26486206, 16.59152794], [82.26486206, 16.59236145], [82.26513672, 16.59236145], [82.26513672, 16.59347153], [82.26541901, 16.59346962], [82.26541901, 16.59403038], [82.26569366, 16.59402847], [82.26569366, 16.59458351], [82.26597595, 16.5945797], [82.26597595, 16.59514046], [82.26625061, 16.59513855], [82.26625061, 16.59569359], [82.26652527, 16.59569359], [82.26652527, 16.59597206], [82.26763916, 16.59597015], [82.26763916, 16.59625053], [82.26875305, 16.59625053], [82.26875305, 16.59653091], [82.27069092, 16.59653091], [82.27069092, 16.59680748], [82.2729187, 16.59680557], [82.2729187, 16.59708405], [82.27485657, 16.59708023], [82.27485657, 16.59736824], [82.27540588, 16.59736824], [82.27540588, 16.59763908], [82.27625275, 16.59763908], [82.27625275, 16.59791756], [82.27735901, 16.59791756], [82.27735901, 16.59819412], [82.27819824, 16.59819412], [82.27819824, 16.5984726], [82.27874756, 16.59847069], [82.27874756, 16.59874916], [82.27986145, 16.59874916], [82.27986145, 16.59903145], [82.2804184, 16.59903145], [82.2804184, 16.59931183], [82.28069305, 16.59930611], [82.28069305, 16.59958267], [82.28124237, 16.59958076], [82.28124237, 16.59985924], [82.28235626, 16.59985924], [82.28235626, 16.60014153], [82.28347015, 16.60014153], [82.28347015, 16.60042953], [82.28569794, 16.60042953], [82.28569794, 16.60014153], [82.28736877, 16.60014153], [82.28736877, 16.60042953], [82.2876358, 16.60041618], [82.2876358, 16.60069466], [82.28778076, 16.60069466], [82.28874969, 16.60069466], [82.28874969, 16.60097122], [82.28930664, 16.60096931], [82.28930664, 16.6012516], [82.29013824, 16.6012516], [82.29013824, 16.60153008], [82.29069519, 16.60152817], [82.29069519, 16.60180473], [82.29152679, 16.60180473], [82.29152679, 16.6020813], [82.29208374, 16.6020813], [82.29208374, 16.60236359], [82.29264069, 16.60235977], [82.29264069, 16.60264015], [82.29402924, 16.60264015], [82.29402924, 16.60235977], [82.29458618, 16.60236359], [82.29458618, 16.60180473], [82.29486084, 16.60180473], [82.29486084, 16.6012516], [82.29514313, 16.6012516], [82.2951355, 16.60069466], [82.29541779, 16.60069466], [82.29541779, 16.59902763], [82.29569244, 16.59903145], [82.29569244, 16.59874916], [82.2959671, 16.59874916], [82.2959671, 16.59847069], [82.29652405, 16.5984726], [82.29652405, 16.59819412], [82.29680634, 16.59819412], [82.29680634, 16.59791756], [82.29708099, 16.59791756], [82.29708099, 16.59736824], [82.29736328, 16.59736824], [82.29736328, 16.59680748], [82.29763794, 16.59680748], [82.29763794, 16.59653091], [82.29792023, 16.59653091], [82.29792023, 16.59568977], [82.29819489, 16.59569359], [82.29819489, 16.59486198], [82.29846954, 16.59486198], [82.29846954, 16.59402847], [82.29875183, 16.59403038], [82.29875183, 16.59346962], [82.29902649, 16.59347153], [82.29902649, 16.59308815], [82.29902649, 16.59263802], [82.29930878, 16.59263992], [82.29930878, 16.59181023], [82.29957581, 16.59181023], [82.29957581, 16.59041977], [82.29930878, 16.59041977], [82.29930878, 16.58930969], [82.29902649, 16.58930969], [82.29902649, 16.58708191], [82.29875183, 16.58708382], [82.29875183, 16.58680534], [82.29846954, 16.58681107], [82.29846954, 16.5862484], [82.29818726, 16.5862484], [82.29818726, 16.58596992], [82.29763794, 16.58597183], [82.29763794, 16.58569527], [82.29736328, 16.58569908], [82.29736328, 16.58346939], [82.29708099, 16.5834713], [82.29708099, 16.58319473], [82.29680634, 16.58319473], [82.29680634, 16.58291626], [82.29651642, 16.58291817], [82.29651642, 16.58263969], [82.29624176, 16.58263969], [82.29624176, 16.58236122], [82.29569244, 16.58236122], [82.29569244, 16.58208084], [82.29541779, 16.58208275], [82.29541779, 16.58180618], [82.29514313, 16.58180809], [82.29514313, 16.58152962], [82.29486084, 16.58152962], [82.29486084, 16.58097076], [82.29458618, 16.58097267], [82.29458618, 16.58080292], [82.29458618, 16.5806942], [82.29430389, 16.5806942], [82.29430389, 16.57986069], [82.29402924, 16.57986069], [82.29402924, 16.57929993], [82.29374695, 16.57930565], [82.29374695, 16.57902718], [82.29402924, 16.57903099], [82.29402924, 16.57875061], [82.29374695, 16.57875061], [82.29374695, 16.57736015], [82.29347229, 16.57736206], [82.29347229, 16.57680511], [82.29319763, 16.57681084], [82.29319763, 16.57653046], [82.29292297, 16.57653046], [82.29292297, 16.57625961], [82.29264069, 16.57625961], [82.29264069, 16.57570076], [82.2923584, 16.57570076], [82.2923584, 16.57542038], [82.29207611, 16.57542038], [82.29207611, 16.57485962], [82.29125214, 16.57485962], [82.29125214, 16.57458115], [82.29096985, 16.57458115], [82.29096985, 16.57402992], [82.29070282, 16.57403183], [82.29070282, 16.57346916], [82.2904129, 16.57347107], [82.2904129, 16.5731945], [82.29013824, 16.57320023], [82.29013824, 16.57264137], [82.28985596, 16.57264137], [82.28985596, 16.57208061], [82.2895813, 16.57208252], [82.2895813, 16.57125092], [82.28930664, 16.57125092], [82.28930664, 16.57097054], [82.28902435, 16.57097244], [82.28902435, 16.57069397], [82.28847504, 16.57069397], [82.28847504, 16.5704174], [82.28819275, 16.57042122], [82.28819275, 16.57014084], [82.28736115, 16.57013893], [82.28736115, 16.57069397], [82.28708649, 16.57069016], [82.28708649, 16.57125092], [82.28679657, 16.57125092], [82.28679657, 16.57152748], [82.28652954, 16.57152748], [82.28652954, 16.57208252], [82.28624725, 16.57208061], [82.28624725, 16.57264137], [82.28457642, 16.57264137], [82.28457642, 16.57235909], [82.28291321, 16.57235909], [82.28291321, 16.57208061], [82.28152466, 16.57208252], [82.28152466, 16.57180595], [82.28069305, 16.57180977], [82.28069305, 16.57152748], [82.27874756, 16.57152748], [82.27874756, 16.57125092], [82.27791595, 16.57125092], [82.27791595, 16.57097054], [82.2776413, 16.57097244], [82.2776413, 16.57069397], [82.27735901, 16.57069397], [82.27735901, 16.5704174], [82.27680206, 16.57042122], [82.27680206, 16.57014084], [82.27597046, 16.57014084], [82.27597046, 16.56986046], [82.27540588, 16.56986046], [82.27540588, 16.56931114], [82.27485657, 16.56931114], [82.27485657, 16.56903076], [82.27430725, 16.56903076], [82.27430725, 16.56875038], [82.27401733, 16.56875038], [82.27401733, 16.56820107], [82.27375031, 16.56820107], [82.27375031, 16.56792068], [82.27348328, 16.56792068], [82.27348328, 16.5676403], [82.27319336, 16.5676403], [82.27319336, 16.56735992], [82.27263641, 16.56736183], [82.27263641, 16.56708336], [82.2720871, 16.56708336], [82.2720871, 16.56680679], [82.27153015, 16.56680679], [82.27153015, 16.56652832], [82.27097321, 16.56653023], [82.27097321, 16.56624985], [82.27041626, 16.56624985], [82.27041626, 16.56596947], [82.26985931, 16.56597137], [82.26985931, 16.56569481], [82.26958466, 16.56569481], [82.26958466, 16.56541634], [82.26930237, 16.56542015], [82.26930237, 16.56513977], [82.26847076, 16.56513977], [82.26847076, 16.56485939], [82.26819611, 16.5648613], [82.26819611, 16.56458473], [82.26791382, 16.56458473], [82.26791382, 16.56402779], [82.26847076, 16.56402969], [82.26847076, 16.56375122], [82.26875305, 16.56375122], [82.26875305, 16.56347275], [82.26958466, 16.56347466], [82.26958466, 16.56319427], [82.27069092, 16.56319427], [82.27069092, 16.5629158], [82.27097321, 16.56291962], [82.27097321, 16.56264114], [82.27124786, 16.56264114], [82.27124786, 16.56236267], [82.27153015, 16.56236267], [82.27153015, 16.56208038], [82.27180481, 16.5620842], [82.27180481, 16.56180573], [82.2720871, 16.56180954], [82.2720871, 16.56153107], [82.27236176, 16.56153107], [82.27236176, 16.56097031], [82.27263641, 16.56097031], [82.27263641, 16.56041718], [82.2729187, 16.5604229], [82.2729187, 16.5601387], [82.27348328, 16.5601387], [82.27348328, 16.55985832], [82.27458191, 16.55985832], [82.27458191, 16.5601387], [82.27485657, 16.5601387], [82.27485657, 16.5604229], [82.27597046, 16.5604229], [82.27597046, 16.5601387], [82.27902985, 16.5601387], [82.27902985, 16.5604229], [82.2793045, 16.56041718], [82.2793045, 16.56069374], [82.2804184, 16.56069374], [82.2804184, 16.56097031], [82.28069305, 16.56097031], [82.28069305, 16.56126022], [82.28098297, 16.56126022], [82.28098297, 16.56180954], [82.28125, 16.56180573], [82.28125, 16.5620842], [82.28180695, 16.56208038], [82.28180695, 16.56236267], [82.28235626, 16.56236267], [82.28235626, 16.56264114], [82.2831955, 16.56263924], [82.2831955, 16.56319427], [82.28375244, 16.56319427], [82.28375244, 16.5629158], [82.28457642, 16.56291962], [82.28457642, 16.56264114], [82.28652954, 16.56264114], [82.28652954, 16.56291962], [82.2868042, 16.5629158], [82.2868042, 16.56319427], [82.28736115, 16.56319427], [82.28736115, 16.56347466], [82.2876358, 16.56347275], [82.2876358, 16.56375122], [82.28819275, 16.56375122], [82.28819275, 16.56402969], [82.28851318, 16.56402969], [82.2904129, 16.56402969], [82.2904129, 16.56375122], [82.2923584, 16.56375122], [82.2923584, 16.56402969], [82.29264069, 16.56402969], [82.29264069, 16.56431961], [82.29402924, 16.56430626], [82.29402924, 16.56458473], [82.29430389, 16.56458473], [82.29430389, 16.5648613], [82.29486084, 16.56485939], [82.29486084, 16.56513977], [82.29514313, 16.56513977], [82.29514313, 16.56542015], [82.29569244, 16.56541634], [82.29569244, 16.56597137], [82.29541779, 16.56597137], [82.29541779, 16.56680679], [82.29736328, 16.56680679], [82.29736328, 16.56708336], [82.29792023, 16.56708336], [82.29792023, 16.56680679], [82.29819489, 16.56680679], [82.29819489, 16.56652832], [82.29875183, 16.56652832], [82.29875183, 16.56680679], [82.29902649, 16.56680107], [82.29902649, 16.5676403], [82.29957581, 16.5676403], [82.29957581, 16.56792068], [82.30042267, 16.56792068], [82.30042267, 16.56820107], [82.30097198, 16.56820107], [82.30097198, 16.56792068], [82.30179596, 16.56792068], [82.30179596, 16.56820107], [82.30208588, 16.56819534], [82.30208588, 16.56847191], [82.30263519, 16.56847191], [82.30263519, 16.56875038], [82.30291748, 16.56875038], [82.30291748, 16.56903076], [82.30319214, 16.56903076], [82.30319214, 16.56875038], [82.30596924, 16.56875038], [82.30596924, 16.56903076], [82.30708313, 16.56902695], [82.30708313, 16.56921005], [82.30708313, 16.57069397], [82.30680847, 16.57069397], [82.30680847, 16.57097244], [82.30652618, 16.57097054], [82.30652618, 16.57152748], [82.30680847, 16.57152748], [82.30680847, 16.57208252], [82.30652618, 16.57208061], [82.30652618, 16.57264137], [82.30625153, 16.57264137], [82.30625153, 16.57374954], [82.30596924, 16.57374954], [82.30596924, 16.57394028], [82.30596924, 16.57458115], [82.30652618, 16.57458115], [82.30652618, 16.57430649], [82.30708313, 16.57430077], [82.30708313, 16.57402992], [82.30764008, 16.57403183], [82.30764008, 16.57374954], [82.30847168, 16.57374954], [82.30847168, 16.57349014], [82.3086319, 16.57348442], [82.30902863, 16.57347107], [82.30902863, 16.57332039], [82.30902863, 16.57291603], [82.3095932, 16.57292175], [82.3095932, 16.57235909], [82.30986023, 16.57235909], [82.30986023, 16.57208061], [82.31014252, 16.57208252], [82.31014252, 16.57152748], [82.31041718, 16.57152748], [82.31041718, 16.57069016], [82.31069183, 16.57069397], [82.31069183, 16.5704174], [82.31096649, 16.57042122], [82.31096649, 16.56958008], [82.31069183, 16.56958389], [82.31069183, 16.56875038], [82.31041718, 16.56875038], [82.31041718, 16.56820107], [82.31014252, 16.56820107], [82.31014252, 16.56792068], [82.30986023, 16.56792068], [82.30986023, 16.5676403], [82.30847168, 16.56763077], [82.30847168, 16.56736183], [82.30791473, 16.56736183], [82.30791473, 16.56708336], [82.30708313, 16.56708336], [82.30708313, 16.56680679], [82.30596924, 16.56680679], [82.30596924, 16.56652832], [82.30541229, 16.56653023], [82.30541229, 16.56624985], [82.30486298, 16.56624985], [82.30486298, 16.56596947], [82.30403137, 16.56597137], [82.30403137, 16.56569481], [82.30319214, 16.56569481], [82.30319214, 16.56541634], [82.30208588, 16.56542015], [82.30208588, 16.56513977], [82.30179596, 16.56513977], [82.30179596, 16.56485939], [82.30152893, 16.5648613], [82.30152893, 16.56458473], [82.30069733, 16.56458473], [82.30069733, 16.56430626], [82.30014038, 16.56431961], [82.30014038, 16.56402969], [82.29957581, 16.56402969], [82.29957581, 16.56375122], [82.29846954, 16.56375122], [82.29846954, 16.56347275], [82.29736328, 16.56347466], [82.29736328, 16.56319427], [82.29680634, 16.56319427], [82.29680634, 16.5629158], [82.29624176, 16.56291962], [82.29624176, 16.56264114], [82.2959671, 16.56264114], [82.2959671, 16.56236267], [82.29569244, 16.56236267], [82.29569244, 16.56208038], [82.29541779, 16.5620842], [82.29541779, 16.56180573], [82.29486084, 16.56180954], [82.29486084, 16.56153107], [82.29458618, 16.56153107], [82.29458618, 16.56126022], [82.29319763, 16.56126022], [82.29319763, 16.56097031], [82.29264069, 16.56097031], [82.29264069, 16.56069374], [82.2923584, 16.56069374], [82.2923584, 16.56041718], [82.29207611, 16.5604229], [82.29207611, 16.5601387], [82.29152679, 16.5601387], [82.29152679, 16.55985832], [82.29096985, 16.55985832], [82.29096985, 16.55957985], [82.29069519, 16.55958366], [82.29069519, 16.55930519], [82.28985596, 16.55931091], [82.28985596, 16.55903053], [82.28930664, 16.55903053], [82.28930664, 16.55874825], [82.28874969, 16.55874825], [82.28874969, 16.55846977], [82.28791809, 16.55847168], [82.28791809, 16.55819511], [82.28736877, 16.55820084], [82.28736877, 16.55792046], [82.28695679, 16.55792046], [82.28679657, 16.55792046], [82.28678894, 16.55770874], [82.28652954, 16.55763817], [82.28652954, 16.5574894], [82.28652954, 16.5573616], [82.28617859, 16.5573616], [82.28569794, 16.5573616], [82.28569794, 16.55708313], [82.28544617, 16.55708313], [82.2840271, 16.55708313], [82.2840271, 16.55680466], [82.2831955, 16.55680466], [82.2831955, 16.55652618], [82.28235626, 16.55652809], [82.28235626, 16.55624962], [82.2804184, 16.55624962], [82.2804184, 16.55597115], [82.27819824, 16.55597305], [82.27819061, 16.55569458], [82.27791595, 16.55569458], [82.27791595, 16.55541611], [82.2776413, 16.55541992], [82.2776413, 16.55513], [82.27735901, 16.55513954], [82.27735901, 16.55486107], [82.27485657, 16.55486107], [82.27485657, 16.55458069], [82.27402496, 16.5545826], [82.27402496, 16.55430794], [82.27375031, 16.55430984], [82.27375031, 16.55402946], [82.27319336, 16.55402946], [82.27319336, 16.55375099], [82.27153015, 16.55375099], [82.27153015, 16.55347061], [82.27124786, 16.55347252], [82.27124786, 16.55319595], [82.27041626, 16.55319595], [82.27041626, 16.55291748], [82.26902771, 16.55291939], [82.26902771, 16.55264091], [82.26819611, 16.55264091], [82.26819611, 16.55236053], [82.26652527, 16.55236053], [82.26652527, 16.55208588], [82.26541901, 16.55208588], [82.26541901, 16.5518055], [82.26457977, 16.55181122], [82.26457977, 16.55153084], [82.26403046, 16.55153084], [82.26403046, 16.55125046], [82.26319122, 16.55125046], [82.26319122, 16.55097389], [82.26208496, 16.55097389], [82.26208496, 16.55069542], [82.26040649, 16.5506897], [82.26041412, 16.55041695], [82.25985718, 16.55042076], [82.25985718, 16.55014038], [82.2590332, 16.55014038], [82.2590332, 16.54986191], [82.25819397, 16.54986382], [82.25819397, 16.54958344], [82.25680542, 16.54958344], [82.25680542, 16.54930305], [82.25624847, 16.54932022], [82.25624847, 16.5490303], [82.25541687, 16.5490303], [82.25541687, 16.54875183], [82.25458527, 16.54875183], [82.25458527, 16.54847336], [82.25421143, 16.54847336], [82.25375366, 16.54847336], [82.25375366, 16.54819489], [82.25291443, 16.54819489], [82.25291443, 16.54791641], [82.25208282, 16.54792023], [82.25208282, 16.54764175], [82.25125885, 16.54764175], [82.25125885, 16.54735947], [82.24986267, 16.54735947], [82.24986267, 16.54680634], [82.24931335, 16.54681015], [82.24931335, 16.54653168], [82.24874878, 16.54653168], [82.24874878, 16.54626274], [82.24736023, 16.54626274], [82.24736023, 16.54597092], [82.24652863, 16.54597282], [82.24652863, 16.54569435], [82.24597168, 16.54569435], [82.24597168, 16.54541588], [82.2454071, 16.5454216], [82.2454071, 16.54513931], [82.24430847, 16.54513931], [82.24430847, 16.54486084], [82.24375153, 16.54486084], [82.24375153, 16.54458046], [82.24263763, 16.54458427], [82.24263763, 16.5443058], [82.24180603, 16.54430962], [82.24180603, 16.54403114], [82.24124908, 16.54403114], [82.24124908, 16.54375076], [82.24069214, 16.54375076], [82.24069214, 16.54347038], [82.23986053, 16.54347229], [82.23986053, 16.54319382], [82.23958588, 16.54319382], [82.23958588, 16.54291725], [82.23874664, 16.54292107], [82.23874664, 16.54264069], [82.23819733, 16.54264069], [82.23819733, 16.54236031], [82.23792267, 16.54236031], [82.23792267, 16.54264069], [82.23764038, 16.54264069], [82.23764038, 16.54236031], [82.23735809, 16.54236031], [82.23735809, 16.54207993], [82.23652649, 16.54208374], [82.23652649, 16.54180527], [82.23568726, 16.54181099], [82.23568726, 16.54153061], [82.23458099, 16.54153061], [82.23458099, 16.54125023], [82.23401642, 16.54125023], [82.23401642, 16.54096985], [82.23347473, 16.54097176], [82.23347473, 16.54069519], [82.23264313, 16.54070091], [82.23264313, 16.54042053], [82.23208618, 16.54042053], [82.23208618, 16.54013062], [82.23124695, 16.54013824], [82.23124695, 16.53986168], [82.23097229, 16.53986168], [82.23097229, 16.53958321], [82.22930908, 16.53958321], [82.22930908, 16.53930473], [82.22875214, 16.53930473], [82.22875214, 16.53902817], [82.22820282, 16.53903008], [82.22820282, 16.53874969], [82.2279129, 16.53874969], [82.2279129, 16.53847122], [82.22763824, 16.53847313], [82.22763824, 16.53819466], [82.22736359, 16.53819466], [82.22736359, 16.53847313], [82.22680664, 16.53847313], [82.22680664, 16.53819466], [82.22624969, 16.53819466], [82.22624969, 16.53791618], [82.22541809, 16.53791618], [82.22541809, 16.53819466], [82.2251358, 16.53819466], [82.2251358, 16.53791618], [82.22429657, 16.53792], [82.22429657, 16.53763962], [82.22402954, 16.53763962], [82.22402954, 16.53736115], [82.22374725, 16.53736115], [82.22374725, 16.5370903], [82.22319794, 16.5370903], [82.22319794, 16.53680992], [82.2223587, 16.53680992], [82.2223587, 16.53652954], [82.2215271, 16.53652954], [82.2215271, 16.53625107], [82.22125244, 16.53625107], [82.22125244, 16.53569031], [82.22097015, 16.53569221], [82.22097015, 16.53541756], [82.2195816, 16.53541946], [82.2195816, 16.5351429], [82.21901703, 16.5351429], [82.21901703, 16.53486252], [82.21875, 16.53486252], [82.21875, 16.53458023], [82.21819305, 16.53458405], [82.21819305, 16.53430557], [82.21736145, 16.53430939], [82.21736145, 16.53403282], [82.21624756, 16.53403282], [82.21624756, 16.53375244], [82.21569824, 16.53375244], [82.21569061, 16.53346825], [82.21541595, 16.53347015], [82.21541595, 16.53319359], [82.2151413, 16.53319359], [82.2151413, 16.53291702], [82.21457672, 16.53292084], [82.21457672, 16.53263855], [82.21430206, 16.53263855], [82.21430206, 16.53292084], [82.21347046, 16.53292084], [82.21347046, 16.53263855], [82.21290588, 16.53263855], [82.21290588, 16.53235817], [82.21263885, 16.53236008], [82.21263885, 16.53208351], [82.2123642, 16.53208351], [82.2123642, 16.53180504], [82.21180725, 16.53181076], [82.21180725, 16.53152847], [82.21069336, 16.53152847], [82.21069336, 16.53124809], [82.2104187, 16.53124809], [82.2104187, 16.53096008], [82.20986176, 16.53097153], [82.20986176, 16.53069496], [82.20929718, 16.53070068], [82.20929718, 16.5304203], [82.20902252, 16.5304203], [82.20902252, 16.53013992], [82.20819092, 16.53013992], [82.20819092, 16.52985954], [82.2076416, 16.52986145], [82.2076416, 16.52958298], [82.20708466, 16.52958298], [82.20708466, 16.52902794], [82.20540619, 16.52902985], [82.20540619, 16.52874947], [82.20513916, 16.52874947], [82.20513916, 16.52847099], [82.2048645, 16.5284729], [82.2048645, 16.52819443], [82.20430756, 16.52819443], [82.20430756, 16.52791786], [82.20347595, 16.52791977], [82.20347595, 16.52763939], [82.20318604, 16.52763939], [82.20318604, 16.52736092], [82.20263672, 16.52736092], [82.20263672, 16.52708054], [82.20236206, 16.52708244], [82.20236206, 16.52680588], [82.20069122, 16.52680969], [82.20069122, 16.52653122], [82.20014954, 16.52653122], [82.20014954, 16.52625084], [82.19957733, 16.52625084], [82.19957733, 16.52542114], [82.19875336, 16.52542114], [82.19875336, 16.5251503], [82.19819641, 16.5251503], [82.19819641, 16.52486038], [82.19735718, 16.52486038], [82.19735718, 16.52458], [82.19680786, 16.52458572], [82.19680786, 16.52430534], [82.19596863, 16.52431107], [82.19596863, 16.52403069], [82.19541931, 16.52403069], [82.19541931, 16.52375031], [82.19486237, 16.52375031], [82.19486237, 16.52346992], [82.19403076, 16.52347374], [82.19403076, 16.52319527], [82.19374847, 16.5232029], [82.19374847, 16.52292061], [82.19291687, 16.52292061], [82.19291687, 16.52264023], [82.19235992, 16.52264023], [82.19235992, 16.52236176], [82.19180298, 16.52236366], [82.19180298, 16.52208138], [82.19124603, 16.52209282], [82.19124603, 16.5218029], [82.19041443, 16.52180481], [82.19041443, 16.52152824], [82.18985748, 16.52153015], [82.18985748, 16.52125168], [82.18930817, 16.52125168], [82.18930817, 16.52096939], [82.18875122, 16.52096939], [82.18875122, 16.52069473], [82.18819427, 16.52069473], [82.18819427, 16.52041626], [82.18763733, 16.52042007], [82.18763733, 16.5201416], [82.18708038, 16.5201416], [82.18708038, 16.51985931], [82.18653107, 16.51985931], [82.18653107, 16.51958084], [82.18624878, 16.51958275], [82.18624878, 16.51930618], [82.18596649, 16.5193119], [82.18596649, 16.51901817], [82.18541718, 16.51902771], [82.18541718, 16.51874924], [82.18514252, 16.51874924], [82.18514252, 16.51847076], [82.18402863, 16.51847267], [82.18402863, 16.5181942], [82.18319702, 16.5181942], [82.18319702, 16.51791763], [82.1829071, 16.51791763], [82.1829071, 16.51763916], [82.18208313, 16.51763916], [82.18208313, 16.51736069], [82.18152618, 16.51736069], [82.18152618, 16.51708031], [82.18096924, 16.51708412], [82.18096924, 16.51680565], [82.18068695, 16.51680946], [82.18068695, 16.51652908], [82.18013763, 16.51652908], [82.18013763, 16.51625061], [82.17986298, 16.51625061], [82.17986298, 16.51596069], [82.17930603, 16.51597214], [82.17930603, 16.51569366], [82.17874908, 16.51569366], [82.17874908, 16.51541519], [82.1784668, 16.51542091], [82.1784668, 16.51514053], [82.17791748, 16.51514053], [82.17791748, 16.51486015], [82.17736053, 16.51486206], [82.17736053, 16.51458359], [82.17708588, 16.51458359], [82.17708588, 16.51430511], [82.17679596, 16.51431084], [82.17679596, 16.51403046], [82.17652893, 16.51403046], [82.17652893, 16.51375008], [82.17597961, 16.51375008], [82.17597961, 16.51403046], [82.17514038, 16.51403046], [82.17514038, 16.51375008], [82.17457581, 16.51375008], [82.17457581, 16.5134697], [82.17430878, 16.5134716], [82.17430878, 16.51291656], [82.17402649, 16.51292038], [82.17402649, 16.51264], [82.17318726, 16.51264], [82.17318726, 16.51235962], [82.17263794, 16.51235962], [82.17263794, 16.51264], [82.17208099, 16.51264], [82.17208099, 16.51235962], [82.17152405, 16.51236153], [82.17152405, 16.51152802], [82.17124939, 16.51152992], [82.17124939, 16.51124954], [82.1709671, 16.51124954], [82.1709671, 16.51097107], [82.17069244, 16.51097488], [82.17069244, 16.5106945], [82.16986084, 16.5106945], [82.16986084, 16.51041603], [82.16929626, 16.51041985], [82.16929626, 16.51015091], [82.16847229, 16.51015091], [82.16847229, 16.5098629], [82.16819763, 16.5098629], [82.16819763, 16.50958061], [82.16764069, 16.50958061], [82.16764069, 16.50930595], [82.16707611, 16.50930977], [82.16707611, 16.50902939], [82.16652679, 16.50902939], [82.16652679, 16.50875282], [82.16596985, 16.50875282], [82.16596985, 16.50847054], [82.16569519, 16.50847054], [82.16569519, 16.50819206], [82.1654129, 16.50819206], [82.1654129, 16.5079174], [82.1645813, 16.50792122], [82.1645813, 16.50764275], [82.16401672, 16.50764275], [82.16401672, 16.50736237], [82.16347504, 16.50736237], [82.16347504, 16.50708389], [82.1626358, 16.50708389], [82.1626358, 16.50680542], [82.16236115, 16.50681114], [82.16236115, 16.50653076], [82.16208649, 16.50653076], [82.16208649, 16.50624847], [82.16124725, 16.50624847], [82.16124725, 16.50596809], [82.16014099, 16.50597191], [82.16014099, 16.50569534], [82.15957642, 16.50569916], [82.15957642, 16.50542068], [82.1590271, 16.50542068], [82.1590271, 16.5051384], [82.15838623, 16.5051384], [82.15820313, 16.5051384], [82.15820313, 16.50485992], [82.15791321, 16.50486183], [82.15791321, 16.50458336], [82.15763855, 16.50458336], [82.15763855, 16.50430489], [82.15680695, 16.50430489], [82.15680695, 16.50402832], [82.15625, 16.50402832], [82.15625, 16.50374985], [82.15569305, 16.50374985], [82.15569305, 16.50346947], [82.1543045, 16.50347137], [82.1543045, 16.50291634], [82.15402985, 16.50291824], [82.15402985, 16.50263977], [82.15319824, 16.50263977], [82.15319061, 16.50235939], [82.15291595, 16.5023613], [82.15291595, 16.50208282], [82.1526413, 16.50208282], [82.1526413, 16.50180626], [82.15207672, 16.50181007], [82.15207672, 16.50152969], [82.15180969, 16.50152969], [82.15180969, 16.50125122], [82.15125275, 16.50125122], [82.15125275, 16.50098038], [82.15040588, 16.50098038], [82.15040588, 16.50069046], [82.15013885, 16.50069427], [82.15013885, 16.5004158], [82.14930725, 16.50041962], [82.14930725, 16.50014114], [82.14848328, 16.50014114], [82.14848328, 16.49986076], [82.1479187, 16.49986076], [82.1479187, 16.49958038], [82.14653015, 16.4995842], [82.14653015, 16.49930573], [82.14597321, 16.49930954], [82.14597321, 16.49903107], [82.1451416, 16.49903107], [82.1451416, 16.49875069], [82.14457703, 16.49875069], [82.14457703, 16.49847031], [82.14430237, 16.49847221], [82.14430237, 16.49819565], [82.14375305, 16.49819565], [82.14375305, 16.4976387], [82.14235687, 16.49764061], [82.14235687, 16.49792099], [82.1415329, 16.49792099], [82.1415329, 16.49736023], [82.14125061, 16.49736023], [82.14125061, 16.49707985], [82.14097595, 16.49708366], [82.14097595, 16.49680519], [82.14068604, 16.49681091], [82.14068604, 16.49653053], [82.14041901, 16.49653053], [82.14041901, 16.49625015], [82.14013672, 16.49625015], [82.14013672, 16.49596977], [82.13931274, 16.49596977], [82.13931274, 16.49653053], [82.13903046, 16.49653053], [82.13903046, 16.49570084], [82.13846588, 16.49570084], [82.13846588, 16.49542046], [82.13819122, 16.49542046], [82.13819122, 16.49514008], [82.1368103, 16.49514008], [82.1368103, 16.49484825], [82.13652802, 16.4948597], [82.13652802, 16.49458122], [82.13625336, 16.49458122], [82.13625336, 16.49430466], [82.13569641, 16.49430466], [82.13569641, 16.49402809], [82.13513947, 16.49403191], [82.13513947, 16.49375153], [82.13402557, 16.49375153], [82.13402557, 16.49347115], [82.13346863, 16.49347115], [82.13346863, 16.49291611], [82.13291931, 16.49292183], [82.13291931, 16.49264145], [82.13236237, 16.49264145], [82.13236237, 16.49208069], [82.13208008, 16.4920826], [82.13208008, 16.49180603], [82.13168335, 16.49180603], [82.13014221, 16.49181175], [82.13014221, 16.49152756], [82.12985992, 16.49152756], [82.12985992, 16.49124908], [82.12930298, 16.49124908], [82.12930298, 16.49097061], [82.12902832, 16.49097252], [82.12902832, 16.49069405], [82.12819672, 16.49069405], [82.12819672, 16.49041748], [82.12708282, 16.49041748], [82.12708282, 16.49014091], [82.12680817, 16.49014091], [82.12680817, 16.48986053], [82.12652588, 16.48986053], [82.12652588, 16.48958015], [82.12569427, 16.48958397], [82.12569427, 16.4893055], [82.1248703, 16.48931122], [82.1248703, 16.48904037], [82.12458038, 16.48904037], [82.12458038, 16.48875046], [82.12403107, 16.48875046], [82.12403107, 16.48847008], [82.12374878, 16.48847198], [82.12374878, 16.48819542], [82.12264252, 16.4881897], [82.12264252, 16.48791695], [82.1220932, 16.48792076], [82.1220932, 16.48764038], [82.12124634, 16.48764038], [82.12124634, 16.48736], [82.12097168, 16.48736191], [82.12097168, 16.48708344], [82.12041473, 16.48708344], [82.12041473, 16.4865284], [82.12014008, 16.4865303], [82.12014008, 16.48598099], [82.11958313, 16.48598099], [82.11958313, 16.48569107], [82.11875153, 16.48569489], [82.11875153, 16.48541641], [82.11791992, 16.48541641], [82.11791992, 16.48569489], [82.11763763, 16.48569489], [82.11763763, 16.48541641], [82.11680603, 16.48542023], [82.11680603, 16.48513985], [82.11541748, 16.48513985], [82.11541748, 16.48624992], [82.11514282, 16.48624992], [82.11514282, 16.48681068], [82.11486053, 16.48680687], [82.11486053, 16.48708344], [82.11458588, 16.48707962], [82.11458588, 16.48764038], [82.11429596, 16.48764038], [82.11429596, 16.48792076], [82.11402893, 16.48791695], [82.11402893, 16.4881897], [82.11374664, 16.48819542], [82.11374664, 16.48847198], [82.11264038, 16.48847198], [82.11264038, 16.48819542], [82.11235809, 16.4881897], [82.11235809, 16.48763847], [82.11207581, 16.48764038], [82.11207581, 16.48736], [82.11235809, 16.48736191], [82.11235809, 16.48569489], [82.11264038, 16.48569489], [82.11264038, 16.48541641], [82.1129303, 16.48542023], [82.1129303, 16.48485947], [82.11319733, 16.48486137], [82.11319733, 16.48458481], [82.11347198, 16.48458481], [82.11347198, 16.48430634], [82.11402893, 16.48431015], [82.11402893, 16.48374939], [82.11374664, 16.48374939], [82.11374664, 16.48347282], [82.11347198, 16.48347473], [82.11347198, 16.48319435], [82.11291504, 16.48319435], [82.11291504, 16.48291588], [82.11235809, 16.48291588], [82.11235809, 16.48263931], [82.11207581, 16.48264122], [82.11207581, 16.48236275], [82.11152649, 16.48236275], [82.11152649, 16.48208046], [82.11096954, 16.48208427], [82.11096954, 16.4818058], [82.11042023, 16.48180962], [82.11042023, 16.48153114], [82.10986328, 16.48153114], [82.10986328, 16.48125267], [82.10957336, 16.48125267], [82.10957336, 16.48097038], [82.10902405, 16.48097038], [82.10902405, 16.48069382], [82.10847473, 16.48069382], [82.10847473, 16.48041725], [82.10791779, 16.48042107], [82.10791779, 16.48014259], [82.10736084, 16.48014259], [82.10736084, 16.47985077], [82.10680389, 16.4798584], [82.10680389, 16.47958374], [82.10624695, 16.47958374], [82.10624695, 16.47930527], [82.10542297, 16.47930908], [82.10542297, 16.47903061], [82.1048584, 16.47903061], [82.1048584, 16.47874832], [82.10402679, 16.47874832], [82.10402679, 16.47846985], [82.10346985, 16.47847176], [82.10346985, 16.47819519], [82.10263824, 16.47820091], [82.10263824, 16.47792053], [82.1020813, 16.47792053], [82.1020813, 16.47763824], [82.10124969, 16.47763824], [82.10124969, 16.47735977], [82.10069275, 16.47736168], [82.10069275, 16.47708321], [82.10041809, 16.47708321], [82.10041809, 16.47680473], [82.1001358, 16.47680473], [82.1001358, 16.47652626], [82.09958649, 16.47652817], [82.09958649, 16.47624969], [82.09902954, 16.47624969], [82.09902954, 16.47597122], [82.09874725, 16.47597313], [82.09874725, 16.47569466], [82.0984726, 16.47569466], [82.0984726, 16.47541618], [82.09792328, 16.47541809], [82.09792328, 16.47513962], [82.09707642, 16.47513962], [82.09707642, 16.47486115], [82.0965271, 16.47486115], [82.0965271, 16.47458076], [82.09597015, 16.47458267], [82.09597015, 16.47430611], [82.09541321, 16.47430992], [82.09541321, 16.47404099], [82.09456635, 16.47404099], [82.09456635, 16.47375107], [82.09430695, 16.47375107], [82.09430695, 16.47347069], [82.09375, 16.4734726], [82.09375, 16.47319412], [82.09319305, 16.47319412], [82.09319305, 16.47291756], [82.09236145, 16.47291946], [82.09236145, 16.47264099], [82.09152985, 16.47264099], [82.09152985, 16.47236061], [82.09124756, 16.47236061], [82.09124756, 16.47208023], [82.0909729, 16.47208595], [82.0909729, 16.47180557], [82.09041595, 16.47180939], [82.09041595, 16.47153091], [82.0901413, 16.47153091], [82.0901413, 16.47097015], [82.08875275, 16.47097206], [82.08875275, 16.47069359], [82.08847046, 16.47069359], [82.08847046, 16.47041702], [82.08790588, 16.47042084], [82.08790588, 16.47014046], [82.08735657, 16.47014046], [82.08735657, 16.46986008], [82.08680725, 16.46986389], [82.08680725, 16.46958351], [82.08652496, 16.46958351], [82.08652496, 16.46930504], [82.08598328, 16.46931076], [82.08598328, 16.46903038], [82.0854187, 16.46903038], [82.0854187, 16.46875191], [82.08429718, 16.46875191], [82.08429718, 16.46846962], [82.08374786, 16.46847343], [82.08374786, 16.46819496], [82.08319092, 16.46820068], [82.08319092, 16.46791077], [82.0826416, 16.46791649], [82.0826416, 16.46763802], [82.08180237, 16.46764183], [82.08180237, 16.46735954], [82.08152771, 16.46735954], [82.08152771, 16.46708107], [82.08097076, 16.46708107], [82.08097076, 16.46680641], [82.08013916, 16.46681023], [82.08013916, 16.46653175], [82.07958984, 16.46653175], [82.07958984, 16.46624947], [82.07875061, 16.46624947], [82.07875061, 16.46596909], [82.07847595, 16.4659729], [82.07847595, 16.46569443], [82.07791901, 16.46569443], [82.07791901, 16.46541595], [82.07736206, 16.46542168], [82.07736206, 16.46513748], [82.07680511, 16.46513748], [82.07680511, 16.46486092], [82.07653046, 16.46486092], [82.07653046, 16.46458244], [82.07624817, 16.46458244], [82.07624817, 16.46430588], [82.07596588, 16.46430969], [82.07596588, 16.46403122], [82.07541656, 16.46403122], [82.07541656, 16.46375084], [82.07514191, 16.46375084], [82.07514191, 16.46347046], [82.07347107, 16.46347237], [82.07347107, 16.46319389], [82.07291412, 16.46319389], [82.07291412, 16.46291733], [82.07263947, 16.46292114], [82.07263947, 16.46264076], [82.07235718, 16.46264076], [82.07235718, 16.46236038], [82.07180786, 16.46236038], [82.07180786, 16.46208], [82.07125092, 16.46208382], [82.07125092, 16.46180534], [82.07068634, 16.46181107], [82.07068634, 16.46125031], [82.06986237, 16.46125031], [82.06986237, 16.46096992], [82.06958008, 16.46097183], [82.06958008, 16.46069527], [82.06903076, 16.46070099], [82.06903076, 16.46042061], [82.06846619, 16.46042061], [82.06846619, 16.46014023], [82.06791687, 16.46014023], [82.06791687, 16.45985985], [82.06735992, 16.45986176], [82.06735992, 16.45958328], [82.06680298, 16.45958328], [82.06680298, 16.45930481], [82.06625366, 16.45930481], [82.06625366, 16.45902824], [82.06597137, 16.45903015], [82.06597137, 16.45874977], [82.06569672, 16.45874977], [82.06569672, 16.45846939], [82.06541443, 16.4584713], [82.06541443, 16.45819473], [82.06458282, 16.45819473], [82.06458282, 16.45791626], [82.06346893, 16.45792007], [82.06346893, 16.45763969], [82.06318665, 16.45763969], [82.06318665, 16.45736122], [82.06291962, 16.45736122], [82.06291962, 16.45708275], [82.06236267, 16.45708466], [82.06236267, 16.45680618], [82.06208038, 16.45681], [82.06208038, 16.45652962], [82.06151581, 16.45652962], [82.06151581, 16.45625114], [82.06096649, 16.45625114], [82.06096649, 16.45597267], [82.05986023, 16.45597267], [82.05986023, 16.4556942], [82.05958557, 16.4556942], [82.05958557, 16.45541763], [82.05930328, 16.45541954], [82.05930328, 16.45514107], [82.05902863, 16.45514107], [82.05902863, 16.45486259], [82.05845642, 16.45486259], [82.05845642, 16.45458031], [82.05791473, 16.45458412], [82.05791473, 16.45430565], [82.05764008, 16.45430946], [82.05764008, 16.4540329], [82.05708313, 16.4540329], [82.05708313, 16.45375252], [82.05680847, 16.45375252], [82.05680847, 16.45347023], [82.05569458, 16.45347023], [82.05569458, 16.45319366], [82.05486298, 16.45319366], [82.05486298, 16.4529171], [82.05430603, 16.45293045], [82.05430603, 16.45263863], [82.05403137, 16.45263863], [82.05403137, 16.45235825], [82.05347443, 16.45236015], [82.05347443, 16.45208359], [82.05291748, 16.45208359], [82.05291748, 16.45180511], [82.05265045, 16.45181084], [82.05265045, 16.45153046], [82.05208588, 16.45153046], [82.05208588, 16.45124817], [82.05179596, 16.45124817], [82.05179596, 16.4509697], [82.05124664, 16.4509716], [82.05124664, 16.45069504], [82.05069733, 16.45070076], [82.05069733, 16.45042038], [82.05014038, 16.45042038], [82.05014038, 16.45013809], [82.04875183, 16.45013809], [82.04875183, 16.44986916], [82.04818726, 16.44986916], [82.04818726, 16.44958115], [82.04792023, 16.44958305], [82.04792023, 16.44930649], [82.04763794, 16.4493103], [82.04763794, 16.44902992], [82.04736328, 16.44902992], [82.04736328, 16.44874954], [82.04680634, 16.44874954], [82.04680634, 16.44847107], [82.04652405, 16.44847298], [82.04652405, 16.4481945], [82.04624939, 16.4481945], [82.04624939, 16.44791794], [82.0459671, 16.44791985], [82.0459671, 16.44763947], [82.04486084, 16.44763947], [82.04486084, 16.44736099], [82.04429626, 16.44736099], [82.04429626, 16.44708061], [82.04374695, 16.44708252], [82.04374695, 16.44680405], [82.04345703, 16.44680977], [82.04345703, 16.44652939], [82.04125214, 16.44652939], [82.04125214, 16.44625092], [82.04096985, 16.44625092], [82.04096985, 16.44597054], [82.04013824, 16.44597054], [82.04013824, 16.44625092], [82.03874969, 16.44625092], [82.03874969, 16.44597054], [82.03819275, 16.44597244], [82.03819275, 16.44569588], [82.03736115, 16.44569588], [82.03736115, 16.4454174], [82.03708649, 16.44542122], [82.03708649, 16.44514084], [82.03679657, 16.44514084], [82.03679657, 16.44458008], [82.03652954, 16.44458008], [82.03652954, 16.44514084], [82.0359726, 16.44514084], [82.0359726, 16.44542122], [82.03514099, 16.44542122], [82.03514099, 16.44514084], [82.03291321, 16.44514084], [82.03291321, 16.44486046], [82.03263855, 16.44486046], [82.03263855, 16.44458008], [82.03236389, 16.4445858], [82.03236389, 16.44430542], [82.03180695, 16.44431114], [82.03180695, 16.44403076], [82.03151703, 16.44403076], [82.03151703, 16.44374275], [82.03125, 16.44375038], [82.03125, 16.44347382], [82.03097534, 16.44347382], [82.03097534, 16.44319534], [82.0304184, 16.44320107], [82.0304184, 16.44292068], [82.03013611, 16.44292068], [82.03013611, 16.4426403], [82.02986145, 16.4426403], [82.02986145, 16.44236183], [82.02958679, 16.44236374], [82.02958679, 16.44208336], [82.0293045, 16.44208336], [82.0293045, 16.44152832], [82.0276413, 16.44153023], [82.0276413, 16.44125175], [82.02735901, 16.44125175], [82.02735901, 16.44096947], [82.02708435, 16.44096947], [82.02708435, 16.43985939], [82.02735901, 16.43985939], [82.02735901, 16.43958282], [82.02819824, 16.43958282], [82.02819824, 16.43985939], [82.02874756, 16.43985939], [82.02874756, 16.44014168], [82.02902985, 16.44014168], [82.02902985, 16.44042015], [82.03013611, 16.44042015], [82.03013611, 16.44014168], [82.03098297, 16.44014168], [82.03097534, 16.43985939], [82.03152466, 16.43985939], [82.03152466, 16.43958282], [82.03097534, 16.43958282], [82.03097534, 16.43930626], [82.0304184, 16.43931007], [82.0304184, 16.4390316], [82.03013611, 16.4390316], [82.03013611, 16.43874931], [82.02986145, 16.43874931], [82.02986145, 16.43847084], [82.0293045, 16.43847275], [82.0293045, 16.43819427], [82.02902985, 16.43819427], [82.02902985, 16.4379158], [82.02848053, 16.43792915], [82.02848053, 16.43763924], [82.02791595, 16.43763924], [82.02791595, 16.43736076], [82.02735901, 16.43736076], [82.02735901, 16.43708038], [82.02708435, 16.4370842], [82.02708435, 16.43680573], [82.02680206, 16.43680954], [82.02680206, 16.43653107], [82.02597046, 16.43653107], [82.02597046, 16.43625069], [82.02513885, 16.43625069], [82.02513885, 16.43597031], [82.0248642, 16.43597221], [82.0248642, 16.43569374], [82.02458191, 16.43569374], [82.02458191, 16.43541527], [82.02430725, 16.43542099], [82.02430725, 16.43514061], [82.02401733, 16.43514061], [82.02401733, 16.43486977], [82.02319336, 16.43486977], [82.02319336, 16.43457985], [82.0229187, 16.43458366], [82.0229187, 16.43430519], [82.02124786, 16.43431091], [82.02124786, 16.43403053], [82.02097321, 16.43403053], [82.02097321, 16.43375015], [82.02069092, 16.43375015], [82.02069092, 16.43346977], [82.02041626, 16.43347168], [82.02041626, 16.43319511], [82.0201416, 16.43320084], [82.0201416, 16.43264008], [82.02041626, 16.43264008], [82.02041626, 16.43180084], [82.02097321, 16.43180466], [82.02097321, 16.43152809], [82.0201416, 16.43153], [82.0201416, 16.43124962], [82.01985931, 16.43124962], [82.01985931, 16.43153], [82.01930237, 16.43152809], [82.01930237, 16.43208313], [82.01902771, 16.43208313], [82.01902771, 16.4323616], [82.01847076, 16.4323616], [82.01847076, 16.43208313], [82.01763916, 16.43208313], [82.01763916, 16.43180466], [82.01652527, 16.43180466], [82.01652527, 16.43152809], [82.01597595, 16.43153], [82.01597595, 16.43124962], [82.01541901, 16.43124962], [82.01541901, 16.43097115], [82.01513672, 16.43097305], [82.01513672, 16.43069458], [82.01457977, 16.43069458], [82.01457977, 16.43041611], [82.01431274, 16.43041992], [82.01431274, 16.43013954], [82.01403046, 16.43013954], [82.01403046, 16.42986107], [82.01347351, 16.42986107], [82.01347351, 16.42958069], [82.01264191, 16.42958069], [82.01264191, 16.42930603], [82.01235962, 16.42930984], [82.01235962, 16.42902946], [82.01207733, 16.42902946], [82.01207733, 16.42873955], [82.01152802, 16.42874908], [82.01152802, 16.42847252], [82.01041412, 16.42847252], [82.01041412, 16.42819214], [82.00986481, 16.42819214], [82.00986481, 16.42791748], [82.00958252, 16.42791939], [82.00958252, 16.42764282], [82.0090332, 16.42764282], [82.0090332, 16.42736244], [82.00846863, 16.42736244], [82.00846863, 16.42708015], [82.00763702, 16.42708397], [82.00763702, 16.4268055], [82.00734711, 16.42681122], [82.00734711, 16.42653084], [82.00708008, 16.42653084], [82.00708008, 16.42624855], [82.00680542, 16.42624855], [82.00680542, 16.42597008], [82.00653076, 16.42597008], [82.00653076, 16.42569351], [82.00708008, 16.42569923], [82.00708008, 16.42513847], [82.00681305, 16.42513847], [82.00681305, 16.42431068], [82.00653076, 16.42431068], [82.00653076, 16.4240284], [82.00514221, 16.4240284], [82.00514221, 16.42513847], [82.00596619, 16.42513847], [82.00596619, 16.42569923], [82.00541687, 16.42569923], [82.00541687, 16.42542076], [82.00460052, 16.42542076], [82.00460052, 16.42513847], [82.00402832, 16.42513847], [82.00402832, 16.42485809], [82.00347137, 16.42486191], [82.00347137, 16.42458344], [82.00291443, 16.42458344], [82.00291443, 16.42430496], [82.00235748, 16.42431068], [82.00235748, 16.4240284], [82.00180817, 16.4240284], [82.00180817, 16.42374992], [82.00125122, 16.42374992], [82.00125122, 16.42346954], [82.00096893, 16.42347145], [82.00096893, 16.42319489], [82.00069427, 16.42319489], [82.00069427, 16.42291641], [82.00041962, 16.42292976], [82.00041962, 16.42263985], [81.99986267, 16.42263985], [81.99931335, 16.42263985], [81.99931335, 16.42235947], [81.99874878, 16.42236137], [81.99874878, 16.4220829], [81.99819183, 16.4220829], [81.99819183, 16.42180634], [81.99764252, 16.42181015], [81.99764252, 16.42152977], [81.9970932, 16.42152977], [81.9970932, 16.42124939], [81.99680328, 16.42124939], [81.99680328, 16.42097092], [81.99652863, 16.42097282], [81.99652863, 16.42069435], [81.99514008, 16.42069435], [81.99514008, 16.42041588], [81.99485779, 16.42041969], [81.99485779, 16.42014122], [81.99458313, 16.42014122], [81.99458313, 16.41986084], [81.99430847, 16.41986084], [81.99430847, 16.41957283], [81.99346924, 16.41958427], [81.99346924, 16.4193058], [81.99263763, 16.41930962], [81.99263763, 16.41903114], [81.99208069, 16.41903114], [81.99208069, 16.41875076], [81.99124908, 16.41875076], [81.99124908, 16.41847038], [81.99097443, 16.41847229], [81.99097443, 16.41819572], [81.99041748, 16.41819572], [81.99041748, 16.41791725], [81.98960114, 16.41792107], [81.98960114, 16.41764069], [81.98931122, 16.41764069], [81.98931122, 16.41736031], [81.98874664, 16.41736031], [81.98874664, 16.41707993], [81.98819733, 16.41708374], [81.98819733, 16.41680527], [81.98764038, 16.41680527], [81.98764038, 16.4165287], [81.98707581, 16.41653061], [81.98707581, 16.41625023], [81.98680878, 16.41625023], [81.98680878, 16.41596985], [81.98652649, 16.41597366], [81.98652649, 16.41569519], [81.98568726, 16.41570282], [81.98568726, 16.41542053], [81.98486328, 16.41542053], [81.98486328, 16.41514015], [81.98401642, 16.41514015], [81.98401642, 16.41486168], [81.98374939, 16.41486359], [81.98374939, 16.4145813], [81.98319244, 16.4145813], [81.98319244, 16.41430473], [81.9826355, 16.41430473], [81.9826355, 16.41402817], [81.98179626, 16.41403008], [81.98179626, 16.41376114], [81.98152924, 16.41376114], [81.98152924, 16.41346931], [81.98097229, 16.41347313], [81.98097229, 16.41319466], [81.98041534, 16.41319466], [81.98041534, 16.41291618], [81.98014069, 16.41292191], [81.98014069, 16.41264153], [81.9798584, 16.41264153], [81.9798584, 16.41235924], [81.97930908, 16.41235924], [81.97930908, 16.41208076], [81.97875214, 16.41208267], [81.97875214, 16.41180611], [81.97846985, 16.41181183], [81.97846985, 16.41152763], [81.9779129, 16.41152763], [81.9779129, 16.41124916], [81.97598267, 16.41124916], [81.97598267, 16.41097069], [81.97569275, 16.4109726], [81.97569275, 16.41069412], [81.9751358, 16.41069984], [81.9751358, 16.41041756], [81.97486115, 16.41041756], [81.97486115, 16.41013908], [81.97458649, 16.41013908], [81.97458649, 16.40986061], [81.97402954, 16.40986061], [81.97402954, 16.40958023], [81.97319794, 16.40958405], [81.97319794, 16.40930557], [81.97292328, 16.40930939], [81.97292328, 16.40903091], [81.9723587, 16.40903091], [81.9723587, 16.40875053], [81.97180176, 16.40875053], [81.97180176, 16.40847015], [81.97123718, 16.40847015], [81.97125244, 16.40875053], [81.9706955, 16.40875053], [81.9706955, 16.40847206], [81.97041321, 16.40847206], [81.97041321, 16.40819359], [81.97013855, 16.40819359], [81.97013855, 16.40791512], [81.96985626, 16.40792084], [81.96985626, 16.40763092], [81.96736145, 16.40763855], [81.96736145, 16.40736198], [81.96708679, 16.40736198], [81.96708679, 16.40708351], [81.9668045, 16.40708351], [81.9668045, 16.40680695], [81.96652985, 16.40681076], [81.96652985, 16.40653038], [81.96624756, 16.40653038], [81.96624756, 16.40625], [81.96569824, 16.40625], [81.96569061, 16.40596962], [81.96485901, 16.40597153], [81.96485901, 16.40569305], [81.96457672, 16.40570068], [81.96457672, 16.4054203], [81.96430206, 16.4054203], [81.96430206, 16.40513992], [81.9631958, 16.40513992], [81.9631958, 16.40485954], [81.96263885, 16.40486145], [81.96263885, 16.40458488], [81.96208191, 16.40458488], [81.96208191, 16.40430641], [81.96098328, 16.40431023], [81.96098328, 16.40402985], [81.96069336, 16.40402985], [81.96069336, 16.40374947], [81.9604187, 16.40374947], [81.9604187, 16.40402985], [81.9595871, 16.40402985], [81.9595871, 16.4034729], [81.95930481, 16.40347481], [81.95930481, 16.40319443], [81.95874786, 16.40319443], [81.95874786, 16.40291595], [81.95819092, 16.40291977], [81.95819092, 16.40263939], [81.9576416, 16.40263939], [81.9576416, 16.40236282], [81.95707703, 16.40236282], [81.95707703, 16.40208054], [81.95652771, 16.40208054], [81.95652771, 16.40180588], [81.95597076, 16.40182114], [81.95597076, 16.40153122], [81.95540619, 16.40153122], [81.95540619, 16.40125275], [81.95485687, 16.40125275], [81.95485687, 16.40097046], [81.95430756, 16.40097046], [81.95430756, 16.40069389], [81.95375061, 16.40070534], [81.95375061, 16.40042114], [81.95361328, 16.40042114], [81.95291901, 16.40042114], [81.95291901, 16.40014267], [81.95236206, 16.40014267], [81.95236206, 16.39985847], [81.95180511, 16.39985847], [81.95180511, 16.39958382], [81.95124817, 16.39958382], [81.95124817, 16.39930534], [81.95069122, 16.39930916], [81.95069122, 16.39903069], [81.95014191, 16.39903069], [81.95014191, 16.39876175], [81.94959259, 16.39876175], [81.94959259, 16.39846992], [81.94902802, 16.39847183], [81.94902802, 16.39819527], [81.94847107, 16.39819527], [81.94847107, 16.39847183], [81.94819641, 16.39847183], [81.94819641, 16.39819527], [81.94790649, 16.39819908], [81.94790649, 16.39792061], [81.94763947, 16.39792061], [81.94763947, 16.39763832], [81.94706726, 16.39763832], [81.94706726, 16.39735985], [81.94652557, 16.39736176], [81.94652557, 16.39708328], [81.94625092, 16.39708328], [81.94625092, 16.39680481], [81.94596863, 16.39680481], [81.94596863, 16.39652634], [81.94568634, 16.39652824], [81.94568634, 16.39624977], [81.94541931, 16.39624977], [81.94541931, 16.39596939], [81.94513702, 16.3959713], [81.94513702, 16.39569473], [81.94486237, 16.39569473], [81.94486237, 16.39541626], [81.94458008, 16.39541817], [81.94458008, 16.39513969], [81.94319153, 16.39513969], [81.94319153, 16.39541817], [81.94235992, 16.39541817], [81.94235992, 16.39513969], [81.94211578, 16.39513969], [81.94180298, 16.39513969], [81.94180298, 16.39486122], [81.94097137, 16.39486122], [81.94097137, 16.39458084], [81.93875122, 16.39458084], [81.93875122, 16.39486122], [81.93819427, 16.39486122], [81.9382019, 16.39513969], [81.93708038, 16.39513969], [81.93708038, 16.39486122], [81.93596649, 16.39486122], [81.93596649, 16.39458084], [81.93569183, 16.39458275], [81.93569183, 16.39430618], [81.9345932, 16.39431], [81.9345932, 16.39402962], [81.93402863, 16.39402962], [81.93402863, 16.39375114], [81.93264008, 16.39375114], [81.93264008, 16.39402962], [81.92958069, 16.39402962], [81.92958069, 16.39375114], [81.9284668, 16.39375114], [81.9284668, 16.39402962], [81.92736053, 16.39402962], [81.92736053, 16.39375114], [81.92457581, 16.39375114], [81.92457581, 16.39347076], [81.92319489, 16.39347267], [81.92319489, 16.3931942], [81.92292023, 16.3931942], [81.92292023, 16.39291763], [81.92263794, 16.39291954], [81.92263794, 16.39262962], [81.92180634, 16.39263916], [81.92180634, 16.39236069], [81.92124939, 16.39236069], [81.92124939, 16.39263916], [81.92069244, 16.39263916], [81.92069244, 16.39236069], [81.91958618, 16.39236069], [81.91958618, 16.39208031], [81.91930389, 16.39208412], [81.91930389, 16.39180565], [81.91792297, 16.39180946], [81.91792297, 16.39153099], [81.9154129, 16.39153099], [81.9154129, 16.39125061], [81.91402435, 16.39125061], [81.91402435, 16.39097214], [81.91291809, 16.39097214], [81.91291809, 16.3904171], [81.91208649, 16.39042091], [81.91208649, 16.39014053], [81.91095734, 16.39014053], [81.91095734, 16.39042091], [81.91042328, 16.39042091], [81.91042328, 16.39014053], [81.90930176, 16.39014053], [81.90930176, 16.38986015], [81.90736389, 16.38986206], [81.90736389, 16.38958359], [81.90651703, 16.38959122], [81.90651703, 16.38931084], [81.90569305, 16.38931084], [81.90569305, 16.38903046], [81.9054184, 16.38903046], [81.9054184, 16.38875008], [81.90458679, 16.38875008], [81.90458679, 16.38903046], [81.90374756, 16.38903046], [81.90374756, 16.38875008], [81.90291595, 16.38875008], [81.90291595, 16.38820076], [81.90125275, 16.38820076], [81.90125275, 16.38792038], [81.90013885, 16.38792038], [81.90013885, 16.38764191], [81.89736176, 16.38764191], [81.89736176, 16.38735962], [81.89680481, 16.38735962], [81.89680481, 16.38708115], [81.89597321, 16.38708115], [81.89597321, 16.38680649], [81.89457703, 16.38681984], [81.89457703, 16.38653183], [81.89402771, 16.38653183], [81.89402771, 16.38625145], [81.89292145, 16.38625145], [81.89292145, 16.38653183], [81.89235687, 16.38653183], [81.89235687, 16.38625145], [81.89152527, 16.38625145], [81.89152527, 16.38597107], [81.89097595, 16.38597107], [81.89097595, 16.3856945], [81.89041901, 16.3856945], [81.89041901, 16.38541603], [81.88903046, 16.38542175], [81.88903046, 16.38514137], [81.88819122, 16.38514137], [81.88819122, 16.38485909], [81.88735962, 16.38485909], [81.88735962, 16.38458061], [81.88625336, 16.38458252], [81.88625336, 16.38430595], [81.88540649, 16.38430977], [81.88540649, 16.38402748], [81.88375092, 16.38402748], [81.88375092, 16.38375092], [81.88318634, 16.38375092], [81.88318634, 16.38347054], [81.88236237, 16.38347244], [81.88236237, 16.38319397], [81.88180542, 16.38319397], [81.88180542, 16.3829174], [81.88069153, 16.38292122], [81.88069153, 16.38264084], [81.87902832, 16.38264084], [81.87902832, 16.38236046], [81.87819672, 16.38236046], [81.87819672, 16.38208389], [81.87791443, 16.38208389], [81.87791443, 16.38180542], [81.87735748, 16.38181114], [81.87735748, 16.38153076], [81.87652588, 16.38153076], [81.87652588, 16.38125038], [81.87513733, 16.38125038], [81.87513733, 16.38097], [81.87403107, 16.38097191], [81.87403107, 16.38069534], [81.87319183, 16.38069534], [81.87319183, 16.38041687], [81.87207794, 16.38042068], [81.87207794, 16.3801403], [81.87097168, 16.3801403], [81.87097168, 16.37985992], [81.87041473, 16.37986183], [81.87041473, 16.37958336], [81.86958313, 16.37958336], [81.86958313, 16.37930679], [81.86875153, 16.37930679], [81.86875153, 16.37902832], [81.86763763, 16.37903023], [81.86763763, 16.37874985], [81.86680603, 16.37874985], [81.86680603, 16.37846947], [81.86513519, 16.37847137], [81.86513519, 16.37819481], [81.86430359, 16.37819481], [81.86430359, 16.37791634], [81.86290741, 16.37792015], [81.86290741, 16.37765121], [81.86264038, 16.37765121], [81.86264038, 16.37735939], [81.86235809, 16.3773613], [81.86235809, 16.37708473], [81.86180878, 16.37708473], [81.86180878, 16.37680626], [81.86096954, 16.37681007], [81.86096954, 16.37652969], [81.86042023, 16.37652969], [81.86042023, 16.37625122], [81.85958099, 16.37625122], [81.85958099, 16.37597275], [81.85902405, 16.37597275], [81.85902405, 16.37569427], [81.85791779, 16.37569427], [81.85791779, 16.3754158], [81.85736084, 16.37541962], [81.85736084, 16.37514114], [81.85678864, 16.37514114], [81.85678864, 16.37486267], [81.85597229, 16.37486267], [81.85597229, 16.37458992], [81.85404205, 16.37458992], [81.85404205, 16.37430954], [81.85375214, 16.37430954], [81.85375214, 16.37403107], [81.85346985, 16.37403107], [81.85346985, 16.37347031], [81.85263824, 16.37347031], [81.85263824, 16.37319374], [81.85152435, 16.37319374], [81.85152435, 16.37291718], [81.85096741, 16.37291908], [81.85096741, 16.37264061], [81.8501358, 16.37264061], [81.8501358, 16.37235832], [81.84986115, 16.37235832], [81.84986115, 16.37207985], [81.84902954, 16.37208366], [81.84902954, 16.37180519], [81.8484726, 16.37181091], [81.8484726, 16.37153053], [81.84764099, 16.37153053], [81.84764099, 16.37124825], [81.84597015, 16.37124825], [81.84597015, 16.37096977], [81.8456955, 16.37097168], [81.8456955, 16.37069511], [81.84541321, 16.37070084], [81.84541321, 16.37042046], [81.84401703, 16.37042046], [81.84401703, 16.37013817], [81.84319305, 16.37013817], [81.84319305, 16.3698597], [81.84236145, 16.3698616], [81.84236145, 16.36958313], [81.8418045, 16.36958313], [81.8418045, 16.36930466], [81.84124756, 16.36930466], [81.84124756, 16.36902618], [81.8409729, 16.36902809], [81.8409729, 16.36874962], [81.8401413, 16.36874962], [81.8401413, 16.3684597], [81.83958435, 16.36847305], [81.83958435, 16.36819458], [81.8390274, 16.36819458], [81.8390274, 16.36791611], [81.8381958, 16.36791992], [81.8381958, 16.36763954], [81.83790588, 16.36763954], [81.83790588, 16.36736107], [81.83735657, 16.36736107], [81.83735657, 16.36708069], [81.83708191, 16.3670826], [81.83708191, 16.36680412], [81.83596802, 16.36680984], [81.83596802, 16.36652946], [81.83513641, 16.36652946], [81.83513641, 16.36625099], [81.8345871, 16.36625099], [81.8345871, 16.36597061], [81.83374786, 16.36597252], [81.83374786, 16.36569595], [81.83347321, 16.36569595], [81.83347321, 16.36541748], [81.83293152, 16.36541939], [81.83293152, 16.36514091], [81.83235931, 16.36514091], [81.83235931, 16.36486053], [81.83207703, 16.36486053], [81.83207703, 16.36458015], [81.83125305, 16.36458588], [81.83125305, 16.3643055], [81.83069611, 16.36431122], [81.83069611, 16.36403084], [81.83040619, 16.36403084], [81.83040619, 16.36375046], [81.83013916, 16.36375046], [81.83013916, 16.36347008], [81.82875061, 16.36347389], [81.82875061, 16.36319542], [81.82847595, 16.3631897], [81.82847595, 16.36291695], [81.82818604, 16.36292076], [81.82818604, 16.36264992], [81.82763672, 16.36264992], [81.82763672, 16.36236191], [81.82707977, 16.36236382], [81.82707977, 16.36208344], [81.82653046, 16.36208344], [81.82653046, 16.36180496], [81.82596588, 16.36181068], [81.82596588, 16.3615303], [81.82485962, 16.3615303], [81.82485962, 16.36181068], [81.82459259, 16.36181068], [81.82459259, 16.3615303], [81.82402802, 16.3615303], [81.82402802, 16.36125183], [81.82347107, 16.36125183], [81.82347107, 16.36096954], [81.82291412, 16.36096954], [81.82291412, 16.36069489], [81.82236481, 16.36069489], [81.82236481, 16.36041641], [81.82180786, 16.36042023], [81.82180786, 16.36014175], [81.8215332, 16.36014175], [81.8215332, 16.35985947], [81.82125092, 16.35985947], [81.82125092, 16.3595829], [81.82069397, 16.3595829], [81.82069397, 16.35930634], [81.82041931, 16.35931015], [81.82041931, 16.35903168], [81.81958008, 16.35903168], [81.81958008, 16.35874939], [81.81903076, 16.35874939], [81.81903076, 16.35847092], [81.81874847, 16.35847282], [81.81874847, 16.35819435], [81.81847382, 16.35819435], [81.81847382, 16.35791588], [81.81819153, 16.35791969], [81.81819153, 16.35764122], [81.81735992, 16.35764122], [81.81735992, 16.35736084], [81.81708527, 16.35736084], [81.81708527, 16.35708427], [81.81625366, 16.35708427], [81.81625366, 16.3568058], [81.8154068, 16.35680962], [81.8154068, 16.3565197], [81.81513977, 16.35652733], [81.81513977, 16.35625076], [81.81430817, 16.35625076], [81.81430817, 16.35597038], [81.81402588, 16.35597229], [81.81402588, 16.35569382], [81.81346893, 16.35569382], [81.81346893, 16.35541725], [81.81291962, 16.35542107], [81.81291962, 16.35514069], [81.81236267, 16.35514069], [81.81236267, 16.35486031], [81.81208038, 16.35486031], [81.81208038, 16.35457993], [81.81153107, 16.35458374], [81.81153107, 16.35430527], [81.81096649, 16.35431099], [81.81096649, 16.35403061], [81.81041718, 16.35403061], [81.81041718, 16.35375023], [81.80902863, 16.35375023], [81.80902863, 16.35346031], [81.80847168, 16.35347176], [81.80847168, 16.35319519], [81.80819702, 16.35320091], [81.80819702, 16.35292053], [81.80764008, 16.35292053], [81.80764008, 16.35264015], [81.80708313, 16.35264015], [81.80708313, 16.35235977], [81.80680847, 16.35236168], [81.80680847, 16.35208321], [81.80652618, 16.35208321], [81.80652618, 16.35180473], [81.80625153, 16.35180473], [81.80625153, 16.35152817], [81.80570221, 16.35153008], [81.80570221, 16.35124969], [81.80541992, 16.35124969], [81.80541992, 16.35097122], [81.80513763, 16.35097313], [81.80513763, 16.35069466], [81.80430603, 16.35069466], [81.80430603, 16.35041618], [81.80374908, 16.35042], [81.80374908, 16.35013962], [81.8034668, 16.35013962], [81.8034668, 16.34986115], [81.80291748, 16.34986115], [81.80291748, 16.34958458], [81.80208588, 16.34958458], [81.80208588, 16.34930611], [81.80152893, 16.34930992], [81.80152893, 16.34902954], [81.80124664, 16.34902954], [81.80124664, 16.34875107], [81.80069733, 16.34875107], [81.80069733, 16.3484726], [81.80014038, 16.3484726], [81.80014038, 16.34819412], [81.79985809, 16.34819412], [81.79985809, 16.34791756], [81.79930878, 16.34791946], [81.79930878, 16.3476429], [81.79875183, 16.3476429], [81.79875183, 16.34736252], [81.79792023, 16.34736252], [81.79792023, 16.34708023], [81.79736328, 16.34708405], [81.79736328, 16.34680557], [81.79679871, 16.34680939], [81.79679871, 16.34653282], [81.79650879, 16.34653282], [81.79650879, 16.34624863], [81.7959671, 16.34624863], [81.7959671, 16.34596825], [81.79569244, 16.34597015], [81.79569244, 16.34569359], [81.7951355, 16.34569359], [81.7951355, 16.34541893], [81.79458618, 16.34542084], [81.79458618, 16.34513855], [81.79402924, 16.34513855], [81.79402924, 16.34485817], [81.79347229, 16.34486008], [81.79347229, 16.34458351], [81.79291534, 16.34458351], [81.79291534, 16.34430504], [81.7923584, 16.34431076], [81.7923584, 16.34403038], [81.79207611, 16.34403038], [81.79207611, 16.34374809], [81.79180908, 16.34374809], [81.79180908, 16.34346962], [81.79125214, 16.34347153], [81.79125214, 16.34319496], [81.79070282, 16.34320068], [81.79070282, 16.3429203], [81.79013824, 16.3429203], [81.79013824, 16.34263992], [81.78985596, 16.34263992], [81.78985596, 16.34235954], [81.78930664, 16.34236145], [81.78930664, 16.34208298], [81.78874969, 16.34208298], [81.78874969, 16.34180641], [81.78819275, 16.34181023], [81.78819275, 16.34152031], [81.7876358, 16.34152794], [81.7876358, 16.34124947], [81.78736115, 16.34124947], [81.78736115, 16.34097099], [81.7868042, 16.3409729], [81.7868042, 16.34069443], [81.7859726, 16.34069443], [81.7859726, 16.34041405], [81.78514099, 16.34041977], [81.78514099, 16.34013939], [81.78456879, 16.34013939], [81.78456879, 16.33986092], [81.78430176, 16.33986092], [81.78430176, 16.33958054], [81.7840271, 16.33958244], [81.7840271, 16.33930588], [81.78375244, 16.33930969], [81.78375244, 16.33903122], [81.78347015, 16.33903122], [81.78347015, 16.33875084], [81.78291321, 16.33875084], [81.78291321, 16.33848], [81.7820816, 16.33848], [81.7820816, 16.33819008], [81.78180695, 16.3381958], [81.78180695, 16.33791733], [81.78098297, 16.33792114], [81.78098297, 16.33764076], [81.7804184, 16.33764076], [81.7804184, 16.33736038], [81.77986145, 16.33736038], [81.77986145, 16.33708], [81.7793045, 16.33708382], [81.7793045, 16.33680534], [81.7784729, 16.33681107], [81.7784729, 16.33653069], [81.77791595, 16.33653069], [81.77791595, 16.33625031], [81.7776413, 16.33625031], [81.7776413, 16.33597183], [81.77708435, 16.33597374], [81.77708435, 16.33569527], [81.7765274, 16.3357029], [81.7765274, 16.33542061], [81.77625275, 16.33542061], [81.77625275, 16.33514023], [81.77568817, 16.33514023], [81.77568817, 16.33486176], [81.77513885, 16.33486366], [81.77513885, 16.33458328], [81.77458191, 16.33458328], [81.77458191, 16.33430481], [81.77402496, 16.33430481], [81.77402496, 16.33402824], [81.7729187, 16.33403015], [81.7729187, 16.33375168], [81.77236176, 16.33375168], [81.77236176, 16.33346939], [81.7720871, 16.33346939], [81.7720871, 16.33319473], [81.77097321, 16.33319473], [81.77097321, 16.33291626], [81.7701416, 16.33292007], [81.7701416, 16.3326416], [81.76958466, 16.3326416], [81.76958466, 16.33235931], [81.76930237, 16.33235931], [81.76930237, 16.33208275], [81.76902771, 16.33208275], [81.76902771, 16.33180618], [81.76763916, 16.3318119], [81.76763916, 16.33152771], [81.76708221, 16.33152771], [81.76708221, 16.33124924], [81.76597595, 16.33124924], [81.76597595, 16.33097076], [81.76569366, 16.33097267], [81.76569366, 16.3306942], [81.76513672, 16.3306942], [81.76513672, 16.33041954], [81.76457977, 16.33041954], [81.76457977, 16.33013916], [81.76403046, 16.33013916], [81.76403046, 16.32986069], [81.76345825, 16.32986069], [81.76345825, 16.32958031], [81.76264191, 16.32958412], [81.76264191, 16.32930565], [81.76235962, 16.32930946], [81.76235962, 16.32903099], [81.76097107, 16.32903099], [81.76097107, 16.32875061], [81.76039886, 16.32875061], [81.76039886, 16.32847023], [81.75958252, 16.32847214], [81.75958252, 16.32819366], [81.75902557, 16.32819366], [81.75902557, 16.32791519], [81.75875092, 16.32792091], [81.75875092, 16.32764053], [81.75791931, 16.32764053], [81.75791931, 16.32736015], [81.75680542, 16.32736206], [81.75680542, 16.32708359], [81.75624847, 16.32708359], [81.75624847, 16.32680511], [81.75569153, 16.32681084], [81.75569153, 16.32653809], [81.75514221, 16.32653809], [81.75514221, 16.32625008], [81.75430298, 16.32625008], [81.75430298, 16.3259697], [81.75375366, 16.3259716], [81.75375366, 16.32569313], [81.75319672, 16.32570076], [81.75319672, 16.32542038], [81.75263977, 16.32542038], [81.75263977, 16.32514], [81.75125122, 16.32514], [81.75125122, 16.32485962], [81.75069427, 16.32486153], [81.75069427, 16.32458305], [81.75041962, 16.32458305], [81.75041962, 16.32430649], [81.75013733, 16.3243103], [81.75013733, 16.32402992], [81.74931335, 16.32402992], [81.74931335, 16.32374954], [81.74845886, 16.32374954], [81.74845886, 16.32348061], [81.74791718, 16.32348061], [81.74791718, 16.32319069], [81.74736023, 16.3231945], [81.74736023, 16.32291603], [81.7470932, 16.32291985], [81.7470932, 16.32263947], [81.74624634, 16.32263947], [81.74624634, 16.3223629], [81.74539948, 16.3223629], [81.74539948, 16.32208061], [81.74485779, 16.32208061], [81.74485779, 16.32180595], [81.74375153, 16.32180977], [81.74375153, 16.32152939], [81.74291992, 16.32152939], [81.74291992, 16.32125282], [81.74208069, 16.32125282], [81.74208069, 16.32097244], [81.74153137, 16.32097244], [81.74153137, 16.32069206], [81.74097443, 16.32069206], [81.74097443, 16.3204174], [81.74041748, 16.3204174], [81.74041748, 16.32014084], [81.73958588, 16.32014084], [81.73958588, 16.3204174], [81.73874664, 16.3204174], [81.73874664, 16.32069206], [81.73847198, 16.32069206], [81.73847198, 16.32014084], [81.73874664, 16.32014275], [81.73874664, 16.31957817], [81.73847198, 16.31958389], [81.73847198, 16.31930542], [81.73792267, 16.31930923], [81.73792267, 16.31903076], [81.73680878, 16.31903076], [81.73680878, 16.31874847], [81.73651886, 16.31874847], [81.73651886, 16.31846809], [81.73596954, 16.31847191], [81.73596954, 16.31819534], [81.73568726, 16.31819916], [81.73568726, 16.31792068], [81.73486328, 16.31792068], [81.73486328, 16.3176384], [81.73430634, 16.3176384], [81.73430634, 16.31735039], [81.73402405, 16.31736183], [81.73402405, 16.31708336], [81.73319244, 16.31708336], [81.73319244, 16.31624985], [81.73291779, 16.31624985], [81.73291779, 16.31569099], [81.7326355, 16.31569481], [81.7326355, 16.31541634], [81.73208618, 16.31542015], [81.73208618, 16.31513977], [81.73069763, 16.31513977], [81.73069763, 16.3148613], [81.72958374, 16.3148613], [81.72958374, 16.31458282], [81.72930908, 16.31458282], [81.72930908, 16.31430626], [81.72846985, 16.31431007], [81.72846985, 16.31402969], [81.7279129, 16.31402969], [81.7279129, 16.31375122], [81.72680664, 16.31375122], [81.72680664, 16.31347084], [81.72569275, 16.31347275], [81.72569275, 16.31319427], [81.72458649, 16.31319427], [81.72458649, 16.3129158], [81.72402954, 16.31291962], [81.72402954, 16.31264114], [81.7234726, 16.31264114], [81.7234726, 16.31236076], [81.72319794, 16.31236076], [81.72319794, 16.31208038], [81.72264099, 16.3120842], [81.72264099, 16.31180573], [81.7223587, 16.31180954], [81.7223587, 16.3115406], [81.72207642, 16.3115406], [81.72207642, 16.31125069], [81.72180939, 16.31125069], [81.72180176, 16.3115406], [81.72097015, 16.3115406], [81.72097015, 16.31068993], [81.7206955, 16.31069374], [81.7206955, 16.31041718], [81.72041321, 16.31042099], [81.72041321, 16.31014061], [81.71901703, 16.31014061], [81.71901703, 16.31042099], [81.71875, 16.31042099], [81.71875, 16.3115406], [81.71901703, 16.3115406], [81.71901703, 16.31180954], [81.71930695, 16.31180954], [81.71930695, 16.31236076], [81.7195816, 16.31236076], [81.7195816, 16.31264114], [81.72013855, 16.31264114], [81.72013855, 16.31291962], [81.71986389, 16.3129158], [81.71986389, 16.31319427], [81.71930695, 16.31319427], [81.71930695, 16.31347275], [81.71902466, 16.31347275], [81.71902466, 16.31458282], [81.71930695, 16.31458282], [81.71930695, 16.31597137], [81.7195816, 16.31597137], [81.7195816, 16.31685066], [81.7195816, 16.31708336], [81.71986389, 16.31708336], [81.71986389, 16.31736183], [81.72013855, 16.31735039], [81.72013855, 16.3176384], [81.72041321, 16.3176384], [81.72041321, 16.31792068], [81.7206955, 16.31791687], [81.7206955, 16.31847191], [81.72019958, 16.31846809], [81.72013855, 16.31874847], [81.7195816, 16.31874847], [81.7195816, 16.31903076], [81.71901703, 16.31903076], [81.71901703, 16.31930923], [81.71819305, 16.31930542], [81.71819305, 16.31958389], [81.71763611, 16.31957817], [81.71763611, 16.31986237], [81.71708679, 16.31986237], [81.71708679, 16.32014275], [81.71624756, 16.32014084], [81.71624756, 16.3204174], [81.7159729, 16.3204174], [81.7159729, 16.31986237], [81.71569824, 16.31986237], [81.71569061, 16.31957817], [81.71457672, 16.31957817], [81.71457672, 16.31986237], [81.71430206, 16.31986237], [81.71430206, 16.31957817], [81.71296692, 16.31958008], [81.71097565, 16.31958389], [81.71097565, 16.31986237], [81.71055603, 16.31986237], [81.7104187, 16.31986237], [81.7104187, 16.3204174], [81.71013641, 16.3204174], [81.71013641, 16.32069206], [81.7095871, 16.32069206], [81.7095871, 16.32097244], [81.70903015, 16.32097244], [81.70903015, 16.32125282], [81.70707703, 16.32125282], [81.70707703, 16.32152939], [81.70680237, 16.32152939], [81.70680237, 16.32180977], [81.70625305, 16.32180595], [81.70625305, 16.32208061], [81.70569611, 16.32208061], [81.70569611, 16.3223629], [81.70513916, 16.3223629], [81.70513916, 16.32263947], [81.70458221, 16.32263947], [81.70458221, 16.32291985], [81.70402527, 16.32291603], [81.70402527, 16.3231945], [81.70347595, 16.32319069], [81.70347595, 16.32348061], [81.70291901, 16.32348061], [81.70291901, 16.32374954], [81.70263672, 16.32374954], [81.70263672, 16.32402992], [81.70207977, 16.32402802], [81.70207977, 16.32458305], [81.70180511, 16.32458305], [81.70180511, 16.32486153], [81.70124817, 16.32485962], [81.70124817, 16.32514], [81.70069122, 16.32514], [81.70069122, 16.32542038], [81.69985962, 16.32542038], [81.69985962, 16.32570076], [81.69847107, 16.32569313], [81.69847107, 16.3259716], [81.69819641, 16.3259697], [81.69819641, 16.32653809], [81.69790649, 16.32653809], [81.69790649, 16.32681084], [81.69763947, 16.32680511], [81.69763947, 16.32708359], [81.69652557, 16.32708359], [81.69652557, 16.32736206], [81.69541931, 16.32736015], [81.69541931, 16.32764053], [81.69513702, 16.32764053], [81.69513702, 16.32792091], [81.69458008, 16.32791519], [81.69458008, 16.32819366], [81.69430542, 16.32819366], [81.69430542, 16.32847214], [81.69374847, 16.32847023], [81.69374847, 16.32875061], [81.6920929, 16.32875061], [81.6920929, 16.32903099], [81.69180298, 16.32903099], [81.69180298, 16.32930946], [81.69152832, 16.32930565], [81.69152832, 16.32958412], [81.69124603, 16.32958031], [81.69124603, 16.32986069], [81.6904068, 16.32986069], [81.6904068, 16.33013916], [81.69013977, 16.33013916], [81.69013977, 16.33041954], [81.68958282, 16.33041954], [81.68958282, 16.3306942], [81.68875122, 16.3306942], [81.68875122, 16.33097267], [81.68846893, 16.33097076], [81.68846893, 16.33124924], [81.68817902, 16.33124924], [81.68817902, 16.33152771], [81.68736267, 16.33152771], [81.68736267, 16.3318119], [81.68653107, 16.33180618], [81.68653107, 16.33208275], [81.68486023, 16.33208275], [81.68486023, 16.33235931], [81.68458557, 16.33235931], [81.6845932, 16.3326416], [81.68402863, 16.3326416], [81.68402863, 16.33292007], [81.68374634, 16.33292007], [81.68374634, 16.3326416], [81.68096924, 16.3326416], [81.68096924, 16.33234978], [81.68041992, 16.33235931], [81.68041992, 16.33208275], [81.67930603, 16.33208275], [81.67930603, 16.33180618], [81.67903137, 16.33180618], [81.67903137, 16.33208275], [81.67874908, 16.33208275], [81.67874908, 16.33180618], [81.67791748, 16.33180618], [81.67791748, 16.33208275], [81.67736053, 16.33208275], [81.67736053, 16.33235931], [81.67652893, 16.33234978], [81.67652893, 16.3326416], [81.67569733, 16.3326416], [81.67569733, 16.33292007], [81.67485809, 16.33291626], [81.67485809, 16.33319473], [81.67430878, 16.33319473], [81.67430878, 16.33346939], [81.67375183, 16.33346939], [81.67375183, 16.33375168], [81.67346954, 16.33375168], [81.67346954, 16.33346939], [81.66874695, 16.33346939], [81.66874695, 16.33375168], [81.66847229, 16.33375168], [81.66847229, 16.33346939], [81.66791534, 16.33346939], [81.66791534, 16.33375168], [81.6673584, 16.33375168], [81.6673584, 16.33346939], [81.66569519, 16.33346939], [81.66570282, 16.33375168], [81.66179657, 16.33375168], [81.66179657, 16.33346939], [81.66041565, 16.33346939], [81.66041565, 16.33319473], [81.66014099, 16.33319473], [81.66014099, 16.33346939], [81.65957642, 16.33346939], [81.65958405, 16.33375168], [81.65820313, 16.33375168], [81.65820313, 16.33403015], [81.65513611, 16.33402824], [81.65513611, 16.33430481], [81.65402985, 16.33430481], [81.65402985, 16.33458328], [81.6526413, 16.33458328], [81.6526413, 16.33430481], [81.65208435, 16.33430481], [81.65208435, 16.33402824], [81.6506958, 16.33402824], [81.6506958, 16.33430481], [81.65041351, 16.33430481], [81.65041351, 16.33458328], [81.64902496, 16.33458328], [81.64902496, 16.33430481], [81.6479187, 16.33430481], [81.6479187, 16.33458328], [81.64763641, 16.33458328], [81.64763641, 16.33486366], [81.64653015, 16.33486366], [81.64653015, 16.33458328], [81.6451416, 16.33458328], [81.6451416, 16.33486366], [81.64457703, 16.33486176], [81.64457703, 16.33514023], [81.64097595, 16.33514023], [81.64097595, 16.33542061], [81.63903046, 16.33542061], [81.63903046, 16.3357029], [81.63791656, 16.33569527], [81.63791656, 16.33597374], [81.63652802, 16.33597183], [81.63652802, 16.33625031], [81.63569641, 16.33625031], [81.63569641, 16.33597183], [81.63485718, 16.33597183], [81.63486481, 16.33625031], [81.6340332, 16.33625031], [81.6340332, 16.33653069], [81.63263702, 16.33653069], [81.63263702, 16.33625031], [81.63181305, 16.33625031], [81.63181305, 16.33653069], [81.6312561, 16.33653069], [81.6312561, 16.33681107], [81.62791443, 16.33680534], [81.62791443, 16.33708382], [81.62763977, 16.33708], [81.62763977, 16.33736038], [81.62625122, 16.33736038], [81.62625122, 16.33708], [81.62458038, 16.33708], [81.62458038, 16.33736038], [81.62374878, 16.33736038], [81.62374878, 16.33764076], [81.62319183, 16.33764076], [81.62319183, 16.33792114], [81.62291718, 16.33792114], [81.62291718, 16.33764076], [81.62014008, 16.33764076], [81.62014008, 16.33792114], [81.61985779, 16.33791733], [81.61985779, 16.3381958], [81.61902618, 16.3381958], [81.61902618, 16.33791733], [81.61846924, 16.33791733], [81.61846924, 16.3381958], [81.61708069, 16.33819008], [81.61708069, 16.33848], [81.61624908, 16.33848], [81.61624908, 16.33875084], [81.61569214, 16.33875084], [81.61569214, 16.33903122], [81.61541748, 16.33903122], [81.61541748, 16.33930969], [81.61458588, 16.33930969], [81.61458588, 16.33903122], [81.6131897, 16.33903122], [81.6131897, 16.33930969], [81.61069489, 16.33930588], [81.61069489, 16.33958244], [81.60958099, 16.33958054], [81.60958099, 16.33986092], [81.6084671, 16.33986092], [81.60847473, 16.34013939], [81.6076355, 16.34013939], [81.6076355, 16.33986092], [81.60652924, 16.33986092], [81.60652924, 16.34013939], [81.6048584, 16.34013939], [81.6048584, 16.34041977], [81.6029129, 16.34041405], [81.6029129, 16.34069443], [81.6001358, 16.34069443], [81.6001358, 16.3409729], [81.59764099, 16.34097099], [81.59764099, 16.34124947], [81.59708405, 16.34124947], [81.59708405, 16.34152794], [81.59401703, 16.34152031], [81.59401703, 16.34181023], [81.59347534, 16.34180641], [81.59347534, 16.34208298], [81.5901413, 16.34208298], [81.5901413, 16.34236145], [81.5881958, 16.34235954], [81.5881958, 16.34263992], [81.58651733, 16.34263992], [81.58651733, 16.3429203], [81.5854187, 16.3429203], [81.5854187, 16.34320068], [81.58430481, 16.34319496], [81.58430481, 16.34347153], [81.58347321, 16.34346962], [81.58347321, 16.34374809], [81.5826416, 16.34374809], [81.5826416, 16.34346962], [81.58013916, 16.34347153], [81.58014679, 16.34374809], [81.57958221, 16.34374809], [81.57958221, 16.34403038], [81.57818604, 16.34403038], [81.57818604, 16.34374809], [81.57707977, 16.34374809], [81.57707977, 16.34403038], [81.57457733, 16.34403038], [81.57457733, 16.34431076], [81.57375336, 16.34430504], [81.57375336, 16.34458351], [81.57291412, 16.34458351], [81.57291412, 16.34430504], [81.57208252, 16.34430504], [81.57208252, 16.34458351], [81.56874847, 16.34458351], [81.56874847, 16.34486008], [81.56680298, 16.34485817], [81.56680298, 16.34513855], [81.56652832, 16.34513855], [81.56652832, 16.34542084], [81.56597137, 16.34542084], [81.56597137, 16.34513855], [81.56569672, 16.34513855], [81.56569672, 16.34542084], [81.56430817, 16.34542084], [81.56430817, 16.34513855], [81.56318665, 16.34513855], [81.56318665, 16.34542084], [81.56097412, 16.34541893], [81.56096649, 16.34558105], [81.56097412, 16.34569359], [81.56014252, 16.34569359], [81.56014252, 16.34597015], [81.55958557, 16.34597015], [81.55958557, 16.34624863], [81.55903625, 16.34624863], [81.55903625, 16.34653282], [81.55874634, 16.3465271], [81.55874634, 16.34708405], [81.55903625, 16.34708023], [81.55903625, 16.34791946], [81.5595932, 16.34791946], [81.5595932, 16.34875107], [81.55986023, 16.34875107], [81.55986023, 16.34902954], [81.56014252, 16.34902763], [81.56014252, 16.34958458], [81.55986023, 16.34958458], [81.55986023, 16.35069466], [81.5595932, 16.35069084], [81.5595932, 16.35153008], [81.55486298, 16.35153008], [81.55486298, 16.35124969], [81.55264282, 16.35124969], [81.55264282, 16.35153008], [81.55180359, 16.35152817], [81.55180359, 16.35180473], [81.55124664, 16.35180473], [81.55124664, 16.35208321], [81.55097198, 16.35208321], [81.55097198, 16.35236168], [81.55069733, 16.35235977], [81.55069733, 16.35264015], [81.55042267, 16.35264015], [81.55042267, 16.35320091], [81.54846954, 16.35319519], [81.54846954, 16.35347176], [81.54792023, 16.35346031], [81.54792023, 16.35403061], [81.54763794, 16.35403061], [81.54763794, 16.35431099], [81.54708099, 16.35431099], [81.54708099, 16.35486031], [81.54651642, 16.35486031], [81.54651642, 16.35514069], [81.5459671, 16.35514069], [81.5459671, 16.35542107], [81.54569244, 16.35541725], [81.54569244, 16.35569382], [81.54541779, 16.35569382], [81.54541779, 16.35597229], [81.5451355, 16.35597229], [81.54514313, 16.35625076], [81.54486084, 16.35625076], [81.54486084, 16.35652733], [81.54458618, 16.3565197], [81.54458618, 16.35680962], [81.54430389, 16.3568058], [81.54430389, 16.35708427], [81.54402924, 16.35708427], [81.54403687, 16.35736084], [81.54347229, 16.35736084], [81.54347229, 16.35764122], [81.54319763, 16.35764122], [81.54319763, 16.35791969], [81.54291534, 16.35791588], [81.54291534, 16.35819435], [81.54180908, 16.35819435], [81.54180908, 16.35847282], [81.54125214, 16.35847092], [81.54125214, 16.35874939], [81.54096985, 16.35874939], [81.54096985, 16.35903168], [81.53791046, 16.35903168], [81.53791046, 16.35874939], [81.53708649, 16.35874939], [81.53708649, 16.35903168], [81.53624725, 16.35903168], [81.53624725, 16.35874939], [81.53457642, 16.35874939], [81.53457642, 16.35847092], [81.5340271, 16.35847282], [81.5340271, 16.35819435], [81.5331955, 16.35819435], [81.5331955, 16.35791588], [81.53291321, 16.35791969], [81.53291321, 16.35764122], [81.53263855, 16.35764122], [81.53263855, 16.35736084], [81.53151703, 16.35736084], [81.53151703, 16.35708046], [81.53125, 16.35708427], [81.53125, 16.3568058], [81.53098297, 16.35680962], [81.53098297, 16.35625076], [81.53069305, 16.35625076], [81.53069305, 16.35569], [81.5304184, 16.35569382], [81.5304184, 16.35513878], [81.53013611, 16.35514069], [81.53013611, 16.35486031], [81.52986145, 16.35486031], [81.52986145, 16.35457993], [81.52902985, 16.35458374], [81.52902985, 16.35430527], [81.52791595, 16.35431099], [81.52791595, 16.35403061], [81.5265274, 16.3540287], [81.5265274, 16.35458374], [81.52625275, 16.35457993], [81.52625275, 16.35486031], [81.52458191, 16.35486031], [81.52458191, 16.35514069], [81.52430725, 16.35514069], [81.52430725, 16.35542107], [81.52402496, 16.35541725], [81.52402496, 16.35569382], [81.52375031, 16.35569382], [81.52375031, 16.35652733], [81.52403259, 16.3565197], [81.52403259, 16.35680962], [81.52430725, 16.3568058], [81.52430725, 16.35819435], [81.5229187, 16.35819435], [81.5229187, 16.35791588], [81.52236176, 16.35791969], [81.52236176, 16.35764122], [81.52124786, 16.35764122], [81.52124786, 16.35791969], [81.52041626, 16.35791588], [81.52041626, 16.35819435], [81.51958466, 16.35819435], [81.51958466, 16.35847282], [81.51875305, 16.35847282], [81.51875305, 16.35819435], [81.51819611, 16.35819435], [81.51819611, 16.35791588], [81.51763916, 16.35791969], [81.51763916, 16.35764122], [81.51735687, 16.35764122], [81.51735687, 16.35736084], [81.51708221, 16.35736084], [81.51708221, 16.35708046], [81.51680756, 16.35708427], [81.51680756, 16.3568058], [81.5165329, 16.35680962], [81.5165329, 16.3565197], [81.51597595, 16.35652733], [81.51597595, 16.35597229], [81.51569366, 16.35597229], [81.51569366, 16.35569382], [81.51541901, 16.35569382], [81.51541901, 16.35541725], [81.51513672, 16.35542107], [81.51513672, 16.35514069], [81.51486206, 16.35514069], [81.51486206, 16.35486031], [81.51457977, 16.35486031], [81.51457977, 16.35457993], [81.51374817, 16.35458374], [81.51374817, 16.35430527], [81.51291656, 16.35430527], [81.51291656, 16.35458374], [81.51069641, 16.35458374], [81.51069641, 16.35430527], [81.51013947, 16.35431099], [81.51013947, 16.35403061], [81.50985718, 16.35403061], [81.50985718, 16.35375023], [81.50930786, 16.35375023], [81.50930786, 16.35320091], [81.5090332, 16.35320091], [81.5090332, 16.35264015], [81.50875092, 16.35264015], [81.50875092, 16.35235977], [81.50763702, 16.35235977], [81.50763702, 16.35264015], [81.50708008, 16.35264015], [81.50708008, 16.35292053], [81.50653076, 16.35292053], [81.50653076, 16.35320091], [81.50569153, 16.35320091], [81.50569153, 16.35292053], [81.50541687, 16.35292053], [81.50541687, 16.35264015], [81.50486755, 16.35264015], [81.50486755, 16.35235977], [81.50180817, 16.35236168], [81.50180817, 16.35208321], [81.50152588, 16.35208321], [81.50152588, 16.35180473], [81.50125122, 16.35180473], [81.50125122, 16.35152817], [81.49874878, 16.35152817], [81.49874878, 16.35180473], [81.49597168, 16.35180473], [81.49597168, 16.35152817], [81.49485779, 16.35152817], [81.49485779, 16.35180473], [81.49208069, 16.35180473], [81.49208069, 16.35208321], [81.49153137, 16.35208321], [81.49153137, 16.35236168], [81.49124908, 16.35235977], [81.49124908, 16.35264015], [81.4909668, 16.35264015], [81.4909668, 16.35292053], [81.48486328, 16.35292053], [81.48486328, 16.35264015], [81.48458099, 16.35264015], [81.48458099, 16.35292053], [81.48375702, 16.35292053], [81.48375702, 16.35320091], [81.48124695, 16.35320091], [81.48124695, 16.35292053], [81.48069763, 16.35292053], [81.48069763, 16.35264015], [81.48042297, 16.35264015], [81.48042297, 16.35292053], [81.48014069, 16.35292053], [81.48014069, 16.35264015], [81.47957611, 16.35264015], [81.47957611, 16.35292053], [81.47902679, 16.35292053], [81.47902679, 16.35320091], [81.47819519, 16.35319519], [81.47819519, 16.35347176], [81.47652435, 16.35347176], [81.47652435, 16.35319519], [81.47402954, 16.35319519], [81.47402954, 16.35347176], [81.47264099, 16.35347176], [81.47264099, 16.35319519], [81.47013855, 16.35320091], [81.47013855, 16.35292053], [81.46901703, 16.35292053], [81.46901703, 16.35320091], [81.46875763, 16.35320091], [81.46875763, 16.35292053], [81.46763611, 16.35292053], [81.46763611, 16.35264015], [81.46736145, 16.35264015], [81.46736145, 16.35292053], [81.4651413, 16.35292053], [81.4651413, 16.35264015], [81.46235657, 16.35264015], [81.46235657, 16.35235977], [81.45874786, 16.35236168], [81.45874786, 16.35208321], [81.45652771, 16.35208321], [81.45652771, 16.35180473], [81.45430756, 16.35180473], [81.45430756, 16.35152817], [81.45263672, 16.35153008], [81.45263672, 16.35124969], [81.44930267, 16.35124969], [81.44930267, 16.35097122], [81.44680786, 16.35097313], [81.44680786, 16.35069466], [81.44458008, 16.35069466], [81.44458008, 16.35041618], [81.44235992, 16.35042], [81.44235992, 16.35013962], [81.44069672, 16.35013962], [81.44069672, 16.34986115], [81.4384613, 16.34986115], [81.4384613, 16.34958267], [81.43708038, 16.34958458], [81.43708038, 16.34930611], [81.43596649, 16.34930992], [81.43596649, 16.34902954], [81.43402863, 16.34902954], [81.43402863, 16.34875107], [81.43180847, 16.34875107], [81.43180847, 16.3484726], [81.43069458, 16.3484726], [81.43069458, 16.34819412], [81.42874908, 16.34819412], [81.42874908, 16.34791756], [81.42708588, 16.34791946], [81.42708588, 16.3476429], [81.42597198, 16.3476429], [81.42597198, 16.34736252], [81.42485809, 16.34736252], [81.42485809, 16.34708023], [81.42375183, 16.34708405], [81.42375183, 16.34680557], [81.42151642, 16.34680939], [81.42151642, 16.34653282], [81.41986084, 16.34653282], [81.41986084, 16.34624863], [81.41764069, 16.34624863], [81.41764069, 16.34596825], [81.41708374, 16.34597015], [81.41708374, 16.34569359], [81.41625214, 16.34569359], [81.41625214, 16.34541893], [81.41485596, 16.34542084], [81.41485596, 16.34513855], [81.41401672, 16.34513855], [81.41401672, 16.34485817], [81.41152954, 16.34486008], [81.41152954, 16.34458351], [81.41041565, 16.34458351], [81.41041565, 16.34430504], [81.4090271, 16.34431076], [81.4090271, 16.34403038], [81.40763855, 16.34403038], [81.40763855, 16.34374809], [81.4054184, 16.34374809], [81.4054184, 16.34403038], [81.40374756, 16.34403038], [81.40374756, 16.34431076], [81.4034729, 16.34431076], [81.4034729, 16.34542084], [81.40374756, 16.34541893], [81.40374756, 16.34569359], [81.40513611, 16.34569359], [81.40513611, 16.34597015], [81.40625, 16.34596825], [81.40625, 16.34624863], [81.40680695, 16.34624863], [81.40680695, 16.34653282], [81.4070816, 16.34653282], [81.4070816, 16.34736252], [81.40680695, 16.34736252], [81.40680695, 16.3476429], [81.40651703, 16.3476429], [81.40651703, 16.34791946], [81.40625, 16.34791756], [81.40625, 16.3484726], [81.4054184, 16.3484726], [81.4054184, 16.34819412], [81.40458679, 16.34819412], [81.40458679, 16.34791756], [81.40402985, 16.34791946], [81.40402985, 16.3476429], [81.4034729, 16.3476429], [81.4034729, 16.34791946], [81.40319824, 16.34791756], [81.40319824, 16.34819412], [81.40291595, 16.34819412], [81.40291595, 16.3484726], [81.4026413, 16.3484726], [81.4026413, 16.34902954], [81.40235901, 16.34902763], [81.40235901, 16.35180473], [81.40208435, 16.35180473], [81.40208435, 16.35208321], [81.40125275, 16.35208321], [81.40125275, 16.35180473], [81.40097046, 16.35180473], [81.40097046, 16.35041618], [81.40125275, 16.35042], [81.40125275, 16.35013962], [81.4015274, 16.35013962], [81.4015274, 16.34819031], [81.40180206, 16.34819412], [81.40180206, 16.34708405], [81.4015274, 16.34708405], [81.4015274, 16.34569359], [81.40125275, 16.34569359], [81.40125275, 16.34541893], [81.4006958, 16.34542084], [81.4006958, 16.34513855], [81.40013885, 16.34513855], [81.40013885, 16.34485817], [81.3998642, 16.34486008], [81.3998642, 16.34458351], [81.39958191, 16.34458351], [81.39958191, 16.34430504], [81.39930725, 16.34431076], [81.39930725, 16.34403038], [81.39736176, 16.34403038], [81.39736176, 16.34431076], [81.3970871, 16.34430504], [81.3970871, 16.34458351], [81.39624786, 16.3445797], [81.39624786, 16.34513855], [81.39597321, 16.34513855], [81.39597321, 16.34530067], [81.39597321, 16.34597015], [81.39569092, 16.34596825], [81.39569092, 16.34624863], [81.39541626, 16.34624863], [81.39541626, 16.34653282], [81.39457703, 16.34653282], [81.39457703, 16.34680939], [81.39430237, 16.34680557], [81.39430237, 16.34708405], [81.39375305, 16.34708023], [81.39375305, 16.34736252], [81.39299011, 16.34736252], [81.39263916, 16.34736252], [81.39263916, 16.3476429], [81.39235687, 16.3476429], [81.39235687, 16.34791946], [81.39208221, 16.34791946], [81.39208221, 16.34902954], [81.3923645, 16.34902763], [81.3923645, 16.34917068], [81.39235687, 16.34986115], [81.39208221, 16.34986115], [81.39208221, 16.35013962], [81.39180756, 16.35013962], [81.39180756, 16.35042], [81.39152527, 16.35041618], [81.39152527, 16.35069466], [81.39069366, 16.35069466], [81.39069366, 16.35097313], [81.39013672, 16.35097313], [81.39013672, 16.35208321], [81.38986206, 16.35207939], [81.38986206, 16.35264015], [81.38957977, 16.35264015], [81.38957977, 16.35320091], [81.38930511, 16.35319519], [81.38930511, 16.35347176], [81.38903046, 16.35346031], [81.38903046, 16.35375023], [81.38874817, 16.35375023], [81.38874817, 16.35403061], [81.38846588, 16.35403061], [81.38846588, 16.35431099], [81.38791656, 16.35430527], [81.38791656, 16.35458374], [81.38735199, 16.35457993], [81.38735199, 16.35486031], [81.38652802, 16.35486031], [81.38652802, 16.35514069], [81.38569641, 16.35514069], [81.38569641, 16.35542107], [81.38486481, 16.35541725], [81.38486481, 16.35569382], [81.38430786, 16.35569], [81.38430786, 16.35625076], [81.3840332, 16.35625076], [81.3840332, 16.35680962], [81.38375092, 16.3568058], [81.38375092, 16.35807037], [81.38375092, 16.35874939], [81.38346863, 16.35874939], [81.38346863, 16.35931015], [81.38318634, 16.35931015], [81.38318634, 16.3615303], [81.38291931, 16.3615303], [81.38291931, 16.36181068], [81.38263702, 16.36181068], [81.38263702, 16.3615303], [81.38236237, 16.3615303], [81.38236237, 16.36125183], [81.38208008, 16.36125183], [81.38208008, 16.36096954], [81.38180542, 16.36096954], [81.38181305, 16.36125183], [81.38124847, 16.36125183], [81.38124847, 16.3615303], [81.38069153, 16.3615303], [81.38069153, 16.36181068], [81.38041687, 16.36180496], [81.38041687, 16.36208344], [81.37930298, 16.36208344], [81.37930298, 16.36180496], [81.37847137, 16.36181068], [81.37847137, 16.3615303], [81.37735748, 16.3615303], [81.37735748, 16.36125183], [81.37680817, 16.36125183], [81.37680817, 16.36096954], [81.37625122, 16.36096954], [81.37625122, 16.36069489], [81.37513733, 16.36069489], [81.37513733, 16.36041641], [81.37458038, 16.36042023], [81.37458038, 16.36014175], [81.37319183, 16.36014175], [81.37319183, 16.35985947], [81.37291718, 16.35985947], [81.37291718, 16.36014175], [81.37180328, 16.36014175], [81.37180328, 16.36042023], [81.37152863, 16.36041641], [81.37152863, 16.36208344], [81.37124634, 16.36208344], [81.37124634, 16.36180496], [81.36985779, 16.36180496], [81.36985779, 16.36208344], [81.36930847, 16.36208344], [81.36930847, 16.36180496], [81.36902618, 16.36181068], [81.36902618, 16.3615303], [81.36875153, 16.3615303], [81.36875153, 16.36125183], [81.36846924, 16.36125183], [81.36846924, 16.36096954], [81.36819458, 16.36096954], [81.36819458, 16.36069489], [81.36736298, 16.36069489], [81.36736298, 16.36041641], [81.36653137, 16.36042023], [81.36653137, 16.36014175], [81.3659668, 16.36014175], [81.3659668, 16.35985947], [81.36513519, 16.35985947], [81.36513519, 16.3595829], [81.36486053, 16.3595829], [81.36486053, 16.35902977], [81.36458588, 16.35903168], [81.36458588, 16.35847092], [81.36430359, 16.35847282], [81.36430359, 16.35791588], [81.36374664, 16.35791969], [81.36374664, 16.35764122], [81.36347198, 16.35764122], [81.36347198, 16.35736084], [81.36319733, 16.35736084], [81.36319733, 16.35708046], [81.36264038, 16.35708427], [81.36264038, 16.3568058], [81.36235809, 16.35680962], [81.36235809, 16.3565197], [81.36208344, 16.35652733], [81.36208344, 16.35597229], [81.36180878, 16.35597229], [81.36180878, 16.35569382], [81.36152649, 16.35569382], [81.36152649, 16.35513878], [81.36125183, 16.35514069], [81.36125183, 16.35486031], [81.36096954, 16.35486031], [81.36096954, 16.35403061], [81.36068726, 16.35403061], [81.36068726, 16.35320091], [81.36042786, 16.35320091], [81.36042786, 16.35292053], [81.36068726, 16.35292053], [81.36068726, 16.35235977], [81.36096954, 16.35236168], [81.36096954, 16.35152817], [81.36125183, 16.35153008], [81.36125183, 16.35124969], [81.36042023, 16.35124969], [81.36042023, 16.35069466], [81.35986328, 16.35069466], [81.35986328, 16.35041618], [81.35874939, 16.35042], [81.35874939, 16.35013962], [81.35819244, 16.35013962], [81.35819244, 16.34986115], [81.35791779, 16.34986115], [81.35791779, 16.34930992], [81.35958099, 16.34930992], [81.35958099, 16.34902954], [81.35986328, 16.34902954], [81.35986328, 16.34875107], [81.36013794, 16.34875107], [81.36013794, 16.34819031], [81.35986328, 16.34819412], [81.35986328, 16.34791756], [81.35958099, 16.34791946], [81.35958099, 16.34708023], [81.35930634, 16.34708405], [81.35930634, 16.34581947], [81.35930634, 16.34569359], [81.35902405, 16.34569359], [81.35902405, 16.34541893], [81.35874939, 16.34542084], [81.35874939, 16.34513855], [81.3584671, 16.34513855], [81.3584671, 16.34485817], [81.35819244, 16.34486008], [81.35819244, 16.34430504], [81.35791779, 16.34431076], [81.35791779, 16.34403038], [81.35764313, 16.34403038], [81.35764313, 16.34374809], [81.35736084, 16.34374809], [81.35736084, 16.34347153], [81.35708618, 16.34347153], [81.35708618, 16.34319496], [81.35679626, 16.34320068], [81.35679626, 16.34263992], [81.35652924, 16.34263992], [81.35652924, 16.34235954], [81.35624695, 16.34236145], [81.35624695, 16.34180641], [81.35597229, 16.34181023], [81.35597229, 16.34069061], [81.35541534, 16.34069443], [81.35541534, 16.34041405], [81.35514069, 16.34041977], [81.35514069, 16.33986092], [81.3548584, 16.33986092], [81.3548584, 16.33958054], [81.35458374, 16.33958244], [81.35458374, 16.33930588], [81.35430145, 16.33930969], [81.35430145, 16.33903122], [81.35402679, 16.33903122], [81.35402679, 16.33875084], [81.35375214, 16.33875084], [81.35375214, 16.33819008], [81.35346985, 16.3381958], [81.35346985, 16.33763885], [81.35320282, 16.33764076], [81.35320282, 16.33736038], [81.3529129, 16.33736038], [81.3529129, 16.33708], [81.35263824, 16.33708382], [81.35263824, 16.33680534], [81.35235596, 16.33681107], [81.35235596, 16.33653069], [81.35180664, 16.33653069], [81.35180664, 16.33625031], [81.35151672, 16.33625031], [81.35151672, 16.33597183], [81.35124969, 16.33597374], [81.35124969, 16.33541679], [81.35098267, 16.33542061], [81.35098267, 16.33514023], [81.35069275, 16.33514023], [81.35069275, 16.33486176], [81.35041809, 16.33486366], [81.35041809, 16.33458328], [81.34986115, 16.33458328], [81.34986115, 16.33430481], [81.34958649, 16.33430481], [81.34958649, 16.33402824], [81.34929657, 16.33403015], [81.34929657, 16.33375168], [81.34874725, 16.33375168], [81.34874725, 16.33346939], [81.3484726, 16.33346939], [81.3484726, 16.33319473], [81.34819794, 16.33319473], [81.34819794, 16.33291626], [81.34792328, 16.33292007], [81.34792328, 16.3326416], [81.34764099, 16.3326416], [81.34764099, 16.33234978], [81.34708405, 16.33235931], [81.34708405, 16.33208275], [81.34680176, 16.33208275], [81.34680176, 16.33180618], [81.3465271, 16.3318119], [81.3465271, 16.33152771], [81.34597015, 16.33152771], [81.34597015, 16.33124924], [81.34570313, 16.33124924], [81.34570313, 16.33069038], [81.34680176, 16.3306942], [81.34680939, 16.33097267], [81.34764099, 16.33097076], [81.34764099, 16.33124924], [81.34819794, 16.33124924], [81.34819794, 16.33152771], [81.34874725, 16.33152771], [81.34874725, 16.3318119], [81.3493042, 16.33180618], [81.3493042, 16.33208275], [81.34958649, 16.33208275], [81.34958649, 16.33235931], [81.35069275, 16.33234978], [81.35069275, 16.3326416], [81.3520813, 16.3326416], [81.3520813, 16.33292007], [81.35263824, 16.33291626], [81.35263824, 16.33319473], [81.35346985, 16.33319473], [81.35346985, 16.33346939], [81.35402679, 16.33346939], [81.35402679, 16.33375168], [81.35569763, 16.33375168], [81.35569763, 16.33403015], [81.35597229, 16.33402824], [81.35597229, 16.33430481], [81.35652924, 16.33430481], [81.35652924, 16.33458328], [81.35679626, 16.33457947], [81.35679626, 16.33514023], [81.35708618, 16.33514023], [81.35708618, 16.33542061], [81.35736084, 16.33541679], [81.35736084, 16.33597374], [81.3576355, 16.33597374], [81.3576355, 16.33625031], [81.35791779, 16.33625031], [81.35791779, 16.33681107], [81.35819244, 16.33681107], [81.35819244, 16.33736038], [81.3584671, 16.33736038], [81.3584671, 16.33764076], [81.35874939, 16.33763885], [81.35874939, 16.3381958], [81.35901642, 16.33819008], [81.35901642, 16.33875084], [81.35930634, 16.33875084], [81.35930634, 16.33958244], [81.35958099, 16.33958054], [81.35958099, 16.33986092], [81.35986328, 16.33986092], [81.35986328, 16.34041977], [81.36013794, 16.34041405], [81.36013794, 16.34069443], [81.36069489, 16.34069443], [81.36069489, 16.3409729], [81.36096954, 16.34097099], [81.36096954, 16.34124947], [81.36152649, 16.34124947], [81.36152649, 16.34152794], [81.36207581, 16.34152031], [81.36207581, 16.34181023], [81.36264038, 16.34180641], [81.36264038, 16.34208298], [81.36319733, 16.34208298], [81.36319733, 16.34236145], [81.36347198, 16.34235954], [81.36347198, 16.34263992], [81.36374664, 16.34263992], [81.36374664, 16.34320068], [81.36402893, 16.34320068], [81.36402893, 16.34374809], [81.36429596, 16.34374809], [81.36429596, 16.34431076], [81.36458588, 16.34430504], [81.36458588, 16.34458351], [81.36513519, 16.34458351], [81.36513519, 16.34486008], [81.36569214, 16.34485817], [81.36569214, 16.34513855], [81.3659668, 16.34513855], [81.3659668, 16.34542084], [81.36653137, 16.34541893], [81.36653137, 16.34569359], [81.36680603, 16.34569359], [81.36680603, 16.34597015], [81.36708069, 16.34597015], [81.36708069, 16.34569359], [81.36958313, 16.34569359], [81.36958313, 16.34597015], [81.37097168, 16.34596825], [81.37097168, 16.34653282], [81.37069702, 16.34653282], [81.37069702, 16.34680939], [81.37041473, 16.34680557], [81.37041473, 16.34708405], [81.37014008, 16.34708023], [81.37014008, 16.34736252], [81.36985779, 16.34736252], [81.36985779, 16.34791946], [81.36902618, 16.34791756], [81.36902618, 16.34819412], [81.36846924, 16.34819412], [81.36846924, 16.3484726], [81.36763763, 16.3484726], [81.36763763, 16.34875107], [81.36736298, 16.34875107], [81.36736298, 16.34902954], [81.36708069, 16.34902954], [81.36708069, 16.34930992], [81.36680603, 16.34930611], [81.36680603, 16.34958458], [81.36653137, 16.34958267], [81.36653137, 16.34986115], [81.36624146, 16.34986115], [81.36624146, 16.35042], [81.36541748, 16.35042], [81.36541748, 16.35124969], [81.36569214, 16.35124969], [81.36569214, 16.35208321], [81.36597443, 16.35208321], [81.36597443, 16.35236168], [81.36624146, 16.35235977], [81.36624146, 16.35264015], [81.36653137, 16.35264015], [81.36653137, 16.35292053], [81.36680603, 16.35292053], [81.36680603, 16.35320091], [81.36708069, 16.35319519], [81.36708069, 16.35347176], [81.36763763, 16.35346031], [81.36763763, 16.35403061], [81.36791992, 16.35403061], [81.36791992, 16.35431099], [81.36846924, 16.35430527], [81.36846924, 16.35458374], [81.37124634, 16.35457993], [81.37124634, 16.35486031], [81.3720932, 16.35486031], [81.3720932, 16.35514069], [81.37264252, 16.35514069], [81.37264252, 16.35542107], [81.37291718, 16.35541725], [81.37291718, 16.35569382], [81.37347412, 16.35569382], [81.37347412, 16.35597229], [81.37430573, 16.35597229], [81.37430573, 16.35625076], [81.37486267, 16.35625076], [81.37486267, 16.35652733], [81.37513733, 16.3565197], [81.37513733, 16.35680962], [81.37569427, 16.3568058], [81.37569427, 16.35708237], [81.37625122, 16.35708046], [81.37625122, 16.35736084], [81.37652588, 16.35736084], [81.37652588, 16.35764122], [81.37680817, 16.35763741], [81.37680817, 16.35819435], [81.37708282, 16.35819054], [81.37708282, 16.35874939], [81.37735748, 16.35874939], [81.37735748, 16.35903168], [81.3779068, 16.35903168], [81.3779068, 16.35931015], [81.37875366, 16.35930634], [81.37875366, 16.3595829], [81.37985992, 16.3595829], [81.37985992, 16.35985947], [81.38097382, 16.35985947], [81.38097382, 16.3595829], [81.38153076, 16.3595829], [81.38153076, 16.35930634], [81.38181305, 16.35931015], [81.38181305, 16.35903168], [81.38236237, 16.35903168], [81.38236237, 16.35847092], [81.38263702, 16.35847282], [81.38263702, 16.35736084], [81.38291931, 16.35733032], [81.38291931, 16.3568058], [81.38318634, 16.35680962], [81.38318634, 16.35625076], [81.38346863, 16.35625076], [81.38346863, 16.35569], [81.38375092, 16.35569382], [81.38375092, 16.35513878], [81.3840332, 16.35514069], [81.3840332, 16.35431099], [81.38430786, 16.35431099], [81.38430786, 16.35403061], [81.38458252, 16.35403061], [81.38458252, 16.35375023], [81.38652802, 16.35375023], [81.38652802, 16.35346031], [81.38708496, 16.35347176], [81.38708496, 16.35319519], [81.38764191, 16.35320091], [81.38764191, 16.35292053], [81.38791656, 16.35292053], [81.38791656, 16.35124969], [81.38764191, 16.35124969], [81.38764191, 16.35097122], [81.38708496, 16.35097313], [81.38708496, 16.35013962], [81.38791656, 16.35013962], [81.38791656, 16.34986115], [81.38846588, 16.34986115], [81.38846588, 16.34958267], [81.38874817, 16.34958458], [81.38874817, 16.34930611], [81.38903046, 16.34930992], [81.38903046, 16.3484726], [81.38930511, 16.3484726], [81.38930511, 16.34819412], [81.38957977, 16.34819412], [81.38957977, 16.34763908], [81.38986206, 16.3476429], [81.38986206, 16.34708023], [81.39013672, 16.34708405], [81.39013672, 16.34680557], [81.39041138, 16.34680939], [81.39041138, 16.34653282], [81.39068604, 16.34653282], [81.39068604, 16.34624863], [81.39097595, 16.34624863], [81.39097595, 16.34596825], [81.39125061, 16.34597015], [81.39125061, 16.34569359], [81.39152527, 16.34569359], [81.39152527, 16.34541893], [81.39208221, 16.34542084], [81.39208221, 16.34513855], [81.39235687, 16.34513855], [81.39235687, 16.3445797], [81.39263916, 16.34458351], [81.39263916, 16.34208298], [81.3923645, 16.34208298], [81.3923645, 16.34180641], [81.39180756, 16.34181023], [81.39180756, 16.34152031], [81.39152527, 16.34152794], [81.39152527, 16.34124947], [81.39097595, 16.34124947], [81.39097595, 16.34097099], [81.39041901, 16.3409729], [81.39041901, 16.34069443], [81.39013672, 16.34069443], [81.39013672, 16.34041405], [81.38957977, 16.34041977], [81.38957977, 16.34013939], [81.38791656, 16.34013939], [81.38791656, 16.33986092], [81.38735199, 16.33986092], [81.38735199, 16.33958054], [81.38652802, 16.33958244], [81.38652802, 16.33930588], [81.38597107, 16.33930969], [81.38597107, 16.33903122], [81.38513947, 16.33903122], [81.38513947, 16.33875084], [81.38375092, 16.33875084], [81.38375092, 16.33848], [81.38263702, 16.33848], [81.38263702, 16.33819008], [81.38180542, 16.3381958], [81.38180542, 16.33791733], [81.38096619, 16.33792114], [81.38096619, 16.33764076], [81.38041687, 16.33764076], [81.38041687, 16.33736038], [81.37985992, 16.33736038], [81.37985992, 16.33708], [81.37930298, 16.33708382], [81.37930298, 16.33680534], [81.37847137, 16.33681107], [81.37847137, 16.33653069], [81.37735748, 16.33653069], [81.37735748, 16.33625031], [81.37652588, 16.33625031], [81.37652588, 16.33597183], [81.37458038, 16.33597374], [81.37458038, 16.33569527], [81.37403107, 16.3357029], [81.37403107, 16.33542061], [81.37346649, 16.33542061], [81.37346649, 16.33514023], [81.37236786, 16.33514023], [81.37236786, 16.33486176], [81.37152863, 16.33486366], [81.37152863, 16.33458328], [81.37097168, 16.33458328], [81.37097168, 16.33430481], [81.37014008, 16.33430481], [81.37014008, 16.33402824], [81.36930847, 16.33403015], [81.36930847, 16.33375168], [81.36846924, 16.33375168], [81.36846924, 16.33346939], [81.36763763, 16.33346939], [81.36763763, 16.33319473], [81.36653137, 16.33319473], [81.36653137, 16.33291626], [81.3659668, 16.33292007], [81.3659668, 16.3326416], [81.36513519, 16.3326416], [81.36513519, 16.33235931], [81.36430359, 16.33235931], [81.36430359, 16.33208275], [81.36347198, 16.33208275], [81.36347198, 16.33180618], [81.36292267, 16.3318119], [81.36292267, 16.33152771], [81.36235809, 16.33152771], [81.36235809, 16.33124924], [81.36207581, 16.33124924], [81.36207581, 16.33097076], [81.36152649, 16.33097267], [81.36152649, 16.3306942], [81.36013794, 16.3306942], [81.36013794, 16.33041954], [81.35930634, 16.33041954], [81.35930634, 16.33013916], [81.3584671, 16.33013916], [81.3584671, 16.32986069], [81.35708618, 16.32986069], [81.35708618, 16.32958031], [81.35652924, 16.32958412], [81.35652924, 16.32930565], [81.35624695, 16.32930946], [81.35624695, 16.32903099], [81.35542297, 16.32903099], [81.35542297, 16.32875061], [81.3548584, 16.32875061], [81.3548584, 16.32847023], [81.35402679, 16.32847214], [81.35402679, 16.32819366], [81.35319519, 16.32819366], [81.35319519, 16.32791519], [81.3529129, 16.32792091], [81.3529129, 16.32764053], [81.35235596, 16.32764053], [81.35235596, 16.32736015], [81.35180664, 16.32736206], [81.35180664, 16.32708359], [81.35124969, 16.32708359], [81.35124969, 16.32680511], [81.35041809, 16.32681084], [81.35041809, 16.32653809], [81.34902954, 16.32653809], [81.34902954, 16.32625008], [81.3484726, 16.32625008], [81.3484726, 16.3259697], [81.34819794, 16.3259716], [81.34819794, 16.32569313], [81.3473587, 16.32570076], [81.3473587, 16.32542038], [81.3465271, 16.32542038], [81.3465271, 16.32514], [81.34597015, 16.32514], [81.34597015, 16.32485962], [81.3456955, 16.32486153], [81.3456955, 16.32458305], [81.3445816, 16.32458305], [81.3445816, 16.32430649], [81.34375, 16.3243103], [81.34375, 16.32402992], [81.34319305, 16.32402992], [81.34319305, 16.32374954], [81.34236145, 16.32374954], [81.34236145, 16.32348061], [81.34179688, 16.32348061], [81.34179688, 16.32319069], [81.34124756, 16.3231945], [81.34124756, 16.32291603], [81.34069824, 16.32291985], [81.34069061, 16.32263947], [81.33985901, 16.32263947], [81.33985901, 16.3223629], [81.33875275, 16.3223629], [81.33875275, 16.32208061], [81.3381958, 16.32208061], [81.3381958, 16.32180595], [81.33735657, 16.32180977], [81.33735657, 16.32152939], [81.33708191, 16.32152939], [81.33708191, 16.32125282], [81.33625031, 16.32125282], [81.33625031, 16.32097244], [81.33597565, 16.32097244], [81.33597565, 16.32069206], [81.3354187, 16.32069206], [81.3354187, 16.3204174], [81.3345871, 16.3204174], [81.3345871, 16.32014084], [81.33347321, 16.32014275], [81.33347321, 16.31986237], [81.3326416, 16.31986237], [81.3326416, 16.31957817], [81.33235931, 16.31958389], [81.33235931, 16.31930542], [81.33180237, 16.31930923], [81.33180237, 16.31903076], [81.33152771, 16.31903076], [81.33152771, 16.31874847], [81.33097076, 16.31874847], [81.33097076, 16.31846809], [81.33013916, 16.31847191], [81.33013916, 16.31819534], [81.32930756, 16.31819916], [81.32930756, 16.31792068], [81.32847595, 16.31792068], [81.32847595, 16.3176384], [81.32791901, 16.3176384], [81.32791901, 16.31735039], [81.32763672, 16.31736183], [81.32763672, 16.31708336], [81.32736206, 16.31708336], [81.32736206, 16.31680489], [81.32653046, 16.31680489], [81.32653046, 16.31652641], [81.32596588, 16.31652832], [81.32596588, 16.31624985], [81.32541656, 16.31624985], [81.32541656, 16.31596947], [81.32485962, 16.31597137], [81.32485962, 16.31569481], [81.32430267, 16.31569481], [81.32430267, 16.31541634], [81.32375336, 16.31542015], [81.32375336, 16.31513977], [81.32347107, 16.31513977], [81.32347107, 16.31485939], [81.32291412, 16.3148613], [81.32291412, 16.31458282], [81.32236481, 16.31458282], [81.32236481, 16.31430626], [81.3215332, 16.31431007], [81.3215332, 16.31402969], [81.32096863, 16.31402969], [81.32096863, 16.31375122], [81.32041931, 16.31375122], [81.32041931, 16.31347084], [81.31958008, 16.31347275], [81.31958008, 16.31319427], [81.31874847, 16.31319427], [81.31874847, 16.3129158], [81.31846619, 16.31291962], [81.31846619, 16.31264114], [81.31819153, 16.31264114], [81.31819153, 16.31236076], [81.31791687, 16.31236076], [81.31791687, 16.31208038], [81.31764221, 16.3120842], [81.31764221, 16.31180573], [81.3170929, 16.31180954], [81.3170929, 16.3115406], [81.31652832, 16.3115406], [81.31652832, 16.31125069], [81.31597137, 16.31125069], [81.31597137, 16.31097031], [81.31541443, 16.31097221], [81.31541443, 16.31069374], [81.31513977, 16.31069374], [81.31513977, 16.31041718], [81.31485748, 16.31042099], [81.31485748, 16.31014061], [81.31458282, 16.31014061], [81.31458282, 16.30994987], [81.31458282, 16.30986023], [81.3140564, 16.30986023], [81.31375122, 16.30986023], [81.31375122, 16.30958366], [81.31291962, 16.30958366], [81.31291962, 16.30930519], [81.31207275, 16.30931091], [81.31207275, 16.30903053], [81.31181335, 16.30903053], [81.31181335, 16.30875015], [81.31153107, 16.30875015], [81.31153107, 16.30846977], [81.31124878, 16.30847359], [81.31124878, 16.30819511], [81.31069183, 16.30820274], [81.31069183, 16.30792046], [81.31014252, 16.30792046], [81.31014252, 16.30764008], [81.3095932, 16.30764008], [81.3095932, 16.3073616], [81.30902863, 16.3073616], [81.30902863, 16.30708122], [81.30847168, 16.30708122], [81.30847168, 16.30680466], [81.30819702, 16.30680466], [81.30819702, 16.30652809], [81.3079071, 16.30653191], [81.3079071, 16.30625153], [81.30735779, 16.30625153], [81.30735779, 16.30596924], [81.30708313, 16.30597305], [81.30708313, 16.30569458], [81.30625153, 16.30569458], [81.30625153, 16.30541611], [81.30596924, 16.30541611], [81.30596924, 16.30514145], [81.30568695, 16.30514145], [81.30568695, 16.30485916], [81.30541992, 16.30485916], [81.30541992, 16.30458069], [81.30458069, 16.3045826], [81.30458069, 16.30430603], [81.30374908, 16.30430984], [81.30374908, 16.30402756], [81.3034668, 16.30402756], [81.3034668, 16.30374908], [81.30291748, 16.30374908], [81.30291748, 16.30347061], [81.30263519, 16.30347252], [81.30263519, 16.30319405], [81.30208588, 16.30319405], [81.30208588, 16.30291748], [81.30152893, 16.30291748], [81.30152893, 16.30264091], [81.30124664, 16.30264091], [81.30124664, 16.30236816], [81.30069733, 16.30236816], [81.30069733, 16.30208015], [81.30041504, 16.30208397], [81.30041504, 16.3018055], [81.30013275, 16.30181122], [81.30013275, 16.30153084], [81.29985809, 16.30153084], [81.29985809, 16.30125046], [81.29930878, 16.30125046], [81.29930878, 16.30097008], [81.29902649, 16.30097198], [81.29902649, 16.30069542], [81.29846954, 16.3006897], [81.29846954, 16.30041695], [81.29736328, 16.30042076], [81.29736328, 16.29986], [81.29680634, 16.29986191], [81.29680634, 16.29958344], [81.29652405, 16.29958344], [81.29652405, 16.29930687], [81.29624939, 16.29931068], [81.29624939, 16.2990303], [81.2959671, 16.2990303], [81.2959671, 16.29874992], [81.29541779, 16.29874992], [81.29541779, 16.29846954], [81.29458618, 16.29847145], [81.29458618, 16.29819489], [81.29430389, 16.29819489], [81.29430389, 16.29791641], [81.29402924, 16.29792023], [81.29402924, 16.29763985], [81.29374695, 16.29763985], [81.29374695, 16.29735947], [81.29347229, 16.29736137], [81.29347229, 16.29708481], [81.29319763, 16.29708481], [81.29319763, 16.29680634], [81.2923584, 16.29681015], [81.2923584, 16.29652977], [81.29207611, 16.29652977], [81.29207611, 16.29624176], [81.29152679, 16.29624939], [81.29152679, 16.29597282], [81.29125214, 16.29597282], [81.29125214, 16.29569435], [81.29069519, 16.29569435], [81.29069519, 16.29541588], [81.2904129, 16.29541969], [81.2904129, 16.29514122], [81.28985596, 16.29514122], [81.28985596, 16.29486275], [81.28901672, 16.29486275], [81.28901672, 16.29458046], [81.28847504, 16.29458427], [81.28847504, 16.2943058], [81.28819275, 16.29430962], [81.28819275, 16.29403114], [81.28791809, 16.29403114], [81.28791809, 16.29375267], [81.28708649, 16.29375267], [81.28708649, 16.29347038], [81.2868042, 16.29347038], [81.2868042, 16.29319382], [81.28652954, 16.29319382], [81.28652954, 16.29291725], [81.28624725, 16.29291916], [81.28624725, 16.29264069], [81.2859726, 16.29264069], [81.2859726, 16.2923584], [81.28569794, 16.2923584], [81.28569794, 16.29207993], [81.28541565, 16.29208374], [81.28541565, 16.29180527], [81.2848587, 16.29180908], [81.2848587, 16.29153061], [81.28457642, 16.29153061], [81.28457642, 16.29124832], [81.28430176, 16.29124832], [81.28430176, 16.29096985], [81.2831955, 16.29097176], [81.2831955, 16.29069519], [81.28263855, 16.29070091], [81.28263855, 16.29013824], [81.28235626, 16.29013824], [81.28235626, 16.28985977], [81.2820816, 16.28986168], [81.2820816, 16.28958321], [81.28180695, 16.28958321], [81.28180695, 16.28930473], [81.28152466, 16.28930473], [81.28152466, 16.28902626], [81.28125, 16.28902817], [81.28125, 16.28874969], [81.28069305, 16.28874969], [81.28069305, 16.28819084], [81.28013611, 16.28819466], [81.28013611, 16.28763962], [81.27986145, 16.28763962], [81.27986145, 16.28737068], [81.27958679, 16.28737068], [81.27958679, 16.28708076], [81.2793045, 16.28708267], [81.2793045, 16.28652763], [81.2784729, 16.28652954], [81.2784729, 16.28625107], [81.27819824, 16.28625107], [81.27819061, 16.28597069], [81.27791595, 16.2859726], [81.27791595, 16.28569412], [81.2776413, 16.28569412], [81.2776413, 16.28541756], [81.27680206, 16.28541946], [81.27680206, 16.28514099], [81.2765274, 16.28514099], [81.2765274, 16.28486061], [81.27625275, 16.28486061], [81.27625275, 16.28458023], [81.2756958, 16.28458595], [81.2756958, 16.28430557], [81.27541351, 16.28430557], [81.27541351, 16.2840271], [81.27485657, 16.28403091], [81.27485657, 16.28375053], [81.27458191, 16.28375053], [81.27458191, 16.28347015], [81.27430725, 16.28347206], [81.27430725, 16.28319359], [81.27402496, 16.28319359], [81.27402496, 16.28291702], [81.27348328, 16.28292084], [81.27348328, 16.28264046], [81.27319336, 16.28264046], [81.27319336, 16.28236008], [81.2729187, 16.28236389], [81.2729187, 16.28208351], [81.27263641, 16.28208351], [81.27263641, 16.28180504], [81.2720871, 16.28181076], [81.2720871, 16.28123856], [81.27180481, 16.28125191], [81.27180481, 16.28096962], [81.27124786, 16.28096962], [81.27124786, 16.28069496], [81.27069092, 16.28070068], [81.27069092, 16.2804203], [81.27041626, 16.2804203], [81.27041626, 16.28014183], [81.27014923, 16.28014183], [81.27014923, 16.27957916], [81.26985931, 16.27958107], [81.26985931, 16.27930641], [81.26930237, 16.27931023], [81.26930237, 16.27903175], [81.26875305, 16.27903175], [81.26875305, 16.27875137], [81.26847076, 16.27875137], [81.26847076, 16.27846909], [81.26819611, 16.27846909], [81.26819611, 16.27875137], [81.26699829, 16.27875137], [81.26680756, 16.27875137], [81.26680756, 16.27903175], [81.2665329, 16.27903175], [81.2665329, 16.27931023], [81.26625061, 16.27931023], [81.26625061, 16.28014183], [81.26597595, 16.28013992], [81.26597595, 16.28096962], [81.26569366, 16.28096962], [81.26569366, 16.28125191], [81.26541901, 16.28125191], [81.26541901, 16.28096962], [81.26513672, 16.28096962], [81.26513672, 16.28013992], [81.26541901, 16.28014183], [81.26541901, 16.27957916], [81.26513672, 16.27958107], [81.26513672, 16.27902985], [81.26486206, 16.27903175], [81.26486206, 16.27807999], [81.26486206, 16.27791595], [81.26457977, 16.27791977], [81.26457977, 16.27653122], [81.26431274, 16.27653122], [81.26431274, 16.27625084], [81.26402283, 16.27625084], [81.26402283, 16.27597046], [81.26374817, 16.27597237], [81.26374817, 16.27541733], [81.26346588, 16.27543068], [81.26346588, 16.27514076], [81.26319122, 16.27514076], [81.26319122, 16.27458], [81.26291656, 16.27458382], [81.26291656, 16.27347183], [81.26264191, 16.27347183], [81.26264191, 16.27124977], [81.26235962, 16.27124977], [81.26235962, 16.27096939], [81.26208496, 16.2709713], [81.26208496, 16.27069473], [81.26180267, 16.27069473], [81.26180267, 16.27041626], [81.26152802, 16.27042007], [81.26152802, 16.27013969], [81.26125336, 16.27013969], [81.2612381, 16.26958275], [81.26097107, 16.26958466], [81.26097107, 16.26930618], [81.26069641, 16.26930618], [81.26069641, 16.26902771], [81.26040649, 16.26902962], [81.26040649, 16.26875114], [81.26013947, 16.26875114], [81.26013947, 16.26847267], [81.25986481, 16.26847267], [81.25986481, 16.2681942], [81.25958252, 16.2681942], [81.25958252, 16.26791763], [81.25930786, 16.26791954], [81.25930786, 16.26764107], [81.2590332, 16.26764107], [81.2590332, 16.26736259], [81.25875092, 16.26736259], [81.25875092, 16.26680946], [81.25846863, 16.26680946], [81.25846863, 16.2665329], [81.25791931, 16.2665329], [81.25791931, 16.26626015], [81.25763702, 16.26626015], [81.25763702, 16.26596832], [81.25736237, 16.26597023], [81.25736237, 16.26569366], [81.25708008, 16.26569366], [81.25708008, 16.2654171], [81.25681305, 16.26542091], [81.25681305, 16.26514053], [81.25653076, 16.26514053], [81.25653076, 16.26485825], [81.25624847, 16.26486015], [81.25624847, 16.26458359], [81.25597382, 16.26458359], [81.25597382, 16.26430511], [81.25569153, 16.26431084], [81.25569153, 16.26403046], [81.25541687, 16.26403046], [81.25541687, 16.26374817], [81.25514221, 16.26374817], [81.25514221, 16.2634697], [81.25485992, 16.2634716], [81.25485992, 16.26319504], [81.2545929, 16.26320076], [81.2545929, 16.26292038], [81.25430298, 16.26292038], [81.25430298, 16.26263809], [81.25402832, 16.26263809], [81.25402832, 16.26208115], [81.25430298, 16.26208305], [81.25430298, 16.26180649], [81.25319672, 16.2618103], [81.25319672, 16.26152992], [81.2529068, 16.26152992], [81.2529068, 16.26124954], [81.25263977, 16.26124954], [81.25263977, 16.26097107], [81.25235748, 16.26097298], [81.25235748, 16.2606945], [81.25208282, 16.2606945], [81.25208282, 16.26041412], [81.25180817, 16.26041985], [81.25180817, 16.26013947], [81.25152588, 16.26013947], [81.25152588, 16.25986099], [81.25125122, 16.25986099], [81.25125122, 16.25958061], [81.25096893, 16.25958252], [81.25096893, 16.25930405], [81.25068665, 16.25930977], [81.25068665, 16.25902939], [81.25041962, 16.25902939], [81.25041962, 16.25875092], [81.25013733, 16.25875092], [81.25013733, 16.25819016], [81.25041962, 16.25819588], [81.25041962, 16.2579174], [81.25013733, 16.25792122], [81.25013733, 16.25764084], [81.24931335, 16.25764084], [81.24931335, 16.25736046], [81.24903107, 16.25736046], [81.24903107, 16.25708389], [81.24874878, 16.25708389], [81.24874878, 16.25680542], [81.24846649, 16.25681114], [81.24846649, 16.2565403], [81.24847412, 16.25625038], [81.24819183, 16.25625038], [81.24819183, 16.25597191], [81.24791718, 16.25597382], [81.24791718, 16.25569534], [81.24764252, 16.25570107], [81.24764252, 16.25542068], [81.24736023, 16.25542068], [81.24736023, 16.2551403], [81.2470932, 16.2551403], [81.2470932, 16.25457954], [81.24680328, 16.25458336], [81.24680328, 16.25430489], [81.24652863, 16.25430489], [81.24652863, 16.25402832], [81.24624634, 16.25403023], [81.24624634, 16.25375175], [81.24597168, 16.25375175], [81.24597168, 16.25346947], [81.24569702, 16.25346947], [81.24569702, 16.25291634], [81.2454071, 16.25292015], [81.2454071, 16.25264168], [81.24514008, 16.25264168], [81.24514008, 16.25235939], [81.24485779, 16.25235939], [81.24485779, 16.25208282], [81.24458313, 16.25208282], [81.24458313, 16.25180626], [81.24430847, 16.25181007], [81.24430847, 16.2515316], [81.24402618, 16.2515316], [81.24402618, 16.25097084], [81.24375153, 16.25097275], [81.24375153, 16.25069427], [81.24346924, 16.25069427], [81.24346924, 16.2504158], [81.24318695, 16.25041962], [81.24318695, 16.25014114], [81.24291229, 16.25014114], [81.24291229, 16.24986076], [81.24263763, 16.24986076], [81.24263763, 16.24930954], [81.24236298, 16.24930954], [81.24236298, 16.24847031], [81.24208069, 16.24847221], [81.24208069, 16.24819374], [81.24153137, 16.24819946], [81.24153137, 16.24792099], [81.24124908, 16.24792099], [81.24124908, 16.24764061], [81.2409668, 16.24764061], [81.2409668, 16.24736023], [81.24069214, 16.24736023], [81.24069214, 16.24707985], [81.24041748, 16.24708366], [81.24041748, 16.24680519], [81.24014282, 16.24681091], [81.24014282, 16.24625015], [81.23985291, 16.24625015], [81.23985291, 16.24596977], [81.23958588, 16.24597168], [81.23958588, 16.24541664], [81.23929596, 16.24542046], [81.23929596, 16.24513054], [81.23902893, 16.24513817], [81.23902893, 16.2448616], [81.23874664, 16.2448616], [81.23874664, 16.24430466], [81.23847198, 16.24430466], [81.23847198, 16.24402809], [81.23819733, 16.24403], [81.23819733, 16.24347115], [81.23791504, 16.24347305], [81.23791504, 16.24319458], [81.23764038, 16.24319458], [81.23764038, 16.24263954], [81.23735809, 16.24263954], [81.23735809, 16.24236107], [81.23707581, 16.24236107], [81.23707581, 16.24180984], [81.23680878, 16.24180984], [81.23680878, 16.2412529], [81.23652649, 16.2412529], [81.23652649, 16.24097252], [81.23680878, 16.24097252], [81.23680878, 16.24069405], [81.23652649, 16.24069405], [81.23652649, 16.24041748], [81.23596954, 16.24041939], [81.23596954, 16.24014282], [81.23568726, 16.24014282], [81.23568726, 16.23986244], [81.23542023, 16.23986244], [81.23542023, 16.23957825], [81.23513794, 16.23958397], [81.23513794, 16.23847008], [81.23542023, 16.23847008], [81.23542023, 16.23819542], [81.23458099, 16.2381897], [81.23458099, 16.23791885], [81.23430634, 16.23792076], [81.23430634, 16.23735809], [81.23402405, 16.23736191], [81.23402405, 16.23708344], [81.23374939, 16.23708344], [81.23374939, 16.23680496], [81.2334671, 16.23681068], [81.2334671, 16.2365303], [81.23264313, 16.2365303], [81.23264313, 16.23625755], [81.23236084, 16.23625755], [81.23236084, 16.23596954], [81.23208618, 16.23597145], [81.23208618, 16.23569489], [81.23180389, 16.23569489], [81.23180389, 16.23541641], [81.23124695, 16.23542023], [81.23124695, 16.23513985], [81.23097229, 16.23513985], [81.23097229, 16.23458099], [81.23069763, 16.2345829], [81.23069763, 16.23430634], [81.23097229, 16.23431015], [81.23097229, 16.23180962], [81.23069763, 16.23180962], [81.23069763, 16.23153114], [81.23014069, 16.23153114], [81.23014069, 16.23125076], [81.2298584, 16.23125076], [81.2298584, 16.23069], [81.22958374, 16.23069382], [81.22958374, 16.23013878], [81.22930908, 16.23013878], [81.22930908, 16.22958374], [81.22902679, 16.22958374], [81.22902679, 16.22930527], [81.22875214, 16.2293129], [81.22875214, 16.22875023], [81.22846985, 16.22875023], [81.22846985, 16.22820282], [81.22820282, 16.22820282], [81.22820282, 16.22764015], [81.2279129, 16.22764015], [81.2279129, 16.22709274], [81.22763824, 16.22709274], [81.22763824, 16.22680092], [81.22736359, 16.22680473], [81.22736359, 16.2262516], [81.2270813, 16.2262516], [81.2270813, 16.22569084], [81.22680664, 16.22569466], [81.22680664, 16.22514153], [81.22651672, 16.22514153], [81.22651672, 16.22485924], [81.22624969, 16.22485924], [81.22624969, 16.22430992], [81.22598267, 16.22430992], [81.22598267, 16.22374916], [81.22569275, 16.22374916], [81.22569275, 16.22319031], [81.22541809, 16.22319412], [81.22541809, 16.22263718], [81.2251358, 16.22264099], [81.2251358, 16.22236061], [81.22486115, 16.22236061], [81.22486115, 16.22180557], [81.22458649, 16.22180939], [81.22458649, 16.22125053], [81.22429657, 16.22125053], [81.22429657, 16.22068977], [81.22402954, 16.22069359], [81.22402954, 16.22041512], [81.22374725, 16.22042084], [81.22374725, 16.21986008], [81.2234726, 16.21986198], [81.2234726, 16.21930695], [81.22319794, 16.21931076], [81.22319794, 16.21875], [81.22291565, 16.21875], [81.22291565, 16.21819305], [81.22264099, 16.21819305], [81.22264099, 16.21763802], [81.2223587, 16.21763992], [81.2223587, 16.21735954], [81.22208405, 16.21736145], [81.22208405, 16.21680641], [81.22180939, 16.21681023], [81.22180939, 16.21624947], [81.2215271, 16.21624947], [81.2215271, 16.21569061], [81.22125244, 16.21569443], [81.22125244, 16.21513939], [81.22097015, 16.21515083], [81.22097015, 16.21458054], [81.2206955, 16.21458054], [81.2206955, 16.2140274], [81.22041321, 16.21403122], [81.22041321, 16.21375275], [81.22013855, 16.21375275], [81.22013855, 16.21319008], [81.21986389, 16.21319389], [81.21986389, 16.21264076], [81.2195816, 16.21264076], [81.2195816, 16.21208954], [81.21930695, 16.21208954], [81.21930695, 16.21153069], [81.21901703, 16.21153069], [81.21901703, 16.21096992], [81.21875, 16.21097183], [81.21875, 16.21041679], [81.21848297, 16.21042061], [81.21848297, 16.20985985], [81.21819305, 16.20986176], [81.21819305, 16.20902634], [81.2179184, 16.20902634], [81.2179184, 16.2084713], [81.21763611, 16.2084713], [81.21763611, 16.20763969], [81.21736145, 16.20763969], [81.21736145, 16.20708084], [81.21708679, 16.20708275], [81.21708679, 16.20624924], [81.21679688, 16.20625114], [81.21679688, 16.20569038], [81.21652985, 16.2056942], [81.21652985, 16.20486069], [81.21624756, 16.20486069], [81.21624756, 16.20430946], [81.2159729, 16.20430946], [81.2159729, 16.20347023], [81.21569824, 16.20347214], [81.21569061, 16.2029171], [81.21541595, 16.20292091], [81.21541595, 16.20207977], [81.2151413, 16.20208359], [81.2151413, 16.20152855], [81.21485901, 16.20153046], [81.21485901, 16.20070267], [81.21457672, 16.20070267], [81.21457672, 16.19986153], [81.21430206, 16.19986153], [81.21430206, 16.19902992], [81.2140274, 16.19903183], [81.2140274, 16.19819069], [81.21375275, 16.1981945], [81.21375275, 16.19735909], [81.21347046, 16.19735909], [81.21347046, 16.19625092], [81.2131958, 16.19625092], [81.2131958, 16.19542122], [81.21290588, 16.19542122], [81.21290588, 16.19458008], [81.21263885, 16.19458389], [81.21263885, 16.19375038], [81.21235657, 16.19375038], [81.21235657, 16.19292068], [81.21208191, 16.19292068], [81.21208191, 16.19207954], [81.21180725, 16.19208336], [81.21180725, 16.19124985], [81.21152496, 16.19124985], [81.21152496, 16.19013977], [81.21125031, 16.19013977], [81.21125031, 16.18931007], [81.21098328, 16.18931007], [81.21098328, 16.18847275], [81.21069336, 16.18847275], [81.21069336, 16.18736267], [81.2104187, 16.18736267], [81.2104187, 16.18653107], [81.21013641, 16.18653107], [81.21013641, 16.18568993], [81.20986176, 16.18569374], [81.20986176, 16.18514061], [81.2095871, 16.18514061], [81.2095871, 16.18457985], [81.20930481, 16.18458366], [81.20930481, 16.18403053], [81.20903015, 16.18403053], [81.20903015, 16.18320084], [81.20874786, 16.18320084], [81.20874786, 16.18263817], [81.20847321, 16.18263817], [81.20847321, 16.18208122], [81.20819092, 16.18208313], [81.20819092, 16.18124962], [81.20791626, 16.18124962], [81.20791626, 16.18069077], [81.2076416, 16.18069458], [81.2076416, 16.18013954], [81.20735931, 16.18013954], [81.20735931, 16.17958069], [81.20708466, 16.1795826], [81.20708466, 16.17874908], [81.20681, 16.17875099], [81.20681, 16.17791939], [81.20652771, 16.17791939], [81.20652771, 16.17708015], [81.20625305, 16.17708206], [81.20625305, 16.1768055], [81.20569611, 16.17681122], [81.20569611, 16.17653084], [81.20540619, 16.17653084], [81.20540619, 16.17597961], [81.20513916, 16.17597961], [81.20513916, 16.17486191], [81.20541382, 16.17486382], [81.20541382, 16.17375183], [81.20513916, 16.17375183], [81.20513916, 16.17264175], [81.20485687, 16.17264175], [81.20485687, 16.17153168], [81.20458221, 16.17153168], [81.20458221, 16.17069054], [81.20430756, 16.17069435], [81.20430756, 16.16986084], [81.20402527, 16.16986084], [81.20402527, 16.1693058], [81.20374298, 16.16930962], [81.20374298, 16.16792107], [81.2040329, 16.16792107], [81.2040329, 16.16485977], [81.20375061, 16.16486168], [81.20375061, 16.16402817], [81.20347595, 16.16403961], [81.20347595, 16.16319275], [81.20319366, 16.16319466], [81.20319366, 16.16152763], [81.20291901, 16.16152954], [81.20291901, 16.15681076], [81.20318604, 16.15681076], [81.20318604, 16.15570068], [81.20347595, 16.15570068], [81.20347595, 16.15458107], [81.20375061, 16.15458298], [81.20375061, 16.15402794], [81.2040329, 16.15402985], [81.2040329, 16.15208054], [81.20430756, 16.15208244], [81.20430756, 16.14958382], [81.20402527, 16.14958382], [81.20402527, 16.14930534], [81.20374298, 16.14931107], [81.20374298, 16.14847183], [81.20347595, 16.14847374], [81.20347595, 16.14819527], [81.20318604, 16.1482029], [81.20318604, 16.14792061], [81.20291901, 16.14792061], [81.20291901, 16.14707947], [81.20263672, 16.14708328], [81.20263672, 16.14680481], [81.20236206, 16.14680481], [81.20236206, 16.14541626], [81.20207977, 16.14542007], [81.20207977, 16.1451416], [81.20180511, 16.1451416], [81.20180511, 16.14485931], [81.20124817, 16.14485931], [81.20124817, 16.14458084], [81.20014191, 16.14458084], [81.20014191, 16.1451416], [81.20041656, 16.1451416], [81.20041656, 16.14653015], [81.20014191, 16.14652824], [81.20014191, 16.14736176], [81.19958496, 16.14736176], [81.19958496, 16.14708328], [81.19902802, 16.14708328], [81.19902802, 16.14680481], [81.19847107, 16.14680481], [81.19847107, 16.14541626], [81.19819641, 16.14542007], [81.19819641, 16.14375114], [81.19790649, 16.14375114], [81.19790649, 16.14347076], [81.19763947, 16.14347267], [81.19763947, 16.1431942], [81.19736481, 16.1431942], [81.19736481, 16.14291954], [81.19680786, 16.14292908], [81.19680786, 16.14264107], [81.19568634, 16.14264107], [81.19568634, 16.14292908], [81.19041443, 16.14291954], [81.19041443, 16.1431942], [81.18902588, 16.1431942], [81.18902588, 16.14291954], [81.18875122, 16.14291954], [81.18875122, 16.1431942], [81.18819427, 16.1431942], [81.18819427, 16.14347267], [81.18763733, 16.14347076], [81.18763733, 16.14375114], [81.18708038, 16.14375114], [81.18708038, 16.14402962], [81.18569946, 16.14402962], [81.18569946, 16.14375114], [81.18514252, 16.14375114], [81.18514252, 16.14347076], [81.18264008, 16.14347267], [81.18264008, 16.14291573], [81.18319702, 16.14292908], [81.18319702, 16.14264107], [81.18402863, 16.14264107], [81.18402863, 16.14236069], [81.18514252, 16.14236069], [81.18514252, 16.14264107], [81.18624878, 16.14264107], [81.18624878, 16.14292908], [81.18736267, 16.14292908], [81.18736267, 16.14264107], [81.18763733, 16.14264107], [81.18763733, 16.14292908], [81.18846893, 16.14292908], [81.18846893, 16.14264107], [81.18863678, 16.14264107], [81.18958282, 16.14264107], [81.18958282, 16.14236069], [81.1904068, 16.14236069], [81.1904068, 16.14208031], [81.19097137, 16.14208412], [81.19097137, 16.14180565], [81.19235992, 16.14180946], [81.19235992, 16.14153099], [81.19374847, 16.14153099], [81.19374847, 16.14125061], [81.19487, 16.14125061], [81.19486237, 16.14097214], [81.19708252, 16.14097023], [81.19708252, 16.14125061], [81.19735718, 16.14125061], [81.19735718, 16.14097023], [81.19819641, 16.14097023], [81.19819641, 16.14125061], [81.19875336, 16.14125061], [81.19875336, 16.14153099], [81.19930267, 16.14153099], [81.19930267, 16.14180946], [81.19985962, 16.14180946], [81.19985962, 16.14236069], [81.20014191, 16.14236069], [81.20014191, 16.1431942], [81.20153046, 16.1431942], [81.20153046, 16.14291573], [81.20181274, 16.14292908], [81.20181274, 16.14236069], [81.20153046, 16.14236069], [81.20153046, 16.14097023], [81.20124817, 16.14097214], [81.20124817, 16.13986206], [81.20096588, 16.13986969], [81.20096588, 16.13820076], [81.20067596, 16.13820076], [81.20067596, 16.13597107], [81.20041656, 16.13597488], [81.20041656, 16.13541603], [81.20014191, 16.13541985], [81.20014191, 16.13402939], [81.19985962, 16.13402939], [81.19985962, 16.13319016], [81.19958496, 16.13319397], [81.19958496, 16.13264084], [81.19930267, 16.13264084], [81.19930267, 16.13207817], [81.19902802, 16.13208389], [81.19902802, 16.13152695], [81.19875336, 16.13153076], [81.19875336, 16.13042068], [81.19847107, 16.13042068], [81.19847107, 16.12957954], [81.19819641, 16.12958336], [81.19819641, 16.12847137], [81.19791412, 16.12847137], [81.19791412, 16.12652779], [81.19763947, 16.12652969], [81.19763947, 16.12597084], [81.19736481, 16.12597275], [81.19736481, 16.12513924], [81.19708252, 16.12514114], [81.19708252, 16.12458038], [81.19680786, 16.1245842], [81.19680786, 16.12375069], [81.19652557, 16.12375069], [81.19652557, 16.12319374], [81.19625092, 16.12319374], [81.19625092, 16.12236023], [81.19596863, 16.12236023], [81.19596863, 16.12153053], [81.19568634, 16.12153053], [81.19568634, 16.12070274], [81.19541931, 16.12070274], [81.19541931, 16.12014008], [81.19513702, 16.12014008], [81.19513702, 16.11930084], [81.19486237, 16.11930466], [81.19486237, 16.11847305], [81.19458008, 16.11847305], [81.19458008, 16.11763763], [81.19430542, 16.11763763], [81.19430542, 16.11680794], [81.19403076, 16.11680984], [81.19403076, 16.11597061], [81.19374847, 16.11597252], [81.19374847, 16.11541939], [81.19346619, 16.11541939], [81.19346619, 16.11458015], [81.19319153, 16.11458397], [81.19319153, 16.11375046], [81.19291687, 16.11375046], [81.19291687, 16.1129303], [81.19264221, 16.1129303], [81.19264221, 16.11236], [81.19235992, 16.11236191], [81.19235992, 16.1115284], [81.1920929, 16.1115303], [81.1920929, 16.11069107], [81.19180298, 16.11069489], [81.19180298, 16.11013985], [81.19152832, 16.11013985], [81.19152832, 16.10931015], [81.19124603, 16.10931015], [81.19124603, 16.10874939], [81.19097137, 16.10874939], [81.19097137, 16.10791969], [81.19069672, 16.10791969], [81.19069672, 16.10708046], [81.19041443, 16.10708427], [81.19041443, 16.10652733], [81.19013977, 16.10653114], [81.19013977, 16.1056881], [81.18985748, 16.10569382], [81.18985748, 16.10514069], [81.18958282, 16.10514069], [81.18958282, 16.10430908], [81.18930817, 16.10430908], [81.18930817, 16.10346985], [81.18902588, 16.10347176], [81.18902588, 16.10291862], [81.18873596, 16.10292053], [81.18873596, 16.10235977], [81.18846893, 16.10236168], [81.18846893, 16.10180473], [81.18819427, 16.10180473], [81.18819427, 16.10124969], [81.18791962, 16.10124969], [81.18791962, 16.10070038], [81.18763733, 16.10070038], [81.18763733, 16.10013962], [81.18736267, 16.10013962], [81.18736267, 16.09958076], [81.18708038, 16.09958267], [81.18708038, 16.09902763], [81.18681335, 16.09902954], [81.18681335, 16.09847069], [81.18653107, 16.0984726], [81.18653107, 16.09819412], [81.18624878, 16.09819412], [81.18624878, 16.09763908], [81.18597412, 16.09763908], [81.18597412, 16.09708214], [81.18569183, 16.09708214], [81.18569183, 16.0965271], [81.18541718, 16.09653091], [81.18541718, 16.09597015], [81.18514252, 16.09597206], [81.18514252, 16.09541702], [81.18486023, 16.09542084], [81.18486023, 16.09486008], [81.18458557, 16.09486389], [81.18458557, 16.09430504], [81.18430328, 16.09431076], [81.18430328, 16.09375191], [81.18402863, 16.09375191], [81.18402863, 16.09346962], [81.18374634, 16.09346962], [81.18374634, 16.09291649], [81.18347168, 16.0929203], [81.18347168, 16.09236145], [81.18319702, 16.09236145], [81.18319702, 16.09180641], [81.1829071, 16.09181976], [81.1829071, 16.09124756], [81.18264008, 16.09124756], [81.18264008, 16.09069061], [81.18235779, 16.09069443], [81.18235779, 16.09013748], [81.18208313, 16.09013748], [81.18208313, 16.08958054], [81.18180847, 16.08958244], [81.18180847, 16.08930779], [81.18152618, 16.08930969], [81.18152618, 16.08876038], [81.18125153, 16.08876038], [81.18125153, 16.08819008], [81.18096924, 16.08819389], [81.18096924, 16.08763885], [81.18068695, 16.08764076], [81.18068695, 16.08736038], [81.18041992, 16.08736038], [81.18041992, 16.08681107], [81.18013763, 16.08681107], [81.18013763, 16.08625031], [81.17986298, 16.08625031], [81.17986298, 16.08568954], [81.17958069, 16.08569527], [81.17958069, 16.08541679], [81.17930603, 16.08542061], [81.17930603, 16.08485985], [81.17903137, 16.08486176], [81.17903137, 16.08430481], [81.17874908, 16.08430481], [81.17874908, 16.08374977], [81.1784668, 16.08374977], [81.1784668, 16.08346939], [81.17819214, 16.0834713], [81.17819214, 16.08291626], [81.17791748, 16.08292007], [81.17791748, 16.08236122], [81.17763519, 16.08236122], [81.17763519, 16.08180618], [81.17736053, 16.08181], [81.17736053, 16.08152962], [81.17708588, 16.08152962], [81.17708588, 16.08097267], [81.17680359, 16.08097267], [81.17680359, 16.08041763], [81.17664337, 16.08041573], [81.17652893, 16.08041954], [81.17652893, 16.07986259], [81.17624664, 16.07986259], [81.17624664, 16.07959175], [81.17597198, 16.07959175], [81.17597198, 16.07902908], [81.17569733, 16.07902908], [81.17569733, 16.07846832], [81.17541504, 16.07847023], [81.17541504, 16.0779171], [81.17514038, 16.07792091], [81.17514038, 16.07764053], [81.17485809, 16.07764053], [81.17485809, 16.07707977], [81.17458344, 16.07708359], [81.17458344, 16.07653046], [81.17430878, 16.07653046], [81.17430878, 16.0759697], [81.17402649, 16.0759716], [81.17402649, 16.07569695], [81.17375946, 16.07570076], [81.17375946, 16.07513809], [81.17346954, 16.07513809], [81.17346954, 16.07458115], [81.17319489, 16.07458305], [81.17319489, 16.07402611], [81.17292023, 16.07402992], [81.17292023, 16.07374954], [81.17263794, 16.07374954], [81.17263794, 16.07319069], [81.17236328, 16.0731945], [81.17236328, 16.07263947], [81.17208099, 16.07263947], [81.17208099, 16.07208061], [81.17180634, 16.07208252], [81.17180634, 16.07152748], [81.17151642, 16.07152939], [81.17151642, 16.07097054], [81.17124939, 16.07097244], [81.17124939, 16.07069588], [81.17097473, 16.07069588], [81.17097473, 16.07013893], [81.17070007, 16.07014084], [81.17070007, 16.06958008], [81.17041779, 16.06958389], [81.17041779, 16.06902695], [81.17014313, 16.06903076], [81.17014313, 16.06847191], [81.16986084, 16.06847382], [81.16986084, 16.06791687], [81.16958618, 16.06792068], [81.16958618, 16.06764984], [81.16929626, 16.06764984], [81.16929626, 16.06707954], [81.16902924, 16.06708336], [81.16902924, 16.06652832], [81.16874695, 16.06653023], [81.16874695, 16.06596947], [81.16847229, 16.06596947], [81.16847229, 16.06541634], [81.16819763, 16.06542015], [81.16819763, 16.0648613], [81.16791534, 16.0648613], [81.16791534, 16.06430626], [81.16763306, 16.06430817], [81.16763306, 16.06402969], [81.1673584, 16.06402969], [81.1673584, 16.06347084], [81.16708374, 16.06347275], [81.16708374, 16.0629158], [81.16680908, 16.06291962], [81.16680908, 16.06236076], [81.16652679, 16.06236076], [81.16652679, 16.06180954], [81.16625214, 16.06180954], [81.16625214, 16.06125069], [81.16596985, 16.06125069], [81.16596985, 16.06097031], [81.16569519, 16.06097221], [81.16569519, 16.06041527], [81.1654129, 16.06042099], [81.1654129, 16.05986023], [81.16513824, 16.05986023], [81.16513824, 16.05931091], [81.16485596, 16.05931091], [81.16485596, 16.05875015], [81.16456604, 16.05875015], [81.16456604, 16.05820084], [81.16430664, 16.05820084], [81.16430664, 16.05792046], [81.16401672, 16.05792046], [81.16401672, 16.0573597], [81.16374969, 16.0573616], [81.16374969, 16.05680466], [81.16347504, 16.05680466], [81.16347504, 16.05624962], [81.16319275, 16.05624962], [81.16319275, 16.05597115], [81.16291809, 16.05597305], [81.16291809, 16.05541611], [81.1626358, 16.05541992], [81.1626358, 16.05486107], [81.16236115, 16.05486107], [81.16236115, 16.05455017], [81.16236115, 16.05430603], [81.16208649, 16.05430603], [81.16208649, 16.05402756], [81.1618042, 16.05402756], [81.1618042, 16.05347252], [81.16152954, 16.05347252], [81.16152954, 16.05291748], [81.16124725, 16.05291939], [81.16124725, 16.05235863], [81.1609726, 16.05235863], [81.1609726, 16.05207825], [81.16069794, 16.05208397], [81.16069794, 16.05152893], [81.16042328, 16.05153084], [81.16042328, 16.05096817], [81.16014099, 16.05097008], [81.16014099, 16.05041885], [81.1598587, 16.05042076], [81.1598587, 16.05014038], [81.15957642, 16.05014038], [81.15957642, 16.04957962], [81.15930176, 16.04958344], [81.15930176, 16.04902649], [81.1590271, 16.0490303], [81.1590271, 16.04846954], [81.15875244, 16.04847145], [81.15875244, 16.04819489], [81.15847015, 16.04819489], [81.15847015, 16.04763985], [81.15820313, 16.04763985], [81.15820313, 16.04708099], [81.15791321, 16.0470829], [81.15791321, 16.04652786], [81.15763855, 16.04652786], [81.15763855, 16.04624939], [81.15735626, 16.04624939], [81.15735626, 16.04569054], [81.1570816, 16.04569435], [81.1570816, 16.04513931], [81.15680695, 16.04514122], [81.15680695, 16.04458046], [81.15652466, 16.04458427], [81.15652466, 16.04402733], [81.15625, 16.04403114], [81.15625, 16.04346275], [81.15597534, 16.04347229], [81.15597534, 16.04291725], [81.15569305, 16.04292107], [81.15569305, 16.04236031], [81.1554184, 16.04236031], [81.1554184, 16.0418129], [81.15513611, 16.0418129], [81.15513611, 16.04125023], [81.15486145, 16.04125023], [81.15486145, 16.04071045], [81.15458679, 16.04071045], [81.15458679, 16.04042053], [81.15429688, 16.04042053], [81.15429688, 16.03986168], [81.15402985, 16.03986168], [81.15402985, 16.03930473], [81.1543045, 16.03930473], [81.1543045, 16.0387516], [81.15402985, 16.0387516], [81.15402985, 16.03846931], [81.1534729, 16.03847313], [81.1534729, 16.03819466], [81.15319824, 16.03819466], [81.15319061, 16.03763962], [81.15291595, 16.03763962], [81.15291595, 16.03708076], [81.1526413, 16.03708267], [81.1526413, 16.03652954], [81.15235901, 16.03652954], [81.15235901, 16.03597069], [81.15208435, 16.0359726], [81.15208435, 16.03541946], [81.15180206, 16.03541946], [81.15180206, 16.03486061], [81.1515274, 16.03486061], [81.1515274, 16.03458023], [81.15125275, 16.03458405], [81.15125275, 16.03402519], [81.15097046, 16.03403091], [81.15097046, 16.03347015], [81.1506958, 16.03347206], [81.1506958, 16.03319359], [81.15041351, 16.03319359], [81.15041351, 16.03263855], [81.15013885, 16.03264046], [81.15013885, 16.03236008], [81.1498642, 16.03236198], [81.1498642, 16.03180313], [81.14958954, 16.03181076], [81.14958954, 16.03125], [81.14930725, 16.03125], [81.14930725, 16.03096962], [81.14902496, 16.03097153], [81.14902496, 16.03041649], [81.14875031, 16.0304203], [81.14875031, 16.03013992], [81.14848328, 16.03013992], [81.14848328, 16.02958107], [81.14819336, 16.02958488], [81.14819336, 16.02930641], [81.1479187, 16.02931023], [81.1479187, 16.02902985], [81.14763641, 16.02902985], [81.14763641, 16.02848053], [81.14736176, 16.02848053], [81.14736176, 16.02819061], [81.1470871, 16.02819443], [81.1470871, 16.02791595], [81.14679718, 16.02791977], [81.14679718, 16.02736282], [81.14653015, 16.02736282], [81.14653015, 16.02708244], [81.14624786, 16.02708244], [81.14624786, 16.0265274], [81.14597321, 16.02653122], [81.14597321, 16.02625275], [81.14569092, 16.02625275], [81.14569092, 16.02596855], [81.14541626, 16.02597237], [81.14541626, 16.02541733], [81.1451416, 16.02541924], [81.1451416, 16.02514076], [81.14485931, 16.02514076], [81.14485931, 16.02485847], [81.14457703, 16.02485847], [81.14457703, 16.02430916], [81.14430237, 16.02430916], [81.14430237, 16.02403069], [81.14402771, 16.02403069], [81.14402771, 16.0237484], [81.14375305, 16.0237484], [81.14375305, 16.02319908], [81.14346313, 16.02319908], [81.14346313, 16.02264023], [81.14319611, 16.02264023], [81.14319611, 16.02207947], [81.14291382, 16.02208328], [81.14291382, 16.02152634], [81.14263916, 16.02153015], [81.14263916, 16.02096939], [81.1423645, 16.0209713], [81.1423645, 16.02041626], [81.14208221, 16.02042007], [81.14208221, 16.01986122], [81.14180756, 16.01986122], [81.14180756, 16.01931], [81.14154053, 16.01931], [81.14152527, 16.01919937], [81.14152527, 16.01874924], [81.14137268, 16.01874924], [81.14125061, 16.01875114], [81.14125061, 16.01844978], [81.14125061, 16.0181942], [81.14097595, 16.0181942], [81.14097595, 16.01769257], [81.14097595, 16.01680565], [81.14068604, 16.01680946], [81.14068604, 16.01542091], [81.14041901, 16.01542091], [81.14041901, 16.01375008], [81.14013672, 16.01375008], [81.14013672, 16.01207924], [81.13986206, 16.01208305], [81.13986206, 16.00985909], [81.13957977, 16.00985909], [81.13957977, 16.00764084], [81.13986206, 16.00764084], [81.13986206, 16.00653076], [81.13957977, 16.00653076], [81.13957977, 16.0051403], [81.13986206, 16.0051403], [81.13986206, 16.0031929], [81.13957977, 16.00319481], [81.13957977, 16.00013924], [81.13957977, 15.99986172], [81.13957977, 15.99763966], [81.13931274, 15.99763966], [81.13931274, 15.99735928], [81.13903046, 15.99736214], [81.13903046, 15.99597359], [81.13930511, 15.99597359], [81.13930511, 15.99569321], [81.13957977, 15.99569321], [81.13957977, 15.99513912], [81.13986206, 15.99514198], [81.13986206, 15.99431038], [81.14013672, 15.99431038], [81.14013672, 15.99403191], [81.14041901, 15.99403191], [81.14041901, 15.99347115], [81.14069366, 15.99347115], [81.14069366, 15.99180508], [81.14097595, 15.99181175], [81.14097595, 15.99097061], [81.14125061, 15.99097347], [81.14125061, 15.98986053], [81.14097595, 15.98986053], [81.14097595, 15.98875141], [81.14125061, 15.98875141], [81.14125061, 15.98847103], [81.14152527, 15.98847294], [81.14152527, 15.98736095], [81.14180756, 15.98736095], [81.14180756, 15.98596954], [81.14208221, 15.98597336], [81.14208221, 15.98513889], [81.14235687, 15.9851408], [81.14235687, 15.98486137], [81.14263916, 15.98486137], [81.14263916, 15.9845829], [81.14291382, 15.9845829], [81.14291382, 15.98430443], [81.14346313, 15.9843111], [81.14346313, 15.98236275], [81.14402771, 15.98236275], [81.14402771, 15.98264122], [81.14430237, 15.98264122], [81.14430237, 15.98236275], [81.14485931, 15.98236275], [81.14485931, 15.98181057], [81.1451416, 15.98181057], [81.1451416, 15.98153114], [81.14541626, 15.98153114], [81.14541626, 15.98097038], [81.14569092, 15.98097229], [81.14569092, 15.98069382], [81.14597321, 15.98069382], [81.14597321, 15.97930622], [81.14569092, 15.97931099], [81.14569092, 15.97903061], [81.14541626, 15.97903061], [81.14541626, 15.97846985], [81.1451416, 15.97847176], [81.1451416, 15.97764015], [81.14541626, 15.97764015], [81.14541626, 15.97486019], [81.14597321, 15.9748621], [81.14597321, 15.97430611], [81.14569092, 15.97430611], [81.14569092, 15.97375011], [81.14402771, 15.97375202], [81.14402771, 15.97347164], [81.14375305, 15.97347164], [81.14375305, 15.97319412], [81.14319611, 15.97319412], [81.14319611, 15.97291565], [81.1423645, 15.97291565], [81.1423645, 15.97319412], [81.14152527, 15.97319412], [81.14152527, 15.97347164], [81.14097595, 15.97347164], [81.14097595, 15.97319412], [81.13986206, 15.97319412], [81.13986206, 15.97347164], [81.13903046, 15.97347164], [81.13903046, 15.97319412], [81.13874817, 15.97319412], [81.13874817, 15.97347164], [81.13819122, 15.97347164], [81.13819122, 15.97375202], [81.13680267, 15.97375202], [81.13680267, 15.97402954], [81.13569641, 15.97402763], [81.13569641, 15.97430611], [81.13541412, 15.97430611], [81.13541412, 15.97402763], [81.13346863, 15.97402954], [81.13346863, 15.97375202], [81.13263702, 15.97375202], [81.13263702, 15.97347164], [81.13236237, 15.97347164], [81.13236237, 15.97319412], [81.13208008, 15.97319412], [81.13208008, 15.97291565], [81.13152313, 15.97292042], [81.13152313, 15.97264194], [81.13124847, 15.97264194], [81.13124847, 15.97235966], [81.13097382, 15.97236156], [81.13097382, 15.97208405], [81.13069153, 15.97208405], [81.13069153, 15.97180557], [81.13041687, 15.97181034], [81.13041687, 15.97124004], [81.13069153, 15.97124958], [81.13069153, 15.97041798], [81.13096619, 15.97042179], [81.13096619, 15.96875191], [81.13069153, 15.96875191], [81.13069153, 15.96736145], [81.13041687, 15.96736145], [81.13041687, 15.96708298], [81.13014221, 15.96708298], [81.13014221, 15.96680546], [81.12985992, 15.96681023], [81.12985992, 15.96653175], [81.1295929, 15.96653175], [81.1295929, 15.96597099], [81.12930298, 15.96597099], [81.12930298, 15.96579075], [81.12930298, 15.96513939], [81.12902832, 15.9651413], [81.12902832, 15.96458054], [81.12875366, 15.9645834], [81.12875366, 15.9640274], [81.12845612, 15.96402931], [81.12845612, 15.96347141], [81.12819672, 15.96347332], [81.12819672, 15.96319485], [81.12791443, 15.96319485], [81.12791443, 15.96291733], [81.12735748, 15.96291924], [81.12735748, 15.96264076], [81.12708282, 15.96264076], [81.12708282, 15.96236134], [81.12680817, 15.96236134], [81.12680817, 15.96208286], [81.12652588, 15.96208286], [81.12652588, 15.96180534], [81.12625122, 15.96181202], [81.12625122, 15.96153069], [81.12596893, 15.96153069], [81.12596893, 15.96125126], [81.12568665, 15.96125126], [81.12568665, 15.96097088], [81.12513733, 15.96097279], [81.12513733, 15.96069527], [81.12486267, 15.96069527], [81.12486267, 15.96041679], [81.12431335, 15.96042061], [81.12431335, 15.96014118], [81.12403107, 15.96014118], [81.12403107, 15.9598608], [81.12374878, 15.9598608], [81.12374878, 15.95958328], [81.12347412, 15.95958328], [81.12347412, 15.9590292], [81.12319183, 15.95903111], [81.12316132, 15.95875072], [81.12291718, 15.95875072], [81.12291718, 15.95847034], [81.12236023, 15.95847321], [81.12236023, 15.95819473], [81.12208557, 15.95819473], [81.12208557, 15.95791721], [81.12152863, 15.95792103], [81.12152863, 15.95764065], [81.12124634, 15.95764065], [81.12124634, 15.95736122], [81.12069702, 15.95736122], [81.12069702, 15.95708466], [81.12041473, 15.95708466], [81.12041473, 15.95680428], [81.12014008, 15.95681095], [81.12014008, 15.95653057], [81.11985779, 15.95653057], [81.11985779, 15.95625973], [81.11958313, 15.95625973], [81.11958313, 15.95597267], [81.11930847, 15.95597267], [81.11930847, 15.9556942], [81.11875153, 15.9556942], [81.11875153, 15.95541573], [81.11846924, 15.95542145], [81.11846924, 15.95514107], [81.11818695, 15.95514107], [81.11818695, 15.95485973], [81.11791992, 15.95485973], [81.11791992, 15.95458031], [81.11708069, 15.95458221], [81.11708069, 15.95430565], [81.11680603, 15.95431137], [81.11680603, 15.95403099], [81.11651611, 15.95403099], [81.11651611, 15.95374966], [81.1159668, 15.95374966], [81.1159668, 15.95347023], [81.11569214, 15.95347214], [81.11569214, 15.95319366], [81.11541748, 15.95320129], [81.11541748, 15.95292091], [81.11514282, 15.95292091], [81.11514282, 15.95263958], [81.11486053, 15.95263958], [81.11486053, 15.95236015], [81.11458588, 15.95236015], [81.11458588, 15.95208359], [81.11430359, 15.95208359], [81.11430359, 15.95180416], [81.11374664, 15.95181084], [81.11374664, 15.95125008], [81.11345673, 15.95125008], [81.11345673, 15.9509697], [81.11319733, 15.9509716], [81.11319733, 15.95069408], [81.11264038, 15.95069408], [81.11264038, 15.95041561], [81.11235809, 15.95042133], [81.11235809, 15.95014], [81.11207581, 15.95014], [81.11207581, 15.94985962], [81.11152649, 15.94986153], [81.11152649, 15.94958401], [81.11125183, 15.94958401], [81.11125183, 15.94930553], [81.11096954, 15.94931126], [81.11096954, 15.94902992], [81.11042023, 15.94902992], [81.11042023, 15.94874954], [81.11013794, 15.94874954], [81.11013794, 15.94847202], [81.10986328, 15.94847202], [81.10986328, 15.94791794], [81.10958099, 15.94791985], [81.10958099, 15.94764042], [81.10930634, 15.94764042], [81.10930634, 15.94736195], [81.10874939, 15.94736195], [81.10874939, 15.94707012], [81.10847473, 15.94708443], [81.10847473, 15.94680595], [81.10791779, 15.94680977], [81.10791779, 15.94653034], [81.10764313, 15.94653034], [81.10764313, 15.94625187], [81.10736084, 15.94625187], [81.10736084, 15.94597244], [81.10708618, 15.94597244], [81.10708618, 15.94569588], [81.10679626, 15.9456892], [81.10680389, 15.94541645], [81.10652924, 15.94542027], [81.10652924, 15.94514179], [81.10624695, 15.94514179], [81.10624695, 15.94485855], [81.10597229, 15.94486237], [81.10597229, 15.94458389], [81.10569763, 15.94458389], [81.10569763, 15.94430637], [81.10542297, 15.94432163], [81.10542297, 15.94402981], [81.10514069, 15.94402981], [81.10514069, 15.94375038], [81.1048584, 15.94375038], [81.1048584, 15.94347095], [81.10458374, 15.94347095], [81.10458374, 15.94291782], [81.10430908, 15.94291973], [81.10430908, 15.9426403], [81.10402679, 15.9426403], [81.10402679, 15.94236183], [81.10375214, 15.94236183], [81.10375214, 15.94208145], [81.10346985, 15.94208336], [81.10346985, 15.94180489], [81.10320282, 15.94180965], [81.10320282, 15.94153023], [81.10263824, 15.94153023], [81.10263824, 15.94126129], [81.10235596, 15.94126129], [81.10235596, 15.94097137], [81.1020813, 15.94097137], [81.1020813, 15.94069481], [81.10152435, 15.94069481], [81.10152435, 15.94041729], [81.10124969, 15.94042015], [81.10124969, 15.9398613], [81.10097504, 15.9398613], [81.10097504, 15.93958282], [81.10069275, 15.93958282], [81.10069275, 15.93930531], [81.10041809, 15.93931198], [81.10041809, 15.9390316], [81.1001358, 15.9390316], [81.1001358, 15.93875122], [81.09986115, 15.93875122], [81.09986115, 15.93847084], [81.09902954, 15.93847084], [81.09902954, 15.9382], [81.09874725, 15.9382], [81.09874725, 15.93791866], [81.09848022, 15.93791866], [81.09848022, 15.93763924], [81.09819794, 15.93763924], [81.09819794, 15.93736076], [81.09764099, 15.93736076], [81.09764099, 15.93708134], [81.0973587, 15.93708324], [81.0973587, 15.93680477], [81.09707642, 15.93680954], [81.09707642, 15.93653107], [81.09680176, 15.93653107], [81.09680176, 15.93625069], [81.0965271, 15.93625069], [81.0965271, 15.93597126], [81.09597015, 15.93597317], [81.09597015, 15.93569469], [81.0956955, 15.93569469], [81.0956955, 15.93541718], [81.09542084, 15.93542194], [81.09542084, 15.93513203], [81.09513855, 15.9351387], [81.09513855, 15.93486118], [81.09486389, 15.93486118], [81.09486389, 15.93458271], [81.0945816, 15.93458271], [81.0945816, 15.93430519], [81.09401703, 15.93431187], [81.09401703, 15.93403053], [81.09348297, 15.93403053], [81.09348297, 15.93375111], [81.09319305, 15.93375111], [81.09319305, 15.93347073], [81.0929184, 15.93347263], [81.0929184, 15.93319511], [81.09263611, 15.93319511], [81.09263611, 15.93291664], [81.09234619, 15.93292141], [81.09234619, 15.93264103], [81.09179688, 15.93264103], [81.09179688, 15.93236065], [81.09124756, 15.93236065], [81.09124756, 15.93207073], [81.0909729, 15.93208313], [81.0909729, 15.93180466], [81.09069824, 15.93181133], [81.09069061, 15.93153095], [81.0901413, 15.93153095], [81.0901413, 15.93125057], [81.08957672, 15.93125057], [81.08957672, 15.93097019], [81.08930206, 15.93097305], [81.08930206, 15.93069458], [81.0890274, 15.93069458], [81.0890274, 15.93041706], [81.08847046, 15.93042088], [81.08847046, 15.93014145], [81.0881958, 15.93014145], [81.0881958, 15.92986012], [81.08790588, 15.92986012], [81.08790588, 15.92957973], [81.08763885, 15.92958546], [81.08763885, 15.92902946], [81.08735657, 15.92903137], [81.08735657, 15.92875099], [81.08708191, 15.92875099], [81.08708191, 15.92819023], [81.08680725, 15.92819405], [81.08680725, 15.92791557], [81.08651733, 15.9279213], [81.08651733, 15.92735958], [81.08625031, 15.9273634], [81.08625031, 15.92680645], [81.08598328, 15.92681122], [81.08598328, 15.9262619], [81.08569336, 15.9262619], [81.08569336, 15.92597008], [81.0854187, 15.92597198], [81.0854187, 15.92569447], [81.08513641, 15.92569447], [81.08513641, 15.92541599], [81.08486176, 15.92542076], [81.08486176, 15.92514038], [81.0845871, 15.92514038], [81.0845871, 15.92486], [81.08429718, 15.92486], [81.08429718, 15.92457962], [81.08403015, 15.92458439], [81.08403015, 15.92430592], [81.08374786, 15.92431068], [81.08374786, 15.92374992], [81.08348083, 15.92374992], [81.08348083, 15.92346954], [81.08319092, 15.9234724], [81.08319092, 15.92319393], [81.0826416, 15.92319393], [81.0826416, 15.92291641], [81.08235931, 15.92292023], [81.08235931, 15.92263985], [81.08207703, 15.92263985], [81.08207703, 15.92236042], [81.08152771, 15.92236233], [81.08152771, 15.92208195], [81.08097076, 15.92208195], [81.08097076, 15.92180634], [81.08069611, 15.9218111], [81.08069611, 15.92152977], [81.08013916, 15.92152977], [81.08013916, 15.92125034], [81.07958221, 15.92125034], [81.07958221, 15.92097187], [81.07930756, 15.92097187], [81.07930756, 15.92069435], [81.07902527, 15.92069435], [81.07902527, 15.92041588], [81.07875061, 15.92041969], [81.07875061, 15.92013073], [81.07847595, 15.92014027], [81.07847595, 15.91986179], [81.07818604, 15.91986179], [81.07818604, 15.91958237], [81.07791901, 15.91958427], [81.07791901, 15.91902828], [81.07763672, 15.91903019], [81.07763672, 15.91874981], [81.0773468, 15.91874981], [81.0773468, 15.91846943], [81.07707977, 15.91847229], [81.07707977, 15.91819572], [81.07680511, 15.91819572], [81.07680511, 15.91763973], [81.07653046, 15.91763973], [81.07653046, 15.91735935], [81.07624817, 15.91736221], [81.07624817, 15.91708374], [81.07596588, 15.91709042], [81.07596588, 15.91681004], [81.07569122, 15.91681004], [81.07569122, 15.91649055], [81.07569122, 15.91624928], [81.07541656, 15.91624928], [81.07541656, 15.9159708], [81.07514191, 15.9159708], [81.07514191, 15.91569138], [81.07485962, 15.91569328], [81.07485962, 15.91541767], [81.07457733, 15.91541958], [81.07457733, 15.91486073], [81.07430267, 15.91486073], [81.07430267, 15.91458321], [81.07402802, 15.91458321], [81.07402802, 15.91430473], [81.07375336, 15.91431046], [81.07375336, 15.91403198], [81.07347107, 15.91403198], [81.07347107, 15.9137516], [81.07319641, 15.9137516], [81.07319641, 15.91347122], [81.07291412, 15.91347122], [81.07291412, 15.91319466], [81.07263947, 15.91319466], [81.07263947, 15.91291714], [81.07235718, 15.91292191], [81.07235718, 15.91264153], [81.07180786, 15.91264153], [81.07180786, 15.91236115], [81.07125092, 15.91236115], [81.07125092, 15.91208267], [81.07069397, 15.91208267], [81.07069397, 15.91152668], [81.07041931, 15.91152859], [81.07041931, 15.91125107], [81.07013702, 15.91125107], [81.07013702, 15.9109602], [81.06986237, 15.9109726], [81.06986237, 15.91069508], [81.06930542, 15.91069508], [81.06930542, 15.91013908], [81.06903076, 15.91014099], [81.06903076, 15.90986061], [81.06874847, 15.90986061], [81.06874847, 15.90958309], [81.06847382, 15.90958309], [81.06847382, 15.90902901], [81.06817627, 15.90903091], [81.06817627, 15.90875053], [81.06791687, 15.90875053], [81.06791687, 15.90847111], [81.06764221, 15.90847301], [81.06764221, 15.90791702], [81.06735992, 15.90792084], [81.06735992, 15.90764141], [81.0670929, 15.90764141], [81.0670929, 15.90736103], [81.06680298, 15.90736103], [81.06680298, 15.90681171], [81.06652832, 15.90681171], [81.06652832, 15.90653133], [81.06624603, 15.90653133], [81.06624603, 15.90597057], [81.06597137, 15.90597343], [81.06597137, 15.90569496], [81.06569672, 15.90569496], [81.06569672, 15.90513897], [81.0654068, 15.90515041], [81.0654068, 15.90486145], [81.06513977, 15.90486145], [81.06513977, 15.90458298], [81.06485748, 15.90458298], [81.06485748, 15.90430546], [81.06458282, 15.90431118], [81.06458282, 15.9040308], [81.06430817, 15.9040308], [81.06430817, 15.90347004], [81.06402588, 15.9034729], [81.06402588, 15.90319538], [81.06375122, 15.90319538], [81.06375122, 15.90291691], [81.06318665, 15.90292072], [81.06318665, 15.9026413], [81.06291962, 15.9026413], [81.06291962, 15.90235996], [81.06263733, 15.90235996], [81.06263733, 15.90209103], [81.0623703, 15.90209103], [81.0623703, 15.90181065], [81.06208038, 15.90181065], [81.06208038, 15.90153122], [81.06181335, 15.90153122], [81.06181335, 15.90125275], [81.06153107, 15.90125275], [81.06153107, 15.90097046], [81.06124878, 15.90097237], [81.06124878, 15.90069389], [81.06097412, 15.90069389], [81.06097412, 15.90041637], [81.06069183, 15.90042114], [81.06069183, 15.89986038], [81.06041718, 15.89986229], [81.06041718, 15.89958382], [81.06014252, 15.89958191], [81.06014252, 15.8993063], [81.05960083, 15.89931107], [81.05960083, 15.89901924], [81.05930328, 15.89902782], [81.05930328, 15.89819431], [81.05902863, 15.89819431], [81.05902863, 15.89791584], [81.05874634, 15.89792061], [81.05874634, 15.89764023], [81.05847168, 15.89764023], [81.05847168, 15.89735985], [81.05819702, 15.89735985], [81.05819702, 15.89708424], [81.05791473, 15.89708424], [81.05791473, 15.89652824], [81.05764008, 15.89653015], [81.05764008, 15.89596081], [81.05735779, 15.89597225], [81.05735779, 15.89569378], [81.05708313, 15.89569378], [81.05708313, 15.89541626], [81.05680847, 15.89542007], [81.05680847, 15.89513969], [81.05652618, 15.89513969], [81.05652618, 15.89486027], [81.05625153, 15.89486217], [81.05625153, 15.8945837], [81.05596924, 15.8945837], [81.05596924, 15.89430618], [81.05568695, 15.89431095], [81.05568695, 15.89375019], [81.05541992, 15.89375019], [81.05541992, 15.89347172], [81.05513763, 15.89347172], [81.05513763, 15.8931942], [81.05486298, 15.8931942], [81.05486298, 15.89264011], [81.05458069, 15.89264202], [81.05458069, 15.89207935], [81.05430603, 15.89208412], [81.05430603, 15.89152813], [81.05403137, 15.89153004], [81.05403137, 15.89124966], [81.05374908, 15.89124966], [81.05374908, 15.89096928], [81.05347443, 15.89097214], [81.05347443, 15.89069366], [81.05319214, 15.89069366], [81.05319214, 15.89041805], [81.05291748, 15.89041996], [81.05291748, 15.89015102], [81.05264282, 15.89015102], [81.05264282, 15.8898592], [81.05236053, 15.88986206], [81.05236053, 15.88958359], [81.05208588, 15.88958359], [81.05208588, 15.88930607], [81.05179596, 15.88931179], [81.05179596, 15.88875198], [81.05152893, 15.88875198], [81.05152893, 15.88847065], [81.05097198, 15.88847446], [81.05097198, 15.88819313], [81.05069733, 15.88819313], [81.05069733, 15.88736057], [81.05041504, 15.88736057], [81.05041504, 15.88708305], [81.05014038, 15.88708305], [81.05014038, 15.88652706], [81.04985809, 15.88653183], [81.04985809, 15.88597107], [81.04958344, 15.88597107], [81.04958344, 15.88569546], [81.04930878, 15.88569546], [81.04930878, 15.88513947], [81.04902649, 15.88514233], [81.04902649, 15.88458061], [81.04875183, 15.88458347], [81.04875183, 15.884305], [81.04846954, 15.88430977], [81.04846954, 15.88401985], [81.04819489, 15.88402653], [81.04819489, 15.88374901], [81.04763794, 15.88375092], [81.04763794, 15.88347054], [81.04736328, 15.8834734], [81.04736328, 15.88319492], [81.04708099, 15.88319111], [81.04708099, 15.8829174], [81.04680634, 15.88291931], [81.04680634, 15.88264084], [81.04651642, 15.88264084], [81.04651642, 15.88236141], [81.04624939, 15.88236141], [81.04624939, 15.88208294], [81.04597473, 15.88208294], [81.04597473, 15.88180542], [81.04541779, 15.88180923], [81.04541779, 15.88153076], [81.04486084, 15.88153076], [81.04486084, 15.88125134], [81.04458618, 15.88125134], [81.04458618, 15.88097954], [81.04429626, 15.88097954], [81.04429626, 15.88068962], [81.04402924, 15.88069534], [81.04402924, 15.88041687], [81.04374695, 15.88042068], [81.04374695, 15.88014126], [81.04347229, 15.88014126], [81.04347229, 15.87986088], [81.04319763, 15.87986088], [81.04319763, 15.87957954], [81.04291534, 15.87958336], [81.04291534, 15.87930679], [81.04264069, 15.87931156], [81.04264069, 15.87903118], [81.0423584, 15.87903118], [81.0423584, 15.8787508], [81.04207611, 15.8787508], [81.04207611, 15.87847137], [81.04152679, 15.87847328], [81.04152679, 15.87791729], [81.04123688, 15.8779211], [81.04123688, 15.87764072], [81.04070282, 15.87764072], [81.04070282, 15.8773613], [81.0404129, 15.8773613], [81.0404129, 15.87708473], [81.03986359, 15.87708473], [81.03986359, 15.87652874], [81.0395813, 15.87653065], [81.0395813, 15.87625122], [81.03930664, 15.87625122], [81.03930664, 15.87597275], [81.03874969, 15.87597275], [81.03874969, 15.87569046], [81.03847504, 15.87569523], [81.03847504, 15.87513828], [81.03820038, 15.87514114], [81.03820038, 15.87485123], [81.03791809, 15.87485981], [81.03791809, 15.87430668], [81.0376358, 15.87431145], [81.0376358, 15.87403107], [81.03736115, 15.87403107], [81.03736115, 15.87374973], [81.03708649, 15.87374973], [81.03708649, 15.87347031], [81.0368042, 15.87347221], [81.0368042, 15.87319374], [81.03624725, 15.87319374], [81.03624725, 15.87291622], [81.0359726, 15.87292099], [81.0359726, 15.87236023], [81.03569794, 15.87236023], [81.03569794, 15.87208366], [81.03541565, 15.87208366], [81.03541565, 15.87180614], [81.0348587, 15.87181091], [81.0348587, 15.87153053], [81.03457642, 15.87153053], [81.03457642, 15.87125015], [81.03430176, 15.87125015], [81.03430176, 15.87097168], [81.03375244, 15.87097168], [81.03375244, 15.87069416], [81.0331955, 15.87069416], [81.0331955, 15.87041569], [81.03291321, 15.87042141], [81.03291321, 15.87014008], [81.03263855, 15.87014008], [81.03263855, 15.8698597], [81.03236389, 15.8698597], [81.03235626, 15.86958027], [81.0320816, 15.86958408], [81.0320816, 15.86902809], [81.03180695, 15.86903858], [81.03180695, 15.86874962], [81.03151703, 15.86874962], [81.03151703, 15.86847019], [81.03125, 15.8684721], [81.03125, 15.86819363], [81.03097534, 15.86819363], [81.03097534, 15.86791801], [81.03069305, 15.86791992], [81.03069305, 15.86763954], [81.0304184, 15.86763954], [81.0304184, 15.86708164], [81.03013611, 15.86708355], [81.03013611, 15.86680603], [81.02986145, 15.86680984], [81.02986145, 15.86653042], [81.02958679, 15.86653042], [81.02958679, 15.8659811], [81.02929688, 15.8659811], [81.02929688, 15.86568928], [81.02902985, 15.86569405], [81.02902985, 15.86541557], [81.02874756, 15.86542034], [81.02874756, 15.86513996], [81.0284729, 15.86513996], [81.0284729, 15.86485958], [81.02819824, 15.86486244], [81.02819061, 15.86430645], [81.02791595, 15.86431026], [81.02791595, 15.86403179], [81.0276413, 15.86403179], [81.0276413, 15.86375046], [81.02735901, 15.86375046], [81.02735901, 15.86347198], [81.02708435, 15.86347198], [81.02708435, 15.86319256], [81.0265274, 15.86319256], [81.0265274, 15.8629179], [81.02597046, 15.8629179], [81.02597046, 15.86263657], [81.0256958, 15.86264038], [81.0256958, 15.86236191], [81.02540588, 15.86236191], [81.02540588, 15.86208057], [81.02513885, 15.86208439], [81.02513885, 15.86124897], [81.02485657, 15.86125183], [81.02485657, 15.86069107], [81.02458191, 15.86069584], [81.02458191, 15.86041737], [81.02401733, 15.86042023], [81.02401733, 15.86014175], [81.02375031, 15.86014175], [81.02375031, 15.85984993], [81.02319336, 15.85986137], [81.02319336, 15.8595829], [81.0229187, 15.8595829], [81.0229187, 15.85930538], [81.02263641, 15.85931015], [81.02263641, 15.85903168], [81.02236176, 15.85903168], [81.02236176, 15.8587513], [81.0220871, 15.8587513], [81.0220871, 15.85819054], [81.02180481, 15.8581953], [81.02180481, 15.85791683], [81.02153015, 15.85791969], [81.02153015, 15.85763931], [81.02124786, 15.85763931], [81.02124786, 15.85736084], [81.02097321, 15.85736084], [81.02097321, 15.85708141], [81.02069092, 15.85708332], [81.02069092, 15.85680485], [81.02041626, 15.85680962], [81.02041626, 15.85652924], [81.0201416, 15.85652924], [81.0201416, 15.85625076], [81.01985931, 15.85625076], [81.01985931, 15.85597134], [81.01958466, 15.85597324], [81.01958466, 15.85569477], [81.01930237, 15.85569477], [81.01930237, 15.85486126], [81.01902771, 15.85486126], [81.01902771, 15.85458279], [81.01875305, 15.85458279], [81.01875305, 15.85430527], [81.01847076, 15.85431194], [81.01847076, 15.85375118], [81.01819611, 15.85375118], [81.01819611, 15.8534708], [81.01791382, 15.8534708], [81.01791382, 15.85319519], [81.01763916, 15.85319519], [81.01763916, 15.85236073], [81.01735687, 15.85236073], [81.01735687, 15.85153103], [81.01706696, 15.85153103], [81.01706696, 15.85097027], [81.01680756, 15.85097313], [81.01680756, 15.85069466], [81.01652527, 15.85069466], [81.01652527, 15.85013866], [81.01625061, 15.85014057], [81.01625061, 15.84957981], [81.01597595, 15.84958458], [81.01597595, 15.84902859], [81.01568604, 15.84903145], [81.01568604, 15.84875107], [81.01541901, 15.84875107], [81.01541901, 15.84846973], [81.01513672, 15.8484726], [81.01513672, 15.84763813], [81.01486206, 15.84764099], [81.01486206, 15.84735966], [81.01457977, 15.84736347], [81.01457977, 15.84708214], [81.01430511, 15.84708214], [81.01430511, 15.84680557], [81.01403046, 15.84681129], [81.01403046, 15.84624958], [81.01374817, 15.84624958], [81.01374817, 15.84597015], [81.01347351, 15.84597206], [81.01347351, 15.84569359], [81.01319122, 15.84569359], [81.01319122, 15.8451376], [81.01291656, 15.84514046], [81.01291656, 15.84485054], [81.01264191, 15.84486008], [81.01264191, 15.84402847], [81.01235962, 15.84403038], [81.01235962, 15.84263992], [81.01207733, 15.84263992], [81.01207733, 15.84208202], [81.01180267, 15.84208393], [81.01180267, 15.84152794], [81.01152802, 15.84152985], [81.01152802, 15.84125042], [81.01125336, 15.84125042], [81.01125336, 15.84097195], [81.01097107, 15.84097195], [81.01097107, 15.84041595], [81.01069641, 15.84041977], [81.01069641, 15.83986187], [81.01040649, 15.83986187], [81.01040649, 15.83930969], [81.01013947, 15.83930969], [81.01013947, 15.83903027], [81.00985718, 15.83903027], [81.00985718, 15.83819103], [81.00958252, 15.8381958], [81.00958252, 15.83791637], [81.00930786, 15.83792019], [81.00930786, 15.83735943], [81.00902557, 15.83736229], [81.00902557, 15.83708382], [81.00846863, 15.83708382], [81.00846863, 15.83736229], [81.00819397, 15.83736229], [81.00819397, 15.83847237], [81.00846863, 15.83846855], [81.00846863, 15.83903027], [81.00818634, 15.83903027], [81.00818634, 15.83930969], [81.00791931, 15.83930588], [81.00791931, 15.83958435], [81.00763702, 15.83958435], [81.00763702, 15.83930588], [81.00736237, 15.83930969], [81.00736237, 15.83903027], [81.00708008, 15.83903027], [81.00708008, 15.83875179], [81.00681305, 15.83875179], [81.00681305, 15.83763981], [81.00708008, 15.83763981], [81.00708008, 15.83541965], [81.00736237, 15.83541965], [81.00736237, 15.83458138], [81.00763702, 15.83458328], [81.00763702, 15.83374882], [81.00736237, 15.83375168], [81.00736237, 15.83236122], [81.00708008, 15.83236122], [81.00708008, 15.83208275], [81.00736237, 15.83208275], [81.00736237, 15.83180523], [81.00681305, 15.8318119], [81.00681305, 15.83153152], [81.00653076, 15.83152676], [81.00653076, 15.8334713], [81.00624847, 15.8334713], [81.00624847, 15.83403015], [81.00597382, 15.83402729], [81.00597382, 15.83569336], [81.00569153, 15.83568192], [81.00569153, 15.83625031], [81.00541687, 15.83625031], [81.00541687, 15.83736229], [81.00512695, 15.83735943], [81.00512695, 15.83903027], [81.00541687, 15.83903027], [81.00541687, 15.83930969], [81.00569153, 15.83930969], [81.00569153, 15.84041977], [81.00541687, 15.84041595], [81.00541687, 15.84069443], [81.00458527, 15.84069443], [81.00458527, 15.84041595], [81.00430298, 15.84041977], [81.00430298, 15.83903027], [81.0045929, 15.83903027], [81.0045929, 15.83875179], [81.00430298, 15.83875179], [81.00430298, 15.83792019], [81.00402832, 15.83792019], [81.00402832, 15.83763981], [81.00374603, 15.83763981], [81.00374603, 15.83681011], [81.00402832, 15.83681011], [81.00402832, 15.83597088], [81.00430298, 15.83597088], [81.00430298, 15.83430481], [81.00235748, 15.83430958], [81.00235748, 15.8334713], [81.00263977, 15.8334713], [81.00263977, 15.83152676], [81.00235748, 15.83153152], [81.00235748, 15.83124924], [81.00180817, 15.83124924], [81.00180817, 15.83153152], [81.00152588, 15.83152676], [81.00152588, 15.83208275], [81.00125122, 15.83208275], [81.00125122, 15.83236122], [81.00013733, 15.83236122], [81.00013733, 15.83208275], [80.99986267, 15.83208275], [80.99986267, 15.83180523], [80.99958038, 15.8318119], [80.99958038, 15.83124924], [80.99930573, 15.83124924], [80.99930573, 15.83069515], [80.99903107, 15.83069515], [80.99903107, 15.83041668], [80.99874878, 15.83041859], [80.99874878, 15.83014107], [80.99846649, 15.83014107], [80.99846649, 15.82987022], [80.99819183, 15.82987022], [80.99819183, 15.82958126], [80.99791718, 15.82958317], [80.99791718, 15.82736111], [80.99764252, 15.82736111], [80.99764252, 15.82680511], [80.99736023, 15.82681179], [80.99736023, 15.82625103], [80.9970932, 15.82625103], [80.9970932, 15.82458019], [80.99680328, 15.82458305], [80.99680328, 15.82402897], [80.99652863, 15.82403088], [80.99652863, 15.82347012], [80.99624634, 15.82347298], [80.99624634, 15.82291698], [80.99597168, 15.8229208], [80.99597168, 15.8215313], [80.99569702, 15.8215313], [80.99569702, 15.82096958], [80.99541473, 15.82097244], [80.99541473, 15.82069397], [80.99485779, 15.82069397], [80.99485779, 15.82097244], [80.99430847, 15.82096958], [80.99430847, 15.82125092], [80.99318695, 15.82125092], [80.99318695, 15.82070065], [80.99291992, 15.82068062], [80.99291992, 15.81847191], [80.99319458, 15.81847191], [80.99319458, 15.81735992], [80.99346924, 15.81735992], [80.99346924, 15.81707954], [80.99375153, 15.81708431], [80.99375153, 15.81680584], [80.99402618, 15.81681061], [80.99402618, 15.81569195], [80.99430847, 15.81569386], [80.99430847, 15.81513786], [80.99458313, 15.81514168], [80.99458313, 15.81375027], [80.99430847, 15.81375027], [80.99430847, 15.81347179], [80.99402618, 15.81347179], [80.99402618, 15.81291962], [80.99375153, 15.81291962], [80.99375153, 15.81013966], [80.99402618, 15.81013966], [80.99402618, 15.80985928], [80.99430847, 15.80986214], [80.99430847, 15.80958366], [80.99458313, 15.80958366], [80.99458313, 15.80930614], [80.99485779, 15.80930996], [80.99485779, 15.80792046], [80.99458313, 15.80792046], [80.99458313, 15.80681038], [80.99485779, 15.80681038], [80.99485779, 15.80347061], [80.99514008, 15.80347347], [80.99514008, 15.80263901], [80.9954071, 15.80264091], [80.9954071, 15.80208111], [80.99569702, 15.80208302], [80.99569702, 15.80152702], [80.99597168, 15.80153084], [80.99597168, 15.80097103], [80.99624634, 15.80097294], [80.99624634, 15.80013943], [80.99652863, 15.80014133], [80.99652863, 15.79986095], [80.99680328, 15.79986095], [80.99680328, 15.79957104], [80.99708557, 15.79958344], [80.99708557, 15.79902744], [80.99736023, 15.79903126], [80.99736023, 15.79875088], [80.99764252, 15.79875088], [80.99764252, 15.79819012], [80.99791718, 15.79819489], [80.99791718, 15.79763889], [80.99819183, 15.7976408], [80.99819183, 15.79708004], [80.99847412, 15.7970829], [80.99847412, 15.79652882], [80.99874878, 15.79653072], [80.99874878, 15.7962513], [80.99903107, 15.7962513], [80.99903107, 15.79568958], [80.99930573, 15.7956953], [80.99930573, 15.79513836], [80.99958038, 15.79514122], [80.99958038, 15.79431057], [80.99986267, 15.79431057], [80.99986267, 15.79403114], [81.00013733, 15.79403114], [81.00013733, 15.7937603], [81.00041962, 15.7937603], [81.00041962, 15.79264069], [81.00068665, 15.79264069], [81.00068665, 15.79153061], [81.00096893, 15.79153061], [81.00096893, 15.79070091], [81.00125122, 15.79070091], [81.00125122, 15.78874969], [81.00152588, 15.78874969], [81.00152588, 15.78792], [81.00180817, 15.78792], [81.00180817, 15.78736019], [81.00208282, 15.7873621], [81.00208282, 15.78708363], [81.00235748, 15.78708363], [81.00235748, 15.78680611], [81.00263977, 15.78681087], [81.00263977, 15.78625202], [81.0029068, 15.78625202], [81.0029068, 15.78568935], [81.00319672, 15.78569412], [81.00319672, 15.78514004], [81.00347137, 15.78514004], [81.00347137, 15.78485966], [81.00375366, 15.78485966], [81.00374603, 15.78456974], [81.00402832, 15.78458405], [81.00402832, 15.78430557], [81.00430298, 15.78431034], [81.00430298, 15.78402996], [81.0045929, 15.78402996], [81.0045929, 15.78374958], [81.00485992, 15.78374958], [81.00485992, 15.7834692], [81.00514221, 15.78347206], [81.00514221, 15.78319359], [81.00541687, 15.78319359], [81.00541687, 15.78291798], [81.00569153, 15.78292179], [81.00569153, 15.78264046], [81.00541687, 15.78264046], [81.00541687, 15.78236198], [81.00569153, 15.78236198], [81.00569153, 15.78208065], [81.00597382, 15.78208447], [81.00597382, 15.78097057], [81.00624847, 15.78097057], [81.00624847, 15.7804184], [81.00653076, 15.7804203], [81.00653076, 15.78014183], [81.00681305, 15.78014183], [81.00681305, 15.77986145], [81.00763702, 15.77986145], [81.00763702, 15.78014183], [81.00791931, 15.78013897], [81.00791931, 15.78208447], [81.00763702, 15.78208065], [81.00763702, 15.78264046], [81.00736237, 15.78264046], [81.00736237, 15.78292179], [81.00708008, 15.78291798], [81.00708008, 15.78347206], [81.00681305, 15.7834692], [81.00681305, 15.78402996], [81.00653076, 15.78402805], [81.00653076, 15.78458405], [81.00791931, 15.78458405], [81.00791931, 15.78430557], [81.00818634, 15.78431034], [81.00818634, 15.7834692], [81.00846863, 15.78347206], [81.00846863, 15.78263664], [81.00875092, 15.78264046], [81.00875092, 15.78208065], [81.00902557, 15.78208447], [81.00902557, 15.78124905], [81.00930786, 15.78125191], [81.00930786, 15.7804203], [81.00958252, 15.7804203], [81.00958252, 15.78014183], [81.01040649, 15.78014183], [81.01040649, 15.77958107], [81.01069641, 15.77958298], [81.01069641, 15.77875137], [81.01097107, 15.77876091], [81.01097107, 15.77791977], [81.01126099, 15.77791977], [81.01126099, 15.77652931], [81.01152802, 15.77652931], [81.01152802, 15.77625084], [81.01207733, 15.77625084], [81.01207733, 15.77514076], [81.01180267, 15.77514076], [81.01180267, 15.77431202], [81.01152802, 15.77431202], [81.01152802, 15.77375126], [81.01125336, 15.77375126], [81.01125336, 15.77347088], [81.01152802, 15.77347088], [81.01152802, 15.77263927], [81.01180267, 15.77263927], [81.01180267, 15.77208328], [81.01208496, 15.77208328], [81.01208496, 15.7715292], [81.01235962, 15.77153111], [81.01235962, 15.7709713], [81.01208496, 15.77097321], [81.01208496, 15.77013874], [81.01180267, 15.77014065], [81.01180267, 15.76958942], [81.01152802, 15.76958942], [81.01152802, 15.76875114], [81.01125336, 15.76875114], [81.01125336, 15.76847267], [81.01097107, 15.76847267], [81.01097107, 15.76819515], [81.01069641, 15.76819515], [81.01069641, 15.76791573], [81.00930786, 15.76792145], [81.00930786, 15.76764107], [81.00846863, 15.76764107], [81.00846863, 15.76735973], [81.00763702, 15.76735973], [81.00763702, 15.76708031], [81.00597382, 15.76708221], [81.00597382, 15.7668066], [81.00569153, 15.76681995], [81.00569153, 15.76653099], [81.00596619, 15.76653099], [81.00596619, 15.76624966], [81.00569153, 15.76624966], [81.00569153, 15.76124954], [81.00541687, 15.76124954], [81.00541687, 15.76041985], [81.00569153, 15.76041985], [81.00569153, 15.75958157], [81.00597382, 15.75958443], [81.00597382, 15.75847244], [81.00624847, 15.75847244], [81.00624847, 15.75791645], [81.00596619, 15.75792027], [81.00596619, 15.75765133], [81.00569153, 15.75765133], [81.00569153, 15.75736046], [81.00541687, 15.75736237], [81.00541687, 15.75708389], [81.00514221, 15.75708389], [81.00514221, 15.75680637], [81.00485992, 15.75681019], [81.00485992, 15.75652981], [81.0045929, 15.75652981], [81.0045929, 15.75625038], [81.00430298, 15.75625038], [81.00430298, 15.75597191], [81.00402832, 15.75597191], [81.00402832, 15.75569344], [81.00375366, 15.75569344], [81.00375366, 15.7551403], [81.00319672, 15.7551403], [81.00319672, 15.75486183], [81.00235748, 15.75486183], [81.00235748, 15.75459003], [81.00206757, 15.75459003], [81.00206757, 15.75319099], [81.00180817, 15.75319576], [81.00180817, 15.75291538], [81.00152588, 15.75292015], [81.00152588, 15.75264168], [81.00125122, 15.75264168], [81.00125122, 15.7523613], [81.00096893, 15.7523613], [81.00096893, 15.75180531], [80.99986267, 15.75181198], [80.99986267, 15.75152016], [80.99958038, 15.75152683], [80.99958038, 15.75124931], [80.99930573, 15.75124931], [80.99930573, 15.75097084], [80.99903107, 15.75097084], [80.99903107, 15.75069141], [80.99874878, 15.75069523], [80.99874878, 15.75041676], [80.99846649, 15.75041962], [80.99846649, 15.75013924], [80.99791718, 15.75013924], [80.99791718, 15.74986076], [80.99764252, 15.74986076], [80.99764252, 15.74958134], [80.99708557, 15.74958324], [80.99708557, 15.74930477], [80.99652863, 15.74930954], [80.99652863, 15.74903202], [80.99624634, 15.74903202], [80.99624634, 15.74875069], [80.99569702, 15.74875069], [80.99569702, 15.74845886], [80.99514008, 15.74847317], [80.99514008, 15.74819469], [80.99485779, 15.74819469], [80.99485779, 15.74791718], [80.99430847, 15.74792194], [80.99430847, 15.74764061], [80.99402618, 15.74764061], [80.99402618, 15.74736118], [80.99346924, 15.74736118], [80.99346924, 15.74708271], [80.99291992, 15.74708271], [80.99291992, 15.74680519], [80.99263763, 15.74681187], [80.99263763, 15.74653053], [80.99208069, 15.74653053], [80.99208069, 15.74625111], [80.99180603, 15.74625111], [80.99180603, 15.74597073], [80.99124908, 15.74597263], [80.99124908, 15.74569511], [80.99069214, 15.74569511], [80.99069214, 15.74541664], [80.99041748, 15.74542141], [80.99041748, 15.74514103], [80.98986053, 15.74514103], [80.98986053, 15.74486065], [80.98930359, 15.74486065], [80.98929596, 15.74458027], [80.98902893, 15.74458313], [80.98902893, 15.74430466], [80.98847198, 15.74431133], [80.98847198, 15.74403095], [80.98819733, 15.74403095], [80.98819733, 15.74375057], [80.98764038, 15.74375057], [80.98764038, 15.74347019], [80.98735809, 15.74347305], [80.98735809, 15.74319458], [80.98680878, 15.74319458], [80.98680878, 15.74291706], [80.98652649, 15.74292088], [80.98652649, 15.74265003], [80.98596954, 15.74265003], [80.98596954, 15.74236107], [80.98568726, 15.74236107], [80.98568726, 15.74207973], [80.98513794, 15.74208164], [80.98513794, 15.74180698], [80.98486328, 15.7418108], [80.98486328, 15.74153137], [80.98430634, 15.74153137], [80.98430634, 15.74125099], [80.98403168, 15.74125099], [80.98403168, 15.74096966], [80.98347473, 15.74097347], [80.98347473, 15.74069405], [80.98319244, 15.74069405], [80.98319244, 15.74041557], [80.98264313, 15.7404213], [80.98264313, 15.74014091], [80.98208618, 15.74014091], [80.98208618, 15.73985958], [80.98152924, 15.7398634], [80.98152924, 15.73958206], [80.98097229, 15.73958206], [80.98097229, 15.73930645], [80.98042297, 15.73931122], [80.98042297, 15.73903084], [80.9798584, 15.73903084], [80.9798584, 15.73875046], [80.97957611, 15.73875046], [80.97957611, 15.73847008], [80.97902679, 15.73847198], [80.97902679, 15.73819447], [80.97846985, 15.73819447], [80.97846985, 15.73791599], [80.97789764, 15.73792076], [80.97789764, 15.73764038], [80.97735596, 15.73764038], [80.97735596, 15.73736], [80.97680664, 15.73736], [80.97680664, 15.73707962], [80.97624969, 15.73708439], [80.97624969, 15.73680592], [80.97569275, 15.73681068], [80.97569275, 15.73651886], [80.9751358, 15.7365284], [80.9751358, 15.73624992], [80.97458649, 15.73624992], [80.97458649, 15.73596954], [80.97402954, 15.7359724], [80.97402954, 15.73569393], [80.9734726, 15.73569393], [80.9734726, 15.73541641], [80.97292328, 15.73542118], [80.97292328, 15.73513985], [80.9723587, 15.73513985], [80.9723587, 15.73486042], [80.9715271, 15.73486233], [80.9715271, 15.73458195], [80.97125244, 15.73458195], [80.97125244, 15.73430634], [80.97070313, 15.7343111], [80.97070313, 15.73403263], [80.97013855, 15.73403263], [80.97013855, 15.73375034], [80.96985626, 15.73375034], [80.96985626, 15.73346138], [80.96930695, 15.73347187], [80.96930695, 15.73319435], [80.96875, 15.73319435], [80.96875, 15.73291588], [80.96819305, 15.73291969], [80.96819305, 15.73264027], [80.96763611, 15.73264027], [80.96763611, 15.73236179], [80.96708679, 15.73236179], [80.96708679, 15.73207855], [80.9668045, 15.73208427], [80.9668045, 15.7318058], [80.96624756, 15.73180962], [80.96624756, 15.73153019], [80.96569824, 15.73153019], [80.96569061, 15.73124981], [80.9651413, 15.73124981], [80.9651413, 15.73096943], [80.96458435, 15.73097229], [80.96458435, 15.73069572], [80.9640274, 15.73069572], [80.9640274, 15.7304163], [80.96347046, 15.73042011], [80.96347046, 15.73013973], [80.96292114, 15.73013973], [80.96292114, 15.72985935], [80.96208191, 15.72986221], [80.96208191, 15.72958374], [80.96152496, 15.72958374], [80.96152496, 15.72930622], [80.96098328, 15.72931004], [80.96098328, 15.72902966], [80.9604187, 15.72902966], [80.9604187, 15.72875023], [80.95986176, 15.72875023], [80.95986176, 15.7284708], [80.95874786, 15.7284708], [80.95874786, 15.72819138], [80.95735931, 15.72819328], [80.95735931, 15.72791767], [80.95678711, 15.72791958], [80.95678711, 15.72764015], [80.95652771, 15.72764015], [80.95652771, 15.72736168], [80.95569611, 15.72736168], [80.95569611, 15.72764015], [80.95401764, 15.72764015], [80.95401764, 15.72736168], [80.95375061, 15.72736168], [80.95375061, 15.7270813], [80.95319366, 15.72708321], [80.95319366, 15.72680473], [80.95263672, 15.72681046], [80.95263672, 15.72653198], [80.95207977, 15.72653198], [80.95207977, 15.7262516], [80.95153046, 15.7262516], [80.95153046, 15.72597122], [80.95097351, 15.72597122], [80.95097351, 15.72569466], [80.95056915, 15.72569466], [80.95041656, 15.72569466], [80.95041656, 15.72541714], [80.94985962, 15.72542191], [80.94985962, 15.72514153], [80.94930267, 15.72514153], [80.94930267, 15.72458076], [80.94902802, 15.72458267], [80.94902802, 15.72430515], [80.94875336, 15.72430992], [80.94875336, 15.72420025], [80.94875336, 15.72374916], [80.94847107, 15.72375107], [80.94847107, 15.72347069], [80.94819641, 15.7234726], [80.94819641, 15.72319317], [80.94791412, 15.72319317], [80.94791412, 15.7229166], [80.94763947, 15.72291946], [80.94763947, 15.72264099], [80.94708252, 15.72264099], [80.94708252, 15.72236061], [80.94652557, 15.72236061], [80.94652557, 15.72208309], [80.94625092, 15.72208309], [80.94625092, 15.72180462], [80.94596863, 15.72181034], [80.94596863, 15.72152042], [80.94569397, 15.7215271], [80.94569397, 15.72124863], [80.94484711, 15.72125053], [80.94484711, 15.72097111], [80.94430542, 15.72097301], [80.94430542, 15.72069454], [80.94403076, 15.72069454], [80.94403076, 15.72041702], [80.94374847, 15.72042179], [80.94374847, 15.72014141], [80.94319153, 15.72014141], [80.94319153, 15.71986103], [80.94291687, 15.71986103], [80.94291687, 15.71958065], [80.94208527, 15.71958256], [80.94208527, 15.71930695], [80.94152832, 15.71931171], [80.94152832, 15.71903133], [80.94069672, 15.71903133], [80.94069672, 15.71875095], [80.93985748, 15.71875095], [80.93985748, 15.71848202], [80.93904114, 15.71848202], [80.93904114, 15.71819019], [80.93791962, 15.71819019], [80.93791962, 15.71848202], [80.93736267, 15.71848202], [80.93736267, 15.71875095], [80.93681335, 15.71875095], [80.93681335, 15.71903133], [80.93569183, 15.71903133], [80.93569183, 15.71931171], [80.93514252, 15.71930695], [80.93514252, 15.71958256], [80.93486023, 15.71958065], [80.93486023, 15.71986103], [80.9345932, 15.71986103], [80.9345932, 15.72014141], [80.93430328, 15.72014141], [80.93430328, 15.72042179], [80.93402863, 15.72041702], [80.93402863, 15.72069454], [80.93374634, 15.72069454], [80.93374634, 15.72097301], [80.93347168, 15.72097111], [80.93347168, 15.72181034], [80.93319702, 15.72181034], [80.93319702, 15.72264099], [80.9329071, 15.72264099], [80.9329071, 15.72375107], [80.93264008, 15.72375107], [80.93264008, 15.72402859], [80.93180847, 15.72402859], [80.93180847, 15.72375107], [80.93041992, 15.72375107], [80.93041992, 15.72347069], [80.92930603, 15.7234726], [80.92930603, 15.72319317], [80.92791748, 15.72319317], [80.92791748, 15.7229166], [80.92652893, 15.72291946], [80.92652893, 15.72264099], [80.92542267, 15.72264099], [80.92542267, 15.72236061], [80.92514038, 15.72236061], [80.92514038, 15.72208309], [80.92430878, 15.72208309], [80.92430878, 15.72180462], [80.92263794, 15.72181034], [80.92263794, 15.72152042], [80.92041779, 15.7215271], [80.92041779, 15.72124863], [80.91929626, 15.72125053], [80.91929626, 15.72097111], [80.91847229, 15.72097301], [80.91847229, 15.72069454], [80.91764069, 15.72069454], [80.91764069, 15.72041702], [80.91680908, 15.72042179], [80.91680908, 15.72014141], [80.91513824, 15.72014141], [80.91513824, 15.71986103], [80.91348267, 15.71986103], [80.91348267, 15.72014141], [80.91236115, 15.72014141], [80.91236115, 15.71986103], [80.91124725, 15.71986103], [80.91124725, 15.71958065], [80.9109726, 15.71958256], [80.9109726, 15.71930695], [80.9090271, 15.71931171], [80.9090271, 15.71903133], [80.90791321, 15.71903133], [80.90791321, 15.71875095], [80.90680695, 15.71875095], [80.90680695, 15.71848202], [80.90625763, 15.71848202], [80.9056778, 15.71848202], [80.9056778, 15.71819019], [80.90097046, 15.71819496], [80.90097046, 15.71791744], [80.9006958, 15.71792126], [80.9006958, 15.71764088], [80.90013885, 15.71764088], [80.90013885, 15.71736145], [80.8998642, 15.71736145], [80.8998642, 15.71708298], [80.89902496, 15.71708298], [80.89902496, 15.71680546], [80.89624786, 15.71680927], [80.89624786, 15.71652889], [80.89541626, 15.71652889], [80.89541626, 15.71625137], [80.89290619, 15.71625137], [80.89290619, 15.71597004], [80.8923645, 15.7159729], [80.8923645, 15.71569538], [80.88986206, 15.71569538], [80.88986206, 15.71541691], [80.88957977, 15.71542072], [80.88957977, 15.7151413], [80.88874817, 15.7151413], [80.88874817, 15.71485996], [80.88735962, 15.71485996], [80.88735962, 15.71457958], [80.88402557, 15.71458244], [80.88402557, 15.71430683], [80.88208008, 15.71431065], [80.88208008, 15.71403122], [80.88153076, 15.71403122], [80.88153076, 15.71375275], [80.88096619, 15.71375275], [80.88096619, 15.71347046], [80.87902832, 15.71347237], [80.87902832, 15.71319389], [80.87596893, 15.71319389], [80.87596893, 15.71291637], [80.87374878, 15.71292114], [80.87374878, 15.71264076], [80.87124634, 15.71264076], [80.87124634, 15.71235085], [80.86902618, 15.71236038], [80.86902618, 15.71208382], [80.86653137, 15.71208191], [80.86653137, 15.7118063], [80.86207581, 15.71181107], [80.86207581, 15.71153069], [80.86152649, 15.71153069], [80.86152649, 15.71125031], [80.85930634, 15.71125031], [80.85930634, 15.71096992], [80.8576355, 15.71097183], [80.8576355, 15.71069431], [80.85569763, 15.71069431], [80.85569763, 15.71041584], [80.85263824, 15.71042061], [80.85263824, 15.71014023], [80.85041809, 15.71014023], [80.85041809, 15.71042061], [80.8501358, 15.71041584], [80.8501358, 15.71069431], [80.84986115, 15.71069431], [80.84986115, 15.71097183], [80.84929657, 15.71096992], [80.84929657, 15.71125031], [80.8484726, 15.71125031], [80.8484726, 15.71096992], [80.84819794, 15.71097183], [80.84819794, 15.71014023], [80.84792328, 15.71014023], [80.84792328, 15.70985985], [80.84764099, 15.70985985], [80.84764099, 15.70958424], [80.84124756, 15.70958424], [80.84124756, 15.70930576], [80.83930206, 15.70931053], [80.83930206, 15.70903015], [80.83790588, 15.70903015], [80.83790588, 15.70931053], [80.83680725, 15.70930576], [80.83680725, 15.70958424], [80.83652496, 15.70958424], [80.83652496, 15.70985985], [80.83598328, 15.70985985], [80.83598328, 15.71014023], [80.8345871, 15.71014023], [80.8345871, 15.71042061], [80.83319092, 15.71041584], [80.83319092, 15.71069431], [80.83180237, 15.71069431], [80.83180237, 15.71097183], [80.83068848, 15.71096992], [80.83068848, 15.71125031], [80.82930756, 15.71125031], [80.82930756, 15.71153069], [80.82791901, 15.71153069], [80.82791901, 15.71181107], [80.82514191, 15.7118063], [80.82514191, 15.71208191], [80.82402802, 15.71208382], [80.82402802, 15.71236038], [80.82319641, 15.71235085], [80.82319641, 15.71264076], [80.82263947, 15.71264076], [80.82263947, 15.71292114], [80.82208252, 15.71291637], [80.82208252, 15.71319389], [80.82180786, 15.71319389], [80.82180786, 15.71347237], [80.82151794, 15.71347046], [80.82151794, 15.71403122], [80.82096863, 15.71402645], [80.82096863, 15.71458244], [80.82068634, 15.71457958], [80.82068634, 15.71485996], [80.82041931, 15.71485996], [80.82041931, 15.7151413], [80.82013702, 15.71513939], [80.82013702, 15.71569538], [80.81986237, 15.71569538], [80.81986237, 15.7159729], [80.81958008, 15.71597004], [80.81958008, 15.71652889], [80.81931305, 15.71652889], [80.81931305, 15.71680927], [80.81903076, 15.71680546], [80.81903076, 15.71708298], [80.81874847, 15.71708012], [80.81874847, 15.71764088], [80.81845856, 15.71764088], [80.81845856, 15.71792126], [80.81819153, 15.71791744], [80.81819153, 15.71819496], [80.81764221, 15.71819019], [80.81764221, 15.71848202], [80.81735992, 15.71848202], [80.81735992, 15.71875095], [80.8170929, 15.71875095], [80.8170929, 15.71903133], [80.81652832, 15.71903133], [80.81652832, 15.71931171], [80.81625366, 15.71930695], [80.81625366, 15.71958256], [80.81597137, 15.71958065], [80.81597137, 15.72014141], [80.81569672, 15.72013855], [80.81569672, 15.72069454], [80.81539917, 15.72069073], [80.81539917, 15.72181034], [80.81513977, 15.72181034], [80.81513977, 15.72291946], [80.81485748, 15.72291946], [80.81485748, 15.72375107], [80.81458282, 15.72375107], [80.81458282, 15.72430992], [80.81430817, 15.72430515], [80.81430817, 15.72486115], [80.81402588, 15.72486115], [80.81402588, 15.72542191], [80.81375122, 15.72541714], [80.81375122, 15.72569466], [80.81346893, 15.72569084], [80.81346893, 15.7262516], [80.81318665, 15.7262516], [80.81318665, 15.72681046], [80.81291962, 15.72681046], [80.81291962, 15.72736168], [80.81265259, 15.72736168], [80.81265259, 15.72791958], [80.81236267, 15.72791767], [80.81236267, 15.72819328], [80.81208038, 15.72819138], [80.81208038, 15.7284708], [80.81180573, 15.72847366], [80.81181335, 15.72875023], [80.81153107, 15.72875023], [80.81153107, 15.72902966], [80.81124878, 15.72902775], [80.81124878, 15.72958374], [80.81097412, 15.72958374], [80.81097412, 15.72986221], [80.81069183, 15.72985935], [80.81069183, 15.73013973], [80.81041718, 15.73013973], [80.81041718, 15.73069572], [80.81014252, 15.73069572], [80.81014252, 15.73097229], [80.80986023, 15.73096943], [80.80986023, 15.73124981], [80.80957794, 15.73124981], [80.80957794, 15.73153019], [80.80930328, 15.73153019], [80.80930328, 15.73180962], [80.80902863, 15.7318058], [80.80902863, 15.73208427], [80.80874634, 15.73207855], [80.80874634, 15.73236179], [80.80847168, 15.73236179], [80.80847168, 15.73291969], [80.80819702, 15.73291588], [80.80819702, 15.73319435], [80.80791473, 15.73319435], [80.80791473, 15.73347187], [80.80764008, 15.73346138], [80.80764008, 15.73375034], [80.80708313, 15.73375034], [80.80708313, 15.73403263], [80.80680847, 15.73403263], [80.80680847, 15.7343111], [80.80652618, 15.73430634], [80.80652618, 15.73458195], [80.80596924, 15.73458195], [80.80596924, 15.73486233], [80.80568695, 15.73486042], [80.80568695, 15.73513985], [80.80541992, 15.73513985], [80.80541992, 15.73542118], [80.80486298, 15.73541641], [80.80486298, 15.73569393], [80.80458069, 15.73569393], [80.80458069, 15.7359724], [80.80430603, 15.73596954], [80.80430603, 15.73624992], [80.80403137, 15.73624992], [80.80403137, 15.7365284], [80.80374908, 15.73651886], [80.80374908, 15.73681068], [80.80347443, 15.73680592], [80.80347443, 15.73708439], [80.80319214, 15.73707962], [80.80319214, 15.73736], [80.80291748, 15.73736], [80.80291748, 15.73764038], [80.80236053, 15.73764038], [80.80236053, 15.73792076], [80.80208588, 15.73791599], [80.80208588, 15.73819447], [80.80180359, 15.73819447], [80.80180359, 15.73847198], [80.80152893, 15.73847008], [80.80152893, 15.73875046], [80.80124664, 15.73875046], [80.80124664, 15.73903084], [80.80097198, 15.73903084], [80.80097198, 15.73931122], [80.80041504, 15.73930645], [80.80041504, 15.7398634], [80.80023956, 15.7398634], [80.80014038, 15.7398634], [80.80014038, 15.74014091], [80.79985809, 15.74014091], [80.79985809, 15.7404213], [80.79958344, 15.74041557], [80.79958344, 15.74097347], [80.79930878, 15.74096966], [80.79930878, 15.74125099], [80.79902649, 15.74125099], [80.79902649, 15.7418108], [80.79875183, 15.74180698], [80.79875183, 15.74208164], [80.79846954, 15.74207973], [80.79846954, 15.74292088], [80.79819489, 15.74291706], [80.79819489, 15.74319458], [80.79792023, 15.74319458], [80.79792023, 15.74347305], [80.79763794, 15.74347019], [80.79763794, 15.74403095], [80.79736328, 15.74403095], [80.79736328, 15.74431133], [80.79708099, 15.74431133], [80.79708099, 15.74542141], [80.79680634, 15.74541664], [80.79680634, 15.74569511], [80.79652405, 15.74569511], [80.79652405, 15.74597263], [80.79624939, 15.74597263], [80.79624939, 15.74736118], [80.7959671, 15.74736118], [80.7959671, 15.74903202], [80.79569244, 15.74903202], [80.79569244, 15.75013924], [80.79541779, 15.75013924], [80.79541779, 15.75097084], [80.79514313, 15.75097084], [80.79514313, 15.75181198], [80.79486084, 15.75180531], [80.79486084, 15.7523613], [80.79458618, 15.7523613], [80.79458618, 15.75319576], [80.79428864, 15.75319099], [80.79428864, 15.75403023], [80.79402924, 15.75403023], [80.79402924, 15.75486183], [80.79374695, 15.75486183], [80.79374695, 15.7551403], [80.79347229, 15.7551403], [80.79347229, 15.75569344], [80.79319763, 15.75569057], [80.79319763, 15.75625038], [80.79291534, 15.75625038], [80.79291534, 15.75736237], [80.79264069, 15.75736046], [80.79264069, 15.75765133], [80.7923584, 15.75765133], [80.7923584, 15.75792027], [80.79208374, 15.75791645], [80.79208374, 15.75847244], [80.79180908, 15.75846863], [80.79180908, 15.75903034], [80.79151917, 15.75903034], [80.79151917, 15.75930977], [80.79125214, 15.75930595], [80.79125214, 15.75958443], [80.79096985, 15.75958157], [80.79096985, 15.76041985], [80.79069519, 15.76041794], [80.79069519, 15.76097202], [80.7904129, 15.76097202], [80.7904129, 15.76124954], [80.79013824, 15.76124954], [80.79013824, 15.76181126], [80.78986359, 15.76180553], [80.78986359, 15.76208401], [80.7895813, 15.76208019], [80.7895813, 15.76264], [80.78930664, 15.76264], [80.78930664, 15.76292133], [80.78902435, 15.76291561], [80.78902435, 15.76319408], [80.78874969, 15.76319027], [80.78874969, 15.76375008], [80.78848267, 15.76375008], [80.78848267, 15.76431084], [80.78819275, 15.76430416], [80.78819275, 15.76486015], [80.78791809, 15.76486015], [80.78791809, 15.76513958], [80.7876358, 15.76513958], [80.7876358, 15.76542091], [80.78736115, 15.76541615], [80.78736115, 15.76569366], [80.78708649, 15.76568985], [80.78708649, 15.76653099], [80.78679657, 15.76653099], [80.78679657, 15.76681995], [80.78652954, 15.76681995], [80.78652954, 15.76735973], [80.78624725, 15.76735973], [80.78624725, 15.76764107], [80.7859726, 15.76763821], [80.7859726, 15.76847267], [80.78569794, 15.76846981], [80.78569794, 15.76931095], [80.78542328, 15.76931095], [80.78542328, 15.77014065], [80.78514099, 15.77014065], [80.78514099, 15.77153111], [80.7848587, 15.77153111], [80.7848587, 15.77181244], [80.78458405, 15.77180481], [80.78458405, 15.7723608], [80.78430939, 15.7723608], [80.78430176, 15.77263927], [80.7840271, 15.77262974], [80.7840271, 15.77375126], [80.78375244, 15.77375126], [80.78375244, 15.77403069], [80.78347015, 15.77403069], [80.78347015, 15.77431202], [80.7831955, 15.77430534], [80.7831955, 15.77458286], [80.78291321, 15.77458096], [80.78291321, 15.77514076], [80.78263855, 15.77514076], [80.78263855, 15.77652931], [80.78236389, 15.7765274], [80.78236389, 15.7770834], [80.7820816, 15.77708054], [80.7820816, 15.77763939], [80.78180695, 15.77763939], [80.78180695, 15.77791977], [80.78152466, 15.77791691], [80.78152466, 15.77819538], [80.78125, 15.77819538], [80.78125, 15.77847099], [80.78098297, 15.77847099], [80.78098297, 15.7804203], [80.78069305, 15.7804203], [80.78069305, 15.78264046], [80.7804184, 15.78264046], [80.7804184, 15.78542042], [80.78069305, 15.78542042], [80.78069305, 15.78931141], [80.78097534, 15.78930569], [80.78097534, 15.78958416], [80.78125, 15.78958035], [80.78125, 15.79070091], [80.78151703, 15.79070091], [80.78151703, 15.79125023], [80.78180695, 15.79125023], [80.78180695, 15.79181099], [80.7820816, 15.79180622], [80.7820816, 15.79208374], [80.78263855, 15.79208374], [80.78263855, 15.79180622], [80.78291321, 15.79181099], [80.78291321, 15.79153061], [80.78320313, 15.79153061], [80.78320313, 15.79042053], [80.78291321, 15.79042053], [80.78291321, 15.79014015], [80.78263855, 15.79014015], [80.78263855, 15.78986168], [80.78234863, 15.78986168], [80.78234863, 15.78931141], [80.78263855, 15.78931141], [80.78263855, 15.78874969], [80.78347015, 15.78874969], [80.78347015, 15.78847027], [80.78375244, 15.78847218], [80.78375244, 15.78791809], [80.7840271, 15.78792], [80.7840271, 15.78736019], [80.78430176, 15.7873621], [80.78430176, 15.78680611], [80.78457642, 15.78681087], [80.78457642, 15.78652954], [80.7848587, 15.78652954], [80.7848587, 15.78625202], [80.78542328, 15.78625202], [80.78542328, 15.78568935], [80.78569794, 15.78569412], [80.78569794, 15.78514004], [80.78679657, 15.78514004], [80.78679657, 15.78542042], [80.78708649, 15.78541565], [80.78708649, 15.78569412], [80.7876358, 15.78569412], [80.7876358, 15.78541565], [80.78819275, 15.78542042], [80.78819275, 15.78431034], [80.78848267, 15.78431034], [80.78848267, 15.78236198], [80.78819275, 15.78236198], [80.78819275, 15.78208065], [80.78791809, 15.78208447], [80.78791809, 15.78180599], [80.7876358, 15.78181934], [80.7876358, 15.78153038], [80.78736115, 15.78153038], [80.78736115, 15.77986145], [80.7876358, 15.77986145], [80.7876358, 15.77958298], [80.78791809, 15.77958298], [80.78791809, 15.77875137], [80.78819275, 15.77876091], [80.78819275, 15.77736092], [80.78848267, 15.77736092], [80.78847504, 15.7765274], [80.78874969, 15.77652931], [80.78874969, 15.77514076], [80.78901672, 15.77514076], [80.78901672, 15.77403069], [80.78874969, 15.77403069], [80.78874969, 15.77262974], [80.78902435, 15.77263927], [80.78902435, 15.7723608], [80.78930664, 15.7723608], [80.78930664, 15.77208328], [80.7895813, 15.77208328], [80.7895813, 15.77180481], [80.78985596, 15.77181244], [80.78985596, 15.77153111], [80.79013824, 15.77153111], [80.79013824, 15.77125072], [80.79347229, 15.77125072], [80.79347229, 15.7709713], [80.79374695, 15.77097321], [80.79374695, 15.76930428], [80.79347229, 15.76931095], [80.79347229, 15.76903057], [80.79292297, 15.76903057], [80.79292297, 15.76846981], [80.79264069, 15.76847267], [80.79264069, 15.76763821], [80.7923584, 15.76764107], [80.7923584, 15.76568985], [80.79208374, 15.76569366], [80.79208374, 15.76291561], [80.79180908, 15.76292133], [80.79180908, 15.76124954], [80.79207611, 15.76124954], [80.79207611, 15.76069164], [80.7923584, 15.76069355], [80.7923584, 15.76013756], [80.79264069, 15.76014042], [80.79264069, 15.75986195], [80.79319763, 15.75986195], [80.79319763, 15.75958157], [80.79374695, 15.75958443], [80.79374695, 15.75930595], [80.79402924, 15.75930977], [80.79402924, 15.75903034], [80.79457855, 15.75903034], [80.79457855, 15.75874996], [80.79486084, 15.75874996], [80.79486084, 15.7581892], [80.7951355, 15.75819397], [80.7951355, 15.75791645], [80.79541779, 15.75792027], [80.79541779, 15.75736046], [80.79569244, 15.75736237], [80.79569244, 15.75708389], [80.79597473, 15.75708389], [80.79597473, 15.75680637], [80.79624939, 15.75681019], [80.79624939, 15.75625038], [80.79651642, 15.75625038], [80.79651642, 15.75597191], [80.79680634, 15.75597191], [80.79680634, 15.7551403], [80.79708099, 15.7551403], [80.79708099, 15.75403023], [80.79736328, 15.75403023], [80.79736328, 15.75319099], [80.79763794, 15.75319576], [80.79763794, 15.75291538], [80.79792023, 15.75292015], [80.79792023, 15.75208092], [80.79819489, 15.75208282], [80.79819489, 15.75152683], [80.79846954, 15.75152683], [80.79846954, 15.75041676], [80.79875183, 15.75041962], [80.79875183, 15.75013924], [80.79930878, 15.75013924], [80.79930878, 15.74986076], [80.80014038, 15.74986076], [80.80014038, 15.74958134], [80.80041504, 15.74958324], [80.80041504, 15.74930477], [80.80071259, 15.74930954], [80.80071259, 15.74845886], [80.80097198, 15.74847317], [80.80097198, 15.74819469], [80.80124664, 15.74819469], [80.80124664, 15.7476387], [80.80152893, 15.74764061], [80.80152893, 15.74681187], [80.80179596, 15.74681187], [80.80179596, 15.74625111], [80.80208588, 15.74625111], [80.80208588, 15.74597073], [80.80236053, 15.74597263], [80.80236053, 15.74486065], [80.80264282, 15.74486065], [80.80263519, 15.74458313], [80.80291748, 15.74458313], [80.80291748, 15.74402905], [80.80319214, 15.74403095], [80.80319214, 15.74375057], [80.80374908, 15.74375057], [80.80374908, 15.74347019], [80.80403137, 15.74347305], [80.80403137, 15.74319458], [80.80430603, 15.74319458], [80.80430603, 15.74291706], [80.80458069, 15.74292088], [80.80458069, 15.74265003], [80.80513763, 15.74265003], [80.80513763, 15.74236107], [80.80541992, 15.74236107], [80.80541992, 15.74207973], [80.80569458, 15.74208164], [80.80569458, 15.74180698], [80.80596924, 15.7418108], [80.80596924, 15.74153137], [80.80651855, 15.74153137], [80.80651855, 15.74125099], [80.80708313, 15.74125099], [80.80708313, 15.74096966], [80.80753326, 15.74097347], [80.80791473, 15.74097347], [80.80791473, 15.74069405], [80.80847168, 15.74069405], [80.80847168, 15.74041557], [80.81041718, 15.7404213], [80.81041718, 15.74014091], [80.81096649, 15.74014091], [80.81096649, 15.73985958], [80.81236267, 15.7398634], [80.81236267, 15.73958206], [80.81346893, 15.73958206], [80.81346893, 15.7398634], [80.81375122, 15.73985958], [80.81375122, 15.74014091], [80.81402588, 15.74014091], [80.81402588, 15.7404213], [80.81430817, 15.74041557], [80.81430817, 15.74097347], [80.81458282, 15.74096966], [80.81458282, 15.74153137], [80.81485748, 15.74153137], [80.81485748, 15.7418108], [80.81513977, 15.7418108], [80.81513977, 15.74265003], [80.81485748, 15.74263859], [80.81485748, 15.74319458], [80.81458282, 15.74319458], [80.81458282, 15.74347305], [80.81430817, 15.74347019], [80.81430817, 15.74375057], [80.81402588, 15.74375057], [80.81402588, 15.74486065], [80.81375122, 15.74486065], [80.81375122, 15.74569511], [80.81346893, 15.74569035], [80.81346893, 15.74681187], [80.81318665, 15.74681187], [80.81318665, 15.74764061], [80.81291962, 15.74764061], [80.81291962, 15.74875069], [80.81265259, 15.74875069], [80.81265259, 15.74986076], [80.81236267, 15.74986076], [80.81236267, 15.75486183], [80.81208038, 15.75486183], [80.81208038, 15.7551403], [80.81181335, 15.7551403], [80.81181335, 15.76041985], [80.81153107, 15.76041794], [80.81153107, 15.76069355], [80.81124878, 15.76069164], [80.81124878, 15.76181126], [80.81096649, 15.76181126], [80.81096649, 15.76375008], [80.81069183, 15.76375008], [80.81069183, 15.76458359], [80.81041718, 15.76457977], [80.81041718, 15.76513958], [80.81014252, 15.76513767], [80.81014252, 15.76569366], [80.80986023, 15.76569366], [80.80986023, 15.76597214], [80.80930328, 15.76597023], [80.80930328, 15.76653099], [80.80902863, 15.76653099], [80.80902863, 15.76681995], [80.80874634, 15.76681995], [80.80874634, 15.76792145], [80.80847168, 15.76791573], [80.80847168, 15.76819515], [80.80819702, 15.76819038], [80.80819702, 15.76931095], [80.80791473, 15.76930428], [80.80791473, 15.76986122], [80.80764008, 15.76986122], [80.80764008, 15.77014065], [80.80735779, 15.77014065], [80.80735779, 15.77042103], [80.80708313, 15.77041721], [80.80708313, 15.77097321], [80.80680847, 15.7709713], [80.80680847, 15.77125072], [80.80651855, 15.77125072], [80.80651855, 15.77153111], [80.80625153, 15.7715292], [80.80625153, 15.77208328], [80.80596924, 15.77208328], [80.80596924, 15.77347088], [80.80568695, 15.77347088], [80.80568695, 15.77375126], [80.80541992, 15.77375126], [80.80541992, 15.77652931], [80.80513763, 15.77652931], [80.80513763, 15.77763939], [80.80486298, 15.77763939], [80.80486298, 15.77791977], [80.80458069, 15.77791977], [80.80458069, 15.77876091], [80.80430603, 15.77876091], [80.80430603, 15.77931023], [80.80403137, 15.77931023], [80.80403137, 15.78014183], [80.80374908, 15.78013897], [80.80374908, 15.78486156], [80.80345917, 15.78485966], [80.80345917, 15.78542042], [80.80319214, 15.78541565], [80.80319214, 15.78597164], [80.8030014, 15.78597164], [80.80291748, 15.78597164], [80.80291748, 15.78625202], [80.80264282, 15.78625202], [80.80264282, 15.78681087], [80.80236053, 15.78680611], [80.80236053, 15.78763771], [80.80208588, 15.78763103], [80.80208588, 15.78874969], [80.80179596, 15.78874969], [80.80179596, 15.78903008], [80.80152893, 15.78902817], [80.80152893, 15.78958416], [80.80124664, 15.78958035], [80.80124664, 15.79042053], [80.80097198, 15.79041576], [80.80097198, 15.79097176], [80.80069733, 15.79097176], [80.80069733, 15.79125023], [80.80041504, 15.79125023], [80.80041504, 15.79208374], [80.80014038, 15.79207993], [80.80014038, 15.79264069], [80.79985809, 15.79263783], [80.79985809, 15.79347229], [80.79957581, 15.79347038], [80.79957581, 15.7937603], [80.79930878, 15.7937603], [80.79930878, 15.79486275], [80.79902649, 15.79486275], [80.79902649, 15.79514122], [80.79875183, 15.79513836], [80.79875183, 15.7956953], [80.79846954, 15.79568958], [80.79846954, 15.7962513], [80.79818726, 15.7962513], [80.79818726, 15.79653072], [80.79792023, 15.79652882], [80.79792023, 15.79736137], [80.79763794, 15.79736137], [80.79763794, 15.79847336], [80.79736328, 15.79847336], [80.79736328, 15.79958344], [80.79708099, 15.79957104], [80.79708099, 15.80014133], [80.79680634, 15.80013943], [80.79680634, 15.80097294], [80.79652405, 15.80097294], [80.79652405, 15.80208302], [80.79624939, 15.80208302], [80.79624939, 15.80236053], [80.79597473, 15.80236053], [80.79597473, 15.8045826], [80.79569244, 15.8045826], [80.79569244, 15.80597115], [80.79541779, 15.80597115], [80.79541779, 15.80708313], [80.79514313, 15.80708122], [80.79514313, 15.80764198], [80.79486084, 15.80764198], [80.79486084, 15.80792046], [80.79458618, 15.80791759], [80.79458618, 15.80819321], [80.79430389, 15.80819321], [80.79430389, 15.80847359], [80.79402924, 15.80847073], [80.79402924, 15.81042004], [80.79374695, 15.81041622], [80.79374695, 15.8120842], [80.79347229, 15.8120842], [80.79347229, 15.81458378], [80.79319763, 15.81458187], [80.79319763, 15.81624985], [80.79347229, 15.81624985], [80.79347229, 15.81653023], [80.79514313, 15.81653023], [80.79514313, 15.81681061], [80.79597473, 15.81680584], [80.79597473, 15.81708431], [80.79846954, 15.81708431], [80.79846954, 15.81680584], [80.80014038, 15.81681061], [80.80014038, 15.81653023], [80.80097198, 15.81653023], [80.80097198, 15.81624985], [80.80139923, 15.81624985], [80.80291748, 15.81624985], [80.80291748, 15.81597042], [80.80374908, 15.81597042], [80.80374908, 15.81624985], [80.80430603, 15.81624985], [80.80430603, 15.81653023], [80.80513763, 15.81653023], [80.80513763, 15.81624985], [80.80541992, 15.81624985], [80.80541992, 15.81597042], [80.80596924, 15.81597042], [80.80596924, 15.81624985], [80.80625153, 15.81624985], [80.80625153, 15.81653023], [80.80708313, 15.81653023], [80.80708313, 15.81624985], [80.8079071, 15.81624985], [80.8079071, 15.81597042], [80.80902863, 15.81597233], [80.80902863, 15.81569386], [80.81069183, 15.81569386], [80.81069183, 15.81597233], [80.81097412, 15.81597233], [80.81097412, 15.81708431], [80.81069183, 15.81707954], [80.81069183, 15.8176403], [80.81041718, 15.8176403], [80.81041718, 15.81986332], [80.81014252, 15.81986046], [80.81014252, 15.82181072], [80.81041718, 15.82181072], [80.81041718, 15.82236004], [80.81069183, 15.82236004], [80.81069183, 15.82319546], [80.81096649, 15.82318974], [80.81096649, 15.82514095], [80.81124878, 15.82514095], [80.81124878, 15.82625103], [80.81153107, 15.82625103], [80.81153107, 15.82708263], [80.81181335, 15.82708073], [80.81181335, 15.82931042], [80.81208038, 15.82931042], [80.81208038, 15.83153152], [80.81181335, 15.83153152], [80.81181335, 15.83293056], [80.81153107, 15.83291531], [80.81153107, 15.83319473], [80.81124878, 15.83319092], [80.81124878, 15.83375168], [80.81096649, 15.83375168], [80.81096649, 15.83403015], [80.81069183, 15.83402729], [80.81069183, 15.83458328], [80.81041718, 15.83458138], [80.81041718, 15.83486176], [80.81014252, 15.83486176], [80.81014252, 15.83541965], [80.80986023, 15.83541775], [80.80986023, 15.83597088], [80.80958557, 15.83597088], [80.80958557, 15.83708382], [80.80930328, 15.83708382], [80.80930328, 15.83736229], [80.80902863, 15.83735943], [80.80902863, 15.83763981], [80.80874634, 15.83763981], [80.80874634, 15.83792019], [80.80847168, 15.83791637], [80.80847168, 15.8381958], [80.80819702, 15.8381958], [80.80819702, 15.83847237], [80.8079071, 15.83846855], [80.8079071, 15.83875179], [80.80764008, 15.83875179], [80.80764008, 15.83930969], [80.80735779, 15.83930588], [80.80735779, 15.83958435], [80.80708313, 15.83958244], [80.80708313, 15.83986187], [80.80680847, 15.83986187], [80.80680847, 15.84041977], [80.80652618, 15.84041595], [80.80652618, 15.84069443], [80.80625153, 15.84069157], [80.80625153, 15.84152985], [80.80596924, 15.84152985], [80.80596924, 15.84181118], [80.80569458, 15.84180641], [80.80569458, 15.84208393], [80.80541992, 15.84208202], [80.80541992, 15.84263992], [80.80513763, 15.84263992], [80.80513763, 15.84292126], [80.80486298, 15.84291553], [80.80486298, 15.84319401], [80.80458069, 15.84319401], [80.80458069, 15.84347153], [80.80430603, 15.84346962], [80.80430603, 15.84375], [80.80403137, 15.84375], [80.80403137, 15.84403038], [80.80374908, 15.84402847], [80.80374908, 15.84458447], [80.80347443, 15.84458447], [80.80347443, 15.84486008], [80.80319214, 15.84485054], [80.80319214, 15.84514046], [80.80291748, 15.84514046], [80.80291748, 15.84542084], [80.80236053, 15.84541607], [80.80236053, 15.84569359], [80.80208588, 15.84569359], [80.80208588, 15.84597206], [80.80179596, 15.84597015], [80.80179596, 15.84624958], [80.80152893, 15.84624958], [80.80152893, 15.84653091], [80.80097198, 15.84653091], [80.80097198, 15.84681129], [80.80069733, 15.84680557], [80.80069733, 15.84708214], [80.80041504, 15.84708214], [80.80041504, 15.84736347], [80.80014038, 15.84735966], [80.80014038, 15.84764099], [80.79985809, 15.84763813], [80.79985809, 15.84791565], [80.79958344, 15.84791565], [80.79958344, 15.84819412], [80.79930878, 15.84819412], [80.79930878, 15.8484726], [80.79902649, 15.84846973], [80.79902649, 15.84875107], [80.79875183, 15.84875107], [80.79875183, 15.84903145], [80.79846954, 15.84903145], [80.79846954, 15.84931087], [80.79819489, 15.8493042], [80.79819489, 15.84958458], [80.79792023, 15.84958458], [80.79792023, 15.84986115], [80.79763794, 15.84986115], [80.79763794, 15.85014057], [80.79736328, 15.85014057], [80.79736328, 15.85042095], [80.79680634, 15.85041714], [80.79680634, 15.85069466], [80.79624939, 15.85069466], [80.79624939, 15.85097313], [80.7959671, 15.85097027], [80.7959671, 15.85153103], [80.79569244, 15.85153103], [80.79569244, 15.85181141], [80.7951355, 15.85180473], [80.7951355, 15.85208321], [80.79486084, 15.85208035], [80.79486084, 15.85236073], [80.79428864, 15.85236073], [80.79428864, 15.85264111], [80.79402924, 15.85264111], [80.79402924, 15.85292053], [80.79374695, 15.85291672], [80.79374695, 15.85319519], [80.79319763, 15.85319519], [80.79319763, 15.8534708], [80.79291534, 15.85347271], [80.79292297, 15.85375118], [80.79264069, 15.85375118], [80.79264069, 15.85404015], [80.7923584, 15.85402679], [80.7923584, 15.85458279], [80.79208374, 15.85458279], [80.79208374, 15.85486126], [80.79180908, 15.85486126], [80.79180908, 15.85514069], [80.79151917, 15.85514069], [80.79151917, 15.85542202], [80.79125214, 15.85541725], [80.79125214, 15.85569477], [80.79096985, 15.85569096], [80.79096985, 15.85625076], [80.79070282, 15.85625076], [80.79070282, 15.85652924], [80.7904129, 15.85652924], [80.7904129, 15.85680962], [80.78986359, 15.85680485], [80.78986359, 15.85708332], [80.7895813, 15.85708141], [80.7895813, 15.85736084], [80.78930664, 15.85736084], [80.78930664, 15.85763931], [80.78901672, 15.85763931], [80.78901672, 15.85791969], [80.78847504, 15.85791683], [80.78847504, 15.8581953], [80.78819275, 15.8581953], [80.78819275, 15.85847092], [80.7876358, 15.85847092], [80.7876358, 15.8587513], [80.78736115, 15.8587513], [80.78736115, 15.85903168], [80.78679657, 15.85903168], [80.78679657, 15.85931015], [80.78652954, 15.85930538], [80.78652954, 15.8595829], [80.78624725, 15.8595829], [80.78624725, 15.85986137], [80.7859726, 15.85984993], [80.7859726, 15.86014175], [80.78514099, 15.86014175], [80.78514099, 15.85984993], [80.78430176, 15.85986137], [80.78430176, 15.8595829], [80.7840271, 15.8595829], [80.7840271, 15.85902691], [80.78375244, 15.85903168], [80.78375244, 15.8587513], [80.78347015, 15.8587513], [80.78347015, 15.85847092], [80.78234863, 15.85847092], [80.78234863, 15.8587513], [80.78180695, 15.8587513], [80.78180695, 15.85903168], [80.78151703, 15.85903168], [80.78151703, 15.85931015], [80.78097534, 15.85930538], [80.78097534, 15.85986137], [80.78069305, 15.85984993], [80.78069305, 15.86014175], [80.7804184, 15.86014175], [80.7804184, 15.86042023], [80.77986145, 15.86041737], [80.77986145, 15.86069584], [80.77958679, 15.86069584], [80.77958679, 15.86097145], [80.77928925, 15.86097145], [80.77928925, 15.86125183], [80.77902985, 15.86125183], [80.77902985, 15.8615303], [80.77874756, 15.86152744], [80.77874756, 15.86208439], [80.7784729, 15.86208057], [80.7784729, 15.86236191], [80.77791595, 15.86236191], [80.77791595, 15.8629179], [80.7776413, 15.8629179], [80.7776413, 15.86319256], [80.77735901, 15.86319256], [80.77735901, 15.86347198], [80.77680206, 15.86347198], [80.77680206, 15.86375046], [80.77654266, 15.86375046], [80.77654266, 15.86403179], [80.77625275, 15.86403179], [80.77625275, 15.86431026], [80.77597046, 15.86430645], [80.77597046, 15.86458397], [80.77541351, 15.86458397], [80.77541351, 15.86486244], [80.77485657, 15.86485958], [80.77485657, 15.86513996], [80.77458191, 15.86513996], [80.77458191, 15.86542034], [80.77430725, 15.86542034], [80.77430725, 15.8659811], [80.77401733, 15.8659811], [80.77401733, 15.86625195], [80.7720871, 15.86625195], [80.7720871, 15.86542034], [80.77179718, 15.86542034], [80.77179718, 15.86513996], [80.77153015, 15.86513996], [80.77153015, 15.8645792], [80.77124786, 15.86458397], [80.77124786, 15.86402798], [80.77069092, 15.86403179], [80.77069092, 15.86375046], [80.7701416, 15.86375046], [80.7701416, 15.86347198], [80.76930237, 15.86347198], [80.76930237, 15.86319256], [80.76875305, 15.86319256], [80.76875305, 15.86347198], [80.76847076, 15.86347198], [80.76847076, 15.86375046], [80.76790619, 15.86375046], [80.76790619, 15.86403179], [80.76763916, 15.86403179], [80.76763916, 15.86431026], [80.76708221, 15.86430645], [80.76708221, 15.86458397], [80.76680756, 15.86458397], [80.76680756, 15.86486244], [80.7665329, 15.86485958], [80.7665329, 15.86513996], [80.76625061, 15.86513996], [80.76625061, 15.86542034], [80.76486206, 15.86541557], [80.76486206, 15.86569405], [80.76346588, 15.86568928], [80.76346588, 15.8659811], [80.76291656, 15.8659811], [80.76291656, 15.86625195], [80.76235962, 15.86625195], [80.76235962, 15.86653042], [80.76180267, 15.86653042], [80.76180267, 15.86680984], [80.76069641, 15.86680603], [80.76069641, 15.86708355], [80.75985718, 15.86708164], [80.75986481, 15.86736202], [80.7590332, 15.86736202], [80.7590332, 15.86763954], [80.75846863, 15.86763954], [80.75846863, 15.86791992], [80.75791931, 15.86791801], [80.75791931, 15.86819363], [80.75708008, 15.86819363], [80.75708008, 15.8684721], [80.75653076, 15.86847019], [80.75653076, 15.86874962], [80.75596619, 15.86874962], [80.75596619, 15.86903858], [80.75569153, 15.86903858], [80.75569153, 15.86931133], [80.75458527, 15.86930561], [80.75458527, 15.86958408], [80.75402832, 15.86958027], [80.75402832, 15.8698597], [80.75347137, 15.8698597], [80.75347137, 15.87014008], [80.7529068, 15.87014008], [80.7529068, 15.87042141], [80.75180817, 15.87041569], [80.75180817, 15.87069416], [80.75096893, 15.87069416], [80.75096893, 15.87097168], [80.74958038, 15.87097168], [80.74958038, 15.87125015], [80.74903107, 15.87125015], [80.74903107, 15.87153053], [80.74846649, 15.87153053], [80.74846649, 15.87181091], [80.74764252, 15.87180614], [80.74764252, 15.87208366], [80.74708557, 15.87208366], [80.74708557, 15.87236023], [80.74458313, 15.87236023], [80.74458313, 15.87263966], [80.74346924, 15.87263966], [80.74346924, 15.87292099], [80.74291992, 15.87291622], [80.74291992, 15.87319374], [80.74097443, 15.87319374], [80.74097443, 15.87347221], [80.74014282, 15.87347031], [80.74014282, 15.87374973], [80.73929596, 15.87374973], [80.73929596, 15.87403107], [80.73874664, 15.87403107], [80.73874664, 15.87431145], [80.73791504, 15.87430668], [80.73791504, 15.87458229], [80.73680878, 15.87458229], [80.73680878, 15.87485981], [80.73513794, 15.87485123], [80.73513794, 15.87514114], [80.73486328, 15.87514114], [80.73486328, 15.87542057], [80.73374939, 15.8754158], [80.73374939, 15.87569523], [80.73152924, 15.87569046], [80.73152924, 15.87597275], [80.72930908, 15.87597275], [80.72930908, 15.87625122], [80.72875214, 15.87625122], [80.72875214, 15.87653065], [80.72624969, 15.87653065], [80.72624969, 15.87681103], [80.72458649, 15.87680435], [80.72458649, 15.87708473], [80.72402954, 15.87708473], [80.72402954, 15.8773613], [80.72292328, 15.8773613], [80.72292328, 15.87764072], [80.7215271, 15.87764072], [80.7215271, 15.8779211], [80.72041321, 15.87791729], [80.72041321, 15.87819481], [80.7195816, 15.87819481], [80.7195816, 15.87847328], [80.71708679, 15.87847137], [80.71708679, 15.8787508], [80.71457672, 15.8787508], [80.71457672, 15.87903118], [80.71375275, 15.87903118], [80.71375275, 15.87931156], [80.71291351, 15.87930679], [80.71291351, 15.87958336], [80.71235657, 15.87957954], [80.71235657, 15.87986088], [80.71180725, 15.87986088], [80.71180725, 15.88014126], [80.7076416, 15.88014126], [80.7076416, 15.88042068], [80.70652771, 15.88041687], [80.70652771, 15.88069534], [80.70347595, 15.88068962], [80.70347595, 15.88097954], [80.70041656, 15.88097954], [80.70041656, 15.88125134], [80.69902802, 15.88125134], [80.69902802, 15.88153076], [80.69235992, 15.88153076], [80.69235992, 15.88125134], [80.68985748, 15.88125134], [80.68985748, 15.88153076], [80.68846893, 15.88153076], [80.68846893, 15.88180923], [80.68819427, 15.88180542], [80.68819427, 15.88208294], [80.68791962, 15.88208294], [80.68791962, 15.88236141], [80.68763733, 15.88236141], [80.68763733, 15.88264084], [80.68681335, 15.88264084], [80.68681335, 15.88236141], [80.68653107, 15.88236141], [80.68653107, 15.88208294], [80.68597412, 15.88208294], [80.68597412, 15.88180542], [80.68569183, 15.88180923], [80.68569183, 15.88153076], [80.68374634, 15.88153076], [80.68374634, 15.88125134], [80.68125153, 15.88125134], [80.68125153, 15.88097954], [80.67958069, 15.88097954], [80.67958069, 15.88068962], [80.67819214, 15.88069534], [80.67819214, 15.88041687], [80.67569733, 15.88042068], [80.67569733, 15.88014126], [80.66902924, 15.88014126], [80.66902924, 15.87986088], [80.66819, 15.87986088], [80.66819, 15.87957954], [80.66236115, 15.87958336], [80.66236115, 15.87930679], [80.65847015, 15.87931156], [80.65847015, 15.87903118], [80.65651703, 15.87903118], [80.65651703, 15.8787508], [80.65458679, 15.8787508], [80.65458679, 15.87847137], [80.6526413, 15.87847328], [80.6526413, 15.87819481], [80.64930725, 15.87819481], [80.64930725, 15.87791729], [80.64707947, 15.8779211], [80.64707947, 15.87764072], [80.64402008, 15.87764072], [80.64402008, 15.8773613], [80.64347076, 15.8773613], [80.64347076, 15.87708473], [80.64319611, 15.87708473], [80.64319611, 15.87680435], [80.64125061, 15.87681103], [80.64125061, 15.87653065], [80.64013672, 15.87653065], [80.64013672, 15.87625122], [80.63903046, 15.87625122], [80.63903046, 15.87597275], [80.63874817, 15.87597275], [80.63874817, 15.87569046], [80.63847351, 15.87569523], [80.63847351, 15.8754158], [80.63625336, 15.87542057], [80.63625336, 15.87514114], [80.63540649, 15.87514114], [80.63540649, 15.87485123], [80.63319397, 15.87485981], [80.63319397, 15.87458229], [80.63208008, 15.87458229], [80.63208008, 15.87430668], [80.62847137, 15.87431145], [80.62847137, 15.87403107], [80.62652588, 15.87403107], [80.62652588, 15.87374973], [80.62486267, 15.87374973], [80.62486267, 15.87347031], [80.62347412, 15.87347221], [80.62347412, 15.87319374], [80.62041473, 15.87319374], [80.62041473, 15.87291622], [80.61846924, 15.87292099], [80.61846924, 15.87263966], [80.61680603, 15.87263966], [80.61680603, 15.87236023], [80.61597443, 15.87236023], [80.61597443, 15.87208366], [80.61347198, 15.87208366], [80.61347198, 15.87180614], [80.61264038, 15.87181091], [80.61264038, 15.87153053], [80.61013794, 15.87153053], [80.61013794, 15.87125015], [80.60930634, 15.87125015], [80.60930634, 15.87097168], [80.60847473, 15.87097168], [80.60847473, 15.87069416], [80.60708618, 15.87069416], [80.60708618, 15.87041569], [80.60624695, 15.87042141], [80.60624695, 15.87014008], [80.60542297, 15.87014008], [80.60542297, 15.8698597], [80.60319519, 15.8698597], [80.60319519, 15.86958408], [80.60124969, 15.86958408], [80.60124969, 15.86930561], [80.59958649, 15.86931133], [80.59958649, 15.86903858], [80.59874725, 15.86903858], [80.59874725, 15.86874962], [80.59764099, 15.86874962], [80.59764099, 15.86847019], [80.59597015, 15.8684721], [80.59597015, 15.86819363], [80.59486389, 15.86819363], [80.59486389, 15.86791801], [80.5945816, 15.86791992], [80.5945816, 15.86763954], [80.59236145, 15.86763954], [80.59236145, 15.86736202], [80.59124756, 15.86736202], [80.59124756, 15.86708164], [80.59041595, 15.86708355], [80.59041595, 15.86680603], [80.58930206, 15.86680984], [80.58930206, 15.86653042], [80.58875275, 15.86653042], [80.58875275, 15.86625195], [80.58790588, 15.86625195], [80.58790588, 15.8659811], [80.58763885, 15.8659811], [80.58763885, 15.86568928], [80.58569336, 15.86569405], [80.58569336, 15.86541557], [80.58486176, 15.86541557], [80.5845871, 15.86542034], [80.5845871, 15.86513996], [80.58403015, 15.86513996], [80.58403015, 15.86485958], [80.5826416, 15.86486244], [80.5826416, 15.86458397], [80.58152771, 15.86458397], [80.58152771, 15.86430645], [80.58097076, 15.86431026], [80.58097076, 15.86403179], [80.58069611, 15.86403179], [80.58069611, 15.86375046], [80.57847595, 15.86375046], [80.57847595, 15.86347198], [80.57763672, 15.86347198], [80.57763672, 15.86319256], [80.57653046, 15.86319256], [80.57653046, 15.8629179], [80.57597351, 15.8629179], [80.57597351, 15.86263657], [80.57402802, 15.86264038], [80.57402802, 15.86236191], [80.57319641, 15.86236191], [80.57319641, 15.86208057], [80.57236481, 15.86208439], [80.57236481, 15.86180496], [80.5715332, 15.86180973], [80.5715332, 15.8615303], [80.56986237, 15.8615303], [80.56986237, 15.86125183], [80.56958008, 15.86125183], [80.56958008, 15.86097145], [80.56903076, 15.86097145], [80.56903076, 15.86069584], [80.56680298, 15.86069584], [80.56680298, 15.86041737], [80.56624603, 15.86042023], [80.56624603, 15.86014175], [80.56569672, 15.86014175], [80.56569672, 15.85984993], [80.56430817, 15.85986137], [80.56430817, 15.8595829], [80.56375122, 15.8595829], [80.56375122, 15.85930538], [80.56292725, 15.85931015], [80.56292725, 15.85903168], [80.56181335, 15.85903168], [80.56181335, 15.8587513], [80.56096649, 15.8587513], [80.56096649, 15.85847092], [80.56014252, 15.85847092], [80.56014252, 15.8581953], [80.55986023, 15.8581953], [80.55986023, 15.85791683], [80.55847168, 15.85791969], [80.55847168, 15.85763931], [80.5579071, 15.85763931], [80.5579071, 15.85736084], [80.55735779, 15.85736084], [80.55735779, 15.85708141], [80.55625153, 15.85708332], [80.55625153, 15.85680485], [80.55568695, 15.85680962], [80.55568695, 15.85652924], [80.55458069, 15.85652924], [80.55458069, 15.85625076], [80.55430603, 15.85625076], [80.55430603, 15.85597134], [80.55403137, 15.85597324], [80.55403137, 15.85569477], [80.55347443, 15.85569477], [80.55347443, 15.85541725], [80.55208588, 15.85542202], [80.55208588, 15.85514069], [80.55069733, 15.85514069], [80.55069733, 15.85486126], [80.54958344, 15.85486126], [80.54958344, 15.85458279], [80.54902649, 15.85458279], [80.54902649, 15.85430527], [80.54875183, 15.85431194], [80.54875183, 15.85404015], [80.54818726, 15.85404015], [80.54818726, 15.85375118], [80.54792023, 15.85375118], [80.54792023, 15.8534708], [80.54763794, 15.8534708], [80.54763794, 15.85319519], [80.54624939, 15.85319519], [80.54624939, 15.85291672], [80.54569244, 15.85292053], [80.54569244, 15.85264111], [80.54514313, 15.85264111], [80.54514313, 15.85236073], [80.54291534, 15.85236073], [80.54291534, 15.85208321], [80.54152679, 15.85208035], [80.54152679, 15.85236073], [80.54096985, 15.85236073], [80.54096985, 15.85252857], [80.54096985, 15.85264111], [80.54070282, 15.85264111], [80.54070282, 15.85292053], [80.5404129, 15.85291672], [80.5404129, 15.85319519], [80.53986359, 15.85319519], [80.53986359, 15.8534708], [80.5395813, 15.8534708], [80.5395813, 15.85404015], [80.53930664, 15.85404015], [80.53930664, 15.85431194], [80.53874969, 15.85430527], [80.53874969, 15.85458279], [80.53847504, 15.85458279], [80.53847504, 15.85486126], [80.53736115, 15.85486126], [80.53736115, 15.85458279], [80.53652954, 15.85458279], [80.53652954, 15.85430527], [80.5359726, 15.85431194], [80.5359726, 15.85404015], [80.53569031, 15.85404015], [80.53569031, 15.85375118], [80.53514099, 15.85375118], [80.53514099, 15.8534708], [80.53458405, 15.8534708], [80.53458405, 15.85319519], [80.53430176, 15.85319519], [80.53430176, 15.85291672], [80.5340271, 15.85292053], [80.5340271, 15.85264111], [80.53375244, 15.85264111], [80.53375244, 15.85236073], [80.53347015, 15.85236073], [80.53347015, 15.85208035], [80.5331955, 15.85208321], [80.5331955, 15.85180473], [80.53291321, 15.85181141], [80.53291321, 15.85153103], [80.53263092, 15.85153103], [80.53263092, 15.85125065], [80.53098297, 15.85125065], [80.53098297, 15.85153103], [80.53069305, 15.85153103], [80.53069305, 15.85181141], [80.5304184, 15.85180473], [80.5304184, 15.85208321], [80.52986145, 15.85208321], [80.52986145, 15.85180473], [80.52958679, 15.85181141], [80.52958679, 15.85125065], [80.52986145, 15.85125065], [80.52986145, 15.85097027], [80.53013611, 15.85097313], [80.53013611, 15.85069466], [80.5304184, 15.85069466], [80.5304184, 15.85041714], [80.53098297, 15.85042095], [80.53098297, 15.85014057], [80.53125, 15.85014057], [80.53125, 15.84986115], [80.53152466, 15.84986115], [80.53152466, 15.84958458], [80.53180695, 15.84958458], [80.53180695, 15.8493042], [80.53235626, 15.84931087], [80.53235626, 15.84903145], [80.53275299, 15.84902859], [80.53347015, 15.84903145], [80.53347015, 15.84875107], [80.53320313, 15.84875107], [80.53320313, 15.84846973], [80.53263855, 15.8484726], [80.53263855, 15.84819412], [80.53236389, 15.84819412], [80.53236389, 15.84791565], [80.5320816, 15.84791565], [80.5320816, 15.84763813], [80.53125, 15.84764099], [80.53125, 15.84735966], [80.53000641, 15.84736347], [80.5293045, 15.84736347], [80.5293045, 15.84708214], [80.52902985, 15.84708214], [80.52902985, 15.84680557], [80.52874756, 15.84681129], [80.52874756, 15.84653091], [80.52819824, 15.84653091], [80.52819061, 15.84624958], [80.52707672, 15.84624958], [80.52707672, 15.84597015], [80.5248642, 15.84597206], [80.5248642, 15.84569359], [80.52458191, 15.84569359], [80.52458191, 15.84541607], [80.52401733, 15.84542084], [80.52401733, 15.84514046], [80.52375031, 15.84514046], [80.52375031, 15.84485054], [80.5229187, 15.84486008], [80.5229187, 15.84458447], [80.52180481, 15.84458447], [80.52180481, 15.84430599], [80.52097321, 15.84431076], [80.52097321, 15.84403038], [80.52041626, 15.84403038], [80.52041626, 15.84375], [80.51985931, 15.84375], [80.51985931, 15.84346962], [80.51958466, 15.84347153], [80.51958466, 15.84319401], [80.51875305, 15.84319401], [80.51875305, 15.84291553], [80.51764679, 15.84292126], [80.51764679, 15.84263992], [80.51735687, 15.84263992], [80.51735687, 15.84235954], [80.51652527, 15.8423624], [80.51652527, 15.84208393], [80.51597595, 15.84208393], [80.51597595, 15.84180641], [80.51486206, 15.84181118], [80.51486206, 15.84152985], [80.51403046, 15.84152985], [80.51403046, 15.84125042], [80.51264191, 15.84125042], [80.51264191, 15.84097195], [80.51208496, 15.84097195], [80.51208496, 15.84069443], [80.51158905, 15.84069443], [80.51097107, 15.84069443], [80.51097107, 15.84041595], [80.51069641, 15.84041977], [80.51069641, 15.84014034], [80.50875092, 15.84014034], [80.50875092, 15.83986187], [80.50791931, 15.83986187], [80.50791931, 15.83958244], [80.50736237, 15.83958435], [80.50736237, 15.83930588], [80.50681305, 15.83930969], [80.50681305, 15.83903027], [80.50653076, 15.83903027], [80.50653076, 15.83875179], [80.50624847, 15.83875179], [80.50624847, 15.83846855], [80.50569153, 15.83847237], [80.50569153, 15.8381958], [80.50458527, 15.8381958], [80.50458527, 15.83791637], [80.50374603, 15.83792019], [80.50374603, 15.83763981], [80.50235748, 15.83763981], [80.50235748, 15.83735943], [80.50125122, 15.83736229], [80.50125122, 15.83708382], [80.50069427, 15.83708382], [80.50069427, 15.8368063], [80.50041962, 15.83681011], [80.50041962, 15.83652973], [80.50013733, 15.83652973], [80.50013733, 15.83625031], [80.49903107, 15.83625031], [80.49903107, 15.83597088], [80.49847412, 15.83597088], [80.49847412, 15.83569336], [80.49791718, 15.83569336], [80.49791718, 15.83541775], [80.49764252, 15.83541965], [80.49764252, 15.83514023], [80.49680328, 15.83514023], [80.49680328, 15.83486176], [80.49597168, 15.83486176], [80.49597168, 15.83458138], [80.49541473, 15.83458328], [80.49541473, 15.83430481], [80.49430847, 15.83430958], [80.49430847, 15.83403015], [80.49375153, 15.83403015], [80.49375153, 15.83375168], [80.49346161, 15.83375168], [80.49346161, 15.8334713], [80.49291992, 15.8334713], [80.49291992, 15.83319473], [80.49236298, 15.83319473], [80.49236298, 15.83291531], [80.49124908, 15.83293056], [80.49124908, 15.8326416], [80.49069214, 15.8326416], [80.49069214, 15.83236122], [80.48958588, 15.83236122], [80.48958588, 15.83208275], [80.48930359, 15.83208275], [80.48930359, 15.83180523], [80.48874664, 15.8318119], [80.48874664, 15.83153152], [80.48764038, 15.83153152], [80.48764038, 15.83124924], [80.48707581, 15.83124924], [80.48707581, 15.83097076], [80.48680878, 15.83097267], [80.48680878, 15.83069515], [80.48596954, 15.83069515], [80.48596954, 15.83041668], [80.48568726, 15.83041859], [80.48568726, 15.83014107], [80.48486328, 15.83014107], [80.48486328, 15.82987022], [80.48401642, 15.82987022], [80.48401642, 15.82958126], [80.48347473, 15.82958317], [80.48347473, 15.8293047], [80.48319244, 15.82931042], [80.48319244, 15.82903099], [80.48236084, 15.82903099], [80.48236084, 15.82875061], [80.48179626, 15.82875061], [80.48179626, 15.82847118], [80.48097229, 15.82847309], [80.48097229, 15.82819462], [80.48014069, 15.82819462], [80.48014069, 15.8279171], [80.47930908, 15.82792187], [80.47930908, 15.82764053], [80.47902679, 15.82764053], [80.47902679, 15.82736111], [80.47875214, 15.82736111], [80.47875214, 15.82708263], [80.47846985, 15.82708263], [80.47846985, 15.82625103], [80.47820282, 15.82625103], [80.47820282, 15.82597065], [80.47763824, 15.82597065], [80.47763824, 15.82625103], [80.4770813, 15.82625103], [80.4770813, 15.82653141], [80.47598267, 15.82653141], [80.47598267, 15.82625103], [80.47486115, 15.82625103], [80.47486115, 15.82597065], [80.4743042, 15.82597256], [80.4743042, 15.82569504], [80.47402954, 15.82569504], [80.47402954, 15.82541656], [80.47264099, 15.82542133], [80.47264099, 15.82514095], [80.47180176, 15.82514095], [80.47180176, 15.82486057], [80.47125244, 15.82486057], [80.47125244, 15.82458305], [80.47097015, 15.82458305], [80.47097015, 15.82430458], [80.47070313, 15.82431126], [80.47070313, 15.82403088], [80.47041321, 15.82403088], [80.47041321, 15.82374191], [80.47013855, 15.82374763], [80.47013855, 15.82347298], [80.46986389, 15.82347298], [80.46986389, 15.82319546], [80.46847534, 15.82319546], [80.46847534, 15.82291698], [80.4679184, 15.8229208], [80.4679184, 15.82264137], [80.46763611, 15.82264137], [80.46763611, 15.82236004], [80.46708679, 15.82236004], [80.46708679, 15.82207966], [80.4668045, 15.82208157], [80.4668045, 15.82180691], [80.4659729, 15.82181072], [80.4659729, 15.8215313], [80.4651413, 15.8215313], [80.4651413, 15.82125092], [80.4640274, 15.82125092], [80.4640274, 15.82096958], [80.46375275, 15.82097244], [80.46375275, 15.82069397], [80.46347809, 15.82068062], [80.46347046, 15.82041645], [80.4631958, 15.82042122], [80.4631958, 15.82014275], [80.46263885, 15.82014275], [80.46263885, 15.81986046], [80.46208191, 15.81986332], [80.46208191, 15.81958199], [80.46180725, 15.81958199], [80.46180725, 15.81930637], [80.46041107, 15.81931114], [80.46041107, 15.81903076], [80.46013641, 15.81903076], [80.46013641, 15.81875038], [80.45986176, 15.81875038], [80.45986176, 15.81847], [80.45930481, 15.81847191], [80.45930481, 15.81819439], [80.45847321, 15.81819439], [80.45847321, 15.81791592], [80.4576416, 15.81793022], [80.4576416, 15.8176403], [80.45680237, 15.8176403], [80.45680237, 15.81735992], [80.45625305, 15.81735992], [80.45625305, 15.81707954], [80.45569611, 15.81708431], [80.45569611, 15.81680584], [80.45540619, 15.81681061], [80.45540619, 15.81653023], [80.45485687, 15.81653023], [80.45485687, 15.81624985], [80.45318604, 15.81624985], [80.45318604, 15.81597042], [80.45291901, 15.81597233], [80.45291901, 15.81569386], [80.45263672, 15.81569386], [80.45263672, 15.81541634], [80.45153809, 15.81542015], [80.45153809, 15.81514168], [80.45096588, 15.81514168], [80.45096588, 15.81487083], [80.45041656, 15.81487083], [80.45041656, 15.81458187], [80.45014191, 15.81458378], [80.45014191, 15.81430626], [80.44957733, 15.81431103], [80.44957733, 15.81402969], [80.44930267, 15.81402969], [80.44930267, 15.81375027], [80.44902802, 15.81375027], [80.44902802, 15.81347179], [80.44875336, 15.81347179], [80.44875336, 15.81319237], [80.44763947, 15.81319427], [80.44763947, 15.8129158], [80.44680786, 15.81291962], [80.44680786, 15.81264019], [80.44625092, 15.81264019], [80.44625092, 15.81236172], [80.44568634, 15.81236172], [80.44568634, 15.81207943], [80.44541931, 15.8120842], [80.44541931, 15.81180573], [80.44486237, 15.81180573], [80.44486237, 15.81152821], [80.44431305, 15.81153011], [80.44431305, 15.81124973], [80.44374847, 15.81124973], [80.44374847, 15.81096935], [80.44319153, 15.81097221], [80.44319153, 15.81069374], [80.44291687, 15.81069374], [80.44291687, 15.81041622], [80.4420929, 15.81042004], [80.4420929, 15.81013966], [80.44124603, 15.81013966], [80.44124603, 15.80985928], [80.44097137, 15.80986214], [80.44097137, 15.80958366], [80.44013977, 15.80958366], [80.44013977, 15.80930614], [80.43985748, 15.80930996], [80.43985748, 15.80902958], [80.43930817, 15.80902958], [80.43930817, 15.80873966], [80.43902588, 15.8087492], [80.43902588, 15.80847359], [80.43846893, 15.80847359], [80.43846893, 15.80819321], [80.43736267, 15.80819321], [80.43736267, 15.80791759], [80.43681335, 15.80792046], [80.43681335, 15.80764198], [80.43624115, 15.80764198], [80.43624115, 15.80736065], [80.43597412, 15.80736065], [80.43596649, 15.80708122], [80.43541718, 15.80708313], [80.43541718, 15.80680466], [80.43514252, 15.80681038], [80.43514252, 15.80653191], [80.43347168, 15.80653191], [80.43347168, 15.80625153], [80.43319702, 15.80625153], [80.43319702, 15.80597115], [80.43264008, 15.80597115], [80.43264008, 15.80569458], [80.43096924, 15.8057003], [80.43096924, 15.80542183], [80.43068695, 15.80542183], [80.43068695, 15.8051424], [80.43042755, 15.8051424], [80.43042755, 15.80486107], [80.43013763, 15.80486107], [80.43013763, 15.80458069], [80.42986298, 15.8045826], [80.42986298, 15.80430508], [80.42958069, 15.80431175], [80.42958069, 15.80402946], [80.42930603, 15.80402946], [80.42930603, 15.80375099], [80.42903137, 15.80375099], [80.42903137, 15.80347061], [80.42874908, 15.80347347], [80.42874908, 15.80319309], [80.42830658, 15.80319309], [80.42819214, 15.80319309], [80.42819214, 15.80291653], [80.42791748, 15.80293083], [80.42791748, 15.80264091], [80.42736816, 15.80264091], [80.42736816, 15.80236053], [80.42680359, 15.80236053], [80.42680359, 15.80208302], [80.42652893, 15.80208302], [80.42652893, 15.80180454], [80.42624664, 15.80181026], [80.42624664, 15.80153084], [80.42597198, 15.80153084], [80.42597198, 15.80125141], [80.42514038, 15.80125141], [80.42514038, 15.80097103], [80.42458344, 15.80097294], [80.42458344, 15.80069542], [80.42430878, 15.80069542], [80.42430878, 15.80041695], [80.42375183, 15.80042171], [80.42375183, 15.80014133], [80.42346954, 15.80014133], [80.42346954, 15.79986095], [80.42236328, 15.79986095], [80.42236328, 15.79957104], [80.42180634, 15.79958344], [80.42180634, 15.79930687], [80.42151642, 15.79931164], [80.42151642, 15.79903126], [80.42124176, 15.79903126], [80.42124176, 15.79875088], [80.4209671, 15.79875088], [80.4209671, 15.79847145], [80.41986084, 15.79847336], [80.41986084, 15.79819489], [80.41902924, 15.79819489], [80.41902924, 15.79791737], [80.41874695, 15.79792118], [80.41874695, 15.7976408], [80.41819763, 15.7976408], [80.41819763, 15.79736137], [80.41791534, 15.79736137], [80.41791534, 15.7970829], [80.41708374, 15.7970829], [80.41708374, 15.79680538], [80.41680908, 15.79680538], [80.41680908, 15.79652882], [80.41625214, 15.79653072], [80.41625214, 15.7962513], [80.4154129, 15.7962513], [80.4154129, 15.79596996], [80.41486359, 15.79597282], [80.41486359, 15.7956953], [80.4145813, 15.7956953], [80.4145813, 15.79541683], [80.41401672, 15.79542065], [80.41401672, 15.79514122], [80.41374969, 15.79514122], [80.41374969, 15.79486275], [80.41291809, 15.79486275], [80.41291809, 15.79458046], [80.41236115, 15.79458237], [80.41236115, 15.79430676], [80.41179657, 15.79431057], [80.41179657, 15.79403114], [80.41152954, 15.79403114], [80.41152954, 15.7937603], [80.4109726, 15.7937603], [80.4109726, 15.79347038], [80.41014099, 15.79347229], [80.41014099, 15.79319382], [80.4098587, 15.79319382], [80.4098587, 15.7929163], [80.40957642, 15.79292107], [80.40957642, 15.79264069], [80.40930176, 15.79264069], [80.40930176, 15.79236031], [80.40875244, 15.79236031], [80.40875244, 15.79208374], [80.40847015, 15.79208374], [80.40847015, 15.79180622], [80.40820313, 15.79181099], [80.40820313, 15.79153061], [80.40763855, 15.79153061], [80.40763855, 15.79125023], [80.40680695, 15.79125023], [80.40680695, 15.79096985], [80.40625, 15.79097176], [80.40625, 15.79069424], [80.40569305, 15.79070091], [80.40569305, 15.79042053], [80.4054184, 15.79042053], [80.4054184, 15.79014015], [80.40513611, 15.79014015], [80.40513611, 15.78986168], [80.40486145, 15.78986168], [80.40486145, 15.78958035], [80.40402985, 15.78958416], [80.40402985, 15.78930569], [80.4034729, 15.78931141], [80.4034729, 15.78903008], [80.40319824, 15.78903008], [80.40319824, 15.78874969], [80.40291595, 15.78874969], [80.40291595, 15.78847027], [80.40235901, 15.78847218], [80.40235901, 15.7881937], [80.40180206, 15.7881937], [80.40180206, 15.78791809], [80.4015274, 15.78792], [80.4015274, 15.78763103], [80.40097046, 15.78763771], [80.40097046, 15.7873621], [80.40041351, 15.7873621], [80.40041351, 15.78708363], [80.3998642, 15.78708363], [80.3998642, 15.78680611], [80.39958191, 15.78681087], [80.39958191, 15.78652954], [80.39875031, 15.78652954], [80.39875031, 15.78625202], [80.39848328, 15.78625202], [80.39848328, 15.78597164], [80.39819336, 15.78597164], [80.39819336, 15.78569412], [80.39763641, 15.78569412], [80.39763641, 15.78541565], [80.39736176, 15.78542042], [80.39736176, 15.78514004], [80.39653015, 15.78514004], [80.39653015, 15.78485966], [80.39597321, 15.78486156], [80.39597321, 15.78458405], [80.39541626, 15.78458405], [80.39541626, 15.78430557], [80.3951416, 15.78431034], [80.3951416, 15.78402996], [80.39485931, 15.78402996], [80.39485931, 15.78374958], [80.39430237, 15.78374958], [80.39430237, 15.7834692], [80.39402771, 15.78347206], [80.39402771, 15.78319359], [80.39347076, 15.78319359], [80.39347076, 15.78291798], [80.39319611, 15.78292179], [80.39319611, 15.78264046], [80.39263916, 15.78264046], [80.39263916, 15.78236198], [80.39235687, 15.78236198], [80.39235687, 15.78208065], [80.39208221, 15.78208447], [80.39208221, 15.78180599], [80.3915329, 15.78181934], [80.3915329, 15.78153038], [80.39125824, 15.78153038], [80.39125824, 15.78125191], [80.39068604, 15.78125191], [80.39068604, 15.78097057], [80.38986206, 15.78097057], [80.38986206, 15.78069305], [80.38930511, 15.78069305], [80.38930511, 15.7804184], [80.38874817, 15.7804203], [80.38874817, 15.78014183], [80.38819122, 15.78014183], [80.38819122, 15.77986145], [80.38791656, 15.77986145], [80.38791656, 15.77958298], [80.38735962, 15.77958298], [80.38735962, 15.77930546], [80.38680267, 15.77931023], [80.38680267, 15.77903175], [80.38652802, 15.77903175], [80.38652802, 15.77876091], [80.38625336, 15.77876091], [80.38625336, 15.77847099], [80.38569641, 15.77847099], [80.38569641, 15.77819538], [80.38513947, 15.77819538], [80.38513947, 15.77791691], [80.38458252, 15.77791977], [80.38458252, 15.77763939], [80.3840332, 15.77763939], [80.3840332, 15.77736092], [80.38375092, 15.77736092], [80.38375092, 15.77708054], [80.38319397, 15.7770834], [80.38319397, 15.77680492], [80.38291931, 15.77680969], [80.38291931, 15.77652931], [80.38236237, 15.77652931], [80.38236237, 15.77625084], [80.38207245, 15.77625084], [80.38207245, 15.77597141], [80.38180542, 15.77597332], [80.38180542, 15.77569485], [80.38153076, 15.77569485], [80.38153076, 15.77541733], [80.38069153, 15.77541924], [80.38069153, 15.77514076], [80.38041687, 15.77514076], [80.38041687, 15.77486134], [80.37985992, 15.77486134], [80.37985992, 15.77458286], [80.37958527, 15.77458286], [80.37958527, 15.77430534], [80.37930298, 15.77431202], [80.37930298, 15.77403069], [80.37902832, 15.77403069], [80.37902832, 15.77375126], [80.37874603, 15.77375126], [80.37874603, 15.77347088], [80.37847137, 15.77347088], [80.37847137, 15.77319527], [80.37763977, 15.77319527], [80.37763977, 15.77291679], [80.37735748, 15.77292061], [80.37735748, 15.77262974], [80.37680817, 15.77263927], [80.37680817, 15.7723608], [80.37652588, 15.7723608], [80.37652588, 15.77208328], [80.37596893, 15.77208328], [80.37596893, 15.77180481], [80.37513733, 15.77181244], [80.37513733, 15.77153111], [80.37486267, 15.77153111], [80.37486267, 15.77125072], [80.37458038, 15.77125072], [80.37458038, 15.7709713], [80.37430573, 15.77097321], [80.37430573, 15.77069473], [80.37374878, 15.77069473], [80.37374878, 15.77041721], [80.37319183, 15.77042103], [80.37319183, 15.77014065], [80.37236023, 15.77014065], [80.37236023, 15.76986122], [80.37208557, 15.76986122], [80.37208557, 15.76958466], [80.37180328, 15.76958942], [80.37180328, 15.76931095], [80.37124634, 15.76931095], [80.37124634, 15.76903057], [80.37097168, 15.76903057], [80.37097168, 15.76875114], [80.37069702, 15.76875114], [80.37069702, 15.76846981], [80.37014008, 15.76847267], [80.37014008, 15.76819515], [80.36985779, 15.76819515], [80.36985779, 15.76791573], [80.36930847, 15.76792145], [80.36930847, 15.76764107], [80.36875153, 15.76764107], [80.36875153, 15.76735973], [80.36846924, 15.76735973], [80.36846924, 15.76708031], [80.36791992, 15.76708221], [80.36791992, 15.7668066], [80.36763763, 15.76681995], [80.36763763, 15.76653099], [80.36708832, 15.76653099], [80.36708832, 15.76624966], [80.36653137, 15.76624966], [80.36653137, 15.76597023], [80.36597443, 15.76597214], [80.36597443, 15.76569366], [80.36569214, 15.76569366], [80.36569214, 15.76541615], [80.36541748, 15.76542091], [80.36541748, 15.76513958], [80.36514282, 15.76513958], [80.36514282, 15.76486015], [80.36430359, 15.76486015], [80.36430359, 15.76458359], [80.36402893, 15.76458359], [80.36402893, 15.76430416], [80.36347198, 15.76431084], [80.36347198, 15.76403141], [80.36319733, 15.76403141], [80.36319733, 15.76375008], [80.36264038, 15.76375008], [80.36264038, 15.7634697], [80.36180878, 15.7634716], [80.36180878, 15.76319408], [80.36125183, 15.76319408], [80.36125183, 15.76291561], [80.36068726, 15.76292133], [80.36068726, 15.76235962], [80.36042023, 15.76236153], [80.36042023, 15.76208401], [80.35958099, 15.76208401], [80.35958099, 15.76180553], [80.35901642, 15.76181126], [80.35901642, 15.76152992], [80.35874939, 15.76152992], [80.35874939, 15.76124954], [80.3584671, 15.76124954], [80.3584671, 15.76097202], [80.35819244, 15.76097202], [80.35819244, 15.76069355], [80.35791779, 15.76069355], [80.35791779, 15.76041794], [80.35764313, 15.76041985], [80.35764313, 15.76014042], [80.35736084, 15.76014042], [80.35736084, 15.75986195], [80.35679626, 15.75986195], [80.35679626, 15.75958157], [80.35624695, 15.75958443], [80.35624695, 15.75930595], [80.35597229, 15.75930977], [80.35597229, 15.75903034], [80.35569763, 15.75903034], [80.35569763, 15.75846863], [80.35541534, 15.75847244], [80.35541534, 15.75819588], [80.35514832, 15.7581892], [80.35514069, 15.75763988], [80.35457611, 15.75765133], [80.35457611, 15.75736046], [80.35402679, 15.75736237], [80.35402679, 15.75708389], [80.35375214, 15.75708389], [80.35375214, 15.75680637], [80.35346985, 15.75681019], [80.35346985, 15.75625038], [80.35319519, 15.75625038], [80.35319519, 15.75597191], [80.35263824, 15.75597191], [80.35263824, 15.75569344], [80.35236359, 15.75569344], [80.35236359, 15.75541782], [80.35180664, 15.75541973], [80.35180664, 15.7551403], [80.35151672, 15.7551403], [80.35151672, 15.75486183], [80.35124969, 15.75486183], [80.35121918, 15.75464344], [80.35111237, 15.75458813], [80.35098267, 15.75459003], [80.35098267, 15.75430965], [80.35069275, 15.75430965], [80.35069275, 15.75403023], [80.35015106, 15.75402069], [80.3501358, 15.75374889], [80.34986115, 15.75375175], [80.34986115, 15.75347137], [80.34958649, 15.75347137], [80.34958649, 15.75319576], [80.3493042, 15.75319576], [80.3493042, 15.75291538], [80.34902191, 15.75292015], [80.34902191, 15.75264168], [80.34874725, 15.75264168], [80.34874725, 15.7523613], [80.3482666, 15.7523613], [80.34791565, 15.7523613], [80.34791565, 15.75208282], [80.3473587, 15.75208282], [80.3473587, 15.75180531], [80.34625244, 15.75181198], [80.34625244, 15.75152016], [80.34597015, 15.75152683], [80.34597015, 15.75124931], [80.34513855, 15.75124931], [80.34513855, 15.75097084], [80.3445816, 15.75097084], [80.3445816, 15.75069141], [80.34430695, 15.75069523], [80.34430695, 15.75041676], [80.34401703, 15.75041962], [80.34401703, 15.75013924], [80.34375, 15.75013924], [80.34375, 15.74986076], [80.34319305, 15.74986076], [80.34319305, 15.74958134], [80.3429184, 15.74958324], [80.3429184, 15.74930477], [80.34263611, 15.74930954], [80.34263611, 15.74903202], [80.34236145, 15.74903202], [80.34236145, 15.74875069], [80.34179687, 15.74875069], [80.34179687, 15.74845886], [80.34124756, 15.74847317], [80.34124756, 15.74819469], [80.3409729, 15.74819469], [80.3409729, 15.74791718], [80.34041595, 15.74792194], [80.34041595, 15.74764061], [80.34014893, 15.74764061], [80.34014893, 15.74736118], [80.33958435, 15.74736118], [80.33958435, 15.74708271], [80.33930206, 15.74708271], [80.33930206, 15.74680519], [80.3390274, 15.74681187], [80.3390274, 15.74653053], [80.33875275, 15.74653053], [80.33875275, 15.74625111], [80.33847046, 15.74625111], [80.33847046, 15.74597073], [80.3381958, 15.74597263], [80.3381958, 15.74569511], [80.33791351, 15.74569511], [80.33791351, 15.74541664], [80.33763885, 15.74542141], [80.33763885, 15.74514103], [80.33735657, 15.74514103], [80.33735657, 15.74458027], [80.33708191, 15.74458313], [80.33708191, 15.74374866], [80.33680725, 15.74375057], [80.33680725, 15.74347019], [80.33652496, 15.74347305], [80.33652496, 15.74319458], [80.33625031, 15.74319458], [80.33625031, 15.74291706], [80.33598328, 15.74292088], [80.33598328, 15.74267006], [80.33569336, 15.74265003], [80.33569336, 15.74249268], [80.33569336, 15.74236107], [80.3354187, 15.74236107], [80.3354187, 15.74208164], [80.33525085, 15.74208164], [80.33513641, 15.74208164], [80.33513641, 15.74194145], [80.33513641, 15.74180698], [80.33486176, 15.7418108], [80.3348465, 15.7415514], [80.3345871, 15.74153137], [80.3345871, 15.74125099], [80.33429718, 15.74125099], [80.33429718, 15.74096966], [80.33403015, 15.74097347], [80.33403015, 15.74069405], [80.33374786, 15.74069405], [80.33374786, 15.74041557], [80.33347321, 15.7404213], [80.33347321, 15.74014091], [80.33319092, 15.74014091], [80.33319092, 15.73985958], [80.33291626, 15.7398634], [80.33291626, 15.73958206], [80.3326416, 15.73958206], [80.3326416, 15.73930645], [80.33235931, 15.73931122], [80.33235931, 15.73903084], [80.33207703, 15.73903084], [80.33207703, 15.73875046], [80.33180237, 15.73875046], [80.33180237, 15.73847008], [80.33125305, 15.73847198], [80.33125305, 15.73819447], [80.33097076, 15.73819447], [80.33097076, 15.73791599], [80.33069611, 15.73792076], [80.33069611, 15.73764038], [80.32985687, 15.73764038], [80.32985687, 15.73736], [80.32958221, 15.73736], [80.32958221, 15.73707962], [80.32930756, 15.73708439], [80.32930756, 15.73680592], [80.3290329, 15.73681068], [80.3290329, 15.73651886], [80.32847595, 15.7365284], [80.32847595, 15.73624992], [80.32818604, 15.73624992], [80.32818604, 15.73596954], [80.32791901, 15.7359724], [80.32791901, 15.73569393], [80.32763672, 15.73569393], [80.32763672, 15.73541641], [80.32736206, 15.73542118], [80.32736206, 15.73513985], [80.32681274, 15.73513985], [80.32681274, 15.73486042], [80.32653046, 15.73486233], [80.32653046, 15.73458195], [80.32624817, 15.73458195], [80.32624817, 15.73402786], [80.32596588, 15.73403263], [80.32596588, 15.73375034], [80.32569122, 15.73375034], [80.32569122, 15.73346138], [80.32541656, 15.73347187], [80.32541656, 15.73319435], [80.32485962, 15.73319435], [80.32485962, 15.73291588], [80.32459259, 15.73291969], [80.32459259, 15.73264027], [80.32430267, 15.73264027], [80.32430267, 15.73236179], [80.32402802, 15.73236179], [80.32402802, 15.73207855], [80.32375336, 15.73208427], [80.32375336, 15.7318058], [80.32347107, 15.73180962], [80.32347107, 15.73124981], [80.32319641, 15.73124981], [80.32319641, 15.73096943], [80.32291412, 15.73097229], [80.32291412, 15.73069572], [80.32263947, 15.73069572], [80.32263947, 15.7304163], [80.32235718, 15.73042011], [80.32235718, 15.73013973], [80.32208252, 15.73013973], [80.32208252, 15.72985935], [80.32152557, 15.72986221], [80.32152557, 15.72958374], [80.32125092, 15.72958374], [80.32125092, 15.72930622], [80.32096863, 15.72931004], [80.32096863, 15.72902966], [80.32068634, 15.72902966], [80.32068634, 15.72875023], [80.32041931, 15.72875023], [80.32041931, 15.7284708], [80.32013702, 15.7284708], [80.32013702, 15.72819138], [80.31986237, 15.72819328], [80.31986237, 15.72791767], [80.31958008, 15.72791958], [80.31958008, 15.72764015], [80.31931305, 15.72764015], [80.31931305, 15.72736168], [80.31903076, 15.72736168], [80.31903076, 15.72708321], [80.31874847, 15.72708321], [80.31874847, 15.72680473], [80.31846619, 15.72681046], [80.31846619, 15.72653198], [80.31819153, 15.72653198], [80.31819153, 15.7262516], [80.31791687, 15.7262516], [80.31791687, 15.72597122], [80.31764221, 15.72597122], [80.31764221, 15.72569466], [80.31708527, 15.72569466], [80.31708527, 15.72541714], [80.31680298, 15.72542191], [80.31680298, 15.72514153], [80.31652832, 15.72514153], [80.31652832, 15.72486115], [80.31625366, 15.72486115], [80.31625366, 15.72458267], [80.31569672, 15.72458267], [80.31569672, 15.72430515], [80.3154068, 15.72430992], [80.3154068, 15.72402859], [80.31513977, 15.72402859], [80.31513977, 15.72347069], [80.31485748, 15.7234726], [80.31485748, 15.72319317], [80.31458282, 15.72319317], [80.31458282, 15.7229166], [80.31430817, 15.72291946], [80.31430817, 15.72264099], [80.31402588, 15.72264099], [80.31402588, 15.72236061], [80.31375122, 15.72236061], [80.31375122, 15.72208309], [80.31346893, 15.72208309], [80.31346893, 15.72180462], [80.31263733, 15.72181034], [80.31263733, 15.72152042], [80.31236267, 15.7215271], [80.31236267, 15.72124863], [80.31208038, 15.72125053], [80.31208038, 15.72097111], [80.31180573, 15.72097301], [80.31180573, 15.72041702], [80.31153107, 15.72042179], [80.31153107, 15.72014141], [80.31124878, 15.72014141], [80.31124878, 15.71986103], [80.31096649, 15.71986103], [80.31096649, 15.71958065], [80.31069183, 15.71958256], [80.31069183, 15.71930695], [80.31041718, 15.71931171], [80.31041718, 15.71903133], [80.31014252, 15.71903133], [80.31014252, 15.71875095], [80.3098526, 15.71875095], [80.3098526, 15.71848202], [80.3095932, 15.71848202], [80.3095932, 15.71792126], [80.30930328, 15.71792126], [80.30930328, 15.71736145], [80.30902863, 15.71736145], [80.30902863, 15.71708298], [80.30874634, 15.71708298], [80.30874634, 15.71652889], [80.30847168, 15.71652889], [80.30847168, 15.71625137], [80.30819702, 15.71625137], [80.30819702, 15.71597004], [80.30791473, 15.7159729], [80.30791473, 15.71569538], [80.30735779, 15.71569538], [80.30735779, 15.71541691], [80.30708313, 15.71542072], [80.30708313, 15.7151413], [80.30680847, 15.7151413], [80.30680847, 15.71457958], [80.30652618, 15.71458244], [80.30652618, 15.71430683], [80.30625153, 15.71431065], [80.30625153, 15.71403122], [80.30596924, 15.71403122], [80.30596924, 15.71347046], [80.30569458, 15.71347237], [80.30569458, 15.71319389], [80.30541992, 15.71319389], [80.30541992, 15.71291637], [80.30513763, 15.71292114], [80.30513763, 15.71264076], [80.30486298, 15.71264076], [80.30486298, 15.71235085], [80.30458069, 15.71236038], [80.30458069, 15.71208382], [80.30430603, 15.71208191], [80.30430603, 15.7118063], [80.304039, 15.71181107], [80.304039, 15.71153069], [80.30374908, 15.71153069], [80.30374908, 15.71125031], [80.3034668, 15.71125031], [80.3034668, 15.71096992], [80.30319214, 15.71097183], [80.30319214, 15.71069431], [80.30291748, 15.71069431], [80.30291748, 15.71041584], [80.30236053, 15.71042061], [80.30236053, 15.71014023], [80.30208588, 15.71014023], [80.30208588, 15.70985985], [80.30180359, 15.70985985], [80.30180359, 15.70958424], [80.30152893, 15.70958424], [80.30152893, 15.70902824], [80.30124664, 15.70903015], [80.30124664, 15.70875168], [80.30097198, 15.70875168], [80.30097198, 15.70847034], [80.30069733, 15.70847225], [80.30069733, 15.70819378], [80.30041504, 15.70819378], [80.30041504, 15.70763779], [80.30014038, 15.70763969], [80.30014038, 15.70736027], [80.29985809, 15.70736217], [80.29985809, 15.7070837], [80.29958344, 15.7070837], [80.29958344, 15.70652771], [80.29930878, 15.70654202], [80.29930878, 15.70625019], [80.29902649, 15.70625019], [80.29902649, 15.70597172], [80.29875183, 15.70597172], [80.29875183, 15.7056942], [80.29846954, 15.7056942], [80.29846954, 15.70541573], [80.29818726, 15.70541954], [80.29818726, 15.70514011], [80.2979126, 15.70514011], [80.2979126, 15.70485973], [80.29763794, 15.70485973], [80.29763794, 15.70431042], [80.29736328, 15.70431042], [80.29736328, 15.70403004], [80.29680634, 15.70403004], [80.29680634, 15.70374966], [80.29651642, 15.70374966], [80.29651642, 15.70348072], [80.29624939, 15.70348072], [80.29624939, 15.7031889], [80.29597473, 15.70319366], [80.29597473, 15.70263958], [80.29569244, 15.70263958], [80.29569244, 15.70208073], [80.29541779, 15.70208359], [80.29541779, 15.70180607], [80.29514313, 15.70181179], [80.29514313, 15.70125198], [80.29486847, 15.70125198], [80.29486847, 15.70097065], [80.29458618, 15.70097065], [80.29458618, 15.70069313], [80.29430389, 15.70069313], [80.29430389, 15.70041847], [80.29402924, 15.70041847], [80.29402924, 15.70014], [80.29374695, 15.70014191], [80.29374695, 15.69986057], [80.29347229, 15.69986057], [80.29347229, 15.69930458], [80.29319763, 15.6993103], [80.29319763, 15.6987524], [80.29292297, 15.6987524], [80.29292297, 15.69847107], [80.29264069, 15.69847107], [80.29264069, 15.69819546], [80.2923584, 15.69819546], [80.2923584, 15.69791698], [80.29207611, 15.69792175], [80.29207611, 15.69734955], [80.29180908, 15.69736099], [80.29180908, 15.69708347], [80.29152679, 15.69708347], [80.29152679, 15.69652653], [80.29125214, 15.69652939], [80.29123688, 15.6962719], [80.29096985, 15.69625092], [80.29096222, 15.69599247], [80.29070282, 15.69597054], [80.29069519, 15.69569492], [80.2904129, 15.69569111], [80.2904129, 15.6954174], [80.29013824, 15.69541931], [80.29013824, 15.69521046], [80.2895813, 15.69514084], [80.2895813, 15.69486141], [80.28930664, 15.69486141], [80.28930664, 15.69458294], [80.28902435, 15.69458294], [80.28902435, 15.69402695], [80.2889328, 15.69402695], [80.28874969, 15.69403076], [80.28874969, 15.69386959], [80.28874969, 15.69375134], [80.28864288, 15.69375134], [80.28847504, 15.69375134], [80.28847504, 15.69358921], [80.28847504, 15.69347095], [80.28835297, 15.69347095], [80.28819275, 15.69347095], [80.28819275, 15.69331074], [80.28819275, 15.69319534], [80.28807068, 15.69319534], [80.28791809, 15.69319534], [80.28791809, 15.69305134], [80.28791809, 15.69263935], [80.28762817, 15.69264126], [80.2876358, 15.69236088], [80.28746796, 15.69236088], [80.28736115, 15.69236088], [80.28736115, 15.69216919], [80.28736115, 15.69208336], [80.28708649, 15.69208336], [80.28708649, 15.69180489], [80.28679657, 15.69181156], [80.28679657, 15.69154263], [80.28652954, 15.69154263], [80.28652954, 15.6912508], [80.28624725, 15.6912508], [80.28624725, 15.69097137], [80.2859726, 15.69097328], [80.2859726, 15.69069481], [80.28569794, 15.69069481], [80.28569794, 15.69013882], [80.28542328, 15.69014072], [80.28542328, 15.68957996], [80.28514099, 15.68958473], [80.28514099, 15.68930531], [80.2848587, 15.68931103], [80.2848587, 15.68903065], [80.28457642, 15.68903065], [80.28457642, 15.68875122], [80.28430176, 15.68875122], [80.28430176, 15.68847275], [80.2840271, 15.68847275], [80.2840271, 15.68818092], [80.28375244, 15.68819523], [80.28375244, 15.68791676], [80.28347015, 15.68792057], [80.28347015, 15.68735981], [80.2831955, 15.68735981], [80.2831955, 15.68708229], [80.28291321, 15.68708229], [80.28291321, 15.68624973], [80.28263855, 15.68624973], [80.28263855, 15.68597031], [80.28236389, 15.68597221], [80.28236389, 15.68569374], [80.2820816, 15.68569374], [80.2820816, 15.68541622], [80.28180695, 15.68541622], [80.28180695, 15.68513775], [80.28151703, 15.68514061], [80.28151703, 15.68486023], [80.28125, 15.68486023], [80.28125, 15.68458366], [80.28097534, 15.68458366], [80.28097534, 15.68430424], [80.28069305, 15.68431091], [80.28069305, 15.68403053], [80.2804184, 15.68403053], [80.2804184, 15.68375015], [80.28013611, 15.68375015], [80.28013611, 15.68319035], [80.27986145, 15.68319416], [80.27986145, 15.68291569], [80.27958679, 15.68292141], [80.27958679, 15.68264008], [80.27929688, 15.68264008], [80.27929688, 15.68236923], [80.27902985, 15.68236923], [80.27902985, 15.68208027], [80.2784729, 15.68208408], [80.2784729, 15.68152809], [80.27819824, 15.68153], [80.27819061, 15.68097019], [80.27791595, 15.6809721], [80.27791595, 15.68069363], [80.2776413, 15.68069363], [80.2776413, 15.68041801], [80.27735901, 15.68041992], [80.27735901, 15.67986202], [80.27707672, 15.67986202], [80.27707672, 15.67958164], [80.27680206, 15.67958355], [80.27680206, 15.67930603], [80.2765274, 15.6793108], [80.27648926, 15.67880726], [80.27640533, 15.67875004], [80.27625275, 15.67875195], [80.27625275, 15.67863083], [80.27625275, 15.67847157], [80.27601624, 15.67847157], [80.27513885, 15.67847157], [80.27513885, 15.67819405], [80.2748642, 15.67819405], [80.2748642, 15.67763996], [80.27458191, 15.67763996], [80.27458191, 15.67745972], [80.27458191, 15.67708397], [80.27403259, 15.67708397], [80.27375031, 15.67708397], [80.27375031, 15.67688084], [80.27375031, 15.67652798], [80.27348328, 15.67653179], [80.27348328, 15.67541981], [80.27319336, 15.67541981], [80.27319336, 15.67486191], [80.27263641, 15.67486191], [80.27263641, 15.67458057], [80.2720871, 15.67458439], [80.2720871, 15.67430592], [80.27153015, 15.67430973], [80.27153015, 15.6740303], [80.27124786, 15.6740303], [80.27124786, 15.67375183], [80.27097321, 15.67375183], [80.27097321, 15.67347145], [80.27069092, 15.67347145], [80.27069092, 15.67319584], [80.27041626, 15.67319584], [80.27041626, 15.67263889], [80.2701416, 15.67264175], [80.2701416, 15.67208099], [80.26985931, 15.6720829], [80.26985931, 15.67124939], [80.26957703, 15.67124939], [80.26957703, 15.67043114], [80.26930237, 15.67043114], [80.26930237, 15.67013931], [80.26902771, 15.67013931], [80.26902771, 15.66986084], [80.26875305, 15.66986084], [80.26875305, 15.66930962], [80.26847076, 15.66930962], [80.26847076, 15.66819096], [80.26819611, 15.66819477], [80.26819611, 15.66763878], [80.26790619, 15.66764069], [80.26790619, 15.66737175], [80.26763916, 15.66737175], [80.26763916, 15.66708088], [80.2673645, 15.66708279], [80.2673645, 15.66680527], [80.26708221, 15.66681194], [80.26708221, 15.66653061], [80.26680756, 15.66653061], [80.26680756, 15.66542053], [80.2665329, 15.66542053], [80.2665329, 15.66458035], [80.26625061, 15.66458321], [80.26625061, 15.66430473], [80.26597595, 15.66430473], [80.26597595, 15.66347313], [80.26569366, 15.66347313], [80.26569366, 15.66208267], [80.26541901, 15.66208267], [80.26541901, 15.66152859], [80.26513672, 15.66153145], [80.26513672, 15.66124153], [80.26486206, 15.66125107], [80.26486206, 15.66069508], [80.26457977, 15.66069508], [80.26457977, 15.66041565], [80.26431274, 15.66042137], [80.26431274, 15.66014099], [80.26403046, 15.66014099], [80.26403046, 15.65931129], [80.26374817, 15.65931129], [80.26374817, 15.65903091], [80.26346588, 15.65903091], [80.26346588, 15.65820122], [80.26319122, 15.65820122], [80.26319122, 15.65792084], [80.26291656, 15.65792084], [80.26291656, 15.65596962], [80.26264191, 15.65597153], [80.26264191, 15.65347195], [80.26235962, 15.65347195], [80.26235962, 15.65291595], [80.26209259, 15.65292263], [80.26209259, 15.65236187], [80.26180267, 15.65236187], [80.26180267, 15.65180969], [80.26152802, 15.65180969], [80.26152802, 15.65125179], [80.26125336, 15.65125179], [80.26125336, 15.65069103], [80.26097107, 15.6506958], [80.26097107, 15.65041637], [80.26069641, 15.65042019], [80.26069641, 15.65013981], [80.26040649, 15.65013981], [80.26040649, 15.64958096], [80.26013947, 15.64958382], [80.26013947, 15.64902782], [80.25985718, 15.64902973], [80.25985718, 15.64847183], [80.25958252, 15.64847183], [80.25958252, 15.64791775], [80.25930786, 15.64791965], [80.25930786, 15.64680958], [80.2590332, 15.64680958], [80.2590332, 15.64626122], [80.25874329, 15.64626122], [80.25874329, 15.6459713], [80.25846863, 15.6459713], [80.25846863, 15.64569569], [80.25819397, 15.64569569], [80.25819397, 15.64541531], [80.25791931, 15.64542198], [80.25791931, 15.6451416], [80.25763702, 15.6451416], [80.25763702, 15.64458084], [80.25736237, 15.64458275], [80.25736237, 15.64374924], [80.25708008, 15.64374924], [80.25708008, 15.64319992], [80.25681305, 15.64319992], [80.25681305, 15.64264202], [80.25653076, 15.64264202], [80.25653076, 15.64208126], [80.25624847, 15.64208317], [80.25624847, 15.64152718], [80.25596619, 15.64153194], [80.25596619, 15.64125061], [80.25569916, 15.64125061], [80.25569916, 15.6406908], [80.25541687, 15.64069462], [80.25541687, 15.63986111], [80.25514221, 15.63986111], [80.25514221, 15.63958263], [80.25485992, 15.63958263], [80.25485992, 15.63875103], [80.2545929, 15.63875103], [80.2545929, 15.63847065], [80.25430298, 15.63847256], [80.25430298, 15.63819504], [80.25402832, 15.63819504], [80.25402832, 15.63736057], [80.25375366, 15.63736057], [80.25375366, 15.63680458], [80.25347137, 15.63680935], [80.25347137, 15.63653088], [80.25319672, 15.63653088], [80.25319672, 15.63625145], [80.2529068, 15.63625145], [80.2529068, 15.63597012], [80.25263977, 15.63597298], [80.25263977, 15.63569546], [80.25235748, 15.63569546], [80.25235748, 15.63513947], [80.25208282, 15.63514137], [80.25208282, 15.63457966], [80.25180817, 15.63458157], [80.25180817, 15.63430691], [80.25152588, 15.63432026], [80.25152588, 15.63375092], [80.25125122, 15.63375092], [80.25125122, 15.63320065], [80.25096893, 15.63319016], [80.25096893, 15.63263798], [80.25068665, 15.63264084], [80.25068665, 15.63208008], [80.25041962, 15.63208199], [80.25041962, 15.63125038], [80.25013733, 15.63126183], [80.25013733, 15.63068962], [80.24986267, 15.63069439], [80.24986267, 15.6301403], [80.24957275, 15.6301403], [80.24957275, 15.62957954], [80.24930573, 15.62958431], [80.24930573, 15.62874985], [80.24903107, 15.62874985], [80.24903107, 15.62820053], [80.24874878, 15.62820053], [80.24874878, 15.62764263], [80.24846649, 15.62764263], [80.24846649, 15.62736034], [80.24819183, 15.62736225], [80.24819183, 15.62680626], [80.24791718, 15.62681103], [80.24791718, 15.62652969], [80.24764252, 15.62652969], [80.24764252, 15.62597179], [80.24736023, 15.62597179], [80.24736023, 15.62513065], [80.24708557, 15.62514019], [80.24708557, 15.6245842], [80.24680328, 15.6245842], [80.24680328, 15.62374973], [80.24652863, 15.62374973], [80.24652863, 15.62292004], [80.24624634, 15.62292004], [80.24624634, 15.62263966], [80.24597168, 15.62263966], [80.24597168, 15.62207031], [80.24569702, 15.62208366], [80.24569702, 15.62152767], [80.2454071, 15.62152958], [80.2454071, 15.62042046], [80.24514008, 15.62042046], [80.24514008, 15.6198616], [80.24485779, 15.6198616], [80.24485779, 15.61932087], [80.24458313, 15.61932087], [80.24458313, 15.61875153], [80.24430847, 15.61875153], [80.24430847, 15.61819077], [80.24402618, 15.61819458], [80.24402618, 15.61763859], [80.24375916, 15.61763859], [80.24375916, 15.61681175], [80.24346924, 15.61681175], [80.24346924, 15.61626053], [80.24318695, 15.61626053], [80.24318695, 15.61542034], [80.24291992, 15.61542034], [80.24291992, 15.61458111], [80.24263763, 15.61458302], [80.24263763, 15.61402702], [80.24236298, 15.61403179], [80.24236298, 15.61347103], [80.24208069, 15.61347103], [80.24208069, 15.61263943], [80.24180603, 15.61264133], [80.24180603, 15.61181164], [80.24153137, 15.61181164], [80.24153137, 15.61125088], [80.24124908, 15.61125088], [80.24124908, 15.61042118], [80.2409668, 15.61042118], [80.2409668, 15.60958004], [80.24069214, 15.6095829], [80.24069214, 15.60902882], [80.24041748, 15.60903072], [80.24041748, 15.60818958], [80.24013519, 15.6081953], [80.24013519, 15.60763931], [80.23986053, 15.60764122], [80.23986053, 15.60681057], [80.23958588, 15.60681057], [80.23958588, 15.60569], [80.23930359, 15.60569382], [80.23930359, 15.60513783], [80.23902893, 15.60514069], [80.23902893, 15.60457993], [80.23874664, 15.60458374], [80.23874664, 15.60235977], [80.23847198, 15.60235977], [80.23847198, 15.60208035], [80.23819733, 15.60208416], [80.23819733, 15.60180569], [80.23792267, 15.60181141], [80.23792267, 15.60141182], [80.23791504, 15.60124969], [80.23763275, 15.60124969], [80.23763275, 15.60096073], [80.23735809, 15.60097218], [80.23735809, 15.59958363], [80.23708344, 15.59958363], [80.23708344, 15.59791565], [80.23680878, 15.59792042], [80.23680878, 15.59652996], [80.23652649, 15.59652996], [80.23652649, 15.59486198], [80.23625183, 15.59486198], [80.23625183, 15.59403038], [80.23596954, 15.59403038], [80.23596954, 15.5929203], [80.23568726, 15.5929203], [80.23568726, 15.59208965], [80.23542023, 15.59208965], [80.23542023, 15.59097099], [80.23513794, 15.59097099], [80.23513794, 15.59013939], [80.23486328, 15.59013939], [80.23486328, 15.58902264], [80.23458099, 15.5890274], [80.23458099, 15.58819485], [80.23430634, 15.58819485], [80.23430634, 15.58708286], [80.23402405, 15.58708286], [80.23402405, 15.58625126], [80.23374939, 15.58625126], [80.23374939, 15.58514118], [80.2334671, 15.58514118], [80.2334671, 15.58431244], [80.23319244, 15.58431244], [80.23319244, 15.58318996], [80.23291779, 15.58319473], [80.23291779, 15.58208275], [80.2326355, 15.58208275], [80.2326355, 15.58097267], [80.23236084, 15.58097267], [80.23236084, 15.58013821], [80.23208618, 15.58014965], [80.23208618, 15.57874966], [80.23179626, 15.57874966], [80.23179626, 15.57792091], [80.23152924, 15.57792091], [80.23152924, 15.57653141], [80.23124695, 15.57653141], [80.23124695, 15.57542133], [80.23097229, 15.57542133], [80.23097229, 15.57458019], [80.23069763, 15.5745821], [80.23069763, 15.57347202], [80.23041534, 15.57347202], [80.23041534, 15.57236195], [80.23014069, 15.57236195], [80.23014069, 15.57153034], [80.2298584, 15.57153034], [80.2298584, 15.57042027], [80.22957611, 15.57042027], [80.22957611, 15.56931019], [80.22930908, 15.56931019], [80.22930908, 15.56653023], [80.22902679, 15.56653023], [80.22902679, 15.56514168], [80.22875977, 15.56514168], [80.22875977, 15.56458092], [80.22846985, 15.56458282], [80.22846985, 15.56291676], [80.22820282, 15.56291962], [80.22820282, 15.56208134], [80.2279129, 15.56208324], [80.2279129, 15.56097317], [80.22763824, 15.56097317], [80.22763824, 15.56041718], [80.22735596, 15.56042194], [80.22735596, 15.56014061], [80.2270813, 15.56014061], [80.2270813, 15.55904102], [80.22680664, 15.55904102], [80.22680664, 15.55792141], [80.22651672, 15.55792141], [80.22651672, 15.55568981], [80.22624969, 15.55569458], [80.22624969, 15.55486107], [80.22597504, 15.55486107], [80.22597504, 15.553195], [80.22624969, 15.553195], [80.22624969, 15.55263805], [80.22651672, 15.55264091], [80.22651672, 15.55208015], [80.22680664, 15.55208206], [80.22680664, 15.5518074], [80.2270813, 15.55181122], [80.2270813, 15.55097008], [80.22736359, 15.55097198], [80.22736359, 15.55013847], [80.22763824, 15.55014133], [80.22763824, 15.54846954], [80.22736359, 15.5484724], [80.22736359, 15.54791641], [80.2270813, 15.54792118], [80.2270813, 15.54708195], [80.22736359, 15.54708195], [80.22736359, 15.54569435], [80.22763824, 15.54569435], [80.22763824, 15.54208374], [80.22736359, 15.54208374], [80.22736359, 15.54180622], [80.2270813, 15.54181004], [80.2270813, 15.54125023], [80.22680664, 15.54125023], [80.22680664, 15.54069138], [80.22652435, 15.54069328], [80.22652435, 15.54041767], [80.22624969, 15.54041958], [80.22624969, 15.5395813], [80.22597504, 15.53958416], [80.22597504, 15.53902721], [80.22569275, 15.53903198], [80.22569275, 15.53847122], [80.22541809, 15.53847122], [80.22541809, 15.53791714], [80.2251358, 15.53791714], [80.2251358, 15.53763866], [80.22486115, 15.53763866], [80.22486115, 15.53347111], [80.2251358, 15.53347301], [80.2251358, 15.53236103], [80.22486115, 15.53236103], [80.22486115, 15.53208065], [80.22458649, 15.53208256], [80.22458649, 15.53180504], [80.22429657, 15.53181171], [80.22429657, 15.53153133], [80.22402954, 15.53153133], [80.22402954, 15.53097057], [80.22374725, 15.53097343], [80.22374725, 15.53041744], [80.2234726, 15.53042126], [80.2234726, 15.53014088], [80.22319794, 15.53014088], [80.22319794, 15.52958012], [80.22291565, 15.52958298], [80.22291565, 15.52930546], [80.22263336, 15.52930927], [80.22263336, 15.52875137], [80.2223587, 15.52875137], [80.2223587, 15.52818966], [80.22208405, 15.52819538], [80.22208405, 15.52791691], [80.22180176, 15.52792072], [80.22180176, 15.52736092], [80.2215271, 15.52736092], [80.2215271, 15.52681065], [80.22125244, 15.52681065], [80.22125244, 15.52597046], [80.22097015, 15.52597332], [80.22097015, 15.52569389], [80.2206955, 15.52569389], [80.2206955, 15.52486038], [80.22041321, 15.52486038], [80.22041321, 15.52402782], [80.22013855, 15.52403069], [80.22013855, 15.52318954], [80.21986389, 15.52319431], [80.21986389, 15.52291584], [80.21958923, 15.52293015], [80.21958923, 15.52264023], [80.21930695, 15.52264023], [80.21930695, 15.52208042], [80.21902466, 15.52208424], [80.21902466, 15.52124977], [80.21875, 15.52124977], [80.21875, 15.52097034], [80.21847534, 15.52097225], [80.21847534, 15.52069378], [80.21819305, 15.52069378], [80.21819305, 15.52041626], [80.2179184, 15.52042103], [80.2179184, 15.51987076], [80.21763611, 15.51987076], [80.21763611, 15.51902962], [80.21736145, 15.51902962], [80.21736145, 15.51846981], [80.21708679, 15.51847172], [80.21708679, 15.51791573], [80.21679688, 15.51791954], [80.21679688, 15.51764011], [80.21652985, 15.51764011], [80.21652985, 15.51707935], [80.21624756, 15.51708412], [80.21624756, 15.51680565], [80.2159729, 15.51681042], [80.2159729, 15.51653004], [80.21569824, 15.51653004], [80.21569061, 15.51596928], [80.21541595, 15.51597214], [80.21541595, 15.51541805], [80.21569061, 15.51541996], [80.21569061, 15.51373959], [80.21541595, 15.51375008], [80.21541595, 15.51347065], [80.2151413, 15.51347065], [80.2151413, 15.51319313], [80.21485901, 15.51319313], [80.21485901, 15.51291847], [80.21457672, 15.51292038], [80.21457672, 15.51264191], [80.21430206, 15.51264191], [80.21430206, 15.51236153], [80.2140274, 15.51236153], [80.2140274, 15.51208305], [80.21375275, 15.51208305], [80.21375275, 15.51180458], [80.21346283, 15.5118103], [80.21346283, 15.51153183], [80.2131958, 15.51153183], [80.2131958, 15.51097107], [80.21291351, 15.51097107], [80.21291351, 15.50986099], [80.2131958, 15.50986099], [80.2131958, 15.50930977], [80.2140274, 15.509305], [80.2140274, 15.50958347], [80.21485901, 15.50958347], [80.21485901, 15.5084734], [80.21458435, 15.5084734], [80.21458435, 15.5079174], [80.21430206, 15.50793076], [80.21430206, 15.50681019], [80.2140274, 15.50681019], [80.2140274, 15.50569057], [80.21375275, 15.50569534], [80.21375275, 15.50513935], [80.21346283, 15.50514126], [80.21346283, 15.50458145], [80.2131958, 15.50458336], [80.2131958, 15.5037508], [80.21290588, 15.5037508], [80.21290588, 15.50264072], [80.21263885, 15.50264072], [80.21263885, 15.5023613], [80.21208191, 15.5023613], [80.21208191, 15.50264072], [80.21125031, 15.50264072], [80.21125031, 15.5029192], [80.21097565, 15.50291729], [80.21097565, 15.50319481], [80.21069336, 15.50319481], [80.21069336, 15.50347328], [80.2104187, 15.50347137], [80.2104187, 15.5037508], [80.21013641, 15.5037508], [80.21013641, 15.50431156], [80.2104187, 15.50430489], [80.2104187, 15.50458336], [80.21069336, 15.50458145], [80.21069336, 15.50487041], [80.2104187, 15.50487041], [80.2104187, 15.50514126], [80.20986176, 15.50514126], [80.20986176, 15.50542164], [80.20903015, 15.50542164], [80.20903015, 15.50514126], [80.20874786, 15.50514126], [80.20874786, 15.50487041], [80.20847321, 15.50487041], [80.20847321, 15.50458145], [80.20819092, 15.50458336], [80.20819092, 15.50430489], [80.20791626, 15.50431156], [80.20791626, 15.5037508], [80.2076416, 15.5037508], [80.2076416, 15.50347328], [80.20735931, 15.50347328], [80.20735931, 15.50319481], [80.20708466, 15.50319481], [80.20708466, 15.50291729], [80.20680237, 15.5029192], [80.20680237, 15.5023613], [80.20652771, 15.5023613], [80.20652771, 15.50180531], [80.20625305, 15.50180531], [80.20625305, 15.50097275], [80.20597076, 15.50097275], [80.20597076, 15.50042057], [80.20513916, 15.50042057], [80.20513916, 15.50014114], [80.20430756, 15.50014114], [80.20430756, 15.49985981], [80.20347595, 15.49985981], [80.20347595, 15.49931145], [80.2040329, 15.49931145], [80.2040329, 15.49903107], [80.20430756, 15.49903107], [80.20430756, 15.49847031], [80.20402527, 15.49847221], [80.20402527, 15.49819374], [80.20347595, 15.49819374], [80.20347595, 15.49791622], [80.20291901, 15.49791622], [80.20291901, 15.49819374], [80.20263672, 15.49819374], [80.20263672, 15.49847221], [80.20236206, 15.49847221], [80.20236206, 15.49875069], [80.20124817, 15.49875069], [80.20124817, 15.49847221], [80.20097351, 15.49847221], [80.20097351, 15.49819374], [80.20041656, 15.49819374], [80.20041656, 15.49736023], [80.20069122, 15.49736023], [80.20069122, 15.49708462], [80.20097351, 15.49708462], [80.20097351, 15.49625015], [80.20069122, 15.49625015], [80.20069122, 15.49570084], [80.20041656, 15.49570084], [80.20041656, 15.49542141], [80.20014191, 15.49542141], [80.20014191, 15.49514008], [80.20041656, 15.49514008], [80.20041656, 15.4948597], [80.20124817, 15.4948597], [80.20124817, 15.49514008], [80.20181274, 15.49514008], [80.20181274, 15.49542141], [80.20847321, 15.49542141], [80.20847321, 15.49514008], [80.2104187, 15.49514008], [80.2104187, 15.49542141], [80.21098328, 15.49542141], [80.21098328, 15.49570084], [80.21125031, 15.49569416], [80.21125031, 15.49597168], [80.21152496, 15.49597168], [80.21152496, 15.49569416], [80.21180725, 15.49570084], [80.21180725, 15.49514008], [80.21153259, 15.49514008], [80.21153259, 15.49431133], [80.21125031, 15.49431133], [80.21125031, 15.49403], [80.21098328, 15.49403], [80.21098328, 15.49236202], [80.21069336, 15.49236202], [80.21069336, 15.49208164], [80.2104187, 15.49208355], [80.2104187, 15.49069405], [80.21013641, 15.49069405], [80.21013641, 15.48958397], [80.20986176, 15.48958397], [80.20986176, 15.48902798], [80.2095871, 15.48903179], [80.2095871, 15.48764038], [80.20929718, 15.48764038], [80.20929718, 15.48736191], [80.20903015, 15.48736191], [80.20903015, 15.48514175], [80.20874786, 15.48514175], [80.20874786, 15.48458099], [80.20847321, 15.4845829], [80.20847321, 15.48374939], [80.20819092, 15.48376083], [80.20819092, 15.48208141], [80.20791626, 15.48208332], [80.20791626, 15.48069477], [80.20764923, 15.48069954], [80.20764923, 15.47958088], [80.20735931, 15.47958279], [80.20735931, 15.47902679], [80.20707703, 15.47903061], [80.20707703, 15.4784708], [80.20680237, 15.4784708], [80.20680237, 15.47819519], [80.20652771, 15.47819519], [80.20652771, 15.47736073], [80.20625305, 15.47736073], [80.20625305, 15.47681236], [80.20597076, 15.47681236], [80.20597076, 15.47625065], [80.20569611, 15.47625065], [80.20569611, 15.47486115], [80.20541382, 15.47486115], [80.20541382, 15.47458267], [80.20513916, 15.47458267], [80.20513916, 15.47430515], [80.20485687, 15.47431087], [80.20485687, 15.47403145], [80.20458984, 15.47403145], [80.20458984, 15.47346973], [80.20430756, 15.4734726], [80.20430756, 15.47235966], [80.20402527, 15.47235966], [80.20402527, 15.47180653], [80.20375061, 15.47182274], [80.20375061, 15.47153091], [80.20347595, 15.47153091], [80.20347595, 15.47125053], [80.20318604, 15.47125053], [80.20318604, 15.47068977], [80.20291901, 15.47069359], [80.20291901, 15.47041607], [80.20263672, 15.47042084], [80.20263672, 15.4695797], [80.20236206, 15.46958447], [80.20236206, 15.46930599], [80.20207977, 15.46931076], [80.20207977, 15.46875858], [80.20181274, 15.46875858], [80.20181274, 15.46819019], [80.20153046, 15.46819401], [80.20153046, 15.46791553], [80.20124817, 15.46792126], [80.20124817, 15.46652985], [80.20096588, 15.46652985], [80.20096588, 15.46597195], [80.20069122, 15.46597195], [80.20069122, 15.46541595], [80.20041656, 15.46542263], [80.20041656, 15.46514034], [80.20014191, 15.46514034], [80.20014191, 15.46485996], [80.19985962, 15.46485996], [80.19985962, 15.46457863], [80.19958496, 15.46458435], [80.19958496, 15.46402836], [80.19930267, 15.46403027], [80.19930267, 15.46375179], [80.19902802, 15.46375179], [80.19902802, 15.46319103], [80.19875336, 15.46319389], [80.19875336, 15.46291637], [80.19845581, 15.46292019], [80.19845581, 15.46263123], [80.19819641, 15.46263981], [80.19819641, 15.46236229], [80.19791412, 15.46236229], [80.19791412, 15.4618063], [80.19763947, 15.46181011], [80.19763947, 15.46152973], [80.19735718, 15.46152973], [80.19735718, 15.46097183], [80.19708252, 15.46097183], [80.19708252, 15.46069431], [80.19680786, 15.46069431], [80.19680786, 15.46014023], [80.1965332, 15.46014023], [80.1965332, 15.45986176], [80.19625092, 15.45986176], [80.19625092, 15.45930958], [80.19596863, 15.45930958], [80.19596863, 15.45903015], [80.19568634, 15.45903015], [80.19568634, 15.45875168], [80.19541931, 15.45875168], [80.19541931, 15.4584713], [80.19513702, 15.4584713], [80.19513702, 15.45763969], [80.19486237, 15.4576416], [80.19486237, 15.45735931], [80.19458008, 15.45736122], [80.19458008, 15.45680523], [80.19431305, 15.45682144], [80.19431305, 15.45652962], [80.19403076, 15.45652962], [80.19403076, 15.45624924], [80.19374847, 15.45624924], [80.19374847, 15.45597076], [80.19347382, 15.45597267], [80.19347382, 15.45541668], [80.19319153, 15.45541954], [80.19319153, 15.45514202], [80.19291687, 15.45514202], [80.19291687, 15.45458126], [80.19264221, 15.45458317], [80.19264221, 15.4543047], [80.19235992, 15.45431042], [80.19235992, 15.45403194], [80.1920929, 15.45403194], [80.1920929, 15.45375061], [80.19180298, 15.45375061], [80.19180298, 15.45347118], [80.19152832, 15.45347309], [80.19152832, 15.4529171], [80.19124603, 15.45292187], [80.19124603, 15.45264053], [80.19097137, 15.45264053], [80.19097137, 15.45236111], [80.19069672, 15.45236111], [80.19069672, 15.45208263], [80.19041443, 15.45208263], [80.19041443, 15.45180511], [80.19013977, 15.45181179], [80.19013977, 15.45097065], [80.18985748, 15.45097256], [80.18985748, 15.45069504], [80.18930817, 15.45069504], [80.18930817, 15.45041656], [80.18875122, 15.45042133], [80.18875122, 15.45014095], [80.18846893, 15.45014095], [80.18846893, 15.44986057], [80.18819427, 15.44986057], [80.18819427, 15.44930458], [80.18791962, 15.44930935], [80.18791962, 15.44903088], [80.18763733, 15.44903088], [80.18763733, 15.44818974], [80.18736267, 15.44819546], [80.18736267, 15.44791698], [80.18708038, 15.4479208], [80.18708038, 15.44736099], [80.18651581, 15.44736099], [80.18651581, 15.44707966], [80.18624878, 15.44708347], [80.18624878, 15.44680691], [80.18596649, 15.44681072], [80.18596649, 15.4465313], [80.18569183, 15.4465313], [80.18569183, 15.44625092], [80.18541718, 15.44625092], [80.18541718, 15.44596958], [80.18514252, 15.4459734], [80.18514252, 15.44541645], [80.18486023, 15.44542122], [80.18486023, 15.44514084], [80.1845932, 15.44514084], [80.1845932, 15.44459057], [80.18430328, 15.44459057], [80.18430328, 15.44431114], [80.18402863, 15.44431114], [80.18402863, 15.44403076], [80.18374634, 15.44403076], [80.18374634, 15.44347], [80.18347168, 15.44347191], [80.18347168, 15.44319439], [80.18319702, 15.44319439], [80.18319702, 15.44291592], [80.1829071, 15.44292068], [80.1829071, 15.44235992], [80.18264008, 15.44235992], [80.18264008, 15.44207954], [80.18235779, 15.44208431], [80.18235779, 15.44180584], [80.18208313, 15.44181061], [80.18208313, 15.44152069], [80.18180847, 15.44152832], [80.18180847, 15.44124985], [80.18152618, 15.44125271], [80.18152618, 15.44069195], [80.18125153, 15.44069386], [80.18125153, 15.44041634], [80.18096924, 15.4404211], [80.18096924, 15.44013977], [80.18068695, 15.44013977], [80.18068695, 15.43986034], [80.18041992, 15.43986225], [80.18041992, 15.43958378], [80.18013763, 15.43958378], [80.18013763, 15.43930626], [80.17986298, 15.43931103], [80.17986298, 15.43875027], [80.17958069, 15.43875027], [80.17958069, 15.4384613], [80.17930603, 15.43847179], [80.17930603, 15.43819427], [80.17903137, 15.43819427], [80.17903137, 15.4379158], [80.17874908, 15.43791962], [80.17874908, 15.43764019], [80.1784668, 15.43764019], [80.1784668, 15.43707943], [80.17819214, 15.4370842], [80.17819214, 15.43680573], [80.17791748, 15.43680954], [80.17791748, 15.43653011], [80.17764282, 15.43653011], [80.17764282, 15.43624973], [80.17736053, 15.43624973], [80.17736053, 15.43596935], [80.17708588, 15.43597221], [80.17708588, 15.43569374], [80.17680359, 15.43569374], [80.17680359, 15.43513775], [80.17652893, 15.43513966], [80.17652893, 15.43486023], [80.17624664, 15.43486214], [80.17624664, 15.43458366], [80.17597198, 15.43458366], [80.17597198, 15.43430614], [80.17569733, 15.43430996], [80.17569733, 15.43402958], [80.17542267, 15.43402958], [80.17542267, 15.43375015], [80.17514038, 15.43375015], [80.17514038, 15.43347168], [80.17485809, 15.43347168], [80.17485809, 15.43291759], [80.17457581, 15.43292046], [80.17457581, 15.43265057], [80.17430878, 15.43265057], [80.17430878, 15.4323616], [80.17402649, 15.4323616], [80.17402649, 15.43208122], [80.17319489, 15.43208408], [80.17319489, 15.43180561], [80.17292023, 15.43181038], [80.17292023, 15.43125153], [80.17263794, 15.43125153], [80.17263794, 15.43069077], [80.17208099, 15.43069553], [80.17208099, 15.43041801], [80.17180634, 15.43041992], [80.17180634, 15.43013859], [80.17151642, 15.43013859], [80.17151642, 15.42958069], [80.17097473, 15.4295826], [80.17097473, 15.42930508], [80.17069244, 15.42931175], [80.17069244, 15.42903042], [80.17041779, 15.42903042], [80.17041779, 15.42875099], [80.17014313, 15.42875099], [80.17014313, 15.42819118], [80.16958618, 15.42819309], [80.16958618, 15.42763901], [80.16929626, 15.42764187], [80.16929626, 15.42736053], [80.16902924, 15.42736053], [80.16902924, 15.42708302], [80.16874695, 15.42708302], [80.16874695, 15.42652702], [80.16847229, 15.42652702], [80.16847229, 15.42625141], [80.16819763, 15.42625141], [80.16819763, 15.42597103], [80.16791534, 15.42597103], [80.16791534, 15.42569542], [80.1673584, 15.42569542], [80.1673584, 15.42541695], [80.16707611, 15.42542171], [80.16707611, 15.42514133], [80.16652679, 15.42514133], [80.16652679, 15.42458057], [80.16625214, 15.42458344], [80.16625214, 15.42430496], [80.16596985, 15.42431164], [80.16596985, 15.42375088], [80.16570282, 15.42375088], [80.16570282, 15.42319012], [80.1654129, 15.42319489], [80.1654129, 15.42291737], [80.16513824, 15.42291927], [80.16513824, 15.42236137], [80.16486359, 15.42236137], [80.16486359, 15.4220829], [80.1645813, 15.4220829], [80.1645813, 15.42180538], [80.16430664, 15.4218092], [80.16430664, 15.4212513], [80.16374969, 15.4212513], [80.16374969, 15.42096996], [80.16319275, 15.42097282], [80.16319275, 15.42041683], [80.16291809, 15.42042065], [80.16291809, 15.42014122], [80.1626358, 15.42014122], [80.1626358, 15.41986275], [80.16234589, 15.41986275], [80.16234589, 15.41958046], [80.16208649, 15.41958237], [80.16208649, 15.41930676], [80.16179657, 15.41931057], [80.16179657, 15.41903114], [80.16124725, 15.41903114], [80.16124725, 15.41875076], [80.1609726, 15.41875076], [80.1609726, 15.41819], [80.16069794, 15.41819477], [80.16069794, 15.4179163], [80.16042328, 15.41792107], [80.16042328, 15.41764069], [80.16014099, 15.41764069], [80.16014099, 15.41736031], [80.1598587, 15.41736031], [80.1598587, 15.41708469], [80.15958405, 15.41708469], [80.15958405, 15.41680431], [80.1592865, 15.41681099], [80.15930176, 15.4164896], [80.15930176, 15.41625023], [80.15909576, 15.41625023], [80.15875244, 15.41625023], [80.15875244, 15.41596985], [80.15847015, 15.41597176], [80.15847015, 15.41557121], [80.15847015, 15.41541576], [80.15831757, 15.41541862], [80.15820313, 15.41542053], [80.1581955, 15.41529083], [80.1581955, 15.41513824], [80.15805817, 15.41513824], [80.15791321, 15.41514015], [80.15791321, 15.41499043], [80.15791321, 15.41458225], [80.15763855, 15.41458225], [80.15763855, 15.41430569], [80.15735626, 15.41431141], [80.15735626, 15.41374969], [80.1570816, 15.41374969], [80.1570816, 15.41347027], [80.15680695, 15.41347218], [80.15680695, 15.4131937], [80.15652466, 15.4131937], [80.15652466, 15.41291618], [80.15625, 15.41292095], [80.15625, 15.41263962], [80.15598297, 15.41263962], [80.15598297, 15.41208172], [80.15569305, 15.41208363], [80.15569305, 15.41180611], [80.1554184, 15.41181087], [80.1554184, 15.41152096], [80.15513611, 15.41152763], [80.15513611, 15.41125011], [80.15486145, 15.41125011], [80.15486145, 15.41096973], [80.15458679, 15.41097164], [80.15458679, 15.41041565], [80.15402985, 15.41042042], [80.15402985, 15.40985966], [80.15374756, 15.40986156], [80.15374756, 15.40958405], [80.1534729, 15.40958405], [80.1534729, 15.40930557], [80.15319824, 15.40931034], [80.15319061, 15.40902996], [80.15291595, 15.40902996], [80.15291595, 15.40848064], [80.1526413, 15.40848064], [80.1526413, 15.40819073], [80.15235901, 15.40819359], [80.15235901, 15.40791798], [80.15207672, 15.40792179], [80.15207672, 15.40764046], [80.15180206, 15.40764046], [80.15180206, 15.40736198], [80.1515274, 15.40736198], [80.1515274, 15.40708065], [80.15125275, 15.40708447], [80.15125275, 15.40688992], [80.15125275, 15.40652847], [80.15106964, 15.40653038], [80.15097046, 15.40652847], [80.15092468, 15.40630436], [80.15085602, 15.40625], [80.1506958, 15.40625191], [80.1506958, 15.40609169], [80.1506958, 15.40597057], [80.1505661, 15.40597057], [80.15041351, 15.40597057], [80.15041351, 15.40583038], [80.15041351, 15.40569305], [80.15026093, 15.40569305], [80.15013885, 15.40569305], [80.15013885, 15.40557861], [80.15013885, 15.40541458], [80.14996338, 15.4054184], [80.14985657, 15.4054203], [80.14985657, 15.40514183], [80.14965057, 15.40514183], [80.14958191, 15.40458107], [80.14930725, 15.40458393], [80.14930725, 15.40430546], [80.14903259, 15.40431023], [80.14903259, 15.40403175], [80.14875031, 15.40403175], [80.14875031, 15.40374947], [80.14847565, 15.40374947], [80.14847565, 15.40347099], [80.14819336, 15.40347099], [80.14819336, 15.40319633], [80.1479187, 15.40319633], [80.1479187, 15.40263939], [80.14763641, 15.40263939], [80.14763641, 15.40235043], [80.14736176, 15.40236092], [80.14736176, 15.4020834], [80.1470871, 15.4020834], [80.1470871, 15.40180492], [80.14679718, 15.40180969], [80.14679718, 15.40125084], [80.14653015, 15.40125084], [80.14653015, 15.40097141], [80.14624786, 15.40097332], [80.14624786, 15.40069485], [80.14597321, 15.40069485], [80.14597321, 15.40013885], [80.14569092, 15.40014076], [80.14569092, 15.39986134], [80.14541626, 15.39986134], [80.14541626, 15.39958286], [80.1451416, 15.39958286], [80.1451416, 15.39902687], [80.14485931, 15.39903164], [80.14485931, 15.39875126], [80.14457703, 15.39875126], [80.14457703, 15.39847088], [80.14430237, 15.39847088], [80.14430237, 15.39791679], [80.14402771, 15.39792156], [80.14402771, 15.39764118], [80.14375305, 15.39764118], [80.14375305, 15.3973608], [80.14347076, 15.3973608], [80.14347076, 15.39708328], [80.14291382, 15.39708328], [80.14291382, 15.3965292], [80.14263916, 15.39653969], [80.14263916, 15.3959713], [80.1423645, 15.39597321], [80.1423645, 15.39541721], [80.14208221, 15.39542103], [80.14208221, 15.39514065], [80.14180756, 15.39514065], [80.14180756, 15.39486122], [80.14152527, 15.39486122], [80.14152527, 15.39430523], [80.14125061, 15.39431095], [80.14125061, 15.39403057], [80.14097595, 15.39403057], [80.14093781, 15.39349079], [80.14068604, 15.3934803], [80.14065552, 15.39325237], [80.14057159, 15.39319515], [80.14041901, 15.39319515], [80.14041901, 15.39291668], [80.14013672, 15.39292145], [80.14013672, 15.39247036], [80.14013672, 15.39236069], [80.13957977, 15.39236069], [80.13957977, 15.39208031], [80.13930511, 15.39208221], [80.13930511, 15.39152908], [80.13903046, 15.39153099], [80.13903046, 15.39125061], [80.13874817, 15.39125061], [80.13874817, 15.39068985], [80.13847351, 15.39069366], [80.13847351, 15.39041615], [80.13819122, 15.39041615], [80.13819122, 15.39013767], [80.13791656, 15.39014053], [80.13791656, 15.38986015], [80.13764191, 15.38986015], [80.13764191, 15.38930416], [80.13735962, 15.38931084], [80.13735962, 15.38903141], [80.13709259, 15.38903141], [80.13708496, 15.38884163], [80.13708496, 15.38875008], [80.1368866, 15.38875008], [80.13680267, 15.38875008], [80.13680267, 15.38847923], [80.13652802, 15.3884697], [80.13652802, 15.38819408], [80.13625336, 15.38819408], [80.13625336, 15.38763809], [80.13597107, 15.38764], [80.13597107, 15.38735104], [80.13569641, 15.38736153], [80.13569641, 15.3870821], [80.13541412, 15.3870821], [80.13541412, 15.38652802], [80.13513947, 15.38652992], [80.13513947, 15.38624954], [80.13485718, 15.38624954], [80.13485718, 15.38597202], [80.13458252, 15.38597202], [80.13458252, 15.38541603], [80.13430786, 15.3854208], [80.13430786, 15.38514042], [80.1340332, 15.38514042], [80.1340332, 15.38486004], [80.13375092, 15.38486004], [80.13375092, 15.38431072], [80.13346863, 15.38431072], [80.13346863, 15.38403034], [80.13318634, 15.38403034], [80.13318634, 15.38374996], [80.13291931, 15.38374996], [80.13291931, 15.38320065], [80.13263702, 15.3831892], [80.13263702, 15.38291645], [80.13237, 15.38292027], [80.13237, 15.38264179], [80.13208008, 15.38264179], [80.13208008, 15.3821907], [80.13208008, 15.38208389], [80.13197327, 15.38208389], [80.13180542, 15.38208389], [80.13180542, 15.3819313], [80.13180542, 15.38180637], [80.13166809, 15.38180637], [80.13153076, 15.38181019], [80.13153076, 15.38169193], [80.13153076, 15.38125038], [80.13124847, 15.38125038], [80.13124847, 15.38097191], [80.13097382, 15.38097191], [80.13097382, 15.38069439], [80.13069153, 15.38069439], [80.13069153, 15.3801403], [80.13041687, 15.3801403], [80.13041687, 15.37986183], [80.13014221, 15.37986183], [80.13014221, 15.37958145], [80.12985992, 15.37958431], [80.12985992, 15.37902832], [80.12960052, 15.37903023], [80.12960052, 15.37875175], [80.12931061, 15.37875175], [80.12931061, 15.37847137], [80.12902832, 15.37847137], [80.12902832, 15.37791538], [80.12874603, 15.37792015], [80.12874603, 15.37764168], [80.12847137, 15.37764168], [80.12847137, 15.37735939], [80.12819672, 15.37736225], [80.12819672, 15.37680531], [80.1279068, 15.37681007], [80.1279068, 15.37652969], [80.12763977, 15.37652969], [80.12763977, 15.37597084], [80.12735748, 15.37597084], [80.12735748, 15.37569141], [80.12708282, 15.37569332], [80.12708282, 15.37513924], [80.12680817, 15.37513924], [80.12680817, 15.37458134], [80.12652588, 15.37458324], [80.12652588, 15.37430477], [80.12623596, 15.37430954], [80.12623596, 15.37375069], [80.12596893, 15.37375069], [80.12596893, 15.37347126], [80.12569427, 15.37347317], [80.12569427, 15.37291718], [80.12541962, 15.37292194], [80.12541962, 15.37264061], [80.12513733, 15.37264061], [80.12513733, 15.3720808], [80.12486267, 15.37208271], [80.12486267, 15.37152672], [80.12458038, 15.37153053], [80.12458038, 15.37125111], [80.12430573, 15.37125111], [80.12430573, 15.37097263], [80.12403107, 15.37097263], [80.12403107, 15.37013912], [80.12374878, 15.37014103], [80.12374878, 15.36986065], [80.12347412, 15.36986065], [80.12346649, 15.36958122], [80.12319183, 15.36958313], [80.12319183, 15.36902905], [80.12291718, 15.36903095], [80.12291718, 15.36875057], [80.12264252, 15.36875057], [80.12264252, 15.36847115], [80.12236023, 15.36847305], [80.12236023, 15.36791706], [80.1220932, 15.36792088], [80.1220932, 15.36764145], [80.12180328, 15.36764145], [80.12180328, 15.36707973], [80.12152863, 15.3670826], [80.12152863, 15.36652565], [80.12124634, 15.36653137], [80.12124634, 15.36624241], [80.12097168, 15.36625099], [80.12097168, 15.365695], [80.12041473, 15.365695], [80.12041473, 15.36458206], [80.12014008, 15.36458206], [80.12014008, 15.3643074], [80.11985779, 15.36431122], [80.11985779, 15.36375141], [80.11958313, 15.36375141], [80.11958313, 15.36318111], [80.11930847, 15.36319447], [80.11930847, 15.36291599], [80.11902618, 15.36292076], [80.11902618, 15.36236], [80.11875153, 15.36236], [80.11875153, 15.36181068], [80.11846924, 15.36181068], [80.11846924, 15.36153126], [80.11818695, 15.36153126], [80.11818695, 15.36096954], [80.11791992, 15.3609724], [80.11791992, 15.36069393], [80.11763763, 15.36069393], [80.11763763, 15.36013794], [80.11737061, 15.36014271], [80.11737061, 15.35958195], [80.11708069, 15.35958195], [80.11708069, 15.35930634], [80.11680603, 15.3593111], [80.11680603, 15.35875034], [80.11653137, 15.35875034], [80.11653137, 15.35818863], [80.11624908, 15.35819435], [80.11624908, 15.35764027], [80.1159668, 15.35764027], [80.1159668, 15.35707855], [80.11569214, 15.35708427], [80.11569214, 15.35652828], [80.11541748, 15.35653019], [80.11541748, 15.35597038], [80.11513519, 15.35597229], [80.11513519, 15.3554163], [80.11486053, 15.35542011], [80.11486053, 15.35486031], [80.11458588, 15.35486221], [80.11458588, 15.35430622], [80.11430359, 15.35430622], [80.11430359, 15.35375023], [80.11402893, 15.35375023], [80.11402893, 15.35319138], [80.11374664, 15.35319424], [80.11374664, 15.35291767], [80.11347198, 15.35291958], [80.11347198, 15.35236168], [80.11319733, 15.35236168], [80.11319733, 15.35181046], [80.11292267, 15.35181046], [80.11292267, 15.35124016], [80.11264038, 15.35124874], [80.11264038, 15.35069561], [80.11235809, 15.35069561], [80.11235809, 15.35013962], [80.11207581, 15.35013962], [80.11207581, 15.34958076], [80.11180878, 15.34958267], [80.11180878, 15.34902668], [80.11152649, 15.34902954], [80.11152649, 15.34875202], [80.11123657, 15.34875202], [80.11123657, 15.34792042], [80.11096954, 15.34792042], [80.11096954, 15.34736061], [80.11069489, 15.34736061], [80.11069489, 15.34680462], [80.11042023, 15.34681034], [80.11042023, 15.34625053], [80.11013794, 15.34625053], [80.11013794, 15.34543133], [80.10986328, 15.34543133], [80.10986328, 15.34486103], [80.10958099, 15.34486103], [80.10958099, 15.34403133], [80.10930634, 15.34403133], [80.10930634, 15.34347057], [80.10902405, 15.34347343], [80.10902405, 15.34263897], [80.10874939, 15.34264088], [80.10874939, 15.34208012], [80.10847473, 15.34208298], [80.10847473, 15.34125137], [80.10819244, 15.34125137], [80.10819244, 15.34069538], [80.10791779, 15.34069538], [80.10791779, 15.33986092], [80.1076355, 15.33986092], [80.1076355, 15.33930683], [80.10736084, 15.33930683], [80.10736084, 15.33847332], [80.10708618, 15.33847332], [80.10708618, 15.33736038], [80.10680389, 15.33736038], [80.10680389, 15.33652878], [80.10652924, 15.33653069], [80.10652924, 15.33568954], [80.10624695, 15.33569431], [80.10624695, 15.33458424], [80.10597229, 15.33458424], [80.10597229, 15.33374977], [80.10569763, 15.33374977], [80.10569763, 15.33347034], [80.10541534, 15.33347225], [80.10541534, 15.33180618], [80.10514069, 15.33181095], [80.10514069, 15.32931042], [80.1054306, 15.32931042], [80.1054306, 15.32791996], [80.10514069, 15.32791996], [80.10514069, 15.32736015], [80.1048584, 15.32736206], [80.1048584, 15.32708359], [80.10458374, 15.32708359], [80.10458374, 15.32680607], [80.10430908, 15.32681274], [80.10430908, 15.32653046], [80.10402679, 15.32653046], [80.10402679, 15.32625198], [80.10375214, 15.32625198], [80.10375214, 15.3259716], [80.10346985, 15.3259716], [80.10346985, 15.32569408], [80.10319519, 15.32569408], [80.10319519, 15.32541466], [80.10263824, 15.32542038], [80.10263824, 15.32486153], [80.10236359, 15.32486153], [80.10236359, 15.32458401], [80.10097504, 15.32458401], [80.10097504, 15.32486153], [80.1001358, 15.32486153], [80.1001358, 15.32514191], [80.09929657, 15.32514191], [80.09929657, 15.32486153], [80.09902954, 15.32486153], [80.09902954, 15.32402706], [80.09929657, 15.32403183], [80.09929657, 15.32374859], [80.09958649, 15.32374859], [80.09958649, 15.32347107], [80.09986115, 15.32347107], [80.09986115, 15.32319641], [80.10041809, 15.32319641], [80.10041809, 15.32263947], [80.10069275, 15.32263947], [80.10069275, 15.32208061], [80.10097504, 15.32208347], [80.10097504, 15.32124901], [80.10124969, 15.32126141], [80.10124969, 15.31958103], [80.10097504, 15.31958294], [80.10097504, 15.31930542], [80.10124969, 15.31931019], [80.10124969, 15.31903172], [80.10098267, 15.31903172], [80.10098267, 15.31820202], [80.10069275, 15.31820202], [80.10069275, 15.31792164], [80.10041809, 15.31792164], [80.10041809, 15.31736088], [80.1001358, 15.31736088], [80.1001358, 15.31708145], [80.09986115, 15.31708336], [80.09986115, 15.31652737], [80.09958649, 15.31652927], [80.09958649, 15.31624889], [80.09929657, 15.31624889], [80.09929657, 15.31569004], [80.09902954, 15.31569481], [80.09902954, 15.31541729], [80.09874725, 15.3154192], [80.09874725, 15.31513023], [80.0984726, 15.31513882], [80.0984726, 15.3148613], [80.09819794, 15.3148613], [80.09819794, 15.31430531], [80.09792328, 15.31431103], [80.09792328, 15.31403065], [80.09764099, 15.31403065], [80.09764099, 15.31375122], [80.09707642, 15.31375122], [80.09707642, 15.31347275], [80.09625244, 15.31347275], [80.09625244, 15.31319523], [80.0956955, 15.31319523], [80.09570313, 15.31347275], [80.09430695, 15.31347275], [80.09430695, 15.31375122], [80.09401703, 15.31375122], [80.09401703, 15.31403065], [80.09208679, 15.31403065], [80.09208679, 15.31431103], [80.0894928, 15.31430912], [80.08875275, 15.31431103], [80.08875275, 15.31403065], [80.08790588, 15.31403065], [80.08790588, 15.31431103], [80.0873642, 15.31430531], [80.0873642, 15.31458282], [80.08597565, 15.31458282], [80.08597565, 15.3148613], [80.0854187, 15.3148613], [80.0854187, 15.31513882], [80.08374786, 15.31513023], [80.08374786, 15.3154192], [80.08347321, 15.31541729], [80.08347321, 15.31569481], [80.0826416, 15.31569481], [80.0826416, 15.31597328], [80.08125305, 15.31597328], [80.08126068, 15.31624889], [80.08013916, 15.31624889], [80.08013916, 15.31597137], [80.0798645, 15.31597328], [80.0798645, 15.31569481], [80.08013916, 15.31569481], [80.08013916, 15.31541729], [80.08040619, 15.3154192], [80.08040619, 15.31513023], [80.08125305, 15.31513882], [80.08125305, 15.31458282], [80.08152771, 15.31458282], [80.08152771, 15.31430531], [80.08235931, 15.31431103], [80.08235931, 15.31403065], [80.08291626, 15.31403065], [80.08291626, 15.31375122], [80.08319092, 15.31375122], [80.08319092, 15.31347275], [80.08374786, 15.31347275], [80.08374786, 15.31319046], [80.08430481, 15.31319523], [80.08430481, 15.31291676], [80.08513641, 15.31292057], [80.08513641, 15.31264114], [80.08598328, 15.31264114], [80.08598328, 15.31236076], [80.08708191, 15.31236076], [80.08706665, 15.31207085], [80.0881958, 15.31208324], [80.0881958, 15.31180668], [80.08885193, 15.31180668], [80.0890274, 15.31181145], [80.0890274, 15.31153107], [80.08985901, 15.31153107], [80.08985901, 15.31125069], [80.09069061, 15.31125069], [80.09069824, 15.31097031], [80.09236145, 15.31097317], [80.09236145, 15.31069469], [80.09375, 15.31069469], [80.09375, 15.31041622], [80.09485626, 15.31042099], [80.09485626, 15.31014061], [80.09597015, 15.31014061], [80.09597015, 15.30986023], [80.09764099, 15.30986023], [80.09764099, 15.31014061], [80.09902954, 15.31014061], [80.09902954, 15.30986023], [80.0993042, 15.30986023], [80.0993042, 15.30958462], [80.09902954, 15.30958462], [80.09902954, 15.30930424], [80.09874725, 15.30932045], [80.09874725, 15.30903053], [80.0984726, 15.30903053], [80.0984726, 15.30846977], [80.09819794, 15.30847168], [80.09819794, 15.30791569], [80.09792328, 15.30792141], [80.09792328, 15.30764008], [80.09764099, 15.30764008], [80.09764099, 15.3073597], [80.0973587, 15.3073597], [80.0973587, 15.30708027], [80.09708405, 15.30708218], [80.09708405, 15.30624962], [80.09680176, 15.30626202], [80.09680176, 15.30568981], [80.0965271, 15.30569363], [80.0965271, 15.30513763], [80.09626007, 15.30513954], [80.09626007, 15.30403042], [80.09597015, 15.30403042], [80.09597015, 15.30375004], [80.09570313, 15.30375004], [80.09570313, 15.30318928], [80.09541321, 15.30319405], [80.09541321, 15.30236244], [80.09513855, 15.30236244], [80.09513855, 15.30152798], [80.09485626, 15.30153179], [80.09485626, 15.30097198], [80.0945816, 15.30097198], [80.0945816, 15.30069447], [80.09430695, 15.30069447], [80.09430695, 15.30013847], [80.09402466, 15.30013847], [80.09402466, 15.29986191], [80.09375, 15.29986191], [80.09375, 15.29930973], [80.0934906, 15.29930973], [80.0934906, 15.2990303], [80.09320068, 15.2990303], [80.09320068, 15.29819107], [80.0929184, 15.29819584], [80.0929184, 15.29736233], [80.09263611, 15.29736233], [80.09263611, 15.29680538], [80.09236145, 15.29681015], [80.09236145, 15.29624939], [80.09208679, 15.29624939], [80.09208679, 15.29541969], [80.09179688, 15.29541969], [80.09179688, 15.29486084], [80.09152985, 15.29486084], [80.09152985, 15.29430962], [80.09124756, 15.29430962], [80.09124756, 15.29375076], [80.0909729, 15.29375076], [80.0909729, 15.29264069], [80.09069824, 15.29264069], [80.09069061, 15.29181194], [80.09041595, 15.29181194], [80.09041595, 15.29069138], [80.0901413, 15.29069519], [80.0901413, 15.28986073], [80.08985901, 15.28986073], [80.08985901, 15.28875065], [80.08957672, 15.28875065], [80.08957672, 15.28792095], [80.08930206, 15.28792095], [80.08930206, 15.28707981], [80.0890274, 15.28708267], [80.0890274, 15.28625107], [80.08875275, 15.28625107], [80.08875275, 15.28569031], [80.08847046, 15.28569508], [80.08847046, 15.28486061], [80.0881958, 15.28486061], [80.0881958, 15.28402901], [80.08790588, 15.28403091], [80.08790588, 15.28318977], [80.08763885, 15.28319359], [80.08763885, 15.28236008], [80.08735657, 15.28236008], [80.08735657, 15.28181076], [80.08706665, 15.28181076], [80.08706665, 15.27985954], [80.08680725, 15.2798624], [80.08680725, 15.27930641], [80.08653259, 15.27931118], [80.08653259, 15.27764034], [80.08625031, 15.27764034], [80.08625031, 15.27707958], [80.08597565, 15.27708435], [80.08597565, 15.27652836], [80.08569336, 15.27653027], [80.08569336, 15.27595997], [80.0854187, 15.27597237], [80.0854187, 15.27541637], [80.08513641, 15.27542019], [80.08513641, 15.27486038], [80.08486176, 15.27486229], [80.08486176, 15.27041531], [80.0845871, 15.27042007], [80.0845871, 15.26931], [80.08429718, 15.26931], [80.08429718, 15.26847076], [80.08403015, 15.26847363], [80.08403015, 15.26763916], [80.08374786, 15.26764202], [80.08374786, 15.26708126], [80.08347321, 15.26708317], [80.08347321, 15.26402664], [80.08319092, 15.26402664], [80.08319092, 15.26236057], [80.08291626, 15.26236057], [80.08291626, 15.25374985], [80.08319092, 15.25375271], [80.08319092, 15.25263977], [80.08347321, 15.25263977], [80.08347321, 15.25152969], [80.08374786, 15.25152969], [80.08374786, 15.25014019], [80.08403015, 15.25014019], [80.08403015, 15.24874973], [80.08429718, 15.24874973], [80.08429718, 15.24763966], [80.0845871, 15.24763966], [80.0845871, 15.24652958], [80.08486176, 15.24652958], [80.08486176, 15.2456913], [80.08513641, 15.24569416], [80.08513641, 15.24514008], [80.0854187, 15.24514198], [80.0854187, 15.24431038], [80.08569336, 15.24431038], [80.08569336, 15.24346924], [80.08597565, 15.24347115], [80.08597565, 15.24291801], [80.08625031, 15.24291801], [80.08625031, 15.24180508], [80.08651733, 15.24181175], [80.08651733, 15.24042034], [80.08680725, 15.24042034], [80.08680725, 15.23875141], [80.08706665, 15.23875141], [80.08706665, 15.23736095], [80.08735657, 15.23736095], [80.08735657, 15.23236275], [80.08763885, 15.23236275], [80.08763885, 15.22735977], [80.08790588, 15.22735977], [80.08790588, 15.22513962], [80.0881958, 15.22513962], [80.0881958, 15.22402954], [80.08847046, 15.22402954], [80.08847046, 15.21930981], [80.0881958, 15.21930981], [80.0881958, 15.2179203], [80.08790588, 15.2179203], [80.08790588, 15.21568203], [80.08763885, 15.21569347], [80.08763885, 15.21347332], [80.0873642, 15.21347332], [80.0873642, 15.21180534], [80.08706665, 15.21181202], [80.08706665, 15.21069145], [80.08680725, 15.21069527], [80.08680725, 15.2098608], [80.08651733, 15.20987034], [80.08651733, 15.20818996], [80.08625031, 15.20819473], [80.08625031, 15.20652676], [80.08598328, 15.20653057], [80.08598328, 15.20486069], [80.08569336, 15.20486069], [80.08569336, 15.20318985], [80.0854187, 15.20319462], [80.0854187, 15.2015276], [80.08513641, 15.20153141], [80.08513641, 15.20042133], [80.08486176, 15.20042133], [80.08486176, 15.19931126], [80.0845871, 15.19931126], [80.0845871, 15.19847202], [80.08430481, 15.19847202], [80.08430481, 15.19736004], [80.08403015, 15.19736004], [80.08403015, 15.19653034], [80.08374786, 15.19653034], [80.08374786, 15.19542027], [80.08347321, 15.19542027], [80.08347321, 15.19458199], [80.08319092, 15.19458389], [80.08319092, 15.19430637], [80.08291626, 15.19431019], [80.08291626, 15.19375038], [80.0826416, 15.19375038], [80.0826416, 15.19319057], [80.08235931, 15.19319439], [80.08235931, 15.19291782], [80.08207703, 15.19291973], [80.08207703, 15.1926403], [80.08180237, 15.1926403], [80.08180237, 15.19236183], [80.08152771, 15.19236183], [80.08152771, 15.19208145], [80.08125305, 15.19208431], [80.08125305, 15.19180584], [80.08097076, 15.19180584], [80.08097076, 15.19124985], [80.08069611, 15.19125175], [80.08069611, 15.19097233], [80.08041382, 15.19097233], [80.08041382, 15.19069576], [80.08013916, 15.19069576], [80.08013916, 15.19041538], [80.0790329, 15.19042015], [80.0790329, 15.19013977], [80.07875061, 15.19013977], [80.07875061, 15.18985939], [80.07847595, 15.18986225], [80.07847595, 15.18958378], [80.07819366, 15.18958378], [80.07819366, 15.18902683], [80.07707977, 15.18902969], [80.07707977, 15.18931007], [80.07569122, 15.18930531], [80.07569122, 15.18958378], [80.07514191, 15.18958378], [80.07514191, 15.18986225], [80.07501221, 15.18986225], [80.07457733, 15.18985939], [80.07457733, 15.19013977], [80.07430267, 15.19013977], [80.07430267, 15.19042015], [80.07402802, 15.19041538], [80.07402802, 15.19069576], [80.07347107, 15.19069576], [80.07347107, 15.19097233], [80.07290649, 15.19097233], [80.07290649, 15.19125175], [80.07206726, 15.19125175], [80.07206726, 15.19153023], [80.07180786, 15.19152832], [80.07180786, 15.19180584], [80.07152557, 15.19180584], [80.07152557, 15.19208431], [80.07068634, 15.19208145], [80.07068634, 15.19236183], [80.07041931, 15.19236183], [80.07041931, 15.1926403], [80.06986237, 15.1926403], [80.06986237, 15.19291973], [80.06958008, 15.19291782], [80.06958008, 15.19347191], [80.06930542, 15.19347191], [80.06932068, 15.19375038], [80.06903076, 15.19375038], [80.06903076, 15.19402981], [80.06874847, 15.19402981], [80.06874847, 15.19431019], [80.06846619, 15.19431019], [80.06846619, 15.19487095], [80.06819153, 15.19487095], [80.06819153, 15.19542027], [80.06791687, 15.19541645], [80.06791687, 15.1956892], [80.06764221, 15.19569397], [80.06764221, 15.19597244], [80.06735992, 15.19596958], [80.06735992, 15.19624996], [80.0670929, 15.19624996], [80.0670929, 15.19681072], [80.06680298, 15.19680595], [80.06680298, 15.19708443], [80.06652832, 15.19707966], [80.06652832, 15.19764042], [80.06597137, 15.19764042], [80.06597137, 15.19793034], [80.06569672, 15.19791603], [80.06569672, 15.19819355], [80.06513977, 15.19819355], [80.06513977, 15.19847202], [80.06485748, 15.19847202], [80.06485748, 15.19874954], [80.06430817, 15.19874954], [80.06430817, 15.19931126], [80.06375122, 15.19930553], [80.06375122, 15.1995821], [80.06346893, 15.1995821], [80.06346893, 15.19986153], [80.06318665, 15.19985962], [80.06318665, 15.20014], [80.06291962, 15.20014], [80.06291962, 15.20042133], [80.06236267, 15.20041561], [80.06236267, 15.20069408], [80.06208038, 15.20069408], [80.06208038, 15.2009716], [80.06153107, 15.2009697], [80.06153107, 15.20125008], [80.06124878, 15.20125008], [80.06124878, 15.20153141], [80.06096649, 15.20153141], [80.06096649, 15.20181084], [80.06069183, 15.20180416], [80.06069183, 15.20208454], [80.05986023, 15.20208454], [80.05986023, 15.20236015], [80.05930328, 15.20236015], [80.05930328, 15.20264053], [80.05874634, 15.20264053], [80.05874634, 15.20292091], [80.05819702, 15.20291615], [80.05819702, 15.20319462], [80.05791473, 15.20319462], [80.05791473, 15.20347309], [80.05764008, 15.20347309], [80.05764008, 15.20375061], [80.05735779, 15.20374203], [80.05735779, 15.20403099], [80.05709076, 15.20403099], [80.05709076, 15.20431137], [80.05680847, 15.20431137], [80.05680847, 15.20486069], [80.05652618, 15.20486069], [80.05652618, 15.20514107], [80.05625153, 15.20514107], [80.05625153, 15.20542145], [80.05596924, 15.20541668], [80.05596924, 15.20569515], [80.05541992, 15.20569515], [80.05541992, 15.20597267], [80.05513763, 15.20597076], [80.05513763, 15.20625114], [80.05486298, 15.20625114], [80.05486298, 15.20653057], [80.05458069, 15.20653057], [80.05458069, 15.2068119], [80.05403137, 15.20680523], [80.05403137, 15.20708275], [80.05347443, 15.20708275], [80.05347443, 15.20736122], [80.05291748, 15.20736122], [80.05291748, 15.20764065], [80.05208588, 15.20764065], [80.05208588, 15.20792103], [80.05152893, 15.20791721], [80.05152893, 15.20819473], [80.05041504, 15.20819473], [80.05041504, 15.20847321], [80.05014038, 15.2084713], [80.05014038, 15.20875072], [80.04957581, 15.20875072], [80.04957581, 15.2090292], [80.04875183, 15.2090292], [80.04875183, 15.20930862], [80.04846954, 15.20930481], [80.04846954, 15.20958328], [80.04736328, 15.20958138], [80.04736328, 15.20987034], [80.04651642, 15.20987034], [80.04651642, 15.20958138], [80.04624939, 15.20958328], [80.04624939, 15.20930481], [80.0459671, 15.20930862], [80.0459671, 15.2084713], [80.04624939, 15.20847321], [80.04624939, 15.20819473], [80.04680634, 15.20819473], [80.04680634, 15.20791721], [80.04736328, 15.20792103], [80.04736328, 15.20764065], [80.04818726, 15.20764065], [80.04818726, 15.20736122], [80.04875183, 15.20736122], [80.04875183, 15.20708275], [80.04902649, 15.20708275], [80.04902649, 15.20680523], [80.04957581, 15.2068119], [80.04957581, 15.20653057], [80.05014038, 15.20653057], [80.05014038, 15.20597076], [80.05041504, 15.20597267], [80.05041504, 15.20569515], [80.05097198, 15.20569515], [80.05097198, 15.20513916], [80.05124664, 15.20514107], [80.05124664, 15.20486069], [80.05152893, 15.20486069], [80.05152893, 15.20458031], [80.05180359, 15.20458317], [80.05180359, 15.2043066], [80.05236053, 15.20431137], [80.05236053, 15.20403099], [80.05264282, 15.20403099], [80.05264282, 15.20374203], [80.05291748, 15.20375061], [80.05291748, 15.20319462], [80.05319214, 15.20319462], [80.05319214, 15.20291615], [80.0534668, 15.20292091], [80.0534668, 15.20264053], [80.05374908, 15.20264053], [80.05374908, 15.20236015], [80.05403137, 15.20236015], [80.05403137, 15.20208454], [80.05430603, 15.20208454], [80.05430603, 15.20180416], [80.05486298, 15.20181084], [80.05486298, 15.20153141], [80.05513763, 15.20153141], [80.05513763, 15.20125008], [80.05541992, 15.20125008], [80.05541992, 15.20068073], [80.05569458, 15.20069408], [80.05569458, 15.19986153], [80.05596924, 15.19986153], [80.05596924, 15.1995821], [80.05625153, 15.1995821], [80.05625153, 15.19930553], [80.05652618, 15.19931126], [80.05652618, 15.19903088], [80.05680847, 15.19903088], [80.05680847, 15.19847202], [80.05708313, 15.19847202], [80.05708313, 15.19819355], [80.05735779, 15.19819355], [80.05735779, 15.19791603], [80.05764008, 15.19793034], [80.05764008, 15.19764042], [80.0579071, 15.19764042], [80.0579071, 15.19736004], [80.05847168, 15.19736004], [80.05847168, 15.19707966], [80.05902863, 15.19708443], [80.05902863, 15.19680595], [80.05930328, 15.19681072], [80.05930328, 15.19653034], [80.0595932, 15.19653034], [80.0595932, 15.19624996], [80.05986023, 15.19624996], [80.05986023, 15.1956892], [80.06014252, 15.19569397], [80.06014252, 15.19541645], [80.06041718, 15.19542027], [80.06041718, 15.19514179], [80.06069183, 15.19514179], [80.06069183, 15.19487095], [80.06096649, 15.19487095], [80.06096649, 15.19458199], [80.06124878, 15.19458389], [80.06124878, 15.19430637], [80.06153107, 15.19431019], [80.06153107, 15.19402981], [80.06181335, 15.19402981], [80.06181335, 15.19375038], [80.06208038, 15.19375038], [80.06208038, 15.19319057], [80.06236267, 15.19319439], [80.06236267, 15.19291782], [80.06263733, 15.19291973], [80.06263733, 15.1926403], [80.06291962, 15.1926403], [80.06291962, 15.19236183], [80.06346893, 15.19236183], [80.06346893, 15.19208145], [80.06375122, 15.19208431], [80.06375122, 15.19152832], [80.06346893, 15.19153023], [80.06346893, 15.19125175], [80.06236267, 15.19125175], [80.06236267, 15.19153023], [80.06208038, 15.19152832], [80.06208038, 15.19180584], [80.06124878, 15.19180584], [80.06124878, 15.19152832], [80.06096649, 15.19153023], [80.06096649, 15.19125175], [80.06069183, 15.19125175], [80.06069183, 15.19069099], [80.06097412, 15.19069576], [80.06097412, 15.19041538], [80.06181335, 15.19042015], [80.06181335, 15.19013977], [80.06291962, 15.19013977], [80.06291962, 15.18985939], [80.06319427, 15.18986225], [80.06319427, 15.18958378], [80.06430817, 15.18958378], [80.06430817, 15.18930531], [80.06513977, 15.18931007], [80.06513977, 15.18873978], [80.06569672, 15.18874931], [80.06569672, 15.18847084], [80.06597137, 15.18847084], [80.06597137, 15.18819141], [80.06652832, 15.18819332], [80.06652832, 15.18763924], [80.06680298, 15.18763924], [80.06680298, 15.18708134], [80.06735992, 15.18708324], [80.06735992, 15.18680477], [80.06791687, 15.18680954], [80.06791687, 15.18653202], [80.06846619, 15.18653202], [80.06846619, 15.18625069], [80.06874847, 15.18625069], [80.06874847, 15.18597126], [80.06930542, 15.18597126], [80.06930542, 15.18569469], [80.06986237, 15.18570042], [80.06986237, 15.18542194], [80.07013702, 15.18542194], [80.07013702, 15.18514061], [80.07068634, 15.18514061], [80.07068634, 15.18486118], [80.07125092, 15.18486118], [80.07125092, 15.18458271], [80.07152557, 15.18458271], [80.07152557, 15.18430519], [80.07312012, 15.18430519], [80.07319641, 15.18430519], [80.07319641, 15.18403244], [80.07347107, 15.18403244], [80.07347107, 15.18375111], [80.07402802, 15.18375111], [80.07402802, 15.1831913], [80.07485962, 15.18319511], [80.07485962, 15.18291664], [80.07541656, 15.18293095], [80.07541656, 15.18264103], [80.07596588, 15.18264103], [80.07596588, 15.18236065], [80.07624817, 15.18236065], [80.07624817, 15.18208122], [80.07736206, 15.18208313], [80.07736206, 15.18180466], [80.07818604, 15.18180943], [80.07818604, 15.18236065], [80.07847595, 15.18236065], [80.07847595, 15.18293095], [80.07875061, 15.18291664], [80.07875061, 15.18347263], [80.0790329, 15.18347073], [80.0790329, 15.18403244], [80.07930756, 15.18402672], [80.07930756, 15.18458271], [80.07958221, 15.1845808], [80.07958221, 15.18514061], [80.07985687, 15.18514061], [80.07985687, 15.18570042], [80.08013916, 15.18569469], [80.08013916, 15.18597126], [80.08040619, 15.18597126], [80.08040619, 15.18625069], [80.08097076, 15.18625069], [80.08097076, 15.18597126], [80.08125305, 15.18597126], [80.08125305, 15.18541718], [80.08097076, 15.18542194], [80.08097076, 15.1845808], [80.08069611, 15.18458271], [80.08069611, 15.18375111], [80.08040619, 15.18375111], [80.08040619, 15.1831913], [80.08013916, 15.18319511], [80.08013916, 15.18263912], [80.07985687, 15.18264103], [80.07985687, 15.18208122], [80.07958221, 15.18208313], [80.07958221, 15.18152905], [80.07930756, 15.18153095], [80.07930756, 15.18097115], [80.07902527, 15.18097305], [80.07902527, 15.18069458], [80.07819366, 15.18069458], [80.07819366, 15.17986107], [80.07791901, 15.17986107], [80.07791901, 15.17957115], [80.07763672, 15.1795826], [80.07763672, 15.1790266], [80.07736206, 15.17903137], [80.07736206, 15.17846966], [80.07707977, 15.17847347], [80.07707977, 15.178195], [80.07680511, 15.178195], [80.07680511, 15.17763901], [80.07653046, 15.17764091], [80.07653046, 15.17708015], [80.07624817, 15.17708206], [80.07624817, 15.17652893], [80.07596588, 15.17653084], [80.07596588, 15.17597008], [80.07569122, 15.17597294], [80.07569122, 15.17541599], [80.07541656, 15.17542076], [80.07541656, 15.17486], [80.07512665, 15.17486], [80.07512665, 15.17457962], [80.07485962, 15.17458534], [80.07485962, 15.1740284], [80.07457733, 15.17403126], [80.07457733, 15.17346954], [80.07430267, 15.1734724], [80.07430267, 15.17291641], [80.07402802, 15.17292118], [80.07402802, 15.17236042], [80.07375336, 15.17236233], [80.07375336, 15.17180634], [80.07347107, 15.1718111], [80.07347107, 15.17125034], [80.07319641, 15.17125034], [80.07319641, 15.17070103], [80.07290649, 15.17070103], [80.07290649, 15.17014027], [80.07263947, 15.17014027], [80.07263947, 15.16958046], [80.07236481, 15.16958427], [80.07236481, 15.16902828], [80.07206726, 15.16903019], [80.07206726, 15.16819191], [80.07180786, 15.16819382], [80.07180786, 15.16763783], [80.07152557, 15.16763783], [80.07152557, 15.16708374], [80.07125092, 15.16708374], [80.07125092, 15.16652775], [80.07096863, 15.16652966], [80.07096863, 15.16596889], [80.07069397, 15.16597176], [80.07069397, 15.16541767], [80.07041931, 15.16541958], [80.07041931, 15.16486168], [80.07013702, 15.16486168], [80.07013702, 15.16431046], [80.06986237, 15.16431046], [80.06986237, 15.16374969], [80.06958008, 15.16374969], [80.06958008, 15.16319084], [80.06930542, 15.16319561], [80.06930542, 15.16263962], [80.06903076, 15.16263962], [80.06903076, 15.16208076], [80.06874847, 15.16208267], [80.06874847, 15.16152668], [80.06846619, 15.16152954], [80.06846619, 15.16097069], [80.06819153, 15.16097355], [80.06819153, 15.1604166], [80.06791687, 15.16042042], [80.06791687, 15.15986061], [80.06764221, 15.15986061], [80.06764221, 15.15930462], [80.06735992, 15.15931034], [80.06735992, 15.15876007], [80.0670929, 15.15876007], [80.0670929, 15.15819073], [80.06680298, 15.15819454], [80.06680298, 15.15763855], [80.06652832, 15.15764141], [80.06652832, 15.15681171], [80.06624603, 15.15681171], [80.06624603, 15.15597057], [80.06597137, 15.15597343], [80.06597137, 15.15513897], [80.06569672, 15.15514088], [80.06569672, 15.15458107], [80.06541443, 15.15458298], [80.06541443, 15.15375137], [80.06513977, 15.15375137], [80.06513977, 15.15318966], [80.06485748, 15.15319538], [80.06485748, 15.1520834], [80.06458282, 15.1520834], [80.06458282, 15.15125084], [80.06430817, 15.15125084], [80.06430817, 15.15014076], [80.06402588, 15.15014076], [80.06402588, 15.14931107], [80.06375122, 15.14931107], [80.06375122, 15.14846992], [80.06346893, 15.14847183], [80.06346893, 15.14763832], [80.06318665, 15.14764118], [80.06318665, 15.14653111], [80.06291962, 15.14653111], [80.06291962, 15.14569187], [80.06263733, 15.14569378], [80.06263733, 15.14486217], [80.06236267, 15.14486217], [80.06236267, 15.14402771], [80.06208038, 15.14402962], [80.06208038, 15.14318943], [80.06180573, 15.1431942], [80.06180573, 15.14208412], [80.06153107, 15.14208412], [80.06153107, 15.14124966], [80.06124878, 15.14124966], [80.06124878, 15.14041996], [80.06096649, 15.14041996], [80.06096649, 15.13958168], [80.06069183, 15.13958359], [80.06069183, 15.1384716], [80.06041718, 15.1384716], [80.06041718, 15.13736153], [80.06014252, 15.13736153], [80.06014252, 15.13624859], [80.05986023, 15.13624859], [80.05986023, 15.13542175], [80.0595932, 15.13542175], [80.0595932, 15.13430977], [80.05930328, 15.13430977], [80.05930328, 15.13319969], [80.05902863, 15.13319111], [80.05902863, 15.13263893], [80.05874634, 15.13264179], [80.05874634, 15.13181019], [80.05847168, 15.13181019], [80.05847168, 15.13125134], [80.05819702, 15.13125134], [80.05819702, 15.13069057], [80.05791473, 15.13069534], [80.05791473, 15.12930489], [80.05764008, 15.1293087], [80.05764008, 15.12846184], [80.05735779, 15.12847328], [80.05735779, 15.12791729], [80.05709076, 15.1279192], [80.05709076, 15.12708092], [80.05680847, 15.12708282], [80.05680847, 15.12625122], [80.05652618, 15.12625122], [80.05652618, 15.12542057], [80.05625153, 15.12542057], [80.05625153, 15.12458038], [80.05596924, 15.12458324], [80.05596924, 15.12375069], [80.05568695, 15.12375069], [80.05568695, 15.12292099], [80.05541992, 15.12292099], [80.05541992, 15.12181091], [80.05513763, 15.12181091], [80.05513763, 15.12096977], [80.05486298, 15.12097168], [80.05486298, 15.12013817], [80.05458069, 15.12014103], [80.05458069, 15.11931133], [80.05430603, 15.11931133], [80.05430603, 15.11847019], [80.05403137, 15.1184721], [80.05403137, 15.11763763], [80.05374908, 15.11763954], [80.05374908, 15.11652088], [80.05347443, 15.11652756], [80.05347443, 15.11541557], [80.05319214, 15.11542034], [80.05319214, 15.1145792], [80.05291748, 15.11458397], [80.05291748, 15.11347198], [80.05263519, 15.11347198], [80.05263519, 15.11236191], [80.05236053, 15.11236191], [80.05236053, 15.11125183], [80.05208588, 15.11125183], [80.05208588, 15.11014175], [80.05179596, 15.11014175], [80.05179596, 15.10902977], [80.05152893, 15.10902977], [80.05152893, 15.10791969], [80.05124664, 15.10791969], [80.05124664, 15.10680962], [80.05095673, 15.10680962], [80.05095673, 15.10486126], [80.05069733, 15.10486126], [80.05069733, 15.10319519], [80.05041504, 15.10319519], [80.05041504, 15.1026392], [80.05014038, 15.1026392], [80.05014038, 15.10125065], [80.04985809, 15.10125065], [80.04985809, 15.10014057], [80.04957581, 15.10014057], [80.04957581, 15.09903145], [80.04930878, 15.09903145], [80.04930878, 15.09736061], [80.04902649, 15.09736061], [80.04902649, 15.0951376], [80.04875183, 15.09514141], [80.04875183, 15.0945797], [80.04846954, 15.09458542], [80.04846954, 15.09069443], [80.04819489, 15.09069443], [80.04819489, 15.08874989], [80.04792023, 15.08875179], [80.04792023, 15.07734966], [80.04819489, 15.07736111], [80.04819489, 15.06902885], [80.04846954, 15.06903076], [80.04846954, 15.06264019], [80.04875183, 15.06264019], [80.04875183, 15.06042004], [80.04902649, 15.06042004], [80.04902649, 15.05181026], [80.04930878, 15.05181026], [80.04930878, 15.04568958], [80.04958344, 15.0456953], [80.04958344, 15.04291725], [80.04985809, 15.04292107], [80.04985809, 15.03792095], [80.05014038, 15.03792095], [80.05014038, 15.03625011], [80.05042267, 15.03625011], [80.05042267, 15.03347015], [80.05069733, 15.03347206], [80.05069733, 15.02791786], [80.05095673, 15.02791977], [80.05095673, 15.02653027], [80.05124664, 15.02653027], [80.05124664, 15.02569103], [80.05152893, 15.02569485], [80.05152893, 15.02458286], [80.05180359, 15.02458286], [80.05180359, 15.02347088], [80.05208588, 15.02347088], [80.05208588, 15.02180481], [80.05236053, 15.02180958], [80.05236053, 15.01986122], [80.05263519, 15.01986122], [80.05263519, 15.01847267], [80.05291748, 15.01847267], [80.05291748, 15.01486015], [80.05319214, 15.01486015], [80.05319214, 15.01124954], [80.0534668, 15.01126194], [80.05347443, 15.00971031], [80.05347443, 15.00847244], [80.05374908, 15.00847244], [80.05374908, 15.00680637], [80.05403137, 15.00681114], [80.05403137, 15.00569057], [80.05430603, 15.00569439], [80.05430603, 15.00319576], [80.05458069, 15.00319576], [80.05458069, 14.99986076], [80.05458069, 14.99932098], [80.05486298, 14.99932098], [80.05486298, 14.99819088], [80.05513763, 14.99819469], [80.05513763, 14.99680519], [80.05541992, 14.99681187], [80.05541992, 14.9956913], [80.05569458, 14.99569511], [80.05569458, 14.99430466], [80.05596924, 14.99430943], [80.05596924, 14.9931879], [80.05625153, 14.99319458], [80.05625153, 14.9920826], [80.05652618, 14.9920826], [80.05652618, 14.990695], [80.05680847, 14.990695], [80.05680847, 14.98958302], [80.05708313, 14.98958302], [80.05708313, 14.98819542], [80.05735779, 14.98819542], [80.05735779, 14.98708153], [80.05764008, 14.98709106], [80.05764008, 14.98569202], [80.05791473, 14.98569393], [80.05791473, 14.98430634], [80.05819702, 14.9843111], [80.05819702, 14.98264027], [80.05847168, 14.98264027], [80.05847168, 14.98124981], [80.05874634, 14.98124981], [80.05874634, 14.97986031], [80.05902863, 14.97986221], [80.05902863, 14.97847176], [80.05930328, 14.97847176], [80.05930328, 14.97680569], [80.0595932, 14.97681046], [80.0595932, 14.97542], [80.05986023, 14.97542], [80.05986023, 14.97402954], [80.06012726, 14.97402954], [80.06012726, 14.97236061], [80.06041718, 14.97236061], [80.06041718, 14.97097111], [80.06069183, 14.97097111], [80.06069183, 14.96930504], [80.06096649, 14.96931171], [80.06096649, 14.96791935], [80.06124878, 14.96791935], [80.06124878, 14.96680927], [80.06153107, 14.96680927], [80.06153107, 14.96625137], [80.06181335, 14.96625137], [80.06180573, 14.96430683], [80.06208038, 14.96431065], [80.06208038, 14.96375084], [80.06181335, 14.96375084], [80.06181335, 14.96319008], [80.06208038, 14.96319485], [80.06208038, 14.96208191], [80.06291962, 14.96208191], [80.06291962, 14.96152878], [80.06236267, 14.96153069], [80.06236267, 14.96042061], [80.06263733, 14.96042061], [80.06263733, 14.95986271], [80.06291962, 14.95986271], [80.06291962, 14.95874977], [80.06318665, 14.95874977], [80.06318665, 14.95597172], [80.06346893, 14.95597172], [80.06346893, 14.95542145], [80.06375122, 14.95542145], [80.06375122, 14.95431137], [80.06346893, 14.95431137], [80.06346893, 14.95347023], [80.06375122, 14.95347214], [80.06375122, 14.95236206], [80.06402588, 14.95236206], [80.06402588, 14.95014], [80.06430817, 14.95014191], [80.06430817, 14.94847107], [80.06458282, 14.94847107], [80.06458282, 14.94708347], [80.06485748, 14.94708347], [80.06485748, 14.94597435], [80.06513977, 14.94597435], [80.06513977, 14.9454174], [80.0654068, 14.94542027], [80.0654068, 14.94484997], [80.06569672, 14.94486141], [80.06569672, 14.94375134], [80.06597137, 14.94375134], [80.06597137, 14.94347095], [80.06652832, 14.94347095], [80.06652832, 14.94263935], [80.06624603, 14.94263935], [80.06624603, 14.94208145], [80.06597137, 14.94208336], [80.06597137, 14.94124889], [80.06624603, 14.94124889], [80.06624603, 14.9404192], [80.06652832, 14.9404192], [80.06652832, 14.93958092], [80.06680298, 14.93958282], [80.06680298, 14.93791676], [80.0670929, 14.93792057], [80.0670929, 14.93708038], [80.06735992, 14.93708324], [80.06735992, 14.93652916], [80.06764221, 14.93653107], [80.06764221, 14.93598175], [80.06791687, 14.93598175], [80.06791687, 14.93375111], [80.06764221, 14.93375111], [80.06764221, 14.93319035], [80.06791687, 14.93319416], [80.06791687, 14.93263817], [80.06819153, 14.93264103], [80.06819153, 14.93153095], [80.06846619, 14.93153095], [80.06846619, 14.92903042], [80.06874847, 14.92903042], [80.06874847, 14.92708015], [80.06903076, 14.92708397], [80.06903076, 14.92652798], [80.06932068, 14.92653275], [80.06932068, 14.92597198], [80.06958008, 14.92597198], [80.06958008, 14.9254179], [80.06986237, 14.92541981], [80.06986237, 14.92486191], [80.07013702, 14.92486191], [80.07013702, 14.92404079], [80.07041931, 14.92404079], [80.07041931, 14.92346859], [80.07069397, 14.9234724], [80.07069397, 14.92319584], [80.07096863, 14.92319584], [80.07096863, 14.92291641], [80.07125092, 14.92292023], [80.07125092, 14.92235947], [80.07152557, 14.92236233], [80.07152557, 14.92208385], [80.07180786, 14.92208385], [80.07180786, 14.92152786], [80.07206726, 14.92152977], [80.07206726, 14.92124939], [80.07235718, 14.92124939], [80.07235718, 14.92069054], [80.07263947, 14.9206934], [80.07263947, 14.92041779], [80.07290649, 14.92041969], [80.07290649, 14.92014027], [80.07319641, 14.92014027], [80.07319641, 14.91958141], [80.07347107, 14.91958332], [80.07347107, 14.91902733], [80.07375336, 14.91903019], [80.07375336, 14.91819096], [80.07402802, 14.91819477], [80.07402802, 14.91763878], [80.07430267, 14.91764164], [80.07430267, 14.91708088], [80.07458496, 14.91708279], [80.07458496, 14.91652679], [80.07485962, 14.91653156], [80.07485962, 14.91596889], [80.07514191, 14.9159708], [80.07514191, 14.91541672], [80.07541656, 14.91541862], [80.07541656, 14.91431046], [80.07569122, 14.91431046], [80.07569122, 14.91347122], [80.07597351, 14.91347313], [80.07597351, 14.91236115], [80.07624817, 14.91236115], [80.07624817, 14.91152668], [80.07653046, 14.91153145], [80.07653046, 14.91042137], [80.07681274, 14.91042137], [80.07681274, 14.90958023], [80.07707977, 14.90958309], [80.07707977, 14.90847301], [80.07736206, 14.90847301], [80.07736206, 14.9076376], [80.07763672, 14.90764141], [80.07763672, 14.90653133], [80.07791901, 14.90653133], [80.07791901, 14.90568066], [80.07819366, 14.90569401], [80.07819366, 14.90458202], [80.07847595, 14.90458202], [80.07847595, 14.90375042], [80.07875061, 14.90375042], [80.07875061, 14.90264034], [80.0790329, 14.90264034], [80.0790329, 14.90153027], [80.07930756, 14.90153027], [80.07930756, 14.90069199], [80.07958221, 14.90069389], [80.07958221, 14.89958191], [80.0798645, 14.89958191], [80.0798645, 14.89875031], [80.08013916, 14.89875031], [80.08013916, 14.89764023], [80.08040619, 14.89764023], [80.08040619, 14.89680958], [80.08069611, 14.89680958], [80.08069611, 14.89569092], [80.08097076, 14.89569569], [80.08097076, 14.8945837], [80.08125305, 14.8945837], [80.08125305, 14.89374924], [80.08152771, 14.89374924], [80.08152771, 14.89263916], [80.08180237, 14.89264202], [80.08180237, 14.89153194], [80.08207703, 14.89153194], [80.08207703, 14.89067936], [80.08235931, 14.89069462], [80.08235931, 14.88958263], [80.0826416, 14.88958263], [80.0826416, 14.88874912], [80.08291626, 14.88875103], [80.08291626, 14.88764095], [80.08319092, 14.88764095], [80.08319092, 14.88653088], [80.08347321, 14.88653088], [80.08347321, 14.88541889], [80.08374786, 14.88541889], [80.08374786, 14.88375092], [80.08403015, 14.88375092], [80.08403015, 14.88208008], [80.08430481, 14.88208294], [80.08430481, 14.88069534], [80.0845871, 14.88069534], [80.0845871, 14.87902832], [80.08486176, 14.87903118], [80.08486176, 14.87681103], [80.08513641, 14.87681103], [80.08513641, 14.87403011], [80.0854187, 14.87403011], [80.0854187, 14.87125015], [80.08569336, 14.87125015], [80.08569336, 14.86653042], [80.08598328, 14.86653042], [80.08598328, 14.85986137], [80.08625031, 14.85986137], [80.08625031, 14.85208225], [80.08652496, 14.85208225], [80.08652496, 14.84986019], [80.08680725, 14.84986019], [80.08680725, 14.84958363], [80.08708191, 14.84958363], [80.08708191, 14.84902763], [80.08735657, 14.84903145], [80.08735657, 14.84846973], [80.08708191, 14.84847164], [80.08708191, 14.84791565], [80.08680725, 14.84792137], [80.08680725, 14.84708023], [80.08652496, 14.84708405], [80.08652496, 14.84486198], [80.08680725, 14.84486198], [80.08680725, 14.84041977], [80.08706665, 14.84041977], [80.08706665, 14.83653164], [80.08735657, 14.83653164], [80.08735657, 14.83319092], [80.08708191, 14.83319473], [80.08708191, 14.83069515], [80.0873642, 14.83069515], [80.0873642, 14.82680416], [80.08763885, 14.82681084], [80.08763885, 14.82431126], [80.08790588, 14.82431126], [80.08790588, 14.82264042], [80.0881958, 14.82264042], [80.0881958, 14.8215189], [80.08763885, 14.82152843], [80.08763885, 14.82208443], [80.08735657, 14.82207966], [80.08735657, 14.82236004], [80.08706665, 14.82236004], [80.08706665, 14.82264042], [80.08651733, 14.82264042], [80.08651733, 14.8229208], [80.08598328, 14.8229208], [80.08598328, 14.82264042], [80.08429718, 14.82264042], [80.08429718, 14.8215189], [80.08513641, 14.8215189], [80.08513641, 14.82181072], [80.08680725, 14.82181072], [80.08680725, 14.82124996], [80.08706665, 14.82124996], [80.08706665, 14.82096958], [80.0873642, 14.82097244], [80.0873642, 14.82013798], [80.08706665, 14.82014179], [80.08706665, 14.81931114], [80.08735657, 14.81931114], [80.08735657, 14.81902981], [80.08763885, 14.81902981], [80.08763885, 14.81875038], [80.08790588, 14.81875038], [80.08790588, 14.81819153], [80.0881958, 14.81819439], [80.0881958, 14.81791592], [80.08847046, 14.81791973], [80.08847046, 14.8176403], [80.08875275, 14.8176403], [80.08875275, 14.81708241], [80.08847046, 14.81708431], [80.08847046, 14.81597233], [80.0881958, 14.81597233], [80.0881958, 14.81513977], [80.08847046, 14.81513977], [80.08847046, 14.81458092], [80.08875275, 14.81458378], [80.08875275, 14.81402779], [80.0890274, 14.81402969], [80.0890274, 14.81265068], [80.08875275, 14.81265068], [80.08875275, 14.81153202], [80.08790588, 14.81153202], [80.08790588, 14.81125164], [80.08706665, 14.81125164], [80.08706665, 14.81097126], [80.08625031, 14.81097126], [80.08625031, 14.81069469], [80.08513641, 14.81069469], [80.08513641, 14.81041527], [80.08429718, 14.81042194], [80.08429718, 14.81014156], [80.08347321, 14.81014156], [80.08347321, 14.80986118], [80.08180237, 14.80986118], [80.08180237, 14.81014156], [80.08069611, 14.81014156], [80.08069611, 14.81042194], [80.08041382, 14.81041527], [80.08041382, 14.81069469], [80.08013916, 14.81069469], [80.08013916, 14.81097126], [80.07985687, 14.81097126], [80.07985687, 14.81125164], [80.07930756, 14.81125164], [80.07930756, 14.81153202], [80.0790329, 14.81153202], [80.0790329, 14.81180954], [80.07875061, 14.81180477], [80.07875061, 14.81208324], [80.07847595, 14.81208134], [80.07847595, 14.81236076], [80.07818604, 14.81236076], [80.07818604, 14.81265068], [80.07763672, 14.81265068], [80.07763672, 14.81291962], [80.07736206, 14.81291771], [80.07736206, 14.81319332], [80.07707977, 14.81319141], [80.07707977, 14.81347084], [80.07680511, 14.81347084], [80.07681274, 14.81374931], [80.07653046, 14.81374931], [80.07653046, 14.81402969], [80.07624817, 14.81402969], [80.07624817, 14.81431007], [80.07569122, 14.81430626], [80.07569122, 14.81442165], [80.07569122, 14.81458378], [80.07541656, 14.81458378], [80.07541656, 14.81486225], [80.07485962, 14.81485939], [80.07485962, 14.81513977], [80.07457733, 14.81513977], [80.07457733, 14.81542015], [80.07430267, 14.81541634], [80.07430267, 14.81569576], [80.07375336, 14.81569576], [80.07375336, 14.81597233], [80.07347107, 14.81596947], [80.07347107, 14.81624985], [80.07290649, 14.81624985], [80.07290649, 14.81653023], [80.07206726, 14.81653023], [80.07206726, 14.81680965], [80.07152557, 14.81680584], [80.07152557, 14.81708431], [80.07068634, 14.81708241], [80.07068634, 14.81736183], [80.07013702, 14.81736183], [80.07013702, 14.8176403], [80.06986237, 14.8176403], [80.06986237, 14.81791973], [80.06958008, 14.81791592], [80.06958008, 14.81819439], [80.06930542, 14.81819439], [80.06930542, 14.81847191], [80.06903076, 14.81846046], [80.06903076, 14.81875038], [80.06874847, 14.81875038], [80.06874847, 14.81931114], [80.06819153, 14.81930637], [80.06819153, 14.81958199], [80.06735992, 14.81958199], [80.06735992, 14.81986237], [80.06680298, 14.81986046], [80.06680298, 14.82014179], [80.06624603, 14.82014179], [80.06624603, 14.82042122], [80.06485748, 14.82041645], [80.06485748, 14.8206892], [80.06346893, 14.82069397], [80.06346893, 14.82097244], [80.06291962, 14.82096958], [80.06291962, 14.82124996], [80.06124878, 14.82124996], [80.06124878, 14.82096958], [80.06069183, 14.82097244], [80.06069183, 14.82069397], [80.06012726, 14.8206892], [80.06014252, 14.82041645], [80.0595932, 14.82042122], [80.0595932, 14.82014179], [80.05930328, 14.82014179], [80.05930328, 14.81986046], [80.06069183, 14.81986046], [80.06069183, 14.82014179], [80.06263733, 14.82014179], [80.06263733, 14.81986046], [80.06346893, 14.81986237], [80.06346893, 14.81958199], [80.06402588, 14.81958199], [80.06402588, 14.81930637], [80.06485748, 14.81931114], [80.06485748, 14.81902981], [80.06624603, 14.81902981], [80.06624603, 14.81875038], [80.06680298, 14.81875038], [80.06680298, 14.81846046], [80.06708527, 14.81847191], [80.06708527, 14.81819439], [80.06735992, 14.81819439], [80.06735992, 14.81791592], [80.06764221, 14.81791973], [80.06764221, 14.8176403], [80.06791687, 14.8176403], [80.06791687, 14.81708241], [80.06819153, 14.81708431], [80.06819153, 14.81680584], [80.06874847, 14.81680965], [80.06874847, 14.81653023], [80.06903076, 14.81653023], [80.06903076, 14.81624985], [80.06958008, 14.81624985], [80.06958008, 14.81596947], [80.07041931, 14.81597233], [80.07041931, 14.81569576], [80.07096863, 14.81569576], [80.07096863, 14.81541634], [80.07125092, 14.81542015], [80.07125092, 14.81513977], [80.0715332, 14.81513977], [80.0715332, 14.81431007], [80.07180786, 14.81431007], [80.07180786, 14.81402969], [80.07235718, 14.81402969], [80.07235718, 14.81374931], [80.07263947, 14.81374931], [80.07263947, 14.81347084], [80.07290649, 14.81347084], [80.07290649, 14.81319141], [80.07485962, 14.81319332], [80.07485962, 14.81291771], [80.07511139, 14.81291962], [80.07512665, 14.81242085], [80.07514191, 14.81208324], [80.07541656, 14.81208324], [80.07541656, 14.81180477], [80.07518768, 14.81180477], [80.07458496, 14.81180477], [80.07458496, 14.81208324], [80.07430267, 14.81208324], [80.07430267, 14.81180477], [80.07402802, 14.81180954], [80.07402802, 14.81153202], [80.07430267, 14.81153202], [80.07430267, 14.81069088], [80.07458496, 14.81069469], [80.07458496, 14.81041527], [80.07557678, 14.81041527], [80.07597351, 14.81041527], [80.07597351, 14.81069469], [80.07624817, 14.81069469], [80.07624817, 14.81041527], [80.07707977, 14.81042194], [80.07707977, 14.81014156], [80.07763672, 14.81014156], [80.07763672, 14.80986118], [80.07819366, 14.80986118], [80.07819366, 14.80958271], [80.07902527, 14.80958271], [80.07902527, 14.80930519], [80.07958221, 14.80931187], [80.07958221, 14.80902863], [80.08013916, 14.80902863], [80.08013916, 14.8087492], [80.08040619, 14.8087492], [80.08040619, 14.80847073], [80.08097076, 14.80847263], [80.08097076, 14.80819511], [80.08152771, 14.80819511], [80.08152771, 14.80791664], [80.08180237, 14.80791855], [80.08180237, 14.80764103], [80.08291626, 14.80764103], [80.08291626, 14.80791855], [80.08319092, 14.80791664], [80.08319092, 14.80819511], [80.08569336, 14.80819511], [80.08569336, 14.80847263], [80.08625031, 14.80847263], [80.08625031, 14.80819511], [80.08652496, 14.80819511], [80.08652496, 14.80847263], [80.08706665, 14.80847073], [80.08706665, 14.8087492], [80.08735657, 14.8087492], [80.08735657, 14.80902863], [80.08790588, 14.80902863], [80.08790588, 14.80931187], [80.08930206, 14.80930519], [80.08930206, 14.80958271], [80.09041595, 14.80958271], [80.09041595, 14.80986118], [80.0909729, 14.80986118], [80.0909729, 14.81014156], [80.09124756, 14.8101387], [80.09124756, 14.81097126], [80.09208679, 14.81097126], [80.09208679, 14.81069469], [80.09236145, 14.81069469], [80.09236145, 14.81041527], [80.0929184, 14.81042194], [80.0929184, 14.81014156], [80.09320068, 14.81014156], [80.09320068, 14.80931187], [80.0934906, 14.80931187], [80.0934906, 14.80902863], [80.09263611, 14.80902863], [80.09263611, 14.8087492], [80.09236145, 14.8087492], [80.09236145, 14.80847073], [80.09263611, 14.80847263], [80.09263611, 14.80819511], [80.0929184, 14.80819511], [80.0929184, 14.80680466], [80.09263611, 14.80681038], [80.09263611, 14.80625057], [80.0929184, 14.80625057], [80.0929184, 14.80597115], [80.09319305, 14.80597305], [80.09319305, 14.80569458], [80.0929184, 14.80569458], [80.0929184, 14.80513859], [80.09320068, 14.80514145], [80.09320068, 14.80486107], [80.0929184, 14.80486107], [80.0929184, 14.80458069], [80.09319305, 14.8045826], [80.09319305, 14.80375099], [80.0929184, 14.80375099], [80.0929184, 14.80346107], [80.09319305, 14.80347347], [80.09319305, 14.803195], [80.09347534, 14.803195], [80.09347534, 14.80263901], [80.09375, 14.80264091], [80.09375, 14.80236053], [80.09402466, 14.80236053], [80.09402466, 14.80208302], [80.09375, 14.80208302], [80.09375, 14.80152893], [80.09401703, 14.80153084], [80.09401703, 14.79957962], [80.0945816, 14.79958153], [80.0945816, 14.79930687], [80.09430695, 14.79931068], [80.09430695, 14.79846954], [80.0945816, 14.7984724], [80.0945816, 14.79680634], [80.09430695, 14.7968111], [80.09430695, 14.79625034], [80.0945816, 14.79625034], [80.0945816, 14.79568958], [80.09486389, 14.79569435], [80.09486389, 14.79541588], [80.09513855, 14.79542065], [80.09513855, 14.79514027], [80.09541321, 14.79514027], [80.09541321, 14.79347038], [80.0956955, 14.79347229], [80.0956955, 14.7929163], [80.09597015, 14.79292011], [80.09597015, 14.79096985], [80.09625244, 14.79097176], [80.09625244, 14.79014015], [80.0965271, 14.79014015], [80.0965271, 14.78931046], [80.09680176, 14.78931046], [80.09680176, 14.78903008], [80.0965271, 14.78903008], [80.0965271, 14.78819084], [80.09625244, 14.7881937], [80.09625244, 14.78763962], [80.0965271, 14.78763962], [80.0965271, 14.78735924], [80.09680176, 14.7873621], [80.09680176, 14.78680611], [80.09707642, 14.78680992], [80.09707642, 14.78597069], [80.0973587, 14.78597355], [80.0973587, 14.78486061], [80.09791565, 14.78486061], [80.09791565, 14.7840271], [80.09764099, 14.78403187], [80.09764099, 14.78375244], [80.09792328, 14.78375244], [80.09792328, 14.78264236], [80.0984726, 14.78264236], [80.0984726, 14.78208065], [80.09819794, 14.78208256], [80.09819794, 14.78180504], [80.09764099, 14.78181171], [80.09764099, 14.78152943], [80.09792328, 14.78152943], [80.09792328, 14.78069115], [80.09819794, 14.78069305], [80.09819794, 14.77930546], [80.0984726, 14.77930927], [80.0984726, 14.77902889], [80.09874725, 14.77902889], [80.09874725, 14.77847099], [80.09902954, 14.7784729], [80.09902954, 14.77763939], [80.09929657, 14.7776413], [80.09929657, 14.77707958], [80.09986115, 14.7770834], [80.09986115, 14.77625084], [80.1001358, 14.77625084], [80.1001358, 14.77569008], [80.09986115, 14.77569485], [80.09986115, 14.77513885], [80.1001358, 14.77514076], [80.1001358, 14.77431107], [80.09986115, 14.77431107], [80.09986115, 14.77347946], [80.1001358, 14.77347946], [80.1001358, 14.77292061], [80.10041809, 14.77292061], [80.10041809, 14.77264118], [80.10069275, 14.77264118], [80.10069275, 14.77181053], [80.10098267, 14.77181053], [80.10098267, 14.77097034], [80.10124969, 14.77097225], [80.10124969, 14.77041626], [80.10097504, 14.77041626], [80.10097504, 14.76986027], [80.10124969, 14.76986027], [80.10124969, 14.76930618], [80.10151672, 14.76931095], [80.10151672, 14.76819038], [80.10180664, 14.7681942], [80.10180664, 14.76735973], [80.10236359, 14.76735973], [80.10236359, 14.76708412], [80.1029129, 14.76708412], [80.1029129, 14.76624966], [80.10346985, 14.76624966], [80.10346985, 14.76541996], [80.10375214, 14.76541996], [80.10375214, 14.76486015], [80.10402679, 14.76486206], [80.10402679, 14.7640276], [80.10430908, 14.76403046], [80.10430908, 14.76318932], [80.10402679, 14.76319408], [80.10402679, 14.76264], [80.10375214, 14.76264], [80.10375214, 14.7618103], [80.10402679, 14.7618103], [80.10402679, 14.76154137], [80.10430908, 14.76154137], [80.10430908, 14.76069069], [80.10458374, 14.7606926], [80.10458374, 14.76041794], [80.1048584, 14.76042175], [80.1048584, 14.76014042], [80.10514069, 14.76014042], [80.10514069, 14.75986195], [80.1054306, 14.75986195], [80.10541534, 14.75874901], [80.10597229, 14.75875187], [80.10597229, 14.75847054], [80.10569763, 14.75847054], [80.10569763, 14.75708294], [80.10597229, 14.75708294], [80.10597229, 14.75680542], [80.10624695, 14.75681019], [80.10624695, 14.75597095], [80.10652924, 14.75597095], [80.10652924, 14.75541687], [80.10680389, 14.75541687], [80.10680389, 14.75513935], [80.10736084, 14.75513935], [80.10736084, 14.75458145], [80.10708618, 14.75458336], [80.10708618, 14.75402737], [80.10736084, 14.75402927], [80.10736084, 14.75374889], [80.10764313, 14.75374889], [80.1076355, 14.75347328], [80.10791779, 14.75347328], [80.10791779, 14.75319481], [80.10819244, 14.75319481], [80.10819244, 14.75291729], [80.1084671, 14.7529192], [80.1084671, 14.75125122], [80.10874939, 14.75125122], [80.10874939, 14.75097084], [80.10901642, 14.75097084], [80.10901642, 14.75069046], [80.10930634, 14.75069523], [80.10930634, 14.75013924], [80.10958099, 14.75014114], [80.10958099, 14.74931145], [80.11013794, 14.74931145], [80.11013794, 14.74903107], [80.11042023, 14.74903107], [80.11042023, 14.74847031], [80.11069489, 14.74847317], [80.11069489, 14.74680424], [80.11096954, 14.74681091], [80.11096954, 14.74624062], [80.11125183, 14.74625111], [80.11125183, 14.74569511], [80.11152649, 14.74569511], [80.11152649, 14.74556923], [80.11152649, 14.74402809], [80.11180878, 14.74403095], [80.11180878, 14.74374962], [80.11235809, 14.74374962], [80.11235809, 14.74403095], [80.11347198, 14.74403095], [80.11347198, 14.74374962], [80.11374664, 14.74374962], [80.11374664, 14.74318123], [80.11402893, 14.74319363], [80.11402893, 14.74291611], [80.11429596, 14.74292088], [80.11429596, 14.74263954], [80.11458588, 14.74263954], [80.11458588, 14.74207973], [80.11486053, 14.74208355], [80.11486053, 14.74180603], [80.11514282, 14.7418108], [80.11514282, 14.74153137], [80.11429596, 14.74153137], [80.11429596, 14.74013996], [80.11458588, 14.74013996], [80.11458588, 14.73958015], [80.11486053, 14.73958397], [80.11486053, 14.73763847], [80.11514282, 14.73764038], [80.11514282, 14.73430061], [80.11486053, 14.73430634], [80.11486053, 14.73208427], [80.11458588, 14.73208427], [80.11458588, 14.73124886], [80.11486053, 14.73124886], [80.11486053, 14.73097134], [80.11513519, 14.73097134], [80.11513519, 14.73069572], [80.11541748, 14.73069572], [80.11541748, 14.73097134], [80.11569214, 14.73097134], [80.11569214, 14.73153019], [80.1159668, 14.73153019], [80.1159668, 14.73236179], [80.11624908, 14.73236179], [80.11624908, 14.73291969], [80.11653137, 14.73291779], [80.11653137, 14.73347092], [80.11680603, 14.73347092], [80.11680603, 14.73402977], [80.11653137, 14.73402786], [80.11653137, 14.73569584], [80.11680603, 14.73569107], [80.11680603, 14.7365303], [80.11708069, 14.7365303], [80.11708069, 14.73680973], [80.11736298, 14.73680592], [80.11736298, 14.73708439], [80.11708069, 14.73708153], [80.11708069, 14.73737144], [80.11680603, 14.73737144], [80.11680603, 14.73764038], [80.11653137, 14.73763847], [80.11653137, 14.73819447], [80.11624908, 14.73819447], [80.11624908, 14.73847198], [80.1159668, 14.73847198], [80.1159668, 14.73875046], [80.11569214, 14.73875046], [80.11569214, 14.73931122], [80.11597443, 14.73930645], [80.11597443, 14.73958397], [80.11653137, 14.73958397], [80.11653137, 14.73930645], [80.11708069, 14.73931122], [80.11708069, 14.73903275], [80.11737061, 14.73903275], [80.11737061, 14.73847198], [80.11763763, 14.73847198], [80.11763763, 14.73791599], [80.11791992, 14.73791981], [80.11791992, 14.73737144], [80.11846924, 14.73737144], [80.11846924, 14.7365303], [80.11875153, 14.7365303], [80.11875153, 14.73596859], [80.11902618, 14.7359724], [80.11902618, 14.73569584], [80.11958313, 14.73569584], [80.11958313, 14.73513985], [80.12014008, 14.73513985], [80.12014008, 14.73485947], [80.12041473, 14.73486233], [80.12041473, 14.73430634], [80.12097168, 14.73430634], [80.12097168, 14.73402786], [80.12124634, 14.73402977], [80.12124634, 14.73375034], [80.12152863, 14.73375034], [80.12152863, 14.73347092], [80.12180328, 14.73347092], [80.12180328, 14.7331934], [80.12208557, 14.7331934], [80.12208557, 14.73291779], [80.12236023, 14.73291969], [80.12236023, 14.73236179], [80.12264252, 14.73236179], [80.12264252, 14.73208141], [80.12291718, 14.73208427], [80.12291718, 14.73180485], [80.12317657, 14.73180962], [80.12317657, 14.73153019], [80.12346649, 14.73153019], [80.12346649, 14.73124027], [80.12374878, 14.73124886], [80.12374878, 14.73069572], [80.12403107, 14.73069572], [80.12403107, 14.73041534], [80.12458038, 14.73042202], [80.12458038, 14.73014164], [80.12541962, 14.73014164], [80.12541962, 14.72874928], [80.12568665, 14.72874928], [80.12568665, 14.72846889], [80.12596893, 14.7284708], [80.12596893, 14.72819519], [80.12623596, 14.72819996], [80.12623596, 14.72791958], [80.12652588, 14.72791958], [80.12652588, 14.72625065], [80.12680817, 14.72625065], [80.12680817, 14.72597122], [80.12708282, 14.72597313], [80.12708282, 14.72569466], [80.12735748, 14.72569466], [80.12735748, 14.72513866], [80.12763977, 14.72514057], [80.12763977, 14.72486115], [80.12819672, 14.72486115], [80.12819672, 14.72458267], [80.12847137, 14.72458267], [80.12847137, 14.72430515], [80.12902832, 14.72431183], [80.12902832, 14.72375107], [80.12931061, 14.72375107], [80.12931061, 14.72347069], [80.12985992, 14.7234726], [80.12985992, 14.7229166], [80.13014221, 14.72292137], [80.13014221, 14.72236061], [80.13041687, 14.72236061], [80.13041687, 14.72208023], [80.13069153, 14.72208309], [80.13069153, 14.72152901], [80.13096619, 14.72153091], [80.13096619, 14.72097015], [80.13124847, 14.72097301], [80.13124847, 14.72069454], [80.13153076, 14.72069454], [80.13153076, 14.72013855], [80.13208008, 14.72014141], [80.13208008, 14.71986008], [80.13237, 14.71986008], [80.13236237, 14.7195816], [80.13263702, 14.7195816], [80.13263702, 14.71902943], [80.13291931, 14.71903133], [80.13291931, 14.71764088], [80.13318634, 14.71764088], [80.13318634, 14.71735954], [80.13346863, 14.71736336], [80.13346863, 14.71652794], [80.13375092, 14.7165308], [80.13375092, 14.71597004], [80.13402557, 14.71597195], [80.13402557, 14.71541595], [80.13430786, 14.71542072], [80.13430786, 14.71485996], [80.13458252, 14.71485996], [80.13458252, 14.71457958], [80.13486481, 14.71458435], [80.13486481, 14.71430588], [80.13513947, 14.71431065], [80.13513947, 14.71403027], [80.13540649, 14.71403027], [80.13540649, 14.71347046], [80.13513947, 14.71347237], [80.13513947, 14.71208191], [80.13541412, 14.71208191], [80.13541412, 14.71236229], [80.13597107, 14.71236229], [80.13597107, 14.71125031], [80.13652802, 14.71125031], [80.13652802, 14.71069241], [80.13680267, 14.71069431], [80.13680267, 14.71041584], [80.13652802, 14.71041965], [80.13652802, 14.70903015], [80.13680267, 14.70903015], [80.13680267, 14.70819092], [80.13652802, 14.70819378], [80.13652802, 14.70736217], [80.13680267, 14.70736217], [80.13680267, 14.70680618], [80.13707733, 14.70681], [80.13707733, 14.70625019], [80.13735962, 14.70625019], [80.13735962, 14.70597076], [80.13791656, 14.70597076], [80.13791656, 14.70569324], [80.13819122, 14.70569324], [80.13819122, 14.70486164], [80.13791656, 14.70486164], [80.13791656, 14.70403194], [80.13764191, 14.70403194], [80.13764191, 14.70347118], [80.13735962, 14.70347118], [80.13735962, 14.7029171], [80.13707733, 14.70292187], [80.13707733, 14.70264244], [80.13680267, 14.70264244], [80.13680267, 14.70208073], [80.13652802, 14.70208263], [80.13652802, 14.70124912], [80.13625336, 14.70125961], [80.13625336, 14.70097065], [80.13569641, 14.70097256], [80.13569641, 14.70041656], [80.13540649, 14.70041943], [80.13540649, 14.70014095], [80.13513947, 14.70014095], [80.13513947, 14.69958115], [80.13486481, 14.69958305], [80.13486481, 14.69930458], [80.13458252, 14.6993103], [80.13458252, 14.69847107], [80.13430786, 14.69847298], [80.13430786, 14.69819546], [80.1340332, 14.69820023], [80.1340332, 14.69791889], [80.13375092, 14.69791889], [80.13375092, 14.69736099], [80.13346863, 14.69736099], [80.13346863, 14.69625092], [80.13318634, 14.69625092], [80.13318634, 14.6957016], [80.13291931, 14.69569016], [80.13291931, 14.69513893], [80.13236237, 14.69513893], [80.13236237, 14.69486141], [80.13208008, 14.69486141], [80.13208008, 14.69458294], [80.13180542, 14.69458294], [80.13180542, 14.69402885], [80.13124847, 14.69403076], [80.13124847, 14.69375134], [80.13096619, 14.69375134], [80.13096619, 14.69347], [80.13069153, 14.69347286], [80.13069153, 14.69319534], [80.13041687, 14.69319534], [80.13041687, 14.69291687], [80.12985992, 14.69292068], [80.12985992, 14.69264126], [80.12960052, 14.69264126], [80.12960052, 14.69207096], [80.13014221, 14.69208241], [80.13014221, 14.69180679], [80.13041687, 14.69180679], [80.13041687, 14.69208241], [80.13124847, 14.69207096], [80.13124847, 14.69235992], [80.13181305, 14.69235992], [80.13181305, 14.69264126], [80.13237, 14.69264126], [80.13237, 14.69235992], [80.13263702, 14.69235992], [80.13263702, 14.69207096], [80.13318634, 14.69207096], [80.13318634, 14.69235992], [80.1340332, 14.69235992], [80.1340332, 14.69264126], [80.13430786, 14.69264126], [80.13430786, 14.69292068], [80.13458252, 14.69291687], [80.13458252, 14.69458294], [80.13485718, 14.69458008], [80.13485718, 14.69542122], [80.13513947, 14.6954174], [80.13513947, 14.6959734], [80.13540649, 14.69597054], [80.13540649, 14.69625092], [80.13569641, 14.69625092], [80.13569641, 14.6965313], [80.13597107, 14.6965313], [80.13597107, 14.69681168], [80.13569641, 14.69681168], [80.13569641, 14.69791889], [80.13597107, 14.69791889], [80.13597107, 14.69820023], [80.13625336, 14.69820023], [80.13625336, 14.69875145], [80.13680267, 14.69875145], [80.13680267, 14.69903088], [80.13707733, 14.69903088], [80.13707733, 14.6993103], [80.13735962, 14.69930458], [80.13735962, 14.69986057], [80.13764191, 14.69986057], [80.13764191, 14.70041943], [80.13791656, 14.70041656], [80.13791656, 14.70097256], [80.13846588, 14.70097065], [80.13846588, 14.70125961], [80.13874817, 14.70125961], [80.13874817, 14.70152855], [80.13903046, 14.70152664], [80.13903046, 14.70236111], [80.13931274, 14.7023592], [80.13931274, 14.70264244], [80.13957977, 14.70264244], [80.13957977, 14.70292187], [80.13986206, 14.7029171], [80.13986206, 14.70319462], [80.14013672, 14.70319462], [80.14013672, 14.70597363], [80.13986206, 14.70597076], [80.13986206, 14.70652962], [80.13957977, 14.70652771], [80.13957977, 14.70819378], [80.13931274, 14.70819092], [80.13931274, 14.70930958], [80.13903046, 14.70930958], [80.13903046, 14.71041965], [80.13874817, 14.71041584], [80.13874817, 14.71097183], [80.13846588, 14.71097183], [80.13846588, 14.71181107], [80.13819122, 14.7118063], [80.13819122, 14.71236229], [80.13791656, 14.71236038], [80.13791656, 14.71292114], [80.13764191, 14.71291637], [80.13764191, 14.71347237], [80.13735962, 14.71347046], [80.13735962, 14.71403027], [80.13708496, 14.71402836], [80.13708496, 14.71458435], [80.13680267, 14.71457958], [80.13680267, 14.71485996], [80.13652802, 14.71485996], [80.13652802, 14.71597195], [80.13625336, 14.71597004], [80.13625336, 14.7165308], [80.13597107, 14.71652794], [80.13597107, 14.71708202], [80.13569641, 14.71708012], [80.13569641, 14.71764088], [80.13541412, 14.71763802], [80.13541412, 14.71819401], [80.13513947, 14.71819019], [80.13513947, 14.71875095], [80.13569641, 14.71875095], [80.13569641, 14.71846962], [80.13597107, 14.71847343], [80.13597107, 14.71791553], [80.13625336, 14.71792126], [80.13625336, 14.71764088], [80.13652802, 14.71764088], [80.13652802, 14.71735954], [80.13680267, 14.71736336], [80.13680267, 14.71680641], [80.13707733, 14.71681118], [80.13707733, 14.7165308], [80.13735962, 14.7165308], [80.13735962, 14.71626186], [80.13764191, 14.71626186], [80.13764191, 14.71597004], [80.13791656, 14.71597195], [80.13791656, 14.71541595], [80.13817596, 14.71542072], [80.13817596, 14.71514034], [80.13846588, 14.71514034], [80.13846588, 14.71457958], [80.13874817, 14.71458435], [80.13874817, 14.71347237], [80.13903046, 14.71347237], [80.13903046, 14.71236229], [80.13930511, 14.71236229], [80.13930511, 14.71125031], [80.13957977, 14.71125031], [80.13957977, 14.71014023], [80.13986206, 14.71014023], [80.13986206, 14.70957947], [80.14013672, 14.70958424], [80.14013672, 14.70930576], [80.14125061, 14.70930958], [80.14125061, 14.70874977], [80.14154053, 14.70874977], [80.14154053, 14.70819092], [80.14180756, 14.70819378], [80.14180756, 14.70625019], [80.14208221, 14.70625019], [80.14208221, 14.70541954], [80.14235687, 14.70541954], [80.14235687, 14.70458126], [80.14263916, 14.70458317], [80.14263916, 14.7037487], [80.14290619, 14.70375156], [80.14290619, 14.70292187], [80.14319611, 14.70292187], [80.14319611, 14.70208073], [80.14347076, 14.70208263], [80.14347076, 14.70152664], [80.14375305, 14.70152855], [80.14375305, 14.70069122], [80.14402771, 14.70069313], [80.14402771, 14.70013905], [80.14431, 14.70014095], [80.14431, 14.69958115], [80.14458466, 14.69958305], [80.14458466, 14.69902706], [80.14485931, 14.69903088], [80.14485931, 14.69875145], [80.14457703, 14.69875145], [80.14457703, 14.69820023], [80.14431, 14.69820023], [80.14431, 14.69708061], [80.14458466, 14.69708347], [80.14458466, 14.69652653], [80.14485931, 14.6965313], [80.14485931, 14.69569016], [80.1451416, 14.69569492], [80.1451416, 14.69513893], [80.14541626, 14.69513893], [80.14541626, 14.69263935], [80.1451416, 14.69264126], [80.1451416, 14.69207096], [80.14569092, 14.69208241], [80.14569092, 14.69152641], [80.14597321, 14.69153118], [80.14597321, 14.69069195], [80.14624786, 14.69069386], [80.14624786, 14.68986034], [80.14653015, 14.68986034], [80.14653015, 14.68902779], [80.14679718, 14.68903065], [80.14679718, 14.68819046], [80.1470871, 14.68819427], [80.1470871, 14.68764019], [80.1473465, 14.68764019], [80.1473465, 14.68736172], [80.1470871, 14.68736172], [80.1470871, 14.68681145], [80.14679718, 14.68681145], [80.14679718, 14.68624973], [80.1470871, 14.68624973], [80.1470871, 14.68569183], [80.14736176, 14.68569374], [80.14736176, 14.68513775], [80.14763641, 14.68513966], [80.14763641, 14.6845789], [80.1479187, 14.68458366], [80.1479187, 14.68347168], [80.14819336, 14.68347168], [80.14819336, 14.68264008], [80.14848328, 14.68264008], [80.14848328, 14.68153], [80.14875031, 14.68153], [80.14875031, 14.68041992], [80.14901733, 14.68041992], [80.14901733, 14.67931175], [80.14930725, 14.67931175], [80.14930725, 14.67847061], [80.1498642, 14.67847061], [80.1498642, 14.67791843], [80.15013885, 14.67792034], [80.15013885, 14.67736053], [80.15041351, 14.67736053], [80.15041351, 14.67680454], [80.15013885, 14.67681026], [80.15013885, 14.67569065], [80.15041351, 14.67569542], [80.15041351, 14.67486095], [80.15097046, 14.67486095], [80.15097046, 14.67402935], [80.1506958, 14.67402935], [80.1506958, 14.67347145], [80.15041351, 14.67347336], [80.15041351, 14.67291737], [80.1506958, 14.67291927], [80.1506958, 14.67263889], [80.15125275, 14.67263889], [80.15125275, 14.67236137], [80.1515274, 14.67236137], [80.1515274, 14.6712513], [80.15180206, 14.6712513], [80.15180206, 14.67068958], [80.1515274, 14.6706953], [80.1515274, 14.67041683], [80.15180206, 14.67042065], [80.15180206, 14.66903114], [80.15207672, 14.66903114], [80.15207672, 14.66819], [80.15235901, 14.66819477], [80.15235901, 14.66791725], [80.1526413, 14.66792107], [80.1526413, 14.66764069], [80.15235901, 14.66764069], [80.15235901, 14.66736126], [80.1526413, 14.66736126], [80.1526413, 14.66625118], [80.15291595, 14.66625118], [80.15291595, 14.66569042], [80.15319061, 14.66569519], [80.15319824, 14.66541672], [80.15348053, 14.66542053], [80.15348053, 14.66431141], [80.15374756, 14.66431141], [80.15374756, 14.66209126], [80.15402985, 14.66209126], [80.15402985, 14.66125011], [80.15429687, 14.66125011], [80.15429687, 14.65931129], [80.15486145, 14.65931129], [80.15486145, 14.65819168], [80.15513611, 14.65819359], [80.15513611, 14.65791798], [80.1554184, 14.65792274], [80.1554184, 14.65764046], [80.15569305, 14.65764046], [80.15569305, 14.65736198], [80.15598297, 14.65736198], [80.15597534, 14.65625], [80.15625, 14.65625], [80.15625, 14.65568924], [80.15597534, 14.65569401], [80.15597534, 14.65513992], [80.15625, 14.65513992], [80.15625, 14.65485954], [80.15652466, 14.6548624], [80.15652466, 14.65375042], [80.15625, 14.65375042], [80.15625, 14.65264034], [80.15651703, 14.65264034], [80.15651703, 14.65208054], [80.1570816, 14.65208435], [80.1570816, 14.65180588], [80.15625, 14.65180969], [80.15625, 14.65125179], [80.15651703, 14.65125179], [80.15651703, 14.65015125], [80.15680695, 14.65015125], [80.15680695, 14.64903164], [80.1570816, 14.64903164], [80.1570816, 14.64819145], [80.15736389, 14.64819527], [80.15736389, 14.64708328], [80.15763855, 14.64708328], [80.15763855, 14.64624882], [80.15791321, 14.64625072], [80.15791321, 14.64514065], [80.15820313, 14.64514065], [80.15820313, 14.64402008], [80.15847015, 14.64402676], [80.15847015, 14.64319515], [80.15875244, 14.64319515], [80.15875244, 14.64236069], [80.1590271, 14.64236069], [80.1590271, 14.64153099], [80.1592865, 14.64153099], [80.1592865, 14.64068985], [80.15958405, 14.64069462], [80.15958405, 14.64013863], [80.1598587, 14.64014053], [80.1598587, 14.63931084], [80.16014099, 14.63931084], [80.16014099, 14.6384697], [80.16041565, 14.63847256], [80.16041565, 14.63763809], [80.16069794, 14.63764095], [80.16069794, 14.63681126], [80.1609726, 14.63681126], [80.1609726, 14.63597012], [80.16124725, 14.63597202], [80.16124725, 14.63541603], [80.16152954, 14.6354208], [80.16152954, 14.63457966], [80.1618042, 14.63458443], [80.1618042, 14.63374996], [80.16208649, 14.63374996], [80.16208649, 14.63292122], [80.16234589, 14.63292122], [80.16234589, 14.63208199], [80.1626358, 14.63208199], [80.1626358, 14.63125038], [80.16291809, 14.63125038], [80.16291809, 14.63069153], [80.16319275, 14.63069439], [80.16319275, 14.62986183], [80.16348267, 14.62986183], [80.16347504, 14.62930584], [80.16374969, 14.62930965], [80.16374969, 14.62846947], [80.16402435, 14.62847233], [80.16402435, 14.62791634], [80.16430664, 14.62792015], [80.16430664, 14.62708092], [80.1645813, 14.62708378], [80.1645813, 14.62625027], [80.16485596, 14.62625027], [80.16485596, 14.62569141], [80.16513824, 14.62569332], [80.16513824, 14.62486172], [80.16542053, 14.62486172], [80.1654129, 14.62402725], [80.16570282, 14.62403202], [80.16570282, 14.62347126], [80.16596985, 14.62347126], [80.16596985, 14.6226387], [80.16625214, 14.62264156], [80.16625214, 14.62180996], [80.16652679, 14.62180996], [80.16652679, 14.6212492], [80.16680908, 14.6212492], [80.16680908, 14.6206913], [80.16708374, 14.62069321], [80.16708374, 14.62013912], [80.1673584, 14.62014103], [80.1673584, 14.61958122], [80.16764069, 14.61958313], [80.16764069, 14.61902714], [80.16792297, 14.61903191], [80.16792297, 14.61847115], [80.16819763, 14.61847305], [80.16819763, 14.61791706], [80.16847992, 14.61792183], [80.16847992, 14.61736107], [80.16874695, 14.61736107], [80.16874695, 14.61681175], [80.16902924, 14.61681175], [80.16902924, 14.61625099], [80.16929626, 14.61625099], [80.16929626, 14.61597061], [80.16958618, 14.61597347], [80.16958618, 14.61541653], [80.16986084, 14.6154213], [80.16986084, 14.61486053], [80.1701355, 14.61486053], [80.1701355, 14.61430454], [80.17041779, 14.61430931], [80.17041779, 14.61375141], [80.17069244, 14.61375141], [80.17069244, 14.6131897], [80.17097473, 14.61319542], [80.17097473, 14.61263943], [80.17124939, 14.61264133], [80.17124939, 14.61207962], [80.17152405, 14.61208153], [80.17152405, 14.61180687], [80.17180634, 14.61181068], [80.17180634, 14.61125088], [80.17208099, 14.61125088], [80.17208099, 14.60958004], [80.17236328, 14.60958195], [80.17236328, 14.60930634], [80.17263794, 14.6093111], [80.17263794, 14.60903072], [80.17318726, 14.60903072], [80.17318726, 14.60875034], [80.17346954, 14.60875034], [80.17346954, 14.60846996], [80.17375183, 14.60847187], [80.17375183, 14.60819435], [80.17402649, 14.60819435], [80.17402649, 14.60791588], [80.17458344, 14.60791588], [80.17458344, 14.60764027], [80.17485809, 14.60764027], [80.17485809, 14.60736179], [80.17514038, 14.60736179], [80.17514038, 14.60708046], [80.17541504, 14.60708427], [80.17541504, 14.6068058], [80.17597198, 14.60681057], [80.17597198, 14.60653019], [80.17624664, 14.60653019], [80.17624664, 14.60625172], [80.17679596, 14.60625172], [80.17679596, 14.60597038], [80.17708588, 14.60597229], [80.17708588, 14.60569382], [80.17763519, 14.60569382], [80.17763519, 14.6054163], [80.17791748, 14.60542107], [80.17791748, 14.60513973], [80.1784668, 14.60513973], [80.1784668, 14.6048708], [80.17903137, 14.6048708], [80.17903137, 14.60458183], [80.17930603, 14.60458374], [80.17930603, 14.60430622], [80.17986298, 14.60431099], [80.17986298, 14.60402966], [80.18041992, 14.60402966], [80.18041992, 14.60375023], [80.18096924, 14.60375023], [80.18096924, 14.60346985], [80.18152618, 14.60347176], [80.18152618, 14.60319424], [80.18208313, 14.60319424], [80.18208313, 14.60291576], [80.18235779, 14.60291958], [80.18235779, 14.60264015], [80.1829071, 14.60264015], [80.1829071, 14.60235977], [80.18345642, 14.60235977], [80.18345642, 14.60207939], [80.18430328, 14.60208416], [80.18430328, 14.60180569], [80.18541718, 14.60181046], [80.18541718, 14.60153008], [80.18596649, 14.60153008], [80.18596649, 14.60124969], [80.18681335, 14.60124969], [80.18681335, 14.60096931], [80.18736267, 14.60097218], [80.18736267, 14.6006937], [80.18763733, 14.6006937], [80.18763733, 14.60041809], [80.18791962, 14.60042], [80.18791962, 14.60013962], [80.18818665, 14.60013962], [80.18818665, 14.60042], [80.18930817, 14.60041809], [80.18930817, 14.6006937], [80.19041443, 14.6006937], [80.19041443, 14.60097218], [80.19180298, 14.60097218], [80.19180298, 14.6006937], [80.19235992, 14.6006937], [80.19235992, 14.60041809], [80.19264984, 14.60042], [80.19264984, 14.60013962], [80.19291687, 14.60013962], [80.19291687, 14.59985924], [80.19319153, 14.5998621], [80.19319153, 14.59930611], [80.19346619, 14.59930992], [80.19346619, 14.59875202], [80.19374847, 14.59875202], [80.19374847, 14.59847069], [80.19403076, 14.59847355], [80.19403076, 14.59819317], [80.19430542, 14.59819317], [80.19430542, 14.59764004], [80.19458008, 14.59764194], [80.19458008, 14.59681034], [80.19486237, 14.59681034], [80.19486237, 14.59513855], [80.19513702, 14.59513855], [80.19513702, 14.59486103], [80.19625092, 14.59486103], [80.19625092, 14.59458065], [80.19652557, 14.59458256], [80.19652557, 14.59430504], [80.19680786, 14.59431171], [80.19680786, 14.59402943], [80.19708252, 14.59402943], [80.19708252, 14.59319115], [80.19736481, 14.59319305], [80.19736481, 14.59013939], [80.19763947, 14.5901413], [80.19763947, 14.58958054], [80.19791412, 14.5895834], [80.19791412, 14.58847332], [80.19819641, 14.58847332], [80.19819641, 14.58791733], [80.19845581, 14.58791924], [80.19845581, 14.58764076], [80.19875336, 14.58764076], [80.19875336, 14.58708], [80.19902802, 14.58708286], [80.19902802, 14.5840292], [80.19875336, 14.58403111], [80.19875336, 14.58373928], [80.19819641, 14.58375072], [80.19819641, 14.58347225], [80.19791412, 14.58347225], [80.19791412, 14.58291626], [80.19763947, 14.58292103], [80.19763947, 14.58236027], [80.19736481, 14.58236027], [80.19736481, 14.5820837], [80.19763947, 14.5820837], [80.19763947, 14.58180428], [80.19790649, 14.58181095], [80.19790649, 14.58068085], [80.19763947, 14.5806942], [80.19763947, 14.57958412], [80.19736481, 14.57958412], [80.19736481, 14.57930565], [80.19708252, 14.57931137], [80.19706726, 14.57820129], [80.19680786, 14.5781889], [80.19680786, 14.57806015], [80.19680786, 14.57680607], [80.1965332, 14.57681274], [80.1965332, 14.57653046], [80.19625092, 14.57653046], [80.19625092, 14.57625198], [80.19596863, 14.57625198], [80.19596863, 14.57568932], [80.19569397, 14.57569408], [80.19569397, 14.57374954], [80.19541931, 14.57374954], [80.19541931, 14.57291985], [80.19513702, 14.57291985], [80.19513702, 14.57180119], [80.19486237, 14.57180595], [80.19486237, 14.57097054], [80.19458008, 14.57097054], [80.19458008, 14.57013988], [80.19431305, 14.57014179], [80.19431305, 14.56931019], [80.19403076, 14.56931019], [80.19403076, 14.56819057], [80.19374847, 14.56819534], [80.19374847, 14.56736088], [80.19346619, 14.56736088], [80.19346619, 14.56652927], [80.19319153, 14.56652927], [80.19319153, 14.56597137], [80.19291687, 14.56597328], [80.19291687, 14.56541729], [80.19264984, 14.5654192], [80.19264984, 14.5648613], [80.19235992, 14.5648613], [80.19235992, 14.56375122], [80.19208527, 14.56375122], [80.19208527, 14.56291676], [80.19180298, 14.56293106], [80.19180298, 14.5618124], [80.19152832, 14.5618124], [80.19152832, 14.56068993], [80.19125366, 14.56069469], [80.19125366, 14.55930519], [80.19097137, 14.55931091], [80.19097137, 14.55819035], [80.19069672, 14.55819511], [80.19069672, 14.55736256], [80.19041443, 14.5573597], [80.1904068, 14.55708027], [80.19013977, 14.55708218], [80.19013977, 14.55680656], [80.18958282, 14.55680656], [80.18958282, 14.55652905], [80.18930817, 14.55653095], [80.18930817, 14.55624962], [80.18902588, 14.55624962], [80.18902588, 14.55569172], [80.18875122, 14.55569363], [80.18875122, 14.55458355], [80.18846893, 14.55458355], [80.18846893, 14.55319405], [80.18819427, 14.55319405], [80.18819427, 14.55208206], [80.18791962, 14.55208206], [80.18791962, 14.55069447], [80.18763733, 14.55070114], [80.18763733, 14.54957867], [80.18736267, 14.54958439], [80.18736267, 14.5484724], [80.18708038, 14.5484724], [80.18708038, 14.54763985], [80.18680573, 14.54763985], [80.18680573, 14.54652786], [80.18651581, 14.54652977], [80.18651581, 14.54569054], [80.18624878, 14.54569435], [80.18624878, 14.54486179], [80.18596649, 14.54486179], [80.18596649, 14.54375172], [80.18569183, 14.54375172], [80.18569183, 14.54292202], [80.18541718, 14.54292202], [80.18541718, 14.54208088], [80.18514252, 14.54208279], [80.18514252, 14.54097271], [80.18486023, 14.5409708], [80.18486023, 14.5401392], [80.1845932, 14.5401392], [80.1845932, 14.53931046], [80.18430328, 14.53931046], [80.18430328, 14.53819275], [80.18402863, 14.53819466], [80.18402863, 14.53736115], [80.18374634, 14.53736115], [80.18374634, 14.53680515], [80.18345642, 14.53681183], [80.18345642, 14.53653145], [80.18319702, 14.53653145], [80.18319702, 14.53625107], [80.1829071, 14.53625107], [80.1829071, 14.53597069], [80.18264008, 14.5359726], [80.18264008, 14.53569508], [80.18235779, 14.53569508], [80.18235779, 14.5354166], [80.18208313, 14.53542137], [80.18208313, 14.53514099], [80.17914581, 14.53514099], [80.17874908, 14.53514099], [80.17874908, 14.53486061], [80.17847443, 14.53486061], [80.17847443, 14.53458309], [80.17791748, 14.53458309], [80.17791748, 14.53430462], [80.17764282, 14.53430939], [80.17764282, 14.53403091], [80.17708588, 14.53403091], [80.17708588, 14.53375053], [80.17679596, 14.53375053], [80.17679596, 14.53347111], [80.17624664, 14.53347301], [80.17624664, 14.53319454], [80.17542267, 14.53318977], [80.17542267, 14.53375053], [80.17514038, 14.53375053], [80.17514038, 14.53403091], [80.17485809, 14.53402901], [80.17485809, 14.53458309], [80.17457581, 14.53458023], [80.17457581, 14.53514099], [80.17430878, 14.53514099], [80.17430878, 14.53542137], [80.17402649, 14.5354166], [80.17402649, 14.53569508], [80.17263794, 14.53569508], [80.17263794, 14.53513908], [80.17236328, 14.53514099], [80.17236328, 14.53458023], [80.17263794, 14.53458309], [80.17263794, 14.53374863], [80.17292023, 14.53375053], [80.17292023, 14.53263187], [80.17319489, 14.53263855], [80.17319489, 14.53208256], [80.17346954, 14.53208256], [80.17346954, 14.53180695], [80.17402649, 14.53181076], [80.17402649, 14.53153133], [80.17652893, 14.53153133], [80.17652893, 14.53181076], [80.17819214, 14.53180695], [80.17819214, 14.53208256], [80.1784668, 14.5320797], [80.1784668, 14.53236103], [80.17874908, 14.53236103], [80.17874908, 14.53263855], [80.17903137, 14.53263855], [80.17903137, 14.53319454], [80.17930603, 14.53319454], [80.17930603, 14.53347301], [80.17958069, 14.53347111], [80.17958069, 14.53375053], [80.18068695, 14.53375053], [80.18068695, 14.53347111], [80.18096924, 14.53347301], [80.18096924, 14.53319454], [80.18125153, 14.53319454], [80.18125153, 14.53291702], [80.18152618, 14.53292084], [80.18152618, 14.53236103], [80.18180847, 14.53236103], [80.18180847, 14.53181076], [80.18208313, 14.53181076], [80.18208313, 14.53153133], [80.18264008, 14.53153133], [80.18264008, 14.53042126], [80.18235779, 14.53042126], [80.18235779, 14.52875042], [80.18208313, 14.52875042], [80.18208313, 14.52735996], [80.18180847, 14.52735996], [80.18180847, 14.52514267], [80.18152618, 14.52514267], [80.18152618, 14.52346134], [80.18125153, 14.52347183], [80.18125153, 14.52152824], [80.18096924, 14.52153015], [80.18096924, 14.51958084], [80.18069458, 14.5195837], [80.18069458, 14.51791763], [80.18041992, 14.51791954], [80.18041992, 14.51597118], [80.18013763, 14.51597118], [80.18013763, 14.51402664], [80.17986298, 14.51402855], [80.17986298, 14.51236057], [80.17958069, 14.51236057], [80.17958069, 14.50958347], [80.17930603, 14.50958347], [80.17930603, 14.50569534], [80.17903137, 14.50569534], [80.17903137, 14.50180435], [80.17874908, 14.50181103], [80.17874908, 14.49792099], [80.1784668, 14.49792099], [80.1784668, 14.49403], [80.17819214, 14.49403], [80.17819214, 14.49069118], [80.17791748, 14.49069309], [80.17791748, 14.48736095], [80.17763519, 14.48736095], [80.17763519, 14.48430538], [80.17736053, 14.48431015], [80.17736053, 14.48125076], [80.17708588, 14.48125076], [80.17708588, 14.47792053], [80.17679596, 14.47792053], [80.17679596, 14.47486019], [80.17652893, 14.47486019], [80.17652893, 14.47097206], [80.17624664, 14.47097206], [80.17624664, 14.46597195], [80.17597198, 14.46597195], [80.17597198, 14.46097088], [80.17569733, 14.46097088], [80.17569733, 14.45625114], [80.17541504, 14.45625114], [80.17541504, 14.45125103], [80.17514038, 14.45125103], [80.17514038, 14.44707966], [80.17485809, 14.44708443], [80.17485809, 14.44375038], [80.17457581, 14.44375038], [80.17457581, 14.44042015], [80.17430878, 14.44042015], [80.17430878, 14.43708134], [80.17402649, 14.4370842], [80.17402649, 14.4337492], [80.17375183, 14.4337492], [80.17375183, 14.43043137], [80.17346954, 14.43043137], [80.17346954, 14.4256897], [80.17319489, 14.42569542], [80.17319489, 14.41958427], [80.17292023, 14.41958427], [80.17292023, 14.41291809], [80.17263794, 14.41292], [80.17263794, 14.40569115], [80.17236328, 14.40569305], [80.17236328, 14.39013767], [80.17208099, 14.39013958], [80.17208099, 14.38735962], [80.17236328, 14.38736153], [80.17236328, 14.38624954], [80.17180634, 14.38624954], [80.17180634, 14.38486195], [80.17208099, 14.38486195], [80.17208099, 14.38264179], [80.17180634, 14.38264179], [80.17180634, 14.38097095], [80.17152405, 14.38097095], [80.17152405, 14.37930489], [80.17124939, 14.3793211], [80.17124939, 14.37764072], [80.1709671, 14.37764072], [80.1709671, 14.37597084], [80.17069244, 14.37597084], [80.17069244, 14.37458134], [80.17041779, 14.37458324], [80.17041779, 14.37069511], [80.17097473, 14.37069511], [80.17097473, 14.37013912], [80.17041779, 14.37013912], [80.17041779, 14.36958218], [80.1701355, 14.36958218], [80.1701355, 14.36458206], [80.16986084, 14.36458206], [80.16986084, 14.36069393], [80.16958618, 14.36069393], [80.16958618, 14.35958385], [80.16930389, 14.35958385], [80.16930389, 14.35902786], [80.16958618, 14.35902977], [80.16958618, 14.35875034], [80.16929626, 14.35875034], [80.16929626, 14.35819054], [80.16902924, 14.35819435], [80.16902924, 14.35708427], [80.16874695, 14.35708427], [80.16874695, 14.35569572], [80.16847229, 14.35569572], [80.16847229, 14.35430527], [80.16819763, 14.35431004], [80.16819763, 14.35374928], [80.16847992, 14.35374928], [80.16847229, 14.35319328], [80.16819763, 14.35319328], [80.16819763, 14.35236073], [80.16791534, 14.35236073], [80.16791534, 14.35180473], [80.16764069, 14.35181046], [80.16764069, 14.35014057], [80.1673584, 14.35014057], [80.1673584, 14.3495779], [80.16708374, 14.34958267], [80.16708374, 14.34902668], [80.16680908, 14.34902668], [80.16680908, 14.34819508], [80.16652679, 14.34819508], [80.16652679, 14.34763908], [80.16625214, 14.34764099], [80.16625214, 14.34680939], [80.16596985, 14.34680939], [80.16596985, 14.34486103], [80.16569519, 14.34486103], [80.16569519, 14.34458256], [80.1654129, 14.34458256], [80.1654129, 14.34347343], [80.16569519, 14.34347343], [80.16569519, 14.34291744], [80.16542053, 14.34292126], [80.16542053, 14.34235954], [80.16513824, 14.34235954], [80.16513824, 14.34180737], [80.16485596, 14.34181118], [80.16485596, 14.34042072], [80.1645813, 14.34042072], [80.1645813, 14.34015179], [80.16430664, 14.34015179], [80.16430664, 14.33985996], [80.16401672, 14.33985996], [80.16401672, 14.33903122], [80.16374969, 14.33903122], [80.16374969, 14.33847046], [80.16347504, 14.33847237], [80.16347504, 14.33791637], [80.16319275, 14.33792114], [80.16319275, 14.33736038], [80.16291809, 14.33736229], [80.16291809, 14.33652782], [80.1626358, 14.33652973], [80.1626358, 14.33597183], [80.16236115, 14.33597183], [80.16236115, 14.33541584], [80.16208649, 14.33541965], [80.16208649, 14.33485985], [80.16160583, 14.33485985], [80.16124725, 14.33485985], [80.16124725, 14.33402061], [80.16124725, 14.33374977], [80.16107178, 14.33374977], [80.1609726, 14.33374977], [80.1609726, 14.33360195], [80.1609726, 14.33319378], [80.16069794, 14.33319378], [80.16069794, 14.33236217], [80.16041565, 14.33236217], [80.16041565, 14.33180618], [80.16014099, 14.33181], [80.16014099, 14.33125019], [80.1598587, 14.33125019], [80.1598587, 14.33041954], [80.15957642, 14.33041954], [80.15957642, 14.32986164], [80.1592865, 14.32986164], [80.1592865, 14.32931042], [80.1590271, 14.32931042], [80.1590271, 14.32846928], [80.15875244, 14.32847118], [80.15875244, 14.32791805], [80.15847015, 14.32791996], [80.15847015, 14.3273592], [80.1581955, 14.32736111], [80.1581955, 14.32708263], [80.15791321, 14.32708263], [80.15791321, 14.32680511], [80.15763855, 14.32681179], [80.15763855, 14.32597065], [80.15736389, 14.32597256], [80.15736389, 14.32541656], [80.1570816, 14.32542038], [80.1570816, 14.32485199], [80.15680695, 14.32486057], [80.15680695, 14.32402706], [80.15651703, 14.32403183], [80.15651703, 14.32347107], [80.15625, 14.32347107], [80.15625, 14.32291698], [80.15598297, 14.32292175], [80.15598297, 14.32208061], [80.15569305, 14.32208347], [80.15569305, 14.32152653], [80.1554184, 14.3215313], [80.1554184, 14.32097054], [80.15513611, 14.3209734], [80.15513611, 14.32013893], [80.15486145, 14.32014084], [80.15486145, 14.31958008], [80.15458679, 14.31958294], [80.15458679, 14.31875134], [80.15429687, 14.31875134], [80.15429687, 14.31818962], [80.15402985, 14.31819534], [80.15402985, 14.31736088], [80.15374756, 14.31736088], [80.15374756, 14.31681061], [80.15348053, 14.31681061], [80.15348053, 14.31598186], [80.15319824, 14.31598186], [80.15319061, 14.3154211], [80.15290833, 14.3154211], [80.15291595, 14.31457996], [80.15262604, 14.31459141], [80.1526413, 14.31403065], [80.15244293, 14.31402779], [80.15235901, 14.31402779], [80.15235901, 14.31379414], [80.15235901, 14.31319427], [80.15208435, 14.31319427], [80.15208435, 14.31298923], [80.15208435, 14.31263828], [80.15196228, 14.31263828], [80.15180206, 14.31264019], [80.15180206, 14.31215954], [80.15180206, 14.31180573], [80.15167999, 14.31180859], [80.1515274, 14.31181145], [80.1515274, 14.31135273], [80.1515274, 14.31124973], [80.15125275, 14.31124973], [80.15125275, 14.31041622], [80.15116882, 14.31041813], [80.15097046, 14.31042099], [80.15097046, 14.31000996], [80.15097046, 14.30986214], [80.1506958, 14.30986214], [80.1506958, 14.30951977], [80.1506958, 14.30930614], [80.15058136, 14.30930614], [80.15040588, 14.30931091], [80.15041351, 14.30900955], [80.15041351, 14.30847168], [80.15013885, 14.30847168], [80.15013885, 14.30791569], [80.14985657, 14.30792046], [80.14985657, 14.30707932], [80.14958191, 14.30708408], [80.14958191, 14.30652809], [80.14930725, 14.30653], [80.14930725, 14.30568886], [80.14902496, 14.30569363], [80.14902496, 14.30513763], [80.14875031, 14.30513954], [80.14875031, 14.30430984], [80.14848328, 14.30430984], [80.14848328, 14.30375195], [80.14819336, 14.30375195], [80.14819336, 14.30292034], [80.1479187, 14.30292034], [80.1479187, 14.30236244], [80.14763641, 14.30236244], [80.14763641, 14.30152702], [80.1473465, 14.30153179], [80.1473465, 14.30097103], [80.1470871, 14.30097103], [80.1470871, 14.30013943], [80.14679718, 14.30013943], [80.14679718, 14.29958057], [80.14653015, 14.29958344], [80.14653015, 14.29874897], [80.14624786, 14.29875088], [80.14624786, 14.29790974], [80.14597321, 14.29791737], [80.14597321, 14.29680538], [80.14569092, 14.29681015], [80.14569092, 14.29597092], [80.14541626, 14.29597092], [80.14541626, 14.29513931], [80.1451416, 14.29514122], [80.1451416, 14.29431152], [80.14485931, 14.29431152], [80.14485931, 14.29347134], [80.14458466, 14.29347324], [80.14458466, 14.29236126], [80.14430237, 14.29236126], [80.14430237, 14.2915287], [80.14402771, 14.29153061], [80.14402771, 14.29069042], [80.14375305, 14.29069519], [80.14375305, 14.28986073], [80.14347076, 14.28986073], [80.14347076, 14.28903103], [80.14319611, 14.28903103], [80.14319611, 14.28792095], [80.14290619, 14.28792095], [80.14290619, 14.28708172], [80.14263916, 14.28708458], [80.14263916, 14.28625011], [80.14235687, 14.28625011], [80.14235687, 14.28542137], [80.14208221, 14.28542137], [80.14208221, 14.28431129], [80.14180756, 14.28431129], [80.14180756, 14.28319168], [80.14152527, 14.28319359], [80.14152527, 14.28208447], [80.14125061, 14.28208447], [80.14125061, 14.28097153], [80.14097595, 14.28097153], [80.14097595, 14.2798624], [80.14068604, 14.27987099], [80.14068604, 14.27875042], [80.14041901, 14.27875042], [80.14041901, 14.27791977], [80.14013672, 14.27791977], [80.14013672, 14.27680969], [80.13986206, 14.27680969], [80.13986206, 14.27569103], [80.13957977, 14.2756958], [80.13957977, 14.27458286], [80.13930511, 14.27458286], [80.13930511, 14.27347088], [80.13903046, 14.27347088], [80.13903046, 14.2723608], [80.13874817, 14.2723608], [80.13874817, 14.27013874], [80.13846588, 14.27014065], [80.13846588, 14.26680946], [80.13817596, 14.26680946], [80.13817596, 14.2634697], [80.13791656, 14.26347256], [80.13791656, 14.25847244], [80.13764191, 14.25847244], [80.13764191, 14.25374985], [80.13735962, 14.25374985], [80.13735962, 14.25263977], [80.13709259, 14.25263977], [80.13709259, 14.25208187], [80.13680267, 14.25208378], [80.13680267, 14.25180626], [80.13652802, 14.25181007], [80.13652802, 14.25152969], [80.13569641, 14.25152969], [80.13569641, 14.25069141], [80.13541412, 14.25069427], [80.13541412, 14.24930573], [80.13513947, 14.24930954], [80.13513947, 14.24819088], [80.13486481, 14.24819565], [80.13486481, 14.24680519], [80.13458252, 14.24680519], [80.13458252, 14.24541664], [80.13430786, 14.24542046], [80.13430786, 14.24431038], [80.1340332, 14.24431038], [80.1340332, 14.24374008], [80.13402557, 14.24291706], [80.13375092, 14.24292183], [80.13375092, 14.24236107], [80.13434601, 14.24236107], [80.13458252, 14.24236107], [80.13458252, 14.24097061], [80.13486481, 14.24097347], [80.13486481, 14.23986053], [80.13458252, 14.23986053], [80.13458252, 14.23930454], [80.13430786, 14.23930931], [80.13430786, 14.23875141], [80.13402557, 14.23875141], [80.13402557, 14.23819542], [80.13375092, 14.23819542], [80.13375092, 14.23763943], [80.13346863, 14.23763943], [80.13346863, 14.23708344], [80.13319397, 14.23708344], [80.13319397, 14.23652554], [80.13291931, 14.23653126], [80.13291931, 14.23569012], [80.13263702, 14.23569489], [80.13263702, 14.23458195], [80.13236237, 14.23458195], [80.13236237, 14.23319435], [80.13208008, 14.23319435], [80.13208008, 14.2318058], [80.13181305, 14.23182011], [80.13181305, 14.23069191], [80.13153076, 14.23069382], [80.13153076, 14.22930622], [80.13124847, 14.22931099], [80.13124847, 14.22764015], [80.13096619, 14.22764015], [80.13096619, 14.22597027], [80.13069153, 14.22597218], [80.13069153, 14.22430611], [80.13041687, 14.22430992], [80.13041687, 14.22292042], [80.13014221, 14.22292042], [80.13014221, 14.22124863], [80.12985992, 14.22124863], [80.12985992, 14.21959019], [80.12960052, 14.21959019], [80.12960052, 14.2179203], [80.12931061, 14.2179203], [80.12931061, 14.21653175], [80.12902832, 14.21653175], [80.12902832, 14.21486092], [80.12874603, 14.21486092], [80.12874603, 14.21319008], [80.12847137, 14.21319485], [80.12847137, 14.21152878], [80.12819672, 14.21153069], [80.12819672, 14.21068954], [80.12902832, 14.21069527], [80.12902832, 14.21013927], [80.12874603, 14.21014118], [80.12874603, 14.20931053], [80.12847137, 14.20931053], [80.12847137, 14.20792103], [80.12819672, 14.20792103], [80.12819672, 14.20653057], [80.1279068, 14.20653057], [80.1279068, 14.20514107], [80.12819672, 14.20514107], [80.12819672, 14.2045908], [80.12847137, 14.2045908], [80.12847137, 14.20431137], [80.12819672, 14.20431137], [80.12819672, 14.20374966], [80.1279068, 14.20374966], [80.1279068, 14.20125008], [80.12763977, 14.20125008], [80.12763977, 14.19957924], [80.12791443, 14.19958401], [80.12791443, 14.19902802], [80.12763977, 14.19902992], [80.12763977, 14.19845963], [80.12791443, 14.19847202], [80.12791443, 14.19458389], [80.12763977, 14.19458389], [80.12763977, 14.19430542], [80.12735748, 14.19431019], [80.12735748, 14.19402981], [80.12708282, 14.19402981], [80.12708282, 14.19291973], [80.12735748, 14.19291973], [80.12735748, 14.19208145], [80.12763977, 14.19208336], [80.12763977, 14.19152737], [80.12735748, 14.19153023], [80.12735748, 14.1912508], [80.12708282, 14.1912508], [80.12708282, 14.19014168], [80.12680817, 14.19014168], [80.12680817, 14.1898613], [80.12708282, 14.1898613], [80.12708282, 14.18958282], [80.12680817, 14.18958282], [80.12680817, 14.18930531], [80.12708282, 14.18931198], [80.12708282, 14.18651962], [80.12735748, 14.18652916], [80.12735748, 14.18541718], [80.12708282, 14.18542099], [80.12708282, 14.18457985], [80.12652588, 14.18458271], [80.12652588, 14.18402672], [80.12680817, 14.18403053], [80.12680817, 14.18375111], [80.12708282, 14.18375111], [80.12708282, 14.18319035], [80.12735748, 14.18319511], [80.12735748, 14.18263912], [80.12708282, 14.18264103], [80.12708282, 14.18097019], [80.12680817, 14.18097305], [80.12680817, 14.18069363], [80.12652588, 14.18069363], [80.12652588, 14.17875004], [80.12680817, 14.17875004], [80.12680817, 14.17819023], [80.12652588, 14.17819405], [80.12652588, 14.17763805], [80.12623596, 14.17763996], [80.12623596, 14.17681122], [80.12652588, 14.17681122], [80.12652588, 14.17653275], [80.12680817, 14.17653275], [80.12680817, 14.17542267], [80.12652588, 14.17542267], [80.12652588, 14.17514038], [80.12680817, 14.17514038], [80.12680817, 14.17486], [80.12652588, 14.17486], [80.12652588, 14.17457962], [80.12680817, 14.17458439], [80.12680817, 14.17374992], [80.12652588, 14.17374992], [80.12652588, 14.17319202], [80.12625122, 14.17319393], [80.12625122, 14.17125034], [80.12680817, 14.17125034], [80.12680817, 14.16958141], [80.12652588, 14.16958427], [80.12652588, 14.1693058], [80.12623596, 14.16930962], [80.12623596, 14.16903019], [80.12652588, 14.16903019], [80.12652588, 14.16875172], [80.12680817, 14.16875172], [80.12680817, 14.16792011], [80.12708282, 14.16792011], [80.12708282, 14.16763973], [80.12680817, 14.16763973], [80.12680817, 14.16681004], [80.12708282, 14.16681004], [80.12708282, 14.16652966], [80.12680817, 14.16652966], [80.12680817, 14.16624928], [80.12652588, 14.16624928], [80.12652588, 14.1645813], [80.12680817, 14.16458321], [80.12680817, 14.16374874], [80.12708282, 14.16375065], [80.12708282, 14.16264057], [80.12680817, 14.16264057], [80.12680817, 14.16207886], [80.12708282, 14.16208267], [80.12708282, 14.1604166], [80.12735748, 14.16041946], [80.12735748, 14.16014099], [80.12708282, 14.16014099], [80.12708282, 14.15986061], [80.12680817, 14.15986061], [80.12680817, 14.15958309], [80.12652588, 14.15958309], [80.12652588, 14.15902901], [80.12623596, 14.15903091], [80.12623596, 14.15875053], [80.12596893, 14.15875053], [80.12596893, 14.15847111], [80.12625122, 14.15847301], [80.12625122, 14.15791702], [80.12652588, 14.15792084], [80.12652588, 14.15736103], [80.12680817, 14.15736103], [80.12680817, 14.15596962], [80.12652588, 14.15597343], [80.12652588, 14.15430355], [80.12680817, 14.15431118], [80.12680817, 14.15292072], [80.12708282, 14.15292072], [80.12708282, 14.1526413], [80.12735748, 14.1526413], [80.12735748, 14.15207958], [80.12763977, 14.1520853], [80.12763977, 14.1501379], [80.12735748, 14.15014267], [80.12735748, 14.14958191], [80.12708282, 14.14958191], [80.12708282, 14.1493063], [80.12735748, 14.14931107], [80.12735748, 14.14875031], [80.12763977, 14.14875031], [80.12763977, 14.14792061], [80.12735748, 14.14792061], [80.12735748, 14.14764023], [80.12708282, 14.14764023], [80.12708282, 14.14681053], [80.12735748, 14.14681053], [80.12735748, 14.14653015], [80.1279068, 14.14653015], [80.1279068, 14.14542007], [80.12819672, 14.14542007], [80.12819672, 14.14375019], [80.1279068, 14.14375019], [80.1279068, 14.14291954], [80.12763977, 14.14291954], [80.12763977, 14.14236164], [80.1279068, 14.14236164], [80.1279068, 14.14208126], [80.12819672, 14.14208412], [80.12819672, 14.14069557], [80.12791443, 14.14069557], [80.12791443, 14.14041805], [80.12763977, 14.14041996], [80.12763977, 14.14013958], [80.12819672, 14.14013958], [80.12819672, 14.1398592], [80.12847137, 14.13986111], [80.12847137, 14.13930511], [80.12819672, 14.13931179], [80.12819672, 14.13903046], [80.12847137, 14.13903046], [80.12847137, 14.13792038], [80.12874603, 14.13792038], [80.12874603, 14.13764191], [80.12847137, 14.13764191], [80.12847137, 14.13736057], [80.12875366, 14.13736057], [80.12875366, 14.13569546], [80.12902832, 14.13569546], [80.12902832, 14.134305], [80.12874603, 14.13431168], [80.12874603, 14.13319016], [80.12902832, 14.13319492], [80.12902832, 14.13152885], [80.12931061, 14.13153076], [80.12931061, 14.12957954], [80.12958527, 14.12958336], [80.12958527, 14.12902641], [80.12931061, 14.12903118], [80.12931061, 14.12847042], [80.12958527, 14.12847328], [80.12958527, 14.12819481], [80.12930298, 14.12819481], [80.12930298, 14.12763786], [80.12960052, 14.12764072], [80.12960052, 14.12707996], [80.12930298, 14.12708473], [80.12930298, 14.12569427], [80.12958527, 14.12569427], [80.12958527, 14.12374973], [80.12874603, 14.12374973], [80.12874603, 14.12403107], [80.12847137, 14.12403107], [80.12847137, 14.12374973], [80.12819672, 14.12374973], [80.12819672, 14.12347031], [80.12791443, 14.12347221], [80.12791443, 14.12319374], [80.12763977, 14.12319374], [80.12763977, 14.12291622], [80.12735748, 14.12292099], [80.12735748, 14.12263966], [80.12623596, 14.12263966], [80.12623596, 14.12403107], [80.12596893, 14.12403107], [80.12596893, 14.12597179], [80.12625122, 14.12597179], [80.12625122, 14.12736034], [80.12680817, 14.12736034], [80.12680817, 14.12708473], [80.12735748, 14.12707996], [80.12735748, 14.12764072], [80.12763977, 14.12764072], [80.12763977, 14.1279211], [80.12791443, 14.12791729], [80.12791443, 14.12958336], [80.12763977, 14.12957954], [80.12763977, 14.12986088], [80.12735748, 14.12986088], [80.12735748, 14.13042068], [80.12708282, 14.13041687], [80.12708282, 14.13208294], [80.12735748, 14.13208103], [80.12735748, 14.13264084], [80.12708282, 14.13264084], [80.12708282, 14.13375092], [80.12680817, 14.13375092], [80.12680817, 14.13431168], [80.12596893, 14.13431168], [80.12596893, 14.1340313], [80.12568665, 14.1340313], [80.12568665, 14.13291931], [80.12541962, 14.13291931], [80.12541962, 14.13180923], [80.12568665, 14.13180923], [80.12568665, 14.13042068], [80.12541962, 14.13042068], [80.12541962, 14.13014126], [80.12568665, 14.13014126], [80.12568665, 14.12986088], [80.12541962, 14.12986088], [80.12541962, 14.12847042], [80.12513733, 14.12847328], [80.12513733, 14.12485981], [80.12541962, 14.12486267], [80.12541962, 14.1204319], [80.12513733, 14.1204319], [80.12513733, 14.12014008], [80.12486267, 14.12014008], [80.12486267, 14.11957932], [80.12458038, 14.11958408], [80.12458038, 14.11930561], [80.12431335, 14.11931133], [80.12431335, 14.11847019], [80.12374878, 14.1184721], [80.12374878, 14.11791801], [80.12346649, 14.11791992], [80.12346649, 14.11763954], [80.12317657, 14.11763954], [80.12317657, 14.11708164], [80.12291718, 14.11708355], [80.12291718, 14.11680603], [80.12264252, 14.11680984], [80.12264252, 14.11653042], [80.12236023, 14.11653042], [80.12236023, 14.11597157], [80.12208557, 14.11597157], [80.12208557, 14.11458397], [80.12236023, 14.11458397], [80.12236023, 14.11430645], [80.12264252, 14.11430645], [80.12264252, 14.11458397], [80.12291718, 14.1145792], [80.12291718, 14.11542034], [80.12317657, 14.11542034], [80.12317657, 14.11625195], [80.12346649, 14.11625195], [80.12346649, 14.11680984], [80.12374878, 14.11680984], [80.12374878, 14.11737061], [80.12403107, 14.11737061], [80.12403107, 14.11763954], [80.12431335, 14.11763954], [80.12431335, 14.11791992], [80.12458038, 14.11791801], [80.12458038, 14.11819363], [80.12486267, 14.11819363], [80.12486267, 14.1184721], [80.12513733, 14.11847019], [80.12513733, 14.11874962], [80.12568665, 14.11874962], [80.12568665, 14.11818886], [80.12596893, 14.11819363], [80.12596893, 14.11708355], [80.12625122, 14.11708355], [80.12625122, 14.11597157], [80.12652588, 14.11597157], [80.12652588, 14.11541462], [80.12623596, 14.11542034], [80.12623596, 14.11514187], [80.12652588, 14.11514187], [80.12652588, 14.11180973], [80.12680817, 14.11180973], [80.12680817, 14.1115303], [80.12763977, 14.1115303], [80.12763977, 14.11180973], [80.12819672, 14.11180496], [80.12819672, 14.11208344], [80.12874603, 14.11208057], [80.12874603, 14.11264038], [80.12902832, 14.11264038], [80.12902832, 14.11291981], [80.12930298, 14.1129179], [80.12930298, 14.11319256], [80.12958527, 14.11319256], [80.12958527, 14.11347103], [80.12985992, 14.11347103], [80.12985992, 14.11403179], [80.12902832, 14.11403179], [80.12902832, 14.11374855], [80.12874603, 14.11374855], [80.12874603, 14.11347103], [80.12763977, 14.11347103], [80.12763977, 14.11903], [80.12708282, 14.11903], [80.12708282, 14.1204319], [80.12735748, 14.12041569], [80.12735748, 14.12097168], [80.12763977, 14.12097168], [80.12763977, 14.12125015], [80.1279068, 14.12125015], [80.1279068, 14.12152958], [80.12960052, 14.12152958], [80.12960052, 14.12125015], [80.12985992, 14.12125015], [80.12985992, 14.1198597], [80.13014221, 14.1198597], [80.13014221, 14.11957932], [80.13097382, 14.11958408], [80.13097382, 14.1184721], [80.13124847, 14.1184721], [80.13124847, 14.11680603], [80.13096619, 14.11680984], [80.13096619, 14.11569118], [80.13124847, 14.11569405], [80.13124847, 14.11374855], [80.13153076, 14.11374855], [80.13153076, 14.11291981], [80.13181305, 14.11291981], [80.13181305, 14.11236095], [80.13153076, 14.11236095], [80.13153076, 14.11180973], [80.13181305, 14.11180973], [80.13181305, 14.10736084], [80.13208008, 14.10736084], [80.13208008, 14.10486126], [80.13236237, 14.10486126], [80.13236237, 14.10319519], [80.13263702, 14.10319519], [80.13263702, 14.1026392], [80.13291931, 14.10264111], [80.13291931, 14.10181141], [80.13263702, 14.10181141], [80.13263702, 14.10042095], [80.13291931, 14.10042095], [80.13291931, 14.09930038], [80.13319397, 14.0993042], [80.13319397, 14.09736156], [80.13346863, 14.09735966], [80.13346863, 14.09626198], [80.13375092, 14.09626198], [80.13375092, 14.09486008], [80.1340332, 14.09486008], [80.13402557, 14.09347153], [80.13430786, 14.09347153], [80.13430786, 14.0923624], [80.13458252, 14.0923624], [80.13458252, 14.09125042], [80.13485718, 14.09125042], [80.13485718, 14.09041977], [80.13513947, 14.09041977], [80.13513947, 14.08930969], [80.13540649, 14.08930969], [80.13540649, 14.08792019], [80.13569641, 14.08792019], [80.13569641, 14.08624935], [80.13597107, 14.08624935], [80.13597107, 14.08432102], [80.13625336, 14.08432102], [80.13625336, 14.0826416], [80.13652802, 14.0826416], [80.13652802, 14.08069134], [80.13680267, 14.08069515], [80.13680267, 14.07902908], [80.13707733, 14.07903099], [80.13707733, 14.07736111], [80.13735962, 14.07736111], [80.13735962, 14.07597256], [80.13764191, 14.07597256], [80.13764191, 14.07513905], [80.13791656, 14.07513905], [80.13791656, 14.07402897], [80.13817596, 14.07403088], [80.13817596, 14.07318974], [80.13847351, 14.07319546], [80.13847351, 14.07236004], [80.13817596, 14.07236004], [80.13817596, 14.07207108], [80.13847351, 14.07208538], [80.13847351, 14.07180691], [80.13874817, 14.07181072], [80.13874817, 14.0715313], [80.13903046, 14.0715313], [80.13903046, 14.07124996], [80.13931274, 14.07124996], [80.13931274, 14.07096958], [80.13957977, 14.07097244], [80.13957977, 14.07069397], [80.13986206, 14.07069397], [80.13986206, 14.07013798], [80.14013672, 14.07014275], [80.14013672, 14.06986046], [80.14097595, 14.06986237], [80.14097595, 14.0690279], [80.14125061, 14.06903267], [80.14125061, 14.06818962], [80.14152527, 14.06819439], [80.14152527, 14.06791592], [80.14125061, 14.06792068], [80.14125061, 14.06653023], [80.14154053, 14.06653023], [80.14154053, 14.06513977], [80.14125061, 14.06513977], [80.14125061, 14.06375027], [80.14097595, 14.06375027], [80.14097595, 14.06208134], [80.14125061, 14.0620842], [80.14125061, 14.06152821], [80.14097595, 14.06153202], [80.14097595, 14.06042004], [80.14125061, 14.06042004], [80.14125061, 14.06013012], [80.14152527, 14.06013966], [80.14152527, 14.05986214], [80.14180756, 14.05986214], [80.14180756, 14.05958366], [80.14208221, 14.05958366], [80.14208221, 14.05930519], [80.14235687, 14.05930996], [80.14235687, 14.05792046], [80.14263916, 14.05792046], [80.14263916, 14.05653191], [80.14235687, 14.05653191], [80.14235687, 14.05597115], [80.14291382, 14.05597115], [80.14291382, 14.05541706], [80.14263916, 14.05542183], [80.14263916, 14.05458069], [80.14291382, 14.0545826], [80.14291382, 14.0540266], [80.14319611, 14.05403233], [80.14319611, 14.05180931], [80.14347076, 14.05180931], [80.14347076, 14.0506897], [80.14375305, 14.05069542], [80.14375305, 14.05013943], [80.14402771, 14.05014133], [80.14402771, 14.04957962], [80.14430237, 14.04958344], [80.14430237, 14.04930687], [80.14457703, 14.04931068], [80.14457703, 14.04903126], [80.14485931, 14.04903126], [80.14485931, 14.04819012], [80.14458466, 14.04819489], [80.14458466, 14.04763889], [80.14431, 14.0476408], [80.14431, 14.04736042], [80.14458466, 14.04736042], [80.14458466, 14.04652882], [80.14485931, 14.04653072], [80.14485931, 14.0462513], [80.1451416, 14.0462513], [80.1451416, 14.04596996], [80.14485931, 14.04597282], [80.14485931, 14.04541588], [80.1451416, 14.04542065], [80.1451416, 14.04431057], [80.14541626, 14.04431057], [80.14541626, 14.04319191], [80.14569092, 14.04319382], [80.14569092, 14.04097176], [80.14597321, 14.04097176], [80.14597321, 14.04041576], [80.14624786, 14.04042053], [80.14624786, 14.03986168], [80.14653015, 14.03986168], [80.14653015, 14.03902054], [80.14680481, 14.03902817], [80.14680481, 14.0381937], [80.1470871, 14.0381937], [80.1470871, 14.0373621], [80.14736176, 14.0373621], [80.14736176, 14.03680611], [80.14763641, 14.03680992], [80.14763641, 14.0359602], [80.1479187, 14.03597164], [80.1479187, 14.03514004], [80.14819336, 14.03514194], [80.14819336, 14.03264046], [80.14848328, 14.03264046], [80.14848328, 14.03015137], [80.14819336, 14.03015137], [80.14819336, 14.02875137], [80.1479187, 14.02875137], [80.1479187, 14.02792168], [80.14819336, 14.02792168], [80.14819336, 14.02736092], [80.14848328, 14.02736092], [80.14847565, 14.02680492], [80.14875031, 14.02680969], [80.14875031, 14.02625084], [80.14901733, 14.02625084], [80.14901733, 14.02569008], [80.14930725, 14.02569485], [80.14930725, 14.02541733], [80.14958191, 14.02541924], [80.14958191, 14.02486134], [80.1498642, 14.02486134], [80.1498642, 14.02430534], [80.15013885, 14.02431202], [80.15013885, 14.02375126], [80.15040588, 14.02375126], [80.15040588, 14.02153111], [80.15013885, 14.02153111], [80.15013885, 14.02098179], [80.14985657, 14.02098179], [80.14985657, 14.02042103], [80.14958191, 14.02042103], [80.14958191, 14.01875114], [80.14985657, 14.01875114], [80.14985657, 14.01903057], [80.15013885, 14.01903057], [80.15013885, 14.01931095], [80.15041351, 14.01930428], [80.15041351, 14.01958466], [80.1506958, 14.01958466], [80.1506958, 14.01986027], [80.15097046, 14.01986027], [80.15097046, 14.02014065], [80.15125275, 14.02014065], [80.15125275, 14.02042103], [80.15180206, 14.02041721], [80.15180206, 14.02069473], [80.15207672, 14.02068996], [80.15207672, 14.02098179], [80.15235901, 14.02098179], [80.15235901, 14.02125072], [80.1526413, 14.02125072], [80.1526413, 14.02153111], [80.15291595, 14.02153111], [80.15291595, 14.02181053], [80.15319824, 14.02181053], [80.15319824, 14.02292061], [80.15291595, 14.02292061], [80.15291595, 14.02375126], [80.1526413, 14.02375126], [80.1526413, 14.02402687], [80.15235901, 14.02402687], [80.15235901, 14.02486134], [80.15207672, 14.02486134], [80.15207672, 14.02541924], [80.15180206, 14.02541733], [80.15180206, 14.02597332], [80.1515274, 14.02597141], [80.1515274, 14.02680969], [80.15125275, 14.02680969], [80.15125275, 14.02736092], [80.1506958, 14.02736092], [80.1506958, 14.02792168], [80.15040588, 14.02792168], [80.15040588, 14.02931023], [80.1506958, 14.02931023], [80.1506958, 14.0304203], [80.1515274, 14.0304203], [80.1515274, 14.03015137], [80.15180206, 14.03015137], [80.15180206, 14.02958107], [80.15208435, 14.02958298], [80.15208435, 14.02847099], [80.15235901, 14.02847099], [80.15235901, 14.02736092], [80.1526413, 14.02736092], [80.1526413, 14.02625084], [80.15291595, 14.02625084], [80.15291595, 14.02514076], [80.15319061, 14.02514076], [80.15319824, 14.02458096], [80.1534729, 14.02458286], [80.1534729, 14.02402687], [80.15374756, 14.02402687], [80.15374756, 14.02347279], [80.15402985, 14.02347279], [80.15402985, 14.02291679], [80.15429687, 14.02292061], [80.15429687, 14.0223608], [80.15458679, 14.0223608], [80.15458679, 14.02180672], [80.15486145, 14.02181053], [80.15486145, 14.02125072], [80.15513611, 14.02125072], [80.15513611, 14.02068996], [80.1554184, 14.02069473], [80.1554184, 14.01958466], [80.15513611, 14.01958466], [80.15513611, 14.01930428], [80.15458679, 14.01931095], [80.15458679, 14.01819038], [80.15486145, 14.0181942], [80.15486145, 14.01624966], [80.15458679, 14.01624966], [80.15458679, 14.01513958], [80.15429687, 14.01513958], [80.15429687, 14.01292038], [80.15458679, 14.01292038], [80.15458679, 14.01152992], [80.15486145, 14.01152992], [80.15486145, 14.01097202], [80.15513611, 14.01097202], [80.15513611, 14.01041794], [80.1554184, 14.01041985], [80.1554184, 14.01014042], [80.15569305, 14.01014042], [80.15569305, 14.00986195], [80.15598297, 14.00986195], [80.15597534, 14.00930595], [80.15625, 14.00930977], [80.15625, 14.00904083], [80.15651703, 14.00904083], [80.15651703, 14.00875187], [80.15680695, 14.00875187], [80.15680695, 14.00819111], [80.1570816, 14.00819397], [80.1570816, 14.00791454], [80.15735626, 14.00792027], [80.15735626, 14.00735855], [80.15763855, 14.00736237], [80.15763855, 14.0065279], [80.15791321, 14.00652981], [80.15791321, 14.00486088], [80.15763855, 14.00486088], [80.15763855, 14.00013924], [80.15791321, 14.00013924], [80.15791321, 13.99985027], [80.1581955, 13.99986076], [80.1581955, 13.99958324], [80.15847015, 13.99958324], [80.15847015, 13.99902916], [80.15866089, 13.99902916], [80.1598587, 13.99903107], [80.1598587, 13.99847126], [80.16014099, 13.99847317], [80.16014099, 13.9976387], [80.16042328, 13.99764061], [80.16042328, 13.99681187], [80.16069794, 13.99681187], [80.16069794, 13.99597073], [80.1609726, 13.99597263], [80.1609726, 13.99513912], [80.16124725, 13.99514103], [80.16124725, 13.99431133], [80.16152954, 13.99431133], [80.16152954, 13.99096966], [80.16069794, 13.99096966], [80.16069794, 13.99125004], [80.1598587, 13.99125004], [80.1598587, 13.99069023], [80.16014099, 13.99069405], [80.16014099, 13.99013805], [80.16042328, 13.99014091], [80.16042328, 13.98958015], [80.16069794, 13.98958206], [80.16069794, 13.98902798], [80.1609726, 13.98903275], [80.1609726, 13.98875046], [80.16124725, 13.98875046], [80.16124725, 13.9881897], [80.16152954, 13.98819447], [80.16152954, 13.98791599], [80.16236115, 13.98791599], [80.16236115, 13.98819447], [80.16291809, 13.98819447], [80.16291809, 13.98791599], [80.16374969, 13.98791599], [80.16374969, 13.98736], [80.16401672, 13.98736], [80.16401672, 13.98569202], [80.16374969, 13.98569393], [80.16374969, 13.98513794], [80.16319275, 13.98513985], [80.16319275, 13.98542023], [80.16291809, 13.98541641], [80.16291809, 13.98569393], [80.16236115, 13.98569393], [80.16236115, 13.98402786], [80.1626358, 13.98402977], [80.1626358, 13.98347187], [80.16291809, 13.98347187], [80.16291809, 13.98264027], [80.16319275, 13.98264027], [80.16319275, 13.98208141], [80.16347504, 13.98208427], [80.16347504, 13.98097229], [80.16374969, 13.98097229], [80.16374969, 13.97930622], [80.16401672, 13.97931004], [80.16401672, 13.97846889], [80.16430664, 13.9784708], [80.16430664, 13.97819328], [80.16486359, 13.97819328], [80.16486359, 13.97791767], [80.16513824, 13.97791958], [80.16513824, 13.9776392], [80.16542053, 13.9776392], [80.16542053, 13.97736073], [80.16596985, 13.97736073], [80.16596985, 13.9770813], [80.16625214, 13.97708321], [80.16625214, 13.97652721], [80.16652679, 13.97653198], [80.16652679, 13.97625065], [80.16680908, 13.97625065], [80.16680908, 13.9756794], [80.16708374, 13.97569466], [80.16708374, 13.97513866], [80.1673584, 13.97514153], [80.1673584, 13.97458076], [80.16764069, 13.97458267], [80.16764069, 13.97402668], [80.16792297, 13.9740324], [80.16792297, 13.97347069], [80.16819763, 13.9734726], [80.16819763, 13.97319508], [80.16847229, 13.97319508], [80.16847229, 13.9729166], [80.16902924, 13.97293091], [80.16902924, 13.97208118], [80.16930389, 13.97208309], [80.16930389, 13.97041702], [80.16958618, 13.97042084], [80.16958618, 13.96708012], [80.16986084, 13.96708298], [80.16986084, 13.96430683], [80.16958618, 13.96431065], [80.16958618, 13.9637413], [80.17041779, 13.9637413], [80.17041779, 13.96403122], [80.17069244, 13.96403122], [80.17069244, 13.96431065], [80.17097473, 13.96430683], [80.17097473, 13.96458244], [80.17124939, 13.96458244], [80.17124939, 13.96430683], [80.17151642, 13.96431065], [80.17151642, 13.96319199], [80.17180634, 13.96319389], [80.17180634, 13.96152782], [80.17208099, 13.96153069], [80.17208099, 13.96014023], [80.17292023, 13.96014023], [80.17292023, 13.96097183], [80.17318726, 13.96096992], [80.17318726, 13.96153069], [80.17375183, 13.96152782], [80.17375183, 13.96347237], [80.17346954, 13.96347046], [80.17346954, 13.96431065], [80.17318726, 13.96431065], [80.17318726, 13.9651413], [80.17292023, 13.96513844], [80.17292023, 13.9659729], [80.17263794, 13.96597004], [80.17263794, 13.96681118], [80.17236328, 13.96681118], [80.17236328, 13.96764088], [80.17208099, 13.96763897], [80.17208099, 13.96847343], [80.17180634, 13.96846962], [80.17180634, 13.96931076], [80.17151642, 13.96931076], [80.17151642, 13.97014141], [80.17124939, 13.97013855], [80.17124939, 13.97097301], [80.1709671, 13.97097111], [80.1709671, 13.97153091], [80.17069244, 13.97153091], [80.17069244, 13.97180939], [80.17041779, 13.97180462], [80.17041779, 13.97208309], [80.17014313, 13.97208118], [80.17014313, 13.97264099], [80.16986084, 13.97264099], [80.16986084, 13.97293091], [80.16958618, 13.9729166], [80.16958618, 13.97319508], [80.16929626, 13.97319126], [80.16929626, 13.97375107], [80.16958618, 13.97375107], [80.16958618, 13.97431183], [80.16986084, 13.97430515], [80.16986084, 13.97486115], [80.17014313, 13.97486115], [80.17014313, 13.97542191], [80.16902924, 13.97541714], [80.16902924, 13.97597122], [80.16874695, 13.97597122], [80.16874695, 13.97653198], [80.16847992, 13.97653198], [80.16847992, 13.97681046], [80.16819763, 13.97681046], [80.16819763, 13.97736073], [80.16792297, 13.97736073], [80.16792297, 13.97791958], [80.16764069, 13.97791767], [80.16764069, 13.97819328], [80.16791534, 13.97819328], [80.16791534, 13.9784708], [80.16819763, 13.97846889], [80.16819763, 13.97874928], [80.16874695, 13.97874928], [80.16874695, 13.97931004], [80.16847992, 13.97931004], [80.16847992, 13.98013973], [80.16819763, 13.98013973], [80.16819763, 13.98069572], [80.16792297, 13.98069096], [80.16792297, 13.98125172], [80.16764069, 13.98125172], [80.16764069, 13.98236179], [80.1673584, 13.98236179], [80.1673584, 13.98264027], [80.16707611, 13.98264027], [80.16707611, 13.98291969], [80.16652679, 13.98291969], [80.16652679, 13.98236179], [80.16625214, 13.98236179], [80.16625214, 13.98125172], [80.16596985, 13.98125172], [80.16596985, 13.98069096], [80.16569519, 13.98069572], [80.16569519, 13.98041534], [80.16513824, 13.98041534], [80.16513824, 13.98069572], [80.16485596, 13.98069096], [80.16485596, 13.98153019], [80.1645813, 13.98153019], [80.1645813, 13.98236179], [80.16486359, 13.98236179], [80.16486359, 13.98347187], [80.16513824, 13.98347187], [80.16513824, 13.98431015], [80.16542053, 13.98431015], [80.16542053, 13.98542023], [80.16569519, 13.98541641], [80.16569519, 13.9859724], [80.16596985, 13.98596954], [80.16596985, 13.98624992], [80.16625214, 13.98624992], [80.16625214, 13.98596954], [80.16680908, 13.98596954], [80.16680908, 13.9865303], [80.16652679, 13.9865303], [80.16652679, 13.98764038], [80.16625214, 13.98763847], [80.16625214, 13.98819447], [80.16596985, 13.9881897], [80.16596985, 13.98875046], [80.16570282, 13.98875046], [80.16570282, 13.98931122], [80.16542053, 13.98931122], [80.16542053, 13.99014091], [80.16513824, 13.99013805], [80.16513824, 13.99097157], [80.16485596, 13.99096966], [80.16485596, 13.99236012], [80.1645813, 13.99236012], [80.1645813, 13.99347305], [80.16430664, 13.99347019], [80.16430664, 13.99403954], [80.16402435, 13.99402905], [80.16402435, 13.99458313], [80.16374969, 13.99458027], [80.16374969, 13.99514103], [80.16347504, 13.99513912], [80.16347504, 13.99569511], [80.16319275, 13.99569511], [80.16319275, 13.99597263], [80.16291809, 13.99597073], [80.16291809, 13.99653053], [80.1626358, 13.99652672], [80.1626358, 13.99708271], [80.16234589, 13.99707985], [80.16234589, 13.99764061], [80.1626358, 13.9976387], [80.1626358, 13.99819469], [80.16234589, 13.99818993], [80.16234589, 13.99875069], [80.16208649, 13.99875069], [80.16208649, 14.00013924], [80.1618042, 14.00013924], [80.1618042, 14.00069523], [80.16152954, 14.00069141], [80.16152954, 14.00097084], [80.16124725, 14.00097084], [80.16124725, 14.00125122], [80.1609726, 14.00125122], [80.1609726, 14.00264168], [80.16069794, 14.00264168], [80.16069794, 14.00374889], [80.16042328, 14.00374889], [80.16042328, 14.00541973], [80.16014099, 14.00541973], [80.16014099, 14.00598145], [80.1598587, 14.00598145], [80.1598587, 14.00652981], [80.15958405, 14.0065279], [80.15958405, 14.00736237], [80.15930939, 14.00735855], [80.1592865, 14.00764179], [80.1590271, 14.00763988], [80.1590271, 14.00819111], [80.15875244, 14.00819969], [80.15875244, 14.00875187], [80.15847015, 14.00875187], [80.15847015, 14.00904083], [80.15820313, 14.00904083], [80.15820313, 14.00930977], [80.15791321, 14.00930595], [80.15791321, 14.00958443], [80.15763855, 14.00958157], [80.15763855, 14.00986195], [80.15736389, 14.00986195], [80.15736389, 14.01069355], [80.1570816, 14.01069355], [80.1570816, 14.01236153], [80.15680695, 14.01235962], [80.15680695, 14.01375008], [80.15652466, 14.01375008], [80.15652466, 14.01486015], [80.15625, 14.01486015], [80.15625, 14.01597214], [80.15597534, 14.01597214], [80.15597534, 14.01708221], [80.15569305, 14.01708031], [80.15569305, 14.01764107], [80.15625, 14.01764107], [80.15625, 14.01735973], [80.15651703, 14.01735973], [80.15651703, 14.01653099], [80.15680695, 14.01653099], [80.15680695, 14.01624966], [80.15735626, 14.01624966], [80.15735626, 14.01542091], [80.15763855, 14.01542091], [80.15763855, 14.01458168], [80.15791321, 14.01458359], [80.15791321, 14.0140276], [80.15820313, 14.01403046], [80.15820313, 14.0134697], [80.15847015, 14.0134716], [80.15847015, 14.01264], [80.15875244, 14.01264], [80.15875244, 14.01181126], [80.1590271, 14.01181126], [80.1590271, 14.01124954], [80.1592865, 14.01124954], [80.1592865, 14.00930977], [80.15957642, 14.00930977], [80.15957642, 14.00904083], [80.1598587, 14.00904083], [80.1598587, 14.00875187], [80.16014099, 14.00875187], [80.16014099, 14.00847244], [80.16041565, 14.00847244], [80.16041565, 14.00763988], [80.16069794, 14.00764179], [80.16069794, 14.00652981], [80.1609726, 14.00652981], [80.1609726, 14.00598145], [80.16124725, 14.00598145], [80.16124725, 14.00569057], [80.16152954, 14.00569344], [80.16152954, 14.00458336], [80.1618042, 14.00458336], [80.1618042, 14.00402737], [80.16208649, 14.00403023], [80.16208649, 14.00347137], [80.16236115, 14.00347328], [80.16236115, 14.00291729], [80.1626358, 14.00291729], [80.1626358, 14.00208282], [80.16291809, 14.00208282], [80.16291809, 14.00180531], [80.16319275, 14.00181198], [80.16319275, 14.0015316], [80.16348267, 14.0015316], [80.16348267, 14.00097084], [80.16374969, 14.00097084], [80.16374969, 13.99985027], [80.16374969, 13.99958324], [80.16402435, 13.99958324], [80.16402435, 13.99930477], [80.16430664, 13.99930859], [80.16430664, 13.99875069], [80.1645813, 13.99875069], [80.1645813, 13.99818993], [80.16486359, 13.99819469], [80.16486359, 13.99791718], [80.16513824, 13.99792099], [80.16513824, 13.99736118], [80.1654129, 13.99736118], [80.1654129, 13.99680519], [80.16570282, 13.99681187], [80.16570282, 13.99625111], [80.16596985, 13.99625111], [80.16596985, 13.99486065], [80.16625214, 13.99486065], [80.16625214, 13.99403954], [80.16652679, 13.99403954], [80.16652679, 13.99347019], [80.16680908, 13.99347305], [80.16680908, 13.99319458], [80.16708374, 13.99319458], [80.16708374, 13.99291706], [80.1673584, 13.99292088], [80.1673584, 13.99264145], [80.16764069, 13.99264145], [80.16764069, 13.99125004], [80.16792297, 13.99125004], [80.16792297, 13.99069023], [80.16819763, 13.99069405], [80.16819763, 13.99041557], [80.16847992, 13.9904213], [80.16847992, 13.99014091], [80.16874695, 13.99014091], [80.16874695, 13.98985958], [80.16902924, 13.98986244], [80.16902924, 13.98930645], [80.16929626, 13.98931122], [80.16929626, 13.98875046], [80.16958618, 13.98875046], [80.16958618, 13.98764038], [80.16929626, 13.98764038], [80.16929626, 13.98707962], [80.16958618, 13.98708439], [80.16958618, 13.98680592], [80.16986084, 13.98681068], [80.16986084, 13.9865303], [80.17014313, 13.9865303], [80.17014313, 13.98596954], [80.17041779, 13.9859724], [80.17041779, 13.98569393], [80.17069244, 13.98569393], [80.17069244, 13.98513794], [80.17041779, 13.98513985], [80.17041779, 13.98487091], [80.1709671, 13.98487091], [80.1709671, 13.98458195], [80.17124939, 13.98458385], [80.17124939, 13.98430634], [80.17151642, 13.98431015], [80.17151642, 13.98402977], [80.17180634, 13.98402977], [80.17180634, 13.98264027], [80.17208099, 13.98264027], [80.17208099, 13.98180962], [80.17236328, 13.98180962], [80.17236328, 13.98069096], [80.17263794, 13.98069572], [80.17263794, 13.98013973], [80.17292023, 13.98013973], [80.17292023, 13.97958088], [80.17319489, 13.97958374], [80.17319489, 13.97930622], [80.17346954, 13.97931004], [80.17346954, 13.97902966], [80.17375183, 13.97902966], [80.17375183, 13.97874928], [80.17402649, 13.97874928], [80.17402649, 13.97791958], [80.17430878, 13.97791958], [80.17430878, 13.97681046], [80.17457581, 13.97681046], [80.17457581, 13.97625065], [80.17485809, 13.97625065], [80.17485809, 13.9756794], [80.17514038, 13.97569466], [80.17514038, 13.97513866], [80.17542267, 13.97514153], [80.17542267, 13.97486115], [80.17597198, 13.97486115], [80.17597198, 13.97430515], [80.17624664, 13.97431183], [80.17624664, 13.97319126], [80.17652893, 13.97319508], [80.17652893, 13.97263908], [80.17679596, 13.97264099], [80.17679596, 13.97208118], [80.17708588, 13.97208309], [80.17708588, 13.97097301], [80.17736053, 13.97097301], [80.17736053, 13.97069454], [80.17763519, 13.97069454], [80.17763519, 13.97041702], [80.17791748, 13.97042084], [80.17791748, 13.96986961], [80.17819214, 13.96986961], [80.17819214, 13.96903133], [80.1784668, 13.96903133], [80.1784668, 13.96875095], [80.17874908, 13.96875095], [80.17874908, 13.96792126], [80.17903137, 13.96792126], [80.17903137, 13.96736145], [80.17930603, 13.96736145], [80.17930603, 13.96708298], [80.17958069, 13.96708298], [80.17958069, 13.96652889], [80.17986298, 13.9665308], [80.17986298, 13.96542072], [80.18013763, 13.96542072], [80.18013763, 13.96485996], [80.18041992, 13.96485996], [80.18041992, 13.96403122], [80.18068695, 13.96403122], [80.18068695, 13.96347046], [80.18096924, 13.96347237], [80.18096924, 13.96291637], [80.18125153, 13.96292114], [80.18125153, 13.96181107], [80.18096924, 13.96181107], [80.18096924, 13.96096992], [80.18125153, 13.96097183], [80.18125153, 13.96069431], [80.18152618, 13.96069431], [80.18152618, 13.96041584], [80.18180847, 13.96042061], [80.18180847, 13.95985985], [80.18208313, 13.95985985], [80.18208313, 13.95958424], [80.18235779, 13.95958424], [80.18235779, 13.95930576], [80.18264008, 13.95931053], [80.18264008, 13.95903015], [80.1829071, 13.95903015], [80.1829071, 13.95875168], [80.18319702, 13.95875168], [80.18319702, 13.95847034], [80.18347168, 13.95847225], [80.18347168, 13.95736217], [80.18374634, 13.95736217], [80.18374634, 13.95680618], [80.18402863, 13.95681], [80.18402863, 13.95596886], [80.18430328, 13.95597172], [80.18430328, 13.95541573], [80.1845932, 13.95541954], [80.1845932, 13.95458126], [80.18486023, 13.95458412], [80.18486023, 13.95402813], [80.18514252, 13.95403004], [80.18514252, 13.95346928], [80.18541718, 13.95347214], [80.18541718, 13.95263958], [80.18569183, 13.95263958], [80.18569183, 13.95208073], [80.18597412, 13.95208359], [80.18597412, 13.95124912], [80.18624878, 13.95125198], [80.18624878, 13.95069122], [80.18653107, 13.95069313], [80.18653107, 13.95013905], [80.18681335, 13.95014191], [80.18681335, 13.94764137], [80.18708038, 13.94764137], [80.18708038, 13.94708061], [80.18736267, 13.94708347], [80.18736267, 13.94652653], [80.18763733, 13.94652939], [80.18763733, 13.94625092], [80.18791962, 13.94625092], [80.18791962, 13.94569969], [80.18818665, 13.94569969], [80.18818665, 13.94430923], [80.18846893, 13.94430923], [80.18846893, 13.94375134], [80.18875122, 13.94375134], [80.18875122, 13.94347095], [80.18902588, 13.94347286], [80.18902588, 13.94319534], [80.18930817, 13.94319534], [80.18930817, 13.94263935], [80.18958282, 13.94264126], [80.18958282, 13.94181061], [80.18985748, 13.94181061], [80.18985748, 13.94097042], [80.19013977, 13.94097328], [80.19013977, 13.93958473], [80.19041443, 13.93958473], [80.19041443, 13.93902874], [80.19069672, 13.93903065], [80.19069672, 13.93875122], [80.19097137, 13.93875122], [80.19097137, 13.93819046], [80.19125366, 13.93819427], [80.19125366, 13.93763828], [80.19152832, 13.93764114], [80.19152832, 13.93708038], [80.19180298, 13.93708229], [80.19180298, 13.93569374], [80.19208527, 13.93569374], [80.19208527, 13.93513775], [80.19235992, 13.93513966], [80.19235992, 13.93431091], [80.19264984, 13.93431091], [80.19264984, 13.93292141], [80.19291687, 13.93292141], [80.19291687, 13.93208027], [80.19319153, 13.93208408], [80.19319153, 13.93152809], [80.19346619, 13.93153], [80.19346619, 13.93041992], [80.19374847, 13.93041992], [80.19374847, 13.92958164], [80.19403076, 13.92958355], [80.19403076, 13.92875004], [80.19431305, 13.92875195], [80.19431305, 13.92819118], [80.19458008, 13.92819405], [80.19458008, 13.92763996], [80.19486237, 13.92763996], [80.19486237, 13.92736244], [80.19513702, 13.92736244], [80.19513702, 13.92680645], [80.19541931, 13.92681026], [80.19541931, 13.92457199], [80.19569397, 13.92458344], [80.19569397, 13.92374897], [80.19596863, 13.92375183], [80.19596863, 13.92347145], [80.19625092, 13.92347431], [80.19625092, 13.92263889], [80.1965332, 13.92264175], [80.1965332, 13.92182064], [80.19680786, 13.92182064], [80.19680786, 13.9212513], [80.19708252, 13.9212513], [80.19708252, 13.92069054], [80.19736481, 13.9206953], [80.19736481, 13.92013931], [80.19763947, 13.92013931], [80.19763947, 13.91958141], [80.19791412, 13.91958332], [80.19791412, 13.91874886], [80.19819641, 13.9187603], [80.19819641, 13.91847134], [80.19791412, 13.91847324], [80.19791412, 13.91819477], [80.19819641, 13.91819477], [80.19819641, 13.91791725], [80.19845581, 13.91792202], [80.19845581, 13.91736126], [80.19875336, 13.91736126], [80.19875336, 13.91708279], [80.19902802, 13.91708279], [80.19902802, 13.91652679], [80.19930267, 13.91653061], [80.19930267, 13.9159708], [80.19958496, 13.91597271], [80.19958496, 13.91569519], [80.19985962, 13.91569519], [80.19985962, 13.9151392], [80.20014191, 13.91514111], [80.20014191, 13.91458035], [80.20041656, 13.91458321], [80.20041656, 13.91402912], [80.20069122, 13.91403103], [80.20069122, 13.91292095], [80.20096588, 13.91292095], [80.20096588, 13.91263199], [80.20124817, 13.91263866], [80.20124817, 13.91208458], [80.20153046, 13.91208458], [80.20153046, 13.91097164], [80.20207977, 13.91097164], [80.20207977, 13.91069412], [80.20236206, 13.91069412], [80.20236206, 13.91041565], [80.20263672, 13.91042137], [80.20263672, 13.90959072], [80.20291901, 13.90959072], [80.20291901, 13.90903091], [80.20318604, 13.90903091], [80.20318604, 13.90874958], [80.20375061, 13.90874958], [80.20375061, 13.90819168], [80.20402527, 13.90819359], [80.20402527, 13.9076376], [80.20430756, 13.90764046], [80.20430756, 13.9070797], [80.20458221, 13.90708447], [80.20458221, 13.90652847], [80.20485687, 13.90653038], [80.20485687, 13.90568924], [80.20513916, 13.90569401], [80.20513916, 13.90541553], [80.20540619, 13.9054203], [80.20540619, 13.90513992], [80.20569611, 13.90513992], [80.20569611, 13.90458202], [80.20597076, 13.90458393], [80.20597076, 13.90402794], [80.20625305, 13.90402985], [80.20625305, 13.90345955], [80.20652771, 13.90347195], [80.20652771, 13.90291786], [80.20680237, 13.90291977], [80.20680237, 13.90264034], [80.20707703, 13.90264034], [80.20707703, 13.90236187], [80.20735931, 13.90236187], [80.20735931, 13.90180969], [80.20764923, 13.90180969], [80.20764923, 13.90125179], [80.20791626, 13.90125179], [80.20791626, 13.90096855], [80.20819092, 13.90097237], [80.20819092, 13.9006958], [80.20847321, 13.9006958], [80.20847321, 13.89986229], [80.20874786, 13.89986229], [80.20874786, 13.8993063], [80.20903015, 13.89931011], [80.20903015, 13.89819145], [80.20874786, 13.89819336], [80.20874786, 13.8973608], [80.20903015, 13.8973608], [80.20903015, 13.89708328], [80.21013641, 13.89708328], [80.21013641, 13.89680481], [80.2104187, 13.89680958], [80.2104187, 13.89653015], [80.21069336, 13.89653015], [80.21069336, 13.89569092], [80.21097565, 13.89569473], [80.21097565, 13.89513874], [80.21125031, 13.8951416], [80.21125031, 13.89375114], [80.21151733, 13.89375114], [80.21151733, 13.89319134], [80.21208191, 13.89319515], [80.21208191, 13.89291668], [80.21235657, 13.89291859], [80.21235657, 13.89236069], [80.21263885, 13.89236069], [80.21263885, 13.89151955], [80.21291351, 13.89152908], [80.21291351, 13.89069462], [80.2131958, 13.89069462], [80.2131958, 13.89013863], [80.21346283, 13.89014053], [80.21346283, 13.88931179], [80.21375275, 13.88931179], [80.21375275, 13.88819027], [80.2140274, 13.88819504], [80.2140274, 13.88736057], [80.21430206, 13.88736057], [80.21430206, 13.88680458], [80.21457672, 13.88681126], [80.21457672, 13.88653088], [80.21485901, 13.88653088], [80.21485901, 13.88625145], [80.2151413, 13.88625145], [80.2151413, 13.88597012], [80.21541595, 13.88597298], [80.21541595, 13.88569546], [80.21569061, 13.88569546], [80.21569824, 13.88541698], [80.2159729, 13.8854208], [80.2159729, 13.88514137], [80.21624756, 13.88514137], [80.21624756, 13.88457966], [80.21652985, 13.88458157], [80.21652985, 13.88402939], [80.21679688, 13.8840313], [80.21679688, 13.88346958], [80.21708679, 13.88347244], [80.21708679, 13.88263798], [80.21736145, 13.88265038], [80.21736145, 13.88208199], [80.21763611, 13.88208199], [80.21763611, 13.88097191], [80.2179184, 13.88097191], [80.2179184, 13.88041592], [80.21819305, 13.88042068], [80.21819305, 13.8801403], [80.21848297, 13.8801403], [80.21848297, 13.87985992], [80.21875, 13.87985992], [80.21875, 13.87903023], [80.21901703, 13.87903023], [80.21901703, 13.87847042], [80.21930695, 13.87847233], [80.21930695, 13.87791634], [80.21958923, 13.87792015], [80.21958923, 13.87736034], [80.21986389, 13.87736225], [80.21986389, 13.87680626], [80.22013855, 13.87681007], [80.22013855, 13.87597179], [80.22041321, 13.87597179], [80.22041321, 13.87514019], [80.22070313, 13.87514019], [80.22070313, 13.87430954], [80.22097015, 13.87430954], [80.22097015, 13.87319088], [80.22125244, 13.87319565], [80.22125244, 13.87236214], [80.2215271, 13.87236214], [80.2215271, 13.87152672], [80.22180176, 13.87152958], [80.22180176, 13.8706913], [80.22208405, 13.87069321], [80.22208405, 13.86986065], [80.2223587, 13.86986065], [80.2223587, 13.86875057], [80.22263336, 13.86875057], [80.22263336, 13.86792183], [80.22292328, 13.86792183], [80.22292328, 13.86681175], [80.22319794, 13.86681175], [80.22319794, 13.86597061], [80.2234726, 13.86597347], [80.2234726, 13.86486053], [80.22374725, 13.86486053], [80.22374725, 13.86375141], [80.22402954, 13.86375141], [80.22402954, 13.86292076], [80.22429657, 13.86292076], [80.22429657, 13.86181164], [80.22458649, 13.86181164], [80.22458649, 13.86097145], [80.22486115, 13.86097336], [80.22486115, 13.85986137], [80.2251358, 13.85986137], [80.2251358, 13.85847282], [80.22541809, 13.85847855], [80.22541809, 13.85653114], [80.22569275, 13.85653114], [80.22569275, 13.85569191], [80.22597504, 13.85569382], [80.22597504, 13.85486031], [80.22624969, 13.85486031], [80.22624969, 13.85430622], [80.22651672, 13.85431099], [80.22651672, 13.85375023], [80.22680664, 13.85375023], [80.22680664, 13.85235119], [80.2270813, 13.85235977], [80.2270813, 13.85180569], [80.22735596, 13.85181141], [80.22735596, 13.85124969], [80.22763824, 13.85124969], [80.22763824, 13.8506918], [80.2279129, 13.8506937], [80.2279129, 13.85013771], [80.22820282, 13.85013962], [80.22820282, 13.84986019], [80.22846985, 13.8498621], [80.22846985, 13.84875011], [80.22875977, 13.84875202], [80.22875977, 13.84735966], [80.22902679, 13.84735966], [80.22902679, 13.84681034], [80.22930908, 13.84681034], [80.22930908, 13.84624958], [80.22957611, 13.84624958], [80.22957611, 13.8459692], [80.2298584, 13.84597206], [80.2298584, 13.84514046], [80.23014069, 13.84514046], [80.23014069, 13.84486198], [80.23042297, 13.84486198], [80.23041534, 13.84430504], [80.23069763, 13.84430981], [80.23069763, 13.84375191], [80.23097229, 13.84375191], [80.23097229, 13.84236145], [80.23124695, 13.84236145], [80.23124695, 13.84208298], [80.23152924, 13.84208298], [80.23152924, 13.84152699], [80.23179626, 13.84153175], [80.23179626, 13.84125137], [80.23208618, 13.84125137], [80.23208618, 13.84041023], [80.23236084, 13.84041691], [80.23236084, 13.83986092], [80.23264313, 13.83986092], [80.2326355, 13.83874893], [80.23291779, 13.83875084], [80.23291779, 13.83819103], [80.23319244, 13.83819485], [80.23319244, 13.83763885], [80.2334671, 13.83764076], [80.2334671, 13.8373518], [80.23374939, 13.83736134], [80.23374939, 13.83652687], [80.23401642, 13.83653069], [80.23401642, 13.83542061], [80.23430634, 13.83542061], [80.23430634, 13.83458042], [80.23458099, 13.83458328], [80.23458099, 13.8340292], [80.23486328, 13.83403111], [80.23486328, 13.83318996], [80.23513794, 13.83319473], [80.23513794, 13.83236122], [80.23542023, 13.83236122], [80.23542023, 13.83180428], [80.23568726, 13.83181095], [80.23568726, 13.83154011], [80.23596954, 13.83154011], [80.23596954, 13.83125114], [80.23625183, 13.83125114], [80.23625183, 13.8309679], [80.23680878, 13.83097267], [80.23680878, 13.8306942], [80.23708344, 13.8306942], [80.23708344, 13.83013821], [80.23735809, 13.83014107], [80.23735809, 13.82931137], [80.23763275, 13.82931137], [80.23763275, 13.82847023], [80.23791504, 13.82847214], [80.23791504, 13.82763767], [80.23819733, 13.82763958], [80.23819733, 13.82681084], [80.23847198, 13.82681084], [80.23847198, 13.82625008], [80.23874664, 13.82625008], [80.23874664, 13.8259697], [80.23902893, 13.8259716], [80.23902893, 13.82569408], [80.23930359, 13.82569408], [80.23930359, 13.82513809], [80.23958588, 13.82514], [80.23958588, 13.82485962], [80.23986053, 13.82486153], [80.23986053, 13.82458401], [80.24013519, 13.82458401], [80.24013519, 13.82430553], [80.24041748, 13.82431126], [80.24041748, 13.82402992], [80.24069977, 13.82402992], [80.24069977, 13.82374954], [80.2409668, 13.82374954], [80.2409668, 13.82347202], [80.24124908, 13.82347202], [80.24124908, 13.82319355], [80.24153137, 13.82319355], [80.24153137, 13.82291794], [80.24208069, 13.82291985], [80.24208069, 13.82264042], [80.24236298, 13.82264042], [80.24236298, 13.82237053], [80.24263763, 13.82237053], [80.24263763, 13.82208157], [80.24291992, 13.82208443], [80.24291992, 13.82180595], [80.24318695, 13.82180977], [80.24318695, 13.82153034], [80.24346924, 13.82153034], [80.24346924, 13.82097244], [80.24375153, 13.82097244], [80.24375153, 13.82069397], [80.24402618, 13.82069397], [80.24402618, 13.82041645], [80.24430847, 13.82042027], [80.24430847, 13.81985855], [80.24458313, 13.81986237], [80.24458313, 13.81958389], [80.24485779, 13.81958389], [80.24485779, 13.81708336], [80.24514008, 13.81708336], [80.24514008, 13.81402683], [80.2454071, 13.8140316], [80.2454071, 13.81236076], [80.24569702, 13.81236076], [80.24569702, 13.81068993], [80.24597168, 13.81069469], [80.24597168, 13.80930519], [80.24624634, 13.80931187], [80.24624634, 13.80847073], [80.24652863, 13.80847263], [80.24652863, 13.80763912], [80.24680328, 13.80764103], [80.24680328, 13.80681133], [80.2470932, 13.80681133], [80.2470932, 13.80597019], [80.24736023, 13.80597305], [80.24736023, 13.80513859], [80.24764252, 13.80514145], [80.24764252, 13.80403137], [80.24791718, 13.80403137], [80.24791718, 13.8029213], [80.24819183, 13.8029213], [80.24819183, 13.80153275], [80.24846649, 13.80153275], [80.24846649, 13.80042076], [80.24874878, 13.80042076], [80.24874878, 13.79957962], [80.24791718, 13.79958439], [80.24791718, 13.79930592], [80.24764252, 13.79931068], [80.24764252, 13.79846954], [80.24791718, 13.7984724], [80.24791718, 13.79819393], [80.24819183, 13.79820061], [80.24819183, 13.79792023], [80.24846649, 13.79792023], [80.24846649, 13.79763985], [80.24874878, 13.79763985], [80.24874878, 13.79736042], [80.24903107, 13.79736233], [80.24903107, 13.79708195], [80.24930573, 13.79708195], [80.24930573, 13.79625034], [80.24958038, 13.79625034], [80.24957275, 13.79569244], [80.24986267, 13.79569435], [80.24986267, 13.79514027], [80.25013733, 13.79514027], [80.25013733, 13.79374981], [80.25041962, 13.79374981], [80.25041962, 13.79069138], [80.25013733, 13.79069328], [80.25013733, 13.78930473], [80.25041962, 13.78930473], [80.25041962, 13.78819466], [80.25069427, 13.78819466], [80.25069427, 13.78708267], [80.25096893, 13.78708267], [80.25096893, 13.78624916], [80.25152588, 13.78625965], [80.25152588, 13.78541946], [80.25180817, 13.78541946], [80.25180817, 13.78430939], [80.25208282, 13.78430939], [80.25208282, 13.78292179], [80.25235748, 13.78292179], [80.25235748, 13.78097057], [80.25208282, 13.78097343], [80.25208282, 13.78041744], [80.25235748, 13.78042126], [80.25235748, 13.78014088], [80.25208282, 13.78014088], [80.25208282, 13.77875137], [80.25180817, 13.77875137], [80.25180817, 13.77792072], [80.25152588, 13.77792072], [80.25152588, 13.77597046], [80.25125122, 13.77597237], [80.25125122, 13.7751379], [80.25096893, 13.77514267], [80.25096893, 13.77486038], [80.25125122, 13.77486038], [80.25125122, 13.77458382], [80.25096893, 13.77458191], [80.25096893, 13.77375031], [80.25068665, 13.77375031], [80.25068665, 13.77318954], [80.25041962, 13.77319431], [80.25041962, 13.77152824], [80.25013733, 13.77153015], [80.25013733, 13.77097034], [80.24986267, 13.77097225], [80.24986267, 13.76847172], [80.24958038, 13.76847172], [80.24958038, 13.76791573], [80.24931335, 13.76791954], [80.24931335, 13.76707935], [80.24903107, 13.76708412], [80.24903107, 13.76597214], [80.24930573, 13.76597214], [80.24930573, 13.76458359], [80.24903107, 13.76458359], [80.24903107, 13.76263905], [80.24874878, 13.76264191], [80.24874878, 13.7618103], [80.24846649, 13.7618103], [80.24846649, 13.76153183], [80.24819183, 13.76153183], [80.24819183, 13.75986099], [80.24791718, 13.75986099], [80.24791718, 13.75932121], [80.24764252, 13.75932121], [80.24764252, 13.75791931], [80.24736023, 13.75791931], [80.24736023, 13.75736141], [80.24708557, 13.75736141], [80.24708557, 13.75680542], [80.24680328, 13.75680923], [80.24680328, 13.75625134], [80.24652863, 13.75625134], [80.24652863, 13.75568962], [80.24624634, 13.75569534], [80.24624634, 13.75458336], [80.24597168, 13.75458336], [80.24597168, 13.75402737], [80.24569702, 13.75403118], [80.24569702, 13.75319004], [80.24541473, 13.75319481], [80.24541473, 13.75208473], [80.24514008, 13.75208473], [80.24514008, 13.75097275], [80.24485779, 13.75097275], [80.24485779, 13.75042057], [80.24458313, 13.75042057], [80.24458313, 13.74958038], [80.24485779, 13.74958229], [80.24485779, 13.74874973], [80.24458313, 13.74874973], [80.24458313, 13.74818993], [80.24430847, 13.74819374], [80.24430847, 13.74791622], [80.24402618, 13.74792099], [80.24402618, 13.74736023], [80.24375153, 13.74736023], [80.24375153, 13.74708366], [80.24346924, 13.74709129], [80.24346924, 13.74653053], [80.24318695, 13.74653053], [80.24318695, 13.74431133], [80.24291992, 13.74431133], [80.24291992, 13.74374962], [80.24263763, 13.74374962], [80.24263763, 13.74347019], [80.24236298, 13.7434721], [80.24236298, 13.74319363], [80.24208069, 13.74319363], [80.24208069, 13.74180603], [80.24180603, 13.74180984], [80.24180603, 13.74042034], [80.24153137, 13.74042034], [80.24153137, 13.73903179], [80.24124908, 13.73903179], [80.24124908, 13.73764038], [80.2409668, 13.73764038], [80.2409668, 13.73736191], [80.24069214, 13.73736191], [80.24069214, 13.73597145], [80.24041748, 13.73597145], [80.24041748, 13.73402691], [80.24014282, 13.73403168], [80.24014282, 13.73347092], [80.23986053, 13.73347092], [80.23986053, 13.73152924], [80.23958588, 13.73152924], [80.23958588, 13.73125076], [80.23929596, 13.73125076], [80.23929596, 13.72958088], [80.23902893, 13.72958279], [80.23902893, 13.72791672], [80.23874664, 13.72792053], [80.23874664, 13.72653103], [80.23847198, 13.72653103], [80.23847198, 13.72486115], [80.23819733, 13.72486115], [80.23819733, 13.72319412], [80.23791504, 13.72319412], [80.23791504, 13.72263813], [80.23763275, 13.72264099], [80.23763275, 13.72181129], [80.23792267, 13.72181129], [80.23792267, 13.72042084], [80.23763275, 13.72042084], [80.23763275, 13.71903038], [80.23735809, 13.71903038], [80.23735809, 13.71681118], [80.23707581, 13.71681118], [80.23707581, 13.71597195], [80.23680878, 13.71597195], [80.23680878, 13.71374989], [80.23652649, 13.71375179], [80.23652649, 13.71319103], [80.23625183, 13.7131958], [80.23625183, 13.70930481], [80.23596954, 13.70930958], [80.23596954, 13.70875168], [80.23568726, 13.70875168], [80.23568726, 13.7068119], [80.23542023, 13.7068119], [80.23542023, 13.70347118], [80.23513794, 13.70347309], [80.23513794, 13.70125103], [80.23486328, 13.70125103], [80.23486328, 13.70042133], [80.23457336, 13.70042133], [80.23457336, 13.69818974], [80.23486328, 13.69819546], [80.23486328, 13.69763947], [80.23430634, 13.69764137], [80.23430634, 13.69736004], [80.23401642, 13.69736004], [80.23401642, 13.69707966], [80.23430634, 13.69708157], [80.23430634, 13.69513798], [80.23401642, 13.69514275], [80.23401642, 13.69403076], [80.23430634, 13.69403076], [80.23430634, 13.69318962], [80.23402405, 13.69319439], [80.23402405, 13.69180584], [80.23430634, 13.69181061], [80.23430634, 13.69069195], [80.23402405, 13.69069386], [80.23402405, 13.69041634], [80.23374939, 13.6904211], [80.23374939, 13.68931103], [80.2334671, 13.68931103], [80.2334671, 13.68902969], [80.23374939, 13.68902969], [80.23374939, 13.68624973], [80.2334671, 13.68624973], [80.2334671, 13.6837492], [80.23374939, 13.6837492], [80.23374939, 13.68292046], [80.23401642, 13.68292046], [80.23401642, 13.68264198], [80.23374939, 13.68264198], [80.23374939, 13.68181038], [80.2334671, 13.68181038], [80.2334671, 13.68153191], [80.23319244, 13.68153191], [80.23319244, 13.68097115], [80.23347473, 13.68097115], [80.23347473, 13.68041706], [80.23374939, 13.68042183], [80.23374939, 13.67764091], [80.2334671, 13.67764091], [80.2334671, 13.67736053], [80.23374939, 13.67736053], [80.23374939, 13.67569542], [80.23347473, 13.67569542], [80.23347473, 13.67319489], [80.23374939, 13.67319489], [80.23374939, 13.67291737], [80.2334671, 13.67292118], [80.2334671, 13.67208004], [80.23319244, 13.6720829], [80.23319244, 13.6706953], [80.23291779, 13.6706953], [80.23291779, 13.67041683], [80.23264313, 13.67042065], [80.23264313, 13.66958046], [80.23291779, 13.66958237], [80.23291779, 13.66930676], [80.23374939, 13.66931057], [80.23374939, 13.66903114], [80.2334671, 13.66903114], [80.2334671, 13.66874981], [80.23319244, 13.66874981], [80.23319244, 13.66764069], [80.2334671, 13.66764069], [80.2334671, 13.66736031], [80.23402405, 13.66736031], [80.23402405, 13.66652775], [80.23374939, 13.66653061], [80.23374939, 13.66596985], [80.23347473, 13.66597176], [80.23347473, 13.66541576], [80.23319244, 13.66542053], [80.23319244, 13.66458035], [80.23291779, 13.66458416], [80.23291779, 13.66374969], [80.2334671, 13.66374969], [80.2334671, 13.66347027], [80.23402405, 13.66347218], [80.23402405, 13.6631937], [80.23374939, 13.6631937], [80.23374939, 13.66152763], [80.23401642, 13.66152954], [80.23401642, 13.6598711], [80.23430634, 13.6598711], [80.23430634, 13.65792179], [80.23401642, 13.65792179], [80.23401642, 13.65597057], [80.23430634, 13.65597057], [80.23430634, 13.65513897], [80.23401642, 13.65514183], [80.23401642, 13.65486145], [80.23430634, 13.65486145], [80.23430634, 13.65402699], [80.23457336, 13.65403175], [80.23457336, 13.65263939], [80.23486328, 13.65263939], [80.23486328, 13.65152931], [80.23457336, 13.65152931], [80.23457336, 13.64986134], [80.23486328, 13.64986134], [80.23486328, 13.64875126], [80.23513794, 13.64875126], [80.23513794, 13.64818954], [80.23542023, 13.64819527], [80.23542023, 13.64708328], [80.23569489, 13.64708328], [80.23569489, 13.64513874], [80.23596954, 13.64514065], [80.23596954, 13.64153099], [80.23625183, 13.64153099], [80.23625183, 13.63986015], [80.23652649, 13.63986015], [80.23652649, 13.6384716], [80.23680878, 13.6384716], [80.23680878, 13.63763809], [80.23707581, 13.63764], [80.23707581, 13.63652992], [80.23735809, 13.63652992], [80.23735809, 13.63403034], [80.23763275, 13.63403034], [80.23763275, 13.6331892], [80.23791504, 13.63319397], [80.23791504, 13.63263988], [80.23819733, 13.63264179], [80.23819733, 13.63181019], [80.23847198, 13.63181019], [80.23847198, 13.63041973], [80.23874664, 13.63041973], [80.23874664, 13.62930965], [80.23847198, 13.62930965], [80.23847198, 13.62874889], [80.23874664, 13.62874889], [80.23874664, 13.62792015], [80.23902893, 13.62792015], [80.23902893, 13.62708092], [80.23930359, 13.62708282], [80.23930359, 13.62624931], [80.23958588, 13.62624931], [80.23958588, 13.62513924], [80.23986053, 13.62513924], [80.23986053, 13.62458134], [80.24013519, 13.62458324], [80.24013519, 13.62319469], [80.24041748, 13.62319469], [80.24041748, 13.62236118], [80.24069214, 13.62236118], [80.24069214, 13.62180519], [80.2409668, 13.62181187], [80.2409668, 13.62125111], [80.24124908, 13.62125111], [80.24124908, 13.61958027], [80.24153137, 13.61958313], [80.24153137, 13.61902905], [80.24180603, 13.61903095], [80.24180603, 13.61736107], [80.24208069, 13.61736107], [80.24208069, 13.61625099], [80.24236298, 13.61625099], [80.24236298, 13.61569023], [80.24263763, 13.61569405], [80.24263763, 13.61541557], [80.24291992, 13.6154213], [80.24291992, 13.61485958], [80.24319458, 13.6148634], [80.24319458, 13.61375046], [80.24346924, 13.61375046], [80.24346924, 13.61347008], [80.24375153, 13.61347198], [80.24375153, 13.61291599], [80.24402618, 13.61292076], [80.24402618, 13.61236], [80.24430847, 13.61236], [80.24430847, 13.61153126], [80.24458313, 13.61153126], [80.24458313, 13.61096954], [80.24485779, 13.6109724], [80.24485779, 13.61041641], [80.24514008, 13.61042118], [80.24514008, 13.60986042], [80.24541473, 13.60986233], [80.24541473, 13.60930634], [80.24569702, 13.6093111], [80.24569702, 13.60876083], [80.24597168, 13.60876083], [80.24597168, 13.60819244], [80.24624634, 13.60819435], [80.24624634, 13.60764027], [80.24652863, 13.60764027], [80.24652863, 13.60707855], [80.24680328, 13.60708427], [80.24680328, 13.60652828], [80.2470932, 13.60653019], [80.2470932, 13.60624981], [80.24736023, 13.60624981], [80.24736023, 13.60569096], [80.24764252, 13.60569382], [80.24764252, 13.60513973], [80.24791718, 13.60513973], [80.24791718, 13.60458088], [80.24819183, 13.60458374], [80.24819183, 13.60402775], [80.24846649, 13.60402966], [80.24846649, 13.60346889], [80.24874878, 13.6034708], [80.24874878, 13.60291767], [80.24903107, 13.60291958], [80.24903107, 13.60236168], [80.24931335, 13.60236168], [80.24930573, 13.60180473], [80.24957275, 13.60181046], [80.24957275, 13.6012516], [80.24986267, 13.6012516], [80.24986267, 13.60069084], [80.25013733, 13.60069466], [80.25013733, 13.60041714], [80.25041962, 13.60042191], [80.25041962, 13.59986115], [80.25069427, 13.59986115], [80.25069427, 13.59930515], [80.25096893, 13.59930992], [80.25096893, 13.59875107], [80.25125122, 13.59875107], [80.25125122, 13.59847069], [80.25152588, 13.5984726], [80.25152588, 13.5979166], [80.25180817, 13.59792042], [80.25180817, 13.59736061], [80.25208282, 13.59736061], [80.25208282, 13.59708118], [80.25235748, 13.59708309], [80.25235748, 13.5965271], [80.25263977, 13.59653187], [80.25263977, 13.59625053], [80.2529068, 13.59625053], [80.2529068, 13.59597111], [80.25319672, 13.59597301], [80.25319672, 13.59541702], [80.25347137, 13.59542179], [80.25347137, 13.59514141], [80.25374603, 13.59514141], [80.25374603, 13.59486103], [80.25347137, 13.59486103], [80.25347137, 13.59431171], [80.25374603, 13.59431171], [80.25374603, 13.59375095], [80.25402832, 13.59375095], [80.25402832, 13.59346199], [80.25375366, 13.59347343], [80.25375366, 13.59319496], [80.25402832, 13.59319496], [80.25402832, 13.59291744], [80.2545929, 13.59292126], [80.2545929, 13.59236145], [80.25485992, 13.59236145], [80.25485992, 13.59125137], [80.25514221, 13.59125137], [80.25514221, 13.59068966], [80.25541687, 13.59069538], [80.25541687, 13.58985996], [80.25569916, 13.58985996], [80.25569153, 13.58958244], [80.25597382, 13.58958244], [80.25597382, 13.58930683], [80.25624847, 13.58931065], [80.25624847, 13.58847046], [80.25653076, 13.58847237], [80.25653076, 13.58791637], [80.25681305, 13.58792114], [80.25681305, 13.58736038], [80.25708008, 13.58736038], [80.25708008, 13.5868063], [80.25736237, 13.58681107], [80.25736237, 13.58625031], [80.25763702, 13.58625031], [80.25763702, 13.58596992], [80.25791931, 13.58597183], [80.25791931, 13.58541584], [80.25818634, 13.58542061], [80.25818634, 13.58514023], [80.25846863, 13.58514023], [80.25846863, 13.58459091], [80.25874329, 13.58459091], [80.25874329, 13.58403015], [80.2590332, 13.58403015], [80.2590332, 13.58125019], [80.25930786, 13.58125019], [80.25930786, 13.58096981], [80.25958252, 13.58097172], [80.25958252, 13.58041573], [80.25985718, 13.58041954], [80.25985718, 13.57985973], [80.26013947, 13.57985973], [80.26013947, 13.57931042], [80.26040649, 13.57931042], [80.26040649, 13.57903004], [80.26069641, 13.57903004], [80.26069641, 13.57845974], [80.26097107, 13.57847214], [80.26097107, 13.57819366], [80.26125336, 13.57819366], [80.26125336, 13.57791805], [80.26152802, 13.57791996], [80.26152802, 13.5773592], [80.26180267, 13.57736206], [80.26180267, 13.5765276], [80.26207733, 13.57653046], [80.26207733, 13.57625198], [80.26235962, 13.57625198], [80.26235962, 13.57569122], [80.26264191, 13.57569313], [80.26264191, 13.57541847], [80.26291656, 13.57542038], [80.26291656, 13.57486057], [80.26319122, 13.57486057], [80.26319122, 13.57402706], [80.26346588, 13.57403183], [80.26346588, 13.5737524], [80.26374817, 13.5737524], [80.26374817, 13.57292175], [80.26403046, 13.57292175], [80.26403046, 13.57208061], [80.26430511, 13.57208347], [80.26430511, 13.57124901], [80.26457977, 13.57125092], [80.26457977, 13.57069111], [80.26486206, 13.57069302], [80.26486206, 13.57013893], [80.26513672, 13.57014084], [80.26513672, 13.56986141], [80.26541901, 13.56986141], [80.26541901, 13.56930542], [80.26568604, 13.56931019], [80.26568604, 13.56875134], [80.26597595, 13.56875134], [80.26597595, 13.56818962], [80.26625061, 13.56819534], [80.26625061, 13.56763935], [80.2665329, 13.56764126], [80.2665329, 13.56681156], [80.26680756, 13.56681156], [80.26680756, 13.5662508], [80.26708221, 13.5662508], [80.26708221, 13.56569004], [80.2673645, 13.56569481], [80.2673645, 13.56513882], [80.26763916, 13.56514072], [80.26763916, 13.56457996], [80.26791382, 13.56458473], [80.26791382, 13.56402874], [80.26819611, 13.56403065], [80.26819611, 13.56319046], [80.26847076, 13.56319523], [80.26847076, 13.56263828], [80.26875305, 13.56264114], [80.26875305, 13.56245422], [80.26431274, 13.56014061], [80.26431274, 13.56124973], [80.26403046, 13.56124973], [80.26403046, 13.56153107], [80.26374817, 13.56152916], [80.26374817, 13.56208229], [80.26346588, 13.56208038], [80.26346588, 13.56235981], [80.26319122, 13.56235981], [80.26319122, 13.56264114], [80.26291656, 13.56264114], [80.26291656, 13.56292057], [80.26264191, 13.56291676], [80.26264191, 13.56347275], [80.26235962, 13.5634613], [80.26235962, 13.56375122], [80.26207733, 13.56375122], [80.26207733, 13.56403065], [80.26180267, 13.56403065], [80.26180267, 13.56431103], [80.26152802, 13.56430531], [80.26152802, 13.56458473], [80.26125336, 13.56458473], [80.26125336, 13.5648613], [80.26097107, 13.5648613], [80.26097107, 13.56514072], [80.26069641, 13.56514072], [80.26069641, 13.5654192], [80.26013947, 13.56541729], [80.26013947, 13.56569481], [80.25986481, 13.56569481], [80.25986481, 13.56597328], [80.25958252, 13.56597137], [80.25958252, 13.5662508], [80.25930786, 13.5662508], [80.25930786, 13.56652737], [80.2590332, 13.56651974], [80.2590332, 13.56681156], [80.25875092, 13.56680489], [80.25875092, 13.56708336], [80.25846863, 13.56708145], [80.25846863, 13.56736088], [80.25818634, 13.56736088], [80.25818634, 13.56764126], [80.25791931, 13.56764126], [80.25791931, 13.56792164], [80.25736237, 13.56791687], [80.25736237, 13.56819534], [80.25708008, 13.56819534], [80.25708008, 13.56847095], [80.25680542, 13.56847095], [80.25681305, 13.56875134], [80.25624847, 13.56875134], [80.25624847, 13.56903076], [80.25596619, 13.56903076], [80.25596619, 13.56931019], [80.25569153, 13.56930542], [80.25569153, 13.56958294], [80.25541687, 13.56958294], [80.25541687, 13.56986141], [80.25514221, 13.56986141], [80.25514221, 13.57014084], [80.2545929, 13.57014084], [80.2545929, 13.57041931], [80.25430298, 13.5704174], [80.25430298, 13.57069111], [80.25402832, 13.57069492], [80.25402832, 13.5709734], [80.2529068, 13.57097054], [80.2529068, 13.57125092], [80.25208282, 13.57125092], [80.25208282, 13.57152939], [80.25096893, 13.57152939], [80.25096893, 13.57180977], [80.25041962, 13.571805], [80.25041962, 13.57208347], [80.24986267, 13.57208347], [80.24986267, 13.57347107], [80.25013733, 13.57347107], [80.25013733, 13.57486057], [80.25041962, 13.57486057], [80.25041962, 13.57514191], [80.25069427, 13.57514], [80.25069427, 13.57569313], [80.25096893, 13.57569313], [80.25096893, 13.57597065], [80.25125122, 13.57597065], [80.25125122, 13.57763958], [80.25096893, 13.57763958], [80.25096893, 13.57874966], [80.25068665, 13.57874966], [80.25068665, 13.57931042], [80.25041962, 13.57930565], [80.25041962, 13.57958412], [80.25013733, 13.57957935], [80.25013733, 13.57985973], [80.24986267, 13.57985973], [80.24986267, 13.58041954], [80.24958038, 13.58041573], [80.24958038, 13.5806942], [80.24930573, 13.5806942], [80.24930573, 13.58097172], [80.24903107, 13.58096981], [80.24903107, 13.58125019], [80.24847412, 13.58125019], [80.24847412, 13.58152771], [80.24819183, 13.58152103], [80.24819183, 13.58181095], [80.24764252, 13.58180618], [80.24764252, 13.5820837], [80.24736023, 13.5820837], [80.24736023, 13.58236217], [80.2470932, 13.58236027], [80.2470932, 13.58263969], [80.24652863, 13.58263969], [80.24652863, 13.58292103], [80.24624634, 13.58292103], [80.24624634, 13.58403015], [80.24597168, 13.58403015], [80.24597168, 13.58431053], [80.2454071, 13.58431053], [80.2454071, 13.58459091], [80.24514008, 13.58458424], [80.24514008, 13.58485985], [80.24485779, 13.58485985], [80.24485779, 13.58514023], [80.24458313, 13.58514023], [80.24458313, 13.58542061], [80.24430847, 13.58542061], [80.24430847, 13.58625031], [80.24402618, 13.58625031], [80.24402618, 13.58708191], [80.24375916, 13.58708], [80.24375916, 13.5876503], [80.24346924, 13.5876503], [80.24346924, 13.58792114], [80.24318695, 13.58792114], [80.24318695, 13.58931065], [80.24291992, 13.58931065], [80.24291992, 13.5901413], [80.24263763, 13.59013939], [80.24263763, 13.5909729], [80.24236298, 13.59097004], [80.24236298, 13.59180927], [80.24263763, 13.59180546], [80.24263763, 13.59236145], [80.24236298, 13.59236145], [80.24236298, 13.59347343], [80.24208069, 13.59347343], [80.24208069, 13.59458256], [80.24180603, 13.59458065], [80.24180603, 13.59542179], [80.24153137, 13.59541702], [80.24153137, 13.59569454], [80.24124908, 13.59569454], [80.24124908, 13.59597301], [80.2409668, 13.59597111], [80.2409668, 13.59682083], [80.24069214, 13.59680462], [80.24069214, 13.59708309], [80.24041748, 13.59708309], [80.24041748, 13.59736061], [80.24014282, 13.59736061], [80.24014282, 13.59764099], [80.23986053, 13.59764099], [80.23986053, 13.59792042], [80.23958588, 13.5979166], [80.23958588, 13.5984726], [80.23929596, 13.59847069], [80.23929596, 13.59875107], [80.23902893, 13.59875107], [80.23902893, 13.59902859], [80.23847198, 13.59902859], [80.23847198, 13.59930992], [80.23819733, 13.59930992], [80.23819733, 13.5995903], [80.23791504, 13.59958267], [80.23791504, 13.59986115], [80.23735809, 13.59986115], [80.23735809, 13.60042191], [80.23708344, 13.60041714], [80.23708344, 13.60069466], [80.23680878, 13.60069466], [80.23680878, 13.60097122], [80.23652649, 13.60097122], [80.23652649, 13.6012516], [80.23625183, 13.6012516], [80.23625183, 13.60153198], [80.23596954, 13.60153198], [80.23596954, 13.60181046], [80.23542023, 13.60180473], [80.23542023, 13.60208321], [80.23513794, 13.6020813], [80.23513794, 13.60236168], [80.23458099, 13.60236168], [80.23458099, 13.60264015], [80.23430634, 13.60262966], [80.23430634, 13.60291958], [80.23402405, 13.60291767], [80.23402405, 13.60319328], [80.23347473, 13.60319328], [80.23347473, 13.6034708], [80.23319244, 13.60346889], [80.23319244, 13.60375023], [80.23264313, 13.60375023], [80.23264313, 13.60402966], [80.2325058, 13.60402775], [80.23236084, 13.60402966], [80.23236084, 13.60431004], [80.23180389, 13.60430622], [80.23180389, 13.60458374], [80.23097229, 13.60458374], [80.23097229, 13.60486221], [80.23069763, 13.60485935], [80.23069763, 13.60513973], [80.23042297, 13.60513973], [80.23042297, 13.60542011], [80.2298584, 13.6054163], [80.2298584, 13.60569382], [80.22958374, 13.60569382], [80.22958374, 13.60597229], [80.22930908, 13.60596943], [80.22930908, 13.60624981], [80.22902679, 13.60624981], [80.22902679, 13.60653019], [80.2279129, 13.60653019], [80.2279129, 13.60680962], [80.22736359, 13.6068058], [80.22736359, 13.60708427], [80.2270813, 13.60707855], [80.2270813, 13.60736179], [80.22680664, 13.60736179], [80.22680664, 13.60764027], [80.22651672, 13.60764027], [80.22651672, 13.60791969], [80.22680664, 13.60791588], [80.22680664, 13.60819435], [80.2270813, 13.60819244], [80.2270813, 13.60876083], [80.22651672, 13.60876083], [80.22651672, 13.60903263], [80.22541809, 13.60902786], [80.22541809, 13.60986233], [80.22486115, 13.60986042], [80.22486115, 13.61182022], [80.22458649, 13.61182022], [80.22458649, 13.61264038], [80.22429657, 13.61264038], [80.22429657, 13.61292076], [80.22402954, 13.61291599], [80.22402954, 13.61347198], [80.22374725, 13.61347008], [80.22374725, 13.61375046], [80.2234726, 13.61375046], [80.2234726, 13.61403084], [80.22319794, 13.61403084], [80.22319794, 13.61431122], [80.22291565, 13.61430645], [80.22291565, 13.6148634], [80.22263336, 13.61485958], [80.22263336, 13.61514091], [80.2223587, 13.61513805], [80.2223587, 13.61597347], [80.22180939, 13.61596966], [80.22180176, 13.61625099], [80.2215271, 13.61625099], [80.2215271, 13.61708164], [80.22125244, 13.61707973], [80.22125244, 13.61792088], [80.22097015, 13.61791706], [80.22097015, 13.61847305], [80.22070313, 13.61847019], [80.22070313, 13.61931133], [80.22041321, 13.61930466], [80.22041321, 13.61958313], [80.22013855, 13.61958027], [80.22013855, 13.62014103], [80.21985626, 13.62014103], [80.21985626, 13.62070179], [80.2195816, 13.62069511], [80.2195816, 13.62097263], [80.21930695, 13.62097073], [80.21930695, 13.62125111], [80.21901703, 13.62125111], [80.21901703, 13.62153053], [80.21875, 13.62153053], [80.21875, 13.62181187], [80.21848297, 13.62181187], [80.21848297, 13.62264061], [80.21819305, 13.6226387], [80.21819305, 13.62347317], [80.21763611, 13.62347126], [80.21763611, 13.62376022], [80.21736145, 13.62376022], [80.21736145, 13.62403202], [80.21708679, 13.62403202], [80.21708679, 13.62430954], [80.2168045, 13.62430477], [80.2168045, 13.62458324], [80.21652985, 13.62458134], [80.21652985, 13.62486076], [80.21624756, 13.62486076], [80.21624756, 13.62513924], [80.2159729, 13.62513924], [80.2159729, 13.62541962], [80.21569824, 13.62541676], [80.21569824, 13.62569523], [80.21541595, 13.62569141], [80.21541595, 13.62597084], [80.2151413, 13.62597084], [80.2151413, 13.62624931], [80.21485901, 13.62624931], [80.21485901, 13.6265316], [80.21458435, 13.62652683], [80.21458435, 13.62680531], [80.21430206, 13.62680531], [80.21430206, 13.62708282], [80.2140274, 13.62708282], [80.2140274, 13.6273613], [80.21346283, 13.6273613], [80.21346283, 13.62764168], [80.21290588, 13.62764168], [80.21290588, 13.62792015], [80.2123642, 13.62791538], [80.2123642, 13.62819576], [80.21180725, 13.62819576], [80.21180725, 13.62847137], [80.21125031, 13.62847137], [80.21125031, 13.62874889], [80.21069336, 13.62874889], [80.21069336, 13.62903023], [80.2104187, 13.62903023], [80.2104187, 13.62930965], [80.20986176, 13.62930489], [80.20986176, 13.62958431], [80.20903015, 13.62957001], [80.20903015, 13.62986183], [80.20791626, 13.62986183], [80.20791626, 13.6301403], [80.20707703, 13.6301403], [80.20707703, 13.63041973], [80.20680237, 13.63041782], [80.20680237, 13.63069344], [80.20652771, 13.63069344], [80.20652771, 13.63097191], [80.20597076, 13.63097191], [80.20597076, 13.63125038], [80.20540619, 13.63125038], [80.20540619, 13.63152981], [80.20458984, 13.63152981], [80.20458984, 13.63181019], [80.20402527, 13.63180637], [80.20402527, 13.63208389], [80.20347595, 13.63208389], [80.20347595, 13.63180637], [80.20319366, 13.63180637], [80.20319366, 13.63208389], [80.20236206, 13.63208389], [80.20236206, 13.63236237], [80.20207977, 13.63236046], [80.20207977, 13.63264179], [80.20180511, 13.63263988], [80.20181274, 13.6331892], [80.20124817, 13.63319588], [80.20124817, 13.63347244], [80.20096588, 13.63346863], [80.20096588, 13.63374996], [80.20041656, 13.63374996], [80.20041656, 13.63346863], [80.19985962, 13.63346863], [80.19985962, 13.63374996], [80.19930267, 13.63374996], [80.19930267, 13.63403034], [80.19902802, 13.63403034], [80.19902802, 13.63514042], [80.19875336, 13.63514042], [80.19875336, 13.63541985], [80.19845581, 13.63541985], [80.19845581, 13.63570118], [80.19791412, 13.63569355], [80.19791412, 13.63597202], [80.19735718, 13.63597202], [80.19735718, 13.63624954], [80.19708252, 13.63624954], [80.19708252, 13.63652992], [80.1965332, 13.63652992], [80.1965332, 13.63681126], [80.19625092, 13.63680553], [80.19625092, 13.63708401], [80.19569397, 13.63708401], [80.19569397, 13.63736153], [80.19513702, 13.63735962], [80.19513702, 13.63764], [80.19486237, 13.63764], [80.19486237, 13.63792133], [80.19430542, 13.63791561], [80.19430542, 13.63819408], [80.19403076, 13.63819408], [80.19403076, 13.63875008], [80.19374847, 13.63874054], [80.19374847, 13.63931084], [80.19347382, 13.63930416], [80.19347382, 13.63958359], [80.19319153, 13.63958359], [80.19319153, 13.63986015], [80.19264984, 13.63986015], [80.19264984, 13.64013958], [80.19235992, 13.64013958], [80.19235992, 13.64042091], [80.19180298, 13.64041615], [80.19180298, 13.64097214], [80.19152832, 13.64097023], [80.19152832, 13.64124966], [80.19097137, 13.64124966], [80.19097137, 13.6418066], [80.19069672, 13.6418066], [80.19069672, 13.64208221], [80.1904068, 13.64208031], [80.1904068, 13.64235973], [80.19013977, 13.64235973], [80.19013977, 13.64264107], [80.18985748, 13.64263821], [80.18985748, 13.64319515], [80.18958282, 13.64319038], [80.18958282, 13.64375114], [80.18930817, 13.64375114], [80.18930817, 13.64403057], [80.18902588, 13.64403057], [80.18902588, 13.64431095], [80.18875122, 13.64431095], [80.18875122, 13.6448698], [80.18846893, 13.6448698], [80.18846893, 13.64681244], [80.18818665, 13.64681244], [80.18818665, 13.6479311], [80.18791962, 13.64791679], [80.18791962, 13.64819527], [80.18763733, 13.64818954], [80.18763733, 13.64931202], [80.18791962, 13.64931202], [80.18791962, 13.65152931], [80.18819427, 13.6515274], [80.18819427, 13.65375137], [80.18846893, 13.65375137], [80.18846893, 13.65458298], [80.18875122, 13.65458298], [80.18875122, 13.65569305], [80.18902588, 13.65569115], [80.18902588, 13.65653038], [80.18930817, 13.65653038], [80.18930817, 13.65792179], [80.18958282, 13.65791798], [80.18958282, 13.65819359], [80.18930817, 13.65819359], [80.18930817, 13.65847206], [80.18958282, 13.65847206], [80.18958282, 13.65958405], [80.18985748, 13.65957928], [80.18985748, 13.66014004], [80.19013977, 13.66014004], [80.19013977, 13.6623621], [80.18985748, 13.66236019], [80.18985748, 13.66263962], [80.19013977, 13.66263771], [80.19013977, 13.6631937], [80.18985748, 13.6631918], [80.18985748, 13.66431141], [80.18958282, 13.66431141], [80.18958282, 13.66486168], [80.18930817, 13.66485977], [80.18930817, 13.66597176], [80.18902588, 13.66596985], [80.18902588, 13.66681099], [80.18875122, 13.66680622], [80.18875122, 13.66736031], [80.18846893, 13.66736031], [80.18846893, 13.66764069], [80.18818665, 13.66764069], [80.18818665, 13.66792107], [80.18791962, 13.66792107], [80.18791962, 13.66874981], [80.18763733, 13.66874981], [80.18763733, 13.66903114], [80.18736267, 13.66902924], [80.18736267, 13.66958237], [80.18708038, 13.66958046], [80.18708038, 13.67014122], [80.18651581, 13.67014122], [80.18651581, 13.67042065], [80.18624878, 13.67041683], [80.18624878, 13.67097282], [80.18596649, 13.67096996], [80.18596649, 13.6712513], [80.18541718, 13.6712513], [80.18541718, 13.67153072], [80.18486023, 13.67152882], [80.18486023, 13.6720829], [80.18430328, 13.67208004], [80.18430328, 13.6726408], [80.18402863, 13.6726408], [80.18402863, 13.67292118], [80.18374634, 13.67291737], [80.18374634, 13.67347336], [80.18345642, 13.67347145], [80.18345642, 13.67375088], [80.18319702, 13.67375088], [80.18319702, 13.67431164], [80.18264008, 13.67430687], [80.18264008, 13.67458344], [80.18208313, 13.67458057], [80.18208313, 13.67486954], [80.18180847, 13.67486954], [80.18180847, 13.67514133], [80.18152618, 13.67514133], [80.18152618, 13.67542171], [80.18096924, 13.67541695], [80.18096924, 13.67569542], [80.18041992, 13.6756897], [80.18041992, 13.67625141], [80.17986298, 13.67625141], [80.17986298, 13.67653084], [80.17958069, 13.67653084], [80.17958069, 13.67681026], [80.17930603, 13.67680454], [80.17930603, 13.67708302], [80.17903137, 13.67708302], [80.17903137, 13.67791653], [80.17847443, 13.67791653], [80.17847443, 13.67847347], [80.17819214, 13.67847061], [80.17819214, 13.67875099], [80.17764282, 13.67875099], [80.17764282, 13.67902946], [80.17791748, 13.67902946], [80.17791748, 13.67931175], [80.17763519, 13.67930508], [80.17763519, 13.6795826], [80.17736053, 13.67958069], [80.17736053, 13.6801424], [80.17708588, 13.6801424], [80.17708588, 13.68042183], [80.17680359, 13.68041706], [80.17680359, 13.68069458], [80.17652893, 13.68069458], [80.17652893, 13.68097115], [80.17624664, 13.68097115], [80.17624664, 13.68125153], [80.17597198, 13.68125153], [80.17597198, 13.68153191], [80.17514038, 13.68153191], [80.17514038, 13.68181038], [80.17458344, 13.68180466], [80.17458344, 13.68208313], [80.17402649, 13.68208122], [80.17402649, 13.68236065], [80.17375183, 13.68236065], [80.17375183, 13.68319321], [80.17346954, 13.68319321], [80.17346954, 13.68347359], [80.17292023, 13.68347073], [80.17292023, 13.6837492], [80.17263794, 13.6837492], [80.17263794, 13.68486214], [80.17236328, 13.68485928], [80.17236328, 13.68542004], [80.17208099, 13.68541622], [80.17208099, 13.68597221], [80.17180634, 13.68596935], [80.17180634, 13.68624973], [80.17151642, 13.68624973], [80.17151642, 13.68735981], [80.17180634, 13.68735981], [80.17180634, 13.68791962], [80.17151642, 13.68791962], [80.17151642, 13.68847179], [80.17124939, 13.68847179], [80.17124939, 13.68875027], [80.17097473, 13.68875027], [80.17097473, 13.68958378], [80.17041779, 13.68958378], [80.17041779, 13.68986225], [80.16986084, 13.68986225], [80.16986084, 13.68958378], [80.16958618, 13.68958378], [80.16958618, 13.68930626], [80.16929626, 13.68931103], [80.16929626, 13.68819237], [80.16902924, 13.68819427], [80.16902924, 13.68735981], [80.16874695, 13.68735981], [80.16874695, 13.68680954], [80.16652679, 13.68680573], [80.16652679, 13.6870842], [80.16625214, 13.68707943], [80.16625214, 13.68764019], [80.16596985, 13.68764019], [80.16596985, 13.68819427], [80.16569519, 13.68819427], [80.16570282, 13.68875027], [80.16485596, 13.68875027], [80.16485596, 13.68902969], [80.16430664, 13.68902969], [80.16430664, 13.68931103], [80.16402435, 13.68930626], [80.16402435, 13.68958378], [80.16374969, 13.68958378], [80.16374969, 13.68986225], [80.16348267, 13.68985081], [80.16348267, 13.69014168], [80.16319275, 13.69014168], [80.16319275, 13.6904211], [80.16291809, 13.69041634], [80.16291809, 13.69069386], [80.1626358, 13.69069386], [80.1626358, 13.69097233], [80.16234589, 13.69097042], [80.16234589, 13.69153023], [80.16208649, 13.69153023], [80.16208649, 13.69181061], [80.16179657, 13.69181061], [80.16179657, 13.69431114], [80.16152954, 13.69430637], [80.16152954, 13.69458199], [80.16124725, 13.69458199], [80.16124725, 13.69486332], [80.1609726, 13.69486046], [80.1609726, 13.69514275], [80.16069794, 13.69514275], [80.16069794, 13.69542122], [80.16041565, 13.69541645], [80.16042328, 13.69569016], [80.16014099, 13.69570065], [80.16014099, 13.69625092], [80.1598587, 13.69625092], [80.1598587, 13.69681072], [80.15957642, 13.69681072], [80.15957642, 13.69736004], [80.15930939, 13.69736004], [80.1592865, 13.69764137], [80.1590271, 13.69764137], [80.1590271, 13.6979208], [80.15847015, 13.69791698], [80.15847015, 13.69819546], [80.1581955, 13.69819546], [80.1581955, 13.69847298], [80.15791321, 13.69847012], [80.15791321, 13.69904041], [80.15763855, 13.69904041], [80.15763855, 13.69931126], [80.15736389, 13.69930458], [80.15736389, 13.69986057], [80.1570816, 13.69986057], [80.1570816, 13.69995022], [80.1570816, 13.70014095], [80.15680695, 13.70014095], [80.15680695, 13.70042133], [80.15652466, 13.70041656], [80.15652466, 13.70069504], [80.15625, 13.70069504], [80.15625, 13.70097256], [80.15598297, 13.70097065], [80.15598297, 13.70125103], [80.15569305, 13.70125103], [80.15569305, 13.70153141], [80.1554184, 13.70153141], [80.1554184, 13.70181179], [80.15513611, 13.70180511], [80.15513611, 13.70208263], [80.15486145, 13.70208073], [80.15486145, 13.70264053], [80.15458679, 13.70264053], [80.15458679, 13.70292187], [80.15402985, 13.7029171], [80.15402985, 13.70319462], [80.1534729, 13.70319462], [80.1534729, 13.7029171], [80.15208435, 13.7029171], [80.15208435, 13.70319462], [80.1515274, 13.70319462], [80.1515274, 13.70263863], [80.14930725, 13.70264053], [80.14930725, 13.70292187], [80.14875031, 13.7029171], [80.14875031, 13.70319462], [80.14848328, 13.7031908], [80.14848328, 13.70375061], [80.14819336, 13.70375061], [80.14819336, 13.70403194], [80.1479187, 13.70403194], [80.1479187, 13.70431042], [80.14763641, 13.70431042], [80.14763641, 13.70403194], [80.1473465, 13.70403194], [80.1473465, 13.70375061], [80.1470871, 13.70375061], [80.1470871, 13.70264053], [80.14679718, 13.70264053], [80.14679718, 13.70208073], [80.14653015, 13.70208263], [80.14653015, 13.70152664], [80.14597321, 13.70153141], [80.14597321, 13.70125103], [80.14541626, 13.70125103], [80.14541626, 13.70097065], [80.14457703, 13.70097065], [80.14457703, 13.70125103], [80.14431, 13.70125103], [80.14431, 13.70153141], [80.14402771, 13.70152664], [80.14402771, 13.70208263], [80.14375305, 13.70208073], [80.14375305, 13.70264053], [80.14347076, 13.70263863], [80.14347076, 13.70319462], [80.14319611, 13.7031908], [80.14319611, 13.70375061], [80.14263916, 13.70375061], [80.14263916, 13.70403194], [80.14235687, 13.70403194], [80.14235687, 13.70431042], [80.14208221, 13.7043047], [80.14208221, 13.70486069], [80.14235687, 13.7048502], [80.14235687, 13.70541859], [80.14208221, 13.70541859], [80.14208221, 13.7068119], [80.14180756, 13.70680523], [80.14180756, 13.70736122], [80.14125061, 13.70736122], [80.14125061, 13.70792198], [80.14097595, 13.70791531], [80.14097595, 13.70819473], [80.14069366, 13.70819473], [80.14069366, 13.7084713], [80.14041901, 13.7084713], [80.14041901, 13.70875168], [80.14013672, 13.70874882], [80.14013672, 13.70986176], [80.13986206, 13.70985889], [80.13986206, 13.71041965], [80.14013672, 13.71041775], [80.14013672, 13.71069336], [80.14097595, 13.71069336], [80.14097595, 13.71041775], [80.14125061, 13.71041965], [80.14125061, 13.70985889], [80.14235687, 13.70985889], [80.14235687, 13.71041965], [80.14208221, 13.71041965], [80.14208221, 13.71125031], [80.14180756, 13.71125031], [80.14180756, 13.71152973], [80.14154053, 13.71152973], [80.14154053, 13.71263981], [80.14125061, 13.71263981], [80.14125061, 13.71292019], [80.14097595, 13.71291637], [80.14097595, 13.7131958], [80.14041901, 13.7131958], [80.14041901, 13.71347237], [80.13957977, 13.71347237], [80.13957977, 13.71291637], [80.13903046, 13.71291637], [80.13903046, 13.7131958], [80.13817596, 13.71319103], [80.13817596, 13.71375179], [80.13791656, 13.71374989], [80.13791656, 13.71402836], [80.13764191, 13.71402836], [80.13764191, 13.71458435], [80.13708496, 13.71458435], [80.13709259, 13.71486187], [80.13680267, 13.71486187], [80.13680267, 13.71597195], [80.13652802, 13.71597195], [80.13652802, 13.71681118], [80.13625336, 13.71680641], [80.13625336, 13.71708393], [80.13597107, 13.71708393], [80.13597107, 13.71760082], [80.13597107, 13.71875], [80.13652802, 13.71875], [80.13652802, 13.71846962], [80.13680267, 13.71847153], [80.13680267, 13.71819401], [80.13708496, 13.71819401], [80.13708496, 13.71791553], [80.13735962, 13.71792126], [80.13735962, 13.71763992], [80.13764191, 13.71763992], [80.13764191, 13.71735954], [80.13791656, 13.7173624], [80.13791656, 13.71708393], [80.13819122, 13.71708393], [80.13819122, 13.71680641], [80.13846588, 13.71681118], [80.13846588, 13.71652985], [80.13874817, 13.71652985], [80.13874817, 13.71625042], [80.13903046, 13.71625042], [80.13903046, 13.71569157], [80.13930511, 13.71569443], [80.13930511, 13.71513844], [80.13957977, 13.71514034], [80.13957977, 13.71458244], [80.13986206, 13.71458435], [80.13986206, 13.71430588], [80.14041901, 13.71430969], [80.14041901, 13.71542263], [80.14013672, 13.71541595], [80.14013672, 13.71708393], [80.14041901, 13.71708393], [80.14041901, 13.71819401], [80.14068604, 13.71818924], [80.14068604, 13.71875], [80.14235687, 13.71875], [80.14235687, 13.71846962], [80.14402771, 13.71846962], [80.14402771, 13.71875], [80.14431, 13.71875], [80.14431, 13.71903038], [80.14457703, 13.71903038], [80.14457703, 13.71931076], [80.1451416, 13.71930599], [80.1451416, 13.71958447], [80.14541626, 13.7195797], [80.14541626, 13.71986008], [80.14569092, 13.71986008], [80.14569092, 13.7201519], [80.14597321, 13.7201519], [80.14597321, 13.72042084], [80.14653015, 13.72041607], [80.14653015, 13.72069359], [80.1470871, 13.72069359], [80.1470871, 13.72097206], [80.14679718, 13.72097015], [80.14679718, 13.72153091], [80.14653015, 13.72152805], [80.14653015, 13.72208214], [80.14624786, 13.72208023], [80.14624786, 13.72235966], [80.14653015, 13.72235966], [80.14653015, 13.72292137], [80.14680481, 13.72291565], [80.14680481, 13.7234726], [80.1470871, 13.72346973], [80.1470871, 13.72431087], [80.14541626, 13.72431087], [80.14541626, 13.72403145], [80.14402771, 13.72403145], [80.14402771, 13.72375107], [80.14229584, 13.72375107], [80.14208221, 13.72375107], [80.14208221, 13.72346973], [80.14180756, 13.7234726], [80.14180756, 13.72319412], [80.14125061, 13.72319412], [80.14125061, 13.72291565], [80.14069366, 13.72291565], [80.14069366, 13.7234726], [80.14041901, 13.72346973], [80.14041901, 13.72403145], [80.14013672, 13.72403145], [80.14013672, 13.72431087], [80.14097595, 13.7243042], [80.14097595, 13.72458458], [80.14154053, 13.7245779], [80.14154053, 13.72514057], [80.14097595, 13.72514057], [80.14097595, 13.72542095], [80.13957977, 13.72541714], [80.13957977, 13.72597313], [80.13931274, 13.72596073], [80.13931274, 13.72625065], [80.13874817, 13.72625065], [80.13874817, 13.72596073], [80.13819122, 13.72597313], [80.13819122, 13.72569466], [80.13735962, 13.72569466], [80.13735962, 13.72597313], [80.13652802, 13.72596073], [80.13652802, 13.72625065], [80.13458252, 13.72625065], [80.13458252, 13.72596073], [80.13291931, 13.72597313], [80.13291931, 13.72569466], [80.13240051, 13.72569466], [80.13153076, 13.72569466], [80.13153076, 13.72458458], [80.13124847, 13.72458458], [80.13124847, 13.72375107], [80.12985992, 13.72375107], [80.12985992, 13.72235966], [80.13014221, 13.72235966], [80.13014221, 13.72208023], [80.13041687, 13.72208214], [80.13041687, 13.72180557], [80.13053894, 13.72180557], [80.13069153, 13.72181129], [80.13069153, 13.71706104], [80.13069153, 13.71347237], [80.13097382, 13.71347237], [80.13097382, 13.71291637], [80.13124847, 13.71292019], [80.13124847, 13.71263981], [80.13153076, 13.71263981], [80.13153076, 13.71208096], [80.13263702, 13.71208382], [80.13263702, 13.7118063], [80.13318634, 13.71181011], [80.13318634, 13.71152973], [80.13569641, 13.71152782], [80.13569641, 13.7131958], [80.13597107, 13.7131958], [80.13597107, 13.71347237], [80.13625336, 13.71346855], [80.13625336, 13.71375179], [80.13652802, 13.71375179], [80.13652802, 13.71319103], [80.13680267, 13.7131958], [80.13680267, 13.71291637], [80.13709259, 13.71292019], [80.13709259, 13.71263981], [80.13735962, 13.71263981], [80.13735962, 13.71208096], [80.13764191, 13.71208382], [80.13764191, 13.71152782], [80.13791656, 13.71152973], [80.13791656, 13.71041965], [80.13817596, 13.71041965], [80.13817596, 13.70875168], [80.13846588, 13.70875168], [80.13846588, 13.70792198], [80.13817596, 13.70792198], [80.13817596, 13.7068119], [80.13846588, 13.7068119], [80.13846588, 13.70624924], [80.13874817, 13.70624924], [80.13874817, 13.70597076], [80.13930511, 13.70597076], [80.13930511, 13.70569515], [80.13957977, 13.70569515], [80.13957977, 13.70458317], [80.13986206, 13.70458317], [80.13986206, 13.70236111], [80.14013672, 13.70236111], [80.14013672, 13.70069504], [80.14041901, 13.70069504], [80.14041901, 13.70041656], [80.14125061, 13.70041656], [80.14125061, 13.70097256], [80.14154053, 13.70097065], [80.14154053, 13.70153141], [80.14180756, 13.70152664], [80.14180756, 13.70208263], [80.14291382, 13.70208263], [80.14291382, 13.69902897], [80.14263916, 13.69904041], [80.14263916, 13.69875145], [80.14235687, 13.69875145], [80.14235687, 13.69847012], [80.14208221, 13.69847298], [80.14208221, 13.69791698], [80.14180756, 13.6979208], [80.14180756, 13.69570065], [80.14154053, 13.69569016], [80.14152527, 13.6940279], [80.14125061, 13.69403076], [80.14125061, 13.69318962], [80.14097595, 13.69319439], [80.14097595, 13.6926403], [80.14068604, 13.6926403], [80.14068604, 13.69207954], [80.14041901, 13.69208431], [80.14041901, 13.69180584], [80.14013672, 13.69181061], [80.14013672, 13.69124985], [80.13986206, 13.69124985], [80.13986206, 13.69069195], [80.14013672, 13.69069386], [80.14013672, 13.69041634], [80.14041901, 13.6904211], [80.14041901, 13.68985081], [80.14069366, 13.68986225], [80.14069366, 13.68902779], [80.14125061, 13.68902969], [80.14125061, 13.68819237], [80.14097595, 13.68819427], [80.14097595, 13.68764019], [80.14125061, 13.68764019], [80.14125061, 13.68624973], [80.14154053, 13.68624973], [80.14154053, 13.68430996], [80.14180756, 13.68430996], [80.14180756, 13.68292046], [80.14208221, 13.68292046], [80.14208221, 13.68258858], [80.14208221, 13.68180466], [80.14235687, 13.68181038], [80.14235687, 13.68042183], [80.14263916, 13.68042183], [80.14263916, 13.6712513], [80.14290619, 13.6712513], [80.14290619, 13.66931057], [80.14347076, 13.66931057], [80.14347076, 13.66819191], [80.14375305, 13.66819382], [80.14375305, 13.66625023], [80.14402771, 13.66625023], [80.14402771, 13.66514015], [80.14431, 13.66514015], [80.14431, 13.66486168], [80.14457703, 13.66486168], [80.14457703, 13.66458035], [80.14485931, 13.66458416], [80.14485931, 13.66430569], [80.1451416, 13.66431141], [80.1451416, 13.66403008], [80.14541626, 13.66403008], [80.14541626, 13.66374969], [80.14569092, 13.66374969], [80.14569092, 13.6631918], [80.14597321, 13.6631937], [80.14597321, 13.66291809], [80.14624786, 13.66292953], [80.14624786, 13.66263962], [80.14653015, 13.66263962], [80.14653015, 13.66236019], [80.14680481, 13.6623621], [80.14680481, 13.66180611], [80.1470871, 13.66181087], [80.1470871, 13.66068935], [80.14736176, 13.66069412], [80.14736176, 13.65958405], [80.14763641, 13.65958405], [80.14763641, 13.65819359], [80.14736176, 13.65819359], [80.14736176, 13.65597057], [80.1470871, 13.65597057], [80.1470871, 13.65458298], [80.14680481, 13.65458298], [80.14680481, 13.65375137], [80.14653015, 13.65375137], [80.14653015, 13.65291691], [80.14624786, 13.65291977], [80.14624786, 13.65236092], [80.14597321, 13.65236092], [80.14597321, 13.65152931], [80.14569092, 13.65152931], [80.14569092, 13.65068054], [80.14597321, 13.65069485], [80.14597321, 13.64986134], [80.14624786, 13.64986134], [80.14624786, 13.64902687], [80.14653015, 13.64903069], [80.14653015, 13.64847088], [80.14680481, 13.64847088], [80.14680481, 13.6473608], [80.1470871, 13.6473608], [80.1470871, 13.64625072], [80.14679718, 13.64625072], [80.14679718, 13.6459713], [80.14653015, 13.64597321], [80.14653015, 13.64569473], [80.14597321, 13.64569473], [80.14597321, 13.64541721], [80.14569092, 13.64542103], [80.14569092, 13.64514065], [80.14541626, 13.64514065], [80.14541626, 13.6448698], [80.1451416, 13.6448698], [80.1451416, 13.64458275], [80.14402771, 13.64458466], [80.14402771, 13.64069366], [80.14375305, 13.64069366], [80.14375305, 13.63986015], [80.14402771, 13.63986015], [80.14402771, 13.63958359], [80.14375305, 13.63958359], [80.14375305, 13.63763809], [80.14319611, 13.63764], [80.14319611, 13.63514042], [80.14375305, 13.63514042], [80.14375305, 13.63486195], [80.14431, 13.63486195], [80.14430237, 13.63347244], [80.14402771, 13.63347244], [80.14402771, 13.63319397], [80.14430237, 13.63319397], [80.14430237, 13.63291645], [80.14457703, 13.63293171], [80.14457703, 13.63208103], [80.14485931, 13.63208389], [80.14485931, 13.62986183], [80.14457703, 13.62986183], [80.14457703, 13.62903023], [80.14431, 13.62903023], [80.14431, 13.62764168], [80.14402771, 13.62764168], [80.14402771, 13.62708092], [80.14375305, 13.62708282], [80.14375305, 13.62652683], [80.14347076, 13.6265316], [80.14347076, 13.62513924], [80.14319611, 13.62513924], [80.14319611, 13.62403202], [80.14290619, 13.62403202], [80.14290619, 13.62319088], [80.14263916, 13.62319469], [80.14263916, 13.62291718], [80.14235687, 13.62292194], [80.14235687, 13.62236118], [80.14208221, 13.62236118], [80.14208221, 13.62208271], [80.14180756, 13.62208271], [80.14180756, 13.62180519], [80.14154053, 13.62181187], [80.14154053, 13.62125111], [80.14125061, 13.62125111], [80.14125061, 13.62097073], [80.14097595, 13.62097263], [80.14097595, 13.61902905], [80.14068604, 13.61903095], [80.14068604, 13.61875057], [80.14041901, 13.61875057], [80.14041901, 13.6181879], [80.14013672, 13.61819458], [80.14013672, 13.61763859], [80.13986206, 13.61763859], [80.13986206, 13.61652946], [80.13957977, 13.61653137], [80.13957977, 13.61569023], [80.13930511, 13.61569405], [80.13930511, 13.6148634], [80.13903046, 13.6148634], [80.13903046, 13.61430645], [80.13874817, 13.61431122], [80.13874817, 13.61347008], [80.13847351, 13.61347198], [80.13847351, 13.61291599], [80.13817596, 13.61292076], [80.13817596, 13.61264038], [80.13791656, 13.61264038], [80.13791656, 13.61236], [80.13764191, 13.61236], [80.13764191, 13.61207962], [80.13708496, 13.61208439], [80.13708496, 13.61180592], [80.13680267, 13.61182022], [80.13680267, 13.61153126], [80.13652802, 13.61153126], [80.13652802, 13.61124992], [80.13625336, 13.61124992], [80.13625336, 13.61098099], [80.13513947, 13.61096954], [80.13513947, 13.61069393], [80.13402557, 13.61069393], [80.13402557, 13.61041641], [80.13291931, 13.61042118], [80.13291931, 13.61013985], [80.13069153, 13.61013985], [80.13069153, 13.61042118], [80.13014221, 13.61041641], [80.13014221, 13.61069393], [80.12985992, 13.61069393], [80.12985992, 13.6109724], [80.12930298, 13.6109724], [80.12930298, 13.61069393], [80.12763977, 13.61069393], [80.12763977, 13.6109724], [80.12708282, 13.61096954], [80.12708282, 13.61124992], [80.12680817, 13.61124992], [80.12680817, 13.61153126], [80.1264801, 13.6115284], [80.12623596, 13.61153126], [80.12623596, 13.61182022], [80.12596893, 13.61182022], [80.12596893, 13.61236], [80.12568665, 13.61236], [80.12568665, 13.61292076], [80.12541962, 13.61291599], [80.12541962, 13.61347198], [80.12513733, 13.61347008], [80.12513733, 13.61375046], [80.12431335, 13.61375046], [80.12431335, 13.61403084], [80.12403107, 13.61403084], [80.12403107, 13.61431122], [80.12374878, 13.61430645], [80.12374878, 13.61458206], [80.12347412, 13.61458206], [80.12347412, 13.6148634], [80.12317657, 13.61485958], [80.12317657, 13.6154213], [80.12291718, 13.61541557], [80.12291718, 13.61597347], [80.12264252, 13.61596966], [80.12264252, 13.61653137], [80.12236023, 13.61653137], [80.12236023, 13.6168108], [80.12208557, 13.61680698], [80.12208557, 13.61708164], [80.12180328, 13.61708164], [80.12180328, 13.61763859], [80.12152863, 13.61763191], [80.12152863, 13.61792088], [80.12124634, 13.61791706], [80.12124634, 13.61819458], [80.12097168, 13.6181879], [80.12097168, 13.61875057], [80.12069702, 13.61875057], [80.12069702, 13.61903095], [80.1204071, 13.61903095], [80.1204071, 13.61931133], [80.12014008, 13.61931133], [80.12014008, 13.61986065], [80.11985779, 13.61986065], [80.11985779, 13.62014103], [80.11958313, 13.62014103], [80.11958313, 13.62042141], [80.11902618, 13.62042141], [80.11902618, 13.62070179], [80.11875153, 13.62069511], [80.11875153, 13.62097263], [80.11846924, 13.62097263], [80.11846924, 13.62208271], [80.11875153, 13.6220808], [80.11875153, 13.62264061], [80.11902618, 13.62264061], [80.11902618, 13.62292194], [80.11930847, 13.62292194], [80.11930847, 13.62403202], [80.11958313, 13.62403202], [80.11958313, 13.62541962], [80.11930847, 13.62541962], [80.11930847, 13.6265316], [80.11902618, 13.62652683], [80.11902618, 13.62708282], [80.11875153, 13.62708092], [80.11875153, 13.62792015], [80.11846924, 13.62791538], [80.11846924, 13.62819576], [80.11875153, 13.62819576], [80.11875153, 13.62847137], [80.11846924, 13.62847137], [80.11846924, 13.62874889], [80.11818695, 13.62874889], [80.11818695, 13.62930965], [80.11791992, 13.62930489], [80.11791992, 13.62958431], [80.11763763, 13.62957001], [80.11763763, 13.6301403], [80.11737061, 13.6301403], [80.11737061, 13.63041973], [80.11708069, 13.63041782], [80.11708069, 13.63097191], [80.11680603, 13.63097191], [80.11680603, 13.63125038], [80.11653137, 13.63125038], [80.11653137, 13.63152981], [80.1159668, 13.63152981], [80.1159668, 13.63181019], [80.11569214, 13.63180637], [80.11569214, 13.63208389], [80.11541748, 13.63208389], [80.11541748, 13.63236237], [80.11486053, 13.63236046], [80.11486053, 13.63264179], [80.11458588, 13.63264179], [80.11458588, 13.63293171], [80.11430359, 13.63291645], [80.11429596, 13.6331892], [80.11374664, 13.63319588], [80.11374664, 13.63347244], [80.11347198, 13.63347244], [80.11345673, 13.63375854], [80.1134491, 13.63403034], [80.11319733, 13.63403034], [80.11319733, 13.63431263], [80.11291504, 13.63430595], [80.11291504, 13.63458443], [80.11264038, 13.63458157], [80.11264038, 13.63514042], [80.11235809, 13.63514042], [80.11235809, 13.63541985], [80.11207581, 13.63541985], [80.11207581, 13.63570118], [80.11180878, 13.63570118], [80.11180878, 13.63652992], [80.11152649, 13.63652802], [80.11152649, 13.63708401], [80.11123657, 13.63708019], [80.11123657, 13.63764], [80.11096954, 13.63763809], [80.11096954, 13.63875008], [80.11068726, 13.63874054], [80.11068726, 13.63931084], [80.11042023, 13.63930416], [80.11042023, 13.63958359], [80.11013794, 13.63958359], [80.11013794, 13.63986015], [80.10986328, 13.63986015], [80.10986328, 13.64042091], [80.10958099, 13.64041615], [80.10958099, 13.64097214], [80.10930634, 13.64097214], [80.10930634, 13.6418066], [80.10902405, 13.6418066], [80.10902405, 13.64208221], [80.10874939, 13.64208031], [80.10874939, 13.64542103], [80.10902405, 13.64541721], [80.10902405, 13.64597321], [80.10930634, 13.6459713], [80.10930634, 13.64681244], [80.10902405, 13.64680481], [80.10902405, 13.64819527], [80.10930634, 13.64818954], [80.10930634, 13.64875126], [80.10902405, 13.64875126], [80.10902405, 13.64986134], [80.10874939, 13.64986134], [80.10874939, 13.65097332], [80.10847473, 13.65097332], [80.10847473, 13.6520834], [80.10819244, 13.6520834], [80.10819244, 13.65319538], [80.10791779, 13.65319061], [80.10791779, 13.65431023], [80.10820007, 13.65431023], [80.10820007, 13.6554203], [80.1084671, 13.6554203], [80.1084671, 13.65653038], [80.10874939, 13.65652657], [80.10874939, 13.65683079], [80.10874939, 13.65736198], [80.10901642, 13.65736198], [80.10901642, 13.65764046], [80.10958099, 13.65764046], [80.10958099, 13.65792179], [80.10986328, 13.65791798], [80.10986328, 13.65819359], [80.11235809, 13.65819359], [80.11235809, 13.65791798], [80.11402893, 13.65792179], [80.11402893, 13.65764046], [80.11624908, 13.65764046], [80.11624908, 13.65874958], [80.11818695, 13.65874958], [80.11818695, 13.65569115], [80.11791992, 13.65569305], [80.11791992, 13.6554184], [80.11763763, 13.6554203], [80.11763763, 13.65514183], [80.11737061, 13.65514183], [80.11737061, 13.65486145], [80.11708069, 13.65486145], [80.11708069, 13.65625191], [80.11541748, 13.65625191], [80.11541748, 13.65597057], [80.11513519, 13.65597057], [80.11513519, 13.65585136], [80.11513519, 13.6554184], [80.11486053, 13.6554203], [80.11486053, 13.65514183], [80.11514282, 13.65514183], [80.11514282, 13.65458107], [80.11541748, 13.65458298], [80.11541748, 13.65430546], [80.11569214, 13.65431023], [80.11569214, 13.65403175], [80.1159668, 13.65403175], [80.1159668, 13.65347099], [80.11624908, 13.65347099], [80.11624908, 13.65319538], [80.11736298, 13.65319538], [80.11736298, 13.65375137], [80.11791992, 13.65375137], [80.11791992, 13.65347099], [80.11819458, 13.65347099], [80.11819458, 13.65291691], [80.11839294, 13.65291977], [80.11846924, 13.65291691], [80.11846924, 13.65263939], [80.11875153, 13.65263939], [80.11875153, 13.65208054], [80.11902618, 13.6520834], [80.11902618, 13.6515274], [80.11930847, 13.65152931], [80.11930847, 13.65125084], [80.11958313, 13.65125084], [80.11958313, 13.65068054], [80.11985779, 13.65069485], [80.11985779, 13.65013885], [80.11958313, 13.65014076], [80.11958313, 13.64931202], [80.11930847, 13.64931202], [80.11930847, 13.64875126], [80.11902618, 13.64875126], [80.11902618, 13.64818954], [80.11875153, 13.64819527], [80.11875153, 13.64791679], [80.11818695, 13.6479311], [80.11818695, 13.64764118], [80.11791992, 13.64764118], [80.11791992, 13.6473608], [80.11763763, 13.6473608], [80.11763763, 13.64708328], [80.11736298, 13.64708328], [80.11736298, 13.64680481], [80.11680603, 13.64681244], [80.11680603, 13.64653111], [80.11653137, 13.64653111], [80.11653137, 13.64625072], [80.11624908, 13.64625072], [80.11624908, 13.6459713], [80.11582184, 13.64597321], [80.11569214, 13.64597321], [80.11569214, 13.64569473], [80.11541748, 13.64569473], [80.11541748, 13.64541721], [80.11514282, 13.64542103], [80.11514282, 13.64514065], [80.11486053, 13.64514065], [80.11486053, 13.6448698], [80.11429596, 13.6448698], [80.11429596, 13.64458275], [80.11402893, 13.64458466], [80.11402893, 13.64430428], [80.11374664, 13.64431095], [80.11374664, 13.64403057], [80.11347198, 13.64403057], [80.11347198, 13.64375114], [80.11319733, 13.64375114], [80.11319733, 13.6434679], [80.11291504, 13.64347267], [80.11291504, 13.64319515], [80.11264038, 13.64319515], [80.11264038, 13.64291573], [80.11180878, 13.64292145], [80.11180878, 13.64208031], [80.11235809, 13.64208221], [80.11235809, 13.6418066], [80.11374664, 13.6418066], [80.11374664, 13.64208221], [80.11402893, 13.64208031], [80.11402893, 13.64264107], [80.11429596, 13.64264107], [80.11429596, 13.64292145], [80.11486053, 13.64291573], [80.11486053, 13.64319515], [80.11522675, 13.64319515], [80.11541748, 13.64319515], [80.11541748, 13.64347267], [80.1159668, 13.6434679], [80.1159668, 13.64375114], [80.11653137, 13.64375114], [80.11653137, 13.64403057], [80.11708069, 13.64403057], [80.11708069, 13.64431095], [80.11791992, 13.64430428], [80.11791992, 13.64458466], [80.11846924, 13.64458275], [80.11846924, 13.6448698], [80.11902618, 13.6448698], [80.11902618, 13.64514065], [80.11958313, 13.64514065], [80.11958313, 13.64542103], [80.12014008, 13.64541721], [80.12014008, 13.64569473], [80.12069702, 13.64569473], [80.12069702, 13.64597321], [80.1204071, 13.6459713], [80.1204071, 13.64625072], [80.12014008, 13.64625072], [80.12014008, 13.64847088], [80.1204071, 13.64847088], [80.1204071, 13.64903069], [80.12069702, 13.64902687], [80.12069702, 13.64986134], [80.12097168, 13.64986134], [80.12097168, 13.65069485], [80.12124634, 13.65068054], [80.12124634, 13.65125084], [80.12152863, 13.65125084], [80.12152863, 13.65180969], [80.12180328, 13.65180969], [80.12180328, 13.65291977], [80.12152863, 13.65291691], [80.12152863, 13.65458298], [80.12124634, 13.65458298], [80.12124634, 13.65475178], [80.12124634, 13.6554203], [80.12014008, 13.6554184], [80.12014008, 13.65597057], [80.11985779, 13.65597057], [80.11985779, 13.65653038], [80.12014008, 13.65653038], [80.12014008, 13.65736198], [80.1204071, 13.65736198], [80.1204071, 13.66042042], [80.12014008, 13.66041565], [80.12014008, 13.66097164], [80.11985779, 13.66097164], [80.11985779, 13.66181087], [80.11958313, 13.66180611], [80.11958313, 13.6631937], [80.11985779, 13.6631918], [80.11985779, 13.66374969], [80.12014008, 13.66374969], [80.12014008, 13.66403008], [80.12152863, 13.66403008], [80.12152863, 13.66431141], [80.1220932, 13.66431141], [80.1220932, 13.66486168], [80.12236023, 13.66486168], [80.12236023, 13.66542053], [80.12264252, 13.66541576], [80.12264252, 13.66597176], [80.12291718, 13.66596985], [80.12291718, 13.66653061], [80.12317657, 13.66653061], [80.12317657, 13.66681099], [80.12347412, 13.66680622], [80.12347412, 13.66736031], [80.12374878, 13.66736031], [80.12374878, 13.66792107], [80.12403107, 13.6679163], [80.12403107, 13.66847229], [80.12431335, 13.66847038], [80.12431335, 13.66903114], [80.12458038, 13.66902637], [80.12458038, 13.66958237], [80.12486267, 13.66958046], [80.12486267, 13.66986275], [80.12541962, 13.66986275], [80.12541962, 13.66958046], [80.12596893, 13.66958046], [80.12596893, 13.67042065], [80.12568665, 13.67042065], [80.12568665, 13.6712513], [80.12541962, 13.6712513], [80.12541962, 13.67236137], [80.12513733, 13.67236137], [80.12513733, 13.67319489], [80.12486267, 13.67319489], [80.12486267, 13.67572021], [80.12486267, 13.67681026], [80.12458038, 13.67680454], [80.12458038, 13.67708302], [80.12431335, 13.67708111], [80.12431335, 13.67764091], [80.12403107, 13.67763901], [80.12403107, 13.67791653], [80.12236023, 13.67791653], [80.12236023, 13.67819309], [80.12041473, 13.67819309], [80.12041473, 13.67708302], [80.12069702, 13.67708302], [80.12069702, 13.67652702], [80.12097168, 13.67653084], [80.12097168, 13.67597103], [80.12124634, 13.67597294], [80.12124634, 13.67541695], [80.12152863, 13.67542171], [80.12152863, 13.67486954], [80.12180328, 13.67486954], [80.12180328, 13.67403126], [80.12152863, 13.67403126], [80.12152863, 13.6726408], [80.12124634, 13.6726408], [80.12124634, 13.67153072], [80.12097168, 13.67153072], [80.12097168, 13.67068958], [80.11958313, 13.6706953], [80.11958313, 13.67097282], [80.11875153, 13.67096996], [80.11875153, 13.6712513], [80.11791992, 13.6712513], [80.11791992, 13.67153072], [80.11763763, 13.67153072], [80.11763763, 13.6718092], [80.11736298, 13.67180538], [80.11736298, 13.6720829], [80.11680603, 13.6720829], [80.11680603, 13.67236137], [80.11653137, 13.67236137], [80.11653137, 13.6726408], [80.11624908, 13.6726408], [80.11624908, 13.67292118], [80.11597443, 13.67291737], [80.11597443, 13.67319489], [80.11569214, 13.67319012], [80.11569214, 13.67375088], [80.11541748, 13.67375088], [80.11541748, 13.67431164], [80.11514282, 13.67431164], [80.11514282, 13.67486954], [80.11486053, 13.67486954], [80.11486053, 13.67542171], [80.11458588, 13.67541695], [80.11458588, 13.67597294], [80.11347198, 13.67597294], [80.11347198, 13.67541695], [80.11319733, 13.67542171], [80.11319733, 13.67458057], [80.11291504, 13.67458344], [80.11291504, 13.67402744], [80.11264038, 13.67403126], [80.11264038, 13.67347145], [80.11235809, 13.67347336], [80.11235809, 13.67319489], [80.11208344, 13.67319489], [80.11208344, 13.67263889], [80.11180878, 13.6726408], [80.11180878, 13.67236137], [80.11152649, 13.67236137], [80.11152649, 13.67180538], [80.11123657, 13.6718092], [80.11123657, 13.67153072], [80.10901642, 13.67153072], [80.10901642, 13.6712513], [80.1084671, 13.6712513], [80.1084671, 13.6726408], [80.10819244, 13.67263889], [80.10819244, 13.67347336], [80.10764313, 13.67347145], [80.10764313, 13.67375088], [80.10736084, 13.67375088], [80.10736084, 13.67403126], [80.10679626, 13.67403126], [80.10679626, 13.67431164], [80.10736084, 13.67430687], [80.10736084, 13.67458344], [80.1076355, 13.67458344], [80.1076355, 13.67736053], [80.10736084, 13.67736053], [80.10736084, 13.67847347], [80.10764313, 13.67847061], [80.10764313, 13.67875099], [80.10791779, 13.67875099], [80.10791779, 13.67931175], [80.10819244, 13.67930508], [80.10819244, 13.67986107], [80.10847473, 13.67986107], [80.10847473, 13.68069458], [80.10820007, 13.68069077], [80.10820007, 13.68125153], [80.10791779, 13.68125153], [80.10791779, 13.68153191], [80.1076355, 13.68152714], [80.1076355, 13.68208313], [80.10736084, 13.68208122], [80.10736084, 13.68264198], [80.10708618, 13.68264008], [80.10708618, 13.68319321], [80.10680389, 13.68319321], [80.10680389, 13.68347359], [80.10652924, 13.68347073], [80.10652924, 13.6837492], [80.10624695, 13.6837492], [80.10624695, 13.68404102], [80.10652924, 13.68404102], [80.10652924, 13.68430996], [80.10847473, 13.68430614], [80.10847473, 13.68458366], [80.10874939, 13.6845789], [80.10874939, 13.68513966], [80.10902405, 13.68513966], [80.10902405, 13.68569374], [80.10874939, 13.68569088], [80.10874939, 13.68624973], [80.1084671, 13.68624973], [80.1084671, 13.68680954], [80.10819244, 13.68680573], [80.10819244, 13.68847179], [80.10847473, 13.68847179], [80.10847473, 13.68986225], [80.10874939, 13.68985081], [80.10874939, 13.69014168], [80.10901642, 13.69014168], [80.10901642, 13.6904211], [80.10930634, 13.69041634], [80.10930634, 13.69069386], [80.10958099, 13.69069386], [80.10958099, 13.69097233], [80.10986328, 13.69097042], [80.10986328, 13.69124985], [80.11013794, 13.69124985], [80.11013794, 13.69153023], [80.11068726, 13.69153023], [80.11068726, 13.69181061], [80.11096954, 13.69180584], [80.11096954, 13.69208431], [80.11123657, 13.69207954], [80.11123657, 13.6926403], [80.11152649, 13.6926403], [80.11152649, 13.69375038], [80.11125183, 13.69375038], [80.11125183, 13.69458199], [80.11096954, 13.69458199], [80.11096954, 13.69486332], [80.11068726, 13.69486046], [80.11068726, 13.69542122], [80.11042023, 13.69541645], [80.11042023, 13.69569016], [80.11013794, 13.69570065], [80.11013794, 13.69598198], [80.10986328, 13.69598198], [80.10986328, 13.69625092], [80.10958099, 13.69625092], [80.10958099, 13.69681072], [80.10930634, 13.69680691], [80.10930634, 13.69708157], [80.10901642, 13.69707966], [80.10901642, 13.69736004], [80.10874939, 13.69736004], [80.10874939, 13.6979208], [80.10847473, 13.69791698], [80.10847473, 13.69847298], [80.10820007, 13.69847012], [80.10820007, 13.69904041], [80.10791779, 13.69904041], [80.10791779, 13.69931126], [80.1076355, 13.69930458], [80.1076355, 13.69958305], [80.10736084, 13.69958305], [80.10736084, 13.69986057], [80.10708618, 13.69986057], [80.10708618, 13.70014095], [80.10680389, 13.70013905], [80.10680389, 13.70069504], [80.10708618, 13.70069027], [80.10708618, 13.70181179], [80.10736084, 13.70181179], [80.10736084, 13.70292187], [80.10764313, 13.70292187], [80.10764313, 13.70375061], [80.10791779, 13.7037487], [80.10791779, 13.70388126], [80.10791779, 13.70624924], [80.10820007, 13.70624924], [80.10820007, 13.7068119], [80.10847473, 13.70680523], [80.10847473, 13.70708275], [80.10902405, 13.70708275], [80.10902405, 13.70736122], [80.10930634, 13.70736122], [80.10930634, 13.70792198], [80.10902405, 13.70791531], [80.10902405, 13.7084713], [80.10874939, 13.7084713], [80.10874939, 13.70875168], [80.1084671, 13.70875168], [80.1084671, 13.70903015], [80.10820007, 13.70903015], [80.10820007, 13.70930958], [80.10679626, 13.70930958], [80.10679626, 13.70903015], [80.10652924, 13.70903015], [80.10652924, 13.7084713], [80.10624695, 13.7084713], [80.10624695, 13.70791531], [80.10597229, 13.70792198], [80.10597229, 13.7076416], [80.10514069, 13.7076416], [80.10514069, 13.70736122], [80.10430908, 13.70736122], [80.10430908, 13.70708275], [80.10458374, 13.70708275], [80.10458374, 13.70652676], [80.1048584, 13.70652866], [80.1048584, 13.70347118], [80.10458374, 13.70347309], [80.10458374, 13.70319462], [80.10430908, 13.70319462], [80.10430908, 13.7029171], [80.10402679, 13.70292187], [80.10402679, 13.70236111], [80.10375214, 13.70236111], [80.10375214, 13.70208263], [80.10346985, 13.70208263], [80.10346985, 13.70180511], [80.1029129, 13.70180511], [80.1029129, 13.70208263], [80.10180664, 13.70208263], [80.10180664, 13.70236111], [80.10069275, 13.70236111], [80.10069275, 13.70208263], [80.10041809, 13.70208263], [80.10041809, 13.69902897], [80.10069275, 13.69904041], [80.10069275, 13.69847012], [80.10097504, 13.69847298], [80.10097504, 13.69819546], [80.10124969, 13.69819546], [80.10124969, 13.69763947], [80.10151672, 13.69764137], [80.10151672, 13.69707966], [80.10180664, 13.69708157], [80.10180664, 13.69680691], [80.1020813, 13.69681072], [80.1020813, 13.69625092], [80.10235596, 13.69625092], [80.10235596, 13.69598198], [80.10260773, 13.69598198], [80.10263824, 13.69542122], [80.1029129, 13.69542122], [80.1029129, 13.69514275], [80.10597229, 13.69514275], [80.10597229, 13.69486046], [80.10652924, 13.69486332], [80.10652924, 13.69458199], [80.10680389, 13.69458199], [80.10680389, 13.69430637], [80.10736084, 13.69431114], [80.10736084, 13.6930418], [80.10736084, 13.69291592], [80.1076355, 13.69291592], [80.1076355, 13.69152832], [80.10736084, 13.69153023], [80.10736084, 13.69124985], [80.10679626, 13.69124985], [80.10679626, 13.69097042], [80.10652924, 13.69097233], [80.10652924, 13.69069386], [80.10624695, 13.69069386], [80.10624695, 13.69041634], [80.10569763, 13.6904211], [80.10569763, 13.69014168], [80.1054306, 13.69014168], [80.1054306, 13.68958187], [80.10514069, 13.68958378], [80.10514069, 13.68902779], [80.1048584, 13.68902969], [80.1048584, 13.68847179], [80.10457611, 13.68847179], [80.10457611, 13.68791962], [80.10430908, 13.68791962], [80.10430908, 13.68764019], [80.10375214, 13.68764019], [80.10375214, 13.68735981], [80.10319519, 13.68735981], [80.10319519, 13.6870842], [80.10263824, 13.6870842], [80.10263824, 13.68680573], [80.10180664, 13.68680573], [80.10180664, 13.6870842], [80.10097504, 13.6870842], [80.10097504, 13.6790266], [80.10124969, 13.67902946], [80.10124969, 13.67875099], [80.10098267, 13.67875099], [80.10098267, 13.67847061], [80.10069275, 13.67847347], [80.10069275, 13.67791653], [80.10097504, 13.67791653], [80.10097504, 13.67680454], [80.10124969, 13.67681026], [80.10124969, 13.67597103], [80.10152435, 13.67597294], [80.10152435, 13.67486095], [80.10180664, 13.67486954], [80.10180664, 13.67375088], [80.1020813, 13.67375088], [80.1020813, 13.6726408], [80.10235596, 13.6726408], [80.10235596, 13.66736031], [80.10263824, 13.66736031], [80.10263824, 13.66708374], [80.10346985, 13.66708374], [80.10346985, 13.66541576], [80.10375214, 13.66542053], [80.10375214, 13.66263962], [80.10402679, 13.66263962], [80.10402679, 13.66152954], [80.10430908, 13.66152954], [80.10430908, 13.66042042], [80.10457611, 13.66042042], [80.10457611, 13.65902996], [80.10430908, 13.65902996], [80.10430908, 13.65764046], [80.10402679, 13.65764046], [80.10402679, 13.65653038], [80.10375214, 13.65653038], [80.10375214, 13.65618992], [80.10375214, 13.65513897], [80.10346985, 13.65514183], [80.10346985, 13.65431023], [80.10320282, 13.65431023], [80.10320282, 13.65403175], [80.1029129, 13.65403175], [80.1029129, 13.65373993], [80.10263824, 13.65375137], [80.10263824, 13.65347099], [80.1020813, 13.65347099], [80.1020813, 13.65319538], [80.10180664, 13.65319538], [80.10180664, 13.65291691], [80.10151672, 13.65291977], [80.10151672, 13.65263939], [80.09764099, 13.65263939], [80.09764099, 13.65319538], [80.0973587, 13.65319538], [80.0973587, 13.65375137], [80.09707642, 13.65373993], [80.09707642, 13.65431023], [80.0973587, 13.65430546], [80.0973587, 13.65492058], [80.0973587, 13.6554203], [80.09764099, 13.6554203], [80.09764099, 13.65653038], [80.09792328, 13.65653038], [80.09792328, 13.65764046], [80.09819794, 13.65763664], [80.09819794, 13.65958405], [80.0984726, 13.65957928], [80.0984726, 13.66125202], [80.09819794, 13.66125202], [80.09819794, 13.66152954], [80.0973587, 13.66152954], [80.0973587, 13.66125202], [80.09707642, 13.66125202], [80.09707642, 13.66097164], [80.09680176, 13.66097164], [80.09680176, 13.66041565], [80.0965271, 13.66042042], [80.0965271, 13.6598711], [80.09626007, 13.6598711], [80.09626007, 13.65957928], [80.09597015, 13.65958405], [80.09597015, 13.65902805], [80.09570313, 13.65902996], [80.09570313, 13.65874958], [80.09541321, 13.65874958], [80.09541321, 13.65819073], [80.09513855, 13.65819359], [80.09513855, 13.65763664], [80.09485626, 13.65764046], [80.09485626, 13.65736198], [80.0945816, 13.65736198], [80.0945816, 13.65680981], [80.09430695, 13.65680981], [80.09430695, 13.65653038], [80.09401703, 13.65653038], [80.09401703, 13.65597057], [80.09375, 13.65597057], [80.09375, 13.6554184], [80.0934906, 13.6554203], [80.0934906, 13.65514183], [80.09320068, 13.65514183], [80.09320068, 13.65458107], [80.0929184, 13.65458298], [80.0929184, 13.65430546], [80.09236145, 13.65431023], [80.09236145, 13.65414143], [80.09236145, 13.65402699], [80.09179688, 13.65403175], [80.09179688, 13.65373993], [80.0890274, 13.65375137], [80.0890274, 13.65388107], [80.0890274, 13.65403175], [80.08875275, 13.65403175], [80.08875275, 13.6554203], [80.08930206, 13.6554184], [80.08930206, 13.65569305], [80.08958435, 13.65569305], [80.08958435, 13.65597057], [80.0901413, 13.65597057], [80.0901413, 13.65625191], [80.09041595, 13.65625191], [80.09041595, 13.65653038], [80.0909729, 13.65653038], [80.0909729, 13.65680981], [80.09124756, 13.65680981], [80.09124756, 13.65736198], [80.09152985, 13.65736198], [80.09152985, 13.65764046], [80.0918045, 13.65763664], [80.0918045, 13.65819359], [80.09208679, 13.65819073], [80.09208679, 13.65874958], [80.09236145, 13.65874958], [80.09236145, 13.65902996], [80.09263611, 13.65902805], [80.09263611, 13.65958405], [80.0929184, 13.65957928], [80.0929184, 13.6598711], [80.09320068, 13.6598711], [80.09320068, 13.66042042], [80.09347534, 13.66041565], [80.09347534, 13.66097164], [80.09375, 13.66097164], [80.09375, 13.66125202], [80.09401703, 13.66125202], [80.09401703, 13.66181087], [80.09430695, 13.66180611], [80.09430695, 13.66208363], [80.09541321, 13.66207886], [80.09541321, 13.66263962], [80.0956955, 13.66263771], [80.0956955, 13.6631937], [80.09597015, 13.6631918], [80.09597015, 13.66374969], [80.09626007, 13.66374969], [80.09626007, 13.66431141], [80.0965271, 13.66431141], [80.0965271, 13.66486168], [80.09680176, 13.66485977], [80.09680176, 13.66569424], [80.0965271, 13.66567993], [80.0965271, 13.66681099], [80.09626007, 13.66681099], [80.09626007, 13.66792107], [80.09597015, 13.6679163], [80.09597015, 13.66847229], [80.09570313, 13.66847038], [80.09570313, 13.66874981], [80.0945816, 13.66874981], [80.0945816, 13.66819191], [80.09430695, 13.66819382], [80.09430695, 13.66763783], [80.09401703, 13.66764069], [80.09401703, 13.66736031], [80.09347534, 13.66736031], [80.09347534, 13.66708374], [80.09319305, 13.66708374], [80.09319305, 13.66680622], [80.09263611, 13.66681099], [80.09263611, 13.66653061], [80.09236145, 13.66653061], [80.09236145, 13.66625023], [80.09208679, 13.66625023], [80.09208679, 13.66596985], [80.09152985, 13.66597176], [80.09152985, 13.66569424], [80.09124756, 13.66569424], [80.09124756, 13.66541576], [80.0909729, 13.66542053], [80.0909729, 13.66514015], [80.09041595, 13.66514015], [80.09041595, 13.66486168], [80.0901413, 13.66486168], [80.0901413, 13.66458035], [80.08930206, 13.66458035], [80.08930206, 13.66514015], [80.0890274, 13.66514015], [80.0890274, 13.66569424], [80.08791351, 13.66569424], [80.08791351, 13.66541576], [80.08763885, 13.66542053], [80.08763885, 13.66486168], [80.08735657, 13.66486168], [80.08735657, 13.66431141], [80.08706665, 13.66431141], [80.08706665, 13.66374969], [80.08680725, 13.66374969], [80.08680725, 13.66347027], [80.08652496, 13.66347218], [80.08652496, 13.66291809], [80.08625031, 13.66292953], [80.08625031, 13.66236019], [80.08597565, 13.6623621], [80.08597565, 13.66208363], [80.08569336, 13.66208363], [80.08569336, 13.66152763], [80.0854187, 13.66152954], [80.0854187, 13.66125202], [80.08513641, 13.66125202], [80.08513641, 13.66068935], [80.08430481, 13.66069412], [80.08430481, 13.65958405], [80.08403015, 13.65958405], [80.08403015, 13.65847206], [80.08374786, 13.65847206], [80.08374786, 13.65819359], [80.08347321, 13.65819359], [80.08347321, 13.65791798], [80.08291626, 13.65792179], [80.08291626, 13.65764046], [80.0826416, 13.65764046], [80.0826416, 13.65736198], [80.08235931, 13.65736198], [80.08235931, 13.65708065], [80.08208466, 13.65708447], [80.08208466, 13.65680599], [80.08180237, 13.65680981], [80.08180237, 13.65653038], [80.08126068, 13.65653038], [80.08126068, 13.65625191], [80.08097076, 13.65625191], [80.08097076, 13.65597057], [80.07930756, 13.65597057], [80.07930756, 13.65513897], [80.07958221, 13.65514183], [80.07958221, 13.65458107], [80.08013916, 13.65458298], [80.08013916, 13.65263939], [80.07985687, 13.65263939], [80.07985687, 13.65180969], [80.08013916, 13.65180969], [80.08013916, 13.65152931], [80.08040619, 13.65152931], [80.08040619, 13.65125084], [80.08069611, 13.65125084], [80.08069611, 13.65097141], [80.08097076, 13.65097332], [80.08097076, 13.65069485], [80.08125305, 13.65069485], [80.08125305, 13.65041733], [80.08235931, 13.65041733], [80.08235931, 13.65097332], [80.08319092, 13.65097332], [80.08319092, 13.65069485], [80.08374786, 13.65069485], [80.08374786, 13.65041733], [80.08403015, 13.65041924], [80.08403015, 13.65014076], [80.08735657, 13.65014076], [80.08735657, 13.65041924], [80.0901413, 13.65041733], [80.0901413, 13.65097332], [80.09069824, 13.65097141], [80.09069824, 13.65125084], [80.09124756, 13.65125084], [80.09124756, 13.65097141], [80.0918045, 13.65097332], [80.0918045, 13.64958286], [80.09152985, 13.64958286], [80.09152985, 13.64930534], [80.0909729, 13.64931202], [80.0909729, 13.64875126], [80.09320068, 13.64875126], [80.09319305, 13.64847088], [80.09375, 13.64847088], [80.09375, 13.64819527], [80.09430695, 13.64819527], [80.09430695, 13.64791679], [80.09485626, 13.6479311], [80.09485626, 13.6473608], [80.09430695, 13.6473608], [80.09430695, 13.64680481], [80.09401703, 13.64681244], [80.09401703, 13.64653111], [80.09375, 13.64653111], [80.09375, 13.64625072], [80.0934906, 13.64625072], [80.0934906, 13.6459713], [80.09236145, 13.64597321], [80.09236145, 13.64569473], [80.09152985, 13.64569473], [80.09152985, 13.64541721], [80.09108734, 13.64541721], [80.08875275, 13.64541721], [80.08875275, 13.64569473], [80.0845871, 13.64569473], [80.0845871, 13.64541721], [80.08403015, 13.64542103], [80.08403015, 13.64514065], [80.08347321, 13.64514065], [80.08347321, 13.6448698], [80.08291626, 13.6448698], [80.08291626, 13.64458275], [80.0826416, 13.64458275], [80.0826416, 13.6448698], [80.08235931, 13.6448698], [80.08235931, 13.64458275], [80.08152771, 13.64458466], [80.08152771, 13.64430428], [80.08097076, 13.64431095], [80.08097076, 13.64403057], [80.08069611, 13.64403057], [80.08069611, 13.6434679], [80.08013916, 13.64347267], [80.08013916, 13.64319515], [80.07930756, 13.64319515], [80.07930756, 13.64291573], [80.0790329, 13.64292145], [80.0790329, 13.64264107], [80.07875061, 13.64264107], [80.07875061, 13.64235973], [80.07818604, 13.64235973], [80.07818604, 13.64208031], [80.07763672, 13.64208221], [80.07763672, 13.6418066], [80.07736206, 13.6418066], [80.07736206, 13.64152813], [80.07681274, 13.64153099], [80.07681274, 13.64124966], [80.07653046, 13.64124966], [80.07653046, 13.64097023], [80.07624817, 13.64097214], [80.07624817, 13.64069366], [80.07569122, 13.64069366], [80.07569122, 13.64041615], [80.07541656, 13.64042091], [80.07541656, 13.64013958], [80.07512665, 13.64013958], [80.07512665, 13.63957977], [80.07458496, 13.63958359], [80.07458496, 13.6390276], [80.07430267, 13.63903141], [80.07430267, 13.63874054], [80.07402802, 13.63875008], [80.07402802, 13.63819408], [80.07375336, 13.63819408], [80.07375336, 13.63791561], [80.07347107, 13.63792133], [80.07347107, 13.63735962], [80.07319641, 13.63736153], [80.07319641, 13.63708401], [80.07263947, 13.63708401], [80.07263947, 13.63652802], [80.07235718, 13.63652992], [80.07235718, 13.63597202], [80.07208252, 13.63597202], [80.07208252, 13.63541794], [80.07180786, 13.63541985], [80.07180786, 13.63486195], [80.07152557, 13.63486195], [80.07152557, 13.63374996], [80.07125092, 13.63374996], [80.07125092, 13.63264179], [80.07096863, 13.63264179], [80.07096863, 13.63181019], [80.07068634, 13.63181019], [80.07068634, 13.63069057], [80.07041931, 13.63069344], [80.07041931, 13.62819576], [80.07069397, 13.62819576], [80.07069397, 13.62763882], [80.07096863, 13.62764168], [80.07096863, 13.6273613], [80.07125092, 13.6273613], [80.07125092, 13.62680531], [80.07152557, 13.62680531], [80.07152557, 13.62569523], [80.07180786, 13.62569523], [80.07180786, 13.62465096], [80.07180786, 13.62236118], [80.07152557, 13.62236118], [80.07152557, 13.62097263], [80.07125092, 13.62097263], [80.07125092, 13.61986065], [80.07096863, 13.61986065], [80.07096863, 13.61736107], [80.07125092, 13.61736107], [80.07125092, 13.61457062], [80.07180786, 13.61458206], [80.07180786, 13.61430645], [80.07235718, 13.61431122], [80.07235718, 13.61403084], [80.07430267, 13.61403084], [80.07430267, 13.61375046], [80.07485962, 13.61375046], [80.07485962, 13.61347008], [80.07514191, 13.61347198], [80.07514191, 13.61319447], [80.07541656, 13.61319447], [80.07541656, 13.61236], [80.07569122, 13.61236], [80.07569122, 13.61182022], [80.07596588, 13.61182022], [80.07596588, 13.61153126], [80.07624817, 13.61153126], [80.07624817, 13.61069202], [80.07597351, 13.61069393], [80.07597351, 13.61013794], [80.07569122, 13.61013985], [80.07569122, 13.60986042], [80.07541656, 13.60986233], [80.07541656, 13.60958195], [80.07514191, 13.60958195], [80.07514191, 13.60875034], [80.07485962, 13.60876083], [80.07485962, 13.60847187], [80.07430267, 13.60847187], [80.07430267, 13.60819435], [80.07208252, 13.60819435], [80.07208252, 13.60791588], [80.07180786, 13.60791969], [80.07180786, 13.60764027], [80.0715332, 13.60764027], [80.0715332, 13.60736179], [80.07125092, 13.60736179], [80.07125092, 13.60707855], [80.07096863, 13.60708427], [80.07096863, 13.6068058], [80.07068634, 13.60680962], [80.07068634, 13.60653019], [80.07096863, 13.60653019], [80.07096863, 13.60596943], [80.07125092, 13.60597229], [80.07125092, 13.6054163], [80.06986237, 13.60542011], [80.06986237, 13.60458088], [80.07013702, 13.60458374], [80.07013702, 13.60291767], [80.06986237, 13.60291958], [80.06986237, 13.60236168], [80.06930542, 13.60236168], [80.06930542, 13.60208321], [80.06819153, 13.60208321], [80.06819153, 13.60319328], [80.06764221, 13.60319328], [80.06764221, 13.60291767], [80.06735992, 13.60291958], [80.06735992, 13.60262966], [80.06625366, 13.60264015], [80.06625366, 13.60236168], [80.06569672, 13.60236168], [80.06569672, 13.6020813], [80.06541443, 13.60208321], [80.06541443, 13.60124874], [80.06513977, 13.6012516], [80.06513977, 13.60097122], [80.06485748, 13.60097122], [80.06485748, 13.60069466], [80.06430817, 13.60069466], [80.06430817, 13.60041714], [80.06402588, 13.60042191], [80.06402588, 13.60014153], [80.06375122, 13.60014153], [80.06375122, 13.59986115], [80.06319427, 13.59986115], [80.06319427, 13.59958267], [80.06291962, 13.5995903], [80.06291962, 13.59902859], [80.06263733, 13.59902859], [80.06263733, 13.59736061], [80.06236267, 13.59736061], [80.06236267, 13.59708309], [80.06208038, 13.59708309], [80.06208038, 13.5965271], [80.06153107, 13.59653187], [80.06153107, 13.59625053], [80.06124878, 13.59625053], [80.06124878, 13.59569073], [80.06097412, 13.59569454], [80.06097412, 13.59513855], [80.06041718, 13.59514141], [80.06041718, 13.59486103], [80.05986023, 13.59486103], [80.05986023, 13.59458256], [80.05930328, 13.59458256], [80.05930328, 13.59430695], [80.05874634, 13.59430695], [80.05874634, 13.59458256], [80.05819702, 13.59458065], [80.05819702, 13.59486103], [80.05764008, 13.59486103], [80.05764008, 13.59514141], [80.05735779, 13.59514141], [80.05735779, 13.59542179], [80.05709076, 13.59542179], [80.05709076, 13.59514141], [80.05680847, 13.59514141], [80.05680847, 13.59542179], [80.05652618, 13.59542179], [80.05652618, 13.59625053], [80.05596924, 13.59625053], [80.05596924, 13.59597111], [80.05569458, 13.59597301], [80.05569458, 13.59569454], [80.05541992, 13.59569454], [80.05541992, 13.59541702], [80.05513763, 13.59542179], [80.05513763, 13.59514141], [80.05486298, 13.59514141], [80.05486298, 13.59486103], [80.05430603, 13.59486103], [80.05430603, 13.59458065], [80.05403137, 13.59458256], [80.05403137, 13.59402657], [80.05430603, 13.59403133], [80.05430603, 13.59346199], [80.05458069, 13.59347343], [80.05458069, 13.59291744], [80.05486298, 13.59292126], [80.05486298, 13.59180927], [80.05513763, 13.59180927], [80.05513763, 13.59097004], [80.05541992, 13.5909729], [80.05541992, 13.59069538], [80.05486298, 13.59069538], [80.05486298, 13.59041691], [80.05236053, 13.59042072], [80.05236053, 13.5901413], [80.05208588, 13.5901413], [80.05208588, 13.58985996], [80.05152893, 13.58985996], [80.05152893, 13.58957958], [80.05124664, 13.58958244], [80.05124664, 13.58902645], [80.05095673, 13.58903122], [80.05095673, 13.58819199], [80.05124664, 13.58819389], [80.05124664, 13.5876379], [80.05152893, 13.5876503], [80.05152893, 13.58736038], [80.05180359, 13.58736038], [80.05180359, 13.58708191], [80.05208588, 13.58708191], [80.05208588, 13.5868063], [80.05236053, 13.58681107], [80.05236053, 13.58542061], [80.05264282, 13.58539963], [80.05263519, 13.58485985], [80.05291748, 13.58485985], [80.05291748, 13.58430576], [80.05319214, 13.58431053], [80.05319214, 13.58403015], [80.0534668, 13.58403015], [80.0534668, 13.58375168], [80.05319214, 13.58375168], [80.05319214, 13.58347034], [80.05347443, 13.58347225], [80.05347443, 13.58291626], [80.05374908, 13.58292103], [80.05374908, 13.58236027], [80.05403137, 13.58236217], [80.05403137, 13.58180618], [80.05430603, 13.58181095], [80.05430603, 13.58152103], [80.05458069, 13.58152771], [80.05458069, 13.58125019], [80.05486298, 13.58125019], [80.05486298, 13.58069229], [80.05513763, 13.5806942], [80.05513763, 13.58041573], [80.05541992, 13.58041954], [80.05541992, 13.58014011], [80.05568695, 13.58014011], [80.05568695, 13.57985973], [80.05596924, 13.57985973], [80.05596924, 13.57957935], [80.05625153, 13.57958412], [80.05625153, 13.57930565], [80.05652618, 13.57931042], [80.05652618, 13.57903004], [80.05680847, 13.57903004], [80.05680847, 13.57874966], [80.05709076, 13.57874966], [80.05709076, 13.57845974], [80.05735779, 13.57847214], [80.05735779, 13.57791805], [80.05764008, 13.57791996], [80.05764008, 13.57763958], [80.0579071, 13.57763958], [80.0579071, 13.5773592], [80.05819702, 13.57736206], [80.05819702, 13.57708359], [80.05847168, 13.57708359], [80.05847168, 13.57680607], [80.05874634, 13.57681179], [80.05874634, 13.57653046], [80.05902863, 13.57653046], [80.05902863, 13.57625198], [80.05930328, 13.57625198], [80.05930328, 13.57597065], [80.05986023, 13.57597065], [80.05986023, 13.57569313], [80.06014252, 13.57569313], [80.06014252, 13.57541847], [80.06069183, 13.57542038], [80.06069183, 13.57514191], [80.06096649, 13.57514191], [80.06096649, 13.57486057], [80.06153107, 13.57486057], [80.06153107, 13.57458305], [80.06180573, 13.57458305], [80.06180573, 13.57430458], [80.06236267, 13.5743103], [80.06236267, 13.57403183], [80.06291962, 13.57403183], [80.06291962, 13.5737524], [80.06375122, 13.5737524], [80.06375122, 13.57347107], [80.06430817, 13.57347107], [80.06430817, 13.57319546], [80.06513977, 13.57319546], [80.06513977, 13.57291698], [80.06569672, 13.57292175], [80.06569672, 13.57265091], [80.06652832, 13.57265091], [80.06652832, 13.57208061], [80.06680298, 13.57208347], [80.06680298, 13.57124901], [80.0670929, 13.57125092], [80.0670929, 13.57069111], [80.06735992, 13.57069302], [80.06735992, 13.56986141], [80.06764221, 13.56986141], [80.06764221, 13.56902695], [80.06791687, 13.56903076], [80.06791687, 13.56818962], [80.06819153, 13.56819534], [80.06819153, 13.56736088], [80.06846619, 13.56736088], [80.06846619, 13.56681156], [80.06874847, 13.56681156], [80.06874847, 13.56597137], [80.06903076, 13.56597328], [80.06903076, 13.56541729], [80.06932068, 13.5654192], [80.06932068, 13.5648613], [80.06958008, 13.5648613], [80.06958008, 13.56458473], [80.06986237, 13.56458473], [80.06986237, 13.56430531], [80.07013702, 13.56431103], [80.07013702, 13.56375122], [80.07041931, 13.56375122], [80.07041931, 13.5634613], [80.07069397, 13.56347275], [80.07069397, 13.56319523], [80.07096863, 13.56319523], [80.07096863, 13.56263828], [80.07125092, 13.56264114], [80.07125092, 13.56208038], [80.07152557, 13.56208229], [80.07152557, 13.56152916], [80.07180786, 13.56153107], [80.07180786, 13.56068993], [80.07208252, 13.56069374], [80.07208252, 13.56013775], [80.07235718, 13.56014061], [80.07235718, 13.55931091], [80.07263947, 13.55931091], [80.07263947, 13.55875015], [80.07290649, 13.55875015], [80.07290649, 13.55819035], [80.07347107, 13.55819416], [80.07347107, 13.55791569], [80.07402802, 13.55792141], [80.07402802, 13.55764008], [80.07459259, 13.55764008], [80.07459259, 13.5573597], [80.07485962, 13.5573597], [80.07485962, 13.55708027], [80.07541656, 13.55708408], [80.07541656, 13.55680561], [80.07596588, 13.55681133], [80.07596588, 13.55653], [80.07653046, 13.55653], [80.07653046, 13.55597019], [80.07680511, 13.5559721], [80.07680511, 13.55513763], [80.07707977, 13.55513954], [80.07707977, 13.55458164], [80.07736206, 13.55458355], [80.07736206, 13.55402756], [80.07847595, 13.55403042], [80.07847595, 13.55375004], [80.07985687, 13.55375004], [80.07985687, 13.55346966], [80.08097076, 13.55347157], [80.08097076, 13.55319405], [80.08208466, 13.55319405], [80.08208466, 13.55291557], [80.08319092, 13.55292034], [80.08319092, 13.55263996], [80.0845871, 13.55263996], [80.0845871, 13.55235958], [80.08569336, 13.55236244], [80.08569336, 13.55208397], [80.08625031, 13.55208397], [80.08625031, 13.55180645], [80.08653259, 13.55181026], [80.08653259, 13.5515213], [80.08708191, 13.55152798], [80.08708191, 13.55125046], [80.08735657, 13.55125046], [80.08735657, 13.55097198], [80.08791351, 13.55097198], [80.08791351, 13.55013657], [80.0881958, 13.55014038], [80.0881958, 13.54875183], [80.08847046, 13.54875183], [80.08847046, 13.54764175], [80.0881958, 13.54764175], [80.0881958, 13.54708099], [80.08847046, 13.5470829], [80.08847046, 13.54652691], [80.08875275, 13.54653168], [80.08875275, 13.54597092], [80.0890274, 13.54597092], [80.0890274, 13.5456953], [80.08930206, 13.5456953], [80.08930206, 13.54513931], [80.08957672, 13.54513931], [80.08957672, 13.54458141], [80.08985901, 13.54458332], [80.08985901, 13.54430485], [80.0901413, 13.54430962], [80.0901413, 13.54375076], [80.09041595, 13.54375076], [80.09041595, 13.54319096], [80.09069061, 13.54319477], [80.09069824, 13.54291725], [80.09152985, 13.54292202], [80.09152985, 13.54264069], [80.09208679, 13.54264069], [80.09208679, 13.54234982], [80.0929184, 13.54236126], [80.0929184, 13.54208279], [80.09347534, 13.54208279], [80.09347534, 13.54180527], [80.09430695, 13.54181194], [80.09430695, 13.54153061], [80.09513855, 13.54153061], [80.09513855, 13.54125118], [80.09570313, 13.54125118], [80.0956955, 13.5409708], [80.0965271, 13.5409708], [80.0965271, 13.54069519], [80.09680176, 13.54069519], [80.09680176, 13.5401392], [80.09707642, 13.54014111], [80.09707642, 13.53958035], [80.0973587, 13.53958321], [80.0973587, 13.53791714], [80.09764099, 13.53792095], [80.09764099, 13.53654003], [80.09819794, 13.53654003], [80.09819794, 13.53625107], [80.09902954, 13.53625107], [80.09902954, 13.53596973], [80.09958649, 13.5359726], [80.09958649, 13.53513813], [80.09929657, 13.53514099], [80.09929657, 13.53403091], [80.09902954, 13.53403091], [80.09902954, 13.53292084], [80.09874725, 13.53292084], [80.09874725, 13.53181076], [80.0984726, 13.53181076], [80.0984726, 13.53125], [80.09874725, 13.53125], [80.09874725, 13.53069019], [80.09902954, 13.53069401], [80.09902954, 13.53041553], [80.0993042, 13.53041553], [80.0993042, 13.5298624], [80.09958649, 13.5298624], [80.09958649, 13.52958202], [80.09986115, 13.52958202], [80.09986115, 13.52902794], [80.1001358, 13.52902985], [80.1001358, 13.52875042], [80.10069275, 13.52875042], [80.10069275, 13.52847195], [80.10124969, 13.52847195], [80.10124969, 13.52819443], [80.10180664, 13.52819443], [80.10180664, 13.52791595], [80.10263824, 13.52792263], [80.10263824, 13.52764034], [80.10320282, 13.52764034], [80.10320282, 13.52735138], [80.10375214, 13.52736187], [80.10375214, 13.52652836], [80.10402679, 13.52653027], [80.10402679, 13.52542019], [80.10430908, 13.52542019], [80.10430908, 13.52486038], [80.1048584, 13.52486229], [80.1048584, 13.52458382], [80.10541534, 13.52458382], [80.10541534, 13.5243063], [80.10597229, 13.52431011], [80.10597229, 13.52402973], [80.10652924, 13.52402973], [80.10652924, 13.52375031], [80.10679626, 13.52375031], [80.10679626, 13.52319145], [80.10708618, 13.52319336], [80.10708618, 13.52264023], [80.10736084, 13.52264023], [80.10736084, 13.52235889], [80.1076355, 13.52236176], [80.1076355, 13.52180481], [80.10791779, 13.52180958], [80.10791779, 13.52125168], [80.10820007, 13.52125168], [80.10820007, 13.5209713], [80.10847473, 13.5209713], [80.10847473, 13.52041531], [80.10874939, 13.52042198], [80.10874939, 13.51986122], [80.10902405, 13.51986122], [80.10902405, 13.51930523], [80.11013794, 13.51931], [80.11013794, 13.51902962], [80.11068726, 13.51902962], [80.11068726, 13.51874924], [80.11152649, 13.51874924], [80.11152649, 13.51847076], [80.11208344, 13.51847076], [80.11207581, 13.51764202], [80.11180878, 13.51764202], [80.11180878, 13.51653194], [80.11207581, 13.51653194], [80.11207581, 13.51681042], [80.11235809, 13.5168047], [80.11235809, 13.51708317], [80.11264038, 13.51708126], [80.11264038, 13.51736069], [80.11292267, 13.51736069], [80.11292267, 13.51764202], [80.11486053, 13.51764202], [80.11486053, 13.51736069], [80.1159668, 13.51736069], [80.1159668, 13.51708126], [80.11736298, 13.51708317], [80.11736298, 13.51652718], [80.11763763, 13.51653194], [80.11763763, 13.51597118], [80.11791992, 13.51597309], [80.11791992, 13.5154171], [80.11819458, 13.5154171], [80.11819458, 13.51513863], [80.11902618, 13.51514053], [80.11902618, 13.51458073], [80.11930847, 13.51458263], [80.11930847, 13.51375103], [80.11958313, 13.51375103], [80.11958313, 13.51208019], [80.11930847, 13.51208305], [80.11930847, 13.51180458], [80.11763763, 13.51180458], [80.11763763, 13.51208305], [80.11708069, 13.51208019], [80.11708069, 13.51237202], [80.11624908, 13.51237202], [80.11624908, 13.51153088], [80.1159668, 13.51153088], [80.1159668, 13.51041889], [80.11569214, 13.51041889], [80.11569214, 13.50931072], [80.11486053, 13.50931072], [80.11486053, 13.5090313], [80.11429596, 13.5090313], [80.11429596, 13.50875092], [80.11458588, 13.50875092], [80.11458588, 13.50846958], [80.11486053, 13.5084734], [80.11486053, 13.50819397], [80.11513519, 13.50819397], [80.11513519, 13.50791645], [80.11541748, 13.50792122], [80.11541748, 13.50764084], [80.1159668, 13.50764084], [80.1159668, 13.50736046], [80.11653137, 13.50736046], [80.11653137, 13.50708199], [80.11708069, 13.50708199], [80.11708069, 13.50680637], [80.11763763, 13.50680637], [80.11763763, 13.50708199], [80.11737061, 13.50708008], [80.11737061, 13.50764084], [80.11708069, 13.50763798], [80.11708069, 13.50819016], [80.11680603, 13.50819397], [80.11680603, 13.51069546], [80.11791992, 13.51069546], [80.11791992, 13.5084734], [80.11819458, 13.5084734], [80.11687469, 13.50280857], [80.10691071, 13.50394154], [80.10504913, 13.50363159], [80.10035706, 13.50520039], [80.09942627, 13.50631046], [80.09670258, 13.50821018], [80.09565735, 13.50984001], [80.09377289, 13.5135603], [80.08866882, 13.52552986], [80.0879364, 13.52595997], [80.08766937, 13.52661037], [80.08672333, 13.52724075], [80.07943726, 13.52936077], [80.07627869, 13.52612019], [80.07582092, 13.5267601], [80.07276154, 13.53392124], [80.06944275, 13.53759098], [80.06717682, 13.53592014], [80.06561279, 13.53476048], [80.05950928, 13.5325489], [80.05098724, 13.53051186], [80.04541779, 13.52198124], [80.03409576, 13.52180099], [80.0295105, 13.52359009], [80.01754761, 13.52513123], [80.01449585, 13.52849007], [80.00771332, 13.53237247], [79.994133, 13.52960014], [79.98967743, 13.5267601], [79.9892807, 13.51900005], [79.98973846, 13.51300144], [79.99017334, 13.51009083], [80.00039673, 13.51237202], [80.00623322, 13.51506233], [80.00842285, 13.50830173], [80.01361847, 13.50391197], [80.01908875, 13.50166035], [80.0256424, 13.5039711], [80.03275299, 13.50183964], [80.03697968, 13.49935055], [80.0371933, 13.49282169], [80.03604126, 13.4844799], [80.02481842, 13.48670006], [80.01885223, 13.48637199], [80.00589752, 13.48777103], [80.00440216, 13.47826004], [79.99537659, 13.45945072], [79.9907608, 13.45921993], [79.99056244, 13.46205997], [79.98747253, 13.46191025], [79.96826935, 13.45643139], [79.96186066, 13.45127964], [79.96218872, 13.44413853], [79.9630661, 13.44057274], [79.96102142, 13.42766094], [79.96322632, 13.41791058], [79.95848083, 13.41285133], [79.95085144, 13.40812016], [79.94426727, 13.41078186], [79.93595123, 13.40957165], [79.93247986, 13.40437126], [79.93557739, 13.39059067], [79.93562317, 13.38484955], [79.95028687, 13.38197136], [79.95358276, 13.37411118], [79.94803619, 13.36722088], [79.93974304, 13.36910057], [79.94064331, 13.36098099], [79.93998718, 13.35811138], [79.9287262, 13.34353065], [79.92550659, 13.33594036], [79.91713715, 13.34103966], [79.91068268, 13.34370041], [79.90628815, 13.33905125], [79.903862, 13.33327103], [79.89736176, 13.32948971], [79.8917923, 13.32461929], [79.88607788, 13.32129192], [79.88015747, 13.32043934], [79.87496185, 13.31740093], [79.87055206, 13.31175995], [79.86519623, 13.31072998], [79.8588562, 13.31374073], [79.85568237, 13.30814075], [79.85116577, 13.3034296], [79.83905792, 13.30334091], [79.8367691, 13.30299854], [79.83059692, 13.30206013], [79.82404327, 13.30231953], [79.80848694, 13.30508041], [79.80029297, 13.30432129], [79.7950058, 13.29857063], [79.79226685, 13.29164028], [79.78727722, 13.28462029], [79.77980042, 13.28207016], [79.77422333, 13.28513145], [79.76835632, 13.28962994], [79.75405884, 13.30278969], [79.75055695, 13.29881001], [79.74975586, 13.29088116], [79.74614716, 13.28000069], [79.74149323, 13.27666187], [79.72963715, 13.27507973], [79.72129059, 13.27223969], [79.72177887, 13.26573086], [79.73938751, 13.25443077], [79.74558258, 13.24821091], [79.7527771, 13.24376011], [79.77539063, 13.23411942], [79.78325653, 13.22816181], [79.78489685, 13.22348022], [79.78325653, 13.21791935], [79.77733612, 13.2171917], [79.7735672, 13.21751976], [79.76716614, 13.21333981], [79.76333618, 13.20885086], [79.75772095, 13.20557117], [79.75183105, 13.20477962], [79.74437714, 13.194911], [79.73826599, 13.19825935], [79.73750305, 13.20552063], [79.73368073, 13.21023178], [79.73252869, 13.21496105], [79.72651672, 13.21738052], [79.72283173, 13.22185135], [79.71856689, 13.2225914], [79.71570587, 13.21440029], [79.71142578, 13.21047974], [79.70568848, 13.20923138], [79.69963837, 13.20268059], [79.69243622, 13.20753098], [79.68875122, 13.20740986], [79.68943787, 13.21125031], [79.69574738, 13.2237606], [79.69603729, 13.23389053], [79.69193268, 13.23852921], [79.68456268, 13.23384953], [79.68068695, 13.22837067], [79.67331696, 13.22949028], [79.67111206, 13.23584175], [79.67376709, 13.24702072], [79.68430328, 13.25667953], [79.68161011, 13.26555061], [79.67932129, 13.26933193], [79.66853333, 13.28193092], [79.66590118, 13.27327919], [79.66256714, 13.26814175], [79.65740204, 13.2684803], [79.65338135, 13.27456856], [79.64862823, 13.2733593], [79.64376831, 13.2733593], [79.63848114, 13.2761898], [79.63250732, 13.2735424], [79.63072205, 13.26815987], [79.62956238, 13.26086044], [79.62431335, 13.26202011], [79.62075806, 13.25895023], [79.61519623, 13.26045036], [79.61075592, 13.26459122], [79.60510254, 13.26736069], [79.60114288, 13.26772976], [79.59485626, 13.26304245], [79.58867645, 13.26041126], [79.58644867, 13.25348091], [79.5854187, 13.24710083], [79.58026123, 13.24537086], [79.570961, 13.2473793], [79.56537628, 13.24940109], [79.55478668, 13.25918102], [79.54872894, 13.26712132], [79.54634094, 13.27404976], [79.54144287, 13.27893162], [79.53922272, 13.28975964], [79.53887177, 13.30092144], [79.53578186, 13.31107044], [79.52271271, 13.31593132], [79.50953674, 13.31470013], [79.49781036, 13.31482124], [79.48722839, 13.31655121], [79.47927856, 13.32145977], [79.45464325, 13.32432079], [79.42887878, 13.32356167], [79.41732025, 13.32195854], [79.40139771, 13.31575108], [79.37460327, 13.30303955], [79.38562775, 13.29470062], [79.39897919, 13.28915119], [79.40542603, 13.28541088], [79.42177582, 13.28666019], [79.42502594, 13.2813406], [79.41837311, 13.27458954], [79.41799164, 13.26906109], [79.41902161, 13.2663393], [79.41230011, 13.25751019], [79.40866852, 13.24674129], [79.407341, 13.23766136], [79.40968323, 13.22815037], [79.40865326, 13.21959019], [79.4108429, 13.21216202], [79.41699982, 13.21220112], [79.41816711, 13.21846199], [79.42690277, 13.22274017], [79.43609619, 13.2298317], [79.44245911, 13.22918034], [79.4454422, 13.2217207], [79.44550323, 13.21677113], [79.42163086, 13.20853138], [79.42315674, 13.2038002], [79.42315674, 13.19891071], [79.42156982, 13.19318104], [79.42378998, 13.1874609], [79.42059326, 13.18446159], [79.41329193, 13.18584919], [79.3979187, 13.18642235], [79.39256287, 13.18446159], [79.38437653, 13.18472099], [79.37835693, 13.18243122], [79.3690033, 13.17626095], [79.37078094, 13.16858959], [79.36717224, 13.16558075], [79.36493683, 13.16037083], [79.36120605, 13.15604115], [79.35472107, 13.16133976], [79.34777069, 13.16301918], [79.34709167, 13.15395069], [79.34783936, 13.14381981], [79.34686279, 13.14015102], [79.34674835, 13.13486099], [79.35457611, 13.12977123], [79.35009766, 13.12545013], [79.34435272, 13.12356091], [79.33779144, 13.12317085], [79.33531952, 13.12751007], [79.33068848, 13.12123108], [79.31672668, 13.11936855], [79.31239319, 13.11376953], [79.30973053, 13.10690022], [79.31002808, 13.0999403], [79.30793762, 13.09691143], [79.29747009, 13.0973711], [79.29876709, 13.11483192], [79.2881012, 13.11828041], [79.28495026, 13.12285042], [79.27751923, 13.11972046], [79.27384949, 13.12090111], [79.27266693, 13.12666035], [79.27128601, 13.13806057], [79.26741028, 13.14120102], [79.26120758, 13.14074993], [79.25646973, 13.13654041], [79.25267029, 13.14129925], [79.25137329, 13.14619923], [79.2472229, 13.14808178], [79.24423981, 13.14115143], [79.24333954, 13.13335037], [79.23670197, 13.1267519], [79.23304749, 13.12769985], [79.22635651, 13.13461018], [79.21832275, 13.13555145], [79.21466064, 13.12767029], [79.21826935, 13.12043095], [79.22244263, 13.11600971], [79.21827698, 13.1103096], [79.21827698, 13.10394192], [79.2142868, 13.0968399], [79.20744324, 13.09144115], [79.20220947, 13.09029007], [79.19332123, 13.08969021], [79.18891907, 13.08461857], [79.18699646, 13.07705021], [79.1835022, 13.07294083], [79.18065643, 13.06704044], [79.17910004, 13.060112], [79.16942596, 13.05300999], [79.17473602, 13.04967976], [79.17227173, 13.04372025], [79.17653656, 13.03827095], [79.17697144, 13.03337955], [79.17662048, 13.0297699], [79.1743927, 13.02525043], [79.17310333, 13.01928139], [79.17059326, 13.01568031], [79.16120148, 13.01179886], [79.15270233, 13.00729275], [79.14163208, 13.00981998], [79.13114929, 13.01676273], [79.11927032, 13.02256966], [79.10437775, 13.02422047], [79.08278656, 13.0124712], [79.06906891, 13.01415062], [79.06057739, 13.02083969], [79.05397797, 13.02816105], [79.05326843, 13.03799057], [79.04389191, 13.04372025], [79.03353882, 13.04566002], [79.02588654, 13.04957962], [79.02281952, 13.05640125], [79.01142883, 13.05782986], [79.00036621, 13.05788136], [78.99523926, 13.06304073], [78.98825073, 13.07265186], [78.98174286, 13.07619953], [78.97959137, 13.07651043], [78.97167969, 13.07511997], [78.96465302, 13.07279968], [78.9629364, 13.07155991], [78.95918274, 13.06544018], [78.95509338, 13.06492996], [78.95001221, 13.06608963], [78.94584656, 13.06350994], [78.93663788, 13.06997108], [78.9300766, 13.06602192], [78.91438293, 13.06776142], [78.91204071, 13.06328201], [78.9108429, 13.05610085], [78.90867615, 13.05045986], [78.90091705, 13.05210114], [78.89346313, 13.03509235], [78.89839935, 13.0316906], [78.90439606, 13.03105068], [78.91739655, 13.03254986], [78.92043304, 13.02862072], [78.92745972, 13.02346134], [78.9286499, 13.021451], [78.92463684, 13.01864147], [78.92299652, 13.02176094], [78.9159317, 13.02306175], [78.8901062, 13.01982975], [78.88191986, 13.01976204], [78.87937164, 13.02550125], [78.88088989, 13.04428101], [78.88040924, 13.06960201], [78.88352203, 13.08198929], [78.8760376, 13.08615971], [78.87032318, 13.08692074], [78.86473846, 13.08468056], [78.86068726, 13.0795002], [78.85835266, 13.07106972], [78.84393311, 13.0714798], [78.83226776, 13.06959057], [78.81342316, 13.0746479], [78.80809021, 13.07793045], [78.8008728, 13.07553005], [78.79418182, 13.06975937], [78.78659058, 13.06215191], [78.7830658, 13.05637169], [78.77752686, 13.05315971], [78.7544632, 13.04698181], [78.74601746, 13.0454092], [78.73951721, 13.04549122], [78.73217773, 13.05040264], [78.72550201, 13.05278015], [78.70244598, 13.05615139], [78.7012558, 13.04426003], [78.69597626, 13.01252079], [78.6937561, 13.00439167], [78.67935944, 13.00897026], [78.66861725, 13.01105976], [78.65110779, 13.01793194], [78.6489563, 13.0163517], [78.64505005, 13.00731087], [78.641716, 13.00161076], [78.63733673, 12.99684143], [78.62837982, 12.9897213], [78.62049866, 12.98252106], [78.61366272, 12.97889042], [78.62024689, 12.97391033], [78.63791656, 12.9544096], [78.6289978, 12.95311069], [78.63566589, 12.93834019], [78.64671326, 12.9190197], [78.63746643, 12.91588116], [78.6307373, 12.91597939], [78.62770081, 12.91792107], [78.62570953, 12.91918182], [78.62477112, 12.91418076], [78.61965179, 12.90207195], [78.61554718, 12.89321995], [78.61222839, 12.88856125], [78.60597229, 12.87369919], [78.60462189, 12.86600018], [78.60443115, 12.8574419], [78.59900665, 12.84947014], [78.59156799, 12.83854961], [78.59229279, 12.83677006], [78.59379578, 12.83300114], [78.59562683, 12.81548977], [78.59767151, 12.81107998], [78.5881958, 12.80478001], [78.59060669, 12.7979002], [78.58976746, 12.79244995], [78.58251953, 12.78532124], [78.58290863, 12.77622032], [78.5819397, 12.77077103], [78.5800705, 12.76724052], [78.57765961, 12.76585007], [78.56572723, 12.75901127], [78.56684875, 12.75214958], [78.56157684, 12.75257015], [78.5581131, 12.7516489], [78.55406189, 12.74606991], [78.55091858, 12.74680996], [78.54663086, 12.74560928], [78.54554749, 12.74391079], [78.55030823, 12.73876095], [78.54564667, 12.72861195], [78.55088806, 12.72622967], [78.55393219, 12.72606087], [78.55224609, 12.72039127], [78.54824829, 12.71498013], [78.54550934, 12.70738125], [78.54931641, 12.70070076], [78.55224609, 12.6970911], [78.55195618, 12.69433975], [78.54801178, 12.69536972], [78.54509735, 12.6926012], [78.54773712, 12.68911171], [78.54767609, 12.68559074], [78.54467773, 12.68443966], [78.54371643, 12.68460083], [78.54135895, 12.68501186], [78.53978729, 12.68422127], [78.53127289, 12.67993164], [78.52774811, 12.67900181], [78.52436829, 12.67969036], [78.52015686, 12.6870079], [78.51853943, 12.69237995], [78.52085876, 12.6971817], [78.52561188, 12.69474983], [78.52745819, 12.69730091], [78.52641296, 12.70123005], [78.51597595, 12.70352077], [78.51616669, 12.7062397], [78.51618958, 12.70640087], [78.51474762, 12.70698929], [78.51230621, 12.70800972], [78.51094055, 12.72172165], [78.5093689, 12.71979141], [78.50740814, 12.7130909], [78.50356293, 12.71337128], [78.50315857, 12.71809959], [78.50180054, 12.72150993], [78.49710083, 12.72411919], [78.4943161, 12.73037148], [78.48886108, 12.7319603], [78.48435211, 12.73478127], [78.47966003, 12.73001957], [78.48441315, 12.72305012], [78.49146271, 12.71706963], [78.49362946, 12.71116924], [78.5090332, 12.7049017], [78.51051331, 12.70176983], [78.5098114, 12.69878006], [78.5045929, 12.69800091], [78.50389099, 12.6933012], [78.49978638, 12.69685173], [78.49788666, 12.69851112], [78.49492645, 12.70372963], [78.49340057, 12.70347023], [78.494133, 12.69794083], [78.49301147, 12.69369984], [78.49090576, 12.69329166], [78.48754883, 12.69262886], [78.48631287, 12.69051075], [78.48956299, 12.68660927], [78.49357605, 12.68575001], [78.49340057, 12.68103027], [78.49740601, 12.67924976], [78.49711609, 12.67648983], [78.4940567, 12.67470074], [78.49344635, 12.66959095], [78.48855591, 12.66334248], [78.47406006, 12.65917969], [78.45765686, 12.66224957], [78.45935822, 12.63876057], [78.46292877, 12.63537025]]], [[[81.54180908, 16.35542107], [81.54180908, 16.35514069], [81.54207611, 16.35514069], [81.54207611, 16.35486031], [81.54264069, 16.35486031], [81.54264069, 16.35457993], [81.54291534, 16.35458374], [81.54291534, 16.35430527], [81.54319763, 16.35431099], [81.54319763, 16.35403061], [81.54347229, 16.35403061], [81.54347229, 16.35375023], [81.54403687, 16.35375023], [81.54402924, 16.35347176], [81.54430389, 16.35347176], [81.54430389, 16.35319519], [81.54458618, 16.35320091], [81.54458618, 16.35292053], [81.54486084, 16.35292053], [81.54486084, 16.35264015], [81.54511261, 16.35264015], [81.54541779, 16.35264015], [81.54541779, 16.35235977], [81.54569244, 16.35236168], [81.54569244, 16.35208321], [81.54597473, 16.35208321], [81.54597473, 16.35180473], [81.54624939, 16.35180473], [81.54624939, 16.35152817], [81.54651642, 16.35153008], [81.54651642, 16.35124969], [81.54680634, 16.35124969], [81.54680634, 16.35097122], [81.54708099, 16.35097313], [81.54708099, 16.35069466], [81.54736328, 16.35069466], [81.54736328, 16.34958458], [81.54708099, 16.34958458], [81.54708099, 16.34930611], [81.54680634, 16.34930992], [81.54680634, 16.34902954], [81.54624939, 16.34902954], [81.54624939, 16.34875107], [81.54541779, 16.34875107], [81.54541779, 16.3484726], [81.5451355, 16.3484726], [81.5451355, 16.34819412], [81.54373169, 16.34819412], [81.54319763, 16.34819412], [81.54319763, 16.3484726], [81.54070282, 16.3484726], [81.54070282, 16.34875107], [81.5404129, 16.34875107], [81.5404129, 16.3484726], [81.54013824, 16.3484726], [81.54013824, 16.34875107], [81.53985596, 16.34875107], [81.53985596, 16.3484726], [81.5395813, 16.3484726], [81.5395813, 16.34875107], [81.53874969, 16.34875107], [81.53874969, 16.3484726], [81.53736115, 16.3484726], [81.53736115, 16.34875107], [81.53180695, 16.34875107], [81.53180695, 16.34902954], [81.53151703, 16.34902954], [81.53151703, 16.34875107], [81.53098297, 16.34875107], [81.53098297, 16.34902954], [81.52401733, 16.34902954], [81.52401733, 16.34930992], [81.51930237, 16.34930611], [81.51930237, 16.34958458], [81.51486206, 16.34958267], [81.51486206, 16.34986115], [81.51346588, 16.34986115], [81.51346588, 16.35013962], [81.51319122, 16.35013962], [81.51319122, 16.35124969], [81.51346588, 16.35124969], [81.51346588, 16.35153008], [81.51403046, 16.35152817], [81.51403046, 16.35180473], [81.51430511, 16.35180473], [81.51430511, 16.35208321], [81.51457977, 16.35208321], [81.51457977, 16.35236168], [81.51513672, 16.35235977], [81.51513672, 16.35264015], [81.51541901, 16.35264015], [81.51541901, 16.35292053], [81.51568604, 16.35292053], [81.51568604, 16.35320091], [81.51652527, 16.35319519], [81.51652527, 16.35347176], [81.51708221, 16.35346031], [81.51708221, 16.35375023], [81.51790619, 16.35375023], [81.51790619, 16.35403061], [81.51930237, 16.35403061], [81.51930237, 16.35431099], [81.52041626, 16.35430527], [81.52041626, 16.35458374], [81.5220871, 16.35458374], [81.5220871, 16.35430527], [81.52236176, 16.35431099], [81.52236176, 16.35346031], [81.52263641, 16.35347176], [81.52263641, 16.35236168], [81.5229187, 16.35236168], [81.5229187, 16.35180473], [81.52347565, 16.35180473], [81.52347565, 16.35152817], [81.52401733, 16.35153008], [81.52401733, 16.35124969], [81.52458191, 16.35124969], [81.52458191, 16.35097122], [81.52513885, 16.35097313], [81.52513885, 16.35069466], [81.5284729, 16.35069466], [81.5284729, 16.35097313], [81.52874756, 16.35097122], [81.52874756, 16.35153008], [81.52902985, 16.35152817], [81.52902985, 16.35180473], [81.53013611, 16.35180473], [81.53013611, 16.35152817], [81.53236389, 16.35152817], [81.53236389, 16.35180473], [81.53347015, 16.35180473], [81.53347015, 16.35208321], [81.53375244, 16.35208321], [81.53375244, 16.35236168], [81.5340271, 16.35235977], [81.5340271, 16.35264015], [81.53430176, 16.35264015], [81.53430176, 16.35292053], [81.53457642, 16.35292053], [81.53457642, 16.35320091], [81.5348587, 16.35319519], [81.5348587, 16.35347176], [81.53514099, 16.35346031], [81.53514099, 16.35375023], [81.53542328, 16.35375023], [81.53542328, 16.35403061], [81.5359726, 16.35403061], [81.5359726, 16.35431099], [81.53624725, 16.35430527], [81.53624725, 16.35458374], [81.53652954, 16.35457993], [81.53652954, 16.35486031], [81.53819275, 16.35486031], [81.53819275, 16.35514069], [81.53985596, 16.35514069], [81.53985596, 16.35542107], [81.54180908, 16.35542107]]], [[[81.53514099, 16.35597229], [81.53514099, 16.35569382], [81.53541565, 16.35569382], [81.53541565, 16.35458374], [81.53514099, 16.35458374], [81.53514099, 16.35430527], [81.53486633, 16.35431099], [81.53486633, 16.35403061], [81.53457642, 16.35403061], [81.53457642, 16.35346031], [81.53430939, 16.35347176], [81.53430176, 16.35319519], [81.53375244, 16.35320091], [81.53375244, 16.35292053], [81.53347015, 16.35292053], [81.53347015, 16.35235977], [81.53263855, 16.35235977], [81.53263855, 16.35264015], [81.53151703, 16.35264015], [81.53151703, 16.35375023], [81.53180695, 16.35375023], [81.53180695, 16.35458374], [81.5320816, 16.35457993], [81.5320816, 16.35486031], [81.53235626, 16.35486031], [81.53235626, 16.35542107], [81.53291321, 16.35541725], [81.53291321, 16.35569382], [81.53347015, 16.35569382], [81.53347015, 16.35597229], [81.53514099, 16.35597229]]]]}}, {\\\"id\\\": \\\"2\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.3_1\\\", \\\"HASC_1\\\": \\\"IN.AR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Arunachal Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Agence de la Fronti\\\\u00e8re du Nord-Est(French-obsolete)|North East Frontier Agency\\\", \\\"apm25_popweighted\\\": 16.1, \\\"dalys_apm25_rate_6cod_mean_total\\\": 506.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1919.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2425.0, \\\"geo-id\\\": 2, \\\"hpm25_child_popweighted\\\": 148.4, \\\"hpm25_female_popweighted\\\": 170.6, \\\"hpm25_male_popweighted\\\": 122.8, \\\"location\\\": \\\"Arunachal Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 292.0, \\\"mort_hpm25_6cod_mean_total\\\": 970.0, \\\"mort_tpm25_6cod_mean_total\\\": 1263.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[94.21111298, 27.61084175], [94.21350861, 27.60442162], [94.22292328, 27.60074043], [94.22505188, 27.59851074], [94.22531128, 27.59523964], [94.22144318, 27.58791161], [94.22547913, 27.5810585], [94.22647858, 27.57563019], [94.23414612, 27.57146072], [94.24060059, 27.57035065], [94.25650024, 27.55742836], [94.2557373, 27.55076027], [94.25686646, 27.54050064], [94.26251221, 27.52742958], [94.25972748, 27.52349091], [94.25905609, 27.52260017], [94.22167206, 27.50703049], [94.2154007, 27.5031395], [94.21232605, 27.4979496], [94.21065521, 27.49790382], [94.19522858, 27.49745941], [94.19124603, 27.49632072], [94.18689728, 27.49081039], [94.17471313, 27.48407173], [94.1679306, 27.48418808], [94.16422272, 27.48098946], [94.1572113, 27.47804832], [94.15873718, 27.47000122], [94.16020203, 27.46647072], [94.15445709, 27.46046066], [94.14080811, 27.44845963], [94.13585663, 27.44585991], [94.12333679, 27.43498039], [94.11708069, 27.43097115], [94.10652161, 27.41805077], [94.09992218, 27.41391945], [94.09329987, 27.41094017], [94.08634949, 27.40456009], [94.07244873, 27.38301277], [94.06864929, 27.37440109], [94.0631485, 27.36891174], [94.06092834, 27.36355972], [94.05483246, 27.36283112], [94.04831696, 27.35874939], [94.04164124, 27.35329056], [94.0300827, 27.34799194], [94.02583313, 27.34770012], [94.00978851, 27.33889008], [94.00000763, 27.33470917], [94.00068665, 27.33013916], [93.99780273, 27.32785988], [93.99603271, 27.32788277], [93.99018097, 27.32464981], [93.985672, 27.32057953], [93.9809494, 27.31376839], [93.97267151, 27.30834007], [93.95652008, 27.29475975], [93.93891144, 27.27327919], [93.93390656, 27.26834106], [93.91889954, 27.25714111], [93.90104675, 27.24154091], [93.89298248, 27.23097038], [93.89097595, 27.23018074], [93.88561249, 27.2243824], [93.8674469, 27.19884109], [93.85746002, 27.19110107], [93.84716797, 27.17978096], [93.8398819, 27.1734581], [93.83699799, 27.17207909], [93.82897949, 27.17064285], [93.82666016, 27.16937065], [93.8170166, 27.15824127], [93.80858612, 27.15175056], [93.80729675, 27.15014076], [93.80680847, 27.14720917], [93.80561066, 27.13779068], [93.80143738, 27.13791084], [93.79824066, 27.13716125], [93.79779816, 27.13600922], [93.7984314, 27.13439941], [93.80024719, 27.13262939], [93.80222321, 27.13286018], [93.80580902, 27.13475037], [93.80818939, 27.13286972], [93.81350708, 27.13201141], [93.81423187, 27.13082123], [93.8138504, 27.12861824], [93.81136322, 27.12626839], [93.81315613, 27.12376022], [93.81495667, 27.12260818], [93.81910706, 27.12290192], [93.82195282, 27.12203026], [93.82549286, 27.1193409], [93.82723236, 27.11194038], [93.82663727, 27.09938049], [93.83132172, 27.09243965], [93.8330307, 27.08761024], [93.83621216, 27.08647919], [93.83436584, 27.0828495], [93.83476257, 27.08205032], [93.83674622, 27.07821274], [93.83502197, 27.07499123], [93.83209991, 27.07286835], [93.82901001, 27.07212257], [93.82824707, 27.06895065], [93.82710266, 27.06884956], [93.82549286, 27.07212257], [93.82457733, 27.07217026], [93.82287598, 27.06832123], [93.81878662, 27.06493187], [93.81571198, 27.06545067], [93.81288147, 27.07068062], [93.81018829, 27.06814003], [93.80854797, 27.06257057], [93.80488586, 27.06134987], [93.80213165, 27.06176186], [93.79942322, 27.06687164], [93.79876709, 27.06968117], [93.79805756, 27.07094193], [93.79709625, 27.0708828], [93.79399872, 27.05772972], [93.7911911, 27.05456924], [93.78742218, 27.05422974], [93.78613281, 27.05537033], [93.78511047, 27.05835915], [93.78321075, 27.06719017], [93.78227234, 27.06690025], [93.78116608, 27.06081963], [93.77913666, 27.05829048], [93.77915955, 27.05334282], [93.77794647, 27.05277061], [93.7754364, 27.0562191], [93.77368164, 27.06236076], [93.7723999, 27.06230164], [93.77178955, 27.0555191], [93.77095795, 27.05455017], [93.77007294, 27.05558014], [93.76819611, 27.0555191], [93.76847839, 27.04329109], [93.74642944, 27.03240967], [93.7425766, 27.02971268], [93.73388672, 27.02723122], [93.71893311, 27.01922035], [93.70556641, 27.00832939], [93.70449829, 27.00656128], [93.70568085, 27.00368118], [93.70095062, 26.99710274], [93.69828033, 26.99479103], [93.69655609, 26.99237823], [93.67578125, 26.97107124], [93.65511322, 26.96647835], [93.64016724, 26.96478081], [93.62449646, 26.96421051], [93.59583282, 26.95518112], [93.58422089, 26.95264816], [93.57079315, 26.95412254], [93.54548645, 26.95174026], [93.52584076, 26.94863129], [93.48935699, 26.93852997], [93.48683167, 26.94309044], [93.48029327, 26.94017982], [93.46810913, 26.93889046], [93.46383667, 26.94354057], [93.44786835, 26.95415115], [93.43666077, 26.95609093], [93.39073181, 26.9600296], [93.37423706, 26.96038055], [93.34793854, 26.96324158], [93.26685333, 26.95600128], [93.22238922, 26.94914055], [93.1842804, 26.93873978], [93.10896301, 26.92728043], [93.09187317, 26.9155407], [93.07636261, 26.91994095], [93.06884003, 26.92420959], [93.06017303, 26.92118073], [93.03820801, 26.91788101], [93.01937103, 26.91683006], [92.99743652, 26.93034935], [92.9957962, 26.93032074], [92.99375916, 26.93178749], [92.98668671, 26.93383026], [92.98271942, 26.93593979], [92.98069763, 26.93562126], [92.97297668, 26.94082069], [92.96161652, 26.94588089], [92.95136261, 26.94890976], [92.93276978, 26.9569397], [92.92640686, 26.96066093], [92.92166138, 26.96190834], [92.91777039, 26.96424103], [92.91494751, 26.96976089], [92.91667938, 26.98465157], [92.89977264, 26.9962616], [92.89028931, 26.99982071], [92.88751984, 27.00022125], [92.88337708, 27.00234032], [92.87243652, 27.00769997], [92.836586, 27.0135498], [92.82441711, 27.0184803], [92.78527069, 27.0306797], [92.76909637, 27.033041], [92.72750854, 27.02840042], [92.71367645, 27.02609062], [92.70231628, 27.02758026], [92.68238831, 27.03174019], [92.65892792, 27.03852081], [92.65702057, 27.03759003], [92.65048981, 27.02477837], [92.63909912, 27.01853943], [92.64463043, 27.01004028], [92.64420319, 27.00251007], [92.64530945, 26.99561119], [92.64546204, 26.98744965], [92.58521271, 26.96186256], [92.55361176, 26.95907021], [92.53176117, 26.9633007], [92.51544189, 26.96442032], [92.50502014, 26.96677017], [92.49063873, 26.96473122], [92.48375702, 26.96474075], [92.46629333, 26.96306038], [92.45957184, 26.96331024], [92.44616699, 26.96063995], [92.44216919, 26.95502281], [92.42576599, 26.94346809], [92.41188812, 26.94419098], [92.39975739, 26.92627144], [92.36728668, 26.93155098], [92.36443329, 26.9326992], [92.35305023, 26.93556976], [92.34677887, 26.93346024], [92.3200531, 26.92838097], [92.30285645, 26.92420959], [92.30374908, 26.90954018], [92.30053711, 26.90814018], [92.29007721, 26.90546036], [92.28148651, 26.9041481], [92.27639008, 26.90246964], [92.26786804, 26.9050827], [92.2651062, 26.9076004], [92.26123047, 26.90876961], [92.25456238, 26.91222954], [92.20935059, 26.89689064], [92.19484711, 26.89100075], [92.1771698, 26.89248085], [92.16882324, 26.89191055], [92.16239929, 26.89266014], [92.14792633, 26.89088821], [92.12953949, 26.89071274], [92.12419128, 26.88976097], [92.12036896, 26.89030075], [92.1129837, 26.89238358], [92.11442566, 26.89390564], [92.11675262, 26.89645004], [92.11721039, 26.89809799], [92.11795044, 26.89937973], [92.11843109, 26.90102768], [92.11888123, 26.90300941], [92.11951447, 26.90539551], [92.11992645, 26.90775681], [92.12013245, 26.90954208], [92.11989594, 26.91101456], [92.11922455, 26.91245079], [92.11779022, 26.9137001], [92.11710358, 26.91493988], [92.11662292, 26.9167347], [92.11646271, 26.91841507], [92.11645508, 26.92025566], [92.1166153, 26.9223175], [92.1167984, 26.92402077], [92.11714935, 26.92584229], [92.11751556, 26.92727089], [92.1175766, 26.92895126], [92.11716461, 26.93087196], [92.11683655, 26.93156052], [92.11626434, 26.93274498], [92.11579895, 26.93420601], [92.1158905, 26.93604851], [92.11614227, 26.93635559], [92.11696625, 26.93736458], [92.11795807, 26.9385891], [92.11827087, 26.9409008], [92.11764526, 26.94330025], [92.11620331, 26.94451714], [92.11475372, 26.94573402], [92.11438751, 26.94753075], [92.11455536, 26.94944191], [92.11445618, 26.95111656], [92.11473846, 26.95230865], [92.1160965, 26.95360374], [92.11735535, 26.95474815], [92.11920166, 26.9555912], [92.12149811, 26.95687103], [92.12217712, 26.95793724], [92.12207031, 26.95913506], [92.1218338, 26.96093178], [92.12132263, 26.96225357], [92.12054443, 26.96334076], [92.11991882, 26.96550179], [92.11968231, 26.96729851], [92.11945343, 26.96945381], [92.11962128, 26.97136307], [92.11965942, 26.97327614], [92.11860657, 26.97412682], [92.11621857, 26.97487831], [92.11326599, 26.97564507], [92.11277008, 26.97577286], [92.11263275, 26.97586441], [92.11119843, 26.97684288], [92.10934448, 26.9783268], [92.10829163, 26.97917747], [92.10683441, 26.97979736], [92.10604095, 26.98040581], [92.10499573, 26.98173523], [92.10475922, 26.98329353], [92.10453033, 26.98509026], [92.10456848, 26.9869709], [92.10492706, 26.98744392], [92.10592651, 26.98877525], [92.10639954, 26.98932266], [92.10715485, 26.99019241], [92.10652924, 26.99271202], [92.10564423, 26.99523354], [92.10448456, 26.99740219], [92.10409546, 26.99836349], [92.10345459, 26.99956894], [92.10321045, 27.00088692], [92.10311127, 27.00391197], [92.10169983, 27.00605011], [92.10115814, 27.00679207], [92.0994873, 27.00745201], [92.09853363, 27.00800705], [92.09708405, 27.00910378], [92.09579468, 27.00973129], [92.09552002, 27.01093864], [92.09539032, 27.01151848], [92.09315491, 27.01310539], [92.09274292, 27.01323509], [92.08996582, 27.01410675], [92.08757782, 27.01497841], [92.08479309, 27.01609421], [92.08187103, 27.01673317], [92.07826233, 27.01768494], [92.07788086, 27.01846123], [92.07770538, 27.01970863], [92.0773468, 27.02041054], [92.07730865, 27.02335358], [92.07772064, 27.02636719], [92.07896423, 27.03026772], [92.08074188, 27.03173065], [92.08246613, 27.03361511], [92.08283997, 27.03464317], [92.08267975, 27.03583717], [92.08181763, 27.03704262], [92.08139038, 27.03824043], [92.08152771, 27.04121971], [92.07450867, 27.04187775], [92.07434845, 27.04196358], [92.07107544, 27.04369164], [92.06945801, 27.04432678], [92.06607056, 27.04679108], [92.06202698, 27.04826736], [92.06113434, 27.0485878], [92.06040955, 27.04890442], [92.05909729, 27.0495739], [92.05786133, 27.05020523], [92.05641937, 27.05087852], [92.05497742, 27.05139732], [92.0535202, 27.05160904], [92.04919434, 27.05155563], [92.04637146, 27.05178642], [92.04399109, 27.05164528], [92.04341888, 27.05272102], [92.0433197, 27.05378532], [92.04276276, 27.05609322], [92.03913879, 27.05959511], [92.0381012, 27.06129837], [92.03717041, 27.0623455], [92.03722382, 27.06291008], [92.03738403, 27.06449127], [92.03760529, 27.06732559], [92.03720856, 27.0692482], [92.03630066, 27.07133293], [92.03554535, 27.07226372], [92.0348587, 27.07335281], [92.03271484, 27.07675171], [92.03172302, 27.07920456], [92.03123474, 27.08041573], [92.0309906, 27.08215904], [92.03108978, 27.08359718], [92.0315094, 27.08466911], [92.03139496, 27.08574867], [92.03120422, 27.08665085], [92.03131104, 27.08868599], [92.03147888, 27.09096146], [92.03123474, 27.09204292], [92.03098297, 27.0931263], [92.03033447, 27.09433365], [92.02934265, 27.0953064], [92.02875519, 27.09591293], [92.02897644, 27.09710884], [92.02893066, 27.09830856], [92.02862549, 27.10016823], [92.02791595, 27.10155678], [92.02681732, 27.10384941], [92.02590179, 27.10506058], [92.0249176, 27.10633278], [92.02484894, 27.10771942], [92.02390289, 27.10948944], [92.02426147, 27.11124039], [92.025177, 27.11162949], [92.02557373, 27.11190224], [92.02593231, 27.11239243], [92.0262146, 27.11263657], [92.02610016, 27.11523247], [92.0269165, 27.11628723], [92.02772522, 27.11703682], [92.02857208, 27.11889648], [92.02967072, 27.12039757], [92.03110504, 27.12179375], [92.03218842, 27.12282181], [92.0328064, 27.12511253], [92.03309631, 27.12654305], [92.03339386, 27.12809181], [92.03353882, 27.12904739], [92.03410339, 27.13047218], [92.03411865, 27.13154793], [92.03420258, 27.1323967], [92.03427887, 27.13322067], [92.03442383, 27.13381577], [92.03472137, 27.13536644], [92.03514862, 27.13703346], [92.03544617, 27.13858223], [92.03572845, 27.13953972], [92.03586578, 27.14001083], [92.03560638, 27.14049149], [92.03523254, 27.14157295], [92.03394318, 27.14434052], [92.03251648, 27.14723015], [92.0321579, 27.14914703], [92.03166199, 27.15178299], [92.03130341, 27.15405846], [92.02998352, 27.15503311], [92.02947998, 27.15659523], [92.02831268, 27.15864372], [92.02780914, 27.16032219], [92.02755737, 27.16128349], [92.02745056, 27.16283798], [92.02720642, 27.16427612], [92.02709961, 27.16595078], [92.0272522, 27.16714287], [92.02682495, 27.1686039], [92.02771759, 27.17072296], [92.02960968, 27.17201233], [92.03137207, 27.1733017], [92.0343399, 27.17469597], [92.03505707, 27.17661476], [92.03531647, 27.17731094], [92.03748322, 27.17895508], [92.03939819, 27.18143654], [92.03977203, 27.1818924], [92.04007721, 27.18226433], [92.04128265, 27.18236732], [92.04302216, 27.18258286], [92.04438782, 27.18234062], [92.04449463, 27.18232155], [92.04533386, 27.18260002], [92.04624176, 27.18289566], [92.04758453, 27.18323517], [92.04852295, 27.18346214], [92.05065918, 27.18355179], [92.05188751, 27.18461037], [92.05324554, 27.18590546], [92.05406189, 27.18696976], [92.05439758, 27.1877327], [92.05467987, 27.18836021], [92.05587769, 27.19124603], [92.05641174, 27.19194412], [92.05696869, 27.1926651], [92.05900574, 27.19416237], [92.05890656, 27.19582176], [92.05838013, 27.19682884], [92.05841064, 27.19874191], [92.05857849, 27.20041275], [92.05954742, 27.2021904], [92.05970764, 27.20410156], [92.06040955, 27.20552635], [92.06053162, 27.2069664], [92.06056976, 27.20743561], [92.06113434, 27.20898247], [92.06210327, 27.21088028], [92.06304932, 27.21134567], [92.06412506, 27.21192741], [92.06461334, 27.21209145], [92.06529236, 27.21232033], [92.06650543, 27.21325111], [92.06784821, 27.21447563], [92.06895447, 27.21591759], [92.06987, 27.21925735], [92.06977844, 27.22152901], [92.06980133, 27.22296333], [92.07050323, 27.2247467], [92.07093048, 27.22617531], [92.070961, 27.22772789], [92.07097626, 27.22868347], [92.07099152, 27.22975922], [92.07077026, 27.23203278], [92.07118988, 27.2331028], [92.07107544, 27.23453903], [92.07123566, 27.23585129], [92.07084656, 27.23657417], [92.07064819, 27.23801613], [92.06996155, 27.23933601], [92.06905365, 27.24078178], [92.06826782, 27.2421093], [92.06681824, 27.2429657], [92.06584167, 27.24363899], [92.06575775, 27.24369812], [92.06404877, 27.2452755], [92.06313324, 27.24636459], [92.06245422, 27.24704552], [92.06168365, 27.2478199], [92.06090546, 27.24890518], [92.05999756, 27.2508316], [92.05948639, 27.25203323], [92.0580368, 27.2530098], [92.05631256, 27.25399017], [92.05416107, 27.25342369], [92.05216217, 27.25369072], [92.05117035, 27.25399208], [92.04803467, 27.25494385], [92.0464325, 27.25496483], [92.04389954, 27.25535965], [92.04145813, 27.25525284], [92.03853607, 27.25476074], [92.03829193, 27.25594711], [92.03863525, 27.25695038], [92.03924561, 27.25765228], [92.03987885, 27.25866699], [92.04115295, 27.26066399], [92.04145813, 27.26098633], [92.04214478, 27.26172066], [92.04386902, 27.26237106], [92.0453186, 27.26365471], [92.04529572, 27.2664547], [92.04514313, 27.26888657], [92.04708862, 27.26888657], [92.04813385, 27.26896858], [92.04899597, 27.2696228], [92.04901123, 27.27043724], [92.04991913, 27.27042389], [92.05084229, 27.27122307], [92.05174255, 27.27039909], [92.05266571, 27.27119827], [92.05357361, 27.27118492], [92.05448151, 27.27117348], [92.05539703, 27.27116013], [92.05632019, 27.2719593], [92.05722809, 27.27194786], [92.05813599, 27.27193451], [92.05904388, 27.27192116], [92.05995941, 27.27190971], [92.06088257, 27.27270889], [92.06179047, 27.27269554], [92.06271362, 27.27349663], [92.06363678, 27.27429581], [92.06455994, 27.27509689], [92.06549072, 27.27589607], [92.06586456, 27.27622223], [92.06641388, 27.27669716], [92.06732178, 27.27668381], [92.0675354, 27.27667999], [92.06822968, 27.27667046], [92.06913757, 27.2766571], [92.07003784, 27.27583313], [92.070961, 27.27663231], [92.0714798, 27.27708244], [92.07188416, 27.27743149], [92.07279205, 27.27742004], [92.07371521, 27.27821922], [92.07463074, 27.27820587], [92.07553864, 27.27819443], [92.07643127, 27.27736855], [92.07641602, 27.27655411], [92.07696533, 27.27604866], [92.07731628, 27.27572823], [92.07820892, 27.27490234], [92.07910156, 27.27407646], [92.08000183, 27.27325058], [92.08090973, 27.27323914], [92.08180237, 27.27241325], [92.08267975, 27.2723999], [92.08287048, 27.27222824], [92.08361053, 27.27157402], [92.08451843, 27.27156067], [92.08541107, 27.27073479], [92.08540344, 27.26992226], [92.08631134, 27.26990891], [92.08720398, 27.26908302], [92.08879089, 27.26965714], [92.08904266, 27.26987076], [92.08995056, 27.26985741], [92.0908432, 27.26903152], [92.0917511, 27.26901817], [92.09266663, 27.26900482], [92.09357452, 27.26899147], [92.09449768, 27.26979256], [92.09540558, 27.26977921], [92.09630585, 27.26895332], [92.09721375, 27.26893997], [92.09812164, 27.26892662], [92.09901428, 27.26810074], [92.09992981, 27.26808739], [92.10083771, 27.26807404], [92.10174561, 27.26806259], [92.1026535, 27.26804924], [92.1035614, 27.26803589], [92.10447693, 27.26802254], [92.10540009, 27.26882172], [92.10630798, 27.26880836], [92.10723114, 27.26960945], [92.1081543, 27.27040863], [92.10906982, 27.27039528], [92.10997772, 27.27038193], [92.11088562, 27.27037048], [92.11177826, 27.26954269], [92.11269379, 27.26953125], [92.11360168, 27.2695179], [92.11452484, 27.27031708], [92.11543274, 27.27030373], [92.11636353, 27.27110291], [92.11727142, 27.27108955], [92.11817932, 27.27107811], [92.11908722, 27.27106476], [92.11999512, 27.27105141], [92.1209259, 27.27185059], [92.12184906, 27.27264977], [92.12186432, 27.2734623], [92.12278748, 27.27426338], [92.12371063, 27.27506256], [92.12372589, 27.27587509], [92.12374115, 27.27668762], [92.12375641, 27.27750206], [92.12467957, 27.27830124], [92.12469482, 27.27911377], [92.12471008, 27.2799263], [92.12472534, 27.28073883], [92.12475586, 27.2823658], [92.12385559, 27.28319168], [92.12296295, 27.28401756], [92.12297821, 27.28483009], [92.12299347, 27.28564262], [92.12300873, 27.28645706], [92.12211609, 27.28728294], [92.12121582, 27.28810883], [92.12032318, 27.28893471], [92.11943054, 27.28976059], [92.1190033, 27.2901516], [92.11853027, 27.29058647], [92.11763763, 27.29141235], [92.116745, 27.29223824], [92.11582947, 27.29225159], [92.11493683, 27.29307747], [92.11402893, 27.29309082], [92.11313629, 27.2939167], [92.11223602, 27.29474258], [92.11132813, 27.29475594], [92.11043549, 27.29558182], [92.10951996, 27.29559517], [92.10862732, 27.29642105], [92.10773468, 27.29724693], [92.10681915, 27.29726028], [92.10592651, 27.29808617], [92.10503387, 27.29891205], [92.10413361, 27.29973984], [92.10324097, 27.30056572], [92.10234833, 27.3013916], [92.1014328, 27.30140305], [92.1006012, 27.30217552], [92.10054016, 27.30223083], [92.10044098, 27.30223274], [92.09963226, 27.30224228], [92.09872437, 27.30225563], [92.0978241, 27.30308151], [92.0969162, 27.30309486], [92.0960083, 27.30310822], [92.09509277, 27.30312157], [92.09420013, 27.30394745], [92.09329224, 27.3039608], [92.09237671, 27.30397224], [92.09146881, 27.3039856], [92.09056091, 27.30399895], [92.08965302, 27.3040123], [92.08875275, 27.30483818], [92.08786011, 27.30566406], [92.08696747, 27.30648994], [92.08605194, 27.3065033], [92.0851593, 27.30732918], [92.08447266, 27.30796242], [92.08425903, 27.30815506], [92.08336639, 27.30898094], [92.0824585, 27.30899239], [92.08155823, 27.30981827], [92.08066559, 27.31064415], [92.07977295, 27.31147003], [92.07885742, 27.31148338], [92.07796478, 27.31230927], [92.07707214, 27.31313515], [92.0770874, 27.31394768], [92.07618713, 27.31477356], [92.07529449, 27.31559944], [92.07530975, 27.31641197], [92.07440948, 27.31723785], [92.07351685, 27.31806374], [92.0735321, 27.31887817], [92.07263184, 27.31970215], [92.0717392, 27.32052803], [92.07084656, 27.32135391], [92.06994629, 27.32217979], [92.06903839, 27.32219315], [92.06813812, 27.32301903], [92.06724548, 27.32384491], [92.06635284, 27.32467079], [92.0663681, 27.32548332], [92.06546783, 27.3263092], [92.06548309, 27.32712173], [92.06511688, 27.32747269], [92.06506348, 27.32780457], [92.06432343, 27.3311615], [92.06357574, 27.33451843], [92.06362915, 27.3376255], [92.06304932, 27.33949661], [92.06255341, 27.34153557], [92.06178284, 27.34333801], [92.06073761, 27.34502792], [92.05968475, 27.34599876], [92.05876923, 27.34708595], [92.05705261, 27.34877205], [92.05679321, 27.34902763], [92.05342102, 27.35147095], [92.05410767, 27.35201073], [92.05490112, 27.35263634], [92.05171967, 27.35635376], [92.05042267, 27.35796928], [92.04985809, 27.35963631], [92.04811096, 27.35970688], [92.04759979, 27.35972786], [92.04723358, 27.36087227], [92.04769135, 27.36179161], [92.04806519, 27.36253548], [92.04850006, 27.36432266], [92.04839325, 27.36623573], [92.0483017, 27.36838722], [92.04834747, 27.37089729], [92.04839325, 27.37364578], [92.04911804, 27.37686157], [92.04994965, 27.37828445], [92.05049133, 27.37875366], [92.05072784, 27.37898064], [92.05106354, 27.3791256], [92.05146027, 27.37946701], [92.05221558, 27.37990379], [92.05387878, 27.3816452], [92.05477905, 27.38275909], [92.05496979, 27.38598251], [92.05487823, 27.38849449], [92.05504608, 27.39028358], [92.05508423, 27.39231491], [92.05523682, 27.39350891], [92.05513763, 27.39542198], [92.05577087, 27.39811897], [92.05825806, 27.39998055], [92.05628204, 27.40054131], [92.05511475, 27.40187454], [92.05432892, 27.40284348], [92.05327606, 27.40393257], [92.05236053, 27.40514183], [92.05037689, 27.40636444], [92.04931641, 27.40721512], [92.04773712, 27.40891075], [92.04628754, 27.41000748], [92.04497528, 27.4116993], [92.04364014, 27.41410446], [92.04347229, 27.41570854], [92.04270172, 27.41706085], [92.04123688, 27.41963768], [92.04180908, 27.42214012], [92.04375458, 27.42415237], [92.04386139, 27.42426109], [92.04406738, 27.42695427], [92.04335785, 27.42811394], [92.04299927, 27.42869568], [92.04263306, 27.43116951], [92.04251862, 27.43192863], [92.04151154, 27.43528938], [92.03894043, 27.43751144], [92.03874207, 27.43807793], [92.03795624, 27.43904495], [92.03569031, 27.43991089], [92.03408813, 27.43993378], [92.03174591, 27.43992043], [92.02902985, 27.44031525], [92.02684021, 27.44034576], [92.02503967, 27.44340706], [92.02372742, 27.44485855], [92.02266693, 27.44582939], [92.02255249, 27.44678688], [92.02203369, 27.44775009], [92.02152252, 27.44919205], [92.02114105, 27.45063019], [92.02102661, 27.45146942], [92.02080536, 27.45410156], [92.0212326, 27.45588875], [92.02140808, 27.45803642], [92.0218277, 27.45898628], [92.02145386, 27.46066475], [92.02122498, 27.46293831], [92.02113342, 27.46533012], [92.02079773, 27.46915817], [92.02017975, 27.47227478], [92.02007294, 27.47371101], [92.01965332, 27.47770309], [92.01916504, 27.47913933], [92.01876831, 27.48032379], [92.01734161, 27.48013878], [92.01670074, 27.48005486], [92.01403046, 27.47902489], [92.01071167, 27.47901154], [92.0090332, 27.47852325], [92.00153351, 27.47862434], [92.00097656, 27.47866631], [91.99765015, 27.47891808], [91.99700165, 27.47890091], [91.99650574, 27.47808647], [91.99582672, 27.47805405], [91.99489594, 27.4779129], [91.99377441, 27.47688103], [91.99330902, 27.47631454], [91.99272919, 27.47574043], [91.99227905, 27.47529793], [91.99198151, 27.4747982], [91.99183655, 27.4743824], [91.99176025, 27.47353172], [91.99183655, 27.47217941], [91.99168396, 27.47172928], [91.99150085, 27.47129631], [91.99076843, 27.46969604], [91.98980713, 27.46819687], [91.98884583, 27.4670639], [91.98828125, 27.46663094], [91.98705292, 27.46591759], [91.98577118, 27.46618652], [91.9853363, 27.46620369], [91.98492432, 27.46612167], [91.98439789, 27.46568871], [91.98394775, 27.46547318], [91.98339081, 27.46537399], [91.98282623, 27.4651413], [91.98260498, 27.4649086], [91.9821701, 27.46444321], [91.98181152, 27.46415901], [91.98113251, 27.4640274], [91.98051453, 27.46382904], [91.97982025, 27.46352959], [91.97899628, 27.46299744], [91.97787476, 27.46248245], [91.97742462, 27.46286774], [91.97746277, 27.46321869], [91.97721863, 27.46351814], [91.97673035, 27.4638195], [91.97584534, 27.46422195], [91.97483063, 27.46469116], [91.97437286, 27.46499252], [91.97406769, 27.46519279], [91.97354126, 27.46547699], [91.97292328, 27.46567917], [91.97238159, 27.46604729], [91.97180176, 27.46629715], [91.97126007, 27.46574783], [91.97101593, 27.46548843], [91.97018433, 27.46459961], [91.96941376, 27.46386719], [91.96858978, 27.46345139], [91.96734619, 27.46318626], [91.96604919, 27.46288872], [91.96434784, 27.46279144], [91.96344757, 27.4627285], [91.96237183, 27.46151161], [91.96122742, 27.46042824], [91.96073914, 27.46018028], [91.96008301, 27.45993233], [91.95954132, 27.45988274], [91.95793915, 27.46011925], [91.95706177, 27.4602375], [91.95556641, 27.46040726], [91.95487213, 27.46035767], [91.954216, 27.46014214], [91.95352936, 27.45972633], [91.953125, 27.45957756], [91.95155334, 27.45969582], [91.94936371, 27.46001625], [91.94871521, 27.46020126], [91.94777679, 27.46073914], [91.94769287, 27.46081161], [91.94701385, 27.46138954], [91.94641876, 27.46194077], [91.94603729, 27.46179199], [91.94561005, 27.46139336], [91.94496918, 27.46089363], [91.94471741, 27.46074867], [91.94430542, 27.46051025], [91.94300079, 27.459795], [91.94252777, 27.45989609], [91.94213867, 27.46016312], [91.94142151, 27.46067238], [91.94103241, 27.46094894], [91.94043732, 27.46133423], [91.93936157, 27.46190262], [91.9389267, 27.46208763], [91.93824005, 27.46247292], [91.93780518, 27.46285629], [91.93737793, 27.46349144], [91.93687439, 27.46436119], [91.93624878, 27.46497917], [91.93566895, 27.46534729], [91.93531036, 27.46568108], [91.93507385, 27.46619797], [91.93445587, 27.46651649], [91.93405914, 27.46590042], [91.93367004, 27.46549988], [91.93278503, 27.46501732], [91.93229675, 27.46491814], [91.93180084, 27.46499062], [91.9313736, 27.46505356], [91.93071747, 27.46517181], [91.93022919, 27.46549034], [91.92959595, 27.46604156], [91.92931366, 27.46650887], [91.92900085, 27.46695328], [91.9288559, 27.4674778], [91.92867279, 27.46829414], [91.92848206, 27.46876144], [91.9281311, 27.46926308], [91.92700195, 27.4703331], [91.92613983, 27.47136688], [91.92585754, 27.47185326], [91.92514801, 27.47253609], [91.9243927, 27.47335625], [91.92362976, 27.47429085], [91.92333221, 27.47527695], [91.92301178, 27.47512627], [91.92289734, 27.47480965], [91.92272186, 27.47449303], [91.92219543, 27.4739933], [91.92134857, 27.47347832], [91.92063904, 27.47326279], [91.91989136, 27.47312927], [91.91923523, 27.47296524], [91.91841888, 27.47289848], [91.91692352, 27.47281837], [91.91629028, 27.47263527], [91.91557312, 27.47228622], [91.91503143, 27.47232056], [91.9145813, 27.47238731], [91.9141922, 27.47242165], [91.91383362, 27.47247124], [91.91294861, 27.47250748], [91.91201019, 27.47195816], [91.91135406, 27.47165871], [91.91094208, 27.47165871], [91.91053009, 27.4717598], [91.90977478, 27.47202873], [91.9080658, 27.47269821], [91.90769958, 27.47264862], [91.90579224, 27.4719677], [91.90459442, 27.47171974], [91.90268707, 27.47132111], [91.90231323, 27.47138786], [91.90184021, 27.47150612], [91.90126038, 27.47152328], [91.90029907, 27.47125816], [91.89943695, 27.47104263], [91.89833832, 27.47094345], [91.89704132, 27.47091293], [91.89595795, 27.47099686], [91.89545441, 27.47113228], [91.89489746, 27.47138214], [91.8932724, 27.47233582], [91.89149475, 27.47305489], [91.88983917, 27.47365761], [91.88790894, 27.47459602], [91.88671112, 27.475214], [91.88611603, 27.47519875], [91.88561249, 27.47468185], [91.88508606, 27.47456741], [91.88469696, 27.47470093], [91.88363647, 27.4749527], [91.88214111, 27.47512054], [91.88148499, 27.47510529], [91.88092804, 27.47490501], [91.87971497, 27.47465706], [91.87864685, 27.47449112], [91.87814331, 27.47419167], [91.87769318, 27.47374153], [91.87724304, 27.47322464], [91.87696075, 27.47293091], [91.87631989, 27.47225952], [91.87586975, 27.47177505], [91.875, 27.47105789], [91.87451935, 27.47084236], [91.87329865, 27.47052765], [91.87254333, 27.47052956], [91.87201691, 27.47061348], [91.87136078, 27.47076416], [91.87078094, 27.47103119], [91.87044525, 27.47124863], [91.86999512, 27.4716835], [91.86940002, 27.4723835], [91.86910248, 27.47301865], [91.86889648, 27.47340393], [91.86877441, 27.47393608], [91.86871338, 27.47445488], [91.86873627, 27.47502136], [91.86875153, 27.47597122], [91.8686676, 27.47640991], [91.86857605, 27.47690582], [91.8684082, 27.47767448], [91.8680191, 27.47847557], [91.86751556, 27.47945976], [91.86714935, 27.47987747], [91.86619568, 27.48076248], [91.865448, 27.48138046], [91.86434174, 27.48208427], [91.86299896, 27.48290253], [91.86214447, 27.48323631], [91.8612442, 27.48343849], [91.86064911, 27.48343849], [91.85955811, 27.4832077], [91.85768127, 27.4825573], [91.85694885, 27.48228264], [91.85679626, 27.48222542], [91.85614014, 27.48204231], [91.85558319, 27.48199272], [91.85520935, 27.48197746], [91.85477448, 27.48212814], [91.85428619, 27.48237419], [91.85370636, 27.48266411], [91.85322571, 27.48296356], [91.85208893, 27.48384857], [91.8509903, 27.48465157], [91.85014343, 27.48521996], [91.84922791, 27.48578835], [91.84844208, 27.4861393], [91.84812164, 27.48625565], [91.84747314, 27.48602295], [91.84729767, 27.48568916], [91.84713745, 27.48538971], [91.84699249, 27.48453903], [91.8467865, 27.48428917], [91.84646606, 27.48397255], [91.84609222, 27.48377228], [91.84560394, 27.4833889], [91.84534454, 27.48300552], [91.84495544, 27.48223877], [91.84473419, 27.48168755], [91.84460449, 27.48128891], [91.84413147, 27.48060417], [91.84370422, 27.48005486], [91.84337616, 27.47957039], [91.84326172, 27.47920418], [91.84313202, 27.47865295], [91.84292603, 27.47810936], [91.84283447, 27.47787094], [91.84227753, 27.47722054], [91.84133911, 27.47636986], [91.84083557, 27.47605324], [91.84010315, 27.47572136], [91.83944702, 27.47537041], [91.83892822, 27.47505569], [91.83843994, 27.47463799], [91.83818817, 27.47437286], [91.83699036, 27.47353935], [91.83640289, 27.47299004], [91.83584595, 27.47232246], [91.83509064, 27.47185707], [91.83437347, 27.47154045], [91.83366394, 27.47135735], [91.83267212, 27.47109032], [91.83210754, 27.47092438], [91.8314743, 27.47065926], [91.83087158, 27.46997452], [91.83042145, 27.46925735], [91.82987976, 27.46870804], [91.82935333, 27.46839142], [91.82867432, 27.46817589], [91.82781982, 27.46806717], [91.8272171, 27.46800613], [91.8267746, 27.4679718], [91.82636261, 27.46788216], [91.82579041, 27.46767235], [91.82528687, 27.46767998], [91.82489777, 27.46743393], [91.8239212, 27.46792984], [91.82327271, 27.46849823], [91.82273102, 27.46866608], [91.82209778, 27.46886635], [91.82170105, 27.46910095], [91.82134247, 27.46941757], [91.82123566, 27.46961021], [91.82112122, 27.46981812], [91.82089996, 27.47028542], [91.82065582, 27.47083473], [91.82033539, 27.47118568], [91.81991577, 27.47122002], [91.81942749, 27.47127151], [91.81832123, 27.47145462], [91.81785583, 27.4716568], [91.81729889, 27.47185516], [91.81656647, 27.47204018], [91.81571198, 27.47239113], [91.81468201, 27.47300911], [91.81380463, 27.47359467], [91.8130722, 27.47367859], [91.81243896, 27.47359467], [91.81182098, 27.47341347], [91.81092834, 27.4731636], [91.81027985, 27.47296333], [91.80975342, 27.47289848], [91.80945587, 27.47309875], [91.8090744, 27.47323227], [91.8086853, 27.47306442], [91.80782318, 27.47274971], [91.80701447, 27.47266579], [91.80617523, 27.47266579], [91.80541992, 27.47273445], [91.80461121, 27.47286797], [91.80388641, 27.47280121], [91.80339813, 27.47265244], [91.80303955, 27.47240257], [91.80257416, 27.47203636], [91.80217743, 27.471735], [91.80141449, 27.47163582], [91.80086517, 27.47168732], [91.80039978, 27.47177124], [91.79964447, 27.47203827], [91.79889679, 27.47243881], [91.79790497, 27.47307396], [91.79754639, 27.4729557], [91.79717255, 27.47265816], [91.79685211, 27.47227478], [91.79656982, 27.47177315], [91.79623413, 27.47127342], [91.79576874, 27.47070694], [91.79517365, 27.47027588], [91.79405212, 27.46978951], [91.79291534, 27.46962357], [91.79231262, 27.46967506], [91.79195404, 27.46975136], [91.79160309, 27.46982574], [91.79100037, 27.46986008], [91.79057312, 27.4698925], [91.78990173, 27.46982574], [91.78926086, 27.46974373], [91.78862, 27.46962738], [91.78801727, 27.4695282], [91.78764343, 27.46937752], [91.78730774, 27.46914482], [91.78710175, 27.46887779], [91.78670502, 27.46866035], [91.78556824, 27.46847725], [91.78505707, 27.46832848], [91.78472137, 27.4681282], [91.78443146, 27.46787643], [91.78420258, 27.46767807], [91.78343201, 27.467062], [91.78310394, 27.46676064], [91.78257751, 27.46651077], [91.78179169, 27.46621132], [91.78113556, 27.46604538], [91.78025818, 27.46574593], [91.77952576, 27.46554565], [91.7790451, 27.46539497], [91.77831268, 27.46511269], [91.77772522, 27.46487999], [91.77690125, 27.46484756], [91.77574158, 27.46503067], [91.77557373, 27.46507263], [91.77458191, 27.46531487], [91.77352905, 27.46541595], [91.77298737, 27.46538353], [91.77189636, 27.46518517], [91.77095795, 27.46500969], [91.77063751, 27.46495056], [91.76925659, 27.46485138], [91.7673111, 27.46489716], [91.76682281, 27.46509933], [91.76667023, 27.46538162], [91.76642609, 27.46572113], [91.76641083, 27.46579933], [91.76628113, 27.46642113], [91.76625824, 27.46698952], [91.76622772, 27.46797371], [91.76643372, 27.46912384], [91.76682281, 27.47032547], [91.76721191, 27.47172546], [91.76750946, 27.47272682], [91.76758575, 27.47339439], [91.76737976, 27.47379494], [91.76670074, 27.47421074], [91.76621246, 27.47444534], [91.76560974, 27.4745121], [91.76419067, 27.47458076], [91.76331329, 27.47473145], [91.76187897, 27.47496414], [91.75967407, 27.47518349], [91.75759125, 27.47541809], [91.75623322, 27.47551918], [91.75457001, 27.47566986], [91.75335693, 27.47600365], [91.75307465, 27.47628784], [91.75254822, 27.47667122], [91.75205994, 27.47667122], [91.75163269, 27.47647095], [91.75123596, 27.47627068], [91.75088501, 27.47597122], [91.75043488, 27.47543716], [91.75006866, 27.47492027], [91.74945068, 27.47421455], [91.74920654, 27.47393608], [91.74851227, 27.47322083], [91.74808502, 27.47285271], [91.74761963, 27.4724865], [91.7472229, 27.47230339], [91.74655151, 27.47226334], [91.74544525, 27.47186089], [91.74356079, 27.47128677], [91.74060059, 27.47084427], [91.73845673, 27.47027206], [91.73522186, 27.46947289], [91.73267365, 27.46938324], [91.7314682, 27.46892166], [91.72945404, 27.46894455], [91.72866058, 27.46931267], [91.72719574, 27.46980667], [91.7260437, 27.47030067], [91.72432709, 27.47103691], [91.7196579, 27.47216606], [91.71712494, 27.47315216], [91.71437073, 27.47472191], [91.71472168, 27.47631836], [91.71542358, 27.47873688], [91.71675873, 27.48357964], [91.71703339, 27.48452377], [91.71723938, 27.48517227], [91.71496582, 27.48816109], [91.71318054, 27.49357224], [91.71240234, 27.4944706], [91.71022797, 27.49621391], [91.7071228, 27.49707985], [91.70560455, 27.49774933], [91.70402527, 27.49877357], [91.70098877, 27.49993324], [91.70015717, 27.50100327], [91.69831848, 27.50208855], [91.69773865, 27.50333977], [91.69749451, 27.50458336], [91.69664001, 27.50542259], [91.69472504, 27.5059185], [91.69312286, 27.5055809], [91.69171906, 27.50453186], [91.69078827, 27.5045433], [91.68865967, 27.50391769], [91.68751526, 27.50292397], [91.68727875, 27.50260353], [91.68622589, 27.50116348], [91.68527985, 27.49957848], [91.68553162, 27.49856949], [91.68504333, 27.49721336], [91.68402863, 27.49568748], [91.68302155, 27.49510765], [91.68182373, 27.49464798], [91.68082428, 27.4946003], [91.67856598, 27.49409294], [91.67709351, 27.49310493], [91.67562866, 27.49306107], [91.67456818, 27.49307442], [91.67284393, 27.49315262], [91.67190552, 27.49310684], [91.67092133, 27.49299812], [91.67018127, 27.49235535], [91.66931152, 27.49212837], [91.66905975, 27.491642], [91.66836548, 27.49065971], [91.66732025, 27.49071884], [91.66703796, 27.4907341], [91.66668701, 27.49030685], [91.66612244, 27.48962212], [91.66379547, 27.48800659], [91.66343689, 27.48672676], [91.66251373, 27.48668671], [91.66082001, 27.48511314], [91.65978241, 27.48507309], [91.65873718, 27.48436737], [91.65628052, 27.48435783], [91.65171051, 27.48434258], [91.65155029, 27.48538017], [91.65116119, 27.48514175], [91.6510849, 27.48621559], [91.65072632, 27.48758888], [91.65077209, 27.48853302], [91.65053558, 27.48897743], [91.64990997, 27.4898777], [91.64952087, 27.49040985], [91.64911652, 27.49106407], [91.64890289, 27.49132538], [91.64865875, 27.49154282], [91.64851379, 27.49194336], [91.64841461, 27.49236298], [91.64811707, 27.49401665], [91.64797974, 27.49475479], [91.6479187, 27.49526978], [91.64783478, 27.49573517], [91.64746094, 27.49609947], [91.64727783, 27.49653625], [91.64700317, 27.49721336], [91.64696503, 27.49801254], [91.64713287, 27.49853516], [91.64691162, 27.49955177], [91.64670563, 27.50050163], [91.6452179, 27.50140762], [91.64385986, 27.50275803], [91.64232635, 27.50421333], [91.6403656, 27.50587845], [91.63897705, 27.50655365], [91.63768768, 27.50780296], [91.63634491, 27.50938606], [91.6335144, 27.51029778], [91.63179779, 27.5112648], [91.62968445, 27.51229477], [91.62763214, 27.51285172], [91.62591553, 27.51358032], [91.62432861, 27.51395416], [91.62360382, 27.51431656], [91.62304688, 27.5177002], [91.62249756, 27.51937294], [91.62182617, 27.52050972], [91.62075043, 27.5220089], [91.61962128, 27.52346039], [91.6190033, 27.52485275], [91.61850739, 27.52634621], [91.61755371, 27.52784729], [91.61625671, 27.52986336], [91.61472321, 27.53157425], [91.61415863, 27.53255463], [91.61430359, 27.53455544], [91.61397552, 27.53609848], [91.61367035, 27.53846359], [91.61334229, 27.54005814], [91.61307526, 27.54134369], [91.61252594, 27.54335213], [91.61126709, 27.54418755], [91.60990906, 27.54399872], [91.60837555, 27.54324532], [91.60653687, 27.54310417], [91.60601807, 27.54306412], [91.60428619, 27.5428791], [91.60229492, 27.54258347], [91.59966278, 27.54195404], [91.5973587, 27.54187584], [91.59534454, 27.54254723], [91.59394836, 27.54354858], [91.59357452, 27.54408836], [91.59296417, 27.54498482], [91.59218597, 27.54642105], [91.59150696, 27.54794693], [91.58972931, 27.54992867], [91.58826447, 27.55244064], [91.58638763, 27.55415726], [91.58569336, 27.5545063], [91.58439636, 27.55515862], [91.58312225, 27.55704498], [91.58314514, 27.55883026], [91.58318329, 27.5591774], [91.58339691, 27.5610199], [91.58358765, 27.56261063], [91.58377075, 27.56353188], [91.58367157, 27.56430435], [91.58362579, 27.56512451], [91.58334351, 27.56623077], [91.58196259, 27.56731606], [91.58028412, 27.56920815], [91.57749939, 27.57039642], [91.5758667, 27.57111168], [91.57501221, 27.57189178], [91.57387543, 27.57287979], [91.57269287, 27.57453537], [91.57218933, 27.57592583], [91.57170105, 27.57875443], [91.57062531, 27.58054924], [91.56916046, 27.58196259], [91.5668869, 27.58414459], [91.56691742, 27.58645439], [91.56755829, 27.58826447], [91.56827545, 27.5900898], [91.56890869, 27.59136581], [91.56904602, 27.59165001], [91.57012177, 27.59314346], [91.5705719, 27.59474945], [91.57142639, 27.59590149], [91.57270813, 27.59737587], [91.57444763, 27.59797478], [91.57572174, 27.59873009], [91.57681274, 27.59958649], [91.57759094, 27.60019875], [91.57904816, 27.60131264], [91.5809021, 27.60231972], [91.58213806, 27.60456467], [91.58309174, 27.60686493], [91.58426666, 27.60823822], [91.58438873, 27.60890388], [91.58405304, 27.60957527], [91.58319855, 27.61035347], [91.58211517, 27.61087799], [91.58067322, 27.61264229], [91.57987976, 27.61336517], [91.57810211, 27.61481094], [91.57691956, 27.61651802], [91.57543945, 27.61831856], [91.57405853, 27.61985016], [91.57256317, 27.6200428], [91.57077789, 27.62122154], [91.56889343, 27.62249184], [91.56661224, 27.62447739], [91.56544495, 27.62716675], [91.56460571, 27.62882614], [91.56319427, 27.63074112], [91.56292725, 27.63264275], [91.56319427, 27.63530922], [91.56327057, 27.6360836], [91.56340027, 27.63746262], [91.56359863, 27.63941193], [91.56443787, 27.64196968], [91.56536865, 27.6427803], [91.56607819, 27.64400482], [91.56716156, 27.64686394], [91.5684967, 27.6484127], [91.5697403, 27.64992905], [91.57062531, 27.65156937], [91.57144928, 27.65336037], [91.57196045, 27.65535736], [91.57250977, 27.6572628], [91.57305145, 27.65868568], [91.57382965, 27.66099167], [91.57467651, 27.66172409], [91.5761795, 27.66206741], [91.57762909, 27.66266823], [91.57906342, 27.66280556], [91.58005524, 27.66289902], [91.58161163, 27.66313934], [91.58335876, 27.66419792], [91.58521271, 27.66494751], [91.5875473, 27.66704941], [91.58862305, 27.66769028], [91.58952332, 27.66823769], [91.59216309, 27.67002106], [91.59394073, 27.67090988], [91.59477234, 27.67254257], [91.59525299, 27.67387199], [91.59590149, 27.67509842], [91.59637451, 27.67678261], [91.59669495, 27.67862892], [91.59770203, 27.68040657], [91.59922791, 27.68139458], [91.60082245, 27.68226814], [91.60269165, 27.6826725], [91.60513306, 27.68413353], [91.60526276, 27.68505669], [91.60612488, 27.68718147], [91.60708618, 27.68910789], [91.60809326, 27.68979836], [91.60960388, 27.69065475], [91.61135101, 27.69161224], [91.61325836, 27.69205284], [91.61586761, 27.69294739], [91.61800385, 27.69333458], [91.61997986, 27.69408226], [91.62177277, 27.69462776], [91.62420654, 27.69547272], [91.62572479, 27.69684219], [91.62763977, 27.69855881], [91.62870026, 27.69932365], [91.62916565, 27.70038414], [91.62960815, 27.70234108], [91.62997437, 27.7038784], [91.62994385, 27.7056694], [91.63026428, 27.7075386], [91.63039398, 27.70923042], [91.63121033, 27.71029282], [91.6315155, 27.71082497], [91.63202667, 27.71144295], [91.63244629, 27.71286583], [91.6330719, 27.71482086], [91.63318634, 27.71835136], [91.63330841, 27.71959877], [91.63412476, 27.72139168], [91.63433838, 27.72292328], [91.63488007, 27.72461128], [91.63566589, 27.72691154], [91.63637543, 27.72849655], [91.63786316, 27.7300415], [91.63871002, 27.73151016], [91.63936615, 27.73314095], [91.63957977, 27.73482513], [91.63941956, 27.7358017], [91.63886261, 27.73719406], [91.63784027, 27.73843765], [91.63705444, 27.73972893], [91.63575745, 27.74154854], [91.63470459, 27.74488831], [91.63536835, 27.74698448], [91.63637543, 27.74902725], [91.63737488, 27.75019646], [91.63911438, 27.75094604], [91.64022827, 27.75190926], [91.64116669, 27.75234795], [91.64150238, 27.75261497], [91.64186096, 27.75312424], [91.64169312, 27.75384331], [91.64212036, 27.75548172], [91.64289856, 27.75711441], [91.64332581, 27.75905991], [91.64393616, 27.76110649], [91.64447021, 27.76239967], [91.64511108, 27.76364708], [91.64555359, 27.76534843], [91.64592743, 27.76744843], [91.64588928, 27.76868057], [91.64554596, 27.76924896], [91.64401245, 27.77054977], [91.64205933, 27.77129173], [91.63991547, 27.77342987], [91.63854218, 27.7754364], [91.63804626, 27.77744293], [91.63758087, 27.77863121], [91.63790894, 27.78050041], [91.63794708, 27.78317451], [91.6386795, 27.78518677], [91.63800812, 27.78688812], [91.63745117, 27.78838158], [91.63752747, 27.78986931], [91.63755035, 27.79151154], [91.63737488, 27.79245567], [91.63708496, 27.79343987], [91.63659668, 27.79424858], [91.63631439, 27.79532242], [91.63603973, 27.79737663], [91.63543701, 27.79969215], [91.63569641, 27.80150032], [91.63540649, 27.80220032], [91.63511658, 27.80291557], [91.63482666, 27.80363274], [91.63433075, 27.80426216], [91.63314056, 27.80534554], [91.63214111, 27.80562401], [91.63095093, 27.80626297], [91.6301651, 27.80725288], [91.62858582, 27.80932045], [91.62770081, 27.81048965], [91.62690735, 27.81156921], [91.62541199, 27.81185341], [91.62501526, 27.81239319], [91.62322235, 27.81339264], [91.62113953, 27.81466484], [91.61924744, 27.81593513], [91.61787415, 27.81791115], [91.61669922, 27.8199749], [91.61490631, 27.8210659], [91.6131134, 27.82206535], [91.61181641, 27.82270432], [91.61062622, 27.82352066], [91.60922241, 27.82371521], [91.60752106, 27.82373428], [91.60540771, 27.82331085], [91.60329437, 27.82288742], [91.60097504, 27.82210922], [91.60005951, 27.8212986], [91.59918976, 27.82063675], [91.59864044, 27.82022095], [91.59741974, 27.81956673], [91.59591675, 27.81868553], [91.59490967, 27.8183403], [91.59290314, 27.81836319], [91.59018707, 27.81821251], [91.58737946, 27.817976], [91.58605194, 27.81647491], [91.58451843, 27.81443977], [91.58229828, 27.8133049], [91.57978821, 27.81306458], [91.5770874, 27.81336021], [91.57665253, 27.81359291], [91.57501221, 27.81447029], [91.57379913, 27.81535721], [91.57250977, 27.81653023], [91.57135773, 27.81743431], [91.57016754, 27.8188343], [91.56891632, 27.82048988], [91.56835175, 27.82141876], [91.56761932, 27.82260704], [91.5668869, 27.82415581], [91.56620789, 27.82516098], [91.56522369, 27.82659721], [91.5644455, 27.82812309], [91.56295776, 27.8294754], [91.56237793, 27.83099747], [91.56199646, 27.83296394], [91.56142426, 27.83493233], [91.5611496, 27.83671951], [91.56096649, 27.83796883], [91.5599823, 27.83958435], [91.55918884, 27.84030724], [91.55860901, 27.84156227], [91.55770874, 27.84183884], [91.55701447, 27.84282684], [91.55574799, 27.84533691], [91.55540466, 27.84827423], [91.55482483, 27.84994507], [91.55541229, 27.85075951], [91.55739594, 27.85233116], [91.55808258, 27.85242844], [91.55941772, 27.85261536], [91.56092834, 27.85316467], [91.56295013, 27.85246086], [91.56305695, 27.85242462], [91.56369019, 27.85236549], [91.56449127, 27.85199738], [91.56580353, 27.85070038], [91.56660461, 27.85033226], [91.56855011, 27.84892654], [91.56952667, 27.84850502], [91.57015991, 27.8485508], [91.57068634, 27.84900665], [91.5712204, 27.84951401], [91.57209778, 27.85073662], [91.57266998, 27.85185242], [91.57294464, 27.85354996], [91.57350922, 27.85511208], [91.57377625, 27.85667229], [91.57433319, 27.85876083], [91.57488251, 27.86037827], [91.57595062, 27.86183548], [91.57674408, 27.86279678], [91.57776642, 27.86310005], [91.57966614, 27.86327553], [91.58264923, 27.86279678], [91.58519745, 27.86120605], [91.58690643, 27.86028099], [91.58815765, 27.8591423], [91.58851624, 27.85869408], [91.58908844, 27.85797691], [91.58985138, 27.85709381], [91.59051514, 27.85664749], [91.59166718, 27.85635376], [91.59244537, 27.85643959], [91.59356689, 27.85624123], [91.59462738, 27.85660362], [91.5956192, 27.85767937], [91.59655762, 27.85877991], [91.59793854, 27.85969353], [91.59815216, 27.85990906], [91.59928131, 27.85930824], [91.6073761, 27.85400009], [91.61492157, 27.85689163], [91.62160492, 27.85769272], [91.62658691, 27.85582924], [91.62725067, 27.85557938], [91.6318512, 27.85505867], [91.63776398, 27.85450935], [91.64185333, 27.85412979], [91.65406036, 27.85706139], [91.66195679, 27.85824013], [91.66932678, 27.85671043], [91.67959595, 27.8441391], [91.68952942, 27.82913971], [91.69412231, 27.8221302], [91.7022171, 27.81682014], [91.70957184, 27.81328964], [91.72115326, 27.81049919], [91.74627686, 27.80335045], [91.75813293, 27.80129814], [91.77112579, 27.80124092], [91.77870178, 27.80306053], [91.78859711, 27.80463982], [91.79907227, 27.80822182], [91.80412292, 27.80888939], [91.81051636, 27.80298996], [91.8152771, 27.80337906], [91.82421112, 27.81035042], [91.82794952, 27.80755043], [91.8289032, 27.79667091], [91.83136749, 27.78895187], [91.83348846, 27.77988815], [91.84519958, 27.77565956], [91.84886932, 27.76824951], [91.85119629, 27.76506042], [91.8529129, 27.75933075], [91.85759735, 27.7422905], [91.86052704, 27.73693275], [91.87043762, 27.73446083], [91.87330627, 27.73047066], [91.8757782, 27.72600937], [91.87864685, 27.7218399], [91.88844299, 27.72424126], [91.90225983, 27.72706985], [91.90281677, 27.72700119], [91.9083786, 27.72631073], [91.91500854, 27.71816063], [91.91876221, 27.71510124], [91.934021, 27.72156906], [91.94506073, 27.7286911], [91.94659424, 27.73217773], [91.94982147, 27.73953056], [91.95558929, 27.75066948], [91.96105957, 27.75097084], [91.96582794, 27.75144005], [91.9728775, 27.75990105], [91.97894287, 27.76473045], [91.9838562, 27.76999092], [91.99497223, 27.76841927], [92.00028992, 27.76746941], [92.01074219, 27.76473045], [92.03777313, 27.75720024], [92.04863739, 27.75699043], [92.05539703, 27.75913048], [92.06762695, 27.76786995], [92.08457184, 27.77977943], [92.09922028, 27.79338074], [92.11995697, 27.81060028], [92.13889313, 27.82446289], [92.15609741, 27.83702087], [92.17088318, 27.84291267], [92.18934631, 27.85205078], [92.20028687, 27.85707283], [92.21039581, 27.85898972], [92.23419189, 27.86264992], [92.23680878, 27.86283875], [92.24627686, 27.86351967], [92.25515747, 27.86216927], [92.26402283, 27.85793114], [92.26737976, 27.85393906], [92.27110291, 27.84464264], [92.27741241, 27.82518959], [92.28469086, 27.80755997], [92.30738831, 27.77923965], [92.31595612, 27.7782402], [92.32892609, 27.78354836], [92.35028076, 27.79066086], [92.36424255, 27.79363823], [92.36962891, 27.79330254], [92.37470245, 27.79367065], [92.37983704, 27.79501915], [92.38295746, 27.81557083], [92.39797974, 27.82047081], [92.40686035, 27.82208824], [92.41385651, 27.82304001], [92.42736816, 27.81200981], [92.44380951, 27.80078125], [92.45493317, 27.80326271], [92.45948792, 27.80758095], [92.46703339, 27.81521988], [92.47672272, 27.82152939], [92.48455811, 27.82863998], [92.49250793, 27.8368206], [92.50132751, 27.84150124], [92.51509094, 27.8402195], [92.52636719, 27.83113098], [92.53447723, 27.82433128], [92.54389954, 27.81747055], [92.55425262, 27.81829834], [92.56069183, 27.82104111], [92.56529999, 27.82735062], [92.57624054, 27.84181023], [92.58574677, 27.85687065], [92.60507202, 27.87750816], [92.62036133, 27.88446808], [92.6315918, 27.88729095], [92.65157318, 27.89297104], [92.66921234, 27.90013123], [92.67415619, 27.90600014], [92.68636322, 27.91948128], [92.7012558, 27.93380928], [92.71385193, 27.94927979], [92.72979736, 27.97192001], [92.73316193, 27.97793007], [92.73948669, 27.9894104], [92.73352051, 27.99570847], [92.72779083, 28.0014801], [92.72208405, 28.01447487], [92.72126007, 28.01634026], [92.70954132, 28.03327942], [92.70246887, 28.04084015], [92.69542694, 28.04837036], [92.68125153, 28.05857849], [92.67964935, 28.0589447], [92.66293335, 28.06277084], [92.66116333, 28.06770134], [92.66725922, 28.07826805], [92.67311859, 28.09670067], [92.67763519, 28.11037445], [92.68016052, 28.11800957], [92.68490601, 28.12342453], [92.68698883, 28.12579918], [92.69415283, 28.12982559], [92.69576263, 28.13072968], [92.70458221, 28.13656807], [92.72090149, 28.14497948], [92.73655701, 28.15155029], [92.737854, 28.15246582], [92.74424744, 28.15697289], [92.7583313, 28.16690063], [92.75953674, 28.16772461], [92.78302765, 28.18374062], [92.79963684, 28.20223045], [92.80754852, 28.20407867], [92.81617737, 28.2016201], [92.81932068, 28.19741058], [92.81768036, 28.18431091], [92.81861877, 28.18159676], [92.82126617, 28.17391968], [92.82646942, 28.17203522], [92.83010101, 28.17295647], [92.83937836, 28.17920494], [92.83960724, 28.17935944], [92.84729004, 28.18282127], [92.8526001, 28.18523216], [92.87275696, 28.19438934], [92.89525604, 28.20461082], [92.90532684, 28.21524048], [92.91294861, 28.23501968], [92.92288971, 28.24258041], [92.92771912, 28.24413872], [92.93347168, 28.24599075], [92.94172668, 28.2486496], [92.95552063, 28.25832939], [92.96452332, 28.2618103], [92.97447205, 28.25962067], [92.98596191, 28.25131035], [92.98686981, 28.24249077], [92.98999023, 28.23442268], [92.99465942, 28.23026085], [93.00035858, 28.23079109], [93.00994873, 28.23987007], [93.02033997, 28.25229836], [93.03378296, 28.26313019], [93.03289032, 28.26683044], [93.02565765, 28.28664017], [93.02393341, 28.29276657], [93.02262115, 28.29740524], [93.02191162, 28.29993057], [93.02366638, 28.30319977], [93.02497864, 28.30327606], [93.03224182, 28.30369949], [93.04592133, 28.30249977], [93.04624939, 28.30247116], [93.06167603, 28.30693054], [93.06266022, 28.30715179], [93.06916809, 28.30861473], [93.07203674, 28.30925941], [93.08711243, 28.30622101], [93.09535217, 28.30707932], [93.11068726, 28.31479073], [93.11213684, 28.31552124], [93.12478638, 28.32679939], [93.12906647, 28.3264904], [93.13646698, 28.32489014], [93.15496826, 28.31848145], [93.17978668, 28.31721115], [93.1937561, 28.31804085], [93.20693207, 28.3232708], [93.21897888, 28.3337307], [93.21988678, 28.33551025], [93.22145844, 28.33856964], [93.22274017, 28.34106827], [93.22029877, 28.35548973], [93.21927643, 28.36149979], [93.22225952, 28.37794113], [93.23152161, 28.40071106], [93.22586823, 28.4083004], [93.21605682, 28.41366959], [93.20461273, 28.4192791], [93.19036865, 28.42601967], [93.18106842, 28.43274117], [93.18266296, 28.439991], [93.19033813, 28.44415092], [93.20088196, 28.44899178], [93.20754242, 28.45222855], [93.21357727, 28.45816994], [93.22245026, 28.47027969], [93.22905731, 28.47795105], [93.23530579, 28.48273087], [93.23638916, 28.48324203], [93.25395966, 28.49155045], [93.26286316, 28.49690056], [93.26963043, 28.50114059], [93.27591705, 28.50482941], [93.27934265, 28.51379013], [93.28164673, 28.5212307], [93.28890991, 28.54341125], [93.29743958, 28.55758858], [93.30526733, 28.56625938], [93.3033371, 28.57687187], [93.29753876, 28.59202957], [93.29987335, 28.59955025], [93.30639648, 28.60098267], [93.31137085, 28.60375023], [93.31958008, 28.60700989], [93.32763672, 28.60828972], [93.32987976, 28.6156311], [93.33096313, 28.62347984], [93.33230591, 28.63368034], [93.33550262, 28.63817978], [93.33690643, 28.64015961], [93.34191895, 28.64011955], [93.3508606, 28.63889122], [93.36177063, 28.64082909], [93.36971283, 28.64454079], [93.38967896, 28.64946938], [93.39539337, 28.65035629], [93.40518188, 28.65187073], [93.41184235, 28.6529007], [93.42980194, 28.66230965], [93.43714142, 28.66913414], [93.43746948, 28.66943932], [93.44132996, 28.67255974], [93.44567108, 28.67604065], [93.45674896, 28.66842079], [93.46256256, 28.65703011], [93.46675873, 28.65212059], [93.47419739, 28.65365028], [93.47550201, 28.66230965], [93.47917938, 28.67498016], [93.4835968, 28.68009186], [93.48556519, 28.68110275], [93.49111938, 28.68396187], [93.49550629, 28.6840229], [93.50086975, 28.68209267], [93.50920868, 28.67984009], [93.51199341, 28.67802811], [93.51843262, 28.67383003], [93.51893616, 28.67149544], [93.52020264, 28.66564178], [93.52446747, 28.66127968], [93.53383636, 28.65884972], [93.56127167, 28.65961075], [93.606987, 28.65587807], [93.62008667, 28.6577301], [93.63487244, 28.66102028], [93.63887024, 28.6619091], [93.65364075, 28.6668396], [93.66942596, 28.67196083], [93.68551636, 28.67934036], [93.699646, 28.67992973], [93.71382141, 28.68386078], [93.72502899, 28.68821907], [93.73156738, 28.68927956], [93.74364471, 28.68462753], [93.74732971, 28.68321037], [93.76127625, 28.67460823], [93.77171326, 28.67003632], [93.775177, 28.66851807], [93.78528595, 28.67140961], [93.79736328, 28.68027115], [93.81878662, 28.69489098], [93.83555603, 28.70452118], [93.84403992, 28.70738983], [93.84966278, 28.7069912], [93.85787201, 28.70580292], [93.86527252, 28.70371246], [93.90412903, 28.67666054], [93.91960144, 28.67037964], [93.9261322, 28.67180061], [93.93456268, 28.67709923], [93.94352722, 28.68917084], [93.95697021, 28.70467949], [93.960289, 28.71306038], [93.96253967, 28.71871185], [93.96555328, 28.7232399], [93.96511078, 28.74299049], [93.96850586, 28.75138283], [93.97763062, 28.75930023], [93.99035645, 28.76563072], [93.99809265, 28.77164078], [94.0014267, 28.7755394], [94.00163269, 28.78428078], [93.99841309, 28.78804016], [93.98526764, 28.79829025], [93.98557281, 28.80677032], [93.98680115, 28.80787849], [93.99997711, 28.81977081], [93.9980011, 28.83111954], [93.99491119, 28.84136963], [94.00285339, 28.8470211], [94.01480865, 28.85118103], [94.01792145, 28.85164261], [94.03006744, 28.85345078], [94.03420258, 28.86096191], [94.04399872, 28.8738308], [94.0569458, 28.88642883], [94.0581131, 28.88755989], [94.06653595, 28.89608955], [94.07884216, 28.90582085], [94.09416199, 28.91513062], [94.12046814, 28.93028069], [94.13648987, 28.94039154], [94.15513611, 28.95476151], [94.15692139, 28.95936966], [94.15831757, 28.97406006], [94.16677094, 28.98116112], [94.17294312, 28.99182129], [94.17177582, 29.00316811], [94.17192841, 29.00700188], [94.17195892, 29.00776291], [94.17520905, 29.02049065], [94.17945862, 29.0285511], [94.18498993, 29.03912163], [94.19198608, 29.04879951], [94.1989975, 29.06010818], [94.2057724, 29.0693512], [94.21469116, 29.08408928], [94.22471619, 29.09000969], [94.233078, 29.09628105], [94.23806, 29.10045815], [94.2457962, 29.10798073], [94.2576828, 29.11679077], [94.26889038, 29.1271286], [94.27755737, 29.13539124], [94.28772736, 29.14814949], [94.29235077, 29.14962006], [94.2975769, 29.15055084], [94.30745697, 29.15088081], [94.31155396, 29.15059853], [94.31846619, 29.15011978], [94.33132935, 29.15028954], [94.35016632, 29.15020943], [94.35692596, 29.1525898], [94.35778046, 29.15317345], [94.35824585, 29.15349197], [94.36370087, 29.15722084], [94.36763, 29.16633987], [94.37008667, 29.18176079], [94.37227631, 29.19022942], [94.37684631, 29.19450188], [94.39707947, 29.20383072], [94.3995285, 29.20496941], [94.41387939, 29.21269035], [94.4257431, 29.22356033], [94.43118286, 29.2268219], [94.4338913, 29.2264595], [94.44146729, 29.22543907], [94.45465851, 29.22397041], [94.46694946, 29.22167969], [94.47006989, 29.2209034], [94.47869873, 29.21875954], [94.49446106, 29.2166729], [94.5, 29.21682167], [94.50297546, 29.21690178], [94.51400757, 29.21720123], [94.5330658, 29.21871948], [94.54580688, 29.22327042], [94.55789948, 29.22891045], [94.55995178, 29.23148346], [94.56739807, 29.24082947], [94.57208252, 29.2505703], [94.57264709, 29.25649071], [94.57344818, 29.26490021], [94.57389069, 29.27517128], [94.57775879, 29.28076935], [94.58383179, 29.28269005], [94.58895874, 29.28630066], [94.59388733, 29.2898407], [94.60536957, 29.29698944], [94.61071014, 29.30116272], [94.6190033, 29.31279945], [94.62108612, 29.32253075], [94.623703, 29.33677101], [94.62354279, 29.34559059], [94.62815857, 29.34859085], [94.6414566, 29.34692001], [94.64955139, 29.34192276], [94.66597748, 29.33177948], [94.67724609, 29.32784081], [94.68158722, 29.32380104], [94.69095612, 29.31671143], [94.69461823, 29.31394005], [94.70445251, 29.3077507], [94.71105194, 29.30434036], [94.71586609, 29.30013275], [94.73070526, 29.28716087], [94.7366333, 29.28198051], [94.74822235, 29.26625824], [94.7665329, 29.25279045], [94.7773819, 29.24111938], [94.78276825, 29.23319054], [94.79084015, 29.22619057], [94.79538727, 29.21873093], [94.79789734, 29.20998955], [94.79653168, 29.19549942], [94.79286957, 29.18036079], [94.79292297, 29.16974068], [94.79798889, 29.16460991], [94.80948639, 29.1667099], [94.82028961, 29.17095947], [94.83261871, 29.17674255], [94.84026337, 29.18016052], [94.84658813, 29.18299103], [94.85244751, 29.18371964], [94.87180328, 29.18428993], [94.88115692, 29.1817894], [94.89263153, 29.17604065], [94.90695953, 29.16652107], [94.91880035, 29.16230011], [94.92682648, 29.16275978], [94.93824005, 29.16097832], [94.93939972, 29.16094208], [94.95688629, 29.16037178], [94.96768951, 29.15975189], [94.97097778, 29.15624046], [94.9815979, 29.14995003], [94.98654938, 29.14670944], [94.99510193, 29.14096069], [95.00498199, 29.13574982], [95.0111618, 29.13340759], [95.02279663, 29.13062096], [95.02567291, 29.1335907], [95.01822662, 29.14295959], [95.01040649, 29.15185928], [95.00421906, 29.15771103], [94.99195862, 29.16581917], [94.98668671, 29.17353821], [94.99749756, 29.17301178], [95.00491333, 29.1704998], [95.01088715, 29.16707993], [95.0202713, 29.16114998], [95.02339172, 29.15980148], [95.02922821, 29.15727997], [95.03974152, 29.15242195], [95.05368042, 29.15018463], [95.05433655, 29.15007973], [95.06555939, 29.14793015], [95.07810974, 29.14560127], [95.09211731, 29.14435768], [95.0983963, 29.14380074], [95.10251617, 29.14010811], [95.10888672, 29.12902069], [95.11353302, 29.12120056], [95.12175751, 29.11625099], [95.14592743, 29.11561012], [95.15487671, 29.11334991], [95.17752075, 29.10857964], [95.19664764, 29.10758018], [95.20289612, 29.10785675], [95.21362305, 29.10833359], [95.21671295, 29.10847092], [95.24047852, 29.11071014], [95.25076294, 29.10988045], [95.24785614, 29.09377289], [95.25137329, 29.08573914], [95.25057983, 29.08135796], [95.24971008, 29.07658005], [95.25010681, 29.06857109], [95.25750732, 29.06197929], [95.26655579, 29.05764961], [95.27237701, 29.05861282], [95.27787781, 29.05953026], [95.28618622, 29.06221962], [95.29750061, 29.06319046], [95.30274963, 29.06291962], [95.30870819, 29.05931091], [95.31826782, 29.05507088], [95.33112335, 29.05145073], [95.3454895, 29.04611015], [95.37387085, 29.04129028], [95.38463593, 29.03804016], [95.39996338, 29.03540039], [95.41013336, 29.03412056], [95.41651154, 29.03816032], [95.42154694, 29.04121017], [95.42935944, 29.04128075], [95.43871307, 29.03720284], [95.44742584, 29.03601265], [95.45433807, 29.03699112], [95.45926666, 29.04310036], [95.46485901, 29.05461121], [95.47020721, 29.06089973], [95.47402954, 29.06592941], [95.48298645, 29.07113075], [95.48589325, 29.07625008], [95.48908997, 29.08974075], [95.4919281, 29.10918045], [95.49186707, 29.12368011], [95.49498749, 29.13529968], [95.49633026, 29.14031029], [95.50353241, 29.14299011], [95.51381683, 29.13891983], [95.52778625, 29.13474274], [95.53827667, 29.13056946], [95.54680634, 29.12865067], [95.54656219, 29.14575005], [95.54708099, 29.15133286], [95.54679871, 29.15871048], [95.5463028, 29.16806984], [95.5453186, 29.18058014], [95.54505157, 29.18175125], [95.54155731, 29.19697952], [95.53717804, 29.20824242], [95.53771973, 29.2140007], [95.54502869, 29.21558952], [95.56035614, 29.21653175], [95.57971954, 29.21737289], [95.58580017, 29.21799278], [95.58560944, 29.22816086], [95.58763123, 29.24237251], [95.59303284, 29.2542305], [95.59873199, 29.2618618], [95.60510254, 29.26247025], [95.62062073, 29.25494957], [95.63121796, 29.24904823], [95.63802338, 29.24983978], [95.6428833, 29.25602913], [95.65228271, 29.26049042], [95.66023254, 29.26522827], [95.67323303, 29.27109909], [95.68315125, 29.27728081], [95.69225311, 29.28652191], [95.69734192, 29.29458809], [95.70189667, 29.30042076], [95.70633698, 29.30068016], [95.71517181, 29.29829979], [95.72705078, 29.30246925], [95.74349976, 29.31624985], [95.7454071, 29.32912064], [95.76509857, 29.34459114], [95.77294922, 29.35184097], [95.77762604, 29.35639954], [95.78309631, 29.35638046], [95.78695679, 29.34736061], [95.79102325, 29.33789825], [95.7964859, 29.33633041], [95.80256653, 29.33937263], [95.80349731, 29.34007454], [95.81008148, 29.34506989], [95.81925201, 29.35205078], [95.82681274, 29.35571098], [95.84030151, 29.3537426], [95.84825897, 29.35865974], [95.85894012, 29.36750984], [95.87523651, 29.38558006], [95.88085175, 29.39149094], [95.88931274, 29.39136124], [95.8992691, 29.38975334], [95.90959167, 29.38809013], [95.93537903, 29.38425064], [95.95710754, 29.38266754], [95.96589661, 29.38739014], [95.97796631, 29.40044975], [95.98719025, 29.4068718], [95.99318695, 29.41044044], [96.00248718, 29.41207123], [96.01452637, 29.42135048], [96.02555084, 29.43342972], [96.03472137, 29.44298935], [96.04406738, 29.45046997], [96.05560303, 29.45841026], [96.06945038, 29.46227264], [96.08053589, 29.46334457], [96.08718872, 29.46161079], [96.09281921, 29.45643044], [96.10118103, 29.44531059], [96.11319733, 29.42750931], [96.12394714, 29.41761971], [96.13923645, 29.40779114], [96.14998627, 29.39925957], [96.15777588, 29.38310051], [96.1638031, 29.37668037], [96.17524719, 29.36453056], [96.18032074, 29.35550117], [96.18578339, 29.34448051], [96.185112, 29.33909988], [96.18308258, 29.30925179], [96.18840027, 29.30463028], [96.19719696, 29.29810333], [96.20323944, 29.29361916], [96.20754242, 29.28177071], [96.21005249, 29.27486038], [96.22619629, 29.25980949], [96.23416901, 29.2434597], [96.24356842, 29.23512268], [96.25083923, 29.23323822], [96.26571655, 29.23655128], [96.26613617, 29.23652077], [96.28279877, 29.23533058], [96.29299927, 29.23578835], [96.29347229, 29.23634911], [96.31260681, 29.25909996], [96.32015991, 29.26165009], [96.34533691, 29.26735115], [96.35074615, 29.27189064], [96.35838318, 29.28154182], [96.36315155, 29.28563118], [96.36902618, 29.28630066], [96.37497711, 29.28372955], [96.37548828, 29.2831974], [96.37576294, 29.28291702], [96.38208771, 29.27638054], [96.38754272, 29.26382065], [96.39280701, 29.25650024], [96.39176941, 29.24617195], [96.38867188, 29.23665237], [96.38771057, 29.23371124], [96.38021088, 29.22657967], [96.37136841, 29.21803093], [96.36935425, 29.21379852], [96.36633301, 29.2074604], [96.36302948, 29.1984005], [96.35849762, 29.18162918], [96.34635925, 29.17103004], [96.33255768, 29.16953087], [96.31004333, 29.1685009], [96.30764008, 29.16839027], [96.30641174, 29.16794014], [96.29058075, 29.16214752], [96.27246094, 29.16068077], [96.26670074, 29.16109085], [96.2602005, 29.16016006], [96.25551605, 29.15417099], [96.24890137, 29.15017128], [96.23877716, 29.14848709], [96.23808289, 29.14837074], [96.22776031, 29.14637947], [96.21749878, 29.13809967], [96.21508789, 29.13325119], [96.20868683, 29.12071037], [96.20503235, 29.11444092], [96.20033264, 29.10593033], [96.18562317, 29.09461975], [96.17980957, 29.09210014], [96.16950226, 29.08763123], [96.16316986, 29.08673859], [96.15554047, 29.08566093], [96.12420654, 29.0806694], [96.11450195, 29.07760239], [96.13671112, 29.06447029], [96.15039063, 29.05314064], [96.1608429, 29.03651047], [96.16520691, 29.02010918], [96.16883087, 29.01288033], [96.1756134, 29.00346947], [96.18022919, 28.99941063], [96.1848526, 28.98811913], [96.18454742, 28.97777939], [96.18044281, 28.96854019], [96.16220093, 28.95968056], [96.15516663, 28.95560265], [96.15406036, 28.94651031], [96.15033722, 28.94313049], [96.14524841, 28.93748856], [96.1553421, 28.92832947], [96.16297913, 28.92206001], [96.16557312, 28.91403961], [96.16652679, 28.90592957], [96.17472839, 28.90426064], [96.18599701, 28.91201019], [96.20465088, 28.91916084], [96.21546936, 28.92329979], [96.22814941, 28.92933083], [96.24829865, 28.94284058], [96.25565338, 28.9592514], [96.26065063, 28.96513939], [96.26819611, 28.97129059], [96.28186798, 28.98369026], [96.28659058, 28.99201965], [96.29370117, 28.99872971], [96.3010788, 29.00224113], [96.30912781, 29.00559044], [96.31411743, 29.00847816], [96.3215332, 29.0127697], [96.3372879, 29.02452087], [96.34139252, 29.0279007], [96.34670258, 29.03226852], [96.35740662, 29.03424072], [96.36873627, 29.03495026], [96.38896179, 29.03414154], [96.40441132, 29.03536034], [96.42086792, 29.03700066], [96.43579102, 29.03758812], [96.43855286, 29.03852081], [96.44979858, 29.04231071], [96.45001221, 29.04239273], [96.45889282, 29.04582977], [96.46492767, 29.05226707], [96.46658325, 29.05402756], [96.46943665, 29.05567741], [96.47715759, 29.06014061], [96.4798584, 29.061203], [96.49163055, 29.06583977], [96.50031281, 29.07090187], [96.50815582, 29.07377815], [96.51862335, 29.07845116], [96.52519989, 29.07928085], [96.51169586, 29.0526104], [96.50540924, 29.0418911], [96.4988327, 29.03133011], [96.49281311, 29.02033043], [96.4885788, 29.01048088], [96.48425293, 29.00534248], [96.47740173, 28.99403954], [96.48116302, 28.98230934], [96.48138428, 28.98161316], [96.48153687, 28.98113823], [96.48432922, 28.97284126], [96.48752594, 28.96533966], [96.49324799, 28.96232033], [96.4936676, 28.96239662], [96.50076294, 28.9636898], [96.51335907, 28.97031975], [96.51882935, 28.97098923], [96.52121735, 28.96520996], [96.52263641, 28.95548058], [96.52366638, 28.94800949], [96.53029633, 28.93696976], [96.53547668, 28.93000031], [96.53792572, 28.9231987], [96.53872681, 28.92098236], [96.53687286, 28.90966034], [96.53607941, 28.89717102], [96.5374527, 28.88412094], [96.54225922, 28.87920952], [96.54686737, 28.87450027], [96.55265045, 28.86408997], [96.55319977, 28.86310005], [96.55381775, 28.86242485], [96.55976868, 28.85593033], [96.56285858, 28.84799004], [96.56697845, 28.84192085], [96.57585907, 28.83049011], [96.58425903, 28.82151985], [96.59514618, 28.81520081], [96.60383606, 28.80442047], [96.60838318, 28.79807091], [96.61123657, 28.79004097], [96.61599731, 28.77857971], [96.61551666, 28.7648201], [96.61361694, 28.75979805], [96.60943604, 28.75338173], [96.59815979, 28.73801994], [96.5859375, 28.72158813], [96.57232666, 28.71471024], [96.56001282, 28.71186256], [96.53222656, 28.71149826], [96.52720642, 28.71021843], [96.52236938, 28.70898056], [96.50802612, 28.70112038], [96.49841309, 28.69256973], [96.49057007, 28.68849754], [96.48432159, 28.68829918], [96.47274017, 28.68820953], [96.47054291, 28.68455124], [96.47425079, 28.68031311], [96.47499084, 28.67947006], [96.47840118, 28.67287827], [96.4839325, 28.66526031], [96.48681641, 28.65876961], [96.4911499, 28.6507225], [96.49159241, 28.64994812], [96.49516296, 28.64376068], [96.4940567, 28.63819122], [96.48423004, 28.6315403], [96.47289276, 28.62247276], [96.45825958, 28.61387062], [96.44444275, 28.60598946], [96.4393692, 28.600811], [96.43502808, 28.59699059], [96.42807007, 28.58714104], [96.42250061, 28.5850296], [96.41507721, 28.5884304], [96.40735626, 28.59443283], [96.40091705, 28.59431076], [96.39994049, 28.59044075], [96.40615082, 28.5778904], [96.40670013, 28.57150078], [96.40660858, 28.56404114], [96.40077209, 28.5623703], [96.39421844, 28.56269836], [96.3863678, 28.56365967], [96.3707962, 28.56415176], [96.36797333, 28.56353188], [96.35460663, 28.56059074], [96.34324646, 28.55105972], [96.33481598, 28.53853035], [96.32567596, 28.53400993], [96.32430267, 28.53034019], [96.33113861, 28.52659988], [96.33220673, 28.52607346], [96.34210205, 28.52120018], [96.35299683, 28.51490021], [96.36091614, 28.50972939], [96.36660767, 28.50472832], [96.37171173, 28.49677086], [96.37296295, 28.48703957], [96.36965942, 28.48290634], [96.36695862, 28.47953033], [96.34136963, 28.47002029], [96.33506012, 28.46278], [96.32386017, 28.45504951], [96.30963898, 28.44569969], [96.29712677, 28.43914032], [96.28476715, 28.43077087], [96.27448273, 28.42401123], [96.26596069, 28.41704941], [96.26377106, 28.41337967], [96.26740265, 28.41020966], [96.27291107, 28.40944862], [96.2769928, 28.40888023], [96.28782654, 28.40870857], [96.299263, 28.40665054], [96.30464172, 28.40472031], [96.30809784, 28.40035248], [96.31030273, 28.39756966], [96.31532288, 28.3884201], [96.31987762, 28.3861599], [96.330513, 28.38777924], [96.36184692, 28.39375114], [96.37094116, 28.39430046], [96.37484741, 28.38726997], [96.38001251, 28.36409187], [96.39215088, 28.36264992], [96.39940643, 28.34449959], [96.4127121, 28.34673119], [96.42285919, 28.35097122], [96.42698669, 28.36343002], [96.4287262, 28.37251091], [96.42993164, 28.38105011], [96.4305191, 28.38609123], [96.43199921, 28.39173126], [96.43914795, 28.40102959], [96.44698334, 28.40717125], [96.4538269, 28.41564941], [96.45826721, 28.41922188], [96.46972656, 28.4228096], [96.4799881, 28.42461014], [96.49672699, 28.42355919], [96.50628662, 28.42006111], [96.51026154, 28.41830826], [96.5201416, 28.42333984], [96.53385925, 28.43464088], [96.5511322, 28.4422226], [96.55953217, 28.45302963], [96.57958984, 28.4630928], [96.59866333, 28.46623039], [96.62142181, 28.46440125], [96.63918304, 28.4641304], [96.66008759, 28.46635056], [96.66456604, 28.46577072], [96.67539978, 28.45676041], [96.68144989, 28.45120239], [96.68734741, 28.44828033], [96.70619965, 28.43746948], [96.71687317, 28.43294907], [96.7339859, 28.43078995], [96.73996735, 28.42723274], [96.75105286, 28.42171288], [96.75749207, 28.41543007], [96.76316071, 28.40421867], [96.76732635, 28.38969994], [96.77068329, 28.38076019], [96.77437592, 28.37407112], [96.78257751, 28.37038994], [96.79708862, 28.37050056], [96.81156921, 28.36810112], [96.82647705, 28.36720276], [96.85221863, 28.36836052], [96.86248779, 28.37830925], [96.86956787, 28.3808403], [96.88001251, 28.38278961], [96.89395142, 28.38614082], [96.89866638, 28.3859005], [96.90419006, 28.37990952], [96.91028595, 28.37140083], [96.91996002, 28.36334991], [96.91977692, 28.3592205], [96.92089844, 28.35218811], [96.92590332, 28.34502983], [96.94229126, 28.34206009], [96.95276642, 28.33995056], [96.96193695, 28.33202934], [96.97406006, 28.32369041], [96.97973633, 28.32228088], [96.98699188, 28.32219124], [96.99649811, 28.31623077], [97.00428772, 28.31838036], [97.02268982, 28.32625961], [97.02715302, 28.33006096], [97.03636932, 28.33867264], [97.04135132, 28.34921074], [97.04532623, 28.35411072], [97.05181885, 28.35806847], [97.06111145, 28.35832024], [97.06613159, 28.35951042], [97.07929993, 28.36508942], [97.09256744, 28.36969185], [97.0949173, 28.36877251], [97.09825134, 28.36747169], [97.10418701, 28.3629818], [97.11279297, 28.35890961], [97.12095642, 28.35798836], [97.12593842, 28.35622025], [97.12980652, 28.35140991], [97.13899231, 28.34436989], [97.1519928, 28.33403015], [97.15880585, 28.32694054], [97.16536713, 28.31301117], [97.16937256, 28.30225182], [97.17391968, 28.29906082], [97.1780014, 28.29730034], [97.1830368, 28.29632187], [97.19259644, 28.29440117], [97.2027359, 28.29560089], [97.2140274, 28.29905128], [97.22424316, 28.29989052], [97.22801971, 28.29445267], [97.23419189, 28.28079033], [97.24124146, 28.27513123], [97.25443268, 28.27646828], [97.26812744, 28.27826118], [97.28206635, 28.27626038], [97.29257202, 28.27063942], [97.30632782, 28.26396751], [97.30766296, 28.25810051], [97.31304169, 28.25183105], [97.32202911, 28.25188065], [97.32737732, 28.25082016], [97.33377075, 28.24777985], [97.34171295, 28.24217033], [97.34950256, 28.23581314], [97.35135651, 28.23430061], [97.35688782, 28.23320007], [97.36499023, 28.23159027], [97.37465668, 28.2256012], [97.37700653, 28.22341919], [97.38124847, 28.21946907], [97.38967896, 28.21236038], [97.4005661, 28.20050049], [97.40042114, 28.19351006], [97.39222717, 28.19120026], [97.38719177, 28.19450951], [97.38223267, 28.19655037], [97.37201691, 28.2003994], [97.36357117, 28.19646835], [97.36177826, 28.1931591], [97.35923004, 28.18844986], [97.35183716, 28.18153954], [97.34127045, 28.17225075], [97.33080292, 28.1629715], [97.32705688, 28.15431023], [97.3246994, 28.1482296], [97.32670593, 28.14163971], [97.33170319, 28.13572121], [97.33495331, 28.13126945], [97.33507538, 28.13110542], [97.34002686, 28.12454987], [97.33901215, 28.11954117], [97.3272171, 28.10946083], [97.31748199, 28.10099602], [97.31694031, 28.10051918], [97.31021118, 28.09325027], [97.3081131, 28.08572769], [97.30774689, 28.07710075], [97.31179047, 28.0699501], [97.31886292, 28.06706047], [97.33167267, 28.06536293], [97.34532928, 28.06659126], [97.34980011, 28.0669899], [97.35675812, 28.06760979], [97.36604309, 28.06809807], [97.3735199, 28.07023811], [97.37399292, 28.06259155], [97.3718338, 28.0589447], [97.36797333, 28.0524292], [97.37706757, 28.03909111], [97.38218689, 28.04018974], [97.38976288, 28.03738976], [97.3985672, 28.03411102], [97.40561676, 28.03004837], [97.41156006, 28.02727127], [97.41516113, 28.02408028], [97.41394806, 28.01923943], [97.41162872, 28.01514053], [97.40222168, 28.01301956], [97.40142822, 28.01294136], [97.39121246, 28.01193047], [97.38883972, 28.00620079], [97.38330841, 27.99367142], [97.38276672, 27.99245071], [97.37806702, 27.98615074], [97.37815094, 27.98179054], [97.3782196, 27.97850037], [97.37854004, 27.96321106], [97.37561798, 27.94438934], [97.3826828, 27.93610954], [97.38765717, 27.93073082], [97.38768768, 27.9265995], [97.381073, 27.92111969], [97.37856293, 27.91801071], [97.37979126, 27.91258812], [97.38755035, 27.9036808], [97.38902283, 27.89637947], [97.378479, 27.89311028], [97.37135315, 27.88693047], [97.3647995, 27.88512993], [97.3500061, 27.89133835], [97.34352112, 27.89406013], [97.33557892, 27.8931694], [97.32116699, 27.88951111], [97.32285309, 27.90341949], [97.32393646, 27.91185951], [97.32216644, 27.91620064], [97.31474304, 27.92519188], [97.30870819, 27.92996025], [97.30174255, 27.92708015], [97.28810883, 27.92177963], [97.28074646, 27.91954994], [97.25647736, 27.90953064], [97.24720001, 27.90390968], [97.24124146, 27.89545059], [97.23677063, 27.88993835], [97.22647095, 27.88216019], [97.22049713, 27.87738991], [97.21244049, 27.87199974], [97.20256042, 27.86440277], [97.19560242, 27.85639954], [97.19543457, 27.8562355], [97.19361115, 27.85520172], [97.19185638, 27.85275078], [97.18949127, 27.85045052], [97.18791962, 27.84760094], [97.1869812, 27.84589958], [97.18183136, 27.8417511], [97.18052673, 27.84116173], [97.17444611, 27.83842278], [97.16780853, 27.83625984], [97.16867828, 27.83086014], [97.16397095, 27.82677078], [97.16287994, 27.82460785], [97.16034698, 27.82259178], [97.15225983, 27.81920052], [97.14428711, 27.81696129], [97.13735199, 27.81506157], [97.13394165, 27.80647087], [97.12787628, 27.80107117], [97.12428284, 27.79850006], [97.11489105, 27.79593277], [97.10246277, 27.79342079], [97.0983963, 27.7885704], [97.09963989, 27.78440475], [97.10011292, 27.78280258], [97.10476685, 27.77518845], [97.10119629, 27.76723099], [97.09807587, 27.75728035], [97.09642029, 27.74992943], [97.09142303, 27.74846077], [97.08628082, 27.75041008], [97.08235168, 27.75189972], [97.06754303, 27.75972176], [97.06201172, 27.7574501], [97.0565567, 27.75202942], [97.04808044, 27.74933815], [97.03736115, 27.75216103], [97.02857208, 27.74912071], [97.01574707, 27.7406311], [97.01322174, 27.7353611], [97.01032257, 27.72550011], [97.00550079, 27.71549034], [97.00322723, 27.7104702], [97.00145721, 27.70820045], [96.99720764, 27.70273972], [96.9888382, 27.69689941], [96.98484802, 27.69099045], [96.9825592, 27.67976952], [96.978302, 27.67187309], [96.9776001, 27.67192268], [96.95865631, 27.67428017], [96.94876862, 27.67142868], [96.94232178, 27.66744995], [96.93887329, 27.6607399], [96.93522644, 27.65983963], [96.92896271, 27.65603256], [96.92700958, 27.64190102], [96.92556763, 27.64020157], [96.92030334, 27.63267136], [96.91944885, 27.63145065], [96.91308594, 27.62748909], [96.91208649, 27.6272316], [96.90058136, 27.62426949], [96.89758301, 27.62080193], [96.89778137, 27.61814117], [96.89910126, 27.60045815], [96.89922333, 27.59362984], [96.90299988, 27.58989906], [96.9101181, 27.58992195], [96.91403198, 27.5884304], [96.91409302, 27.58439255], [96.91324615, 27.57630157], [96.91422272, 27.56729126], [96.91542816, 27.5604496], [96.91580963, 27.55828285], [96.92034912, 27.55562019], [96.92453766, 27.55125999], [96.9286499, 27.54231071], [96.93363953, 27.53722], [96.93768311, 27.53005981], [96.93638611, 27.52325058], [96.9335022, 27.51571083], [96.93081665, 27.51188087], [96.92572021, 27.50304031], [96.92185974, 27.49936676], [96.92076874, 27.49722099], [96.91385651, 27.48841286], [96.91365051, 27.48786926], [96.91121674, 27.48152161], [96.91081238, 27.47459984], [96.91092682, 27.46801949], [96.91184998, 27.46270943], [96.91755676, 27.4588604], [96.92592621, 27.45644951], [96.93334198, 27.45051193], [96.93702698, 27.43959045], [96.94139099, 27.42695045], [96.94889069, 27.4209404], [96.96552277, 27.4153595], [96.96893311, 27.40182114], [96.97554016, 27.39600182], [96.9690094, 27.38627052], [96.97174072, 27.37895012], [96.97696686, 27.37675095], [96.98197937, 27.37371063], [96.98504639, 27.36260986], [96.9895401, 27.35852051], [96.99746704, 27.35510063], [96.99842834, 27.35086823], [97.00026703, 27.3399601], [97.00334167, 27.3299408], [97.009552, 27.32564926], [97.01686859, 27.3200798], [97.04032898, 27.30785942], [97.04358673, 27.28975105], [97.05164337, 27.28650284], [97.05667114, 27.28564072], [97.05885315, 27.27679825], [97.06331635, 27.27224922], [97.06851196, 27.2675209], [97.07366943, 27.26188087], [97.08184052, 27.2538681], [97.08937073, 27.25082016], [97.09407806, 27.24789047], [97.09597015, 27.24121094], [97.09514618, 27.22142982], [97.10050201, 27.21497917], [97.10804749, 27.21310043], [97.11669922, 27.20922089], [97.12023926, 27.20458984], [97.12390137, 27.19987106], [97.12568665, 27.19238853], [97.12729645, 27.18517113], [97.1335907, 27.1809597], [97.14031219, 27.17746925], [97.1499176, 27.17834091], [97.15289307, 27.16841125], [97.15599823, 27.16217995], [97.16720581, 27.15547943], [97.17215729, 27.14435959], [97.17173767, 27.1368103], [97.16625214, 27.13256073], [97.16590118, 27.13229179], [97.15590668, 27.12638092], [97.15236664, 27.11967087], [97.15011597, 27.11152077], [97.14693451, 27.10403252], [97.14643097, 27.10284042], [97.13994598, 27.10128975], [97.13098907, 27.10374069], [97.12233734, 27.11202049], [97.11469269, 27.11993027], [97.10855865, 27.12125969], [97.09921265, 27.11857033], [97.08925629, 27.1138401], [97.08428192, 27.11194992], [97.07910156, 27.10997963], [97.07151794, 27.10917091], [97.0630188, 27.11108208], [97.06268311, 27.11116028], [97.05889893, 27.11407089], [97.05258179, 27.11893082], [97.0479126, 27.12374115], [97.04553986, 27.12681961], [97.04199982, 27.13126945], [97.03501129, 27.13710976], [97.03022003, 27.1417408], [97.02099609, 27.14545059], [97.01315308, 27.1468811], [97.00681305, 27.14982986], [96.99900055, 27.15394974], [96.99256134, 27.16122055], [96.98465729, 27.1667099], [96.97351074, 27.17105293], [96.96372986, 27.17259026], [96.95526123, 27.17368126], [96.94467926, 27.17405128], [96.92801666, 27.17513275], [96.91841125, 27.17548943], [96.90273285, 27.1807785], [96.89689636, 27.18336105], [96.88297272, 27.19051933], [96.87563324, 27.19355965], [96.8662262, 27.19968987], [96.8640213, 27.20690155], [96.8635788, 27.21220016], [96.8633728, 27.21924019], [96.86625671, 27.22361946], [96.87409973, 27.22669029], [96.88031769, 27.23077011], [96.8852005, 27.23259926], [96.89000702, 27.23686981], [96.8914032, 27.24090958], [96.89269257, 27.24763107], [96.88703918, 27.25473022], [96.88790894, 27.25938988], [96.88877869, 27.2635994], [96.88510132, 27.26795959], [96.87507629, 27.26716042], [96.8662262, 27.2690506], [96.86171722, 27.27251053], [96.85566711, 27.28030968], [96.85378265, 27.29067039], [96.85177612, 27.30041122], [96.8497467, 27.30628014], [96.83625793, 27.31054115], [96.83125305, 27.31464005], [96.82486725, 27.32047081], [96.82160187, 27.32444954], [96.81710052, 27.32954025], [96.8127594, 27.33641815], [96.8086319, 27.34492111], [96.80584717, 27.35042953], [96.80236053, 27.35443115], [96.79483032, 27.35647964], [96.78531647, 27.35881042], [96.77960205, 27.3621006], [96.77295685, 27.36495972], [96.75979614, 27.36329079], [96.75419617, 27.36277008], [96.74775696, 27.36403084], [96.74069214, 27.36445999], [96.72844696, 27.37239075], [96.72251892, 27.37695122], [96.7125473, 27.38072968], [96.70876312, 27.37519073], [96.70638275, 27.37116051], [96.69909668, 27.36556053], [96.69374084, 27.36551857], [96.6831665, 27.36894035], [96.67619324, 27.3708992], [96.67015839, 27.3723011], [96.6608429, 27.37138939], [96.65603638, 27.36892128], [96.64611816, 27.36783028], [96.63913727, 27.36923981], [96.63037109, 27.37182999], [96.6204834, 27.3728199], [96.6125412, 27.36936951], [96.61077118, 27.36730766], [96.60894012, 27.36518288], [96.60260773, 27.36071777], [96.60251617, 27.36065102], [96.59829712, 27.35645103], [96.59793854, 27.35149956], [96.59901428, 27.34892464], [96.60080719, 27.3446312], [96.59720612, 27.34300804], [96.59632111, 27.34260941], [96.59166718, 27.34085083], [96.58592224, 27.33683968], [96.57991791, 27.33365059], [96.57543945, 27.32919121], [96.56598663, 27.32666016], [96.56182861, 27.32525253], [96.55621338, 27.32061958], [96.55046082, 27.31472015], [96.54527283, 27.3097229], [96.53759766, 27.3042984], [96.53074646, 27.29804993], [96.52233124, 27.29397011], [96.51703644, 27.30057907], [96.5118103, 27.30405045], [96.50538635, 27.30760002], [96.50003052, 27.3093605], [96.49402618, 27.30626106], [96.48603058, 27.30523109], [96.47917938, 27.30808067], [96.4707489, 27.31246185], [96.46666718, 27.31105042], [96.461586, 27.30911064], [96.45250702, 27.3098011], [96.44613647, 27.31030083], [96.43976593, 27.31035995], [96.43348694, 27.30994034], [96.42495728, 27.3061409], [96.41609192, 27.29989243], [96.40862274, 27.29994965], [96.4017334, 27.2985611], [96.39157104, 27.29458046], [96.38279724, 27.29751968], [96.373703, 27.29893112], [96.36412048, 27.30016136], [96.36151886, 27.29405975], [96.35788727, 27.2916584], [96.35520172, 27.28988266], [96.34807587, 27.28846169], [96.34771729, 27.28839111], [96.34118652, 27.2915802], [96.33574677, 27.2959404], [96.32039642, 27.29801941], [96.31083679, 27.3020401], [96.30330658, 27.29922295], [96.29042816, 27.2940712], [96.28217316, 27.28602028], [96.27865601, 27.27938271], [96.26743317, 27.27783966], [96.25421143, 27.28098106], [96.24138641, 27.28429031], [96.23432922, 27.28487968], [96.22709656, 27.28059959], [96.21810913, 27.26958084], [96.20585632, 27.26613045], [96.19632721, 27.26519012], [96.19406891, 27.26345253], [96.19187927, 27.26177025], [96.18520355, 27.25663376], [96.18209839, 27.25424957], [96.1811676, 27.25426102], [96.16368866, 27.25448036], [96.15040588, 27.24950981], [96.11450195, 27.2333107], [96.09902191, 27.23140907], [96.09213257, 27.22667122], [96.08731079, 27.21859932], [96.08638763, 27.21705055], [96.0851593, 27.2167778], [96.06897736, 27.21319008], [96.05728149, 27.20279121], [96.03643036, 27.19605064], [96.02979279, 27.18778992], [96.02700043, 27.17901802], [96.02298737, 27.16638947], [96.01693726, 27.15479088], [96.00431824, 27.14044189], [96.00325012, 27.13933182], [95.98958588, 27.12519073], [95.97918701, 27.11072922], [95.97389221, 27.10201263], [95.97193909, 27.09879112], [95.9630661, 27.08197975], [95.9571228, 27.06822014], [95.94596863, 27.05970955], [95.9402771, 27.05577278], [95.93624878, 27.05299187], [95.92318726, 27.0489006], [95.91580963, 27.04532051], [95.90923309, 27.04030037], [95.90068817, 27.03178024], [95.88918304, 27.0278511], [95.87713623, 27.02049828], [95.86747742, 27.02234077], [95.85777283, 27.02235985], [95.83796692, 27.01531029], [95.82798004, 27.01805115], [95.81529999, 27.02222061], [95.80793762, 27.02045059], [95.80486298, 27.01199913], [95.77964783, 26.98999023], [95.77294159, 26.98253059], [95.77172852, 26.97864151], [95.76705933, 26.97289085], [95.76087952, 26.96398926], [95.76158142, 26.95926094], [95.76368713, 26.94498062], [95.76056671, 26.94201088], [95.75673676, 26.94021988], [95.75254822, 26.93023109], [95.75454712, 26.92500114], [95.75724792, 26.92040062], [95.75813293, 26.91489983], [95.75499725, 26.90788841], [95.74507904, 26.90089989], [95.73596191, 26.89270973], [95.73081207, 26.88749123], [95.72113037, 26.88363075], [95.71247864, 26.88430786], [95.71156311, 26.88438034], [95.71141815, 26.88442993], [95.70349121, 26.88718987], [95.69859314, 26.89521027], [95.692276, 26.89991951], [95.68798828, 26.90189362], [95.68128967, 26.90497971], [95.67336273, 26.9102211], [95.66819763, 26.90834045], [95.66295624, 26.90492058], [95.65777588, 26.89808083], [95.6553421, 26.89295006], [95.65414429, 26.89045143], [95.65099335, 26.88384819], [95.64644623, 26.88287926], [95.64562225, 26.8829155], [95.64221954, 26.88306046], [95.6367569, 26.87928963], [95.63413239, 26.8732605], [95.63478851, 26.86768913], [95.63491821, 26.86657906], [95.63355255, 26.85514069], [95.63223267, 26.84947968], [95.62812042, 26.84384918], [95.62769318, 26.84325981], [95.62203217, 26.83723259], [95.61798096, 26.82985115], [95.61151886, 26.82121277], [95.59910583, 26.82221985], [95.59226227, 26.82303047], [95.58473206, 26.82277107], [95.57475281, 26.82567024], [95.56851196, 26.82991028], [95.56562042, 26.83378983], [95.56269836, 26.8372097], [95.55475616, 26.83956909], [95.54567719, 26.83786011], [95.53277588, 26.83120918], [95.53024292, 26.82679176], [95.52500153, 26.8199482], [95.52147675, 26.81667519], [95.52025604, 26.81554031], [95.51480103, 26.8132], [95.50650787, 26.79663086], [95.50215149, 26.78273964], [95.49590302, 26.77194023], [95.48914337, 26.76167107], [95.48348999, 26.75498962], [95.47956085, 26.75365829], [95.47585297, 26.75239944], [95.4656601, 26.75041008], [95.46141052, 26.74600029], [95.45848083, 26.73771095], [95.45453644, 26.73293877], [95.4541626, 26.7324791], [95.45343781, 26.73201752], [95.44629669, 26.72743988], [95.4419632, 26.72284126], [95.4397583, 26.71797943], [95.43733215, 26.71446037], [95.43548584, 26.7082386], [95.43238831, 26.70355988], [95.4288559, 26.70004082], [95.42330933, 26.69671249], [95.40643311, 26.69662094], [95.39463806, 26.69102097], [95.38356781, 26.68806076], [95.37814331, 26.68334961], [95.37470245, 26.68125343], [95.37151337, 26.67930984], [95.36586761, 26.67758942], [95.36543274, 26.67757034], [95.35581207, 26.67712975], [95.34664917, 26.67794037], [95.32441711, 26.66908264], [95.31788635, 26.6668396], [95.31479645, 26.66386795], [95.30841064, 26.65772057], [95.30258179, 26.65602112], [95.29992676, 26.65788841], [95.29927063, 26.65834808], [95.2931366, 26.66123009], [95.28288269, 26.66284943], [95.27202606, 26.66282082], [95.26597595, 26.6678791], [95.26204681, 26.67365074], [95.26165771, 26.68148994], [95.26003265, 26.68635178], [95.25652313, 26.68931961], [95.25078583, 26.69239044], [95.24395752, 26.69390106], [95.24044037, 26.69164085], [95.23763275, 26.68629074], [95.23597717, 26.68823051], [95.23596954, 26.69152069], [95.23369598, 26.69709969], [95.23610687, 26.7122097], [95.2296524, 26.71688271], [95.22820282, 26.72384834], [95.21614075, 26.73531914], [95.21685028, 26.74130058], [95.22097778, 26.7474308], [95.22136688, 26.75152016], [95.21926117, 26.75555038], [95.2201004, 26.75982094], [95.22408295, 26.76172256], [95.22920227, 26.76847076], [95.23317719, 26.77193069], [95.23330688, 26.77371979], [95.23163605, 26.77769279], [95.23467255, 26.78034973], [95.24253845, 26.78451157], [95.24491882, 26.78733063], [95.24172211, 26.78693008], [95.24025726, 26.78917122], [95.23501587, 26.78928947], [95.2274704, 26.79234123], [95.22157288, 26.79354095], [95.21511841, 26.7983799], [95.20684052, 26.81169128], [95.20355225, 26.82131958], [95.20258331, 26.82875061], [95.20056152, 26.83288956], [95.19904327, 26.83992958], [95.20050812, 26.84287834], [95.20641327, 26.84628105], [95.20860291, 26.85071945], [95.20423889, 26.8489399], [95.19770813, 26.85153961], [95.19732666, 26.84939194], [95.19561005, 26.84962082], [95.19304657, 26.85116959], [95.18576813, 26.85963058], [95.18450165, 26.86483002], [95.20642853, 26.87787056], [95.21135712, 26.88173294], [95.21285248, 26.88560295], [95.21782684, 26.88686943], [95.22992706, 26.88566971], [95.2338562, 26.89084053], [95.23132324, 26.89834976], [95.23377228, 26.90590286], [95.23410034, 26.9096508], [95.23208618, 26.91483116], [95.23195648, 26.91789055], [95.23396301, 26.91875267], [95.23396301, 26.92060089], [95.23184967, 26.92614174], [95.22930908, 26.93063164], [95.22556305, 26.93442917], [95.21705627, 26.93420029], [95.21444702, 26.93695068], [95.21219635, 26.94334984], [95.20923615, 26.95667076], [95.21341705, 26.95878983], [95.20851135, 26.9607296], [95.20675659, 26.96259117], [95.20883942, 26.9653511], [95.21366882, 26.96812057], [95.21504211, 26.97037125], [95.20877075, 26.97508049], [95.20655823, 26.9788208], [95.20522308, 26.9821701], [95.20996094, 26.98262978], [95.20775604, 26.98470116], [95.20043945, 26.98555946], [95.19519806, 26.98999023], [95.19626617, 26.99781036], [95.19982147, 26.99935913], [95.20008087, 27.0062294], [95.19761658, 27.01568985], [95.19785309, 27.01984024], [95.19579315, 27.03250122], [95.19551849, 27.04294968], [95.19845581, 27.04442978], [95.20094299, 27.04232979], [95.20379639, 27.04300117], [95.20768738, 27.0347805], [95.21380615, 27.03347969], [95.21969604, 27.03679085], [95.22263336, 27.04089165], [95.22598267, 27.04225922], [95.2294693, 27.04017067], [95.23214722, 27.04292107], [95.23091125, 27.04570961], [95.23471832, 27.0435791], [95.23787689, 27.04322052], [95.24371338, 27.03416061], [95.24822998, 27.03025246], [95.25219727, 27.03191948], [95.2607193, 27.03725052], [95.25994873, 27.03897285], [95.26262665, 27.0410099], [95.26669312, 27.04043961], [95.27097321, 27.04507065], [95.27762604, 27.04977036], [95.27944946, 27.05391121], [95.27783203, 27.05676842], [95.28791809, 27.06632042], [95.29662323, 27.07285118], [95.30967712, 27.08113098], [95.31317902, 27.08674049], [95.32327271, 27.089571], [95.3351059, 27.09592056], [95.34860229, 27.10476112], [95.36647034, 27.11285019], [95.37126923, 27.1114006], [95.3706665, 27.11014938], [95.36778259, 27.10971069], [95.36830139, 27.10736275], [95.37365723, 27.1079998], [95.37267303, 27.10167122], [95.37697601, 27.10218048], [95.38546753, 27.10509109], [95.38611603, 27.11170959], [95.39614868, 27.11446953], [95.40631104, 27.11832047], [95.42027283, 27.13078117], [95.42919159, 27.13405037], [95.44098663, 27.13281059], [95.44557953, 27.1342907], [95.44713593, 27.13833046], [95.45075226, 27.13883972], [95.45339966, 27.13587952], [95.45778656, 27.1356411], [95.4610672, 27.14022064], [95.46367645, 27.15036011], [95.46585083, 27.15480042], [95.46507263, 27.15760994], [95.46331787, 27.15954018], [95.4598999, 27.16041946], [95.45870972, 27.16328812], [95.46383667, 27.1670208], [95.46800995, 27.1722908], [95.46366882, 27.18212128], [95.46711731, 27.18555069], [95.46864319, 27.19050026], [95.46581268, 27.19742966], [95.46205139, 27.20301056], [95.45890045, 27.20956993], [95.45970917, 27.2134304], [95.46942902, 27.21825981], [95.47067261, 27.22321129], [95.47389984, 27.22364998], [95.47451019, 27.22686958], [95.48055267, 27.23233986], [95.48722839, 27.24603081], [95.49099731, 27.24869919], [95.50627899, 27.2546196], [95.51064301, 27.2589798], [95.51088715, 27.26626968], [95.51618195, 27.26863098], [95.52046204, 27.26374054], [95.52593231, 27.26626015], [95.52971649, 27.26906967], [95.53481293, 27.27062035], [95.55416107, 27.25934029], [95.55613708, 27.25436974], [95.56326294, 27.25250244], [95.57446289, 27.25106049], [95.57830048, 27.24714088], [95.57788086, 27.24215126], [95.59008789, 27.2295208], [95.59916687, 27.22961044], [95.60735321, 27.23137283], [95.61914063, 27.23655128], [95.63413239, 27.23981094], [95.63700104, 27.23690987], [95.67920685, 27.2539196], [95.67939758, 27.25616264], [95.68441772, 27.25741005], [95.69542694, 27.25814819], [95.70188141, 27.25564003], [95.71549225, 27.25909996], [95.72107697, 27.25760078], [95.72548676, 27.25922966], [95.73188019, 27.26654053], [95.73638916, 27.26675034], [95.7399292, 27.26988983], [95.75701141, 27.27435112], [95.78468323, 27.27913094], [95.790802, 27.28545952], [95.80075836, 27.2887001], [95.80628967, 27.29174042], [95.8065033, 27.28801155], [95.80848694, 27.28544044], [95.81019592, 27.28092003], [95.8379364, 27.28707123], [95.85022736, 27.29314995], [95.860466, 27.29421043], [95.86192322, 27.29002953], [95.86064148, 27.28342056], [95.86084747, 27.27979279], [95.86544037, 27.2766819], [95.87238312, 27.26691055], [95.87760162, 27.26740837], [95.88243103, 27.26694107], [95.88765717, 27.26332092], [95.89396667, 27.26301193], [95.89810944, 27.26431084], [95.90116119, 27.27638817], [95.90428925, 27.27985954], [95.90453339, 27.28623962], [95.90238953, 27.28783035], [95.90643311, 27.29187965], [95.91229248, 27.29314041], [95.91874695, 27.29922295], [95.94056702, 27.30958939], [95.96321869, 27.3170681], [95.96556854, 27.3216629], [95.96260834, 27.32433128], [95.96785736, 27.3245697], [95.96903229, 27.32840919], [95.96871185, 27.33183098], [95.9780426, 27.33269119], [95.98420715, 27.33434105], [95.97228241, 27.33462906], [95.97001648, 27.33698082], [95.97421265, 27.33936119], [95.9773407, 27.34230042], [95.99368286, 27.35144043], [95.99487305, 27.36024094], [95.99697113, 27.36347961], [96.00211334, 27.36412811], [96.00314331, 27.36445999], [96.01319885, 27.36403084], [96.01835632, 27.36790085], [96.02091217, 27.37125969], [96.01494598, 27.37545967], [96.01056671, 27.38128281], [96.00836945, 27.38721085], [96.00205231, 27.39349937], [96.00006866, 27.39756966], [96.00100708, 27.4034729], [95.99459076, 27.41235924], [95.99093628, 27.41457176], [95.9912262, 27.41939926], [95.98945618, 27.4217205], [95.97952271, 27.4218502], [95.97807312, 27.42533112], [95.98092651, 27.42612267], [95.98023224, 27.43021965], [95.97782898, 27.43229103], [95.9777832, 27.43549919], [95.97329712, 27.43675041], [95.97177887, 27.43037033], [95.96803284, 27.42411995], [95.96703339, 27.43666077], [95.96357727, 27.43548012], [95.96105194, 27.42871094], [95.95729065, 27.4328804], [95.95297241, 27.43328094], [95.95052338, 27.4372406], [95.95350647, 27.4407711], [95.95307159, 27.44345093], [95.94989014, 27.44502068], [95.94300079, 27.44639015], [95.93327332, 27.4466877], [95.91684723, 27.4431591], [95.91117096, 27.43996048], [95.90796661, 27.43264008], [95.90612793, 27.42326927], [95.90010071, 27.41133118], [95.89305878, 27.40604019], [95.89187622, 27.4097805], [95.89425659, 27.41438293], [95.89437866, 27.41828918], [95.89002991, 27.42641068], [95.88941956, 27.43162918], [95.89037323, 27.43967056], [95.88865662, 27.44407082], [95.88259125, 27.44408035], [95.87577057, 27.43535805], [95.86490631, 27.4290123], [95.8632431, 27.42485809], [95.86422729, 27.42131805], [95.8666687, 27.41921043], [95.86733246, 27.4171505], [95.85795593, 27.420681], [95.85761261, 27.42481995], [95.85573578, 27.42766953], [95.84934235, 27.43032074], [95.84947205, 27.43490982], [95.8529129, 27.44475937], [95.8551712, 27.44737053], [95.85955811, 27.44905281], [95.86379242, 27.45203018], [95.85945892, 27.46261024], [95.86116791, 27.46629906], [95.86606598, 27.46902275], [95.87625885, 27.47110939], [95.87843323, 27.4756012], [95.8812561, 27.48742104], [95.87915802, 27.49267006], [95.87905121, 27.49919128], [95.88046265, 27.50110054], [95.88604736, 27.50356293], [95.88964081, 27.50616837], [95.88710785, 27.51127052], [95.88179779, 27.51509094], [95.878479, 27.5198307], [95.88080597, 27.52251053], [95.87992096, 27.52979088], [95.88143921, 27.54583168], [95.8813324, 27.55323029], [95.87361908, 27.55117035], [95.86701965, 27.55109978], [95.86235809, 27.55260086], [95.85209656, 27.56565094], [95.84601593, 27.56799126], [95.83989716, 27.56661034], [95.83628845, 27.57117844], [95.83193207, 27.57888985], [95.82772827, 27.58175087], [95.82124329, 27.58172035], [95.81980896, 27.59028053], [95.82025909, 27.59557152], [95.82419586, 27.60301018], [95.82087708, 27.60472107], [95.81682587, 27.60543823], [95.80960846, 27.60527039], [95.79802704, 27.60783005], [95.79606628, 27.61819077], [95.79429626, 27.62236977], [95.787117, 27.62340927], [95.78504181, 27.62739944], [95.78734589, 27.63229942], [95.79741669, 27.63589096], [95.79734039, 27.6395607], [95.79959106, 27.64296913], [95.80145264, 27.6490097], [95.79485321, 27.65279961], [95.78623199, 27.65566063], [95.77922058, 27.66053963], [95.77784729, 27.66625977], [95.7784729, 27.67234993], [95.78044891, 27.67918968], [95.78549194, 27.68325996], [95.79453278, 27.68419075], [95.79647064, 27.68806076], [95.79312897, 27.69227028], [95.77876282, 27.69439125], [95.77455139, 27.69670105], [95.77266693, 27.69995117], [95.77336121, 27.70535088], [95.77262115, 27.71132088], [95.77052307, 27.7159996], [95.77039337, 27.72002983], [95.76304626, 27.72266006], [95.75871277, 27.72668076], [95.75821686, 27.73110962], [95.76267242, 27.73293114], [95.7718811, 27.73451042], [95.78479767, 27.73978043], [95.78777313, 27.74205017], [95.78053284, 27.75822067], [95.78882599, 27.7650528], [95.79538727, 27.77263069], [95.8009491, 27.77686119], [95.80636597, 27.78358078], [95.80757904, 27.78994942], [95.81131744, 27.79372025], [95.82312775, 27.80924988], [95.82894135, 27.81365967], [95.8349762, 27.8157711], [95.84336853, 27.82147026], [95.84599304, 27.83010101], [95.85209656, 27.83411026], [95.86633301, 27.83846092], [95.87372589, 27.83980179], [95.87657166, 27.84177017], [95.89209747, 27.85704041], [95.89422607, 27.86096001], [95.89502716, 27.86722183], [95.89763641, 27.86746979], [95.90055847, 27.86668015], [95.90722656, 27.8686409], [95.90618134, 27.87722969], [95.91137695, 27.87301826], [95.91409302, 27.87465096], [95.91291809, 27.8781395], [95.91400146, 27.88084984], [95.91866302, 27.88278008], [95.92262268, 27.88618088], [95.92127991, 27.8904705], [95.92375183, 27.89033127], [95.92735291, 27.88726044], [95.92855072, 27.89052963], [95.92392731, 27.89599991], [95.92501068, 27.90094185], [95.92864227, 27.9028511], [95.9383316, 27.90327072], [95.9393158, 27.90982056], [95.94351196, 27.91263962], [95.95249176, 27.92281914], [95.95529938, 27.92682076], [95.95381165, 27.93024063], [95.95754242, 27.9328804], [95.95755005, 27.93708038], [95.9523468, 27.93717957], [95.95155334, 27.93917084], [95.95231628, 27.94184113], [95.96520996, 27.9526329], [95.97746277, 27.96850014], [95.95688629, 27.96912956], [95.82588196, 27.97737122], [95.60674286, 27.95776939], [95.59694672, 27.95112991], [95.58866119, 27.94162941], [95.58053589, 27.94356155], [95.57121277, 27.94238091], [95.56626129, 27.93159103], [95.56504822, 27.92251968], [95.54380035, 27.91345978], [95.54206848, 27.91074181], [95.54434204, 27.9057827], [95.54353333, 27.90232277], [95.53302002, 27.90043068], [95.52622986, 27.89789963], [95.51595306, 27.88178825], [95.38433838, 27.84202194], [95.31655884, 27.87112999], [95.30847168, 27.86782074], [95.29254913, 27.86499023], [95.23654175, 27.84835052], [95.19486237, 27.83444977], [95.05182648, 27.7902298], [95.04886627, 27.78646088], [95.03875732, 27.77773094], [95.03121948, 27.77477074], [95.01914978, 27.77249908], [94.99787903, 27.77655029], [94.98703766, 27.77085114], [94.93003082, 27.75673103], [94.88394165, 27.74205971], [94.86086273, 27.73947906], [94.86602783, 27.73624039], [94.86071777, 27.73338127], [94.85357666, 27.73162079], [94.84879303, 27.71068192], [94.83938599, 27.7035408], [94.82126617, 27.6962204], [94.81803131, 27.69684029], [94.80021667, 27.69709015], [94.7975769, 27.69893265], [94.79534912, 27.69807816], [94.79405975, 27.69322014], [94.79099274, 27.6888504], [94.77645111, 27.68337822], [94.77216339, 27.6839695], [94.76693726, 27.68013954], [94.76432037, 27.67456055], [94.75955963, 27.66843987], [94.75592041, 27.66651917], [94.74266815, 27.66342163], [94.73703003, 27.66564941], [94.72767639, 27.66786003], [94.72554016, 27.67033958], [94.72070313, 27.66999054], [94.71663666, 27.6616497], [94.7130661, 27.66026115], [94.69808197, 27.66710091], [94.68940735, 27.66719055], [94.68387604, 27.66333961], [94.68650818, 27.65714264], [94.68699646, 27.65331078], [94.68251038, 27.64958954], [94.6757431, 27.65065193], [94.66911316, 27.65027809], [94.66464233, 27.64785957], [94.64842224, 27.64207077], [94.6452179, 27.63653946], [94.6397934, 27.63096046], [94.63445282, 27.62877083], [94.63069153, 27.62829018], [94.62497711, 27.63011932], [94.61406708, 27.62574005], [94.60938263, 27.62263107], [94.6040802, 27.62310028], [94.60060883, 27.62193108], [94.59577179, 27.6214695], [94.59146881, 27.62281036], [94.58629608, 27.62010956], [94.58185577, 27.61668015], [94.5735321, 27.60696983], [94.56947327, 27.60635185], [94.56389618, 27.6069603], [94.55612183, 27.60323906], [94.55171204, 27.60404968], [94.54641724, 27.60353279], [94.53659058, 27.59699059], [94.53173065, 27.59692955], [94.52628326, 27.59576988], [94.51566315, 27.58473015], [94.50940704, 27.58407021], [94.50022888, 27.57731056], [94.5, 27.57726479], [94.4909668, 27.57549286], [94.48310852, 27.57720184], [94.47915649, 27.57699013], [94.46930695, 27.56401253], [94.45973969, 27.55771065], [94.45622253, 27.56290245], [94.45346832, 27.57094002], [94.44960785, 27.57504082], [94.44238281, 27.57946014], [94.43605042, 27.58442116], [94.43058777, 27.59646034], [94.4310379, 27.60308075], [94.42092896, 27.60134125], [94.40318298, 27.58719063], [94.3948288, 27.58877945], [94.38759613, 27.58927917], [94.38437653, 27.58646011], [94.38043213, 27.58509064], [94.37583923, 27.58457756], [94.37230682, 27.57926941], [94.36749268, 27.5767498], [94.36219788, 27.58023071], [94.35569763, 27.57738113], [94.34884644, 27.57945061], [94.34507751, 27.58459091], [94.34057617, 27.58344078], [94.3381424, 27.58103943], [94.32905579, 27.58839035], [94.3237381, 27.58716965], [94.31970978, 27.59005165], [94.31240845, 27.58965111], [94.30835724, 27.59558105], [94.30164337, 27.59988022], [94.29801941, 27.60427094], [94.29289246, 27.60036087], [94.28848267, 27.59451103], [94.28765869, 27.59179115], [94.27603149, 27.59334946], [94.27520752, 27.59740067], [94.27245331, 27.60346985], [94.2618866, 27.61009979], [94.25408936, 27.61370087], [94.25710297, 27.61911964], [94.26222229, 27.62451935], [94.26716614, 27.62786293], [94.26670837, 27.63256073], [94.26278687, 27.63602066], [94.25907135, 27.6370182], [94.25598907, 27.63655281], [94.25222778, 27.64093018], [94.25006866, 27.63972092], [94.24726868, 27.63581085], [94.24507141, 27.63586998], [94.2350769, 27.63251114], [94.22595978, 27.61799049], [94.21743774, 27.60900116], [94.21111298, 27.61084175]]]}}, {\\\"id\\\": \\\"3\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.4_1\\\", \\\"HASC_1\\\": \\\"IN.AS\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Assam\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 29.9, \\\"dalys_apm25_rate_6cod_mean_total\\\": 724.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1977.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2701.0, \\\"geo-id\\\": 3, \\\"hpm25_child_popweighted\\\": 201.0, \\\"hpm25_female_popweighted\\\": 231.0, \\\"hpm25_male_popweighted\\\": 166.3, \\\"location\\\": \\\"Assam\\\", \\\"mort_apm25_6cod_mean_total\\\": 7670.0, \\\"mort_hpm25_6cod_mean_total\\\": 19627.0, \\\"mort_tpm25_6cod_mean_total\\\": 27297.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[89.83874512, 25.96647453], [89.8381424, 25.96792793], [89.83805084, 25.96814346], [89.83853912, 25.96846962], [89.83866119, 25.96846962], [89.840271, 25.96847153], [89.84041595, 25.96877861], [89.8411026, 25.97018814], [89.84141541, 25.9704113], [89.84187317, 25.97073936], [89.84549713, 25.97136688], [89.84825134, 25.97097397], [89.84980774, 25.97075272], [89.85055542, 25.97043419], [89.85138702, 25.97009277], [89.85182953, 25.96994209], [89.85231781, 25.96979523], [89.85293579, 25.96954918], [89.85355377, 25.96935654], [89.85520172, 25.968853], [89.85564423, 25.96887016], [89.85621643, 25.96889687], [89.85700989, 25.96895981], [89.85736847, 25.96899605], [89.85771179, 25.96902657], [89.8578949, 25.96903419], [89.85801697, 25.96904373], [89.85812378, 25.96906281], [89.85823059, 25.96909332], [89.85855865, 25.96917725], [89.85902405, 25.96932602], [89.85919189, 25.96936798], [89.85944366, 25.9694519], [89.85961914, 25.96953964], [89.85983276, 25.96960258], [89.85997009, 25.96965218], [89.86016083, 25.96974945], [89.8607254, 25.97003937], [89.86089325, 25.97013283], [89.86104584, 25.97020531], [89.86113739, 25.97024727], [89.86135101, 25.97036552], [89.8616333, 25.97056198], [89.86192322, 25.97074318], [89.86251068, 25.97109795], [89.8625946, 25.97118187], [89.86289978, 25.97140312], [89.86341858, 25.97167969], [89.86353302, 25.97171402], [89.86376953, 25.97178841], [89.86407471, 25.97185516], [89.86421967, 25.97188568], [89.86465454, 25.97194862], [89.86536407, 25.97203064], [89.86553192, 25.97201538], [89.86589813, 25.97204781], [89.86618805, 25.97205925], [89.86664581, 25.9720993], [89.86678314, 25.97215462], [89.86709595, 25.97234535], [89.86735535, 25.97250175], [89.86968231, 25.97347069], [89.87175751, 25.97416306], [89.8730545, 25.97569656], [89.87319946, 25.9758625], [89.87310791, 25.97602654], [89.87203217, 25.97788239], [89.87181091, 25.97829247], [89.8713913, 25.97840309], [89.87112427, 25.97847176], [89.87109375, 25.97855568], [89.87091827, 25.97901535], [89.87110138, 25.97981071], [89.87095642, 25.98057938], [89.87065887, 25.98145294], [89.87014008, 25.98161507], [89.86968231, 25.98175621], [89.86896515, 25.98130035], [89.86860657, 25.97977829], [89.86841583, 25.97963524], [89.86798096, 25.97930908], [89.86710358, 25.97948074], [89.86678314, 25.97999001], [89.86663055, 25.98022842], [89.86665344, 25.98039246], [89.86676788, 25.98114967], [89.86532593, 25.98236084], [89.86134338, 25.98441124], [89.85920715, 25.98507118], [89.85766602, 25.98558044], [89.85732269, 25.98594856], [89.85312653, 25.98754692], [89.85202026, 25.98945808], [89.85128784, 25.98963928], [89.85076141, 25.98976707], [89.85023499, 25.99020004], [89.84983063, 25.99090195], [89.84914398, 25.99209785], [89.84886932, 25.99290085], [89.84881592, 25.9929924], [89.84873962, 25.9929924], [89.84864044, 25.9932251], [89.84793854, 25.99493599], [89.84765625, 25.99603462], [89.84748077, 25.99669838], [89.84741974, 25.996912], [89.84722137, 25.99685669], [89.84723663, 25.99818993], [89.84725189, 25.99926949], [89.84758759, 26.00068474], [89.84761047, 26.0007782], [89.84618378, 26.00272942], [89.84420013, 26.00607872], [89.84405518, 26.00625038], [89.84383392, 26.00650215], [89.8430481, 26.00724411], [89.84289551, 26.00730133], [89.84237671, 26.00766182], [89.84169006, 26.00822639], [89.84137726, 26.00842667], [89.84091949, 26.00859833], [89.84034729, 26.00886726], [89.84001923, 26.00894928], [89.83961487, 26.00901985], [89.83930206, 26.00923157], [89.83898926, 26.00947762], [89.83875275, 26.00968933], [89.83747101, 26.00850105], [89.83656311, 26.00653076], [89.83650208, 26.00555992], [89.83638, 26.00390816], [89.83583069, 26.00119019], [89.8349762, 25.9995594], [89.83432007, 25.99747086], [89.83566284, 25.99500084], [89.83644104, 25.99277115], [89.83673096, 25.99158096], [89.83612061, 25.98913956], [89.83740997, 25.98718834], [89.83912659, 25.98476982], [89.83922577, 25.98323059], [89.8397522, 25.98101044], [89.83757782, 25.97944832], [89.83476257, 25.98006058], [89.8325119, 25.98084068], [89.82887268, 25.9811306], [89.82637024, 25.98219109], [89.82344055, 25.98451996], [89.8229599, 25.98490906], [89.82112122, 25.98688507], [89.82080078, 25.98722458], [89.82067871, 25.98735428], [89.82045746, 25.9875946], [89.82034302, 25.98764801], [89.82015228, 25.98774147], [89.81975555, 25.98828697], [89.81951141, 25.98859024], [89.81928253, 25.98888397], [89.81919098, 25.989048], [89.8190918, 25.98921967], [89.8188324, 25.98950577], [89.81877136, 25.98965836], [89.81873322, 25.98976135], [89.81855011, 25.99002075], [89.8175354, 25.99128532], [89.81739807, 25.9914875], [89.81728363, 25.99177742], [89.81716156, 25.99200821], [89.81700897, 25.9923172], [89.81671906, 25.99288559], [89.81653595, 25.9931469], [89.81649017, 25.99333191], [89.81627655, 25.99374771], [89.81609344, 25.99423409], [89.81575775, 25.99526978], [89.81546021, 25.99592781], [89.81539154, 25.99630356], [89.81524658, 25.99662399], [89.81510162, 25.99703598], [89.81498718, 25.99749184], [89.81491852, 25.99757576], [89.81481171, 25.99794769], [89.81490326, 25.99801636], [89.81520844, 25.9977932], [89.81573486, 25.99743271], [89.81608582, 25.99718857], [89.81645966, 25.99694633], [89.8167038, 25.99674416], [89.81687927, 25.99657631], [89.81704712, 25.99641609], [89.81746674, 25.99617958], [89.8176651, 25.99611282], [89.81803894, 25.9960289], [89.81812286, 25.99600601], [89.81826019, 25.99596786], [89.81855011, 25.9959507], [89.81890106, 25.99600601], [89.8192215, 25.99604988], [89.8194809, 25.99622536], [89.81975555, 25.99651146], [89.81987762, 25.99668121], [89.81995392, 25.99678993], [89.82012177, 25.99710846], [89.82021332, 25.99736023], [89.82029724, 25.99750328], [89.82041931, 25.99803734], [89.82046509, 25.9984684], [89.82050323, 25.9987812], [89.82055664, 25.99965286], [89.82032776, 26.00021362], [89.81998444, 26.00094604], [89.81988525, 26.00123978], [89.81968689, 26.00172615], [89.81924438, 26.00263023], [89.81900787, 26.00314903], [89.81905365, 26.00339699], [89.81912231, 26.00422096], [89.81915283, 26.00434113], [89.81918335, 26.0044651], [89.81938934, 26.00507736], [89.81945801, 26.00517654], [89.81968689, 26.00561905], [89.81980133, 26.00593567], [89.82001495, 26.00649261], [89.8201828, 26.00703621], [89.82027435, 26.00734901], [89.82038879, 26.00779724], [89.82078552, 26.00777626], [89.8213501, 26.00775528], [89.82189178, 26.00772095], [89.82196045, 26.00806236], [89.82192993, 26.00832367], [89.8219223, 26.00857544], [89.8218689, 26.00889206], [89.82183838, 26.00915909], [89.82184601, 26.00939941], [89.82188416, 26.00977135], [89.82194519, 26.01003838], [89.82151794, 26.01045036], [89.82132721, 26.01062965], [89.82131195, 26.01089287], [89.82131195, 26.01100159], [89.82130432, 26.0112381], [89.82129669, 26.01142502], [89.82126617, 26.01173019], [89.82122803, 26.01200104], [89.82118988, 26.0120697], [89.82082367, 26.01243591], [89.82050323, 26.01271629], [89.82032013, 26.01288986], [89.82000732, 26.01318741], [89.81981659, 26.01338959], [89.81971741, 26.01350212], [89.8196106, 26.01366997], [89.81954193, 26.01387787], [89.81946564, 26.01408386], [89.81931305, 26.01450539], [89.81919098, 26.01483154], [89.81905365, 26.01530075], [89.81893921, 26.01554298], [89.8188858, 26.01569366], [89.81860352, 26.01597595], [89.81820679, 26.01637268], [89.8179245, 26.01664352], [89.81773376, 26.01685715], [89.81761169, 26.01697731], [89.81747437, 26.01711655], [89.81699371, 26.01722145], [89.81666565, 26.01729774], [89.81633759, 26.01714897], [89.81613922, 26.01707458], [89.8160553, 26.01723099], [89.81576538, 26.01772308], [89.81568146, 26.0179615], [89.81557465, 26.01820564], [89.81548309, 26.01860619], [89.81539154, 26.0192337], [89.81533813, 26.01969719], [89.81529999, 26.02031136], [89.81539154, 26.02064133], [89.81543732, 26.02082253], [89.8155365, 26.02106857], [89.81563568, 26.02127457], [89.81569672, 26.02143288], [89.81589508, 26.02168846], [89.81627655, 26.02228737], [89.81647491, 26.02260399], [89.81668854, 26.02291107], [89.81700897, 26.02331161], [89.81731415, 26.02365685], [89.81748962, 26.02382469], [89.81765747, 26.02400589], [89.81782532, 26.02427673], [89.81790161, 26.02445984], [89.81829834, 26.02493668], [89.81864929, 26.02526665], [89.8192215, 26.02591515], [89.81880951, 26.02632141], [89.81859589, 26.0265274], [89.81835175, 26.02679443], [89.8181076, 26.02703476], [89.81785583, 26.02731514], [89.81735992, 26.02783394], [89.81715393, 26.0280304], [89.81686401, 26.02829933], [89.81681061, 26.02834892], [89.8164978, 26.02862167], [89.8161087, 26.02898216], [89.81578827, 26.02926826], [89.81547546, 26.02953529], [89.81522369, 26.0297699], [89.81492615, 26.03006172], [89.81480408, 26.03023338], [89.81453705, 26.03066444], [89.81430054, 26.03102493], [89.81400299, 26.03151131], [89.81378937, 26.03189468], [89.81370544, 26.03212357], [89.81364441, 26.03236389], [89.81358337, 26.03264999], [89.81356049, 26.03296089], [89.81352234, 26.03321075], [89.81347656, 26.03354645], [89.8134079, 26.03386879], [89.81334686, 26.03427505], [89.81327057, 26.03463554], [89.81322479, 26.03510284], [89.81315613, 26.03570366], [89.81311798, 26.03596306], [89.81310272, 26.03614807], [89.81291962, 26.03606224], [89.81287384, 26.03636742], [89.81279755, 26.03701591], [89.81275177, 26.03718948], [89.81253815, 26.03798485], [89.81242371, 26.03840065], [89.81231689, 26.03874969], [89.81227112, 26.03880692], [89.81197357, 26.03918648], [89.81208801, 26.03939819], [89.81201172, 26.03953552], [89.81190491, 26.03981209], [89.81170654, 26.04030991], [89.81156158, 26.04061127], [89.81138611, 26.04090118], [89.811203, 26.04115105], [89.81088257, 26.04155922], [89.81075287, 26.04169273], [89.81053925, 26.04191589], [89.81032562, 26.04211235], [89.80995178, 26.04245377], [89.80960846, 26.04276657], [89.80947113, 26.04286957], [89.80908203, 26.0431366], [89.80883026, 26.04328537], [89.80860901, 26.0434227], [89.80597687, 26.04462433], [89.80558777, 26.04457092], [89.80532074, 26.04412079], [89.80517578, 26.04386139], [89.80503845, 26.04359627], [89.80499268, 26.04349327], [89.80460358, 26.04235649], [89.80451202, 26.04200554], [89.80450439, 26.04147911], [89.80457306, 26.04128265], [89.80453491, 26.04093742], [89.80456543, 26.04066658], [89.80457306, 26.0404129], [89.80449677, 26.04011536], [89.80436707, 26.03981209], [89.80412292, 26.03966713], [89.80393982, 26.0396328], [89.8037796, 26.03963089], [89.80361176, 26.03886032], [89.80342102, 26.03786659], [89.80329895, 26.03721619], [89.80319977, 26.03664017], [89.8030777, 26.03606224], [89.80303955, 26.03581619], [89.80297852, 26.03540802], [89.80290985, 26.03507233], [89.80284882, 26.03478622], [89.80278778, 26.03450394], [89.8026886, 26.03409576], [89.80259705, 26.03363419], [89.80256653, 26.03328705], [89.80240631, 26.0327816], [89.80214691, 26.03212738], [89.80198669, 26.0317955], [89.80182648, 26.03152657], [89.80167389, 26.03134537], [89.80151367, 26.03112984], [89.80125427, 26.0308094], [89.80111694, 26.03064728], [89.80096436, 26.03042603], [89.80085754, 26.03022957], [89.80065918, 26.02986145], [89.8004837, 26.02939034], [89.80027771, 26.0288887], [89.79985046, 26.02820206], [89.79960632, 26.02774239], [89.79943085, 26.02744293], [89.79924011, 26.02709389], [89.79909515, 26.02677727], [89.79879761, 26.02624512], [89.79853058, 26.02586174], [89.79797363, 26.02505112], [89.7976532, 26.02462387], [89.79755402, 26.02450562], [89.79716492, 26.02409744], [89.79677582, 26.02369499], [89.7964859, 26.02337456], [89.79615021, 26.02312851], [89.79521942, 26.02302933], [89.79497528, 26.02327347], [89.79434204, 26.02299881], [89.79418182, 26.02239799], [89.79415894, 26.02232742], [89.79423523, 26.02228165], [89.79456329, 26.02209282], [89.79476929, 26.02205849], [89.7953186, 26.02191353], [89.7950592, 26.02174759], [89.79485321, 26.02165413], [89.79467773, 26.0215435], [89.79477692, 26.02141571], [89.79450989, 26.02115059], [89.79436493, 26.0210228], [89.79425812, 26.02087593], [89.79412079, 26.02059174], [89.79392242, 26.02036476], [89.79377747, 26.02028656], [89.79321289, 26.01963425], [89.79306793, 26.01951981], [89.79277039, 26.01918983], [89.79235077, 26.01880836], [89.79174042, 26.01835823], [89.79151917, 26.01822472], [89.7914505, 26.0181179], [89.79084778, 26.01800728], [89.79056549, 26.01789665], [89.79026794, 26.01786613], [89.79000854, 26.0178833], [89.7898941, 26.0179081], [89.78935242, 26.0181675], [89.78910065, 26.01831436], [89.78878784, 26.01848221], [89.78871155, 26.0185318], [89.78838348, 26.01882172], [89.7879715, 26.01930618], [89.78768158, 26.01973152], [89.78749847, 26.02000809], [89.7874527, 26.02018738], [89.78738403, 26.02046585], [89.78739929, 26.02062225], [89.78742218, 26.02071953], [89.7874527, 26.02086449], [89.78760529, 26.02136421], [89.78775787, 26.0214653], [89.78787994, 26.02137947], [89.78863525, 26.02083969], [89.79151917, 26.02095985], [89.79206085, 26.02116585], [89.79248047, 26.02146912], [89.79291534, 26.02176285], [89.79319, 26.02207184], [89.79367065, 26.02248764], [89.79381561, 26.02263451], [89.79387665, 26.02301788], [89.79393768, 26.02346992], [89.79334259, 26.02506256], [89.79322052, 26.02586746], [89.79330444, 26.02697945], [89.79347229, 26.02766037], [89.79366302, 26.02822495], [89.7950592, 26.02851486], [89.79512787, 26.02864647], [89.79521942, 26.02873611], [89.79536438, 26.028862], [89.79573059, 26.02923203], [89.79598236, 26.02923775], [89.79627228, 26.02928162], [89.79646301, 26.02952766], [89.79672241, 26.02973557], [89.79698944, 26.02998543], [89.79734039, 26.03035164], [89.79763794, 26.03071022], [89.79781342, 26.03095818], [89.7974472, 26.03112221], [89.79779053, 26.03160858], [89.79794312, 26.03183365], [89.79810333, 26.03210258], [89.79826355, 26.03239059], [89.7984314, 26.03268051], [89.79864502, 26.03311729], [89.79844666, 26.03318787], [89.79858398, 26.03357315], [89.79868317, 26.03398323], [89.79870605, 26.03412819], [89.79878998, 26.03435516], [89.7990799, 26.03495407], [89.79927826, 26.0353241], [89.79965973, 26.03586006], [89.80003357, 26.03629684], [89.80010986, 26.03653336], [89.80054474, 26.03679276], [89.80104065, 26.03701973], [89.80126953, 26.0371666], [89.8015976, 26.03748894], [89.80174255, 26.03764153], [89.80189514, 26.03777504], [89.80214691, 26.03810501], [89.80224609, 26.03832626], [89.80226898, 26.03860664], [89.80194855, 26.03866577], [89.80184174, 26.0390873], [89.80173492, 26.03936386], [89.80157471, 26.03962135], [89.80157471, 26.03983688], [89.80163574, 26.04002762], [89.80177307, 26.04035378], [89.8014679, 26.04052162], [89.80132294, 26.04060173], [89.80089569, 26.04084206], [89.80056763, 26.04106712], [89.80045319, 26.04107094], [89.79971313, 26.04109955], [89.79767609, 26.03982925], [89.79749298, 26.03906059], [89.79720306, 26.03784943], [89.79740906, 26.03557014], [89.79574585, 26.03388977], [89.79367065, 26.03415108], [89.79273987, 26.03495216], [89.7926178, 26.03505516], [89.79251862, 26.03523064], [89.79244995, 26.03559685], [89.79230499, 26.03523827], [89.79212189, 26.03500175], [89.79176331, 26.03472137], [89.79144287, 26.03457832], [89.7910614, 26.03447533], [89.79077148, 26.03439331], [89.79058838, 26.03437424], [89.79006958, 26.0344162], [89.7896347, 26.03458023], [89.78948212, 26.03467941], [89.7893219, 26.03483582], [89.78911591, 26.03496552], [89.78899384, 26.03506279], [89.78889465, 26.03505135], [89.78877258, 26.03512001], [89.78868866, 26.03517151], [89.78856659, 26.03516769], [89.78844452, 26.03516197], [89.7882843, 26.03509331], [89.7881012, 26.03530693], [89.7879715, 26.03550911], [89.78780365, 26.03578949], [89.7877121, 26.03593445], [89.78765106, 26.03608704], [89.78755188, 26.03633118], [89.78752899, 26.03651619], [89.78751373, 26.03662872], [89.78752136, 26.03691483], [89.78754425, 26.03709984], [89.78760529, 26.03732491], [89.78775024, 26.03764153], [89.78784943, 26.03780937], [89.78822327, 26.03823471], [89.78852844, 26.03860283], [89.78877258, 26.03891563], [89.78904724, 26.0392437], [89.78929138, 26.03949165], [89.78942871, 26.03963661], [89.78765869, 26.03970146], [89.78556824, 26.03861046], [89.78528595, 26.03833961], [89.78344727, 26.03659058], [89.78247833, 26.0351181], [89.78119659, 26.03412056], [89.78031921, 26.033741], [89.77900696, 26.03443909], [89.77793121, 26.03570557], [89.7779541, 26.03656769], [89.77776337, 26.03629875], [89.7776413, 26.0361557], [89.77739716, 26.03594589], [89.77729034, 26.03582382], [89.77700806, 26.03549004], [89.77685547, 26.03528214], [89.77671814, 26.03515434], [89.77661133, 26.0350666], [89.77651215, 26.03501701], [89.77599335, 26.0354557], [89.77586365, 26.0355835], [89.77555084, 26.03590775], [89.77510071, 26.03635979], [89.77471924, 26.03671837], [89.7743454, 26.03709602], [89.77416229, 26.03727341], [89.77398682, 26.03746033], [89.77383423, 26.03759193], [89.77357483, 26.03773117], [89.77373505, 26.03808975], [89.77380371, 26.03833771], [89.77378082, 26.03841019], [89.77386475, 26.03855324], [89.77394104, 26.03884888], [89.77405548, 26.03907967], [89.77420044, 26.03938484], [89.77435303, 26.03957367], [89.77458191, 26.03991508], [89.77466583, 26.04006004], [89.77511597, 26.04049301], [89.77529144, 26.04063606], [89.77547455, 26.04082298], [89.77574921, 26.04109001], [89.77596283, 26.04128647], [89.77627563, 26.041605], [89.77708435, 26.04240799], [89.7774353, 26.04276466], [89.77770233, 26.04309654], [89.77796173, 26.04336548], [89.77840424, 26.04379463], [89.7791748, 26.04449081], [89.77960205, 26.04469681], [89.77985382, 26.04486465], [89.78000641, 26.04495049], [89.7802124, 26.04508018], [89.78042603, 26.04512024], [89.78083801, 26.04512787], [89.78119659, 26.04510117], [89.78160858, 26.045084], [89.78197479, 26.04508781], [89.78209686, 26.04510307], [89.78253937, 26.04520798], [89.78272247, 26.04526901], [89.78298187, 26.04545403], [89.78314972, 26.04560852], [89.78348541, 26.04597092], [89.78369904, 26.04627037], [89.78378296, 26.04640007], [89.78383636, 26.0464859], [89.78396606, 26.04668999], [89.78420258, 26.04692268], [89.7843399, 26.04699707], [89.7844162, 26.04707909], [89.78456116, 26.04711342], [89.78448486, 26.04735374], [89.78445435, 26.04756737], [89.78444672, 26.04765892], [89.78488159, 26.0476017], [89.78578949, 26.04755402], [89.78781891, 26.04781342], [89.78822327, 26.04940033], [89.78812408, 26.04984474], [89.78651428, 26.05127907], [89.78625488, 26.05132294], [89.78591156, 26.05136108], [89.78536224, 26.05140686], [89.78465271, 26.0514164], [89.78468323, 26.05194855], [89.78458405, 26.05201149], [89.78453064, 26.05259705], [89.78468323, 26.05262566], [89.78479004, 26.05264854], [89.7846756, 26.05310059], [89.78462982, 26.05347061], [89.78461456, 26.0538311], [89.78462219, 26.05396652], [89.78450012, 26.05395317], [89.78424835, 26.05392647], [89.7841568, 26.05429459], [89.78443909, 26.05434036], [89.78475189, 26.05439377], [89.7846756, 26.05523109], [89.78462219, 26.05577278], [89.7845993, 26.05599594], [89.7846756, 26.05600548], [89.78509521, 26.05605698], [89.78511047, 26.05629349], [89.78516388, 26.05635262], [89.7852478, 26.05697632], [89.78570557, 26.0569458], [89.78570557, 26.05723], [89.78649902, 26.05718231], [89.78656769, 26.05696869], [89.78695679, 26.05709839], [89.7875061, 26.05712509], [89.78796387, 26.05715561], [89.78808594, 26.05685806], [89.78862762, 26.05698776], [89.78910065, 26.057127], [89.7898407, 26.05733871], [89.79026794, 26.0574379], [89.79063416, 26.0574894], [89.79078674, 26.05747223], [89.79092407, 26.05747223], [89.79108429, 26.05741882], [89.7911911, 26.05739403], [89.79135132, 26.05738449], [89.79179382, 26.05743027], [89.79212952, 26.05753136], [89.79237366, 26.05757713], [89.7926178, 26.05761528], [89.79303741, 26.05770683], [89.79341888, 26.05776215], [89.79373932, 26.0578289], [89.79447937, 26.05791473], [89.79447937, 26.05798721], [89.79504395, 26.05809593], [89.79586792, 26.05825424], [89.79576111, 26.05866623], [89.79593658, 26.05875015], [89.79592896, 26.05888939], [89.79594421, 26.05903435], [89.79595184, 26.0592308], [89.79598236, 26.05937004], [89.79592896, 26.05953979], [89.79595947, 26.05974579], [89.79633331, 26.05972672], [89.79671478, 26.05971909], [89.79706573, 26.0596714], [89.79763794, 26.05953217], [89.79769897, 26.05942345], [89.79798126, 26.05935287], [89.79786682, 26.05905151], [89.79815674, 26.05898094], [89.79872131, 26.05966377], [89.7987442, 26.06012535], [89.79873657, 26.06026268], [89.79872131, 26.06040764], [89.79866028, 26.06086731], [89.79846954, 26.06094933], [89.7983017, 26.06154251], [89.79807281, 26.06214523], [89.79795074, 26.06214333], [89.79785919, 26.06249809], [89.79782867, 26.0627594], [89.79772186, 26.06269073], [89.79756165, 26.06262398], [89.79730988, 26.06253052], [89.79727936, 26.06266594], [89.79727173, 26.06285095], [89.79724121, 26.06302071], [89.79721832, 26.06317139], [89.7973175, 26.06336594], [89.79741669, 26.06336021], [89.79759216, 26.06334877], [89.79792786, 26.06333542], [89.79798126, 26.06351089], [89.79815674, 26.06351471], [89.79820251, 26.06358337], [89.79839325, 26.0637207], [89.79847717, 26.06381035], [89.79856873, 26.06397057], [89.79862213, 26.06409264], [89.79853058, 26.06454849], [89.79849243, 26.06487083], [89.7984314, 26.06512642], [89.79803467, 26.06516457], [89.79792786, 26.06506348], [89.79777527, 26.06484985], [89.79769135, 26.06468391], [89.79759979, 26.0644989], [89.79729462, 26.0644455], [89.79698181, 26.06435394], [89.7966156, 26.06435585], [89.79628754, 26.06443405], [89.79603577, 26.0645504], [89.79590607, 26.06460762], [89.7958374, 26.06453705], [89.79548645, 26.06466103], [89.79556274, 26.06487274], [89.79558563, 26.06506157], [89.79560089, 26.06514549], [89.79563904, 26.06541252], [89.79576111, 26.06542397], [89.79579926, 26.06556129], [89.79588318, 26.06555176], [89.79605865, 26.06592751], [89.79637146, 26.06590462], [89.79647064, 26.0658989], [89.79711151, 26.06590271], [89.79709625, 26.06575012], [89.79749298, 26.06574631], [89.79764557, 26.06573105], [89.79789734, 26.06575012], [89.79807281, 26.06579781], [89.79798126, 26.06592751], [89.79788971, 26.06608391], [89.79782867, 26.06615067], [89.79776001, 26.06623077], [89.79756165, 26.06669426], [89.79746246, 26.06694984], [89.79740143, 26.06715012], [89.79728699, 26.06757164], [89.79714203, 26.06835938], [89.79720306, 26.06840515], [89.79706573, 26.06923103], [89.79695892, 26.06961632], [89.79682159, 26.07001686], [89.79675293, 26.07031822], [89.79663086, 26.07093048], [89.79624176, 26.07118607], [89.7959671, 26.07138634], [89.79559326, 26.07174301], [89.79536438, 26.07194519], [89.79518127, 26.07215691], [89.79510498, 26.07232285], [89.79497528, 26.07259941], [89.79489136, 26.07298088], [89.79488373, 26.07323456], [89.79491425, 26.07336235], [89.79493713, 26.07346916], [89.79499054, 26.07357025], [89.79510498, 26.0737133], [89.79547119, 26.07402229], [89.79572296, 26.07424927], [89.79577637, 26.07432556], [89.79538727, 26.07484055], [89.79572296, 26.07649994], [89.795578, 26.07646179], [89.79545593, 26.07693672], [89.79494476, 26.07690239], [89.79476166, 26.07714462], [89.79419708, 26.07692528], [89.79402161, 26.07685661], [89.79371643, 26.07674026], [89.79370117, 26.07641983], [89.79333496, 26.0762558], [89.7931366, 26.07603645], [89.79264069, 26.07580566], [89.79251099, 26.07573891], [89.79211426, 26.07552528], [89.79191589, 26.07541084], [89.79174042, 26.07531357], [89.79133606, 26.07505417], [89.79076385, 26.07525253], [89.79031372, 26.0755291], [89.79031372, 26.07595444], [89.79048157, 26.07631302], [89.79148865, 26.07843971], [89.79244995, 26.08015251], [89.79296875, 26.0806942], [89.79321289, 26.08093643], [89.7935791, 26.08132553], [89.79410553, 26.08190727], [89.79429626, 26.08220863], [89.79451752, 26.08254242], [89.7948761, 26.0832653], [89.79496765, 26.08348656], [89.79499817, 26.08369637], [89.79502106, 26.08378792], [89.79510498, 26.08422852], [89.7951355, 26.08454514], [89.79512024, 26.0850296], [89.79509735, 26.08538437], [89.79496765, 26.08540726], [89.79496002, 26.08597946], [89.79494476, 26.08636856], [89.79486084, 26.08727455], [89.79453278, 26.08723068], [89.79219818, 26.08493805], [89.79190826, 26.08465004], [89.78978729, 26.08218956], [89.78813171, 26.08119011], [89.78588867, 26.08320808], [89.78588867, 26.08335114], [89.78586578, 26.08461761], [89.78542328, 26.08401299], [89.78518677, 26.08364487], [89.7850647, 26.08347511], [89.78453827, 26.08343315], [89.78431702, 26.08341599], [89.78420258, 26.08340645], [89.7832489, 26.08333015], [89.78209686, 26.08324051], [89.78211975, 26.08343697], [89.78121948, 26.08355331], [89.78131104, 26.08384132], [89.78137207, 26.08418274], [89.78148651, 26.08496666], [89.78167725, 26.08497238], [89.78166962, 26.0852375], [89.78165436, 26.08551788], [89.78165436, 26.08577347], [89.7816925, 26.08611679], [89.78170776, 26.08653831], [89.78155518, 26.0873909], [89.78192139, 26.08820343], [89.78256989, 26.08965492], [89.78244781, 26.09026146], [89.78237915, 26.09057426], [89.78243256, 26.090662], [89.78266144, 26.09094238], [89.78270721, 26.09103394], [89.78277588, 26.09127045], [89.78285217, 26.09141922], [89.78296661, 26.09157372], [89.78294373, 26.09165192], [89.78285217, 26.09203911], [89.78278351, 26.09250259], [89.78282928, 26.09278488], [89.78286743, 26.09306526], [89.78291321, 26.09333038], [89.78301239, 26.09367561], [89.7831955, 26.09404373], [89.7833252, 26.09427261], [89.78343964, 26.09448433], [89.78354645, 26.09463501], [89.78374481, 26.0948391], [89.78385925, 26.09483719], [89.78448486, 26.09532928], [89.784729, 26.09549904], [89.78552246, 26.09606743], [89.78596497, 26.09641075], [89.78568268, 26.09712982], [89.78547668, 26.0976429], [89.78526306, 26.09819221], [89.78430939, 26.09880257], [89.78405762, 26.09867477], [89.78385925, 26.0986042], [89.78374481, 26.09856606], [89.783638, 26.09852791], [89.78302002, 26.09839821], [89.78253937, 26.09834099], [89.78217316, 26.09830666], [89.78173065, 26.09830093], [89.78164673, 26.09887886], [89.78156281, 26.09950829], [89.78173065, 26.09965897], [89.78178406, 26.09970856], [89.78208923, 26.09998131], [89.78224945, 26.10013962], [89.78245544, 26.10033417], [89.7828598, 26.10081482], [89.78309631, 26.10106468], [89.78331757, 26.10128021], [89.78357697, 26.10142326], [89.78374481, 26.10149193], [89.78427887, 26.10149956], [89.78439331, 26.10152245], [89.78479004, 26.10150719], [89.78495789, 26.10148811], [89.78529358, 26.1014328], [89.78573608, 26.10133934], [89.7857666, 26.10145569], [89.7857666, 26.10154724], [89.78572083, 26.10173225], [89.7855835, 26.10204506], [89.78553772, 26.10242653], [89.78553009, 26.10271835], [89.7855072, 26.1029129], [89.78530884, 26.10372925], [89.78523254, 26.10386467], [89.78509521, 26.10408211], [89.78466797, 26.10467148], [89.78440094, 26.10505676], [89.78420258, 26.10530663], [89.78411865, 26.10540009], [89.78384399, 26.10560226], [89.78326416, 26.10598755], [89.78289032, 26.10580063], [89.7802887, 26.10451126], [89.77710724, 26.10347176], [89.77410889, 26.10420036], [89.7723999, 26.10549736], [89.77219391, 26.10540581], [89.7718277, 26.10524559], [89.77159119, 26.10514832], [89.77093506, 26.10483932], [89.77056885, 26.10465431], [89.77044678, 26.10468674], [89.77030182, 26.10470009], [89.7701416, 26.1046772], [89.76988983, 26.10461617], [89.7696991, 26.10485649], [89.7695694, 26.10528564], [89.76947784, 26.10560226], [89.76928711, 26.10614204], [89.76909637, 26.10660172], [89.76902771, 26.10678673], [89.76894379, 26.10689926], [89.76870728, 26.10705948], [89.76855469, 26.10735321], [89.76849365, 26.1076622], [89.76837921, 26.10788345], [89.76828003, 26.1080761], [89.7681427, 26.10810089], [89.76803589, 26.10811996], [89.76780701, 26.10816193], [89.76744843, 26.10820198], [89.76686859, 26.10829926], [89.7652359, 26.10783958], [89.76281738, 26.10716057], [89.76104736, 26.10691071], [89.75933838, 26.10880852], [89.75912476, 26.10861588], [89.75879669, 26.10838699], [89.75843048, 26.10817528], [89.75798035, 26.10798836], [89.75760651, 26.10798264], [89.75649261, 26.10891724], [89.75642395, 26.1090126], [89.75634766, 26.10911942], [89.75611115, 26.10946846], [89.75600433, 26.10967445], [89.75588226, 26.11005592], [89.7558136, 26.11015511], [89.7556839, 26.11058617], [89.75557709, 26.11095047], [89.75545502, 26.11136055], [89.75527954, 26.11195564], [89.75521088, 26.11231613], [89.75517273, 26.1127491], [89.75519562, 26.11296463], [89.75525665, 26.11329842], [89.7552948, 26.11368942], [89.75534821, 26.11382866], [89.75539398, 26.11390686], [89.75622559, 26.11441422], [89.75707245, 26.11489868], [89.75778961, 26.11509705], [89.75778961, 26.11539078], [89.75785828, 26.11545372], [89.75803375, 26.11565971], [89.75836182, 26.1160965], [89.75879669, 26.11664963], [89.75914764, 26.11709595], [89.75941467, 26.1173954], [89.75955963, 26.11754417], [89.75974274, 26.11769104], [89.76021576, 26.11811066], [89.76060486, 26.11847115], [89.76074982, 26.1186409], [89.76113129, 26.11915779], [89.76121521, 26.11927223], [89.76138306, 26.11956978], [89.76171875, 26.12016296], [89.76196289, 26.12062263], [89.76216888, 26.12104607], [89.76246643, 26.12142372], [89.76275635, 26.12190628], [89.76307678, 26.12232018], [89.76325226, 26.12256813], [89.76338196, 26.12275887], [89.76379395, 26.12335396], [89.76402283, 26.12366104], [89.76409149, 26.12375641], [89.76439667, 26.12409973], [89.76486206, 26.12458038], [89.76506042, 26.12477493], [89.76515961, 26.12490082], [89.76530457, 26.12512398], [89.76555634, 26.12564278], [89.76564026, 26.12578964], [89.76590729, 26.12640953], [89.76615906, 26.12674904], [89.76615906, 26.1271019], [89.76636505, 26.12752914], [89.76641846, 26.12767029], [89.76643372, 26.12777138], [89.76644897, 26.12805367], [89.76646423, 26.12828445], [89.76647186, 26.1284523], [89.76651001, 26.12883186], [89.76654816, 26.129282], [89.7665329, 26.12981415], [89.76641083, 26.13033676], [89.76641846, 26.13080788], [89.76636505, 26.13098145], [89.76616669, 26.13136864], [89.76597595, 26.13175392], [89.76583862, 26.13202286], [89.76551819, 26.1326046], [89.76532745, 26.13294983], [89.76507568, 26.13337517], [89.76486969, 26.13372612], [89.76480103, 26.13387108], [89.76468658, 26.13419724], [89.76449585, 26.13474846], [89.76430511, 26.13521957], [89.76409149, 26.135746], [89.76386261, 26.1360569], [89.76356506, 26.13647461], [89.76329041, 26.13684654], [89.76319122, 26.13698006], [89.75913239, 26.13837051], [89.7589798, 26.13853264], [89.75862885, 26.13860321], [89.75823212, 26.13874245], [89.75787354, 26.13889885], [89.75759125, 26.13898277], [89.75697327, 26.13909721], [89.75647736, 26.13919067], [89.75602722, 26.13924217], [89.75575256, 26.1392765], [89.75544739, 26.13936615], [89.7550354, 26.13944244], [89.75497437, 26.13920975], [89.75437164, 26.13998604], [89.75411987, 26.14030647], [89.75434113, 26.14287758], [89.75397491, 26.14601326], [89.7537384, 26.14679146], [89.75308228, 26.14848518], [89.75265503, 26.1495018], [89.75213623, 26.15047073], [89.7517395, 26.15120888], [89.75151062, 26.15165901], [89.751297, 26.1519928], [89.75112915, 26.15226746], [89.75086212, 26.1527977], [89.75057983, 26.15316772], [89.75004578, 26.15393257], [89.74978638, 26.15431023], [89.74925232, 26.15512657], [89.74880981, 26.15579414], [89.74856567, 26.15618134], [89.74837494, 26.15642548], [89.74759674, 26.157444], [89.74662781, 26.15813828], [89.74652863, 26.15815735], [89.74593353, 26.1585083], [89.74521637, 26.15890312], [89.7444458, 26.15912056], [89.7437973, 26.15930367], [89.74355316, 26.15938187], [89.74324036, 26.15939522], [89.74297333, 26.15939331], [89.74226379, 26.15929031], [89.74193573, 26.15922546], [89.74160004, 26.15917778], [89.74110413, 26.15912628], [89.7410202, 26.15911293], [89.74073792, 26.15902901], [89.7406311, 26.15901184], [89.74006653, 26.15887451], [89.73973846, 26.15879822], [89.73928833, 26.15872955], [89.73899841, 26.15851212], [89.7390213, 26.15882492], [89.73882294, 26.15915489], [89.73825836, 26.15914345], [89.7374115, 26.15921402], [89.73743439, 26.1587429], [89.73688507, 26.15832329], [89.73639679, 26.15834236], [89.73616028, 26.15870285], [89.73565674, 26.15867424], [89.73509979, 26.15877151], [89.73480988, 26.15823746], [89.73455048, 26.15777397], [89.73419952, 26.15788841], [89.73403931, 26.157938], [89.73369598, 26.15807533], [89.73331451, 26.15812492], [89.73291016, 26.15819359], [89.73281097, 26.15823555], [89.73258972, 26.1582737], [89.73233032, 26.15831947], [89.73197174, 26.15837479], [89.73137665, 26.15832329], [89.73083496, 26.15830612], [89.73027802, 26.15825653], [89.72986603, 26.15818977], [89.72896576, 26.15811157], [89.72852325, 26.15796471], [89.7279892, 26.1577816], [89.72712708, 26.15764999], [89.72642517, 26.15754128], [89.72593689, 26.15748596], [89.72480011, 26.15730476], [89.72452545, 26.15720367], [89.72394562, 26.15698814], [89.72354126, 26.15684128], [89.72310638, 26.15653229], [89.72274017, 26.15626907], [89.72242737, 26.15604401], [89.72216797, 26.15656853], [89.72180176, 26.15629578], [89.72164154, 26.15620613], [89.7203598, 26.15639877], [89.72041321, 26.15724373], [89.72044373, 26.15791893], [89.72045898, 26.15810776], [89.72048187, 26.15844536], [89.72051239, 26.15889359], [89.72045898, 26.159338], [89.72031403, 26.16017342], [89.72015381, 26.16115952], [89.71989441, 26.16233444], [89.71981049, 26.1625824], [89.71961212, 26.16316032], [89.71946716, 26.16356468], [89.71927643, 26.1644001], [89.71912384, 26.16527367], [89.71916199, 26.16551018], [89.71918488, 26.16568565], [89.71923828, 26.16599083], [89.71930695, 26.16640663], [89.72509766, 26.16963005], [89.72509766, 26.17160988], [89.72705078, 26.17387962], [89.73293304, 26.17297173], [89.73375702, 26.17337036], [89.73417664, 26.1749897], [89.73314667, 26.1758709], [89.73023987, 26.17700005], [89.71980286, 26.17793846], [89.71705627, 26.17720985], [89.71161652, 26.1735096], [89.70652008, 26.17313004], [89.70427704, 26.1745491], [89.70253754, 26.17712021], [89.70263672, 26.17755508], [89.70266724, 26.17801094], [89.70269012, 26.17843819], [89.70269012, 26.17887878], [89.7026825, 26.17933273], [89.70269775, 26.17982674], [89.70272827, 26.18026352], [89.70278931, 26.1807003], [89.70280457, 26.18106842], [89.70278931, 26.18141174], [89.70278931, 26.18176651], [89.70269012, 26.18201637], [89.70253754, 26.18229485], [89.70237732, 26.18247795], [89.70223236, 26.18260765], [89.70204926, 26.182724], [89.70188904, 26.18282509], [89.70165253, 26.18297195], [89.70141602, 26.18311691], [89.70110321, 26.18328094], [89.70075989, 26.18341827], [89.70061493, 26.18346405], [89.70020294, 26.18482971], [89.69483948, 26.18907166], [89.69757843, 26.19086075], [89.70184326, 26.18815041], [89.70536804, 26.1880703], [89.70822144, 26.18683815], [89.71073914, 26.18856049], [89.71405029, 26.18935966], [89.71613312, 26.19132805], [89.7181015, 26.19679832], [89.71747589, 26.20012093], [89.71556091, 26.20265007], [89.71163177, 26.20319939], [89.71421814, 26.20597839], [89.7172699, 26.20561028], [89.72062683, 26.20617104], [89.7232132, 26.2053299], [89.72566223, 26.20607948], [89.73132324, 26.21076965], [89.73203278, 26.21228981], [89.73127747, 26.21491051], [89.72438049, 26.21729088], [89.71549988, 26.21478081], [89.70307922, 26.21329117], [89.70024872, 26.21376038], [89.69754791, 26.21594238], [89.69722748, 26.21722984], [89.6995697, 26.21890068], [89.70310211, 26.21730995], [89.70555878, 26.21706009], [89.71022797, 26.21914101], [89.71170807, 26.22774124], [89.7128067, 26.22896957], [89.7181778, 26.23162079], [89.72332001, 26.23292923], [89.7287674, 26.23820114], [89.72357178, 26.24353981], [89.71572113, 26.24637985], [89.71502686, 26.24897194], [89.71652222, 26.25233841], [89.71642303, 26.25526047], [89.71537018, 26.25649071], [89.71138763, 26.25803947], [89.70362091, 26.25697136], [89.7009964, 26.25918961], [89.70067596, 26.26084137], [89.7048111, 26.26990128], [89.70894623, 26.27082062], [89.71154022, 26.26958084], [89.71084595, 26.2645607], [89.71142578, 26.26326942], [89.71734619, 26.259161], [89.72521973, 26.2584095], [89.73227692, 26.26033974], [89.73345184, 26.26250076], [89.7336731, 26.26646042], [89.73745728, 26.271101], [89.72918701, 26.28293991], [89.72109222, 26.28816986], [89.71705627, 26.29305267], [89.71544647, 26.2970295], [89.71568298, 26.30198097], [89.71782684, 26.3057003], [89.72025299, 26.30813026], [89.72276306, 26.30755043], [89.71980286, 26.29863167], [89.72088623, 26.29628944], [89.72344971, 26.29475021], [89.73179626, 26.29290009], [89.74234772, 26.29520988], [89.74606323, 26.29076195], [89.74888611, 26.2894001], [89.75710297, 26.28853035], [89.75865936, 26.28932953], [89.75914001, 26.29259109], [89.75089264, 26.30624008], [89.75054169, 26.32146072], [89.75166321, 26.32216072], [89.75364685, 26.32180023], [89.76196289, 26.3170681], [89.7685318, 26.32380295], [89.77774811, 26.3277607], [89.7808609, 26.33088112], [89.78103638, 26.33584023], [89.77921295, 26.34320259], [89.77906036, 26.3474102], [89.78089142, 26.35217094], [89.78201294, 26.35327911], [89.79032135, 26.35806274], [89.80400085, 26.36234283], [89.8098526, 26.36650085], [89.81256104, 26.36700058], [89.82041931, 26.37062073], [89.81723022, 26.36610031], [89.81266785, 26.36240005], [89.81154633, 26.36071014], [89.81149292, 26.35802078], [89.81362915, 26.35317039], [89.81556702, 26.3514595], [89.82009888, 26.35038185], [89.82118988, 26.35113907], [89.82341003, 26.3552494], [89.82106018, 26.35906982], [89.82705688, 26.36664963], [89.8274231, 26.36981964], [89.82440948, 26.37689018], [89.82559204, 26.37931824], [89.82787323, 26.38112068], [89.83098602, 26.38203049], [89.83402252, 26.38126183], [89.84092712, 26.37775993], [89.84549713, 26.38402939], [89.85125732, 26.38405037], [89.85507202, 26.38203049], [89.85729218, 26.38446045], [89.85315704, 26.39599037], [89.85032654, 26.3982811], [89.84681702, 26.40274048], [89.84606171, 26.39779282], [89.84449768, 26.39435005], [89.84039307, 26.39081955], [89.83058929, 26.39019966], [89.82797241, 26.39347839], [89.82727814, 26.39647293], [89.82946777, 26.40328026], [89.8332901, 26.41229057], [89.83634186, 26.41127014], [89.84484863, 26.4102211], [89.84980774, 26.41420937], [89.84764862, 26.41982269], [89.84778595, 26.42175293], [89.84976196, 26.42225075], [89.85299683, 26.42456055], [89.85520172, 26.43404961], [89.8576889, 26.4381218], [89.86112976, 26.44042015], [89.86949921, 26.44841957], [89.86943054, 26.45728111], [89.87062073, 26.45989037], [89.87020874, 26.46397972], [89.86709595, 26.46581078], [89.86237335, 26.46607018], [89.86102295, 26.47478104], [89.85269165, 26.48777962], [89.85497284, 26.49430275], [89.85560608, 26.5051403], [89.85350037, 26.51723289], [89.85443115, 26.52107811], [89.86183929, 26.53046036], [89.86226654, 26.53729057], [89.86141968, 26.5431881], [89.86461639, 26.54829025], [89.86432648, 26.56077957], [89.86548615, 26.56583977], [89.86499786, 26.57027054], [89.86152649, 26.57456017], [89.86200714, 26.57788277], [89.86987305, 26.57950974], [89.87754822, 26.58424187], [89.8742218, 26.58921242], [89.87211609, 26.5947094], [89.87254333, 26.59757042], [89.87522125, 26.60116959], [89.87663269, 26.60634232], [89.87722778, 26.61305046], [89.87161255, 26.61495972], [89.86183167, 26.61515045], [89.85900116, 26.61721039], [89.85704041, 26.62341118], [89.85729218, 26.63208961], [89.86126709, 26.63555908], [89.87367249, 26.64351082], [89.87583923, 26.64630127], [89.87637329, 26.64949989], [89.87275696, 26.65185928], [89.86805725, 26.65661812], [89.86828613, 26.66076088], [89.86987305, 26.66267014], [89.87052155, 26.66621971], [89.86933899, 26.67094994], [89.86946869, 26.67381096], [89.87148285, 26.67921829], [89.87142944, 26.68353081], [89.86141205, 26.70034981], [89.8600769, 26.70137405], [89.86315155, 26.70065498], [89.86250305, 26.70165253], [89.86555481, 26.70597649], [89.86505127, 26.70776939], [89.86401367, 26.71076202], [89.8625946, 26.71372986], [89.8620224, 26.71652603], [89.86276245, 26.7192688], [89.86349487, 26.72217751], [89.86423492, 26.72541809], [89.86450958, 26.72724724], [89.86429596, 26.72800064], [89.86431885, 26.73056984], [89.86265564, 26.73189735], [89.8602829, 26.73395538], [89.85968781, 26.73447037], [89.8588562, 26.73521805], [89.85977936, 26.73596573], [89.8609848, 26.73638344], [89.86292267, 26.73738289], [89.89745331, 26.72444916], [89.96213531, 26.72386932], [89.96701813, 26.72382545], [89.97540283, 26.72566795], [89.99258423, 26.7294445], [89.99703217, 26.73042297], [90.00608063, 26.73204803], [90.00820923, 26.73243141], [90.00971222, 26.7323494], [90.01288605, 26.73217583], [90.01319122, 26.73215866], [90.01874542, 26.7318573], [90.04924011, 26.73070335], [90.13835144, 26.7532959], [90.18861389, 26.77130318], [90.19459534, 26.77344513], [90.18746185, 26.80699921], [90.20076752, 26.8353653], [90.22745514, 26.85688972], [90.22907257, 26.85819435], [90.23021698, 26.85911751], [90.23403168, 26.8591423], [90.24175262, 26.85918999], [90.24859619, 26.85923195], [90.25405121, 26.85819817], [90.25445557, 26.85811996], [90.25547028, 26.85792923], [90.26498413, 26.85613632], [90.28310394, 26.85271835], [90.30021667, 26.84840584], [90.31504059, 26.85682869], [90.31539154, 26.85703087], [90.322052, 26.86081505], [90.33726501, 26.86945534], [90.34696198, 26.87496376], [90.34778595, 26.87543488], [90.35005951, 26.88862419], [90.35017395, 26.88930511], [90.35644531, 26.90100861], [90.41648102, 26.90470123], [90.42024994, 26.90214539], [90.42390442, 26.89966965], [90.43824768, 26.8899498], [90.46601105, 26.87112999], [90.48187256, 26.86036873], [90.50170135, 26.84691429], [90.5089035, 26.84202766], [90.51459503, 26.83816338], [90.53340912, 26.82538414], [90.54299164, 26.81887627], [90.54585266, 26.81693649], [90.57039642, 26.80870056], [90.5849762, 26.80380821], [90.63389587, 26.79397583], [90.64320374, 26.78033638], [90.64592743, 26.7763443], [90.64685822, 26.77658844], [90.6758194, 26.78416061], [90.6890564, 26.77373314], [90.69345856, 26.77026558], [90.69584656, 26.77008247], [90.71676636, 26.76847839], [90.74058533, 26.7748394], [90.74128723, 26.77502632], [90.74291992, 26.7754631], [90.77682495, 26.77586365], [90.78678894, 26.77598], [90.81661224, 26.77632332], [90.94927216, 26.78741837], [90.95646667, 26.78801727], [90.9577179, 26.78641319], [90.95902252, 26.78475571], [90.95874786, 26.78437805], [90.95667267, 26.78152847], [90.96429443, 26.78355026], [90.97018433, 26.78511238], [90.99160004, 26.79079247], [91.01895905, 26.78665161], [91.02842712, 26.78521919], [91.03859711, 26.78367805], [91.04135895, 26.78416824], [91.046875, 26.7832222], [91.04972076, 26.78280449], [91.05221558, 26.78234673], [91.05541229, 26.78235054], [91.0569458, 26.78391647], [91.0582962, 26.78508186], [91.05979919, 26.78629303], [91.06163025, 26.78802681], [91.06342316, 26.78988838], [91.06498718, 26.79140854], [91.06814575, 26.79434395], [91.06957245, 26.79558945], [91.07261658, 26.79881477], [91.07430267, 26.80040169], [91.07616425, 26.80198479], [91.07801056, 26.80370712], [91.07844543, 26.8041153], [91.08015442, 26.805933], [91.08181763, 26.80748558], [91.08322144, 26.80865097], [91.0843811, 26.8099575], [91.08627319, 26.81155205], [91.08970642, 26.81502342], [91.0909729, 26.81624794], [91.09217834, 26.81755447], [91.09375, 26.81894684], [91.09427643, 26.81938362], [91.09608459, 26.82089233], [91.09745026, 26.82217979], [91.14580536, 26.81115341], [91.16135406, 26.81190109], [91.17836761, 26.81279755], [91.19219208, 26.81358337], [91.22182465, 26.81262016], [91.23683929, 26.81231308], [91.25099945, 26.80817986], [91.26164246, 26.80506897], [91.26284027, 26.80471992], [91.26356506, 26.80450821], [91.27677155, 26.80064774], [91.28185272, 26.79717064], [91.29641724, 26.7871933], [91.327034, 26.78258705], [91.33742523, 26.78123474], [91.35971832, 26.78951836], [91.37564087, 26.79543495], [91.39037323, 26.8159256], [91.3922348, 26.81851387], [91.40431213, 26.83528709], [91.40617371, 26.83787346], [91.40746307, 26.83965874], [91.40844727, 26.83910942], [91.44094849, 26.81533432], [91.4417572, 26.81474304], [91.44831848, 26.81108284], [91.45524597, 26.80727577], [91.46363831, 26.8026638], [91.49494171, 26.79138374], [91.52999115, 26.79682159], [91.53185272, 26.7971096], [91.54429626, 26.79895592], [91.59134674, 26.80500603], [91.60248566, 26.81035042], [91.60370636, 26.81093597], [91.60837555, 26.81317711], [91.62562561, 26.82115173], [91.64424896, 26.81701279], [91.65445709, 26.81474113], [91.68974304, 26.80688667], [91.69015503, 26.80705643], [91.70168304, 26.81181335], [91.70500946, 26.81318665], [91.72063446, 26.81192207], [91.74853516, 26.82628632], [91.76015472, 26.83221817], [91.76118469, 26.83274269], [91.76472473, 26.83455086], [91.78115845, 26.84292603], [91.80227661, 26.85367966], [91.80738831, 26.85614014], [91.81391144, 26.85927963], [91.81642914, 26.8604908], [91.82388306, 26.86437225], [91.83280182, 26.87685966], [91.85913086, 26.91370773], [91.86304474, 26.91418457], [91.87780762, 26.9159832], [91.88223267, 26.91637993], [91.88511658, 26.91671371], [91.89209747, 26.91921425], [91.90158081, 26.91477013], [91.9422226, 26.89573097], [91.95075989, 26.89094353], [91.96385193, 26.88286209], [91.97026062, 26.87055397], [91.97749329, 26.86366272], [91.983078, 26.85833931], [91.99037933, 26.85657501], [92.00010681, 26.85422707], [92.01700592, 26.85014534], [92.03614044, 26.84892273], [92.05222321, 26.84789658], [92.056633, 26.84761429], [92.08629608, 26.85959244], [92.10289001, 26.86755943], [92.10267639, 26.88149643], [92.1129837, 26.89238358], [92.12036896, 26.89030075], [92.12419128, 26.88976097], [92.12953949, 26.89071274], [92.14792633, 26.89088821], [92.16239929, 26.89266014], [92.16882324, 26.89191055], [92.1771698, 26.89248085], [92.19484711, 26.89100075], [92.20935059, 26.89689064], [92.25456238, 26.91222954], [92.26123047, 26.90876961], [92.2651062, 26.9076004], [92.26786804, 26.9050827], [92.27639008, 26.90246964], [92.28148651, 26.9041481], [92.29007721, 26.90546036], [92.30053711, 26.90814018], [92.30374908, 26.90954018], [92.30285645, 26.92420959], [92.3200531, 26.92838097], [92.34677887, 26.93346024], [92.35305023, 26.93556976], [92.36443329, 26.9326992], [92.36728668, 26.93155098], [92.39975739, 26.92627144], [92.41188812, 26.94419098], [92.42576599, 26.94346809], [92.44216919, 26.95502281], [92.44616699, 26.96063995], [92.45957184, 26.96331024], [92.46629333, 26.96306038], [92.48375702, 26.96474075], [92.49063873, 26.96473122], [92.50502014, 26.96677017], [92.51544189, 26.96442032], [92.53176117, 26.9633007], [92.55361176, 26.95907021], [92.58521271, 26.96186256], [92.64546204, 26.98744965], [92.64530945, 26.99561119], [92.64420319, 27.00251007], [92.64463043, 27.01004028], [92.63909912, 27.01853943], [92.65048981, 27.02477837], [92.65702057, 27.03759003], [92.65892792, 27.03852081], [92.68238831, 27.03174019], [92.70231628, 27.02758026], [92.71367645, 27.02609062], [92.72750854, 27.02840042], [92.76909637, 27.033041], [92.78527069, 27.0306797], [92.82441711, 27.0184803], [92.836586, 27.0135498], [92.87243652, 27.00769997], [92.88337708, 27.00234032], [92.88751984, 27.00022125], [92.89028931, 26.99982071], [92.89977264, 26.9962616], [92.91667938, 26.98465157], [92.91494751, 26.96976089], [92.91777039, 26.96424103], [92.92166138, 26.96190834], [92.92640686, 26.96066093], [92.93276978, 26.9569397], [92.95136261, 26.94890976], [92.96161652, 26.94588089], [92.97297668, 26.94082069], [92.98069763, 26.93562126], [92.98271942, 26.93593979], [92.98668671, 26.93383026], [92.99375916, 26.93178749], [92.9957962, 26.93032074], [92.99743652, 26.93034935], [93.01937103, 26.91683006], [93.03820801, 26.91788101], [93.06017303, 26.92118073], [93.06884003, 26.92420959], [93.07636261, 26.91994095], [93.09187317, 26.9155407], [93.10896301, 26.92728043], [93.1842804, 26.93873978], [93.22238922, 26.94914055], [93.26685333, 26.95600128], [93.34793854, 26.96324158], [93.37423706, 26.96038055], [93.39073181, 26.9600296], [93.43666077, 26.95609093], [93.44786835, 26.95415115], [93.46383667, 26.94354057], [93.46810913, 26.93889046], [93.48029327, 26.94017982], [93.48683167, 26.94309044], [93.48935699, 26.93852997], [93.52584076, 26.94863129], [93.54548645, 26.95174026], [93.57079315, 26.95412254], [93.58422089, 26.95264816], [93.59583282, 26.95518112], [93.62449646, 26.96421051], [93.64016724, 26.96478081], [93.65511322, 26.96647835], [93.67578125, 26.97107124], [93.69655609, 26.99237823], [93.69828033, 26.99479103], [93.70095062, 26.99710274], [93.70568085, 27.00368118], [93.70449829, 27.00656128], [93.70556641, 27.00832939], [93.71893311, 27.01922035], [93.73388672, 27.02723122], [93.7425766, 27.02971268], [93.74642944, 27.03240967], [93.76847839, 27.04329109], [93.76819611, 27.0555191], [93.77007294, 27.05558014], [93.77095795, 27.05455017], [93.77178955, 27.0555191], [93.7723999, 27.06230164], [93.77368164, 27.06236076], [93.7754364, 27.0562191], [93.77794647, 27.05277061], [93.77915955, 27.05334282], [93.77913666, 27.05829048], [93.78116608, 27.06081963], [93.78227234, 27.06690025], [93.78321075, 27.06719017], [93.78511047, 27.05835915], [93.78613281, 27.05537033], [93.78742218, 27.05422974], [93.7911911, 27.05456924], [93.79399872, 27.05772972], [93.79709625, 27.0708828], [93.79805756, 27.07094193], [93.79876709, 27.06968117], [93.79942322, 27.06687164], [93.80213165, 27.06176186], [93.80488586, 27.06134987], [93.80854797, 27.06257057], [93.81018829, 27.06814003], [93.81288147, 27.07068062], [93.81571198, 27.06545067], [93.81878662, 27.06493187], [93.82287598, 27.06832123], [93.82457733, 27.07217026], [93.82549286, 27.07212257], [93.82710266, 27.06884956], [93.82824707, 27.06895065], [93.82901001, 27.07212257], [93.83209991, 27.07286835], [93.83502197, 27.07499123], [93.83674622, 27.07821274], [93.83476257, 27.08205032], [93.83436584, 27.0828495], [93.83621216, 27.08647919], [93.8330307, 27.08761024], [93.83132172, 27.09243965], [93.82663727, 27.09938049], [93.82723236, 27.11194038], [93.82549286, 27.1193409], [93.82195282, 27.12203026], [93.81910706, 27.12290192], [93.81495667, 27.12260818], [93.81315613, 27.12376022], [93.81136322, 27.12626839], [93.8138504, 27.12861824], [93.81423187, 27.13082123], [93.81350708, 27.13201141], [93.80818939, 27.13286972], [93.80580902, 27.13475037], [93.80222321, 27.13286018], [93.80024719, 27.13262939], [93.7984314, 27.13439941], [93.79779816, 27.13600922], [93.79824066, 27.13716125], [93.80143738, 27.13791084], [93.80561066, 27.13779068], [93.80680847, 27.14720917], [93.80729675, 27.15014076], [93.80858612, 27.15175056], [93.8170166, 27.15824127], [93.82666016, 27.16937065], [93.82897949, 27.17064285], [93.83699799, 27.17207909], [93.8398819, 27.1734581], [93.84716797, 27.17978096], [93.85746002, 27.19110107], [93.8674469, 27.19884109], [93.88561249, 27.2243824], [93.89097595, 27.23018074], [93.89298248, 27.23097038], [93.90104675, 27.24154091], [93.91889954, 27.25714111], [93.93390656, 27.26834106], [93.93891144, 27.27327919], [93.95652008, 27.29475975], [93.97267151, 27.30834007], [93.9809494, 27.31376839], [93.985672, 27.32057953], [93.99018097, 27.32464981], [93.99603271, 27.32788277], [93.99780273, 27.32785988], [94.00068665, 27.33013916], [94.00000763, 27.33470917], [94.00978851, 27.33889008], [94.02583313, 27.34770012], [94.0300827, 27.34799194], [94.04164124, 27.35329056], [94.04831696, 27.35874939], [94.05483246, 27.36283112], [94.06092834, 27.36355972], [94.0631485, 27.36891174], [94.06864929, 27.37440109], [94.07244873, 27.38301277], [94.08634949, 27.40456009], [94.09329987, 27.41094017], [94.09992218, 27.41391945], [94.10652161, 27.41805077], [94.11708069, 27.43097115], [94.12333679, 27.43498039], [94.13585663, 27.44585991], [94.14080811, 27.44845963], [94.15445709, 27.46046066], [94.16020203, 27.46647072], [94.15873718, 27.47000122], [94.1572113, 27.47804832], [94.16422272, 27.48098946], [94.1679306, 27.48418808], [94.17471313, 27.48407173], [94.18689728, 27.49081039], [94.19124603, 27.49632072], [94.19522858, 27.49745941], [94.21065521, 27.49790382], [94.21232605, 27.4979496], [94.2154007, 27.5031395], [94.22167206, 27.50703049], [94.25905609, 27.52260017], [94.25972748, 27.52349091], [94.26251221, 27.52742958], [94.25686646, 27.54050064], [94.2557373, 27.55076027], [94.25650024, 27.55742836], [94.24060059, 27.57035065], [94.23414612, 27.57146072], [94.22647858, 27.57563019], [94.22547913, 27.5810585], [94.22144318, 27.58791161], [94.22531128, 27.59523964], [94.22505188, 27.59851074], [94.22292328, 27.60074043], [94.21350861, 27.60442162], [94.21111298, 27.61084175], [94.21743774, 27.60900116], [94.22595978, 27.61799049], [94.2350769, 27.63251114], [94.24507141, 27.63586998], [94.24726868, 27.63581085], [94.25006866, 27.63972092], [94.25222778, 27.64093018], [94.25598907, 27.63655281], [94.25907135, 27.6370182], [94.26278687, 27.63602066], [94.26670837, 27.63256073], [94.26716614, 27.62786293], [94.26222229, 27.62451935], [94.25710297, 27.61911964], [94.25408936, 27.61370087], [94.2618866, 27.61009979], [94.27245331, 27.60346985], [94.27520752, 27.59740067], [94.27603149, 27.59334946], [94.28765869, 27.59179115], [94.28848267, 27.59451103], [94.29289246, 27.60036087], [94.29801941, 27.60427094], [94.30164337, 27.59988022], [94.30835724, 27.59558105], [94.31240845, 27.58965111], [94.31970978, 27.59005165], [94.3237381, 27.58716965], [94.32905579, 27.58839035], [94.3381424, 27.58103943], [94.34057617, 27.58344078], [94.34507751, 27.58459091], [94.34884644, 27.57945061], [94.35569763, 27.57738113], [94.36219788, 27.58023071], [94.36749268, 27.5767498], [94.37230682, 27.57926941], [94.37583923, 27.58457756], [94.38043213, 27.58509064], [94.38437653, 27.58646011], [94.38759613, 27.58927917], [94.3948288, 27.58877945], [94.40318298, 27.58719063], [94.42092896, 27.60134125], [94.4310379, 27.60308075], [94.43058777, 27.59646034], [94.43605042, 27.58442116], [94.44238281, 27.57946014], [94.44960785, 27.57504082], [94.45346832, 27.57094002], [94.45622253, 27.56290245], [94.45973969, 27.55771065], [94.46930695, 27.56401253], [94.47915649, 27.57699013], [94.48310852, 27.57720184], [94.4909668, 27.57549286], [94.5, 27.57726479], [94.50022888, 27.57731056], [94.50940704, 27.58407021], [94.51566315, 27.58473015], [94.52628326, 27.59576988], [94.53173065, 27.59692955], [94.53659058, 27.59699059], [94.54641724, 27.60353279], [94.55171204, 27.60404968], [94.55612183, 27.60323906], [94.56389618, 27.6069603], [94.56947327, 27.60635185], [94.5735321, 27.60696983], [94.58185577, 27.61668015], [94.58629608, 27.62010956], [94.59146881, 27.62281036], [94.59577179, 27.6214695], [94.60060883, 27.62193108], [94.6040802, 27.62310028], [94.60938263, 27.62263107], [94.61406708, 27.62574005], [94.62497711, 27.63011932], [94.63069153, 27.62829018], [94.63445282, 27.62877083], [94.6397934, 27.63096046], [94.6452179, 27.63653946], [94.64842224, 27.64207077], [94.66464233, 27.64785957], [94.66911316, 27.65027809], [94.6757431, 27.65065193], [94.68251038, 27.64958954], [94.68699646, 27.65331078], [94.68650818, 27.65714264], [94.68387604, 27.66333961], [94.68940735, 27.66719055], [94.69808197, 27.66710091], [94.7130661, 27.66026115], [94.71663666, 27.6616497], [94.72070313, 27.66999054], [94.72554016, 27.67033958], [94.72767639, 27.66786003], [94.73703003, 27.66564941], [94.74266815, 27.66342163], [94.75592041, 27.66651917], [94.75955963, 27.66843987], [94.76432037, 27.67456055], [94.76693726, 27.68013954], [94.77216339, 27.6839695], [94.77645111, 27.68337822], [94.79099274, 27.6888504], [94.79405975, 27.69322014], [94.79534912, 27.69807816], [94.7975769, 27.69893265], [94.80021667, 27.69709015], [94.81803131, 27.69684029], [94.82126617, 27.6962204], [94.83938599, 27.7035408], [94.84879303, 27.71068192], [94.85357666, 27.73162079], [94.86071777, 27.73338127], [94.86602783, 27.73624039], [94.86086273, 27.73947906], [94.88394165, 27.74205971], [94.93003082, 27.75673103], [94.98703766, 27.77085114], [94.99787903, 27.77655029], [95.01914978, 27.77249908], [95.03121948, 27.77477074], [95.03875732, 27.77773094], [95.04886627, 27.78646088], [95.05182648, 27.7902298], [95.19486237, 27.83444977], [95.23654175, 27.84835052], [95.29254913, 27.86499023], [95.30847168, 27.86782074], [95.31655884, 27.87112999], [95.38433838, 27.84202194], [95.51595306, 27.88178825], [95.52622986, 27.89789963], [95.53302002, 27.90043068], [95.54353333, 27.90232277], [95.54434204, 27.9057827], [95.54206848, 27.91074181], [95.54380035, 27.91345978], [95.56504822, 27.92251968], [95.56626129, 27.93159103], [95.57121277, 27.94238091], [95.58053589, 27.94356155], [95.58866119, 27.94162941], [95.59694672, 27.95112991], [95.60674286, 27.95776939], [95.82588196, 27.97737122], [95.95688629, 27.96912956], [95.97746277, 27.96850014], [95.96520996, 27.9526329], [95.95231628, 27.94184113], [95.95155334, 27.93917084], [95.9523468, 27.93717957], [95.95755005, 27.93708038], [95.95754242, 27.9328804], [95.95381165, 27.93024063], [95.95529938, 27.92682076], [95.95249176, 27.92281914], [95.94351196, 27.91263962], [95.9393158, 27.90982056], [95.9383316, 27.90327072], [95.92864227, 27.9028511], [95.92501068, 27.90094185], [95.92392731, 27.89599991], [95.92855072, 27.89052963], [95.92735291, 27.88726044], [95.92375183, 27.89033127], [95.92127991, 27.8904705], [95.92262268, 27.88618088], [95.91866302, 27.88278008], [95.91400146, 27.88084984], [95.91291809, 27.8781395], [95.91409302, 27.87465096], [95.91137695, 27.87301826], [95.90618134, 27.87722969], [95.90722656, 27.8686409], [95.90055847, 27.86668015], [95.89763641, 27.86746979], [95.89502716, 27.86722183], [95.89422607, 27.86096001], [95.89209747, 27.85704041], [95.87657166, 27.84177017], [95.87372589, 27.83980179], [95.86633301, 27.83846092], [95.85209656, 27.83411026], [95.84599304, 27.83010101], [95.84336853, 27.82147026], [95.8349762, 27.8157711], [95.82894135, 27.81365967], [95.82312775, 27.80924988], [95.81131744, 27.79372025], [95.80757904, 27.78994942], [95.80636597, 27.78358078], [95.8009491, 27.77686119], [95.79538727, 27.77263069], [95.78882599, 27.7650528], [95.78053284, 27.75822067], [95.78777313, 27.74205017], [95.78479767, 27.73978043], [95.7718811, 27.73451042], [95.76267242, 27.73293114], [95.75821686, 27.73110962], [95.75871277, 27.72668076], [95.76304626, 27.72266006], [95.77039337, 27.72002983], [95.77052307, 27.7159996], [95.77262115, 27.71132088], [95.77336121, 27.70535088], [95.77266693, 27.69995117], [95.77455139, 27.69670105], [95.77876282, 27.69439125], [95.79312897, 27.69227028], [95.79647064, 27.68806076], [95.79453278, 27.68419075], [95.78549194, 27.68325996], [95.78044891, 27.67918968], [95.7784729, 27.67234993], [95.77784729, 27.66625977], [95.77922058, 27.66053963], [95.78623199, 27.65566063], [95.79485321, 27.65279961], [95.80145264, 27.6490097], [95.79959106, 27.64296913], [95.79734039, 27.6395607], [95.79741669, 27.63589096], [95.78734589, 27.63229942], [95.78504181, 27.62739944], [95.787117, 27.62340927], [95.79429626, 27.62236977], [95.79606628, 27.61819077], [95.79802704, 27.60783005], [95.80960846, 27.60527039], [95.81682587, 27.60543823], [95.82087708, 27.60472107], [95.82419586, 27.60301018], [95.82025909, 27.59557152], [95.81980896, 27.59028053], [95.82124329, 27.58172035], [95.82772827, 27.58175087], [95.83193207, 27.57888985], [95.83628845, 27.57117844], [95.83989716, 27.56661034], [95.84601593, 27.56799126], [95.85209656, 27.56565094], [95.86235809, 27.55260086], [95.86701965, 27.55109978], [95.87361908, 27.55117035], [95.8813324, 27.55323029], [95.88143921, 27.54583168], [95.87992096, 27.52979088], [95.88080597, 27.52251053], [95.878479, 27.5198307], [95.88179779, 27.51509094], [95.88710785, 27.51127052], [95.88964081, 27.50616837], [95.88604736, 27.50356293], [95.88046265, 27.50110054], [95.87905121, 27.49919128], [95.87915802, 27.49267006], [95.8812561, 27.48742104], [95.87843323, 27.4756012], [95.87625885, 27.47110939], [95.86606598, 27.46902275], [95.86116791, 27.46629906], [95.85945892, 27.46261024], [95.86379242, 27.45203018], [95.85955811, 27.44905281], [95.8551712, 27.44737053], [95.8529129, 27.44475937], [95.84947205, 27.43490982], [95.84934235, 27.43032074], [95.85573578, 27.42766953], [95.85761261, 27.42481995], [95.85795593, 27.420681], [95.86733246, 27.4171505], [95.8666687, 27.41921043], [95.86422729, 27.42131805], [95.8632431, 27.42485809], [95.86490631, 27.4290123], [95.87577057, 27.43535805], [95.88259125, 27.44408035], [95.88865662, 27.44407082], [95.89037323, 27.43967056], [95.88941956, 27.43162918], [95.89002991, 27.42641068], [95.89437866, 27.41828918], [95.89425659, 27.41438293], [95.89187622, 27.4097805], [95.89305878, 27.40604019], [95.90010071, 27.41133118], [95.90612793, 27.42326927], [95.90796661, 27.43264008], [95.91117096, 27.43996048], [95.91684723, 27.4431591], [95.93327332, 27.4466877], [95.94300079, 27.44639015], [95.94989014, 27.44502068], [95.95307159, 27.44345093], [95.95350647, 27.4407711], [95.95052338, 27.4372406], [95.95297241, 27.43328094], [95.95729065, 27.4328804], [95.96105194, 27.42871094], [95.96357727, 27.43548012], [95.96703339, 27.43666077], [95.96803284, 27.42411995], [95.97177887, 27.43037033], [95.97329712, 27.43675041], [95.9777832, 27.43549919], [95.97782898, 27.43229103], [95.98023224, 27.43021965], [95.98092651, 27.42612267], [95.97807312, 27.42533112], [95.97952271, 27.4218502], [95.98945618, 27.4217205], [95.9912262, 27.41939926], [95.99093628, 27.41457176], [95.99459076, 27.41235924], [96.00100708, 27.4034729], [96.00006866, 27.39756966], [96.00205231, 27.39349937], [96.00836945, 27.38721085], [96.01056671, 27.38128281], [96.01494598, 27.37545967], [96.02091217, 27.37125969], [96.01835632, 27.36790085], [96.01319885, 27.36403084], [96.00314331, 27.36445999], [96.00211334, 27.36412811], [95.99697113, 27.36347961], [95.99487305, 27.36024094], [95.99368286, 27.35144043], [95.9773407, 27.34230042], [95.97421265, 27.33936119], [95.97001648, 27.33698082], [95.97228241, 27.33462906], [95.98420715, 27.33434105], [95.9780426, 27.33269119], [95.96871185, 27.33183098], [95.96903229, 27.32840919], [95.96785736, 27.3245697], [95.96260834, 27.32433128], [95.96556854, 27.3216629], [95.96321869, 27.3170681], [95.94056702, 27.30958939], [95.91874695, 27.29922295], [95.91229248, 27.29314041], [95.90643311, 27.29187965], [95.90238953, 27.28783035], [95.90453339, 27.28623962], [95.90428925, 27.27985954], [95.90116119, 27.27638817], [95.89810944, 27.26431084], [95.89396667, 27.26301193], [95.88765717, 27.26332092], [95.88243103, 27.26694107], [95.87760162, 27.26740837], [95.87238312, 27.26691055], [95.86544037, 27.2766819], [95.86084747, 27.27979279], [95.86064148, 27.28342056], [95.86192322, 27.29002953], [95.860466, 27.29421043], [95.85022736, 27.29314995], [95.8379364, 27.28707123], [95.81019592, 27.28092003], [95.80848694, 27.28544044], [95.8065033, 27.28801155], [95.80628967, 27.29174042], [95.80075836, 27.2887001], [95.790802, 27.28545952], [95.78468323, 27.27913094], [95.75701141, 27.27435112], [95.7399292, 27.26988983], [95.73638916, 27.26675034], [95.73188019, 27.26654053], [95.72548676, 27.25922966], [95.72107697, 27.25760078], [95.71549225, 27.25909996], [95.70188141, 27.25564003], [95.69542694, 27.25814819], [95.68441772, 27.25741005], [95.67939758, 27.25616264], [95.67920685, 27.2539196], [95.63700104, 27.23690987], [95.63413239, 27.23981094], [95.61914063, 27.23655128], [95.60735321, 27.23137283], [95.59916687, 27.22961044], [95.59008789, 27.2295208], [95.57788086, 27.24215126], [95.57830048, 27.24714088], [95.57446289, 27.25106049], [95.56326294, 27.25250244], [95.55613708, 27.25436974], [95.55416107, 27.25934029], [95.53481293, 27.27062035], [95.52971649, 27.26906967], [95.52593231, 27.26626015], [95.52046204, 27.26374054], [95.51618195, 27.26863098], [95.51088715, 27.26626968], [95.51064301, 27.2589798], [95.50627899, 27.2546196], [95.49099731, 27.24869919], [95.48722839, 27.24603081], [95.48055267, 27.23233986], [95.47451019, 27.22686958], [95.47389984, 27.22364998], [95.47067261, 27.22321129], [95.46942902, 27.21825981], [95.45970917, 27.2134304], [95.45890045, 27.20956993], [95.46205139, 27.20301056], [95.46581268, 27.19742966], [95.46864319, 27.19050026], [95.46711731, 27.18555069], [95.46366882, 27.18212128], [95.46800995, 27.1722908], [95.46383667, 27.1670208], [95.45870972, 27.16328812], [95.4598999, 27.16041946], [95.46331787, 27.15954018], [95.46507263, 27.15760994], [95.46585083, 27.15480042], [95.46367645, 27.15036011], [95.4610672, 27.14022064], [95.45778656, 27.1356411], [95.45339966, 27.13587952], [95.45075226, 27.13883972], [95.44713593, 27.13833046], [95.44557953, 27.1342907], [95.44098663, 27.13281059], [95.42919159, 27.13405037], [95.42027283, 27.13078117], [95.40631104, 27.11832047], [95.39614868, 27.11446953], [95.38611603, 27.11170959], [95.38546753, 27.10509109], [95.37697601, 27.10218048], [95.37267303, 27.10167122], [95.37365723, 27.1079998], [95.36830139, 27.10736275], [95.36778259, 27.10971069], [95.3706665, 27.11014938], [95.37126923, 27.1114006], [95.36647034, 27.11285019], [95.34860229, 27.10476112], [95.3351059, 27.09592056], [95.32327271, 27.089571], [95.31317902, 27.08674049], [95.30967712, 27.08113098], [95.29662323, 27.07285118], [95.28791809, 27.06632042], [95.27783203, 27.05676842], [95.27944946, 27.05391121], [95.27762604, 27.04977036], [95.27097321, 27.04507065], [95.26669312, 27.04043961], [95.26262665, 27.0410099], [95.25994873, 27.03897285], [95.2607193, 27.03725052], [95.25219727, 27.03191948], [95.24822998, 27.03025246], [95.24371338, 27.03416061], [95.23787689, 27.04322052], [95.23471832, 27.0435791], [95.23091125, 27.04570961], [95.23214722, 27.04292107], [95.2294693, 27.04017067], [95.22598267, 27.04225922], [95.22263336, 27.04089165], [95.21969604, 27.03679085], [95.21380615, 27.03347969], [95.20768738, 27.0347805], [95.20379639, 27.04300117], [95.20094299, 27.04232979], [95.19845581, 27.04442978], [95.19551849, 27.04294968], [95.15450287, 27.00604057], [95.14948273, 26.99983978], [95.14276123, 26.99830055], [95.13698578, 26.99357986], [95.12638092, 26.98690987], [95.11694336, 26.98368073], [95.1135025, 26.97758102], [95.11322021, 26.97232056], [95.11004639, 26.96690941], [95.08686066, 26.95274162], [95.06533813, 26.94819069], [95.05464935, 26.94087982], [95.03804779, 26.93848038], [95.02855682, 26.93251038], [95.02134705, 26.92539978], [95.01657104, 26.92435265], [95.00579071, 26.92486954], [94.99946594, 26.9242897], [94.99305725, 26.92616081], [94.99118805, 26.92292023], [94.99205017, 26.91838837], [94.98944855, 26.91782951], [94.985672, 26.91824913], [94.97966003, 26.92462158], [94.97425842, 26.92760277], [94.97067261, 26.92836189], [94.96794128, 26.93148994], [94.96676636, 26.93618011], [94.96417236, 26.9406414], [94.95728302, 26.94355011], [94.94709015, 26.94020081], [94.94122314, 26.93927193], [94.93855286, 26.93797112], [94.93360138, 26.93853951], [94.92816162, 26.95210075], [94.92376709, 26.95033073], [94.91799164, 26.94514275], [94.91385651, 26.94256973], [94.90882111, 26.94227028], [94.90129089, 26.94034004], [94.89447021, 26.93733025], [94.88622284, 26.93246078], [94.88154602, 26.92671013], [94.86963654, 26.91500854], [94.86862183, 26.90989113], [94.8653183, 26.90690994], [94.85900879, 26.89328003], [94.85334778, 26.88533974], [94.85153198, 26.88134003], [94.84584045, 26.876791], [94.83878326, 26.87400055], [94.8364563, 26.8684597], [94.83226013, 26.86271095], [94.82628632, 26.85931015], [94.82108307, 26.85445976], [94.82173157, 26.84930992], [94.8210907, 26.84486961], [94.81669617, 26.84147072], [94.8154068, 26.83680916], [94.81507111, 26.8300209], [94.81305695, 26.82476044], [94.80918121, 26.82328033], [94.80671692, 26.82122993], [94.79664612, 26.81851959], [94.80161285, 26.81381035], [94.80535889, 26.81219101], [94.80220795, 26.80606079], [94.79496002, 26.80373192], [94.79078674, 26.80145264], [94.7856369, 26.79857063], [94.77308655, 26.79496193], [94.76906586, 26.79109955], [94.76832581, 26.78339767], [94.76235962, 26.77993011], [94.76003265, 26.77662849], [94.75934601, 26.7741375], [94.75637054, 26.7722683], [94.75409698, 26.77431107], [94.75071716, 26.77967072], [94.7457962, 26.78214073], [94.74236298, 26.77864075], [94.74167633, 26.77357101], [94.73773193, 26.76885033], [94.73651123, 26.76741028], [94.73188019, 26.76400948], [94.71969604, 26.75803947], [94.71140289, 26.75282288], [94.69687653, 26.73969078], [94.69148254, 26.73575974], [94.68660736, 26.73258972], [94.66513824, 26.72776031], [94.65853882, 26.72480011], [94.65338898, 26.72363091], [94.64621735, 26.72451019], [94.64028931, 26.72397041], [94.63197327, 26.71965027], [94.6282959, 26.71862984], [94.62271881, 26.71953011], [94.62108612, 26.72117043], [94.62014771, 26.72673988], [94.61740112, 26.73055077], [94.61194611, 26.73265076], [94.61044312, 26.73586082], [94.61006165, 26.74010277], [94.60414886, 26.7392807], [94.59993744, 26.73772049], [94.5951767, 26.72989082], [94.59333038, 26.72613144], [94.60048676, 26.72525978], [94.60318756, 26.7238102], [94.60463715, 26.71985245], [94.60468292, 26.71721077], [94.60372162, 26.71617126], [94.59831238, 26.71994019], [94.59616852, 26.7181797], [94.59501648, 26.71236038], [94.59493256, 26.7065506], [94.59240723, 26.70273018], [94.58898163, 26.70244026], [94.58538818, 26.70331001], [94.58278656, 26.70557976], [94.57150269, 26.69622231], [94.57469177, 26.69102097], [94.57086945, 26.69005966], [94.56608582, 26.68992805], [94.56295013, 26.69063187], [94.56233215, 26.69383049], [94.56472778, 26.70600128], [94.56343842, 26.70737076], [94.56112671, 26.70813942], [94.55467224, 26.70844078], [94.55036926, 26.71017075], [94.5450592, 26.71090126], [94.54087067, 26.70963287], [94.52776337, 26.70128059], [94.52272797, 26.70436859], [94.52009583, 26.70145035], [94.51967621, 26.69460106], [94.51550293, 26.68729973], [94.50994873, 26.68342972], [94.50714111, 26.68297958], [94.50300598, 26.67769051], [94.5, 26.67516708], [94.49826813, 26.67371178], [94.49279785, 26.67225266], [94.48574829, 26.67370033], [94.46794128, 26.66982079], [94.46452332, 26.66751099], [94.46183014, 26.66316032], [94.45857239, 26.65534973], [94.46141815, 26.64809036], [94.46166229, 26.64384079], [94.46446228, 26.64036942], [94.46482086, 26.63871002], [94.46250153, 26.6354599], [94.45681, 26.63664055], [94.45452118, 26.63902092], [94.43448639, 26.62537956], [94.40988159, 26.61643982], [94.40786743, 26.61433029], [94.40857697, 26.6097908], [94.40600586, 26.60193062], [94.41484833, 26.58328056], [94.41188049, 26.5734005], [94.40930939, 26.56899071], [94.40776062, 26.56142807], [94.41057587, 26.56059837], [94.41195679, 26.5584507], [94.40896606, 26.55713081], [94.40609741, 26.55738068], [94.40479279, 26.55523109], [94.40763855, 26.55240059], [94.40795135, 26.54971123], [94.40674591, 26.5482502], [94.40267944, 26.54686165], [94.40133667, 26.54408073], [94.40248108, 26.53880119], [94.39891815, 26.53454971], [94.39945221, 26.53232002], [94.39656067, 26.52973175], [94.39408875, 26.53264046], [94.39141083, 26.53282928], [94.37827301, 26.52526093], [94.37690735, 26.52317047], [94.37806702, 26.51716042], [94.37761688, 26.51312065], [94.36924744, 26.50999069], [94.36445618, 26.5103302], [94.35874939, 26.50914192], [94.35459137, 26.51028061], [94.35111237, 26.50862122], [94.35372162, 26.50481033], [94.35552979, 26.50345039], [94.3535614, 26.50215912], [94.3518219, 26.49920273], [94.35206604, 26.49575043], [94.34963226, 26.49284172], [94.34340668, 26.49003983], [94.33693695, 26.48481941], [94.33259583, 26.48502922], [94.32932281, 26.48384094], [94.32388306, 26.47937965], [94.32478333, 26.47220993], [94.32430267, 26.47070122], [94.31651306, 26.46293068], [94.31347656, 26.46500015], [94.31098175, 26.46606064], [94.30330658, 26.46726036], [94.29392242, 26.4807415], [94.29242706, 26.49003029], [94.29023743, 26.49596977], [94.28723907, 26.50852013], [94.28707123, 26.51496124], [94.28878784, 26.51831818], [94.2890625, 26.52517128], [94.28562164, 26.53409195], [94.28494263, 26.54029083], [94.28562164, 26.54656982], [94.28483582, 26.5553627], [94.28530884, 26.55824089], [94.28890991, 26.55990028], [94.28978729, 26.5641098], [94.2822876, 26.56353951], [94.27674103, 26.5588398], [94.26257324, 26.54394913], [94.25331879, 26.53252983], [94.25205231, 26.52773285], [94.24482727, 26.51692009], [94.23989105, 26.51143074], [94.22891998, 26.50326157], [94.22361755, 26.5005703], [94.21148682, 26.48984909], [94.20936584, 26.48372269], [94.20111847, 26.46990013], [94.18654633, 26.46051025], [94.17575836, 26.43180084], [94.1765213, 26.42807007], [94.17401123, 26.42089081], [94.17684174, 26.41341019], [94.17694092, 26.39956093], [94.17909241, 26.38872147], [94.17404938, 26.37782288], [94.17549133, 26.37445068], [94.17560577, 26.37175941], [94.17357635, 26.36757851], [94.16446686, 26.36012077], [94.1676712, 26.35330963], [94.16938019, 26.35406113], [94.17533875, 26.35513115], [94.17999268, 26.35412025], [94.17928314, 26.35083961], [94.17550659, 26.34421921], [94.17214966, 26.34440994], [94.16452026, 26.33934021], [94.15453339, 26.33998108], [94.14932251, 26.33908081], [94.14671326, 26.33542061], [94.14224243, 26.3360405], [94.14383698, 26.34020042], [94.14264679, 26.34213066], [94.13877106, 26.34155273], [94.13565826, 26.33821869], [94.12397003, 26.3359108], [94.11936951, 26.33370018], [94.11936188, 26.33049011], [94.12872314, 26.32324982], [94.1184082, 26.32271957], [94.11128998, 26.3260498], [94.10804749, 26.32640076], [94.10447693, 26.32204056], [94.10267639, 26.30869102], [94.09807587, 26.30294037], [94.09028625, 26.29713058], [94.08722687, 26.29042053], [94.08444214, 26.28860092], [94.08006287, 26.28881073], [94.07682037, 26.28520012], [94.07781982, 26.27535057], [94.07601929, 26.26923943], [94.07047272, 26.26003075], [94.06463623, 26.26177025], [94.05285645, 26.25579071], [94.0491333, 26.25021172], [94.04421997, 26.23996925], [94.04178619, 26.23389053], [94.03816986, 26.22951126], [94.04046631, 26.22351074], [94.03656006, 26.21771049], [94.03681946, 26.20972061], [94.03573608, 26.20318985], [94.03109741, 26.19939041], [94.02661896, 26.19714928], [94.0219574, 26.19145966], [94.01300049, 26.1862812], [94.00876617, 26.18053055], [94.00480652, 26.17327118], [94.00389862, 26.16938019], [94.00434875, 26.16407013], [93.99965668, 26.15824127], [94.0029068, 26.15133858], [94.00636292, 26.14723969], [94.00522614, 26.14186096], [94.00309753, 26.13902092], [93.99965668, 26.1364994], [93.99627686, 26.13741112], [93.99320221, 26.13739014], [93.99075317, 26.13387108], [93.99326324, 26.13281822], [93.99830627, 26.13097954], [93.99832916, 26.12935829], [93.99661255, 26.1281395], [93.99648285, 26.12236977], [93.99282074, 26.12026978], [93.99124146, 26.11812019], [93.99495697, 26.11570168], [93.99986267, 26.11590958], [94.00213623, 26.11486053], [94.00216675, 26.11137962], [93.99957275, 26.10847092], [93.994133, 26.10608864], [93.99217224, 26.09782982], [93.99249268, 26.09278107], [93.9909668, 26.08949089], [93.98642731, 26.0883007], [93.98602295, 26.08356857], [93.98938751, 26.07411957], [93.99111938, 26.07263947], [93.98081207, 26.0586319], [93.97450256, 26.05216026], [93.97263336, 26.04496193], [93.96588898, 26.04240036], [93.96312714, 26.0333519], [93.96266174, 26.02215958], [93.95838165, 26.01189041], [93.95488739, 26.00732994], [93.95598602, 26.00457001], [93.95897675, 26.00245857], [93.96058655, 25.99700928], [93.95804596, 25.9815712], [93.95600891, 25.97418976], [93.96920776, 25.96084023], [93.97084808, 25.95326042], [93.97109222, 25.94485283], [93.98268127, 25.92626953], [93.97939301, 25.91967964], [93.97197723, 25.9175396], [93.96916962, 25.91142273], [93.96075439, 25.90585518], [93.95983887, 25.90525055], [93.94835663, 25.90120125], [93.94019318, 25.90096092], [93.93463135, 25.8914299], [93.92385101, 25.88980293], [93.91590118, 25.88766289], [93.91382599, 25.88176918], [93.90184021, 25.87103081], [93.89861298, 25.86375046], [93.89340973, 25.86481094], [93.89161682, 25.85864067], [93.8885498, 25.85246086], [93.88273621, 25.84590912], [93.87362671, 25.85091972], [93.86872864, 25.85540962], [93.85170746, 25.86297035], [93.84233856, 25.86260986], [93.83274078, 25.85625076], [93.82430267, 25.84709167], [93.82137299, 25.83240128], [93.81884003, 25.8262291], [93.81157684, 25.82126999], [93.80758667, 25.81633759], [93.79576111, 25.81435013], [93.7913208, 25.8160305], [93.79070282, 25.82080078], [93.78875732, 25.82601929], [93.78734589, 25.82796288], [93.78452301, 25.8357811], [93.78259277, 25.8382206], [93.78108978, 25.84464073], [93.7798233, 25.84630966], [93.78380585, 25.84996033], [93.78296661, 25.85140038], [93.78359222, 25.85392952], [93.78147125, 25.8592701], [93.78528595, 25.86326027], [93.78578186, 25.86689949], [93.79181671, 25.86969185], [93.79064178, 25.8737812], [93.78827667, 25.87572098], [93.7874527, 25.87892914], [93.79145813, 25.89005852], [93.79184723, 25.89491272], [93.79514313, 25.89804077], [93.79573059, 25.90121078], [93.79811096, 25.90628815], [93.79833221, 25.90969276], [93.7963028, 25.91819191], [93.79226685, 25.92251968], [93.79360962, 25.92604065], [93.79321289, 25.93098068], [93.78862, 25.93296051], [93.7932663, 25.93674088], [93.79141998, 25.94005013], [93.79067993, 25.94419098], [93.78940582, 25.94602013], [93.78659821, 25.9474411], [93.7891922, 25.94901085], [93.78942108, 25.95258141], [93.78660583, 25.95423126], [93.78518677, 25.95829964], [93.78028107, 25.96060944], [93.77881622, 25.96325111], [93.77301788, 25.96602058], [93.76954651, 25.95799065], [93.77025604, 25.95350075], [93.76841736, 25.95504951], [93.76278687, 25.95492935], [93.7588501, 25.94869041], [93.74941254, 25.94205093], [93.75202179, 25.9396019], [93.75184631, 25.93637085], [93.75009155, 25.93728065], [93.7364502, 25.93053818], [93.72894287, 25.92839813], [93.71650696, 25.9217205], [93.71250916, 25.92267036], [93.70506287, 25.92127991], [93.69767761, 25.91706848], [93.68768311, 25.90944099], [93.68582916, 25.90493965], [93.69090271, 25.88927078], [93.70643616, 25.85329056], [93.70548248, 25.84863091], [93.70237732, 25.84699059], [93.70363617, 25.84970093], [93.70359039, 25.85350037], [93.69785309, 25.85131264], [93.69377136, 25.84724998], [93.6905365, 25.84756851], [93.6920166, 25.84412956], [93.68250275, 25.84070015], [93.68287659, 25.83575058], [93.67806244, 25.82887077], [93.67256165, 25.82812119], [93.66950989, 25.82879257], [93.66860962, 25.82463074], [93.66082764, 25.82438087], [93.65673828, 25.82635117], [93.65235901, 25.82282066], [93.64849091, 25.82397079], [93.64435577, 25.81957054], [93.64099884, 25.81792068], [93.64029694, 25.81343079], [93.63611603, 25.81368065], [93.63405609, 25.80997086], [93.63334656, 25.80524063], [93.6289978, 25.80439949], [93.62979889, 25.79998016], [93.62753296, 25.79862976], [93.62695313, 25.79160118], [93.62381744, 25.79042816], [93.6211319, 25.78523064], [93.62355804, 25.78392029], [93.62232971, 25.77983093], [93.61141205, 25.77649117], [93.60807037, 25.77687073], [93.60571289, 25.77263069], [93.60556793, 25.76745987], [93.60275269, 25.77082062], [93.5983429, 25.76836014], [93.59371185, 25.76428986], [93.59266663, 25.76624107], [93.58822632, 25.76815033], [93.58712006, 25.76555061], [93.58718872, 25.75945091], [93.58377075, 25.75774956], [93.57324982, 25.76079941], [93.57382202, 25.75966072], [93.57341766, 25.75661087], [93.56925201, 25.7550106], [93.57006073, 25.7517395], [93.56548309, 25.74134064], [93.56194305, 25.74094963], [93.55626678, 25.7419281], [93.55692291, 25.73773956], [93.54988098, 25.73244095], [93.54669952, 25.73447037], [93.54483795, 25.72697067], [93.54619598, 25.72151947], [93.5497818, 25.71897125], [93.54881287, 25.7147007], [93.54592896, 25.71018982], [93.54441833, 25.70590019], [93.54355621, 25.70170021], [93.53797913, 25.70319939], [93.53149414, 25.69400597], [93.53057098, 25.69269943], [93.52855682, 25.69376945], [93.52593994, 25.6996727], [93.52272797, 25.69320107], [93.51683807, 25.6880703], [93.51938629, 25.68597031], [93.52028656, 25.68367004], [93.51019287, 25.67102051], [93.50829315, 25.66681099], [93.50208282, 25.66201973], [93.49991608, 25.65652084], [93.49394226, 25.65526009], [93.49019623, 25.65596962], [93.49072266, 25.65343857], [93.48721313, 25.65047073], [93.4835968, 25.6517601], [93.48335266, 25.64576912], [93.47593689, 25.64798927], [93.47477722, 25.64429092], [93.46852875, 25.64376068], [93.46556854, 25.64419174], [93.46070099, 25.64154816], [93.45713806, 25.64059067], [93.45860291, 25.6384201], [93.46121979, 25.6365509], [93.46195984, 25.63339043], [93.45935822, 25.63312912], [93.45198059, 25.63747978], [93.44993591, 25.63493156], [93.4467926, 25.63881111], [93.44439697, 25.63804245], [93.44152069, 25.63478088], [93.4391861, 25.63439941], [93.43908691, 25.63233948], [93.43418121, 25.62986946], [93.43102264, 25.62920189], [93.42753601, 25.63145828], [93.42247009, 25.62226105], [93.41829681, 25.62105942], [93.41487122, 25.61664009], [93.41677856, 25.61488914], [93.41227722, 25.61367989], [93.40904999, 25.61169052], [93.40763855, 25.60942078], [93.40722656, 25.60649109], [93.40963745, 25.60410118], [93.40924835, 25.60041046], [93.40683746, 25.59647942], [93.40019989, 25.59628105], [93.3900528, 25.59472084], [93.39063263, 25.58909988], [93.38240051, 25.58475113], [93.38311005, 25.58279991], [93.38503265, 25.58119965], [93.38474274, 25.57792091], [93.38269806, 25.5761795], [93.37648773, 25.57731056], [93.37683868, 25.57374001], [93.37599182, 25.57104111], [93.37342072, 25.56917191], [93.36943817, 25.57025909], [93.36515808, 25.56976128], [93.36598206, 25.56326103], [93.36418152, 25.56064987], [93.36070251, 25.56043816], [93.35439301, 25.56520081], [93.34831238, 25.56321907], [93.34546661, 25.56112099], [93.34126282, 25.55485916], [93.33338165, 25.54902077], [93.33174133, 25.54681015], [93.33574677, 25.54541016], [93.34039307, 25.53729057], [93.3445816, 25.53607941], [93.34922791, 25.53832817], [93.3523407, 25.53757095], [93.35016632, 25.53367043], [93.35417938, 25.53119087], [93.35756683, 25.52766991], [93.36004639, 25.5203228], [93.36472321, 25.51616859], [93.36682129, 25.5128727], [93.36502075, 25.51013947], [93.36689758, 25.50786972], [93.37114716, 25.50514984], [93.37181854, 25.50113106], [93.38304138, 25.49756813], [93.3863678, 25.49335098], [93.38710022, 25.49031067], [93.39050293, 25.48562813], [93.39131165, 25.48143005], [93.39103699, 25.4780426], [93.39190674, 25.4742012], [93.39041901, 25.46916962], [93.3959198, 25.46412086], [93.40291595, 25.45918274], [93.41710663, 25.45279121], [93.42201996, 25.45479965], [93.42751312, 25.45526123], [93.43495941, 25.45477295], [93.44359589, 25.45060921], [93.45687103, 25.44194984], [93.46186829, 25.4346981], [93.46514893, 25.42340279], [93.46540833, 25.41587067], [93.46325684, 25.41096115], [93.46718597, 25.40306091], [93.47393799, 25.39311028], [93.47728729, 25.38600922], [93.47821808, 25.37988281], [93.46626282, 25.36173058], [93.46231842, 25.35886955], [93.45374298, 25.34811974], [93.45188904, 25.3441906], [93.45790863, 25.34091949], [93.46193695, 25.33658981], [93.45796967, 25.33005142], [93.45670319, 25.32526016], [93.46312714, 25.31986046], [93.46797943, 25.31381035], [93.47402191, 25.3092804], [93.46559143, 25.29905128], [93.45996857, 25.29473114], [93.45197296, 25.29474831], [93.44481659, 25.29231071], [93.43863678, 25.28655052], [93.42642975, 25.28106117], [93.42331696, 25.27791023], [93.42330933, 25.27216148], [93.4207077, 25.26626015], [93.41205597, 25.26345062], [93.40634155, 25.26408005], [93.40357208, 25.26307106], [93.39459229, 25.25029945], [93.38871765, 25.24592018], [93.38710022, 25.24239159], [93.38762665, 25.23204041], [93.38551331, 25.22855759], [93.38479614, 25.2257309], [93.38198853, 25.22386932], [93.37950134, 25.22079086], [93.3780899, 25.21610069], [93.36958313, 25.20806122], [93.37056732, 25.20359039], [93.3685379, 25.20005035], [93.36222076, 25.19560814], [93.36081696, 25.19195938], [93.35307312, 25.18180084], [93.34915161, 25.16673088], [93.3473587, 25.16389084], [93.34883881, 25.15717125], [93.34855652, 25.15349007], [93.35101318, 25.14454079], [93.34686279, 25.13770103], [93.34889984, 25.13479042], [93.34607697, 25.12986946], [93.3470459, 25.12746048], [93.34921265, 25.12540817], [93.34644318, 25.12508965], [93.34436035, 25.12133026], [93.34435272, 25.1161499], [93.34046173, 25.11441994], [93.33917236, 25.10640907], [93.33577728, 25.09584045], [93.32950592, 25.09449959], [93.32363129, 25.09167099], [93.32234192, 25.08838081], [93.31272125, 25.07795906], [93.31079102, 25.07262993], [93.30879211, 25.07059288], [93.30607605, 25.0644207], [93.30892944, 25.05852127], [93.30425262, 25.05603027], [93.30459595, 25.04799271], [93.30245972, 25.04818916], [93.30240631, 25.05194092], [93.30008698, 25.05260086], [93.29933929, 25.05046082], [93.29698181, 25.04767036], [93.29189301, 25.04709053], [93.28687286, 25.04680061], [93.28449249, 25.05154991], [93.26818085, 25.04968071], [93.26779938, 25.04880905], [93.26946259, 25.04659081], [93.26835632, 25.04409027], [93.26291656, 25.0418396], [93.26391602, 25.03890991], [93.2638092, 25.0359211], [93.25984955, 25.03207016], [93.2556076, 25.0286808], [93.25836945, 25.02519989], [93.25778961, 25.02174187], [93.25382996, 25.02135086], [93.24884033, 25.01880074], [93.25171661, 25.01601982], [93.24916077, 25.01316071], [93.24669647, 25.00416756], [93.24694824, 25.00363159], [93.24746704, 25.00328064], [93.24807739, 25.00303078], [93.24868774, 25.00290108], [93.24935913, 25.00287247], [93.25, 25.00295067], [93.25064087, 25.00316048], [93.25121307, 25.00348091], [93.2518158, 25.00418091], [93.253479, 25.00637054], [93.25521088, 25.00420952], [93.25533295, 25.00364113], [93.25580597, 25.00325966], [93.2564621, 25.00311089], [93.25710297, 25.00319099], [93.2576828, 25.00350189], [93.25800323, 25.00420952], [93.25990295, 25.00645065], [93.26245117, 25.00602913], [93.26332092, 25.00423813], [93.26143646, 25.00092125], [93.2571106, 25.00094032], [93.25567627, 25.00220108], [93.25562286, 24.99971008], [93.25705719, 24.99847031], [93.25695801, 24.99602127], [93.25525665, 24.99240112], [93.25202179, 24.98880959], [93.25325775, 24.98637009], [93.25302124, 24.98266029], [93.25152588, 24.98142052], [93.25432587, 24.97891998], [93.25287628, 24.97514915], [93.2529068, 24.97262955], [93.25871277, 24.97265053], [93.263237, 24.96637917], [93.26332855, 24.96388054], [93.2605896, 24.95887184], [93.26082611, 24.95387077], [93.26241302, 24.95137024], [93.25950623, 24.9513607], [93.25354004, 24.95508957], [93.24923706, 24.95508003], [93.24938965, 24.95259285], [93.25092316, 24.95009995], [93.25110626, 24.94634819], [93.25411987, 24.94261932], [93.24983978, 24.94260025], [93.24693298, 24.94384956], [93.24407959, 24.94384003], [93.24131775, 24.94133949], [93.2399826, 24.93884277], [93.24003601, 24.93758011], [93.24143982, 24.93758965], [93.24707794, 24.94009972], [93.24849701, 24.94009972], [93.24720001, 24.93634033], [93.24304962, 24.93132973], [93.24450684, 24.93008041], [93.25019836, 24.93008041], [93.25325775, 24.91883087], [93.25045776, 24.91506195], [93.24185944, 24.91504097], [93.24043274, 24.91628075], [93.23899078, 24.91502953], [93.24188995, 24.91127014], [93.24336243, 24.90750122], [93.24337769, 24.90374184], [93.24195099, 24.90122032], [93.23622131, 24.90245056], [93.23338318, 24.89869118], [93.23338318, 24.89491081], [93.23049164, 24.89490128], [93.23483276, 24.88989067], [93.23339081, 24.88484955], [93.22908783, 24.88484001], [93.22621918, 24.88106918], [93.22908783, 24.87730026], [93.22480774, 24.87478065], [93.22194672, 24.87099266], [93.21906281, 24.86972046], [93.21618652, 24.86469078], [93.2142868, 24.86194992], [93.21013641, 24.85904121], [93.20870209, 24.85653114], [93.20584106, 24.85526085], [93.20007324, 24.85775948], [93.19719696, 24.85649109], [93.19864655, 24.8527298], [93.20152283, 24.85021973], [93.20155334, 24.84394073], [93.19580078, 24.84644127], [93.19438171, 24.84391975], [93.19727325, 24.84016037], [93.19869995, 24.84016037], [93.20012665, 24.84143066], [93.20155334, 24.84017181], [93.19870758, 24.83638954], [93.1958313, 24.83764076], [93.19438934, 24.83764076], [93.19297028, 24.83638191], [93.19297791, 24.83386993], [93.19728851, 24.83388138], [93.19300079, 24.82632065], [93.19159698, 24.82256126], [93.19590759, 24.8162899], [93.19877625, 24.81504059], [93.19735718, 24.81126022], [93.19449615, 24.80875015], [93.19307709, 24.80623055], [93.19020081, 24.80622101], [93.18589783, 24.80495071], [93.18158722, 24.80493927], [93.18017578, 24.80241966], [93.18017578, 24.79865074], [93.17875671, 24.79614067], [93.1772995, 24.79611969], [93.1758728, 24.79738808], [93.17442322, 24.80367088], [93.16867828, 24.80112839], [93.16581726, 24.79861069], [93.16153717, 24.79734039], [93.15724182, 24.79231071], [93.15294647, 24.78977966], [93.15293121, 24.79353905], [93.15148163, 24.79605103], [93.14861298, 24.7985611], [93.14428711, 24.79980087], [93.14285278, 24.80105972], [93.13994598, 24.80480957], [93.13706207, 24.81109047], [93.13134003, 24.80604172], [93.12700653, 24.80854034], [93.12127686, 24.80853081], [93.11984253, 24.81102943], [93.12269592, 24.8148098], [93.12267303, 24.81982994], [93.11979675, 24.81731033], [93.11122131, 24.81226158], [93.10978699, 24.80974007], [93.11270142, 24.80220985], [93.10845947, 24.7908802], [93.10558319, 24.78837013], [93.10562897, 24.78460121], [93.10706329, 24.78334045], [93.10132599, 24.77831078], [93.10280609, 24.77329063], [93.10566711, 24.76953125], [93.10427856, 24.76324081], [93.10002899, 24.75444031], [93.10003662, 24.75066948], [93.10147095, 24.74941063], [93.09864044, 24.74438095], [93.10150146, 24.74188042], [93.10293579, 24.74315071], [93.10292053, 24.74690056], [93.10579681, 24.74566078], [93.1072464, 24.74189949], [93.10441589, 24.73686981], [93.09725952, 24.73180962], [93.09729004, 24.72805023], [93.09442902, 24.7242794], [93.09298706, 24.72426033], [93.09443665, 24.72050858], [93.09303284, 24.71548271], [93.08878326, 24.70919037], [93.0786972, 24.71417046], [93.0758667, 24.71039009], [93.08020782, 24.70414162], [93.08306885, 24.70164108], [93.08452606, 24.69787025], [93.09028625, 24.69286919], [93.09319305, 24.68785286], [93.09320068, 24.68408012], [93.09179688, 24.68032074], [93.09179688, 24.67781067], [93.09324646, 24.67654991], [93.09754181, 24.67782021], [93.1018219, 24.68035126], [93.10469055, 24.67910004], [93.10470581, 24.67534256], [93.103302, 24.67156029], [93.09903717, 24.66653061], [93.09763336, 24.66276169], [93.09765625, 24.6590004], [93.09626007, 24.6564827], [93.09628296, 24.6527195], [93.08912659, 24.65270996], [93.08625793, 24.65143967], [93.0848465, 24.64767075], [93.08930206, 24.63389015], [93.08938599, 24.62763023], [93.08220673, 24.62760162], [93.07935333, 24.62634087], [93.079422, 24.62132263], [93.08233643, 24.61758041], [93.08673096, 24.61382103], [93.08676147, 24.61133003], [93.07678223, 24.60377121], [93.07538605, 24.60000038], [93.07541656, 24.59622955], [93.07981873, 24.59250069], [93.08854675, 24.59003067], [93.09866333, 24.59134293], [93.10444641, 24.58760262], [93.10675049, 24.58395958], [93.10697937, 24.58356094], [93.10447693, 24.58257294], [93.09726715, 24.58254051], [93.09622955, 24.58022118], [93.08714294, 24.57118034], [93.07845306, 24.57491112], [93.07122803, 24.57613182], [93.06111908, 24.57483292], [93.07269287, 24.56109047], [93.0655365, 24.54726982], [93.06121826, 24.55477905], [93.05268097, 24.5447197], [93.05130005, 24.53718948], [93.04846954, 24.53091049], [93.05282593, 24.52466965], [93.05282593, 24.51964951], [93.04141998, 24.51459122], [93.04001617, 24.51081085], [93.04432678, 24.50580025], [93.0357666, 24.49694824], [93.04572296, 24.48181915], [93.04852295, 24.47548294], [93.04825592, 24.46396065], [93.03790283, 24.46115112], [93.03674316, 24.44394112], [93.03215027, 24.42885971], [93.03932953, 24.41756821], [93.03916931, 24.41113091], [93.02921295, 24.40633965], [93.01599121, 24.40253067], [93.00889587, 24.40537071], [93.00644684, 24.41193008], [93.00049591, 24.40327072], [92.99804688, 24.40157127], [92.99534607, 24.40195084], [92.99192047, 24.40549278], [92.98832703, 24.40764999], [92.98542786, 24.40756035], [92.98026276, 24.40969086], [92.97564697, 24.40776062], [92.97083282, 24.40121269], [92.96032715, 24.39588165], [92.95813751, 24.39805031], [92.95469666, 24.40388107], [92.95388794, 24.40462112], [92.95124817, 24.40483093], [92.94415283, 24.40183258], [92.94055176, 24.40105057], [92.93855286, 24.39902115], [92.93773651, 24.39670944], [92.93570709, 24.39554024], [92.92765045, 24.39862823], [92.92537689, 24.40221977], [92.92366028, 24.40261078], [92.92259979, 24.40415955], [92.92339325, 24.40571976], [92.91153717, 24.41290092], [92.90930939, 24.40316963], [92.9057312, 24.3990593], [92.90587616, 24.39537048], [92.90516663, 24.39445114], [92.90097809, 24.39343071], [92.8963623, 24.39430046], [92.89438629, 24.39530945], [92.89173126, 24.40179062], [92.89077759, 24.40229034], [92.88800812, 24.4016304], [92.88424683, 24.40303993], [92.87819672, 24.39888954], [92.87386322, 24.39725113], [92.87178802, 24.39705086], [92.86289978, 24.39949989], [92.85906219, 24.3984108], [92.85447693, 24.39400101], [92.85164642, 24.39237022], [92.84909058, 24.38613129], [92.84690857, 24.38229942], [92.84427643, 24.37986946], [92.8396225, 24.38080025], [92.83270264, 24.37636948], [92.82898712, 24.37776947], [92.82816315, 24.37931061], [92.82826233, 24.38557816], [92.82541656, 24.38842964], [92.82504272, 24.39049149], [92.82659912, 24.39355278], [92.83167267, 24.39934158], [92.83136749, 24.40050125], [92.8303299, 24.40175056], [92.82479095, 24.40418053], [92.82112885, 24.40678024], [92.81832886, 24.41272926], [92.81645203, 24.41225052], [92.8111496, 24.41364288], [92.81140137, 24.41537285], [92.80944061, 24.4152317], [92.80887604, 24.4168911], [92.80948639, 24.41930008], [92.80715942, 24.41986275], [92.80370331, 24.41879082], [92.80079651, 24.41905022], [92.80004883, 24.42146111], [92.80381775, 24.42172241], [92.80425262, 24.4229908], [92.80284882, 24.42728043], [92.80031586, 24.4319706], [92.7977829, 24.43470955], [92.79390717, 24.4440403], [92.78987885, 24.45607948], [92.78624725, 24.4637394], [92.78437805, 24.47120285], [92.78222656, 24.47480011], [92.77913666, 24.48649979], [92.76519775, 24.52084923], [92.76451111, 24.51883125], [92.75918579, 24.51176071], [92.75364685, 24.50704193], [92.75450134, 24.50111961], [92.75132751, 24.49436951], [92.7507782, 24.49149132], [92.74884033, 24.48854065], [92.74360657, 24.47462845], [92.73053741, 24.45275116], [92.72376251, 24.43594933], [92.71813965, 24.41621971], [92.71511841, 24.41452026], [92.71411896, 24.41296005], [92.71420288, 24.41036987], [92.71508789, 24.40876961], [92.71412659, 24.40777969], [92.71421814, 24.40532112], [92.70742035, 24.39241028], [92.70745087, 24.38701057], [92.70343781, 24.38380051], [92.70410919, 24.3762207], [92.70240784, 24.3752327], [92.69827271, 24.37496185], [92.69687653, 24.37400055], [92.69500732, 24.36956978], [92.69325256, 24.36782074], [92.69420624, 24.36495972], [92.69391632, 24.36363029], [92.69177246, 24.36216927], [92.69167328, 24.35642052], [92.6906662, 24.35480118], [92.68799591, 24.35201073], [92.684021, 24.34988976], [92.68379974, 24.34748077], [92.67964172, 24.34778023], [92.6747818, 24.34980011], [92.66699982, 24.34560966], [92.66525269, 24.34521103], [92.66410828, 24.34674072], [92.6632309, 24.34379959], [92.6622467, 24.3434391], [92.66072083, 24.34514999], [92.65847015, 24.34346008], [92.65751648, 24.34350967], [92.65759277, 24.34155083], [92.65645599, 24.33912086], [92.65239716, 24.33529091], [92.65203857, 24.33286095], [92.65184021, 24.33033943], [92.6493988, 24.33082008], [92.64978027, 24.32922173], [92.64904022, 24.32875061], [92.64524841, 24.33181], [92.64594269, 24.32923126], [92.6450119, 24.32767105], [92.64099121, 24.32871056], [92.63983917, 24.32973099], [92.63925934, 24.33175087], [92.63668823, 24.33269119], [92.63654327, 24.33423805], [92.638237, 24.33443069], [92.6377182, 24.33551979], [92.6359024, 24.33574104], [92.63063812, 24.33337021], [92.6261673, 24.33447266], [92.62428284, 24.33265114], [92.62335205, 24.33077049], [92.62310028, 24.32028961], [92.61943817, 24.31150818], [92.61963654, 24.30846024], [92.61802673, 24.30435944], [92.61830902, 24.29970932], [92.61678314, 24.29123116], [92.61723328, 24.28906059], [92.6190567, 24.28787041], [92.61940002, 24.2867794], [92.61904144, 24.28132057], [92.61682129, 24.27531052], [92.61576843, 24.2705307], [92.61550903, 24.26362038], [92.61308289, 24.25583839], [92.61158752, 24.2533493], [92.60795593, 24.25008011], [92.60595703, 24.24920082], [92.59596252, 24.24930954], [92.59356689, 24.24858856], [92.59140015, 24.24598122], [92.5880127, 24.2448616], [92.58184052, 24.24535942], [92.56455994, 24.25008965], [92.55893707, 24.24789047], [92.55063629, 24.2458992], [92.54882812, 24.24323082], [92.54709625, 24.23769951], [92.54693604, 24.23476028], [92.5477829, 24.23188972], [92.54738617, 24.2244091], [92.54574585, 24.21990013], [92.54223633, 24.21417809], [92.54242706, 24.21062088], [92.54147339, 24.20622826], [92.53726959, 24.201931], [92.53639984, 24.19989967], [92.53781891, 24.19647026], [92.53147888, 24.18346024], [92.53346252, 24.18083191], [92.53289032, 24.18053055], [92.53151703, 24.17741966], [92.52990723, 24.17641068], [92.52966309, 24.17480087], [92.52539825, 24.17292976], [92.52175903, 24.17292976], [92.51759338, 24.1762104], [92.51512909, 24.17548752], [92.51357269, 24.17358017], [92.5147934, 24.17020035], [92.51373291, 24.16926003], [92.50863647, 24.1692009], [92.51200104, 24.16481972], [92.51283264, 24.16257858], [92.50953674, 24.16288948], [92.50678253, 24.16682053], [92.50488281, 24.16731071], [92.50325775, 24.16666985], [92.50245667, 24.16211128], [92.50013733, 24.16052055], [92.49475861, 24.15994072], [92.48808289, 24.16221809], [92.48586273, 24.16220093], [92.48493958, 24.16138077], [92.48490143, 24.15930939], [92.48396301, 24.15814018], [92.48264313, 24.15709114], [92.48118591, 24.1570797], [92.48355865, 24.15393066], [92.48293304, 24.1527195], [92.48065948, 24.15229988], [92.48062897, 24.15011024], [92.47875214, 24.14871025], [92.48149872, 24.14294052], [92.48087311, 24.14132118], [92.47960663, 24.14089966], [92.474823, 24.14291], [92.47332001, 24.14203072], [92.47335052, 24.13996124], [92.46858978, 24.13800049], [92.46682739, 24.13504028], [92.4659729, 24.13475037], [92.46483612, 24.13663101], [92.4630661, 24.13636971], [92.45722198, 24.14350128], [92.45063019, 24.14369011], [92.4438858, 24.15309906], [92.44182587, 24.1528511], [92.43875885, 24.15125084], [92.43743134, 24.15135002], [92.43656921, 24.15242958], [92.43522644, 24.16257858], [92.43814087, 24.16913033], [92.43775177, 24.1704998], [92.43445587, 24.17414093], [92.43419647, 24.18138123], [92.43321228, 24.1832695], [92.42214966, 24.18852997], [92.41897583, 24.19436073], [92.41971588, 24.20247078], [92.41822052, 24.2109108], [92.42018127, 24.21788979], [92.41851807, 24.22164917], [92.42005157, 24.23520279], [92.42253113, 24.24817085], [92.42237854, 24.25311089], [92.4164505, 24.25342941], [92.40683746, 24.25193977], [92.39570618, 24.25252914], [92.37652588, 24.25131035], [92.31407166, 24.25260162], [92.3105011, 24.2513485], [92.30349731, 24.25269127], [92.29668427, 24.25174141], [92.29660797, 24.25172997], [92.29187012, 24.25128174], [92.28491211, 24.25205231], [92.28478241, 24.25206757], [92.25970459, 24.25048828], [92.25958252, 24.25049019], [92.24047852, 24.25067139], [92.21289063, 24.24932861], [92.26409912, 24.36214828], [92.26415253, 24.36226082], [92.26812744, 24.36730957], [92.2677002, 24.37329102], [92.26830292, 24.3747921], [92.27225494, 24.37768936], [92.27246857, 24.37928009], [92.27187347, 24.38003349], [92.2698822, 24.38219833], [92.26994324, 24.38228989], [92.2726593, 24.38622284], [92.27270508, 24.3862915], [92.27308655, 24.38845062], [92.27050781, 24.39093018], [92.26989746, 24.39489746], [92.26428223, 24.39770508], [92.26267242, 24.40482903], [92.26264954, 24.40491676], [92.26330566, 24.40808105], [92.26268005, 24.40981102], [92.25927734, 24.41351318], [92.25863647, 24.41464615], [92.25595856, 24.41897964], [92.25747681, 24.43251991], [92.25653076, 24.4362793], [92.25632477, 24.4364109], [92.23931885, 24.44732666], [92.23606873, 24.45027161], [92.23593903, 24.45378113], [92.23506927, 24.45643234], [92.2322998, 24.45849609], [92.23114777, 24.46041489], [92.23108673, 24.46051025], [92.23109436, 24.46081352], [92.23117065, 24.46544075], [92.22895813, 24.47200203], [92.22891998, 24.47210121], [92.23029327, 24.4800396], [92.23384094, 24.48471069], [92.23950195, 24.4899292], [92.23660278, 24.49282265], [92.23632813, 24.49432373], [92.23615265, 24.49484444], [92.23547363, 24.49688721], [92.23510742, 24.49829102], [92.23468018, 24.49932861], [92.23426819, 24.5004406], [92.23099518, 24.50409126], [92.23094177, 24.50222969], [92.230896, 24.49969482], [92.22148132, 24.50151062], [92.22113037, 24.50292969], [92.22027588, 24.50628662], [92.21714783, 24.50720024], [92.21572876, 24.50774193], [92.21632385, 24.50882339], [92.21750641, 24.51111794], [92.21864319, 24.51323318], [92.22002411, 24.51494598], [92.22006226, 24.51503181], [92.21982574, 24.51594353], [92.21994781, 24.51636696], [92.22122192, 24.51669121], [92.22336578, 24.51729584], [92.22360229, 24.51742935], [92.22428131, 24.518713], [92.2247467, 24.51991463], [92.2261734, 24.52310371], [92.22721863, 24.52541924], [92.22834778, 24.52769279], [92.22866821, 24.52854919], [92.22927094, 24.52949905], [92.22979736, 24.52984047], [92.23073578, 24.53019142], [92.23083496, 24.53022766], [92.2310257, 24.53101921], [92.23101044, 24.53403664], [92.23106384, 24.53705788], [92.23124695, 24.54734993], [92.23130035, 24.54841995], [92.23139954, 24.55059433], [92.23152161, 24.55353355], [92.23165131, 24.55656433], [92.23181152, 24.56026459], [92.23193359, 24.56314659], [92.23204803, 24.56577873], [92.23214722, 24.56814194], [92.23220062, 24.56932449], [92.23227692, 24.57108307], [92.23325348, 24.57237625], [92.23374176, 24.57370567], [92.23366547, 24.57484818], [92.2341156, 24.57512093], [92.23458099, 24.57541656], [92.23388672, 24.57657623], [92.23412323, 24.57705688], [92.23434448, 24.57749939], [92.23455048, 24.57790947], [92.233284, 24.57790756], [92.23310089, 24.57930756], [92.23330688, 24.58109093], [92.23332214, 24.581213], [92.23336792, 24.58187675], [92.23394012, 24.58321762], [92.23378754, 24.58464432], [92.23430634, 24.58588409], [92.23477936, 24.58809662], [92.23490143, 24.5888443], [92.23510742, 24.59012032], [92.23542023, 24.59146881], [92.2358551, 24.5934906], [92.23613739, 24.59585381], [92.23540497, 24.59607506], [92.23529053, 24.59763908], [92.2359314, 24.59915161], [92.23616791, 24.5991478], [92.23690033, 24.59913063], [92.23719788, 24.60014153], [92.23722839, 24.60024071], [92.23740387, 24.60156059], [92.23822021, 24.60399246], [92.2386322, 24.60528374], [92.23906708, 24.607584], [92.23997498, 24.60799217], [92.24049377, 24.60822487], [92.24050903, 24.60841751], [92.2405777, 24.60944366], [92.24113464, 24.61059189], [92.24221039, 24.61147881], [92.24186707, 24.61240578], [92.24178314, 24.61416817], [92.24211884, 24.61477661], [92.24211884, 24.61514282], [92.24274445, 24.61555862], [92.24350739, 24.61606789], [92.24363708, 24.6161499], [92.24377441, 24.61750603], [92.24395752, 24.61824989], [92.24394989, 24.61902809], [92.24430847, 24.62035751], [92.2432785, 24.62156868], [92.24333191, 24.62320137], [92.24337006, 24.62559128], [92.24404144, 24.62716293], [92.24424744, 24.62825203], [92.24437714, 24.62893867], [92.24508667, 24.6300087], [92.24610138, 24.6317234], [92.24636841, 24.63235664], [92.24661255, 24.63292503], [92.24707794, 24.63430405], [92.24732971, 24.63581085], [92.24740601, 24.63658714], [92.24742126, 24.63680077], [92.24745178, 24.63710976], [92.24810791, 24.63850975], [92.2483139, 24.63935852], [92.24838257, 24.63954735], [92.24893951, 24.64104652], [92.24897003, 24.64126968], [92.24910736, 24.64235115], [92.24922943, 24.64325333], [92.2490387, 24.64353752], [92.24848175, 24.64436722], [92.24851227, 24.64446831], [92.24905396, 24.64608383], [92.24950409, 24.64780617], [92.24980927, 24.64917564], [92.24959564, 24.64954567], [92.24917603, 24.65026855], [92.24885559, 24.65081787], [92.24814606, 24.65239525], [92.24700928, 24.65491867], [92.24774933, 24.65628433], [92.24795532, 24.65750885], [92.24855804, 24.65860748], [92.24935913, 24.65881538], [92.24967194, 24.65890884], [92.24987793, 24.66002274], [92.25153351, 24.6601181], [92.25237274, 24.66184998], [92.25299835, 24.66349411], [92.25354004, 24.66534996], [92.2539978, 24.66607475], [92.25467682, 24.66716385], [92.25498962, 24.66840363], [92.25559998, 24.66990471], [92.25611877, 24.67096901], [92.25650024, 24.67222977], [92.25701904, 24.67358589], [92.25504303, 24.67425537], [92.25437927, 24.67527199], [92.25466156, 24.67643738], [92.25484467, 24.67722321], [92.25434113, 24.67818069], [92.25505066, 24.6787262], [92.25595093, 24.67980957], [92.25654602, 24.67966843], [92.25711823, 24.67952919], [92.25830078, 24.67964745], [92.25856018, 24.68008041], [92.25932312, 24.68133163], [92.25926971, 24.68239784], [92.25846863, 24.68261909], [92.25815582, 24.68326569], [92.25840759, 24.68532753], [92.25954437, 24.68658447], [92.25963593, 24.68740273], [92.26078033, 24.68805504], [92.26154327, 24.69024467], [92.26268768, 24.69043541], [92.26345825, 24.69056511], [92.26467896, 24.69076347], [92.26506042, 24.69118309], [92.2651825, 24.69131851], [92.26531219, 24.69157219], [92.26597595, 24.69291115], [92.2666626, 24.69429207], [92.26773834, 24.69446564], [92.26785278, 24.69512177], [92.26802826, 24.69613266], [92.26833344, 24.69655418], [92.2697525, 24.69869995], [92.27036285, 24.70021248], [92.27119446, 24.70115662], [92.27129364, 24.70171165], [92.27230072, 24.70273972], [92.27436829, 24.70552254], [92.27533722, 24.70674515], [92.27606201, 24.70758629], [92.27490997, 24.70815659], [92.27546692, 24.70932961], [92.27702332, 24.71168327], [92.2786026, 24.71347809], [92.2807312, 24.7147274], [92.2820816, 24.71701622], [92.28264618, 24.71792793], [92.28465271, 24.71985817], [92.28523254, 24.72104073], [92.28713226, 24.7226944], [92.28718567, 24.72278214], [92.2872467, 24.7228756], [92.28878784, 24.72519112], [92.28919983, 24.72581863], [92.28957367, 24.72642517], [92.29004669, 24.72710419], [92.29029846, 24.72760391], [92.29117584, 24.72855568], [92.29138947, 24.72878838], [92.29152679, 24.72925758], [92.29151154, 24.72944832], [92.29206848, 24.73041725], [92.29229736, 24.73074532], [92.29239655, 24.73094559], [92.29277039, 24.73110199], [92.2929306, 24.73119164], [92.293396, 24.73145103], [92.29380035, 24.73167801], [92.29395294, 24.73188591], [92.29390717, 24.73204041], [92.29377747, 24.73213768], [92.29359436, 24.73232079], [92.29350281, 24.73252296], [92.29358673, 24.73261833], [92.29379272, 24.73264313], [92.29390717, 24.73262787], [92.29410553, 24.73260117], [92.29428101, 24.73264503], [92.29458618, 24.73292542], [92.29464722, 24.73309898], [92.2946701, 24.73335648], [92.29462433, 24.73349953], [92.29437256, 24.73363686], [92.29415894, 24.73382187], [92.29384613, 24.7342186], [92.29376221, 24.73451614], [92.2938385, 24.73469734], [92.29393768, 24.73485756], [92.29404449, 24.73497963], [92.29425812, 24.73509026], [92.29447174, 24.73520279], [92.29499054, 24.73546219], [92.29541016, 24.73567581], [92.29547119, 24.73580742], [92.29534912, 24.73620224], [92.29540253, 24.73639679], [92.29588318, 24.7366333], [92.29512787, 24.73693085], [92.2934494, 24.7375927], [92.28988647, 24.73899269], [92.28817749, 24.73966599], [92.28552246, 24.7407093], [92.28380585, 24.7413826], [92.28183746, 24.74215698], [92.28119659, 24.74245262], [92.28179169, 24.74355316], [92.27963257, 24.74448967], [92.27896118, 24.74572372], [92.28004456, 24.74556351], [92.28006744, 24.74580574], [92.28009033, 24.74598122], [92.28028107, 24.74782753], [92.27972412, 24.74830627], [92.28159332, 24.75049973], [92.28353119, 24.75278664], [92.28469849, 24.75415993], [92.28672028, 24.75653648], [92.28710938, 24.75852394], [92.28739166, 24.75974846], [92.28823853, 24.75967789], [92.28886414, 24.7611618], [92.28795624, 24.76176643], [92.28742218, 24.76212311], [92.28733826, 24.76217842], [92.28702545, 24.76234436], [92.28678894, 24.76246834], [92.28565216, 24.76306915], [92.28530121, 24.76330757], [92.28489685, 24.7635746], [92.28427124, 24.76374817], [92.28411102, 24.76379204], [92.28269958, 24.76436615], [92.28242493, 24.76488876], [92.28217316, 24.76530075], [92.28127289, 24.76576042], [92.28015137, 24.76633072], [92.28090668, 24.7673893], [92.28193665, 24.7684021], [92.28253937, 24.77059746], [92.28298187, 24.7709465], [92.28292084, 24.7734127], [92.28208923, 24.77443314], [92.28172302, 24.77545738], [92.28226471, 24.77554512], [92.28260803, 24.77559853], [92.28288269, 24.7756424], [92.28296661, 24.77559853], [92.28462982, 24.77474022], [92.28466797, 24.77514267], [92.28482819, 24.7766552], [92.28633881, 24.77699471], [92.28675079, 24.77859306], [92.28783417, 24.77932739], [92.28762054, 24.78114128], [92.28866577, 24.78150368], [92.28824615, 24.78189278], [92.28803253, 24.78209496], [92.28813171, 24.78239822], [92.2885437, 24.7837162], [92.28864288, 24.78403664], [92.28883362, 24.78463173], [92.2881546, 24.78621674], [92.2881012, 24.78635406], [92.28765869, 24.78705025], [92.28734589, 24.78754616], [92.2881012, 24.78743935], [92.28839874, 24.78819656], [92.28844452, 24.78832245], [92.28753662, 24.78860664], [92.28710938, 24.78874016], [92.28688049, 24.7889061], [92.28653717, 24.78916359], [92.28601074, 24.78918839], [92.28569031, 24.78894997], [92.28462219, 24.78905106], [92.28438568, 24.78907967], [92.2841568, 24.78910828], [92.28358459, 24.7895031], [92.2824707, 24.78999138], [92.28232574, 24.79005432], [92.28214264, 24.79003525], [92.28205109, 24.79002571], [92.28199005, 24.79006386], [92.28171539, 24.79024696], [92.28099823, 24.79074287], [92.28063965, 24.79153633], [92.2804184, 24.79210281], [92.28023529, 24.79250908], [92.28001404, 24.7928009], [92.2798996, 24.79297066], [92.27980804, 24.79305649], [92.27974701, 24.7931118], [92.27934265, 24.79337311], [92.27952576, 24.79342842], [92.27984619, 24.79366302], [92.27941132, 24.79411125], [92.27914429, 24.7942276], [92.27922058, 24.79435349], [92.27927399, 24.79442024], [92.27931213, 24.79452515], [92.2795639, 24.79496193], [92.27960968, 24.7950573], [92.27977753, 24.79567719], [92.27968597, 24.79598427], [92.27950287, 24.7964859], [92.27916718, 24.7970047], [92.27912903, 24.79706764], [92.27901459, 24.79719925], [92.27881622, 24.79753494], [92.2784729, 24.7976284], [92.27786255, 24.79779434], [92.27750397, 24.7978344], [92.27737427, 24.7978878], [92.27718353, 24.79795647], [92.27709961, 24.79794502], [92.27682495, 24.79791069], [92.27649689, 24.79814529], [92.27619934, 24.79829788], [92.27606964, 24.79836464], [92.27574158, 24.7985363], [92.2756424, 24.79858398], [92.2755661, 24.79861641], [92.27528381, 24.79868698], [92.275177, 24.7986908], [92.27496338, 24.79870033], [92.27462769, 24.79881859], [92.27437592, 24.79888535], [92.27381134, 24.79914474], [92.27349854, 24.7993145], [92.27346039, 24.79971886], [92.27326202, 24.79992676], [92.27323151, 24.80008316], [92.27326965, 24.80023193], [92.27304077, 24.80032349], [92.27311707, 24.80046844], [92.2730484, 24.8006649], [92.27301788, 24.80075264], [92.27318573, 24.80115509], [92.27331543, 24.80151176], [92.27342224, 24.80169296], [92.2735672, 24.80195427], [92.27378082, 24.80223083], [92.27388763, 24.80236435], [92.27410889, 24.80259705], [92.27436066, 24.80286598], [92.27455902, 24.80307007], [92.27481842, 24.80331039], [92.27523041, 24.80384636], [92.27498627, 24.80416489], [92.27490997, 24.80426407], [92.27431488, 24.80558968], [92.27420044, 24.80585098], [92.27416229, 24.80666924], [92.27430725, 24.80708313], [92.27436066, 24.80719185], [92.27442932, 24.80730057], [92.27436829, 24.80735779], [92.27456665, 24.80755615], [92.27468872, 24.80773163], [92.27474976, 24.80783653], [92.27490997, 24.80787849], [92.27497864, 24.80825615], [92.27516937, 24.80842209], [92.27548218, 24.8087883], [92.27555847, 24.80898285], [92.27583313, 24.80956078], [92.27607727, 24.81004143], [92.2760849, 24.81071854], [92.27603149, 24.81080818], [92.27574158, 24.81104279], [92.27533722, 24.81123352], [92.27616882, 24.81214142], [92.27584076, 24.81237793], [92.2751236, 24.81299782], [92.27485657, 24.81305313], [92.27476501, 24.81305885], [92.27426147, 24.81349945], [92.27424622, 24.81360054], [92.27419281, 24.8137207], [92.27396393, 24.81383514], [92.27378082, 24.81393051], [92.27377319, 24.81424713], [92.27403259, 24.81458855], [92.27448273, 24.81462288], [92.27458954, 24.81464577], [92.27474976, 24.81473541], [92.27513123, 24.81495285], [92.27536011, 24.81503677], [92.27575684, 24.81518936], [92.27588654, 24.81529236], [92.27619171, 24.81557083], [92.27599335, 24.81582451], [92.27587128, 24.81599617], [92.27596283, 24.81627464], [92.27542877, 24.81701469], [92.27545166, 24.81712532], [92.27549744, 24.81739044], [92.27532196, 24.81764221], [92.27526855, 24.81785583], [92.2751236, 24.81815529], [92.27497101, 24.81839943], [92.27483368, 24.81869888], [92.27481079, 24.81877136], [92.2747879, 24.81885147], [92.27461243, 24.81893158], [92.27393341, 24.81923485], [92.27391052, 24.81946754], [92.27387238, 24.81962776], [92.27379608, 24.81972122], [92.27371216, 24.81981659], [92.27361298, 24.81992531], [92.27342224, 24.82060242], [92.27335358, 24.82094193], [92.27323151, 24.82099915], [92.27282715, 24.8211422], [92.27269745, 24.82143974], [92.27266693, 24.82153511], [92.27267456, 24.82169342], [92.27268982, 24.82178879], [92.27297974, 24.82258606], [92.27288818, 24.8227005], [92.27288818, 24.82278824], [92.27288818, 24.82288551], [92.27281189, 24.82300949], [92.27267456, 24.8231926], [92.27259827, 24.82383728], [92.27256775, 24.82409286], [92.27276611, 24.8244648], [92.27294922, 24.82475281], [92.27279663, 24.82546806], [92.27276611, 24.82557869], [92.27272797, 24.82597351], [92.27272797, 24.82624817], [92.27266693, 24.82645416], [92.27264404, 24.82656288], [92.27256775, 24.82695961], [92.27298737, 24.82756996], [92.27259827, 24.82775116], [92.27235413, 24.82787704], [92.27191162, 24.82810402], [92.27100372, 24.82876396], [92.27064514, 24.82904625], [92.2702713, 24.82926369], [92.26987457, 24.82960129], [92.26977539, 24.82966614], [92.26969147, 24.82971382], [92.26960754, 24.82976532], [92.26921844, 24.82995224], [92.26889038, 24.82998466], [92.26850891, 24.83003044], [92.26838684, 24.83005142], [92.26687622, 24.83019829], [92.26621246, 24.83019447], [92.26569366, 24.83025742], [92.26443481, 24.83033371], [92.26439667, 24.83050346], [92.26335144, 24.83045387], [92.26263428, 24.8304348], [92.26178741, 24.83037949], [92.26152039, 24.83043671], [92.2609787, 24.83044624], [92.26086426, 24.83051682], [92.26049042, 24.83073425], [92.26029205, 24.83036232], [92.25852966, 24.83081436], [92.25763702, 24.83102608], [92.25675964, 24.8312397], [92.25650787, 24.83124161], [92.25611877, 24.83135414], [92.25547028, 24.83154869], [92.25502777, 24.83174515], [92.25474548, 24.83181], [92.25417328, 24.8318882], [92.25367737, 24.83203125], [92.25338745, 24.83212471], [92.25311279, 24.83222961], [92.25289917, 24.8322773], [92.25267792, 24.83158112], [92.25242615, 24.83098221], [92.25228119, 24.83096504], [92.25215912, 24.83063316], [92.25208282, 24.83064651], [92.25163269, 24.83074951], [92.25117493, 24.83074379], [92.251091, 24.8306427], [92.25079346, 24.83068466], [92.25008392, 24.83024025], [92.24958801, 24.83018494], [92.24924469, 24.83014679], [92.24919891, 24.83001709], [92.24900818, 24.82987404], [92.24887085, 24.83065224], [92.24886322, 24.83075333], [92.24878693, 24.83080292], [92.24878693, 24.83095932], [92.24866486, 24.83112717], [92.24867249, 24.83147621], [92.24865723, 24.83156586], [92.24829865, 24.83241844], [92.24868011, 24.83266258], [92.24900055, 24.83264351], [92.248909, 24.83279991], [92.24993896, 24.8331604], [92.25031281, 24.83335114], [92.25076294, 24.83364296], [92.2512207, 24.83407784], [92.25150299, 24.83423233], [92.25161743, 24.83433533], [92.25160217, 24.83463669], [92.25032806, 24.835289], [92.25025177, 24.83582115], [92.2507782, 24.83622551], [92.25180817, 24.83701897], [92.25299835, 24.83747101], [92.25399017, 24.83785057], [92.25462341, 24.83837128], [92.25487518, 24.83857727], [92.25465393, 24.83880615], [92.25392151, 24.83858871], [92.25350189, 24.83844185], [92.25328064, 24.83838654], [92.25262451, 24.83839798], [92.25228119, 24.83847427], [92.2519455, 24.83860779], [92.2516098, 24.838871], [92.25117493, 24.83948708], [92.24859619, 24.83956337], [92.24751282, 24.83968163], [92.24600983, 24.83984566], [92.24528503, 24.83992386], [92.24518585, 24.84039688], [92.24378204, 24.84049034], [92.24300385, 24.84054184], [92.24242401, 24.84057999], [92.2425766, 24.84196854], [92.24259186, 24.84207344], [92.2423172, 24.8420887], [92.24138641, 24.84214211], [92.24165344, 24.84420395], [92.24154663, 24.84427834], [92.2416153, 24.84521866], [92.24098206, 24.84540367], [92.24103546, 24.84667778], [92.24108887, 24.84710312], [92.24112701, 24.84745216], [92.24115753, 24.84788895], [92.24125671, 24.84899521], [92.2413559, 24.84954071], [92.24140167, 24.84996986], [92.24119568, 24.85006332], [92.24071503, 24.85027885], [92.24075317, 24.85110855], [92.24039459, 24.8512001], [92.24038696, 24.8521595], [92.24016571, 24.85224152], [92.24015808, 24.85262299], [92.23967743, 24.85273743], [92.23957825, 24.85391045], [92.23960114, 24.85520172], [92.23964691, 24.85654259], [92.23972321, 24.85782623], [92.23899078, 24.85824203], [92.23820496, 24.85864067], [92.23807526, 24.85868263], [92.23750305, 24.8588562], [92.23674011, 24.85899544], [92.23631287, 24.85905647], [92.23580933, 24.85912895], [92.23582458, 24.85940552], [92.23581696, 24.86017418], [92.23529053, 24.86089897], [92.23484802, 24.86150551], [92.23576355, 24.8628788], [92.23522949, 24.86386299], [92.23557281, 24.86412239], [92.2358017, 24.86429596], [92.23682404, 24.86552238], [92.23719788, 24.86616516], [92.23741913, 24.86680412], [92.23754883, 24.86742973], [92.23789215, 24.86812019], [92.23825073, 24.86837006], [92.23875427, 24.86850929], [92.23939514, 24.86847496], [92.23984528, 24.86835289], [92.24029541, 24.86822891], [92.24054718, 24.87030029], [92.24060059, 24.87065125], [92.24209595, 24.87253952], [92.24391937, 24.87265968], [92.24677277, 24.87285423], [92.24688721, 24.87445068], [92.24638367, 24.87454224], [92.24685669, 24.87763977], [92.24719238, 24.87992477], [92.24711609, 24.88055229], [92.24689484, 24.88171959], [92.24714661, 24.88212204], [92.24713135, 24.88303757], [92.24687958, 24.88301849], [92.24706268, 24.88502884], [92.24729919, 24.88502312], [92.24803162, 24.88500786], [92.24787903, 24.88541794], [92.24802399, 24.88562584], [92.24719238, 24.88585472], [92.24727631, 24.88693047], [92.24707794, 24.88693047], [92.24713135, 24.88765717], [92.24598694, 24.88817596], [92.24485779, 24.88871384], [92.24341583, 24.88896942], [92.2430191, 24.88897514], [92.24209595, 24.8889904], [92.24073029, 24.88977242], [92.23933411, 24.89015579], [92.23938751, 24.89162254], [92.23940277, 24.89203644], [92.23924255, 24.89196968], [92.2388916, 24.89193916], [92.23833466, 24.89189911], [92.23802948, 24.89192009], [92.23739624, 24.89195442], [92.23699188, 24.89200974], [92.23653412, 24.89209747], [92.23652649, 24.89255142], [92.23554993, 24.8932457], [92.23556519, 24.89334869], [92.23557281, 24.89368248], [92.23561096, 24.89385414], [92.23570251, 24.89423561], [92.23576355, 24.89432335], [92.23601532, 24.89471436], [92.23635864, 24.8949585], [92.23640442, 24.8952198], [92.23613739, 24.89536285], [92.23604584, 24.89627838], [92.23554993, 24.8964901], [92.23553467, 24.89677811], [92.23590851, 24.89691544], [92.23595428, 24.8981781], [92.23602295, 24.8991642], [92.23602295, 24.89926338], [92.2348175, 24.89942741], [92.23445892, 24.89949989], [92.23360443, 24.89966965], [92.23336792, 24.89967918], [92.2329483, 24.89991379], [92.23239899, 24.90025711], [92.23232269, 24.90030098], [92.23212433, 24.90042877], [92.23262024, 24.90205574], [92.23429108, 24.90353775], [92.23474884, 24.90394592], [92.23674774, 24.90481758], [92.23957825, 24.90553474], [92.24115753, 24.90598869], [92.24281311, 24.90667725], [92.24501801, 24.9083252], [92.24523163, 24.91024971], [92.25020599, 24.91286278], [92.25505829, 24.91393089], [92.25640106, 24.91039085], [92.25759888, 24.90727425], [92.25824738, 24.90709496], [92.25945282, 24.9072113], [92.26087189, 24.90724373], [92.26329041, 24.9074688], [92.2634964, 24.90743065], [92.26558685, 24.90704536], [92.26721191, 24.90668678], [92.26793671, 24.90622711], [92.27085876, 24.9112587], [92.27908325, 24.91003036], [92.27986145, 24.9099102], [92.27999878, 24.90969086], [92.28226471, 24.9060936], [92.28304291, 24.90616608], [92.28376007, 24.90651512], [92.28404999, 24.90716171], [92.28399658, 24.90758705], [92.28456879, 24.90839958], [92.28473663, 24.90910149], [92.28529358, 24.91064453], [92.2857666, 24.91131401], [92.28682709, 24.91208267], [92.28791809, 24.91268921], [92.28939056, 24.91337013], [92.29013062, 24.91364288], [92.29057312, 24.91380501], [92.29092407, 24.91392326], [92.29205322, 24.91448021], [92.29272461, 24.91481018], [92.29434967, 24.91574097], [92.29595947, 24.91616821], [92.29773712, 24.91619492], [92.29890442, 24.91609573], [92.30042267, 24.91572571], [92.30065155, 24.91567039], [92.30176544, 24.91520309], [92.30306244, 24.91432571], [92.30370331, 24.91363716], [92.30407715, 24.91325188], [92.30529785, 24.91303825], [92.30857086, 24.90830994], [92.31214905, 24.90785027], [92.31445313, 24.90755081], [92.31519318, 24.90384102], [92.31925201, 24.90100098], [92.3200531, 24.90043068], [92.31973267, 24.89580917], [92.31983948, 24.89585304], [92.32053375, 24.8961544], [92.32128143, 24.89653969], [92.32299805, 24.89694786], [92.3237381, 24.89712524], [92.32521057, 24.89667702], [92.32582855, 24.89631653], [92.32637787, 24.89599991], [92.32695007, 24.89536858], [92.32725525, 24.89484024], [92.32736969, 24.89450836], [92.32770538, 24.8935318], [92.32782745, 24.89317322], [92.32798004, 24.89119148], [92.32823181, 24.88978004], [92.32949829, 24.88835144], [92.3314743, 24.88639832], [92.33357239, 24.88427925], [92.33628845, 24.88141251], [92.33834839, 24.87937546], [92.33966064, 24.87834358], [92.34030914, 24.87824059], [92.34083557, 24.87815475], [92.34209442, 24.87833405], [92.34225464, 24.87835693], [92.34375763, 24.87932777], [92.34468842, 24.88082886], [92.34490967, 24.88274765], [92.34494781, 24.88488579], [92.34477997, 24.8862915], [92.34476471, 24.88644791], [92.34466553, 24.88762665], [92.34458923, 24.89033508], [92.34465027, 24.89194107], [92.3447876, 24.89243317], [92.34487915, 24.89278603], [92.34497833, 24.89318085], [92.34580994, 24.89368248], [92.34661102, 24.89364243], [92.34750366, 24.89336777], [92.34765625, 24.89323616], [92.34868622, 24.8923378], [92.34875488, 24.89217567], [92.34978485, 24.88989258], [92.35077667, 24.88861275], [92.35158539, 24.8867321], [92.35286713, 24.88376999], [92.35350037, 24.88245964], [92.35355377, 24.88251877], [92.35371399, 24.88261986], [92.35384369, 24.88273811], [92.35394287, 24.88281059], [92.35411072, 24.88294792], [92.35549164, 24.88046265], [92.36210632, 24.88264847], [92.36289215, 24.88243103], [92.36546326, 24.88170052], [92.36736298, 24.87805939], [92.3693924, 24.87416077], [92.37025452, 24.87456703], [92.37177277, 24.87494087], [92.37359619, 24.87491035], [92.37541962, 24.87448502], [92.37619781, 24.87342453], [92.37696075, 24.8714447], [92.37731171, 24.86991501], [92.37731934, 24.86972427], [92.37822723, 24.86795998], [92.37838745, 24.86783218], [92.37849426, 24.86781502], [92.37859344, 24.86777115], [92.37875366, 24.86775589], [92.37892151, 24.86775208], [92.37892151, 24.86786842], [92.38098145, 24.86759377], [92.381073, 24.86758232], [92.3813324, 24.86754799], [92.3814621, 24.86753082], [92.3815918, 24.86751366], [92.38174438, 24.86749268], [92.38182831, 24.86740685], [92.38195801, 24.86746407], [92.38205719, 24.86745071], [92.3835907, 24.86724854], [92.384552, 24.86712265], [92.38883209, 24.86155128], [92.38925171, 24.86100006], [92.38539124, 24.85720062], [92.38695526, 24.8527317], [92.38851166, 24.85218811], [92.39051056, 24.85156059], [92.39232635, 24.85123253], [92.39505768, 24.85535812], [92.4028244, 24.85489273], [92.40296173, 24.85530281], [92.40331268, 24.85605049], [92.40408325, 24.85769653], [92.40414429, 24.85778046], [92.40437317, 24.85808182], [92.4048233, 24.85867882], [92.40499878, 24.85885239], [92.40573883, 24.85959244], [92.40720367, 24.8601284], [92.40908813, 24.86026955], [92.41152954, 24.86011314], [92.41430664, 24.85938644], [92.4164505, 24.86284256], [92.42172241, 24.86133957], [92.42592621, 24.86014175], [92.42588043, 24.8599205], [92.42491913, 24.85432053], [92.42524719, 24.85412979], [92.42605591, 24.85413742], [92.42757416, 24.85442924], [92.42980957, 24.85515022], [92.43131256, 24.8559742], [92.43378448, 24.85652924], [92.43321228, 24.85954094], [92.43752289, 24.86101913], [92.44068909, 24.86370087], [92.44107819, 24.86365318], [92.44116211, 24.86400032], [92.44129944, 24.8658123], [92.44124603, 24.86616325], [92.44091797, 24.86812973], [92.44100189, 24.86920166], [92.44174957, 24.87088776], [92.44262695, 24.87182999], [92.44364929, 24.87252617], [92.44517517, 24.87309647], [92.44836426, 24.87335014], [92.4498291, 24.87329292], [92.45077515, 24.87325668], [92.45253754, 24.87336349], [92.4551239, 24.87401581], [92.4569931, 24.87438202], [92.45935822, 24.87460518], [92.45964813, 24.87458229], [92.45959473, 24.87473869], [92.45959473, 24.87492371], [92.45954132, 24.87506676], [92.4595108, 24.87531281], [92.45946503, 24.87551689], [92.4594574, 24.87569809], [92.46006775, 24.87452507], [92.46136475, 24.87434578], [92.46577454, 24.87307358], [92.46810913, 24.87213135], [92.47003174, 24.87127876], [92.47063446, 24.87101555], [92.47196198, 24.87043381], [92.47353363, 24.86975861], [92.47419739, 24.86937714], [92.47492981, 24.86886024], [92.47530365, 24.86873627], [92.47583008, 24.86857796], [92.47618103, 24.86828232], [92.47637939, 24.86886024], [92.47660065, 24.86883926], [92.4769516, 24.86985588], [92.47684479, 24.86995125], [92.47694397, 24.87059784], [92.47716522, 24.87085533], [92.47742462, 24.87123871], [92.47779846, 24.87166786], [92.47828674, 24.87205696], [92.4783783, 24.87213326], [92.47909546, 24.87253952], [92.47950745, 24.87267303], [92.47973633, 24.87274742], [92.47988892, 24.8727951], [92.48040009, 24.87287331], [92.48051453, 24.87231064], [92.48182678, 24.87229156], [92.48262787, 24.87223244], [92.48497009, 24.87199593], [92.48549652, 24.87189484], [92.48784637, 24.87143135], [92.4878006, 24.87179375], [92.48765564, 24.87292862], [92.48925781, 24.87324715], [92.48941803, 24.8728466], [92.48949432, 24.87266159], [92.4901123, 24.8733902], [92.49014282, 24.87346077], [92.49032593, 24.8739357], [92.49190521, 24.87796402], [92.49124146, 24.87998772], [92.49188232, 24.88259125], [92.49182129, 24.88288689], [92.49172211, 24.88326836], [92.49176025, 24.88396835], [92.49184418, 24.88452339], [92.49185944, 24.88524818], [92.49186707, 24.88565254], [92.49172974, 24.88660622], [92.491539, 24.8871727], [92.49150085, 24.88730049], [92.49140167, 24.88796043], [92.49123383, 24.88890076], [92.49102783, 24.89016342], [92.49098969, 24.89072418], [92.49100494, 24.89096069], [92.49105835, 24.89160538], [92.49133301, 24.89226341], [92.491745, 24.89326477], [92.49275208, 24.89497375], [92.49382019, 24.8967514], [92.493927, 24.89750481], [92.49395752, 24.89769745], [92.49460602, 24.89884949], [92.49517059, 24.89951134], [92.49551392, 24.8999157], [92.49642181, 24.90108109], [92.49678802, 24.90217209], [92.49633026, 24.90252113], [92.4957428, 24.90310478], [92.49539185, 24.90332031], [92.49491119, 24.90351105], [92.49463654, 24.90348053], [92.49414825, 24.90375519], [92.49371338, 24.90409088], [92.49333954, 24.90451431], [92.49308014, 24.9049263], [92.49302673, 24.90557861], [92.49290466, 24.90591621], [92.49282074, 24.90622902], [92.49313354, 24.90801811], [92.49350739, 24.9101162], [92.493927, 24.91118622], [92.49449158, 24.91227341], [92.49488068, 24.91413307], [92.49480438, 24.91482162], [92.49474335, 24.91531754], [92.49452209, 24.91600418], [92.49414063, 24.91663933], [92.49385071, 24.91695976], [92.49337769, 24.91748428], [92.49268341, 24.9178524], [92.49248505, 24.91795731], [92.49240875, 24.91799927], [92.49146271, 24.91850662], [92.49069977, 24.91886902], [92.48973846, 24.91932297], [92.48825073, 24.92009544], [92.48773193, 24.92054367], [92.48748779, 24.92075539], [92.48723602, 24.92115974], [92.48696899, 24.9216671], [92.48622131, 24.92306137], [92.48530579, 24.92518425], [92.48474884, 24.92649841], [92.48423767, 24.92775536], [92.48423004, 24.92814064], [92.48394012, 24.92860413], [92.4838562, 24.92923546], [92.48374176, 24.93071938], [92.48381805, 24.93228912], [92.48402405, 24.93355942], [92.4845047, 24.93545532], [92.48471069, 24.93616104], [92.4852829, 24.93761635], [92.48556519, 24.93865585], [92.48596954, 24.9398365], [92.48642731, 24.94108391], [92.48728943, 24.94274902], [92.48783875, 24.94420433], [92.48790741, 24.94479752], [92.48783112, 24.945467], [92.48775482, 24.94621849], [92.48764038, 24.94667435], [92.48725891, 24.94724655], [92.48674011, 24.94757462], [92.48619843, 24.94771004], [92.48583221, 24.94779968], [92.48527527, 24.94783401], [92.4848938, 24.94777107], [92.48434448, 24.94765663], [92.48338318, 24.94728088], [92.48285675, 24.94688225], [92.48225403, 24.94633675], [92.48158264, 24.94571495], [92.48132324, 24.94544983], [92.48112488, 24.94524765], [92.48074341, 24.94489288], [92.48014069, 24.94423485], [92.47974396, 24.94387817], [92.47958374, 24.94375038], [92.47921753, 24.9425602], [92.47744751, 24.94260216], [92.47612, 24.94219971], [92.47377777, 24.94199181], [92.4730835, 24.94177246], [92.47122192, 24.941782], [92.4699173, 24.9417057], [92.46848297, 24.94176102], [92.46704865, 24.94167709], [92.46565247, 24.94160652], [92.46421051, 24.94149208], [92.46263885, 24.94124413], [92.46166992, 24.94102859], [92.46064758, 24.94081306], [92.45951843, 24.94054413], [92.45805359, 24.94021225], [92.45623016, 24.93964195], [92.45475006, 24.93916893], [92.45300293, 24.93865204], [92.45217896, 24.93865395], [92.45136261, 24.93858147], [92.45108032, 24.93871498], [92.45085907, 24.93882179], [92.45064545, 24.93873215], [92.45031738, 24.93859291], [92.4495697, 24.93872643], [92.44915771, 24.93889999], [92.44890594, 24.93909264], [92.44877625, 24.93952179], [92.44841766, 24.94055939], [92.44814301, 24.94170189], [92.44776917, 24.94382668], [92.44785309, 24.94513512], [92.44787598, 24.94542885], [92.44798279, 24.94600105], [92.44802856, 24.94623375], [92.44812012, 24.94671249], [92.44818878, 24.94733429], [92.44839478, 24.94762611], [92.44857025, 24.94805717], [92.44965363, 24.95012474], [92.45028687, 24.95082283], [92.45128632, 24.95211792], [92.45239258, 24.95307732], [92.45348358, 24.95390701], [92.45497894, 24.95471954], [92.45665741, 24.95500755], [92.45778656, 24.95520973], [92.45955658, 24.95540619], [92.46116638, 24.95543098], [92.46296692, 24.95584869], [92.46328735, 24.95591736], [92.46470642, 24.95478058], [92.47158051, 24.9559803], [92.47371674, 24.95709991], [92.47103119, 24.96409988], [92.46711731, 24.96858025], [92.4640274, 24.97077942], [92.4605484, 24.97615051], [92.45445251, 24.97318077], [92.44940948, 24.97208977], [92.44904327, 24.97154808], [92.44590759, 24.96696281], [92.44003296, 24.96680069], [92.43515778, 24.96637917], [92.43161011, 24.97066116], [92.42849731, 24.97257996], [92.42855072, 24.97290993], [92.42948151, 24.97988129], [92.42446899, 24.98257065], [92.42363739, 24.99609947], [92.4258728, 25.00319099], [92.42945099, 25.00969124], [92.43036652, 25.01280975], [92.43105316, 25.01581955], [92.43099976, 25.0216198], [92.43219757, 25.02507973], [92.43325043, 25.02808952], [92.43284607, 25.03102112], [92.4306488, 25.03226089], [92.42782593, 25.03157043], [92.4262619, 25.03164101], [92.42590332, 25.0318203], [92.43192291, 25.03290749], [92.43788147, 25.03375244], [92.44178009, 25.03985023], [92.4465332, 25.04204178], [92.45101929, 25.04095078], [92.45420837, 25.03660965], [92.45680237, 25.03503036], [92.45976257, 25.03518105], [92.46325684, 25.03712845], [92.46466064, 25.04722977], [92.46286011, 25.05014992], [92.46015167, 25.04959106], [92.45983887, 25.0546608], [92.46203613, 25.05583], [92.46366882, 25.0555706], [92.46598816, 25.05715752], [92.46750641, 25.06137085], [92.47091675, 25.06689072], [92.474617, 25.07080078], [92.47654724, 25.07825279], [92.48017883, 25.08584023], [92.47975922, 25.09574127], [92.48031616, 25.10040855], [92.48429871, 25.10806084], [92.49910736, 25.10814857], [92.50978088, 25.10547066], [92.52651215, 25.10585022], [92.53201294, 25.10396004], [92.53804779, 25.09931183], [92.54294586, 25.09959984], [92.54081726, 25.10412979], [92.53305817, 25.11214828], [92.53132629, 25.11990166], [92.53024292, 25.1218605], [92.52522278, 25.12557983], [92.52466583, 25.14002991], [92.52746582, 25.13994026], [92.53018951, 25.13682175], [92.53562927, 25.13441277], [92.53993988, 25.13727951], [92.54312897, 25.1350193], [92.55316925, 25.1307106], [92.55784607, 25.12997055], [92.56549835, 25.1312809], [92.56803894, 25.13009071], [92.5790329, 25.13200951], [92.58168793, 25.13187027], [92.59443665, 25.12829018], [92.59842682, 25.12471008], [92.60314941, 25.12499046], [92.61003113, 25.12409973], [92.62164307, 25.11770058], [92.62470245, 25.11869049], [92.62996674, 25.12503052], [92.63079834, 25.13183975], [92.6324234, 25.13755989], [92.63800812, 25.1452198], [92.6440506, 25.15117073], [92.64826965, 25.15265274], [92.65120697, 25.15240097], [92.65571594, 25.15413094], [92.65953827, 25.15912056], [92.66081238, 25.16225243], [92.66297913, 25.1729908], [92.66433716, 25.17535973], [92.66690826, 25.17706108], [92.67224121, 25.17815971], [92.6770401, 25.18218994], [92.6794281, 25.18309021], [92.68284607, 25.18204117], [92.68762207, 25.18231964], [92.69393921, 25.18135071], [92.70461273, 25.19052124], [92.71621704, 25.19415855], [92.72416687, 25.19919968], [92.7333374, 25.20322037], [92.74202728, 25.20309067], [92.74713898, 25.20776939], [92.7516861, 25.20734978], [92.75453949, 25.20537186], [92.75889587, 25.20402908], [92.76345062, 25.20384979], [92.76764679, 25.2047596], [92.77957153, 25.20310974], [92.78775024, 25.20952988], [92.79289246, 25.21235275], [92.7984314, 25.21344948], [92.80356598, 25.21723938], [92.80442047, 25.21932983], [92.80309296, 25.22150993], [92.79434967, 25.22600937], [92.78630829, 25.23140144], [92.77223969, 25.2332592], [92.77028656, 25.24020004], [92.76464844, 25.24934959], [92.77670288, 25.2605381], [92.77617645, 25.26293945], [92.76976013, 25.26893044], [92.77947235, 25.27376175], [92.78211975, 25.27592087], [92.78913879, 25.27852249], [92.79222107, 25.28518105], [92.79222107, 25.28679848], [92.78882599, 25.29154015], [92.78691101, 25.30067062], [92.78383636, 25.30800056], [92.78473663, 25.31152916], [92.78801727, 25.31760979], [92.78437042, 25.3325386], [92.78246307, 25.33428955], [92.77245331, 25.33961105], [92.76947021, 25.33950806], [92.76326752, 25.33559036], [92.76056671, 25.33527946], [92.75875854, 25.33986092], [92.75115967, 25.34847069], [92.75009918, 25.35437965], [92.74823761, 25.35811043], [92.7456665, 25.3611393], [92.74060822, 25.36372948], [92.74009705, 25.36464119], [92.74059296, 25.36678123], [92.73610687, 25.37380981], [92.73705292, 25.38125038], [92.73480988, 25.38249969], [92.72543335, 25.38043022], [92.72136688, 25.37549019], [92.7205658, 25.37490273], [92.7181015, 25.37498283], [92.716362, 25.37934113], [92.71289825, 25.38454056], [92.70973206, 25.38611984], [92.70292664, 25.38661957], [92.70037842, 25.38779068], [92.69351959, 25.39999008], [92.68817139, 25.40442085], [92.68004608, 25.40858078], [92.67376709, 25.41714096], [92.67093658, 25.41671944], [92.66703796, 25.41407967], [92.66368866, 25.40937042], [92.66010284, 25.41036034], [92.65688324, 25.41570091], [92.65365601, 25.42394066], [92.65428162, 25.43534088], [92.65054321, 25.43166924], [92.64163208, 25.41953278], [92.63961029, 25.41963005], [92.63922882, 25.4203701], [92.63791656, 25.42266083], [92.63791656, 25.42881966], [92.63265991, 25.43314171], [92.62930298, 25.43464088], [92.62851715, 25.43061066], [92.62931061, 25.42699051], [92.62864685, 25.42502975], [92.62063599, 25.42371941], [92.6178894, 25.42202187], [92.61477661, 25.41743088], [92.61183929, 25.41612053], [92.60909271, 25.41657066], [92.60700989, 25.41853905], [92.60697174, 25.42718124], [92.60775757, 25.43035126], [92.60529327, 25.4419117], [92.60555267, 25.44836044], [92.60450745, 25.4501915], [92.60114288, 25.45239067], [92.60018921, 25.45387268], [92.59976959, 25.45705032], [92.60138702, 25.46413994], [92.59815979, 25.47165108], [92.59369659, 25.47101021], [92.58544159, 25.4675808], [92.58229065, 25.47289085], [92.5714798, 25.46407127], [92.56912994, 25.46479034], [92.56741333, 25.46747017], [92.56655121, 25.47512054], [92.56783295, 25.48077011], [92.57559204, 25.49043083], [92.58104706, 25.49515915], [92.58950043, 25.49951935], [92.59358215, 25.50308037], [92.60559082, 25.50811958], [92.60959625, 25.51260948], [92.62162781, 25.51575089], [92.62760925, 25.52221107], [92.63762665, 25.52852821], [92.6446991, 25.53744125], [92.64496613, 25.54660034], [92.64987946, 25.56001091], [92.65735626, 25.5633812], [92.66065216, 25.57031822], [92.66072083, 25.58184052], [92.66047668, 25.58506012], [92.65760803, 25.58906174], [92.65345764, 25.59218025], [92.65119171, 25.59272957], [92.64833832, 25.59235001], [92.64063263, 25.58736992], [92.63414764, 25.57888031], [92.63323212, 25.57479095], [92.63056946, 25.57066917], [92.6288681, 25.56949043], [92.62610626, 25.5680294], [92.62110138, 25.56830978], [92.61248779, 25.56550026], [92.60871124, 25.56573105], [92.60349274, 25.56108284], [92.60259247, 25.55738068], [92.59346771, 25.55393028], [92.58747864, 25.55298805], [92.58141327, 25.55977249], [92.57610321, 25.55965042], [92.57250214, 25.56042099], [92.56954193, 25.56446075], [92.56468201, 25.56825829], [92.56095886, 25.57425117], [92.56092834, 25.58273125], [92.55632019, 25.59280014], [92.55724335, 25.59621048], [92.55618286, 25.6058712], [92.55861664, 25.60895157], [92.55761719, 25.61198807], [92.55323792, 25.6138401], [92.54453278, 25.61425018], [92.54043579, 25.61777115], [92.5332489, 25.61594963], [92.51727295, 25.62008286], [92.51055145, 25.61720085], [92.50170898, 25.62293053], [92.49790192, 25.62696075], [92.49326324, 25.63613129], [92.48828888, 25.64999008], [92.48134613, 25.66389275], [92.47466278, 25.67331123], [92.47154999, 25.67494965], [92.46544647, 25.68246078], [92.45987701, 25.68297005], [92.45524597, 25.6842308], [92.45128632, 25.68661118], [92.44303894, 25.68765259], [92.44001007, 25.68922043], [92.44046783, 25.68812943], [92.43434143, 25.68753052], [92.43213654, 25.69100952], [92.43334198, 25.69523048], [92.43152618, 25.70425034], [92.42722321, 25.71041107], [92.42962646, 25.71326828], [92.43644714, 25.71560097], [92.4420166, 25.72085953], [92.4331665, 25.73145294], [92.43200684, 25.7319603], [92.42134857, 25.72945023], [92.41697693, 25.72968102], [92.41277313, 25.73298073], [92.41326141, 25.73396111], [92.41246796, 25.73739052], [92.41639709, 25.7404995], [92.41073608, 25.74312973], [92.40479279, 25.74369049], [92.39476776, 25.74147987], [92.39212799, 25.74259949], [92.38696289, 25.74311066], [92.38495636, 25.74475098], [92.38353729, 25.7474308], [92.38433838, 25.75032997], [92.38694763, 25.752491], [92.38510132, 25.75356293], [92.37146759, 25.7464695], [92.36753845, 25.74238014], [92.36830902, 25.74044037], [92.36299896, 25.73651123], [92.35179901, 25.73487091], [92.34805298, 25.73193169], [92.33901215, 25.72685051], [92.33354187, 25.72523117], [92.31768036, 25.72379112], [92.3139267, 25.72468185], [92.31150055, 25.72607994], [92.30825806, 25.72615051], [92.30610657, 25.72313118], [92.29358673, 25.71730042], [92.28797913, 25.71590042], [92.28460693, 25.71586037], [92.27052307, 25.71093178], [92.260849, 25.7103405], [92.25570679, 25.7107296], [92.25357819, 25.71012115], [92.24804688, 25.71096039], [92.23684692, 25.70839119], [92.23475647, 25.70882034], [92.23384857, 25.71006966], [92.23262787, 25.71511078], [92.22899628, 25.71620941], [92.22490692, 25.71397018], [92.21063995, 25.69592094], [92.20156097, 25.68972015], [92.2000885, 25.68728828], [92.19831085, 25.68635941], [92.19692993, 25.68695068], [92.19407654, 25.68611908], [92.19198608, 25.68632126], [92.18791962, 25.68343163], [92.18477631, 25.6811409], [92.17495728, 25.67021751], [92.17095184, 25.66687965], [92.16976166, 25.66640091], [92.16445923, 25.66931915], [92.16069794, 25.67185974], [92.1605072, 25.67329025], [92.16546631, 25.67840958], [92.16435242, 25.68485069], [92.16044617, 25.69090271], [92.16145325, 25.69598007], [92.16104889, 25.69729042], [92.15757751, 25.70103836], [92.15585327, 25.70914268], [92.15106201, 25.71183014], [92.14956665, 25.71450806], [92.15101624, 25.71936989], [92.15371704, 25.72270012], [92.15629578, 25.72481155], [92.16092682, 25.72625923], [92.16423035, 25.72873116], [92.16552734, 25.73444939], [92.1648407, 25.74475098], [92.15824127, 25.75719833], [92.15738678, 25.76197052], [92.15596771, 25.76454163], [92.15410614, 25.77292061], [92.15421295, 25.77672958], [92.15518188, 25.77864265], [92.15479279, 25.77977943], [92.15099335, 25.78364944], [92.15116882, 25.78745079], [92.15368652, 25.79549026], [92.15310669, 25.81274986], [92.15573883, 25.81659126], [92.16308594, 25.82183075], [92.16326141, 25.82575035], [92.16551971, 25.83304024], [92.16934204, 25.8353405], [92.17144012, 25.83773041], [92.17524719, 25.84654236], [92.17830658, 25.84807968], [92.18096161, 25.85136032], [92.18078613, 25.86321068], [92.17910004, 25.86791039], [92.17988586, 25.8701725], [92.1810379, 25.87162018], [92.18694305, 25.87481117], [92.19496155, 25.88126945], [92.20332336, 25.89009094], [92.20641327, 25.89145279], [92.21286011, 25.8921299], [92.21560669, 25.89384079], [92.2182312, 25.90019989], [92.22384644, 25.90068817], [92.22503662, 25.90162086], [92.22547913, 25.90704918], [92.22380066, 25.91036034], [92.22260284, 25.91131973], [92.2175293, 25.90991974], [92.20752716, 25.91053009], [92.20513916, 25.90871048], [92.20059967, 25.90824127], [92.19773102, 25.91125107], [92.19700623, 25.91366005], [92.1971817, 25.91802979], [92.19203949, 25.91578293], [92.1867218, 25.91580963], [92.18364716, 25.91283035], [92.18315125, 25.91091919], [92.18089294, 25.90859032], [92.17431641, 25.90918922], [92.16369629, 25.91179085], [92.15992737, 25.91518974], [92.16017151, 25.92596054], [92.16142273, 25.93254089], [92.15751648, 25.93927956], [92.15609741, 25.94300079], [92.15631866, 25.94479942], [92.16075897, 25.95152092], [92.16532898, 25.95395088], [92.16732788, 25.95876122], [92.16555023, 25.96443939], [92.16739655, 25.96769905], [92.17311096, 25.97219849], [92.17694092, 25.97310066], [92.18097687, 25.97523117], [92.19161987, 25.98520279], [92.20089722, 25.98560905], [92.20738983, 25.98823166], [92.2091217, 25.9896698], [92.2077179, 25.99174118], [92.21100616, 25.99465942], [92.21520233, 25.99627113], [92.2191925, 26.00078011], [92.22168732, 25.99860191], [92.22141266, 26.00225067], [92.25572205, 26.02893257], [92.30158234, 26.0764904], [92.29966736, 26.07673073], [92.2973175, 26.07914925], [92.29598236, 26.07888985], [92.29392242, 26.07779121], [92.29004669, 26.0737896], [92.29014587, 26.07279968], [92.28806305, 26.06999016], [92.2807312, 26.06918907], [92.27368927, 26.06501961], [92.27372742, 26.06589127], [92.27231598, 26.0666008], [92.26864624, 26.0679493], [92.26568604, 26.06539917], [92.25145721, 26.06436157], [92.24117279, 26.06254005], [92.22834015, 26.0676403], [92.21835327, 26.07015038], [92.21611023, 26.0692997], [92.21356201, 26.06967926], [92.21201324, 26.07097054], [92.21042633, 26.07110023], [92.2088089, 26.07065964], [92.20934296, 26.06918907], [92.20826721, 26.06856918], [92.20182037, 26.07002068], [92.1893692, 26.06688118], [92.18834686, 26.06887054], [92.18460083, 26.06918907], [92.18232727, 26.07034111], [92.18044281, 26.06850052], [92.17888641, 26.06921005], [92.18094635, 26.0761795], [92.17830658, 26.07950974], [92.16909027, 26.07759094], [92.15467834, 26.06805992], [92.15052032, 26.06489944], [92.14898682, 26.06163025], [92.14621735, 26.05855942], [92.14377594, 26.05764008], [92.13816833, 26.0528183], [92.13311768, 26.04589081], [92.12702179, 26.04590034], [92.12338257, 26.04488945], [92.1162262, 26.04655266], [92.10888672, 26.04971123], [92.0933609, 26.04852104], [92.08113098, 26.04362106], [92.0788269, 26.04178047], [92.07363129, 26.04027939], [92.07045746, 26.03784943], [92.06321716, 26.03471756], [92.05285645, 26.03283119], [92.05018616, 26.033041], [92.03961182, 26.03622055], [92.03610229, 26.0394001], [92.03475189, 26.03968811], [92.02789307, 26.03989983], [92.02387238, 26.03843117], [92.02218628, 26.03926086], [92.01761627, 26.03959084], [92.00817871, 26.03944969], [92.00337982, 26.03803062], [92.0004425, 26.03918076], [91.99765015, 26.03884125], [91.99106598, 26.04103279], [91.98739624, 26.03872108], [91.98423004, 26.03054047], [91.9781723, 26.0258503], [91.95781708, 26.01889038], [91.9524231, 26.01781273], [91.94631958, 26.01449966], [91.94129181, 26.01400185], [91.93396759, 26.01466942], [91.92681122, 26.0016098], [91.92582703, 25.9997406], [91.92209625, 25.99953079], [91.91957092, 26.0001297], [91.91953278, 26.00159073], [91.91871643, 26.0072403], [91.91565704, 26.01032829], [91.91684723, 26.01375961], [91.9169693, 26.02146149], [91.91165161, 26.02383041], [91.90746307, 26.02711105], [91.90091705, 26.02626991], [91.89195251, 26.02955246], [91.88323212, 26.03000069], [91.87016296, 26.05219078], [91.86934662, 26.05685997], [91.87523651, 26.08456039], [91.87578583, 26.09773064], [91.86470032, 26.10034752], [91.85383606, 26.10478973], [91.82655334, 26.11814117], [91.81931305, 26.11874008], [91.81555939, 26.11144066], [91.81080627, 26.1051712], [91.80805969, 26.10382271], [91.80178833, 26.10494041], [91.79036713, 26.08702087], [91.78457642, 26.08658028], [91.78042603, 26.0883007], [91.77851868, 26.09124947], [91.77206421, 26.08448219], [91.75948334, 26.07129288], [91.73126221, 26.05920982], [91.73458862, 26.05664063], [91.73295593, 26.05102921], [91.72640991, 26.04691124], [91.72318268, 26.03032112], [91.72466278, 26.02725983], [91.72276306, 26.01979828], [91.72116852, 26.00184059], [91.71977997, 25.97830009], [91.72162628, 25.96507835], [91.7201767, 25.95407104], [91.71393585, 25.94722939], [91.70816803, 25.94437027], [91.70091248, 25.94189072], [91.70197296, 25.93792915], [91.69232178, 25.92910194], [91.68641663, 25.92124939], [91.6785965, 25.91732025], [91.67598724, 25.91183281], [91.66931152, 25.90538979], [91.66723633, 25.90818977], [91.66194153, 25.90987968], [91.65688324, 25.90788078], [91.65148926, 25.90766907], [91.6479187, 25.91374016], [91.63282776, 25.92576981], [91.62275696, 25.93099022], [91.61115265, 25.93992043], [91.6109314, 25.94460106], [91.62462616, 25.94597054], [91.63011932, 25.94463921], [91.63408661, 25.96050072], [91.63794708, 25.96484947], [91.63214111, 25.97079086], [91.62802124, 25.97697067], [91.62679291, 25.98238945], [91.62471771, 25.98590279], [91.62866974, 25.99513054], [91.62671661, 25.99765015], [91.63044739, 25.99982834], [91.63207245, 26.00187111], [91.63302612, 26.00490952], [91.63210297, 26.01395988], [91.63339996, 26.01785088], [91.63215637, 26.02240944], [91.62610626, 26.02396965], [91.62029266, 26.02703094], [91.61654663, 26.02472115], [91.60186768, 26.02263069], [91.59680939, 26.02079964], [91.59706116, 26.01706123], [91.58812714, 26.03014946], [91.58409882, 26.03198051], [91.57583618, 26.03310966], [91.57003021, 26.02748108], [91.56880951, 26.02174187], [91.56971741, 26.01684189], [91.56859589, 26.01194954], [91.56513214, 26.00750923], [91.56608582, 26.00375938], [91.56536865, 26.00184059], [91.55484009, 25.98661041], [91.5512619, 25.97489929], [91.54894257, 25.97509766], [91.53727722, 25.96838951], [91.53717041, 25.96210098], [91.53240967, 25.96224022], [91.52584839, 25.96132088], [91.52379608, 25.95940971], [91.51850128, 25.95815086], [91.51818848, 25.95280266], [91.51978302, 25.94089127], [91.51628876, 25.9383297], [91.50163269, 25.92076111], [91.50334167, 25.9143219], [91.50557709, 25.91308022], [91.51078033, 25.91543007], [91.51685333, 25.92002106], [91.521698, 25.92485046], [91.5358963, 25.93400192], [91.53132629, 25.92371178], [91.52478027, 25.92078972], [91.50853729, 25.90975952], [91.50115204, 25.89846992], [91.50325775, 25.89216042], [91.49861145, 25.8924675], [91.49291992, 25.89557838], [91.48853302, 25.89484978], [91.48338318, 25.89105988], [91.47867584, 25.8846817], [91.47593689, 25.87803841], [91.47476196, 25.87123108], [91.47738647, 25.86872292], [91.49369049, 25.86552811], [91.49830627, 25.86720276], [91.50778198, 25.86744118], [91.5135498, 25.8709507], [91.51725006, 25.87467194], [91.51976776, 25.87802124], [91.5222168, 25.88593292], [91.52577972, 25.89010811], [91.52973938, 25.88968086], [91.53205872, 25.88815117], [91.53262329, 25.88406944], [91.52887726, 25.88087082], [91.52540588, 25.87289047], [91.52176666, 25.87434959], [91.51911926, 25.87312126], [91.51275635, 25.86655807], [91.50788116, 25.8647995], [91.49603271, 25.86234093], [91.48303986, 25.86289978], [91.47840118, 25.85768127], [91.47496033, 25.85719109], [91.46872711, 25.85902977], [91.45495605, 25.85131264], [91.44740295, 25.84566116], [91.44439697, 25.84102058], [91.44122314, 25.84163094], [91.43084717, 25.84776115], [91.42430115, 25.85355949], [91.41889954, 25.85472107], [91.41272736, 25.85391808], [91.40509033, 25.84988022], [91.40119171, 25.85110092], [91.38851929, 25.84729958], [91.38211823, 25.84693909], [91.3768692, 25.84487915], [91.37049866, 25.84430122], [91.36370087, 25.84049034], [91.35688782, 25.84146118], [91.35330963, 25.83773994], [91.34855652, 25.8403511], [91.3443985, 25.83943939], [91.34249115, 25.83609962], [91.33642578, 25.83840942], [91.33355713, 25.83884048], [91.33217621, 25.83370018], [91.33242798, 25.83209038], [91.32498932, 25.8237896], [91.30632782, 25.79636955], [91.29689789, 25.77824974], [91.28729248, 25.76411057], [91.27958679, 25.75666237], [91.27646637, 25.75167084], [91.27562714, 25.74694061], [91.26228333, 25.74929047], [91.25537109, 25.74782944], [91.23249817, 25.7291584], [91.22387695, 25.72341919], [91.22144318, 25.72604942], [91.21586609, 25.72390938], [91.19799805, 25.73097992], [91.19198608, 25.72958183], [91.19233704, 25.73608971], [91.18871307, 25.73892975], [91.18917847, 25.7634697], [91.18569946, 25.76687813], [91.18591309, 25.76993942], [91.18118286, 25.77334976], [91.17993164, 25.7763195], [91.18396759, 25.78259087], [91.18474579, 25.79503059], [91.18724823, 25.80328941], [91.19095612, 25.81069946], [91.18815613, 25.81557083], [91.18987274, 25.8207798], [91.19431305, 25.82640076], [91.19451904, 25.83061028], [91.20262909, 25.84054184], [91.1986618, 25.84763908], [91.19812012, 25.8548317], [91.1964798, 25.8590107], [91.19303894, 25.85523033], [91.18547058, 25.84996986], [91.1817627, 25.84412193], [91.17901611, 25.84275055], [91.16819, 25.84563065], [91.16165161, 25.84931946], [91.15286255, 25.85007286], [91.14539337, 25.84733963], [91.13790894, 25.84213066], [91.13168335, 25.84194946], [91.12634277, 25.83819962], [91.12078094, 25.83134079], [91.08135223, 25.82934189], [91.06653595, 25.82575989], [91.06326294, 25.82036972], [91.059021, 25.82226944], [91.04988098, 25.82889938], [91.05722046, 25.83204269], [91.0617981, 25.83608055], [91.06751251, 25.83630943], [91.07287598, 25.83833122], [91.07299805, 25.84247971], [91.07853699, 25.85261917], [91.06590271, 25.84642029], [91.04910278, 25.84880829], [91.0419693, 25.83940125], [91.02494049, 25.82756042], [91.02081299, 25.82262039], [91.01270294, 25.8210907], [91.00611115, 25.8207798], [91.00078583, 25.82225037], [91.00158691, 25.82579994], [91.00866699, 25.83823967], [91.01274109, 25.84884071], [91.0131073, 25.85719109], [91.01512909, 25.85906029], [91.0218277, 25.86133194], [91.02651978, 25.86662102], [91.02910614, 25.87985039], [91.02922058, 25.88804817], [91.02828979, 25.88857079], [91.02568054, 25.88838005], [91.02060699, 25.88727951], [91.01373291, 25.88431931], [91.00132751, 25.88648987], [90.99688721, 25.8886795], [90.98480225, 25.88993263], [90.97538757, 25.88945007], [90.97132874, 25.88767052], [90.967453, 25.88718033], [90.96660614, 25.89100075], [90.96730804, 25.89664078], [90.96689606, 25.90533066], [90.96063995, 25.92769814], [90.95791626, 25.93394279], [90.95384979, 25.93670273], [90.9455719, 25.93912125], [90.94274902, 25.9475708], [90.93749237, 25.94476128], [90.93466187, 25.94114113], [90.93206787, 25.93967247], [90.91834259, 25.94316101], [90.9158783, 25.94316101], [90.91629791, 25.92814064], [90.91911316, 25.913311], [90.91607666, 25.91505814], [90.91252899, 25.92029953], [90.90119171, 25.92959023], [90.89537811, 25.93151093], [90.89704132, 25.93538094], [90.89646149, 25.93746948], [90.89238739, 25.93906021], [90.88835907, 25.94362068], [90.88298035, 25.9517498], [90.88143921, 25.95063972], [90.88022614, 25.94625092], [90.87523651, 25.94911957], [90.87240601, 25.94672966], [90.87288666, 25.94292259], [90.86960602, 25.94239998], [90.85679626, 25.94433022], [90.84323883, 25.94481087], [90.84104156, 25.94317055], [90.83983612, 25.93843269], [90.83676147, 25.93819046], [90.8361969, 25.9472599], [90.83226013, 25.94528008], [90.82800293, 25.94742966], [90.82388306, 25.94510078], [90.82044983, 25.94842911], [90.80989075, 25.95215988], [90.80869293, 25.94718933], [90.79709625, 25.9414711], [90.79170227, 25.93573952], [90.78167725, 25.92124939], [90.77848816, 25.91430092], [90.77806091, 25.90829086], [90.7690506, 25.90851021], [90.75772095, 25.91107178], [90.75762939, 25.91657066], [90.75894928, 25.9216404], [90.75006104, 25.91924095], [90.74543762, 25.91229057], [90.74234009, 25.91295052], [90.74053955, 25.91521072], [90.74619293, 25.92193031], [90.75263977, 25.93395996], [90.75070953, 25.93408012], [90.74746704, 25.93231964], [90.744133, 25.93279076], [90.74030304, 25.94089127], [90.74469757, 25.94650078], [90.74378967, 25.94943047], [90.74604797, 25.95264053], [90.74743652, 25.95732117], [90.74355316, 25.95667267], [90.74028778, 25.95491028], [90.73226929, 25.95256042], [90.72540283, 25.94877052], [90.72068024, 25.94917107], [90.71774292, 25.9547081], [90.71309662, 25.95218277], [90.68604279, 25.95080948], [90.67565155, 25.93647957], [90.6701889, 25.93425941], [90.6539917, 25.9296627], [90.63783264, 25.92333031], [90.62732697, 25.91699028], [90.62686157, 25.91127014], [90.62893677, 25.90654945], [90.62671661, 25.90135956], [90.62480927, 25.89889908], [90.61419678, 25.89950943], [90.61074829, 25.90744972], [90.60809326, 25.90801811], [90.60650635, 25.91228104], [90.60756683, 25.91958046], [90.62901306, 25.93742943], [90.60539246, 25.94695091], [90.60193634, 25.95178032], [90.59185028, 25.95211983], [90.58727264, 25.95391273], [90.5824585, 25.95979118], [90.57879639, 25.9580307], [90.57277679, 25.94815063], [90.57273865, 25.94400024], [90.57137299, 25.93902969], [90.56324005, 25.93556976], [90.55335999, 25.92912102], [90.54682159, 25.91987991], [90.53917694, 25.91546059], [90.53360748, 25.90880013], [90.52548218, 25.90101051], [90.518013, 25.89648056], [90.51254272, 25.89624023], [90.51110077, 25.90014076], [90.51851654, 25.90940094], [90.52616119, 25.92827988], [90.5322113, 25.93255234], [90.53378296, 25.93629265], [90.53479767, 25.94564056], [90.53446198, 25.95802116], [90.52983856, 25.96186066], [90.52406311, 25.96990013], [90.51355743, 25.98237038], [90.5057373, 25.99602127], [90.50013733, 26.00136185], [90.49793243, 26.00365067], [90.49236298, 26.00650978], [90.48958588, 26.00963974], [90.48121643, 26.01402283], [90.47728729, 26.0152607], [90.47090149, 26.01259995], [90.46530151, 26.00722122], [90.45909882, 26.00323105], [90.45791626, 26.00134087], [90.45751953, 25.99957275], [90.44711304, 25.99653053], [90.42862701, 25.98904037], [90.41742706, 25.99234009], [90.41649628, 25.99685097], [90.41394043, 26.00131989], [90.41104126, 26.00587082], [90.40756226, 26.00756073], [90.40019226, 26.00928116], [90.39729309, 26.01222992], [90.39649963, 26.01415062], [90.39395142, 26.01410103], [90.38736725, 26.01126289], [90.38080597, 26.01164818], [90.36499023, 26.01032066], [90.3466568, 26.00295258], [90.34485626, 26.00123978], [90.33931732, 25.9968605], [90.33692169, 25.99016953], [90.32994843, 25.9885006], [90.32905579, 25.98269844], [90.32434082, 25.97438049], [90.28658295, 25.96389961], [90.27781677, 25.96317291], [90.22737122, 25.95513916], [90.21276093, 25.95388985], [90.21112061, 25.95564079], [90.20844269, 25.96157265], [90.1939621, 25.95700073], [90.18945313, 25.95323944], [90.18566895, 25.94556999], [90.18251038, 25.94445038], [90.18052673, 25.9470005], [90.17611694, 25.95708275], [90.1726532, 25.95874977], [90.16848755, 25.95738029], [90.16349792, 25.95736122], [90.15838623, 25.95825958], [90.15448761, 25.9602108], [90.15339661, 25.9647007], [90.14739227, 25.96447945], [90.14002991, 25.95813942], [90.13407898, 25.95780945], [90.12844849, 25.95877075], [90.12322998, 25.95716286], [90.12000275, 25.9577198], [90.11865234, 25.96125984], [90.11377716, 25.95743942], [90.11091614, 25.9541111], [90.10788727, 25.95059013], [90.10536957, 25.94193077], [90.10051727, 25.9420681], [90.09913635, 25.93926048], [90.09612274, 25.93951988], [90.08795929, 25.93619919], [90.09192657, 25.92876053], [90.08738708, 25.92626953], [90.08072662, 25.92452812], [90.07945251, 25.9192791], [90.07797241, 25.91768074], [90.07242584, 25.91933823], [90.06761932, 25.91616058], [90.06330872, 25.91554832], [90.05892181, 25.91027069], [90.0550766, 25.90809059], [90.05219269, 25.89868927], [90.042099, 25.89075089], [90.03450775, 25.89351082], [90.02791595, 25.89431], [90.02126312, 25.89319038], [90.01525116, 25.88862038], [90.00473785, 25.87868118], [90.00977325, 25.87573051], [90.01436615, 25.87178993], [90.01872253, 25.87137032], [90.02137756, 25.86849022], [90.02191925, 25.86552811], [90.02076721, 25.86161041], [90.01152039, 25.84967041], [90.00831604, 25.84683037], [90.00026703, 25.84860039], [89.99756622, 25.84670067], [89.99743652, 25.84420967], [89.99983215, 25.84369087], [90.00160217, 25.84224129], [89.99780273, 25.83967018], [89.99471283, 25.83876038], [89.99080658, 25.83551025], [89.97589874, 25.83403969], [89.97354889, 25.82814026], [89.96795654, 25.82615089], [89.95886993, 25.8265686], [89.95056915, 25.82487106], [89.94458008, 25.82447815], [89.94581604, 25.82023048], [89.94561768, 25.81610107], [89.94935608, 25.81442261], [89.95199585, 25.81091118], [89.95081329, 25.79198074], [89.9526062, 25.78342056], [89.95501709, 25.78164101], [89.95524597, 25.77445984], [89.95239258, 25.77017021], [89.94668579, 25.76472092], [89.94351959, 25.76054192], [89.93371582, 25.75253105], [89.93464661, 25.74753952], [89.93350983, 25.7445507], [89.92794037, 25.74135017], [89.92186737, 25.73916817], [89.9161377, 25.73919106], [89.91137695, 25.74156952], [89.899086, 25.74405098], [89.89541626, 25.74411964], [89.89261627, 25.73500061], [89.89424133, 25.72723961], [89.90487671, 25.71478081], [89.9126358, 25.70706177], [89.91427612, 25.7040081], [89.91850281, 25.70268822], [89.91954803, 25.69676971], [89.92112732, 25.69442177], [89.93235016, 25.68996048], [89.93699646, 25.68663025], [89.94172668, 25.67811966], [89.94184875, 25.67365074], [89.94695282, 25.65883064], [89.98043823, 25.63756943], [89.98230743, 25.62843132], [89.98332214, 25.62671089], [89.99529266, 25.62302971], [89.99933624, 25.62185097], [90.00138092, 25.62443161], [90.00453949, 25.62382126], [90.01844025, 25.60839081], [90.01729584, 25.60219193], [90.01106262, 25.59835052], [90.00582123, 25.58836937], [90.00212097, 25.58419037], [89.99536133, 25.58634949], [89.98950195, 25.58880997], [89.97915649, 25.59073067], [89.97505188, 25.58350945], [89.97280884, 25.57460976], [89.96646118, 25.57170105], [89.95675659, 25.57046127], [89.94937897, 25.56825066], [89.94164276, 25.56762123], [89.93583679, 25.56270981], [89.92605591, 25.56352997], [89.91809845, 25.5626297], [89.90441132, 25.55949974], [89.88636017, 25.55787086], [89.87758636, 25.54893112], [89.87380219, 25.54928017], [89.87010193, 25.54422188], [89.87015533, 25.54494286], [89.86621094, 25.54284096], [89.86273193, 25.54319382], [89.86293793, 25.54328918], [89.86383057, 25.54381371], [89.86461639, 25.54472733], [89.86535645, 25.54558372], [89.86593628, 25.54628372], [89.86605835, 25.54683876], [89.8662796, 25.54780388], [89.86629486, 25.54914856], [89.86629486, 25.54926682], [89.86631775, 25.54957008], [89.86631775, 25.54965019], [89.86633301, 25.55078697], [89.86630249, 25.55105782], [89.86629486, 25.55148315], [89.86620331, 25.55278206], [89.86615753, 25.55345345], [89.86611176, 25.55414391], [89.86618805, 25.55472183], [89.86637878, 25.55628395], [89.86644745, 25.55659676], [89.86647034, 25.55677032], [89.86651611, 25.55745506], [89.8666153, 25.55815125], [89.86671448, 25.55870628], [89.86675262, 25.55900002], [89.8667984, 25.55927086], [89.86684418, 25.55977249], [89.86690521, 25.56006241], [89.86692047, 25.5602932], [89.86709595, 25.5614872], [89.86714172, 25.56184006], [89.8671875, 25.56211662], [89.86721039, 25.56229401], [89.86739349, 25.5627079], [89.86752319, 25.56298256], [89.86763, 25.56325722], [89.86795807, 25.56401825], [89.86811066, 25.56433678], [89.86833954, 25.56489754], [89.86846161, 25.56515121], [89.86875916, 25.56587219], [89.86917877, 25.56650543], [89.86932373, 25.56674385], [89.86950684, 25.56700325], [89.86972809, 25.56733322], [89.87011719, 25.56789207], [89.87018585, 25.56798935], [89.87030029, 25.56820107], [89.8706665, 25.56835556], [89.87098694, 25.56851578], [89.87163544, 25.56883621], [89.87225342, 25.56913948], [89.87274933, 25.56941032], [89.87286377, 25.56960678], [89.87299347, 25.56995964], [89.8731308, 25.5702877], [89.87313843, 25.57043457], [89.87316895, 25.57086945], [89.87321472, 25.57147026], [89.8729248, 25.57216454], [89.87276459, 25.57254601], [89.87295532, 25.57383156], [89.87306213, 25.57458878], [89.8732605, 25.57506943], [89.87350464, 25.57579803], [89.87374115, 25.57642746], [89.87428284, 25.57768822], [89.87445831, 25.57816505], [89.87472534, 25.57871437], [89.87504578, 25.57940674], [89.87511444, 25.57957268], [89.87515259, 25.57970238], [89.87520599, 25.58002853], [89.87533569, 25.58040237], [89.87554169, 25.58107185], [89.87557983, 25.58128548], [89.87558746, 25.58280373], [89.87556458, 25.5829792], [89.87551117, 25.58311653], [89.87531281, 25.58385086], [89.87517548, 25.58431816], [89.87505341, 25.58483505], [89.87497711, 25.58498764], [89.87482452, 25.58524895], [89.87329865, 25.58794785], [89.8732605, 25.5880146], [89.87349701, 25.58883095], [89.87361908, 25.58930779], [89.8740387, 25.59088707], [89.87423706, 25.59163094], [89.87452698, 25.59273529], [89.87466431, 25.59322929], [89.87477875, 25.59366798], [89.87534332, 25.59441757], [89.87631226, 25.59648514], [89.87649536, 25.59684753], [89.87662506, 25.59715271], [89.87667847, 25.59726334], [89.87676239, 25.59748459], [89.87699127, 25.59795189], [89.87753296, 25.59906769], [89.87787628, 25.59981155], [89.87826538, 25.60063934], [89.8787384, 25.60165596], [89.87909698, 25.60305786], [89.87932587, 25.60386658], [89.87950134, 25.60464096], [89.87971497, 25.60545349], [89.87978363, 25.60567284], [89.87983704, 25.60597038], [89.88013458, 25.60720444], [89.88023376, 25.60761452], [89.88028717, 25.60783386], [89.88037109, 25.60809708], [89.8804245, 25.60840797], [89.88052368, 25.60880852], [89.88054657, 25.60912704], [89.88054657, 25.60949898], [89.88053894, 25.60978317], [89.88054657, 25.61024666], [89.88058472, 25.61059761], [89.8806076, 25.61113358], [89.88059998, 25.61126137], [89.88105011, 25.61420441], [89.88111877, 25.61456299], [89.88146973, 25.61529541], [89.8820343, 25.61650658], [89.8822937, 25.61704445], [89.88241577, 25.61730766], [89.88206482, 25.61840439], [89.88191986, 25.6188488], [89.88168335, 25.61953735], [89.8817215, 25.62094307], [89.88172913, 25.62142563], [89.88171387, 25.62181473], [89.88171387, 25.62203407], [89.88172913, 25.62236023], [89.88175964, 25.62285042], [89.88174438, 25.62314034], [89.88174438, 25.62341499], [89.88181305, 25.62481499], [89.88175201, 25.62551308], [89.88172913, 25.62597466], [89.88168335, 25.62622643], [89.88156891, 25.62700272], [89.88154602, 25.62718582], [89.88152313, 25.62754822], [89.88148499, 25.62783051], [89.88140106, 25.62831306], [89.88134003, 25.62890434], [89.88119507, 25.62989235], [89.88115692, 25.63029099], [89.8811264, 25.63059998], [89.88101196, 25.6313839], [89.88096619, 25.6317997], [89.88069153, 25.63333321], [89.8805542, 25.63386536], [89.88046265, 25.63430214], [89.88037872, 25.63476944], [89.88031006, 25.63510895], [89.88027191, 25.6353054], [89.87981415, 25.63686562], [89.879776, 25.63698006], [89.87966156, 25.63726425], [89.87957764, 25.63751793], [89.87953186, 25.63768959], [89.87941742, 25.63810921], [89.87935638, 25.63822937], [89.87838745, 25.63915253], [89.87828827, 25.63924408], [89.87813568, 25.63939095], [89.87776947, 25.64039993], [89.87763977, 25.64076424], [89.87735748, 25.64173698], [89.87698364, 25.64300346], [89.87693024, 25.64322853], [89.87687683, 25.64341354], [89.87683868, 25.64353561], [89.8766098, 25.64429474], [89.87644196, 25.6447258], [89.87638092, 25.64496422], [89.87599945, 25.64613914], [89.87574768, 25.64694023], [89.87562561, 25.64733124], [89.87557983, 25.6475296], [89.87553406, 25.64764023], [89.87548065, 25.64787483], [89.87535095, 25.64844131], [89.87506866, 25.64956665], [89.87485504, 25.65038109], [89.8746109, 25.65134811], [89.87438965, 25.65215874], [89.87415314, 25.65313911], [89.87389374, 25.65407944], [89.87382507, 25.65430832], [89.87377167, 25.6545105], [89.87372589, 25.65469933], [89.87368774, 25.65495491], [89.87364197, 25.65509987], [89.87356567, 25.65531158], [89.87335968, 25.65573692], [89.87306976, 25.65643501], [89.87298584, 25.65664864], [89.87288666, 25.65686798], [89.87277985, 25.65709496], [89.87271118, 25.65723801], [89.87264252, 25.65736961], [89.87256622, 25.65749168], [89.87250519, 25.65760612], [89.87228394, 25.65813828], [89.87216949, 25.65818024], [89.86992645, 25.65900993], [89.86750793, 25.66070175], [89.86672974, 25.66275978], [89.86663818, 25.66294861], [89.86642456, 25.66304398], [89.86625671, 25.66312218], [89.86605072, 25.66322327], [89.86591339, 25.66331291], [89.86579132, 25.66340446], [89.86566162, 25.66347885], [89.8651886, 25.66381645], [89.86505127, 25.66393471], [89.86484528, 25.66412163], [89.86465454, 25.66433334], [89.86437225, 25.66462708], [89.86421967, 25.66477394], [89.8638382, 25.66521645], [89.86355591, 25.66559982], [89.86322784, 25.6660347], [89.86318207, 25.6661129], [89.86299896, 25.66635513], [89.86286163, 25.66654778], [89.86278534, 25.66669273], [89.86260223, 25.66699028], [89.86248016, 25.66718292], [89.86208344, 25.66804314], [89.86139679, 25.66958809], [89.86118317, 25.6701355], [89.86106873, 25.67033958], [89.86086273, 25.67076492], [89.86056519, 25.67149353], [89.86042786, 25.67190742], [89.86009979, 25.67333984], [89.85977936, 25.67466927], [89.85962677, 25.67538261], [89.85934448, 25.67675972], [89.85918427, 25.67755127], [89.85915375, 25.67773247], [89.85910797, 25.67789459], [89.85904694, 25.67810822], [89.85896301, 25.67838097], [89.8589325, 25.67853737], [89.85886383, 25.67871666], [89.85874939, 25.67903709], [89.85862732, 25.67935753], [89.85852814, 25.67966461], [89.85844421, 25.67985916], [89.85801697, 25.68037605], [89.85765839, 25.68065262], [89.85730743, 25.68091774], [89.85694885, 25.68120575], [89.85655975, 25.68152428], [89.85620117, 25.68184853], [89.85569763, 25.68230629], [89.85552979, 25.68243217], [89.85480499, 25.68330574], [89.852005, 25.68668175], [89.85171509, 25.68700409], [89.85149384, 25.68734741], [89.85044861, 25.68905067], [89.84960175, 25.6904335], [89.84922791, 25.69102669], [89.84897614, 25.69138718], [89.84877014, 25.69171906], [89.84868622, 25.69183922], [89.84864807, 25.69190216], [89.84841156, 25.69234276], [89.84789276, 25.69317245], [89.84775543, 25.69342232], [89.84764862, 25.69361115], [89.84750366, 25.69384956], [89.84724426, 25.69437981], [89.84708405, 25.69473839], [89.84703064, 25.69480705], [89.84693909, 25.69497108], [89.84689331, 25.69507027], [89.84682465, 25.69524956], [89.84671021, 25.69551086], [89.84661102, 25.69571114], [89.84657288, 25.69585609], [89.84705353, 25.6964817], [89.84751892, 25.69707108], [89.84781647, 25.69742966], [89.8480072, 25.69767189], [89.8480835, 25.69775963], [89.84815216, 25.69788361], [89.84829712, 25.69812965], [89.84849548, 25.6984005], [89.84860992, 25.69863129], [89.84867859, 25.69878387], [89.84890747, 25.69958687], [89.84899902, 25.69987679], [89.84909058, 25.70029831], [89.84913635, 25.70047188], [89.84915161, 25.7005806], [89.84918213, 25.70106316], [89.84919739, 25.70144081], [89.84918976, 25.70152092], [89.8491745, 25.70169449], [89.84922028, 25.70194817], [89.84936523, 25.7021122], [89.8495636, 25.70225716], [89.84997559, 25.70261955], [89.85030365, 25.70293617], [89.85044098, 25.70310402], [89.8506546, 25.70341682], [89.85076141, 25.70360374], [89.85115051, 25.70448112], [89.85123444, 25.70473099], [89.85131836, 25.70502281], [89.85136414, 25.70521927], [89.85138702, 25.70540237], [89.85142517, 25.70570564], [89.85150146, 25.70608521], [89.85152435, 25.70640755], [89.85189056, 25.7067337], [89.85194397, 25.70750427], [89.85196686, 25.70785904], [89.85195923, 25.70804024], [89.85190582, 25.70862389], [89.85185242, 25.70897293], [89.85179901, 25.70931053], [89.85174561, 25.70949745], [89.85157776, 25.71003532], [89.85151672, 25.71017838], [89.8514328, 25.71036148], [89.85131073, 25.71082115], [89.8510437, 25.71180725], [89.85090637, 25.7121582], [89.85083008, 25.71236229], [89.8506546, 25.71268463], [89.85049438, 25.71305656], [89.84985352, 25.71408844], [89.84976196, 25.71421623], [89.8495636, 25.71453857], [89.84932709, 25.71497917], [89.84928131, 25.71507072], [89.84918213, 25.71523285], [89.84824371, 25.71525002], [89.84809875, 25.71527672], [89.84781647, 25.71525955], [89.84673309, 25.71531868], [89.84663391, 25.71531677], [89.84632874, 25.7152977], [89.84581757, 25.71534157], [89.84539032, 25.7153244], [89.8444519, 25.71531487], [89.84375763, 25.71529388], [89.84316254, 25.71525192], [89.8425293, 25.71519089], [89.84129333, 25.71501732], [89.84085846, 25.71496773], [89.84029388, 25.71489525], [89.83970642, 25.71487999], [89.8392334, 25.71484375], [89.83903503, 25.71483803], [89.8388443, 25.71484375], [89.83803558, 25.71484375], [89.83776855, 25.71485329], [89.83751678, 25.71488571], [89.8373642, 25.71491241], [89.8370285, 25.71498871], [89.83674622, 25.71504784], [89.83614349, 25.71524239], [89.83583069, 25.71541786], [89.83504486, 25.71585083], [89.83492279, 25.71594429], [89.8348465, 25.71600342], [89.83442688, 25.71635437], [89.83429718, 25.71648979], [89.83404541, 25.71680832], [89.83388519, 25.71703529], [89.83371735, 25.71722412], [89.83365631, 25.71731377], [89.83335114, 25.71780396], [89.83324432, 25.71801186], [89.83308411, 25.71836662], [89.83271027, 25.71903992], [89.83242035, 25.71972275], [89.8323288, 25.71993065], [89.83216858, 25.72030067], [89.83210754, 25.72041702], [89.83207703, 25.72048378], [89.83197784, 25.72073936], [89.83181763, 25.72114372], [89.8317337, 25.72140503], [89.83169556, 25.72152901], [89.83165741, 25.72164536], [89.83161163, 25.72178268], [89.83155823, 25.72192955], [89.83151245, 25.72205162], [89.83135986, 25.72253609], [89.83135223, 25.7226429], [89.8312912, 25.72286034], [89.83127594, 25.72294235], [89.8311615, 25.72341156], [89.83104706, 25.72389984], [89.83096313, 25.7241993], [89.83083344, 25.72460365], [89.83073425, 25.72480392], [89.83069611, 25.72487831], [89.83063507, 25.72499847], [89.83047485, 25.72529602], [89.8303833, 25.7254715], [89.83022308, 25.72565842], [89.82924652, 25.72680855], [89.82859802, 25.72792816], [89.82827759, 25.72846985], [89.82733154, 25.72995186], [89.82733154, 25.7314949], [89.82733154, 25.73163605], [89.82709503, 25.73227882], [89.826828, 25.73301125], [89.82704163, 25.73475075], [89.8273468, 25.7359314], [89.82883453, 25.74179459], [89.82901764, 25.74251366], [89.83105469, 25.74452782], [89.83255005, 25.74626923], [89.83598328, 25.75056076], [89.83605957, 25.75066185], [89.8371048, 25.75200081], [89.83781433, 25.75305176], [89.83907318, 25.75495338], [89.83924866, 25.7553196], [89.84034729, 25.75767136], [89.84108734, 25.75881577], [89.84127045, 25.75909424], [89.84111786, 25.76012039], [89.84080505, 25.76223946], [89.84078217, 25.76236343], [89.84074402, 25.76263618], [89.84072876, 25.76270866], [89.84037781, 25.7651844], [89.83994293, 25.76839256], [89.83991241, 25.76848221], [89.83987427, 25.76861191], [89.83981323, 25.76871872], [89.83977509, 25.76882935], [89.83971405, 25.76900101], [89.83969879, 25.76918983], [89.83969116, 25.76929855], [89.83969116, 25.76976585], [89.83968353, 25.76984787], [89.83966064, 25.77000427], [89.83963013, 25.77015686], [89.83959198, 25.77033234], [89.83956909, 25.77044487], [89.83955383, 25.77059174], [89.83953094, 25.77075005], [89.83893585, 25.77325821], [89.83831787, 25.77573776], [89.83664703, 25.77897072], [89.8364563, 25.77934456], [89.83390808, 25.78304863], [89.8338623, 25.78528404], [89.83395386, 25.7866478], [89.83395386, 25.78694153], [89.83394623, 25.78723907], [89.8339386, 25.78736877], [89.83391571, 25.78764725], [89.83390045, 25.78796768], [89.83387756, 25.78819084], [89.83383179, 25.78853226], [89.83350372, 25.78879547], [89.83312988, 25.7890873], [89.8327713, 25.78943443], [89.83221436, 25.78991318], [89.83180237, 25.79033661], [89.83163452, 25.79052353], [89.83137512, 25.79088211], [89.83120728, 25.79118156], [89.83113098, 25.7913723], [89.83092499, 25.79228401], [89.83083344, 25.7928772], [89.83080292, 25.7931881], [89.83071899, 25.79402542], [89.83065796, 25.79425049], [89.83059692, 25.79448128], [89.830513, 25.79477692], [89.83031464, 25.79504585], [89.8299942, 25.79541397], [89.82985687, 25.79561806], [89.8296051, 25.79609299], [89.82939911, 25.79670906], [89.82936096, 25.79683304], [89.82931519, 25.79714012], [89.82922363, 25.79783249], [89.829216, 25.79808807], [89.82920837, 25.79821396], [89.82923889, 25.79845619], [89.82926941, 25.79865265], [89.82949066, 25.7994175], [89.82956696, 25.79960251], [89.82965088, 25.79980659], [89.82977295, 25.8001709], [89.82988739, 25.80049324], [89.82991028, 25.80075264], [89.8298645, 25.8008709], [89.82969666, 25.80124092], [89.82954407, 25.80162811], [89.82950592, 25.80173874], [89.82943726, 25.80192184], [89.82920837, 25.80260277], [89.8290329, 25.80327034], [89.82884979, 25.8037014], [89.82865143, 25.80421829], [89.82850647, 25.80458832], [89.8279953, 25.80596924], [89.82713318, 25.80821609], [89.82693481, 25.80899239], [89.826828, 25.80920982], [89.8267746, 25.80950546], [89.82674408, 25.80958366], [89.82661438, 25.8098793], [89.82653046, 25.8100853], [89.8264389, 25.81028748], [89.82496643, 25.81065941], [89.82327271, 25.81114006], [89.82291412, 25.81179619], [89.82229614, 25.8126545], [89.822052, 25.81300163], [89.82174683, 25.81311798], [89.82124329, 25.81334496], [89.82090759, 25.81349754], [89.82048798, 25.81363487], [89.81996918, 25.81380844], [89.8192749, 25.81406784], [89.8190918, 25.81403923], [89.81817627, 25.81389046], [89.81694031, 25.81296158], [89.81452942, 25.81698036], [89.81504059, 25.8175106], [89.81516266, 25.81746674], [89.81530762, 25.81742668], [89.81543732, 25.81738281], [89.81552124, 25.81735611], [89.8156662, 25.81729126], [89.81580353, 25.81726074], [89.81591797, 25.81721878], [89.81604767, 25.81717682], [89.81616211, 25.81716537], [89.81626129, 25.81713676], [89.81639099, 25.81711197], [89.81649017, 25.81708527], [89.81658936, 25.81705666], [89.81671906, 25.81702995], [89.81684875, 25.81697273], [89.81708527, 25.8169117], [89.8172226, 25.81688881], [89.817276, 25.81746864], [89.81730652, 25.81783295], [89.8187561, 25.81962204], [89.82202148, 25.82364655], [89.82230377, 25.82406425], [89.8224411, 25.82426834], [89.82284546, 25.8247776], [89.82318878, 25.8252449], [89.823349, 25.82550621], [89.82367706, 25.8259182], [89.82421875, 25.82668495], [89.82450867, 25.82709122], [89.82473755, 25.82740593], [89.82512665, 25.82796097], [89.82553864, 25.82861137], [89.82570648, 25.82880783], [89.82577515, 25.82893562], [89.82587433, 25.82911682], [89.82596588, 25.82938766], [89.82603455, 25.82967186], [89.82613373, 25.82993698], [89.82634735, 25.83049583], [89.82642365, 25.83075523], [89.8265686, 25.83127403], [89.82678223, 25.83213043], [89.82691956, 25.83250999], [89.82698059, 25.83266449], [89.82713318, 25.83296585], [89.82717133, 25.83304405], [89.82746124, 25.83320808], [89.82788849, 25.83350563], [89.82859039, 25.83399963], [89.8309021, 25.83761978], [89.83039856, 25.85214043], [89.830513, 25.85329056], [89.83270264, 25.85334015], [89.83411407, 25.85341644], [89.83410645, 25.85412407], [89.83407593, 25.85601807], [89.83489227, 25.85844994], [89.83501434, 25.85881042], [89.83557892, 25.86048889], [89.8343277, 25.86520767], [89.83413696, 25.86696815], [89.83317566, 25.8691864], [89.83309174, 25.86945343], [89.83301544, 25.86962318], [89.8328476, 25.86994362], [89.83269501, 25.87028313], [89.83258057, 25.8705368], [89.83250427, 25.87071228], [89.83283997, 25.87097359], [89.83442688, 25.87239456], [89.8358078, 25.87362862], [89.83657074, 25.87427139], [89.83774567, 25.87525749], [89.8391037, 25.87680435], [89.83966827, 25.87834549], [89.84054565, 25.87982559], [89.84069061, 25.88007545], [89.84115601, 25.88057709], [89.84231567, 25.88183403], [89.84342957, 25.88303947], [89.84481812, 25.88453865], [89.84597778, 25.88578796], [89.84611511, 25.88593483], [89.84638977, 25.88611984], [89.84672546, 25.88639832], [89.84764099, 25.88719559], [89.84799194, 25.88743401], [89.84848022, 25.88776588], [89.84873199, 25.88793373], [89.84854889, 25.88847351], [89.84837341, 25.88898468], [89.84833527, 25.88909149], [89.84819794, 25.88985062], [89.8480835, 25.89147568], [89.84812927, 25.89188576], [89.84819794, 25.89211082], [89.84880829, 25.89289284], [89.84924316, 25.89327621], [89.8494339, 25.89343262], [89.84973145, 25.89362335], [89.84983063, 25.89369202], [89.85068512, 25.89419365], [89.85108948, 25.89445877], [89.85114288, 25.89455223], [89.85131836, 25.89517975], [89.8514328, 25.89562607], [89.85158539, 25.89591789], [89.85271454, 25.89685822], [89.85297394, 25.89700508], [89.85334015, 25.89726067], [89.85365295, 25.89744759], [89.85394287, 25.89761734], [89.85441589, 25.89791489], [89.85475922, 25.89813614], [89.85527039, 25.89848518], [89.8555069, 25.89866257], [89.85587311, 25.8989563], [89.85620117, 25.89925194], [89.85636902, 25.8993988], [89.85678864, 25.89978218], [89.85720825, 25.90031433], [89.85741425, 25.90065575], [89.8576889, 25.90101814], [89.85785675, 25.90122032], [89.85803986, 25.90147591], [89.85819244, 25.90174294], [89.85855103, 25.90258026], [89.85865784, 25.90280533], [89.85904694, 25.90350723], [89.85919189, 25.90378571], [89.85948944, 25.90442276], [89.85999298, 25.90539551], [89.86013031, 25.90576553], [89.86035919, 25.90651131], [89.86045074, 25.90674782], [89.86049652, 25.90685272], [89.86062622, 25.90710449], [89.86074829, 25.90743065], [89.86142731, 25.90708733], [89.86172485, 25.90693474], [89.86308289, 25.90827942], [89.86352539, 25.90875816], [89.86408234, 25.90934372], [89.86469269, 25.91004181], [89.86525726, 25.91065598], [89.86562347, 25.91108704], [89.86591339, 25.9114151], [89.86688995, 25.91242027], [89.86756134, 25.91308403], [89.86820221, 25.91370773], [89.86871338, 25.91422462], [89.86924744, 25.91478348], [89.87043762, 25.91587257], [89.87107849, 25.91651344], [89.87164307, 25.91708374], [89.8724823, 25.91794968], [89.87343597, 25.9188652], [89.87425232, 25.91966438], [89.87477112, 25.92024422], [89.87548065, 25.92112923], [89.87614441, 25.92189407], [89.87685394, 25.92276382], [89.87763977, 25.92372131], [89.87845612, 25.92428589], [89.87853241, 25.92433548], [89.87848663, 25.92466354], [89.87830353, 25.92581367], [89.87802124, 25.92649078], [89.87793732, 25.92669678], [89.87844849, 25.92764473], [89.87910461, 25.92885017], [89.87980652, 25.93157578], [89.87986755, 25.93179703], [89.88025665, 25.93265724], [89.88134003, 25.93502045], [89.88174438, 25.93598938], [89.88260651, 25.93808365], [89.88365936, 25.93987274], [89.88460541, 25.94144249], [89.884758, 25.94169044], [89.88577271, 25.94330025], [89.88594055, 25.94358063], [89.87885284, 25.94319153], [89.87732697, 25.94310951], [89.87143707, 25.94144058], [89.86519623, 25.94098091], [89.86073303, 25.94059944], [89.85713959, 25.94008064], [89.85386658, 25.93979836], [89.8526001, 25.93925095], [89.84954071, 25.93719292], [89.84731293, 25.93597984], [89.84606171, 25.9359417], [89.84407043, 25.93733978], [89.84427643, 25.93898964], [89.84397125, 25.94011307], [89.84266663, 25.94011497], [89.8396759, 25.9410038], [89.8392868, 25.94111824], [89.8391037, 25.94117165], [89.83924103, 25.94135475], [89.83975983, 25.94196701], [89.83988953, 25.94211006], [89.83677673, 25.94161034], [89.83541107, 25.94140053], [89.8319397, 25.94146156], [89.82949829, 25.94218063], [89.82820129, 25.94355965], [89.82834625, 25.94534111], [89.8283844, 25.94581223], [89.82789612, 25.9458065], [89.82749939, 25.94578743], [89.82679749, 25.94570541], [89.82630157, 25.94565773], [89.8253479, 25.9455719], [89.82519531, 25.94623756], [89.82510376, 25.94687653], [89.82506561, 25.94712448], [89.82499695, 25.94850159], [89.82498932, 25.94875526], [89.82505035, 25.94904518], [89.82522583, 25.94981384], [89.82541656, 25.95067596], [89.82563019, 25.95162582], [89.82582855, 25.95181656], [89.82900238, 25.95477867], [89.82907867, 25.95485497], [89.83100128, 25.95521545], [89.83261871, 25.95487404], [89.83540344, 25.95363045], [89.83750916, 25.95269394], [89.83828735, 25.95233727], [89.83921051, 25.95192337], [89.84037018, 25.9514122], [89.84127808, 25.95118904], [89.84216309, 25.95098877], [89.84348297, 25.95071602], [89.84427643, 25.95064735], [89.84503937, 25.95058441], [89.84619141, 25.95046616], [89.84737396, 25.94996071], [89.84909058, 25.94925499], [89.84926605, 25.94921875], [89.84867096, 25.94964027], [89.84838867, 25.94984436], [89.84815979, 25.95001411], [89.84784698, 25.95033264], [89.847435, 25.95066452], [89.84725952, 25.95083046], [89.8470459, 25.95100784], [89.84675598, 25.95129395], [89.84670258, 25.95136833], [89.84562683, 25.95271301], [89.8453598, 25.95298004], [89.8453598, 25.95320702], [89.84516907, 25.95359802], [89.84503937, 25.953825], [89.84482574, 25.9541626], [89.84464264, 25.95450211], [89.84449768, 25.95475197], [89.84443665, 25.95486832], [89.8445282, 25.95493507], [89.84473419, 25.95511246], [89.84498596, 25.95531464], [89.84525299, 25.95554161], [89.84643555, 25.95649719], [89.84664917, 25.95659447], [89.84674072, 25.95663834], [89.84689331, 25.956707], [89.84713745, 25.95681763], [89.84698486, 25.95700073], [89.84683228, 25.95728302], [89.84628296, 25.9581089], [89.84607697, 25.95842361], [89.84596252, 25.95859528], [89.8458252, 25.95878792], [89.8456955, 25.95902252], [89.8455658, 25.95927429], [89.84548187, 25.95945549], [89.84532928, 25.95970917], [89.84522247, 25.95993614], [89.84494781, 25.96032143], [89.8447876, 25.96071434], [89.84456635, 25.96108246], [89.84442902, 25.96129036], [89.84303284, 25.96397209], [89.84255981, 25.96455765], [89.84234619, 25.96465683], [89.8401947, 25.96565056], [89.83882141, 25.9662838], [89.83874512, 25.96647453]], [[89.84065247, 25.94222641], [89.84042358, 25.94219589], [89.84061432, 25.94200134], [89.84065247, 25.94222641]]]}}, {\\\"id\\\": \\\"4\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.5_1\\\", \\\"HASC_1\\\": \\\"IN.BR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Bihar\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 80.3, \\\"dalys_apm25_rate_6cod_mean_total\\\": 752.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 2750.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3502.0, \\\"geo-id\\\": 4, \\\"hpm25_child_popweighted\\\": 455.6, \\\"hpm25_female_popweighted\\\": 523.7, \\\"hpm25_male_popweighted\\\": 377.1, \\\"location\\\": \\\"Bihar\\\", \\\"mort_apm25_6cod_mean_total\\\": 25946.0, \\\"mort_hpm25_6cod_mean_total\\\": 100623.0, \\\"mort_tpm25_6cod_mean_total\\\": 126569.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[87.26291656, 27.85071564], [87.25248718, 27.8428669], [87.25118256, 27.84306145], [87.25131989, 27.84311485], [87.26291656, 27.85071564]]], [[[87.26721191, 27.85011673], [87.26628113, 27.84945297], [87.26291656, 27.85071564], [87.26721191, 27.85011673]]], [[[88.1054306, 26.53940773], [88.10547638, 26.53903961], [88.10504913, 26.53584862], [88.10621643, 26.53601456], [88.10202026, 26.5343895], [88.1013031, 26.53530312], [88.1006546, 26.536129], [88.10301971, 26.53923607], [88.1054306, 26.53940773]]], [[[85.38336945, 24.53519058], [85.38278198, 24.53253174], [85.37026978, 24.52958107], [85.36116028, 24.52971268], [85.34581757, 24.52799988], [85.33790588, 24.52799034], [85.3315506, 24.5262413], [85.32250214, 24.52557945], [85.31855774, 24.52462959], [85.31253052, 24.52658081], [85.29734802, 24.52864075], [85.28804779, 24.52840042], [85.28251648, 24.52668953], [85.27935791, 24.51910019], [85.27980804, 24.51388168], [85.28192902, 24.509161], [85.28237152, 24.50375938], [85.28103638, 24.49975014], [85.28196716, 24.49720001], [85.26956177, 24.49837112], [85.25444031, 24.49793053], [85.24649811, 24.49529076], [85.23941803, 24.48882294], [85.23532867, 24.47985077], [85.22853851, 24.47941017], [85.22392273, 24.4711895], [85.21578217, 24.47254944], [85.20326233, 24.47294998], [85.19924927, 24.46739006], [85.19052124, 24.46858025], [85.18260193, 24.46866035], [85.17632294, 24.46797943], [85.1698761, 24.46609116], [85.16750336, 24.46735954], [85.16323853, 24.46718979], [85.15289307, 24.46414948], [85.15067291, 24.46286964], [85.14927673, 24.45928001], [85.14990997, 24.45585251], [85.15260315, 24.45375061], [85.15872955, 24.45125008], [85.16133118, 24.44329071], [85.16372681, 24.4414196], [85.1648407, 24.43580055], [85.16625977, 24.43349075], [85.1688385, 24.4317894], [85.16938019, 24.42947006], [85.16439056, 24.42769051], [85.1578598, 24.42416], [85.15529633, 24.41801071], [85.14795685, 24.4181881], [85.12693024, 24.41151047], [85.1206665, 24.40843964], [85.11898804, 24.40913963], [85.1150589, 24.40901947], [85.10932922, 24.39882088], [85.09867096, 24.3939209], [85.09594727, 24.39077187], [85.092453, 24.38152122], [85.0894165, 24.37919998], [85.08068085, 24.38075066], [85.06548309, 24.38676071], [85.07100677, 24.39969254], [85.06919861, 24.40119934], [85.07038879, 24.40517998], [85.07302094, 24.40653992], [85.07454681, 24.40846252], [85.07375336, 24.4129982], [85.07567596, 24.42175102], [85.07615662, 24.43987083], [85.06906891, 24.43565941], [85.06461334, 24.43058968], [85.06040955, 24.42460823], [85.05748749, 24.41648293], [85.05329132, 24.41513062], [85.04223633, 24.41827965], [85.03954315, 24.42412758], [85.03573608, 24.42311287], [85.03209686, 24.42535019], [85.02066803, 24.42201996], [85.01460266, 24.41912079], [85.01069641, 24.41608047], [84.99040222, 24.41222954], [84.96856689, 24.37594986], [84.94793701, 24.37177086], [84.93495178, 24.37645912], [84.92533875, 24.37804031], [84.91297913, 24.37565041], [84.90331268, 24.37231064], [84.89803314, 24.37212944], [84.89441681, 24.37504005], [84.9005127, 24.38208008], [84.8981781, 24.39381981], [84.89190674, 24.39853096], [84.88234711, 24.41710281], [84.87789917, 24.42263031], [84.88004303, 24.43204117], [84.87805176, 24.44379044], [84.88017273, 24.46280098], [84.87625122, 24.46278954], [84.87271881, 24.46582031], [84.8674469, 24.46692085], [84.8629303, 24.4576416], [84.85974884, 24.45664024], [84.85703278, 24.45758247], [84.85733795, 24.46076965], [84.84748077, 24.46593094], [84.84198761, 24.45547104], [84.83439636, 24.45252037], [84.83062744, 24.45920944], [84.83273315, 24.46116066], [84.83345795, 24.46958923], [84.82718658, 24.47011948], [84.82792664, 24.48600006], [84.83262634, 24.51148033], [84.81949615, 24.52482033], [84.80164337, 24.52111816], [84.79532623, 24.52949142], [84.78970337, 24.52154922], [84.78367615, 24.51770973], [84.7798996, 24.50485039], [84.7629776, 24.50176811], [84.74201965, 24.49645805], [84.74006653, 24.48826981], [84.72490692, 24.47294998], [84.71750641, 24.4688282], [84.71292877, 24.46863174], [84.70652771, 24.4723587], [84.69407654, 24.46179962], [84.68405914, 24.45919991], [84.67891693, 24.4563427], [84.67401123, 24.44114113], [84.66622925, 24.43119049], [84.66584778, 24.42843056], [84.66838837, 24.42629051], [84.66779327, 24.41296005], [84.66294861, 24.4106102], [84.6601181, 24.39598083], [84.65825653, 24.39374161], [84.64305115, 24.39861107], [84.62885284, 24.40017128], [84.62288666, 24.40394974], [84.61929321, 24.40205956], [84.61521149, 24.4038105], [84.61251068, 24.40121269], [84.60096741, 24.40097809], [84.59420013, 24.40401077], [84.58992004, 24.4043808], [84.58184814, 24.40146065], [84.58006287, 24.41041946], [84.57247925, 24.41234016], [84.56539154, 24.4074707], [84.56121826, 24.40184021], [84.55912018, 24.39710808], [84.56430817, 24.38989067], [84.56578064, 24.38393974], [84.5560379, 24.3797226], [84.54585266, 24.37369919], [84.54167938, 24.37671089], [84.52152252, 24.37626076], [84.52406311, 24.36876106], [84.52796173, 24.36483002], [84.52671051, 24.36102104], [84.51882172, 24.35316086], [84.51937866, 24.34584045], [84.52548981, 24.33947945], [84.51741028, 24.33366966], [84.51419067, 24.3236084], [84.51069641, 24.3171711], [84.50319672, 24.31541061], [84.50454712, 24.30590057], [84.50123596, 24.29880905], [84.50229645, 24.29454994], [84.49688721, 24.29272079], [84.4935379, 24.28704071], [84.48420715, 24.29692078], [84.48751068, 24.29883957], [84.48874664, 24.3021698], [84.48706055, 24.30483246], [84.47856903, 24.30289078], [84.47534943, 24.30256271], [84.46839905, 24.30529022], [84.46511078, 24.30838966], [84.46196747, 24.31755066], [84.45453644, 24.33864975], [84.4466629, 24.3397007], [84.44491577, 24.33418083], [84.41742706, 24.33136177], [84.41816711, 24.34235954], [84.42253876, 24.35914993], [84.39494324, 24.36779022], [84.3997879, 24.37463951], [84.39766693, 24.37741089], [84.39202881, 24.37574959], [84.3850174, 24.37934113], [84.38221741, 24.38969994], [84.37377167, 24.39099121], [84.36725616, 24.38695908], [84.36136627, 24.38663292], [84.3553009, 24.39096069], [84.34696198, 24.39207077], [84.33586121, 24.39583015], [84.33798218, 24.40129089], [84.33162689, 24.40464973], [84.3258667, 24.41093063], [84.32779694, 24.41657066], [84.32778931, 24.4221611], [84.32486725, 24.42366982], [84.3182373, 24.42021942], [84.31505585, 24.42345238], [84.31939697, 24.42925072], [84.32749176, 24.42772865], [84.33065796, 24.42843056], [84.33039856, 24.43119049], [84.31498718, 24.44750977], [84.29321289, 24.45082283], [84.29022217, 24.45808029], [84.28526306, 24.46591949], [84.29418945, 24.48076057], [84.3082428, 24.48690033], [84.32170868, 24.48975754], [84.32565308, 24.49670982], [84.32634735, 24.50271988], [84.32168579, 24.51317978], [84.31910706, 24.52231026], [84.31284332, 24.52676964], [84.3119278, 24.53375816], [84.30944824, 24.53954124], [84.30200958, 24.54725266], [84.29743195, 24.56314278], [84.29297638, 24.56599045], [84.27997589, 24.56336021], [84.26922607, 24.56425285], [84.27189636, 24.55402184], [84.28009033, 24.55191994], [84.27828217, 24.54747009], [84.26859283, 24.54685974], [84.26944733, 24.54136848], [84.26474762, 24.54057121], [84.26274109, 24.53711128], [84.25846863, 24.53769112], [84.25714111, 24.53075027], [84.24852753, 24.53158951], [84.24994659, 24.5357399], [84.24829865, 24.53876114], [84.24108887, 24.54322052], [84.23426056, 24.5435791], [84.23500824, 24.55318069], [84.22068024, 24.55033112], [84.21749115, 24.5351696], [84.20892334, 24.53716087], [84.20620728, 24.54533005], [84.20050049, 24.54944038], [84.19991302, 24.55702019], [84.18830109, 24.55532074], [84.18695831, 24.54930115], [84.18158722, 24.54706001], [84.17288208, 24.54713058], [84.17282104, 24.54198074], [84.18239594, 24.52360916], [84.18641663, 24.52249908], [84.18225861, 24.51834106], [84.18226624, 24.51563072], [84.17926025, 24.51041985], [84.17137146, 24.50979042], [84.16114044, 24.51258278], [84.15364075, 24.51764107], [84.15589142, 24.51948166], [84.15571594, 24.52433968], [84.16440582, 24.53371239], [84.16065979, 24.53824043], [84.14955902, 24.54030037], [84.14605713, 24.54030037], [84.1362915, 24.52936172], [84.1370163, 24.51818085], [84.13996124, 24.5048008], [84.13654327, 24.50254059], [84.12901306, 24.50068092], [84.12490845, 24.49831963], [84.12258148, 24.48666954], [84.10977936, 24.48139954], [84.10092163, 24.48790169], [84.0969696, 24.49572182], [84.08909607, 24.5041275], [84.086586, 24.51463127], [84.08969116, 24.53392982], [84.08870697, 24.53607941], [84.08429718, 24.5387001], [84.07833862, 24.54500961], [84.07723999, 24.5524807], [84.07367706, 24.55758095], [84.07467651, 24.56475067], [84.07247925, 24.56960106], [84.06774139, 24.57102966], [84.06526184, 24.57505989], [84.05974579, 24.57698059], [84.06265259, 24.58371925], [84.06136322, 24.58937073], [84.05808258, 24.58836174], [84.05293274, 24.5879612], [84.05142212, 24.59152031], [84.05311584, 24.59469986], [84.04785919, 24.60650826], [84.0448761, 24.6069603], [84.04673767, 24.61228943], [84.03823853, 24.61940956], [84.0332489, 24.61895943], [84.03205109, 24.62157822], [84.0289917, 24.62264061], [84.0267868, 24.62774277], [84.02416992, 24.62906075], [84.01963806, 24.62681961], [84.01566315, 24.62760162], [84.01452637, 24.63163948], [84.00196838, 24.63540077], [83.99221039, 24.63803291], [83.97924042, 24.61512947], [83.97235107, 24.59662819], [83.9648819, 24.58764076], [83.95758057, 24.57632828], [83.94818115, 24.56651115], [83.93649292, 24.55591965], [83.93300629, 24.55174255], [83.92845917, 24.54791069], [83.92407227, 24.54620934], [83.9179306, 24.54578972], [83.90274811, 24.54244041], [83.87885284, 24.53650093], [83.86804199, 24.53288078], [83.8576889, 24.53755951], [83.84807587, 24.5363102], [83.8414917, 24.53450012], [83.82740021, 24.53314972], [83.81623077, 24.53125954], [83.80895233, 24.52894974], [83.79901123, 24.52988052], [83.794487, 24.52944946], [83.78803253, 24.52717018], [83.78174591, 24.52358055], [83.74865723, 24.51053047], [83.73073578, 24.50879097], [83.71669006, 24.50494957], [83.70236969, 24.50733948], [83.69567871, 24.51061058], [83.68245697, 24.51558113], [83.67080688, 24.51477051], [83.66252899, 24.51568031], [83.64483643, 24.51618004], [83.60015869, 24.51324081], [83.59240723, 24.51489067], [83.57121277, 24.51700974], [83.54725647, 24.52403069], [83.54244232, 24.52618027], [83.53504181, 24.52557945], [83.52384186, 24.52592087], [83.50950623, 24.52754021], [83.49816895, 24.52705956], [83.49761963, 24.52897072], [83.49320221, 24.53607941], [83.49341583, 24.54207039], [83.50495911, 24.54438972], [83.5171814, 24.54916954], [83.51793671, 24.55494118], [83.52458954, 24.5673008], [83.52400208, 24.57502174], [83.52514648, 24.58019829], [83.52498627, 24.58503914], [83.52350616, 24.58782005], [83.51999664, 24.59101105], [83.51721954, 24.59873009], [83.51743317, 24.60322952], [83.52555847, 24.61368942], [83.53453064, 24.61560059], [83.53843689, 24.62162971], [83.54171753, 24.6245594], [83.54141235, 24.62618065], [83.53890991, 24.62774277], [83.52068329, 24.6300106], [83.52419281, 24.64209938], [83.52394104, 24.64435005], [83.52169037, 24.64453125], [83.51590729, 24.64282036], [83.50717163, 24.64937019], [83.50251007, 24.64871025], [83.49971771, 24.64941025], [83.49752045, 24.65166092], [83.49704742, 24.65921974], [83.4994812, 24.66847992], [83.50218201, 24.67158127], [83.51319122, 24.67892075], [83.51370239, 24.68115044], [83.51264954, 24.68341064], [83.50917053, 24.6847496], [83.49990082, 24.69453049], [83.49571228, 24.6962204], [83.49498749, 24.70268059], [83.49205017, 24.70516014], [83.48960876, 24.70585823], [83.48589325, 24.70271111], [83.48335266, 24.70295906], [83.48071289, 24.70573235], [83.47997284, 24.70993805], [83.48036957, 24.71620941], [83.48327637, 24.72277069], [83.48332214, 24.73106956], [83.48245239, 24.73493958], [83.47984314, 24.73783112], [83.47532654, 24.73801994], [83.47174835, 24.73567009], [83.46695709, 24.73452759], [83.46243286, 24.73513031], [83.45308685, 24.73332024], [83.44467163, 24.74044991], [83.44146729, 24.74403], [83.43424225, 24.75684929], [83.42542267, 24.76311111], [83.41941833, 24.76987076], [83.41129303, 24.77532005], [83.40344238, 24.77667046], [83.39409637, 24.77947044], [83.38680267, 24.78421974], [83.38633728, 24.78659058], [83.3884964, 24.79154015], [83.39254761, 24.7971096], [83.38990021, 24.80185127], [83.39006042, 24.80442047], [83.39559937, 24.81099129], [83.39566803, 24.81559944], [83.39492798, 24.8202095], [83.39131165, 24.82315826], [83.38963318, 24.82715034], [83.39038849, 24.83308029], [83.38915253, 24.83607101], [83.38527679, 24.84007072], [83.38250732, 24.84025955], [83.38076019, 24.84303093], [83.38101959, 24.84445953], [83.37864685, 24.84613991], [83.36827087, 24.86318016], [83.35575104, 24.86865044], [83.35399628, 24.87061119], [83.3572464, 24.87352753], [83.36316681, 24.87697029], [83.36424255, 24.87858009], [83.36386871, 24.88043976], [83.36180115, 24.88233948], [83.35623169, 24.88430977], [83.35489655, 24.8855381], [83.35505676, 24.88747978], [83.35617828, 24.88921928], [83.35962677, 24.89018059], [83.36001587, 24.89184952], [83.35138702, 24.90306091], [83.35121155, 24.90623283], [83.35202789, 24.90784073], [83.35598755, 24.90983963], [83.35730743, 24.91140175], [83.35803223, 24.91399002], [83.35735321, 24.91924095], [83.35852051, 24.93740082], [83.35761261, 24.94598961], [83.35790253, 24.95162964], [83.35701752, 24.95535278], [83.34938049, 24.95952988], [83.34629822, 24.96294975], [83.34393311, 24.96388054], [83.33846283, 24.96355057], [83.34052277, 24.97481918], [83.34040833, 24.97921944], [83.34593201, 24.99209023], [83.34619904, 24.99596024], [83.34487915, 25.0026207], [83.34387207, 25.01048279], [83.34208679, 25.01146126], [83.33909607, 25.01189041], [83.32765198, 25.01632118], [83.31965637, 25.01554108], [83.31817627, 25.01732063], [83.31607056, 25.02733994], [83.3164978, 25.03838158], [83.31784058, 25.04165077], [83.32345581, 25.04805183], [83.32145691, 25.05243111], [83.3219223, 25.05583], [83.32495117, 25.05597115], [83.32624054, 25.0553894], [83.32711792, 25.0533905], [83.33016968, 25.05097961], [83.33210754, 25.05050087], [83.3338089, 25.05099106], [83.33360291, 25.05803108], [83.33123779, 25.05982971], [83.32778168, 25.06100082], [83.33120728, 25.07335281], [83.33222198, 25.0824604], [83.33351135, 25.08479118], [83.33669281, 25.08634949], [83.33802795, 25.08806038], [83.34031677, 25.09864998], [83.34012604, 25.11240005], [83.34288788, 25.11248016], [83.34783936, 25.11079979], [83.35375977, 25.11037254], [83.35736084, 25.12419128], [83.35762787, 25.12792015], [83.35212708, 25.13121986], [83.35399628, 25.14017105], [83.35343933, 25.14916039], [83.3524704, 25.15182114], [83.35080719, 25.15339088], [83.34320831, 25.15867043], [83.34509277, 25.16669083], [83.34673309, 25.16959953], [83.3481369, 25.17860031], [83.34224701, 25.17885971], [83.3380127, 25.17991066], [83.33535767, 25.18139267], [83.33586121, 25.18357086], [83.34121704, 25.18555069], [83.34394836, 25.18740273], [83.34739685, 25.19304085], [83.34960938, 25.19894028], [83.35597229, 25.1986618], [83.36026001, 25.1963501], [83.36662292, 25.20033073], [83.37210083, 25.20111084], [83.3745575, 25.20251083], [83.37770844, 25.20965958], [83.37957764, 25.21175003], [83.38173676, 25.21079826], [83.38535309, 25.20602989], [83.38822174, 25.20700836], [83.38999176, 25.2116394], [83.38990021, 25.21412086], [83.39113617, 25.21558952], [83.39505005, 25.21690941], [83.39597321, 25.22252083], [83.39727783, 25.22521019], [83.40151215, 25.23003006], [83.40233612, 25.23755074], [83.40416718, 25.24241066], [83.40690613, 25.2472496], [83.40927124, 25.24928093], [83.41706848, 25.24611092], [83.41934204, 25.24636078], [83.41854858, 25.25206947], [83.41934204, 25.25332069], [83.42251587, 25.25224113], [83.4287262, 25.24448967], [83.43136597, 25.24450111], [83.43115234, 25.25008011], [83.43321991, 25.25356102], [83.43979645, 25.25920105], [83.44294739, 25.25926018], [83.45355225, 25.25127983], [83.45729065, 25.25041008], [83.46028137, 25.25197029], [83.46325684, 25.25640869], [83.4704361, 25.26267815], [83.4719162, 25.26545906], [83.470047, 25.26922989], [83.47101593, 25.27214813], [83.48026276, 25.28240967], [83.48206329, 25.28289032], [83.48619843, 25.27950287], [83.48961639, 25.28116989], [83.4912796, 25.28659058], [83.49476624, 25.28729057], [83.49572754, 25.28440285], [83.49688721, 25.28300095], [83.49820709, 25.28297043], [83.50260162, 25.28957176], [83.5080719, 25.28619957], [83.51117706, 25.28782082], [83.51795197, 25.29323959], [83.51690674, 25.29846954], [83.51693726, 25.30060959], [83.51806641, 25.3024807], [83.52002716, 25.30332184], [83.52310181, 25.30045128], [83.52561188, 25.29953957], [83.52879333, 25.30144119], [83.53118134, 25.30451012], [83.54257965, 25.30932045], [83.54531097, 25.30985069], [83.54664612, 25.31160927], [83.5443573, 25.31314278], [83.53314972, 25.31287193], [83.53465271, 25.31520081], [83.53946686, 25.31764984], [83.54747772, 25.31585121], [83.55123138, 25.31389236], [83.55430603, 25.31406975], [83.56088257, 25.31608009], [83.56426239, 25.31585121], [83.56289673, 25.30965805], [83.56417084, 25.30814934], [83.56938171, 25.31013107], [83.57224274, 25.31761932], [83.57788086, 25.31664848], [83.5788269, 25.31726837], [83.58081818, 25.32234955], [83.58389282, 25.32489014], [83.58805847, 25.32644081], [83.60320282, 25.33156967], [83.60721588, 25.33230972], [83.61065674, 25.3325901], [83.61464691, 25.33166122], [83.62005615, 25.32858086], [83.62238312, 25.32952118], [83.62477112, 25.33493805], [83.62835693, 25.33625031], [83.62898254, 25.3379097], [83.628479, 25.34113121], [83.62996674, 25.34324074], [83.63182831, 25.34205055], [83.63877106, 25.34015274], [83.64250183, 25.34111977], [83.64440155, 25.34500122], [83.64657593, 25.34720039], [83.64351654, 25.35444069], [83.64540863, 25.35764122], [83.65022278, 25.35910034], [83.65059662, 25.36157036], [83.6496582, 25.36544037], [83.65020752, 25.36795998], [83.65616608, 25.36366081], [83.65879822, 25.36302948], [83.66020203, 25.36387062], [83.65791321, 25.3692112], [83.66020966, 25.37100029], [83.66477966, 25.36689949], [83.66908264, 25.3644619], [83.67221832, 25.36458969], [83.67899323, 25.36658096], [83.68628693, 25.36944962], [83.68897247, 25.3712883], [83.68784332, 25.37414169], [83.67681885, 25.37675095], [83.67520142, 25.37839127], [83.67626953, 25.38170052], [83.68940735, 25.38585091], [83.69277954, 25.39377022], [83.69458008, 25.39609909], [83.69628143, 25.39635086], [83.69893646, 25.38819122], [83.70140839, 25.38585091], [83.70400238, 25.38614845], [83.70947266, 25.39525032], [83.7154007, 25.39923286], [83.71806335, 25.39981079], [83.72531128, 25.39767075], [83.72717285, 25.39850044], [83.72944641, 25.40621948], [83.7325058, 25.41060066], [83.7349472, 25.40933037], [83.73784637, 25.40089035], [83.74060059, 25.40020943], [83.74198151, 25.4005909], [83.74809265, 25.40434074], [83.7507019, 25.40497017], [83.75332642, 25.40416908], [83.75805664, 25.40121078], [83.75887299, 25.40051079], [83.75195313, 25.39839172], [83.74971771, 25.39677048], [83.74973297, 25.39206123], [83.76193237, 25.38791084], [83.76225281, 25.39114189], [83.76346588, 25.39861107], [83.7651825, 25.39966011], [83.77068329, 25.40019989], [83.78227234, 25.39872932], [83.79660797, 25.40827942], [83.79936981, 25.41098022], [83.80327606, 25.41810989], [83.80522156, 25.42453003], [83.80319214, 25.42692947], [83.79270172, 25.43015862], [83.7943573, 25.43161964], [83.79670715, 25.43279266], [83.80294037, 25.43285942], [83.81762695, 25.43732071], [83.82064819, 25.43761063], [83.82408142, 25.43324089], [83.8302002, 25.43358994], [83.83837128, 25.43688965], [83.83937073, 25.43877983], [83.83943939, 25.44211006], [83.83751678, 25.44622993], [83.83338165, 25.45014954], [83.83043671, 25.45108032], [83.82150269, 25.45158005], [83.81858826, 25.45294762], [83.81381989, 25.45389938], [83.8103714, 25.45425034], [83.80793762, 25.45325279], [83.80555725, 25.45370102], [83.80671692, 25.45850945], [83.81022644, 25.46591949], [83.81233978, 25.46790123], [83.81474304, 25.46832085], [83.82256317, 25.46202278], [83.82467651, 25.46124077], [83.82935333, 25.46149063], [83.83378601, 25.4629612], [83.8478775, 25.47100258], [83.85112, 25.47372055], [83.85491943, 25.48485947], [83.85977936, 25.48920059], [83.86443329, 25.49061966], [83.86672974, 25.49349976], [83.8712616, 25.5031929], [83.86820984, 25.51163292], [83.87296295, 25.52040291], [83.87692261, 25.52140808], [83.88247681, 25.52145958], [83.8881073, 25.52321053], [83.89280701, 25.5254612], [83.89626312, 25.52827263], [83.89942169, 25.53177071], [83.91356659, 25.55434036], [83.91705322, 25.55849075], [83.92098236, 25.56172943], [83.9253006, 25.56315231], [83.93966675, 25.56543159], [83.94432068, 25.56734085], [83.95587921, 25.57542992], [83.99156952, 25.60102272], [84.00004578, 25.60771942], [84.01423645, 25.61613083], [84.02822113, 25.62273979], [84.05683136, 25.63222122], [84.07650757, 25.63753128], [84.07969666, 25.65273094], [84.07402802, 25.67250061], [84.07356262, 25.68357277], [84.06964874, 25.69561005], [84.08289337, 25.71269035], [84.09439087, 25.72038078], [84.10787201, 25.72364044], [84.12309265, 25.72394943], [84.13511658, 25.73163033], [84.13669586, 25.72754097], [84.1367569, 25.72375107], [84.13150024, 25.72393036], [84.12654877, 25.71851921], [84.12930298, 25.71735954], [84.13572693, 25.71688271], [84.14453125, 25.72060966], [84.14834595, 25.72601128], [84.14524841, 25.72860909], [84.14823151, 25.73096085], [84.15550995, 25.7259407], [84.16750336, 25.72175026], [84.17398071, 25.7157402], [84.19431305, 25.70342064], [84.19719696, 25.69223022], [84.19950867, 25.67234993], [84.20291138, 25.66963959], [84.21707916, 25.66406059], [84.23322296, 25.6639595], [84.24759674, 25.66281128], [84.26843262, 25.66325951], [84.2729187, 25.66168976], [84.28557587, 25.66152954], [84.29013062, 25.66283035], [84.2928009, 25.66852951], [84.28218842, 25.67461014], [84.28357697, 25.67713928], [84.28777313, 25.67632294], [84.29212952, 25.67704964], [84.29477692, 25.6741581], [84.29876709, 25.67179108], [84.31212616, 25.67242813], [84.31339264, 25.66890907], [84.31858826, 25.67193985], [84.32071686, 25.68208122], [84.32356262, 25.70400047], [84.32318878, 25.72313118], [84.32443237, 25.73327065], [84.32562256, 25.7371006], [84.3312912, 25.74457169], [84.33748627, 25.74513054], [84.35440826, 25.74361992], [84.36617279, 25.73843956], [84.36950684, 25.7360096], [84.37168884, 25.73830032], [84.3675766, 25.74170113], [84.36953735, 25.74373055], [84.37296295, 25.74226952], [84.38001251, 25.74868965], [84.38852692, 25.74427986], [84.38448334, 25.73768044], [84.38117218, 25.73425102], [84.39364624, 25.72890282], [84.39311981, 25.72602081], [84.39546967, 25.72439957], [84.4004364, 25.71689034], [84.39710999, 25.70907021], [84.40187836, 25.69950104], [84.4108963, 25.69847107], [84.42360687, 25.6950798], [84.42417145, 25.71171951], [84.43247223, 25.71207809], [84.43855286, 25.71068001], [84.44877625, 25.71449089], [84.44901276, 25.71138], [84.45516968, 25.71031189], [84.45865631, 25.70321083], [84.45877838, 25.69843292], [84.4631958, 25.69864273], [84.46276093, 25.6958828], [84.46031952, 25.69071007], [84.46650696, 25.68551064], [84.48934174, 25.69108963], [84.48838806, 25.67785072], [84.49903107, 25.67739105], [84.50576782, 25.68226051], [84.51638031, 25.67770958], [84.52458954, 25.68435097], [84.52794647, 25.71537018], [84.5304718, 25.72462082], [84.53586578, 25.72649002], [84.53138733, 25.69283295], [84.55233002, 25.68403053], [84.55639648, 25.68857002], [84.55860901, 25.70098114], [84.55896759, 25.72165108], [84.55562592, 25.73640823], [84.59552002, 25.73911095], [84.61306, 25.73073959], [84.62419128, 25.72790909], [84.63059998, 25.72834015], [84.62989807, 25.73311043], [84.62628174, 25.74160194], [84.62232971, 25.74731827], [84.61487579, 25.75283813], [84.60318756, 25.75757027], [84.60053253, 25.76062965], [84.60289001, 25.77243996], [84.61013794, 25.77728081], [84.6146698, 25.77242279], [84.62075043, 25.77238083], [84.6190567, 25.78897095], [84.62111664, 25.79236031], [84.62021637, 25.79409027], [84.61682892, 25.79554939], [84.61089325, 25.80065918], [84.59819794, 25.80965042], [84.5871582, 25.81960106], [84.57141876, 25.82983971], [84.55654907, 25.83751106], [84.54685211, 25.84132004], [84.54425049, 25.82998085], [84.53292084, 25.83222961], [84.52697754, 25.83432961], [84.52625275, 25.85540962], [84.51999664, 25.86115074], [84.52825928, 25.86473083], [84.53990936, 25.8603611], [84.54055023, 25.86211967], [84.53164673, 25.87272072], [84.52864075, 25.87774086], [84.50652313, 25.8723793], [84.4852829, 25.8892498], [84.47867584, 25.88836098], [84.46655273, 25.88368988], [84.46105194, 25.888731], [84.45066071, 25.89022064], [84.44371796, 25.88966942], [84.43118286, 25.89266968], [84.4276886, 25.89118958], [84.42331696, 25.89242172], [84.42417145, 25.89833832], [84.42151642, 25.90220833], [84.4175415, 25.9114399], [84.4092865, 25.92438126], [84.40830231, 25.93135071], [84.3862915, 25.93818092], [84.36501312, 25.95053291], [84.35138702, 25.95934105], [84.34880066, 25.95998192], [84.34371185, 25.9587307], [84.3138504, 25.94796944], [84.30927277, 25.94688988], [84.30310822, 25.94639015], [84.29633331, 25.94698906], [84.29155731, 25.94828033], [84.28366089, 25.95560074], [84.27536774, 25.96129036], [84.2645874, 25.96726036], [84.25466919, 25.97108841], [84.24455261, 25.97681808], [84.24048615, 25.98275948], [84.23522949, 25.98600006], [84.22344208, 25.99117088], [84.21412659, 25.99620056], [84.20181274, 26.00056076], [84.19474792, 25.99130058], [84.192276, 25.98953819], [84.17640686, 25.99775124], [84.17243958, 25.99879074], [84.17024231, 25.99166107], [84.16622925, 25.99150085], [84.166008, 26.00270081], [84.16726685, 26.02547073], [84.1590271, 26.03224182], [84.13667297, 26.04701042], [84.12792206, 26.05553055], [84.11605072, 26.0748806], [84.1071701, 26.08171272], [84.09104156, 26.09654045], [84.08113861, 26.09976959], [84.06923676, 26.09912109], [84.04905701, 26.09970093], [84.04824829, 26.10383034], [84.04514313, 26.10631943], [84.04223633, 26.11162186], [84.04361725, 26.11717033], [84.04187775, 26.12050056], [84.04524231, 26.12042046], [84.04239655, 26.13154984], [84.03362274, 26.13747978], [84.0181427, 26.14512062], [84.02363586, 26.15414047], [84.02731323, 26.1530304], [84.02841187, 26.15962029], [84.02784729, 26.16296005], [84.02289581, 26.16534805], [84.01970673, 26.1640625], [84.01381683, 26.16698074], [84.00302124, 26.17823029], [84.00406647, 26.18069077], [84.00211334, 26.19013977], [84.00901031, 26.19955826], [84.01499939, 26.19742966], [84.02044678, 26.19755936], [84.02359009, 26.2009201], [84.02323914, 26.20449066], [84.01950073, 26.20601082], [84.01902008, 26.20928955], [84.02091217, 26.21422005], [84.0242691, 26.21976089], [84.02047729, 26.22364998], [84.01676941, 26.22161293], [84.00946045, 26.22392082], [84.0082016, 26.22531128], [84.00551605, 26.23406982], [84.01091003, 26.23581123], [84.01048279, 26.23879051], [84.01152039, 26.2406826], [84.01412201, 26.24058914], [84.01838684, 26.23878098], [84.02050018, 26.24163055], [84.02400208, 26.23958969], [84.03132629, 26.23907089], [84.03115845, 26.23567009], [84.03363037, 26.23208809], [84.04680634, 26.23019028], [84.04943848, 26.22557068], [84.05726624, 26.22521019], [84.05835724, 26.22674942], [84.07357788, 26.22488022], [84.07367706, 26.22103119], [84.07936859, 26.22121048], [84.08014679, 26.22442055], [84.08190155, 26.22710037], [84.07952118, 26.23184013], [84.08738708, 26.23653984], [84.09137726, 26.23402977], [84.09229279, 26.24022102], [84.10035706, 26.2392807], [84.10135651, 26.2430706], [84.11045837, 26.24183083], [84.11270142, 26.24967957], [84.1099472, 26.25309753], [84.11234283, 26.25657272], [84.11295319, 26.26192093], [84.12375641, 26.25881958], [84.12594604, 26.26144981], [84.1414032, 26.25774956], [84.14533997, 26.26165962], [84.1534729, 26.24526978], [84.15730286, 26.24413109], [84.15934753, 26.24590111], [84.15570831, 26.25254059], [84.15512848, 26.25772095], [84.15740204, 26.26091957], [84.16365051, 26.26136971], [84.1676178, 26.26402092], [84.1713562, 26.26773071], [84.17099762, 26.27050018], [84.16815948, 26.27367973], [84.16964722, 26.27723122], [84.1709671, 26.28664017], [84.16874695, 26.29286957], [84.17150879, 26.30369186], [84.17944336, 26.31178093], [84.18173981, 26.31703949], [84.17681885, 26.32249069], [84.16720581, 26.33810997], [84.16723633, 26.36022949], [84.1696167, 26.36256027], [84.1713562, 26.37397957], [84.15634155, 26.37825966], [84.15402985, 26.37615967], [84.13078308, 26.3821907], [84.12844086, 26.38421059], [84.11675262, 26.38524818], [84.11519623, 26.38756943], [84.09654236, 26.38791084], [84.09230042, 26.39043045], [84.08970642, 26.38751984], [84.087677, 26.39011955], [84.08116913, 26.38966942], [84.08055878, 26.38622093], [84.07884216, 26.38572121], [84.0772171, 26.38396263], [84.07200623, 26.38446999], [84.07061768, 26.38689041], [84.06151581, 26.39009094], [84.06181335, 26.39427948], [84.0550766, 26.40024757], [84.05497742, 26.40204811], [84.04509735, 26.40407181], [84.04498291, 26.4052906], [84.0412674, 26.40555], [84.04087067, 26.40849113], [84.03826141, 26.41040039], [84.03618622, 26.40784073], [84.03056335, 26.41300964], [84.03318024, 26.41378021], [84.02178192, 26.4250412], [84.02052307, 26.42884064], [84.0164032, 26.43192291], [84.01494598, 26.43947029], [84.01611328, 26.44197083], [84.01098633, 26.44845963], [84.0090332, 26.44498062], [84.00170135, 26.44359016], [83.99263, 26.44761086], [83.990448, 26.44762993], [83.9834671, 26.43490028], [83.98195648, 26.4346199], [83.96129608, 26.43714905], [83.94626617, 26.43810844], [83.9360733, 26.44168091], [83.91902161, 26.44552994], [83.9081192, 26.44950104], [83.90228271, 26.45025063], [83.90302277, 26.4610405], [83.90154266, 26.46730995], [83.90323639, 26.47227097], [83.90496826, 26.49434853], [83.90746307, 26.50037956], [83.90679169, 26.50675964], [83.90175629, 26.51044083], [83.90084076, 26.51371193], [83.90220642, 26.51807976], [83.91467285, 26.52024078], [83.93048859, 26.52478027], [83.93499756, 26.52444077], [83.9392395, 26.52128029], [83.94584656, 26.51842117], [83.94352722, 26.51589966], [83.94271851, 26.51347923], [83.94565582, 26.5102005], [83.95616913, 26.50819969], [83.9625473, 26.50860023], [83.96541595, 26.51173973], [83.96655273, 26.52095032], [83.96810913, 26.52584076], [83.97054291, 26.52943993], [83.97418976, 26.53194046], [83.9835968, 26.53146172], [83.99030304, 26.53014183], [83.99835205, 26.5273819], [83.9986496, 26.52503014], [84.00068665, 26.52501106], [84.01448059, 26.53202057], [84.02004242, 26.5320797], [84.03082275, 26.53555107], [84.0430069, 26.54096031], [84.04776001, 26.54348946], [84.04878235, 26.55033112], [84.04814148, 26.55751991], [84.04931641, 26.56159019], [84.05474854, 26.5676899], [84.05690765, 26.57341003], [84.06285095, 26.57969284], [84.06772614, 26.58130074], [84.0712204, 26.58448029], [84.07028961, 26.58925819], [84.07914734, 26.59435081], [84.08252716, 26.59959984], [84.08178711, 26.60311127], [84.08476257, 26.61055946], [84.08280182, 26.61505127], [84.08352661, 26.61825943], [84.07962036, 26.6237011], [84.08213806, 26.62655067], [84.08383942, 26.6314106], [84.08059692, 26.63392067], [84.08138275, 26.63677979], [84.08042145, 26.64075279], [84.08177948, 26.64286041], [84.08448792, 26.6401329], [84.09407806, 26.63832092], [84.09493256, 26.63648033], [84.09934998, 26.63557053], [84.09934998, 26.63396835], [84.10431671, 26.63266182], [84.1060791, 26.63723183], [84.1156311, 26.63743019], [84.12146759, 26.63462067], [84.12098694, 26.63755035], [84.12413025, 26.63741112], [84.12906647, 26.63850021], [84.13742065, 26.63648033], [84.13951111, 26.63903046], [84.15203094, 26.63850021], [84.15345764, 26.63367081], [84.14853668, 26.62774849], [84.16725159, 26.6241703], [84.16779327, 26.62629128], [84.17698669, 26.62454033], [84.18467712, 26.62585068], [84.20198822, 26.62434006], [84.20388031, 26.62053108], [84.20681763, 26.6209507], [84.21569824, 26.61868095], [84.22199249, 26.61568069], [84.22305298, 26.61309052], [84.22866821, 26.61321068], [84.2309494, 26.6097908], [84.24009705, 26.61004066], [84.25063324, 26.60794067], [84.25888824, 26.60732269], [84.26291656, 26.60302162], [84.2722168, 26.59936142], [84.27346802, 26.60135078], [84.27741241, 26.60073853], [84.27934265, 26.60658073], [84.28679657, 26.60392189], [84.28919983, 26.60699081], [84.2931366, 26.60551071], [84.29502106, 26.60663033], [84.29702759, 26.61569977], [84.30267334, 26.61747169], [84.30651855, 26.6170311], [84.3107605, 26.61457253], [84.32549286, 26.61532021], [84.3300705, 26.61832047], [84.35093689, 26.62042809], [84.37059021, 26.61539078], [84.37885284, 26.62183952], [84.38343811, 26.62150955], [84.39499664, 26.62573814], [84.4005661, 26.62413025], [84.41439819, 26.62717056], [84.40737152, 26.63805962], [84.40479279, 26.64275169], [84.40223694, 26.67122269], [84.36675262, 26.67881012], [84.35484314, 26.67888069], [84.35012054, 26.6814003], [84.34480286, 26.68042946], [84.33706665, 26.68144035], [84.32566071, 26.68425751], [84.32334137, 26.68847847], [84.31851196, 26.71623039], [84.3110199, 26.73360252], [84.30561829, 26.73768044], [84.30664825, 26.73957062], [84.29802704, 26.7532711], [84.28675079, 26.75144005], [84.27861023, 26.75123978], [84.27130127, 26.74454117], [84.26677704, 26.74207115], [84.25936127, 26.74081993], [84.25528717, 26.73896027], [84.25448608, 26.73426819], [84.25234222, 26.73147011], [84.24738312, 26.72929001], [84.24227905, 26.73077011], [84.2339859, 26.73953056], [84.2332077, 26.74510956], [84.22460938, 26.75710106], [84.23548889, 26.76698112], [84.24112701, 26.77543068], [84.24848938, 26.79268074], [84.2493515, 26.8022728], [84.25229645, 26.80867958], [84.24680328, 26.81454086], [84.2485199, 26.82089806], [84.242836, 26.82181931], [84.24646759, 26.8275795], [84.25102997, 26.83069992], [84.25041962, 26.83782005], [84.25211334, 26.84492111], [84.24563599, 26.85872269], [84.2410965, 26.86243057], [84.23538208, 26.86433983], [84.2286377, 26.8698101], [84.22196198, 26.87018013], [84.22109985, 26.87223816], [84.20922089, 26.87099075], [84.19655609, 26.86118126], [84.18955994, 26.85981941], [84.18531799, 26.86009026], [84.18080902, 26.85737991], [84.1764679, 26.85334015], [84.17694855, 26.84937859], [84.17533112, 26.84593964], [84.17740631, 26.8426609], [84.17471313, 26.8357811], [84.16892242, 26.83451843], [84.15727997, 26.83636093], [84.15054321, 26.83946991], [84.13165283, 26.85569], [84.13183594, 26.87055969], [84.13929749, 26.8740406], [84.13752747, 26.87630081], [84.13861847, 26.88306999], [84.14073944, 26.88391113], [84.14083862, 26.88758087], [84.13024902, 26.88527107], [84.12301636, 26.88902092], [84.12201691, 26.8926506], [84.11164093, 26.89188957], [84.10941315, 26.89443016], [84.10640717, 26.8950901], [84.10063171, 26.90084076], [84.09922028, 26.89521027], [84.10106659, 26.89383125], [84.09986877, 26.88799095], [84.09683228, 26.88633919], [84.09262085, 26.87783051], [84.09002686, 26.87715149], [84.08651733, 26.8789196], [84.08789063, 26.88235283], [84.08550262, 26.88524246], [84.0762558, 26.87878036], [84.07155609, 26.88187027], [84.06008911, 26.88646126], [84.05905151, 26.8907795], [84.05200195, 26.89170074], [84.04898071, 26.89994049], [84.05079651, 26.90164948], [84.04737854, 26.90621948], [84.04514313, 26.90474129], [84.04239655, 26.90912819], [84.04408264, 26.90979958], [84.04924011, 26.91459084], [84.04766846, 26.93182945], [84.04521942, 26.93042183], [84.03846741, 26.93087959], [84.03655243, 26.93301964], [84.03866577, 26.93828964], [84.03630829, 26.94113159], [84.02980804, 26.93956947], [84.02880859, 26.94120026], [84.02490234, 26.94272041], [84.02636719, 26.94896126], [84.0316925, 26.94933128], [84.03514862, 26.94872093], [84.03909302, 26.95430946], [84.03862, 26.95775986], [84.04086304, 26.95745277], [84.04415894, 26.96087074], [84.04666138, 26.96194077], [84.04599762, 26.96809006], [84.04125977, 26.96801186], [84.04345703, 26.98039055], [84.04250336, 26.9815712], [84.03643036, 26.98403168], [84.03901672, 26.98801994], [84.0459671, 26.98715973], [84.0495224, 26.99081039], [84.04432678, 26.99768066], [84.04516602, 26.99973106], [84.04270172, 27.00312042], [84.03993225, 27.00587273], [84.03044891, 27.01181984], [84.03572845, 27.01931953], [84.03595734, 27.02901268], [84.04030609, 27.03530121], [84.04081726, 27.04467964], [84.0356369, 27.0465107], [84.03125763, 27.04646111], [84.0242691, 27.0447197], [84.01217651, 27.05379105], [83.99489594, 27.06125069], [83.9907608, 27.06859016], [83.9910965, 27.07129288], [84.00559235, 27.07193947], [84.01194, 27.08127975], [84.01689148, 27.08376122], [84.01831818, 27.08723831], [84.01609802, 27.09176064], [84.01892853, 27.09344101], [84.02072144, 27.09548187], [84.01422119, 27.10008049], [84.0116272, 27.10488129], [84.00531769, 27.10403061], [84.00251007, 27.10028076], [83.99751282, 27.09848022], [83.99265289, 27.10014915], [83.99017334, 27.09884071], [83.98123169, 27.09382057], [83.97786713, 27.09262085], [83.97120667, 27.09194183], [83.9549408, 27.08612061], [83.94777679, 27.08620071], [83.94409943, 27.08725166], [83.94082642, 27.08962059], [83.93942261, 27.09299278], [83.94034576, 27.10230064], [83.93856812, 27.10732079], [83.93839264, 27.11102295], [83.93955994, 27.11667061], [83.94143677, 27.11983109], [83.94766235, 27.12362099], [83.95081329, 27.12634087], [83.9524765, 27.12898254], [83.95363617, 27.13194084], [83.95079803, 27.13908005], [83.95091248, 27.14088058], [83.95864868, 27.1486702], [83.96658325, 27.1608429], [83.9683075, 27.16559982], [83.97972107, 27.17340279], [83.98419952, 27.17871094], [83.98512268, 27.1817627], [83.97878265, 27.20043945], [83.97660828, 27.20342064], [83.96457672, 27.21100998], [83.96167755, 27.21376038], [83.96031189, 27.21665955], [83.96328735, 27.22108078], [83.96411896, 27.22319031], [83.96376038, 27.22526932], [83.96153259, 27.22795105], [83.95501709, 27.23106956], [83.95585632, 27.23352051], [83.95448303, 27.23504066], [83.94814301, 27.23833084], [83.92531586, 27.24253082], [83.91175842, 27.24650192], [83.90762329, 27.24802971], [83.90190125, 27.25213051], [83.89795685, 27.25942993], [83.89549255, 27.26815033], [83.89615631, 27.277071], [83.89804077, 27.27898979], [83.90406799, 27.2811718], [83.9105072, 27.28563118], [83.91883087, 27.29265976], [83.92188263, 27.29635811], [83.92565155, 27.30418968], [83.92534637, 27.30952072], [83.92359924, 27.31643105], [83.91668701, 27.32533073], [83.90804291, 27.33039093], [83.89758301, 27.33012962], [83.89356232, 27.32905006], [83.88794708, 27.32646942], [83.87240601, 27.31620979], [83.85907745, 27.3116703], [83.85463715, 27.31122971], [83.85051727, 27.31209946], [83.84797668, 27.31397057], [83.84741974, 27.3168602], [83.84523773, 27.31965256], [83.8425293, 27.32131195], [83.83625793, 27.3194809], [83.83058929, 27.32135963], [83.8289566, 27.32275963], [83.82849121, 27.32467079], [83.82833099, 27.3259182], [83.82933807, 27.32747078], [83.84934235, 27.33560944], [83.8549881, 27.34033012], [83.85624695, 27.3477211], [83.85640717, 27.34821129], [83.85850525, 27.35096169], [83.86479187, 27.34639359], [83.8735199, 27.35161591], [83.88989258, 27.35819817], [83.89352417, 27.36254501], [83.89421844, 27.36751556], [83.89945984, 27.37000465], [83.90551758, 27.37621498], [83.90840912, 27.38429642], [83.9072876, 27.38951683], [83.88827515, 27.39061928], [83.87523651, 27.39191246], [83.8768158, 27.40031624], [83.87758636, 27.40569878], [83.87350464, 27.41226387], [83.86938477, 27.4254303], [83.87024689, 27.42850685], [83.8744812, 27.43089485], [83.88282013, 27.434515], [83.89759827, 27.43761063], [83.9154892, 27.44121361], [83.93313599, 27.44937897], [83.93326569, 27.44940567], [83.94432068, 27.44755173], [83.94526672, 27.44672585], [83.94631195, 27.44581223], [83.94532013, 27.44332695], [83.94805145, 27.44096565], [83.96470642, 27.44382286], [83.96630859, 27.4450264], [83.96818542, 27.44643402], [83.97472382, 27.44186592], [83.97481537, 27.44183922], [83.97982025, 27.44221497], [83.97961426, 27.43911552], [83.98609161, 27.44368172], [83.9936676, 27.44393158], [83.9982605, 27.4459362], [83.9988327, 27.44558907], [83.99891663, 27.44561577], [83.99894714, 27.44552231], [83.99950409, 27.44519043], [83.99983978, 27.44303131], [84.00024414, 27.44046783], [84.00063324, 27.44139671], [84.00086975, 27.44195938], [84.00191498, 27.44127655], [84.00411224, 27.44107056], [84.00447083, 27.44195938], [84.00583649, 27.44108963], [84.00757599, 27.44195938], [84.00745392, 27.44072151], [84.00874329, 27.44049263], [84.00968933, 27.44034386], [84.00978088, 27.44015503], [84.01103973, 27.4375248], [84.0140152, 27.4386158], [84.01791382, 27.43461609], [84.02101898, 27.43591499], [84.02348328, 27.43399048], [84.02510834, 27.43274689], [84.02941895, 27.43362999], [84.02940369, 27.43377304], [84.02796173, 27.43823051], [84.02897644, 27.43893242], [84.02994537, 27.43959808], [84.03077698, 27.43940735], [84.03318024, 27.43885231], [84.03347778, 27.4401226], [84.03379822, 27.44146156], [84.03778076, 27.4407177], [84.041008, 27.4424572], [84.04129028, 27.4424324], [84.04535675, 27.44208336], [84.04557037, 27.44271469], [84.04573059, 27.44320297], [84.05354309, 27.44262886], [84.05419922, 27.44262123], [84.05683136, 27.44920158], [84.0589447, 27.45116234], [84.06390381, 27.45576286], [84.06064606, 27.46097374], [84.06182098, 27.4614296], [84.06288147, 27.46184349], [84.06412506, 27.46669006], [84.06871796, 27.46941566], [84.07059479, 27.4733181], [84.07111359, 27.47911453], [84.0723114, 27.48090363], [84.07269287, 27.48148155], [84.0760498, 27.48060799], [84.07804108, 27.48212814], [84.08031464, 27.48383331], [84.08612061, 27.48309326], [84.08856964, 27.48412514], [84.09292603, 27.48596001], [84.0931778, 27.48694038], [84.09362793, 27.48869514], [84.09754944, 27.48943138], [84.10079956, 27.5023613], [84.09928894, 27.50484276], [84.10012054, 27.50511932], [84.10191345, 27.51021576], [84.09983063, 27.51678848], [84.10961151, 27.52103615], [84.11071777, 27.52151489], [84.11100006, 27.52121735], [84.11296082, 27.5192585], [84.11880493, 27.51913261], [84.11958313, 27.51412964], [84.11967468, 27.51354027], [84.12588501, 27.51080704], [84.13201904, 27.51170921], [84.14092255, 27.51764297], [84.14589691, 27.5168972], [84.14801025, 27.5186367], [84.14871979, 27.51781464], [84.15285492, 27.51666069], [84.15296936, 27.51662827], [84.15198517, 27.51229858], [84.15335083, 27.51006126], [84.15231323, 27.50960922], [84.15145111, 27.50556183], [84.15148926, 27.50409698], [84.15101624, 27.50351334], [84.15201569, 27.50061607], [84.14751434, 27.49601555], [84.14838409, 27.49527359], [84.14753723, 27.49263573], [84.15099335, 27.48881149], [84.15099335, 27.48618126], [84.15099335, 27.48570442], [84.15397644, 27.4858284], [84.15492249, 27.48481941], [84.15583801, 27.48383904], [84.16581726, 27.48361588], [84.16925812, 27.48160362], [84.16943359, 27.48061752], [84.16963196, 27.47949028], [84.1732254, 27.47887039], [84.17372131, 27.47556114], [84.17460632, 27.47514725], [84.17767334, 27.47387123], [84.1782074, 27.47364998], [84.17828369, 27.47366714], [84.18206024, 27.47451973], [84.18456268, 27.47315216], [84.18611145, 27.4723053], [84.19089508, 27.47189903], [84.19325256, 27.46904564], [84.19660187, 27.47302818], [84.19731903, 27.47241592], [84.20171356, 27.4719162], [84.20791626, 27.46941566], [84.21101379, 27.46519852], [84.20604706, 27.45935631], [84.20950317, 27.45645523], [84.20989227, 27.45612717], [84.21038818, 27.45281219], [84.20881653, 27.44641495], [84.21057892, 27.44246101], [84.21063995, 27.44233322], [84.22170258, 27.44021988], [84.22242737, 27.4414711], [84.22306824, 27.44701958], [84.22306824, 27.44742775], [84.22605896, 27.45013237], [84.2275238, 27.45045662], [84.22911835, 27.4508152], [84.23254395, 27.45471764], [84.23375702, 27.45612717], [84.23728943, 27.45433235], [84.24133301, 27.45229912], [84.24146271, 27.45232964], [84.2461853, 27.45451164], [84.24724579, 27.45370102], [84.24829865, 27.45289612], [84.25276947, 27.45326805], [84.25624847, 27.45190048], [84.25691986, 27.44921494], [84.26030731, 27.44655037], [84.26158142, 27.4455452], [84.26087952, 27.43984032], [84.26072693, 27.43860435], [84.26407623, 27.43525124], [84.26830292, 27.43412971], [84.27020264, 27.43153954], [84.27476501, 27.42866135], [84.27574158, 27.42111969], [84.28031921, 27.41521454], [84.27973938, 27.40952492], [84.28122711, 27.40641785], [84.27762604, 27.4008255], [84.27873993, 27.39523315], [84.28458405, 27.39635086], [84.28562164, 27.39531898], [84.28657532, 27.3943634], [84.2875061, 27.39145851], [84.28759766, 27.39126968], [84.28794098, 27.39089966], [84.29341125, 27.38504219], [84.29589081, 27.38417244], [84.29750824, 27.38454437], [84.29974365, 27.38864708], [84.30272675, 27.3902626], [84.30683136, 27.38765144], [84.30789948, 27.38743401], [84.31291962, 27.38640976], [84.31835938, 27.38278198], [84.31963348, 27.38193512], [84.32116699, 27.38167953], [84.33081818, 27.38011551], [84.33320618, 27.37818909], [84.33429718, 27.3773365], [84.33921814, 27.37757874], [84.33992004, 27.37761497], [84.34121704, 27.37723351], [84.34867859, 27.37504387], [84.34911346, 27.37491608], [84.35907745, 27.37352943], [84.36064148, 27.37335968], [84.36145782, 27.37346649], [84.37442017, 27.37581444], [84.37493134, 27.37646675], [84.3897171, 27.372118], [84.39001465, 27.37182617], [84.39394379, 27.3680172], [84.39916229, 27.37012863], [84.40000916, 27.36970329], [84.40823364, 27.37012863], [84.41246796, 27.36824989], [84.41621399, 27.37051582], [84.42253113, 27.36963272], [84.42638397, 27.37174416], [84.43434906, 27.3700428], [84.43740845, 27.36938858], [84.4433136, 27.3700161], [84.4460144, 27.36841583], [84.44676208, 27.36491013], [84.44771576, 27.36421204], [84.45433044, 27.36296844], [84.45959473, 27.36197662], [84.45993805, 27.36192703], [84.4640274, 27.35909653], [84.46689606, 27.35956573], [84.46725464, 27.35878181], [84.46823883, 27.35662651], [84.47172546, 27.35499573], [84.47492218, 27.35702705], [84.47509766, 27.35819817], [84.47810364, 27.36228752], [84.48802185, 27.35832405], [84.50454712, 27.35558891], [84.50509644, 27.35513878], [84.50521851, 27.35511589], [84.51216888, 27.35435295], [84.51251984, 27.3543148], [84.51673126, 27.35260773], [84.5229187, 27.35351563], [84.53570557, 27.34988403], [84.56718445, 27.34726334], [84.58867645, 27.34102631], [84.60372162, 27.33843994], [84.61091614, 27.33581543], [84.61192322, 27.33645058], [84.61660767, 27.33704567], [84.61776733, 27.33729553], [84.62201691, 27.33820724], [84.6207428, 27.33757019], [84.62447357, 27.33607864], [84.6452179, 27.30601501], [84.68412018, 27.23641586], [84.68785095, 27.22883034], [84.68760681, 27.22753906], [84.69168091, 27.22226524], [84.69161987, 27.21801567], [84.69306183, 27.21480179], [84.68941498, 27.21391487], [84.68933105, 27.21387863], [84.68897247, 27.21304703], [84.68704987, 27.21292686], [84.68946838, 27.20882225], [84.68275452, 27.20036888], [84.68571472, 27.19641495], [84.68401337, 27.18821526], [84.68251801, 27.18591499], [84.6825943, 27.18559265], [84.68362427, 27.18570709], [84.68301392, 27.18373299], [84.68473816, 27.18404579], [84.68511963, 27.18411446], [84.6852951, 27.18370628], [84.68611145, 27.18384361], [84.68585968, 27.18241882], [84.68648529, 27.18098259], [84.68735504, 27.18011475], [84.68364716, 27.17988586], [84.68586731, 27.17762947], [84.67791748, 27.17011452], [84.68183136, 27.17001915], [84.68201447, 27.17004967], [84.68312836, 27.16855812], [84.68278503, 27.1679306], [84.68238831, 27.16719055], [84.67951965, 27.1662159], [84.67919922, 27.16278839], [84.67912292, 27.1623497], [84.679245, 27.16225624], [84.68362427, 27.15898895], [84.68648529, 27.16060448], [84.68868256, 27.15864182], [84.68881989, 27.15851784], [84.68857574, 27.15820503], [84.68449402, 27.1540184], [84.68456268, 27.15317917], [84.68462372, 27.15240097], [84.68251801, 27.15181541], [84.6853714, 27.14980507], [84.6856308, 27.14512825], [84.68571472, 27.14321518], [84.68225861, 27.13574982], [84.68169403, 27.13544655], [84.68064117, 27.13488007], [84.67952728, 27.1328907], [84.68051147, 27.13269424], [84.68138885, 27.13251877], [84.6805191, 27.13029289], [84.68002319, 27.12903786], [84.6805191, 27.12811279], [84.68101501, 27.12717438], [84.67870331, 27.12412071], [84.67753601, 27.12257576], [84.67741394, 27.12046432], [84.67902374, 27.11896896], [84.67915344, 27.1188488], [84.6791153, 27.11501503], [84.67482758, 27.11388206], [84.67210388, 27.10991096], [84.67320251, 27.10704994], [84.67691803, 27.10865784], [84.67688751, 27.1085434], [84.67801666, 27.10901451], [84.67591858, 27.10517883], [84.67778778, 27.10292435], [84.67693329, 27.09995461], [84.67642212, 27.09548378], [84.6723175, 27.09801483], [84.66970825, 27.09337234], [84.66846466, 27.09380531], [84.66684723, 27.09436607], [84.66660309, 27.09225273], [84.6685791, 27.09286118], [84.67256927, 27.09088707], [84.67173004, 27.09029007], [84.67082977, 27.08964348], [84.66886902, 27.09022141], [84.6687088, 27.09021759], [84.66822052, 27.08740616], [84.66696167, 27.08806229], [84.6653595, 27.08889771], [84.66629791, 27.08731461], [84.66697693, 27.08616447], [84.66546631, 27.08656693], [84.66362, 27.08491516], [84.66041565, 27.0833168], [84.66001892, 27.08231163], [84.65727997, 27.08405113], [84.65702057, 27.08344269], [84.65628815, 27.08168983], [84.66088867, 27.08032227], [84.65865326, 27.07893944], [84.65846252, 27.07903481], [84.65556335, 27.0802784], [84.65522003, 27.07915878], [84.65529633, 27.07746506], [84.65481567, 27.07782173], [84.65429688, 27.07821083], [84.65200806, 27.07706642], [84.65183258, 27.07698441], [84.65081787, 27.07451439], [84.64970398, 27.07634735], [84.64846039, 27.07535172], [84.64958954, 27.07090759], [84.64651489, 27.06481552], [84.64746094, 27.06367111], [84.64514923, 27.05952072], [84.64511871, 27.05941582], [84.64796448, 27.05832672], [84.64733124, 27.05712509], [84.64836884, 27.05137825], [84.64846039, 27.05111885], [84.6453476, 27.05071831], [84.64659119, 27.04875565], [84.64485168, 27.04724693], [84.65419006, 27.04311752], [84.66123199, 27.04003906], [84.66150665, 27.03993416], [84.66590118, 27.03821564], [84.67518616, 27.03460693], [84.67539978, 27.03452873], [84.68412781, 27.03135872], [84.70363617, 27.02676201], [84.70800781, 27.02373505], [84.70809937, 27.0236721], [84.7117157, 27.02121544], [84.71195221, 27.02117538], [84.71618652, 27.02129364], [84.71649933, 27.02042007], [84.71871948, 27.01955414], [84.71878815, 27.01952934], [84.72052765, 27.01799202], [84.7206192, 27.01791573], [84.7208252, 27.01730156], [84.72103119, 27.01731682], [84.7215271, 27.01520348], [84.7251358, 27.01346397], [84.72543335, 27.01344681], [84.72973633, 27.01321602], [84.7308197, 27.0140152], [84.73184204, 27.01470757], [84.74017334, 27.01122665], [84.7544632, 27.0046978], [84.75893402, 27.00265121], [84.76277924, 27.00490761], [84.7628479, 27.00503922], [84.7644043, 27.00874138], [84.76408386, 27.0097065], [84.76622009, 27.01311493], [84.77309418, 27.01663589], [84.77482605, 27.01753235], [84.78466034, 27.01396179], [84.784729, 27.01370239], [84.78759003, 27.00832558], [84.78839111, 27.01073074], [84.78900909, 27.0086174], [84.79100037, 27.0086174], [84.7906723, 27.00785255], [84.79091644, 27.00781441], [84.79077911, 27.00742149], [84.78961945, 27.00401497], [84.78960419, 27.00393867], [84.79000854, 27.00290108], [84.78851318, 26.99830246], [84.79062653, 26.99855042], [84.79062653, 26.99761009], [84.79091644, 26.99751472], [84.79311371, 26.99942017], [84.79410553, 26.99780464], [84.793396, 26.9974823], [84.79273987, 26.99718475], [84.79572296, 26.99556923], [84.79582977, 26.99580765], [84.79932404, 27.00389481], [84.80029297, 27.00357437], [84.80036163, 27.00355148], [84.80119324, 27.00327301], [84.8024292, 27.0004158], [84.8028183, 27.00117302], [84.80467224, 27.00476456], [84.80549622, 27.00514984], [84.80971527, 27.00751495], [84.80969238, 27.00779724], [84.80914307, 27.00799561], [84.8088913, 27.01023293], [84.80941772, 27.01101685], [84.80989075, 27.01172447], [84.81095886, 27.01112175], [84.8122406, 27.01120949], [84.8123703, 27.01142502], [84.81265259, 27.01260567], [84.81274414, 27.01458168], [84.80912018, 27.01371574], [84.81091309, 27.01779938], [84.81274414, 27.01806259], [84.81341553, 27.018116], [84.81394196, 27.01927567], [84.81386566, 27.02029991], [84.81445313, 27.02023315], [84.81498718, 27.02017403], [84.81562042, 27.01791573], [84.81578064, 27.01804161], [84.81983185, 27.02042389], [84.82218933, 27.0204258], [84.82479858, 27.02104378], [84.83188629, 27.01930428], [84.83934021, 27.0144577], [84.84434509, 27.012537], [84.84841919, 27.01101685], [84.84973145, 27.01051331], [84.85686493, 27.00799561], [84.85703278, 27.00772476], [84.85748291, 27.00700188], [84.85546875, 27.00617218], [84.85540009, 27.00614357], [84.85421753, 27.00221443], [84.85419464, 27.0021019], [84.85487366, 27.00153351], [84.85400391, 26.99917221], [84.85348511, 26.99884033], [84.85341644, 26.99851608], [84.85620117, 26.99851608], [84.85649109, 26.99851608], [84.85997009, 26.99743271], [84.85926056, 26.99654198], [84.85897827, 26.99618912], [84.85971832, 26.99545097], [84.86022186, 26.99494743], [84.85984802, 26.99233818], [84.85971832, 26.99233246], [84.85971832, 26.99180222], [84.85971832, 26.99131584], [84.85934448, 26.99053574], [84.85959625, 26.99034882], [84.85887146, 26.9895401], [84.85748291, 26.98798752], [84.85798645, 26.98649597], [84.85997772, 26.98795128], [84.86121368, 26.98885727], [84.86115265, 26.98829842], [84.86109161, 26.98773956], [84.86842346, 26.98351479], [84.86865997, 26.98398781], [84.86933136, 26.9835968], [84.87115479, 26.98376274], [84.87115479, 26.98271751], [84.87115479, 26.98251915], [84.8731842, 26.98180962], [84.87364197, 26.9816494], [84.89079285, 26.97717667], [84.89091492, 26.97631454], [84.89103699, 26.97543716], [84.89278412, 26.97441864], [84.89241028, 26.9710865], [84.89364624, 26.96959496], [84.89501953, 26.969347], [84.8946228, 26.97080994], [84.89427185, 26.97208023], [84.89691925, 26.9726162], [84.89866638, 26.9716301], [84.90085602, 26.97046471], [84.91038513, 26.96818352], [84.91278839, 26.9676075], [84.91937256, 26.9687252], [84.9262085, 26.96735764], [84.93156433, 26.96850014], [84.94571686, 26.96361542], [84.95553589, 26.95940399], [84.95851898, 26.96064949], [84.95887756, 26.96080017], [84.96448517, 26.96027565], [84.96498108, 26.95944595], [84.96511841, 26.95941544], [84.96665192, 26.95825386], [84.96808624, 26.95803833], [84.96802521, 26.95721626], [84.97177887, 26.95186615], [84.98051453, 26.9400177], [84.97705841, 26.93927765], [84.97977448, 26.93678665], [84.97990417, 26.93652534], [84.98001862, 26.93641472], [84.98039246, 26.93554497], [84.97877502, 26.9318161], [84.97731018, 26.93174934], [84.9760437, 26.93169212], [84.97232056, 26.92871475], [84.97405243, 26.92585182], [84.9728241, 26.92529678], [84.97157288, 26.92473221], [84.97303009, 26.92297935], [84.97405243, 26.92174911], [84.97320557, 26.92096519], [84.97288513, 26.91705322], [84.97293854, 26.91677856], [84.97286224, 26.91675949], [84.96982574, 26.91603279], [84.98061371, 26.9148159], [84.99129486, 26.9133606], [84.9967804, 26.91261292], [85.00179291, 26.91189384], [85.00388336, 26.90957069], [85.00334167, 26.90909004], [85.00276184, 26.90857697], [85.00291443, 26.90621567], [85.0043869, 26.90312958], [84.99803925, 26.90633965], [84.99530792, 26.90534592], [84.99518585, 26.90391922], [84.99505615, 26.9024868], [85.00611877, 26.89478302], [85.02191925, 26.89281464], [85.02513123, 26.89142799], [85.03196716, 26.89154816], [85.04411316, 26.89116478], [85.04581451, 26.89111519], [85.05429077, 26.88899612], [85.05462646, 26.88894463], [85.05545044, 26.88881683], [85.05473328, 26.88833618], [85.05358887, 26.88757515], [85.05358887, 26.8860836], [85.05506134, 26.88640404], [85.05644989, 26.8867054], [85.05895996, 26.88579941], [85.06125641, 26.88597298], [85.0616684, 26.88707733], [85.06241608, 26.8867054], [85.06204224, 26.88508987], [85.05741882, 26.88111496], [85.05607605, 26.88446808], [85.0557251, 26.88449287], [85.05469513, 26.88456726], [85.05433655, 26.88459206], [85.05284119, 26.88297653], [85.05060577, 26.8849659], [85.05197144, 26.88210678], [85.05343628, 26.88226128], [85.05433655, 26.88235474], [85.05445862, 26.88098907], [85.04823303, 26.87830544], [85.04813385, 26.87823105], [85.04538727, 26.87937546], [85.04351807, 26.87711525], [85.04426575, 26.87490845], [85.04211426, 26.87461472], [85.04005432, 26.87728119], [85.03967285, 26.87775803], [85.03966522, 26.87755585], [85.03955078, 26.87552071], [85.03830719, 26.87477493], [85.03160858, 26.87501717], [85.03151703, 26.87502098], [85.03010559, 26.87030029], [85.03231049, 26.8674221], [85.02885437, 26.8662281], [85.02889252, 26.86602592], [85.02960205, 26.86259651], [85.03043365, 26.86231995], [85.03109741, 26.86209869], [85.03098297, 26.85918808], [85.03101349, 26.85901451], [85.02463531, 26.85625839], [85.02444458, 26.85543251], [85.02586365, 26.85510063], [85.0461731, 26.85071182], [85.05967712, 26.84892654], [85.06022644, 26.84940529], [85.0589447, 26.85230827], [85.05896759, 26.8523922], [85.05980682, 26.8556366], [85.06056976, 26.85474586], [85.06061554, 26.85481453], [85.06342316, 26.85378647], [85.06465149, 26.85526276], [85.06315613, 26.85613441], [85.06365967, 26.85687828], [85.06526947, 26.85799789], [85.06465149, 26.85613441], [85.06713867, 26.85625839], [85.06378174, 26.85352325], [85.06562042, 26.84931564], [85.06813812, 26.85071182], [85.06861877, 26.85361481], [85.06887817, 26.85369301], [85.0776062, 26.8563118], [85.07853699, 26.85659218], [85.0785675, 26.8567543], [85.07866669, 26.85668755], [85.07914734, 26.85733604], [85.07894135, 26.85762405], [85.07991791, 26.85838318], [85.08001709, 26.85851479], [85.08096313, 26.85782814], [85.08279419, 26.85649681], [85.08378601, 26.85687828], [85.08353424, 26.85606575], [85.0845108, 26.85584068], [85.08565521, 26.85638237], [85.08572388, 26.8555584], [85.08589935, 26.85352325], [85.08968353, 26.85333252], [85.08654785, 26.85514832], [85.08963013, 26.85650635], [85.08926392, 26.85748291], [85.08888245, 26.8584938], [85.09161377, 26.85971451], [85.09155273, 26.85983086], [85.08776855, 26.86508179], [85.08836365, 26.86614037], [85.08888245, 26.86706924], [85.08997345, 26.86706924], [85.09095764, 26.86763763], [85.09074402, 26.86806297], [85.09136963, 26.86787605], [85.09161377, 26.86801529], [85.09198761, 26.86794853], [85.09198761, 26.86856079], [85.09832001, 26.86681557], [85.10168457, 26.87079811], [85.11251831, 26.87141609], [85.11336517, 26.87216568], [85.12291718, 26.87131691], [85.1231842, 26.871315], [85.12685394, 26.87026978], [85.13633728, 26.86759567], [85.14331818, 26.87079811], [85.15601349, 26.87031555], [85.1676712, 26.86832237], [85.17861176, 26.86893463], [85.18689728, 26.86950874], [85.1913147, 26.86981583], [85.19770813, 26.86659431], [85.19509125, 26.86330605], [85.19501495, 26.86321449], [85.19313049, 26.84971428], [85.19361877, 26.84381485], [85.19600677, 26.84171867], [85.19262695, 26.82954407], [85.18854523, 26.82445145], [85.18842316, 26.82121277], [85.17922974, 26.814888], [85.1791153, 26.81191444], [85.17985535, 26.80803871], [85.18430328, 26.79945183], [85.18171692, 26.79809761], [85.18258667, 26.79548836], [85.19117737, 26.79379272], [85.19141388, 26.79371452], [85.19509888, 26.79079628], [85.19701385, 26.78491592], [85.19501495, 26.77933311], [85.19971466, 26.76931572], [85.20154572, 26.76888847], [85.20272064, 26.76861572], [85.20829773, 26.76105118], [85.21253967, 26.76168633], [85.2124939, 26.7611084], [85.2122879, 26.75870323], [85.21614838, 26.75792313], [85.23041534, 26.76131439], [85.2341156, 26.76321602], [85.24198151, 26.76159286], [85.2505188, 26.75983047], [85.2551651, 26.76094055], [85.25911713, 26.75891495], [85.2596283, 26.75603104], [85.25985718, 26.75600624], [85.26251984, 26.75501442], [85.2857666, 26.75365639], [85.28660583, 26.7536087], [85.2872467, 26.75354958], [85.30251312, 26.75211716], [85.30407715, 26.75238609], [85.3061142, 26.75273705], [85.32010651, 26.74889946], [85.32450867, 26.74500275], [85.32471466, 26.74481773], [85.32497406, 26.74485779], [85.32518768, 26.74493217], [85.32910156, 26.74627495], [85.32863617, 26.74554443], [85.32798767, 26.74453545], [85.33631897, 26.74141502], [85.35719299, 26.76019478], [85.35930634, 26.76094055], [85.36057281, 26.7615757], [85.36352539, 26.76305199], [85.36536407, 26.76075554], [85.36601257, 26.75994492], [85.37171936, 26.75811577], [85.37711334, 26.7606163], [85.38030243, 26.76504135], [85.38613892, 26.77401924], [85.39421844, 26.77521515], [85.39912415, 26.77800941], [85.40461731, 26.78271484], [85.40802002, 26.78902626], [85.40963745, 26.7911377], [85.41159058, 26.7909317], [85.41907501, 26.79012108], [85.42208099, 26.78856087], [85.42740631, 26.78579521], [85.4311142, 26.78621483], [85.4312973, 26.7863369], [85.43473816, 26.78989601], [85.43593597, 26.78935814], [85.43722534, 26.7887764], [85.44869995, 26.78346825], [85.4497757, 26.7837677], [85.45481873, 26.78169823], [85.45574188, 26.7823143], [85.45563507, 26.78189278], [85.46061707, 26.78411484], [85.46099091, 26.7843647], [85.46033478, 26.78492546], [85.46617889, 26.7887764], [85.46681976, 26.78831482], [85.47521973, 26.78991508], [85.4801178, 26.79321861], [85.4812088, 26.79953194], [85.48152161, 26.80135918], [85.48159027, 26.80195045], [85.48783112, 26.80050087], [85.4983139, 26.79811478], [85.49820709, 26.80015755], [85.49736786, 26.80120468], [85.49811554, 26.8020153], [85.49919128, 26.80800629], [85.49874115, 26.80915833], [85.50020599, 26.80985069], [85.50072479, 26.81081963], [85.49997711, 26.81189156], [85.50209045, 26.81313515], [85.50388336, 26.81373978], [85.5058136, 26.81501579], [85.51044464, 26.81602478], [85.5112915, 26.81624222], [85.51461029, 26.8155899], [85.52211761, 26.81411552], [85.53229523, 26.82456589], [85.53529358, 26.82768631], [85.54508972, 26.83786583], [85.54709625, 26.83713341], [85.55562592, 26.83402824], [85.55818176, 26.83980179], [85.55991364, 26.84371567], [85.5679245, 26.84073448], [85.57429504, 26.85663033], [85.57642365, 26.85923195], [85.57765198, 26.86073112], [85.5803833, 26.85921478], [85.58141327, 26.85611534], [85.58473206, 26.8584938], [85.5885849, 26.85228157], [85.58783722, 26.85129738], [85.58751678, 26.84696007], [85.5941391, 26.85004616], [85.60211945, 26.85381699], [85.60921478, 26.85701561], [85.62164307, 26.86933899], [85.6262207, 26.87341499], [85.62861633, 26.87307167], [85.63668823, 26.87190247], [85.6385498, 26.86781502], [85.64461517, 26.85291481], [85.65391541, 26.85042572], [85.68254089, 26.84296036], [85.70477295, 26.83263397], [85.72332001, 26.82001495], [85.73101807, 26.80781555], [85.73091888, 26.80261612], [85.73262024, 26.80011559], [85.73671722, 26.79561615], [85.73711395, 26.78391457], [85.73734283, 26.77771759], [85.7357254, 26.76963997], [85.7310257, 26.74975014], [85.73635101, 26.7372036], [85.73287201, 26.73558807], [85.73240662, 26.73471832], [85.73371887, 26.73041344], [85.73051453, 26.72951508], [85.73175049, 26.72502518], [85.73111725, 26.72490883], [85.73038483, 26.72477531], [85.72841644, 26.71941566], [85.73013306, 26.71744347], [85.72714233, 26.70936203], [85.72864532, 26.70576286], [85.72678375, 26.70290375], [85.72714996, 26.70004654], [85.72652435, 26.69970322], [85.7257843, 26.69930077], [85.72759247, 26.69521141], [85.72763062, 26.69512367], [85.72564697, 26.68640709], [85.7276535, 26.68463516], [85.72693634, 26.6838665], [85.72711945, 26.68351555], [85.72690582, 26.6819706], [85.72714996, 26.68177795], [85.72593689, 26.67484474], [85.72581482, 26.67394447], [85.7287674, 26.67357635], [85.72781372, 26.67011452], [85.73162842, 26.66683388], [85.73311615, 26.66711235], [85.73265076, 26.66618729], [85.73861694, 26.66365814], [85.73871613, 26.66361618], [85.73720551, 26.65718651], [85.73461914, 26.65431595], [85.73597717, 26.65281677], [85.7375946, 26.65207672], [85.73721313, 26.6514492], [85.73751831, 26.65111542], [85.73786926, 26.65077019], [85.73833466, 26.65095711], [85.74915314, 26.63964844], [85.75536346, 26.637537], [85.76194763, 26.63592148], [85.76760864, 26.63210678], [85.76909637, 26.6312027], [85.77176666, 26.62958336], [85.77603912, 26.62885094], [85.80221558, 26.62436295], [85.80383301, 26.62349319], [85.8054657, 26.61519432], [85.80557251, 26.6146698], [85.81190491, 26.60932922], [85.81832123, 26.60381889], [85.81982422, 26.6025238], [85.83262634, 26.6012516], [85.83269501, 26.60157776], [85.83353424, 26.61094093], [85.83460999, 26.61077499], [85.83515167, 26.61077881], [85.84207916, 26.61029625], [85.85331726, 26.60951614], [85.85562134, 26.604702], [85.85650635, 26.59954071], [85.85997009, 26.58958626], [85.85069275, 26.57653427], [85.85150909, 26.57193756], [85.85211945, 26.56841469], [85.8552475, 26.56959343], [85.85888672, 26.57167053], [85.85968781, 26.57126808], [85.8598175, 26.57131577], [85.85987091, 26.57117844], [85.86062622, 26.57080078], [85.86089325, 26.56857681], [85.87055206, 26.57466316], [85.87060547, 26.5747242], [85.8729248, 26.57937622], [85.87401581, 26.57891464], [85.87801361, 26.58091545], [85.8813324, 26.58250999], [85.88175201, 26.58347702], [85.88581085, 26.58246231], [85.88892365, 26.58242989], [85.89323425, 26.59454346], [85.8948288, 26.59433746], [85.89628601, 26.59466171], [85.89731598, 26.59401703], [85.90272522, 26.59454346], [85.90275574, 26.59471321], [85.90299988, 26.60037804], [85.90381622, 26.60021591], [85.91162872, 26.60416985], [85.91191101, 26.60433197], [85.91481781, 26.60401535], [85.91621399, 26.60861588], [85.91902924, 26.60931778], [85.92411804, 26.60971451], [85.92910004, 26.61031151], [85.9287262, 26.61131477], [85.93019104, 26.61278152], [85.93121338, 26.61511612], [85.93108368, 26.61628532], [85.93502045, 26.61321449], [85.94023895, 26.61582756], [85.94041443, 26.6159153], [85.94261932, 26.61291504], [85.95034027, 26.61322021], [85.94966888, 26.61600304], [85.94851685, 26.62091637], [85.95171356, 26.62436295], [85.95281982, 26.62421608], [85.95714569, 26.62893867], [85.95760345, 26.62947273], [85.95672607, 26.63310242], [85.95469666, 26.63716316], [85.95552063, 26.63811302], [85.95569611, 26.64362526], [85.95730591, 26.64561462], [85.95880127, 26.64896965], [85.95967102, 26.6488533], [85.9597168, 26.64891624], [85.9616394, 26.64995575], [85.96252441, 26.65108109], [85.96341705, 26.65091896], [85.96389771, 26.65083313], [85.96541595, 26.65021515], [85.96612549, 26.65121841], [85.96711731, 26.65261459], [85.97001648, 26.65161705], [85.97032166, 26.65203476], [85.97232056, 26.65481567], [85.97545624, 26.65455818], [85.97797394, 26.6576519], [85.97818756, 26.65791702], [85.98062897, 26.65760803], [85.98696136, 26.65680885], [85.98999023, 26.65642548], [86.00217438, 26.654562], [86.00813293, 26.65592957], [86.00823975, 26.65586853], [86.01281738, 26.65401459], [86.01468658, 26.65863419], [86.01422882, 26.65928459], [86.02059937, 26.66067505], [86.02101898, 26.66081619], [86.03073883, 26.66642189], [86.05039978, 26.66129494], [86.05722046, 26.65951538], [86.06502533, 26.65808296], [86.07201385, 26.65679932], [86.07621002, 26.64951324], [86.09001923, 26.64301491], [86.09035492, 26.64287376], [86.11997223, 26.63043404], [86.12983704, 26.62961578], [86.13150024, 26.62947845], [86.14073944, 26.62871361], [86.14321899, 26.6164093], [86.14241791, 26.61622429], [86.13911438, 26.60796738], [86.1384201, 26.6062088], [86.14483643, 26.6047287], [86.14894104, 26.60845566], [86.15742493, 26.60960579], [86.16360474, 26.61454582], [86.16931915, 26.61392403], [86.17100525, 26.6149826], [86.17391968, 26.61681557], [86.1758194, 26.61548996], [86.17721558, 26.6145153], [86.17732239, 26.61450005], [86.17826843, 26.61516762], [86.1848526, 26.61342621], [86.18860626, 26.61445045], [86.18895721, 26.61453247], [86.19454956, 26.61442184], [86.19628906, 26.61243248], [86.19566345, 26.61094093], [86.19554138, 26.61102676], [86.19521332, 26.61041451], [86.19777679, 26.60770988], [86.19889069, 26.60072899], [86.1982193, 26.59781456], [86.19902039, 26.59752083], [86.19783783, 26.59514809], [86.19781494, 26.59501457], [86.19941711, 26.59329987], [86.20170593, 26.59560776], [86.20301819, 26.5969162], [86.20375824, 26.59473801], [86.20399475, 26.59403992], [86.20796967, 26.59615326], [86.21061707, 26.59271622], [86.21369171, 26.59247208], [86.2144165, 26.59241486], [86.21721649, 26.59110832], [86.21741486, 26.59101486], [86.21755981, 26.59082222], [86.21961212, 26.58810997], [86.2230835, 26.58966255], [86.22611237, 26.59105873], [86.22626495, 26.59101486], [86.2302475, 26.59102631], [86.2312088, 26.5918026], [86.23193359, 26.59156036], [86.23339844, 26.59202385], [86.23369598, 26.59279823], [86.23681641, 26.59041595], [86.23683929, 26.59072113], [86.23731995, 26.59731483], [86.23692322, 26.59764481], [86.23808289, 26.59827995], [86.23953247, 26.60012436], [86.23965454, 26.60124779], [86.24102783, 26.60112381], [86.24245453, 26.60207558], [86.24251556, 26.60311317], [86.24551392, 26.60251617], [86.24475098, 26.60547447], [86.24576569, 26.60572624], [86.24581909, 26.60641479], [86.246315, 26.60688972], [86.24599457, 26.60758591], [86.24711609, 26.60907745], [86.24773407, 26.60823822], [86.24791718, 26.6084156], [86.25112152, 26.60900879], [86.25102997, 26.6103611], [86.25009918, 26.61206055], [86.25092316, 26.61218643], [86.25243378, 26.61344528], [86.25457001, 26.61678314], [86.25507355, 26.61557961], [86.26289368, 26.6152916], [86.27383423, 26.61655617], [86.27793121, 26.6170311], [86.28903961, 26.61437607], [86.28938293, 26.61433029], [86.29521179, 26.6129303], [86.30800629, 26.61864662], [86.3102417, 26.61964035], [86.32479095, 26.61935616], [86.32928467, 26.61930275], [86.33003998, 26.61915398], [86.34656525, 26.61590385], [86.34648132, 26.61576271], [86.34603882, 26.61504173], [86.34559631, 26.61391068], [86.34381866, 26.61151505], [86.34376526, 26.61144829], [86.34305573, 26.61168671], [86.34132385, 26.60823059], [86.3427124, 26.60647011], [86.34329987, 26.60572243], [86.35501862, 26.60431671], [86.35883331, 26.60385895], [86.3607254, 26.60333824], [86.3874588, 26.59665489], [86.39594269, 26.59453392], [86.39629364, 26.59444618], [86.39723969, 26.59528351], [86.39937592, 26.59279251], [86.39951324, 26.59271622], [86.39941406, 26.59076309], [86.39935303, 26.58869743], [86.39733887, 26.58485794], [86.43265533, 26.57266617], [86.44797516, 26.56972122], [86.45788574, 26.56781769], [86.48832703, 26.54942703], [86.50112915, 26.54159737], [86.50327301, 26.54125214], [86.51816559, 26.53884888], [86.52411652, 26.54321289], [86.52809143, 26.54275513], [86.53058624, 26.54251862], [86.53381348, 26.5405159], [86.54421997, 26.53811455], [86.54723358, 26.53463745], [86.552948, 26.52991486], [86.55410767, 26.52333832], [86.55680084, 26.52395058], [86.55817413, 26.52265358], [86.55778503, 26.52057457], [86.55804443, 26.51773643], [86.55727386, 26.51815796], [86.55722046, 26.51791573], [86.56331635, 26.50931549], [86.56376648, 26.50928497], [86.56656647, 26.50154877], [86.56690216, 26.50072289], [86.5712204, 26.49881554], [86.57204437, 26.49745941], [86.57283783, 26.49760437], [86.57277679, 26.49689484], [86.58059692, 26.49482155], [86.58289337, 26.49444008], [86.58976746, 26.49330711], [86.59035492, 26.49325371], [86.59819031, 26.49064445], [86.60549927, 26.48863029], [86.60775757, 26.48801231], [86.61470795, 26.48611832], [86.61508942, 26.48654366], [86.61759949, 26.48515511], [86.62221527, 26.48361588], [86.62341309, 26.48381042], [86.62381744, 26.48227882], [86.62474823, 26.48150444], [86.6256485, 26.4815731], [86.62581635, 26.48101425], [86.6282196, 26.48061562], [86.62926483, 26.47713089], [86.6293869, 26.47672844], [86.63050079, 26.47859001], [86.63186646, 26.47747231], [86.62987518, 26.47511101], [86.62857819, 26.46943474], [86.62851715, 26.46911621], [86.63236237, 26.46914482], [86.63114166, 26.46792793], [86.63161469, 26.46771622], [86.63179779, 26.46760941], [86.63174438, 26.46777916], [86.63261414, 26.46827507], [86.63413239, 26.46626854], [86.63630676, 26.46502113], [86.63683319, 26.46578979], [86.64093781, 26.465168], [86.64087677, 26.46436501], [86.64122009, 26.46431541], [86.67917633, 26.45368385], [86.67945862, 26.45361137], [86.69261932, 26.45061493], [86.69574738, 26.45088387], [86.69763184, 26.44891167], [86.69760895, 26.4487648], [86.69790649, 26.44859695], [86.6984787, 26.44826698], [86.69800568, 26.44443321], [86.69798279, 26.44421959], [86.69983673, 26.44307899], [86.70093536, 26.44244003], [86.70215607, 26.4372654], [86.70220184, 26.43708229], [86.71022797, 26.43610382], [86.71256256, 26.43582344], [86.72258759, 26.4346199], [86.72817993, 26.42540169], [86.72966766, 26.42440605], [86.73046875, 26.42564964], [86.73103333, 26.42651939], [86.73190308, 26.42608452], [86.73277283, 26.42564964], [86.73226166, 26.42416], [86.73165894, 26.42241859], [86.73262024, 26.42221451], [86.73352051, 26.42204475], [86.73501587, 26.42401505], [86.73948669, 26.42304039], [86.73981476, 26.42421532], [86.74010468, 26.4252758], [86.74308777, 26.4243145], [86.74571991, 26.42691612], [86.74917603, 26.42800331], [86.74954224, 26.43323135], [86.74669647, 26.43360329], [86.7464447, 26.43459702], [86.74967957, 26.43584061], [86.75241852, 26.44101524], [86.75551605, 26.44168091], [86.75588989, 26.44615555], [86.75945282, 26.44699669], [86.76272583, 26.44781494], [86.7628479, 26.45121765], [86.76303864, 26.451231], [86.76657867, 26.45087624], [86.76692963, 26.45150757], [86.76719666, 26.45199585], [86.76659393, 26.45254135], [86.76583099, 26.45323753], [86.76623535, 26.45370483], [86.76657867, 26.45410919], [86.76495361, 26.45546722], [86.76745605, 26.45818901], [86.7677002, 26.45845795], [86.77020264, 26.45887375], [86.77155304, 26.45909882], [86.78260803, 26.45435715], [86.80323792, 26.44714928], [86.82379913, 26.44181252], [86.8293457, 26.44037437], [86.83580017, 26.43869781], [86.83753967, 26.44068718], [86.83843994, 26.44026756], [86.83851624, 26.44031525], [86.84041595, 26.44221497], [86.84051514, 26.44213867], [86.84250641, 26.44143295], [86.84220123, 26.44082451], [86.84188843, 26.44018936], [86.84536743, 26.43992805], [86.84591675, 26.44074821], [86.84698486, 26.4423027], [86.84947205, 26.44205284], [86.84785461, 26.44404221], [86.84835052, 26.44789505], [86.8520813, 26.44826698], [86.85303497, 26.44781876], [86.85419464, 26.44727325], [86.8584137, 26.44814301], [86.85952759, 26.45121193], [86.85958862, 26.4513073], [86.86239624, 26.45423317], [86.86239624, 26.45497704], [86.86239624, 26.45584869], [86.86310577, 26.45594406], [86.86330414, 26.45597076], [86.86425781, 26.45609665], [86.86416626, 26.456213], [86.86338806, 26.45721436], [86.86771393, 26.45721626], [86.86724091, 26.4552269], [86.86839294, 26.45568848], [86.86910248, 26.45597267], [86.86903381, 26.45517349], [86.86898041, 26.45448112], [86.871315, 26.45411491], [86.87320709, 26.4552269], [86.87371826, 26.45420074], [86.87394714, 26.45373535], [86.87532043, 26.45373535], [86.8784256, 26.4552269], [86.87805176, 26.45627975], [86.87767792, 26.45734024], [86.88161469, 26.45673752], [86.88176727, 26.4568119], [86.88476562, 26.4593277], [86.88554382, 26.45926857], [86.88637543, 26.45920372], [86.8870163, 26.46108055], [86.89641571, 26.4617157], [86.89756012, 26.46703339], [86.89724731, 26.46792412], [86.89694214, 26.46877289], [86.89471436, 26.46891594], [86.89607239, 26.47175598], [86.89548492, 26.47181511], [86.8948288, 26.47187996], [86.89550018, 26.47288895], [86.89582062, 26.47337151], [86.89521027, 26.47434616], [86.89457703, 26.47535896], [86.89497375, 26.47553825], [86.89595032, 26.47598076], [86.89493561, 26.47598076], [86.89421082, 26.47598076], [86.89510345, 26.47773552], [86.8926239, 26.48143768], [86.89411163, 26.48578644], [86.89596558, 26.4867878], [86.89557648, 26.48728943], [86.9065094, 26.48791122], [86.93222809, 26.48931694], [86.93204498, 26.49028587], [86.93087006, 26.49648476], [86.93509674, 26.51649284], [86.94702148, 26.51674271], [86.94734955, 26.517313], [86.94916534, 26.52052498], [86.94924927, 26.52059746], [86.9495697, 26.52059937], [86.96183014, 26.52000618], [86.96265411, 26.52153778], [86.96367645, 26.52345276], [86.96839905, 26.52332878], [86.96829987, 26.522789], [86.96814728, 26.52196121], [86.97759247, 26.51972389], [86.98181915, 26.52482033], [86.99321747, 26.52283669], [86.99636841, 26.52393532], [87.00235748, 26.52614784], [87.01771545, 26.53181458], [87.02258301, 26.53973198], [87.03588104, 26.55659676], [87.04483032, 26.56794357], [87.04730988, 26.58695602], [87.05066681, 26.58681679], [87.07427979, 26.58546638], [87.07436371, 26.58443069], [87.07440186, 26.58397484], [87.0754776, 26.57730293], [87.07551575, 26.57701492], [87.07511902, 26.54161453], [87.07841492, 26.53701591], [87.08220673, 26.52294922], [87.08811951, 26.48529243], [87.09391785, 26.45001602], [87.11156464, 26.43683434], [87.13014984, 26.42302513], [87.14151001, 26.41458893], [87.16371155, 26.40441704], [87.16501617, 26.40381622], [87.17344666, 26.4030323], [87.19147491, 26.40510941], [87.18881989, 26.41401482], [87.20381927, 26.41329575], [87.20535278, 26.41322708], [87.21381378, 26.41284943], [87.21446228, 26.4101162], [87.21391296, 26.40968895], [87.21392059, 26.4094162], [87.2166748, 26.4079895], [87.21971893, 26.40641594], [87.22142029, 26.40291595], [87.22615051, 26.40557098], [87.22638702, 26.40837479], [87.22761536, 26.40850449], [87.22866058, 26.41004753], [87.22863007, 26.41048813], [87.22905731, 26.41063118], [87.22931671, 26.41101456], [87.22962189, 26.41129684], [87.22912598, 26.41160583], [87.23044586, 26.41207123], [87.23123932, 26.41235161], [87.23123932, 26.412817], [87.23123932, 26.41334724], [87.247612, 26.41398811], [87.25037384, 26.4135952], [87.25031281, 26.41251945], [87.25036621, 26.41243553], [87.2525177, 26.40911484], [87.2559433, 26.41008186], [87.25870514, 26.41086006], [87.26418304, 26.40777779], [87.26860046, 26.40529442], [87.26811218, 26.39081955], [87.26680756, 26.38627434], [87.26828766, 26.37440491], [87.26838684, 26.37361145], [87.27482605, 26.37234116], [87.28611755, 26.37307739], [87.29192352, 26.37343025], [87.29946136, 26.36871529], [87.30381012, 26.36599731], [87.30879211, 26.36829376], [87.31482697, 26.37107277], [87.31491852, 26.37111473], [87.31590271, 26.36725044], [87.32431793, 26.35990906], [87.33825684, 26.35147095], [87.34049225, 26.35011864], [87.34341431, 26.34751511], [87.34715271, 26.34960175], [87.35016632, 26.35133362], [87.35561371, 26.35614777], [87.36083221, 26.36082268], [87.35590363, 26.37183571], [87.35720062, 26.37893486], [87.35886383, 26.38787079], [87.36411285, 26.3966198], [87.37129211, 26.4077549], [87.37863922, 26.40674019], [87.38513947, 26.41302872], [87.39102936, 26.41869736], [87.41433716, 26.42152977], [87.42162323, 26.42241859], [87.42285919, 26.42236519], [87.43019867, 26.42204475], [87.43379974, 26.42453194], [87.44551086, 26.43274117], [87.4647522, 26.43892479], [87.46909332, 26.44006538], [87.48712921, 26.43698311], [87.48851013, 26.4367466], [87.49820709, 26.4350872], [87.51892853, 26.43062019], [87.53929901, 26.42068672], [87.55001831, 26.4182148], [87.55532074, 26.40541458], [87.57361603, 26.39681625], [87.59022522, 26.39221382], [87.59055328, 26.39025116], [87.59088135, 26.38799477], [87.58973694, 26.38223648], [87.58965302, 26.38181305], [87.6084137, 26.38060188], [87.61463165, 26.38982964], [87.63038635, 26.39346886], [87.63089752, 26.39358711], [87.64583588, 26.39334869], [87.65438843, 26.39321327], [87.65280914, 26.40553093], [87.68086243, 26.41545868], [87.68082428, 26.41670036], [87.68023682, 26.43509483], [87.68091583, 26.43509483], [87.68173218, 26.43509483], [87.69451904, 26.43531609], [87.70064545, 26.42834282], [87.70101929, 26.42791557], [87.70858002, 26.42739105], [87.71217346, 26.4271183], [87.71590424, 26.4252758], [87.71608734, 26.42400932], [87.71627808, 26.42266655], [87.71851349, 26.42154884], [87.71971893, 26.42180252], [87.7208786, 26.42204475], [87.72277069, 26.41982269], [87.72431183, 26.41881943], [87.72485352, 26.41893959], [87.72634125, 26.41521072], [87.72531891, 26.41221619], [87.72978973, 26.4102726], [87.73616028, 26.40750504], [87.74163055, 26.41719818], [87.7432785, 26.41747475], [87.74991608, 26.41851616], [87.75569916, 26.40894508], [87.75631714, 26.40791512], [87.76885986, 26.41209602], [87.76809692, 26.4129734], [87.77071381, 26.41496277], [87.7700882, 26.41856575], [87.77082062, 26.41849899], [87.77334595, 26.42122841], [87.7735672, 26.42154884], [87.77555847, 26.41918755], [87.77878571, 26.42154884], [87.77575684, 26.42026711], [87.77555847, 26.42018127], [87.7760849, 26.42101669], [87.77789307, 26.4251709], [87.77307129, 26.42714119], [87.77766418, 26.42690659], [87.77736664, 26.42744064], [87.77505493, 26.42975044], [87.77571869, 26.43041611], [87.77629852, 26.43099403], [87.77841949, 26.42961502], [87.77843475, 26.42971039], [87.78028107, 26.43559074], [87.77967072, 26.436203], [87.77915955, 26.43671036], [87.77806854, 26.43582726], [87.77716827, 26.43509483], [87.77630615, 26.43540192], [87.77542877, 26.43571663], [87.77703857, 26.4404068], [87.78028107, 26.4423027], [87.77902222, 26.44244194], [87.77803802, 26.44255066], [87.77912903, 26.44739723], [87.77642059, 26.4501152], [87.78152466, 26.45038033], [87.78040314, 26.45336342], [87.78487396, 26.45371246], [87.78661346, 26.45771599], [87.79018402, 26.46169472], [87.78835297, 26.46271324], [87.788414, 26.46319771], [87.78860474, 26.46479607], [87.78878021, 26.46497345], [87.78901672, 26.46611595], [87.78959656, 26.46509361], [87.79096222, 26.46392632], [87.79245758, 26.46554184], [87.79101563, 26.46596909], [87.78939819, 26.46644783], [87.78910065, 26.46653557], [87.78897858, 26.46765327], [87.79221344, 26.46891594], [87.79354095, 26.46645546], [87.79364014, 26.46660042], [87.79494476, 26.46852493], [87.81395721, 26.46156502], [87.81785583, 26.4596138], [87.81968689, 26.4587307], [87.82771301, 26.4519062], [87.83221436, 26.44991493], [87.83071899, 26.43981552], [87.84430695, 26.43742943], [87.85121918, 26.43621445], [87.853508, 26.44490433], [87.85359955, 26.44495583], [87.86372375, 26.44972801], [87.86354065, 26.45075226], [87.86512756, 26.452631], [87.86241913, 26.45371628], [87.86071014, 26.45599365], [87.86105347, 26.45882988], [87.8611908, 26.45890427], [87.86217499, 26.45945168], [87.86122894, 26.46039772], [87.86067963, 26.46094322], [87.86080933, 26.4634285], [87.86512756, 26.46405792], [87.86604309, 26.46762276], [87.88814545, 26.47622871], [87.88954926, 26.48205185], [87.89015198, 26.48455238], [87.89028931, 26.48512268], [87.89063263, 26.48641968], [87.90252686, 26.47712708], [87.90892029, 26.46431541], [87.91210175, 26.45744896], [87.90345001, 26.45026016], [87.90119934, 26.44839096], [87.9260025, 26.446455], [87.92667389, 26.4464035], [87.92816162, 26.44006538], [87.92580414, 26.43745613], [87.92266846, 26.43592072], [87.91996002, 26.43459702], [87.9198761, 26.43441582], [87.91912079, 26.43071556], [87.92415619, 26.42923355], [87.92667389, 26.42888069], [87.92743683, 26.42826843], [87.92761993, 26.42821503], [87.92763519, 26.42810822], [87.92853546, 26.42738914], [87.92926025, 26.41824532], [87.92930603, 26.41794777], [87.93499756, 26.417696], [87.96831512, 26.39681625], [87.98072815, 26.39458084], [87.99328613, 26.39247131], [87.9936142, 26.39237595], [87.99415588, 26.39221954], [87.99452209, 26.38266182], [87.99502563, 26.36935425], [87.99575806, 26.36935425], [87.99626923, 26.36935425], [87.99619293, 26.36837959], [87.99998474, 26.36501312], [88.00037384, 26.36472702], [88.00496674, 26.36624718], [88.00471497, 26.36561584], [88.00447083, 26.36487961], [88.00671387, 26.36441612], [88.00832367, 26.3614006], [88.01018524, 26.36077881], [88.03255463, 26.36463165], [88.0329361, 26.3657074], [88.03104401, 26.36834526], [88.03031921, 26.36885643], [88.02999878, 26.3698101], [88.0296936, 26.37071991], [88.03072357, 26.37127304], [88.03112793, 26.37211037], [88.03069305, 26.37333107], [88.03173828, 26.37370491], [88.03208923, 26.37494087], [88.03156281, 26.37643814], [88.0324173, 26.3761158], [88.0338974, 26.37818146], [88.03082275, 26.37870598], [88.0298233, 26.38119888], [88.0296936, 26.38153267], [88.03205872, 26.38290024], [88.03264618, 26.38249016], [88.03271484, 26.38251495], [88.03390503, 26.38465691], [88.03466797, 26.38799477], [88.03582001, 26.38811684], [88.03702545, 26.38824272], [88.03715515, 26.39172363], [88.03901672, 26.39001465], [88.04049683, 26.39271355], [88.04038239, 26.39358711], [88.0424881, 26.39383507], [88.04380035, 26.39457893], [88.04299164, 26.39507866], [88.04455566, 26.39498138], [88.04498291, 26.39495468], [88.04501343, 26.39521217], [88.04510498, 26.39594841], [88.04616547, 26.39578819], [88.04759216, 26.39557457], [88.04701996, 26.39621735], [88.04660034, 26.39669418], [88.04750061, 26.39691925], [88.0490799, 26.39731598], [88.04846954, 26.39834976], [88.0478363, 26.39942741], [88.04991913, 26.40081596], [88.05021667, 26.40074921], [88.05293274, 26.40029716], [88.05306244, 26.4001236], [88.05417633, 26.39868164], [88.05475616, 26.40021706], [88.05492401, 26.40067101], [88.05570984, 26.40060806], [88.05802917, 26.40042114], [88.05740356, 26.40130234], [88.05678558, 26.40216255], [88.05793762, 26.40273857], [88.05877686, 26.40315628], [88.05848694, 26.40423965], [88.05815125, 26.40551758], [88.0594635, 26.40592766], [88.05987549, 26.40662956], [88.05939484, 26.40750504], [88.06053162, 26.40750504], [88.06261444, 26.4094162], [88.06275177, 26.40940285], [88.06648254, 26.41036415], [88.06673431, 26.40902328], [88.06697845, 26.4077549], [88.06867218, 26.40875816], [88.06970978, 26.40937042], [88.07039642, 26.40849495], [88.07107544, 26.40762901], [88.07390594, 26.40774345], [88.07207489, 26.41284943], [88.08111572, 26.41981506], [88.08624268, 26.4258976], [88.08740234, 26.42999649], [88.08752441, 26.43040848], [88.09069061, 26.43346214], [88.0912323, 26.43398857], [88.09740448, 26.43744278], [88.09901428, 26.44304848], [88.09941101, 26.45211983], [88.09616089, 26.45900345], [88.09442902, 26.462677], [88.09550476, 26.46356773], [88.09667969, 26.46454811], [88.0969696, 26.46457672], [88.10205078, 26.46578979], [88.1059494, 26.46670723], [88.10624695, 26.46790314], [88.10041046, 26.47225189], [88.10699463, 26.47175598], [88.10709381, 26.47186661], [88.10923004, 26.47592545], [88.10289001, 26.47945976], [88.10375214, 26.48356438], [88.10832214, 26.48910713], [88.10819244, 26.48922539], [88.10580444, 26.49132919], [88.10292053, 26.49411583], [88.10301971, 26.4985981], [88.10128021, 26.50543404], [88.09518433, 26.50431442], [88.09368134, 26.50590706], [88.0929184, 26.50671577], [88.09339905, 26.50704384], [88.09911346, 26.51091576], [88.09804535, 26.51480865], [88.09770966, 26.51613235], [88.09955597, 26.51662254], [88.10551453, 26.51821518], [88.10590363, 26.52012825], [88.10717773, 26.5263195], [88.10732269, 26.52701569], [88.10749054, 26.52842331], [88.10525513, 26.53041267], [88.10614777, 26.53562355], [88.10819244, 26.5352211], [88.11030579, 26.53024101], [88.11514282, 26.53018951], [88.12354279, 26.52013969], [88.13217926, 26.51258087], [88.13765717, 26.51419258], [88.14129639, 26.51179123], [88.14539337, 26.51097107], [88.14769745, 26.51663971], [88.15090179, 26.51692009], [88.15506744, 26.51577187], [88.15744019, 26.51874161], [88.16538239, 26.52164078], [88.16602325, 26.53446007], [88.1682663, 26.53736115], [88.17063141, 26.53650284], [88.17382813, 26.53282928], [88.17868042, 26.53087044], [88.17962646, 26.53449059], [88.17913055, 26.53699112], [88.18242645, 26.5429306], [88.18573761, 26.54413986], [88.19050598, 26.54430962], [88.19668579, 26.54356003], [88.19898987, 26.54175186], [88.19924164, 26.53872108], [88.20149231, 26.53860092], [88.20405579, 26.53955078], [88.2049408, 26.53725052], [88.20742035, 26.5352211], [88.21456146, 26.53558922], [88.21534729, 26.53791046], [88.21109009, 26.53869057], [88.20966339, 26.54072189], [88.21235657, 26.54166985], [88.21689606, 26.54156113], [88.22080231, 26.54627991], [88.21922302, 26.54859161], [88.21389008, 26.55076981], [88.21539307, 26.55726814], [88.22180939, 26.55323029], [88.23120117, 26.55198288], [88.23114777, 26.53921127], [88.23336029, 26.53236961], [88.22582245, 26.52663994], [88.21865082, 26.52370071], [88.20665741, 26.51498032], [88.20635986, 26.51006126], [88.1998291, 26.51065063], [88.19386292, 26.50801086], [88.18634033, 26.50007057], [88.17920685, 26.49398041], [88.179039, 26.49057961], [88.18340302, 26.48839951], [88.18295288, 26.48526001], [88.19164276, 26.48307991], [88.1937561, 26.4720211], [88.21479034, 26.46973038], [88.21694183, 26.47265053], [88.21264648, 26.47458076], [88.21315765, 26.47777939], [88.22622681, 26.4762516], [88.22595978, 26.4720211], [88.22112274, 26.46684837], [88.21533966, 26.46573067], [88.22460175, 26.45574951], [88.22897339, 26.44715118], [88.23388672, 26.44625092], [88.23664856, 26.4493103], [88.24340057, 26.44930077], [88.24835205, 26.43880081], [88.25219727, 26.43379021], [88.25963593, 26.43066978], [88.26275635, 26.42808914], [88.26560974, 26.4233799], [88.26790619, 26.42175293], [88.26834869, 26.41792107], [88.26315308, 26.41501045], [88.25538635, 26.4158802], [88.23581696, 26.39616966], [88.23044586, 26.39396095], [88.22924805, 26.38985062], [88.23171234, 26.38490105], [88.23760986, 26.37537766], [88.24312592, 26.37409019], [88.24511719, 26.37599754], [88.25126648, 26.37585831], [88.25489807, 26.37446976], [88.26164246, 26.38002968], [88.26759338, 26.38116074], [88.26994324, 26.37887955], [88.27397919, 26.37728119], [88.2818985, 26.36013031], [88.28990173, 26.35691071], [88.29191589, 26.35391045], [88.28913879, 26.35113907], [88.28336334, 26.34930992], [88.27935028, 26.34634972], [88.28170013, 26.33980942], [88.27955627, 26.33553123], [88.27626038, 26.33249283], [88.27243805, 26.3305397], [88.26976013, 26.33268929], [88.26859283, 26.33700943], [88.26526642, 26.33649063], [88.26113129, 26.33785057], [88.25801086, 26.33423996], [88.25630951, 26.33011818], [88.25370789, 26.3277607], [88.24819946, 26.32653809], [88.24469757, 26.3162899], [88.23912811, 26.31319809], [88.2364502, 26.30540085], [88.23416138, 26.30668068], [88.23177338, 26.31035805], [88.22690582, 26.30397034], [88.22677612, 26.29664993], [88.22458649, 26.2894001], [88.22101593, 26.28821945], [88.21900177, 26.28567123], [88.21498108, 26.28493118], [88.21425629, 26.28168106], [88.21115875, 26.28000069], [88.20410156, 26.27959061], [88.19448853, 26.27412987], [88.1893692, 26.27510071], [88.1833725, 26.27468109], [88.17690277, 26.26172829], [88.16706085, 26.25720024], [88.16311646, 26.25753021], [88.15882874, 26.25691032], [88.14444733, 26.25279999], [88.14064789, 26.24963951], [88.14063263, 26.24572945], [88.13741302, 26.2437706], [88.13593292, 26.23715019], [88.13880157, 26.2308197], [88.13582611, 26.22821045], [88.13105011, 26.22681046], [88.12612915, 26.22691917], [88.12560272, 26.22789955], [88.11995697, 26.22794914], [88.11187744, 26.22620964], [88.11390686, 26.22397995], [88.11601257, 26.2229805], [88.10838318, 26.21705055], [88.10572815, 26.21640015], [88.10246277, 26.21224976], [88.09718323, 26.20643044], [88.09359741, 26.20653915], [88.08969116, 26.20323181], [88.08759308, 26.19797134], [88.08724213, 26.19444084], [88.08162689, 26.19235039], [88.07298279, 26.18539047], [88.0748291, 26.18128014], [88.07141876, 26.17879295], [88.06983185, 26.17571831], [88.06710052, 26.17762947], [88.06343079, 26.17667007], [88.05864716, 26.17375946], [88.05233002, 26.17167282], [88.04836273, 26.17464066], [88.04618073, 26.17788124], [88.04046631, 26.17681122], [88.03743744, 26.17770004], [88.03233337, 26.17351913], [88.03363037, 26.17028999], [88.02852631, 26.16728973], [88.02662659, 26.16279984], [88.01751709, 26.15555954], [88.01174164, 26.15479088], [88.01078033, 26.14929008], [88.01509094, 26.1429081], [88.01306915, 26.14087105], [88.00681305, 26.14328957], [87.99910736, 26.1403904], [87.99603271, 26.14179039], [87.98840332, 26.14861107], [87.98210907, 26.15917969], [87.97479248, 26.15286064], [87.96953583, 26.15440941], [87.96405792, 26.15197945], [87.96334076, 26.14888954], [87.96869659, 26.14787102], [87.96877289, 26.13935089], [87.97097015, 26.13714027], [87.9678421, 26.13183022], [87.95713043, 26.12886047], [87.95868683, 26.12569809], [87.96740723, 26.12537193], [87.97563171, 26.12162971], [87.96935272, 26.10931015], [87.95823669, 26.1088295], [87.95494843, 26.10568237], [87.95440674, 26.10279274], [87.95812988, 26.10085106], [87.95765686, 26.09708977], [87.96273041, 26.09472084], [87.96570587, 26.09192085], [87.96948242, 26.0916481], [87.97025299, 26.08735085], [87.97219086, 26.08485031], [87.96813202, 26.08136177], [87.96401215, 26.08325005], [87.9598465, 26.08403969], [87.95052338, 26.08304024], [87.94300842, 26.08469009], [87.93788147, 26.08446121], [87.93694305, 26.07975006], [87.93820953, 26.07676125], [87.93470001, 26.0705204], [87.93112946, 26.06895065], [87.92253876, 26.07180977], [87.92185974, 26.07687187], [87.91652679, 26.07969856], [87.91750336, 26.08801079], [87.91293335, 26.0909729], [87.89572906, 26.07987022], [87.89256287, 26.08035088], [87.88928223, 26.07509995], [87.88826752, 26.07193947], [87.88471985, 26.07151985], [87.87606049, 26.06619072], [87.87769318, 26.05791092], [87.87520599, 26.05557823], [87.86325073, 26.05610085], [87.84915161, 26.04496956], [87.84211731, 26.04448128], [87.84126282, 26.04120827], [87.84165192, 26.03230095], [87.83892822, 26.02287102], [87.84062195, 26.01976967], [87.83333588, 26.00109291], [87.83075714, 25.9921608], [87.82720184, 25.99234009], [87.82604218, 25.98831177], [87.82618713, 25.98368263], [87.82987976, 25.97187996], [87.83126068, 25.96409988], [87.83097839, 25.96223068], [87.82538605, 25.95872116], [87.82704926, 25.95358086], [87.82657623, 25.95004272], [87.82390594, 25.94645119], [87.82480621, 25.94366074], [87.82830811, 25.94111061], [87.82711029, 25.93778038], [87.82993317, 25.93545151], [87.82681274, 25.93185043], [87.82350922, 25.93135071], [87.81787109, 25.93301964], [87.80696106, 25.92991829], [87.80573273, 25.92843056], [87.80358124, 25.92072105], [87.80745697, 25.91827011], [87.80747986, 25.91583061], [87.80355835, 25.91394806], [87.80375671, 25.91214943], [87.80780029, 25.90899086], [87.81066132, 25.91399956], [87.81186676, 25.9131794], [87.81646729, 25.91270828], [87.81726074, 25.90918922], [87.81680298, 25.90487099], [87.81365967, 25.89995193], [87.81459045, 25.89884186], [87.81891632, 25.89715958], [87.82026672, 25.89376068], [87.81796265, 25.88845062], [87.81552124, 25.88796043], [87.81550598, 25.88554001], [87.81706238, 25.88334084], [87.81828308, 25.88148117], [87.81986237, 25.88097954], [87.82283783, 25.87146759], [87.83454132, 25.86874008], [87.84314728, 25.86871147], [87.85043335, 25.86707115], [87.855896, 25.86473083], [87.86528015, 25.8675518], [87.86766052, 25.86445045], [87.87068939, 25.86600113], [87.87223816, 25.85965919], [87.87874603, 25.85845947], [87.88121796, 25.85840988], [87.88481903, 25.86465263], [87.89945221, 25.85983086], [87.90138245, 25.85624123], [87.90483093, 25.85308838], [87.91091156, 25.85174942], [87.8973465, 25.83959961], [87.89742279, 25.83452034], [87.89530945, 25.83317947], [87.89261627, 25.8350811], [87.88935852, 25.83280182], [87.88764954, 25.83287048], [87.88339996, 25.82860947], [87.88433838, 25.82731056], [87.89096832, 25.82650948], [87.89379883, 25.82916069], [87.8964386, 25.82909012], [87.89795685, 25.82765007], [87.89385223, 25.8250618], [87.89874268, 25.82014084], [87.90445709, 25.81892014], [87.9105072, 25.8148098], [87.90947723, 25.81069183], [87.9076004, 25.80939293], [87.90313721, 25.81413078], [87.90200806, 25.81314087], [87.90203857, 25.81101036], [87.90119171, 25.81069946], [87.89927673, 25.81159019], [87.89672852, 25.81105995], [87.89501953, 25.80468941], [87.89907074, 25.80550194], [87.90188599, 25.80398941], [87.90305328, 25.80187035], [87.90159607, 25.80050087], [87.89919281, 25.8002491], [87.89800262, 25.79927063], [87.90094757, 25.78030968], [87.89774323, 25.77181053], [87.89846802, 25.76976013], [87.90125275, 25.76923943], [87.90497589, 25.77196121], [87.91866302, 25.77404022], [87.92862701, 25.76785088], [87.92919922, 25.77209091], [87.93239594, 25.77132034], [87.93734741, 25.76794052], [87.93752289, 25.75830078], [87.94164276, 25.75595093], [87.9420166, 25.75323105], [87.93862915, 25.74854088], [87.94386292, 25.74814034], [87.94415283, 25.74381256], [87.95102692, 25.73862076], [87.95665741, 25.73544121], [87.96047974, 25.73212051], [87.96199799, 25.72969818], [87.96099854, 25.72468185], [87.9716568, 25.72006989], [87.97966766, 25.71846008], [87.98184204, 25.72170067], [87.98779297, 25.72367096], [87.98770905, 25.72002029], [87.99256134, 25.71912956], [87.99717712, 25.71191025], [88.00196838, 25.70910072], [88.00676727, 25.70651054], [88.01667023, 25.70471191], [88.01751709, 25.70249939], [88.01431274, 25.69748116], [88.01434326, 25.6943512], [88.01615906, 25.69171906], [88.02239227, 25.6915226], [88.02677917, 25.6989212], [88.03016663, 25.69881058], [88.03219604, 25.69647026], [88.03475189, 25.69403076], [88.03985596, 25.69813919], [88.04332733, 25.69469261], [88.0451889, 25.69000053], [88.04862976, 25.69057083], [88.0508194, 25.68580055], [88.04910278, 25.68147087], [88.04467773, 25.67696953], [88.0431366, 25.67388916], [88.04538727, 25.65980148], [88.04888153, 25.6579895], [88.04876709, 25.65542984], [88.04397583, 25.65258026], [88.04537201, 25.64810944], [88.04853821, 25.64390945], [88.0473175, 25.64302254], [88.04614258, 25.64441109], [88.044487, 25.64287949], [88.04438782, 25.63965988], [88.04294586, 25.63899994], [88.04016113, 25.64191246], [88.03582001, 25.64097977], [88.03555298, 25.63683128], [88.04081726, 25.63611984], [88.04347992, 25.63207054], [88.0542984, 25.63286018], [88.04749298, 25.6276207], [88.04376984, 25.62822914], [88.03942871, 25.62730026], [88.03694153, 25.62200928], [88.03502655, 25.61705017], [88.0372467, 25.6155777], [88.04042816, 25.61046028], [88.03930664, 25.60848999], [88.04139709, 25.60549927], [88.03605652, 25.60240173], [88.02970123, 25.60003853], [88.03131104, 25.59826279], [88.03565216, 25.59698105], [88.03983307, 25.59736061], [88.03858948, 25.59504128], [88.03121948, 25.59101105], [88.03138733, 25.58749962], [88.02649689, 25.58590126], [88.02102661, 25.58692169], [88.02194214, 25.58292007], [88.03002167, 25.57434082], [88.02526855, 25.5690918], [88.02818298, 25.56631088], [88.03392792, 25.5659008], [88.03824615, 25.56388092], [88.03547668, 25.56038094], [88.03343964, 25.56145096], [88.02961731, 25.55948067], [88.03042603, 25.55754852], [88.0270462, 25.55327034], [88.0298233, 25.55039024], [88.03787994, 25.54618073], [88.0357132, 25.53672981], [88.03909302, 25.53318977], [88.04247284, 25.53206062], [88.04605103, 25.53433037], [88.04884338, 25.53333092], [88.0507431, 25.53051949], [88.05597687, 25.52993011], [88.05812073, 25.52870941], [88.05748749, 25.52567101], [88.06687927, 25.51642036], [88.06886292, 25.51304817], [88.06491089, 25.5085125], [88.0638504, 25.50617027], [88.06642914, 25.50503922], [88.07125854, 25.50488091], [88.07285309, 25.50390053], [88.06981659, 25.50188255], [88.06812286, 25.49679947], [88.06815338, 25.48984909], [88.07041168, 25.48050117], [88.06593323, 25.48115158], [88.06167603, 25.48558998], [88.05580139, 25.483881], [88.05296326, 25.48662949], [88.04947662, 25.48615074], [88.04933929, 25.48271942], [88.04633331, 25.4826107], [88.04213715, 25.48538971], [88.03660583, 25.48654175], [88.03862762, 25.49155807], [88.03450775, 25.49273109], [88.03122711, 25.48599052], [88.02754974, 25.4861412], [88.02868652, 25.4889698], [88.02028656, 25.4953804], [88.01573181, 25.50049973], [88.00994873, 25.50097084], [88.00792694, 25.50283051], [88.01167297, 25.50756073], [88.00747681, 25.51039124], [88.00377655, 25.50481987], [88.00300598, 25.49969101], [88.00424194, 25.49403954], [87.99835205, 25.49539948], [87.99276733, 25.49785042], [87.9866333, 25.50263023], [87.98496246, 25.50811005], [87.98055267, 25.51585007], [87.98780823, 25.52071953], [87.98819733, 25.52260017], [87.98764801, 25.52394104], [87.98603821, 25.52482986], [87.97225952, 25.5232296], [87.96914673, 25.52606964], [87.96408844, 25.53308105], [87.95561218, 25.5380497], [87.95239258, 25.53646088], [87.94287872, 25.53467751], [87.93804932, 25.53528976], [87.93354797, 25.5349617], [87.92604828, 25.53621292], [87.92411041, 25.53564835], [87.91963196, 25.53083992], [87.91609955, 25.53190994], [87.91440582, 25.5309391], [87.91456604, 25.52523041], [87.91374969, 25.52376938], [87.90815735, 25.52412033], [87.9030304, 25.5190506], [87.90631866, 25.51366806], [87.90271759, 25.51122093], [87.90480804, 25.50733948], [87.9005127, 25.50723076], [87.89898682, 25.50430107], [87.89585114, 25.50472069], [87.89501953, 25.5099411], [87.88815308, 25.5127697], [87.88532257, 25.51708984], [87.87921906, 25.51597023], [87.88047791, 25.51332092], [87.88136292, 25.50556946], [87.86988068, 25.50300026], [87.86872864, 25.49718285], [87.86348724, 25.49342918], [87.86086273, 25.48605156], [87.86052704, 25.47783089], [87.86390686, 25.47031975], [87.86428833, 25.46788979], [87.86347198, 25.46538925], [87.85067749, 25.46834946], [87.84955597, 25.46499062], [87.83381653, 25.46457291], [87.8338089, 25.45881081], [87.82769012, 25.45883179], [87.82559967, 25.45754051], [87.8273468, 25.45158958], [87.82496643, 25.44939041], [87.82578278, 25.445261], [87.82171631, 25.44302177], [87.82092285, 25.43977165], [87.81922913, 25.43753815], [87.80864716, 25.43419075], [87.80680084, 25.43477821], [87.79830933, 25.44186974], [87.7933197, 25.44219971], [87.79260254, 25.44561958], [87.78652191, 25.44869995], [87.78132629, 25.44465065], [87.7796402, 25.43659973], [87.77651215, 25.42897034], [87.77011108, 25.42876816], [87.76586151, 25.42429161], [87.77120209, 25.41852951], [87.77242279, 25.41491127], [87.77127075, 25.41155815], [87.76998138, 25.40983009], [87.76798248, 25.40876961], [87.76413727, 25.40897942], [87.76213837, 25.41206169], [87.75975037, 25.41008949], [87.75910187, 25.40504074], [87.76381683, 25.4048996], [87.76644897, 25.40353012], [87.76306915, 25.39561081], [87.76255798, 25.38899994], [87.76268768, 25.38623047], [87.76570129, 25.37799072], [87.77379608, 25.37195015], [87.77671814, 25.37084961], [87.78882599, 25.3722496], [87.78736115, 25.35486031], [87.78486633, 25.34460068], [87.78159332, 25.33839989], [87.78398132, 25.33242989], [87.79144287, 25.32233047], [87.79728699, 25.32208061], [87.80162811, 25.3234005], [87.8110733, 25.31916046], [87.82035065, 25.31282043], [87.82892609, 25.30342102], [87.83114624, 25.30216026], [87.84037018, 25.2983799], [87.85041046, 25.29743767], [87.85137939, 25.29249954], [87.853302, 25.28936958], [87.85501099, 25.2895298], [87.85616302, 25.28297043], [87.85652161, 25.2777729], [87.85428619, 25.26791], [87.85137939, 25.26906967], [87.84996796, 25.26728058], [87.8497467, 25.26148033], [87.85103607, 25.25796127], [87.84925079, 25.25342751], [87.84729004, 25.25225067], [87.84555054, 25.2522583], [87.84158325, 25.25358009], [87.83553314, 25.24981117], [87.83228302, 25.24464989], [87.83024597, 25.23966026], [87.82493591, 25.23655128], [87.82277679, 25.23434067], [87.83380127, 25.21336937], [87.83683777, 25.20310974], [87.83664703, 25.19926071], [87.83230591, 25.20078087], [87.82965851, 25.20405006], [87.82119751, 25.20808983], [87.81004333, 25.21173286], [87.80134583, 25.21824074], [87.7875824, 25.2204895], [87.78753662, 25.22862053], [87.78544617, 25.23631287], [87.78520203, 25.24045944], [87.78367615, 25.24299049], [87.78330994, 25.24617767], [87.76911926, 25.24665833], [87.76283264, 25.24928856], [87.73087311, 25.25315094], [87.72106171, 25.25344086], [87.70778656, 25.25640869], [87.70687103, 25.25978088], [87.70796967, 25.2713604], [87.70591736, 25.27457047], [87.70096588, 25.2777729], [87.69641113, 25.27886963], [87.69130707, 25.28139114], [87.68907166, 25.28494072], [87.69030762, 25.29121971], [87.69478607, 25.29541016], [87.69140625, 25.29860115], [87.6934967, 25.3030529], [87.68824005, 25.30476952], [87.6806488, 25.30427933], [87.68087006, 25.30767059], [87.68409729, 25.30805016], [87.6841507, 25.31013107], [87.65878296, 25.30973053], [87.6517868, 25.30724907], [87.6340332, 25.31235123], [87.63179016, 25.31186104], [87.62597656, 25.31861115], [87.6262207, 25.3157196], [87.62267303, 25.31080055], [87.61361694, 25.31553841], [87.60688019, 25.31138039], [87.59989166, 25.31466293], [87.58925629, 25.32188988], [87.5892868, 25.3237896], [87.5811615, 25.32803917], [87.58046722, 25.33232117], [87.58766174, 25.34054756], [87.5800705, 25.34839058], [87.57891846, 25.34678268], [87.57948303, 25.3439312], [87.57144165, 25.34050941], [87.56710815, 25.33389091], [87.5474472, 25.33094025], [87.54680634, 25.32365036], [87.54412079, 25.32290077], [87.54112244, 25.30425072], [87.53849792, 25.29623032], [87.53974915, 25.28161812], [87.53562927, 25.28010941], [87.52942657, 25.27961922], [87.52552032, 25.28098106], [87.51287079, 25.29214287], [87.49887085, 25.29228973], [87.49006653, 25.30520058], [87.48638153, 25.2960701], [87.48150635, 25.29517174], [87.48757935, 25.27761078], [87.49447632, 25.27543068], [87.49195862, 25.27143097], [87.49559021, 25.26530075], [87.49571991, 25.26247978], [87.49484253, 25.25969124], [87.48755646, 25.26199913], [87.47264099, 25.24088287], [87.47305298, 25.23143005], [87.47181702, 25.22237968], [87.47216034, 25.19466972], [87.46763611, 25.19314194], [87.46685791, 25.1956501], [87.46192932, 25.19515038], [87.45783234, 25.19779968], [87.45511627, 25.19750023], [87.41660309, 25.21491051], [87.40949249, 25.21513939], [87.40764618, 25.2190094], [87.40215302, 25.22141075], [87.3966217, 25.22571945], [87.39177704, 25.22751808], [87.38648224, 25.22570992], [87.38330078, 25.22347069], [87.37713623, 25.2226181], [87.37394714, 25.21853065], [87.36988831, 25.20504951], [87.36846161, 25.20689964], [87.35801697, 25.21121979], [87.35507965, 25.21340942], [87.34777832, 25.21317291], [87.33045197, 25.21706963], [87.33053589, 25.22219086], [87.32345581, 25.22309113], [87.31833649, 25.20124054], [87.315979, 25.19695091], [87.31574249, 25.19298935], [87.31711578, 25.18868065], [87.31601715, 25.18630028], [87.31064606, 25.16982079], [87.31301117, 25.16926003], [87.31437683, 25.16736984], [87.31503296, 25.16504097], [87.3143692, 25.16275978], [87.31041718, 25.16032982], [87.30963898, 25.1535511], [87.30797577, 25.15029144], [87.30229187, 25.14532089], [87.30171967, 25.14389992], [87.30343628, 25.14320946], [87.30239105, 25.14059067], [87.30342865, 25.13814163], [87.29988098, 25.13459015], [87.2979126, 25.13466072], [87.2932663, 25.11435127], [87.2948761, 25.11381912], [87.29486847, 25.1119194], [87.29280853, 25.10469055], [87.29535675, 25.09970093], [87.29110718, 25.08926964], [87.28560638, 25.09091949], [87.27488708, 25.09218979], [87.27024841, 25.09363937], [87.26444244, 25.09777832], [87.26307678, 25.10082054], [87.25875092, 25.10461044], [87.25055695, 25.10585022], [87.24923706, 25.1053791], [87.24533081, 25.09908104], [87.24106598, 25.10079956], [87.23986053, 25.0994606], [87.23387909, 25.08582115], [87.22708893, 25.08757019], [87.21795654, 25.08854294], [87.21563721, 25.09019089], [87.21135712, 25.08959961], [87.21071625, 25.08525085], [87.20832062, 25.08332062], [87.19986725, 25.07944107], [87.19747162, 25.07365036], [87.18776703, 25.06699944], [87.18431854, 25.06701088], [87.17664337, 25.06402016], [87.17384338, 25.05800247], [87.17325592, 25.05647087], [87.16847992, 25.0489502], [87.16503906, 25.04586983], [87.1649704, 25.04281998], [87.15834045, 25.03100014], [87.15232086, 25.02651978], [87.14904785, 25.0262394], [87.14676666, 25.02431107], [87.14420319, 25.01797104], [87.14388275, 25.01078987], [87.1444931, 25.00642967], [87.14597321, 25.00355911], [87.14647675, 24.9998703], [87.15368652, 24.99097061], [87.15299225, 24.9831295], [87.15203094, 24.97443962], [87.1519165, 24.96861267], [87.15258026, 24.96299934], [87.15075684, 24.95574951], [87.14877319, 24.94938087], [87.14859009, 24.9421196], [87.15213013, 24.93653107], [87.15531158, 24.93168068], [87.15461731, 24.92651749], [87.15268707, 24.9239502], [87.14971161, 24.92122269], [87.14762878, 24.9178009], [87.14650726, 24.91286278], [87.14774323, 24.9081707], [87.14877319, 24.90509033], [87.15023041, 24.90316963], [87.15432739, 24.90011024], [87.15695953, 24.89608955], [87.15822601, 24.88955116], [87.1581192, 24.88563156], [87.15653992, 24.88070107], [87.15453339, 24.87647057], [87.14964294, 24.87240028], [87.14792633, 24.86786842], [87.14733887, 24.86240768], [87.15168762, 24.86308098], [87.15097809, 24.85843086], [87.14451599, 24.8592205], [87.13881683, 24.85926056], [87.13273621, 24.85957909], [87.12980652, 24.85749054], [87.12731934, 24.85448265], [87.12333679, 24.8529911], [87.11915588, 24.85396957], [87.11447144, 24.85552979], [87.10949707, 24.85078812], [87.10604858, 24.84733009], [87.10462189, 24.84445953], [87.10240936, 24.83925819], [87.0996933, 24.83476067], [87.09754944, 24.82985115], [87.0949707, 24.82620049], [87.09121704, 24.82356071], [87.0877533, 24.82304192], [87.08423615, 24.82322121], [87.08036041, 24.8243618], [87.0785675, 24.82225037], [87.07730103, 24.81814194], [87.0776062, 24.81422043], [87.07713318, 24.81182098], [87.07730103, 24.80834961], [87.08078003, 24.80951118], [87.08138275, 24.80738068], [87.08345032, 24.80658913], [87.0863266, 24.80591011], [87.08886719, 24.8040905], [87.09072876, 24.80266953], [87.09395599, 24.80441093], [87.09660339, 24.80402756], [87.09667206, 24.80149269], [87.09568024, 24.79759979], [87.09288025, 24.79229164], [87.0912323, 24.78811073], [87.08804321, 24.78523827], [87.08560181, 24.7824707], [87.0828476, 24.77922821], [87.08254242, 24.7729702], [87.08254242, 24.76798248], [87.08339691, 24.76452065], [87.08486938, 24.7614994], [87.08631134, 24.75831985], [87.08508301, 24.75580978], [87.08309174, 24.7536602], [87.08097076, 24.75168991], [87.08120728, 24.75075912], [87.08161163, 24.74834061], [87.07982635, 24.74658966], [87.07646179, 24.74549103], [87.07454681, 24.74472046], [87.07359314, 24.7430706], [87.07398987, 24.74054909], [87.07636261, 24.7399292], [87.07576752, 24.73814964], [87.0756073, 24.73641968], [87.07704926, 24.73566055], [87.07847595, 24.73615074], [87.08040619, 24.73698044], [87.08132172, 24.73594284], [87.08119202, 24.73265076], [87.08138275, 24.72925949], [87.08235168, 24.72699928], [87.08185577, 24.72454071], [87.08029175, 24.7219696], [87.07772064, 24.71879959], [87.07660675, 24.71459961], [87.07367706, 24.7125206], [87.07264709, 24.7109108], [87.07125092, 24.70734978], [87.07138062, 24.70313072], [87.07087708, 24.69885063], [87.07063293, 24.69449997], [87.06932831, 24.69124985], [87.0670166, 24.68847275], [87.06381226, 24.68503952], [87.06131744, 24.68152046], [87.06017303, 24.67721939], [87.05892181, 24.67225075], [87.05473328, 24.67060089], [87.05532074, 24.66509056], [87.05475616, 24.66069031], [87.05237579, 24.65551186], [87.05101013, 24.64927101], [87.05039978, 24.64344025], [87.04881287, 24.63701057], [87.04580688, 24.63089752], [87.04440308, 24.62403107], [87.04592133, 24.62017059], [87.04670715, 24.61740112], [87.04673004, 24.61421013], [87.04834747, 24.61014938], [87.05046844, 24.60676956], [87.04463196, 24.60539818], [87.0430069, 24.60893059], [87.04086304, 24.61104965], [87.03872681, 24.6125412], [87.03671265, 24.61325073], [87.03592682, 24.61177063], [87.03497314, 24.61010933], [87.0326004, 24.60989761], [87.03011322, 24.60951996], [87.02751923, 24.60931969], [87.02643585, 24.61123276], [87.02646637, 24.61605072], [87.02635193, 24.62008286], [87.02435303, 24.62109947], [87.02144623, 24.61962128], [87.01670074, 24.61779976], [87.01558685, 24.61330032], [87.01291656, 24.60909271], [87.0102005, 24.6062603], [86.99260712, 24.61918068], [86.99014282, 24.62071037], [86.99008942, 24.62002945], [86.98815155, 24.6201992], [86.98549652, 24.62162971], [86.9801178, 24.62467003], [86.97119141, 24.63030052], [86.96556091, 24.63186836], [86.95842743, 24.62943077], [86.95347595, 24.62765121], [86.94550323, 24.62656021], [86.94474792, 24.63117027], [86.94754791, 24.63586807], [86.94861603, 24.64276123], [86.93884277, 24.64307022], [86.93009186, 24.64282036], [86.93344116, 24.63572121], [86.93605804, 24.63037109], [86.93414307, 24.62652016], [86.92926788, 24.62644005], [86.92386627, 24.62433052], [86.91893768, 24.61940956], [86.9189682, 24.61347961], [86.91786194, 24.61079025], [86.91001892, 24.60114288], [86.90895081, 24.59698868], [86.90467834, 24.59514046], [86.90123749, 24.5915699], [86.89807892, 24.58654022], [86.89795685, 24.58053017], [86.90065765, 24.57615089], [86.90322113, 24.57152939], [86.90122223, 24.56679916], [86.90635681, 24.56336975], [86.90644073, 24.55989075], [86.90650177, 24.55529976], [86.90629578, 24.54926109], [86.9071579, 24.54338074], [86.91117859, 24.53867912], [86.90583038, 24.54097176], [86.90117645, 24.54449272], [86.89842224, 24.54975128], [86.89308929, 24.55483818], [86.88672638, 24.55402946], [86.88414001, 24.5544796], [86.88398743, 24.56035805], [86.87909698, 24.56305122], [86.87639618, 24.56731987], [86.87320709, 24.56497955], [86.86949158, 24.56138039], [86.86161041, 24.56027031], [86.85745239, 24.55661011], [86.85463715, 24.55046082], [86.84710693, 24.55297089], [86.83880615, 24.55406952], [86.83869171, 24.55862045], [86.83857727, 24.56278038], [86.83705139, 24.56828117], [86.83152771, 24.56805038], [86.82559204, 24.56599998], [86.82147217, 24.56831932], [86.81825256, 24.56933975], [86.81358337, 24.56820107], [86.80871582, 24.56377029], [86.80499268, 24.56412125], [86.80029297, 24.5646019], [86.80018616, 24.56592941], [86.80033875, 24.56870079], [86.80120087, 24.57196808], [86.80322266, 24.57435989], [86.80761719, 24.57685089], [86.80625916, 24.58114052], [86.80488586, 24.58538055], [86.80446625, 24.59065056], [86.8057785, 24.5945015], [86.8017807, 24.59745979], [86.80018616, 24.59857941], [86.79866791, 24.60114288], [86.79808807, 24.60346985], [86.79749298, 24.60573959], [86.79660797, 24.60852051], [86.7943573, 24.61209106], [86.79184723, 24.61531067], [86.78560638, 24.61720085], [86.78585052, 24.61309242], [86.78736115, 24.61092949], [86.79032135, 24.60844994], [86.79251099, 24.60518074], [86.79429626, 24.60070038], [86.79437256, 24.59683037], [86.78690338, 24.59937096], [86.78647614, 24.60457993], [86.78407288, 24.61028099], [86.78085327, 24.61483955], [86.7771225, 24.61976051], [86.77519226, 24.61951065], [86.7755127, 24.61557961], [86.76912689, 24.61648178], [86.75405121, 24.61475945], [86.75086212, 24.61797905], [86.74459839, 24.60288048], [86.74565125, 24.58950043], [86.73950958, 24.58649254], [86.7350769, 24.58084106], [86.73158264, 24.57579994], [86.7186203, 24.57821274], [86.70990753, 24.57353973], [86.69536591, 24.5689106], [86.68663788, 24.57044029], [86.68151855, 24.5650692], [86.67767334, 24.56611252], [86.668396, 24.56064034], [86.65593719, 24.56319809], [86.64575958, 24.5672226], [86.64126587, 24.57611847], [86.63420105, 24.57667923], [86.62716675, 24.57962036], [86.61828613, 24.58449173], [86.61885834, 24.59469986], [86.60691833, 24.59435081], [86.60791779, 24.59931946], [86.60936737, 24.60192108], [86.60968018, 24.60252953], [86.60929871, 24.60741043], [86.60292053, 24.60506821], [86.59998322, 24.59949112], [86.59485626, 24.59707069], [86.58976746, 24.59268951], [86.58389282, 24.58531952], [86.58315277, 24.57278061], [86.57823944, 24.56787109], [86.56804657, 24.56279945], [86.56170654, 24.56311035], [86.55831909, 24.55928993], [86.55464172, 24.55927086], [86.55792999, 24.54847908], [86.5513382, 24.54342079], [86.54669189, 24.5350399], [86.54057312, 24.53662109], [86.53614807, 24.5364399], [86.53044891, 24.53293037], [86.52352905, 24.53574944], [86.50572205, 24.5177002], [86.49752808, 24.49797821], [86.49812317, 24.48727036], [86.49532318, 24.48527908], [86.49028015, 24.48437119], [86.49080658, 24.47875023], [86.48877716, 24.47426987], [86.48974609, 24.46760178], [86.48448944, 24.45882034], [86.49112701, 24.45405006], [86.49098969, 24.44695282], [86.49194336, 24.43930054], [86.48819733, 24.43386078], [86.48858643, 24.42500114], [86.48207855, 24.42498016], [86.4733963, 24.42276192], [86.46582794, 24.42188072], [86.46367645, 24.4185009], [86.46568298, 24.41378975], [86.46366882, 24.40775108], [86.46711731, 24.39516068], [86.46568298, 24.38500023], [86.46179962, 24.37672043], [86.45504761, 24.37396812], [86.45220947, 24.36862946], [86.44632721, 24.36844063], [86.4341507, 24.37685966], [86.43070221, 24.37613106], [86.42514801, 24.37811852], [86.41558838, 24.37920952], [86.40101624, 24.39627075], [86.3986969, 24.40028954], [86.38123322, 24.4123497], [86.37326813, 24.41585159], [86.36789703, 24.42424965], [86.36271667, 24.42679024], [86.35350037, 24.44206047], [86.35072327, 24.44371033], [86.34781647, 24.44049835], [86.33273315, 24.44019127], [86.31949615, 24.44016075], [86.31555939, 24.4439106], [86.30375671, 24.44483948], [86.29957581, 24.44898987], [86.2988205, 24.45426178], [86.30090332, 24.45680046], [86.27913666, 24.4620018], [86.28183746, 24.47047806], [86.28557587, 24.47680283], [86.29387665, 24.47643089], [86.29773712, 24.48252106], [86.29824066, 24.48899841], [86.30162811, 24.49353981], [86.30349731, 24.49827194], [86.30973053, 24.50636292], [86.31241608, 24.50847054], [86.31056213, 24.51382256], [86.30751801, 24.52635956], [86.30330658, 24.52773094], [86.3013382, 24.53197861], [86.3081665, 24.54083252], [86.30983734, 24.54734039], [86.30404663, 24.55829048], [86.30982208, 24.56310081], [86.30809784, 24.5657196], [86.31098938, 24.56818008], [86.31936646, 24.57445908], [86.318573, 24.57892036], [86.32269287, 24.58056068], [86.32286072, 24.58409119], [86.31223297, 24.58588028], [86.31005096, 24.58156013], [86.30166626, 24.58315086], [86.29263306, 24.58609009], [86.28835297, 24.58433914], [86.28040314, 24.58418083], [86.27378845, 24.58274841], [86.27612305, 24.57908058], [86.27688599, 24.57419968], [86.27348328, 24.57562065], [86.26970673, 24.57780075], [86.26625824, 24.58195114], [86.26413727, 24.57583809], [86.26152802, 24.57690048], [86.25747681, 24.58312988], [86.24855042, 24.58513069], [86.24288177, 24.59213829], [86.23874664, 24.59679985], [86.23026276, 24.60227013], [86.21737671, 24.61177063], [86.21656036, 24.60280037], [86.21570587, 24.59117126], [86.19493866, 24.58516121], [86.16565704, 24.58368111], [86.15696716, 24.58923912], [86.15226746, 24.59971046], [86.14463043, 24.60305977], [86.13329315, 24.60354042], [86.13076019, 24.60893059], [86.12558746, 24.61182022], [86.12322998, 24.61968994], [86.12200928, 24.62393188], [86.12185669, 24.63005066], [86.11824799, 24.64189148], [86.1231308, 24.64793015], [86.12631989, 24.65422058], [86.12848663, 24.66597939], [86.12594604, 24.67080116], [86.13002777, 24.6714592], [86.13359833, 24.67551041], [86.13201141, 24.6803894], [86.12909698, 24.69003105], [86.12444305, 24.70516014], [86.11863708, 24.71165085], [86.1159668, 24.7188797], [86.11094666, 24.72402763], [86.10929871, 24.73224068], [86.10553741, 24.73596954], [86.08657837, 24.74632072], [86.06318665, 24.75167084], [86.06041718, 24.74768066], [86.05503845, 24.74634933], [86.04270935, 24.74387169], [86.03907013, 24.74131966], [86.03681946, 24.74382973], [86.03601074, 24.74734116], [86.04154968, 24.74790001], [86.04535675, 24.75191116], [86.04984283, 24.75578117], [86.0530014, 24.76174927], [86.05288696, 24.76770973], [86.05264282, 24.77318954], [86.05058289, 24.77954102], [86.04788208, 24.77828979], [86.04305267, 24.77740097], [86.03897858, 24.77667046], [86.03443909, 24.77617073], [86.03179169, 24.77275276], [86.02778625, 24.77029037], [86.02275848, 24.76938057], [86.01967621, 24.76776123], [86.01397705, 24.7689991], [86.00956726, 24.76799965], [86.00611115, 24.76568031], [85.99997711, 24.75138092], [85.97725677, 24.74763107], [85.97589111, 24.74596977], [85.97271729, 24.73628998], [85.97016907, 24.73357964], [85.96613312, 24.73229027], [85.96064758, 24.7317009], [85.95030212, 24.73211861], [85.94270325, 24.73442078], [85.92767334, 24.7404995], [85.9209671, 24.74456024], [85.9105072, 24.75366974], [85.90457153, 24.76128006], [85.90168762, 24.76986122], [85.88717651, 24.78558922], [85.88967896, 24.79165077], [85.8777771, 24.80029106], [85.86402893, 24.80542946], [85.85381317, 24.80764008], [85.84194183, 24.80805969], [85.8272171, 24.80964279], [85.82257843, 24.80895042], [85.81803131, 24.80696106], [85.81260681, 24.79936028], [85.81066132, 24.79449844], [85.78572845, 24.79868126], [85.77923584, 24.80048943], [85.77723694, 24.7989502], [85.76940155, 24.8028717], [85.76859283, 24.80404091], [85.76879883, 24.80881119], [85.76544952, 24.81250954], [85.76074982, 24.81507111], [85.75827789, 24.81508827], [85.74727631, 24.81991959], [85.73674011, 24.82265091], [85.73500824, 24.82138252], [85.73252106, 24.81648254], [85.72978973, 24.80849075], [85.72830963, 24.80066109], [85.72296906, 24.79890823], [85.72099304, 24.7869606], [85.71231079, 24.78333282], [85.70980072, 24.7809906], [85.709198, 24.77563858], [85.70478058, 24.76883125], [85.70346832, 24.76349258], [85.70355988, 24.7574501], [85.70553589, 24.75162125], [85.70812988, 24.7476902], [85.70533752, 24.74005127], [85.70477295, 24.72872925], [85.70343781, 24.72537041], [85.69875336, 24.72106934], [85.69639587, 24.71725082], [85.6966629, 24.71347237], [85.6870575, 24.70089149], [85.67965698, 24.69376755], [85.6495285, 24.68704033], [85.64826202, 24.68188095], [85.65046692, 24.67924118], [85.65997314, 24.6747303], [85.65975952, 24.67031288], [85.66079712, 24.66757965], [85.66333008, 24.66471291], [85.66371918, 24.66098022], [85.66069794, 24.65060234], [85.66118622, 24.64664078], [85.66364288, 24.64447021], [85.66432953, 24.6410408], [85.66570282, 24.63626099], [85.66895294, 24.6305294], [85.67212677, 24.61940002], [85.670578, 24.59943008], [85.67238617, 24.59818077], [85.67352295, 24.59563065], [85.67324829, 24.59294128], [85.67031097, 24.5880928], [85.66470337, 24.58193016], [85.64427948, 24.57829094], [85.63279724, 24.58056068], [85.62198639, 24.58385849], [85.615448, 24.58292961], [85.60852051, 24.58503914], [85.60787964, 24.59078979], [85.59825134, 24.59757042], [85.59114075, 24.59705925], [85.58196259, 24.60009956], [85.57657623, 24.60301018], [85.56989288, 24.60021973], [85.56520081, 24.59666061], [85.56285095, 24.59127045], [85.56138611, 24.58366966], [85.56221771, 24.58098984], [85.56711578, 24.57822037], [85.56575775, 24.571661], [85.56829071, 24.56520081], [85.56445313, 24.56184959], [85.55658722, 24.56064034], [85.55625916, 24.55681992], [85.55461121, 24.55612946], [85.55233002, 24.5594101], [85.54380798, 24.56447983], [85.53901672, 24.56587029], [85.53679657, 24.56524086], [85.53646088, 24.56380081], [85.53820038, 24.56145096], [85.53987122, 24.5561409], [85.54035187, 24.55034828], [85.53646088, 24.53601074], [85.53418732, 24.53219032], [85.51830292, 24.52454948], [85.51481628, 24.52782822], [85.50435638, 24.52972984], [85.50241852, 24.53142929], [85.50319672, 24.53572273], [85.50254822, 24.5428791], [85.49997711, 24.54389], [85.49746704, 24.54688072], [85.49752045, 24.54850006], [85.49446106, 24.55061913], [85.48944092, 24.54915047], [85.48648071, 24.55075073], [85.4809494, 24.5481205], [85.47215271, 24.54779053], [85.45658875, 24.53921127], [85.44655609, 24.53997993], [85.44230652, 24.53944969], [85.44213104, 24.53938484], [85.43327332, 24.53607941], [85.42753601, 24.53729057], [85.411026, 24.54511261], [85.40661621, 24.54566193], [85.40305328, 24.54494095], [85.39517212, 24.54128075], [85.38860321, 24.53708076], [85.38336945, 24.53519058]]]]}}, {\\\"id\\\": \\\"5\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.7_1\\\", \\\"HASC_1\\\": \\\"IN.CT\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Chhattisgarh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 76.9, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1205.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1868.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3073.0, \\\"geo-id\\\": 5, \\\"hpm25_child_popweighted\\\": 204.4, \\\"hpm25_female_popweighted\\\": 235.0, \\\"hpm25_male_popweighted\\\": 169.2, \\\"location\\\": \\\"Chhattisgarh\\\", \\\"mort_apm25_6cod_mean_total\\\": 10640.0, \\\"mort_hpm25_6cod_mean_total\\\": 16566.0, \\\"mort_tpm25_6cod_mean_total\\\": 27206.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[80.98058319, 17.93985939], [80.98013306, 17.94326019], [80.97981262, 17.94573021], [80.97805786, 17.9496212], [80.9759903, 17.96291924], [80.97383881, 17.97681046], [80.9731369, 17.98635292], [80.97264099, 17.99317932], [80.97151947, 17.99736977], [80.9699173, 18.00305939], [80.96845245, 18.0118103], [80.96617126, 18.01859856], [80.96389771, 18.02444077], [80.96321106, 18.02816963], [80.96264648, 18.03117943], [80.96227264, 18.03153038], [80.96595764, 18.04346848], [80.96350098, 18.04977989], [80.95243835, 18.07188034], [80.94399261, 18.08102036], [80.94597626, 18.08424187], [80.94835663, 18.09127045], [80.94983673, 18.0983181], [80.94979858, 18.1036911], [80.94754791, 18.11683846], [80.94935608, 18.12318039], [80.96753693, 18.13799286], [80.97263336, 18.14355087], [80.97480011, 18.15192032], [80.97383881, 18.1583004], [80.97367859, 18.16814995], [80.96556854, 18.16835976], [80.95419312, 18.16698074], [80.94985962, 18.16422844], [80.94422913, 18.15709114], [80.93672943, 18.15480042], [80.93582153, 18.15253067], [80.93199158, 18.14941025], [80.9119873, 18.13850975], [80.90072632, 18.13467026], [80.89292908, 18.13445091], [80.88111877, 18.13253021], [80.8620224, 18.13266945], [80.86160278, 18.1364727], [80.86035156, 18.13750076], [80.85838318, 18.1391201], [80.8557663, 18.14293098], [80.85549927, 18.14501953], [80.85526276, 18.14678955], [80.8555069, 18.14915085], [80.85578918, 18.15168953], [80.85167694, 18.16835976], [80.85263062, 18.17850113], [80.85222626, 18.18348122], [80.84893799, 18.19318962], [80.84848022, 18.19594955], [80.84819794, 18.19765091], [80.84877777, 18.19919014], [80.84915924, 18.20021057], [80.85650635, 18.19842911], [80.86126709, 18.19869995], [80.86564636, 18.20099258], [80.86725616, 18.20318031], [80.86749268, 18.20725822], [80.86353302, 18.21718979], [80.86174774, 18.22167015], [80.85910034, 18.22600174], [80.8396225, 18.2280407], [80.83423615, 18.23328018], [80.82958984, 18.23411942], [80.82419586, 18.23357964], [80.81891632, 18.23098183], [80.81719208, 18.22521019], [80.81835175, 18.21903038], [80.81772614, 18.21276093], [80.81874847, 18.19202042], [80.81791687, 18.18712044], [80.81067657, 18.18325996], [80.81085205, 18.17847252], [80.79792786, 18.16629982], [80.79364014, 18.16546059], [80.78691864, 18.16418076], [80.76239777, 18.16296959], [80.75385284, 18.16389084], [80.74507141, 18.16483116], [80.73455811, 18.17171288], [80.73253632, 18.19419098], [80.73226166, 18.20545006], [80.73326874, 18.21879005], [80.75688934, 18.22949982], [80.76937866, 18.2364006], [80.7842865, 18.24327087], [80.78726959, 18.24656105], [80.78827667, 18.24978065], [80.78811646, 18.25403976], [80.78663635, 18.25591087], [80.78489685, 18.25809097], [80.78161621, 18.25958252], [80.77739716, 18.25974083], [80.77340698, 18.26493073], [80.76638031, 18.27823257], [80.76322174, 18.28172112], [80.76156616, 18.28210258], [80.75949097, 18.28256989], [80.75702667, 18.28470993], [80.7529068, 18.29127121], [80.75132751, 18.29747009], [80.74462128, 18.30218124], [80.7452774, 18.30508995], [80.74443817, 18.3168602], [80.74292755, 18.32216072], [80.73478699, 18.33868027], [80.72638702, 18.35025024], [80.72405243, 18.35737038], [80.72276306, 18.36131096], [80.72289276, 18.3642292], [80.72306824, 18.36790085], [80.72424316, 18.37198257], [80.7227478, 18.37580109], [80.71862793, 18.37924194], [80.71626282, 18.38294029], [80.71594238, 18.38552284], [80.71572876, 18.38729095], [80.72400665, 18.39524841], [80.72712708, 18.39999962], [80.72878265, 18.40380096], [80.72653961, 18.40899086], [80.72248077, 18.41032028], [80.71827698, 18.40979958], [80.71734619, 18.40908051], [80.71302795, 18.4057312], [80.69100952, 18.41934967], [80.69262695, 18.42885017], [80.69525909, 18.43457031], [80.69889069, 18.43600082], [80.69496918, 18.4407711], [80.69191742, 18.44045067], [80.68309021, 18.44462013], [80.68280029, 18.44716072], [80.68245697, 18.45001984], [80.6805191, 18.45355034], [80.67414856, 18.45631981], [80.67318726, 18.45831108], [80.67153168, 18.45973969], [80.66982269, 18.46121025], [80.66610718, 18.46264076], [80.66236115, 18.4657402], [80.65077972, 18.4722805], [80.64826202, 18.4790802], [80.64485168, 18.48351097], [80.63681793, 18.49394989], [80.63459015, 18.49863052], [80.63395691, 18.50125122], [80.63350677, 18.50315094], [80.63533783, 18.50572968], [80.63640594, 18.50723076], [80.63564301, 18.51158905], [80.63497925, 18.51531029], [80.63347626, 18.51761246], [80.6326828, 18.51884079], [80.62697601, 18.51816177], [80.62132263, 18.52312851], [80.61384583, 18.52605057], [80.61081696, 18.53353119], [80.60402679, 18.54071999], [80.60098267, 18.54503059], [80.5955658, 18.5490799], [80.58146667, 18.55745125], [80.56794739, 18.56145096], [80.56195068, 18.5695591], [80.55779266, 18.57275963], [80.54043579, 18.58295059], [80.53199768, 18.58605957], [80.53003693, 18.58879089], [80.52931976, 18.58980942], [80.52871704, 18.59284973], [80.52857208, 18.59370041], [80.52179718, 18.60075951], [80.518013, 18.60345078], [80.51525116, 18.6072998], [80.51383209, 18.6131382], [80.51071167, 18.61567116], [80.49812317, 18.61765289], [80.48838806, 18.62672043], [80.4834671, 18.62812042], [80.48204803, 18.62791824], [80.48005676, 18.62763977], [80.47218323, 18.62368965], [80.46774292, 18.62280083], [80.4630127, 18.6226902], [80.45524597, 18.62490273], [80.45020294, 18.6263504], [80.41755676, 18.61071968], [80.41599274, 18.60878754], [80.40703583, 18.60774994], [80.40209198, 18.60717964], [80.39325714, 18.60296059], [80.38939667, 18.59925842], [80.38558197, 18.59649086], [80.38156128, 18.59359932], [80.37052917, 18.60305977], [80.36695099, 18.6046505], [80.36251831, 18.60374069], [80.35972595, 18.60218048], [80.35749054, 18.59834099], [80.35594177, 18.59370995], [80.35289764, 18.59094048], [80.348526, 18.58848953], [80.34184265, 18.58644104], [80.33879089, 18.58820915], [80.33667755, 18.59052086], [80.33146667, 18.59659958], [80.31931305, 18.62173271], [80.31500244, 18.63628769], [80.30780792, 18.65228081], [80.29946136, 18.67921066], [80.29631042, 18.68564034], [80.28884125, 18.69500923], [80.27790833, 18.71096039], [80.27091217, 18.71350098], [80.26753998, 18.71796989], [80.25753784, 18.7312603], [80.25480652, 18.73613167], [80.24745178, 18.74355125], [80.24079895, 18.74868965], [80.23956299, 18.75221062], [80.2405014, 18.75661087], [80.24215698, 18.75974846], [80.24900055, 18.76525116], [80.25456238, 18.76595116], [80.26065063, 18.7650795], [80.26145172, 18.76497078], [80.26291656, 18.76428986], [80.26541901, 18.76316071], [80.27182007, 18.76222038], [80.27655029, 18.76485062], [80.27953339, 18.76785278], [80.29017639, 18.78625107], [80.29415894, 18.79059029], [80.29943848, 18.79353142], [80.30589294, 18.79434967], [80.31873322, 18.79598045], [80.33470154, 18.80611038], [80.34622192, 18.81108093], [80.34778595, 18.81594086], [80.34850311, 18.82394028], [80.34558105, 18.83393097], [80.33963776, 18.8483429], [80.33573151, 18.85611916], [80.32565308, 18.86996078], [80.3216629, 18.87483025], [80.31346893, 18.88117981], [80.30990601, 18.88480186], [80.30856323, 18.88616753], [80.29810333, 18.9004612], [80.29138947, 18.90759087], [80.27046967, 18.92491913], [80.26763916, 18.92878914], [80.26516724, 18.93456078], [80.26468658, 18.93732071], [80.26412964, 18.94052124], [80.26531982, 18.94699287], [80.26747894, 18.95257187], [80.26902008, 18.96416092], [80.26734924, 18.98067093], [80.26753235, 18.98396111], [80.26772308, 18.98732948], [80.27230835, 18.99744034], [80.28811646, 19.01393127], [80.29341125, 19.02159119], [80.29528809, 19.02873993], [80.2905426, 19.04001045], [80.28884125, 19.04628944], [80.29170227, 19.04980087], [80.30224609, 19.05554962], [80.31577301, 19.06458092], [80.31996155, 19.06940269], [80.32211304, 19.07487106], [80.32256317, 19.08216095], [80.31994629, 19.0882206], [80.32411957, 19.09493065], [80.33154297, 19.10107994], [80.3296814, 19.10741997], [80.32235718, 19.12022018], [80.32086182, 19.12449074], [80.32485199, 19.1415329], [80.3355484, 19.14756966], [80.33963013, 19.15302086], [80.34059143, 19.15891838], [80.34411621, 19.16180992], [80.34546661, 19.16291046], [80.36235809, 19.16932106], [80.37290192, 19.1751194], [80.38111115, 19.18073082], [80.38667297, 19.18902016], [80.38611603, 19.19563293], [80.37993622, 19.20870972], [80.37702179, 19.21736908], [80.37918091, 19.2326107], [80.38334656, 19.23913956], [80.38845062, 19.24331093], [80.39684296, 19.2462101], [80.40157318, 19.24682999], [80.40818024, 19.24770164], [80.41446686, 19.24918938], [80.41916656, 19.25028038], [80.42807007, 19.25438118], [80.43702698, 19.26107025], [80.44542694, 19.26988983], [80.45680237, 19.2991581], [80.46212769, 19.3081398], [80.46450043, 19.31395149], [80.46530151, 19.31591988], [80.47049713, 19.32892036], [80.47558594, 19.33504295], [80.48110199, 19.33782005], [80.5003891, 19.34129906], [80.50720978, 19.34359169], [80.51383972, 19.34819984], [80.51898193, 19.35400963], [80.52271271, 19.35975075], [80.52612305, 19.36721039], [80.53153992, 19.3743], [80.55934143, 19.39755249], [80.56781769, 19.40092087], [80.57084656, 19.39942169], [80.57286072, 19.39842033], [80.5839386, 19.37715912], [80.5847168, 19.3737011], [80.58226013, 19.36833954], [80.58558655, 19.35301971], [80.58862305, 19.34440041], [80.59266663, 19.3352108], [80.59568024, 19.33131981], [80.59851837, 19.3246727], [80.60006714, 19.31809044], [80.60394287, 19.31176949], [80.6101532, 19.30714035], [80.61772156, 19.30481911], [80.62549591, 19.30681038], [80.63530731, 19.3128376], [80.65788269, 19.32427979], [80.66439056, 19.32657814], [80.67189026, 19.32644844], [80.67922211, 19.32414055], [80.68419647, 19.32002831], [80.68528748, 19.31260109], [80.68180084, 19.29584122], [80.68356323, 19.28691101], [80.68860626, 19.28348923], [80.69374847, 19.28232193], [80.6987381, 19.28227043], [80.70043945, 19.2822628], [80.70918274, 19.28330994], [80.7183075, 19.28549957], [80.73065948, 19.28403091], [80.73673248, 19.2869606], [80.7434082, 19.28597069], [80.74923706, 19.28674126], [80.75505066, 19.2952404], [80.75974274, 19.29975128], [80.76397705, 19.30527115], [80.7661972, 19.30813026], [80.77809143, 19.31854057], [80.78246307, 19.3217411], [80.78790283, 19.32411194], [80.7950058, 19.32476044], [80.79934692, 19.32516289], [80.80282593, 19.33228111], [80.80634308, 19.33490944], [80.81282806, 19.33813095], [80.81649017, 19.34247017], [80.82641602, 19.34803963], [80.83908081, 19.35515022], [80.84500885, 19.36091042], [80.84282684, 19.36610985], [80.83499908, 19.37068176], [80.8232193, 19.3747406], [80.815979, 19.37907028], [80.81273651, 19.38274002], [80.80854797, 19.39703941], [80.79795074, 19.4116497], [80.79538727, 19.4187603], [80.79244995, 19.42266083], [80.78793335, 19.42670059], [80.79432678, 19.42876816], [80.80799866, 19.43161964], [80.82524872, 19.43912125], [80.83508301, 19.44238091], [80.85748291, 19.44254112], [80.86749268, 19.44346046], [80.87599945, 19.44795036], [80.88562775, 19.45650291], [80.89206696, 19.46568108], [80.89215851, 19.4815197], [80.8914032, 19.49084091], [80.88970184, 19.49925041], [80.88553619, 19.50925064], [80.87905121, 19.51902962], [80.87359619, 19.52235031], [80.86334991, 19.52194977], [80.85225677, 19.52416992], [80.84538269, 19.5291729], [80.84082794, 19.53357124], [80.83737946, 19.54063034], [80.83605194, 19.54898071], [80.83352661, 19.55597115], [80.8276062, 19.56267166], [80.8196106, 19.56540108], [80.80922699, 19.56451035], [80.78515625, 19.56040955], [80.76641083, 19.56831932], [80.76503754, 19.57426071], [80.76426697, 19.58483124], [80.75795746, 19.59017181], [80.72099304, 19.60839081], [80.7077713, 19.61045837], [80.69668579, 19.61083031], [80.6830368, 19.61060905], [80.66203308, 19.60873032], [80.65685272, 19.61226082], [80.65589142, 19.6169796], [80.6561203, 19.62515068], [80.66220093, 19.66258049], [80.66538239, 19.67296982], [80.666008, 19.68626976], [80.66455078, 19.69075012], [80.66584015, 19.69221115], [80.66133881, 19.69750023], [80.64563751, 19.7064991], [80.64029694, 19.71245956], [80.63350677, 19.7184906], [80.62020874, 19.72377014], [80.61313629, 19.72892952], [80.59033203, 19.73443031], [80.58207703, 19.73807144], [80.57868195, 19.74392128], [80.57052612, 19.75473976], [80.56765747, 19.75667953], [80.55021667, 19.76455116], [80.53967285, 19.77459908], [80.53887177, 19.78070259], [80.54244232, 19.79424286], [80.54194641, 19.80315018], [80.54424286, 19.8112011], [80.54242706, 19.81927109], [80.5353775, 19.81813049], [80.51780701, 19.82886124], [80.50750732, 19.82994843], [80.49839783, 19.82947159], [80.4907074, 19.82536125], [80.47602844, 19.82800102], [80.46916199, 19.82466125], [80.45954895, 19.8113308], [80.46290588, 19.80575943], [80.47480774, 19.8033905], [80.47714233, 19.80122948], [80.48023987, 19.79544067], [80.48207092, 19.78950119], [80.4825592, 19.78071022], [80.47808838, 19.77240944], [80.46679688, 19.78487968], [80.46176147, 19.7882328], [80.45243835, 19.79290009], [80.44953918, 19.79265976], [80.44270325, 19.7905407], [80.43579102, 19.79185104], [80.42900848, 19.7951107], [80.41768646, 19.79714012], [80.40014648, 19.7936306], [80.39470673, 19.79457855], [80.39842987, 19.80319023], [80.3975296, 19.81623077], [80.40497589, 19.81542015], [80.41731262, 19.8091507], [80.42459106, 19.80804062], [80.43165588, 19.81030083], [80.44696808, 19.82032013], [80.45511627, 19.82379913], [80.46029663, 19.82802963], [80.46363068, 19.8358326], [80.46861267, 19.83753014], [80.47103119, 19.8426609], [80.47502136, 19.85705948], [80.48764038, 19.86512947], [80.49752045, 19.86874962], [80.4969101, 19.8771801], [80.49166107, 19.89053917], [80.48983765, 19.89367294], [80.48265076, 19.89889908], [80.46895599, 19.90336037], [80.46121979, 19.90343094], [80.45278931, 19.90000916], [80.44444275, 19.89355087], [80.43579865, 19.89551926], [80.43100739, 19.8984108], [80.41474915, 19.90291977], [80.4076767, 19.90590286], [80.40265656, 19.90960121], [80.40577698, 19.92545128], [80.40629578, 19.93250084], [80.40931702, 19.93538094], [80.42059326, 19.93622971], [80.42510986, 19.93730927], [80.43100739, 19.94094086], [80.43855286, 19.9471302], [80.4437027, 19.95267105], [80.45300293, 19.94523811], [80.46450043, 19.94625092], [80.46875, 19.94026947], [80.469841, 19.93366051], [80.47289276, 19.93124962], [80.48047638, 19.92780113], [80.5017395, 19.92475128], [80.50875092, 19.92591095], [80.52037811, 19.93087959], [80.52600861, 19.94112015], [80.52628326, 19.94862747], [80.53383636, 19.95302963], [80.53237152, 19.96706009], [80.53473663, 19.97092056], [80.53775787, 19.97356033], [80.54415131, 19.98151016], [80.54554749, 19.98718071], [80.54353333, 19.99508286], [80.53994751, 19.99772072], [80.53578949, 19.99991989], [80.53253937, 20.00393295], [80.53542328, 20.01120949], [80.54158783, 20.03722191], [80.54109192, 20.04818916], [80.54522705, 20.05957031], [80.54615784, 20.06571007], [80.54183197, 20.07668114], [80.53495789, 20.08539963], [80.53523254, 20.09218025], [80.54125214, 20.10494995], [80.54036713, 20.10983276], [80.53575897, 20.11384964], [80.52880859, 20.11750031], [80.52668762, 20.12137985], [80.52359009, 20.12447166], [80.51815033, 20.12683105], [80.51053619, 20.12693024], [80.50358582, 20.1287899], [80.49803162, 20.13891983], [80.4911499, 20.14147949], [80.48293304, 20.13788986], [80.47730255, 20.13853073], [80.46678162, 20.14268112], [80.45865631, 20.14455032], [80.45133972, 20.14487076], [80.44787598, 20.14157104], [80.44413757, 20.13034248], [80.4396286, 20.12911987], [80.4319458, 20.13134003], [80.42695618, 20.13023949], [80.40149689, 20.13951111], [80.39383698, 20.14402008], [80.38762665, 20.15158081], [80.38456726, 20.15851021], [80.38601685, 20.16280937], [80.39045715, 20.16627121], [80.39190674, 20.17073059], [80.39279938, 20.17740059], [80.39459229, 20.18158913], [80.39827728, 20.18344116], [80.40406036, 20.1844101], [80.41340637, 20.18753052], [80.41398621, 20.19023132], [80.41201782, 20.20220947], [80.40982056, 20.20528984], [80.39800262, 20.21278], [80.38803864, 20.23061943], [80.38295746, 20.2417202], [80.3862381, 20.24461174], [80.40371704, 20.24769974], [80.4090271, 20.24913025], [80.41526794, 20.25229073], [80.4196167, 20.25156021], [80.42294312, 20.25260925], [80.43730927, 20.25847816], [80.44838715, 20.26388168], [80.45646667, 20.26890945], [80.46544647, 20.2716217], [80.47587585, 20.27368927], [80.49447632, 20.27479935], [80.51082611, 20.26961136], [80.52667999, 20.2847805], [80.53582001, 20.29467964], [80.53930664, 20.30039024], [80.54202271, 20.30684853], [80.55158234, 20.31153107], [80.58423615, 20.3192997], [80.60542297, 20.32019043], [80.60671234, 20.32534981], [80.61669159, 20.32574081], [80.61776733, 20.33368111], [80.61667633, 20.33761024], [80.61071014, 20.34526062], [80.61149597, 20.34934235], [80.60601044, 20.35642052], [80.60620117, 20.36079025], [80.60513306, 20.36615944], [80.60089874, 20.36919022], [80.60072327, 20.37260056], [80.60222626, 20.37644005], [80.5983963, 20.38068008], [80.59017181, 20.38434982], [80.58744049, 20.38789177], [80.58598328, 20.39204979], [80.58602142, 20.39561081], [80.58651733, 20.40072823], [80.5897522, 20.41277122], [80.59173584, 20.41505051], [80.5944519, 20.42070961], [80.5998764, 20.42692184], [80.60343933, 20.43325043], [80.60144806, 20.4373703], [80.59715271, 20.44207001], [80.59468842, 20.44642067], [80.60166931, 20.45726013], [80.60331726, 20.46241951], [80.60494232, 20.48115158], [80.60620117, 20.48707008], [80.6072464, 20.50391006], [80.60688782, 20.51254082], [80.60852814, 20.51620293], [80.61003113, 20.53198051], [80.61273956, 20.53726006], [80.61341095, 20.54157066], [80.61029816, 20.5450592], [80.61178589, 20.55096054], [80.6099472, 20.55632973], [80.6121521, 20.55958939], [80.61707306, 20.56223106], [80.61972046, 20.56731987], [80.61424255, 20.576931], [80.61746979, 20.58103752], [80.61460876, 20.58527184], [80.61286163, 20.59057808], [80.61949158, 20.59791946], [80.62232208, 20.60386276], [80.61767578, 20.60617065], [80.60896301, 20.60598946], [80.60256958, 20.60738945], [80.59246826, 20.61309814], [80.58573151, 20.61415291], [80.57866669, 20.61412048], [80.56730652, 20.61240768], [80.55903625, 20.60997963], [80.55140686, 20.59907913], [80.52983093, 20.59008026], [80.51950836, 20.58468056], [80.51190186, 20.58511925], [80.50009918, 20.58686256], [80.49717712, 20.59580994], [80.49291229, 20.60408974], [80.48419189, 20.61195946], [80.4815979, 20.61709976], [80.48095703, 20.62355042], [80.48159027, 20.62976265], [80.48484802, 20.63517952], [80.48964691, 20.6398983], [80.50203705, 20.6491909], [80.50760651, 20.65460014], [80.51891327, 20.66176033], [80.5255661, 20.66319084], [80.53742218, 20.66402054], [80.54738617, 20.67126083], [80.55271149, 20.67308998], [80.56680298, 20.67292976], [80.57279205, 20.6742897], [80.57833862, 20.67877007], [80.58011627, 20.68364143], [80.5792923, 20.68997955], [80.57772064, 20.69407082], [80.57492065, 20.69842911], [80.56394958, 20.70718956], [80.56018829, 20.71177292], [80.55587006, 20.72257042], [80.55454254, 20.74715042], [80.55200958, 20.75345039], [80.54817963, 20.75908089], [80.54553223, 20.76536942], [80.54545593, 20.78227806], [80.54334259, 20.79179955], [80.54569244, 20.80137253], [80.54889679, 20.80841064], [80.55076599, 20.81546021], [80.55589294, 20.81968117], [80.55478668, 20.82942009], [80.55036926, 20.8456707], [80.55060577, 20.85991096], [80.54891205, 20.86808968], [80.54975891, 20.88891029], [80.54618835, 20.90307999], [80.53910065, 20.92106056], [80.53813171, 20.9260807], [80.5418396, 20.93391991], [80.5352478, 20.93132019], [80.52641296, 20.93210983], [80.51062012, 20.92880058], [80.50067902, 20.92891121], [80.4912796, 20.92785072], [80.48274994, 20.92847061], [80.47392273, 20.92736053], [80.46531677, 20.92728806], [80.45909119, 20.92815018], [80.45555878, 20.93210983], [80.45658875, 20.93724823], [80.4487915, 20.94530106], [80.448349, 20.95101166], [80.4437561, 20.96103287], [80.44069672, 20.96545982], [80.43894196, 20.97155952], [80.43808746, 20.99209976], [80.43334198, 20.99975014], [80.42948914, 21.00263977], [80.42662811, 21.00505066], [80.42475128, 21.00733948], [80.42375946, 21.00959015], [80.42758179, 21.01246071], [80.42881012, 21.01357079], [80.43010712, 21.01635933], [80.43247223, 21.01713181], [80.43454742, 21.01923943], [80.43596649, 21.02205086], [80.43675995, 21.02501106], [80.43860626, 21.02717018], [80.44085693, 21.02800941], [80.44325256, 21.02918816], [80.44523621, 21.03094292], [80.4465332, 21.03362083], [80.44734192, 21.03662109], [80.44754791, 21.03961945], [80.44734955, 21.04076195], [80.44706726, 21.04432106], [80.44786835, 21.04687119], [80.44850159, 21.04961014], [80.44822693, 21.05196953], [80.44763184, 21.05448914], [80.44727325, 21.0566597], [80.44610596, 21.05998993], [80.44474792, 21.06158066], [80.44399261, 21.06324005], [80.44297791, 21.06592941], [80.44259644, 21.06698036], [80.44097137, 21.07040024], [80.44261169, 21.07246017], [80.44275665, 21.07419014], [80.44254303, 21.07743073], [80.4420166, 21.08060074], [80.44095612, 21.08325195], [80.44000244, 21.08531952], [80.43813324, 21.08880806], [80.43640137, 21.09271049], [80.43550873, 21.09518051], [80.43331909, 21.0971508], [80.43419647, 21.09802246], [80.43518066, 21.09901047], [80.4360733, 21.10104752], [80.4367218, 21.10267067], [80.43766022, 21.10453033], [80.43872833, 21.10696983], [80.4390564, 21.10917091], [80.43950653, 21.11178017], [80.44226074, 21.11186981], [80.44371796, 21.11165047], [80.44550323, 21.11125946], [80.44696045, 21.1110611], [80.44924927, 21.11194038], [80.44933319, 21.114851], [80.44914246, 21.11531067], [80.44822693, 21.1162796], [80.44618988, 21.11816978], [80.44387054, 21.11925125], [80.44037628, 21.12030983], [80.43865204, 21.12140083], [80.44072723, 21.12547112], [80.44246674, 21.12816048], [80.44402313, 21.13060951], [80.44602966, 21.13578033], [80.44696045, 21.13814926], [80.44821167, 21.14152908], [80.44921875, 21.14442825], [80.45009613, 21.14691925], [80.45157623, 21.14965057], [80.45281982, 21.15434074], [80.45391846, 21.15862274], [80.45400238, 21.16174126], [80.45426941, 21.1654377], [80.45526886, 21.16908073], [80.45729828, 21.17284012], [80.46163177, 21.17282104], [80.46418762, 21.17209053], [80.46784973, 21.17148972], [80.4733429, 21.17131042], [80.47490692, 21.17143059], [80.47709656, 21.17307091], [80.47943878, 21.17493057], [80.48181152, 21.17657089], [80.48600006, 21.17719078], [80.48953247, 21.17756081], [80.49230957, 21.17994118], [80.49549866, 21.18325806], [80.49787903, 21.18403244], [80.49989319, 21.18404007], [80.50257111, 21.18330956], [80.50453186, 21.18304062], [80.50763702, 21.18244171], [80.50932312, 21.18347931], [80.5103302, 21.18649101], [80.51081085, 21.18890953], [80.5115509, 21.19111061], [80.51316833, 21.19361115], [80.51480103, 21.1960392], [80.51624298, 21.19829941], [80.51822662, 21.20108032], [80.52073669, 21.2035408], [80.52501678, 21.2026329], [80.5279007, 21.20202065], [80.53045654, 21.20084], [80.532341, 21.20022011], [80.53498077, 21.19960976], [80.53888702, 21.19928932], [80.54187775, 21.19919014], [80.54351044, 21.20001984], [80.54656982, 21.20066833], [80.54930115, 21.20098114], [80.55063629, 21.20117188], [80.55367279, 21.20251083], [80.55779266, 21.20393944], [80.56124115, 21.20581055], [80.56402588, 21.20802116], [80.56611633, 21.21027946], [80.56661224, 21.21080971], [80.56842804, 21.21388245], [80.57183838, 21.21685028], [80.57483673, 21.21825981], [80.57810211, 21.21990013], [80.5815506, 21.22177124], [80.58447266, 21.22306061], [80.58938599, 21.22471046], [80.5923233, 21.22484016], [80.59622192, 21.22453117], [80.59889984, 21.22512817], [80.60099792, 21.22618294], [80.60344696, 21.22742271], [80.60507965, 21.22875977], [80.60608673, 21.22997093], [80.60766602, 21.23125076], [80.60868835, 21.23179054], [80.61048889, 21.23329163], [80.61170959, 21.23456955], [80.61344147, 21.23682976], [80.61572266, 21.24002075], [80.62010193, 21.24236107], [80.62464142, 21.2442894], [80.62767029, 21.24570084], [80.6322403, 21.24729919], [80.63530731, 21.25013924], [80.63735962, 21.25269127], [80.63873291, 21.25478172], [80.63948059, 21.25749969], [80.64111328, 21.26143074], [80.64190674, 21.26442909], [80.64264679, 21.2690506], [80.64340973, 21.27229118], [80.64488983, 21.27600288], [80.64676666, 21.27814293], [80.64862061, 21.28017044], [80.65080261, 21.28158951], [80.65215302, 21.28325272], [80.65368652, 21.28604126], [80.65480804, 21.28951073], [80.65808868, 21.28940964], [80.6608963, 21.28977966], [80.66332245, 21.29095078], [80.66526794, 21.29229164], [80.66828918, 21.29399109], [80.67095947, 21.29590988], [80.67295074, 21.29828835], [80.67308807, 21.30117989], [80.67237091, 21.30588913], [80.67378998, 21.30908012], [80.67273712, 21.31126976], [80.67095184, 21.31228065], [80.6680603, 21.31381989], [80.66699982, 21.31618118], [80.66654205, 21.3193512], [80.66559601, 21.32211113], [80.66355896, 21.32485962], [80.66239929, 21.32612038], [80.65986633, 21.32777023], [80.6579361, 21.3293705], [80.65653229, 21.3307724], [80.65991211, 21.3344326], [80.66130066, 21.33547974], [80.66291809, 21.3373394], [80.66494751, 21.34093285], [80.66638184, 21.34428978], [80.66845703, 21.34856987], [80.66998291, 21.35423088], [80.67150879, 21.35856056], [80.67517853, 21.36355019], [80.67827606, 21.36623001], [80.68097687, 21.36919022], [80.68416595, 21.37261009], [80.68583679, 21.37683105], [80.68781281, 21.38008118], [80.68946838, 21.3842392], [80.69165039, 21.38818169], [80.69326782, 21.3937912], [80.69335175, 21.39817047], [80.69287109, 21.40145111], [80.69507599, 21.4057312], [80.69706726, 21.40858078], [80.69814301, 21.41117859], [80.6992569, 21.41411972], [80.6985321, 21.41913033], [80.69764709, 21.42259026], [80.69754791, 21.42719841], [80.69904327, 21.42974091], [80.70162964, 21.43138123], [80.70423126, 21.43365288], [80.70818329, 21.43621063], [80.71209717, 21.43942833], [80.71482086, 21.44226074], [80.71803284, 21.44540024], [80.72120667, 21.44940186], [80.72392273, 21.45317078], [80.72624207, 21.45786095], [80.72770691, 21.46329117], [80.72911072, 21.46825981], [80.73021698, 21.47205162], [80.72891235, 21.47460175], [80.72824097, 21.4769001], [80.72727203, 21.48074913], [80.72583771, 21.48437119], [80.72426605, 21.48794174], [80.72233582, 21.49081039], [80.72197723, 21.4956398], [80.72377014, 21.49871063], [80.72464752, 21.50223923], [80.72429657, 21.50597954], [80.72426605, 21.50926018], [80.72437286, 21.51185989], [80.72442627, 21.51619148], [80.72477722, 21.51825905], [80.72583008, 21.52218819], [80.72702026, 21.52536964], [80.72833252, 21.52813911], [80.72988129, 21.53144836], [80.7308197, 21.53543091], [80.73065948, 21.53872108], [80.72972107, 21.54002953], [80.72807312, 21.54180908], [80.72583771, 21.54421043], [80.72412109, 21.54673958], [80.72087097, 21.5506897], [80.71935272, 21.55200005], [80.71492767, 21.55455971], [80.71354675, 21.55571175], [80.71383667, 21.55865097], [80.7151413, 21.5615406], [80.71608734, 21.56311035], [80.71723938, 21.56501961], [80.71922302, 21.56814957], [80.71953583, 21.57150078], [80.71884918, 21.57356071], [80.71821594, 21.57476807], [80.71689606, 21.57740974], [80.71598053, 21.57953072], [80.71369934, 21.58130074], [80.71253204, 21.58216095], [80.71164703, 21.58319092], [80.70955658, 21.58478928], [80.70923615, 21.58675003], [80.70913696, 21.58980942], [80.70905304, 21.59238815], [80.70915985, 21.59447289], [80.70935059, 21.59810066], [80.70903015, 21.60075951], [80.70939636, 21.60398102], [80.71083832, 21.60624123], [80.71351624, 21.60741043], [80.71617126, 21.60956955], [80.71781158, 21.61246109], [80.71990967, 21.61461067], [80.7216568, 21.61721992], [80.72138977, 21.62050056], [80.72245789, 21.62276077], [80.72210693, 21.62500191], [80.72117615, 21.62783051], [80.72097015, 21.63047028], [80.72025299, 21.63422012], [80.71968842, 21.63582039], [80.71955872, 21.63663292], [80.72049713, 21.64067078], [80.71910858, 21.64365959], [80.71684265, 21.64427948], [80.71463776, 21.64495087], [80.71235657, 21.64613914], [80.71121979, 21.64907074], [80.71045685, 21.65241051], [80.71050262, 21.65369034], [80.70979309, 21.65615082], [80.70909882, 21.65815926], [80.70833588, 21.66098976], [80.7078476, 21.6619606], [80.70749664, 21.66410065], [80.70944977, 21.66571045], [80.71003723, 21.66773987], [80.70874023, 21.66934967], [80.70735168, 21.67158127], [80.70923615, 21.67361069], [80.71089172, 21.67408943], [80.71190643, 21.67485046], [80.712883, 21.67584038], [80.71408844, 21.67728043], [80.71510315, 21.67867088], [80.71631622, 21.68081093], [80.71781921, 21.68307114], [80.71877289, 21.68481064], [80.72027588, 21.6877594], [80.72212982, 21.69059944], [80.72374725, 21.69360161], [80.72492218, 21.69777107], [80.72511292, 21.69828987], [80.72529602, 21.70100021], [80.72490692, 21.70433044], [80.72390747, 21.70583153], [80.72200775, 21.70730972], [80.7197113, 21.7097702], [80.71852875, 21.71186066], [80.7199173, 21.71364021], [80.72267151, 21.71447945], [80.72312927, 21.71562004], [80.72341919, 21.71747017], [80.72387695, 21.71970749], [80.72445679, 21.72249031], [80.72570801, 21.72578049], [80.72580719, 21.72948074], [80.72632599, 21.73102951], [80.72891235, 21.73516083], [80.73101044, 21.73919868], [80.73483276, 21.74764061], [80.73699951, 21.75065041], [80.73841858, 21.75354004], [80.74005127, 21.75649071], [80.74297333, 21.75796127], [80.74503326, 21.75826073], [80.74962616, 21.75773048], [80.75463867, 21.75700951], [80.75874329, 21.75715065], [80.76210022, 21.75791931], [80.76641846, 21.75513077], [80.76982117, 21.75205231], [80.7738266, 21.74982071], [80.77683258, 21.74430847], [80.77709198, 21.74086189], [80.78272247, 21.73957062], [80.78845978, 21.7412796], [80.79258728, 21.74322128], [80.79582977, 21.74427032], [80.79899597, 21.74535179], [80.80362701, 21.74605942], [80.80813599, 21.74644089], [80.811203, 21.74749184], [80.8116684, 21.7508297], [80.81033325, 21.75538063], [80.81044769, 21.75844002], [80.8106308, 21.7610302], [80.81156158, 21.7639904], [80.81355286, 21.76749992], [80.81446075, 21.76832008], [80.81682587, 21.77421761], [80.8182373, 21.77601051], [80.81918335, 21.77815819], [80.82041931, 21.78226089], [80.82081604, 21.78478813], [80.82110596, 21.78697968], [80.82388306, 21.79091072], [80.82550049, 21.79450035], [80.82797241, 21.79682159], [80.82990265, 21.80070114], [80.83170319, 21.80480957], [80.83171082, 21.80867004], [80.83183289, 21.81057167], [80.83238983, 21.81380081], [80.83304596, 21.81691933], [80.83380127, 21.8202095], [80.83558655, 21.82454109], [80.83660126, 21.82719994], [80.837677, 21.82985115], [80.83709717, 21.83176041], [80.83587646, 21.83214951], [80.83368683, 21.83479118], [80.83280945, 21.83749962], [80.83230591, 21.84013939], [80.8316803, 21.8461895], [80.83289337, 21.8490696], [80.8343277, 21.85069847], [80.837677, 21.8518219], [80.84041595, 21.85276031], [80.84117126, 21.85645294], [80.83994293, 21.85881042], [80.83702087, 21.86248016], [80.83666229, 21.86701965], [80.83763885, 21.86881256], [80.8396759, 21.87158012], [80.83959198, 21.87540054], [80.83660126, 21.87854958], [80.83406067, 21.88249969], [80.83141327, 21.88427925], [80.83010864, 21.88479042], [80.82543945, 21.88665009], [80.82405853, 21.88936043], [80.82422638, 21.89103127], [80.82456207, 21.89470863], [80.82380676, 21.89788055], [80.82544708, 21.90388107], [80.82453156, 21.9084301], [80.82620239, 21.9119606], [80.82699585, 21.91358185], [80.83006287, 21.91843033], [80.83139038, 21.92012024], [80.83251953, 21.92175102], [80.83452606, 21.92601967], [80.83589935, 21.92793083], [80.83654022, 21.93180084], [80.83656311, 21.93565941], [80.83561707, 21.93703079], [80.83502197, 21.94089127], [80.83338928, 21.94664001], [80.83184814, 21.9474411], [80.83074188, 21.94719124], [80.8289566, 21.94701958], [80.82627106, 21.94711113], [80.82338715, 21.94732094], [80.82221985, 21.94835091], [80.82115936, 21.95058823], [80.82102966, 21.95145035], [80.81958771, 21.95356941], [80.8184433, 21.95679092], [80.82022095, 21.95813179], [80.82168579, 21.95819855], [80.8245163, 21.95684052], [80.82885742, 21.95743942], [80.83178711, 21.95794106], [80.83583832, 21.95761108], [80.83938599, 21.95774078], [80.8433609, 21.95841026], [80.84577179, 21.96089935], [80.84673309, 21.96362114], [80.84745026, 21.96690941], [80.84851074, 21.97001076], [80.85037231, 21.97281075], [80.8516922, 21.97512054], [80.85253143, 21.97841072], [80.85309601, 21.98129272], [80.85312653, 21.98348045], [80.85456848, 21.9872303], [80.85546875, 21.98880959], [80.85640717, 21.99185181], [80.85719299, 21.99324036], [80.85840607, 21.99543953], [80.85929871, 21.99776077], [80.85933685, 22.0001297], [80.86859894, 22.01120949], [80.86950684, 22.01650047], [80.86894989, 22.03359032], [80.87011719, 22.03858948], [80.87735748, 22.05071259], [80.87663269, 22.0567894], [80.87895966, 22.06060028], [80.88498688, 22.06071091], [80.88844299, 22.06241035], [80.89122772, 22.06595993], [80.8947525, 22.07650948], [80.89817047, 22.1013298], [80.90608978, 22.11444092], [80.9108429, 22.1191597], [80.9171524, 22.12088966], [80.92479706, 22.12067032], [80.93891907, 22.11901093], [80.94552612, 22.11748123], [80.95052338, 22.11301041], [80.95752716, 22.0971508], [80.96553802, 22.08197975], [80.96573639, 22.07917023], [80.96208954, 22.0619297], [80.96341705, 22.05836105], [80.97181702, 22.05429077], [80.97364044, 22.05177116], [80.97885132, 22.04831123], [80.98259735, 22.04895973], [80.98776245, 22.04847908], [80.98808289, 22.05220985], [80.98972321, 22.05649757], [80.99117279, 22.05808067], [80.99282074, 22.05766106], [80.99916077, 22.06150055], [81.00427246, 22.07002068], [80.99742889, 22.08086967], [80.99991608, 22.08965111], [81.00395203, 22.0944519], [81.00369263, 22.0968895], [81.00006866, 22.10083008], [80.99282074, 22.10519028], [80.99027252, 22.10907936], [80.98725128, 22.11065102], [80.98020935, 22.11280823], [80.97666931, 22.11280823], [80.97432709, 22.11136055], [80.97226715, 22.11189079], [80.97081757, 22.11465073], [80.97175598, 22.12148094], [80.97342682, 22.12368965], [80.98670197, 22.13087082], [80.992836, 22.13153076], [81.00517273, 22.13272285], [81.01579285, 22.1327095], [81.01740265, 22.14027977], [81.01761627, 22.15384865], [81.0190506, 22.16526031], [81.01715088, 22.17103958], [81.01328278, 22.17749023], [81.01169586, 22.18400955], [81.01551056, 22.18840981], [81.02150726, 22.18703079], [81.02511597, 22.18882179], [81.02477264, 22.19313049], [81.02575684, 22.19769096], [81.02349091, 22.20282936], [81.01922607, 22.20779037], [81.01579285, 22.21410942], [81.01570892, 22.22021103], [81.01944733, 22.22919083], [81.03631592, 22.23771858], [81.04043579, 22.24057007], [81.04886627, 22.24419022], [81.05452728, 22.24387169], [81.06282043, 22.24685287], [81.06923676, 22.24625969], [81.07258606, 22.24174118], [81.08467865, 22.24674988], [81.09178162, 22.26786041], [81.09681702, 22.2774601], [81.11384583, 22.29438019], [81.11501312, 22.30323982], [81.11470032, 22.31258965], [81.11045837, 22.32149124], [81.10926819, 22.32963943], [81.1120224, 22.3346405], [81.11566162, 22.34408951], [81.11054993, 22.35300064], [81.1068573, 22.36218071], [81.10093689, 22.38323975], [81.10266113, 22.39126968], [81.1046524, 22.41080284], [81.10346985, 22.42208099], [81.10491943, 22.43279076], [81.10999298, 22.44112015], [81.12275696, 22.44762039], [81.13404083, 22.45199966], [81.14807892, 22.4558506], [81.15782166, 22.47448158], [81.16407013, 22.48191071], [81.17066193, 22.48800087], [81.18004608, 22.49015045], [81.18686676, 22.48921013], [81.19264221, 22.4824791], [81.1932373, 22.47370911], [81.19503784, 22.46775818], [81.19419098, 22.46208], [81.20214081, 22.45676994], [81.2097702, 22.45384979], [81.21839142, 22.45165062], [81.22355652, 22.45160866], [81.23310852, 22.45513153], [81.24038696, 22.45918083], [81.25551605, 22.47248268], [81.25623322, 22.48806953], [81.26045227, 22.49356079], [81.26674652, 22.49414063], [81.27146912, 22.49584961], [81.27546692, 22.49944115], [81.28019714, 22.49882126], [81.29170227, 22.48931122], [81.2977829, 22.4865799], [81.30396271, 22.48175049], [81.31591034, 22.48970985], [81.31414795, 22.4996109], [81.31481171, 22.5159111], [81.31939697, 22.51955032], [81.32293701, 22.52433014], [81.33188629, 22.52236938], [81.34794617, 22.51408958], [81.35569, 22.51324272], [81.36177826, 22.5153904], [81.36650085, 22.51436996], [81.37325287, 22.51075172], [81.3787384, 22.50530052], [81.37960815, 22.49790955], [81.37914276, 22.49339104], [81.38067627, 22.48534966], [81.38479614, 22.47784042], [81.38305664, 22.46260262], [81.38617706, 22.45116043], [81.38887024, 22.44483948], [81.39655304, 22.44132042], [81.41411591, 22.44852066], [81.41893005, 22.45421982], [81.42064667, 22.45940018], [81.41783142, 22.46515083], [81.41758728, 22.47363091], [81.42443848, 22.47923851], [81.43177795, 22.48049164], [81.43357086, 22.47771835], [81.43595886, 22.46948814], [81.44246674, 22.46615982], [81.44802856, 22.46739006], [81.45028687, 22.47256279], [81.44332886, 22.47154045], [81.44391632, 22.47867012], [81.43907928, 22.47947121], [81.44081116, 22.48464966], [81.44422913, 22.48702049], [81.43908691, 22.4910202], [81.43805695, 22.49394035], [81.44624329, 22.49586105], [81.45330811, 22.4910202], [81.46067047, 22.49435806], [81.46996307, 22.49398994], [81.47637177, 22.4921608], [81.4798584, 22.49331093], [81.48574829, 22.5033493], [81.49011993, 22.50843048], [81.49175262, 22.51733017], [81.49320984, 22.5196209], [81.50293732, 22.52679062], [81.50656128, 22.52177811], [81.51197052, 22.52352905], [81.5147171, 22.52869034], [81.51467133, 22.53403091], [81.51541901, 22.53675079], [81.51906586, 22.53998184], [81.52797699, 22.53979111], [81.53595734, 22.53324127], [81.54222107, 22.52992058], [81.54720306, 22.53126144], [81.55693054, 22.53216171], [81.56278229, 22.53417969], [81.55731201, 22.53759003], [81.55741882, 22.54689026], [81.56305695, 22.55100822], [81.5697403, 22.55005074], [81.5831604, 22.54453087], [81.58795929, 22.54403114], [81.59274292, 22.53765106], [81.59976959, 22.53570938], [81.60896301, 22.5364399], [81.61579132, 22.53902054], [81.62188721, 22.54383087], [81.62136078, 22.5477829], [81.61942291, 22.55327988], [81.61940765, 22.55855942], [81.6235733, 22.56427765], [81.63250732, 22.56199837], [81.63791656, 22.5621109], [81.64565277, 22.56589127], [81.64868927, 22.56895065], [81.64942169, 22.57608032], [81.64441681, 22.58337975], [81.64012146, 22.58654976], [81.64163208, 22.59209061], [81.64138794, 22.60754013], [81.64353943, 22.61440086], [81.64840698, 22.6199894], [81.65479279, 22.62158966], [81.65654755, 22.63200188], [81.66316223, 22.63272095], [81.6785965, 22.64888], [81.68839264, 22.64663124], [81.6988678, 22.64588165], [81.70701599, 22.64964104], [81.71411133, 22.65563011], [81.71800232, 22.66373062], [81.71962738, 22.67002106], [81.72294617, 22.6762104], [81.73014069, 22.67327118], [81.73693848, 22.66905022], [81.73934937, 22.6613903], [81.74053955, 22.64806938], [81.74893188, 22.64607048], [81.76272583, 22.66358948], [81.76506042, 22.66905975], [81.76597595, 22.67612076], [81.76288605, 22.68535995], [81.7559433, 22.69765091], [81.74833679, 22.71953964], [81.74661255, 22.72648811], [81.74912262, 22.73316956], [81.76249695, 22.73530006], [81.76277924, 22.74151039], [81.76397705, 22.74677086], [81.77815247, 22.75803947], [81.78427887, 22.76662064], [81.78128052, 22.7747097], [81.77440643, 22.78560066], [81.77590179, 22.80013847], [81.77300262, 22.8091507], [81.76159668, 22.82933044], [81.76085663, 22.83433914], [81.7648468, 22.84069061], [81.76931763, 22.85116005], [81.77005005, 22.86042976], [81.76940155, 22.87350845], [81.78592682, 22.87708092], [81.79582977, 22.88025093], [81.82065582, 22.88286018], [81.82644653, 22.88227081], [81.83142853, 22.88297081], [81.83558655, 22.88647079], [81.85634613, 22.8908596], [81.86110687, 22.89394951], [81.86194611, 22.90460968], [81.86000824, 22.91500092], [81.87050629, 22.91184044], [81.8746109, 22.91332054], [81.88027954, 22.91986084], [81.88654327, 22.9251709], [81.89488983, 22.92817116], [81.90146637, 22.93305969], [81.90567017, 22.94046021], [81.91385651, 22.94822121], [81.92344666, 22.9511795], [81.92797852, 22.95420074], [81.93327332, 22.95476151], [81.94024658, 22.95709038], [81.94256592, 22.96453094], [81.94241333, 22.97526932], [81.94120789, 22.98494911], [81.93844604, 22.99165154], [81.9385376, 23.00081062], [81.93701172, 23.00329971], [81.93721771, 23.00949287], [81.93229675, 23.01742172], [81.92679596, 23.02238083], [81.92707062, 23.02603912], [81.92597198, 23.02854156], [81.91941833, 23.03668022], [81.91842651, 23.04097939], [81.92138672, 23.04746056], [81.92394257, 23.05829811], [81.92608643, 23.06221008], [81.93501282, 23.0668602], [81.93786621, 23.06960106], [81.93747711, 23.07658005], [81.93810272, 23.07781029], [81.95262909, 23.07645035], [81.96127319, 23.08018112], [81.96507263, 23.08037186], [81.96930695, 23.0793705], [81.97215271, 23.08140945], [81.9748764, 23.08176041], [81.97997284, 23.08554268], [81.98214722, 23.08624268], [81.98545837, 23.08613014], [81.99048615, 23.08467102], [81.99253845, 23.08489037], [81.99680328, 23.08032036], [82.00218964, 23.07840919], [82.0102005, 23.08061981], [82.01278687, 23.07929993], [82.01616669, 23.07933044], [82.024086, 23.08012009], [82.02825165, 23.08166122], [82.03952026, 23.09151077], [82.04567719, 23.09910965], [82.04767609, 23.10335922], [82.06137085, 23.11594009], [82.06713104, 23.11681747], [82.06912231, 23.11488914], [82.07189178, 23.11359978], [82.07550812, 23.11215019], [82.0791626, 23.1121006], [82.08590698, 23.10925293], [82.10164642, 23.10851097], [82.10951996, 23.10548973], [82.11588287, 23.10379982], [82.11936188, 23.10746956], [82.12825012, 23.11211014], [82.12924194, 23.11403084], [82.12961578, 23.12507057], [82.13098907, 23.12895012], [82.13276672, 23.13162041], [82.15107727, 23.1417408], [82.15406799, 23.15114021], [82.15376282, 23.158041], [82.15138245, 23.16055107], [82.14494324, 23.16314125], [82.1401062, 23.16372108], [82.13732147, 23.1649704], [82.13790131, 23.16833115], [82.14170837, 23.17473984], [82.14095306, 23.17848969], [82.1374588, 23.18020058], [82.13698578, 23.18279839], [82.13765717, 23.18812943], [82.1401825, 23.19034958], [82.14057159, 23.19807053], [82.14665985, 23.20944977], [82.14634705, 23.21384048], [82.14292908, 23.22237968], [82.14248657, 23.22770119], [82.14698792, 23.23191833], [82.15371704, 23.24596977], [82.15953064, 23.24915123], [82.1598587, 23.25291824], [82.16652679, 23.26140022], [82.1681366, 23.2674408], [82.16982269, 23.27017975], [82.17402649, 23.27248955], [82.18419647, 23.27526283], [82.18638611, 23.27765846], [82.18946075, 23.28458977], [82.1869812, 23.29023933], [82.1869812, 23.29499054], [82.188797, 23.29837036], [82.18990326, 23.30348969], [82.18884277, 23.30873108], [82.18998718, 23.31153107], [82.18750763, 23.32222939], [82.18585968, 23.32538986], [82.18428802, 23.32689095], [82.179039, 23.3270607], [82.16007996, 23.33218956], [82.15808105, 23.33332062], [82.15553284, 23.33548927], [82.15358734, 23.34249115], [82.15130615, 23.3455677], [82.1452179, 23.34921074], [82.14282227, 23.35440826], [82.13783264, 23.3618412], [82.13247681, 23.36217117], [82.12905121, 23.36103821], [82.11844635, 23.35448074], [82.11444855, 23.35403061], [82.11090088, 23.35584068], [82.10788727, 23.35847092], [82.10449982, 23.36317825], [82.10546112, 23.36928177], [82.1051712, 23.38282967], [82.10411835, 23.38682175], [82.10079193, 23.3907795], [82.09876251, 23.39469147], [82.09848022, 23.39770126], [82.09488678, 23.3985405], [82.08512878, 23.39331055], [82.08364868, 23.39677238], [82.07995605, 23.39719009], [82.06929779, 23.39502907], [82.06307983, 23.39246941], [82.05677032, 23.39353943], [82.05396271, 23.39048958], [82.052742, 23.38513947], [82.04923248, 23.37873077], [82.04573822, 23.37787056], [82.03707123, 23.37955093], [82.03285217, 23.38539124], [82.02941895, 23.38755035], [82.02561188, 23.38593292], [82.02323914, 23.38376045], [82.02039337, 23.38430023], [82.01451874, 23.38791847], [82.0136261, 23.39026833], [82.01428986, 23.39351082], [82.01719666, 23.39639091], [82.01992035, 23.4009304], [82.01751709, 23.40551949], [82.01735687, 23.40806007], [82.02324677, 23.41018295], [82.01841736, 23.42111969], [82.01597595, 23.4235096], [82.00977325, 23.42052841], [81.99952698, 23.41281128], [81.99545288, 23.41559982], [81.99191284, 23.41929245], [81.98739624, 23.41951942], [81.97886658, 23.41152954], [81.97612, 23.41311073], [81.97589111, 23.41557121], [81.97360992, 23.41759109], [81.97158813, 23.41973114], [81.97054291, 23.42387009], [81.97338104, 23.42628288], [81.9750824, 23.4318409], [81.97145844, 23.44164085], [81.97190857, 23.44520187], [81.9713974, 23.44746971], [81.96821594, 23.45036125], [81.96660614, 23.45372009], [81.96124268, 23.45979118], [81.95674133, 23.46336937], [81.95033264, 23.46606064], [81.94761658, 23.4716301], [81.94702911, 23.47548103], [81.94893646, 23.49674034], [81.94471741, 23.50014114], [81.93444824, 23.50555038], [81.92829895, 23.51324081], [81.92767334, 23.51754951], [81.91635895, 23.53209114], [81.91375732, 23.53375816], [81.9094162, 23.53502274], [81.90392303, 23.53508949], [81.89997101, 23.5341301], [81.89624786, 23.53194809], [81.88448334, 23.52248001], [81.87935638, 23.51843262], [81.86968994, 23.51457024], [81.86223602, 23.51387024], [81.85507202, 23.51645088], [81.85074615, 23.51646042], [81.83410645, 23.51216125], [81.82717896, 23.5112896], [81.81653595, 23.51486015], [81.81257629, 23.51762962], [81.81006622, 23.52260971], [81.81019592, 23.52634048], [81.81150818, 23.53067017], [81.81104279, 23.53392029], [81.80461884, 23.5458107], [81.80127716, 23.54776001], [81.79756165, 23.54883194], [81.76299286, 23.55076981], [81.7563858, 23.55252075], [81.75361633, 23.55856133], [81.75060272, 23.5630703], [81.74796295, 23.5653801], [81.7407074, 23.56764984], [81.73603058, 23.5674305], [81.72923279, 23.56509972], [81.72595215, 23.56245041], [81.72344208, 23.55882835], [81.71923065, 23.55605125], [81.71675873, 23.54834938], [81.7130661, 23.5426693], [81.71034241, 23.54124069], [81.70638275, 23.53358078], [81.69309235, 23.52334023], [81.68744659, 23.5244503], [81.68187714, 23.5272007], [81.66718292, 23.53190041], [81.66203308, 23.53243828], [81.65453339, 23.53155136], [81.65309906, 23.52769279], [81.65396118, 23.5199604], [81.6536026, 23.51389122], [81.64765167, 23.50242996], [81.64398956, 23.50012016], [81.63717651, 23.49930191], [81.63524628, 23.49835968], [81.63109589, 23.49174118], [81.62822723, 23.4903698], [81.62422943, 23.49105072], [81.61721802, 23.49486923], [81.61443329, 23.49776077], [81.60704803, 23.50688934], [81.60521698, 23.51088905], [81.60632324, 23.52067947], [81.60546875, 23.5247612], [81.60665131, 23.54496956], [81.60569763, 23.55048943], [81.60227203, 23.55367279], [81.58690643, 23.55451012], [81.58392334, 23.5539608], [81.57707214, 23.55488968], [81.57550812, 23.5587101], [81.57444763, 23.56668091], [81.57042694, 23.5798111], [81.56973267, 23.58864975], [81.57077026, 23.59091949], [81.57505798, 23.59202194], [81.58024597, 23.59679031], [81.59480286, 23.59547043], [81.59984589, 23.59692192], [81.60267639, 23.60003281], [81.60108948, 23.61394119], [81.60437775, 23.62137032], [81.60652161, 23.62445831], [81.60951233, 23.63298988], [81.6132431, 23.66098022], [81.61849213, 23.66138077], [81.63500977, 23.65896988], [81.64312744, 23.66033173], [81.64640808, 23.66320992], [81.64795685, 23.66799927], [81.64949799, 23.6834507], [81.67321014, 23.69343185], [81.68464661, 23.71364021], [81.68728638, 23.72134972], [81.68688965, 23.72262001], [81.68234253, 23.72561073], [81.67749786, 23.73460007], [81.67209625, 23.74002075], [81.6733017, 23.74336052], [81.67829132, 23.74887085], [81.67408752, 23.7539711], [81.66932678, 23.75735092], [81.66178131, 23.75991058], [81.65354919, 23.76427078], [81.64415741, 23.76807976], [81.63965607, 23.77112961], [81.63816833, 23.77478981], [81.6383667, 23.77787971], [81.64348602, 23.7918396], [81.64362335, 23.79889107], [81.64256287, 23.80458069], [81.63601685, 23.81635094], [81.63053894, 23.83081055], [81.62811279, 23.83432961], [81.62570953, 23.83582115], [81.62023163, 23.8368206], [81.60942078, 23.83579063], [81.60733032, 23.83624077], [81.60582733, 23.83820915], [81.60497284, 23.84139061], [81.60456085, 23.84383965], [81.59844208, 23.85367966], [81.59738922, 23.85746002], [81.59738922, 23.86194038], [81.5983429, 23.86421967], [81.60620117, 23.86395073], [81.61142731, 23.86702919], [81.61485291, 23.87277031], [81.60874939, 23.87817955], [81.60019684, 23.88339806], [81.59757996, 23.88624191], [81.59690857, 23.88902283], [81.60338593, 23.89240074], [81.60555267, 23.89585114], [81.60756683, 23.90327072], [81.61051178, 23.90697289], [81.61444855, 23.90827942], [81.62451172, 23.90691948], [81.62921906, 23.90765953], [81.63728333, 23.91362], [81.6414566, 23.91517067], [81.64811707, 23.91616058], [81.6516571, 23.91782951], [81.65740967, 23.92456818], [81.66159821, 23.92559814], [81.66491699, 23.92207909], [81.66771698, 23.91570091], [81.67733002, 23.91024017], [81.67949677, 23.90764809], [81.68239594, 23.88978958], [81.68692017, 23.8849411], [81.6973877, 23.88596153], [81.69966888, 23.88149071], [81.69845581, 23.87799072], [81.70297241, 23.87285042], [81.70228577, 23.86898994], [81.7026825, 23.86339951], [81.71253204, 23.86296272], [81.71495056, 23.86188126], [81.72091675, 23.86082268], [81.7230072, 23.85898018], [81.72384644, 23.85688972], [81.72389221, 23.85071754], [81.72141266, 23.8490715], [81.71835327, 23.84338951], [81.71906281, 23.84042931], [81.72685242, 23.84095955], [81.7305069, 23.83936119], [81.73443604, 23.83619118], [81.74518585, 23.83092117], [81.77262878, 23.81419945], [81.78266144, 23.81184006], [81.78748322, 23.8119297], [81.79341888, 23.8144207], [81.80058289, 23.81355095], [81.80564117, 23.81043816], [81.81172943, 23.80949974], [81.81741333, 23.81124115], [81.82411957, 23.81641006], [81.82863617, 23.8170929], [81.83164978, 23.82130241], [81.85293579, 23.82431984], [81.85765839, 23.82876968], [81.86207581, 23.83481026], [81.87843323, 23.83790016], [81.88535309, 23.84173965], [81.89409637, 23.8440609], [81.89807129, 23.84828949], [81.90077972, 23.85122108], [81.90425873, 23.85852051], [81.90983582, 23.8640995], [81.91470337, 23.87187958], [81.91644287, 23.87298965], [81.93164825, 23.86791039], [81.93289948, 23.86675072], [81.93228149, 23.86261177], [81.93390656, 23.86193275], [81.93685913, 23.86206245], [81.93856049, 23.86096954], [81.94004822, 23.85777092], [81.94490051, 23.85692978], [81.95070648, 23.85289001], [81.96238708, 23.85707855], [81.97154999, 23.85835075], [81.98394012, 23.86199951], [81.99214935, 23.86264038], [82.00073242, 23.86314011], [82.00567627, 23.85880089], [82.00759888, 23.85495186], [82.01161194, 23.85227966], [82.02849579, 23.84770012], [82.03251648, 23.84507942], [82.03515625, 23.84255981], [82.03433228, 23.83867073], [82.03100586, 23.83189964], [82.03217316, 23.82930946], [82.04052734, 23.82632828], [82.04234314, 23.82496071], [82.04540253, 23.82058907], [82.06328583, 23.81911087], [82.07202148, 23.81978035], [82.07801819, 23.8170681], [82.08911133, 23.81789017], [82.10018158, 23.82010078], [82.10678864, 23.81849098], [82.10875702, 23.81868172], [82.11746216, 23.82312012], [82.12576294, 23.81966972], [82.13407898, 23.81816101], [82.14456177, 23.81925011], [82.15573883, 23.82197762], [82.16240692, 23.81995964], [82.16525269, 23.82075119], [82.1682663, 23.82269287], [82.16971588, 23.82467842], [82.17249298, 23.8379097], [82.17352295, 23.83909035], [82.17875671, 23.84204292], [82.18933868, 23.84370995], [82.19557953, 23.85038185], [82.20388794, 23.8529911], [82.20687103, 23.84404182], [82.20664978, 23.84103012], [82.20435333, 23.83712006], [82.20096588, 23.83453941], [82.1992569, 23.83192062], [82.20136261, 23.82829285], [82.21160126, 23.82393265], [82.21611023, 23.82096291], [82.22107697, 23.8100605], [82.22614288, 23.80693245], [82.22899628, 23.80667114], [82.23152924, 23.80779076], [82.24855042, 23.81979942], [82.25528717, 23.82188988], [82.26476288, 23.81874084], [82.27121735, 23.81869125], [82.27767181, 23.81713104], [82.28382874, 23.81290054], [82.29511261, 23.80854988], [82.29759216, 23.80816078], [82.30432129, 23.80986023], [82.30715942, 23.81116295], [82.31112671, 23.81118965], [82.31505585, 23.81030846], [82.32096863, 23.80874062], [82.32823181, 23.80367088], [82.33125305, 23.80536079], [82.33854675, 23.8060112], [82.3429184, 23.80389977], [82.34703064, 23.80371094], [82.35658264, 23.80833054], [82.36834717, 23.81110001], [82.37985229, 23.80704117], [82.3839798, 23.80487061], [82.38822937, 23.80137062], [82.39335632, 23.80241013], [82.40296936, 23.80277824], [82.42323303, 23.80608749], [82.43644714, 23.80470848], [82.44023895, 23.80572128], [82.44576263, 23.81085968], [82.44904327, 23.81165123], [82.46002197, 23.81139946], [82.46350861, 23.81084824], [82.46987915, 23.80764961], [82.4826889, 23.79751968], [82.48375702, 23.79057121], [82.4850769, 23.78837967], [82.49175262, 23.78570747], [82.4966507, 23.78504944], [82.50670624, 23.7854805], [82.5161972, 23.78423119], [82.52879333, 23.79134941], [82.53578949, 23.79210091], [82.54026794, 23.79120064], [82.54451752, 23.79418945], [82.54477692, 23.79831123], [82.54399109, 23.80282021], [82.54086304, 23.81015015], [82.53975677, 23.81182861], [82.53690338, 23.81249046], [82.53399658, 23.81479836], [82.53196716, 23.81982994], [82.52910614, 23.82159996], [82.52735138, 23.82407951], [82.53366089, 23.82499123], [82.53874969, 23.82410812], [82.54207611, 23.82674026], [82.54821777, 23.82690048], [82.56115723, 23.82278061], [82.56633759, 23.82472992], [82.57849121, 23.8224411], [82.58598328, 23.82286072], [82.58963776, 23.82479095], [82.60051727, 23.83391953], [82.60591125, 23.83616257], [82.6295166, 23.8390007], [82.63130188, 23.84168243], [82.6312561, 23.84633064], [82.63482666, 23.84767914], [82.63772583, 23.84988976], [82.64064026, 23.85803032], [82.64354706, 23.85962105], [82.64541626, 23.85782051], [82.65202332, 23.85650063], [82.65335846, 23.85778046], [82.65492249, 23.86271095], [82.65795898, 23.86558151], [82.66020966, 23.87033844], [82.65953064, 23.87458038], [82.65727234, 23.87815094], [82.64611816, 23.88873291], [82.64730072, 23.89499092], [82.65473938, 23.90629005], [82.65651703, 23.90786171], [82.65905762, 23.90863991], [82.66290283, 23.90867043], [82.66812134, 23.9076004], [82.67090607, 23.90977097], [82.67708588, 23.90982056], [82.68186188, 23.91226959], [82.68733978, 23.91777039], [82.68900299, 23.91953087], [82.68987274, 23.92042923], [82.70192719, 23.92493248], [82.70667267, 23.92461967], [82.71811676, 23.92144966], [82.74333191, 23.92064095], [82.74810028, 23.92228127], [82.75006866, 23.92653275], [82.75019836, 23.93005943], [82.75377655, 23.93588066], [82.77484894, 23.93857002], [82.7902832, 23.95061111], [82.79210663, 23.95570946], [82.79680634, 23.96142006], [82.79865265, 23.96218109], [82.8077774, 23.96305847], [82.82071686, 23.9649601], [82.84133911, 23.95014954], [82.84889984, 23.94683266], [82.85515594, 23.93877983], [82.86296082, 23.92552948], [82.86569214, 23.92266273], [82.87529755, 23.91641045], [82.88118744, 23.91028023], [82.89034271, 23.90456009], [82.90608215, 23.89789963], [82.91747284, 23.895401], [82.92251587, 23.89269066], [82.9251709, 23.89071083], [82.93058777, 23.88196945], [82.93308258, 23.87940025], [82.93881989, 23.87586975], [82.94950104, 23.87298965], [82.95359039, 23.87277031], [82.98396301, 23.87955284], [82.99227905, 23.87850952], [83.02052307, 23.88269806], [83.02546692, 23.88162994], [83.03643799, 23.88305092], [83.04345703, 23.87939072], [83.06104279, 23.87524033], [83.08660126, 23.87817192], [83.12741089, 23.89002037], [83.13437653, 23.89455032], [83.13526154, 23.8985405], [83.13878632, 23.90437126], [83.1452179, 23.90994263], [83.15557098, 23.91130829], [83.15785217, 23.91303062], [83.16433716, 23.91510963], [83.1678772, 23.91786957], [83.17260742, 23.91765976], [83.17756653, 23.91951942], [83.18312836, 23.91948128], [83.18956757, 23.92110062], [83.19313049, 23.92690086], [83.19135284, 23.93263054], [83.20176697, 23.94054031], [83.20323181, 23.94753265], [83.20587158, 23.95379066], [83.21121216, 23.96035767], [83.21063995, 23.96541023], [83.20835114, 23.9727993], [83.21057129, 23.97725105], [83.21562958, 23.98077965], [83.21476746, 23.9862709], [83.21602631, 23.98940277], [83.22252655, 23.99205971], [83.22677612, 23.99631119], [83.23352051, 23.99831009], [83.23692322, 24.00139046], [83.23535919, 24.00715065], [83.23697662, 24.00995827], [83.24182129, 24.013731], [83.24703217, 24.01519966], [83.25306702, 24.01213074], [83.25894928, 24.0116291], [83.26239777, 24.01366043], [83.26574707, 24.01725006], [83.27052307, 24.02026939], [83.2738266, 24.02115059], [83.27607727, 24.0232811], [83.27646637, 24.02730942], [83.279953, 24.03476906], [83.27680206, 24.04566956], [83.27748871, 24.04995918], [83.28040314, 24.05507088], [83.28417206, 24.06464958], [83.28900909, 24.07290077], [83.29242706, 24.07720947], [83.3110733, 24.09276009], [83.31344604, 24.09742928], [83.31352234, 24.10140038], [83.31491089, 24.10698128], [83.31894684, 24.10645103], [83.32356262, 24.1013298], [83.32759857, 24.09964943], [83.3457489, 24.09707069], [83.35723114, 24.10169029], [83.36197662, 24.10196114], [83.38326263, 24.09987068], [83.39240265, 24.09495163], [83.4006958, 24.08177948], [83.40309143, 24.08077812], [83.40895081, 24.08047104], [83.41467285, 24.08121109], [83.42137909, 24.08378029], [83.42536926, 24.08376122], [83.42858887, 24.07977295], [83.43013, 24.07401085], [83.43061066, 24.06904984], [83.42920685, 24.06202126], [83.43132019, 24.0579319], [83.4332428, 24.05470085], [83.44758606, 24.04248047], [83.45307922, 24.04142189], [83.45813751, 24.04191971], [83.46840668, 24.04067039], [83.4789505, 24.03854942], [83.50122833, 24.03068924], [83.50670624, 24.0282402], [83.5096283, 24.02540016], [83.51483154, 24.01576042], [83.51655579, 24.01062012], [83.50750732, 24.00139046], [83.50654602, 23.99134064], [83.50772095, 23.97945976], [83.51243591, 23.96699905], [83.5226059, 23.95216942], [83.53373718, 23.94174004], [83.53894043, 23.93350029], [83.537323, 23.91463089], [83.54284668, 23.89824104], [83.54936981, 23.89283943], [83.56050873, 23.89265823], [83.57015228, 23.89035988], [83.57615662, 23.88438034], [83.57302856, 23.87706947], [83.56369781, 23.87306023], [83.55760956, 23.86952972], [83.56121063, 23.86295128], [83.57177734, 23.86306], [83.58116913, 23.8619194], [83.59044647, 23.85649109], [83.60057068, 23.85347748], [83.61148834, 23.85336113], [83.62998962, 23.84736061], [83.63790131, 23.84703064], [83.64955139, 23.84806061], [83.65624237, 23.84364128], [83.65759277, 23.83697128], [83.65528107, 23.83201027], [83.65833282, 23.82781982], [83.66649628, 23.8259182], [83.67220306, 23.8200798], [83.67772675, 23.82266808], [83.68200684, 23.82580185], [83.68849182, 23.82393265], [83.69538879, 23.82066917], [83.69859314, 23.81646156], [83.69558716, 23.80759811], [83.69989777, 23.80163002], [83.70775604, 23.79495049], [83.71080017, 23.7895298], [83.71250153, 23.78083992], [83.71235657, 23.77233124], [83.72709656, 23.75990105], [83.72940063, 23.75473022], [83.73000336, 23.74368095], [83.72934723, 23.7318306], [83.73246002, 23.72398949], [83.73471832, 23.71355057], [83.73213959, 23.70466995], [83.72431183, 23.69678116], [83.72257996, 23.69413948], [83.71507263, 23.69024086], [83.71472931, 23.68254089], [83.72132874, 23.67374039], [83.72891235, 23.66740036], [83.74404144, 23.65913963], [83.75094604, 23.65332985], [83.75208282, 23.64898109], [83.74462128, 23.64565086], [83.74302673, 23.64046097], [83.74778748, 23.62664986], [83.76493835, 23.62148094], [83.76573944, 23.61754036], [83.76776886, 23.60908127], [83.77488708, 23.59950066], [83.78614807, 23.59818077], [83.79772186, 23.5900898], [83.80047607, 23.58317947], [83.80634308, 23.58230972], [83.81088257, 23.58885956], [83.8212204, 23.58485031], [83.83763123, 23.58135986], [83.84616089, 23.58092117], [83.85959625, 23.5783329], [83.88292694, 23.57277107], [83.89009094, 23.5759201], [83.89849091, 23.57116127], [83.9052887, 23.56950951], [83.91467285, 23.56874084], [83.92249298, 23.56504822], [83.93525696, 23.56303978], [83.92958832, 23.59367943], [83.93152618, 23.6114006], [83.9378891, 23.6224308], [83.94861603, 23.62431908], [83.962677, 23.62618828], [83.97545624, 23.63083076], [83.99267578, 23.63305283], [84.00702667, 23.63231087], [84.00771332, 23.62852097], [84.0036087, 23.62631989], [84.00177765, 23.62290955], [84.0018692, 23.62043953], [84.01257324, 23.60548019], [84.02030182, 23.60017967], [84.02233887, 23.59736061], [84.02194214, 23.59221077], [84.02411652, 23.58788109], [84.02291107, 23.57459068], [84.02511597, 23.56579018], [84.02128601, 23.54992867], [84.02266693, 23.54424095], [84.01539612, 23.52563286], [84.01274872, 23.52081108], [84.01228333, 23.5081501], [84.00875854, 23.49958038], [84.00563812, 23.49646187], [83.99724579, 23.49311066], [83.99272156, 23.4851799], [83.98889923, 23.48178101], [83.98462677, 23.47559166], [83.97914886, 23.46058083], [83.9695282, 23.4554081], [83.96972656, 23.44766808], [83.97775269, 23.4314518], [83.97944641, 23.42669106], [83.97815704, 23.42093086], [83.97805786, 23.4141407], [83.97616577, 23.40752029], [83.96778107, 23.39299011], [83.96582794, 23.38121033], [83.96688843, 23.37422943], [83.97025299, 23.36939812], [83.97486115, 23.36479187], [83.98301697, 23.35955048], [83.99276733, 23.35588264], [84.00653076, 23.35280037], [84.01145172, 23.36339951], [84.01715088, 23.37158966], [84.02073669, 23.37545967], [84.02648163, 23.37692833], [84.03803253, 23.3761692], [84.04338837, 23.37401009], [84.04722595, 23.37121964], [84.04345703, 23.36972046], [84.04444885, 23.36712074], [84.04734039, 23.36365128], [84.04860687, 23.35416031], [84.04995728, 23.35186005], [84.06051636, 23.3431797], [84.06797028, 23.33409119], [84.07025146, 23.32999039], [84.05995178, 23.30820084], [84.05938721, 23.30430031], [84.06381989, 23.29224014], [84.06304169, 23.28964043], [84.06005859, 23.28628922], [84.05906677, 23.28232002], [84.05906677, 23.27412033], [84.05126953, 23.2466011], [84.05045319, 23.24094963], [84.05400848, 23.23418045], [84.05223846, 23.2212429], [84.05236816, 23.21643066], [84.0535965, 23.21317101], [84.05802917, 23.20800018], [84.05834961, 23.20359993], [84.05612183, 23.19640923], [84.05090332, 23.18958092], [84.04399109, 23.18460083], [84.03932953, 23.1785183], [84.03380585, 23.16784096], [84.03112793, 23.16113281], [84.02909088, 23.15388107], [84.03026581, 23.14936829], [84.03336334, 23.14273071], [84.03367615, 23.13844109], [84.03595734, 23.13495064], [84.03997803, 23.1321106], [84.04527283, 23.13052177], [84.0528717, 23.12446976], [84.05560303, 23.12070084], [84.05893707, 23.11259079], [84.0614624, 23.10989952], [84.06671143, 23.10711288], [84.07646179, 23.10984993], [84.08786774, 23.10948944], [84.09736633, 23.10482025], [84.10492706, 23.09922028], [84.11026001, 23.09208107], [84.11244965, 23.08718109], [84.11618805, 23.08613968], [84.12647247, 23.08514977], [84.12937927, 23.08154106], [84.13092041, 23.07748985], [84.13170624, 23.0674305], [84.13076782, 23.06336021], [84.12587738, 23.05688286], [84.12483215, 23.05347824], [84.12335968, 23.04499245], [84.12367249, 23.03661919], [84.1246109, 23.03074837], [84.12664795, 23.02601051], [84.13169861, 23.01826286], [84.13733673, 23.00626945], [84.13835907, 22.99848938], [84.14421082, 22.9881897], [84.14511108, 22.98257065], [84.14356995, 22.97511101], [84.14800262, 22.96386909], [84.15458679, 22.96437263], [84.16786194, 22.97096062], [84.1713562, 22.97707939], [84.17059326, 22.98518944], [84.16860199, 22.99500084], [84.17314911, 22.99875069], [84.17397308, 23.00035095], [84.17259979, 23.00720024], [84.17537689, 23.01190186], [84.17668152, 23.02051926], [84.17904663, 23.02256012], [84.18992615, 23.02371979], [84.19824982, 23.01898956], [84.19993591, 23.01511955], [84.1967926, 23.00410271], [84.20107269, 22.99882126], [84.21202087, 22.98638916], [84.21494293, 22.97743034], [84.21705627, 22.97647285], [84.22680664, 22.98007011], [84.2374115, 22.98040009], [84.24150848, 22.97287941], [84.2509079, 22.97142982], [84.25461578, 22.97369957], [84.2620697, 22.9800415], [84.26789093, 22.98791122], [84.27140045, 22.98884964], [84.27111053, 22.98415947], [84.26888275, 22.97903061], [84.27192688, 22.97093964], [84.27857208, 22.9612484], [84.28933716, 22.9616394], [84.3067627, 22.96751022], [84.31449127, 22.97223091], [84.3182373, 22.97657967], [84.32515717, 22.97933006], [84.33181, 22.97913933], [84.34361267, 22.97372055], [84.34823608, 22.97587013], [84.36149597, 22.97455025], [84.3705368, 22.97507095], [84.3733902, 22.97214127], [84.37638092, 22.96630287], [84.37773132, 22.96171951], [84.37779236, 22.95191765], [84.37922668, 22.94890022], [84.38195038, 22.94573021], [84.38645935, 22.94238091], [84.38905334, 22.93873978], [84.38964844, 22.92374039], [84.38629913, 22.9168396], [84.37619019, 22.90920067], [84.37085724, 22.90160942], [84.37278748, 22.8984108], [84.37670898, 22.89772987], [84.37825775, 22.8931427], [84.37818909, 22.88786125], [84.37587738, 22.88140106], [84.37692261, 22.87589073], [84.3759613, 22.87363815], [84.37145996, 22.87212944], [84.36995697, 22.86890984], [84.36988831, 22.86450005], [84.35793304, 22.86059952], [84.34789276, 22.86316109], [84.34217834, 22.85917091], [84.33835602, 22.85904121], [84.33500671, 22.86024094], [84.32946014, 22.85955048], [84.3203125, 22.84942055], [84.31839752, 22.84375191], [84.31858826, 22.83513069], [84.32038116, 22.83603096], [84.31770325, 22.81718063], [84.31252289, 22.81035042], [84.31169128, 22.80330086], [84.30996704, 22.79898262], [84.3034668, 22.79846954], [84.30181885, 22.79507065], [84.29627991, 22.79363823], [84.29030609, 22.78716278], [84.28710938, 22.77671051], [84.28768921, 22.77090073], [84.28528595, 22.76337051], [84.28144836, 22.76011086], [84.27877808, 22.76136017], [84.27403259, 22.76559067], [84.26010132, 22.76494026], [84.25422668, 22.76297951], [84.25370789, 22.76072121], [84.25158691, 22.75807953], [84.2416687, 22.74835014], [84.2297287, 22.74015045], [84.22535706, 22.73516083], [84.22471619, 22.72735023], [84.22763062, 22.72315025], [84.22944641, 22.70523262], [84.22769165, 22.6979599], [84.23223877, 22.68857956], [84.22775269, 22.67699051], [84.22061157, 22.66891098], [84.21479034, 22.66456032], [84.20967102, 22.6629982], [84.20717621, 22.66506004], [84.20160675, 22.66518974], [84.1969986, 22.66378021], [84.19161987, 22.66025162], [84.18035126, 22.6498394], [84.16483307, 22.64532089], [84.15743256, 22.64093971], [84.14993286, 22.63442039], [84.13210297, 22.63578033], [84.11531067, 22.63525963], [84.1072464, 22.63667107], [84.09764099, 22.63301086], [84.09395599, 22.63264084], [84.08039093, 22.6365509], [84.05930328, 22.6074028], [84.05287933, 22.60260963], [84.04812622, 22.59414291], [84.04193115, 22.59218025], [84.03359222, 22.59127045], [84.02134705, 22.58723259], [84.02002716, 22.58279037], [84.01777649, 22.5789299], [84.01103973, 22.57500267], [84.00505066, 22.56956291], [84.00392914, 22.56192017], [84.00417328, 22.55486107], [84.00212097, 22.54659843], [83.99944305, 22.53950119], [84.00157928, 22.53399086], [84.00489807, 22.53013039], [84.00518036, 22.52473068], [84.00250244, 22.52086067], [83.99429321, 22.5288105], [83.99298096, 22.52737808], [83.98584747, 22.52548027], [83.98010254, 22.52201271], [83.97657013, 22.51839066], [83.97445679, 22.51398087], [83.97384644, 22.50913811], [83.97609711, 22.50221062], [83.98069, 22.49873161], [83.990448, 22.49439049], [83.99298096, 22.49398041], [83.99707794, 22.4907608], [84.01302338, 22.48524094], [84.01548767, 22.48242188], [84.02168274, 22.47205925], [84.0238266, 22.47071075], [84.03465271, 22.46989822], [84.03872681, 22.46888161], [84.04155731, 22.46410942], [84.03951263, 22.44872284], [84.04139709, 22.43792915], [84.04000854, 22.43289948], [84.03270721, 22.42603111], [84.02398682, 22.42218018], [84.02599335, 22.41909027], [84.02216339, 22.41016006], [84.01875305, 22.40678024], [84.01444244, 22.40409279], [84.01248932, 22.39889908], [84.00994873, 22.39608955], [84.00898743, 22.39139938], [84.00166321, 22.38036919], [84.00167847, 22.37585068], [84.00421143, 22.36766052], [84.00119019, 22.36967087], [83.99739838, 22.36853981], [83.99297333, 22.36923981], [83.98536682, 22.36637115], [83.97820282, 22.36510849], [83.96698761, 22.35784912], [83.95661163, 22.3610611], [83.95231628, 22.36120987], [83.9432373, 22.35845947], [83.92958069, 22.35628128], [83.92402649, 22.35749054], [83.91929626, 22.35978127], [83.9155426, 22.35967064], [83.9053421, 22.35261154], [83.89697266, 22.33968925], [83.87194824, 22.33893013], [83.86714935, 22.34102058], [83.86414337, 22.34361839], [83.86100769, 22.34378052], [83.85330963, 22.33880043], [83.84757996, 22.33083916], [83.84303284, 22.32634926], [83.82940674, 22.32394028], [83.82520294, 22.31962967], [83.82248688, 22.31563759], [83.82065582, 22.31025124], [83.82010651, 22.30508232], [83.82080841, 22.29603958], [83.81944275, 22.29245186], [83.81598663, 22.29120255], [83.80478668, 22.28988075], [83.79798889, 22.28996277], [83.79751587, 22.28948975], [83.79364777, 22.28769112], [83.79078674, 22.28464127], [83.78862762, 22.28025055], [83.77855682, 22.27450943], [83.77471924, 22.26733971], [83.77131653, 22.25733948], [83.76583862, 22.25601959], [83.76180267, 22.25415039], [83.7568512, 22.25037956], [83.75279999, 22.24286079], [83.74565125, 22.24122047], [83.71898651, 22.2432518], [83.70043182, 22.24588013], [83.69300079, 22.24550056], [83.67904663, 22.2406311], [83.67273712, 22.2374382], [83.66461945, 22.2319603], [83.65744019, 22.22479057], [83.65457153, 22.2238903], [83.64575195, 22.22458839], [83.62628174, 22.20585823], [83.61927032, 22.19635963], [83.61183929, 22.17714119], [83.60594177, 22.15760994], [83.60233307, 22.1518383], [83.59253693, 22.13998032], [83.56730652, 22.1137085], [83.56575775, 22.11285019], [83.55916595, 22.10386086], [83.55726624, 22.0999794], [83.55892181, 22.0954895], [83.56482697, 22.09397125], [83.57369995, 22.08880043], [83.58306885, 22.08049011], [83.58917999, 22.07635117], [83.60031891, 22.0655098], [83.59056854, 22.05934143], [83.58595276, 22.0555706], [83.58351135, 22.05495071], [83.56562805, 22.0567894], [83.55095673, 22.05564117], [83.5430069, 22.05939102], [83.53836823, 22.05537987], [83.53414917, 22.04343987], [83.53244781, 22.03404808], [83.5326767, 22.02863121], [83.53399658, 22.02227974], [83.53885651, 22.01437187], [83.5485611, 22.00670242], [83.54673767, 22.00335121], [83.54496765, 21.99938965], [83.54663849, 21.99827957], [83.543396, 21.99436951], [83.54083252, 21.99323273], [83.54010773, 21.98533058], [83.53544617, 21.9796505], [83.53447723, 21.97624969], [83.53517151, 21.96350098], [83.54949188, 21.95038986], [83.55771637, 21.9439106], [83.55397034, 21.9362812], [83.55335999, 21.9321804], [83.58776855, 21.92612076], [83.60047913, 21.91084099], [83.59931183, 21.90600014], [83.59263611, 21.90075111], [83.58325195, 21.89856911], [83.58151245, 21.89743042], [83.58319855, 21.89406967], [83.58333588, 21.89096069], [83.57988739, 21.88925171], [83.57670593, 21.8861599], [83.57810974, 21.87978935], [83.57330322, 21.87636948], [83.57151794, 21.87187004], [83.58405304, 21.85279274], [83.5859375, 21.84762955], [83.58447266, 21.84360123], [83.57948303, 21.83712006], [83.57489777, 21.83260155], [83.5735321, 21.82966042], [83.56453705, 21.83036995], [83.55745697, 21.83440971], [83.54853821, 21.83523178], [83.54094696, 21.83465958], [83.53124237, 21.83189964], [83.52765656, 21.82299042], [83.53639984, 21.81834984], [83.53478241, 21.80681992], [83.53866577, 21.80061913], [83.5357666, 21.79896164], [83.53656769, 21.79393005], [83.52218628, 21.79411125], [83.51412201, 21.79780006], [83.50614166, 21.80039978], [83.49771881, 21.80618095], [83.49091339, 21.81454086], [83.49133301, 21.80866051], [83.48545837, 21.80322075], [83.48404694, 21.79434013], [83.47429657, 21.78614998], [83.46717834, 21.78273964], [83.47592163, 21.77379036], [83.47789001, 21.76459122], [83.47902679, 21.75869942], [83.47541809, 21.75341034], [83.47390747, 21.7496109], [83.47733307, 21.74588966], [83.48413086, 21.74155235], [83.47986603, 21.7341404], [83.47801971, 21.7279911], [83.46692657, 21.71056938], [83.46160889, 21.70627975], [83.45762634, 21.69967079], [83.45633698, 21.69432068], [83.44970703, 21.69095993], [83.4407959, 21.69338989], [83.43183136, 21.6939106], [83.42796326, 21.69232941], [83.42488098, 21.68901062], [83.42111206, 21.68654823], [83.4197464, 21.67502022], [83.4286499, 21.66889], [83.43535614, 21.66312027], [83.44077301, 21.65517044], [83.46621704, 21.64412117], [83.47477722, 21.64121819], [83.483078, 21.63960075], [83.4833374, 21.6371727], [83.48647308, 21.63317108], [83.48454285, 21.62556267], [83.4765625, 21.62729263], [83.46990204, 21.62677002], [83.46296692, 21.60551071], [83.45275879, 21.60519028], [83.45279694, 21.60732269], [83.44872284, 21.60822105], [83.45001221, 21.61339951], [83.44993591, 21.6169796], [83.44133759, 21.61809158], [83.44142151, 21.62502289], [83.44048309, 21.62669945], [83.44139099, 21.63246155], [83.44757843, 21.64459991], [83.44123077, 21.64927292], [83.42650604, 21.64353943], [83.42405701, 21.63848114], [83.41352844, 21.63631058], [83.40862274, 21.63420105], [83.40518951, 21.63181114], [83.40180969, 21.62675095], [83.39524078, 21.62419128], [83.38981628, 21.62054062], [83.38683319, 21.61536026], [83.38072205, 21.61275101], [83.37725067, 21.60467911], [83.36818695, 21.59707069], [83.36232758, 21.57252121], [83.3633194, 21.56777954], [83.36686707, 21.55931282], [83.36692047, 21.55302048], [83.36577606, 21.54968071], [83.35426331, 21.53531837], [83.34896851, 21.51596069], [83.3458786, 21.50823975], [83.3377533, 21.50263023], [83.33589935, 21.49963951], [83.33463287, 21.49555016], [83.33561707, 21.49191093], [83.34205627, 21.48533058], [83.34197998, 21.47413063], [83.34335327, 21.46488953], [83.34732819, 21.45514107], [83.35028839, 21.44398117], [83.36094666, 21.44218063], [83.36579132, 21.43984032], [83.37014008, 21.43610001], [83.37137604, 21.42835999], [83.37393951, 21.42222023], [83.38140869, 21.40957832], [83.38967133, 21.40166283], [83.39376068, 21.39944267], [83.39308929, 21.38321114], [83.39655304, 21.37227058], [83.3963089, 21.36927032], [83.39317322, 21.36519051], [83.39415741, 21.3611412], [83.4018631, 21.3583107], [83.40444946, 21.35511971], [83.40265656, 21.34843063], [83.39385986, 21.34208107], [83.3879776, 21.33893967], [83.37663269, 21.34329987], [83.37481689, 21.3399601], [83.33460236, 21.35579109], [83.31933594, 21.35814285], [83.3095932, 21.36456108], [83.30164337, 21.36783981], [83.2872467, 21.3714695], [83.2813797, 21.37514114], [83.27614594, 21.37592125], [83.27001953, 21.37503815], [83.26951599, 21.36721039], [83.27078247, 21.35923958], [83.26609039, 21.34543037], [83.26064301, 21.33717918], [83.25495911, 21.33192062], [83.25578308, 21.32932281], [83.26085663, 21.32674026], [83.25421143, 21.31958961], [83.25409698, 21.31237984], [83.25879669, 21.30212975], [83.27268219, 21.29613113], [83.27480316, 21.29057121], [83.27455902, 21.28567123], [83.2713089, 21.28050041], [83.26767731, 21.26857758], [83.26275635, 21.27260971], [83.25730133, 21.27555084], [83.24836731, 21.27730179], [83.2424469, 21.27643967], [83.23187256, 21.26534081], [83.22489929, 21.26696968], [83.21835327, 21.26012039], [83.21414185, 21.25086975], [83.21469879, 21.24041939], [83.21906281, 21.22371101], [83.21520996, 21.22369194], [83.21438599, 21.22058105], [83.21536255, 21.21549034], [83.20757294, 21.20139122], [83.21121216, 21.19118118], [83.2100296, 21.1880703], [83.20520782, 21.18404007], [83.20201874, 21.17743111], [83.19953156, 21.17404938], [83.20007324, 21.16889954], [83.1993866, 21.16197014], [83.19373322, 21.1576519], [83.19274902, 21.13944054], [83.19010162, 21.13552856], [83.18297577, 21.13204956], [83.17662048, 21.13074112], [83.16986847, 21.13151932], [83.16139221, 21.13145065], [83.15339661, 21.12577057], [83.14875031, 21.11987114], [83.13771057, 21.1098175], [83.13400269, 21.10523033], [83.11984253, 21.10106087], [83.10827637, 21.10770035], [83.0951767, 21.1043129], [83.09208679, 21.10597038], [83.08870697, 21.10745049], [83.08156586, 21.1067009], [83.07144165, 21.10807037], [83.06436157, 21.11110115], [83.05976105, 21.11591148], [83.05139923, 21.11717033], [83.04682922, 21.12021065], [83.04058075, 21.11893082], [83.03643036, 21.1212101], [83.03275299, 21.12436295], [83.02908325, 21.12602997], [83.02954102, 21.13132286], [83.01862335, 21.13817978], [83.01589203, 21.13972092], [83.01048279, 21.14537048], [83.00772858, 21.14653015], [83.00554657, 21.14583015], [82.99912262, 21.14813995], [82.99297333, 21.15427971], [82.98342133, 21.14826965], [82.97992706, 21.15746117], [82.97161102, 21.15631104], [82.96514893, 21.15575981], [82.96363831, 21.16167068], [82.95964813, 21.17385101], [82.95606995, 21.17548943], [82.9489975, 21.16977119], [82.94232941, 21.16304016], [82.93739319, 21.16114807], [82.9280014, 21.16103172], [82.92192841, 21.15821075], [82.91442108, 21.16064072], [82.90795898, 21.1602726], [82.90231323, 21.16296959], [82.8951416, 21.15982056], [82.88741302, 21.15377235], [82.87922668, 21.14908981], [82.87285614, 21.1510582], [82.86882782, 21.15974998], [82.86367035, 21.15538025], [82.85949707, 21.15730286], [82.85402679, 21.15700912], [82.84677124, 21.1581707], [82.84712982, 21.16268158], [82.83999634, 21.1633606], [82.81247711, 21.1585598], [82.80684662, 21.15664101], [82.80381012, 21.15307045], [82.79559326, 21.1505909], [82.79176331, 21.14511108], [82.78884888, 21.13927269], [82.78208923, 21.14101982], [82.75752258, 21.1585598], [82.75229645, 21.15974045], [82.73535156, 21.15787125], [82.72724152, 21.15919113], [82.72115326, 21.15894127], [82.7114563, 21.15576935], [82.70553589, 21.15489006], [82.70053864, 21.15326118], [82.69403839, 21.15280151], [82.6919632, 21.15685081], [82.68453217, 21.15806007], [82.66204834, 21.15075111], [82.64582825, 21.15171051], [82.63594055, 21.1494503], [82.63279724, 21.14266014], [82.63408661, 21.13635063], [82.6383667, 21.13161278], [82.6446228, 21.12881088], [82.64775848, 21.12496185], [82.64531708, 21.12066841], [82.63955688, 21.11700058], [82.63710022, 21.11161995], [82.63833618, 21.10647011], [82.64502716, 21.10187912], [82.64299774, 21.09776115], [82.63536072, 21.09198952], [82.63183594, 21.08695984], [82.62587738, 21.07682037], [82.62194061, 21.07520103], [82.61524963, 21.07517052], [82.60938263, 21.07119751], [82.60912323, 21.06392097], [82.62003326, 21.04439926], [82.62230682, 21.0365696], [82.60861969, 21.01819992], [82.60772705, 21.01216125], [82.60444641, 21.00587273], [82.59514618, 20.99712944], [82.58207703, 20.98677826], [82.57813263, 20.97894096], [82.56651306, 20.96700096], [82.55294037, 20.94148064], [82.54573822, 20.93494034], [82.53585052, 20.92952156], [82.52625275, 20.92770958], [82.51924133, 20.92469025], [82.51344299, 20.91721916], [82.50309753, 20.91389084], [82.49363708, 20.90934944], [82.485672, 20.90351105], [82.48313904, 20.8996582], [82.48467255, 20.87955093], [82.48452759, 20.87289047], [82.48136902, 20.86145973], [82.48192596, 20.85531044], [82.47762299, 20.84671974], [82.46826172, 20.84263039], [82.46338654, 20.83967018], [82.45983124, 20.83564949], [82.46231079, 20.83035088], [82.46246338, 20.8275795], [82.45905304, 20.82384109], [82.45350647, 20.8212204], [82.44837189, 20.82217979], [82.44465637, 20.82406998], [82.44108582, 20.82376289], [82.43939209, 20.8271904], [82.43650055, 20.82953072], [82.42294312, 20.82600021], [82.41552734, 20.82646942], [82.4134903, 20.82956123], [82.40563202, 20.8372097], [82.40737152, 20.84349823], [82.40727997, 20.84802055], [82.40225983, 20.85328102], [82.40246582, 20.85795975], [82.40141296, 20.86243057], [82.38279724, 20.8699398], [82.37667084, 20.86692047], [82.36801147, 20.8640995], [82.35903931, 20.86654091], [82.35591888, 20.8699398], [82.35617828, 20.87635994], [82.35917664, 20.8827095], [82.34661865, 20.88384819], [82.34121704, 20.86806107], [82.33687592, 20.8492527], [82.33403778, 20.84058952], [82.3355484, 20.82783127], [82.33310699, 20.8196907], [82.33567047, 20.79737282], [82.33879089, 20.79017067], [82.33692932, 20.77930069], [82.33512878, 20.75851822], [82.3404007, 20.74671936], [82.34586334, 20.72871971], [82.33940887, 20.72583008], [82.34699249, 20.71423912], [82.34426117, 20.7095108], [82.34329987, 20.69885254], [82.3455658, 20.69491005], [82.35131836, 20.67807007], [82.35428619, 20.6750412], [82.36068726, 20.67191124], [82.36522675, 20.66376114], [82.36580658, 20.66114998], [82.36225128, 20.65047073], [82.36380005, 20.6395607], [82.36754608, 20.62957001], [82.36823273, 20.62405968], [82.36633301, 20.6202507], [82.35817719, 20.61516953], [82.35665894, 20.61136055], [82.35785675, 20.60921097], [82.35582733, 20.60349083], [82.34799957, 20.6016407], [82.3454895, 20.59790039], [82.33867645, 20.5943203], [82.33837128, 20.59082985], [82.33766937, 20.58493042], [82.3425293, 20.57522011], [82.34063721, 20.56973267], [82.33715057, 20.56517982], [82.33235168, 20.56227112], [82.32782745, 20.56196022], [82.3274765, 20.55789757], [82.32637787, 20.55657959], [82.32446289, 20.55664825], [82.32401276, 20.55388069], [82.32775879, 20.54927063], [82.33609009, 20.54323959], [82.34224701, 20.53769112], [82.34879303, 20.52293015], [82.35851288, 20.51623917], [82.36994934, 20.51394081], [82.38049316, 20.50984955], [82.38131714, 20.50777054], [82.38123322, 20.50180054], [82.38375092, 20.48266029], [82.38613129, 20.47552109], [82.38513947, 20.4704895], [82.38960266, 20.46536064], [82.39006805, 20.45939064], [82.38809204, 20.45251083], [82.39731598, 20.45191956], [82.40640259, 20.46614075], [82.41007996, 20.47330093], [82.41609955, 20.4661808], [82.41938782, 20.45728111], [82.41940308, 20.44557953], [82.41771698, 20.43830109], [82.42565155, 20.43631935], [82.427742, 20.43206978], [82.4291687, 20.42575264], [82.42295837, 20.41833115], [82.42428589, 20.41015053], [82.41768646, 20.4056282], [82.40989685, 20.40267944], [82.41274261, 20.38824272], [82.41060638, 20.38247108], [82.41040802, 20.37720108], [82.40307617, 20.36526108], [82.40251923, 20.36133003], [82.39794159, 20.35585976], [82.39795685, 20.34677124], [82.39441681, 20.34013748], [82.39377594, 20.3355217], [82.39878845, 20.33165169], [82.40029907, 20.32925034], [82.40045929, 20.32467079], [82.40717316, 20.32207108], [82.41629791, 20.31695938], [82.42243958, 20.30965996], [82.42395782, 20.29650116], [82.4283371, 20.28986168], [82.42922974, 20.2829628], [82.42804718, 20.27861023], [82.42082214, 20.27260017], [82.412323, 20.26990128], [82.4050827, 20.26353073], [82.40537262, 20.25587273], [82.41407776, 20.24155045], [82.40837097, 20.24166107], [82.40432739, 20.23960114], [82.40727997, 20.22764015], [82.40818787, 20.22063065], [82.41277313, 20.21744919], [82.41365051, 20.21327972], [82.41308594, 20.20795059], [82.41359711, 20.20227051], [82.40763092, 20.19409943], [82.40574646, 20.17898941], [82.39048767, 20.16731262], [82.38330078, 20.16045952], [82.38719177, 20.14885139], [82.37892914, 20.14463043], [82.38228607, 20.13817024], [82.38658142, 20.13338089], [82.38775635, 20.12693977], [82.39073944, 20.11905098], [82.39264679, 20.10824966], [82.39466858, 20.08916092], [82.39260101, 20.07331085], [82.39034271, 20.06423187], [82.39086151, 20.05958939], [82.39576721, 20.04899979], [82.40618896, 20.04631042], [82.41713715, 20.04534912], [82.4247818, 20.04354095], [82.43192291, 20.03897095], [82.44142914, 20.03535271], [82.45149994, 20.03526115], [82.45832825, 20.0338707], [82.46409607, 20.03154945], [82.47077179, 20.03202057], [82.47590637, 20.03005028], [82.48159027, 20.02456093], [82.49006653, 20.01857185], [82.5021286, 20.01353073], [82.52424622, 20.01044083], [82.53198242, 20.01222992], [82.54361725, 20.01213074], [82.57594299, 19.99895287], [82.57872009, 19.9956398], [82.58235931, 19.98994064], [82.59836578, 19.98563957], [82.61438751, 19.9869709], [82.61875916, 19.99156952], [82.62088776, 19.99555969], [82.62358093, 19.99764061], [82.63175964, 20.00008965], [82.63625336, 19.99829102], [82.64189911, 19.99790955], [82.65048218, 19.99940109], [82.68102264, 19.99545097], [82.68644714, 19.99463081], [82.69230652, 19.9924202], [82.69802094, 19.99273109], [82.70063019, 19.99287033], [82.70748901, 19.99021912], [82.71092987, 19.98326111], [82.70944977, 19.94667053], [82.71156311, 19.9444809], [82.71061707, 19.93947029], [82.70649719, 19.93353081], [82.70632172, 19.92685127], [82.70426178, 19.91833115], [82.70587921, 19.91123009], [82.70040894, 19.90661049], [82.70147705, 19.90073013], [82.70053101, 19.89328957], [82.70269012, 19.88584137], [82.70636749, 19.87851906], [82.70935059, 19.870121], [82.71750641, 19.87080956], [82.71385956, 19.86209106], [82.71100616, 19.84856033], [82.70471191, 19.84460068], [82.70588684, 19.8380909], [82.70271301, 19.83103943], [82.69844055, 19.82686043], [82.6905365, 19.82575989], [82.68331909, 19.82372093], [82.66913605, 19.82520294], [82.66001892, 19.82372093], [82.65410614, 19.8255291], [82.64573669, 19.82537079], [82.64179993, 19.8137207], [82.6362915, 19.80799294], [82.62890625, 19.80376053], [82.62734222, 19.79615021], [82.62296295, 19.78931046], [82.61886597, 19.78610039], [82.60813141, 19.78512955], [82.60327911, 19.78355026], [82.59900665, 19.78127289], [82.59828186, 19.7751503], [82.59513855, 19.77306938], [82.58506012, 19.7710495], [82.5812912, 19.77269173], [82.57847595, 19.77581978], [82.57791138, 19.77959061], [82.5792923, 19.78466034], [82.57781219, 19.78780937], [82.57779694, 19.79232979], [82.57927704, 19.7972126], [82.57157898, 19.80200958], [82.57303619, 19.80555916], [82.57183838, 19.80760956], [82.57382965, 19.82370949], [82.57126617, 19.82238007], [82.57182312, 19.82780838], [82.57419586, 19.83197975], [82.57894135, 19.83662987], [82.58349609, 19.83832169], [82.58149719, 19.84049034], [82.58573151, 19.8463707], [82.58982086, 19.8481884], [82.59146881, 19.85243034], [82.59738159, 19.86046982], [82.59349823, 19.8645401], [82.59076691, 19.86621857], [82.57758331, 19.86343956], [82.56674957, 19.87172127], [82.55488586, 19.86950111], [82.5508728, 19.8745594], [82.54721832, 19.87330055], [82.54428864, 19.86903], [82.53636169, 19.87689018], [82.5298996, 19.88212967], [82.52305603, 19.87278938], [82.51795959, 19.87631035], [82.51241302, 19.88412094], [82.5022583, 19.88244057], [82.49848175, 19.88516998], [82.497612, 19.8950882], [82.49423981, 19.89735985], [82.48692322, 19.89653015], [82.47569275, 19.90052986], [82.46808624, 19.89948082], [82.46556091, 19.89657974], [82.45835114, 19.89464951], [82.44239044, 19.90298271], [82.43949127, 19.90291977], [82.43225861, 19.89948082], [82.42492676, 19.89760971], [82.42090607, 19.89833069], [82.41388702, 19.89652061], [82.41043854, 19.89340019], [82.40040588, 19.8888092], [82.39700317, 19.88454056], [82.38881683, 19.88175964], [82.38617706, 19.87684059], [82.37798309, 19.86869049], [82.37725067, 19.86296844], [82.36804962, 19.85448074], [82.35845184, 19.85688019], [82.35607147, 19.85513115], [82.35736084, 19.84950066], [82.35624695, 19.84662056], [82.33944702, 19.82996178], [82.32675171, 19.83833122], [82.32511902, 19.84049034], [82.32132721, 19.85191917], [82.31794739, 19.85915947], [82.29823303, 19.883461], [82.29532623, 19.89895821], [82.28333282, 19.91806984], [82.26946259, 19.94524956], [82.26864624, 19.95792961], [82.26169586, 19.97155952], [82.25863647, 19.97174072], [82.25271606, 19.97647858], [82.23335266, 19.99587059], [82.23062897, 19.99808121], [82.22438049, 19.99587059], [82.2194519, 19.9934597], [82.21425629, 19.99334145], [82.21058655, 19.99081039], [82.2042923, 19.98033905], [82.19381714, 19.98130989], [82.18418121, 19.98116112], [82.1784668, 19.97808266], [82.17578125, 19.98553085], [82.16607666, 19.99584007], [82.16583252, 19.99814987], [82.15557861, 20.0023098], [82.14834595, 20.00300026], [82.13169861, 20.01268959], [82.12841034, 20.01258087], [82.12142181, 20.00979042], [82.1160965, 20.01040077], [82.10547638, 20.01781273], [82.10273743, 20.02082825], [82.09773254, 20.02337074], [82.0952301, 20.02680016], [82.09319305, 20.03267288], [82.08943939, 20.03454971], [82.08304596, 20.03273964], [82.07630157, 20.04404068], [82.06980133, 20.04804039], [82.05789948, 20.04986954], [82.04897308, 20.03524017], [82.03875732, 20.02891922], [82.03102875, 20.02288055], [82.03156281, 20.01666069], [82.03070068, 20.01503944], [82.02440643, 20.01004028], [82.01478577, 20.01951027], [82.01551819, 20.02683067], [82.01449585, 20.03025055], [82.014328, 20.0364399], [82.01270294, 20.04103088], [82.00995636, 20.0447998], [82.00689697, 20.04733086], [82.00102997, 20.04926109], [81.99555206, 20.04753113], [81.9927063, 20.04782104], [81.98660278, 20.05207253], [81.98329926, 20.05702972], [81.97849274, 20.06917953], [81.97357178, 20.07561111], [81.96264648, 20.08556938], [81.95477295, 20.09148026], [81.94420624, 20.10160255], [81.94135284, 20.10225105], [81.93696594, 20.10115051], [81.93392944, 20.09930992], [81.92563629, 20.09011841], [81.92188263, 20.08694839], [81.91542816, 20.07382965], [81.91027069, 20.06705093], [81.90142822, 20.05912018], [81.8941803, 20.04824829], [81.8894577, 20.04327011], [81.88504028, 20.04171944], [81.880867, 20.04241943], [81.8762207, 20.04438972], [81.87375641, 20.04618073], [81.866539, 20.03603935], [81.86611176, 20.03518105], [81.86548615, 20.03388023], [81.86458588, 20.02864075], [81.86016846, 20.02336121], [81.85891724, 20.01637077], [81.85762024, 20.00908089], [81.85546112, 20.00352097], [81.85205078, 19.99715996], [81.85161591, 19.99605942], [81.85101318, 19.98975182], [81.85031891, 19.98260117], [81.84689331, 19.9703598], [81.84026337, 19.95513916], [81.83730316, 19.95008087], [81.83895111, 19.94549942], [81.84651184, 19.94144058], [81.84883118, 19.938591], [81.84567261, 19.92295265], [81.84580994, 19.91486168], [81.84963226, 19.90805054], [81.85840607, 19.89954948], [81.86924744, 19.89281082], [81.89805603, 19.87851906], [81.92447662, 19.86872292], [81.93942261, 19.86484146], [81.96037292, 19.85473824], [81.95741272, 19.83600998], [81.9614563, 19.82443237], [81.97020721, 19.81274033], [81.98014832, 19.79578018], [81.98741913, 19.79174042], [81.99237061, 19.79442978], [81.99932098, 19.79830933], [82.00289154, 19.7985096], [82.00305176, 19.79851913], [82.00818634, 19.79656982], [82.02419281, 19.79297829], [82.02906036, 19.79219055], [82.03494263, 19.79265976], [82.04107666, 19.79219055], [82.04444122, 19.78924942], [82.04827881, 19.78841019], [82.05219269, 19.79134178], [82.05982971, 19.78309822], [82.05938721, 19.77903938], [82.05898285, 19.77507019], [82.05541992, 19.7610302], [82.05719757, 19.75341034], [82.04659271, 19.74302101], [82.04400635, 19.73768997], [82.04425812, 19.72912979], [82.04255676, 19.72313118], [82.0437088, 19.71391106], [82.04160309, 19.70828819], [82.03756714, 19.70391083], [82.03848267, 19.69277954], [82.04677582, 19.66937065], [82.04766846, 19.66268921], [82.04603577, 19.65359116], [82.04830933, 19.64937019], [82.04638672, 19.64402962], [82.04728699, 19.63828087], [82.05082703, 19.63162041], [82.05134583, 19.62444115], [82.04847717, 19.61581039], [82.04471588, 19.61079025], [82.0450592, 19.60165024], [82.03727722, 19.59791946], [82.03395844, 19.59069061], [82.03489685, 19.58327293], [82.03779602, 19.5771904], [82.0422287, 19.57092094], [82.04323578, 19.56767082], [82.04413605, 19.56479836], [82.0426178, 19.55800056], [82.04042053, 19.55220985], [82.0430069, 19.5444603], [82.04612732, 19.5386219], [82.04257202, 19.53156853], [82.04102325, 19.52570152], [82.03246307, 19.52129173], [82.0302124, 19.51420975], [82.02239227, 19.50180244], [82.05979156, 19.50364113], [82.0671463, 19.51102066], [82.07084656, 19.51592064], [82.08822632, 19.51044273], [82.09207916, 19.50984001], [82.09101868, 19.49405861], [82.09902954, 19.48957062], [82.10182953, 19.47365952], [82.09986877, 19.46606064], [82.09689331, 19.46108055], [82.10716248, 19.45261192], [82.10679626, 19.44307137], [82.11930847, 19.4239006], [82.13410187, 19.42482758], [82.16069031, 19.42951965], [82.1672287, 19.42984962], [82.17045593, 19.42949104], [82.17925262, 19.41913986], [82.18305969, 19.41761017], [82.18348694, 19.41246033], [82.17777252, 19.40557289], [82.17398071, 19.37693977], [82.16636658, 19.36593056], [82.15080261, 19.37034035], [82.14456177, 19.37011909], [82.14118195, 19.36578178], [82.14083099, 19.3619194], [82.14225769, 19.35511017], [82.14234924, 19.34817123], [82.14955139, 19.34437943], [82.15722656, 19.34284019], [82.16314697, 19.33780289], [82.16895294, 19.33723068], [82.17320251, 19.33407974], [82.17749023, 19.33237076], [82.18025208, 19.33220291], [82.1831665, 19.31970024], [82.17368317, 19.31630135], [82.17008972, 19.3024807], [82.1700058, 19.29572105], [82.16853333, 19.29066086], [82.15836334, 19.28148079], [82.15487671, 19.27477837], [82.15172577, 19.26546288], [82.15099335, 19.25842285], [82.15196228, 19.23890114], [82.15164948, 19.22356987], [82.15376282, 19.21577835], [82.16117859, 19.20838928], [82.15570831, 19.19652939], [82.15804291, 19.19317818], [82.16478729, 19.18732071], [82.17339325, 19.18431091], [82.16940308, 19.17670059], [82.17459869, 19.17358017], [82.17516327, 19.16963959], [82.17112732, 19.16827011], [82.17298126, 19.16476059], [82.17823792, 19.16147995], [82.17878723, 19.15885925], [82.17684174, 19.15497971], [82.17471313, 19.15275002], [82.1714859, 19.15390968], [82.16760254, 19.15687943], [82.16413879, 19.15463829], [82.16500092, 19.15044975], [82.17238617, 19.14764977], [82.17478943, 19.14523125], [82.17198944, 19.14249992], [82.16990662, 19.14364052], [82.1658783, 19.14314079], [82.16471863, 19.13947105], [82.1681366, 19.13384056], [82.16655731, 19.13214111], [82.16117096, 19.12975121], [82.15978241, 19.1264801], [82.16480255, 19.11469078], [82.16982269, 19.11285973], [82.17623901, 19.12506104], [82.19101715, 19.11631012], [82.19975281, 19.11746025], [82.20149994, 19.11576271], [82.19689941, 19.10115051], [82.19948578, 19.09982109], [82.1985321, 19.09416962], [82.19986725, 19.09217834], [82.21058655, 19.09225082], [82.21211243, 19.09054947], [82.21122742, 19.08575821], [82.20855713, 19.07852173], [82.19683075, 19.06786919], [82.1940918, 19.06022072], [82.22248077, 19.02111053], [82.22506714, 19.01459122], [82.22666168, 18.99398041], [82.23956299, 18.91045952], [82.23429108, 18.90526962], [82.23121643, 18.90522003], [82.22767639, 18.9066906], [82.22486115, 18.90924835], [82.21378326, 18.91213989], [82.1987381, 18.90554047], [82.18538666, 18.89698029], [82.17714691, 18.89690018], [82.17272949, 18.89528847], [82.17076874, 18.89159012], [82.17041016, 18.87757111], [82.16310883, 18.87193108], [82.15820313, 18.86945915], [82.16279602, 18.86551094], [82.16126251, 18.8577404], [82.15802765, 18.85197067], [82.16242218, 18.8451004], [82.16175079, 18.83786011], [82.16493988, 18.83020973], [82.15830994, 18.81147003], [82.15867615, 18.80920029], [82.16184235, 18.80496025], [82.16101074, 18.80356979], [82.15611267, 18.79994011], [82.15429688, 18.7963028], [82.15891266, 18.79507065], [82.16114807, 18.79096031], [82.15921783, 18.78811073], [82.15170288, 18.78380013], [82.15001678, 18.77869987], [82.14547729, 18.77327919], [82.13897705, 18.76954079], [82.13066101, 18.77009964], [82.1281662, 18.76432037], [82.12906647, 18.75765038], [82.11392212, 18.76066017], [82.10572815, 18.75844955], [82.09129333, 18.75617981], [82.08470917, 18.75839996], [82.08141327, 18.75587082], [82.08674622, 18.74693108], [82.0848999, 18.73269081], [82.08048248, 18.72274017], [82.07858276, 18.71208191], [82.07398224, 18.7130909], [82.06739044, 18.71710968], [82.06128693, 18.71800995], [82.05912781, 18.71778107], [82.05799103, 18.71251106], [82.05175781, 18.71183968], [82.04943085, 18.7175808], [82.03949738, 18.71704102], [82.03373718, 18.71879959], [82.01561737, 18.71353149], [82.00998688, 18.7105999], [81.99772644, 18.7004509], [81.99186707, 18.69769096], [81.97603607, 18.69514847], [81.96768188, 18.69061279], [81.96386719, 18.68779945], [81.95716095, 18.68341064], [81.95507813, 18.68022919], [81.96063232, 18.66772079], [81.95163727, 18.66098022], [81.9473877, 18.65571022], [81.94592285, 18.64637947], [81.94608307, 18.64048958], [81.94832611, 18.63278961], [81.9474411, 18.62882042], [81.93557739, 18.63289833], [81.91552734, 18.63582039], [81.90914154, 18.6409893], [81.9048996, 18.64639282], [81.89483643, 18.65196037], [81.89317322, 18.65388107], [81.88537598, 18.65032959], [81.89000702, 18.64347076], [81.88931274, 18.64112854], [81.88820648, 18.6373806], [81.88780212, 18.63162994], [81.88729095, 18.62438965], [81.8883667, 18.62099075], [81.89993286, 18.61960983], [81.91303253, 18.6129303], [81.92623138, 18.60322952], [81.92971802, 18.59638977], [81.9330368, 18.59465027], [81.93847656, 18.59179115], [81.94888306, 18.58954048], [81.95452881, 18.58670998], [81.94576263, 18.57491112], [81.943573, 18.56615829], [81.94534302, 18.56245041], [81.94690704, 18.5591507], [81.94625854, 18.55841064], [81.94352722, 18.55541992], [81.93624115, 18.55770111], [81.92984772, 18.55800056], [81.92545319, 18.55768013], [81.92019653, 18.55730057], [81.91639709, 18.559021], [81.91316986, 18.56118965], [81.90859985, 18.56422806], [81.90080261, 18.55717087], [81.89975739, 18.54904175], [81.89763641, 18.54271126], [81.89794159, 18.53773117], [81.89865112, 18.53615952], [81.90029144, 18.53251839], [81.8968277, 18.52839279], [81.89607239, 18.52843094], [81.88259888, 18.52918053], [81.87867737, 18.52627945], [81.87538147, 18.5214119], [81.87361908, 18.51993942], [81.8707962, 18.51758957], [81.86805725, 18.51748276], [81.86296082, 18.51727295], [81.85794067, 18.51305962], [81.85302734, 18.50732994], [81.84896088, 18.50060081], [81.84958649, 18.48904991], [81.84430695, 18.48154068], [81.82892609, 18.46895027], [81.79756927, 18.43976021], [81.76738739, 18.41477013], [81.76210022, 18.4113102], [81.76036835, 18.39982986], [81.75554657, 18.38624954], [81.74675751, 18.35550117], [81.74607849, 18.35174179], [81.74491119, 18.34535027], [81.73707581, 18.34422112], [81.71750641, 18.34320068], [81.69924164, 18.34357071], [81.68078613, 18.34103012], [81.65809631, 18.33929062], [81.65280914, 18.33667946], [81.64916992, 18.33100128], [81.64937592, 18.33057976], [81.65245819, 18.32478905], [81.6603775, 18.31575966], [81.65866852, 18.3110981], [81.64675903, 18.31150055], [81.63214111, 18.3080101], [81.62761688, 18.30487061], [81.6213913, 18.30372238], [81.61588287, 18.30084038], [81.60611725, 18.2994194], [81.59687042, 18.30211067], [81.59340668, 18.30128098], [81.59203339, 18.29747963], [81.59050751, 18.29333115], [81.58624268, 18.29215813], [81.58178711, 18.28816032], [81.57401276, 18.28116989], [81.56759644, 18.27321053], [81.54807281, 18.26213074], [81.53945923, 18.26210976], [81.52796173, 18.25908089], [81.52368164, 18.24865913], [81.52577209, 18.23652077], [81.52287292, 18.22737122], [81.51113892, 18.20194054], [81.50878906, 18.1925106], [81.504776, 18.18381119], [81.50524902, 18.17778969], [81.50892639, 18.17407036], [81.51487732, 18.17217064], [81.5226059, 18.15727043], [81.52173615, 18.14830971], [81.51580048, 18.13993073], [81.51187897, 18.1292305], [81.51072693, 18.10387993], [81.50865936, 18.09241104], [81.49684906, 18.07271194], [81.49600983, 18.07069969], [81.49516296, 18.06868935], [81.49488068, 18.06266022], [81.49465942, 18.05800056], [81.48149872, 18.04992294], [81.47751617, 18.03872108], [81.47389221, 18.02851105], [81.47750092, 18.01999283], [81.47894287, 18.00370026], [81.47767639, 17.9935112], [81.47451019, 17.98870277], [81.47307587, 17.98328972], [81.47666931, 17.97389984], [81.47688293, 17.97265053], [81.47731018, 17.97002029], [81.47644043, 17.96763039], [81.47567749, 17.96708107], [81.47325897, 17.96532059], [81.46695709, 17.95490074], [81.45479584, 17.94655991], [81.44523621, 17.92617035], [81.44510651, 17.92546844], [81.44445801, 17.92210007], [81.44592285, 17.91717911], [81.44621277, 17.91028023], [81.44806671, 17.90714073], [81.44818115, 17.9050808], [81.44827271, 17.90302086], [81.4437027, 17.89323044], [81.44274902, 17.88516045], [81.44026184, 17.87914085], [81.43725586, 17.87593842], [81.43595886, 17.87544823], [81.43450928, 17.87490082], [81.4302063, 17.87467957], [81.42312622, 17.87742043], [81.41166687, 17.88539124], [81.40376282, 17.88859177], [81.39901733, 17.88849068], [81.39585114, 17.88755989], [81.39382935, 17.88513947], [81.39050293, 17.87429047], [81.38954926, 17.8621006], [81.38987732, 17.85943031], [81.39805603, 17.84678078], [81.39736938, 17.84364128], [81.39334106, 17.83582115], [81.38442993, 17.82579041], [81.38378906, 17.82348824], [81.38300323, 17.82057953], [81.38304901, 17.81695175], [81.38310242, 17.81414032], [81.38497162, 17.80659294], [81.38413239, 17.80348969], [81.3744278, 17.80532074], [81.36760712, 17.8080883], [81.36107635, 17.80961037], [81.35749817, 17.81042099], [81.3445282, 17.81158066], [81.33537292, 17.81125069], [81.32598877, 17.81241035], [81.31505585, 17.81233978], [81.29812622, 17.80985069], [81.2633667, 17.81046295], [81.25403595, 17.81212997], [81.2279129, 17.82629013], [81.22036743, 17.82935905], [81.21349335, 17.83304977], [81.1919632, 17.84710121], [81.18730164, 17.84834099], [81.18379211, 17.84926987], [81.17637634, 17.84912109], [81.15956879, 17.85263062], [81.12124634, 17.82832909], [81.10903168, 17.82312012], [81.09770203, 17.81710052], [81.08908844, 17.81087112], [81.08708191, 17.80334282], [81.07956696, 17.79497147], [81.07647705, 17.79050064], [81.07360077, 17.78629112], [81.06910706, 17.78511047], [81.06581116, 17.78424072], [81.06128693, 17.78359032], [81.05597687, 17.78283119], [81.04522705, 17.78399086], [81.03765106, 17.78623962], [81.03244781, 17.78973007], [81.01257324, 17.81666946], [81.00434875, 17.83834839], [81.00332642, 17.8491497], [81.0018692, 17.86473083], [80.99723816, 17.89516068], [80.99433899, 17.91423035], [80.99196625, 17.91937065], [80.98464966, 17.92290115], [80.98329163, 17.93495178], [80.98058319, 17.93985939]]]}}, {\\\"id\\\": \\\"6\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.8_1\\\", \\\"HASC_1\\\": \\\"IN.DN\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Dadra and Nagar Haveli\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": \\\"DAdra et Nagar Haveli|Dadra e Nagar Haveli\\\", \\\"apm25_popweighted\\\": 96.7, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1531.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1565.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3095.0, \\\"geo-id\\\": 6, \\\"hpm25_child_popweighted\\\": 260.0, \\\"hpm25_female_popweighted\\\": 299.0, \\\"hpm25_male_popweighted\\\": 215.0, \\\"location\\\": \\\"Dadra and Nagar Haveli\\\", \\\"mort_apm25_6cod_mean_total\\\": 176.0, \\\"mort_hpm25_6cod_mean_total\\\": 181.0, \\\"mort_tpm25_6cod_mean_total\\\": 357.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[73.02468109, 20.09630013], [73.01954651, 20.10502052], [73.01020813, 20.11040115], [73.01499176, 20.12486076], [73.01667023, 20.13049126], [73.01702118, 20.1324501], [73.01747894, 20.13495827], [73.01051331, 20.14022255], [73.00875854, 20.13701057], [73.00763702, 20.13246918], [73.00771332, 20.12940025], [73.00778198, 20.12639046], [73.00727844, 20.12412071], [73.00665283, 20.12125015], [73.00431061, 20.11791992], [72.9941864, 20.11390114], [72.98924255, 20.11321259], [72.98532104, 20.113451], [72.97962952, 20.12529945], [72.97322845, 20.13080025], [72.98596191, 20.15752983], [72.98623657, 20.16271973], [72.98668671, 20.17131042], [72.98603821, 20.17654991], [72.97619629, 20.18001938], [72.97592163, 20.18959808], [72.97042847, 20.21232986], [72.97437286, 20.21497154], [72.97543335, 20.21920013], [72.9744873, 20.22583961], [72.96962738, 20.23394012], [72.96534729, 20.23718071], [72.95778656, 20.24115181], [72.95146942, 20.24357033], [72.94367218, 20.24488068], [72.9408493, 20.24682045], [72.92375183, 20.26819992], [72.92230988, 20.27440071], [72.92459106, 20.27865982], [72.930336, 20.28397942], [72.93811035, 20.28800964], [72.94142151, 20.29212761], [72.94597626, 20.29343033], [72.95078278, 20.2920208], [72.95749664, 20.28770065], [72.96977997, 20.27474022], [72.9744873, 20.27178001], [72.98005676, 20.27075005], [72.98409271, 20.27168083], [72.98779297, 20.27466965], [72.98947144, 20.27753067], [72.99046326, 20.29208946], [73.00357056, 20.29314041], [73.01048279, 20.29236984], [73.01728821, 20.29053116], [73.02049255, 20.29090118], [73.02179718, 20.2927475], [73.02217102, 20.29706955], [73.02056885, 20.30207825], [73.02053833, 20.30751991], [73.01760101, 20.31549263], [73.01983643, 20.31739807], [73.02226257, 20.31585121], [73.02469635, 20.31279945], [73.02696228, 20.30380058], [73.02651978, 20.29412079], [73.02979279, 20.29226112], [73.03726959, 20.29059982], [73.04197693, 20.2902298], [73.04416656, 20.2911129], [73.04586029, 20.29243279], [73.0475769, 20.3044529], [73.04767609, 20.31661034], [73.05047607, 20.32299805], [73.05512238, 20.32524109], [73.06204224, 20.32574081], [73.06668091, 20.32608032], [73.07151031, 20.32716942], [73.07525635, 20.3296299], [73.08273315, 20.32912064], [73.08628845, 20.32611084], [73.08863068, 20.32648277], [73.09089661, 20.32683945], [73.09741211, 20.33509827], [73.09916687, 20.33993912], [73.10132599, 20.35603905], [73.10212708, 20.35845947], [73.10253143, 20.35967064], [73.10338593, 20.3603611], [73.10542297, 20.36054039], [73.1073761, 20.36071014], [73.11138153, 20.35609818], [73.11425018, 20.35279083], [73.11638641, 20.34716034], [73.11801147, 20.34287071], [73.12145996, 20.3364296], [73.12195587, 20.33287811], [73.11888123, 20.32620049], [73.11650848, 20.31270981], [73.11440277, 20.3106308], [73.11286926, 20.30494118], [73.11566162, 20.30404091], [73.1291275, 20.30578041], [73.1342926, 20.30532837], [73.13931274, 20.30957985], [73.14015198, 20.31468964], [73.1417923, 20.31746101], [73.14731598, 20.31682968], [73.15242004, 20.31747055], [73.16139984, 20.31719017], [73.16551971, 20.31592941], [73.16838074, 20.31380081], [73.17073822, 20.31052971], [73.17710114, 20.31232262], [73.17801666, 20.31071091], [73.17753601, 20.30907059], [73.17710876, 20.30759811], [73.17698669, 20.30088043], [73.17954254, 20.28986168], [73.17887878, 20.28646088], [73.17578888, 20.28417015], [73.17195129, 20.28250122], [73.1690979, 20.28231812], [73.16680145, 20.28341103], [73.1654129, 20.28703117], [73.16129303, 20.29179192], [73.15820313, 20.29048157], [73.15625763, 20.28742981], [73.15519714, 20.28541946], [73.15513611, 20.28236008], [73.1542511, 20.27934837], [73.15355682, 20.2770195], [73.15254211, 20.27667999], [73.14987183, 20.28012276], [73.1469574, 20.28104973], [73.14628601, 20.28053093], [73.14270782, 20.27528954], [73.14260101, 20.26863098], [73.14095306, 20.26523018], [73.13684845, 20.26046944], [73.1280365, 20.25850105], [73.12458038, 20.25671959], [73.11331177, 20.24418068], [73.10852051, 20.23855019], [73.110466, 20.23213005], [73.10192871, 20.22894287], [73.0875473, 20.23397255], [73.08187866, 20.23281288], [73.07685852, 20.22980118], [73.07036591, 20.22145081], [73.0642395, 20.20316124], [73.0666275, 20.19787979], [73.0703125, 20.19745064], [73.07048035, 20.19737053], [73.07303619, 20.19613075], [73.07435608, 20.19252014], [73.07422638, 20.17728043], [73.07244873, 20.16345024], [73.07553101, 20.16007996], [73.08244324, 20.15658951], [73.08648682, 20.1570015], [73.08790588, 20.16575813], [73.08991241, 20.17043114], [73.09348297, 20.17389107], [73.09616089, 20.17424011], [73.09790802, 20.17334938], [73.0994873, 20.17257118], [73.10182953, 20.16410828], [73.10334015, 20.16134834], [73.10514069, 20.15996933], [73.10910034, 20.15920067], [73.11302948, 20.1584301], [73.1167984, 20.15879059], [73.11974335, 20.15906906], [73.12259674, 20.15775108], [73.12494659, 20.15666008], [73.12802887, 20.15711975], [73.12555695, 20.16109276], [73.12606049, 20.16362762], [73.13260651, 20.16777039], [73.13582611, 20.17231941], [73.13947296, 20.1731205], [73.14702606, 20.17105293], [73.15007019, 20.17284012], [73.1523819, 20.17605972], [73.15213013, 20.17974281], [73.14839935, 20.18548012], [73.14602661, 20.18739128], [73.14157104, 20.20186996], [73.1421814, 20.20438957], [73.14575195, 20.20697975], [73.14981842, 20.20560074], [73.15223694, 20.20318985], [73.15284729, 20.2027607], [73.15364075, 20.20222092], [73.16351318, 20.20146942], [73.16895294, 20.19968987], [73.17298126, 20.20132065], [73.18017578, 20.20860863], [73.18113708, 20.20240021], [73.1885376, 20.20062065], [73.19132996, 20.19860268], [73.19586945, 20.19752121], [73.20440674, 20.19832039], [73.20993042, 20.19735146], [73.21615601, 20.19278908], [73.21936798, 20.19043922], [73.2277832, 20.18704987], [73.22915649, 20.18429947], [73.22833252, 20.18009949], [73.22673035, 20.17636108], [73.2220993, 20.17142105], [73.21775055, 20.16813278], [73.19924164, 20.16164017], [73.19609833, 20.15611267], [73.19532776, 20.15093994], [73.19597626, 20.13994026], [73.20069122, 20.12969971], [73.21095276, 20.12360001], [73.21631622, 20.12199974], [73.21774292, 20.10634041], [73.21911621, 20.09749985], [73.21393585, 20.09064102], [73.20691681, 20.08371162], [73.20289612, 20.08105087], [73.19803619, 20.07781029], [73.19890594, 20.06227112], [73.18586731, 20.05290031], [73.18379974, 20.0522995], [73.18144226, 20.05162048], [73.17539215, 20.05805016], [73.17022705, 20.06560135], [73.16329956, 20.07311058], [73.15674591, 20.07395935], [73.1444931, 20.07785988], [73.13954163, 20.08427048], [73.13669586, 20.08525085], [73.13140106, 20.07942963], [73.12967682, 20.07884026], [73.12773895, 20.07816124], [73.12612152, 20.07809067], [73.1231308, 20.07793999], [73.11754608, 20.07880974], [73.11183167, 20.08301163], [73.11038208, 20.08461189], [73.10794067, 20.08732033], [73.1051712, 20.08721924], [73.09844971, 20.09366989], [73.08831787, 20.09446907], [73.07823181, 20.09527016], [73.06063843, 20.09906006], [73.05799103, 20.09673119], [73.05921173, 20.06793022], [73.05281067, 20.06767082], [73.04527283, 20.07178116], [73.03852844, 20.0780983], [73.03177643, 20.08442116], [73.02468109, 20.09630013]]]}}, {\\\"id\\\": \\\"7\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.9_1\\\", \\\"HASC_1\\\": \\\"IN.DD\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Daman and Diu\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 97.9, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1540.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1560.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3100.0, \\\"geo-id\\\": 7, \\\"hpm25_child_popweighted\\\": 260.0, \\\"hpm25_female_popweighted\\\": 299.0, \\\"hpm25_male_popweighted\\\": 215.0, \\\"location\\\": \\\"Daman and Diu\\\", \\\"mort_apm25_6cod_mean_total\\\": 319.0, \\\"mort_hpm25_6cod_mean_total\\\": 326.0, \\\"mort_tpm25_6cod_mean_total\\\": 646.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[72.88378143, 20.370224], [72.87988281, 20.3707695], [72.87520599, 20.3728199], [72.86501312, 20.37241173], [72.85894775, 20.37434006], [72.8353653, 20.37371254], [72.83132935, 20.36873817], [72.82649231, 20.36676025], [72.8215332, 20.3710804], [72.82178497, 20.37101936], [72.8215332, 20.37125015], [72.82125092, 20.37125015], [72.82125092, 20.37152863], [72.8215332, 20.3715229], [72.8215332, 20.37292099], [72.82180023, 20.37292099], [72.82180023, 20.37375069], [72.82208252, 20.37375069], [72.82208252, 20.37430954], [72.82235718, 20.37430954], [72.82235718, 20.37486076], [72.82263947, 20.37486076], [72.82263947, 20.37541962], [72.82290649, 20.37541962], [72.82290649, 20.37625122], [72.82319641, 20.37624931], [72.82319641, 20.37708282], [72.82347107, 20.37708282], [72.82347107, 20.37819481], [72.82375336, 20.37819099], [72.82375336, 20.37903023], [72.82402802, 20.37902641], [72.82402802, 20.37986183], [72.82430267, 20.37985992], [72.82430267, 20.38042068], [72.82458496, 20.38041878], [72.82458496, 20.38124847], [72.82485962, 20.38124847], [72.82485962, 20.38208389], [72.82514191, 20.38207817], [72.82514191, 20.38264084], [72.82541656, 20.38264084], [72.82541656, 20.38347244], [72.82569122, 20.38345909], [72.82569122, 20.38402939], [72.82597351, 20.38402748], [72.82597351, 20.38458252], [72.82624817, 20.38458252], [72.82624817, 20.38513947], [72.82653046, 20.38513947], [72.82653046, 20.3856945], [72.82680511, 20.3856945], [72.82681274, 20.38680077], [72.82707977, 20.38680649], [72.82707977, 20.38736153], [72.82763672, 20.38735962], [72.82763672, 20.38764], [72.82791901, 20.38763809], [72.82791901, 20.3884716], [72.82763672, 20.3884697], [72.82763672, 20.38903046], [72.82736206, 20.38903046], [72.82736206, 20.39014053], [72.82763672, 20.39013863], [72.82763672, 20.39069366], [72.82791901, 20.39069366], [72.82791901, 20.39208412], [72.82819366, 20.39208412], [72.82819366, 20.39458275], [72.82847595, 20.39458084], [72.82847595, 20.40042114], [72.82875061, 20.40041733], [72.82875061, 20.4034729], [72.82847595, 20.40347099], [72.82847595, 20.40513992], [72.82875061, 20.40513992], [72.82875061, 20.40624809], [72.82902527, 20.40624809], [72.82902527, 20.40708351], [72.82930756, 20.40708351], [72.82930756, 20.40819359], [72.82958221, 20.40819359], [72.82958221, 20.40847015], [72.82985687, 20.40846825], [72.82985687, 20.40903091], [72.83013916, 20.4090271], [72.83013916, 20.40958405], [72.83040619, 20.40958023], [72.83040619, 20.40986252], [72.83069611, 20.40986252], [72.83069611, 20.4101429], [72.83097076, 20.4101429], [72.83097076, 20.41041946], [72.83125305, 20.41041756], [72.83125305, 20.41122818], [72.83125305, 20.41263962], [72.83069611, 20.41263962], [72.83069611, 20.41319466], [72.83041382, 20.41319466], [72.83041382, 20.41347313], [72.83013916, 20.41347122], [72.83013916, 20.41374969], [72.8298645, 20.41374969], [72.8298645, 20.41430473], [72.82958221, 20.41430092], [72.82958221, 20.41542053], [72.82930756, 20.41542053], [72.82930756, 20.42124748], [72.82902527, 20.42124748], [72.82902527, 20.42569351], [72.82875061, 20.42569542], [72.82875061, 20.4295826], [72.82847595, 20.42958069], [72.82847595, 20.42986107], [72.82819366, 20.42986107], [72.82819366, 20.43208313], [72.82847595, 20.43208122], [72.82847595, 20.43374825], [72.82875061, 20.43374825], [72.82875061, 20.43431091], [72.8290329, 20.43431091], [72.8290329, 20.43514061], [72.82930756, 20.43514061], [72.82930756, 20.43625259], [72.82958221, 20.43625259], [72.82958221, 20.4370842], [72.82985687, 20.43708038], [72.82985687, 20.43875122], [72.83013916, 20.43874931], [72.83013916, 20.43958473], [72.83040619, 20.43958282], [72.83040619, 20.44042015], [72.83069611, 20.44041634], [72.83069611, 20.44097137], [72.83097076, 20.44096947], [72.83097076, 20.44153023], [72.83125305, 20.44152832], [72.83125305, 20.44208336], [72.83152771, 20.44207954], [72.83152771, 20.4426403], [72.83180237, 20.4426384], [72.83180237, 20.44347191], [72.83207703, 20.44347], [72.83207703, 20.44403076], [72.83235931, 20.44403076], [72.83235931, 20.44486046], [72.8326416, 20.44486046], [72.8326416, 20.44597244], [72.83291626, 20.44597054], [72.83291626, 20.44625092], [72.83347321, 20.44625092], [72.83347321, 20.44652748], [72.83374786, 20.44652748], [72.83374786, 20.44680595], [72.83403015, 20.44680023], [72.83403015, 20.44735909], [72.8345871, 20.44735909], [72.8345871, 20.44791985], [72.83486176, 20.44791603], [72.83486176, 20.4481945], [72.83513641, 20.44819069], [72.83513641, 20.44875145], [72.8354187, 20.44875145], [72.8354187, 20.44903183], [72.83569336, 20.44902992], [72.83569336, 20.44986153], [72.83598328, 20.44986153], [72.83598328, 20.45014191], [72.83625031, 20.45014191], [72.83625031, 20.45042038], [72.83652496, 20.45041656], [72.83652496, 20.45125008], [72.83679962, 20.45125008], [72.83679962, 20.45153046], [72.83708191, 20.45153046], [72.83708191, 20.45181084], [72.83735657, 20.45181084], [72.8373642, 20.45236015], [72.83763885, 20.45236015], [72.83763885, 20.45264053], [72.83791351, 20.45263863], [72.83791351, 20.45319366], [72.8381958, 20.45319366], [72.8381958, 20.45347214], [72.83847046, 20.45347023], [72.83847046, 20.45375061], [72.8390274, 20.45375061], [72.8390274, 20.45403099], [72.83930206, 20.45403099], [72.83930206, 20.45430946], [72.83957672, 20.45430946], [72.83957672, 20.45486069], [72.8401413, 20.45486069], [72.8401413, 20.45514107], [72.84041595, 20.45514107], [72.84041595, 20.45541954], [72.84069824, 20.45541954], [72.84069824, 20.45569992], [72.8409729, 20.4556942], [72.8409729, 20.45597267], [72.84123993, 20.45597076], [72.84124756, 20.45625114], [72.84152985, 20.45624924], [72.84152985, 20.45634842], [72.84152985, 20.45652962], [72.84166718, 20.45652771], [72.8418045, 20.45652771], [72.8418045, 20.45669937], [72.84179688, 20.45681], [72.84191132, 20.45680618], [72.84208679, 20.45680428], [72.84208679, 20.45708275], [72.84236145, 20.45708084], [72.84236145, 20.45736122], [72.84263611, 20.45736122], [72.84263611, 20.45775032], [72.84263611, 20.45792007], [72.84276581, 20.45791626], [72.8429184, 20.45791626], [72.8429184, 20.45819473], [72.84347534, 20.45819473], [72.84347534, 20.4584713], [72.84401703, 20.45846939], [72.84401703, 20.45902824], [72.84430695, 20.45902634], [72.84430695, 20.45930481], [72.8445816, 20.45930481], [72.8445816, 20.45958328], [72.84541321, 20.45958328], [72.84541321, 20.45986176], [72.84597015, 20.45986176], [72.84597015, 20.45958328], [72.84625244, 20.45957947], [72.84625244, 20.46013832], [72.84680176, 20.46013832], [72.84680939, 20.46042061], [72.84764099, 20.46042061], [72.84764099, 20.46069908], [72.84791565, 20.46069527], [72.84791565, 20.46097183], [72.8484726, 20.46096992], [72.8484726, 20.4612484], [72.84902954, 20.4612484], [72.84902954, 20.46153069], [72.8493042, 20.46152687], [72.8493042, 20.46180534], [72.84986115, 20.46180534], [72.84986115, 20.46208382], [72.8501358, 20.46207809], [72.8501358, 20.46264076], [72.85041809, 20.46264076], [72.85041809, 20.46292114], [72.85124969, 20.46291733], [72.85124969, 20.46319389], [72.85152435, 20.46319389], [72.85152435, 20.46347237], [72.8520813, 20.46347237], [72.8520813, 20.46319389], [72.85236359, 20.46319389], [72.85236359, 20.46347237], [72.8529129, 20.46347237], [72.8529129, 20.46375275], [72.85320282, 20.46375275], [72.85320282, 20.46403122], [72.85346985, 20.4640274], [72.85346985, 20.46458054], [72.85375214, 20.46458054], [72.85375214, 20.46487045], [72.85402679, 20.46487045], [72.85402679, 20.46513939], [72.85430908, 20.46513939], [72.85430908, 20.46569443], [72.85514069, 20.46569443], [72.85514069, 20.46597481], [72.85597229, 20.46597481], [72.85597229, 20.46569443], [72.85624695, 20.46569443], [72.85624695, 20.46541595], [72.85679626, 20.46541977], [72.85679626, 20.46513939], [72.85708618, 20.46513939], [72.85708618, 20.46487045], [72.85874939, 20.46487045], [72.85874939, 20.46458054], [72.85901642, 20.46458054], [72.85901642, 20.46487045], [72.85930634, 20.46487045], [72.85930634, 20.46541977], [72.85902405, 20.46541595], [72.85902405, 20.46569443], [72.85874939, 20.46569443], [72.85874939, 20.46597481], [72.8584671, 20.4659729], [72.8584671, 20.46681023], [72.85874939, 20.46680641], [72.85874939, 20.46708488], [72.85901642, 20.46708107], [72.85901642, 20.46763992], [72.85930634, 20.46763992], [72.85930634, 20.46820068], [72.85958099, 20.46820068], [72.85958099, 20.46875], [72.85986328, 20.46875], [72.85986328, 20.47042084], [72.86013794, 20.47041512], [72.86013794, 20.47096062], [72.86340332, 20.46883965], [72.86589813, 20.46751022], [72.8664093, 20.46469688], [72.87428284, 20.46296692], [72.88248444, 20.46276665], [72.88564301, 20.45907021], [72.88744354, 20.45333099], [72.89000702, 20.44886017], [72.89334869, 20.44538689], [72.89280701, 20.44166946], [72.88877869, 20.43915558], [72.88488007, 20.44006157], [72.87704468, 20.44462204], [72.87340546, 20.44420815], [72.86811066, 20.434412], [72.86154938, 20.42836952], [72.85932159, 20.42437363], [72.86031342, 20.41961479], [72.86510468, 20.41617584], [72.8688736, 20.41582489], [72.87956238, 20.41846848], [72.88889313, 20.41911316], [72.89583588, 20.42136002], [72.89962769, 20.41921425], [72.90261078, 20.41524124], [72.90330505, 20.41033745], [72.90042114, 20.40526772], [72.88951111, 20.3982811], [72.88632202, 20.39336777], [72.88685608, 20.38718224], [72.88873291, 20.38420105], [72.89564514, 20.38036346], [72.89637756, 20.37669563], [72.89354706, 20.37214661], [72.88378143, 20.370224]]], [[[70.96263885, 20.72938156], [70.96263885, 20.72903061], [70.96235657, 20.72903061], [70.96235657, 20.72846985], [70.96208191, 20.72847176], [70.96208191, 20.72791672], [70.96179962, 20.72792053], [70.96179962, 20.72707939], [70.96152496, 20.72708321], [70.96152496, 20.72597313], [70.96125031, 20.72597313], [70.96125031, 20.72319412], [70.96152496, 20.72319412], [70.96152496, 20.72263908], [70.96179962, 20.72264099], [70.96179962, 20.72236061], [70.96208191, 20.72236061], [70.96208191, 20.72208023], [70.9623642, 20.72208595], [70.9623642, 20.72180557], [70.96290588, 20.72180939], [70.96290588, 20.72153091], [70.96347046, 20.72153091], [70.96347046, 20.72180939], [70.96375275, 20.72180939], [70.96375275, 20.72153091], [70.9640274, 20.72153091], [70.9640274, 20.72180939], [70.9651413, 20.72180557], [70.9651413, 20.72208595], [70.96541595, 20.72208023], [70.96541595, 20.72291946], [70.96347046, 20.72291756], [70.96347046, 20.72319412], [70.96291351, 20.72319412], [70.96291351, 20.7234726], [70.96263885, 20.72347069], [70.96263885, 20.72513962], [70.96291351, 20.72513962], [70.96291351, 20.72569466], [70.9631958, 20.72569466], [70.9631958, 20.72597313], [70.96347046, 20.72597122], [70.96347046, 20.72652817], [70.96375275, 20.72652626], [70.96375275, 20.72680473], [70.9640274, 20.72680473], [70.9640274, 20.72708321], [70.96430206, 20.72708321], [70.96430206, 20.72736168], [70.96457672, 20.72735977], [70.96457672, 20.72763824], [70.96485901, 20.72763824], [70.96485901, 20.72792053], [70.9651413, 20.72792053], [70.9651413, 20.72820091], [70.96541595, 20.72819519], [70.96541595, 20.72847176], [70.96763611, 20.72847176], [70.96763611, 20.72819519], [70.96819305, 20.72820091], [70.96819305, 20.72792053], [70.96901703, 20.72792053], [70.96901703, 20.72763824], [70.97070313, 20.72763824], [70.97070313, 20.72707939], [70.97180176, 20.72708321], [70.97180176, 20.72680473], [70.9723587, 20.72680473], [70.9723587, 20.72652626], [70.97292328, 20.72652817], [70.97292328, 20.72624969], [70.97374725, 20.72624969], [70.97373962, 20.72597122], [70.97458649, 20.72597313], [70.97458649, 20.72569466], [70.97541809, 20.72569466], [70.97541809, 20.72541618], [70.97569275, 20.72541809], [70.97569275, 20.72513962], [70.97598267, 20.72513962], [70.97597504, 20.72486115], [70.97624969, 20.72486115], [70.97624969, 20.72430992], [70.97651672, 20.72430992], [70.97651672, 20.72402954], [70.97679901, 20.72402954], [70.97679901, 20.72375107], [70.9770813, 20.72375107], [70.9770813, 20.72319031], [70.97736359, 20.72319412], [70.97736359, 20.72291756], [70.97763824, 20.72291946], [70.97763824, 20.72264099], [70.9779129, 20.72264099], [70.9779129, 20.72236061], [70.97820282, 20.72236061], [70.97819519, 20.72208595], [70.97875214, 20.72208595], [70.97875214, 20.72180557], [70.97902679, 20.72180939], [70.97902679, 20.72153091], [70.97930908, 20.72153091], [70.97930908, 20.72125053], [70.97957611, 20.72125053], [70.97957611, 20.72068977], [70.9798584, 20.72069359], [70.9798584, 20.72041702], [70.98152924, 20.72042084], [70.98152924, 20.72014046], [70.98236084, 20.72014046], [70.98236084, 20.71986008], [70.9834671, 20.71986008], [70.9834671, 20.72014046], [70.98596954, 20.72014046], [70.98596954, 20.71986008], [70.98625183, 20.71986389], [70.98625183, 20.71958351], [70.98652649, 20.71958351], [70.98652649, 20.71930504], [70.98764038, 20.71931076], [70.98764038, 20.71903038], [70.98958588, 20.71903038], [70.98958588, 20.71875191], [70.99014282, 20.71875191], [70.99013519, 20.71847343], [70.99069214, 20.71847343], [70.99069214, 20.71819496], [70.9909668, 20.71820068], [70.9909668, 20.7179203], [70.99124908, 20.7179203], [70.99124908, 20.71735954], [70.99153137, 20.71735954], [70.99153137, 20.71708107], [70.99208069, 20.71708107], [70.99208069, 20.71680641], [70.99318695, 20.71681023], [70.99318695, 20.71653175], [70.99402618, 20.71653175], [70.99402618, 20.71624947], [70.9970932, 20.71624947], [70.99708557, 20.7159729], [70.99736023, 20.7159729], [70.99736023, 20.71569443], [70.99764252, 20.71569443], [70.99764252, 20.71442032], [70.99764252, 20.7140274], [70.99736023, 20.71403122], [70.99736023, 20.71347046], [70.99708557, 20.71347237], [70.99708557, 20.71319389], [70.99680328, 20.71319389], [70.99680328, 20.71291733], [70.99624634, 20.71292114], [70.99624634, 20.71236038], [70.99597168, 20.71236038], [70.99597168, 20.71208], [70.99514008, 20.71208382], [70.99514008, 20.71180534], [70.99487305, 20.71181107], [70.99487305, 20.71125031], [70.99458313, 20.71125031], [70.99458313, 20.71096992], [70.99430847, 20.71097183], [70.99430847, 20.71069527], [70.99346924, 20.71070099], [70.99346924, 20.71042061], [70.99291992, 20.71042061], [70.99291992, 20.71014023], [70.99153137, 20.71014023], [70.99153137, 20.70985985], [70.99041748, 20.70986176], [70.99041748, 20.70930672], [70.99013519, 20.70930672], [70.99013519, 20.70902824], [70.98986053, 20.70903015], [70.98986053, 20.70874977], [70.98958588, 20.70874977], [70.98958588, 20.70845985], [70.98902893, 20.70845985], [70.98902893, 20.70874977], [70.98873901, 20.70874977], [70.98873901, 20.70903015], [70.98847198, 20.70902824], [70.98847198, 20.70930672], [70.98791504, 20.70930672], [70.98791504, 20.70958328], [70.98680878, 20.70958328], [70.98680878, 20.70930672], [70.98569489, 20.70930672], [70.98569489, 20.70902824], [70.98513794, 20.70903015], [70.98513794, 20.70845985], [70.98486328, 20.7084713], [70.98486328, 20.70791626], [70.98458099, 20.70792007], [70.98458099, 20.70763969], [70.9834671, 20.70763969], [70.9834671, 20.70736122], [70.98208618, 20.70736122], [70.98208618, 20.70708275], [70.98152924, 20.70708466], [70.98152924, 20.70680618], [70.98097229, 20.70681], [70.98097229, 20.70652962], [70.98042297, 20.70652962], [70.98042297, 20.70625114], [70.98014069, 20.70625114], [70.98014069, 20.70597267], [70.97930908, 20.70597267], [70.97930908, 20.7056942], [70.97902679, 20.7056942], [70.97902679, 20.70541763], [70.97875214, 20.70541954], [70.97875214, 20.70458031], [70.97846985, 20.70458412], [70.97846985, 20.70430565], [70.97820282, 20.70430946], [70.97820282, 20.7040329], [70.9779129, 20.7040329], [70.9779129, 20.70375252], [70.97763824, 20.70375252], [70.97763824, 20.70347023], [70.97736359, 20.70347023], [70.97736359, 20.70205116], [70.97736359, 20.70180511], [70.9770813, 20.70181084], [70.9770813, 20.70153046], [70.97624969, 20.70153046], [70.97624969, 20.70181084], [70.97597504, 20.70180511], [70.97597504, 20.70197105], [70.97597504, 20.70208359], [70.97569275, 20.70207977], [70.97569275, 20.70292091], [70.97597504, 20.7029171], [70.97597504, 20.70319366], [70.97624969, 20.70318985], [70.97624969, 20.7040329], [70.97429657, 20.7040329], [70.97429657, 20.70375252], [70.97292328, 20.70375252], [70.97292328, 20.7040329], [70.97264099, 20.70402718], [70.97264099, 20.70458412], [70.9723587, 20.70458412], [70.9723587, 20.70430565], [70.97207642, 20.70430946], [70.97207642, 20.7040329], [70.9715271, 20.7040329], [70.9715271, 20.70430946], [70.9706955, 20.70430565], [70.9706955, 20.70458412], [70.97041321, 20.70458031], [70.97041321, 20.70486259], [70.96985626, 20.70486259], [70.96985626, 20.70541954], [70.97013855, 20.70541573], [70.97013855, 20.7056942], [70.97041321, 20.70569038], [70.97041321, 20.70681], [70.97013855, 20.70680618], [70.97013855, 20.70708466], [70.96736145, 20.70708466], [70.96736145, 20.70680618], [70.96679687, 20.70681], [70.96679687, 20.70652962], [70.96624756, 20.70652962], [70.96624756, 20.70625114], [70.9659729, 20.70625114], [70.9659729, 20.70597267], [70.96569824, 20.70597267], [70.96569061, 20.7056942], [70.96541595, 20.7056942], [70.96541595, 20.70541763], [70.9640274, 20.70541763], [70.9640274, 20.7056942], [70.96235657, 20.70569038], [70.96235657, 20.70625114], [70.9615097, 20.70625114], [70.9615097, 20.70652962], [70.9604187, 20.70652962], [70.9604187, 20.70681], [70.96013641, 20.70681], [70.96013641, 20.70625114], [70.95986176, 20.70625114], [70.95986176, 20.70597267], [70.95903015, 20.70597267], [70.95903015, 20.7056942], [70.95791626, 20.7056942], [70.95791626, 20.70541763], [70.95774841, 20.70541573], [70.9576416, 20.70541954], [70.9576416, 20.70514107], [70.95735931, 20.70514107], [70.95735931, 20.70486259], [70.95680237, 20.70486259], [70.95680237, 20.70458031], [70.95625305, 20.70458412], [70.95625305, 20.70430565], [70.95597076, 20.70430946], [70.95597076, 20.7040329], [70.95540619, 20.7040329], [70.95540619, 20.70375252], [70.95181274, 20.70375252], [70.95181274, 20.7040329], [70.95096588, 20.7040329], [70.95096588, 20.70430946], [70.95041656, 20.70430565], [70.95041656, 20.70458412], [70.94985962, 20.70458031], [70.94985962, 20.70486259], [70.94875336, 20.70486259], [70.94875336, 20.70514107], [70.94763947, 20.70514107], [70.94763947, 20.70541954], [70.94596863, 20.70541763], [70.94596863, 20.7056942], [70.94374847, 20.7056942], [70.94374847, 20.70597267], [70.94319153, 20.70597267], [70.94319153, 20.70625114], [70.94235992, 20.70625114], [70.94235992, 20.70652962], [70.94152832, 20.70652962], [70.94152832, 20.70681], [70.94097137, 20.70680618], [70.94097137, 20.70708466], [70.93930817, 20.70708275], [70.93930817, 20.70736122], [70.93902588, 20.70736122], [70.93902588, 20.70763969], [70.93875122, 20.70763969], [70.93875122, 20.70792007], [70.93846893, 20.70791626], [70.93846893, 20.70819473], [70.93791962, 20.70819092], [70.93791962, 20.70903015], [70.93763733, 20.70902824], [70.93763733, 20.70930672], [70.93736267, 20.70930672], [70.93736267, 20.70958328], [70.93708038, 20.70958328], [70.93708038, 20.70986176], [70.93653107, 20.70985985], [70.93653107, 20.71014023], [70.93596649, 20.71014023], [70.93596649, 20.71042061], [70.93541718, 20.71042061], [70.93541718, 20.71070099], [70.93458557, 20.71069527], [70.93458557, 20.71097183], [70.9329071, 20.71096992], [70.93291473, 20.71125031], [70.9318161, 20.71125031], [70.9318161, 20.71153069], [70.92930603, 20.71153069], [70.92930603, 20.71181107], [70.92514038, 20.71181107], [70.92514038, 20.71153069], [70.92346954, 20.71153069], [70.92346954, 20.71125031], [70.92263031, 20.71125031], [70.92263031, 20.71096992], [70.92180634, 20.71097183], [70.92180634, 20.71069527], [70.92041779, 20.71070099], [70.92041779, 20.71042061], [70.91929626, 20.71042061], [70.91929626, 20.71014023], [70.91874695, 20.71014023], [70.91874695, 20.70985985], [70.91847229, 20.70986176], [70.91847229, 20.70958328], [70.91764069, 20.70958328], [70.91764069, 20.70930672], [70.9173584, 20.70930672], [70.9173584, 20.70874977], [70.91707611, 20.70874977], [70.91707611, 20.70845985], [70.91652679, 20.7084713], [70.91652679, 20.70819473], [70.91625214, 20.70819473], [70.91625214, 20.70763969], [70.91596985, 20.70763969], [70.91596985, 20.70652962], [70.91570282, 20.70652962], [70.91570282, 20.70569038], [70.9154129, 20.7056942], [70.9154129, 20.70486259], [70.91570282, 20.70486259], [70.91569519, 20.70347023], [70.91596985, 20.70347023], [70.91596985, 20.70263863], [70.91625214, 20.70265007], [70.91625214, 20.70235825], [70.91819763, 20.70235825], [70.91819763, 20.70207977], [70.91791534, 20.70208359], [70.91791534, 20.70153046], [70.91707611, 20.70153046], [70.91707611, 20.70124817], [70.91652679, 20.70124817], [70.91652679, 20.7009697], [70.91569519, 20.7009716], [70.91569519, 20.70069504], [70.9154129, 20.70070076], [70.9154129, 20.70042038], [70.91513824, 20.70042038], [70.91513824, 20.70013809], [70.91485596, 20.70013809], [70.91485596, 20.69985962], [70.91430664, 20.69986153], [70.91430664, 20.69958305], [70.91401672, 20.69959068], [70.91401672, 20.69902992], [70.9126358, 20.69902992], [70.9126358, 20.6993103], [70.91179657, 20.6993103], [70.91179657, 20.70042038], [70.91152954, 20.70041656], [70.91152954, 20.70152092], [70.91152954, 20.70181084], [70.9106369, 20.70181084], [70.91014099, 20.70181084], [70.91014099, 20.70153046], [70.9098587, 20.70153046], [70.9098587, 20.7009697], [70.90930176, 20.7009716], [70.90930176, 20.70069504], [70.90764618, 20.70070076], [70.90764618, 20.70042038], [70.90735626, 20.70042038], [70.90735626, 20.70070076], [70.90625, 20.70070076], [70.90625, 20.70042038], [70.90513611, 20.70042038], [70.90513611, 20.70013809], [70.9034729, 20.70013809], [70.9034729, 20.69985962], [70.9026413, 20.69986153], [70.9026413, 20.69958305], [70.90151978, 20.69959068], [70.90151978, 20.6993103], [70.90125275, 20.6993103], [70.90125275, 20.69902992], [70.90013885, 20.69902992], [70.90013885, 20.69874954], [70.89930725, 20.69874954], [70.89930725, 20.69902992], [70.89901733, 20.69902992], [70.89901733, 20.6993103], [70.89875031, 20.6993103], [70.89875031, 20.69959068], [70.89847565, 20.69958305], [70.89847565, 20.69986153], [70.8979187, 20.69985962], [70.8979187, 20.70013809], [70.89736176, 20.70013809], [70.89736176, 20.70042038], [70.8970871, 20.70041656], [70.8970871, 20.7009716], [70.89736176, 20.7009697], [70.89736176, 20.70124817], [70.89763641, 20.70124817], [70.89763641, 20.70208359], [70.8979187, 20.70207977], [70.8979187, 20.70375252], [70.89763641, 20.70375252], [70.89763641, 20.70430946], [70.89736176, 20.70430946], [70.89736176, 20.70486259], [70.89653015, 20.70486259], [70.89653015, 20.70514107], [70.89624786, 20.70513916], [70.89624786, 20.7056942], [70.89597321, 20.7056942], [70.89597321, 20.70597267], [70.89576721, 20.70597267], [70.89541626, 20.70597267], [70.89541626, 20.70625114], [70.8951416, 20.70625114], [70.8951416, 20.70652962], [70.89485931, 20.70652962], [70.89485931, 20.70681], [70.89458466, 20.70680618], [70.89458466, 20.70708466], [70.89430237, 20.70708275], [70.89430237, 20.70736122], [70.89375305, 20.70736122], [70.89375305, 20.70763969], [70.89290619, 20.70763969], [70.89290619, 20.70792007], [70.89208221, 20.70791626], [70.89208221, 20.70819092], [70.89295959, 20.71302032], [70.89689636, 20.72000122], [70.89965057, 20.7238903], [70.90487671, 20.72652817], [70.92093658, 20.72891045], [70.92965698, 20.73192024], [70.93403625, 20.73595047], [70.93889618, 20.73648834], [70.94854736, 20.73374176], [70.96203613, 20.7292099], [70.96263885, 20.72938156]]]]}}, {\\\"id\\\": \\\"8\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.10_1\\\", \\\"HASC_1\\\": \\\"IN.GA\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Goa\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"G\\\\u00f4a\\\", \\\"apm25_popweighted\\\": 71.2, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1839.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 768.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2607.0, \\\"geo-id\\\": 8, \\\"hpm25_child_popweighted\\\": 66.9, \\\"hpm25_female_popweighted\\\": 76.9, \\\"hpm25_male_popweighted\\\": 55.4, \\\"location\\\": \\\"Goa\\\", \\\"mort_apm25_6cod_mean_total\\\": 781.0, \\\"mort_hpm25_6cod_mean_total\\\": 325.0, \\\"mort_tpm25_6cod_mean_total\\\": 1105.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[73.77986145, 15.3554163], [73.77986145, 15.35569382], [73.78180695, 15.35569382], [73.78180695, 15.3554163], [73.78235626, 15.35542011], [73.78235626, 15.35513973], [73.78291321, 15.35513973], [73.78291321, 15.35486031], [73.7831955, 15.35486221], [73.7831955, 15.35458374], [73.78347015, 15.35458374], [73.78347015, 15.35430622], [73.78375244, 15.35430622], [73.78375244, 15.35402775], [73.7840271, 15.35402966], [73.7840271, 15.35375023], [73.78430176, 15.35375023], [73.78430939, 15.35346889], [73.78458405, 15.35347176], [73.78458405, 15.35236168], [73.78486633, 15.35236168], [73.7848587, 15.35152817], [73.78457642, 15.35153198], [73.78457642, 15.35124016], [73.78430939, 15.35124874], [73.78430176, 15.35097122], [73.78375244, 15.35097122], [73.78375244, 15.35069561], [73.78347015, 15.35069561], [73.78347015, 15.35041809], [73.78320313, 15.35042], [73.78320313, 15.34958076], [73.78291321, 15.34958267], [73.78291321, 15.34930515], [73.78320313, 15.34930992], [73.78320313, 15.34902954], [73.78291321, 15.34902954], [73.78291321, 15.34875202], [73.7820816, 15.34875202], [73.7820816, 15.34847069], [73.78125, 15.34847069], [73.78125, 15.34875202], [73.78013611, 15.34875202], [73.78013611, 15.34902954], [73.77986145, 15.34902668], [73.77986145, 15.34986115], [73.78013611, 15.34985924], [73.78013611, 15.35042], [73.77986145, 15.35041809], [73.77986145, 15.35069561], [73.77958679, 15.35069561], [73.77958679, 15.35097122], [73.7784729, 15.35097122], [73.7784729, 15.35069561], [73.7776413, 15.35069561], [73.7776413, 15.35041809], [73.77707672, 15.35042], [73.77707672, 15.35013962], [73.77625275, 15.35013962], [73.77625275, 15.34985924], [73.77597046, 15.34985924], [73.77597046, 15.35013962], [73.77375031, 15.35013962], [73.77375031, 15.35042], [73.77319336, 15.35042], [73.77319336, 15.35013962], [73.77236176, 15.35013962], [73.77236176, 15.34985924], [73.77153015, 15.34985924], [73.77153015, 15.35013962], [73.77097321, 15.35013962], [73.77097321, 15.35042], [73.7701416, 15.35041809], [73.7701416, 15.35069561], [73.76958466, 15.35069561], [73.76958466, 15.35097122], [73.76875305, 15.35097122], [73.76875305, 15.35124874], [73.76763916, 15.35124874], [73.76763916, 15.35097122], [73.7673645, 15.35097122], [73.7673645, 15.35069561], [73.76708221, 15.35069561], [73.76708221, 15.35041809], [73.7665329, 15.35042], [73.7665329, 15.35013962], [73.76597595, 15.35013962], [73.76597595, 15.34985924], [73.76486206, 15.34985924], [73.76486206, 15.35013962], [73.76431274, 15.35013962], [73.76431274, 15.35042], [73.76319122, 15.35041809], [73.76319122, 15.35069561], [73.76264191, 15.35069561], [73.76264191, 15.35097122], [73.76235962, 15.35097122], [73.76235962, 15.35124874], [73.76180267, 15.35124016], [73.76180267, 15.35153198], [73.76125336, 15.35153198], [73.76125336, 15.35181046], [73.76097107, 15.35180569], [73.76097107, 15.35208416], [73.76069641, 15.3520813], [73.76069641, 15.35402966], [73.76097107, 15.35402775], [73.76097107, 15.35430622], [73.76125336, 15.35430622], [73.76125336, 15.35458374], [73.76180267, 15.35458374], [73.76180267, 15.35486221], [73.76207733, 15.35486031], [73.76207733, 15.35513973], [73.76291656, 15.35513973], [73.76291656, 15.35486031], [73.76347351, 15.35486221], [73.76347351, 15.35458374], [73.76403046, 15.35458374], [73.76403046, 15.35430622], [73.76430511, 15.35430622], [73.76430511, 15.35402775], [73.76457977, 15.35402966], [73.76457977, 15.35375023], [73.76486206, 15.35375023], [73.76486206, 15.35346889], [73.76513672, 15.35347176], [73.76513672, 15.35319424], [73.76541901, 15.35319424], [73.76541901, 15.35264015], [73.76568604, 15.35264015], [73.76568604, 15.35236168], [73.76679993, 15.35236168], [73.76679993, 15.35264015], [73.76790619, 15.35264015], [73.76790619, 15.35291958], [73.76957703, 15.35291958], [73.76957703, 15.35264015], [73.76986694, 15.35264015], [73.76986694, 15.35291958], [73.77124786, 15.35291767], [73.77124786, 15.35319424], [73.7720871, 15.35319424], [73.7720871, 15.35347176], [73.7729187, 15.35347176], [73.7729187, 15.35375023], [73.77401733, 15.35375023], [73.77401733, 15.35402966], [73.77458191, 15.35402775], [73.77458191, 15.35430622], [73.77735901, 15.35430622], [73.77735901, 15.35458374], [73.77791595, 15.35458374], [73.77791595, 15.35486221], [73.77873993, 15.35486031], [73.77873993, 15.35513973], [73.77929688, 15.35513973], [73.77929688, 15.35542011], [73.77986145, 15.3554163]]], [[[73.79458618, 15.37875175], [73.79458618, 15.37903023], [73.79651642, 15.37903023], [73.79651642, 15.37875175], [73.79736328, 15.37875175], [73.79736328, 15.37847137], [73.79846954, 15.37847137], [73.79846954, 15.37819576], [73.79930878, 15.37819576], [73.79930878, 15.37763977], [73.79902649, 15.37764168], [73.79902649, 15.37569141], [73.79875183, 15.37569332], [73.79875183, 15.37430477], [73.79846954, 15.37430954], [73.79846954, 15.37403202], [73.79818726, 15.37403202], [73.79818726, 15.37375069], [73.79792023, 15.37375069], [73.79792023, 15.37347126], [73.79763794, 15.37347317], [73.79763794, 15.37319469], [73.79736328, 15.37319469], [73.79736328, 15.3726387], [73.79651642, 15.37264061], [73.79651642, 15.37236977], [73.79624939, 15.37236977], [73.79624939, 15.37264061], [73.79569244, 15.37264061], [73.79569244, 15.37292194], [73.7951355, 15.37291718], [73.7951355, 15.37319469], [73.79486084, 15.37319469], [73.79486084, 15.37347317], [73.79458618, 15.37347126], [73.79458618, 15.37375069], [73.79429626, 15.37375069], [73.79429626, 15.37403202], [73.79403687, 15.37403202], [73.79403687, 15.37430954], [73.79374695, 15.37430477], [73.79374695, 15.37458324], [73.79292297, 15.37458134], [73.79292297, 15.37513924], [73.79264069, 15.37513924], [73.79264069, 15.37681007], [73.79292297, 15.37681007], [73.79292297, 15.37764168], [73.79319763, 15.37763977], [73.79319763, 15.37819576], [73.79347229, 15.37819576], [73.79347229, 15.37847137], [73.79403687, 15.37847137], [73.79403687, 15.37875175], [73.79458618, 15.37875175]]], [[[74.04650879, 14.96652889], [74.04624939, 14.96652889], [74.04624939, 14.96708298], [74.0459671, 14.96708107], [74.0459671, 14.96791935], [74.04569244, 14.96791935], [74.04569244, 14.96875095], [74.04541779, 14.96874905], [74.04541779, 14.96958256], [74.04514313, 14.96958065], [74.04514313, 14.97042179], [74.04486084, 14.97042179], [74.04486084, 14.97125053], [74.04458618, 14.97125053], [74.04458618, 14.97181034], [74.04430389, 14.97180462], [74.04430389, 14.97236061], [74.04292297, 14.97236061], [74.04292297, 14.97430992], [74.04319763, 14.97430992], [74.04319763, 14.97653008], [74.04292297, 14.97653008], [74.04292297, 14.97681046], [74.04264069, 14.97680569], [74.04264069, 14.97708416], [74.0423584, 14.9770813], [74.0423584, 14.97764015], [74.04207611, 14.97764015], [74.04207611, 14.97875023], [74.04180908, 14.97875023], [74.04180908, 14.97902966], [74.04152679, 14.97902775], [74.04152679, 14.97958374], [74.04125214, 14.97958374], [74.04125214, 14.97986221], [74.04096985, 14.97986031], [74.04096985, 14.98013973], [74.04069519, 14.98013783], [74.04069519, 14.98069382], [74.0404129, 14.98069382], [74.0404129, 14.98097229], [74.04013824, 14.98096085], [74.04013824, 14.98124981], [74.03985596, 14.98124981], [74.03985596, 14.98153019], [74.0395813, 14.98153019], [74.0395813, 14.98181057], [74.03874969, 14.9818058], [74.03874969, 14.98208427], [74.03708649, 14.98208046], [74.03708649, 14.98236179], [74.0359726, 14.98236179], [74.0359726, 14.98264027], [74.03542328, 14.98264027], [74.03542328, 14.98236179], [74.0348587, 14.98236179], [74.0348587, 14.98264027], [74.03430939, 14.98264027], [74.03430939, 14.98375034], [74.03456879, 14.98375034], [74.03456879, 14.9843111], [74.03514099, 14.98430634], [74.03514099, 14.98458195], [74.03736115, 14.98458195], [74.03736115, 14.98486233], [74.03791809, 14.98486042], [74.03791809, 14.98514271], [74.03819275, 14.98514271], [74.03819275, 14.98542118], [74.03901672, 14.98542118], [74.03901672, 14.98486042], [74.03930664, 14.98486233], [74.03930664, 14.98430634], [74.03985596, 14.9843111], [74.03985596, 14.98403072], [74.04125214, 14.98403072], [74.04125214, 14.9843111], [74.04180908, 14.98430634], [74.04180908, 14.98458195], [74.04207611, 14.98458195], [74.04207611, 14.98514271], [74.04264069, 14.98514271], [74.04264069, 14.98542118], [74.04291534, 14.98541641], [74.04291534, 14.98569393], [74.04347229, 14.98569393], [74.04347229, 14.9859724], [74.04376221, 14.98596954], [74.04376221, 14.98709106], [74.04402924, 14.98708153], [74.04402924, 14.98847294], [74.0451355, 14.98847294], [74.0451355, 14.98819542], [74.04569244, 14.98819542], [74.04569244, 14.98791599], [74.0463028, 14.98791599], [74.04650879, 14.98792076], [74.04651642, 14.98779964], [74.04652405, 14.98763847], [74.04685974, 14.98763847], [74.04708099, 14.98764133], [74.04708099, 14.98753071], [74.04708099, 14.98736], [74.04741669, 14.98736], [74.04792023, 14.98736], [74.04794312, 14.98709106], [74.04846954, 14.98709106], [74.04849243, 14.98681068], [74.04930878, 14.98681068], [74.04930878, 14.98653126], [74.04985809, 14.98653126], [74.04985809, 14.98792076], [74.05014038, 14.98791599], [74.05014038, 14.98819542], [74.04985809, 14.98819542], [74.04985809, 14.98847294], [74.04930878, 14.98847294], [74.04930878, 14.98819542], [74.04846954, 14.98819542], [74.04846954, 14.98847294], [74.04792023, 14.98847008], [74.04792023, 14.98875141], [74.04708099, 14.98875141], [74.04708099, 14.98903084], [74.04650879, 14.98903084], [74.04650879, 14.98931122], [74.04416656, 14.98930359], [74.04402924, 14.98931122], [74.04402924, 14.98903084], [74.04292297, 14.98903084], [74.04292297, 14.98875141], [74.04069519, 14.98875141], [74.04069519, 14.98819542], [74.0404129, 14.98819542], [74.0404129, 14.98791599], [74.03985596, 14.98792076], [74.03985596, 14.98736], [74.0395813, 14.98736], [74.0395813, 14.98681068], [74.03930664, 14.98681068], [74.03930664, 14.98653126], [74.03901672, 14.98653126], [74.03901672, 14.98596954], [74.03848267, 14.98596954], [74.03848267, 14.98624992], [74.03819275, 14.98624992], [74.03819275, 14.98653126], [74.03791809, 14.98653126], [74.03791809, 14.98875141], [74.03762817, 14.98875141], [74.03762817, 14.98931122], [74.03736115, 14.98930359], [74.03736115, 14.98986053], [74.03708649, 14.98986053], [74.03708649, 14.990695], [74.03679657, 14.99069023], [74.03679657, 14.99125099], [74.03652954, 14.99125099], [74.03652954, 14.99181175], [74.03624725, 14.99181175], [74.03624725, 14.99236107], [74.0359726, 14.99236107], [74.0359726, 14.99292088], [74.03569794, 14.99291706], [74.03569794, 14.99319458], [74.03542328, 14.9931879], [74.03542328, 14.99375057], [74.03514099, 14.99375057], [74.03514099, 14.99403095], [74.0348587, 14.99402905], [74.0348587, 14.99458313], [74.03458405, 14.99458313], [74.03458405, 14.99569511], [74.03430939, 14.9956913], [74.03430176, 14.99625111], [74.0340271, 14.99625111], [74.0340271, 14.99681187], [74.03375244, 14.99680519], [74.03375244, 14.99736118], [74.03347015, 14.99736118], [74.03347015, 14.99752998], [74.03347015, 14.99792194], [74.0331955, 14.99791718], [74.0331955, 14.99847126], [74.03291321, 14.99847126], [74.03291321, 14.99903202], [74.03276062, 14.99903011], [74.03235626, 14.99903202], [74.03235626, 14.99932098], [74.03152466, 14.99930477], [74.03152466, 14.99958324], [74.03013611, 14.99958324], [74.03013611, 14.99930477], [74.02929688, 14.99932098], [74.02929688, 14.99903202], [74.02876282, 14.99903202], [74.02876282, 14.99875069], [74.0284729, 14.99875069], [74.0284729, 14.99847126], [74.02819824, 14.99847126], [74.02819061, 14.99819469], [74.02791595, 14.99819469], [74.02791595, 14.99791718], [74.02680206, 14.99791718], [74.02680206, 14.99847126], [74.0265274, 14.99847126], [74.0265274, 14.99875069], [74.02680206, 14.99875069], [74.02680206, 14.99903202], [74.02707672, 14.99903202], [74.02707672, 14.99932098], [74.0276413, 14.99930477], [74.0276413, 14.99958324], [74.02819824, 14.99958134], [74.02819824, 14.99986076], [74.02876282, 14.99986076], [74.02876282, 15.00013924], [74.02902985, 15.00013924], [74.02902985, 15.00041962], [74.02929688, 15.00041962], [74.02929688, 15.00097084], [74.02986145, 15.00097084], [74.02986145, 15.00124931], [74.02958679, 15.00124931], [74.02958679, 15.00185108], [74.02958679, 15.00208378], [74.02932739, 15.00208378], [74.02874756, 15.00208378], [74.02874756, 15.00180626], [74.0284729, 15.00181007], [74.0284729, 15.00152969], [74.02819824, 15.00152683], [74.02819824, 15.00236225], [74.0276413, 15.00235939], [74.0276413, 15.00263977], [74.02707672, 15.00263977], [74.02707672, 15.00235939], [74.02680206, 15.00236225], [74.02680206, 15.00208378], [74.0265274, 15.00208378], [74.0265274, 15.00180626], [74.02597046, 15.00181007], [74.02597046, 15.00097084], [74.02568817, 15.00097084], [74.02568817, 15.00069141], [74.02541351, 15.00069332], [74.02541351, 15.00236225], [74.02513885, 15.00235939], [74.02513885, 15.00263977], [74.02458191, 15.00263977], [74.02458191, 15.00292015], [74.02430725, 15.00291538], [74.02430725, 15.00347233], [74.02485657, 15.00346947], [74.02485657, 15.00375175], [74.02539825, 15.00375175], [74.02539825, 15.00346947], [74.02597046, 15.00346947], [74.02597046, 15.00375175], [74.02625275, 15.00375175], [74.02625275, 15.00403023], [74.0265274, 15.00402832], [74.0265274, 15.00434017], [74.0265274, 15.0051384], [74.02680206, 15.0051403], [74.02680206, 15.00569439], [74.02707672, 15.00569057], [74.02707672, 15.00652981], [74.02680206, 15.00652981], [74.02680206, 15.00681114], [74.0265274, 15.00680637], [74.0265274, 15.00736237], [74.02597046, 15.00736046], [74.02597046, 15.00792027], [74.0256958, 15.00791645], [74.0256958, 15.00847244], [74.02539825, 15.00846958], [74.02539825, 15.00874996], [74.02513885, 15.00874996], [74.02513885, 15.00903034], [74.02485657, 15.00903034], [74.02485657, 15.00931072], [74.02430725, 15.00930595], [74.02430725, 15.00958443], [74.02402496, 15.00958443], [74.02402496, 15.00986004], [74.02348328, 15.00986004], [74.02348328, 15.01014042], [74.02319336, 15.01014042], [74.02319336, 15.0104208], [74.0229187, 15.01041603], [74.0229187, 15.01069355], [74.02263641, 15.01069355], [74.02263641, 15.01097202], [74.0220871, 15.01097012], [74.0220871, 15.01126194], [74.02179718, 15.01126194], [74.02179718, 15.01153088], [74.02124786, 15.01153088], [74.02124786, 15.01181126], [74.02097321, 15.01180553], [74.02097321, 15.0120821], [74.01875305, 15.0120821], [74.01875305, 15.01236153], [74.01735687, 15.01235962], [74.01735687, 15.01264095], [74.01680756, 15.01263809], [74.01680756, 15.01319408], [74.01708221, 15.01319408], [74.01708221, 15.0134716], [74.01735687, 15.0134697], [74.01735687, 15.01375008], [74.01763916, 15.01375008], [74.01763916, 15.01403141], [74.01625061, 15.01403141], [74.01625061, 15.01375008], [74.01597595, 15.01375008], [74.01597595, 15.0134697], [74.01569366, 15.0134716], [74.01569366, 15.01291561], [74.01541901, 15.01292133], [74.01541901, 15.01264095], [74.01486206, 15.01264095], [74.01486206, 15.01208019], [74.01457977, 15.0120821], [74.01457977, 15.01152802], [74.01431274, 15.01153088], [74.01431274, 15.01068974], [74.01374817, 15.01069355], [74.01374817, 15.01013756], [74.01345825, 15.01014042], [74.01345825, 15.00986004], [74.01374817, 15.00986004], [74.01374817, 15.00957966], [74.01403046, 15.00958443], [74.01403046, 15.00930595], [74.01431274, 15.00931072], [74.01431274, 15.00652981], [74.01374817, 15.00652981], [74.01374817, 15.00681114], [74.01347351, 15.00680637], [74.01347351, 15.00708389], [74.01235962, 15.00708199], [74.01235962, 15.00764179], [74.01209259, 15.00764179], [74.01209259, 15.00792027], [74.01180267, 15.00791645], [74.01180267, 15.00847244], [74.01152802, 15.00846958], [74.01152802, 15.00931072], [74.01180267, 15.00930595], [74.01180267, 15.00958443], [74.01235962, 15.00957966], [74.01235962, 15.00986004], [74.01291656, 15.00986004], [74.01291656, 15.0104208], [74.01235962, 15.0104208], [74.01235962, 15.01153088], [74.01208496, 15.01152802], [74.01208496, 15.01236153], [74.01180267, 15.01235962], [74.01180267, 15.01264095], [74.01125336, 15.01264095], [74.01125336, 15.01292133], [74.01069641, 15.01291561], [74.01069641, 15.01319408], [74.01041412, 15.01319408], [74.01041412, 15.0134716], [74.00985718, 15.0134697], [74.00985718, 15.01375008], [74.00930786, 15.01375008], [74.00930786, 15.01403141], [74.0090332, 15.01403141], [74.0090332, 15.01432037], [74.00846863, 15.01430416], [74.00846863, 15.01458454], [74.00819397, 15.01458454], [74.00819397, 15.01569462], [74.00791931, 15.01568985], [74.00791931, 15.01625061], [74.00765228, 15.01625061], [74.00765228, 15.01681137], [74.00736237, 15.01681137], [74.00736237, 15.01792145], [74.00624847, 15.01792145], [74.00624847, 15.01764107], [74.00596619, 15.01764107], [74.00596619, 15.01736069], [74.00569153, 15.01736069], [74.00569153, 15.01707077], [74.00541687, 15.01708317], [74.00541687, 15.01652908], [74.00514221, 15.01653099], [74.00514221, 15.01597023], [74.00485992, 15.01597023], [74.00485992, 15.01625061], [74.00319672, 15.01625061], [74.00319672, 15.01653099], [74.00263977, 15.01653099], [74.00263977, 15.01792145], [74.00235748, 15.01791668], [74.00235748, 15.01819515], [74.00180817, 15.01819515], [74.00180817, 15.01847267], [74.00151825, 15.01847076], [74.00151825, 15.01875114], [74.00068665, 15.01875114], [74.00068665, 15.01847076], [74.00069427, 15.01819515], [73.99997711, 15.01819515], [73.99964142, 15.01819515], [73.99903107, 15.01819515], [73.99903107, 15.01847267], [73.99874878, 15.01847267], [73.99874878, 15.01867104], [73.99874878, 15.0193119], [73.99819183, 15.0193119], [73.99819183, 15.02042198], [73.99791718, 15.02041721], [73.99791718, 15.02069473], [73.99764252, 15.02068996], [73.99764252, 15.02125072], [73.99680328, 15.02125072], [73.99680328, 15.02042198], [73.99652863, 15.02042198], [73.99652863, 15.01970959], [73.99652863, 15.01958275], [73.99597168, 15.01958275], [73.99597168, 15.01930523], [73.99571228, 15.0193119], [73.99571228, 15.01903057], [73.99485779, 15.01903057], [73.99485779, 15.01875114], [73.99458313, 15.01875114], [73.99458313, 15.01903057], [73.99430847, 15.01903057], [73.99430847, 15.01875114], [73.99346924, 15.01875114], [73.99346924, 15.01847076], [73.99291992, 15.01847267], [73.99291992, 15.01819515], [73.99236298, 15.01819515], [73.99236298, 15.01791668], [73.99208069, 15.01791668], [73.99208069, 15.01819515], [73.99180603, 15.01819515], [73.99180603, 15.01847267], [73.99124908, 15.01847076], [73.99124908, 15.01875114], [73.9909668, 15.01875114], [73.9909668, 15.01903057], [73.99069214, 15.01902676], [73.99069214, 15.01958275], [73.99013519, 15.01958275], [73.99013519, 15.01986122], [73.98957825, 15.01986122], [73.98957825, 15.02014065], [73.98902893, 15.02014065], [73.98902893, 15.02042198], [73.98874664, 15.02042198], [73.98874664, 15.0215292], [73.98847198, 15.0215292], [73.98847198, 15.02320194], [73.98819733, 15.02320194], [73.98819733, 15.02375126], [73.98764038, 15.02375126], [73.98764038, 15.02403164], [73.98735809, 15.02403164], [73.98735809, 15.02431202], [73.98680878, 15.02430534], [73.98680878, 15.02458286], [73.98625183, 15.02458286], [73.98625183, 15.02486134], [73.98596954, 15.02486134], [73.98596954, 15.02514172], [73.98542023, 15.02514172], [73.98542023, 15.02680969], [73.98569489, 15.02680492], [73.98569489, 15.02819347], [73.98542023, 15.02819061], [73.98542023, 15.02903175], [73.98596954, 15.02902794], [73.98596954, 15.02958393], [73.98652649, 15.02958393], [73.98652649, 15.0298624], [73.98680878, 15.02985859], [73.98680878, 15.03013992], [73.98735809, 15.03013992], [73.98735809, 15.0304203], [73.98764038, 15.0304203], [73.98764038, 15.03013992], [73.98847198, 15.03013992], [73.98847198, 15.0304203], [73.98902893, 15.03041553], [73.98902893, 15.03069401], [73.98929596, 15.03069115], [73.98929596, 15.03180981], [73.98957825, 15.03180981], [73.98957825, 15.03264046], [73.98986053, 15.0326376], [73.98986053, 15.03347206], [73.99014282, 15.03347015], [73.99014282, 15.03431129], [73.98986053, 15.03430557], [73.98986053, 15.03486156], [73.98957825, 15.03485966], [73.98957825, 15.03625011], [73.98929596, 15.03625011], [73.98929596, 15.03652954], [73.98902893, 15.03652954], [73.98902893, 15.03681087], [73.98874664, 15.03680611], [73.98874664, 15.03736019], [73.98847198, 15.03736019], [73.98847198, 15.03820133], [73.98819733, 15.03820133], [73.98819733, 15.03903103], [73.98792267, 15.03903103], [73.98792267, 15.03931141], [73.98764038, 15.03930569], [73.98764038, 15.03958225], [73.98792267, 15.03958035], [73.98792267, 15.04014111], [73.98764038, 15.04013824], [73.98764038, 15.04069424], [73.98735809, 15.04069424], [73.98735809, 15.04125118], [73.98707581, 15.04124069], [73.98707581, 15.04181099], [73.98680878, 15.04181099], [73.98680878, 15.04264069], [73.98652649, 15.04263878], [73.98652649, 15.04319477], [73.98625183, 15.04319], [73.98625183, 15.04375076], [73.98596954, 15.04375076], [73.98596954, 15.04430676], [73.98569489, 15.04430676], [73.98569489, 15.04458332], [73.98542023, 15.04458046], [73.98542023, 15.04542065], [73.98513794, 15.04542065], [73.98513794, 15.0462513], [73.98486328, 15.0462513], [73.98486328, 15.04653072], [73.98458099, 15.04652691], [73.98458099, 15.0470829], [73.98430634, 15.04708099], [73.98430634, 15.04763889], [73.98402405, 15.04763889], [73.98402405, 15.04819489], [73.98374939, 15.04819107], [73.98374939, 15.04875088], [73.98348236, 15.04875088], [73.98348236, 15.04930973], [73.98319244, 15.04930973], [73.98319244, 15.04986095], [73.98291779, 15.04986095], [73.98291779, 15.05014133], [73.98236084, 15.05013943], [73.98236084, 15.05069542], [73.98208618, 15.05069542], [73.98208618, 15.05097103], [73.98179626, 15.05097103], [73.98179626, 15.05125141], [73.98152924, 15.05125141], [73.98152924, 15.05153179], [73.98097229, 15.05153179], [73.98097229, 15.05181026], [73.98041534, 15.05180454], [73.98041534, 15.05209923], [73.98041534, 15.05236053], [73.97921753, 15.05236053], [73.97819519, 15.05236053], [73.97819519, 15.05208302], [73.97763824, 15.05208302], [73.97763824, 15.05180454], [73.97735596, 15.05181026], [73.97735596, 15.05153179], [73.9770813, 15.05153179], [73.9770813, 15.05125141], [73.97651672, 15.05125141], [73.97651672, 15.05097103], [73.97624969, 15.05097103], [73.97624969, 15.05069542], [73.97569275, 15.05069542], [73.97569275, 15.05041695], [73.97458649, 15.05041695], [73.97458649, 15.05069542], [73.97402954, 15.05069542], [73.97402954, 15.05097103], [73.97264099, 15.05097103], [73.97264099, 15.05125141], [73.97207642, 15.05125141], [73.97207642, 15.05153179], [73.97180939, 15.05153179], [73.97180176, 15.05181026], [73.9715271, 15.05180454], [73.9715271, 15.05208302], [73.97125244, 15.05208302], [73.97125244, 15.05236053], [73.97097015, 15.05236053], [73.97097015, 15.05292034], [73.97070313, 15.05292034], [73.97070313, 15.05431175], [73.97097015, 15.05430508], [73.97097015, 15.0545826], [73.97125244, 15.05458069], [73.97125244, 15.05681038], [73.97097015, 15.05680561], [73.97097015, 15.05708408], [73.9706955, 15.05708408], [73.9706955, 15.0573616], [73.97041321, 15.0573616], [73.97041321, 15.05847168], [73.97013855, 15.05847168], [73.97013855, 15.05986214], [73.96985626, 15.05986023], [73.96985626, 15.06013966], [73.9695816, 15.06013966], [73.9695816, 15.06042004], [73.96902466, 15.06041622], [73.96902466, 15.06097221], [73.96875, 15.06097031], [73.96875, 15.06124973], [73.96848297, 15.06124973], [73.96848297, 15.06153011], [73.96763611, 15.06153011], [73.96763611, 15.06181145], [73.96736145, 15.06180573], [73.96736145, 15.0620842], [73.96679688, 15.06208038], [73.96679688, 15.06237125], [73.96624756, 15.06237125], [73.96624756, 15.06292057], [73.96652985, 15.0629158], [73.96652985, 15.06319427], [73.96679688, 15.06318855], [73.96679688, 15.06347179], [73.96708679, 15.06347179], [73.96708679, 15.06431103], [73.96736145, 15.06431103], [73.96736145, 15.06513977], [73.96708679, 15.06513786], [73.96708679, 15.06559181], [73.96708679, 15.06569386], [73.9668045, 15.06569386], [73.9668045, 15.06597233], [73.96627808, 15.06597233], [73.96458435, 15.06597233], [73.96458435, 15.06569386], [73.96430206, 15.06569386], [73.96430206, 15.06597233], [73.96375275, 15.06597042], [73.96375275, 15.06625271], [73.96347046, 15.06625271], [73.96347046, 15.06653118], [73.96290588, 15.06653118], [73.96290588, 15.06681061], [73.96234894, 15.06681061], [73.96234894, 15.06735992], [73.96208191, 15.06735992], [73.96208191, 15.06764126], [73.96153259, 15.06764126], [73.96153259, 15.06792068], [73.96125031, 15.06791592], [73.96125031, 15.06819439], [73.9604187, 15.06819439], [73.9604187, 15.06847286], [73.96013641, 15.06847], [73.96013641, 15.06875134], [73.95960236, 15.06875134], [73.95960236, 15.06903076], [73.95903015, 15.06902885], [73.95903015, 15.06958199], [73.95874786, 15.06958008], [73.95874786, 15.07014084], [73.9576416, 15.07014084], [73.9576416, 15.06986141], [73.95569611, 15.06986141], [73.95569611, 15.07014084], [73.95430756, 15.07014084], [73.95430756, 15.07042122], [73.95375061, 15.0704174], [73.95375061, 15.07069016], [73.95346832, 15.0707016], [73.95346832, 15.07154274], [73.95375061, 15.07154274], [73.95375061, 15.07181072], [73.9540329, 15.07181072], [73.9540329, 15.07264137], [73.95375061, 15.07264137], [73.95375061, 15.07291889], [73.95347595, 15.07291698], [73.95347595, 15.07319546], [73.95291901, 15.07319546], [73.95291901, 15.07347107], [73.95181274, 15.0734911], [73.95181274, 15.07375145], [73.95124817, 15.07375145], [73.95124817, 15.07403088], [73.95096588, 15.07403088], [73.95096588, 15.07430935], [73.95041656, 15.07430458], [73.95041656, 15.07458305], [73.95014191, 15.07458305], [73.95014191, 15.07486057], [73.94959259, 15.07486057], [73.94959259, 15.07514095], [73.94847107, 15.07514095], [73.94847107, 15.07541943], [73.94374847, 15.07541943], [73.94374847, 15.07514095], [73.94291687, 15.07514095], [73.94291687, 15.07487011], [73.94264221, 15.07486057], [73.94264221, 15.07514095], [73.94208527, 15.07513905], [73.94208527, 15.07486057], [73.94180298, 15.07486057], [73.94180298, 15.07514095], [73.94124603, 15.07514095], [73.94124603, 15.07541943], [73.94069672, 15.07541656], [73.94069672, 15.07569504], [73.94013977, 15.07569504], [73.94013977, 15.07541656], [73.93958282, 15.07541656], [73.93958282, 15.07569504], [73.93902588, 15.07569504], [73.93902588, 15.07597256], [73.93875122, 15.07597065], [73.93875122, 15.07625103], [73.93846893, 15.07625103], [73.93846893, 15.07653236], [73.93817902, 15.07653236], [73.93817902, 15.07681179], [73.93597412, 15.07680511], [73.93597412, 15.07708263], [73.93569183, 15.07708073], [73.93569183, 15.07764053], [73.93540955, 15.07764053], [73.93540955, 15.07792187], [73.93514252, 15.0779171], [73.93514252, 15.07819462], [73.93235779, 15.07819462], [73.93235779, 15.0779171], [73.93180847, 15.0779171], [73.93180847, 15.07819462], [73.93152618, 15.07819462], [73.93152618, 15.07847118], [73.93096924, 15.07847118], [73.93096924, 15.07903194], [73.93069458, 15.07902718], [73.93069458, 15.07958317], [73.93013763, 15.07958126], [73.93013763, 15.08014202], [73.92986298, 15.08013916], [73.92986298, 15.08041668], [73.92958069, 15.08041668], [73.92958069, 15.08069324], [73.92930603, 15.08069324], [73.92930603, 15.08097363], [73.92903137, 15.08097363], [73.92903137, 15.08121967], [73.92903137, 15.08152962], [73.92930603, 15.08152676], [73.92930603, 15.0820837], [73.92958069, 15.08208084], [73.92958069, 15.08263969], [73.92930603, 15.08263969], [73.92930603, 15.08348274], [73.92819214, 15.08348274], [73.92819214, 15.08375168], [73.92791748, 15.08375168], [73.92791748, 15.08348274], [73.92764282, 15.08348274], [73.92764282, 15.08375168], [73.92708588, 15.08375168], [73.92708588, 15.08430958], [73.92679596, 15.08430958], [73.92679596, 15.08486176], [73.92623901, 15.08486176], [73.92623901, 15.08541965], [73.92597198, 15.08541775], [73.92597198, 15.08569431], [73.92485809, 15.08569431], [73.92485809, 15.08597183], [73.92430878, 15.08597183], [73.92430878, 15.08569431], [73.92346954, 15.08569431], [73.92346954, 15.08541775], [73.92319489, 15.08541775], [73.92319489, 15.08569431], [73.92263794, 15.08569431], [73.92263794, 15.08597183], [73.92208099, 15.08597183], [73.92208099, 15.08569431], [73.92180634, 15.08569431], [73.92180634, 15.08514023], [73.92124939, 15.08514023], [73.92124939, 15.08458138], [73.9201355, 15.08458424], [73.9201355, 15.08430576], [73.91986084, 15.08430576], [73.91986084, 15.08458424], [73.91958618, 15.08458424], [73.91958618, 15.08430576], [73.91902924, 15.08430958], [73.91902924, 15.08403015], [73.91874695, 15.08403015], [73.91874695, 15.08375168], [73.91819763, 15.08375168], [73.91819763, 15.08348274], [73.91764069, 15.08348274], [73.91764069, 15.08319092], [73.9173584, 15.08319569], [73.9173584, 15.08291531], [73.91708374, 15.08291531], [73.91708374, 15.08319569], [73.91652679, 15.08319092], [73.91652679, 15.08403015], [73.91625214, 15.08403015], [73.91625214, 15.08430958], [73.91429901, 15.08430958], [73.91429901, 15.08403015], [73.9118042, 15.08402824], [73.9118042, 15.08458424], [73.91208649, 15.08458138], [73.91208649, 15.08541965], [73.91236115, 15.08541775], [73.91236115, 15.08569431], [73.9126358, 15.08569431], [73.9126358, 15.08597183], [73.91319275, 15.08597183], [73.91319275, 15.08625031], [73.91374969, 15.08625031], [73.91374969, 15.08653927], [73.91429901, 15.08653927], [73.91429901, 15.08681011], [73.91486359, 15.0868063], [73.91486359, 15.08708382], [73.91513824, 15.08708382], [73.91513824, 15.08736229], [73.9154129, 15.08736038], [73.9154129, 15.08763981], [73.91570282, 15.08763981], [73.91570282, 15.08792019], [73.91596985, 15.08791637], [73.91596985, 15.08819389], [73.91625214, 15.08819389], [73.91625214, 15.08847237], [73.91652679, 15.08847046], [73.91652679, 15.08875179], [73.91680908, 15.08875179], [73.91680908, 15.08903027], [73.91736603, 15.08903027], [73.91736603, 15.08931065], [73.91819763, 15.08930588], [73.91819763, 15.08958435], [73.91874695, 15.08957958], [73.91874695, 15.08985996], [73.91929626, 15.08985996], [73.91929626, 15.09014034], [73.91986084, 15.09014034], [73.91986084, 15.09042072], [73.9201355, 15.09041595], [73.9201355, 15.09069443], [73.92069244, 15.09069443], [73.92069244, 15.09097195], [73.9209671, 15.09097004], [73.9209671, 15.09125042], [73.92151642, 15.09125042], [73.92151642, 15.09153271], [73.92180634, 15.09153271], [73.92180634, 15.09181118], [73.92236328, 15.09180641], [73.92236328, 15.09208202], [73.92263794, 15.09208202], [73.92263794, 15.0923624], [73.92292023, 15.09235096], [73.92292023, 15.09263992], [73.92346954, 15.09263992], [73.92346954, 15.09292126], [73.92375183, 15.09292126], [73.92375183, 15.09375], [73.92402649, 15.09375], [73.92402649, 15.09458542], [73.92375183, 15.0945797], [73.92375183, 15.09486008], [73.92402649, 15.09486008], [73.92402649, 15.09514141], [73.92430878, 15.09514141], [73.92430878, 15.09542084], [73.92458344, 15.09541607], [73.92458344, 15.09569454], [73.92514038, 15.09569454], [73.92514038, 15.09597301], [73.92569733, 15.09597015], [73.92569733, 15.09625053], [73.92597198, 15.09625053], [73.92597198, 15.09681129], [73.92624664, 15.09680367], [73.92623901, 15.09913063], [73.92623901, 15.10014057], [73.92597198, 15.10013866], [73.92597198, 15.10097313], [73.92569733, 15.10097122], [73.92569733, 15.10180855], [73.92541504, 15.10180473], [73.92542267, 15.10236073], [73.92514038, 15.10236073], [73.92514038, 15.10319519], [73.92541504, 15.10319519], [73.92542267, 15.10375118], [73.92514038, 15.10375118], [73.92514038, 15.10431194], [73.92485809, 15.10430527], [73.92485809, 15.10458279], [73.92402649, 15.10458279], [73.92402649, 15.10486126], [73.92375183, 15.10486126], [73.92375183, 15.10514164], [73.92317963, 15.10514164], [73.92317963, 15.10542202], [73.92292023, 15.10541725], [73.92292023, 15.10569477], [73.92236328, 15.10569477], [73.92236328, 15.10597134], [73.92208099, 15.10597134], [73.92208099, 15.10625076], [73.92151642, 15.10625076], [73.92151642, 15.10736084], [73.92069244, 15.10736084], [73.92069244, 15.10708141], [73.92043304, 15.10708141], [73.92043304, 15.10736084], [73.91929626, 15.10736084], [73.91929626, 15.10708141], [73.91847229, 15.10708141], [73.91847229, 15.10736084], [73.91792297, 15.10736084], [73.91792297, 15.10763931], [73.91764069, 15.10763931], [73.91764069, 15.10791969], [73.9173584, 15.10791779], [73.9173584, 15.1081934], [73.91791534, 15.1081934], [73.91791534, 15.10847092], [73.91847229, 15.10847092], [73.91847229, 15.10874939], [73.9209671, 15.10874939], [73.9209671, 15.10902977], [73.92180634, 15.10902977], [73.92180634, 15.10931015], [73.92208099, 15.10930634], [73.92208099, 15.10958385], [73.92236328, 15.10958385], [73.92236328, 15.10986233], [73.92292023, 15.10985947], [73.92292023, 15.11014175], [73.92514038, 15.11014175], [73.92514038, 15.11042023], [73.92652893, 15.11041546], [73.92652893, 15.11069584], [73.92680359, 15.11069584], [73.92680359, 15.1109724], [73.92736053, 15.1109724], [73.92736053, 15.11125183], [73.92791748, 15.11125183], [73.92791748, 15.1115303], [73.92874908, 15.1115303], [73.92874908, 15.11180973], [73.92986298, 15.11180592], [73.92986298, 15.11208439], [73.93041992, 15.11208153], [73.93041992, 15.11236191], [73.93096924, 15.11236191], [73.93096924, 15.11264038], [73.93152618, 15.11264038], [73.93152618, 15.11291981], [73.93180847, 15.1129179], [73.93180847, 15.11319447], [73.93208313, 15.11319447], [73.93208313, 15.11347198], [73.93237305, 15.11345959], [73.93237305, 15.11375046], [73.93319702, 15.11375046], [73.93319702, 15.11345959], [73.93374634, 15.11347198], [73.93374634, 15.11319447], [73.93402863, 15.11319447], [73.93402863, 15.1129179], [73.93430328, 15.11291981], [73.93430328, 15.11264038], [73.9345932, 15.11264038], [73.9345932, 15.11236191], [73.93514252, 15.11236191], [73.93514252, 15.11264038], [73.93569183, 15.11263847], [73.93569183, 15.11319447], [73.93596649, 15.11319065], [73.93596649, 15.11431122], [73.93624878, 15.11431122], [73.93624878, 15.11625004], [73.93653107, 15.11625004], [73.93653107, 15.11652756], [73.93681335, 15.11652088], [73.93681335, 15.11763954], [73.93736267, 15.11763763], [73.93736267, 15.11819363], [73.93763733, 15.11819172], [73.93763733, 15.11874962], [73.93875122, 15.11874962], [73.93875122, 15.11903095], [73.93902588, 15.11903095], [73.93902588, 15.11931133], [73.93985748, 15.11930561], [73.93985748, 15.11958218], [73.9406662, 15.11958027], [73.94069672, 15.12153053], [73.94041443, 15.12152863], [73.94041443, 15.12208462], [73.93985748, 15.12208462], [73.93985748, 15.12458324], [73.93958282, 15.12458038], [73.93958282, 15.12597275], [73.93985748, 15.12597275], [73.93985748, 15.12653065], [73.94013977, 15.12652683], [73.94013977, 15.12708282], [73.9404068, 15.12708092], [73.9404068, 15.12764072], [73.94013977, 15.12764072], [73.94013977, 15.1279192], [73.93958282, 15.12791729], [73.93958282, 15.12819481], [73.93930817, 15.12819004], [73.93930817, 15.12874889], [73.93902588, 15.12874889], [73.93902588, 15.1293087], [73.93846893, 15.12930489], [73.93846893, 15.12958336], [73.93817902, 15.12958145], [73.93817902, 15.12986088], [73.93763733, 15.12986088], [73.93763733, 15.13014126], [73.93708038, 15.13013935], [73.93708038, 15.13152695], [73.93681335, 15.13152027], [73.93681335, 15.13181019], [73.93624878, 15.13181019], [73.93624878, 15.13152027], [73.93569183, 15.13152027], [73.93569183, 15.13181019], [73.93514252, 15.13180542], [73.93514252, 15.13236141], [73.93540955, 15.13236141], [73.93540955, 15.13292027], [73.93569183, 15.1329174], [73.93569183, 15.13319302], [73.93596649, 15.13319111], [73.93596649, 15.13375187], [73.93624878, 15.13375187], [73.93624878, 15.13403034], [73.93653107, 15.13403034], [73.93653107, 15.13430977], [73.93817902, 15.13430977], [73.93817902, 15.13459015], [73.93875122, 15.13459015], [73.93875122, 15.13486099], [73.93958282, 15.13486099], [73.93958282, 15.13514042], [73.94013977, 15.13514042], [73.94013977, 15.13542175], [73.94125366, 15.13541794], [73.94125366, 15.13569641], [73.94152832, 15.13569069], [73.94152832, 15.13624859], [73.94180298, 15.13624859], [73.94180298, 15.13652992], [73.9420929, 15.13652992], [73.9420929, 15.1368103], [73.94235992, 15.13680553], [73.94235992, 15.13736153], [73.94264221, 15.13736153], [73.94264221, 15.13792038], [73.94291687, 15.13792038], [73.94291687, 15.13903046], [73.94319153, 15.13903046], [73.94319153, 15.13931274], [73.94374847, 15.13930607], [73.94374847, 15.13958359], [73.94403076, 15.13958168], [73.94403076, 15.14013958], [73.94374847, 15.14013958], [73.94374847, 15.14041996], [73.94403076, 15.14041805], [73.94403076, 15.14097214], [73.94431305, 15.14097023], [73.94431305, 15.14124966], [73.94486237, 15.14124966], [73.94486237, 15.14153004], [73.94513702, 15.14153004], [73.94513702, 15.14181137], [73.94568634, 15.14181137], [73.94568634, 15.14235973], [73.94625092, 15.14235973], [73.94625092, 15.14264011], [73.94708252, 15.14264011], [73.94708252, 15.1431942], [73.94736481, 15.1431942], [73.94736481, 15.14375019], [73.94763947, 15.14375019], [73.94763947, 15.14431095], [73.94791412, 15.14430618], [73.94791412, 15.14486217], [73.94819641, 15.14486027], [73.94819641, 15.14542103], [73.94847107, 15.14541626], [73.94847107, 15.14597225], [73.94819641, 15.14597034], [73.94819641, 15.14736271], [73.94790649, 15.14736271], [73.94790649, 15.14792061], [73.94763947, 15.14792061], [73.94763947, 15.14903069], [73.94734955, 15.14903069], [73.94734955, 15.14931107], [73.94708252, 15.14930439], [73.94708252, 15.14986038], [73.94734955, 15.14986038], [73.94734955, 15.15014076], [73.94708252, 15.15013885], [73.94708252, 15.15097332], [73.94680786, 15.15097046], [73.94680786, 15.15181065], [73.9465332, 15.15181065], [73.9465332, 15.15292072], [73.94625092, 15.15292072], [73.94625092, 15.15375137], [73.94596863, 15.15375137], [73.94596863, 15.15514088], [73.94569397, 15.15513897], [73.94569397, 15.15569496], [73.94541931, 15.15569019], [73.94541931, 15.15625095], [73.94513702, 15.15625095], [73.94513702, 15.15681171], [73.94486237, 15.15680504], [73.94486237, 15.15708256], [73.94458008, 15.15708256], [73.94458008, 15.15819454], [73.94430542, 15.15819454], [73.94430542, 15.15847111], [73.94403076, 15.15847111], [73.94403076, 15.16182137], [73.94374847, 15.16180515], [73.94374847, 15.16208267], [73.94403076, 15.16208076], [73.94403076, 15.16263962], [73.94374847, 15.16263962], [73.94374847, 15.16374969], [73.94347382, 15.16374969], [73.94347382, 15.16458416], [73.94319153, 15.16458416], [73.94319153, 15.16569424], [73.94291687, 15.16569138], [73.94291687, 15.16681004], [73.94264221, 15.16681004], [73.94264221, 15.16903019], [73.94235992, 15.16902828], [73.94235992, 15.17097187], [73.9420929, 15.17096996], [73.9420929, 15.1718111], [73.94180298, 15.17180634], [73.94180298, 15.17236233], [73.94152832, 15.17236233], [73.94152832, 15.17319393], [73.94124603, 15.17319202], [73.94124603, 15.17403126], [73.94097137, 15.17403126], [73.94097137, 15.17514133], [73.94069672, 15.17514133], [73.94069672, 15.17625141], [73.94041443, 15.17625141], [73.94041443, 15.17736053], [73.94013977, 15.17736053], [73.94013977, 15.17875099], [73.93985748, 15.17875099], [73.93985748, 15.1795826], [73.93958282, 15.1795826], [73.93958282, 15.18097305], [73.93930817, 15.18097305], [73.93930817, 15.18208313], [73.93902588, 15.18208313], [73.93902588, 15.18319511], [73.93875122, 15.1831913], [73.93875122, 15.18403244], [73.93846893, 15.18402672], [73.93846893, 15.18458271], [73.93817902, 15.1845808], [73.93817902, 15.18514061], [73.93791962, 15.18514061], [73.93791962, 15.18625069], [73.93763733, 15.18625069], [73.93763733, 15.18736076], [73.93736267, 15.18736076], [73.93736267, 15.18902969], [73.93708038, 15.18902683], [73.93708038, 15.18958378], [73.93680573, 15.18958378], [73.93680573, 15.19097233], [73.93653107, 15.19097233], [73.93653107, 15.19180584], [73.93624878, 15.19180107], [73.93624878, 15.19291973], [73.93597412, 15.19291782], [73.93597412, 15.19458389], [73.93569183, 15.19458389], [73.93569183, 15.1956892], [73.93540955, 15.19570065], [73.93540955, 15.19681072], [73.93514252, 15.19680595], [73.93514252, 15.19847202], [73.93486023, 15.19847202], [73.93486023, 15.20069408], [73.93458557, 15.20069408], [73.93458557, 15.20236015], [73.93430328, 15.20236015], [73.93430328, 15.20292091], [73.93402863, 15.20291615], [73.93402863, 15.20347309], [73.93374634, 15.20347023], [73.93374634, 15.20431137], [73.93347168, 15.20431137], [73.93347168, 15.20486069], [73.93319702, 15.20486069], [73.93319702, 15.20569515], [73.9329071, 15.20569038], [73.9329071, 15.20625114], [73.93264008, 15.20625114], [73.93264008, 15.20653057], [73.9329071, 15.20653057], [73.9329071, 15.20792103], [73.93264008, 15.20791721], [73.93264008, 15.20847321], [73.93237305, 15.2084713], [73.93237305, 15.20930862], [73.93208313, 15.20930862], [73.93208313, 15.20987034], [73.93180847, 15.20987034], [73.93180847, 15.21042156], [73.93152618, 15.21041679], [73.93152618, 15.21097088], [73.93125153, 15.21097088], [73.93125153, 15.21153164], [73.93096924, 15.21152687], [73.93096924, 15.21319485], [73.93068695, 15.21319103], [73.93068695, 15.21541977], [73.93041992, 15.21541977], [73.93041992, 15.21653175], [73.93013763, 15.21653175], [73.93013763, 15.21764183], [73.92986298, 15.21764183], [73.92986298, 15.21875191], [73.92958069, 15.21875191], [73.92958069, 15.21986198], [73.92930603, 15.21986198], [73.92930603, 15.22042274], [73.92903137, 15.22041798], [73.92903137, 15.22097206], [73.92930603, 15.22097206], [73.92930603, 15.22236156], [73.92874908, 15.22235966], [73.92874908, 15.22292042], [73.92903137, 15.22292042], [73.92903137, 15.22402954], [73.92874908, 15.22402763], [73.92874908, 15.22458363], [73.9284668, 15.22457981], [73.9284668, 15.22624969], [73.92819214, 15.22624969], [73.92819214, 15.22681141], [73.92791748, 15.22680569], [73.92791748, 15.22708225], [73.92763519, 15.22708225], [73.92763519, 15.22735977], [73.92791748, 15.22735977], [73.92791748, 15.22791576], [73.92763519, 15.22791576], [73.92763519, 15.22847176], [73.92736053, 15.22846985], [73.92736053, 15.22903061], [73.92708588, 15.2290287], [73.92708588, 15.22958469], [73.92680359, 15.22958469], [73.92680359, 15.22986031], [73.92652893, 15.22986031], [73.92652893, 15.23042107], [73.92624664, 15.23041725], [73.92624664, 15.23097324], [73.92597198, 15.23097324], [73.92597198, 15.23208332], [73.92569733, 15.23208332], [73.92569733, 15.2331953], [73.92542267, 15.23318958], [73.92542267, 15.2343092], [73.92514038, 15.2343092], [73.92514038, 15.23541927], [73.92485809, 15.23541927], [73.92485809, 15.23625088], [73.92457581, 15.23625088], [73.92457581, 15.23736095], [73.92430878, 15.23736095], [73.92430878, 15.23819542], [73.92402649, 15.23819065], [73.92402649, 15.23931026], [73.92375183, 15.23931026], [73.92375183, 15.24042034], [73.92346954, 15.24042034], [73.92346954, 15.24153042], [73.92317963, 15.24153042], [73.92317963, 15.24263954], [73.92292023, 15.24263954], [73.92292023, 15.24347115], [73.92263794, 15.24346924], [73.92263794, 15.24403191], [73.92236328, 15.24403191], [73.92236328, 15.24542046], [73.92208099, 15.24541569], [73.92208099, 15.24736214], [73.92180634, 15.24736214], [73.92180634, 15.24819374], [73.92151642, 15.24819088], [73.92151642, 15.24931145], [73.92124939, 15.24931145], [73.92124939, 15.25014019], [73.9209671, 15.25014019], [73.9209671, 15.25097179], [73.92069244, 15.25097179], [73.92069244, 15.25208378], [73.92043304, 15.25208187], [73.92043304, 15.2529211], [73.9201355, 15.25291634], [73.9201355, 15.25319386], [73.91986084, 15.25319195], [73.91986084, 15.25375271], [73.91958618, 15.25375271], [73.91958618, 15.25514126], [73.91929626, 15.25514126], [73.91929626, 15.25625134], [73.91902924, 15.25625134], [73.91902924, 15.25819016], [73.91874695, 15.25821114], [73.91874695, 15.2590313], [73.91847229, 15.2590313], [73.91847229, 15.25986099], [73.91819763, 15.25986099], [73.91819763, 15.26069546], [73.91792297, 15.26068974], [73.91792297, 15.26180935], [73.91764069, 15.26180935], [73.91764069, 15.26264095], [73.91708374, 15.26263905], [73.91708374, 15.26319504], [73.9173584, 15.26319504], [73.9173584, 15.26347256], [73.91680908, 15.26347065], [73.91680908, 15.26431179], [73.91652679, 15.26431179], [73.91652679, 15.26542187], [73.91680908, 15.2654171], [73.91680908, 15.26597118], [73.91652679, 15.26597118], [73.91652679, 15.26653194], [73.91625214, 15.26653194], [73.91625214, 15.26736069], [73.91596985, 15.26736069], [73.91596985, 15.26791954], [73.91569519, 15.26791668], [73.91569519, 15.26847363], [73.9154129, 15.26847076], [73.9154129, 15.26931], [73.91513824, 15.26930523], [73.91513824, 15.26986217], [73.91485596, 15.26985931], [73.91485596, 15.27153015], [73.9145813, 15.27152824], [73.9145813, 15.27319431], [73.91429901, 15.27319145], [73.91429901, 15.27375031], [73.91400909, 15.27375031], [73.91400909, 15.27431011], [73.91374969, 15.2743063], [73.91374969, 15.27486229], [73.91348267, 15.27486038], [73.91348267, 15.27542019], [73.91319275, 15.27541637], [73.91319275, 15.27597237], [73.91291809, 15.27595997], [73.91291809, 15.27653027], [73.9126358, 15.27652836], [73.9126358, 15.27708435], [73.91236115, 15.27708435], [73.91236115, 15.2798624], [73.91208649, 15.2798624], [73.91208649, 15.28069401], [73.91179657, 15.28069019], [73.91179657, 15.28153133], [73.91152954, 15.28153133], [73.91152954, 15.28236008], [73.91124725, 15.28236008], [73.91124725, 15.28319359], [73.9109726, 15.28318977], [73.9109726, 15.28431129], [73.91069794, 15.28431129], [73.91069794, 15.28542137], [73.91041565, 15.2854166], [73.91041565, 15.2859726], [73.9098587, 15.2859726], [73.9098587, 15.28819466], [73.90957642, 15.28819275], [73.90957642, 15.28903103], [73.90930939, 15.28903103], [73.90930176, 15.29014111], [73.9090271, 15.2901392], [73.9090271, 15.29069519], [73.90875244, 15.29069519], [73.90875244, 15.2909708], [73.90820313, 15.29095936], [73.90820313, 15.29153156], [73.90791321, 15.29153156], [73.90791321, 15.29264069], [73.90763855, 15.29263878], [73.90763855, 15.29347324], [73.90735626, 15.29347134], [73.90735626, 15.29430962], [73.9070816, 15.29430962], [73.9070816, 15.29513931], [73.90680695, 15.29513931], [73.90680695, 15.29597092], [73.90651703, 15.29597092], [73.90651703, 15.29681015], [73.90625, 15.29681015], [73.90625, 15.29764175], [73.90598297, 15.29764175], [73.90598297, 15.29875183], [73.90569305, 15.29874992], [73.90569305, 15.29958439], [73.90542603, 15.29958057], [73.90542603, 15.30041981], [73.90513611, 15.30041981], [73.90513611, 15.30125046], [73.90486145, 15.30125046], [73.90486145, 15.30208397], [73.90458679, 15.3020792], [73.90458679, 15.30292034], [73.90429687, 15.30292034], [73.90429687, 15.30375004], [73.90402985, 15.30375004], [73.90402985, 15.30486202], [73.90374756, 15.30486202], [73.90374756, 15.30569363], [73.9034729, 15.30568981], [73.9034729, 15.30626202], [73.90319824, 15.30624962], [73.90319824, 15.30708218], [73.90291595, 15.30708027], [73.90291595, 15.30792141], [73.9026413, 15.30791569], [73.9026413, 15.30847168], [73.90235901, 15.30846977], [73.90235901, 15.30932045], [73.90206909, 15.30932045], [73.90206909, 15.31014061], [73.90180206, 15.31013775], [73.90180206, 15.31097317], [73.9015274, 15.31097031], [73.9015274, 15.31181145], [73.90125275, 15.31181145], [73.90125275, 15.31264114], [73.90097046, 15.31263924], [73.90097046, 15.31319523], [73.9006958, 15.31319046], [73.9006958, 15.31403065], [73.90041351, 15.31402874], [73.90041351, 15.3148613], [73.90013885, 15.3148613], [73.90013885, 15.3154192], [73.89985657, 15.3154192], [73.89985657, 15.31624889], [73.89958191, 15.31624889], [73.89958191, 15.31652927], [73.89930725, 15.31652737], [73.89930725, 15.31708336], [73.89958191, 15.31708145], [73.89958191, 15.31764126], [73.8998642, 15.31763935], [73.89985657, 15.3179903], [73.89985657, 15.31820202], [73.89958191, 15.31820202], [73.89958191, 15.31875134], [73.89929962, 15.31875134], [73.89929962, 15.31903172], [73.89902496, 15.31902695], [73.89902496, 15.31958294], [73.89875031, 15.31958294], [73.89875031, 15.31986141], [73.89848328, 15.31986141], [73.89848328, 15.32014179], [73.89819336, 15.32014179], [73.89819336, 15.32153034], [73.8979187, 15.32153034], [73.8979187, 15.32180977], [73.89763641, 15.32180977], [73.89763641, 15.32236099], [73.89736176, 15.32236099], [73.89736176, 15.32319641], [73.8970871, 15.32319641], [73.8970871, 15.32458401], [73.89680481, 15.32458401], [73.89680481, 15.32486153], [73.8970871, 15.32486153], [73.8970871, 15.32514191], [73.89680481, 15.32514], [73.89680481, 15.32569408], [73.89653015, 15.32569122], [73.89653015, 15.32681274], [73.89624786, 15.32680607], [73.89624786, 15.32736206], [73.89597321, 15.32736015], [73.89597321, 15.32763958], [73.89569092, 15.32763767], [73.89569092, 15.32819366], [73.89597321, 15.3281889], [73.89597321, 15.32874966], [73.89569092, 15.32874966], [73.89569092, 15.32958412], [73.89541626, 15.32957935], [73.89541626, 15.33014011], [73.8951416, 15.33014011], [73.8951416, 15.33097172], [73.89485931, 15.33096981], [73.89485931, 15.33181095], [73.89458466, 15.33180618], [73.89458466, 15.33236217], [73.89430237, 15.33236027], [73.89430237, 15.33292103], [73.89402771, 15.33291626], [73.89402771, 15.33347225], [73.89375305, 15.33347034], [73.89375305, 15.33403111], [73.89347076, 15.33402824], [73.89347076, 15.33458424], [73.89319611, 15.33458042], [73.89319611, 15.33514118], [73.89291382, 15.33513832], [73.89291382, 15.33569431], [73.89263916, 15.33568954], [73.89263916, 15.33653069], [73.8923645, 15.33652878], [73.8923645, 15.33736038], [73.89208221, 15.33736038], [73.89208221, 15.33819485], [73.89180756, 15.33819008], [73.89180756, 15.33875084], [73.89152527, 15.33875084], [73.89152527, 15.3395834], [73.89125061, 15.33957958], [73.89125061, 15.34042072], [73.89097595, 15.34041691], [73.89097595, 15.3409729], [73.89068604, 15.34097099], [73.89068604, 15.34152889], [73.89041901, 15.34152889], [73.89041901, 15.34208298], [73.89012909, 15.34208012], [73.89012909, 15.34264088], [73.88986206, 15.34263897], [73.88986206, 15.34319496], [73.88957977, 15.34319019], [73.88957977, 15.34403133], [73.88930511, 15.34402657], [73.88930511, 15.34458256], [73.88903046, 15.34458065], [73.88903046, 15.34514141], [73.88874817, 15.34513855], [73.88874817, 15.34569454], [73.88846588, 15.34569073], [73.88846588, 15.34625053], [73.88819122, 15.34624863], [73.88819122, 15.34708309], [73.88791656, 15.34708118], [73.88791656, 15.34764194], [73.88764191, 15.34764194], [73.88764191, 15.34820175], [73.88735962, 15.34820175], [73.88735962, 15.34875202], [73.8870697, 15.34875202], [73.8870697, 15.34930992], [73.88680267, 15.34930515], [73.88680267, 15.34986115], [73.88652802, 15.34985924], [73.88652802, 15.35042], [73.88625336, 15.35041809], [73.88625336, 15.35069561], [73.88597107, 15.35069561], [73.88597107, 15.35124874], [73.88569641, 15.35124016], [73.88569641, 15.35153198], [73.88541412, 15.35152817], [73.88541412, 15.35208416], [73.88513947, 15.3520813], [73.88513947, 15.35264015], [73.88486481, 15.35264015], [73.88486481, 15.35319424], [73.88458252, 15.35319138], [73.88458252, 15.35375023], [73.88430786, 15.35375023], [73.88430786, 15.35430622], [73.88402557, 15.35430622], [73.88402557, 15.35486221], [73.88375092, 15.35486031], [73.88375092, 15.35542011], [73.88346863, 15.3554163], [73.88346863, 15.35597229], [73.88318634, 15.35597038], [73.88318634, 15.35653019], [73.88291931, 15.35652828], [73.88291931, 15.35708427], [73.88263702, 15.35707855], [73.88263702, 15.35737133], [73.88236237, 15.35737133], [73.88236237, 15.35791969], [73.88208008, 15.35791588], [73.88208008, 15.35819435], [73.88180542, 15.35819435], [73.88181305, 15.35875034], [73.88153076, 15.35875034], [73.88153076, 15.35902977], [73.88124847, 15.35902786], [73.88124847, 15.35958195], [73.88097382, 15.35958195], [73.88097382, 15.35986233], [73.88069153, 15.35986042], [73.88069153, 15.36042976], [73.88041687, 15.36041641], [73.88041687, 15.36069393], [73.88014221, 15.36069202], [73.88014221, 15.36124992], [73.87985992, 15.36124992], [73.87985992, 15.36153126], [73.87958527, 15.3615284], [73.87958527, 15.36208439], [73.87930298, 15.36207962], [73.87930298, 15.36236], [73.87902832, 15.36236], [73.87902832, 15.36292076], [73.87875366, 15.36291599], [73.87875366, 15.36319447], [73.87847137, 15.36318111], [73.87847137, 15.36375141], [73.87818909, 15.36375141], [73.87818909, 15.36403084], [73.87791443, 15.36402893], [73.87791443, 15.36458206], [73.87763977, 15.36458206], [73.87763977, 15.36485958], [73.87735748, 15.36485958], [73.87735748, 15.3654213], [73.87708282, 15.36541653], [73.87708282, 15.365695], [73.87680817, 15.365695], [73.87680817, 15.36625099], [73.87652588, 15.36624241], [73.87652588, 15.36653137], [73.87625122, 15.36652565], [73.87625122, 15.3670826], [73.87596893, 15.36707973], [73.87596893, 15.36736107], [73.87568665, 15.36736107], [73.87568665, 15.36764145], [73.87541962, 15.36763859], [73.87541962, 15.36819458], [73.87513733, 15.36819458], [73.87513733, 15.36847305], [73.87486267, 15.36847115], [73.87486267, 15.36875057], [73.87458038, 15.36875057], [73.87458038, 15.36903095], [73.87431335, 15.36903095], [73.87431335, 15.36930943], [73.87403107, 15.36930466], [73.87403107, 15.36958313], [73.87374878, 15.36958122], [73.87374878, 15.36986065], [73.87346649, 15.36986065], [73.87346649, 15.37014103], [73.87264252, 15.37014103], [73.87264252, 15.37042236], [73.87208557, 15.37041664], [73.87208557, 15.37069511], [73.86985779, 15.37069511], [73.86985779, 15.37041664], [73.86875153, 15.37042236], [73.86875153, 15.37014103], [73.86818695, 15.37014103], [73.86818695, 15.36986065], [73.86458588, 15.36986065], [73.86458588, 15.36958122], [73.86319733, 15.36958313], [73.86319733, 15.36930466], [73.86292267, 15.36930943], [73.86292267, 15.36903095], [73.86264038, 15.36903095], [73.86264038, 15.36847115], [73.86291504, 15.36847305], [73.86291504, 15.36791706], [73.8631897, 15.36792088], [73.8631897, 15.36764145], [73.86264038, 15.36764145], [73.86264038, 15.36707973], [73.86235809, 15.3670826], [73.86235809, 15.36652565], [73.86207581, 15.36653137], [73.86207581, 15.36624241], [73.86180878, 15.36625099], [73.86180878, 15.36597347], [73.86096954, 15.36597347], [73.86096954, 15.365695], [73.86069489, 15.365695], [73.86069489, 15.36597347], [73.86042023, 15.36597347], [73.86042023, 15.365695], [73.85958099, 15.365695], [73.85958099, 15.36597347], [73.85902405, 15.36597347], [73.85902405, 15.36625099], [73.85402679, 15.36625099], [73.85402679, 15.36597347], [73.85375214, 15.36597347], [73.85375214, 15.365695], [73.85319519, 15.365695], [73.85319519, 15.36541653], [73.8529129, 15.3654213], [73.8529129, 15.36485958], [73.85263824, 15.36485958], [73.85263824, 15.36402893], [73.85235596, 15.36403084], [73.85235596, 15.36153126], [73.8520813, 15.36153126], [73.8520813, 15.36124992], [73.85151672, 15.36124992], [73.85151672, 15.36096954], [73.8501358, 15.3609724], [73.8501358, 15.36069393], [73.84958649, 15.36069393], [73.84958649, 15.3609724], [73.84924316, 15.3609724], [73.84764099, 15.3609724], [73.84764099, 15.36069393], [73.8465271, 15.36069393], [73.8465271, 15.36041641], [73.84319305, 15.36042976], [73.84319305, 15.36014271], [73.84179688, 15.36014271], [73.84179688, 15.36042976], [73.8409729, 15.36041641], [73.8409729, 15.36069393], [73.84069824, 15.36069393], [73.84069824, 15.3609724], [73.8401413, 15.36096954], [73.8401413, 15.36124992], [73.83985901, 15.36124992], [73.83985901, 15.36153126], [73.83957672, 15.36153126], [73.83957672, 15.36181068], [73.83875275, 15.36180592], [73.83875275, 15.36208439], [73.8381958, 15.36207962], [73.8381958, 15.36236], [73.83763885, 15.36236], [73.83763885, 15.36292076], [73.83708191, 15.36291599], [73.83708191, 15.36319447], [73.83680725, 15.36319447], [73.83680725, 15.36347198], [73.83652496, 15.36347198], [73.83652496, 15.36485958], [73.83625031, 15.36485958], [73.83625031, 15.3654213], [73.83597565, 15.36541653], [73.83597565, 15.365695], [73.83569336, 15.36569023], [73.83569336, 15.3668108], [73.8354187, 15.36680698], [73.8354187, 15.3670826], [73.83513641, 15.36707973], [73.83513641, 15.36792088], [73.83486176, 15.36791706], [73.83486176, 15.36819458], [73.8345871, 15.36819458], [73.8345871, 15.36847305], [73.83429718, 15.36847115], [73.83429718, 15.36903095], [73.83403015, 15.36902905], [73.83403015, 15.36958313], [73.83347321, 15.36958122], [73.83347321, 15.36986065], [73.83291626, 15.36986065], [73.83291626, 15.37014103], [73.83235931, 15.37014103], [73.83235931, 15.37042236], [73.83180237, 15.37041664], [73.83180237, 15.37069511], [73.83152771, 15.37069511], [73.83152771, 15.37097263], [73.83125305, 15.37097263], [73.83125305, 15.37069511], [73.83041382, 15.37069511], [73.83041382, 15.37013912], [73.83014679, 15.37014103], [73.83014679, 15.36986065], [73.82958221, 15.36986065], [73.82958221, 15.36958122], [73.82875061, 15.36958313], [73.82875061, 15.36930466], [73.82736206, 15.36930466], [73.82736206, 15.36958313], [73.82624817, 15.36958122], [73.82624817, 15.36986065], [73.82514191, 15.36986065], [73.82514191, 15.37014103], [73.82485962, 15.37014103], [73.82485962, 15.37042236], [73.82430267, 15.37041664], [73.82430267, 15.37069511], [73.82402802, 15.37069511], [73.82402802, 15.37041664], [73.82375336, 15.37041664], [73.82375336, 15.37069511], [73.82319641, 15.37069511], [73.82319641, 15.37041664], [73.82291412, 15.37041664], [73.82291412, 15.37069511], [73.82208252, 15.37069035], [73.82208252, 15.37125111], [73.82235718, 15.37125111], [73.82235718, 15.37181187], [73.82208252, 15.37180519], [73.82208252, 15.37208271], [73.82180786, 15.3720808], [73.82180786, 15.37236977], [73.8215332, 15.37236977], [73.8215332, 15.37264061], [73.82125092, 15.37264061], [73.82125092, 15.37292194], [73.82096863, 15.37291718], [73.82096863, 15.37319469], [73.81930542, 15.37319469], [73.81930542, 15.37291718], [73.81903076, 15.37291718], [73.81903076, 15.37319469], [73.81819153, 15.37319469], [73.81819153, 15.37347317], [73.81680298, 15.37347126], [73.81680298, 15.37375069], [73.81569672, 15.37375069], [73.81569672, 15.37403202], [73.81513977, 15.37403202], [73.81513977, 15.37430954], [73.81484985, 15.37430954], [73.81484985, 15.37513924], [73.81458282, 15.37513924], [73.81458282, 15.37569332], [73.81402588, 15.37569141], [73.81402588, 15.37597084], [73.81291962, 15.37597084], [73.81291962, 15.37624931], [73.81263733, 15.37624931], [73.81263733, 15.37652969], [73.81208038, 15.37652969], [73.81208038, 15.37624931], [73.81181335, 15.37624931], [73.81181335, 15.37652969], [73.81096649, 15.37652969], [73.81096649, 15.37624931], [73.81069183, 15.37624931], [73.81069183, 15.37652969], [73.80874634, 15.37652969], [73.80874634, 15.37681007], [73.80819702, 15.37680531], [73.80819702, 15.37736225], [73.8079071, 15.37735939], [73.8079071, 15.37764168], [73.80764008, 15.37764168], [73.80764008, 15.37792015], [73.80708313, 15.37791538], [73.80708313, 15.37847137], [73.80680847, 15.37847137], [73.80680847, 15.37903023], [73.80708313, 15.37903023], [73.80708313, 15.37986183], [73.80735779, 15.37986183], [73.80735779, 15.38041973], [73.80764008, 15.38041973], [73.80764008, 15.38181019], [73.80735779, 15.38180637], [73.80735779, 15.38319397], [73.80764008, 15.38319397], [73.80764008, 15.38597202], [73.80735779, 15.38597202], [73.80735779, 15.39014053], [73.80708313, 15.39013767], [73.80708313, 15.39069366], [73.80680847, 15.39068985], [73.80680847, 15.39153099], [73.80652618, 15.39152908], [73.80652618, 15.39208221], [73.80625153, 15.39208031], [73.80625153, 15.39264107], [73.80597687, 15.39264107], [73.80597687, 15.39292145], [73.80569458, 15.39291668], [73.80569458, 15.39319515], [73.80541992, 15.39319038], [73.80541992, 15.3934803], [73.80513763, 15.3934803], [73.80513763, 15.39375114], [73.80486298, 15.39375114], [73.80486298, 15.39403057], [73.80430603, 15.39402866], [73.80430603, 15.39458275], [73.80374908, 15.39458275], [73.80374908, 15.39486122], [73.80208588, 15.39486122], [73.80208588, 15.39458275], [73.80097198, 15.39458275], [73.80097198, 15.39430523], [73.79624939, 15.39430523], [73.79624939, 15.39458275], [73.79541779, 15.39458275], [73.79541779, 15.39430523], [73.79486084, 15.39431095], [73.79486084, 15.39403057], [73.79429626, 15.39403057], [73.79429626, 15.39375114], [73.79319763, 15.39375114], [73.79319763, 15.39403057], [73.79180908, 15.39403057], [73.79180908, 15.39431095], [73.79152679, 15.39431095], [73.79152679, 15.39403057], [73.79096985, 15.39403057], [73.79096985, 15.39431095], [73.79069519, 15.39430523], [73.79069519, 15.39486122], [73.79013824, 15.39486122], [73.79013824, 15.39514065], [73.78986359, 15.39513874], [73.78986359, 15.39569473], [73.7895813, 15.39569473], [73.7895813, 15.39597321], [73.78930664, 15.3959713], [73.78930664, 15.39653969], [73.78902435, 15.3965292], [73.78902435, 15.3973608], [73.78930664, 15.3973608], [73.78930664, 15.39819527], [73.7895813, 15.39819145], [73.7895813, 15.39875126], [73.78985596, 15.39875126], [73.78985596, 15.39903164], [73.79013824, 15.39902687], [73.79013824, 15.39958286], [73.7904129, 15.39958286], [73.7904129, 15.39986134], [73.79013824, 15.39986134], [73.79013824, 15.40014076], [73.78985596, 15.40014076], [73.78985596, 15.40042019], [73.78930664, 15.40041733], [73.78930664, 15.40069485], [73.78902435, 15.40069485], [73.78902435, 15.40097332], [73.78874969, 15.40097141], [73.78874969, 15.40125084], [73.78791046, 15.40125084], [73.78791046, 15.40180969], [73.7876358, 15.40180492], [73.7876358, 15.4020834], [73.78736115, 15.4020834], [73.78736115, 15.40236092], [73.78708649, 15.40235043], [73.78708649, 15.40291977], [73.78679657, 15.40291977], [73.78679657, 15.40374947], [73.78652954, 15.40374947], [73.78652954, 15.4048624], [73.78624725, 15.4048624], [73.78624725, 15.40569305], [73.7859726, 15.40569115], [73.7859726, 15.40625191], [73.78569794, 15.40625191], [73.78569794, 15.40680981], [73.78541565, 15.40680599], [73.78541565, 15.40708447], [73.78457642, 15.40708065], [73.78457642, 15.40736198], [73.7840271, 15.40736198], [73.7840271, 15.40764046], [73.78375244, 15.40764046], [73.78375244, 15.40792179], [73.78347015, 15.40792179], [73.78347015, 15.40848064], [73.78320313, 15.40848064], [73.78320313, 15.40874958], [73.78291321, 15.40874958], [73.78291321, 15.41042042], [73.78263855, 15.41041565], [73.78263855, 15.4123621], [73.78291321, 15.41236019], [73.78291321, 15.41292095], [73.7831955, 15.41291618], [73.7831955, 15.4131937], [73.78347015, 15.4131937], [73.78347015, 15.41347218], [73.78375244, 15.41347027], [73.78375244, 15.41374969], [73.7840271, 15.41374969], [73.7840271, 15.41403103], [73.78430176, 15.41403103], [73.78430939, 15.41431141], [73.78514099, 15.41430569], [73.78514099, 15.41458225], [73.78736115, 15.41458225], [73.78736115, 15.41430569], [73.78791046, 15.41431141], [73.78791046, 15.41403103], [73.78848267, 15.41403103], [73.78848267, 15.41374969], [73.78874969, 15.41374969], [73.78874969, 15.41403103], [73.78930664, 15.41403103], [73.78930664, 15.41431141], [73.78986359, 15.41430569], [73.78986359, 15.41458225], [73.79013824, 15.41458035], [73.79013824, 15.41542053], [73.7904129, 15.41542053], [73.7904129, 15.41681099], [73.79070282, 15.41681099], [73.79070282, 15.41764069], [73.79096985, 15.41764069], [73.79096985, 15.41792107], [73.79125214, 15.4179163], [73.79125214, 15.41847324], [73.79152679, 15.41847038], [73.79152679, 15.41875076], [73.79207611, 15.41875076], [73.79207611, 15.41847038], [73.7923584, 15.41847324], [73.7923584, 15.41763783], [73.79264069, 15.41764069], [73.79264069, 15.41681099], [73.79403687, 15.41681099], [73.79403687, 15.41653061], [73.79486084, 15.41653061], [73.79486084, 15.41625023], [73.79514313, 15.41625023], [73.7951355, 15.41513824], [73.79541779, 15.41514015], [73.79541779, 15.41485977], [73.79569244, 15.41485977], [73.79569244, 15.41431141], [73.7959671, 15.41431141], [73.7959671, 15.41374969], [73.79624939, 15.41374969], [73.79624939, 15.41347027], [73.79652405, 15.41347218], [73.79652405, 15.4131937], [73.79680634, 15.4131937], [73.79680634, 15.41291618], [73.79736328, 15.41292095], [73.79736328, 15.41263962], [73.79792023, 15.41263962], [73.79792023, 15.41236019], [73.80041504, 15.4123621], [73.80041504, 15.41208363], [73.80097198, 15.41208363], [73.80097198, 15.41180611], [73.80124664, 15.41181087], [73.80124664, 15.41152096], [73.80180359, 15.41152763], [73.80180359, 15.41125011], [73.80208588, 15.41125011], [73.80208588, 15.41042042], [73.80236053, 15.41042042], [73.80236053, 15.40985966], [73.80374908, 15.40985966], [73.80374908, 15.40957928], [73.80403137, 15.40958405], [73.80403137, 15.40930557], [73.80430603, 15.40931034], [73.80430603, 15.40902996], [73.80486298, 15.40902996], [73.80486298, 15.40819073], [73.80513763, 15.40819359], [73.80513763, 15.40791798], [73.80625153, 15.40792179], [73.80625153, 15.40764046], [73.80652618, 15.40764046], [73.80652618, 15.40736198], [73.80680847, 15.40736198], [73.80680847, 15.40708065], [73.80735779, 15.40708447], [73.80735779, 15.40680599], [73.80764008, 15.40680981], [73.80764008, 15.40653038], [73.8079071, 15.40653038], [73.8079071, 15.40625191], [73.80819702, 15.40625191], [73.80819702, 15.40569115], [73.80847168, 15.40569305], [73.80847168, 15.40513992], [73.80874634, 15.40514183], [73.80874634, 15.40458107], [73.80902863, 15.40458393], [73.80902863, 15.40392017], [73.80902863, 15.40263939], [73.80930328, 15.40263939], [73.80930328, 15.40097141], [73.81096649, 15.40097141], [73.81096649, 15.40125084], [73.81181335, 15.40125084], [73.81181335, 15.40152931], [73.81234741, 15.40152931], [73.81236267, 15.40180969], [73.81319427, 15.40180492], [73.81319427, 15.4020834], [73.81346893, 15.4020834], [73.81346893, 15.40236092], [73.81375122, 15.40235043], [73.81375122, 15.40263939], [73.81430817, 15.40263939], [73.81430817, 15.40291977], [73.81485748, 15.40291691], [73.81485748, 15.40319633], [73.81541443, 15.40319633], [73.81541443, 15.40347099], [73.81569672, 15.40347099], [73.81569672, 15.40374947], [73.81597137, 15.40374947], [73.81597137, 15.40403175], [73.81624603, 15.40403175], [73.81624603, 15.40431023], [73.81652832, 15.40431023], [73.81652832, 15.40514183], [73.81625366, 15.40513992], [73.81625366, 15.40708447], [73.81652832, 15.40708065], [73.81652832, 15.40764046], [73.81624603, 15.40764046], [73.81624603, 15.40848064], [73.81597137, 15.40848064], [73.81597137, 15.41042042], [73.81652832, 15.41041565], [73.81652832, 15.41069412], [73.81680298, 15.41069412], [73.81680298, 15.41097164], [73.81874847, 15.41097164], [73.81874847, 15.41069412], [73.81958008, 15.41069412], [73.81958008, 15.41041565], [73.82125092, 15.41042042], [73.82125092, 15.41014004], [73.82208252, 15.41014004], [73.82208252, 15.40957928], [73.82263947, 15.40958405], [73.82263947, 15.40930557], [73.82319641, 15.40931034], [73.82319641, 15.40819073], [73.82347107, 15.40819359], [73.82347107, 15.40791798], [73.82319641, 15.40792179], [73.82319641, 15.40764046], [73.82347107, 15.40764046], [73.82347107, 15.40569115], [73.82375336, 15.40569305], [73.82375336, 15.40541458], [73.82460022, 15.40541458], [73.82485962, 15.4054203], [73.82485962, 15.40514183], [73.82624817, 15.40514183], [73.82624817, 15.4048624], [73.82653046, 15.4048624], [73.82653046, 15.40458393], [73.82680511, 15.40458393], [73.82680511, 15.40430546], [73.82707977, 15.40431023], [73.82707977, 15.40374947], [73.82736206, 15.40374947], [73.82736206, 15.40347099], [73.82818604, 15.40347099], [73.82818604, 15.40431023], [73.82791901, 15.40430546], [73.82791901, 15.4048624], [73.82763672, 15.4048624], [73.82763672, 15.40653038], [73.82791901, 15.40653038], [73.82791901, 15.40680981], [73.82819366, 15.40680599], [73.82819366, 15.40708447], [73.82930756, 15.40708065], [73.82930756, 15.40736198], [73.82958221, 15.40736198], [73.82958221, 15.40708065], [73.83013916, 15.40708447], [73.83013916, 15.40680599], [73.83097076, 15.40680981], [73.83097076, 15.40653038], [73.83235931, 15.40653038], [73.83235931, 15.40680981], [73.83291626, 15.40680981], [73.83291626, 15.40736198], [73.83319092, 15.40736198], [73.83319092, 15.40792179], [73.83347321, 15.40791798], [73.83347321, 15.40819359], [73.83374786, 15.40819359], [73.83374786, 15.40958405], [73.83403015, 15.40957928], [73.83403015, 15.40985966], [73.8345871, 15.40985966], [73.8345871, 15.41014004], [73.83569336, 15.41014004], [73.83569336, 15.40985966], [73.83625031, 15.40985966], [73.83625031, 15.41014004], [73.83735657, 15.41014004], [73.83735657, 15.41042042], [73.8381958, 15.41041565], [73.8381958, 15.41069412], [73.83930206, 15.41069412], [73.83930206, 15.41097164], [73.83958435, 15.41097164], [73.83958435, 15.41069412], [73.84069061, 15.41069412], [73.84069824, 15.41041565], [73.84124756, 15.41042042], [73.84124756, 15.41014004], [73.84152985, 15.41014004], [73.84152985, 15.40957928], [73.8418045, 15.40958405], [73.8418045, 15.40930557], [73.84263611, 15.40931034], [73.84263611, 15.40902996], [73.84319305, 15.40902996], [73.84319305, 15.40874958], [73.84401703, 15.40874958], [73.84401703, 15.40848064], [73.84430695, 15.40848064], [73.84432983, 15.40764046], [73.8445816, 15.40764046], [73.8445816, 15.40625191], [73.84485626, 15.40625191], [73.84485626, 15.4054203], [73.84514618, 15.4054203], [73.84514618, 15.4048624], [73.84486389, 15.4048624], [73.84486389, 15.40374947], [73.84514618, 15.40374947], [73.84513855, 15.40347099], [73.8445816, 15.40347099], [73.8445816, 15.40319633], [73.84486389, 15.40319633], [73.84486389, 15.40263939], [73.8445816, 15.40263939], [73.8445816, 15.40235043], [73.84402466, 15.40236092], [73.84402466, 15.40180492], [73.84430695, 15.40180969], [73.84430695, 15.40152931], [73.8445816, 15.40152931], [73.8445816, 15.40097141], [73.84486389, 15.40097332], [73.84486389, 15.40041733], [73.84514618, 15.40042019], [73.84514618, 15.40014076], [73.84541321, 15.40014076], [73.84541321, 15.39986134], [73.84625244, 15.39986134], [73.84625244, 15.39958286], [73.84764099, 15.39958286], [73.84764099, 15.39986134], [73.84902954, 15.39986134], [73.84902954, 15.40014076], [73.84958649, 15.40013885], [73.84958649, 15.40069485], [73.84986115, 15.40069485], [73.84986115, 15.40097332], [73.8501358, 15.40097141], [73.8501358, 15.40152931], [73.85041809, 15.40152931], [73.85041809, 15.40180969], [73.85180664, 15.40180492], [73.85180664, 15.4020834], [73.85263824, 15.4020834], [73.85263824, 15.40180492], [73.85346985, 15.40180969], [73.85346985, 15.40152931], [73.85402679, 15.40152931], [73.85402679, 15.40125084], [73.8548584, 15.40125084], [73.8548584, 15.40097141], [73.85569763, 15.40097332], [73.85569763, 15.40069485], [73.85624695, 15.40069485], [73.85624695, 15.40041733], [73.85652924, 15.40042019], [73.85652924, 15.40014076], [73.85708618, 15.40014076], [73.85708618, 15.39986134], [73.8576355, 15.39986134], [73.8576355, 15.39958286], [73.85791779, 15.39958286], [73.85791779, 15.39902687], [73.85817719, 15.39903164], [73.85819244, 15.39875126], [73.8584671, 15.39875126], [73.8584671, 15.39903164], [73.85874939, 15.39903164], [73.85874939, 15.39847088], [73.85901642, 15.39847088], [73.85901642, 15.39875126], [73.85930634, 15.39875126], [73.85930634, 15.39903164], [73.85958099, 15.39903164], [73.85958099, 15.39931202], [73.85986328, 15.39930534], [73.85986328, 15.39958286], [73.86013794, 15.39958286], [73.86013794, 15.39986134], [73.86042023, 15.39986134], [73.86042023, 15.40014076], [73.86069489, 15.40013885], [73.86069489, 15.40041733], [73.86083221, 15.40041733], [73.86096954, 15.40041733], [73.86096954, 15.40069485], [73.86125183, 15.40069103], [73.86125183, 15.40125084], [73.86180878, 15.40125084], [73.86180878, 15.40152931], [73.86264038, 15.4015274], [73.86264038, 15.4020834], [73.86347198, 15.4020834], [73.86347198, 15.40236092], [73.86456299, 15.40236092], [73.86486053, 15.40236092], [73.86486053, 15.40252113], [73.86486053, 15.40291977], [73.86514282, 15.40291977], [73.86514282, 15.40263939], [73.86541748, 15.40263939], [73.86541748, 15.40235043], [73.86736298, 15.40236092], [73.86736298, 15.4020834], [73.86791992, 15.4020834], [73.86791992, 15.40180492], [73.86875153, 15.40180969], [73.86875153, 15.40152931], [73.8693161, 15.40152931], [73.8693161, 15.40125084], [73.87014008, 15.40125084], [73.87014008, 15.40069103], [73.87097168, 15.40069485], [73.87097168, 15.40041733], [73.87152863, 15.40042019], [73.87152863, 15.39986134], [73.87180328, 15.39986134], [73.87180328, 15.39875126], [73.87124634, 15.39875126], [73.87124634, 15.39847088], [73.87097168, 15.39847088], [73.87097168, 15.39791679], [73.87124634, 15.39792156], [73.87124634, 15.3973608], [73.87152863, 15.3973608], [73.87152863, 15.39708328], [73.87208557, 15.39708328], [73.87208557, 15.39680481], [73.87403107, 15.39680481], [73.87403107, 15.39708328], [73.87513733, 15.39708328], [73.87513733, 15.3973608], [73.87541962, 15.3973608], [73.87541962, 15.39708328], [73.87569427, 15.39708328], [73.87569427, 15.39680481], [73.87680817, 15.39680481], [73.87680817, 15.39708328], [73.87708282, 15.39708328], [73.87708282, 15.3973608], [73.87735748, 15.3973608], [73.87735748, 15.39792156], [73.87763977, 15.39791679], [73.87763977, 15.39819527], [73.87847137, 15.39819527], [73.87847137, 15.39847088], [73.87874603, 15.39847088], [73.87874603, 15.39875126], [73.87902832, 15.39875126], [73.87902832, 15.39903164], [73.88041687, 15.39903164], [73.88041687, 15.39875126], [73.88069153, 15.39875126], [73.88069153, 15.39847088], [73.88263702, 15.39847088], [73.88263702, 15.39875126], [73.88291931, 15.39875126], [73.88291931, 15.39903164], [73.88318634, 15.39903164], [73.88318634, 15.39931202], [73.88346863, 15.39930534], [73.88346863, 15.39958286], [73.88375092, 15.39958286], [73.88375092, 15.39986134], [73.8840332, 15.39986134], [73.8840332, 15.40014076], [73.88430786, 15.40013885], [73.88430786, 15.40069485], [73.88458252, 15.40069485], [73.88458252, 15.40097332], [73.88485718, 15.40097141], [73.88485718, 15.40125084], [73.88513947, 15.40125084], [73.88513947, 15.40152931], [73.88540649, 15.40152931], [73.88540649, 15.40180969], [73.88569641, 15.40180492], [73.88569641, 15.40236092], [73.88652802, 15.40235043], [73.88652802, 15.40263939], [73.88680267, 15.40263939], [73.88680267, 15.4048624], [73.88652802, 15.4048624], [73.88652802, 15.40597057], [73.88625336, 15.40597057], [73.88625336, 15.40625191], [73.8870697, 15.40625191], [73.8870697, 15.40653038], [73.88791656, 15.40653038], [73.88791656, 15.40764046], [73.88846588, 15.40764046], [73.88846588, 15.40792179], [73.88957977, 15.40792179], [73.88957977, 15.40764046], [73.89041901, 15.40764046], [73.89041901, 15.40792179], [73.89069366, 15.40791798], [73.89069366, 15.40819359], [73.89097595, 15.40819073], [73.89097595, 15.40848064], [73.8915329, 15.40848064], [73.8915329, 15.40874958], [73.89208221, 15.40874958], [73.89208221, 15.40848064], [73.89235687, 15.40848064], [73.89235687, 15.40874958], [73.89263916, 15.40874958], [73.89263916, 15.40848064], [73.89319611, 15.40848064], [73.89319611, 15.40819073], [73.89375305, 15.40819359], [73.89375305, 15.40791798], [73.89402771, 15.40792179], [73.89402771, 15.40764046], [73.89457703, 15.40764046], [73.89457703, 15.40736198], [73.89485931, 15.40736198], [73.89485931, 15.40819359], [73.8951416, 15.40819073], [73.8951416, 15.40931034], [73.89541626, 15.40931034], [73.89541626, 15.41042042], [73.89569092, 15.41042042], [73.89569092, 15.41125011], [73.89597321, 15.41125011], [73.89597321, 15.4123621], [73.89624786, 15.4123621], [73.89624786, 15.41347218], [73.89653015, 15.41347218], [73.89653015, 15.41458225], [73.89679718, 15.41458035], [73.89679718, 15.41485977], [73.89653015, 15.41485977], [73.89653015, 15.41514015], [73.89626312, 15.41514015], [73.89626312, 15.41542053], [73.89597321, 15.41541576], [73.89597321, 15.41597176], [73.89569092, 15.41596985], [73.89569092, 15.41653061], [73.89541626, 15.41653061], [73.89541626, 15.41681099], [73.89485931, 15.41681099], [73.89485931, 15.41764069], [73.89457703, 15.41764069], [73.89457703, 15.41792107], [73.89430237, 15.4179163], [73.89430237, 15.41847324], [73.89375305, 15.41847038], [73.89375305, 15.41875076], [73.89347076, 15.41875076], [73.89347076, 15.41903114], [73.89319611, 15.41902924], [73.89319611, 15.41958237], [73.89290619, 15.41958046], [73.89290619, 15.42042065], [73.89263916, 15.42042065], [73.89263916, 15.4212513], [73.89208221, 15.4212513], [73.89208221, 15.42236137], [73.89180756, 15.42236137], [73.89180756, 15.42291927], [73.89152527, 15.42291737], [73.89152527, 15.42347336], [73.89125061, 15.42346191], [73.89125061, 15.42403126], [73.89097595, 15.42402744], [73.89097595, 15.42458344], [73.89068604, 15.42458057], [73.89068604, 15.42486095], [73.89041901, 15.42486095], [73.89041901, 15.42514133], [73.89012909, 15.42514133], [73.89012909, 15.42570019], [73.88957977, 15.42569542], [73.88957977, 15.42607975], [73.88957977, 15.42625141], [73.88932037, 15.42625141], [73.88931274, 15.42681026], [73.88903046, 15.42680454], [73.88903046, 15.42708302], [73.88874817, 15.42708302], [73.88874817, 15.42736053], [73.88847351, 15.42736053], [73.88847351, 15.42819309], [73.88819122, 15.42819309], [73.88819122, 15.42847347], [73.88791656, 15.42847061], [73.88791656, 15.42903042], [73.88764191, 15.42903042], [73.88764191, 15.42986107], [73.88735962, 15.42986107], [73.88735962, 15.43013859], [73.88680267, 15.43013859], [73.88680267, 15.43041992], [73.88735962, 15.43041801], [73.88735962, 15.43069553], [73.88708496, 15.43069553], [73.88708496, 15.43097115], [73.88652802, 15.43096924], [73.88652802, 15.43125153], [73.88625336, 15.43125153], [73.88625336, 15.43153191], [73.88569641, 15.43153191], [73.88569641, 15.43181038], [73.88541412, 15.43180561], [73.88541412, 15.43208408], [73.88485718, 15.43208122], [73.88486481, 15.4323616], [73.88432312, 15.4323616], [73.88432312, 15.43265057], [73.88236237, 15.43265057], [73.88236237, 15.43292046], [73.88181305, 15.43292046], [73.88181305, 15.43265057], [73.88041687, 15.43265057], [73.88041687, 15.43292046], [73.88014221, 15.43292046], [73.88014221, 15.43265057], [73.8795929, 15.43265057], [73.8795929, 15.43292046], [73.87930298, 15.43292046], [73.87930298, 15.43265057], [73.87902832, 15.43265057], [73.87902832, 15.4323616], [73.87847137, 15.4323616], [73.87847137, 15.43208122], [73.87791443, 15.43208408], [73.87791443, 15.43152714], [73.87735748, 15.43153191], [73.87735748, 15.43125153], [73.87708282, 15.43125153], [73.87708282, 15.43096924], [73.87652588, 15.43097115], [73.87652588, 15.43069553], [73.87569427, 15.43069553], [73.87569427, 15.43041801], [73.87541962, 15.43041801], [73.87541962, 15.43069553], [73.87486267, 15.43069553], [73.87486267, 15.43097115], [73.87430573, 15.43097115], [73.87430573, 15.43069553], [73.87374878, 15.43069553], [73.87374878, 15.43097115], [73.87319183, 15.43096924], [73.87319183, 15.43125153], [73.87264252, 15.43125153], [73.87264252, 15.43153191], [73.87236023, 15.43153191], [73.87236023, 15.43125153], [73.8720932, 15.43125153], [73.8720932, 15.43153191], [73.87095642, 15.43152714], [73.87069702, 15.43153191], [73.87069702, 15.43125153], [73.86875153, 15.43125153], [73.86875153, 15.43096924], [73.86791992, 15.43097115], [73.86791992, 15.43069553], [73.86763763, 15.43069553], [73.86763763, 15.43041801], [73.86736298, 15.43041992], [73.86736298, 15.43013859], [73.86708069, 15.43013859], [73.86708069, 15.42958069], [73.86624908, 15.4295826], [73.86624908, 15.42930508], [73.86541748, 15.42931175], [73.86541748, 15.42903042], [73.86514282, 15.42903042], [73.86514282, 15.42875099], [73.86458588, 15.42875099], [73.86458588, 15.42847061], [73.86152649, 15.42847347], [73.86152649, 15.4295826], [73.86180878, 15.42958069], [73.86180878, 15.43041992], [73.86207581, 15.43041992], [73.86207581, 15.43125153], [73.86180878, 15.43125153], [73.86180878, 15.43265057], [73.86152649, 15.43264008], [73.86152649, 15.43319321], [73.86125183, 15.4331913], [73.86125183, 15.43375015], [73.86096954, 15.43375015], [73.86096954, 15.43402958], [73.86068726, 15.43402958], [73.86068726, 15.43430996], [73.86042023, 15.43430614], [73.86042023, 15.43486214], [73.8601532, 15.43486023], [73.8601532, 15.43764019], [73.86042023, 15.43764019], [73.86042023, 15.43791962], [73.8601532, 15.43791962], [73.8601532, 15.44013977], [73.85986328, 15.44013786], [73.85986328, 15.44097233], [73.85958099, 15.44097233], [73.85958099, 15.44152832], [73.85930634, 15.44152832], [73.85930634, 15.44208431], [73.8584671, 15.44207954], [73.8584671, 15.44235992], [73.85819244, 15.44235992], [73.85819244, 15.44264126], [73.85764313, 15.44264126], [73.85764313, 15.44292068], [73.85652924, 15.44291592], [73.85652924, 15.44347191], [73.85569763, 15.44347], [73.85569763, 15.44375038], [73.85542297, 15.44375038], [73.85542297, 15.44459057], [73.85514069, 15.44459057], [73.85514069, 15.44514084], [73.8548584, 15.44513798], [73.8548584, 15.44569016], [73.85375214, 15.44570065], [73.85375214, 15.44625092], [73.85346985, 15.44625092], [73.85346985, 15.4465313], [73.85320282, 15.4465313], [73.85320282, 15.44681072], [73.8529129, 15.44681072], [73.8529129, 15.44736099], [73.85263824, 15.44736099], [73.85263824, 15.44847298], [73.8520813, 15.44847107], [73.8520813, 15.44903088], [73.85180664, 15.44902897], [73.85180664, 15.44958305], [73.85152435, 15.44958305], [73.85152435, 15.44968987], [73.85152435, 15.44986057], [73.85124969, 15.44986057], [73.85124969, 15.45014095], [73.85098267, 15.45014095], [73.85098267, 15.45042133], [73.85069275, 15.45041656], [73.85069275, 15.45069504], [73.8501358, 15.45069027], [73.8501358, 15.45125103], [73.84986115, 15.45125103], [73.84986115, 15.45153141], [73.84929657, 15.45153141], [73.84929657, 15.45181179], [73.84902954, 15.45180511], [73.84902954, 15.45208263], [73.84764099, 15.45208263], [73.84764099, 15.45236111], [73.8465271, 15.45236111], [73.8465271, 15.45208263], [73.84597015, 15.45208263], [73.84597015, 15.45152664], [73.84570313, 15.45153141], [73.84570313, 15.45181179], [73.84541321, 15.45181179], [73.84541321, 15.45153141], [73.8445816, 15.45153141], [73.8445816, 15.45125103], [73.84401703, 15.45125103], [73.84401703, 15.45097065], [73.84319305, 15.45097256], [73.84319305, 15.45069504], [73.8429184, 15.45069504], [73.8429184, 15.45041656], [73.84263611, 15.45042133], [73.84263611, 15.44875145], [73.84236145, 15.44875145], [73.84236145, 15.44818974], [73.84208679, 15.44819546], [73.84208679, 15.44763947], [73.84069824, 15.44764996], [73.84069824, 15.4479208], [73.84041595, 15.44791698], [73.84041595, 15.44819546], [73.8401413, 15.44819546], [73.8401413, 15.44847298], [73.83957672, 15.44847107], [73.83957672, 15.44875145], [73.83930206, 15.44875145], [73.83930206, 15.44903088], [73.83875275, 15.44902897], [73.83875275, 15.44958305], [73.83847046, 15.44958305], [73.83847046, 15.44986057], [73.83875275, 15.44986057], [73.83875275, 15.45006084], [73.83875275, 15.45013905], [73.83854675, 15.45013905], [73.8381958, 15.45013905], [73.8381958, 15.45028019], [73.8381958, 15.45042133], [73.83791351, 15.45041656], [73.83791351, 15.45069504], [73.8373642, 15.45069504], [73.8373642, 15.45097256], [73.83708191, 15.45097065], [73.83708191, 15.45125103], [73.83680725, 15.45125103], [73.83680725, 15.45097065], [73.83609009, 15.45097256], [73.83597565, 15.45097256], [73.83597565, 15.45069504], [73.83569336, 15.45069504], [73.83569336, 15.45097256], [73.8354187, 15.45097256], [73.8354187, 15.45069504], [73.83513641, 15.45069504], [73.83513641, 15.45097256], [73.83486176, 15.45097256], [73.83486176, 15.45069504], [73.83403015, 15.45069027], [73.83403015, 15.45125103], [73.83291626, 15.45125103], [73.83291626, 15.45153141], [73.83235931, 15.45153141], [73.83233643, 15.45181179], [73.83208466, 15.45180511], [73.83208466, 15.45208263], [73.83152771, 15.45208263], [73.83152771, 15.45236111], [73.83097076, 15.45236111], [73.83097076, 15.45264053], [73.83069611, 15.45264053], [73.83069611, 15.45292187], [73.83013916, 15.4529171], [73.83013916, 15.45319462], [73.82958221, 15.45319462], [73.82958221, 15.45347309], [73.82930756, 15.45347309], [73.82930756, 15.45319462], [73.82875061, 15.45319462], [73.82875061, 15.4529171], [73.82736206, 15.4529171], [73.82736206, 15.45319462], [73.82680511, 15.45319462], [73.82680511, 15.45347309], [73.82624817, 15.45347118], [73.82624817, 15.45375061], [73.82569122, 15.45375061], [73.82569122, 15.45403194], [73.82485962, 15.45403194], [73.82485962, 15.45431042], [73.82457733, 15.45431042], [73.82457733, 15.45403194], [73.82430267, 15.45403194], [73.82430267, 15.45431042], [73.82290649, 15.45431042], [73.82290649, 15.45403194], [73.81874847, 15.45403194], [73.81874847, 15.45375061], [73.81819153, 15.45375061], [73.81819153, 15.45347118], [73.81791687, 15.45347309], [73.81791687, 15.45319462], [73.81764221, 15.45319462], [73.81764221, 15.45296955], [73.81764221, 15.45263863], [73.81652832, 15.45264053], [73.81652832, 15.45236111], [73.81597137, 15.45236111], [73.81597137, 15.45306969], [73.81597137, 15.45319462], [73.81569672, 15.4531908], [73.81569672, 15.45375061], [73.8154068, 15.45375061], [73.8154068, 15.45403194], [73.81513977, 15.45403194], [73.81513977, 15.45431042], [73.81485748, 15.4543047], [73.81485748, 15.45458317], [73.81430817, 15.45458126], [73.81430817, 15.45486069], [73.81402588, 15.45486069], [73.81402588, 15.45514202], [73.81346893, 15.45514202], [73.81346893, 15.45541954], [73.81236267, 15.45541668], [73.81236267, 15.45569324], [73.81208038, 15.45569324], [73.81208038, 15.45541668], [73.81124878, 15.45541954], [73.81124878, 15.45514202], [73.81069183, 15.45514202], [73.81069183, 15.45486069], [73.81041718, 15.45486069], [73.81041718, 15.45458126], [73.80986023, 15.45458126], [73.80986023, 15.45486069], [73.80958557, 15.45486069], [73.80958557, 15.45458317], [73.80930328, 15.45458317], [73.80930328, 15.4543047], [73.80903625, 15.45431042], [73.80903625, 15.45403194], [73.80819702, 15.45403194], [73.80819702, 15.45375061], [73.80708313, 15.45375061], [73.80708313, 15.45403194], [73.80652618, 15.45403194], [73.80652618, 15.45431042], [73.80513763, 15.45431042], [73.80513763, 15.45403194], [73.80374908, 15.45403194], [73.80374908, 15.4531908], [73.80347443, 15.45319462], [73.80347443, 15.45180511], [73.80374908, 15.45181179], [73.80374908, 15.45069027], [73.80403137, 15.45069504], [73.80403137, 15.44986057], [73.80319214, 15.44986057], [73.80319214, 15.45014095], [73.80290985, 15.45014095], [73.80290985, 15.45042133], [73.80236053, 15.45041656], [73.80236053, 15.45097256], [73.80208588, 15.45097065], [73.80208588, 15.45153141], [73.80152893, 15.45153141], [73.80152893, 15.45181179], [73.80124664, 15.45180511], [73.80124664, 15.45208263], [73.80069733, 15.45208263], [73.80069733, 15.45236111], [73.80097198, 15.45236111], [73.80097198, 15.45292187], [73.80069733, 15.4529171], [73.80069733, 15.45319462], [73.80041504, 15.45319462], [73.80041504, 15.45347309], [73.80014038, 15.45347118], [73.80014038, 15.45375061], [73.79875183, 15.45375061], [73.79875183, 15.45431042], [73.79792023, 15.45431042], [73.79792023, 15.45486069], [73.79736328, 15.45486069], [73.79736328, 15.45541954], [73.79708099, 15.45541668], [73.79708099, 15.45569324], [73.79624939, 15.45569324], [73.79624939, 15.45597267], [73.79569244, 15.45597076], [73.79569244, 15.45652962], [73.79541779, 15.45652962], [73.79541779, 15.45682144], [73.7951355, 15.45680523], [73.7951355, 15.45736122], [73.79458618, 15.45735931], [73.79458618, 15.45792198], [73.79402924, 15.45791531], [73.79402924, 15.45819569], [73.79374695, 15.45819569], [73.79374695, 15.4584713], [73.79319763, 15.4584713], [73.79319763, 15.45875168], [73.79292297, 15.45875168], [73.79292297, 15.45903015], [73.79207611, 15.45903015], [73.79207611, 15.45930958], [73.79152679, 15.45930958], [73.79152679, 15.45958996], [73.79125214, 15.45958996], [73.79125214, 15.46014023], [73.79096985, 15.46014023], [73.79096985, 15.46069431], [73.79069519, 15.46069431], [73.79069519, 15.46097183], [73.79013824, 15.46097183], [73.79013824, 15.46125031], [73.7895813, 15.46125031], [73.7895813, 15.46097183], [73.78901672, 15.46097183], [73.78901672, 15.46125031], [73.78791046, 15.46125031], [73.78791046, 15.46152973], [73.7876358, 15.46152782], [73.7876358, 15.46208382], [73.78736115, 15.46208191], [73.78736115, 15.46292019], [73.78708649, 15.46292019], [73.78708649, 15.46431065], [73.78736115, 15.46430588], [73.78736115, 15.46458435], [73.7876358, 15.46457863], [73.7876358, 15.46485996], [73.78819275, 15.46485996], [73.78819275, 15.46514034], [73.79013824, 15.46514034], [73.79013824, 15.46485996], [73.79070282, 15.46485996], [73.79069519, 15.46458435], [73.79125214, 15.46458435], [73.79125214, 15.46430588], [73.79152679, 15.46431065], [73.79152679, 15.46403027], [73.79207611, 15.46403027], [73.79207611, 15.46375179], [73.79264069, 15.46375179], [73.79264069, 15.46347046], [73.79291534, 15.46347237], [73.79291534, 15.46319389], [73.79319763, 15.46319389], [73.79319763, 15.46291637], [73.79347229, 15.46292019], [73.79347229, 15.46263123], [73.79430389, 15.46263981], [73.79430389, 15.46236229], [73.79458618, 15.46236229], [73.79458618, 15.46208382], [73.79486084, 15.46208382], [73.79486084, 15.4618063], [73.79514313, 15.46181011], [73.79514313, 15.46152973], [73.79569244, 15.46152973], [73.79569244, 15.46125031], [73.79624939, 15.46125031], [73.79624939, 15.46097183], [73.79680634, 15.46097183], [73.79680634, 15.46069431], [73.79708099, 15.46069431], [73.79708099, 15.46041775], [73.79792023, 15.46041965], [73.79792023, 15.46014023], [73.79875183, 15.46014023], [73.79875183, 15.46041965], [73.80014038, 15.46041775], [73.80014038, 15.46069431], [73.80097198, 15.46069431], [73.80097198, 15.46097183], [73.80124664, 15.46097183], [73.80124664, 15.46125031], [73.80152893, 15.46125031], [73.80152893, 15.46152973], [73.80179596, 15.46152973], [73.80179596, 15.46181011], [73.80208588, 15.4618063], [73.80208588, 15.46236229], [73.80236053, 15.46236229], [73.80236053, 15.46263981], [73.80264282, 15.46263123], [73.80264282, 15.46292019], [73.80291748, 15.46291637], [73.80291748, 15.46319389], [73.80319214, 15.46319103], [73.80319214, 15.46375179], [73.80347443, 15.46374989], [73.8034668, 15.46391201], [73.8034668, 15.46403027], [73.80374908, 15.46402836], [73.80374908, 15.46458435], [73.80403137, 15.46457863], [73.80403137, 15.46485996], [73.80430603, 15.46485996], [73.80430603, 15.46514034], [73.80458069, 15.46513844], [73.80458069, 15.46569443], [73.80486298, 15.46569157], [73.80486298, 15.46652985], [73.80513763, 15.46652794], [73.80513763, 15.4673624], [73.80541992, 15.46735954], [73.80541992, 15.46792126], [73.80568695, 15.46792126], [73.80568695, 15.46875858], [73.80596924, 15.46875], [73.80596924, 15.46958447], [73.80625153, 15.4695797], [73.80625153, 15.47292137], [73.80652618, 15.4729166], [73.80652618, 15.47319508], [73.80680847, 15.47319508], [73.80680847, 15.47458267], [73.80708313, 15.47458267], [73.80708313, 15.47597313], [73.80680847, 15.47597122], [73.80680847, 15.47653103], [73.80652618, 15.47653103], [73.80652618, 15.47681236], [73.80680847, 15.47681236], [73.80680847, 15.47792244], [73.80708313, 15.47792244], [73.80708313, 15.47903061], [73.80735779, 15.47903061], [73.80735779, 15.47931194], [73.80708313, 15.47930527], [73.80708313, 15.48097324], [73.80680847, 15.48097134], [73.80680847, 15.48125076], [73.80625153, 15.48124886], [73.80625153, 15.48208332], [73.80596924, 15.48208332], [73.80596924, 15.4831953], [73.80625153, 15.48319054], [73.80625153, 15.48402977], [73.80652618, 15.48402691], [73.80652618, 15.48486233], [73.80708313, 15.48486233], [73.80708313, 15.48514175], [73.80735779, 15.48513985], [73.80735779, 15.48597145], [73.80708313, 15.48597145], [73.80708313, 15.48708439], [73.80680847, 15.48708439], [73.80680847, 15.48847198], [73.80652618, 15.48847198], [73.80652618, 15.48986244], [73.80625153, 15.48986244], [73.80625153, 15.49097157], [73.80596924, 15.49097157], [73.80597687, 15.49236202], [73.80569458, 15.49236202], [73.80568695, 15.49338055], [73.80568695, 15.49374962], [73.80541992, 15.49374962], [73.80541992, 15.4948597], [73.80458069, 15.4948597], [73.80458069, 15.49514008], [73.8034668, 15.49514008], [73.8034668, 15.49542141], [73.80124664, 15.49542141], [73.80124664, 15.49570084], [73.80097198, 15.49569416], [73.80097198, 15.49597168], [73.80014038, 15.49596977], [73.80014038, 15.49625015], [73.79875183, 15.49625015], [73.79875183, 15.49681091], [73.79819489, 15.49680424], [73.79819489, 15.49708462], [73.79792023, 15.49708462], [73.79792023, 15.49736023], [73.79736328, 15.49736023], [73.79736328, 15.49764061], [73.79708099, 15.49764061], [73.79708099, 15.49792099], [73.79680634, 15.49791622], [73.79680634, 15.49819374], [73.79624939, 15.49819374], [73.79624939, 15.49847221], [73.79486084, 15.49847221], [73.79486084, 15.49819374], [73.79458618, 15.49819374], [73.79458618, 15.49847221], [73.79402924, 15.49847221], [73.79402924, 15.49875069], [73.79347229, 15.49873924], [73.79347229, 15.49903107], [73.79319763, 15.49903107], [73.79319763, 15.49931145], [73.79208374, 15.49930668], [73.79208374, 15.49958229], [73.7904129, 15.49958038], [73.7904129, 15.49985981], [73.79013824, 15.49985981], [73.79013824, 15.49958038], [73.78985596, 15.49958038], [73.78985596, 15.49985981], [73.78930664, 15.49985981], [73.78930664, 15.49958038], [73.78901672, 15.49958038], [73.78901672, 15.49985981], [73.78874969, 15.49985981], [73.78874969, 15.49958038], [73.78847504, 15.49958229], [73.78847504, 15.49930668], [73.78791046, 15.49931145], [73.78791046, 15.49903107], [73.78708649, 15.49903107], [73.78708649, 15.49873924], [73.7868042, 15.49875069], [73.7868042, 15.49847221], [73.78652954, 15.49847221], [73.78652954, 15.49819374], [73.78624725, 15.49819374], [73.78624725, 15.49763775], [73.78569794, 15.49764061], [73.78569794, 15.49707985], [73.7859726, 15.49708462], [73.7859726, 15.49652767], [73.78624725, 15.49653053], [73.78624725, 15.49625015], [73.78679657, 15.49625015], [73.78679657, 15.49596977], [73.78736115, 15.49597168], [73.78736115, 15.49569416], [73.78791046, 15.49570084], [73.78791046, 15.49542141], [73.78819275, 15.49542141], [73.78819275, 15.49514008], [73.78791046, 15.49514008], [73.78791046, 15.49431133], [73.7876358, 15.49431133], [73.7876358, 15.49403], [73.78736115, 15.49403], [73.78736115, 15.49374962], [73.78708649, 15.49374962], [73.78708649, 15.49319172], [73.78652954, 15.49319363], [73.78652954, 15.49291611], [73.78624725, 15.49293041], [73.78624725, 15.49263954], [73.78569794, 15.49263954], [73.78569794, 15.49236202], [73.78542328, 15.49236202], [73.78542328, 15.49263954], [73.78347015, 15.49263954], [73.78347015, 15.49236202], [73.78235626, 15.49236202], [73.78235626, 15.49208164], [73.78125, 15.49208355], [73.78125, 15.49180603], [73.78097534, 15.49180603], [73.78097534, 15.49208355], [73.77986145, 15.49208164], [73.77986145, 15.49263954], [73.77958679, 15.49263954], [73.77958679, 15.49236202], [73.77929688, 15.49236202], [73.77929688, 15.49263954], [73.77873993, 15.49263954], [73.77873993, 15.49236202], [73.77791595, 15.49236202], [73.77791595, 15.49208164], [73.77735901, 15.49208355], [73.77735901, 15.49180603], [73.77690125, 15.49180603], [73.77680206, 15.49180603], [73.77680206, 15.49125004], [73.7765274, 15.49125004], [73.7765274, 15.49096966], [73.77597046, 15.49097157], [73.77597046, 15.49041557], [73.7756958, 15.49042034], [73.7756958, 15.49013996], [73.77513885, 15.49013996], [73.77513885, 15.48985958], [73.77179718, 15.48985958], [73.77179718, 15.49013996], [73.77069092, 15.49013996], [73.77069092, 15.49042034], [73.76847076, 15.49041557], [73.76847076, 15.49069405], [73.76791382, 15.49069405], [73.76791382, 15.49097157], [73.76763916, 15.49096966], [73.76763916, 15.49153042], [73.76735687, 15.49153042], [73.76735687, 15.49236202], [73.76708221, 15.49236202], [73.76708221, 15.4934721], [73.76679993, 15.49347019], [73.76679993, 15.49374962], [73.76625061, 15.49374962], [73.76625061, 15.49403], [73.76513672, 15.49403], [73.76513672, 15.49431133], [73.76486206, 15.49430561], [73.76486206, 15.49458218], [73.76457977, 15.49458027], [73.76457977, 15.49514008], [73.76431274, 15.49514008], [73.76431274, 15.49653053], [73.76403046, 15.49653053], [73.76403046, 15.49681091], [73.76431274, 15.49681091], [73.76431274, 15.49792099], [73.76457977, 15.49791622], [73.76457977, 15.49819374], [73.76541901, 15.49819374], [73.76541901, 15.49847221], [73.76597595, 15.49847031], [73.76597595, 15.49903107], [73.7665329, 15.49903107], [73.7665329, 15.49931145], [73.76679993, 15.49931145], [73.76679993, 15.49985981], [73.76708221, 15.49985981], [73.76708221, 15.50042057], [73.76679993, 15.50042057], [73.76679993, 15.50153065], [73.76652527, 15.50152874], [73.7665329, 15.5037508], [73.76625061, 15.5037508], [73.76625061, 15.50431156], [73.76597595, 15.50431156], [73.76597595, 15.50514126], [73.76625061, 15.50513935], [73.76625061, 15.50569534], [73.76597595, 15.50569534], [73.76597595, 15.50597095], [73.76625061, 15.50597095], [73.76625061, 15.50653172], [73.76597595, 15.50653172], [73.76597595, 15.50681019], [73.76541901, 15.50680542], [73.76541901, 15.50708294], [73.76513672, 15.50708294], [73.76513672, 15.50736141], [73.76486206, 15.50736141], [73.76486206, 15.50958347], [73.76457977, 15.50958061], [73.76457977, 15.51013947], [73.76431274, 15.51013947], [73.76431274, 15.5112524], [73.76403046, 15.5112524], [73.76403046, 15.5118103], [73.76374817, 15.51180458], [73.76374817, 15.51236153], [73.76403046, 15.51236153], [73.76403046, 15.51264191], [73.76374054, 15.51264191], [73.76374054, 15.51403046], [73.76346588, 15.51403046], [73.76346588, 15.51513958], [73.76319122, 15.51513958], [73.76319122, 15.51653004], [73.76291656, 15.51653004], [73.76291656, 15.51735973], [73.76264191, 15.51735973], [73.76264191, 15.51764011], [73.76235962, 15.51764011], [73.76235962, 15.51791954], [73.76208496, 15.51791573], [73.76208496, 15.51847172], [73.76180267, 15.51846981], [73.76180267, 15.51875019], [73.76207733, 15.51875019], [73.76207733, 15.51987076], [73.76180267, 15.51987076], [73.76180267, 15.52042103], [73.76152802, 15.52042103], [73.76152802, 15.52153111], [73.76125336, 15.52152824], [73.76125336, 15.52208424], [73.76097107, 15.52208424], [73.76097107, 15.52319431], [73.76069641, 15.52319431], [73.76069641, 15.52458191], [73.76041412, 15.52458477], [73.76041412, 15.52486038], [73.76013947, 15.52486038], [73.76013947, 15.52569389], [73.76040649, 15.52568054], [73.76040649, 15.52625275], [73.76013947, 15.52625275], [73.76013947, 15.52653122], [73.75985718, 15.52653122], [73.75985718, 15.52681065], [73.75958252, 15.52681065], [73.75958252, 15.52875137], [73.75930786, 15.52875137], [73.75930786, 15.52958298], [73.75902557, 15.52958298], [73.75902557, 15.52986145], [73.75875092, 15.52986145], [73.75875092, 15.53069496], [73.75846863, 15.53069019], [73.75846863, 15.53125095], [73.75818634, 15.53125095], [73.75818634, 15.53292179], [73.75792694, 15.53292179], [73.75792694, 15.53375053], [73.75763702, 15.53375053], [73.75763702, 15.53542042], [73.75736237, 15.53542042], [73.75736237, 15.53625107], [73.75708008, 15.53625107], [73.75708008, 15.53652954], [73.75680542, 15.53652668], [73.75680542, 15.53708267], [73.75653076, 15.53708267], [73.75653076, 15.53847122], [73.75681305, 15.53847122], [73.75681305, 15.53931046], [73.75624847, 15.53930473], [73.75624847, 15.53958416], [73.75596619, 15.5395813], [73.75596619, 15.54041958], [73.75569153, 15.54041958], [73.75569153, 15.54181004], [73.75541687, 15.54181004], [73.75541687, 15.54292011], [73.75514221, 15.54292011], [73.75514221, 15.54374981], [73.75485992, 15.54374981], [73.75485992, 15.54569435], [73.75458527, 15.54569435], [73.7545929, 15.54625034], [73.75402832, 15.54625034], [73.75402832, 15.54763985], [73.75374603, 15.54763985], [73.75374603, 15.54874992], [73.75347137, 15.54874992], [73.75347137, 15.54903126], [73.75319672, 15.54903126], [73.75319672, 15.55014133], [73.7529068, 15.55014133], [73.7529068, 15.55125046], [73.75263977, 15.55125046], [73.75263977, 15.55208206], [73.75235748, 15.55208015], [73.75235748, 15.55264091], [73.75208282, 15.55264091], [73.75208282, 15.55375099], [73.75180054, 15.55375099], [73.75180054, 15.5543108], [73.75152588, 15.5543108], [73.75152588, 15.55486107], [73.75125122, 15.55486107], [73.75125122, 15.55708313], [73.75096893, 15.55708027], [73.75096893, 15.55764103], [73.75069427, 15.55763912], [73.75069427, 15.55847263], [73.75041962, 15.55847073], [73.75041962, 15.55904102], [73.75013733, 15.55904102], [73.75013733, 15.55931187], [73.74986267, 15.55930519], [73.74986267, 15.55986118], [73.74958038, 15.55986118], [73.74958038, 15.56042194], [73.74930573, 15.56041718], [73.74930573, 15.56069469], [73.74874115, 15.56069088], [73.74874115, 15.56125069], [73.74846649, 15.56125069], [73.74846649, 15.56153202], [73.74791718, 15.56153202], [73.74791718, 15.56180954], [73.74736023, 15.56180954], [73.74736023, 15.56153202], [73.74652863, 15.56153202], [73.74652863, 15.56125069], [73.74624634, 15.56125069], [73.74624634, 15.56097126], [73.74514008, 15.56097317], [73.74514008, 15.56069469], [73.74485779, 15.56069469], [73.74485779, 15.56097317], [73.74458313, 15.56097126], [73.74458313, 15.56125069], [73.74430847, 15.56125069], [73.74430847, 15.56153202], [73.74402618, 15.56153202], [73.74402618, 15.56180954], [73.74375153, 15.56180477], [73.74375153, 15.56208324], [73.74346924, 15.56208134], [73.74346924, 15.56236076], [73.74318695, 15.56236076], [73.74318695, 15.56263924], [73.74291992, 15.56263924], [73.74291992, 15.56291962], [73.74263763, 15.56291676], [73.74263763, 15.56319523], [73.74124908, 15.56319141], [73.74124908, 15.56347084], [73.7409668, 15.56347084], [73.7409668, 15.56431007], [73.74069214, 15.56431007], [73.74069214, 15.56514168], [73.74041748, 15.56514168], [73.74041748, 15.56542015], [73.74069214, 15.56541538], [73.74069214, 15.56569576], [73.74097443, 15.56569576], [73.74097443, 15.56597137], [73.74124908, 15.56597137], [73.74124908, 15.56625175], [73.74153137, 15.56625175], [73.74153137, 15.56653023], [73.74124908, 15.56652737], [73.74124908, 15.56708431], [73.7409668, 15.56708145], [73.7409668, 15.5676403], [73.74069214, 15.5676403], [73.74069214, 15.56819439], [73.7409668, 15.56819057], [73.7409668, 15.56931019], [73.74124908, 15.56930637], [73.74124908, 15.56986237], [73.74153137, 15.56986046], [73.74153137, 15.57014179], [73.74180603, 15.57013988], [73.74180603, 15.5706892], [73.74153137, 15.57070065], [73.74153137, 15.57124996], [73.74124908, 15.57124996], [73.74124908, 15.57153034], [73.74097443, 15.57152843], [73.74097443, 15.57208443], [73.74069214, 15.57208157], [73.74069214, 15.57291985], [73.74041748, 15.57291603], [73.74041748, 15.57319355], [73.74014282, 15.57319164], [73.74014282, 15.57374954], [73.74041748, 15.57374954], [73.74041748, 15.57402802], [73.74014282, 15.57402134], [73.74014282, 15.57514], [73.73986053, 15.57513809], [73.73986053, 15.57569408], [73.73958588, 15.57569027], [73.73958588, 15.57681084], [73.73930359, 15.57680416], [73.73930359, 15.57736015], [73.73902893, 15.57736015], [73.73902893, 15.57792091], [73.73874664, 15.57791615], [73.73874664, 15.57819366], [73.73847198, 15.57819366], [73.73847198, 15.57847214], [73.73819733, 15.57847023], [73.73819733, 15.57903099], [73.73792267, 15.57903099], [73.73792267, 15.57931137], [73.73764038, 15.5793066], [73.73764038, 15.57958221], [73.73792267, 15.57958031], [73.73792267, 15.58014965], [73.73764038, 15.58013821], [73.73764038, 15.58069515], [73.73708344, 15.58069515], [73.73708344, 15.58097267], [73.73680878, 15.58097267], [73.73680878, 15.58347321], [73.73652649, 15.5834713], [73.73652649, 15.58431244], [73.73625183, 15.58430481], [73.73625183, 15.5848608], [73.73652649, 15.5848608], [73.73652649, 15.58542156], [73.73625183, 15.58541679], [73.73625183, 15.58597088], [73.73596954, 15.58595943], [73.73596954, 15.58625126], [73.73568726, 15.58625126], [73.73568726, 15.58653069], [73.73542023, 15.58652687], [73.73542023, 15.58708286], [73.73513794, 15.58708286], [73.73513794, 15.58736134], [73.73458099, 15.58736134], [73.73458099, 15.58764076], [73.73430634, 15.58764076], [73.73430634, 15.58791924], [73.73374939, 15.58791733], [73.73374939, 15.58819485], [73.73347473, 15.58819485], [73.73347473, 15.58847332], [73.73291779, 15.58847141], [73.73291779, 15.58875084], [73.73236084, 15.58874893], [73.73236084, 15.5890274], [73.73208618, 15.58902264], [73.73208618, 15.58930969], [73.73179626, 15.58930969], [73.73179626, 15.58986092], [73.73152924, 15.58986092], [73.73152924, 15.59041977], [73.73124695, 15.59041691], [73.73124695, 15.59097099], [73.73152924, 15.59097099], [73.73152924, 15.59125233], [73.73208618, 15.59125233], [73.73208618, 15.59208965], [73.7326355, 15.59208298], [73.7326355, 15.59236145], [73.73291779, 15.59236145], [73.73291779, 15.59264183], [73.73319244, 15.59264183], [73.73319244, 15.5929203], [73.73402405, 15.5929184], [73.73402405, 15.59319305], [73.73430634, 15.59319305], [73.73430634, 15.59347057], [73.73401642, 15.59347057], [73.73401642, 15.59430981], [73.73375702, 15.59430981], [73.73375702, 15.59515095], [73.7334671, 15.59515095], [73.7334671, 15.59624958], [73.73319244, 15.59624958], [73.73319244, 15.59708405], [73.73291779, 15.59708405], [73.73291779, 15.59819412], [73.73264313, 15.59818935], [73.73264313, 15.59875202], [73.73236084, 15.59875202], [73.73236084, 15.59902954], [73.73208618, 15.59902954], [73.73208618, 15.60042095], [73.7326355, 15.60041809], [73.7326355, 15.6006937], [73.73291779, 15.6006937], [73.73291779, 15.60097218], [73.73319244, 15.60096073], [73.73319244, 15.60124969], [73.7334671, 15.60124969], [73.73347473, 15.60347176], [73.73319244, 15.60347176], [73.73319244, 15.60403061], [73.73291779, 15.60402775], [73.73291779, 15.60458374], [73.73264313, 15.60457993], [73.73264313, 15.60514069], [73.73236084, 15.60514069], [73.73236084, 15.60542107], [73.73208618, 15.6054163], [73.73208618, 15.60569382], [73.73236084, 15.60569], [73.73236084, 15.60625076], [73.73208618, 15.60625076], [73.73208618, 15.60653114], [73.73179626, 15.60653114], [73.73179626, 15.60681057], [73.73152924, 15.60681057], [73.73152924, 15.6070919], [73.73124695, 15.6070919], [73.73124695, 15.60764122], [73.73097229, 15.60763931], [73.73097229, 15.6081953], [73.73124695, 15.6081953], [73.73124695, 15.60847282], [73.73319244, 15.60847282], [73.73319244, 15.6081953], [73.73402405, 15.6081953], [73.73402405, 15.60847282], [73.73458099, 15.60846996], [73.73458099, 15.6087513], [73.73513794, 15.6087513], [73.73513794, 15.60846996], [73.73542023, 15.60846996], [73.73542023, 15.6087513], [73.73764038, 15.6087513], [73.73764038, 15.60903072], [73.73902893, 15.60903072], [73.73902893, 15.60846996], [73.73930359, 15.60847282], [73.73930359, 15.6081953], [73.73902893, 15.6081953], [73.73902893, 15.60735989], [73.73929596, 15.60736275], [73.73929596, 15.6070919], [73.74014282, 15.6070919], [73.74014282, 15.60681057], [73.74041748, 15.60681057], [73.74041748, 15.60653114], [73.7409668, 15.60653114], [73.7409668, 15.60625076], [73.74124908, 15.60625076], [73.74124908, 15.60486031], [73.74153137, 15.60486031], [73.74153137, 15.60458374], [73.74263763, 15.60458374], [73.74263763, 15.60486031], [73.74346924, 15.60486031], [73.74346924, 15.60514069], [73.74430847, 15.60514069], [73.74430847, 15.60542107], [73.74514008, 15.6054163], [73.74514008, 15.60569382], [73.74541473, 15.60569382], [73.74541473, 15.60597229], [73.74597168, 15.60597038], [73.74597168, 15.60625076], [73.74624634, 15.60625076], [73.74624634, 15.60653114], [73.74652863, 15.60653114], [73.74652863, 15.60681057], [73.74680328, 15.60681057], [73.74680328, 15.6070919], [73.7470932, 15.6070919], [73.7470932, 15.60764122], [73.74736023, 15.60764122], [73.74736023, 15.60792065], [73.74764252, 15.60791683], [73.74764252, 15.6081953], [73.74847412, 15.6081953], [73.74847412, 15.60847282], [73.74958038, 15.60846996], [73.74958038, 15.6087513], [73.75041962, 15.6087513], [73.75041962, 15.60903072], [73.75096893, 15.60903072], [73.75096893, 15.6093092], [73.75125122, 15.60930538], [73.75125122, 15.6095829], [73.75180817, 15.6095829], [73.75180817, 15.60986137], [73.75208282, 15.60986137], [73.75208282, 15.61042118], [73.75235748, 15.61042118], [73.75235748, 15.61153126], [73.75263977, 15.61153126], [73.75263977, 15.61236095], [73.75291443, 15.61236095], [73.75291443, 15.61347103], [73.75319672, 15.61347103], [73.75319672, 15.61403179], [73.75374603, 15.61403179], [73.75374603, 15.61431026], [73.75402832, 15.61430454], [73.75402832, 15.61486053], [73.75430298, 15.61486053], [73.75430298, 15.61542034], [73.75458527, 15.61541653], [73.75458527, 15.61569309], [73.75485992, 15.61569118], [73.75485992, 15.61736107], [73.75430298, 15.61736107], [73.75430298, 15.61763859], [73.75374603, 15.61763859], [73.75374603, 15.61792183], [73.75319672, 15.61791706], [73.75319672, 15.61819458], [73.75263977, 15.61819458], [73.75263977, 15.61847115], [73.75208282, 15.61847115], [73.75208282, 15.61875153], [73.75152588, 15.61875153], [73.75152588, 15.61903191], [73.75096893, 15.61903191], [73.75096893, 15.61932087], [73.75068665, 15.61932087], [73.75069427, 15.6198616], [73.75041962, 15.6198616], [73.75041962, 15.62014198], [73.74986267, 15.62014198], [73.74986267, 15.62042046], [73.74930573, 15.62041759], [73.74931335, 15.62066174], [73.74903107, 15.62069321], [73.74903107, 15.62097359], [73.74846649, 15.62097073], [73.74846649, 15.62125015], [73.74819183, 15.62125015], [73.74819183, 15.62180996], [73.74791718, 15.62180996], [73.74791718, 15.62263966], [73.74819183, 15.62263966], [73.74819183, 15.62430954], [73.74847412, 15.62430573], [73.74847412, 15.6245842], [73.74819183, 15.62457943], [73.74819183, 15.62485981], [73.74791718, 15.62485981], [73.74791718, 15.62514019], [73.74764252, 15.62513065], [73.74764252, 15.62541962], [73.74736023, 15.6254158], [73.74736023, 15.62569427], [73.74708557, 15.62569427], [73.7470932, 15.62597179], [73.74680328, 15.62597179], [73.74680328, 15.62625027], [73.74652863, 15.62625027], [73.74652863, 15.62652969], [73.74624634, 15.62652969], [73.74624634, 15.62681103], [73.74597168, 15.62681103], [73.74597168, 15.62652969], [73.7454071, 15.62652969], [73.7454071, 15.62625027], [73.74485779, 15.62625027], [73.74485779, 15.62597179], [73.74402618, 15.62597179], [73.74402618, 15.62569237], [73.74375153, 15.62569427], [73.74375153, 15.6254158], [73.74318695, 15.62541962], [73.74318695, 15.62513065], [73.74263763, 15.62514019], [73.74263763, 15.62485981], [73.74236298, 15.62485981], [73.74236298, 15.62457943], [73.74180603, 15.6245842], [73.74180603, 15.62430573], [73.74124908, 15.62430954], [73.74124908, 15.62403011], [73.74069214, 15.62403011], [73.74069214, 15.62374973], [73.74041748, 15.62374973], [73.74041748, 15.62346935], [73.74013519, 15.62347221], [73.74013519, 15.62319374], [73.73986053, 15.62319374], [73.73986053, 15.62291622], [73.73958588, 15.62292004], [73.73958588, 15.62263966], [73.73929596, 15.62263966], [73.73929596, 15.62207031], [73.73902893, 15.62208366], [73.73902893, 15.62125015], [73.73874664, 15.62125015], [73.73874664, 15.6198616], [73.73847198, 15.6198616], [73.73847198, 15.61958122], [73.73874664, 15.61958313], [73.73874664, 15.61930466], [73.73847198, 15.61930466], [73.73847198, 15.6170826], [73.73791504, 15.6170826], [73.73791504, 15.61624908], [73.73735809, 15.61626053], [73.73735809, 15.61542034], [73.73707581, 15.61542034], [73.73707581, 15.61514091], [73.73680115, 15.61514091], [73.73680115, 15.61486053], [73.73652649, 15.61486053], [73.73652649, 15.61458302], [73.73625183, 15.61458302], [73.73625183, 15.61430454], [73.73596954, 15.61430454], [73.73596954, 15.61458302], [73.73569489, 15.61458302], [73.73569489, 15.61486053], [73.73542023, 15.61486053], [73.73542023, 15.61597347], [73.73486328, 15.61597061], [73.73486328, 15.61626053], [73.73430634, 15.61626053], [73.73430634, 15.61652946], [73.73375702, 15.61652946], [73.73375702, 15.61681175], [73.73347473, 15.61680508], [73.73347473, 15.6170826], [73.73319244, 15.6170826], [73.73319244, 15.61680508], [73.73291779, 15.61681175], [73.73291779, 15.61763859], [73.73264313, 15.61763859], [73.73264313, 15.61903191], [73.73236084, 15.61902714], [73.73236084, 15.61958313], [73.73208618, 15.61958122], [73.73208618, 15.62014198], [73.73124695, 15.62014008], [73.73124695, 15.62069321], [73.73097229, 15.62069321], [73.73097229, 15.62097359], [73.73069763, 15.62097073], [73.73069763, 15.62125015], [73.73042297, 15.62125015], [73.73042297, 15.62263966], [73.73014069, 15.62263966], [73.73014069, 15.62292004], [73.7298584, 15.62291622], [73.7298584, 15.62319374], [73.72957611, 15.62319088], [73.72957611, 15.62374973], [73.72930908, 15.62374973], [73.72930908, 15.62403011], [73.72958374, 15.62402821], [73.72958374, 15.6245842], [73.72930908, 15.62457943], [73.72930908, 15.62541962], [73.72902679, 15.6254158], [73.72902679, 15.62569427], [73.72875214, 15.62569237], [73.72875214, 15.62597179], [73.72846985, 15.62597179], [73.72846985, 15.62625027], [73.72819519, 15.62625027], [73.72819519, 15.62708378], [73.7279129, 15.62708187], [73.7279129, 15.62764263], [73.72763062, 15.62764263], [73.72763062, 15.6279211], [73.72735596, 15.6279211], [73.72735596, 15.62820053], [73.72680664, 15.62819386], [73.72680664, 15.62847233], [73.72624969, 15.62847042], [73.72624969, 15.62874985], [73.72569275, 15.62874985], [73.72569275, 15.62903118], [73.7251358, 15.62903118], [73.7251358, 15.62931061], [73.72486115, 15.62930584], [73.72486115, 15.62958431], [73.72319794, 15.62957954], [73.72319794, 15.62985992], [73.72292328, 15.62985992], [73.72292328, 15.6301403], [73.72264099, 15.6301403], [73.72264099, 15.63126183], [73.72292328, 15.63126183], [73.72292328, 15.63153076], [73.72264099, 15.6315279], [73.72264099, 15.63236046], [73.7223587, 15.63236046], [73.7223587, 15.63292122], [73.72208405, 15.63291645], [73.72208405, 15.6334734], [73.72181702, 15.63346958], [73.72180176, 15.63432026], [73.7215271, 15.63432026], [73.7215271, 15.63514137], [73.72125244, 15.63513947], [73.72125244, 15.63569546], [73.72097015, 15.63568974], [73.72097015, 15.63653088], [73.7206955, 15.63652897], [73.7206955, 15.63708305], [73.72041321, 15.63708305], [73.72041321, 15.63736057], [73.72013855, 15.63736057], [73.72013855, 15.63819504], [73.71985626, 15.63819027], [73.71985626, 15.63875103], [73.7195816, 15.63875103], [73.7195816, 15.63903141], [73.71930695, 15.63903141], [73.71930695, 15.63931179], [73.71902466, 15.63930511], [73.71902466, 15.63958263], [73.71875763, 15.63958073], [73.71875763, 15.64014053], [73.71848297, 15.64014053], [73.71848297, 15.64042187], [73.71819305, 15.6404171], [73.71819305, 15.64069462], [73.7179184, 15.6406908], [73.7179184, 15.64181042], [73.71763611, 15.64181042], [73.71763611, 15.64264202], [73.71736145, 15.64264202], [73.71736145, 15.64402866], [73.71708679, 15.64402866], [73.71708679, 15.6451416], [73.71679688, 15.6451416], [73.71679688, 15.64542198], [73.71652985, 15.64542198], [73.71652985, 15.64626122], [73.71624756, 15.64626122], [73.71624756, 15.64680958], [73.71652985, 15.64680481], [73.71652985, 15.64708424], [73.71624756, 15.64708138], [73.71624756, 15.64764023], [73.7159729, 15.64764023], [73.7159729, 15.64819336], [73.71569824, 15.64819336], [73.71569824, 15.64847183], [73.71541595, 15.64847183], [73.71541595, 15.6493063], [73.7151413, 15.6493063], [73.7151413, 15.64958382], [73.71485901, 15.64958096], [73.71485901, 15.65013981], [73.7151413, 15.65013981], [73.7151413, 15.6506958], [73.71541595, 15.65069103], [73.71541595, 15.65264034], [73.71569061, 15.65264034], [73.71569061, 15.65375042], [73.71541595, 15.65375042], [73.71541595, 15.65431118], [73.7151413, 15.65430641], [73.7151413, 15.6548624], [73.71430206, 15.65485954], [73.71430206, 15.65543175], [73.71375275, 15.65541553], [73.71375275, 15.65597153], [73.71347046, 15.65596962], [73.71347046, 15.65625], [73.7131958, 15.65625], [73.7131958, 15.65681076], [73.71291351, 15.65680599], [73.71291351, 15.65847206], [73.71263885, 15.65847206], [73.71263885, 15.66125107], [73.71235657, 15.66124153], [73.71235657, 15.66181087], [73.71208191, 15.66181087], [73.71208191, 15.66264057], [73.71180725, 15.66264057], [73.71180725, 15.66375065], [73.71151733, 15.66375065], [73.71151733, 15.66403103], [73.71180725, 15.66402912], [73.71180725, 15.66458321], [73.71151733, 15.66458035], [73.71151733, 15.66514111], [73.71125031, 15.6651392], [73.71125031, 15.66569519], [73.71097565, 15.66569519], [73.71097565, 15.66708279], [73.71125031, 15.66708279], [73.71125031, 15.66847324], [73.71098328, 15.66847134], [73.71098328, 15.66875076], [73.71069336, 15.66875076], [73.71069336, 15.66902924], [73.7104187, 15.66902924], [73.7104187, 15.66930962], [73.71013641, 15.66930962], [73.71013641, 15.66986084], [73.70986176, 15.66986084], [73.70986176, 15.67043114], [73.7095871, 15.67041683], [73.7095871, 15.6706953], [73.70930481, 15.6706953], [73.70930481, 15.67097092], [73.70903015, 15.67097092], [73.70903015, 15.67124939], [73.70847321, 15.67124939], [73.70847321, 15.67153168], [73.70791626, 15.67153168], [73.70791626, 15.67181015], [73.7076416, 15.67180538], [73.7076416, 15.6720829], [73.70735931, 15.6720829], [73.70735931, 15.67236137], [73.70707703, 15.67236137], [73.70707703, 15.67292023], [73.70680237, 15.67291832], [73.70680237, 15.67347145], [73.70652771, 15.67347145], [73.70652771, 15.67430973], [73.70625305, 15.67430973], [73.70625305, 15.67486191], [73.70597076, 15.67486191], [73.70597076, 15.67514038], [73.70569611, 15.67513657], [73.70569611, 15.67569447], [73.70541382, 15.67569447], [73.70541382, 15.67625046], [73.70513916, 15.67624092], [73.70513916, 15.67653179], [73.70540619, 15.67653179], [73.70540619, 15.67681026], [73.70513916, 15.67681026], [73.70513916, 15.67875195], [73.70485687, 15.67875195], [73.70485687, 15.67903042], [73.70458221, 15.67902756], [73.70458221, 15.67958355], [73.70430756, 15.67958355], [73.70430756, 15.6809721], [73.7040329, 15.68097019], [73.7040329, 15.68181133], [73.70375061, 15.68181133], [73.70375061, 15.68236923], [73.7040329, 15.68236923], [73.7040329, 15.68264008], [73.70375061, 15.68264008], [73.70375061, 15.68431091], [73.70347595, 15.68431091], [73.70347595, 15.68514061], [73.70319366, 15.68513775], [73.70319366, 15.68569374], [73.70263672, 15.68569374], [73.70263672, 15.68597221], [73.70291901, 15.68597031], [73.70291901, 15.68653107], [73.70318604, 15.68653107], [73.70318604, 15.68681145], [73.70291901, 15.68681145], [73.70291901, 15.68764114], [73.70263672, 15.68764114], [73.70263672, 15.68792057], [73.70236206, 15.68792057], [73.70236206, 15.68875122], [73.70207977, 15.68875122], [73.70207977, 15.68931103], [73.70180511, 15.68930531], [73.70180511, 15.6898613], [73.70153046, 15.6898613], [73.70153046, 15.69069481], [73.70124817, 15.69069004], [73.70124817, 15.6912508], [73.70096588, 15.6912508], [73.70096588, 15.69154263], [73.70069122, 15.69154263], [73.70069122, 15.69181156], [73.70041656, 15.69180489], [73.70041656, 15.69208336], [73.69957733, 15.69208145], [73.69957733, 15.69236088], [73.69930267, 15.69236088], [73.69930267, 15.69208145], [73.69790649, 15.69208145], [73.69790649, 15.69431019], [73.69763947, 15.69430542], [73.69763947, 15.69486141], [73.69735718, 15.69486141], [73.69735718, 15.69541931], [73.69708252, 15.69541931], [73.69708252, 15.69680977], [73.69736481, 15.696805], [73.69736481, 15.69819546], [73.69708252, 15.69819546], [73.69708252, 15.69847107], [73.69680786, 15.69847107], [73.69680786, 15.6987524], [73.69708252, 15.6987524], [73.69708252, 15.6993103], [73.69652557, 15.69930458], [73.69652557, 15.69958305], [73.69569397, 15.69958305], [73.69569397, 15.69930458], [73.69541931, 15.69930458], [73.69541931, 15.69958305], [73.69513702, 15.69958305], [73.69513702, 15.69986057], [73.69486237, 15.69986057], [73.69486237, 15.70014191], [73.69430542, 15.70014], [73.69430542, 15.70041847], [73.69403076, 15.70041847], [73.69403076, 15.70208359], [73.69374847, 15.70208073], [73.69374847, 15.70263958], [73.69319153, 15.70263958], [73.69319153, 15.70514011], [73.69347382, 15.70514011], [73.69347382, 15.7070837], [73.69291687, 15.70708179], [73.69291687, 15.70792103], [73.69264221, 15.70792103], [73.69264221, 15.70903015], [73.69235992, 15.70903015], [73.69235992, 15.70931053], [73.69264221, 15.70931053], [73.69264221, 15.71014023], [73.6920929, 15.71014023], [73.6920929, 15.71042061], [73.69180298, 15.71041584], [73.69180298, 15.71069431], [73.69152069, 15.71068954], [73.69152069, 15.71153069], [73.69124603, 15.71153069], [73.69124603, 15.71181107], [73.69097137, 15.7118063], [73.69097137, 15.71208191], [73.69125366, 15.71208191], [73.69125366, 15.71236038], [73.69097137, 15.71235085], [73.69097137, 15.71264076], [73.69124603, 15.71264076], [73.69124603, 15.71375275], [73.69097137, 15.71375275], [73.69097137, 15.71403122], [73.69069672, 15.71403122], [73.69069672, 15.7151413], [73.69041443, 15.71513939], [73.69041443, 15.71569538], [73.69013977, 15.71568966], [73.69013977, 15.71625137], [73.68985748, 15.71625137], [73.68985748, 15.71652889], [73.68958282, 15.71652889], [73.68958282, 15.71708298], [73.68985748, 15.71708012], [73.68985748, 15.71792126], [73.69013977, 15.71792126], [73.69013977, 15.71848202], [73.68985748, 15.71848202], [73.68985748, 15.71875095], [73.68930817, 15.71875095], [73.68930817, 15.71903133], [73.68902588, 15.71903133], [73.68902588, 15.71931171], [73.68846893, 15.71930695], [73.68846893, 15.71958256], [73.68791962, 15.71958065], [73.68791962, 15.71986103], [73.68763733, 15.71986103], [73.68763733, 15.72014141], [73.68708038, 15.72014141], [73.68708038, 15.72042179], [73.68680573, 15.72041702], [73.68680573, 15.72069454], [73.68653107, 15.72069454], [73.68653107, 15.72041702], [73.68624878, 15.72042179], [73.68624878, 15.72014141], [73.68319702, 15.72014141], [73.68319702, 15.72042179], [73.6829071, 15.72042179], [73.6829071, 15.72181034], [73.68125153, 15.72181034], [73.68125153, 15.72152042], [73.68096924, 15.7215271], [73.68096924, 15.72097301], [73.68069458, 15.72097301], [73.68069458, 15.72069454], [73.67986298, 15.72069454], [73.67986298, 15.72097301], [73.67958069, 15.72097301], [73.67958069, 15.7215271], [73.67930603, 15.72152042], [73.67930603, 15.72236061], [73.67958069, 15.72236061], [73.67958069, 15.72291946], [73.67986298, 15.7229166], [73.67986298, 15.7234726], [73.68013763, 15.7234726], [73.68013763, 15.72437096], [73.68245697, 15.7252512], [73.68530273, 15.72587109], [73.69185638, 15.72690964], [73.69734192, 15.72623062], [73.70265961, 15.72491074], [73.70658875, 15.72173023], [73.71098328, 15.7202301], [73.71856689, 15.72161961], [73.72255707, 15.7228899], [73.72764587, 15.72247982], [73.73226166, 15.72058105], [73.73703766, 15.71725082], [73.7410202, 15.71872139], [73.7440567, 15.72564125], [73.74871063, 15.73057079], [73.75824738, 15.73275185], [73.77578735, 15.73053169], [73.78649139, 15.72325039], [73.79321289, 15.72366047], [73.79756927, 15.72509193], [73.80284119, 15.73219967], [73.81262207, 15.73351955], [73.81603241, 15.73526955], [73.82039642, 15.73991013], [73.83303833, 15.73775196], [73.83846283, 15.7488308], [73.84030151, 15.75620174], [73.83878326, 15.76089001], [73.84512329, 15.76336002], [73.84716797, 15.76613045], [73.84963226, 15.77602959], [73.85190582, 15.77841187], [73.856987, 15.77822971], [73.85579681, 15.78326035], [73.8600769, 15.78779125], [73.86158752, 15.79388046], [73.86548615, 15.79752922], [73.87349701, 15.79532146], [73.87593079, 15.79323101], [73.87483978, 15.78634071], [73.87509918, 15.78289986], [73.87986755, 15.779212], [73.88024902, 15.77739143], [73.88685608, 15.77029133], [73.88684082, 15.7671299], [73.88432312, 15.76462078], [73.88260651, 15.75669193], [73.88024139, 15.75255108], [73.88244629, 15.74935055], [73.8859024, 15.74726105], [73.90860748, 15.74233055], [73.91483307, 15.74549198], [73.91793823, 15.74540138], [73.92415619, 15.74282074], [73.94536591, 15.74152184], [73.94976044, 15.73263073], [73.95082092, 15.72322941], [73.95593262, 15.71692085], [73.95886993, 15.71129131], [73.95778656, 15.70735073], [73.9560318, 15.70479107], [73.9586792, 15.70125198], [73.95723724, 15.6967392], [73.96573639, 15.69502068], [73.97130585, 15.68725109], [73.97219849, 15.67669201], [73.97158813, 15.66839123], [73.97570038, 15.65978146], [73.97422791, 15.65467072], [73.97072601, 15.64966106], [73.96926117, 15.64432144], [73.97598267, 15.62894154], [73.98142242, 15.62503147], [73.98606873, 15.62338066], [73.99021149, 15.62063026], [73.99294281, 15.61631107], [73.998703, 15.61112976], [74.002388, 15.6090517], [74.00784302, 15.60829926], [74.01317596, 15.60934067], [74.02793121, 15.60459995], [74.03557587, 15.60929108], [74.03929901, 15.62085056], [74.05680084, 15.62272167], [74.06770325, 15.62471199], [74.0735321, 15.62667179], [74.08055115, 15.62617016], [74.10243988, 15.63896084], [74.10804749, 15.63887024], [74.11263275, 15.64308071], [74.12275696, 15.64522076], [74.12602997, 15.65028954], [74.12896729, 15.65023994], [74.14277649, 15.64711094], [74.14685059, 15.64866066], [74.15497589, 15.64977074], [74.1632309, 15.64859009], [74.16593933, 15.65237999], [74.1734314, 15.65205193], [74.17543793, 15.67016029], [74.17867279, 15.6714201], [74.18302917, 15.67735004], [74.19013214, 15.68098068], [74.19769287, 15.67893028], [74.19811249, 15.67365074], [74.19447327, 15.67214012], [74.19632721, 15.66491127], [74.21154022, 15.66097927], [74.21196747, 15.65849972], [74.20986176, 15.65413094], [74.21324921, 15.64902973], [74.22409058, 15.65031147], [74.22879791, 15.65296078], [74.2284317, 15.65445042], [74.22405243, 15.6588707], [74.23158264, 15.66652012], [74.23683929, 15.66189098], [74.24191284, 15.66585922], [74.24504089, 15.66563129], [74.25525665, 15.65421009], [74.25647736, 15.64680099], [74.25723267, 15.63393974], [74.2545166, 15.62961197], [74.25253296, 15.6238203], [74.25435638, 15.62313175], [74.25942993, 15.62446117], [74.26249695, 15.62291145], [74.26747131, 15.61704922], [74.26854706, 15.60958862], [74.26545715, 15.60160065], [74.26515961, 15.59016037], [74.25637054, 15.58256054], [74.25741577, 15.57549953], [74.25441742, 15.57250118], [74.25431061, 15.56583023], [74.26457977, 15.56079102], [74.26763916, 15.56343937], [74.26988983, 15.56115055], [74.27258301, 15.55426121], [74.27894592, 15.54870033], [74.28292847, 15.54157066], [74.28559875, 15.5341711], [74.28727722, 15.52600002], [74.28279877, 15.52054119], [74.28375244, 15.51945019], [74.2818985, 15.51295185], [74.2681427, 15.50592136], [74.26082611, 15.50084114], [74.25724792, 15.49676132], [74.2563324, 15.48952007], [74.27255249, 15.46523952], [74.2798996, 15.45076084], [74.28251648, 15.44312096], [74.28295898, 15.43748093], [74.27999878, 15.43593121], [74.2826767, 15.43329144], [74.27561951, 15.4239006], [74.27735901, 15.41486931], [74.28144836, 15.4090414], [74.2845459, 15.40151119], [74.28263855, 15.38862038], [74.28624725, 15.38260078], [74.28996277, 15.38121986], [74.30568695, 15.38050175], [74.31282806, 15.37488174], [74.32836914, 15.3672514], [74.32859802, 15.36547089], [74.32364655, 15.36203194], [74.32261658, 15.35725021], [74.32595062, 15.34724045], [74.32840729, 15.3434], [74.32334137, 15.3295908], [74.32797241, 15.31326962], [74.34044647, 15.29680061], [74.34165192, 15.2929306], [74.33412933, 15.28286171], [74.31841278, 15.28192043], [74.30980682, 15.28323078], [74.30230713, 15.28586102], [74.30002594, 15.28230095], [74.29554749, 15.28310966], [74.28914642, 15.27907181], [74.28295898, 15.28129959], [74.27661896, 15.27444935], [74.27275085, 15.26777172], [74.27024078, 15.26093197], [74.26793671, 15.25839138], [74.25752258, 15.25762939], [74.25926208, 15.24999046], [74.26174927, 15.24372196], [74.26351929, 15.24188137], [74.27075195, 15.2385006], [74.27867126, 15.23719025], [74.29427338, 15.23198032], [74.30213165, 15.22814178], [74.3066864, 15.2232008], [74.30670929, 15.21899986], [74.31005859, 15.2134304], [74.31066132, 15.20895195], [74.31163025, 15.20705128], [74.31445313, 15.20561028], [74.31555939, 15.20321274], [74.31577301, 15.19631195], [74.31697083, 15.1910696], [74.32190704, 15.18406963], [74.31813049, 15.17533016], [74.31086731, 15.16203117], [74.30142975, 15.14988136], [74.29782867, 15.14630985], [74.29258728, 15.14767933], [74.28956604, 15.1431303], [74.29122925, 15.13538074], [74.289711, 15.1299696], [74.29144287, 15.12329865], [74.29309082, 15.11996269], [74.2906189, 15.11663055], [74.28824615, 15.10558128], [74.28572845, 15.10373116], [74.28106689, 15.10182953], [74.2783432, 15.09589958], [74.28379059, 15.09401035], [74.28721619, 15.06936073], [74.28900909, 15.0658493], [74.29525757, 15.06269264], [74.29499054, 15.05429173], [74.30120087, 15.04407024], [74.30233765, 15.03985977], [74.29310608, 15.03374958], [74.2890625, 15.0301218], [74.28936768, 15.02656174], [74.28978729, 15.02161121], [74.28186035, 15.01557159], [74.27641296, 15.00964069], [74.27184296, 15.00249195], [74.27291107, 15.00146103], [74.27102661, 14.99880791], [74.27126312, 14.9977417], [74.27159119, 14.9977417], [74.27065277, 14.99489117], [74.26644135, 14.99295139], [74.26171112, 14.9907608], [74.27095795, 14.98042965], [74.27391052, 14.97522163], [74.27095032, 14.97153187], [74.27011871, 14.96664143], [74.2665863, 14.96682072], [74.26434326, 14.96324921], [74.2620697, 14.95755196], [74.25659943, 14.95842171], [74.25100708, 14.9608202], [74.24639893, 14.95866108], [74.24386597, 14.95748997], [74.24167633, 14.94645023], [74.22471619, 14.94134045], [74.2192688, 14.93138027], [74.21183777, 14.9214201], [74.20308685, 14.92742062], [74.20405579, 14.9321003], [74.2041626, 14.93785095], [74.19741821, 14.94326973], [74.19248199, 14.94500923], [74.1902771, 14.95171928], [74.18656158, 14.95338058], [74.18036652, 14.95304966], [74.17215729, 14.95100975], [74.16989899, 14.94729996], [74.16966248, 14.94218063], [74.16609955, 14.93944168], [74.16596222, 14.9367609], [74.17383575, 14.91794014], [74.17516327, 14.91615105], [74.17735291, 14.91320038], [74.17539215, 14.90891933], [74.16982269, 14.90927029], [74.16339111, 14.91325188], [74.15389252, 14.91726971], [74.14922333, 14.91852093], [74.14570618, 14.91743183], [74.13939667, 14.9204607], [74.13622284, 14.91966057], [74.13342285, 14.91594791], [74.13204193, 14.91265011], [74.12652588, 14.91321087], [74.1227417, 14.91264057], [74.11733246, 14.9096117], [74.11308289, 14.91116047], [74.10417175, 14.90375042], [74.10331726, 14.90147972], [74.0973587, 14.89565945], [74.09708405, 14.89569569], [74.09708405, 14.89597225], [74.09680939, 14.89596939], [74.09680176, 14.89624977], [74.0965271, 14.89624977], [74.0965271, 14.89653015], [74.09625244, 14.89652824], [74.09625244, 14.89708424], [74.09597015, 14.89708233], [74.09597015, 14.89764023], [74.09541321, 14.89764023], [74.09541321, 14.89791965], [74.0945816, 14.89791584], [74.0945816, 14.89819431], [74.09402466, 14.89819431], [74.09402466, 14.89847183], [74.09375, 14.89847183], [74.09375, 14.89875031], [74.09263611, 14.89875031], [74.09263611, 14.89902973], [74.09181213, 14.89902973], [74.09181213, 14.89931107], [74.09041595, 14.89931107], [74.09041595, 14.89902973], [74.08981323, 14.89902782], [74.08957672, 14.89902973], [74.08957672, 14.89875031], [74.0890274, 14.89875031], [74.0890274, 14.89847183], [74.08875275, 14.89847183], [74.08875275, 14.89819431], [74.0881958, 14.89819431], [74.0881958, 14.89847183], [74.08763885, 14.89847183], [74.08763885, 14.89875031], [74.08680725, 14.89875031], [74.08680725, 14.89902973], [74.08625031, 14.89902973], [74.08625031, 14.89931107], [74.08569336, 14.8993063], [74.08569336, 14.89958191], [74.08513641, 14.89958191], [74.08513641, 14.89987087], [74.08486176, 14.89987087], [74.08486176, 14.90042019], [74.0845871, 14.90041637], [74.0845871, 14.90069389], [74.08430481, 14.90069389], [74.08430481, 14.90097237], [74.08403015, 14.90097046], [74.08403015, 14.90125179], [74.08347321, 14.90125179], [74.08347321, 14.90153027], [74.08319092, 14.90153027], [74.08319092, 14.90293026], [74.08291626, 14.90291595], [74.08291626, 14.90347195], [74.0826416, 14.90347195], [74.0826416, 14.90458202], [74.08291626, 14.90458202], [74.08291626, 14.90526104], [74.08291626, 14.90569401], [74.08319092, 14.90568066], [74.08319092, 14.90653133], [74.08291626, 14.90652943], [74.08291626, 14.9070816], [74.0826416, 14.9070797], [74.0826416, 14.90764141], [74.08235931, 14.9076376], [74.08235931, 14.90819454], [74.08207703, 14.90818977], [74.08207703, 14.90875053], [74.08152771, 14.90875053], [74.08152771, 14.90903091], [74.08125305, 14.90903091], [74.08125305, 14.90931129], [74.08069611, 14.90930462], [74.08069611, 14.90958309], [74.08041382, 14.90958309], [74.08041382, 14.90986061], [74.07875061, 14.90986061], [74.07875061, 14.91014099], [74.07707977, 14.91014099], [74.07707977, 14.90986061], [74.07624817, 14.90986061], [74.07624817, 14.90958309], [74.07541656, 14.90958309], [74.07541656, 14.90930462], [74.07459259, 14.90931129], [74.07459259, 14.90903091], [74.07430267, 14.90903091], [74.07430267, 14.90931129], [74.07402802, 14.90931129], [74.07402802, 14.90903091], [74.0737381, 14.90903091], [74.0737381, 14.90875053], [74.07290649, 14.90875053], [74.07290649, 14.90847015], [74.07236481, 14.90847301], [74.07236481, 14.90819454], [74.07152557, 14.90819454], [74.07152557, 14.90791702], [74.07125092, 14.90792084], [74.07125092, 14.90764141], [74.07096863, 14.90764141], [74.07096863, 14.90736008], [74.06986237, 14.90736008], [74.06986237, 14.90792084], [74.06958008, 14.90791702], [74.06958008, 14.90847301], [74.06903076, 14.90847015], [74.06903076, 14.90875053], [74.06793213, 14.90875053], [74.06793213, 14.90818977], [74.06735992, 14.90819454], [74.06735992, 14.90791702], [74.0670929, 14.90792084], [74.0670929, 14.90736008], [74.06680298, 14.90736008], [74.06680298, 14.9070797], [74.06652832, 14.9070797], [74.06652832, 14.90736008], [74.06597137, 14.90736008], [74.06597137, 14.90764141], [74.06513977, 14.9076376], [74.06513977, 14.90819454], [74.06485748, 14.90819454], [74.06485748, 14.90847301], [74.06458282, 14.90847015], [74.06458282, 14.90903091], [74.06430817, 14.90902901], [74.06430817, 14.90958309], [74.06375122, 14.90958309], [74.06375122, 14.90986061], [74.06346893, 14.90986061], [74.06346893, 14.91042137], [74.06291962, 14.9104166], [74.06291962, 14.91069508], [74.06236267, 14.91069508], [74.06236267, 14.9104166], [74.06153107, 14.91042137], [74.06153107, 14.90986061], [74.06124878, 14.90986061], [74.06124878, 14.90958309], [74.06104279, 14.90958309], [74.06069183, 14.90958309], [74.06069183, 14.90969181], [74.06069183, 14.90986061], [74.06014252, 14.90986061], [74.06014252, 14.91014099], [74.05958557, 14.91013908], [74.05958557, 14.91069508], [74.05986023, 14.91069508], [74.05986023, 14.9109726], [74.0595932, 14.91097069], [74.0595932, 14.91264057], [74.05930328, 14.91264057], [74.05930328, 14.91292191], [74.05902863, 14.91291714], [74.05902863, 14.91347313], [74.05819702, 14.91347122], [74.05819702, 14.91375065], [74.05735779, 14.91375065], [74.05735779, 14.91403103], [74.05708313, 14.91403103], [74.05708313, 14.91431046], [74.05680847, 14.91430473], [74.05680847, 14.91458321], [74.05652618, 14.91458321], [74.05652618, 14.91430473], [74.05625153, 14.91430473], [74.05625153, 14.91458321], [74.05486298, 14.91458321], [74.05486298, 14.91430473], [74.05264282, 14.91431046], [74.05264282, 14.91403103], [74.05236053, 14.91403103], [74.05236053, 14.91431046], [74.05180359, 14.91430473], [74.05180359, 14.91458321], [74.05041504, 14.91458321], [74.05041504, 14.91486073], [74.04956818, 14.91485023], [74.04956818, 14.9151392], [74.04914856, 14.9151392], [74.04875183, 14.9151392], [74.04875183, 14.91541862], [74.04708099, 14.91541672], [74.04708099, 14.91569519], [74.04680634, 14.91569519], [74.04680634, 14.9159708], [74.04650879, 14.91596889], [74.04650879, 14.91625118], [74.04624939, 14.91625118], [74.04624939, 14.91653156], [74.0459671, 14.91653156], [74.0459671, 14.91681194], [74.04541779, 14.91680527], [74.04541779, 14.91708279], [74.0451355, 14.91708279], [74.0451355, 14.91736126], [74.04458618, 14.91736126], [74.04458618, 14.91764164], [74.04402924, 14.91763878], [74.04402924, 14.91791725], [74.04374695, 14.91791725], [74.04374695, 14.91819477], [74.04319763, 14.91819477], [74.04319763, 14.91847134], [74.04292297, 14.91847134], [74.04292297, 14.91903019], [74.04319763, 14.91903019], [74.04319763, 14.91930962], [74.04291534, 14.91930485], [74.04291534, 14.91958332], [74.04264069, 14.91958141], [74.04264069, 14.92014027], [74.0423584, 14.92014027], [74.0423584, 14.92041969], [74.04207611, 14.92041969], [74.04207611, 14.92152977], [74.0423584, 14.92152977], [74.0423584, 14.92292023], [74.04264069, 14.92291641], [74.04264069, 14.9234724], [74.04292297, 14.92346859], [74.04292297, 14.92375183], [74.04319763, 14.92375183], [74.04319763, 14.92404079], [74.04347229, 14.92404079], [74.04347229, 14.92430973], [74.04402924, 14.92430592], [74.04402924, 14.92458439], [74.04429626, 14.92458153], [74.04429626, 14.92486191], [74.04458618, 14.92486191], [74.04458618, 14.92541981], [74.04486084, 14.9254179], [74.04486084, 14.92708397], [74.04458618, 14.92708397], [74.04458618, 14.92847157], [74.04429626, 14.92846966], [74.04429626, 14.92875004], [74.04402924, 14.92875004], [74.04402924, 14.9293108], [74.04374695, 14.92930603], [74.04374695, 14.92986012], [74.04347229, 14.92986012], [74.04347229, 14.93069363], [74.04514313, 14.93069172], [74.04514313, 14.93124962], [74.04541779, 14.93124962], [74.04541779, 14.93291569], [74.04569244, 14.93291569], [74.04569244, 14.93347168], [74.0459671, 14.93346977], [74.0459671, 14.93375111], [74.04624939, 14.93375111], [74.04624939, 14.93431091], [74.04650879, 14.93431091], [74.04650879, 14.93514061], [74.04624939, 14.93514061], [74.04624939, 14.93681145], [74.04597473, 14.93680668], [74.04597473, 14.93819523], [74.04569244, 14.93819046], [74.04569244, 14.93904018], [74.04541779, 14.93902683], [74.04541779, 14.93958282], [74.0451355, 14.93958282], [74.0451355, 14.9398613], [74.04486084, 14.9398613], [74.04486084, 14.94014072], [74.04458618, 14.94014072], [74.04458618, 14.9404192], [74.04430389, 14.94041729], [74.04430389, 14.94069481], [74.04402924, 14.94069481], [74.04402924, 14.94097328], [74.04374695, 14.94097328], [74.04376221, 14.94124889], [74.04347229, 14.94124889], [74.04347229, 14.94152927], [74.04319763, 14.94152927], [74.04319763, 14.94180965], [74.04292297, 14.94180965], [74.04292297, 14.94292164], [74.04319763, 14.94291687], [74.04319763, 14.94347095], [74.04347229, 14.94347095], [74.04347229, 14.94403172], [74.04376221, 14.94403172], [74.04376221, 14.94431019], [74.04430389, 14.94430542], [74.04430389, 14.94486141], [74.04458618, 14.94484997], [74.04458618, 14.94514179], [74.04486084, 14.94514179], [74.04486084, 14.94542027], [74.0451355, 14.9454174], [74.0451355, 14.94597435], [74.04486084, 14.94597054], [74.04486084, 14.94653034], [74.04458618, 14.94653034], [74.04458618, 14.94680977], [74.04430389, 14.946805], [74.04430389, 14.94708347], [74.04319763, 14.94708061], [74.04319763, 14.94736195], [74.04291534, 14.94736195], [74.04291534, 14.9481926], [74.04319763, 14.9481926], [74.04319763, 14.94791794], [74.04374695, 14.94791794], [74.04374695, 14.94847107], [74.04347229, 14.94847107], [74.04347229, 14.94874954], [74.04319763, 14.94874954], [74.04319763, 14.9493103], [74.04347229, 14.94930553], [74.04347229, 14.94958401], [74.04402924, 14.94958401], [74.04402924, 14.94986153], [74.04624939, 14.94985867], [74.04624939, 14.95014191], [74.04708099, 14.95014191], [74.04708099, 14.95042038], [74.04763794, 14.95041561], [74.04763794, 14.95069408], [74.04736328, 14.95069122], [74.04736328, 14.95098114], [74.04679871, 14.95098114], [74.04679871, 14.95125198], [74.04650879, 14.95125198], [74.04650879, 14.95153046], [74.04624939, 14.95153046], [74.04624939, 14.95181274], [74.04652405, 14.95180607], [74.04652405, 14.95236206], [74.04679871, 14.95236015], [74.04679871, 14.95291996], [74.04708099, 14.95291805], [74.04708099, 14.95402813], [74.04736328, 14.95402813], [74.04736328, 14.95458412], [74.04763794, 14.95458031], [74.04763794, 14.95514011], [74.04792023, 14.95514011], [74.04792023, 14.9556942], [74.04818726, 14.95569038], [74.04818726, 14.95625019], [74.04846954, 14.95625019], [74.04846954, 14.9570837], [74.04930878, 14.9570837], [74.04930878, 14.95736027], [74.05124664, 14.95736027], [74.05124664, 14.9570837], [74.05180359, 14.9570837], [74.05180359, 14.95736027], [74.05347443, 14.95736027], [74.05347443, 14.95819378], [74.05319214, 14.95819378], [74.05319214, 14.95847225], [74.05291748, 14.95847034], [74.05291748, 14.95874977], [74.05236053, 14.95874977], [74.05236053, 14.95903111], [74.05179596, 14.95903111], [74.05179596, 14.95931053], [74.05069733, 14.95931053], [74.05069733, 14.95903111], [74.05042267, 14.95903111], [74.05042267, 14.95874977], [74.04985809, 14.95874977], [74.04985809, 14.95847034], [74.04958344, 14.95847225], [74.04958344, 14.95819378], [74.04875183, 14.95819187], [74.04875183, 14.95903111], [74.04902649, 14.95903111], [74.04902649, 14.96014977], [74.04875183, 14.96013832], [74.04875183, 14.96069431], [74.04846954, 14.96068954], [74.04846954, 14.96153069], [74.04819489, 14.96152878], [74.04819489, 14.96208191], [74.04792023, 14.96208], [74.04792023, 14.96292114], [74.04763794, 14.96291733], [74.04763794, 14.96347332], [74.04736328, 14.96347046], [74.04736328, 14.96431065], [74.04708099, 14.96431065], [74.04708099, 14.9651413], [74.04680634, 14.96513939], [74.04680634, 14.96569538], [74.04650879, 14.96568966], [74.04650879, 14.96652889]]], [[[73.86235809, 15.40792179], [73.86235809, 15.40848064], [73.86429596, 15.40848064], [73.86429596, 15.40819073], [73.86541748, 15.40819359], [73.86541748, 15.40736198], [73.86569214, 15.40736198], [73.86569214, 15.40653038], [73.86541748, 15.40653038], [73.86541748, 15.40431023], [73.86514282, 15.40431023], [73.86514282, 15.40403175], [73.86541748, 15.40403175], [73.86541748, 15.40374947], [73.86513519, 15.40374947], [73.86513519, 15.40347099], [73.86319733, 15.40347099], [73.86319733, 15.40319633], [73.86264038, 15.40319633], [73.86264038, 15.40347099], [73.86235809, 15.40347099], [73.86235809, 15.40374947], [73.86207581, 15.40374947], [73.86207581, 15.40431023], [73.86180878, 15.40430546], [73.86180878, 15.40458393], [73.86152649, 15.40458107], [73.86152649, 15.40514183], [73.86125183, 15.40513992], [73.86125183, 15.40597057], [73.86152649, 15.40597057], [73.86152649, 15.40708447], [73.86180878, 15.40708065], [73.86180878, 15.40792179], [73.86235809, 15.40792179]]]]}}, {\\\"id\\\": \\\"9\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.11_1\\\", \\\"HASC_1\\\": \\\"IN.GJ\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Gujarat\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Goudjerate|Gujerat|Gujerate\\\", \\\"apm25_popweighted\\\": 96.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1860.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1021.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2881.0, \\\"geo-id\\\": 9, \\\"hpm25_child_popweighted\\\": 131.5, \\\"hpm25_female_popweighted\\\": 151.1, \\\"hpm25_male_popweighted\\\": 108.8, \\\"location\\\": \\\"Gujarat\\\", \\\"mort_apm25_6cod_mean_total\\\": 36829.0, \\\"mort_hpm25_6cod_mean_total\\\": 20217.0, \\\"mort_tpm25_6cod_mean_total\\\": 57047.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[72.84597015, 20.76320076], [72.84597015, 20.76292992], [72.84625244, 20.76292992], [72.84625244, 20.76264], [72.8465271, 20.76264], [72.8465271, 20.76235962], [72.84707642, 20.76235962], [72.84707642, 20.76264], [72.84728241, 20.76264], [72.84902954, 20.76264], [72.84902954, 20.76235962], [72.84958649, 20.76236153], [72.84958649, 20.76208305], [72.85041809, 20.76208305], [72.85041809, 20.76180649], [72.8520813, 20.7618103], [72.8520813, 20.76152992], [72.8529129, 20.76152992], [72.8529129, 20.76124954], [72.85346985, 20.76124954], [72.85346985, 20.76097107], [72.85375214, 20.76097488], [72.85375214, 20.7606945], [72.85402679, 20.7606945], [72.85402679, 20.76041603], [72.85430908, 20.76041985], [72.85430908, 20.76013947], [72.85457611, 20.76013947], [72.85457611, 20.7598629], [72.85486603, 20.7598629], [72.8548584, 20.75958061], [72.85541534, 20.75958061], [72.85541534, 20.75902748], [72.85569763, 20.75902939], [72.85569763, 20.75847054], [72.85597229, 20.75847054], [72.85597229, 20.7579174], [72.85624695, 20.75792122], [72.85624695, 20.75736237], [72.85652924, 20.75736237], [72.85652924, 20.75708008], [72.85680389, 20.75708389], [72.85680389, 20.75669098], [72.85680389, 20.75597191], [72.85708618, 20.75597191], [72.85708618, 20.75541687], [72.85736084, 20.75542068], [72.85736084, 20.75402832], [72.85764313, 20.75402832], [72.85764313, 20.75263977], [72.85736084, 20.75263977], [72.85736084, 20.75235939], [72.85652924, 20.7523613], [72.85652924, 20.75208282], [72.8548584, 20.75208282], [72.8548584, 20.7523613], [72.85430908, 20.75235939], [72.85430908, 20.75263977], [72.85098267, 20.75263977], [72.85098267, 20.75291824], [72.8493042, 20.75291634], [72.8493042, 20.75319481], [72.8484726, 20.75319481], [72.8484726, 20.75347137], [72.84764099, 20.75346947], [72.84764099, 20.75375938], [72.84707642, 20.75375938], [72.84707642, 20.75402832], [72.84680176, 20.75402832], [72.84680176, 20.75430489], [72.8465271, 20.75430489], [72.8465271, 20.75458336], [72.84625244, 20.75458336], [72.84625244, 20.75486183], [72.84597015, 20.75485992], [72.84597015, 20.75542068], [72.8456955, 20.75541687], [72.8456955, 20.75597191], [72.84541321, 20.75596809], [72.84541321, 20.75624847], [72.84513855, 20.75624847], [72.84513855, 20.75680542], [72.84486389, 20.75680542], [72.84486389, 20.75708389], [72.8445816, 20.75708008], [72.8445816, 20.75764275], [72.84430695, 20.75764275], [72.84430695, 20.75875282], [72.84401703, 20.75875282], [72.84401703, 20.76152992], [72.84430695, 20.76152992], [72.84430695, 20.76292992], [72.8445816, 20.76292992], [72.8445816, 20.76320076], [72.84597015, 20.76320076]]], [[[71.51625061, 20.91430473], [71.51625061, 20.91402817], [71.5165329, 20.91402817], [71.5165329, 20.91374969], [71.5173645, 20.91374969], [71.51735687, 20.91320038], [71.51763916, 20.91320038], [71.51763916, 20.91291809], [71.51790619, 20.91291809], [71.51790619, 20.91208076], [71.51819611, 20.91208267], [71.51819611, 20.91069412], [71.51791382, 20.91069412], [71.51791382, 20.91013908], [71.51819611, 20.91014099], [71.51819611, 20.90958023], [71.51847076, 20.90958595], [71.51847076, 20.9090271], [71.51875305, 20.90903091], [71.51875305, 20.90875053], [71.51902771, 20.90875053], [71.51902771, 20.90764046], [71.51957703, 20.90764046], [71.51957703, 20.90681076], [71.5201416, 20.90681076], [71.5201416, 20.90625191], [71.52179718, 20.90625191], [71.52179718, 20.90596962], [71.52458191, 20.90597343], [71.52458191, 20.90625191], [71.52513885, 20.90625191], [71.52513885, 20.90653038], [71.52540588, 20.90653038], [71.52540588, 20.90681076], [71.52680206, 20.90681076], [71.52680206, 20.90625191], [71.52707672, 20.90625191], [71.52707672, 20.90596962], [71.52841949, 20.90597343], [71.52874756, 20.90597343], [71.52874756, 20.90569496], [71.52902985, 20.90570068], [71.52902985, 20.9054203], [71.52986145, 20.9054203], [71.52986145, 20.90514183], [71.53013611, 20.90514183], [71.53013611, 20.90485954], [71.5304184, 20.90485954], [71.5304184, 20.9034729], [71.53013611, 20.9034729], [71.53013611, 20.90319443], [71.5293045, 20.90319443], [71.5293045, 20.90291595], [71.5284729, 20.90291595], [71.5284729, 20.90319443], [71.52780914, 20.90319443], [71.5276413, 20.90319443], [71.5276413, 20.9034729], [71.52625275, 20.9034729], [71.52625275, 20.90319443], [71.52430725, 20.90319443], [71.52430725, 20.9034729], [71.52375031, 20.90346909], [71.52375031, 20.90374947], [71.52263641, 20.90374947], [71.52263641, 20.90346909], [71.52180481, 20.9034729], [71.52180481, 20.90319443], [71.51985931, 20.90319443], [71.51985931, 20.9034729], [71.51930237, 20.90346909], [71.51930237, 20.90374947], [71.51846313, 20.90374947], [71.51846313, 20.90403175], [71.51790619, 20.90403175], [71.51790619, 20.90431976], [71.51763916, 20.90430641], [71.51763916, 20.90458107], [71.51569366, 20.90458107], [71.51569366, 20.90402794], [71.51457977, 20.90403175], [71.51457977, 20.90374947], [71.51374817, 20.90374947], [71.51374817, 20.90346909], [71.51208496, 20.9034729], [71.51208496, 20.90319443], [71.51152802, 20.90319443], [71.51152802, 20.90291595], [71.51040649, 20.90292168], [71.51040649, 20.90263939], [71.51013947, 20.90263939], [71.51013947, 20.90236092], [71.50958252, 20.90236092], [71.50958252, 20.90292168], [71.50902557, 20.90291595], [71.50902557, 20.90319443], [71.50736237, 20.90319443], [71.50736237, 20.90291595], [71.50708008, 20.90291595], [71.50708008, 20.90319443], [71.50680542, 20.90319443], [71.50681305, 20.90374947], [71.50652313, 20.90374947], [71.50652313, 20.90431976], [71.50736237, 20.90430641], [71.50736237, 20.90458107], [71.50763702, 20.90457916], [71.50763702, 20.90514183], [71.50791931, 20.90514183], [71.50791931, 20.90570068], [71.50818634, 20.90570068], [71.50818634, 20.90625191], [71.50846863, 20.90625191], [71.50846863, 20.90681076], [71.50902557, 20.90680313], [71.50902557, 20.9070816], [71.50986481, 20.9070816], [71.50986481, 20.90736389], [71.51041412, 20.90736389], [71.51041412, 20.9081955], [71.51069641, 20.9081955], [71.51069641, 20.90847206], [71.51125336, 20.90847015], [71.51125336, 20.90875053], [71.51180267, 20.90875053], [71.51180267, 20.90903091], [71.51235962, 20.90903091], [71.51235962, 20.90930939], [71.51291656, 20.90930557], [71.51291656, 20.91069412], [71.51264191, 20.91069412], [71.51264954, 20.91110039], [71.51264954, 20.91125107], [71.51235962, 20.91124916], [71.51235962, 20.91208267], [71.51264191, 20.91208267], [71.51264191, 20.91236115], [71.51291656, 20.91236115], [71.51291656, 20.91263962], [71.51403046, 20.91263962], [71.51403046, 20.91291809], [71.51457977, 20.91291809], [71.51457977, 20.91320038], [71.51513672, 20.91320038], [71.51513672, 20.91374969], [71.51541901, 20.91374969], [71.51541901, 20.91402817], [71.51597595, 20.91402817], [71.51597595, 20.91430473], [71.51625061, 20.91430473]]], [[[71.38847351, 20.8670845], [71.38847351, 20.86652756], [71.38819122, 20.86652946], [71.38819122, 20.8662529], [71.38791656, 20.8662529], [71.38791656, 20.86569023], [71.38764191, 20.86569214], [71.38764191, 20.86514091], [71.38735962, 20.86515045], [71.38735962, 20.8647995], [71.38735962, 20.8643055], [71.38764191, 20.86431122], [71.38764191, 20.86346817], [71.38680267, 20.86346817], [71.38680267, 20.86375237], [71.38652802, 20.86375237], [71.38652802, 20.86403275], [71.38625336, 20.86403275], [71.38625336, 20.86431122], [71.38597107, 20.86431122], [71.38597107, 20.86541939], [71.38611603, 20.86541748], [71.38625336, 20.86541748], [71.38625336, 20.86569214], [71.38652802, 20.86569214], [71.38652802, 20.86597061], [71.38680267, 20.86597061], [71.38680267, 20.8662529], [71.38707733, 20.8662529], [71.38707733, 20.86680984], [71.38735962, 20.86680603], [71.38735962, 20.8670845], [71.38847351, 20.8670845]]], [[[71.64901733, 20.97792053], [71.64901733, 20.97735977], [71.64930725, 20.97736168], [71.64930725, 20.97652817], [71.64901733, 20.97653961], [71.64901733, 20.97624969], [71.64875031, 20.97624969], [71.64875031, 20.97597122], [71.64847565, 20.97597313], [71.64847565, 20.97458458], [71.64763641, 20.97458076], [71.64763641, 20.97486115], [71.64736176, 20.97486115], [71.64736176, 20.97513962], [71.64653015, 20.97513962], [71.64653015, 20.97486115], [71.64597321, 20.97486115], [71.64597321, 20.97458076], [71.64430237, 20.97458076], [71.64430237, 20.97513962], [71.64402771, 20.97513962], [71.64402771, 20.97569466], [71.64430237, 20.97569084], [71.64430237, 20.97624969], [71.64457703, 20.97624969], [71.64457703, 20.97653961], [71.64485931, 20.97652817], [71.64485931, 20.97680664], [71.6451416, 20.97680664], [71.6451416, 20.97708321], [71.64597321, 20.97708321], [71.64597321, 20.97736168], [71.6470871, 20.97735977], [71.6470871, 20.97764015], [71.6479187, 20.97764015], [71.6479187, 20.97792053], [71.64901733, 20.97792053]]], [[[71.68653107, 20.99652863], [71.68653107, 20.99624825], [71.68681335, 20.99624825], [71.68680573, 20.99597168], [71.68708038, 20.99597168], [71.68708038, 20.99569511], [71.68736267, 20.99570084], [71.68736267, 20.99542046], [71.68763733, 20.99542046], [71.68763733, 20.99513817], [71.68791962, 20.99513817], [71.68791962, 20.99458122], [71.68763733, 20.99458313], [71.68763733, 20.99347305], [71.68736267, 20.99347305], [71.68736267, 20.99331093], [71.68736267, 20.99152756], [71.68569183, 20.99151993], [71.68569183, 20.99180984], [71.68541718, 20.99180794], [71.68541718, 20.9920826], [71.68486023, 20.9920826], [71.68486023, 20.99180794], [71.68125153, 20.99180984], [71.68125153, 20.99151993], [71.68096924, 20.99152756], [71.68096924, 20.99124908], [71.68068695, 20.99125099], [71.68068695, 20.99097061], [71.68041992, 20.99097252], [71.68041992, 20.99069595], [71.68013763, 20.99069595], [71.68013763, 20.99041748], [71.67986298, 20.99041939], [71.67986298, 20.99014091], [71.67958069, 20.99014091], [71.67958069, 20.98986053], [71.67930603, 20.98986053], [71.67930603, 20.98958015], [71.67874908, 20.98958588], [71.67874908, 20.9893055], [71.67819214, 20.98931122], [71.67819214, 20.98903084], [71.67764282, 20.98903084], [71.67764282, 20.98875046], [71.67791748, 20.98875046], [71.67791748, 20.98847961], [71.67819214, 20.98847961], [71.67819214, 20.98792076], [71.67791748, 20.98792076], [71.67791748, 20.98764038], [71.67764282, 20.98764038], [71.67764282, 20.98736], [71.67736053, 20.98736382], [71.67736053, 20.98680305], [71.67708588, 20.98681068], [71.67708588, 20.9865303], [71.67679596, 20.9865303], [71.67679596, 20.98625183], [71.67652893, 20.98625183], [71.67652893, 20.98596954], [71.67624664, 20.98597145], [71.67624664, 20.98569489], [71.67597198, 20.98569489], [71.67597198, 20.98513794], [71.67569733, 20.98514175], [71.67569733, 20.98485947], [71.67430878, 20.98485947], [71.67430878, 20.98514175], [71.67375183, 20.98514175], [71.67375183, 20.98542023], [71.67402649, 20.98541641], [71.67402649, 20.98597145], [71.67430878, 20.98596954], [71.67430878, 20.9865303], [71.67402649, 20.9865284], [71.67402649, 20.98708153], [71.67375183, 20.98707962], [71.67375183, 20.98764038], [71.67402649, 20.98764038], [71.67402649, 20.98875046], [71.67430878, 20.98875046], [71.67430878, 20.98958588], [71.67457581, 20.98958015], [71.67457581, 20.99014091], [71.67402649, 20.99014091], [71.67402649, 20.99041939], [71.67375183, 20.99041748], [71.67375183, 20.99069595], [71.67333984, 20.99069595], [71.67319489, 20.99069595], [71.67319489, 20.99097252], [71.67292023, 20.99097061], [71.67292023, 20.99125099], [71.67318726, 20.99125099], [71.67318726, 20.99180984], [71.67346954, 20.99180794], [71.67346954, 20.9920826], [71.67375183, 20.99208069], [71.67375183, 20.99263954], [71.67402649, 20.99263954], [71.67402649, 20.99291992], [71.67458344, 20.99291611], [71.67458344, 20.99319458], [71.67514038, 20.99319458], [71.67514038, 20.99347305], [71.67541504, 20.99347305], [71.67541504, 20.99374962], [71.67597198, 20.99374962], [71.67597198, 20.99430466], [71.67652893, 20.99430466], [71.67652893, 20.99458313], [71.67736053, 20.99458313], [71.67736053, 20.9948616], [71.67791748, 20.9948597], [71.67791748, 20.99513817], [71.67874908, 20.99513817], [71.67874908, 20.99542046], [71.67986298, 20.99542046], [71.67986298, 20.99570084], [71.68069458, 20.99569511], [71.68069458, 20.99597168], [71.68180847, 20.99596977], [71.68180847, 20.99624825], [71.68264008, 20.99624825], [71.68264008, 20.99652863], [71.68653107, 20.99652863]]], [[[71.70375061, 20.99958229], [71.70375061, 20.99930573], [71.7040329, 20.99930954], [71.7040329, 20.99903107], [71.70458221, 20.99903107], [71.70458221, 20.99875259], [71.70513153, 20.99875259], [71.70513153, 20.99765015], [71.70485687, 20.99765015], [71.70485687, 20.99707985], [71.70458221, 20.99708366], [71.70458221, 20.99652863], [71.70430756, 20.99652863], [71.70430756, 20.99624825], [71.70402527, 20.99624825], [71.70402527, 20.99569511], [71.70375061, 20.99570084], [71.70375061, 20.99513817], [71.70291901, 20.99513817], [71.70291901, 20.99570084], [71.70263672, 20.99569511], [71.70263672, 20.99597168], [71.70236206, 20.99596977], [71.70236206, 20.99652863], [71.70181274, 20.99652863], [71.70181274, 20.99624825], [71.69847107, 20.99624825], [71.69847107, 20.99652863], [71.69568634, 20.99652863], [71.69568634, 20.99681091], [71.69541931, 20.99681091], [71.69541931, 20.99736023], [71.69568634, 20.99736023], [71.69568634, 20.99765015], [71.69625092, 20.99765015], [71.69625092, 20.9979229], [71.69652557, 20.99791718], [71.69652557, 20.99819374], [71.69708252, 20.99819374], [71.69708252, 20.99847031], [71.69735718, 20.99847031], [71.69735718, 20.99875259], [71.69790649, 20.99875259], [71.69790649, 20.99903107], [71.69819641, 20.99903107], [71.69819641, 20.99930954], [71.69985962, 20.99930573], [71.69985962, 20.99958229], [71.70375061, 20.99958229]]], [[[71.7104187, 20.99958229], [71.7104187, 20.99930573], [71.71153259, 20.99930954], [71.71153259, 20.99903107], [71.71263885, 20.99903107], [71.71263885, 20.99875259], [71.7140274, 20.99875259], [71.7140274, 20.99765015], [71.71347046, 20.99765015], [71.71347046, 20.99736023], [71.71290588, 20.99736023], [71.71290588, 20.99707985], [71.71125031, 20.99708366], [71.71125031, 20.99680519], [71.7104187, 20.99681091], [71.7104187, 20.99652863], [71.70819092, 20.99652863], [71.70819092, 20.99681091], [71.70735931, 20.99680519], [71.70735931, 20.99708366], [71.70625305, 20.99707985], [71.70625305, 20.99736023], [71.70597076, 20.99736023], [71.70597076, 20.99847031], [71.70652771, 20.99847031], [71.70652771, 20.99875259], [71.70735931, 20.99875259], [71.70735931, 20.99903107], [71.70791626, 20.99903107], [71.70791626, 20.99930954], [71.70847321, 20.99930573], [71.70847321, 20.99958229], [71.7104187, 20.99958229]]], [[[72.64763641, 21.07624817], [72.64763641, 21.07541847], [72.6479187, 21.07541847], [72.6479187, 21.07513809], [72.64819336, 21.07513809], [72.64819336, 21.07485962], [72.64875031, 21.07486153], [72.64875031, 21.07458305], [72.64902496, 21.07458305], [72.64902496, 21.07430649], [72.64985657, 21.0743103], [72.64985657, 21.07402992], [72.65040588, 21.07402992], [72.65040588, 21.0743103], [72.6506958, 21.0743103], [72.6506958, 21.07402992], [72.65097046, 21.07402992], [72.65097046, 21.07374954], [72.65235901, 21.07374954], [72.65235901, 21.07458305], [72.6526413, 21.07458305], [72.6526413, 21.07430649], [72.65402985, 21.0743103], [72.65402985, 21.07402992], [72.65429688, 21.07402992], [72.65429688, 21.07374954], [72.65458679, 21.07374954], [72.65458679, 21.07319069], [72.65486145, 21.0731945], [72.65486145, 21.07263947], [72.65513611, 21.07263947], [72.65513611, 21.07208061], [72.6554184, 21.07208252], [72.6554184, 21.07152748], [72.65569305, 21.07152939], [72.65569305, 21.07125092], [72.65598297, 21.07125092], [72.65597534, 21.07097244], [72.65625, 21.07097244], [72.65625, 21.07069588], [72.65652466, 21.07069588], [72.65652466, 21.06902695], [72.65625763, 21.06903076], [72.65625763, 21.06847], [72.6570816, 21.06847382], [72.6570816, 21.06791687], [72.65735626, 21.06792068], [72.65735626, 21.06707954], [72.65763855, 21.06708145], [72.65763855, 21.06680489], [72.65791321, 21.06680489], [72.65791321, 21.06569481], [72.65763855, 21.06569481], [72.65763855, 21.06541634], [72.65735626, 21.06542015], [72.65735626, 21.06514168], [72.65598297, 21.06514168], [72.65598297, 21.06542015], [72.65569305, 21.06541634], [72.65569305, 21.06569481], [72.65597534, 21.06569481], [72.65597534, 21.06624985], [72.65625, 21.06624985], [72.65625, 21.06708145], [72.65597534, 21.06708145], [72.65597534, 21.06680489], [72.65513611, 21.06680489], [72.65513611, 21.06652832], [72.65374756, 21.06653023], [72.65374756, 21.06624985], [72.65291595, 21.06624985], [72.65291595, 21.06542015], [72.65208435, 21.06541634], [72.65208435, 21.06569481], [72.6515274, 21.06569481], [72.6515274, 21.06597137], [72.65097046, 21.06597137], [72.65097046, 21.06708145], [72.65013885, 21.06708145], [72.65013885, 21.06680489], [72.64930725, 21.06680489], [72.64930725, 21.06736374], [72.64875031, 21.06735992], [72.64875031, 21.0676403], [72.64819336, 21.0676403], [72.64819336, 21.06792068], [72.6479187, 21.06792068], [72.6479187, 21.06820107], [72.64819336, 21.06819534], [72.64819336, 21.06847382], [72.64847565, 21.06847382], [72.64848328, 21.06875038], [72.64819336, 21.06875038], [72.64819336, 21.06903076], [72.6479187, 21.06902695], [72.6479187, 21.0695858], [72.64763641, 21.06957054], [72.64763641, 21.06986046], [72.6470871, 21.06986046], [72.6470871, 21.07042122], [72.64680481, 21.0704174], [72.64680481, 21.07069588], [72.64653015, 21.07069588], [72.64653015, 21.07097244], [72.64624786, 21.07097054], [72.64624786, 21.07125092], [72.64597321, 21.07125092], [72.64597321, 21.07152939], [72.64541626, 21.07152748], [72.64541626, 21.07208252], [72.64569092, 21.07208061], [72.64569092, 21.07236099], [72.64597321, 21.07236099], [72.64597321, 21.07263947], [72.64624786, 21.07263947], [72.64624786, 21.07374954], [72.64597321, 21.07374954], [72.64597321, 21.07402992], [72.64569092, 21.07402611], [72.64569092, 21.07430077], [72.64541626, 21.0743103], [72.64541626, 21.07513809], [72.64569092, 21.07513809], [72.64569092, 21.07570076], [72.64597321, 21.07570076], [72.64597321, 21.07624817], [72.64763641, 21.07624817]]], [[[72.67930603, 21.09875107], [72.67930603, 21.09819031], [72.67958069, 21.09819412], [72.67958069, 21.09795952], [72.67958069, 21.09763908], [72.68013763, 21.09764099], [72.68013763, 21.09708023], [72.68041992, 21.09708595], [72.68041992, 21.0965271], [72.68068695, 21.09653091], [72.68068695, 21.09542084], [72.68013763, 21.09541702], [72.68013763, 21.0956955], [72.67986298, 21.09568977], [72.67986298, 21.09625053], [72.67958069, 21.09625053], [72.67958069, 21.09653091], [72.67903137, 21.09653091], [72.67903137, 21.09680939], [72.67874908, 21.09680557], [72.67874908, 21.09806061], [72.67874908, 21.09819412], [72.6784668, 21.09819031], [72.6784668, 21.09875107], [72.67930603, 21.09875107]]], [[[72.67208099, 21.11514091], [72.67208099, 21.11431122], [72.67236328, 21.11431122], [72.67236328, 21.11347008], [72.67263794, 21.11347198], [72.67263794, 21.11291885], [72.67236328, 21.11292076], [72.67236328, 21.10764122], [72.67263794, 21.10764122], [72.67263794, 21.10597038], [72.67292023, 21.10597038], [72.67292023, 21.10430527], [72.67318726, 21.1043129], [72.67318726, 21.10346985], [72.67346954, 21.10347176], [72.67346954, 21.10263824], [72.67375183, 21.10263824], [72.67375183, 21.10207939], [72.67402649, 21.10208321], [72.67402649, 21.10180473], [72.67430878, 21.10180473], [72.67430878, 21.10124969], [72.67457581, 21.10124969], [72.67457581, 21.10097122], [72.67485809, 21.10097313], [72.67485809, 21.10069466], [72.67541504, 21.10069466], [72.67541504, 21.10041618], [72.67569733, 21.10041809], [72.67569733, 21.09987068], [72.67624664, 21.09987068], [72.67624664, 21.09902954], [72.67652893, 21.09902954], [72.67652893, 21.09830284], [72.67652893, 21.09791756], [72.67624664, 21.09791946], [72.67624664, 21.09708023], [72.67430115, 21.09708023], [72.67430115, 21.09764099], [72.67402649, 21.09764099], [72.67402649, 21.09875107], [72.67375183, 21.09875107], [72.67375183, 21.09902954], [72.67318726, 21.09902954], [72.67318726, 21.09930992], [72.67292023, 21.09930611], [72.67292023, 21.09958267], [72.67236328, 21.09958076], [72.67236328, 21.09987068], [72.67208099, 21.09987068], [72.67208099, 21.10013962], [72.67151642, 21.10013962], [72.67151642, 21.10041809], [72.67124939, 21.10041618], [72.67124939, 21.10097313], [72.6709671, 21.10097122], [72.6709671, 21.10124969], [72.67069244, 21.10124969], [72.67069244, 21.10180473], [72.67041779, 21.10180092], [72.67041779, 21.10320091], [72.6701355, 21.10319519], [72.6701355, 21.10347176], [72.66986084, 21.10347176], [72.66986084, 21.10458374], [72.66958618, 21.10458183], [72.66958618, 21.10486031], [72.66929626, 21.10486031], [72.66929626, 21.10542107], [72.66958618, 21.10542107], [72.66958618, 21.10791969], [72.66929626, 21.10791969], [72.66929626, 21.10931015], [72.66958618, 21.10930634], [72.66958618, 21.11097145], [72.66929626, 21.11096954], [72.66929626, 21.11124992], [72.66958618, 21.11124992], [72.66958618, 21.11208344], [72.66986084, 21.11208344], [72.66986084, 21.11347198], [72.67014313, 21.11347008], [72.67014313, 21.11403084], [72.67041779, 21.11402893], [72.67041779, 21.11486053], [72.67124176, 21.114851], [72.67124176, 21.11514091], [72.67208099, 21.11514091]]], [[[72.70207977, 21.12236023], [72.70207977, 21.12070084], [72.70236206, 21.12070084], [72.70236206, 21.11790848], [72.70263672, 21.11791611], [72.70263672, 21.11680603], [72.70291901, 21.11681175], [72.70291901, 21.11624908], [72.70318604, 21.11624908], [72.70318604, 21.11458015], [72.70291901, 21.11458397], [72.70291901, 21.11402893], [72.70263672, 21.11403084], [72.70263672, 21.11347008], [72.70236206, 21.11347198], [72.70236206, 21.11319351], [72.70207977, 21.11319351], [72.70207977, 21.11291885], [72.70181274, 21.11292076], [72.70181274, 21.11264038], [72.70069122, 21.11264038], [72.70069122, 21.11236], [72.69957733, 21.11236], [72.69957733, 21.11264038], [72.69930267, 21.11263847], [72.69930267, 21.11319351], [72.69902802, 21.11319351], [72.69902802, 21.11347198], [72.69875336, 21.11347008], [72.69875336, 21.11375046], [72.69847107, 21.11375046], [72.69847107, 21.11514091], [72.69819641, 21.1151371], [72.69819641, 21.11569405], [72.69790649, 21.11569023], [72.69790649, 21.11653137], [72.69763947, 21.11653137], [72.69763947, 21.11681175], [72.69819641, 21.11681175], [72.69819641, 21.11903191], [72.69847107, 21.11902809], [72.69847107, 21.11930466], [72.69875336, 21.11930466], [72.69875336, 21.11958122], [72.69902802, 21.11958122], [72.69902802, 21.11986351], [72.69930267, 21.1198597], [72.69930267, 21.12014008], [72.69957733, 21.12014008], [72.69957733, 21.12042046], [72.70014191, 21.12041664], [72.70014191, 21.12097359], [72.70041656, 21.12096977], [72.70041656, 21.12125015], [72.70096588, 21.12125015], [72.70096588, 21.12153053], [72.70124817, 21.12153053], [72.70124817, 21.12181091], [72.70153046, 21.12180328], [72.70153046, 21.12208557], [72.70180511, 21.12208557], [72.70180511, 21.12236023], [72.70207977, 21.12236023]]], [[[72.67652893, 21.15570068], [72.67652893, 21.1554184], [72.67764282, 21.1554184], [72.67764282, 21.15513992], [72.67874908, 21.15513992], [72.67874908, 21.15485954], [72.67930603, 21.15486145], [72.67930603, 21.15458298], [72.68013763, 21.15458298], [72.68013763, 21.15430641], [72.68042755, 21.15430832], [72.68042755, 21.15402031], [72.68069458, 21.15402794], [72.68069458, 21.15374947], [72.68096924, 21.15374947], [72.68096924, 21.15347099], [72.68180847, 21.1534729], [72.68180847, 21.15319443], [72.68208313, 21.15319443], [72.68208313, 21.15291786], [72.68264008, 21.15291977], [72.68264008, 21.15263939], [72.6829071, 21.15263939], [72.6829071, 21.15236092], [72.68486023, 21.15236092], [72.68486023, 21.15208054], [72.68569183, 21.15208244], [72.68569183, 21.15180779], [72.68624115, 21.15180969], [72.68624115, 21.15153122], [72.68736267, 21.15153122], [72.68736267, 21.15125084], [72.68818665, 21.15125084], [72.68818665, 21.15098], [72.68846893, 21.15098], [72.68846893, 21.15069008], [72.68902588, 21.1506958], [72.68902588, 21.15041733], [72.6904068, 21.15042114], [72.6904068, 21.14986038], [72.69152832, 21.14986038], [72.69152832, 21.14958], [72.69264221, 21.14958572], [72.69264221, 21.14930344], [72.69346619, 21.14931107], [72.69346619, 21.14903069], [72.69374847, 21.14903069], [72.69374847, 21.14875031], [72.69403076, 21.14875031], [72.69403076, 21.14846992], [72.69458008, 21.14847374], [72.69458008, 21.14819527], [72.69541168, 21.14821053], [72.69541168, 21.14792061], [72.69596863, 21.14792061], [72.69596863, 21.14764023], [72.69680786, 21.14764023], [72.69680786, 21.14735985], [72.69791412, 21.14736366], [72.69791412, 21.14708138], [72.69847107, 21.14708138], [72.69847107, 21.14736366], [72.69930267, 21.14736366], [72.69930267, 21.14708138], [72.69958496, 21.14708138], [72.69958496, 21.14736366], [72.69985962, 21.14736366], [72.69985962, 21.14680481], [72.70124817, 21.14680481], [72.70124817, 21.14652824], [72.70263672, 21.14653015], [72.70263672, 21.14624977], [72.70318604, 21.14624977], [72.70318604, 21.14485931], [72.70347595, 21.14485931], [72.70347595, 21.14458084], [72.70375061, 21.14458275], [72.70375061, 21.14402771], [72.70430756, 21.14403152], [72.70430756, 21.14374924], [72.70485687, 21.14374924], [72.70485687, 21.14347076], [72.70541382, 21.14347267], [72.70541382, 21.1431942], [72.70597076, 21.1431942], [72.70597076, 21.14291763], [72.70680237, 21.14292145], [72.70680237, 21.14263916], [72.70707703, 21.14263916], [72.70707703, 21.14236069], [72.7076416, 21.14236069], [72.7076416, 21.14208031], [72.70791626, 21.14208412], [72.70791626, 21.14180565], [72.70819092, 21.14180756], [72.70819092, 21.14152908], [72.70874786, 21.14152908], [72.70874786, 21.14125061], [72.70986176, 21.14125061], [72.70986176, 21.14068985], [72.7104187, 21.14069366], [72.7104187, 21.13986206], [72.71013641, 21.13986015], [72.71013641, 21.13764], [72.70986176, 21.13764], [72.70986176, 21.13735962], [72.7095871, 21.13736153], [72.7095871, 21.13680649], [72.70903015, 21.13680077], [72.70903015, 21.13652802], [72.70874786, 21.13652992], [72.70874786, 21.13598061], [72.70847321, 21.13598061], [72.70847321, 21.13569069], [72.70791626, 21.1356926], [72.70791626, 21.13541412], [72.7076416, 21.13541985], [72.7076416, 21.13513947], [72.70735168, 21.13513947], [72.70735168, 21.13402939], [72.70625305, 21.13402939], [72.70625305, 21.13375282], [72.70485687, 21.13375282], [72.70485687, 21.13347054], [72.70430756, 21.13347054], [72.70430756, 21.13319206], [72.70458221, 21.13319206], [72.70458221, 21.13236046], [72.70485687, 21.13236046], [72.70485687, 21.13208008], [72.70458221, 21.13208389], [72.70458221, 21.13152695], [72.70430756, 21.13153267], [72.70430756, 21.13042068], [72.7040329, 21.13042068], [72.7040329, 21.12957954], [72.70375061, 21.12958336], [72.70375061, 21.12874985], [72.70347595, 21.12874985], [72.70347595, 21.12846947], [72.70319366, 21.12847137], [72.70319366, 21.12791634], [72.70291901, 21.12791824], [72.70291901, 21.12763977], [72.70263672, 21.12763977], [72.70263672, 21.12708092], [72.70207977, 21.12708282], [72.70207977, 21.12652779], [72.70181274, 21.12652969], [72.70181274, 21.12347031], [72.70124817, 21.12347221], [72.70124817, 21.12319565], [72.70097351, 21.12319565], [72.70097351, 21.1226387], [72.70069122, 21.12264061], [72.70069122, 21.12236023], [72.70041656, 21.12236023], [72.70041656, 21.12207985], [72.70014191, 21.12208557], [72.70014191, 21.12180328], [72.69985962, 21.12181091], [72.69985962, 21.12125015], [72.69930267, 21.12125015], [72.69930267, 21.12096977], [72.69847107, 21.12097359], [72.69847107, 21.12069321], [72.69819641, 21.12070084], [72.69819641, 21.12014008], [72.69763947, 21.12014008], [72.69763947, 21.11958122], [72.69736481, 21.11958122], [72.69736481, 21.11930466], [72.69708252, 21.11930466], [72.69708252, 21.11874962], [72.69680786, 21.11874962], [72.69680786, 21.11597061], [72.69708252, 21.11597252], [72.69708252, 21.1143055], [72.69735718, 21.11431122], [72.69735718, 21.11403084], [72.69763947, 21.11403084], [72.69763947, 21.11375046], [72.69790649, 21.11375046], [72.69790649, 21.11292076], [72.69819641, 21.11292076], [72.69819641, 21.11042023], [72.69847107, 21.11042023], [72.69847107, 21.10902977], [72.69875336, 21.10902977], [72.69875336, 21.10819054], [72.69847107, 21.10819244], [72.69847107, 21.10791588], [72.69819641, 21.10791969], [72.69819641, 21.10764122], [72.69790649, 21.10764122], [72.69790649, 21.10736275], [72.69763947, 21.10736275], [72.69763947, 21.10708046], [72.69736481, 21.10708237], [72.69736481, 21.10625267], [72.69708252, 21.10625267], [72.69708252, 21.10568047], [72.69652557, 21.10569382], [72.69652557, 21.10486031], [72.69625092, 21.10486031], [72.69625092, 21.10403252], [72.69596863, 21.10403252], [72.69596863, 21.10374832], [72.69568634, 21.10374832], [72.69568634, 21.10346985], [72.69541931, 21.10347176], [72.69541931, 21.10319519], [72.69513702, 21.10320091], [72.69513702, 21.10290909], [72.69458008, 21.10291672], [72.69458008, 21.10180473], [72.69403076, 21.10180473], [72.69403076, 21.10124969], [72.69374847, 21.10124969], [72.69374847, 21.10097122], [72.69347382, 21.10097313], [72.69347382, 21.10013962], [72.69319153, 21.10013962], [72.69319153, 21.09958076], [72.69291687, 21.09958267], [72.69291687, 21.09874916], [72.69264221, 21.09875107], [72.69264221, 21.09819031], [72.69235992, 21.09819412], [72.69235992, 21.09791756], [72.6920929, 21.09791946], [72.6920929, 21.09764099], [72.69180298, 21.09764099], [72.69180298, 21.09708023], [72.69152832, 21.09708595], [72.69152832, 21.09669113], [72.69152832, 21.09597206], [72.69125366, 21.09597206], [72.69125366, 21.09486389], [72.69097137, 21.09486389], [72.69097137, 21.09430313], [72.69069672, 21.09431076], [72.69069672, 21.09264183], [72.6904068, 21.09264183], [72.6904068, 21.09153175], [72.69013977, 21.09153175], [72.69013977, 21.09096909], [72.68985748, 21.0909729], [72.68985748, 21.09041595], [72.68958282, 21.09042168], [72.68958282, 21.09013939], [72.68902588, 21.09013939], [72.68902588, 21.08986092], [72.68763733, 21.08986092], [72.68763733, 21.09013939], [72.68736267, 21.09013939], [72.68736267, 21.09042168], [72.68653107, 21.09041595], [72.68653107, 21.09069443], [72.68624115, 21.09068108], [72.68624115, 21.09264183], [72.68653107, 21.09264183], [72.68653107, 21.09320068], [72.68624878, 21.09319305], [72.68624878, 21.09375191], [72.68597412, 21.09375191], [72.68597412, 21.0945816], [72.68569183, 21.0945797], [72.68569183, 21.09514046], [72.68541718, 21.09514046], [72.68541718, 21.09542084], [72.68514252, 21.09541702], [72.68514252, 21.0956955], [72.68486023, 21.0956955], [72.68486023, 21.09597206], [72.68458557, 21.09597206], [72.6845932, 21.09625053], [72.68430328, 21.09625053], [72.68430328, 21.09653091], [72.68402863, 21.0965271], [72.68402863, 21.09708595], [72.68374634, 21.09708595], [72.68374634, 21.09752083], [72.68374634, 21.09764099], [72.68347168, 21.09764099], [72.68347168, 21.09791946], [72.68291473, 21.09791756], [72.68291473, 21.09819412], [72.68264008, 21.09819031], [72.68264008, 21.09875107], [72.68235779, 21.09875107], [72.68235779, 21.09902954], [72.68180847, 21.09902954], [72.68180847, 21.09930992], [72.68125153, 21.09930992], [72.68125153, 21.09987068], [72.68096924, 21.09987068], [72.68096924, 21.10013962], [72.68042755, 21.10013962], [72.68042755, 21.10041809], [72.67986298, 21.10041618], [72.67986298, 21.10069466], [72.67930603, 21.10069466], [72.67930603, 21.10097313], [72.67903137, 21.10097122], [72.67903137, 21.10124969], [72.67874908, 21.10124969], [72.67874908, 21.10152817], [72.67819214, 21.10152817], [72.67819214, 21.10180473], [72.67791748, 21.10180473], [72.67791748, 21.10208321], [72.67764282, 21.10207939], [72.67764282, 21.10263824], [72.67736053, 21.10263824], [72.67736053, 21.10347176], [72.67708588, 21.10346985], [72.67708588, 21.10374832], [72.67679596, 21.10374832], [72.67679596, 21.10403252], [72.67652893, 21.10403252], [72.67652893, 21.1043129], [72.67624664, 21.10430527], [72.67624664, 21.10458374], [72.67597198, 21.10458183], [72.67597198, 21.10514259], [72.67569733, 21.10514259], [72.67569733, 21.10625267], [72.67542267, 21.10625267], [72.67542267, 21.10653114], [72.67514038, 21.10653114], [72.67514038, 21.10736275], [72.67485809, 21.10736275], [72.67485809, 21.10847473], [72.67458344, 21.10847473], [72.67458344, 21.10986137], [72.67430115, 21.10985947], [72.67430115, 21.11013985], [72.67402649, 21.11013985], [72.67402649, 21.1115303], [72.67375183, 21.1115284], [72.67375183, 21.11319351], [72.67346954, 21.11319351], [72.67346954, 21.11847115], [72.67375183, 21.11847115], [72.67375183, 21.11930466], [72.67346954, 21.11930275], [72.67346954, 21.12042046], [72.67318726, 21.12042046], [72.67318726, 21.12153053], [72.67292023, 21.12153053], [72.67292023, 21.12264061], [72.67263794, 21.1226387], [72.67263794, 21.12319565], [72.67236328, 21.12319565], [72.67236328, 21.12347221], [72.67208099, 21.12347031], [72.67208099, 21.12375069], [72.67180634, 21.12375069], [72.67180634, 21.1245842], [72.67151642, 21.12458038], [72.67151642, 21.12680817], [72.67124939, 21.12680626], [72.67124939, 21.1273613], [72.67097473, 21.1273613], [72.67097473, 21.12819481], [72.67069244, 21.12819481], [72.67069244, 21.12847137], [72.67041779, 21.12847137], [72.67041779, 21.12986183], [72.6701355, 21.12986183], [72.6701355, 21.13097191], [72.66986084, 21.13097191], [72.66986084, 21.13181114], [72.66958618, 21.13180542], [72.66958618, 21.13208389], [72.66929626, 21.13208008], [72.66929626, 21.13236046], [72.66902924, 21.13236046], [72.66902924, 21.13264275], [72.66874695, 21.13263893], [72.66874695, 21.13319206], [72.66847229, 21.13319016], [72.66847229, 21.13402939], [72.66819763, 21.13402939], [72.66819763, 21.13513947], [72.66791534, 21.13513947], [72.66791534, 21.1356926], [72.66764069, 21.13569069], [72.66764069, 21.13598061], [72.6673584, 21.13598061], [72.6673584, 21.13624954], [72.66707611, 21.13624954], [72.66707611, 21.13652992], [72.66680908, 21.13652802], [72.66680908, 21.13736153], [72.66652679, 21.13735962], [72.66652679, 21.13820076], [72.66625214, 21.13820076], [72.66625214, 21.13903809], [72.66596985, 21.13903809], [72.66596985, 21.13986015], [72.66570282, 21.13986015], [72.66570282, 21.14152908], [72.6654129, 21.14152718], [72.6654129, 21.14208412], [72.66513824, 21.14208412], [72.66513824, 21.1431942], [72.6654129, 21.1431942], [72.6654129, 21.14347267], [72.66513824, 21.14347076], [72.66513824, 21.14403152], [72.66486359, 21.14402771], [72.66486359, 21.14847374], [72.66513824, 21.14846992], [72.66513824, 21.14875031], [72.6654129, 21.14875031], [72.6654129, 21.14931107], [72.66569519, 21.14930344], [72.66569519, 21.14958572], [72.66625214, 21.14958], [72.66625214, 21.15014076], [72.66652679, 21.15014076], [72.66652679, 21.15042114], [72.66680908, 21.15041733], [72.66680908, 21.1506958], [72.66791534, 21.1506958], [72.66791534, 21.15125084], [72.66819763, 21.15125084], [72.66819763, 21.15208244], [72.66874695, 21.15208054], [72.66874695, 21.15236092], [72.66902924, 21.15236092], [72.66902924, 21.15263939], [72.66930389, 21.15263939], [72.66930389, 21.1534729], [72.66986084, 21.15347099], [72.66986084, 21.15374947], [72.67041779, 21.15374947], [72.67041779, 21.15402794], [72.6709671, 21.15402031], [72.6709671, 21.15430832], [72.67152405, 21.15430641], [72.67152405, 21.15458298], [72.67208099, 21.15458298], [72.67208099, 21.15486145], [72.67236328, 21.15485954], [72.67236328, 21.15513992], [72.67292023, 21.15513992], [72.67292023, 21.1554184], [72.67457581, 21.1554184], [72.67457581, 21.15570068], [72.67652893, 21.15570068]]], [[[69.72374725, 21.56375122], [69.72374725, 21.56402969], [69.72429657, 21.56402969], [69.72429657, 21.56375122], [69.72458649, 21.56375122], [69.72458649, 21.56347084], [69.72486115, 21.56347466], [69.72486115, 21.56319237], [69.72458649, 21.56319237], [69.72458649, 21.5629158], [69.72429657, 21.56291962], [69.72429657, 21.56208038], [69.72402954, 21.56208229], [69.72402954, 21.56180573], [69.72374725, 21.56180954], [69.72374725, 21.56069183], [69.7234726, 21.56069374], [69.7234726, 21.56041718], [69.72319794, 21.56043053], [69.72319794, 21.55903244], [69.72292328, 21.55903244], [69.72292328, 21.55875015], [69.72264099, 21.55875015], [69.72264099, 21.55792236], [69.72292328, 21.55792236], [69.72292328, 21.55708122], [69.72264099, 21.55708313], [69.72264099, 21.55680466], [69.7223587, 21.55680466], [69.7223587, 21.55569458], [69.72208405, 21.55569458], [69.72208405, 21.5545826], [69.72180939, 21.5545826], [69.72180176, 21.55402756], [69.7195816, 21.55402756], [69.7195816, 21.55430794], [69.71930695, 21.55430794], [69.71930695, 21.5545826], [69.71901703, 21.55458069], [69.71902466, 21.55513954], [69.71875, 21.55513954], [69.71875, 21.55569458], [69.71848297, 21.55569077], [69.71848297, 21.55763817], [69.71875763, 21.55763817], [69.71875763, 21.55820274], [69.71901703, 21.55820274], [69.71901703, 21.55875015], [69.71930695, 21.55875015], [69.71930695, 21.55903244], [69.7195816, 21.55903244], [69.7195816, 21.55986023], [69.72013855, 21.55986023], [69.72013855, 21.56043053], [69.72041321, 21.56043053], [69.72041321, 21.56125069], [69.72070313, 21.56125069], [69.72070313, 21.56153107], [69.7215271, 21.56153107], [69.7215271, 21.56180954], [69.72125244, 21.56180573], [69.72125244, 21.56208229], [69.72180176, 21.56208038], [69.72180176, 21.56264114], [69.72207642, 21.56264114], [69.72207642, 21.56291962], [69.72319794, 21.56291962], [69.72319794, 21.56375122], [69.72374725, 21.56375122]]], [[[69.73373413, 21.59569359], [69.73347473, 21.59569359], [69.73347473, 21.59587097], [69.7334671, 21.59625053], [69.73319244, 21.59625053], [69.73319244, 21.59680939], [69.73291779, 21.59680939], [69.73291779, 21.59763908], [69.73264313, 21.59763908], [69.73264313, 21.59791946], [69.73236084, 21.59791946], [69.73236084, 21.59874916], [69.73208618, 21.59874916], [69.73208618, 21.59902954], [69.73179626, 21.59902954], [69.73179626, 21.59931183], [69.73152924, 21.59930611], [69.73152924, 21.59958267], [69.73179626, 21.59958076], [69.73179626, 21.59986115], [69.73152924, 21.59986115], [69.73152924, 21.60013962], [69.73124695, 21.60013962], [69.73124695, 21.60069466], [69.73097229, 21.60069275], [69.73097229, 21.60124969], [69.73042297, 21.60124969], [69.73042297, 21.60292053], [69.73014069, 21.60292053], [69.73014069, 21.60320091], [69.7298584, 21.60319328], [69.7298584, 21.60347176], [69.72957611, 21.60346985], [69.72957611, 21.60375023], [69.72930908, 21.60375023], [69.72930908, 21.60431099], [69.72902679, 21.60430336], [69.72902679, 21.60458565], [69.72930908, 21.60457993], [69.72930908, 21.60486031], [69.72846985, 21.60486031], [69.72846985, 21.60514069], [69.72820282, 21.60514069], [69.72820282, 21.60542107], [69.7279129, 21.60541534], [69.7279129, 21.60569572], [69.7270813, 21.60569], [69.7270813, 21.60625076], [69.72680664, 21.60625076], [69.72680664, 21.60680962], [69.72651672, 21.60680962], [69.72651672, 21.60736084], [69.72624969, 21.60736084], [69.72624969, 21.60791969], [69.72569275, 21.60791779], [69.72569275, 21.60819435], [69.72541809, 21.60819054], [69.72541809, 21.60848045], [69.7251358, 21.60848045], [69.7251358, 21.60874939], [69.72486115, 21.60874939], [69.72486115, 21.60902977], [69.72458649, 21.60902977], [69.72458649, 21.60986137], [69.72486115, 21.60986137], [69.72486115, 21.61069489], [69.72763824, 21.61069489], [69.72763824, 21.6115284], [69.7279129, 21.6115284], [69.7279129, 21.61208344], [69.72846985, 21.61208344], [69.72846985, 21.61180496], [69.72875214, 21.61181259], [69.72875214, 21.61152077], [69.72958374, 21.6115284], [69.72958374, 21.61124992], [69.73069763, 21.61124992], [69.73069763, 21.61096764], [69.73152924, 21.61097145], [69.73152924, 21.61069489], [69.73180389, 21.61069489], [69.73180389, 21.61041641], [69.73208618, 21.61041832], [69.73208618, 21.61013985], [69.73264313, 21.61013985], [69.73264313, 21.60985947], [69.73291779, 21.60986137], [69.73291779, 21.6095829], [69.73486328, 21.6095829], [69.73486328, 21.60902977], [69.73513794, 21.60902977], [69.73513794, 21.60819054], [69.73542023, 21.60819435], [69.73542023, 21.60736084], [69.73568726, 21.60736084], [69.73568726, 21.60653114], [69.73542023, 21.60653114], [69.73542023, 21.60597038], [69.73513794, 21.60597229], [69.73513794, 21.60486031], [69.73542023, 21.60486031], [69.73542023, 21.60403061], [69.73568726, 21.60403061], [69.73568726, 21.60346985], [69.73596954, 21.60347176], [69.73596954, 21.60291672], [69.73625183, 21.60292053], [69.73625183, 21.60264015], [69.73652649, 21.60264015], [69.73652649, 21.60207939], [69.73680878, 21.6020813], [69.73680878, 21.60180473], [69.73708344, 21.60180473], [69.73708344, 21.60124969], [69.73735809, 21.60124969], [69.73735809, 21.60097122], [69.73764038, 21.60097122], [69.73764038, 21.60069466], [69.73708344, 21.60069466], [69.73708344, 21.60013962], [69.73680115, 21.60013962], [69.73680115, 21.59902954], [69.73652649, 21.59902954], [69.73652649, 21.59568977], [69.73680878, 21.59569359], [69.73680878, 21.59541893], [69.73707581, 21.59542084], [69.73707581, 21.59514046], [69.73764038, 21.59514046], [69.73764038, 21.59486008], [69.73791504, 21.59486198], [69.73791504, 21.59458351], [69.73819733, 21.59458351], [69.73819733, 21.59402847], [69.73847198, 21.59403038], [69.73847198, 21.59375], [69.73874664, 21.59375], [69.73874664, 21.59348106], [69.73958588, 21.59348106], [69.73958588, 21.59320068], [69.73986816, 21.59320068], [69.73986816, 21.5929203], [69.74014282, 21.5929203], [69.74014282, 21.59263992], [69.73958588, 21.59263992], [69.73958588, 21.59235954], [69.73842621, 21.59233284], [69.73844147, 21.5922451], [69.73847198, 21.59208488], [69.73735809, 21.59208488], [69.73735809, 21.59236145], [69.73707581, 21.59235954], [69.73707581, 21.59263992], [69.73680115, 21.59263992], [69.73680115, 21.5929203], [69.73625183, 21.5929203], [69.73625183, 21.59320068], [69.73596954, 21.59320068], [69.73596954, 21.59348106], [69.73568726, 21.59348106], [69.73568726, 21.59403038], [69.73486328, 21.59403038], [69.73486328, 21.59431076], [69.73458099, 21.59431076], [69.73458862, 21.59514809], [69.73430634, 21.59513855], [69.73426819, 21.59536743], [69.73419952, 21.59541893], [69.73405457, 21.59548187], [69.73402405, 21.59569359], [69.73373413, 21.59569359]]], [[[72.35319519, 21.61347008], [72.35319519, 21.61291695], [72.35375214, 21.61292267], [72.35375214, 21.61264038], [72.35402679, 21.61264038], [72.35402679, 21.61236191], [72.35430908, 21.61236191], [72.35430908, 21.61097145], [72.35402679, 21.61097145], [72.35402679, 21.6095829], [72.35458374, 21.6095829], [72.35458374, 21.60930634], [72.35514069, 21.60930824], [72.35514069, 21.60902977], [72.3554306, 21.60902977], [72.3554306, 21.60874939], [72.35514069, 21.60874939], [72.35514069, 21.60848045], [72.3554306, 21.60848045], [72.3554306, 21.60736084], [72.35569763, 21.60736084], [72.35569763, 21.60708046], [72.35597229, 21.60708427], [72.35597229, 21.60625076], [72.35624695, 21.60625076], [72.35624695, 21.60597038], [72.35652924, 21.60597229], [72.35652924, 21.60513878], [72.35708618, 21.60514069], [72.35708618, 21.60486031], [72.35736084, 21.60486031], [72.35736084, 21.60403061], [72.35764313, 21.60403061], [72.35764313, 21.60375023], [72.35791779, 21.60375023], [72.35791779, 21.60346985], [72.35847473, 21.60347176], [72.35847473, 21.60319328], [72.35874939, 21.60320091], [72.35874939, 21.60292053], [72.35901642, 21.60292053], [72.35901642, 21.60235023], [72.35958099, 21.60236168], [72.35958099, 21.6020813], [72.36013794, 21.6020813], [72.36013794, 21.60236168], [72.36042023, 21.60235023], [72.36042023, 21.60264015], [72.36068726, 21.60264015], [72.36068726, 21.60292053], [72.36096954, 21.60292053], [72.36096954, 21.60264015], [72.36152649, 21.60264015], [72.36152649, 21.60235023], [72.36180878, 21.60236168], [72.36180878, 21.60180473], [72.36208344, 21.60180473], [72.36208344, 21.60152817], [72.36235809, 21.60153008], [72.36235809, 21.60124969], [72.36264038, 21.60124969], [72.36264038, 21.60097122], [72.36291504, 21.60097122], [72.36291504, 21.60069466], [72.36374664, 21.60069466], [72.36374664, 21.60041618], [72.36402893, 21.60042191], [72.36402893, 21.59958076], [72.36291504, 21.59958267], [72.36291504, 21.59930611], [72.36235809, 21.59931183], [72.36235809, 21.59902954], [72.36207581, 21.59902954], [72.36207581, 21.59847069], [72.36235809, 21.5984726], [72.36235809, 21.59819412], [72.36264038, 21.59819412], [72.36264038, 21.59791756], [72.36458588, 21.59791756], [72.36458588, 21.59819412], [72.36486053, 21.59819412], [72.36486053, 21.59763908], [72.36514282, 21.59763908], [72.36514282, 21.59625053], [72.36486053, 21.59625053], [72.36486053, 21.59596825], [72.36430359, 21.59597206], [72.36430359, 21.59319687], [72.36486053, 21.59320068], [72.36486053, 21.5929203], [72.36514282, 21.5929203], [72.36514282, 21.59263992], [72.36486053, 21.59263992], [72.36486053, 21.59208107], [72.36458588, 21.59208488], [72.36458588, 21.5918045], [72.36429596, 21.59181023], [72.36429596, 21.59152985], [72.36458588, 21.59152985], [72.36458588, 21.59124947], [72.36486053, 21.59124947], [72.36486053, 21.59069061], [72.36513519, 21.59069633], [72.36513519, 21.59013939], [72.36541748, 21.59013939], [72.36541748, 21.58986092], [72.36513519, 21.58986092], [72.36513519, 21.58791733], [72.36486053, 21.58792114], [72.36486053, 21.58764267], [72.36347198, 21.58764267], [72.36347198, 21.58735085], [72.36291504, 21.58736038], [72.36291504, 21.58708382], [72.36264038, 21.58708382], [72.36264038, 21.58683968], [72.36264038, 21.58625031], [72.36312866, 21.58625031], [72.36319733, 21.58597183], [72.36347198, 21.58597183], [72.36347198, 21.58569527], [72.36292267, 21.5857029], [72.36292267, 21.58542252], [72.36235809, 21.58542252], [72.36235809, 21.58514023], [72.36207581, 21.58514023], [72.36207581, 21.58263969], [72.36180878, 21.58263969], [72.36180878, 21.58180809], [72.36152649, 21.58180809], [72.36152649, 21.58125114], [72.35986328, 21.58125114], [72.35986328, 21.58097076], [72.35958099, 21.58097267], [72.35958099, 21.5806942], [72.35930634, 21.5806942], [72.35930634, 21.58041763], [72.35901642, 21.58041954], [72.35901642, 21.58014107], [72.35874939, 21.58014107], [72.35874939, 21.57986069], [72.35791779, 21.57986069], [72.35791779, 21.58041954], [72.35736084, 21.58041763], [72.35736084, 21.58097267], [72.35764313, 21.58097076], [72.35764313, 21.58153915], [72.3548584, 21.58152771], [72.3548584, 21.58208275], [72.35458374, 21.58208275], [72.35458374, 21.5834713], [72.35430908, 21.58346748], [72.35430908, 21.58374977], [72.35375214, 21.58374977], [72.35375214, 21.58514023], [72.35263824, 21.58514023], [72.35263824, 21.58542252], [72.35235596, 21.58542252], [72.35235596, 21.5857029], [72.3520813, 21.58569527], [72.3520813, 21.58708382], [72.35235596, 21.58708191], [72.35235596, 21.58764267], [72.3520813, 21.58763885], [72.3520813, 21.58819389], [72.35180664, 21.58819008], [72.35180664, 21.58903122], [72.35152435, 21.5890274], [72.35152435, 21.58958244], [72.35124969, 21.58958244], [72.35124969, 21.59069633], [72.35098267, 21.59069061], [72.35098267, 21.59152985], [72.35069275, 21.59152985], [72.35069275, 21.59263992], [72.35041809, 21.59263992], [72.35041809, 21.59320068], [72.3501358, 21.59320068], [72.3501358, 21.59348106], [72.35041809, 21.59348106], [72.35041809, 21.59431076], [72.3501358, 21.59430695], [72.3501358, 21.59458351], [72.34986115, 21.5945797], [72.34986115, 21.59514046], [72.3501358, 21.59513855], [72.3501358, 21.59597206], [72.3493042, 21.59597206], [72.3493042, 21.59708405], [72.34902954, 21.59707832], [72.34902954, 21.59791946], [72.34874725, 21.59791946], [72.34874725, 21.59874916], [72.3484726, 21.59874916], [72.3484726, 21.59931183], [72.34874725, 21.59930611], [72.34874725, 21.59958267], [72.3484726, 21.59958076], [72.3484726, 21.60013962], [72.34792328, 21.60013962], [72.34792328, 21.60042191], [72.3473587, 21.60041618], [72.3473587, 21.60069466], [72.34707642, 21.60069275], [72.34707642, 21.60124969], [72.3465271, 21.60124969], [72.3465271, 21.60153008], [72.34625244, 21.60152817], [72.34625244, 21.60180473], [72.34597015, 21.60180473], [72.34597015, 21.60236168], [72.34541321, 21.60235023], [72.34541321, 21.60292053], [72.34597015, 21.60292053], [72.34597015, 21.60320091], [72.34625244, 21.60319328], [72.34625244, 21.60569572], [72.3465271, 21.60569572], [72.3465271, 21.60597229], [72.34626007, 21.60597038], [72.34626007, 21.60680962], [72.34597015, 21.60680771], [72.34597015, 21.60708427], [72.34707642, 21.60708046], [72.34707642, 21.60791969], [72.34680176, 21.60791779], [72.34680176, 21.60819435], [72.3465271, 21.60819435], [72.3465271, 21.6095829], [72.34680176, 21.6095829], [72.34680176, 21.60986137], [72.34707642, 21.60985947], [72.34707642, 21.61041832], [72.3473587, 21.61041641], [72.3473587, 21.61069489], [72.34764099, 21.61069489], [72.34764099, 21.61097145], [72.34791565, 21.61097145], [72.34791565, 21.61124992], [72.34819794, 21.61124992], [72.34819794, 21.6115284], [72.3484726, 21.61152077], [72.3484726, 21.61181259], [72.35069275, 21.61180496], [72.35069275, 21.61208344], [72.35097504, 21.61208344], [72.35097504, 21.61236191], [72.35124969, 21.61236191], [72.35124969, 21.61264038], [72.35151672, 21.61264038], [72.35151672, 21.61292267], [72.35180664, 21.61291695], [72.35180664, 21.6131916], [72.35236359, 21.61319542], [72.35236359, 21.61347008], [72.3529892, 21.61347008], [72.35319519, 21.61347008]]], [[[72.61180878, 21.6320858], [72.61180878, 21.63152695], [72.61152649, 21.63153076], [72.61152649, 21.63125038], [72.61125183, 21.63125038], [72.61125183, 21.63070107], [72.61113739, 21.63070107], [72.61096191, 21.63070107], [72.61096191, 21.63042068], [72.61068726, 21.63042068], [72.61068726, 21.62985992], [72.61042023, 21.62986374], [72.61042023, 21.62958336], [72.60986328, 21.62959099], [72.60986328, 21.63042068], [72.61013794, 21.63042068], [72.61013794, 21.63125038], [72.61042023, 21.63125038], [72.61042023, 21.63153076], [72.61068726, 21.6315403], [72.61068726, 21.63181114], [72.61125183, 21.63180351], [72.61125183, 21.6320858], [72.61180878, 21.6320858]]], [[[72.60930634, 21.62874985], [72.60930634, 21.62792015], [72.60901642, 21.62792015], [72.60901642, 21.62708282], [72.60874939, 21.62708282], [72.60874939, 21.62652779], [72.60847473, 21.62652779], [72.60847473, 21.62569427], [72.60819244, 21.62569427], [72.60819244, 21.62486076], [72.60791779, 21.62486076], [72.60791779, 21.62431145], [72.60764313, 21.62431145], [72.60764313, 21.62402916], [72.60791779, 21.62402916], [72.60791779, 21.62291908], [72.60764313, 21.62291908], [72.60764313, 21.62236023], [72.60736084, 21.62236023], [72.60736084, 21.62181091], [72.60764313, 21.62181091], [72.60764313, 21.62096977], [72.60791779, 21.62097168], [72.60791779, 21.62069511], [72.60764313, 21.62070847], [72.60764313, 21.62014008], [72.60736084, 21.62014008], [72.60736084, 21.61903], [72.60680389, 21.61902618], [72.60680389, 21.61930656], [72.60624695, 21.61930656], [72.60624695, 21.61958313], [72.60514832, 21.61958122], [72.60514832, 21.62014008], [72.60541534, 21.62013626], [72.60541534, 21.62097168], [72.60514832, 21.62096977], [72.60514832, 21.62181091], [72.6048584, 21.62180519], [72.6048584, 21.62319374], [72.60514832, 21.62318993], [72.60514832, 21.62402916], [72.60541534, 21.62402725], [72.60541534, 21.62486076], [72.60569763, 21.62486076], [72.60569763, 21.62569427], [72.60597229, 21.62569427], [72.60597229, 21.6273613], [72.60624695, 21.6273613], [72.60624695, 21.62847137], [72.60791779, 21.62846947], [72.60791779, 21.62874985], [72.60819244, 21.62874985], [72.60819244, 21.62903023], [72.60958099, 21.62903023], [72.60958099, 21.62874985], [72.60930634, 21.62874985]]], [[[72.5845871, 21.62903023], [72.5845871, 21.62708282], [72.58430481, 21.62708282], [72.58430481, 21.62624931], [72.58402252, 21.62625122], [72.58402252, 21.62597084], [72.58152771, 21.62597084], [72.58152771, 21.62625122], [72.58125305, 21.62624931], [72.58125305, 21.62708282], [72.58152771, 21.62708282], [72.58152771, 21.6273613], [72.58207703, 21.62735939], [72.58207703, 21.62763977], [72.58235931, 21.62763977], [72.58235931, 21.62792015], [72.5826416, 21.62791634], [72.5826416, 21.62819481], [72.58319092, 21.6281929], [72.58319092, 21.62874985], [72.58347321, 21.62874985], [72.58347321, 21.62903023], [72.5845871, 21.62903023]]], [[[72.59570313, 21.63903046], [72.59570313, 21.63875008], [72.59597015, 21.63875008], [72.59596252, 21.63763809], [72.59570313, 21.63763809], [72.59570313, 21.63735962], [72.59541321, 21.63736153], [72.59541321, 21.63652992], [72.59513855, 21.63652992], [72.59513855, 21.63569069], [72.59486389, 21.6356945], [72.59486389, 21.63541794], [72.5945816, 21.63541985], [72.5945816, 21.63486099], [72.59430695, 21.63486099], [72.59430695, 21.63458061], [72.59375, 21.63458252], [72.59375, 21.63430786], [72.5945816, 21.63430977], [72.5945816, 21.63402939], [72.59513855, 21.63402939], [72.59513855, 21.63319016], [72.59541321, 21.63319588], [72.59541321, 21.63306808], [72.59541321, 21.63069344], [72.59570313, 21.63070107], [72.59570313, 21.63042068], [72.59596252, 21.63042068], [72.59596252, 21.6301403], [72.5973587, 21.6301384], [72.5973587, 21.63097191], [72.59764099, 21.63097], [72.59764099, 21.63125038], [72.59792328, 21.63125038], [72.59792328, 21.63153076], [72.59874725, 21.63153076], [72.59874725, 21.63125038], [72.59902191, 21.63125038], [72.59902191, 21.63153076], [72.59937286, 21.63153076], [72.59958649, 21.63153076], [72.59958649, 21.63181114], [72.59986115, 21.63181114], [72.59986115, 21.63236046], [72.60098267, 21.63236046], [72.60097504, 21.6320858], [72.60124969, 21.6320858], [72.60124969, 21.63125038], [72.60069275, 21.63125038], [72.60069275, 21.63100052], [72.60069275, 21.63069344], [72.60148621, 21.63069344], [72.6020813, 21.63069344], [72.6020813, 21.63097191], [72.60235596, 21.63097], [72.60235596, 21.63125038], [72.60263824, 21.63125038], [72.60263824, 21.63153076], [72.60320282, 21.63153076], [72.60320282, 21.63125038], [72.60346985, 21.63125038], [72.60346985, 21.63097], [72.60375214, 21.63097], [72.60375214, 21.63181114], [72.60402679, 21.63180351], [72.60402679, 21.6320858], [72.60430908, 21.63208008], [72.60430908, 21.63236046], [72.60457611, 21.63236046], [72.60457611, 21.63265038], [72.60514832, 21.63265038], [72.60514832, 21.63292122], [72.60541534, 21.6329174], [72.60541534, 21.63319588], [72.60569763, 21.63319588], [72.60569763, 21.63347244], [72.60541534, 21.63347244], [72.60541534, 21.63458252], [72.60708618, 21.63458061], [72.60708618, 21.63486099], [72.60791779, 21.63486099], [72.60791779, 21.63513947], [72.6084671, 21.63513947], [72.6084671, 21.63486099], [72.60874939, 21.63486099], [72.60874939, 21.63513947], [72.60901642, 21.63513947], [72.60901642, 21.63486099], [72.60958099, 21.63486099], [72.60958099, 21.63513947], [72.60986328, 21.63513947], [72.60986328, 21.63541985], [72.61069489, 21.63541794], [72.61069489, 21.6356945], [72.61152649, 21.6356945], [72.61152649, 21.63486099], [72.61125183, 21.63486099], [72.61125183, 21.63458061], [72.61096954, 21.63458252], [72.61096954, 21.63430786], [72.61068726, 21.63430977], [72.61068726, 21.63347054], [72.61042023, 21.63347244], [72.61042023, 21.63319588], [72.61013794, 21.63319588], [72.61013794, 21.63263893], [72.60930634, 21.63265038], [72.60930634, 21.63292122], [72.60819244, 21.63292122], [72.60819244, 21.63265038], [72.60764313, 21.63265038], [72.60764313, 21.63236046], [72.60736084, 21.63236046], [72.60736084, 21.63208008], [72.60680389, 21.6320858], [72.60680389, 21.63180351], [72.60652924, 21.63181114], [72.60652924, 21.63153076], [72.60624695, 21.63153076], [72.60624695, 21.63125038], [72.60597229, 21.63125038], [72.60597229, 21.63097], [72.60569763, 21.63097191], [72.60569763, 21.63069344], [72.60514832, 21.63070107], [72.60514832, 21.63042068], [72.6048584, 21.63042068], [72.6048584, 21.6301403], [72.60457611, 21.6301403], [72.60457611, 21.62985992], [72.60430908, 21.62986374], [72.60430908, 21.62958336], [72.60346985, 21.62959099], [72.60346985, 21.62903023], [72.60320282, 21.62903023], [72.60320282, 21.62846947], [72.6029129, 21.62847137], [72.6029129, 21.62791634], [72.60263824, 21.62792015], [72.60263824, 21.62763977], [72.60235596, 21.62763977], [72.60235596, 21.62735939], [72.6020813, 21.6273613], [72.6020813, 21.62680626], [72.60151672, 21.62681007], [72.60151672, 21.62625122], [72.60180664, 21.62625122], [72.60180664, 21.62568855], [72.6020813, 21.62569427], [72.6020813, 21.6245842], [72.60236359, 21.6245842], [72.60236359, 21.62402725], [72.6029129, 21.62402916], [72.6029129, 21.62346077], [72.60263824, 21.62347221], [72.60263824, 21.62319374], [72.6029129, 21.62319374], [72.6029129, 21.62152863], [72.60263824, 21.62153053], [72.60263824, 21.62042046], [72.60235596, 21.62042046], [72.60235596, 21.62014008], [72.60208893, 21.62014008], [72.60208893, 21.61958122], [72.60180664, 21.61958313], [72.60180664, 21.61930656], [72.60124969, 21.61930656], [72.60124969, 21.61902618], [72.60098267, 21.61903], [72.60098267, 21.61874962], [72.60041809, 21.61874962], [72.60041809, 21.61847115], [72.59986115, 21.61847305], [72.59986115, 21.61819649], [72.59958649, 21.61819649], [72.59958649, 21.61763954], [72.59902191, 21.61765099], [72.59902191, 21.61736107], [72.5984726, 21.61736107], [72.5984726, 21.61765099], [72.59764099, 21.61765099], [72.59764099, 21.61791992], [72.5973587, 21.6179142], [72.5973587, 21.61819649], [72.59708405, 21.61819649], [72.59708405, 21.61958313], [72.59625244, 21.61958313], [72.59625244, 21.61930656], [72.5956955, 21.61930656], [72.5956955, 21.61902618], [72.59541321, 21.61903], [72.59541321, 21.61874962], [72.59430695, 21.61874962], [72.59430695, 21.61903], [72.59375, 21.61903], [72.59375, 21.61874962], [72.59319305, 21.61874962], [72.59319305, 21.61903], [72.59263611, 21.61902618], [72.59263611, 21.61930656], [72.59208679, 21.61930656], [72.59208679, 21.61958313], [72.5918045, 21.61958313], [72.5918045, 21.6198616], [72.59152985, 21.6198597], [72.59152985, 21.62014008], [72.59124756, 21.62014008], [72.59124756, 21.62042046], [72.59069824, 21.62042046], [72.59069061, 21.62070847], [72.59041595, 21.62070847], [72.59041595, 21.62181091], [72.5901413, 21.62180519], [72.5901413, 21.62208366], [72.58985901, 21.62207985], [72.58985901, 21.62236023], [72.59014893, 21.62236023], [72.59014893, 21.62291908], [72.59041595, 21.62291718], [72.59041595, 21.62319374], [72.5909729, 21.62318993], [72.5909729, 21.62375069], [72.59124756, 21.62375069], [72.59124756, 21.6245842], [72.5909729, 21.62457848], [72.5909729, 21.62513924], [72.59069824, 21.62513924], [72.59069061, 21.62597275], [72.59041595, 21.62597275], [72.59041595, 21.62652779], [72.59014893, 21.62652016], [72.59014893, 21.62681007], [72.58930206, 21.62680626], [72.58930206, 21.6273613], [72.5890274, 21.62735939], [72.5890274, 21.62792015], [72.58875275, 21.62792015], [72.58875275, 21.62903023], [72.58847046, 21.62903023], [72.58847046, 21.62959099], [72.5881958, 21.62959099], [72.5881958, 21.6301403], [72.58790588, 21.6301403], [72.58790588, 21.63070107], [72.5881958, 21.63070107], [72.5881958, 21.63236046], [72.58847046, 21.63236046], [72.58847046, 21.63292122], [72.58875275, 21.6329174], [72.58875275, 21.63319588], [72.5890274, 21.63319016], [72.5890274, 21.63375092], [72.58930206, 21.63375092], [72.58930206, 21.63402939], [72.59041595, 21.63402557], [72.59041595, 21.63417053], [72.59041595, 21.63541985], [72.5909729, 21.63541794], [72.5909729, 21.6356945], [72.59124756, 21.6356945], [72.59124756, 21.63597298], [72.59152985, 21.63597107], [72.59152985, 21.63624954], [72.59208679, 21.63624954], [72.59208679, 21.6368084], [72.59236145, 21.6368084], [72.59236145, 21.63820267], [72.59263611, 21.63819504], [72.59263611, 21.6384716], [72.59375, 21.63845825], [72.59375, 21.63875008], [72.59401703, 21.63875008], [72.59401703, 21.63903046], [72.59570313, 21.63903046]]], [[[72.72264099, 21.66597176], [72.72264099, 21.66569519], [72.72374725, 21.66569519], [72.72374725, 21.66541672], [72.72402954, 21.66542244], [72.72402954, 21.66514015], [72.72429657, 21.66514015], [72.72429657, 21.66485977], [72.72458649, 21.66486168], [72.72458649, 21.66458321], [72.7251358, 21.66458321], [72.7251358, 21.66430473], [72.72541809, 21.66430473], [72.72541809, 21.66374969], [72.72598267, 21.66374969], [72.72597504, 21.66347313], [72.72624969, 21.66347313], [72.72624969, 21.66319466], [72.72680664, 21.66319466], [72.72680664, 21.66291618], [72.72735596, 21.66291809], [72.72735596, 21.66263008], [72.7279129, 21.66263962], [72.7279129, 21.66236115], [72.72847748, 21.66236115], [72.72846985, 21.66208267], [72.72902679, 21.66208267], [72.72902679, 21.66180611], [72.72957611, 21.66180992], [72.72957611, 21.66152954], [72.7298584, 21.66152954], [72.7298584, 21.66097069], [72.73124695, 21.66097069], [72.73124695, 21.66125107], [72.73264313, 21.66125107], [72.73264313, 21.66097069], [72.73374939, 21.6609726], [72.73374939, 21.66069412], [72.73430634, 21.66069412], [72.73430634, 21.66041756], [72.73596954, 21.66041946], [72.73596954, 21.66014099], [72.73680878, 21.66014099], [72.73680878, 21.65986061], [72.73735809, 21.65986061], [72.73735809, 21.65958977], [72.73792267, 21.65958977], [72.73792267, 21.65903091], [72.73902893, 21.65903091], [72.73902893, 21.65930939], [72.7409668, 21.65930939], [72.7409668, 21.65903091], [72.74180603, 21.65903091], [72.74180603, 21.65875053], [72.74236298, 21.65875053], [72.74236298, 21.65847015], [72.74291992, 21.65847015], [72.74291992, 21.65875053], [72.74318695, 21.65875053], [72.74318695, 21.65818977], [72.74402618, 21.65818977], [72.74402618, 21.65875053], [72.74511719, 21.65875053], [72.74597168, 21.65875053], [72.74597168, 21.65847015], [72.74652863, 21.65847206], [72.74652863, 21.65819359], [72.74680328, 21.65819359], [72.74680328, 21.65791512], [72.74736023, 21.65792084], [72.74736023, 21.65764046], [72.74819183, 21.65764046], [72.74819183, 21.65736008], [72.74847412, 21.65736389], [72.74847412, 21.65708542], [72.74874878, 21.65708542], [72.74874878, 21.65680313], [72.74931335, 21.6568203], [72.74931335, 21.65653038], [72.74958038, 21.65653038], [72.74958038, 21.65625], [72.74986267, 21.65625], [72.74986267, 21.65596962], [72.75013733, 21.65597153], [72.75013733, 21.65569305], [72.75068665, 21.65570068], [72.75068665, 21.65458107], [72.75096893, 21.65458107], [72.75096893, 21.65291595], [72.75041962, 21.65292168], [72.75041962, 21.65236092], [72.75013733, 21.65236092], [72.75013733, 21.65208054], [72.74986267, 21.65208244], [72.74986267, 21.6515274], [72.74931335, 21.65152931], [72.74931335, 21.65125084], [72.74903107, 21.65125084], [72.74903107, 21.65097046], [72.74874878, 21.65097237], [72.74874878, 21.65069389], [72.74847412, 21.65069389], [72.74847412, 21.65041733], [72.74819183, 21.65041924], [72.74819183, 21.65014076], [72.74791718, 21.65014076], [72.74791718, 21.64930916], [72.74736023, 21.64930916], [72.74736023, 21.64903069], [72.7470932, 21.64903069], [72.7470932, 21.64846992], [72.74680328, 21.64847183], [72.74680328, 21.64819527], [72.746521, 21.64819908], [72.746521, 21.64764977], [72.74597168, 21.64764977], [72.74597168, 21.64680099], [72.74569702, 21.64680672], [72.74569702, 21.64652824], [72.7454071, 21.64653015], [72.7454071, 21.64624977], [72.74458313, 21.64624977], [72.74458313, 21.64596939], [72.74430847, 21.6459713], [72.74430847, 21.64569664], [72.74346924, 21.64569664], [72.74346924, 21.64541435], [72.74236298, 21.64542007], [72.74236298, 21.64513969], [72.74208069, 21.64513969], [72.74208069, 21.64486122], [72.73986053, 21.64486122], [72.73986053, 21.64459038], [72.73902893, 21.64459038], [72.73902893, 21.64431], [72.73847198, 21.64431], [72.73847198, 21.64402962], [72.73792267, 21.64402962], [72.73792267, 21.64375114], [72.73735809, 21.64375114], [72.73735809, 21.64402962], [72.73707581, 21.64402962], [72.73707581, 21.64375114], [72.73625183, 21.64375114], [72.73625183, 21.64513969], [72.73680878, 21.64513969], [72.73680878, 21.64624977], [72.73596954, 21.64624977], [72.73596954, 21.64708328], [72.73542023, 21.64708328], [72.73542023, 21.64680672], [72.73374939, 21.64680672], [72.73374939, 21.64652824], [72.73291779, 21.64653015], [72.73291779, 21.64624977], [72.73236084, 21.64624977], [72.73236084, 21.64596939], [72.73069763, 21.6459713], [72.73069763, 21.64569664], [72.73041534, 21.64569664], [72.73041534, 21.64541435], [72.73014069, 21.64542007], [72.73014069, 21.64513969], [72.72957611, 21.64513969], [72.72957611, 21.64486122], [72.72930908, 21.64486122], [72.72930908, 21.64513969], [72.72902679, 21.64513969], [72.72902679, 21.64486122], [72.72875214, 21.64486122], [72.72875214, 21.64459038], [72.72847748, 21.64459038], [72.72847748, 21.64431], [72.72820282, 21.64431], [72.72820282, 21.64402962], [72.72680664, 21.64402962], [72.72680664, 21.64375114], [72.72486115, 21.64375114], [72.72486115, 21.64347076], [72.72429657, 21.64347076], [72.72429657, 21.64375114], [72.72402954, 21.64375114], [72.72402954, 21.64347076], [72.7234726, 21.64347458], [72.7234726, 21.64319229], [72.72180176, 21.64319229], [72.72180176, 21.64347458], [72.72125244, 21.64347076], [72.72125244, 21.64375114], [72.72041321, 21.64375114], [72.72041321, 21.64402962], [72.71985626, 21.64402962], [72.71985626, 21.64431], [72.71930695, 21.64431], [72.71930695, 21.64459038], [72.71679688, 21.64459038], [72.71679688, 21.64513969], [72.71624756, 21.64513969], [72.71624756, 21.64542007], [72.7159729, 21.64541435], [72.7159729, 21.64569664], [72.71569824, 21.64569664], [72.71569061, 21.6459713], [72.71541595, 21.64596939], [72.71541595, 21.64764977], [72.71569061, 21.64764977], [72.71569824, 21.64819908], [72.7159729, 21.64819527], [72.7159729, 21.64958382], [72.71624756, 21.64958382], [72.71624756, 21.65097237], [72.7159729, 21.65097046], [72.7159729, 21.65125084], [72.71569824, 21.65125084], [72.71569061, 21.65152931], [72.71541595, 21.65152931], [72.71541595, 21.6518116], [72.7151413, 21.65180588], [72.7151413, 21.65208244], [72.71485901, 21.65208054], [72.71485901, 21.65236092], [72.71430206, 21.65236092], [72.71430206, 21.65263939], [72.71375275, 21.65263939], [72.71375275, 21.65292168], [72.71347046, 21.65291595], [72.71347046, 21.65319443], [72.7131958, 21.65319443], [72.7131958, 21.6534729], [72.71290588, 21.6534729], [72.71290588, 21.65374947], [72.71263885, 21.65374947], [72.71263885, 21.65431023], [72.7123642, 21.65430641], [72.7123642, 21.65486145], [72.71208191, 21.65485954], [72.71208191, 21.65570068], [72.71180725, 21.65570068], [72.71180725, 21.65625], [72.71151733, 21.65625], [72.71151733, 21.65653038], [72.71097565, 21.65652847], [72.71097565, 21.65736389], [72.71069336, 21.65736008], [72.71069336, 21.65764046], [72.7104187, 21.65763855], [72.7104187, 21.65819359], [72.71013641, 21.65818977], [72.71013641, 21.65903091], [72.71041107, 21.65903091], [72.71041107, 21.65986061], [72.71069336, 21.65986061], [72.71069336, 21.66014099], [72.71098328, 21.66014099], [72.71098328, 21.66041946], [72.71125031, 21.66041756], [72.71125031, 21.66069412], [72.71152496, 21.66069412], [72.71152496, 21.6609726], [72.71180725, 21.66097069], [72.71180725, 21.66125107], [72.71235657, 21.66125107], [72.71235657, 21.66152954], [72.71263885, 21.66152763], [72.71263885, 21.66208267], [72.71290588, 21.66208076], [72.71290588, 21.66236115], [72.7131958, 21.66236115], [72.7131958, 21.66263962], [72.71347046, 21.66263008], [72.71347046, 21.66291809], [72.71375275, 21.66291618], [72.71375275, 21.66319466], [72.7140274, 21.66319466], [72.7140274, 21.66347313], [72.71457672, 21.66347122], [72.71457672, 21.66374969], [72.71485901, 21.66374969], [72.71485901, 21.66402817], [72.71541595, 21.66402817], [72.71541595, 21.66430473], [72.7159729, 21.66430473], [72.7159729, 21.66458321], [72.71652985, 21.66458321], [72.71652985, 21.66486168], [72.71679688, 21.66485977], [72.71679688, 21.66514015], [72.71736145, 21.66514015], [72.71736145, 21.66542244], [72.71819305, 21.66541672], [72.71819305, 21.66569519], [72.72041321, 21.66569519], [72.72041321, 21.66597176], [72.72264099, 21.66597176]]], [[[72.61708069, 21.6384716], [72.61708069, 21.63763809], [72.61680603, 21.63763809], [72.61680603, 21.63735962], [72.61653137, 21.63736153], [72.61653137, 21.63708305], [72.61624908, 21.63708305], [72.61624908, 21.63680649], [72.6159668, 21.63680077], [72.61597443, 21.63624954], [72.61569214, 21.63624954], [72.61569214, 21.63597107], [72.61541748, 21.63597298], [72.61541748, 21.6356945], [72.61513519, 21.6356945], [72.61513519, 21.63541794], [72.61458588, 21.63541794], [72.61458588, 21.63597298], [72.61429596, 21.63597107], [72.61429596, 21.63652992], [72.61458588, 21.63652992], [72.61458588, 21.6368084], [72.61486053, 21.63680649], [72.61486053, 21.63708305], [72.61541748, 21.63708305], [72.61541748, 21.63736153], [72.61569214, 21.63735962], [72.61569214, 21.63763809], [72.6159668, 21.63763809], [72.6159668, 21.63791847], [72.61653137, 21.63791847], [72.61653137, 21.63820267], [72.61680603, 21.63819504], [72.61680603, 21.6384716], [72.61708069, 21.6384716]]], [[[72.61958313, 21.63958359], [72.61958313, 21.63930511], [72.62014771, 21.63931274], [72.62014771, 21.63903046], [72.61902618, 21.63903046], [72.61902618, 21.63875008], [72.61846924, 21.63875008], [72.61846924, 21.63845825], [72.61763763, 21.63845825], [72.61763763, 21.63903046], [72.61708069, 21.63902855], [72.61708069, 21.63958359], [72.61736298, 21.63958359], [72.61736298, 21.63930511], [72.61902618, 21.63930511], [72.61902618, 21.63958359], [72.61958313, 21.63958359]]], [[[72.60236359, 21.64097023], [72.60236359, 21.64069366], [72.60263824, 21.64069366], [72.60263824, 21.63986015], [72.6020813, 21.63986015], [72.6020813, 21.63930511], [72.60180664, 21.63931274], [72.60180664, 21.63875008], [72.6001358, 21.63875008], [72.6001358, 21.63845825], [72.59986115, 21.6384716], [72.59986115, 21.63819504], [72.59958649, 21.63820267], [72.59958649, 21.63791847], [72.59929657, 21.63791847], [72.59929657, 21.63735962], [72.59958649, 21.63736153], [72.59958649, 21.63708305], [72.59874725, 21.63708305], [72.59874725, 21.63736153], [72.59819794, 21.63735962], [72.59819794, 21.63763809], [72.59791565, 21.63763809], [72.59791565, 21.6384716], [72.59764099, 21.63845825], [72.59764099, 21.63875008], [72.5973587, 21.63875008], [72.5973587, 21.63903046], [72.59708405, 21.63902855], [72.59708405, 21.63958359], [72.59680176, 21.63958168], [72.59680176, 21.64014053], [72.59625244, 21.64014053], [72.59625244, 21.64042282], [72.59597015, 21.6404171], [72.59597015, 21.64069366], [72.5956955, 21.64069366], [72.5956955, 21.64097023], [72.59596252, 21.64097023], [72.59596252, 21.64125061], [72.5965271, 21.64125061], [72.5965271, 21.64097023], [72.59764099, 21.64097023], [72.59764099, 21.64069366], [72.59791565, 21.64069366], [72.59791565, 21.6404171], [72.59819794, 21.64042282], [72.59819794, 21.64014053], [72.5984726, 21.64014053], [72.5984726, 21.63986015], [72.59958649, 21.63986015], [72.59958649, 21.63958359], [72.59986115, 21.63958359], [72.59986115, 21.63986015], [72.6001358, 21.63986015], [72.6001358, 21.64014053], [72.60098267, 21.64014053], [72.60098267, 21.64042282], [72.6020813, 21.6404171], [72.6020813, 21.64125061], [72.60263824, 21.64125061], [72.60263824, 21.64097023], [72.60236359, 21.64097023]]], [[[72.27430725, 21.74958229], [72.27430725, 21.74930573], [72.27458191, 21.74930954], [72.27458191, 21.74903107], [72.27485657, 21.74903107], [72.27485657, 21.7479229], [72.27513885, 21.7479229], [72.27513885, 21.74708176], [72.27541351, 21.74708366], [72.27541351, 21.74652863], [72.2756958, 21.74653053], [72.2756958, 21.74625015], [72.27597046, 21.74625015], [72.27597046, 21.74542236], [72.27625275, 21.74542236], [72.27625275, 21.7448597], [72.2765274, 21.7448616], [72.2765274, 21.74458313], [72.27680206, 21.74458313], [72.27680206, 21.74430466], [72.27708435, 21.74430466], [72.27708435, 21.74402809], [72.27735901, 21.74403954], [72.27735901, 21.74374962], [72.2776413, 21.74374962], [72.2776413, 21.74347115], [72.27819824, 21.74347305], [72.27819824, 21.74319458], [72.2784729, 21.74319458], [72.2784729, 21.74291611], [72.27874756, 21.74291992], [72.27874756, 21.74263954], [72.27902985, 21.74263954], [72.27902985, 21.74236107], [72.27929688, 21.74236107], [72.27929688, 21.74208069], [72.27958679, 21.7420826], [72.27958679, 21.74152565], [72.27986145, 21.74152946], [72.27986145, 21.74041939], [72.28015137, 21.74041939], [72.28015137, 21.73986053], [72.2804184, 21.73986053], [72.2804184, 21.73931122], [72.28069305, 21.73931122], [72.28069305, 21.73875046], [72.28098297, 21.73875046], [72.28097534, 21.73819351], [72.28125, 21.7381897], [72.28125, 21.73597145], [72.28152466, 21.73597145], [72.28152466, 21.73541641], [72.28180695, 21.73542023], [72.28180695, 21.73513985], [72.2820816, 21.73513985], [72.2820816, 21.73485184], [72.28236389, 21.73486137], [72.28236389, 21.7345829], [72.28263855, 21.7345829], [72.28263855, 21.73347282], [72.28236389, 21.73347282], [72.28236389, 21.73263931], [72.2820816, 21.73263931], [72.2820816, 21.73097038], [72.28180695, 21.73097229], [72.28180695, 21.72958374], [72.28152466, 21.72958374], [72.28152466, 21.7290287], [72.28125, 21.72903061], [72.28125, 21.72875023], [72.28069305, 21.72875023], [72.28069305, 21.72735977], [72.28097534, 21.72736168], [72.28097534, 21.72652626], [72.28125, 21.72653008], [72.28125, 21.72597122], [72.28152466, 21.72597313], [72.28152466, 21.7234726], [72.28180695, 21.7234726], [72.28180695, 21.72208214], [72.28236389, 21.72208214], [72.28236389, 21.72097015], [72.28263855, 21.72097015], [72.28263855, 21.72069359], [72.28291321, 21.72069359], [72.28291321, 21.72041702], [72.28321075, 21.72042274], [72.28321075, 21.72014046], [72.28347015, 21.72014046], [72.28347015, 21.71986961], [72.28375244, 21.71986961], [72.28375244, 21.71875191], [72.2840271, 21.71875191], [72.2840271, 21.71707916], [72.28430176, 21.71708298], [72.28430939, 21.71680641], [72.28457642, 21.71680832], [72.28457642, 21.71624947], [72.2848587, 21.71624947], [72.2848587, 21.71541977], [72.28457642, 21.71541977], [72.28457642, 21.71513939], [72.2848587, 21.71513939], [72.2848587, 21.71458054], [72.28514099, 21.71458244], [72.28514099, 21.71375084], [72.28541565, 21.71375084], [72.28541565, 21.7131958], [72.28569794, 21.7131958], [72.28569794, 21.71263885], [72.28595734, 21.71264076], [72.28595734, 21.71181107], [72.28624725, 21.71181107], [72.28624725, 21.71125031], [72.28652954, 21.71125031], [72.28652954, 21.71070099], [72.28679657, 21.71070099], [72.28679657, 21.71014023], [72.28708649, 21.71014023], [72.28708649, 21.70957947], [72.28736115, 21.70958328], [72.28736115, 21.70874977], [72.2876358, 21.70874977], [72.2876358, 21.70819283], [72.28791809, 21.70819473], [72.28791809, 21.70763969], [72.2876358, 21.70763969], [72.2876358, 21.70736122], [72.28736115, 21.70736122], [72.28736115, 21.70763969], [72.28708649, 21.70763969], [72.28708649, 21.70792961], [72.2868042, 21.70791626], [72.2868042, 21.70819473], [72.28652954, 21.70819473], [72.28652954, 21.7084713], [72.28624725, 21.70846939], [72.28624725, 21.70874977], [72.28595734, 21.70874977], [72.28595734, 21.70903015], [72.28569794, 21.70902824], [72.28569794, 21.70930481], [72.28541565, 21.70930481], [72.28541565, 21.70986176], [72.28514099, 21.70985985], [72.28514099, 21.71014023], [72.2848587, 21.71014023], [72.2848587, 21.71070099], [72.28458405, 21.71069336], [72.28458405, 21.71097183], [72.28430176, 21.71096992], [72.28430176, 21.71125031], [72.2840271, 21.71125031], [72.2840271, 21.71181107], [72.28375244, 21.71181107], [72.28375244, 21.71236038], [72.28347015, 21.71236038], [72.28347015, 21.71264076], [72.2831955, 21.71263885], [72.2831955, 21.7131958], [72.28263855, 21.7131958], [72.28263855, 21.71375084], [72.28235626, 21.7137394], [72.28235626, 21.71403122], [72.2820816, 21.71403122], [72.2820816, 21.71486092], [72.28180695, 21.71486092], [72.28180695, 21.71541977], [72.28151703, 21.71541977], [72.28151703, 21.71680832], [72.28125, 21.71680641], [72.28125, 21.71708298], [72.28097534, 21.71708298], [72.28097534, 21.71736145], [72.28069305, 21.71735954], [72.28069305, 21.7179184], [72.2804184, 21.7179184], [72.2804184, 21.71820259], [72.27958679, 21.71819496], [72.27958679, 21.71847153], [72.27929688, 21.71847153], [72.27929688, 21.71875191], [72.27902985, 21.71875191], [72.27902985, 21.71931267], [72.27874756, 21.71931267], [72.27874756, 21.71986961], [72.2784729, 21.71986961], [72.2784729, 21.72014046], [72.27819824, 21.72013855], [72.27819061, 21.72069359], [72.27791595, 21.72069359], [72.27791595, 21.72097015], [72.2776413, 21.72097015], [72.2776413, 21.72153282], [72.27707672, 21.72153282], [72.27707672, 21.72236061], [72.2767868, 21.72236061], [72.2767868, 21.7226429], [72.2765274, 21.72263908], [72.2765274, 21.72291756], [72.27625275, 21.72291756], [72.27625275, 21.72319221], [72.27597046, 21.72319031], [72.27597046, 21.72430992], [72.2756958, 21.7243042], [72.2756958, 21.72458267], [72.27540588, 21.72458076], [72.27540588, 21.72486115], [72.27485657, 21.72486115], [72.27485657, 21.72513962], [72.27458191, 21.72513962], [72.27458191, 21.72542], [72.27430725, 21.72541428], [72.27430725, 21.72597313], [72.27401733, 21.72597122], [72.27401733, 21.72624969], [72.27375031, 21.72624969], [72.27375031, 21.72653008], [72.27347565, 21.72652626], [72.27347565, 21.72736168], [72.27319336, 21.72735977], [72.27319336, 21.72764015], [72.2729187, 21.72764015], [72.2729187, 21.72792053], [72.27263641, 21.72792053], [72.27263641, 21.72820091], [72.27236176, 21.72819519], [72.27236176, 21.72847176], [72.2720871, 21.72846985], [72.2720871, 21.72875023], [72.27179718, 21.72875023], [72.27179718, 21.72903061], [72.27153015, 21.7290287], [72.27153015, 21.72958374], [72.27124786, 21.72957993], [72.27124786, 21.73041916], [72.27097321, 21.73041725], [72.27097321, 21.73069382], [72.27069092, 21.73069382], [72.27069092, 21.73097229], [72.27041626, 21.73097038], [72.27041626, 21.73152924], [72.2701416, 21.73152924], [72.2701416, 21.73263931], [72.26957703, 21.73263931], [72.26957703, 21.73291969], [72.26930237, 21.73291588], [72.26930237, 21.73319435], [72.26902771, 21.73318863], [72.26902771, 21.73402977], [72.26875305, 21.73402786], [72.26875305, 21.7345829], [72.26847076, 21.7345829], [72.26847076, 21.73597145], [72.26819611, 21.73596954], [72.26819611, 21.73624992], [72.26792145, 21.73624992], [72.26792145, 21.7365303], [72.26763916, 21.7365303], [72.26763916, 21.73903084], [72.26791382, 21.73902512], [72.26792145, 21.73986053], [72.26763916, 21.73986053], [72.26763916, 21.74069595], [72.26791382, 21.74069595], [72.26791382, 21.74097252], [72.26847076, 21.74097061], [72.26847076, 21.74125099], [72.26902771, 21.74125099], [72.26902771, 21.74152946], [72.26930237, 21.74152946], [72.26930237, 21.74180984], [72.26958466, 21.74180794], [72.26958466, 21.7420826], [72.26985931, 21.74208069], [72.26985931, 21.74263954], [72.2701416, 21.74263954], [72.2701416, 21.74291992], [72.27041626, 21.74291611], [72.27041626, 21.74319458], [72.27069092, 21.74319458], [72.27069092, 21.74347305], [72.27097321, 21.74347305], [72.27097321, 21.74374962], [72.27124786, 21.74374962], [72.27124786, 21.74430466], [72.27153015, 21.74430466], [72.27153015, 21.7448616], [72.27179718, 21.7448597], [72.27179718, 21.74570274], [72.2720871, 21.74570274], [72.2720871, 21.74681282], [72.27236176, 21.74681282], [72.27236176, 21.7479229], [72.27263641, 21.74791718], [72.27263641, 21.74847221], [72.2729187, 21.74847031], [72.2729187, 21.74875069], [72.27319336, 21.74875069], [72.27319336, 21.74903107], [72.27348328, 21.74903107], [72.27348328, 21.74930954], [72.27375031, 21.74930573], [72.27375031, 21.74958229], [72.27430725, 21.74958229]]], [[[72.58790588, 21.33930969], [72.58790588, 21.33792114], [72.58763885, 21.33792114], [72.58763885, 21.33681107], [72.58735657, 21.33681107], [72.58735657, 21.33625031], [72.58598328, 21.33625031], [72.58598328, 21.33653069], [72.58569336, 21.33653069], [72.58569336, 21.33681107], [72.5854187, 21.33680344], [72.5854187, 21.33708572], [72.58569336, 21.33708], [72.58569336, 21.33736038], [72.58598328, 21.33736038], [72.58598328, 21.3376503], [72.58625031, 21.33763885], [72.58625031, 21.3381958], [72.58652496, 21.3381958], [72.58652496, 21.33847237], [72.58680725, 21.33847046], [72.58680725, 21.33903122], [72.58708191, 21.33903122], [72.58708191, 21.33986092], [72.5881958, 21.33986092], [72.5881958, 21.33930969], [72.58790588, 21.33930969]]], [[[72.58319092, 21.36541939], [72.58319092, 21.36514091], [72.58374786, 21.36514091], [72.58374786, 21.36457062], [72.58347321, 21.36458588], [72.58347321, 21.36375046], [72.58319092, 21.36375046], [72.58319092, 21.36292076], [72.58291626, 21.36292076], [72.58291626, 21.36236], [72.58235931, 21.36236382], [72.58235931, 21.36208153], [72.58208466, 21.36208153], [72.58208466, 21.36180305], [72.58152771, 21.36182022], [72.58152771, 21.3615303], [72.58125305, 21.3615303], [72.58125305, 21.36124992], [72.58069611, 21.36124992], [72.58069611, 21.36096954], [72.58041382, 21.36097145], [72.58041382, 21.36069489], [72.5798645, 21.36069489], [72.5798645, 21.36041641], [72.57958221, 21.36042023], [72.57958221, 21.36013985], [72.57875061, 21.36013985], [72.57875061, 21.36042023], [72.57902527, 21.36041641], [72.57902527, 21.36097145], [72.57930756, 21.36096954], [72.57930756, 21.36182022], [72.57958221, 21.36182022], [72.57958221, 21.36431122], [72.58013916, 21.36430359], [72.58013916, 21.36458588], [72.58097076, 21.36458588], [72.58097076, 21.36486053], [72.58152771, 21.36486053], [72.58152771, 21.36514091], [72.58207703, 21.36514091], [72.58207703, 21.36541939], [72.58319092, 21.36541939]]], [[[72.1029129, 21.27431107], [72.1029129, 21.27403069], [72.10346985, 21.27403069], [72.10346985, 21.27264023], [72.10320282, 21.27264023], [72.10320282, 21.27042007], [72.1029129, 21.27042007], [72.1029129, 21.27013969], [72.10263824, 21.27013969], [72.10263824, 21.26958084], [72.10236359, 21.26958466], [72.10236359, 21.26930618], [72.1020813, 21.26931], [72.1020813, 21.26902962], [72.10180664, 21.26902962], [72.10180664, 21.26847076], [72.10152435, 21.26847458], [72.10152435, 21.26819229], [72.10124969, 21.26819229], [72.10124969, 21.26791573], [72.10098267, 21.26791954], [72.10098267, 21.26736069], [72.10069275, 21.26736069], [72.10069275, 21.26708031], [72.10041809, 21.26708221], [72.10041809, 21.26680565], [72.1001358, 21.26680946], [72.1001358, 21.26597023], [72.09986115, 21.26597023], [72.09986115, 21.26569366], [72.09958649, 21.26569366], [72.09958649, 21.2654171], [72.09902954, 21.26540947], [72.09902954, 21.26625061], [72.09928894, 21.26625061], [72.09928894, 21.26680946], [72.09958649, 21.26680565], [72.09958649, 21.26736069], [72.09986115, 21.26736069], [72.09986115, 21.26791954], [72.1001358, 21.26791763], [72.1001358, 21.26847458], [72.10041809, 21.26847076], [72.10041809, 21.26902962], [72.10069275, 21.26902962], [72.10069275, 21.26931], [72.10097504, 21.26930618], [72.10097504, 21.26958466], [72.10124969, 21.26958084], [72.10124969, 21.27013969], [72.10151672, 21.27013969], [72.10151672, 21.27042007], [72.10180664, 21.27041435], [72.10180664, 21.27069664], [72.1020813, 21.27069092], [72.1020813, 21.27292061], [72.10234833, 21.27292061], [72.10234833, 21.27403069], [72.10263824, 21.27403069], [72.10263824, 21.27431107], [72.1029129, 21.27431107]]], [[[72.60041809, 21.38708115], [72.60041809, 21.38375092], [72.6001358, 21.38375092], [72.6001358, 21.37930107], [72.59986115, 21.37930679], [72.59986115, 21.37791443], [72.59958649, 21.37792015], [72.59958649, 21.37763977], [72.59929657, 21.37763977], [72.59929657, 21.37735939], [72.59902954, 21.3773613], [72.59902954, 21.37708473], [72.59874725, 21.37708473], [72.59874725, 21.37680626], [72.5984726, 21.37680626], [72.5984726, 21.37652779], [72.59819794, 21.37652969], [72.59819794, 21.37625122], [72.59792328, 21.37625122], [72.59792328, 21.37597084], [72.59764099, 21.37597466], [72.59764099, 21.37569237], [72.5973587, 21.37569237], [72.5973587, 21.3754158], [72.59707642, 21.37541962], [72.59707642, 21.37514114], [72.59680939, 21.37514114], [72.59680176, 21.37486076], [72.59625244, 21.37486076], [72.59625244, 21.37458038], [72.59597015, 21.37458229], [72.59597015, 21.37430573], [72.59570313, 21.37430954], [72.59570313, 21.37403107], [72.59541321, 21.37403107], [72.59541321, 21.37376022], [72.59513855, 21.37376022], [72.59513855, 21.37347031], [72.59486389, 21.37347031], [72.59486389, 21.37319374], [72.5945816, 21.37319374], [72.5945816, 21.37291718], [72.59430695, 21.3729229], [72.59430695, 21.37264252], [72.59401703, 21.37264252], [72.59401703, 21.37236023], [72.59375, 21.37236023], [72.59375, 21.37208176], [72.59347534, 21.37208366], [72.59347534, 21.37180519], [72.59319305, 21.37181282], [72.59319305, 21.37153244], [72.5929184, 21.37153244], [72.5929184, 21.37125015], [72.59263611, 21.37125015], [72.59263611, 21.37096977], [72.59236145, 21.37097168], [72.59236145, 21.37069511], [72.59208679, 21.37070084], [72.59208679, 21.37041855], [72.59179688, 21.37041855], [72.59179688, 21.37013817], [72.59152985, 21.37013817], [72.59152985, 21.3698597], [72.59124756, 21.3698616], [72.59124756, 21.36958313], [72.5909729, 21.36958313], [72.5909729, 21.36930466], [72.59041595, 21.36930466], [72.59041595, 21.36902809], [72.59014893, 21.36902809], [72.59014893, 21.36874962], [72.58985901, 21.36874962], [72.58985901, 21.36847115], [72.58958435, 21.36847305], [72.58958435, 21.36819458], [72.58930206, 21.36819458], [72.58930206, 21.36791611], [72.5890274, 21.36791992], [72.5890274, 21.36763], [72.58875275, 21.36763954], [72.58875275, 21.36736107], [72.58763885, 21.36736107], [72.58763885, 21.36763954], [72.58790588, 21.36763], [72.58790588, 21.36791992], [72.5881958, 21.36791611], [72.5881958, 21.36819458], [72.58847046, 21.36819458], [72.58847046, 21.36847305], [72.58875275, 21.36847115], [72.58875275, 21.36874962], [72.5890274, 21.36874962], [72.5890274, 21.36902809], [72.58930206, 21.36902809], [72.58930206, 21.36930466], [72.58958435, 21.36930466], [72.58958435, 21.36958313], [72.58985901, 21.36958122], [72.58985901, 21.37013817], [72.59014893, 21.37013817], [72.59014893, 21.37041855], [72.59041595, 21.37041855], [72.59041595, 21.37070084], [72.59069061, 21.37069511], [72.59069824, 21.37097168], [72.5909729, 21.37096977], [72.5909729, 21.37125015], [72.59124756, 21.37125015], [72.59124756, 21.37153244], [72.59152985, 21.37153244], [72.59152985, 21.37181282], [72.5918045, 21.37180519], [72.5918045, 21.37208366], [72.5909729, 21.37208176], [72.5909729, 21.37236023], [72.59014893, 21.37236023], [72.59014893, 21.37264252], [72.58930206, 21.37264252], [72.58930206, 21.3729229], [72.58958435, 21.37291718], [72.58958435, 21.37347031], [72.58985901, 21.37347031], [72.58985901, 21.37403107], [72.59014893, 21.37403107], [72.59014893, 21.37430954], [72.59041595, 21.37430954], [72.59041595, 21.37486076], [72.59069061, 21.37486076], [72.59069824, 21.37541962], [72.5909729, 21.3754158], [72.5909729, 21.37597466], [72.59124756, 21.37597084], [72.59124756, 21.37625122], [72.59152985, 21.37624931], [72.59152985, 21.37680626], [72.5918045, 21.37680626], [72.5918045, 21.3773613], [72.59208679, 21.37735939], [72.59208679, 21.37763977], [72.59236145, 21.37763977], [72.59236145, 21.37819672], [72.59263611, 21.37819099], [72.59263611, 21.37874985], [72.5929184, 21.37874985], [72.5929184, 21.37930679], [72.59319305, 21.37930679], [72.59319305, 21.37958336], [72.59348297, 21.37957001], [72.59348297, 21.3801403], [72.59375, 21.3801403], [72.59375, 21.38070107], [72.59402466, 21.38069534], [72.59402466, 21.38097191], [72.59430695, 21.38096809], [72.59430695, 21.38125038], [72.5945816, 21.38125038], [72.5945816, 21.38180923], [72.59486389, 21.38180542], [72.59486389, 21.38208389], [72.59513855, 21.38207817], [72.59513855, 21.38236046], [72.59541321, 21.38236046], [72.59541321, 21.38293266], [72.5956955, 21.3829174], [72.5956955, 21.38319397], [72.59597015, 21.38319397], [72.59597015, 21.38347244], [72.59625244, 21.38347054], [72.59625244, 21.38402939], [72.5965271, 21.38402939], [72.5965271, 21.38431168], [72.59680176, 21.38430595], [72.59680176, 21.38458252], [72.59707642, 21.38458061], [72.59707642, 21.38513947], [72.5973587, 21.38513947], [72.5973587, 21.38542175], [72.59764099, 21.38542175], [72.59764099, 21.38570023], [72.59791565, 21.3856945], [72.59791565, 21.38624954], [72.59819794, 21.38624954], [72.59819794, 21.38653183], [72.59902191, 21.38653183], [72.59902191, 21.3868103], [72.59986115, 21.38680649], [72.59986115, 21.38708115], [72.60041809, 21.38708115]]], [[[72.62819672, 21.41736031], [72.62819672, 21.41681099], [72.62847137, 21.41681099], [72.62847137, 21.41625023], [72.62819672, 21.41625023], [72.62819672, 21.41542053], [72.6279068, 21.41542053], [72.6279068, 21.41485977], [72.62763977, 21.41486359], [72.62763977, 21.41402817], [72.62735748, 21.41403008], [72.62735748, 21.41319275], [72.62708282, 21.41319466], [72.62708282, 21.41235924], [72.62680817, 21.41235924], [72.62680817, 21.41181183], [72.62652588, 21.41181183], [72.62652588, 21.41097069], [72.62625122, 21.4109726], [72.62625122, 21.41041756], [72.62596893, 21.41041946], [72.62596893, 21.40987015], [72.62568665, 21.40987015], [72.62568665, 21.40957832], [72.62541962, 21.40958405], [72.62541962, 21.4090271], [72.62513733, 21.40903091], [72.62513733, 21.40847015], [72.62486267, 21.40847206], [72.62486267, 21.40819359], [72.62458038, 21.40819359], [72.62458038, 21.40763855], [72.62431335, 21.40764046], [72.62431335, 21.40736008], [72.62403107, 21.40736198], [72.62403107, 21.40680695], [72.62374878, 21.40681076], [72.62374878, 21.40625], [72.62346649, 21.40625], [72.62346649, 21.40596962], [72.62319183, 21.40597153], [72.62319183, 21.40541649], [72.62291718, 21.4054203], [72.62291718, 21.40513992], [72.62264252, 21.40513992], [72.62264252, 21.40458107], [72.62236023, 21.40458488], [72.62236023, 21.40402794], [72.6220932, 21.40402985], [72.6220932, 21.40373993], [72.62180328, 21.40374947], [72.62180328, 21.40319252], [72.62152863, 21.40319252], [72.62152863, 21.40291405], [72.62124634, 21.40291977], [72.62124634, 21.40263939], [72.62097168, 21.40263939], [72.62097168, 21.40236092], [72.6204071, 21.40236092], [72.6204071, 21.40208054], [72.62014008, 21.40208244], [72.62014008, 21.40180588], [72.61985779, 21.40180969], [72.61985779, 21.40153122], [72.61958313, 21.40153122], [72.61958313, 21.40125275], [72.61902618, 21.40125275], [72.61902618, 21.40097046], [72.61875153, 21.40097237], [72.61875153, 21.40069389], [72.61846924, 21.40069389], [72.61846924, 21.40041733], [72.61818695, 21.40042114], [72.61818695, 21.40014267], [72.61763763, 21.40014267], [72.61763763, 21.39986038], [72.61736298, 21.39986038], [72.61736298, 21.39958191], [72.61708069, 21.39958382], [72.61708069, 21.39930534], [72.61680603, 21.39931107], [72.61680603, 21.39875031], [72.61653137, 21.39875031], [72.61653137, 21.3982029], [72.61624908, 21.3982029], [72.61624908, 21.39763832], [72.6159668, 21.39763832], [72.6159668, 21.39707756], [72.61569214, 21.39708328], [72.61569214, 21.39652824], [72.61541748, 21.39652824], [72.61541748, 21.39624977], [72.61513519, 21.39624977], [72.61513519, 21.3959713], [72.61486053, 21.3959713], [72.61486053, 21.39569473], [72.61264038, 21.39569473], [72.61264038, 21.3959713], [72.61235809, 21.39596748], [72.61235809, 21.39652824], [72.61208344, 21.39652824], [72.61208344, 21.39708328], [72.61235809, 21.39707756], [72.61235809, 21.39793015], [72.61264038, 21.39791679], [72.61264038, 21.39847183], [72.61292267, 21.39847183], [72.61292267, 21.39903259], [72.61319733, 21.39903259], [72.61319733, 21.39931107], [72.61347198, 21.39931107], [72.61347198, 21.39986038], [72.61374664, 21.39986038], [72.61374664, 21.40014267], [72.61402893, 21.40013885], [72.61402893, 21.40069389], [72.61430359, 21.40069389], [72.61430359, 21.40097237], [72.61458588, 21.40097046], [72.61458588, 21.40153122], [72.61486053, 21.40153122], [72.61486053, 21.40180969], [72.61513519, 21.40180588], [72.61513519, 21.40208244], [72.61541748, 21.40208054], [72.61541748, 21.40263939], [72.61569214, 21.40263939], [72.61569214, 21.40291977], [72.61597443, 21.40291405], [72.61597443, 21.40347481], [72.61624908, 21.40347481], [72.61624908, 21.40374947], [72.61653137, 21.40373993], [72.61653137, 21.40431023], [72.61680603, 21.40430641], [72.61680603, 21.40458488], [72.61708832, 21.40458107], [72.61708832, 21.40513992], [72.61736298, 21.40513992], [72.61736298, 21.4054203], [72.61763763, 21.4054203], [72.61763763, 21.40570068], [72.61819458, 21.40569687], [72.61819458, 21.40597153], [72.61846924, 21.40596962], [72.61846924, 21.40625], [72.61875153, 21.40625], [72.61875153, 21.40653038], [72.61930847, 21.40653038], [72.61930847, 21.40681076], [72.61958313, 21.40680695], [72.61958313, 21.40708351], [72.61985779, 21.40708351], [72.61985779, 21.40736198], [72.62014771, 21.40736008], [72.62014771, 21.40764046], [72.62069702, 21.40764046], [72.62069702, 21.40792084], [72.62097168, 21.40791893], [72.62097168, 21.40819359], [72.62124634, 21.40818977], [72.62124634, 21.40875053], [72.62152863, 21.40875053], [72.62152863, 21.40930748], [72.62180328, 21.40930557], [72.62180328, 21.40958405], [72.6220932, 21.40957832], [72.6220932, 21.41013908], [72.62236023, 21.41013908], [72.62236023, 21.41069412], [72.62264252, 21.41069412], [72.62264252, 21.4109726], [72.62291718, 21.41097069], [72.62291718, 21.41124916], [72.62319183, 21.41124916], [72.62319183, 21.41181183], [72.62347412, 21.41180611], [72.62347412, 21.41208267], [72.62374878, 21.41208076], [72.62374878, 21.41235924], [72.62403107, 21.41235924], [72.62403107, 21.41291618], [72.62430573, 21.41291618], [72.62430573, 21.41319466], [72.62513733, 21.41319466], [72.62513733, 21.41291618], [72.62541962, 21.41291618], [72.62541962, 21.41263962], [72.62596893, 21.41263962], [72.62596893, 21.41319466], [72.62625122, 21.41319275], [72.62625122, 21.41403008], [72.62652588, 21.41402817], [72.62652588, 21.41486359], [72.62680817, 21.41485977], [72.62680817, 21.41542053], [72.62708282, 21.41542053], [72.62708282, 21.41625023], [72.62735748, 21.41625023], [72.62735748, 21.41708565], [72.62763977, 21.41707993], [72.62763977, 21.41736031], [72.62819672, 21.41736031]]], [[[72.63597107, 21.41764069], [72.63597107, 21.41736031], [72.63680267, 21.41736031], [72.63680267, 21.41681099], [72.63707733, 21.41681099], [72.63707733, 21.41596985], [72.63680267, 21.41597176], [72.63680267, 21.41541672], [72.63652802, 21.41542053], [72.63652802, 21.41485977], [72.63625336, 21.41486359], [72.63625336, 21.41430473], [72.63597107, 21.41430473], [72.63597107, 21.41374969], [72.63569641, 21.41374969], [72.63569641, 21.41319275], [72.63541412, 21.41319466], [72.63541412, 21.41291618], [72.63486481, 21.41291618], [72.63486481, 21.41263962], [72.63458252, 21.41263962], [72.63458252, 21.41235924], [72.63402557, 21.41235924], [72.63402557, 21.41208267], [72.63375092, 21.41208267], [72.63375092, 21.41180611], [72.63153076, 21.41180611], [72.63153076, 21.41208267], [72.63180542, 21.41208267], [72.63180542, 21.41263962], [72.63208008, 21.41263962], [72.63208008, 21.41319466], [72.63236237, 21.41319275], [72.63236237, 21.41374969], [72.63263702, 21.41374969], [72.63263702, 21.41403008], [72.63291931, 21.41402817], [72.63291931, 21.41430473], [72.63319397, 21.41430473], [72.63319397, 21.4145813], [72.63346863, 21.4145813], [72.63346863, 21.41486359], [72.63375092, 21.41485977], [72.63375092, 21.41514015], [72.6340332, 21.41514015], [72.6340332, 21.41542053], [72.63430786, 21.41542053], [72.63430786, 21.41570091], [72.63458252, 21.41569328], [72.63458252, 21.41597176], [72.63513184, 21.41596985], [72.63513184, 21.41764069], [72.63597107, 21.41764069]]], [[[72.67597198, 21.44680977], [72.67597198, 21.44598007], [72.67624664, 21.44598007], [72.67624664, 21.44431114], [72.67597198, 21.44431114], [72.67597198, 21.44320107], [72.67569733, 21.44320107], [72.67569733, 21.44292068], [72.67485809, 21.44292068], [72.67485809, 21.4426403], [72.67457581, 21.4426403], [72.67457581, 21.44235992], [72.67402649, 21.44236374], [72.67402649, 21.44208145], [72.67375183, 21.44208145], [72.67375183, 21.44180489], [72.67346954, 21.44180489], [72.67346954, 21.44124985], [72.67318726, 21.44124985], [72.67318726, 21.4406929], [72.67292023, 21.44069481], [72.67292023, 21.44041634], [72.67263794, 21.44042015], [72.67263794, 21.44013977], [72.67180634, 21.44013977], [72.67180634, 21.43985176], [72.67097473, 21.4398613], [72.67097473, 21.43958282], [72.67041779, 21.43958282], [72.67041779, 21.43902779], [72.66879272, 21.43902969], [72.66819763, 21.43902969], [72.66819763, 21.43874931], [72.66764069, 21.43874931], [72.66764069, 21.43847084], [72.66625214, 21.43847275], [72.66625214, 21.43819427], [72.66596985, 21.43819427], [72.66596985, 21.43847275], [72.66570282, 21.43847084], [72.66570282, 21.43874931], [72.66513824, 21.43874931], [72.66513824, 21.43931007], [72.66486359, 21.43930626], [72.66486359, 21.43958282], [72.66374969, 21.43958282], [72.66374969, 21.44097137], [72.66401672, 21.44096947], [72.66401672, 21.44153023], [72.66430664, 21.44152832], [72.66430664, 21.44180489], [72.6645813, 21.44180489], [72.6645813, 21.44208145], [72.66486359, 21.44208145], [72.66486359, 21.44236374], [72.66513824, 21.44235992], [72.66513824, 21.44292068], [72.6654129, 21.44292068], [72.6654129, 21.44320107], [72.66596985, 21.44319344], [72.66596985, 21.44347382], [72.66707611, 21.44347], [72.66707611, 21.44375038], [72.66764069, 21.44375038], [72.66764069, 21.44403076], [72.66792297, 21.44403076], [72.66792297, 21.44431114], [72.66847229, 21.44430351], [72.66847229, 21.4445858], [72.66902924, 21.44458008], [72.66902924, 21.44514084], [72.66958618, 21.44514084], [72.66958618, 21.44542122], [72.67041779, 21.4454174], [72.67041779, 21.44569588], [72.67069244, 21.44569016], [72.67069244, 21.44598007], [72.67124176, 21.44598007], [72.67124176, 21.44625092], [72.67514038, 21.44625092], [72.67514038, 21.44652939], [72.67569733, 21.44652939], [72.67569733, 21.44680977], [72.67597198, 21.44680977]]], [[[72.47264099, 22.20819473], [72.47264099, 22.20791435], [72.47319794, 22.20792007], [72.47319794, 22.20763969], [72.47291565, 22.20763969], [72.47291565, 22.20708275], [72.47264099, 22.20708275], [72.47264099, 22.20680428], [72.47207642, 22.20681], [72.47207642, 22.20597076], [72.4723587, 22.20597267], [72.4723587, 22.20513916], [72.47207642, 22.20514107], [72.47207642, 22.20375061], [72.4723587, 22.20375061], [72.4723587, 22.20318985], [72.47097015, 22.20319366], [72.47097015, 22.20347214], [72.4695816, 22.20347214], [72.46958923, 22.20375061], [72.46930695, 22.20375061], [72.46930695, 22.20318985], [72.46902466, 22.20319366], [72.46902466, 22.20263863], [72.46875, 22.20264053], [72.46875, 22.20236015], [72.4679184, 22.20236015], [72.4679184, 22.20541954], [72.46875, 22.20541954], [72.46875, 22.20514107], [72.46930695, 22.20513916], [72.46930695, 22.20597267], [72.46958923, 22.20597076], [72.46958923, 22.20625114], [72.46985626, 22.20625114], [72.46985626, 22.20652962], [72.47041321, 22.20652962], [72.47041321, 22.20681], [72.4706955, 22.20680428], [72.4706955, 22.20708275], [72.47097015, 22.20708275], [72.47097015, 22.20736122], [72.4715271, 22.20734978], [72.4715271, 22.20763969], [72.47180176, 22.20763969], [72.47180176, 22.20792007], [72.47208405, 22.20791435], [72.47208405, 22.20819473], [72.47264099, 22.20819473]]], [[[72.38430786, 22.21569443], [72.38430786, 22.21541595], [72.38540649, 22.21541977], [72.38540649, 22.21513939], [72.38625336, 22.21513939], [72.38625336, 22.21486282], [72.38735962, 22.21486282], [72.38735962, 22.21458244], [72.38819122, 22.21458244], [72.38819122, 22.21430588], [72.38874817, 22.21430969], [72.38874817, 22.21403122], [72.38903046, 22.21403122], [72.38903046, 22.21375084], [72.38957977, 22.21375084], [72.38957977, 22.2134819], [72.39013672, 22.2134819], [72.39013672, 22.21318817], [72.39041901, 22.21319389], [72.39041901, 22.21264076], [72.39068604, 22.21264076], [72.39068604, 22.21235847], [72.39097595, 22.21235847], [72.39097595, 22.21180916], [72.39125061, 22.21180916], [72.39125061, 22.21153069], [72.3915329, 22.21153069], [72.3915329, 22.21125031], [72.39180756, 22.21125031], [72.39180756, 22.21069908], [72.39208221, 22.21069908], [72.39208221, 22.21041107], [72.39180756, 22.2104187], [72.39180756, 22.21013641], [72.38764191, 22.21013641], [72.38764191, 22.2104187], [72.38735962, 22.21041107], [72.38735962, 22.21069908], [72.38764191, 22.21069527], [72.38764191, 22.21097183], [72.38791656, 22.21096992], [72.38791656, 22.21125031], [72.38817596, 22.21125031], [72.38817596, 22.21153069], [72.38846588, 22.21153069], [72.38846588, 22.21180916], [72.38819122, 22.21180534], [72.38819122, 22.21208382], [72.38791656, 22.21207809], [72.38791656, 22.21235847], [72.38764191, 22.21235847], [72.38764191, 22.21291924], [72.38735962, 22.21291733], [72.38735962, 22.21319389], [72.38707733, 22.21318817], [72.38707733, 22.2134819], [72.38652802, 22.2134819], [72.38652802, 22.21375084], [72.38597107, 22.21375084], [72.38597107, 22.21403122], [72.38540649, 22.21403122], [72.38540649, 22.21430969], [72.38486481, 22.21430588], [72.38486481, 22.21458244], [72.38430786, 22.21458244], [72.38430786, 22.21486282], [72.38375092, 22.21486282], [72.38375092, 22.21513939], [72.38318634, 22.21513939], [72.38318634, 22.21541977], [72.38263702, 22.21541595], [72.38263702, 22.21569443], [72.38430786, 22.21569443]]], [[[72.37069702, 22.23513985], [72.37069702, 22.23402977], [72.3704071, 22.23402977], [72.3704071, 22.23319054], [72.37014008, 22.23319435], [72.37014008, 22.23291588], [72.36985779, 22.23291969], [72.36985779, 22.23264122], [72.36958313, 22.23264122], [72.36958313, 22.23236084], [72.36930847, 22.23236084], [72.36930847, 22.23180962], [72.36902618, 22.23180962], [72.36902618, 22.23125076], [72.36875153, 22.23125076], [72.36875153, 22.23069191], [72.36902618, 22.23069382], [72.36902618, 22.23041725], [72.36930847, 22.23042107], [72.36930847, 22.23014069], [72.36985779, 22.23014069], [72.36985779, 22.22986031], [72.37014008, 22.22986031], [72.37014008, 22.22958183], [72.37041473, 22.22958374], [72.37041473, 22.2290287], [72.37014008, 22.22903061], [72.37014008, 22.22820282], [72.36985779, 22.22820282], [72.36985779, 22.22764015], [72.37069702, 22.22764015], [72.37069702, 22.22680092], [72.37041473, 22.22680473], [72.37041473, 22.2262516], [72.36846924, 22.2262516], [72.36846924, 22.22513962], [72.36818695, 22.22513962], [72.36818695, 22.22402954], [72.36846924, 22.22402954], [72.36846924, 22.22375107], [72.36902618, 22.22375107], [72.36902618, 22.22347069], [72.36930847, 22.2234726], [72.36930847, 22.22319412], [72.36985779, 22.22319412], [72.36985779, 22.22291946], [72.37014008, 22.22291946], [72.37014008, 22.22014046], [72.3704071, 22.22014046], [72.37041473, 22.21750069], [72.37041473, 22.21680641], [72.37069702, 22.21681023], [72.37069702, 22.21513939], [72.37097168, 22.21513939], [72.37097168, 22.21403122], [72.37124634, 22.21403122], [72.37124634, 22.2134819], [72.37152863, 22.2134819], [72.37152863, 22.21291924], [72.37180328, 22.21291924], [72.37180328, 22.21235847], [72.3720932, 22.21235847], [72.37208557, 22.21180534], [72.37236023, 22.21180916], [72.37236023, 22.21125031], [72.37264252, 22.21125031], [72.37264252, 22.21069908], [72.37291718, 22.21069908], [72.37291718, 22.21014023], [72.37317657, 22.21014023], [72.37317657, 22.20985985], [72.37347412, 22.20986176], [72.37347412, 22.20958328], [72.37374878, 22.20958328], [72.37374878, 22.20930481], [72.37403107, 22.20930481], [72.37403107, 22.20902634], [72.37431335, 22.20903015], [72.37431335, 22.20874977], [72.37458038, 22.20874977], [72.37458038, 22.20846939], [72.37486267, 22.2084713], [72.37486267, 22.20819473], [72.37513733, 22.20819473], [72.37513733, 22.20791435], [72.37541962, 22.20792007], [72.37541962, 22.20763969], [72.37568665, 22.20763969], [72.37568665, 22.20734978], [72.37596893, 22.20736122], [72.37596893, 22.20708275], [72.37625122, 22.20708275], [72.37625122, 22.20541763], [72.37652588, 22.20541954], [72.37652588, 22.20375061], [72.37513733, 22.20375061], [72.37513733, 22.20403099], [72.37486267, 22.20403099], [72.37486267, 22.20430946], [72.37430573, 22.20430565], [72.37430573, 22.20458221], [72.37346649, 22.20458031], [72.37346649, 22.20486069], [72.37264252, 22.20486069], [72.37264252, 22.20514107], [72.3720932, 22.20514107], [72.3720932, 22.20541954], [72.37152863, 22.20541573], [72.37152863, 22.2056942], [72.37124634, 22.2056942], [72.37124634, 22.20597267], [72.37069702, 22.20597076], [72.37069702, 22.20625114], [72.36958313, 22.20625114], [72.36958313, 22.20652962], [72.36875153, 22.20652962], [72.36875153, 22.20681], [72.36819458, 22.20680428], [72.36819458, 22.20708275], [72.36791992, 22.20708275], [72.36791992, 22.20736122], [72.36736298, 22.20736122], [72.36737061, 22.20763969], [72.36680603, 22.20763969], [72.36680603, 22.20792007], [72.36624908, 22.20791435], [72.36624908, 22.20819473], [72.36597443, 22.20819473], [72.36597443, 22.2084713], [72.36541748, 22.20846939], [72.36541748, 22.20903015], [72.36513519, 22.20902634], [72.36513519, 22.20958328], [72.36486053, 22.20957947], [72.36486053, 22.21014023], [72.36458588, 22.21013641], [72.36458588, 22.21097183], [72.36486053, 22.21096992], [72.36486053, 22.21153069], [72.36458588, 22.21152878], [72.36458588, 22.21175957], [72.36458588, 22.21208382], [72.36429596, 22.21207809], [72.36429596, 22.21264076], [72.36402893, 22.21264076], [72.36402893, 22.21319389], [72.36374664, 22.21318817], [72.36374664, 22.21403122], [72.36347198, 22.2140274], [72.36347198, 22.2234726], [72.36374664, 22.22347069], [72.36374664, 22.22402954], [72.36402893, 22.22402954], [72.36402893, 22.22430992], [72.36429596, 22.22430992], [72.36429596, 22.22485924], [72.36458588, 22.22485924], [72.36458588, 22.22541809], [72.36486053, 22.22541809], [72.36486053, 22.22653008], [72.36514282, 22.22653008], [72.36514282, 22.22792053], [72.36541748, 22.22792053], [72.36541748, 22.22903061], [72.3659668, 22.22903061], [72.3659668, 22.2293129], [72.36708069, 22.2293129], [72.36708069, 22.22986031], [72.36736298, 22.22986031], [72.36736298, 22.23069382], [72.36708069, 22.23069382], [72.36708069, 22.23097229], [72.36680603, 22.23097229], [72.36680603, 22.23152733], [72.36653137, 22.2315197], [72.36653137, 22.23180962], [72.36680603, 22.2318058], [72.36680603, 22.23208427], [72.36708069, 22.23208046], [72.36708069, 22.23236084], [72.36737061, 22.23236084], [72.36737061, 22.23264122], [72.36763763, 22.23264122], [72.36763763, 22.23291969], [72.36791992, 22.23291588], [72.36791992, 22.23319435], [72.36818695, 22.23319054], [72.36818695, 22.23374939], [72.36846924, 22.23374939], [72.36846924, 22.23402977], [72.36875153, 22.23402977], [72.36875153, 22.23431015], [72.36902618, 22.23430443], [72.36902618, 22.2345829], [72.36930847, 22.2345829], [72.36930847, 22.23486137], [72.36958313, 22.23485947], [72.36958313, 22.23513985], [72.37069702, 22.23513985]]], [[[69.31041718, 22.30625153], [69.31041718, 22.30596924], [69.31069183, 22.30597305], [69.31069183, 22.30513763], [69.31096649, 22.30513763], [69.31096649, 22.30485916], [69.31124878, 22.30485916], [69.31124878, 22.30458069], [69.31153107, 22.3045826], [69.31153107, 22.30430794], [69.31181335, 22.30430984], [69.31181335, 22.30402946], [69.31208038, 22.30402946], [69.31208038, 22.30347061], [69.31180573, 22.30347252], [69.31180573, 22.30319405], [69.31041718, 22.30319405], [69.31041718, 22.30347252], [69.31014252, 22.30347061], [69.31014252, 22.30376053], [69.30986023, 22.30376053], [69.30986023, 22.30402946], [69.30958557, 22.30402946], [69.30958557, 22.3045826], [69.30928802, 22.30458069], [69.30928802, 22.30513763], [69.30958557, 22.30513763], [69.30958557, 22.30569458], [69.30986023, 22.30569458], [69.30986023, 22.30597305], [69.31014252, 22.30596924], [69.31014252, 22.30625153], [69.31041718, 22.30625153]]], [[[69.45263672, 22.35819435], [69.45263672, 22.35791588], [69.45319366, 22.35791588], [69.45319366, 22.35763741], [69.45404053, 22.35764122], [69.45404053, 22.35736084], [69.45430756, 22.35736084], [69.45430756, 22.35708046], [69.45458221, 22.35708427], [69.45458221, 22.3568058], [69.45513916, 22.35680962], [69.45513916, 22.35653114], [69.45540619, 22.35653114], [69.45540619, 22.35625076], [69.45597076, 22.35625076], [69.45597076, 22.35597038], [69.45652771, 22.35597229], [69.45652771, 22.35569382], [69.45708466, 22.35569382], [69.45708466, 22.35513878], [69.45735931, 22.35514069], [69.45735931, 22.35485077], [69.4576416, 22.35486031], [69.4576416, 22.35430527], [69.45791626, 22.35431099], [69.45791626, 22.35403061], [69.45819092, 22.35403061], [69.45819092, 22.35346985], [69.45847321, 22.35347176], [69.45847321, 22.35263824], [69.45819092, 22.35264015], [69.45819092, 22.35207939], [69.45735931, 22.35208321], [69.45735931, 22.35180473], [69.45569611, 22.35181046], [69.45569611, 22.35153008], [69.45485687, 22.35153008], [69.45485687, 22.35124969], [69.45402527, 22.35124969], [69.45402527, 22.35097313], [69.45375061, 22.35097313], [69.45375061, 22.35069466], [69.44985962, 22.35069466], [69.44985962, 22.35097313], [69.44875336, 22.35097122], [69.44875336, 22.35124969], [69.44790649, 22.35124969], [69.44790649, 22.35153008], [69.44680786, 22.35153008], [69.44680786, 22.35181046], [69.44596863, 22.35180473], [69.44596863, 22.35208321], [69.44486237, 22.35208321], [69.44486237, 22.35236168], [69.44403076, 22.35235977], [69.44403076, 22.35264015], [69.44319153, 22.35264015], [69.44319153, 22.35292053], [69.44235992, 22.35292053], [69.44235992, 22.35320091], [69.44152832, 22.35319328], [69.44152832, 22.35347176], [69.44069672, 22.35346985], [69.44069672, 22.35375023], [69.43985748, 22.35375023], [69.43985748, 22.35403061], [69.43958282, 22.35403061], [69.43958282, 22.35375023], [69.43902588, 22.35375023], [69.43902588, 22.35403061], [69.43818665, 22.35403061], [69.43818665, 22.35431099], [69.43736267, 22.35430527], [69.43736267, 22.35458374], [69.43763733, 22.35457993], [69.43763733, 22.35514069], [69.43791962, 22.35514069], [69.43791962, 22.35542107], [69.43819427, 22.35541534], [69.43819427, 22.35569382], [69.43846893, 22.35569382], [69.43846893, 22.35597229], [69.43873596, 22.35597038], [69.43873596, 22.35625076], [69.43930817, 22.35625076], [69.43930817, 22.35653114], [69.43958282, 22.35653114], [69.43958282, 22.35680962], [69.44097137, 22.3568058], [69.44097137, 22.35708427], [69.44347382, 22.35708427], [69.44347382, 22.3568058], [69.44486237, 22.3568058], [69.44486237, 22.35708427], [69.44541931, 22.35708427], [69.44541931, 22.3568058], [69.44568634, 22.35680962], [69.44568634, 22.35653114], [69.44708252, 22.35653114], [69.44708252, 22.35680962], [69.44791412, 22.3568058], [69.44791412, 22.35708427], [69.44819641, 22.35708046], [69.44819641, 22.35736084], [69.44875336, 22.35736084], [69.44875336, 22.35764122], [69.44930267, 22.35763741], [69.44930267, 22.35791588], [69.45014191, 22.35791588], [69.45014191, 22.35819435], [69.45263672, 22.35819435]]], [[[69.18402863, 22.36763954], [69.18402863, 22.36736107], [69.18486023, 22.36736107], [69.18486023, 22.36708069], [69.18569183, 22.3670826], [69.18569183, 22.36513901], [69.18541718, 22.36514091], [69.18541718, 22.36404037], [69.18430328, 22.36404037], [69.18430328, 22.36431122], [69.18402863, 22.36431122], [69.18402863, 22.36486053], [69.18374634, 22.36486053], [69.18374634, 22.36541939], [69.18347168, 22.36541748], [69.18347168, 22.36569595], [69.18321228, 22.36569023], [69.18321228, 22.36625099], [69.18292236, 22.36625099], [69.18292236, 22.36680984], [69.18264008, 22.36680984], [69.18264008, 22.36736107], [69.18291473, 22.36736107], [69.18291473, 22.36763954], [69.18402863, 22.36763954]]], [[[72.35679626, 21.93180084], [72.35680389, 21.93124962], [72.35708618, 21.93124962], [72.35708618, 21.93041992], [72.35736084, 21.93041992], [72.35736084, 21.92930984], [72.35764313, 21.92930984], [72.35764313, 21.92847061], [72.35791779, 21.92847252], [72.35791779, 21.9276371], [72.35820007, 21.92765045], [72.35820007, 21.92708015], [72.35874939, 21.92708588], [72.35874939, 21.9268074], [72.35901642, 21.92681122], [72.35901642, 21.92653084], [72.35958099, 21.92653084], [72.35958099, 21.92625046], [72.35986328, 21.92625046], [72.35986328, 21.92597008], [72.36042023, 21.92597198], [72.36042023, 21.92458344], [72.35874939, 21.92458344], [72.35874939, 21.92486191], [72.35736084, 21.92486], [72.35736084, 21.92514038], [72.35624695, 21.92514038], [72.35624695, 21.92542076], [72.35597229, 21.92541695], [72.35597229, 21.92597198], [72.35569763, 21.92597008], [72.35569763, 21.92653084], [72.35541534, 21.92652512], [72.35541534, 21.92708588], [72.35514069, 21.92708015], [72.35514069, 21.92765045], [72.3548584, 21.9276371], [72.3548584, 21.92819595], [72.35457611, 21.92819023], [72.35457611, 21.92875099], [72.35430908, 21.92875099], [72.35430908, 21.92930984], [72.35402679, 21.92930984], [72.35402679, 21.92847061], [72.35375214, 21.92847252], [72.35375214, 21.9276371], [72.35346985, 21.92765045], [72.35346985, 21.92708015], [72.35319519, 21.92708588], [72.35319519, 21.92652512], [72.3529129, 21.92653084], [72.3529129, 21.92597008], [72.35263824, 21.92597198], [72.35263824, 21.92541695], [72.35180664, 21.92541695], [72.35180664, 21.92569351], [72.35152435, 21.92569351], [72.35152435, 21.92597198], [72.35124969, 21.92597008], [72.35124969, 21.92625046], [72.35098267, 21.92625046], [72.35098267, 21.92681122], [72.35069275, 21.9268074], [72.35069275, 21.92708588], [72.35041809, 21.92708015], [72.35041809, 21.92736053], [72.3501358, 21.92736053], [72.3501358, 21.92765045], [72.34958649, 21.92765045], [72.34958649, 21.92791939], [72.3493042, 21.92791557], [72.3493042, 21.92819595], [72.34792328, 21.92819023], [72.34792328, 21.92902946], [72.34764099, 21.92902946], [72.34764099, 21.92986107], [72.34792328, 21.92986107], [72.34792328, 21.93041992], [72.34819794, 21.93041611], [72.34819794, 21.93097305], [72.3484726, 21.93097115], [72.3484726, 21.93152809], [72.34874725, 21.93152809], [72.34874725, 21.93208313], [72.34902954, 21.93207932], [72.34902954, 21.93264008], [72.34929657, 21.93264008], [72.34929657, 21.93292046], [72.34958649, 21.93291664], [72.34958649, 21.93347168], [72.34986115, 21.93345833], [72.34986115, 21.93403053], [72.3501358, 21.93402863], [72.3501358, 21.93458366], [72.35041809, 21.93458176], [72.35041809, 21.93514061], [72.35069275, 21.9351387], [72.35069275, 21.93569374], [72.35098267, 21.93569183], [72.35098267, 21.93764114], [72.35124969, 21.93764114], [72.35124969, 21.93959045], [72.35151672, 21.93959045], [72.35151672, 21.94042015], [72.35180664, 21.94041443], [72.35180664, 21.94097137], [72.35206604, 21.94096947], [72.35206604, 21.94153023], [72.35236359, 21.94152641], [72.35236359, 21.94208336], [72.3529129, 21.94208336], [72.3529129, 21.94236183], [72.35320282, 21.94235992], [72.35320282, 21.94264984], [72.35375214, 21.94264984], [72.35375214, 21.94292068], [72.35402679, 21.94292068], [72.35402679, 21.94319916], [72.3548584, 21.94319916], [72.3548584, 21.94292068], [72.35514069, 21.94292068], [72.35514069, 21.94235992], [72.35541534, 21.94236183], [72.35541534, 21.94180679], [72.35569763, 21.94180679], [72.35569763, 21.94097137], [72.35597229, 21.94097137], [72.35597229, 21.94041443], [72.35624695, 21.94042015], [72.35624695, 21.93985939], [72.35652924, 21.9398613], [72.35652924, 21.93930435], [72.35679626, 21.93931007], [72.35679626, 21.9354229], [72.35708618, 21.9354229], [72.35708618, 21.93431282], [72.35736084, 21.93431282], [72.35736084, 21.93375015], [72.35764313, 21.93375015], [72.3576355, 21.93291664], [72.35791779, 21.93292046], [72.35791779, 21.93207932], [72.35819244, 21.93208313], [72.35819244, 21.93152809], [72.3584671, 21.93152809], [72.3584671, 21.93069077], [72.35819244, 21.93069458], [72.35819244, 21.93041611], [72.3576355, 21.93041611], [72.3576355, 21.93097305], [72.35736084, 21.93097115], [72.35736084, 21.93152809], [72.35708618, 21.93152809], [72.35708618, 21.93180466], [72.35679626, 21.93180084]]], [[[72.2140274, 22.00542068], [72.2140274, 22.00485992], [72.21375275, 22.00486183], [72.21375275, 22.00458336], [72.21347046, 22.00458336], [72.21347046, 22.00430489], [72.21291351, 22.00430489], [72.21291351, 22.00402832], [72.21263885, 22.00403023], [72.21263885, 22.00374985], [72.21235657, 22.00374985], [72.21235657, 22.00346947], [72.21263885, 22.00347137], [72.21263885, 22.00291634], [72.2131958, 22.00292969], [72.2131958, 22.00263977], [72.21373749, 22.00263977], [72.21373749, 22.00292969], [72.21430206, 22.00291634], [72.21430206, 22.00319481], [72.21458435, 22.00319481], [72.21458435, 22.00291634], [72.21485901, 22.00291634], [72.21485901, 22.00319481], [72.21541595, 22.00319481], [72.21541595, 22.00347137], [72.21569061, 22.00346947], [72.21569824, 22.00374985], [72.2159729, 22.00374985], [72.2159729, 22.00346947], [72.21624756, 22.00347137], [72.21624756, 22.00263977], [72.2159729, 22.00263977], [72.2159729, 22.00208282], [72.2151413, 22.00208282], [72.2151413, 22.00180626], [72.21457672, 22.00181007], [72.21457672, 22.00152969], [72.21430206, 22.00152969], [72.21430206, 22.00125122], [72.21347046, 22.00125122], [72.21347046, 22.00152969], [72.2131958, 22.00152969], [72.2131958, 22.00181007], [72.21291351, 22.00180626], [72.21291351, 22.00208282], [72.2123642, 22.00208282], [72.2123642, 22.0023613], [72.21180725, 22.00235939], [72.21180725, 22.00263977], [72.21151733, 22.00263977], [72.21151733, 22.00292969], [72.21069336, 22.00291634], [72.21069336, 22.00319481], [72.2104187, 22.0031929], [72.2104187, 22.00374985], [72.2106781, 22.00374985], [72.2106781, 22.00403023], [72.21097565, 22.00402832], [72.21097565, 22.00430489], [72.21152496, 22.00430489], [72.21152496, 22.00458336], [72.21180725, 22.00458336], [72.21180725, 22.00486183], [72.21208191, 22.00485992], [72.21208191, 22.0051403], [72.21235657, 22.0051403], [72.21235657, 22.00542068], [72.2140274, 22.00542068]]], [[[68.21624756, 23.59124947], [68.21624756, 23.59069061], [68.21652985, 23.59069443], [68.21652985, 23.59013939], [68.21681213, 23.59013939], [68.2168045, 23.58819389], [68.21708679, 23.58819389], [68.21708679, 23.58763885], [68.21736145, 23.58764076], [68.21736145, 23.58707809], [68.21763611, 23.58708382], [68.21763611, 23.58680534], [68.21736145, 23.58680916], [68.21736145, 23.58653069], [68.21710205, 23.58653069], [68.21710205, 23.58625031], [68.21652985, 23.58625031], [68.21652985, 23.58653069], [68.2159729, 23.58653069], [68.2159729, 23.58680916], [68.21541595, 23.58680534], [68.21541595, 23.58708382], [68.2151413, 23.58707809], [68.2151413, 23.58736038], [68.21541595, 23.58736038], [68.21541595, 23.58819389], [68.2151413, 23.58818817], [68.2151413, 23.5893116], [68.21485901, 23.58930588], [68.21485901, 23.59069443], [68.2151413, 23.59069061], [68.2151413, 23.59124947], [68.21624756, 23.59124947]]], [[[68.2234726, 23.58625031], [68.2234726, 23.58596992], [68.22569275, 23.58597183], [68.22569275, 23.58569527], [68.22651672, 23.58569908], [68.22651672, 23.58542061], [68.22735596, 23.58542061], [68.22735596, 23.58514023], [68.2279129, 23.58514023], [68.2279129, 23.58485985], [68.22819519, 23.58486176], [68.22819519, 23.58430672], [68.2279129, 23.58430672], [68.2279129, 23.58402824], [68.22680664, 23.58403015], [68.22680664, 23.58374977], [68.2251358, 23.58374977], [68.2251358, 23.58403015], [68.22402954, 23.58402824], [68.22402954, 23.58430672], [68.22374725, 23.58430672], [68.22374725, 23.58458328], [68.22319794, 23.58458328], [68.22319794, 23.58486176], [68.22290802, 23.58485985], [68.22290802, 23.58514023], [68.22264099, 23.58514023], [68.22264099, 23.58542061], [68.2223587, 23.5854187], [68.2223587, 23.58597183], [68.22264099, 23.58596992], [68.22264099, 23.58625031], [68.2234726, 23.58625031]]], [[[68.25514221, 23.59013939], [68.25514221, 23.58986092], [68.25541687, 23.58986092], [68.25541687, 23.58902931], [68.25569153, 23.58902931], [68.25569153, 23.58791924], [68.25595856, 23.58791924], [68.25595856, 23.58764076], [68.25624847, 23.58764076], [68.25624847, 23.58625031], [68.25595856, 23.58625031], [68.25595856, 23.58542061], [68.25681305, 23.58542061], [68.25681305, 23.58569908], [68.25791931, 23.58569908], [68.25791931, 23.58514023], [68.25763702, 23.58514023], [68.25763702, 23.58485985], [68.25736237, 23.58486176], [68.25736237, 23.58430672], [68.25708008, 23.58430672], [68.25708008, 23.58402824], [68.25569153, 23.58402824], [68.25569153, 23.58430672], [68.25485992, 23.58430672], [68.25485992, 23.58374977], [68.25514221, 23.58374977], [68.25514221, 23.58291054], [68.25430298, 23.58291435], [68.25430298, 23.58263969], [68.25402832, 23.58263969], [68.25402832, 23.58236122], [68.25347137, 23.58236122], [68.25347137, 23.58208084], [68.25235748, 23.58208084], [68.25235748, 23.58236122], [68.25180817, 23.58236122], [68.25180817, 23.58263969], [68.25152588, 23.58263969], [68.25152588, 23.58291435], [68.24986267, 23.58291435], [68.24986267, 23.58319664], [68.24958038, 23.58319092], [68.24958038, 23.58374977], [68.24986267, 23.58374977], [68.24986267, 23.58403015], [68.25013733, 23.58402824], [68.25013733, 23.58430672], [68.25041962, 23.58430672], [68.25041962, 23.58458328], [68.25068665, 23.58457947], [68.25068665, 23.58542061], [68.25096893, 23.58542061], [68.25096893, 23.58653069], [68.25125122, 23.58653069], [68.25125122, 23.58680916], [68.25068665, 23.58680916], [68.25068665, 23.58736038], [68.24846649, 23.58736038], [68.24846649, 23.58707809], [68.24485779, 23.58707809], [68.24485779, 23.58764076], [68.24514008, 23.58764076], [68.24514008, 23.58875084], [68.24597168, 23.58875084], [68.24597168, 23.58902931], [68.24736023, 23.58902931], [68.24736023, 23.58847046], [68.24764252, 23.58847046], [68.24764252, 23.58902931], [68.24791718, 23.5890274], [68.24791718, 23.58958244], [68.24930573, 23.58958244], [68.24930573, 23.58986092], [68.25402832, 23.58986092], [68.25402832, 23.59013939], [68.25514221, 23.59013939]]], [[[68.4779129, 23.72236061], [68.4779129, 23.72207832], [68.47902679, 23.72208405], [68.47902679, 23.72180557], [68.48042297, 23.72180939], [68.48042297, 23.72153091], [68.48069763, 23.72153091], [68.48069763, 23.721241], [68.48152924, 23.72125053], [68.48152924, 23.72097206], [68.48236084, 23.72097206], [68.48236084, 23.72041893], [68.48208618, 23.72042084], [68.48208618, 23.71986008], [68.48180389, 23.71986198], [68.48180389, 23.71958351], [68.48152924, 23.71958351], [68.48152924, 23.71930695], [68.48097229, 23.71931076], [68.48097229, 23.71903038], [68.48069763, 23.71903038], [68.48069763, 23.71875], [68.48014069, 23.71875], [68.48014069, 23.71846962], [68.4798584, 23.71847153], [68.4798584, 23.71791458], [68.47957611, 23.7179203], [68.47957611, 23.71763992], [68.47930908, 23.71763992], [68.47930908, 23.71747971], [68.47930908, 23.71736145], [68.47846985, 23.71736145], [68.47846985, 23.71708488], [68.47763824, 23.71708488], [68.47763824, 23.7168045], [68.4770813, 23.71681023], [68.4770813, 23.71652985], [68.47680664, 23.71652985], [68.47680664, 23.71624947], [68.47624969, 23.71624947], [68.47624969, 23.71597099], [68.47569275, 23.71597481], [68.47569275, 23.71569633], [68.47541809, 23.71569633], [68.47541809, 23.71541405], [68.47486115, 23.71543121], [68.47486115, 23.71513939], [68.47458649, 23.71513939], [68.47458649, 23.71486092], [68.47374725, 23.71486092], [68.47374725, 23.71458054], [68.47264099, 23.71458054], [68.47264099, 23.71486092], [68.4723587, 23.71486092], [68.4723587, 23.71543121], [68.47208405, 23.71541405], [68.47208405, 23.71569633], [68.47180176, 23.71569633], [68.47180176, 23.71597481], [68.4715271, 23.71597099], [68.4715271, 23.71624947], [68.47125244, 23.71624947], [68.47125244, 23.71652985], [68.4715271, 23.71652794], [68.4715271, 23.71680069], [68.4715271, 23.71708488], [68.47180176, 23.71708488], [68.47180176, 23.71736145], [68.47207642, 23.71735954], [68.47207642, 23.7179203], [68.4723587, 23.71791458], [68.4723587, 23.71847153], [68.47264099, 23.71846962], [68.47264099, 23.71903038], [68.47291565, 23.71902847], [68.47291565, 23.71986198], [68.47319794, 23.71986008], [68.47319794, 23.72042084], [68.4734726, 23.72041893], [68.4734726, 23.72097206], [68.47374725, 23.72097206], [68.47374725, 23.72125053], [68.47402954, 23.721241], [68.47402954, 23.72153091], [68.47486115, 23.72153091], [68.47486115, 23.72180939], [68.47569275, 23.72180557], [68.47569275, 23.72208405], [68.4770813, 23.72207832], [68.4770813, 23.72236061], [68.4779129, 23.72236061]]], [[[68.40791321, 23.45792007], [68.40791321, 23.45735931], [68.40820313, 23.45735931], [68.4081955, 23.45708275], [68.40791321, 23.45708275], [68.40791321, 23.45680618], [68.40763855, 23.4568119], [68.40763855, 23.45597076], [68.40736389, 23.45597267], [68.40736389, 23.4556942], [68.4070816, 23.4556942], [68.4070816, 23.45513916], [68.40680695, 23.45513916], [68.40680695, 23.45458031], [68.40652466, 23.45458412], [68.40652466, 23.45402718], [68.40625, 23.45402908], [68.40625, 23.45318985], [68.40652466, 23.45319366], [68.40652466, 23.45263863], [68.40625, 23.45264053], [68.40625, 23.45236015], [68.40569305, 23.45236015], [68.40569305, 23.45207977], [68.4054184, 23.45207977], [68.4054184, 23.45236015], [68.40513611, 23.45236015], [68.40513611, 23.45264053], [68.40458679, 23.45264053], [68.40458679, 23.45236015], [68.4043045, 23.45236015], [68.40429688, 23.45207977], [68.40291595, 23.45207977], [68.40291595, 23.45236015], [68.4026413, 23.45236015], [68.4026413, 23.45264053], [68.40235901, 23.45264053], [68.40235901, 23.45292091], [68.40208435, 23.4529171], [68.40208435, 23.45319366], [68.40180206, 23.45318985], [68.40180206, 23.45347977], [68.4015274, 23.45347977], [68.4015274, 23.45375061], [68.40125275, 23.45375061], [68.40125275, 23.45513916], [68.40207672, 23.45513916], [68.40207672, 23.45542145], [68.40486145, 23.45541763], [68.40486145, 23.4556942], [68.40513611, 23.4556942], [68.40513611, 23.45597267], [68.4054184, 23.45597076], [68.4054184, 23.45624924], [68.40598297, 23.45624924], [68.40598297, 23.45654106], [68.40625, 23.45654106], [68.40625, 23.4568119], [68.40652466, 23.45680618], [68.40652466, 23.45691109], [68.40652466, 23.45708275], [68.40680695, 23.45708084], [68.40680695, 23.45735931], [68.4070816, 23.45735931], [68.4070816, 23.45763969], [68.40735626, 23.45763969], [68.40735626, 23.45792007], [68.40791321, 23.45792007]]], [[[68.3998642, 23.42847252], [68.3998642, 23.42819405], [68.40013885, 23.42819405], [68.40013885, 23.42791748], [68.40042114, 23.42791939], [68.40042114, 23.42736053], [68.4006958, 23.42736053], [68.4006958, 23.4268055], [68.40097046, 23.42681122], [68.40097046, 23.42542076], [68.40125275, 23.42542076], [68.40125275, 23.42317963], [68.40097046, 23.42319679], [68.40097046, 23.42263794], [68.40071106, 23.42263985], [68.40071106, 23.42208099], [68.39958191, 23.42208481], [68.39958191, 23.42180634], [68.39819336, 23.42180634], [68.39819336, 23.42236137], [68.3979187, 23.42236137], [68.3979187, 23.42319679], [68.39819336, 23.42317963], [68.39819336, 23.4240303], [68.39847565, 23.4240284], [68.39847565, 23.42486191], [68.39875031, 23.42486191], [68.39875031, 23.42597198], [68.39847565, 23.42597198], [68.39847565, 23.42708397], [68.39875031, 23.42707825], [68.39875031, 23.42764091], [68.39902496, 23.4276371], [68.39902496, 23.42819405], [68.39930725, 23.42819405], [68.39930725, 23.42847252], [68.3998642, 23.42847252]]], [[[68.40042114, 23.42124939], [68.40041351, 23.42097473], [68.4006958, 23.42097473], [68.4006958, 23.42041588], [68.40097046, 23.42043114], [68.40097046, 23.42014122], [68.40125275, 23.42014122], [68.40125275, 23.41986084], [68.40180206, 23.41986084], [68.40180206, 23.41958046], [68.40208435, 23.41958237], [68.40208435, 23.4193058], [68.40235901, 23.41930962], [68.40235901, 23.41847038], [68.4026413, 23.41847038], [68.4026413, 23.41791725], [68.40235901, 23.41792107], [68.40235901, 23.41736984], [68.40207672, 23.41736984], [68.40207672, 23.41653252], [68.40180206, 23.41653252], [68.40180206, 23.41597176], [68.40041351, 23.41597176], [68.40042114, 23.41625023], [68.40013885, 23.41625023], [68.40013885, 23.41653252], [68.3998642, 23.4165287], [68.3998642, 23.41708374], [68.39958191, 23.41708183], [68.39958191, 23.41736984], [68.39930725, 23.41736984], [68.39930725, 23.41792107], [68.39902496, 23.41791725], [68.39902496, 23.41847038], [68.39875031, 23.41847038], [68.39875031, 23.41903114], [68.39848328, 23.41903114], [68.39848328, 23.42014122], [68.39875031, 23.42014122], [68.39875031, 23.42043114], [68.39902496, 23.42041588], [68.39902496, 23.42097473], [68.39985657, 23.42097092], [68.39985657, 23.42124939], [68.40042114, 23.42124939]]], [[[68.40208435, 23.42319679], [68.40208435, 23.42263985], [68.40235901, 23.42263985], [68.40235901, 23.42181015], [68.4026413, 23.42181015], [68.4026413, 23.42069054], [68.40235901, 23.42069244], [68.40235901, 23.42041588], [68.40180206, 23.42041588], [68.40180206, 23.42069244], [68.4015274, 23.42069244], [68.4015274, 23.42097473], [68.40125275, 23.42097092], [68.40125275, 23.42292023], [68.4015274, 23.42291641], [68.4015274, 23.42319679], [68.40208435, 23.42319679]]], [[[68.4090271, 23.40930939], [68.4090271, 23.40903091], [68.4092865, 23.40903091], [68.40930939, 23.40847015], [68.40958405, 23.40847206], [68.40958405, 23.40791702], [68.4098587, 23.40792084], [68.4098587, 23.40570068], [68.40958405, 23.40569305], [68.40958405, 23.40597153], [68.4092865, 23.40596962], [68.4092865, 23.40625], [68.4090271, 23.40625], [68.4090271, 23.40792084], [68.40875244, 23.40792084], [68.40875244, 23.40930939], [68.4090271, 23.40930939]]], [[[68.46098328, 23.40514183], [68.46098328, 23.40485954], [68.46125031, 23.40486145], [68.46125031, 23.40458107], [68.46208191, 23.40458107], [68.46208191, 23.40430641], [68.46235657, 23.40431023], [68.46235657, 23.40403175], [68.46290588, 23.40403175], [68.46290588, 23.40374947], [68.46380615, 23.40374947], [68.4651413, 23.40374947], [68.4651413, 23.40346909], [68.46624756, 23.40346909], [68.46624756, 23.40374947], [68.46679688, 23.40374947], [68.46679688, 23.40403175], [68.46736145, 23.40403175], [68.46736145, 23.40431023], [68.4679184, 23.40431023], [68.4679184, 23.40403175], [68.46848297, 23.40403175], [68.46848297, 23.40374947], [68.46902466, 23.40374947], [68.46901703, 23.40346909], [68.46847534, 23.4034729], [68.46847534, 23.40319443], [68.46708679, 23.40319443], [68.46708679, 23.40291595], [68.46569824, 23.40292168], [68.46569824, 23.40263939], [68.46430206, 23.40263939], [68.46430206, 23.40236092], [68.4625473, 23.40236092], [68.46208191, 23.40236092], [68.46208191, 23.40263939], [68.46153259, 23.40263939], [68.46153259, 23.40292168], [68.46097565, 23.40291595], [68.46097565, 23.4034729], [68.46070099, 23.40346909], [68.46070099, 23.40431023], [68.4604187, 23.40431023], [68.4604187, 23.40514183], [68.46098328, 23.40514183]]], [[[68.4145813, 23.40986061], [68.4145813, 23.40958023], [68.41486359, 23.40958595], [68.41486359, 23.40930557], [68.41513824, 23.40930939], [68.41513824, 23.40903091], [68.41542053, 23.40903091], [68.41542053, 23.40875053], [68.41596985, 23.40875053], [68.41596985, 23.40847015], [68.41625214, 23.40847206], [68.41625214, 23.4081955], [68.41652679, 23.4081955], [68.41652679, 23.40791702], [68.41680908, 23.40792084], [68.41680908, 23.40764046], [68.41707611, 23.40764046], [68.41707611, 23.4070797], [68.4173584, 23.40708542], [68.4173584, 23.40652847], [68.41764069, 23.40653038], [68.41764069, 23.40570068], [68.41792297, 23.40570068], [68.41792297, 23.40542984], [68.41845703, 23.40542984], [68.41845703, 23.40570068], [68.41874695, 23.40569305], [68.41874695, 23.40597153], [68.41845703, 23.40596962], [68.41845703, 23.40681076], [68.41930389, 23.40680313], [68.41930389, 23.40708542], [68.41958618, 23.40708542], [68.41958618, 23.40680313], [68.42014313, 23.40681076], [68.42014313, 23.40653038], [68.41986084, 23.40653038], [68.41986084, 23.40596962], [68.41930389, 23.40597153], [68.41930389, 23.40569305], [68.41902924, 23.40570068], [68.41902924, 23.40485954], [68.41930389, 23.40486145], [68.41930389, 23.40430641], [68.41958618, 23.40431023], [68.41958618, 23.40374947], [68.41929626, 23.40374947], [68.41929626, 23.40319061], [68.41902924, 23.40319443], [68.41902924, 23.40291595], [68.41958618, 23.40292168], [68.41958618, 23.40263939], [68.42014313, 23.40263939], [68.4201355, 23.40236092], [68.42041779, 23.40236092], [68.42041779, 23.4018116], [68.42069244, 23.4018116], [68.42069244, 23.40152931], [68.4209671, 23.40152931], [68.4209671, 23.40125084], [68.42151642, 23.40125084], [68.42151642, 23.40152931], [68.42180634, 23.4015274], [68.42180634, 23.40208244], [68.42208099, 23.40208054], [68.42208099, 23.40236092], [68.42180634, 23.40236092], [68.42180634, 23.40263939], [68.42151642, 23.40263939], [68.42151642, 23.40292168], [68.42124939, 23.40292168], [68.42124939, 23.40403175], [68.42097473, 23.40402794], [68.42097473, 23.40486145], [68.42124939, 23.40485954], [68.42124939, 23.40514183], [68.42236328, 23.40514183], [68.42236328, 23.40458107], [68.42263794, 23.40458107], [68.42263794, 23.40430641], [68.42292023, 23.40431023], [68.42292023, 23.40403175], [68.42318726, 23.40403175], [68.42318726, 23.40346909], [68.42346954, 23.4034729], [68.42346954, 23.40319443], [68.42375183, 23.40319443], [68.42375183, 23.40291595], [68.42402649, 23.40292168], [68.42402649, 23.40152931], [68.42375183, 23.40152931], [68.42375183, 23.40125084], [68.42346954, 23.40125084], [68.42346954, 23.40068817], [68.42236328, 23.40069389], [68.42236328, 23.40013885], [68.42208099, 23.40014076], [68.42208099, 23.40041924], [68.42097473, 23.40041733], [68.42097473, 23.40069389], [68.41958618, 23.40069389], [68.41958618, 23.40041733], [68.41874695, 23.40041733], [68.41874695, 23.40069389], [68.41819763, 23.40069389], [68.41819763, 23.40097237], [68.41764069, 23.40097046], [68.41764069, 23.40125084], [68.41680908, 23.40125084], [68.41680908, 23.40208244], [68.41596985, 23.40208054], [68.41596985, 23.40236092], [68.4154129, 23.40236092], [68.41542053, 23.40263939], [68.41513824, 23.40263939], [68.41513824, 23.40292168], [68.4145813, 23.40291595], [68.4145813, 23.40319443], [68.41374969, 23.40319443], [68.41374969, 23.4034729], [68.41347504, 23.4034729], [68.41348267, 23.40374947], [68.41319275, 23.40374947], [68.41319275, 23.40486145], [68.41291809, 23.40485954], [68.41291809, 23.40514183], [68.41430664, 23.40514183], [68.41430664, 23.40458107], [68.4145813, 23.40458107], [68.4145813, 23.40430641], [68.41485596, 23.40431023], [68.41485596, 23.40403175], [68.41542053, 23.40403175], [68.41542053, 23.40431023], [68.41569519, 23.40430641], [68.41569519, 23.40486145], [68.41542053, 23.40485954], [68.41542053, 23.40542984], [68.41513824, 23.40542984], [68.41513824, 23.40570068], [68.41485596, 23.40570068], [68.41485596, 23.40625], [68.4145813, 23.40625], [68.4145813, 23.40653038], [68.41430664, 23.40653038], [68.41430664, 23.40625], [68.41319275, 23.40625], [68.41319275, 23.40653038], [68.41348267, 23.40653038], [68.41348267, 23.40764046], [68.41319275, 23.40763855], [68.41319275, 23.40958595], [68.41347504, 23.40958595], [68.41347504, 23.40986061], [68.4145813, 23.40986061]]], [[[68.42986298, 23.40708542], [68.42986298, 23.40680313], [68.43096924, 23.40681076], [68.43096924, 23.40653038], [68.43125153, 23.40653038], [68.43125153, 23.40625], [68.43152618, 23.40625], [68.43152618, 23.40596962], [68.43180847, 23.40597153], [68.43180847, 23.40569305], [68.43235779, 23.40570068], [68.43235779, 23.40485954], [68.43125153, 23.40485954], [68.43125153, 23.40514183], [68.43096924, 23.40514183], [68.43096924, 23.40542984], [68.43041992, 23.40542984], [68.43041992, 23.40570068], [68.43013763, 23.40569305], [68.43013763, 23.40597153], [68.42958069, 23.40596962], [68.42958069, 23.40625], [68.42930603, 23.40625], [68.42930603, 23.40653038], [68.42903137, 23.40653038], [68.42903137, 23.40681076], [68.42930603, 23.40680313], [68.42930603, 23.40708542], [68.42986298, 23.40708542]]], [[[68.4631958, 23.40903091], [68.4631958, 23.40681076], [68.46347046, 23.40681076], [68.46347046, 23.40625], [68.46376038, 23.40625], [68.46375275, 23.40597153], [68.4640274, 23.40597153], [68.4640274, 23.40569305], [68.46430206, 23.40570068], [68.46430206, 23.40542984], [68.46457672, 23.40542984], [68.46457672, 23.40514183], [68.4631958, 23.40514183], [68.4631958, 23.40542984], [68.46235657, 23.40542984], [68.46235657, 23.40570068], [68.46208191, 23.40569305], [68.46208191, 23.40597153], [68.46180725, 23.40596962], [68.46180725, 23.40625], [68.46153259, 23.40625], [68.46153259, 23.40681076], [68.46180725, 23.40681076], [68.46180725, 23.40764046], [68.46208191, 23.40763855], [68.46208191, 23.4081955], [68.46235657, 23.40818024], [68.46235657, 23.40875053], [68.46263885, 23.40875053], [68.46263885, 23.40903091], [68.4631958, 23.40903091]]], [[[68.46069336, 23.41263962], [68.46069336, 23.41236115], [68.46180725, 23.41236115], [68.46180725, 23.41208076], [68.46208191, 23.41208267], [68.46208191, 23.41180611], [68.46235657, 23.41180992], [68.46235657, 23.41152954], [68.46263885, 23.41152954], [68.46263885, 23.41123962], [68.46291351, 23.41124916], [68.46291351, 23.4109726], [68.46125031, 23.4109726], [68.46125031, 23.41124916], [68.46070099, 23.41123962], [68.46070099, 23.41152954], [68.46013641, 23.41152954], [68.46013641, 23.41180992], [68.45996094, 23.41180611], [68.45929718, 23.41180992], [68.45929718, 23.41152954], [68.45903015, 23.41152954], [68.45903015, 23.41123962], [68.45791626, 23.41124916], [68.45791626, 23.41208267], [68.45847321, 23.41208076], [68.45847321, 23.41236115], [68.45903015, 23.41236115], [68.45903015, 23.41263962], [68.46024323, 23.41263962], [68.46069336, 23.41263962]]], [[[68.31346893, 23.5834713], [68.30986023, 23.5834713], [68.30986023, 23.58319664], [68.30902863, 23.58319664], [68.30902863, 23.58291435], [68.30847168, 23.58291435], [68.30847168, 23.58319664], [68.30874634, 23.58319664], [68.30874634, 23.5834713], [68.30902863, 23.58346939], [68.30902863, 23.58374977], [68.30930328, 23.58374977], [68.30930328, 23.58403015], [68.30986023, 23.58402824], [68.30986023, 23.58430672], [68.31014252, 23.58430672], [68.31014252, 23.58486176], [68.30986023, 23.58485985], [68.30986023, 23.58569908], [68.30958557, 23.58569527], [68.30958557, 23.58597183], [68.30930328, 23.58596992], [68.30930328, 23.58625031], [68.30902863, 23.58625031], [68.30902863, 23.58653069], [68.30819702, 23.58653069], [68.30819702, 23.58680916], [68.30706787, 23.58680916], [68.30706787, 23.58653069], [68.30652618, 23.58653069], [68.30652618, 23.58736038], [68.30625153, 23.58736038], [68.30625153, 23.58847237], [68.30596924, 23.58847237], [68.30596924, 23.58958244], [68.30569458, 23.58958244], [68.30569458, 23.59069443], [68.30541992, 23.59069061], [68.30541992, 23.59153175], [68.30513763, 23.59152794], [68.30513763, 23.59208107], [68.30486298, 23.59208107], [68.30486298, 23.59263992], [68.30458069, 23.59263802], [68.30458069, 23.5956955], [68.30432129, 23.59568977], [68.30432129, 23.59653091], [68.30374908, 23.59653091], [68.30374908, 23.59597015], [68.30347443, 23.59597206], [68.30347443, 23.59541512], [68.30319214, 23.59542084], [68.30319214, 23.59485054], [68.30291748, 23.59486389], [68.30291748, 23.59458542], [68.30263519, 23.59458542], [68.30263519, 23.59402847], [68.30236053, 23.59403038], [68.30236053, 23.59375], [68.30208588, 23.59375], [68.30208588, 23.59346962], [68.30152893, 23.59347153], [68.30152893, 23.59319305], [68.3012619, 23.59320068], [68.3012619, 23.5929203], [68.30069733, 23.5929203], [68.30069733, 23.59263992], [68.30042267, 23.59263992], [68.30042267, 23.59208107], [68.30014038, 23.59208107], [68.30014038, 23.59180641], [68.29985809, 23.59181023], [68.29985809, 23.59124947], [68.29957581, 23.59124947], [68.29957581, 23.59069061], [68.29985809, 23.59069443], [68.29985809, 23.59013939], [68.30014038, 23.59013939], [68.30014038, 23.5893116], [68.30042267, 23.5893116], [68.30042267, 23.58875084], [68.30014038, 23.58875084], [68.30014038, 23.58847046], [68.29985809, 23.58847237], [68.29985809, 23.58819389], [68.29958344, 23.58819389], [68.29958344, 23.58791733], [68.29985809, 23.58791924], [68.29985809, 23.58736038], [68.30014038, 23.58736038], [68.30014038, 23.58707809], [68.30041504, 23.58708382], [68.30041504, 23.58680534], [68.30069733, 23.58680916], [68.30069733, 23.58653069], [68.30180359, 23.58652878], [68.30180359, 23.58708382], [68.30263519, 23.58708382], [68.30263519, 23.58680534], [68.30291748, 23.58680916], [68.30291748, 23.58653069], [68.30432129, 23.58653069], [68.30432129, 23.58514023], [68.30458069, 23.58514023], [68.30458069, 23.58485985], [68.30735779, 23.58486176], [68.30735779, 23.58430672], [68.30764008, 23.58430672], [68.30764008, 23.58402824], [68.30706787, 23.58403015], [68.30706787, 23.58374977], [68.30625153, 23.58374977], [68.30625153, 23.58346939], [68.30458069, 23.58346939], [68.30458069, 23.58374977], [68.3034668, 23.58374977], [68.3034668, 23.58403015], [68.30263519, 23.58402824], [68.30263519, 23.58430672], [68.30069733, 23.58430672], [68.30069733, 23.58208466], [68.30041504, 23.58208466], [68.30041504, 23.58180428], [68.30014038, 23.58181], [68.30014038, 23.58152962], [68.29985809, 23.58152962], [68.29985809, 23.58125114], [68.29957581, 23.58125114], [68.29957581, 23.58097076], [68.29930878, 23.58097458], [68.29930878, 23.58069229], [68.29846954, 23.58069229], [68.29846954, 23.58041573], [68.29792023, 23.58041954], [68.29792023, 23.58014107], [68.29708099, 23.58014107], [68.29708099, 23.57987022], [68.29651642, 23.57987022], [68.29651642, 23.57958031], [68.29597473, 23.57958221], [68.29597473, 23.57930565], [68.29541779, 23.57930946], [68.29541779, 23.5790329], [68.29486084, 23.5790329], [68.29486084, 23.57875061], [68.29096985, 23.57875061], [68.29096985, 23.5790329], [68.28903198, 23.5790329], [68.28903198, 23.57930946], [68.28819275, 23.57930565], [68.28819275, 23.57958221], [68.2876358, 23.57958031], [68.2876358, 23.57987022], [68.28679657, 23.57987022], [68.28679657, 23.58014107], [68.28624725, 23.58014107], [68.28624725, 23.58041954], [68.28569794, 23.58041573], [68.28569794, 23.58069229], [68.28541565, 23.58069229], [68.28541565, 23.58097458], [68.2848587, 23.58097076], [68.2848587, 23.58125114], [68.28457642, 23.58125114], [68.28457642, 23.58152962], [68.28430176, 23.58152771], [68.28430176, 23.58208466], [68.2840271, 23.58208084], [68.2840271, 23.58263969], [68.28347015, 23.58263969], [68.28347015, 23.58291435], [68.2831955, 23.58291435], [68.2831955, 23.58319664], [68.28289795, 23.58319092], [68.28289795, 23.58374977], [68.28235626, 23.58374977], [68.28235626, 23.58291054], [68.2820816, 23.58291435], [68.2820816, 23.58236122], [68.28069305, 23.58236122], [68.28069305, 23.58263969], [68.2804184, 23.58263969], [68.2804184, 23.58291435], [68.28013611, 23.58291435], [68.28013611, 23.58319664], [68.27986145, 23.58319664], [68.27986145, 23.5834713], [68.27958679, 23.58346939], [68.27958679, 23.58374977], [68.27902985, 23.58374977], [68.27902985, 23.58403015], [68.27874756, 23.58402824], [68.27874756, 23.58430672], [68.2784729, 23.58430672], [68.2784729, 23.58458328], [68.27819824, 23.58458328], [68.27819061, 23.58486176], [68.27791595, 23.58485985], [68.27791595, 23.58514023], [68.2776413, 23.58514023], [68.2776413, 23.58542061], [68.27735901, 23.58542061], [68.27735901, 23.58569908], [68.27708435, 23.58569527], [68.27709198, 23.58625031], [68.27680206, 23.58625031], [68.27680206, 23.58653069], [68.2765274, 23.58653069], [68.2765274, 23.58680916], [68.27625275, 23.58680916], [68.27625275, 23.58736038], [68.27597046, 23.58736038], [68.27597046, 23.58847237], [68.2756958, 23.58847046], [68.2756958, 23.58902931], [68.27541351, 23.5890274], [68.27541351, 23.58958244], [68.27513885, 23.58958054], [68.27513885, 23.59013939], [68.2748642, 23.59013939], [68.2748642, 23.59069443], [68.27458191, 23.59069061], [68.27458191, 23.59181023], [68.27430725, 23.59181023], [68.27430725, 23.59375], [68.27458191, 23.59375], [68.27458191, 23.59431076], [68.27485657, 23.59431076], [68.27485657, 23.59542084], [68.27513885, 23.59541512], [68.27513885, 23.5956955], [68.27540588, 23.59568977], [68.27540588, 23.59625053], [68.2756958, 23.59625053], [68.2756958, 23.59653091], [68.27597046, 23.59652519], [68.27597046, 23.59708595], [68.27625275, 23.59708023], [68.27625275, 23.59736061], [68.27819824, 23.59736061], [68.27819824, 23.59708023], [68.27902985, 23.59708595], [68.27902985, 23.59652519], [68.27929688, 23.59653091], [68.27929688, 23.59542084], [68.27958679, 23.59542084], [68.27958679, 23.5945797], [68.2793045, 23.59458542], [68.2793045, 23.59375], [68.27902985, 23.59375], [68.27902985, 23.5929203], [68.27874756, 23.5929203], [68.27874756, 23.59181023], [68.2784729, 23.59181023], [68.2784729, 23.59069061], [68.27819824, 23.59069443], [68.27819824, 23.58986092], [68.2784729, 23.58986092], [68.2784729, 23.58958054], [68.27902985, 23.58958244], [68.27902985, 23.58930588], [68.27929688, 23.5893116], [68.27929688, 23.58902931], [68.27958679, 23.58902931], [68.27958679, 23.58875084], [68.28013611, 23.58875084], [68.28015137, 23.59013939], [68.27986145, 23.59013939], [68.27986145, 23.59153175], [68.28015137, 23.59153175], [68.28015137, 23.59263992], [68.2804184, 23.59263992], [68.2804184, 23.59375], [68.28069305, 23.59375], [68.28069305, 23.59458542], [68.28098297, 23.5945797], [68.28098297, 23.59542084], [68.28125, 23.59541512], [68.28125, 23.59597206], [68.28152466, 23.59597206], [68.28152466, 23.59708595], [68.28180695, 23.59708595], [68.28180695, 23.5984726], [68.2820816, 23.59847069], [68.2820816, 23.59930992], [68.28236389, 23.59930611], [68.28236389, 23.59958267], [68.28263855, 23.59958076], [68.28263855, 23.60013962], [68.28289795, 23.60013962], [68.28289795, 23.60041809], [68.2831955, 23.60041618], [68.2831955, 23.60069466], [68.28375244, 23.60069084], [68.28375244, 23.60098076], [68.2840271, 23.60098076], [68.2840271, 23.60124969], [68.28708649, 23.60124969], [68.28708649, 23.60098076], [68.28819275, 23.60098076], [68.28819275, 23.60069084], [68.28902435, 23.60069466], [68.28902435, 23.60041618], [68.2895813, 23.60041809], [68.2895813, 23.60013962], [68.2904129, 23.60013962], [68.2904129, 23.59986115], [68.29096985, 23.59986115], [68.29096985, 23.59958076], [68.2923584, 23.59958076], [68.2923584, 23.60013962], [68.29264069, 23.60013962], [68.29264069, 23.60069466], [68.2923584, 23.60069084], [68.2923584, 23.60098076], [68.29096985, 23.60098076], [68.29096985, 23.60152817], [68.29069519, 23.60152817], [68.29069519, 23.60208321], [68.2904129, 23.60207748], [68.2904129, 23.60263824], [68.2893219, 23.60263824], [68.2893219, 23.60292244], [68.28848267, 23.60292244], [68.28848267, 23.60320282], [68.28819275, 23.60319519], [68.28819275, 23.60347176], [68.28791809, 23.60347176], [68.28791809, 23.60375023], [68.2876358, 23.60375023], [68.2876358, 23.60404015], [68.28736115, 23.60404015], [68.28736115, 23.6043129], [68.2868042, 23.60430527], [68.2868042, 23.60458374], [68.28652954, 23.60458183], [68.28652954, 23.60486031], [68.28624725, 23.60486031], [68.28624725, 23.60514259], [68.28457642, 23.60514259], [68.28457642, 23.60542107], [68.28430176, 23.60541725], [68.28430176, 23.60569382], [68.28347015, 23.60569382], [68.28347015, 23.60597229], [68.28289795, 23.60597038], [68.28289795, 23.60625076], [68.28125, 23.60625076], [68.28125, 23.60653114], [68.28151703, 23.60653114], [68.28151703, 23.60736084], [68.28180695, 23.60736084], [68.28180695, 23.60764122], [68.28235626, 23.60764122], [68.28235626, 23.60736084], [68.28347015, 23.60736084], [68.28347015, 23.60764122], [68.28375244, 23.60764122], [68.28375244, 23.60791969], [68.28514099, 23.60791969], [68.28514099, 23.60764122], [68.28542328, 23.60764122], [68.28542328, 23.60736084], [68.2859726, 23.60736084], [68.2859726, 23.60708046], [68.28624725, 23.60708237], [68.28624725, 23.6068058], [68.28679657, 23.60680962], [68.28679657, 23.60653114], [68.28708649, 23.60653114], [68.28708649, 23.60625076], [68.2876358, 23.60625076], [68.2876358, 23.60597038], [68.28819275, 23.60597038], [68.28819275, 23.60625076], [68.28791809, 23.60625076], [68.28791809, 23.60708237], [68.2876358, 23.60708046], [68.2876358, 23.60764122], [68.28736115, 23.60763931], [68.28736115, 23.60847473], [68.28652954, 23.60847092], [68.28652954, 23.60874939], [68.2859726, 23.60874939], [68.2859726, 23.60902977], [68.28569794, 23.60902786], [68.28569794, 23.61097145], [68.2848587, 23.61097145], [68.2848587, 23.61069679], [68.28430176, 23.61069107], [68.28430176, 23.61181068], [68.28375244, 23.61181068], [68.28375244, 23.6115303], [68.28347015, 23.6115303], [68.28347015, 23.61124992], [68.28289795, 23.61124992], [68.28289795, 23.6115303], [68.28263855, 23.6115303], [68.28263855, 23.61264038], [68.28235626, 23.61264038], [68.28235626, 23.61375046], [68.2820816, 23.61375046], [68.2820816, 23.61403084], [68.28125, 23.61403084], [68.28125, 23.61346817], [68.28097534, 23.61347198], [68.28097534, 23.61291885], [68.28069305, 23.61292076], [68.28069305, 23.61236], [68.2804184, 23.61236191], [68.2804184, 23.61180687], [68.27958679, 23.61181068], [68.27958679, 23.6115303], [68.27929688, 23.6115303], [68.27929688, 23.61124992], [68.27874756, 23.61124992], [68.27874756, 23.61096954], [68.2784729, 23.61097145], [68.2784729, 23.61069679], [68.27819824, 23.61069679], [68.27819824, 23.60986137], [68.27791595, 23.60986137], [68.27791595, 23.61097145], [68.2776413, 23.61096954], [68.2776413, 23.61124992], [68.27735901, 23.61124992], [68.27735901, 23.6115303], [68.27709198, 23.6115303], [68.27709198, 23.61181068], [68.27680206, 23.61180687], [68.27680206, 23.61208344], [68.2765274, 23.61208344], [68.2765274, 23.61236191], [68.27625275, 23.61236], [68.27625275, 23.61264038], [68.27597046, 23.61264038], [68.27597046, 23.61292076], [68.2756958, 23.61291885], [68.2756958, 23.61319351], [68.27540588, 23.6131897], [68.27540588, 23.61375046], [68.27513885, 23.61375046], [68.27513885, 23.61430931], [68.27485657, 23.61430931], [68.27485657, 23.61486053], [68.27458191, 23.61486053], [68.27458191, 23.61541939], [68.27430725, 23.61541939], [68.27430725, 23.61598015], [68.27403259, 23.61598015], [68.27403259, 23.61624908], [68.27375031, 23.61624908], [68.27375031, 23.61681175], [68.27347565, 23.61680603], [68.27348328, 23.61735916], [68.27319336, 23.61735916], [68.27319336, 23.61792183], [68.2729187, 23.61792183], [68.2729187, 23.61874962], [68.27263641, 23.61874962], [68.27263641, 23.62070084], [68.2729187, 23.62070084], [68.2729187, 23.62181091], [68.27319336, 23.62180328], [68.27319336, 23.62208557], [68.27348328, 23.62207985], [68.27348328, 23.62264061], [68.27375031, 23.6226387], [68.27375031, 23.62319565], [68.27402496, 23.62319565], [68.27402496, 23.62375069], [68.27430725, 23.62375069], [68.27430725, 23.62430954], [68.27458191, 23.62430954], [68.27458191, 23.62486076], [68.27485657, 23.62486076], [68.27485657, 23.62541962], [68.27513885, 23.62541771], [68.27513885, 23.62569427], [68.27541351, 23.62569427], [68.27541351, 23.62597275], [68.2756958, 23.62597084], [68.2756958, 23.62652969], [68.27597046, 23.62652969], [68.27597046, 23.62680817], [68.27625275, 23.62680626], [68.27625275, 23.6273613], [68.2765274, 23.6273613], [68.2765274, 23.62819481], [68.27680206, 23.62818909], [68.27680206, 23.62874985], [68.27708435, 23.62874985], [68.27708435, 23.62930489], [68.27735901, 23.62930489], [68.27735901, 23.62986183], [68.2776413, 23.62986183], [68.2776413, 23.63042259], [68.27791595, 23.63042259], [68.27791595, 23.63125038], [68.2784729, 23.63125038], [68.2784729, 23.63097954], [68.27902985, 23.63097954], [68.27902985, 23.63070107], [68.27958679, 23.63070107], [68.27958679, 23.63042259], [68.28015137, 23.63042259], [68.28015137, 23.6301403], [68.28069305, 23.6301403], [68.28069305, 23.62986183], [68.28097534, 23.62986183], [68.28097534, 23.62958336], [68.28152466, 23.62958336], [68.28152466, 23.62930489], [68.2820816, 23.62930489], [68.2820816, 23.62902832], [68.28263855, 23.62902832], [68.28263855, 23.62874985], [68.28289795, 23.62874985], [68.28289795, 23.62846756], [68.28347015, 23.62847137], [68.28347015, 23.62819481], [68.28458405, 23.62819481], [68.28458405, 23.62791634], [68.28542328, 23.62791824], [68.28542328, 23.62763977], [68.28652954, 23.62763977], [68.28652954, 23.62735939], [68.2895813, 23.62735939], [68.2895813, 23.62763977], [68.29096985, 23.62763977], [68.29096985, 23.62791824], [68.2923584, 23.62791634], [68.2923584, 23.62819481], [68.29347229, 23.62819481], [68.29347229, 23.62847137], [68.29429626, 23.62846756], [68.29429626, 23.62874985], [68.29541779, 23.62874985], [68.29541779, 23.62902832], [68.29708099, 23.62902832], [68.29708099, 23.62930489], [68.29846954, 23.62930489], [68.29846954, 23.62958336], [68.30014038, 23.62958336], [68.30014038, 23.62986183], [68.30152893, 23.62986183], [68.30152893, 23.6301403], [68.30458069, 23.6301403], [68.30458069, 23.62986183], [68.30541992, 23.62986183], [68.30541992, 23.62958336], [68.30625153, 23.62958336], [68.30625153, 23.62930489], [68.30652618, 23.62930489], [68.30652618, 23.62874985], [68.30680847, 23.62874985], [68.30680847, 23.62791824], [68.30706787, 23.62791824], [68.30706787, 23.62763977], [68.30735779, 23.62763977], [68.30735779, 23.62735939], [68.30764008, 23.6273613], [68.30764008, 23.62708282], [68.30791473, 23.62708282], [68.30791473, 23.62680626], [68.30819702, 23.62680817], [68.30819702, 23.62652969], [68.30847168, 23.62652969], [68.30847168, 23.62625122], [68.30902863, 23.62625122], [68.30902863, 23.62597084], [68.30930328, 23.62597275], [68.30930328, 23.62541771], [68.3095932, 23.62541962], [68.3095932, 23.62514114], [68.31012726, 23.62514114], [68.31012726, 23.62486076], [68.31069183, 23.62486076], [68.31069183, 23.62458038], [68.31124878, 23.6245842], [68.31124878, 23.62430763], [68.31153107, 23.62430954], [68.31153107, 23.62403107], [68.31181335, 23.62403107], [68.31181335, 23.62375069], [68.31208038, 23.62375069], [68.31208038, 23.62347031], [68.31236267, 23.62347221], [68.31236267, 23.62319565], [68.31263733, 23.62319565], [68.31263733, 23.62291527], [68.31291962, 23.62292099], [68.31291962, 23.62264061], [68.3132019, 23.62264061], [68.3132019, 23.62236023], [68.31375122, 23.62236023], [68.31375122, 23.62264061], [68.31402588, 23.62264061], [68.31402588, 23.62292099], [68.31375122, 23.62291527], [68.31375122, 23.62319565], [68.31319427, 23.62319565], [68.3132019, 23.62375069], [68.31291962, 23.62375069], [68.31291962, 23.62403107], [68.31263733, 23.62403107], [68.31263733, 23.62430954], [68.31236267, 23.62430763], [68.31236267, 23.6245842], [68.31180573, 23.6245842], [68.31181335, 23.62486076], [68.31153107, 23.62486076], [68.31153107, 23.62514114], [68.31124878, 23.62514114], [68.31124878, 23.62541962], [68.31069183, 23.62541771], [68.31069183, 23.62569427], [68.31014252, 23.62569427], [68.31014252, 23.62597275], [68.30986023, 23.62597084], [68.30986023, 23.62652969], [68.3095932, 23.62652969], [68.3095932, 23.62680817], [68.30902863, 23.62680626], [68.30902863, 23.62708282], [68.30874634, 23.62708282], [68.30874634, 23.6273613], [68.30847168, 23.62735939], [68.30847168, 23.62763977], [68.30819702, 23.62763977], [68.30819702, 23.62791824], [68.30791473, 23.62791634], [68.30791473, 23.62819481], [68.30764008, 23.62818909], [68.30764008, 23.62874985], [68.30735779, 23.62874985], [68.30735779, 23.62930489], [68.30706787, 23.62929916], [68.30706787, 23.6301403], [68.30680847, 23.6301403], [68.30680847, 23.63070107], [68.30403137, 23.63070107], [68.30403137, 23.63097954], [68.3012619, 23.63097954], [68.3012619, 23.63070107], [68.29818726, 23.63070107], [68.29818726, 23.63042259], [68.29736328, 23.63042259], [68.29736328, 23.6301403], [68.29651642, 23.6301403], [68.29651642, 23.62986183], [68.29541779, 23.62986183], [68.29541779, 23.62958336], [68.29430389, 23.62958336], [68.29430389, 23.62930489], [68.29347229, 23.62930489], [68.29347229, 23.62902832], [68.2923584, 23.62902832], [68.2923584, 23.62874985], [68.28819275, 23.62874985], [68.28819275, 23.62902832], [68.28736115, 23.62902832], [68.28736115, 23.62930489], [68.28652954, 23.62930489], [68.28652954, 23.62958336], [68.2859726, 23.62958336], [68.2859726, 23.62986183], [68.28514099, 23.62986183], [68.28514099, 23.6301403], [68.28457642, 23.6301403], [68.28457642, 23.63042259], [68.2840271, 23.63042259], [68.2840271, 23.63070107], [68.28347015, 23.63070107], [68.28347015, 23.63097954], [68.28318787, 23.63097954], [68.28318787, 23.63125038], [68.28263855, 23.63125038], [68.28263855, 23.63153267], [68.2820816, 23.63153267], [68.2820816, 23.63181114], [68.28152466, 23.63180542], [68.28152466, 23.63208389], [68.28013611, 23.63208389], [68.28015137, 23.63236046], [68.27958679, 23.63236046], [68.27958679, 23.63264275], [68.27709198, 23.63264275], [68.27709198, 23.63236046], [68.27680206, 23.63236046], [68.27680206, 23.63208008], [68.2765274, 23.63208389], [68.2765274, 23.63180542], [68.27625275, 23.63181114], [68.27625275, 23.63153267], [68.27597046, 23.63153267], [68.27597046, 23.63070107], [68.2756958, 23.63070107], [68.2756958, 23.62929916], [68.27597046, 23.62930489], [68.27597046, 23.62874985], [68.2756958, 23.62874985], [68.2756958, 23.62818909], [68.27541351, 23.62819481], [68.27541351, 23.62791634], [68.27513885, 23.62791824], [68.27513885, 23.62763977], [68.27485657, 23.62763977], [68.27485657, 23.62735939], [68.27430725, 23.6273613], [68.27430725, 23.62708282], [68.27402496, 23.62708282], [68.27402496, 23.62680626], [68.27375031, 23.62680817], [68.27375031, 23.62652969], [68.27263641, 23.62652969], [68.27263641, 23.62625122], [68.2720871, 23.62625122], [68.2720871, 23.62597084], [68.27153015, 23.62597275], [68.27153015, 23.62569427], [68.27124786, 23.62569427], [68.27124786, 23.62541771], [68.27069092, 23.62541962], [68.27069092, 23.62514114], [68.2701416, 23.62514114], [68.2701416, 23.62486076], [68.26985931, 23.62486076], [68.26985931, 23.62430954], [68.26957703, 23.62430954], [68.26957703, 23.62403107], [68.26930237, 23.62403107], [68.26930237, 23.62347031], [68.26902771, 23.62347221], [68.26902771, 23.62291527], [68.26875305, 23.62292099], [68.26875305, 23.62236023], [68.26847076, 23.62236023], [68.26847076, 23.62181091], [68.26821136, 23.62181091], [68.26821136, 23.62096977], [68.26791382, 23.62097168], [68.26791382, 23.62069321], [68.26763916, 23.62070084], [68.26763916, 23.62042046], [68.26735687, 23.62042046], [68.26735687, 23.62014008], [68.26708221, 23.62014008], [68.26708221, 23.6198597], [68.2673645, 23.6198616], [68.2673645, 23.61958122], [68.26791382, 23.61958122], [68.26791382, 23.61930466], [68.26819611, 23.61930466], [68.26819611, 23.61819458], [68.26847076, 23.61819458], [68.26847076, 23.61680603], [68.26875305, 23.61681175], [68.26875305, 23.61514091], [68.26902771, 23.61514091], [68.26902771, 23.61403084], [68.26930237, 23.61403084], [68.26930237, 23.61292076], [68.26957703, 23.61292076], [68.26957703, 23.60984993], [68.26930237, 23.60986137], [68.26930237, 23.60874939], [68.26902771, 23.60874939], [68.26902771, 23.60764122], [68.26875305, 23.60764122], [68.26875305, 23.60708046], [68.26847076, 23.60708237], [68.26847076, 23.6068058], [68.26821136, 23.60680962], [68.26821136, 23.60653114], [68.26763916, 23.60653114], [68.26763916, 23.60625076], [68.26735687, 23.60625076], [68.26735687, 23.60597038], [68.26708221, 23.60597229], [68.26708221, 23.60569382], [68.26680756, 23.60569382], [68.26680756, 23.60541725], [68.2665329, 23.60542107], [68.2665329, 23.60514259], [68.26625061, 23.60514259], [68.26625061, 23.60486031], [68.26597595, 23.60486031], [68.26597595, 23.60458183], [68.26569366, 23.60458374], [68.26569366, 23.60430527], [68.26541901, 23.6043129], [68.26541901, 23.60375023], [68.26513672, 23.60375023], [68.26513672, 23.60347176], [68.26486206, 23.60347176], [68.26486206, 23.60319519], [68.26457977, 23.60320282], [68.26457977, 23.60292244], [68.26431274, 23.60292244], [68.26431274, 23.60263824], [68.26403046, 23.60263824], [68.26403046, 23.60235977], [68.25986481, 23.60236168], [68.25986481, 23.60208321], [68.25902557, 23.60208321], [68.25902557, 23.60180473], [68.25819397, 23.60180473], [68.25819397, 23.60152817], [68.25736237, 23.60152817], [68.25736237, 23.60124969], [68.25653076, 23.60124969], [68.25653076, 23.60069084], [68.25624847, 23.60069466], [68.25624847, 23.60041618], [68.25569153, 23.60041618], [68.25569153, 23.60069466], [68.2545929, 23.60069084], [68.2545929, 23.60098076], [68.25402832, 23.60098076], [68.25402832, 23.60124969], [68.25347137, 23.60124969], [68.25347137, 23.60152817], [68.25291443, 23.60152817], [68.25291443, 23.60180473], [68.25235748, 23.60180473], [68.25235748, 23.60208321], [68.25180817, 23.60208321], [68.25180817, 23.60236168], [68.25125122, 23.60235977], [68.25125122, 23.60263824], [68.25068665, 23.60263824], [68.25068665, 23.60292244], [68.24958038, 23.60292244], [68.24958038, 23.60320282], [68.24847412, 23.60319519], [68.24847412, 23.60347176], [68.24736023, 23.60347176], [68.24736023, 23.60375023], [68.24652863, 23.60375023], [68.24652863, 23.60404015], [68.2454071, 23.60404015], [68.2454071, 23.6043129], [68.24514008, 23.6043129], [68.24514008, 23.60514259], [68.24485779, 23.60514259], [68.24485779, 23.60542107], [68.24458313, 23.60541725], [68.24458313, 23.60569382], [68.24485779, 23.60569382], [68.24485779, 23.60597229], [68.24514008, 23.60597038], [68.24514008, 23.60625076], [68.2454071, 23.60625076], [68.2454071, 23.60653114], [68.24375153, 23.60653114], [68.24375153, 23.60625076], [68.24208069, 23.60625076], [68.24208069, 23.60597038], [68.24263763, 23.60597229], [68.24263763, 23.60569382], [68.24319458, 23.60569382], [68.24319458, 23.60541725], [68.24263763, 23.60542107], [68.24263763, 23.60514259], [68.24180603, 23.60514259], [68.24180603, 23.60458183], [68.24208069, 23.60458374], [68.24208069, 23.60430527], [68.24236298, 23.6043129], [68.24236298, 23.60375023], [68.24208069, 23.60375023], [68.24208069, 23.60347176], [68.24180603, 23.60347176], [68.24180603, 23.60319519], [68.24153137, 23.60320282], [68.24153137, 23.60292244], [68.24124908, 23.60292244], [68.24124908, 23.60263824], [68.24098206, 23.60263824], [68.24098206, 23.60235977], [68.24069214, 23.60236168], [68.24069214, 23.60208321], [68.24041748, 23.60208321], [68.24041748, 23.60180473], [68.24013519, 23.60180473], [68.24013519, 23.60124969], [68.23986053, 23.60124969], [68.23986053, 23.60098076], [68.23958588, 23.60098076], [68.23958588, 23.60069084], [68.23930359, 23.60069466], [68.23930359, 23.60041618], [68.23958588, 23.60041809], [68.23958588, 23.60013962], [68.23986053, 23.60013962], [68.23986053, 23.59986115], [68.24041748, 23.59986115], [68.24041748, 23.59958076], [68.24069214, 23.59958267], [68.24069214, 23.59930611], [68.24124908, 23.59930992], [68.24124908, 23.59902954], [68.24153137, 23.59902954], [68.24153137, 23.59875107], [68.24180603, 23.59875107], [68.24180603, 23.59847069], [68.24236298, 23.5984726], [68.24236298, 23.59819412], [68.24263763, 23.59819412], [68.24263763, 23.59791756], [68.24319458, 23.59791756], [68.24319458, 23.59763908], [68.24346924, 23.59764099], [68.24346924, 23.59736061], [68.24401855, 23.59736061], [68.24401855, 23.59708023], [68.24430847, 23.59708595], [68.24430847, 23.59680367], [68.24458313, 23.59680939], [68.24458313, 23.59653091], [68.24514008, 23.59653091], [68.24514008, 23.59625053], [68.2454071, 23.59625053], [68.2454071, 23.59597015], [68.24597168, 23.59597206], [68.24597168, 23.5956955], [68.24624634, 23.5956955], [68.24624634, 23.59541512], [68.24678802, 23.59542084], [68.24678802, 23.59514046], [68.24707794, 23.59514046], [68.24707794, 23.59485054], [68.24764252, 23.59486389], [68.24764252, 23.59458542], [68.24791718, 23.59458542], [68.24791718, 23.59430313], [68.24846649, 23.59431076], [68.24846649, 23.59403038], [68.24874878, 23.59403038], [68.24874878, 23.59375], [68.25096893, 23.59375], [68.25096893, 23.59403038], [68.25125122, 23.59403038], [68.25125122, 23.59431076], [68.25152588, 23.59430313], [68.25152588, 23.59486389], [68.25180817, 23.59485054], [68.25180817, 23.59514046], [68.25208282, 23.59514046], [68.25208282, 23.59542084], [68.25235748, 23.59541512], [68.25235748, 23.5956955], [68.25263977, 23.5956955], [68.25263977, 23.59597206], [68.25319672, 23.59597206], [68.25319672, 23.59625053], [68.25347137, 23.59625053], [68.25347137, 23.59653091], [68.25374603, 23.59653091], [68.25374603, 23.59680939], [68.25541687, 23.59680939], [68.25541687, 23.59625053], [68.25569153, 23.59625053], [68.25569153, 23.59568977], [68.25624847, 23.5956955], [68.25624847, 23.59458542], [68.25569153, 23.59458542], [68.25569153, 23.59402847], [68.25541687, 23.59403038], [68.25541687, 23.59375], [68.25514221, 23.59375], [68.25514221, 23.59346962], [68.25485992, 23.59347153], [68.25485992, 23.59319305], [68.2545929, 23.59320068], [68.2545929, 23.5929203], [68.25430298, 23.5929203], [68.25430298, 23.59263992], [68.25402832, 23.59263992], [68.25402832, 23.59235954], [68.25319672, 23.59236145], [68.25319672, 23.59208107], [68.25235748, 23.59208107], [68.25235748, 23.59180641], [68.25180817, 23.59181023], [68.25180817, 23.59153175], [68.25125122, 23.59153175], [68.25125122, 23.59124947], [68.25068665, 23.59124947], [68.25068665, 23.59096909], [68.25013733, 23.5909729], [68.25013733, 23.59069443], [68.24736023, 23.59069443], [68.24736023, 23.59041595], [68.24485779, 23.59041595], [68.24485779, 23.59069443], [68.24458313, 23.59069443], [68.24458313, 23.5909729], [68.24430847, 23.59096909], [68.24430847, 23.59153175], [68.24458313, 23.59152794], [68.24458313, 23.59208107], [68.24430847, 23.59208107], [68.24430847, 23.59236145], [68.24401855, 23.59235954], [68.24401855, 23.5929203], [68.24375153, 23.5929203], [68.24375153, 23.59320068], [68.24346924, 23.59319305], [68.24346924, 23.59347153], [68.24318695, 23.59346962], [68.24318695, 23.59375], [68.24236298, 23.59375], [68.24236298, 23.59346962], [68.24180603, 23.59347153], [68.24180603, 23.59319305], [68.24098206, 23.59320068], [68.24098206, 23.5929203], [68.23986053, 23.5929203], [68.23986053, 23.59263992], [68.23902893, 23.59263992], [68.23902893, 23.59235954], [68.23847198, 23.59235954], [68.23847198, 23.59375], [68.23819733, 23.59375], [68.23819733, 23.59431076], [68.23791504, 23.59430313], [68.23791504, 23.59486389], [68.23819733, 23.59485054], [68.23819733, 23.59542084], [68.23764038, 23.59541512], [68.23764038, 23.5956955], [68.23680878, 23.5956955], [68.23680878, 23.59319305], [68.23652649, 23.59320068], [68.23652649, 23.59124947], [68.23625183, 23.59124947], [68.23625183, 23.59069061], [68.23542023, 23.59069443], [68.23542023, 23.59041595], [68.23430634, 23.59041595], [68.23430634, 23.59069443], [68.23401642, 23.59069061], [68.23401642, 23.59124947], [68.2334671, 23.59124947], [68.2334671, 23.59096909], [68.23319244, 23.5909729], [68.23319244, 23.59013939], [68.2334671, 23.59013939], [68.2334671, 23.58791924], [68.23319244, 23.58791924], [68.23319244, 23.58707809], [68.23291779, 23.58707809], [68.23291779, 23.58736038], [68.23264313, 23.58736038], [68.23264313, 23.58764076], [68.23236084, 23.58764076], [68.23236084, 23.58791924], [68.23180389, 23.58791733], [68.23180389, 23.58819389], [68.23152924, 23.58819389], [68.23152924, 23.58847237], [68.23097229, 23.58847046], [68.23097229, 23.58875084], [68.23069763, 23.58875084], [68.23069763, 23.58902931], [68.22735596, 23.58902931], [68.22735596, 23.5893116], [68.2270813, 23.58930588], [68.2270813, 23.58958244], [68.2251358, 23.58958244], [68.2251358, 23.58930588], [68.22458649, 23.5893116], [68.22458649, 23.58902931], [68.22290802, 23.58902931], [68.22290802, 23.5893116], [68.2223587, 23.58930588], [68.2223587, 23.58958244], [68.22180176, 23.58958054], [68.22180176, 23.58986092], [68.22125244, 23.58986092], [68.22125244, 23.59013939], [68.22097015, 23.59013939], [68.22097015, 23.59042168], [68.2206955, 23.59041595], [68.2206955, 23.59069443], [68.22041321, 23.59069443], [68.22041321, 23.5909729], [68.22013855, 23.59096909], [68.22013855, 23.59124947], [68.21984863, 23.59124947], [68.21984863, 23.59181023], [68.22013855, 23.59180641], [68.22013855, 23.59236145], [68.22041321, 23.59235954], [68.22041321, 23.59263992], [68.22070313, 23.59263992], [68.22070313, 23.59320068], [68.22097015, 23.59319305], [68.22097015, 23.59347153], [68.22125244, 23.59346962], [68.22125244, 23.59375], [68.2215271, 23.59375], [68.2215271, 23.59431076], [68.22180176, 23.59430313], [68.22180176, 23.59486389], [68.22207642, 23.59485054], [68.22207642, 23.59542084], [68.2223587, 23.59541512], [68.2223587, 23.5956955], [68.22264099, 23.5956955], [68.22264099, 23.59597206], [68.22290802, 23.59597015], [68.22290802, 23.59625053], [68.2234726, 23.59625053], [68.2234726, 23.59653091], [68.22402954, 23.59653091], [68.22402954, 23.59680939], [68.2243042, 23.59680367], [68.2243042, 23.59708595], [68.22486115, 23.59708023], [68.22486115, 23.59736061], [68.2251358, 23.59736061], [68.2251358, 23.59764099], [68.22541809, 23.59763908], [68.22541809, 23.59791756], [68.22569275, 23.59791756], [68.22569275, 23.5984726], [68.22541809, 23.59847069], [68.22541809, 23.59875107], [68.22486115, 23.59875107], [68.22486115, 23.59902954], [68.22458649, 23.59902954], [68.22458649, 23.59930992], [68.2243042, 23.59930611], [68.2243042, 23.59958267], [68.22402954, 23.59958076], [68.22402954, 23.59986115], [68.2234726, 23.59986115], [68.2234726, 23.60013962], [68.22374725, 23.60013962], [68.22374725, 23.60041809], [68.22402954, 23.60041809], [68.22402954, 23.60098076], [68.22429657, 23.60098076], [68.22429657, 23.60152817], [68.22402954, 23.60152817], [68.22402954, 23.60208321], [68.22374725, 23.60207748], [68.22374725, 23.60375023], [68.22402954, 23.60375023], [68.22402954, 23.60404015], [68.22458649, 23.60404015], [68.22458649, 23.6043129], [68.22486115, 23.60430527], [68.22486115, 23.60458374], [68.22624969, 23.60458374], [68.22624969, 23.60430527], [68.22651672, 23.6043129], [68.22651672, 23.60404015], [68.22763824, 23.60404015], [68.22763824, 23.6043129], [68.2279129, 23.60430527], [68.2279129, 23.60458374], [68.22763824, 23.60458183], [68.22763824, 23.60514259], [68.22736359, 23.60513878], [68.22736359, 23.60569382], [68.2270813, 23.60569382], [68.2270813, 23.60597229], [68.22680664, 23.60597038], [68.22680664, 23.60625076], [68.22624969, 23.60625076], [68.22624969, 23.60653114], [68.22598267, 23.60653114], [68.22598267, 23.60680962], [68.22486115, 23.60680962], [68.22486115, 23.60653114], [68.2223587, 23.60653114], [68.2223587, 23.60597038], [68.22264099, 23.60597229], [68.22264099, 23.60541725], [68.2223587, 23.60542107], [68.2223587, 23.60514259], [68.22207642, 23.60514259], [68.22207642, 23.60458183], [68.22180939, 23.60458374], [68.22180176, 23.60430527], [68.2215271, 23.6043129], [68.2215271, 23.60404015], [68.22097015, 23.60404015], [68.22097015, 23.60375023], [68.2195816, 23.60375023], [68.2195816, 23.6043129], [68.21930695, 23.60430527], [68.21930695, 23.60458374], [68.21901703, 23.60458183], [68.21901703, 23.60514259], [68.21875, 23.60514259], [68.21875, 23.60542107], [68.21819305, 23.60541725], [68.21819305, 23.60569382], [68.2179184, 23.60569382], [68.2179184, 23.60597229], [68.21736145, 23.60597038], [68.21736145, 23.60625076], [68.21652985, 23.60625076], [68.21652985, 23.60320282], [68.21624756, 23.60320282], [68.21624756, 23.60235977], [68.2159729, 23.60236168], [68.2159729, 23.60180473], [68.21569824, 23.60180473], [68.21569824, 23.60152817], [68.21541595, 23.60152817], [68.21541595, 23.60124969], [68.2151413, 23.60124969], [68.2151413, 23.60098076], [68.21457672, 23.60098076], [68.21457672, 23.60069084], [68.21404266, 23.60069084], [68.21404266, 23.60098076], [68.2123642, 23.60097313], [68.2123642, 23.60236168], [68.21152496, 23.60236168], [68.21152496, 23.60208321], [68.21125031, 23.60208321], [68.21125031, 23.60180473], [68.21069336, 23.60180473], [68.21069336, 23.60152817], [68.21013641, 23.60152817], [68.21013641, 23.60124969], [68.20929718, 23.60124969], [68.20929718, 23.60098076], [68.20874786, 23.60098076], [68.20874786, 23.60041809], [68.20903015, 23.60041809], [68.20903015, 23.59986115], [68.20790863, 23.59986115], [68.20790863, 23.60041809], [68.2076416, 23.60041809], [68.2076416, 23.60124969], [68.20735931, 23.60124969], [68.20735931, 23.60180473], [68.20708466, 23.60180473], [68.20708466, 23.60208321], [68.20541382, 23.60208321], [68.20541382, 23.60097313], [68.20569611, 23.60098076], [68.20569611, 23.59958076], [68.20541382, 23.59958267], [68.20541382, 23.59902763], [68.20569611, 23.59902954], [68.20569611, 23.59819031], [68.20541382, 23.59819412], [68.20541382, 23.59763908], [68.20513916, 23.59764099], [68.20513916, 23.59625053], [68.2048645, 23.59625053], [68.2048645, 23.59597206], [68.20458221, 23.59597206], [68.20458221, 23.5956955], [68.20430756, 23.5956955], [68.20430756, 23.59541512], [68.2040329, 23.59542084], [68.2040329, 23.59514046], [68.20375061, 23.59514046], [68.20375061, 23.59485054], [68.20347595, 23.59486389], [68.20347595, 23.59458542], [68.20236206, 23.59458542], [68.20236206, 23.59486389], [68.20181274, 23.59485054], [68.20181274, 23.59514046], [68.20153046, 23.59514046], [68.20153046, 23.59542084], [68.20097351, 23.59541512], [68.20097351, 23.5956955], [68.20069122, 23.5956955], [68.20069122, 23.59597206], [68.20014191, 23.59597015], [68.20014191, 23.59625053], [68.19985962, 23.59625053], [68.19985962, 23.59653091], [68.19902802, 23.59653091], [68.19902802, 23.59625053], [68.19847107, 23.59625053], [68.19847107, 23.59653091], [68.19790649, 23.59653091], [68.19790649, 23.59680939], [68.19763947, 23.59680367], [68.19763947, 23.59708595], [68.19708252, 23.59708595], [68.19708252, 23.59791756], [68.19735718, 23.59790993], [68.19735718, 23.59902954], [68.19708252, 23.59902954], [68.19708252, 23.59930992], [68.19680786, 23.59930611], [68.19680786, 23.59958267], [68.1965332, 23.59958076], [68.1965332, 23.60041809], [68.19625092, 23.60041809], [68.19625092, 23.60152817], [68.19596863, 23.60152817], [68.19596863, 23.60180473], [68.19569397, 23.60180473], [68.19569397, 23.60236168], [68.19541931, 23.60235977], [68.19541931, 23.60375023], [68.19513702, 23.60375023], [68.19513702, 23.60404015], [68.19486237, 23.60404015], [68.19486237, 23.6043129], [68.19430542, 23.60430527], [68.19431305, 23.60625076], [68.19403076, 23.60625076], [68.19403076, 23.60680962], [68.19374847, 23.6068058], [68.19374847, 23.60708237], [68.19346619, 23.60708046], [68.19346619, 23.60736084], [68.19319153, 23.60736084], [68.19319153, 23.60764122], [68.19264221, 23.60764122], [68.19264221, 23.60736084], [68.19208527, 23.60736084], [68.19208527, 23.60708237], [68.19124603, 23.60708046], [68.19124603, 23.60736084], [68.19097137, 23.60736084], [68.19097137, 23.60764122], [68.19069672, 23.60764122], [68.19069672, 23.60791969], [68.19041443, 23.60791588], [68.19041443, 23.60819244], [68.19013977, 23.60819244], [68.19013977, 23.60847473], [68.18985748, 23.60847473], [68.18987274, 23.60874939], [68.18958282, 23.60874939], [68.18958282, 23.60902977], [68.18930817, 23.60902977], [68.18930817, 23.60931015], [68.18902588, 23.60930634], [68.18902588, 23.60986137], [68.18875122, 23.60984993], [68.18875122, 23.61042023], [68.18846893, 23.61042023], [68.18846893, 23.61013985], [68.18818665, 23.61013985], [68.18818665, 23.61042023], [68.18791962, 23.61041451], [68.18791962, 23.61069679], [68.18763733, 23.61069679], [68.18763733, 23.61097145], [68.18736267, 23.61097145], [68.18736267, 23.61208344], [68.18708038, 23.61207962], [68.18708038, 23.61486053], [68.1867981, 23.61486053], [68.1867981, 23.61598015], [68.18653107, 23.61598015], [68.18653107, 23.61874962], [68.18624878, 23.61874962], [68.18624878, 23.62097168], [68.18653107, 23.62096977], [68.18653107, 23.62292099], [68.18624878, 23.62292099], [68.18624878, 23.62430954], [68.18653107, 23.62430954], [68.18653107, 23.62486076], [68.1867981, 23.62486076], [68.1867981, 23.62514114], [68.18708038, 23.62513924], [68.18708038, 23.62569427], [68.18736267, 23.62569427], [68.18736267, 23.62597275], [68.18763733, 23.62597084], [68.18763733, 23.62652969], [68.18791962, 23.62652779], [68.18791962, 23.62708282], [68.18819427, 23.62708282], [68.18819427, 23.62847137], [68.18846893, 23.62846756], [68.18846893, 23.62874985], [68.18875122, 23.62874985], [68.18875122, 23.62902832], [68.18902588, 23.62902832], [68.18902588, 23.62958336], [68.18930817, 23.62957764], [68.18930817, 23.6301403], [68.18958282, 23.6301403], [68.18958282, 23.63042259], [68.18987274, 23.63042259], [68.18987274, 23.63070107], [68.19013977, 23.63070107], [68.19013977, 23.63125038], [68.1904068, 23.63125038], [68.1904068, 23.63153267], [68.19069672, 23.63153267], [68.19069672, 23.63181114], [68.19097137, 23.63180542], [68.19097137, 23.63208389], [68.19124603, 23.63208008], [68.19124603, 23.63236046], [68.19152832, 23.63236046], [68.19152832, 23.63264275], [68.19180298, 23.63263893], [68.19180298, 23.63319206], [68.19208527, 23.63319206], [68.19208527, 23.63347244], [68.19235992, 23.63347054], [68.19235992, 23.63375282], [68.19264221, 23.63375282], [68.19264221, 23.63402748], [68.19293213, 23.63401985], [68.19293213, 23.63430977], [68.19319153, 23.63430405], [68.19319153, 23.63458252], [68.19291687, 23.63458252], [68.19291687, 23.63513947], [68.19346619, 23.63513947], [68.19346619, 23.63541985], [68.19403076, 23.63541412], [68.19403076, 23.63569641], [68.19430542, 23.63569641], [68.19430542, 23.63624954], [68.19458008, 23.63624954], [68.19458008, 23.6368103], [68.19486237, 23.63680649], [68.19486237, 23.63708305], [68.19513702, 23.63708305], [68.19513702, 23.63736153], [68.19567871, 23.63735962], [68.19567871, 23.63764], [68.19596863, 23.63763618], [68.19596863, 23.6384716], [68.19625092, 23.6384697], [68.19625092, 23.63875008], [68.1965332, 23.63875008], [68.1965332, 23.63903046], [68.19680786, 23.63903046], [68.19680786, 23.63931084], [68.19708252, 23.63930511], [68.19708252, 23.63958359], [68.19736481, 23.63958359], [68.19736481, 23.63986206], [68.19819641, 23.63986015], [68.19819641, 23.64014816], [68.19875336, 23.64013863], [68.19875336, 23.64069366], [68.19902802, 23.64068985], [68.19902802, 23.64152908], [68.19959259, 23.64152908], [68.19959259, 23.64181137], [68.19985962, 23.64180565], [68.19985962, 23.64208412], [68.20041656, 23.6420784], [68.20041656, 23.64236069], [68.20069122, 23.64236069], [68.20069122, 23.64291954], [68.20097351, 23.64291763], [68.20097351, 23.6431942], [68.20124817, 23.64318848], [68.20124817, 23.64374924], [68.20153046, 23.64374924], [68.20153046, 23.6443119], [68.20124817, 23.6443119], [68.20124817, 23.64486122], [68.20153046, 23.64486122], [68.20153046, 23.64513969], [68.20181274, 23.64513969], [68.20181274, 23.64542007], [68.20236206, 23.64541626], [68.20236206, 23.64569473], [68.20263672, 23.64569473], [68.20263672, 23.6459713], [68.20318604, 23.64596176], [68.20318604, 23.64653015], [68.20347595, 23.64652824], [68.20347595, 23.64680481], [68.20375061, 23.64680481], [68.20375061, 23.64708138], [68.20430756, 23.64708138], [68.20430756, 23.64736366], [68.20458221, 23.64735985], [68.20458221, 23.64764023], [68.20625305, 23.64764023], [68.20625305, 23.64735985], [68.2076416, 23.64736366], [68.2076416, 23.64680481], [68.20791626, 23.64680481], [68.20791626, 23.6459713], [68.20735931, 23.6459713], [68.20735931, 23.64569473], [68.20708466, 23.64569473], [68.20708466, 23.64541626], [68.20680237, 23.64542007], [68.20680237, 23.64513969], [68.20652771, 23.64513969], [68.20652771, 23.64486122], [68.20569611, 23.64486122], [68.20569611, 23.64458275], [68.2048645, 23.64458275], [68.2048645, 23.64430618], [68.20513916, 23.6443119], [68.20513916, 23.64402962], [68.20540619, 23.64402962], [68.20540619, 23.64374924], [68.20597076, 23.64374924], [68.20597076, 23.64347076], [68.20625305, 23.64347267], [68.20625305, 23.6431942], [68.20652771, 23.6431942], [68.20652771, 23.64291763], [68.20680237, 23.64291954], [68.20680237, 23.64236069], [68.20707703, 23.64236069], [68.20707703, 23.6420784], [68.20735931, 23.64208412], [68.20735931, 23.64180565], [68.20791626, 23.64180565], [68.20791626, 23.64208412], [68.20819092, 23.6420784], [68.20819092, 23.64263916], [68.20847321, 23.64263916], [68.20847321, 23.64291954], [68.20903015, 23.64291763], [68.20903015, 23.6431942], [68.2095871, 23.6431942], [68.2095871, 23.64347267], [68.21152496, 23.64347267], [68.21152496, 23.64291573], [68.21125031, 23.64291954], [68.21125031, 23.64236069], [68.21096802, 23.64236069], [68.21096802, 23.64181137], [68.2106781, 23.64181137], [68.2106781, 23.64125061], [68.2104187, 23.64125061], [68.2104187, 23.64068985], [68.21013641, 23.64069366], [68.21013641, 23.6404171], [68.21208191, 23.6404171], [68.21208191, 23.64069366], [68.2123642, 23.64069366], [68.2123642, 23.64097214], [68.21263885, 23.64097023], [68.21263885, 23.64152908], [68.21290588, 23.64152908], [68.21290588, 23.64181137], [68.2131958, 23.64180565], [68.2131958, 23.64208412], [68.21347046, 23.6420784], [68.21347046, 23.64263916], [68.21375275, 23.64263916], [68.21375275, 23.64291954], [68.2140274, 23.64291763], [68.2140274, 23.6431942], [68.21430206, 23.6431942], [68.21430206, 23.64291763], [68.21624756, 23.64291763], [68.21624756, 23.6431942], [68.21847534, 23.6431942], [68.21847534, 23.64347267], [68.21930695, 23.64347076], [68.21930695, 23.64374924], [68.21901703, 23.64374924], [68.21901703, 23.6443119], [68.21875, 23.64430618], [68.21875, 23.64458275], [68.21930695, 23.64458275], [68.21930695, 23.64486122], [68.2195816, 23.64486122], [68.2195816, 23.64513969], [68.21984863, 23.64513969], [68.21984863, 23.64542007], [68.22013855, 23.64541626], [68.22013855, 23.64569473], [68.22041321, 23.64569473], [68.22041321, 23.6459713], [68.22097015, 23.64596176], [68.22097015, 23.64624977], [68.2215271, 23.64624977], [68.2215271, 23.64653015], [68.22180176, 23.64652824], [68.22180176, 23.64680481], [68.2223587, 23.64680481], [68.2223587, 23.64708138], [68.22319794, 23.64708138], [68.22319794, 23.64680481], [68.2234726, 23.64680481], [68.2234726, 23.64624977], [68.22374725, 23.64624977], [68.22374725, 23.64596176], [68.22402954, 23.6459713], [68.22402954, 23.64541626], [68.22429657, 23.64542007], [68.22429657, 23.64486122], [68.22458649, 23.64486122], [68.22458649, 23.6443119], [68.2251358, 23.6443119], [68.2251358, 23.64402962], [68.22541809, 23.64402962], [68.22541809, 23.64374924], [68.22598267, 23.64374924], [68.22598267, 23.64347076], [68.22624969, 23.64347267], [68.22624969, 23.6431942], [68.22652435, 23.6431942], [68.22652435, 23.64291763], [68.2270813, 23.64291954], [68.2270813, 23.64263916], [68.22735596, 23.64263916], [68.22735596, 23.64236069], [68.2279129, 23.64236069], [68.2279129, 23.6420784], [68.22875214, 23.64208412], [68.22875214, 23.64180565], [68.22930908, 23.64181137], [68.22930908, 23.64152908], [68.23374939, 23.64152908], [68.23374939, 23.64125061], [68.23625183, 23.64125061], [68.23625183, 23.64152908], [68.23819733, 23.64152908], [68.23819733, 23.64181137], [68.23986053, 23.64180565], [68.23986053, 23.64208412], [68.24069214, 23.6420784], [68.24069214, 23.64236069], [68.24153137, 23.64236069], [68.24153137, 23.64263916], [68.24346924, 23.64263916], [68.24346924, 23.64236069], [68.24375153, 23.64236069], [68.24375153, 23.6420784], [68.24430847, 23.64208412], [68.24430847, 23.64180565], [68.24514008, 23.64181137], [68.24514008, 23.64291954], [68.24569702, 23.64291763], [68.24569702, 23.6431942], [68.24624634, 23.6431942], [68.24624634, 23.64347267], [68.24707794, 23.64347076], [68.24707794, 23.64374924], [68.24764252, 23.64374924], [68.24764252, 23.64402962], [68.24819183, 23.64402962], [68.24819183, 23.6443119], [68.25069427, 23.64430618], [68.25069427, 23.64458275], [68.25235748, 23.64458275], [68.25235748, 23.64486122], [68.25514221, 23.64486122], [68.25514221, 23.64513969], [68.25595856, 23.64513969], [68.25595856, 23.64458275], [68.25624847, 23.64458275], [68.25624847, 23.64402771], [68.25653076, 23.64402962], [68.25653076, 23.64347076], [68.25680542, 23.64347267], [68.25680542, 23.64263916], [68.25708008, 23.64263916], [68.25708008, 23.6420784], [68.25736237, 23.64208412], [68.25736237, 23.64152718], [68.25763702, 23.64152908], [68.25763702, 23.64125061], [68.25791931, 23.64125061], [68.25791931, 23.64097023], [68.25819397, 23.64097214], [68.25819397, 23.6404171], [68.25846863, 23.64042091], [68.25846863, 23.64014816], [68.25875092, 23.64014816], [68.25875092, 23.63986015], [68.26013947, 23.63986015], [68.26013947, 23.64014816], [68.25985718, 23.64014816], [68.25985718, 23.64042091], [68.25958252, 23.6404171], [68.25958252, 23.64069366], [68.25930786, 23.64069366], [68.25930786, 23.64097214], [68.25901794, 23.64097023], [68.25901794, 23.64125061], [68.25875092, 23.64125061], [68.25875092, 23.64152908], [68.25846863, 23.64152908], [68.25846863, 23.64181137], [68.25818634, 23.64181137], [68.25818634, 23.64486122], [68.25985718, 23.64486122], [68.25985718, 23.64513969], [68.26152802, 23.64513969], [68.26152802, 23.64542007], [68.26486206, 23.64541626], [68.26486206, 23.64569473], [68.26597595, 23.64569473], [68.26597595, 23.6459713], [68.26680756, 23.64596176], [68.26680756, 23.64624977], [68.27069092, 23.64624977], [68.27069092, 23.64653015], [68.27180481, 23.64652824], [68.27180481, 23.64680481], [68.2729187, 23.64680481], [68.2729187, 23.64708138], [68.27375031, 23.64708138], [68.27375031, 23.64736366], [68.27485657, 23.64735985], [68.27485657, 23.64764023], [68.2756958, 23.64764023], [68.2756958, 23.64792061], [68.2765274, 23.64792061], [68.2765274, 23.64820099], [68.2776413, 23.64819336], [68.2776413, 23.64847183], [68.2784729, 23.64846992], [68.2784729, 23.64875031], [68.27986145, 23.64875031], [68.27986145, 23.64902687], [68.28430176, 23.64902687], [68.28430939, 23.64875031], [68.28569794, 23.64875031], [68.28569794, 23.64846992], [68.28736115, 23.64847183], [68.28736115, 23.64819336], [68.28848267, 23.64820099], [68.28848267, 23.64792061], [68.2893219, 23.64792061], [68.2893219, 23.64764023], [68.2904129, 23.64764023], [68.2904129, 23.64735985], [68.29957581, 23.64735985], [68.29957581, 23.64764023], [68.30208588, 23.64764023], [68.30208588, 23.64792061], [68.30432129, 23.64792061], [68.30432129, 23.64820099], [68.30847168, 23.64819336], [68.30847168, 23.64847183], [68.30902863, 23.64846992], [68.30902863, 23.64875031], [68.30958557, 23.64875031], [68.30958557, 23.64902687], [68.31012726, 23.64902115], [68.31012726, 23.64931107], [68.31041718, 23.64930344], [68.31041718, 23.64958572], [68.31069183, 23.64958], [68.31069183, 23.64986038], [68.31096649, 23.64986038], [68.31096649, 23.65014076], [68.31181335, 23.65014076], [68.31181335, 23.65042114], [68.31153107, 23.65041733], [68.31153107, 23.65097237], [68.31124878, 23.65097046], [68.31124878, 23.65153122], [68.31096649, 23.65153122], [68.31096649, 23.65208817], [68.31041718, 23.65208817], [68.31041718, 23.65125084], [68.31012726, 23.65125084], [68.31012726, 23.65069008], [68.30986023, 23.6506958], [68.30986023, 23.65041733], [68.30930328, 23.65042114], [68.30930328, 23.65014076], [68.30902863, 23.65014076], [68.30902863, 23.64986038], [68.30819702, 23.64986038], [68.30819702, 23.64958], [68.30735779, 23.64958572], [68.30735779, 23.64930344], [68.30652618, 23.64931107], [68.30652618, 23.64902115], [68.30291748, 23.64902687], [68.30291748, 23.64875031], [68.30097198, 23.64875031], [68.30097198, 23.64846992], [68.29930878, 23.64847183], [68.29930878, 23.64819336], [68.28986359, 23.64819336], [68.28986359, 23.64847183], [68.2895813, 23.64846992], [68.2895813, 23.64875031], [68.28930664, 23.64875031], [68.28930664, 23.64902687], [68.28874969, 23.64902115], [68.28874969, 23.64931107], [68.28847504, 23.64930344], [68.28847504, 23.64958572], [68.28819275, 23.64958], [68.28819275, 23.64986038], [68.2876358, 23.64986038], [68.2876358, 23.65014076], [68.28736115, 23.65014076], [68.28736115, 23.65042114], [68.2868042, 23.65041733], [68.2868042, 23.6506958], [68.28652954, 23.6506958], [68.28652954, 23.65097237], [68.28569794, 23.65097046], [68.28569794, 23.65125084], [68.28514099, 23.65125084], [68.28514099, 23.65153122], [68.28430176, 23.65153122], [68.28430176, 23.65180969], [68.28318787, 23.65180969], [68.28318787, 23.65208817], [68.2804184, 23.65208817], [68.2804184, 23.65180969], [68.27986145, 23.65180969], [68.27986145, 23.65153122], [68.27929688, 23.65153122], [68.27929688, 23.65125084], [68.27902985, 23.65125084], [68.27902985, 23.65097046], [68.2784729, 23.65097237], [68.2784729, 23.6506958], [68.27791595, 23.6506958], [68.27791595, 23.65041733], [68.27735901, 23.65042114], [68.27735901, 23.65014076], [68.2765274, 23.65014076], [68.2765274, 23.64986038], [68.27597046, 23.64986038], [68.27597046, 23.64958], [68.27513885, 23.64958572], [68.27513885, 23.64930344], [68.27458191, 23.64931107], [68.27458191, 23.64902115], [68.27319336, 23.64902687], [68.27319336, 23.64875031], [68.2720871, 23.64875031], [68.2720871, 23.64846992], [68.27069092, 23.64847183], [68.27069092, 23.64819336], [68.26875305, 23.64820099], [68.26875305, 23.64792061], [68.2665329, 23.64792061], [68.2665329, 23.64764023], [68.26568604, 23.64764023], [68.26568604, 23.64735985], [68.26457977, 23.64736366], [68.26457977, 23.64708138], [68.26374817, 23.64708138], [68.26374817, 23.64680481], [68.26208496, 23.64680481], [68.26208496, 23.64652824], [68.26013947, 23.64653015], [68.26013947, 23.64624977], [68.25930786, 23.64624977], [68.25930786, 23.64596176], [68.25485992, 23.6459713], [68.25485992, 23.64569473], [68.25180817, 23.64569473], [68.25180817, 23.64541626], [68.24764252, 23.64542007], [68.24764252, 23.64513969], [68.24678802, 23.64513969], [68.24678802, 23.64486122], [68.24597168, 23.64486122], [68.24597168, 23.64458275], [68.24485779, 23.64458275], [68.24485779, 23.64430618], [68.24401855, 23.6443119], [68.24401855, 23.64402962], [68.24208069, 23.64402962], [68.24208069, 23.64374924], [68.24014282, 23.64374924], [68.24014282, 23.64347076], [68.23902893, 23.64347267], [68.23902893, 23.6431942], [68.23764038, 23.6431942], [68.23764038, 23.64291573], [68.23568726, 23.64291954], [68.23568726, 23.64263916], [68.23291779, 23.64263916], [68.23291779, 23.64291954], [68.23124695, 23.64291573], [68.23124695, 23.64347267], [68.23178864, 23.64347076], [68.23178864, 23.64374924], [68.23207855, 23.64374924], [68.23207855, 23.64402962], [68.23264313, 23.64402962], [68.23264313, 23.6443119], [68.23319244, 23.64430618], [68.23319244, 23.64458275], [68.2334671, 23.64458275], [68.2334671, 23.64486122], [68.23707581, 23.64486122], [68.23707581, 23.64542007], [68.23735809, 23.64541626], [68.23735809, 23.6459713], [68.23764038, 23.6459713], [68.23764038, 23.64680481], [68.23791504, 23.64680481], [68.23791504, 23.64736366], [68.23819733, 23.64735985], [68.23819733, 23.64792061], [68.23847198, 23.64792061], [68.23847198, 23.64764023], [68.23874664, 23.64764023], [68.23874664, 23.64735985], [68.23902893, 23.64736366], [68.23902893, 23.64708138], [68.23958588, 23.64708138], [68.23958588, 23.64680481], [68.24153137, 23.64680481], [68.24153137, 23.64708138], [68.24208069, 23.64708138], [68.24208069, 23.64736366], [68.24375153, 23.64735985], [68.24375153, 23.64764023], [68.24485779, 23.64764023], [68.24485779, 23.64735985], [68.24597168, 23.64736366], [68.24597168, 23.64708138], [68.24847412, 23.64708138], [68.24847412, 23.64736366], [68.24986267, 23.64736366], [68.24986267, 23.64708138], [68.25041962, 23.64708138], [68.25041962, 23.64680481], [68.25319672, 23.64680481], [68.25319672, 23.64708138], [68.25430298, 23.64708138], [68.25430298, 23.64736366], [68.25514221, 23.64735985], [68.25514221, 23.64764023], [68.25846863, 23.64764023], [68.25846863, 23.64792061], [68.26069641, 23.64792061], [68.26069641, 23.64820099], [68.26208496, 23.64819336], [68.26208496, 23.64847183], [68.26346588, 23.64846992], [68.26346588, 23.64875031], [68.26319122, 23.64875031], [68.26319122, 23.64902687], [68.26291656, 23.64902687], [68.26291656, 23.64958572], [68.26264191, 23.64958], [68.26264191, 23.64986038], [68.26374817, 23.64986038], [68.26374817, 23.65014076], [68.26597595, 23.65014076], [68.26597595, 23.64986038], [68.26625061, 23.64986038], [68.26625061, 23.64958], [68.26652527, 23.64958572], [68.26652527, 23.64930344], [68.26847076, 23.64930344], [68.26847076, 23.64958572], [68.26957703, 23.64958], [68.26957703, 23.64986038], [68.26930237, 23.64986038], [68.26930237, 23.65042114], [68.26902771, 23.65041733], [68.26902771, 23.65097237], [68.26875305, 23.65097046], [68.26875305, 23.65153122], [68.26902771, 23.65153122], [68.26902771, 23.65180969], [68.26930237, 23.65180969], [68.26930237, 23.65208817], [68.26957703, 23.65208817], [68.26957703, 23.65236092], [68.26985931, 23.65236092], [68.26985931, 23.65263939], [68.2701416, 23.65263939], [68.2701416, 23.65291977], [68.27041626, 23.65291786], [68.27041626, 23.65319443], [68.27069092, 23.65319443], [68.27069092, 23.6534729], [68.27095795, 23.65347099], [68.27095795, 23.65374947], [68.27124786, 23.65374947], [68.27124786, 23.65430832], [68.27153015, 23.65430641], [68.27153015, 23.65486145], [68.27179718, 23.65485954], [68.27179718, 23.65570068], [68.2720871, 23.65570068], [68.2720871, 23.65653038], [68.27236176, 23.65652847], [68.27236176, 23.65708351], [68.27263641, 23.6570816], [68.27263641, 23.65792274], [68.2729187, 23.65791702], [68.2729187, 23.65847015], [68.27319336, 23.65847015], [68.27319336, 23.65875053], [68.27348328, 23.65875053], [68.27348328, 23.65930939], [68.27375031, 23.65930557], [68.27375031, 23.65958214], [68.27402496, 23.65958214], [68.27402496, 23.65986061], [68.27430725, 23.65986061], [68.27430725, 23.66041946], [68.27458191, 23.66041756], [68.27458191, 23.66069221], [68.2748642, 23.66069221], [68.2748642, 23.6609745], [68.27513885, 23.66096115], [68.27513885, 23.66125107], [68.27540588, 23.66125107], [68.27540588, 23.66152954], [68.27708435, 23.66152763], [68.27708435, 23.66236115], [68.27735901, 23.66236115], [68.27735901, 23.66319656], [68.27791595, 23.66319656], [68.27791595, 23.66291428], [68.27902985, 23.66292], [68.27902985, 23.66263962], [68.28015137, 23.66263962], [68.28015137, 23.66403008], [68.2804184, 23.66403008], [68.2804184, 23.66514015], [68.28069305, 23.66514015], [68.28069305, 23.66653061], [68.28097534, 23.6665287], [68.28098297, 23.66736031], [68.28069305, 23.66736031], [68.28069305, 23.66764069], [68.2804184, 23.66764069], [68.2804184, 23.66791916], [68.28069305, 23.66791725], [68.28069305, 23.66847229], [68.28098297, 23.66847038], [68.28098297, 23.66931152], [68.28125, 23.66931152], [68.28125, 23.66986084], [68.28152466, 23.66986084], [68.28152466, 23.67013931], [68.28180695, 23.67012978], [68.28180695, 23.6704216], [68.2820816, 23.67041588], [68.2820816, 23.67069435], [68.28263855, 23.67069435], [68.28263855, 23.67097282], [68.28289795, 23.67097092], [68.28289795, 23.67124939], [68.28318787, 23.67124939], [68.28318787, 23.67152977], [68.28347015, 23.67152977], [68.28347015, 23.67181015], [68.28430176, 23.67180634], [68.28430176, 23.6720829], [68.28457642, 23.6720829], [68.28457642, 23.67263985], [68.28514099, 23.67263985], [68.28514099, 23.67292023], [68.28541565, 23.67291641], [68.28541565, 23.67319489], [68.2859726, 23.67319489], [68.2859726, 23.67347145], [68.28624725, 23.67346954], [68.28624725, 23.67374992], [68.28679657, 23.67374992], [68.28679657, 23.6740303], [68.28708649, 23.6740303], [68.28708649, 23.67431068], [68.2876358, 23.67430305], [68.2876358, 23.67458534], [68.28791809, 23.67458534], [68.28791809, 23.67486382], [68.28848267, 23.67486], [68.28848267, 23.67514038], [68.28874969, 23.67514038], [68.28874969, 23.67542076], [68.28902435, 23.67541695], [68.28903198, 23.6756897], [68.28930664, 23.67569351], [68.28930664, 23.67597198], [68.2895813, 23.67597008], [68.2895813, 23.67625999], [68.28985596, 23.67625999], [68.28985596, 23.67653084], [68.2904129, 23.67653084], [68.2904129, 23.67681122], [68.29069519, 23.67680359], [68.29069519, 23.67708588], [68.29096985, 23.67708015], [68.29096985, 23.67736053], [68.29125214, 23.67736053], [68.29125214, 23.67764091], [68.29180908, 23.67764091], [68.29180908, 23.67791939], [68.29208374, 23.67791748], [68.29208374, 23.67819595], [68.2923584, 23.67819595], [68.2923584, 23.67847252], [68.29402924, 23.67847061], [68.29402924, 23.67875099], [68.29429626, 23.67875099], [68.29429626, 23.67902946], [68.29486084, 23.67902946], [68.29486084, 23.67875099], [68.2959671, 23.67875099], [68.2959671, 23.67902946], [68.29624939, 23.67902946], [68.29624939, 23.67931747], [68.29652405, 23.67930794], [68.29652405, 23.6795826], [68.29708099, 23.67958069], [68.29708099, 23.67986107], [68.29792023, 23.67986107], [68.29792023, 23.67958069], [68.29930878, 23.6795826], [68.29930878, 23.67930794], [68.30042267, 23.67931747], [68.30042267, 23.67902946], [68.30152893, 23.67902946], [68.30152893, 23.67875099], [68.30291748, 23.67875099], [68.30291748, 23.67902946], [68.30432129, 23.67902946], [68.30432129, 23.67931747], [68.30458069, 23.67930794], [68.30458069, 23.6795826], [68.30486298, 23.67958069], [68.30486298, 23.68013954], [68.30513763, 23.68013954], [68.30513763, 23.68069458], [68.30569458, 23.68069458], [68.30569458, 23.68097305], [68.30596924, 23.68097115], [68.30596924, 23.68124962], [68.30625153, 23.68124962], [68.30625153, 23.68152809], [68.30596924, 23.68152809], [68.30596924, 23.68180466], [68.30541992, 23.68180466], [68.30541992, 23.68152809], [68.30486298, 23.68152809], [68.30486298, 23.68124962], [68.30458069, 23.68124962], [68.30458069, 23.68069077], [68.30430603, 23.68069458], [68.30430603, 23.68013954], [68.30403137, 23.68013954], [68.30403137, 23.67986107], [68.30263519, 23.67986107], [68.30263519, 23.6795826], [68.30152893, 23.67958069], [68.30152893, 23.67986107], [68.30069733, 23.67986107], [68.30069733, 23.68013954], [68.29985809, 23.68013954], [68.29985809, 23.68041992], [68.29958344, 23.68041611], [68.29958344, 23.68069458], [68.29902649, 23.68069458], [68.29902649, 23.68097305], [68.29875183, 23.68097115], [68.29875183, 23.68124962], [68.29846954, 23.68124962], [68.29846954, 23.68180466], [68.29819489, 23.68180466], [68.29819489, 23.68208313], [68.29792023, 23.68208313], [68.29792023, 23.6823616], [68.29763794, 23.6823597], [68.29763794, 23.68292236], [68.29736328, 23.68292236], [68.29736328, 23.68403244], [68.29763794, 23.68402863], [68.29763794, 23.68458366], [68.29792023, 23.68458366], [68.29792023, 23.6851387], [68.29818726, 23.68512917], [68.29818726, 23.6854229], [68.29846954, 23.68541718], [68.29846954, 23.68569374], [68.29875183, 23.68569374], [68.29875183, 23.68597221], [68.29930878, 23.68597031], [68.29930878, 23.68625069], [68.29957581, 23.68625069], [68.29957581, 23.68653107], [68.29985809, 23.68653107], [68.29985809, 23.68680954], [68.30014038, 23.68680573], [68.30014038, 23.68708229], [68.30041504, 23.68708229], [68.30041504, 23.68736076], [68.30069733, 23.68736076], [68.30069733, 23.68764114], [68.30097198, 23.68764114], [68.30097198, 23.68791962], [68.30124664, 23.6879158], [68.30124664, 23.68847466], [68.30152893, 23.68847084], [68.30152893, 23.68875122], [68.30179596, 23.68875122], [68.30179596, 23.68902969], [68.30208588, 23.68902969], [68.30208588, 23.68931007], [68.30236053, 23.68930435], [68.30236053, 23.68958282], [68.30263519, 23.68958282], [68.30263519, 23.6898613], [68.30291748, 23.68985939], [68.30291748, 23.69042015], [68.30319214, 23.69041443], [68.30319214, 23.69069672], [68.30347443, 23.69069672], [68.30347443, 23.69097137], [68.30374908, 23.69096947], [68.30374908, 23.69125938], [68.30403137, 23.69125938], [68.30403137, 23.69153023], [68.30430603, 23.69152832], [68.30430603, 23.69180679], [68.30458069, 23.69180679], [68.30458069, 23.69208336], [68.30513763, 23.69208336], [68.30513763, 23.69236183], [68.30541992, 23.69235992], [68.30541992, 23.6926403], [68.30568695, 23.6926403], [68.30568695, 23.69292068], [68.30596924, 23.69292068], [68.30596924, 23.69319916], [68.30625153, 23.69319534], [68.30625153, 23.69347191], [68.30652618, 23.69346809], [68.30652618, 23.69403076], [68.30680847, 23.69402885], [68.30680847, 23.69430542], [68.30708313, 23.69430542], [68.30708313, 23.69458389], [68.30735779, 23.69457817], [68.30735779, 23.69486046], [68.30764008, 23.69486046], [68.30764008, 23.69541931], [68.30791473, 23.6954174], [68.30791473, 23.69569397], [68.30819702, 23.69569397], [68.30819702, 23.69597244], [68.30847168, 23.69597054], [68.30847168, 23.69652939], [68.30874634, 23.69652939], [68.30874634, 23.69681168], [68.30902863, 23.69680595], [68.30902863, 23.69708252], [68.30930328, 23.69706917], [68.30930328, 23.69763947], [68.3095932, 23.69763947], [68.3095932, 23.69792175], [68.30986023, 23.69791603], [68.30986023, 23.69847107], [68.31012726, 23.69847107], [68.31012726, 23.69903183], [68.31041718, 23.69903183], [68.31041718, 23.6993103], [68.31069183, 23.69930649], [68.31069183, 23.69986153], [68.31096649, 23.69985962], [68.31096649, 23.70042038], [68.31124878, 23.70041656], [68.31124878, 23.7009716], [68.31153107, 23.7009697], [68.31153107, 23.70125008], [68.31181335, 23.70125008], [68.31181335, 23.70181084], [68.31208038, 23.70180321], [68.31208038, 23.70236206], [68.31236267, 23.70236015], [68.31236267, 23.70319939], [68.31263733, 23.70319939], [68.31263733, 23.70430946], [68.31291962, 23.70430946], [68.31291962, 23.70541954], [68.31319427, 23.70541763], [68.31319427, 23.70597267], [68.31346893, 23.70597267], [68.31346893, 23.70708275], [68.31375122, 23.70708275], [68.31375122, 23.7084713], [68.31346893, 23.7084713], [68.31346893, 23.70986176], [68.31319427, 23.70986176], [68.31319427, 23.71097183], [68.31346893, 23.71097183], [68.31346893, 23.71208382], [68.31375122, 23.71208191], [68.31375122, 23.71264267], [68.31402588, 23.71263885], [68.31402588, 23.71319389], [68.31430817, 23.71319008], [68.31430817, 23.71375084], [68.31458282, 23.71375084], [68.31458282, 23.71430969], [68.31485748, 23.71430588], [68.31485748, 23.71458244], [68.31513977, 23.71458054], [68.31513977, 23.71486092], [68.3154068, 23.71486092], [68.3154068, 23.71513939], [68.31569672, 23.71513939], [68.31569672, 23.71543121], [68.31597137, 23.71541405], [68.31597137, 23.71569633], [68.31625366, 23.71569633], [68.31625366, 23.71597481], [68.31680298, 23.71597099], [68.31680298, 23.71624947], [68.3170929, 23.71624947], [68.3170929, 23.71652985], [68.31735992, 23.71652985], [68.31735992, 23.71681023], [68.31764221, 23.7168045], [68.31764221, 23.71708488], [68.31791687, 23.71708107], [68.31791687, 23.71763992], [68.31819153, 23.71763992], [68.31819153, 23.7179203], [68.31846619, 23.7179203], [68.31846619, 23.71820068], [68.31903076, 23.71819687], [68.31903076, 23.71847153], [68.31929779, 23.71846962], [68.31929779, 23.71875], [68.31986237, 23.71875], [68.31986237, 23.71903038], [68.32013702, 23.71903038], [68.32013702, 23.71931076], [68.32069397, 23.71930695], [68.32069397, 23.71958351], [68.32096863, 23.71958351], [68.32096863, 23.71986198], [68.3215332, 23.71986008], [68.3215332, 23.72014046], [68.32206726, 23.72014046], [68.32206726, 23.72042084], [68.32236481, 23.72041893], [68.32236481, 23.72069359], [68.32291412, 23.72069359], [68.32291412, 23.72097206], [68.32347107, 23.72097206], [68.32347107, 23.72125053], [68.32402802, 23.721241], [68.32402802, 23.72153091], [68.32485962, 23.72153091], [68.32485962, 23.72180939], [68.32541656, 23.72180557], [68.32541656, 23.72208405], [68.32596588, 23.72207832], [68.32596588, 23.72236061], [68.32624817, 23.72236061], [68.32624817, 23.72263908], [68.32681274, 23.72263908], [68.32681274, 23.72291946], [68.32707977, 23.72291756], [68.32707977, 23.72319412], [68.32763672, 23.72319412], [68.32763672, 23.7234726], [68.32820129, 23.72347069], [68.32820129, 23.72374916], [68.32958221, 23.72374916], [68.32958221, 23.72263908], [68.32985687, 23.72263908], [68.32985687, 23.72236061], [68.32958221, 23.72236061], [68.32958221, 23.72068977], [68.3298645, 23.72069359], [68.3298645, 23.71986198], [68.33013916, 23.71986198], [68.33013916, 23.71958351], [68.33041382, 23.71958351], [68.33041382, 23.71902847], [68.33069611, 23.71903038], [68.33069611, 23.71875], [68.33097076, 23.71875], [68.33097076, 23.71820068], [68.33123779, 23.71820068], [68.33123779, 23.7179203], [68.33152771, 23.7179203], [68.33152771, 23.71763992], [68.33207703, 23.71763992], [68.33207703, 23.71735954], [68.33235931, 23.71736145], [68.33235931, 23.71708488], [68.3326416, 23.71708488], [68.3326416, 23.71624947], [68.33291626, 23.71624947], [68.33291626, 23.71543121], [68.33319092, 23.71543121], [68.33319092, 23.71347046], [68.33347321, 23.71347237], [68.33347321, 23.71236038], [68.33319092, 23.71236038], [68.33319092, 23.71097183], [68.33347321, 23.71097183], [68.33347321, 23.71069527], [68.33374786, 23.71069527], [68.33374786, 23.71097183], [68.33403015, 23.71097183], [68.33403015, 23.71236038], [68.33429718, 23.71236038], [68.33429718, 23.71375084], [68.33403015, 23.71375084], [68.33403015, 23.71543121], [68.33374786, 23.71543121], [68.33374786, 23.71624947], [68.33347321, 23.71624947], [68.33347321, 23.71708488], [68.33319092, 23.71708488], [68.33319092, 23.71736145], [68.33291626, 23.71735954], [68.33291626, 23.71763992], [68.3326416, 23.71763992], [68.3326416, 23.7179203], [68.33235931, 23.7179203], [68.33235931, 23.71820068], [68.33208466, 23.71819687], [68.33208466, 23.71847153], [68.33180237, 23.71846962], [68.33180237, 23.71875], [68.33152771, 23.71875], [68.33152771, 23.71903038], [68.33125305, 23.71902847], [68.33125305, 23.71958351], [68.33097076, 23.7195797], [68.33097076, 23.72014046], [68.33069611, 23.72013855], [68.33069611, 23.72069359], [68.33040619, 23.72068977], [68.33040619, 23.72236061], [68.33069611, 23.72236061], [68.33069611, 23.72319412], [68.33097076, 23.7231884], [68.33097076, 23.72374916], [68.33125305, 23.72374916], [68.33125305, 23.72430611], [68.33152771, 23.72430611], [68.33152771, 23.72458267], [68.33207703, 23.72458267], [68.33207703, 23.72486115], [68.33235931, 23.72486115], [68.33235931, 23.72513962], [68.3345871, 23.72513962], [68.3345871, 23.72542191], [68.33486176, 23.72541618], [68.33486176, 23.72569466], [68.3354187, 23.72569466], [68.3354187, 23.72597122], [68.33569336, 23.72597122], [68.33569336, 23.72653008], [68.33597565, 23.72652817], [68.33597565, 23.7270813], [68.33625031, 23.72707939], [68.33625031, 23.72764015], [68.33653259, 23.72764015], [68.33653259, 23.72820091], [68.33680725, 23.72819328], [68.33680725, 23.72847176], [68.33708191, 23.72846985], [68.33708191, 23.72875023], [68.33737183, 23.72875023], [68.33737183, 23.72903061], [68.33763885, 23.7290287], [68.33763885, 23.72958565], [68.33790588, 23.72957993], [68.33790588, 23.7304306], [68.3381958, 23.7304306], [68.3381958, 23.73125076], [68.33847046, 23.73125076], [68.33847046, 23.73208427], [68.33875275, 23.73208046], [68.33875275, 23.73291969], [68.3390274, 23.73291969], [68.3390274, 23.73430824], [68.33930206, 23.73430634], [68.33930206, 23.73597145], [68.3390274, 23.73596764], [68.3390274, 23.73792267], [68.33930206, 23.73792267], [68.33930206, 23.74263954], [68.33957672, 23.74263954], [68.33957672, 23.74291992], [68.3401413, 23.74291992], [68.3401413, 23.74263954], [68.34069824, 23.74263954], [68.34069824, 23.74237061], [68.34124756, 23.74237061], [68.34124756, 23.74208069], [68.34236145, 23.7420826], [68.34236145, 23.74180412], [68.34263611, 23.74180984], [68.34263611, 23.74152946], [68.3434906, 23.74152946], [68.3434906, 23.7412529], [68.34401703, 23.7412529], [68.34401703, 23.74097061], [68.34486389, 23.74097252], [68.34486389, 23.74041748], [68.34513855, 23.74041939], [68.34513855, 23.74014282], [68.34541321, 23.74014282], [68.34541321, 23.73986053], [68.34570313, 23.73986053], [68.3456955, 23.73791695], [68.34597015, 23.73792267], [68.34597015, 23.73764038], [68.34623718, 23.73764038], [68.34623718, 23.73708153], [68.3465271, 23.73708344], [68.3465271, 23.73541641], [68.34680176, 23.73541832], [68.34680939, 23.73485947], [68.34708405, 23.73486137], [68.34708405, 23.7345829], [68.3473587, 23.7345829], [68.3473587, 23.73402977], [68.34764099, 23.73402977], [68.34764099, 23.73374939], [68.34792328, 23.73374939], [68.34791565, 23.73319435], [68.34819794, 23.73319435], [68.34819794, 23.73263931], [68.3484726, 23.73264122], [68.3484726, 23.73236084], [68.34874725, 23.73236084], [68.34874725, 23.73208046], [68.34902954, 23.73208427], [68.34902954, 23.73180771], [68.34986115, 23.73180771], [68.34986115, 23.73208427], [68.3501358, 23.73208046], [68.3501358, 23.73291969], [68.34986115, 23.73291779], [68.34986115, 23.73347282], [68.34958649, 23.73347092], [68.34958649, 23.73374939], [68.34931183, 23.73374939], [68.34931183, 23.73430824], [68.34902954, 23.73430634], [68.34902954, 23.73486137], [68.34874725, 23.73485947], [68.34874725, 23.73513985], [68.3484726, 23.73513985], [68.3484726, 23.73819351], [68.34819794, 23.7381916], [68.34819794, 23.73931122], [68.34792328, 23.73931122], [68.34792328, 23.74014282], [68.3473587, 23.74013901], [68.3473587, 23.74069214], [68.34708405, 23.74069214], [68.34708405, 23.74097252], [68.3473587, 23.74097061], [68.3473587, 23.7412529], [68.34764099, 23.7412529], [68.34764099, 23.74152946], [68.34792328, 23.74152946], [68.34792328, 23.74180984], [68.3493042, 23.74180412], [68.3493042, 23.7420826], [68.34958649, 23.74208069], [68.34958649, 23.74237061], [68.35069275, 23.74237061], [68.35069275, 23.74263954], [68.35151672, 23.74263954], [68.35151672, 23.74291992], [68.35180664, 23.74291992], [68.35180664, 23.74374962], [68.35151672, 23.74374962], [68.35151672, 23.74403], [68.3501358, 23.74403], [68.3501358, 23.74374962], [68.34902954, 23.74374962], [68.34902954, 23.74347115], [68.3484726, 23.74347305], [68.3484726, 23.74319649], [68.3473587, 23.74319649], [68.3473587, 23.7429142], [68.34680939, 23.74291992], [68.34680176, 23.74263954], [68.34597015, 23.74263954], [68.34597015, 23.74291992], [68.34486389, 23.7429142], [68.34486389, 23.74319649], [68.34430695, 23.74319649], [68.34430695, 23.74347305], [68.34401703, 23.74347115], [68.34401703, 23.74374962], [68.34375, 23.74374962], [68.34375, 23.74403], [68.34319305, 23.74402618], [68.34319305, 23.74430656], [68.3429184, 23.74430656], [68.3429184, 23.74458313], [68.34236145, 23.74458313], [68.34236145, 23.7448616], [68.3409729, 23.7448597], [68.3409729, 23.74791908], [68.34124756, 23.74791718], [68.34124756, 23.7495842], [68.3409729, 23.74957848], [68.3409729, 23.75013924], [68.34152985, 23.75013924], [68.34152985, 23.75069427], [68.34179688, 23.75068855], [68.34179688, 23.75125122], [68.3429184, 23.75125122], [68.3429184, 23.75154114], [68.34319305, 23.75152779], [68.34319305, 23.7523613], [68.3429184, 23.75235939], [68.3429184, 23.75263977], [68.3409729, 23.75263977], [68.3409729, 23.75235939], [68.34069824, 23.7523613], [68.34069824, 23.75208282], [68.34041595, 23.75208282], [68.34041595, 23.75180626], [68.33985901, 23.75181007], [68.33985901, 23.75154114], [68.3390274, 23.75154114], [68.3390274, 23.75181007], [68.33847046, 23.75180626], [68.33847046, 23.75208282], [68.33791351, 23.75208282], [68.33791351, 23.7523613], [68.33763885, 23.75235939], [68.33763885, 23.75263977], [68.33790588, 23.75263977], [68.33790588, 23.75292015], [68.3381958, 23.75291634], [68.3381958, 23.75319481], [68.33847046, 23.75319481], [68.33847046, 23.75347137], [68.3381958, 23.75346947], [68.3381958, 23.75374985], [68.33790588, 23.75374985], [68.33790588, 23.75431061], [68.3373642, 23.75430489], [68.3373642, 23.75458336], [68.33708191, 23.75458336], [68.33708191, 23.75486183], [68.33680725, 23.75485992], [68.33680725, 23.75542068], [68.33653259, 23.75542068], [68.33653259, 23.75570107], [68.33625031, 23.75569344], [68.33625031, 23.75597191], [68.33569336, 23.75597], [68.33569336, 23.75625038], [68.33486176, 23.75625038], [68.33486176, 23.75875092], [68.33513641, 23.75875092], [68.33513641, 23.75930977], [68.3354187, 23.75930786], [68.3354187, 23.75958252], [68.33569336, 23.75958061], [68.33569336, 23.76013947], [68.33597565, 23.76013947], [68.33597565, 23.76041794], [68.33625031, 23.76041794], [68.33625031, 23.76097298], [68.33653259, 23.76097107], [68.33653259, 23.76152992], [68.33680725, 23.76152992], [68.33680725, 23.7618084], [68.33708191, 23.76180649], [68.33708191, 23.76208305], [68.3373642, 23.76208305], [68.3373642, 23.76236153], [68.33763885, 23.76235962], [68.33763885, 23.76263809], [68.33790588, 23.76263809], [68.33790588, 23.76291847], [68.3381958, 23.76291847], [68.3381958, 23.76320267], [68.33847046, 23.76320267], [68.33847046, 23.76375008], [68.33875275, 23.76375008], [68.33875275, 23.76403046], [68.3390274, 23.76403046], [68.3390274, 23.76431274], [68.33930206, 23.76430511], [68.33930206, 23.76458359], [68.33957672, 23.76458168], [68.33957672, 23.76514053], [68.33985901, 23.76514053], [68.33985901, 23.76542282], [68.3401413, 23.7654171], [68.3401413, 23.76597023], [68.34043121, 23.76597023], [68.34043121, 23.76654053], [68.34069061, 23.76654053], [68.34069824, 23.76680946], [68.3409729, 23.76680946], [68.3409729, 23.76736069], [68.34124756, 23.76736069], [68.34124756, 23.76791954], [68.34152985, 23.76791763], [68.34152985, 23.76819229], [68.34179688, 23.76819038], [68.34179688, 23.76875114], [68.34208679, 23.76875114], [68.34208679, 23.76931], [68.34236145, 23.76931], [68.34236145, 23.76986122], [68.34263611, 23.76986122], [68.34263611, 23.77042007], [68.3429184, 23.77041435], [68.3429184, 23.7709713], [68.3431778, 23.77096939], [68.3431778, 23.77153015], [68.34347534, 23.77152824], [68.34347534, 23.77208328], [68.34375, 23.77207947], [68.34375, 23.77264023], [68.34401703, 23.77264023], [68.34401703, 23.77319908], [68.34430695, 23.77319908], [68.34430695, 23.77375031], [68.3445816, 23.77375031], [68.3445816, 23.77403069], [68.34486389, 23.77402878], [68.34486389, 23.77458382], [68.34513855, 23.77457809], [68.34513855, 23.77514076], [68.34541321, 23.77514076], [68.34541321, 23.77541924], [68.3456955, 23.77541733], [68.3456955, 23.77597237], [68.34597015, 23.77597046], [68.34597015, 23.77652931], [68.34625244, 23.7765274], [68.34625244, 23.77708244], [68.3465271, 23.77708054], [68.3465271, 23.77763939], [68.34680176, 23.77763939], [68.34680176, 23.77848053], [68.34707642, 23.77848053], [68.34707642, 23.77902985], [68.3473587, 23.77902794], [68.3473587, 23.77958107], [68.34764099, 23.77958107], [68.34764099, 23.78013992], [68.34792328, 23.78013992], [68.34792328, 23.78070068], [68.34819794, 23.78070068], [68.34819794, 23.78125], [68.3484726, 23.78125], [68.3484726, 23.78152847], [68.34874725, 23.78152847], [68.34874725, 23.78236389], [68.34902954, 23.78236389], [68.34902954, 23.78458595], [68.3493042, 23.78458595], [68.3493042, 23.78874969], [68.34958649, 23.78874969], [68.34958649, 23.79071045], [68.34986115, 23.79069519], [68.34986115, 23.79208374], [68.35041809, 23.79208183], [68.35041809, 23.79292107], [68.3501358, 23.79291725], [68.3501358, 23.79347229], [68.34986115, 23.79346275], [68.34986115, 23.79430962], [68.34958649, 23.7943058], [68.34958649, 23.79652786], [68.34986115, 23.79652786], [68.34986115, 23.79847145], [68.3501358, 23.79846954], [68.3501358, 23.79959106], [68.35041809, 23.79958344], [68.35041809, 23.8006897], [68.35152435, 23.80069542], [68.35152435, 23.80097198], [68.35180664, 23.80096817], [68.35180664, 23.80153084], [68.3520813, 23.80152893], [68.3520813, 23.80208397], [68.35236359, 23.80208397], [68.35236359, 23.80236053], [68.35263824, 23.80236053], [68.35263824, 23.80265045], [68.3529129, 23.80265045], [68.3529129, 23.80291939], [68.35319519, 23.80291748], [68.35319519, 23.80319405], [68.35346985, 23.80319405], [68.35346985, 23.80347252], [68.35375214, 23.80347061], [68.35375214, 23.80374908], [68.35402679, 23.80374908], [68.35402679, 23.80402946], [68.35457611, 23.80402946], [68.35457611, 23.80431175], [68.3548584, 23.80430603], [68.3548584, 23.8045826], [68.35540771, 23.80458069], [68.35540771, 23.80486107], [68.35679626, 23.80486107], [68.35679626, 23.80513954], [68.3584671, 23.80513954], [68.3584671, 23.80486107], [68.35930634, 23.80486107], [68.35930634, 23.80458069], [68.36042023, 23.8045826], [68.36042023, 23.80430603], [68.36125183, 23.80431175], [68.36125183, 23.80402946], [68.36180878, 23.80402946], [68.36180878, 23.80374908], [68.36235809, 23.80374908], [68.36235809, 23.80347061], [68.36264038, 23.80347252], [68.36264038, 23.80319405], [68.36319733, 23.80319405], [68.36319733, 23.80291748], [68.36374664, 23.80291939], [68.36374664, 23.80265045], [68.36431122, 23.80265045], [68.36431122, 23.80236053], [68.36458588, 23.80236053], [68.36458588, 23.80208397], [68.36486053, 23.80208397], [68.36486053, 23.8018055], [68.36514282, 23.80180931], [68.36514282, 23.80153084], [68.36569214, 23.80153084], [68.36569214, 23.80125046], [68.3659668, 23.80125046], [68.3659668, 23.80096817], [68.36624908, 23.80097198], [68.36624908, 23.80069542], [68.36653137, 23.8006897], [68.36653137, 23.80041885], [68.36680603, 23.80042076], [68.36680603, 23.80014038], [68.36708069, 23.80014038], [68.36708069, 23.79985809], [68.36736298, 23.79986191], [68.36736298, 23.79958344], [68.36763763, 23.79959106], [68.36763763, 23.79931068], [68.36791992, 23.79931068], [68.36791992, 23.7990303], [68.36818695, 23.7990303], [68.36818695, 23.79874992], [68.36846924, 23.79874992], [68.36846924, 23.79846954], [68.36875153, 23.79847145], [68.36875153, 23.79819679], [68.36902618, 23.79819679], [68.36902618, 23.79791451], [68.36930847, 23.79792023], [68.36930847, 23.79735947], [68.36958313, 23.79736137], [68.36958313, 23.7970829], [68.36985779, 23.7970829], [68.36985779, 23.79680443], [68.37014008, 23.79681015], [68.37014008, 23.79652023], [68.37041473, 23.79652786], [68.37041473, 23.79624939], [68.37069702, 23.79624939], [68.37069702, 23.79597092], [68.37124634, 23.79597473], [68.37124634, 23.79569244], [68.37152863, 23.79569244], [68.37152863, 23.79541588], [68.37180328, 23.79541969], [68.37180328, 23.79514122], [68.3720932, 23.79514122], [68.3720932, 23.79486084], [68.37264252, 23.79486084], [68.37264252, 23.79458046], [68.37319183, 23.79458237], [68.37319183, 23.7943058], [68.37374878, 23.79430962], [68.37374878, 23.79403114], [68.37403107, 23.79403114], [68.37403107, 23.79375076], [68.37458038, 23.79375076], [68.37458038, 23.79346275], [68.37513733, 23.79347229], [68.37513733, 23.79319382], [68.37541962, 23.79319382], [68.37541962, 23.79291725], [68.37596893, 23.79292107], [68.37596893, 23.79264069], [68.37654114, 23.79264069], [68.37654114, 23.79236031], [68.37680817, 23.79236031], [68.37680817, 23.79208183], [68.37708282, 23.79208374], [68.37708282, 23.79180527], [68.37763977, 23.7918129], [68.37763977, 23.79153252], [68.37819672, 23.79153252], [68.37819672, 23.79125023], [68.37874603, 23.79125023], [68.37874603, 23.79097176], [68.37930298, 23.79097176], [68.37930298, 23.79069519], [68.37985992, 23.79071045], [68.37985992, 23.79042244], [68.38069153, 23.79042244], [68.38069153, 23.79014015], [68.38124847, 23.79014015], [68.38124847, 23.78986168], [68.38236237, 23.78986168], [68.38236237, 23.78958321], [68.38346863, 23.78958321], [68.38346863, 23.78930473], [68.38402557, 23.78930473], [68.38402557, 23.78902817], [68.38485718, 23.78902817], [68.38485718, 23.78874969], [68.38764191, 23.78874969], [68.38764191, 23.78847122], [68.38847351, 23.78847313], [68.38847351, 23.78819466], [68.38930511, 23.78819466], [68.38930511, 23.78791618], [68.38986206, 23.78791809], [68.38986206, 23.78764915], [68.39068604, 23.78764915], [68.39068604, 23.78736115], [68.39154053, 23.78736115], [68.39152527, 23.78708267], [68.3923645, 23.78708267], [68.3923645, 23.78680611], [68.39319611, 23.78680992], [68.39319611, 23.78652954], [68.39402771, 23.78652954], [68.39402771, 23.78625107], [68.39485931, 23.78625107], [68.39485931, 23.78597069], [68.39569092, 23.7859726], [68.39569092, 23.78569412], [68.39624786, 23.78569412], [68.39624786, 23.78541756], [68.3970871, 23.78541946], [68.3970871, 23.78514099], [68.3979187, 23.78514099], [68.3979187, 23.78486061], [68.40125275, 23.78486061], [68.40125275, 23.78514099], [68.40207672, 23.78514099], [68.40207672, 23.78541946], [68.4026413, 23.78541756], [68.4026413, 23.78569412], [68.40291595, 23.78569412], [68.40291595, 23.7859726], [68.40348053, 23.78597069], [68.40348053, 23.78625107], [68.40458679, 23.78625107], [68.40458679, 23.78652954], [68.4054184, 23.78652954], [68.4054184, 23.78680992], [68.40597534, 23.78680611], [68.40597534, 23.78708267], [68.40625, 23.78708076], [68.40625, 23.78736115], [68.40680695, 23.78736115], [68.40680695, 23.78764915], [68.40735626, 23.78764915], [68.40735626, 23.78791809], [68.40763855, 23.78791618], [68.40763855, 23.78819466], [68.4081955, 23.78819466], [68.4081955, 23.78847313], [68.40847015, 23.78847122], [68.40847015, 23.78874969], [68.4090271, 23.78874969], [68.4090271, 23.78930473], [68.40930176, 23.78930473], [68.40930176, 23.78958321], [68.40957642, 23.78957748], [68.40957642, 23.79014015], [68.41014099, 23.79014015], [68.41014099, 23.79042244], [68.41042328, 23.79042244], [68.41042328, 23.79071045], [68.41069794, 23.79071045], [68.41069794, 23.79125023], [68.4109726, 23.79125023], [68.4109726, 23.7918129], [68.41124725, 23.7918129], [68.41124725, 23.79264069], [68.41152954, 23.79264069], [68.41152954, 23.79292107], [68.4118042, 23.79291725], [68.4118042, 23.79347229], [68.41236115, 23.79346275], [68.41236115, 23.79375076], [68.41291809, 23.79375076], [68.41291809, 23.79403114], [68.41374969, 23.79403114], [68.41374969, 23.79430962], [68.41430664, 23.7943058], [68.41430664, 23.79458237], [68.41513824, 23.79458046], [68.41513824, 23.79486084], [68.41625214, 23.79486084], [68.41625214, 23.79514122], [68.41845703, 23.79514122], [68.41845703, 23.79486084], [68.41902924, 23.79486084], [68.41902924, 23.79458046], [68.42151642, 23.79458046], [68.42151642, 23.79486084], [68.42208099, 23.79486084], [68.42208099, 23.79514122], [68.42263794, 23.79514122], [68.42263794, 23.79541969], [68.42319489, 23.79541588], [68.42319489, 23.79569244], [68.42346954, 23.79569054], [68.42346954, 23.79624939], [68.42375183, 23.79624939], [68.42375183, 23.79652786], [68.42402649, 23.79652023], [68.42402649, 23.79681015], [68.42430878, 23.79680443], [68.42430878, 23.7970829], [68.42514038, 23.7970829], [68.42514038, 23.79680443], [68.42542267, 23.79681015], [68.42542267, 23.79624939], [68.42569733, 23.79624939], [68.42569733, 23.79597092], [68.42597198, 23.79597473], [68.42597198, 23.79486084], [68.42624664, 23.79486084], [68.42624664, 23.79292107], [68.42597198, 23.79292107], [68.42597198, 23.79236031], [68.42569733, 23.79236031], [68.42569733, 23.79153252], [68.42542267, 23.79153252], [68.42542267, 23.79014015], [68.42514038, 23.79014015], [68.42514038, 23.78957748], [68.42541504, 23.78958321], [68.42541504, 23.78874969], [68.42569733, 23.78874969], [68.42569733, 23.78541946], [68.42542267, 23.78541946], [68.42542267, 23.78514099], [68.42569733, 23.78514099], [68.42569733, 23.78486061], [68.42541504, 23.78486061], [68.42541504, 23.78430748], [68.42569733, 23.78430939], [68.42569733, 23.78375053], [68.42541504, 23.78375053], [68.42541504, 23.78319359], [68.42569733, 23.78319359], [68.42569733, 23.78180313], [68.42542267, 23.78181076], [68.42542267, 23.78096962], [68.42514038, 23.78097153], [68.42514038, 23.77986145], [68.42485809, 23.77986145], [68.42485809, 23.7784729], [68.42459106, 23.77848053], [68.42459106, 23.77708054], [68.42430878, 23.77708244], [68.42430878, 23.7765274], [68.42375183, 23.77652931], [68.42375183, 23.77625084], [68.42346954, 23.77625084], [68.42346954, 23.77597046], [68.42292023, 23.77597237], [68.42292023, 23.77569389], [68.42263794, 23.77569389], [68.42263794, 23.77541733], [68.42236328, 23.77541924], [68.42236328, 23.77514076], [68.42208099, 23.77514076], [68.42208099, 23.77486038], [68.42180634, 23.77486038], [68.42180634, 23.77457809], [68.42152405, 23.77458382], [68.42152405, 23.77375031], [68.42124939, 23.77375031], [68.42124939, 23.77346992], [68.42097473, 23.77347183], [68.42097473, 23.7729187], [68.42069244, 23.77292061], [68.42069244, 23.77180099], [68.42041779, 23.77180672], [68.42041779, 23.77152824], [68.42014313, 23.77153015], [68.42014313, 23.77069092], [68.41986084, 23.77069664], [68.41986084, 23.77013969], [68.41958618, 23.77013969], [68.41958618, 23.76986122], [68.41929626, 23.76986122], [68.41929626, 23.76875114], [68.41902924, 23.76875114], [68.41902924, 23.76708031], [68.41930389, 23.76708221], [68.41930389, 23.76680565], [68.41902924, 23.76680946], [68.41902924, 23.76597023], [68.41874695, 23.76597023], [68.41874695, 23.76486015], [68.41847229, 23.76486015], [68.41845703, 23.76348114], [68.41819763, 23.76348114], [68.41819763, 23.76320267], [68.41792297, 23.76320267], [68.41792297, 23.76291847], [68.41819763, 23.76291847], [68.41819763, 23.76263809], [68.41792297, 23.76263809], [68.41792297, 23.76235962], [68.41764069, 23.76236153], [68.41764069, 23.76208305], [68.4173584, 23.76208305], [68.4173584, 23.76180649], [68.41430664, 23.76180649], [68.41430664, 23.76208305], [68.41374969, 23.76208305], [68.41374969, 23.76180649], [68.41265106, 23.76180077], [68.4126358, 23.76152992], [68.41152954, 23.76152992], [68.41152954, 23.76124954], [68.41124725, 23.76124954], [68.41124725, 23.76097107], [68.41152954, 23.76097298], [68.41152954, 23.7606945], [68.4109726, 23.7606945], [68.4109726, 23.76041794], [68.41041565, 23.76041794], [68.41041565, 23.75986099], [68.41014099, 23.75986099], [68.41014099, 23.75958061], [68.4098587, 23.75958252], [68.4098587, 23.75930786], [68.40930939, 23.75930977], [68.4092865, 23.75902939], [68.40847015, 23.75902939], [68.40847015, 23.75875092], [68.40791321, 23.75875092], [68.40791321, 23.75847054], [68.40763855, 23.75847244], [68.40763855, 23.75819588], [68.40736389, 23.75819588], [68.40736389, 23.7579174], [68.4070816, 23.75792122], [68.4070816, 23.75764084], [68.40680695, 23.75764084], [68.40680695, 23.75735092], [68.40625, 23.75736046], [68.40625, 23.7570858], [68.40597534, 23.7570858], [68.40597534, 23.75680351], [68.4054184, 23.75681114], [68.4054184, 23.75653076], [68.40513611, 23.75653076], [68.40513611, 23.75625038], [68.40486145, 23.75625038], [68.40486145, 23.75597], [68.40458679, 23.75597191], [68.40458679, 23.75569344], [68.40402985, 23.75570107], [68.40402985, 23.75542068], [68.40374756, 23.75542068], [68.40374756, 23.7551403], [68.40348053, 23.7551403], [68.40348053, 23.75457954], [68.40319824, 23.75458336], [68.40319824, 23.75374985], [68.40291595, 23.75374985], [68.40291595, 23.7531929], [68.4026413, 23.75319481], [68.4026413, 23.75291634], [68.40235901, 23.75292015], [68.40235901, 23.75263977], [68.40207672, 23.75263977], [68.40207672, 23.75235939], [68.40180206, 23.7523613], [68.40180206, 23.75208282], [68.4015274, 23.75208282], [68.4015274, 23.75180626], [68.40097046, 23.75181007], [68.40097046, 23.75154114], [68.40042114, 23.75154114], [68.40042114, 23.75125122], [68.39958191, 23.75125122], [68.39958191, 23.75097084], [68.39930725, 23.75097275], [68.39930725, 23.7504158], [68.39958191, 23.75041962], [68.39958191, 23.75013924], [68.39985657, 23.75013924], [68.39985657, 23.75041962], [68.40041351, 23.7504158], [68.40041351, 23.75069427], [68.40097046, 23.75069427], [68.40097046, 23.75097275], [68.4015274, 23.75097084], [68.4015274, 23.75125122], [68.40180206, 23.75125122], [68.40180206, 23.75154114], [68.40207672, 23.75154114], [68.40207672, 23.75181007], [68.4034729, 23.75180626], [68.4034729, 23.75208282], [68.40402985, 23.75208282], [68.40402985, 23.7523613], [68.40458679, 23.75235939], [68.40458679, 23.75263977], [68.40486145, 23.75263977], [68.40486145, 23.75292015], [68.40513611, 23.75291634], [68.40513611, 23.75319481], [68.4054184, 23.7531929], [68.4054184, 23.75403023], [68.40513611, 23.75403023], [68.40513611, 23.75542068], [68.4054184, 23.75542068], [68.4054184, 23.75570107], [68.40569305, 23.75569344], [68.40569305, 23.75597191], [68.40625, 23.75597], [68.40625, 23.75625038], [68.40651703, 23.75625038], [68.40651703, 23.75653076], [68.40680695, 23.75653076], [68.40680695, 23.75681114], [68.4070816, 23.75680351], [68.4070816, 23.7570858], [68.40736389, 23.7570858], [68.40736389, 23.75736046], [68.40763855, 23.75735092], [68.40763855, 23.75764084], [68.40820313, 23.75764084], [68.40820313, 23.75792122], [68.40847015, 23.7579174], [68.40847015, 23.75819588], [68.40930176, 23.75819588], [68.40930176, 23.75847244], [68.4098587, 23.75847054], [68.4098587, 23.75875092], [68.41042328, 23.75875092], [68.41042328, 23.75902939], [68.41069794, 23.75902939], [68.41069794, 23.75930977], [68.4109726, 23.75930786], [68.4109726, 23.75958252], [68.41124725, 23.75958061], [68.41124725, 23.75986099], [68.41179657, 23.75986099], [68.41179657, 23.76013947], [68.41236115, 23.76013947], [68.41236115, 23.76041794], [68.41319275, 23.76041794], [68.41319275, 23.7606945], [68.41430664, 23.7606945], [68.41430664, 23.76097298], [68.41680908, 23.76097298], [68.41680908, 23.7606945], [68.41708374, 23.7606945], [68.41708374, 23.76041794], [68.4173584, 23.76041794], [68.4173584, 23.75875092], [68.41707611, 23.75875092], [68.41707611, 23.75708008], [68.41680908, 23.7570858], [68.41680908, 23.75652695], [68.41652679, 23.75653076], [68.41652679, 23.75597], [68.41625214, 23.75597191], [68.41625214, 23.75541687], [68.41596985, 23.75542068], [68.41596985, 23.75346947], [68.41569519, 23.75347137], [68.41569519, 23.7504158], [68.41542053, 23.75041962], [68.41542053, 23.74791908], [68.41571045, 23.74791908], [68.41571045, 23.74596977], [68.41596985, 23.74597168], [68.41596985, 23.74319649], [68.41625214, 23.74319649], [68.41625214, 23.74013901], [68.41652679, 23.74014282], [68.41652679, 23.73764038], [68.41680908, 23.73764038], [68.41680908, 23.73596764], [68.41708374, 23.73597145], [68.41708374, 23.73513985], [68.4173584, 23.73513985], [68.4173584, 23.73402977], [68.41764069, 23.73402977], [68.41764069, 23.73264122], [68.41792297, 23.73264122], [68.41792297, 23.73125076], [68.41819763, 23.73125076], [68.41819763, 23.72875023], [68.41845703, 23.72875023], [68.41845703, 23.72429848], [68.41819763, 23.72430611], [68.41819763, 23.7234726], [68.41791534, 23.7234726], [68.41791534, 23.72291756], [68.41764069, 23.72291946], [68.41764069, 23.72236061], [68.4173584, 23.72236061], [68.4173584, 23.72207832], [68.41708374, 23.72208405], [68.41708374, 23.71958351], [68.41680908, 23.71958351], [68.41680908, 23.71819687], [68.41652679, 23.71820068], [68.41652679, 23.7179203], [68.41625214, 23.7179203], [68.41625214, 23.71763992], [68.41596985, 23.71763992], [68.41596985, 23.71735954], [68.41569519, 23.71736145], [68.41569519, 23.71708488], [68.4154129, 23.71708488], [68.4154129, 23.71597481], [68.41513824, 23.71597481], [68.41513824, 23.71513939], [68.41485596, 23.71513939], [68.41485596, 23.71430969], [68.4145813, 23.71430969], [68.4145813, 23.71347046], [68.41430664, 23.71347237], [68.41430664, 23.71263885], [68.41401672, 23.71264267], [68.41401672, 23.71208191], [68.41374969, 23.71208382], [68.41374969, 23.71152687], [68.41348267, 23.71153259], [68.41348267, 23.71097183], [68.41319275, 23.71097183], [68.41319275, 23.71041679], [68.41291809, 23.71042252], [68.41291809, 23.71014023], [68.41265106, 23.71014023], [68.41265106, 23.70986176], [68.41236115, 23.70986176], [68.41236115, 23.70958328], [68.41208649, 23.70958328], [68.41208649, 23.70930481], [68.4118042, 23.70930481], [68.4118042, 23.70902824], [68.41152954, 23.70902824], [68.41152954, 23.70846748], [68.41124725, 23.7084713], [68.41124725, 23.70791626], [68.4109726, 23.70791817], [68.4109726, 23.70736122], [68.41069794, 23.70736122], [68.41069794, 23.70680809], [68.41042328, 23.70680809], [68.41042328, 23.7062397], [68.41014099, 23.70624924], [68.41014099, 23.70597267], [68.4098587, 23.70597267], [68.4098587, 23.70541763], [68.40957642, 23.70541954], [68.40957642, 23.70486069], [68.40930939, 23.70486069], [68.4092865, 23.70430946], [68.4090271, 23.70430946], [68.4090271, 23.70375061], [68.40875244, 23.70375061], [68.40875244, 23.70319939], [68.40847015, 23.70319939], [68.40847015, 23.70264053], [68.40820313, 23.70264053], [68.40820313, 23.70207977], [68.40791321, 23.70208549], [68.40791321, 23.69874954], [68.40763855, 23.69874954], [68.40763855, 23.69763947], [68.40735626, 23.69763947], [68.40735626, 23.69652939], [68.4070816, 23.69652939], [68.4070816, 23.69541931], [68.40680695, 23.69541931], [68.40680695, 23.6942997], [68.40652466, 23.69430542], [68.40652466, 23.69319534], [68.40625, 23.69319916], [68.40625, 23.69207954], [68.40597534, 23.69208336], [68.40597534, 23.69152832], [68.40569305, 23.69153023], [68.40569305, 23.69096947], [68.4054184, 23.69097137], [68.4054184, 23.69013977], [68.40513611, 23.69013977], [68.40513611, 23.68958092], [68.40486145, 23.68958282], [68.40486145, 23.68902779], [68.40458679, 23.68902969], [68.40458679, 23.68847084], [68.4043045, 23.68847466], [68.4043045, 23.6879158], [68.40402985, 23.68791962], [68.40402985, 23.68764114], [68.40374756, 23.68764114], [68.40374756, 23.68736076], [68.4034729, 23.68736076], [68.4034729, 23.68680573], [68.40319824, 23.68680954], [68.40319824, 23.68625069], [68.40291595, 23.68625069], [68.40291595, 23.68569183], [68.4026413, 23.68569374], [68.4026413, 23.68486023], [68.40235901, 23.68486023], [68.40235901, 23.68431282], [68.40207672, 23.68431282], [68.40207672, 23.68320274], [68.40180206, 23.68320274], [68.40180206, 23.68206978], [68.4015274, 23.68208313], [68.4015274, 23.68097305], [68.40125275, 23.68097305], [68.40125275, 23.68013954], [68.40097046, 23.68013954], [68.40097046, 23.67931747], [68.40071106, 23.67931747], [68.40071106, 23.67875099], [68.40042114, 23.67875099], [68.40042114, 23.67819023], [68.40013885, 23.67819595], [68.40013885, 23.67763901], [68.39985657, 23.67764091], [68.39985657, 23.67708015], [68.39958191, 23.67708588], [68.39958191, 23.67652512], [68.39930725, 23.67653084], [68.39930725, 23.67597008], [68.39902496, 23.67597198], [68.39902496, 23.67513847], [68.39875031, 23.67514038], [68.39875031, 23.6740303], [68.39848328, 23.6740303], [68.39848328, 23.67319107], [68.39819336, 23.67319489], [68.39819336, 23.6720829], [68.3979187, 23.6720829], [68.3979187, 23.67152786], [68.39763641, 23.67152977], [68.39763641, 23.67097092], [68.39736176, 23.67097282], [68.39736176, 23.67069435], [68.3970871, 23.67069435], [68.3970871, 23.67041588], [68.39679718, 23.6704216], [68.39679718, 23.66986084], [68.39653015, 23.66986084], [68.39653015, 23.66931152], [68.39624786, 23.66931152], [68.39624786, 23.66875076], [68.39597321, 23.66875076], [68.39597321, 23.66791916], [68.39569092, 23.66791916], [68.39569092, 23.66736031], [68.39541626, 23.66736031], [68.39541626, 23.66680908], [68.3951416, 23.66680908], [68.3951416, 23.66625023], [68.39541626, 23.66625023], [68.39541626, 23.66596985], [68.39569092, 23.66597176], [68.39569092, 23.66430664], [68.3951416, 23.66430664], [68.3951416, 23.66319656], [68.39485931, 23.66319656], [68.39485931, 23.66291428], [68.39428711, 23.66292], [68.39428711, 23.66236115], [68.39457703, 23.66236115], [68.39457703, 23.66152954], [68.39428711, 23.66152954], [68.39428711, 23.66125107], [68.39402771, 23.66125107], [68.39402771, 23.66096115], [68.39375305, 23.6609745], [68.39375305, 23.66069221], [68.39319611, 23.66069221], [68.39319611, 23.66041756], [68.39290619, 23.66041946], [68.39290619, 23.6601429], [68.39263916, 23.6601429], [68.39263916, 23.65986061], [68.39235687, 23.65986061], [68.39235687, 23.6601429], [68.39097595, 23.6601429], [68.39097595, 23.65847015], [68.39069366, 23.65847015], [68.39069366, 23.65791702], [68.39041901, 23.65792274], [68.39041901, 23.6570816], [68.39069366, 23.65708351], [68.39069366, 23.65486145], [68.39041901, 23.65486145], [68.39041901, 23.65430641], [68.39013672, 23.65430832], [68.39013672, 23.65402985], [68.38986206, 23.65402985], [68.38986206, 23.65374947], [68.38957977, 23.65374947], [68.38957977, 23.65347099], [68.38930511, 23.6534729], [68.38930511, 23.65319443], [68.38903046, 23.65319443], [68.38903046, 23.65291786], [68.38874817, 23.65291977], [68.38874817, 23.65236092], [68.38847351, 23.65236092], [68.38847351, 23.65208244], [68.38819122, 23.65208817], [68.38819122, 23.65180969], [68.38791656, 23.65180969], [68.38791656, 23.65153122], [68.38764191, 23.65153122], [68.38764191, 23.65125084], [68.38735962, 23.65125084], [68.38735962, 23.65069008], [68.38708496, 23.6506958], [68.38708496, 23.65041733], [68.38680267, 23.65042114], [68.38680267, 23.65014076], [68.38652802, 23.65014076], [68.38652802, 23.64986038], [68.38625336, 23.64986038], [68.38625336, 23.64958], [68.38597107, 23.64958572], [68.38597107, 23.64930344], [68.38569641, 23.64931107], [68.38569641, 23.64875031], [68.38540649, 23.64875031], [68.38540649, 23.64846992], [68.38513947, 23.64847183], [68.38513947, 23.64819336], [68.38485718, 23.64820099], [68.38485718, 23.64764023], [68.38458252, 23.64764023], [68.38458252, 23.64707947], [68.38430786, 23.64708138], [68.38430786, 23.64652824], [68.3840332, 23.64653015], [68.3840332, 23.64624977], [68.38375092, 23.64624977], [68.38375092, 23.64596176], [68.38346863, 23.6459713], [68.38346863, 23.64569473], [68.38291931, 23.64569473], [68.38291931, 23.64541626], [68.38263702, 23.64542007], [68.38263702, 23.64513969], [68.38234711, 23.64513969], [68.38234711, 23.64486122], [68.38208008, 23.64486122], [68.38208008, 23.64458275], [68.38153076, 23.64458275], [68.38153076, 23.64430618], [68.38124847, 23.6443119], [68.38124847, 23.64402962], [68.38041687, 23.64402962], [68.38041687, 23.64374924], [68.37960052, 23.64374924], [68.37960052, 23.64347076], [68.37875366, 23.64347267], [68.37875366, 23.6431942], [68.37791443, 23.6431942], [68.37791443, 23.64291573], [68.37652588, 23.64291573], [68.37652588, 23.6431942], [68.37541962, 23.64318848], [68.37541962, 23.6443119], [68.37569427, 23.64430618], [68.37569427, 23.64708138], [68.37596893, 23.64707947], [68.37596893, 23.64820099], [68.37625122, 23.64819336], [68.37625122, 23.64902687], [68.37652588, 23.64902687], [68.37652588, 23.6506958], [68.37680817, 23.65069008], [68.37680817, 23.65153122], [68.37708282, 23.65153122], [68.37708282, 23.65180969], [68.37735748, 23.65180969], [68.37735748, 23.65236092], [68.37763977, 23.65236092], [68.37763977, 23.65263939], [68.37791443, 23.65263939], [68.37791443, 23.65319443], [68.37819672, 23.65319443], [68.37819672, 23.6534729], [68.37847137, 23.65347099], [68.37847137, 23.65402985], [68.37874603, 23.65402985], [68.37874603, 23.65430832], [68.37902832, 23.65430641], [68.37902832, 23.65458298], [68.37928772, 23.65458107], [68.37928772, 23.65514946], [68.37960052, 23.65514946], [68.37960052, 23.6554184], [68.37985992, 23.65541649], [68.37985992, 23.65597153], [68.38014221, 23.65596962], [68.38014221, 23.65653038], [68.38041687, 23.65653038], [68.38041687, 23.65681267], [68.38069153, 23.65681267], [68.38069153, 23.65764046], [68.38096619, 23.65764046], [68.38096619, 23.65792274], [68.38124847, 23.65791702], [68.38124847, 23.65847015], [68.38153076, 23.65847015], [68.38153076, 23.65903282], [68.38181305, 23.65903282], [68.38181305, 23.65930939], [68.38208008, 23.65930939], [68.38208008, 23.65986061], [68.38234711, 23.65986061], [68.38234711, 23.66041946], [68.38263702, 23.66041756], [68.38263702, 23.6609745], [68.38291931, 23.66096115], [68.38291931, 23.66152954], [68.38319397, 23.66152763], [68.38319397, 23.66208267], [68.38346863, 23.66208267], [68.38346863, 23.66319656], [68.38375092, 23.66319084], [68.38375092, 23.66374969], [68.38402557, 23.66374969], [68.38402557, 23.66430664], [68.38430786, 23.66430664], [68.38430786, 23.66486168], [68.38458252, 23.66485977], [68.38458252, 23.66570091], [68.38485718, 23.66570091], [68.38485718, 23.66625023], [68.38513947, 23.66625023], [68.38513947, 23.66653061], [68.38540649, 23.66653061], [68.38540649, 23.66708755], [68.38569641, 23.66708755], [68.38569641, 23.66764069], [68.38597107, 23.66764069], [68.38597107, 23.66875076], [68.38625336, 23.66875076], [68.38625336, 23.66958427], [68.38652802, 23.66958427], [68.38652802, 23.67013931], [68.38625336, 23.67012978], [68.38625336, 23.67124939], [68.38652802, 23.67124939], [68.38652802, 23.67236137], [68.38680267, 23.67235947], [68.38680267, 23.67374992], [68.38709259, 23.67374992], [68.38709259, 23.67542076], [68.38735962, 23.67541695], [68.38735962, 23.67597198], [68.38764191, 23.67597008], [68.38764191, 23.67653084], [68.38791656, 23.67652512], [68.38791656, 23.67708588], [68.38819122, 23.67708588], [68.38819122, 23.67819595], [68.38848114, 23.67819023], [68.38848114, 23.67931747], [68.38874817, 23.67931747], [68.38874817, 23.68041992], [68.38903046, 23.68041611], [68.38903046, 23.6823616], [68.38930511, 23.6823616], [68.38930511, 23.68347168], [68.38957977, 23.68347168], [68.38957977, 23.68403244], [68.38986206, 23.68403244], [68.38986206, 23.68486023], [68.39013672, 23.68486023], [68.39013672, 23.68569374], [68.38986206, 23.68569374], [68.38986206, 23.68597221], [68.38957977, 23.68597221], [68.38957977, 23.68569374], [68.38930511, 23.68569374], [68.38930511, 23.6851387], [68.38903046, 23.6851387], [68.38903046, 23.68430519], [68.38874817, 23.68431282], [68.38874817, 23.68375015], [68.38847351, 23.68375015], [68.38847351, 23.6823616], [68.38819122, 23.6823616], [68.38819122, 23.68041611], [68.38791656, 23.68041992], [68.38791656, 23.67931747], [68.38764191, 23.67931747], [68.38764191, 23.67819023], [68.38735962, 23.67819595], [68.38735962, 23.67708588], [68.38708496, 23.67708588], [68.38708496, 23.67652512], [68.38680267, 23.67653084], [68.38680267, 23.67597008], [68.38652802, 23.67597198], [68.38652802, 23.67541695], [68.38625336, 23.67542076], [68.38625336, 23.67374992], [68.38597107, 23.67374992], [68.38597107, 23.67235947], [68.38569641, 23.67236137], [68.38569641, 23.67124939], [68.38540649, 23.67124939], [68.38540649, 23.67012978], [68.38513947, 23.67013931], [68.38513947, 23.6693058], [68.38485718, 23.66931152], [68.38485718, 23.66847038], [68.38458252, 23.66847229], [68.38458252, 23.66791725], [68.38430786, 23.66791916], [68.38430786, 23.66736031], [68.38402557, 23.66736031], [68.38402557, 23.66569519], [68.38375092, 23.66570091], [68.38375092, 23.66542053], [68.38346863, 23.66542053], [68.38346863, 23.66457939], [68.38319397, 23.66458321], [68.38319397, 23.66430664], [68.38291931, 23.66430664], [68.38291931, 23.66347313], [68.38263702, 23.66347313], [68.38263702, 23.66263962], [68.38234711, 23.66263962], [68.38234711, 23.66180992], [68.38208008, 23.66180992], [68.38208008, 23.66125107], [68.38181305, 23.66125107], [68.38181305, 23.66069031], [68.38153076, 23.66069221], [68.38153076, 23.66013908], [68.38124847, 23.6601429], [68.38124847, 23.65958023], [68.38097382, 23.65958214], [68.38097382, 23.65930557], [68.38069153, 23.65930939], [68.38069153, 23.65847015], [68.38041687, 23.65847015], [68.38041687, 23.65819359], [68.38014221, 23.65819359], [68.38014221, 23.65763855], [68.37985992, 23.65764046], [68.37985992, 23.65681267], [68.37960052, 23.65681267], [68.37960052, 23.65653038], [68.37928772, 23.65653038], [68.37928772, 23.65596962], [68.37902832, 23.65597153], [68.37902832, 23.65541649], [68.37874603, 23.6554184], [68.37874603, 23.65514946], [68.37847137, 23.65514946], [68.37847137, 23.65485954], [68.37819672, 23.65486145], [68.37819672, 23.65430641], [68.3779068, 23.65430832], [68.3779068, 23.65402985], [68.37763977, 23.65402985], [68.37763977, 23.65347099], [68.37735748, 23.6534729], [68.37735748, 23.65319443], [68.37708282, 23.65319443], [68.37708282, 23.65263939], [68.37680817, 23.65263939], [68.37680817, 23.65236092], [68.37652588, 23.65236092], [68.37652588, 23.65208244], [68.37625122, 23.65208817], [68.37625122, 23.65153122], [68.37596893, 23.65153122], [68.37596893, 23.65069008], [68.37569427, 23.6506958], [68.37569427, 23.64902687], [68.37541962, 23.64902687], [68.37541962, 23.64819336], [68.37513733, 23.64820099], [68.37513733, 23.64707947], [68.37486267, 23.64708138], [68.37486267, 23.64430618], [68.37458038, 23.6443119], [68.37458038, 23.64181137], [68.37486267, 23.64181137], [68.37486267, 23.64014816], [68.37458038, 23.64014816], [68.37458038, 23.63931084], [68.37403107, 23.63931084], [68.37403107, 23.63903046], [68.37346649, 23.63903046], [68.37346649, 23.63875008], [68.37291718, 23.63875008], [68.37291718, 23.63735962], [68.37264252, 23.63736153], [68.37264252, 23.63680649], [68.37236023, 23.63680077], [68.37236023, 23.63624954], [68.37208557, 23.63624954], [68.37208557, 23.63569641], [68.37180328, 23.63569641], [68.37180328, 23.63513947], [68.37152863, 23.63513947], [68.37152863, 23.63486099], [68.37124634, 23.63486099], [68.37124634, 23.63458061], [68.37097168, 23.63458252], [68.37097168, 23.63430405], [68.37069702, 23.63430977], [68.37069702, 23.63401985], [68.37041473, 23.63402748], [68.37041473, 23.63375282], [68.36985779, 23.63375282], [68.36985779, 23.63347054], [68.36930847, 23.63347244], [68.36930847, 23.63319206], [68.36875153, 23.63319206], [68.36875153, 23.6329174], [68.36818695, 23.63292122], [68.36818695, 23.63264275], [68.36763763, 23.63264275], [68.36763763, 23.63236046], [68.36708069, 23.63236046], [68.36708069, 23.63125038], [68.36680603, 23.63125038], [68.36680603, 23.63097954], [68.36624908, 23.63097954], [68.36624908, 23.63070107], [68.36569214, 23.63070107], [68.36569214, 23.63042259], [68.36514282, 23.63042259], [68.36514282, 23.6301403], [68.36460114, 23.6301403], [68.36460114, 23.62986183], [68.36402893, 23.62986183], [68.36402893, 23.62958336], [68.36347198, 23.62958336], [68.36347198, 23.62930489], [68.36208344, 23.62930489], [68.36208344, 23.62847137], [68.36180878, 23.62847137], [68.36180878, 23.62791634], [68.36152649, 23.62791824], [68.36152649, 23.62763977], [68.36096954, 23.62763977], [68.36096954, 23.62735939], [68.36069489, 23.6273613], [68.36069489, 23.62708282], [68.35986328, 23.62708282], [68.35986328, 23.6273613], [68.35958099, 23.62735939], [68.35958099, 23.62763977], [68.35874939, 23.62763977], [68.35874939, 23.62708092], [68.35847473, 23.62708282], [68.35847473, 23.62624931], [68.35817719, 23.62625122], [68.35817719, 23.62430954], [68.35791779, 23.62430954], [68.35791779, 23.62375069], [68.3576355, 23.62375069], [68.3576355, 23.62347221], [68.35736084, 23.62347221], [68.35736084, 23.62291527], [68.35708618, 23.62292099], [68.35708618, 23.62264061], [68.35679626, 23.62264061], [68.35679626, 23.62207985], [68.35652924, 23.62208557], [68.35652924, 23.62152863], [68.35320282, 23.62153053], [68.35320282, 23.61681175], [68.35041809, 23.61681175], [68.35041809, 23.61652946], [68.34986115, 23.61652946], [68.34986115, 23.61624908], [68.34819794, 23.61624908], [68.34819794, 23.61598015], [68.34792328, 23.61598015], [68.34792328, 23.61486053], [68.34819794, 23.61486053], [68.34819794, 23.61457825], [68.3484726, 23.61458397], [68.3484726, 23.6143055], [68.34874725, 23.61430931], [68.34874725, 23.61375046], [68.34902954, 23.61375046], [68.34902954, 23.61292076], [68.34931183, 23.61292076], [68.34931183, 23.61207962], [68.34958649, 23.61208344], [68.34958649, 23.61097145], [68.34986115, 23.61097145], [68.34986115, 23.61041451], [68.3501358, 23.61042023], [68.3501358, 23.61013985], [68.35041809, 23.61013985], [68.35041809, 23.60958099], [68.35069275, 23.60958481], [68.35069275, 23.60930634], [68.35098267, 23.60931015], [68.35098267, 23.60847092], [68.35124969, 23.60847473], [68.35124969, 23.60486031], [68.35097504, 23.60486031], [68.35097504, 23.60430527], [68.35069275, 23.6043129], [68.35069275, 23.60375023], [68.35041809, 23.60375023], [68.35041809, 23.60320282], [68.3501358, 23.60320282], [68.3501358, 23.60292244], [68.34986115, 23.60292244], [68.34986115, 23.60263824], [68.34958649, 23.60263824], [68.34958649, 23.60235977], [68.34902954, 23.60236168], [68.34902954, 23.60208321], [68.34874725, 23.60208321], [68.34874725, 23.60152817], [68.3484726, 23.60152817], [68.3484726, 23.60098076], [68.34819794, 23.60098076], [68.34819794, 23.60069084], [68.34791565, 23.60069466], [68.34791565, 23.60013962], [68.34764099, 23.60013962], [68.34764099, 23.59958076], [68.3473587, 23.59958267], [68.3473587, 23.59930611], [68.34707642, 23.59930992], [68.34707642, 23.59875107], [68.34680939, 23.59875107], [68.34680176, 23.59819031], [68.3465271, 23.59819412], [68.3465271, 23.59791756], [68.34625244, 23.59791756], [68.34625244, 23.59763908], [68.34570313, 23.59764099], [68.34570313, 23.59736061], [68.34541321, 23.59736061], [68.34541321, 23.59708023], [68.34486389, 23.59708595], [68.34486389, 23.59680367], [68.34430695, 23.59680939], [68.34430695, 23.59653091], [68.34401703, 23.59653091], [68.34401703, 23.59625053], [68.34347534, 23.59625053], [68.34347534, 23.59597206], [68.3429184, 23.59597206], [68.3429184, 23.5956955], [68.3418045, 23.5956955], [68.3418045, 23.59541512], [68.34069824, 23.59542084], [68.34069824, 23.59514046], [68.33957672, 23.59514046], [68.33957672, 23.59485054], [68.33930206, 23.59486389], [68.33930206, 23.59430313], [68.3390274, 23.59431076], [68.3390274, 23.59403038], [68.33847046, 23.59403038], [68.33847046, 23.59375], [68.33763885, 23.59375], [68.33763885, 23.59346962], [68.33708191, 23.59347153], [68.33708191, 23.59319305], [68.33625031, 23.59320068], [68.33625031, 23.5929203], [68.33569336, 23.5929203], [68.33569336, 23.59263992], [68.3354187, 23.59263992], [68.3354187, 23.59208107], [68.33569336, 23.59208107], [68.33569336, 23.59180641], [68.33429718, 23.59181023], [68.33429718, 23.59153175], [68.33374786, 23.59153175], [68.33374786, 23.59124947], [68.33291626, 23.59124947], [68.33291626, 23.59096909], [68.33235931, 23.5909729], [68.33235931, 23.59041595], [68.33207703, 23.59042168], [68.33207703, 23.58986092], [68.33180237, 23.58986092], [68.33180237, 23.58958054], [68.33125305, 23.58958244], [68.33125305, 23.58930588], [68.33040619, 23.5893116], [68.33040619, 23.58902931], [68.32736206, 23.58902931], [68.32736206, 23.5893116], [68.32596588, 23.5893116], [68.32596588, 23.58902931], [68.32569122, 23.58902931], [68.32569122, 23.58818817], [68.32402802, 23.58819389], [68.32402802, 23.58847237], [68.32319641, 23.58847046], [68.32319641, 23.58875084], [68.32263947, 23.58875084], [68.32263947, 23.58902931], [68.31819153, 23.58902931], [68.31819153, 23.5893116], [68.31597137, 23.58930588], [68.31597137, 23.58958244], [68.3154068, 23.58958054], [68.3154068, 23.58986092], [68.31458282, 23.58986092], [68.31458282, 23.58875084], [68.31430817, 23.58875084], [68.31430817, 23.58764076], [68.3154068, 23.58764076], [68.3154068, 23.58736038], [68.31569672, 23.58736038], [68.31569672, 23.58707809], [68.31597137, 23.58708382], [68.31597137, 23.58652878], [68.31626129, 23.58653069], [68.31626129, 23.58596992], [68.31652832, 23.58597183], [68.31652832, 23.5854187], [68.31680298, 23.58542061], [68.31680298, 23.58514023], [68.3170929, 23.58514023], [68.3170929, 23.58403015], [68.31626129, 23.58403015], [68.31626129, 23.58374977], [68.31569672, 23.58374977], [68.31569672, 23.58346939], [68.31485748, 23.5834713], [68.31485748, 23.58319664], [68.31346893, 23.58319664], [68.31346893, 23.5834713]]], [[[68.43736267, 23.50041962], [68.43736267, 23.50014114], [68.43791962, 23.50014114], [68.43791962, 23.49986076], [68.43818665, 23.49986076], [68.43818665, 23.49958038], [68.43930817, 23.49958229], [68.43930817, 23.49930573], [68.43959045, 23.49930954], [68.43959045, 23.49875069], [68.43930817, 23.49875069], [68.43930817, 23.49846077], [68.43846893, 23.49846077], [68.43846893, 23.49875069], [68.43791962, 23.49875069], [68.43791962, 23.49903107], [68.43736267, 23.49903107], [68.43736267, 23.49930954], [68.43708038, 23.49930573], [68.43708038, 23.49958229], [68.43682098, 23.49958038], [68.43682098, 23.50014114], [68.43708038, 23.50014114], [68.43708038, 23.50041962], [68.43736267, 23.50041962]]], [[[68.4679184, 23.52403259], [68.4679184, 23.5232029], [68.46819305, 23.5232029], [68.46819305, 23.52292252], [68.46848297, 23.52292252], [68.46848297, 23.52263069], [68.46875, 23.52263832], [68.46875, 23.52208328], [68.46902466, 23.52208328], [68.46902466, 23.52180481], [68.46930695, 23.52180481], [68.46930695, 23.52152824], [68.47041321, 23.52152824], [68.47041321, 23.52124977], [68.47070313, 23.52124977], [68.4706955, 23.52041626], [68.47041321, 23.52041817], [68.47041321, 23.51875114], [68.47013855, 23.51875114], [68.47013855, 23.51819038], [68.46986389, 23.5181942], [68.46986389, 23.51791763], [68.4695816, 23.51791763], [68.4695816, 23.51847267], [68.46930695, 23.51847076], [68.46930695, 23.51875114], [68.46901703, 23.51875114], [68.46901703, 23.51902962], [68.46848297, 23.51902962], [68.46848297, 23.51875114], [68.46819305, 23.51875114], [68.46819305, 23.51819038], [68.4679184, 23.5181942], [68.4679184, 23.51763916], [68.46736145, 23.51763916], [68.46736145, 23.51847267], [68.46763611, 23.51847076], [68.46763611, 23.51902962], [68.4679184, 23.51902962], [68.4679184, 23.51930809], [68.46819305, 23.51930618], [68.46819305, 23.51958275], [68.46847534, 23.51958275], [68.46848297, 23.51986122], [68.46763611, 23.51986122], [68.46763611, 23.5195694], [68.4668045, 23.51958275], [68.4668045, 23.51930618], [68.46652985, 23.51930809], [68.46652985, 23.51875114], [68.46624756, 23.51875114], [68.46624756, 23.51819038], [68.4659729, 23.5181942], [68.4659729, 23.51625061], [68.4651413, 23.51625061], [68.4651413, 23.51597023], [68.4651413, 23.5154171], [68.46430206, 23.5154171], [68.46430206, 23.51569557], [68.4640274, 23.51569557], [68.4640274, 23.51597214], [68.46375275, 23.51597214], [68.46376038, 23.51625061], [68.46347046, 23.51625061], [68.46347046, 23.5168705], [68.46347046, 23.51764107], [68.4631958, 23.51764107], [68.4631958, 23.51875114], [68.46376038, 23.51875114], [68.46376038, 23.51847076], [68.4640274, 23.51847267], [68.4640274, 23.5181942], [68.46458435, 23.5181942], [68.46458435, 23.51847267], [68.46485901, 23.51847076], [68.46485901, 23.51875114], [68.4651413, 23.51874924], [68.4651413, 23.51958275], [68.46541595, 23.5195694], [68.46541595, 23.52013969], [68.46569061, 23.52013969], [68.46569824, 23.52041817], [68.4659729, 23.52041626], [68.4659729, 23.52069473], [68.46624756, 23.52069092], [68.46624756, 23.52152824], [68.46652985, 23.52152824], [68.46652985, 23.52263832], [68.46624756, 23.52263069], [68.46624756, 23.52292252], [68.46652985, 23.52291679], [68.46652985, 23.52347183], [68.46708679, 23.52347183], [68.46708679, 23.52375031], [68.46736145, 23.52375031], [68.46736145, 23.52403259], [68.4679184, 23.52403259]]], [[[68.45847321, 23.60041809], [68.45847321, 23.60013962], [68.46153259, 23.60013962], [68.46152496, 23.59986115], [68.46291351, 23.59986115], [68.46290588, 23.59958076], [68.46347046, 23.59958267], [68.46347046, 23.59930611], [68.46430206, 23.59930992], [68.46430206, 23.59902954], [68.46485901, 23.59902954], [68.46485901, 23.59875107], [68.4651413, 23.59875107], [68.4651413, 23.59847069], [68.46569824, 23.5984726], [68.46569824, 23.59819412], [68.4659729, 23.59819412], [68.4659729, 23.59763908], [68.46624756, 23.59764099], [68.46624756, 23.59542084], [68.46652985, 23.59542084], [68.46652985, 23.59320068], [68.46679688, 23.59320068], [68.46679688, 23.5929203], [68.46708679, 23.5929203], [68.46708679, 23.59263992], [68.46736145, 23.59263992], [68.46736145, 23.59208107], [68.46763611, 23.59208107], [68.46763611, 23.59180641], [68.46736145, 23.59181023], [68.46736145, 23.59153175], [68.46708679, 23.59153175], [68.46708679, 23.59096909], [68.4668045, 23.5909729], [68.4668045, 23.59041595], [68.46652985, 23.59042168], [68.46652985, 23.58986092], [68.46624756, 23.58986092], [68.46624756, 23.58958054], [68.4659729, 23.58958244], [68.4659729, 23.5890274], [68.46569824, 23.58902931], [68.46569824, 23.58875084], [68.46541595, 23.58875084], [68.46541595, 23.58818817], [68.4651413, 23.58819389], [68.4651413, 23.58763885], [68.46485901, 23.58764076], [68.46485901, 23.58707809], [68.46458435, 23.58708382], [68.46458435, 23.58652878], [68.46430206, 23.58653069], [68.46430206, 23.58596992], [68.46375275, 23.58597183], [68.46375275, 23.58569527], [68.46347046, 23.58569908], [68.46347046, 23.58542061], [68.4631958, 23.58542061], [68.4631958, 23.58514023], [68.46290588, 23.58514023], [68.46290588, 23.58485985], [68.46263885, 23.58486176], [68.46263885, 23.58458328], [68.4623642, 23.58458328], [68.4623642, 23.58402824], [68.46208191, 23.58403015], [68.46208191, 23.58374977], [68.46180725, 23.58374977], [68.46180725, 23.58346939], [68.46152496, 23.5834713], [68.46152496, 23.58208466], [68.46125031, 23.58208466], [68.46125031, 23.58152771], [68.46153259, 23.58152962], [68.46153259, 23.57958031], [68.46180725, 23.57958221], [68.46180725, 23.57930565], [68.46208191, 23.57930946], [68.46208191, 23.5790329], [68.46235657, 23.5790329], [68.46235657, 23.57847023], [68.46263885, 23.57847023], [68.46263885, 23.5779171], [68.46235657, 23.57792282], [68.46235657, 23.57736015], [68.46208191, 23.57736015], [68.46208191, 23.57681274], [68.46180725, 23.57681274], [68.46180725, 23.57653236], [68.46125031, 23.57653236], [68.46125031, 23.57625008], [68.46069336, 23.57625008], [68.46069336, 23.5759716], [68.45930481, 23.5759716], [68.45930481, 23.57569504], [68.45847321, 23.57570076], [68.45847321, 23.57541847], [68.45735931, 23.57541847], [68.45735931, 23.57513809], [68.45652771, 23.57513809], [68.45652771, 23.57485962], [68.45541382, 23.57486153], [68.45541382, 23.57458305], [68.45402527, 23.57458305], [68.45402527, 23.57486153], [68.45318604, 23.57485962], [68.45318604, 23.57513809], [68.45236206, 23.57513809], [68.45236206, 23.57541847], [68.45182037, 23.57541847], [68.45182037, 23.5743084], [68.45207977, 23.5743084], [68.45207977, 23.57374001], [68.45236206, 23.57374954], [68.45236206, 23.5731945], [68.45124817, 23.5731945], [68.45124817, 23.57347298], [68.45041656, 23.57347298], [68.45041656, 23.57374954], [68.44985962, 23.57374001], [68.44985962, 23.57402992], [68.44902802, 23.57402992], [68.44902802, 23.57430077], [68.44819641, 23.57430649], [68.44819641, 23.57458305], [68.44791412, 23.57458305], [68.44791412, 23.57486153], [68.44735718, 23.57485962], [68.44735718, 23.57513809], [68.44708252, 23.57513809], [68.44708252, 23.57541847], [68.44680786, 23.57541847], [68.44680786, 23.57570076], [68.44625092, 23.57569504], [68.44625092, 23.5759716], [68.44596863, 23.5759697], [68.44596863, 23.57625008], [68.44541931, 23.57625008], [68.44541931, 23.57653236], [68.44513702, 23.57653236], [68.44513702, 23.57681274], [68.44486237, 23.57681274], [68.44486237, 23.57736015], [68.44458008, 23.57736015], [68.44458008, 23.57764053], [68.44430542, 23.57763863], [68.44430542, 23.57819366], [68.44458008, 23.57819176], [68.44458008, 23.57875061], [68.44486237, 23.57875061], [68.44486237, 23.57930946], [68.44541931, 23.57930565], [68.44541931, 23.57958221], [68.44568634, 23.57958031], [68.44568634, 23.58041954], [68.44625092, 23.58041763], [68.44625092, 23.58069229], [68.44680786, 23.58069229], [68.44680786, 23.58097458], [68.44708252, 23.58097458], [68.44708252, 23.58069229], [68.44763947, 23.58069229], [68.44763947, 23.58013916], [68.44957733, 23.58014107], [68.44957733, 23.57958031], [68.44985962, 23.57958221], [68.44985962, 23.57902718], [68.45014191, 23.5790329], [68.45014191, 23.57764053], [68.45041656, 23.57764053], [68.45041656, 23.57708168], [68.45124817, 23.57708359], [68.45124817, 23.57736015], [68.45207977, 23.57736015], [68.45207977, 23.57764053], [68.45291901, 23.57764053], [68.45291901, 23.57792282], [68.45319366, 23.5779171], [68.45319366, 23.57847023], [68.45347595, 23.57847023], [68.45347595, 23.5790329], [68.45375061, 23.5790329], [68.45375061, 23.57987022], [68.4540329, 23.57987022], [68.4540329, 23.58041954], [68.45430756, 23.58041763], [68.45430756, 23.58097458], [68.45456696, 23.58097076], [68.45456696, 23.58125114], [68.45485687, 23.58125114], [68.45485687, 23.58181], [68.45513916, 23.58181], [68.45513916, 23.58236122], [68.45541382, 23.58236122], [68.45541382, 23.5834713], [68.45597076, 23.58346939], [68.45597076, 23.58374977], [68.45625305, 23.58374977], [68.45625305, 23.58486176], [68.45652771, 23.58485985], [68.45652771, 23.58625031], [68.45680237, 23.58625031], [68.45680237, 23.58708382], [68.45707703, 23.58707809], [68.45707703, 23.58764076], [68.45680237, 23.58764076], [68.45680237, 23.58791924], [68.45513916, 23.58791733], [68.45513916, 23.58847237], [68.45375061, 23.58847237], [68.45375061, 23.58819389], [68.45291901, 23.58819389], [68.45291901, 23.58847237], [68.45263672, 23.58847237], [68.45263672, 23.5909729], [68.45291901, 23.59096909], [68.45291901, 23.59153175], [68.45319366, 23.59152794], [68.45319366, 23.59208107], [68.45291901, 23.59208107], [68.45291901, 23.59236145], [68.45263672, 23.59235954], [68.45263672, 23.59263992], [68.45236206, 23.59263992], [68.45236206, 23.59320068], [68.45263672, 23.59320068], [68.45263672, 23.59431076], [68.45236206, 23.59431076], [68.45236206, 23.59542084], [68.45263672, 23.59541512], [68.45263672, 23.59597206], [68.45291901, 23.59597015], [68.45291901, 23.59625053], [68.45318604, 23.59625053], [68.45318604, 23.59680939], [68.45347595, 23.59680367], [68.45347595, 23.59791756], [68.45375061, 23.59790993], [68.45375061, 23.59875107], [68.4540329, 23.59875107], [68.4540329, 23.59930992], [68.45430756, 23.59930611], [68.45430756, 23.59958267], [68.45485687, 23.59958076], [68.45485687, 23.59986115], [68.45513916, 23.59986115], [68.45513916, 23.60013962], [68.45569611, 23.60013962], [68.45569611, 23.60041809], [68.45847321, 23.60041809]]], [[[68.45625305, 23.62486076], [68.45625305, 23.62458038], [68.45708466, 23.6245842], [68.45708466, 23.62430763], [68.45819092, 23.62430954], [68.45819092, 23.62403107], [68.45874786, 23.62403107], [68.45874786, 23.62375069], [68.46180725, 23.62375069], [68.46180725, 23.62347031], [68.4623642, 23.62347221], [68.4623642, 23.62319565], [68.4631958, 23.62319565], [68.4631958, 23.62291527], [68.46485901, 23.62292099], [68.46485901, 23.62264061], [68.4651413, 23.62264061], [68.4651413, 23.62236023], [68.46541595, 23.62236023], [68.46541595, 23.62181091], [68.46569824, 23.62181091], [68.46569824, 23.62153053], [68.4659729, 23.62153053], [68.4659729, 23.62070084], [68.46624756, 23.62070084], [68.46624756, 23.61958122], [68.46652985, 23.61958122], [68.46652985, 23.61847115], [68.4668045, 23.61847115], [68.4668045, 23.6170826], [68.46652985, 23.6170826], [68.46652985, 23.61597252], [68.46624756, 23.61598015], [68.46624756, 23.61540031], [68.46624756, 23.6143055], [68.4659729, 23.61430931], [68.4659729, 23.61264038], [68.46569824, 23.61264038], [68.46569824, 23.60736084], [68.4659729, 23.60736084], [68.4659729, 23.60542107], [68.46624756, 23.60542107], [68.46624756, 23.60375023], [68.46652985, 23.60375023], [68.46652985, 23.60207748], [68.46624756, 23.60208321], [68.46624756, 23.60124969], [68.46652985, 23.60124969], [68.46652985, 23.60098076], [68.46569824, 23.60098076], [68.46569061, 23.60152817], [68.46375275, 23.60152817], [68.46375275, 23.60180473], [68.46291351, 23.60180473], [68.46291351, 23.60208321], [68.4623642, 23.60208321], [68.4623642, 23.60236168], [68.46180725, 23.60235977], [68.46180725, 23.60263824], [68.46153259, 23.60263824], [68.46153259, 23.60292244], [68.46098328, 23.60292244], [68.46098328, 23.60320282], [68.4604187, 23.60319519], [68.4604187, 23.60347176], [68.45986176, 23.60347176], [68.45986176, 23.60375023], [68.45929718, 23.60375023], [68.45929718, 23.60404015], [68.45874786, 23.60404015], [68.45874786, 23.6043129], [68.45762634, 23.6043129], [68.45762634, 23.60404015], [68.45735931, 23.60404015], [68.45735931, 23.60375023], [68.45680237, 23.60375023], [68.45680237, 23.60404015], [68.45625305, 23.60404015], [68.45625305, 23.6043129], [68.45485687, 23.6043129], [68.45485687, 23.60404015], [68.45430756, 23.60404015], [68.45430756, 23.60375023], [68.45375061, 23.60375023], [68.45375061, 23.60347176], [68.45319366, 23.60347176], [68.45319366, 23.60319519], [68.45263672, 23.60320282], [68.45263672, 23.60292244], [68.45182037, 23.60292244], [68.45182037, 23.60263824], [68.45153046, 23.60263824], [68.45153046, 23.60235977], [68.45124817, 23.60236168], [68.45124817, 23.60208321], [68.45069122, 23.60208321], [68.45069122, 23.60180473], [68.45014191, 23.60180473], [68.45014191, 23.60152817], [68.44957733, 23.60152817], [68.44957733, 23.60124969], [68.44930267, 23.60124969], [68.44930267, 23.60069084], [68.44875336, 23.60069466], [68.44875336, 23.60041618], [68.44847107, 23.60041809], [68.44847107, 23.59986115], [68.44819641, 23.59986115], [68.44819641, 23.59902954], [68.44790649, 23.59902954], [68.44790649, 23.59847069], [68.44763947, 23.5984726], [68.44763947, 23.59736061], [68.44735718, 23.59736061], [68.44735718, 23.59625053], [68.44708252, 23.59625053], [68.44708252, 23.59514046], [68.44680786, 23.59514046], [68.44680786, 23.59431076], [68.4465332, 23.59431076], [68.4465332, 23.59320068], [68.44625092, 23.59320068], [68.44625092, 23.59153175], [68.44596863, 23.59153175], [68.44596863, 23.59069061], [68.44569397, 23.59069443], [68.44569397, 23.59041595], [68.44513702, 23.59042168], [68.44513702, 23.59013939], [68.44458008, 23.59013939], [68.44458008, 23.58958054], [68.44513702, 23.58958244], [68.44513702, 23.58930588], [68.44541931, 23.5893116], [68.44541931, 23.58902931], [68.44568634, 23.58902931], [68.44568634, 23.58847046], [68.44235992, 23.58847237], [68.44235992, 23.58819389], [68.44180298, 23.58819389], [68.44180298, 23.58791733], [68.44124603, 23.58791924], [68.44124603, 23.58653069], [68.4404068, 23.58653069], [68.4404068, 23.58680916], [68.44013977, 23.58680916], [68.44013977, 23.58736038], [68.43985748, 23.58736038], [68.43985748, 23.58791924], [68.43958282, 23.58791733], [68.43958282, 23.58819389], [68.44041443, 23.58819389], [68.44041443, 23.58847237], [68.44013977, 23.58847046], [68.44013977, 23.58902931], [68.43846893, 23.58902931], [68.43846893, 23.5893116], [68.43875122, 23.5893116], [68.43875122, 23.59013939], [68.43902588, 23.59013939], [68.43902588, 23.59236145], [68.43930817, 23.59235954], [68.43930817, 23.59263992], [68.43985748, 23.59263992], [68.43985748, 23.5929203], [68.44013977, 23.59291649], [68.44013977, 23.59347153], [68.4404068, 23.59346962], [68.4404068, 23.59403038], [68.44069672, 23.59402847], [68.44069672, 23.59486389], [68.44097137, 23.59485054], [68.44097137, 23.59542084], [68.44125366, 23.59541512], [68.44125366, 23.59708595], [68.44152832, 23.59708023], [68.44152832, 23.59764099], [68.44125366, 23.59763908], [68.44125366, 23.5984726], [68.44152832, 23.59847069], [68.44152832, 23.59930992], [68.44125366, 23.59930611], [68.44125366, 23.59958267], [68.44097137, 23.59958267], [68.44097137, 23.60069466], [68.44069672, 23.60069466], [68.44069672, 23.60208321], [68.44097137, 23.60208321], [68.44097137, 23.60347176], [68.44069672, 23.60347176], [68.44069672, 23.60375023], [68.4404068, 23.60375023], [68.4404068, 23.60404015], [68.44013977, 23.60404015], [68.44013977, 23.60486031], [68.43985748, 23.60486031], [68.43985748, 23.60542107], [68.44013977, 23.60541725], [68.44013977, 23.60569382], [68.44041443, 23.60569382], [68.44041443, 23.60597229], [68.44013977, 23.60597038], [68.44013977, 23.60625076], [68.43985748, 23.60625076], [68.43985748, 23.60653114], [68.43959045, 23.60653114], [68.43959045, 23.60680962], [68.43769836, 23.6068058], [68.43708038, 23.6068058], [68.43708038, 23.60708237], [68.43680573, 23.60708237], [68.43680573, 23.60819244], [68.43708038, 23.60819244], [68.43708038, 23.60847473], [68.43736267, 23.60847092], [68.43736267, 23.60931015], [68.43708038, 23.60931015], [68.43708038, 23.61042023], [68.43680573, 23.61041451], [68.43682098, 23.61124992], [68.43653107, 23.61124992], [68.43653107, 23.61208344], [68.43624878, 23.61207962], [68.43624878, 23.61264038], [68.43597412, 23.61263847], [68.43597412, 23.61347198], [68.43569183, 23.61346817], [68.43569183, 23.61403084], [68.43541718, 23.61402893], [68.43541718, 23.61458397], [68.43514252, 23.61457825], [68.43514252, 23.61514091], [68.43486023, 23.61514091], [68.43486023, 23.61569405], [68.4345932, 23.61568832], [68.4345932, 23.61624908], [68.43486023, 23.61624908], [68.43486023, 23.61681175], [68.43514252, 23.61681175], [68.43514252, 23.61735916], [68.43541718, 23.61735916], [68.43541718, 23.61763954], [68.43624878, 23.61763954], [68.43624878, 23.61903954], [68.43653107, 23.61902809], [68.43653107, 23.61930466], [68.43763733, 23.61930466], [68.43763733, 23.61847115], [68.43818665, 23.61847115], [68.43818665, 23.61874962], [68.43846893, 23.61874962], [68.43846893, 23.61930466], [68.43875122, 23.61930466], [68.43875122, 23.61958122], [68.43958282, 23.61958122], [68.43958282, 23.6198616], [68.43985748, 23.6198597], [68.43985748, 23.62042046], [68.44124603, 23.62042046], [68.44124603, 23.61958122], [68.44374847, 23.61958122], [68.44374847, 23.62125015], [68.44403076, 23.62125015], [68.44403076, 23.62153053], [68.44431305, 23.62153053], [68.44431305, 23.62181091], [68.44819641, 23.62180328], [68.44819641, 23.62208557], [68.44847107, 23.62207985], [68.44847107, 23.62236023], [68.44876099, 23.62236023], [68.44876099, 23.62292099], [68.44902802, 23.62291527], [68.44902802, 23.62319565], [68.45096588, 23.62318993], [68.45096588, 23.62403107], [68.45182037, 23.62403107], [68.45182037, 23.62430954], [68.45207977, 23.62430954], [68.45207977, 23.62403107], [68.45291901, 23.62403107], [68.45291901, 23.62375069], [68.45541382, 23.62375069], [68.45541382, 23.6245842], [68.45569611, 23.62458038], [68.45569611, 23.62486076], [68.45625305, 23.62486076]]], [[[68.2765274, 23.79597473], [68.27708435, 23.79597473], [68.27708435, 23.79624939], [68.27735901, 23.79624939], [68.27735901, 23.79652786], [68.27791595, 23.79652023], [68.27791595, 23.79681015], [68.27902985, 23.79680443], [68.27902985, 23.7970829], [68.28013611, 23.7970829], [68.28013611, 23.79736137], [68.2804184, 23.79735947], [68.2804184, 23.79763985], [68.28069305, 23.79763985], [68.28069305, 23.79792023], [68.28097534, 23.79791451], [68.28097534, 23.79819679], [68.28236389, 23.79819679], [68.28236389, 23.79847145], [68.28375244, 23.79846954], [68.28375244, 23.79874992], [68.28514099, 23.79874992], [68.28514099, 23.7990303], [68.28624725, 23.7990303], [68.28624725, 23.79931068], [68.2876358, 23.79931068], [68.2876358, 23.79959106], [68.28874969, 23.79958344], [68.28874969, 23.79986191], [68.29069519, 23.79986191], [68.29069519, 23.80097198], [68.29152679, 23.80096817], [68.29152679, 23.80125046], [68.29264069, 23.80125046], [68.29264069, 23.80153084], [68.29374695, 23.80153084], [68.29374695, 23.80180931], [68.29430389, 23.8018055], [68.29430389, 23.80208397], [68.29486084, 23.80207825], [68.29486084, 23.80236053], [68.29541779, 23.80236053], [68.29541779, 23.80265045], [68.2959671, 23.80265045], [68.2959671, 23.80291939], [68.29652405, 23.80291748], [68.29652405, 23.80319405], [68.29708099, 23.80319405], [68.29708099, 23.80347252], [68.29763794, 23.80347061], [68.29763794, 23.80374908], [68.29819489, 23.80374908], [68.29819489, 23.8045826], [68.29792023, 23.80458069], [68.29792023, 23.81014061], [68.29763794, 23.8101387], [68.29763794, 23.81097221], [68.29736328, 23.81097031], [68.29736328, 23.81153107], [68.29708099, 23.81152534], [68.29708099, 23.8120842], [68.29680634, 23.81208038], [68.29680634, 23.81236076], [68.29624939, 23.81236076], [68.29624939, 23.81264114], [68.29569244, 23.81264114], [68.29569244, 23.81291962], [68.29486084, 23.81291771], [68.29486084, 23.81319427], [68.29430389, 23.81319427], [68.29430389, 23.81347275], [68.29402924, 23.81347084], [68.29402924, 23.81375122], [68.29264069, 23.81375122], [68.29264069, 23.81402969], [68.2923584, 23.81402969], [68.2923584, 23.81430817], [68.29209137, 23.81430817], [68.29209137, 23.81459045], [68.29180908, 23.81458282], [68.29180908, 23.8148613], [68.29152679, 23.81485748], [68.29152679, 23.81513977], [68.29096985, 23.81513977], [68.29096985, 23.81541824], [68.29069519, 23.81541634], [68.29069519, 23.81569481], [68.2904129, 23.81569481], [68.2904129, 23.81597137], [68.29013824, 23.81597137], [68.29013824, 23.81680489], [68.29069519, 23.81680489], [68.29069519, 23.81708336], [68.29125214, 23.81708336], [68.29125214, 23.81736183], [68.29180908, 23.81736183], [68.29180908, 23.81764984], [68.29209137, 23.81764984], [68.29209137, 23.81792259], [68.29264069, 23.81792259], [68.29264069, 23.81820107], [68.29319763, 23.81819534], [68.29319763, 23.81847191], [68.29347229, 23.81847191], [68.29347229, 23.81875038], [68.29402924, 23.81875038], [68.29402924, 23.81903267], [68.29458618, 23.81903267], [68.29458618, 23.81931114], [68.29569244, 23.81930542], [68.29569244, 23.81958389], [68.29651642, 23.81958008], [68.29651642, 23.81986046], [68.29736328, 23.81986046], [68.29736328, 23.82014275], [68.29763794, 23.82014275], [68.29763794, 23.82042122], [68.29846954, 23.8204174], [68.29846954, 23.82069206], [68.29902649, 23.82069206], [68.29902649, 23.82097244], [68.29985809, 23.82097054], [68.29985809, 23.82125092], [68.30042267, 23.82125092], [68.30042267, 23.82152939], [68.30097198, 23.82152939], [68.30097198, 23.82180977], [68.30152893, 23.82180405], [68.30152893, 23.82208252], [68.30236053, 23.82208061], [68.30236053, 23.82236099], [68.3034668, 23.82236099], [68.3034668, 23.82263947], [68.30374908, 23.82263947], [68.30374908, 23.82291985], [68.30430603, 23.82291412], [68.30430603, 23.82319641], [68.30569458, 23.82319641], [68.30569458, 23.82347488], [68.30680847, 23.82347107], [68.30680847, 23.82374954], [68.3079071, 23.82374954], [68.3079071, 23.82347107], [68.30958557, 23.82347488], [68.30958557, 23.82319641], [68.31014252, 23.82319641], [68.31014252, 23.82291412], [68.31069183, 23.82291985], [68.31069183, 23.82263947], [68.31096649, 23.82263947], [68.31096649, 23.82236099], [68.31124878, 23.82236099], [68.31124878, 23.82208061], [68.31153107, 23.82208252], [68.31153107, 23.82180405], [68.31181335, 23.82180977], [68.31181335, 23.82152939], [68.31263733, 23.82152939], [68.31263733, 23.82125092], [68.31291962, 23.82125092], [68.31291962, 23.82069016], [68.31319427, 23.82069206], [68.31319427, 23.8204174], [68.31346893, 23.82042122], [68.31346893, 23.81986046], [68.31375122, 23.81986046], [68.31375122, 23.81931114], [68.31402588, 23.81931114], [68.31402588, 23.81820107], [68.31430817, 23.81820107], [68.31430817, 23.81792259], [68.31458282, 23.81792259], [68.31458282, 23.81764984], [68.31485748, 23.81764984], [68.31485748, 23.81736183], [68.31513977, 23.81736183], [68.31513977, 23.81652832], [68.3154068, 23.81653023], [68.3154068, 23.81568909], [68.31569672, 23.81569481], [68.31569672, 23.81513977], [68.31597137, 23.81513977], [68.31597137, 23.81430817], [68.31626129, 23.81430817], [68.31626129, 23.81402969], [68.31652832, 23.81402969], [68.31652832, 23.81291962], [68.31680298, 23.81291962], [68.31680298, 23.81236076], [68.3170929, 23.81236076], [68.31708527, 23.81152534], [68.31735992, 23.81153107], [68.31735992, 23.81014061], [68.31764221, 23.81014061], [68.31764221, 23.80875015], [68.31791687, 23.80875015], [68.31791687, 23.80820084], [68.31819153, 23.80820084], [68.31819153, 23.80764008], [68.31846619, 23.80764008], [68.31846619, 23.8073597], [68.31874847, 23.8073616], [68.31874847, 23.80708122], [68.31903076, 23.80708122], [68.31903076, 23.80680466], [68.31930542, 23.80680466], [68.31930542, 23.80652809], [68.31958008, 23.80653191], [68.31958008, 23.80624962], [68.32013702, 23.80624962], [68.32013702, 23.80597115], [68.32041931, 23.80597115], [68.32041931, 23.80569458], [68.32069397, 23.80569458], [68.32069397, 23.80541611], [68.3215332, 23.80542183], [68.3215332, 23.80486107], [68.32236481, 23.80486107], [68.32235718, 23.80431175], [68.32206726, 23.80431175], [68.32206726, 23.80374908], [68.32180786, 23.80374908], [68.32180786, 23.80318832], [68.32152557, 23.80319405], [68.32152557, 23.80291748], [68.32125092, 23.80291939], [68.32125092, 23.80236053], [68.32096863, 23.80236053], [68.32096863, 23.80180931], [68.32068634, 23.80180931], [68.32068634, 23.80125046], [68.32041931, 23.80125046], [68.32041931, 23.8006897], [68.32013702, 23.80069351], [68.32013702, 23.80041885], [68.31986237, 23.80042076], [68.31986237, 23.79985809], [68.31958008, 23.79986191], [68.31958008, 23.79930687], [68.31929779, 23.79931068], [68.31929779, 23.7990303], [68.31903076, 23.7990303], [68.31903076, 23.79846954], [68.31874847, 23.79847145], [68.31874847, 23.79819679], [68.31847382, 23.79819679], [68.31847382, 23.79763794], [68.31819153, 23.79763985], [68.31819153, 23.79708099], [68.31791687, 23.7970829], [68.31791687, 23.79624939], [68.31764221, 23.79624939], [68.31764221, 23.79514122], [68.31735992, 23.79514122], [68.31735992, 23.79430962], [68.3170929, 23.79430962], [68.3170929, 23.79346275], [68.31680298, 23.79347229], [68.31680298, 23.79291725], [68.31652832, 23.79292107], [68.31652832, 23.79236031], [68.31625366, 23.79236031], [68.31625366, 23.7915287], [68.31597137, 23.79153252], [68.31597137, 23.79071045], [68.31569672, 23.79071045], [68.31569672, 23.79014015], [68.3154068, 23.79014015], [68.3154068, 23.78930092], [68.31513977, 23.78930473], [68.31513977, 23.78874969], [68.31485748, 23.78874969], [68.31485748, 23.78847122], [68.31458282, 23.78847313], [68.31458282, 23.78819466], [68.31430817, 23.78819466], [68.31430817, 23.78763962], [68.31458282, 23.78764915], [68.31458282, 23.78736115], [68.31430817, 23.78736115], [68.31430817, 23.78708076], [68.31375122, 23.78708267], [68.31375122, 23.78680611], [68.31402588, 23.78680992], [68.31402588, 23.78569031], [68.31430817, 23.78569412], [68.31430817, 23.78513908], [68.31458282, 23.78514099], [68.31458282, 23.78347015], [68.31430817, 23.78347206], [68.31430817, 23.78097153], [68.31402588, 23.78097153], [68.31402588, 23.77930641], [68.31430817, 23.77931023], [68.31430817, 23.77792168], [68.31458282, 23.77792168], [68.31458282, 23.77042007], [68.31485748, 23.77042007], [68.31485748, 23.76847076], [68.31513977, 23.76847267], [68.31513977, 23.76652718], [68.3154068, 23.76654053], [68.3154068, 23.76458168], [68.31569672, 23.76458359], [68.31569672, 23.76319504], [68.31597137, 23.76320267], [68.31597137, 23.76235962], [68.31625366, 23.76236153], [68.31625366, 23.76124954], [68.31652832, 23.76124954], [68.31652832, 23.76041031], [68.31680298, 23.76041794], [68.31680298, 23.75958252], [68.31708527, 23.75958252], [68.31708527, 23.75875092], [68.31735992, 23.75875092], [68.31735992, 23.75764084], [68.31764221, 23.75764084], [68.31764221, 23.75681114], [68.31791687, 23.75681114], [68.31791687, 23.75597], [68.31819153, 23.75597191], [68.31819153, 23.7551384], [68.31846619, 23.7551403], [68.31846619, 23.75431061], [68.31874847, 23.75431061], [68.31874847, 23.75346947], [68.31903076, 23.75347137], [68.31903076, 23.75263977], [68.31929779, 23.75263977], [68.31929779, 23.75181007], [68.31958008, 23.75181007], [68.31958008, 23.75097084], [68.31986237, 23.75097275], [68.31986237, 23.74791718], [68.32013702, 23.74791908], [68.32013702, 23.74596977], [68.32041931, 23.74597168], [68.32041931, 23.74541855], [68.32069397, 23.74541855], [68.32069397, 23.74513626], [68.32096863, 23.74514008], [68.32096863, 23.7448597], [68.32125092, 23.7448616], [68.32125092, 23.74430656], [68.32152557, 23.74430656], [68.32152557, 23.74347305], [68.32180786, 23.74347305], [68.32180786, 23.74263954], [68.32206726, 23.74263954], [68.32206726, 23.74208069], [68.32236481, 23.7420826], [68.32236481, 23.74124908], [68.32263947, 23.7412529], [68.32263947, 23.74041939], [68.32290649, 23.74041939], [68.32290649, 23.73986053], [68.32319641, 23.73986053], [68.32319641, 23.73931122], [68.32347107, 23.73931122], [68.32347107, 23.73792267], [68.32375336, 23.73792267], [68.32375336, 23.7365303], [68.32402802, 23.7365303], [68.32402802, 23.73513985], [68.32430267, 23.73513985], [68.32430267, 23.73430824], [68.32402802, 23.73430824], [68.32402802, 23.73402977], [68.32180786, 23.73402977], [68.32180786, 23.733181], [68.32152557, 23.73319435], [68.32152557, 23.73291779], [68.32096863, 23.73291969], [68.32096863, 23.73264122], [68.32013702, 23.73264122], [68.32013702, 23.73236084], [68.31929779, 23.73236084], [68.31929779, 23.73208046], [68.31819153, 23.73208237], [68.31819153, 23.73180771], [68.31458282, 23.73180771], [68.31458282, 23.73208237], [68.31375122, 23.73208237], [68.31375122, 23.73152542], [68.31346893, 23.73153114], [68.31346893, 23.73097038], [68.31319427, 23.73097229], [68.31319427, 23.73069572], [68.31291962, 23.73069572], [68.31291962, 23.73041534], [68.30735779, 23.7304306], [68.30735779, 23.73014069], [68.30625153, 23.73014069], [68.30625153, 23.72986031], [68.30486298, 23.72986031], [68.30486298, 23.72957993], [68.30374908, 23.72958565], [68.30374908, 23.72930336], [68.30291748, 23.72931099], [68.30291748, 23.72903061], [68.30236053, 23.72903061], [68.30236053, 23.72875023], [68.30152893, 23.72875023], [68.30152893, 23.72846985], [68.29985809, 23.72847176], [68.29985809, 23.72819328], [68.29930878, 23.72820091], [68.29930878, 23.72792053], [68.29875183, 23.72792053], [68.29875183, 23.72764015], [68.29818726, 23.72764015], [68.29818726, 23.72737122], [68.29792023, 23.72737122], [68.29792023, 23.72707939], [68.29763794, 23.7270813], [68.29763794, 23.72680473], [68.29708099, 23.72680473], [68.29708099, 23.72652817], [68.29680634, 23.72653008], [68.29680634, 23.72624969], [68.29651642, 23.72624969], [68.29651642, 23.72597122], [68.29624939, 23.72597122], [68.29624939, 23.72624969], [68.29512787, 23.72624969], [68.29512787, 23.72653008], [68.29430389, 23.72652817], [68.29430389, 23.72680473], [68.29347229, 23.72680473], [68.29347229, 23.7270813], [68.29292297, 23.72707939], [68.29292297, 23.72737122], [68.29209137, 23.72737122], [68.29209137, 23.72764015], [68.29125214, 23.72764015], [68.29125214, 23.72792053], [68.29096985, 23.72792053], [68.29096985, 23.72820091], [68.2904129, 23.72819328], [68.2904129, 23.72847176], [68.28985596, 23.72846985], [68.28985596, 23.72875023], [68.2895813, 23.72875023], [68.2895813, 23.72903061], [68.2893219, 23.72903061], [68.2893219, 23.72931099], [68.28902435, 23.72930336], [68.28902435, 23.72958565], [68.28847504, 23.72958565], [68.28848267, 23.72986031], [68.28819275, 23.72986031], [68.28819275, 23.7304306], [68.28791809, 23.73041534], [68.28791809, 23.73069572], [68.2876358, 23.73069572], [68.2876358, 23.73097229], [68.28736115, 23.73097038], [68.28736115, 23.73125076], [68.2868042, 23.73125076], [68.2868042, 23.73208237], [68.28652954, 23.73208046], [68.28652954, 23.73264122], [68.28624725, 23.73264122], [68.28624725, 23.73374939], [68.28652954, 23.73374939], [68.28652954, 23.7345829], [68.2868042, 23.7345829], [68.2868042, 23.73486137], [68.28708649, 23.73485947], [68.28708649, 23.73513985], [68.28736115, 23.73513985], [68.28736115, 23.73541832], [68.2876358, 23.73541641], [68.2876358, 23.73569489], [68.28819275, 23.73569489], [68.28819275, 23.73597145], [68.28847504, 23.73597145], [68.28847504, 23.73624992], [68.28985596, 23.73624039], [68.28985596, 23.7365303], [68.29070282, 23.7365303], [68.29070282, 23.73681259], [68.29152679, 23.73680496], [68.29152679, 23.73708344], [68.29180908, 23.73708344], [68.29180908, 23.73736191], [68.29264069, 23.73736191], [68.29264069, 23.73764038], [68.29292297, 23.73764038], [68.29292297, 23.73792267], [68.29319763, 23.73791695], [68.29319763, 23.73847008], [68.29347229, 23.73847008], [68.29347229, 23.73875046], [68.29374695, 23.73875046], [68.29374695, 23.73903275], [68.29402924, 23.73903275], [68.29402924, 23.73931122], [68.29429626, 23.73931122], [68.29429626, 23.73986053], [68.29458618, 23.73986053], [68.29458618, 23.7412529], [68.29429626, 23.7412529], [68.29429626, 23.74237061], [68.29402924, 23.74237061], [68.29402924, 23.74291992], [68.29374695, 23.7429142], [68.29374695, 23.74319649], [68.29347229, 23.74319649], [68.29347229, 23.74347305], [68.29319763, 23.74347115], [68.29319763, 23.74403], [68.29291534, 23.74402618], [68.29291534, 23.74430656], [68.29264069, 23.74430656], [68.29264069, 23.74458313], [68.2923584, 23.74458313], [68.2923584, 23.7448616], [68.29209137, 23.7448597], [68.29209137, 23.74514008], [68.29180908, 23.74513626], [68.29180908, 23.74541855], [68.29152679, 23.74541092], [68.29152679, 23.74570084], [68.29125214, 23.74569511], [68.29125214, 23.74597168], [68.29096985, 23.74596977], [68.29096985, 23.74625015], [68.29070282, 23.74625015], [68.29070282, 23.74653053], [68.2904129, 23.74653053], [68.2904129, 23.74681091], [68.29013824, 23.74681091], [68.29013824, 23.74736023], [68.28985596, 23.74736023], [68.28985596, 23.74764061], [68.2895813, 23.74764061], [68.2895813, 23.74791908], [68.28902435, 23.74791718], [68.28902435, 23.74847221], [68.28874969, 23.74847031], [68.28874969, 23.74931145], [68.28847504, 23.74930573], [68.28847504, 23.7495842], [68.28819275, 23.74957848], [68.28819275, 23.74986076], [68.28791809, 23.74986076], [68.28791809, 23.75069427], [68.2876358, 23.75069427], [68.2876358, 23.75097275], [68.28736115, 23.75097084], [68.28736115, 23.75181007], [68.28708649, 23.75180626], [68.28708649, 23.75319481], [68.2868042, 23.75319481], [68.2868042, 23.75347137], [68.28708649, 23.75346947], [68.28708649, 23.75431061], [68.28652954, 23.75430489], [68.28652954, 23.75458336], [68.28569794, 23.75458336], [68.28569794, 23.75430489], [68.28542328, 23.75431061], [68.28542328, 23.75235939], [68.28569794, 23.7523613], [68.28569794, 23.75124931], [68.2859726, 23.75125122], [68.2859726, 23.75013924], [68.28624725, 23.75013924], [68.28624725, 23.74957848], [68.28652954, 23.7495842], [68.28652954, 23.74875069], [68.28679657, 23.74875069], [68.28679657, 23.74847031], [68.28708649, 23.74847221], [68.28708649, 23.74819374], [68.28736115, 23.74819374], [68.28736115, 23.74708366], [68.2876358, 23.74708366], [68.2876358, 23.74652863], [68.28791809, 23.74653053], [68.28791809, 23.74625015], [68.28819275, 23.74625015], [68.28819275, 23.74570084], [68.28848267, 23.74570084], [68.28848267, 23.74541092], [68.28874969, 23.74541855], [68.28874969, 23.74513626], [68.28903198, 23.74514008], [68.28903198, 23.7448597], [68.2895813, 23.7448616], [68.2895813, 23.74458313], [68.28986359, 23.74458313], [68.28986359, 23.74430656], [68.29013824, 23.74430656], [68.29013824, 23.74402618], [68.29070282, 23.74403], [68.29070282, 23.74374962], [68.29152679, 23.74374962], [68.29152679, 23.74319077], [68.29180908, 23.74319649], [68.29180908, 23.74263954], [68.29209137, 23.74263954], [68.29208374, 23.74236107], [68.2923584, 23.74237061], [68.2923584, 23.74208069], [68.29264069, 23.7420826], [68.29264069, 23.74180412], [68.29292297, 23.74180984], [68.29292297, 23.74069023], [68.29319763, 23.74069214], [68.29319763, 23.74041748], [68.29292297, 23.74041939], [68.29292297, 23.74014282], [68.29264069, 23.74014282], [68.29264069, 23.73986053], [68.2923584, 23.73986053], [68.2923584, 23.73958015], [68.29208374, 23.73958206], [68.29208374, 23.7393055], [68.29152679, 23.73931122], [68.29152679, 23.73903275], [68.29096985, 23.73903275], [68.29096985, 23.73875046], [68.29013824, 23.73875046], [68.29013824, 23.73847008], [68.28930664, 23.73847008], [68.28930664, 23.73819351], [68.28902435, 23.73819351], [68.28902435, 23.73791695], [68.28848267, 23.73792267], [68.28848267, 23.73764038], [68.28791809, 23.73764038], [68.28791809, 23.73736191], [68.2876358, 23.73736191], [68.2876358, 23.73708344], [68.28708649, 23.73708344], [68.28708649, 23.73680496], [68.28679657, 23.73681259], [68.28679657, 23.7365303], [68.28652954, 23.7365303], [68.28652954, 23.73624039], [68.28624725, 23.73624992], [68.28624725, 23.73597145], [68.28569794, 23.73597145], [68.28569794, 23.73569489], [68.28541565, 23.73569489], [68.28541565, 23.73513985], [68.28514099, 23.73513985], [68.28514099, 23.73457909], [68.2848587, 23.7345829], [68.2848587, 23.73208427], [68.28514099, 23.73208427], [68.28514099, 23.73152542], [68.28542328, 23.73153114], [68.28542328, 23.73069], [68.28569794, 23.73069572], [68.28569794, 23.73041534], [68.2859726, 23.7304306], [68.2859726, 23.73014069], [68.28624725, 23.73014069], [68.28624725, 23.72986031], [68.28652954, 23.72986031], [68.28652954, 23.72957993], [68.2868042, 23.72958565], [68.2868042, 23.72930336], [68.28708649, 23.72931099], [68.28708649, 23.72903061], [68.28736115, 23.72903061], [68.28736115, 23.72875023], [68.2876358, 23.72875023], [68.2876358, 23.72846985], [68.28791809, 23.72847176], [68.28791809, 23.72819328], [68.28819275, 23.72820091], [68.28819275, 23.72792053], [68.28848267, 23.72792053], [68.28848267, 23.72764015], [68.28874969, 23.72764015], [68.28874969, 23.72737122], [68.2893219, 23.72737122], [68.2893219, 23.72707939], [68.28986359, 23.7270813], [68.28986359, 23.72680473], [68.2904129, 23.72680473], [68.2904129, 23.72652817], [68.29070282, 23.72653008], [68.29070282, 23.72624969], [68.29152679, 23.72624969], [68.29152679, 23.72597122], [68.2923584, 23.72597122], [68.2923584, 23.72569466], [68.29291534, 23.72569466], [68.29291534, 23.72541618], [68.29347229, 23.72542191], [68.29347229, 23.72513962], [68.29374695, 23.72513962], [68.29374695, 23.72486115], [68.29429626, 23.72486115], [68.29429626, 23.72402954], [68.29458618, 23.72402954], [68.29458618, 23.7231884], [68.29430389, 23.72319412], [68.29430389, 23.72236061], [68.29402924, 23.72236061], [68.29402924, 23.72207832], [68.29374695, 23.72208405], [68.29374695, 23.72180557], [68.29347229, 23.72180939], [68.29347229, 23.72153091], [68.29292297, 23.72153091], [68.29292297, 23.721241], [68.29264069, 23.72125053], [68.29264069, 23.72097206], [68.2923584, 23.72097206], [68.2923584, 23.72069359], [68.29208374, 23.72069359], [68.29208374, 23.72041893], [68.29180908, 23.72042084], [68.29180908, 23.72014046], [68.29152679, 23.72014046], [68.29152679, 23.7195797], [68.29125214, 23.71958351], [68.29125214, 23.71930695], [68.29096985, 23.71931076], [68.29096985, 23.71903038], [68.28985596, 23.71903038], [68.28985596, 23.71875], [68.28930664, 23.71875], [68.28930664, 23.71791458], [68.28903198, 23.7179203], [68.28903198, 23.71735954], [68.28874969, 23.71736145], [68.28874969, 23.71708488], [68.28847504, 23.71708488], [68.28847504, 23.71652794], [68.28819275, 23.71652985], [68.28819275, 23.71624947], [68.28791809, 23.71624947], [68.28791809, 23.71597099], [68.2876358, 23.71597481], [68.2876358, 23.71541405], [68.28736115, 23.71543121], [68.28736115, 23.71513939], [68.28679657, 23.71513939], [68.28679657, 23.71486092], [68.28652954, 23.71486092], [68.28652954, 23.71458054], [68.28624725, 23.71458244], [68.28624725, 23.71430588], [68.2859726, 23.71430969], [68.2859726, 23.71403122], [68.28569794, 23.71403122], [68.28569794, 23.71347046], [68.28541565, 23.71347237], [68.28541565, 23.71319389], [68.28514099, 23.71319389], [68.28514099, 23.71263885], [68.2848587, 23.71264267], [68.2848587, 23.71236038], [68.28457642, 23.71236038], [68.28457642, 23.71181107], [68.28430939, 23.71181107], [68.28430176, 23.71153259], [68.2840271, 23.71153259], [68.2840271, 23.71097183], [68.28375244, 23.71097183], [68.28375244, 23.71069527], [68.28347015, 23.7107029], [68.28347015, 23.71042252], [68.28318787, 23.71042252], [68.28318787, 23.70986176], [68.28263855, 23.70986176], [68.28263855, 23.71014023], [68.28235626, 23.71014023], [68.28235626, 23.71042252], [68.28180695, 23.71042252], [68.28180695, 23.7107029], [68.28152466, 23.71069527], [68.28152466, 23.71097183], [68.28125, 23.71097183], [68.28125, 23.71125031], [68.28013611, 23.71125031], [68.28013611, 23.71097183], [68.27986145, 23.71097183], [68.27986145, 23.71041679], [68.27958679, 23.71042252], [68.27958679, 23.71014023], [68.27929688, 23.71014023], [68.27929688, 23.70986176], [68.27902985, 23.70986176], [68.27902985, 23.70930481], [68.27874756, 23.70930481], [68.27874756, 23.70902824], [68.2784729, 23.70902824], [68.2784729, 23.70874977], [68.27819824, 23.70874977], [68.27819824, 23.70819092], [68.27791595, 23.70819473], [68.27791595, 23.70791626], [68.2776413, 23.70791817], [68.2776413, 23.70763969], [68.27735901, 23.70763969], [68.27735901, 23.70736122], [68.27680206, 23.70736122], [68.27680206, 23.70763969], [68.27708435, 23.70763969], [68.27708435, 23.7084713], [68.27735901, 23.70846748], [68.27735901, 23.70902824], [68.2776413, 23.70902824], [68.2776413, 23.70930481], [68.27791595, 23.70930481], [68.27791595, 23.70958328], [68.27819061, 23.70957756], [68.27819061, 23.71014023], [68.2776413, 23.71014023], [68.2776413, 23.70986176], [68.27735901, 23.70986176], [68.27735901, 23.70958328], [68.27708435, 23.70958328], [68.27708435, 23.70930481], [68.2765274, 23.70930481], [68.2765274, 23.70902824], [68.27597046, 23.70902824], [68.27597046, 23.70874977], [68.27540588, 23.70874977], [68.27540588, 23.70846748], [68.2748642, 23.7084713], [68.2748642, 23.70791626], [68.27458191, 23.70791817], [68.27458191, 23.70708084], [68.27402496, 23.70708275], [68.27402496, 23.70819473], [68.2729187, 23.70819473], [68.2729187, 23.70791626], [68.27263641, 23.70791817], [68.27263641, 23.70763969], [68.2720871, 23.70763969], [68.2720871, 23.70708084], [68.27180481, 23.70708275], [68.27180481, 23.7056942], [68.27153015, 23.7056942], [68.27153015, 23.70486069], [68.27236176, 23.70486069], [68.27236176, 23.70514107], [68.27263641, 23.70514107], [68.27263641, 23.70541954], [68.2729187, 23.70541763], [68.2729187, 23.7056942], [68.27347565, 23.7056942], [68.27347565, 23.70597267], [68.27375031, 23.70597267], [68.27375031, 23.70624924], [68.27402496, 23.70624924], [68.27402496, 23.7056942], [68.27375031, 23.7056942], [68.27375031, 23.70541763], [68.27348328, 23.70541954], [68.27348328, 23.70486069], [68.27319336, 23.70486069], [68.27319336, 23.70430946], [68.2729187, 23.70430946], [68.2729187, 23.70375061], [68.27319336, 23.70375061], [68.27319336, 23.70347023], [68.27347565, 23.70347214], [68.27347565, 23.70291519], [68.27375031, 23.70292091], [68.27375031, 23.70264053], [68.27403259, 23.70264053], [68.27403259, 23.70236015], [68.27430725, 23.70236206], [68.27430725, 23.70180321], [68.27458191, 23.70181084], [68.27458191, 23.70125008], [68.27403259, 23.70125008], [68.27403259, 23.70153046], [68.27375031, 23.70153046], [68.27375031, 23.70181084], [68.27347565, 23.70180321], [68.27347565, 23.70208549], [68.27319336, 23.70207977], [68.27319336, 23.70236015], [68.2729187, 23.70236015], [68.2729187, 23.70264053], [68.27263641, 23.70264053], [68.27263641, 23.70292091], [68.27236176, 23.70292091], [68.27236176, 23.70319939], [68.2720871, 23.70319366], [68.2720871, 23.70347214], [68.27179718, 23.70347023], [68.27179718, 23.70375061], [68.27069092, 23.70375061], [68.27069092, 23.70347023], [68.27041626, 23.70347023], [68.27041626, 23.70375061], [68.2701416, 23.70375061], [68.2701416, 23.70403099], [68.26985931, 23.70403099], [68.26985931, 23.70430946], [68.26875305, 23.70430756], [68.26875305, 23.70458412], [68.26763916, 23.70458031], [68.26763916, 23.70486069], [68.26735687, 23.70486069], [68.26735687, 23.70514107], [68.26708221, 23.70514107], [68.26708221, 23.70541954], [68.26680756, 23.70541763], [68.26680756, 23.7056942], [68.26652527, 23.7056942], [68.26652527, 23.70597267], [68.26625061, 23.70597267], [68.26625061, 23.70624924], [68.26597595, 23.7062397], [68.26597595, 23.70652962], [68.26568604, 23.70652962], [68.26568604, 23.70680809], [68.26541901, 23.70680618], [68.26541901, 23.70708275], [68.26513672, 23.70708275], [68.26515198, 23.70736122], [68.26486206, 23.70736122], [68.26486206, 23.70763969], [68.26457977, 23.70763969], [68.26457977, 23.70791817], [68.26430511, 23.70791626], [68.26430511, 23.70819473], [68.26403046, 23.70819473], [68.26403046, 23.7084713], [68.26374817, 23.70846748], [68.26374817, 23.70874977], [68.26346588, 23.70874977], [68.26346588, 23.70902824], [68.26319122, 23.70902824], [68.26319122, 23.70930481], [68.26291656, 23.70930481], [68.26291656, 23.70958328], [68.26264191, 23.70958328], [68.26264191, 23.70986176], [68.26235962, 23.70986176], [68.26235962, 23.71014023], [68.26207733, 23.71014023], [68.26207733, 23.7107029], [68.26180267, 23.71069527], [68.26180267, 23.71097183], [68.26152802, 23.71097183], [68.26152802, 23.71125031], [68.26125336, 23.71125031], [68.26125336, 23.71153259], [68.26097107, 23.71153259], [68.26097107, 23.71181107], [68.26069641, 23.71180534], [68.26069641, 23.71208382], [68.26040649, 23.71208191], [68.26040649, 23.71236038], [68.26013947, 23.71236038], [68.26013947, 23.71264267], [68.25986481, 23.71263885], [68.25986481, 23.71319389], [68.25958252, 23.71319389], [68.25958252, 23.71347237], [68.25930786, 23.71347046], [68.25930786, 23.71375084], [68.25901794, 23.71375084], [68.25901794, 23.71403122], [68.25875092, 23.7140274], [68.25875092, 23.71458244], [68.25846863, 23.71458054], [68.25846863, 23.71486092], [68.25818634, 23.71486092], [68.25818634, 23.71513939], [68.25791931, 23.71513939], [68.25791931, 23.71569633], [68.25763702, 23.71569633], [68.25763702, 23.71597481], [68.25736237, 23.71597481], [68.25736237, 23.71708488], [68.25763702, 23.71708107], [68.25763702, 23.71763992], [68.25791931, 23.71763992], [68.25791931, 23.7179203], [68.25819397, 23.71791458], [68.25819397, 23.71847153], [68.25846863, 23.71846962], [68.25846863, 23.71875], [68.25875092, 23.71875], [68.25875092, 23.71903038], [68.25901794, 23.71903038], [68.25901794, 23.71931076], [68.25930786, 23.71930695], [68.25930786, 23.71958351], [68.25958252, 23.71958351], [68.25958252, 23.71986198], [68.25985718, 23.71986008], [68.25985718, 23.72014046], [68.26040649, 23.72014046], [68.26040649, 23.72042084], [68.26069641, 23.72041893], [68.26069641, 23.72069359], [68.26097107, 23.72069359], [68.26097107, 23.72097206], [68.26125336, 23.72097206], [68.26125336, 23.72125053], [68.26152802, 23.721241], [68.26152802, 23.72153091], [68.26180267, 23.72153091], [68.26180267, 23.72180939], [68.26208496, 23.72180557], [68.26208496, 23.72208405], [68.26235962, 23.72207832], [68.26235962, 23.72236061], [68.26264191, 23.72236061], [68.26264191, 23.72263908], [68.26291656, 23.72263908], [68.26291656, 23.72291946], [68.26319122, 23.72291756], [68.26319122, 23.72319412], [68.26346588, 23.7231884], [68.26346588, 23.72374916], [68.26374817, 23.72374916], [68.26374817, 23.72430611], [68.26403046, 23.72429848], [68.26403046, 23.72486115], [68.26430511, 23.72486115], [68.26430511, 23.72513962], [68.26457977, 23.72513962], [68.26457977, 23.72569466], [68.26486206, 23.72569275], [68.26486206, 23.72624969], [68.26513672, 23.72624969], [68.26513672, 23.72680473], [68.26541901, 23.72680283], [68.26541901, 23.72875023], [68.26569366, 23.72875023], [68.26569366, 23.72958565], [68.26597595, 23.72958565], [68.26597595, 23.73097229], [68.26568604, 23.73097038], [68.26568604, 23.73264122], [68.26541901, 23.73263931], [68.26541901, 23.73347282], [68.26515198, 23.73347092], [68.26515198, 23.73430824], [68.26486206, 23.73430634], [68.26486206, 23.73486137], [68.26457977, 23.73485947], [68.26457977, 23.73541832], [68.26430511, 23.73541641], [68.26430511, 23.73569489], [68.26403046, 23.73569489], [68.26403046, 23.73624992], [68.26374817, 23.73624992], [68.26374817, 23.73708344], [68.26347351, 23.73708344], [68.26347351, 23.73847008], [68.26374817, 23.73847008], [68.26374817, 23.73931122], [68.26403046, 23.7393055], [68.26403046, 23.73958206], [68.26431274, 23.73958015], [68.26431274, 23.74014282], [68.26457977, 23.74014282], [68.26457977, 23.74041939], [68.26486206, 23.74041748], [68.26486206, 23.74069214], [68.26513672, 23.74069214], [68.26513672, 23.74097252], [68.26541901, 23.74097061], [68.26541901, 23.7412529], [68.26597595, 23.7412529], [68.26597595, 23.74152946], [68.26625061, 23.74152946], [68.26625061, 23.74180984], [68.26680756, 23.74180412], [68.26680756, 23.7420826], [68.26708221, 23.74208069], [68.26708221, 23.74237061], [68.26763916, 23.74237061], [68.26763916, 23.74263954], [68.26791382, 23.74263954], [68.26791382, 23.74319649], [68.26763916, 23.74319077], [68.26763916, 23.74403], [68.26789856, 23.74403], [68.26789856, 23.74514008], [68.26819611, 23.74513626], [68.26819611, 23.74597168], [68.26847076, 23.74597168], [68.26847076, 23.74708366], [68.26875305, 23.74708366], [68.26875305, 23.74819374], [68.26902771, 23.74818993], [68.26902771, 23.74931145], [68.26930237, 23.74931145], [68.26930237, 23.74986076], [68.26902771, 23.74986076], [68.26902771, 23.75013924], [68.26875305, 23.75013924], [68.26875305, 23.75154114], [68.26847076, 23.75152779], [68.26847076, 23.75208282], [68.26763916, 23.75208282], [68.26763916, 23.75124931], [68.26735687, 23.75125122], [68.26735687, 23.75154114], [68.2665329, 23.75154114], [68.2665329, 23.75181007], [68.26597595, 23.75180626], [68.26597595, 23.75208282], [68.26569366, 23.75208282], [68.26569366, 23.7523613], [68.26541901, 23.75235939], [68.26541901, 23.75292015], [68.26513672, 23.75291634], [68.26513672, 23.75347137], [68.26486206, 23.75346947], [68.26486206, 23.75403023], [68.26457977, 23.75403023], [68.26457977, 23.75653076], [68.26430511, 23.75652695], [68.26430511, 23.75986099], [68.26457977, 23.75986099], [68.26457977, 23.76041794], [68.26486206, 23.76041794], [68.26486206, 23.76097298], [68.26515198, 23.76097107], [68.26515198, 23.76152992], [68.26541901, 23.76152992], [68.26541901, 23.76208305], [68.26568604, 23.76208115], [68.26568604, 23.76263809], [68.26597595, 23.76263809], [68.26597595, 23.76320267], [68.26625061, 23.76320267], [68.26625061, 23.76403046], [68.26652527, 23.76402855], [68.26652527, 23.76486015], [68.26680756, 23.76486015], [68.26680756, 23.76542282], [68.26708221, 23.76542282], [68.26708221, 23.76764107], [68.26735687, 23.76764107], [68.26735687, 23.77124977], [68.26763916, 23.77124977], [68.26763916, 23.77236176], [68.26789856, 23.77235031], [68.26789856, 23.77264023], [68.26821136, 23.77264023], [68.26821136, 23.77292061], [68.26847076, 23.7729187], [68.26847076, 23.77347183], [68.26875305, 23.77346992], [68.26875305, 23.77403069], [68.26902771, 23.77402878], [68.26902771, 23.77458382], [68.26930237, 23.77457809], [68.26930237, 23.77514076], [68.26957703, 23.77514076], [68.26957703, 23.77541924], [68.26985931, 23.77541733], [68.26985931, 23.77597237], [68.2701416, 23.77597046], [68.2701416, 23.7768116], [68.27041626, 23.7768116], [68.27041626, 23.77792168], [68.27069092, 23.77792168], [68.27069092, 23.77848053], [68.27095795, 23.77848053], [68.27095795, 23.77931023], [68.27124786, 23.77930641], [68.27124786, 23.77986145], [68.27153015, 23.77986145], [68.27153015, 23.78236389], [68.27179718, 23.78236008], [68.27179718, 23.78430939], [68.2720871, 23.78430939], [68.2720871, 23.78625107], [68.27236176, 23.78624725], [68.27236176, 23.78847313], [68.27263641, 23.78847313], [68.27263641, 23.78958321], [68.2729187, 23.78957748], [68.2729187, 23.79071045], [68.27319336, 23.79071045], [68.27319336, 23.79153252], [68.27348328, 23.79153252], [68.27348328, 23.79264069], [68.27375031, 23.79264069], [68.27375031, 23.79292107], [68.27430725, 23.79291725], [68.27430725, 23.79347229], [68.27458191, 23.79346275], [68.27458191, 23.79375076], [68.27485657, 23.79375076], [68.27485657, 23.79430962], [68.27513885, 23.7943058], [68.27513885, 23.79458237], [68.27540588, 23.79458046], [68.27540588, 23.79514122], [68.2756958, 23.79514122], [68.2756958, 23.79541969], [68.27625275, 23.79541588], [68.27625275, 23.79569244], [68.2765274, 23.79569244], [68.2765274, 23.79597473]]], [[[68.21652985, 23.77931023], [68.21652985, 23.77874947], [68.21736145, 23.77874947], [68.21736145, 23.77848053], [68.2179184, 23.77848053], [68.2179184, 23.77819252], [68.21847534, 23.77819443], [68.21847534, 23.77791595], [68.21901703, 23.77792168], [68.21901703, 23.77763939], [68.2195816, 23.77763939], [68.2195816, 23.77736092], [68.21984863, 23.77736092], [68.21984863, 23.7768116], [68.22013855, 23.7768116], [68.22013855, 23.77652931], [68.22041321, 23.77652931], [68.22041321, 23.77625084], [68.22070313, 23.77625084], [68.2206955, 23.77569389], [68.22097015, 23.77569389], [68.22097015, 23.77541733], [68.22125244, 23.77541924], [68.22125244, 23.77375031], [68.2215271, 23.77375031], [68.2215271, 23.77319908], [68.22180176, 23.77319908], [68.22180939, 23.77292061], [68.22207642, 23.77292061], [68.22207642, 23.77264023], [68.2223587, 23.77264023], [68.2223587, 23.77235031], [68.22264099, 23.77236176], [68.22264099, 23.77013969], [68.22290802, 23.77013969], [68.22290802, 23.76847076], [68.22319794, 23.76847267], [68.22319794, 23.76652718], [68.2234726, 23.76654053], [68.2234726, 23.76514053], [68.22374725, 23.76514053], [68.22374725, 23.76403046], [68.22402954, 23.76403046], [68.22402954, 23.76320267], [68.22374725, 23.76320267], [68.22374725, 23.76208115], [68.2234726, 23.76208305], [68.2234726, 23.76180649], [68.22319794, 23.76180077], [68.22319794, 23.76124954], [68.22290802, 23.76124954], [68.22290802, 23.76097107], [68.22264099, 23.76097298], [68.22264099, 23.7606945], [68.2223587, 23.7606945], [68.2223587, 23.76041794], [68.22208405, 23.76041794], [68.22208405, 23.76013947], [68.22180939, 23.76013947], [68.22180176, 23.75986099], [68.22125244, 23.75986099], [68.22125244, 23.75958061], [68.22097015, 23.75958252], [68.22097015, 23.75930786], [68.22070313, 23.75930977], [68.22070313, 23.75902939], [68.22041321, 23.75902939], [68.22041321, 23.75875092], [68.22013855, 23.75875092], [68.22013855, 23.75847054], [68.21986389, 23.75847244], [68.21986389, 23.75819588], [68.2195816, 23.75819588], [68.2195816, 23.7579174], [68.21930695, 23.75792122], [68.21930695, 23.75764084], [68.21901703, 23.75764084], [68.21901703, 23.75735092], [68.21875, 23.75736046], [68.21875, 23.7570858], [68.21847534, 23.7570858], [68.21847534, 23.75652695], [68.21819305, 23.75653076], [68.21819305, 23.75625038], [68.2179184, 23.75625038], [68.2179184, 23.75597], [68.21763611, 23.75597191], [68.21763611, 23.75569344], [68.2168045, 23.75569344], [68.2168045, 23.75597191], [68.21652985, 23.75597], [68.21652985, 23.75625038], [68.21624756, 23.75625038], [68.21624756, 23.75653076], [68.2159729, 23.75653076], [68.2159729, 23.75681114], [68.21569824, 23.75680351], [68.21569061, 23.7570858], [68.21541595, 23.75708008], [68.21541595, 23.75764084], [68.2151413, 23.75763893], [68.2151413, 23.75819588], [68.21485901, 23.75819588], [68.21485901, 23.75958252], [68.2151413, 23.75958252], [68.2151413, 23.7606945], [68.21541595, 23.76069069], [68.21541595, 23.76124954], [68.21569061, 23.76124954], [68.21569824, 23.7618084], [68.2159729, 23.7618084], [68.2159729, 23.76291847], [68.21624756, 23.76291656], [68.21624756, 23.76486015], [68.21652985, 23.76486015], [68.21652985, 23.76569366], [68.21624756, 23.76569176], [68.21624756, 23.76680946], [68.2159729, 23.76680565], [68.2159729, 23.76708221], [68.21569824, 23.76708031], [68.21569061, 23.76736069], [68.21541595, 23.76736069], [68.21541595, 23.76764107], [68.2151413, 23.76764107], [68.2151413, 23.76791954], [68.21485901, 23.76791573], [68.21485901, 23.76819229], [68.21457672, 23.76819038], [68.21457672, 23.76902962], [68.21485901, 23.76902771], [68.21485901, 23.77347183], [68.2151413, 23.77346992], [68.2151413, 23.77541924], [68.21541595, 23.77541924], [68.21541595, 23.77736092], [68.2151413, 23.77736092], [68.2151413, 23.77848053], [68.21541595, 23.77848053], [68.21541595, 23.77874947], [68.2159729, 23.77874947], [68.2159729, 23.77902985], [68.21624756, 23.77902985], [68.21624756, 23.77931023], [68.21652985, 23.77931023]]], [[[68.44957733, 23.73233986], [68.44958496, 23.73152542], [68.44985962, 23.73153114], [68.44985962, 23.73180962], [68.45014191, 23.73180771], [68.45014191, 23.73208427], [68.45069122, 23.73208427], [68.45069122, 23.73125076], [68.45041656, 23.73125076], [68.45041656, 23.73097038], [68.45014191, 23.73097229], [68.45014191, 23.73041534], [68.44875336, 23.73041534], [68.44875336, 23.73060226], [68.44875336, 23.73069572], [68.44847107, 23.73069572], [68.44847107, 23.73097229], [68.44790649, 23.73097038], [68.44790649, 23.73125076], [68.44763947, 23.73125076], [68.44763947, 23.73180962], [68.44735718, 23.73180962], [68.44735718, 23.73236084], [68.44763947, 23.73236084], [68.44763947, 23.73264122], [68.44847107, 23.73264122], [68.44847107, 23.73236084], [68.44957733, 23.73233986]]], [[[68.46736145, 23.73986053], [68.46736145, 23.73958015], [68.4679184, 23.73958206], [68.4679184, 23.7393055], [68.46875, 23.73931122], [68.46875, 23.73903275], [68.46930695, 23.73903275], [68.46930695, 23.73875046], [68.46985626, 23.73875046], [68.46985626, 23.73847008], [68.47041321, 23.73847008], [68.47041321, 23.73819542], [68.47070313, 23.7381916], [68.4706955, 23.73791695], [68.47125244, 23.73792267], [68.47125244, 23.73764038], [68.4715271, 23.73764038], [68.4715271, 23.73736191], [68.47208405, 23.73736191], [68.47208405, 23.73708344], [68.4723587, 23.73708344], [68.4723587, 23.73680496], [68.47292328, 23.73681259], [68.47292328, 23.7365303], [68.47319794, 23.7365303], [68.47319794, 23.73624039], [68.47374725, 23.73624992], [68.47374725, 23.73597145], [68.4743042, 23.73597145], [68.4743042, 23.73569489], [68.47458649, 23.73569489], [68.47458649, 23.73541641], [68.4751358, 23.73541832], [68.4751358, 23.73513985], [68.47570038, 23.73513985], [68.47570038, 23.73485947], [68.47624969, 23.73486137], [68.47624969, 23.7345829], [68.47680664, 23.7345829], [68.47680664, 23.73430634], [68.47735596, 23.73430824], [68.47735596, 23.73402977], [68.4779129, 23.73402977], [68.4779129, 23.73374939], [68.47902679, 23.73374939], [68.47902679, 23.73347092], [68.4798584, 23.73347282], [68.4798584, 23.73319435], [68.48097229, 23.73319435], [68.48097229, 23.73291779], [68.48401642, 23.73291969], [68.48401642, 23.73264122], [68.48458099, 23.73264122], [68.48458099, 23.73236084], [68.48513794, 23.73236084], [68.48513794, 23.73208046], [68.48542023, 23.73208427], [68.48542023, 23.73180771], [68.48596954, 23.73180962], [68.48596954, 23.73153114], [68.48625183, 23.73153114], [68.48625183, 23.73125076], [68.48680878, 23.73125076], [68.48680878, 23.73097038], [68.48708344, 23.73097229], [68.48708344, 23.73069572], [68.48735809, 23.73069572], [68.48735809, 23.72986031], [68.48764038, 23.72986031], [68.48764038, 23.72903061], [68.48735809, 23.72903061], [68.48735809, 23.72875023], [68.48707581, 23.72875023], [68.48707581, 23.72846985], [68.48680878, 23.72847176], [68.48680878, 23.72819328], [68.48430634, 23.72820091], [68.48430634, 23.72792053], [68.47820282, 23.72792053], [68.47820282, 23.72820091], [68.47736359, 23.72819328], [68.47736359, 23.72847176], [68.47651672, 23.72846985], [68.47651672, 23.72875023], [68.4734726, 23.72875023], [68.4734726, 23.72846985], [68.4723587, 23.72847176], [68.4723587, 23.72819328], [68.47041321, 23.72819328], [68.47041321, 23.72847176], [68.46708679, 23.72847176], [68.46708679, 23.72819328], [68.46652985, 23.72820091], [68.46652985, 23.72792053], [68.46569824, 23.72792053], [68.46569824, 23.72764015], [68.4651413, 23.72764015], [68.4651413, 23.72737122], [68.46485901, 23.72737122], [68.46485901, 23.72764015], [68.4631958, 23.72764015], [68.4631958, 23.72737122], [68.46290588, 23.72737122], [68.46290588, 23.72707939], [68.4623642, 23.7270813], [68.4623642, 23.72680473], [68.46208191, 23.72680473], [68.46208191, 23.72652817], [68.46153259, 23.72653008], [68.46153259, 23.72624969], [68.46125031, 23.72624969], [68.46125031, 23.72597122], [68.46069336, 23.72597122], [68.46069336, 23.72569466], [68.4604187, 23.72569466], [68.4604187, 23.72541618], [68.45986176, 23.72542191], [68.45986176, 23.72513962], [68.4595871, 23.72513962], [68.4595871, 23.72486115], [68.45929718, 23.72486115], [68.45929718, 23.72653008], [68.45903015, 23.72652817], [68.45903015, 23.72847176], [68.45874786, 23.72847176], [68.45874786, 23.72958565], [68.45903015, 23.72957993], [68.45903015, 23.73014069], [68.45930481, 23.73013878], [68.45930481, 23.73069572], [68.4595871, 23.73069], [68.4595871, 23.73125076], [68.45929718, 23.73125076], [68.45929718, 23.73153114], [68.45903015, 23.73153114], [68.45903015, 23.73180962], [68.45874786, 23.73180771], [68.45874786, 23.73208237], [68.45847321, 23.73208046], [68.45847321, 23.73236084], [68.45819092, 23.73236084], [68.45819092, 23.73264122], [68.45791626, 23.73264122], [68.45791626, 23.73291969], [68.4576416, 23.73291779], [68.4576416, 23.73319435], [68.45735931, 23.73319435], [68.45735931, 23.73347282], [68.45707703, 23.73347092], [68.45707703, 23.73374939], [68.45735931, 23.73374939], [68.45735931, 23.73402977], [68.4576416, 23.73402977], [68.4576416, 23.7345829], [68.45791626, 23.73457909], [68.45791626, 23.73513985], [68.45819092, 23.73513985], [68.45819092, 23.73569489], [68.45847321, 23.73569489], [68.45847321, 23.73624992], [68.45874786, 23.73624039], [68.45874786, 23.73681259], [68.45903015, 23.73680496], [68.45903015, 23.73708344], [68.4595871, 23.73708344], [68.4595871, 23.73736191], [68.45986176, 23.73736191], [68.45986176, 23.73764038], [68.46013641, 23.73764038], [68.46013641, 23.73792267], [68.4604187, 23.73791695], [68.4604187, 23.7381916], [68.46069336, 23.73819542], [68.46069336, 23.73847008], [68.46097565, 23.73847008], [68.46097565, 23.73875046], [68.46180725, 23.73875046], [68.46180725, 23.73903275], [68.46263885, 23.73903275], [68.46263885, 23.73931122], [68.4631958, 23.7393055], [68.4631958, 23.73958206], [68.4640274, 23.73958015], [68.4640274, 23.73986053], [68.46736145, 23.73986053]]], [[[68.48680878, 23.74597168], [68.48680878, 23.74513626], [68.48652649, 23.74514008], [68.48652649, 23.74319077], [68.48625183, 23.74319649], [68.48625183, 23.74124908], [68.48596954, 23.7412529], [68.48596954, 23.74014282], [68.48568726, 23.74014282], [68.48568726, 23.73931122], [68.48542023, 23.73931122], [68.48542023, 23.73875046], [68.48513794, 23.73875046], [68.48513794, 23.7381916], [68.48486328, 23.73819351], [68.48486328, 23.73763847], [68.48458099, 23.73764038], [68.48458099, 23.73736191], [68.48430634, 23.73736191], [68.48430634, 23.73708344], [68.48402405, 23.73708344], [68.48402405, 23.73680496], [68.48374939, 23.73681259], [68.48374939, 23.7365303], [68.4834671, 23.7365303], [68.4834671, 23.73624039], [68.48319244, 23.73624992], [68.48319244, 23.73597145], [68.48236084, 23.73597145], [68.48236084, 23.73624992], [68.48179626, 23.73624039], [68.48179626, 23.7365303], [68.48152924, 23.7365284], [68.48152924, 23.73708344], [68.48124695, 23.73708153], [68.48124695, 23.73764038], [68.48152924, 23.73763847], [68.48152924, 23.7381916], [68.48179626, 23.73820114], [68.48179626, 23.73903275], [68.48208618, 23.73902702], [68.48208618, 23.73958206], [68.48236084, 23.73958015], [68.48236084, 23.74014282], [68.4826355, 23.74013901], [68.4826355, 23.74069214], [68.48291779, 23.74069023], [68.48291779, 23.7412529], [68.48319244, 23.7412529], [68.48319244, 23.74180984], [68.4834671, 23.74180984], [68.4834671, 23.74237061], [68.48374939, 23.74237061], [68.48374939, 23.74263954], [68.48402405, 23.74263954], [68.48402405, 23.74319649], [68.48430634, 23.74319649], [68.48430634, 23.74347305], [68.48458099, 23.74347115], [68.48458099, 23.74403], [68.48486328, 23.74402618], [68.48486328, 23.74458313], [68.48513794, 23.74458313], [68.48513794, 23.7448616], [68.48596954, 23.7448597], [68.48596954, 23.74514008], [68.48625183, 23.74514008], [68.48625183, 23.74570084], [68.48652649, 23.74569511], [68.48652649, 23.74597168], [68.48680878, 23.74597168]]], [[[68.51790619, 23.77736092], [68.51819611, 23.77736092], [68.51819611, 23.77708054], [68.51902771, 23.77708244], [68.51902771, 23.77680588], [68.51985931, 23.7768116], [68.51985931, 23.77652931], [68.52068329, 23.77652931], [68.52068329, 23.77625084], [68.52097321, 23.77625084], [68.52097321, 23.77597046], [68.52124786, 23.77597237], [68.52124786, 23.77569389], [68.52180481, 23.77569389], [68.52180481, 23.77541733], [68.52236176, 23.77541924], [68.52236176, 23.77514076], [68.5220871, 23.77514076], [68.5220871, 23.77069092], [68.52180481, 23.77069664], [68.52180481, 23.76958275], [68.52153015, 23.76958275], [68.52153015, 23.76874924], [68.52124786, 23.76875114], [68.52124786, 23.76791954], [68.52097321, 23.76791954], [68.52097321, 23.76708031], [68.52069092, 23.76708221], [68.52069092, 23.76597023], [68.52041626, 23.76597023], [68.52041626, 23.76513863], [68.5201416, 23.76514053], [68.5201416, 23.76431274], [68.51985931, 23.76431274], [68.51985931, 23.76348114], [68.51957703, 23.76348114], [68.51957703, 23.76263809], [68.51930237, 23.76263809], [68.51930237, 23.7618084], [68.51902771, 23.76180077], [68.51902771, 23.76097298], [68.51875305, 23.76097298], [68.51875305, 23.76041794], [68.51819611, 23.76041794], [68.51819611, 23.76013947], [68.51790619, 23.76013947], [68.51790619, 23.75958061], [68.51763916, 23.75958252], [68.51763916, 23.75680351], [68.51735687, 23.75681114], [68.51735687, 23.75597], [68.51708221, 23.75597191], [68.51708221, 23.7551384], [68.51680756, 23.7551403], [68.51680756, 23.75457954], [68.51652527, 23.75458336], [68.51652527, 23.75430489], [68.51625061, 23.75431061], [68.51625061, 23.75403023], [68.51597595, 23.75403023], [68.51597595, 23.75346947], [68.51569366, 23.75347137], [68.51569366, 23.75319481], [68.51541901, 23.75319481], [68.51541901, 23.75291634], [68.51513672, 23.75292015], [68.51513672, 23.75263977], [68.51486206, 23.75263977], [68.51486206, 23.7523613], [68.51430511, 23.7523613], [68.51430511, 23.75208282], [68.51291656, 23.75208282], [68.51291656, 23.75180626], [68.51264191, 23.75181007], [68.51264191, 23.75154114], [68.51207733, 23.75154114], [68.51207733, 23.75125122], [68.5118103, 23.75125122], [68.5118103, 23.75097084], [68.51013947, 23.75097084], [68.51013947, 23.75125122], [68.5090332, 23.75125122], [68.5090332, 23.75154114], [68.50846863, 23.75154114], [68.50846863, 23.75181007], [68.50819397, 23.75180626], [68.50819397, 23.75208282], [68.50763702, 23.75208282], [68.50763702, 23.7523613], [68.50736237, 23.75235939], [68.50736237, 23.75263977], [68.50708008, 23.75263977], [68.50708008, 23.75292015], [68.50680542, 23.75291634], [68.50680542, 23.75319481], [68.50624847, 23.75319481], [68.50624847, 23.75347137], [68.50596619, 23.75346947], [68.50596619, 23.75374985], [68.50567627, 23.75374985], [68.50567627, 23.75403023], [68.50541687, 23.75403023], [68.50541687, 23.75431061], [68.50485992, 23.75430489], [68.50485992, 23.75458336], [68.50458527, 23.75458336], [68.50458527, 23.75486183], [68.50430298, 23.75485992], [68.50430298, 23.7551403], [68.50347137, 23.7551403], [68.50347137, 23.75542068], [68.50263977, 23.75542068], [68.50263977, 23.75570107], [68.50208282, 23.75569344], [68.50208282, 23.75597191], [68.50125122, 23.75597], [68.50125122, 23.75625038], [68.50041962, 23.75625038], [68.50041962, 23.75653076], [68.49958038, 23.75653076], [68.49958038, 23.75681114], [68.49847412, 23.75680351], [68.49847412, 23.7570858], [68.49764252, 23.7570858], [68.49764252, 23.75736046], [68.49652863, 23.75735092], [68.49652863, 23.75764084], [68.49514008, 23.75764084], [68.49514008, 23.75792122], [68.49402618, 23.7579174], [68.49402618, 23.75819588], [68.49319458, 23.75819588], [68.49319458, 23.75847244], [68.49236298, 23.75847054], [68.49236298, 23.75875092], [68.4909668, 23.75875092], [68.4909668, 23.75902939], [68.49041748, 23.75902939], [68.49041748, 23.75930977], [68.49013519, 23.75930786], [68.49013519, 23.75958252], [68.48958588, 23.75958252], [68.48958588, 23.75902557], [68.48986053, 23.75902939], [68.48986053, 23.75847054], [68.49041748, 23.75847244], [68.49041748, 23.75819588], [68.49097443, 23.75819588], [68.49097443, 23.7579174], [68.49180603, 23.75792122], [68.49180603, 23.75764084], [68.49236298, 23.75764084], [68.49236298, 23.75735092], [68.49319458, 23.75736046], [68.49319458, 23.7570858], [68.49430847, 23.7570858], [68.49430847, 23.75680351], [68.49514008, 23.75681114], [68.49514008, 23.75653076], [68.49624634, 23.75653076], [68.49624634, 23.75625038], [68.4970932, 23.75625038], [68.49708557, 23.75597191], [68.49819183, 23.75597191], [68.49819183, 23.75569344], [68.49903107, 23.75570107], [68.49903107, 23.75542068], [68.50013733, 23.75542068], [68.50013733, 23.7551403], [68.50096893, 23.7551403], [68.50096893, 23.75485992], [68.50152588, 23.75486183], [68.50152588, 23.75458336], [68.50235748, 23.75458336], [68.50235748, 23.75430489], [68.5029068, 23.75431061], [68.5029068, 23.75403023], [68.50319672, 23.75403023], [68.50319672, 23.75374985], [68.50374603, 23.75374985], [68.50374603, 23.75346947], [68.50402832, 23.75347137], [68.50402832, 23.75319481], [68.50458527, 23.75319481], [68.50458527, 23.75291634], [68.50485992, 23.75292015], [68.50485992, 23.75263977], [68.50514221, 23.75263977], [68.50514221, 23.75235939], [68.50541687, 23.7523613], [68.50541687, 23.75180626], [68.50567627, 23.75181007], [68.50567627, 23.75154114], [68.50596619, 23.75154114], [68.50596619, 23.75125122], [68.50624847, 23.75125122], [68.50624847, 23.75068855], [68.50653076, 23.75069427], [68.50653076, 23.75013924], [68.50681305, 23.75013924], [68.50681305, 23.74957848], [68.50708008, 23.7495842], [68.50708008, 23.74902725], [68.50736237, 23.74902916], [68.50736237, 23.74847031], [68.50708008, 23.74847221], [68.50708008, 23.7476387], [68.50681305, 23.74764061], [68.50681305, 23.74707985], [68.50653076, 23.74708366], [68.50653076, 23.74680519], [68.50596619, 23.74681091], [68.50596619, 23.74653053], [68.50567627, 23.74653053], [68.50567627, 23.74625015], [68.50541687, 23.74625015], [68.50541687, 23.74596977], [68.50485992, 23.74597168], [68.50485992, 23.74569511], [68.5045929, 23.74570084], [68.5045929, 23.74541092], [68.50430298, 23.74541855], [68.50430298, 23.74513626], [68.50374603, 23.74514008], [68.50374603, 23.7448597], [68.50347137, 23.7448616], [68.50347137, 23.74458313], [68.50291443, 23.74458313], [68.50291443, 23.74430656], [68.50263977, 23.74430656], [68.50263977, 23.74402618], [68.50208282, 23.74403], [68.50208282, 23.74374962], [68.50180817, 23.74374962], [68.50180817, 23.74347115], [68.50125122, 23.74347305], [68.50125122, 23.74319649], [68.50069427, 23.74319649], [68.50069427, 23.7429142], [68.4998703, 23.74291992], [68.4998703, 23.74263954], [68.49958038, 23.74263954], [68.49958038, 23.74237061], [68.49931335, 23.74237061], [68.49931335, 23.74208069], [68.49903107, 23.7420826], [68.49903107, 23.74180412], [68.49874878, 23.74180984], [68.49874878, 23.7412529], [68.49846649, 23.7412529], [68.49846649, 23.74097061], [68.49819183, 23.74097252], [68.49819183, 23.74069214], [68.49791718, 23.74069214], [68.49791718, 23.74041748], [68.49764252, 23.74041939], [68.49764252, 23.74014282], [68.49736023, 23.74014282], [68.49736023, 23.73986053], [68.49708557, 23.73986053], [68.49708557, 23.73958206], [68.49680328, 23.73958206], [68.49680328, 23.7393055], [68.49652863, 23.73931122], [68.49652863, 23.73903275], [68.49624634, 23.73903275], [68.49624634, 23.73875046], [68.49597168, 23.73875046], [68.49597168, 23.73847008], [68.49569702, 23.73847008], [68.49569702, 23.73819351], [68.49541473, 23.73819351], [68.49541473, 23.73791695], [68.49514008, 23.73792267], [68.49514008, 23.73764038], [68.49485779, 23.73764038], [68.49485779, 23.73736191], [68.49153137, 23.73736191], [68.49153137, 23.73764038], [68.48958588, 23.73764038], [68.48958588, 23.73736191], [68.48874664, 23.73736191], [68.48874664, 23.73708344], [68.48764038, 23.73708153], [68.48764038, 23.73903275], [68.48791504, 23.73902702], [68.48791504, 23.74069214], [68.48819733, 23.74069023], [68.48819733, 23.7412529], [68.48847198, 23.7412529], [68.48847198, 23.74237061], [68.48874664, 23.74236107], [68.48874664, 23.74597168], [68.48847198, 23.74596977], [68.48847198, 23.74653053], [68.4879303, 23.74653053], [68.4879303, 23.74681091], [68.48764038, 23.74681091], [68.48764038, 23.74764061], [68.48791504, 23.7476387], [68.48791504, 23.74819374], [68.48819733, 23.74819374], [68.48819733, 23.74847221], [68.48791504, 23.74847221], [68.4879303, 23.74875069], [68.48764038, 23.74875069], [68.48764038, 23.74931145], [68.48735809, 23.74930573], [68.48735809, 23.7495842], [68.48707581, 23.74957848], [68.48707581, 23.74986076], [68.48680878, 23.74986076], [68.48680878, 23.75013924], [68.48652649, 23.75013924], [68.48652649, 23.75041962], [68.48596954, 23.7504158], [68.48596954, 23.75069427], [68.48569489, 23.75069427], [68.48569489, 23.75097275], [68.48542023, 23.75097084], [68.48542023, 23.75125122], [68.48513794, 23.75125122], [68.48513794, 23.75154114], [68.48458099, 23.75154114], [68.48458099, 23.75181007], [68.48430634, 23.75180626], [68.48430634, 23.75208282], [68.48374939, 23.75208282], [68.48374939, 23.7523613], [68.4834671, 23.75235939], [68.4834671, 23.75263977], [68.48124695, 23.75263977], [68.48124695, 23.75292015], [68.47652435, 23.75291634], [68.47652435, 23.75319481], [68.47569275, 23.75319481], [68.47569275, 23.75347137], [68.47458649, 23.75346947], [68.47458649, 23.75374985], [68.47402954, 23.75374985], [68.47402954, 23.75403023], [68.4734726, 23.75403023], [68.4734726, 23.75431061], [68.47291565, 23.75430489], [68.47291565, 23.75458336], [68.4723587, 23.75458336], [68.4723587, 23.75486183], [68.47180176, 23.75485992], [68.47180176, 23.7551403], [68.4715271, 23.7551403], [68.4715271, 23.75570107], [68.47125244, 23.75569344], [68.47125244, 23.75597191], [68.47097015, 23.75597], [68.47097015, 23.75625038], [68.47070313, 23.75625038], [68.47070313, 23.75681114], [68.47041321, 23.75680351], [68.47041321, 23.7570858], [68.47013855, 23.7570858], [68.47013855, 23.75736046], [68.46985626, 23.75735092], [68.46985626, 23.75792122], [68.4695816, 23.7579174], [68.4695816, 23.75847244], [68.46930695, 23.75847054], [68.46930695, 23.75902939], [68.46902466, 23.75902557], [68.46902466, 23.75958252], [68.46875, 23.75958061], [68.46875, 23.76013947], [68.46847534, 23.76013947], [68.46847534, 23.7606945], [68.46819305, 23.76069069], [68.46819305, 23.76124954], [68.4679184, 23.76124954], [68.4679184, 23.76180077], [68.46763611, 23.7618084], [68.46763611, 23.76320267], [68.46708679, 23.76320267], [68.46708679, 23.76375008], [68.4668045, 23.76375008], [68.4668045, 23.76458359], [68.46652985, 23.76458168], [68.46652985, 23.76542282], [68.46624756, 23.76542282], [68.46624756, 23.76625061], [68.4659729, 23.76625061], [68.4659729, 23.76680946], [68.46569824, 23.76680946], [68.46569061, 23.76764107], [68.46541595, 23.76763916], [68.46541595, 23.76847267], [68.46569061, 23.76847267], [68.46569061, 23.76874924], [68.46569824, 23.76902962], [68.4659729, 23.76902962], [68.4659729, 23.76986122], [68.46624756, 23.76986122], [68.46624756, 23.77042007], [68.46652985, 23.77041435], [68.46652985, 23.77208328], [68.46679688, 23.77207947], [68.46679688, 23.77403069], [68.46652985, 23.77403069], [68.46652985, 23.77486038], [68.46624756, 23.77486038], [68.46624756, 23.77541924], [68.46541595, 23.77541924], [68.46541595, 23.77457809], [68.46569824, 23.77458382], [68.46569824, 23.77263641], [68.46541595, 23.77264023], [68.46541595, 23.77096939], [68.4651413, 23.7709713], [68.4651413, 23.77013969], [68.46485901, 23.77013969], [68.46485901, 23.76958084], [68.46458435, 23.76958275], [68.46458435, 23.76874924], [68.46430206, 23.76875114], [68.46430206, 23.76791954], [68.4640274, 23.76791954], [68.4640274, 23.76625061], [68.46430206, 23.76625061], [68.46430206, 23.76569176], [68.46458435, 23.76569366], [68.46458435, 23.76486015], [68.46485901, 23.76486015], [68.46485901, 23.76430511], [68.4651413, 23.76431274], [68.4651413, 23.76348114], [68.46541595, 23.76348114], [68.46541595, 23.76291847], [68.46569824, 23.76291847], [68.46569824, 23.76235962], [68.4659729, 23.76236153], [68.4659729, 23.76152992], [68.46624756, 23.76152992], [68.46624756, 23.76097107], [68.46652985, 23.76097298], [68.46652985, 23.76041794], [68.4668045, 23.76041794], [68.4668045, 23.75986099], [68.46708679, 23.75986099], [68.46708679, 23.75930977], [68.46736145, 23.75930977], [68.46736145, 23.75875092], [68.46763611, 23.75875092], [68.46763611, 23.75847054], [68.4679184, 23.75847244], [68.4679184, 23.7579174], [68.46819305, 23.75792122], [68.46819305, 23.75764084], [68.46848297, 23.75764084], [68.46848297, 23.75708008], [68.46875, 23.7570858], [68.46875, 23.75680351], [68.46901703, 23.75681114], [68.46901703, 23.75625038], [68.46930695, 23.75625038], [68.46930695, 23.75570107], [68.46956635, 23.75570107], [68.46956635, 23.7551403], [68.46985626, 23.7551403], [68.46985626, 23.75457954], [68.47013855, 23.75458336], [68.47013855, 23.75374985], [68.47041321, 23.75374985], [68.47041321, 23.75292015], [68.47070313, 23.75292015], [68.47070313, 23.75235939], [68.47097015, 23.7523613], [68.47097015, 23.75208282], [68.47125244, 23.75208282], [68.47125244, 23.75180626], [68.4715271, 23.75181007], [68.4715271, 23.75154114], [68.47180176, 23.75154114], [68.47180939, 23.75125122], [68.47207642, 23.75125122], [68.47207642, 23.75097084], [68.4723587, 23.75097275], [68.4723587, 23.75069427], [68.47264099, 23.75069427], [68.47264099, 23.7504158], [68.47292328, 23.75041962], [68.47292328, 23.75013924], [68.4734726, 23.75013924], [68.4734726, 23.74986076], [68.47402954, 23.74986076], [68.47402954, 23.74957848], [68.47458649, 23.7495842], [68.47458649, 23.74930573], [68.4751358, 23.74931145], [68.4751358, 23.74902916], [68.47570038, 23.74902916], [68.47570038, 23.74875069], [68.47652435, 23.74875069], [68.47651672, 23.74847031], [68.4770813, 23.74847221], [68.4770813, 23.74819374], [68.47763824, 23.74819374], [68.47763824, 23.74791718], [68.4779129, 23.74791908], [68.4779129, 23.74764061], [68.47846985, 23.74764061], [68.47846985, 23.74653053], [68.47875977, 23.74653053], [68.47875977, 23.74514008], [68.47902679, 23.74514008], [68.47902679, 23.74430084], [68.47875214, 23.74430656], [68.47875214, 23.74374962], [68.47846985, 23.74374962], [68.47846985, 23.74319077], [68.47819519, 23.74319649], [68.47819519, 23.74263954], [68.4779129, 23.74263954], [68.4779129, 23.74237061], [68.47763824, 23.74237061], [68.47763824, 23.74180984], [68.47735596, 23.74180984], [68.47735596, 23.74152946], [68.4770813, 23.74152946], [68.4770813, 23.7412529], [68.47680664, 23.7412529], [68.47680664, 23.74069023], [68.47486115, 23.74069214], [68.47486115, 23.74041748], [68.47292328, 23.74041939], [68.47292328, 23.74014282], [68.47041321, 23.74014282], [68.47041321, 23.74041939], [68.46986389, 23.74041748], [68.46986389, 23.74069214], [68.46902466, 23.74069214], [68.46902466, 23.74097252], [68.46848297, 23.74097061], [68.46848297, 23.7412529], [68.4679184, 23.7412529], [68.4679184, 23.74152946], [68.46763611, 23.74152946], [68.46763611, 23.74180984], [68.46708679, 23.74180412], [68.46708679, 23.7420826], [68.46679688, 23.74208069], [68.46679688, 23.74237061], [68.46624756, 23.74237061], [68.46624756, 23.74263954], [68.4659729, 23.74263954], [68.4659729, 23.74291992], [68.46541595, 23.7429142], [68.46541595, 23.74319649], [68.46458435, 23.74319649], [68.46458435, 23.74347305], [68.45874786, 23.74347305], [68.45874786, 23.74319649], [68.45819092, 23.74319649], [68.45819092, 23.7429142], [68.45680237, 23.74291992], [68.45680237, 23.74263954], [68.45625305, 23.74263954], [68.45625305, 23.74237061], [68.45569611, 23.74237061], [68.45569611, 23.74208069], [68.4548645, 23.7420826], [68.4548645, 23.74180412], [68.45153046, 23.74180984], [68.45153046, 23.74152946], [68.45069122, 23.74152946], [68.45069122, 23.7412529], [68.44790649, 23.7412529], [68.44790649, 23.74097061], [68.44708252, 23.74097252], [68.44708252, 23.74069214], [68.44652557, 23.74069214], [68.44652557, 23.74041748], [68.44625092, 23.74041939], [68.44625092, 23.74014282], [68.44596863, 23.74014282], [68.44596863, 23.73986053], [68.44541931, 23.73986053], [68.44541931, 23.73958015], [68.44513702, 23.73958206], [68.44513702, 23.7393055], [68.44403076, 23.7393055], [68.44403076, 23.73958206], [68.44374847, 23.73958015], [68.44374847, 23.73986053], [68.44319153, 23.73986053], [68.44319153, 23.74014282], [68.44291687, 23.74014282], [68.44291687, 23.74041939], [68.44069672, 23.74041939], [68.44069672, 23.74014282], [68.44013977, 23.74014282], [68.44013977, 23.73986053], [68.43958282, 23.73986053], [68.43958282, 23.73958206], [68.43819427, 23.73958206], [68.43819427, 23.7393055], [68.43736267, 23.73931122], [68.43736267, 23.73986053], [68.43708038, 23.73986053], [68.43708038, 23.74069214], [68.43680573, 23.74069214], [68.43680573, 23.7420826], [68.43708038, 23.7420826], [68.43708038, 23.74319649], [68.43736267, 23.74319649], [68.43736267, 23.74347305], [68.43763733, 23.74347115], [68.43763733, 23.74403], [68.43791962, 23.74402618], [68.43791962, 23.74430656], [68.43819427, 23.74430656], [68.43819427, 23.74458313], [68.43846893, 23.74458122], [68.43846893, 23.74514008], [68.43875122, 23.74513626], [68.43875122, 23.74541855], [68.43902588, 23.74541092], [68.43902588, 23.74570084], [68.43930817, 23.74569511], [68.43930817, 23.74597168], [68.43959045, 23.74596977], [68.43959045, 23.74681091], [68.43985748, 23.74681091], [68.43985748, 23.74791908], [68.44013977, 23.74791718], [68.44013977, 23.74819374], [68.4404068, 23.74818993], [68.4404068, 23.74875069], [68.44069672, 23.74875069], [68.44069672, 23.74902916], [68.44097137, 23.74902916], [68.44097137, 23.74931145], [68.44125366, 23.74930573], [68.44125366, 23.7495842], [68.44152832, 23.74957848], [68.44152832, 23.75013924], [68.44180298, 23.75013924], [68.44180298, 23.75041962], [68.44208527, 23.7504158], [68.44208527, 23.75097275], [68.44235992, 23.75097084], [68.44235992, 23.75154114], [68.44264221, 23.75152779], [68.44264221, 23.7523613], [68.44291687, 23.7523613], [68.44291687, 23.75347137], [68.44346619, 23.75346947], [68.44346619, 23.75374985], [68.44374847, 23.75374985], [68.44374847, 23.75403023], [68.44403076, 23.75403023], [68.44403076, 23.75431061], [68.44430542, 23.75430489], [68.44430542, 23.75486183], [68.44458008, 23.75485992], [68.44458008, 23.7551403], [68.44486237, 23.7551403], [68.44486237, 23.75542068], [68.44513702, 23.75542068], [68.44513702, 23.75570107], [68.44541931, 23.75569344], [68.44541931, 23.75597191], [68.44568634, 23.75597], [68.44568634, 23.75653076], [68.44596863, 23.75653076], [68.44596863, 23.75681114], [68.44625092, 23.75680351], [68.44625092, 23.7570858], [68.44652557, 23.7570858], [68.44652557, 23.75736046], [68.44680786, 23.75735092], [68.44680786, 23.75764084], [68.44708252, 23.75763893], [68.44708252, 23.75819588], [68.44736481, 23.75819588], [68.44736481, 23.75847244], [68.44763947, 23.75847054], [68.44763947, 23.75875092], [68.44790649, 23.75875092], [68.44790649, 23.75930977], [68.44819641, 23.75930977], [68.44819641, 23.76013947], [68.44847107, 23.76013947], [68.44847107, 23.76097298], [68.44876099, 23.76097107], [68.44876099, 23.76152992], [68.44902802, 23.76152992], [68.44902802, 23.76208305], [68.44930267, 23.76208115], [68.44930267, 23.76403046], [68.44958496, 23.76402855], [68.44958496, 23.76458359], [68.44985962, 23.76458168], [68.44985962, 23.76514053], [68.45014191, 23.76513863], [68.45014191, 23.76569366], [68.45041656, 23.76569176], [68.45041656, 23.76625061], [68.45069122, 23.76625061], [68.45069122, 23.76654053], [68.45097351, 23.76652718], [68.45097351, 23.76708221], [68.45124817, 23.76708031], [68.45124817, 23.76736069], [68.45153046, 23.76736069], [68.45153046, 23.76764107], [68.45180511, 23.76763916], [68.45180511, 23.76819229], [68.45207977, 23.76819229], [68.45207977, 23.76847267], [68.45236206, 23.76847076], [68.45236206, 23.76875114], [68.45291901, 23.76875114], [68.45291901, 23.76902962], [68.45319366, 23.76902771], [68.45319366, 23.76958275], [68.45347595, 23.76958084], [68.45347595, 23.77013969], [68.45375061, 23.77013969], [68.45375061, 23.77042007], [68.45402527, 23.77041435], [68.45402527, 23.77069664], [68.45430756, 23.77069092], [68.45430756, 23.77124977], [68.45456696, 23.77124977], [68.45456696, 23.77153015], [68.4548645, 23.77152824], [68.4548645, 23.77180672], [68.45541382, 23.77180672], [68.45541382, 23.77208328], [68.45569611, 23.77208328], [68.45569611, 23.77236176], [68.45597076, 23.77235031], [68.45597076, 23.77319908], [68.45625305, 23.77319908], [68.45625305, 23.77403069], [68.45652771, 23.77402878], [68.45652771, 23.77458382], [68.45597076, 23.77457809], [68.45597076, 23.77541924], [68.45569611, 23.77541924], [68.45569611, 23.7768116], [68.45541382, 23.77680588], [68.45541382, 23.77819443], [68.45513916, 23.77819252], [68.45513916, 23.78125], [68.45485687, 23.78125], [68.45485687, 23.78403091], [68.45458221, 23.78402519], [68.45458221, 23.7859726], [68.45430756, 23.78597069], [68.45430756, 23.78652954], [68.4540329, 23.78652954], [68.4540329, 23.78680992], [68.45319366, 23.78680611], [68.45319366, 23.78708267], [68.45263672, 23.78708076], [68.45263672, 23.78736115], [68.45236206, 23.78736115], [68.45236206, 23.78819466], [68.45207977, 23.78819084], [68.45207977, 23.78874969], [68.45182037, 23.78874969], [68.45182037, 23.78902817], [68.45124817, 23.78902817], [68.45124817, 23.78930473], [68.45097351, 23.78930473], [68.45097351, 23.78958321], [68.45069122, 23.78958321], [68.45069122, 23.78986168], [68.45041656, 23.78986168], [68.45041656, 23.79014015], [68.45014191, 23.79014015], [68.45014191, 23.79042244], [68.44985962, 23.79042244], [68.44985962, 23.79071045], [68.44957733, 23.79071045], [68.44957733, 23.79236031], [68.44930267, 23.79236031], [68.44930267, 23.79292107], [68.44957733, 23.79292107], [68.44957733, 23.79375076], [68.44985962, 23.79375076], [68.44985962, 23.79514122], [68.45014191, 23.79514122], [68.45014191, 23.79624939], [68.44985962, 23.79624939], [68.44985962, 23.7970829], [68.45014191, 23.7970829], [68.45014191, 23.79736137], [68.44985962, 23.79735947], [68.44985962, 23.79763985], [68.45014191, 23.79763985], [68.45014191, 23.79819679], [68.44985962, 23.79819107], [68.44985962, 23.79874992], [68.44957733, 23.79874992], [68.44957733, 23.79959106], [68.44902802, 23.79958344], [68.44902802, 23.80097198], [68.44875336, 23.80097198], [68.44875336, 23.80208397], [68.44847107, 23.80207825], [68.44847107, 23.80291939], [68.44819641, 23.80291939], [68.44819641, 23.80402946], [68.44790649, 23.80402946], [68.44790649, 23.80513954], [68.44763947, 23.80513954], [68.44763947, 23.80597115], [68.44790649, 23.80597115], [68.44790649, 23.80653191], [68.44819641, 23.80652809], [68.44819641, 23.80680466], [68.44847107, 23.80680466], [68.44847107, 23.80708122], [68.44902802, 23.80708122], [68.44902802, 23.8073616], [68.44930267, 23.8073597], [68.44930267, 23.80764008], [68.44985962, 23.80764008], [68.44985962, 23.80792046], [68.45014191, 23.80792046], [68.45014191, 23.80820084], [68.45097351, 23.80819321], [68.45097351, 23.80847168], [68.45207977, 23.80846024], [68.45207977, 23.80875015], [68.45291901, 23.80875015], [68.45291901, 23.80903053], [68.45375061, 23.80903053], [68.45375061, 23.80875015], [68.4540329, 23.80875015], [68.45402527, 23.80847168], [68.45430756, 23.80847168], [68.45430756, 23.80763817], [68.45456696, 23.80764008], [68.45456696, 23.8073597], [68.4548645, 23.8073616], [68.4548645, 23.80708122], [68.45513916, 23.80708122], [68.45513916, 23.8073616], [68.45540619, 23.8073597], [68.45540619, 23.80792046], [68.45513916, 23.80791664], [68.45513916, 23.80847168], [68.45485687, 23.80846024], [68.45485687, 23.80903053], [68.45458221, 23.80902863], [68.45458221, 23.80958557], [68.45430756, 23.80958557], [68.45430756, 23.81347275], [68.45456696, 23.81347084], [68.45456696, 23.81402969], [68.45485687, 23.81402969], [68.45485687, 23.81459045], [68.45513916, 23.81459045], [68.45513916, 23.81513977], [68.45540619, 23.81513977], [68.45540619, 23.81541824], [68.45569611, 23.81541634], [68.45569611, 23.81569481], [68.45597076, 23.81569481], [68.45597076, 23.81597137], [68.45625305, 23.81596756], [68.45625305, 23.81624985], [68.45680237, 23.81624985], [68.45680237, 23.81653023], [68.45708466, 23.81652832], [68.45708466, 23.81680489], [68.45735931, 23.81680489], [68.45735931, 23.81708336], [68.4576416, 23.81708336], [68.4576416, 23.81736183], [68.45819092, 23.81736183], [68.45819092, 23.81764984], [68.45903015, 23.81764984], [68.45903015, 23.81792259], [68.4595871, 23.81792259], [68.4595871, 23.81820107], [68.46013641, 23.81819534], [68.46013641, 23.81847191], [68.46097565, 23.81847191], [68.46097565, 23.81875038], [68.46153259, 23.81875038], [68.46153259, 23.81903267], [68.46290588, 23.81903267], [68.46290588, 23.81931114], [68.46430206, 23.81930542], [68.46430206, 23.81958389], [68.4706955, 23.81958389], [68.4706955, 23.81986046], [68.47207642, 23.81986046], [68.47207642, 23.82014275], [68.47319794, 23.82014275], [68.47319794, 23.82042122], [68.47402954, 23.8204174], [68.47402954, 23.82069206], [68.4751358, 23.82069206], [68.4751358, 23.82097244], [68.47569275, 23.82097244], [68.47569275, 23.82125092], [68.47651672, 23.82125092], [68.47651672, 23.82152939], [68.4770813, 23.82152939], [68.4770813, 23.82180977], [68.47763824, 23.82180405], [68.47763824, 23.82208252], [68.47819519, 23.82208252], [68.47819519, 23.82236099], [68.47875214, 23.82236099], [68.47875214, 23.82263947], [68.47930908, 23.82263947], [68.47930908, 23.82291985], [68.47958374, 23.82291412], [68.47958374, 23.82319641], [68.48014069, 23.82319641], [68.48014069, 23.82347488], [68.48069763, 23.82347107], [68.48069763, 23.82374954], [68.48097229, 23.82374954], [68.48097229, 23.82402992], [68.48124695, 23.82402992], [68.48124695, 23.8243103], [68.48152924, 23.82430458], [68.48152924, 23.82458305], [68.48208618, 23.82458305], [68.48208618, 23.82486153], [68.48236084, 23.82485962], [68.48236084, 23.82514], [68.48264313, 23.82514], [68.48264313, 23.82542038], [68.48291779, 23.82542038], [68.48291779, 23.82570076], [68.48319244, 23.82569695], [68.48319244, 23.8259716], [68.4834671, 23.8259697], [68.4834671, 23.82625008], [68.48374939, 23.82625008], [68.48374939, 23.82653046], [68.48430634, 23.82653046], [68.48430634, 23.82681847], [68.48458099, 23.82680511], [68.48458099, 23.82708359], [68.48486328, 23.82708359], [68.48486328, 23.82736206], [68.48513794, 23.82736015], [68.48513794, 23.82764053], [68.48542023, 23.82764053], [68.48542023, 23.82792091], [68.48596954, 23.8279171], [68.48596954, 23.82819366], [68.48625183, 23.82819366], [68.48625183, 23.82847214], [68.48680878, 23.82846832], [68.48680878, 23.82875061], [68.48707581, 23.82875061], [68.48707581, 23.82902908], [68.48764038, 23.82902908], [68.48764038, 23.82930946], [68.48819733, 23.82930565], [68.48819733, 23.82958412], [68.48874664, 23.82957077], [68.48874664, 23.82986069], [68.48929596, 23.82986069], [68.48929596, 23.83013916], [68.48986053, 23.83013916], [68.48986053, 23.83041954], [68.49346924, 23.83041763], [68.49346924, 23.8306942], [68.49458313, 23.8306942], [68.49458313, 23.83097267], [68.49652863, 23.83097267], [68.49652863, 23.8306942], [68.49791718, 23.8306942], [68.49791718, 23.83041763], [68.49931335, 23.83041954], [68.49931335, 23.83013916], [68.50013733, 23.83013916], [68.50013733, 23.82986069], [68.50096893, 23.82986069], [68.50096893, 23.82957077], [68.50180817, 23.82958412], [68.50180817, 23.82930565], [68.50263977, 23.82930946], [68.50263977, 23.82902908], [68.50347137, 23.82902908], [68.50347137, 23.82875061], [68.50402832, 23.82875061], [68.50402832, 23.82846832], [68.50430298, 23.82847214], [68.50430298, 23.82819366], [68.50485992, 23.82819366], [68.50485992, 23.8279171], [68.50514221, 23.82792091], [68.50514221, 23.82764053], [68.50541687, 23.82764053], [68.50541687, 23.82736015], [68.50569153, 23.82736206], [68.50569153, 23.82708359], [68.50624847, 23.82708359], [68.50624847, 23.82680511], [68.50708008, 23.82681847], [68.50708008, 23.82653046], [68.50736237, 23.82653046], [68.50736237, 23.82625008], [68.50791931, 23.82625008], [68.50791931, 23.8259697], [68.50819397, 23.8259716], [68.50819397, 23.82569695], [68.50846863, 23.82570076], [68.50846863, 23.82485962], [68.50875092, 23.82486153], [68.50875092, 23.82430458], [68.5090332, 23.8243103], [68.5090332, 23.82374954], [68.50930786, 23.82374954], [68.50930786, 23.82347107], [68.50958252, 23.82347488], [68.50958252, 23.82319641], [68.50986481, 23.82319641], [68.50986481, 23.82291412], [68.51040649, 23.82291985], [68.51040649, 23.82263947], [68.51069641, 23.82263947], [68.51069641, 23.82236099], [68.51125336, 23.82236099], [68.51125336, 23.82208061], [68.51180267, 23.82208252], [68.51180267, 23.82152748], [68.51235962, 23.82152939], [68.51235962, 23.82125092], [68.51264191, 23.82125092], [68.51264191, 23.82097054], [68.51291656, 23.82097244], [68.51291656, 23.82069206], [68.51319122, 23.82069206], [68.51319122, 23.82013893], [68.51346588, 23.82014275], [68.51346588, 23.81986046], [68.51374817, 23.81986046], [68.51374817, 23.81931114], [68.51403046, 23.81931114], [68.51403046, 23.81903267], [68.51431274, 23.81903267], [68.51431274, 23.81847191], [68.51513672, 23.81847191], [68.51513672, 23.81875038], [68.51568604, 23.81875038], [68.51568604, 23.81903267], [68.51735687, 23.81903267], [68.51735687, 23.81875038], [68.51819611, 23.81875038], [68.51819611, 23.81847191], [68.51930237, 23.81847191], [68.51930237, 23.81819534], [68.51957703, 23.81820107], [68.51957703, 23.81792259], [68.51985931, 23.81792259], [68.51985931, 23.81596756], [68.51958466, 23.81597137], [68.51958466, 23.81458282], [68.51930237, 23.81459045], [68.51930237, 23.81375122], [68.51902771, 23.81375122], [68.51902771, 23.81097031], [68.51930237, 23.81097221], [68.51930237, 23.81041527], [68.51957703, 23.81042099], [68.51957703, 23.80986023], [68.51985931, 23.80986023], [68.51985931, 23.80903053], [68.5201416, 23.80903053], [68.5201416, 23.80792046], [68.52041626, 23.80792046], [68.52041626, 23.8073597], [68.52069092, 23.8073616], [68.52069092, 23.80680466], [68.52097321, 23.80680466], [68.52097321, 23.80624962], [68.52124786, 23.80624962], [68.52124786, 23.80597115], [68.52153015, 23.80597115], [68.52153015, 23.80569458], [68.52180481, 23.80569458], [68.52180481, 23.80513954], [68.5220871, 23.80513954], [68.5220871, 23.80486107], [68.52236176, 23.80486107], [68.52236176, 23.80431175], [68.52263641, 23.80431175], [68.52263641, 23.80374908], [68.5229187, 23.80374908], [68.5229187, 23.80236053], [68.52263641, 23.80236053], [68.52263641, 23.80207825], [68.52236176, 23.80208397], [68.52236176, 23.8018055], [68.5220871, 23.80180931], [68.5220871, 23.80153084], [68.52179718, 23.80153084], [68.52179718, 23.8006897], [68.52041626, 23.80069351], [68.52041626, 23.80041885], [68.51985931, 23.80042076], [68.51985931, 23.80014038], [68.51930237, 23.80014038], [68.51930237, 23.79985809], [68.51902771, 23.79986191], [68.51902771, 23.79958344], [68.51875305, 23.79959106], [68.51875305, 23.7990303], [68.51847076, 23.7990303], [68.51847076, 23.79874992], [68.51790619, 23.79874992], [68.51790619, 23.79846954], [68.51763916, 23.79847145], [68.51763916, 23.79819679], [68.5173645, 23.79819679], [68.5173645, 23.79791451], [68.51708221, 23.79792023], [68.51708221, 23.79763985], [68.51680756, 23.79763985], [68.51680756, 23.79681015], [68.51625061, 23.79681015], [68.51625061, 23.79652023], [68.51597595, 23.79652786], [68.51597595, 23.79597473], [68.51541901, 23.79597473], [68.51541901, 23.79569244], [68.51513672, 23.79569244], [68.51513672, 23.79513931], [68.51486969, 23.79514122], [68.51486969, 23.79458046], [68.51457977, 23.79458237], [68.51457977, 23.79402733], [68.51431274, 23.79403114], [68.51431274, 23.79346275], [68.51403046, 23.79347229], [68.51403046, 23.79319382], [68.51374817, 23.79319382], [68.51374817, 23.79263878], [68.51346588, 23.79264069], [68.51346588, 23.79208183], [68.51319122, 23.79208374], [68.51319122, 23.79097176], [68.51291656, 23.79097176], [68.51291656, 23.79041672], [68.51264191, 23.79042244], [68.51264191, 23.78957748], [68.51235962, 23.78958321], [68.51235962, 23.78874969], [68.51152802, 23.78874969], [68.51152802, 23.78902817], [68.51041412, 23.78902817], [68.51041412, 23.78930473], [68.50986481, 23.78930473], [68.50986481, 23.78958321], [68.50902557, 23.78958321], [68.50902557, 23.78986168], [68.50846863, 23.78986168], [68.50846863, 23.79014015], [68.50791931, 23.79014015], [68.50791931, 23.79042244], [68.50763702, 23.79042244], [68.50763702, 23.79071045], [68.50736237, 23.79069519], [68.50736237, 23.79097176], [68.50708008, 23.79097176], [68.50708008, 23.79125023], [68.50681305, 23.79125023], [68.50681305, 23.7918129], [68.50653076, 23.79180527], [68.50653076, 23.79208374], [68.50596619, 23.79208183], [68.50596619, 23.79236031], [68.50567627, 23.79236031], [68.50567627, 23.79264069], [68.50514221, 23.79264069], [68.50514221, 23.79292107], [68.50485992, 23.79291725], [68.50485992, 23.79319382], [68.50458527, 23.79319382], [68.50458527, 23.79347229], [68.50430298, 23.79346275], [68.50430298, 23.79375076], [68.50402832, 23.79375076], [68.50402832, 23.79403114], [68.50263977, 23.79403114], [68.50263977, 23.79430962], [68.50152588, 23.7943058], [68.50152588, 23.79458237], [68.50013733, 23.79458046], [68.50013733, 23.79486084], [68.49874878, 23.79486084], [68.49874878, 23.79458046], [68.49847412, 23.79458237], [68.49847412, 23.79375076], [68.49874878, 23.79375076], [68.49874878, 23.79346275], [68.49958038, 23.79347229], [68.49958038, 23.79319382], [68.50096893, 23.79319382], [68.50096893, 23.79291725], [68.50208282, 23.79292107], [68.50208282, 23.79264069], [68.50319672, 23.79264069], [68.50319672, 23.79236031], [68.50347137, 23.79236031], [68.50347137, 23.79208183], [68.50375366, 23.79208374], [68.50375366, 23.79180527], [68.50402832, 23.7918129], [68.50402832, 23.79153252], [68.5045929, 23.79153252], [68.5045929, 23.79125023], [68.50514221, 23.79125023], [68.50514221, 23.79097176], [68.50541687, 23.79097176], [68.50541687, 23.79069519], [68.50567627, 23.79071045], [68.50567627, 23.79042244], [68.50596619, 23.79042244], [68.50596619, 23.79014015], [68.50624847, 23.79014015], [68.50624847, 23.78957748], [68.50653076, 23.78958321], [68.50653076, 23.78930473], [68.50680542, 23.78930473], [68.50680542, 23.78902817], [68.50736237, 23.78902817], [68.50736237, 23.78874969], [68.50791931, 23.78874969], [68.50791931, 23.78847122], [68.50846863, 23.78847313], [68.50846863, 23.78819466], [68.50930786, 23.78819466], [68.50930786, 23.78791618], [68.50985718, 23.78791809], [68.50985718, 23.78764915], [68.51097107, 23.78764915], [68.51097107, 23.78736115], [68.51264191, 23.78736115], [68.51264191, 23.78652954], [68.51291656, 23.78652954], [68.51291656, 23.78486061], [68.51319122, 23.78486061], [68.51319122, 23.78375053], [68.51403046, 23.78375053], [68.51403046, 23.78318977], [68.51430511, 23.78319359], [68.51430511, 23.78208351], [68.51457977, 23.78208351], [68.51457977, 23.78152847], [68.51486206, 23.78152847], [68.51486206, 23.78125], [68.51513672, 23.78125], [68.51513672, 23.7804203], [68.51541901, 23.7804203], [68.51541901, 23.77985954], [68.51569366, 23.77986145], [68.51569366, 23.77930641], [68.51597595, 23.77931023], [68.51597595, 23.77902985], [68.51625061, 23.77902985], [68.51625061, 23.77874947], [68.5165329, 23.77874947], [68.51652527, 23.7784729], [68.51680756, 23.77848053], [68.51680756, 23.77819252], [68.5173645, 23.77819443], [68.5173645, 23.77763939], [68.51790619, 23.77763939], [68.51790619, 23.77736092]]], [[[68.34931183, 23.80014038], [68.34931183, 23.7990303], [68.34902954, 23.7990303], [68.34902954, 23.79319191], [68.34874725, 23.79319382], [68.34874725, 23.79069519], [68.3484726, 23.79071045], [68.3484726, 23.78791809], [68.34819794, 23.78791809], [68.34819794, 23.78569031], [68.34791565, 23.78569412], [68.34791565, 23.78402519], [68.34764099, 23.78403091], [68.34764099, 23.78264046], [68.3473587, 23.78264046], [68.3473587, 23.78181076], [68.34707642, 23.78181076], [68.34707642, 23.78096962], [68.34680939, 23.78097153], [68.34680176, 23.78013802], [68.3465271, 23.78013992], [68.3465271, 23.77958107], [68.34625244, 23.77958107], [68.34625244, 23.77930641], [68.34597015, 23.77931023], [68.34597015, 23.77902985], [68.34570313, 23.77902985], [68.34570313, 23.77874947], [68.34541321, 23.77874947], [68.34541321, 23.77848053], [68.34513855, 23.77848053], [68.34513855, 23.77819252], [68.34486389, 23.77819443], [68.34486389, 23.77791595], [68.3445816, 23.77792168], [68.3445816, 23.77763939], [68.34401703, 23.77763939], [68.34401703, 23.77736092], [68.34236145, 23.77736092], [68.34236145, 23.77708054], [68.34041595, 23.77708244], [68.34043121, 23.77763939], [68.3401413, 23.77763939], [68.3401413, 23.77792168], [68.33985901, 23.77792168], [68.33985901, 23.77848053], [68.33957672, 23.77848053], [68.33957672, 23.77931023], [68.33985901, 23.77931023], [68.33985901, 23.78264046], [68.3401413, 23.78263855], [68.3401413, 23.78319359], [68.34043121, 23.78318977], [68.34043121, 23.78403091], [68.34069061, 23.78403091], [68.34069824, 23.78514099], [68.3409729, 23.78514099], [68.3409729, 23.78625107], [68.34124756, 23.78625107], [68.34124756, 23.78736115], [68.34152985, 23.78736115], [68.34152985, 23.78847313], [68.3418045, 23.78847313], [68.3418045, 23.78930473], [68.34208679, 23.78930473], [68.34208679, 23.78986168], [68.34236145, 23.78986168], [68.34236145, 23.79042244], [68.34263611, 23.79041672], [68.34263611, 23.79097176], [68.3429184, 23.79097176], [68.3429184, 23.79153252], [68.3431778, 23.79153252], [68.3431778, 23.79236031], [68.3434906, 23.79236031], [68.3434906, 23.79292107], [68.34375, 23.79291725], [68.34375, 23.79347229], [68.34401703, 23.79346275], [68.34401703, 23.79403114], [68.34430695, 23.79402733], [68.34430695, 23.79458237], [68.3445816, 23.79458046], [68.3445816, 23.79514122], [68.34486389, 23.79513931], [68.34486389, 23.79569244], [68.34513855, 23.79569054], [68.34513855, 23.79624939], [68.34541321, 23.79624939], [68.34541321, 23.79681015], [68.3456955, 23.79680443], [68.3456955, 23.79736137], [68.34597015, 23.79735947], [68.34597015, 23.79792023], [68.34625244, 23.79791451], [68.34625244, 23.79847145], [68.3465271, 23.79846954], [68.3465271, 23.79874992], [68.34680176, 23.79874992], [68.34680176, 23.7990303], [68.34707642, 23.7990303], [68.34707642, 23.79959106], [68.3473587, 23.79958344], [68.3473587, 23.79986191], [68.34764099, 23.79985809], [68.34764099, 23.80014038], [68.34902954, 23.80014038], [68.34902954, 23.80042076], [68.34958649, 23.80042076], [68.34958649, 23.80014038], [68.34931183, 23.80014038]]], [[[68.60514069, 23.80958557], [68.60514069, 23.80930328], [68.60569763, 23.80931091], [68.60569763, 23.80875015], [68.60597229, 23.80875015], [68.60597229, 23.80792046], [68.60624695, 23.80792046], [68.60624695, 23.80708122], [68.60652924, 23.80708122], [68.60652924, 23.80652809], [68.60736084, 23.80653191], [68.60736084, 23.80624962], [68.60791779, 23.80624962], [68.60791779, 23.80569267], [68.6076355, 23.80569458], [68.6076355, 23.80541611], [68.60736084, 23.80542183], [68.60736084, 23.80486107], [68.60708618, 23.80486107], [68.60708618, 23.80458069], [68.60680389, 23.8045826], [68.60680389, 23.80347252], [68.60624695, 23.80347252], [68.60624695, 23.80319405], [68.60597229, 23.80319405], [68.60597229, 23.80264091], [68.60569763, 23.80265045], [68.60569763, 23.80236053], [68.60541534, 23.80236053], [68.60541534, 23.80208397], [68.60514069, 23.80208397], [68.60514069, 23.80152893], [68.6048584, 23.80153084], [68.6048584, 23.80125046], [68.60457611, 23.80125046], [68.60457611, 23.80096817], [68.60430908, 23.80097198], [68.60430908, 23.80069351], [68.60375214, 23.80069351], [68.60375214, 23.80041885], [68.60346985, 23.80042076], [68.60346985, 23.79985809], [68.60319519, 23.79986191], [68.60319519, 23.79958344], [68.6029129, 23.79959106], [68.6029129, 23.79931068], [68.60263824, 23.79931068], [68.60263824, 23.7990303], [68.60208893, 23.7990303], [68.60208893, 23.79874992], [68.60180664, 23.79874992], [68.60180664, 23.79792023], [68.60208893, 23.79792023], [68.60208893, 23.79681015], [68.60180664, 23.79681015], [68.60180664, 23.79624939], [68.60151672, 23.79624939], [68.60151672, 23.79597092], [68.60124969, 23.79597092], [68.60124969, 23.79624939], [68.60041809, 23.79624939], [68.60041809, 23.79652786], [68.59874725, 23.79652023], [68.59874725, 23.79681015], [68.59819794, 23.79681015], [68.59819794, 23.79652023], [68.59791565, 23.79652786], [68.59791565, 23.79624939], [68.59764099, 23.79624939], [68.59764099, 23.79569054], [68.59708405, 23.79569244], [68.59708405, 23.79597473], [68.59680176, 23.79597092], [68.59680176, 23.79624939], [68.5965271, 23.79624939], [68.5965271, 23.79652786], [68.59625244, 23.79652023], [68.59625244, 23.79681015], [68.59513855, 23.79680443], [68.59513855, 23.79736137], [68.59486389, 23.79736137], [68.59486389, 23.79819679], [68.5945816, 23.79819107], [68.5945816, 23.79874992], [68.59430695, 23.79874992], [68.59430695, 23.79931068], [68.59402466, 23.79930687], [68.59402466, 23.79986191], [68.59375, 23.79986191], [68.59375, 23.8006897], [68.59401703, 23.80069923], [68.59401703, 23.80125046], [68.59430695, 23.80125046], [68.59430695, 23.80180931], [68.59401703, 23.80180931], [68.59401703, 23.80236053], [68.59375, 23.80236053], [68.59375, 23.80291939], [68.59347534, 23.80291748], [68.59347534, 23.80347252], [68.59401703, 23.80347061], [68.59401703, 23.80374908], [68.59570313, 23.80374908], [68.59570313, 23.80402946], [68.59707642, 23.80402946], [68.59707642, 23.80431175], [68.59874725, 23.80430603], [68.59874725, 23.8045826], [68.59902954, 23.80458069], [68.59902954, 23.80513954], [68.5993042, 23.80513954], [68.5993042, 23.80569458], [68.59958649, 23.80569267], [68.59958649, 23.80624962], [68.59986115, 23.80624962], [68.59986115, 23.80653191], [68.6001358, 23.80652809], [68.6001358, 23.80708122], [68.60041809, 23.80708122], [68.60041809, 23.80764008], [68.60069275, 23.80764008], [68.60069275, 23.80792046], [68.60098267, 23.80792046], [68.60098267, 23.80820084], [68.60152435, 23.80819321], [68.60152435, 23.80847168], [68.60180664, 23.80846024], [68.60180664, 23.80875015], [68.60208893, 23.80875015], [68.60208893, 23.80903053], [68.6029129, 23.80903053], [68.6029129, 23.80931091], [68.60402679, 23.80930328], [68.60402679, 23.80958557], [68.60514069, 23.80958557]]], [[[68.5965271, 23.81264114], [68.5965271, 23.81208038], [68.59625244, 23.8120842], [68.59625244, 23.81180763], [68.59597015, 23.81180954], [68.59597015, 23.81153107], [68.59570313, 23.81153107], [68.59570313, 23.81068993], [68.59541321, 23.81069374], [68.59541321, 23.8101387], [68.59430695, 23.8101387], [68.59430695, 23.81069374], [68.59401703, 23.81068993], [68.59401703, 23.81125069], [68.59375, 23.81125069], [68.59375, 23.81153107], [68.59347534, 23.81152534], [68.59347534, 23.8120842], [68.59401703, 23.81208038], [68.59401703, 23.81236076], [68.59513855, 23.81236076], [68.59513855, 23.81264114], [68.5965271, 23.81264114]]], [[[68.3434906, 23.83792114], [68.34375, 23.83791542], [68.34375, 23.83847237], [68.34401703, 23.83847046], [68.34401703, 23.83876038], [68.34430695, 23.83876038], [68.34430695, 23.83930969], [68.3445816, 23.83930779], [68.3445816, 23.83958244], [68.34485626, 23.83958054], [68.34485626, 23.83986092], [68.34513855, 23.83986092], [68.34513855, 23.84013939], [68.34541321, 23.84013939], [68.34541321, 23.84041977], [68.3456955, 23.84041786], [68.3456955, 23.84069443], [68.34597015, 23.84069443], [68.34597015, 23.8409729], [68.3465271, 23.84097099], [68.3465271, 23.84124947], [68.34680176, 23.84124947], [68.34680176, 23.84152985], [68.34707642, 23.84152985], [68.34707642, 23.84182167], [68.34764099, 23.84180641], [68.34764099, 23.84208298], [68.34819794, 23.84208298], [68.34819794, 23.84236145], [68.34902954, 23.84235954], [68.34902954, 23.84263992], [68.34958649, 23.84263992], [68.34958649, 23.8429184], [68.3501358, 23.8429184], [68.3501358, 23.84320259], [68.35124969, 23.84319496], [68.35124969, 23.84347153], [68.35180664, 23.84347153], [68.35180664, 23.84375191], [68.35237122, 23.84375191], [68.35237122, 23.84403038], [68.35263824, 23.84403038], [68.35263824, 23.84431267], [68.35319519, 23.84430504], [68.35319519, 23.84458351], [68.35346985, 23.84458351], [68.35346985, 23.84486008], [68.35402679, 23.84486008], [68.35402679, 23.84514046], [68.35430908, 23.84514046], [68.35430908, 23.84542274], [68.35458374, 23.84541702], [68.35458374, 23.84569359], [68.35514069, 23.84569359], [68.35514069, 23.84597015], [68.35541534, 23.84597015], [68.35541534, 23.84708214], [68.35569763, 23.84708023], [68.35569763, 23.84791946], [68.35597229, 23.84791756], [68.35597229, 23.84819221], [68.35624695, 23.84819031], [68.35624695, 23.84875107], [68.35652924, 23.84875107], [68.35652924, 23.84902954], [68.35679626, 23.84902954], [68.35679626, 23.84930992], [68.35708618, 23.8493042], [68.35708618, 23.84958267], [68.3576355, 23.84958267], [68.3576355, 23.84986115], [68.35791779, 23.84986115], [68.35791779, 23.85013962], [68.3584671, 23.85013962], [68.3584671, 23.85042], [68.35901642, 23.85042], [68.35901642, 23.85070038], [68.35958099, 23.85069656], [68.35958099, 23.85097313], [68.36013794, 23.85097122], [68.36013794, 23.85124969], [68.36068726, 23.85124969], [68.36068726, 23.85153008], [68.36125183, 23.85152626], [68.36125183, 23.85180664], [68.36180878, 23.85180664], [68.36180878, 23.85208321], [68.36235809, 23.85208321], [68.36235809, 23.85236168], [68.36292267, 23.85235977], [68.36292267, 23.85264015], [68.36431122, 23.85264015], [68.36431122, 23.85292053], [68.36458588, 23.85291862], [68.36458588, 23.85347176], [68.36486053, 23.85346985], [68.36486053, 23.85375977], [68.36569214, 23.85375977], [68.36569214, 23.85403061], [68.36653137, 23.85403061], [68.36653137, 23.85430908], [68.36708069, 23.85430527], [68.36708069, 23.85458374], [68.36791992, 23.85457993], [68.36791992, 23.85486031], [68.36846924, 23.85486031], [68.36846924, 23.85514069], [68.36902618, 23.85514069], [68.36902618, 23.85541916], [68.36958313, 23.85541725], [68.36958313, 23.85569382], [68.37014008, 23.85569382], [68.37014008, 23.85597229], [68.37069702, 23.85597038], [68.37069702, 23.85625076], [68.37097168, 23.85625076], [68.37097168, 23.85652924], [68.37124634, 23.85652733], [68.37124634, 23.8568058], [68.37152863, 23.8568058], [68.37152863, 23.85708427], [68.37180328, 23.85707855], [68.37180328, 23.85736084], [68.3720932, 23.85736084], [68.3720932, 23.85763931], [68.37236023, 23.85763931], [68.37236023, 23.85791969], [68.37291718, 23.85791969], [68.37291718, 23.85763931], [68.37319183, 23.85763931], [68.37319183, 23.85736084], [68.37346649, 23.85736084], [68.37346649, 23.85707855], [68.37374878, 23.85708427], [68.37374878, 23.8568058], [68.37403107, 23.8568058], [68.37403107, 23.85652733], [68.37486267, 23.85652733], [68.37486267, 23.85708427], [68.37513733, 23.85707855], [68.37513733, 23.85736084], [68.37568665, 23.85736084], [68.37568665, 23.85763931], [68.37596893, 23.85763931], [68.37596893, 23.85791969], [68.37708282, 23.85791588], [68.37708282, 23.85847282], [68.37568665, 23.85847282], [68.37568665, 23.85874939], [68.37458038, 23.85874939], [68.37458038, 23.85902977], [68.37431335, 23.85902977], [68.37431335, 23.85931015], [68.37403107, 23.85930634], [68.37403107, 23.8595829], [68.37374878, 23.85957146], [68.37374878, 23.86013985], [68.37403107, 23.86013985], [68.37403107, 23.8615303], [68.37431335, 23.8615303], [68.37431335, 23.86431122], [68.37458038, 23.86431122], [68.37458038, 23.86541939], [68.37486267, 23.86541939], [68.37486267, 23.86680984], [68.37513733, 23.86680984], [68.37513733, 23.86763954], [68.37541962, 23.86763954], [68.37541962, 23.86847305], [68.37569427, 23.86847305], [68.37569427, 23.86958313], [68.37596893, 23.86958122], [68.37596893, 23.87042236], [68.37625122, 23.87042236], [68.37625122, 23.87153053], [68.37652588, 23.87152863], [68.37652588, 23.87236023], [68.37680817, 23.87236023], [68.37680817, 23.8729229], [68.37708282, 23.87291718], [68.37708282, 23.87319374], [68.37735748, 23.87319374], [68.37735748, 23.87347221], [68.37763977, 23.87347031], [68.37763977, 23.87403107], [68.3779068, 23.87403107], [68.3779068, 23.87430954], [68.37847137, 23.87430573], [68.37847137, 23.87458229], [68.37874603, 23.87458038], [68.37874603, 23.8748703], [68.38014221, 23.8748703], [68.38014221, 23.87458038], [68.38180542, 23.87458229], [68.38180542, 23.87430573], [68.38318634, 23.87430954], [68.38318634, 23.87403107], [68.38764191, 23.87403107], [68.38764191, 23.87430954], [68.38874817, 23.87430573], [68.38874817, 23.87458229], [68.38957977, 23.87458038], [68.38957977, 23.8748703], [68.39013672, 23.8748703], [68.39013672, 23.87514114], [68.39041901, 23.87514114], [68.39041901, 23.87541962], [68.39069366, 23.8754158], [68.39069366, 23.87569237], [68.39097595, 23.87569237], [68.39097595, 23.87597275], [68.39154053, 23.87597084], [68.39154053, 23.87625122], [68.39180756, 23.87625122], [68.39180756, 23.87652969], [68.39235687, 23.87652969], [68.39235687, 23.87681007], [68.39263916, 23.87680435], [68.39263916, 23.87708282], [68.39319611, 23.87708282], [68.39319611, 23.8773613], [68.39347076, 23.87735939], [68.39347076, 23.87763977], [68.39375305, 23.87763977], [68.39375305, 23.87792969], [68.39402771, 23.87791443], [68.39402771, 23.87819672], [68.39569092, 23.87819672], [68.39569092, 23.87791443], [68.39624786, 23.87792969], [68.39624786, 23.87763977], [68.39679718, 23.87763977], [68.39679718, 23.87735939], [68.3970871, 23.8773613], [68.3970871, 23.87708282], [68.39763641, 23.87708282], [68.39763641, 23.87680435], [68.39819336, 23.87681007], [68.39819336, 23.87652969], [68.39875031, 23.87652969], [68.39875031, 23.87625122], [68.39958191, 23.87625122], [68.39958191, 23.87597084], [68.40013885, 23.87597275], [68.40013885, 23.87569237], [68.40097046, 23.87569237], [68.40097046, 23.8754158], [68.4015274, 23.87541962], [68.4015274, 23.87514114], [68.40235901, 23.87514114], [68.40235901, 23.8748703], [68.40291595, 23.8748703], [68.40291595, 23.87458038], [68.4034729, 23.87458229], [68.4034729, 23.87430573], [68.40429688, 23.87430954], [68.40429688, 23.87403107], [68.40486145, 23.87403107], [68.40486145, 23.87375069], [68.4054184, 23.87375069], [68.4054184, 23.87347031], [68.40597534, 23.87347221], [68.40597534, 23.87319374], [68.40652466, 23.87319374], [68.40652466, 23.87291718], [68.4070816, 23.8729229], [68.4070816, 23.87264061], [68.40791321, 23.87264061], [68.40791321, 23.87236023], [68.40847015, 23.87236023], [68.40847015, 23.87208176], [68.4090271, 23.87208366], [68.4090271, 23.87180519], [68.4109726, 23.87180519], [68.4109726, 23.87152863], [68.41236115, 23.87153053], [68.41236115, 23.87125015], [68.41348267, 23.87125015], [68.41347504, 23.87097168], [68.41486359, 23.87097168], [68.41486359, 23.87069511], [68.41680908, 23.87070274], [68.41680908, 23.87042236], [68.4173584, 23.87042236], [68.4173584, 23.87014008], [68.41792297, 23.87014008], [68.41792297, 23.8698597], [68.41819763, 23.8698616], [68.41819763, 23.86958313], [68.41874695, 23.86958313], [68.41874695, 23.86930466], [68.41930389, 23.86930466], [68.41930389, 23.86902809], [68.41986084, 23.86902809], [68.41986084, 23.86874008], [68.4201355, 23.86874962], [68.4201355, 23.86847305], [68.42069244, 23.86847305], [68.42069244, 23.86819458], [68.42097473, 23.86819458], [68.42097473, 23.86791611], [68.42124939, 23.86791992], [68.42124939, 23.86763954], [68.42151642, 23.86763954], [68.42151642, 23.86736107], [68.42180634, 23.86736107], [68.42180634, 23.86708069], [68.42208099, 23.8670826], [68.42208099, 23.86680794], [68.42236328, 23.86680984], [68.42236328, 23.86652946], [68.42263794, 23.86652946], [68.42263794, 23.86625099], [68.42292023, 23.86625099], [68.42292023, 23.86597061], [68.42319489, 23.86597252], [68.42319489, 23.86569595], [68.42346954, 23.86569977], [68.42346954, 23.86541939], [68.42375183, 23.86541939], [68.42375183, 23.86514091], [68.42402649, 23.86514091], [68.42402649, 23.86486053], [68.42459106, 23.86486053], [68.42458344, 23.86319351], [68.42485809, 23.8631897], [68.42485809, 23.86291695], [68.42514038, 23.8629303], [68.42514038, 23.86236], [68.42541504, 23.86236191], [68.42541504, 23.8615284], [68.42569733, 23.8615303], [68.42569733, 23.85985947], [68.42541504, 23.85986137], [68.42541504, 23.85819435], [68.42514038, 23.85819435], [68.42514038, 23.85736084], [68.42485809, 23.85736084], [68.42485809, 23.85625076], [68.42458344, 23.85625076], [68.42458344, 23.85541725], [68.42485809, 23.85541916], [68.42485809, 23.85486031], [68.42514038, 23.85486031], [68.42514038, 23.85430908], [68.42542267, 23.85430908], [68.42542267, 23.85375977], [68.42569733, 23.85375977], [68.42569733, 23.85320091], [68.42597198, 23.85320091], [68.42597198, 23.85264015], [68.42624664, 23.85264015], [68.42624664, 23.85207939], [68.42652893, 23.85208321], [68.42652893, 23.85152626], [68.42679596, 23.85153008], [68.42679596, 23.85097122], [68.42708588, 23.85097313], [68.42708588, 23.85041428], [68.42736053, 23.85042], [68.42736053, 23.85013962], [68.42765045, 23.85013962], [68.42763519, 23.84986115], [68.42791748, 23.84986115], [68.42791748, 23.84930992], [68.42819214, 23.84930992], [68.42819214, 23.84902954], [68.4284668, 23.84902954], [68.4284668, 23.84875107], [68.42874908, 23.84875107], [68.42874908, 23.84819031], [68.42903137, 23.84819221], [68.42903137, 23.84791756], [68.42930603, 23.84791946], [68.42930603, 23.84762955], [68.42903137, 23.84763908], [68.42903137, 23.84708214], [68.42930603, 23.84708214], [68.42930603, 23.84680557], [68.42874908, 23.84680939], [68.42874908, 23.84597015], [68.42958069, 23.84597015], [68.42958069, 23.84625053], [68.43068695, 23.84625053], [68.43068695, 23.84597015], [68.43125153, 23.84597015], [68.43125153, 23.84569359], [68.43152618, 23.84569359], [68.43152618, 23.84541702], [68.43180847, 23.84542274], [68.43180847, 23.84514046], [68.43208313, 23.84514046], [68.43208313, 23.84486008], [68.43235779, 23.84486008], [68.43235779, 23.84458351], [68.43264008, 23.84458351], [68.43264008, 23.84430504], [68.4329071, 23.84431267], [68.4329071, 23.84403038], [68.43319702, 23.84403038], [68.43319702, 23.84375191], [68.43345642, 23.84375191], [68.43345642, 23.84347153], [68.43374634, 23.84347153], [68.43374634, 23.84319496], [68.43402863, 23.84320259], [68.43402863, 23.8429184], [68.4345932, 23.8429184], [68.4345932, 23.84263992], [68.43486023, 23.84263992], [68.43486023, 23.84235954], [68.43514252, 23.84236145], [68.43514252, 23.84208298], [68.43541718, 23.84208298], [68.43541718, 23.84180641], [68.43596649, 23.84182167], [68.43596649, 23.84152985], [68.43624878, 23.84152985], [68.43624878, 23.84124947], [68.43653107, 23.84124947], [68.43653107, 23.84097099], [68.43708038, 23.8409729], [68.43708038, 23.84069443], [68.43736267, 23.84069443], [68.43736267, 23.84041786], [68.43763733, 23.84041977], [68.43763733, 23.84013939], [68.43791962, 23.84013939], [68.43791962, 23.83986092], [68.43818665, 23.83986092], [68.43818665, 23.83958054], [68.43846893, 23.83958244], [68.43846893, 23.83930779], [68.43902588, 23.83930969], [68.43902588, 23.83903122], [68.43930817, 23.83903122], [68.43930817, 23.83792114], [68.43902588, 23.83792114], [68.43902588, 23.83542061], [68.43875122, 23.83542061], [68.43875122, 23.8343029], [68.43846893, 23.83430481], [68.43846893, 23.83374977], [68.43818665, 23.83374977], [68.43818665, 23.83319283], [68.43791962, 23.83319473], [68.43791962, 23.83291626], [68.43763733, 23.83292007], [68.43763733, 23.83236122], [68.43736267, 23.83236122], [68.43736267, 23.83208275], [68.43708038, 23.83208275], [68.43708038, 23.83152771], [68.43682098, 23.83152962], [68.43682098, 23.83097076], [68.43653107, 23.83097267], [68.43653107, 23.83041573], [68.43624878, 23.83041954], [68.43624878, 23.82986069], [68.43596649, 23.82986069], [68.43596649, 23.82930946], [68.43569183, 23.82930946], [68.43569183, 23.82902908], [68.43541718, 23.82902908], [68.43541718, 23.82846832], [68.43514252, 23.82847214], [68.43514252, 23.8279171], [68.43486023, 23.82792091], [68.43486023, 23.82764053], [68.4345932, 23.82764053], [68.4345932, 23.82707977], [68.43430328, 23.82708359], [68.43430328, 23.82680511], [68.43374634, 23.82681847], [68.43374634, 23.82653046], [68.43345642, 23.82653046], [68.43345642, 23.82625008], [68.4329071, 23.82625008], [68.4329071, 23.82570076], [68.43264008, 23.82570076], [68.43264008, 23.82514], [68.43235779, 23.82514], [68.43235779, 23.82485962], [68.43208313, 23.82486153], [68.43208313, 23.82458305], [68.43152618, 23.82458305], [68.43152618, 23.82430458], [68.43125153, 23.82430077], [68.43125153, 23.82402611], [68.43096924, 23.82402992], [68.43096924, 23.82347107], [68.43069458, 23.82347488], [68.43069458, 23.82319641], [68.43041992, 23.82319641], [68.43041992, 23.82291412], [68.43013763, 23.82291985], [68.43013763, 23.82236099], [68.42986298, 23.82236099], [68.42986298, 23.82208061], [68.42958069, 23.82208252], [68.42958069, 23.82152748], [68.42930603, 23.82152939], [68.42930603, 23.82097054], [68.42903137, 23.82097244], [68.42903137, 23.8204174], [68.42874908, 23.82042122], [68.42874908, 23.81986046], [68.4284668, 23.81986046], [68.4284668, 23.81931114], [68.42819214, 23.81931114], [68.42819214, 23.81875038], [68.42791748, 23.81875038], [68.42791748, 23.81792259], [68.42765045, 23.81792259], [68.42765045, 23.81679916], [68.42736053, 23.81680489], [68.42736053, 23.81569481], [68.42708588, 23.81569481], [68.42708588, 23.81458282], [68.42679596, 23.81459045], [68.42679596, 23.81291962], [68.42652893, 23.81291962], [68.42652893, 23.81042099], [68.42569733, 23.81042099], [68.42569733, 23.81014061], [68.42485809, 23.81014061], [68.42485809, 23.80986023], [68.42430878, 23.80986023], [68.42430878, 23.80957985], [68.42402649, 23.80958557], [68.42402649, 23.80930328], [68.42346954, 23.80931091], [68.42346954, 23.80903053], [68.42292023, 23.80903053], [68.42292023, 23.80875015], [68.42263794, 23.80875015], [68.42263794, 23.80846024], [68.42208099, 23.80847168], [68.42208099, 23.80819321], [68.42151642, 23.80820084], [68.42151642, 23.80792046], [68.4209671, 23.80792046], [68.4209671, 23.80764008], [68.42069244, 23.80764008], [68.42069244, 23.8073597], [68.4201355, 23.8073616], [68.4201355, 23.80708122], [68.41986084, 23.80708122], [68.41986084, 23.80680466], [68.41958618, 23.80680466], [68.41958618, 23.80652809], [68.41902924, 23.80653191], [68.41902924, 23.80624962], [68.41874695, 23.80624962], [68.41874695, 23.80597115], [68.41847229, 23.80597115], [68.41847229, 23.80569458], [68.41819763, 23.80569458], [68.41819763, 23.80541611], [68.41792297, 23.80542183], [68.41792297, 23.80513954], [68.41764069, 23.80513954], [68.41764069, 23.80569458], [68.41708374, 23.80569458], [68.41708374, 23.80597115], [68.41652679, 23.80597115], [68.41652679, 23.80624962], [68.41596985, 23.80624962], [68.41596985, 23.80653191], [68.41569519, 23.80652809], [68.41569519, 23.80680466], [68.41513824, 23.80680466], [68.41513824, 23.80708122], [68.41430664, 23.80708122], [68.41430664, 23.8073616], [68.41348267, 23.8073597], [68.41348267, 23.80764008], [68.41291809, 23.80764008], [68.41291809, 23.80792046], [68.41265106, 23.80792046], [68.41265106, 23.80820084], [68.41208649, 23.80819321], [68.41208649, 23.80847168], [68.41152954, 23.80846024], [68.41152954, 23.80875015], [68.41069794, 23.80875015], [68.41069794, 23.80903053], [68.41014099, 23.80903053], [68.41014099, 23.80931091], [68.4098587, 23.80931091], [68.4098587, 23.80986023], [68.40957642, 23.80986023], [68.40957642, 23.81014061], [68.4092865, 23.81014061], [68.4092865, 23.81042099], [68.4090271, 23.81041527], [68.4090271, 23.81069374], [68.40875244, 23.81069374], [68.40875244, 23.81097221], [68.40847015, 23.81097031], [68.40847015, 23.81180954], [68.4081955, 23.81180763], [68.40820313, 23.81236076], [68.40791321, 23.81236076], [68.40791321, 23.81430817], [68.4081955, 23.81430626], [68.4081955, 23.81513977], [68.40875244, 23.81513977], [68.40875244, 23.81541824], [68.4090271, 23.81541634], [68.4090271, 23.81597137], [68.40957642, 23.81596756], [68.40957642, 23.81624985], [68.4098587, 23.81624985], [68.4098587, 23.81653023], [68.41014099, 23.81652832], [68.41014099, 23.81680489], [68.41041565, 23.81680489], [68.41041565, 23.81708336], [68.41069794, 23.81708336], [68.41069794, 23.81736183], [68.4109726, 23.81736183], [68.4109726, 23.81792259], [68.41124725, 23.81792259], [68.41124725, 23.81820107], [68.41152954, 23.81819534], [68.41152954, 23.81847191], [68.41179657, 23.81847191], [68.41179657, 23.81875038], [68.41208649, 23.81875038], [68.41208649, 23.81903267], [68.41236115, 23.81903267], [68.41236115, 23.81931114], [68.4126358, 23.81930542], [68.4126358, 23.81958389], [68.41291809, 23.81958389], [68.41291809, 23.82069206], [68.4126358, 23.82069206], [68.4126358, 23.82097244], [68.41152954, 23.82097244], [68.41152954, 23.8204174], [68.41124725, 23.82042122], [68.41124725, 23.81986046], [68.41069794, 23.81986046], [68.41069794, 23.81958008], [68.41041565, 23.81958389], [68.41041565, 23.81930542], [68.41014099, 23.81931114], [68.41014099, 23.81875038], [68.4098587, 23.81875038], [68.4098587, 23.81847191], [68.40958405, 23.81847191], [68.40958405, 23.81791687], [68.4090271, 23.81792259], [68.4090271, 23.81764984], [68.40875244, 23.81764984], [68.40875244, 23.81736183], [68.40847015, 23.81736183], [68.40847015, 23.81708336], [68.4081955, 23.81708336], [68.4081955, 23.81680489], [68.40791321, 23.81680489], [68.40791321, 23.81652832], [68.40763855, 23.81653023], [68.40763855, 23.81624985], [68.40735626, 23.81624985], [68.40735626, 23.81596756], [68.4070816, 23.81597137], [68.4070816, 23.81569481], [68.40680695, 23.81569481], [68.40680695, 23.81513977], [68.40651703, 23.81513977], [68.40651703, 23.81180954], [68.40680695, 23.81180954], [68.40680695, 23.81125069], [68.4070816, 23.81125069], [68.4070816, 23.81014061], [68.40735626, 23.81014061], [68.40735626, 23.80986023], [68.40763855, 23.80986023], [68.40763855, 23.80957985], [68.40791321, 23.80958557], [68.40791321, 23.80930328], [68.40820313, 23.80931091], [68.40820313, 23.80903053], [68.40847015, 23.80903053], [68.40847015, 23.80875015], [68.40875244, 23.80875015], [68.40875244, 23.80846024], [68.4090271, 23.80847168], [68.4090271, 23.80819321], [68.4092865, 23.80820084], [68.40930939, 23.80792046], [68.40957642, 23.80792046], [68.40957642, 23.80764008], [68.41014099, 23.80764008], [68.41014099, 23.8073597], [68.4109726, 23.8073616], [68.4109726, 23.80708122], [68.41152954, 23.80708122], [68.41152954, 23.80680466], [68.41208649, 23.80680466], [68.41208649, 23.80652809], [68.41236115, 23.80653191], [68.41236115, 23.80624962], [68.41291809, 23.80624962], [68.41291809, 23.80597115], [68.41347504, 23.80597115], [68.41347504, 23.80569458], [68.41374969, 23.80569458], [68.41374969, 23.80541611], [68.41430664, 23.80542183], [68.41430664, 23.80513954], [68.41485596, 23.80513954], [68.41485596, 23.80486107], [68.41513824, 23.80486107], [68.41513824, 23.80431175], [68.41542053, 23.80431175], [68.41542053, 23.80374908], [68.41596985, 23.80374908], [68.41596985, 23.80207825], [68.41569519, 23.80208397], [68.41569519, 23.80152893], [68.41542053, 23.80153084], [68.41542053, 23.80125046], [68.41513824, 23.80125046], [68.41513824, 23.80096817], [68.41486359, 23.80097198], [68.41486359, 23.80069351], [68.4145813, 23.80069351], [68.4145813, 23.80013847], [68.41430664, 23.80014038], [68.41430664, 23.79985809], [68.41402435, 23.79986191], [68.41402435, 23.79958344], [68.41374969, 23.79959106], [68.41374969, 23.79931068], [68.41348267, 23.79931068], [68.41348267, 23.7990303], [68.41319275, 23.7990303], [68.41319275, 23.79874992], [68.41291809, 23.79874992], [68.41291809, 23.79846954], [68.4126358, 23.79847145], [68.4126358, 23.79819679], [68.41236115, 23.79819679], [68.41236115, 23.79791451], [68.41208649, 23.79792023], [68.41208649, 23.79735947], [68.4118042, 23.79736137], [68.4118042, 23.79680443], [68.41152954, 23.79681015], [68.41152954, 23.79652023], [68.41124725, 23.79652786], [68.41124725, 23.79624939], [68.4109726, 23.79624939], [68.4109726, 23.79569054], [68.41014099, 23.79569244], [68.41014099, 23.79541588], [68.4098587, 23.79541969], [68.4098587, 23.79514122], [68.40957642, 23.79514122], [68.40957642, 23.79486084], [68.4090271, 23.79486084], [68.4090271, 23.79458046], [68.40847015, 23.79458237], [68.40847015, 23.7943058], [68.40820313, 23.79430962], [68.40820313, 23.79403114], [68.40763855, 23.79403114], [68.40763855, 23.79375076], [68.4070816, 23.79375076], [68.4070816, 23.79346275], [68.40625, 23.79347229], [68.40625, 23.79319382], [68.4054184, 23.79319191], [68.4054184, 23.79375076], [68.40513611, 23.79375076], [68.40513611, 23.79403114], [68.40486145, 23.79403114], [68.40486145, 23.79430962], [68.4043045, 23.7943058], [68.4043045, 23.79458237], [68.40402985, 23.79458046], [68.40402985, 23.79486084], [68.40319824, 23.79486084], [68.40319061, 23.79514122], [68.40291595, 23.79514122], [68.40291595, 23.79541969], [68.40235901, 23.79541588], [68.40235901, 23.79569244], [68.40180206, 23.79569244], [68.40180206, 23.79597473], [68.4015274, 23.79597092], [68.4015274, 23.79624939], [68.40125275, 23.79624939], [68.40125275, 23.79681015], [68.40097046, 23.79680443], [68.40097046, 23.7970829], [68.4006958, 23.7970829], [68.4006958, 23.79736137], [68.40042114, 23.79735947], [68.40042114, 23.79763985], [68.40013885, 23.79763794], [68.40013885, 23.79819679], [68.3998642, 23.79819679], [68.3998642, 23.79847145], [68.39958191, 23.79846954], [68.39958191, 23.79874992], [68.39930725, 23.79874992], [68.39930725, 23.7990303], [68.39903259, 23.7990303], [68.39903259, 23.79959106], [68.39875031, 23.79958344], [68.39875031, 23.79986191], [68.39819336, 23.79985809], [68.39819336, 23.80014038], [68.3979187, 23.80013847], [68.3979187, 23.80069351], [68.39763641, 23.80069351], [68.39763641, 23.80097198], [68.3973465, 23.80096817], [68.3973465, 23.80125046], [68.3970871, 23.80125046], [68.3970871, 23.80180931], [68.39680481, 23.8018055], [68.39680481, 23.80208397], [68.39653015, 23.80207825], [68.39653015, 23.80236053], [68.39624786, 23.80236053], [68.39624786, 23.80291939], [68.39597321, 23.80291748], [68.39597321, 23.80319405], [68.39569092, 23.80319405], [68.39569092, 23.80347252], [68.39541626, 23.80347061], [68.39541626, 23.80374908], [68.3951416, 23.80374908], [68.3951416, 23.80402946], [68.39485931, 23.80402946], [68.39485931, 23.80431175], [68.39457703, 23.80431175], [68.39457703, 23.80486107], [68.39428711, 23.80486107], [68.39428711, 23.80542183], [68.39402771, 23.80541611], [68.39402771, 23.80597115], [68.39375305, 23.80597115], [68.39375305, 23.80624962], [68.39347076, 23.80624962], [68.39347076, 23.80653191], [68.39319611, 23.80652809], [68.39319611, 23.80708122], [68.39290619, 23.80708122], [68.39290619, 23.80764008], [68.39263916, 23.80763817], [68.39263916, 23.80847168], [68.39235687, 23.80846024], [68.39235687, 23.80875015], [68.39208221, 23.80875015], [68.39208221, 23.80903053], [68.39180756, 23.80902863], [68.39180756, 23.80958557], [68.39208221, 23.80958557], [68.39208221, 23.81097221], [68.39180756, 23.81097221], [68.39180756, 23.8120842], [68.39152527, 23.8120842], [68.39152527, 23.81319427], [68.39125061, 23.81319046], [68.39125061, 23.81430817], [68.39097595, 23.81430626], [68.39097595, 23.81597137], [68.39068604, 23.81596756], [68.39068604, 23.81792259], [68.39097595, 23.81792259], [68.39097595, 23.81986046], [68.39125061, 23.81986046], [68.39125061, 23.82347488], [68.39154053, 23.82347107], [68.39154053, 23.82542038], [68.39180756, 23.82541847], [68.39180756, 23.82819366], [68.39154053, 23.82818985], [68.39154053, 23.82902908], [68.39125061, 23.82902908], [68.39125061, 23.82930946], [68.39097595, 23.82930946], [68.39097595, 23.82986069], [68.39068604, 23.82986069], [68.39068604, 23.83041954], [68.39041901, 23.83041573], [68.39041901, 23.83097267], [68.39013672, 23.83097076], [68.39013672, 23.83152962], [68.38986206, 23.83152771], [68.38986206, 23.83208275], [68.38957977, 23.83208275], [68.38957977, 23.83236122], [68.38931274, 23.83236122], [68.38931274, 23.83292007], [68.38903046, 23.83291626], [68.38903046, 23.8334713], [68.38874817, 23.83346939], [68.38874817, 23.83374977], [68.38847351, 23.83374977], [68.38847351, 23.83430481], [68.38819122, 23.83430481], [68.38819122, 23.83458328], [68.38791656, 23.83458328], [68.38791656, 23.83486176], [68.38764191, 23.83485985], [68.38764191, 23.83514023], [68.38735962, 23.83514023], [68.38735962, 23.83542061], [68.38680267, 23.83541679], [68.38680267, 23.83569336], [68.38652802, 23.83569336], [68.38652802, 23.83597183], [68.38597107, 23.83596992], [68.38597107, 23.83625031], [68.38540649, 23.83625031], [68.38540649, 23.83653069], [68.38513947, 23.83653069], [68.38513947, 23.83681107], [68.38458252, 23.83680344], [68.38458252, 23.83708572], [68.38430786, 23.83708], [68.38430786, 23.83736038], [68.38375092, 23.83736038], [68.38375092, 23.83764076], [68.38263702, 23.83764076], [68.38263702, 23.83792114], [68.38180542, 23.83791542], [68.38180542, 23.8381958], [68.37958527, 23.8381958], [68.37958527, 23.83708572], [68.38014221, 23.83708572], [68.38014221, 23.83680344], [68.38096619, 23.83681107], [68.38096619, 23.83653069], [68.38181305, 23.83653069], [68.38181305, 23.83625031], [68.38263702, 23.83625031], [68.38263702, 23.83596992], [68.38375092, 23.83597183], [68.38375092, 23.83569336], [68.38402557, 23.83569336], [68.38402557, 23.83541679], [68.38458252, 23.83542061], [68.38458252, 23.83514023], [68.38513947, 23.83514023], [68.38513947, 23.83485985], [68.38569641, 23.83486176], [68.38569641, 23.83458328], [68.38625336, 23.83458328], [68.38625336, 23.83430481], [68.38680267, 23.83430481], [68.38680267, 23.83402824], [68.38707733, 23.83403015], [68.38707733, 23.83346939], [68.38735962, 23.8334713], [68.38735962, 23.83319473], [68.38764191, 23.83319473], [68.38764191, 23.83291626], [68.38791656, 23.83292007], [68.38791656, 23.83236122], [68.38819122, 23.83236122], [68.38819122, 23.8318119], [68.38848114, 23.8318119], [68.38848114, 23.83152962], [68.38874817, 23.83152962], [68.38874817, 23.83097076], [68.38903046, 23.83097267], [68.38903046, 23.83041763], [68.38931274, 23.83041954], [68.38931274, 23.82930946], [68.38957977, 23.82930946], [68.38957977, 23.82818985], [68.38986206, 23.82819366], [68.38986206, 23.81930542], [68.38957977, 23.81931114], [68.38957977, 23.81624985], [68.38930511, 23.81624985], [68.38930511, 23.81430626], [68.38957977, 23.81430817], [68.38957977, 23.81180954], [68.38986206, 23.81180954], [68.38986206, 23.81068993], [68.39013672, 23.81069374], [68.39013672, 23.80958557], [68.39041901, 23.80958557], [68.39041901, 23.80902863], [68.39068604, 23.80903053], [68.39068604, 23.80875015], [68.39097595, 23.80875015], [68.39097595, 23.80764008], [68.39125061, 23.80764008], [68.39125061, 23.8073597], [68.39152527, 23.8073616], [68.39152527, 23.80680466], [68.39180756, 23.80680466], [68.39180756, 23.80624962], [68.39208221, 23.80624962], [68.39208221, 23.80542183], [68.39235687, 23.80542183], [68.39235687, 23.80486107], [68.39263916, 23.80486107], [68.39263916, 23.80458069], [68.39291382, 23.8045826], [68.39291382, 23.80430603], [68.39319611, 23.80431175], [68.39319611, 23.80402946], [68.39347076, 23.80402946], [68.39347076, 23.80374908], [68.39375305, 23.80374908], [68.39375305, 23.80318832], [68.39402771, 23.80319405], [68.39402771, 23.80291748], [68.39428711, 23.80291939], [68.39428711, 23.80236053], [68.39457703, 23.80236053], [68.39457703, 23.80180931], [68.39485931, 23.80180931], [68.39485931, 23.80153084], [68.3951416, 23.80153084], [68.3951416, 23.80096817], [68.39541626, 23.80097198], [68.39541626, 23.80041885], [68.39569092, 23.80042076], [68.39569092, 23.80014038], [68.39597321, 23.80014038], [68.39597321, 23.79985809], [68.39624786, 23.79986191], [68.39624786, 23.79958344], [68.39653015, 23.79959106], [68.39653015, 23.79931068], [68.3970871, 23.79931068], [68.3970871, 23.7990303], [68.3973465, 23.7990303], [68.3973465, 23.79874992], [68.39763641, 23.79874992], [68.39763641, 23.79846954], [68.3979187, 23.79847145], [68.3979187, 23.79819679], [68.39819336, 23.79819679], [68.39819336, 23.79791451], [68.39848328, 23.79792023], [68.39848328, 23.79735947], [68.39875031, 23.79736137], [68.39875031, 23.7970829], [68.39902496, 23.7970829], [68.39902496, 23.79680443], [68.39930725, 23.79681015], [68.39930725, 23.79624939], [68.39958191, 23.79624939], [68.39958191, 23.79569054], [68.3998642, 23.79569244], [68.3998642, 23.79541588], [68.40013885, 23.79541969], [68.40013885, 23.79486084], [68.40042114, 23.79486084], [68.40041351, 23.79458237], [68.4006958, 23.79458237], [68.4006958, 23.79402733], [68.40097046, 23.79403114], [68.40097046, 23.79319191], [68.40125275, 23.79319382], [68.40125275, 23.79291725], [68.4015274, 23.79292107], [68.4015274, 23.79264069], [68.40180206, 23.79264069], [68.40180206, 23.79097176], [68.4015274, 23.79097176], [68.4015274, 23.79041672], [68.40125275, 23.79042244], [68.40125275, 23.79014015], [68.40071106, 23.79014015], [68.40071106, 23.78986168], [68.40013885, 23.78986168], [68.40013885, 23.78958321], [68.39902496, 23.78958321], [68.39902496, 23.78986168], [68.3970871, 23.78986168], [68.3970871, 23.79014015], [68.39541626, 23.79014015], [68.39541626, 23.79042244], [68.39402771, 23.79042244], [68.39402771, 23.79071045], [68.39263916, 23.79069519], [68.39263916, 23.79097176], [68.39125061, 23.79097176], [68.39125061, 23.79125023], [68.38986206, 23.79125023], [68.38986206, 23.79153252], [68.38903046, 23.7915287], [68.38903046, 23.79208374], [68.38764191, 23.79208183], [68.38764191, 23.79236031], [68.38707733, 23.79236031], [68.38707733, 23.79264069], [68.38652802, 23.79264069], [68.38652802, 23.79292107], [68.38569641, 23.79291725], [68.38569641, 23.79319382], [68.38513947, 23.79319382], [68.38513947, 23.79347229], [68.38458252, 23.79346275], [68.38458252, 23.79375076], [68.38375092, 23.79375076], [68.38375092, 23.79403114], [68.38318634, 23.79403114], [68.38318634, 23.79430962], [68.38236237, 23.7943058], [68.38236237, 23.79458237], [68.38180542, 23.79458237], [68.38181305, 23.79486084], [68.38096619, 23.79486084], [68.38096619, 23.79514122], [68.38014221, 23.79514122], [68.38014221, 23.79541969], [68.37875366, 23.79541588], [68.37875366, 23.79569244], [68.37847137, 23.79569244], [68.37847137, 23.79597473], [68.37819672, 23.79597092], [68.37819672, 23.79624939], [68.37791443, 23.79624939], [68.37791443, 23.79652786], [68.37763977, 23.79652786], [68.37763977, 23.7970829], [68.37708282, 23.7970829], [68.37708282, 23.79986191], [68.37680817, 23.79985809], [68.37680817, 23.80125046], [68.37652588, 23.80125046], [68.37652588, 23.80208397], [68.37625122, 23.80208397], [68.37625122, 23.80319405], [68.37596893, 23.80318832], [68.37596893, 23.80374908], [68.37541962, 23.80374908], [68.37541962, 23.80431175], [68.37513733, 23.80430603], [68.37513733, 23.8045826], [68.37486267, 23.80458069], [68.37486267, 23.80486107], [68.37458038, 23.80486107], [68.37458038, 23.80513954], [68.37431335, 23.80513954], [68.37431335, 23.80542183], [68.37403107, 23.80541611], [68.37403107, 23.80569458], [68.37347412, 23.80569458], [68.37347412, 23.80597115], [68.37319183, 23.80597115], [68.37319183, 23.80624962], [68.37291718, 23.80624962], [68.37291718, 23.80653191], [68.37264252, 23.80652809], [68.37264252, 23.80680466], [68.37208557, 23.80680466], [68.37208557, 23.80708122], [68.37180328, 23.80708122], [68.37180328, 23.8073616], [68.37152863, 23.8073597], [68.37152863, 23.80764008], [68.37097168, 23.80764008], [68.37097168, 23.80820084], [68.37069702, 23.80819321], [68.37069702, 23.80847168], [68.3704071, 23.80846024], [68.3704071, 23.80875015], [68.36985779, 23.80875015], [68.36985779, 23.80931091], [68.36958313, 23.80930328], [68.36958313, 23.80958557], [68.36818695, 23.80957985], [68.36818695, 23.80986023], [68.36708069, 23.80986023], [68.36708069, 23.80957985], [68.36653137, 23.80957985], [68.36653137, 23.80986023], [68.36541748, 23.80986023], [68.36541748, 23.81014061], [68.36486053, 23.81014061], [68.36486053, 23.80986023], [68.36431122, 23.80986023], [68.36431122, 23.81014061], [68.36292267, 23.81014061], [68.36292267, 23.80986023], [68.36264038, 23.80986023], [68.36264038, 23.81014061], [68.36207581, 23.81014061], [68.36207581, 23.81042099], [68.36069489, 23.81041527], [68.36069489, 23.81069374], [68.36013794, 23.81069374], [68.36013794, 23.81041527], [68.35958099, 23.81041527], [68.35958099, 23.81069374], [68.35930634, 23.81069374], [68.35930634, 23.81041527], [68.35847473, 23.81041527], [68.35847473, 23.81069374], [68.35736084, 23.81069374], [68.35736084, 23.81097221], [68.35514069, 23.81097221], [68.35514069, 23.81069374], [68.35375214, 23.81069374], [68.35375214, 23.81041527], [68.35320282, 23.81042099], [68.35320282, 23.81014061], [68.35237122, 23.81014061], [68.35237122, 23.80986023], [68.35124969, 23.80986023], [68.35124969, 23.80957985], [68.35041809, 23.80958557], [68.35041809, 23.80930328], [68.34931183, 23.80931091], [68.34931183, 23.80903053], [68.34902954, 23.80903053], [68.34902954, 23.80875015], [68.34874725, 23.80875015], [68.34874725, 23.80846024], [68.3484726, 23.80847168], [68.3484726, 23.80819321], [68.34819794, 23.80820084], [68.34819794, 23.80792046], [68.34764099, 23.80792046], [68.34764099, 23.80764008], [68.34680939, 23.80764008], [68.34680176, 23.8073597], [68.3465271, 23.8073616], [68.3465271, 23.80708122], [68.34625244, 23.80708122], [68.34625244, 23.80680466], [68.3456955, 23.80680466], [68.3456955, 23.80652809], [68.34541321, 23.80653191], [68.34541321, 23.80624962], [68.34513855, 23.80624962], [68.34513855, 23.80569267], [68.34486389, 23.80569458], [68.34486389, 23.80541611], [68.34430695, 23.80542183], [68.34430695, 23.80513954], [68.34401703, 23.80513954], [68.34401703, 23.80486107], [68.34375, 23.80486107], [68.34375, 23.80458069], [68.3429184, 23.8045826], [68.3429184, 23.80430603], [68.34263611, 23.80431175], [68.34263611, 23.80402946], [68.34236145, 23.80402946], [68.34236145, 23.80374908], [68.34208679, 23.80374908], [68.34208679, 23.80347061], [68.34152985, 23.80347252], [68.34152985, 23.80319405], [68.34124756, 23.80319405], [68.34124756, 23.80291748], [68.3409729, 23.80291939], [68.3409729, 23.80265045], [68.34069824, 23.80265045], [68.34069824, 23.80236053], [68.3401413, 23.80236053], [68.3401413, 23.80207825], [68.34041595, 23.80208397], [68.34041595, 23.8018055], [68.3401413, 23.80180931], [68.3401413, 23.80153084], [68.33930206, 23.80153084], [68.33930206, 23.80125046], [68.3390274, 23.80125046], [68.3390274, 23.80096817], [68.33847046, 23.80097198], [68.33847046, 23.80069351], [68.3381958, 23.80069351], [68.3381958, 23.79986191], [68.33791351, 23.79986191], [68.33791351, 23.79958344], [68.33737183, 23.79959106], [68.33737183, 23.79931068], [68.33708191, 23.79931068], [68.33708191, 23.7990303], [68.33680725, 23.7990303], [68.33680725, 23.79874992], [68.33652496, 23.79874992], [68.33652496, 23.79819679], [68.33597565, 23.79819679], [68.33597565, 23.79791451], [68.33569336, 23.79792023], [68.33569336, 23.79735947], [68.3354187, 23.79736137], [68.3354187, 23.7970829], [68.33513641, 23.7970829], [68.33513641, 23.79680443], [68.33486176, 23.79681015], [68.33486176, 23.79624939], [68.3345871, 23.79624939], [68.3345871, 23.79541969], [68.33429718, 23.79541969], [68.33429718, 23.79486084], [68.33403015, 23.79486084], [68.33403015, 23.79430962], [68.33374786, 23.79430962], [68.33374786, 23.79375076], [68.33347321, 23.79375076], [68.33347321, 23.79346275], [68.33374786, 23.79347229], [68.33374786, 23.79319382], [68.33347321, 23.79319382], [68.33347321, 23.79180527], [68.33319092, 23.7918129], [68.33319092, 23.79125023], [68.33291626, 23.79125023], [68.33291626, 23.79097176], [68.3326416, 23.79097176], [68.3326416, 23.78986168], [68.33235931, 23.78986168], [68.33235931, 23.78958321], [68.33208466, 23.78958321], [68.33208466, 23.78930473], [68.33180237, 23.78930473], [68.33180237, 23.78902817], [68.33152771, 23.78902817], [68.33152771, 23.78847122], [68.33125305, 23.78847313], [68.33125305, 23.78736115], [68.33013916, 23.78736115], [68.33013916, 23.78764915], [68.32985687, 23.78764915], [68.32985687, 23.78791809], [68.32958221, 23.78791618], [68.32958221, 23.78847313], [68.32930756, 23.78847122], [68.32930756, 23.78874969], [68.32847595, 23.78874969], [68.32847595, 23.78930473], [68.32819366, 23.78930473], [68.32819366, 23.78958321], [68.32791901, 23.78957748], [68.32791901, 23.79042244], [68.32763672, 23.79042244], [68.32763672, 23.79125023], [68.32736206, 23.79125023], [68.32736206, 23.7918129], [68.32707977, 23.7918129], [68.32707977, 23.79236031], [68.32681274, 23.79236031], [68.32681274, 23.79264069], [68.32653046, 23.79263878], [68.32653046, 23.79319382], [68.32624817, 23.79319191], [68.32624817, 23.79375076], [68.32596588, 23.79375076], [68.32596588, 23.79430962], [68.32569122, 23.7943058], [68.32569122, 23.79458237], [68.32541656, 23.79458237], [68.32543182, 23.79486084], [68.32514191, 23.79486084], [68.32514191, 23.79514122], [68.32485962, 23.79514122], [68.32485962, 23.79541969], [68.32514191, 23.79541588], [68.32514191, 23.79597473], [68.32485962, 23.79597473], [68.32485962, 23.7970829], [68.32514191, 23.79708099], [68.32514191, 23.79792023], [68.32569122, 23.79791451], [68.32569122, 23.79847145], [68.32596588, 23.79846954], [68.32596588, 23.7990303], [68.32624817, 23.7990303], [68.32624817, 23.79931068], [68.32653046, 23.79931068], [68.32653046, 23.79959106], [68.32680511, 23.79958344], [68.32680511, 23.79986191], [68.32707977, 23.79985809], [68.32707977, 23.80014038], [68.32763672, 23.80014038], [68.32763672, 23.80042076], [68.32791901, 23.80041885], [68.32791901, 23.8006897], [68.32847595, 23.80069542], [68.32847595, 23.80097198], [68.32875061, 23.80096817], [68.32875061, 23.80125046], [68.3290329, 23.80125046], [68.3290329, 23.80153084], [68.32930756, 23.80153084], [68.32930756, 23.80180931], [68.3298645, 23.8018055], [68.3298645, 23.80208397], [68.33013916, 23.80207825], [68.33013916, 23.80236053], [68.33069611, 23.80236053], [68.33069611, 23.80265045], [68.33097076, 23.80265045], [68.33097076, 23.80291939], [68.33125305, 23.80291748], [68.33125305, 23.80319405], [68.33152771, 23.80319405], [68.33152771, 23.80347252], [68.33180237, 23.80347061], [68.33180237, 23.80374908], [68.33207703, 23.80374908], [68.33207703, 23.80402946], [68.33235931, 23.80402946], [68.33235931, 23.80431175], [68.3326416, 23.80431175], [68.3326416, 23.80486107], [68.33291626, 23.80486107], [68.33291626, 23.80513954], [68.33319092, 23.80513954], [68.33319092, 23.80542183], [68.33347321, 23.80541611], [68.33347321, 23.80569458], [68.33374786, 23.80569458], [68.33374786, 23.80597115], [68.33403015, 23.80597115], [68.33403015, 23.80624962], [68.33429718, 23.80624962], [68.33429718, 23.80653191], [68.3345871, 23.80652809], [68.3345871, 23.80680466], [68.33486176, 23.80680466], [68.33486176, 23.80708122], [68.33513641, 23.80708122], [68.33513641, 23.8073616], [68.3354187, 23.8073597], [68.3354187, 23.80764008], [68.33569336, 23.80764008], [68.33569336, 23.80792046], [68.33598328, 23.80792046], [68.33598328, 23.80820084], [68.33625031, 23.80819321], [68.33625031, 23.80847168], [68.33680725, 23.80846024], [68.33680725, 23.80875015], [68.33708191, 23.80875015], [68.33708191, 23.80903053], [68.33737183, 23.80903053], [68.33737183, 23.80931091], [68.33763885, 23.80930328], [68.33763885, 23.80958557], [68.33790588, 23.80957985], [68.33790588, 23.80986023], [68.3381958, 23.80986023], [68.3381958, 23.81014061], [68.33847046, 23.81014061], [68.33847046, 23.81042099], [68.33875275, 23.81041527], [68.33875275, 23.81069374], [68.3390274, 23.81069374], [68.3390274, 23.81097221], [68.33930206, 23.81097031], [68.33930206, 23.81125069], [68.33985901, 23.81125069], [68.33985901, 23.81153107], [68.3401413, 23.81153107], [68.3401413, 23.81180954], [68.34041595, 23.81180763], [68.34041595, 23.8120842], [68.3409729, 23.81208038], [68.3409729, 23.81236076], [68.34124756, 23.81236076], [68.34124756, 23.81264114], [68.34152985, 23.81264114], [68.34152985, 23.81291962], [68.34208679, 23.81291771], [68.34208679, 23.81319427], [68.34236145, 23.81319427], [68.34236145, 23.81347275], [68.34263611, 23.81347084], [68.34263611, 23.81375122], [68.3429184, 23.81375122], [68.3429184, 23.81402969], [68.3431778, 23.81402969], [68.3431778, 23.81430817], [68.3434906, 23.81430817], [68.3434906, 23.81459045], [68.34375, 23.81458282], [68.34375, 23.8148613], [68.34401703, 23.81485748], [68.34401703, 23.81541824], [68.34430695, 23.81541634], [68.34430695, 23.81569481], [68.3445816, 23.81569481], [68.3445816, 23.81597137], [68.34485626, 23.81596756], [68.34485626, 23.81624985], [68.34513855, 23.81624985], [68.34513855, 23.81653023], [68.34541321, 23.81652832], [68.34541321, 23.81680489], [68.3456955, 23.81680489], [68.3456955, 23.81708336], [68.34597015, 23.81708145], [68.34597015, 23.81764984], [68.34623718, 23.81764984], [68.34623718, 23.81792259], [68.3465271, 23.81792259], [68.3465271, 23.81820107], [68.34680176, 23.81820107], [68.34680176, 23.81875038], [68.34708405, 23.81875038], [68.34708405, 23.81958389], [68.3473587, 23.81958389], [68.3473587, 23.82097244], [68.34764099, 23.82097054], [68.34764099, 23.82263947], [68.34791565, 23.82263947], [68.34791565, 23.82458305], [68.34764099, 23.82458115], [68.34764099, 23.82514], [68.3473587, 23.82514], [68.3473587, 23.82570076], [68.34707642, 23.82570076], [68.34707642, 23.82625008], [68.34680176, 23.82625008], [68.34680176, 23.82681847], [68.3465271, 23.82681847], [68.3465271, 23.82736015], [68.34623718, 23.82736015], [68.34623718, 23.82792091], [68.34597015, 23.8279171], [68.34597015, 23.82847214], [68.3456955, 23.82847214], [68.34570313, 23.82875061], [68.34541321, 23.82875061], [68.34541321, 23.82902908], [68.3445816, 23.82902908], [68.3445816, 23.82930946], [68.34402466, 23.82930565], [68.34402466, 23.82958412], [68.34375, 23.82957077], [68.34375, 23.83013916], [68.34347534, 23.83013916], [68.34347534, 23.8306942], [68.3431778, 23.83068848], [68.3431778, 23.83124924], [68.3429184, 23.83124924], [68.3429184, 23.83569336], [68.34263611, 23.83568954], [68.34263611, 23.83653069], [68.3429184, 23.83652687], [68.3429184, 23.83708572], [68.3431778, 23.83708], [68.3431778, 23.83764076], [68.3434906, 23.83764076], [68.3434906, 23.83792114]]], [[[68.26430511, 23.74902725], [68.26457977, 23.74902916], [68.26457977, 23.74875069], [68.26486206, 23.74875069], [68.26486206, 23.74818993], [68.26513672, 23.74819374], [68.26513672, 23.7476387], [68.26541901, 23.74764061], [68.26541901, 23.74707985], [68.26569366, 23.74708366], [68.26569366, 23.74652863], [68.26597595, 23.74653053], [68.26597595, 23.74625015], [68.26568604, 23.74625015], [68.26568604, 23.74570084], [68.26541901, 23.74570084], [68.26541901, 23.74541092], [68.26513672, 23.74541855], [68.26513672, 23.74513626], [68.26486206, 23.74514008], [68.26486206, 23.7448597], [68.26457977, 23.7448616], [68.26457977, 23.74458313], [68.26430511, 23.74458313], [68.26430511, 23.74430656], [68.26403046, 23.74430656], [68.26403046, 23.74402618], [68.26374817, 23.74403], [68.26374817, 23.74374962], [68.26346588, 23.74374962], [68.26346588, 23.74347115], [68.26319122, 23.74347305], [68.26319122, 23.74319649], [68.26291656, 23.74319649], [68.26291656, 23.74263954], [68.26264191, 23.74263954], [68.26264191, 23.74208069], [68.26235962, 23.7420826], [68.26235962, 23.74152756], [68.26207733, 23.74152946], [68.26207733, 23.74097061], [68.26180267, 23.74097252], [68.26180267, 23.74013901], [68.26152802, 23.74014282], [68.26152802, 23.73903275], [68.26125336, 23.73903275], [68.26125336, 23.73764038], [68.26097107, 23.73764038], [68.26097107, 23.73568916], [68.26125336, 23.73569489], [68.26125336, 23.73402977], [68.26152802, 23.73402977], [68.26152802, 23.73291969], [68.26180267, 23.73291969], [68.26180267, 23.73208046], [68.26208496, 23.73208427], [68.26208496, 23.73152542], [68.26235962, 23.73153114], [68.26235962, 23.73097038], [68.26264191, 23.73097229], [68.26264191, 23.73013878], [68.26235962, 23.73014069], [68.26235962, 23.72931099], [68.26207733, 23.72931099], [68.26207733, 23.72846985], [68.26180267, 23.72847176], [68.26180267, 23.72736168], [68.26152802, 23.72737122], [68.26152802, 23.72653008], [68.26125336, 23.72653008], [68.26125336, 23.72597122], [68.26097107, 23.72597122], [68.26097107, 23.72541618], [68.26069641, 23.72542191], [68.26069641, 23.72513962], [68.26040649, 23.72513962], [68.26040649, 23.72486115], [68.26013947, 23.72486115], [68.26013947, 23.72458267], [68.25986481, 23.72458267], [68.25986481, 23.72430611], [68.25958252, 23.72430611], [68.25958252, 23.72402763], [68.25930786, 23.72402954], [68.25930786, 23.72347069], [68.25902557, 23.7234726], [68.25902557, 23.72319412], [68.25875092, 23.72319412], [68.25875092, 23.72291756], [68.25846863, 23.72291946], [68.25846863, 23.72263908], [68.25818634, 23.72263908], [68.25818634, 23.72236061], [68.25791931, 23.72236061], [68.25791931, 23.72207832], [68.25763702, 23.72208405], [68.25763702, 23.72180557], [68.25736237, 23.72180939], [68.25736237, 23.72153091], [68.25708008, 23.72153091], [68.25708008, 23.721241], [68.25680542, 23.72125053], [68.25680542, 23.72097206], [68.25653076, 23.72097206], [68.25653076, 23.72069359], [68.25624847, 23.72069359], [68.25624847, 23.72041893], [68.25595856, 23.72042084], [68.25595856, 23.72014046], [68.25569153, 23.72014046], [68.25569153, 23.71986008], [68.25541687, 23.71986198], [68.25541687, 23.71958351], [68.25514221, 23.71958351], [68.25514221, 23.71930695], [68.25402832, 23.71931076], [68.25402832, 23.71875], [68.25430298, 23.71875], [68.25430298, 23.71763992], [68.2545929, 23.71763992], [68.2545929, 23.71652985], [68.25485992, 23.71652985], [68.25485992, 23.71375084], [68.25514221, 23.71375084], [68.25514221, 23.71264267], [68.25541687, 23.71264267], [68.25541687, 23.71181107], [68.25514221, 23.71181107], [68.25514221, 23.71125031], [68.25569153, 23.71125031], [68.25569153, 23.71097183], [68.25624847, 23.71097183], [68.25624847, 23.71069527], [68.25681305, 23.7107029], [68.25681305, 23.71042252], [68.25708008, 23.71042252], [68.25708008, 23.70986176], [68.25736237, 23.70986176], [68.25736237, 23.70958328], [68.25763702, 23.70958328], [68.25763702, 23.70930481], [68.25819397, 23.70930481], [68.25819397, 23.70902824], [68.25875092, 23.70902824], [68.25875092, 23.70846748], [68.25902557, 23.7084713], [68.25902557, 23.70819473], [68.25930786, 23.70819473], [68.25930786, 23.70791626], [68.25958252, 23.70791817], [68.25958252, 23.70763969], [68.25985718, 23.70763969], [68.25985718, 23.70736122], [68.26013947, 23.70736122], [68.26013947, 23.70652962], [68.26040649, 23.70652962], [68.26040649, 23.70569038], [68.26069641, 23.7056942], [68.26069641, 23.70513916], [68.26040649, 23.70514107], [68.26040649, 23.70486069], [68.26013947, 23.70486069], [68.26013947, 23.70458031], [68.26097107, 23.70458412], [68.26097107, 23.70430756], [68.26180267, 23.70430946], [68.26180267, 23.70403099], [68.26207733, 23.70403099], [68.26207733, 23.70375061], [68.26235962, 23.70375061], [68.26235962, 23.70347023], [68.26264191, 23.70347214], [68.26264191, 23.70319366], [68.26291656, 23.70319939], [68.26291656, 23.70264053], [68.26319122, 23.70264053], [68.26319122, 23.70207977], [68.26347351, 23.70208549], [68.26347351, 23.70152855], [68.26374817, 23.70153046], [68.26374817, 23.70125008], [68.26403046, 23.70125008], [68.26403046, 23.7009697], [68.26457977, 23.7009716], [68.26457977, 23.70069313], [68.26486206, 23.70070076], [68.26486206, 23.70014], [68.26515198, 23.70014], [68.26515198, 23.6993103], [68.26541901, 23.6993103], [68.26541901, 23.69847107], [68.26569366, 23.69847107], [68.26569366, 23.69791603], [68.26597595, 23.69792175], [68.26597595, 23.69735909], [68.26625061, 23.69735909], [68.26625061, 23.69681168], [68.2665329, 23.69681168], [68.2665329, 23.69625092], [68.26680756, 23.69625092], [68.26680756, 23.69568825], [68.26708221, 23.69569397], [68.26708221, 23.69430542], [68.26680756, 23.69430542], [68.26680756, 23.69180679], [68.26652527, 23.69180679], [68.26652527, 23.69097137], [68.26625061, 23.69097137], [68.26625061, 23.69041443], [68.26597595, 23.69042015], [68.26597595, 23.68985939], [68.26569366, 23.6898613], [68.26569366, 23.68930435], [68.26541901, 23.68931007], [68.26541901, 23.68875122], [68.26515198, 23.68875122], [68.26515198, 23.68847084], [68.26486206, 23.68847466], [68.26486206, 23.68819237], [68.26403046, 23.6882], [68.26403046, 23.68791962], [68.26374817, 23.68791962], [68.26374817, 23.68736076], [68.26346588, 23.68736076], [68.26346588, 23.68708038], [68.26319122, 23.68708229], [68.26319122, 23.68625069], [68.26291656, 23.68625069], [68.26291656, 23.68597031], [68.26264191, 23.68597221], [68.26264191, 23.68569374], [68.26235962, 23.68569374], [68.26235962, 23.68541718], [68.26207733, 23.6854229], [68.26207733, 23.68512917], [68.26180267, 23.6851387], [68.26180267, 23.68486023], [68.26152802, 23.68486023], [68.26152802, 23.68431282], [68.26125336, 23.68431282], [68.26125336, 23.68403244], [68.26097107, 23.68403244], [68.26097107, 23.68375015], [68.26069641, 23.68375015], [68.26069641, 23.68347168], [68.26041412, 23.68347168], [68.26041412, 23.68319511], [68.26013947, 23.68320274], [68.26013947, 23.68263817], [68.25875092, 23.68263817], [68.25875092, 23.6823597], [68.25846863, 23.6823616], [68.25846863, 23.68180466], [68.25819397, 23.68180466], [68.25819397, 23.68152809], [68.25791931, 23.68152809], [68.25791931, 23.68124962], [68.25763702, 23.68124962], [68.25763702, 23.68069077], [68.25736237, 23.68069458], [68.25736237, 23.68041611], [68.25708008, 23.68041992], [68.25708008, 23.68013954], [68.25653076, 23.68013954], [68.25653076, 23.67986107], [68.25595856, 23.67986107], [68.25595856, 23.67958069], [68.25208282, 23.67958069], [68.25208282, 23.67986107], [68.25180817, 23.67986107], [68.25180817, 23.68069458], [68.25096893, 23.68069458], [68.25096893, 23.68041611], [68.25041962, 23.68041992], [68.25041962, 23.68013954], [68.25013733, 23.68013954], [68.25013733, 23.67986107], [68.24958038, 23.67986107], [68.24958038, 23.67958069], [68.24903107, 23.6795826], [68.24903107, 23.67930794], [68.24708557, 23.67930794], [68.24708557, 23.6795826], [68.24652863, 23.6795826], [68.24652863, 23.67930794], [68.24597168, 23.67931747], [68.24597168, 23.67902946], [68.24514008, 23.67902756], [68.24514008, 23.6795826], [68.24485779, 23.67958069], [68.24485779, 23.68013954], [68.24458313, 23.68013954], [68.24458313, 23.68041992], [68.24402618, 23.68041611], [68.24402618, 23.68069458], [68.24319458, 23.68069458], [68.24319458, 23.68097305], [68.24263763, 23.68097305], [68.24263763, 23.68069458], [68.24236298, 23.68069458], [68.24236298, 23.68097305], [68.23847198, 23.68097115], [68.23847198, 23.68124962], [68.23792267, 23.68124962], [68.23792267, 23.68152809], [68.23764038, 23.68152809], [68.23764038, 23.68180466], [68.23735809, 23.68180466], [68.23735809, 23.68208313], [68.23680878, 23.68208313], [68.23680878, 23.6823616], [68.23652649, 23.6823597], [68.23652649, 23.68263817], [68.23625183, 23.68263817], [68.23625183, 23.68292236], [68.23568726, 23.68292236], [68.23568726, 23.68320274], [68.23542023, 23.68319511], [68.23542023, 23.68347168], [68.23513794, 23.68347168], [68.23513794, 23.68375015], [68.23458099, 23.68375015], [68.23458099, 23.68403244], [68.23430634, 23.68403244], [68.23430634, 23.68431282], [68.23374939, 23.68430519], [68.23374939, 23.68458366], [68.2334671, 23.68458176], [68.2334671, 23.68486023], [68.23291779, 23.68486023], [68.23291779, 23.6851387], [68.23236084, 23.68512917], [68.23236084, 23.6854229], [68.23208618, 23.68541718], [68.23208618, 23.68569374], [68.23180389, 23.68569374], [68.23180389, 23.68597221], [68.23152924, 23.68597031], [68.23152924, 23.68653107], [68.23124695, 23.68653107], [68.23124695, 23.68680954], [68.23097229, 23.68680954], [68.23097229, 23.68764114], [68.23069763, 23.68763924], [68.23069763, 23.68847466], [68.23042297, 23.68847084], [68.23042297, 23.68875122], [68.2298584, 23.68875122], [68.2298584, 23.68902969], [68.22930908, 23.68902969], [68.22930908, 23.68931007], [68.22875214, 23.68930435], [68.22875214, 23.68958282], [68.22736359, 23.68958282], [68.22736359, 23.6898613], [68.2270813, 23.68985939], [68.2270813, 23.69013977], [68.22680664, 23.69013977], [68.22680664, 23.69125938], [68.22652435, 23.69124985], [68.22652435, 23.69208336], [68.22624969, 23.69208336], [68.22624969, 23.69236183], [68.22597504, 23.69236183], [68.22597504, 23.69347191], [68.22569275, 23.69346809], [68.22569275, 23.69486046], [68.22598267, 23.69486046], [68.22598267, 23.69514084], [68.22763824, 23.69514084], [68.22763824, 23.69763947], [68.2279129, 23.69763947], [68.2279129, 23.6981945], [68.22819519, 23.6981945], [68.22819519, 23.69874954], [68.22846985, 23.69874954], [68.22846985, 23.69958115], [68.22820282, 23.69958115], [68.22820282, 23.70042038], [68.22846985, 23.70042038], [68.22846985, 23.70070076], [68.22875214, 23.70069313], [68.22875214, 23.7009716], [68.22902679, 23.7009716], [68.22902679, 23.70069313], [68.22930908, 23.70070076], [68.22930908, 23.70125008], [68.22957611, 23.70125008], [68.22958374, 23.70236015], [68.22930908, 23.70236015], [68.22930908, 23.70292091], [68.22904205, 23.70292091], [68.22904205, 23.70264053], [68.22735596, 23.70264053], [68.22735596, 23.70236015], [68.2270813, 23.70236015], [68.2270813, 23.70125008], [68.22597504, 23.70125008], [68.22597504, 23.7009716], [68.22624969, 23.7009716], [68.22624969, 23.70069313], [68.22598267, 23.70070076], [68.22598267, 23.70042038], [68.22569275, 23.70042038], [68.22569275, 23.70014], [68.22541809, 23.70014], [68.22541809, 23.69985962], [68.2243042, 23.69986153], [68.2243042, 23.69958115], [68.21986389, 23.69958115], [68.21986389, 23.69986153], [68.21901703, 23.69985962], [68.21901703, 23.70014], [68.21875, 23.70014], [68.21875, 23.70042038], [68.21848297, 23.70042038], [68.21848297, 23.70070076], [68.21819305, 23.70069313], [68.21819305, 23.7009716], [68.2179184, 23.7009697], [68.2179184, 23.70125008], [68.21763611, 23.70125008], [68.21763611, 23.70153046], [68.21710205, 23.70153046], [68.21710205, 23.70181084], [68.2159729, 23.70180321], [68.2159729, 23.70208549], [68.21541595, 23.70207977], [68.21541595, 23.70236015], [68.21485901, 23.70236015], [68.21485901, 23.70264053], [68.21430206, 23.70264053], [68.21430206, 23.70292091], [68.21404266, 23.70292091], [68.21404266, 23.70319939], [68.21347046, 23.70319366], [68.21347046, 23.70347214], [68.21290588, 23.70347023], [68.21290588, 23.70375061], [68.21235657, 23.70375061], [68.21235657, 23.70403099], [68.21208191, 23.70403099], [68.21208191, 23.70430946], [68.21152496, 23.70430756], [68.21152496, 23.70458412], [68.21096802, 23.70458031], [68.21096802, 23.70486069], [68.21069336, 23.70486069], [68.21069336, 23.7056942], [68.2104187, 23.70569038], [68.2104187, 23.70652962], [68.20903015, 23.70652962], [68.20903015, 23.70680809], [68.2076416, 23.70680618], [68.2076416, 23.70708275], [68.20735931, 23.70708084], [68.20735931, 23.70736122], [68.20707703, 23.70736122], [68.20707703, 23.70763969], [68.20680237, 23.70763969], [68.20680237, 23.70874977], [68.20652771, 23.70874977], [68.20652771, 23.70930481], [68.20680237, 23.70930481], [68.20680237, 23.70986176], [68.20652771, 23.70986176], [68.20652771, 23.71042252], [68.20625305, 23.71041679], [68.20625305, 23.71097183], [68.20597076, 23.71097183], [68.20597076, 23.71153259], [68.20569611, 23.71153259], [68.20569611, 23.71181107], [68.20541382, 23.71180534], [68.20541382, 23.71208382], [68.20513916, 23.71208191], [68.20513916, 23.71236038], [68.20487213, 23.71236038], [68.20487213, 23.71264267], [68.20458221, 23.71264267], [68.20458221, 23.71292114], [68.20430756, 23.71291733], [68.20430756, 23.71347237], [68.20402527, 23.71347237], [68.2040329, 23.71375084], [68.20375061, 23.71375084], [68.20375061, 23.71430969], [68.20347595, 23.71430588], [68.20347595, 23.71458244], [68.20318604, 23.71458054], [68.20318604, 23.71486092], [68.20291901, 23.71486092], [68.20291901, 23.71513939], [68.20263672, 23.71513939], [68.20263672, 23.71652985], [68.20236206, 23.71652985], [68.20236206, 23.71681023], [68.20207977, 23.7168045], [68.20207977, 23.71722984], [68.20207977, 23.71736145], [68.20181274, 23.71735954], [68.20181274, 23.71763992], [68.20153046, 23.71763992], [68.20153046, 23.71820068], [68.20124817, 23.71820068], [68.20124817, 23.71875], [68.20096588, 23.71875], [68.20096588, 23.71931076], [68.20069122, 23.71930695], [68.20069122, 23.71986198], [68.20041656, 23.71986198], [68.20041656, 23.72125053], [68.20014191, 23.721241], [68.20014191, 23.72153091], [68.19985962, 23.72153091], [68.19985962, 23.72180939], [68.19958496, 23.72180557], [68.19958496, 23.72208405], [68.19930267, 23.72207832], [68.19930267, 23.72236061], [68.1987381, 23.72236061], [68.1987381, 23.72263908], [68.19847107, 23.72263908], [68.19847107, 23.72291946], [68.19819641, 23.72291756], [68.19819641, 23.72319412], [68.19791412, 23.72319412], [68.19791412, 23.7234726], [68.19763947, 23.72347069], [68.19763947, 23.72374916], [68.19735718, 23.72374916], [68.19735718, 23.72402954], [68.19708252, 23.72402763], [68.19708252, 23.72430611], [68.19680786, 23.72430611], [68.19680786, 23.72458267], [68.19652557, 23.72458267], [68.1965332, 23.72513962], [68.19625092, 23.72513962], [68.19625092, 23.72542191], [68.19596863, 23.72541618], [68.19596863, 23.72569466], [68.19569397, 23.72569466], [68.19569397, 23.72597122], [68.19541931, 23.72597122], [68.19541931, 23.72624969], [68.19513702, 23.72624969], [68.19513702, 23.72680473], [68.19486237, 23.72680473], [68.19486237, 23.7270813], [68.19458008, 23.72707939], [68.19458008, 23.72764015], [68.19431305, 23.72764015], [68.19431305, 23.72820091], [68.19403076, 23.72820091], [68.19403076, 23.72875023], [68.19374847, 23.72875023], [68.19374847, 23.72931099], [68.19346619, 23.72931099], [68.19346619, 23.72986031], [68.19319153, 23.72986031], [68.19319153, 23.7304306], [68.19291687, 23.73041534], [68.19291687, 23.73097229], [68.19264221, 23.73097038], [68.19264221, 23.73236084], [68.19293213, 23.73236084], [68.19293213, 23.73291969], [68.19264221, 23.73291779], [68.19264221, 23.73319435], [68.19235992, 23.733181], [68.19235992, 23.73402977], [68.19264221, 23.73402977], [68.19264221, 23.7345829], [68.19293213, 23.73457909], [68.19293213, 23.73513985], [68.19319153, 23.73513985], [68.19319153, 23.73569489], [68.19347382, 23.73569489], [68.19347382, 23.73597145], [68.19374847, 23.73597145], [68.19374847, 23.73624992], [68.19431305, 23.73624039], [68.19431305, 23.7365303], [68.19458008, 23.7365303], [68.19458008, 23.73681259], [68.19513702, 23.73680496], [68.19513702, 23.73708344], [68.19541931, 23.73708344], [68.19541931, 23.73736191], [68.19567871, 23.73736191], [68.19567871, 23.73764038], [68.19625092, 23.73764038], [68.19625092, 23.73792267], [68.19652557, 23.73791695], [68.19652557, 23.73847008], [68.19680786, 23.73847008], [68.19680786, 23.73931122], [68.19708252, 23.73931122], [68.19708252, 23.73986053], [68.19735718, 23.73986053], [68.19735718, 23.74041939], [68.19763947, 23.74041748], [68.19763947, 23.74097252], [68.19790649, 23.74097061], [68.19790649, 23.74152946], [68.19819641, 23.74152946], [68.19819641, 23.74180984], [68.19847107, 23.74180412], [68.19847107, 23.7420826], [68.1987381, 23.74208069], [68.1987381, 23.74237061], [68.19902802, 23.74237061], [68.19902802, 23.74263954], [68.19930267, 23.74263954], [68.19930267, 23.74291992], [68.19958496, 23.7429142], [68.19958496, 23.74319649], [68.19985962, 23.74319649], [68.19985962, 23.74347305], [68.20014191, 23.74347115], [68.20014191, 23.74374962], [68.20041656, 23.74374962], [68.20041656, 23.74403], [68.20069122, 23.74402618], [68.20069122, 23.74430656], [68.20097351, 23.74430656], [68.20097351, 23.74458313], [68.20124817, 23.74458313], [68.20124817, 23.7448616], [68.20153046, 23.7448597], [68.20153046, 23.74570084], [68.20097351, 23.74569511], [68.20097351, 23.74597168], [68.20014191, 23.74596977], [68.20014191, 23.74625015], [68.19985962, 23.74625015], [68.19985962, 23.74681091], [68.20014191, 23.74681091], [68.20014191, 23.74736023], [68.20041656, 23.74736023], [68.20041656, 23.74764061], [68.20096588, 23.74764061], [68.20096588, 23.74791908], [68.20124817, 23.74791718], [68.20124817, 23.74819374], [68.20207977, 23.74819374], [68.20207977, 23.74847221], [68.20236206, 23.74847031], [68.20236206, 23.74902916], [68.20263672, 23.74902916], [68.20263672, 23.74931145], [68.20291901, 23.74930573], [68.20291901, 23.7495842], [68.20318604, 23.74957848], [68.20318604, 23.75013924], [68.20347595, 23.75013924], [68.20347595, 23.75069427], [68.20375061, 23.75068855], [68.20375061, 23.75125122], [68.20402527, 23.75124931], [68.20402527, 23.75208282], [68.20430756, 23.75208282], [68.20430756, 23.75263977], [68.20458221, 23.75263977], [68.20458221, 23.75319481], [68.2048645, 23.75319481], [68.2048645, 23.75374985], [68.20513916, 23.75374985], [68.20513916, 23.75403023], [68.20541382, 23.75402832], [68.20541382, 23.75458336], [68.20569611, 23.75458336], [68.20569611, 23.75486183], [68.20652771, 23.75485992], [68.20652771, 23.7551403], [68.20707703, 23.7551403], [68.20707703, 23.75542068], [68.20735931, 23.75541687], [68.20735931, 23.75597191], [68.2076416, 23.75597], [68.2076416, 23.75653076], [68.20791626, 23.75652695], [68.20791626, 23.7570858], [68.20819092, 23.75708008], [68.20819092, 23.75764084], [68.20847321, 23.75764084], [68.20847321, 23.75792122], [68.20903015, 23.7579174], [68.20903015, 23.75819588], [68.20930481, 23.75819588], [68.20930481, 23.75847244], [68.2095871, 23.75847054], [68.2095871, 23.75902939], [68.20986176, 23.75902557], [68.20986176, 23.75958252], [68.21013641, 23.75958061], [68.21013641, 23.76013947], [68.2104187, 23.76013947], [68.2104187, 23.7606945], [68.2106781, 23.76069069], [68.2106781, 23.76124954], [68.21096802, 23.76124954], [68.21096802, 23.76152992], [68.21125031, 23.76152992], [68.21125031, 23.76208305], [68.21152496, 23.76208305], [68.21152496, 23.76236153], [68.21180725, 23.76235962], [68.21180725, 23.76291847], [68.21208191, 23.76291847], [68.21208191, 23.76320267], [68.21180725, 23.76320267], [68.21180725, 23.76348114], [68.21263885, 23.76348114], [68.21263885, 23.76263809], [68.21290588, 23.76263809], [68.21290588, 23.76097107], [68.2131958, 23.76097298], [68.2131958, 23.75875092], [68.21290588, 23.75875092], [68.21290588, 23.75764084], [68.2131958, 23.75764084], [68.2131958, 23.75653076], [68.21347046, 23.75653076], [68.21347046, 23.75597], [68.21375275, 23.75597191], [68.21375275, 23.75541687], [68.21404266, 23.75542068], [68.21404266, 23.7551403], [68.21457672, 23.7551403], [68.21457672, 23.75485992], [68.2151413, 23.75486183], [68.2151413, 23.75458336], [68.21569824, 23.75458336], [68.21569824, 23.75430489], [68.21819305, 23.75430489], [68.21819305, 23.75458336], [68.21902466, 23.75458336], [68.21902466, 23.75486183], [68.2195816, 23.75485992], [68.2195816, 23.7551403], [68.21984863, 23.7551403], [68.21984863, 23.75542068], [68.22013855, 23.75542068], [68.22013855, 23.75570107], [68.22041321, 23.75569344], [68.22041321, 23.75597191], [68.2206955, 23.75597191], [68.2206955, 23.75625038], [68.22097015, 23.75625038], [68.22097015, 23.75681114], [68.22125244, 23.75680351], [68.22125244, 23.7570858], [68.2215271, 23.7570858], [68.2215271, 23.75736046], [68.22180176, 23.75735092], [68.22180176, 23.75764084], [68.22207642, 23.75764084], [68.22207642, 23.75792122], [68.2223587, 23.7579174], [68.2223587, 23.75819588], [68.22264099, 23.75819588], [68.22264099, 23.75847244], [68.22290802, 23.75847054], [68.22290802, 23.75902939], [68.22319794, 23.75902939], [68.22319794, 23.75930977], [68.2234726, 23.75930786], [68.2234726, 23.75958252], [68.22374725, 23.75958061], [68.22374725, 23.75986099], [68.22402954, 23.75986099], [68.22402954, 23.76013947], [68.2243042, 23.76013947], [68.2243042, 23.76041794], [68.22458649, 23.76041794], [68.22458649, 23.7606945], [68.22486115, 23.7606945], [68.22486115, 23.76097298], [68.2251358, 23.76097107], [68.2251358, 23.76152992], [68.22541809, 23.76152992], [68.22541809, 23.76208305], [68.22569275, 23.76208115], [68.22569275, 23.76263809], [68.22598267, 23.76263809], [68.22598267, 23.76403046], [68.22569275, 23.76403046], [68.22569275, 23.76486015], [68.22541809, 23.76486015], [68.22541809, 23.76585007], [68.22541809, 23.76597023], [68.2251358, 23.76597023], [68.2251358, 23.76736069], [68.22486115, 23.76736069], [68.22486115, 23.76902962], [68.22458649, 23.76902771], [68.22458649, 23.77069664], [68.22429657, 23.77069092], [68.22429657, 23.77124977], [68.22458649, 23.77124977], [68.22458649, 23.77180672], [68.2251358, 23.77180672], [68.2251358, 23.77208328], [68.22541809, 23.77208328], [68.22541809, 23.77236176], [68.22569275, 23.77236176], [68.22569275, 23.77208328], [68.22593689, 23.77208328], [68.22819519, 23.77208328], [68.22819519, 23.77236176], [68.22957611, 23.77235031], [68.22957611, 23.77264023], [68.23014069, 23.77264023], [68.23014069, 23.77292061], [68.23097229, 23.77292061], [68.23097229, 23.77319908], [68.23124695, 23.77319527], [68.23124695, 23.77347183], [68.23152924, 23.77346992], [68.23152924, 23.77375031], [68.23178864, 23.77375031], [68.23178864, 23.77403069], [68.23208618, 23.77402878], [68.23208618, 23.77458382], [68.23236084, 23.77457809], [68.23236084, 23.77486038], [68.23291779, 23.77486038], [68.23291779, 23.77457809], [68.23401642, 23.77457809], [68.23401642, 23.77486038], [68.23430634, 23.77486038], [68.23430634, 23.77569389], [68.23402405, 23.77569389], [68.23402405, 23.77597237], [68.23374939, 23.77597046], [68.23374939, 23.77625084], [68.23319244, 23.77625084], [68.23319244, 23.77763939], [68.23347473, 23.77763939], [68.23347473, 23.77819443], [68.23374939, 23.77819252], [68.23374939, 23.77874947], [68.23401642, 23.77874947], [68.23401642, 23.77902985], [68.23430634, 23.77902985], [68.23430634, 23.78013992], [68.23401642, 23.78013992], [68.23401642, 23.7804203], [68.23347473, 23.78041649], [68.23347473, 23.78097153], [68.23319244, 23.78096962], [68.23319244, 23.78181076], [68.2326355, 23.78180313], [68.2326355, 23.78208351], [68.23180389, 23.78208351], [68.23180389, 23.78041649], [68.23207855, 23.7804203], [68.23207855, 23.77902985], [68.23178864, 23.77902985], [68.23178864, 23.77708054], [68.23152924, 23.77708244], [68.23152924, 23.77625084], [68.23124695, 23.77625084], [68.23124695, 23.77568817], [68.23097229, 23.77569389], [68.23097229, 23.77541733], [68.23069763, 23.77541924], [68.23069763, 23.77514076], [68.23042297, 23.77514076], [68.23042297, 23.77486038], [68.23014069, 23.77486038], [68.23014069, 23.77457809], [68.2298584, 23.77458382], [68.2298584, 23.77430534], [68.22957611, 23.77430916], [68.22957611, 23.77403069], [68.22875214, 23.77403069], [68.22875214, 23.77375031], [68.2270813, 23.77375031], [68.2270813, 23.77403069], [68.22579193, 23.77402878], [68.22569275, 23.77402878], [68.22569275, 23.77430916], [68.22458649, 23.77430916], [68.22458649, 23.77403069], [68.22429657, 23.77403069], [68.22429657, 23.77346992], [68.22374725, 23.77346992], [68.22374725, 23.77403069], [68.2234726, 23.77402878], [68.2234726, 23.77458382], [68.22319794, 23.77457809], [68.22319794, 23.77514076], [68.22291565, 23.77514076], [68.22291565, 23.77569389], [68.22264099, 23.77568817], [68.22264099, 23.77652931], [68.2223587, 23.77652931], [68.2223587, 23.77736092], [68.22207642, 23.77736092], [68.22207642, 23.77763939], [68.22180176, 23.77763939], [68.22180176, 23.77792168], [68.2215271, 23.77791595], [68.2215271, 23.77819443], [68.22125244, 23.77819252], [68.22125244, 23.77848053], [68.22097015, 23.77848053], [68.22097015, 23.77902985], [68.22070313, 23.77902985], [68.22070313, 23.77931023], [68.22041321, 23.77930641], [68.22041321, 23.77958107], [68.22013855, 23.77958107], [68.22013855, 23.77986145], [68.21984863, 23.77985954], [68.21984863, 23.78013992], [68.21930695, 23.78013992], [68.21930695, 23.7804203], [68.21875, 23.7804203], [68.21875, 23.78070068], [68.21847534, 23.78069305], [68.21848297, 23.78125], [68.2179184, 23.78125], [68.2179184, 23.78236389], [68.21763611, 23.78236389], [68.21763611, 23.78347206], [68.2179184, 23.78347206], [68.2179184, 23.78569412], [68.21763611, 23.78569031], [68.21763611, 23.78652954], [68.21736145, 23.78652954], [68.21736145, 23.78680992], [68.2168045, 23.78680611], [68.2168045, 23.78708267], [68.21652985, 23.78708267], [68.21652985, 23.78847313], [68.21624756, 23.78847313], [68.21624756, 23.79319382], [68.2159729, 23.79319382], [68.2159729, 23.79347229], [68.21569824, 23.79346275], [68.21569061, 23.79375076], [68.21541595, 23.79375076], [68.21541595, 23.79430962], [68.2151413, 23.79430962], [68.2151413, 23.79514122], [68.21485901, 23.79513931], [68.21485901, 23.79569244], [68.21458435, 23.79569244], [68.21458435, 23.79652786], [68.21430206, 23.79652786], [68.21430206, 23.7970829], [68.21404266, 23.79708099], [68.21404266, 23.79763985], [68.21375275, 23.79763794], [68.21375275, 23.79847145], [68.21347046, 23.79846954], [68.21347046, 23.7990303], [68.2131958, 23.7990284], [68.2131958, 23.79986191], [68.21291351, 23.79986191], [68.21291351, 23.80069351], [68.21263885, 23.8006897], [68.21263885, 23.80153084], [68.2123642, 23.80152893], [68.2123642, 23.80208397], [68.21208191, 23.80207825], [68.21208191, 23.80291939], [68.21180725, 23.80291748], [68.21180725, 23.80347252], [68.21153259, 23.80347061], [68.21153259, 23.80431175], [68.21125031, 23.80431175], [68.21125031, 23.80513954], [68.21097565, 23.80513954], [68.21097565, 23.80569458], [68.2106781, 23.80569267], [68.2106781, 23.80653191], [68.2104187, 23.80653191], [68.2104187, 23.80764008], [68.21013641, 23.80764008], [68.21013641, 23.80875015], [68.20986176, 23.80875015], [68.20986176, 23.80986023], [68.2095871, 23.80986023], [68.2095871, 23.81097221], [68.20929718, 23.81097031], [68.20929718, 23.81264114], [68.2095871, 23.81264114], [68.2095871, 23.81541824], [68.20986176, 23.81541824], [68.20986176, 23.81903267], [68.21013641, 23.81903267], [68.21013641, 23.82180977], [68.2104187, 23.82180405], [68.2104187, 23.82347488], [68.21069336, 23.82347488], [68.21069336, 23.82819366], [68.21097565, 23.82819366], [68.21097565, 23.82958412], [68.21125031, 23.82957077], [68.21125031, 23.83041954], [68.21152496, 23.83041763], [68.21152496, 23.83097267], [68.21180725, 23.83097076], [68.21180725, 23.83152962], [68.21208191, 23.83152771], [68.21208191, 23.83208275], [68.21235657, 23.83208275], [68.21235657, 23.83292007], [68.21263885, 23.83292007], [68.21263885, 23.83374977], [68.21291351, 23.83374977], [68.21291351, 23.83458328], [68.2131958, 23.83458328], [68.2131958, 23.83486176], [68.21375275, 23.83485985], [68.21375275, 23.83514023], [68.21430206, 23.83514023], [68.21430206, 23.83542061], [68.21485901, 23.83541679], [68.21485901, 23.83569336], [68.21541595, 23.83569336], [68.21541595, 23.83597183], [68.2159729, 23.83596992], [68.2159729, 23.83625031], [68.2195816, 23.83625031], [68.2195816, 23.83596992], [68.2215271, 23.83597183], [68.2215271, 23.83569336], [68.22264099, 23.83569336], [68.22264099, 23.83541679], [68.22374725, 23.83542061], [68.22374725, 23.83514023], [68.22486115, 23.83514023], [68.22486115, 23.83485985], [68.22728729, 23.83485985], [68.23014069, 23.83485985], [68.23014069, 23.83514023], [68.23152924, 23.83514023], [68.23152924, 23.83542061], [68.23208618, 23.83541679], [68.23208618, 23.83569336], [68.2326355, 23.83569336], [68.2326355, 23.83597183], [68.23458099, 23.83596992], [68.23458099, 23.83625031], [68.23484802, 23.83625031], [68.23484802, 23.83681107], [68.23513794, 23.83681107], [68.23513794, 23.83736038], [68.23542023, 23.83736038], [68.23542023, 23.83792114], [68.23569489, 23.83791542], [68.23569489, 23.8381958], [68.23596954, 23.8381958], [68.23596954, 23.83847237], [68.23625183, 23.83847046], [68.23625183, 23.83903122], [68.23652649, 23.83903122], [68.23652649, 23.83930969], [68.23680878, 23.83930779], [68.23680878, 23.83958244], [68.23707581, 23.83958054], [68.23707581, 23.84013939], [68.23735809, 23.84013939], [68.23735809, 23.8409729], [68.23764038, 23.84097099], [68.23764038, 23.84152985], [68.23792267, 23.84152985], [68.23792267, 23.84182167], [68.23764038, 23.84180641], [68.23764038, 23.84236145], [68.23792267, 23.84235954], [68.23792267, 23.8429184], [68.23819733, 23.84291649], [68.23819733, 23.84347153], [68.23847198, 23.84347153], [68.23847198, 23.84403038], [68.23874664, 23.84402847], [68.23874664, 23.84458351], [68.23902893, 23.84456825], [68.23902893, 23.84514046], [68.23930359, 23.84513855], [68.23930359, 23.84569359], [68.23958588, 23.84569168], [68.23958588, 23.84625053], [68.23986053, 23.84625053], [68.23986053, 23.84680939], [68.24013519, 23.84680557], [68.24013519, 23.84736061], [68.24041748, 23.84736061], [68.24041748, 23.84791946], [68.24069214, 23.84791756], [68.24069214, 23.8484726], [68.24098206, 23.84847069], [68.24098206, 23.84902954], [68.24124908, 23.84902763], [68.24124908, 23.84958267], [68.24153137, 23.84958076], [68.24153137, 23.84986115], [68.24180603, 23.84986115], [68.24180603, 23.85042], [68.24208069, 23.85042], [68.24208069, 23.85070038], [68.24236298, 23.85070038], [68.24236298, 23.85124969], [68.24263763, 23.85124969], [68.24263763, 23.85153008], [68.24291992, 23.85152626], [68.24291992, 23.85208321], [68.24319458, 23.85208321], [68.24319458, 23.85236168], [68.24346924, 23.85235977], [68.24346924, 23.85264015], [68.24375153, 23.85264015], [68.24375153, 23.85292053], [68.24401855, 23.85292053], [68.24401855, 23.85320091], [68.24430847, 23.85319519], [68.24430847, 23.85347176], [68.2454071, 23.85346985], [68.2454071, 23.85375977], [68.24624634, 23.85375977], [68.24624634, 23.85346985], [68.24652863, 23.85347176], [68.24652863, 23.85291862], [68.24678802, 23.85292053], [68.24678802, 23.85235977], [68.24708557, 23.85236168], [68.24708557, 23.85124969], [68.24736023, 23.85124969], [68.24736023, 23.85013962], [68.24764252, 23.85013962], [68.24764252, 23.84958076], [68.24791718, 23.84958267], [68.24791718, 23.84902763], [68.24819183, 23.84902954], [68.24819183, 23.84847069], [68.24847412, 23.8484726], [68.24847412, 23.84791756], [68.24874878, 23.84791946], [68.24874878, 23.84736061], [68.24903107, 23.84736061], [68.24903107, 23.84708023], [68.24930573, 23.84708214], [68.24930573, 23.84680557], [68.24958038, 23.84680939], [68.24958038, 23.84653282], [68.25013733, 23.84653282], [68.25013733, 23.84625053], [68.25041962, 23.84625053], [68.25041962, 23.84597015], [68.25069427, 23.84597015], [68.25069427, 23.84569359], [68.25458527, 23.84569359], [68.25458527, 23.84541702], [68.25514221, 23.84542274], [68.25514221, 23.84514046], [68.25595856, 23.84514046], [68.25595856, 23.84486008], [68.25653076, 23.84486008], [68.25653076, 23.84458351], [68.25708008, 23.84458351], [68.25708008, 23.84375191], [68.25736237, 23.84375191], [68.25736237, 23.8429184], [68.25763702, 23.8429184], [68.25763702, 23.84207916], [68.25791931, 23.84208298], [68.25791931, 23.8409729], [68.25819397, 23.8409729], [68.25819397, 23.83986092], [68.25846863, 23.83986092], [68.25846863, 23.83876038], [68.25875092, 23.83876038], [68.25875092, 23.83764076], [68.25901794, 23.83764076], [68.25901794, 23.83681107], [68.25930786, 23.83681107], [68.25930786, 23.83457947], [68.25958252, 23.83458328], [68.25958252, 23.83430481], [68.25930786, 23.83430481], [68.25930786, 23.83152771], [68.25958252, 23.83152962], [68.25958252, 23.83041954], [68.25985718, 23.83041954], [68.25985718, 23.82986069], [68.26013947, 23.82986069], [68.26013947, 23.82846832], [68.26041412, 23.82847214], [68.26041412, 23.82736206], [68.26069641, 23.82736206], [68.26069641, 23.82680511], [68.26040649, 23.82681847], [68.26040649, 23.82485962], [68.26180267, 23.82485962], [68.26180267, 23.82625008], [68.26207733, 23.82625008], [68.26207733, 23.82792091], [68.26180267, 23.82792091], [68.26180267, 23.82902908], [68.26152802, 23.82902908], [68.26152802, 23.83041954], [68.26125336, 23.83041954], [68.26125336, 23.83124924], [68.26097107, 23.83124924], [68.26097107, 23.83208275], [68.26069641, 23.83208275], [68.26069641, 23.8334713], [68.26097107, 23.83346939], [68.26097107, 23.83514023], [68.26069641, 23.83514023], [68.26069641, 23.83681107], [68.26097107, 23.83681107], [68.26097107, 23.83736038], [68.26125336, 23.83736038], [68.26125336, 23.83708], [68.26180267, 23.83708572], [68.26180267, 23.83680344], [68.26291656, 23.83681107], [68.26291656, 23.83653069], [68.26486206, 23.83653069], [68.26486206, 23.83681107], [68.26875305, 23.83681107], [68.26875305, 23.83653069], [68.26930237, 23.83653069], [68.26930237, 23.83625031], [68.26985931, 23.83625031], [68.26985931, 23.83596992], [68.27069092, 23.83597183], [68.27069092, 23.83569336], [68.27124786, 23.83569336], [68.27124786, 23.83541679], [68.27153015, 23.83542061], [68.27153015, 23.83514023], [68.27179718, 23.83514023], [68.27179718, 23.83485985], [68.2720871, 23.83486176], [68.2720871, 23.83458328], [68.27263641, 23.83458328], [68.27263641, 23.83430481], [68.27735901, 23.83430481], [68.27735901, 23.83458328], [68.27791595, 23.83458328], [68.27791595, 23.83486176], [68.27819061, 23.83485985], [68.27819824, 23.83514023], [68.2784729, 23.83514023], [68.2784729, 23.83542061], [68.27874756, 23.83541679], [68.27874756, 23.83597183], [68.27902985, 23.83596992], [68.27902985, 23.83653069], [68.27929688, 23.83653069], [68.27929688, 23.83681107], [68.27958679, 23.83680344], [68.27958679, 23.83708572], [68.27986145, 23.83708], [68.27986145, 23.83764076], [68.28015137, 23.83764076], [68.28015137, 23.83792114], [68.2804184, 23.83791542], [68.2804184, 23.8381958], [68.28069305, 23.8381958], [68.28069305, 23.83847237], [68.28125, 23.83847046], [68.28125, 23.83876038], [68.28151703, 23.83876038], [68.28151703, 23.83903122], [68.28180695, 23.83903122], [68.28180695, 23.83930969], [68.2820816, 23.83930779], [68.2820816, 23.83958244], [68.28235626, 23.83958054], [68.28235626, 23.83986092], [68.28289795, 23.83986092], [68.28289795, 23.84013939], [68.28375244, 23.84013939], [68.28375244, 23.84041977], [68.28457642, 23.84041977], [68.28457642, 23.84013939], [68.28542328, 23.84013939], [68.28541565, 23.83986092], [68.2859726, 23.83986092], [68.2859726, 23.83958054], [68.28624725, 23.83958244], [68.28624725, 23.83930779], [68.28736115, 23.83930779], [68.28736115, 23.83958244], [68.2876358, 23.83958054], [68.2876358, 23.84041977], [68.28736115, 23.84041786], [68.28736115, 23.84069443], [68.28708649, 23.84069443], [68.28708649, 23.8409729], [68.28679657, 23.84097099], [68.28679657, 23.84124947], [68.2859726, 23.84124947], [68.2859726, 23.84152985], [68.28514099, 23.84152985], [68.28514099, 23.84182167], [68.28318787, 23.84182167], [68.28318787, 23.84152985], [68.28235626, 23.84152985], [68.28235626, 23.84124947], [68.28151703, 23.84124947], [68.28151703, 23.84097099], [68.28125, 23.8409729], [68.28125, 23.84041786], [68.28098297, 23.84041977], [68.28098297, 23.84013939], [68.28069305, 23.84013939], [68.28069305, 23.83986092], [68.28013611, 23.83986092], [68.28013611, 23.83958244], [68.27958679, 23.83958244], [68.27958679, 23.83930779], [68.27929688, 23.83930969], [68.27929688, 23.83903122], [68.27902985, 23.83903122], [68.27902985, 23.83847046], [68.27874756, 23.83847237], [68.27874756, 23.8381958], [68.2784729, 23.8381958], [68.2784729, 23.83763885], [68.27819824, 23.83764076], [68.27819824, 23.83736038], [68.27791595, 23.83736038], [68.27791595, 23.83708], [68.2776413, 23.83708572], [68.2776413, 23.83652687], [68.27735901, 23.83653069], [68.27735901, 23.83596992], [68.27680206, 23.83597183], [68.27680206, 23.83569336], [68.27319336, 23.83568954], [68.27319336, 23.83625031], [68.2729187, 23.83625031], [68.2729187, 23.83681107], [68.27263641, 23.83680344], [68.27263641, 23.83708572], [68.27236176, 23.83708], [68.27236176, 23.83736038], [68.2720871, 23.83736038], [68.2720871, 23.83764076], [68.27124786, 23.83764076], [68.27124786, 23.83792114], [68.26930237, 23.83791542], [68.26930237, 23.8381958], [68.26403046, 23.8381958], [68.26403046, 23.83791542], [68.26347351, 23.83791542], [68.26347351, 23.8381958], [68.26264191, 23.83819008], [68.26264191, 23.83876038], [68.26097107, 23.83876038], [68.26097107, 23.83930969], [68.26069641, 23.83930969], [68.26069641, 23.83986092], [68.26040649, 23.83986092], [68.26040649, 23.84013939], [68.26013947, 23.84013939], [68.26013947, 23.84069443], [68.25985718, 23.84069061], [68.25985718, 23.84124947], [68.25958252, 23.84124947], [68.25958252, 23.84182167], [68.25930786, 23.84182167], [68.25930786, 23.8429184], [68.25902557, 23.84291649], [68.25902557, 23.84347153], [68.25875092, 23.84347153], [68.25875092, 23.84403038], [68.25846863, 23.84402847], [68.25846863, 23.84458351], [68.25818634, 23.84456825], [68.25818634, 23.84514046], [68.25791931, 23.84514046], [68.25791931, 23.84542274], [68.25736237, 23.84541702], [68.25736237, 23.84569359], [68.25708008, 23.84569359], [68.25708008, 23.84597015], [68.25680542, 23.84597015], [68.25681305, 23.84625053], [68.25569153, 23.84625053], [68.25569153, 23.84653282], [68.25485992, 23.84653282], [68.25485992, 23.84680939], [68.25402832, 23.84680557], [68.25402832, 23.84708214], [68.25319672, 23.84708214], [68.25321198, 23.84736061], [68.25208282, 23.84736061], [68.25208282, 23.84763908], [68.25125122, 23.84762955], [68.25125122, 23.84791946], [68.25041962, 23.84791756], [68.25041962, 23.84819221], [68.25013733, 23.84819221], [68.25013733, 23.8484726], [68.24986267, 23.84847069], [68.24986267, 23.84875107], [68.24958038, 23.84874916], [68.24958038, 23.85236168], [68.24931335, 23.85235977], [68.24931335, 23.85320091], [68.24903107, 23.85320091], [68.24903107, 23.85375977], [68.24874878, 23.85375977], [68.24874878, 23.85403061], [68.24931335, 23.85403061], [68.24931335, 23.85430908], [68.24958038, 23.85430527], [68.24958038, 23.85458374], [68.24986267, 23.85457993], [68.24986267, 23.85486031], [68.25013733, 23.85486031], [68.25013733, 23.85514069], [68.25041962, 23.85514069], [68.25041962, 23.85541916], [68.25069427, 23.85541725], [68.25069427, 23.85569382], [68.25125122, 23.85569382], [68.25125122, 23.85597229], [68.25152588, 23.85597038], [68.25152588, 23.85625076], [68.25180817, 23.85625076], [68.25180817, 23.85652924], [68.25208282, 23.85652733], [68.25208282, 23.8568058], [68.25235748, 23.8568058], [68.25235748, 23.85708427], [68.25263977, 23.85707855], [68.25263977, 23.85736084], [68.25292206, 23.85736084], [68.25292206, 23.85763931], [68.25321198, 23.85763931], [68.25321198, 23.85791969], [68.25347137, 23.85791588], [68.25347137, 23.85819435], [68.25375366, 23.85819435], [68.25375366, 23.85847282], [68.25402832, 23.85847282], [68.25402832, 23.85874939], [68.25430298, 23.85874939], [68.25430298, 23.85902977], [68.25402832, 23.85902977], [68.25402832, 23.85931015], [68.25430298, 23.85930634], [68.25430298, 23.85986137], [68.2545929, 23.85985947], [68.2545929, 23.86042023], [68.25485992, 23.86041641], [68.25485992, 23.86097145], [68.25514221, 23.86096954], [68.25514221, 23.86124992], [68.25541687, 23.86124992], [68.25541687, 23.86181068], [68.25569153, 23.86180305], [68.25569153, 23.86208344], [68.25597382, 23.86208344], [68.25597382, 23.86236191], [68.25624847, 23.86236], [68.25624847, 23.86264038], [68.25653076, 23.86263847], [68.25653076, 23.8631897], [68.25681305, 23.86320114], [68.25681305, 23.86403084], [68.25708008, 23.86402512], [68.25708008, 23.86458588], [68.25736237, 23.86458015], [68.25736237, 23.86514091], [68.25763702, 23.8651371], [68.25763702, 23.86918259], [68.25763702, 23.86930466], [68.2578125, 23.86930275], [68.25791931, 23.86930084], [68.25791931, 23.87070274], [68.25819397, 23.87069511], [68.25819397, 23.87097168], [68.25846863, 23.87097168], [68.25846863, 23.87125015], [68.25875092, 23.87125015], [68.25875092, 23.87153053], [68.25930786, 23.87152863], [68.25930786, 23.87180519], [68.26097107, 23.87180519], [68.26097107, 23.87152863], [68.26125336, 23.87152863], [68.26264191, 23.87153053], [68.26264191, 23.87125015], [68.26515198, 23.87125015], [68.26513672, 23.87097168], [68.26819611, 23.87097168], [68.26819611, 23.87069511], [68.27124786, 23.87070274], [68.27124786, 23.87042236], [68.2720871, 23.87042236], [68.2720871, 23.87014008], [68.27263641, 23.87014008], [68.27263641, 23.8698597], [68.2729187, 23.8698616], [68.2729187, 23.86958313], [68.27347565, 23.86958313], [68.27347565, 23.86930466], [68.27402496, 23.86930466], [68.27402496, 23.86902809], [68.27430725, 23.86902809], [68.27430725, 23.86874008], [68.2748642, 23.86874962], [68.2748642, 23.86847305], [68.27541351, 23.86847305], [68.27541351, 23.86819458], [68.27708435, 23.86819458], [68.27708435, 23.86791611], [68.2804184, 23.86791611], [68.2804184, 23.86819458], [68.28152466, 23.86819458], [68.28152466, 23.86847305], [68.28291321, 23.86847305], [68.28291321, 23.86874962], [68.28318787, 23.86874008], [68.28318787, 23.86902809], [68.28347015, 23.86902809], [68.28347015, 23.86930466], [68.28430176, 23.86930466], [68.28430176, 23.86958313], [68.28458405, 23.86958313], [68.28458405, 23.8698616], [68.2848587, 23.8698597], [68.2848587, 23.87014008], [68.28569794, 23.87014008], [68.28569794, 23.87042236], [68.28624725, 23.87042236], [68.28624725, 23.87070274], [68.28652954, 23.87069511], [68.28652954, 23.87097168], [68.28708649, 23.87097168], [68.28708649, 23.87125015], [68.28736115, 23.87125015], [68.28736115, 23.87153053], [68.28791809, 23.87152863], [68.28791809, 23.87180519], [68.28847504, 23.87180519], [68.28847504, 23.87208366], [68.28874969, 23.87208176], [68.28874969, 23.87236023], [68.2895813, 23.87236023], [68.2895813, 23.87264061], [68.29013824, 23.87264061], [68.29013824, 23.8729229], [68.29319763, 23.8729229], [68.29319763, 23.87264061], [68.29374695, 23.87264061], [68.29374695, 23.87236023], [68.29402924, 23.87236023], [68.29402924, 23.87179947], [68.29430389, 23.87180519], [68.29430389, 23.87125015], [68.29458618, 23.87125015], [68.29458618, 23.87097168], [68.29486084, 23.87097168], [68.29486084, 23.87069511], [68.29512787, 23.87070274], [68.29512787, 23.87042236], [68.29541779, 23.87042236], [68.29541779, 23.8698597], [68.29569244, 23.8698616], [68.29569244, 23.86958313], [68.29597473, 23.86958313], [68.29597473, 23.86930466], [68.29624939, 23.86930466], [68.29624939, 23.86902809], [68.29651642, 23.86902809], [68.29651642, 23.86874008], [68.29680634, 23.86874962], [68.29680634, 23.86847305], [68.29736328, 23.86847305], [68.29736328, 23.86819458], [68.29763794, 23.86819458], [68.29763794, 23.86791611], [68.29818726, 23.86791992], [68.29818726, 23.86763954], [68.29875183, 23.86763954], [68.29875183, 23.86736107], [68.29930878, 23.86736107], [68.29930878, 23.86708069], [68.29985809, 23.8670826], [68.29985809, 23.86680794], [68.30042267, 23.86680984], [68.30042267, 23.86652946], [68.30097198, 23.86652946], [68.30097198, 23.86625099], [68.30152893, 23.86625099], [68.30152893, 23.86597061], [68.30208588, 23.86597252], [68.30208588, 23.86569595], [68.30513763, 23.86569595], [68.30513763, 23.86597252], [68.30541992, 23.86597061], [68.30541992, 23.86625099], [68.30568695, 23.86625099], [68.30568695, 23.86652946], [68.30596924, 23.86652946], [68.30596924, 23.86680984], [68.30625153, 23.86680794], [68.30625153, 23.8670826], [68.30652618, 23.86708069], [68.30652618, 23.86763954], [68.30680847, 23.86763954], [68.30680847, 23.86819458], [68.30708313, 23.86819458], [68.30708313, 23.86847305], [68.30735779, 23.86847115], [68.30735779, 23.86902809], [68.30764008, 23.86902809], [68.30764008, 23.86958313], [68.30791473, 23.86958313], [68.30791473, 23.8698616], [68.30819702, 23.8698597], [68.30819702, 23.87014008], [68.30847168, 23.87014008], [68.30847168, 23.87125015], [68.30874634, 23.87125015], [68.30874634, 23.87208366], [68.30902863, 23.87208176], [68.30902863, 23.87264061], [68.30930328, 23.8726387], [68.30930328, 23.87319374], [68.3095932, 23.87319183], [68.3095932, 23.87403107], [68.30986023, 23.87403107], [68.30986023, 23.8748703], [68.31014252, 23.87486076], [68.31014252, 23.87569237], [68.31041718, 23.87569046], [68.31041718, 23.87625122], [68.31069183, 23.87625122], [68.31069183, 23.87652969], [68.31097412, 23.87652779], [68.31097412, 23.87708282], [68.31124878, 23.87708092], [68.31124878, 23.87763977], [68.31153107, 23.87763977], [68.31153107, 23.87792969], [68.31180573, 23.87791443], [68.31180573, 23.87819672], [68.31208038, 23.87819672], [68.31208038, 23.87847137], [68.31236267, 23.87846947], [68.31236267, 23.87874985], [68.31346893, 23.87874985], [68.31346893, 23.87903023], [68.31430817, 23.87902832], [68.31430817, 23.87930679], [68.31513977, 23.87930679], [68.31513977, 23.87958336], [68.31680298, 23.87958336], [68.31680298, 23.87930679], [68.31764221, 23.87930107], [68.31764221, 23.88042068], [68.31735992, 23.88042068], [68.31735992, 23.88069916], [68.31708527, 23.88069534], [68.3170929, 23.88125038], [68.31680298, 23.88125038], [68.31680298, 23.88153076], [68.31513977, 23.88153076], [68.31513977, 23.88125038], [68.31430817, 23.88125038], [68.31430817, 23.88096809], [68.31346893, 23.88097191], [68.31346893, 23.88069534], [68.31263733, 23.88069916], [68.31263733, 23.88042068], [68.31208038, 23.88042068], [68.31208038, 23.8801403], [68.31153107, 23.8801403], [68.31153107, 23.87985992], [68.31097412, 23.87986183], [68.31097412, 23.87958336], [68.31041718, 23.87958336], [68.31041718, 23.87930679], [68.31014252, 23.87930679], [68.31014252, 23.87902832], [68.3095932, 23.87903023], [68.3095932, 23.87874985], [68.30930328, 23.87874985], [68.30930328, 23.87846947], [68.30902863, 23.87847137], [68.30902863, 23.87819672], [68.30874634, 23.87819672], [68.30874634, 23.87763977], [68.30847168, 23.87763977], [68.30847168, 23.87708092], [68.30819702, 23.87708282], [68.30819702, 23.87680435], [68.3079071, 23.87681007], [68.3079071, 23.87625122], [68.30767059, 23.87625122], [68.30766296, 23.87612724], [68.30764008, 23.87569237], [68.30747986, 23.87569237], [68.30735779, 23.87569237], [68.30735779, 23.8754158], [68.30706787, 23.87541962], [68.3070755, 23.87462044], [68.30708313, 23.87430573], [68.30696106, 23.87430573], [68.30680847, 23.87430954], [68.30680847, 23.87375069], [68.30652618, 23.87375069], [68.30652618, 23.87264061], [68.30625153, 23.87264061], [68.30625153, 23.87125015], [68.30596924, 23.87125015], [68.30596924, 23.87070274], [68.30568695, 23.87070274], [68.30568695, 23.8698597], [68.30541992, 23.8698616], [68.30541992, 23.86847305], [68.30513763, 23.86847305], [68.30513763, 23.86819458], [68.30486298, 23.86819458], [68.30486298, 23.86763954], [68.30430603, 23.86763954], [68.30430603, 23.86736107], [68.30374908, 23.86736107], [68.30374908, 23.86708069], [68.30236053, 23.86708069], [68.30236053, 23.86736107], [68.30179596, 23.86736107], [68.30180359, 23.86763954], [68.30124664, 23.86763954], [68.30124664, 23.86819458], [68.29985809, 23.86819458], [68.29985809, 23.86847305], [68.29930878, 23.86847305], [68.29930878, 23.86874962], [68.29902649, 23.86874008], [68.29902649, 23.86902809], [68.29875183, 23.86902809], [68.29875183, 23.86930466], [68.29846954, 23.86930466], [68.29846954, 23.8698616], [68.29818726, 23.8698597], [68.29818726, 23.87014008], [68.29792023, 23.87014008], [68.29792023, 23.87042236], [68.29763794, 23.87041664], [68.29763794, 23.87097168], [68.29736328, 23.87097168], [68.29736328, 23.87125015], [68.29708099, 23.87125015], [68.29708099, 23.87153053], [68.29680634, 23.87152863], [68.29680634, 23.87180519], [68.29652405, 23.87180519], [68.29652405, 23.87208366], [68.29624939, 23.87208176], [68.29624939, 23.87264061], [68.2959671, 23.87264061], [68.2959671, 23.8729229], [68.29569244, 23.87291718], [68.29569244, 23.87319374], [68.29541779, 23.87319374], [68.29541779, 23.87347221], [68.29512787, 23.87347031], [68.29512787, 23.87375069], [68.29486084, 23.87375069], [68.29486084, 23.87403107], [68.29458618, 23.87403107], [68.29458618, 23.87430954], [68.29430389, 23.87430573], [68.29430389, 23.87458229], [68.29374695, 23.87458038], [68.29374695, 23.8748703], [68.29319763, 23.8748703], [68.29319763, 23.87514114], [68.29180908, 23.87514114], [68.29180908, 23.8748703], [68.29096985, 23.8748703], [68.29096985, 23.87458038], [68.29070282, 23.87458038], [68.29070282, 23.8748703], [68.28985596, 23.8748703], [68.28985596, 23.87458038], [68.28874969, 23.87458229], [68.28874969, 23.87430573], [68.28819275, 23.87430954], [68.28819275, 23.87403107], [68.2876358, 23.87403107], [68.2876358, 23.87375069], [68.28679657, 23.87375069], [68.28679657, 23.87347031], [68.28624725, 23.87347221], [68.28624725, 23.87319374], [68.2859726, 23.87319374], [68.2859726, 23.87291718], [68.28569794, 23.8729229], [68.28569794, 23.87264061], [68.28514099, 23.87264061], [68.28514099, 23.87236023], [68.28457642, 23.87236023], [68.28457642, 23.87208176], [68.28430939, 23.87208366], [68.28430176, 23.87180519], [68.28375244, 23.87180519], [68.28375244, 23.87125015], [68.28318787, 23.87125015], [68.28318787, 23.87097168], [68.28263855, 23.87097168], [68.28263855, 23.87069511], [68.28235626, 23.87070274], [68.28235626, 23.87042236], [68.28180695, 23.87042236], [68.28180695, 23.87014008], [68.27874756, 23.87014008], [68.27874756, 23.87042236], [68.27791595, 23.87042236], [68.27791595, 23.87070274], [68.27708435, 23.87069511], [68.27708435, 23.87097168], [68.2765274, 23.87097168], [68.2765274, 23.87125015], [68.2756958, 23.87125015], [68.2756958, 23.87153053], [68.27541351, 23.87152863], [68.27541351, 23.87180519], [68.27402496, 23.87180519], [68.27402496, 23.87208366], [68.2729187, 23.87208176], [68.2729187, 23.87236023], [68.27179718, 23.87236023], [68.27179718, 23.87264061], [68.27153015, 23.87264061], [68.27153015, 23.8729229], [68.27097321, 23.87291718], [68.27097321, 23.87319374], [68.27041626, 23.87319374], [68.27041626, 23.87347221], [68.26985931, 23.87347031], [68.26985931, 23.87375069], [68.26930237, 23.87375069], [68.26930237, 23.87403107], [68.26847076, 23.87403107], [68.26847076, 23.87430954], [68.26791382, 23.87430573], [68.26791382, 23.87458229], [68.26735687, 23.87458038], [68.26735687, 23.8748703], [68.2664032, 23.87486839], [68.26625061, 23.8748703], [68.26625061, 23.87514114], [68.26541901, 23.87514114], [68.26541901, 23.87541962], [68.26430511, 23.8754158], [68.26430511, 23.87569237], [68.26097107, 23.87569237], [68.26097107, 23.8754158], [68.26040649, 23.87541962], [68.26040649, 23.87514114], [68.25901794, 23.87514114], [68.25901794, 23.87541962], [68.25875092, 23.8754158], [68.25875092, 23.87569237], [68.25846863, 23.87569237], [68.25846863, 23.87847137], [68.25818634, 23.87846947], [68.25818634, 23.87903023], [68.25846863, 23.87903023], [68.25846863, 23.88042068], [68.25875092, 23.88041878], [68.25875092, 23.88097191], [68.25901794, 23.88096809], [68.25901794, 23.88153076], [68.25930786, 23.88153076], [68.25930786, 23.88236046], [68.25958252, 23.88236046], [68.25958252, 23.88291931], [68.25986481, 23.8829174], [68.25986481, 23.88347244], [68.26013947, 23.88347244], [68.26013947, 23.88375092], [68.26040649, 23.88373947], [68.26040649, 23.88402939], [68.26069641, 23.88402748], [68.26069641, 23.88458252], [68.26097107, 23.88458061], [68.26097107, 23.88513947], [68.26125336, 23.88513947], [68.26125336, 23.88652992], [68.26152802, 23.88652992], [68.26152802, 23.8868103], [68.26180267, 23.88680649], [68.26180267, 23.88708115], [68.26208496, 23.88708115], [68.26208496, 23.88736153], [68.26319122, 23.88735962], [68.26319122, 23.88764], [68.26346588, 23.88764], [68.26346588, 23.88792038], [68.26374817, 23.88792038], [68.26374817, 23.88820076], [68.26430511, 23.88819313], [68.26430511, 23.8884716], [68.26457977, 23.8884697], [68.26457977, 23.88875008], [68.26486206, 23.88875008], [68.26486206, 23.88903046], [68.26515198, 23.88903046], [68.26515198, 23.88931084], [68.26541901, 23.88930321], [68.26541901, 23.88958359], [68.26568604, 23.88957977], [68.26568604, 23.88986969], [68.26597595, 23.88986969], [68.26597595, 23.89014053], [68.26625061, 23.89013863], [68.26625061, 23.89069366], [68.26652527, 23.89069366], [68.26652527, 23.89097214], [68.26680756, 23.89097023], [68.26680756, 23.89125061], [68.26708221, 23.89125061], [68.26708221, 23.89153099], [68.26789856, 23.89153099], [68.26789856, 23.89180946], [68.26847076, 23.89180756], [68.26847076, 23.89208412], [68.26930237, 23.89208031], [68.26930237, 23.89236069], [68.26985931, 23.89236069], [68.26985931, 23.89264107], [68.27069092, 23.89263916], [68.27069092, 23.89291763], [68.2701416, 23.89291], [68.2701416, 23.89430809], [68.27041626, 23.89430809], [68.27041626, 23.89486122], [68.27124786, 23.89486122], [68.27124786, 23.89513969], [68.27179718, 23.89513969], [68.27179718, 23.89541817], [68.2720871, 23.89541626], [68.2720871, 23.89569473], [68.27236176, 23.89569473], [68.27236176, 23.8959713], [68.27263641, 23.89596748], [68.27263641, 23.89624977], [68.2729187, 23.89624977], [68.2729187, 23.89652824], [68.27319336, 23.89652824], [68.27319336, 23.89680481], [68.27347565, 23.89680481], [68.27347565, 23.89708328], [68.27402496, 23.89708328], [68.27402496, 23.89736176], [68.27430725, 23.89736176], [68.27430725, 23.89764023], [68.27458191, 23.89764023], [68.27458191, 23.89792252], [68.27485657, 23.89792252], [68.27485657, 23.8982029], [68.27513885, 23.89819527], [68.27513885, 23.89847183], [68.27540588, 23.89847183], [68.27540588, 23.89931107], [68.2756958, 23.89931107], [68.2756958, 23.89986038], [68.27597046, 23.89986038], [68.27597046, 23.90042114], [68.27625275, 23.90041733], [68.27625275, 23.90097237], [68.2765274, 23.90097046], [68.2765274, 23.90153122], [68.27680206, 23.90153122], [68.27680206, 23.90180969], [68.27735901, 23.90180588], [68.27735901, 23.90208244], [68.27819061, 23.90208054], [68.27819824, 23.90236092], [68.2784729, 23.90236092], [68.2784729, 23.90402985], [68.27819824, 23.90402794], [68.27819061, 23.90458298], [68.27791595, 23.90458298], [68.27791595, 23.90486145], [68.2776413, 23.90485001], [68.2776413, 23.9054203], [68.27735901, 23.90541458], [68.27735901, 23.90791893], [68.2776413, 23.90790939], [68.2776413, 23.91013908], [68.27791595, 23.91013908], [68.27791595, 23.91124916], [68.27819061, 23.91124916], [68.27819824, 23.91236115], [68.2784729, 23.91236115], [68.2784729, 23.91292191], [68.27819824, 23.91291618], [68.27819061, 23.91319466], [68.27791595, 23.91319466], [68.27791595, 23.91347122], [68.2776413, 23.91347122], [68.2776413, 23.91374969], [68.27735901, 23.91374969], [68.27735901, 23.91403961], [68.27708435, 23.91402817], [68.27708435, 23.91486168], [68.2776413, 23.91485977], [68.2776413, 23.91514015], [68.27791595, 23.91514015], [68.27791595, 23.91542053], [68.2784729, 23.91542053], [68.2784729, 23.91570091], [68.27874756, 23.91569328], [68.27874756, 23.91597176], [68.27902985, 23.91596985], [68.27902985, 23.91625023], [68.27929688, 23.91625023], [68.27929688, 23.91653061], [68.27958679, 23.91653061], [68.27958679, 23.91681099], [68.27986145, 23.91680336], [68.27986145, 23.91708565], [68.28013611, 23.91708565], [68.28013611, 23.91736031], [68.2804184, 23.91736031], [68.2804184, 23.91764069], [68.28069305, 23.91763878], [68.28069305, 23.91819382], [68.28097534, 23.91819382], [68.28097534, 23.91847229], [68.28125, 23.91847038], [68.28125, 23.91875076], [68.28151703, 23.91875076], [68.28151703, 23.91903114], [68.28180695, 23.91903114], [68.28180695, 23.91930962], [68.28236389, 23.91930771], [68.28236389, 23.91958427], [68.28263855, 23.91958427], [68.28263855, 23.91986084], [68.28318787, 23.9198494], [68.28318787, 23.92014122], [68.28347015, 23.92014122], [68.28347015, 23.92041969], [68.28430176, 23.92041779], [68.28430176, 23.92069435], [68.28514099, 23.92069435], [68.28514099, 23.92097282], [68.28652954, 23.92097092], [68.28652954, 23.92124939], [68.2876358, 23.92124939], [68.2876358, 23.92152977], [68.28903198, 23.92152977], [68.28903198, 23.92180824], [68.29209137, 23.92180824], [68.29209137, 23.92152977], [68.29374695, 23.92152977], [68.29374695, 23.92124939], [68.29541779, 23.92124939], [68.29541779, 23.92097092], [68.29708099, 23.92097282], [68.29708099, 23.92069435], [68.29819489, 23.92069435], [68.29819489, 23.92041779], [68.29930878, 23.92041969], [68.29930878, 23.92014122], [68.30042267, 23.92014122], [68.30042267, 23.9198494], [68.30132294, 23.91985512], [68.30180359, 23.91986084], [68.30180359, 23.91958427], [68.30291748, 23.91958427], [68.30291748, 23.91930771], [68.30403137, 23.91930962], [68.30403137, 23.91903114], [68.30513763, 23.91903114], [68.30513763, 23.91875076], [68.30625153, 23.91875076], [68.30625153, 23.91847038], [68.30735779, 23.91847229], [68.30735779, 23.91819382], [68.30847168, 23.91819382], [68.30847168, 23.91791534], [68.3095932, 23.91792107], [68.3095932, 23.91764069], [68.31096649, 23.91764069], [68.31096649, 23.91736031], [68.31430817, 23.91736031], [68.31430817, 23.91707993], [68.31485748, 23.91708565], [68.31485748, 23.91680336], [68.3154068, 23.91681099], [68.3154068, 23.91653061], [68.31597137, 23.91653061], [68.31597137, 23.91625023], [68.31652832, 23.91625023], [68.31652832, 23.91596985], [68.31708527, 23.91597176], [68.31708527, 23.91569328], [68.317276, 23.9156971], [68.31791687, 23.91570091], [68.31791687, 23.91542053], [68.31874847, 23.91542053], [68.31874847, 23.91514015], [68.31958008, 23.91514015], [68.31958008, 23.91485977], [68.32152557, 23.91486168], [68.32152557, 23.91458321], [68.32485962, 23.91458321], [68.32485962, 23.91430473], [68.32624817, 23.91430473], [68.32624817, 23.91458321], [68.32736206, 23.91458321], [68.32736206, 23.91486168], [68.32820129, 23.91485977], [68.32820129, 23.91514015], [68.3290329, 23.91514015], [68.3290329, 23.91542053], [68.32958221, 23.91542053], [68.32958221, 23.91570091], [68.33041382, 23.91569328], [68.33041382, 23.91597176], [68.33097076, 23.91596985], [68.33097076, 23.91625023], [68.33180237, 23.91625023], [68.33180237, 23.91653061], [68.33235931, 23.91653061], [68.33235931, 23.91681099], [68.33291626, 23.91680336], [68.33291626, 23.91708565], [68.33347321, 23.91707993], [68.33347321, 23.91736031], [68.33403015, 23.91736031], [68.33403015, 23.91764069], [68.3345871, 23.91764069], [68.3345871, 23.91792107], [68.33486176, 23.91791534], [68.33486176, 23.91819382], [68.3354187, 23.91819382], [68.3354187, 23.91847229], [68.33569336, 23.91847038], [68.33569336, 23.91875076], [68.33598328, 23.91875076], [68.33598328, 23.91903114], [68.33625031, 23.91903114], [68.33625031, 23.91930962], [68.33680725, 23.91930771], [68.33680725, 23.91958427], [68.33708191, 23.91958427], [68.33708191, 23.91986084], [68.33737183, 23.9198494], [68.33737183, 23.92014122], [68.33763885, 23.92014122], [68.33763885, 23.92041969], [68.3381958, 23.92041779], [68.3381958, 23.92069435], [68.33847046, 23.92069435], [68.33847046, 23.92097282], [68.33875275, 23.92097092], [68.33875275, 23.92124939], [68.3390274, 23.92124939], [68.3390274, 23.92152977], [68.33930206, 23.92152977], [68.33930206, 23.92180824], [68.33958435, 23.92180634], [68.33958435, 23.9220829], [68.33985901, 23.92207909], [68.33985901, 23.9240303], [68.3409729, 23.9240303], [68.3409729, 23.92431259], [68.3418045, 23.92430496], [68.3418045, 23.92458344], [68.34236145, 23.92458153], [68.34236145, 23.92625046], [68.34263611, 23.92625046], [68.34263611, 23.92764091], [68.34236145, 23.92763901], [68.34236145, 23.92847252], [68.34263611, 23.92847061], [68.34263611, 23.92875099], [68.3431778, 23.92875099], [68.3431778, 23.92904091], [68.3434906, 23.92904091], [68.3434906, 23.92930984], [68.34375, 23.92930412], [68.34375, 23.9295826], [68.34401703, 23.92958069], [68.34401703, 23.92986107], [68.3445816, 23.92986107], [68.3445816, 23.93013954], [68.34485626, 23.93013954], [68.34485626, 23.93041992], [68.34513855, 23.93041992], [68.34513855, 23.93124962], [68.34541321, 23.93124962], [68.34541321, 23.93208313], [68.34570313, 23.93208122], [68.34570313, 23.93264008], [68.34597015, 23.93264008], [68.34597015, 23.93320084], [68.34570313, 23.93320084], [68.34570313, 23.93514061], [68.34597015, 23.93514061], [68.34597015, 23.93625069], [68.34623718, 23.93625069], [68.34623718, 23.93736076], [68.3465271, 23.93736076], [68.3465271, 23.94292068], [68.34625244, 23.94291687], [68.34625244, 23.9445858], [68.34597015, 23.94458008], [68.34597015, 23.94791985], [68.34625244, 23.94791794], [68.34625244, 23.94958305], [68.34597015, 23.94957924], [68.34597015, 23.95070267], [68.34570313, 23.95070267], [68.34570313, 23.95181274], [68.34541321, 23.95181274], [68.34541321, 23.95292282], [68.34513855, 23.9529171], [68.34513855, 23.95347214], [68.34485626, 23.95347023], [68.34485626, 23.95430946], [68.34513855, 23.95430565], [68.34513855, 23.95569229], [68.34541321, 23.95569229], [68.34541321, 23.95708275], [68.3456955, 23.95708275], [68.3456955, 23.95819664], [68.34597015, 23.95819664], [68.34597015, 23.95930672], [68.34623718, 23.95930099], [68.34623718, 23.96042061], [68.3465271, 23.9604187], [68.3465271, 23.96097183], [68.34680176, 23.96096992], [68.34680176, 23.96153069], [68.34707642, 23.96153069], [68.34707642, 23.96180916], [68.3473587, 23.96180916], [68.3473587, 23.96236038], [68.34764099, 23.96236038], [68.34764099, 23.96291924], [68.34791565, 23.96291733], [68.34791565, 23.96319389], [68.34819794, 23.96318817], [68.34819794, 23.96375084], [68.3484726, 23.96375084], [68.3484726, 23.96402931], [68.34874725, 23.96402931], [68.34874725, 23.9643116], [68.34902954, 23.9643116], [68.34902954, 23.96486092], [68.34931183, 23.96486092], [68.34931183, 23.96515274], [68.34958649, 23.96515274], [68.34958649, 23.96541977], [68.34986115, 23.96541595], [68.34986115, 23.9659729], [68.3501358, 23.9659729], [68.3501358, 23.96624947], [68.35041809, 23.96624947], [68.35041809, 23.96652985], [68.35069275, 23.96652985], [68.35069275, 23.96681023], [68.35097504, 23.96680641], [68.35097504, 23.96736145], [68.35124969, 23.96735954], [68.35124969, 23.9679203], [68.35152435, 23.96791649], [68.35152435, 23.96819305], [68.35180664, 23.96819305], [68.35180664, 23.96847153], [68.35236359, 23.96847153], [68.35236359, 23.96875], [68.35263824, 23.96875], [68.35263824, 23.96903038], [68.3529129, 23.96903038], [68.3529129, 23.96931076], [68.35319519, 23.96930313], [68.35319519, 23.96958351], [68.35346985, 23.96958351], [68.35346985, 23.96986198], [68.35375214, 23.96986008], [68.35375214, 23.97014046], [68.35402679, 23.97014046], [68.35402679, 23.97042084], [68.35430908, 23.97041512], [68.35430908, 23.97069359], [68.35514069, 23.97069359], [68.35514069, 23.97097206], [68.35569763, 23.97096062], [68.35569763, 23.97125053], [68.35679626, 23.97125053], [68.35679626, 23.97153091], [68.35708618, 23.97153091], [68.35708618, 23.97180939], [68.35736084, 23.97180939], [68.35736084, 23.97236061], [68.3576355, 23.97236061], [68.3576355, 23.97258186], [68.3576355, 23.97319412], [68.35791779, 23.97319031], [68.35791779, 23.97375107], [68.35819244, 23.97374725], [68.35819244, 23.97458267], [68.3584671, 23.97458076], [68.3584671, 23.97541809], [68.35874939, 23.97541618], [68.35874939, 23.97597313], [68.35901642, 23.97597122], [68.35901642, 23.97652817], [68.35930634, 23.97652817], [68.35930634, 23.97680473], [68.35958099, 23.97680473], [68.35958099, 23.97736168], [68.35986328, 23.97736168], [68.35986328, 23.97764015], [68.36042023, 23.97764015], [68.36042023, 23.97792244], [68.36068726, 23.97792244], [68.36068726, 23.97820282], [68.36125183, 23.97819519], [68.36125183, 23.97847176], [68.36180878, 23.97847176], [68.36180878, 23.97875023], [68.36235809, 23.97875023], [68.36235809, 23.97903061], [68.36264038, 23.97903061], [68.36264038, 23.9793129], [68.36319733, 23.97930527], [68.36319733, 23.97958374], [68.36374664, 23.97958183], [68.36374664, 23.97986031], [68.36430359, 23.97986031], [68.36430359, 23.98013878], [68.36486053, 23.98013115], [68.36486053, 23.98042107], [68.36541748, 23.98041725], [68.36541748, 23.98069382], [68.36569214, 23.98069382], [68.36569214, 23.98097229], [68.36624908, 23.98097038], [68.36624908, 23.98125076], [68.36680603, 23.98125076], [68.36680603, 23.98153114], [68.36763763, 23.98153114], [68.36763763, 23.98180962], [68.36819458, 23.9818058], [68.36819458, 23.98208237], [68.36902618, 23.98208046], [68.36902618, 23.98236084], [68.36958313, 23.98236084], [68.36958313, 23.98264122], [68.3704071, 23.98264122], [68.3704071, 23.98291969], [68.37124634, 23.98291588], [68.37124634, 23.98319435], [68.37208557, 23.98319435], [68.37208557, 23.98347282], [68.37264252, 23.98347092], [68.37264252, 23.98374939], [68.37346649, 23.98374939], [68.37346649, 23.98402977], [68.37431335, 23.98402977], [68.37431335, 23.98431015], [68.37513733, 23.98430443], [68.37513733, 23.9845829], [68.37541962, 23.9845829], [68.37541962, 23.98430443], [68.37625122, 23.98431015], [68.37625122, 23.98402977], [68.37654114, 23.98402977], [68.37654114, 23.98374939], [68.37680817, 23.98374939], [68.37680817, 23.98347092], [68.37708282, 23.98347282], [68.37708282, 23.98319435], [68.37735748, 23.98319435], [68.37735748, 23.98291588], [68.37763977, 23.98291969], [68.37763977, 23.98264122], [68.3779068, 23.98264122], [68.3779068, 23.98208046], [68.37819672, 23.98208237], [68.37819672, 23.9818058], [68.37847137, 23.98180962], [68.37847137, 23.98153114], [68.37874603, 23.98153114], [68.37874603, 23.98097038], [68.37902832, 23.98097229], [68.37902832, 23.97986031], [68.37928772, 23.97986031], [68.37928772, 23.97875023], [68.37960052, 23.97875023], [68.37958527, 23.97763824], [68.37985992, 23.97764015], [68.37985992, 23.97652817], [68.38014221, 23.97652817], [68.38014221, 23.97513962], [68.38041687, 23.97513962], [68.38041687, 23.97347069], [68.38069153, 23.9734726], [68.38069153, 23.97208595], [68.38097382, 23.97208595], [68.38097382, 23.97180748], [68.38124847, 23.97180939], [68.38124847, 23.97125053], [68.38153076, 23.97125053], [68.38153076, 23.97096062], [68.38180542, 23.97097206], [68.38180542, 23.97041512], [68.38208008, 23.97042084], [68.38208008, 23.9695797], [68.38236237, 23.96958351], [68.38236237, 23.96902847], [68.38263702, 23.96903038], [68.38263702, 23.96875], [68.38291931, 23.96875], [68.38291931, 23.96846962], [68.38319397, 23.96847153], [68.38319397, 23.96819305], [68.38346863, 23.96819305], [68.38346863, 23.96791649], [68.3840332, 23.9679203], [68.3840332, 23.96763992], [68.38430786, 23.96763992], [68.38430786, 23.96735954], [68.38486481, 23.96736145], [68.38486481, 23.96680641], [68.38513947, 23.96681023], [68.38513947, 23.96624947], [68.38540649, 23.96624947], [68.38540649, 23.9659729], [68.38597107, 23.9659729], [68.38597107, 23.96569443], [68.38625336, 23.96569443], [68.38625336, 23.96541595], [68.38680267, 23.96541977], [68.38680267, 23.96515274], [68.38735962, 23.96515274], [68.38735962, 23.96486092], [68.38903046, 23.96486092], [68.38903046, 23.96457863], [68.39208221, 23.96457863], [68.39208221, 23.96486092], [68.39375305, 23.96486092], [68.39375305, 23.96515274], [68.39485931, 23.96515274], [68.39485931, 23.96541977], [68.39597321, 23.96541595], [68.39597321, 23.96569443], [68.39653015, 23.96569443], [68.39653015, 23.9659729], [68.39679718, 23.9659729], [68.39679718, 23.96624947], [68.3973465, 23.96624947], [68.3973465, 23.96652985], [68.3979187, 23.96652985], [68.3979187, 23.96681023], [68.39819336, 23.96680641], [68.39819336, 23.96708107], [68.39902496, 23.96708107], [68.39902496, 23.96736145], [68.39930725, 23.96735954], [68.39930725, 23.96763992], [68.39985657, 23.96763992], [68.39985657, 23.9679203], [68.40013885, 23.96791649], [68.40013885, 23.96819305], [68.40041351, 23.96819305], [68.40041351, 23.96847153], [68.4006958, 23.96847153], [68.4006958, 23.96875], [68.40125275, 23.96875], [68.40125275, 23.96903038], [68.4015274, 23.96903038], [68.4015274, 23.96931076], [68.40180206, 23.96930313], [68.40180206, 23.96958351], [68.40207672, 23.9695797], [68.40207672, 23.97014046], [68.40235901, 23.97014046], [68.40235901, 23.97042084], [68.4026413, 23.97041512], [68.4026413, 23.97069359], [68.40291595, 23.97069359], [68.40291595, 23.97097206], [68.40319061, 23.97096062], [68.40319824, 23.97125053], [68.40374756, 23.97125053], [68.40374756, 23.97153091], [68.40402985, 23.97153091], [68.40402985, 23.97180939], [68.4043045, 23.97180748], [68.4043045, 23.97208595], [68.40458679, 23.97208023], [68.40458679, 23.97236061], [68.40486145, 23.97236061], [68.40486145, 23.97291946], [68.40513611, 23.97291756], [68.40513611, 23.97319412], [68.4054184, 23.97319412], [68.4054184, 23.9734726], [68.40569305, 23.97347069], [68.40569305, 23.97402954], [68.40598297, 23.97402954], [68.40598297, 23.97431946], [68.40625, 23.97431946], [68.40625, 23.97486115], [68.40651703, 23.97486115], [68.40651703, 23.97513962], [68.40680695, 23.97513962], [68.40680695, 23.97569466], [68.4070816, 23.97569466], [68.4070816, 23.97597313], [68.40735626, 23.97597122], [68.40735626, 23.97624969], [68.40763855, 23.97624969], [68.40763855, 23.97652817], [68.4081955, 23.97652817], [68.4081955, 23.97680473], [68.40847015, 23.97680092], [68.40847015, 23.97709274], [68.40875244, 23.97708321], [68.40875244, 23.97736168], [68.4092865, 23.97736168], [68.4092865, 23.97764015], [68.4098587, 23.97764015], [68.4098587, 23.97792244], [68.41042328, 23.97792244], [68.41042328, 23.97820282], [68.41069794, 23.97819519], [68.41069794, 23.97847176], [68.4109726, 23.97847176], [68.4109726, 23.97875023], [68.41124725, 23.97875023], [68.41124725, 23.9793129], [68.41152954, 23.97930527], [68.41152954, 23.97958374], [68.41179657, 23.97958183], [68.41179657, 23.97986031], [68.41208649, 23.97986031], [68.41208649, 23.98013878], [68.41236115, 23.98013115], [68.41236115, 23.98042107], [68.4126358, 23.98041725], [68.4126358, 23.98069382], [68.41291809, 23.98069382], [68.41291809, 23.98097229], [68.41319275, 23.98097038], [68.41319275, 23.98125076], [68.41348267, 23.98125076], [68.41348267, 23.98153114], [68.41374969, 23.98152733], [68.41374969, 23.98208237], [68.41401672, 23.98208046], [68.41401672, 23.98236084], [68.41430664, 23.98236084], [68.41430664, 23.98264122], [68.4145813, 23.98264122], [68.4145813, 23.98291969], [68.41486359, 23.98291588], [68.41486359, 23.98319435], [68.41513824, 23.98319435], [68.41513824, 23.98347282], [68.41542053, 23.98347092], [68.41542053, 23.98402977], [68.41569519, 23.98402786], [68.41569519, 23.9845829], [68.41596985, 23.9845829], [68.41596985, 23.98486137], [68.41625214, 23.98485947], [68.41625214, 23.98542023], [68.41652679, 23.98541451], [68.41652679, 23.98597145], [68.41680908, 23.98596954], [68.41680908, 23.98625946], [68.41707611, 23.98625946], [68.41707611, 23.98681068], [68.4173584, 23.98680687], [68.4173584, 23.98708344], [68.41764069, 23.98708344], [68.41764069, 23.98736191], [68.41792297, 23.98735809], [68.41792297, 23.98792076], [68.41819763, 23.98791885], [68.41819763, 23.9881897], [68.41845703, 23.98819923], [68.41845703, 23.98875046], [68.41874695, 23.98875046], [68.41874695, 23.98903084], [68.41902924, 23.98902893], [68.41902924, 23.98958397], [68.41929626, 23.98957825], [68.41929626, 23.98986053], [68.41958618, 23.98986053], [68.41958618, 23.99014091], [68.41986084, 23.99014091], [68.41986084, 23.99069405], [68.4201355, 23.99069405], [68.4201355, 23.99097252], [68.42041779, 23.99097061], [68.42041779, 23.99124908], [68.42069244, 23.99124908], [68.42069244, 23.99152946], [68.4209671, 23.99152946], [68.4209671, 23.99181175], [68.42152405, 23.99180603], [68.42152405, 23.9920826], [68.42180634, 23.99206924], [68.42180634, 23.99236107], [68.42208099, 23.99236107], [68.42208099, 23.99263954], [68.42236328, 23.99263954], [68.42236328, 23.99291992], [68.42292023, 23.99291611], [68.42292023, 23.99319458], [68.42346954, 23.99319458], [68.42346954, 23.99347115], [68.42375183, 23.99347115], [68.42375183, 23.99374962], [68.42430878, 23.99374962], [68.42430878, 23.99403], [68.42485809, 23.99402809], [68.42485809, 23.99430466], [68.42569733, 23.99430466], [68.42569733, 23.99458313], [68.42624664, 23.99458313], [68.42624664, 23.9948616], [68.42708588, 23.9948616], [68.42708588, 23.99513817], [68.4284668, 23.99513054], [68.4284668, 23.99542046], [68.43013763, 23.99542046], [68.43013763, 23.99513054], [68.43041992, 23.99513817], [68.43041992, 23.9948616], [68.43069458, 23.9948616], [68.43069458, 23.99458313], [68.43096924, 23.99458313], [68.43096924, 23.99430466], [68.43125153, 23.99430466], [68.43125153, 23.99402809], [68.43152618, 23.99403], [68.43152618, 23.99374962], [68.43180847, 23.99374962], [68.43180847, 23.99347115], [68.43208313, 23.99347115], [68.43208313, 23.99319458], [68.43235779, 23.99319458], [68.43235779, 23.99263954], [68.43264008, 23.99263954], [68.43264008, 23.99236107], [68.4329071, 23.99236107], [68.4329071, 23.99206924], [68.43319702, 23.9920826], [68.43319702, 23.99180603], [68.43345642, 23.99181175], [68.43345642, 23.99152946], [68.43374634, 23.99152946], [68.43374634, 23.99124908], [68.43402863, 23.99124908], [68.43402863, 23.99097061], [68.43430328, 23.99097252], [68.43430328, 23.99041748], [68.4345932, 23.99041939], [68.4345932, 23.99014091], [68.43486023, 23.99014091], [68.43486023, 23.98986053], [68.43514252, 23.98986053], [68.43514252, 23.98932266], [68.43541718, 23.98932266], [68.43541718, 23.98903084], [68.43569183, 23.98903084], [68.43569183, 23.98875046], [68.43596649, 23.98875046], [68.43596649, 23.98819923], [68.43624878, 23.9881897], [68.43624878, 23.98791885], [68.43653107, 23.98792076], [68.43653107, 23.98764038], [68.43682098, 23.98764038], [68.43682098, 23.9865303], [68.43653107, 23.9865303], [68.43653107, 23.98513985], [68.43624878, 23.98513985], [68.43624878, 23.98402977], [68.43596649, 23.98402977], [68.43596649, 23.98319054], [68.43569183, 23.98319435], [68.43569183, 23.98208237], [68.43541718, 23.98208237], [68.43541718, 23.98097229], [68.43514252, 23.98097229], [68.43514252, 23.97958374], [68.43486023, 23.97958374], [68.43486023, 23.97791672], [68.4345932, 23.97792244], [68.4345932, 23.97680092], [68.43430328, 23.97680473], [68.43430328, 23.96819305], [68.43402863, 23.96819305], [68.43402863, 23.9659729], [68.43374634, 23.9659729], [68.43374634, 23.9640274], [68.43345642, 23.96402931], [68.43345642, 23.96388435], [68.43347168, 23.96319389], [68.43319702, 23.96319389], [68.43319702, 23.96236038], [68.4329071, 23.96236038], [68.4329071, 23.96153069], [68.43264008, 23.96153069], [68.43264008, 23.96096992], [68.43235779, 23.96097183], [68.43235779, 23.96013641], [68.43264008, 23.96014023], [68.43264008, 23.95985985], [68.43208313, 23.95986176], [68.43208313, 23.95958328], [68.43125153, 23.95958328], [68.43125153, 23.95930672], [68.43096924, 23.95930672], [68.43096924, 23.95902634], [68.43069458, 23.95902634], [68.43069458, 23.9584713], [68.43041992, 23.9584713], [68.43041992, 23.95819664], [68.43013763, 23.95819664], [68.43013763, 23.95791435], [68.42986298, 23.95792007], [68.42986298, 23.95763969], [68.42958069, 23.95763969], [68.42958069, 23.95708084], [68.42930603, 23.95708275], [68.42930603, 23.95680428], [68.42903137, 23.95681], [68.42903137, 23.95652962], [68.42874908, 23.95652962], [68.42874908, 23.95625114], [68.4284668, 23.95625114], [68.4284668, 23.95596123], [68.42819214, 23.95597267], [68.42819214, 23.95541573], [68.42791748, 23.95541954], [68.42791748, 23.95514107], [68.42765045, 23.95514107], [68.42765045, 23.95486069], [68.42736053, 23.95486069], [68.42736053, 23.95458031], [68.42708588, 23.95458221], [68.42708588, 23.95402718], [68.42679596, 23.9540329], [68.42679596, 23.95375061], [68.42652893, 23.95375061], [68.42652893, 23.95347023], [68.42624664, 23.95347214], [68.42624664, 23.95319366], [68.42597198, 23.95319366], [68.42597198, 23.9529171], [68.42569733, 23.95292282], [68.42569733, 23.95236015], [68.42541504, 23.95236015], [68.42541504, 23.95180511], [68.42514038, 23.95181274], [68.42514038, 23.9509716], [68.42485809, 23.9509716], [68.42485809, 23.95041656], [68.42459106, 23.95042038], [68.42459106, 23.94957924], [68.42430878, 23.94958305], [68.42430878, 23.94902992], [68.42402649, 23.94902992], [68.42402649, 23.94819069], [68.42375183, 23.9481945], [68.42375183, 23.94763947], [68.42346954, 23.94763947], [68.42346954, 23.94688988], [68.42346954, 23.94680786], [68.42318726, 23.94680977], [68.42318726, 23.94597054], [68.42292023, 23.94597244], [68.42292023, 23.9454155], [68.42263794, 23.94542122], [68.42263794, 23.94431114], [68.42236328, 23.94431114], [68.42236328, 23.94320107], [68.42208099, 23.94320107], [68.42208099, 23.94207954], [68.42180634, 23.94208336], [68.42180634, 23.94152832], [68.42151642, 23.94153023], [68.42151642, 23.9406929], [68.42124939, 23.94069481], [68.42124939, 23.94013977], [68.4209671, 23.94013977], [68.4209671, 23.93931007], [68.42069244, 23.93931007], [68.42069244, 23.93875122], [68.42041779, 23.93875122], [68.42041779, 23.93818855], [68.4201355, 23.93819427], [68.4201355, 23.93736076], [68.41986084, 23.93736076], [68.41986084, 23.93680954], [68.41958618, 23.93680954], [68.41958618, 23.9359684], [68.41930389, 23.93597221], [68.41930389, 23.9351387], [68.41902924, 23.93514061], [68.41902924, 23.93457985], [68.41874695, 23.93458366], [68.41874695, 23.93402863], [68.41845703, 23.93403053], [68.41845703, 23.93375015], [68.41819763, 23.93375015], [68.41819763, 23.93346977], [68.41791534, 23.93347168], [68.41791534, 23.93319511], [68.41764069, 23.93320084], [68.41764069, 23.93292046], [68.4173584, 23.93292046], [68.4173584, 23.9323597], [68.41708374, 23.9323616], [68.41708374, 23.93208313], [68.41680908, 23.93208313], [68.41680908, 23.93180466], [68.41652679, 23.93180466], [68.41652679, 23.93152618], [68.41625214, 23.93153], [68.41625214, 23.93124962], [68.41596985, 23.93124962], [68.41596985, 23.93097115], [68.41569519, 23.93097305], [68.41569519, 23.93069649], [68.4154129, 23.93069649], [68.4154129, 23.93013954], [68.41513824, 23.93013954], [68.41513824, 23.92986107], [68.41485596, 23.92986107], [68.41485596, 23.92958069], [68.4145813, 23.9295826], [68.4145813, 23.92930412], [68.41374969, 23.92930984], [68.41374969, 23.92904091], [68.41348267, 23.92904091], [68.41348267, 23.92847061], [68.41319275, 23.92847252], [68.41319275, 23.92791748], [68.41291809, 23.92791939], [68.41291809, 23.92736053], [68.4126358, 23.92736053], [68.4126358, 23.92708206], [68.41236115, 23.92708206], [68.41236115, 23.9268055], [68.41208649, 23.92681122], [68.41208649, 23.92653275], [68.41179657, 23.92653275], [68.41179657, 23.92625046], [68.41152954, 23.92625046], [68.41152954, 23.92597961], [68.4109726, 23.92597961], [68.4109726, 23.9256916], [68.41069794, 23.92569351], [68.41069794, 23.92541695], [68.41014099, 23.92542267], [68.41014099, 23.92514038], [68.4098587, 23.92514038], [68.4098587, 23.92486191], [68.40930939, 23.92486191], [68.40930176, 23.92458344], [68.4090271, 23.92458344], [68.4090271, 23.92430496], [68.40847015, 23.92431259], [68.40847015, 23.9240303], [68.40791321, 23.9240303], [68.40791321, 23.92375183], [68.40735626, 23.92375183], [68.40735626, 23.92347145], [68.40652466, 23.92347145], [68.40652466, 23.92319489], [68.40597534, 23.92319489], [68.40597534, 23.92291641], [68.40402985, 23.92291832], [68.40402985, 23.92207909], [68.40374756, 23.9220829], [68.40374756, 23.92152977], [68.40348053, 23.92152977], [68.40348053, 23.92124939], [68.40291595, 23.92124939], [68.40291595, 23.92097092], [68.4026413, 23.92097282], [68.4026413, 23.92069435], [68.40097046, 23.92069435], [68.40097046, 23.92041779], [68.40013885, 23.92041969], [68.40013885, 23.92014122], [68.39848328, 23.92014122], [68.39848328, 23.9198494], [68.3979187, 23.91986084], [68.3979187, 23.91958427], [68.39763641, 23.91958237], [68.39763641, 23.91930771], [68.3970871, 23.91930962], [68.3970871, 23.91903114], [68.39653015, 23.91903114], [68.39653015, 23.91875076], [68.39624786, 23.91875076], [68.39624786, 23.91847038], [68.39569092, 23.91847229], [68.39569092, 23.91819382], [68.39319611, 23.91819382], [68.39319611, 23.91791534], [68.39263916, 23.91792107], [68.39263916, 23.91764069], [68.39208221, 23.91764069], [68.39208221, 23.91736031], [68.39152527, 23.91736031], [68.39152527, 23.91708565], [68.39097595, 23.91708565], [68.39097595, 23.91680336], [68.39068604, 23.91681099], [68.39068604, 23.91653061], [68.39013672, 23.91653061], [68.39013672, 23.91625023], [68.38986206, 23.91625023], [68.38986206, 23.91596985], [68.38930511, 23.91597176], [68.38930511, 23.91569328], [68.38903046, 23.91570091], [68.38903046, 23.91542053], [68.38848114, 23.91542053], [68.38848114, 23.91514015], [68.38791656, 23.91514015], [68.38791656, 23.91485977], [68.38764191, 23.91486168], [68.38764191, 23.91458321], [68.38708496, 23.91458321], [68.38708496, 23.91430473], [68.38569641, 23.91430473], [68.38569641, 23.91458321], [68.38458252, 23.91458321], [68.38458252, 23.91486168], [68.38375092, 23.91485977], [68.38375092, 23.91514015], [68.37708282, 23.91514015], [68.37708282, 23.91542053], [68.37680817, 23.91542053], [68.37680817, 23.91625023], [68.37654114, 23.91625023], [68.37654114, 23.91653061], [68.37625122, 23.91653061], [68.37625122, 23.91903114], [68.37652588, 23.91902542], [68.37652588, 23.91958427], [68.37708282, 23.91958427], [68.37708282, 23.91930771], [68.37847137, 23.91930771], [68.37847137, 23.91958427], [68.37875366, 23.91958427], [68.37875366, 23.91986084], [68.37847137, 23.9198494], [68.37847137, 23.92014122], [68.37735748, 23.92014122], [68.37735748, 23.92041969], [68.37625122, 23.92041969], [68.37625122, 23.92014122], [68.37596893, 23.92014122], [68.37596893, 23.9198494], [68.37569427, 23.91986084], [68.37569427, 23.91930771], [68.37541962, 23.91930962], [68.37541962, 23.91653061], [68.37568665, 23.91653061], [68.37568665, 23.91596985], [68.37596893, 23.91597176], [68.37596893, 23.91541672], [68.37625122, 23.91542053], [68.37625122, 23.91514015], [68.37654114, 23.91514015], [68.37654114, 23.91485977], [68.37541962, 23.91486168], [68.37541962, 23.91458321], [68.3737793, 23.91458321], [68.37069702, 23.91458321], [68.37069702, 23.91430473], [68.36985779, 23.91430473], [68.36985779, 23.91402817], [68.36902618, 23.91403961], [68.36902618, 23.91374969], [68.36818695, 23.91374969], [68.36818695, 23.91347122], [68.36791992, 23.91347122], [68.36791992, 23.91319466], [68.36680603, 23.91319466], [68.36680603, 23.91347122], [68.3659668, 23.91347122], [68.3659668, 23.91374969], [68.36347198, 23.91374969], [68.36347198, 23.91347122], [68.36264038, 23.91347122], [68.36264038, 23.91319466], [68.36208344, 23.91319466], [68.36208344, 23.91291618], [68.36125183, 23.91292191], [68.36125183, 23.91263962], [68.36042023, 23.91263962], [68.36042023, 23.91236115], [68.35930634, 23.91236115], [68.35930634, 23.91208267], [68.35791779, 23.91208267], [68.35791779, 23.91180611], [68.35736084, 23.91181183], [68.35736084, 23.91152954], [68.35652924, 23.91152954], [68.35652924, 23.91124916], [68.35597229, 23.91124916], [68.35597229, 23.91098022], [68.35540771, 23.91098022], [68.35540771, 23.9106884], [68.3548584, 23.91069412], [68.3548584, 23.91041756], [68.35430908, 23.91041946], [68.35430908, 23.91013908], [68.35375214, 23.91013908], [68.35375214, 23.90986061], [68.35319519, 23.90986061], [68.35319519, 23.90958405], [68.35263824, 23.90958405], [68.35263824, 23.90930557], [68.3520813, 23.90930939], [68.3520813, 23.90903091], [68.35151672, 23.90903091], [68.35151672, 23.90875053], [68.35097504, 23.90875053], [68.35097504, 23.90847206], [68.35041809, 23.90847206], [68.35041809, 23.90819359], [68.3501358, 23.90819359], [68.3501358, 23.90791893], [68.34986115, 23.90791893], [68.34986115, 23.90763855], [68.34958649, 23.90764046], [68.34958649, 23.90735817], [68.3493042, 23.90736198], [68.3493042, 23.90708351], [68.34902954, 23.90708351], [68.34902954, 23.90652847], [68.34874725, 23.90653038], [68.34874725, 23.90625], [68.3484726, 23.90625], [68.3484726, 23.90596962], [68.34819794, 23.90597153], [68.34819794, 23.90569687], [68.34792328, 23.90570068], [68.34792328, 23.9054203], [68.34764099, 23.9054203], [68.34764099, 23.90485001], [68.3473587, 23.90486145], [68.3473587, 23.90458298], [68.34708405, 23.90458298], [68.34708405, 23.9043045], [68.34680939, 23.90431023], [68.34680176, 23.90402985], [68.3465271, 23.90402985], [68.3465271, 23.90347099], [68.34625244, 23.90347481], [68.34625244, 23.90291405], [68.34597015, 23.90291977], [68.34597015, 23.90236092], [68.3456955, 23.90236092], [68.3456955, 23.90208244], [68.34541321, 23.90208244], [68.34541321, 23.9015274], [68.34513855, 23.90153122], [68.34513855, 23.90125084], [68.34485626, 23.90125084], [68.34485626, 23.90014076], [68.3445816, 23.90014076], [68.3445816, 23.89931107], [68.34430695, 23.89931107], [68.34430695, 23.89792252], [68.34401703, 23.89792252], [68.34401703, 23.89652824], [68.34375, 23.89652824], [68.34375, 23.89541817], [68.3434906, 23.89541817], [68.3434906, 23.89402962], [68.3431778, 23.89402962], [68.3431778, 23.89291], [68.3429184, 23.89291763], [68.3429184, 23.89180756], [68.34263611, 23.89180946], [68.34263611, 23.89068985], [68.34236145, 23.89069366], [68.34236145, 23.88986206], [68.34263611, 23.88986969], [68.34263611, 23.88931084], [68.3429184, 23.88931084], [68.3429184, 23.88903046], [68.3431778, 23.88903046], [68.3431778, 23.88875008], [68.3434906, 23.88875008], [68.34347534, 23.88819313], [68.34375, 23.88820076], [68.34375, 23.88792038], [68.34401703, 23.88792038], [68.34401703, 23.88735962], [68.34430695, 23.88736153], [68.34430695, 23.88680649], [68.3445816, 23.8868103], [68.3445816, 23.88624954], [68.34485626, 23.88624954], [68.34485626, 23.8856926], [68.34513855, 23.8856945], [68.34513855, 23.88513947], [68.34541321, 23.88513947], [68.34541321, 23.88458061], [68.3456955, 23.88458252], [68.3456955, 23.88375092], [68.34597015, 23.88375092], [68.34597015, 23.88319397], [68.34625244, 23.88319397], [68.34625244, 23.88264084], [68.3465271, 23.88264084], [68.3465271, 23.88236046], [68.34680176, 23.88236046], [68.34680939, 23.88180923], [68.34707642, 23.88180923], [68.34707642, 23.88096809], [68.3473587, 23.88097191], [68.3473587, 23.87958336], [68.34764099, 23.87958336], [68.34764099, 23.87819672], [68.34791565, 23.87819672], [68.34791565, 23.87708282], [68.34819794, 23.87708282], [68.34819794, 23.87597275], [68.3484726, 23.87597275], [68.3484726, 23.87375069], [68.34819794, 23.87375069], [68.34819794, 23.86763954], [68.3484726, 23.86763954], [68.3484726, 23.86652946], [68.34874725, 23.86652946], [68.34874725, 23.86514091], [68.3484726, 23.86514091], [68.3484726, 23.86375046], [68.34819794, 23.86375046], [68.34819794, 23.86264038], [68.34792328, 23.86264038], [68.34792328, 23.8615303], [68.34764099, 23.8615303], [68.34764099, 23.86042023], [68.3473587, 23.86042023], [68.3473587, 23.85957146], [68.34708405, 23.8595829], [68.34708405, 23.85902786], [68.34680939, 23.85902977], [68.34680176, 23.85819244], [68.3465271, 23.85819435], [68.3465271, 23.85763931], [68.34623718, 23.85763931], [68.34623718, 23.85707855], [68.34597015, 23.85708237], [68.34597015, 23.85625076], [68.3456955, 23.85625076], [68.3456955, 23.85569382], [68.34541321, 23.85569382], [68.34541321, 23.85486031], [68.34513855, 23.85486031], [68.34513855, 23.85430908], [68.34485626, 23.85430908], [68.34485626, 23.85375977], [68.3445816, 23.85375977], [68.3445816, 23.85320091], [68.34430695, 23.85320091], [68.34430695, 23.85264015], [68.34401703, 23.85264015], [68.34401703, 23.85207939], [68.34375, 23.85208321], [68.34375, 23.85152626], [68.3434906, 23.85153008], [68.3434906, 23.85097122], [68.34319305, 23.85097313], [68.34319305, 23.85013962], [68.3429184, 23.85013962], [68.3429184, 23.84958076], [68.34263611, 23.84958267], [68.34263611, 23.84902763], [68.34236145, 23.84902954], [68.34236145, 23.84819031], [68.34208679, 23.84819221], [68.34208679, 23.84763908], [68.3418045, 23.84763908], [68.3418045, 23.84708214], [68.34152985, 23.84708214], [68.34152985, 23.84680557], [68.34124756, 23.84680939], [68.34124756, 23.84625053], [68.3409729, 23.84625053], [68.3409729, 23.84569168], [68.34069824, 23.84569359], [68.34069824, 23.84541702], [68.34043121, 23.84542274], [68.34043121, 23.84486008], [68.3401413, 23.84486008], [68.3401413, 23.84430504], [68.33985901, 23.84431267], [68.33985901, 23.84375191], [68.33957672, 23.84375191], [68.33957672, 23.84347153], [68.33930206, 23.84347153], [68.33930206, 23.84319496], [68.3390274, 23.84320259], [68.3390274, 23.84263992], [68.33875275, 23.84263992], [68.33875275, 23.84235954], [68.33847046, 23.84236145], [68.33847046, 23.84208298], [68.3381958, 23.84208298], [68.3381958, 23.84180641], [68.33790588, 23.84182167], [68.33790588, 23.84124947], [68.33763885, 23.84124947], [68.33763885, 23.84069061], [68.3373642, 23.84069443], [68.3373642, 23.84041786], [68.33708191, 23.84041977], [68.33708191, 23.83986092], [68.33680725, 23.83986092], [68.33680725, 23.83930969], [68.33653259, 23.83930969], [68.33653259, 23.83876038], [68.33625031, 23.83876038], [68.33625031, 23.83596992], [68.33652496, 23.83597183], [68.33652496, 23.83152771], [68.33680725, 23.83152962], [68.33680725, 23.82818985], [68.33708191, 23.82819366], [68.33708191, 23.82486153], [68.3373642, 23.82486153], [68.3373642, 23.82208252], [68.33763885, 23.82208252], [68.33763885, 23.81930542], [68.33737183, 23.81931114], [68.33737183, 23.81903267], [68.33680725, 23.81903267], [68.33680725, 23.81875038], [68.33652496, 23.81875038], [68.33652496, 23.81847191], [68.33597565, 23.81847191], [68.33597565, 23.81819534], [68.3354187, 23.81820107], [68.3354187, 23.81792259], [68.33513641, 23.81792259], [68.33513641, 23.81764984], [68.3345871, 23.81764984], [68.3345871, 23.81736183], [68.33403015, 23.81736183], [68.33403015, 23.81708336], [68.33347321, 23.81708336], [68.33347321, 23.81680489], [68.33291626, 23.81680489], [68.33291626, 23.81652832], [68.33235931, 23.81653023], [68.33235931, 23.81624985], [68.33180237, 23.81624985], [68.33180237, 23.81596756], [68.33125305, 23.81597137], [68.33125305, 23.81569481], [68.33097076, 23.81569481], [68.33097076, 23.81541634], [68.33040619, 23.81541824], [68.33040619, 23.81513977], [68.33013916, 23.81513977], [68.33013916, 23.81485748], [68.32958221, 23.8148613], [68.32958221, 23.81458282], [68.32930756, 23.81459045], [68.32930756, 23.81430817], [68.3290329, 23.81430817], [68.3290329, 23.81402969], [68.32875061, 23.81402969], [68.32875061, 23.81375122], [68.32849121, 23.81375122], [68.32849121, 23.81347084], [68.32819366, 23.81347275], [68.32819366, 23.81319427], [68.32791901, 23.81319427], [68.32791901, 23.81291771], [68.32763672, 23.81291962], [68.32763672, 23.81264114], [68.32736206, 23.81264114], [68.32736206, 23.81236076], [68.32707977, 23.81236076], [68.32707977, 23.81208038], [68.32680511, 23.8120842], [68.32680511, 23.81180763], [68.32653046, 23.81180954], [68.32653046, 23.81125069], [68.32624817, 23.81125069], [68.32624817, 23.81097031], [68.32597351, 23.81097221], [68.32597351, 23.81069374], [68.32569122, 23.81069374], [68.32569122, 23.81041527], [68.32543182, 23.81042099], [68.32543182, 23.81014061], [68.32514191, 23.81014061], [68.32514191, 23.80957985], [68.32485962, 23.80958557], [68.32485962, 23.80930328], [68.32457733, 23.80931091], [68.32457733, 23.80903053], [68.32430267, 23.80903053], [68.32430267, 23.80875015], [68.32402802, 23.80875015], [68.32402802, 23.80846024], [68.32375336, 23.80847168], [68.32375336, 23.80819321], [68.32347107, 23.80820084], [68.32347107, 23.80764008], [68.32319641, 23.80764008], [68.32319641, 23.8073597], [68.32125092, 23.8073616], [68.32125092, 23.80708122], [68.32096863, 23.80708122], [68.32096863, 23.8073616], [68.32068634, 23.8073597], [68.32068634, 23.80764008], [68.32013702, 23.80764008], [68.32013702, 23.80792046], [68.31986237, 23.80792046], [68.31986237, 23.80820084], [68.31958008, 23.80820084], [68.31958008, 23.80875015], [68.31929779, 23.80875015], [68.31929779, 23.80931091], [68.31903076, 23.80930328], [68.31903076, 23.81069374], [68.31874847, 23.81068993], [68.31874847, 23.81264114], [68.31846619, 23.81264114], [68.31846619, 23.81375122], [68.31819153, 23.81375122], [68.31819153, 23.81402969], [68.31791687, 23.81402969], [68.31791687, 23.8148613], [68.31764221, 23.8148613], [68.31764221, 23.81569481], [68.31735992, 23.81569481], [68.31735992, 23.81597137], [68.3170929, 23.81596756], [68.3170929, 23.81653023], [68.31680298, 23.81652832], [68.31680298, 23.81708336], [68.31652832, 23.81708145], [68.31652832, 23.81792259], [68.31626129, 23.81792259], [68.31626129, 23.81820107], [68.31597137, 23.81819534], [68.31597137, 23.81847191], [68.31569672, 23.81847191], [68.31569672, 23.81875038], [68.3154068, 23.81875038], [68.3154068, 23.81986046], [68.31513977, 23.81986046], [68.31513977, 23.82042122], [68.31485748, 23.8204174], [68.31485748, 23.82097244], [68.31458282, 23.82097054], [68.31458282, 23.82125092], [68.31430817, 23.82125092], [68.31430817, 23.82180977], [68.31402588, 23.82180405], [68.31402588, 23.82208252], [68.31430817, 23.82208061], [68.31430817, 23.82236099], [68.31458282, 23.82236099], [68.31458282, 23.82402992], [68.31430817, 23.82402611], [68.31430817, 23.82430458], [68.31346893, 23.82430458], [68.31346893, 23.82402611], [68.3132019, 23.82402992], [68.3132019, 23.82319069], [68.31291962, 23.82319641], [68.31291962, 23.82291412], [68.31236267, 23.82291412], [68.31236267, 23.82319641], [68.31208038, 23.82319069], [68.31208038, 23.82374954], [68.31181335, 23.82374954], [68.31181335, 23.82402992], [68.31124878, 23.82402611], [68.31124878, 23.82430077], [68.31069183, 23.82430458], [68.31069183, 23.82458305], [68.31014252, 23.82458305], [68.31014252, 23.82486153], [68.30847168, 23.82485962], [68.30847168, 23.82514], [68.30625153, 23.82514], [68.30625153, 23.82485962], [68.30486298, 23.82486153], [68.30486298, 23.82458305], [68.30374908, 23.82458305], [68.30374908, 23.82430458], [68.30319214, 23.82430077], [68.30319214, 23.82402611], [68.30264282, 23.82402992], [68.30264282, 23.82374954], [68.30179596, 23.82374954], [68.30179596, 23.82347107], [68.30097198, 23.82347488], [68.30097198, 23.82319641], [68.30041504, 23.82319641], [68.30041504, 23.82291412], [68.29985809, 23.82291985], [68.29985809, 23.82263947], [68.29930878, 23.82263947], [68.29930878, 23.82236099], [68.29846954, 23.82236099], [68.29846954, 23.82208061], [68.29792023, 23.82208252], [68.29792023, 23.82180405], [68.29708099, 23.82180977], [68.29708099, 23.82152939], [68.29651642, 23.82152939], [68.29651642, 23.82125092], [68.2959671, 23.82125092], [68.2959671, 23.82097054], [68.2951355, 23.82097244], [68.2951355, 23.82069206], [68.29402924, 23.82069206], [68.29402924, 23.8204174], [68.29347229, 23.82042122], [68.29347229, 23.82014275], [68.29292297, 23.82014275], [68.29292297, 23.81986046], [68.2923584, 23.81986046], [68.2923584, 23.81958008], [68.29208374, 23.81958389], [68.29208374, 23.81930542], [68.29125214, 23.81931114], [68.29125214, 23.81903267], [68.29096985, 23.81903267], [68.29096985, 23.81875038], [68.29069519, 23.81875038], [68.29069519, 23.81847191], [68.29013824, 23.81847191], [68.29013824, 23.81819534], [68.2895813, 23.81820107], [68.2895813, 23.81792259], [68.2893219, 23.81792259], [68.2893219, 23.81764984], [68.28903198, 23.81764984], [68.28903198, 23.81736183], [68.28874969, 23.81736183], [68.28874969, 23.8148613], [68.28902435, 23.8148613], [68.28902435, 23.81458282], [68.2893219, 23.81459045], [68.2893219, 23.81430817], [68.28985596, 23.81430817], [68.28985596, 23.81402969], [68.2904129, 23.81402969], [68.2904129, 23.81375122], [68.29070282, 23.81375122], [68.29070282, 23.81347084], [68.29125214, 23.81347275], [68.29125214, 23.81319427], [68.29180908, 23.81319427], [68.29180908, 23.81291771], [68.29209137, 23.81291962], [68.29209137, 23.81264114], [68.29264069, 23.81264114], [68.29264069, 23.81236076], [68.29319763, 23.81236076], [68.29319763, 23.81208038], [68.29402924, 23.8120842], [68.29402924, 23.81180763], [68.29458618, 23.81180954], [68.29458618, 23.81153107], [68.29486084, 23.81153107], [68.29486084, 23.81125069], [68.29541779, 23.81125069], [68.29541779, 23.81097031], [68.29569244, 23.81097221], [68.29569244, 23.81041527], [68.2959671, 23.81042099], [68.2959671, 23.80903053], [68.29624939, 23.80903053], [68.29624939, 23.80708122], [68.29652405, 23.80708122], [68.29652405, 23.80652809], [68.29624939, 23.80653191], [68.29624939, 23.80569267], [68.29597473, 23.80569458], [68.29597473, 23.80486107], [68.29569244, 23.80486107], [68.29569244, 23.80431175], [68.29512787, 23.80431175], [68.29512787, 23.80402946], [68.29458618, 23.80402946], [68.29458618, 23.80374908], [68.29374695, 23.80374908], [68.29374695, 23.80347061], [68.29319763, 23.80347252], [68.29319763, 23.80319405], [68.29264069, 23.80319405], [68.29264069, 23.80291748], [68.29180908, 23.80291939], [68.29180908, 23.80265045], [68.29125214, 23.80265045], [68.29125214, 23.80236053], [68.2895813, 23.80236053], [68.2895813, 23.80207825], [68.28847504, 23.80208397], [68.28847504, 23.8018055], [68.2876358, 23.80180931], [68.2876358, 23.80153084], [68.28652954, 23.80153084], [68.28652954, 23.80125046], [68.28541565, 23.80125046], [68.28541565, 23.80097198], [68.2848587, 23.80097198], [68.2848587, 23.80069351], [68.28430939, 23.80069351], [68.28430176, 23.80041885], [68.28180695, 23.80042076], [68.28180695, 23.80014038], [68.28098297, 23.80014038], [68.28098297, 23.79985809], [68.2804184, 23.79986191], [68.2804184, 23.79958344], [68.27929688, 23.79959106], [68.27929688, 23.79931068], [68.27874756, 23.79931068], [68.27874756, 23.7990303], [68.27819824, 23.7990303], [68.27819824, 23.79874992], [68.27680206, 23.79874992], [68.27680206, 23.79846954], [68.27625275, 23.79847145], [68.27625275, 23.79819679], [68.2756958, 23.79819679], [68.2756958, 23.79791451], [68.27540588, 23.79792023], [68.27540588, 23.79763985], [68.27485657, 23.79763985], [68.27485657, 23.79735947], [68.27430725, 23.79736137], [68.27430725, 23.7970829], [68.27402496, 23.7970829], [68.27402496, 23.79680443], [68.27375031, 23.79681015], [68.27375031, 23.79652023], [68.27347565, 23.79652786], [68.27347565, 23.79597473], [68.27319336, 23.79597473], [68.27319336, 23.79569244], [68.2729187, 23.79569244], [68.2729187, 23.79541588], [68.27263641, 23.79541969], [68.27263641, 23.79486084], [68.27236176, 23.79486084], [68.27236176, 23.79375076], [68.2720871, 23.79375076], [68.2720871, 23.79292107], [68.27179718, 23.79292107], [68.27179718, 23.79208183], [68.27153015, 23.79208374], [68.27153015, 23.7915287], [68.27124786, 23.79153252], [68.27124786, 23.78957748], [68.27097321, 23.78958321], [68.27097321, 23.78763962], [68.27069092, 23.78764915], [68.27069092, 23.78652954], [68.27041626, 23.78652954], [68.27041626, 23.78569031], [68.26985931, 23.78569031], [68.26985931, 23.78625107], [68.26957703, 23.78625107], [68.26957703, 23.78680992], [68.26930237, 23.78680992], [68.26930237, 23.78764915], [68.26902771, 23.78763962], [68.26902771, 23.78847313], [68.26875305, 23.78847122], [68.26875305, 23.78874969], [68.26847076, 23.78874969], [68.26847076, 23.78902817], [68.26821136, 23.78902817], [68.26821136, 23.79014015], [68.26789856, 23.79014015], [68.26789856, 23.79071045], [68.26763916, 23.79071045], [68.26763916, 23.79125023], [68.26735687, 23.79125023], [68.26735687, 23.7918129], [68.26708221, 23.7918129], [68.26708221, 23.79292107], [68.26680756, 23.79291725], [68.26680756, 23.79319382], [68.26597595, 23.79319382], [68.26597595, 23.79291725], [68.26568604, 23.79292107], [68.26568604, 23.79125023], [68.26597595, 23.79125023], [68.26597595, 23.79042244], [68.26625061, 23.79042244], [68.26625061, 23.79014015], [68.2665329, 23.79014015], [68.2665329, 23.78930092], [68.26680756, 23.78930473], [68.26680756, 23.78847313], [68.26708221, 23.78847313], [68.26708221, 23.78791618], [68.26735687, 23.78791809], [68.26735687, 23.78736115], [68.26763916, 23.78736115], [68.26763916, 23.78652954], [68.26789856, 23.78652954], [68.26789856, 23.78569031], [68.26819611, 23.78569412], [68.26819611, 23.78513908], [68.26847076, 23.78514099], [68.26847076, 23.78430939], [68.26875305, 23.78430939], [68.26875305, 23.78347015], [68.26930237, 23.78347206], [68.26930237, 23.78263855], [68.26957703, 23.78264046], [68.26957703, 23.78181076], [68.26985931, 23.78181076], [68.26985931, 23.78096962], [68.26958466, 23.78097153], [68.26958466, 23.78041649], [68.26930237, 23.7804203], [68.26930237, 23.77985954], [68.26902771, 23.77986145], [68.26902771, 23.77930641], [68.26875305, 23.77931023], [68.26875305, 23.77874947], [68.26847076, 23.77874947], [68.26847076, 23.77819252], [68.26819611, 23.77819443], [68.26819611, 23.77763939], [68.26789856, 23.77763939], [68.26789856, 23.77708054], [68.26763916, 23.77708244], [68.26763916, 23.7765274], [68.26735687, 23.77652931], [68.26735687, 23.77597046], [68.26708221, 23.77597237], [68.26708221, 23.77541733], [68.26680756, 23.77541924], [68.26680756, 23.77486038], [68.26652527, 23.77486038], [68.26652527, 23.77430534], [68.26625061, 23.77430916], [68.26625061, 23.77346992], [68.26597595, 23.77347183], [68.26597595, 23.77263641], [68.26568604, 23.77264023], [68.26568604, 23.77235031], [68.26541901, 23.77236176], [68.26541901, 23.77180672], [68.26569366, 23.77180672], [68.26569366, 23.77152824], [68.26597595, 23.77153015], [68.26597595, 23.77042007], [68.26568604, 23.77042007], [68.26568604, 23.76931], [68.26541901, 23.76931], [68.26541901, 23.76875114], [68.26515198, 23.76875114], [68.26515198, 23.76819038], [68.26486206, 23.76819229], [68.26486206, 23.76763916], [68.26457977, 23.76764107], [68.26457977, 23.76708031], [68.26430511, 23.76708221], [68.26430511, 23.76652718], [68.26403046, 23.76654053], [68.26403046, 23.76597023], [68.26374817, 23.76597023], [68.26374817, 23.7654171], [68.26346588, 23.76542282], [68.26346588, 23.76458168], [68.26319122, 23.76458359], [68.26319122, 23.76375008], [68.26291656, 23.76375008], [68.26291656, 23.76291847], [68.26264191, 23.76291847], [68.26264191, 23.76069069], [68.26235962, 23.7606945], [68.26235962, 23.76013947], [68.26207733, 23.76013947], [68.26207733, 23.75625038], [68.26235962, 23.75625038], [68.26235962, 23.75346947], [68.26264191, 23.75347137], [68.26264191, 23.7523613], [68.26291656, 23.7523613], [68.26291656, 23.75152779], [68.26319122, 23.75154114], [68.26319122, 23.75097084], [68.26347351, 23.75097275], [68.26347351, 23.7504158], [68.26374817, 23.75041962], [68.26374817, 23.74986076], [68.26403046, 23.74986076], [68.26403046, 23.74957848], [68.26430511, 23.7495842], [68.26430511, 23.74902725]]], [[[68.24819183, 23.88042068], [68.24819183, 23.8801403], [68.24931335, 23.8801403], [68.24931335, 23.87985992], [68.25013733, 23.87986183], [68.25013733, 23.87958336], [68.25125122, 23.87958336], [68.25125122, 23.87930679], [68.25152588, 23.87930679], [68.25152588, 23.87902832], [68.25180817, 23.87903023], [68.25180817, 23.87874985], [68.25208282, 23.87874985], [68.25208282, 23.87819099], [68.25235748, 23.87819672], [68.25235748, 23.87791443], [68.25263977, 23.87792969], [68.25263977, 23.87763977], [68.25292206, 23.87763977], [68.25291443, 23.8773613], [68.25319672, 23.8773613], [68.25319672, 23.87708282], [68.25347137, 23.87708282], [68.25347137, 23.87680435], [68.25374603, 23.87681007], [68.25374603, 23.87652969], [68.25402832, 23.87652969], [68.25402832, 23.87625122], [68.25430298, 23.87625122], [68.25430298, 23.87569046], [68.25458527, 23.87569237], [68.25458527, 23.87513924], [68.25485992, 23.87514114], [68.25485992, 23.87375069], [68.25458527, 23.87375069], [68.25458527, 23.8726387], [68.25430298, 23.87264061], [68.25430298, 23.87179947], [68.25402832, 23.87180519], [68.25402832, 23.87097168], [68.25375366, 23.87097168], [68.25375366, 23.8698616], [68.25347137, 23.8698616], [68.25347137, 23.86902809], [68.25321198, 23.86902809], [68.25321198, 23.86791992], [68.25292206, 23.86791992], [68.25292206, 23.86683273], [68.2527771, 23.86681938], [68.25263977, 23.86680984], [68.25263977, 23.86625099], [68.25235748, 23.86625099], [68.25235748, 23.86541939], [68.25208282, 23.86541939], [68.25208282, 23.86403084], [68.25180817, 23.86403084], [68.25180817, 23.86236], [68.25152588, 23.86236191], [68.25152588, 23.86208344], [68.25096893, 23.86208344], [68.25096893, 23.86180305], [68.25068665, 23.86181068], [68.25068665, 23.8615303], [68.25041962, 23.8615303], [68.25041962, 23.86124992], [68.25013733, 23.86124992], [68.25013733, 23.86096954], [68.24958038, 23.86097145], [68.24958038, 23.86069489], [68.24930573, 23.86069489], [68.24930573, 23.86041641], [68.24903107, 23.86042023], [68.24903107, 23.86013985], [68.24846649, 23.86013985], [68.24846649, 23.85985947], [68.24819183, 23.85986137], [68.24819183, 23.8595829], [68.24791718, 23.8595829], [68.24791718, 23.85930634], [68.24736023, 23.85931015], [68.24736023, 23.85902977], [68.24707794, 23.85902977], [68.24707794, 23.85874939], [68.24678802, 23.85874939], [68.24678802, 23.85847282], [68.24624634, 23.85847282], [68.24624634, 23.85819435], [68.24597168, 23.85819435], [68.24597168, 23.85791588], [68.24569702, 23.85791969], [68.24569702, 23.85763931], [68.24514008, 23.85763931], [68.24514008, 23.85736084], [68.24485779, 23.85736084], [68.24485779, 23.85707855], [68.24458313, 23.85708237], [68.24458313, 23.8568058], [68.24402618, 23.8568058], [68.24402618, 23.85652733], [68.24375153, 23.85652924], [68.24375153, 23.85625076], [68.24318695, 23.85625076], [68.24318695, 23.85597038], [68.24291992, 23.85597229], [68.24291992, 23.85569382], [68.24263763, 23.85569382], [68.24263763, 23.85541725], [68.24208069, 23.85541916], [68.24208069, 23.85514069], [68.24180603, 23.85514069], [68.24180603, 23.85486031], [68.24153137, 23.85486031], [68.24153137, 23.85457993], [68.24097443, 23.85458374], [68.24097443, 23.85430527], [68.24069214, 23.85430908], [68.24069214, 23.85403061], [68.24041748, 23.85403061], [68.24041748, 23.85375977], [68.23986053, 23.85375977], [68.23986053, 23.85346985], [68.23958588, 23.85347176], [68.23958588, 23.85319519], [68.23929596, 23.85320091], [68.23929596, 23.85292053], [68.23902893, 23.85292053], [68.23902893, 23.85235977], [68.23874664, 23.85236168], [68.23874664, 23.85208321], [68.23847198, 23.85208321], [68.23847198, 23.85180664], [68.23819733, 23.85180664], [68.23819733, 23.85124969], [68.23791504, 23.85124969], [68.23791504, 23.85097313], [68.23764038, 23.85097313], [68.23764038, 23.85041428], [68.23735809, 23.85042], [68.23735809, 23.84986115], [68.23707581, 23.84986115], [68.23707581, 23.84930992], [68.23680878, 23.84930992], [68.23680878, 23.84875107], [68.23652649, 23.84875107], [68.23652649, 23.84819031], [68.23625183, 23.84819221], [68.23625183, 23.84763908], [68.23569489, 23.84763908], [68.23569489, 23.8465271], [68.23542023, 23.84653282], [68.23542023, 23.84625053], [68.23513794, 23.84625053], [68.23513794, 23.84597015], [68.23486328, 23.84597015], [68.23486328, 23.84458351], [68.23458099, 23.84458351], [68.23458099, 23.84430504], [68.23430634, 23.84431267], [68.23430634, 23.84347153], [68.23402405, 23.84347153], [68.23402405, 23.84291649], [68.23374939, 23.8429184], [68.23374939, 23.84263992], [68.2334671, 23.84263992], [68.2334671, 23.84235954], [68.23291779, 23.84235954], [68.23291779, 23.84263992], [68.23236084, 23.84263992], [68.23236084, 23.8429184], [68.23207855, 23.8429184], [68.23207855, 23.84320259], [68.23152924, 23.84319496], [68.23152924, 23.84347153], [68.23124695, 23.84347153], [68.23124695, 23.84375191], [68.23014069, 23.84375191], [68.23014069, 23.84403038], [68.22930908, 23.84403038], [68.22930908, 23.84430504], [68.2292099, 23.84430504], [68.22846985, 23.84430504], [68.22846985, 23.84458351], [68.2279129, 23.84458351], [68.2279129, 23.84486008], [68.2270813, 23.84486008], [68.2270813, 23.84514046], [68.22680664, 23.84514046], [68.22680664, 23.84542274], [68.22652435, 23.84541702], [68.22652435, 23.84569359], [68.22597504, 23.84569359], [68.22597504, 23.84597015], [68.22569275, 23.84597015], [68.22569275, 23.84625053], [68.22541809, 23.84625053], [68.22541809, 23.84653282], [68.22458649, 23.84653282], [68.22458649, 23.84680939], [68.22402954, 23.84680557], [68.22402954, 23.84708214], [68.21847534, 23.84708214], [68.21847534, 23.84736061], [68.21708679, 23.84736061], [68.21708679, 23.84763908], [68.2159729, 23.84762955], [68.2159729, 23.84875107], [68.21569824, 23.84875107], [68.21569824, 23.85070038], [68.2159729, 23.85069656], [68.2159729, 23.85208321], [68.21569824, 23.85208321], [68.21569824, 23.85347176], [68.2159729, 23.85346985], [68.2159729, 23.85430908], [68.21569824, 23.85430527], [68.21569824, 23.85569382], [68.2159729, 23.85569382], [68.2159729, 23.8568058], [68.21624756, 23.85679817], [68.21624756, 23.85736084], [68.2159729, 23.85736084], [68.2159729, 23.85791969], [68.21569824, 23.85791588], [68.21569061, 23.85847282], [68.21541595, 23.85847282], [68.21541595, 23.85931015], [68.21569061, 23.85930634], [68.21569061, 23.85986137], [68.21541595, 23.85985947], [68.21541595, 23.86042023], [68.2151413, 23.86041641], [68.2151413, 23.86069489], [68.21485901, 23.86069489], [68.21485901, 23.86097145], [68.21457672, 23.86096954], [68.21457672, 23.8615303], [68.21430206, 23.8615303], [68.21430206, 23.86181068], [68.21375275, 23.86181068], [68.21375275, 23.86264038], [68.21404266, 23.86264038], [68.21404266, 23.8629303], [68.21430206, 23.86291695], [68.21430206, 23.86347198], [68.21457672, 23.86347008], [68.21457672, 23.86403084], [68.21485901, 23.86403084], [68.21485901, 23.86486053], [68.2151413, 23.86486053], [68.2151413, 23.86541939], [68.21541595, 23.86541748], [68.21541595, 23.86597252], [68.21569061, 23.86597061], [68.21569824, 23.86652946], [68.2159729, 23.86652946], [68.2159729, 23.86680984], [68.21624756, 23.86680794], [68.21624756, 23.8670826], [68.21652985, 23.86708069], [68.21652985, 23.86736107], [68.2168045, 23.86736107], [68.2168045, 23.86763954], [68.2179184, 23.86763954], [68.2179184, 23.86791992], [68.21875, 23.86791611], [68.21875, 23.86819458], [68.21986389, 23.86819458], [68.21986389, 23.86847305], [68.22013855, 23.86847305], [68.22013855, 23.86874962], [68.22041321, 23.86874008], [68.22041321, 23.86902809], [68.2206955, 23.86902809], [68.2206955, 23.86930466], [68.2223587, 23.86930466], [68.2223587, 23.86958313], [68.22291565, 23.86958313], [68.22291565, 23.8698616], [68.22374725, 23.8698597], [68.22374725, 23.87014008], [68.22429657, 23.87014008], [68.22429657, 23.87042236], [68.22486115, 23.87042236], [68.22486115, 23.87070274], [68.22541809, 23.87069511], [68.22541809, 23.87097168], [68.22624969, 23.87097168], [68.22624969, 23.87125015], [68.22680664, 23.87125015], [68.22680664, 23.87153053], [68.22736359, 23.87152863], [68.22736359, 23.87180519], [68.22846985, 23.87180519], [68.22846985, 23.87208366], [68.22930908, 23.87208176], [68.22930908, 23.87236023], [68.2298584, 23.87236023], [68.2298584, 23.87264061], [68.23042297, 23.87264061], [68.23042297, 23.8729229], [68.23097229, 23.87291718], [68.23097229, 23.87319374], [68.23152924, 23.87319374], [68.23152924, 23.87347221], [68.23236084, 23.87347031], [68.23236084, 23.87375069], [68.23319244, 23.87375069], [68.23319244, 23.87403107], [68.23374939, 23.87403107], [68.23374939, 23.87430954], [68.23458099, 23.87430573], [68.23458099, 23.87458229], [68.23542023, 23.87458038], [68.23542023, 23.8748703], [68.23596954, 23.8748703], [68.23596954, 23.87514114], [68.23652649, 23.87514114], [68.23652649, 23.87541962], [68.23708344, 23.8754158], [68.23708344, 23.87569237], [68.23764038, 23.87569237], [68.23764038, 23.87597275], [68.23847198, 23.87597084], [68.23847198, 23.87625122], [68.23902893, 23.87625122], [68.23902893, 23.87652969], [68.23958588, 23.87652969], [68.23958588, 23.87681007], [68.24013519, 23.87680435], [68.24013519, 23.87708282], [68.24069214, 23.87708282], [68.24069214, 23.8773613], [68.24124908, 23.87735939], [68.24124908, 23.87763977], [68.24180603, 23.87763977], [68.24180603, 23.87792969], [68.24208069, 23.87791443], [68.24208069, 23.87819672], [68.24263763, 23.87819672], [68.24263763, 23.87847137], [68.24291992, 23.87846947], [68.24291992, 23.87874985], [68.24318695, 23.87874985], [68.24318695, 23.87903023], [68.24346924, 23.87902832], [68.24346924, 23.87930679], [68.24375153, 23.87930679], [68.24375153, 23.87958336], [68.24402618, 23.87958336], [68.24402618, 23.87986183], [68.24458313, 23.87985992], [68.24458313, 23.8801403], [68.24485779, 23.8801403], [68.24485779, 23.88042068], [68.24819183, 23.88042068]]], [[[68.70707703, 23.85124969], [68.70707703, 23.85097122], [68.70874786, 23.85097313], [68.70874786, 23.85069656], [68.70929718, 23.85070038], [68.70929718, 23.85042], [68.7095871, 23.85042], [68.7095871, 23.85013962], [68.71013641, 23.85013962], [68.71013641, 23.84986115], [68.71069336, 23.84986115], [68.71069336, 23.84930992], [68.7104187, 23.84930992], [68.7104187, 23.84875107], [68.71013641, 23.84875107], [68.71013641, 23.84930992], [68.70874786, 23.8493042], [68.70874786, 23.84958267], [68.70819092, 23.84958267], [68.70819092, 23.8493042], [68.70735168, 23.84930992], [68.70735168, 23.84902954], [68.70540619, 23.84902954], [68.70540619, 23.84847069], [68.70513916, 23.84847069], [68.70513916, 23.84875107], [68.70485687, 23.84875107], [68.70485687, 23.84902954], [68.70458221, 23.84902763], [68.70458221, 23.84958267], [68.70375061, 23.84958076], [68.70375061, 23.84986115], [68.70318604, 23.84986115], [68.70318604, 23.85013962], [68.70291901, 23.85013962], [68.70291901, 23.85042], [68.70263672, 23.85041428], [68.70263672, 23.85097313], [68.70652771, 23.85097122], [68.70652771, 23.85124969], [68.70707703, 23.85124969]]], [[[68.69930267, 23.85320091], [68.69930267, 23.85292053], [68.70014191, 23.85292053], [68.70014191, 23.85264015], [68.70041656, 23.85264015], [68.70041656, 23.85235977], [68.70069122, 23.85236168], [68.70069122, 23.85180664], [68.70041656, 23.85180664], [68.70041656, 23.85152626], [68.69985962, 23.85153008], [68.69985962, 23.85124969], [68.69957733, 23.85124969], [68.69957733, 23.85097122], [68.69930267, 23.85097313], [68.69930267, 23.85069656], [68.69875336, 23.85070038], [68.69875336, 23.85042], [68.6984787, 23.85042], [68.6984787, 23.85013962], [68.69790649, 23.85013962], [68.69790649, 23.84986115], [68.69763947, 23.84986115], [68.69763947, 23.84958076], [68.69708252, 23.84958267], [68.69708252, 23.8493042], [68.69680786, 23.84930992], [68.69680786, 23.84902954], [68.69541168, 23.84902954], [68.69541168, 23.84930992], [68.69486237, 23.84930992], [68.69486237, 23.85042], [68.69513702, 23.85042], [68.69513702, 23.85153008], [68.69596863, 23.85152626], [68.69596863, 23.85180664], [68.69625092, 23.85180664], [68.69625092, 23.85208321], [68.69680786, 23.85208321], [68.69680786, 23.85236168], [68.69708252, 23.85235977], [68.69708252, 23.85264015], [68.69763947, 23.85264015], [68.69763947, 23.85292053], [68.69790649, 23.85292053], [68.69790649, 23.85320091], [68.69930267, 23.85320091]]], [[[68.53320312, 23.87375069], [68.5331955, 23.8726387], [68.53347015, 23.87264061], [68.53347015, 23.87236023], [68.53375244, 23.87236023], [68.53375244, 23.87208176], [68.5340271, 23.87208366], [68.5340271, 23.87180519], [68.53430176, 23.87180519], [68.53430939, 23.87013817], [68.53457642, 23.87014008], [68.53457642, 23.86569977], [68.5348587, 23.86569977], [68.5348587, 23.86486053], [68.53291321, 23.86486053], [68.53291321, 23.86403084], [68.53263855, 23.86403084], [68.53263855, 23.8631897], [68.5320816, 23.86319351], [68.5320816, 23.86291695], [68.53151703, 23.8629303], [68.53151703, 23.86264038], [68.53125, 23.86264038], [68.53125, 23.86236], [68.53069305, 23.86236191], [68.53069305, 23.86208344], [68.53013611, 23.86208344], [68.53013611, 23.86180305], [68.52958679, 23.86181068], [68.52958679, 23.8615303], [68.52902985, 23.8615303], [68.52902985, 23.86124992], [68.52874756, 23.86124992], [68.52874756, 23.86096954], [68.5284729, 23.86097145], [68.5284729, 23.86041641], [68.52819824, 23.86042023], [68.52819824, 23.86013985], [68.52791595, 23.86013985], [68.52791595, 23.85985947], [68.5276413, 23.85986137], [68.5276413, 23.8595829], [68.52735901, 23.8595829], [68.52735901, 23.85930634], [68.5256958, 23.85931015], [68.5256958, 23.85874939], [68.52540588, 23.85874939], [68.52540588, 23.85847282], [68.52402496, 23.85847282], [68.52402496, 23.8595829], [68.52430725, 23.85957146], [68.52430725, 23.86013985], [68.52458191, 23.86013985], [68.52458191, 23.86042023], [68.5248642, 23.86041641], [68.5248642, 23.86069489], [68.52513885, 23.86069107], [68.52513885, 23.86124992], [68.52540588, 23.86124992], [68.52540588, 23.8615303], [68.5256958, 23.8615303], [68.5256958, 23.86181068], [68.52597046, 23.86180305], [68.52597046, 23.86236191], [68.52625275, 23.86236], [68.52625275, 23.86264038], [68.5265274, 23.86264038], [68.5265274, 23.8629303], [68.52680206, 23.86291695], [68.52680206, 23.86347198], [68.52707672, 23.86347008], [68.52707672, 23.86375046], [68.52735901, 23.86375046], [68.52735901, 23.86403084], [68.5276413, 23.86402512], [68.5276413, 23.86458588], [68.52791595, 23.86458015], [68.52791595, 23.86514091], [68.52819061, 23.86514091], [68.52819824, 23.86569977], [68.5284729, 23.86569595], [68.5284729, 23.86597252], [68.52874756, 23.86597061], [68.52874756, 23.86680984], [68.52902985, 23.86680794], [68.52902985, 23.8670826], [68.5293045, 23.8670826], [68.5293045, 23.86819458], [68.52958679, 23.86819077], [68.52958679, 23.86902809], [68.52986145, 23.86902809], [68.52986145, 23.86958313], [68.53013611, 23.86958122], [68.53013611, 23.87014008], [68.5304184, 23.87013817], [68.5304184, 23.87097168], [68.53069305, 23.87097168], [68.53069305, 23.87125015], [68.53098297, 23.87125015], [68.53098297, 23.87153053], [68.53125, 23.87152863], [68.53125, 23.87180519], [68.53151703, 23.87179947], [68.53151703, 23.87236023], [68.53180695, 23.87236023], [68.53180695, 23.8729229], [68.5320816, 23.87291718], [68.5320816, 23.87319374], [68.53236389, 23.87319374], [68.53236389, 23.87347221], [68.53263855, 23.87347031], [68.53263855, 23.87375069], [68.53320312, 23.87375069]]], [[[68.41571045, 23.88986969], [68.41596985, 23.88986969], [68.41596985, 23.89014053], [68.41680908, 23.89014053], [68.41680908, 23.89042091], [68.41708374, 23.89041519], [68.41708374, 23.89069366], [68.41764069, 23.89069366], [68.41764069, 23.89097214], [68.41791534, 23.89097214], [68.41791534, 23.89125061], [68.41819763, 23.89125061], [68.41819763, 23.89153099], [68.41845703, 23.89153099], [68.41845703, 23.89180946], [68.41874695, 23.89180756], [68.41874695, 23.89208412], [68.41986084, 23.89208031], [68.41986084, 23.89236069], [68.42069244, 23.89236069], [68.42069244, 23.89264107], [68.42152405, 23.89263916], [68.42152405, 23.89291763], [68.42236328, 23.89291763], [68.42236328, 23.8931942], [68.42292023, 23.8931942], [68.42292023, 23.89347267], [68.42542267, 23.89347076], [68.42542267, 23.89375114], [68.42679596, 23.89375114], [68.42679596, 23.89402962], [68.42765045, 23.89402962], [68.42765045, 23.89430809], [68.42847443, 23.89430618], [68.42847443, 23.89458275], [68.42903137, 23.89458084], [68.42903137, 23.89486122], [68.42930603, 23.89486122], [68.42930603, 23.8959713], [68.42903137, 23.89596748], [68.42903137, 23.89624977], [68.42819214, 23.89624977], [68.42819214, 23.89596748], [68.42791748, 23.8959713], [68.42791748, 23.89569473], [68.42680359, 23.89569473], [68.42680359, 23.89541626], [68.42624664, 23.89541817], [68.42624664, 23.89513969], [68.42458344, 23.89513969], [68.42458344, 23.89486122], [68.42236328, 23.89486122], [68.42236328, 23.89458084], [68.42180634, 23.89458275], [68.42180634, 23.89430618], [68.4209671, 23.89430809], [68.4209671, 23.89402962], [68.42014313, 23.89402962], [68.42014313, 23.89375114], [68.41929626, 23.89375114], [68.41929626, 23.89347076], [68.41819763, 23.89347267], [68.41819763, 23.8931942], [68.41791534, 23.8931942], [68.41791534, 23.89291763], [68.41764069, 23.89291763], [68.41764069, 23.89263916], [68.4173584, 23.89264107], [68.4173584, 23.89236069], [68.41707611, 23.89236069], [68.41707611, 23.89208031], [68.41652679, 23.89208412], [68.41652679, 23.89180756], [68.41625214, 23.89180946], [68.41625214, 23.89153099], [68.41542053, 23.89153099], [68.41542053, 23.89125061], [68.41485596, 23.89125061], [68.41485596, 23.89097023], [68.4145813, 23.89097214], [68.4145813, 23.89041519], [68.41430664, 23.89042091], [68.41430664, 23.89014053], [68.41401672, 23.89014053], [68.41401672, 23.88986969], [68.41374969, 23.88986969], [68.41374969, 23.88957977], [68.41347504, 23.88958359], [68.41347504, 23.88930321], [68.41319275, 23.88931084], [68.41319275, 23.88903046], [68.41291809, 23.88903046], [68.41291809, 23.88875008], [68.4126358, 23.88875008], [68.4126358, 23.8884716], [68.41236115, 23.8884716], [68.41236115, 23.88819313], [68.41179657, 23.88820076], [68.41179657, 23.88792038], [68.41124725, 23.88792038], [68.41124725, 23.88764], [68.41069794, 23.88764], [68.41069794, 23.88735962], [68.41041565, 23.88736153], [68.41041565, 23.88708115], [68.41014099, 23.88708115], [68.41014099, 23.88680649], [68.4098587, 23.8868103], [68.4098587, 23.88652992], [68.40957642, 23.88652992], [68.40957642, 23.88624954], [68.40930939, 23.88624954], [68.4092865, 23.8856926], [68.4090271, 23.8856945], [68.4090271, 23.88541603], [68.40875244, 23.88542175], [68.40875244, 23.88513947], [68.40847015, 23.88513947], [68.40847015, 23.88402939], [68.40875244, 23.88402939], [68.40875244, 23.88347054], [68.4090271, 23.88347244], [68.4090271, 23.88319397], [68.40930176, 23.88319397], [68.40930939, 23.8829174], [68.40957642, 23.88291931], [68.40957642, 23.88264084], [68.41042328, 23.88264084], [68.41042328, 23.88236046], [68.41124725, 23.88236046], [68.41124725, 23.88207817], [68.41208649, 23.88208389], [68.41208649, 23.88180542], [68.41236115, 23.88180923], [68.41236115, 23.88153076], [68.41291809, 23.88153076], [68.41291809, 23.88125038], [68.41319275, 23.88125038], [68.41319275, 23.88096809], [68.41347504, 23.88097191], [68.41347504, 23.88069534], [68.41401672, 23.88069916], [68.41401672, 23.88042068], [68.41430664, 23.88042068], [68.41430664, 23.8801403], [68.4145813, 23.8801403], [68.4145813, 23.87985992], [68.41486359, 23.87986183], [68.41486359, 23.87958336], [68.4154129, 23.87958336], [68.4154129, 23.87930679], [68.41569519, 23.87930679], [68.41569519, 23.87902832], [68.41596985, 23.87903023], [68.41596985, 23.87874985], [68.41625214, 23.87874985], [68.41625214, 23.87846947], [68.41652679, 23.87847137], [68.41652679, 23.87819672], [68.41680908, 23.87819672], [68.41680908, 23.87763977], [68.41707611, 23.87763977], [68.41707611, 23.87735939], [68.4173584, 23.8773613], [68.4173584, 23.87708282], [68.41764069, 23.87708282], [68.41764069, 23.87680435], [68.41792297, 23.87681007], [68.41792297, 23.87625122], [68.41819763, 23.87625122], [68.41819763, 23.87514114], [68.41792297, 23.87514114], [68.41792297, 23.87430954], [68.41764069, 23.87430954], [68.41764069, 23.87375069], [68.4173584, 23.87375069], [68.4173584, 23.8729229], [68.41707611, 23.8729229], [68.41707611, 23.87236023], [68.41513824, 23.87236023], [68.41513824, 23.87264061], [68.41430664, 23.87264061], [68.41430664, 23.8729229], [68.4109726, 23.87291718], [68.4109726, 23.87319374], [68.41014099, 23.87319374], [68.41014099, 23.87347221], [68.4092865, 23.87347031], [68.4092865, 23.87375069], [68.40847015, 23.87375069], [68.40847015, 23.87403107], [68.40820313, 23.87403107], [68.40820313, 23.87430954], [68.40763855, 23.87430573], [68.40763855, 23.87458229], [68.40680695, 23.87458038], [68.40680695, 23.8748703], [68.40651703, 23.8748703], [68.40651703, 23.87514114], [68.40598297, 23.87514114], [68.40598297, 23.87541962], [68.4054184, 23.8754158], [68.4054184, 23.87569237], [68.40486145, 23.87569237], [68.40486145, 23.87597275], [68.40402985, 23.87597084], [68.40402985, 23.87625122], [68.40319824, 23.87625122], [68.40319061, 23.87652969], [68.40235901, 23.87652969], [68.40235901, 23.87681007], [68.40208435, 23.87680435], [68.40208435, 23.87708282], [68.4015274, 23.87708282], [68.4015274, 23.8773613], [68.4006958, 23.8773613], [68.40071106, 23.87763977], [68.40013885, 23.87763977], [68.40013885, 23.87792969], [68.39958191, 23.87791443], [68.39958191, 23.87819672], [68.39847565, 23.87819672], [68.39847565, 23.87847137], [68.39763641, 23.87846947], [68.39763641, 23.87874985], [68.3970871, 23.87874985], [68.3970871, 23.87903023], [68.39653015, 23.87902832], [68.39653015, 23.87930679], [68.39569092, 23.87930679], [68.39569092, 23.87958336], [68.39375305, 23.87957954], [68.39375305, 23.8801403], [68.39347076, 23.8801403], [68.39347076, 23.88042068], [68.39263916, 23.88042068], [68.39263916, 23.8801403], [68.39235687, 23.8801403], [68.39235687, 23.87957954], [68.39208221, 23.87958336], [68.39208221, 23.87902832], [68.39125061, 23.87903023], [68.39125061, 23.87874985], [68.39097595, 23.87874985], [68.39097595, 23.87846947], [68.39069366, 23.87847137], [68.39069366, 23.8773613], [68.39041901, 23.8773613], [68.39041901, 23.87708282], [68.38986206, 23.87708282], [68.38986206, 23.87680435], [68.38957977, 23.87681007], [68.38957977, 23.87652969], [68.38903046, 23.87652969], [68.38903046, 23.87625122], [68.38848114, 23.87625122], [68.38848114, 23.87597084], [68.38625336, 23.87597084], [68.38625336, 23.87625122], [68.37847137, 23.87625122], [68.37847137, 23.87652969], [68.37735748, 23.87652969], [68.37735748, 23.87625122], [68.37708282, 23.87625122], [68.37708282, 23.87597084], [68.37680817, 23.87597275], [68.37680817, 23.87569237], [68.37625122, 23.87569237], [68.37625122, 23.8754158], [68.37596893, 23.87541962], [68.37596893, 23.87514114], [68.37568665, 23.87514114], [68.37568665, 23.87458038], [68.37541962, 23.87458229], [68.37541962, 23.87402725], [68.37513733, 23.87403107], [68.37513733, 23.87347031], [68.37486267, 23.87347221], [68.37486267, 23.87291718], [68.37458038, 23.8729229], [68.37458038, 23.87236023], [68.37430573, 23.87236023], [68.37430573, 23.87180519], [68.37403107, 23.87180519], [68.37403107, 23.87097168], [68.37374878, 23.87097168], [68.37374878, 23.87013817], [68.37346649, 23.87014008], [68.37346649, 23.86958122], [68.37319183, 23.86958313], [68.37319183, 23.86874962], [68.37291718, 23.86874962], [68.37291718, 23.86597252], [68.37264252, 23.86597252], [68.37264252, 23.8615284], [68.37236023, 23.8615303], [68.37236023, 23.85957146], [68.37208557, 23.8595829], [68.37208557, 23.85930634], [68.37180328, 23.85931015], [68.37180328, 23.85902977], [68.37152863, 23.85902977], [68.37152863, 23.85874939], [68.37124634, 23.85874939], [68.37124634, 23.85847282], [68.37069702, 23.85847282], [68.37069702, 23.85819435], [68.37041473, 23.85819435], [68.37041473, 23.85791588], [68.37014008, 23.85791969], [68.37014008, 23.85763931], [68.36958313, 23.85763931], [68.36958313, 23.85736084], [68.36930847, 23.85736084], [68.36930847, 23.85707855], [68.36875153, 23.85708237], [68.36875153, 23.8568058], [68.36846924, 23.8568058], [68.36846924, 23.85652733], [68.36791992, 23.85652924], [68.36791992, 23.85625076], [68.36708069, 23.85625076], [68.36708069, 23.85597038], [68.36653137, 23.85597229], [68.36653137, 23.85569382], [68.36597443, 23.85569382], [68.36597443, 23.85541725], [68.36514282, 23.85541916], [68.36514282, 23.85514069], [68.36431122, 23.85514069], [68.36431122, 23.85486031], [68.36374664, 23.85486031], [68.36374664, 23.85457993], [68.36347198, 23.85458374], [68.36347198, 23.85430527], [68.36292267, 23.85430908], [68.36292267, 23.85403061], [68.36235809, 23.85403061], [68.36235809, 23.85375977], [68.36180878, 23.85375977], [68.36180878, 23.85346985], [68.36125183, 23.85347176], [68.36125183, 23.85319519], [68.36068726, 23.85320091], [68.36068726, 23.85292053], [68.36042023, 23.85292053], [68.36042023, 23.85264015], [68.35986328, 23.85264015], [68.35986328, 23.85235977], [68.35930634, 23.85236168], [68.35930634, 23.85208321], [68.35874939, 23.85208321], [68.35874939, 23.85180664], [68.35819244, 23.85180664], [68.35819244, 23.85152626], [68.35791779, 23.85153008], [68.35791779, 23.85124969], [68.35736084, 23.85124969], [68.35736084, 23.85097122], [68.35708618, 23.85097313], [68.35708618, 23.85069656], [68.35652924, 23.85070038], [68.35652924, 23.85013962], [68.35624695, 23.85013962], [68.35624695, 23.84986115], [68.35597229, 23.84986115], [68.35597229, 23.84958076], [68.35569763, 23.84958267], [68.35569763, 23.8493042], [68.35540771, 23.84930992], [68.35540771, 23.84902954], [68.35514069, 23.84902954], [68.35514069, 23.84847069], [68.3548584, 23.8484726], [68.3548584, 23.84791756], [68.35457611, 23.84791946], [68.35457611, 23.84762955], [68.35430908, 23.84763908], [68.35430908, 23.84736061], [68.35375214, 23.84736061], [68.35375214, 23.84680939], [68.35346985, 23.84680939], [68.35346985, 23.84625053], [68.3529129, 23.84625053], [68.3529129, 23.84597015], [68.35236359, 23.84597015], [68.35236359, 23.84569359], [68.35069275, 23.84569359], [68.35069275, 23.84597015], [68.3501358, 23.84597015], [68.3501358, 23.84625053], [68.34986115, 23.84625053], [68.34986115, 23.84736061], [68.3501358, 23.84736061], [68.3501358, 23.84819221], [68.35041809, 23.84819221], [68.35041809, 23.8484726], [68.35069275, 23.84847069], [68.35069275, 23.84875107], [68.35098267, 23.84875107], [68.35098267, 23.85042], [68.35124969, 23.85041428], [68.35124969, 23.85097313], [68.35152435, 23.85097313], [68.35152435, 23.85180664], [68.35180664, 23.85180092], [68.35180664, 23.85292053], [68.3520813, 23.85291862], [68.3520813, 23.85347176], [68.35237122, 23.85346985], [68.35237122, 23.85375977], [68.35263824, 23.85375977], [68.35263824, 23.85403061], [68.3529129, 23.85403061], [68.3529129, 23.85430908], [68.35319519, 23.85430527], [68.35319519, 23.85486031], [68.35346985, 23.85486031], [68.35346985, 23.85541916], [68.35375214, 23.85541725], [68.35375214, 23.85597229], [68.35402679, 23.85597038], [68.35402679, 23.85652924], [68.35430908, 23.85652733], [68.35430908, 23.85708427], [68.35457611, 23.85707855], [68.35457611, 23.85763931], [68.3548584, 23.85763931], [68.3548584, 23.85847282], [68.35514069, 23.85847282], [68.35514069, 23.85931015], [68.35541534, 23.85930634], [68.35541534, 23.85986137], [68.35569763, 23.85986137], [68.35569763, 23.86097145], [68.35597229, 23.86097145], [68.35597229, 23.86208344], [68.35624695, 23.86208344], [68.35624695, 23.8631897], [68.35652924, 23.86320114], [68.35652924, 23.86569977], [68.35680389, 23.86569595], [68.35680389, 23.87208366], [68.35652924, 23.87208176], [68.35652924, 23.87430954], [68.35624695, 23.87430954], [68.35624695, 23.87625122], [68.35597229, 23.87624931], [68.35597229, 23.8773613], [68.35569763, 23.8773613], [68.35569763, 23.87847137], [68.35541534, 23.87847137], [68.35541534, 23.87930679], [68.35514069, 23.87930679], [68.35514069, 23.87986183], [68.3548584, 23.87985992], [68.3548584, 23.88042068], [68.35458374, 23.88041878], [68.35458374, 23.88208389], [68.3548584, 23.88207817], [68.3548584, 23.88264084], [68.35514069, 23.88264084], [68.35514069, 23.88319397], [68.35541534, 23.88319397], [68.35541534, 23.88347244], [68.35569763, 23.88347244], [68.35569763, 23.88375092], [68.35597229, 23.88373947], [68.35597229, 23.88402939], [68.35624695, 23.88402939], [68.35624695, 23.88431168], [68.35652924, 23.88431168], [68.35652924, 23.88513947], [68.35624695, 23.88513947], [68.35624695, 23.88597107], [68.35597229, 23.88597107], [68.35597229, 23.88708115], [68.35569763, 23.88708115], [68.35569763, 23.88736153], [68.35540771, 23.88735962], [68.35540771, 23.88764], [68.35514069, 23.88764], [68.35514069, 23.88792038], [68.35541534, 23.88791656], [68.35541534, 23.8884716], [68.35569763, 23.8884697], [68.35569763, 23.88931084], [68.35597229, 23.88931084], [68.35597229, 23.89014053], [68.35624695, 23.89013863], [68.35624695, 23.89069366], [68.35652924, 23.89069366], [68.35652924, 23.89097214], [68.35679626, 23.89097023], [68.35679626, 23.89153099], [68.35708618, 23.89153099], [68.35708618, 23.89180946], [68.35736084, 23.89180756], [68.35736084, 23.89208412], [68.35764313, 23.89208031], [68.35764313, 23.89264107], [68.35791779, 23.89263916], [68.35791779, 23.89291763], [68.35847473, 23.89291763], [68.35847473, 23.8931942], [68.35986328, 23.8931942], [68.35986328, 23.89291763], [68.36096954, 23.89291763], [68.36096954, 23.89263916], [68.36180878, 23.89264107], [68.36180878, 23.89236069], [68.36486053, 23.89236069], [68.36486053, 23.89208031], [68.36541748, 23.89208412], [68.36541748, 23.89180756], [68.36569214, 23.89180946], [68.36569214, 23.89153099], [68.36624908, 23.89153099], [68.36624908, 23.89125061], [68.36653137, 23.89125061], [68.36653137, 23.89097023], [68.36680603, 23.89097214], [68.36680603, 23.89069366], [68.36708069, 23.89069366], [68.36708069, 23.89041519], [68.36736298, 23.89041519], [68.36736298, 23.89069366], [68.36763763, 23.89069366], [68.36763763, 23.89097214], [68.36734772, 23.89097023], [68.36734772, 23.89153099], [68.36708069, 23.89153099], [68.36708069, 23.89180946], [68.36680603, 23.89180756], [68.36680603, 23.89208412], [68.36624908, 23.89208031], [68.36624908, 23.89236069], [68.36734772, 23.89236069], [68.36734772, 23.89264107], [68.36763763, 23.89263916], [68.36763763, 23.89291763], [68.36736298, 23.89291763], [68.36736298, 23.8931942], [68.36624908, 23.8931942], [68.36624908, 23.89291763], [68.36597443, 23.89291763], [68.36597443, 23.8931942], [68.36180878, 23.8931942], [68.36180878, 23.89347267], [68.36096954, 23.89347076], [68.36096954, 23.89375114], [68.35986328, 23.89375114], [68.35986328, 23.89402962], [68.3584671, 23.89402962], [68.3584671, 23.89375114], [68.35791779, 23.89375114], [68.35791779, 23.89347076], [68.35736084, 23.89347267], [68.35736084, 23.8931942], [68.35708618, 23.8931942], [68.35708618, 23.89263916], [68.35679626, 23.89264107], [68.35679626, 23.89236069], [68.35652924, 23.89236069], [68.35652924, 23.89208031], [68.35624695, 23.89208412], [68.35624695, 23.89152527], [68.35597229, 23.89153099], [68.35597229, 23.89097023], [68.35569763, 23.89097214], [68.35569763, 23.89069366], [68.35541534, 23.89069366], [68.35541534, 23.89013863], [68.35514069, 23.89014053], [68.35514069, 23.88957977], [68.3548584, 23.88958359], [68.3548584, 23.8884716], [68.35458374, 23.8884716], [68.35458374, 23.88819313], [68.35430908, 23.88820076], [68.35430908, 23.88764], [68.35457611, 23.88764], [68.35457611, 23.88735962], [68.3548584, 23.88736153], [68.3548584, 23.88680649], [68.35514069, 23.8868103], [68.35514069, 23.88597107], [68.35541534, 23.88597107], [68.35541534, 23.8848629], [68.35569763, 23.8848629], [68.35569763, 23.88458061], [68.35514069, 23.88458252], [68.35514069, 23.88430595], [68.35430908, 23.88431168], [68.35430908, 23.88402939], [68.35402679, 23.88402939], [68.35402679, 23.88373947], [68.35320282, 23.88373947], [68.35320282, 23.88431168], [68.3529129, 23.88431168], [68.3529129, 23.88542175], [68.35263824, 23.88542175], [68.35263824, 23.88652992], [68.35237122, 23.88652992], [68.35237122, 23.88764], [68.3520813, 23.88764], [68.3520813, 23.88820076], [68.35180664, 23.88820076], [68.35180664, 23.88875008], [68.35151672, 23.88875008], [68.35151672, 23.88931084], [68.35124969, 23.88931084], [68.35124969, 23.88986969], [68.35098267, 23.88986969], [68.35098267, 23.89042091], [68.35069275, 23.89042091], [68.35069275, 23.89125061], [68.35041809, 23.89125061], [68.35041809, 23.89624977], [68.35069275, 23.89624977], [68.35069275, 23.89652824], [68.35097504, 23.89652824], [68.35097504, 23.89708328], [68.35124969, 23.89708328], [68.35124969, 23.89736176], [68.35151672, 23.89736176], [68.35151672, 23.89764023], [68.35180664, 23.89764023], [68.35180664, 23.8982029], [68.3520813, 23.8982029], [68.3520813, 23.89875031], [68.35237122, 23.89875031], [68.35237122, 23.89931107], [68.35263824, 23.89931107], [68.35263824, 23.89986038], [68.3529129, 23.89986038], [68.3529129, 23.90069389], [68.35375214, 23.90069389], [68.35375214, 23.90097237], [68.35402679, 23.90097046], [68.35402679, 23.90125084], [68.35430908, 23.90125084], [68.35430908, 23.90153122], [68.35457611, 23.90153122], [68.35457611, 23.90180969], [68.35514069, 23.90180588], [68.35514069, 23.90208244], [68.35540771, 23.90208054], [68.35540771, 23.90236092], [68.35569763, 23.90236092], [68.35569763, 23.90263939], [68.35597229, 23.90263939], [68.35597229, 23.90291977], [68.35652924, 23.90291405], [68.35652924, 23.90319443], [68.35708618, 23.90319443], [68.35708618, 23.90347481], [68.35791779, 23.90347099], [68.35791779, 23.90374947], [68.3584671, 23.90374947], [68.3584671, 23.90402985], [68.35901642, 23.90402985], [68.35901642, 23.90431023], [68.35986328, 23.9043045], [68.35986328, 23.90458298], [68.36069489, 23.90458298], [68.36069489, 23.90486145], [68.36152649, 23.90485001], [68.36152649, 23.90513992], [68.36235809, 23.90513992], [68.36235809, 23.9054203], [68.36292267, 23.9054203], [68.36292267, 23.90570068], [68.36374664, 23.90569687], [68.36374664, 23.90597153], [68.3659668, 23.90596962], [68.3659668, 23.90625], [68.36791992, 23.90625], [68.36791992, 23.90653038], [68.36958313, 23.90653038], [68.36958313, 23.90625], [68.3704071, 23.90625], [68.3704071, 23.90653038], [68.37124634, 23.90653038], [68.37124634, 23.90681076], [68.37291718, 23.90681076], [68.37291718, 23.90653038], [68.37596893, 23.90653038], [68.37596893, 23.90625], [68.37847137, 23.90625], [68.37847137, 23.90596962], [68.38180542, 23.90597153], [68.38180542, 23.90625], [68.38625336, 23.90625], [68.38625336, 23.90653038], [68.38735962, 23.90653038], [68.38735962, 23.90681076], [68.38874817, 23.90680695], [68.38874817, 23.90708351], [68.38986206, 23.90708351], [68.38986206, 23.90736198], [68.39068604, 23.90735817], [68.39068604, 23.90764046], [68.39152527, 23.90763855], [68.39152527, 23.90791893], [68.3923645, 23.90791893], [68.3923645, 23.90819359], [68.39319611, 23.90819359], [68.39319611, 23.90847206], [68.39347076, 23.90846825], [68.39347076, 23.90875053], [68.39402771, 23.90875053], [68.39402771, 23.90903091], [68.39428711, 23.90903091], [68.39428711, 23.90930939], [68.39458466, 23.90930557], [68.39458466, 23.90958405], [68.39485931, 23.90957832], [68.39485931, 23.90986061], [68.39653015, 23.90986061], [68.39653015, 23.91013908], [68.3973465, 23.91013908], [68.3973465, 23.91041946], [68.3979187, 23.91041756], [68.3979187, 23.91069412], [68.39930725, 23.9106884], [68.39930725, 23.91098022], [68.39985657, 23.91098022], [68.39985657, 23.91124916], [68.40042114, 23.91124916], [68.40042114, 23.91152954], [68.40125275, 23.91152954], [68.40125275, 23.91181183], [68.40180206, 23.91180611], [68.40180206, 23.91208267], [68.4026413, 23.91208267], [68.4026413, 23.91236115], [68.40513611, 23.91236115], [68.40513611, 23.91263962], [68.4054184, 23.91263962], [68.4054184, 23.91292191], [68.40597534, 23.91291618], [68.40597534, 23.91319466], [68.40625, 23.91319466], [68.40625, 23.91347122], [68.40680695, 23.91347122], [68.40680695, 23.91374969], [68.4070816, 23.91374969], [68.4070816, 23.91403961], [68.40763855, 23.91402817], [68.40763855, 23.91430473], [68.4081955, 23.91430473], [68.4081955, 23.91458321], [68.4090271, 23.91458321], [68.4090271, 23.91486168], [68.40957642, 23.91485977], [68.40957642, 23.91514015], [68.41014099, 23.91514015], [68.41014099, 23.91542053], [68.41069794, 23.91542053], [68.41069794, 23.91570091], [68.41124725, 23.91569328], [68.41124725, 23.91597176], [68.41152954, 23.91596985], [68.41152954, 23.91625023], [68.4126358, 23.91625023], [68.4126358, 23.91708565], [68.41319275, 23.91707993], [68.41319275, 23.91736031], [68.41485596, 23.91736031], [68.41485596, 23.91764069], [68.41542053, 23.91764069], [68.41542053, 23.91792107], [68.41569519, 23.91791534], [68.41569519, 23.91819382], [68.41596985, 23.91819382], [68.41596985, 23.91847229], [68.41625214, 23.91847038], [68.41625214, 23.91875076], [68.41680908, 23.91875076], [68.41680908, 23.91903114], [68.41707611, 23.91903114], [68.41707611, 23.91930962], [68.41764069, 23.91930771], [68.41764069, 23.91958427], [68.41791534, 23.91958427], [68.41791534, 23.91986084], [68.41845703, 23.9198494], [68.41845703, 23.92014122], [68.41874695, 23.92014122], [68.41874695, 23.92041969], [68.41930389, 23.92041779], [68.41930389, 23.92069435], [68.41958618, 23.92069435], [68.41958618, 23.92097282], [68.4201355, 23.92097282], [68.4201355, 23.92124939], [68.42041779, 23.92124939], [68.42041779, 23.92152977], [68.42069244, 23.92152977], [68.42069244, 23.92180824], [68.42097473, 23.92180634], [68.42097473, 23.9220829], [68.42124939, 23.92207909], [68.42124939, 23.92263985], [68.42152405, 23.92263985], [68.42152405, 23.92319489], [68.42180634, 23.92318916], [68.42180634, 23.92375183], [68.42208099, 23.92375183], [68.42208099, 23.92431259], [68.42236328, 23.92430496], [68.42236328, 23.92486191], [68.42263794, 23.92486191], [68.42263794, 23.92514038], [68.42292023, 23.92513847], [68.42292023, 23.9256916], [68.42318726, 23.92570114], [68.42318726, 23.92597961], [68.42346954, 23.92597961], [68.42346954, 23.92653275], [68.42375183, 23.92653275], [68.42375183, 23.92681122], [68.42402649, 23.92681122], [68.42402649, 23.92736053], [68.42430878, 23.92736053], [68.42430878, 23.92764091], [68.42458344, 23.92763901], [68.42458344, 23.92819214], [68.42485809, 23.92819214], [68.42485809, 23.92847252], [68.42514038, 23.92847061], [68.42514038, 23.92904091], [68.42542267, 23.92904091], [68.42542267, 23.92930984], [68.42569733, 23.92930984], [68.42569733, 23.92986107], [68.42597198, 23.92986107], [68.42597198, 23.93041992], [68.42624664, 23.9304142], [68.42624664, 23.93097305], [68.42680359, 23.93097305], [68.42680359, 23.93180466], [68.42708588, 23.9317894], [68.42708588, 23.93292046], [68.42736053, 23.93291855], [68.42736053, 23.93347168], [68.42791748, 23.93346977], [68.42791748, 23.93375015], [68.4284668, 23.93375015], [68.4284668, 23.93403053], [68.42930603, 23.93403053], [68.42930603, 23.93431091], [68.42986298, 23.93430519], [68.42986298, 23.93458366], [68.43152618, 23.93457985], [68.43152618, 23.93486023], [68.43264008, 23.93486023], [68.43264008, 23.93514061], [68.43345642, 23.93514061], [68.43345642, 23.93541908], [68.43458557, 23.93541718], [68.43458557, 23.93569374], [68.43624878, 23.93569374], [68.43624878, 23.93597221], [68.43680573, 23.93597221], [68.43680573, 23.93569374], [68.43819427, 23.93569374], [68.43819427, 23.93541718], [68.43875122, 23.93541908], [68.43875122, 23.93514061], [68.43959045, 23.93514061], [68.43959045, 23.93486023], [68.43985748, 23.93486023], [68.43985748, 23.93457985], [68.44097137, 23.93457985], [68.44097137, 23.93486023], [68.44180298, 23.93486023], [68.44180298, 23.93514061], [68.44235992, 23.93514061], [68.44235992, 23.93541908], [68.44319153, 23.93541718], [68.44319153, 23.93569374], [68.44374847, 23.93569374], [68.44374847, 23.93597221], [68.44458008, 23.9359684], [68.44458008, 23.93625069], [68.44513702, 23.93625069], [68.44513702, 23.93652916], [68.44568634, 23.93652916], [68.44568634, 23.93680954], [68.44596863, 23.93680573], [68.44596863, 23.9370842], [68.44625092, 23.93707848], [68.44625092, 23.93736076], [68.4465332, 23.93736076], [68.4465332, 23.93763924], [68.44680786, 23.93763924], [68.44680786, 23.93791962], [68.44708252, 23.9379158], [68.44708252, 23.93819427], [68.44736481, 23.93819427], [68.44736481, 23.93847275], [68.44930267, 23.93847275], [68.44930267, 23.93819427], [68.45069122, 23.93819427], [68.45069122, 23.9379158], [68.45096588, 23.93791962], [68.45096588, 23.93763924], [68.45153046, 23.93763924], [68.45153046, 23.93736076], [68.45182037, 23.93736076], [68.45180511, 23.9370842], [68.45236206, 23.9370842], [68.45236206, 23.93680573], [68.45291901, 23.93680954], [68.45291901, 23.93652916], [68.45318604, 23.93652916], [68.45318604, 23.93625069], [68.45347595, 23.93625069], [68.45347595, 23.9359684], [68.45375061, 23.93597221], [68.45375061, 23.93569374], [68.45430756, 23.93569374], [68.45430756, 23.93541718], [68.45456696, 23.93541908], [68.45456696, 23.93514061], [68.45485687, 23.93514061], [68.45485687, 23.93486023], [68.45513916, 23.93486023], [68.45513916, 23.93457985], [68.45569611, 23.93458366], [68.45569611, 23.93430519], [68.45597076, 23.93431091], [68.45597076, 23.93346977], [68.45652771, 23.93347168], [68.45652771, 23.93291855], [68.45680237, 23.93292046], [68.45680237, 23.9323597], [68.45708466, 23.9323616], [68.45708466, 23.93180466], [68.45735931, 23.93180466], [68.45735931, 23.93152618], [68.45819092, 23.93153], [68.45819092, 23.93124962], [68.45874786, 23.93124962], [68.45874786, 23.93069077], [68.45847321, 23.93069649], [68.45847321, 23.9304142], [68.45735931, 23.93041992], [68.45735931, 23.93013954], [68.45625305, 23.93013954], [68.45625305, 23.92986107], [68.45569611, 23.92986107], [68.45569611, 23.92958069], [68.4548645, 23.9295826], [68.4548645, 23.92930412], [68.45456696, 23.92930984], [68.45456696, 23.92875099], [68.45430756, 23.92875099], [68.45430756, 23.92791939], [68.4540329, 23.92791939], [68.4540329, 23.92681122], [68.45375061, 23.92681122], [68.45375061, 23.9256916], [68.45347595, 23.92569351], [68.45347595, 23.92458344], [68.45319366, 23.92458344], [68.45319366, 23.9240284], [68.45291901, 23.9240303], [68.45291901, 23.92318916], [68.45263672, 23.92319489], [68.45263672, 23.92291641], [68.45236206, 23.92291832], [68.45236206, 23.92263985], [68.45207977, 23.92263985], [68.45207977, 23.92235756], [68.45180511, 23.92236137], [68.45180511, 23.9220829], [68.45153046, 23.9220829], [68.45153046, 23.92180634], [68.45124817, 23.92180824], [68.45124817, 23.92152977], [68.45096588, 23.92152977], [68.45096588, 23.92124939], [68.45041656, 23.92124939], [68.45041656, 23.92097092], [68.44958496, 23.92097282], [68.44958496, 23.92069435], [68.44930267, 23.92069435], [68.44930267, 23.92041779], [68.44819641, 23.92041969], [68.44819641, 23.92014122], [68.44763947, 23.92014122], [68.44763947, 23.9198494], [68.44458008, 23.91986084], [68.44458008, 23.91958427], [68.44430542, 23.91958237], [68.44430542, 23.91930771], [68.44403076, 23.91930962], [68.44403076, 23.91903114], [68.44431305, 23.91903114], [68.44431305, 23.91875076], [68.44458008, 23.91875076], [68.44458008, 23.91819], [68.44486237, 23.91819382], [68.44486237, 23.91791534], [68.44458008, 23.91792107], [68.44458008, 23.91736031], [68.44513702, 23.91736031], [68.44513702, 23.91764069], [68.44541931, 23.91764069], [68.44541931, 23.91792107], [68.44596863, 23.91791534], [68.44596863, 23.91819382], [68.44652557, 23.91819382], [68.44652557, 23.91847229], [68.44708252, 23.91847038], [68.44708252, 23.91875076], [68.44735718, 23.91875076], [68.44735718, 23.91903114], [68.44790649, 23.91903114], [68.44790649, 23.91930962], [68.44875336, 23.91930771], [68.44875336, 23.91958427], [68.44902802, 23.91958427], [68.44902802, 23.91930771], [68.44930267, 23.91930962], [68.44930267, 23.91875076], [68.44957733, 23.91875076], [68.44957733, 23.91847038], [68.44985962, 23.91847229], [68.44985962, 23.91819382], [68.45014191, 23.91819382], [68.45014191, 23.91763878], [68.45041656, 23.91764069], [68.45041656, 23.91736031], [68.45096588, 23.91736031], [68.45096588, 23.91707993], [68.45124817, 23.91708565], [68.45124817, 23.9165287], [68.45153046, 23.91653061], [68.45153046, 23.91596985], [68.45180511, 23.91597176], [68.45180511, 23.91486168], [68.45153046, 23.91486168], [68.45153046, 23.91430473], [68.45097351, 23.91430473], [68.45097351, 23.91458321], [68.45069122, 23.91458321], [68.45069122, 23.91486168], [68.45041656, 23.91485977], [68.45041656, 23.91542053], [68.44930267, 23.91542053], [68.44930267, 23.91514015], [68.44819641, 23.91514015], [68.44819641, 23.91457939], [68.44763947, 23.91458321], [68.44763947, 23.91486168], [68.44735718, 23.91485977], [68.44735718, 23.91542053], [68.44708252, 23.91542053], [68.44708252, 23.91570091], [68.44625092, 23.91570091], [68.44625092, 23.91542053], [68.44596863, 23.91542053], [68.44596863, 23.91457939], [68.44625092, 23.91458321], [68.44625092, 23.91402817], [68.44568634, 23.91403961], [68.44568634, 23.91374969], [68.44541931, 23.91374969], [68.44541931, 23.91347122], [68.44486237, 23.91347122], [68.44486237, 23.91319466], [68.44430542, 23.91319466], [68.44430542, 23.91263962], [68.44486237, 23.91263962], [68.44486237, 23.91292191], [68.44596863, 23.91291618], [68.44596863, 23.91319466], [68.44680786, 23.91319466], [68.44680786, 23.91347122], [68.44930267, 23.91347122], [68.44930267, 23.91374969], [68.45124817, 23.91374969], [68.45124817, 23.91347122], [68.45153046, 23.91347122], [68.45153046, 23.91291618], [68.45182037, 23.91292191], [68.45182037, 23.91124916], [68.45153046, 23.91124916], [68.45153046, 23.90903091], [68.45124817, 23.90903091], [68.45124817, 23.90790939], [68.45097351, 23.90791893], [68.45097351, 23.90680695], [68.45069122, 23.90681076], [68.45069122, 23.90570068], [68.45041656, 23.90570068], [68.45041656, 23.9054203], [68.44957733, 23.9054203], [68.44957733, 23.90570068], [68.44708252, 23.90570068], [68.44708252, 23.90625], [68.44680786, 23.90625], [68.44680786, 23.90653038], [68.4465332, 23.90653038], [68.4465332, 23.90681076], [68.44596863, 23.90681076], [68.44596863, 23.90764046], [68.44569397, 23.90763855], [68.44569397, 23.90791893], [68.44541931, 23.90791893], [68.44541931, 23.90763855], [68.44513702, 23.90764046], [68.44513702, 23.9070797], [68.44486237, 23.90708351], [68.44486237, 23.90736198], [68.44458008, 23.90735817], [68.44458008, 23.90764046], [68.44430542, 23.90763855], [68.44430542, 23.90791893], [68.44458008, 23.90791893], [68.44458008, 23.90819359], [68.44486237, 23.90818977], [68.44486237, 23.90875053], [68.44458008, 23.90875053], [68.44458008, 23.90903091], [68.44431305, 23.90903091], [68.44431305, 23.90930939], [68.44319153, 23.90930939], [68.44319153, 23.90903091], [68.44291687, 23.90903091], [68.44291687, 23.90818977], [68.44319153, 23.90819359], [68.44319153, 23.90791893], [68.44347382, 23.90791893], [68.44347382, 23.90763855], [68.44374847, 23.90764046], [68.44374847, 23.9070797], [68.44403076, 23.90708351], [68.44403076, 23.90680695], [68.44431305, 23.90681076], [68.44431305, 23.90596962], [68.44458008, 23.90597153], [68.44458008, 23.90569687], [68.44513702, 23.90570068], [68.44513702, 23.9054203], [68.44596863, 23.9054203], [68.44596863, 23.90513992], [68.44680786, 23.90513992], [68.44680786, 23.90485001], [68.44958496, 23.90486145], [68.44958496, 23.90458298], [68.45041656, 23.90458298], [68.45041656, 23.90374947], [68.45069122, 23.90374947], [68.45069122, 23.90208054], [68.45097351, 23.90208244], [68.45097351, 23.90013885], [68.44902802, 23.90014076], [68.44902802, 23.89903259], [68.44876099, 23.89903259], [68.44876099, 23.89847183], [68.44847107, 23.89847183], [68.44847107, 23.89819527], [68.44819641, 23.89819527], [68.44819641, 23.89847183], [68.44790649, 23.89847183], [68.44790649, 23.89875031], [68.44763947, 23.89875031], [68.44763947, 23.89903259], [68.44680786, 23.89903259], [68.44680786, 23.89875031], [68.44708252, 23.89875031], [68.44708252, 23.8982029], [68.44735718, 23.8982029], [68.44735718, 23.89792252], [68.44763947, 23.89792252], [68.44763947, 23.89764023], [68.44819641, 23.89764023], [68.44819641, 23.89708138], [68.44847107, 23.89708328], [68.44847107, 23.89291763], [68.44875336, 23.89291763], [68.44875336, 23.89208412], [68.44902802, 23.89208412], [68.44902802, 23.89180756], [68.44876099, 23.89180946], [68.44876099, 23.89153099], [68.44902802, 23.89153099], [68.44902802, 23.89125061], [68.44930267, 23.89125061], [68.44930267, 23.89042091], [68.44957733, 23.89042091], [68.44957733, 23.88986969], [68.44985962, 23.88986969], [68.44985962, 23.88792038], [68.45014191, 23.88792038], [68.45014191, 23.88735962], [68.45041656, 23.88736153], [68.45041656, 23.88680649], [68.45069122, 23.8868103], [68.45069122, 23.88624954], [68.45096588, 23.88624954], [68.45096588, 23.88513947], [68.45124817, 23.88513947], [68.45124817, 23.88431168], [68.45153046, 23.88431168], [68.45153046, 23.88373947], [68.45180511, 23.88375092], [68.45180511, 23.8829174], [68.45207977, 23.88291931], [68.45207977, 23.88180923], [68.45182037, 23.88180923], [68.45182037, 23.88153076], [68.45153046, 23.88153076], [68.45153046, 23.88125038], [68.45096588, 23.88125038], [68.45096588, 23.88096809], [68.45014191, 23.88097191], [68.45014191, 23.88069534], [68.44985962, 23.88069916], [68.44985962, 23.88042068], [68.44957733, 23.88042068], [68.44957733, 23.8801403], [68.44930267, 23.8801403], [68.44930267, 23.87985992], [68.44902802, 23.87986183], [68.44902802, 23.87958336], [68.44736481, 23.87958336], [68.44736481, 23.87930679], [68.44625092, 23.87930679], [68.44625092, 23.87902832], [68.44568634, 23.87903023], [68.44568634, 23.87874985], [68.44541931, 23.87874985], [68.44541931, 23.87846947], [68.44486237, 23.87847137], [68.44486237, 23.87819672], [68.44430542, 23.87819672], [68.44430542, 23.87847137], [68.44374847, 23.87847137], [68.44374847, 23.87791443], [68.44346619, 23.87792969], [68.44346619, 23.87763977], [68.44374847, 23.87763977], [68.44374847, 23.87681007], [68.44346619, 23.87681007], [68.44346619, 23.87652969], [68.44319153, 23.87652969], [68.44319153, 23.87569046], [68.44291687, 23.87569237], [68.44291687, 23.87513924], [68.44262695, 23.87514114], [68.44262695, 23.8748703], [68.4420929, 23.8748703], [68.4420929, 23.87430954], [68.44235992, 23.87430954], [68.44235992, 23.87403107], [68.4420929, 23.87403107], [68.4420929, 23.87125015], [68.44235992, 23.87125015], [68.44235992, 23.87070274], [68.4420929, 23.87070274], [68.4420929, 23.87042236], [68.44124603, 23.87042236], [68.44124603, 23.87014008], [68.44069672, 23.87014008], [68.44069672, 23.8698597], [68.44013977, 23.8698616], [68.44013977, 23.86958313], [68.43930817, 23.86958313], [68.43930817, 23.86930466], [68.43875122, 23.86930466], [68.43875122, 23.86902809], [68.43791962, 23.86902809], [68.43791962, 23.86874008], [68.43736267, 23.86874962], [68.43736267, 23.86847305], [68.43653107, 23.86847305], [68.43653107, 23.86819458], [68.43597412, 23.86819458], [68.43597412, 23.86791611], [68.43514252, 23.86791992], [68.43514252, 23.86763954], [68.43430328, 23.86763954], [68.43430328, 23.86736107], [68.43374634, 23.86736107], [68.43374634, 23.86708069], [68.43291473, 23.8670826], [68.43291473, 23.86680794], [68.43152618, 23.86680984], [68.43152618, 23.86652946], [68.43013763, 23.86652946], [68.43013763, 23.86625099], [68.42903137, 23.86625099], [68.42903137, 23.86597061], [68.42874908, 23.86597252], [68.42874908, 23.86569595], [68.42819214, 23.86569977], [68.42819214, 23.86541939], [68.42791748, 23.86541939], [68.42791748, 23.86514091], [68.42736053, 23.86514091], [68.42736053, 23.86486053], [68.42708588, 23.86486053], [68.42708588, 23.86458015], [68.42597198, 23.86458015], [68.42597198, 23.86486053], [68.42569733, 23.86486053], [68.42569733, 23.86514091], [68.42597198, 23.86514091], [68.42597198, 23.86541939], [68.42569733, 23.86541748], [68.42569733, 23.86597252], [68.42542267, 23.86597061], [68.42542267, 23.86625099], [68.42514038, 23.86625099], [68.42514038, 23.86680984], [68.42485809, 23.86680794], [68.42485809, 23.8670826], [68.42458344, 23.8670826], [68.42459106, 23.86736107], [68.42430878, 23.86736107], [68.42430878, 23.86763954], [68.42402649, 23.86763954], [68.42402649, 23.86791992], [68.42375183, 23.86791611], [68.42375183, 23.86819458], [68.42346954, 23.86819458], [68.42346954, 23.86847305], [68.42319489, 23.86847305], [68.42319489, 23.86874962], [68.42292023, 23.86874008], [68.42292023, 23.86902809], [68.42236328, 23.86902809], [68.42236328, 23.86930466], [68.42208099, 23.86930466], [68.42208099, 23.86958313], [68.42152405, 23.86958313], [68.42152405, 23.8698616], [68.42124939, 23.8698597], [68.42124939, 23.87014008], [68.42069244, 23.87014008], [68.42069244, 23.87042236], [68.42014313, 23.87042236], [68.42014313, 23.87070274], [68.41986084, 23.87069511], [68.41986084, 23.87097168], [68.41958618, 23.87097168], [68.41958618, 23.87208366], [68.41929626, 23.87208176], [68.41929626, 23.87236023], [68.41958618, 23.87236023], [68.41958618, 23.87264061], [68.41986084, 23.87264061], [68.41986084, 23.8729229], [68.4201355, 23.87291718], [68.4201355, 23.87347221], [68.42041779, 23.87347221], [68.42041779, 23.87458229], [68.42069244, 23.87458229], [68.42069244, 23.87708282], [68.42041779, 23.87708282], [68.42041779, 23.8773613], [68.4201355, 23.8773613], [68.42014313, 23.87763977], [68.41986084, 23.87763977], [68.41986084, 23.87792969], [68.41958618, 23.87791443], [68.41958618, 23.87819672], [68.41930389, 23.87819672], [68.41930389, 23.87847137], [68.41902924, 23.87846947], [68.41902924, 23.87874985], [68.41874695, 23.87874985], [68.41874695, 23.87903023], [68.41847229, 23.87902832], [68.41847229, 23.87930679], [68.41819763, 23.87930679], [68.41819763, 23.87958336], [68.41791534, 23.87958336], [68.41791534, 23.87986183], [68.41764069, 23.87985992], [68.41764069, 23.8801403], [68.4173584, 23.8801403], [68.4173584, 23.88042068], [68.41707611, 23.88042068], [68.41707611, 23.88069916], [68.41680908, 23.88069534], [68.41680908, 23.88097191], [68.41652679, 23.88096809], [68.41652679, 23.88125038], [68.41571045, 23.88125038], [68.41571045, 23.88153076], [68.41513824, 23.88153076], [68.41513824, 23.88180923], [68.41430664, 23.88180542], [68.41430664, 23.88208389], [68.41374969, 23.88207817], [68.41374969, 23.88236046], [68.41348267, 23.88236046], [68.41348267, 23.88264084], [68.41319275, 23.88264084], [68.41319275, 23.88291931], [68.41291809, 23.8829174], [68.41291809, 23.88319397], [68.4126358, 23.88319397], [68.4126358, 23.88347244], [68.41236115, 23.88347244], [68.41236115, 23.88375092], [68.41208649, 23.88373947], [68.41208649, 23.88402939], [68.41179657, 23.88402939], [68.41179657, 23.88431168], [68.41124725, 23.88430595], [68.41124725, 23.88458252], [68.4109726, 23.88458061], [68.4109726, 23.8848629], [68.41069794, 23.8848629], [68.41069794, 23.88542175], [68.4109726, 23.88541603], [68.4109726, 23.88597107], [68.41124725, 23.88597107], [68.41124725, 23.88624954], [68.41179657, 23.88624954], [68.41179657, 23.88652992], [68.41236115, 23.88652992], [68.41236115, 23.8868103], [68.41291809, 23.88680649], [68.41291809, 23.88708115], [68.41347504, 23.88708115], [68.41347504, 23.88736153], [68.41374969, 23.88735962], [68.41374969, 23.88764], [68.41401672, 23.88764], [68.41401672, 23.88820076], [68.41430664, 23.88819313], [68.41430664, 23.8884716], [68.41485596, 23.8884697], [68.41485596, 23.88875008], [68.41513824, 23.88875008], [68.41513824, 23.88903046], [68.4154129, 23.88902855], [68.4154129, 23.88958359], [68.41571045, 23.88957977], [68.41571045, 23.88986969]]], [[[68.5220871, 23.85625076], [68.52097321, 23.85625076], [68.52097321, 23.85652924], [68.52069092, 23.85652733], [68.52069092, 23.8568058], [68.51763916, 23.8568058], [68.51763916, 23.85652733], [68.51708221, 23.85652733], [68.51708221, 23.8568058], [68.51625061, 23.8568058], [68.51625061, 23.85708237], [68.51513672, 23.85707855], [68.51513672, 23.85736084], [68.51457977, 23.85736084], [68.51457977, 23.85763931], [68.51431274, 23.85763931], [68.51431274, 23.85791969], [68.51403046, 23.85791588], [68.51403046, 23.85819435], [68.51374817, 23.85819435], [68.51374817, 23.85847282], [68.51346588, 23.85847282], [68.51346588, 23.85931015], [68.51374817, 23.85931015], [68.51374817, 23.85902977], [68.51403046, 23.85902977], [68.51403046, 23.85931015], [68.51430511, 23.85930634], [68.51430511, 23.8595829], [68.51403046, 23.8595829], [68.51403046, 23.85986137], [68.51374817, 23.85985947], [68.51374817, 23.86013985], [68.51346588, 23.86013985], [68.51346588, 23.86042023], [68.51319122, 23.86041641], [68.51319122, 23.86069489], [68.51291656, 23.86069489], [68.51291656, 23.86097145], [68.51264191, 23.86096954], [68.51264191, 23.86124992], [68.51235962, 23.86124992], [68.51235962, 23.8615303], [68.51207733, 23.8615303], [68.51207733, 23.86181068], [68.51125336, 23.86180305], [68.51125336, 23.86208344], [68.51069641, 23.86208344], [68.51069641, 23.86236191], [68.51040649, 23.86236], [68.51040649, 23.86264038], [68.51013947, 23.86263847], [68.51013947, 23.86319351], [68.50986481, 23.86319351], [68.50986481, 23.86347198], [68.50930786, 23.86347198], [68.50930786, 23.86319351], [68.50902557, 23.86319351], [68.50902557, 23.86347198], [68.50874329, 23.86347008], [68.50874329, 23.86375046], [68.50818634, 23.86375046], [68.50818634, 23.86403084], [68.50763702, 23.86403084], [68.50763702, 23.86431122], [68.50569153, 23.8643074], [68.50569153, 23.86458588], [68.50541687, 23.86458015], [68.50541687, 23.86486053], [68.50485992, 23.86486053], [68.50485992, 23.86514091], [68.5045929, 23.86514091], [68.5045929, 23.86541939], [68.50402832, 23.86541939], [68.50402832, 23.86569977], [68.50319672, 23.86569595], [68.50319672, 23.86597252], [68.50263977, 23.86597061], [68.50263977, 23.86625099], [68.50125122, 23.86625099], [68.50125122, 23.86652946], [68.50041962, 23.86652946], [68.50041962, 23.86763954], [68.50013733, 23.86763954], [68.50013733, 23.86847305], [68.50041962, 23.86847115], [68.50041962, 23.87264061], [68.50069427, 23.8726387], [68.50069427, 23.87319374], [68.50096893, 23.87319374], [68.50096893, 23.87347221], [68.50125122, 23.87347031], [68.50125122, 23.87375069], [68.50180817, 23.87375069], [68.50180817, 23.87403107], [68.50208282, 23.87403107], [68.50208282, 23.87430954], [68.50235748, 23.87430954], [68.50235748, 23.87514114], [68.50208282, 23.87514114], [68.50208282, 23.87541962], [68.50125122, 23.87541962], [68.50125122, 23.87514114], [68.50068665, 23.87514114], [68.50068665, 23.8748703], [68.50013733, 23.8748703], [68.50013733, 23.87458038], [68.49986267, 23.87458229], [68.49986267, 23.87430573], [68.49958038, 23.87430954], [68.49958038, 23.87375069], [68.49930573, 23.87375069], [68.49930573, 23.87347221], [68.49903107, 23.87347221], [68.49903107, 23.87125015], [68.49874878, 23.87125015], [68.49874878, 23.87042236], [68.49903107, 23.87042236], [68.49903107, 23.86930084], [68.49874878, 23.86930466], [68.49874878, 23.86874962], [68.49847412, 23.86874962], [68.49847412, 23.86847305], [68.49819183, 23.86847305], [68.49819183, 23.86819458], [68.49791718, 23.86819458], [68.49791718, 23.86791611], [68.49736023, 23.86791992], [68.49736023, 23.86763954], [68.49708557, 23.86763954], [68.49708557, 23.8670826], [68.49514008, 23.8670826], [68.49514008, 23.86680794], [68.49373627, 23.86680984], [68.49373627, 23.86652946], [68.49291992, 23.86652946], [68.49291992, 23.86625099], [68.49263763, 23.86625099], [68.49263763, 23.86597061], [68.49236298, 23.86597252], [68.49236298, 23.86569595], [68.49208069, 23.86569595], [68.49208069, 23.86597252], [68.49153137, 23.86597061], [68.49153137, 23.86625099], [68.4909668, 23.86625099], [68.4909668, 23.86680984], [68.49069214, 23.86680794], [68.49069977, 23.86736107], [68.49041748, 23.86736107], [68.49041748, 23.86874962], [68.49013519, 23.86874962], [68.49013519, 23.86930466], [68.48986053, 23.86930466], [68.48986053, 23.87097168], [68.48958588, 23.87097168], [68.48958588, 23.87153053], [68.48929596, 23.87153053], [68.48929596, 23.87236023], [68.48902893, 23.87236023], [68.48902893, 23.8748703], [68.48874664, 23.87486076], [68.48874664, 23.87597275], [68.48847198, 23.87597275], [68.48847198, 23.87708282], [68.48819733, 23.87708282], [68.48819733, 23.87847137], [68.4879303, 23.87846947], [68.4879303, 23.87903023], [68.48764038, 23.87903023], [68.48764038, 23.8801403], [68.48735809, 23.88013649], [68.48735809, 23.88097191], [68.48708344, 23.88097191], [68.48708344, 23.88458252], [68.48680878, 23.88458061], [68.48680878, 23.8848629], [68.48652649, 23.8848629], [68.48652649, 23.8856945], [68.48625183, 23.8856926], [68.48625183, 23.88764], [68.48596954, 23.88764], [68.48596954, 23.88986969], [68.48625183, 23.88986969], [68.48625183, 23.89042091], [68.48652649, 23.89041519], [68.48652649, 23.89069366], [68.48680878, 23.89069366], [68.48680878, 23.89097214], [68.48764038, 23.89097023], [68.48764038, 23.89125061], [68.48819733, 23.89125061], [68.48819733, 23.89153099], [68.48902893, 23.89153099], [68.48902893, 23.89180946], [68.48958588, 23.89180756], [68.48958588, 23.89208412], [68.49041748, 23.89208031], [68.49041748, 23.89236069], [68.4909668, 23.89236069], [68.4909668, 23.89264107], [68.49180603, 23.89263916], [68.49180603, 23.89291763], [68.49236298, 23.89291763], [68.49236298, 23.8931942], [68.49319458, 23.8931942], [68.49319458, 23.89347267], [68.49373627, 23.89347076], [68.49373627, 23.89375114], [68.49430847, 23.89375114], [68.49430847, 23.89402962], [68.49485779, 23.89402962], [68.49485779, 23.89430809], [68.49541473, 23.89430618], [68.49541473, 23.89458275], [68.49597168, 23.89458084], [68.49597168, 23.89486122], [68.49652863, 23.89486122], [68.49652863, 23.89513969], [68.49736023, 23.89513969], [68.49736023, 23.89541817], [68.49791718, 23.89541626], [68.49791718, 23.89569473], [68.49847412, 23.89569473], [68.49847412, 23.8959713], [68.49903107, 23.89596748], [68.49903107, 23.89624977], [68.49958038, 23.89624977], [68.49958038, 23.89652824], [68.50013733, 23.89652824], [68.50013733, 23.89680481], [68.50041962, 23.89680481], [68.50041962, 23.89708328], [68.50096893, 23.89708328], [68.50096893, 23.89736176], [68.50125122, 23.89736176], [68.50125122, 23.89764023], [68.50180817, 23.89764023], [68.50180817, 23.89792252], [68.50208282, 23.89792252], [68.50208282, 23.8982029], [68.50263977, 23.89819527], [68.50263977, 23.89847183], [68.5029068, 23.89847183], [68.5029068, 23.89875031], [68.50319672, 23.89875031], [68.50319672, 23.89903259], [68.50347137, 23.89903259], [68.50347137, 23.89931107], [68.50375366, 23.89930534], [68.50375366, 23.89958382], [68.50402832, 23.89958191], [68.50402832, 23.89986038], [68.5045929, 23.89986038], [68.5045929, 23.90014076], [68.50485992, 23.90014076], [68.50485992, 23.90042114], [68.50514221, 23.90041733], [68.50514221, 23.90069389], [68.50541687, 23.90069389], [68.50541687, 23.90097237], [68.50567627, 23.90097046], [68.50567627, 23.90125084], [68.50596619, 23.90125084], [68.50596619, 23.90153122], [68.50653076, 23.90153122], [68.50653076, 23.90180969], [68.50708008, 23.90180588], [68.50708008, 23.90208244], [68.50736237, 23.90208054], [68.50736237, 23.90236092], [68.50791931, 23.90236092], [68.50791931, 23.90263939], [68.51097107, 23.90263939], [68.51097107, 23.90291977], [68.51208496, 23.90291405], [68.51208496, 23.90319443], [68.51347351, 23.90319443], [68.51347351, 23.90291405], [68.51374817, 23.90291977], [68.51374817, 23.90263939], [68.51403046, 23.90263939], [68.51403046, 23.90236092], [68.51431274, 23.90236092], [68.51430511, 23.90208244], [68.51457977, 23.90208244], [68.51457977, 23.90180588], [68.51513672, 23.90180969], [68.51513672, 23.90153122], [68.51541901, 23.90153122], [68.51541901, 23.90125084], [68.51568604, 23.90125084], [68.51568604, 23.90097046], [68.51597595, 23.90097237], [68.51597595, 23.90041733], [68.51568604, 23.90042114], [68.51568604, 23.90014076], [68.51597595, 23.90014076], [68.51597595, 23.89986038], [68.51625061, 23.89986038], [68.51625061, 23.89958191], [68.51680756, 23.89958382], [68.51680756, 23.89930534], [68.51708221, 23.89931107], [68.51708221, 23.89903259], [68.51735687, 23.89903259], [68.51735687, 23.89875031], [68.51763916, 23.89875031], [68.51763916, 23.89847183], [68.51791382, 23.89847183], [68.51791382, 23.89819527], [68.51819611, 23.8982029], [68.51819611, 23.89792252], [68.51847076, 23.89792252], [68.51847076, 23.89764023], [68.51875305, 23.89764023], [68.51875305, 23.89736176], [68.51902771, 23.89736176], [68.51902771, 23.89708328], [68.51958466, 23.89708328], [68.51958466, 23.89680481], [68.51985931, 23.89680481], [68.51985931, 23.89652824], [68.5201416, 23.89652824], [68.5201416, 23.89596748], [68.52041626, 23.8959713], [68.52041626, 23.89541626], [68.52068329, 23.89541817], [68.52068329, 23.89486122], [68.52097321, 23.89486122], [68.52097321, 23.89430809], [68.52236176, 23.89430809], [68.52236176, 23.89402962], [68.52348328, 23.89402962], [68.52348328, 23.89375114], [68.52404022, 23.89375114], [68.52404022, 23.89319038], [68.52430725, 23.8931942], [68.52430725, 23.89263916], [68.52458191, 23.89264107], [68.52458191, 23.89236069], [68.52540588, 23.89236069], [68.52540588, 23.89264107], [68.5256958, 23.89264107], [68.5256958, 23.89375114], [68.52541351, 23.89374733], [68.52541351, 23.89458275], [68.52513885, 23.89458084], [68.52513885, 23.89486122], [68.52458191, 23.89486122], [68.52458191, 23.89513969], [68.52430725, 23.89513969], [68.52430725, 23.89541817], [68.52319336, 23.89541626], [68.52319336, 23.89569473], [68.5229187, 23.89569473], [68.5229187, 23.8959713], [68.52263641, 23.89596748], [68.52263641, 23.89624977], [68.52236176, 23.89624977], [68.52236176, 23.89652824], [68.5220871, 23.89652824], [68.5220871, 23.89680481], [68.52180481, 23.89680481], [68.52180481, 23.89708328], [68.52153015, 23.89708138], [68.52153015, 23.89764023], [68.52097321, 23.89764023], [68.52097321, 23.89792252], [68.52069092, 23.89791679], [68.52069092, 23.89847183], [68.52041626, 23.89847183], [68.52041626, 23.89875031], [68.5201416, 23.89875031], [68.5201416, 23.89931107], [68.51985931, 23.89930534], [68.51985931, 23.89958382], [68.51957703, 23.89958191], [68.51957703, 23.89986038], [68.51930237, 23.89986038], [68.51930237, 23.90014076], [68.51902771, 23.90013885], [68.51902771, 23.90069389], [68.51875305, 23.90069389], [68.51875305, 23.90097237], [68.51847076, 23.90097046], [68.51847076, 23.90125084], [68.51819611, 23.90125084], [68.51819611, 23.90180969], [68.51791382, 23.90180588], [68.51791382, 23.90208244], [68.51763916, 23.90208054], [68.51763916, 23.90236092], [68.51708221, 23.90236092], [68.51708221, 23.90208054], [68.51597595, 23.90208054], [68.51597595, 23.90236092], [68.51568604, 23.90236092], [68.51568604, 23.90291977], [68.51541901, 23.90291405], [68.51541901, 23.90347481], [68.51486206, 23.90347481], [68.51486206, 23.90374947], [68.51431274, 23.90374947], [68.51431274, 23.90402985], [68.51403046, 23.90402794], [68.51403046, 23.90458298], [68.51430511, 23.90458298], [68.51430511, 23.90486145], [68.51457977, 23.90485001], [68.51457977, 23.90513992], [68.51513672, 23.90513992], [68.51513672, 23.9054203], [68.51541901, 23.9054203], [68.51541901, 23.90570068], [68.51597595, 23.90569687], [68.51597595, 23.90597153], [68.51680756, 23.90596962], [68.51680756, 23.90625], [68.51735687, 23.90625], [68.51735687, 23.90653038], [68.51763916, 23.90653038], [68.51763916, 23.90681076], [68.51791382, 23.90680695], [68.51791382, 23.90708351], [68.51847076, 23.90708351], [68.51847076, 23.90736198], [68.51875305, 23.90735817], [68.51875305, 23.90764046], [68.51902771, 23.90763855], [68.51902771, 23.90791893], [68.51930237, 23.90791893], [68.51930237, 23.90819359], [68.51985931, 23.90819359], [68.51985931, 23.90847206], [68.5201416, 23.90846825], [68.5201416, 23.90875053], [68.52041626, 23.90875053], [68.52041626, 23.90903091], [68.52097321, 23.90903091], [68.52097321, 23.90930939], [68.52153015, 23.90930557], [68.52153015, 23.90958405], [68.52179718, 23.90957832], [68.52179718, 23.90986061], [68.5220871, 23.90986061], [68.5220871, 23.91013908], [68.52236176, 23.91013908], [68.52236176, 23.91041946], [68.52263641, 23.91041756], [68.52263641, 23.91069412], [68.52319336, 23.9106884], [68.52319336, 23.91098022], [68.52348328, 23.91098022], [68.52348328, 23.91124916], [68.52404022, 23.91124916], [68.52404022, 23.91152954], [68.52430725, 23.91152954], [68.52430725, 23.91181183], [68.5248642, 23.91180611], [68.5248642, 23.91208267], [68.52513885, 23.91208267], [68.52513885, 23.91236115], [68.52540588, 23.91236115], [68.52540588, 23.91292191], [68.5256958, 23.91291618], [68.5256958, 23.91319466], [68.52597046, 23.91319275], [68.52597046, 23.91374969], [68.52625275, 23.91374969], [68.52625275, 23.91403961], [68.5265274, 23.91402817], [68.5265274, 23.91430473], [68.52680206, 23.91430473], [68.52680206, 23.91458321], [68.52708435, 23.91458321], [68.52708435, 23.91486168], [68.52735901, 23.91485977], [68.52735901, 23.91514015], [68.52874756, 23.91514015], [68.52874756, 23.91570091], [68.52902985, 23.91570091], [68.52902985, 23.91625023], [68.52929688, 23.91625023], [68.52929688, 23.91653061], [68.52958679, 23.91653061], [68.52958679, 23.91681099], [68.53013611, 23.91680336], [68.53013611, 23.91708565], [68.5304184, 23.91707993], [68.5304184, 23.91764069], [68.53069305, 23.91764069], [68.53069305, 23.91792107], [68.53097534, 23.91791534], [68.53097534, 23.91847229], [68.53125, 23.91847038], [68.53125, 23.91903114], [68.53152466, 23.91902542], [68.53152466, 23.91958427], [68.53180695, 23.91958046], [68.53180695, 23.92014122], [68.5320816, 23.92014122], [68.5320816, 23.92263985], [68.53180695, 23.92263985], [68.53180695, 23.92347145], [68.5320816, 23.92347145], [68.5320816, 23.92319489], [68.53236389, 23.92319489], [68.53236389, 23.92263985], [68.53263855, 23.92263985], [68.53263855, 23.92180824], [68.53291321, 23.92180824], [68.53291321, 23.92124939], [68.53320312, 23.92124939], [68.5331955, 23.92097282], [68.53347015, 23.92097282], [68.53347015, 23.92041779], [68.53375244, 23.92041969], [68.53375244, 23.92014122], [68.5340271, 23.92014122], [68.5340271, 23.91930962], [68.53430176, 23.91930962], [68.53430939, 23.91903114], [68.53457642, 23.91903114], [68.53457642, 23.91875076], [68.53514099, 23.91875076], [68.53514099, 23.91847038], [68.53541565, 23.91847229], [68.53541565, 23.91819382], [68.53569794, 23.91819382], [68.53569794, 23.91791534], [68.53598022, 23.91792107], [68.53598022, 23.91764069], [68.53652954, 23.91764069], [68.53652954, 23.91736031], [68.53736115, 23.91736031], [68.53736115, 23.91764069], [68.5376358, 23.91763878], [68.5376358, 23.91847229], [68.53736115, 23.91847038], [68.53736115, 23.91875076], [68.53708649, 23.91875076], [68.53708649, 23.91903114], [68.53652954, 23.91902542], [68.53652954, 23.91958237], [68.53624725, 23.91958427], [68.53624725, 23.91986084], [68.53569794, 23.9198494], [68.53569794, 23.92014122], [68.53541565, 23.92013931], [68.53541565, 23.92069435], [68.53514099, 23.92069435], [68.53514099, 23.92097282], [68.5348587, 23.92097092], [68.5348587, 23.92152977], [68.53457642, 23.92152977], [68.53457642, 23.92180824], [68.53430176, 23.92180634], [68.53430176, 23.92236137], [68.5340271, 23.92236137], [68.5340271, 23.92319489], [68.53375244, 23.92318916], [68.53375244, 23.9240303], [68.53347015, 23.9240303], [68.53347015, 23.92431259], [68.53291321, 23.92430496], [68.53291321, 23.92458344], [68.53235626, 23.92458153], [68.53235626, 23.92736053], [68.5320816, 23.92736053], [68.5320816, 23.93013954], [68.53180695, 23.93013954], [68.53180695, 23.93153], [68.53152466, 23.93152618], [68.53152466, 23.93208313], [68.53125, 23.93208122], [68.53125, 23.93320084], [68.53097534, 23.93319511], [68.53097534, 23.93347168], [68.53069305, 23.93346977], [68.53069305, 23.93375015], [68.5304184, 23.93375015], [68.5304184, 23.93403053], [68.53013611, 23.93403053], [68.53013611, 23.93431091], [68.52986145, 23.93430519], [68.52986145, 23.93458366], [68.52958679, 23.93457985], [68.52958679, 23.93486023], [68.52902985, 23.93486023], [68.52902985, 23.93514061], [68.52874756, 23.93514061], [68.52874756, 23.93541908], [68.5284729, 23.93541718], [68.5284729, 23.93569374], [68.52819824, 23.93568993], [68.52819061, 23.93625069], [68.52791595, 23.93625069], [68.52791595, 23.93652916], [68.5276413, 23.93652916], [68.5276413, 23.93680954], [68.52735901, 23.93680954], [68.52735901, 23.93736076], [68.52680969, 23.93736076], [68.52680969, 23.93763924], [68.5265274, 23.93763924], [68.5265274, 23.93875122], [68.52625275, 23.93875122], [68.52625275, 23.93931007], [68.52597046, 23.93930626], [68.52597046, 23.9398613], [68.5256958, 23.93985939], [68.5256958, 23.94013977], [68.52541351, 23.94013977], [68.52541351, 23.94069481], [68.5256958, 23.9406929], [68.5256958, 23.94098091], [68.52625275, 23.94098091], [68.52625275, 23.94124985], [68.5265274, 23.94124985], [68.5265274, 23.94153023], [68.52680206, 23.94152832], [68.52680206, 23.94180489], [68.52708435, 23.94180489], [68.52708435, 23.94236183], [68.52735901, 23.94235992], [68.52735901, 23.9426403], [68.5276413, 23.9426403], [68.5276413, 23.94292068], [68.52819061, 23.94292068], [68.52819824, 23.94320107], [68.5284729, 23.94319344], [68.5284729, 23.94347191], [68.52874756, 23.94347], [68.52874756, 23.94375038], [68.5293045, 23.94375038], [68.5293045, 23.94402695], [68.52958679, 23.94402122], [68.52958679, 23.94431114], [68.52986145, 23.94430733], [68.52986145, 23.9445858], [68.53180695, 23.94458008], [68.53180695, 23.94486046], [68.53235626, 23.94486046], [68.53235626, 23.94514084], [68.53263855, 23.94514084], [68.53263855, 23.94542122], [68.53291321, 23.9454155], [68.53291321, 23.94569588], [68.5348587, 23.94569588], [68.5348587, 23.94597244], [68.53541565, 23.94597244], [68.53541565, 23.94402695], [68.53624725, 23.94402695], [68.53624725, 23.94375038], [68.53708649, 23.94375038], [68.53708649, 23.94320107], [68.53736115, 23.94320107], [68.53736115, 23.9426403], [68.5376358, 23.9426403], [68.5376358, 23.94180107], [68.53791809, 23.94180489], [68.53791809, 23.94124985], [68.53819275, 23.94124985], [68.53819275, 23.94042015], [68.53848267, 23.94042015], [68.53848267, 23.93985939], [68.53874969, 23.9398613], [68.53874969, 23.93930626], [68.53901672, 23.93931007], [68.53901672, 23.93875122], [68.53930664, 23.93875122], [68.53930664, 23.93847275], [68.5395813, 23.93847275], [68.5395813, 23.9379158], [68.53985596, 23.93791962], [68.53985596, 23.93763924], [68.54013824, 23.93763924], [68.54013824, 23.93736076], [68.5404129, 23.93736076], [68.5404129, 23.93680954], [68.54070282, 23.93680954], [68.54070282, 23.93652916], [68.54096985, 23.93652916], [68.54096985, 23.9359684], [68.54125214, 23.93597221], [68.54125214, 23.93569374], [68.54152679, 23.93569374], [68.54152679, 23.9351387], [68.54180908, 23.93514061], [68.54180908, 23.93457985], [68.54208374, 23.93458366], [68.54208374, 23.93402863], [68.5423584, 23.93403053], [68.5423584, 23.93375015], [68.54292297, 23.93375015], [68.54291534, 23.93347168], [68.54374695, 23.93347168], [68.54374695, 23.93319511], [68.54429626, 23.93320084], [68.54429626, 23.93292046], [68.54514313, 23.93292046], [68.54514313, 23.93264008], [68.54680634, 23.93264008], [68.54680634, 23.9323597], [68.54846954, 23.9323616], [68.54846954, 23.93208313], [68.55180359, 23.93208313], [68.55180359, 23.93180466], [68.55708313, 23.93180466], [68.55708313, 23.93152618], [68.55735779, 23.93153], [68.55735779, 23.93124962], [68.55764008, 23.93124962], [68.55764008, 23.93097115], [68.55819702, 23.93097305], [68.55819702, 23.93069649], [68.55847168, 23.93069649], [68.55847168, 23.9304142], [68.55874634, 23.93041992], [68.55874634, 23.92958069], [68.55902863, 23.9295826], [68.55902863, 23.92847252], [68.55874634, 23.92847252], [68.55874634, 23.92763901], [68.55847168, 23.92764091], [68.55847168, 23.92708015], [68.55819702, 23.92708206], [68.55819702, 23.92625046], [68.5579071, 23.92625046], [68.5579071, 23.92375183], [68.55819702, 23.92375183], [68.55819702, 23.92347145], [68.55847168, 23.92347145], [68.55847168, 23.92319489], [68.55958557, 23.92319489], [68.55958557, 23.92291641], [68.56153107, 23.92291832], [68.56153107, 23.92263985], [68.56485748, 23.92263985], [68.56485748, 23.92291832], [68.57125092, 23.92291641], [68.57125092, 23.92319489], [68.57236481, 23.92319489], [68.57236481, 23.92347145], [68.57958221, 23.92347145], [68.57958221, 23.92319489], [68.58097076, 23.92319489], [68.58097076, 23.92291641], [68.5826416, 23.92291832], [68.5826416, 23.92263985], [68.58374786, 23.92263985], [68.58374786, 23.92235756], [68.5845871, 23.92236137], [68.5845871, 23.9220829], [68.5854187, 23.9220829], [68.5854187, 23.92180634], [68.58569336, 23.92180824], [68.58569336, 23.92152977], [68.58625031, 23.92152977], [68.58625031, 23.92124939], [68.58680725, 23.92124939], [68.58680725, 23.92152977], [68.58790588, 23.92152977], [68.58790588, 23.92014122], [68.5881958, 23.92014122], [68.5881958, 23.91958046], [68.58847046, 23.91958427], [68.58847046, 23.91875076], [68.58875275, 23.91875076], [68.58875275, 23.91681099], [68.58847046, 23.91681099], [68.58847046, 23.91653061], [68.58763885, 23.91653061], [68.58763885, 23.91625023], [68.58652496, 23.91625023], [68.58652496, 23.91597176], [68.5854187, 23.91597176], [68.5854187, 23.91569328], [68.58429718, 23.91570091], [68.58429718, 23.91542053], [68.58319092, 23.91542053], [68.58319092, 23.91514015], [68.58207703, 23.91514015], [68.58207703, 23.91485977], [68.58152771, 23.91486168], [68.58152771, 23.91458321], [68.58125305, 23.91458321], [68.58125305, 23.91430473], [68.58069611, 23.91430473], [68.58069611, 23.91402817], [68.58013916, 23.91403961], [68.58013916, 23.91374969], [68.57958221, 23.91374969], [68.57958221, 23.91347122], [68.57930756, 23.91347122], [68.57930756, 23.91319466], [68.57875061, 23.91319466], [68.57875061, 23.91291618], [68.57847595, 23.91292191], [68.57847595, 23.91263962], [68.57791901, 23.91263962], [68.57791901, 23.91236115], [68.57763672, 23.91236115], [68.57763672, 23.91208267], [68.57736206, 23.91208267], [68.57736206, 23.91180611], [68.57707977, 23.91181183], [68.57707977, 23.91152954], [68.57653046, 23.91152954], [68.57653046, 23.91124916], [68.57624817, 23.91124916], [68.57624817, 23.91098022], [68.57596588, 23.91098022], [68.57596588, 23.9106884], [68.57541656, 23.91069412], [68.57541656, 23.91041756], [68.57514954, 23.91041946], [68.57514954, 23.91013908], [68.57485962, 23.91013908], [68.57485962, 23.90986061], [68.57457733, 23.90986061], [68.57457733, 23.90957832], [68.57430267, 23.90958405], [68.57430267, 23.90930557], [68.57375336, 23.90930939], [68.57375336, 23.90903091], [68.57319641, 23.90903091], [68.57319641, 23.90875053], [68.57263947, 23.90875053], [68.57263947, 23.90846825], [68.57208252, 23.90847206], [68.57208252, 23.90819359], [68.57180786, 23.90819359], [68.57180786, 23.90791893], [68.57152557, 23.90791893], [68.57152557, 23.90736198], [68.57125092, 23.90736198], [68.57125092, 23.90708351], [68.57069397, 23.90708351], [68.57069397, 23.90680695], [68.57041931, 23.90681076], [68.57041931, 23.90653038], [68.57013702, 23.90653038], [68.57013702, 23.90596962], [68.56958008, 23.90597153], [68.56958008, 23.90569687], [68.56931305, 23.90570068], [68.56931305, 23.9054203], [68.56902313, 23.9054203], [68.56902313, 23.90513992], [68.56874847, 23.90513992], [68.56874847, 23.90458107], [68.56819153, 23.90458298], [68.56819153, 23.9043045], [68.56791687, 23.90431023], [68.56791687, 23.90402985], [68.56764221, 23.90402985], [68.56764221, 23.90374947], [68.56735992, 23.90374947], [68.56735992, 23.90347099], [68.56708527, 23.90347481], [68.56708527, 23.90263939], [68.56680298, 23.90263939], [68.56680298, 23.90236092], [68.56652832, 23.90236092], [68.56652832, 23.90208054], [68.56625366, 23.90208244], [68.56625366, 23.9015274], [68.56595612, 23.90153122], [68.56595612, 23.90125084], [68.56569672, 23.90125084], [68.56569672, 23.90042114], [68.5654068, 23.90042114], [68.5654068, 23.90014076], [68.56595612, 23.90014076], [68.56595612, 23.89986038], [68.56624603, 23.89986038], [68.56624603, 23.89958191], [68.56680298, 23.89958382], [68.56680298, 23.89930534], [68.5670929, 23.89931107], [68.5670929, 23.89903259], [68.56735992, 23.89903259], [68.56735992, 23.89875031], [68.56708527, 23.89875031], [68.56708527, 23.89819527], [68.56680298, 23.8982029], [68.56680298, 23.89764023], [68.56652832, 23.89764023], [68.56652832, 23.89708138], [68.56625366, 23.89708328], [68.56625366, 23.89680481], [68.56597137, 23.89680481], [68.56597137, 23.89624977], [68.56569672, 23.89624977], [68.56569672, 23.89567947], [68.56541443, 23.89569473], [68.56541443, 23.89541626], [68.56513977, 23.89541817], [68.56513977, 23.89486122], [68.56485748, 23.89486122], [68.56485748, 23.89430809], [68.56458282, 23.89430809], [68.56458282, 23.89375114], [68.56430817, 23.89375114], [68.56430817, 23.89347076], [68.56402588, 23.89347267], [68.56402588, 23.8931942], [68.56375122, 23.8931942], [68.56375122, 23.89291763], [68.56319427, 23.89291763], [68.56319427, 23.89263916], [68.56291962, 23.89264107], [68.56291962, 23.89236069], [68.56263733, 23.89236069], [68.56263733, 23.89208031], [68.56236267, 23.89208412], [68.56236267, 23.89180756], [68.56181335, 23.89180946], [68.56181335, 23.89153099], [68.56153107, 23.89153099], [68.56153107, 23.89125061], [68.56124878, 23.89125061], [68.56124878, 23.89097023], [68.56097412, 23.89097214], [68.56097412, 23.89041519], [68.56069183, 23.89042091], [68.56069183, 23.89014053], [68.56041718, 23.89014053], [68.56041718, 23.88986969], [68.56014252, 23.88986969], [68.56014252, 23.88931084], [68.55986023, 23.88931084], [68.55986023, 23.88903046], [68.5595932, 23.88903046], [68.5595932, 23.88875008], [68.55930328, 23.88875008], [68.55930328, 23.8884697], [68.55902863, 23.8884716], [68.55902863, 23.88791656], [68.55874634, 23.88792038], [68.55874634, 23.88764], [68.55847168, 23.88764], [68.55847168, 23.88735962], [68.55819702, 23.88736153], [68.55819702, 23.88708115], [68.55791473, 23.88708115], [68.55791473, 23.88680649], [68.55764008, 23.8868103], [68.55764008, 23.88652992], [68.55735779, 23.88652992], [68.55735779, 23.88597107], [68.55708313, 23.88597107], [68.55708313, 23.8856945], [68.55680847, 23.8856945], [68.55680847, 23.88541603], [68.55652618, 23.88542175], [68.55652618, 23.88513947], [68.55625153, 23.88513947], [68.55625153, 23.88458061], [68.55596924, 23.88458252], [68.55596924, 23.88402748], [68.55568695, 23.88402939], [68.55568695, 23.88347054], [68.55541992, 23.88347244], [68.55541992, 23.8829174], [68.55513763, 23.88291931], [68.55513763, 23.88264084], [68.55486298, 23.88264084], [68.55486298, 23.88236046], [68.55458069, 23.88236046], [68.55458069, 23.88180923], [68.55430603, 23.88180923], [68.55430603, 23.88153076], [68.55401611, 23.88153076], [68.55401611, 23.88125038], [68.55374908, 23.88125038], [68.55374908, 23.88096809], [68.55319214, 23.88097191], [68.55319214, 23.88069534], [68.55291748, 23.88069916], [68.55291748, 23.88042068], [68.55264282, 23.88042068], [68.55264282, 23.8801403], [68.55208588, 23.8801403], [68.55208588, 23.87985992], [68.55180359, 23.87986183], [68.55180359, 23.87958336], [68.55152893, 23.87958336], [68.55152893, 23.87930679], [68.55097198, 23.87930679], [68.55097198, 23.87902832], [68.55069733, 23.87903023], [68.55069733, 23.87874985], [68.55014038, 23.87874985], [68.55014038, 23.87846947], [68.54930878, 23.87847137], [68.54930878, 23.87569237], [68.54902649, 23.87569237], [68.54902649, 23.87513924], [68.54875183, 23.87514114], [68.54875183, 23.8748703], [68.54846954, 23.8748703], [68.54846954, 23.87458038], [68.54819489, 23.87458229], [68.54819489, 23.87430573], [68.54792023, 23.87430954], [68.54792023, 23.87403107], [68.54763794, 23.87403107], [68.54763794, 23.87375069], [68.54736328, 23.87375069], [68.54736328, 23.87347031], [68.54708099, 23.87347221], [68.54708099, 23.87319374], [68.54680634, 23.87319374], [68.54680634, 23.87291718], [68.54624939, 23.8729229], [68.54624939, 23.87264061], [68.54569244, 23.87264061], [68.54569244, 23.87236023], [68.5451355, 23.87236023], [68.5451355, 23.87208366], [68.54486084, 23.87208366], [68.54486084, 23.87180519], [68.54319763, 23.87180519], [68.54319763, 23.87208366], [68.54264069, 23.87208366], [68.54264069, 23.87180519], [68.5423584, 23.87180519], [68.5423584, 23.87152863], [68.54207611, 23.87153053], [68.54207611, 23.87125015], [68.54180908, 23.87125015], [68.54180908, 23.87097168], [68.54152679, 23.87097168], [68.54152679, 23.87069511], [68.54125214, 23.87070274], [68.54125214, 23.87042236], [68.54096985, 23.87042236], [68.54096985, 23.87014008], [68.54070282, 23.87014008], [68.54070282, 23.8698597], [68.5404129, 23.8698616], [68.5404129, 23.86958313], [68.54013824, 23.86958313], [68.54013824, 23.86930466], [68.53986359, 23.86930466], [68.53986359, 23.86902809], [68.5395813, 23.86902809], [68.5395813, 23.86874008], [68.53930664, 23.86874962], [68.53930664, 23.86847305], [68.53874969, 23.86847305], [68.53874969, 23.86819458], [68.53847504, 23.86819458], [68.53847504, 23.86791611], [68.53819275, 23.86791992], [68.53819275, 23.86763954], [68.53791809, 23.86763954], [68.53791809, 23.86736107], [68.53708649, 23.86736107], [68.53708649, 23.86958313], [68.53736115, 23.86958122], [68.53736115, 23.87070274], [68.5376358, 23.87069511], [68.5376358, 23.87097168], [68.53624725, 23.87097168], [68.53624725, 23.87180519], [68.53598022, 23.87179947], [68.53598022, 23.8729229], [68.53624725, 23.8729229], [68.53624725, 23.87403107], [68.53652954, 23.87403107], [68.53652954, 23.87430954], [68.5368042, 23.87430573], [68.5368042, 23.87458229], [68.53652954, 23.87458038], [68.53652954, 23.8748703], [68.53679657, 23.8748703], [68.53679657, 23.87541962], [68.5359726, 23.8754158], [68.5359726, 23.87569237], [68.53569794, 23.87569046], [68.53569794, 23.87625122], [68.53263855, 23.87625122], [68.53263855, 23.87597084], [68.53236389, 23.87597275], [68.53236389, 23.87569237], [68.5320816, 23.87569237], [68.5320816, 23.8754158], [68.53180695, 23.87541962], [68.53180695, 23.8748703], [68.53125, 23.8748703], [68.53125, 23.87458038], [68.53097534, 23.87458229], [68.53097534, 23.87375069], [68.53069305, 23.87375069], [68.53069305, 23.87347031], [68.5304184, 23.87347221], [68.5304184, 23.87291718], [68.53013611, 23.8729229], [68.53013611, 23.87264061], [68.52984619, 23.87264061], [68.52984619, 23.87236023], [68.52958679, 23.87236023], [68.52958679, 23.87208176], [68.5293045, 23.87208366], [68.5293045, 23.87152863], [68.52902985, 23.87153053], [68.52902985, 23.87070274], [68.52874756, 23.87070274], [68.52874756, 23.87014008], [68.5284729, 23.87014008], [68.5284729, 23.86958122], [68.52819824, 23.86958313], [68.52819824, 23.86874962], [68.52791595, 23.86874962], [68.52791595, 23.86763954], [68.5276413, 23.86763954], [68.5276413, 23.86736107], [68.52735901, 23.86736107], [68.52735901, 23.86680984], [68.52707672, 23.86680984], [68.52707672, 23.86625099], [68.52680969, 23.86625099], [68.52680969, 23.86597061], [68.5265274, 23.86597252], [68.5265274, 23.8651371], [68.52625275, 23.86514091], [68.52625275, 23.86486053], [68.52597046, 23.86486053], [68.52597046, 23.86458015], [68.5256958, 23.86458588], [68.5256958, 23.86402512], [68.52540588, 23.86403084], [68.52540588, 23.86375046], [68.52513885, 23.86375046], [68.52513885, 23.86347008], [68.5248642, 23.86347198], [68.5248642, 23.86319351], [68.52458191, 23.86319351], [68.52458191, 23.86263847], [68.52430725, 23.86264038], [68.52430725, 23.86236], [68.52402496, 23.86236191], [68.52402496, 23.86180305], [68.52375031, 23.86181068], [68.52375031, 23.8615303], [68.52348328, 23.8615303], [68.52348328, 23.86124992], [68.52319336, 23.86124992], [68.52319336, 23.86069107], [68.5229187, 23.86069489], [68.5229187, 23.86013794], [68.52263641, 23.86013985], [68.52263641, 23.85957146], [68.52236176, 23.8595829], [68.52236176, 23.85874939], [68.52263641, 23.85874939], [68.52263641, 23.85847282], [68.52236176, 23.85847282], [68.52236176, 23.85736084], [68.5220871, 23.85736084], [68.5220871, 23.85625076]]], [[[68.47930908, 23.88820076], [68.47902679, 23.88820076], [68.47902679, 23.88708115], [68.47875214, 23.88708115], [68.47875214, 23.88624954], [68.47846985, 23.88624954], [68.47846985, 23.88291931], [68.47820282, 23.88291931], [68.47820282, 23.88207817], [68.4779129, 23.88208389], [68.4779129, 23.88152885], [68.47763824, 23.88153076], [68.47763824, 23.88096809], [68.47736359, 23.88097191], [68.47736359, 23.88041878], [68.4770813, 23.88042068], [68.4770813, 23.87957954], [68.47680664, 23.87958336], [68.47680664, 23.87874985], [68.47651672, 23.87874985], [68.47651672, 23.87819099], [68.47624969, 23.87819672], [68.47624969, 23.8773613], [68.47597504, 23.8773613], [68.47597504, 23.87652779], [68.47570038, 23.87652969], [68.47570038, 23.87597084], [68.47541809, 23.87597275], [68.47541809, 23.87513924], [68.4751358, 23.87514114], [68.4751358, 23.87403107], [68.47486115, 23.87403107], [68.47486115, 23.8729229], [68.47458649, 23.8729229], [68.47458649, 23.87179947], [68.4743042, 23.87180519], [68.4743042, 23.87069511], [68.47402954, 23.87070274], [68.47402954, 23.86930084], [68.47374725, 23.86930466], [68.47374725, 23.86819458], [68.4734726, 23.86819458], [68.4734726, 23.86763954], [68.47319794, 23.86763954], [68.47319794, 23.86680984], [68.47292328, 23.86680984], [68.47292328, 23.8629303], [68.47264099, 23.8629303], [68.47264099, 23.86264038], [68.4723587, 23.86264038], [68.4723587, 23.86207962], [68.47208405, 23.86208344], [68.47208405, 23.86180305], [68.47180939, 23.86181068], [68.47180176, 23.8615303], [68.46848297, 23.8615303], [68.46848297, 23.86124992], [68.4679184, 23.86124992], [68.4679184, 23.86096954], [68.46736145, 23.86097145], [68.46736145, 23.86069489], [68.46485901, 23.86069489], [68.46485901, 23.86041641], [68.46376038, 23.86042023], [68.46376038, 23.86013985], [68.46347046, 23.86013985], [68.46347046, 23.85985947], [68.4631958, 23.85986137], [68.4631958, 23.8595829], [68.46263885, 23.8595829], [68.46263885, 23.85930634], [68.46208191, 23.85931015], [68.46208191, 23.85902977], [68.46125031, 23.85902977], [68.46125031, 23.85874939], [68.4604187, 23.85874939], [68.4604187, 23.85847282], [68.46013641, 23.85847282], [68.46013641, 23.85819435], [68.45986176, 23.85819435], [68.45986176, 23.85736084], [68.4595871, 23.85736084], [68.4595871, 23.85707855], [68.45930481, 23.85708237], [68.45930481, 23.85652733], [68.45874786, 23.85652924], [68.45874786, 23.85625076], [68.45707703, 23.85625076], [68.45707703, 23.85597038], [68.45625305, 23.85597229], [68.45625305, 23.85569382], [68.45541382, 23.85569382], [68.45541382, 23.85541725], [68.45485687, 23.85541916], [68.45485687, 23.85514069], [68.45430756, 23.85514069], [68.45430756, 23.85486031], [68.45347595, 23.85486031], [68.45347595, 23.85457993], [68.45291901, 23.85458374], [68.45291901, 23.85430527], [68.45236206, 23.85430908], [68.45236206, 23.85403061], [68.45207977, 23.85403061], [68.45207977, 23.85375977], [68.45153046, 23.85375977], [68.45153046, 23.85346985], [68.45097351, 23.85347176], [68.45097351, 23.85319519], [68.45069122, 23.85320091], [68.45069122, 23.85292053], [68.45041656, 23.85292053], [68.45041656, 23.85264015], [68.45014191, 23.85264015], [68.45014191, 23.85235977], [68.44985962, 23.85236168], [68.44985962, 23.85180664], [68.44930267, 23.85180664], [68.44930267, 23.85124969], [68.44902802, 23.85124969], [68.44902802, 23.85070038], [68.44847107, 23.85069656], [68.44847107, 23.85097313], [68.44708252, 23.85097313], [68.44708252, 23.85069656], [68.44625092, 23.85070038], [68.44625092, 23.85042], [68.44596863, 23.85042], [68.44596863, 23.85013962], [68.44541931, 23.85013962], [68.44541931, 23.84986115], [68.44486237, 23.84986115], [68.44486237, 23.84958076], [68.44458008, 23.84958267], [68.44458008, 23.8493042], [68.44431305, 23.84930992], [68.44431305, 23.84902954], [68.44403076, 23.84902954], [68.44403076, 23.84847069], [68.44346619, 23.84847069], [68.44346619, 23.84875107], [68.44291687, 23.84875107], [68.44291687, 23.84902954], [68.44235992, 23.84902954], [68.44235992, 23.84930992], [68.44208527, 23.8493042], [68.44208527, 23.84958267], [68.44152832, 23.84958076], [68.44152832, 23.84986115], [68.44097137, 23.84986115], [68.44097137, 23.85013962], [68.4404068, 23.85013962], [68.4404068, 23.85042], [68.44013977, 23.85042], [68.44013977, 23.85070038], [68.43902588, 23.85069656], [68.43902588, 23.85097313], [68.43791962, 23.85097122], [68.43791962, 23.85124969], [68.43708038, 23.85124969], [68.43708038, 23.85153008], [68.43653107, 23.85152626], [68.43653107, 23.85180664], [68.43569183, 23.85180664], [68.43569183, 23.85208321], [68.43235779, 23.85208321], [68.43235779, 23.85236168], [68.43208313, 23.85235977], [68.43208313, 23.85264015], [68.43180847, 23.85264015], [68.43180847, 23.85292053], [68.43152618, 23.85292053], [68.43152618, 23.85320091], [68.43125153, 23.85320091], [68.43125153, 23.85403061], [68.43096924, 23.85403061], [68.43096924, 23.85486031], [68.43069458, 23.85486031], [68.43069458, 23.85569382], [68.43041992, 23.8556881], [68.43041992, 23.85625076], [68.43013763, 23.85625076], [68.43013763, 23.85708237], [68.42986298, 23.85707855], [68.42986298, 23.85763931], [68.42958069, 23.85763931], [68.42958069, 23.85791969], [68.42930603, 23.85791588], [68.42930603, 23.85819435], [68.42903137, 23.85819435], [68.42903137, 23.85847282], [68.42874908, 23.85847282], [68.42874908, 23.85931015], [68.42847443, 23.85930634], [68.42847443, 23.85986137], [68.42819214, 23.85985947], [68.42819214, 23.86181068], [68.42874908, 23.86180305], [68.42874908, 23.86208344], [68.42903137, 23.86208344], [68.42903137, 23.86236191], [68.42986298, 23.86236], [68.42986298, 23.86264038], [68.43041992, 23.86264038], [68.43041992, 23.8629303], [68.43125153, 23.86291695], [68.43125153, 23.8631897], [68.43180847, 23.86319351], [68.43180847, 23.86347198], [68.43235779, 23.86347008], [68.43235779, 23.86375046], [68.43402863, 23.86375046], [68.43402863, 23.86403084], [68.43430328, 23.86403084], [68.43430328, 23.86431122], [68.43486023, 23.8643074], [68.43486023, 23.86458588], [68.43541718, 23.86458015], [68.43541718, 23.86486053], [68.43569183, 23.86486053], [68.43569183, 23.86514091], [68.43624878, 23.86514091], [68.43624878, 23.86541939], [68.43653107, 23.86541939], [68.43653107, 23.86569977], [68.43708038, 23.86569595], [68.43708038, 23.86597252], [68.43763733, 23.86597061], [68.43763733, 23.86625099], [68.43930817, 23.86625099], [68.43930817, 23.86652946], [68.43985748, 23.86652946], [68.43985748, 23.86680984], [68.44013977, 23.86680794], [68.44013977, 23.8670826], [68.4404068, 23.86708069], [68.4404068, 23.86736107], [68.44097137, 23.86736107], [68.44097137, 23.86763954], [68.44124603, 23.86763954], [68.44124603, 23.86791992], [68.44152832, 23.86791611], [68.44152832, 23.86819458], [68.44208527, 23.86819458], [68.44208527, 23.86847305], [68.44235992, 23.86847305], [68.44235992, 23.86874962], [68.44262695, 23.86874008], [68.44262695, 23.86902809], [68.44291687, 23.86902809], [68.44291687, 23.86930466], [68.44319153, 23.86930466], [68.44319153, 23.86958313], [68.44347382, 23.86958313], [68.44347382, 23.8698616], [68.44374847, 23.8698597], [68.44374847, 23.87014008], [68.44430542, 23.87013817], [68.44430542, 23.87097168], [68.44458008, 23.87097168], [68.44458008, 23.87347221], [68.44486237, 23.87347031], [68.44486237, 23.8748703], [68.44513702, 23.8748703], [68.44513702, 23.87541962], [68.44541931, 23.87541962], [68.44541931, 23.87625122], [68.44596863, 23.87625122], [68.44596863, 23.87652969], [68.44680786, 23.87652779], [68.44680786, 23.87708282], [68.44902802, 23.87708282], [68.44902802, 23.8773613], [68.44985962, 23.87735939], [68.44985962, 23.87763977], [68.45069122, 23.87763977], [68.45069122, 23.87792969], [68.45124817, 23.87791443], [68.45124817, 23.87819672], [68.45153046, 23.87819672], [68.45153046, 23.87847137], [68.45182037, 23.87846947], [68.45182037, 23.87903023], [68.45236206, 23.87902832], [68.45236206, 23.87930679], [68.45263672, 23.87930679], [68.45263672, 23.87958336], [68.45291901, 23.87958336], [68.45291901, 23.87986183], [68.45318604, 23.87985992], [68.45318604, 23.88153076], [68.45347595, 23.88153076], [68.45347595, 23.88180923], [68.45375061, 23.88180542], [68.45375061, 23.88458252], [68.45347595, 23.88458061], [68.45347595, 23.8848629], [68.45318604, 23.8848629], [68.45318604, 23.88542175], [68.45291901, 23.88542175], [68.45291901, 23.88624954], [68.45263672, 23.88624954], [68.45263672, 23.88708115], [68.45236206, 23.88708115], [68.45236206, 23.88820076], [68.45207977, 23.88820076], [68.45207977, 23.88903046], [68.45182037, 23.88903046], [68.45182037, 23.88931084], [68.45153046, 23.88930321], [68.45153046, 23.89069366], [68.45124817, 23.89068985], [68.45124817, 23.89236069], [68.45097351, 23.89236069], [68.45097351, 23.89291763], [68.45069122, 23.89291763], [68.45069122, 23.8931942], [68.45041656, 23.8931942], [68.45041656, 23.89347267], [68.45069122, 23.89347076], [68.45069122, 23.89430809], [68.45096588, 23.89430809], [68.45096588, 23.89513969], [68.45124817, 23.89513969], [68.45124817, 23.89569473], [68.45153046, 23.89569473], [68.45153046, 23.8959713], [68.45182037, 23.89596748], [68.45182037, 23.89652824], [68.45207977, 23.89652824], [68.45207977, 23.89708328], [68.45236206, 23.89708138], [68.45236206, 23.89792252], [68.45263672, 23.89792252], [68.45263672, 23.89931107], [68.45291901, 23.89931107], [68.45291901, 23.90042114], [68.45318604, 23.90042114], [68.45318604, 23.90125084], [68.45291901, 23.90125084], [68.45291901, 23.90374947], [68.45263672, 23.90374947], [68.45263672, 23.9054203], [68.45291901, 23.90541458], [68.45291901, 23.90791893], [68.45319366, 23.90791893], [68.45319366, 23.90847206], [68.45347595, 23.90846825], [68.45347595, 23.90875053], [68.45430756, 23.90875053], [68.45430756, 23.90903091], [68.45485687, 23.90903091], [68.45485687, 23.90930939], [68.45513916, 23.90930557], [68.45513916, 23.90958405], [68.45540619, 23.90957832], [68.45540619, 23.90986061], [68.45652771, 23.90986061], [68.45652771, 23.90957832], [68.45762634, 23.90957832], [68.45762634, 23.90986061], [68.45735931, 23.90986061], [68.45735931, 23.91013908], [68.45680237, 23.91013908], [68.45680237, 23.91041946], [68.45652771, 23.91041756], [68.45652771, 23.91069412], [68.45680237, 23.9106884], [68.45680237, 23.91098022], [68.45707703, 23.91098022], [68.45707703, 23.91124916], [68.45735931, 23.91124916], [68.45735931, 23.91152954], [68.45762634, 23.91152954], [68.45762634, 23.91181183], [68.45791626, 23.91180611], [68.45791626, 23.91208267], [68.45819092, 23.91208267], [68.45819092, 23.91458321], [68.45791626, 23.91457939], [68.45791626, 23.91570091], [68.45735931, 23.91570091], [68.45735931, 23.91514015], [68.45707703, 23.91514015], [68.45707703, 23.91457939], [68.45680237, 23.91458321], [68.45680237, 23.91374969], [68.45652771, 23.91374969], [68.45652771, 23.91319275], [68.45625305, 23.91319466], [68.45625305, 23.91291618], [68.45569611, 23.91292191], [68.45569611, 23.91263962], [68.45540619, 23.91263962], [68.45540619, 23.91236115], [68.45485687, 23.91236115], [68.45485687, 23.91208267], [68.45430756, 23.91208267], [68.45430756, 23.91236115], [68.4540329, 23.91236115], [68.4540329, 23.91292191], [68.45430756, 23.91292191], [68.45430756, 23.91374969], [68.4540329, 23.91374969], [68.4540329, 23.91403961], [68.45375061, 23.91403961], [68.45375061, 23.91570091], [68.45402527, 23.91569328], [68.45402527, 23.91597176], [68.45456696, 23.91596985], [68.45456696, 23.91625023], [68.45485687, 23.91625023], [68.45485687, 23.91681099], [68.4540329, 23.91681099], [68.4540329, 23.91653061], [68.45347595, 23.91653061], [68.45347595, 23.91625023], [68.45291901, 23.91625023], [68.45291901, 23.91596985], [68.45263672, 23.91596985], [68.45263672, 23.91625023], [68.45236206, 23.91625023], [68.45236206, 23.91653061], [68.45207977, 23.91653061], [68.45207977, 23.91681099], [68.45180511, 23.91680336], [68.45180511, 23.91708565], [68.45153046, 23.91707993], [68.45153046, 23.91764069], [68.45124817, 23.91763878], [68.45124817, 23.91986084], [68.45153046, 23.9198494], [68.45153046, 23.92041969], [68.45207977, 23.92041779], [68.45207977, 23.92069435], [68.45263672, 23.92069435], [68.45263672, 23.92097282], [68.45318604, 23.92097092], [68.45318604, 23.92124939], [68.45347595, 23.92124939], [68.45347595, 23.92180824], [68.45375061, 23.92180634], [68.45375061, 23.9220829], [68.4540329, 23.92207909], [68.4540329, 23.92291832], [68.45430756, 23.92291641], [68.45430756, 23.92458344], [68.45456696, 23.92458153], [68.45456696, 23.92625046], [68.45485687, 23.92625046], [68.45485687, 23.92681122], [68.45513916, 23.92681122], [68.45513916, 23.92764091], [68.45541382, 23.92763901], [68.45541382, 23.92819214], [68.45569611, 23.92819023], [68.45569611, 23.92875099], [68.45652771, 23.92875099], [68.45652771, 23.92904091], [68.45791626, 23.92904091], [68.45791626, 23.92930984], [68.45903015, 23.92930412], [68.45903015, 23.9295826], [68.4595871, 23.92958069], [68.4595871, 23.92986107], [68.45986176, 23.92986107], [68.45986176, 23.93013954], [68.4604187, 23.93013954], [68.4604187, 23.93069649], [68.46013641, 23.93069077], [68.46013641, 23.93153], [68.4604187, 23.93152618], [68.4604187, 23.93180466], [68.46291351, 23.93180466], [68.46291351, 23.93208313], [68.46208191, 23.93208313], [68.46208191, 23.9323616], [68.46125031, 23.9323597], [68.46125031, 23.93264008], [68.46098328, 23.93264008], [68.46098328, 23.93320084], [68.46069336, 23.93319511], [68.46069336, 23.93347168], [68.4595871, 23.93346977], [68.4595871, 23.93375015], [68.45874786, 23.93375015], [68.45874786, 23.93403053], [68.45735931, 23.93403053], [68.45735931, 23.93431091], [68.45652771, 23.93430519], [68.45652771, 23.93458366], [68.45625305, 23.93457985], [68.45625305, 23.93486023], [68.45597076, 23.93486023], [68.45597076, 23.93514061], [68.45569611, 23.93514061], [68.45569611, 23.93541908], [68.45541382, 23.93541718], [68.45541382, 23.93569374], [68.45513916, 23.93569374], [68.45513916, 23.93597221], [68.45485687, 23.9359684], [68.45485687, 23.93625069], [68.45456696, 23.93625069], [68.45456696, 23.93652916], [68.45430756, 23.93652725], [68.45430756, 23.9370842], [68.45402527, 23.9370842], [68.4540329, 23.93736076], [68.45347595, 23.93736076], [68.45347595, 23.93763924], [68.45291901, 23.93763924], [68.45291901, 23.93791962], [68.45236206, 23.9379158], [68.45236206, 23.93819427], [68.45180511, 23.93819427], [68.45180511, 23.93847275], [68.45124817, 23.93847275], [68.45124817, 23.93875122], [68.45041656, 23.93875122], [68.45041656, 23.93902969], [68.44985962, 23.93902969], [68.44985962, 23.93931007], [68.44902802, 23.93930626], [68.44902802, 23.93958282], [68.44875336, 23.93958282], [68.44876099, 23.94013977], [68.44847107, 23.94013977], [68.44847107, 23.93985939], [68.44819641, 23.9398613], [68.44819641, 23.93958282], [68.44763947, 23.93958282], [68.44763947, 23.93930626], [68.44708252, 23.93931007], [68.44708252, 23.93902969], [68.4465332, 23.93902969], [68.4465332, 23.93875122], [68.44568634, 23.93875122], [68.44568634, 23.93847275], [68.44513702, 23.93847275], [68.44513702, 23.93819427], [68.44486237, 23.93819427], [68.44486237, 23.9379158], [68.44458008, 23.93791962], [68.44458008, 23.93763924], [68.44403076, 23.93763924], [68.44403076, 23.93736076], [68.44374847, 23.93736076], [68.44374847, 23.93707848], [68.44319153, 23.9370842], [68.44319153, 23.93680573], [68.44235992, 23.93680954], [68.44235992, 23.93652916], [68.44180298, 23.93652916], [68.44180298, 23.93625069], [68.44097137, 23.93625069], [68.44097137, 23.93652916], [68.43930817, 23.93652916], [68.43930817, 23.93680954], [68.43875122, 23.93680573], [68.43875122, 23.9370842], [68.43791962, 23.93707848], [68.43791962, 23.93736076], [68.43682098, 23.93736076], [68.43682098, 23.93763924], [68.43430328, 23.93763924], [68.43430328, 23.93736076], [68.43345642, 23.93736076], [68.43345642, 23.93707848], [68.43264008, 23.9370842], [68.43264008, 23.93680573], [68.43180847, 23.93680954], [68.43180847, 23.93652916], [68.43096924, 23.93652916], [68.43096924, 23.93625069], [68.42903137, 23.93625069], [68.42903137, 23.93652916], [68.42819214, 23.93652916], [68.42819214, 23.93791962], [68.42847443, 23.9379158], [68.42847443, 23.93847275], [68.42874908, 23.93847275], [68.42874908, 23.93902969], [68.42903137, 23.93902779], [68.42903137, 23.93958282], [68.42930603, 23.93958282], [68.42930603, 23.94042015], [68.42958069, 23.94041634], [68.42958069, 23.94069481], [68.42986298, 23.9406929], [68.42986298, 23.94098091], [68.43013763, 23.94097137], [68.43013763, 23.94208336], [68.43041992, 23.94207954], [68.43041992, 23.9426403], [68.43068695, 23.9426403], [68.43068695, 23.94320107], [68.43096924, 23.94320107], [68.43096924, 23.94375038], [68.43125153, 23.94375038], [68.43125153, 23.94402695], [68.43180847, 23.94402122], [68.43180847, 23.94431114], [68.43208313, 23.94431114], [68.43208313, 23.94486046], [68.43235779, 23.94486046], [68.43235779, 23.94597244], [68.43264008, 23.94597054], [68.43264008, 23.94680977], [68.43291473, 23.94680786], [68.43291473, 23.94708252], [68.43319702, 23.94708061], [68.43319702, 23.94736099], [68.43347168, 23.94736099], [68.43347168, 23.94753265], [68.43345642, 23.94791985], [68.43374634, 23.94791985], [68.43374634, 23.94874954], [68.43402863, 23.94874954], [68.43402863, 23.94986153], [68.43430328, 23.94986153], [68.43430328, 23.9509716], [68.4345932, 23.9509716], [68.4345932, 23.95153046], [68.43486023, 23.95152855], [68.43486023, 23.95236015], [68.43514252, 23.95236015], [68.43514252, 23.95430946], [68.43541718, 23.95430946], [68.43541718, 23.95486069], [68.43569183, 23.95486069], [68.43569183, 23.95514107], [68.43597412, 23.95513916], [68.43597412, 23.95569229], [68.43624878, 23.95569038], [68.43624878, 23.95625114], [68.43653107, 23.95625114], [68.43653107, 23.95681], [68.43680573, 23.95680428], [68.43680573, 23.95736122], [68.43708038, 23.95736122], [68.43708038, 23.95763969], [68.43736267, 23.95763969], [68.43736267, 23.95792007], [68.43763733, 23.95791435], [68.43763733, 23.95819664], [68.43791962, 23.95819664], [68.43791962, 23.9584713], [68.43818665, 23.95846939], [68.43818665, 23.95874977], [68.43846893, 23.95874977], [68.43846893, 23.95902634], [68.43875122, 23.95902634], [68.43875122, 23.95930672], [68.43902588, 23.95930672], [68.43902588, 23.95958328], [68.43930817, 23.95958328], [68.43930817, 23.95986176], [68.43959045, 23.95985985], [68.43959045, 23.96014023], [68.43985748, 23.96014023], [68.43985748, 23.96042061], [68.44013977, 23.96042061], [68.44013977, 23.96069908], [68.4404068, 23.96069908], [68.4404068, 23.96125031], [68.44069672, 23.96125031], [68.44069672, 23.96153069], [68.44097137, 23.96153069], [68.44097137, 23.96180916], [68.44124603, 23.96180916], [68.44124603, 23.96209145], [68.44152832, 23.96209145], [68.44152832, 23.96264076], [68.4420929, 23.96264076], [68.4420929, 23.96209145], [68.44291687, 23.96209145], [68.44291687, 23.96180916], [68.44374847, 23.96180916], [68.44374847, 23.96153069], [68.44431305, 23.96153069], [68.44431305, 23.96125031], [68.44513702, 23.96125031], [68.44513702, 23.96096992], [68.44569397, 23.96097183], [68.44569397, 23.96069527], [68.44625092, 23.96069908], [68.44625092, 23.96042061], [68.4465332, 23.96042061], [68.4465332, 23.96014023], [68.44708252, 23.96014023], [68.44708252, 23.95985985], [68.44763947, 23.95986176], [68.44763947, 23.95958328], [68.44902802, 23.95958328], [68.44902802, 23.96097183], [68.44819641, 23.96096992], [68.44819641, 23.96125031], [68.44735718, 23.96125031], [68.44735718, 23.96153069], [68.44680786, 23.96153069], [68.44680786, 23.96180916], [68.44625092, 23.96180916], [68.44625092, 23.96209145], [68.44596863, 23.96209145], [68.44596863, 23.96236038], [68.44541931, 23.96236038], [68.44541931, 23.96264076], [68.44513702, 23.96264076], [68.44513702, 23.96291924], [68.44458008, 23.96291733], [68.44458008, 23.96319389], [68.44403076, 23.96319389], [68.44403076, 23.96347237], [68.44374847, 23.96347046], [68.44374847, 23.96375084], [68.44348907, 23.9638195], [68.44346619, 23.96402931], [68.44262695, 23.96402931], [68.44262695, 23.96486092], [68.44291687, 23.96486092], [68.44291687, 23.9659729], [68.44319153, 23.9659729], [68.44319153, 23.96708107], [68.44346619, 23.96708107], [68.44346619, 23.96763992], [68.44374847, 23.96763992], [68.44374847, 23.96875], [68.44403076, 23.96875], [68.44403076, 23.96903038], [68.44430542, 23.96902847], [68.44430542, 23.97208595], [68.44458008, 23.97208023], [68.44458008, 23.97236061], [68.44486237, 23.97236061], [68.44486237, 23.97291946], [68.44513702, 23.97291756], [68.44513702, 23.9734726], [68.44541931, 23.97347069], [68.44541931, 23.97402954], [68.44569397, 23.97402954], [68.44569397, 23.97458267], [68.44596863, 23.97458076], [68.44596863, 23.97513962], [68.44625092, 23.97513962], [68.44625092, 23.97624969], [68.4465332, 23.97624969], [68.4465332, 23.97709274], [68.44680786, 23.97708321], [68.44680786, 23.97736168], [68.44708252, 23.97736168], [68.44708252, 23.97820282], [68.44735718, 23.97820282], [68.44735718, 23.97903061], [68.44763947, 23.9790287], [68.44763947, 23.98069382], [68.44791412, 23.98069382], [68.44791412, 23.98097229], [68.44819641, 23.98097038], [68.44819641, 23.98125076], [68.44876099, 23.98125076], [68.44876099, 23.98153114], [68.44930267, 23.98153114], [68.44930267, 23.98180962], [68.44958496, 23.9818058], [68.44958496, 23.98208237], [68.44985962, 23.98208046], [68.44985962, 23.98236084], [68.45041656, 23.98236084], [68.45041656, 23.98264122], [68.45069122, 23.98264122], [68.45069122, 23.98291969], [68.45097351, 23.98291588], [68.45097351, 23.98319435], [68.45124817, 23.98319435], [68.45124817, 23.98347282], [68.45153046, 23.98347092], [68.45153046, 23.98374939], [68.45182037, 23.98374939], [68.45182037, 23.98402977], [68.45207977, 23.98402977], [68.45207977, 23.98431015], [68.45236206, 23.98430443], [68.45236206, 23.9845829], [68.45263672, 23.9845829], [68.45263672, 23.98486137], [68.45291901, 23.98485947], [68.45291901, 23.98513985], [68.45375061, 23.98513985], [68.45375061, 23.98542023], [68.45402527, 23.98541451], [68.45402527, 23.98597145], [68.45430756, 23.98596954], [68.45430756, 23.9865303], [68.45485687, 23.9865303], [68.45485687, 23.98681068], [68.45541382, 23.98680687], [68.45541382, 23.98708344], [68.45569611, 23.98708344], [68.45569611, 23.98736191], [68.45625305, 23.98735809], [68.45625305, 23.98764038], [68.45652771, 23.98764038], [68.45652771, 23.98792076], [68.45680237, 23.98791885], [68.45680237, 23.9881897], [68.45708466, 23.98819542], [68.45708466, 23.98847198], [68.45735931, 23.98846817], [68.45735931, 23.98875046], [68.45762634, 23.98875046], [68.45762634, 23.98903084], [68.45791626, 23.98903084], [68.45791626, 23.98932266], [68.45819092, 23.9893055], [68.45819092, 23.98958397], [68.45847321, 23.98957825], [68.45847321, 23.98986053], [68.45874786, 23.98986053], [68.45874786, 23.99014091], [68.45903015, 23.99014091], [68.45903015, 23.99041939], [68.45930481, 23.99041748], [68.45930481, 23.99069405], [68.45986176, 23.99069405], [68.45986176, 23.99097252], [68.4604187, 23.99097061], [68.4604187, 23.99124908], [68.46125031, 23.99124908], [68.46125031, 23.99152946], [68.46180725, 23.99152946], [68.46180725, 23.99181175], [68.4631958, 23.99180603], [68.4631958, 23.9920826], [68.4668045, 23.9920826], [68.4668045, 23.99180603], [68.46930695, 23.99180603], [68.46930695, 23.9920826], [68.47041321, 23.99206924], [68.47041321, 23.99236107], [68.4734726, 23.99236107], [68.4734726, 23.99263954], [68.47429657, 23.99263954], [68.47429657, 23.99236107], [68.47486115, 23.99236107], [68.47486115, 23.99206924], [68.47541809, 23.99206924], [68.47541809, 23.99236107], [68.4770813, 23.99236107], [68.4770813, 23.99263954], [68.48208618, 23.99263954], [68.48208618, 23.99236107], [68.48458099, 23.99236107], [68.48458099, 23.99206924], [68.48652649, 23.9920826], [68.48652649, 23.99180603], [68.48680878, 23.99181175], [68.48680878, 23.99152946], [68.48707581, 23.99152946], [68.48707581, 23.99124908], [68.48735809, 23.99124908], [68.48735809, 23.99097061], [68.48764038, 23.99097252], [68.48764038, 23.99069405], [68.48791504, 23.99069405], [68.48791504, 23.99041748], [68.48819733, 23.99041939], [68.48819733, 23.99014091], [68.48847198, 23.99014091], [68.48847198, 23.98986053], [68.48874664, 23.98986053], [68.48874664, 23.98957825], [68.48902893, 23.98958397], [68.48902893, 23.9893055], [68.48929596, 23.98932266], [68.48929596, 23.98903084], [68.48958588, 23.98903084], [68.48958588, 23.98846817], [68.48986053, 23.98847198], [68.48986053, 23.98819542], [68.49014282, 23.9881897], [68.49013519, 23.98791885], [68.49041748, 23.98792076], [68.49041748, 23.98764038], [68.49069977, 23.98764038], [68.49069977, 23.98735809], [68.49097443, 23.98736191], [68.49097443, 23.98708344], [68.49124908, 23.98708344], [68.49124908, 23.98680687], [68.49153137, 23.98681068], [68.49153137, 23.9865303], [68.49180603, 23.9865303], [68.49180603, 23.98625946], [68.49208069, 23.98625946], [68.49208069, 23.98596954], [68.49236298, 23.98597145], [68.49236298, 23.98569679], [68.49263763, 23.98569679], [68.49263763, 23.98541451], [68.49291992, 23.98542023], [68.49291992, 23.98513985], [68.49318695, 23.98513985], [68.49318695, 23.98485947], [68.49346924, 23.98486137], [68.49346924, 23.9845829], [68.49375153, 23.9845829], [68.49375153, 23.98430443], [68.49402618, 23.98431015], [68.49402618, 23.98402977], [68.49430847, 23.98402977], [68.49430847, 23.98374939], [68.49458313, 23.98374939], [68.49458313, 23.98347092], [68.49485779, 23.98347282], [68.49485779, 23.98291588], [68.49514008, 23.98291969], [68.49514008, 23.98264122], [68.49569702, 23.98264122], [68.49569702, 23.98236084], [68.49597168, 23.98236084], [68.49597168, 23.98208046], [68.49624634, 23.98208237], [68.49624634, 23.9818058], [68.49652863, 23.98180962], [68.49652863, 23.98153114], [68.49680328, 23.98153114], [68.49680328, 23.98125076], [68.49736023, 23.98125076], [68.49736023, 23.98097038], [68.49764252, 23.98097229], [68.49764252, 23.98069382], [68.49791718, 23.98069382], [68.49791718, 23.98041725], [68.49819183, 23.98042107], [68.49819183, 23.98013115], [68.49930573, 23.98013878], [68.49930573, 23.97986031], [68.49986267, 23.97986031], [68.49986267, 23.97958374], [68.50069427, 23.97958374], [68.50069427, 23.97930527], [68.50125122, 23.9793129], [68.50125122, 23.97903061], [68.50152588, 23.97903061], [68.50152588, 23.97875023], [68.50208282, 23.97875023], [68.50208282, 23.97847176], [68.50235748, 23.97847176], [68.50235748, 23.97763824], [68.50263977, 23.97764015], [68.50263977, 23.97541809], [68.50235748, 23.97541809], [68.50235748, 23.97458076], [68.50208282, 23.97458267], [68.50208282, 23.97374725], [68.50180817, 23.97375107], [68.50180817, 23.97264099], [68.50152588, 23.97264099], [68.50152588, 23.97180939], [68.50125122, 23.97180939], [68.50125122, 23.97125053], [68.50096893, 23.97125053], [68.50096893, 23.97068977], [68.50041962, 23.97069359], [68.50041962, 23.97041512], [68.50013733, 23.97042084], [68.50013733, 23.97014046], [68.49958038, 23.97014046], [68.49958038, 23.96986008], [68.49930573, 23.96986198], [68.49930573, 23.96958351], [68.49903107, 23.96958351], [68.49903107, 23.96930313], [68.49874878, 23.96931076], [68.49874878, 23.96903038], [68.49846649, 23.96903038], [68.49846649, 23.96875], [68.49819183, 23.96875], [68.49819183, 23.96819115], [68.49791718, 23.96819305], [68.49791718, 23.96791649], [68.49764252, 23.9679203], [68.49764252, 23.96735954], [68.49736023, 23.96736145], [68.49736023, 23.96708107], [68.49680328, 23.96708107], [68.49680328, 23.96652794], [68.49652863, 23.96652985], [68.49652863, 23.9659729], [68.49624634, 23.9659729], [68.49624634, 23.96347237], [68.49597168, 23.96352005], [68.49597168, 23.96236038], [68.49569702, 23.96236038], [68.49569702, 23.95957947], [68.49597168, 23.95958328], [68.49597168, 23.95819664], [68.49624634, 23.95819664], [68.49624634, 23.95791435], [68.49597168, 23.95792007], [68.49597168, 23.95763969], [68.49624634, 23.95763969], [68.49624634, 23.95681], [68.49652863, 23.95681], [68.49652863, 23.95569038], [68.49680328, 23.95569229], [68.49680328, 23.95486069], [68.4970932, 23.95486069], [68.49708557, 23.95402718], [68.49736023, 23.9540329], [68.49736023, 23.95319176], [68.49764252, 23.95319366], [68.49764252, 23.95236015], [68.49791718, 23.95236015], [68.49791718, 23.95180511], [68.49819183, 23.95181274], [68.49819183, 23.95125008], [68.49846649, 23.95125008], [68.49846649, 23.95070267], [68.49874878, 23.95070267], [68.49874878, 23.95014954], [68.49903107, 23.95014954], [68.49903107, 23.94985962], [68.49930573, 23.94986153], [68.49930573, 23.94948959], [68.49930573, 23.94930649], [68.49958038, 23.9493084], [68.49958038, 23.94874954], [68.4998703, 23.94874954], [68.49986267, 23.94847298], [68.50013733, 23.94847298], [68.50013733, 23.9481945], [68.50069427, 23.9481945], [68.50069427, 23.94791794], [68.50096893, 23.94791985], [68.50096893, 23.94763947], [68.50125122, 23.94763947], [68.50125122, 23.94736099], [68.50152588, 23.94736099], [68.50152588, 23.94708061], [68.50180817, 23.94708252], [68.50180817, 23.94680786], [68.50208282, 23.94680977], [68.50208282, 23.94652939], [68.50235748, 23.94652939], [68.50235748, 23.94625092], [68.50263977, 23.94625092], [68.50263977, 23.94597054], [68.50319672, 23.94597244], [68.50319672, 23.94569588], [68.50402832, 23.94569588], [68.50402832, 23.9454155], [68.5045929, 23.94542122], [68.5045929, 23.94514084], [68.50485992, 23.94514084], [68.50485992, 23.94486046], [68.50567627, 23.94486046], [68.50567627, 23.94458008], [68.50653076, 23.9445858], [68.50653076, 23.94430733], [68.50708008, 23.94431114], [68.50708008, 23.94402122], [68.50846863, 23.94402695], [68.50846863, 23.94375038], [68.50930786, 23.94375038], [68.50930786, 23.94347], [68.51097107, 23.94347191], [68.51097107, 23.94319344], [68.51264191, 23.94320107], [68.51264191, 23.94292068], [68.51319122, 23.94292068], [68.51319122, 23.9426403], [68.51403046, 23.9426403], [68.51403046, 23.94235992], [68.51457977, 23.94235992], [68.51457977, 23.9426403], [68.51541901, 23.9426403], [68.51541901, 23.94235992], [68.51652527, 23.94236183], [68.51652527, 23.94208336], [68.5173645, 23.94208336], [68.5173645, 23.94180489], [68.51763916, 23.94180489], [68.51763916, 23.94152832], [68.51790619, 23.94153023], [68.51790619, 23.94124985], [68.51819611, 23.94124985], [68.51819611, 23.94098091], [68.51847076, 23.94098091], [68.51847076, 23.9406929], [68.51875305, 23.94069481], [68.51875305, 23.93902779], [68.51902771, 23.93902969], [68.51902771, 23.93818855], [68.51652527, 23.93819427], [68.51652527, 23.9379158], [68.51625061, 23.9379158], [68.51625061, 23.93819427], [68.51513672, 23.93819427], [68.51513672, 23.93847275], [68.51457977, 23.93847275], [68.51457977, 23.93875122], [68.51403046, 23.93875122], [68.51403046, 23.93902969], [68.51374817, 23.93902969], [68.51374817, 23.93931007], [68.51180267, 23.93930626], [68.51180267, 23.93958282], [68.51125336, 23.93958282], [68.51125336, 23.9398613], [68.51040649, 23.93985939], [68.51040649, 23.94013977], [68.50930786, 23.94013977], [68.50930786, 23.94042015], [68.50875092, 23.94041634], [68.50875092, 23.94069481], [68.50818634, 23.9406929], [68.50818634, 23.94098091], [68.50791931, 23.94098091], [68.50791931, 23.94124985], [68.50736237, 23.94124985], [68.50736237, 23.94153023], [68.50680542, 23.94152832], [68.50680542, 23.94180489], [68.50569153, 23.94180489], [68.50569153, 23.94041634], [68.50596619, 23.94042015], [68.50596619, 23.94013977], [68.50681305, 23.94013977], [68.50680542, 23.9398613], [68.50736237, 23.9398613], [68.50736237, 23.93958282], [68.50763702, 23.93958282], [68.50763702, 23.93930626], [68.50818634, 23.93931007], [68.50818634, 23.93902969], [68.50874329, 23.93902969], [68.50874329, 23.93875122], [68.50985718, 23.93875122], [68.50985718, 23.93847275], [68.51069641, 23.93847275], [68.51069641, 23.93819427], [68.51125336, 23.93819427], [68.51125336, 23.9379158], [68.51319122, 23.93791962], [68.51319122, 23.93763924], [68.51346588, 23.93763924], [68.51346588, 23.93736076], [68.51403046, 23.93736076], [68.51403046, 23.93707848], [68.51457977, 23.9370842], [68.51457977, 23.93680573], [68.51568604, 23.93680954], [68.51568604, 23.93652916], [68.51680756, 23.93652916], [68.51680756, 23.93625069], [68.51708221, 23.93625069], [68.51708221, 23.9359684], [68.51819611, 23.93597221], [68.51819611, 23.93569374], [68.51847076, 23.93569374], [68.51847076, 23.92430496], [68.51819611, 23.92431259], [68.51819611, 23.9240303], [68.51790619, 23.9240303], [68.51790619, 23.92375183], [68.51735687, 23.92375183], [68.51735687, 23.92347145], [68.51708221, 23.92347145], [68.51708221, 23.92319489], [68.51680756, 23.92319489], [68.51680756, 23.92291641], [68.5165329, 23.92291832], [68.5165329, 23.92263985], [68.51625061, 23.92263985], [68.51625061, 23.92235756], [68.51597595, 23.92236137], [68.51597595, 23.9220829], [68.51569366, 23.9220829], [68.51569366, 23.92180634], [68.51513672, 23.92180824], [68.51513672, 23.92152977], [68.51486969, 23.92152977], [68.51486969, 23.92124939], [68.51457977, 23.92124939], [68.51457977, 23.92097092], [68.51430511, 23.92097282], [68.51430511, 23.92069435], [68.51403046, 23.92069435], [68.51403046, 23.92041779], [68.51346588, 23.92041969], [68.51346588, 23.92014122], [68.51319122, 23.92014122], [68.51319122, 23.9198494], [68.51264191, 23.9198494], [68.51264191, 23.92041969], [68.51235962, 23.92041779], [68.51235962, 23.92069435], [68.51208496, 23.92069435], [68.51208496, 23.92097282], [68.51152802, 23.92097092], [68.51152802, 23.92180824], [68.51125336, 23.92180634], [68.51125336, 23.92319489], [68.51097107, 23.92319489], [68.51097107, 23.92347145], [68.51013947, 23.92347145], [68.51013947, 23.92319489], [68.50986481, 23.92319489], [68.50986481, 23.92124939], [68.51013947, 23.92124939], [68.51013947, 23.92041969], [68.51040649, 23.92041969], [68.51040649, 23.91958046], [68.51069641, 23.91958427], [68.51069641, 23.91902542], [68.51097107, 23.91903114], [68.51097107, 23.91847038], [68.51125336, 23.91847229], [68.51125336, 23.91791534], [68.51097107, 23.91792107], [68.51097107, 23.91681099], [68.51069641, 23.91681099], [68.51069641, 23.91653061], [68.51040649, 23.91653061], [68.51040649, 23.91625023], [68.51013947, 23.91625023], [68.51013947, 23.91570091], [68.50985718, 23.91570091], [68.50985718, 23.91542053], [68.50958252, 23.91542053], [68.50958252, 23.91514015], [68.50930786, 23.91514015], [68.50930786, 23.91485977], [68.50902557, 23.91486168], [68.50902557, 23.91458321], [68.50875092, 23.91458321], [68.50875092, 23.91402817], [68.50846863, 23.91403961], [68.50846863, 23.91374969], [68.50818634, 23.91374969], [68.50818634, 23.91347122], [68.50791931, 23.91347122], [68.50791931, 23.91319466], [68.50763702, 23.91319466], [68.50763702, 23.91291618], [68.50736237, 23.91292191], [68.50736237, 23.91263962], [68.50708008, 23.91263962], [68.50708008, 23.91208267], [68.50680542, 23.91208267], [68.50680542, 23.91180611], [68.50653076, 23.91181183], [68.50653076, 23.91152954], [68.50624847, 23.91152954], [68.50624847, 23.91124916], [68.50596619, 23.91124916], [68.50596619, 23.9106884], [68.50569153, 23.91069412], [68.50569153, 23.91013908], [68.50541687, 23.91013908], [68.50541687, 23.90957832], [68.50514221, 23.90958405], [68.50514221, 23.90930557], [68.50485992, 23.90930939], [68.50485992, 23.90875053], [68.50458527, 23.90875053], [68.50458527, 23.90847206], [68.50375366, 23.90847206], [68.50375366, 23.90819359], [68.50347137, 23.90819359], [68.50347137, 23.90791893], [68.50319672, 23.90791893], [68.50319672, 23.90736198], [68.50291443, 23.90736198], [68.50291443, 23.90708351], [68.50235748, 23.90708351], [68.50235748, 23.90680695], [68.50096893, 23.90681076], [68.50096893, 23.90653038], [68.4998703, 23.90653038], [68.4998703, 23.90625], [68.49903107, 23.90625], [68.49903107, 23.90596962], [68.49847412, 23.90597153], [68.49847412, 23.90569687], [68.49819183, 23.90570068], [68.49819183, 23.9054203], [68.49680328, 23.9054203], [68.49680328, 23.90513992], [68.49597168, 23.90513992], [68.49597168, 23.90485001], [68.49514008, 23.90486145], [68.49514008, 23.90458298], [68.49375153, 23.90458298], [68.49375153, 23.9043045], [68.49346924, 23.90431023], [68.49346924, 23.90402985], [68.49318695, 23.90402985], [68.49318695, 23.90374947], [68.49263763, 23.90374947], [68.49263763, 23.90347099], [68.49180603, 23.90347481], [68.49180603, 23.90319443], [68.49097443, 23.90319443], [68.49097443, 23.90291405], [68.49041748, 23.90291977], [68.49041748, 23.90263939], [68.48986053, 23.90263939], [68.48986053, 23.90236092], [68.48958588, 23.90236092], [68.48958588, 23.90208054], [68.48902893, 23.90208244], [68.48902893, 23.90180588], [68.48847198, 23.90180969], [68.48847198, 23.90153122], [68.4879303, 23.90153122], [68.4879303, 23.90125084], [68.48764038, 23.90125084], [68.48764038, 23.90097046], [68.48735809, 23.90097237], [68.48735809, 23.90069389], [68.48708344, 23.90069389], [68.48708344, 23.90041733], [68.48680878, 23.90042114], [68.48680878, 23.90014076], [68.48652649, 23.90014076], [68.48652649, 23.89986038], [68.48625183, 23.89986038], [68.48625183, 23.89958191], [68.48596954, 23.89958382], [68.48596954, 23.89930534], [68.48568726, 23.89931107], [68.48568726, 23.89903259], [68.48542023, 23.89903259], [68.48542023, 23.89847183], [68.48513794, 23.89847183], [68.48513794, 23.89819527], [68.48486328, 23.8982029], [68.48486328, 23.89764023], [68.48458099, 23.89764023], [68.48458099, 23.89736176], [68.48430634, 23.89736176], [68.48430634, 23.89680481], [68.48402405, 23.89680481], [68.48402405, 23.89652824], [68.48374939, 23.89652824], [68.48374939, 23.89596748], [68.48347473, 23.8959713], [68.48347473, 23.89541626], [68.48319244, 23.89541817], [68.48319244, 23.89486122], [68.48291779, 23.89486122], [68.48291779, 23.89458084], [68.4826355, 23.89458275], [68.4826355, 23.89402962], [68.48236084, 23.89402962], [68.48236084, 23.89347076], [68.48208618, 23.89347267], [68.48208618, 23.8931942], [68.48180389, 23.8931942], [68.48180389, 23.89263916], [68.48152924, 23.89264107], [68.48152924, 23.89236069], [68.48124695, 23.89236069], [68.48124695, 23.89180946], [68.48097229, 23.89180946], [68.48097229, 23.89153099], [68.48069763, 23.89153099], [68.48069763, 23.89097023], [68.48041534, 23.89097214], [68.48041534, 23.89041519], [68.47958374, 23.89041519], [68.47958374, 23.89069366], [68.47875214, 23.89069366], [68.47875214, 23.89097214], [68.47735596, 23.89097023], [68.47735596, 23.89125061], [68.47651672, 23.89125061], [68.47651672, 23.89153099], [68.47541809, 23.89153099], [68.47541809, 23.89180946], [68.4743042, 23.89180756], [68.4743042, 23.89208412], [68.4734726, 23.89208031], [68.4734726, 23.89236069], [68.47292328, 23.89236069], [68.47292328, 23.89264107], [68.47208405, 23.89263916], [68.47208405, 23.89291763], [68.47125244, 23.89291763], [68.47125244, 23.8931942], [68.47097015, 23.8931942], [68.47097015, 23.89347267], [68.47070313, 23.89347076], [68.47070313, 23.89375114], [68.47041321, 23.89375114], [68.47041321, 23.89402962], [68.46985626, 23.89402962], [68.46985626, 23.89430809], [68.46930695, 23.89430618], [68.46930695, 23.89458275], [68.46875, 23.89458084], [68.46875, 23.89486122], [68.46763611, 23.89486122], [68.46763611, 23.89458084], [68.46736145, 23.89458275], [68.46736145, 23.89374733], [68.46763611, 23.89375114], [68.46763611, 23.89347076], [68.46819305, 23.89347267], [68.46819305, 23.8931942], [68.46875, 23.8931942], [68.46875, 23.89291763], [68.46902466, 23.89291763], [68.46902466, 23.89263916], [68.46956635, 23.89264107], [68.46956635, 23.89236069], [68.47013855, 23.89236069], [68.47013855, 23.89208031], [68.47041321, 23.89208412], [68.47041321, 23.89180756], [68.47070313, 23.89180946], [68.47070313, 23.89153099], [68.4715271, 23.89153099], [68.4715271, 23.89125061], [68.4723587, 23.89125061], [68.4723587, 23.89097023], [68.47291565, 23.89097214], [68.47291565, 23.89069366], [68.4734726, 23.89069366], [68.4734726, 23.89041519], [68.47486115, 23.89042091], [68.47486115, 23.89014053], [68.4759903, 23.89014053], [68.4759903, 23.88986969], [68.47680664, 23.88986969], [68.47680664, 23.88957977], [68.47819519, 23.88958359], [68.47819519, 23.88930321], [68.47875977, 23.88931084], [68.47875977, 23.88903046], [68.47957611, 23.88903046], [68.47957611, 23.88875008], [68.47930908, 23.88875008], [68.47930908, 23.88820076]]], [[[68.51457977, 23.94958305], [68.5256958, 23.94952965], [68.5256958, 23.94930649], [68.52597046, 23.94930077], [68.52597046, 23.94847298], [68.5256958, 23.94847298], [68.5256958, 23.9481945], [68.52513885, 23.9481945], [68.52513885, 23.94763947], [68.52485657, 23.94763947], [68.52485657, 23.94736099], [68.52458191, 23.94736099], [68.52458191, 23.94708061], [68.52430725, 23.94708252], [68.52430725, 23.94680786], [68.52375031, 23.94680977], [68.52375031, 23.94625092], [68.52347565, 23.94625092], [68.52347565, 23.94597244], [68.52319336, 23.94597244], [68.52319336, 23.94569588], [68.5229187, 23.94569588], [68.5229187, 23.9454155], [68.52153015, 23.9454155], [68.52153015, 23.94597244], [68.52124786, 23.94597054], [68.52124786, 23.94625092], [68.52068329, 23.94625092], [68.52068329, 23.94652939], [68.51985931, 23.94652939], [68.51985931, 23.94680977], [68.51958466, 23.94680786], [68.51958466, 23.94708252], [68.51930237, 23.94708061], [68.51930237, 23.94736099], [68.51875305, 23.94736099], [68.51875305, 23.94763947], [68.51847076, 23.94763947], [68.51847076, 23.94791985], [68.51791382, 23.94791794], [68.51791382, 23.9481945], [68.51763916, 23.9481945], [68.51763916, 23.94847298], [68.51680756, 23.94847107], [68.51680756, 23.94874954], [68.51597595, 23.94874954], [68.51597595, 23.94902992], [68.51541901, 23.94902992], [68.51541901, 23.9493084], [68.51457977, 23.94930649], [68.51457977, 23.94958305]]], [[[70.45513916, 22.99570084], [70.45513916, 22.99430084], [70.4548645, 22.99430466], [70.4548645, 22.99152756], [70.45458221, 22.99152946], [70.45458221, 22.99097061], [70.45430756, 22.99097061], [70.45430756, 22.99069214], [70.45458221, 22.99069214], [70.45458221, 22.99014091], [70.45430756, 22.99014282], [70.45430756, 22.98984909], [70.45402527, 22.98986053], [70.45402527, 22.9893055], [70.45375061, 22.98931122], [70.45375061, 22.98903275], [70.45347595, 22.98903275], [70.45347595, 22.98846817], [70.45319366, 22.98847008], [70.45319366, 22.98819351], [70.45291901, 22.98819351], [70.45291901, 22.98791695], [70.45236206, 22.98792076], [70.45236206, 22.98763847], [70.45207977, 22.98763847], [70.45207977, 22.98735809], [70.45180511, 22.98736191], [70.45180511, 22.98680496], [70.45153046, 22.98681068], [70.45153046, 22.9865284], [70.45124817, 22.9865284], [70.45124817, 22.98624992], [70.45096588, 22.98624992], [70.45096588, 22.98596954], [70.45041656, 22.98597145], [70.45041656, 22.98569489], [70.45014191, 22.98569489], [70.45014191, 22.98541641], [70.44959259, 22.98541832], [70.44959259, 22.98513985], [70.44930267, 22.98513985], [70.44930267, 22.98485947], [70.44902802, 22.98486137], [70.44902802, 22.9845829], [70.44847107, 22.9845829], [70.44847107, 22.98430634], [70.44819641, 22.98431015], [70.44819641, 22.98404121], [70.44763947, 22.98404121], [70.44763947, 22.98374939], [70.44708252, 22.98374939], [70.44708252, 22.98347282], [70.44680786, 22.98347282], [70.44680786, 22.98319435], [70.44625092, 22.98319435], [70.44625092, 22.98291779], [70.44596863, 22.98291969], [70.44596863, 22.98264122], [70.44541931, 22.98264122], [70.44541931, 22.98236084], [70.44513702, 22.98236084], [70.44513702, 22.98208046], [70.44486237, 22.98208237], [70.44486237, 22.9818058], [70.44431305, 22.98180962], [70.44431305, 22.98153114], [70.44403076, 22.98153114], [70.44403076, 22.98125076], [70.44346619, 22.98125076], [70.44346619, 22.98097992], [70.44319153, 22.98097992], [70.44319153, 22.98069], [70.44291687, 22.98069572], [70.44291687, 22.98041725], [70.44264221, 22.98042107], [70.44264221, 22.98014069], [70.4420929, 22.98014069], [70.4420929, 22.97986031], [70.44152832, 22.97986031], [70.44152832, 22.97957993], [70.44097137, 22.97958565], [70.44097137, 22.97930527], [70.4404068, 22.97931099], [70.4404068, 22.97903061], [70.43985748, 22.97903061], [70.43985748, 22.97875023], [70.43930817, 22.97875023], [70.43930817, 22.97846985], [70.43875122, 22.97847366], [70.43875122, 22.97819519], [70.43763733, 22.97819519], [70.43763733, 22.97847366], [70.43374634, 22.97846985], [70.43374634, 22.97875023], [70.43264008, 22.97875023], [70.43264008, 22.97958565], [70.4329071, 22.97957993], [70.4329071, 22.98014069], [70.43319702, 22.98014069], [70.43319702, 22.98042107], [70.43347168, 22.98041725], [70.43347168, 22.98069572], [70.43374634, 22.98069], [70.43374634, 22.98097992], [70.43402863, 22.98097992], [70.43402863, 22.98180962], [70.43430328, 22.98180962], [70.43430328, 22.98236084], [70.43486023, 22.98236084], [70.43486023, 22.98264122], [70.43515015, 22.98264122], [70.43515015, 22.98291969], [70.43541718, 22.98291779], [70.43541718, 22.98319435], [70.43569183, 22.98319054], [70.43569183, 22.98374939], [70.43653107, 22.98374939], [70.43653107, 22.98404121], [70.43708038, 22.98404121], [70.43708038, 22.98431015], [70.43763733, 22.98430634], [70.43763733, 22.9845829], [70.43791962, 22.9845829], [70.43791962, 22.98486137], [70.43846893, 22.98485947], [70.43846893, 22.98513985], [70.43902588, 22.98513985], [70.43902588, 22.98541832], [70.43930817, 22.98541641], [70.43930817, 22.98569489], [70.43958282, 22.98569489], [70.43958282, 22.98597145], [70.43985748, 22.98596954], [70.43985748, 22.98624992], [70.44013977, 22.98624992], [70.44013977, 22.9865284], [70.44069672, 22.9865284], [70.44069672, 22.98681068], [70.44097137, 22.98680496], [70.44097137, 22.98708344], [70.44125366, 22.98708344], [70.44125366, 22.98736191], [70.4420929, 22.98735809], [70.4420929, 22.98763847], [70.44264221, 22.98763847], [70.44264221, 22.98792076], [70.44291687, 22.98791695], [70.44291687, 22.9881897], [70.44347382, 22.98819542], [70.44347382, 22.98847008], [70.44374847, 22.98846817], [70.44374847, 22.98875237], [70.44403076, 22.98875237], [70.44403076, 22.98903275], [70.44458008, 22.98903275], [70.44458008, 22.98931122], [70.44513702, 22.9893055], [70.44513702, 22.98958206], [70.44541931, 22.98958206], [70.44541931, 22.98986053], [70.44596863, 22.98984909], [70.44596863, 22.99014282], [70.44680786, 22.99014282], [70.44680786, 22.99041939], [70.44736481, 22.99041748], [70.44736481, 22.99069214], [70.44763947, 22.99069023], [70.44763947, 22.9912529], [70.44819641, 22.9912529], [70.44819641, 22.99152946], [70.44847107, 22.99152946], [70.44847107, 22.99180984], [70.44875336, 22.99180984], [70.44875336, 22.99152946], [70.44902802, 22.99152946], [70.44902802, 22.99180984], [70.44930267, 22.99180603], [70.44930267, 22.9920845], [70.44958496, 22.9920845], [70.44958496, 22.99236107], [70.44985962, 22.99236107], [70.44985962, 22.99263954], [70.45014954, 22.99263954], [70.45014954, 22.99291992], [70.45097351, 22.99291611], [70.45097351, 22.99319458], [70.45153046, 22.99319458], [70.45153046, 22.99347305], [70.45180511, 22.99347305], [70.45180511, 22.99374962], [70.45207977, 22.99374962], [70.45207977, 22.99403], [70.45263672, 22.99402809], [70.45263672, 22.99430466], [70.45319366, 22.99430466], [70.45319366, 22.99458313], [70.45347595, 22.99458313], [70.45347595, 22.9948616], [70.45375061, 22.9948597], [70.45375061, 22.99514008], [70.4540329, 22.99514008], [70.4540329, 22.99542046], [70.45485687, 22.99542046], [70.45485687, 22.99570084], [70.45513916, 22.99570084]]], [[[70.44124603, 23.04624939], [70.44124603, 23.04681015], [70.44152832, 23.04681015], [70.44152832, 23.04709053], [70.44180298, 23.04708481], [70.44180298, 23.04736137], [70.4420929, 23.04735947], [70.4420929, 23.04763985], [70.44235992, 23.04763794], [70.44235992, 23.04819679], [70.44264221, 23.04819679], [70.44264221, 23.04847145], [70.44291687, 23.04846954], [70.44291687, 23.04874992], [70.44346619, 23.04874992], [70.44346619, 23.0490303], [70.44403076, 23.0490303], [70.44403076, 23.04931068], [70.44430542, 23.04930687], [70.44430542, 23.04986191], [70.44458008, 23.04986191], [70.44458008, 23.05013847], [70.44486237, 23.05013084], [70.44486237, 23.05042076], [70.44541931, 23.05041695], [70.44541931, 23.05069351], [70.44596863, 23.05069351], [70.44596863, 23.05097198], [70.44652557, 23.05097198], [70.44652557, 23.05125046], [70.44709015, 23.05125046], [70.44709015, 23.05153084], [70.44763947, 23.05153084], [70.44763947, 23.05181122], [70.44819641, 23.0518055], [70.44819641, 23.05208397], [70.44847107, 23.05208397], [70.44847107, 23.0518055], [70.44875336, 23.05181122], [70.44875336, 23.05125046], [70.44902802, 23.05125046], [70.44902802, 23.05097008], [70.44875336, 23.05097198], [70.44875336, 23.05041695], [70.44847107, 23.05042076], [70.44847107, 23.05022812], [70.44847107, 23.05013847], [70.44829559, 23.05013847], [70.44819641, 23.05013847], [70.44819641, 23.04986191], [70.44791412, 23.04986191], [70.44791412, 23.04930687], [70.44763947, 23.04931068], [70.44763947, 23.04763985], [70.44735718, 23.04763985], [70.44735718, 23.04709053], [70.44709015, 23.04709053], [70.44709015, 23.04681015], [70.44680786, 23.04681015], [70.44680786, 23.04624939], [70.44652557, 23.04624939], [70.44652557, 23.04569244], [70.44625092, 23.04569244], [70.44625092, 23.04486275], [70.44596863, 23.04486275], [70.44596863, 23.04432106], [70.44568634, 23.04432106], [70.44568634, 23.04347038], [70.44541931, 23.04347038], [70.44541931, 23.04291725], [70.44513702, 23.04292107], [70.44513702, 23.04208183], [70.44486237, 23.04208374], [70.44486237, 23.04153061], [70.44458008, 23.04153061], [70.44458008, 23.04070091], [70.44431305, 23.04070091], [70.44431305, 23.04013824], [70.44403076, 23.04013824], [70.44403076, 23.03874969], [70.44374847, 23.03874969], [70.44374847, 23.03736115], [70.44346619, 23.03736115], [70.44346619, 23.03652954], [70.44319153, 23.03652954], [70.44319153, 23.03569031], [70.44291687, 23.03569412], [70.44291687, 23.03486061], [70.44264221, 23.03486061], [70.44264221, 23.03445053], [70.44264221, 23.0340271], [70.44235992, 23.03403091], [70.44235992, 23.03347015], [70.44208527, 23.03347206], [70.44208527, 23.03291702], [70.44180298, 23.03292084], [70.44180298, 23.03236008], [70.44152832, 23.03236389], [70.44152832, 23.03180313], [70.44124603, 23.03181076], [70.44124603, 23.03096962], [70.44097137, 23.03097343], [70.44097137, 23.03013802], [70.44069672, 23.03014183], [70.44069672, 23.02957916], [70.44041443, 23.02958107], [70.44041443, 23.02874947], [70.44013977, 23.02874947], [70.44013977, 23.02792168], [70.43985748, 23.02792168], [70.43985748, 23.02708054], [70.43958282, 23.02708244], [70.43958282, 23.02625084], [70.43930817, 23.02625084], [70.43930817, 23.02542114], [70.43902588, 23.02542114], [70.43902588, 23.02458], [70.43875122, 23.02458382], [70.43875122, 23.02402687], [70.43846893, 23.02403069], [70.43846893, 23.02321053], [70.43818665, 23.02321053], [70.43818665, 23.02235985], [70.43791962, 23.02236176], [70.43791962, 23.02152824], [70.43763733, 23.02153015], [70.43763733, 23.02069092], [70.43736267, 23.02069473], [70.43736267, 23.02013969], [70.43708038, 23.02015114], [70.43708038, 23.01958084], [70.43680573, 23.01958466], [70.43680573, 23.01902771], [70.43653107, 23.01902962], [70.43653107, 23.01847076], [70.43624878, 23.01847458], [70.43624878, 23.01791763], [70.43596649, 23.01791954], [70.43596649, 23.01736259], [70.43569183, 23.01736259], [70.43569183, 23.0165329], [70.43541718, 23.0165329], [70.43541718, 23.01597023], [70.43514252, 23.01597023], [70.43514252, 23.0154171], [70.43486023, 23.01542282], [70.43486023, 23.01485825], [70.43458557, 23.01486015], [70.43458557, 23.01430511], [70.43430328, 23.01431084], [70.43430328, 23.01374817], [70.43402863, 23.01374817], [70.43402863, 23.0134697], [70.43374634, 23.0134716], [70.43374634, 23.01291656], [70.43347168, 23.01292038], [70.43347168, 23.01235962], [70.43319702, 23.01236153], [70.43319702, 23.01208305], [70.43291473, 23.01208305], [70.43291473, 23.01152611], [70.43264008, 23.01152992], [70.43264008, 23.01098061], [70.43235779, 23.01098061], [70.43235779, 23.01069069], [70.43208313, 23.0106945], [70.43208313, 23.01013947], [70.43180847, 23.01013947], [70.43180847, 23.00986099], [70.43152618, 23.00986099], [70.43152618, 23.00930977], [70.43125153, 23.00930977], [70.43125153, 23.00875092], [70.43096924, 23.00875092], [70.43096924, 23.00847054], [70.43069458, 23.00847244], [70.43069458, 23.0079174], [70.43041992, 23.00792122], [70.43041992, 23.00736046], [70.43013763, 23.00736046], [70.43013763, 23.00708008], [70.42986298, 23.0070858], [70.42986298, 23.00652695], [70.42958069, 23.00653076], [70.42958069, 23.00597], [70.42930603, 23.00597382], [70.42930603, 23.00541687], [70.42901611, 23.00542068], [70.42901611, 23.00485992], [70.42874908, 23.00486374], [70.42874908, 23.00458145], [70.42847443, 23.00458145], [70.42847443, 23.00430489], [70.42819214, 23.00430489], [70.42819214, 23.00402832], [70.42764282, 23.00403023], [70.42764282, 23.00375175], [70.42736053, 23.00375175], [70.42736053, 23.00346947], [70.42708588, 23.00347137], [70.42708588, 23.00319481], [70.42680359, 23.00319481], [70.42680359, 23.00264168], [70.42652893, 23.00264168], [70.42652893, 23.00235939], [70.42624664, 23.00235939], [70.42624664, 23.00208282], [70.42597198, 23.00208282], [70.42597198, 23.00180626], [70.42569733, 23.00181007], [70.42569733, 23.00124931], [70.42542267, 23.00124931], [70.42542267, 23.00069046], [70.42514038, 23.00069427], [70.42514038, 23.0004158], [70.42457581, 23.00042152], [70.42457581, 23.00013924], [70.42457581, 22.99958038], [70.42430878, 22.9995842], [70.42430878, 22.99930573], [70.42402649, 22.99930954], [70.42402649, 22.9990406], [70.42375183, 22.9990406], [70.42375183, 22.99875069], [70.42346954, 22.99875069], [70.42346954, 22.99818993], [70.42319489, 22.99819374], [70.42319489, 22.99791718], [70.42292023, 22.99792099], [70.42292023, 22.99736023], [70.4225769, 22.99736023], [70.42236328, 22.99736023], [70.42236328, 22.99707985], [70.42208099, 22.99708366], [70.42208099, 22.99680519], [70.42180634, 22.99681091], [70.42180634, 22.99653053], [70.42151642, 22.99653053], [70.42151642, 22.99625015], [70.42124939, 22.99625015], [70.42124939, 22.99598122], [70.4209671, 22.99598122], [70.4209671, 22.99542046], [70.42069244, 22.99542046], [70.42069244, 22.99514008], [70.42041779, 22.99514008], [70.42041779, 22.9948597], [70.4201355, 22.9948616], [70.4201355, 22.99458313], [70.41958618, 22.99458313], [70.41958618, 22.99430466], [70.41930389, 22.99430466], [70.41930389, 22.99402809], [70.41874695, 22.99403], [70.41874695, 22.99374962], [70.41819763, 22.99374962], [70.41819763, 22.99347115], [70.41791534, 22.99347305], [70.41791534, 22.99319458], [70.41764069, 22.99319458], [70.41764069, 22.99263954], [70.41707611, 22.99263954], [70.41707611, 22.99208069], [70.41680908, 22.9920845], [70.41680908, 22.99180603], [70.41652679, 22.99180984], [70.41652679, 22.99152946], [70.41625214, 22.99152946], [70.41625214, 22.99097061], [70.41596985, 22.99097061], [70.41596985, 22.99069214], [70.41569519, 22.99069214], [70.41569519, 22.99041748], [70.4154129, 22.99041939], [70.4154129, 22.99014282], [70.41485596, 22.99014282], [70.41485596, 22.98984909], [70.41374969, 22.98984909], [70.41374969, 22.99014282], [70.41348267, 22.99014282], [70.41348267, 22.99041939], [70.41319275, 22.99041748], [70.41319275, 22.99069214], [70.41291809, 22.99069023], [70.41291809, 22.9912529], [70.4126358, 22.9912529], [70.4126358, 22.99291992], [70.41236115, 22.99291992], [70.41236115, 22.99374962], [70.41208649, 22.99374962], [70.41208649, 22.99458313], [70.41179657, 22.99458122], [70.41179657, 22.99542046], [70.41152954, 22.99542046], [70.41152954, 22.99625015], [70.41124725, 22.99625015], [70.41124725, 22.99708366], [70.4109726, 22.99708366], [70.4109726, 22.99819374], [70.41069794, 22.99819374], [70.41069794, 22.99847221], [70.41042328, 22.99847031], [70.41042328, 22.9990406], [70.41069794, 22.9990406], [70.41069794, 22.99930954], [70.41041565, 22.99930573], [70.41041565, 22.9995842], [70.41069794, 22.99958038], [70.41069794, 22.99986076], [70.41069794, 23.00069427], [70.41098022, 23.00069046], [70.41098022, 23.00292015], [70.41124725, 23.00292015], [70.41124725, 23.0051403], [70.41152954, 23.0051403], [70.41152954, 23.00625038], [70.4118042, 23.00625038], [70.4118042, 23.00847244], [70.41208649, 23.00847054], [70.41208649, 23.01098061], [70.41236115, 23.01098061], [70.41236115, 23.01263809], [70.4126358, 23.01263809], [70.4126358, 23.01431084], [70.41291809, 23.01430511], [70.41291809, 23.01569366], [70.41319275, 23.01569176], [70.41319275, 23.0165329], [70.41347504, 23.01652718], [70.41347504, 23.01708221], [70.41374969, 23.01708031], [70.41374969, 23.01764107], [70.41402435, 23.01763916], [70.41402435, 23.01819229], [70.41430664, 23.01819038], [70.41430664, 23.01875114], [70.4145813, 23.01875114], [70.4145813, 23.01931], [70.41486359, 23.01930618], [70.41486359, 23.01958466], [70.41513824, 23.01958084], [70.41513824, 23.02015114], [70.4154129, 23.02015114], [70.4154129, 23.02042007], [70.41569519, 23.02041626], [70.41569519, 23.02069473], [70.41596985, 23.02069092], [70.41596985, 23.02124977], [70.41625214, 23.02124977], [70.41625214, 23.02153015], [70.41652679, 23.02152824], [70.41652679, 23.02180672], [70.41680908, 23.02180672], [70.41680908, 23.02236176], [70.41707611, 23.02235985], [70.41707611, 23.02264023], [70.4173584, 23.02264023], [70.4173584, 23.02292061], [70.41764069, 23.02291679], [70.41764069, 23.02347183], [70.41791534, 23.02347183], [70.41791534, 23.02375031], [70.41819763, 23.02375031], [70.41819763, 23.02403069], [70.41847229, 23.02402687], [70.41847229, 23.02458382], [70.41874695, 23.02458], [70.41874695, 23.02486038], [70.41902924, 23.02486038], [70.41902924, 23.02514076], [70.41929626, 23.02514076], [70.41929626, 23.02542114], [70.41958618, 23.02541733], [70.41958618, 23.02569389], [70.41986084, 23.02569008], [70.41986084, 23.02625084], [70.42014313, 23.02625084], [70.42014313, 23.02653122], [70.42041779, 23.02653122], [70.42041779, 23.02680969], [70.42069244, 23.02680588], [70.42069244, 23.02708244], [70.4209671, 23.02708054], [70.4209671, 23.02736092], [70.42151642, 23.02736092], [70.42151642, 23.02763939], [70.42180634, 23.02763939], [70.42180634, 23.02792168], [70.42236328, 23.02791595], [70.42236328, 23.02819443], [70.42263794, 23.02819443], [70.42263794, 23.0284729], [70.42318726, 23.02846909], [70.42318726, 23.02874947], [70.42375183, 23.02874947], [70.42375183, 23.02902794], [70.42402649, 23.0290184], [70.42402649, 23.02931023], [70.42430878, 23.02930641], [70.42430878, 23.02958107], [70.42485809, 23.02958107], [70.42485809, 23.02985954], [70.42514038, 23.02985954], [70.42514038, 23.03014183], [70.42542267, 23.03014183], [70.42542267, 23.0304203], [70.42569733, 23.0304203], [70.42569733, 23.03070068], [70.42624664, 23.03069305], [70.42624664, 23.03097343], [70.42652893, 23.03096962], [70.42652893, 23.03125191], [70.42679596, 23.03125191], [70.42679596, 23.03153038], [70.42736053, 23.03153038], [70.42736053, 23.03181076], [70.42764282, 23.03181076], [70.42764282, 23.03209114], [70.42819214, 23.0320816], [70.42819214, 23.03236389], [70.4284668, 23.03236008], [70.4284668, 23.03264046], [70.42874908, 23.03264046], [70.42874908, 23.03292084], [70.42930603, 23.03291702], [70.42930603, 23.0331955], [70.42958069, 23.0331955], [70.42958069, 23.03347206], [70.42986298, 23.03347015], [70.42986298, 23.03375053], [70.43013763, 23.03375053], [70.43013763, 23.03403091], [70.43041992, 23.03403091], [70.43041992, 23.03430939], [70.43069458, 23.03430557], [70.43069458, 23.03458595], [70.43096924, 23.03458023], [70.43096924, 23.03486061], [70.43125153, 23.03486061], [70.43125153, 23.03515053], [70.43152618, 23.03513908], [70.43152618, 23.03569412], [70.43180847, 23.03569412], [70.43180847, 23.0359726], [70.43209076, 23.03597069], [70.43209076, 23.03625107], [70.43235779, 23.03625107], [70.43235779, 23.03652954], [70.43264008, 23.03652954], [70.43264008, 23.03680992], [70.43291473, 23.03680611], [70.43291473, 23.03708267], [70.43319702, 23.03708076], [70.43319702, 23.03736115], [70.43347168, 23.03736115], [70.43347168, 23.03763962], [70.43374634, 23.03763962], [70.43374634, 23.03791809], [70.43402863, 23.03791618], [70.43402863, 23.03847313], [70.43430328, 23.03847122], [70.43430328, 23.03874969], [70.4345932, 23.03874969], [70.4345932, 23.03902817], [70.43486023, 23.03902817], [70.43486023, 23.03958321], [70.43514252, 23.03958321], [70.43514252, 23.03986168], [70.43541718, 23.03985977], [70.43541718, 23.04013824], [70.43569183, 23.04013824], [70.43569183, 23.04042053], [70.43596649, 23.04042053], [70.43596649, 23.04070091], [70.43624878, 23.04069519], [70.43624878, 23.04097176], [70.43653107, 23.04096031], [70.43653107, 23.04153061], [70.43681335, 23.04153061], [70.43681335, 23.0418129], [70.43708038, 23.04180527], [70.43708038, 23.04208374], [70.43736267, 23.04208183], [70.43736267, 23.04236031], [70.43763733, 23.04236031], [70.43763733, 23.04264259], [70.43791962, 23.04264259], [70.43791962, 23.04292107], [70.43819427, 23.04291725], [70.43819427, 23.04319382], [70.43846893, 23.04319382], [70.43846893, 23.04347038], [70.43875122, 23.04347038], [70.43875122, 23.04375267], [70.43902588, 23.04375267], [70.43902588, 23.04403114], [70.43930817, 23.04403114], [70.43930817, 23.04432106], [70.43958282, 23.0443058], [70.43958282, 23.04458046], [70.43985748, 23.04458046], [70.43985748, 23.04486275], [70.44013977, 23.04486275], [70.44013977, 23.04514122], [70.44041443, 23.04513931], [70.44041443, 23.04569244], [70.44069672, 23.04569244], [70.44069672, 23.04597473], [70.44095612, 23.04597282], [70.44095612, 23.04624939], [70.44124603, 23.04624939]]], [[[70.44152832, 23.04958344], [70.44152832, 23.04819679], [70.44125366, 23.04819679], [70.44125366, 23.04763794], [70.44095612, 23.04763985], [70.44095612, 23.04735947], [70.44069672, 23.04736137], [70.44069672, 23.04708481], [70.4404068, 23.04709053], [70.4404068, 23.04681015], [70.44013977, 23.04681015], [70.44013977, 23.04652977], [70.43985748, 23.04652977], [70.43985748, 23.04624939], [70.43958282, 23.04624939], [70.43958282, 23.04597282], [70.43930817, 23.04597473], [70.43930817, 23.04569244], [70.43902588, 23.04569244], [70.43902588, 23.04541588], [70.43875122, 23.04541969], [70.43875122, 23.04514122], [70.43846893, 23.04514122], [70.43846893, 23.04486275], [70.43818665, 23.04486275], [70.43818665, 23.04458046], [70.43791962, 23.04458046], [70.43791962, 23.0443058], [70.43763733, 23.04432106], [70.43763733, 23.04403114], [70.43736267, 23.04403114], [70.43736267, 23.04375267], [70.43708038, 23.04375267], [70.43708038, 23.04319191], [70.43680573, 23.04319382], [70.43680573, 23.04291725], [70.43653107, 23.04292107], [70.43653107, 23.04236031], [70.43624878, 23.04236031], [70.43624878, 23.04208183], [70.43597412, 23.04208374], [70.43597412, 23.04180527], [70.43569183, 23.0418129], [70.43569183, 23.04153061], [70.43541718, 23.04153061], [70.43541718, 23.04124832], [70.43514252, 23.04124832], [70.43514252, 23.04097176], [70.43486023, 23.04097176], [70.43486023, 23.04069519], [70.4345932, 23.04070091], [70.4345932, 23.04042053], [70.43430328, 23.04042053], [70.43430328, 23.03985977], [70.43402863, 23.03986168], [70.43402863, 23.03930473], [70.43374634, 23.03930473], [70.43374634, 23.03902817], [70.43347168, 23.03902817], [70.43347168, 23.03874969], [70.4329071, 23.03874969], [70.4329071, 23.03847122], [70.43264008, 23.03847313], [70.43264008, 23.03819466], [70.43235779, 23.03819466], [70.43235779, 23.03763962], [70.43208313, 23.03763962], [70.43208313, 23.03736115], [70.43180847, 23.03736115], [70.43180847, 23.03680992], [70.43152618, 23.03680992], [70.43152618, 23.03652954], [70.43125153, 23.03652954], [70.43125153, 23.03625107], [70.43096924, 23.03625107], [70.43096924, 23.03597069], [70.43069458, 23.0359726], [70.43069458, 23.03569412], [70.43041992, 23.03569412], [70.43041992, 23.03541756], [70.43013763, 23.03541946], [70.43013763, 23.03515053], [70.42986298, 23.03515053], [70.42986298, 23.03486061], [70.42958069, 23.03486061], [70.42958069, 23.03458023], [70.42903137, 23.03458595], [70.42903137, 23.03430557], [70.42874908, 23.03430939], [70.42874908, 23.03403091], [70.4284668, 23.03403091], [70.4284668, 23.03375053], [70.42791748, 23.03375053], [70.42791748, 23.03347015], [70.42763519, 23.03347206], [70.42763519, 23.0331955], [70.42708588, 23.0331955], [70.42708588, 23.03291702], [70.42679596, 23.03292084], [70.42679596, 23.03264046], [70.42652893, 23.03264046], [70.42652893, 23.03236008], [70.42597198, 23.03236389], [70.42597198, 23.0320816], [70.42569733, 23.03209114], [70.42569733, 23.03181076], [70.42542267, 23.03181076], [70.42542267, 23.03153038], [70.42485809, 23.03153038], [70.42485809, 23.03125191], [70.42457581, 23.03125191], [70.42457581, 23.03096962], [70.42402649, 23.03097343], [70.42402649, 23.03069305], [70.42375183, 23.03070068], [70.42375183, 23.0304203], [70.42318726, 23.0304203], [70.42318726, 23.03014183], [70.42292023, 23.03014183], [70.42292023, 23.02985954], [70.42236328, 23.02985954], [70.42236328, 23.02958107], [70.42208099, 23.02958107], [70.42208099, 23.02930641], [70.42151642, 23.02931023], [70.42151642, 23.02874947], [70.42124939, 23.02874947], [70.42124939, 23.02846909], [70.42097473, 23.0284729], [70.42097473, 23.02819443], [70.42041779, 23.02819443], [70.42041779, 23.02791595], [70.42014313, 23.02792168], [70.42014313, 23.02763939], [70.41986084, 23.02763939], [70.41986084, 23.02736092], [70.41958618, 23.02736092], [70.41958618, 23.02708054], [70.41930389, 23.02708244], [70.41930389, 23.02680588], [70.41874695, 23.02680969], [70.41874695, 23.02653122], [70.41847229, 23.02653122], [70.41847229, 23.02625084], [70.41819763, 23.02625084], [70.41819763, 23.02596092], [70.41791534, 23.02597237], [70.41791534, 23.02569389], [70.41764069, 23.02569389], [70.41764069, 23.02541733], [70.4173584, 23.02542114], [70.4173584, 23.02486038], [70.41707611, 23.02486038], [70.41707611, 23.02458], [70.41680908, 23.02458382], [70.41680908, 23.02430534], [70.41652679, 23.02431107], [70.41652679, 23.02403069], [70.41625214, 23.02403069], [70.41625214, 23.02375031], [70.41596985, 23.02375031], [70.41596985, 23.02321053], [70.41570282, 23.02321053], [70.41570282, 23.02292061], [70.4154129, 23.02292061], [70.4154129, 23.02264023], [70.4145813, 23.02263832], [70.4145813, 23.02458382], [70.41485596, 23.02458], [70.41485596, 23.02653122], [70.41506195, 23.0265274], [70.41513824, 23.0265274], [70.41513824, 23.02792168], [70.4154129, 23.02791595], [70.4154129, 23.02902794], [70.41569519, 23.02902794], [70.41569519, 23.02958107], [70.41596985, 23.02957916], [70.41596985, 23.0304203], [70.41625214, 23.03041649], [70.41625214, 23.03097343], [70.41652679, 23.03096962], [70.41652679, 23.03153038], [70.41680908, 23.03153038], [70.41681671, 23.03209114], [70.41708374, 23.0320816], [70.41708374, 23.03226089], [70.41708374, 23.03236389], [70.41720581, 23.03236389], [70.4173584, 23.03236389], [70.4173584, 23.03244972], [70.4173584, 23.03292084], [70.41764069, 23.03291702], [70.41764069, 23.03347206], [70.41791534, 23.03347206], [70.41791534, 23.03375053], [70.41819763, 23.03375053], [70.41819763, 23.03430939], [70.41847229, 23.03430557], [70.41847229, 23.03458595], [70.41819763, 23.03458023], [70.41819763, 23.03486061], [70.41847229, 23.03486061], [70.41847229, 23.03515053], [70.41874695, 23.03515053], [70.41874695, 23.03541946], [70.41902924, 23.03541756], [70.41902924, 23.0359726], [70.41929626, 23.03597069], [70.41929626, 23.03625107], [70.41958618, 23.03625107], [70.41958618, 23.03652954], [70.41986084, 23.03652954], [70.41986084, 23.03680992], [70.4200058, 23.03680611], [70.4201355, 23.03680611], [70.4201355, 23.03717041], [70.4201355, 23.03736115], [70.42035675, 23.03736115], [70.42041779, 23.03763962], [70.42069244, 23.03763962], [70.42069244, 23.03791809], [70.42097473, 23.03791618], [70.42097473, 23.03819466], [70.42124939, 23.03819466], [70.42124939, 23.03847313], [70.42151642, 23.03847122], [70.42151642, 23.03902817], [70.42180634, 23.03902817], [70.42180634, 23.03930473], [70.42208099, 23.03930473], [70.42208099, 23.03958321], [70.42236328, 23.03958321], [70.42236328, 23.03986168], [70.42263794, 23.03985977], [70.42263794, 23.04013824], [70.42292023, 23.04013824], [70.42292023, 23.04042053], [70.42318726, 23.04042053], [70.42318726, 23.04070091], [70.42346954, 23.04069519], [70.42346954, 23.04097176], [70.42375183, 23.04096031], [70.42375183, 23.04124832], [70.42430878, 23.04124832], [70.42430878, 23.04153061], [70.42457581, 23.04153061], [70.42457581, 23.0418129], [70.42485809, 23.04180527], [70.42485809, 23.04208374], [70.42514038, 23.04208183], [70.42514038, 23.04236031], [70.42542267, 23.04236031], [70.42542267, 23.04264259], [70.42569733, 23.04264259], [70.42569733, 23.04292107], [70.42597198, 23.04291725], [70.42597198, 23.04319382], [70.42624664, 23.04319382], [70.42624664, 23.04347038], [70.42652893, 23.04347038], [70.42652893, 23.04375267], [70.42708588, 23.04375267], [70.42708588, 23.04403114], [70.42736053, 23.04403114], [70.42736053, 23.04432106], [70.42763519, 23.0443058], [70.42763519, 23.04458427], [70.42791748, 23.04458046], [70.42791748, 23.04514122], [70.42819214, 23.04514122], [70.42819214, 23.04541969], [70.42847443, 23.04541588], [70.42847443, 23.04569244], [70.42874908, 23.04569054], [70.42874908, 23.04624939], [70.42901611, 23.04624939], [70.42901611, 23.04652977], [70.42958069, 23.04652977], [70.42958069, 23.04681015], [70.43013763, 23.04681015], [70.43013763, 23.04709053], [70.43069458, 23.04708481], [70.43069458, 23.04736137], [70.43125153, 23.04735947], [70.43125153, 23.04763985], [70.43180847, 23.04763985], [70.43180847, 23.04792023], [70.43235779, 23.04791641], [70.43235779, 23.04819679], [70.43291473, 23.04819679], [70.43291473, 23.04847145], [70.43430328, 23.04846954], [70.43430328, 23.04874992], [70.43596649, 23.04874992], [70.43596649, 23.0490303], [70.43736267, 23.0490303], [70.43736267, 23.04931068], [70.44097137, 23.04930687], [70.44097137, 23.04958344], [70.44152832, 23.04958344]]], [[[70.48236084, 23.06541824], [70.48236084, 23.06485939], [70.4826355, 23.0648613], [70.4826355, 23.06374931], [70.48236084, 23.06375122], [70.48236084, 23.06264114], [70.48208618, 23.06264114], [70.48208618, 23.06207085], [70.48180389, 23.0620842], [70.48180389, 23.06152725], [70.48152924, 23.06153107], [70.48152924, 23.06097031], [70.48124695, 23.06097221], [70.48124695, 23.06069565], [70.48097229, 23.06069565], [70.48097229, 23.0601387], [70.48069763, 23.06014061], [70.48069763, 23.05986023], [70.48041534, 23.05986023], [70.48041534, 23.05958366], [70.48014069, 23.05958366], [70.48014069, 23.05930328], [70.4798584, 23.05932045], [70.4798584, 23.05903053], [70.47957611, 23.05903053], [70.47957611, 23.05881119], [70.47930908, 23.05875015], [70.47930908, 23.05820084], [70.47902679, 23.05820084], [70.47902679, 23.05792046], [70.47875214, 23.05792046], [70.47875214, 23.05764008], [70.47846985, 23.05764008], [70.47846985, 23.0573597], [70.47819519, 23.05736351], [70.47819519, 23.05708122], [70.4779129, 23.05708122], [70.4779129, 23.05680466], [70.47736359, 23.05680466], [70.47736359, 23.05652809], [70.47706604, 23.05653191], [70.47706604, 23.05626106], [70.47651672, 23.05626106], [70.47651672, 23.05596924], [70.47624969, 23.05597115], [70.47624969, 23.05569458], [70.47569275, 23.05569458], [70.47569275, 23.05541611], [70.47541809, 23.05542183], [70.47541809, 23.05514145], [70.47486115, 23.05514145], [70.47486115, 23.05485916], [70.47458649, 23.05485916], [70.47458649, 23.05458069], [70.4743042, 23.0545826], [70.4743042, 23.05430603], [70.47374725, 23.05431175], [70.47374725, 23.05403137], [70.4734726, 23.05403137], [70.4734726, 23.05374908], [70.47319794, 23.05374908], [70.47319794, 23.05347061], [70.47291565, 23.05347252], [70.47291565, 23.05319405], [70.4723587, 23.05319405], [70.4723587, 23.05291748], [70.47207642, 23.05291748], [70.47207642, 23.05264091], [70.47180939, 23.05264091], [70.47180176, 23.05236053], [70.4715271, 23.05236053], [70.4715271, 23.05208015], [70.47097015, 23.05208397], [70.47097015, 23.0518055], [70.47070313, 23.05181122], [70.47070313, 23.05153084], [70.47041321, 23.05153084], [70.47041321, 23.05125046], [70.47013855, 23.05125046], [70.47013855, 23.05097008], [70.4695816, 23.05097198], [70.4695816, 23.05069351], [70.46930695, 23.05069351], [70.46930695, 23.05041695], [70.46901703, 23.05042076], [70.46901703, 23.05013084], [70.46875, 23.05013847], [70.46875, 23.04986191], [70.46847534, 23.04986191], [70.46847534, 23.04958344], [70.4679184, 23.04958344], [70.4679184, 23.04930687], [70.46763611, 23.04931068], [70.46763611, 23.0490303], [70.46736145, 23.0490303], [70.46736145, 23.04874992], [70.46708679, 23.04874992], [70.46708679, 23.04846954], [70.46652985, 23.04847145], [70.46652985, 23.04819679], [70.46624756, 23.04819679], [70.46624756, 23.04791641], [70.46569824, 23.04792023], [70.46569824, 23.04763985], [70.46541595, 23.04763985], [70.46541595, 23.04735947], [70.4651413, 23.04736137], [70.4651413, 23.04708481], [70.46485901, 23.04709053], [70.46485901, 23.04681015], [70.46457672, 23.04681015], [70.46457672, 23.04652977], [70.46430206, 23.04652977], [70.46430206, 23.04624939], [70.4640274, 23.04624939], [70.4640274, 23.04597282], [70.46375275, 23.04597473], [70.46375275, 23.04569244], [70.46347046, 23.04569244], [70.46347046, 23.04541588], [70.4631958, 23.04541969], [70.4631958, 23.04514122], [70.46290588, 23.04514122], [70.46290588, 23.04486275], [70.46263885, 23.04486275], [70.46263885, 23.04458046], [70.4623642, 23.04458046], [70.4623642, 23.0443058], [70.46208954, 23.04432106], [70.46208954, 23.04403114], [70.46180725, 23.04403114], [70.46180725, 23.04375267], [70.46152496, 23.04375267], [70.46152496, 23.04347038], [70.46125031, 23.04347038], [70.46125031, 23.04319382], [70.46097565, 23.04319382], [70.46097565, 23.04291725], [70.46069336, 23.04292107], [70.46069336, 23.04264259], [70.4604187, 23.04264259], [70.4604187, 23.04292107], [70.46013641, 23.04291725], [70.46013641, 23.04319382], [70.45986176, 23.04319191], [70.45986176, 23.04432106], [70.4595871, 23.04432106], [70.4595871, 23.04124832], [70.45929718, 23.04124832], [70.45929718, 23.04096031], [70.45903015, 23.04097176], [70.45903015, 23.04041672], [70.45874786, 23.04042053], [70.45874786, 23.03985977], [70.45847321, 23.03986168], [70.45847321, 23.03930473], [70.45819092, 23.03930473], [70.45819092, 23.03902817], [70.45791626, 23.03902817], [70.45791626, 23.03874969], [70.4576416, 23.03874969], [70.4576416, 23.03819084], [70.45735931, 23.03819466], [70.45735931, 23.03763962], [70.45707703, 23.03763962], [70.45707703, 23.03708076], [70.45680237, 23.03708267], [70.45680237, 23.03652763], [70.45652771, 23.03652954], [70.45652771, 23.03625107], [70.45625305, 23.03625107], [70.45625305, 23.03569031], [70.45597076, 23.03569412], [70.45597076, 23.03513908], [70.45569611, 23.03515053], [70.45569611, 23.03486061], [70.45540619, 23.03486061], [70.45540619, 23.03430939], [70.45527649, 23.03430939], [70.45513916, 23.03430939], [70.45513916, 23.03403091], [70.45485687, 23.03403091], [70.45485687, 23.03347015], [70.45458221, 23.03347206], [70.45458221, 23.03291702], [70.45430756, 23.03292084], [70.45430756, 23.03236008], [70.45402527, 23.03236389], [70.45402527, 23.0320816], [70.45375061, 23.03209114], [70.45375061, 23.03153038], [70.45347595, 23.03153038], [70.45347595, 23.03096962], [70.45319366, 23.03097343], [70.45319366, 23.03041649], [70.45291901, 23.0304203], [70.45291901, 23.02931023], [70.45263672, 23.02931023], [70.45263672, 23.02846909], [70.45236206, 23.0284729], [70.45236206, 23.02763939], [70.45207977, 23.02763939], [70.45207977, 23.02708054], [70.45180511, 23.02708244], [70.45180511, 23.0265274], [70.45153046, 23.02653122], [70.45153046, 23.02625084], [70.45096588, 23.02625084], [70.45096588, 23.02596092], [70.45069122, 23.02597237], [70.45069122, 23.02569389], [70.45014191, 23.02569389], [70.45014191, 23.02541733], [70.44875336, 23.02542114], [70.44875336, 23.02514076], [70.44625092, 23.02513885], [70.44625092, 23.02569389], [70.4465332, 23.02569008], [70.4465332, 23.02680969], [70.44680786, 23.02680969], [70.44680786, 23.02792168], [70.44708252, 23.02791595], [70.44708252, 23.0284729], [70.44735718, 23.02846909], [70.44735718, 23.02931023], [70.44763947, 23.02931023], [70.44763947, 23.03014183], [70.44790649, 23.03014183], [70.44790649, 23.03070068], [70.44819641, 23.03070068], [70.44819641, 23.03125191], [70.44847107, 23.03125191], [70.44847107, 23.03181076], [70.44875336, 23.03180313], [70.44875336, 23.03236389], [70.44902802, 23.03236008], [70.44902802, 23.03292084], [70.44930267, 23.03291702], [70.44930267, 23.03347206], [70.44959259, 23.03347015], [70.44959259, 23.03403091], [70.44985962, 23.0340271], [70.44985962, 23.03458595], [70.45014954, 23.03458023], [70.45014954, 23.03515053], [70.45041656, 23.03513908], [70.45041656, 23.03569412], [70.45069122, 23.03569031], [70.45069122, 23.03652954], [70.45097351, 23.03652763], [70.45097351, 23.03708267], [70.45124817, 23.03708076], [70.45124817, 23.03791809], [70.45153046, 23.03791618], [70.45153046, 23.03847313], [70.45180511, 23.03847313], [70.45180511, 23.03866005], [70.45180511, 23.03930473], [70.45207977, 23.03930473], [70.45207977, 23.03986168], [70.45236206, 23.03985977], [70.45236206, 23.04070091], [70.45263672, 23.04070091], [70.45263672, 23.04153061], [70.45291901, 23.04153061], [70.45291901, 23.04236031], [70.45318604, 23.04236031], [70.45318604, 23.04292107], [70.45347595, 23.04291725], [70.45347595, 23.04347038], [70.45375061, 23.04347038], [70.45375061, 23.04375267], [70.4540329, 23.04375267], [70.4540329, 23.04403114], [70.45430756, 23.04402733], [70.45430756, 23.04458427], [70.45458221, 23.04458046], [70.45458221, 23.04486275], [70.45485687, 23.04486275], [70.45485687, 23.04541969], [70.45513916, 23.04541588], [70.45513916, 23.04569244], [70.45540619, 23.04569054], [70.45540619, 23.04624939], [70.45569611, 23.04624939], [70.45569611, 23.04652977], [70.45597076, 23.04652977], [70.45597076, 23.04709053], [70.45625305, 23.04708481], [70.45625305, 23.04736137], [70.45652771, 23.04735947], [70.45652771, 23.04792023], [70.45680237, 23.04791641], [70.45680237, 23.04819679], [70.45708466, 23.04819679], [70.45708466, 23.04847145], [70.45735931, 23.04846954], [70.45735931, 23.04874992], [70.4576416, 23.04874992], [70.4576416, 23.0490303], [70.45791626, 23.0490303], [70.45791626, 23.04931068], [70.45819092, 23.04930687], [70.45819092, 23.04986191], [70.45874786, 23.04986191], [70.45874786, 23.0490284], [70.45903015, 23.0490303], [70.45903015, 23.04763985], [70.4595871, 23.04763985], [70.4595871, 23.04652977], [70.45986176, 23.04652786], [70.45986176, 23.04847145], [70.4595871, 23.04847145], [70.4595871, 23.04986191], [70.45930481, 23.04986191], [70.45930481, 23.05013847], [70.4595871, 23.05013084], [70.4595871, 23.05042076], [70.45986176, 23.05041695], [70.45986176, 23.05097198], [70.46013641, 23.05097008], [70.46013641, 23.05153084], [70.4604187, 23.05152893], [70.4604187, 23.05208397], [70.46069336, 23.05208015], [70.46069336, 23.05236053], [70.46098328, 23.05236053], [70.46098328, 23.05264091], [70.46125031, 23.05264091], [70.46125031, 23.05291748], [70.46152496, 23.05291748], [70.46152496, 23.05319405], [70.46180725, 23.05319023], [70.46180725, 23.05374908], [70.46208954, 23.05374908], [70.46208954, 23.05403137], [70.46235657, 23.05403137], [70.46235657, 23.05431175], [70.46263885, 23.05430603], [70.46263885, 23.0545826], [70.46290588, 23.05458069], [70.46290588, 23.05485916], [70.4631958, 23.05485916], [70.4631958, 23.05514145], [70.46375275, 23.05514145], [70.46375275, 23.05542183], [70.4640274, 23.05541611], [70.4640274, 23.05569458], [70.46430206, 23.05569458], [70.46430206, 23.05597115], [70.46457672, 23.05596924], [70.46457672, 23.05626106], [70.46512604, 23.05626106], [70.46512604, 23.05653191], [70.46569061, 23.05652809], [70.46569824, 23.05680466], [70.46624756, 23.05680466], [70.46624756, 23.05708122], [70.4668045, 23.05708122], [70.4668045, 23.05736351], [70.46736145, 23.0573597], [70.46736145, 23.05764008], [70.46875, 23.05764008], [70.46875, 23.05792046], [70.46902466, 23.05791664], [70.46902466, 23.05804062], [70.46901703, 23.05820084], [70.4695816, 23.05819511], [70.4695816, 23.05847359], [70.46985626, 23.05846977], [70.46985626, 23.05875015], [70.47013855, 23.05875015], [70.47013855, 23.05903053], [70.47070313, 23.05903053], [70.47070313, 23.05932045], [70.47097015, 23.05930328], [70.47097015, 23.05958366], [70.47126007, 23.05957985], [70.47126007, 23.06014061], [70.4715271, 23.06014061], [70.4715271, 23.06042099], [70.47180176, 23.06041718], [70.47180176, 23.06069565], [70.4723587, 23.06069565], [70.4723587, 23.06097221], [70.47291565, 23.06097221], [70.47291565, 23.06125069], [70.4734726, 23.06125069], [70.4734726, 23.06153107], [70.47402954, 23.06153107], [70.47402954, 23.06180954], [70.47458649, 23.06180573], [70.47458649, 23.0620842], [70.4751358, 23.06207085], [70.4751358, 23.06236076], [70.47541809, 23.06236076], [70.47541809, 23.06264114], [70.47598267, 23.06264114], [70.47598267, 23.06291962], [70.47624969, 23.06291771], [70.47624969, 23.06319427], [70.47680664, 23.06319427], [70.47680664, 23.06347275], [70.47706604, 23.06347084], [70.47706604, 23.06375122], [70.4779129, 23.06375122], [70.4779129, 23.06402969], [70.47846985, 23.06402969], [70.47846985, 23.06430817], [70.47930908, 23.06430626], [70.47930908, 23.06458282], [70.48014069, 23.06458282], [70.48014069, 23.0648613], [70.48069763, 23.0648613], [70.48069763, 23.06513977], [70.48152924, 23.06513023], [70.48152924, 23.06541824], [70.48236084, 23.06541824]]], [[[70.45903015, 23.05764008], [70.45903015, 23.05708122], [70.45930481, 23.05708122], [70.45930481, 23.05652809], [70.45903015, 23.05653191], [70.45903015, 23.05626106], [70.45929718, 23.05626106], [70.45929718, 23.05596924], [70.46013641, 23.05597115], [70.46013641, 23.05558968], [70.46013641, 23.05541611], [70.4604187, 23.05542183], [70.4604187, 23.05514145], [70.46013641, 23.05514145], [70.46013641, 23.05485916], [70.45986176, 23.05485916], [70.45986176, 23.05458069], [70.4595871, 23.0545826], [70.4595871, 23.05430603], [70.45929718, 23.05431175], [70.45929718, 23.05403137], [70.45903015, 23.05403137], [70.45903015, 23.05374908], [70.45874786, 23.05374908], [70.45874786, 23.05319023], [70.45847321, 23.05319405], [70.45847321, 23.05291748], [70.45819092, 23.05291748], [70.45819092, 23.05264091], [70.45791626, 23.05264091], [70.45791626, 23.05236053], [70.4576416, 23.05236053], [70.4576416, 23.05208015], [70.45708466, 23.05208397], [70.45708466, 23.0518055], [70.45680237, 23.05181122], [70.45680237, 23.05153084], [70.45625305, 23.05153084], [70.45625305, 23.05097008], [70.45652771, 23.05097008], [70.45652771, 23.05125046], [70.45707703, 23.05125046], [70.45707703, 23.05153084], [70.45735931, 23.05153084], [70.45735931, 23.05181122], [70.4576416, 23.05181122], [70.4576416, 23.0506897], [70.45735931, 23.05069351], [70.45735931, 23.05013847], [70.45708466, 23.05013847], [70.45708466, 23.04986191], [70.45680237, 23.04986191], [70.45680237, 23.04958344], [70.45652771, 23.04958344], [70.45652771, 23.04930687], [70.45625305, 23.04931068], [70.45625305, 23.0490303], [70.45597076, 23.0490303], [70.45597076, 23.04874992], [70.45569611, 23.04874992], [70.45569611, 23.04846954], [70.45541382, 23.04847145], [70.45541382, 23.04819679], [70.4548645, 23.04819679], [70.4548645, 23.04791641], [70.45458221, 23.04792023], [70.45458221, 23.04763985], [70.4540329, 23.04763985], [70.4540329, 23.04735947], [70.45375061, 23.04736137], [70.45375061, 23.04708481], [70.45347595, 23.04709053], [70.45347595, 23.04681015], [70.45291901, 23.04681015], [70.45291901, 23.04652977], [70.45263672, 23.04652977], [70.45263672, 23.04624939], [70.45236206, 23.04624939], [70.45236206, 23.04597282], [70.45207977, 23.04597473], [70.45207977, 23.04569244], [70.45180511, 23.04569244], [70.45180511, 23.04541588], [70.45153046, 23.04541969], [70.45153046, 23.04514122], [70.45124817, 23.04514122], [70.45124817, 23.04486275], [70.45096588, 23.04486275], [70.45096588, 23.04458046], [70.45069122, 23.04458046], [70.45069122, 23.04402733], [70.45041656, 23.04403114], [70.45041656, 23.04347038], [70.45014191, 23.04347038], [70.45014191, 23.04319382], [70.44958496, 23.04319382], [70.44958496, 23.04375267], [70.44985962, 23.04375267], [70.44985962, 23.04486275], [70.45014954, 23.04486275], [70.45014954, 23.04541969], [70.45041656, 23.04541588], [70.45041656, 23.04597473], [70.45069122, 23.04597282], [70.45069122, 23.04652977], [70.45096588, 23.04652977], [70.45096588, 23.04681015], [70.45153046, 23.04681015], [70.45153046, 23.04709053], [70.45181274, 23.04709053], [70.45181274, 23.04763985], [70.45153046, 23.04763985], [70.45153046, 23.04792023], [70.45207977, 23.04791641], [70.45207977, 23.04819679], [70.45236206, 23.04819107], [70.45236206, 23.0490303], [70.45207977, 23.0490303], [70.45207977, 23.04931068], [70.45153046, 23.04931068], [70.45153046, 23.0490303], [70.45096588, 23.0490303], [70.45096588, 23.04931068], [70.45124817, 23.04930687], [70.45124817, 23.04958344], [70.45153046, 23.04958344], [70.45153046, 23.04986191], [70.45207977, 23.04986191], [70.45207977, 23.05013847], [70.45236206, 23.05013847], [70.45236206, 23.0506897], [70.45263672, 23.05070114], [70.45263672, 23.05153084], [70.45318604, 23.05153084], [70.45318604, 23.05181122], [70.45347595, 23.0518055], [70.45347595, 23.05208397], [70.45375061, 23.05208015], [70.45375061, 23.05236053], [70.4540329, 23.05236053], [70.4540329, 23.05264091], [70.45430756, 23.05264091], [70.45430756, 23.05291748], [70.45458221, 23.05291748], [70.45458221, 23.05319405], [70.4548645, 23.05319405], [70.4548645, 23.05347252], [70.45513916, 23.05347061], [70.45513916, 23.05374908], [70.45541382, 23.05374718], [70.45540619, 23.05391121], [70.45540619, 23.05403137], [70.45581055, 23.05404472], [70.45597076, 23.05405045], [70.45597076, 23.05431175], [70.45652771, 23.05430603], [70.45652771, 23.0545826], [70.45680237, 23.05458069], [70.45680237, 23.05485916], [70.45735931, 23.05485916], [70.45735931, 23.05514145], [70.45652771, 23.05514145], [70.45652771, 23.05485916], [70.45540619, 23.05485916], [70.45540619, 23.05514145], [70.45485687, 23.05514145], [70.45485687, 23.05485916], [70.45458221, 23.05485916], [70.45458221, 23.05458069], [70.45430756, 23.0545826], [70.45430756, 23.05430603], [70.45375061, 23.05431175], [70.45375061, 23.05403137], [70.45318604, 23.05403137], [70.45318604, 23.05374908], [70.45291901, 23.05374908], [70.45291901, 23.05347061], [70.45236206, 23.05347252], [70.45236206, 23.05319405], [70.45207977, 23.05319405], [70.45207977, 23.05291748], [70.45181274, 23.05291748], [70.45181274, 23.05264091], [70.45041656, 23.05264091], [70.45041656, 23.05236053], [70.44959259, 23.05236053], [70.44959259, 23.05264091], [70.44985962, 23.05264091], [70.44985962, 23.05291748], [70.45041656, 23.05291748], [70.45041656, 23.05319405], [70.45069122, 23.05319405], [70.45069122, 23.05347252], [70.45096588, 23.05347061], [70.45096588, 23.05374908], [70.45124817, 23.05374908], [70.45124817, 23.05403137], [70.45153046, 23.05403137], [70.45153046, 23.05431175], [70.45180511, 23.05430603], [70.45180511, 23.0545826], [70.45236206, 23.05458069], [70.45236206, 23.05485916], [70.45263672, 23.05485916], [70.45263672, 23.05514145], [70.45291901, 23.05514145], [70.45291901, 23.05542183], [70.45375061, 23.05541611], [70.45375061, 23.05569458], [70.45430756, 23.05569458], [70.45430756, 23.05597115], [70.45458221, 23.05596924], [70.45458221, 23.05626106], [70.45513916, 23.05626106], [70.45513916, 23.05653191], [70.45541382, 23.05652809], [70.45541382, 23.05680466], [70.45680237, 23.05680466], [70.45680237, 23.05708122], [70.45791626, 23.05708122], [70.45791626, 23.05736351], [70.45819092, 23.0573597], [70.45819092, 23.05764008], [70.45903015, 23.05764008]]], [[[70.45236206, 23.05236053], [70.45236206, 23.05208015], [70.45207977, 23.05208397], [70.45207977, 23.05152893], [70.45181274, 23.05153084], [70.45181274, 23.05097008], [70.45153046, 23.05097198], [70.45153046, 23.05069351], [70.45124817, 23.05069351], [70.45124817, 23.05041695], [70.45041656, 23.05042076], [70.45041656, 23.05013084], [70.45014191, 23.05013847], [70.45014191, 23.05097198], [70.45041656, 23.05097008], [70.45041656, 23.05125046], [70.45069122, 23.05125046], [70.45069122, 23.05153084], [70.45097351, 23.05152893], [70.45097351, 23.0518055], [70.45114136, 23.0518055], [70.45153046, 23.0518055], [70.45153046, 23.05200005], [70.45153046, 23.05236053], [70.45207977, 23.05236053], [70.45207977, 23.05264091], [70.45236206, 23.05264091], [70.45236206, 23.05291748], [70.45263672, 23.05291748], [70.45263672, 23.05319405], [70.45347595, 23.05319405], [70.45347595, 23.05291748], [70.45333099, 23.05291748], [70.45318604, 23.05291748], [70.45318604, 23.05264091], [70.45291901, 23.05264091], [70.45291901, 23.05236053], [70.45236206, 23.05236053]]], [[[70.4695816, 23.06125069], [70.4695816, 23.06097031], [70.47013855, 23.06097221], [70.47013855, 23.06069565], [70.46986389, 23.06069565], [70.46986389, 23.06041718], [70.46930695, 23.06042099], [70.46930695, 23.06014061], [70.46901703, 23.06014061], [70.46901703, 23.05986023], [70.46847534, 23.05986023], [70.46847534, 23.05930328], [70.46819305, 23.05932045], [70.46819305, 23.05875015], [70.46679688, 23.05875015], [70.46679688, 23.05846977], [70.46624756, 23.05847359], [70.46624756, 23.05819511], [70.4659729, 23.05820084], [70.4659729, 23.05792046], [70.46541595, 23.05792046], [70.46541595, 23.05764008], [70.46485901, 23.05764008], [70.46482849, 23.05737114], [70.46430206, 23.0573597], [70.46430206, 23.05721092], [70.46430206, 23.05708122], [70.46388245, 23.05708122], [70.46347046, 23.05708122], [70.46347046, 23.05696106], [70.46347046, 23.05680466], [70.46291351, 23.05680466], [70.46291351, 23.05652809], [70.46235657, 23.05653191], [70.46235657, 23.05626106], [70.46208954, 23.05626106], [70.46208954, 23.05596924], [70.46152496, 23.05597115], [70.46152496, 23.05569458], [70.46097565, 23.05569458], [70.46097565, 23.05541611], [70.46069336, 23.05541611], [70.46069336, 23.05569077], [70.4604187, 23.05570984], [70.4604187, 23.05626106], [70.46013641, 23.05626106], [70.46013641, 23.05653191], [70.46069336, 23.05652809], [70.46069336, 23.05680466], [70.46098328, 23.05680084], [70.46098328, 23.05764008], [70.46125031, 23.05764008], [70.46125031, 23.05792046], [70.46208954, 23.05792046], [70.46208954, 23.05820084], [70.46263885, 23.05819511], [70.46263885, 23.05847359], [70.4631958, 23.05846977], [70.4631958, 23.05875015], [70.46375275, 23.05875015], [70.46375275, 23.05903053], [70.46457672, 23.05903053], [70.46457672, 23.05932045], [70.4651413, 23.05930328], [70.4651413, 23.05958366], [70.46541595, 23.05957985], [70.46541595, 23.05986023], [70.4659729, 23.05986023], [70.4659729, 23.06014061], [70.46652985, 23.06014061], [70.46652985, 23.06042099], [70.46708679, 23.06041718], [70.46708679, 23.06069565], [70.46763611, 23.06069565], [70.46763611, 23.06097221], [70.46819305, 23.06097031], [70.46819305, 23.06125069], [70.4695816, 23.06125069]]], [[[70.45207977, 23.06069565], [70.45207977, 23.06041718], [70.45236206, 23.06042099], [70.45236206, 23.05986023], [70.45207977, 23.05986023], [70.45207977, 23.05932045], [70.45124817, 23.05932045], [70.45124817, 23.05903053], [70.45069122, 23.05903053], [70.45069122, 23.05875015], [70.45014191, 23.05875015], [70.45014191, 23.05847359], [70.44958496, 23.05847359], [70.44958496, 23.05819511], [70.44902802, 23.05820084], [70.44902802, 23.05792046], [70.44625092, 23.05792046], [70.44625092, 23.05820084], [70.44596863, 23.05819511], [70.44596863, 23.05847359], [70.44625092, 23.05846977], [70.44625092, 23.05875015], [70.44680786, 23.05875015], [70.44680786, 23.05903053], [70.44709015, 23.05903053], [70.44709015, 23.05932045], [70.44819641, 23.05930328], [70.44819641, 23.05958366], [70.44902802, 23.05957985], [70.44902802, 23.05986023], [70.45014954, 23.05986023], [70.45014954, 23.06014061], [70.45096588, 23.06014061], [70.45096588, 23.06042099], [70.45153046, 23.06041718], [70.45153046, 23.06069565], [70.45207977, 23.06069565]]], [[[68.47319794, 23.35680962], [68.47319794, 23.35653114], [68.4734726, 23.35653114], [68.4734726, 23.35625076], [68.47402954, 23.35625076], [68.47402954, 23.35597038], [68.4743042, 23.35597229], [68.4743042, 23.35569572], [68.4751358, 23.35569572], [68.4751358, 23.35486031], [68.47541809, 23.35486031], [68.47541809, 23.35514069], [68.47570038, 23.35514069], [68.47570038, 23.35542107], [68.47651672, 23.35542107], [68.47651672, 23.35403061], [68.47624969, 23.35403061], [68.47624969, 23.35346985], [68.47486115, 23.35346985], [68.47486115, 23.35375023], [68.47402954, 23.35375023], [68.47402954, 23.35403061], [68.4734726, 23.3540287], [68.4734726, 23.35458565], [68.47374725, 23.35457993], [68.47374725, 23.35514069], [68.47207642, 23.35514069], [68.47207642, 23.35542107], [68.47180176, 23.35541725], [68.47180176, 23.35569572], [68.4715271, 23.35569572], [68.4715271, 23.35597229], [68.47097015, 23.35597038], [68.47097015, 23.35625076], [68.47125244, 23.35625076], [68.47125244, 23.35680962], [68.47319794, 23.35680962]]], [[[68.53514099, 23.38763809], [68.53514099, 23.3870697], [68.5348587, 23.38708305], [68.5348587, 23.38652992], [68.53457642, 23.38652992], [68.53457642, 23.38597107], [68.53430939, 23.38597298], [68.53430176, 23.38541794], [68.5340271, 23.38541985], [68.5340271, 23.38486099], [68.53375244, 23.38486099], [68.53375244, 23.38513947], [68.53235626, 23.38513947], [68.53235626, 23.38458061], [68.5320816, 23.38458252], [68.5320816, 23.38263893], [68.53235626, 23.38264084], [68.53235626, 23.38208008], [68.53263855, 23.3820858], [68.53263855, 23.38152695], [68.53291321, 23.38153076], [68.53291321, 23.38125992], [68.53263855, 23.38125992], [68.53263855, 23.38097], [68.5320816, 23.38097382], [68.5320816, 23.38069534], [68.53235626, 23.38070107], [68.53235626, 23.38042068], [68.5340271, 23.38042068], [68.5340271, 23.37957954], [68.53375244, 23.37958145], [68.53375244, 23.37874985], [68.53430176, 23.37874985], [68.53430176, 23.37792015], [68.53347015, 23.37792015], [68.53347015, 23.37763977], [68.53291321, 23.37763977], [68.53291321, 23.37708092], [68.53263855, 23.37708282], [68.53263855, 23.37680626], [68.5348587, 23.37680626], [68.5348587, 23.37708282], [68.53531647, 23.37708282], [68.5359726, 23.37708282], [68.5359726, 23.3773613], [68.53624725, 23.37735939], [68.53624725, 23.37763977], [68.53652954, 23.37763977], [68.53652954, 23.37735939], [68.5368042, 23.3773613], [68.5368042, 23.37652779], [68.53652954, 23.3765316], [68.53652954, 23.37624931], [68.53514099, 23.37624931], [68.53514099, 23.37597084], [68.53457642, 23.37597084], [68.53457642, 23.37624931], [68.53430939, 23.37624931], [68.53430176, 23.37597084], [68.5340271, 23.37597275], [68.5340271, 23.37559128], [68.5340271, 23.37486076], [68.53375244, 23.37486076], [68.53375244, 23.37431145], [68.5340271, 23.37431145], [68.5340271, 23.37375069], [68.53457642, 23.37375069], [68.53457642, 23.37431145], [68.5348587, 23.37431145], [68.5348587, 23.37486076], [68.53514099, 23.37486076], [68.53514099, 23.37542152], [68.53569794, 23.37542152], [68.53569794, 23.37486076], [68.53652954, 23.37486076], [68.53652954, 23.37431145], [68.53679657, 23.37431145], [68.53679657, 23.37402916], [68.53624725, 23.37402916], [68.53624725, 23.37375069], [68.53652954, 23.37375069], [68.53652954, 23.37347031], [68.5368042, 23.37347221], [68.5368042, 23.3726387], [68.53652954, 23.37264061], [68.53652954, 23.37236023], [68.53624725, 23.37236023], [68.53624725, 23.37207031], [68.5359726, 23.37208366], [68.5359726, 23.37180519], [68.53569794, 23.37181091], [68.53569794, 23.37153053], [68.53542328, 23.37153053], [68.53542328, 23.37125015], [68.53430176, 23.37125015], [68.53430176, 23.37153053], [68.53347015, 23.37153053], [68.53347015, 23.37181091], [68.53291321, 23.37180519], [68.53291321, 23.37208366], [68.53320312, 23.37207031], [68.53320312, 23.37264061], [68.53291321, 23.3726387], [68.53291321, 23.37297058], [68.53291321, 23.37319374], [68.53263855, 23.37318993], [68.53263855, 23.37375069], [68.53235626, 23.37375069], [68.53235626, 23.37486076], [68.5320816, 23.37486076], [68.5320816, 23.37624931], [68.53180695, 23.37624931], [68.53180695, 23.37847137], [68.53151703, 23.37846947], [68.53151703, 23.38042068], [68.53125, 23.38042068], [68.53125, 23.38125992], [68.53097534, 23.38125038], [68.53097534, 23.3820858], [68.53069305, 23.38208008], [68.53069305, 23.38292122], [68.5304184, 23.3829174], [68.5304184, 23.38319588], [68.53069305, 23.38319016], [68.53069305, 23.38486099], [68.53125, 23.38486099], [68.53125, 23.38513947], [68.53180695, 23.38513947], [68.53180695, 23.38541985], [68.5320816, 23.38541794], [68.5320816, 23.3856945], [68.53263855, 23.3856945], [68.53263855, 23.38597298], [68.5331955, 23.38597298], [68.5331955, 23.38624954], [68.53347015, 23.38624954], [68.53347015, 23.38652992], [68.53375244, 23.38652992], [68.53375244, 23.3868084], [68.5340271, 23.38680649], [68.5340271, 23.38736153], [68.53430176, 23.38735962], [68.53430176, 23.38763809], [68.53514099, 23.38763809]]], [[[68.50291443, 23.38347244], [68.50291443, 23.38319588], [68.50319672, 23.38319588], [68.50319672, 23.38263893], [68.50347137, 23.38264084], [68.50347137, 23.38236046], [68.50319672, 23.38236046], [68.50319672, 23.38208008], [68.50291443, 23.3820858], [68.50291443, 23.38097382], [68.50319672, 23.38097382], [68.50319672, 23.38069534], [68.50347137, 23.38070107], [68.50347137, 23.38042068], [68.50374603, 23.38042068], [68.50374603, 23.3801403], [68.50430298, 23.3801403], [68.50430298, 23.37985992], [68.50514221, 23.37986374], [68.50514221, 23.37902832], [68.50541687, 23.37903023], [68.50541687, 23.37874985], [68.50514221, 23.37874985], [68.50514221, 23.37799072], [68.50514221, 23.3773613], [68.50430298, 23.37735939], [68.50430298, 23.37763977], [68.50374603, 23.37763977], [68.50374603, 23.37792015], [68.50319672, 23.37791634], [68.50319672, 23.37808037], [68.50319672, 23.37820053], [68.50291443, 23.37819481], [68.50291443, 23.37847137], [68.50263977, 23.37846947], [68.50263977, 23.37903023], [68.50291443, 23.37902832], [68.50291443, 23.37930489], [68.50263977, 23.37930489], [68.50263977, 23.37986374], [68.50235748, 23.37985992], [68.50235748, 23.38042068], [68.50208282, 23.38041687], [68.50208282, 23.38097382], [68.50180817, 23.38097382], [68.50180817, 23.3820858], [68.50235748, 23.38208008], [68.50235748, 23.38236046], [68.50263977, 23.38236046], [68.50263977, 23.38347244], [68.50291443, 23.38347244]]], [[[68.50597382, 23.34236145], [68.50597382, 23.34208488], [68.50624847, 23.34209061], [68.50624847, 23.34152985], [68.50653076, 23.34152985], [68.50653076, 23.34097099], [68.50875092, 23.34097481], [68.50875092, 23.34069252], [68.50961304, 23.34069252], [68.51041412, 23.34069252], [68.51041412, 23.34041405], [68.51097107, 23.34041977], [68.51097107, 23.34013939], [68.51152802, 23.34013939], [68.51152802, 23.33986282], [68.51235962, 23.33986282], [68.51235962, 23.33958054], [68.51291656, 23.33958244], [68.51291656, 23.33930588], [68.51374817, 23.33930588], [68.51374817, 23.33958244], [68.51457977, 23.33958054], [68.51457977, 23.33986282], [68.51513672, 23.33986282], [68.51513672, 23.34013939], [68.51541901, 23.34013939], [68.51541901, 23.34041977], [68.51569366, 23.34041405], [68.51569366, 23.34097481], [68.51597595, 23.34097099], [68.51597595, 23.34124947], [68.5167923, 23.34124947], [68.51790619, 23.34124947], [68.51790619, 23.34152985], [68.51930237, 23.34152985], [68.51930237, 23.34124947], [68.51985931, 23.34124947], [68.51985931, 23.34097099], [68.5201416, 23.34097481], [68.5201416, 23.34069252], [68.52069092, 23.34069252], [68.52069092, 23.33930588], [68.52041626, 23.33930969], [68.52041626, 23.33875275], [68.52153015, 23.33875275], [68.52153015, 23.33708191], [68.52180481, 23.33708382], [68.52180481, 23.33680534], [68.52236176, 23.33681107], [68.52236176, 23.33653259], [68.52263641, 23.33653259], [68.52263641, 23.33736038], [68.5229187, 23.33736038], [68.5229187, 23.33792114], [68.5256958, 23.33792114], [68.5256958, 23.33736038], [68.52597046, 23.33736038], [68.52597046, 23.33708191], [68.5276413, 23.33708382], [68.5276413, 23.33652687], [68.52791595, 23.33653259], [68.52791595, 23.3354187], [68.52819824, 23.3354187], [68.52819824, 23.33457756], [68.5284729, 23.33458328], [68.5284729, 23.3334713], [68.52874756, 23.3334713], [68.52874756, 23.33263969], [68.5284729, 23.33263969], [68.5284729, 23.33152962], [68.52819824, 23.33152962], [68.52819824, 23.33097076], [68.52735901, 23.33097267], [68.52735901, 23.3306942], [68.5265274, 23.3306942], [68.5265274, 23.33041763], [68.5256958, 23.33041954], [68.5256958, 23.3301506], [68.52597046, 23.3301506], [68.52597046, 23.32958031], [68.52625275, 23.32958412], [68.52625275, 23.32902718], [68.5265274, 23.32903099], [68.5265274, 23.32875061], [68.52680969, 23.32875061], [68.52680206, 23.32819557], [68.52708435, 23.32819557], [68.52708435, 23.3279171], [68.52735901, 23.32792091], [68.52735901, 23.32764053], [68.5276413, 23.32764053], [68.5276413, 23.32736015], [68.52791595, 23.32736206], [68.52791595, 23.32708549], [68.52819824, 23.32708549], [68.52819824, 23.32680321], [68.5284729, 23.32681084], [68.5284729, 23.32653046], [68.52874756, 23.32653046], [68.52874756, 23.32625008], [68.52902985, 23.32625008], [68.52902985, 23.3259697], [68.52986145, 23.3259716], [68.52986145, 23.32569313], [68.5304184, 23.32570076], [68.5304184, 23.32542038], [68.53125, 23.32542038], [68.53125, 23.32514191], [68.53180695, 23.32514191], [68.53180695, 23.32485962], [68.53375244, 23.32486343], [68.53375244, 23.32458115], [68.5340271, 23.32458115], [68.5340271, 23.32430649], [68.53430176, 23.3243103], [68.53430939, 23.32401848], [68.5348587, 23.32402802], [68.5348587, 23.32374954], [68.53514099, 23.32374954], [68.53514099, 23.32346916], [68.53541565, 23.32347107], [68.53541565, 23.3231945], [68.53569794, 23.3231945], [68.53569794, 23.32291603], [68.53598022, 23.32292175], [68.53598022, 23.32263947], [68.53624725, 23.32263947], [68.53624725, 23.32235909], [68.53679657, 23.32235909], [68.53679657, 23.32208061], [68.53708649, 23.32208252], [68.53708649, 23.32180595], [68.53736115, 23.32181168], [68.53736115, 23.32068825], [68.53624725, 23.32068825], [68.53624725, 23.32125092], [68.53598022, 23.32125092], [68.53598022, 23.32181168], [68.53569794, 23.32180595], [68.53569794, 23.32208252], [68.53541565, 23.32208252], [68.53541565, 23.32180595], [68.5348587, 23.32181168], [68.5348587, 23.32152939], [68.53457642, 23.32152939], [68.53457642, 23.32125092], [68.53430939, 23.32125092], [68.53430176, 23.32068825], [68.5340271, 23.32069397], [68.5340271, 23.3204174], [68.53430176, 23.32041931], [68.53430939, 23.31986046], [68.53624725, 23.31986046], [68.53624725, 23.31957817], [68.53652954, 23.31958389], [68.53652954, 23.31930542], [68.53679657, 23.31931114], [68.53679657, 23.31903076], [68.53736115, 23.31903076], [68.53736115, 23.31875038], [68.5376358, 23.31875038], [68.5376358, 23.31847], [68.53736115, 23.31847191], [68.53736115, 23.31819534], [68.53708649, 23.3182106], [68.53708649, 23.31792068], [68.53652954, 23.31792068], [68.53652954, 23.3176403], [68.53624725, 23.3176403], [68.53624725, 23.31735992], [68.5359726, 23.31736183], [68.5359726, 23.31680679], [68.53569794, 23.31680679], [68.53569794, 23.31652832], [68.5304184, 23.31652832], [68.5304184, 23.31680679], [68.52791595, 23.31680679], [68.52791595, 23.31708336], [68.51930237, 23.31708336], [68.51930237, 23.31736183], [68.51763916, 23.31735992], [68.51763916, 23.3176403], [68.51625061, 23.3176403], [68.51625061, 23.31792068], [68.51513672, 23.31792068], [68.51513672, 23.3182106], [68.51319122, 23.31819534], [68.51319122, 23.31847191], [68.51152802, 23.31847], [68.51152802, 23.31875038], [68.51097107, 23.31875038], [68.51097107, 23.31903076], [68.51040649, 23.31903076], [68.51040649, 23.31931114], [68.50958252, 23.31930542], [68.50958252, 23.31958389], [68.50902557, 23.31958389], [68.5090332, 23.31986046], [68.50846863, 23.31986046], [68.50846863, 23.32014084], [68.50791931, 23.32014084], [68.50791931, 23.32041931], [68.50763702, 23.3204174], [68.50763702, 23.32069397], [68.50708008, 23.32068825], [68.50708008, 23.32098007], [68.50680542, 23.32097244], [68.50681305, 23.32125092], [68.50653076, 23.32125092], [68.50653076, 23.32152939], [68.50624847, 23.32152939], [68.50624847, 23.32181168], [68.50569153, 23.32180595], [68.50569153, 23.32208252], [68.50541687, 23.32208061], [68.50541687, 23.32235909], [68.50514221, 23.32235909], [68.50514221, 23.32263947], [68.5045929, 23.32263947], [68.5045929, 23.32292175], [68.50402832, 23.32291603], [68.50402832, 23.3231945], [68.50347137, 23.3231945], [68.50347137, 23.32347107], [68.5029068, 23.32346916], [68.5029068, 23.32374954], [68.50235748, 23.32374954], [68.50235748, 23.32402802], [68.5029068, 23.32401848], [68.5029068, 23.3243103], [68.50319672, 23.32430649], [68.50319672, 23.32458115], [68.50347137, 23.32458115], [68.50347137, 23.32486343], [68.50374603, 23.32485962], [68.50374603, 23.32542038], [68.50402832, 23.32542038], [68.50402832, 23.32570076], [68.50430298, 23.32570076], [68.50430298, 23.32792091], [68.5045929, 23.32792091], [68.5045929, 23.32707977], [68.50514221, 23.32707977], [68.50514221, 23.32903099], [68.50485992, 23.32902718], [68.50485992, 23.32958412], [68.50541687, 23.32958031], [68.50541687, 23.32986069], [68.50514221, 23.32986069], [68.50514221, 23.3306942], [68.50541687, 23.3306942], [68.50541687, 23.33097267], [68.50596619, 23.33097076], [68.50596619, 23.33125114], [68.50681305, 23.33125114], [68.50681305, 23.33152962], [68.50708008, 23.33152771], [68.50708008, 23.33208275], [68.50680542, 23.33208275], [68.50681305, 23.33236122], [68.50653076, 23.33236122], [68.50653076, 23.33263969], [68.50624847, 23.33263969], [68.50624847, 23.33291817], [68.50596619, 23.33291817], [68.50596619, 23.33374977], [68.50653076, 23.33374977], [68.50653076, 23.3354187], [68.50596619, 23.3354187], [68.50596619, 23.33513832], [68.50567627, 23.33513832], [68.50567627, 23.33429909], [68.50541687, 23.33430481], [68.50541687, 23.3334713], [68.50514221, 23.3334713], [68.50514221, 23.33319473], [68.50485992, 23.33319473], [68.50485992, 23.33291626], [68.5045929, 23.33291817], [68.5045929, 23.33180809], [68.50430298, 23.33180618], [68.50430298, 23.33208275], [68.50319672, 23.33208084], [68.50319672, 23.33291817], [68.50291443, 23.33291626], [68.50291443, 23.33430481], [68.50319672, 23.33430481], [68.50319672, 23.33458328], [68.50347137, 23.33457756], [68.50347137, 23.3357029], [68.50319672, 23.3357029], [68.50319672, 23.33736038], [68.50291443, 23.33736038], [68.50291443, 23.3390274], [68.50263977, 23.33902168], [68.50263977, 23.34041977], [68.50291443, 23.34041405], [68.50291443, 23.34097481], [68.50319672, 23.34097099], [68.50319672, 23.34124947], [68.50347137, 23.34124947], [68.50347137, 23.34152985], [68.50374603, 23.34152985], [68.50374603, 23.34209061], [68.50402832, 23.34208488], [68.50402832, 23.34236145], [68.50597382, 23.34236145]]], [[[68.52513885, 23.34403038], [68.52513885, 23.34375], [68.52902985, 23.34375], [68.52902985, 23.34346962], [68.52958679, 23.34347153], [68.52958679, 23.34319687], [68.5304184, 23.34320068], [68.5304184, 23.3429203], [68.53098297, 23.3429203], [68.53098297, 23.34263992], [68.53125, 23.34263992], [68.53125, 23.34235954], [68.53180695, 23.34236145], [68.53180695, 23.34208488], [68.5320816, 23.34209061], [68.5320816, 23.34181023], [68.53235626, 23.34181023], [68.53235626, 23.34152985], [68.53263855, 23.34152985], [68.53263855, 23.34097099], [68.53236389, 23.34097481], [68.53236389, 23.34069252], [68.5320816, 23.34069252], [68.5320816, 23.33930588], [68.53069305, 23.33930969], [68.53069305, 23.34013939], [68.5304184, 23.34013939], [68.5304184, 23.34097481], [68.5293045, 23.34097481], [68.5293045, 23.34041405], [68.52874756, 23.34041405], [68.52874756, 23.34069252], [68.52819824, 23.34069252], [68.52819061, 23.34097481], [68.5276413, 23.34097099], [68.5276413, 23.34124947], [68.52707672, 23.34124947], [68.52707672, 23.34152985], [68.52597046, 23.34152985], [68.52597046, 23.34181023], [68.52513885, 23.34181023], [68.52513885, 23.34209061], [68.52402496, 23.34208488], [68.52402496, 23.34236145], [68.52319336, 23.34235954], [68.52319336, 23.34263992], [68.52124786, 23.34263802], [68.52124786, 23.34347153], [68.52319336, 23.34346962], [68.52319336, 23.34375], [68.52375031, 23.34375], [68.52375031, 23.34403038], [68.52513885, 23.34403038]]], [[[68.60901642, 23.23125267], [68.60901642, 23.23097038], [68.60958099, 23.23097038], [68.60958099, 23.23069382], [68.60986328, 23.23069954], [68.60986328, 23.23042107], [68.61013794, 23.23042107], [68.61013794, 23.22986031], [68.61042023, 23.22986031], [68.61042023, 23.22958183], [68.61069489, 23.22958374], [68.61069489, 23.22930527], [68.61096954, 23.2293129], [68.61096954, 23.22874832], [68.61125946, 23.22874832], [68.61125183, 23.22819519], [68.61152649, 23.22820091], [68.61152649, 23.22763062], [68.61180878, 23.22763824], [68.61180878, 23.22680473], [68.61208344, 23.22680473], [68.61208344, 23.22569466], [68.61235809, 23.22569466], [68.61235809, 23.22458267], [68.61264038, 23.22458267], [68.61264038, 23.22402763], [68.61292267, 23.22402954], [68.61292267, 23.22347069], [68.61319733, 23.2234726], [68.61319733, 23.22263908], [68.61347198, 23.22264099], [68.61347198, 23.22208023], [68.61374664, 23.22208595], [68.61374664, 23.22180557], [68.61347198, 23.22182083], [68.61347198, 23.22153091], [68.61292267, 23.22153091], [68.61292267, 23.22125053], [68.61235809, 23.22125053], [68.61235809, 23.22153091], [68.61208344, 23.2215271], [68.61208344, 23.22208595], [68.61180878, 23.22208595], [68.61180878, 23.22180557], [68.61013794, 23.22180557], [68.61013794, 23.22208595], [68.60986328, 23.22208023], [68.60986328, 23.22236061], [68.60847473, 23.22236061], [68.6084671, 23.22344017], [68.6084671, 23.22402954], [68.60819244, 23.22402954], [68.60819244, 23.2232914], [68.60819244, 23.22319412], [68.60801697, 23.22319412], [68.60791779, 23.22319412], [68.60791779, 23.22263908], [68.60764313, 23.22264099], [68.60764313, 23.22236061], [68.60643768, 23.22236061], [68.60597229, 23.22236061], [68.60597229, 23.22264099], [68.60569763, 23.22264099], [68.60569763, 23.22291946], [68.60541534, 23.22291756], [68.60541534, 23.22319412], [68.60514069, 23.22319412], [68.60514069, 23.2234726], [68.6048584, 23.22347069], [68.6048584, 23.22375107], [68.60458374, 23.22374916], [68.60458374, 23.22458267], [68.60430908, 23.22457123], [68.60430908, 23.22486115], [68.60402679, 23.22486115], [68.60402679, 23.22513962], [68.60375214, 23.22513962], [68.60375214, 23.22569466], [68.60346985, 23.22569466], [68.60346985, 23.22680473], [68.60319519, 23.22680473], [68.60319519, 23.22847176], [68.60346985, 23.22846985], [68.60346985, 23.22903252], [68.60375214, 23.22903252], [68.60375214, 23.22986031], [68.60402679, 23.22986031], [68.60402679, 23.23069954], [68.60569763, 23.23069382], [68.60569763, 23.23097038], [68.60652924, 23.23097038], [68.60652924, 23.23125267], [68.60901642, 23.23125267]]], [[[68.59430695, 23.26208305], [68.59430695, 23.26180649], [68.59485626, 23.2618103], [68.59485626, 23.26152992], [68.59541321, 23.26152992], [68.59541321, 23.26068115], [68.59764099, 23.2606926], [68.59764099, 23.26013947], [68.5973587, 23.26013947], [68.5973587, 23.2598629], [68.59707642, 23.2598629], [68.59707642, 23.25958061], [68.59680939, 23.25958443], [68.59680176, 23.25930405], [68.59625244, 23.25930405], [68.59625244, 23.25958443], [68.5945816, 23.25958061], [68.5945816, 23.2598629], [68.59430695, 23.2598629], [68.59430695, 23.26013947], [68.59402466, 23.26013947], [68.59402466, 23.2606926], [68.59375, 23.2606926], [68.59375, 23.26208305], [68.59430695, 23.26208305]]], [[[68.65847015, 23.27124977], [68.65847015, 23.27096939], [68.65875244, 23.2709713], [68.65875244, 23.27069473], [68.6590271, 23.27069473], [68.6590271, 23.27041626], [68.65930939, 23.27042007], [68.65930939, 23.26987267], [68.6590271, 23.26987267], [68.6590271, 23.26958084], [68.65875244, 23.26958275], [68.65875244, 23.26930618], [68.65957642, 23.2693119], [68.65957642, 23.26903152], [68.66014099, 23.26903152], [68.66014099, 23.26874924], [68.66042328, 23.26874924], [68.66042328, 23.26847076], [68.66014099, 23.26847267], [68.66014099, 23.26791573], [68.65875244, 23.26791573], [68.65875244, 23.2681942], [68.65847015, 23.2681942], [68.65847015, 23.26847267], [68.65735626, 23.26847076], [68.65735626, 23.26874924], [68.6570816, 23.26874924], [68.6570816, 23.2693119], [68.65680695, 23.2693119], [68.65680695, 23.26987267], [68.6570816, 23.26987267], [68.6570816, 23.27013969], [68.65735626, 23.27013969], [68.65735626, 23.27042007], [68.65763855, 23.27041626], [68.65763855, 23.27069473], [68.65791321, 23.27069473], [68.65791321, 23.2709713], [68.6581955, 23.2709713], [68.6581955, 23.27124977], [68.65847015, 23.27124977]]], [[[68.55819702, 23.31375122], [68.55819702, 23.31347084], [68.55847168, 23.31347466], [68.55847168, 23.31319237], [68.55874634, 23.31319237], [68.55874634, 23.3129158], [68.55902863, 23.31291962], [68.55902863, 23.31264114], [68.55930328, 23.31264114], [68.55930328, 23.31208038], [68.55958557, 23.31208229], [68.55958557, 23.31152725], [68.55986023, 23.31153107], [68.55986023, 23.31097031], [68.56014252, 23.31097031], [68.56014252, 23.31041718], [68.56041718, 23.3104229], [68.56041718, 23.30986023], [68.56069183, 23.30986023], [68.56069183, 23.30904007], [68.56096649, 23.30904007], [68.56096649, 23.30846977], [68.56124878, 23.30847168], [68.56124878, 23.30763817], [68.56153107, 23.30763817], [68.56153107, 23.30680084], [68.56180573, 23.30680466], [68.56180573, 23.30597305], [68.56208038, 23.30598068], [68.56208038, 23.30541992], [68.56236267, 23.30541992], [68.56236267, 23.30458069], [68.56263733, 23.3045826], [68.56263733, 23.30374908], [68.56291962, 23.30375099], [68.56291962, 23.30319023], [68.56319427, 23.30319595], [68.56319427, 23.30263901], [68.56346893, 23.30264091], [68.56346893, 23.30181122], [68.56375122, 23.30181122], [68.56375122, 23.30125046], [68.56402588, 23.30125046], [68.56402588, 23.30070114], [68.56430817, 23.30070114], [68.56430817, 23.30153084], [68.56458282, 23.30152512], [68.56458282, 23.30208588], [68.56680298, 23.30208588], [68.56680298, 23.3018055], [68.56735992, 23.30181122], [68.56735992, 23.30153084], [68.56764221, 23.30153084], [68.56764221, 23.30125046], [68.56791687, 23.30125046], [68.56791687, 23.30097008], [68.56874847, 23.30097389], [68.56874847, 23.30069542], [68.56986237, 23.3006897], [68.56986237, 23.30041695], [68.57041931, 23.30042076], [68.57041931, 23.29931068], [68.57068634, 23.29931068], [68.57068634, 23.29764175], [68.57096863, 23.29764175], [68.57096863, 23.29707909], [68.57125092, 23.2970829], [68.57125092, 23.29624939], [68.5715332, 23.29624939], [68.57152557, 23.29597282], [68.57180786, 23.29597282], [68.57180786, 23.29569435], [68.57236481, 23.29569435], [68.57236481, 23.29541588], [68.57263947, 23.2954216], [68.57263947, 23.29513931], [68.57290649, 23.29513931], [68.57290649, 23.29486084], [68.57347107, 23.29486084], [68.57347107, 23.29458046], [68.57402802, 23.29458427], [68.57402802, 23.2943058], [68.57485962, 23.2943058], [68.57485962, 23.29458427], [68.57514954, 23.29458046], [68.57514954, 23.29513931], [68.57485962, 23.29513931], [68.57485962, 23.29569435], [68.57457733, 23.29569054], [68.57457733, 23.29624939], [68.57430267, 23.29624939], [68.57430267, 23.29653168], [68.57402802, 23.29653168], [68.57402802, 23.29681015], [68.57375336, 23.29680634], [68.57375336, 23.2970829], [68.57347107, 23.2970829], [68.57347107, 23.29736137], [68.57319641, 23.29735947], [68.57319641, 23.29792023], [68.57291412, 23.29791641], [68.57291412, 23.29819489], [68.57263947, 23.29819489], [68.57263947, 23.29958153], [68.57235718, 23.29957962], [68.57235718, 23.30014038], [68.57208252, 23.30014038], [68.57208252, 23.30042076], [68.57180786, 23.30041695], [68.57180786, 23.30097389], [68.5715332, 23.30097008], [68.5715332, 23.30153084], [68.57180786, 23.30153084], [68.57180786, 23.30236053], [68.57208252, 23.30236053], [68.57208252, 23.30347252], [68.57235718, 23.30347061], [68.57235718, 23.30375099], [68.57514954, 23.30375099], [68.57514954, 23.30347061], [68.57569122, 23.30347252], [68.57569122, 23.30319595], [68.57624817, 23.30319595], [68.57624817, 23.30291748], [68.57707977, 23.30291939], [68.57707977, 23.30264091], [68.57763672, 23.30264091], [68.57763672, 23.30236053], [68.57818604, 23.30236053], [68.57818604, 23.30208015], [68.57958221, 23.30208588], [68.57958221, 23.3018055], [68.58040619, 23.30181122], [68.58040619, 23.30153084], [68.58096313, 23.30153084], [68.58096313, 23.30125046], [68.58180237, 23.30125046], [68.58180237, 23.30097008], [68.58235931, 23.30097389], [68.58235931, 23.30069542], [68.5826416, 23.3006897], [68.5826416, 23.30041695], [68.58291626, 23.30042076], [68.58291626, 23.30014038], [68.58347321, 23.30014038], [68.58347321, 23.29985046], [68.58486176, 23.29986382], [68.58486176, 23.29958153], [68.58513641, 23.29958153], [68.58513641, 23.29930305], [68.5854187, 23.29931068], [68.5854187, 23.2990303], [68.58569336, 23.2990303], [68.58569336, 23.29819107], [68.58597565, 23.29819489], [68.58597565, 23.29680634], [68.58625031, 23.29681015], [68.58625031, 23.29648018], [68.58625031, 23.29624939], [68.58653259, 23.29624939], [68.58652496, 23.29569435], [68.58680725, 23.29569435], [68.58680725, 23.29541588], [68.58708954, 23.2954216], [68.58708954, 23.29513931], [68.58735657, 23.29513931], [68.58735657, 23.29486084], [68.58763885, 23.29486084], [68.58766174, 23.29513931], [68.58790588, 23.29513931], [68.58790588, 23.2954216], [68.5881958, 23.29541588], [68.5881958, 23.29597282], [68.58847046, 23.29597092], [68.58847046, 23.29653168], [68.58875275, 23.29653168], [68.58875275, 23.29764175], [68.58847046, 23.29764175], [68.58847046, 23.29792023], [68.5881958, 23.29791641], [68.5881958, 23.29819489], [68.58790588, 23.29819107], [68.58790588, 23.29874992], [68.58763885, 23.29874992], [68.58763885, 23.29958153], [68.5873642, 23.29958153], [68.5873642, 23.30097389], [68.58708191, 23.30097389], [68.58708954, 23.30125046], [68.58680725, 23.30125046], [68.58680725, 23.30153084], [68.58652496, 23.30152512], [68.58652496, 23.30208588], [68.58597565, 23.30208588], [68.58597565, 23.30152512], [68.5854187, 23.30153084], [68.5854187, 23.30181122], [68.58486176, 23.3018055], [68.58486176, 23.30208588], [68.5845871, 23.30208015], [68.5845871, 23.30264091], [68.58429718, 23.30264091], [68.58429718, 23.30486107], [68.58403015, 23.30486107], [68.58403015, 23.30513954], [68.58347321, 23.30513954], [68.58347321, 23.30541992], [68.58319092, 23.30541611], [68.58319092, 23.30569458], [68.5826416, 23.30569077], [68.5826416, 23.30598068], [68.58235931, 23.30598068], [68.58235931, 23.30624962], [68.58207703, 23.30624962], [68.58207703, 23.30763817], [68.58180237, 23.30763817], [68.58180237, 23.30847168], [68.58207703, 23.30846977], [68.58207703, 23.30904007], [68.58180237, 23.30902863], [68.58180237, 23.30958366], [68.58207703, 23.30958176], [68.58207703, 23.31014252], [68.58235931, 23.31014252], [68.58235931, 23.30986023], [68.58291626, 23.30986023], [68.58291626, 23.30958176], [68.58319092, 23.30958366], [68.58319092, 23.30930519], [68.58347321, 23.30931282], [68.58347321, 23.30874825], [68.58374786, 23.30874825], [68.58374786, 23.30846977], [68.58430481, 23.30847168], [68.58430481, 23.30819511], [68.5845871, 23.30820084], [68.5845871, 23.30791855], [68.58513641, 23.30791855], [68.58513641, 23.30763817], [68.5854187, 23.30763817], [68.5854187, 23.3073597], [68.58597565, 23.3073616], [68.58597565, 23.30708313], [68.58652496, 23.30708313], [68.58652496, 23.30680466], [68.58680725, 23.30680466], [68.58680725, 23.30652809], [68.58735657, 23.30652809], [68.58735657, 23.30624962], [68.5881958, 23.30624962], [68.5881958, 23.30598068], [68.5890274, 23.30598068], [68.5890274, 23.30569077], [68.58930206, 23.30569458], [68.58930206, 23.30541611], [68.58957672, 23.30541992], [68.58957672, 23.30513954], [68.58985901, 23.30513954], [68.58985901, 23.30486107], [68.59014893, 23.30486107], [68.5901413, 23.30430794], [68.59069824, 23.30430984], [68.59069824, 23.30402946], [68.5909729, 23.30402946], [68.5909729, 23.30375099], [68.59152985, 23.30375099], [68.59152985, 23.30347061], [68.5918045, 23.30347252], [68.5918045, 23.30319595], [68.59208679, 23.30319595], [68.59208679, 23.30291748], [68.59236145, 23.30291939], [68.59236145, 23.30264091], [68.5929184, 23.30264091], [68.5929184, 23.30236053], [68.59319305, 23.30236053], [68.59319305, 23.30208015], [68.59347534, 23.30208588], [68.59347534, 23.3018055], [68.59375, 23.30181122], [68.59375, 23.30153084], [68.59430695, 23.30153084], [68.59430695, 23.30125046], [68.5945816, 23.30125046], [68.5945816, 23.30097008], [68.59486389, 23.30097389], [68.59486389, 23.30069542], [68.59513855, 23.3006897], [68.59513855, 23.30041695], [68.59541321, 23.30042076], [68.59541321, 23.29985046], [68.5956955, 23.29986382], [68.5956955, 23.29958153], [68.59625244, 23.29957962], [68.59625244, 23.30014038], [68.5965271, 23.30014038], [68.5965271, 23.30042076], [68.59680176, 23.30042076], [68.59680939, 23.30014038], [68.59731293, 23.30014038], [68.59749603, 23.30014038], [68.59874725, 23.30014038], [68.59874725, 23.29985046], [68.60236359, 23.29986382], [68.60236359, 23.29930305], [68.60263824, 23.29931068], [68.60263824, 23.2990303], [68.60320282, 23.2990303], [68.60320282, 23.29931068], [68.60457611, 23.29931068], [68.60457611, 23.2990303], [68.60513306, 23.2990303], [68.60513306, 23.29874992], [68.60569763, 23.29874992], [68.60569763, 23.29846954], [68.6062088, 23.29846954], [68.60708618, 23.29847145], [68.60708618, 23.29764175], [68.60764313, 23.29764175], [68.60764313, 23.29735947], [68.60874939, 23.29736137], [68.60874939, 23.2970829], [68.60986328, 23.2970829], [68.60986328, 23.29680634], [68.61152649, 23.29681015], [68.61152649, 23.29653168], [68.61207581, 23.29653168], [68.61207581, 23.29569054], [68.60819244, 23.29569435], [68.60819244, 23.29541588], [68.60736084, 23.2954216], [68.60736084, 23.29486084], [68.60764313, 23.29486084], [68.6076355, 23.29458427], [68.60791779, 23.29458427], [68.60791779, 23.2943058], [68.6084671, 23.29431152], [68.6084671, 23.29404259], [68.60930634, 23.29404259], [68.60930634, 23.29375076], [68.60986328, 23.29375076], [68.60986328, 23.29347038], [68.61013794, 23.29347229], [68.61013794, 23.29291725], [68.61042023, 23.29291916], [68.61042023, 23.29264069], [68.61125946, 23.29264069], [68.61125946, 23.29236031], [68.61180878, 23.29236031], [68.61180878, 23.29207993], [68.61208344, 23.29208374], [68.61208344, 23.2915287], [68.61180878, 23.29153061], [68.61180878, 23.29125023], [68.61152649, 23.29125023], [68.61152649, 23.29070091], [68.61125946, 23.29070091], [68.61125946, 23.29042053], [68.61096954, 23.29042053], [68.61096954, 23.28985977], [68.61069489, 23.28986168], [68.61069489, 23.28958321], [68.61042023, 23.28958321], [68.61042023, 23.28902817], [68.61068726, 23.28903008], [68.61068726, 23.28819084], [68.61042023, 23.28819466], [68.61042023, 23.28708458], [68.61013794, 23.28708458], [68.61013794, 23.28541756], [68.61042023, 23.28541946], [68.61042023, 23.28375053], [68.61068726, 23.28375053], [68.61068726, 23.28264236], [68.61096954, 23.28264236], [68.61096954, 23.2820797], [68.61125183, 23.28208351], [68.61125183, 23.28152847], [68.61152649, 23.28152847], [68.61152649, 23.28096962], [68.61180878, 23.28097153], [68.61180878, 23.28013992], [68.61207581, 23.28013992], [68.61207581, 23.27958107], [68.61235809, 23.27958298], [68.61235809, 23.27902794], [68.61264038, 23.27902985], [68.61264038, 23.27847099], [68.61291504, 23.2784729], [68.61291504, 23.27791786], [68.61319733, 23.27791977], [68.61319733, 23.27736092], [68.61347198, 23.27736092], [68.61347198, 23.27680969], [68.61374664, 23.27680969], [68.61374664, 23.27625084], [68.61402893, 23.27625084], [68.61402893, 23.27568054], [68.61430359, 23.2756958], [68.61430359, 23.27458572], [68.61458588, 23.27458572], [68.61458588, 23.27375031], [68.61486053, 23.27375031], [68.61486053, 23.27153015], [68.61429596, 23.27153015], [68.61429596, 23.27124977], [68.61207581, 23.27124977], [68.61207581, 23.27153015], [68.61125183, 23.27152824], [68.61125183, 23.27180481], [68.61096954, 23.27180481], [68.61096954, 23.27208138], [68.61069489, 23.27208138], [68.61069489, 23.27236366], [68.61042023, 23.27235985], [68.61042023, 23.27264023], [68.61013794, 23.27263832], [68.61013794, 23.27291679], [68.60986328, 23.27291107], [68.60986328, 23.27320099], [68.60736084, 23.27319527], [68.60736084, 23.27347374], [68.60624695, 23.27347374], [68.60624695, 23.27319527], [68.60652924, 23.27320099], [68.60652924, 23.27291107], [68.60680389, 23.27291679], [68.60680389, 23.27263832], [68.60708618, 23.27264023], [68.60708618, 23.27207947], [68.60736084, 23.27208138], [68.60736084, 23.27152824], [68.60764313, 23.27153015], [68.60764313, 23.27069283], [68.60736084, 23.27069473], [68.60736084, 23.26958275], [68.60708618, 23.26958275], [68.60708618, 23.26902771], [68.60679626, 23.26903152], [68.60679626, 23.26874924], [68.60624695, 23.26874924], [68.60624695, 23.26847076], [68.60597229, 23.26847267], [68.60597229, 23.2681942], [68.60236359, 23.2681942], [68.60236359, 23.26847267], [68.60208893, 23.26847076], [68.60208893, 23.26903152], [68.60180664, 23.26902771], [68.60180664, 23.26958275], [68.60151672, 23.26958084], [68.60151672, 23.27042007], [68.60124969, 23.27041626], [68.60124969, 23.27236366], [68.60097504, 23.27236366], [68.60097504, 23.27291679], [68.59986115, 23.27291679], [68.59986115, 23.27208138], [68.59958649, 23.27208138], [68.59958649, 23.27124977], [68.59986115, 23.27124977], [68.59986115, 23.27013969], [68.59958649, 23.27013969], [68.59958649, 23.26958084], [68.5993042, 23.26958275], [68.5993042, 23.26902771], [68.59902954, 23.26903152], [68.59902954, 23.26874924], [68.59874725, 23.26874924], [68.59874725, 23.26847076], [68.5984726, 23.26847267], [68.5984726, 23.2681942], [68.5956955, 23.2681942], [68.5956955, 23.26763916], [68.59513855, 23.26763916], [68.59513855, 23.26736069], [68.5945816, 23.26736069], [68.5945816, 23.26708031], [68.59208679, 23.26708412], [68.59208679, 23.26680565], [68.59152985, 23.26680756], [68.59152985, 23.26652908], [68.5909729, 23.26652908], [68.5909729, 23.26625061], [68.59069824, 23.26625061], [68.59069824, 23.26597023], [68.5901413, 23.26597214], [68.5901413, 23.26569366], [68.58958435, 23.26569366], [68.58958435, 23.2654171], [68.58930206, 23.26542091], [68.58930206, 23.26514053], [68.58875275, 23.26514053], [68.58875275, 23.26486015], [68.58847046, 23.26486015], [68.58847046, 23.26457977], [68.58791351, 23.26458359], [68.58791351, 23.26430511], [68.58763885, 23.26431084], [68.58763885, 23.26403046], [68.58653259, 23.26403046], [68.58653259, 23.26374054], [68.5854187, 23.26375008], [68.5854187, 23.2634716], [68.5845871, 23.2634716], [68.5845871, 23.26319695], [68.58347321, 23.26320076], [68.58347321, 23.26292038], [68.58235931, 23.26292038], [68.58235931, 23.26264], [68.58013916, 23.26264], [68.58013916, 23.26235962], [68.57819366, 23.26236153], [68.57819366, 23.26208305], [68.57597351, 23.26208305], [68.57597351, 23.26180649], [68.57514954, 23.26180077], [68.57514191, 23.26152802], [68.57375336, 23.26152992], [68.57375336, 23.26124954], [68.57290649, 23.26124954], [68.57290649, 23.26097107], [68.57236481, 23.26097488], [68.57236481, 23.2606926], [68.57208252, 23.2606926], [68.57208252, 23.26041412], [68.57180786, 23.26041985], [68.57180786, 23.2598629], [68.57152557, 23.2598629], [68.57152557, 23.25930405], [68.57125092, 23.25930977], [68.57125092, 23.25902939], [68.57096863, 23.25902939], [68.57096863, 23.25764275], [68.57180786, 23.25764275], [68.57180786, 23.25708008], [68.57402802, 23.25708008], [68.57402802, 23.25736046], [68.57485962, 23.25736046], [68.57485962, 23.25764275], [68.57763672, 23.25764275], [68.57763672, 23.25570107], [68.57791901, 23.25570107], [68.57791901, 23.25542068], [68.57847595, 23.25542068], [68.57847595, 23.2551384], [68.5790329, 23.2551384], [68.5790329, 23.25486946], [68.58096313, 23.25486946], [68.58096313, 23.2551384], [68.58152771, 23.2551384], [68.58152771, 23.25542068], [68.5826416, 23.25542068], [68.5826416, 23.2551384], [68.58319092, 23.2551384], [68.58319092, 23.25457954], [68.58347321, 23.25458336], [68.58347321, 23.25430489], [68.58374786, 23.25430489], [68.58374786, 23.25402832], [68.58403015, 23.25402832], [68.58403015, 23.25374985], [68.58429718, 23.25374985], [68.58429718, 23.25291824], [68.58403015, 23.25291824], [68.58403015, 23.25263977], [68.58374786, 23.25263977], [68.58374786, 23.25235939], [68.58347321, 23.2523613], [68.58347321, 23.25208282], [68.58319092, 23.25208282], [68.58319092, 23.25180626], [68.58125305, 23.25180626], [68.58125305, 23.25208282], [68.58069611, 23.25208282], [68.58069611, 23.2523613], [68.57958221, 23.2523613], [68.57958221, 23.25208282], [68.57875061, 23.25208282], [68.57875061, 23.25180626], [68.57597351, 23.25180626], [68.57597351, 23.25152779], [68.57347107, 23.25152969], [68.57347107, 23.25125122], [68.57290649, 23.25125122], [68.57290649, 23.25041962], [68.57319641, 23.25041962], [68.57319641, 23.24958038], [68.57347107, 23.2495842], [68.57347107, 23.24930573], [68.57514954, 23.24930954], [68.57514954, 23.24903107], [68.57541656, 23.24903107], [68.57541656, 23.24874115], [68.57569122, 23.24875069], [68.57569122, 23.2476387], [68.57514954, 23.24764061], [68.57514191, 23.24641037], [68.57514191, 23.24625015], [68.57485962, 23.24625015], [68.57485962, 23.24570084], [68.57402802, 23.24570084], [68.57402802, 23.24514008], [68.57319641, 23.24514008], [68.57319641, 23.24542046], [68.57290649, 23.24542046], [68.57290649, 23.24570084], [68.57236481, 23.24569321], [68.57236481, 23.24597359], [68.57180786, 23.24596977], [68.57180786, 23.24625015], [68.5715332, 23.24625015], [68.5715332, 23.24653053], [68.57096863, 23.24653053], [68.57096863, 23.24681091], [68.57041931, 23.24680328], [68.57041931, 23.24708557], [68.57013702, 23.24707985], [68.57013702, 23.24736023], [68.56986237, 23.24736023], [68.56986237, 23.2475605], [68.56986237, 23.2476387], [68.56958008, 23.2476387], [68.56958008, 23.24819565], [68.56930542, 23.24819565], [68.56930542, 23.24847221], [68.56903076, 23.24847221], [68.56903076, 23.24875069], [68.56874847, 23.24874115], [68.56874847, 23.24903107], [68.56902313, 23.24903107], [68.56902313, 23.25014114], [68.56874847, 23.25014114], [68.56874847, 23.25041962], [68.56847382, 23.25041771], [68.56847382, 23.25069427], [68.56819153, 23.25069427], [68.56819153, 23.25097275], [68.56764221, 23.25097084], [68.56764221, 23.25125122], [68.56680298, 23.25125122], [68.56680298, 23.25152969], [68.56597137, 23.25152779], [68.56597137, 23.25180626], [68.56513977, 23.25180626], [68.56513977, 23.25208282], [68.56375122, 23.25208282], [68.56375122, 23.2523613], [68.56236267, 23.25235939], [68.56236267, 23.25263977], [68.56181335, 23.25263977], [68.56181335, 23.25291824], [68.56124878, 23.25291634], [68.56124878, 23.25319481], [68.56051636, 23.25319481], [68.56014252, 23.25319481], [68.56014252, 23.25347137], [68.55874634, 23.25346947], [68.55874634, 23.25374985], [68.55847168, 23.25374985], [68.55847168, 23.25430489], [68.55819702, 23.25430489], [68.55819702, 23.25458336], [68.55764008, 23.25457954], [68.55764008, 23.25486946], [68.55735779, 23.25486946], [68.55735779, 23.2551384], [68.55708313, 23.2551384], [68.55708313, 23.25570107], [68.55735779, 23.25570107], [68.55735779, 23.25625038], [68.55708313, 23.25625038], [68.55708313, 23.25653267], [68.55652618, 23.25653267], [68.55652618, 23.25681114], [68.55625153, 23.25680542], [68.55625153, 23.25708389], [68.55568695, 23.25708008], [68.55568695, 23.25736046], [68.55513763, 23.25736046], [68.55513763, 23.25764275], [68.55458069, 23.25764275], [68.55458069, 23.25793076], [68.55430603, 23.2579174], [68.55430603, 23.25819206], [68.55403137, 23.25819206], [68.55403137, 23.25847054], [68.5534668, 23.25847054], [68.5534668, 23.25875282], [68.55319214, 23.25875282], [68.55319214, 23.25902939], [68.55264282, 23.25902939], [68.55264282, 23.25930977], [68.55208588, 23.25930405], [68.55208588, 23.25958443], [68.55179596, 23.25958061], [68.55179596, 23.2598629], [68.55069733, 23.2598629], [68.55069733, 23.26013947], [68.55014038, 23.26013947], [68.55014038, 23.26041985], [68.54985809, 23.26041412], [68.54985809, 23.2606926], [68.54958344, 23.2606926], [68.54958344, 23.26097488], [68.54902649, 23.26097107], [68.54902649, 23.26124954], [68.54846954, 23.26124954], [68.54846954, 23.26152992], [68.54763794, 23.26152802], [68.54763794, 23.26180077], [68.54736328, 23.26180649], [68.54736328, 23.26208305], [68.54708099, 23.26208115], [68.54708099, 23.26264], [68.54680634, 23.26264], [68.54680634, 23.26292038], [68.54651642, 23.26292038], [68.54651642, 23.26320076], [68.54624939, 23.26319695], [68.54624939, 23.2634716], [68.5459671, 23.2634697], [68.5459671, 23.26514053], [68.54569244, 23.26514053], [68.54569244, 23.26542091], [68.5451355, 23.2654171], [68.5451355, 23.26569366], [68.54319763, 23.26569366], [68.54319763, 23.26513863], [68.54207611, 23.26514053], [68.54207611, 23.26542091], [68.54180908, 23.2654171], [68.54180908, 23.26569366], [68.54096985, 23.26569366], [68.54096985, 23.26597214], [68.54070282, 23.26597023], [68.54070282, 23.26652908], [68.5404129, 23.26652908], [68.5404129, 23.2693119], [68.54013824, 23.2693119], [68.54013824, 23.26987267], [68.53985596, 23.26987267], [68.53985596, 23.27042007], [68.53930664, 23.27041626], [68.53930664, 23.27069473], [68.53902435, 23.27069473], [68.53902435, 23.2709713], [68.53847504, 23.2709713], [68.53848267, 23.27124977], [68.53819275, 23.27124977], [68.53819275, 23.27291679], [68.53791809, 23.27291679], [68.53791809, 23.27458572], [68.53819275, 23.27458], [68.53819275, 23.27514076], [68.53847504, 23.27513885], [68.53847504, 23.2756958], [68.53874969, 23.2756958], [68.53874969, 23.27958298], [68.53901672, 23.27958107], [68.53901672, 23.28013992], [68.53930664, 23.28013992], [68.53930664, 23.28070068], [68.5395813, 23.28070068], [68.5395813, 23.28124809], [68.53985596, 23.28124809], [68.53985596, 23.28264236], [68.54013824, 23.28263855], [68.54013824, 23.28347015], [68.5404129, 23.28347015], [68.5404129, 23.28430939], [68.54069519, 23.28430557], [68.54069519, 23.28486061], [68.54096985, 23.28484917], [68.54096985, 23.2851429], [68.54207611, 23.2851429], [68.54207611, 23.28484917], [68.5423584, 23.28484917], [68.5423584, 23.2851429], [68.54264069, 23.2851429], [68.54264069, 23.28541946], [68.54319763, 23.28541756], [68.54319763, 23.2859745], [68.54402924, 23.2859745], [68.54402924, 23.28569221], [68.54430389, 23.28569221], [68.54430389, 23.28541756], [68.54458618, 23.28541946], [68.54458618, 23.28484917], [68.54486084, 23.28486061], [68.54486084, 23.28430557], [68.54514313, 23.28430939], [68.54514313, 23.28403282], [68.54541779, 23.28403282], [68.54541779, 23.28347015], [68.54569244, 23.28347015], [68.54569244, 23.28319359], [68.54624939, 23.28319359], [68.54624939, 23.28291702], [68.54736328, 23.28292274], [68.54736328, 23.28264236], [68.54792023, 23.28264236], [68.54792023, 23.28236008], [68.54624939, 23.28236008], [68.54624939, 23.28208351], [68.54541779, 23.28208351], [68.54541779, 23.27902794], [68.54569244, 23.27902985], [68.54569244, 23.27874947], [68.5459671, 23.27874947], [68.5459671, 23.27819061], [68.54624939, 23.27819443], [68.54624939, 23.27791786], [68.54736328, 23.27791977], [68.54736328, 23.27763939], [68.54818726, 23.27763939], [68.54818726, 23.27736092], [68.54985809, 23.27736092], [68.54985809, 23.27763939], [68.55042267, 23.27763939], [68.55042267, 23.27791977], [68.55152893, 23.27791977], [68.55152893, 23.27763939], [68.55208588, 23.27763939], [68.55208588, 23.27736092], [68.55236053, 23.27736092], [68.55236053, 23.27708054], [68.55263519, 23.27708244], [68.55263519, 23.27680779], [68.55291748, 23.27680969], [68.55291748, 23.27625084], [68.55303192, 23.27625084], [68.55319214, 23.27625084], [68.55319214, 23.27597046], [68.55347443, 23.27597237], [68.55347443, 23.2756958], [68.55374908, 23.2756958], [68.55374908, 23.27541733], [68.55430603, 23.27542114], [68.55430603, 23.27486038], [68.55486298, 23.27486038], [68.55486298, 23.27458], [68.55513763, 23.27458572], [68.55513763, 23.27430344], [68.55625153, 23.27431107], [68.55625153, 23.27403069], [68.55735779, 23.27403069], [68.55735779, 23.27431107], [68.55764008, 23.27431107], [68.55764008, 23.27680969], [68.55791473, 23.27680779], [68.55791473, 23.27708244], [68.55819702, 23.27708054], [68.55819702, 23.27763939], [68.55902863, 23.27763939], [68.55902863, 23.27736092], [68.5595932, 23.27736092], [68.55958557, 23.27708244], [68.56041718, 23.27708244], [68.56041718, 23.27680779], [68.56069183, 23.27680969], [68.56069183, 23.27653122], [68.56096649, 23.27653122], [68.56096649, 23.27680969], [68.56124878, 23.27680779], [68.56124878, 23.27708244], [68.56180573, 23.27708244], [68.56180573, 23.27736092], [68.56208038, 23.27736092], [68.56208038, 23.27763939], [68.56263733, 23.27763939], [68.56263733, 23.27791977], [68.56291962, 23.27791786], [68.56291962, 23.27819443], [68.56346893, 23.27819443], [68.56346893, 23.2784729], [68.56430817, 23.27847099], [68.56430817, 23.28070068], [68.56402588, 23.28069496], [68.56402588, 23.28097153], [68.56375122, 23.28096962], [68.56375122, 23.28124809], [68.56346893, 23.28124809], [68.56346893, 23.28181076], [68.56402588, 23.28180504], [68.56402588, 23.28208351], [68.56430817, 23.28208351], [68.56430817, 23.28236008], [68.56458282, 23.28236008], [68.56458282, 23.28264236], [68.56485748, 23.28263855], [68.56485748, 23.28347015], [68.56513977, 23.28347015], [68.56513977, 23.28375053], [68.56624603, 23.28375053], [68.56624603, 23.28319168], [68.56652832, 23.28319359], [68.56652832, 23.28059959], [68.56652832, 23.28041649], [68.56680298, 23.2804184], [68.56680298, 23.28070068], [68.56735992, 23.28069496], [68.56735992, 23.28097153], [68.56764221, 23.28096962], [68.56764221, 23.28124809], [68.56791687, 23.28124809], [68.56791687, 23.28208351], [68.56819153, 23.28208351], [68.56819153, 23.28297806], [68.56819153, 23.28486061], [68.56735992, 23.28484917], [68.56735992, 23.2851429], [68.5670929, 23.2851429], [68.5670929, 23.28541946], [68.56680298, 23.28541756], [68.56680298, 23.28569221], [68.56652832, 23.28569221], [68.56652832, 23.2859745], [68.56624603, 23.28597069], [68.56624603, 23.28625107], [68.56595612, 23.28625107], [68.56595612, 23.28680992], [68.56513977, 23.28680992], [68.56513977, 23.28652954], [68.56346893, 23.28652954], [68.56346893, 23.28680992], [68.56069183, 23.28680611], [68.56069183, 23.28708458], [68.55958557, 23.28708458], [68.5595932, 23.28736115], [68.55930328, 23.28736115], [68.55930328, 23.28763962], [68.55902863, 23.28763962], [68.55902863, 23.28791428], [68.55874634, 23.28791428], [68.55874634, 23.28819466], [68.55847168, 23.28819466], [68.55847168, 23.28847313], [68.55819702, 23.28847122], [68.55819702, 23.28874969], [68.5579071, 23.28874969], [68.5579071, 23.28903008], [68.55764008, 23.28902817], [68.55764008, 23.28930664], [68.55735779, 23.28930664], [68.55735779, 23.28958321], [68.55708313, 23.28958321], [68.55708313, 23.28986168], [68.55680847, 23.28985977], [68.55680847, 23.29042053], [68.55652618, 23.29042053], [68.55652618, 23.29097939], [68.55625153, 23.29097939], [68.55625153, 23.29153061], [68.55596924, 23.2915287], [68.55596924, 23.29208374], [68.55568695, 23.29207993], [68.55568695, 23.29264069], [68.55541992, 23.29263878], [68.55541992, 23.29319382], [68.55513763, 23.2931881], [68.55513763, 23.29375076], [68.55486298, 23.29375076], [68.55486298, 23.29431152], [68.55458069, 23.2943058], [68.55458069, 23.29458237], [68.55430603, 23.29458046], [68.55430603, 23.29513931], [68.55403137, 23.29513931], [68.55403137, 23.29569435], [68.55374908, 23.29569054], [68.55374908, 23.29624939], [68.5534668, 23.29624939], [68.5534668, 23.29681015], [68.55319214, 23.29681015], [68.55319214, 23.29764175], [68.55347443, 23.29764175], [68.55347443, 23.29958153], [68.55374908, 23.29957962], [68.55374908, 23.30153084], [68.55401611, 23.30153084], [68.55401611, 23.30375099], [68.55430603, 23.30375099], [68.55430603, 23.30624962], [68.55458069, 23.30624962], [68.55458069, 23.30874825], [68.55486298, 23.30874825], [68.55486298, 23.30986023], [68.55513763, 23.30986023], [68.55513763, 23.31069374], [68.55541992, 23.31069183], [68.55541992, 23.31180954], [68.55568695, 23.31180954], [68.55568695, 23.31236076], [68.55596924, 23.31236076], [68.55596924, 23.31264114], [68.55625153, 23.31264114], [68.55625153, 23.31291962], [68.55652618, 23.3129158], [68.55652618, 23.31319237], [68.55680847, 23.31319237], [68.55680847, 23.31347466], [68.55708313, 23.31347084], [68.55708313, 23.31375122], [68.55819702, 23.31375122]]], [[[68.62874603, 23.29014015], [68.62874603, 23.28957939], [68.62902832, 23.28958321], [68.62902832, 23.28902817], [68.62930298, 23.28903008], [68.62930298, 23.28708076], [68.62902832, 23.28708458], [68.62902832, 23.28541756], [68.62847137, 23.28541756], [68.62847137, 23.2859745], [68.62819672, 23.28597069], [68.62819672, 23.28652954], [68.62791443, 23.28652763], [68.62791443, 23.28930664], [68.62819672, 23.28930092], [68.62819672, 23.29014015], [68.62874603, 23.29014015]]], [[[68.58847046, 23.31903076], [68.58847046, 23.31875038], [68.59041595, 23.31875038], [68.59041595, 23.31847], [68.59069824, 23.31847191], [68.59069824, 23.31825066], [68.59069824, 23.31791878], [68.5909729, 23.31792068], [68.5909729, 23.3176403], [68.59124756, 23.3176403], [68.59124756, 23.31707954], [68.59152985, 23.31708336], [68.59152985, 23.31680679], [68.59236145, 23.31680679], [68.59236145, 23.31569672], [68.59263611, 23.31569672], [68.59263611, 23.31513977], [68.5929184, 23.31513977], [68.5929184, 23.31485939], [68.59375, 23.3148613], [68.59375, 23.31458473], [68.59486389, 23.31458473], [68.59486389, 23.3148613], [68.5965271, 23.31485939], [68.5965271, 23.31513977], [68.59680176, 23.31513977], [68.59680176, 23.31569672], [68.59708405, 23.31569672], [68.59708405, 23.31597137], [68.59819794, 23.31597137], [68.59819794, 23.31569672], [68.59986115, 23.31569672], [68.59986115, 23.31541634], [68.60069275, 23.31542015], [68.60069275, 23.31513977], [68.60180664, 23.31513977], [68.60180664, 23.31485939], [68.6020813, 23.3148613], [68.6020813, 23.31458473], [68.60263824, 23.31458473], [68.60263824, 23.31430626], [68.6029129, 23.31431007], [68.6029129, 23.31402969], [68.60375214, 23.31402969], [68.60375214, 23.31319046], [68.60402679, 23.31319237], [68.60402679, 23.31263924], [68.6048584, 23.31264114], [68.6048584, 23.31236076], [68.60513306, 23.31236076], [68.60513306, 23.31208038], [68.60541534, 23.31208229], [68.60541534, 23.31180573], [68.60569763, 23.31180954], [68.60569763, 23.31153107], [68.60597229, 23.31153107], [68.60597229, 23.31125259], [68.60624695, 23.31125259], [68.60624695, 23.31097031], [68.60652924, 23.31097031], [68.60652924, 23.31069374], [68.60708618, 23.31069374], [68.60708618, 23.31041718], [68.60736084, 23.3104229], [68.60736084, 23.31014252], [68.60791779, 23.31014252], [68.60791779, 23.30986023], [68.60874939, 23.30986023], [68.60874939, 23.3104229], [68.60847473, 23.31041718], [68.60847473, 23.31097031], [68.60819244, 23.31097031], [68.60819244, 23.31153107], [68.60791779, 23.31153107], [68.60791779, 23.31180954], [68.60708618, 23.31180573], [68.60708618, 23.31208229], [68.60652924, 23.31208038], [68.60652924, 23.31236076], [68.60597229, 23.31236076], [68.60597229, 23.31264114], [68.60542297, 23.31264114], [68.60542297, 23.31375122], [68.60514069, 23.31374931], [68.60514069, 23.3148613], [68.60542297, 23.31485939], [68.60542297, 23.31542015], [68.60569763, 23.31541634], [68.60569763, 23.31597137], [68.60597229, 23.31596947], [68.60597229, 23.31653023], [68.60847473, 23.31652832], [68.60847473, 23.31680679], [68.60930634, 23.31680679], [68.60930634, 23.31652832], [68.60958099, 23.31653023], [68.60958099, 23.31624985], [68.60930634, 23.31624985], [68.60930634, 23.31596947], [68.60902405, 23.31597137], [68.60902405, 23.31569672], [68.60874939, 23.31569672], [68.60874939, 23.31513977], [68.6084671, 23.31513977], [68.6084671, 23.31485939], [68.60819244, 23.3148613], [68.60819244, 23.31458473], [68.60847473, 23.31458473], [68.60847473, 23.31402779], [68.60874939, 23.31402969], [68.60874939, 23.31347084], [68.60902405, 23.31347466], [68.60902405, 23.3129158], [68.60930634, 23.31291962], [68.60930634, 23.31264114], [68.60958099, 23.31264114], [68.60958099, 23.31236076], [68.60986328, 23.31236076], [68.60986328, 23.31208038], [68.61013794, 23.31208229], [68.61013794, 23.31069374], [68.61042023, 23.31069374], [68.61042023, 23.31041718], [68.61096954, 23.3104229], [68.61096954, 23.31014252], [68.61125946, 23.31014252], [68.61125946, 23.30986023], [68.61152649, 23.30986023], [68.61152649, 23.30931282], [68.61180878, 23.30931282], [68.61180878, 23.30904007], [68.61207581, 23.30904007], [68.61207581, 23.30874825], [68.61235809, 23.30874825], [68.61235809, 23.30846977], [68.61264038, 23.30847168], [68.61264038, 23.30791664], [68.61292267, 23.30791855], [68.61292267, 23.30763817], [68.61319733, 23.30763817], [68.61319733, 23.30708122], [68.61347198, 23.30708313], [68.61347198, 23.30680466], [68.61374664, 23.30680466], [68.61374664, 23.30624962], [68.61402893, 23.30624962], [68.61402893, 23.30598068], [68.61429596, 23.30598068], [68.61430359, 23.30553055], [68.61430359, 23.30541611], [68.61458588, 23.30541992], [68.61458588, 23.30486107], [68.61486053, 23.30486107], [68.61486053, 23.30430984], [68.61514282, 23.30430984], [68.61514282, 23.30375099], [68.61541748, 23.30375099], [68.61541748, 23.30319023], [68.61569214, 23.30319595], [68.61569214, 23.30263901], [68.6159668, 23.30264091], [68.6159668, 23.30208015], [68.61653137, 23.30208588], [68.61653137, 23.30347252], [68.61708069, 23.30347252], [68.61708069, 23.30291748], [68.61736298, 23.30291939], [68.61736298, 23.30236053], [68.61763763, 23.30236053], [68.61763763, 23.30181122], [68.61791992, 23.30181122], [68.61791992, 23.30125046], [68.61818695, 23.30125046], [68.61818695, 23.30097008], [68.61846924, 23.30097389], [68.61846924, 23.30041695], [68.61875153, 23.30042076], [68.61875153, 23.29931068], [68.61846924, 23.29931068], [68.61846924, 23.2990303], [68.61818695, 23.2990303], [68.61818695, 23.29874992], [68.61763763, 23.29874992], [68.61763763, 23.29846954], [68.61708069, 23.29847145], [68.61708069, 23.29819489], [68.61680603, 23.29819489], [68.61680603, 23.29791641], [68.61653137, 23.29792023], [68.61653137, 23.29764175], [68.61624908, 23.29764175], [68.61624908, 23.29735947], [68.6159668, 23.29735947], [68.6159668, 23.29764175], [68.61514282, 23.29764175], [68.61514282, 23.29792023], [68.61458588, 23.29791641], [68.61458588, 23.29819489], [68.61402893, 23.29819489], [68.61402893, 23.29847145], [68.61347198, 23.29846954], [68.61347198, 23.29874992], [68.61292267, 23.29874992], [68.61292267, 23.2990303], [68.61235809, 23.2990303], [68.61235809, 23.29931068], [68.61180878, 23.29930305], [68.61180878, 23.29958153], [68.61013794, 23.29958153], [68.61013794, 23.29930305], [68.60874939, 23.29930305], [68.60874939, 23.29958153], [68.6076355, 23.29958153], [68.6076355, 23.29986382], [68.60679626, 23.29985046], [68.60679626, 23.30014038], [68.60597229, 23.30014038], [68.60597229, 23.30042076], [68.60541534, 23.30041695], [68.60541534, 23.30058098], [68.60541534, 23.30069542], [68.60458374, 23.30069542], [68.60458374, 23.30097389], [68.60346985, 23.30097008], [68.60346985, 23.30125046], [68.60041809, 23.30125046], [68.60041809, 23.30153084], [68.59986115, 23.30153084], [68.59986115, 23.30181122], [68.5993042, 23.3018055], [68.5993042, 23.30208588], [68.5984726, 23.30208015], [68.5984726, 23.30236053], [68.59819794, 23.30236053], [68.59819794, 23.30264091], [68.59792328, 23.30264091], [68.59792328, 23.30291939], [68.59764099, 23.30291748], [68.59764099, 23.30347252], [68.5973587, 23.30347061], [68.5973587, 23.30375099], [68.59707642, 23.30375099], [68.59707642, 23.30402946], [68.59680176, 23.30402946], [68.59680176, 23.30430984], [68.5973587, 23.30430794], [68.5973587, 23.3045826], [68.59764099, 23.30458069], [68.59764099, 23.30486107], [68.59819794, 23.30486107], [68.59819794, 23.30513954], [68.5984726, 23.30513954], [68.5984726, 23.30541992], [68.5973587, 23.30541992], [68.5973587, 23.30513954], [68.59680939, 23.30513954], [68.59680176, 23.30486107], [68.59541321, 23.30486107], [68.59541321, 23.30458069], [68.59485626, 23.30458069], [68.59485626, 23.30486107], [68.59430695, 23.30486107], [68.59430695, 23.30513954], [68.59401703, 23.30513954], [68.59401703, 23.30541992], [68.59375, 23.30541611], [68.59375, 23.30680466], [68.59402466, 23.30680466], [68.59402466, 23.3073616], [68.59430695, 23.3073597], [68.59430695, 23.30791855], [68.59401703, 23.30791855], [68.59401703, 23.30931282], [68.59430695, 23.30930519], [68.59430695, 23.30958366], [68.59347534, 23.30958366], [68.59347534, 23.30930519], [68.5929184, 23.30930519], [68.5929184, 23.30958366], [68.59179688, 23.30958176], [68.59179688, 23.30986023], [68.5909729, 23.30986023], [68.5909729, 23.31014252], [68.59041595, 23.31014252], [68.59041595, 23.3104229], [68.5901413, 23.31041718], [68.5901413, 23.31069374], [68.58958435, 23.31069374], [68.58958435, 23.31097031], [68.5890274, 23.31097031], [68.5890274, 23.31125259], [68.58847046, 23.31125259], [68.58847046, 23.31153107], [68.58790588, 23.31153107], [68.58790588, 23.31180954], [68.58763885, 23.31180573], [68.58763885, 23.31208229], [68.58708191, 23.31208229], [68.58708954, 23.31236076], [68.58680725, 23.31236076], [68.58680725, 23.31264114], [68.58653259, 23.31264114], [68.58653259, 23.31291962], [68.58625031, 23.3129158], [68.58625031, 23.31319237], [68.58597565, 23.31319237], [68.58597565, 23.31347466], [68.58569336, 23.31347084], [68.58569336, 23.31375122], [68.58513641, 23.31375122], [68.58513641, 23.31402969], [68.5845871, 23.31402969], [68.5845871, 23.31431007], [68.58403015, 23.31430626], [68.58403015, 23.31458473], [68.58347321, 23.31458473], [68.58347321, 23.3148613], [68.58319092, 23.31485939], [68.58319092, 23.31513977], [68.58291626, 23.31513977], [68.58291626, 23.31569672], [68.5826416, 23.31569672], [68.5826416, 23.31597137], [68.58291626, 23.31596947], [68.58291626, 23.31653023], [68.58319092, 23.31652832], [68.58319092, 23.31708336], [68.58347321, 23.31708336], [68.58347321, 23.31736183], [68.58374786, 23.31735992], [68.58374786, 23.3176403], [68.58403015, 23.3176403], [68.58403015, 23.31792068], [68.58486176, 23.31792068], [68.58486176, 23.3182106], [68.58569336, 23.31819534], [68.58569336, 23.31847191], [68.58652496, 23.31847191], [68.58652496, 23.31875038], [68.58698273, 23.31875038], [68.58708954, 23.31875038], [68.58708954, 23.31903076], [68.58847046, 23.31903076]]], [[[68.70513916, 23.31180954], [68.70513916, 23.31153107], [68.70597076, 23.31153107], [68.70597076, 23.31125259], [68.70707703, 23.31125259], [68.70707703, 23.31097031], [68.70735931, 23.31097031], [68.70735931, 23.31069374], [68.70791626, 23.31069374], [68.70791626, 23.31041718], [68.70819092, 23.3104229], [68.70819092, 23.30986023], [68.70847321, 23.30986023], [68.70847321, 23.30958176], [68.70874786, 23.30958366], [68.70874786, 23.30930519], [68.70819092, 23.30930519], [68.70819092, 23.30958366], [68.70735931, 23.30958366], [68.70735931, 23.30930519], [68.70680237, 23.30931282], [68.70680237, 23.30904007], [68.70735168, 23.30904007], [68.70735168, 23.30874825], [68.70819092, 23.30874825], [68.70819092, 23.30846977], [68.70847321, 23.30847168], [68.70847321, 23.30819511], [68.70874786, 23.30820084], [68.70874786, 23.30680084], [68.70847321, 23.30680466], [68.70847321, 23.30652809], [68.70791626, 23.30652809], [68.70791626, 23.30680466], [68.70680237, 23.30680466], [68.70680237, 23.30708313], [68.70625305, 23.30708313], [68.70625305, 23.3073616], [68.70597076, 23.3073597], [68.70597076, 23.30763817], [68.70540619, 23.30763817], [68.70540619, 23.30791855], [68.70485687, 23.30791855], [68.70485687, 23.30820084], [68.70430756, 23.30819511], [68.70430756, 23.30847168], [68.70347595, 23.30846977], [68.70347595, 23.30874825], [68.70263672, 23.30874825], [68.70263672, 23.30904007], [68.70096588, 23.30904007], [68.70096588, 23.30931282], [68.69985962, 23.30931282], [68.69985962, 23.31014252], [68.70041656, 23.31014252], [68.70041656, 23.3104229], [68.70181274, 23.3104229], [68.70181274, 23.31014252], [68.70319366, 23.3101387], [68.70319366, 23.31069374], [68.70347595, 23.31069374], [68.70347595, 23.31097031], [68.70375061, 23.31097031], [68.70375061, 23.31125259], [68.70347595, 23.31125259], [68.70347595, 23.31153107], [68.70318604, 23.31153107], [68.70318604, 23.31180954], [68.70513916, 23.31180954]]], [[[68.64263916, 23.31402969], [68.64263916, 23.31375122], [68.64290619, 23.31375122], [68.64290619, 23.31347084], [68.64347076, 23.31347466], [68.64347076, 23.31302834], [68.64347076, 23.31263924], [68.64375305, 23.31264114], [68.64375305, 23.31208038], [68.64402771, 23.31208229], [68.64402771, 23.31152725], [68.64430237, 23.31153107], [68.64430237, 23.3111496], [68.64430237, 23.31097031], [68.64458466, 23.31097031], [68.64458466, 23.31041718], [68.64485931, 23.3104229], [68.64485931, 23.31014252], [68.6451416, 23.31014252], [68.6451416, 23.30958176], [68.64541626, 23.30958366], [68.64541626, 23.30902863], [68.64569092, 23.30904007], [68.64569092, 23.30846977], [68.64597321, 23.30847168], [68.64597321, 23.30791664], [68.64624786, 23.30791855], [68.64624786, 23.3073597], [68.64569092, 23.3073597], [68.64569092, 23.30763817], [68.64541626, 23.30763817], [68.64541626, 23.30791855], [68.6451416, 23.30791855], [68.6451416, 23.30820084], [68.64458466, 23.30819511], [68.64458466, 23.30847168], [68.64430237, 23.30846977], [68.64430237, 23.30874825], [68.64347076, 23.30874825], [68.64347076, 23.30904007], [68.64190674, 23.30903816], [68.6415329, 23.30904007], [68.6415329, 23.30931282], [68.64097595, 23.30930519], [68.64097595, 23.30958366], [68.64041901, 23.30958176], [68.64041901, 23.30986023], [68.64013672, 23.30986023], [68.64013672, 23.31014252], [68.63957977, 23.31014252], [68.63957977, 23.3104229], [68.63874817, 23.3104229], [68.63874817, 23.31014252], [68.63819885, 23.31014252], [68.63819885, 23.3104229], [68.63791656, 23.31041718], [68.63791656, 23.31069374], [68.63735962, 23.31069374], [68.63735962, 23.3101387], [68.63764191, 23.31014252], [68.63764191, 23.30958176], [68.63791656, 23.30958366], [68.63791656, 23.30874825], [68.63764191, 23.30874825], [68.63764191, 23.30820084], [68.63735962, 23.30820084], [68.63735962, 23.30791855], [68.63707733, 23.30791855], [68.63707733, 23.3073597], [68.63680267, 23.3073616], [68.63680267, 23.30708313], [68.63652802, 23.30708313], [68.63652802, 23.30680466], [68.63625336, 23.30680466], [68.63625336, 23.30708313], [68.63569641, 23.30708313], [68.63569641, 23.3073616], [68.63540649, 23.3073597], [68.63540649, 23.30763817], [68.63346863, 23.30763817], [68.63346863, 23.30791855], [68.63318634, 23.30791855], [68.63318634, 23.30904007], [68.63291931, 23.30902863], [68.63291931, 23.30937958], [68.63291931, 23.30958366], [68.63263702, 23.30958176], [68.63263702, 23.31014252], [68.63236237, 23.31014252], [68.63236237, 23.3104229], [68.63208008, 23.31041718], [68.63208008, 23.31097031], [68.63236237, 23.31097031], [68.63236237, 23.31069374], [68.63375092, 23.31069374], [68.63375092, 23.31097031], [68.6340332, 23.31097031], [68.6340332, 23.31153107], [68.63375092, 23.31152725], [68.63375092, 23.31208229], [68.63346863, 23.31208038], [68.63346863, 23.31264114], [68.63375092, 23.31263924], [68.63375092, 23.31319237], [68.63402557, 23.31319237], [68.63402557, 23.31347466], [68.63430786, 23.31347084], [68.63430786, 23.31375122], [68.63485718, 23.31375122], [68.63485718, 23.31347084], [68.63541412, 23.31347466], [68.63541412, 23.31319237], [68.63569641, 23.31319237], [68.63569641, 23.3129158], [68.63625336, 23.31291962], [68.63625336, 23.31264114], [68.63652802, 23.31264114], [68.63652802, 23.31208038], [68.63680267, 23.31208229], [68.63680267, 23.31175995], [68.63680267, 23.31152725], [68.63764191, 23.31152725], [68.63764191, 23.31208229], [68.63777924, 23.31208229], [68.63957977, 23.31208229], [68.63957977, 23.31180573], [68.63986206, 23.31180954], [68.63986206, 23.31153107], [68.64069366, 23.31152725], [68.64069366, 23.31270981], [68.64069366, 23.31319237], [68.64180756, 23.31319237], [68.64180756, 23.31347466], [68.64208221, 23.31347084], [68.64208221, 23.31402969], [68.64263916, 23.31402969]]], [[[68.62708282, 23.32181168], [68.62708282, 23.32152939], [68.62763977, 23.32152939], [68.62763977, 23.32125092], [68.62847137, 23.32125092], [68.62847137, 23.32098007], [68.62874603, 23.32098007], [68.62874603, 23.32068825], [68.62902832, 23.32069397], [68.62902832, 23.31986046], [68.62930298, 23.31986046], [68.62930298, 23.31847], [68.62958527, 23.31847191], [68.62958527, 23.31569672], [68.62985992, 23.31569672], [68.62985992, 23.31374931], [68.62902832, 23.31375122], [68.62902832, 23.31347084], [68.62875366, 23.31347466], [68.62875366, 23.31319237], [68.62847137, 23.31319237], [68.62847137, 23.3129158], [68.62874603, 23.31291962], [68.62874603, 23.31236076], [68.62847137, 23.31236076], [68.62847137, 23.31208038], [68.62819672, 23.31208229], [68.62819672, 23.31180573], [68.6279068, 23.31180954], [68.6279068, 23.31153107], [68.62747955, 23.31153107], [68.62735748, 23.31153107], [68.62735748, 23.31264114], [68.62680817, 23.31264114], [68.62680817, 23.31236076], [68.62652588, 23.31236076], [68.62652588, 23.31208038], [68.62568665, 23.31208038], [68.62568665, 23.31291962], [68.62596893, 23.3129158], [68.62596893, 23.31319237], [68.62625885, 23.31319046], [68.62625885, 23.31375122], [68.62652588, 23.31375122], [68.62652588, 23.31402969], [68.62680817, 23.31402969], [68.62680817, 23.31431007], [68.62708282, 23.31430626], [68.62708282, 23.3148613], [68.62735748, 23.31485939], [68.62735748, 23.31513977], [68.62763977, 23.31513977], [68.62763977, 23.31569672], [68.62735748, 23.31569099], [68.62735748, 23.31624985], [68.62708282, 23.31624985], [68.62708282, 23.3182106], [68.62735748, 23.3182106], [68.62735748, 23.31875038], [68.62708282, 23.31875038], [68.62708282, 23.31931114], [68.62680817, 23.31930542], [68.62680817, 23.31958389], [68.62652588, 23.31957817], [68.62652588, 23.31986046], [68.62625122, 23.31986046], [68.62625122, 23.32125092], [68.62652588, 23.32125092], [68.62652588, 23.32152939], [68.62680817, 23.32152939], [68.62680817, 23.32181168], [68.62708282, 23.32181168]]], [[[68.63986206, 23.31847191], [68.63986206, 23.31819534], [68.64013672, 23.3182106], [68.64013672, 23.31792068], [68.64041901, 23.31792068], [68.64041901, 23.31735992], [68.64069366, 23.31736183], [68.64069366, 23.31708336], [68.64125061, 23.31708336], [68.64125061, 23.31736183], [68.64097595, 23.31735992], [68.64097595, 23.3182106], [68.6415329, 23.3182106], [68.6415329, 23.31735992], [68.64180756, 23.31736183], [68.64180756, 23.31680679], [68.64263916, 23.31680107], [68.64263916, 23.3176403], [68.64290619, 23.3176403], [68.64290619, 23.3182106], [68.64347076, 23.3182106], [68.64347076, 23.31792068], [68.64375305, 23.31792068], [68.64375305, 23.31735992], [68.64347076, 23.31736183], [68.64347076, 23.31680679], [68.64319611, 23.31680679], [68.64319611, 23.31652832], [68.64290619, 23.31653023], [68.64290619, 23.31624985], [68.64319611, 23.31624985], [68.64319611, 23.31542015], [68.64180756, 23.31541634], [68.64180756, 23.31597137], [68.64013672, 23.31596947], [68.64013672, 23.31624985], [68.63957977, 23.31624985], [68.63957977, 23.31653023], [68.63930511, 23.31652832], [68.63930511, 23.31847191], [68.63986206, 23.31847191]]], [[[68.63263702, 23.3176403], [68.63263702, 23.31707954], [68.63291931, 23.31708336], [68.63291931, 23.31624985], [68.63318634, 23.31624985], [68.63318634, 23.31596947], [68.63375092, 23.31597137], [68.63375092, 23.31569672], [68.63402557, 23.31569672], [68.63402557, 23.31402779], [68.63375092, 23.31402969], [68.63375092, 23.31375122], [68.63346863, 23.31375122], [68.63346863, 23.31347084], [68.63319397, 23.31347466], [68.63319397, 23.31319237], [68.63291931, 23.31319237], [68.63291931, 23.3129158], [68.63263702, 23.31291962], [68.63263702, 23.31264114], [68.63207245, 23.31264114], [68.63207245, 23.31236076], [68.63180542, 23.31236076], [68.63180542, 23.31208229], [68.63124847, 23.31208038], [68.63124847, 23.31236076], [68.63069153, 23.31236076], [68.63069153, 23.31291962], [68.63041687, 23.3129158], [68.63041687, 23.31319237], [68.63069153, 23.31319046], [68.63069153, 23.31375122], [68.63096619, 23.31375122], [68.63096619, 23.31431007], [68.63124847, 23.31430626], [68.63124847, 23.31569672], [68.63153076, 23.31569099], [68.63153076, 23.3176403], [68.63263702, 23.3176403]]], [[[68.63181305, 23.32125092], [68.63180542, 23.32013893], [68.63207245, 23.32014084], [68.63207245, 23.31931114], [68.63236237, 23.31931114], [68.63236237, 23.31875038], [68.63153076, 23.31875038], [68.63153076, 23.31958389], [68.63124847, 23.31957817], [68.63124847, 23.32098007], [68.63153076, 23.32098007], [68.63153076, 23.32125092], [68.63181305, 23.32125092]]], [[[68.57347107, 23.36041832], [68.57347107, 23.36013031], [68.57375336, 23.36013985], [68.57375336, 23.35986137], [68.57402802, 23.35986137], [68.57402802, 23.3595829], [68.57430267, 23.3595829], [68.57430267, 23.35902786], [68.57457733, 23.35902977], [68.57457733, 23.35791969], [68.57402802, 23.35791969], [68.57402802, 23.35764122], [68.57375336, 23.35764122], [68.57375336, 23.35736084], [68.57402802, 23.35736084], [68.57402802, 23.35709], [68.57430267, 23.35709], [68.57430267, 23.35653114], [68.57457733, 23.35653114], [68.57457733, 23.35597038], [68.57430267, 23.35597229], [68.57430267, 23.35569572], [68.57458496, 23.35569572], [68.57458496, 23.35541725], [68.57485962, 23.35542107], [68.57485962, 23.35486031], [68.57514954, 23.35486031], [68.57514191, 23.35430336], [68.57541656, 23.35432053], [68.57541656, 23.35375023], [68.57569122, 23.35375023], [68.57569122, 23.35235977], [68.57457733, 23.35235977], [68.57457733, 23.35264015], [68.57347107, 23.35263824], [68.57347107, 23.35347366], [68.57319641, 23.35346985], [68.57319641, 23.35432053], [68.57290649, 23.35432053], [68.57290649, 23.35486031], [68.57263947, 23.35486031], [68.57263947, 23.35514069], [68.57235718, 23.35514069], [68.57235718, 23.35542107], [68.57096863, 23.35542107], [68.57096863, 23.35653114], [68.57068634, 23.35653114], [68.57068634, 23.35736084], [68.57041931, 23.35736084], [68.57041931, 23.35764122], [68.57013702, 23.35763931], [68.57013702, 23.35819435], [68.56986237, 23.35819054], [68.56986237, 23.35874939], [68.56958008, 23.35874939], [68.56958008, 23.35902977], [68.56986237, 23.35902786], [68.56986237, 23.3595829], [68.57041931, 23.3595829], [68.57041931, 23.35986137], [68.57096863, 23.35986137], [68.57096863, 23.3595829], [68.57125092, 23.3595829], [68.57125092, 23.35930634], [68.5715332, 23.35930824], [68.5715332, 23.35902977], [68.57180786, 23.35902977], [68.57180786, 23.35874939], [68.57236481, 23.35874939], [68.57236481, 23.3595829], [68.57263947, 23.35958099], [68.57263947, 23.36041832], [68.57347107, 23.36041832]]], [[[68.59791565, 23.36097145], [68.59791565, 23.36069489], [68.59902954, 23.36069489], [68.59902954, 23.36041641], [68.59929657, 23.36041832], [68.59929657, 23.36013031], [68.59958649, 23.36013985], [68.59958649, 23.3595829], [68.5993042, 23.3595829], [68.5993042, 23.35930634], [68.5984726, 23.35930634], [68.5984726, 23.3595829], [68.59819794, 23.3595829], [68.59819794, 23.35986137], [68.59708405, 23.35986137], [68.59708405, 23.3595829], [68.59680939, 23.3595829], [68.59680176, 23.35930634], [68.59625244, 23.35930634], [68.59625244, 23.3595829], [68.59597015, 23.35958099], [68.59597015, 23.36041832], [68.59625244, 23.36041641], [68.59625244, 23.36069489], [68.59708405, 23.36069489], [68.59708405, 23.36097145], [68.59791565, 23.36097145]]], [[[68.54070282, 23.37763977], [68.54069519, 23.3773613], [68.54096985, 23.3773613], [68.54096985, 23.37708282], [68.54069519, 23.37708282], [68.54069519, 23.37680626], [68.5404129, 23.37681007], [68.5404129, 23.37624931], [68.54013824, 23.37624931], [68.54013824, 23.37597084], [68.53986359, 23.37597275], [68.53986359, 23.3754158], [68.5395813, 23.37542152], [68.5395813, 23.3751297], [68.53930664, 23.37513924], [68.53930664, 23.37486076], [68.53819275, 23.37486076], [68.53819275, 23.37513924], [68.53791809, 23.3751297], [68.53791809, 23.37542152], [68.53819275, 23.3754158], [68.53819275, 23.37569427], [68.53847504, 23.37569427], [68.53847504, 23.37597275], [68.53874969, 23.37597084], [68.53874969, 23.3765316], [68.53902435, 23.37652779], [68.53902435, 23.37708282], [68.5395813, 23.37708282], [68.5395813, 23.3773613], [68.54013824, 23.37735939], [68.54013824, 23.37763977], [68.54070282, 23.37763977]]], [[[68.62680817, 23.3259716], [68.62680817, 23.32569313], [68.62763977, 23.32570076], [68.62763977, 23.32542038], [68.6279068, 23.32542038], [68.6279068, 23.32514191], [68.62819672, 23.32514191], [68.62819672, 23.32485962], [68.62847137, 23.32486343], [68.62847137, 23.32430649], [68.62874603, 23.3243103], [68.62874603, 23.32374954], [68.62902832, 23.32374954], [68.62902832, 23.32319069], [68.62930298, 23.3231945], [68.62930298, 23.32235909], [68.62902832, 23.32235909], [68.62902832, 23.32152939], [68.62875366, 23.32152748], [68.62875366, 23.32208252], [68.62847137, 23.32208061], [68.62847137, 23.32235909], [68.62819672, 23.32235909], [68.62819672, 23.32263947], [68.6279068, 23.32263947], [68.6279068, 23.32292175], [68.62763977, 23.32291603], [68.62763977, 23.32347107], [68.62735748, 23.32346916], [68.62735748, 23.32374954], [68.62708282, 23.32374954], [68.62708282, 23.32430458], [68.62625122, 23.32430458], [68.62625122, 23.32374954], [68.62596893, 23.32374954], [68.62596893, 23.32402802], [68.62541962, 23.32402802], [68.62541962, 23.32430267], [68.62513733, 23.32430649], [68.62513733, 23.32486343], [68.62486267, 23.32486343], [68.62486267, 23.3259716], [68.62541962, 23.3259716], [68.62541962, 23.32569313], [68.62625122, 23.32569313], [68.62625122, 23.3259716], [68.62680817, 23.3259716]]], [[[68.54207611, 23.34152985], [68.54207611, 23.34124947], [68.5423584, 23.34124947], [68.5423584, 23.33902168], [68.54264069, 23.33902168], [68.54264069, 23.33930969], [68.54429626, 23.33930969], [68.54429626, 23.33902168], [68.54458618, 23.3390274], [68.54458618, 23.33847046], [68.54430389, 23.33847046], [68.54430389, 23.33819389], [68.54208374, 23.33819389], [68.54208374, 23.33736038], [68.54180908, 23.33736038], [68.54180908, 23.33708191], [68.54152679, 23.33708191], [68.54152679, 23.33736038], [68.54125214, 23.33736038], [68.54125214, 23.33819389], [68.54152679, 23.33819389], [68.54152679, 23.33847046], [68.54125214, 23.33847046], [68.54125214, 23.33875275], [68.54152679, 23.33875275], [68.54152679, 23.33930969], [68.54125214, 23.33930969], [68.54125214, 23.33902168], [68.54096985, 23.3390274], [68.54096985, 23.33875275], [68.54069519, 23.33875275], [68.54069519, 23.3390274], [68.5404129, 23.33902168], [68.5404129, 23.33930969], [68.54069519, 23.33930588], [68.54069519, 23.33986282], [68.54096985, 23.33986282], [68.54096985, 23.34013939], [68.54125214, 23.34013939], [68.54125214, 23.34041977], [68.54152679, 23.34041977], [68.54152679, 23.34124947], [68.54180908, 23.34124947], [68.54180908, 23.34152985], [68.54207611, 23.34152985]]], [[[68.55014038, 23.34152985], [68.55014038, 23.34124947], [68.55042267, 23.34124947], [68.55041504, 23.34097481], [68.55069733, 23.34097481], [68.55069733, 23.34013939], [68.55097961, 23.34013939], [68.55097198, 23.33958244], [68.55069733, 23.33958244], [68.55069733, 23.33930588], [68.54875183, 23.33930969], [68.54875183, 23.33902168], [68.54792023, 23.3390274], [68.54792023, 23.33875275], [68.5459671, 23.33875275], [68.5459671, 23.33847046], [68.54541779, 23.33847046], [68.54541779, 23.33875275], [68.5451355, 23.33875275], [68.5451355, 23.34013939], [68.54541779, 23.34013939], [68.54541779, 23.34041977], [68.5459671, 23.34041977], [68.5459671, 23.34013939], [68.54624939, 23.34013939], [68.54624939, 23.33986282], [68.5459671, 23.33986282], [68.5459671, 23.33958054], [68.54763794, 23.33958054], [68.54763794, 23.33986282], [68.54846954, 23.33986282], [68.54846954, 23.34013939], [68.54985809, 23.34013939], [68.54985809, 23.34069252], [68.54957581, 23.34069061], [68.54957581, 23.34124947], [68.54985809, 23.34124947], [68.54985809, 23.34152985], [68.55014038, 23.34152985]]], [[[68.55680847, 23.34181023], [68.55680847, 23.34167099], [68.55680847, 23.34152794], [68.55625153, 23.34152985], [68.55625153, 23.34124947], [68.55541992, 23.34124947], [68.55541992, 23.33902168], [68.55513763, 23.33902168], [68.55513763, 23.33930969], [68.55403137, 23.33930588], [68.55403137, 23.33958244], [68.55374908, 23.33958054], [68.55374908, 23.33986282], [68.55319214, 23.33986282], [68.55319214, 23.34069252], [68.55291748, 23.34069252], [68.55291748, 23.34097481], [68.55319214, 23.34097099], [68.55319214, 23.34124947], [68.5534668, 23.34124947], [68.5534668, 23.34152985], [68.55374908, 23.34152985], [68.55374908, 23.34181023], [68.55647278, 23.34180641], [68.55680847, 23.34181023]]], [[[68.56375122, 23.34486198], [68.56375122, 23.34458351], [68.56430817, 23.34458351], [68.56430817, 23.34430695], [68.56458282, 23.34431076], [68.56458282, 23.34403038], [68.56485748, 23.34403038], [68.56485748, 23.3429203], [68.56513977, 23.3429203], [68.56513977, 23.34263992], [68.56458282, 23.34263992], [68.56458282, 23.34235954], [68.56346893, 23.34236145], [68.56346893, 23.34208488], [68.56263733, 23.34209061], [68.56263733, 23.34181023], [68.56124878, 23.34181023], [68.56124878, 23.34209061], [68.56096649, 23.34209061], [68.56096649, 23.3429203], [68.56124878, 23.3429203], [68.56124878, 23.34320068], [68.56153107, 23.34319687], [68.56153107, 23.34347153], [68.56180573, 23.34347153], [68.56180573, 23.34375], [68.56208038, 23.34375], [68.56208038, 23.34403038], [68.56236267, 23.34403038], [68.56236267, 23.34431076], [68.56263733, 23.34430695], [68.56263733, 23.34458351], [68.56319427, 23.34458351], [68.56319427, 23.34486198], [68.56375122, 23.34486198]]], [[[68.63153076, 23.35180473], [68.63153076, 23.35152817], [68.63181305, 23.35153008], [68.63181305, 23.35096169], [68.63208008, 23.35097122], [68.63208008, 23.34985924], [68.63236237, 23.34985924], [68.63236237, 23.34847069], [68.63263702, 23.3484726], [68.63263702, 23.34791756], [68.63291931, 23.34792137], [68.63291931, 23.34763908], [68.63318634, 23.34763908], [68.63318634, 23.34708023], [68.63346863, 23.34708405], [68.63346863, 23.34680557], [68.63430786, 23.34680748], [68.63430786, 23.34568977], [68.63486481, 23.34569359], [68.63486481, 23.34541893], [68.63569641, 23.34542084], [68.63569641, 23.34375], [68.63540649, 23.34375], [68.63540649, 23.34346962], [68.63513947, 23.34347153], [68.63513947, 23.34291649], [68.63485718, 23.3429203], [68.63485718, 23.34263992], [68.63430786, 23.34263992], [68.63430786, 23.34235954], [68.6340332, 23.34235954], [68.6340332, 23.34263992], [68.63346863, 23.34263992], [68.63346863, 23.3429203], [68.63291931, 23.34291649], [68.63291931, 23.34347153], [68.63318634, 23.34346962], [68.63318634, 23.34375], [68.63236237, 23.34375], [68.63236237, 23.34431076], [68.63069153, 23.34431076], [68.63069153, 23.34514809], [68.63096619, 23.34514809], [68.63096619, 23.34542084], [68.63124847, 23.34541893], [68.63124847, 23.34569359], [68.63153076, 23.34569359], [68.63153076, 23.34597206], [68.63263702, 23.34597015], [68.63263702, 23.34653091], [68.63236237, 23.34653091], [68.63236237, 23.34680748], [68.63180542, 23.34680557], [68.63180542, 23.34708405], [68.63153076, 23.34708023], [68.63153076, 23.34763908], [68.63180542, 23.34763908], [68.63180542, 23.3484726], [68.63096619, 23.34847069], [68.63096619, 23.34874916], [68.63124847, 23.34874916], [68.63124847, 23.34902954], [68.63153076, 23.34902954], [68.63153076, 23.34931183], [68.63124847, 23.34930611], [68.63124847, 23.34958267], [68.63096619, 23.34958076], [68.63096619, 23.34985924], [68.63041687, 23.34985924], [68.63041687, 23.34958076], [68.63014221, 23.34958267], [68.63014221, 23.34930611], [68.62985992, 23.34931183], [68.62985992, 23.34902954], [68.6295929, 23.34902954], [68.6295929, 23.34874916], [68.62930298, 23.34874916], [68.62930298, 23.34847069], [68.62874603, 23.34847069], [68.62874603, 23.34874916], [68.62847137, 23.34874916], [68.62847137, 23.35097122], [68.62985992, 23.35096169], [68.62985992, 23.35124969], [68.63041687, 23.35124969], [68.63041687, 23.35153008], [68.63097382, 23.35152817], [68.63097382, 23.35180473], [68.63153076, 23.35180473]]], [[[68.60346985, 23.33402824], [68.60346985, 23.33458328], [68.60320282, 23.33457756], [68.60320282, 23.33513832], [68.60208893, 23.33513832], [68.60208893, 23.33457756], [68.60152435, 23.33458328], [68.60152435, 23.33486176], [68.60124969, 23.33485985], [68.60124969, 23.3354187], [68.60098267, 23.3354187], [68.60098267, 23.3357029], [68.60069275, 23.33569527], [68.60069275, 23.33597183], [68.60041809, 23.33596039], [68.60041809, 23.33625031], [68.6001358, 23.33625031], [68.6001358, 23.33653259], [68.59986115, 23.33653259], [68.59986115, 23.33681107], [68.59958649, 23.33680534], [68.59958649, 23.33708382], [68.59819794, 23.33708191], [68.59819794, 23.33764267], [68.59792328, 23.33764267], [68.59792328, 23.33792114], [68.59764099, 23.33791733], [68.59764099, 23.33819389], [68.5973587, 23.33819389], [68.5973587, 23.33847046], [68.59597015, 23.33847046], [68.59597015, 23.33875275], [68.59541321, 23.33875275], [68.59541321, 23.33847046], [68.59485626, 23.33847046], [68.59485626, 23.33875275], [68.59430695, 23.33875275], [68.59430695, 23.33930969], [68.59401703, 23.33930969], [68.59401703, 23.33986282], [68.59375, 23.33986282], [68.59375, 23.34041977], [68.5929184, 23.34041405], [68.5929184, 23.34069252], [68.59263611, 23.34069061], [68.59263611, 23.34124947], [68.59179688, 23.34124947], [68.59179688, 23.34152985], [68.5909729, 23.34152985], [68.5909729, 23.34263992], [68.59069824, 23.34263992], [68.59069061, 23.34320068], [68.59041595, 23.34319687], [68.59041595, 23.34347153], [68.5901413, 23.34347153], [68.59014893, 23.34375], [68.58985901, 23.34375], [68.58985901, 23.34403038], [68.58958435, 23.34402847], [68.58958435, 23.34458351], [68.58930206, 23.3445797], [68.58930206, 23.34514809], [68.5890274, 23.34513855], [68.5890274, 23.34569359], [68.58875275, 23.34568977], [68.58872986, 23.34625053], [68.58847046, 23.34625053], [68.58847046, 23.34680748], [68.5881958, 23.34680557], [68.5881958, 23.34708405], [68.58790588, 23.34708023], [68.58790588, 23.34736061], [68.58763885, 23.34736061], [68.58763885, 23.34763908], [68.5873642, 23.34763908], [68.5873642, 23.34819412], [68.58708191, 23.34819412], [68.58708191, 23.3484726], [68.58680725, 23.34847069], [68.58680725, 23.34874916], [68.58653259, 23.34874916], [68.58653259, 23.34902954], [68.58625031, 23.34902763], [68.58625031, 23.34958267], [68.58597565, 23.34958267], [68.58598328, 23.35013962], [68.58569336, 23.35013962], [68.58569336, 23.35069466], [68.5854187, 23.35069275], [68.5854187, 23.35124969], [68.58513641, 23.35124969], [68.58513641, 23.35180473], [68.58486176, 23.35180473], [68.58486176, 23.3520813], [68.5845871, 23.35207939], [68.5845871, 23.35264015], [68.58429718, 23.35264015], [68.58429718, 23.35320091], [68.58403015, 23.35319328], [68.58403015, 23.35347366], [68.58347321, 23.35346985], [68.58347321, 23.35375023], [68.58235931, 23.35375023], [68.58235931, 23.35346985], [68.58152771, 23.35347366], [68.58152771, 23.35319328], [68.58069611, 23.35320091], [68.58069611, 23.35292053], [68.58040619, 23.35292053], [68.58040619, 23.35153008], [68.57985687, 23.35153008], [68.57985687, 23.35124969], [68.5790329, 23.35124969], [68.5790329, 23.35153008], [68.57847595, 23.35152817], [68.57847595, 23.35180473], [68.57819366, 23.35180473], [68.57819366, 23.3520813], [68.57791901, 23.3520813], [68.57791901, 23.35236359], [68.57763672, 23.35235977], [68.57763672, 23.35264015], [68.57791901, 23.35264015], [68.57791901, 23.35292053], [68.57763672, 23.35291672], [68.57763672, 23.35347366], [68.57736206, 23.35346985], [68.57736206, 23.35403061], [68.57707977, 23.35403061], [68.57707977, 23.35514069], [68.57736206, 23.35513878], [68.57736206, 23.35597229], [68.57707977, 23.35597038], [68.57707977, 23.35653114], [68.57736206, 23.35653114], [68.57736206, 23.35625076], [68.57763672, 23.35625076], [68.57763672, 23.35597038], [68.57791901, 23.35597229], [68.57791901, 23.35541725], [68.57818604, 23.35542107], [68.57818604, 23.35486031], [68.57847595, 23.35486031], [68.57847595, 23.35432053], [68.57875061, 23.35432053], [68.57875061, 23.35403061], [68.5790329, 23.35403061], [68.5790329, 23.35375023], [68.57930756, 23.35375023], [68.57930756, 23.35346985], [68.58013916, 23.35346985], [68.58013916, 23.35375023], [68.58040619, 23.35375023], [68.58040619, 23.35432053], [68.57985687, 23.35432053], [68.57985687, 23.35486031], [68.57958221, 23.35486031], [68.57958221, 23.35542107], [68.57930756, 23.35541725], [68.57930756, 23.35597229], [68.5790329, 23.35597038], [68.5790329, 23.35653114], [68.57958221, 23.35653114], [68.57958221, 23.35680962], [68.57985687, 23.35680962], [68.57985687, 23.35791969], [68.57958221, 23.35791969], [68.57958221, 23.35874939], [68.57930756, 23.35874939], [68.57930756, 23.35902977], [68.57902527, 23.35902786], [68.57902527, 23.3595829], [68.57930756, 23.3595829], [68.57930756, 23.36013985], [68.5790329, 23.36013031], [68.5790329, 23.36041832], [68.57875061, 23.36041641], [68.57875061, 23.36097145], [68.57847595, 23.36096954], [68.57847595, 23.36124992], [68.57791901, 23.36124992], [68.57791901, 23.3615284], [68.57763672, 23.3615284], [68.57763672, 23.36208344], [68.57736206, 23.36207962], [68.57736206, 23.36264038], [68.57707977, 23.36264038], [68.57707977, 23.36292267], [68.57680511, 23.36291695], [68.57680511, 23.36319351], [68.57653046, 23.36319351], [68.57653046, 23.36347008], [68.57597351, 23.36347008], [68.57597351, 23.36319351], [68.57569122, 23.36319351], [68.57569122, 23.36291695], [68.57485962, 23.36292267], [68.57485962, 23.36181068], [68.57514954, 23.36181068], [68.57514954, 23.36041832], [68.57485962, 23.36041641], [68.57485962, 23.36069489], [68.57430267, 23.36069489], [68.57430267, 23.36097145], [68.57402802, 23.36096954], [68.57402802, 23.3615284], [68.57375336, 23.3615284], [68.57375336, 23.36208344], [68.57319641, 23.36208344], [68.57319641, 23.36236191], [68.57290649, 23.36235809], [68.57290649, 23.36264038], [68.57263947, 23.36264038], [68.57263947, 23.36292267], [68.57236481, 23.36291695], [68.57236481, 23.36319351], [68.57208252, 23.3631916], [68.57208252, 23.36375046], [68.57180786, 23.36375046], [68.57180786, 23.36403275], [68.57152557, 23.36402702], [68.57152557, 23.36458206], [68.57125092, 23.36458015], [68.57125092, 23.36514282], [68.57096863, 23.36513901], [68.57096863, 23.36597443], [68.57068634, 23.36597061], [68.57068634, 23.36652946], [68.57041931, 23.36652946], [68.57041931, 23.36763954], [68.57013702, 23.36763954], [68.57013702, 23.36874962], [68.56986237, 23.36874962], [68.56986237, 23.36930656], [68.57068634, 23.36930084], [68.57068634, 23.37014008], [68.57041931, 23.37013817], [68.57041931, 23.37097168], [68.56986237, 23.37096977], [68.56986237, 23.37125015], [68.56931305, 23.37125015], [68.56931305, 23.37153053], [68.56874847, 23.37153053], [68.56874847, 23.37181091], [68.56819153, 23.37180519], [68.56819153, 23.37208366], [68.56791687, 23.37207031], [68.56791687, 23.37236023], [68.56819153, 23.37236023], [68.56819153, 23.37264061], [68.56846619, 23.37264061], [68.56846619, 23.37291908], [68.56874847, 23.37291718], [68.56874847, 23.37319374], [68.56958008, 23.37319374], [68.56958008, 23.37347221], [68.57068634, 23.37347031], [68.57068634, 23.37375069], [68.57180786, 23.37375069], [68.57180786, 23.37347031], [68.57263947, 23.37347221], [68.57263947, 23.37319374], [68.57347107, 23.37319374], [68.57347107, 23.37291718], [68.57458496, 23.37291718], [68.57458496, 23.37319374], [68.57485962, 23.37319374], [68.57485962, 23.37347221], [68.57541656, 23.37347221], [68.57541656, 23.37319374], [68.57653046, 23.37319374], [68.57653046, 23.37291718], [68.57818604, 23.37291908], [68.57818604, 23.37236023], [68.57847595, 23.37236023], [68.57847595, 23.37181091], [68.58013916, 23.37181091], [68.58013916, 23.37153053], [68.58096313, 23.37153053], [68.58096313, 23.37125015], [68.58152771, 23.37125015], [68.58152771, 23.37153053], [68.58180237, 23.37153053], [68.58180237, 23.37181091], [68.58152771, 23.37180519], [68.58152771, 23.37208366], [68.58180237, 23.37207031], [68.58180237, 23.37264061], [68.58208466, 23.3726387], [68.58208466, 23.37319374], [68.58235931, 23.37319374], [68.58235931, 23.37347221], [68.58625031, 23.37347221], [68.58625031, 23.37291718], [68.58653259, 23.37291908], [68.58653259, 23.37264061], [68.58763885, 23.37264061], [68.58763885, 23.37181091], [68.58735657, 23.37181091], [68.58735657, 23.37125015], [68.58680725, 23.37125015], [68.58680725, 23.37070084], [68.58653259, 23.37070084], [68.58653259, 23.37014008], [68.58625031, 23.37014008], [68.58625031, 23.3698597], [68.58652496, 23.3698616], [68.58652496, 23.36930656], [68.58680725, 23.36930656], [68.58680725, 23.36902809], [68.58708954, 23.36903], [68.58708954, 23.36874962], [68.5873642, 23.36874962], [68.58735657, 23.36847115], [68.58791351, 23.36847305], [68.58791351, 23.36930656], [68.5881958, 23.36930656], [68.5881958, 23.37097168], [68.58847046, 23.37096977], [68.58847046, 23.37125015], [68.58875275, 23.37125015], [68.58875275, 23.37153053], [68.5890274, 23.37153053], [68.5890274, 23.37181091], [68.58930206, 23.37181091], [68.58930206, 23.37236023], [68.58957672, 23.37236023], [68.58957672, 23.37291908], [68.58930206, 23.37291718], [68.58930206, 23.37319374], [68.58875275, 23.37318993], [68.58875275, 23.37431145], [68.5890274, 23.37431145], [68.5890274, 23.37402916], [68.58957672, 23.37402916], [68.58957672, 23.37375069], [68.58985901, 23.37375069], [68.58985901, 23.37347031], [68.5901413, 23.37347221], [68.5901413, 23.37291718], [68.59041595, 23.37291908], [68.59041595, 23.37236023], [68.5909729, 23.37236023], [68.5909729, 23.37207031], [68.59124756, 23.37208366], [68.59124756, 23.37180519], [68.59179688, 23.37181091], [68.59179688, 23.37153053], [68.59208679, 23.37153053], [68.59208679, 23.37125015], [68.59263611, 23.37125015], [68.59263611, 23.37096977], [68.5929184, 23.37097168], [68.5929184, 23.37041664], [68.59319305, 23.37042046], [68.59319305, 23.37014008], [68.59348297, 23.37014008], [68.59348297, 23.3698597], [68.59375, 23.3698616], [68.59375, 23.36958313], [68.59402466, 23.36958313], [68.59402466, 23.36930656], [68.59430695, 23.36930656], [68.59430695, 23.36902809], [68.5945816, 23.36903], [68.5945816, 23.36874962], [68.59485626, 23.36874962], [68.59485626, 23.36791992], [68.59513855, 23.36791992], [68.59513855, 23.36763954], [68.59541321, 23.36763954], [68.59541321, 23.36708069], [68.5956955, 23.3670845], [68.5956955, 23.36652756], [68.59597015, 23.36652946], [68.59597015, 23.36626053], [68.59625244, 23.36626053], [68.59625244, 23.36597061], [68.5965271, 23.36597443], [68.5965271, 23.36569214], [68.59680176, 23.36569214], [68.59680939, 23.36513901], [68.59707642, 23.36514282], [68.59707642, 23.36486053], [68.5973587, 23.36486053], [68.5973587, 23.36458015], [68.59764099, 23.36458206], [68.59764099, 23.36402702], [68.59792328, 23.36403275], [68.59792328, 23.3631916], [68.59819794, 23.36319351], [68.59819794, 23.36263847], [68.59792328, 23.36264038], [68.59792328, 23.36235809], [68.59764099, 23.36236191], [68.59764099, 23.36208344], [68.5973587, 23.36208344], [68.5973587, 23.36180496], [68.59707642, 23.36181068], [68.59707642, 23.3615284], [68.59680939, 23.3615284], [68.59680176, 23.36124992], [68.59570313, 23.36124992], [68.59570313, 23.3615284], [68.59430695, 23.3615284], [68.59430695, 23.36096954], [68.5945816, 23.36097145], [68.5945816, 23.36041641], [68.59485626, 23.36041832], [68.59485626, 23.35902977], [68.59513855, 23.35902977], [68.59513855, 23.35874939], [68.59570313, 23.35874939], [68.5956955, 23.35847282], [68.5965271, 23.35847282], [68.5965271, 23.35819435], [68.59680176, 23.35819435], [68.59680939, 23.35791779], [68.59707642, 23.35791969], [68.59707642, 23.35764122], [68.5973587, 23.35764122], [68.5973587, 23.35736084], [68.59764099, 23.35736084], [68.59764099, 23.35709], [68.59874725, 23.35709], [68.59874725, 23.35736084], [68.59902954, 23.35736084], [68.59902954, 23.35791969], [68.59986115, 23.35791779], [68.59986115, 23.35819435], [68.6020813, 23.35819435], [68.6020813, 23.35791779], [68.60263824, 23.35791969], [68.60263824, 23.35764122], [68.60375214, 23.35764122], [68.60375214, 23.35709], [68.60346985, 23.35709], [68.60346985, 23.35653114], [68.60375214, 23.35653114], [68.60375214, 23.35625076], [68.60430908, 23.35625076], [68.60430908, 23.35597038], [68.60458374, 23.35597229], [68.60458374, 23.35569572], [68.6048584, 23.35569572], [68.6048584, 23.35541725], [68.60542297, 23.35542107], [68.60542297, 23.35514069], [68.60569763, 23.35514069], [68.60569763, 23.35486031], [68.60597229, 23.35486031], [68.60597229, 23.35432053], [68.60624695, 23.35432053], [68.60624695, 23.35403061], [68.60652924, 23.35403061], [68.60652924, 23.35375023], [68.60679626, 23.35375023], [68.60679626, 23.35346985], [68.60708618, 23.35347366], [68.60708618, 23.35319328], [68.60736084, 23.35320091], [68.60736084, 23.35292053], [68.6084671, 23.35292053], [68.6084671, 23.35264015], [68.60901642, 23.35264015], [68.60901642, 23.35235977], [68.60958099, 23.35236359], [68.60958099, 23.3520813], [68.61013794, 23.3520813], [68.61013794, 23.35180473], [68.61069489, 23.35180473], [68.61069489, 23.3520813], [68.61042023, 23.35207939], [68.61042023, 23.35264015], [68.61013794, 23.35264015], [68.61013794, 23.35320091], [68.60986328, 23.35320091], [68.60986328, 23.35375023], [68.61013794, 23.35375023], [68.61013794, 23.35514069], [68.60986328, 23.35513878], [68.60986328, 23.35569572], [68.60958099, 23.35569572], [68.60958099, 23.35597229], [68.60930634, 23.35597038], [68.60930634, 23.35653114], [68.60902405, 23.35652733], [68.60902405, 23.35819435], [68.60930634, 23.35819054], [68.60930634, 23.35930824], [68.60902405, 23.35930634], [68.60902405, 23.36013985], [68.60874939, 23.36013985], [68.60874939, 23.36069489], [68.6084671, 23.36069107], [68.6084671, 23.36124992], [68.60791779, 23.36124992], [68.60791779, 23.3615284], [68.60764313, 23.3615284], [68.60764313, 23.36292267], [68.60736084, 23.36291695], [68.60736084, 23.36347008], [68.60708618, 23.36347008], [68.60708618, 23.36375046], [68.60679626, 23.36375046], [68.60679626, 23.36403275], [68.60708618, 23.36402702], [68.60708618, 23.36458206], [68.60736084, 23.36458206], [68.60736084, 23.3643055], [68.60874939, 23.36431122], [68.60874939, 23.36375046], [68.60901642, 23.36375046], [68.60901642, 23.36292267], [68.60930634, 23.36292267], [68.60930634, 23.36207962], [68.60958099, 23.36208344], [68.60958099, 23.3615284], [68.61013794, 23.3615284], [68.61013794, 23.36096954], [68.61042023, 23.36097145], [68.61042023, 23.35874939], [68.61068726, 23.35874939], [68.61068726, 23.35764122], [68.61152649, 23.35764122], [68.61152649, 23.35736084], [68.61180878, 23.35736084], [68.61180878, 23.35709], [68.61235809, 23.35709], [68.61235809, 23.35653114], [68.61264038, 23.35653114], [68.61264038, 23.35597038], [68.61291504, 23.35597229], [68.61291504, 23.35569572], [68.61347198, 23.35569572], [68.61347198, 23.35541725], [68.61402893, 23.35542107], [68.61402893, 23.35514069], [68.61486053, 23.35514069], [68.61486053, 23.35486031], [68.6159668, 23.35486031], [68.6159668, 23.35457993], [68.61680603, 23.35458565], [68.61680603, 23.35430336], [68.61736298, 23.35432053], [68.61736298, 23.35403061], [68.61791992, 23.35403061], [68.61791992, 23.35346985], [68.61819458, 23.35347366], [68.61819458, 23.35291672], [68.61846924, 23.35292053], [68.61846924, 23.35124969], [68.61818695, 23.35124969], [68.61818695, 23.35069275], [68.61791992, 23.35069466], [68.61791992, 23.34985924], [68.61763763, 23.34985924], [68.61763763, 23.34902954], [68.61736298, 23.34902954], [68.61736298, 23.34847069], [68.61680603, 23.34847069], [68.61680603, 23.34874916], [68.61653137, 23.34874916], [68.61653137, 23.34931183], [68.61624908, 23.34930611], [68.61624908, 23.34958267], [68.6159668, 23.34958076], [68.6159668, 23.34985924], [68.61569214, 23.34985924], [68.61569214, 23.35042191], [68.61486053, 23.35042191], [68.61486053, 23.34985924], [68.61514282, 23.34985924], [68.61513519, 23.34930611], [68.61541748, 23.34931183], [68.61541748, 23.34847069], [68.61569214, 23.3484726], [68.61569214, 23.34791756], [68.6159668, 23.34792137], [68.6159668, 23.34736061], [68.61624908, 23.34736061], [68.61624908, 23.34708023], [68.61653137, 23.34708405], [68.61653137, 23.3465271], [68.61680603, 23.34653091], [68.61680603, 23.34568977], [68.61708069, 23.34569359], [68.61708069, 23.34458351], [68.61736298, 23.34458351], [68.61736298, 23.34319687], [68.61763763, 23.34320068], [68.61763763, 23.34181023], [68.61791992, 23.34181023], [68.61791992, 23.34041977], [68.61818695, 23.34041977], [68.61818695, 23.33958054], [68.61846924, 23.33958244], [68.61846924, 23.33930588], [68.61875153, 23.33930969], [68.61875153, 23.33902168], [68.61902618, 23.3390274], [68.61902618, 23.33875275], [68.61930847, 23.33875275], [68.61930847, 23.33847046], [68.61958313, 23.33847046], [68.61958313, 23.33791733], [68.61985779, 23.33792114], [68.61985779, 23.33736038], [68.62013245, 23.33736038], [68.62013245, 23.33681107], [68.6204071, 23.33681107], [68.6204071, 23.33291817], [68.62013245, 23.33291817], [68.62013245, 23.33180809], [68.61985779, 23.33180809], [68.61985779, 23.33069038], [68.61958313, 23.3306942], [68.61958313, 23.33013916], [68.61930847, 23.3301506], [68.61930847, 23.32958031], [68.61902618, 23.32958412], [68.61902618, 23.32902718], [68.61875153, 23.32903099], [68.61875153, 23.32875061], [68.61846924, 23.32875061], [68.61846924, 23.32847023], [68.61819458, 23.32847214], [68.61819458, 23.32819557], [68.61763763, 23.32819557], [68.61763763, 23.3279171], [68.61736298, 23.32792091], [68.61736298, 23.32764053], [68.61707306, 23.32764053], [68.61707306, 23.32792091], [68.61680603, 23.3279171], [68.61680603, 23.32819557], [68.61653137, 23.32819557], [68.61653137, 23.32958412], [68.61624908, 23.32958031], [68.61624908, 23.33291817], [68.61653137, 23.33291817], [68.61653137, 23.33402824], [68.61569214, 23.33402824], [68.61569214, 23.33374977], [68.61429596, 23.33374977], [68.61429596, 23.33402824], [68.61347198, 23.33402824], [68.61347198, 23.33374977], [68.61374664, 23.33374977], [68.61374664, 23.33319092], [68.61402893, 23.33319473], [68.61402893, 23.33263969], [68.61374664, 23.33263969], [68.61374664, 23.33236122], [68.61152649, 23.33236122], [68.61152649, 23.33263969], [68.61068726, 23.33263969], [68.61068726, 23.33402824], [68.61042023, 23.33402824], [68.61042023, 23.3354187], [68.61068726, 23.3354187], [68.61068726, 23.33513832], [68.61096954, 23.33513832], [68.61096954, 23.33485985], [68.61125183, 23.33486176], [68.61125183, 23.33458328], [68.61180878, 23.33457756], [68.61180878, 23.3357029], [68.61152649, 23.33569527], [68.61152649, 23.33597183], [68.61096954, 23.33596039], [68.61096954, 23.33625031], [68.61068726, 23.33625031], [68.61068726, 23.33653259], [68.61042023, 23.33653259], [68.61042023, 23.33681107], [68.61013794, 23.33680534], [68.61013794, 23.33708382], [68.60986328, 23.33708191], [68.60986328, 23.33736038], [68.60958099, 23.33736038], [68.60958099, 23.33764267], [68.60930634, 23.33763885], [68.60930634, 23.33819389], [68.60902405, 23.33819389], [68.60902405, 23.33847046], [68.60874939, 23.33847046], [68.60874939, 23.33875275], [68.60791779, 23.33875275], [68.60791779, 23.3390274], [68.60736084, 23.33902168], [68.60736084, 23.33930969], [68.60708618, 23.33930588], [68.60708618, 23.33958244], [68.60652924, 23.33958054], [68.60652924, 23.33986282], [68.60624695, 23.33986282], [68.60624695, 23.34013939], [68.60597229, 23.34013939], [68.60597229, 23.34041977], [68.60569763, 23.34041405], [68.60569763, 23.34069252], [68.60541534, 23.34069252], [68.60541534, 23.34097481], [68.60513306, 23.34097099], [68.60513306, 23.34124947], [68.60430908, 23.34124947], [68.60430908, 23.34097099], [68.60402679, 23.34097099], [68.60402679, 23.34152985], [68.60375214, 23.34152794], [68.60375214, 23.34236145], [68.60346985, 23.34235954], [68.60346985, 23.3429203], [68.6029129, 23.3429203], [68.6029129, 23.34320068], [68.60236359, 23.34319687], [68.60236359, 23.34347153], [68.60180664, 23.34346962], [68.60180664, 23.34375], [68.60151672, 23.34375], [68.60151672, 23.34403038], [68.60124969, 23.34403038], [68.60124969, 23.34431076], [68.60069275, 23.34430695], [68.60069275, 23.34458351], [68.60041809, 23.34458351], [68.60041809, 23.34486198], [68.6001358, 23.34486008], [68.6001358, 23.34542084], [68.59986115, 23.34541893], [68.59986115, 23.34569359], [68.5993042, 23.34569359], [68.5993042, 23.34597206], [68.59874725, 23.34597015], [68.59874725, 23.34625053], [68.59819794, 23.34625053], [68.59819794, 23.34653091], [68.59764099, 23.34653091], [68.59764099, 23.34680748], [68.59680939, 23.34680748], [68.59680939, 23.34625053], [68.59707642, 23.34625053], [68.59707642, 23.34568977], [68.5973587, 23.34569359], [68.5973587, 23.34513855], [68.59764099, 23.34514809], [68.59764099, 23.3445797], [68.59791565, 23.34458351], [68.59791565, 23.34430695], [68.59819794, 23.34431076], [68.59819794, 23.34403038], [68.59874725, 23.34403038], [68.59874725, 23.34375], [68.59902954, 23.34375], [68.59902954, 23.34346962], [68.59958649, 23.34347153], [68.59958649, 23.34319687], [68.59986115, 23.34320068], [68.59986115, 23.3429203], [68.60041809, 23.3429203], [68.60041809, 23.34263992], [68.60069275, 23.34263992], [68.60069275, 23.34209061], [68.60098267, 23.34209061], [68.60098267, 23.34181023], [68.60124969, 23.34181023], [68.60124969, 23.34097099], [68.60152435, 23.34097481], [68.60152435, 23.34013939], [68.60180664, 23.34013939], [68.60180664, 23.33986282], [68.60208893, 23.33986282], [68.6020813, 23.33958244], [68.60236359, 23.33958244], [68.60236359, 23.33930588], [68.60263824, 23.33930969], [68.60263824, 23.33902168], [68.6029129, 23.3390274], [68.6029129, 23.33875275], [68.60346985, 23.33875275], [68.60346985, 23.33847046], [68.60375214, 23.33847046], [68.60375214, 23.33819389], [68.60402679, 23.33819389], [68.60402679, 23.33763885], [68.60430908, 23.33764267], [68.60430908, 23.33736038], [68.60457611, 23.33736038], [68.60457611, 23.33681107], [68.6048584, 23.33681107], [68.6048584, 23.33625031], [68.60513306, 23.33625031], [68.60513306, 23.33596039], [68.60541534, 23.33597183], [68.60541534, 23.33541679], [68.60569763, 23.3354187], [68.60569763, 23.33485985], [68.60541534, 23.33486176], [68.60541534, 23.33458328], [68.60569763, 23.33458328], [68.60569763, 23.33402824], [68.60597229, 23.33402824], [68.60597229, 23.33346939], [68.60624695, 23.3334713], [68.60624695, 23.33319473], [68.60652924, 23.33319473], [68.60652924, 23.33291626], [68.60679626, 23.33291817], [68.60679626, 23.33263969], [68.60708618, 23.33263969], [68.60708618, 23.33236122], [68.60736084, 23.33236122], [68.60736084, 23.33180809], [68.60652924, 23.33180618], [68.60652924, 23.33208275], [68.60597229, 23.33208084], [68.60597229, 23.33236122], [68.60569763, 23.33236122], [68.60569763, 23.33263969], [68.60513306, 23.33263969], [68.60513306, 23.33291817], [68.6048584, 23.33291626], [68.6048584, 23.33319473], [68.60430908, 23.33319473], [68.60430908, 23.3334713], [68.60402679, 23.33346939], [68.60402679, 23.33374977], [68.60375214, 23.33374977], [68.60375214, 23.33402824], [68.60346985, 23.33402824]]], [[[68.50458527, 23.38458252], [68.50458527, 23.38430786], [68.50485992, 23.38430786], [68.50485992, 23.38375092], [68.50514221, 23.38375092], [68.50514221, 23.38125992], [68.50485992, 23.38125992], [68.50485992, 23.38097], [68.50430298, 23.38097], [68.50430298, 23.38125992], [68.5045929, 23.38125992], [68.5045929, 23.38181114], [68.50430298, 23.38181114], [68.50430298, 23.38264084], [68.5045929, 23.38264084], [68.5045929, 23.38292122], [68.50430298, 23.3829174], [68.50430298, 23.38319588], [68.50375366, 23.38319588], [68.50375366, 23.38430786], [68.50430298, 23.38430786], [68.50430298, 23.38458252], [68.50458527, 23.38458252]]], [[[68.57930756, 23.38541985], [68.57930756, 23.38513947], [68.58013916, 23.38513947], [68.58013916, 23.38486099], [68.58069611, 23.38486099], [68.58069611, 23.38458061], [68.58125305, 23.38458252], [68.58125305, 23.38430786], [68.58152771, 23.38430786], [68.58152771, 23.38402748], [68.58180237, 23.38402939], [68.58180237, 23.38375092], [68.58207703, 23.38375092], [68.58207703, 23.38347054], [68.58235931, 23.38347244], [68.58235931, 23.38319588], [68.5826416, 23.38319588], [68.5826416, 23.3829174], [68.58319092, 23.38292122], [68.58319092, 23.38264084], [68.58347321, 23.38264084], [68.58347321, 23.38236046], [68.58374786, 23.38236046], [68.58374786, 23.38208008], [68.58403015, 23.3820858], [68.58403015, 23.38152695], [68.58429718, 23.38153076], [68.58429718, 23.38125992], [68.58486176, 23.38125992], [68.58486176, 23.38097], [68.5854187, 23.38097382], [68.5854187, 23.38041687], [68.58598328, 23.38042068], [68.58598328, 23.3801403], [68.58625031, 23.3801403], [68.58625031, 23.37903023], [68.58653259, 23.37903023], [68.58653259, 23.37874985], [68.58680725, 23.37874985], [68.58680725, 23.37846947], [68.58708191, 23.37847137], [68.58708191, 23.37791634], [68.58735657, 23.37792015], [68.58735657, 23.37624931], [68.58708954, 23.37624931], [68.58708954, 23.37597084], [68.58652496, 23.37597275], [68.58652496, 23.37569427], [68.58625031, 23.37569427], [68.58625031, 23.37597275], [68.58569336, 23.37597275], [68.58569336, 23.37708282], [68.5854187, 23.37708092], [68.5854187, 23.37763977], [68.58486176, 23.37763977], [68.58486176, 23.37792015], [68.5845871, 23.37792015], [68.5845871, 23.37820053], [68.58429718, 23.37820053], [68.58429718, 23.37903023], [68.58374786, 23.37903023], [68.58374786, 23.37874985], [68.58319092, 23.37874985], [68.58319092, 23.37930489], [68.58291626, 23.37930489], [68.58291626, 23.37986374], [68.58319092, 23.37985992], [68.58319092, 23.3801403], [68.58374786, 23.3801403], [68.58374786, 23.38042068], [68.58347321, 23.38042068], [68.58347321, 23.38070107], [68.58319092, 23.38069534], [68.58319092, 23.38097382], [68.58291626, 23.38097], [68.58291626, 23.38125992], [68.58235931, 23.38125992], [68.58235931, 23.38153076], [68.58207703, 23.38153076], [68.58207703, 23.38181114], [68.58125305, 23.38180351], [68.58125305, 23.3820858], [68.58069611, 23.38208008], [68.58069611, 23.38236046], [68.58040619, 23.38236046], [68.58040619, 23.38264084], [68.58013916, 23.38264084], [68.58013916, 23.38292122], [68.5798645, 23.3829174], [68.5798645, 23.38319588], [68.57902527, 23.38319588], [68.57902527, 23.38347244], [68.57847595, 23.38347054], [68.57847595, 23.38375092], [68.57818604, 23.38375092], [68.57818604, 23.38402939], [68.57791901, 23.38402939], [68.57791901, 23.38513947], [68.57818604, 23.38513947], [68.57818604, 23.38541985], [68.57930756, 23.38541985]]], [[[68.53624725, 23.38541985], [68.53624725, 23.38458061], [68.53652954, 23.38458252], [68.53652954, 23.38375092], [68.53624725, 23.38375092], [68.53624725, 23.38319016], [68.5359726, 23.38319588], [68.5359726, 23.3829174], [68.53624725, 23.38292122], [68.53624725, 23.38264084], [68.53652954, 23.38264084], [68.53652954, 23.38236046], [68.53779602, 23.38236046], [68.53874969, 23.38236046], [68.53874969, 23.38264084], [68.53901672, 23.38264084], [68.53901672, 23.38236046], [68.53985596, 23.38236046], [68.53985596, 23.38208008], [68.54069519, 23.3820858], [68.54069519, 23.38180351], [68.54152679, 23.38181114], [68.54152679, 23.38153076], [68.54207611, 23.38153076], [68.54207611, 23.38125992], [68.5423584, 23.38125992], [68.5423584, 23.38097], [68.54291534, 23.38097382], [68.54291534, 23.3801384], [68.54264069, 23.3801403], [68.54264069, 23.37985992], [68.5423584, 23.37986374], [68.5423584, 23.37958145], [68.54208374, 23.37958145], [68.54208374, 23.37930489], [68.54125214, 23.37930489], [68.54125214, 23.37958145], [68.54069519, 23.37958145], [68.54069519, 23.37986374], [68.54013824, 23.37985992], [68.54013824, 23.3801403], [68.5395813, 23.3801403], [68.5395813, 23.38042068], [68.53848267, 23.38042068], [68.53848267, 23.38070107], [68.53791809, 23.38069534], [68.53791809, 23.38097382], [68.53708649, 23.38097382], [68.53708649, 23.38069534], [68.53736115, 23.38070107], [68.53736115, 23.38042068], [68.5376358, 23.38042068], [68.5376358, 23.3801403], [68.53708649, 23.3801403], [68.53708649, 23.38042068], [68.53652954, 23.38042068], [68.53652954, 23.38070107], [68.53617859, 23.38069725], [68.53542328, 23.38070107], [68.53542328, 23.38125992], [68.53624725, 23.38125992], [68.53624725, 23.38153076], [68.53598022, 23.38153076], [68.53598022, 23.38181114], [68.53569794, 23.38180351], [68.53569794, 23.3820858], [68.53541565, 23.3820858], [68.53542328, 23.38236046], [68.53514099, 23.38236046], [68.53514099, 23.38264084], [68.5348587, 23.38263893], [68.5348587, 23.38319588], [68.53457642, 23.38319016], [68.53457642, 23.38402939], [68.5348587, 23.38402939], [68.5348587, 23.38513947], [68.53514099, 23.38513947], [68.53514099, 23.38541985], [68.53624725, 23.38541985]]], [[[68.47097015, 23.40570068], [68.47097015, 23.40542984], [68.4723587, 23.40542984], [68.4723587, 23.40485954], [68.47208405, 23.40486145], [68.47208405, 23.40458107], [68.47125244, 23.40458107], [68.47125244, 23.40430641], [68.47206879, 23.40430641], [68.47292328, 23.40431023], [68.47292328, 23.40403175], [68.47402954, 23.40403175], [68.47402954, 23.40374947], [68.47486115, 23.40374947], [68.47486115, 23.40403175], [68.47570038, 23.40403175], [68.47570038, 23.40346909], [68.47597504, 23.4034729], [68.47597504, 23.40291595], [68.47402954, 23.40291595], [68.47402954, 23.40319443], [68.47291565, 23.40319443], [68.47291565, 23.4034729], [68.4723587, 23.40346909], [68.4723587, 23.40374947], [68.47180176, 23.40374947], [68.47180176, 23.40395164], [68.47180176, 23.40402794], [68.47097015, 23.40403175], [68.47097015, 23.40431023], [68.47041321, 23.40430641], [68.47041321, 23.40458107], [68.46985626, 23.40458107], [68.46985626, 23.40514183], [68.46956635, 23.40514183], [68.46956635, 23.40570068], [68.47097015, 23.40570068]]], [[[68.55680847, 23.37181091], [68.55708313, 23.37181091], [68.55708313, 23.37264061], [68.55735779, 23.3726387], [68.55735779, 23.37319374], [68.55764008, 23.37319374], [68.55764008, 23.37347221], [68.55819702, 23.37347031], [68.55819702, 23.37375069], [68.55874634, 23.37375069], [68.55874634, 23.37402916], [68.55930328, 23.37402916], [68.55930328, 23.37431145], [68.55958557, 23.37430573], [68.55958557, 23.3745842], [68.56014252, 23.37458038], [68.56014252, 23.37486076], [68.56069183, 23.37486076], [68.56069183, 23.37542152], [68.56041718, 23.3754158], [68.56041718, 23.37569427], [68.56014252, 23.37569427], [68.56014252, 23.37597275], [68.5595932, 23.37597084], [68.5595932, 23.37624931], [68.55652618, 23.37624931], [68.55652618, 23.3765316], [68.55625153, 23.3765316], [68.55625153, 23.37681007], [68.55596924, 23.37680626], [68.55596924, 23.37708282], [68.55513763, 23.37708282], [68.55513763, 23.37680626], [68.55430603, 23.37680626], [68.55430603, 23.37708282], [68.55403137, 23.37708282], [68.55403137, 23.37847137], [68.55430603, 23.37846947], [68.55430603, 23.3801403], [68.55401611, 23.3801403], [68.55401611, 23.38070107], [68.55374908, 23.38069534], [68.55374908, 23.38097382], [68.5534668, 23.38097], [68.5534668, 23.38153076], [68.55319214, 23.38153076], [68.55319214, 23.38181114], [68.55291748, 23.38180351], [68.55291748, 23.3820858], [68.55263519, 23.3820858], [68.55264282, 23.38236046], [68.55236053, 23.38236046], [68.55236053, 23.38430786], [68.55152893, 23.38430023], [68.55152893, 23.38541985], [68.55179596, 23.38541985], [68.55179596, 23.38513947], [68.55263519, 23.38513947], [68.55263519, 23.3856945], [68.55236053, 23.38569069], [68.55236053, 23.38624954], [68.55208588, 23.38624954], [68.55208588, 23.38652992], [68.55124664, 23.38652992], [68.55124664, 23.38624954], [68.55069733, 23.38624954], [68.55069733, 23.38652992], [68.55041504, 23.38652992], [68.55042267, 23.38680077], [68.55014038, 23.38680649], [68.55014038, 23.38736153], [68.54985809, 23.38735962], [68.54985809, 23.38763809], [68.54957581, 23.38763809], [68.54957581, 23.38791847], [68.54930878, 23.38791847], [68.54930878, 23.38902855], [68.54902649, 23.38902855], [68.54902649, 23.39031029], [68.54902649, 23.39069366], [68.54875183, 23.39069176], [68.54875183, 23.39180946], [68.54846954, 23.39180946], [68.54846954, 23.39264107], [68.54792023, 23.39264107], [68.54792023, 23.39291954], [68.54736328, 23.39291954], [68.54736328, 23.39319992], [68.54708099, 23.39319992], [68.54708099, 23.39375114], [68.54680634, 23.39375114], [68.54680634, 23.39431], [68.54569244, 23.39430618], [68.54569244, 23.39458466], [68.54541779, 23.39458084], [68.54541779, 23.39513969], [68.54569244, 23.39513969], [68.54569244, 23.39542007], [68.54652405, 23.39541435], [68.54652405, 23.39624977], [68.54624939, 23.39624977], [68.54624939, 23.39680672], [68.54541779, 23.39680672], [68.54541779, 23.39652824], [68.54514313, 23.39653015], [68.54514313, 23.39596939], [68.54486084, 23.3959713], [68.54486084, 23.39569664], [68.54458618, 23.39569664], [68.54458618, 23.39541435], [68.54319763, 23.39542007], [68.54319763, 23.39513969], [68.54264069, 23.39513969], [68.54264069, 23.39458084], [68.54291534, 23.39458466], [68.54291534, 23.39402771], [68.54319763, 23.39402962], [68.54319763, 23.39347076], [68.54291534, 23.39347458], [68.54291534, 23.39319229], [68.54264069, 23.39319992], [68.54264069, 23.39291954], [68.54207611, 23.39291954], [68.54207611, 23.39264107], [68.5423584, 23.39264107], [68.5423584, 23.39236069], [68.54292297, 23.39236069], [68.54291534, 23.39152718], [68.54319763, 23.3915329], [68.54319763, 23.39069176], [68.54347229, 23.39069366], [68.54347229, 23.39013863], [68.54402924, 23.39014244], [68.54402924, 23.38986015], [68.54430389, 23.38986015], [68.54430389, 23.38930511], [68.54402924, 23.38931274], [68.54402924, 23.38874817], [68.54374695, 23.38874817], [68.54374695, 23.38820076], [68.54291534, 23.38819504], [68.54291534, 23.3884716], [68.5423584, 23.3884697], [68.5423584, 23.38874817], [68.54207611, 23.38874817], [68.54207611, 23.38902855], [68.54180908, 23.38902855], [68.54180908, 23.38958359], [68.54208374, 23.38958359], [68.54208374, 23.38986015], [68.5423584, 23.38986015], [68.5423584, 23.39042282], [68.54264069, 23.39042282], [68.54264069, 23.39125061], [68.5423584, 23.39125061], [68.5423584, 23.39180946], [68.54125214, 23.39180565], [68.54125214, 23.39208221], [68.54096985, 23.39208031], [68.54096985, 23.39236069], [68.54070282, 23.39236069], [68.54070282, 23.39264107], [68.5404129, 23.39264107], [68.5404129, 23.39291954], [68.54013824, 23.39291954], [68.54013824, 23.39319992], [68.5395813, 23.39319229], [68.5395813, 23.39347458], [68.53930664, 23.39347076], [68.53930664, 23.39375114], [68.53985596, 23.39375114], [68.53985596, 23.39402962], [68.5404129, 23.39402962], [68.5404129, 23.39431], [68.5423584, 23.39431], [68.5423584, 23.39486122], [68.54207611, 23.39486122], [68.54207611, 23.39542007], [68.54152679, 23.39541435], [68.54152679, 23.39569664], [68.54125214, 23.39569664], [68.54125214, 23.39680672], [68.5423584, 23.39680672], [68.5423584, 23.39708328], [68.54291534, 23.39708328], [68.54291534, 23.39736176], [68.54429626, 23.39735985], [68.54429626, 23.39792061], [68.54402924, 23.39791679], [68.54402924, 23.39847183], [68.54374695, 23.39846992], [68.54374695, 23.39903069], [68.54347229, 23.39902878], [68.54347229, 23.39958382], [68.5423584, 23.39957809], [68.5423584, 23.39986038], [68.54207611, 23.39986038], [68.54207611, 23.40014076], [68.54180908, 23.40014076], [68.54180908, 23.40041924], [68.54152679, 23.40041733], [68.54152679, 23.40069389], [68.54125214, 23.40068817], [68.54125214, 23.40125084], [68.54035187, 23.40125084], [68.53985596, 23.40125084], [68.53985596, 23.40068817], [68.5395813, 23.40069389], [68.5395813, 23.40013885], [68.53930664, 23.40014076], [68.53930664, 23.39982986], [68.53930664, 23.39958382], [68.53902435, 23.39958382], [68.53902435, 23.39947891], [68.53902435, 23.39875031], [68.53874969, 23.39875031], [68.53874969, 23.39846992], [68.53847504, 23.39847183], [68.53847504, 23.39791679], [68.53874969, 23.39792061], [68.53874969, 23.39680099], [68.53847504, 23.39680672], [68.53847504, 23.39652824], [68.53819275, 23.39653015], [68.53819275, 23.39624023], [68.5376358, 23.39624977], [68.5376358, 23.3959713], [68.53736115, 23.3959713], [68.53736115, 23.39569664], [68.53708649, 23.39569664], [68.53708649, 23.39541435], [68.53652954, 23.39542007], [68.53652954, 23.39513969], [68.53624725, 23.39513969], [68.53624725, 23.39486122], [68.5359726, 23.39486122], [68.5359726, 23.39458466], [68.5348587, 23.39458466], [68.5348587, 23.39430618], [68.53430939, 23.39431], [68.53430176, 23.39402962], [68.5340271, 23.39402962], [68.5340271, 23.39375114], [68.53347015, 23.39375114], [68.53347015, 23.39319992], [68.53291321, 23.39319992], [68.53291321, 23.39264107], [68.53263855, 23.39264107], [68.53263855, 23.39208031], [68.53291321, 23.39208221], [68.53291321, 23.39180565], [68.53320312, 23.39180946], [68.53320312, 23.3915329], [68.53347015, 23.3915329], [68.53347015, 23.39125061], [68.5340271, 23.39125061], [68.5340271, 23.39097023], [68.53430176, 23.39097023], [68.53430176, 23.39069366], [68.5340271, 23.39069366], [68.5340271, 23.39013863], [68.53375244, 23.39014244], [68.53375244, 23.38986015], [68.53347015, 23.38986015], [68.53347015, 23.38958168], [68.5331955, 23.38958359], [68.5331955, 23.38986015], [68.53291321, 23.38986015], [68.53291321, 23.39014244], [68.53263855, 23.39013863], [68.53263855, 23.39097023], [68.5293045, 23.39097023], [68.5293045, 23.39069366], [68.52819824, 23.39069176], [68.52819061, 23.39180946], [68.52791595, 23.39180946], [68.52791595, 23.39236069], [68.52819061, 23.39236069], [68.52819824, 23.39291954], [68.52902985, 23.39291954], [68.52902985, 23.39319992], [68.52874756, 23.39319229], [68.52874756, 23.39347458], [68.52902985, 23.39347076], [68.52902985, 23.39402962], [68.52929688, 23.39402962], [68.52929688, 23.39431], [68.52984619, 23.39431], [68.52984619, 23.39402962], [68.53125, 23.39402962], [68.53125, 23.39431], [68.53152466, 23.39430618], [68.53152466, 23.39458466], [68.53180695, 23.39458084], [68.53180695, 23.39486122], [68.5320816, 23.39486122], [68.5320816, 23.39458084], [68.53263855, 23.39458084], [68.53263855, 23.39486122], [68.53291321, 23.39486122], [68.53291321, 23.39513969], [68.53320312, 23.39513969], [68.53320312, 23.39542007], [68.53430176, 23.39541435], [68.53430176, 23.39569664], [68.5348587, 23.39569664], [68.5348587, 23.3959713], [68.53514099, 23.3959713], [68.53514099, 23.39624977], [68.53542328, 23.39624023], [68.53542328, 23.39653015], [68.53569794, 23.39652824], [68.53569794, 23.39680672], [68.5359726, 23.39680672], [68.53598022, 23.39723969], [68.53598022, 23.39764023], [68.53569794, 23.39763832], [68.53569794, 23.39847183], [68.53541565, 23.39847183], [68.53542328, 23.39986038], [68.53514099, 23.39986038], [68.53514099, 23.40069389], [68.53542328, 23.40068817], [68.53542328, 23.40152931], [68.53569794, 23.40152931], [68.53569794, 23.40125084], [68.53598022, 23.40125084], [68.5359726, 23.40069389], [68.53652954, 23.40069389], [68.53652954, 23.40041733], [68.53708649, 23.40041924], [68.53708649, 23.40014076], [68.53736115, 23.40014076], [68.53736115, 23.39986038], [68.5376358, 23.39986038], [68.5376358, 23.39957809], [68.53819275, 23.39957809], [68.53819275, 23.40014076], [68.53848267, 23.40014076], [68.53848267, 23.40041924], [68.53874969, 23.40041733], [68.53874969, 23.40097237], [68.53901672, 23.40097046], [68.53901672, 23.40125084], [68.53930664, 23.40125084], [68.53930664, 23.40208244], [68.5395813, 23.40208054], [68.5395813, 23.40292168], [68.53902435, 23.40291595], [68.53902435, 23.40319443], [68.53930664, 23.40319443], [68.53930664, 23.4034729], [68.53791809, 23.40346909], [68.53791809, 23.40374947], [68.5376358, 23.40374947], [68.5376358, 23.40403175], [68.53708649, 23.40402794], [68.53708649, 23.40486145], [68.53736115, 23.40486145], [68.53736115, 23.40458107], [68.54165649, 23.40458107], [68.54208374, 23.40458107], [68.54208374, 23.40430641], [68.54264069, 23.40431023], [68.54264069, 23.40403175], [68.54292297, 23.40403175], [68.54292297, 23.40374947], [68.54347229, 23.40374947], [68.54347229, 23.40346909], [68.54374695, 23.4034729], [68.54374695, 23.40319443], [68.54430389, 23.40319443], [68.54430389, 23.40291595], [68.54485321, 23.40292168], [68.54485321, 23.40263939], [68.54541779, 23.40263939], [68.54541779, 23.40236092], [68.54569244, 23.40236092], [68.54569244, 23.40208054], [68.54624939, 23.40208244], [68.54624939, 23.40180588], [68.54680634, 23.4018116], [68.54680634, 23.40152931], [68.54736328, 23.40152931], [68.54736328, 23.40125084], [68.54792023, 23.40125084], [68.54792023, 23.40097046], [68.54894257, 23.40097237], [68.54902649, 23.40097237], [68.54902649, 23.40152931], [68.54930878, 23.40152931], [68.54930878, 23.4018116], [68.54958344, 23.40180588], [68.54958344, 23.40208244], [68.55041504, 23.40208244], [68.55041504, 23.40236092], [68.55069733, 23.40236092], [68.55069733, 23.40208054], [68.55097198, 23.40208244], [68.55097198, 23.40180588], [68.55124664, 23.4018116], [68.55124664, 23.40068817], [68.55097198, 23.40069389], [68.55097198, 23.40041733], [68.55042267, 23.40041924], [68.55042267, 23.40014076], [68.54985809, 23.40014076], [68.54985809, 23.39986038], [68.55014038, 23.39986038], [68.55014038, 23.39957809], [68.55041504, 23.39958382], [68.55041504, 23.39930534], [68.55069733, 23.39930534], [68.55069733, 23.39902878], [68.55180359, 23.39902878], [68.55180359, 23.39930534], [68.55236053, 23.39930534], [68.55236053, 23.39958382], [68.55291748, 23.39958382], [68.55291748, 23.39930534], [68.55374908, 23.39930534], [68.55374908, 23.39902878], [68.55401611, 23.39903069], [68.55401611, 23.39820099], [68.55430603, 23.39820099], [68.55430603, 23.39764023], [68.55458069, 23.39764023], [68.55458069, 23.39707947], [68.55486298, 23.39708328], [68.55486298, 23.3959713], [68.55458069, 23.3959713], [68.55458069, 23.39486122], [68.55430603, 23.39486122], [68.55430603, 23.39431], [68.55401611, 23.39431], [68.55401611, 23.39402962], [68.55374908, 23.39402962], [68.55374908, 23.39375114], [68.5534668, 23.39375114], [68.5534668, 23.39319992], [68.55319214, 23.39319992], [68.55319214, 23.39266968], [68.55319214, 23.39152718], [68.5534668, 23.3915329], [68.5534668, 23.39097023], [68.55374908, 23.39097023], [68.55374908, 23.3904171], [68.55401611, 23.39042282], [68.55401611, 23.38986015], [68.55430603, 23.38986015], [68.55430603, 23.38930511], [68.55452728, 23.38930702], [68.55486298, 23.38931274], [68.55486298, 23.38902855], [68.55568695, 23.38902855], [68.55568695, 23.38874817], [68.55596924, 23.38874817], [68.55596924, 23.38820076], [68.55625153, 23.38820076], [68.55625153, 23.38763809], [68.55652618, 23.38763809], [68.55652618, 23.3870697], [68.55680847, 23.38708305], [68.55680847, 23.38652992], [68.55708313, 23.38652992], [68.55708313, 23.38624954], [68.55735779, 23.38624954], [68.55735779, 23.38569069], [68.55764008, 23.3856945], [68.55764008, 23.38513947], [68.5579071, 23.38513947], [68.5579071, 23.38486099], [68.55819702, 23.38486099], [68.55819702, 23.38430023], [68.55847168, 23.38430786], [68.55847168, 23.38375092], [68.55874634, 23.38375092], [68.55874634, 23.38347054], [68.55902863, 23.38347244], [68.55902863, 23.3829174], [68.55930328, 23.38292122], [68.55930328, 23.38181114], [68.55902863, 23.38181114], [68.55902863, 23.38153076], [68.55819702, 23.38153076], [68.55819702, 23.38125992], [68.55735779, 23.38125992], [68.55735779, 23.38153076], [68.55708313, 23.38152695], [68.55708313, 23.3820858], [68.55680847, 23.38208008], [68.55680847, 23.38236046], [68.55652618, 23.38236046], [68.55652618, 23.38264084], [68.55541992, 23.38264084], [68.55541992, 23.38292122], [68.55486298, 23.3829174], [68.55486298, 23.38319588], [68.55403137, 23.38319588], [68.55403137, 23.3829174], [68.55430603, 23.38292122], [68.55430603, 23.38236046], [68.55458069, 23.38236046], [68.55458069, 23.38181114], [68.55486298, 23.38181114], [68.55486298, 23.38153076], [68.55513763, 23.38153076], [68.55513763, 23.38097], [68.55541992, 23.38097382], [68.55541992, 23.38069534], [68.55568695, 23.38070107], [68.55568695, 23.3801403], [68.55596924, 23.3801403], [68.55596924, 23.37957954], [68.55625153, 23.37958145], [68.55625153, 23.37902832], [68.55652618, 23.37903023], [68.55652618, 23.37874985], [68.5579071, 23.37874985], [68.5579071, 23.37846947], [68.55902863, 23.37847137], [68.55902863, 23.37819481], [68.56014252, 23.37820053], [68.56014252, 23.37792015], [68.56181335, 23.37792015], [68.56181335, 23.37763977], [68.56319427, 23.37763977], [68.56318665, 23.37735939], [68.56375122, 23.3773613], [68.56375122, 23.37708282], [68.56458282, 23.37708282], [68.56458282, 23.37680626], [68.56513977, 23.37681007], [68.56513977, 23.3765316], [68.56680298, 23.3765316], [68.56680298, 23.37624931], [68.5670929, 23.37624931], [68.5670929, 23.37597084], [68.56735992, 23.37597275], [68.56735992, 23.37513924], [68.56708527, 23.37513924], [68.56708527, 23.37486076], [68.56680298, 23.37486076], [68.56680298, 23.37458038], [68.56625366, 23.3745842], [68.56625366, 23.37430573], [68.56595612, 23.37431145], [68.56595612, 23.37402916], [68.56569672, 23.37402916], [68.56569672, 23.37375069], [68.5654068, 23.37375069], [68.5654068, 23.37318993], [68.56513977, 23.37319374], [68.56513977, 23.3726387], [68.56402588, 23.37264061], [68.56402588, 23.37236023], [68.56375122, 23.37236023], [68.56375122, 23.37181091], [68.56346893, 23.37181091], [68.56346893, 23.37153053], [68.56318665, 23.37153053], [68.56318665, 23.37125015], [68.56291962, 23.37125015], [68.56291962, 23.37096977], [68.56263733, 23.37097168], [68.56263733, 23.37069511], [68.56236267, 23.37070084], [68.56236267, 23.37042046], [68.56208038, 23.37042046], [68.56208038, 23.3698597], [68.56180573, 23.3698616], [68.56180573, 23.36958313], [68.56153107, 23.36958313], [68.56153107, 23.36902809], [68.56124878, 23.36903], [68.56124878, 23.36847115], [68.56097412, 23.36847305], [68.56097412, 23.36819267], [68.56069183, 23.36819267], [68.56069183, 23.36763954], [68.56041718, 23.36763954], [68.56041718, 23.36736107], [68.56014252, 23.36736107], [68.56014252, 23.36680984], [68.55986023, 23.36680984], [68.55986023, 23.36626053], [68.5595932, 23.36626053], [68.5595932, 23.36569023], [68.55930328, 23.36569214], [68.55930328, 23.36486053], [68.55902863, 23.36486053], [68.55902863, 23.36347008], [68.55874634, 23.36347008], [68.55874634, 23.36263847], [68.55847168, 23.36264038], [68.55847168, 23.36235809], [68.55791473, 23.36236191], [68.55791473, 23.36208344], [68.55764008, 23.36208344], [68.55764008, 23.36180496], [68.55735779, 23.36181068], [68.55735779, 23.3615284], [68.55680847, 23.3615284], [68.55680847, 23.36124992], [68.55652618, 23.36124992], [68.55652618, 23.36096954], [68.55625153, 23.36097145], [68.55625153, 23.36069489], [68.55569458, 23.36069489], [68.55569458, 23.36041641], [68.55430603, 23.36041832], [68.55430603, 23.36013031], [68.55319214, 23.36013031], [68.55319214, 23.36041832], [68.55291748, 23.36041641], [68.55291748, 23.36069489], [68.55264282, 23.36069107], [68.55264282, 23.3615284], [68.55291748, 23.3615284], [68.55291748, 23.36181068], [68.55347443, 23.36180496], [68.55347443, 23.36208344], [68.55374908, 23.36208344], [68.55374908, 23.36236191], [68.55319214, 23.36236191], [68.55319214, 23.36319351], [68.55291748, 23.3631916], [68.55291748, 23.36652946], [68.55208588, 23.36652946], [68.55208588, 23.36458015], [68.55179596, 23.36458015], [68.55179596, 23.36486053], [68.55152893, 23.36486053], [68.55152893, 23.36514282], [68.55124664, 23.36513901], [68.55124664, 23.36569214], [68.55014038, 23.36569214], [68.55014038, 23.36597443], [68.54957581, 23.36597061], [68.54957581, 23.36626053], [68.54985809, 23.36624908], [68.54985809, 23.3670845], [68.55069733, 23.36708069], [68.55069733, 23.37014008], [68.55042267, 23.37014008], [68.55042267, 23.37070084], [68.55014038, 23.37070084], [68.55014038, 23.37125015], [68.55042267, 23.37125015], [68.55042267, 23.37153053], [68.55069733, 23.37153053], [68.55069733, 23.37125015], [68.55152893, 23.37125015], [68.55152893, 23.37096977], [68.55180359, 23.37097168], [68.55180359, 23.37069511], [68.55236053, 23.37070084], [68.55236053, 23.37042046], [68.55264282, 23.37042046], [68.55264282, 23.37014008], [68.55319214, 23.37014008], [68.55319214, 23.3698597], [68.55347443, 23.3698616], [68.55347443, 23.36958313], [68.55403137, 23.36958313], [68.55403137, 23.36930656], [68.55430603, 23.36930656], [68.55430603, 23.36902809], [68.55513763, 23.36902809], [68.55513763, 23.36930656], [68.55541992, 23.36930656], [68.55541992, 23.36958313], [68.55596924, 23.36958313], [68.55596924, 23.3698616], [68.55652618, 23.3698597], [68.55652618, 23.37070084], [68.55680847, 23.37070084], [68.55680847, 23.37181091]]], [[[68.52347565, 23.40458107], [68.52347565, 23.40402794], [68.52458191, 23.40403175], [68.52458191, 23.40346909], [68.52430725, 23.4034729], [68.52430725, 23.40319443], [68.52402496, 23.40319443], [68.52402496, 23.40236092], [68.52375031, 23.40236092], [68.52375031, 23.40097046], [68.52402496, 23.40097237], [68.52402496, 23.40069389], [68.52541351, 23.40069389], [68.52541351, 23.40013885], [68.5256958, 23.40014076], [68.5256958, 23.39929962], [68.52513885, 23.39930534], [68.52513885, 23.39958382], [68.52430725, 23.39958382], [68.52430725, 23.39902878], [68.52458191, 23.39903069], [68.52458191, 23.39875031], [68.52597046, 23.39875031], [68.52597046, 23.39903069], [68.52735901, 23.39903069], [68.52735901, 23.39792061], [68.5265274, 23.39792061], [68.5265274, 23.39764023], [68.52625275, 23.39764023], [68.52625275, 23.39735985], [68.5265274, 23.39736176], [68.5265274, 23.39708328], [68.52680206, 23.39708328], [68.52680206, 23.39680672], [68.52708435, 23.39680672], [68.52708435, 23.39624977], [68.5265274, 23.39624023], [68.5265274, 23.39653015], [68.52625275, 23.39652824], [68.52625275, 23.39680672], [68.52597046, 23.39680672], [68.52597046, 23.39708328], [68.52513885, 23.39708328], [68.52513885, 23.39612007], [68.52513885, 23.39541435], [68.52540588, 23.39542007], [68.52540588, 23.39486122], [68.5256958, 23.39486122], [68.5256958, 23.39458084], [68.52597046, 23.39458466], [68.52597046, 23.39402771], [68.5256958, 23.39402962], [68.5256958, 23.39319992], [68.52597046, 23.39319992], [68.52597046, 23.39264107], [68.52625275, 23.39264107], [68.52625275, 23.39236069], [68.5265274, 23.39236069], [68.5265274, 23.39208031], [68.52708435, 23.39208221], [68.52708435, 23.39069366], [68.52735901, 23.39069366], [68.52735901, 23.38986015], [68.52708435, 23.38986015], [68.52707672, 23.38820076], [68.52735901, 23.38820076], [68.52735901, 23.38791847], [68.5276413, 23.38791847], [68.5276413, 23.38763809], [68.52791595, 23.38763809], [68.52791595, 23.3868084], [68.52735901, 23.38680077], [68.52735901, 23.38624954], [68.52680969, 23.38624954], [68.52680969, 23.38652992], [68.52625275, 23.38652992], [68.52625275, 23.38680077], [68.52597046, 23.38680649], [68.52597046, 23.38736153], [68.52540588, 23.38735962], [68.52540588, 23.38763809], [68.52513885, 23.38763809], [68.52513885, 23.38791847], [68.52458191, 23.38791847], [68.52458191, 23.38820076], [68.52430725, 23.38819504], [68.52430725, 23.3884716], [68.52402496, 23.3884716], [68.52404022, 23.38874817], [68.52375031, 23.38874817], [68.52375031, 23.38931274], [68.52347565, 23.38930511], [68.52347565, 23.38958359], [68.52319336, 23.38958168], [68.52319336, 23.39014244], [68.5229187, 23.39014244], [68.5229187, 23.39042282], [68.52263641, 23.3904171], [68.52263641, 23.39097023], [68.52236176, 23.39097023], [68.52236176, 23.39125061], [68.5220871, 23.39125061], [68.5220871, 23.39180946], [68.52180481, 23.39180565], [68.52180481, 23.39208221], [68.52153015, 23.39208031], [68.52153015, 23.39264107], [68.52124786, 23.39264107], [68.52124786, 23.39291954], [68.52097321, 23.39291573], [68.52097321, 23.39347458], [68.52068329, 23.39347076], [68.52068329, 23.39402962], [68.52041626, 23.39402962], [68.52041626, 23.39542007], [68.5201416, 23.39541435], [68.5201416, 23.39882088], [68.5201416, 23.39930534], [68.52041626, 23.39929962], [68.52041626, 23.40041924], [68.52069092, 23.40041733], [68.52069092, 23.40097237], [68.52097321, 23.40097046], [68.52097321, 23.40125084], [68.52124786, 23.40125084], [68.52124786, 23.40152931], [68.52153015, 23.40152931], [68.52153015, 23.4018116], [68.5220871, 23.40180588], [68.5220871, 23.40208244], [68.52236176, 23.40208054], [68.52236176, 23.40236092], [68.5229187, 23.40236092], [68.5229187, 23.40319443], [68.52263641, 23.40319061], [68.52263641, 23.40374947], [68.5229187, 23.40374947], [68.5229187, 23.40458107], [68.52319336, 23.40458107], [68.52319336, 23.40514183], [68.52375031, 23.40514183], [68.52375031, 23.40458107], [68.52347565, 23.40458107]]], [[[68.55401611, 23.40403175], [68.55401611, 23.40374947], [68.55652618, 23.40374947], [68.55652618, 23.40319061], [68.55680847, 23.40319443], [68.55680847, 23.40263939], [68.55430603, 23.40263939], [68.55430603, 23.40236092], [68.55401611, 23.40236092], [68.55401611, 23.40208054], [68.55291748, 23.40208054], [68.55291748, 23.40236092], [68.55263519, 23.40236092], [68.55263519, 23.4034729], [68.55291748, 23.40346909], [68.55291748, 23.40403175], [68.55401611, 23.40403175]]], [[[68.55764008, 23.40875053], [68.55764008, 23.40818024], [68.55735779, 23.4081955], [68.55735779, 23.40763855], [68.55708313, 23.40764046], [68.55708313, 23.4070797], [68.55680847, 23.40708542], [68.55680847, 23.40680313], [68.55652618, 23.40681076], [68.55652618, 23.40653038], [68.55625153, 23.40653038], [68.55625153, 23.40625], [68.55596924, 23.40625], [68.55596924, 23.40570068], [68.55568695, 23.40570068], [68.55568695, 23.40542984], [68.55541992, 23.40542984], [68.55541992, 23.40514183], [68.55401611, 23.40514183], [68.55401611, 23.40485954], [68.55374908, 23.40486145], [68.55374908, 23.40458107], [68.55319214, 23.40458107], [68.55319214, 23.40430641], [68.55124664, 23.40430641], [68.55124664, 23.40486145], [68.55152893, 23.40485954], [68.55152893, 23.40514183], [68.55236053, 23.40514183], [68.55236053, 23.40542984], [68.55291748, 23.40542984], [68.55291748, 23.40570068], [68.55319214, 23.40569305], [68.55319214, 23.40597153], [68.5534668, 23.40596962], [68.5534668, 23.40625], [68.55374908, 23.40625], [68.55374908, 23.40596962], [68.55458069, 23.40596962], [68.55458069, 23.40653038], [68.55513763, 23.40653038], [68.55513763, 23.40681076], [68.55541992, 23.40680313], [68.55541992, 23.40708542], [68.55596924, 23.40708542], [68.55596924, 23.40736389], [68.55625153, 23.40736008], [68.55625153, 23.40764046], [68.55652618, 23.40763855], [68.55652618, 23.4081955], [68.55680847, 23.4081955], [68.55680847, 23.40847206], [68.55708313, 23.40847015], [68.55708313, 23.40875053], [68.55735779, 23.40875053], [68.55735779, 23.40930939], [68.5579071, 23.40930939], [68.5579071, 23.40875053], [68.55764008, 23.40875053]]], [[[68.54957581, 23.41374969], [68.54957581, 23.41319084], [68.54930878, 23.41319466], [68.54930878, 23.41291618], [68.54902649, 23.41291809], [68.54902649, 23.41236115], [68.54875183, 23.41236115], [68.54875183, 23.41208076], [68.54846954, 23.41208267], [68.54846954, 23.41152763], [68.54818726, 23.41152954], [68.54818726, 23.41097069], [68.54792023, 23.4109726], [68.54792023, 23.41041756], [68.54780579, 23.41041756], [68.54763794, 23.41041946], [68.54763794, 23.41014099], [68.54736328, 23.41014099], [68.54736328, 23.40986061], [68.54680634, 23.40986061], [68.54680634, 23.40958595], [68.54652405, 23.40958595], [68.54652405, 23.40930557], [68.54624939, 23.40930939], [68.54624939, 23.40903091], [68.5459671, 23.40903091], [68.5459671, 23.40875053], [68.54541779, 23.40875053], [68.54541779, 23.40847015], [68.5451355, 23.40847206], [68.5451355, 23.4081955], [68.54486084, 23.4081955], [68.54486084, 23.40791702], [68.54458618, 23.40792084], [68.54458618, 23.40764046], [68.54429626, 23.40764046], [68.54429626, 23.40736008], [68.54402924, 23.40736389], [68.54402924, 23.40708542], [68.54374695, 23.40708542], [68.54374695, 23.40680313], [68.54347229, 23.40681076], [68.54347229, 23.40653038], [68.54319763, 23.40653038], [68.54319763, 23.40625], [68.54291534, 23.40625], [68.54291534, 23.40597153], [68.54264069, 23.40597153], [68.54264069, 23.40569305], [68.5423584, 23.40570068], [68.5423584, 23.40542984], [68.54199219, 23.40542984], [68.54152679, 23.40542984], [68.54152679, 23.40625], [68.54180908, 23.40625], [68.54180908, 23.40653038], [68.54207611, 23.40653038], [68.54207611, 23.40681076], [68.5423584, 23.40680313], [68.5423584, 23.40708542], [68.54264069, 23.40708542], [68.54264069, 23.40736389], [68.54292297, 23.40736008], [68.54292297, 23.40764046], [68.54319763, 23.40764046], [68.54319763, 23.40792084], [68.54347229, 23.40791702], [68.54347229, 23.4081955], [68.54374695, 23.4081955], [68.54374695, 23.40847206], [68.54402924, 23.40847015], [68.54402924, 23.40875053], [68.54429626, 23.40875053], [68.54429626, 23.40903091], [68.54458618, 23.40903091], [68.54458618, 23.40930939], [68.54486084, 23.40930557], [68.54486084, 23.40958595], [68.5451355, 23.40958595], [68.5451355, 23.40986061], [68.54569244, 23.40986061], [68.54569244, 23.41014099], [68.5459671, 23.41014099], [68.5459671, 23.41041946], [68.54652405, 23.41041756], [68.54652405, 23.41069412], [68.54680634, 23.41069412], [68.54680634, 23.4109726], [68.54708099, 23.41097069], [68.54708099, 23.41152954], [68.54736328, 23.41152763], [68.54736328, 23.41208267], [68.54763794, 23.41208076], [68.54763794, 23.41263962], [68.54792023, 23.41263962], [68.54792023, 23.41291809], [68.54819489, 23.41291618], [68.54819489, 23.41319466], [68.54875183, 23.41319466], [68.54875183, 23.41347313], [68.54902649, 23.41347122], [68.54902649, 23.41374969], [68.54930878, 23.41374969], [68.54930878, 23.41430473], [68.54958344, 23.41430473], [68.54958344, 23.41486168], [68.54985809, 23.41486168], [68.54985809, 23.41374969], [68.54957581, 23.41374969]]], [[[68.50125122, 23.45347977], [68.50125122, 23.45292091], [68.50152588, 23.45292091], [68.50152588, 23.45236015], [68.50180817, 23.45236206], [68.50180817, 23.45125008], [68.50208282, 23.45125008], [68.50208282, 23.45014], [68.50235748, 23.45014], [68.50235748, 23.44958115], [68.50152588, 23.44958305], [68.50152588, 23.44902802], [68.50125122, 23.44902992], [68.50125122, 23.44847107], [68.50096893, 23.44847488], [68.50096893, 23.44763947], [68.50068665, 23.44763947], [68.50068665, 23.44652939], [68.50041962, 23.44652939], [68.50041962, 23.44569016], [68.50013733, 23.44569206], [68.50013733, 23.44513893], [68.4998703, 23.44514275], [68.4998703, 23.44458008], [68.49903107, 23.44458389], [68.49903107, 23.44402695], [68.49819183, 23.44403267], [68.49819183, 23.44431114], [68.4970932, 23.44431114], [68.4970932, 23.44403267], [68.49680328, 23.44402695], [68.49680328, 23.44569206], [68.4970932, 23.44569016], [68.4970932, 23.44652939], [68.49569702, 23.44652939], [68.49569702, 23.44763947], [68.49597168, 23.44763947], [68.49597168, 23.44847488], [68.49624634, 23.44847107], [68.49624634, 23.44874954], [68.49652863, 23.44874954], [68.49652863, 23.44902992], [68.49680328, 23.44902802], [68.49680328, 23.44958305], [68.4970932, 23.44958115], [68.4970932, 23.45014], [68.49764252, 23.45013809], [68.49764252, 23.45041656], [68.49819183, 23.45041084], [68.49819183, 23.45070076], [68.49874878, 23.45069695], [68.49874878, 23.4509716], [68.49930573, 23.4509716], [68.49930573, 23.45125008], [68.4998703, 23.45125008], [68.4998703, 23.45153046], [68.50013733, 23.45153046], [68.50013733, 23.45181084], [68.50069427, 23.45180511], [68.50069427, 23.45208359], [68.50096893, 23.45207977], [68.50096893, 23.45264053], [68.50068665, 23.45264053], [68.50068665, 23.45292091], [68.50096893, 23.45292091], [68.50096893, 23.45347977], [68.50125122, 23.45347977]]], [[[68.46652985, 23.4979229], [68.46652985, 23.49764252], [68.46708679, 23.49764252], [68.46708679, 23.49736023], [68.4679184, 23.49736023], [68.4679184, 23.49708176], [68.46847534, 23.49708366], [68.46847534, 23.49680519], [68.46930695, 23.49681282], [68.46930695, 23.49653244], [68.46956635, 23.49653244], [68.46956635, 23.49596977], [68.47013855, 23.49597168], [68.47013855, 23.49319458], [68.4706955, 23.49319458], [68.4706955, 23.49347305], [68.47097015, 23.49347115], [68.47097015, 23.49402809], [68.47125244, 23.49402809], [68.47125244, 23.49374962], [68.4715271, 23.49374962], [68.4715271, 23.49319077], [68.47180176, 23.49319458], [68.47180939, 23.49291611], [68.47207642, 23.49291992], [68.47207642, 23.49236107], [68.47180939, 23.49236107], [68.47180176, 23.49208069], [68.4715271, 23.4920826], [68.4715271, 23.49180794], [68.47264099, 23.49180984], [68.47264099, 23.49097061], [68.47291565, 23.49097252], [68.47291565, 23.48708534], [68.47264099, 23.48708534], [68.47264099, 23.48569489], [68.4723587, 23.48569489], [68.4723587, 23.48486137], [68.47180176, 23.48485947], [68.47180176, 23.48542023], [68.4715271, 23.48541641], [68.4715271, 23.48597145], [68.4706955, 23.48597145], [68.4706955, 23.48541641], [68.47041321, 23.48542023], [68.47041321, 23.48485947], [68.47013855, 23.48486137], [68.47013855, 23.48430634], [68.46985626, 23.48431015], [68.46985626, 23.48374939], [68.47013855, 23.48374939], [68.47013855, 23.48319054], [68.47041321, 23.48319435], [68.47041321, 23.48236084], [68.47070313, 23.48236084], [68.4706955, 23.48152733], [68.47097015, 23.48152924], [68.47097015, 23.48097038], [68.47125244, 23.48097229], [68.47125244, 23.48041725], [68.47097015, 23.48041916], [68.47097015, 23.48014069], [68.47070313, 23.48014069], [68.47070313, 23.47986031], [68.47041321, 23.47986031], [68.47041321, 23.47957993], [68.47013855, 23.47958374], [68.47013855, 23.47930527], [68.46956635, 23.47930908], [68.46956635, 23.47903061], [68.46848297, 23.47903061], [68.46848297, 23.47930908], [68.46819305, 23.47930527], [68.46819305, 23.47958374], [68.4679184, 23.47957993], [68.4679184, 23.47986031], [68.46736145, 23.47986031], [68.46736145, 23.48014069], [68.46679688, 23.48014069], [68.46679688, 23.48041916], [68.46376038, 23.48041916], [68.46376038, 23.47986031], [68.46347046, 23.47986031], [68.46347046, 23.48014069], [68.46235657, 23.48014069], [68.46235657, 23.47957993], [68.4595871, 23.47958374], [68.4595871, 23.47984123], [68.45929718, 23.47986031], [68.45929718, 23.48152924], [68.4595871, 23.48152924], [68.4595871, 23.48181152], [68.45986176, 23.4818058], [68.45986176, 23.48208237], [68.45929718, 23.48208046], [68.45929718, 23.48236084], [68.45903015, 23.48236084], [68.45903015, 23.48319435], [68.45929718, 23.48319054], [68.45929718, 23.48431015], [68.45903015, 23.48430634], [68.45903015, 23.4845829], [68.45874786, 23.4845829], [68.45874786, 23.48736382], [68.45903015, 23.48736], [68.45903015, 23.48792076], [68.45986176, 23.48792076], [68.45986176, 23.48764038], [68.4604187, 23.48763847], [68.4604187, 23.48847389], [68.46070099, 23.48847008], [68.46070099, 23.48931122], [68.46097565, 23.48930359], [68.46097565, 23.48986053], [68.46125031, 23.48986053], [68.46125031, 23.49041939], [68.46208191, 23.49041939], [68.46208191, 23.49014091], [68.46263885, 23.49014091], [68.46263885, 23.48986053], [68.4631958, 23.48986053], [68.4631958, 23.48958969], [68.46347046, 23.48958969], [68.46347046, 23.48931122], [68.46376038, 23.48931122], [68.46376038, 23.48903084], [68.4640274, 23.48903084], [68.4640274, 23.48875046], [68.46457672, 23.48875046], [68.46457672, 23.48903084], [68.46485901, 23.48903084], [68.46485901, 23.48986053], [68.46457672, 23.48986053], [68.46457672, 23.49014091], [68.46430206, 23.49014091], [68.46430206, 23.49041939], [68.46485901, 23.49041748], [68.46485901, 23.49069595], [68.46541595, 23.49069595], [68.46541595, 23.49097252], [68.46569061, 23.49097061], [68.46569061, 23.49125099], [68.46541595, 23.49125099], [68.46541595, 23.49152946], [68.4651413, 23.49152946], [68.4651413, 23.49180984], [68.46485901, 23.49180794], [68.46485901, 23.4920826], [68.46457672, 23.49208069], [68.46457672, 23.49236107], [68.46430206, 23.49236107], [68.46430206, 23.49264908], [68.4640274, 23.49263954], [68.4640274, 23.49347305], [68.46376038, 23.49347115], [68.46376038, 23.49653244], [68.46430206, 23.49653244], [68.46430206, 23.49625015], [68.46485901, 23.49625015], [68.46485901, 23.49653244], [68.4651413, 23.49653244], [68.4651413, 23.49681282], [68.46541595, 23.49680519], [68.46541595, 23.49708366], [68.46569061, 23.49708176], [68.46569824, 23.49736023], [68.4659729, 23.49736023], [68.4659729, 23.49764252], [68.46569824, 23.49764252], [68.46569824, 23.4979229], [68.46627808, 23.49791908], [68.46652985, 23.4979229]]], [[[68.49903107, 23.47597313], [68.49903107, 23.47541428], [68.49931335, 23.47542], [68.49931335, 23.47402954], [68.49958038, 23.47402954], [68.49958038, 23.47319031], [68.49903107, 23.47319221], [68.49903107, 23.47291756], [68.49819183, 23.47291946], [68.49819183, 23.4726429], [68.49846649, 23.4726429], [68.49846649, 23.46931267], [68.49874878, 23.46931267], [68.49874878, 23.46874809], [68.49903107, 23.46874809], [68.49903107, 23.4679184], [68.49931335, 23.4679184], [68.49931335, 23.46735954], [68.49958038, 23.46736145], [68.49958038, 23.46680641], [68.4998703, 23.46680832], [68.4998703, 23.46652985], [68.50041962, 23.46652985], [68.50041962, 23.46624947], [68.50125122, 23.46624947], [68.50125122, 23.46541977], [68.4998703, 23.46541977], [68.4998703, 23.46486092], [68.49958038, 23.46486092], [68.49958038, 23.46375084], [68.50013733, 23.46375084], [68.50013733, 23.46347046], [68.50125122, 23.46347237], [68.50125122, 23.46291733], [68.50096893, 23.46292114], [68.50096893, 23.46235085], [68.50125122, 23.46236038], [68.50125122, 23.46180344], [68.50152588, 23.46181107], [68.50152588, 23.46125031], [68.50180817, 23.46125031], [68.50180817, 23.46042061], [68.50208282, 23.46042061], [68.50208282, 23.45819283], [68.50235748, 23.45819473], [68.50235748, 23.45763969], [68.50208282, 23.45763969], [68.50208282, 23.45708084], [68.50180817, 23.45708275], [68.50180817, 23.45680618], [68.50152588, 23.4568119], [68.50152588, 23.45624924], [68.50125122, 23.45624924], [68.50125122, 23.45597076], [68.50096893, 23.45597267], [68.50096893, 23.4556942], [68.50069427, 23.4556942], [68.50069427, 23.45541573], [68.50013733, 23.45542145], [68.50013733, 23.45513916], [68.4998703, 23.45513916], [68.4998703, 23.45654106], [68.49958038, 23.45654106], [68.49958038, 23.45792007], [68.49903107, 23.45791626], [68.49903107, 23.45986366], [68.4998703, 23.45985985], [68.4998703, 23.46042061], [68.49931335, 23.46042061], [68.49931335, 23.46070099], [68.49903107, 23.46070099], [68.49903107, 23.46181107], [68.49930573, 23.46180344], [68.49930573, 23.46236038], [68.49846649, 23.46235085], [68.49846649, 23.46292114], [68.49819183, 23.46292114], [68.49819183, 23.46486092], [68.49846649, 23.46486092], [68.49846649, 23.46513939], [68.49874878, 23.46513939], [68.49874878, 23.46541977], [68.49846649, 23.46541977], [68.49846649, 23.46652985], [68.49819183, 23.46652985], [68.49819183, 23.46763992], [68.49791718, 23.46763992], [68.49791718, 23.46874809], [68.49764252, 23.46874809], [68.49764252, 23.46986008], [68.49736023, 23.46986008], [68.49736023, 23.47069359], [68.49708557, 23.47069359], [68.49708557, 23.47097015], [68.49680328, 23.47097015], [68.49680328, 23.47125053], [68.49652863, 23.47125053], [68.49652863, 23.4715271], [68.49624634, 23.4715271], [68.49624634, 23.47208214], [68.49597168, 23.47208023], [68.49597168, 23.47291946], [68.49569702, 23.47291756], [68.49569702, 23.4734745], [68.4954071, 23.47347069], [68.4954071, 23.47402954], [68.49514008, 23.47402954], [68.49514008, 23.47542], [68.49569702, 23.47541428], [68.49569702, 23.47569656], [68.49597168, 23.47569656], [68.49597168, 23.47597313], [68.49903107, 23.47597313]]], [[[68.49846649, 23.48903084], [68.49846649, 23.48847008], [68.49819183, 23.48847389], [68.49819183, 23.48791695], [68.49791718, 23.48792076], [68.49791718, 23.48707962], [68.49764252, 23.48708534], [68.49764252, 23.48624992], [68.49736023, 23.48624992], [68.49736023, 23.48569107], [68.49708557, 23.48569489], [68.49708557, 23.48319435], [68.49736023, 23.48319435], [68.49736023, 23.48152733], [68.49764252, 23.48152924], [68.49764252, 23.47986031], [68.49736023, 23.47986031], [68.49736023, 23.47930908], [68.4970932, 23.47930908], [68.4970932, 23.47875023], [68.49680328, 23.47875023], [68.49680328, 23.47846985], [68.49652863, 23.47847176], [68.49652863, 23.47791672], [68.49624634, 23.47792053], [68.49624634, 23.47764969], [68.49597168, 23.47764969], [68.49597168, 23.47735977], [68.49541473, 23.47736168], [68.49541473, 23.47708321], [68.49514008, 23.47708321], [68.49514008, 23.47680664], [68.49458313, 23.47680664], [68.49458313, 23.47652817], [68.49402618, 23.47653008], [68.49402618, 23.47624969], [68.49346924, 23.47624969], [68.49346924, 23.47597122], [68.49124908, 23.47597313], [68.49124908, 23.47569656], [68.49069214, 23.47569656], [68.49069214, 23.47541428], [68.49041748, 23.47542], [68.49041748, 23.47513962], [68.48986053, 23.47513962], [68.48986053, 23.47486115], [68.48958588, 23.47486115], [68.48958588, 23.47458076], [68.48930359, 23.47458458], [68.48930359, 23.4743042], [68.48874664, 23.47430992], [68.48874664, 23.47402954], [68.48847198, 23.47402954], [68.48847198, 23.47375107], [68.48819733, 23.47375107], [68.48819733, 23.47347069], [68.48707581, 23.47347069], [68.48707581, 23.47430992], [68.48680878, 23.4743042], [68.48680878, 23.47458458], [68.48652649, 23.47458076], [68.48652649, 23.47513962], [68.48625183, 23.47513962], [68.48625183, 23.47542], [68.48596954, 23.47541428], [68.48596954, 23.47569656], [68.48569489, 23.47569656], [68.48569489, 23.47597313], [68.48542023, 23.47597122], [68.48542023, 23.47624969], [68.48513794, 23.47624969], [68.48513794, 23.47653008], [68.48458099, 23.47652817], [68.48458099, 23.47680664], [68.48402405, 23.47680664], [68.48402405, 23.47708321], [68.48374939, 23.47708321], [68.48374939, 23.47736168], [68.48319244, 23.47735977], [68.48319244, 23.47764969], [68.48291779, 23.47764969], [68.48291779, 23.47792053], [68.48208618, 23.47792053], [68.48208618, 23.47820091], [68.48236084, 23.47820091], [68.48236084, 23.47875023], [68.48264313, 23.47875023], [68.48264313, 23.47930908], [68.48291779, 23.47930908], [68.48291779, 23.47986031], [68.48319244, 23.47986031], [68.48319244, 23.48014069], [68.4834671, 23.48014069], [68.4834671, 23.48041916], [68.48374939, 23.48041725], [68.48374939, 23.48069382], [68.48401642, 23.4806881], [68.48401642, 23.48152924], [68.48430634, 23.48152924], [68.48430634, 23.48181152], [68.48458099, 23.4818058], [68.48458099, 23.48208427], [68.48486328, 23.48208046], [68.48486328, 23.48236084], [68.48513794, 23.48236084], [68.48513794, 23.48263931], [68.48542023, 23.48263931], [68.48542023, 23.48319435], [68.48569489, 23.48319435], [68.48569489, 23.48347282], [68.48596954, 23.48345757], [68.48596954, 23.48403168], [68.48625183, 23.48402786], [68.48625183, 23.48431015], [68.48625183, 23.4845829], [68.48652649, 23.4845829], [68.48652649, 23.48486137], [68.48680878, 23.48485947], [68.48680878, 23.48542023], [68.48708344, 23.48541641], [68.48708344, 23.48569489], [68.48791504, 23.48569489], [68.48791504, 23.48597145], [68.48847198, 23.48596954], [68.48847198, 23.48624992], [68.48986053, 23.48624992], [68.48986053, 23.4865284], [68.49124908, 23.48652267], [68.49124908, 23.48681068], [68.49195862, 23.48680878], [68.49514008, 23.48680305], [68.49514008, 23.48708534], [68.49624634, 23.48708534], [68.49624634, 23.48736382], [68.49652863, 23.48736], [68.49652863, 23.48764038], [68.49680328, 23.48764038], [68.49680328, 23.48792076], [68.49708557, 23.48791695], [68.4970932, 23.4881897], [68.49736023, 23.48819542], [68.49736023, 23.48847389], [68.49764252, 23.48847008], [68.49764252, 23.48903084], [68.49791718, 23.48903084], [68.49791718, 23.48931122], [68.49874878, 23.48931122], [68.49874878, 23.48903084], [68.49846649, 23.48903084]]], [[[68.50180817, 23.43208122], [68.50180817, 23.43124962], [68.50152588, 23.43124962], [68.50152588, 23.43069077], [68.50125122, 23.43069458], [68.50125122, 23.43013954], [68.50041962, 23.43013954], [68.50041962, 23.43124962], [68.50096893, 23.43124962], [68.50096893, 23.43153191], [68.50125122, 23.43152809], [68.50125122, 23.43208122], [68.50152588, 23.43208122], [68.50152588, 23.43237114], [68.50208282, 23.43237114], [68.50208282, 23.43208122], [68.50180817, 23.43208122]]], [[[68.51680756, 23.43292046], [68.51680756, 23.43264008], [68.51708221, 23.43264008], [68.51708221, 23.43153191], [68.51680756, 23.43153191], [68.51680756, 23.43097115], [68.51652527, 23.43097115], [68.51652527, 23.43041611], [68.51625061, 23.43042183], [68.51625061, 23.42985916], [68.51597595, 23.42985916], [68.51597595, 23.43013954], [68.51568604, 23.43013954], [68.51568604, 23.43042183], [68.51541901, 23.43041611], [68.51541901, 23.43069458], [68.51430511, 23.43069458], [68.51430511, 23.43041611], [68.51374817, 23.43041611], [68.51374817, 23.43097115], [68.51403046, 23.43097115], [68.51403046, 23.43153191], [68.51374817, 23.43152809], [68.51374817, 23.43208122], [68.51403046, 23.43208122], [68.51403046, 23.43264008], [68.51457977, 23.43264008], [68.51457977, 23.43292046], [68.51680756, 23.43292046]]], [[[68.50068665, 23.43625069], [68.50068665, 23.43597031], [68.50096893, 23.43597221], [68.50096893, 23.43541718], [68.49958038, 23.43541718], [68.49958038, 23.4351387], [68.49931335, 23.43514061], [68.49931335, 23.43486023], [68.49874878, 23.43486023], [68.49874878, 23.43457985], [68.49819183, 23.43458557], [68.49819183, 23.43430328], [68.49791718, 23.43430328], [68.49791718, 23.43458557], [68.49680328, 23.43457985], [68.49680328, 23.43486023], [68.49736023, 23.43486023], [68.49736023, 23.43541718], [68.49791718, 23.43541718], [68.49791718, 23.43569565], [68.49819183, 23.43569565], [68.49819183, 23.43597221], [68.49874878, 23.43597031], [68.49874878, 23.43625069], [68.50068665, 23.43625069]]], [[[68.50125122, 23.44375038], [68.50125122, 23.44347191], [68.50208282, 23.44347191], [68.50208282, 23.44319534], [68.50180817, 23.44320107], [68.50180817, 23.4426403], [68.50152588, 23.4426403], [68.50152588, 23.44154167], [68.50125122, 23.44154167], [68.50125122, 23.43930817], [68.50096893, 23.43930817], [68.50096893, 23.43902969], [68.50068665, 23.43902969], [68.50068665, 23.44041824], [68.50041962, 23.44041634], [68.50041962, 23.44097137], [68.50013733, 23.44096947], [68.50013733, 23.44154167], [68.49958038, 23.44152832], [68.49958038, 23.44180489], [68.49930573, 23.44180489], [68.49930573, 23.44236183], [68.50013733, 23.44235992], [68.50013733, 23.4426403], [68.50041962, 23.4426403], [68.50041962, 23.44292259], [68.50069427, 23.44291687], [68.50069427, 23.44347191], [68.50096893, 23.44347191], [68.50096893, 23.44375038], [68.50125122, 23.44375038]]], [[[68.50681305, 23.45654106], [68.50681305, 23.45624924], [68.50708008, 23.45624924], [68.50708008, 23.45597076], [68.50736237, 23.45597267], [68.50736237, 23.4556942], [68.50763702, 23.4556942], [68.50763702, 23.45541763], [68.50791931, 23.45542145], [68.50791931, 23.45513916], [68.50846863, 23.45513916], [68.50846863, 23.45486069], [68.50874329, 23.45486069], [68.50874329, 23.45431137], [68.5090332, 23.45431137], [68.5090332, 23.45402908], [68.51013947, 23.45402908], [68.51013947, 23.45264053], [68.51097107, 23.45264053], [68.51097107, 23.45236015], [68.51125336, 23.45236206], [68.51125336, 23.45208359], [68.51180267, 23.45208359], [68.51180267, 23.45180511], [68.51152802, 23.45181084], [68.51152802, 23.45153046], [68.51346588, 23.45153046], [68.51346588, 23.45125008], [68.51374817, 23.45125008], [68.51374817, 23.4509697], [68.51403046, 23.4509716], [68.51403046, 23.45069695], [68.51431274, 23.45070076], [68.51431274, 23.45041084], [68.51513672, 23.45041656], [68.51513672, 23.45013809], [68.51597595, 23.45014], [68.51599884, 23.44985962], [68.51680756, 23.44986153], [68.51680756, 23.44958305], [68.51763916, 23.44958305], [68.51763916, 23.44930649], [68.51819611, 23.4493103], [68.51819611, 23.44902992], [68.51902771, 23.44902992], [68.51902771, 23.44847107], [68.51930237, 23.44847488], [68.51930237, 23.44791412], [68.51957703, 23.44791985], [68.51957703, 23.44763947], [68.51985931, 23.44763947], [68.51985931, 23.44708061], [68.5201416, 23.44708252], [68.5201416, 23.44652748], [68.52041626, 23.44652939], [68.52041626, 23.44597054], [68.52069092, 23.44597435], [68.52069092, 23.4454174], [68.52097321, 23.44542122], [68.52097321, 23.44514275], [68.52124786, 23.44514275], [68.52124786, 23.44486046], [68.52179718, 23.44486046], [68.52179718, 23.44458008], [68.52263641, 23.44458389], [68.52263641, 23.44430542], [68.52319336, 23.44431114], [68.52319336, 23.44403267], [68.52375031, 23.44403267], [68.52375031, 23.44375038], [68.52458191, 23.44375038], [68.52458191, 23.44347191], [68.5248642, 23.44347191], [68.5248642, 23.44319534], [68.52513885, 23.44320107], [68.52513885, 23.4426403], [68.52540588, 23.4426403], [68.52540588, 23.44235992], [68.5256958, 23.44236183], [68.5256958, 23.44208336], [68.52597046, 23.44208336], [68.52597046, 23.44124985], [68.52625275, 23.44124985], [68.52625275, 23.43985939], [68.5265274, 23.4398613], [68.5265274, 23.43819427], [68.52625275, 23.43819427], [68.52625275, 23.4370842], [68.52597046, 23.4370842], [68.52597046, 23.43652725], [68.5256958, 23.43653107], [68.5256958, 23.43625069], [68.52513885, 23.43625069], [68.52513885, 23.43653107], [68.52485657, 23.43653107], [68.52485657, 23.43736076], [68.52458191, 23.43736076], [68.52458191, 23.43875122], [68.52430725, 23.43875122], [68.52430725, 23.44041824], [68.52404022, 23.44041824], [68.52404022, 23.44154167], [68.52375031, 23.44152832], [68.52375031, 23.44236183], [68.5229187, 23.44235992], [68.5229187, 23.44320107], [68.5220871, 23.44319534], [68.5220871, 23.44347191], [68.52097321, 23.44347191], [68.52097321, 23.44375038], [68.52068329, 23.44375038], [68.52068329, 23.44403267], [68.5201416, 23.44403267], [68.5201416, 23.44431114], [68.51985931, 23.44430542], [68.51985931, 23.44458389], [68.51957703, 23.44458008], [68.51957703, 23.44486046], [68.51930237, 23.44486046], [68.51930237, 23.44514275], [68.51875305, 23.44514275], [68.51875305, 23.44542122], [68.51790619, 23.44542122], [68.51790619, 23.44625282], [68.51763916, 23.44625282], [68.51763916, 23.44680977], [68.5173645, 23.44680405], [68.5173645, 23.44708252], [68.51708221, 23.44708252], [68.51708221, 23.4473629], [68.51680756, 23.44734955], [68.51680756, 23.44763947], [68.5165329, 23.44763947], [68.5165329, 23.44791985], [68.51582336, 23.44791412], [68.51346588, 23.44791985], [68.51346588, 23.44734955], [68.51374817, 23.4473629], [68.51374817, 23.44708252], [68.51430511, 23.44708252], [68.51430511, 23.44680405], [68.51457977, 23.44680977], [68.51457977, 23.44652939], [68.51486969, 23.44652939], [68.51486969, 23.44625282], [68.51541901, 23.44625282], [68.51541901, 23.44569016], [68.51513672, 23.44569206], [68.51513672, 23.44486046], [68.5165329, 23.44486046], [68.5165329, 23.44514275], [68.51711273, 23.44513893], [68.51735687, 23.44514275], [68.5173645, 23.44482994], [68.51763916, 23.44486046], [68.51757813, 23.44431114], [68.51790619, 23.44431114], [68.51786041, 23.44372559], [68.51819611, 23.44375038], [68.51819611, 23.44347191], [68.51902771, 23.44347191], [68.51902771, 23.44319534], [68.51930237, 23.44320107], [68.51930237, 23.44292259], [68.51957703, 23.44292259], [68.51957703, 23.44235992], [68.51985931, 23.44236183], [68.51985931, 23.44208336], [68.52069092, 23.44208336], [68.52069092, 23.44180489], [68.52097321, 23.44180489], [68.52097321, 23.44152832], [68.52124786, 23.44154167], [68.52124786, 23.44013977], [68.52153015, 23.44013977], [68.52153015, 23.43875122], [68.52124786, 23.43875122], [68.52124786, 23.43764114], [68.52097321, 23.43764114], [68.52097321, 23.43708038], [68.52069092, 23.4370842], [68.52069092, 23.43680763], [68.51985931, 23.43680763], [68.51985931, 23.4370842], [68.51957703, 23.43708038], [68.51957703, 23.43736076], [68.51930237, 23.43736076], [68.51930237, 23.43930817], [68.51902771, 23.43930626], [68.51902771, 23.4398613], [68.51875305, 23.43985939], [68.51875305, 23.44041824], [68.51847076, 23.44041634], [68.51847076, 23.44097137], [68.51819611, 23.44096947], [68.51819611, 23.44154167], [68.51791382, 23.44152832], [68.51791382, 23.44208336], [68.51708221, 23.44208336], [68.51708221, 23.44069481], [68.5173645, 23.44069481], [68.5173645, 23.44013977], [68.51763916, 23.44013977], [68.51763916, 23.43902969], [68.51790619, 23.43902969], [68.51790619, 23.43708038], [68.51819611, 23.4370842], [68.51819611, 23.43625069], [68.51790619, 23.43625069], [68.51790619, 23.43597031], [68.51708221, 23.43597221], [68.51708221, 23.43569565], [68.51680756, 23.43569565], [68.51680756, 23.43541718], [68.51569366, 23.43541718], [68.51569366, 23.43347168], [68.51541901, 23.43346977], [68.51541901, 23.43375015], [68.51513672, 23.43375015], [68.51513672, 23.43680954], [68.51403046, 23.43680763], [68.51403046, 23.4370842], [68.51235962, 23.4370842], [68.51235962, 23.43680763], [68.51207733, 23.43680954], [68.51207733, 23.43653107], [68.51152802, 23.43653107], [68.51152802, 23.43680954], [68.51125336, 23.43680763], [68.51125336, 23.4370842], [68.51097107, 23.43708038], [68.51097107, 23.43764114], [68.51069641, 23.43763924], [68.51069641, 23.43847275], [68.51040649, 23.43847084], [68.51040649, 23.43875122], [68.50985718, 23.43875122], [68.50985718, 23.43819046], [68.51013947, 23.43819427], [68.51013947, 23.43736076], [68.51040649, 23.43736076], [68.51040649, 23.43680954], [68.51069641, 23.43680954], [68.51069641, 23.43625069], [68.51097107, 23.43625069], [68.51097107, 23.43568993], [68.51125336, 23.43569565], [68.51125336, 23.43541718], [68.51152802, 23.43541718], [68.51152802, 23.4351387], [68.51207733, 23.43514061], [68.51207733, 23.43431091], [68.51235962, 23.43431091], [68.51235962, 23.43346977], [68.51208496, 23.43347168], [68.51208496, 23.43291664], [68.5118103, 23.43292046], [68.5118103, 23.43208122], [68.51152802, 23.43208122], [68.51152802, 23.43041611], [68.51041412, 23.43041611], [68.51041412, 23.43069458], [68.51013947, 23.43069458], [68.51013947, 23.43097115], [68.50985718, 23.43097115], [68.50985718, 23.43124962], [68.50958252, 23.43124962], [68.50958252, 23.43153191], [68.50930786, 23.43152809], [68.50930786, 23.43180466], [68.50819397, 23.43180466], [68.50819397, 23.43152809], [68.50708008, 23.43153191], [68.50708008, 23.43124962], [68.50596619, 23.43124962], [68.50596619, 23.43097115], [68.50541687, 23.43097115], [68.50541687, 23.43069458], [68.50514221, 23.43069458], [68.50514221, 23.43041611], [68.5045929, 23.43042183], [68.5045929, 23.43013954], [68.50430298, 23.43013954], [68.50430298, 23.42985916], [68.50374603, 23.42985916], [68.50374603, 23.42958069], [68.50347137, 23.4295826], [68.50347137, 23.42930603], [68.5029068, 23.42931175], [68.5029068, 23.43042183], [68.50319672, 23.43041611], [68.50319672, 23.43069458], [68.50347137, 23.43069458], [68.50347137, 23.43097115], [68.50430298, 23.43097115], [68.50430298, 23.43180466], [68.5045929, 23.43180275], [68.5045929, 23.43264008], [68.50430298, 23.43264008], [68.50430298, 23.43320084], [68.50402832, 23.43320084], [68.50402832, 23.43375015], [68.50374603, 23.43375015], [68.50374603, 23.43431091], [68.50402832, 23.43431091], [68.50402832, 23.43403053], [68.50514221, 23.43403053], [68.50514221, 23.43680954], [68.50569153, 23.43680763], [68.50569153, 23.4370842], [68.50541687, 23.43708038], [68.50541687, 23.43764114], [68.50514221, 23.43764114], [68.50514221, 23.43930817], [68.50485992, 23.43930626], [68.50485992, 23.44069481], [68.50458527, 23.44069481], [68.5045929, 23.44124985], [68.50430298, 23.44124985], [68.50430298, 23.4426403], [68.50402832, 23.4426403], [68.50402832, 23.44375038], [68.50374603, 23.44375038], [68.50374603, 23.44486046], [68.50347137, 23.44486046], [68.50347137, 23.44597435], [68.50319672, 23.44597435], [68.50319672, 23.44708252], [68.5029068, 23.44708061], [68.5029068, 23.44791985], [68.50319672, 23.44791412], [68.50319672, 23.4481926], [68.50347137, 23.4481926], [68.50347137, 23.44847488], [68.50402832, 23.44847107], [68.50402832, 23.44874954], [68.5045929, 23.44874954], [68.5045929, 23.44902992], [68.50514221, 23.44902992], [68.50514221, 23.4493103], [68.50541687, 23.44930649], [68.50541687, 23.44958305], [68.50597382, 23.44958305], [68.50597382, 23.44986153], [68.50624847, 23.44985962], [68.50624847, 23.45014], [68.50653076, 23.45013809], [68.50653076, 23.45041656], [68.50680542, 23.45041656], [68.50680542, 23.4509716], [68.50624847, 23.4509697], [68.50624847, 23.45125008], [68.50597382, 23.45125008], [68.50597382, 23.45208359], [68.50485992, 23.45207977], [68.50485992, 23.45236015], [68.50430298, 23.45236015], [68.50430298, 23.45347977], [68.50458527, 23.45347214], [68.5045929, 23.45375061], [68.50430298, 23.45375061], [68.50430298, 23.45402908], [68.50402832, 23.45402718], [68.50402832, 23.45458412], [68.50374603, 23.45458031], [68.50374603, 23.45486069], [68.50347137, 23.45486069], [68.50347137, 23.45542145], [68.50319672, 23.45541573], [68.50319672, 23.45597267], [68.50402832, 23.45597076], [68.50402832, 23.45624924], [68.5045929, 23.45624924], [68.5045929, 23.45654106], [68.5061264, 23.45652962], [68.50681305, 23.45654106]]], [[[68.43125153, 23.43985939], [68.43152618, 23.4398613], [68.43152618, 23.43958282], [68.43345642, 23.43958092], [68.43345642, 23.44041824], [68.43374634, 23.44041634], [68.43374634, 23.44069481], [68.43430328, 23.44069481], [68.43430328, 23.44041634], [68.43486023, 23.44041634], [68.43486023, 23.44069481], [68.43514252, 23.44068909], [68.43514252, 23.44124985], [68.43486023, 23.44124985], [68.43486023, 23.44154167], [68.43430328, 23.44152832], [68.43430328, 23.44208336], [68.43458557, 23.44208336], [68.43458557, 23.44236183], [68.43514252, 23.44235992], [68.43514252, 23.4426403], [68.43541718, 23.4426403], [68.43541718, 23.44207764], [68.43596649, 23.44207764], [68.43596649, 23.44292259], [68.43624878, 23.44291687], [68.43624878, 23.44347191], [68.43569183, 23.44347191], [68.43569183, 23.44375038], [68.43541718, 23.44375038], [68.43541718, 23.44514275], [68.43458557, 23.44513893], [68.43458557, 23.44597435], [68.43430328, 23.44597054], [68.43430328, 23.44625282], [68.43402863, 23.44625282], [68.43402863, 23.44652939], [68.43374634, 23.44652748], [68.43374634, 23.44708252], [68.43319702, 23.44708252], [68.43319702, 23.4481926], [68.43347168, 23.4481926], [68.43347168, 23.44847488], [68.43319702, 23.44847107], [68.43319702, 23.44874954], [68.4329071, 23.44874954], [68.4329071, 23.44902992], [68.43264008, 23.44902992], [68.43264008, 23.45014], [68.4329071, 23.45014], [68.4329071, 23.44985962], [68.43402863, 23.44986153], [68.43402863, 23.44958305], [68.43430328, 23.44958305], [68.43430328, 23.44930649], [68.4345932, 23.4493103], [68.4345932, 23.44902992], [68.43541718, 23.44902802], [68.43541718, 23.44958305], [68.43569183, 23.44958305], [68.43569183, 23.44986153], [68.43624878, 23.44985962], [68.43624878, 23.45014], [68.43653107, 23.45014], [68.43653107, 23.45125008], [68.43682098, 23.45125008], [68.43682098, 23.45181084], [68.43596649, 23.45181084], [68.43596649, 23.45292091], [68.43624878, 23.45292091], [68.43624878, 23.45264053], [68.43680573, 23.45263863], [68.43680573, 23.45319366], [68.43708038, 23.45318985], [68.43708038, 23.45375061], [68.43763733, 23.45375061], [68.43763733, 23.45402908], [68.43985748, 23.45402908], [68.43985748, 23.45375061], [68.44013977, 23.45375061], [68.44013977, 23.45347977], [68.44097137, 23.45347977], [68.44097137, 23.45375061], [68.44124603, 23.45375061], [68.44124603, 23.45402908], [68.44152832, 23.45402718], [68.44152832, 23.45458412], [68.44235992, 23.45458412], [68.44235992, 23.45430565], [68.44271851, 23.45430565], [68.44319153, 23.45430565], [68.44319153, 23.45490074], [68.44319153, 23.45597267], [68.44420624, 23.45597267], [68.44541931, 23.45597076], [68.44541931, 23.4568119], [68.44569397, 23.45680618], [68.44569397, 23.45753098], [68.44568634, 23.45763969], [68.44580078, 23.45763969], [68.44930267, 23.45763969], [68.44930267, 23.45792007], [68.44985962, 23.45791626], [68.44985962, 23.45819473], [68.45014191, 23.45819473], [68.45014191, 23.4584713], [68.45041656, 23.45846939], [68.45041656, 23.45903015], [68.45069122, 23.45902824], [68.45069122, 23.45930481], [68.45097351, 23.45930481], [68.45097351, 23.45958138], [68.45124817, 23.45957947], [68.45124817, 23.46014023], [68.45153046, 23.46014023], [68.45153046, 23.46042061], [68.45182037, 23.46042061], [68.45182037, 23.46070099], [68.45236206, 23.46069336], [68.45236206, 23.46097374], [68.45263672, 23.46096992], [68.45263672, 23.46125031], [68.45236206, 23.46125031], [68.45236206, 23.46181107], [68.45263672, 23.46180344], [68.45263672, 23.46236038], [68.45291901, 23.46235085], [68.45291901, 23.46264076], [68.45318604, 23.46264076], [68.45318604, 23.46375084], [68.45236206, 23.46375084], [68.45236206, 23.46347046], [68.45207977, 23.46347237], [68.45207977, 23.4631958], [68.45180511, 23.4631958], [68.45180511, 23.46291733], [68.45153046, 23.46292114], [68.45153046, 23.46264076], [68.45096588, 23.46264076], [68.45096588, 23.46235085], [68.45069122, 23.46236038], [68.45069122, 23.46208572], [68.45041656, 23.46208572], [68.45041656, 23.46180344], [68.45014191, 23.46181107], [68.45014191, 23.46153069], [68.44985962, 23.46153069], [68.44985962, 23.46125031], [68.44957733, 23.46125031], [68.44957733, 23.46096992], [68.44896698, 23.46096992], [68.44819641, 23.46096992], [68.44819641, 23.46125031], [68.44708252, 23.46125031], [68.44708252, 23.46153069], [68.44596863, 23.46153069], [68.44596863, 23.46181107], [68.44486237, 23.46180344], [68.44486237, 23.46208572], [68.44458008, 23.46208], [68.44458008, 23.46264076], [68.44486237, 23.46263885], [68.44486237, 23.4631958], [68.44458008, 23.46319008], [68.44458008, 23.46430969], [68.44430542, 23.46430779], [68.44430542, 23.46458244], [68.44403076, 23.46458054], [68.44403076, 23.46652985], [68.44458008, 23.46652985], [68.44458008, 23.46680832], [68.44486237, 23.46680641], [68.44486237, 23.46708298], [68.44513702, 23.46708107], [68.44513702, 23.4679184], [68.44708252, 23.4679184], [68.44708252, 23.46820068], [68.44735718, 23.46820068], [68.44735718, 23.46763992], [68.44819641, 23.46763992], [68.44819641, 23.46820068], [68.44847107, 23.46820068], [68.44847107, 23.46874809], [68.44876099, 23.46874809], [68.44876099, 23.46902847], [68.44930267, 23.46902847], [68.44930267, 23.46847916], [68.44985962, 23.46847916], [68.44985962, 23.46902847], [68.45014191, 23.46902847], [68.45014191, 23.46931267], [68.45041656, 23.46930504], [68.45041656, 23.46958351], [68.45124817, 23.46958351], [68.45124817, 23.46986008], [68.45153046, 23.46986008], [68.45153046, 23.46958351], [68.45207977, 23.46958351], [68.45207977, 23.46930504], [68.45291901, 23.46930504], [68.45291901, 23.46958351], [68.45319366, 23.46958351], [68.45319366, 23.46986008], [68.45375061, 23.46986008], [68.45375061, 23.46958351], [68.45458221, 23.46958351], [68.45458221, 23.46986008], [68.45430756, 23.46986008], [68.45430756, 23.47069359], [68.45458221, 23.47069359], [68.45458221, 23.47041702], [68.45513916, 23.47042274], [68.45513916, 23.47014046], [68.45540619, 23.47014046], [68.45540619, 23.46986008], [68.45569611, 23.46986008], [68.45569611, 23.46930504], [68.45597076, 23.46931267], [68.45597076, 23.46902847], [68.45625305, 23.46902847], [68.45625305, 23.46874809], [68.45652771, 23.46874809], [68.45652771, 23.4679184], [68.45680237, 23.4679184], [68.45680237, 23.46763992], [68.45735931, 23.46763992], [68.45735931, 23.46820068], [68.45707703, 23.46820068], [68.45707703, 23.46874809], [68.45680237, 23.46874809], [68.45680237, 23.46958351], [68.45652771, 23.46958351], [68.45652771, 23.46986008], [68.45625305, 23.46986008], [68.45625305, 23.47014046], [68.45597076, 23.47013855], [68.45597076, 23.47069359], [68.45625305, 23.47069359], [68.45625305, 23.47097015], [68.45708466, 23.47097015], [68.45708466, 23.47069359], [68.45735931, 23.47069359], [68.45735931, 23.47041702], [68.45762634, 23.47042274], [68.45762634, 23.47014046], [68.45791626, 23.47014046], [68.45791626, 23.46986008], [68.45819092, 23.46986008], [68.45819092, 23.46958351], [68.45847321, 23.46958351], [68.45847321, 23.46930504], [68.45874786, 23.46931267], [68.45874786, 23.46902847], [68.45903015, 23.46902847], [68.45903015, 23.46874809], [68.45929718, 23.46874809], [68.45929718, 23.46847916], [68.46013641, 23.46847153], [68.46013641, 23.46899033], [68.46013641, 23.46986008], [68.4604187, 23.46986008], [68.4604187, 23.47458458], [68.46013641, 23.47458076], [68.46013641, 23.47486115], [68.4604187, 23.47486115], [68.4604187, 23.47513962], [68.46070099, 23.47513962], [68.46070099, 23.47542], [68.46125031, 23.47542], [68.46125031, 23.47624969], [68.46098328, 23.47624969], [68.46098328, 23.47653008], [68.4604187, 23.47652817], [68.4604187, 23.47736168], [68.45874786, 23.47736168], [68.45874786, 23.47708321], [68.45847321, 23.47708321], [68.45847321, 23.47680664], [68.45791626, 23.47680664], [68.45791626, 23.47736168], [68.4576416, 23.47736168], [68.45762634, 23.47817993], [68.45735931, 23.47819519], [68.45735931, 23.47847176], [68.45707703, 23.47846985], [68.45707703, 23.47875023], [68.45832825, 23.47875023], [68.45986176, 23.47875023], [68.45986176, 23.47846985], [68.46069336, 23.47847176], [68.46069336, 23.47875023], [68.4640274, 23.47875023], [68.4640274, 23.47903061], [68.4651413, 23.47903061], [68.4651413, 23.47875023], [68.46652985, 23.47875023], [68.46652985, 23.47846985], [68.4668045, 23.47847176], [68.4668045, 23.47819519], [68.4679184, 23.47819519], [68.4679184, 23.47847176], [68.46819305, 23.47847176], [68.46819305, 23.47819519], [68.46909332, 23.47819519], [68.47013855, 23.47819519], [68.47013855, 23.47847176], [68.47041321, 23.47846985], [68.47041321, 23.47875023], [68.47070313, 23.47875023], [68.47070313, 23.47930908], [68.47097015, 23.47930527], [68.47097015, 23.47958374], [68.47109222, 23.47958374], [68.4715271, 23.47958374], [68.4715271, 23.47986031], [68.47167969, 23.47986031], [68.47180176, 23.47986031], [68.47180176, 23.48014069], [68.47226715, 23.48013878], [68.4723587, 23.48013878], [68.4723587, 23.48041916], [68.47286224, 23.48041916], [68.47292328, 23.48014069], [68.4734726, 23.48014069], [68.4734726, 23.47986031], [68.47429657, 23.47986031], [68.47429657, 23.47957993], [68.47486115, 23.47958374], [68.47486115, 23.47930527], [68.4751358, 23.47930908], [68.4751358, 23.47903061], [68.47570038, 23.47903061], [68.47570038, 23.47875023], [68.47624969, 23.47875023], [68.47624969, 23.47846985], [68.47652435, 23.47847176], [68.47652435, 23.47819519], [68.4770813, 23.47820091], [68.4770813, 23.47792053], [68.4779129, 23.47792053], [68.4779129, 23.47764969], [68.47846985, 23.47764969], [68.47846985, 23.47735977], [68.47930908, 23.47736168], [68.47930908, 23.47708321], [68.4826355, 23.47708321], [68.4826355, 23.47680664], [68.48319244, 23.47680664], [68.48319244, 23.47652817], [68.48374939, 23.47653008], [68.48374939, 23.47624969], [68.48401642, 23.47624969], [68.48401642, 23.47597122], [68.48430634, 23.47597313], [68.48430634, 23.47569656], [68.48513794, 23.47569656], [68.48513794, 23.47541428], [68.48542023, 23.47542], [68.48542023, 23.47486115], [68.48568726, 23.47486115], [68.48568726, 23.47430992], [68.48596954, 23.47430992], [68.48596954, 23.47402954], [68.48625183, 23.47402954], [68.48625183, 23.47347069], [68.48652649, 23.4734745], [68.48652649, 23.47319221], [68.48680878, 23.47319221], [68.48680878, 23.47263908], [68.48707581, 23.4726429], [68.48707581, 23.47208023], [68.48680878, 23.47208214], [68.48680878, 23.47180557], [68.48652649, 23.47180939], [68.48652649, 23.47097015], [68.48625183, 23.47097015], [68.48625183, 23.47041702], [68.48652649, 23.47042274], [68.48652649, 23.46874809], [68.48680878, 23.46874809], [68.48680878, 23.46735954], [68.48708344, 23.46736145], [68.48708344, 23.46680641], [68.48735809, 23.46680832], [68.48735809, 23.46624947], [68.48764038, 23.46624947], [68.48764038, 23.46597099], [68.48791504, 23.4659729], [68.48791504, 23.46569443], [68.48819733, 23.46569443], [68.48819733, 23.46541786], [68.48847198, 23.46541977], [68.48847198, 23.46486092], [68.48902893, 23.46486092], [68.48902893, 23.46458054], [68.48930359, 23.46458244], [68.48930359, 23.46430779], [68.48958588, 23.46430969], [68.48958588, 23.46375084], [68.48986053, 23.46375084], [68.48986053, 23.46319008], [68.49013519, 23.4631958], [68.49013519, 23.46263885], [68.49041748, 23.46264076], [68.49041748, 23.46235085], [68.49069214, 23.46236038], [68.49069214, 23.46180344], [68.4909668, 23.46181107], [68.4909668, 23.46153069], [68.49153137, 23.46153069], [68.49153137, 23.46125031], [68.49180603, 23.46125031], [68.49180603, 23.46042061], [68.49208069, 23.46042061], [68.49208069, 23.45985985], [68.49236298, 23.45986366], [68.49236298, 23.45958138], [68.49263763, 23.45958138], [68.49263763, 23.45874977], [68.49291992, 23.45874977], [68.49291992, 23.45846939], [68.49319458, 23.4584713], [68.49319458, 23.45819473], [68.49346924, 23.45819473], [68.49346924, 23.45791626], [68.49373627, 23.45792007], [68.49373627, 23.45763969], [68.49430847, 23.45763969], [68.49430847, 23.45735931], [68.49458313, 23.45735931], [68.49458313, 23.45597076], [68.49485779, 23.45597267], [68.49485779, 23.45513916], [68.49458313, 23.45513916], [68.49458313, 23.45486069], [68.49485779, 23.45486069], [68.49485779, 23.45458031], [68.49458313, 23.45458412], [68.49458313, 23.45319366], [68.49430847, 23.45319366], [68.49430847, 23.45263863], [68.49402618, 23.45264053], [68.49402618, 23.45236015], [68.49375153, 23.45236015], [68.49373627, 23.45125008], [68.49346924, 23.45125008], [68.49346924, 23.4509697], [68.49319458, 23.4509716], [68.49319458, 23.45041656], [68.49291992, 23.45041656], [68.49291992, 23.44986153], [68.49263763, 23.44986153], [68.49263763, 23.44930649], [68.49236298, 23.44930077], [68.49236298, 23.44874954], [68.49208069, 23.44874954], [68.49208069, 23.44819069], [68.49180603, 23.4481926], [68.49180603, 23.4473629], [68.49153137, 23.4473629], [68.49153137, 23.44625282], [68.49124908, 23.44625282], [68.49124908, 23.44514275], [68.49069977, 23.44514275], [68.49069977, 23.44458008], [68.49041748, 23.44458389], [68.49041748, 23.43874931], [68.49014282, 23.43875122], [68.49014282, 23.43708038], [68.48986053, 23.4370842], [68.48986053, 23.43680763], [68.49014282, 23.43680954], [68.49014282, 23.43597031], [68.48986053, 23.43597221], [68.48986053, 23.43541718], [68.49013519, 23.43541718], [68.49013519, 23.43458557], [68.48986053, 23.43458557], [68.48986053, 23.43402863], [68.48958588, 23.43403053], [68.48958588, 23.43264008], [68.48986053, 23.43264008], [68.48986053, 23.42736053], [68.48958588, 23.42736053], [68.48958588, 23.42542076], [68.48929596, 23.42542076], [68.48929596, 23.42457962], [68.48902893, 23.42458344], [68.48902893, 23.42347145], [68.48874664, 23.42347145], [68.48874664, 23.42263794], [68.48847198, 23.42263985], [68.48847198, 23.42069054], [68.48819733, 23.42069244], [68.48819733, 23.41986084], [68.48791504, 23.41986084], [68.48791504, 23.41902733], [68.48764038, 23.41903114], [68.48764038, 23.41819191], [68.48735809, 23.41819382], [68.48735809, 23.41625023], [68.48707581, 23.41625023], [68.48707581, 23.41541862], [68.48680878, 23.41541862], [68.48680878, 23.41457748], [68.48652649, 23.41458321], [68.48652649, 23.41180611], [68.48625183, 23.41180992], [68.48625183, 23.41097069], [68.48596954, 23.4109726], [68.48596954, 23.41013908], [68.48568726, 23.41014099], [68.48568726, 23.40792084], [68.48542023, 23.40792084], [68.48542023, 23.40570068], [68.48513794, 23.40570068], [68.48513794, 23.40542984], [68.48542023, 23.40542984], [68.48542023, 23.40458107], [68.48513794, 23.40458107], [68.48513794, 23.40430641], [68.48486328, 23.40431023], [68.48486328, 23.40374947], [68.48458099, 23.40374947], [68.48458099, 23.40319061], [68.48374939, 23.40319443], [68.48374939, 23.40291595], [68.48208618, 23.40291595], [68.48208618, 23.40319443], [68.48152924, 23.40319443], [68.48152924, 23.4034729], [68.48069763, 23.40346909], [68.48069763, 23.40374947], [68.48014069, 23.40374947], [68.48014069, 23.40403175], [68.47930908, 23.40403175], [68.47930908, 23.40431023], [68.4779129, 23.40431023], [68.4779129, 23.40403175], [68.47763824, 23.40403175], [68.47763824, 23.40346909], [68.4770813, 23.40346909], [68.4770813, 23.40374947], [68.47680664, 23.40374947], [68.47680664, 23.40403175], [68.47628021, 23.40403175], [68.47624969, 23.40431023], [68.47569275, 23.40430641], [68.47569275, 23.40458107], [68.4751358, 23.40458107], [68.4751358, 23.40486145], [68.47458649, 23.40485954], [68.47458649, 23.40514183], [68.47402954, 23.40514183], [68.47402954, 23.40542984], [68.4734726, 23.40542984], [68.4734726, 23.40570068], [68.47310638, 23.40569305], [68.47291565, 23.40569305], [68.47291565, 23.40597153], [68.4723587, 23.40596962], [68.4723587, 23.40625], [68.47180176, 23.40625], [68.47180176, 23.40653038], [68.47070313, 23.40653038], [68.47070313, 23.40625], [68.46956635, 23.40625], [68.46956635, 23.40653038], [68.46901703, 23.40653038], [68.46901703, 23.40625], [68.46819305, 23.40625], [68.46819305, 23.40596962], [68.46679688, 23.40596962], [68.4668045, 23.40625], [68.46608734, 23.40625], [68.4659729, 23.40625], [68.4659729, 23.40708542], [68.46347046, 23.40708542], [68.46347046, 23.40736389], [68.46375275, 23.40736389], [68.46375275, 23.4081955], [68.46458435, 23.4081955], [68.46458435, 23.40847206], [68.46485901, 23.40847015], [68.46485901, 23.40875053], [68.46457672, 23.40875053], [68.46457672, 23.40903091], [68.46485901, 23.40902519], [68.46485901, 23.40958595], [68.4651413, 23.40958023], [68.4651413, 23.40986061], [68.46541595, 23.40986061], [68.46541595, 23.41041946], [68.46569061, 23.41041756], [68.46569824, 23.41069412], [68.4659729, 23.41069412], [68.4659729, 23.4109726], [68.46624756, 23.41097069], [68.46624756, 23.41152954], [68.46652985, 23.41152954], [68.46652985, 23.41180992], [68.46569824, 23.41180611], [68.46569061, 23.41208267], [68.4651413, 23.41208076], [68.4651413, 23.41236115], [68.46457672, 23.41236115], [68.46457672, 23.41263962], [68.46430206, 23.41263962], [68.46430206, 23.41291809], [68.46375275, 23.41291618], [68.46375275, 23.41319466], [68.46347046, 23.41319466], [68.46347046, 23.41347313], [68.46290588, 23.41347122], [68.46290588, 23.41374969], [68.46208191, 23.41374969], [68.46208191, 23.41402817], [68.46152496, 23.41402817], [68.46152496, 23.41430473], [68.46097565, 23.41430473], [68.46097565, 23.41486168], [68.46070099, 23.41485977], [68.46070099, 23.41541862], [68.45986176, 23.41541862], [68.45986176, 23.41570282], [68.4595871, 23.41570282], [68.4595871, 23.41625023], [68.45929718, 23.41625023], [68.45929718, 23.41653252], [68.45903015, 23.4165287], [68.45903015, 23.41708374], [68.45874786, 23.41708183], [68.45874786, 23.41764259], [68.45847321, 23.41764259], [68.45847321, 23.41792107], [68.45819092, 23.41791725], [68.45819092, 23.41819382], [68.45847321, 23.41819191], [68.45847321, 23.41875267], [68.45874786, 23.41875267], [68.45874786, 23.41930962], [68.45903015, 23.4193058], [68.45903015, 23.41958237], [68.45929718, 23.41958046], [68.45929718, 23.41986084], [68.46153259, 23.41986084], [68.46152496, 23.41958237], [68.4623642, 23.41958237], [68.4623642, 23.4193058], [68.46291351, 23.4193058], [68.46291351, 23.41958237], [68.4631958, 23.41958046], [68.4631958, 23.41986084], [68.46347046, 23.41986084], [68.46347046, 23.42014122], [68.46375275, 23.42013931], [68.46375275, 23.42048073], [68.46375275, 23.42069244], [68.4640274, 23.42069244], [68.4640274, 23.42097473], [68.46430206, 23.42097092], [68.46430206, 23.42124939], [68.46457672, 23.42124939], [68.46457672, 23.42152977], [68.4640274, 23.42152977], [68.4640274, 23.42181015], [68.46375275, 23.42180634], [68.46375275, 23.42208481], [68.46347046, 23.42208481], [68.46347046, 23.42236137], [68.4631958, 23.42235947], [68.4631958, 23.42292023], [68.46291351, 23.42291641], [68.46291351, 23.42347145], [68.46263885, 23.42346954], [68.46263885, 23.42374992], [68.46235657, 23.42374992], [68.46235657, 23.42431068], [68.46208191, 23.42431068], [68.46208191, 23.42514038], [68.46180725, 23.42514038], [68.46180725, 23.42653084], [68.46235657, 23.42653084], [68.46235657, 23.42681122], [68.4631958, 23.4268055], [68.4631958, 23.42708397], [68.46375275, 23.42708397], [68.46375275, 23.42736053], [68.4640274, 23.42736053], [68.4640274, 23.42764091], [68.46376038, 23.42764091], [68.46376038, 23.42791939], [68.4631958, 23.42791748], [68.4631958, 23.42819405], [68.46180725, 23.42819405], [68.46180725, 23.42847252], [68.46153259, 23.42847061], [68.46153259, 23.42902946], [68.46125031, 23.42902756], [68.46125031, 23.4295826], [68.46208191, 23.42958069], [68.46208191, 23.42985916], [68.46152496, 23.42985916], [68.46153259, 23.43013954], [68.46125031, 23.43013954], [68.46125031, 23.43042183], [68.46097565, 23.43041611], [68.46097565, 23.43069458], [68.46125031, 23.43069458], [68.46125031, 23.43097115], [68.46152496, 23.43097115], [68.46152496, 23.43124962], [68.46180725, 23.43124962], [68.46180725, 23.43208122], [68.46208191, 23.43208122], [68.46208191, 23.43292046], [68.4595871, 23.43292046], [68.4595871, 23.43320084], [68.45903015, 23.43319321], [68.45903015, 23.43347168], [68.45874786, 23.43346977], [68.45874786, 23.43403053], [68.45903015, 23.43403053], [68.45903015, 23.43431091], [68.4595871, 23.43431091], [68.4595871, 23.43486023], [68.45986176, 23.43486023], [68.45986176, 23.43680954], [68.46013641, 23.43680954], [68.46013641, 23.43736076], [68.46125031, 23.43736076], [68.46125031, 23.43764114], [68.46235657, 23.43764114], [68.46235657, 23.43791962], [68.46263885, 23.43791771], [68.46263885, 23.43819427], [68.46291351, 23.43819427], [68.46291351, 23.43847275], [68.4631958, 23.43847084], [68.4631958, 23.43875122], [68.46347046, 23.43875122], [68.46347046, 23.43902969], [68.46457672, 23.43902969], [68.46457672, 23.43930817], [68.46485901, 23.43930626], [68.46485901, 23.43958282], [68.46541595, 23.43958282], [68.46541595, 23.4398613], [68.46569061, 23.43985939], [68.46569824, 23.44013977], [68.4659729, 23.44013977], [68.4659729, 23.44069481], [68.46624756, 23.44068909], [68.46624756, 23.44124985], [68.46679688, 23.44124985], [68.46679688, 23.44154167], [68.46708679, 23.44152832], [68.46708679, 23.44180489], [68.46736145, 23.44180489], [68.46736145, 23.44208336], [68.46763611, 23.44208336], [68.46763611, 23.44236183], [68.46736145, 23.44235992], [68.46736145, 23.4426403], [68.46652985, 23.4426403], [68.46652985, 23.44292259], [68.4640274, 23.44292259], [68.4640274, 23.44320107], [68.46263885, 23.44319534], [68.46263885, 23.44347191], [68.46152496, 23.44347191], [68.46152496, 23.44375038], [68.46070099, 23.44375038], [68.46070099, 23.44403267], [68.4604187, 23.44402695], [68.4604187, 23.44458389], [68.46125031, 23.44458008], [68.46125031, 23.44486046], [68.46153259, 23.44486046], [68.46153259, 23.44514275], [68.46125031, 23.44513893], [68.46125031, 23.44569206], [68.46097565, 23.44569206], [68.46097565, 23.44625282], [68.46125031, 23.44625282], [68.46125031, 23.44652939], [68.46153259, 23.44652939], [68.46153259, 23.44680977], [68.46069336, 23.44680405], [68.46069336, 23.44763947], [68.46097565, 23.44763947], [68.46097565, 23.44847488], [68.46125031, 23.44847107], [68.46125031, 23.44902992], [68.46152496, 23.44902802], [68.46152496, 23.44958305], [68.46180725, 23.44958305], [68.46180725, 23.44986153], [68.46208191, 23.44986153], [68.46208191, 23.45015907], [68.46208191, 23.45125008], [68.46180725, 23.45125008], [68.46180725, 23.45181084], [68.46152496, 23.45180511], [68.46152496, 23.45236206], [68.46180725, 23.45236015], [68.46180725, 23.45347977], [68.46208191, 23.45347977], [68.46208191, 23.45375061], [68.46235657, 23.45375061], [68.46235657, 23.45402908], [68.46290588, 23.45402908], [68.46290588, 23.45431137], [68.46347046, 23.45430565], [68.46347046, 23.45458412], [68.46485901, 23.45458031], [68.46485901, 23.45486069], [68.46569824, 23.45486069], [68.46569824, 23.45458031], [68.4668045, 23.45458412], [68.4668045, 23.45430565], [68.46736145, 23.45431137], [68.46736145, 23.45402908], [68.46819305, 23.45402908], [68.46819305, 23.45375061], [68.46901703, 23.45375061], [68.46901703, 23.45347977], [68.46956635, 23.45347977], [68.46956635, 23.45318985], [68.47070313, 23.45318985], [68.47070313, 23.45347977], [68.47125244, 23.45347977], [68.47125244, 23.45375061], [68.4715271, 23.45375061], [68.4715271, 23.45402908], [68.47180176, 23.45402908], [68.47180176, 23.45431137], [68.47208405, 23.45430565], [68.47208405, 23.45458412], [68.4723587, 23.45458031], [68.4723587, 23.45486069], [68.47264099, 23.45486069], [68.47264099, 23.4556942], [68.47291565, 23.4556942], [68.47291565, 23.45763969], [68.47319794, 23.45763969], [68.47319794, 23.45819473], [68.4734726, 23.45819283], [68.4734726, 23.45874977], [68.47402954, 23.45874977], [68.47402954, 23.45903015], [68.47429657, 23.45903015], [68.47429657, 23.45874977], [68.47486115, 23.45874977], [68.47486115, 23.45903015], [68.4751358, 23.45902824], [68.4751358, 23.45930481], [68.47486115, 23.45930481], [68.47486115, 23.45958138], [68.47458649, 23.45958138], [68.47458649, 23.45986366], [68.47402954, 23.45986366], [68.47402954, 23.45958138], [68.47291565, 23.45958138], [68.47291565, 23.45930481], [68.47264099, 23.45930481], [68.47264099, 23.4584713], [68.4723587, 23.4584713], [68.4723587, 23.45763969], [68.47207642, 23.45763969], [68.47207642, 23.45568848], [68.47180939, 23.4556942], [68.47180176, 23.45513916], [68.4715271, 23.45513916], [68.4715271, 23.45486069], [68.47125244, 23.45486069], [68.47125244, 23.45458031], [68.47097015, 23.45458412], [68.47097015, 23.45430565], [68.47041321, 23.45431137], [68.47041321, 23.45402908], [68.46956635, 23.45402908], [68.46956635, 23.45431137], [68.46902466, 23.45430565], [68.46902466, 23.45458412], [68.46847534, 23.45458412], [68.46848297, 23.45486069], [68.46763611, 23.45486069], [68.46763611, 23.45513916], [68.46736145, 23.45513916], [68.46736145, 23.45542145], [68.46708679, 23.45541573], [68.46708679, 23.4556942], [68.4668045, 23.4556942], [68.4668045, 23.45597267], [68.46708679, 23.45597076], [68.46708679, 23.45654106], [68.46736145, 23.45652771], [68.46736145, 23.45708275], [68.46763611, 23.45708084], [68.46763611, 23.45735931], [68.4679184, 23.45735931], [68.4679184, 23.45792007], [68.46819305, 23.45791626], [68.46819305, 23.4584713], [68.4679184, 23.45846939], [68.4679184, 23.45874977], [68.46763611, 23.45874977], [68.46763611, 23.45846939], [68.46736145, 23.4584713], [68.46736145, 23.45819473], [68.46708679, 23.45819473], [68.46708679, 23.45763969], [68.46679688, 23.45763969], [68.46679688, 23.45708084], [68.46652985, 23.45708275], [68.46652985, 23.45680618], [68.46624756, 23.4568119], [68.46624756, 23.45624924], [68.4659729, 23.45624924], [68.4659729, 23.45568848], [68.46485901, 23.4556942], [68.46485901, 23.45541573], [68.46405029, 23.45541573], [68.46347046, 23.45542145], [68.46347046, 23.45513916], [68.46290588, 23.45513916], [68.46290588, 23.45486069], [68.46235657, 23.45486069], [68.46235657, 23.45458031], [68.46208191, 23.45458412], [68.46208191, 23.45430565], [68.46153259, 23.45431137], [68.46153259, 23.45402908], [68.4604187, 23.45402908], [68.4604187, 23.45375061], [68.45929718, 23.45375061], [68.45929718, 23.45347977], [68.45847321, 23.45347977], [68.45847321, 23.45318985], [68.45819092, 23.45319366], [68.45819092, 23.45263863], [68.45791626, 23.45264053], [68.45791626, 23.45207977], [68.4576416, 23.45208359], [68.4576416, 23.45180511], [68.45652771, 23.45181084], [68.45652771, 23.45153046], [68.45456696, 23.45153046], [68.45456696, 23.45125008], [68.45375061, 23.45125008], [68.45375061, 23.4509697], [68.45347595, 23.4509716], [68.45347595, 23.45069695], [68.45291901, 23.45070076], [68.45291901, 23.45041084], [68.45097351, 23.45041656], [68.45097351, 23.45013809], [68.45041656, 23.45014], [68.45041656, 23.44985962], [68.44930267, 23.44985962], [68.44930267, 23.45014], [68.44876099, 23.45014], [68.44876099, 23.4493103], [68.44847107, 23.44930077], [68.44847107, 23.44874954], [68.44819641, 23.44874954], [68.44819641, 23.44763947], [68.44790649, 23.44763947], [68.44790649, 23.44734955], [68.44736481, 23.4473629], [68.44736481, 23.44708252], [68.44708252, 23.44708252], [68.44708252, 23.44680405], [68.44680786, 23.44680977], [68.44680786, 23.44652939], [68.44625092, 23.44652939], [68.44625092, 23.44625282], [68.44596863, 23.44625282], [68.44596863, 23.44597054], [68.44513702, 23.44597054], [68.44513702, 23.44652939], [68.44486237, 23.44652939], [68.44486237, 23.44680977], [68.44346619, 23.44680977], [68.44346619, 23.44542122], [68.44403076, 23.44542122], [68.44403076, 23.44458008], [68.44347382, 23.44458389], [68.44347382, 23.44430542], [68.44291687, 23.44431114], [68.44291687, 23.44403267], [68.44235992, 23.44403267], [68.44235992, 23.44375038], [68.44180298, 23.44375038], [68.44180298, 23.44403267], [68.44152832, 23.44403267], [68.44152832, 23.44431114], [68.44097137, 23.44430542], [68.44097137, 23.44458389], [68.44069672, 23.44458008], [68.44069672, 23.44486046], [68.44013977, 23.44486046], [68.44013977, 23.44458008], [68.44041443, 23.44458389], [68.44041443, 23.44402695], [68.44069672, 23.44403267], [68.44069672, 23.44347191], [68.44097137, 23.44347191], [68.44097137, 23.44325066], [68.44097137, 23.44291687], [68.44124603, 23.44292259], [68.44124603, 23.44154167], [68.44097137, 23.44154167], [68.44097137, 23.44096947], [68.44041443, 23.44097137], [68.44041443, 23.44069481], [68.44013977, 23.44069481], [68.44013977, 23.44041634], [68.43985748, 23.44041824], [68.43985748, 23.44013977], [68.43958282, 23.44013977], [68.43958282, 23.4398613], [68.43930817, 23.4398613], [68.43930817, 23.43958282], [68.43902588, 23.43958282], [68.43902588, 23.43930626], [68.43930817, 23.43930817], [68.43930817, 23.43902969], [68.43985748, 23.43902969], [68.43985748, 23.43930817], [68.4404068, 23.43930817], [68.4404068, 23.43902969], [68.44013977, 23.43902969], [68.44013977, 23.43847084], [68.43985748, 23.43847275], [68.43985748, 23.43819427], [68.43958282, 23.43819427], [68.43958282, 23.43791771], [68.43930817, 23.43791962], [68.43930817, 23.43764114], [68.43902588, 23.43764114], [68.43902588, 23.43736076], [68.43875122, 23.43736076], [68.43875122, 23.43625069], [68.43846893, 23.43625069], [68.43846893, 23.43597031], [68.43819427, 23.43597221], [68.43819427, 23.43541718], [68.43791962, 23.43541718], [68.43791962, 23.43569565], [68.43763733, 23.43569565], [68.43763733, 23.43597221], [68.43736267, 23.43597031], [68.43733978, 23.43625069], [68.43708038, 23.43625069], [68.43708038, 23.43653107], [68.43653107, 23.43653107], [68.43653107, 23.43625069], [68.43624878, 23.43625069], [68.43624878, 23.43597031], [68.43597412, 23.43597221], [68.43597412, 23.43541718], [68.43624878, 23.43541718], [68.43624878, 23.43430328], [68.43596649, 23.43431091], [68.43596649, 23.43403053], [68.43569183, 23.43403053], [68.43569183, 23.43375015], [68.43514252, 23.43375015], [68.43514252, 23.43346977], [68.43486023, 23.43347168], [68.43486023, 23.43319321], [68.43152618, 23.43320084], [68.43152618, 23.43375015], [68.43125153, 23.43375015], [68.43125153, 23.43431091], [68.43013763, 23.43431091], [68.43013763, 23.43264008], [68.43041992, 23.43264008], [68.43041992, 23.43124962], [68.42986298, 23.43124962], [68.42986298, 23.43180466], [68.42958069, 23.43180275], [68.42958069, 23.43264008], [68.42930603, 23.43263817], [68.42930603, 23.43347168], [68.42903137, 23.43346977], [68.42903137, 23.43375015], [68.42847443, 23.43375015], [68.42847443, 23.4372406], [68.42847443, 23.43736076], [68.42765045, 23.43736076], [68.42765045, 23.43764114], [68.42708588, 23.43764114], [68.42708588, 23.43791962], [68.42680359, 23.43791771], [68.42680359, 23.43819427], [68.42624664, 23.43819427], [68.42624664, 23.43847275], [68.42597198, 23.43847084], [68.42597198, 23.43875122], [68.42542267, 23.43875122], [68.42542267, 23.43902969], [68.42514038, 23.43902969], [68.42514038, 23.43930817], [68.42458344, 23.43930626], [68.42458344, 23.43958282], [68.42430878, 23.43958282], [68.42430878, 23.4398613], [68.4201355, 23.4398613], [68.42014313, 23.44013977], [68.41874695, 23.44013977], [68.41874695, 23.43985939], [68.41819763, 23.4398613], [68.41819763, 23.43930626], [68.41845703, 23.43930817], [68.41845703, 23.43875122], [68.41874695, 23.43875122], [68.41874695, 23.43819046], [68.41902924, 23.43819427], [68.41902924, 23.43736076], [68.41929626, 23.43736076], [68.41931915, 23.43653107], [68.41958618, 23.43653107], [68.41958618, 23.43597031], [68.41986084, 23.43597221], [68.41986084, 23.43541718], [68.4201355, 23.43541718], [68.4201355, 23.4351387], [68.42041779, 23.43514061], [68.42041779, 23.43486023], [68.42069244, 23.43486023], [68.42069244, 23.43457985], [68.41958618, 23.43458557], [68.41958618, 23.43402863], [68.41986084, 23.43403053], [68.41986084, 23.43375015], [68.42014313, 23.43375015], [68.4201355, 23.43347168], [68.42152405, 23.43347168], [68.42152405, 23.43319321], [68.42430878, 23.43320084], [68.42430878, 23.43375015], [68.42459106, 23.43375015], [68.42459106, 23.43431091], [68.42624664, 23.43431091], [68.42624664, 23.43403053], [68.42682648, 23.43402863], [68.42708588, 23.43403053], [68.42708588, 23.43375015], [68.42765045, 23.43375015], [68.42763519, 23.43347168], [68.42819214, 23.43347168], [68.42819214, 23.43319321], [68.4284668, 23.43320084], [68.4284668, 23.43264008], [68.42874908, 23.43264008], [68.42874908, 23.43153191], [68.42903137, 23.43153191], [68.42903137, 23.43097115], [68.42874908, 23.43097115], [68.42874908, 23.43069458], [68.42791748, 23.43069458], [68.42791748, 23.43041611], [68.42765045, 23.43042183], [68.42765045, 23.43013954], [68.42736053, 23.43013954], [68.42736053, 23.42985916], [68.42708588, 23.42985916], [68.42708588, 23.42958069], [68.42680359, 23.4295826], [68.42680359, 23.42930603], [68.42652893, 23.42931175], [68.42652893, 23.42902946], [68.42624664, 23.42902946], [68.42624664, 23.42874908], [68.42597198, 23.42874908], [68.42597198, 23.42847061], [68.42541504, 23.42847252], [68.42541504, 23.42819405], [68.42514038, 23.42819405], [68.42514038, 23.42708397], [68.42485809, 23.42708397], [68.42485809, 23.4268055], [68.42459106, 23.42681122], [68.42459106, 23.42653084], [68.42402649, 23.42653084], [68.42402649, 23.42624092], [68.42208099, 23.42625046], [68.42208099, 23.42597198], [68.42180634, 23.42597198], [68.42180634, 23.42569351], [68.42152405, 23.42569351], [68.42152405, 23.42541885], [68.42124939, 23.42542076], [68.42124939, 23.42486], [68.42097473, 23.42486191], [68.42097473, 23.42430687], [68.42124939, 23.42431068], [68.42124939, 23.42374992], [68.42151642, 23.42374992], [68.42151642, 23.42346954], [68.42180634, 23.42347145], [68.42180634, 23.42319679], [68.42208099, 23.42319679], [68.42208099, 23.42236137], [68.42180634, 23.42236137], [68.42180634, 23.42180634], [68.42151642, 23.42181015], [68.42151642, 23.42152977], [68.42124939, 23.42152977], [68.42124939, 23.42124939], [68.42151642, 23.42124939], [68.42151642, 23.42069054], [68.42180634, 23.42069244], [68.42180634, 23.42041588], [68.42151642, 23.42043114], [68.42151642, 23.42014122], [68.42124939, 23.42014122], [68.42124939, 23.42043114], [68.42097473, 23.42041588], [68.42097473, 23.42069244], [68.42069244, 23.42069244], [68.42069244, 23.42097473], [68.42041779, 23.42097092], [68.42041779, 23.42124939], [68.42014313, 23.42124939], [68.42014313, 23.42152977], [68.41986084, 23.42152786], [68.41986084, 23.42208481], [68.41958618, 23.42208481], [68.41958618, 23.42236137], [68.41929626, 23.42235947], [68.41929626, 23.42292023], [68.41902924, 23.42291641], [68.41902924, 23.42347145], [68.41874695, 23.42347145], [68.41874695, 23.42486191], [68.41929626, 23.42486], [68.41929626, 23.42514038], [68.41958618, 23.42514038], [68.41958618, 23.42542076], [68.41986084, 23.42541885], [68.41986084, 23.42597198], [68.41958618, 23.42597198], [68.41958618, 23.42621994], [68.41958618, 23.42681122], [68.41986084, 23.42681122], [68.41986084, 23.42931175], [68.41911316, 23.42930603], [68.41680908, 23.42930603], [68.41680908, 23.4295826], [68.41707611, 23.42958069], [68.41707611, 23.42985916], [68.41625214, 23.42985916], [68.41625214, 23.42958069], [68.41596985, 23.4295826], [68.41596985, 23.42930603], [68.41513824, 23.42930603], [68.41513824, 23.4295826], [68.4154129, 23.4295826], [68.4154129, 23.43013954], [68.41571045, 23.43013954], [68.41571045, 23.43042183], [68.41596985, 23.43041611], [68.41596985, 23.43069458], [68.41486359, 23.43069458], [68.41486359, 23.43041611], [68.41430664, 23.43042183], [68.41430664, 23.43013954], [68.41385651, 23.43013954], [68.41374969, 23.43013954], [68.41374969, 23.43069458], [68.41347504, 23.43069458], [68.41348267, 23.43124962], [68.41319275, 23.43124962], [68.41319275, 23.43153191], [68.41291809, 23.43152809], [68.41291809, 23.43208122], [68.41265106, 23.43208122], [68.41265106, 23.43237114], [68.41291809, 23.43237114], [68.41291809, 23.43264008], [68.41319275, 23.43264008], [68.41319275, 23.43320084], [68.41347504, 23.43319321], [68.41347504, 23.43458557], [68.41374969, 23.43458557], [68.41374969, 23.43569565], [68.41347504, 23.43569565], [68.41348267, 23.43625069], [68.41319275, 23.43625069], [68.41319275, 23.43653107], [68.41401672, 23.43653107], [68.41401672, 23.43764114], [68.41374969, 23.43764114], [68.41374969, 23.43791962], [68.41347504, 23.43791771], [68.41347504, 23.43819427], [68.41319275, 23.43819046], [68.41319275, 23.43902969], [68.41291809, 23.43902969], [68.41291809, 23.44013977], [68.41265106, 23.44013977], [68.41265106, 23.44041824], [68.41236115, 23.44041634], [68.41236115, 23.44069481], [68.41208649, 23.44068909], [68.41208649, 23.44124985], [68.41179657, 23.44124985], [68.41179657, 23.44154167], [68.41152954, 23.44152832], [68.41152954, 23.44180489], [68.41208649, 23.44180489], [68.41208649, 23.44347191], [68.4126358, 23.44347191], [68.4126358, 23.44375038], [68.41319275, 23.44375038], [68.41319275, 23.44347191], [68.41347504, 23.44347191], [68.41347504, 23.44319534], [68.41430664, 23.44320107], [68.41430664, 23.44375038], [68.4145813, 23.44375038], [68.4145813, 23.44431114], [68.41530609, 23.44430733], [68.41569519, 23.44430542], [68.41569519, 23.44458389], [68.41625214, 23.44458008], [68.41625214, 23.44486046], [68.41652679, 23.44486046], [68.41652679, 23.44514275], [68.41680908, 23.44514275], [68.41680908, 23.44542122], [68.41708374, 23.4454174], [68.41708374, 23.44597435], [68.41791534, 23.44597435], [68.41791534, 23.44569206], [68.41847229, 23.44569206], [68.41847229, 23.4454174], [68.41874695, 23.44542122], [68.41874695, 23.44514275], [68.41929626, 23.44514275], [68.41929626, 23.44486046], [68.41986084, 23.44486046], [68.41986084, 23.44597435], [68.4201355, 23.44597435], [68.4201355, 23.44569206], [68.42041779, 23.44569206], [68.42041779, 23.4454174], [68.42069244, 23.44542122], [68.42069244, 23.44458008], [68.42124939, 23.44458008], [68.42124939, 23.44486046], [68.42152405, 23.44486046], [68.42152405, 23.44569206], [68.42208099, 23.44569206], [68.42208099, 23.44513893], [68.42236328, 23.44514275], [68.42236328, 23.44431114], [68.42292023, 23.44430542], [68.42292023, 23.44458389], [68.42319489, 23.44458389], [68.42319489, 23.44672966], [68.42319489, 23.4473629], [68.42375183, 23.4473629], [68.42375183, 23.44680405], [68.42402649, 23.44680977], [68.42402649, 23.44625282], [68.42458344, 23.44625282], [68.42458344, 23.44763947], [68.42485809, 23.44763947], [68.42485809, 23.44734955], [68.42514038, 23.4473629], [68.42514038, 23.44680405], [68.42542267, 23.44680977], [68.42542267, 23.44652939], [68.42569733, 23.44652939], [68.42569733, 23.44597054], [68.42597198, 23.44597435], [68.42597198, 23.44569206], [68.42624664, 23.44569206], [68.42624664, 23.44513893], [68.42652893, 23.44514275], [68.42652893, 23.44486046], [68.42679596, 23.44486046], [68.42679596, 23.44431114], [68.42708588, 23.44431114], [68.42708588, 23.44320107], [68.42736053, 23.44320107], [68.42736053, 23.44292259], [68.42791748, 23.44292259], [68.42791748, 23.4426403], [68.4284668, 23.4426403], [68.4284668, 23.44235992], [68.42874908, 23.44236183], [68.42874908, 23.44069481], [68.42903137, 23.44069481], [68.42903137, 23.44041634], [68.42930603, 23.44041824], [68.42930603, 23.44013977], [68.42986298, 23.44013977], [68.42986298, 23.44041824], [68.43004608, 23.44041824], [68.43125153, 23.44041824], [68.43125153, 23.43985939]]], [[[68.48069763, 23.50125122], [68.48069763, 23.50097084], [68.48124695, 23.50097466], [68.48124695, 23.50069237], [68.48180389, 23.50069237], [68.48180389, 23.5004158], [68.48236084, 23.50041962], [68.48236084, 23.50014114], [68.48264313, 23.50014114], [68.48264313, 23.49986076], [68.48291779, 23.49986076], [68.48291779, 23.49930954], [68.48319244, 23.49930954], [68.48319244, 23.49903107], [68.4834671, 23.49903107], [68.4834671, 23.49875069], [68.48374939, 23.49875069], [68.48374939, 23.49819183], [68.48402405, 23.49819374], [68.48402405, 23.49736023], [68.48430634, 23.49736023], [68.48430634, 23.49653244], [68.48458099, 23.49653244], [68.48458099, 23.49625015], [68.48486328, 23.49625015], [68.48486328, 23.49596977], [68.48513794, 23.49597168], [68.48513794, 23.49569511], [68.48542023, 23.49571037], [68.48542023, 23.49541855], [68.48568726, 23.49541855], [68.48568726, 23.4948597], [68.48542023, 23.4948616], [68.48542023, 23.49430466], [68.48513794, 23.49430466], [68.48513794, 23.49291611], [68.48542023, 23.49291992], [68.48542023, 23.49264908], [68.48568726, 23.49264908], [68.48568726, 23.49125099], [68.48542023, 23.49125099], [68.48542023, 23.49069023], [68.48513794, 23.49069595], [68.48513794, 23.48875046], [68.48542023, 23.48875046], [68.48542023, 23.48820114], [68.48568726, 23.4881897], [68.48569489, 23.48763847], [68.48596954, 23.48764038], [68.48596954, 23.48707962], [68.48625183, 23.48708534], [68.48625183, 23.4865284], [68.48652649, 23.4865284], [68.48652649, 23.48624992], [68.48680878, 23.48624992], [68.48680878, 23.48596954], [68.48652649, 23.48597145], [68.48652649, 23.48569489], [68.48625183, 23.48569489], [68.48625183, 23.48541641], [68.48596954, 23.48542023], [68.48596954, 23.48513985], [68.48568726, 23.48513985], [68.48568726, 23.48485947], [68.48542023, 23.48486137], [68.48542023, 23.48430634], [68.48513794, 23.48431015], [68.48513794, 23.4840107], [68.48513794, 23.48347282], [68.48486328, 23.48347282], [68.48486328, 23.48319435], [68.48458099, 23.48319435], [68.48458099, 23.48291588], [68.48430634, 23.4829216], [68.48430634, 23.48263931], [68.48401642, 23.48263931], [68.48401642, 23.48236084], [68.48374939, 23.48236084], [68.48374939, 23.48208046], [68.48347473, 23.48208237], [68.48347473, 23.48152733], [68.48319244, 23.48152924], [68.48319244, 23.48097038], [68.48291779, 23.48097229], [68.48291779, 23.48069382], [68.4826355, 23.48069382], [68.4826355, 23.48041725], [68.48236084, 23.48041916], [68.48236084, 23.47986031], [68.48208618, 23.47986031], [68.48208618, 23.47957993], [68.48180389, 23.47958374], [68.48180389, 23.4790287], [68.48152924, 23.47903061], [68.48152924, 23.47846985], [68.48124695, 23.47847176], [68.48124695, 23.47791672], [68.47957611, 23.47792053], [68.47957611, 23.47820091], [68.47875214, 23.47819519], [68.47875214, 23.47847176], [68.4779129, 23.47846985], [68.4779129, 23.47875023], [68.4770813, 23.47875023], [68.4770813, 23.47903061], [68.47680664, 23.47903061], [68.47680664, 23.47930908], [68.47624969, 23.47930527], [68.47624969, 23.47958374], [68.47597504, 23.47958374], [68.4759903, 23.47986031], [68.47541809, 23.47986031], [68.47541809, 23.48014069], [68.4751358, 23.48014069], [68.4751358, 23.48041916], [68.47458649, 23.48041725], [68.47458649, 23.48069382], [68.4743042, 23.48069382], [68.4743042, 23.48097229], [68.47403717, 23.48097038], [68.47402954, 23.48152924], [68.47374725, 23.48152924], [68.47374725, 23.48181152], [68.47458649, 23.4818058], [68.47458649, 23.48208427], [68.47486115, 23.48208046], [68.47486115, 23.48236084], [68.47541809, 23.48236084], [68.47541809, 23.48263931], [68.47570038, 23.48263931], [68.47570038, 23.4829216], [68.47541809, 23.4829216], [68.47541809, 23.48403168], [68.4751358, 23.48403168], [68.4751358, 23.48513985], [68.47541809, 23.48513985], [68.47541809, 23.48569489], [68.47597504, 23.48569489], [68.47597504, 23.48597145], [68.47624969, 23.48596954], [68.47624969, 23.48624992], [68.4770813, 23.48624992], [68.4770813, 23.48596954], [68.47763824, 23.48597145], [68.47763824, 23.48569489], [68.4798584, 23.48569107], [68.4798584, 23.48624992], [68.48097229, 23.48624992], [68.48097229, 23.4865284], [68.48124695, 23.4865284], [68.48124695, 23.48624992], [68.48152924, 23.48624992], [68.48152924, 23.48596954], [68.48180389, 23.48597145], [68.48180389, 23.48569489], [68.48208618, 23.48569489], [68.48208618, 23.48541641], [68.48374939, 23.48542023], [68.48374939, 23.48513985], [68.48458099, 23.48513985], [68.48458099, 23.48569489], [68.48486328, 23.48569107], [68.48486328, 23.48624992], [68.48513794, 23.48624992], [68.48513794, 23.48764038], [68.48486328, 23.48763847], [68.48486328, 23.48819542], [68.48458099, 23.4881897], [68.48458099, 23.48903084], [68.48430634, 23.48902512], [68.48430634, 23.49069595], [68.48401642, 23.49069023], [68.48401642, 23.49125099], [68.48374939, 23.49125099], [68.48374939, 23.49152946], [68.48264313, 23.49152946], [68.48264313, 23.49041939], [68.48236084, 23.49041939], [68.48236084, 23.48986053], [68.48208618, 23.48986053], [68.48208618, 23.48931122], [68.48179626, 23.48931122], [68.48179626, 23.48903084], [68.48097229, 23.48903084], [68.48097229, 23.48875046], [68.47763824, 23.48875046], [68.47763824, 23.48847008], [68.47680664, 23.48847389], [68.47680664, 23.48791695], [68.47651672, 23.48792076], [68.47651672, 23.48736], [68.47624969, 23.48736382], [68.47624969, 23.48708534], [68.47569275, 23.48708534], [68.47569275, 23.48680305], [68.4751358, 23.48681068], [68.4751358, 23.48652267], [68.47486115, 23.48652267], [68.47486115, 23.48681068], [68.47458649, 23.48680305], [68.47458649, 23.48736382], [68.4743042, 23.48736382], [68.4743042, 23.48847389], [68.47458649, 23.48847008], [68.47458649, 23.48903084], [68.47486115, 23.48903084], [68.47486115, 23.48986053], [68.47429657, 23.48986053], [68.47429657, 23.48958969], [68.47402954, 23.48958969], [68.47402954, 23.49236107], [68.47374725, 23.49236107], [68.47374725, 23.49264908], [68.4734726, 23.49263954], [68.4734726, 23.49319458], [68.47319794, 23.49319077], [68.47319794, 23.49374962], [68.47292328, 23.49374962], [68.47292328, 23.49402809], [68.47319794, 23.49402809], [68.47319794, 23.4948616], [68.4734726, 23.4948597], [68.4734726, 23.49625015], [68.47374725, 23.49625015], [68.47374725, 23.49596977], [68.47402954, 23.49597168], [68.47402954, 23.49569511], [68.47429657, 23.49571037], [68.47429657, 23.49541855], [68.47458649, 23.49541855], [68.47458649, 23.49513817], [68.4751358, 23.49513817], [68.4751358, 23.4948597], [68.47680664, 23.4948616], [68.47680664, 23.49458313], [68.4770813, 23.49458313], [68.4770813, 23.49347305], [68.47736359, 23.49347305], [68.47736359, 23.49291611], [68.47763824, 23.49291992], [68.47763824, 23.49236107], [68.47846985, 23.49236107], [68.47846985, 23.49208069], [68.47902679, 23.4920826], [68.47902679, 23.49180794], [68.4798584, 23.49180984], [68.4798584, 23.49152946], [68.48152924, 23.49152946], [68.48152924, 23.49180984], [68.48124695, 23.49180984], [68.48124695, 23.49236107], [68.48152924, 23.49236107], [68.48152924, 23.49291992], [68.48180389, 23.49291611], [68.48180389, 23.49347305], [68.48208618, 23.49347115], [68.48208618, 23.49402809], [68.48236084, 23.49402809], [68.48236084, 23.49541855], [68.48124695, 23.49541855], [68.48124695, 23.49571037], [68.48069763, 23.49569511], [68.48069763, 23.49597168], [68.48014069, 23.49596977], [68.48014069, 23.49625015], [68.47930908, 23.49625015], [68.47930908, 23.49653244], [68.47875977, 23.49653244], [68.47875977, 23.49681282], [68.47846985, 23.49681282], [68.47846985, 23.49736023], [68.47875977, 23.49736023], [68.47875977, 23.4979229], [68.47846985, 23.49791718], [68.47846985, 23.49819374], [68.47819519, 23.49819374], [68.47819519, 23.49875069], [68.47846985, 23.49875069], [68.47846985, 23.49903107], [68.47875977, 23.49903107], [68.47875977, 23.49930954], [68.4798584, 23.49930573], [68.4798584, 23.49958229], [68.48014069, 23.49958038], [68.48014069, 23.50041962], [68.48042297, 23.50041962], [68.48042297, 23.50125122], [68.48069763, 23.50125122]]], [[[68.48680878, 23.49541855], [68.48680878, 23.49513817], [68.48707581, 23.49513817], [68.48707581, 23.4948597], [68.48735809, 23.4948616], [68.48735809, 23.49458313], [68.48764038, 23.49458313], [68.48764038, 23.49402809], [68.4879303, 23.49402809], [68.4879303, 23.49319077], [68.48764038, 23.49319458], [68.48764038, 23.49236107], [68.48847198, 23.49236107], [68.48847198, 23.49291992], [68.48874664, 23.49291611], [68.48874664, 23.49319458], [68.48902893, 23.49319458], [68.48902893, 23.49347305], [68.48929596, 23.49347115], [68.48929596, 23.49374962], [68.48958588, 23.49374962], [68.48958588, 23.49180984], [68.48929596, 23.49180984], [68.48929596, 23.49097061], [68.48902893, 23.49097252], [68.48902893, 23.49013901], [68.48874664, 23.49014091], [68.48874664, 23.48931122], [68.48847198, 23.48931122], [68.48847198, 23.4881897], [68.48819733, 23.48819542], [68.48819733, 23.48736382], [68.48791504, 23.48736382], [68.48791504, 23.48680305], [68.48764038, 23.48681068], [68.48764038, 23.48652267], [68.48708344, 23.4865284], [68.48708344, 23.48736382], [68.48680878, 23.48736], [68.48680878, 23.48764038], [68.48652649, 23.48763847], [68.48652649, 23.48847389], [68.48625183, 23.48847008], [68.48625183, 23.48903084], [68.48596954, 23.48903084], [68.48596954, 23.49041939], [68.48625183, 23.49041748], [68.48625183, 23.49097252], [68.48652649, 23.49097061], [68.48652649, 23.49264908], [68.48625183, 23.49263954], [68.48625183, 23.49319458], [68.48596954, 23.49319077], [68.48596954, 23.49402809], [68.48625183, 23.49402809], [68.48625183, 23.4948616], [68.48652649, 23.4948597], [68.48652649, 23.49541855], [68.48680878, 23.49541855]]], [[[68.50653076, 23.49264908], [68.50653076, 23.49236107], [68.50736237, 23.49236107], [68.50736237, 23.49208069], [68.50763702, 23.4920826], [68.50763702, 23.49180794], [68.50791931, 23.49180984], [68.50791931, 23.49152946], [68.50818634, 23.49152946], [68.50818634, 23.49125099], [68.50846863, 23.49125099], [68.50846863, 23.49097061], [68.50875092, 23.49097252], [68.50875092, 23.49069595], [68.50902557, 23.49069595], [68.50902557, 23.49041748], [68.50680542, 23.49041748], [68.50680542, 23.49097252], [68.50653076, 23.49097061], [68.50653076, 23.49125099], [68.50624847, 23.49124908], [68.50624847, 23.4920826], [68.50596619, 23.49208069], [68.50596619, 23.49264908], [68.50653076, 23.49264908]]], [[[68.51097107, 23.49264908], [68.51097107, 23.49236107], [68.51152802, 23.49236107], [68.51152802, 23.49125099], [68.51125336, 23.49125099], [68.51125336, 23.49069023], [68.51069641, 23.49069595], [68.51069641, 23.49097252], [68.51013947, 23.49097061], [68.51013947, 23.49152946], [68.50985718, 23.49152946], [68.50985718, 23.49180984], [68.50958252, 23.49180794], [68.50958252, 23.4920826], [68.50930786, 23.49208069], [68.50930786, 23.49264908], [68.51097107, 23.49264908]]], [[[68.4751358, 23.52876091], [68.4751358, 23.52847099], [68.47597504, 23.52847481], [68.47597504, 23.52791405], [68.47624969, 23.52791977], [68.47624969, 23.52763939], [68.47541809, 23.52763939], [68.47541809, 23.52736092], [68.47486115, 23.52736092], [68.47486115, 23.52708054], [68.47458649, 23.52708244], [68.47458649, 23.52680588], [68.47429657, 23.52680969], [68.47429657, 23.52653122], [68.47402954, 23.52653122], [68.47402954, 23.52625275], [68.47429657, 23.52625275], [68.47429657, 23.52597046], [68.47402954, 23.52597237], [68.47402954, 23.52541733], [68.47429657, 23.52542114], [68.47429657, 23.52403259], [68.47458649, 23.52403259], [68.47458649, 23.52207756], [68.47374725, 23.52208328], [68.47374725, 23.52152824], [68.4734726, 23.52152824], [68.4734726, 23.52180481], [68.47319794, 23.52180481], [68.47319794, 23.52208328], [68.47264099, 23.52208328], [68.47264099, 23.52124977], [68.47207642, 23.52124977], [68.47207642, 23.52096748], [68.47180939, 23.5209713], [68.47180176, 23.52069473], [68.4715271, 23.52069092], [68.4715271, 23.52152824], [68.47125244, 23.52152824], [68.47125244, 23.52180481], [68.47097015, 23.52180481], [68.47097015, 23.52208328], [68.4706955, 23.52208328], [68.4706955, 23.52236176], [68.46986389, 23.52236176], [68.46986389, 23.52263832], [68.46956635, 23.52263069], [68.46956635, 23.52292252], [68.46930695, 23.52292252], [68.46930695, 23.5232029], [68.46901703, 23.5232029], [68.46901703, 23.52403259], [68.46875, 23.52402687], [68.46875, 23.52458382], [68.4695816, 23.52458382], [68.4695816, 23.52430534], [68.46985626, 23.52431107], [68.46985626, 23.52403259], [68.47041321, 23.52402687], [68.47041321, 23.52458382], [68.46986389, 23.52458382], [68.46986389, 23.52569389], [68.47013855, 23.52569008], [68.47013855, 23.52625275], [68.47041321, 23.52625275], [68.47041321, 23.52680969], [68.4706955, 23.52680588], [68.4706955, 23.52708244], [68.47180176, 23.52708244], [68.47180939, 23.5265274], [68.47207642, 23.52653122], [68.47207642, 23.52625275], [68.47264099, 23.52625275], [68.47264099, 23.52736092], [68.4723587, 23.52736092], [68.4723587, 23.52763939], [68.47207642, 23.52763939], [68.47207642, 23.52791977], [68.47180176, 23.52791405], [68.47180176, 23.52847481], [68.4723587, 23.52847099], [68.4723587, 23.52876091], [68.4751358, 23.52876091]]], [[[68.4734726, 23.53708267], [68.4734726, 23.53652763], [68.47374725, 23.53652954], [68.47374725, 23.53624916], [68.47402954, 23.53624916], [68.47402954, 23.53597069], [68.4743042, 23.5359726], [68.4743042, 23.53513908], [68.47458649, 23.53513908], [68.47458649, 23.53457069], [68.47486115, 23.53458405], [68.47486115, 23.53430557], [68.4751358, 23.53430748], [68.4751358, 23.53403091], [68.47486115, 23.53403091], [68.47486115, 23.53292084], [68.47569275, 23.53291893], [68.47569275, 23.53319359], [68.47624969, 23.53319359], [68.47624969, 23.53291893], [68.47651672, 23.53292084], [68.47651672, 23.5320797], [68.47624969, 23.53208351], [68.47624969, 23.53180695], [68.4759903, 23.53181839], [68.4759903, 23.53153038], [68.47570038, 23.53153038], [68.47570038, 23.53096962], [68.4751358, 23.53097153], [68.4751358, 23.53069687], [68.47486115, 23.53070068], [68.47486115, 23.5304203], [68.47319794, 23.5304203], [68.47319794, 23.53070068], [68.47291565, 23.53069687], [68.47291565, 23.53097153], [68.47207642, 23.53096962], [68.47207642, 23.53125], [68.4723587, 23.53125], [68.4723587, 23.53181839], [68.47264099, 23.53180695], [68.47264099, 23.53236198], [68.47319794, 23.53236008], [68.47319794, 23.53264046], [68.4734726, 23.53264046], [68.4734726, 23.53292084], [68.47319794, 23.53291893], [68.47319794, 23.53319359], [68.47207642, 23.53318977], [68.47207642, 23.53375053], [68.47180176, 23.53375053], [68.47180176, 23.53458405], [68.47208405, 23.53458405], [68.47208405, 23.53569412], [68.47180176, 23.5356884], [68.47180176, 23.53624916], [68.47264099, 23.53624916], [68.47264099, 23.53652954], [68.47291565, 23.53652763], [68.47291565, 23.53708267], [68.4734726, 23.53708267]]], [[[68.47930908, 23.55541992], [68.47930908, 23.55486107], [68.47957611, 23.55486107], [68.47957611, 23.55430984], [68.4798584, 23.55430984], [68.4798584, 23.5537529], [68.48069763, 23.5537529], [68.48069763, 23.55402946], [68.48097229, 23.55402946], [68.48097229, 23.5537529], [68.48124695, 23.5537529], [68.48124695, 23.55347061], [68.48152924, 23.55347443], [68.48152924, 23.55125046], [68.48124695, 23.55125046], [68.48124695, 23.55014038], [68.48097229, 23.55014038], [68.48097229, 23.54931259], [68.47930908, 23.54931259], [68.47930908, 23.54791832], [68.4798584, 23.54791832], [68.4798584, 23.54597092], [68.48014069, 23.54597282], [68.48014069, 23.54513931], [68.47902679, 23.54514122], [68.47902679, 23.54458046], [68.47875214, 23.54458237], [68.47875214, 23.54347229], [68.47846985, 23.54347229], [68.47846985, 23.54291725], [68.47763824, 23.54291725], [68.47763824, 23.54319572], [68.4770813, 23.54319572], [68.4770813, 23.54347229], [68.47624969, 23.54347229], [68.47624969, 23.54291725], [68.47651672, 23.54292107], [68.47651672, 23.54236031], [68.47680664, 23.54236031], [68.47680664, 23.54207993], [68.4770813, 23.54208565], [68.4770813, 23.54180336], [68.47735596, 23.54181099], [68.47735596, 23.54096985], [68.47680664, 23.54097176], [68.47680664, 23.54041672], [68.47651672, 23.54042053], [68.47651672, 23.53985977], [68.47624969, 23.53986359], [68.47624969, 23.53930473], [68.47597504, 23.53930473], [68.47597504, 23.53902817], [68.47570038, 23.53903008], [68.47570038, 23.53874969], [68.47541809, 23.53874969], [68.47541809, 23.53847122], [68.47486115, 23.53847122], [68.47486115, 23.53819466], [68.4743042, 23.53819466], [68.4743042, 23.53791618], [68.47402954, 23.53791618], [68.47402954, 23.53819466], [68.47374725, 23.53819466], [68.47374725, 23.53847122], [68.47264099, 23.53847122], [68.47264099, 23.53819466], [68.47208405, 23.53819466], [68.47208405, 23.53847122], [68.47180176, 23.53847122], [68.47180176, 23.53874969], [68.4706955, 23.53874969], [68.4706955, 23.53847122], [68.47041321, 23.53847122], [68.47041321, 23.53874969], [68.46956635, 23.53874969], [68.46956635, 23.53819275], [68.46902466, 23.53819466], [68.46902466, 23.53791618], [68.46875, 23.53792191], [68.46875, 23.53762817], [68.46819305, 23.53763962], [68.46819305, 23.53735924], [68.46763611, 23.53735924], [68.46763611, 23.53708076], [68.46736145, 23.53708267], [68.46736145, 23.53680611], [68.46708679, 23.53681183], [68.46708679, 23.53652954], [68.46652985, 23.53652954], [68.46652985, 23.53624916], [68.4659729, 23.53624916], [68.4659729, 23.53597069], [68.46569824, 23.5359726], [68.46569824, 23.53569412], [68.4651413, 23.53569412], [68.4651413, 23.53513908], [68.46457672, 23.53513908], [68.46457672, 23.53541946], [68.46430206, 23.53541756], [68.46430206, 23.5359726], [68.46375275, 23.5359726], [68.46375275, 23.53541756], [68.46347046, 23.53541946], [68.46347046, 23.53513908], [68.46290588, 23.53513908], [68.46290588, 23.53486061], [68.46263885, 23.53486061], [68.46263885, 23.53430748], [68.46290588, 23.53430748], [68.46290588, 23.53375053], [68.46263885, 23.53375053], [68.46263885, 23.53347015], [68.4623642, 23.53347206], [68.4623642, 23.53319359], [68.46180725, 23.53319359], [68.46180725, 23.53263855], [68.46125031, 23.53264046], [68.46125031, 23.53236008], [68.46097565, 23.53236198], [68.46097565, 23.53208351], [68.4604187, 23.53208351], [68.4604187, 23.53152847], [68.45986176, 23.53153038], [68.45986176, 23.53125], [68.4595871, 23.53125], [68.4595871, 23.53096962], [68.45903015, 23.53097153], [68.45903015, 23.53069687], [68.45874786, 23.53069687], [68.45874786, 23.53097153], [68.45819092, 23.53097153], [68.45819092, 23.53069687], [68.45680237, 23.53070068], [68.45680237, 23.53013992], [68.45652771, 23.53013992], [68.45652771, 23.5304203], [68.45597076, 23.5304203], [68.45597076, 23.53013992], [68.45485687, 23.53013992], [68.45485687, 23.52985954], [68.45458221, 23.52986145], [68.45458221, 23.52958488], [68.45430756, 23.52958488], [68.45430756, 23.52930641], [68.45375061, 23.52931023], [68.45375061, 23.52876091], [68.45319366, 23.52874947], [68.45319366, 23.52986145], [68.45347595, 23.52985954], [68.45347595, 23.5304203], [68.45375061, 23.5304203], [68.45375061, 23.53070068], [68.45402527, 23.53069687], [68.45402527, 23.53125], [68.45458221, 23.53125], [68.45456696, 23.53096962], [68.45625305, 23.53096962], [68.45625305, 23.53153038], [68.45707703, 23.53153038], [68.45707703, 23.53181839], [68.45735931, 23.53180695], [68.45735931, 23.53208351], [68.45762634, 23.5320797], [68.45762634, 23.53292084], [68.45735931, 23.53291893], [68.45735931, 23.53347206], [68.45762634, 23.53347015], [68.45762634, 23.53403091], [68.45819092, 23.53403091], [68.45819092, 23.5320797], [68.45874786, 23.53208351], [68.45874786, 23.53236198], [68.45903015, 23.53236008], [68.45903015, 23.53264046], [68.45929718, 23.53264046], [68.45929718, 23.53292084], [68.4595871, 23.53292084], [68.4595871, 23.53236008], [68.46013641, 23.53236008], [68.46013641, 23.53292084], [68.4604187, 23.53291893], [68.4604187, 23.53347206], [68.46013641, 23.53347206], [68.46013641, 23.53458405], [68.46069336, 23.53458405], [68.46069336, 23.5340271], [68.46098328, 23.53403091], [68.46098328, 23.53375053], [68.46180725, 23.53375053], [68.46180725, 23.53458405], [68.46153259, 23.53457069], [68.46153259, 23.53513908], [68.46098328, 23.53513908], [68.46098328, 23.53541946], [68.4604187, 23.53541756], [68.4604187, 23.53569412], [68.4595871, 23.53569412], [68.4595871, 23.5359726], [68.45929718, 23.53597069], [68.45929718, 23.53624916], [68.45903015, 23.53624916], [68.45903015, 23.53681183], [68.45819092, 23.53681183], [68.45819092, 23.53652954], [68.45762634, 23.53652954], [68.45762634, 23.53624916], [68.45680237, 23.53624916], [68.45680237, 23.53597069], [68.45597076, 23.5359726], [68.45597076, 23.53569412], [68.4548645, 23.53569412], [68.4548645, 23.53541756], [68.45458221, 23.53541756], [68.45458221, 23.53569412], [68.45430756, 23.5356884], [68.45430756, 23.53624916], [68.4540329, 23.53624916], [68.4540329, 23.53652954], [68.45375061, 23.53652954], [68.45375061, 23.53681183], [68.45347595, 23.53681183], [68.45347595, 23.53792191], [68.45456696, 23.53792191], [68.45456696, 23.53762817], [68.4548645, 23.53763962], [68.4548645, 23.53735924], [68.45513916, 23.53735924], [68.45513916, 23.53708076], [68.45652771, 23.53708076], [68.45652771, 23.53735924], [68.45708466, 23.53735924], [68.45708466, 23.53763962], [68.45735931, 23.53763962], [68.45735931, 23.53819466], [68.4576416, 23.53819466], [68.4576416, 23.5395813], [68.45847321, 23.5395813], [68.45847321, 23.53986359], [68.45874786, 23.53985977], [68.45874786, 23.54014015], [68.45903015, 23.54014015], [68.45903015, 23.54042053], [68.45791626, 23.54042053], [68.45791626, 23.54070091], [68.45735931, 23.54070091], [68.45735931, 23.54125023], [68.45708466, 23.54125023], [68.45708466, 23.54208565], [68.45735931, 23.54207993], [68.45735931, 23.54264069], [68.45791626, 23.54264069], [68.45791626, 23.54292107], [68.45903015, 23.54291725], [68.45903015, 23.54319572], [68.4595871, 23.54319572], [68.4595871, 23.54347229], [68.46013641, 23.54347038], [68.46013641, 23.5437603], [68.4604187, 23.5437603], [68.4604187, 23.54403114], [68.46098328, 23.54403114], [68.46098328, 23.54430962], [68.46125031, 23.54430771], [68.46125031, 23.54458427], [68.46180725, 23.54458046], [68.46180725, 23.54486084], [68.46235657, 23.54486084], [68.46235657, 23.54514122], [68.46290588, 23.54514122], [68.46290588, 23.54541969], [68.46347046, 23.54541779], [68.46347046, 23.54569435], [68.46430206, 23.54569435], [68.46430206, 23.54597282], [68.46457672, 23.54597092], [68.46457672, 23.54652977], [68.46485901, 23.54652977], [68.46485901, 23.54680634], [68.4651413, 23.54680634], [68.4651413, 23.5470829], [68.46569061, 23.5470829], [68.46569824, 23.54736137], [68.4659729, 23.54735947], [68.4659729, 23.54763985], [68.46652985, 23.54763985], [68.46652985, 23.54791832], [68.4668045, 23.54791641], [68.4668045, 23.54819489], [68.46736145, 23.54819489], [68.46736145, 23.54847145], [68.4679184, 23.54846954], [68.4679184, 23.54874992], [68.46875, 23.54874992], [68.46875, 23.54846954], [68.46956635, 23.54846954], [68.46956635, 23.5490284], [68.46930695, 23.5490284], [68.46930695, 23.55014038], [68.4695816, 23.55013847], [68.46956635, 23.5506916], [68.46985626, 23.55070114], [68.46985626, 23.55125046], [68.47013855, 23.55125046], [68.47013855, 23.55236053], [68.47041321, 23.55236053], [68.47041321, 23.55347443], [68.4715271, 23.55347061], [68.4715271, 23.5537529], [68.47319794, 23.5537529], [68.47319794, 23.55402946], [68.47374725, 23.55402946], [68.47374725, 23.55430984], [68.47458649, 23.55430412], [68.47458649, 23.5545826], [68.47541809, 23.55458069], [68.47541809, 23.55486107], [68.4759903, 23.55486107], [68.47597504, 23.5545826], [68.4770813, 23.55458069], [68.4770813, 23.55486107], [68.47763824, 23.55486107], [68.47763824, 23.55513954], [68.47875977, 23.55513954], [68.47875977, 23.55541992], [68.47930908, 23.55541992]]], [[[68.48236084, 23.55042267], [68.48236084, 23.54986191], [68.4826355, 23.54986191], [68.4826355, 23.54958344], [68.48291779, 23.54958344], [68.48291779, 23.54930496], [68.48319244, 23.54931259], [68.48319244, 23.54874992], [68.48291779, 23.54874992], [68.48291779, 23.54735947], [68.4826355, 23.54736137], [68.4826355, 23.5470829], [68.48208618, 23.5470829], [68.48208618, 23.54736137], [68.48180389, 23.54736137], [68.48180389, 23.54819489], [68.48152924, 23.54818916], [68.48152924, 23.54874992], [68.48180389, 23.54874992], [68.48180389, 23.54958344], [68.48208618, 23.54956818], [68.48208618, 23.55042267], [68.48236084, 23.55042267]]], [[[68.4734726, 23.56292152], [68.4734726, 23.56236076], [68.47374725, 23.56236076], [68.47374725, 23.5617981], [68.47402954, 23.56180573], [68.47402954, 23.56152725], [68.47429657, 23.56152916], [68.47429657, 23.56041908], [68.47458649, 23.56041908], [68.47458649, 23.55931091], [68.47429657, 23.55931091], [68.47429657, 23.55874062], [68.47402954, 23.55875015], [68.47402954, 23.55819511], [68.47374725, 23.55820084], [68.47374725, 23.55792046], [68.47319794, 23.55792046], [68.47319794, 23.55764008], [68.47125244, 23.55764008], [68.47125244, 23.55792046], [68.47097015, 23.55792046], [68.47097015, 23.55820084], [68.46875, 23.55820084], [68.46875, 23.55708122], [68.46902466, 23.55708313], [68.46902466, 23.55652809], [68.47070313, 23.55653], [68.47070313, 23.55624962], [68.47125244, 23.55624962], [68.47125244, 23.5557003], [68.47097015, 23.5557003], [68.47097015, 23.55541992], [68.47070313, 23.55541992], [68.47070313, 23.55513954], [68.47013855, 23.55513954], [68.47013855, 23.55486107], [68.46956635, 23.55486107], [68.46956635, 23.55458069], [68.46930695, 23.5545826], [68.46930695, 23.55430412], [68.46901703, 23.55430984], [68.46901703, 23.55402946], [68.46875, 23.55402946], [68.46875, 23.5537529], [68.46848297, 23.5537529], [68.46848297, 23.55319023], [68.46819305, 23.55319214], [68.46819305, 23.55291748], [68.46763611, 23.55293083], [68.46763611, 23.55264282], [68.46736145, 23.55264282], [68.46736145, 23.55236053], [68.46679688, 23.55236053], [68.46679688, 23.55208015], [68.46652985, 23.55208206], [68.46652985, 23.5518055], [68.46624756, 23.55181122], [68.46624756, 23.55153275], [68.46541595, 23.55153275], [68.46541595, 23.55125046], [68.46485901, 23.55125046], [68.46485901, 23.55097008], [68.46430206, 23.55097008], [68.46430206, 23.55069351], [68.46347046, 23.55069351], [68.46347046, 23.55097008], [68.4631958, 23.55097008], [68.4631958, 23.5537529], [68.46290588, 23.5537529], [68.46290588, 23.55402946], [68.46180725, 23.55402946], [68.46180725, 23.55236053], [68.46208191, 23.55236053], [68.46208191, 23.55125046], [68.46097565, 23.55125046], [68.46097565, 23.55097008], [68.46125031, 23.55097008], [68.46125031, 23.55041695], [68.46153259, 23.55042267], [68.46153259, 23.54986191], [68.46125031, 23.54986191], [68.46125031, 23.54930496], [68.46098328, 23.54931259], [68.46098328, 23.5490284], [68.46070099, 23.5490284], [68.46070099, 23.54874992], [68.46013641, 23.54874992], [68.46013641, 23.54846954], [68.45986176, 23.54847145], [68.45986176, 23.54819489], [68.4595871, 23.54819489], [68.4595871, 23.54791641], [68.45903015, 23.54791832], [68.45903015, 23.54763985], [68.45819092, 23.54763985], [68.45819092, 23.54735947], [68.4576416, 23.54736137], [68.4576416, 23.5470829], [68.45708466, 23.5470829], [68.45708466, 23.54680634], [68.45680237, 23.54680634], [68.45680237, 23.54652977], [68.45625305, 23.54652977], [68.45625305, 23.54624939], [68.45569611, 23.54624939], [68.45569611, 23.54597092], [68.4548645, 23.54597282], [68.4548645, 23.54569435], [68.45430756, 23.54569435], [68.45430756, 23.54541779], [68.4540329, 23.54541969], [68.4540329, 23.54514122], [68.45375061, 23.54514122], [68.45375061, 23.54486084], [68.45347595, 23.54486084], [68.45347595, 23.54458046], [68.45319366, 23.54458237], [68.45319366, 23.54430771], [68.45291901, 23.54430962], [68.45291901, 23.54403114], [68.45263672, 23.54403114], [68.45263672, 23.54347038], [68.45236206, 23.54347229], [68.45236206, 23.54319572], [68.45207977, 23.54319572], [68.45207977, 23.54291725], [68.45153046, 23.54292107], [68.45153046, 23.54264069], [68.45096588, 23.54264069], [68.45096588, 23.54236031], [68.45014191, 23.54236031], [68.45014191, 23.54207993], [68.44958496, 23.54208565], [68.44958496, 23.54180336], [68.44902802, 23.54181099], [68.44902802, 23.54153061], [68.44847107, 23.54153061], [68.44847107, 23.54125023], [68.44819641, 23.54125023], [68.44819641, 23.54096985], [68.44791412, 23.54097176], [68.44791412, 23.54069328], [68.44735718, 23.54070091], [68.44735718, 23.54042053], [68.44625092, 23.54042053], [68.44625092, 23.54014015], [68.44596863, 23.54014015], [68.44596863, 23.53957939], [68.44569397, 23.5395813], [68.44569397, 23.53902817], [68.44541931, 23.53903008], [68.44541931, 23.53847122], [68.44513702, 23.53847122], [68.44513702, 23.53819466], [68.44486237, 23.53819466], [68.44486237, 23.53791618], [68.44458008, 23.53792191], [68.44458008, 23.53762817], [68.44430542, 23.53763962], [68.44430542, 23.53735924], [68.44403076, 23.53735924], [68.44403076, 23.53708076], [68.44374847, 23.53708267], [68.44374847, 23.53680611], [68.44346619, 23.53681183], [68.44346619, 23.53624916], [68.44319153, 23.53624916], [68.44319153, 23.53597069], [68.44291687, 23.5359726], [68.44291687, 23.53569412], [68.44264221, 23.53569412], [68.44264221, 23.53513908], [68.44235992, 23.53513908], [68.44235992, 23.53486061], [68.44208527, 23.53486061], [68.44208527, 23.5340271], [68.44180298, 23.53403091], [68.44180298, 23.53292084], [68.44152832, 23.53292084], [68.44152832, 23.53236008], [68.44125366, 23.53236198], [68.44125366, 23.53152847], [68.44097137, 23.53153038], [68.44097137, 23.53096962], [68.44069672, 23.53097153], [68.44069672, 23.53013611], [68.4404068, 23.53013992], [68.4404068, 23.52931023], [68.44013977, 23.52931023], [68.44013977, 23.52876091], [68.43985748, 23.52876091], [68.43985748, 23.52847099], [68.43902588, 23.52847481], [68.43902588, 23.52819252], [68.43930817, 23.52819252], [68.43930817, 23.52791405], [68.43959045, 23.52791977], [68.43959045, 23.52736092], [68.43985748, 23.52736092], [68.43985748, 23.52653122], [68.43959045, 23.52653122], [68.43959045, 23.52597046], [68.43930817, 23.52597237], [68.43930817, 23.52569389], [68.43902588, 23.52569389], [68.43902588, 23.52541733], [68.43875122, 23.52542114], [68.43875122, 23.52514267], [68.43846893, 23.52514267], [68.43846893, 23.52486038], [68.43736267, 23.52486038], [68.43736267, 23.52458191], [68.43791962, 23.52458382], [68.43791962, 23.52402687], [68.43818665, 23.52403259], [68.43818665, 23.52375031], [68.43791962, 23.52375031], [68.43791962, 23.52347183], [68.43763733, 23.52347183], [68.43763733, 23.52319527], [68.43514252, 23.5232029], [68.43514252, 23.52235985], [68.43486023, 23.52236176], [68.43486023, 23.52263832], [68.4345932, 23.52263069], [68.4345932, 23.52292252], [68.43430328, 23.52292252], [68.43430328, 23.5232029], [68.43345642, 23.5232029], [68.43345642, 23.52292252], [68.43374634, 23.52292252], [68.43374634, 23.52235985], [68.43402863, 23.52236176], [68.43402863, 23.52180481], [68.43430328, 23.52180481], [68.43430328, 23.52124977], [68.43402863, 23.52124977], [68.43402863, 23.52096748], [68.43347168, 23.5209713], [68.43347168, 23.52041626], [68.43374634, 23.52041817], [68.43374634, 23.51902962], [68.43345642, 23.51902962], [68.43345642, 23.51653099], [68.43319702, 23.51653099], [68.43319702, 23.51542091], [68.4329071, 23.51542091], [68.4329071, 23.51320076], [68.43264008, 23.51320076], [68.43264008, 23.50765038], [68.43235779, 23.50765038], [68.43235779, 23.50791931], [68.43125153, 23.50791931], [68.43125153, 23.50765038], [68.43078613, 23.50765038], [68.43041992, 23.50765038], [68.43041992, 23.50791931], [68.43013763, 23.5079174], [68.43013763, 23.50819397], [68.42986298, 23.50819397], [68.42986298, 23.50847244], [68.42958069, 23.50847244], [68.42958069, 23.50958252], [68.42930603, 23.50958061], [68.42930603, 23.51013947], [68.42903137, 23.51013947], [68.42903137, 23.5106945], [68.42874908, 23.5106945], [68.42874908, 23.5134716], [68.42903137, 23.5134697], [68.42903137, 23.51486015], [68.42874908, 23.51486015], [68.42874908, 23.51542091], [68.42903137, 23.5154171], [68.42903137, 23.51569557], [68.42930603, 23.51569557], [68.42930603, 23.51597214], [68.42958069, 23.51597023], [68.42958069, 23.51625061], [68.42930603, 23.51625061], [68.42930603, 23.51653099], [68.42958069, 23.51653099], [68.42958069, 23.51682091], [68.42986298, 23.51682091], [68.42986298, 23.51736069], [68.43013763, 23.51736069], [68.43013763, 23.51875114], [68.43041992, 23.51875114], [68.43041992, 23.51930809], [68.43069458, 23.51930618], [68.43069458, 23.51958275], [68.43096924, 23.5195694], [68.43096924, 23.51986122], [68.43125153, 23.51986122], [68.43125153, 23.52013969], [68.43152618, 23.52013969], [68.43152618, 23.52041817], [68.43180847, 23.52041817], [68.43180847, 23.52124977], [68.43152618, 23.52124977], [68.43152618, 23.52152824], [68.43069458, 23.52152824], [68.43069458, 23.52180481], [68.43041992, 23.52180481], [68.43041992, 23.52208328], [68.43013763, 23.52208328], [68.43013763, 23.52236176], [68.42986298, 23.52236176], [68.42986298, 23.52263832], [68.42958069, 23.52263069], [68.42958069, 23.52292252], [68.42930603, 23.52291679], [68.42930603, 23.52347183], [68.42958069, 23.52347183], [68.42958069, 23.52403259], [68.43041992, 23.52402687], [68.43041992, 23.52569389], [68.43068695, 23.52569008], [68.43068695, 23.52680969], [68.43096924, 23.52680969], [68.43096924, 23.52931023], [68.43125153, 23.52930641], [68.43125153, 23.52958488], [68.43152618, 23.52958488], [68.43152618, 23.52986145], [68.43180847, 23.52985954], [68.43180847, 23.53013992], [68.43208313, 23.53013992], [68.43208313, 23.5304203], [68.43152618, 23.5304203], [68.43152618, 23.53070068], [68.43125153, 23.53070068], [68.43125153, 23.53125], [68.43096924, 23.53125], [68.43096924, 23.53181839], [68.43041992, 23.53180695], [68.43041992, 23.53208351], [68.43013763, 23.5320797], [68.43013763, 23.53264046], [68.42986298, 23.53264046], [68.42986298, 23.53375053], [68.43041992, 23.53375053], [68.43041992, 23.53347015], [68.43069458, 23.53347206], [68.43069458, 23.53319359], [68.43125153, 23.53319359], [68.43125153, 23.53347206], [68.43096924, 23.53347015], [68.43096924, 23.53403091], [68.43069458, 23.5340271], [68.43069458, 23.53458405], [68.43041992, 23.53457069], [68.43041992, 23.53513908], [68.43013763, 23.53513908], [68.43013763, 23.54292107], [68.43041992, 23.54291725], [68.43041992, 23.54319572], [68.43096924, 23.54319572], [68.43096924, 23.54347229], [68.43125153, 23.54347038], [68.43125153, 23.5437603], [68.43152618, 23.5437603], [68.43152618, 23.54430962], [68.43180847, 23.54430771], [68.43180847, 23.54458427], [68.43235779, 23.54458046], [68.43235779, 23.54486084], [68.43264008, 23.54486084], [68.43264008, 23.54514122], [68.43319702, 23.54514122], [68.43319702, 23.54541969], [68.43347168, 23.54541779], [68.43347168, 23.54569435], [68.43374634, 23.54569435], [68.43374634, 23.54597282], [68.43430328, 23.54597092], [68.43430328, 23.54624939], [68.4345932, 23.54624939], [68.4345932, 23.54652977], [68.43514252, 23.54652977], [68.43514252, 23.54680634], [68.43541718, 23.54680634], [68.43541718, 23.54736137], [68.43514252, 23.54736137], [68.43514252, 23.54847145], [68.43541718, 23.54846954], [68.43541718, 23.5490284], [68.43569183, 23.5490284], [68.43569183, 23.54958344], [68.43583679, 23.54958344], [68.43597412, 23.54958344], [68.43597412, 23.54986191], [68.43582153, 23.54986191], [68.43514252, 23.54986191], [68.43514252, 23.55014038], [68.4345932, 23.55014038], [68.4345932, 23.55042267], [68.43430328, 23.55041695], [68.43430328, 23.55069351], [68.43374634, 23.55069351], [68.43374634, 23.55097008], [68.43345642, 23.55097008], [68.43345642, 23.55125046], [68.43374634, 23.55125046], [68.43374634, 23.55153275], [68.43402863, 23.55153275], [68.43402863, 23.55181122], [68.43430328, 23.5518055], [68.43430328, 23.55208206], [68.43458557, 23.55208206], [68.43458557, 23.55319214], [68.43430328, 23.55319214], [68.43430328, 23.55347443], [68.43402863, 23.55347061], [68.43402863, 23.5537529], [68.43430328, 23.55374908], [68.43430328, 23.5545826], [68.4345932, 23.55458069], [68.4345932, 23.55541992], [68.43486023, 23.5554142], [68.43486023, 23.55597305], [68.43512726, 23.55597115], [68.43514252, 23.55653], [68.43541718, 23.55652809], [68.43541718, 23.55708313], [68.43653107, 23.55708313], [68.43653107, 23.5573616], [68.43682098, 23.5573597], [68.43682098, 23.55764008], [68.43708038, 23.55763626], [68.43708038, 23.55847168], [68.43736267, 23.55846977], [68.43736267, 23.55931091], [68.43763733, 23.55931091], [68.43763733, 23.55986023], [68.43902588, 23.55986023], [68.43902588, 23.55957985], [68.43930817, 23.55958366], [68.43930817, 23.55930519], [68.43959045, 23.55931091], [68.43959045, 23.55903053], [68.43985748, 23.55903053], [68.43985748, 23.55874062], [68.44013977, 23.55875015], [68.44013977, 23.55847168], [68.44125366, 23.55847168], [68.44125366, 23.55875015], [68.44097137, 23.55874062], [68.44097137, 23.55931091], [68.44069672, 23.55930519], [68.44069672, 23.55958366], [68.44013977, 23.55957985], [68.44013977, 23.55986023], [68.43985748, 23.55986023], [68.43985748, 23.56041908], [68.44013977, 23.56041718], [68.44013977, 23.56069374], [68.44041443, 23.56069374], [68.44041443, 23.56097221], [68.44125366, 23.56097221], [68.44125366, 23.56069374], [68.44180298, 23.56069374], [68.44180298, 23.56097221], [68.44208527, 23.56097221], [68.44208527, 23.5620842], [68.44235992, 23.56208038], [68.44235992, 23.56263924], [68.44208527, 23.56263924], [68.44208527, 23.56347275], [68.44319153, 23.56347084], [68.44319153, 23.56374931], [68.44431305, 23.56374931], [68.44431305, 23.56347084], [68.44486237, 23.56347084], [68.44486237, 23.56374931], [68.44596863, 23.56374931], [68.44596863, 23.56402969], [68.44625092, 23.56402779], [68.44625092, 23.56458282], [68.4465332, 23.56458282], [68.4465332, 23.56487083], [68.44680786, 23.56487083], [68.44680786, 23.56513977], [68.44708252, 23.56513977], [68.44708252, 23.56542015], [68.44819641, 23.56541634], [68.44819641, 23.56569481], [68.44985962, 23.56569481], [68.44985962, 23.56541634], [68.45041656, 23.56542015], [68.45041656, 23.56513977], [68.45096588, 23.56513977], [68.45096588, 23.56402969], [68.45124817, 23.56402969], [68.45124817, 23.56347084], [68.45153046, 23.56347275], [68.45153046, 23.56236076], [68.45182037, 23.56236076], [68.45180511, 23.56152725], [68.45263672, 23.56152916], [68.45263672, 23.56125069], [68.45318604, 23.56125069], [68.45318604, 23.56152916], [68.45347595, 23.56152725], [68.45347595, 23.56180573], [68.45375061, 23.56180573], [68.45375061, 23.56347275], [68.45402527, 23.56347275], [68.45402527, 23.56458282], [68.45375061, 23.56458282], [68.45375061, 23.56487083], [68.45347595, 23.56487083], [68.45347595, 23.56513977], [68.45318604, 23.56513977], [68.45318604, 23.56542015], [68.45291901, 23.56541634], [68.45291901, 23.56597137], [68.45263672, 23.56596947], [68.45263672, 23.56624985], [68.45291901, 23.56624985], [68.45291901, 23.56680489], [68.45319366, 23.56680489], [68.45319366, 23.56736374], [68.45456696, 23.56735992], [68.45456696, 23.56820107], [68.45430756, 23.56820107], [68.45430756, 23.56875038], [68.4540329, 23.56875038], [68.4540329, 23.56903076], [68.45485687, 23.56903076], [68.45485687, 23.57014084], [68.45513916, 23.57014084], [68.45513916, 23.57152939], [68.45541382, 23.57152748], [68.45541382, 23.57208252], [68.45569611, 23.57208061], [68.45569611, 23.57236099], [68.45625305, 23.57236099], [68.45625305, 23.57263947], [68.45680237, 23.57263947], [68.45680237, 23.57291985], [68.45735931, 23.57291794], [68.45735931, 23.5731945], [68.4576416, 23.5731945], [68.4576416, 23.57347298], [68.45819092, 23.57347298], [68.45819092, 23.57374954], [68.45903015, 23.57374001], [68.45903015, 23.57402992], [68.4595871, 23.57402992], [68.4595871, 23.5743084], [68.45986176, 23.57430649], [68.45986176, 23.57458305], [68.46013641, 23.57458115], [68.46013641, 23.57513809], [68.4604187, 23.57513809], [68.4604187, 23.57541847], [68.46235657, 23.57541847], [68.46235657, 23.57570076], [68.4640274, 23.57569504], [68.4640274, 23.5759716], [68.46430206, 23.5759697], [68.46430206, 23.57625008], [68.46457672, 23.57625008], [68.46457672, 23.57653236], [68.46485901, 23.57653236], [68.46485901, 23.57681274], [68.46569824, 23.57681274], [68.46569824, 23.57653236], [68.4679184, 23.57653236], [68.4679184, 23.57681274], [68.46763611, 23.57681274], [68.46763611, 23.57792282], [68.46819305, 23.5779171], [68.46819305, 23.57819366], [68.46930695, 23.57819366], [68.46930695, 23.57847023], [68.47041321, 23.57847023], [68.47041321, 23.57875061], [68.47070313, 23.57875061], [68.4706955, 23.57847023], [68.47180176, 23.57847023], [68.47180939, 23.57819366], [68.47291565, 23.57819366], [68.47291565, 23.57847023], [68.47264099, 23.57847023], [68.47264099, 23.57875061], [68.4723587, 23.57875061], [68.4723587, 23.5790329], [68.47207642, 23.5790329], [68.47207642, 23.57930946], [68.4715271, 23.57930565], [68.4715271, 23.57958221], [68.47125244, 23.57958031], [68.47125244, 23.58014107], [68.47097015, 23.58014107], [68.47097015, 23.58041954], [68.47041321, 23.58041573], [68.47041321, 23.58069229], [68.47013855, 23.58069229], [68.47013855, 23.58097458], [68.46985626, 23.58097076], [68.46985626, 23.58152962], [68.4695816, 23.58152771], [68.4695816, 23.58291435], [68.46875, 23.58291435], [68.46875, 23.58263969], [68.4679184, 23.58263969], [68.4679184, 23.58291435], [68.46708679, 23.58291435], [68.46708679, 23.58208466], [68.46736145, 23.58208466], [68.46736145, 23.58124924], [68.46763611, 23.58125114], [68.46763611, 23.57987022], [68.46624756, 23.57987022], [68.46624756, 23.57958031], [68.46541595, 23.57958221], [68.46541595, 23.57930565], [68.46485901, 23.57930946], [68.46485901, 23.5790329], [68.4640274, 23.5790329], [68.4640274, 23.57930946], [68.46375275, 23.57930565], [68.46375275, 23.57958221], [68.46347046, 23.57958031], [68.46347046, 23.57987022], [68.4631958, 23.57987022], [68.4631958, 23.58041954], [68.46291351, 23.58041573], [68.46291351, 23.58097458], [68.46263885, 23.58097076], [68.46263885, 23.58152962], [68.4623642, 23.58152771], [68.4623642, 23.58319664], [68.46263885, 23.58319664], [68.46263885, 23.5834713], [68.46290588, 23.58346939], [68.46290588, 23.58374977], [68.4631958, 23.58374977], [68.4631958, 23.58430672], [68.46347046, 23.58430672], [68.46347046, 23.58458328], [68.46375275, 23.58458328], [68.46375275, 23.58486176], [68.4640274, 23.58485985], [68.4640274, 23.58514023], [68.46430206, 23.58514023], [68.46430206, 23.58542061], [68.46457672, 23.58542061], [68.46457672, 23.58569908], [68.46485901, 23.58569527], [68.46485901, 23.58597183], [68.4651413, 23.58596992], [68.4651413, 23.58653069], [68.46541595, 23.58652878], [68.46541595, 23.58708382], [68.46569061, 23.58708382], [68.46569824, 23.58745384], [68.46569824, 23.58764076], [68.4659729, 23.58763885], [68.4659729, 23.58819389], [68.46624756, 23.58818817], [68.46624756, 23.58875084], [68.46652985, 23.58875084], [68.46652985, 23.58902931], [68.4668045, 23.5890274], [68.4668045, 23.58958244], [68.46708679, 23.58958054], [68.46708679, 23.58986092], [68.46736145, 23.58986092], [68.46736145, 23.59042168], [68.46763611, 23.59041595], [68.46763611, 23.5909729], [68.4679184, 23.59096909], [68.4679184, 23.59153175], [68.46819305, 23.59153175], [68.46819305, 23.59181023], [68.46847534, 23.59180641], [68.46847534, 23.59208107], [68.46902466, 23.59208107], [68.46902466, 23.59236145], [68.46985626, 23.59235954], [68.46985626, 23.59263992], [68.47041321, 23.59263992], [68.47041321, 23.5929203], [68.47207642, 23.5929203], [68.47207642, 23.59320068], [68.4734726, 23.59320068], [68.4734726, 23.5929203], [68.47429657, 23.5929203], [68.47429657, 23.59263992], [68.47458649, 23.59263992], [68.47458649, 23.59235954], [68.4751358, 23.59236145], [68.4751358, 23.59180641], [68.47541809, 23.59181023], [68.47541809, 23.59153175], [68.47570038, 23.59153175], [68.47570038, 23.59124947], [68.47624969, 23.59124947], [68.47624969, 23.59096909], [68.47652435, 23.5909729], [68.47652435, 23.59069443], [68.4770813, 23.59069443], [68.4770813, 23.59041595], [68.4779129, 23.59042168], [68.4779129, 23.59013939], [68.47846985, 23.59013939], [68.47846985, 23.58986092], [68.47957611, 23.58986092], [68.47957611, 23.59013939], [68.48014069, 23.59013939], [68.48014069, 23.59042168], [68.48041534, 23.59041595], [68.48041534, 23.59069443], [68.48069763, 23.59069061], [68.48069763, 23.59153175], [68.48097229, 23.59153175], [68.48097229, 23.59320068], [68.48069763, 23.59320068], [68.48069763, 23.59375], [68.48042297, 23.59375], [68.48042297, 23.59680939], [68.48208618, 23.59680939], [68.48208618, 23.59653091], [68.48236084, 23.59653091], [68.48236084, 23.59625053], [68.48264313, 23.59625053], [68.4826355, 23.59597206], [68.48291779, 23.59597206], [68.48291779, 23.5956955], [68.48319244, 23.5956955], [68.48319244, 23.59541512], [68.4834671, 23.59542084], [68.4834671, 23.59514046], [68.48374939, 23.59514046], [68.48374939, 23.59485054], [68.48402405, 23.59486389], [68.48402405, 23.59458542], [68.48430634, 23.59458542], [68.48430634, 23.59430313], [68.48458099, 23.59431076], [68.48458099, 23.59346962], [68.48486328, 23.59347153], [68.48486328, 23.59263802], [68.48513794, 23.59263992], [68.48513794, 23.59181023], [68.48542023, 23.59181023], [68.48542023, 23.58875084], [68.48568726, 23.58875084], [68.48568726, 23.58764076], [68.48542023, 23.58764076], [68.48542023, 23.58680916], [68.48513794, 23.58680916], [68.48513794, 23.58625031], [68.48486328, 23.58625031], [68.48486328, 23.58596992], [68.48458099, 23.58597183], [68.48458099, 23.58486176], [68.48430634, 23.58486176], [68.48430634, 23.58430672], [68.48402405, 23.58430672], [68.48402405, 23.58374977], [68.48374939, 23.58374977], [68.48374939, 23.58041954], [68.48401642, 23.58041954], [68.48401642, 23.57958031], [68.48430634, 23.57958221], [68.48430634, 23.57902718], [68.48458099, 23.5790329], [68.48458099, 23.57847023], [68.48486328, 23.57847023], [68.48486328, 23.57763863], [68.48513794, 23.57764053], [68.48513794, 23.57625008], [68.48542023, 23.57625008], [68.48542023, 23.57513809], [68.48513794, 23.57513809], [68.48513794, 23.57485962], [68.48486328, 23.57486153], [68.48486328, 23.57458305], [68.48458099, 23.57458305], [68.48458099, 23.57402992], [68.48401642, 23.57402992], [68.48401642, 23.57347107], [68.48374939, 23.57347298], [68.48374939, 23.5731945], [68.48347473, 23.5731945], [68.48347473, 23.57291794], [68.48319244, 23.57291985], [68.48319244, 23.57263947], [68.48291779, 23.57263947], [68.48291779, 23.57236099], [68.48236084, 23.57236099], [68.48236084, 23.57208061], [68.48208618, 23.57208252], [68.48208618, 23.57152748], [68.48179626, 23.57152939], [68.48179626, 23.57097054], [68.48152924, 23.57097244], [68.48152924, 23.5704174], [68.48124695, 23.57042122], [68.48124695, 23.57014084], [68.48097229, 23.57014084], [68.48097229, 23.56958008], [68.48069763, 23.5695858], [68.48069763, 23.56902695], [68.48042297, 23.56903076], [68.48042297, 23.56847], [68.48014069, 23.56847382], [68.48014069, 23.56791687], [68.4798584, 23.56793022], [68.4798584, 23.56624985], [68.48014069, 23.56624985], [68.48014069, 23.56542015], [68.48042297, 23.56542015], [68.48042297, 23.56513977], [68.48097229, 23.56513977], [68.48097229, 23.56458282], [68.48124695, 23.56458282], [68.48124695, 23.56402779], [68.48152924, 23.56402969], [68.48152924, 23.56374931], [68.48124695, 23.56374931], [68.48124695, 23.56318855], [68.48097229, 23.56319427], [68.48097229, 23.5620842], [68.48124695, 23.5620842], [68.48124695, 23.56125069], [68.48069763, 23.56125069], [68.48069763, 23.56097031], [68.47930908, 23.56097031], [68.47930908, 23.56125069], [68.47875977, 23.56125069], [68.47875977, 23.56152916], [68.47846985, 23.56152725], [68.47846985, 23.56180573], [68.47902679, 23.56180573], [68.47902679, 23.5620842], [68.47930908, 23.56208038], [68.47930908, 23.56263924], [68.47763824, 23.56263924], [68.47763824, 23.56292152], [68.4770813, 23.5629158], [68.4770813, 23.56319427], [68.47680664, 23.56318855], [68.47680664, 23.56402969], [68.47651672, 23.56402969], [68.47651672, 23.56431007], [68.4759903, 23.56431007], [68.4759903, 23.56402969], [68.47541809, 23.56402969], [68.47541809, 23.56374931], [68.4751358, 23.56374931], [68.4751358, 23.56347084], [68.47458649, 23.56347275], [68.47458649, 23.56319427], [68.47402954, 23.56319427], [68.47402954, 23.5629158], [68.4734726, 23.56292152]]], [[[68.48208618, 23.60653114], [68.48208618, 23.60642052], [68.48208618, 23.60625076], [68.48227692, 23.60625076], [68.48291779, 23.60625076], [68.48291779, 23.60597038], [68.48347473, 23.60597229], [68.48347473, 23.60569382], [68.48374939, 23.60569382], [68.48374939, 23.60541725], [68.48401642, 23.60542107], [68.48401642, 23.60514259], [68.48430634, 23.60514259], [68.48430634, 23.60486031], [68.48458099, 23.60486031], [68.48458099, 23.60458183], [68.48486328, 23.60458374], [68.48486328, 23.60430527], [68.48500061, 23.60430717], [68.48542023, 23.6043129], [68.48542023, 23.60406113], [68.48652649, 23.60404015], [68.48652649, 23.60349083], [68.48652649, 23.60319519], [68.48596954, 23.60320282], [68.48596954, 23.60263824], [68.48568726, 23.60263824], [68.48568726, 23.60235977], [68.48542023, 23.60236168], [68.48542023, 23.60208321], [68.48486328, 23.60208321], [68.48486328, 23.60180473], [68.48458099, 23.60180473], [68.48458099, 23.60152817], [68.48430634, 23.60152817], [68.48430634, 23.60124969], [68.48401642, 23.60124969], [68.48401642, 23.60098076], [68.48374939, 23.60098076], [68.48374939, 23.60069084], [68.48347473, 23.60069466], [68.48347473, 23.60041618], [68.48319244, 23.60041809], [68.48319244, 23.59986115], [68.48291779, 23.59986115], [68.48291779, 23.59930992], [68.48264313, 23.59930992], [68.48264313, 23.59875107], [68.48208618, 23.59875107], [68.48208618, 23.59847069], [68.48152924, 23.5984726], [68.48152924, 23.59819412], [68.48014069, 23.59819031], [68.48014069, 23.59875107], [68.4798584, 23.59875107], [68.4798584, 23.59930992], [68.47957611, 23.59930992], [68.47957611, 23.59986115], [68.47930908, 23.59986115], [68.47930908, 23.60013962], [68.47875977, 23.60013962], [68.47875977, 23.60263824], [68.47902679, 23.60263824], [68.47902679, 23.60404015], [68.47930908, 23.60404015], [68.47930908, 23.60514259], [68.47958374, 23.60513878], [68.47958374, 23.60569382], [68.4798584, 23.60569382], [68.4798584, 23.60597229], [68.48041534, 23.60597229], [68.48041534, 23.60625076], [68.48097229, 23.60625076], [68.48097229, 23.60653114], [68.48195648, 23.60652733], [68.48208618, 23.60653114]]], [[[68.48458099, 23.62791824], [68.48458099, 23.62763977], [68.48680878, 23.62763977], [68.48680878, 23.62735939], [68.48708344, 23.6273613], [68.48708344, 23.62708282], [68.48680878, 23.62708282], [68.48680878, 23.62652779], [68.48652649, 23.62652969], [68.48652649, 23.62625122], [68.48625183, 23.62625122], [68.48625183, 23.62569046], [68.48596954, 23.62569427], [68.48596954, 23.62513924], [68.48568726, 23.62514114], [68.48568726, 23.62458038], [68.48542023, 23.6245842], [68.48542023, 23.62430763], [68.48513794, 23.62430954], [68.48513794, 23.62375069], [68.48486328, 23.62375069], [68.48486328, 23.62347031], [68.48458099, 23.62347221], [68.48458099, 23.62319565], [68.48430634, 23.62319565], [68.48430634, 23.62291527], [68.48401642, 23.62292099], [68.48401642, 23.62264061], [68.48374939, 23.62264061], [68.48374939, 23.62236023], [68.4834671, 23.62236023], [68.4834671, 23.62181091], [68.48319244, 23.62181091], [68.48319244, 23.62153053], [68.48401642, 23.62153053], [68.48401642, 23.62181091], [68.48430634, 23.62180328], [68.48430634, 23.62208557], [68.48458099, 23.62207985], [68.48458099, 23.62236023], [68.48486328, 23.62236023], [68.48486328, 23.62292099], [68.48513794, 23.62291527], [68.48513794, 23.62347221], [68.48568726, 23.62347031], [68.48568726, 23.62375069], [68.48625183, 23.62375069], [68.48625183, 23.62403107], [68.48652649, 23.62403107], [68.48652649, 23.62430954], [68.48680878, 23.62430763], [68.48680878, 23.6245842], [68.48707581, 23.62458038], [68.48707581, 23.62486076], [68.48735809, 23.62486076], [68.48735809, 23.62514114], [68.4879303, 23.62514114], [68.4879303, 23.62541962], [68.48847198, 23.62541771], [68.48847198, 23.62569427], [68.48930359, 23.62569427], [68.48930359, 23.62541771], [68.48958588, 23.62541962], [68.48958588, 23.62514114], [68.48986053, 23.62514114], [68.48986053, 23.62486076], [68.49014282, 23.62486076], [68.49013519, 23.62430763], [68.49041748, 23.62430954], [68.49041748, 23.62264061], [68.49069977, 23.62264061], [68.49069977, 23.62207985], [68.49097443, 23.62208557], [68.49097443, 23.62152863], [68.49069977, 23.62153053], [68.49069977, 23.62096977], [68.49041748, 23.62097168], [68.49041748, 23.62041664], [68.49014282, 23.62042046], [68.49014282, 23.61930275], [68.48986053, 23.61930466], [68.48986053, 23.61819458], [68.48958588, 23.61819458], [68.48958588, 23.6170826], [68.48930359, 23.6170826], [68.48930359, 23.6143055], [68.48958588, 23.61430931], [68.48958588, 23.61320114], [68.48986053, 23.6131897], [68.48986053, 23.61208344], [68.49013519, 23.61208344], [68.49013519, 23.61173058], [68.49013519, 23.61097145], [68.49041748, 23.61097145], [68.49041748, 23.60986137], [68.49069214, 23.60986137], [68.49069214, 23.60902786], [68.4909668, 23.60902977], [68.4909668, 23.60791969], [68.49124908, 23.60791969], [68.49124908, 23.60569191], [68.49097443, 23.60569382], [68.49097443, 23.60430527], [68.49069977, 23.6043129], [68.49069977, 23.60375023], [68.49041748, 23.60375023], [68.49041748, 23.60347176], [68.48929596, 23.60347176], [68.48929596, 23.60375023], [68.48874664, 23.60375023], [68.48874664, 23.60404015], [68.48819733, 23.60404015], [68.48819733, 23.6043129], [68.48764038, 23.60430527], [68.48764038, 23.60458374], [68.48625183, 23.60458183], [68.48625183, 23.60486031], [68.48596954, 23.60486031], [68.48596954, 23.60514259], [68.48568726, 23.60514259], [68.48568726, 23.60542107], [68.48513794, 23.60541725], [68.48513794, 23.60569382], [68.48486328, 23.60569382], [68.48486328, 23.60597229], [68.48430634, 23.60597038], [68.48430634, 23.60625076], [68.48401642, 23.60625076], [68.48401642, 23.60653114], [68.48374939, 23.60653114], [68.48374939, 23.60680962], [68.48319244, 23.6068058], [68.48319244, 23.60708237], [68.4826355, 23.60708237], [68.4826355, 23.60736084], [68.48100281, 23.60736084], [68.48041534, 23.60736084], [68.48041534, 23.60708237], [68.4798584, 23.60708237], [68.4798584, 23.6068058], [68.47957611, 23.60680962], [68.47957611, 23.60653114], [68.47930908, 23.60653114], [68.47930908, 23.60625076], [68.47902679, 23.60625076], [68.47902679, 23.60653114], [68.47875977, 23.60653114], [68.47875977, 23.60625076], [68.47846985, 23.60625076], [68.47846985, 23.60486031], [68.47819519, 23.60486031], [68.47819519, 23.60458374], [68.4779129, 23.60458374], [68.4779129, 23.60375023], [68.47820282, 23.60375023], [68.47819519, 23.60319519], [68.4779129, 23.60320282], [68.4779129, 23.60013962], [68.47820282, 23.60013962], [68.47819519, 23.59902763], [68.47846985, 23.59902954], [68.47846985, 23.59847069], [68.47875214, 23.5984726], [68.47875214, 23.59819412], [68.47902679, 23.59819412], [68.47902679, 23.59791756], [68.47958374, 23.59791756], [68.47958374, 23.59680367], [68.47930908, 23.59680939], [68.47930908, 23.59653091], [68.47957611, 23.59653091], [68.47957611, 23.59375], [68.4798584, 23.59375], [68.4798584, 23.5929203], [68.48014069, 23.5929203], [68.48014069, 23.59153175], [68.4798584, 23.59153175], [68.4798584, 23.59096909], [68.47958374, 23.5909729], [68.47958374, 23.59069443], [68.47846985, 23.59069443], [68.47846985, 23.5909729], [68.4779129, 23.59096909], [68.4779129, 23.59124947], [68.4770813, 23.59124947], [68.4770813, 23.59153175], [68.47651672, 23.59153175], [68.47651672, 23.59181023], [68.47624969, 23.59180641], [68.47624969, 23.59208107], [68.47597504, 23.59208107], [68.47597504, 23.59236145], [68.47570038, 23.59235954], [68.47570038, 23.59263992], [68.47541809, 23.59263992], [68.47541809, 23.5929203], [68.4751358, 23.5929203], [68.4751358, 23.59320068], [68.47458649, 23.59319305], [68.47458649, 23.59347153], [68.47429657, 23.59346962], [68.47429657, 23.59375], [68.4734726, 23.59375], [68.4734726, 23.59403038], [68.47180939, 23.59403038], [68.47180176, 23.59375], [68.47041321, 23.59375], [68.47041321, 23.59346962], [68.4695816, 23.59347153], [68.4695816, 23.59319305], [68.46901703, 23.59320068], [68.46901703, 23.5929203], [68.46848297, 23.5929203], [68.46848297, 23.59263992], [68.46819305, 23.59263992], [68.46819305, 23.5929203], [68.4679184, 23.5929203], [68.4679184, 23.59320068], [68.46763611, 23.59319305], [68.46763611, 23.59347153], [68.46736145, 23.59346962], [68.46736145, 23.59542084], [68.46708679, 23.59542084], [68.46708679, 23.59680939], [68.46736145, 23.59680939], [68.46736145, 23.59764099], [68.46763611, 23.59763908], [68.46763611, 23.59819412], [68.4679184, 23.59819031], [68.4679184, 23.59875107], [68.46819305, 23.59875107], [68.46819305, 23.59930992], [68.46847534, 23.59930611], [68.46847534, 23.60013962], [68.46875, 23.60013962], [68.46875, 23.60098076], [68.46901703, 23.60098076], [68.46901703, 23.60124969], [68.46930695, 23.60124969], [68.46930695, 23.60152817], [68.46956635, 23.60152817], [68.46956635, 23.60486031], [68.46930695, 23.60486031], [68.46930695, 23.60597229], [68.46901703, 23.60597038], [68.46901703, 23.60653114], [68.46875, 23.60653114], [68.46875, 23.60680962], [68.46848297, 23.60680962], [68.46848297, 23.60791969], [68.46875, 23.60791588], [68.46875, 23.60819244], [68.46847534, 23.60819244], [68.46847534, 23.60986137], [68.46819305, 23.60986137], [68.46819305, 23.61097145], [68.46847534, 23.61097145], [68.46847534, 23.61124992], [68.46875, 23.61124992], [68.46875, 23.61264038], [68.46901703, 23.61264038], [68.46901703, 23.61403084], [68.46927643, 23.61403084], [68.46930695, 23.61514091], [68.46956635, 23.61514091], [68.46956635, 23.61624908], [68.46985626, 23.61624908], [68.46985626, 23.61681175], [68.47041321, 23.61680603], [68.47041321, 23.6170826], [68.4706955, 23.6170826], [68.4706955, 23.61735916], [68.47125244, 23.61735916], [68.47125244, 23.61763954], [68.47180176, 23.61763954], [68.47180176, 23.61792183], [68.4723587, 23.61791611], [68.4723587, 23.61819458], [68.47291565, 23.61819458], [68.47291565, 23.61847115], [68.47319794, 23.61847115], [68.47319794, 23.61930466], [68.4734726, 23.61930275], [68.4734726, 23.62014008], [68.47458649, 23.62014008], [68.47458649, 23.6198597], [68.47486115, 23.6198616], [68.47486115, 23.61930466], [68.47570038, 23.61930275], [68.47570038, 23.62014008], [68.47583008, 23.62013817], [68.47957611, 23.62014008], [68.47957611, 23.62070084], [68.4798584, 23.62070084], [68.4798584, 23.62125015], [68.48042297, 23.62125015], [68.48042297, 23.62153053], [68.48069763, 23.62153053], [68.48069763, 23.62181091], [68.48097229, 23.62181091], [68.48097229, 23.62236023], [68.48124695, 23.62236023], [68.48124695, 23.62319565], [68.48152924, 23.62318993], [68.48152924, 23.62375069], [68.48124695, 23.62375069], [68.48124695, 23.62430954], [68.48097229, 23.62430954], [68.48097229, 23.62486076], [68.48069763, 23.62486076], [68.48069763, 23.62569427], [68.48097229, 23.62569046], [68.48097229, 23.62652969], [68.48124695, 23.62652779], [68.48124695, 23.62708282], [68.48152924, 23.62708282], [68.48152924, 23.6273613], [68.48179626, 23.62735939], [68.48179626, 23.62763977], [68.48208618, 23.62763977], [68.48208618, 23.62791824], [68.48458099, 23.62791824]]], [[[69.21318817, 22.38485909], [69.21318817, 22.38458061], [69.2140274, 22.38458252], [69.2140274, 22.38430786], [69.21485901, 22.38430977], [69.21485901, 22.38402748], [69.2151413, 22.38402748], [69.2151413, 22.38319016], [69.21485901, 22.38319397], [69.21485901, 22.3829155], [69.21457672, 22.38292122], [69.21457672, 22.38264084], [69.21430206, 22.38264084], [69.21430206, 22.38236046], [69.21347046, 22.38236046], [69.21347046, 22.38319397], [69.2131958, 22.38319397], [69.2131958, 22.38347244], [69.21289825, 22.38347054], [69.21289825, 22.38375092], [69.21263885, 22.38375092], [69.21263885, 22.38402748], [69.2123642, 22.38402748], [69.2123642, 22.38458252], [69.21263885, 22.38458061], [69.21263885, 22.38485909], [69.21318817, 22.38485909]]], [[[69.20095825, 22.38625145], [69.20095825, 22.38569069], [69.20069122, 22.3856945], [69.20069122, 22.38485909], [69.20041656, 22.38485909], [69.20041656, 22.38458061], [69.20014191, 22.38458252], [69.20014191, 22.38430786], [69.19985962, 22.38430977], [69.19985962, 22.38402748], [69.19957733, 22.38402748], [69.19957733, 22.38430977], [69.19930267, 22.38430977], [69.19930267, 22.38541985], [69.19958496, 22.38541603], [69.19958496, 22.3856945], [69.19930267, 22.3856945], [69.19930267, 22.38597298], [69.19958496, 22.38597298], [69.19958496, 22.38708305], [69.19985962, 22.38708305], [69.19985962, 22.38736153], [69.20014191, 22.38736153], [69.20014191, 22.38764191], [69.20236206, 22.38764191], [69.20236206, 22.38653183], [69.20207977, 22.38653183], [69.20207977, 22.38625145], [69.20095825, 22.38625145]]], [[[69.28013611, 22.41792107], [69.28013611, 22.41764069], [69.2804184, 22.41764069], [69.2804184, 22.41736031], [69.28069305, 22.41736031], [69.28069305, 22.41653061], [69.28098297, 22.41653061], [69.28098297, 22.41597176], [69.28069305, 22.41597366], [69.28069305, 22.41569519], [69.28013611, 22.41569519], [69.28013611, 22.41597366], [69.27986145, 22.41597366], [69.27986145, 22.41541672], [69.27958679, 22.41542053], [69.27958679, 22.41514969], [69.27902985, 22.41514969], [69.27902985, 22.41542053], [69.27819824, 22.41542053], [69.27819061, 22.41570282], [69.27791595, 22.41569519], [69.27791595, 22.41597366], [69.2776413, 22.41597366], [69.2776413, 22.41708374], [69.27791595, 22.41708183], [69.27791595, 22.41764069], [69.27819061, 22.41764069], [69.27819824, 22.41792107], [69.28013611, 22.41792107]]], [[[69.48319244, 22.3987484], [69.48319244, 22.39846992], [69.48374939, 22.39847183], [69.48374939, 22.39819527], [69.48430634, 22.39819908], [69.48430634, 22.39792061], [69.48458099, 22.39792061], [69.48458099, 22.39763832], [69.48513794, 22.39763832], [69.48513794, 22.39735985], [69.48542023, 22.39736176], [69.48542023, 22.39708328], [69.48625183, 22.39708328], [69.48625183, 22.39652634], [69.48652649, 22.39653015], [69.48652649, 22.39624977], [69.48680878, 22.39624977], [69.48680878, 22.39596939], [69.48708344, 22.3959713], [69.48708344, 22.39569473], [69.48735809, 22.39569473], [69.48735809, 22.39541626], [69.48764038, 22.39542007], [69.48764038, 22.39458084], [69.48791504, 22.39458275], [69.48791504, 22.39430428], [69.48819733, 22.39431], [69.48819733, 22.39402008], [69.48847198, 22.39402771], [69.48847198, 22.39374924], [69.48874664, 22.39375114], [69.48874664, 22.39291954], [69.48902893, 22.39291954], [69.48902893, 22.39153099], [69.48874664, 22.39153099], [69.48874664, 22.39068985], [69.48847198, 22.39069366], [69.48847198, 22.3904171], [69.48819733, 22.39042091], [69.48819733, 22.38986015], [69.48764038, 22.38986015], [69.48764038, 22.38957977], [69.48735809, 22.38958359], [69.48735809, 22.38902855], [69.48707581, 22.38903046], [69.48707581, 22.38875008], [69.48680878, 22.38875008], [69.48680878, 22.3884716], [69.48625183, 22.3884716], [69.48625183, 22.38819504], [69.48596954, 22.3882103], [69.48596954, 22.38792038], [69.48458099, 22.38792038], [69.48458099, 22.38764191], [69.48374939, 22.38764191], [69.48374939, 22.38792038], [69.48291779, 22.38792038], [69.48291779, 22.3882103], [69.48097229, 22.38819504], [69.48097229, 22.3884716], [69.48042297, 22.3884716], [69.48042297, 22.39014053], [69.48014069, 22.39013863], [69.48014069, 22.39069366], [69.48042297, 22.39068985], [69.48042297, 22.39180946], [69.48069763, 22.39180946], [69.48069763, 22.39375114], [69.48097229, 22.39374924], [69.48097229, 22.39402771], [69.48152924, 22.39402008], [69.48152924, 22.39431], [69.48179626, 22.39431], [69.48179626, 22.39486122], [69.48208618, 22.39486122], [69.48208618, 22.39569473], [69.48236084, 22.39569473], [69.48236084, 22.3959713], [69.4826355, 22.3959713], [69.4826355, 22.3987484], [69.48319244, 22.3987484]]], [[[69.27931213, 22.42014122], [69.27931213, 22.41986084], [69.27958679, 22.41986084], [69.27958679, 22.41930962], [69.27931213, 22.41930962], [69.27931213, 22.41903114], [69.27819824, 22.41903114], [69.27819824, 22.41847038], [69.27791595, 22.41847229], [69.27791595, 22.41819382], [69.2765274, 22.41819382], [69.2765274, 22.41847229], [69.27597046, 22.41847038], [69.27597046, 22.41875076], [69.27540588, 22.41875076], [69.27540588, 22.41903114], [69.27513885, 22.41903114], [69.27513885, 22.41930962], [69.27541351, 22.4193058], [69.27541351, 22.41958427], [69.2756958, 22.41958046], [69.2756958, 22.41986084], [69.27707672, 22.41986084], [69.27707672, 22.41958046], [69.27735901, 22.41958046], [69.27735901, 22.41986084], [69.27791595, 22.41986084], [69.27791595, 22.42014122], [69.27874756, 22.42014122], [69.27874756, 22.41986084], [69.27902985, 22.41986084], [69.27902985, 22.42014122], [69.27931213, 22.42014122]]], [[[69.60708618, 22.41875076], [69.60679626, 22.41875076], [69.60679626, 22.41903114], [69.60652924, 22.41903114], [69.60652924, 22.41930962], [69.60624695, 22.4193058], [69.60624695, 22.41958237], [69.60597229, 22.41958046], [69.60597229, 22.41986084], [69.60569763, 22.41986084], [69.60569763, 22.42014122], [69.60514069, 22.42014122], [69.60514069, 22.42041969], [69.6048584, 22.42041588], [69.6048584, 22.42069435], [69.60458374, 22.42069435], [69.60458374, 22.42097282], [69.60430908, 22.42095947], [69.60430908, 22.42124939], [69.60402679, 22.42124939], [69.60402679, 22.42152977], [69.60375214, 22.42152977], [69.60375214, 22.42181015], [69.60346985, 22.42180634], [69.60346985, 22.4220829], [69.60319519, 22.4220829], [69.60319519, 22.42236137], [69.6029129, 22.42236137], [69.6029129, 22.42319489], [69.60236359, 22.42319489], [69.60236359, 22.42291641], [69.6020813, 22.42292023], [69.6020813, 22.42235947], [69.6001358, 22.42235947], [69.6001358, 22.42263985], [69.59986115, 22.42263985], [69.59986115, 22.42292023], [69.59902954, 22.42291641], [69.59902954, 22.42319489], [69.59874725, 22.42319489], [69.59874725, 22.42347145], [69.5984726, 22.42346954], [69.5984726, 22.42374992], [69.59819794, 22.42374992], [69.59819794, 22.4240303], [69.59764099, 22.4240303], [69.59764099, 22.42432022], [69.5973587, 22.42430496], [69.5973587, 22.42458344], [69.59597015, 22.42458344], [69.59597015, 22.42486191], [69.59570313, 22.42485809], [69.59570313, 22.42514038], [69.59541321, 22.42514038], [69.59541321, 22.42542076], [69.59513855, 22.42541885], [69.59513855, 22.42569351], [69.59486389, 22.42569351], [69.59486389, 22.42597008], [69.5945816, 22.42596817], [69.5945816, 22.42624855], [69.59401703, 22.42624855], [69.59401703, 22.42653084], [69.59375, 22.42653084], [69.59375, 22.42680931], [69.59348297, 22.42680931], [69.59348297, 22.42708969], [69.59319305, 22.42708969], [69.59319305, 22.42735863], [69.5929184, 22.42735863], [69.5929184, 22.42764282], [69.59263611, 22.42764282], [69.59263611, 22.42791939], [69.59236145, 22.42791748], [69.59236145, 22.42819405], [69.59208679, 22.42819405], [69.59208679, 22.43069458], [69.59152985, 22.43069458], [69.59152985, 22.43180466], [69.59124756, 22.43180084], [69.59124756, 22.43292046], [69.59069824, 22.43291664], [69.59069061, 22.43347168], [69.5901413, 22.43346977], [69.5901413, 22.43486023], [69.58985901, 22.43486023], [69.58985901, 22.43514061], [69.5890274, 22.43514061], [69.5890274, 22.43542099], [69.58875275, 22.43541527], [69.58875275, 22.43597221], [69.58847046, 22.43597221], [69.58847046, 22.4370842], [69.5881958, 22.43708038], [69.5881958, 22.43875122], [69.58847046, 22.43875122], [69.58847046, 22.43931961], [69.58875275, 22.43930626], [69.58875275, 22.43958282], [69.58930206, 22.43958282], [69.58930206, 22.43985939], [69.58957672, 22.43985939], [69.58957672, 22.44014168], [69.58985901, 22.44014168], [69.58985901, 22.44153023], [69.5901413, 22.44152832], [69.5901413, 22.44180489], [69.59041595, 22.44180489], [69.59041595, 22.44208336], [69.59069061, 22.44208336], [69.59069824, 22.44236183], [69.59124756, 22.44236183], [69.59124756, 22.44320107], [69.59179688, 22.44320107], [69.59179688, 22.44375038], [69.59236908, 22.44375038], [69.59236908, 22.44403076], [69.59263611, 22.44402695], [69.59263611, 22.44458389], [69.5929184, 22.44458008], [69.5929184, 22.44486046], [69.59319305, 22.44486046], [69.59319305, 22.44513893], [69.59348297, 22.44512939], [69.59348297, 22.44542122], [69.59402466, 22.4454174], [69.59402466, 22.44569588], [69.59486389, 22.44569588], [69.59486389, 22.44597244], [69.59541321, 22.44597054], [69.59541321, 22.44625092], [69.59625244, 22.44625092], [69.59625244, 22.44652939], [69.59680176, 22.44652939], [69.59680176, 22.44680977], [69.59764099, 22.44680405], [69.59764099, 22.44708252], [69.59819794, 22.44708061], [69.59819794, 22.44736099], [69.59902954, 22.44736099], [69.59902954, 22.44763947], [69.6001358, 22.44763947], [69.6001358, 22.44791985], [69.60069275, 22.44791985], [69.60069275, 22.44820023], [69.6020813, 22.4481945], [69.6020813, 22.44847298], [69.60263824, 22.44847107], [69.60263824, 22.44874954], [69.60320282, 22.44874954], [69.60320282, 22.44902992], [69.60375214, 22.44902992], [69.60375214, 22.4493103], [69.60430908, 22.44930649], [69.60430908, 22.44958305], [69.6048584, 22.44958305], [69.6048584, 22.44986153], [69.60542297, 22.44985962], [69.60542297, 22.45013809], [69.60597229, 22.45013809], [69.60597229, 22.45042038], [69.60652924, 22.45042038], [69.60652924, 22.45070076], [69.60708618, 22.45069504], [69.60708618, 22.4509716], [69.60791779, 22.4509697], [69.60791779, 22.45126152], [69.61125183, 22.45126152], [69.61125183, 22.4509697], [69.61180878, 22.4509716], [69.61180878, 22.45069504], [69.61291504, 22.45069504], [69.61291504, 22.4509716], [69.61319733, 22.4509697], [69.61319733, 22.45153046], [69.61347198, 22.45153046], [69.61347198, 22.45181084], [69.61374664, 22.45180511], [69.61374664, 22.45236206], [69.61402893, 22.45235825], [69.61402893, 22.45264053], [69.61430359, 22.45264053], [69.61430359, 22.45347023], [69.61458588, 22.45346832], [69.61458588, 22.45375061], [69.61486053, 22.45375061], [69.61486053, 22.45402908], [69.61513519, 22.45402718], [69.61513519, 22.45430565], [69.61569214, 22.45430565], [69.61569214, 22.45458412], [69.6159668, 22.45458031], [69.6159668, 22.45486259], [69.616539, 22.45486259], [69.616539, 22.45514107], [69.61680603, 22.45514107], [69.61680603, 22.45541954], [69.61736298, 22.45541763], [69.61736298, 22.4556942], [69.61819458, 22.4556942], [69.61819458, 22.45597267], [69.61846924, 22.45597267], [69.61846924, 22.45625114], [69.61875153, 22.45625114], [69.61875153, 22.45681], [69.61958313, 22.45680618], [69.61958313, 22.45708275], [69.62014008, 22.4570694], [69.62014008, 22.45736122], [69.62069702, 22.45736122], [69.62069702, 22.45763969], [69.62152863, 22.45763969], [69.62152863, 22.45792007], [69.62236023, 22.45791626], [69.62236023, 22.45819473], [69.62291718, 22.45819473], [69.62291718, 22.4584713], [69.62374878, 22.45846939], [69.62374878, 22.45874977], [69.62403107, 22.45874977], [69.62403107, 22.45903015], [69.62486267, 22.45902824], [69.62486267, 22.45930481], [69.62541962, 22.45930481], [69.62541962, 22.45958328], [69.62763977, 22.45958328], [69.62763977, 22.45930481], [69.62819672, 22.45930481], [69.62819672, 22.45902824], [69.62874603, 22.45903015], [69.62874603, 22.45874977], [69.62902832, 22.45874977], [69.62902832, 22.45846939], [69.62930298, 22.4584713], [69.62930298, 22.45791626], [69.6295929, 22.45792007], [69.6295929, 22.45763969], [69.63041687, 22.45763969], [69.63041687, 22.45736122], [69.63069153, 22.45736122], [69.63069153, 22.4570694], [69.63097382, 22.45708275], [69.63097382, 22.45680618], [69.63181305, 22.45681], [69.63181305, 22.45652962], [69.63208008, 22.45652962], [69.63208008, 22.45625114], [69.63263702, 22.45625114], [69.63263702, 22.45597267], [69.63346863, 22.45597267], [69.63346863, 22.4556942], [69.63430786, 22.4556942], [69.63430786, 22.45513916], [69.63458252, 22.45514107], [69.63458252, 22.45486259], [69.63485718, 22.45486259], [69.63485718, 22.45429993], [69.63513947, 22.45430565], [69.63513947, 22.45402718], [69.63569641, 22.45402908], [69.63569641, 22.45375061], [69.63625336, 22.45375061], [69.63625336, 22.45346832], [69.63708496, 22.45347023], [69.63708496, 22.45319366], [69.63764191, 22.45319366], [69.63764191, 22.4529171], [69.63819122, 22.45292091], [69.63819122, 22.45264053], [69.63874817, 22.45264053], [69.63874817, 22.45235825], [69.63903046, 22.45236206], [69.63903046, 22.45208359], [69.63930511, 22.45208359], [69.63930511, 22.45180511], [69.63957977, 22.45181084], [69.63957977, 22.45153046], [69.64013672, 22.45153046], [69.64013672, 22.45126152], [69.64041901, 22.45126152], [69.64041901, 22.4509697], [69.64069366, 22.4509716], [69.64069366, 22.45069504], [69.64180756, 22.45069504], [69.64180756, 22.4509716], [69.64263916, 22.4509716], [69.64263916, 22.45069504], [69.64319611, 22.45070076], [69.64319611, 22.45013809], [69.64347839, 22.45013809], [69.64347839, 22.4493103], [69.64375305, 22.4493103], [69.64375305, 22.44874954], [69.64402771, 22.44874954], [69.64402771, 22.44820023], [69.64430237, 22.44820023], [69.64430237, 22.44763947], [69.64457703, 22.44763947], [69.64457703, 22.44708061], [69.64485931, 22.44708252], [69.64485931, 22.44652748], [69.6451416, 22.44652939], [69.6451416, 22.44597054], [69.64541626, 22.44597244], [69.64541626, 22.4454174], [69.64569092, 22.44542122], [69.64569092, 22.44486046], [69.64597321, 22.44486046], [69.64597321, 22.44431114], [69.64624786, 22.44431114], [69.64624786, 22.44375038], [69.64652252, 22.44375038], [69.64652252, 22.44320107], [69.64679718, 22.44320107], [69.64679718, 22.4426403], [69.6470871, 22.4426403], [69.6470871, 22.4420681], [69.64736176, 22.44208336], [69.64736176, 22.44096947], [69.6470871, 22.44096947], [69.6470871, 22.44014168], [69.64736176, 22.44014168], [69.64736176, 22.43985939], [69.6470871, 22.43985939], [69.6470871, 22.43930626], [69.64736176, 22.43931961], [69.64736176, 22.43902969], [69.64763641, 22.43902969], [69.64763641, 22.43875122], [69.6479187, 22.43875122], [69.6479187, 22.43847084], [69.64819336, 22.43847275], [69.64819336, 22.43819427], [69.64847565, 22.43819427], [69.64847565, 22.4370842], [69.64819336, 22.4370842], [69.64819336, 22.43652725], [69.6479187, 22.43653107], [69.6479187, 22.43597031], [69.64763641, 22.43597221], [69.64763641, 22.43541527], [69.6470871, 22.43542099], [69.6470871, 22.43514061], [69.64597321, 22.43514061], [69.64597321, 22.43486023], [69.6451416, 22.43486023], [69.6451416, 22.43457985], [69.64485931, 22.43458366], [69.64485931, 22.43402863], [69.6451416, 22.43403053], [69.6451416, 22.43375015], [69.64541626, 22.43375015], [69.64541626, 22.43346977], [69.64569092, 22.43347168], [69.64569092, 22.43291664], [69.64597321, 22.43292046], [69.64597321, 22.43264008], [69.64679718, 22.43264008], [69.64679718, 22.4323597], [69.64763641, 22.4323616], [69.64763641, 22.43208313], [69.6498642, 22.43208313], [69.6498642, 22.43180466], [69.6506958, 22.43180466], [69.6506958, 22.43152809], [69.65180206, 22.43153], [69.65180206, 22.43124962], [69.65235901, 22.43124962], [69.65235901, 22.43153], [69.6534729, 22.43153], [69.6534729, 22.43124962], [69.65429688, 22.43124962], [69.65429688, 22.43069267], [69.65458679, 22.43069458], [69.65458679, 22.43013954], [69.65486145, 22.43013954], [69.65486145, 22.4295826], [69.65513611, 22.4295826], [69.65513611, 22.42930603], [69.65569305, 22.42930984], [69.65569305, 22.42902946], [69.65598297, 22.42902946], [69.65598297, 22.4287529], [69.65651703, 22.4287529], [69.65651703, 22.42847252], [69.65680695, 22.42847252], [69.65680695, 22.42819405], [69.6570816, 22.42819405], [69.6570816, 22.42624855], [69.65680695, 22.42624855], [69.65680695, 22.4256897], [69.65652466, 22.42569351], [69.65652466, 22.42514038], [69.65625, 22.42514038], [69.65625, 22.42485809], [69.65597534, 22.42486191], [69.65597534, 22.42458344], [69.6554184, 22.42458344], [69.6554184, 22.42430496], [69.65513611, 22.42432022], [69.65513611, 22.4240303], [69.65486145, 22.4240303], [69.65486145, 22.42374992], [69.65458679, 22.42374992], [69.65458679, 22.42346954], [69.65374756, 22.42347145], [69.65374756, 22.42319489], [69.65319824, 22.42319489], [69.65319824, 22.42291641], [69.65264893, 22.42292023], [69.65264893, 22.42263985], [69.65207672, 22.42263985], [69.65207672, 22.42235947], [69.6515274, 22.42236137], [69.6515274, 22.4220829], [69.65125275, 22.4220829], [69.65125275, 22.42180634], [69.64958191, 22.42180634], [69.64958191, 22.4220829], [69.64930725, 22.4220829], [69.64930725, 22.42180634], [69.64903259, 22.42181015], [69.64903259, 22.42152977], [69.64848328, 22.42152977], [69.64848328, 22.42095947], [69.64819336, 22.42097282], [69.64819336, 22.42069435], [69.6479187, 22.42069435], [69.6479187, 22.42041588], [69.64763641, 22.42041969], [69.64763641, 22.41986084], [69.64736176, 22.41986084], [69.64736176, 22.41958046], [69.6470871, 22.41958237], [69.6470871, 22.41875076], [69.64679718, 22.41875076], [69.64679718, 22.41819], [69.64653015, 22.41819382], [69.64653015, 22.41763878], [69.64569092, 22.41764069], [69.64569092, 22.41736031], [69.64541626, 22.41736031], [69.64541626, 22.4168129], [69.64485931, 22.4168129], [69.64485931, 22.41653061], [69.64457703, 22.41653061], [69.64457703, 22.41625023], [69.64430237, 22.41625023], [69.64430237, 22.41597176], [69.64347076, 22.41597366], [69.64347076, 22.41569519], [69.64235687, 22.41570282], [69.64235687, 22.41542053], [69.64208221, 22.41542053], [69.64208221, 22.41514969], [69.64180756, 22.41514969], [69.64180756, 22.41319084], [69.64152527, 22.41319466], [69.64152527, 22.41291618], [69.64125061, 22.41292191], [69.64125061, 22.41235924], [69.64097595, 22.41235924], [69.64097595, 22.41208839], [69.64068604, 22.41208839], [69.64068604, 22.41180992], [69.64041901, 22.41180992], [69.64041901, 22.41152954], [69.64013672, 22.41152954], [69.64013672, 22.41124916], [69.63986206, 22.41124916], [69.63986206, 22.41069031], [69.63957977, 22.41069412], [69.63957977, 22.41041946], [69.63931274, 22.41041946], [69.63931274, 22.41014099], [69.63903046, 22.41014099], [69.63903046, 22.40986061], [69.63874817, 22.40986061], [69.63874817, 22.40875053], [69.63846588, 22.40875053], [69.63846588, 22.40818977], [69.63819122, 22.40819359], [69.63819122, 22.40791512], [69.63791656, 22.40792084], [69.63791656, 22.40764046], [69.63735199, 22.40764046], [69.63735199, 22.40736008], [69.63708496, 22.40736198], [69.63708496, 22.40708351], [69.63680267, 22.40708351], [69.63680267, 22.40680695], [69.63652802, 22.40681076], [69.63652802, 22.40653038], [69.63458252, 22.40653038], [69.63458252, 22.40681076], [69.63291931, 22.40680695], [69.63291931, 22.40708351], [69.63236237, 22.40708351], [69.63236237, 22.40736198], [69.63181305, 22.40736008], [69.63181305, 22.40764046], [69.63124847, 22.40764046], [69.63124847, 22.40792084], [69.63097382, 22.40791512], [69.63097382, 22.40819359], [69.63069153, 22.40819359], [69.63069153, 22.40847206], [69.63041687, 22.40847015], [69.63041687, 22.40875053], [69.62930298, 22.40875053], [69.62930298, 22.40902519], [69.62902832, 22.40901947], [69.62902832, 22.40930939], [69.62819672, 22.40930557], [69.62819672, 22.40958405], [69.62735748, 22.40958023], [69.62735748, 22.40986061], [69.62680817, 22.40986061], [69.62680817, 22.41014099], [69.62596893, 22.41014099], [69.62596893, 22.41041946], [69.62541962, 22.41041946], [69.62541962, 22.41069412], [69.62513733, 22.41069412], [69.62458038, 22.41069412], [69.62458038, 22.4109726], [69.62403107, 22.41097069], [69.62403107, 22.41124916], [69.62319183, 22.41124916], [69.62319183, 22.41152954], [69.6223526, 22.41152954], [69.6223526, 22.41180992], [69.62180328, 22.41180992], [69.62180328, 22.41208839], [69.62097168, 22.41208839], [69.62097168, 22.41235924], [69.6204071, 22.41235924], [69.6204071, 22.41263771], [69.61958313, 22.41263771], [69.61958313, 22.41292191], [69.61902618, 22.41291618], [69.61902618, 22.41319466], [69.61819458, 22.41319466], [69.61819458, 22.41347313], [69.61763763, 22.41346931], [69.61763763, 22.4137516], [69.61708069, 22.4137516], [69.61708069, 22.41403008], [69.61624908, 22.41402817], [69.61624908, 22.41430473], [69.61569214, 22.41430473], [69.61569214, 22.41458321], [69.61514282, 22.41457939], [69.61514282, 22.41570282], [69.61486053, 22.41569519], [69.61486053, 22.41597366], [69.61458588, 22.41597176], [69.61458588, 22.41625023], [69.61429596, 22.41625023], [69.61429596, 22.41653061], [69.61207581, 22.41653061], [69.61207581, 22.4168129], [69.61042023, 22.41680527], [69.61042023, 22.41708374], [69.60986328, 22.41708183], [69.60986328, 22.41736031], [69.60874939, 22.41736031], [69.60874939, 22.41764069], [69.60791779, 22.41764069], [69.60791779, 22.41792107], [69.6076355, 22.41791725], [69.6076355, 22.41847229], [69.60708618, 22.41847038], [69.60708618, 22.41875076]]], [[[69.0901413, 22.43847275], [69.09069061, 22.43847084], [69.09069824, 22.43875122], [69.09152985, 22.43875122], [69.09152985, 22.43902969], [69.09208679, 22.43902969], [69.09208679, 22.43931961], [69.09236145, 22.43930626], [69.09236145, 22.43958282], [69.09263611, 22.43958282], [69.09263611, 22.43985939], [69.09319305, 22.43985939], [69.09319305, 22.44014168], [69.09430695, 22.44014168], [69.09430695, 22.44042015], [69.09513855, 22.44041634], [69.09513855, 22.44069481], [69.09541321, 22.44069481], [69.09541321, 22.44096947], [69.0956955, 22.44096947], [69.0956955, 22.44125175], [69.09597015, 22.44125175], [69.09597015, 22.44236183], [69.09513855, 22.44236183], [69.09513855, 22.44292068], [69.09486389, 22.44291687], [69.09486389, 22.44347382], [69.09513855, 22.44347191], [69.09513855, 22.44431114], [69.09541321, 22.44430542], [69.09541321, 22.44597244], [69.09401703, 22.44597054], [69.09402466, 22.44625092], [69.09348297, 22.44625092], [69.09348297, 22.44680977], [69.09319305, 22.44680977], [69.09319305, 22.44736099], [69.0929184, 22.44736099], [69.0929184, 22.44791985], [69.09263611, 22.44791412], [69.09263611, 22.44847298], [69.09236145, 22.44847107], [69.09236145, 22.44902992], [69.09263611, 22.44902992], [69.09263611, 22.4493103], [69.09319305, 22.44930649], [69.09319305, 22.44958305], [69.09348297, 22.44958115], [69.09348297, 22.45013809], [69.09375, 22.45013809], [69.09375, 22.45042038], [69.09401703, 22.45042038], [69.09401703, 22.45126152], [69.09263611, 22.45126152], [69.09263611, 22.45153046], [69.09236145, 22.45153046], [69.09236145, 22.45208359], [69.09375, 22.45208359], [69.09375, 22.45153046], [69.09401703, 22.45153046], [69.09401703, 22.45402908], [69.09375, 22.45402718], [69.09375, 22.45430565], [69.09347534, 22.45430565], [69.09347534, 22.45458412], [69.09319305, 22.45458031], [69.09319305, 22.45486259], [69.0929184, 22.45486259], [69.0929184, 22.45541954], [69.09263611, 22.45541573], [69.09263611, 22.4556942], [69.09236145, 22.45569038], [69.09236145, 22.45652962], [69.09208679, 22.45652962], [69.09208679, 22.45736122], [69.09236145, 22.45736122], [69.09236145, 22.45903015], [69.09263611, 22.45902824], [69.09263611, 22.45958328], [69.0929184, 22.45958328], [69.0929184, 22.45986176], [69.09319305, 22.45985985], [69.09319305, 22.46014023], [69.09348297, 22.46014023], [69.09348297, 22.46153069], [69.09597015, 22.46153069], [69.09597015, 22.46181107], [69.0984726, 22.46180534], [69.0984726, 22.46208382], [69.09958649, 22.46208], [69.09958649, 22.46236038], [69.1001358, 22.46236038], [69.1001358, 22.46264076], [69.10069275, 22.46264076], [69.10069275, 22.46292114], [69.10124969, 22.46292114], [69.10124969, 22.46319962], [69.10152435, 22.46319389], [69.10152435, 22.46347237], [69.1020813, 22.46347046], [69.1020813, 22.46375084], [69.10235596, 22.46375084], [69.10235596, 22.46403122], [69.1029129, 22.46403122], [69.1029129, 22.46430969], [69.10319519, 22.46430588], [69.10319519, 22.46458244], [69.10375214, 22.46458054], [69.10375214, 22.46486092], [69.10402679, 22.46486092], [69.10402679, 22.46513748], [69.10457611, 22.46513748], [69.10457611, 22.46541977], [69.1048584, 22.46541595], [69.1048584, 22.46569443], [69.10541534, 22.46569443], [69.10541534, 22.4659729], [69.10569763, 22.4659729], [69.10569763, 22.46625137], [69.10665131, 22.46624565], [69.10793304, 22.46623993], [69.10793304, 22.46653175], [69.10958099, 22.46653175], [69.10958099, 22.46681023], [69.11013794, 22.46680641], [69.11013794, 22.46708107], [69.11069489, 22.46708107], [69.11069489, 22.46736145], [69.11125183, 22.46736145], [69.11125183, 22.46764183], [69.11152649, 22.46764183], [69.11152649, 22.4679203], [69.11207581, 22.4679203], [69.11207581, 22.46820259], [69.11264038, 22.46819496], [69.11264038, 22.46846962], [69.11319733, 22.46846962], [69.11319733, 22.46875191], [69.11347198, 22.46875191], [69.11347198, 22.46903038], [69.11402893, 22.46902847], [69.11402893, 22.46930504], [69.11458588, 22.46930504], [69.11458588, 22.46958351], [69.11486053, 22.46958351], [69.11486053, 22.46986389], [69.11541748, 22.46986008], [69.11541748, 22.47014046], [69.11624908, 22.47014046], [69.11624908, 22.47042084], [69.11653137, 22.47041702], [69.11653137, 22.47069359], [69.11708069, 22.47069359], [69.11708069, 22.47097206], [69.11763763, 22.47097015], [69.11763763, 22.47125053], [69.11818695, 22.47125053], [69.11818695, 22.47153091], [69.11902618, 22.47153091], [69.11902618, 22.47180939], [69.11958313, 22.47180557], [69.11958313, 22.47208595], [69.12014008, 22.47208023], [69.12014008, 22.47236061], [69.12124634, 22.47236061], [69.12124634, 22.47264099], [69.12152863, 22.47264099], [69.12152863, 22.47291946], [69.12208557, 22.47291756], [69.12208557, 22.47319412], [69.12236023, 22.47319412], [69.12236023, 22.4734726], [69.12293243, 22.47347069], [69.12293243, 22.47375107], [69.12319183, 22.47375107], [69.12319183, 22.47402954], [69.12374878, 22.47402954], [69.12374878, 22.47430992], [69.12403107, 22.4743042], [69.12403107, 22.47458267], [69.12458038, 22.47458076], [69.12458038, 22.47486115], [69.12486267, 22.47486115], [69.12486267, 22.47513962], [69.12513733, 22.47513962], [69.12513733, 22.47542953], [69.12569427, 22.47541618], [69.12569427, 22.47569466], [69.12875366, 22.47569466], [69.12875366, 22.47597313], [69.12985992, 22.47597122], [69.12985992, 22.47624969], [69.13096619, 22.47624969], [69.13096619, 22.47652817], [69.13180542, 22.47652626], [69.13180542, 22.47680473], [69.13291931, 22.47680473], [69.13291931, 22.47708321], [69.13402557, 22.47708321], [69.13402557, 22.47736168], [69.13513947, 22.47735977], [69.13513947, 22.47763824], [69.13680267, 22.47763824], [69.13680267, 22.47735977], [69.13735962, 22.47736168], [69.13735962, 22.47708321], [69.13764191, 22.47708321], [69.13764191, 22.47680473], [69.13791656, 22.47680473], [69.13791656, 22.47708321], [69.1423645, 22.47708321], [69.1423645, 22.47736168], [69.14319611, 22.47736168], [69.14319611, 22.47708321], [69.14347076, 22.47708321], [69.14347076, 22.47652626], [69.14375305, 22.47652817], [69.14375305, 22.47624969], [69.14404297, 22.47624969], [69.14402771, 22.47541618], [69.14430237, 22.47542953], [69.14430237, 22.47513962], [69.14485931, 22.47513962], [69.14485931, 22.47486115], [69.14541626, 22.47486115], [69.14541626, 22.47458076], [69.14680481, 22.47458267], [69.14680481, 22.4743042], [69.14763641, 22.47430992], [69.14763641, 22.47402954], [69.14848328, 22.47402954], [69.14848328, 22.47153091], [69.14875031, 22.47153091], [69.14875031, 22.47125053], [69.14903259, 22.47125053], [69.14902496, 22.47097206], [69.14930725, 22.47097206], [69.14930725, 22.47069359], [69.14958191, 22.47069359], [69.14958191, 22.47041702], [69.15013885, 22.47042084], [69.15013885, 22.47014046], [69.15040588, 22.47014046], [69.15040588, 22.46875191], [69.15013885, 22.46875191], [69.15013885, 22.46846962], [69.1498642, 22.46846962], [69.1498642, 22.46819496], [69.14958191, 22.46820259], [69.14958191, 22.4679203], [69.14930725, 22.4679203], [69.14930725, 22.46764183], [69.14903259, 22.46764183], [69.14903259, 22.46736145], [69.14875031, 22.46736145], [69.14875031, 22.46708107], [69.1479187, 22.46708107], [69.1479187, 22.46680641], [69.14736176, 22.46681023], [69.14736176, 22.46653175], [69.14710236, 22.46653175], [69.14710236, 22.46596909], [69.14680481, 22.4659729], [69.14680481, 22.46513748], [69.1470871, 22.46513748], [69.1470871, 22.46458244], [69.14680481, 22.46458244], [69.14680481, 22.46319389], [69.14653015, 22.46319962], [69.14653015, 22.46292114], [69.14624786, 22.46292114], [69.14624786, 22.46264076], [69.14569092, 22.46264076], [69.14569092, 22.46236038], [69.14485931, 22.46236038], [69.14485931, 22.46208], [69.14430237, 22.46208], [69.14430237, 22.46236038], [69.14404297, 22.46236038], [69.14404297, 22.46264076], [69.14347076, 22.46264076], [69.14347076, 22.46319962], [69.14319611, 22.46319389], [69.14319611, 22.46347237], [69.14290619, 22.46347046], [69.14290619, 22.46375084], [69.14235687, 22.46375084], [69.14235687, 22.46403122], [69.1415329, 22.46403122], [69.1415329, 22.46430969], [69.14069366, 22.46430588], [69.14069366, 22.46458244], [69.13986206, 22.46458244], [69.13986206, 22.46291542], [69.13957977, 22.46292114], [69.13957977, 22.46264076], [69.13903046, 22.46264076], [69.13903046, 22.46236038], [69.13735962, 22.46236038], [69.13735962, 22.46264076], [69.13708496, 22.46263885], [69.13708496, 22.46347237], [69.13680267, 22.46347046], [69.13680267, 22.46403122], [69.13652802, 22.46403122], [69.13652802, 22.46430969], [69.13625336, 22.46430588], [69.13625336, 22.46458244], [69.13540649, 22.46458054], [69.13540649, 22.46486092], [69.13513947, 22.46486092], [69.13513947, 22.46541977], [69.13486481, 22.46541595], [69.13486481, 22.46569443], [69.13458252, 22.46569443], [69.13458252, 22.4659729], [69.13402557, 22.4659729], [69.13402557, 22.46569443], [69.13346863, 22.46569443], [69.13346863, 22.4659729], [69.13291931, 22.4659729], [69.13291931, 22.46625137], [69.13263702, 22.46623993], [69.13263702, 22.46653175], [69.13208008, 22.46653175], [69.13208008, 22.46623993], [69.13180542, 22.46625137], [69.13180542, 22.4659729], [69.13153076, 22.4659729], [69.13153076, 22.46569443], [69.13124847, 22.46569443], [69.13124847, 22.46541595], [69.12985992, 22.46541595], [69.12985992, 22.46569443], [69.12847137, 22.46569443], [69.12847137, 22.46541595], [69.12652588, 22.46541595], [69.12652588, 22.46569443], [69.12625122, 22.46569443], [69.12625122, 22.46625137], [69.12596893, 22.46623993], [69.12596893, 22.46681023], [69.12569427, 22.46680641], [69.12569427, 22.46708107], [69.12513733, 22.46708107], [69.12513733, 22.46736145], [69.12458038, 22.46736145], [69.12458038, 22.46764183], [69.12431335, 22.46764183], [69.12431335, 22.4679203], [69.12374878, 22.4679203], [69.12374878, 22.46820259], [69.12319183, 22.46819496], [69.12319183, 22.46846962], [69.12236023, 22.46846962], [69.12236023, 22.46819496], [69.12124634, 22.46820259], [69.12124634, 22.4679203], [69.12097168, 22.4679203], [69.12097168, 22.46764183], [69.11987305, 22.46764183], [69.11987305, 22.46736145], [69.11846924, 22.46736145], [69.11846924, 22.46708107], [69.11791992, 22.46708107], [69.11791992, 22.46680641], [69.11736298, 22.46681023], [69.11736298, 22.46653175], [69.11708069, 22.46653175], [69.11708069, 22.46623993], [69.11653137, 22.46625137], [69.11653137, 22.4659729], [69.11597443, 22.4659729], [69.11597443, 22.46569443], [69.11430359, 22.46569443], [69.11430359, 22.46541595], [69.11373901, 22.46541977], [69.11373901, 22.46513748], [69.11319733, 22.46513748], [69.11319733, 22.46486092], [69.11264038, 22.46486092], [69.11264038, 22.46458054], [69.11208344, 22.46458244], [69.11208344, 22.46430588], [69.11152649, 22.46430969], [69.11152649, 22.46403122], [69.11096954, 22.46403122], [69.11096954, 22.46375084], [69.11067963, 22.46375084], [69.11067963, 22.46347046], [69.11042023, 22.46347237], [69.11042023, 22.46319389], [69.11013794, 22.46319962], [69.11013794, 22.46264076], [69.10986328, 22.46264076], [69.10986328, 22.46236038], [69.10930634, 22.46236038], [69.10930634, 22.46181107], [69.10874939, 22.46181107], [69.10874939, 22.46125031], [69.1084671, 22.46125031], [69.1084671, 22.46070099], [69.10819244, 22.46070099], [69.10819244, 22.45792007], [69.1084671, 22.45792007], [69.1084671, 22.45652962], [69.10874939, 22.45652962], [69.10874939, 22.45569038], [69.10902405, 22.4556942], [69.10902405, 22.45402718], [69.10930634, 22.45402908], [69.10930634, 22.45235825], [69.10902405, 22.45235825], [69.10901642, 22.45207977], [69.10874939, 22.45208359], [69.10874939, 22.44874954], [69.1084671, 22.44874954], [69.1084671, 22.44847107], [69.10819244, 22.44847298], [69.10819244, 22.44791412], [69.10793304, 22.44791985], [69.10793304, 22.44708061], [69.1076355, 22.44708252], [69.1076355, 22.44597244], [69.10736084, 22.44597244], [69.10736084, 22.44486046], [69.10708618, 22.44486046], [69.10708618, 22.44236183], [69.10736084, 22.44236183], [69.10736084, 22.44180489], [69.1076355, 22.44180489], [69.1076355, 22.44069481], [69.10736084, 22.44069481], [69.10736084, 22.43930626], [69.10764313, 22.43931961], [69.10764313, 22.43875122], [69.10793304, 22.43875122], [69.10793304, 22.43791962], [69.10819244, 22.43791962], [69.10819244, 22.43764114], [69.1084671, 22.43764114], [69.1084671, 22.43736076], [69.10791779, 22.43736076], [69.10791779, 22.4370842], [69.10708618, 22.4370842], [69.10708618, 22.43680573], [69.10679626, 22.43680954], [69.10679626, 22.43653107], [69.10652924, 22.43653107], [69.10652924, 22.43625832], [69.10624695, 22.43625832], [69.10624695, 22.43514061], [69.10597229, 22.43514061], [69.10597229, 22.43486023], [69.10569763, 22.43486023], [69.10569763, 22.43457985], [69.10514069, 22.43458366], [69.10514069, 22.43430519], [69.1048584, 22.43431091], [69.1048584, 22.43403053], [69.10457611, 22.43403053], [69.10457611, 22.43375015], [69.10430908, 22.43375015], [69.10430908, 22.43346977], [69.10402679, 22.43347168], [69.10402679, 22.43291664], [69.10375214, 22.43292046], [69.10375214, 22.43264008], [69.10150909, 22.43264008], [69.10150909, 22.43292046], [69.10097504, 22.43291664], [69.10097504, 22.43319321], [69.1001358, 22.43319321], [69.1001358, 22.43291664], [69.09958649, 22.43292046], [69.09958649, 22.43264008], [69.09929657, 22.43264008], [69.09929657, 22.4323597], [69.09902954, 22.4323616], [69.09902954, 22.43180466], [69.0984726, 22.43180466], [69.0984726, 22.43152809], [69.09597015, 22.43153], [69.09597015, 22.43124962], [69.09513855, 22.43124962], [69.09513855, 22.43097115], [69.09486389, 22.43097305], [69.09486389, 22.43069458], [69.09430695, 22.43069458], [69.09430695, 22.43041611], [69.09401703, 22.43041992], [69.09401703, 22.43013191], [69.09347534, 22.43013954], [69.09347534, 22.42986107], [69.09319305, 22.42986107], [69.09319305, 22.4295826], [69.09263611, 22.4295826], [69.09263611, 22.42930603], [69.09236145, 22.42930984], [69.09236145, 22.42902946], [69.09179688, 22.42902946], [69.09179688, 22.4287529], [69.09152985, 22.4287529], [69.09152985, 22.42847252], [69.09124756, 22.42847252], [69.09124756, 22.42819405], [69.09069824, 22.42819405], [69.09069824, 22.42791748], [69.09041595, 22.42791939], [69.09041595, 22.42735863], [69.0901413, 22.42735863], [69.0901413, 22.42680931], [69.08985901, 22.42680931], [69.08985901, 22.42653084], [69.08956909, 22.42653084], [69.08956909, 22.42596817], [69.08930206, 22.42597008], [69.08930206, 22.42374992], [69.0890274, 22.42374992], [69.0890274, 22.42346954], [69.08875275, 22.42347145], [69.08875275, 22.42319489], [69.08847046, 22.42319489], [69.08847046, 22.42263794], [69.0881958, 22.42263985], [69.0881958, 22.42208099], [69.08791351, 22.4220829], [69.08791351, 22.42180634], [69.08735657, 22.42181015], [69.08735657, 22.42152977], [69.08653259, 22.42152977], [69.08653259, 22.42124939], [69.08597565, 22.42124939], [69.08597565, 22.42097282], [69.08486176, 22.42095947], [69.08486176, 22.42124939], [69.0845871, 22.42124939], [69.0845871, 22.42152977], [69.08430481, 22.42152786], [69.08430481, 22.4220829], [69.08376312, 22.42208099], [69.08376312, 22.42263985], [69.08347321, 22.42263985], [69.08347321, 22.42374992], [69.08376312, 22.42374992], [69.08376312, 22.42542076], [69.08403015, 22.42542076], [69.08403015, 22.42653084], [69.0845871, 22.42653084], [69.0845871, 22.42680931], [69.08486176, 22.42680931], [69.08486176, 22.42735863], [69.08513641, 22.42735863], [69.08513641, 22.4287529], [69.0854187, 22.4287529], [69.0854187, 22.42902946], [69.08569336, 22.42902946], [69.08569336, 22.42930984], [69.08597565, 22.42930603], [69.08597565, 22.4295826], [69.08569336, 22.4295826], [69.08569336, 22.43041992], [69.0854187, 22.43041611], [69.0854187, 22.43097115], [69.0854187, 22.43124962], [69.08513641, 22.43124962], [69.08513641, 22.43180466], [69.08486176, 22.43180466], [69.08486176, 22.43208313], [69.08513641, 22.43208122], [69.08513641, 22.43264008], [69.0854187, 22.43264008], [69.0854187, 22.43292046], [69.08652496, 22.43291664], [69.08652496, 22.43319321], [69.08708191, 22.43319321], [69.08708191, 22.43347168], [69.08763885, 22.43346977], [69.08763885, 22.43375015], [69.0881958, 22.43375015], [69.0881958, 22.43403053], [69.08875275, 22.43403053], [69.08875275, 22.43431091], [69.08930206, 22.43431091], [69.08930206, 22.43486023], [69.08956909, 22.43486023], [69.08956909, 22.43542099], [69.08985901, 22.43541527], [69.08985901, 22.43569374], [69.09041595, 22.43569374], [69.09041595, 22.43597221], [69.09069061, 22.43597031], [69.09069061, 22.43625069], [69.09069824, 22.43680954], [69.0909729, 22.43680954], [69.0909729, 22.43736076], [69.09069824, 22.43736076], [69.09069061, 22.43791962], [69.0901413, 22.4379158], [69.0901413, 22.43847275]]], [[[69.14208221, 22.45763969], [69.14208221, 22.4570694], [69.14180756, 22.45708275], [69.14180756, 22.45560837], [69.14180756, 22.45430565], [69.14208221, 22.45430565], [69.14208221, 22.45375061], [69.14235687, 22.45375061], [69.14235687, 22.45346832], [69.14263916, 22.45347023], [69.14263916, 22.4529171], [69.14180756, 22.4529171], [69.14180756, 22.45319366], [69.14152527, 22.45319366], [69.14152527, 22.45347023], [69.14125061, 22.45346832], [69.14125061, 22.45402908], [69.14097595, 22.45402718], [69.14097595, 22.45458412], [69.14069366, 22.45458412], [69.14069366, 22.4550209], [69.14069366, 22.45597267], [69.14096832, 22.45597267], [69.14096832, 22.45681], [69.14125061, 22.45681], [69.14125061, 22.45736122], [69.14152527, 22.45736122], [69.14152527, 22.45763969], [69.14208221, 22.45763969]]], [[[69.0890274, 22.49069405], [69.0890274, 22.49041939], [69.08930206, 22.49043083], [69.08930206, 22.49014091], [69.0890274, 22.49014091], [69.0890274, 22.48986053], [69.08875275, 22.48986053], [69.08875275, 22.48931122], [69.08847046, 22.48931122], [69.08847046, 22.48875046], [69.0881958, 22.48875046], [69.0881958, 22.48847008], [69.08791351, 22.48847198], [69.08791351, 22.48819351], [69.08763885, 22.48819351], [69.08763885, 22.48791695], [69.08682251, 22.48792076], [69.08682251, 22.48736954], [69.08653259, 22.48736954], [69.08653259, 22.48707962], [69.08680725, 22.48708344], [69.08680725, 22.48680305], [69.08653259, 22.48681068], [69.08653259, 22.4865303], [69.08625031, 22.4865303], [69.08625031, 22.48624992], [69.08597565, 22.48624992], [69.08597565, 22.48597145], [69.0854187, 22.48597145], [69.0854187, 22.48569489], [69.08513641, 22.48569489], [69.08513641, 22.48541641], [69.08486176, 22.48542023], [69.08486176, 22.48513985], [69.08403015, 22.48513794], [69.08403015, 22.48569489], [69.08430481, 22.48569489], [69.08430481, 22.48597145], [69.0845871, 22.48597145], [69.0845871, 22.48708344], [69.08486176, 22.48707962], [69.08486176, 22.48764038], [69.08513641, 22.48763847], [69.08513641, 22.4881897], [69.0854187, 22.48819542], [69.0854187, 22.48847198], [69.08569336, 22.48847008], [69.08569336, 22.48875046], [69.08598328, 22.48875046], [69.08598328, 22.48903084], [69.08653259, 22.48903084], [69.08653259, 22.48931122], [69.08680725, 22.4893055], [69.08680725, 22.48958397], [69.08708191, 22.48958015], [69.08708191, 22.48986053], [69.08735657, 22.48986053], [69.08735657, 22.49014091], [69.08790588, 22.49014091], [69.08790588, 22.49043083], [69.08847046, 22.49041939], [69.08847046, 22.49069405], [69.0890274, 22.49069405]]], [[[69.32428741, 22.52763939], [69.32428741, 22.52736092], [69.32485962, 22.52736092], [69.32485962, 22.52708054], [69.32541656, 22.52708244], [69.32541656, 22.52680588], [69.32596588, 22.52680969], [69.32596588, 22.52654076], [69.32624817, 22.52654076], [69.32624817, 22.52625084], [69.32681274, 22.52625084], [69.32680511, 22.52597237], [69.32736206, 22.52597237], [69.32736206, 22.5256958], [69.32791901, 22.5256958], [69.32791901, 22.52541733], [69.32875061, 22.52542114], [69.32875061, 22.52514076], [69.3290329, 22.52514076], [69.3290329, 22.52486038], [69.32930756, 22.52486038], [69.32930756, 22.52458191], [69.33013916, 22.52458382], [69.33013916, 22.52430534], [69.33097076, 22.52430534], [69.33097076, 22.52458382], [69.33125305, 22.52458191], [69.33125305, 22.52486038], [69.33180237, 22.52486038], [69.33180237, 22.52514076], [69.33207703, 22.52514076], [69.33207703, 22.52542114], [69.33235931, 22.52541733], [69.33235931, 22.5256958], [69.33291626, 22.5256958], [69.33291626, 22.52597237], [69.33403015, 22.52597237], [69.33403015, 22.5256958], [69.33985901, 22.5256958], [69.33985901, 22.52541733], [69.34041595, 22.52542114], [69.34041595, 22.52514076], [69.34319305, 22.52514076], [69.34319305, 22.52542114], [69.34347534, 22.52541733], [69.34347534, 22.52597237], [69.34401703, 22.52597046], [69.34401703, 22.52625084], [69.34430695, 22.52625084], [69.34430695, 22.52654076], [69.34485626, 22.52654076], [69.34485626, 22.52680969], [69.3456955, 22.52680588], [69.3456955, 22.52708244], [69.3484726, 22.52708244], [69.3484726, 22.52680588], [69.34874725, 22.52680969], [69.34874725, 22.52625084], [69.34929657, 22.52625084], [69.34929657, 22.52597046], [69.34958649, 22.52597237], [69.34958649, 22.52541733], [69.34986115, 22.52541733], [69.34986115, 22.5256958], [69.3501358, 22.52569008], [69.3501358, 22.52625084], [69.35041809, 22.52625084], [69.35041809, 22.52654076], [69.35124969, 22.52654076], [69.35124969, 22.52625084], [69.35151672, 22.52625084], [69.35151672, 22.52597046], [69.35180664, 22.52597237], [69.35180664, 22.5256958], [69.3520813, 22.5256958], [69.3520813, 22.52541733], [69.35235596, 22.52542114], [69.35235596, 22.52514076], [69.35263824, 22.52514076], [69.35263824, 22.52486038], [69.35320282, 22.52486038], [69.35319519, 22.52458382], [69.35346985, 22.52458382], [69.35346985, 22.52430534], [69.35402679, 22.52431107], [69.35402679, 22.52403069], [69.35459137, 22.52403069], [69.35459137, 22.52375031], [69.3548584, 22.52375031], [69.3548584, 22.52347946], [69.35514069, 22.52347946], [69.35514069, 22.5232029], [69.35542297, 22.5232029], [69.35542297, 22.52292061], [69.35597229, 22.52292061], [69.35597229, 22.52264023], [69.35624695, 22.52264023], [69.35624695, 22.52236176], [69.35652924, 22.52236176], [69.35652924, 22.52208328], [69.35680389, 22.52208328], [69.35680389, 22.52180481], [69.35708618, 22.52180481], [69.35708618, 22.52125168], [69.35736084, 22.52125168], [69.35736084, 22.52096939], [69.3576355, 22.52096939], [69.3576355, 22.52069473], [69.35791779, 22.52069473], [69.35791779, 22.5201416], [69.35819244, 22.5201416], [69.35819244, 22.51985931], [69.3584671, 22.51985931], [69.3584671, 22.51958084], [69.35874939, 22.51958275], [69.35874939, 22.51930618], [69.35901642, 22.51930809], [69.35901642, 22.51874924], [69.35930634, 22.51874924], [69.35930634, 22.51847076], [69.35958099, 22.51847267], [69.35958099, 22.5181942], [69.35986328, 22.5181942], [69.35986328, 22.51763725], [69.36013794, 22.51764107], [69.36013794, 22.51708031], [69.36042023, 22.51708412], [69.36042023, 22.51652527], [69.36068726, 22.51653099], [69.36068726, 22.51625061], [69.36096954, 22.51625061], [69.36096954, 22.51568985], [69.36125183, 22.51569366], [69.36125183, 22.51513863], [69.36235809, 22.51514053], [69.36235809, 22.51486015], [69.36264038, 22.51486206], [69.36264038, 22.51458359], [69.36291504, 22.51458359], [69.36291504, 22.51375008], [69.36347198, 22.51375008], [69.36345673, 22.51320076], [69.36374664, 22.51320076], [69.36374664, 22.51300049], [69.36374664, 22.51236153], [69.36347198, 22.51236153], [69.36347198, 22.51180649], [69.36319733, 22.51180077], [69.36319733, 22.51152802], [69.36264038, 22.51153946], [69.36264038, 22.51124954], [69.36235809, 22.51124954], [69.36235809, 22.51097107], [69.36180878, 22.51097488], [69.36180878, 22.5106945], [69.36125183, 22.5106945], [69.36125183, 22.51041603], [69.36013794, 22.51041985], [69.36013794, 22.51013947], [69.35930634, 22.51013947], [69.35930634, 22.5098629], [69.35819244, 22.5098629], [69.35819244, 22.50958252], [69.35708618, 22.50958252], [69.35708618, 22.50930595], [69.35652924, 22.50930977], [69.35652924, 22.50902939], [69.35624695, 22.50902939], [69.35624695, 22.50847244], [69.35597229, 22.50847244], [69.35597229, 22.50819397], [69.35569763, 22.50819397], [69.35569763, 22.5079174], [69.35542297, 22.50792122], [69.35542297, 22.50764275], [69.35514069, 22.50764275], [69.35514069, 22.50735855], [69.35458374, 22.50735855], [69.35458374, 22.50708389], [69.35430908, 22.50708389], [69.35430908, 22.50680542], [69.35402679, 22.50680923], [69.35402679, 22.50653076], [69.35375214, 22.50653076], [69.35375214, 22.50624847], [69.35346985, 22.50624847], [69.35346985, 22.50596809], [69.35319519, 22.50597191], [69.35319519, 22.50569534], [69.35263824, 22.50569916], [69.35263824, 22.50541115], [69.35236359, 22.50541878], [69.35236359, 22.5051384], [69.3520813, 22.5051384], [69.3520813, 22.50485992], [69.35152435, 22.50486183], [69.35152435, 22.50458336], [69.35041809, 22.50458336], [69.35041809, 22.50430489], [69.3501358, 22.50430489], [69.3501358, 22.50402641], [69.3493042, 22.50402641], [69.3493042, 22.50430489], [69.3484726, 22.50430489], [69.3484726, 22.50402641], [69.34708405, 22.50402641], [69.34708405, 22.50430489], [69.3465271, 22.50430489], [69.3465271, 22.50458336], [69.34625244, 22.50458336], [69.34625244, 22.50486183], [69.34542084, 22.50485992], [69.34542084, 22.5051384], [69.34486389, 22.5051384], [69.34486389, 22.50541878], [69.34401703, 22.50541115], [69.34401703, 22.50569916], [69.34347534, 22.50569534], [69.34347534, 22.50597191], [69.3429184, 22.50596809], [69.3429184, 22.50624847], [69.34236145, 22.50624847], [69.34236145, 22.50653076], [69.34152985, 22.50653076], [69.34152985, 22.50680923], [69.3409729, 22.50680542], [69.3409729, 22.50708389], [69.34041595, 22.50707817], [69.34041595, 22.50735855], [69.33970642, 22.50735855], [69.33513641, 22.50735855], [69.33513641, 22.50764275], [69.3345871, 22.50764275], [69.3345871, 22.50792122], [69.33403015, 22.5079174], [69.33403015, 22.50819397], [69.33347321, 22.50819397], [69.33347321, 22.50847244], [69.33291626, 22.50847244], [69.33291626, 22.50875282], [69.3326416, 22.50875282], [69.3326416, 22.50902939], [69.33207703, 22.50902939], [69.33207703, 22.50930977], [69.33152771, 22.50930595], [69.33152771, 22.50958252], [69.33097076, 22.50958252], [69.33097076, 22.5098629], [69.33041382, 22.5098629], [69.33042145, 22.51013947], [69.32985687, 22.51013947], [69.32985687, 22.51041985], [69.32958221, 22.51041603], [69.32958221, 22.5106945], [69.32902527, 22.5106945], [69.32902527, 22.51097488], [69.32875061, 22.51097107], [69.32875061, 22.51124954], [69.32818604, 22.51124954], [69.32818604, 22.51153946], [69.32791901, 22.51152802], [69.32791901, 22.51180077], [69.32736206, 22.51180649], [69.32736206, 22.51208305], [69.32707977, 22.51208305], [69.32707977, 22.51236153], [69.32653046, 22.51235962], [69.32653046, 22.51264], [69.32624817, 22.51264], [69.32624817, 22.51292038], [69.32569122, 22.51292038], [69.32569122, 22.51320076], [69.32514191, 22.51319313], [69.32514191, 22.5134716], [69.32485962, 22.5134697], [69.32485962, 22.51375008], [69.32428741, 22.51375008], [69.32428741, 22.51403046], [69.32402802, 22.51403046], [69.32402802, 22.51431084], [69.32347107, 22.51430511], [69.32347107, 22.51458359], [69.32319641, 22.51457977], [69.32319641, 22.51486015], [69.32263947, 22.51486015], [69.32263947, 22.51514053], [69.32235718, 22.51514053], [69.32235718, 22.51542091], [69.32180786, 22.51541519], [69.32180786, 22.51569366], [69.32152557, 22.51569366], [69.32152557, 22.51597214], [69.32125092, 22.51597023], [69.32125092, 22.51625061], [69.32068634, 22.51625061], [69.32068634, 22.51653099], [69.32041931, 22.51653099], [69.32041931, 22.51680946], [69.32013702, 22.51680565], [69.32013702, 22.51708412], [69.31986237, 22.51708412], [69.31986237, 22.51736069], [69.31931305, 22.51735115], [69.31931305, 22.51764107], [69.31903076, 22.51764107], [69.31903076, 22.51791954], [69.31874847, 22.51791573], [69.31874847, 22.5181942], [69.31819153, 22.5181942], [69.31819153, 22.51847267], [69.31791687, 22.51847076], [69.31791687, 22.51874924], [69.31764221, 22.51874924], [69.31764221, 22.51902962], [69.3170929, 22.51902962], [69.3170929, 22.51930809], [69.31652832, 22.51930618], [69.31652832, 22.51958275], [69.31597137, 22.51958084], [69.31597137, 22.51985931], [69.31569672, 22.51985931], [69.31569672, 22.52069473], [69.3154068, 22.52069092], [69.3154068, 22.52292061], [69.31569672, 22.52292061], [69.31569672, 22.52347946], [69.31597137, 22.52347946], [69.31597137, 22.52403069], [69.31625366, 22.52402687], [69.31625366, 22.52458382], [69.31652832, 22.52458191], [69.31652832, 22.52486038], [69.31680298, 22.52486038], [69.31680298, 22.52514076], [69.3170929, 22.52514076], [69.3170929, 22.52542114], [69.31735992, 22.52541733], [69.31735992, 22.5256958], [69.31791687, 22.5256958], [69.31791687, 22.52597237], [69.31930542, 22.52597237], [69.31930542, 22.52625084], [69.31986237, 22.52625084], [69.31986237, 22.52654076], [69.32041931, 22.52654076], [69.32041931, 22.52680969], [69.32069397, 22.52680588], [69.32069397, 22.52708244], [69.32125092, 22.52708054], [69.32125092, 22.52736092], [69.32180786, 22.52736092], [69.32180786, 22.52763939], [69.32428741, 22.52763939]]], [[[69.30208588, 22.47402954], [69.30208588, 22.47347069], [69.30236053, 22.4734726], [69.30236053, 22.47319412], [69.30263519, 22.47319412], [69.30263519, 22.47236061], [69.30291748, 22.47236061], [69.30291748, 22.47208023], [69.30319214, 22.47208595], [69.30319214, 22.47180557], [69.3034668, 22.47180939], [69.3034668, 22.47125053], [69.30374908, 22.47125053], [69.30374908, 22.47042084], [69.30403137, 22.47042084], [69.30403137, 22.46986008], [69.30430603, 22.46986389], [69.30430603, 22.46958351], [69.30486298, 22.46958351], [69.30486298, 22.46986389], [69.30513763, 22.46986008], [69.30513763, 22.47042084], [69.30486298, 22.47041702], [69.30486298, 22.47069359], [69.30458069, 22.47068977], [69.30458069, 22.47153091], [69.30486298, 22.47153091], [69.30486298, 22.47180939], [69.30708313, 22.47180557], [69.30708313, 22.47208595], [69.30902863, 22.47208595], [69.30902863, 22.47180557], [69.31291962, 22.47180557], [69.31291962, 22.47208595], [69.31513977, 22.47208023], [69.31513977, 22.47236061], [69.31874847, 22.47236061], [69.31874847, 22.47208023], [69.31930542, 22.47208595], [69.31930542, 22.47180557], [69.31986237, 22.47180939], [69.31986237, 22.47153091], [69.32041931, 22.47153091], [69.32041931, 22.47125053], [69.32096863, 22.47125053], [69.32096863, 22.47097015], [69.32180786, 22.47097206], [69.32180786, 22.47069359], [69.32236481, 22.47069359], [69.32236481, 22.47041702], [69.32290649, 22.47042084], [69.32290649, 22.47014046], [69.32347107, 22.47014046], [69.32347107, 22.46986008], [69.32402802, 22.46986389], [69.32402802, 22.46958351], [69.32458496, 22.46958351], [69.32458496, 22.46902847], [69.32485962, 22.46903038], [69.32485962, 22.46820259], [69.32514191, 22.46820259], [69.32514191, 22.4679203], [69.32485962, 22.4679203], [69.32485962, 22.46764183], [69.32514191, 22.46764183], [69.32514191, 22.46736145], [69.32541656, 22.46736145], [69.32541656, 22.46708107], [69.32569122, 22.46708107], [69.32569122, 22.46680641], [69.32596588, 22.46681023], [69.32596588, 22.46623993], [69.32624817, 22.46625137], [69.32624817, 22.46513748], [69.32653046, 22.46513748], [69.32653046, 22.46458054], [69.32680511, 22.46458244], [69.32680511, 22.46430588], [69.32707977, 22.46430969], [69.32707977, 22.46403122], [69.3273468, 22.46403122], [69.3273468, 22.46375084], [69.32763672, 22.46375084], [69.32763672, 22.46347046], [69.32791901, 22.46347237], [69.32791901, 22.46208382], [69.32763672, 22.46208382], [69.32763672, 22.46041679], [69.3273468, 22.46042061], [69.3273468, 22.45874977], [69.32707977, 22.45874977], [69.32707977, 22.45763969], [69.32680511, 22.45763969], [69.32680511, 22.45708275], [69.32653046, 22.45708275], [69.32653046, 22.45680618], [69.32624817, 22.45681], [69.32624817, 22.45652962], [69.32596588, 22.45652962], [69.32596588, 22.45625114], [69.32569122, 22.45625114], [69.32569122, 22.45597267], [69.32541656, 22.45597267], [69.32541656, 22.4556942], [69.32514191, 22.4556942], [69.32514191, 22.45541573], [69.32485962, 22.45541954], [69.32485962, 22.45514107], [69.32457733, 22.45514107], [69.32457733, 22.45486259], [69.32428741, 22.45486259], [69.32428741, 22.45458031], [69.32402802, 22.45458412], [69.32402802, 22.45430565], [69.32375336, 22.45430565], [69.32375336, 22.45402718], [69.32347107, 22.45402908], [69.32347107, 22.45375061], [69.32319641, 22.45375061], [69.32319641, 22.45346832], [69.32291412, 22.45347023], [69.32291412, 22.45319366], [69.32263947, 22.45319366], [69.32263947, 22.45264053], [69.32208252, 22.45264053], [69.32208252, 22.45235825], [69.32180786, 22.45235825], [69.32180786, 22.45207977], [69.32152557, 22.45208359], [69.32152557, 22.45153046], [69.32068634, 22.45153046], [69.32068634, 22.45126152], [69.32041931, 22.45126152], [69.32041931, 22.4509697], [69.31819153, 22.4509697], [69.31819153, 22.45126152], [69.31735992, 22.45126152], [69.31735992, 22.45153046], [69.31624603, 22.45153046], [69.31624603, 22.45126152], [69.31597137, 22.45126152], [69.31597137, 22.45153046], [69.31532288, 22.45153046], [69.31069183, 22.45153046], [69.31069183, 22.45208359], [69.31041718, 22.45208359], [69.31041718, 22.45180511], [69.31014252, 22.45181084], [69.31014252, 22.45153046], [69.30960083, 22.45153046], [69.30960083, 22.45181084], [69.30847168, 22.45180511], [69.30847168, 22.45208359], [69.30764008, 22.45207977], [69.30764008, 22.45235825], [69.30654144, 22.45235825], [69.30654144, 22.45264053], [69.30568695, 22.45264053], [69.30568695, 22.45292091], [69.30541992, 22.4529171], [69.30541992, 22.45319366], [69.30430603, 22.45319366], [69.30430603, 22.45347023], [69.30347443, 22.45347023], [69.30347443, 22.45319366], [69.30263519, 22.45319366], [69.30263519, 22.4529171], [69.30124664, 22.4529171], [69.30124664, 22.45319366], [69.30097198, 22.45319366], [69.30097198, 22.45347023], [69.30069733, 22.45346832], [69.30069733, 22.45375061], [69.30014038, 22.45375061], [69.30014038, 22.45430565], [69.29985809, 22.45429993], [69.29985809, 22.45541954], [69.29958344, 22.45541573], [69.29958344, 22.4556942], [69.29930878, 22.45569038], [69.29930878, 22.45625114], [69.29902649, 22.45625114], [69.29902649, 22.45652962], [69.29818726, 22.45652962], [69.29818726, 22.45681], [69.29792023, 22.45680618], [69.29792023, 22.45708275], [69.29734802, 22.4570694], [69.29734802, 22.45736122], [69.29708099, 22.45736122], [69.29708099, 22.45763969], [69.29624939, 22.45763969], [69.29624939, 22.45792007], [69.29597473, 22.45791626], [69.29597473, 22.45819473], [69.2951355, 22.45819473], [69.2951355, 22.4584713], [69.29402924, 22.45846939], [69.29402924, 22.45874977], [69.29291534, 22.45874977], [69.29291534, 22.45930481], [69.29319763, 22.45930481], [69.29319763, 22.45986176], [69.29347229, 22.45985985], [69.29347229, 22.46042061], [69.29374695, 22.46041679], [69.29374695, 22.46097183], [69.29402924, 22.46096992], [69.29402924, 22.46153069], [69.29430389, 22.46152687], [69.29430389, 22.46208382], [69.29460144, 22.46208], [69.29460144, 22.46264076], [69.29486084, 22.46264076], [69.29486084, 22.46292114], [69.2951355, 22.46291542], [69.2951355, 22.46347237], [69.29541779, 22.46347046], [69.29541779, 22.46375084], [69.29569244, 22.46375084], [69.29569244, 22.46486092], [69.2959671, 22.46486092], [69.2959671, 22.46541977], [69.29624939, 22.46541595], [69.29624939, 22.46569443], [69.29651642, 22.46569061], [69.29651642, 22.46653175], [69.29680634, 22.46653175], [69.29680634, 22.46681023], [69.29708099, 22.46680641], [69.29708099, 22.46736145], [69.29734802, 22.46736145], [69.29734802, 22.4679203], [69.29763794, 22.4679203], [69.29763794, 22.46820259], [69.29792023, 22.46820259], [69.29792023, 22.46903038], [69.29819489, 22.46902847], [69.29819489, 22.46986389], [69.29846954, 22.46986389], [69.29846954, 22.47069359], [69.29875183, 22.47068977], [69.29875183, 22.47125053], [69.29902649, 22.47125053], [69.29902649, 22.47153091], [69.29930878, 22.47153091], [69.29930878, 22.47180939], [69.29957581, 22.47180939], [69.29957581, 22.47236061], [69.29985809, 22.47236061], [69.29985809, 22.47264099], [69.30014038, 22.47264099], [69.30014038, 22.47291946], [69.30041504, 22.47291756], [69.30041504, 22.47319412], [69.30069733, 22.47319031], [69.30069733, 22.47375107], [69.30124664, 22.47375107], [69.30124664, 22.47402954], [69.30208588, 22.47402954]]], [[[69.40513611, 22.53264046], [69.40513611, 22.5320797], [69.4054184, 22.53208351], [69.4054184, 22.53097153], [69.40569305, 22.53097153], [69.40569305, 22.52902794], [69.4059906, 22.52902985], [69.4059906, 22.52847099], [69.40625, 22.5284729], [69.40625, 22.52791405], [69.40651703, 22.52791977], [69.40651703, 22.52708054], [69.40625, 22.52708244], [69.40625, 22.5265274], [69.4059906, 22.52654076], [69.4059906, 22.52542114], [69.40570068, 22.52542114], [69.40570068, 22.52514076], [69.40513611, 22.52514076], [69.40513611, 22.52486038], [69.40458679, 22.52486038], [69.40458679, 22.52458191], [69.4043045, 22.52458382], [69.4043045, 22.52430534], [69.40319824, 22.52430534], [69.40319061, 22.52458382], [69.40291595, 22.52458191], [69.40291595, 22.52486038], [69.4026413, 22.52486038], [69.4026413, 22.52514076], [69.40235901, 22.52514076], [69.40235901, 22.52542114], [69.40207672, 22.52542114], [69.40207672, 22.52625084], [69.40180206, 22.52625084], [69.40180206, 22.52819443], [69.40207672, 22.52819061], [69.40207672, 22.52902985], [69.40235901, 22.52902794], [69.40235901, 22.52986145], [69.4026413, 22.52985954], [69.4026413, 22.5304203], [69.40291595, 22.5304203], [69.40291595, 22.53124809], [69.40319061, 22.53124809], [69.40319824, 22.53208351], [69.4034729, 22.53208351], [69.4034729, 22.53236008], [69.40374756, 22.53235054], [69.40374756, 22.53264046], [69.40513611, 22.53264046]]], [[[69.91124725, 22.54792023], [69.91124725, 22.54875183], [69.91152954, 22.54875183], [69.91152954, 22.54931068], [69.91124725, 22.54930496], [69.91124725, 22.54958344], [69.9109726, 22.54958344], [69.9109726, 22.54986382], [69.90958405, 22.54986382], [69.90958405, 22.54958344], [69.90791321, 22.54958344], [69.90791321, 22.54986382], [69.90763855, 22.54986191], [69.90763855, 22.55042076], [69.90735626, 22.55042076], [69.90735626, 22.55153084], [69.90875244, 22.55153084], [69.90875244, 22.55181122], [69.91041565, 22.5518055], [69.91041565, 22.55208206], [69.91152954, 22.55208015], [69.91152954, 22.55236053], [69.9126358, 22.55236053], [69.9126358, 22.55264091], [69.91348267, 22.55264091], [69.91348267, 22.55291939], [69.9145813, 22.55291939], [69.9145813, 22.55264091], [69.91570282, 22.55264091], [69.91570282, 22.55291939], [69.91680908, 22.55291748], [69.91680908, 22.55319595], [69.91874695, 22.55319595], [69.91874695, 22.55291748], [69.91902924, 22.55291939], [69.91902924, 22.55264091], [69.91929626, 22.55264091], [69.91929626, 22.55236053], [69.91986084, 22.55236053], [69.91986084, 22.55208015], [69.9201355, 22.55208206], [69.9201355, 22.5518055], [69.92041016, 22.55181122], [69.92041016, 22.55153084], [69.92069244, 22.55153084], [69.92069244, 22.55125046], [69.92124939, 22.55125046], [69.92124939, 22.55097008], [69.92152405, 22.55097389], [69.92152405, 22.55069542], [69.92180634, 22.5506897], [69.92180634, 22.55041695], [69.92208099, 22.55042076], [69.92208099, 22.55014038], [69.92236328, 22.55014038], [69.92236328, 22.54986191], [69.92263794, 22.54986382], [69.92263794, 22.54958344], [69.92319489, 22.54958344], [69.92319489, 22.54930496], [69.92346954, 22.54931068], [69.92346954, 22.5490303], [69.92402649, 22.5490303], [69.92402649, 22.54875183], [69.92430878, 22.54875183], [69.92430878, 22.54846954], [69.92485809, 22.54846954], [69.92485809, 22.54819489], [69.92514038, 22.54819489], [69.92514038, 22.54791641], [69.92569733, 22.54792023], [69.92569733, 22.54764938], [69.92653656, 22.54764938], [69.92653656, 22.54735947], [69.92708588, 22.54735947], [69.92708588, 22.5470829], [69.92791748, 22.5470829], [69.92791748, 22.54680634], [69.9284668, 22.54681015], [69.9284668, 22.54653168], [69.92930603, 22.54653168], [69.92930603, 22.54624748], [69.92986298, 22.54624748], [69.92986298, 22.54597092], [69.93069458, 22.54597282], [69.93069458, 22.54569435], [69.93125153, 22.54569435], [69.93125153, 22.54541588], [69.93180847, 22.54541969], [69.93180847, 22.54486084], [69.93208313, 22.54486084], [69.93208313, 22.54458046], [69.93235779, 22.54458427], [69.93235779, 22.54208374], [69.93208313, 22.54208374], [69.93208313, 22.54041672], [69.93264008, 22.54042053], [69.93264008, 22.54014015], [69.93319702, 22.54014015], [69.93319702, 22.53992081], [69.93319702, 22.53902817], [69.9329071, 22.53903008], [69.9329071, 22.53763962], [69.93208313, 22.53763962], [69.93208313, 22.53652954], [69.93374634, 22.53652954], [69.93374634, 22.5359726], [69.93402863, 22.5359726], [69.93402863, 22.53541756], [69.93430328, 22.53541946], [69.93430328, 22.53403091], [69.93402863, 22.53403091], [69.93402863, 22.53374863], [69.93374634, 22.53374863], [69.93374634, 22.53346825], [69.93319702, 22.53347015], [69.93319702, 22.53319359], [69.93291473, 22.53319359], [69.93291473, 22.53291893], [69.93208313, 22.53292084], [69.93208313, 22.53264046], [69.93125153, 22.53264046], [69.93125153, 22.53235054], [69.93096924, 22.53236008], [69.93096924, 22.53208351], [69.93041992, 22.53208351], [69.93041992, 22.53180504], [69.92986298, 22.53181076], [69.92986298, 22.53153038], [69.92958069, 22.53153038], [69.92958069, 22.53070068], [69.93152618, 22.53070068], [69.93152618, 22.53124809], [69.93235016, 22.53124809], [69.93235016, 22.53153038], [69.9329071, 22.53153038], [69.9329071, 22.53181076], [69.93319702, 22.53180504], [69.93319702, 22.53208351], [69.93347168, 22.53208351], [69.93347168, 22.53236008], [69.93402863, 22.53235054], [69.93402863, 22.53264046], [69.93430328, 22.53264046], [69.93430328, 22.53292084], [69.93458557, 22.53291893], [69.93458557, 22.53319359], [69.93486023, 22.53319359], [69.93486023, 22.53347015], [69.93569183, 22.53347015], [69.93569183, 22.53319359], [69.93597412, 22.53319359], [69.93597412, 22.52791405], [69.93569183, 22.52791977], [69.93569183, 22.52736092], [69.93540955, 22.52736092], [69.93540955, 22.52680969], [69.93514252, 22.52680969], [69.93514252, 22.52625084], [69.93486023, 22.52625084], [69.93486023, 22.52569008], [69.93458557, 22.5256958], [69.93458557, 22.52541733], [69.93514252, 22.52542114], [69.93514252, 22.52514076], [69.93569183, 22.52514076], [69.93569183, 22.52542114], [69.93597412, 22.52541733], [69.93597412, 22.5256958], [69.93624878, 22.52569008], [69.93624878, 22.52654076], [69.93653107, 22.52654076], [69.93653107, 22.52680969], [69.93681335, 22.52680969], [69.93681335, 22.52902985], [69.93708038, 22.52902794], [69.93708038, 22.52958298], [69.93680573, 22.52958298], [69.93680573, 22.52986145], [69.93708038, 22.52985954], [69.93708038, 22.53181076], [69.93763733, 22.53181076], [69.93763733, 22.53153038], [69.93791962, 22.53153038], [69.93791962, 22.53124809], [69.93847656, 22.53124809], [69.93846893, 22.53097153], [69.93875122, 22.53097153], [69.93875122, 22.53069496], [69.93930817, 22.53070068], [69.93930817, 22.5304203], [69.93958282, 22.5304203], [69.93958282, 22.53013992], [69.9404068, 22.53013992], [69.9404068, 22.52985954], [69.94069672, 22.52986145], [69.94069672, 22.52958298], [69.94097137, 22.52958298], [69.94097137, 22.52930641], [69.94153595, 22.52931023], [69.94153595, 22.52874947], [69.94208527, 22.52874947], [69.94208527, 22.52819443], [69.94235992, 22.52819443], [69.94235992, 22.52763939], [69.94291687, 22.52763939], [69.94291687, 22.52680969], [69.94319153, 22.52680969], [69.94319153, 22.52569008], [69.94347382, 22.5256958], [69.94347382, 22.52486038], [69.94374847, 22.52486038], [69.94374847, 22.52403069], [69.94403076, 22.52403069], [69.94403076, 22.52347946], [69.94431305, 22.52347946], [69.94431305, 22.52292061], [69.94403076, 22.52292061], [69.94403076, 22.52179909], [69.94374847, 22.52180481], [69.94374847, 22.52096939], [69.94347382, 22.52096939], [69.94347382, 22.52041626], [69.94319153, 22.52041626], [69.94319153, 22.51985931], [69.94291687, 22.51985931], [69.94291687, 22.51958084], [69.94264221, 22.51958275], [69.94264221, 22.51902962], [69.94235992, 22.51902962], [69.94235992, 22.51874924], [69.9420929, 22.51874924], [69.9420929, 22.51847076], [69.94180298, 22.51847267], [69.94180298, 22.5181942], [69.94152832, 22.5181942], [69.94152832, 22.51791573], [69.94041443, 22.51791573], [69.94041443, 22.5181942], [69.93791962, 22.5181942], [69.93791962, 22.51847267], [69.93708038, 22.51847076], [69.93708038, 22.51874924], [69.93653107, 22.51874924], [69.93653107, 22.51847076], [69.93374634, 22.51847076], [69.93374634, 22.51874924], [69.93319702, 22.51874924], [69.93319702, 22.51902962], [69.9329071, 22.51902962], [69.9329071, 22.51985931], [69.93264008, 22.51985931], [69.93264008, 22.5201416], [69.93125153, 22.5201416], [69.93125153, 22.51958084], [69.93096924, 22.51958275], [69.93096924, 22.51902962], [69.93068695, 22.51902962], [69.93068695, 22.51791954], [69.93013763, 22.51791954], [69.93013763, 22.51764107], [69.92958069, 22.51764107], [69.92958069, 22.51735115], [69.92903137, 22.51736069], [69.92903137, 22.51708412], [69.92819214, 22.51708412], [69.92819214, 22.51680565], [69.92764282, 22.51680946], [69.92764282, 22.51653099], [69.92708588, 22.51653099], [69.92708588, 22.51625061], [69.92597198, 22.51625061], [69.92597198, 22.51597023], [69.92541504, 22.51597214], [69.92541504, 22.51569366], [69.92514038, 22.51569366], [69.92514038, 22.51541519], [69.92457581, 22.51542091], [69.92457581, 22.51514053], [69.92375183, 22.51514053], [69.92375183, 22.51486015], [69.92319489, 22.51486015], [69.92318726, 22.51457977], [69.92236328, 22.51458359], [69.92236328, 22.51430511], [69.92151642, 22.51431084], [69.92151642, 22.51403046], [69.9209671, 22.51403046], [69.9209671, 22.51375008], [69.9201355, 22.51375008], [69.9201355, 22.5134716], [69.91930389, 22.5134716], [69.91930389, 22.51319313], [69.91847229, 22.51320076], [69.91847229, 22.51292038], [69.91792297, 22.51292038], [69.91792297, 22.51264], [69.91707611, 22.51264], [69.91707611, 22.51235962], [69.91625214, 22.51236153], [69.91625214, 22.51208305], [69.91569519, 22.51208305], [69.91569519, 22.51180649], [69.91236115, 22.51180649], [69.91236115, 22.51208305], [69.91042328, 22.51208115], [69.91042328, 22.51264], [69.90957642, 22.51264], [69.90957642, 22.51292038], [69.90847015, 22.51292038], [69.90847015, 22.51320076], [69.90791321, 22.51319313], [69.90791321, 22.5134716], [69.90541077, 22.5134697], [69.90541077, 22.51375008], [69.90374756, 22.51375008], [69.90374756, 22.51403046], [69.9034729, 22.51403046], [69.9034729, 22.51431084], [69.9006958, 22.51431084], [69.9006958, 22.51403046], [69.89736176, 22.51403046], [69.89736176, 22.51375008], [69.8970871, 22.51375008], [69.8970871, 22.51264], [69.89736176, 22.51264], [69.89736176, 22.5118103], [69.89653015, 22.51180649], [69.89653015, 22.51208305], [69.89597321, 22.51208305], [69.89597321, 22.51236153], [69.8951416, 22.51235962], [69.8951416, 22.51264], [69.89457703, 22.51264], [69.89457703, 22.51292038], [69.89375305, 22.51292038], [69.89375305, 22.51320076], [69.89319611, 22.51319313], [69.89319611, 22.5134716], [69.89263916, 22.5134697], [69.89263916, 22.51375008], [69.89235687, 22.51375008], [69.89235687, 22.51403046], [69.89180756, 22.51403046], [69.89180756, 22.51431084], [69.89069366, 22.51430511], [69.89069366, 22.51458359], [69.89041901, 22.51458359], [69.89041901, 22.51486015], [69.89013672, 22.51486015], [69.89013672, 22.51514053], [69.88986206, 22.51514053], [69.88986206, 22.51542091], [69.88903046, 22.51541519], [69.88903046, 22.51569366], [69.88819122, 22.51569366], [69.88819122, 22.51597214], [69.88764191, 22.51597023], [69.88764191, 22.51680946], [69.88735962, 22.51680565], [69.88735962, 22.51708412], [69.88652802, 22.51708412], [69.88652802, 22.51736069], [69.88597107, 22.51735115], [69.88597107, 22.51764107], [69.88485718, 22.51764107], [69.88485718, 22.51791954], [69.88430023, 22.51791954], [69.88430023, 22.51902962], [69.88458252, 22.51902962], [69.88458252, 22.51958275], [69.88430023, 22.51958084], [69.88430023, 22.51985931], [69.88346863, 22.51985931], [69.88346863, 22.5201416], [69.88124847, 22.5201416], [69.88124847, 22.52041626], [69.88041687, 22.52041626], [69.88041687, 22.52069473], [69.87954712, 22.52069473], [69.87625122, 22.52069473], [69.87625122, 22.52096939], [69.87403107, 22.52096939], [69.87403107, 22.52125168], [69.87319183, 22.52125168], [69.87319183, 22.52153015], [69.87281036, 22.52152824], [69.87264252, 22.52152824], [69.87264252, 22.52180481], [69.87152863, 22.52180481], [69.87152863, 22.52208328], [69.87041473, 22.52208328], [69.87041473, 22.52236176], [69.87014008, 22.52236176], [69.87014008, 22.52264023], [69.86930084, 22.52264023], [69.86930084, 22.52292061], [69.86902618, 22.52292061], [69.86902618, 22.5232029], [69.86878967, 22.52319717], [69.86846924, 22.5232029], [69.86846924, 22.52347946], [69.86763763, 22.52347946], [69.86763763, 22.52375031], [69.86736298, 22.52375031], [69.86736298, 22.52403069], [69.86680603, 22.52403069], [69.86680603, 22.52431107], [69.86653137, 22.52430534], [69.86653137, 22.52458382], [69.86624908, 22.52458382], [69.86624908, 22.52430534], [69.86597443, 22.52430534], [69.86597443, 22.52458382], [69.86541748, 22.52458191], [69.86541748, 22.52486038], [69.86486053, 22.52486038], [69.86486053, 22.52514076], [69.86458588, 22.52514076], [69.86458588, 22.52542114], [69.86430359, 22.52541733], [69.86430359, 22.5256958], [69.86402893, 22.5256958], [69.86402893, 22.52597237], [69.86347198, 22.52597046], [69.86347198, 22.52625084], [69.86319733, 22.52625084], [69.86319733, 22.52654076], [69.86292267, 22.52654076], [69.86292267, 22.52680969], [69.86264038, 22.52680588], [69.86264038, 22.52708244], [69.86235809, 22.52708054], [69.86235809, 22.52931023], [69.86319733, 22.52930641], [69.86319733, 22.52958298], [69.86430359, 22.52958298], [69.86430359, 22.52986145], [69.86458588, 22.52985954], [69.86458588, 22.5304203], [69.86486053, 22.5304203], [69.86486053, 22.53070068], [69.86513519, 22.53069496], [69.86513519, 22.53097153], [69.86541748, 22.53096962], [69.86541748, 22.53124809], [69.86569214, 22.53124809], [69.86569214, 22.53096962], [69.86736298, 22.53097153], [69.86736298, 22.53069496], [69.86846924, 22.53070068], [69.86846924, 22.5304203], [69.86958313, 22.5304203], [69.86958313, 22.53013992], [69.8704071, 22.53013992], [69.8704071, 22.52985954], [69.87097168, 22.52986145], [69.87097168, 22.52958298], [69.87291718, 22.52958298], [69.87291718, 22.52930641], [69.87374878, 22.52931023], [69.87374878, 22.52903938], [69.87458038, 22.52902985], [69.87458038, 22.52874947], [69.87542725, 22.52874947], [69.87541962, 22.5284729], [69.87680817, 22.5284729], [69.87680817, 22.52819443], [69.87763977, 22.52819443], [69.87763977, 22.52791405], [69.87819672, 22.52791977], [69.87819672, 22.52763939], [69.87874603, 22.52763939], [69.87902832, 22.52763939], [69.87902832, 22.52736092], [69.8795929, 22.52736092], [69.87958527, 22.52708244], [69.88041687, 22.52708244], [69.88041687, 22.52680588], [69.88124084, 22.52680969], [69.88124084, 22.52654076], [69.88181305, 22.52654076], [69.88181305, 22.52625084], [69.88263702, 22.52625084], [69.88263702, 22.52569008], [69.88346863, 22.5256958], [69.88346863, 22.52541733], [69.8840332, 22.52542114], [69.8840332, 22.52514076], [69.88458252, 22.52514076], [69.88458252, 22.52486038], [69.88540649, 22.52486038], [69.88540649, 22.52458191], [69.88625336, 22.52458382], [69.88625336, 22.52430534], [69.88819122, 22.52431107], [69.88819122, 22.52403069], [69.88931274, 22.52403069], [69.88931274, 22.52375031], [69.88986206, 22.52375031], [69.88986206, 22.52347946], [69.89041901, 22.52347374], [69.89041901, 22.52375031], [69.89097595, 22.52375031], [69.89097595, 22.52403069], [69.89180756, 22.52403069], [69.89180756, 22.52431107], [69.8923645, 22.52430534], [69.8923645, 22.52458382], [69.89290619, 22.52458191], [69.89290619, 22.52486038], [69.89319611, 22.52486038], [69.89319611, 22.52514076], [69.89347076, 22.52514076], [69.89347076, 22.52347946], [69.89375305, 22.52347946], [69.89375305, 22.5232029], [69.89457703, 22.5232029], [69.89457703, 22.52292061], [69.8951416, 22.52292061], [69.8951416, 22.5232029], [69.89541626, 22.5232029], [69.89541626, 22.52347946], [69.89569092, 22.52347946], [69.89569092, 22.52375031], [69.89597321, 22.52375031], [69.89597321, 22.52403069], [69.89624023, 22.52403069], [69.89624023, 22.52431107], [69.89680481, 22.52430534], [69.89680481, 22.52458382], [69.89763641, 22.52458191], [69.89763641, 22.52486038], [69.89875031, 22.52486038], [69.89875031, 22.52514076], [69.89903259, 22.52514076], [69.89903259, 22.52542114], [69.89930725, 22.52541733], [69.89930725, 22.5256958], [69.89958191, 22.5256958], [69.89958191, 22.52597237], [69.89930725, 22.52597046], [69.89930725, 22.52680969], [69.89958191, 22.52680588], [69.89958191, 22.52708244], [69.9006958, 22.52708054], [69.9006958, 22.52736092], [69.90097046, 22.52736092], [69.90097046, 22.52763939], [69.90125275, 22.52763939], [69.90125275, 22.5284729], [69.90040588, 22.52847099], [69.90040588, 22.52874947], [69.89819336, 22.52874947], [69.89819336, 22.53013992], [69.89848328, 22.53013992], [69.89848328, 22.5304203], [69.89819336, 22.53041649], [69.89819336, 22.53097153], [69.89847565, 22.53097153], [69.89847565, 22.53374863], [69.89958191, 22.53374863], [69.89958191, 22.53403091], [69.89985657, 22.53403091], [69.89985657, 22.53486252], [69.89958191, 22.53486252], [69.89958191, 22.53541946], [69.89930725, 22.53541756], [69.89930725, 22.53569412], [69.89903259, 22.53569031], [69.89903259, 22.53625107], [69.89875031, 22.53624916], [69.89875031, 22.53819466], [69.89903259, 22.53819275], [69.89903259, 22.53848076], [69.90013885, 22.53848076], [69.90013885, 22.53874969], [69.90040588, 22.53874969], [69.90040588, 22.53903008], [69.9006958, 22.53902817], [69.9006958, 22.54097176], [69.90040588, 22.54096985], [69.90040588, 22.54236031], [69.90013885, 22.54236031], [69.90013885, 22.54375076], [69.89985657, 22.54375076], [69.89985657, 22.54514122], [69.90013885, 22.54513741], [69.90013885, 22.54569435], [69.90040588, 22.54569054], [69.90040588, 22.54624748], [69.9006958, 22.54624748], [69.9006958, 22.54653168], [69.90097046, 22.54653168], [69.90097046, 22.54681015], [69.90125275, 22.54680634], [69.90125275, 22.5470829], [69.9015274, 22.5470829], [69.9015274, 22.54735947], [69.90207672, 22.54735947], [69.90207672, 22.54764938], [69.90236664, 22.54764938], [69.90236664, 22.54792023], [69.90319061, 22.54791641], [69.90319824, 22.54828644], [69.90319824, 22.54846954], [69.90374756, 22.54846954], [69.90374756, 22.5490303], [69.90486145, 22.5490303], [69.90486145, 22.54931068], [69.90651703, 22.54931068], [69.90651703, 22.5490303], [69.90680695, 22.5490303], [69.90680695, 22.54846954], [69.90652466, 22.54846954], [69.90652466, 22.54819489], [69.90680695, 22.54819489], [69.90680695, 22.54597282], [69.9081955, 22.54597282], [69.9081955, 22.54624748], [69.90875244, 22.54624748], [69.90875244, 22.54653168], [69.91014099, 22.54653168], [69.91014099, 22.54681015], [69.91041565, 22.54680634], [69.91041565, 22.5470829], [69.91069794, 22.5470829], [69.91069794, 22.54735947], [69.9109726, 22.54735947], [69.9109726, 22.54792023], [69.91124725, 22.54792023]]], [[[69.94486237, 22.53236008], [69.94486237, 22.53208351], [69.94569397, 22.53208351], [69.94569397, 22.53180504], [69.9465332, 22.53181076], [69.9465332, 22.53153038], [69.94708252, 22.53153038], [69.94708252, 22.53124809], [69.94734955, 22.53124809], [69.94734955, 22.53096962], [69.94763947, 22.53097153], [69.94763947, 22.53041649], [69.94734955, 22.5304203], [69.94734955, 22.53013992], [69.94680786, 22.53013992], [69.94680786, 22.52985954], [69.94625092, 22.52986145], [69.94625092, 22.52958298], [69.94541931, 22.52958298], [69.94541931, 22.52986145], [69.94458008, 22.52985954], [69.94458008, 22.53013992], [69.94403076, 22.53013992], [69.94403076, 22.5304203], [69.94347382, 22.53041649], [69.94347382, 22.53208351], [69.94374847, 22.53208351], [69.94374847, 22.53236008], [69.94486237, 22.53236008]]], [[[70.02430725, 22.55319595], [70.02430725, 22.55291748], [70.02458191, 22.55291939], [70.02458191, 22.55181122], [70.02403259, 22.55181122], [70.02403259, 22.55153084], [70.02375031, 22.55153084], [70.02375031, 22.55125046], [70.02347565, 22.55125046], [70.02347565, 22.55097389], [70.02319336, 22.55097389], [70.02319336, 22.55069351], [70.0229187, 22.55069351], [70.0229187, 22.55041695], [70.02263641, 22.55042076], [70.02263641, 22.55014038], [70.02236176, 22.55014038], [70.02236176, 22.54986191], [70.0220871, 22.54986382], [70.0220871, 22.54958344], [70.02153015, 22.54958344], [70.02153015, 22.54930496], [70.02097321, 22.54931068], [70.02097321, 22.5490303], [70.02069092, 22.5490303], [70.02069092, 22.54875183], [70.02041626, 22.54875183], [70.02041626, 22.54818916], [70.01985931, 22.54819489], [70.01985931, 22.54791641], [70.01790619, 22.54792023], [70.01790619, 22.54764938], [70.01763916, 22.54764938], [70.01763916, 22.54792023], [70.01569366, 22.54791641], [70.01569366, 22.54819489], [70.01457977, 22.54819489], [70.01457977, 22.54846954], [70.01374817, 22.54846954], [70.0137558, 22.54875183], [70.01291656, 22.54875183], [70.01291656, 22.5490303], [70.01235962, 22.5490303], [70.01235962, 22.54931068], [70.01180267, 22.54930496], [70.01180267, 22.54958344], [70.01152802, 22.54958344], [70.01152802, 22.54986382], [70.01235962, 22.54986191], [70.01235962, 22.55014038], [70.01291656, 22.55014038], [70.01291656, 22.55042076], [70.01374817, 22.55041695], [70.0137558, 22.5506897], [70.01457977, 22.55069542], [70.01457977, 22.55097389], [70.01513672, 22.55097008], [70.01513672, 22.55125046], [70.01597595, 22.55125046], [70.01597595, 22.55153084], [70.01790619, 22.55153084], [70.01790619, 22.55181122], [70.01985931, 22.5518055], [70.01985931, 22.55208206], [70.02097321, 22.55208015], [70.02097321, 22.55236053], [70.02179718, 22.55236053], [70.02179718, 22.55264091], [70.0229187, 22.55264091], [70.0229187, 22.55291939], [70.02375031, 22.55291748], [70.02375031, 22.55319595], [70.02430725, 22.55319595]]], [[[69.95735931, 22.5359726], [69.95735931, 22.53541756], [69.9576416, 22.53541946], [69.9576416, 22.5351429], [69.95735931, 22.5351429], [69.95735931, 22.53486252], [69.95722961, 22.53486252], [69.95707703, 22.53486252], [69.95707703, 22.53430939], [69.95680237, 22.53430939], [69.95680237, 22.53403091], [69.95540619, 22.53403091], [69.95540619, 22.53374863], [69.95513916, 22.53374863], [69.95513916, 22.53346825], [69.95430756, 22.53347015], [69.95430756, 22.53319359], [69.95402527, 22.53319359], [69.95402527, 22.53291893], [69.95375061, 22.53292084], [69.95375061, 22.53264046], [69.95236969, 22.53264046], [69.95236206, 22.53292084], [69.95263672, 22.53291893], [69.95263672, 22.53347015], [69.95291901, 22.53346825], [69.95291901, 22.53374863], [69.95318604, 22.53374863], [69.95318604, 22.53403091], [69.95347595, 22.5340271], [69.95347595, 22.53458405], [69.95375061, 22.53458023], [69.95375061, 22.53486252], [69.9540329, 22.53486252], [69.9540329, 22.5351429], [69.95458221, 22.5351429], [69.95458221, 22.53541946], [69.9548645, 22.53541756], [69.9548645, 22.53569412], [69.95513916, 22.53569412], [69.95513916, 22.5359726], [69.95707703, 22.5359726], [69.95735931, 22.5359726]]], [[[69.9604187, 22.54375076], [69.9604187, 22.54347038], [69.96097565, 22.54347229], [69.96097565, 22.54319382], [69.96180725, 22.54319382], [69.96180725, 22.54291534], [69.96264648, 22.54292107], [69.96264648, 22.54264069], [69.96290588, 22.54264069], [69.96290588, 22.54236031], [69.96347046, 22.54236031], [69.96347046, 22.54181099], [69.9631958, 22.54181099], [69.9631958, 22.54152107], [69.96263885, 22.5415287], [69.96263885, 22.54125023], [69.96251678, 22.54125023], [69.96180725, 22.54125023], [69.96180725, 22.54114151], [69.96180725, 22.54097176], [69.96152496, 22.54097176], [69.96152496, 22.54069519], [69.96098328, 22.54070091], [69.96098328, 22.54042053], [69.96069336, 22.54042053], [69.96069336, 22.54014015], [69.9604187, 22.54014015], [69.9604187, 22.53985977], [69.95986176, 22.53986168], [69.95986176, 22.53958321], [69.9595871, 22.53958321], [69.9595871, 22.53930473], [69.95930481, 22.53930473], [69.95930481, 22.53902817], [69.95903015, 22.53903008], [69.95903015, 22.53848076], [69.95819092, 22.53848076], [69.95819092, 22.53819275], [69.9576416, 22.53819466], [69.9576416, 22.53806114], [69.9576416, 22.53791618], [69.95752716, 22.53791618], [69.95652008, 22.53792], [69.95652008, 22.53763962], [69.95625305, 22.53763962], [69.95625305, 22.53736115], [69.95597076, 22.53736115], [69.95597076, 22.53708267], [69.95541382, 22.53708267], [69.95541382, 22.53680611], [69.95513916, 22.53680992], [69.95513916, 22.53652954], [69.95485687, 22.53652954], [69.95485687, 22.53625107], [69.95458221, 22.53625107], [69.95458221, 22.5359726], [69.9540329, 22.5359726], [69.9540329, 22.53652954], [69.95430756, 22.53652954], [69.95430756, 22.53680992], [69.95458221, 22.53680611], [69.95458221, 22.53708267], [69.95485687, 22.53708267], [69.95485687, 22.53763962], [69.95540619, 22.53763962], [69.95540619, 22.53792], [69.95569611, 22.53792], [69.95569611, 22.53848076], [69.95597076, 22.53848076], [69.95597076, 22.53903008], [69.95625305, 22.53902817], [69.95625305, 22.53930473], [69.95652771, 22.53930473], [69.95652771, 22.53986168], [69.95680237, 22.53985977], [69.95680237, 22.54014015], [69.95707703, 22.54014015], [69.95707703, 22.54070091], [69.95735931, 22.54070091], [69.95735931, 22.54125023], [69.9576416, 22.54125023], [69.9576416, 22.5415287], [69.95791626, 22.5415287], [69.95791626, 22.54208374], [69.95819092, 22.54207993], [69.95819092, 22.54264069], [69.95847321, 22.54264069], [69.95847321, 22.54292107], [69.95874786, 22.54291534], [69.95874786, 22.54319382], [69.95903015, 22.54319382], [69.95903015, 22.54347229], [69.95929718, 22.54347038], [69.95929718, 22.54375076], [69.9604187, 22.54375076]]], [[[69.95207977, 22.55125046], [69.95207977, 22.55097008], [69.95236206, 22.55097389], [69.95236206, 22.55069542], [69.95263672, 22.5506897], [69.95263672, 22.55041695], [69.95291901, 22.55042076], [69.95291901, 22.55014038], [69.95318604, 22.55014038], [69.95318604, 22.54986191], [69.95347595, 22.54986382], [69.95347595, 22.54958344], [69.95375061, 22.54958344], [69.95375061, 22.54930496], [69.9540329, 22.54931068], [69.9540329, 22.5490303], [69.95430756, 22.5490303], [69.95430756, 22.54875183], [69.95458221, 22.54875183], [69.95458221, 22.54846954], [69.9548645, 22.54846954], [69.9548645, 22.54819489], [69.95513916, 22.54819489], [69.95513916, 22.54791641], [69.95540619, 22.54792023], [69.95540619, 22.54764938], [69.95569611, 22.54764938], [69.95569611, 22.54707909], [69.95597076, 22.5470829], [69.95597076, 22.54680634], [69.95625305, 22.54681015], [69.95625305, 22.54653168], [69.95652008, 22.54653168], [69.95652008, 22.54624748], [69.95680237, 22.54624748], [69.95680237, 22.54597092], [69.95708466, 22.54597282], [69.95708466, 22.54569435], [69.95735931, 22.54569435], [69.95735931, 22.54513741], [69.9576416, 22.54514122], [69.9576416, 22.54403114], [69.95735931, 22.54403114], [69.95735931, 22.54375076], [69.95707703, 22.54375076], [69.95707703, 22.54347038], [69.95680237, 22.54347229], [69.95680237, 22.54291534], [69.95652008, 22.54292107], [69.95652008, 22.54264069], [69.95625305, 22.54264069], [69.95625305, 22.54236031], [69.95597076, 22.54236031], [69.95597076, 22.54181099], [69.95569611, 22.54181099], [69.95569611, 22.54152107], [69.95541382, 22.5415287], [69.95541382, 22.54125023], [69.95513916, 22.54125023], [69.95513916, 22.54070091], [69.95485687, 22.54070091], [69.95485687, 22.54014015], [69.95458221, 22.54014015], [69.95458221, 22.53930092], [69.95430756, 22.53930473], [69.95430756, 22.53847313], [69.9540329, 22.53848076], [69.9540329, 22.53792], [69.95375061, 22.53792], [69.95375061, 22.53736115], [69.95347595, 22.53736115], [69.95347595, 22.53708267], [69.95319366, 22.53708267], [69.95319366, 22.53680611], [69.95263672, 22.53680992], [69.95263672, 22.53652954], [69.95207977, 22.53652954], [69.95207977, 22.53625107], [69.95124817, 22.53625107], [69.95124817, 22.5359726], [69.95069122, 22.5359726], [69.95069122, 22.53569412], [69.95014191, 22.53569412], [69.95014191, 22.53541756], [69.94819641, 22.53541756], [69.94819641, 22.53569412], [69.94652557, 22.53569412], [69.94652557, 22.5359726], [69.94568634, 22.5359726], [69.94568634, 22.53625107], [69.94458008, 22.53625107], [69.94458008, 22.53652954], [69.94374847, 22.53652954], [69.94374847, 22.53680992], [69.94291687, 22.53680611], [69.94291687, 22.53708267], [69.94208527, 22.53708267], [69.94208527, 22.53736115], [69.94152832, 22.53736115], [69.94153595, 22.53763962], [69.94069672, 22.53763962], [69.94069672, 22.53792], [69.94013977, 22.53791618], [69.94013977, 22.53819466], [69.93985748, 22.53819275], [69.93985748, 22.53848076], [69.93875122, 22.53848076], [69.93875122, 22.53903008], [69.93846893, 22.53902817], [69.93846893, 22.53958321], [69.93819427, 22.53958321], [69.93819427, 22.54154015], [69.93819427, 22.54208374], [69.93846893, 22.54208374], [69.93846893, 22.54569435], [69.93875122, 22.54569054], [69.93875122, 22.54624748], [69.93902588, 22.54624748], [69.93902588, 22.54681015], [69.93930817, 22.54681015], [69.93930817, 22.54764938], [69.93958282, 22.54764175], [69.93958282, 22.54819489], [69.93985748, 22.54819489], [69.93985748, 22.54846954], [69.94013977, 22.54846954], [69.94013977, 22.54875183], [69.94069672, 22.54875183], [69.94069672, 22.5490303], [69.94097137, 22.5490303], [69.94097137, 22.54931068], [69.94125366, 22.54930496], [69.94125366, 22.54958344], [69.94152832, 22.54958344], [69.94152832, 22.54986382], [69.94180298, 22.54986191], [69.94180298, 22.55042076], [69.94264221, 22.55041695], [69.94264221, 22.5506897], [69.94291687, 22.55069542], [69.94291687, 22.55097389], [69.94430542, 22.55097389], [69.94430542, 22.55125046], [69.95207977, 22.55125046]]], [[[70.0395813, 22.56792068], [70.0395813, 22.5676403], [70.03985596, 22.5676403], [70.03985596, 22.56735992], [70.04013824, 22.56736183], [70.04013824, 22.56680489], [70.0404129, 22.56680489], [70.0404129, 22.56652832], [70.04096985, 22.56653023], [70.04096985, 22.56513977], [70.04069519, 22.56513977], [70.04069519, 22.56458473], [70.0404129, 22.56458473], [70.0404129, 22.56430626], [70.03874969, 22.56430626], [70.03874969, 22.56458473], [70.03847504, 22.56458473], [70.03847504, 22.56680489], [70.03874969, 22.56680489], [70.03874969, 22.56708336], [70.03902435, 22.56708336], [70.03902435, 22.56736183], [70.03930664, 22.56735992], [70.03930664, 22.56792068], [70.0395813, 22.56792068]]], [[[70.01125336, 22.55375099], [70.01125336, 22.55346107], [70.01152802, 22.55347252], [70.01152802, 22.55319595], [70.01180267, 22.55319595], [70.01180267, 22.55291748], [70.01235962, 22.55291939], [70.01235962, 22.55264091], [70.01264191, 22.55264091], [70.01264191, 22.55236053], [70.01207733, 22.55236053], [70.01207733, 22.55208015], [70.01152802, 22.55208206], [70.01152802, 22.5518055], [70.01097107, 22.55181122], [70.01097107, 22.55153084], [70.01040649, 22.55153084], [70.01040649, 22.55125046], [70.01013947, 22.55125046], [70.01013947, 22.55097008], [70.00958252, 22.55097389], [70.00958252, 22.55069542], [70.0090332, 22.5506897], [70.00902557, 22.55041695], [70.00818634, 22.55042076], [70.00818634, 22.55014038], [70.00708008, 22.55014038], [70.00708008, 22.54986191], [70.00624847, 22.54986382], [70.00624847, 22.54958344], [70.00569153, 22.54958344], [70.00569153, 22.54930496], [70.00485992, 22.54931068], [70.00485992, 22.5490303], [70.00041962, 22.5490303], [70.00041962, 22.54875183], [69.99986267, 22.54875183], [69.99874878, 22.54875183], [69.99874878, 22.54846954], [69.99624634, 22.54846954], [69.99624634, 22.54875183], [69.99597168, 22.54875183], [69.99597168, 22.54931068], [69.99624634, 22.54930496], [69.99624634, 22.54958344], [69.99652863, 22.54958344], [69.99652863, 22.54986382], [69.9970932, 22.54986191], [69.9970932, 22.55014038], [69.99736023, 22.55014038], [69.99736023, 22.55042076], [69.99791718, 22.55041695], [69.99791718, 22.55069351], [69.99874878, 22.55069351], [69.99874878, 22.55097389], [69.99903107, 22.55097008], [69.99903107, 22.55125046], [69.99958038, 22.55125046], [69.99958038, 22.55153084], [69.99986267, 22.55153084], [69.99986267, 22.55181122], [70.00013733, 22.55181122], [70.00041962, 22.5518055], [70.00041962, 22.55208206], [70.00068665, 22.55208015], [70.00068665, 22.55236053], [70.00208282, 22.55236053], [70.00208282, 22.55208015], [70.00375366, 22.55208206], [70.00375366, 22.5518055], [70.00818634, 22.55181122], [70.00818634, 22.55264091], [70.00846863, 22.55264091], [70.00846863, 22.55291939], [70.00902557, 22.55291748], [70.00902557, 22.55319595], [70.00930786, 22.55319595], [70.00930786, 22.55347252], [70.00958252, 22.55346107], [70.00958252, 22.55375099], [70.01125336, 22.55375099]]], [[[70.02347565, 22.55847168], [70.02347565, 22.55819511], [70.02403259, 22.55820084], [70.02403259, 22.55792046], [70.02430725, 22.55792046], [70.02430725, 22.55763817], [70.02485657, 22.55763817], [70.02485657, 22.55680084], [70.02513885, 22.55680466], [70.02513885, 22.55597305], [70.0248642, 22.55597305], [70.0248642, 22.55541611], [70.02458191, 22.55541992], [70.02458191, 22.55513954], [70.02375031, 22.55513954], [70.02375031, 22.55486107], [70.02319336, 22.55486107], [70.02319336, 22.55458069], [70.02236176, 22.5545826], [70.02236176, 22.55430412], [70.02153015, 22.55430984], [70.02153015, 22.55402946], [70.02041626, 22.55402946], [70.02041626, 22.55375099], [70.0195694, 22.55375099], [70.0195694, 22.55346107], [70.01763916, 22.55347252], [70.01763916, 22.55319595], [70.01569366, 22.55319595], [70.01569366, 22.55291748], [70.01403046, 22.55291939], [70.01403046, 22.55264091], [70.01347351, 22.55263901], [70.01347351, 22.55319595], [70.01319122, 22.55319023], [70.01319122, 22.55375099], [70.01291656, 22.55375099], [70.01291656, 22.55402946], [70.01264191, 22.55402756], [70.01264191, 22.5545826], [70.01291656, 22.55458069], [70.01291656, 22.55486107], [70.01319122, 22.55486107], [70.01319122, 22.55513954], [70.01346588, 22.55513954], [70.01346588, 22.55541992], [70.01374817, 22.55541611], [70.01374817, 22.55569458], [70.01403046, 22.55569458], [70.01403046, 22.55597305], [70.01430511, 22.55597305], [70.01430511, 22.55624962], [70.01457977, 22.55624962], [70.01457977, 22.55652618], [70.01513672, 22.55652618], [70.01513672, 22.55680466], [70.01541901, 22.55680466], [70.01541901, 22.55708313], [70.01597595, 22.55708313], [70.01597595, 22.5573616], [70.01625061, 22.5573597], [70.01625061, 22.55763817], [70.01682281, 22.55763817], [70.01682281, 22.55792046], [70.01763916, 22.55792046], [70.01763916, 22.55820084], [70.01847076, 22.55819511], [70.01847076, 22.55847168], [70.02347565, 22.55847168]]], [[[70.0090332, 22.59320068], [70.0090332, 22.5929203], [70.00958252, 22.5929203], [70.00958252, 22.59263039], [70.01013947, 22.59263802], [70.01013947, 22.59236145], [70.01097107, 22.59236145], [70.01097107, 22.59208488], [70.01152802, 22.59208488], [70.01152802, 22.59180641], [70.01207733, 22.59181023], [70.01207733, 22.59152985], [70.01291656, 22.59152985], [70.01291656, 22.59124947], [70.01403046, 22.59124947], [70.01403046, 22.5909729], [70.01486206, 22.59097481], [70.01486206, 22.59069443], [70.01569366, 22.59069443], [70.01569366, 22.59041595], [70.01682281, 22.59041977], [70.01682281, 22.59013939], [70.01763916, 22.59013939], [70.01763916, 22.58986282], [70.01819611, 22.58986282], [70.01819611, 22.58956909], [70.01875305, 22.58958054], [70.01875305, 22.58930588], [70.01930237, 22.58930969], [70.01930237, 22.58903122], [70.01985931, 22.58903122], [70.01985931, 22.58875275], [70.02236176, 22.58875275], [70.02236176, 22.58847237], [70.02263641, 22.58847237], [70.02263641, 22.58819389], [70.0229187, 22.58819389], [70.0229187, 22.58791733], [70.02319336, 22.58792114], [70.02319336, 22.58764076], [70.02348328, 22.58764076], [70.02348328, 22.58735847], [70.02375031, 22.58735847], [70.02375031, 22.58707809], [70.02402496, 22.58708382], [70.02402496, 22.58680534], [70.02430725, 22.5868206], [70.02430725, 22.58653069], [70.02458191, 22.58653069], [70.02458191, 22.5862484], [70.02485657, 22.5862484], [70.02485657, 22.58513832], [70.02513885, 22.58513832], [70.02513885, 22.58374977], [70.02540588, 22.58374977], [70.02540588, 22.58292007], [70.0256958, 22.58292007], [70.0256958, 22.58208084], [70.02597046, 22.58208275], [70.02597046, 22.58124924], [70.02625275, 22.58125114], [70.02625275, 22.58041954], [70.0265274, 22.58041954], [70.0265274, 22.58014107], [70.0265274, 22.57958412], [70.02680206, 22.57958412], [70.02680206, 22.57875061], [70.02707672, 22.57875061], [70.02707672, 22.57792091], [70.02735901, 22.57792091], [70.02735901, 22.57707977], [70.0276413, 22.57708359], [70.0276413, 22.57597351], [70.02791595, 22.57597351], [70.02791595, 22.57513809], [70.02819061, 22.57514191], [70.02819061, 22.57346916], [70.02791595, 22.57347298], [70.02791595, 22.57069397], [70.0276413, 22.57069397], [70.0276413, 22.56902695], [70.02735901, 22.56903076], [70.02735901, 22.56846046], [70.02708435, 22.56847191], [70.02708435, 22.56791687], [70.0265274, 22.56792068], [70.0265274, 22.56820107], [70.02513885, 22.56820107], [70.02513885, 22.5676403], [70.02485657, 22.5676403], [70.02485657, 22.56680107], [70.02458191, 22.56680489], [70.02458191, 22.56624985], [70.02430725, 22.56624985], [70.02430725, 22.5656929], [70.02402496, 22.56569481], [70.02402496, 22.56541634], [70.02348328, 22.56542015], [70.02348328, 22.56513977], [70.02319336, 22.56513977], [70.02319336, 22.56485939], [70.0229187, 22.5648613], [70.0229187, 22.56458473], [70.02236176, 22.56458473], [70.02236176, 22.56430626], [70.0220871, 22.56431007], [70.0220871, 22.56402969], [70.02179718, 22.56402969], [70.02179718, 22.56375122], [70.02153015, 22.56375122], [70.02153015, 22.56347275], [70.02097321, 22.56347275], [70.02097321, 22.56319427], [70.02069092, 22.56319427], [70.02069092, 22.5629158], [70.02041626, 22.56291962], [70.02041626, 22.56265068], [70.01985931, 22.56265068], [70.01985931, 22.56236267], [70.0195694, 22.56236267], [70.0195694, 22.56208038], [70.01902771, 22.5620842], [70.01902771, 22.56180573], [70.01847076, 22.56180954], [70.01847076, 22.56153107], [70.01819611, 22.56153107], [70.01819611, 22.56125259], [70.01790619, 22.56125259], [70.01790619, 22.5609684], [70.01763916, 22.56097031], [70.01763916, 22.56069374], [70.01708221, 22.56069374], [70.01708221, 22.56041718], [70.01682281, 22.56041908], [70.01682281, 22.56014061], [70.0165329, 22.56014061], [70.0165329, 22.55985832], [70.01597595, 22.55985832], [70.01597595, 22.55958939], [70.01568604, 22.55958939], [70.01568604, 22.55931091], [70.01541901, 22.55931091], [70.01541901, 22.55903053], [70.01513672, 22.55903053], [70.01513672, 22.55874825], [70.01457977, 22.55874825], [70.01457977, 22.55846977], [70.01430511, 22.55847168], [70.01430511, 22.55819511], [70.01403046, 22.55820084], [70.01403046, 22.55792046], [70.01346588, 22.55792046], [70.01346588, 22.55763817], [70.01207733, 22.55763817], [70.01207733, 22.5573597], [70.01180267, 22.5573616], [70.01180267, 22.55708313], [70.01125336, 22.55708313], [70.01125336, 22.55680466], [70.01097107, 22.55680466], [70.01097107, 22.55652618], [70.01069641, 22.55652618], [70.01069641, 22.55624962], [70.01040649, 22.55624962], [70.01040649, 22.55597115], [70.00986481, 22.55597305], [70.00986481, 22.55569458], [70.00958252, 22.55569458], [70.00958252, 22.55541611], [70.00930786, 22.55541992], [70.00930786, 22.55513954], [70.00902557, 22.55513954], [70.00902557, 22.55486107], [70.00846863, 22.55486107], [70.00846863, 22.55458069], [70.00819397, 22.5545826], [70.00819397, 22.55430412], [70.00791931, 22.55430984], [70.00791931, 22.55402946], [70.00681305, 22.55402946], [70.00681305, 22.55375099], [70.00152588, 22.55375099], [70.00152588, 22.55346107], [70.00041962, 22.55347252], [70.00041962, 22.55319595], [69.99986267, 22.55319595], [69.99874878, 22.55319595], [69.99874878, 22.55236053], [69.99791718, 22.55236053], [69.99791718, 22.55208015], [69.99764252, 22.55208206], [69.99764252, 22.5518055], [69.99736023, 22.55181122], [69.99736023, 22.55153084], [69.9970932, 22.55153084], [69.9970932, 22.55125046], [69.99680328, 22.55125046], [69.99680328, 22.55097008], [69.99514008, 22.55097389], [69.99514008, 22.55069542], [69.99485779, 22.5506897], [69.99485779, 22.55013847], [69.99514008, 22.55014038], [69.99514008, 22.54986191], [69.99485779, 22.54986382], [69.99485779, 22.54958344], [69.99430847, 22.54958344], [69.99430847, 22.54930496], [69.99402618, 22.54931068], [69.99402618, 22.5490303], [69.99346924, 22.5490303], [69.99346924, 22.54875183], [69.99318695, 22.54875183], [69.99318695, 22.54846954], [69.99263763, 22.54846954], [69.99263763, 22.54819489], [69.99041748, 22.54819489], [69.99041748, 22.54791641], [69.98958588, 22.54792023], [69.98958588, 22.54764938], [69.98874664, 22.54764938], [69.98874664, 22.54735947], [69.98764038, 22.54735947], [69.98764038, 22.5470829], [69.98680878, 22.5470829], [69.98680878, 22.54680634], [69.98596954, 22.54681015], [69.98596954, 22.54653168], [69.98430634, 22.54653168], [69.98430634, 22.54624748], [69.98401642, 22.54624748], [69.98401642, 22.54653168], [69.98264313, 22.54653168], [69.98264313, 22.54681015], [69.98152924, 22.54680634], [69.98152924, 22.5470829], [69.97930908, 22.5470829], [69.97930908, 22.54680634], [69.97902679, 22.54681015], [69.97902679, 22.54624748], [69.97820282, 22.54624748], [69.97820282, 22.54653168], [69.9779129, 22.54652977], [69.9779129, 22.5470829], [69.97764587, 22.54707909], [69.97764587, 22.54764938], [69.97735596, 22.54764938], [69.97735596, 22.54792023], [69.9751358, 22.54792023], [69.9751358, 22.54764938], [69.97473907, 22.54764938], [69.97458649, 22.54764938], [69.97458649, 22.54735947], [69.97402954, 22.54735947], [69.97402954, 22.5470829], [69.97264099, 22.5470829], [69.97264099, 22.54680634], [69.97207642, 22.54681015], [69.97207642, 22.54653168], [69.97180176, 22.54653168], [69.97180176, 22.54624748], [69.97041321, 22.54624748], [69.97041321, 22.54597092], [69.96847534, 22.54597282], [69.96847534, 22.54569435], [69.96736145, 22.54569435], [69.96736145, 22.54597282], [69.9668045, 22.54597282], [69.9668045, 22.54569435], [69.96624756, 22.54569435], [69.96624756, 22.54541588], [69.96375275, 22.54541588], [69.96375275, 22.54569435], [69.96291351, 22.54569435], [69.96291351, 22.54597282], [69.96263885, 22.54597282], [69.96264648, 22.54624748], [69.96180725, 22.54624748], [69.96180725, 22.54653168], [69.96153259, 22.54653168], [69.96153259, 22.54681015], [69.96125031, 22.54680634], [69.96125031, 22.54735947], [69.96098328, 22.54735947], [69.96098328, 22.54764938], [69.96069336, 22.54764938], [69.96069336, 22.54792023], [69.9604187, 22.54791641], [69.9604187, 22.54819489], [69.96013641, 22.54819489], [69.96013641, 22.54846954], [69.95986176, 22.54846954], [69.95986176, 22.54875183], [69.95957947, 22.54875183], [69.95957947, 22.5490303], [69.95929718, 22.5490303], [69.95929718, 22.54875183], [69.95903015, 22.54875183], [69.95903015, 22.5490303], [69.95874786, 22.5490303], [69.95874786, 22.54931068], [69.95847321, 22.54930496], [69.95847321, 22.54958344], [69.95791626, 22.54957962], [69.95791626, 22.55014038], [69.9576416, 22.55013847], [69.9576416, 22.5506897], [69.95735931, 22.55071068], [69.95735931, 22.55125046], [69.95707703, 22.55125046], [69.95707703, 22.55375099], [69.95680237, 22.55375099], [69.95680237, 22.55486107], [69.95652771, 22.55486107], [69.95652771, 22.55708313], [69.95680237, 22.55708122], [69.95680237, 22.55820084], [69.95707703, 22.55820084], [69.95707703, 22.55958939], [69.95680237, 22.55958366], [69.95680237, 22.56069374], [69.95707703, 22.56068993], [69.95707703, 22.56153107], [69.95735931, 22.56153107], [69.95735931, 22.56265068], [69.9576416, 22.56265068], [69.9576416, 22.56375122], [69.95791626, 22.56374931], [69.95791626, 22.56458473], [69.95819092, 22.56458282], [69.95819092, 22.56542015], [69.95847321, 22.56542015], [69.95847321, 22.56624985], [69.95874786, 22.56624985], [69.95874786, 22.56680489], [69.95903015, 22.56680489], [69.95903015, 22.56736183], [69.95929718, 22.56735992], [69.95929718, 22.56792068], [69.95957947, 22.56792068], [69.95957947, 22.56875038], [69.95986176, 22.56875038], [69.95986176, 22.56931114], [69.96013641, 22.56931114], [69.96013641, 22.56986046], [69.9604187, 22.56986046], [69.9604187, 22.57042122], [69.96069336, 22.5704174], [69.96069336, 22.57097244], [69.96098328, 22.57097054], [69.96098328, 22.57152748], [69.96125031, 22.57152748], [69.96125031, 22.57208252], [69.96153259, 22.57208061], [69.96153259, 22.57292175], [69.96180725, 22.57291603], [69.96180725, 22.57347298], [69.96208191, 22.57346916], [69.96208191, 22.57403183], [69.96235657, 22.57403183], [69.96235657, 22.57459259], [69.96264648, 22.57459259], [69.96264648, 22.57514191], [69.96290588, 22.57514191], [69.96290588, 22.57570267], [69.9631958, 22.57569504], [69.9631958, 22.57597351], [69.96347046, 22.5759697], [69.96347046, 22.57625008], [69.96375275, 22.57625008], [69.96375275, 22.57653046], [69.9640274, 22.57653046], [69.9640274, 22.57681084], [69.96430206, 22.57680511], [69.96430206, 22.57708359], [69.96457672, 22.57707977], [69.96458435, 22.57736015], [69.96485901, 22.57736015], [69.96485901, 22.57765007], [69.9651413, 22.57765007], [69.9651413, 22.57792091], [69.9659729, 22.5779171], [69.9659729, 22.57819366], [69.96652985, 22.57819366], [69.96652985, 22.57847214], [69.96875, 22.57847214], [69.96875, 22.57819366], [69.96902466, 22.57819366], [69.96902466, 22.5779171], [69.97013855, 22.5779171], [69.97013855, 22.57819366], [69.97291565, 22.57819366], [69.97291565, 22.57847214], [69.9734726, 22.57847023], [69.9734726, 22.57875061], [69.97374725, 22.57875061], [69.97374725, 22.57903099], [69.97429657, 22.57903099], [69.97429657, 22.57930946], [69.97486115, 22.57930565], [69.97486115, 22.57958412], [69.9751358, 22.57958031], [69.9751358, 22.58014107], [69.97541809, 22.58013916], [69.97541809, 22.5806942], [69.97819519, 22.5806942], [69.97819519, 22.58097267], [69.97902679, 22.58097076], [69.97902679, 22.58125114], [69.97957611, 22.58125114], [69.97957611, 22.58152962], [69.98097229, 22.58152962], [69.98097229, 22.58181], [69.98124695, 22.58181], [69.98124695, 22.58152962], [69.98179626, 22.58152962], [69.98179626, 22.58181], [69.9826355, 22.58180428], [69.9826355, 22.58208275], [69.98319244, 22.58208084], [69.98319244, 22.58236122], [69.98401642, 22.58236122], [69.98401642, 22.58263969], [69.98458099, 22.58263969], [69.98458099, 22.58292007], [69.98486328, 22.58291626], [69.98486328, 22.58319473], [69.98513794, 22.58319473], [69.98513794, 22.5834713], [69.98542023, 22.58346939], [69.98542023, 22.58374977], [69.98596954, 22.58374977], [69.98596954, 22.58346939], [69.98680878, 22.5834713], [69.98680878, 22.58319473], [69.98735809, 22.58319473], [69.98735809, 22.5834713], [69.98764038, 22.58346939], [69.98764038, 22.58374977], [69.98847198, 22.58374977], [69.98847198, 22.58346939], [69.98902893, 22.58346939], [69.98902893, 22.58374977], [69.98929596, 22.58374977], [69.98929596, 22.58402824], [69.98958588, 22.58402634], [69.98958588, 22.58430481], [69.98986053, 22.58430481], [69.98986053, 22.58458328], [69.99097443, 22.58458328], [69.99097443, 22.58430481], [69.99208069, 22.58430481], [69.99208069, 22.58458328], [69.99291992, 22.58458328], [69.99291992, 22.58486176], [69.99318695, 22.58485985], [69.99318695, 22.58542061], [69.99346924, 22.58541679], [69.99346924, 22.58597183], [69.99375153, 22.58596992], [69.99375153, 22.58653069], [69.99402618, 22.58652687], [69.99402618, 22.58708382], [69.99430847, 22.58707809], [69.99430847, 22.58764076], [69.99458313, 22.58764076], [69.99458313, 22.58792114], [69.99485779, 22.58791733], [69.99485779, 22.58819389], [69.99514008, 22.58819389], [69.99514008, 22.58847237], [69.99539948, 22.58847237], [69.99539948, 22.58875275], [69.99624634, 22.58875275], [69.99624634, 22.58930969], [69.99708557, 22.58930588], [69.99708557, 22.58958054], [69.99736023, 22.58958054], [69.99736023, 22.58847237], [69.99791718, 22.58847237], [69.99791718, 22.58903122], [69.99819183, 22.58903122], [69.99819183, 22.58930969], [69.99847412, 22.58930588], [69.99847412, 22.58958054], [69.99874878, 22.58958054], [69.99874878, 22.58986282], [69.99931335, 22.58986282], [69.99931335, 22.59041977], [69.99958038, 22.59041595], [69.99958038, 22.59069443], [70.00013733, 22.59069443], [70.00041962, 22.59069443], [70.00041962, 22.59097481], [70.00096893, 22.5909729], [70.00096893, 22.59124947], [70.00125122, 22.59124947], [70.00125122, 22.59152985], [70.00152588, 22.59152985], [70.00152588, 22.59181023], [70.00208282, 22.59180641], [70.00208282, 22.59208488], [70.00235748, 22.59208488], [70.00235748, 22.59236145], [70.00291443, 22.59236145], [70.00291443, 22.59263802], [70.00319672, 22.59263039], [70.00319672, 22.5929203], [70.00374603, 22.5929203], [70.00374603, 22.59320068], [70.0090332, 22.59320068]]], [[[70.04458618, 22.57235909], [70.04458618, 22.57208061], [70.04486084, 22.57208252], [70.04486084, 22.57180595], [70.04514313, 22.57180977], [70.04514313, 22.57152748], [70.04541779, 22.57152748], [70.04541779, 22.57125092], [70.0459671, 22.57125092], [70.0459671, 22.56986046], [70.04569244, 22.56986046], [70.04569244, 22.56958008], [70.04541779, 22.56958389], [70.04541779, 22.56902695], [70.04514313, 22.56903076], [70.04514313, 22.56875038], [70.04486084, 22.56875038], [70.04486084, 22.56846046], [70.04458618, 22.56847191], [70.04458618, 22.56791687], [70.04429626, 22.56792068], [70.04429626, 22.5676403], [70.04402924, 22.5676403], [70.04402924, 22.56735992], [70.04374695, 22.56736183], [70.04374695, 22.56708336], [70.04347229, 22.56708336], [70.04347229, 22.56736183], [70.04207611, 22.56735992], [70.04207611, 22.57014084], [70.0423584, 22.57014084], [70.0423584, 22.57042122], [70.04264069, 22.5704174], [70.04264069, 22.57069397], [70.04291534, 22.57069397], [70.04291534, 22.57097244], [70.04319763, 22.57097054], [70.04319763, 22.57125092], [70.04347229, 22.57125092], [70.04347229, 22.57152748], [70.04374695, 22.57152748], [70.04374695, 22.57208252], [70.04402924, 22.57208061], [70.04402924, 22.57235909], [70.04458618, 22.57235909]]], [[[70.18180847, 22.58374977], [70.18180847, 22.58346939], [70.18208313, 22.5834713], [70.18208313, 22.58319473], [70.18235779, 22.58319473], [70.18235779, 22.58291626], [70.18264008, 22.58292007], [70.18264008, 22.58263969], [70.18319702, 22.58263969], [70.18319702, 22.58097076], [70.18096924, 22.58097076], [70.18096924, 22.58125114], [70.18068695, 22.58125114], [70.18068695, 22.58152962], [70.18013763, 22.58152962], [70.18013763, 22.58263969], [70.18041992, 22.58263969], [70.18041992, 22.58292007], [70.18069458, 22.58291626], [70.18069458, 22.5834713], [70.18125153, 22.58346939], [70.18125153, 22.58374977], [70.18180847, 22.58374977]]], [[[70.1904068, 22.59985924], [70.1904068, 22.59958076], [70.19069672, 22.59958267], [70.19069672, 22.59930611], [70.19097137, 22.59930992], [70.19097137, 22.59902763], [70.1912384, 22.59902763], [70.1912384, 22.5987606], [70.19152832, 22.5987606], [70.19152832, 22.59847069], [70.19180298, 22.5984726], [70.19180298, 22.59819412], [70.19152832, 22.59819412], [70.19152832, 22.59791946], [70.1912384, 22.59791946], [70.1912384, 22.59763908], [70.18930817, 22.59763908], [70.18930817, 22.59791946], [70.18902588, 22.59791946], [70.18902588, 22.5984726], [70.18875122, 22.5984726], [70.18875122, 22.59958267], [70.18930817, 22.59958076], [70.18930817, 22.59985924], [70.1904068, 22.59985924]]], [[[69.94847107, 22.60625076], [69.94847107, 22.60597038], [69.94875336, 22.60597229], [69.94875336, 22.60569572], [69.94985962, 22.60569572], [69.94985962, 22.60541725], [69.95041656, 22.60542107], [69.95041656, 22.60514069], [69.95069122, 22.60514069], [69.95069122, 22.60486031], [69.95096588, 22.60486031], [69.95096588, 22.60457039], [69.95153046, 22.60457039], [69.95153046, 22.60514069], [69.95181274, 22.60514069], [69.95181274, 22.60542107], [69.95207977, 22.60541725], [69.95207977, 22.60569572], [69.95291901, 22.60569572], [69.95291901, 22.60541725], [69.9540329, 22.60542107], [69.9540329, 22.60514069], [69.95485687, 22.60514069], [69.95485687, 22.60486031], [69.95569611, 22.60486031], [69.95569611, 22.60457039], [69.95625305, 22.60458374], [69.95625305, 22.60430527], [69.95680237, 22.6043129], [69.95680237, 22.60403061], [69.95707703, 22.60403061], [69.95707703, 22.60375023], [69.95819092, 22.60375023], [69.95819092, 22.60347176], [69.95874786, 22.60347366], [69.95874786, 22.60319519], [69.95929718, 22.60320282], [69.95929718, 22.60292053], [69.95957947, 22.60292053], [69.95957947, 22.60236168], [69.96013641, 22.60236168], [69.96013641, 22.60208321], [69.9604187, 22.60208321], [69.9604187, 22.60180473], [69.96097565, 22.60180473], [69.96097565, 22.60152817], [69.96153259, 22.60153008], [69.96153259, 22.6012516], [69.96180725, 22.6012516], [69.96180725, 22.60096931], [69.96263885, 22.60097313], [69.96263885, 22.60069466], [69.96291351, 22.60069466], [69.96291351, 22.60041618], [69.9631958, 22.60042191], [69.9631958, 22.60014153], [69.96375275, 22.60014153], [69.96375275, 22.59902763], [69.96347046, 22.59902763], [69.96347046, 22.5987606], [69.96290588, 22.5987606], [69.96290588, 22.59847069], [69.96263885, 22.5984726], [69.96263885, 22.59819412], [69.9623642, 22.59819412], [69.9623642, 22.59791946], [69.96153259, 22.59791946], [69.96153259, 22.59763908], [69.96098328, 22.59763908], [69.96098328, 22.59736061], [69.9604187, 22.59736061], [69.9604187, 22.59708023], [69.96013641, 22.59708405], [69.96013641, 22.59680557], [69.95986176, 22.59680939], [69.95986176, 22.59625053], [69.95957947, 22.59625053], [69.95957947, 22.59597015], [69.95819092, 22.59597206], [69.95819092, 22.59569359], [69.9576416, 22.59569359], [69.9576416, 22.59541512], [69.95707703, 22.59542084], [69.95707703, 22.59514046], [69.95680237, 22.59514046], [69.95680237, 22.59486008], [69.95458221, 22.59486008], [69.95458221, 22.59514046], [69.9540329, 22.59514046], [69.9540329, 22.59542084], [69.95319366, 22.59541512], [69.95319366, 22.59569359], [69.95291901, 22.59569359], [69.95291901, 22.59597206], [69.95207977, 22.59597015], [69.95207977, 22.59625053], [69.95181274, 22.59625053], [69.95181274, 22.59653091], [69.95153046, 22.59653091], [69.95153046, 22.59680939], [69.95124817, 22.59680557], [69.95124817, 22.59708405], [69.95096588, 22.59708023], [69.95096588, 22.59763908], [69.95069122, 22.59763908], [69.95069122, 22.59791946], [69.95041656, 22.59791946], [69.95041656, 22.59819412], [69.94957733, 22.59819031], [69.94957733, 22.5987606], [69.94902802, 22.5987606], [69.94902802, 22.59902763], [69.94875336, 22.59902763], [69.94875336, 22.60153008], [69.94902802, 22.60153008], [69.94902802, 22.60375023], [69.94875336, 22.60375023], [69.94875336, 22.60403061], [69.94847107, 22.60403061], [69.94847107, 22.6043129], [69.94819641, 22.60430527], [69.94819641, 22.60458374], [69.94790649, 22.60457039], [69.94790649, 22.60514069], [69.94763947, 22.60513878], [69.94763947, 22.60569572], [69.94790649, 22.60569], [69.94790649, 22.60625076], [69.94847107, 22.60625076]]], [[[70.2159729, 22.64681053], [70.2159729, 22.64653015], [70.21624756, 22.64653015], [70.21624756, 22.64624977], [70.21708679, 22.64624977], [70.21708679, 22.64596939], [70.21736145, 22.64596939], [70.21736145, 22.64624977], [70.2179184, 22.64624977], [70.2179184, 22.64596939], [70.21819305, 22.6459713], [70.21819305, 22.64541626], [70.21846771, 22.64542007], [70.21846771, 22.64486122], [70.21875, 22.64486122], [70.21875, 22.64458275], [70.2195816, 22.64458466], [70.2195816, 22.64430618], [70.21985626, 22.64431], [70.21985626, 22.64374161], [70.22013855, 22.64374924], [70.22013855, 22.64347267], [70.22097015, 22.64347267], [70.22097015, 22.6431942], [70.21930695, 22.6431942], [70.21930695, 22.64291573], [70.21901703, 22.64291954], [70.21901703, 22.64236259], [70.21930695, 22.64236259], [70.21930695, 22.64208031], [70.2195816, 22.64208412], [70.2195816, 22.64125252], [70.21985626, 22.64125252], [70.21985626, 22.64096832], [70.22013855, 22.64097023], [70.22013855, 22.64069366], [70.22041321, 22.64069366], [70.22041321, 22.64014053], [70.22013855, 22.64014053], [70.22013855, 22.64042091], [70.21986389, 22.6404171], [70.21986389, 22.64069366], [70.2179184, 22.64068031], [70.2179184, 22.64180946], [70.2181778, 22.64180946], [70.2181778, 22.64264107], [70.21736145, 22.64264107], [70.21736145, 22.64236259], [70.21708679, 22.64236259], [70.21708679, 22.64208031], [70.2168045, 22.64208412], [70.2168045, 22.6431942], [70.21708679, 22.64319038], [70.21708679, 22.64513969], [70.21679688, 22.64513969], [70.21679688, 22.64542007], [70.21541595, 22.64541626], [70.21541595, 22.64569473], [70.21569061, 22.64569283], [70.21569824, 22.64681053], [70.2159729, 22.64681053]]], [[[69.19541931, 22.3745842], [69.19541931, 22.37430573], [69.19596863, 22.37430954], [69.19596863, 22.37235832], [69.19625092, 22.37235832], [69.19625092, 22.37070084], [69.19596863, 22.37070084], [69.19596863, 22.37013817], [69.19568634, 22.37013817], [69.19568634, 22.36903], [69.19541931, 22.36903], [69.19541931, 22.36847115], [69.19513702, 22.36847305], [69.19513702, 22.36819458], [69.19486237, 22.36819458], [69.19486237, 22.3679142], [69.19458008, 22.36791992], [69.19458008, 22.36763954], [69.19403076, 22.36763954], [69.19403076, 22.36791992], [69.19374847, 22.36791992], [69.19374847, 22.36874962], [69.19319153, 22.36874962], [69.19319153, 22.36903], [69.19291687, 22.36902618], [69.19291687, 22.36930466], [69.18985748, 22.36930466], [69.18985748, 22.36958313], [69.19013977, 22.36958122], [69.19013977, 22.37013817], [69.19097137, 22.37013817], [69.19097137, 22.37042046], [69.19152832, 22.37042046], [69.19152832, 22.37070084], [69.19208527, 22.37069511], [69.19208527, 22.37097168], [69.19264221, 22.37096977], [69.19264221, 22.37124825], [69.19291687, 22.37124825], [69.19291687, 22.37153053], [69.19319153, 22.37153053], [69.19319153, 22.37208366], [69.19374847, 22.37207985], [69.19374847, 22.37264061], [69.19430542, 22.37264061], [69.19430542, 22.37319374], [69.19458008, 22.37319374], [69.19458008, 22.3745842], [69.19541931, 22.3745842]]], [[[69.3354187, 22.38903046], [69.3354187, 22.38875008], [69.33598328, 22.38875008], [69.33597565, 22.3884716], [69.33680725, 22.3884716], [69.33680725, 22.38763809], [69.33708191, 22.38764191], [69.33708191, 22.38736153], [69.33763885, 22.38736153], [69.33763885, 22.38708305], [69.33791351, 22.38708305], [69.33791351, 22.38680649], [69.3381958, 22.38680649], [69.3381958, 22.38708305], [69.33847046, 22.38708305], [69.33847046, 22.38736153], [69.3390274, 22.38736153], [69.3390274, 22.38708305], [69.33930206, 22.38708305], [69.33930206, 22.38680649], [69.33957672, 22.3868103], [69.33957672, 22.38625145], [69.33985901, 22.38625145], [69.33985901, 22.38430977], [69.33957672, 22.38430977], [69.33957672, 22.38236046], [69.33985901, 22.38236046], [69.33985901, 22.38208008], [69.34041595, 22.38208389], [69.34041595, 22.38097191], [69.3401413, 22.38097191], [69.3401413, 22.38069534], [69.33985901, 22.38070107], [69.33985901, 22.38042068], [69.3381958, 22.38042068], [69.3381958, 22.3801403], [69.33763885, 22.3801403], [69.33763885, 22.37985992], [69.3373642, 22.37986183], [69.3373642, 22.37930489], [69.33708191, 22.37930489], [69.33708191, 22.37874985], [69.33680725, 22.37874985], [69.33680725, 22.3781929], [69.33652496, 22.37819481], [69.33652496, 22.37763977], [69.33486176, 22.37763977], [69.33486176, 22.37735939], [69.33403015, 22.3773613], [69.33403015, 22.37708282], [69.33347321, 22.37708282], [69.33347321, 22.37624931], [69.33319092, 22.37625122], [69.33319092, 22.37541962], [69.33291626, 22.37541962], [69.33291626, 22.37486267], [69.33319092, 22.37486267], [69.33319092, 22.37375069], [69.33348083, 22.37375069], [69.33347321, 22.37347221], [69.33374786, 22.37347221], [69.33374786, 22.37319374], [69.33347321, 22.37319374], [69.33347321, 22.37264061], [69.33207703, 22.37264061], [69.33207703, 22.37291908], [69.33180237, 22.37291718], [69.33180237, 22.37319374], [69.33152771, 22.37318993], [69.33152771, 22.37375069], [69.33125305, 22.37375069], [69.33125305, 22.37486267], [69.3290329, 22.37486267], [69.3290329, 22.37514114], [69.32791901, 22.37514114], [69.32791901, 22.37541962], [69.32763672, 22.3754158], [69.32763672, 22.37569427], [69.3273468, 22.37569046], [69.3273468, 22.37598038], [69.32707977, 22.37598038], [69.32707977, 22.37625122], [69.32681274, 22.37625122], [69.32681274, 22.37652969], [69.32624817, 22.37652969], [69.32624817, 22.37681007], [69.32597351, 22.37680626], [69.32597351, 22.37708282], [69.32569122, 22.37708282], [69.32569122, 22.3773613], [69.32541656, 22.37735939], [69.32541656, 22.37763977], [69.32514191, 22.37763977], [69.32514191, 22.37819481], [69.32457733, 22.3781929], [69.32457733, 22.37874985], [69.32430267, 22.37874985], [69.32430267, 22.37958336], [69.32402802, 22.37958336], [69.32402802, 22.37986183], [69.32375336, 22.37985992], [69.32375336, 22.3801403], [69.32263947, 22.3801384], [69.32263947, 22.38097191], [69.32290649, 22.38097], [69.32290649, 22.38236046], [69.32347107, 22.38236046], [69.32347107, 22.38264084], [69.32402802, 22.38263893], [69.32402802, 22.38319397], [69.32430267, 22.38319397], [69.32430267, 22.38347244], [69.32485962, 22.38347054], [69.32485962, 22.38375092], [69.32847595, 22.38375092], [69.32847595, 22.38347054], [69.32902527, 22.38347244], [69.32902527, 22.38319397], [69.33013916, 22.38319397], [69.33013916, 22.38347244], [69.33041382, 22.38347244], [69.33041382, 22.38375092], [69.33069611, 22.38375092], [69.33069611, 22.38485909], [69.33042145, 22.38485909], [69.33042145, 22.38541985], [69.33013916, 22.38541985], [69.33013916, 22.38625145], [69.33152771, 22.38625145], [69.33152771, 22.38596916], [69.3326416, 22.38596916], [69.3326416, 22.38625145], [69.33430481, 22.38625145], [69.33430481, 22.38736153], [69.33374786, 22.38736153], [69.33374786, 22.38764191], [69.33348083, 22.38764191], [69.33348083, 22.38792038], [69.33374786, 22.38792038], [69.33374786, 22.3882103], [69.33430481, 22.38819504], [69.33430481, 22.3884716], [69.3345871, 22.3884716], [69.3345871, 22.38875008], [69.33486176, 22.38875008], [69.33486176, 22.38903046], [69.3354187, 22.38903046]]], [[[70.85456085, 20.75208282], [70.85736084, 20.75208282], [70.85736084, 20.7523613], [70.85819244, 20.75235939], [70.85819244, 20.75263977], [70.85958099, 20.75263977], [70.85958099, 20.75291824], [70.85986328, 20.75291824], [70.85986328, 20.75263977], [70.86042023, 20.75263977], [70.86042023, 20.75291824], [70.86096954, 20.75291824], [70.86096954, 20.75263977], [70.86152649, 20.75263977], [70.86152649, 20.75235939], [70.86180878, 20.7523613], [70.86180878, 20.75208282], [70.86235809, 20.75208282], [70.86235809, 20.7495842], [70.86180878, 20.7495842], [70.86180878, 20.74902725], [70.86152649, 20.74903107], [70.86152649, 20.74875069], [70.86096954, 20.74875069], [70.86096954, 20.74847031], [70.86042023, 20.74847221], [70.86042023, 20.74791718], [70.85986328, 20.74792099], [70.85986328, 20.74763107], [70.85958099, 20.7476387], [70.85958099, 20.74736023], [70.85874939, 20.74736023], [70.85874939, 20.74707985], [70.85847473, 20.74708366], [70.85847473, 20.74680519], [70.85819244, 20.74681091], [70.85819244, 20.74625015], [70.85791779, 20.74625015], [70.85791779, 20.74570084], [70.85764313, 20.74570084], [70.85764313, 20.74542046], [70.85736084, 20.74542046], [70.85736084, 20.74319077], [70.8576355, 20.74319458], [70.8576355, 20.7420826], [70.85791779, 20.7420826], [70.85791779, 20.74180603], [70.85874939, 20.74181938], [70.85874939, 20.74097061], [70.85902405, 20.74097252], [70.85902405, 20.74069405], [70.85930634, 20.74069405], [70.85930634, 20.7401371], [70.85958099, 20.74014091], [70.85958099, 20.73931122], [70.85986328, 20.73931122], [70.85986328, 20.73875809], [70.86013794, 20.73875809], [70.86013794, 20.73792076], [70.86042023, 20.73792076], [70.86042023, 20.7365303], [70.86068726, 20.7365303], [70.86068726, 20.73624992], [70.86096954, 20.73624992], [70.86096954, 20.73485947], [70.86125183, 20.73486137], [70.86125183, 20.73402786], [70.86152649, 20.73402977], [70.86152649, 20.73347282], [70.86180878, 20.73347473], [70.86180878, 20.73319435], [70.86208344, 20.73319435], [70.86208344, 20.73291588], [70.86235046, 20.73291969], [70.86235046, 20.73236275], [70.86264038, 20.73236275], [70.86264038, 20.73208046], [70.86291504, 20.73208046], [70.86291504, 20.73152733], [70.86319733, 20.73153114], [70.86319733, 20.73125267], [70.86347198, 20.73125267], [70.86347198, 20.73069191], [70.86374664, 20.73069382], [70.86374664, 20.73041725], [70.86402893, 20.73042107], [70.86402893, 20.7298584], [70.86429596, 20.7298584], [70.86429596, 20.72958946], [70.86458588, 20.72958946], [70.86458588, 20.72930908], [70.86486053, 20.72930908], [70.86486053, 20.72903061], [70.86540985, 20.72903061], [70.86540985, 20.72874832], [70.86569214, 20.72874832], [70.86569214, 20.72846985], [70.86597443, 20.72847176], [70.86597443, 20.72819519], [70.86653137, 20.72820091], [70.86653137, 20.72792053], [70.86680603, 20.72792053], [70.86680603, 20.72763824], [70.86736298, 20.72763824], [70.86736298, 20.72735977], [70.86763763, 20.72736168], [70.86763763, 20.72708321], [70.86846924, 20.72708321], [70.86846924, 20.72680473], [70.86930847, 20.72680473], [70.86930847, 20.72652626], [70.86958313, 20.72652817], [70.86958313, 20.72624969], [70.86985779, 20.72624969], [70.86985779, 20.72597122], [70.87069702, 20.72597313], [70.87069702, 20.72569466], [70.87152863, 20.72569466], [70.87152863, 20.72541618], [70.87180328, 20.72541809], [70.87180328, 20.72513962], [70.8720932, 20.72513962], [70.87208557, 20.72458267], [70.87236023, 20.72458267], [70.87236023, 20.72430611], [70.87264252, 20.72430992], [70.87264252, 20.72319031], [70.87236023, 20.72319412], [70.87236023, 20.72291756], [70.8720932, 20.72291946], [70.8720932, 20.72236061], [70.87180328, 20.72236061], [70.87180328, 20.72180939], [70.87153625, 20.72180939], [70.87153625, 20.72153091], [70.87124634, 20.72153091], [70.87124634, 20.72042084], [70.87097168, 20.72042084], [70.87097168, 20.71986008], [70.87069702, 20.71986389], [70.87069702, 20.71930504], [70.8704071, 20.71931076], [70.8704071, 20.71871948], [70.87041473, 20.71541595], [70.87014008, 20.71542168], [70.87014008, 20.71486092], [70.86930847, 20.71486092], [70.86930847, 20.71458817], [70.86875153, 20.71458817], [70.86875153, 20.71403122], [70.86847687, 20.71403122], [70.86847687, 20.71375084], [70.86818695, 20.71375084], [70.86818695, 20.71319008], [70.86791992, 20.71319389], [70.86791992, 20.71263885], [70.86847687, 20.71264076], [70.86847687, 20.71153069], [70.86902618, 20.71153069], [70.86902618, 20.71125031], [70.86875153, 20.71125031], [70.86875153, 20.71070099], [70.86902618, 20.71070099], [70.86902618, 20.70874977], [70.86875153, 20.70874977], [70.86875153, 20.70736122], [70.86902618, 20.70736122], [70.86902618, 20.70625114], [70.86930847, 20.70625114], [70.86930847, 20.70597267], [70.87208557, 20.70597267], [70.87208557, 20.7056942], [70.87374878, 20.7056942], [70.87374878, 20.70541573], [70.87403107, 20.70541954], [70.87403107, 20.70513153], [70.87403107, 20.70486259], [70.87374878, 20.70486259], [70.87374878, 20.70458031], [70.87291718, 20.70458412], [70.87291718, 20.70430565], [70.87264252, 20.70430946], [70.87264252, 20.7040329], [70.87014008, 20.7040329], [70.87014008, 20.70375252], [70.86791992, 20.70375252], [70.86791992, 20.7040329], [70.86708069, 20.7040329], [70.86708069, 20.70430946], [70.86653137, 20.70430565], [70.86653137, 20.70458412], [70.86624908, 20.70458031], [70.86624908, 20.70486259], [70.86540985, 20.70486259], [70.86540985, 20.70514107], [70.86486053, 20.70514107], [70.86486053, 20.70541954], [70.86374664, 20.70541763], [70.86374664, 20.7056942], [70.86152649, 20.7056942], [70.86152649, 20.70597267], [70.85874939, 20.70597267], [70.85874939, 20.70625114], [70.85819244, 20.70625114], [70.85819244, 20.70652962], [70.85736084, 20.70652962], [70.85736084, 20.70681], [70.85680389, 20.70680618], [70.85680389, 20.70708466], [70.85652924, 20.70708466], [70.85653687, 20.70763969], [70.85624695, 20.70763969], [70.85624695, 20.70792007], [70.8548584, 20.70791626], [70.8548584, 20.70819473], [70.85124969, 20.70819473], [70.85124969, 20.70791626], [70.84958649, 20.70792007], [70.84958649, 20.70763969], [70.84735107, 20.70763969], [70.84735107, 20.70736122], [70.84485626, 20.70736122], [70.84485626, 20.70714951], [70.8445816, 20.70708275], [70.8445816, 20.70680618], [70.84348297, 20.70681], [70.84348297, 20.70652962], [70.8429184, 20.70652962], [70.8429184, 20.70625114], [70.84208679, 20.70625114], [70.84208679, 20.70597267], [70.84124756, 20.70597267], [70.84124756, 20.7056942], [70.8409729, 20.7056942], [70.8409729, 20.70541763], [70.84041595, 20.70541954], [70.84041595, 20.70514107], [70.83957672, 20.70514107], [70.83957672, 20.70486259], [70.8390274, 20.70486259], [70.8390274, 20.70458031], [70.83875275, 20.70458412], [70.83875275, 20.70430565], [70.83847046, 20.70430946], [70.83847046, 20.7040329], [70.8381958, 20.7040329], [70.8381958, 20.70375252], [70.83790588, 20.70375252], [70.83790588, 20.70347023], [70.83763885, 20.70347023], [70.83763885, 20.70319366], [70.83680725, 20.70319366], [70.83680725, 20.7029171], [70.83651733, 20.70292091], [70.83651733, 20.70265007], [70.83625031, 20.70265007], [70.83625031, 20.70207977], [70.83597565, 20.70208359], [70.83597565, 20.70153046], [70.83569336, 20.70153046], [70.83569336, 20.70124817], [70.83541107, 20.70124817], [70.83541107, 20.7009697], [70.83513641, 20.7009716], [70.83513641, 20.70069504], [70.83486176, 20.70070076], [70.83486176, 20.70013809], [70.8345871, 20.70013809], [70.8345871, 20.69959068], [70.83429718, 20.69959068], [70.83429718, 20.6993103], [70.83403015, 20.6993103], [70.83403015, 20.69874954], [70.83429718, 20.69874954], [70.83429718, 20.69763947], [70.8345871, 20.69763947], [70.8345871, 20.69733047], [70.8345871, 20.69652748], [70.83486176, 20.69652748], [70.83486176, 20.69625092], [70.83541107, 20.69625092], [70.83541107, 20.69458008], [70.83569336, 20.6945858], [70.83569336, 20.69402695], [70.83598328, 20.69403076], [70.83598328, 20.69320107], [70.83680725, 20.69320107], [70.83680725, 20.69292068], [70.83790588, 20.69292068], [70.83790588, 20.6926403], [70.8381958, 20.6926403], [70.8381958, 20.69180107], [70.83847046, 20.69180489], [70.83847046, 20.69041634], [70.8381958, 20.69042015], [70.8381958, 20.69014168], [70.83708191, 20.69014168], [70.83708191, 20.69042015], [70.83651733, 20.69042015], [70.83648682, 20.69014168], [70.83625031, 20.69014168], [70.83625031, 20.6902504], [70.83625031, 20.69042015], [70.83597565, 20.69041634], [70.83598328, 20.69125175], [70.83486176, 20.69125175], [70.83486176, 20.69096947], [70.83347321, 20.69096947], [70.83347321, 20.69069481], [70.83180237, 20.69069481], [70.83180237, 20.69096947], [70.8298645, 20.69096947], [70.8298645, 20.69069481], [70.82958221, 20.69069481], [70.82958221, 20.69041634], [70.8290329, 20.69042015], [70.8290329, 20.69014168], [70.82763672, 20.69014168], [70.82763672, 20.69042015], [70.82597351, 20.69041634], [70.82597351, 20.69069481], [70.82541656, 20.69069481], [70.82541656, 20.69096947], [70.82485962, 20.69096947], [70.82485962, 20.69125175], [70.82375336, 20.69125175], [70.82375336, 20.69096947], [70.82235718, 20.69096947], [70.82235718, 20.69125175], [70.82180786, 20.69125175], [70.82180786, 20.69153023], [70.82152557, 20.69152832], [70.82152557, 20.69236374], [70.82180786, 20.69236183], [70.82180786, 20.69320107], [70.82152557, 20.69319534], [70.8215332, 20.69375038], [70.82013702, 20.69375038], [70.82013702, 20.69403076], [70.81958008, 20.69403076], [70.81958008, 20.69375038], [70.81903076, 20.69375038], [70.81903076, 20.69403076], [70.81874847, 20.69403076], [70.81874847, 20.69431114], [70.81847382, 20.69430542], [70.81847382, 20.6945858], [70.81819153, 20.69458008], [70.81819153, 20.69486046], [70.81764221, 20.69486046], [70.81764221, 20.69514084], [70.81736755, 20.69514084], [70.81736755, 20.69542122], [70.81708527, 20.6954174], [70.8170929, 20.69625092], [70.81680298, 20.69625092], [70.81680298, 20.69652748], [70.81652832, 20.69651985], [70.81652832, 20.69680977], [70.81597137, 20.69680405], [70.81597137, 20.69708252], [70.8154068, 20.69708061], [70.8154068, 20.69736099], [70.81513977, 20.69736099], [70.81513977, 20.69763947], [70.81485748, 20.69763947], [70.81485748, 20.69791985], [70.81430817, 20.69791794], [70.81430817, 20.6981945], [70.81402588, 20.6981945], [70.81402588, 20.69847298], [70.81375122, 20.69847107], [70.81375122, 20.69874954], [70.81291962, 20.69874954], [70.81291962, 20.69902992], [70.81263733, 20.69902992], [70.81263733, 20.6993103], [70.81236267, 20.6993103], [70.81236267, 20.69959068], [70.81208038, 20.69958305], [70.81208038, 20.69986153], [70.81124115, 20.69985962], [70.81124115, 20.70013809], [70.80930328, 20.70013809], [70.80930328, 20.69985962], [70.80902863, 20.69986153], [70.80902863, 20.69958305], [70.80847168, 20.69958305], [70.80847168, 20.69986153], [70.80764008, 20.69985962], [70.80764008, 20.70013809], [70.80735779, 20.70013809], [70.80735779, 20.70070076], [70.80764008, 20.70069504], [70.80764008, 20.7009716], [70.81014252, 20.7009697], [70.81014252, 20.70124817], [70.81069183, 20.70124817], [70.81069183, 20.70153046], [70.81124115, 20.70153046], [70.81124115, 20.70124817], [70.81236267, 20.70124817], [70.81236267, 20.70153046], [70.81487274, 20.70153046], [70.81513977, 20.70153046], [70.81513977, 20.70181084], [70.81569672, 20.70181084], [70.81569672, 20.70153046], [70.81736755, 20.70153046], [70.81736755, 20.70181084], [70.82013702, 20.70181084], [70.82013702, 20.70153046], [70.82042694, 20.70153046], [70.82042694, 20.70124817], [70.82069397, 20.70124817], [70.82068634, 20.69985962], [70.82041931, 20.69986153], [70.82041931, 20.69958305], [70.82013702, 20.69959068], [70.82013702, 20.6993103], [70.81958008, 20.6993103], [70.81955719, 20.69902992], [70.81931305, 20.69902992], [70.81931305, 20.69819069], [70.82041931, 20.6981945], [70.82041931, 20.69847298], [70.82402802, 20.69847298], [70.82402802, 20.6981945], [70.82514191, 20.6981945], [70.82514191, 20.69791794], [70.82541656, 20.69791985], [70.82541656, 20.69763947], [70.82596588, 20.69763947], [70.82596588, 20.69736099], [70.82736206, 20.69736099], [70.82736206, 20.69791985], [70.82763672, 20.69791985], [70.82763672, 20.69874954], [70.82707977, 20.69874954], [70.82707977, 20.70153046], [70.82736206, 20.70153046], [70.82736206, 20.70181084], [70.82763672, 20.70181084], [70.82763672, 20.70265007], [70.82791901, 20.70265007], [70.82791901, 20.70430946], [70.82819366, 20.70430565], [70.82819366, 20.70708466], [70.82847595, 20.70708466], [70.82847595, 20.7084713], [70.82875061, 20.7084713], [70.82875061, 20.70930672], [70.82819366, 20.70930672], [70.82819366, 20.70958328], [70.82791901, 20.70957947], [70.82791901, 20.71014023], [70.82763672, 20.71014023], [70.82763672, 20.71042061], [70.82791901, 20.71041679], [70.82791901, 20.71097183], [70.82763672, 20.71096992], [70.82763672, 20.71125031], [70.82736206, 20.71125031], [70.82736206, 20.71153069], [70.82707977, 20.71152687], [70.82707977, 20.71208382], [70.82680511, 20.71208382], [70.82681274, 20.71236038], [70.82402802, 20.71236038], [70.82402802, 20.71264076], [70.82375336, 20.71264076], [70.82375336, 20.71292114], [70.82347107, 20.71291733], [70.82347107, 20.71319389], [70.82125092, 20.71319389], [70.82125092, 20.71347237], [70.82041931, 20.71347237], [70.82042694, 20.71375084], [70.81958008, 20.71375084], [70.81958008, 20.71403122], [70.81903076, 20.71403122], [70.81903076, 20.71430969], [70.81791687, 20.71430969], [70.81791687, 20.71458817], [70.81708527, 20.71458244], [70.8170929, 20.71486092], [70.8154068, 20.71486092], [70.8154068, 20.7151413], [70.81513977, 20.7151413], [70.81513977, 20.71542168], [70.81541443, 20.71541595], [70.81541443, 20.71569443], [70.81569672, 20.71569443], [70.81569672, 20.7159729], [70.81597137, 20.71596909], [70.81597137, 20.71653175], [70.81625366, 20.71652985], [70.81625366, 20.71708107], [70.81652832, 20.71708107], [70.81652832, 20.71735954], [70.81680298, 20.71735954], [70.81680298, 20.71847343], [70.81652832, 20.71846962], [70.81652832, 20.71903038], [70.81569672, 20.71903038], [70.81569672, 20.71931076], [70.81485748, 20.71931076], [70.81485748, 20.71903038], [70.81402588, 20.71903038], [70.81402588, 20.71875191], [70.81346893, 20.71875191], [70.81346893, 20.71846962], [70.81331635, 20.71847343], [70.81319427, 20.71847343], [70.81319427, 20.71819496], [70.81291962, 20.71820068], [70.81291962, 20.71764946], [70.81263733, 20.71764946], [70.81263733, 20.71707916], [70.81291962, 20.71708107], [70.81291962, 20.71624947], [70.81318665, 20.71624947], [70.81318665, 20.71596909], [70.81346893, 20.7159729], [70.81346893, 20.7151413], [70.81318665, 20.7151413], [70.81318665, 20.71486092], [70.81096649, 20.71486092], [70.81096649, 20.71458817], [70.81069183, 20.71458817], [70.81069183, 20.71430969], [70.81041718, 20.71430969], [70.81041718, 20.71375084], [70.81014252, 20.71375084], [70.81014252, 20.71181107], [70.80986023, 20.71181107], [70.80986023, 20.71096992], [70.80958557, 20.71097183], [70.80958557, 20.71069527], [70.80930328, 20.71070099], [70.80930328, 20.71042061], [70.80902863, 20.71042061], [70.80902863, 20.71014023], [70.80874634, 20.71014023], [70.80874634, 20.71042061], [70.80847168, 20.71042061], [70.80847168, 20.71070099], [70.80652618, 20.71070099], [70.80652618, 20.71042061], [70.80596924, 20.71042061], [70.80596924, 20.70874977], [70.80625153, 20.70874977], [70.80625153, 20.70845985], [70.80652618, 20.7084713], [70.80652618, 20.70819473], [70.80596924, 20.70819473], [70.80596924, 20.70736122], [70.80568695, 20.70736122], [70.80568695, 20.70652962], [70.80596924, 20.70652962], [70.80596924, 20.70625114], [70.80625153, 20.70625114], [70.80625153, 20.70597267], [70.80652618, 20.70597267], [70.80652618, 20.70581055], [70.80652618, 20.7056942], [70.80674744, 20.7056942], [70.80735779, 20.7056942], [70.80735779, 20.70541573], [70.80819702, 20.70541954], [70.80819702, 20.70514107], [70.80847168, 20.70514107], [70.80847168, 20.70486259], [70.81014252, 20.70486259], [70.81014252, 20.70458031], [70.81069183, 20.70458412], [70.81069183, 20.70430565], [70.81096649, 20.70430946], [70.81096649, 20.70375252], [70.81069183, 20.70375252], [70.81069183, 20.70347023], [70.81014252, 20.70347023], [70.81014252, 20.70319366], [70.80958557, 20.70319366], [70.80958557, 20.7029171], [70.80930328, 20.70292091], [70.80930328, 20.70265007], [70.80902863, 20.70265007], [70.80902863, 20.70235825], [70.80791473, 20.70236015], [70.80791473, 20.70180511], [70.80708313, 20.70180511], [70.80708313, 20.70208359], [70.80625153, 20.70208359], [70.80625153, 20.70236015], [70.80541992, 20.70236015], [70.80541992, 20.70208359], [70.80458069, 20.70208359], [70.80458069, 20.70069504], [70.80374908, 20.70069504], [70.80374908, 20.7009716], [70.8034668, 20.7009697], [70.8034668, 20.70124817], [70.80319214, 20.70124817], [70.80319214, 20.70153046], [70.80291748, 20.70153046], [70.80291748, 20.70181084], [70.80236053, 20.70180511], [70.80236053, 20.70208359], [70.80180359, 20.70208359], [70.80180359, 20.70236015], [70.80124664, 20.70235825], [70.80124664, 20.70292091], [70.80097198, 20.7029171], [70.80097198, 20.70319366], [70.80069733, 20.70319366], [70.80069733, 20.70347023], [70.80041504, 20.70347023], [70.80042267, 20.70375252], [70.79985809, 20.70375252], [70.79985809, 20.7040329], [70.79930115, 20.7040329], [70.79930115, 20.70430946], [70.79902649, 20.70430565], [70.79902649, 20.70458412], [70.79875183, 20.70458031], [70.79875183, 20.70486259], [70.79846954, 20.70486259], [70.79846954, 20.70514107], [70.79792023, 20.70514107], [70.79792023, 20.70541954], [70.79763794, 20.70541763], [70.79763794, 20.7056942], [70.79736328, 20.7056942], [70.79736328, 20.70597267], [70.79708099, 20.70597267], [70.79708099, 20.70625114], [70.79680634, 20.70625114], [70.79680634, 20.70652962], [70.79651642, 20.70652962], [70.79651642, 20.70681], [70.79624939, 20.70680618], [70.79624939, 20.70708466], [70.7959671, 20.70708275], [70.7959671, 20.70736122], [70.79569244, 20.70736122], [70.79569244, 20.70792007], [70.79541779, 20.70791626], [70.79541779, 20.70819473], [70.79514313, 20.70819092], [70.79514313, 20.70903015], [70.79486084, 20.70902824], [70.79486084, 20.70930672], [70.79458618, 20.70930672], [70.79458618, 20.70958328], [70.79430389, 20.70958328], [70.79430389, 20.70986176], [70.79402924, 20.70985985], [70.79402924, 20.71042061], [70.79374695, 20.71041679], [70.79374695, 20.71097183], [70.79347229, 20.71096992], [70.79347229, 20.71125031], [70.79319763, 20.71125031], [70.79319763, 20.71153069], [70.79292297, 20.71153069], [70.79292297, 20.71181107], [70.79264069, 20.71180534], [70.79264069, 20.71208382], [70.79208374, 20.71208382], [70.79208374, 20.71236038], [70.7919693, 20.71236038], [70.79070282, 20.71236038], [70.79070282, 20.71264076], [70.78848267, 20.71264076], [70.78848267, 20.71292114], [70.78624725, 20.71291733], [70.78624725, 20.71319389], [70.7859726, 20.71319008], [70.7859726, 20.71375084], [70.78569794, 20.71375084], [70.78569794, 20.7140274], [70.78557587, 20.7140274], [70.78430176, 20.71403122], [70.78430176, 20.71375084], [70.78347015, 20.71375084], [70.78347015, 20.71403122], [70.78291321, 20.71403122], [70.78291321, 20.71430969], [70.78235626, 20.71430969], [70.78235626, 20.71458817], [70.77986145, 20.71458817], [70.77986145, 20.71486092], [70.77929687, 20.71486092], [70.77929687, 20.7151413], [70.7784729, 20.7151413], [70.7784729, 20.71542168], [70.77791595, 20.71541595], [70.77791595, 20.71569443], [70.77735901, 20.71569443], [70.77735901, 20.71581078], [70.77735901, 20.7159729], [70.7765274, 20.71596909], [70.7765274, 20.71624947], [70.77625275, 20.71624947], [70.77625275, 20.71653175], [70.77375031, 20.71653175], [70.77375031, 20.71681023], [70.77319336, 20.71680641], [70.77319336, 20.71708107], [70.77263641, 20.71708107], [70.77263641, 20.71735954], [70.77236176, 20.71735954], [70.77236176, 20.71764946], [70.77179718, 20.71764946], [70.77179718, 20.7179203], [70.77153015, 20.7179203], [70.77153015, 20.71820068], [70.77124786, 20.71819496], [70.77124786, 20.71847343], [70.77069092, 20.71846962], [70.77069092, 20.71875191], [70.76957703, 20.71875191], [70.76957703, 20.71903038], [70.76902771, 20.71903038], [70.76902771, 20.71931076], [70.76875305, 20.71930504], [70.76875305, 20.71958351], [70.76847076, 20.71958351], [70.76847076, 20.71986389], [70.76819611, 20.71986008], [70.76819611, 20.72014046], [70.76763916, 20.72014046], [70.76763916, 20.72042084], [70.7673645, 20.72041702], [70.7673645, 20.72069359], [70.76652527, 20.72069359], [70.76652527, 20.72097206], [70.76625061, 20.72097015], [70.76625061, 20.72125053], [70.76486206, 20.72125053], [70.76486206, 20.72153091], [70.76207733, 20.72153091], [70.76207733, 20.72180939], [70.76097107, 20.72180557], [70.76097107, 20.72208595], [70.76069641, 20.72208595], [70.76069641, 20.72180557], [70.76041412, 20.72180557], [70.76041412, 20.72208595], [70.75930786, 20.72208023], [70.75930786, 20.72236061], [70.75846863, 20.72236061], [70.75846863, 20.72264099], [70.75653076, 20.72264099], [70.75653076, 20.72236061], [70.75541687, 20.72236061], [70.75541687, 20.72208023], [70.75514221, 20.72208595], [70.75514221, 20.72180557], [70.75485992, 20.72180939], [70.75485992, 20.72153091], [70.75347137, 20.72153091], [70.75347137, 20.72126007], [70.75263977, 20.72125053], [70.75263977, 20.72097015], [70.75235748, 20.72097206], [70.75235748, 20.72069359], [70.75180817, 20.72069359], [70.75180817, 20.72041702], [70.75041962, 20.72042084], [70.75041962, 20.72014046], [70.74986267, 20.72014046], [70.74986267, 20.71986008], [70.74958038, 20.71986389], [70.74958038, 20.71958351], [70.74930573, 20.71958351], [70.74930573, 20.71930504], [70.74708557, 20.71930504], [70.74708557, 20.71958351], [70.74680328, 20.71958351], [70.74680328, 20.71986389], [70.74652863, 20.71986008], [70.74652863, 20.72014046], [70.74514771, 20.72014046], [70.74514771, 20.71986008], [70.74485779, 20.71986008], [70.74485779, 20.72014046], [70.74430847, 20.72014046], [70.74430847, 20.71986008], [70.74375153, 20.71986008], [70.74375153, 20.72014046], [70.74346924, 20.72014046], [70.74346924, 20.72042084], [70.74319458, 20.72041702], [70.74319458, 20.72069359], [70.74236298, 20.72069359], [70.74236298, 20.72097206], [70.74208069, 20.72097206], [70.74208832, 20.72125053], [70.74180603, 20.72125053], [70.74180603, 20.72153091], [70.7409668, 20.72153091], [70.7409668, 20.72180939], [70.74013519, 20.72180557], [70.74013519, 20.72208595], [70.73986053, 20.72208023], [70.73986053, 20.72236061], [70.73929596, 20.72236061], [70.73929596, 20.72264099], [70.73847198, 20.72264099], [70.73847198, 20.72291946], [70.73791504, 20.72291756], [70.73791504, 20.72319412], [70.73735809, 20.72319412], [70.73735809, 20.7234726], [70.73680878, 20.72347069], [70.73680878, 20.72375107], [70.73625183, 20.72375107], [70.73625183, 20.72402954], [70.73542023, 20.72402954], [70.73542023, 20.72430992], [70.73513794, 20.72430992], [70.73513794, 20.72486115], [70.73486328, 20.72486115], [70.73486328, 20.72513962], [70.73430634, 20.72513962], [70.73430634, 20.72541809], [70.73402405, 20.72541618], [70.73402405, 20.72569466], [70.73374939, 20.72569466], [70.73374939, 20.72597313], [70.7334671, 20.72597122], [70.7334671, 20.72624969], [70.73319244, 20.72624969], [70.73319244, 20.72652817], [70.73291779, 20.72652626], [70.73291779, 20.72680473], [70.73236084, 20.72680473], [70.73236084, 20.72708321], [70.73180389, 20.72708321], [70.73180389, 20.72736168], [70.73152924, 20.72735977], [70.73152924, 20.72763824], [70.73097229, 20.72763824], [70.73097229, 20.72792053], [70.73069763, 20.72792053], [70.73069763, 20.72820091], [70.73014069, 20.72819519], [70.73014069, 20.72847176], [70.72875214, 20.72846985], [70.72875214, 20.72874832], [70.72846985, 20.72874832], [70.72846985, 20.72846985], [70.72819519, 20.72847176], [70.72820282, 20.72874832], [70.72735596, 20.72874832], [70.72735596, 20.72903061], [70.72680664, 20.72903061], [70.72680664, 20.72930908], [70.72624969, 20.72930908], [70.72624969, 20.72958946], [70.72458649, 20.72958946], [70.72458649, 20.7298584], [70.72402191, 20.7298584], [70.72402191, 20.73014259], [70.7234726, 20.73014259], [70.7234726, 20.73042107], [70.72319794, 20.73041725], [70.72319794, 20.73069382], [70.72264099, 20.73069382], [70.72264099, 20.73097038], [70.72207642, 20.73097038], [70.72207642, 20.73125267], [70.72180939, 20.73125267], [70.72180176, 20.73153114], [70.72097778, 20.73153114], [70.72097778, 20.73180962], [70.71986389, 20.7318058], [70.71986389, 20.73208427], [70.7195816, 20.73208046], [70.7195816, 20.73236275], [70.71902466, 20.73236275], [70.71902466, 20.73263931], [70.71848297, 20.73263168], [70.71848297, 20.73291969], [70.7179184, 20.73291588], [70.7179184, 20.73319435], [70.71736145, 20.73319435], [70.71736145, 20.73347473], [70.71679688, 20.73347282], [70.71679688, 20.73374939], [70.71624756, 20.73374939], [70.71624756, 20.73402977], [70.71569824, 20.73402977], [70.71569824, 20.73431015], [70.71485901, 20.73430634], [70.71485901, 20.73458481], [70.71430206, 20.73458481], [70.71430206, 20.73486137], [70.7140274, 20.73485947], [70.7140274, 20.73513985], [70.71347046, 20.73513985], [70.71347046, 20.73542023], [70.7131958, 20.73541641], [70.7131958, 20.73569489], [70.71291351, 20.73569489], [70.71291351, 20.73597145], [70.71208191, 20.73596954], [70.71208191, 20.73624992], [70.71125031, 20.73624992], [70.71125031, 20.7365303], [70.71098328, 20.7365303], [70.71098328, 20.73681068], [70.71013641, 20.73680687], [70.71013641, 20.73708344], [70.7095871, 20.73708344], [70.7095871, 20.73736191], [70.70929718, 20.73736], [70.70929718, 20.73764038], [70.70819092, 20.73764038], [70.70819092, 20.73792076], [70.70708466, 20.73791695], [70.70708466, 20.73819351], [70.70513916, 20.73819351], [70.70513916, 20.73791695], [70.70347595, 20.73791695], [70.70347595, 20.7381897], [70.70318604, 20.73820114], [70.70318604, 20.73875809], [70.70263672, 20.73875809], [70.70263672, 20.73903084], [70.70236206, 20.73903084], [70.70236206, 20.73931122], [70.70207977, 20.7393055], [70.70207977, 20.73958397], [70.70181274, 20.73958015], [70.70181274, 20.74014091], [70.70124817, 20.74014091], [70.70124817, 20.74041748], [70.70097351, 20.74041748], [70.70097351, 20.74069405], [70.70069122, 20.74069023], [70.70069122, 20.74124908], [70.70014191, 20.74124908], [70.70014191, 20.74152756], [70.69957733, 20.74152756], [70.69957733, 20.74181938], [70.69930267, 20.74180603], [70.69930267, 20.7420826], [70.69902802, 20.74208069], [70.69902802, 20.74235916], [70.69875336, 20.74235916], [70.69875336, 20.74264145], [70.69819641, 20.74264145], [70.69819641, 20.74292183], [70.69791412, 20.74291611], [70.69791412, 20.74319458], [70.69763947, 20.74319458], [70.69763947, 20.74347115], [70.69735718, 20.74346924], [70.69735718, 20.74375153], [70.69680786, 20.74375153], [70.69680786, 20.74403191], [70.69625092, 20.74402809], [70.69625092, 20.74430466], [70.69596863, 20.74430466], [70.69596863, 20.74486351], [70.69568634, 20.7448597], [70.69568634, 20.74514008], [70.69513702, 20.74514008], [70.69513702, 20.74542046], [70.69458008, 20.74542046], [70.69458008, 20.74570084], [70.69403076, 20.74569511], [70.69403076, 20.74597359], [70.69346619, 20.74596977], [70.69346619, 20.74625015], [70.69319153, 20.74625015], [70.69319153, 20.74653053], [70.69291687, 20.74653053], [70.69291687, 20.74681091], [70.69235992, 20.74680519], [70.69235992, 20.74708366], [70.69152832, 20.74707985], [70.69152832, 20.74736023], [70.69097137, 20.74736023], [70.69097137, 20.7476387], [70.68930817, 20.74763107], [70.68930817, 20.74792099], [70.68846893, 20.74791718], [70.68846893, 20.74819565], [70.68791962, 20.74819565], [70.68791962, 20.74847221], [70.68736267, 20.74847031], [70.68736267, 20.74875069], [70.68681335, 20.74875069], [70.68681335, 20.74903107], [70.68624878, 20.74903107], [70.68624878, 20.74930954], [70.68597412, 20.74930573], [70.68597412, 20.7495842], [70.68569183, 20.74958038], [70.68569183, 20.74986076], [70.68514252, 20.74986076], [70.68514252, 20.75014114], [70.68486786, 20.75014114], [70.68486786, 20.75041962], [70.68430328, 20.75041962], [70.68430328, 20.7507], [70.68402863, 20.75069427], [70.68402863, 20.75097275], [70.68347168, 20.75097084], [70.68347168, 20.75125122], [70.68319702, 20.75125122], [70.68319702, 20.75152969], [70.6829071, 20.75152969], [70.6829071, 20.75181007], [70.68235779, 20.75180626], [70.68235779, 20.75208282], [70.68208313, 20.75208092], [70.68208313, 20.75263977], [70.68180847, 20.75263977], [70.68180847, 20.75291824], [70.68152618, 20.75291634], [70.68152618, 20.75319481], [70.68125153, 20.75319481], [70.68125153, 20.75338173], [70.68125153, 20.75347137], [70.68096924, 20.75346947], [70.68096924, 20.75375938], [70.68068695, 20.75375938], [70.68068695, 20.75402832], [70.68041992, 20.75402832], [70.68041992, 20.75430489], [70.68013763, 20.75430489], [70.68013763, 20.75458336], [70.67903137, 20.75458336], [70.67903137, 20.75486183], [70.67819214, 20.75485992], [70.67819214, 20.7551384], [70.67764282, 20.7551384], [70.67764282, 20.75542068], [70.67736053, 20.75542068], [70.67736053, 20.75569916], [70.67708588, 20.75569534], [70.67708588, 20.75597191], [70.67679596, 20.75596809], [70.67679596, 20.75624847], [70.67652893, 20.75624847], [70.67652893, 20.75653076], [70.67624664, 20.75652695], [70.67624664, 20.75680542], [70.67541504, 20.75680542], [70.67541504, 20.75708389], [70.67514038, 20.75708008], [70.67514038, 20.75736237], [70.67457581, 20.75736237], [70.67457581, 20.75764275], [70.67430878, 20.75764084], [70.67430878, 20.75819206], [70.67402649, 20.75819016], [70.67402649, 20.75930977], [70.67430878, 20.75930977], [70.67430878, 20.7598629], [70.67402649, 20.7598629], [70.67402649, 20.76013947], [70.67375183, 20.76013947], [70.67375183, 20.76097488], [70.67346954, 20.76097488], [70.67346954, 20.76180077], [70.67375183, 20.76180649], [70.67375183, 20.7634716], [70.67346954, 20.7634716], [70.67346954, 20.76458359], [70.67263794, 20.76458359], [70.67263794, 20.76349068], [70.67263794, 20.76319695], [70.67292786, 20.76320076], [70.67292786, 20.76235962], [70.67263794, 20.76236153], [70.67263794, 20.76208305], [70.67236328, 20.76208305], [70.67236328, 20.76180649], [70.67208099, 20.7618103], [70.67208099, 20.76152992], [70.67180634, 20.76152992], [70.67180634, 20.76124954], [70.67151642, 20.76124954], [70.67151642, 20.76097107], [70.6701355, 20.76097488], [70.67014313, 20.76124954], [70.66929626, 20.76124954], [70.66929626, 20.76152992], [70.66707611, 20.76152992], [70.66707611, 20.76124954], [70.66625214, 20.76124954], [70.66625214, 20.76152992], [70.66596985, 20.76152992], [70.66596985, 20.7618103], [70.6654129, 20.7618084], [70.66374969, 20.76180649], [70.66374969, 20.76208305], [70.66291809, 20.76208305], [70.66291809, 20.76152802], [70.6626358, 20.76152992], [70.6626358, 20.76097107], [70.66347504, 20.76097488], [70.66347504, 20.7606945], [70.66374969, 20.7606945], [70.66374969, 20.76013947], [70.66401672, 20.76013947], [70.66401672, 20.75956917], [70.66430664, 20.75958061], [70.66430664, 20.75902748], [70.6645813, 20.75902939], [70.6645813, 20.75854111], [70.6645813, 20.7579174], [70.66513824, 20.75792122], [70.66513824, 20.75736237], [70.6654129, 20.75736237], [70.6654129, 20.75708008], [70.66569519, 20.75708389], [70.66569519, 20.75652695], [70.66596985, 20.75653076], [70.66596985, 20.75596809], [70.66652679, 20.75597191], [70.66652679, 20.75486183], [70.66680908, 20.75486183], [70.66680908, 20.75263977], [70.66652679, 20.75263977], [70.66652679, 20.75235939], [70.66625214, 20.75235939], [70.66625214, 20.75263977], [70.66570282, 20.75263977], [70.66570282, 20.75291824], [70.6654129, 20.75291634], [70.6654129, 20.75319481], [70.66485596, 20.75319099], [70.66485596, 20.75402832], [70.66513824, 20.75402832], [70.66513824, 20.75430489], [70.66485596, 20.75430107], [70.66485596, 20.7551384], [70.6645813, 20.7551384], [70.6645813, 20.75569916], [70.66430664, 20.75569534], [70.66430664, 20.75597191], [70.66401672, 20.75596809], [70.66402435, 20.75624847], [70.66347504, 20.75624847], [70.66347504, 20.75597191], [70.66319275, 20.75596809], [70.66319275, 20.75624847], [70.66291809, 20.75624847], [70.66291809, 20.75819206], [70.6626358, 20.75819206], [70.6626358, 20.75847054], [70.66236115, 20.75847054], [70.66236115, 20.75819206], [70.66152954, 20.75819206], [70.66152954, 20.75847054], [70.66069794, 20.75847054], [70.66069794, 20.75875282], [70.6598587, 20.75875282], [70.6598587, 20.75902939], [70.65763855, 20.75902748], [70.65763855, 20.75958061], [70.65736389, 20.75958061], [70.65736389, 20.7598629], [70.65714264, 20.7598629], [70.65680695, 20.7598629], [70.65680695, 20.76013947], [70.65652466, 20.76013947], [70.65652466, 20.76097488], [70.65680695, 20.76097107], [70.65680695, 20.7618103], [70.65625, 20.76180649], [70.65625, 20.76236153], [70.65680695, 20.76235962], [70.65680695, 20.76264], [70.6570816, 20.76264], [70.6570816, 20.76292992], [70.65735626, 20.76292992], [70.65735626, 20.76431084], [70.6570816, 20.76430511], [70.6570816, 20.76458359], [70.65537262, 20.76458359], [70.65458679, 20.76458359], [70.65458679, 20.76402855], [70.65486145, 20.76403046], [70.65486145, 20.76320076], [70.6543045, 20.76319695], [70.6543045, 20.7634716], [70.65402985, 20.7634697], [70.65402985, 20.76375008], [70.65374756, 20.76375008], [70.65374756, 20.76403046], [70.65319824, 20.76403046], [70.65319824, 20.76431084], [70.65207672, 20.76431084], [70.65207672, 20.76403046], [70.65180206, 20.76403046], [70.65180206, 20.76375008], [70.6515274, 20.76375008], [70.6515274, 20.7634697], [70.64763641, 20.7634716], [70.64763641, 20.76319695], [70.6470871, 20.76320076], [70.6470871, 20.76292992], [70.64653015, 20.76292992], [70.64653015, 20.76320076], [70.6451416, 20.76319695], [70.6451416, 20.7634716], [70.64430237, 20.7634697], [70.64430237, 20.76375008], [70.64402771, 20.76375008], [70.64402771, 20.76403046], [70.64347076, 20.76403046], [70.64347076, 20.76431084], [70.64291382, 20.76430511], [70.64291382, 20.76458359], [70.6423645, 20.76458359], [70.6423645, 20.76486206], [70.64180756, 20.76486015], [70.64180756, 20.76514053], [70.6415329, 20.76514053], [70.6415329, 20.76542091], [70.64125061, 20.76541519], [70.64125061, 20.76597214], [70.64068604, 20.76597023], [70.64068604, 20.76625061], [70.64041901, 20.76625061], [70.64041901, 20.76652908], [70.64013672, 20.76652908], [70.64013672, 20.76680946], [70.63986206, 20.76680565], [70.63986206, 20.76708412], [70.63957214, 20.76708031], [70.63957214, 20.76736069], [70.63874817, 20.76736069], [70.63874817, 20.76763916], [70.63819122, 20.76763916], [70.63819122, 20.76791763], [70.63791656, 20.76791763], [70.63791656, 20.7681942], [70.63735962, 20.7681942], [70.63735962, 20.76874924], [70.63680267, 20.7687397], [70.63680267, 20.76903152], [70.63597107, 20.76903152], [70.63597107, 20.7693119], [70.63541412, 20.76930618], [70.63541412, 20.76958275], [70.63375092, 20.76958275], [70.63375092, 20.76930618], [70.63346863, 20.7693119], [70.63346863, 20.76903152], [70.63318634, 20.76903152], [70.63318634, 20.7687397], [70.63291931, 20.76874924], [70.63291931, 20.7681942], [70.63263702, 20.7681942], [70.63263702, 20.76791763], [70.63208008, 20.76791763], [70.63208008, 20.7681942], [70.63057709, 20.7681942], [70.63014221, 20.7681942], [70.63014221, 20.76847267], [70.62875366, 20.76847267], [70.62875366, 20.7681942], [70.62847137, 20.7681942], [70.62847137, 20.76791763], [70.62735748, 20.76791763], [70.62735748, 20.7681942], [70.62680817, 20.7681942], [70.62680817, 20.76847267], [70.62652588, 20.76847267], [70.62652588, 20.76874924], [70.62625122, 20.7687397], [70.62625122, 20.76903152], [70.62596893, 20.76903152], [70.62596893, 20.7693119], [70.62430573, 20.76930618], [70.62430573, 20.76958275], [70.62346649, 20.76958084], [70.62346649, 20.76985931], [70.62319183, 20.76985931], [70.62319183, 20.7701416], [70.62291718, 20.7701416], [70.62291718, 20.77042007], [70.62264252, 20.77041626], [70.62264252, 20.77069473], [70.62208557, 20.77069473], [70.62208557, 20.77096939], [70.62180328, 20.77096939], [70.62180328, 20.77125168], [70.62097168, 20.77125168], [70.62097168, 20.77153015], [70.61736298, 20.77152824], [70.61736298, 20.77180481], [70.61680603, 20.77180481], [70.61680603, 20.77152824], [70.61624908, 20.77152824], [70.61624908, 20.77180481], [70.61597443, 20.77180481], [70.61597443, 20.77152824], [70.61569214, 20.77153015], [70.61569214, 20.77125168], [70.61541748, 20.77125168], [70.61541748, 20.77096939], [70.61569214, 20.77096939], [70.61569214, 20.7701416], [70.61541748, 20.7701416], [70.61541748, 20.76985931], [70.61458588, 20.76985931], [70.61458588, 20.7701416], [70.61429596, 20.7701416], [70.61429596, 20.77042007], [70.61374664, 20.77041626], [70.61374664, 20.77069473], [70.61347198, 20.77069473], [70.61347198, 20.77096939], [70.61180878, 20.77096939], [70.61180878, 20.77125168], [70.61152649, 20.77125168], [70.61152649, 20.77208138], [70.61180878, 20.77208138], [70.61180878, 20.77236366], [70.61263275, 20.77236176], [70.61263275, 20.77264023], [70.61292267, 20.77264023], [70.61292267, 20.77403069], [70.61264038, 20.77402687], [70.61264038, 20.77458572], [70.61207581, 20.77458], [70.61207581, 20.77486992], [70.61180878, 20.77486992], [70.61180878, 20.77514076], [70.61068726, 20.77514076], [70.61068726, 20.77542114], [70.61042023, 20.77541733], [70.61042023, 20.7756958], [70.61013794, 20.7756958], [70.61013794, 20.77597237], [70.60986328, 20.77597046], [70.60986328, 20.77625084], [70.60901642, 20.77625084], [70.60901642, 20.77653122], [70.6084671, 20.77653122], [70.6084671, 20.77680969], [70.6076355, 20.77680588], [70.6076355, 20.77708244], [70.60736084, 20.77708054], [70.60736084, 20.77736092], [70.60679626, 20.77736092], [70.60679626, 20.77708054], [70.60541534, 20.77708244], [70.60541534, 20.77680588], [70.60514069, 20.77680969], [70.60514069, 20.77653122], [70.60457611, 20.77653122], [70.60457611, 20.77680969], [70.60430908, 20.77680588], [70.60430908, 20.77708244], [70.60402679, 20.77708054], [70.60402679, 20.77736092], [70.60319519, 20.77736092], [70.60320282, 20.77763939], [70.60263824, 20.77763939], [70.60263824, 20.77793121], [70.60180664, 20.77793121], [70.60180664, 20.77763939], [70.60151672, 20.77763939], [70.60151672, 20.77736092], [70.60097504, 20.77736092], [70.60098267, 20.77763939], [70.59929657, 20.77763939], [70.59929657, 20.77793121], [70.59874725, 20.77791786], [70.59874725, 20.77819443], [70.5984726, 20.77819443], [70.5984726, 20.7784729], [70.59791565, 20.7784729], [70.59792328, 20.77874947], [70.59680939, 20.77874947], [70.59680176, 20.77902985], [70.5965271, 20.77902985], [70.5965271, 20.77931023], [70.59541321, 20.77930641], [70.59541321, 20.77958298], [70.59513855, 20.77958298], [70.59513855, 20.77986145], [70.59430695, 20.77985954], [70.59430695, 20.78013992], [70.59401703, 20.78013992], [70.59401703, 20.7804203], [70.59319305, 20.7804203], [70.59319305, 20.78070068], [70.59236145, 20.78069496], [70.59236145, 20.78097153], [70.59179688, 20.78096962], [70.59179688, 20.78124809], [70.59152222, 20.78124809], [70.59152222, 20.78152847], [70.59069824, 20.78152847], [70.59069824, 20.78181076], [70.58985901, 20.78180504], [70.58985901, 20.78208351], [70.58847046, 20.78208351], [70.58847046, 20.78180504], [70.58790588, 20.78181076], [70.58790588, 20.78152847], [70.58763885, 20.78152847], [70.58763885, 20.78124809], [70.58651733, 20.78124809], [70.58651733, 20.78152847], [70.5854187, 20.78152847], [70.5854187, 20.78208351], [70.58513641, 20.78208351], [70.58513641, 20.78236008], [70.58486176, 20.78235817], [70.58486176, 20.78263855], [70.5845871, 20.78263855], [70.5845871, 20.78292084], [70.58430481, 20.78291702], [70.58430481, 20.78347015], [70.58403015, 20.78347015], [70.58403015, 20.78403282], [70.58374786, 20.78403282], [70.58374786, 20.78430939], [70.58347321, 20.78430557], [70.58347321, 20.78458405], [70.58319092, 20.78458023], [70.58319092, 20.78486252], [70.58291626, 20.78486252], [70.58291626, 20.7851429], [70.58235931, 20.7851429], [70.58235931, 20.78541946], [70.58208466, 20.78541756], [70.58208466, 20.78569221], [70.58180237, 20.78569221], [70.58180237, 20.7859726], [70.58152771, 20.7859726], [70.58152771, 20.78625107], [70.58125305, 20.78625107], [70.58125305, 20.78652954], [70.58097076, 20.78652954], [70.58097076, 20.78680992], [70.58069611, 20.78680611], [70.58069611, 20.78708458], [70.58013916, 20.78708076], [70.58013916, 20.78736115], [70.57985687, 20.78736115], [70.57985687, 20.78763962], [70.57958221, 20.78763962], [70.57958221, 20.78792], [70.57930756, 20.78791618], [70.57930756, 20.78847313], [70.57875061, 20.78847122], [70.57875061, 20.78874969], [70.57818604, 20.78874969], [70.57818604, 20.78903008], [70.57763672, 20.78902817], [70.57763672, 20.78930473], [70.57707977, 20.78930473], [70.57707977, 20.78958321], [70.57681274, 20.78957939], [70.57681274, 20.78987122], [70.57652283, 20.78987122], [70.57652283, 20.79014015], [70.57541656, 20.79014015], [70.57541656, 20.79042053], [70.57514191, 20.79042053], [70.57514191, 20.79070091], [70.57458496, 20.79069519], [70.57458496, 20.79097176], [70.57402802, 20.79096985], [70.57402802, 20.79125023], [70.57375336, 20.79125023], [70.57375336, 20.79153061], [70.57290649, 20.79153061], [70.57290649, 20.79181099], [70.57236481, 20.79180527], [70.57236481, 20.79208374], [70.57180786, 20.79207993], [70.57180786, 20.79236031], [70.5715332, 20.79236031], [70.5715332, 20.79264069], [70.57096863, 20.79263878], [70.57096863, 20.79291725], [70.57013702, 20.79291725], [70.57013702, 20.79319382], [70.56680298, 20.79319382], [70.56680298, 20.79347229], [70.56597137, 20.79347229], [70.56597137, 20.79319382], [70.56541443, 20.79319382], [70.56541443, 20.79347229], [70.56375122, 20.79347229], [70.56375122, 20.79291725], [70.56346893, 20.79291725], [70.56346893, 20.79263878], [70.56318665, 20.79264069], [70.56318665, 20.79236031], [70.56291962, 20.79236031], [70.56291962, 20.79264069], [70.56208038, 20.79263878], [70.56208038, 20.79291725], [70.56180573, 20.79291725], [70.56180573, 20.79319382], [70.56208038, 20.79319382], [70.56208038, 20.79347229], [70.56153107, 20.79347229], [70.5615387, 20.79375076], [70.56124878, 20.79375076], [70.56124878, 20.79403114], [70.56096649, 20.79403114], [70.56096649, 20.79430962], [70.56069183, 20.7943058], [70.56069183, 20.79458427], [70.56014252, 20.79458046], [70.56014252, 20.79486084], [70.55986023, 20.79486084], [70.55986023, 20.79513931], [70.5595932, 20.79513931], [70.5595932, 20.7954216], [70.55930328, 20.79541588], [70.55930328, 20.79569435], [70.55902863, 20.79569435], [70.55902863, 20.79735947], [70.55930328, 20.79735947], [70.55930328, 20.79823112], [70.55930328, 20.79847336], [70.55902863, 20.79846954], [70.55902863, 20.79875183], [70.55874634, 20.79875183], [70.55874634, 20.7990303], [70.55847931, 20.7990303], [70.55847931, 20.79931068], [70.55791473, 20.79930305], [70.55791473, 20.79958344], [70.55735779, 20.79958344], [70.55735779, 20.79986382], [70.55708313, 20.79986191], [70.55708313, 20.80042076], [70.55680847, 20.80041695], [70.55680847, 20.80097389], [70.55652618, 20.80097008], [70.55652618, 20.80125046], [70.55568695, 20.80125046], [70.55568695, 20.80153084], [70.55541229, 20.80153084], [70.55541229, 20.80181122], [70.55486298, 20.80181122], [70.55486298, 20.80236053], [70.55458069, 20.80236053], [70.55458069, 20.80264091], [70.55403137, 20.80264091], [70.55403137, 20.80291939], [70.55374908, 20.80291748], [70.55374908, 20.80319595], [70.55347443, 20.80319595], [70.55347443, 20.80347252], [70.55208588, 20.80347061], [70.55208588, 20.80375099], [70.55152893, 20.80375099], [70.55152893, 20.80402946], [70.55097198, 20.80402946], [70.55097198, 20.80430984], [70.55041504, 20.80430794], [70.55041504, 20.8045826], [70.54902649, 20.8045826], [70.54902649, 20.80430794], [70.54763794, 20.80430984], [70.54763794, 20.80402946], [70.54736328, 20.80402946], [70.54736328, 20.80359268], [70.54736328, 20.80347252], [70.54708099, 20.80347252], [70.54708099, 20.80319595], [70.54624939, 20.80319595], [70.54624939, 20.80291748], [70.54458618, 20.80291748], [70.54458618, 20.80319595], [70.54402924, 20.80319595], [70.54402924, 20.80291748], [70.54374695, 20.80291748], [70.54374695, 20.80319595], [70.54347229, 20.80319595], [70.54347229, 20.80291748], [70.54319763, 20.80291939], [70.54319763, 20.80236053], [70.54291534, 20.80236053], [70.54291534, 20.80208588], [70.54264069, 20.80208588], [70.54264069, 20.8018055], [70.5423584, 20.80181122], [70.5423584, 20.80153084], [70.54180908, 20.80153084], [70.54180908, 20.80181122], [70.54152679, 20.8018055], [70.54152679, 20.80208588], [70.54096985, 20.80208015], [70.54096985, 20.80236053], [70.54013824, 20.80236053], [70.54013824, 20.80264091], [70.5395813, 20.80264091], [70.5395813, 20.80291939], [70.53930664, 20.80291748], [70.53930664, 20.80319595], [70.53874969, 20.80319595], [70.53874969, 20.80347252], [70.53848267, 20.80347061], [70.53848267, 20.80375099], [70.53791809, 20.80375099], [70.53791809, 20.80402946], [70.53708649, 20.80402946], [70.53708649, 20.80430984], [70.53652954, 20.80430984], [70.53652954, 20.80402946], [70.53624725, 20.80402946], [70.53624725, 20.80430984], [70.5359726, 20.80430794], [70.5359726, 20.8045826], [70.53569794, 20.80458069], [70.53569794, 20.80513954], [70.53541565, 20.80513954], [70.53541565, 20.80597305], [70.53514099, 20.80597115], [70.53514099, 20.80624962], [70.5348587, 20.80624962], [70.5348587, 20.80652809], [70.53430939, 20.80652618], [70.53430176, 20.80680466], [70.5340271, 20.80680084], [70.5340271, 20.80763817], [70.53375244, 20.80763817], [70.53375244, 20.80791664], [70.5331955, 20.80791664], [70.5331955, 20.80847168], [70.53291321, 20.80846977], [70.53291321, 20.80874825], [70.53263855, 20.80874825], [70.53263855, 20.80903053], [70.53235626, 20.80903053], [70.53235626, 20.80931091], [70.53069305, 20.80930519], [70.53069305, 20.80958366], [70.52958679, 20.80957985], [70.52958679, 20.80985832], [70.52929688, 20.80985832], [70.52929688, 20.81014252], [70.5284729, 20.81014252], [70.5284729, 20.8104229], [70.5276413, 20.81041718], [70.5276413, 20.81069374], [70.52375031, 20.81069374], [70.52375031, 20.81097031], [70.52348328, 20.81097031], [70.52348328, 20.81153107], [70.52319336, 20.81152725], [70.52319336, 20.8120842], [70.52263641, 20.81208038], [70.52263641, 20.81236267], [70.52124786, 20.81236267], [70.52124786, 20.81264114], [70.52069092, 20.81264114], [70.52069092, 20.81291962], [70.5201416, 20.8129158], [70.5201416, 20.81319427], [70.51985931, 20.81319427], [70.51985931, 20.81347466], [70.51957703, 20.81347275], [70.51957703, 20.81375122], [70.51902771, 20.81375122], [70.51902771, 20.81404114], [70.51875305, 20.81402779], [70.51875305, 20.8148613], [70.51819611, 20.81485939], [70.51819611, 20.81513977], [70.51790619, 20.81513977], [70.51790619, 20.81542015], [70.51763916, 20.81542015], [70.51763916, 20.81624985], [70.51735687, 20.81624985], [70.51735687, 20.81653023], [70.51708221, 20.81652832], [70.51708221, 20.81680679], [70.51680756, 20.81680679], [70.51680756, 20.81708336], [70.51652527, 20.81708336], [70.51652527, 20.81736183], [70.51624298, 20.81735992], [70.51624298, 20.8176403], [70.51568604, 20.8176403], [70.51568604, 20.81792068], [70.51457977, 20.81792068], [70.51457977, 20.81820107], [70.51291656, 20.81819534], [70.51291656, 20.81847191], [70.51264191, 20.81847], [70.51264191, 20.81875038], [70.51235962, 20.81875038], [70.51235962, 20.81931114], [70.51208496, 20.81930542], [70.51208496, 20.81986046], [70.51152802, 20.81985092], [70.51152802, 20.82014084], [70.51125336, 20.82014084], [70.51125336, 20.82042122], [70.51097107, 20.8204174], [70.51097107, 20.82069397], [70.51069641, 20.82069397], [70.51069641, 20.82097244], [70.51013947, 20.82097054], [70.51013947, 20.82125092], [70.50958252, 20.82125092], [70.50958252, 20.82152748], [70.5090332, 20.82152748], [70.5090332, 20.82180977], [70.50846863, 20.82180595], [70.50846863, 20.82208252], [70.50763702, 20.82208061], [70.50763702, 20.82235909], [70.50680542, 20.82235909], [70.50681305, 20.82264137], [70.50402832, 20.82264137], [70.50402832, 20.82291603], [70.50291443, 20.82291603], [70.50291443, 20.8231945], [70.50208282, 20.8231945], [70.50208282, 20.82347107], [70.50096893, 20.82346916], [70.50096893, 20.82374954], [70.50041962, 20.82374954], [70.50041962, 20.82403183], [70.49986267, 20.82403183], [70.49986267, 20.8243103], [70.49958038, 20.82430649], [70.49958038, 20.82458115], [70.49903107, 20.82458115], [70.49903107, 20.82485962], [70.49846649, 20.82485962], [70.49846649, 20.82514191], [70.49791718, 20.82514191], [70.49791718, 20.82542038], [70.49764252, 20.82542038], [70.49764252, 20.82570076], [70.49736023, 20.82570076], [70.49736023, 20.82598114], [70.49680328, 20.82598114], [70.49680328, 20.82625008], [70.49652863, 20.82625008], [70.49652863, 20.82653046], [70.49597168, 20.82653046], [70.49597168, 20.82681084], [70.49485779, 20.82680321], [70.49485779, 20.82708359], [70.49430847, 20.82708359], [70.49430847, 20.82736206], [70.49402618, 20.82736015], [70.49402618, 20.82764053], [70.49375153, 20.82764053], [70.49375153, 20.82792091], [70.49346924, 20.8279171], [70.49346924, 20.82819557], [70.49291992, 20.82819557], [70.49291992, 20.82847214], [70.49236298, 20.82847023], [70.49236298, 20.82875061], [70.49013519, 20.82875061], [70.49013519, 20.82847214], [70.48986053, 20.82847214], [70.48986053, 20.82819557], [70.48874664, 20.82818985], [70.48874664, 20.82930946], [70.48847198, 20.82930946], [70.48847198, 20.82986069], [70.48819733, 20.82986069], [70.48819733, 20.83041954], [70.48791504, 20.83041763], [70.48791504, 20.8306942], [70.48819733, 20.83069038], [70.48819733, 20.83125114], [70.48791504, 20.83124924], [70.48792267, 20.83236122], [70.48764038, 20.83236122], [70.48764038, 20.83271027], [70.48764038, 20.83319473], [70.48735809, 20.83319473], [70.48735809, 20.83430481], [70.48708344, 20.83430481], [70.48708344, 20.83458328], [70.48652649, 20.83458328], [70.48652649, 20.83486176], [70.48596954, 20.83485985], [70.48596954, 20.83513832], [70.48320007, 20.83513832], [70.48320007, 20.83542061], [70.48236084, 20.83542061], [70.48236084, 20.83569908], [70.48152924, 20.83569527], [70.48152924, 20.83597183], [70.48069763, 20.83596992], [70.48069763, 20.8362484], [70.48042297, 20.8362484], [70.48042297, 20.83653069], [70.48013306, 20.83653069], [70.48013306, 20.83681107], [70.4798584, 20.83680534], [70.4798584, 20.83708382], [70.47957611, 20.83708191], [70.47957611, 20.83736038], [70.47930908, 20.83736038], [70.47930908, 20.83764267], [70.47902679, 20.83764267], [70.47902679, 20.83792114], [70.47875214, 20.83791733], [70.47875214, 20.83819389], [70.47819519, 20.83819389], [70.47819519, 20.83847046], [70.4779129, 20.83847046], [70.4779129, 20.83875275], [70.47763824, 20.83875275], [70.47763824, 20.83903122], [70.47735596, 20.83903122], [70.47735596, 20.83930969], [70.47680664, 20.83930588], [70.47680664, 20.83958054], [70.47651672, 20.83958054], [70.47651672, 20.84041977], [70.47569275, 20.84041405], [70.47569275, 20.84069443], [70.4751358, 20.84069061], [70.4751358, 20.84098053], [70.47402954, 20.84098053], [70.47402954, 20.84069061], [70.4734726, 20.84069443], [70.4734726, 20.84041405], [70.4723587, 20.84041977], [70.4723587, 20.83986282], [70.47207642, 20.83986282], [70.47207642, 20.83975029], [70.47208405, 20.83930588], [70.47180176, 20.83930969], [70.47180176, 20.83903122], [70.4715271, 20.83903122], [70.4715271, 20.83875275], [70.47125244, 20.83875275], [70.47125244, 20.83847046], [70.47097015, 20.83847046], [70.47097015, 20.83819389], [70.46902466, 20.83819389], [70.46902466, 20.83847046], [70.46847534, 20.83847046], [70.46848297, 20.83875275], [70.4679184, 20.83875275], [70.4679184, 20.83903122], [70.46736145, 20.83903122], [70.46736145, 20.83930969], [70.46652985, 20.83930588], [70.46652985, 20.83958054], [70.46624756, 20.83958054], [70.46624756, 20.83986282], [70.4659729, 20.83986282], [70.4659729, 20.84013939], [70.46569824, 20.84013939], [70.46569824, 20.84041977], [70.46541595, 20.84041405], [70.46541595, 20.84069443], [70.46512604, 20.84069061], [70.46512604, 20.84098053], [70.4640274, 20.84098053], [70.4640274, 20.84124947], [70.46290588, 20.84124947], [70.46290588, 20.84152985], [70.46235657, 20.84152985], [70.46235657, 20.84181023], [70.46208191, 20.84180641], [70.46208191, 20.84236145], [70.46180725, 20.84235954], [70.46180725, 20.84263992], [70.46151733, 20.84263992], [70.46151733, 20.84320068], [70.46125031, 20.84319687], [70.46125031, 20.84347153], [70.46097565, 20.84347153], [70.46098328, 20.84375], [70.45986176, 20.84375], [70.45986176, 20.84402847], [70.4595871, 20.84402084], [70.4595871, 20.84431076], [70.45903015, 20.84430695], [70.45903015, 20.84458351], [70.45874786, 20.84458351], [70.45874786, 20.84486198], [70.45847321, 20.84486008], [70.45847321, 20.84514046], [70.45791626, 20.84514046], [70.45791626, 20.84542084], [70.45708466, 20.84541512], [70.45708466, 20.84569359], [70.45625305, 20.84569359], [70.45625305, 20.84597206], [70.45540619, 20.84597015], [70.45540619, 20.84625053], [70.45513916, 20.84625053], [70.45513916, 20.84653091], [70.45458221, 20.84653091], [70.45458221, 20.84680748], [70.45402527, 20.84680557], [70.45402527, 20.84708405], [70.45375061, 20.84708023], [70.45375061, 20.84791756], [70.45347595, 20.84791756], [70.45347595, 20.84819412], [70.45319366, 20.84819412], [70.45319366, 20.8484726], [70.45236206, 20.84847069], [70.45236206, 20.84874916], [70.45181274, 20.84874916], [70.45181274, 20.84903145], [70.45041656, 20.84903145], [70.45041656, 20.84874916], [70.45014954, 20.84874916], [70.45014954, 20.84847069], [70.44985962, 20.8484726], [70.44985962, 20.84819412], [70.44958496, 20.84819412], [70.44958496, 20.84791756], [70.44930267, 20.84791756], [70.44930267, 20.84763908], [70.44847107, 20.84763908], [70.44847107, 20.84791756], [70.44736481, 20.84791756], [70.44736481, 20.84819412], [70.44709015, 20.84819031], [70.44709015, 20.84874916], [70.44735718, 20.84874916], [70.44735718, 20.84903145], [70.44763947, 20.84903145], [70.44763947, 20.84985924], [70.44735718, 20.84985924], [70.44735718, 20.85015106], [70.44709015, 20.85015106], [70.44709015, 20.85042191], [70.44652557, 20.85041618], [70.44652557, 20.85069466], [70.44596863, 20.85069466], [70.44596863, 20.85097122], [70.44568634, 20.85096931], [70.44568634, 20.8512516], [70.44541931, 20.8512516], [70.44541931, 20.85153008], [70.44513702, 20.85152817], [70.44513702, 20.85180473], [70.44486237, 20.85180473], [70.44486237, 20.8520813], [70.44458008, 20.8520813], [70.44458008, 20.85236359], [70.44403076, 20.85235977], [70.44403076, 20.85264015], [70.44374847, 20.85264015], [70.44374847, 20.85292053], [70.44346619, 20.85292053], [70.44346619, 20.85321045], [70.44319153, 20.85319519], [70.44319153, 20.85347366], [70.44291687, 20.85346985], [70.44291687, 20.85403061], [70.44264221, 20.85403061], [70.44264221, 20.85431099], [70.4420929, 20.85431099], [70.4420929, 20.85403061], [70.44180298, 20.85403061], [70.44180298, 20.85375023], [70.44152832, 20.85375023], [70.44152832, 20.85346985], [70.44069672, 20.85347366], [70.44069672, 20.85291672], [70.4404068, 20.85292053], [70.4404068, 20.85264015], [70.43902588, 20.85264015], [70.43902588, 20.85292053], [70.43875122, 20.85292053], [70.43875122, 20.85321045], [70.43846893, 20.85319519], [70.43846893, 20.85347366], [70.43818665, 20.85346985], [70.43818665, 20.85375023], [70.43763733, 20.85375023], [70.43763733, 20.85403061], [70.43736267, 20.85403061], [70.43736267, 20.85431099], [70.43708038, 20.85430527], [70.43708038, 20.85458374], [70.43653107, 20.85457993], [70.43653107, 20.85486031], [70.43624878, 20.85486031], [70.43624878, 20.85514069], [70.43596649, 20.85514069], [70.43596649, 20.85542107], [70.43569183, 20.85541725], [70.43569183, 20.85569572], [70.43514252, 20.85569572], [70.43514252, 20.85597229], [70.43486023, 20.85596085], [70.43486023, 20.85625076], [70.43430328, 20.85625076], [70.43430328, 20.85653114], [70.43374634, 20.85653114], [70.43374634, 20.85680962], [70.43347168, 20.8568058], [70.43347168, 20.85708427], [70.43319702, 20.85708046], [70.43319702, 20.85736084], [70.4329071, 20.85736084], [70.4329071, 20.85764122], [70.43235779, 20.85764122], [70.43235779, 20.85791969], [70.43208313, 20.85791779], [70.43208313, 20.85819435], [70.43180847, 20.85819435], [70.43180847, 20.85902786], [70.43152618, 20.85902786], [70.43152618, 20.8595829], [70.43125153, 20.8595829], [70.43125153, 20.85986137], [70.43096924, 20.85985947], [70.43096924, 20.86013985], [70.43068695, 20.86013985], [70.43068695, 20.86041832], [70.43041992, 20.86041641], [70.43041992, 20.86069489], [70.43013763, 20.86069107], [70.43013763, 20.86124992], [70.42986298, 20.86124992], [70.42986298, 20.8615284], [70.42930603, 20.8615284], [70.42930603, 20.86181068], [70.42874908, 20.86181068], [70.42874908, 20.86208916], [70.42819214, 20.86208344], [70.42819214, 20.86236191], [70.42791748, 20.86235809], [70.42791748, 20.86263847], [70.42736053, 20.86263847], [70.42736053, 20.86235809], [70.42679596, 20.86235809], [70.42679596, 20.86263847], [70.42624664, 20.86263847], [70.42624664, 20.86292076], [70.42541504, 20.86291695], [70.42542267, 20.8631897], [70.42485809, 20.86319542], [70.42485809, 20.86347008], [70.42457581, 20.86346817], [70.42457581, 20.86403275], [70.42430878, 20.86402702], [70.42430878, 20.86458206], [70.42402649, 20.86458015], [70.42402649, 20.86486244], [70.42375183, 20.86486244], [70.42375183, 20.86515045], [70.42346954, 20.86515045], [70.42346954, 20.86541939], [70.42319489, 20.86541748], [70.42319489, 20.86569214], [70.42292023, 20.86569214], [70.42292023, 20.86597061], [70.42263794, 20.86597061], [70.42263794, 20.8662529], [70.42236328, 20.8662529], [70.42236328, 20.86652946], [70.42208099, 20.86652946], [70.42208099, 20.86680984], [70.42180634, 20.86680984], [70.42180634, 20.86736107], [70.42151642, 20.86736107], [70.42151642, 20.86763954], [70.42124939, 20.86763954], [70.42124939, 20.86791992], [70.42097473, 20.86791611], [70.42097473, 20.86819458], [70.42069244, 20.86819458], [70.42069244, 20.86847305], [70.4201355, 20.86847305], [70.42014313, 20.86874962], [70.41986084, 20.86874962], [70.41986084, 20.86903], [70.41958618, 20.86902809], [70.41958618, 20.86930466], [70.41930389, 20.86930466], [70.41930389, 20.8698616], [70.41902924, 20.8698597], [70.41902924, 20.87042046], [70.41874695, 20.87042046], [70.41874695, 20.87070084], [70.41847229, 20.87069511], [70.41847229, 20.87097168], [70.41819763, 20.87096024], [70.41819763, 20.87125015], [70.41792297, 20.87125015], [70.41792297, 20.87153053], [70.41764069, 20.87153053], [70.41764069, 20.87181091], [70.41708374, 20.87180519], [70.41708374, 20.87208366], [70.41680908, 20.87207985], [70.41680908, 20.87236023], [70.41652679, 20.87236023], [70.41652679, 20.87264061], [70.41625214, 20.87264061], [70.41625214, 20.87292099], [70.41596985, 20.87291718], [70.41596985, 20.87319374], [70.41569519, 20.87319374], [70.41569519, 20.87347221], [70.4154129, 20.87347031], [70.4154129, 20.87375069], [70.41513824, 20.87375069], [70.41513824, 20.87402916], [70.4145813, 20.87402916], [70.4145813, 20.87431908], [70.41430664, 20.87430573], [70.41430664, 20.8745842], [70.41401672, 20.87458038], [70.41402435, 20.87486076], [70.41348267, 20.87486076], [70.41348267, 20.87513924], [70.41319275, 20.87513924], [70.41319275, 20.87542152], [70.41291809, 20.8754158], [70.41291809, 20.87597275], [70.4126358, 20.87597084], [70.4126358, 20.87624931], [70.41236115, 20.87624931], [70.41236115, 20.8765316], [70.41208649, 20.87652779], [70.41208649, 20.87735939], [70.41152954, 20.87735939], [70.41152954, 20.87764168], [70.41124725, 20.87764168], [70.41124725, 20.8801384], [70.41152954, 20.88013268], [70.41152954, 20.88042068], [70.41179657, 20.88042068], [70.41179657, 20.88070107], [70.41208649, 20.88069534], [70.41208649, 20.88097382], [70.41291809, 20.88097], [70.41291809, 20.88125038], [70.41374969, 20.88125038], [70.41374969, 20.88181114], [70.41402435, 20.88180542], [70.41402435, 20.8820858], [70.41430664, 20.88208008], [70.41430664, 20.88236046], [70.4154129, 20.88236046], [70.4154129, 20.88264084], [70.41707611, 20.88264084], [70.41707611, 20.88236046], [70.41764069, 20.88236046], [70.41764069, 20.88208008], [70.41791534, 20.8820858], [70.41791534, 20.88180542], [70.41819763, 20.88181114], [70.41819763, 20.88153076], [70.41958618, 20.88152695], [70.41958618, 20.8820858], [70.41874695, 20.88208008], [70.41874695, 20.88236046], [70.41819763, 20.88236046], [70.41819763, 20.88264084], [70.41791534, 20.88263893], [70.41791534, 20.88363838], [70.41792297, 20.88486099], [70.41764069, 20.88486099], [70.41764069, 20.88597298], [70.4173584, 20.88597107], [70.4173584, 20.88652992], [70.41708374, 20.88652611], [70.41708374, 20.88708305], [70.41680908, 20.88708305], [70.41680908, 20.88680649], [70.41625214, 20.8868103], [70.41625214, 20.88625908], [70.41652679, 20.88625908], [70.41652679, 20.88597107], [70.41680908, 20.88597298], [70.41680908, 20.88486099], [70.41707611, 20.88486099], [70.41708374, 20.88412094], [70.41708374, 20.88347244], [70.41680908, 20.88347244], [70.41680908, 20.88319588], [70.41402435, 20.88319588], [70.41402435, 20.88347244], [70.41374969, 20.88347054], [70.41374969, 20.88375092], [70.41319275, 20.88375092], [70.41319275, 20.88402939], [70.4126358, 20.88402939], [70.4126358, 20.88375092], [70.41124725, 20.88375092], [70.41124725, 20.88347054], [70.41041565, 20.88347244], [70.41041565, 20.88319588], [70.4098587, 20.88319588], [70.4098587, 20.8829174], [70.40957642, 20.88292122], [70.40957642, 20.88236046], [70.40735626, 20.88236046], [70.40735626, 20.88264084], [70.40651703, 20.88264084], [70.40651703, 20.88292122], [70.40625, 20.8829174], [70.40625, 20.88319588], [70.40597534, 20.88319588], [70.40597534, 20.88347244], [70.40569305, 20.88347054], [70.40569305, 20.88375092], [70.4054184, 20.88375092], [70.4054184, 20.88402939], [70.40513611, 20.88402939], [70.40513611, 20.88430977], [70.40486145, 20.88430786], [70.40486145, 20.88458252], [70.40458679, 20.88458061], [70.40458679, 20.88486099], [70.40402985, 20.88486099], [70.40402985, 20.88513947], [70.4034729, 20.88513947], [70.4034729, 20.88541985], [70.40291595, 20.88541794], [70.40291595, 20.8856945], [70.40235901, 20.88569069], [70.40235901, 20.88625908], [70.40207672, 20.88625908], [70.40207672, 20.88652992], [70.4017868, 20.88652992], [70.4017868, 20.8868103], [70.4015274, 20.88680649], [70.4015274, 20.88708305], [70.40097046, 20.88708305], [70.40097046, 20.88736153], [70.4006958, 20.88735962], [70.4006958, 20.88763809], [70.40040588, 20.88763809], [70.40040588, 20.88792038], [70.39985657, 20.88792038], [70.39985657, 20.88820076], [70.39958191, 20.88819504], [70.39958191, 20.8884716], [70.39930725, 20.8884697], [70.39930725, 20.88874817], [70.39901733, 20.88874817], [70.39901733, 20.88902855], [70.39875031, 20.88902855], [70.39875031, 20.88958359], [70.39847565, 20.88958359], [70.39847565, 20.88986015], [70.39819336, 20.88985825], [70.39819336, 20.89013863], [70.3979187, 20.89013863], [70.3979187, 20.89042282], [70.39763641, 20.8904171], [70.39763641, 20.89069366], [70.39736176, 20.89069176], [70.39736176, 20.89125252], [70.3970871, 20.89125252], [70.3970871, 20.8915329], [70.39679718, 20.8915329], [70.39679718, 20.89180946], [70.39624786, 20.89180565], [70.39624786, 20.89208412], [70.39597321, 20.89208412], [70.39598083, 20.89236259], [70.39569092, 20.89236259], [70.39569092, 20.89264107], [70.3951416, 20.89264107], [70.3951416, 20.89291954], [70.39458466, 20.89291763], [70.39458466, 20.89347458], [70.39430237, 20.89347076], [70.39430237, 20.89375114], [70.39402771, 20.89375114], [70.39402771, 20.89402962], [70.39347076, 20.89402962], [70.39347076, 20.89431], [70.39180756, 20.89430618], [70.39180756, 20.89458466], [70.39152527, 20.89458466], [70.3915329, 20.89486122], [70.38957977, 20.89486122], [70.38957977, 20.89513969], [70.38874817, 20.89513016], [70.38874817, 20.89542007], [70.38819122, 20.89541626], [70.38819122, 20.89569473], [70.38791656, 20.89569473], [70.38791656, 20.89541626], [70.38735962, 20.89541626], [70.38735962, 20.89569473], [70.38707733, 20.89569092], [70.38708496, 20.89624977], [70.3868103, 20.89624977], [70.3868103, 20.89653015], [70.38625336, 20.89652824], [70.38625336, 20.89680672], [70.38597107, 20.89680672], [70.38597107, 20.89736176], [70.38513947, 20.89735985], [70.38513947, 20.89764023], [70.38485718, 20.89764023], [70.38485718, 20.89792061], [70.38375092, 20.89792061], [70.38375092, 20.89820099], [70.38263702, 20.89819527], [70.38263702, 20.89847183], [70.38236237, 20.89846992], [70.38236237, 20.89875031], [70.38208008, 20.89875031], [70.38208008, 20.89903069], [70.38101959, 20.89902687], [70.38069153, 20.89902687], [70.38069153, 20.89929008], [70.38069153, 20.89958382], [70.38041687, 20.89958], [70.38041687, 20.89986038], [70.38014221, 20.89986038], [70.38014221, 20.90014076], [70.37961578, 20.90013885], [70.37930298, 20.90013885], [70.37928772, 20.9004097], [70.37875366, 20.90041733], [70.37875366, 20.90069389], [70.37763977, 20.90069389], [70.37763977, 20.90097237], [70.37652588, 20.90097046], [70.37652588, 20.90125847], [70.37625122, 20.90125847], [70.37625122, 20.90153122], [70.37568665, 20.90153122], [70.37568665, 20.90180969], [70.37458038, 20.90180588], [70.37458038, 20.90208244], [70.37346649, 20.90208054], [70.37346649, 20.90236092], [70.37264252, 20.90236092], [70.37264252, 20.90263939], [70.37097168, 20.90263939], [70.37097168, 20.90236092], [70.37069702, 20.90236092], [70.37069702, 20.90153122], [70.37097168, 20.90153122], [70.37097168, 20.90069008], [70.37069702, 20.90069389], [70.37069702, 20.89986038], [70.37097168, 20.89986038], [70.37097168, 20.89931107], [70.37152863, 20.89931107], [70.37152863, 20.89875031], [70.37210083, 20.89875031], [70.37208557, 20.89847183], [70.37236023, 20.89847183], [70.37236023, 20.89763832], [70.37264252, 20.89764023], [70.37264252, 20.89735985], [70.37291718, 20.89736176], [70.37291718, 20.89708328], [70.37319183, 20.89708328], [70.37319183, 20.89680672], [70.37347412, 20.89680672], [70.37347412, 20.89652824], [70.37403107, 20.89653015], [70.37403107, 20.89624977], [70.37458038, 20.89624977], [70.37458038, 20.89486122], [70.37374878, 20.89486122], [70.37374878, 20.89542007], [70.37347412, 20.89541626], [70.37347412, 20.89569473], [70.37236023, 20.89569092], [70.37236023, 20.89624977], [70.37210083, 20.89624977], [70.37210083, 20.89653015], [70.37180328, 20.89652824], [70.37180328, 20.89680672], [70.37152863, 20.89680672], [70.37152863, 20.89708328], [70.37097168, 20.89708328], [70.37097168, 20.89736176], [70.37069702, 20.89735985], [70.37069702, 20.89820099], [70.37041473, 20.89819527], [70.37041473, 20.89847183], [70.37014008, 20.89846992], [70.37014008, 20.89875031], [70.36958313, 20.89875031], [70.36958313, 20.89903069], [70.36930847, 20.89903069], [70.36930847, 20.89931107], [70.36902618, 20.89930534], [70.36902618, 20.89958382], [70.36818695, 20.89958], [70.36818695, 20.89986038], [70.36708069, 20.89986038], [70.36708069, 20.90014076], [70.36653137, 20.90014076], [70.36653137, 20.90042114], [70.36541748, 20.90041733], [70.36541748, 20.90069389], [70.36486053, 20.90069389], [70.36486053, 20.90097237], [70.36458588, 20.90097046], [70.36458588, 20.90125847], [70.36429596, 20.90125847], [70.36429596, 20.90153122], [70.36402893, 20.90153122], [70.36402893, 20.90180969], [70.36374664, 20.90180588], [70.36374664, 20.90208244], [70.36347198, 20.90208054], [70.36347198, 20.90236092], [70.36291504, 20.90236092], [70.3629303, 20.90263939], [70.36264038, 20.90263939], [70.36264038, 20.90292168], [70.36235809, 20.90291595], [70.36235809, 20.90319443], [70.36152649, 20.90319443], [70.36152649, 20.9034729], [70.36096954, 20.90346909], [70.36096954, 20.90374947], [70.36068726, 20.90374947], [70.36068726, 20.90403175], [70.35930634, 20.90403175], [70.35930634, 20.90431976], [70.35902405, 20.90430641], [70.35902405, 20.90458107], [70.35874939, 20.90458107], [70.35874939, 20.90485954], [70.3584671, 20.90485954], [70.3584671, 20.90514183], [70.35819244, 20.90514183], [70.35819244, 20.9054203], [70.35736084, 20.9054203], [70.35736084, 20.90570068], [70.35708618, 20.90569496], [70.35708618, 20.90597343], [70.35652924, 20.90596962], [70.35652924, 20.90653038], [70.35624695, 20.90653038], [70.35624695, 20.90681076], [70.35597229, 20.90680313], [70.35597229, 20.9070816], [70.35542297, 20.90707016], [70.35542297, 20.90764046], [70.3548584, 20.90764046], [70.3548584, 20.90792084], [70.35430908, 20.90791702], [70.35430908, 20.9081955], [70.35402679, 20.9081955], [70.35402679, 20.90847206], [70.35346985, 20.90847015], [70.35346985, 20.90875053], [70.3529129, 20.90875053], [70.3529129, 20.90903091], [70.35263824, 20.90903091], [70.35263824, 20.90930939], [70.3520813, 20.90930557], [70.3520813, 20.90958595], [70.35180664, 20.90958023], [70.35180664, 20.90986061], [70.35151672, 20.90986061], [70.35151672, 20.91014099], [70.35124969, 20.91014099], [70.35124969, 20.91041946], [70.35097504, 20.91041756], [70.35097504, 20.9109726], [70.35067749, 20.91097069], [70.35067749, 20.91152954], [70.35041809, 20.91152763], [70.35041809, 20.91208267], [70.34986115, 20.91208076], [70.34986115, 20.91236115], [70.34958649, 20.91236115], [70.34958649, 20.91263962], [70.34929657, 20.91263962], [70.34929657, 20.91320038], [70.34902954, 20.91319466], [70.34902954, 20.91347313], [70.34874725, 20.91347122], [70.34874725, 20.91402817], [70.3484726, 20.91402817], [70.3484726, 20.91430473], [70.34791565, 20.91430473], [70.34791565, 20.91458321], [70.34764099, 20.91458321], [70.34764099, 20.91486168], [70.3473587, 20.91485977], [70.3473587, 20.91513824], [70.34708405, 20.91513824], [70.34708405, 20.91624832], [70.3473587, 20.91624069], [70.3473587, 20.9168129], [70.34764099, 20.9168129], [70.34764099, 20.91736031], [70.34793091, 20.91736031], [70.34793091, 20.91764259], [70.34819794, 20.91764259], [70.34819794, 20.91792107], [70.3484726, 20.91791725], [70.3484726, 20.91819382], [70.34874725, 20.91819382], [70.34874725, 20.91847038], [70.34958649, 20.91847038], [70.34958649, 20.91875267], [70.34986115, 20.91875267], [70.34986115, 20.91903114], [70.3501358, 20.91902733], [70.3501358, 20.9193058], [70.35041809, 20.9193058], [70.35041809, 20.91958046], [70.3509903, 20.91958046], [70.3509903, 20.92014122], [70.35124969, 20.92013931], [70.35124969, 20.92069244], [70.35069275, 20.92069244], [70.35069275, 20.92041588], [70.35041809, 20.92041969], [70.35041809, 20.92014122], [70.3501358, 20.92014122], [70.3501358, 20.91986275], [70.34986115, 20.91986275], [70.34986115, 20.91958046], [70.3493042, 20.91958427], [70.3493042, 20.91941071], [70.3493042, 20.9193058], [70.34902954, 20.9193058], [70.34902954, 20.91902733], [70.34764099, 20.91902733], [70.34764099, 20.9193058], [70.34707642, 20.91930008], [70.34707642, 20.91986275], [70.3473587, 20.91986275], [70.3473587, 20.92041969], [70.34764099, 20.92041588], [70.34764099, 20.92054939], [70.34764099, 20.92152977], [70.34707642, 20.92152977], [70.34708405, 20.92093086], [70.34708405, 20.92069244], [70.34680176, 20.92069244], [70.34680176, 20.92013931], [70.3465271, 20.92014122], [70.3465271, 20.91736031], [70.34625244, 20.91736031], [70.34625244, 20.91596985], [70.34597015, 20.91597176], [70.34597015, 20.91569519], [70.34513855, 20.91569519], [70.34513855, 20.91597176], [70.34402466, 20.91597176], [70.34402466, 20.91624832], [70.34319305, 20.91624069], [70.34319305, 20.91653061], [70.3429184, 20.91653061], [70.3429184, 20.9168129], [70.34208679, 20.91680527], [70.34208679, 20.91708374], [70.34179688, 20.91708183], [70.34179688, 20.91736031], [70.34124756, 20.91736031], [70.34124756, 20.91764259], [70.34041595, 20.91764259], [70.34041595, 20.91792107], [70.33985901, 20.91791725], [70.33985901, 20.91819382], [70.33958435, 20.91819382], [70.33958435, 20.91847038], [70.33930206, 20.91847038], [70.33930206, 20.91875267], [70.3390274, 20.91875267], [70.3390274, 20.91903114], [70.33847046, 20.91902733], [70.33847046, 20.9193058], [70.33791351, 20.9193058], [70.33791351, 20.91958427], [70.33735657, 20.91958046], [70.33735657, 20.91986275], [70.33708191, 20.91986275], [70.33708191, 20.92014122], [70.33651733, 20.92014122], [70.33651733, 20.92041969], [70.33597565, 20.92041588], [70.33597565, 20.92069244], [70.33569336, 20.92069244], [70.33569336, 20.92097473], [70.3354187, 20.92097282], [70.3354187, 20.92124939], [70.33486176, 20.92124939], [70.33486176, 20.92152977], [70.33429718, 20.92152977], [70.33429718, 20.92181015], [70.33374786, 20.92180634], [70.33374786, 20.92208481], [70.33291626, 20.92208481], [70.33291626, 20.92236137], [70.3326416, 20.92235947], [70.3326416, 20.92263985], [70.33207703, 20.92263985], [70.33207703, 20.92292023], [70.33180237, 20.92291641], [70.33180237, 20.92319679], [70.33097076, 20.92319679], [70.33097076, 20.92347145], [70.33013916, 20.92346954], [70.33013916, 20.92374992], [70.32985687, 20.92374992], [70.32985687, 20.9240303], [70.32956696, 20.9240303], [70.32956696, 20.92431068], [70.32902527, 20.92430687], [70.32902527, 20.92458344], [70.32819366, 20.92458344], [70.32819366, 20.92486191], [70.32736206, 20.92486], [70.32736206, 20.92514038], [70.32596588, 20.92514038], [70.32596588, 20.9254303], [70.32569122, 20.92541695], [70.32569122, 20.9256897], [70.32541656, 20.92569542], [70.32541656, 20.92597198], [70.32514191, 20.92597008], [70.32514191, 20.92625046], [70.32457733, 20.92625046], [70.32457733, 20.92681122], [70.32347107, 20.92681122], [70.32347107, 20.92653084], [70.32263947, 20.92653084], [70.32263947, 20.92681122], [70.32235718, 20.92681122], [70.32236481, 20.92736053], [70.3207016, 20.92736053], [70.3207016, 20.92764091], [70.32041931, 20.92764091], [70.32041931, 20.92791748], [70.32013702, 20.92791748], [70.32013702, 20.92819405], [70.31986237, 20.92818069], [70.31986237, 20.92874908], [70.31958008, 20.92874908], [70.31958008, 20.92903137], [70.31930542, 20.92902756], [70.31930542, 20.9295826], [70.31903076, 20.92958069], [70.31903076, 20.93014145], [70.31874847, 20.93014145], [70.31874847, 20.93042183], [70.31847382, 20.93041611], [70.31847382, 20.93069458], [70.31819153, 20.93069458], [70.31819153, 20.93097115], [70.31791687, 20.93097115], [70.31791687, 20.93124962], [70.31764221, 20.93124962], [70.31764221, 20.93180466], [70.31735992, 20.93180466], [70.31735992, 20.93236351], [70.3170929, 20.9323597], [70.3170929, 20.93264008], [70.31680298, 20.93264008], [70.31680298, 20.93292046], [70.31652832, 20.93292046], [70.31652832, 20.93320084], [70.31625366, 20.93319511], [70.31625366, 20.93347359], [70.31597137, 20.93346977], [70.31597137, 20.93375015], [70.31569672, 20.93375015], [70.31569672, 20.93403053], [70.31541443, 20.93402863], [70.31541443, 20.93430328], [70.31513977, 20.93430328], [70.31513977, 20.93458366], [70.31318665, 20.93457985], [70.31318665, 20.93486023], [70.31208038, 20.93486023], [70.31208038, 20.93514061], [70.31153107, 20.93514061], [70.31153107, 20.93542099], [70.31124878, 20.93541718], [70.31124878, 20.93569565], [70.31096649, 20.93568993], [70.31096649, 20.93625069], [70.31069183, 20.93625069], [70.31069183, 20.9370842], [70.31041718, 20.93708038], [70.31041718, 20.9373703], [70.31014252, 20.9373703], [70.31014252, 20.93764114], [70.30958557, 20.93763924], [70.30958557, 20.93847275], [70.30930328, 20.93847084], [70.30930328, 20.93902969], [70.3087616, 20.93902969], [70.3087616, 20.93930817], [70.30819702, 20.93930626], [70.30819702, 20.93958282], [70.30791473, 20.93958282], [70.30791473, 20.9398613], [70.30735779, 20.93985939], [70.30735779, 20.94013977], [70.30680847, 20.94013977], [70.30680847, 20.94043159], [70.30652618, 20.94041634], [70.30652618, 20.94069481], [70.30569458, 20.94069481], [70.30569458, 20.94097137], [70.30541992, 20.94096947], [70.30541992, 20.94124985], [70.30513763, 20.94124985], [70.30513763, 20.94152832], [70.30403137, 20.94152832], [70.30403137, 20.94180489], [70.30374908, 20.94180489], [70.30374908, 20.94208336], [70.30319214, 20.94208336], [70.30319214, 20.94236183], [70.30291748, 20.94235992], [70.30291748, 20.9426384], [70.30262756, 20.9426384], [70.30262756, 20.94292068], [70.30208588, 20.94292068], [70.30208588, 20.94319916], [70.30152893, 20.94319534], [70.30152893, 20.94347191], [70.30097198, 20.94346809], [70.30097198, 20.94375229], [70.30069733, 20.94375229], [70.30069733, 20.94431114], [70.30014038, 20.94430542], [70.30014038, 20.94458389], [70.29985809, 20.94458008], [70.29985809, 20.94486046], [70.29959106, 20.94486046], [70.29959106, 20.94514275], [70.29902649, 20.94514275], [70.29902649, 20.94542122], [70.29846954, 20.9454174], [70.29846954, 20.94569206], [70.29763794, 20.94569206], [70.29763794, 20.94597054], [70.29736328, 20.94597054], [70.29736328, 20.94625282], [70.29682159, 20.94623947], [70.29682159, 20.94652939], [70.2959671, 20.94652939], [70.2959671, 20.94680977], [70.29541779, 20.94680595], [70.29541779, 20.94708443], [70.29486084, 20.94708061], [70.29486084, 20.9473629], [70.29458618, 20.9473629], [70.29458618, 20.94763947], [70.29374695, 20.94763947], [70.29374695, 20.94791985], [70.29347229, 20.94791412], [70.29347229, 20.94847488], [70.29319763, 20.94847107], [70.29319763, 20.94874954], [70.29264069, 20.94874954], [70.29264069, 20.94902992], [70.29207611, 20.94902992], [70.29207611, 20.9493103], [70.29180908, 20.94930649], [70.29180908, 20.94986153], [70.29152679, 20.94985962], [70.29152679, 20.95014], [70.29096985, 20.95014], [70.29096985, 20.95042038], [70.29068756, 20.95042038], [70.29068756, 20.95070076], [70.2904129, 20.95069695], [70.2904129, 20.9509716], [70.29013824, 20.9509697], [70.29013824, 20.95125008], [70.28985596, 20.95125008], [70.28985596, 20.95153046], [70.28930664, 20.95153046], [70.28930664, 20.95181084], [70.28874969, 20.95180511], [70.28874969, 20.95208359], [70.28848267, 20.95207977], [70.28848267, 20.95236969], [70.28819275, 20.95236969], [70.28819275, 20.95264053], [70.28765106, 20.95264053], [70.28765106, 20.95292091], [70.28736115, 20.9529171], [70.28736115, 20.95319366], [70.2868042, 20.95319366], [70.2868042, 20.95347214], [70.28624725, 20.95347023], [70.28624725, 20.95375061], [70.28569794, 20.95375061], [70.28569794, 20.95402908], [70.28514099, 20.95402908], [70.28514099, 20.95430756], [70.2848587, 20.95430565], [70.2848587, 20.95458412], [70.28430939, 20.95458031], [70.28430176, 20.95486069], [70.28375244, 20.95486069], [70.28375244, 20.95513916], [70.28347015, 20.95513725], [70.28347015, 20.95541573], [70.28236389, 20.95541763], [70.28236389, 20.9556942], [70.2820816, 20.9556942], [70.2820816, 20.95597267], [70.28180695, 20.95597076], [70.28180695, 20.95624924], [70.28151703, 20.95624924], [70.28151703, 20.95653152], [70.28125, 20.95653152], [70.28125, 20.9568119], [70.28069305, 20.95680618], [70.28069305, 20.95708275], [70.2804184, 20.95708084], [70.2804184, 20.95735931], [70.27986145, 20.95735931], [70.27986145, 20.9576416], [70.27958679, 20.9576416], [70.27958679, 20.95792007], [70.2793045, 20.95791626], [70.2793045, 20.95819473], [70.27902985, 20.95819473], [70.27902985, 20.95846939], [70.27874756, 20.95846939], [70.27874756, 20.95930481], [70.2784729, 20.95930481], [70.2784729, 20.95958138], [70.27819824, 20.95958138], [70.27819824, 20.95986366], [70.2776413, 20.95985985], [70.2776413, 20.96014023], [70.27735901, 20.96014023], [70.27735901, 20.96042061], [70.27680206, 20.96042061], [70.27680206, 20.96070099], [70.2765274, 20.96070099], [70.2765274, 20.96125031], [70.27625275, 20.96125031], [70.27625275, 20.96181107], [70.27597046, 20.96180534], [70.27597046, 20.96208572], [70.27485657, 20.96208], [70.27485657, 20.96236038], [70.27458191, 20.96236038], [70.27458191, 20.96264076], [70.27401733, 20.96264076], [70.27401733, 20.96292114], [70.27319336, 20.96291733], [70.27319336, 20.9631958], [70.27263641, 20.9631958], [70.27263641, 20.96347237], [70.27236176, 20.96347046], [70.27236176, 20.96375084], [70.2720871, 20.96375084], [70.2720871, 20.96403122], [70.27179718, 20.96403122], [70.27179718, 20.96430969], [70.27124786, 20.96430588], [70.27124786, 20.96458244], [70.27097321, 20.96458054], [70.27097321, 20.96486092], [70.27069092, 20.96486092], [70.27069092, 20.96513939], [70.26985931, 20.96513939], [70.26985931, 20.96541977], [70.26930237, 20.96541786], [70.26930237, 20.96569443], [70.26902771, 20.96569443], [70.26902771, 20.9659729], [70.26875305, 20.96597099], [70.26875305, 20.96624947], [70.26847076, 20.96624947], [70.26847076, 20.96652985], [70.26790619, 20.96652985], [70.26790619, 20.96681023], [70.26763916, 20.96680641], [70.26763916, 20.96708298], [70.2673645, 20.96708298], [70.2673645, 20.96736145], [70.26680756, 20.96735001], [70.26680756, 20.96763992], [70.26651764, 20.96763992], [70.26651764, 20.9679184], [70.26625061, 20.9679184], [70.26625061, 20.96820068], [70.26597595, 20.96819496], [70.26597595, 20.96847153], [70.26513672, 20.96846962], [70.26513672, 20.96874809], [70.26457977, 20.96874809], [70.26457977, 20.96902847], [70.26431274, 20.96902847], [70.26431274, 20.96931076], [70.26374817, 20.96930504], [70.26374817, 20.96958351], [70.26347351, 20.96958351], [70.26347351, 20.96986008], [70.26319122, 20.96985817], [70.26319122, 20.97013855], [70.26291656, 20.97013855], [70.26291656, 20.97041702], [70.26264191, 20.97041702], [70.26264191, 20.97069359], [70.26235962, 20.97069359], [70.26235962, 20.97097015], [70.26180267, 20.97097015], [70.26180267, 20.97125244], [70.26125336, 20.97125244], [70.26125336, 20.97153282], [70.26097107, 20.97153282], [70.26097107, 20.97180939], [70.26069641, 20.97180557], [70.26069641, 20.97208214], [70.26013947, 20.97208023], [70.26013947, 20.97236061], [70.25985718, 20.97236061], [70.25985718, 20.9726429], [70.25818634, 20.9726429], [70.25818634, 20.97291946], [70.25791931, 20.97291946], [70.25791931, 20.97348022], [70.25763702, 20.97348022], [70.25763702, 20.97375107], [70.25734711, 20.97375107], [70.25734711, 20.97430992], [70.25708008, 20.97430611], [70.25708008, 20.97458458], [70.25680542, 20.97458458], [70.25681305, 20.97486115], [70.25653076, 20.97486115], [70.25653076, 20.97513962], [70.25624847, 20.97513962], [70.25624847, 20.97542], [70.25597382, 20.97541618], [70.25596619, 20.97565079], [70.25541687, 20.97569466], [70.25541687, 20.97597313], [70.25514221, 20.97597122], [70.25514221, 20.97624969], [70.25485992, 20.97624969], [70.25485992, 20.97653961], [70.25458527, 20.97652817], [70.25458527, 20.97680664], [70.25430298, 20.97680664], [70.25430298, 20.97708321], [70.25402832, 20.97708321], [70.25402832, 20.97736168], [70.25374603, 20.97735977], [70.25374603, 20.97764015], [70.25347137, 20.97764015], [70.25347137, 20.97820091], [70.25263977, 20.97819519], [70.25263977, 20.97847176], [70.25235748, 20.97846985], [70.25235748, 20.97875023], [70.25208282, 20.97875023], [70.25208282, 20.97903061], [70.25152588, 20.9790287], [70.25152588, 20.98069382], [70.25125122, 20.98069382], [70.25125122, 20.98097229], [70.25096893, 20.98097038], [70.25096893, 20.98125076], [70.25068665, 20.98125076], [70.25068665, 20.98152924], [70.25013733, 20.98152924], [70.25013733, 20.98180962], [70.24986267, 20.9818058], [70.24986267, 20.98236084], [70.24958038, 20.9823494], [70.24958038, 20.9829216], [70.24930573, 20.98291588], [70.24930573, 20.98319435], [70.24903107, 20.98319435], [70.24903107, 20.98347282], [70.24874878, 20.98347092], [70.24874878, 20.98403168], [70.24848175, 20.98403168], [70.24848175, 20.98431015], [70.24819183, 20.98430634], [70.24819183, 20.9845829], [70.24791718, 20.9845829], [70.24791718, 20.98485947], [70.24764252, 20.98485947], [70.24764252, 20.98513794], [70.2470932, 20.98514175], [70.2470932, 20.98542023], [70.24680328, 20.98541641], [70.24680328, 20.98569489], [70.24624634, 20.98569489], [70.24624634, 20.98597145], [70.24597168, 20.98596954], [70.24597168, 20.98625183], [70.2454071, 20.98625183], [70.2454071, 20.9865303], [70.24514008, 20.9865303], [70.24514008, 20.98681068], [70.24485779, 20.98680305], [70.24485779, 20.98708153], [70.24458313, 20.98708153], [70.24458313, 20.98736382], [70.24430847, 20.98736], [70.24430847, 20.98764038], [70.24402618, 20.98764038], [70.24402618, 20.98792076], [70.24375153, 20.98791695], [70.24375153, 20.9881897], [70.24346924, 20.98820114], [70.24346924, 20.98847961], [70.24318695, 20.98847961], [70.24318695, 20.98875046], [70.24291992, 20.98875046], [70.24291992, 20.98931122], [70.24263763, 20.9893055], [70.24263763, 20.98958588], [70.24234772, 20.98958015], [70.24234772, 20.98986053], [70.24208069, 20.98986053], [70.24208069, 20.99041939], [70.24097443, 20.99041748], [70.24097443, 20.99097252], [70.24069214, 20.99097061], [70.24069214, 20.99125099], [70.24041748, 20.99125099], [70.24041748, 20.99180984], [70.24013519, 20.99180794], [70.24014282, 20.99236107], [70.23986053, 20.99236107], [70.23986053, 20.99263954], [70.23958588, 20.99263954], [70.23958588, 20.99319458], [70.23986053, 20.99319458], [70.23986053, 20.99347305], [70.24013519, 20.99347305], [70.24013519, 20.99374962], [70.24041748, 20.99374962], [70.24041748, 20.99402809], [70.24124908, 20.99402618], [70.24124908, 20.99430466], [70.24153137, 20.99430466], [70.24153137, 20.9948616], [70.24208069, 20.9948597], [70.24208069, 20.99513817], [70.24234772, 20.99513817], [70.24234772, 20.99542046], [70.24263763, 20.99542046], [70.24263763, 20.99570084], [70.24291992, 20.99569511], [70.24291992, 20.99597168], [70.24318695, 20.99596977], [70.24318695, 20.99624825], [70.24346924, 20.99624825], [70.24346924, 20.99652863], [70.24375153, 20.99652863], [70.24375153, 20.99681091], [70.24402618, 20.99680519], [70.24402618, 20.99708366], [70.24430847, 20.99707985], [70.24430847, 20.99736023], [70.24458313, 20.99736023], [70.24458313, 20.99765015], [70.24514008, 20.99765015], [70.24514008, 20.9979229], [70.24541473, 20.99791718], [70.24541473, 20.99819374], [70.24597168, 20.99819374], [70.24597168, 20.99847031], [70.24624634, 20.99847031], [70.24624634, 20.99875259], [70.24652863, 20.99875259], [70.24652863, 20.99930954], [70.24680328, 20.99930763], [70.24708557, 20.99930573], [70.24708557, 20.99958229], [70.24764252, 20.99958038], [70.24764252, 20.99986267], [70.24764252, 21.00014114], [70.24764252, 21.00041962], [70.24708557, 21.0004158], [70.24708557, 21.00069237], [70.24652863, 21.00069237], [70.24652863, 21.0004158], [70.24652863, 21.00014114], [70.24652863, 20.99986267], [70.24624634, 20.99986267], [70.24624634, 20.99958992], [70.24597168, 20.99958038], [70.24597168, 20.99930573], [70.24569702, 20.99930954], [70.24569702, 20.99903107], [70.24514008, 20.99903107], [70.24514008, 20.99875259], [70.24485779, 20.99875259], [70.24485779, 20.99847031], [70.24458313, 20.99847031], [70.24458313, 20.99819374], [70.24430847, 20.99819374], [70.24430847, 20.99791718], [70.24402618, 20.9979229], [70.24402618, 20.99765015], [70.24346924, 20.99765015], [70.24346924, 20.99736023], [70.24263763, 20.99736023], [70.24263763, 20.99707985], [70.24208069, 20.99708366], [70.24208069, 20.99680519], [70.24180603, 20.99681091], [70.24180603, 20.99652863], [70.24153137, 20.99652863], [70.24153137, 20.99596977], [70.24124908, 20.99597168], [70.24124908, 20.99569511], [70.24041748, 20.99570084], [70.24041748, 20.99542046], [70.23960114, 20.99542046], [70.23960114, 20.9948597], [70.23902893, 20.9948616], [70.23902893, 20.99458313], [70.23874664, 20.99458313], [70.23874664, 20.99402618], [70.23819733, 20.99402809], [70.23819733, 20.99374962], [70.23792267, 20.99374962], [70.23792267, 20.99402809], [70.23708344, 20.99402618], [70.23708344, 20.99430466], [70.23652649, 20.99430466], [70.23652649, 20.99458313], [70.23625183, 20.99458122], [70.23625183, 20.99570084], [70.23652649, 20.99569511], [70.23652649, 20.99597168], [70.23680878, 20.99596977], [70.23680878, 20.99624825], [70.23707581, 20.99624825], [70.23707581, 20.99652863], [70.23735809, 20.99652863], [70.23735809, 20.99681091], [70.23764038, 20.99680519], [70.23764038, 20.99708366], [70.23791504, 20.99708366], [70.23791504, 20.99736023], [70.23819733, 20.99736023], [70.23819733, 20.99765015], [70.23847198, 20.99765015], [70.23847198, 20.9979229], [70.23874664, 20.99791718], [70.23874664, 20.99819374], [70.23902893, 20.99819374], [70.23902893, 20.99847031], [70.23960114, 20.99847031], [70.23960114, 20.99903107], [70.23986053, 20.99903107], [70.23986053, 20.99930954], [70.24041748, 20.99930573], [70.24041748, 20.99958229], [70.23930359, 20.99958229], [70.23930359, 20.99930573], [70.23874664, 20.99930954], [70.23874664, 20.99903107], [70.23819733, 20.99903107], [70.23819733, 20.99875259], [70.23791504, 20.99875259], [70.23791504, 20.99847031], [70.23764038, 20.99847031], [70.23764038, 20.99819374], [70.23735809, 20.99819374], [70.23735809, 20.99791718], [70.23707581, 20.9979229], [70.23707581, 20.99736023], [70.23652649, 20.99736023], [70.23652649, 20.99708366], [70.23625183, 20.99708366], [70.23625183, 20.99652863], [70.23596954, 20.99652863], [70.23596954, 20.99624825], [70.23513794, 20.99624825], [70.23513794, 20.99652863], [70.23486328, 20.99652863], [70.23486328, 20.99681091], [70.23430634, 20.99680519], [70.23430634, 20.99708366], [70.23374939, 20.99707985], [70.23374939, 20.99736023], [70.2334671, 20.99736023], [70.2334671, 20.99765015], [70.23291779, 20.99765015], [70.23291779, 20.9979229], [70.23236084, 20.99791718], [70.23236084, 20.99819374], [70.23180389, 20.99819374], [70.23180389, 20.99847031], [70.23152924, 20.99847031], [70.23152924, 20.99875259], [70.22680664, 20.99875259], [70.22680664, 20.99903107], [70.22624969, 20.99902725], [70.22624969, 20.99958229], [70.22598267, 20.99958038], [70.22598267, 21.00014114], [70.22598267, 21.00041962], [70.22569275, 21.0004158], [70.22569275, 21.00069237], [70.22541809, 21.00069237], [70.22541809, 21.00097466], [70.2251358, 21.00097084], [70.2251358, 21.00152969], [70.22460175, 21.00152969], [70.22460175, 21.00181007], [70.22402954, 21.00180626], [70.22402954, 21.00208473], [70.22374725, 21.00208092], [70.22374725, 21.00263977], [70.2234726, 21.00263977], [70.2234726, 21.00292015], [70.22319794, 21.00291634], [70.22319794, 21.00319672], [70.22264099, 21.00319672], [70.22264099, 21.00291634], [70.2223587, 21.00292015], [70.2223587, 21.00263977], [70.22125244, 21.00263977], [70.22125244, 21.00292015], [70.22097015, 21.00292015], [70.22097015, 21.00374985], [70.22125244, 21.00374985], [70.22125244, 21.00458336], [70.22097015, 21.00458336], [70.22097015, 21.00486183], [70.22070313, 21.00485992], [70.22070313, 21.0051403], [70.22041321, 21.0051384], [70.22041321, 21.00597191], [70.22013855, 21.00597], [70.22013855, 21.00625038], [70.21902466, 21.00625038], [70.21902466, 21.00652885], [70.21875, 21.00652122], [70.21875, 21.00681114], [70.21819305, 21.00680542], [70.21819305, 21.00708389], [70.21763611, 21.00708389], [70.21763611, 21.00680542], [70.21652985, 21.00681114], [70.21652985, 21.00736046], [70.21624756, 21.00736046], [70.21624756, 21.00764084], [70.2159729, 21.00764084], [70.2159729, 21.00792122], [70.21569824, 21.0079174], [70.21569824, 21.00819397], [70.21541595, 21.00819397], [70.21541595, 21.00847244], [70.2151413, 21.00847054], [70.2151413, 21.00875092], [70.21485901, 21.00875092], [70.21485901, 21.0090313], [70.21457672, 21.0090313], [70.21457672, 21.00931168], [70.21430206, 21.00931168], [70.21430206, 21.00985909], [70.2140274, 21.00985909], [70.2140274, 21.01013947], [70.21347046, 21.01013947], [70.21347046, 21.01042175], [70.21237183, 21.01042175], [70.21237183, 21.01013947], [70.21208191, 21.01013947], [70.21208191, 21.01042175], [70.21152496, 21.01041603], [70.21152496, 21.0106945], [70.21125031, 21.01069069], [70.21125031, 21.0118103], [70.21097565, 21.01180649], [70.21097565, 21.01236343], [70.2104187, 21.01235962], [70.2104187, 21.01264954], [70.21013641, 21.01264954], [70.21013641, 21.01235962], [70.2095871, 21.01235962], [70.2095871, 21.01264954], [70.20931244, 21.01264954], [70.20931244, 21.01292038], [70.20903015, 21.01292038], [70.20903015, 21.01320076], [70.20874786, 21.01320076], [70.20874786, 21.01403046], [70.20847321, 21.01403046], [70.20847321, 21.01431084], [70.20819092, 21.01430321], [70.20819092, 21.01486206], [70.20791626, 21.01486015], [70.20791626, 21.01514053], [70.20707703, 21.01514053], [70.20707703, 21.01542091], [70.20652771, 21.0154171], [70.20652771, 21.01569557], [70.20625305, 21.01569557], [70.20625305, 21.01597214], [70.20597076, 21.01597023], [70.20597076, 21.01625061], [70.20540619, 21.01625061], [70.20540619, 21.01653099], [70.20513916, 21.01653099], [70.20513916, 21.01680946], [70.2048645, 21.01680565], [70.2048645, 21.01708412], [70.20458221, 21.01708031], [70.20458221, 21.01764107], [70.20430756, 21.01764107], [70.20430756, 21.01791954], [70.20402527, 21.01791763], [70.20402527, 21.0181942], [70.20375061, 21.0181942], [70.20375061, 21.01847267], [70.20346832, 21.01846123], [70.20346832, 21.01875114], [70.20317841, 21.01875114], [70.20317841, 21.01902962], [70.20263672, 21.01902962], [70.20263672, 21.01930809], [70.20236206, 21.01930618], [70.20236206, 21.01958275], [70.20180511, 21.01958275], [70.20181274, 21.01986122], [70.20153046, 21.01986122], [70.20153046, 21.02013969], [70.20124817, 21.02013969], [70.20124817, 21.02041817], [70.20097351, 21.02041626], [70.20097351, 21.02069473], [70.20041656, 21.02069473], [70.20043182, 21.02124977], [70.20014191, 21.02124977], [70.20014191, 21.02152824], [70.19985962, 21.02152824], [70.19985962, 21.02180481], [70.19930267, 21.02180481], [70.19930267, 21.02208328], [70.19902802, 21.02207947], [70.19902802, 21.02263832], [70.19875336, 21.02263832], [70.19875336, 21.02292061], [70.19847107, 21.02292061], [70.19847107, 21.02319908], [70.19791412, 21.02319527], [70.19791412, 21.02347183], [70.19736481, 21.02347183], [70.19737244, 21.0237484], [70.19708252, 21.0237484], [70.19708252, 21.02403259], [70.19680786, 21.02403259], [70.19680786, 21.02431107], [70.19596863, 21.02431107], [70.19596863, 21.02514267], [70.19541931, 21.02514267], [70.19541931, 21.02542114], [70.19458008, 21.02541733], [70.19458008, 21.02569389], [70.19374847, 21.02569008], [70.19374847, 21.02625275], [70.19346619, 21.02625275], [70.19346619, 21.02736282], [70.19264221, 21.02736282], [70.19264221, 21.02765083], [70.19235992, 21.02765083], [70.19235992, 21.02791977], [70.19208527, 21.02791405], [70.19208527, 21.02819252], [70.19152832, 21.02819252], [70.19152832, 21.02847481], [70.1912384, 21.0284729], [70.1912384, 21.02874947], [70.19013977, 21.02874947], [70.19013977, 21.02902985], [70.18985748, 21.02902985], [70.18985748, 21.02931023], [70.18930817, 21.02930641], [70.18930817, 21.02958488], [70.18902588, 21.02958488], [70.18902588, 21.02986145], [70.18878174, 21.02985954], [70.18875122, 21.03013992], [70.18736267, 21.03013802], [70.18736267, 21.03069687], [70.18708038, 21.03069115], [70.18708038, 21.03153038], [70.18680573, 21.03152847], [70.18680573, 21.03208351], [70.18624878, 21.03208351], [70.18624878, 21.03180695], [70.18597412, 21.03180695], [70.18597412, 21.03208351], [70.18541718, 21.03208351], [70.18541718, 21.03236198], [70.18514252, 21.03236008], [70.18514252, 21.03264046], [70.18486023, 21.03263855], [70.18486023, 21.03319359], [70.18458557, 21.03319359], [70.18458557, 21.03347206], [70.18430328, 21.03347015], [70.18430328, 21.03375053], [70.18347168, 21.03375053], [70.18347168, 21.03403091], [70.18319702, 21.03403091], [70.18319702, 21.03430748], [70.18291473, 21.03430557], [70.18291473, 21.03458405], [70.18235779, 21.03458023], [70.18235779, 21.03486061], [70.18180847, 21.03486061], [70.18180847, 21.03513908], [70.18152618, 21.03513908], [70.18152618, 21.03541756], [70.18096924, 21.03541756], [70.18096924, 21.03569412], [70.18041992, 21.03569412], [70.18041992, 21.0359726], [70.18013763, 21.03597069], [70.18013763, 21.03624916], [70.18041992, 21.03624916], [70.18041992, 21.03681946], [70.18013763, 21.03680611], [70.18013763, 21.03708267], [70.17986298, 21.03708076], [70.17986298, 21.03735924], [70.1792984, 21.03735924], [70.1792984, 21.03764153], [70.17874908, 21.03764153], [70.17874908, 21.03792191], [70.17847443, 21.03791618], [70.17847443, 21.03847122], [70.17819214, 21.03846931], [70.17819214, 21.03874969], [70.17679596, 21.03874969], [70.17679596, 21.03903008], [70.17736053, 21.03902817], [70.17736053, 21.03930473], [70.17764282, 21.03930283], [70.17764282, 21.04014015], [70.17736053, 21.04014015], [70.17736053, 21.04042053], [70.17652893, 21.04042053], [70.17652893, 21.04070091], [70.17597198, 21.04069519], [70.17597198, 21.04097366], [70.17569733, 21.04096985], [70.17569733, 21.04125023], [70.17542267, 21.04125023], [70.17542267, 21.04153061], [70.17514038, 21.04153061], [70.17514038, 21.04181099], [70.17458344, 21.04180336], [70.17458344, 21.04208565], [70.17430878, 21.04208565], [70.17430878, 21.04263878], [70.17402649, 21.04263878], [70.17402649, 21.04347229], [70.17375183, 21.04347038], [70.17375183, 21.04375076], [70.17263794, 21.04375076], [70.17263794, 21.04403114], [70.17236328, 21.04403114], [70.17236328, 21.04486084], [70.17180634, 21.04486084], [70.17180634, 21.04514122], [70.17151642, 21.04514122], [70.17151642, 21.04541969], [70.17124939, 21.04541779], [70.17124939, 21.04569435], [70.17097473, 21.04569435], [70.17097473, 21.04597282], [70.17069244, 21.04597092], [70.17069244, 21.04624939], [70.17041779, 21.04624939], [70.17041779, 21.04652977], [70.16986084, 21.04652977], [70.16986084, 21.04680824], [70.16930389, 21.04680634], [70.16930389, 21.0470829], [70.16902924, 21.0470829], [70.16902924, 21.04736137], [70.16874695, 21.04735947], [70.16874695, 21.04763985], [70.16847229, 21.04763985], [70.16847229, 21.04791832], [70.16791534, 21.04791641], [70.16791534, 21.04847145], [70.16764069, 21.04846954], [70.16764069, 21.04875946], [70.16706848, 21.04875946], [70.16706848, 21.0490284], [70.16652679, 21.0490284], [70.16652679, 21.04931068], [70.16625214, 21.04930496], [70.16625214, 21.04958344], [70.16596985, 21.04957962], [70.16596985, 21.05013847], [70.16570282, 21.05013847], [70.16570282, 21.05042267], [70.16485596, 21.05042267], [70.16485596, 21.05013847], [70.16348267, 21.05013847], [70.16348267, 21.05042267], [70.16319275, 21.05042267], [70.16319275, 21.05125046], [70.16374969, 21.05125046], [70.16374969, 21.05153275], [70.16402435, 21.05152702], [70.16402435, 21.05208206], [70.16374969, 21.05208015], [70.16374969, 21.05236053], [70.16319275, 21.05236053], [70.16319275, 21.05264282], [70.16179657, 21.05264282], [70.16179657, 21.05291939], [70.16152954, 21.05291748], [70.16152954, 21.05319214], [70.16124725, 21.05319214], [70.16124725, 21.05347443], [70.16014099, 21.05347061], [70.16014099, 21.0537529], [70.1598587, 21.0537529], [70.1598587, 21.05430984], [70.15958405, 21.05430603], [70.15958405, 21.0545845], [70.15930939, 21.05457115], [70.15930176, 21.05486107], [70.15875244, 21.05486107], [70.15875244, 21.05513954], [70.15847015, 21.05513954], [70.15847015, 21.05541992], [70.15791321, 21.05541992], [70.15791321, 21.05624962], [70.15763855, 21.05624962], [70.15763855, 21.05653], [70.15736389, 21.05652809], [70.15736389, 21.05680656], [70.1570816, 21.05680656], [70.1570816, 21.05708313], [70.15680695, 21.05708313], [70.15680695, 21.0573616], [70.15652466, 21.0573616], [70.15652466, 21.05763817], [70.15625, 21.05763054], [70.15625, 21.05792046], [70.15598297, 21.05792046], [70.15598297, 21.05820084], [70.1554184, 21.05819511], [70.1554184, 21.05847168], [70.15512848, 21.05846977], [70.15512848, 21.05875015], [70.15486145, 21.05875015], [70.15486145, 21.05903053], [70.15458679, 21.05903053], [70.15458679, 21.05931091], [70.1543045, 21.05930519], [70.1543045, 21.05958366], [70.15402985, 21.05957985], [70.15402985, 21.06014061], [70.15374756, 21.06014061], [70.15374756, 21.06041908], [70.1534729, 21.06041908], [70.1534729, 21.06069946], [70.15319824, 21.06069946], [70.15319824, 21.06125069], [70.1526413, 21.06125069], [70.1526413, 21.06180763], [70.15208435, 21.06180573], [70.15208435, 21.0620842], [70.15125275, 21.06208038], [70.15125275, 21.06263924], [70.15097046, 21.06263924], [70.15097046, 21.06292152], [70.1506958, 21.0629158], [70.1506958, 21.06347275], [70.15013885, 21.06347084], [70.15013885, 21.06376266], [70.14985657, 21.06376266], [70.14985657, 21.06431007], [70.14958191, 21.06430626], [70.14958191, 21.06458282], [70.14930725, 21.06458282], [70.14930725, 21.06485939], [70.14902496, 21.06485939], [70.14903259, 21.06514168], [70.14875031, 21.06514168], [70.14875031, 21.06542015], [70.14847565, 21.06541634], [70.14847565, 21.06569481], [70.14819336, 21.06569481], [70.14819336, 21.06597137], [70.14763641, 21.06596947], [70.14763641, 21.06624985], [70.14736176, 21.06624985], [70.14736176, 21.06653023], [70.1470871, 21.06652832], [70.1470871, 21.06680489], [70.14680481, 21.06680489], [70.14680481, 21.06708145], [70.14653015, 21.06708145], [70.14653015, 21.06736374], [70.14430237, 21.06735992], [70.14430237, 21.0676403], [70.14402771, 21.0676403], [70.14402771, 21.06792068], [70.14347076, 21.06792068], [70.14347076, 21.06820107], [70.14319611, 21.06819534], [70.14319611, 21.06847382], [70.14289856, 21.06847], [70.14289856, 21.06875038], [70.14263916, 21.06875038], [70.14263916, 21.06903076], [70.14235687, 21.06903076], [70.14235687, 21.06931114], [70.14208221, 21.06930542], [70.14208221, 21.07069588], [70.14180756, 21.07069016], [70.14180756, 21.07263947], [70.1415329, 21.07263947], [70.1415329, 21.07292747], [70.14125061, 21.07292747], [70.14125061, 21.07374954], [70.14097595, 21.07374954], [70.14097595, 21.0743103], [70.14069366, 21.07430649], [70.14069366, 21.07458305], [70.14041901, 21.07458305], [70.14041901, 21.07486153], [70.14015198, 21.07485962], [70.14015198, 21.07513809], [70.13986206, 21.07513809], [70.13986206, 21.07541847], [70.13930511, 21.07541656], [70.13930511, 21.0759716], [70.13874817, 21.0759697], [70.13874817, 21.07652855], [70.13846588, 21.07652855], [70.13846588, 21.07681084], [70.13819122, 21.07680511], [70.13819122, 21.07736015], [70.13791656, 21.07736015], [70.13791656, 21.07792282], [70.13819122, 21.0779171], [70.13819122, 21.07819366], [70.13847351, 21.07819366], [70.13847351, 21.07875252], [70.13874817, 21.07873917], [70.13874817, 21.07930946], [70.13903046, 21.07930946], [70.13903046, 21.07986069], [70.14041901, 21.07986069], [70.14041901, 21.07958031], [70.14152527, 21.07958221], [70.1415329, 21.08024025], [70.1415329, 21.08041954], [70.1414032, 21.08041954], [70.14125061, 21.08041763], [70.14125061, 21.08069229], [70.14097595, 21.08069229], [70.14097595, 21.08097458], [70.14041901, 21.08097076], [70.14041901, 21.08125114], [70.14015198, 21.08125114], [70.14015198, 21.08152962], [70.13986206, 21.08152771], [70.13986206, 21.08180618], [70.14013672, 21.08180618], [70.14013672, 21.08208466], [70.14125061, 21.08208466], [70.14125061, 21.08180618], [70.14208221, 21.08180618], [70.14208221, 21.08152771], [70.14263916, 21.08152962], [70.14263916, 21.08125114], [70.14289856, 21.08125114], [70.14289856, 21.08097076], [70.14347076, 21.08097458], [70.14347076, 21.08069229], [70.14430237, 21.08069229], [70.14430237, 21.08041573], [70.14485931, 21.08041954], [70.14485931, 21.08014107], [70.1451416, 21.08014107], [70.1451416, 21.07986069], [70.14569092, 21.07986069], [70.14569092, 21.07958031], [70.14597321, 21.07958221], [70.14597321, 21.07930565], [70.14624786, 21.07930946], [70.14624786, 21.0790329], [70.14653015, 21.0790329], [70.14653015, 21.07873917], [70.14680481, 21.07875252], [70.14680481, 21.07847023], [70.14763641, 21.07847023], [70.14763641, 21.0790329], [70.14736176, 21.07902718], [70.14736176, 21.07958221], [70.1470871, 21.07958031], [70.1470871, 21.07986069], [70.14679718, 21.07986069], [70.14679718, 21.08014107], [70.14653015, 21.08014107], [70.14653015, 21.08041954], [70.14624786, 21.08041763], [70.14624786, 21.08069229], [70.14569092, 21.08069229], [70.14569092, 21.08097458], [70.14541626, 21.08097076], [70.14541626, 21.08125114], [70.14485931, 21.08125114], [70.14485931, 21.08152962], [70.14458466, 21.08152771], [70.14458466, 21.08180618], [70.14402771, 21.08180618], [70.14402771, 21.08208466], [70.14347076, 21.08208084], [70.14347076, 21.08236122], [70.14318848, 21.08236122], [70.14318848, 21.08263969], [70.14289856, 21.08263969], [70.14289856, 21.08292007], [70.14208221, 21.08291626], [70.14208221, 21.08319664], [70.14125061, 21.08319664], [70.14125061, 21.0834713], [70.14069366, 21.0834713], [70.14069366, 21.08430672], [70.14041901, 21.08430672], [70.14041901, 21.08458328], [70.14015198, 21.08457947], [70.14015198, 21.08486938], [70.13903046, 21.08486938], [70.13903046, 21.08514023], [70.13846588, 21.08514023], [70.13846588, 21.08542061], [70.13791656, 21.08542061], [70.13791656, 21.08570099], [70.13661194, 21.08569527], [70.13597107, 21.08570099], [70.13597107, 21.08514023], [70.13569641, 21.08514023], [70.13569641, 21.08319092], [70.13597107, 21.08319664], [70.13597107, 21.08291626], [70.13625336, 21.08292007], [70.13625336, 21.08263969], [70.13597107, 21.08263969], [70.13597107, 21.08208084], [70.13569641, 21.08208084], [70.13569641, 21.08236122], [70.13540649, 21.08236122], [70.13540649, 21.08208084], [70.13513947, 21.08208466], [70.13513947, 21.08124924], [70.13485718, 21.08125114], [70.13485718, 21.08097076], [70.13458252, 21.08097458], [70.13458252, 21.08041763], [70.13430786, 21.08041954], [70.13430786, 21.08014107], [70.1340332, 21.08014107], [70.1340332, 21.07986069], [70.13346863, 21.07986069], [70.13346863, 21.07958031], [70.13291931, 21.07958031], [70.13291931, 21.07986069], [70.13236237, 21.07986069], [70.13236237, 21.08014107], [70.13208008, 21.08013916], [70.13208008, 21.08069229], [70.13180542, 21.08069229], [70.13180542, 21.08097458], [70.13124847, 21.08097076], [70.13124847, 21.08125114], [70.13095856, 21.08125114], [70.13095856, 21.08152962], [70.13069153, 21.08152771], [70.13069153, 21.08180618], [70.13014221, 21.08180618], [70.13014221, 21.08208466], [70.12985992, 21.08208084], [70.12985992, 21.08263969], [70.12958527, 21.08263969], [70.12958527, 21.08319664], [70.12930298, 21.08319664], [70.12930298, 21.0834713], [70.12902832, 21.08346939], [70.12902832, 21.08374977], [70.12847137, 21.08374977], [70.12847137, 21.08403015], [70.12791443, 21.08402824], [70.12791443, 21.08430672], [70.12763977, 21.08430672], [70.12763977, 21.08458328], [70.12735748, 21.08457947], [70.12735748, 21.08486938], [70.12680817, 21.08486938], [70.12680817, 21.08542061], [70.12652588, 21.08541679], [70.12652588, 21.08597183], [70.12625122, 21.08596992], [70.12625122, 21.08625031], [70.12568665, 21.08625031], [70.12568665, 21.08653069], [70.12513733, 21.08652878], [70.12515259, 21.08736038], [70.12346649, 21.08736038], [70.12346649, 21.08764076], [70.12319183, 21.08764076], [70.12319183, 21.08793068], [70.12291718, 21.08791733], [70.12291718, 21.08819389], [70.12236023, 21.08819389], [70.12236023, 21.08847237], [70.12208557, 21.08847237], [70.1220932, 21.08875084], [70.12180328, 21.08875084], [70.12180328, 21.08902931], [70.12152863, 21.08902931], [70.12152863, 21.0893116], [70.12124634, 21.0893116], [70.12124634, 21.08986092], [70.12097168, 21.08986092], [70.12097168, 21.09013939], [70.12041473, 21.09013939], [70.12041473, 21.09069443], [70.12014008, 21.09069443], [70.12014008, 21.0909729], [70.11985779, 21.09096909], [70.11985779, 21.09124947], [70.11930847, 21.09124947], [70.11930847, 21.09153175], [70.11901855, 21.09153175], [70.11901855, 21.09181023], [70.11819458, 21.09180641], [70.11819458, 21.09208107], [70.11791992, 21.09208107], [70.11791992, 21.09236336], [70.11763763, 21.09235954], [70.11763763, 21.09264183], [70.11736298, 21.09264183], [70.11736298, 21.0929203], [70.11708069, 21.0929203], [70.11708069, 21.09320068], [70.11653137, 21.09319305], [70.11653137, 21.09347153], [70.11597443, 21.09347153], [70.11597443, 21.09375191], [70.11541748, 21.09374046], [70.11541748, 21.09403038], [70.11513519, 21.09402847], [70.11513519, 21.0945816], [70.11486053, 21.0945816], [70.11486053, 21.09486389], [70.11458588, 21.09486008], [70.11458588, 21.09514046], [70.11429596, 21.09514046], [70.11429596, 21.09542084], [70.11402893, 21.09541702], [70.11402893, 21.0956955], [70.11347198, 21.09568977], [70.11347198, 21.09625053], [70.11321259, 21.09625053], [70.11321259, 21.09653091], [70.11292267, 21.09653091], [70.11292267, 21.09680939], [70.11235809, 21.09680557], [70.11235809, 21.09708595], [70.11207581, 21.09708023], [70.11207581, 21.09736061], [70.11180878, 21.09736061], [70.11180878, 21.09764099], [70.11125183, 21.09764099], [70.11125183, 21.09791946], [70.11096954, 21.09791756], [70.11096954, 21.0984726], [70.11042023, 21.09847069], [70.11042023, 21.09875107], [70.11013794, 21.09875107], [70.11013794, 21.09930992], [70.10986328, 21.09930611], [70.10986328, 21.09958267], [70.10958099, 21.09958076], [70.10958099, 21.09987068], [70.10930634, 21.09987068], [70.10930634, 21.10013962], [70.10901642, 21.10013962], [70.10901642, 21.10041809], [70.10874939, 21.10041809], [70.10874939, 21.10124969], [70.1076355, 21.10124969], [70.1076355, 21.10180473], [70.10736084, 21.10180473], [70.10736084, 21.10208321], [70.10708618, 21.10208321], [70.10708618, 21.10236168], [70.10652924, 21.10235977], [70.10652924, 21.10263824], [70.10569763, 21.10263824], [70.10569763, 21.1043129], [70.10541534, 21.10430527], [70.10542297, 21.10486031], [70.10514069, 21.10486031], [70.10514069, 21.10542107], [70.1048584, 21.10541725], [70.1048584, 21.10569382], [70.10263824, 21.10569382], [70.10263824, 21.10541725], [70.10124969, 21.10542107], [70.10124969, 21.10514259], [70.10041809, 21.10514259], [70.10041809, 21.10458183], [70.09958649, 21.10458183], [70.09958649, 21.10486031], [70.09929657, 21.10486031], [70.09929657, 21.10514259], [70.09902954, 21.10514259], [70.09902954, 21.10542107], [70.09874725, 21.10541725], [70.09874725, 21.10569382], [70.0984726, 21.10568047], [70.0984726, 21.10625267], [70.09819794, 21.10625267], [70.09819794, 21.10708237], [70.09792328, 21.10708046], [70.09792328, 21.10764122], [70.09764099, 21.10764122], [70.09764099, 21.10791969], [70.0973587, 21.10791588], [70.0973587, 21.10819244], [70.09708405, 21.10819244], [70.09708405, 21.10847473], [70.0965271, 21.10847092], [70.0965271, 21.10874939], [70.09597015, 21.10874939], [70.09597015, 21.10902977], [70.09570312, 21.10902977], [70.09570312, 21.10931015], [70.09541321, 21.10930634], [70.09541321, 21.10958481], [70.09513855, 21.10958099], [70.09513855, 21.11042023], [70.09486389, 21.11041641], [70.09486389, 21.11069679], [70.0945816, 21.11069679], [70.0945816, 21.11097145], [70.09401703, 21.11096954], [70.09401703, 21.11124992], [70.09375, 21.11124992], [70.09375, 21.11181068], [70.09347534, 21.11180687], [70.09347534, 21.11208344], [70.09319305, 21.11208344], [70.09319305, 21.11236191], [70.09263611, 21.11236], [70.09263611, 21.11264038], [70.09236145, 21.11263847], [70.09236145, 21.1131897], [70.0918045, 21.11319542], [70.0918045, 21.11347198], [70.09152985, 21.11347008], [70.09152985, 21.11403084], [70.09124756, 21.11403084], [70.09124756, 21.11431122], [70.0909729, 21.1143055], [70.0909729, 21.11458397], [70.09069824, 21.11458397], [70.09069824, 21.11486053], [70.09041595, 21.114851], [70.09041595, 21.11514091], [70.08985901, 21.11514091], [70.08985901, 21.11541748], [70.08958435, 21.11541748], [70.08958435, 21.11569405], [70.08930206, 21.11569405], [70.08930206, 21.11597252], [70.08904266, 21.11597061], [70.08904266, 21.11624908], [70.08875275, 21.11624908], [70.08875275, 21.11653137], [70.08847046, 21.11653137], [70.08847046, 21.11681175], [70.0881958, 21.11680603], [70.0881958, 21.1170826], [70.08790588, 21.11708069], [70.08790588, 21.11735916], [70.08763885, 21.11735916], [70.08763885, 21.11763954], [70.0873642, 21.11763954], [70.0873642, 21.11791611], [70.08680725, 21.11791611], [70.08680725, 21.11819458], [70.08652496, 21.11819458], [70.08652496, 21.11791611], [70.08625031, 21.11790848], [70.08625031, 21.11874962], [70.08598328, 21.11874962], [70.08598328, 21.11903191], [70.08569336, 21.11902809], [70.08569336, 21.11958122], [70.0854187, 21.11958122], [70.0854187, 21.11986351], [70.0845871, 21.1198597], [70.0845871, 21.12014008], [70.08429718, 21.12014008], [70.08429718, 21.12042046], [70.08403015, 21.12042046], [70.08403015, 21.12070084], [70.08374786, 21.12069321], [70.08374786, 21.12097359], [70.08347321, 21.12096977], [70.08347321, 21.12125015], [70.08290863, 21.12125015], [70.08290863, 21.12153053], [70.0826416, 21.12153053], [70.0826416, 21.12181091], [70.08208466, 21.12180328], [70.08208466, 21.12208557], [70.08152771, 21.12207985], [70.08152771, 21.12292099], [70.08097076, 21.12291718], [70.08097076, 21.12319565], [70.08069611, 21.12319565], [70.08069611, 21.12347221], [70.08040619, 21.12347031], [70.08040619, 21.12375069], [70.08013916, 21.12375069], [70.08013916, 21.1240406], [70.07984924, 21.1240406], [70.07984924, 21.12430954], [70.07930756, 21.12430573], [70.07930756, 21.1245842], [70.07902527, 21.1245842], [70.0790329, 21.12486076], [70.07875061, 21.12486076], [70.07875061, 21.12514114], [70.07847595, 21.12514114], [70.07847595, 21.12541962], [70.07819366, 21.12541771], [70.07819366, 21.12569427], [70.07791901, 21.12569046], [70.07791901, 21.12625122], [70.07763672, 21.12625122], [70.07763672, 21.12652969], [70.07736206, 21.12652969], [70.07736206, 21.12680817], [70.07707977, 21.12680626], [70.07707977, 21.12708282], [70.07680511, 21.12708282], [70.07680511, 21.1273613], [70.07653046, 21.12735939], [70.07653046, 21.12763977], [70.07624817, 21.12763977], [70.07624817, 21.12791824], [70.07597351, 21.12791634], [70.07597351, 21.12819481], [70.07569122, 21.12819481], [70.07569122, 21.12847137], [70.07541656, 21.12846947], [70.07541656, 21.12902832], [70.07514191, 21.12902832], [70.07514191, 21.12930489], [70.07458496, 21.12930489], [70.07458496, 21.12958336], [70.07430267, 21.12958336], [70.07430267, 21.12986183], [70.07375336, 21.12985039], [70.07375336, 21.13042068], [70.07347107, 21.13041687], [70.07347107, 21.13097191], [70.07290649, 21.13097191], [70.07290649, 21.13125038], [70.07208252, 21.13125038], [70.07208252, 21.13153267], [70.07180786, 21.13153267], [70.07180786, 21.13181114], [70.07152557, 21.13180542], [70.07152557, 21.13208389], [70.07125092, 21.13208008], [70.07125092, 21.13236046], [70.07096863, 21.13236046], [70.07096863, 21.13264275], [70.07069397, 21.13263893], [70.07069397, 21.13319206], [70.07041931, 21.13319016], [70.07041931, 21.13375282], [70.07013702, 21.13375282], [70.07013702, 21.13513947], [70.06958008, 21.13513947], [70.06958008, 21.13541985], [70.06931305, 21.13541985], [70.06931305, 21.13598061], [70.06874847, 21.13598061], [70.06874847, 21.13764], [70.06790924, 21.13764], [70.06790924, 21.13792038], [70.06764221, 21.13791656], [70.06764221, 21.1384716], [70.06735992, 21.1384697], [70.06735992, 21.13875008], [70.06652832, 21.13875008], [70.06652832, 21.13903809], [70.06513977, 21.13903809], [70.06513977, 21.13931084], [70.06485748, 21.13930511], [70.06485748, 21.13958359], [70.06375122, 21.13958359], [70.06375122, 21.13986206], [70.06346893, 21.13986015], [70.06346893, 21.14042091], [70.06319427, 21.1404171], [70.06319427, 21.14097214], [70.06291962, 21.14097023], [70.06291962, 21.14125061], [70.06263733, 21.14125061], [70.06263733, 21.14152908], [70.06236267, 21.14152908], [70.06236267, 21.14180756], [70.06180573, 21.14180565], [70.06180573, 21.14208412], [70.06096649, 21.14208031], [70.06096649, 21.14236069], [70.06041718, 21.14236069], [70.06041718, 21.14292145], [70.06014252, 21.14291763], [70.06014252, 21.14347267], [70.05986023, 21.14347076], [70.05986023, 21.14374924], [70.0595932, 21.14374924], [70.0595932, 21.14403152], [70.05902863, 21.14403152], [70.05902863, 21.1443119], [70.05874634, 21.14430618], [70.05874634, 21.14458275], [70.05847168, 21.14458084], [70.05847168, 21.14485931], [70.05819702, 21.14485931], [70.05819702, 21.14513969], [70.05791473, 21.14513969], [70.05791473, 21.14569473], [70.05735779, 21.14569473], [70.05735779, 21.1459713], [70.05708313, 21.14596939], [70.05708313, 21.14624977], [70.05680847, 21.14624977], [70.05680847, 21.14653015], [70.05652618, 21.14652824], [70.05652618, 21.14708138], [70.05625153, 21.14708138], [70.05625153, 21.14847374], [70.05596924, 21.14846992], [70.05596924, 21.14875031], [70.05458069, 21.14875031], [70.05458069, 21.14903069], [70.05430603, 21.14903069], [70.05430603, 21.14931107], [70.05458069, 21.14930344], [70.05458069, 21.14958572], [70.05430603, 21.14958], [70.05430603, 21.14986038], [70.05403137, 21.14986038], [70.05403137, 21.15014076], [70.05347443, 21.15013885], [70.05347443, 21.1506958], [70.05319214, 21.15069008], [70.05319214, 21.15125084], [70.05293274, 21.15125084], [70.05293274, 21.15153122], [70.05236053, 21.1515274], [70.05236053, 21.15208244], [70.05208588, 21.15208054], [70.05208588, 21.15236092], [70.05179596, 21.15236092], [70.05179596, 21.15263939], [70.05069733, 21.15263939], [70.05069733, 21.15291977], [70.05041504, 21.15291786], [70.05041504, 21.15319443], [70.05014038, 21.15319443], [70.05014038, 21.1534729], [70.04985809, 21.1534729], [70.04987335, 21.15374947], [70.04958344, 21.15374947], [70.04958344, 21.15402794], [70.04930878, 21.15402794], [70.04930878, 21.15458298], [70.04902649, 21.15458107], [70.04902649, 21.1554184], [70.04875183, 21.1554184], [70.04875183, 21.15570068], [70.04819489, 21.15569496], [70.04819489, 21.15597153], [70.04763794, 21.15596962], [70.04763794, 21.15624809], [70.04679871, 21.15624809], [70.04679871, 21.15652847], [70.04652405, 21.15652847], [70.04652405, 21.15847015], [70.04624939, 21.15847015], [70.04624939, 21.15903282], [70.04569244, 21.15903282], [70.04569244, 21.15930939], [70.04541779, 21.15930557], [70.04541779, 21.15958214], [70.04514313, 21.15958023], [70.04514313, 21.16015053], [70.04486084, 21.16013908], [70.04486084, 21.16069221], [70.04458618, 21.16069221], [70.04458618, 21.1609745], [70.04429626, 21.16097069], [70.04429626, 21.16125107], [70.04373932, 21.16125107], [70.04373932, 21.16152954], [70.04347229, 21.16152954], [70.04347229, 21.16180992], [70.04291534, 21.16180611], [70.04291534, 21.16208458], [70.04264069, 21.16208076], [70.04264069, 21.16236115], [70.0423584, 21.16236115], [70.0423584, 21.16263962], [70.04207611, 21.16263962], [70.04207611, 21.16292], [70.04180908, 21.16292], [70.04180908, 21.16374969], [70.04152679, 21.16374969], [70.04152679, 21.16403008], [70.04125214, 21.16402817], [70.04125214, 21.16430664], [70.04096985, 21.16430664], [70.04096985, 21.16458321], [70.04070282, 21.16457939], [70.04070282, 21.16514015], [70.0404129, 21.16514015], [70.0404129, 21.16542053], [70.04013824, 21.16542053], [70.04013824, 21.16570091], [70.03986359, 21.16569519], [70.03986359, 21.16597176], [70.0395813, 21.16596031], [70.0395813, 21.16653061], [70.03930664, 21.16653061], [70.03930664, 21.16681099], [70.03902435, 21.16680527], [70.03902435, 21.16708374], [70.03874969, 21.16707993], [70.03874969, 21.16736031], [70.03848267, 21.16736031], [70.03848267, 21.16764069], [70.03819275, 21.16764069], [70.03819275, 21.16791916], [70.03791809, 21.16791725], [70.03791809, 21.16819382], [70.0376358, 21.16819382], [70.0376358, 21.16847229], [70.03736115, 21.16847038], [70.03736115, 21.16875076], [70.03708649, 21.16875076], [70.03708649, 21.16931152], [70.0368042, 21.1693058], [70.0368042, 21.16958427], [70.03624725, 21.16958046], [70.03624725, 21.17013931], [70.0359726, 21.17013931], [70.0359726, 21.17069435], [70.03569794, 21.17069435], [70.03569794, 21.17097282], [70.03541565, 21.17097282], [70.03542328, 21.17124939], [70.03514099, 21.17124939], [70.03514099, 21.17153168], [70.0348587, 21.17153168], [70.0348587, 21.17209053], [70.03458405, 21.1720829], [70.03458405, 21.17236137], [70.03430939, 21.17235947], [70.03430176, 21.17264175], [70.0340271, 21.17264175], [70.0340271, 21.17292023], [70.03375244, 21.17291641], [70.03375244, 21.17319489], [70.03347015, 21.17319489], [70.03347015, 21.17347145], [70.03320313, 21.17346954], [70.03320313, 21.1740303], [70.0320816, 21.1740284], [70.0320816, 21.17458153], [70.03179932, 21.17457962], [70.03179932, 21.17514992], [70.0320816, 21.17513847], [70.0320816, 21.17569542], [70.03236389, 21.17569542], [70.03236389, 21.17597389], [70.03263855, 21.17597008], [70.03263855, 21.17625046], [70.03291321, 21.17625046], [70.03291321, 21.17653084], [70.0331955, 21.17652512], [70.0331955, 21.17708588], [70.03347015, 21.17708015], [70.03347015, 21.17764091], [70.03375244, 21.17763901], [70.03375244, 21.17819595], [70.0340271, 21.17819595], [70.0340271, 21.17847252], [70.0348587, 21.17847061], [70.0348587, 21.17875099], [70.03514099, 21.17875099], [70.03514099, 21.17902946], [70.03542328, 21.17902946], [70.03542328, 21.17930984], [70.03569794, 21.17930984], [70.03569794, 21.17986107], [70.0359726, 21.17986107], [70.0359726, 21.18013954], [70.03624725, 21.18013954], [70.03624725, 21.18041992], [70.03652954, 21.18041611], [70.03652954, 21.18069458], [70.0368042, 21.18069458], [70.0368042, 21.18097305], [70.03708649, 21.1809597], [70.03708649, 21.18124962], [70.03736115, 21.18124962], [70.03736115, 21.18152809], [70.0376358, 21.18152809], [70.0376358, 21.18208313], [70.03793335, 21.18208122], [70.03793335, 21.18263817], [70.03819275, 21.18263817], [70.03819275, 21.18347168], [70.03791809, 21.18347168], [70.03791809, 21.18319511], [70.0376358, 21.18320084], [70.0376358, 21.18291855], [70.03708649, 21.18291855], [70.03708649, 21.18263817], [70.03679657, 21.18263817], [70.03679657, 21.1823597], [70.03652954, 21.1823616], [70.03652954, 21.18208313], [70.03624725, 21.18208313], [70.03624725, 21.18180466], [70.0359726, 21.18180466], [70.0359726, 21.18152809], [70.03569794, 21.18152809], [70.03569794, 21.1809597], [70.03541565, 21.18097305], [70.03541565, 21.18069458], [70.03514099, 21.18069458], [70.03514099, 21.18041611], [70.0348587, 21.18041992], [70.0348587, 21.18013954], [70.03347015, 21.18013954], [70.03347015, 21.17986107], [70.0331955, 21.17986107], [70.0331955, 21.17902756], [70.03263855, 21.17902946], [70.03263855, 21.17875099], [70.0320816, 21.17875099], [70.0320816, 21.17847061], [70.02929688, 21.17847061], [70.02929688, 21.17875099], [70.0284729, 21.17875099], [70.0284729, 21.17930984], [70.02819824, 21.17930794], [70.02819824, 21.1795826], [70.02791595, 21.17958069], [70.02791595, 21.17986107], [70.0276413, 21.17986107], [70.0276413, 21.18013954], [70.02735901, 21.18013954], [70.02735901, 21.18041992], [70.02708435, 21.18041611], [70.02708435, 21.18069458], [70.0265274, 21.18069458], [70.0265274, 21.18097305], [70.0256958, 21.1809597], [70.0256958, 21.18124962], [70.02540588, 21.18124962], [70.02540588, 21.18152809], [70.02513885, 21.18152809], [70.02513885, 21.18180466], [70.0248642, 21.18180466], [70.0248642, 21.18208313], [70.02458191, 21.18208313], [70.02458191, 21.1823616], [70.02430725, 21.1823597], [70.02430725, 21.18291855], [70.02375031, 21.18291855], [70.02375031, 21.18320084], [70.02319336, 21.18320084], [70.02319336, 21.18374825], [70.0229187, 21.18374825], [70.0229187, 21.18403244], [70.0220871, 21.18402863], [70.0220871, 21.18458366], [70.02179718, 21.18458176], [70.02179718, 21.18514252], [70.02153015, 21.1851387], [70.02153015, 21.18569374], [70.02097321, 21.18569374], [70.02097321, 21.18597031], [70.02041626, 21.18597031], [70.02041626, 21.18625259], [70.0201416, 21.18625259], [70.0201416, 21.18653107], [70.01985931, 21.18653107], [70.01985931, 21.18708992], [70.0195694, 21.18708992], [70.0195694, 21.18736076], [70.01930237, 21.18736076], [70.01930237, 21.18764114], [70.01902771, 21.18764114], [70.01902771, 21.18791962], [70.01875305, 21.1879158], [70.01875305, 21.18819237], [70.01847076, 21.18819237], [70.01847076, 21.18847466], [70.01790619, 21.18847084], [70.01790619, 21.18902969], [70.01763916, 21.18902779], [70.01763916, 21.18958473], [70.01708221, 21.18958473], [70.01708221, 21.1898613], [70.01680756, 21.1898613], [70.01680756, 21.19013977], [70.01652527, 21.19013977], [70.01652527, 21.19069672], [70.01625061, 21.19069099], [70.01625061, 21.19124985], [70.01597595, 21.19124985], [70.01597595, 21.19153023], [70.01569366, 21.19152832], [70.01569366, 21.19180679], [70.01457977, 21.19180679], [70.01457977, 21.19208336], [70.01374817, 21.19208336], [70.01374817, 21.19236183], [70.01346588, 21.19235992], [70.01346588, 21.1926403], [70.01291656, 21.1926403], [70.01291656, 21.19292068], [70.01264191, 21.19292068], [70.01264191, 21.19431114], [70.01235962, 21.19430542], [70.01235962, 21.19458389], [70.01152802, 21.19458008], [70.01152802, 21.19486046], [70.01125336, 21.19486046], [70.01125336, 21.19514084], [70.01069641, 21.19514084], [70.01069641, 21.19542122], [70.01013947, 21.1954174], [70.01013947, 21.19569397], [70.00986481, 21.19569397], [70.00986481, 21.19597244], [70.00930786, 21.19597054], [70.00930786, 21.19626236], [70.0090332, 21.19626236], [70.0090332, 21.19652939], [70.00875092, 21.19652748], [70.00875092, 21.19708252], [70.00846863, 21.19708061], [70.00846863, 21.19763947], [70.00791931, 21.19763947], [70.00791931, 21.19792175], [70.00763702, 21.19791603], [70.00763702, 21.1981945], [70.00736237, 21.1981945], [70.00736237, 21.19847107], [70.00708008, 21.19846916], [70.00708008, 21.19874954], [70.00681305, 21.19874954], [70.00681305, 21.19931984], [70.00653076, 21.19930649], [70.00653076, 21.19986343], [70.00624847, 21.19985962], [70.00624847, 21.20014191], [70.00596619, 21.20014191], [70.00596619, 21.20070076], [70.00569153, 21.20070076], [70.00569153, 21.20125008], [70.00541687, 21.20125008], [70.00541687, 21.20181084], [70.00514221, 21.20180321], [70.00514221, 21.20208549], [70.00485992, 21.20208549], [70.00485992, 21.20236206], [70.00430298, 21.20236015], [70.00430298, 21.20264053], [70.00374603, 21.20264053], [70.00374603, 21.20292091], [70.00319672, 21.2029171], [70.00319672, 21.20319557], [70.0029068, 21.20318985], [70.0029068, 21.20375061], [70.00263977, 21.20375061], [70.00263977, 21.20403099], [70.00208282, 21.20403099], [70.00208282, 21.20430946], [70.00180817, 21.20430565], [70.00180817, 21.20458412], [70.00152588, 21.20458031], [70.00152588, 21.20486069], [70.00096893, 21.20486069], [70.00096893, 21.20513916], [70.00068665, 21.20512962], [70.00068665, 21.20541954], [70.00041962, 21.20541763], [70.00041962, 21.2056942], [70.00013733, 21.20569038], [70.00013733, 21.20625114], [69.99958038, 21.20625114], [69.99958038, 21.20680809], [69.99930573, 21.20680618], [69.99930573, 21.20708275], [69.99903107, 21.20708084], [69.99903107, 21.20736122], [69.99884796, 21.20736122], [69.99846649, 21.20736122], [69.99846649, 21.20791817], [69.99819183, 21.20791626], [69.99819183, 21.2084713], [69.99791718, 21.20846939], [69.99791718, 21.20874977], [69.99764252, 21.20874977], [69.99764252, 21.20902824], [69.99736023, 21.20902824], [69.99736023, 21.20930481], [69.99708557, 21.20930481], [69.99708557, 21.20958328], [69.99680328, 21.20957756], [69.99680328, 21.21013832], [69.99652863, 21.21013832], [69.99652863, 21.2104187], [69.99624634, 21.2104187], [69.99624634, 21.2107029], [69.99597168, 21.21069527], [69.99597168, 21.21097183], [69.99568939, 21.21097183], [69.99568939, 21.21125984], [69.99539948, 21.21125984], [69.99539948, 21.21153259], [69.99514008, 21.21153259], [69.99514008, 21.21181107], [69.99485779, 21.21181107], [69.99485779, 21.21236038], [69.99458313, 21.21236038], [69.99458313, 21.21264267], [69.99430847, 21.21264267], [69.99430847, 21.21292114], [69.99402618, 21.21291733], [69.99402618, 21.21319389], [69.99375153, 21.21319389], [69.99375153, 21.21347046], [69.99346924, 21.21347046], [69.99346924, 21.21375275], [69.99318695, 21.21375275], [69.99318695, 21.21403122], [69.99291992, 21.21403122], [69.99291992, 21.21432114], [69.99263763, 21.21430588], [69.99263763, 21.21458244], [69.99236298, 21.21458054], [69.99236298, 21.21486282], [69.99208069, 21.21486282], [69.99208069, 21.21513939], [69.99153137, 21.21513939], [69.99153137, 21.21541977], [69.99124908, 21.21541405], [69.99124908, 21.21569252], [69.99069214, 21.21569252], [69.99069214, 21.21597481], [69.99041748, 21.21597099], [69.99041748, 21.21652985], [69.99014282, 21.21652985], [69.99014282, 21.21763992], [69.98986053, 21.21763992], [69.98986053, 21.2179203], [69.98958588, 21.2179203], [69.98958588, 21.21820068], [69.98930359, 21.21819687], [69.98930359, 21.21847153], [69.98902893, 21.21846962], [69.98902893, 21.21875], [69.98874664, 21.21875], [69.98874664, 21.21931076], [69.98847198, 21.21930695], [69.98847198, 21.21958351], [69.98819733, 21.21958351], [69.98819733, 21.21986198], [69.98792267, 21.21986008], [69.98792267, 21.22014046], [69.98764038, 21.22014046], [69.98764038, 21.22042084], [69.98735809, 21.22041893], [69.98735809, 21.22069359], [69.98708344, 21.22069359], [69.98708344, 21.22097206], [69.98680878, 21.22097206], [69.98681641, 21.22125053], [69.98652649, 21.22125053], [69.98652649, 21.22153091], [69.98625183, 21.2215271], [69.98625183, 21.22208405], [69.98596954, 21.22208023], [69.98596954, 21.22236061], [69.98568726, 21.22236061], [69.98568726, 21.22263908], [69.98542023, 21.22263908], [69.98542023, 21.22292137], [69.98513794, 21.22292137], [69.98513794, 21.22320175], [69.98486328, 21.22319412], [69.98486328, 21.2234726], [69.98458099, 21.22347069], [69.98458099, 21.22374916], [69.98430634, 21.22374916], [69.98430634, 21.22431183], [69.98402405, 21.22430611], [69.98402405, 21.22458267], [69.98374939, 21.22458076], [69.98374939, 21.22485924], [69.98345947, 21.22485924], [69.98345947, 21.22513962], [69.98319244, 21.22513962], [69.98319244, 21.22542191], [69.98291779, 21.22541618], [69.98291779, 21.22569466], [69.9826355, 21.22569466], [69.9826355, 21.22624969], [69.98236084, 21.22624016], [69.98236084, 21.22653008], [69.98208618, 21.22652817], [69.98208618, 21.22680473], [69.98180389, 21.22680473], [69.98180389, 21.2270813], [69.98152924, 21.2270813], [69.98152924, 21.22736359], [69.98097229, 21.22735977], [69.98097229, 21.22764015], [69.98069, 21.22764015], [69.98069, 21.22792053], [69.98041534, 21.22791672], [69.98041534, 21.22847366], [69.98014069, 21.22846985], [69.98014069, 21.22875023], [69.9798584, 21.22875023], [69.9798584, 21.22903061], [69.97958374, 21.2290287], [69.97958374, 21.22930336], [69.97930908, 21.22930336], [69.97930908, 21.22958565], [69.97902679, 21.22957993], [69.97902679, 21.22986031], [69.97875214, 21.22986031], [69.97875214, 21.23042107], [69.97846985, 21.23041725], [69.97846985, 21.23069572], [69.97819519, 21.23069572], [69.97819519, 21.23097229], [69.9779129, 21.23097038], [69.9779129, 21.23125076], [69.97764587, 21.23125076], [69.97764587, 21.23153114], [69.97735596, 21.23153114], [69.97735596, 21.23180962], [69.9770813, 21.23180771], [69.9770813, 21.23208427], [69.97680664, 21.23208046], [69.97680664, 21.23236084], [69.97651672, 21.23236084], [69.97651672, 21.23264122], [69.97624969, 21.23264122], [69.97624969, 21.23291969], [69.97597504, 21.23291779], [69.97597504, 21.23319435], [69.97569275, 21.23319054], [69.97569275, 21.23374939], [69.97541809, 21.23374939], [69.97541809, 21.23402977], [69.9751358, 21.23402977], [69.9751358, 21.23430824], [69.97486115, 21.23430634], [69.97486115, 21.2345829], [69.97458649, 21.2345829], [69.97458649, 21.23486137], [69.97429657, 21.23485947], [69.97429657, 21.23513985], [69.97402954, 21.23513985], [69.97402954, 21.23543167], [69.97374725, 21.23541641], [69.97374725, 21.23569489], [69.9734726, 21.23569489], [69.9734726, 21.23597145], [69.97319794, 21.23596954], [69.97319794, 21.23624992], [69.97292328, 21.23624992], [69.97292328, 21.2365284], [69.97264099, 21.2365284], [69.97264099, 21.23681068], [69.9723587, 21.23680496], [69.9723587, 21.23708344], [69.97207642, 21.23707962], [69.97207642, 21.23764038], [69.97180939, 21.23763847], [69.97180176, 21.23817825], [69.97125244, 21.23819542], [69.97125244, 21.23847008], [69.97097015, 21.23847008], [69.97097015, 21.23875046], [69.97070313, 21.23875046], [69.97070313, 21.23903275], [69.97041321, 21.23903275], [69.97041321, 21.23931122], [69.97013855, 21.2393055], [69.97013855, 21.23958206], [69.96985626, 21.23958015], [69.96985626, 21.23986053], [69.9695816, 21.23986053], [69.9695816, 21.24014282], [69.96930695, 21.24014282], [69.96930695, 21.24041939], [69.96902466, 21.24041748], [69.96902466, 21.24069214], [69.96875, 21.24069214], [69.96875, 21.24097443], [69.96847534, 21.24097443], [69.96847534, 21.24124908], [69.96819305, 21.24123955], [69.96819305, 21.24152946], [69.9679184, 21.24152946], [69.9679184, 21.24180984], [69.96763611, 21.24180984], [69.96763611, 21.24236107], [69.96736145, 21.24236107], [69.96736145, 21.24263954], [69.96708679, 21.24263954], [69.96708679, 21.24291992], [69.9668045, 21.2429142], [69.9668045, 21.24319267], [69.96652985, 21.24319267], [69.96652985, 21.24347305], [69.96624756, 21.24347115], [69.96624756, 21.24374962], [69.9659729, 21.24374962], [69.9659729, 21.24403], [69.96569824, 21.24402809], [69.96569824, 21.24430656], [69.96541595, 21.24430656], [69.96541595, 21.2448616], [69.9651413, 21.2448597], [69.9651413, 21.24514008], [69.96485901, 21.24514008], [69.96485901, 21.24542046], [69.96457672, 21.24542046], [69.96457672, 21.24570084], [69.96430206, 21.24569511], [69.96430206, 21.24597168], [69.9640274, 21.24596977], [69.9640274, 21.24625015], [69.96375275, 21.24625015], [69.96375275, 21.24653053], [69.96347046, 21.24653053], [69.96347046, 21.24681091], [69.9631958, 21.24680519], [69.9631958, 21.24708366], [69.96290588, 21.24707985], [69.96290588, 21.24736977], [69.96264648, 21.24736977], [69.96264648, 21.24764061], [69.9623642, 21.2476387], [69.9623642, 21.24819374], [69.96208191, 21.24819374], [69.96208191, 21.24847221], [69.96180725, 21.24847031], [69.96180725, 21.24875069], [69.96153259, 21.24875069], [69.96153259, 21.24902916], [69.96125031, 21.24902916], [69.96125031, 21.24931145], [69.96097565, 21.24930573], [69.96097565, 21.2495842], [69.96069336, 21.24958038], [69.96069336, 21.24986076], [69.9604187, 21.24986076], [69.9604187, 21.25043106], [69.96013641, 21.2504158], [69.96013641, 21.25069427], [69.95986176, 21.25069427], [69.95986176, 21.25097275], [69.95957947, 21.25097084], [69.95957947, 21.25124931], [69.95929718, 21.25124931], [69.95929718, 21.2515316], [69.95903015, 21.2515316], [69.95903015, 21.25181007], [69.95874786, 21.25180626], [69.95874786, 21.25208282], [69.95847321, 21.25208282], [69.95847321, 21.2523613], [69.95819092, 21.25235939], [69.95819092, 21.25292015], [69.95791626, 21.25291634], [69.95791626, 21.25319481], [69.9576416, 21.25319481], [69.9576416, 21.25347137], [69.95735931, 21.25346947], [69.95735931, 21.25374985], [69.95707703, 21.25374985], [69.95707703, 21.25403023], [69.95680237, 21.25402832], [69.95680237, 21.25430489], [69.95652771, 21.25430489], [69.95652771, 21.25486374], [69.95625305, 21.25485992], [69.95625305, 21.2551403], [69.95597076, 21.2551403], [69.95597076, 21.25542068], [69.95569611, 21.25542068], [69.95569611, 21.25570107], [69.95541382, 21.25569534], [69.95541382, 21.25597382], [69.95513916, 21.25597], [69.95513916, 21.25653076], [69.95485687, 21.25653076], [69.95485687, 21.25681114], [69.95458221, 21.25680351], [69.95458221, 21.2570858], [69.95430756, 21.25708008], [69.95430756, 21.25736046], [69.9540329, 21.25736046], [69.9540329, 21.25764084], [69.95375061, 21.25763893], [69.95375061, 21.25819588], [69.95347595, 21.25819588], [69.95347595, 21.25847244], [69.95318604, 21.25847054], [69.95318604, 21.25875092], [69.95291901, 21.25875092], [69.95291901, 21.25902939], [69.95263672, 21.25902748], [69.95263672, 21.25958252], [69.95236206, 21.25958061], [69.95236206, 21.25986099], [69.95207977, 21.25986099], [69.95207977, 21.26013947], [69.95181274, 21.26013947], [69.95181274, 21.26041985], [69.95153046, 21.26041794], [69.95153046, 21.2606945], [69.95124817, 21.26069069], [69.95124817, 21.26124954], [69.95096588, 21.26124954], [69.95096588, 21.26152992], [69.95069122, 21.26152992], [69.95069122, 21.2618084], [69.95041656, 21.26180649], [69.95041656, 21.26208305], [69.95014191, 21.26208115], [69.95014191, 21.26236916], [69.94985962, 21.26236916], [69.94985962, 21.26291847], [69.94959259, 21.26291847], [69.94959259, 21.26320076], [69.94930267, 21.26319504], [69.94930267, 21.2634716], [69.94902802, 21.2634697], [69.94902802, 21.26374817], [69.94875336, 21.26374817], [69.94875336, 21.26402855], [69.94847107, 21.26402855], [69.94847107, 21.26458359], [69.94819641, 21.26458359], [69.94819641, 21.26486015], [69.94790649, 21.26486015], [69.94790649, 21.26514244], [69.94763947, 21.26513863], [69.94763947, 21.2654171], [69.94736481, 21.2654171], [69.94736481, 21.26569366], [69.94708252, 21.26569366], [69.94708252, 21.26597023], [69.94680786, 21.26597023], [69.94680786, 21.2665329], [69.9465332, 21.2665329], [69.9465332, 21.26680946], [69.94625092, 21.26680565], [69.94625092, 21.26708221], [69.94596863, 21.26708031], [69.94596863, 21.26736069], [69.94568634, 21.26736069], [69.94568634, 21.26764107], [69.94541931, 21.26764107], [69.94541931, 21.26791954], [69.94513702, 21.26791763], [69.94513702, 21.26847458], [69.94486237, 21.26847076], [69.94486237, 21.26875114], [69.94458008, 21.26875114], [69.94458008, 21.26902962], [69.94431305, 21.26902962], [69.94431305, 21.26931], [69.94403076, 21.26930618], [69.94403076, 21.26958466], [69.94374847, 21.26958084], [69.94374847, 21.26986122], [69.94346619, 21.26986122], [69.94346619, 21.27042007], [69.94319153, 21.27041435], [69.94319153, 21.27069664], [69.94291687, 21.27069664], [69.94291687, 21.2709713], [69.94264221, 21.27096939], [69.94264221, 21.27124977], [69.94235992, 21.27124977], [69.94235992, 21.27153969], [69.94208527, 21.27152824], [69.94208527, 21.27180672], [69.94180298, 21.27180672], [69.94180298, 21.27236176], [69.94153595, 21.27235985], [69.94153595, 21.27264023], [69.94124603, 21.27264023], [69.94124603, 21.27292061], [69.94097137, 21.27292061], [69.94097137, 21.27320099], [69.94069672, 21.27319527], [69.94069672, 21.27347183], [69.9404068, 21.27346992], [69.9404068, 21.27375031], [69.94013977, 21.27375031], [69.94013977, 21.27403069], [69.93985748, 21.27403069], [69.93985748, 21.27431107], [69.93958282, 21.27430534], [69.93958282, 21.27458382], [69.93930817, 21.27457809], [69.93930817, 21.27486038], [69.93902588, 21.27486038], [69.93902588, 21.27541924], [69.93875122, 21.27541733], [69.93875122, 21.27569389], [69.93846893, 21.27569389], [69.93846893, 21.27597237], [69.93818665, 21.27597046], [69.93818665, 21.27625084], [69.93791962, 21.27625084], [69.93791962, 21.27652931], [69.93763733, 21.27652931], [69.93763733, 21.2768116], [69.93736267, 21.27680588], [69.93736267, 21.27708244], [69.93708038, 21.27708244], [69.93708038, 21.27736092], [69.93680573, 21.27736092], [69.93681335, 21.27763939], [69.93653107, 21.27763939], [69.93653107, 21.27792168], [69.93624878, 21.27791595], [69.93624878, 21.27819443], [69.93597412, 21.27819443], [69.93597412, 21.2784729], [69.93569183, 21.27846909], [69.93569183, 21.27874947], [69.93540955, 21.27874947], [69.93540955, 21.27931023], [69.93514252, 21.27930641], [69.93514252, 21.27958107], [69.93486023, 21.27958107], [69.93486023, 21.27986145], [69.9345932, 21.27985954], [69.9345932, 21.28014183], [69.93430328, 21.28013802], [69.93430328, 21.28041649], [69.93402863, 21.28041267], [69.93402863, 21.28070068], [69.93374634, 21.28069305], [69.93374634, 21.28097153], [69.93347168, 21.28096962], [69.93347168, 21.28125], [69.93319702, 21.28125], [69.93319702, 21.28153038], [69.9329071, 21.28153038], [69.9329071, 21.28181076], [69.93264008, 21.28180313], [69.93264008, 21.28208542], [69.93235779, 21.28208542], [69.93235779, 21.28236389], [69.93208313, 21.28236008], [69.93208313, 21.28264046], [69.93180847, 21.28264046], [69.93180847, 21.28292084], [69.93152618, 21.28291702], [69.93152618, 21.2831955], [69.93125153, 21.28318977], [69.93125153, 21.28347969], [69.93096924, 21.28347969], [69.93096924, 21.28375053], [69.93068695, 21.28375053], [69.93068695, 21.28403091], [69.93041992, 21.28403091], [69.93041992, 21.28430939], [69.93013763, 21.28430557], [69.93013763, 21.28458595], [69.92986298, 21.28458023], [69.92986298, 21.28486061], [69.92958069, 21.28486061], [69.92958069, 21.28514099], [69.92930603, 21.28514099], [69.92930603, 21.28541946], [69.92903137, 21.28541756], [69.92903137, 21.28569412], [69.92874908, 21.28569412], [69.92874908, 21.2859726], [69.9284668, 21.28597069], [69.9284668, 21.28653908], [69.92819214, 21.28653908], [69.92819214, 21.28680992], [69.92791748, 21.28680611], [69.92791748, 21.28708267], [69.92763519, 21.28708267], [69.92764282, 21.28736115], [69.92736053, 21.28736115], [69.92736053, 21.28763962], [69.92708588, 21.28763962], [69.92708588, 21.28791809], [69.92680359, 21.28791618], [69.92680359, 21.28819466], [69.92652893, 21.28819466], [69.92652893, 21.28847313], [69.92624664, 21.28847122], [69.92624664, 21.28874969], [69.92597198, 21.28874969], [69.92597198, 21.28902817], [69.92569733, 21.28902817], [69.92569733, 21.28930473], [69.92541504, 21.28930473], [69.92541504, 21.28958321], [69.92514038, 21.28958321], [69.92514038, 21.28986168], [69.92485809, 21.28985977], [69.92485809, 21.29013824], [69.92457581, 21.29013824], [69.92457581, 21.29041862], [69.92430878, 21.29041862], [69.92430878, 21.29070282], [69.92402649, 21.29069519], [69.92402649, 21.29097176], [69.92375183, 21.29097176], [69.92375183, 21.29125023], [69.92346954, 21.29125023], [69.92346954, 21.29153252], [69.92318726, 21.29153252], [69.92318726, 21.2918129], [69.92292023, 21.29180527], [69.92292023, 21.29236031], [69.92263794, 21.29235077], [69.92263794, 21.29264259], [69.92236328, 21.29264259], [69.92236328, 21.29292107], [69.92208099, 21.29291725], [69.92208099, 21.29319382], [69.92180634, 21.29319382], [69.92180634, 21.29347038], [69.92151642, 21.29347038], [69.92151642, 21.29403114], [69.92124939, 21.29403114], [69.92124939, 21.29430962], [69.92097473, 21.2943058], [69.92097473, 21.29458237], [69.92069244, 21.29458046], [69.92069244, 21.29486084], [69.92041016, 21.29486084], [69.92041016, 21.29514122], [69.9201355, 21.29513931], [69.9201355, 21.29569244], [69.91986084, 21.29569244], [69.91986084, 21.29597473], [69.91958618, 21.29597092], [69.91958618, 21.29624939], [69.91929626, 21.29624939], [69.91929626, 21.29652977], [69.91902924, 21.29652977], [69.91902924, 21.29681015], [69.91874695, 21.29680634], [69.91874695, 21.29736137], [69.91847229, 21.29735947], [69.91847229, 21.29763985], [69.91819763, 21.29763985], [69.91819763, 21.29792023], [69.91791534, 21.29791641], [69.91791534, 21.29819679], [69.91764069, 21.29819107], [69.91764069, 21.29848099], [69.91735077, 21.29848099], [69.91735077, 21.2990303], [69.91707611, 21.2990303], [69.91707611, 21.29931068], [69.91680908, 21.29930687], [69.91680908, 21.29958344], [69.91652679, 21.29958344], [69.91652679, 21.29986191], [69.91625214, 21.29986], [69.91625214, 21.30014038], [69.91596985, 21.30013847], [69.91596985, 21.3006897], [69.91569519, 21.30069542], [69.91569519, 21.30097198], [69.9154129, 21.30097008], [69.9154129, 21.30125046], [69.91513824, 21.30125046], [69.91513824, 21.30152893], [69.91485596, 21.30151939], [69.91485596, 21.30181122], [69.9145813, 21.30181122], [69.9145813, 21.30236053], [69.91430664, 21.30236053], [69.91430664, 21.30264091], [69.91401672, 21.30264091], [69.91401672, 21.30291939], [69.91374969, 21.30291748], [69.91374969, 21.30319405], [69.91347504, 21.30319405], [69.91347504, 21.30347252], [69.91319275, 21.30347061], [69.91319275, 21.30402946], [69.91291809, 21.30402946], [69.91291809, 21.30431175], [69.9126358, 21.30430603], [69.9126358, 21.3045826], [69.91236115, 21.30458069], [69.91236115, 21.30485916], [69.91208649, 21.30485916], [69.91208649, 21.30542183], [69.9118042, 21.30541611], [69.9118042, 21.30569458], [69.91152954, 21.30569458], [69.91152954, 21.30597115], [69.91124725, 21.30597115], [69.91124725, 21.30624962], [69.9109726, 21.30624962], [69.9109726, 21.30653191], [69.91069794, 21.30652809], [69.91069794, 21.30708122], [69.91041565, 21.30708122], [69.91041565, 21.30736351], [69.91014099, 21.3073597], [69.91014099, 21.30764961], [69.9098587, 21.30764961], [69.9098587, 21.30792046], [69.90958405, 21.30791664], [69.90958405, 21.30847168], [69.90930939, 21.30846977], [69.90930176, 21.30875015], [69.9090271, 21.30875015], [69.9090271, 21.30903053], [69.90875244, 21.30903053], [69.90875244, 21.30931091], [69.90847015, 21.30930328], [69.90847015, 21.30958557], [69.90820313, 21.30957985], [69.90820313, 21.31014061], [69.90791321, 21.31014061], [69.90791321, 21.31042099], [69.90763855, 21.31041718], [69.90763855, 21.31069565], [69.90736389, 21.31069565], [69.90736389, 21.31097221], [69.9070816, 21.31097031], [69.9070816, 21.31125069], [69.90680695, 21.31125069], [69.90680695, 21.31153107], [69.90651703, 21.31153107], [69.90651703, 21.31180954], [69.90625, 21.31180763], [69.90625, 21.3120842], [69.90598297, 21.31208038], [69.90598297, 21.31264114], [69.90569305, 21.31264114], [69.90569305, 21.31291962], [69.9054184, 21.31291771], [69.9054184, 21.31319427], [69.90513611, 21.31319427], [69.90513611, 21.31347275], [69.90486145, 21.3134594], [69.90486145, 21.31375122], [69.90458679, 21.31375122], [69.90458679, 21.31402969], [69.90429688, 21.31402969], [69.90429688, 21.31430817], [69.90402985, 21.31430626], [69.90402985, 21.31458282], [69.90374756, 21.31458282], [69.90374756, 21.3148613], [69.9034729, 21.31485939], [69.9034729, 21.31513977], [69.90319824, 21.31513977], [69.90319824, 21.31541824], [69.90291595, 21.31541634], [69.90291595, 21.31597137], [69.9026413, 21.31596947], [69.9026413, 21.31624985], [69.90235901, 21.31624985], [69.90235901, 21.31652832], [69.90208435, 21.31652832], [69.90208435, 21.31680489], [69.90180206, 21.31680489], [69.90180206, 21.31708336], [69.9015274, 21.31708336], [69.9015274, 21.31736183], [69.90125275, 21.31735992], [69.90125275, 21.3176403], [69.90097046, 21.3176403], [69.90097046, 21.31792259], [69.9006958, 21.31792259], [69.9006958, 21.31820107], [69.90041351, 21.31819534], [69.90041351, 21.31847191], [69.90013885, 21.31847191], [69.90013885, 21.31875038], [69.89985657, 21.31875038], [69.89985657, 21.31931114], [69.89958191, 21.31931114], [69.89958191, 21.31958961], [69.89930725, 21.31958961], [69.89930725, 21.31986046], [69.89903259, 21.31986046], [69.89903259, 21.32014275], [69.89875031, 21.32014275], [69.89875031, 21.32042122], [69.89847565, 21.3204174], [69.89847565, 21.32069206], [69.89819336, 21.32069206], [69.89819336, 21.32097435], [69.8979187, 21.32097054], [69.8979187, 21.32125282], [69.89763641, 21.32125282], [69.89763641, 21.32152939], [69.89736176, 21.32152939], [69.89736176, 21.32180977], [69.8970871, 21.32180405], [69.8970871, 21.32208252], [69.89679718, 21.32208061], [69.89679718, 21.32265091], [69.89653015, 21.32265091], [69.89653015, 21.32291985], [69.89624786, 21.32291412], [69.89624786, 21.3231926], [69.89597321, 21.3231926], [69.89597321, 21.32347488], [69.89569092, 21.32347107], [69.89569092, 21.32374954], [69.89541626, 21.32374954], [69.89541626, 21.32402992], [69.8951416, 21.32402992], [69.8951416, 21.3243103], [69.89485931, 21.32430649], [69.89485931, 21.32458305], [69.89458466, 21.32458305], [69.89458466, 21.32486153], [69.89430237, 21.32485962], [69.89430237, 21.32542038], [69.89402771, 21.32542038], [69.89402771, 21.3257103], [69.89375305, 21.32569695], [69.89375305, 21.3259716], [69.89347076, 21.3259697], [69.89347076, 21.32625008], [69.89319611, 21.32625008], [69.89319611, 21.32653046], [69.89290619, 21.32653046], [69.89290619, 21.32681084], [69.89263916, 21.32680511], [69.89263916, 21.32708359], [69.89235687, 21.32707977], [69.89235687, 21.32764053], [69.89208221, 21.32764053], [69.89208221, 21.32792091], [69.89180756, 21.3279171], [69.89180756, 21.32819366], [69.89152527, 21.32819366], [69.89152527, 21.32847214], [69.89125061, 21.32846069], [69.89125061, 21.32875061], [69.89097595, 21.32875061], [69.89097595, 21.32902908], [69.89069366, 21.32902718], [69.89069366, 21.32958412], [69.89041901, 21.32958412], [69.89042664, 21.32986069], [69.89013672, 21.32986069], [69.89013672, 21.33013916], [69.88986206, 21.33013916], [69.88986206, 21.33042145], [69.88957977, 21.33041763], [69.88957977, 21.3306942], [69.88931274, 21.33068848], [69.88931274, 21.33124924], [69.88903046, 21.33124924], [69.88903046, 21.33152962], [69.88874817, 21.33152962], [69.88874817, 21.3318119], [69.88847351, 21.33180618], [69.88847351, 21.33208275], [69.88819122, 21.33208084], [69.88819122, 21.33235931], [69.88791656, 21.33235931], [69.88791656, 21.33292007], [69.88764191, 21.33291626], [69.88764191, 21.33319473], [69.88735962, 21.33319473], [69.88735962, 21.3334713], [69.88708496, 21.3334713], [69.88709259, 21.33374977], [69.88680267, 21.33374977], [69.88680267, 21.33430481], [69.88652802, 21.3343029], [69.88652802, 21.33459091], [69.88625336, 21.33458138], [69.88625336, 21.33486366], [69.88597107, 21.33485985], [69.88597107, 21.33514023], [69.88569641, 21.33514023], [69.88569641, 21.33542061], [69.88541412, 21.33541679], [69.88541412, 21.33597374], [69.88513947, 21.33596992], [69.88513947, 21.33625031], [69.88485718, 21.33625031], [69.88485718, 21.33653069], [69.88458252, 21.33653069], [69.88458252, 21.33681107], [69.88430023, 21.33681107], [69.88430786, 21.33736038], [69.8840332, 21.33736038], [69.8840332, 21.3376503], [69.88375092, 21.3376503], [69.88375092, 21.33792114], [69.88346863, 21.33791733], [69.88346863, 21.3381958], [69.88319397, 21.3381958], [69.88319397, 21.33847237], [69.88291931, 21.33847046], [69.88291931, 21.33903122], [69.88263702, 21.33903122], [69.88263702, 21.33930969], [69.88236237, 21.33930779], [69.88236237, 21.33958244], [69.88208008, 21.33958054], [69.88208008, 21.33986092], [69.88180542, 21.33986092], [69.88181305, 21.34013939], [69.88153076, 21.34013939], [69.88153076, 21.34041977], [69.88124847, 21.34041786], [69.88124847, 21.34069443], [69.88096619, 21.34069061], [69.88096619, 21.34124947], [69.88069153, 21.34124947], [69.88069153, 21.34152985], [69.88041687, 21.34152985], [69.88041687, 21.34180832], [69.88014221, 21.34180641], [69.88014221, 21.34208298], [69.87985992, 21.34208298], [69.87985992, 21.34236145], [69.8795929, 21.34235954], [69.8795929, 21.34263992], [69.87930298, 21.34263992], [69.87930298, 21.3429184], [69.87902832, 21.3429184], [69.87902832, 21.34320068], [69.87875366, 21.34319496], [69.87875366, 21.34347153], [69.87847137, 21.34346962], [69.87847137, 21.34402847], [69.87819672, 21.34402847], [69.87819672, 21.34431267], [69.87791443, 21.34430504], [69.87791443, 21.34458351], [69.87763977, 21.34458351], [69.87763977, 21.34486008], [69.87735748, 21.34486008], [69.87735748, 21.34514046], [69.87708282, 21.34514046], [69.87708282, 21.34542274], [69.87680817, 21.34541702], [69.87680817, 21.34569359], [69.87652588, 21.34569359], [69.87652588, 21.34597015], [69.87625122, 21.34597015], [69.87625122, 21.34625053], [69.87596893, 21.34625053], [69.87596893, 21.34682083], [69.87569427, 21.34680557], [69.87569427, 21.34708214], [69.87541962, 21.34708214], [69.87542725, 21.34736061], [69.87513733, 21.34736061], [69.87513733, 21.3476429], [69.87486267, 21.3476429], [69.87486267, 21.34791946], [69.87458038, 21.34791756], [69.87458038, 21.34819221], [69.87430573, 21.34819221], [69.87430573, 21.3484745], [69.87403107, 21.34847069], [69.87403107, 21.34875107], [69.87374878, 21.34875107], [69.87374878, 21.34902954], [69.87346649, 21.34902954], [69.87346649, 21.3495903], [69.87319183, 21.3495903], [69.87319183, 21.34986115], [69.87291718, 21.34986115], [69.87291718, 21.35013962], [69.87264252, 21.35013962], [69.87264252, 21.35042], [69.87236023, 21.35041428], [69.87236023, 21.35069656], [69.87208557, 21.35069656], [69.87208557, 21.35097313], [69.87180328, 21.35097122], [69.87180328, 21.35124969], [69.87152863, 21.35124969], [69.87152863, 21.35153008], [69.87124634, 21.35152817], [69.87124634, 21.35180664], [69.87097168, 21.35180664], [69.87097168, 21.35236168], [69.87069702, 21.35236168], [69.87069702, 21.35263824], [69.8704071, 21.35263062], [69.8704071, 21.35292053], [69.87014008, 21.35292053], [69.87014008, 21.35320091], [69.86985779, 21.35319519], [69.86985779, 21.35347176], [69.86958313, 21.35346985], [69.86958313, 21.35375023], [69.86930084, 21.35375023], [69.86930084, 21.35403061], [69.86902618, 21.35403061], [69.86902618, 21.35430908], [69.86875153, 21.35430527], [69.86875153, 21.35458374], [69.86846924, 21.35457993], [69.86846924, 21.35514069], [69.86818695, 21.35514069], [69.86818695, 21.35541916], [69.86791992, 21.35541725], [69.86791992, 21.35569382], [69.86763763, 21.35569382], [69.86763763, 21.35597229], [69.86736298, 21.35597038], [69.86736298, 21.35625076], [69.86708069, 21.35625076], [69.86708069, 21.35652924], [69.86680603, 21.35652924], [69.86680603, 21.35681152], [69.86653137, 21.35681152], [69.86653137, 21.35736084], [69.86625671, 21.35736084], [69.86625671, 21.35763931], [69.8659668, 21.35763931], [69.8659668, 21.3579216], [69.86569214, 21.35791588], [69.86569214, 21.35819435], [69.86541748, 21.35819435], [69.86541748, 21.35847282], [69.86514282, 21.35847092], [69.86514282, 21.35876274], [69.86486053, 21.35876274], [69.86486053, 21.35903168], [69.86458588, 21.35902786], [69.86458588, 21.3595829], [69.86430359, 21.3595829], [69.86430359, 21.35986137], [69.86402893, 21.35985947], [69.86402893, 21.36013985], [69.86374664, 21.36013985], [69.86374664, 21.36042023], [69.86347198, 21.36041641], [69.86347198, 21.36069489], [69.86319733, 21.36069489], [69.86319733, 21.36097145], [69.86291504, 21.36097145], [69.86292267, 21.36124992], [69.86264038, 21.36124992], [69.86264038, 21.3615303], [69.86235809, 21.3615284], [69.86235809, 21.36208153], [69.86208344, 21.36208153], [69.86208344, 21.36236382], [69.86180878, 21.36236], [69.86180878, 21.36264038], [69.86152649, 21.36264038], [69.86152649, 21.36292076], [69.86125183, 21.36291695], [69.86125183, 21.3631897], [69.86096954, 21.36319542], [69.86096954, 21.36347389], [69.86068726, 21.36347008], [69.86068726, 21.36375046], [69.86042023, 21.36375046], [69.86042023, 21.36431122], [69.86013794, 21.36430359], [69.86013794, 21.36458588], [69.85986328, 21.36457062], [69.85986328, 21.36486053], [69.85958099, 21.36486053], [69.85958099, 21.36514091], [69.85930634, 21.36514091], [69.85930634, 21.36541939], [69.85902405, 21.36541748], [69.85902405, 21.36569595], [69.85874939, 21.36569595], [69.85874939, 21.36597252], [69.8584671, 21.36597061], [69.8584671, 21.36652946], [69.85819244, 21.36652946], [69.85819244, 21.36680984], [69.85791779, 21.36680794], [69.85791779, 21.3670826], [69.8576355, 21.3670826], [69.85764313, 21.36736107], [69.85736084, 21.36736107], [69.85736084, 21.36763954], [69.85708618, 21.36763], [69.85708618, 21.36791992], [69.85680389, 21.36791611], [69.85680389, 21.36819458], [69.85652924, 21.36819077], [69.85652924, 21.36874962], [69.85624695, 21.36874962], [69.85624695, 21.36902809], [69.85597229, 21.36902809], [69.85597229, 21.36930466], [69.85569763, 21.36930466], [69.85569763, 21.36958313], [69.85541534, 21.36958313], [69.85541534, 21.3698616], [69.85514069, 21.3698597], [69.85514069, 21.37013817], [69.8548584, 21.37013817], [69.8548584, 21.37070084], [69.85458374, 21.37069511], [69.85458374, 21.37097168], [69.85430908, 21.37097168], [69.85431671, 21.37125015], [69.85402679, 21.37125015], [69.85402679, 21.37153244], [69.85375214, 21.37153244], [69.85375214, 21.37181282], [69.85346985, 21.37180519], [69.85346985, 21.37208366], [69.85320282, 21.37208176], [69.85320282, 21.37264252], [69.8529129, 21.37264252], [69.8529129, 21.3729229], [69.85263824, 21.37291718], [69.85263824, 21.37319374], [69.85236359, 21.37319374], [69.85236359, 21.37347031], [69.8520813, 21.37347031], [69.8520813, 21.37376022], [69.85180664, 21.37376022], [69.85180664, 21.37403107], [69.85152435, 21.37402725], [69.85152435, 21.37458229], [69.85124969, 21.37458229], [69.85124969, 21.37486076], [69.85098267, 21.37486076], [69.85098267, 21.37514114], [69.85069275, 21.37514114], [69.85069275, 21.37541962], [69.85041809, 21.3754158], [69.85041809, 21.37569237], [69.8501358, 21.37569237], [69.8501358, 21.37597466], [69.84986115, 21.37597084], [69.84986115, 21.37625122], [69.84958649, 21.37624931], [69.84958649, 21.37680626], [69.8493042, 21.37680626], [69.8493042, 21.37708473], [69.84902954, 21.37708473], [69.84902954, 21.3773613], [69.84874725, 21.37735939], [69.84874725, 21.37763977], [69.8484726, 21.37763977], [69.8484726, 21.37792015], [69.84819794, 21.37791443], [69.84819794, 21.37819672], [69.84791565, 21.37819672], [69.84792328, 21.37874985], [69.84764099, 21.37874985], [69.84764099, 21.37903023], [69.8473587, 21.37902832], [69.8473587, 21.37930679], [69.84708405, 21.37930679], [69.84708405, 21.37958336], [69.84680939, 21.37958336], [69.84680176, 21.37986183], [69.8465271, 21.37985992], [69.8465271, 21.3801403], [69.84625244, 21.3801403], [69.84625244, 21.38070107], [69.84597015, 21.38069534], [69.84597015, 21.38097191], [69.8456955, 21.38097191], [69.84570313, 21.38125038], [69.84541321, 21.38125038], [69.84541321, 21.38153076], [69.84513092, 21.38153076], [69.84513092, 21.38180923], [69.84486389, 21.38180542], [69.84486389, 21.38208389], [69.8445816, 21.38207817], [69.8445816, 21.38264084], [69.84430695, 21.38264084], [69.84430695, 21.38293266], [69.84402466, 21.3829174], [69.84402466, 21.38319397], [69.84375, 21.38319397], [69.84375, 21.38347244], [69.84347534, 21.38347244], [69.84348297, 21.38375092], [69.84319305, 21.38375092], [69.84319305, 21.38402939], [69.8429184, 21.38402939], [69.8429184, 21.38431168], [69.84263611, 21.38431168], [69.84263611, 21.38485909], [69.84236145, 21.38485909], [69.84236145, 21.38513947], [69.84208679, 21.38513947], [69.84208679, 21.38542175], [69.84179688, 21.38542175], [69.84179688, 21.38570023], [69.84152985, 21.3856945], [69.84152985, 21.38597107], [69.84124756, 21.38597107], [69.84124756, 21.38624954], [69.8409729, 21.38624954], [69.8409729, 21.38653183], [69.84069824, 21.38652802], [69.84069824, 21.38708115], [69.84041595, 21.38708115], [69.84041595, 21.38736153], [69.8401413, 21.38735962], [69.8401413, 21.38764191], [69.83985901, 21.38764191], [69.83985901, 21.38792038], [69.83957672, 21.38792038], [69.83957672, 21.38820076], [69.83930206, 21.38819313], [69.83930206, 21.3884716], [69.8390274, 21.3884716], [69.8390274, 21.38875008], [69.83875275, 21.38874054], [69.83875275, 21.38931084], [69.83847046, 21.38930321], [69.83847046, 21.38958549], [69.8381958, 21.38958549], [69.8381958, 21.38986206], [69.83790588, 21.38986015], [69.83790588, 21.39014053], [69.83763885, 21.39014053], [69.83763885, 21.39042091], [69.8373642, 21.3904171], [69.8373642, 21.39069557], [69.83708191, 21.39069557], [69.83708191, 21.39097214], [69.83680725, 21.39097023], [69.83680725, 21.39153099], [69.83652496, 21.39152527], [69.83652496, 21.39180756], [69.83625031, 21.39180756], [69.83625031, 21.39208412], [69.83597565, 21.39208412], [69.83598328, 21.39236069], [69.83569336, 21.39236069], [69.83569336, 21.39264107], [69.8354187, 21.39264107], [69.8354187, 21.39291954], [69.83513641, 21.39291763], [69.83513641, 21.3931942], [69.83486176, 21.39319038], [69.83486176, 21.39375114], [69.8345871, 21.39375114], [69.8345871, 21.39402962], [69.83429718, 21.39402962], [69.83429718, 21.39430809], [69.83403015, 21.39430618], [69.83403015, 21.39458275], [69.83374786, 21.39458084], [69.83374786, 21.39487076], [69.83347321, 21.39487076], [69.83347321, 21.39513969], [69.83319092, 21.39513969], [69.83319092, 21.39541817], [69.83291626, 21.39541626], [69.83291626, 21.3959713], [69.8326416, 21.39596748], [69.8326416, 21.39624977], [69.83235931, 21.39624977], [69.83235931, 21.39652824], [69.83208466, 21.39652824], [69.83208466, 21.39680481], [69.83180237, 21.39680481], [69.83180237, 21.39708328], [69.83152771, 21.39708328], [69.83152771, 21.39736176], [69.83125305, 21.39735985], [69.83125305, 21.39763832], [69.83097076, 21.39763832], [69.83097076, 21.3982029], [69.83069611, 21.39819527], [69.83069611, 21.39847183], [69.83040619, 21.39847183], [69.83041382, 21.39875031], [69.83014679, 21.39875031], [69.83014679, 21.39903259], [69.82985687, 21.39903259], [69.82985687, 21.39931107], [69.82958221, 21.39930534], [69.82958221, 21.39958382], [69.82930756, 21.39958191], [69.82930756, 21.39986038], [69.8290329, 21.39986038], [69.8290329, 21.40014267], [69.82875061, 21.40013885], [69.82875061, 21.40069389], [69.82847595, 21.40069389], [69.82847595, 21.40097237], [69.82818604, 21.40097046], [69.82818604, 21.40125275], [69.82791901, 21.40125275], [69.82791901, 21.40153122], [69.82763672, 21.40153122], [69.82763672, 21.40180969], [69.82736206, 21.40180588], [69.82736206, 21.40208244], [69.82707977, 21.40208244], [69.82707977, 21.40236092], [69.82680511, 21.40236092], [69.82681274, 21.40263939], [69.82653046, 21.40263939], [69.82653046, 21.40319252], [69.82624817, 21.40319252], [69.82624817, 21.40347481], [69.82597351, 21.40347481], [69.82597351, 21.40374947], [69.82569122, 21.40373993], [69.82569122, 21.40402985], [69.82541656, 21.40402985], [69.82541656, 21.40431023], [69.82514191, 21.40430641], [69.82514191, 21.40458488], [69.82485962, 21.40458488], [69.82485962, 21.40486145], [69.82459259, 21.40485954], [69.82459259, 21.4054203], [69.82430267, 21.4054203], [69.82430267, 21.40570068], [69.82402802, 21.40569687], [69.82402802, 21.40597153], [69.82375336, 21.40596962], [69.82375336, 21.40625], [69.82347107, 21.40625], [69.82347107, 21.40653038], [69.82319641, 21.40653038], [69.82319641, 21.40681076], [69.82291412, 21.40680695], [69.82291412, 21.40708351], [69.82263947, 21.40708351], [69.82263947, 21.40736198], [69.82235718, 21.40736008], [69.82235718, 21.40792084], [69.82208252, 21.40791893], [69.82208252, 21.40819359], [69.82180786, 21.40819359], [69.82180786, 21.40847206], [69.82152557, 21.40847206], [69.8215332, 21.40875053], [69.82125092, 21.40875053], [69.82125092, 21.40903091], [69.820961, 21.40903091], [69.820961, 21.40930748], [69.82069397, 21.40930557], [69.82069397, 21.40958405], [69.82041931, 21.40957832], [69.82041931, 21.40987015], [69.82013702, 21.40987015], [69.82013702, 21.41041946], [69.81986237, 21.41041756], [69.81986237, 21.41069412], [69.81958008, 21.41069412], [69.81958008, 21.4109726], [69.81931305, 21.41097069], [69.81931305, 21.41124916], [69.81903076, 21.41124916], [69.81903076, 21.41152954], [69.81874847, 21.41152954], [69.81874847, 21.41181183], [69.81847382, 21.41180611], [69.81847382, 21.41208267], [69.81819153, 21.41208076], [69.81819153, 21.41263962], [69.81791687, 21.41263962], [69.81791687, 21.41291618], [69.81764221, 21.41291618], [69.81764221, 21.41319466], [69.81735992, 21.41319466], [69.81735992, 21.41347122], [69.81708527, 21.41347122], [69.8170929, 21.41374969], [69.81680298, 21.41374969], [69.81680298, 21.41403008], [69.81652832, 21.41402817], [69.81652832, 21.41430473], [69.81625366, 21.41430473], [69.81625366, 21.41486359], [69.81597137, 21.41485977], [69.81597137, 21.41514015], [69.81569672, 21.41514015], [69.81569672, 21.41542053], [69.8154068, 21.41542053], [69.8154068, 21.41570091], [69.81513977, 21.41569328], [69.81513977, 21.41597176], [69.81485748, 21.41596985], [69.81485748, 21.41625023], [69.81458282, 21.41625023], [69.81458282, 21.41653061], [69.81430817, 21.4165287], [69.81430817, 21.41708565], [69.81402588, 21.41707993], [69.81402588, 21.41736031], [69.81375122, 21.41736031], [69.81375122, 21.41764069], [69.81346893, 21.41764069], [69.81346893, 21.41792107], [69.81319427, 21.41791725], [69.81319427, 21.41819572], [69.81291962, 21.41819572], [69.81291962, 21.41847229], [69.81263733, 21.41847038], [69.81263733, 21.41875076], [69.81236267, 21.41875076], [69.81236267, 21.41930962], [69.81208038, 21.41930771], [69.81208038, 21.41958427], [69.81180573, 21.41958427], [69.81181335, 21.41986084], [69.81153107, 21.41986084], [69.81153107, 21.42014122], [69.81124878, 21.42014122], [69.81124878, 21.42041969], [69.81097412, 21.42041779], [69.81097412, 21.42069435], [69.81069183, 21.42069435], [69.81069183, 21.42097282], [69.81041718, 21.42097092], [69.81041718, 21.42152977], [69.81014252, 21.42152977], [69.81014252, 21.42180824], [69.80986023, 21.42180634], [69.80986023, 21.4220829], [69.80958557, 21.4220829], [69.80958557, 21.42236137], [69.80930328, 21.42235947], [69.80930328, 21.42263985], [69.809021, 21.42263985], [69.809021, 21.42291832], [69.80874634, 21.42291641], [69.80874634, 21.42319489], [69.80847168, 21.42319489], [69.80847168, 21.42347145], [69.80819702, 21.42346954], [69.80819702, 21.42374992], [69.8079071, 21.42374992], [69.8079071, 21.42431259], [69.80764008, 21.42430496], [69.80764008, 21.42458344], [69.80735779, 21.42458344], [69.80735779, 21.42486191], [69.80708313, 21.42485046], [69.80708313, 21.42514038], [69.80680847, 21.42514038], [69.80680847, 21.42542267], [69.80652618, 21.42541695], [69.80652618, 21.4256916], [69.80625153, 21.42569542], [69.80625153, 21.42597008], [69.80596161, 21.42597008], [69.80596161, 21.42625046], [69.80568695, 21.42625046], [69.80568695, 21.42681122], [69.80541992, 21.4268055], [69.80541992, 21.42708206], [69.80513763, 21.42708015], [69.80513763, 21.42736053], [69.80486298, 21.42736053], [69.80486298, 21.42764282], [69.80458069, 21.42763901], [69.80458069, 21.42791748], [69.80430603, 21.42791748], [69.80430603, 21.42819214], [69.80403137, 21.42819214], [69.80403137, 21.42847443], [69.80374908, 21.42847061], [69.80374908, 21.4287529], [69.8034668, 21.4287529], [69.8034668, 21.42902946], [69.80319214, 21.42902946], [69.80319214, 21.42930984], [69.80291748, 21.42930412], [69.80291748, 21.4295826], [69.80263519, 21.4295826], [69.80264282, 21.43013954], [69.80236053, 21.43013954], [69.80236053, 21.43041992], [69.80208588, 21.4304142], [69.80208588, 21.43069649], [69.80180359, 21.43069649], [69.80180359, 21.43097305], [69.80152893, 21.43097115], [69.80152893, 21.43124962], [69.80124664, 21.43124962], [69.80124664, 21.43153], [69.80097198, 21.43152809], [69.80097198, 21.43180656], [69.80069733, 21.43180656], [69.80069733, 21.43208313], [69.80041504, 21.43208313], [69.80041504, 21.4323616], [69.80014038, 21.4323597], [69.80014038, 21.43264008], [69.79985809, 21.43264008], [69.79985809, 21.43320084], [69.79958344, 21.43319511], [69.79958344, 21.43347168], [69.79930878, 21.43346977], [69.79930878, 21.43375015], [69.79902649, 21.43375015], [69.79902649, 21.43403816], [69.79875183, 21.43403816], [69.79875183, 21.43431091], [69.79846954, 21.43430519], [69.79846954, 21.43458366], [69.79818726, 21.43457985], [69.79818726, 21.43486023], [69.79792023, 21.43486023], [69.79792023, 21.43514061], [69.79763794, 21.43514061], [69.79763794, 21.43541908], [69.79736328, 21.43541718], [69.79736328, 21.43597221], [69.79708099, 21.43597031], [69.79708099, 21.43625069], [69.79680634, 21.43625069], [69.79680634, 21.43652916], [69.79651642, 21.43652916], [69.79651642, 21.43681145], [69.79624939, 21.43680573], [69.79624939, 21.4370842], [69.7959671, 21.43708038], [69.7959671, 21.43736076], [69.79569244, 21.43736076], [69.79569244, 21.43792152], [69.79541779, 21.4379158], [69.79541779, 21.43819427], [69.7951355, 21.43819427], [69.7951355, 21.43847275], [69.79486084, 21.43847084], [69.79486084, 21.43874931], [69.79458618, 21.43874931], [69.79458618, 21.43902969], [69.79429626, 21.43902969], [69.79429626, 21.43931007], [69.79402924, 21.43930626], [69.79402924, 21.43958282], [69.79374695, 21.43958282], [69.79374695, 21.4398613], [69.79347229, 21.43985176], [69.79347229, 21.44013977], [69.79319763, 21.44013977], [69.79319763, 21.44042015], [69.79291534, 21.44041634], [69.79291534, 21.44069481], [69.79264069, 21.44069481], [69.79264069, 21.44097137], [69.7923584, 21.44096947], [69.7923584, 21.44153023], [69.79208374, 21.44152832], [69.79208374, 21.44180489], [69.79180908, 21.44180489], [69.79180908, 21.44208145], [69.79152679, 21.44208145], [69.79152679, 21.44236374], [69.79125214, 21.44235992], [69.79125214, 21.4426403], [69.79097748, 21.4426403], [69.79097748, 21.44292068], [69.79070282, 21.44292068], [69.79070282, 21.44320107], [69.7904129, 21.44319344], [69.7904129, 21.44347382], [69.79013824, 21.44347], [69.79013824, 21.44375038], [69.78985596, 21.44375038], [69.78985596, 21.44431114], [69.7895813, 21.44430351], [69.7895813, 21.4445858], [69.78930664, 21.44458008], [69.78930664, 21.44486046], [69.78901672, 21.44486046], [69.78901672, 21.44514084], [69.78874969, 21.44514084], [69.78874969, 21.44542122], [69.78847504, 21.4454174], [69.78847504, 21.44569588], [69.78819275, 21.44569016], [69.78819275, 21.44598007], [69.78791809, 21.44598007], [69.78791809, 21.44625092], [69.7876358, 21.44625092], [69.7876358, 21.44652939], [69.78736115, 21.44652939], [69.78736115, 21.44680977], [69.78708649, 21.44680977], [69.78708649, 21.44736099], [69.78679657, 21.44736099], [69.78679657, 21.44763947], [69.78652954, 21.44763947], [69.78652954, 21.44791985], [69.78624725, 21.44791794], [69.78624725, 21.4481945], [69.7859726, 21.4481945], [69.7859726, 21.44847298], [69.78569794, 21.44847107], [69.78569794, 21.44874954], [69.78542328, 21.44874954], [69.78542328, 21.44903946], [69.78514099, 21.44903946], [69.78514099, 21.4493084], [69.7848587, 21.44930649], [69.7848587, 21.44958305], [69.78457642, 21.44958115], [69.78457642, 21.45013809], [69.78430939, 21.45013809], [69.78430176, 21.45041847], [69.7840271, 21.45041847], [69.7840271, 21.45070076], [69.78375244, 21.45069504], [69.78375244, 21.4509716], [69.78347015, 21.4509697], [69.78347015, 21.45125008], [69.78320313, 21.45125008], [69.78320313, 21.45153236], [69.78291321, 21.45153236], [69.78291321, 21.45181274], [69.78263855, 21.45180511], [69.78263855, 21.45236015], [69.78235626, 21.45236015], [69.78235626, 21.45264053], [69.78180695, 21.45264053], [69.78180695, 21.45292282], [69.78152466, 21.4529171], [69.78152466, 21.45319366], [69.78125, 21.45319366], [69.78125, 21.45347023], [69.78097534, 21.45347023], [69.78098297, 21.45375061], [69.78069305, 21.45375061], [69.78069305, 21.4540329], [69.7804184, 21.4540329], [69.7804184, 21.45430946], [69.78013611, 21.45430565], [69.78013611, 21.45458221], [69.77986145, 21.45458031], [69.77986145, 21.45486069], [69.77958679, 21.45486069], [69.77958679, 21.45514107], [69.77929688, 21.45514107], [69.77929688, 21.45541954], [69.78013611, 21.45541573], [69.78013611, 21.45597458], [69.77986145, 21.45597076], [69.77986145, 21.45652962], [69.77958679, 21.45652771], [69.77958679, 21.45708466], [69.77902985, 21.45708466], [69.77903748, 21.45736122], [69.77874756, 21.45736122], [69.77874756, 21.45763969], [69.7784729, 21.45763969], [69.7784729, 21.45792007], [69.77819824, 21.45791435], [69.77819824, 21.4584713], [69.7784729, 21.45846939], [69.7784729, 21.45874977], [69.77874756, 21.45874977], [69.77874756, 21.45846939], [69.77902985, 21.4584713], [69.77902985, 21.45819664], [69.7793045, 21.45819664], [69.7793045, 21.45791435], [69.77986145, 21.45792007], [69.77986145, 21.45763969], [69.78013611, 21.45763969], [69.78013611, 21.45736122], [69.7804184, 21.45736122], [69.7804184, 21.45681], [69.78069305, 21.45681], [69.78069305, 21.45625114], [69.78098297, 21.45625114], [69.78098297, 21.45569038], [69.78125, 21.45569229], [69.78125, 21.45541573], [69.78180695, 21.45541954], [69.78180695, 21.45514107], [69.7820816, 21.45514107], [69.7820816, 21.45486069], [69.78263855, 21.45486069], [69.78263855, 21.45458031], [69.78291321, 21.45458221], [69.78291321, 21.45430565], [69.78320313, 21.45430946], [69.78320313, 21.4540329], [69.78347015, 21.4540329], [69.78347015, 21.45375061], [69.78375244, 21.45375061], [69.78375244, 21.45347023], [69.7840271, 21.45347023], [69.7840271, 21.45319366], [69.78430176, 21.45319366], [69.78430176, 21.4529171], [69.78485107, 21.45292282], [69.78485107, 21.45264053], [69.78542328, 21.45264053], [69.78542328, 21.45236015], [69.78624725, 21.45236015], [69.78624725, 21.45208168], [69.7868042, 21.45208359], [69.7868042, 21.45180511], [69.7876358, 21.45181274], [69.7876358, 21.45153236], [69.79152679, 21.45153236], [69.79152679, 21.45125008], [69.79402161, 21.45125008], [69.79402161, 21.45153236], [69.79651642, 21.45153236], [69.79651642, 21.45181274], [69.79792023, 21.45180511], [69.79792023, 21.45208359], [69.79878998, 21.45208168], [69.79985809, 21.45208168], [69.79985809, 21.45236015], [69.80014038, 21.45236015], [69.80014038, 21.45319366], [69.80097198, 21.45319366], [69.80097198, 21.45347023], [69.80014038, 21.45347023], [69.80014038, 21.45375061], [69.79957581, 21.45375061], [69.79957581, 21.4540329], [69.79985809, 21.4540329], [69.79985809, 21.45430946], [69.80014038, 21.45430565], [69.80014038, 21.45458221], [69.80041504, 21.45458221], [69.80041504, 21.45486069], [69.80097198, 21.45486069], [69.80097198, 21.45514107], [69.80152893, 21.45514107], [69.80152893, 21.45541954], [69.80180359, 21.45541573], [69.80180359, 21.45569229], [69.80208588, 21.45569229], [69.80208588, 21.45541573], [69.80264282, 21.45541954], [69.80264282, 21.45514107], [69.80319214, 21.45514107], [69.80319214, 21.45486069], [69.80458069, 21.45486069], [69.80458069, 21.45597458], [69.80319214, 21.45597076], [69.80319214, 21.45625114], [69.80152893, 21.45625114], [69.80152893, 21.45597076], [69.80097198, 21.45597458], [69.80097198, 21.45708466], [69.80124664, 21.45708084], [69.80124664, 21.45792007], [69.80152893, 21.45792007], [69.80152893, 21.45874977], [69.80180359, 21.45874977], [69.80180359, 21.45930672], [69.80208588, 21.45930672], [69.80208588, 21.45986176], [69.80236053, 21.45985985], [69.80236053, 21.46014023], [69.80264282, 21.46014023], [69.80264282, 21.46069908], [69.80291748, 21.46069908], [69.80291748, 21.46125031], [69.80319214, 21.46125031], [69.80319214, 21.46180916], [69.80347443, 21.46180534], [69.80347443, 21.46208382], [69.80374908, 21.46207809], [69.80374908, 21.46264076], [69.80403137, 21.46264076], [69.80403137, 21.46291924], [69.80430603, 21.46291733], [69.80430603, 21.46319389], [69.80486298, 21.46319389], [69.80486298, 21.46347237], [69.80513763, 21.46347046], [69.80513763, 21.46375084], [69.80486298, 21.46375084], [69.80486298, 21.4640274], [69.80430603, 21.4640274], [69.80430603, 21.46375084], [69.80403137, 21.46375084], [69.80403137, 21.46347046], [69.80374908, 21.46347237], [69.80374908, 21.46319389], [69.80319214, 21.46319389], [69.80319214, 21.46291733], [69.80291748, 21.46291924], [69.80291748, 21.46264076], [69.80264282, 21.46264076], [69.80264282, 21.46236038], [69.80236053, 21.46236038], [69.80236053, 21.46180916], [69.80208588, 21.46180916], [69.80208588, 21.46125031], [69.80179596, 21.46125031], [69.80179596, 21.46069908], [69.80152893, 21.46069908], [69.80152893, 21.46014023], [69.80124664, 21.46014023], [69.80124664, 21.45957947], [69.80097198, 21.45958328], [69.80097198, 21.45902824], [69.80069733, 21.45903015], [69.80069733, 21.45846939], [69.80041504, 21.4584713], [69.80041504, 21.45763969], [69.80014038, 21.45763969], [69.80014038, 21.45652962], [69.79985809, 21.45652962], [69.79985809, 21.45569038], [69.79958344, 21.45569229], [69.79958344, 21.45513916], [69.79930878, 21.45514107], [69.79930878, 21.45486069], [69.79902649, 21.45486069], [69.79902649, 21.45458031], [69.79875183, 21.45458221], [69.79875183, 21.45430565], [69.79846954, 21.45430946], [69.79846954, 21.4540329], [69.79792023, 21.4540329], [69.79792023, 21.45375061], [69.79763794, 21.45375061], [69.79763794, 21.45347023], [69.79708099, 21.45347023], [69.79708099, 21.45319366], [69.79624939, 21.45319366], [69.79624939, 21.4529171], [69.79569244, 21.45292282], [69.79569244, 21.45264053], [69.79347229, 21.45264053], [69.79347229, 21.45292282], [69.79180908, 21.4529171], [69.79180908, 21.45319366], [69.79125214, 21.45319366], [69.79125214, 21.45347023], [69.7859726, 21.45347023], [69.7859726, 21.45375061], [69.78514099, 21.45375061], [69.78514099, 21.45458221], [69.78485107, 21.45458031], [69.78485107, 21.45514107], [69.78430939, 21.45514107], [69.78430176, 21.45541954], [69.7840271, 21.45541763], [69.7840271, 21.45569229], [69.78375244, 21.45569229], [69.78375244, 21.45597458], [69.78347015, 21.45597076], [69.78347015, 21.45625114], [69.78320313, 21.45625114], [69.78320313, 21.45652962], [69.78291321, 21.45652962], [69.78291321, 21.45681], [69.7820816, 21.45680428], [69.7820816, 21.45708466], [69.78180695, 21.45708084], [69.78180695, 21.45736122], [69.78151703, 21.45736122], [69.78151703, 21.45763969], [69.78125, 21.45763969], [69.78125, 21.45792007], [69.78097534, 21.45791435], [69.78097534, 21.4584713], [69.78069305, 21.45846939], [69.78069305, 21.45874977], [69.77958679, 21.45874977], [69.77958679, 21.45930672], [69.7793045, 21.45930672], [69.7793045, 21.45986176], [69.77903748, 21.45985985], [69.77903748, 21.46042061], [69.77819824, 21.46042061], [69.77819824, 21.46069908], [69.77735901, 21.46069908], [69.77735901, 21.46097946], [69.77707672, 21.46097946], [69.77707672, 21.46125031], [69.77735901, 21.46125031], [69.77735901, 21.46153069], [69.7776413, 21.46153069], [69.7776413, 21.46180916], [69.7784729, 21.46180916], [69.7784729, 21.46236038], [69.77819824, 21.46236038], [69.77819824, 21.46291924], [69.77680206, 21.46291733], [69.77680206, 21.46319389], [69.7748642, 21.46319389], [69.7748642, 21.46263885], [69.77458191, 21.46264076], [69.77458191, 21.46207809], [69.7748642, 21.46208382], [69.7748642, 21.46125031], [69.77513885, 21.46125031], [69.77513885, 21.46069908], [69.77540588, 21.46069908], [69.77540588, 21.46042061], [69.7756958, 21.46042061], [69.7756958, 21.45985985], [69.77513885, 21.45985985], [69.77513885, 21.46014023], [69.77485657, 21.46014023], [69.77485657, 21.46042061], [69.77458191, 21.46042061], [69.77458191, 21.46069908], [69.77430725, 21.46069908], [69.77430725, 21.46125031], [69.77403259, 21.46125031], [69.77403259, 21.46153069], [69.77375031, 21.46153069], [69.77375031, 21.46180916], [69.77347565, 21.46180534], [69.77348328, 21.46236038], [69.77319336, 21.46236038], [69.77319336, 21.46264076], [69.77291107, 21.46264076], [69.77291107, 21.46291924], [69.77263641, 21.46291733], [69.77263641, 21.46347237], [69.77236176, 21.46347046], [69.77236176, 21.46375084], [69.7720871, 21.46375084], [69.7720871, 21.4640274], [69.77180481, 21.4640274], [69.77180481, 21.46458244], [69.77153015, 21.46458054], [69.77153015, 21.46486092], [69.77124786, 21.46486092], [69.77124786, 21.46542168], [69.77097321, 21.46541595], [69.77097321, 21.46569443], [69.77069092, 21.46569443], [69.77069092, 21.4659729], [69.77041626, 21.46596909], [69.77041626, 21.46624947], [69.7701416, 21.46624947], [69.7701416, 21.46653175], [69.76985931, 21.46652794], [69.76985931, 21.46708107], [69.76958466, 21.46708107], [69.76958466, 21.46736145], [69.76930237, 21.46735954], [69.76930237, 21.46763992], [69.76902771, 21.46763992], [69.76902771, 21.4679203], [69.76875305, 21.4679203], [69.76875305, 21.46820068], [69.76847076, 21.46819305], [69.76847076, 21.46847153], [69.76819611, 21.46846962], [69.76819611, 21.46875], [69.76790619, 21.46875], [69.76790619, 21.46903038], [69.76763916, 21.46903038], [69.76763916, 21.46931076], [69.7673645, 21.46930313], [69.7673645, 21.46958542], [69.76708221, 21.46958542], [69.76708221, 21.46986389], [69.76680756, 21.46986008], [69.76680756, 21.47014999], [69.7665329, 21.47014999], [69.7665329, 21.47042084], [69.76625061, 21.47041512], [69.76625061, 21.4706955], [69.76597595, 21.4706955], [69.76597595, 21.47097206], [69.76568604, 21.47097015], [69.76568604, 21.47153091], [69.76541901, 21.47153091], [69.76541901, 21.47180939], [69.76513672, 21.47180367], [69.76513672, 21.47208595], [69.76486206, 21.47208023], [69.76486206, 21.47236061], [69.76457977, 21.47236061], [69.76457977, 21.47264099], [69.76431274, 21.47264099], [69.76431274, 21.47291946], [69.76403046, 21.47291756], [69.76403046, 21.47319412], [69.76374817, 21.47319412], [69.76374817, 21.4734726], [69.76346588, 21.47347069], [69.76346588, 21.47375107], [69.76319122, 21.47375107], [69.76319122, 21.47402954], [69.76291656, 21.47402954], [69.76291656, 21.47430992], [69.76264191, 21.47430611], [69.76264191, 21.47458267], [69.76235962, 21.47458076], [69.76235962, 21.47486115], [69.76208496, 21.47486115], [69.76209259, 21.47513962], [69.76180267, 21.47513962], [69.76180267, 21.47541809], [69.76152802, 21.47541618], [69.76152802, 21.47569466], [69.76125336, 21.47569466], [69.76125336, 21.47597313], [69.76097107, 21.47595978], [69.76097107, 21.47624969], [69.76069641, 21.47624969], [69.76069641, 21.47680473], [69.76041412, 21.47680473], [69.76041412, 21.47708321], [69.76013947, 21.47708321], [69.76013947, 21.47736168], [69.75985718, 21.47735977], [69.75985718, 21.47763824], [69.75958252, 21.47763824], [69.75958252, 21.47792244], [69.75930786, 21.47792244], [69.75930786, 21.47820282], [69.75902557, 21.47819519], [69.75902557, 21.47847176], [69.75875092, 21.47847176], [69.75875092, 21.47875023], [69.75846863, 21.47875023], [69.75846863, 21.4790287], [69.75818634, 21.47901917], [69.75818634, 21.4793129], [69.75791931, 21.47930527], [69.75791931, 21.47958374], [69.75763702, 21.47958183], [69.75763702, 21.47986031], [69.75736237, 21.47986031], [69.75736237, 21.48014259], [69.75708008, 21.48014259], [69.75708008, 21.48042107], [69.75680542, 21.48041725], [69.75680542, 21.48069382], [69.75653076, 21.48069382], [69.75653076, 21.48097229], [69.75624847, 21.48097038], [69.75624847, 21.48125076], [69.75596619, 21.48125076], [69.75596619, 21.48153114], [69.75569153, 21.48153114], [69.75569153, 21.48180962], [69.75541687, 21.48180962], [69.75541687, 21.48209], [69.75514221, 21.48209], [69.75514221, 21.48264122], [69.75486755, 21.48264122], [69.75486755, 21.48291969], [69.75458527, 21.48291588], [69.75458527, 21.48319244], [69.75430298, 21.48319244], [69.75430298, 21.48347473], [69.75402832, 21.48347092], [69.75402832, 21.48374939], [69.75374603, 21.48374939], [69.75374603, 21.48402977], [69.75347137, 21.48402977], [69.75347137, 21.48431015], [69.75319672, 21.48430634], [69.75319672, 21.48458481], [69.75291443, 21.48458481], [69.75291443, 21.48486137], [69.75263977, 21.48485947], [69.75263977, 21.48514938], [69.75235748, 21.48514938], [69.75235748, 21.48542023], [69.75208282, 21.48541451], [69.75208282, 21.48569679], [69.75180817, 21.48569679], [69.75180817, 21.48597145], [69.75152588, 21.48596954], [69.75152588, 21.48624992], [69.75125122, 21.48624992], [69.75125122, 21.4865303], [69.75096893, 21.4865303], [69.75096893, 21.48681068], [69.75069427, 21.48680687], [69.75069427, 21.48736191], [69.75041962, 21.48736], [69.75041962, 21.48764038], [69.75013733, 21.48764038], [69.75013733, 21.48792076], [69.74986267, 21.48791885], [69.74986267, 21.48819351], [69.74958038, 21.48819542], [69.74958038, 21.48847198], [69.74930573, 21.48847198], [69.74931335, 21.48875046], [69.74903107, 21.48875046], [69.74903107, 21.48903084], [69.74874115, 21.48903084], [69.74874115, 21.48930931], [69.74847412, 21.4893055], [69.74847412, 21.48958397], [69.74819183, 21.48957825], [69.74819183, 21.48986053], [69.74791718, 21.48986053], [69.74791718, 21.49014091], [69.74764252, 21.49014091], [69.74764252, 21.49041939], [69.74736023, 21.49041748], [69.74736023, 21.49069405], [69.7470932, 21.49068832], [69.7470932, 21.49124908], [69.74680328, 21.49124908], [69.74680328, 21.49152946], [69.74652863, 21.49152946], [69.74652863, 21.49181175], [69.74624634, 21.49180603], [69.74624634, 21.4920826], [69.74597168, 21.49208069], [69.74597168, 21.49235916], [69.74569702, 21.49235916], [69.74569702, 21.49263954], [69.7454071, 21.49263954], [69.7454071, 21.49292183], [69.74514008, 21.49291611], [69.74514008, 21.49319458], [69.74485779, 21.49319458], [69.74485779, 21.49347115], [69.74458313, 21.49347115], [69.74458313, 21.49374962], [69.74430847, 21.49374962], [69.74430847, 21.49403191], [69.74402618, 21.49402809], [69.74402618, 21.49430466], [69.74375153, 21.49430466], [69.74375153, 21.49458122], [69.74346924, 21.49458122], [69.74346924, 21.49514008], [69.74318695, 21.49514008], [69.74318695, 21.49542046], [69.74292755, 21.49542046], [69.74292755, 21.49570084], [69.74263763, 21.49569321], [69.74263763, 21.49597168], [69.74236298, 21.49596977], [69.74236298, 21.49625015], [69.74208069, 21.49625015], [69.74208069, 21.49653053], [69.74180603, 21.49653053], [69.74180603, 21.49681091], [69.74153137, 21.49681091], [69.74153137, 21.49708939], [69.74124908, 21.49708939], [69.74124908, 21.49736023], [69.7409668, 21.49736023], [69.7409668, 21.49764061], [69.74069214, 21.49764061], [69.74069214, 21.49792099], [69.74041748, 21.49791718], [69.74041748, 21.49819565], [69.74013519, 21.49819565], [69.74013519, 21.49847221], [69.73986816, 21.49847031], [69.73986816, 21.49903107], [69.73958588, 21.49903107], [69.73958588, 21.49930954], [69.73930359, 21.49930763], [69.73930359, 21.4995842], [69.73902893, 21.49958038], [69.73902893, 21.49986076], [69.73874664, 21.49986076], [69.73874664, 21.50013924], [69.73847198, 21.5001297], [69.73847198, 21.50041962], [69.73819733, 21.50041771], [69.73819733, 21.50069427], [69.73791504, 21.50069427], [69.73791504, 21.50097275], [69.73764038, 21.50097084], [69.73764038, 21.50152969], [69.73735809, 21.50152969], [69.73735809, 21.50180817], [69.73708344, 21.50180626], [69.73708344, 21.50208282], [69.73680878, 21.50208282], [69.73680878, 21.5023613], [69.73652649, 21.50235939], [69.73652649, 21.50291824], [69.73625183, 21.50291634], [69.73625183, 21.50319481], [69.73596954, 21.50319481], [69.73596954, 21.50347137], [69.73568726, 21.50346756], [69.73568726, 21.50374985], [69.73542023, 21.50374985], [69.73542023, 21.50402832], [69.73513794, 21.50402832], [69.73513794, 21.50458336], [69.73486328, 21.50458336], [69.73486328, 21.50486183], [69.73458099, 21.50486183], [69.73458099, 21.5051403], [69.73430634, 21.5051403], [69.73430634, 21.50542259], [69.73402405, 21.50541687], [69.73402405, 21.50597191], [69.73374176, 21.50597191], [69.73374176, 21.50625992], [69.7334671, 21.50625992], [69.7334671, 21.50653267], [69.73319244, 21.50653267], [69.73319244, 21.50681114], [69.73291779, 21.50681114], [69.73291779, 21.50736046], [69.73236084, 21.50736046], [69.73236084, 21.50764275], [69.73208618, 21.50763893], [69.73208618, 21.50819206], [69.73179626, 21.50819016], [69.73179626, 21.50875282], [69.73152924, 21.50875282], [69.73152924, 21.50902939], [69.73124695, 21.50902939], [69.73124695, 21.50932121], [69.73097229, 21.50930405], [69.73097229, 21.50958252], [69.73069763, 21.50958061], [69.73069763, 21.50986099], [69.73041534, 21.50986099], [69.73042297, 21.51013947], [69.7298584, 21.51013947], [69.7298584, 21.51097488], [69.72957611, 21.51097107], [69.72957611, 21.51124954], [69.72930908, 21.51124954], [69.72930908, 21.5118103], [69.72902679, 21.51180649], [69.72902679, 21.51208305], [69.72875214, 21.51208305], [69.72875214, 21.51236153], [69.72846985, 21.51235962], [69.72846985, 21.51264], [69.72820282, 21.51264], [69.72820282, 21.51292038], [69.7279129, 21.51292038], [69.7279129, 21.51320076], [69.72763824, 21.51319695], [69.72763824, 21.5134716], [69.72735596, 21.5134697], [69.72735596, 21.51375008], [69.7270813, 21.51375008], [69.7270813, 21.51403046], [69.72680664, 21.51403046], [69.72680664, 21.51431084], [69.72652435, 21.51430511], [69.72652435, 21.51458359], [69.72624969, 21.51458359], [69.72624969, 21.51486206], [69.72597504, 21.51486206], [69.72597504, 21.51513863], [69.72569275, 21.515131], [69.72569275, 21.51542091], [69.72541809, 21.5154171], [69.72541809, 21.51569366], [69.7251358, 21.51569366], [69.7251358, 21.51597214], [69.72486115, 21.51597023], [69.72486115, 21.51625061], [69.72458649, 21.51625061], [69.72458649, 21.51652908], [69.72429657, 21.51652908], [69.72429657, 21.51681137], [69.72402954, 21.51680565], [69.72402954, 21.51708412], [69.72319794, 21.5170784], [69.72319794, 21.51791954], [69.72292328, 21.51791954], [69.72292328, 21.51820183], [69.72264099, 21.5181942], [69.72264099, 21.51847267], [69.7223587, 21.51847076], [69.7223587, 21.51874924], [69.72207642, 21.51874924], [69.72207642, 21.5193119], [69.72180939, 21.51930618], [69.72180176, 21.51958275], [69.7215271, 21.51958275], [69.7215271, 21.51986122], [69.72125244, 21.51986122], [69.72125244, 21.52013969], [69.72097015, 21.52013969], [69.72097015, 21.52042007], [69.7206955, 21.52041626], [69.7206955, 21.52069473], [69.72041321, 21.52069473], [69.72041321, 21.5209713], [69.72013855, 21.52096939], [69.72013855, 21.52126122], [69.71985626, 21.52126122], [69.71985626, 21.52153015], [69.7195816, 21.52152824], [69.7195816, 21.52180481], [69.71930695, 21.52180481], [69.71930695, 21.52208138], [69.71902466, 21.52208138], [69.71902466, 21.52236366], [69.71875763, 21.52235985], [69.71875763, 21.52264023], [69.71848297, 21.52264023], [69.71848297, 21.52292061], [69.71819305, 21.52292061], [69.71819305, 21.52320099], [69.7179184, 21.52319336], [69.7179184, 21.52347183], [69.71763611, 21.52346992], [69.71763611, 21.52375031], [69.71736145, 21.52375031], [69.71736145, 21.52403069], [69.71708679, 21.52402687], [69.71708679, 21.52430344], [69.71652985, 21.52430344], [69.71652985, 21.52458572], [69.71624756, 21.52458], [69.71624756, 21.52514076], [69.7159729, 21.52514076], [69.7159729, 21.52542114], [69.71569824, 21.52541733], [69.71569824, 21.5256958], [69.71541595, 21.5256958], [69.71541595, 21.52597237], [69.7151413, 21.52597046], [69.7151413, 21.52625084], [69.71485901, 21.52625084], [69.71485901, 21.52680969], [69.71458435, 21.52680779], [69.71458435, 21.52708244], [69.71430206, 21.527071], [69.71430206, 21.52736092], [69.7140274, 21.52736092], [69.7140274, 21.52763939], [69.71375275, 21.52763939], [69.71375275, 21.52791977], [69.71347046, 21.52791786], [69.71347046, 21.52819443], [69.7131958, 21.52819443], [69.7131958, 21.5284729], [69.71290588, 21.52847099], [69.71290588, 21.52902985], [69.71263885, 21.52902985], [69.71263885, 21.52930832], [69.7123642, 21.52930641], [69.7123642, 21.52986145], [69.71208191, 21.52985954], [69.71208191, 21.5304184], [69.71180725, 21.53041649], [69.71180725, 21.53097153], [69.71152496, 21.53097153], [69.71153259, 21.53124809], [69.71125031, 21.53124809], [69.71125031, 21.53208351], [69.71097565, 21.53208351], [69.71097565, 21.53236008], [69.71153259, 21.53236008], [69.71153259, 21.53264046], [69.71180725, 21.53264046], [69.71180725, 21.53292274], [69.71208191, 21.53292274], [69.71208191, 21.53320122], [69.7123642, 21.53319359], [69.7123642, 21.53347015], [69.71291351, 21.53347015], [69.71291351, 21.53319359], [69.71347046, 21.53319359], [69.71347046, 21.53347015], [69.71375275, 21.53347015], [69.71375275, 21.53375053], [69.71485901, 21.53375053], [69.71485901, 21.53403282], [69.71541595, 21.53403282], [69.71541595, 21.53430939], [69.7159729, 21.53430557], [69.7159729, 21.53458214], [69.71708679, 21.53458023], [69.71708679, 21.5351429], [69.71819305, 21.5351429], [69.71819305, 21.53541946], [69.71930695, 21.53541756], [69.71930695, 21.53569221], [69.71971893, 21.53569221], [69.71986389, 21.53569221], [69.71986389, 21.5359745], [69.72041321, 21.5359745], [69.72041321, 21.53624916], [69.72070313, 21.53623962], [69.72070313, 21.53680992], [69.72097015, 21.53680992], [69.72097015, 21.53763962], [69.72125244, 21.53763962], [69.72125244, 21.53792], [69.7215271, 21.53792], [69.7215271, 21.53903008], [69.72208405, 21.53902817], [69.72208405, 21.53958321], [69.7223587, 21.53957939], [69.7223587, 21.54070091], [69.72291565, 21.54069519], [69.72291565, 21.54125023], [69.7234726, 21.54125023], [69.7234726, 21.54180908], [69.7251358, 21.54180527], [69.7251358, 21.54208374], [69.72541809, 21.54208374], [69.72541809, 21.54180527], [69.72597504, 21.54180527], [69.72597504, 21.54208374], [69.72624969, 21.54208374], [69.72624969, 21.54180527], [69.7270813, 21.54180908], [69.7270813, 21.54153061], [69.72875214, 21.54153061], [69.72875214, 21.54180908], [69.72902679, 21.54180527], [69.72902679, 21.54208374], [69.72957611, 21.54207993], [69.72957611, 21.54291916], [69.72930908, 21.54291916], [69.72930908, 21.54431152], [69.72902679, 21.54431152], [69.72902679, 21.54486084], [69.72875214, 21.54486084], [69.72875214, 21.54569435], [69.72846985, 21.54568863], [69.72846985, 21.54652977], [69.72819519, 21.54652786], [69.72819519, 21.5470829], [69.7279129, 21.5470829], [69.7279129, 21.54792023], [69.72763824, 21.54792023], [69.72763824, 21.54874992], [69.72736359, 21.54874992], [69.72736359, 21.54958534], [69.7270813, 21.54958534], [69.7270813, 21.5506897], [69.72680664, 21.55070114], [69.72680664, 21.55153084], [69.72651672, 21.55153084], [69.72651672, 21.55264091], [69.72624969, 21.55263901], [69.72624969, 21.55347252], [69.72597504, 21.55347252], [69.72597504, 21.5545826], [69.72569275, 21.55458069], [69.72569275, 21.55541992], [69.72597504, 21.55541611], [69.72597504, 21.55569458], [69.72651672, 21.55569077], [69.72651672, 21.55652809], [69.7270813, 21.55652809], [69.7270813, 21.55680466], [69.72736359, 21.55680466], [69.72736359, 21.55708313], [69.7279129, 21.55708122], [69.7279129, 21.55736923], [69.72820282, 21.55736923], [69.72820282, 21.55792236], [69.72875214, 21.55791664], [69.72875214, 21.55847168], [69.72930908, 21.55847168], [69.72930908, 21.55875015], [69.72957611, 21.55875015], [69.72957611, 21.55903244], [69.73042297, 21.55903244], [69.73042297, 21.55931282], [69.73124695, 21.55930519], [69.73124695, 21.55958366], [69.73152924, 21.55958176], [69.73152924, 21.55986023], [69.73179626, 21.55986023], [69.73179626, 21.56014061], [69.73208618, 21.56014061], [69.73208618, 21.56043053], [69.73319244, 21.56041718], [69.73319244, 21.56069374], [69.73347473, 21.56069374], [69.73347473, 21.56097221], [69.73401642, 21.56097031], [69.73401642, 21.56125069], [69.73458099, 21.56125069], [69.73458099, 21.56153107], [69.73513794, 21.56153107], [69.73513794, 21.56125069], [69.73568726, 21.56125069], [69.73568726, 21.56180954], [69.73596954, 21.56180573], [69.73596954, 21.56208229], [69.73735809, 21.56208038], [69.73735809, 21.56236076], [69.73764038, 21.56236076], [69.73764038, 21.56208038], [69.73819733, 21.56208038], [69.73819733, 21.56236076], [69.73929596, 21.56236076], [69.73929596, 21.56208038], [69.74013519, 21.56208229], [69.74013519, 21.56180573], [69.7409668, 21.56180954], [69.7409668, 21.56153107], [69.74180603, 21.56153107], [69.74180603, 21.56180954], [69.74263763, 21.56180573], [69.74263763, 21.56208229], [69.74318695, 21.56208038], [69.74318695, 21.56236076], [69.74346924, 21.56236076], [69.74346924, 21.56208038], [69.74401855, 21.56215477], [69.74402618, 21.56236076], [69.74485779, 21.56236076], [69.74485779, 21.56264114], [69.7454071, 21.56264114], [69.7454071, 21.56236076], [69.74652863, 21.56236076], [69.74652863, 21.56208038], [69.74736023, 21.56208229], [69.74736023, 21.56180573], [69.7470932, 21.56180954], [69.7470932, 21.56153107], [69.74764252, 21.56153107], [69.74764252, 21.56125069], [69.74819183, 21.56125069], [69.74819183, 21.56153107], [69.74874115, 21.56153107], [69.74874115, 21.56125069], [69.74931335, 21.56125069], [69.74931335, 21.56153107], [69.74958038, 21.56153107], [69.74958038, 21.56180954], [69.74986267, 21.56180573], [69.74986267, 21.56208229], [69.75013733, 21.56208038], [69.75013733, 21.56236076], [69.75041962, 21.56236076], [69.75041962, 21.56264114], [69.75068665, 21.56264114], [69.75068665, 21.56291962], [69.75096893, 21.5629158], [69.75096893, 21.56319237], [69.75125122, 21.56318283], [69.75125122, 21.56431007], [69.75096893, 21.56430435], [69.75096893, 21.56458473], [69.75069427, 21.56458473], [69.75069427, 21.5648613], [69.75013733, 21.56485939], [69.75013733, 21.56542015], [69.74986267, 21.56541443], [69.74986267, 21.56569672], [69.74958038, 21.56569672], [69.74958038, 21.56680679], [69.74930573, 21.56680679], [69.74930573, 21.56708336], [69.74903107, 21.56707954], [69.74903107, 21.56792068], [69.74874115, 21.56792068], [69.74874115, 21.56903076], [69.74819183, 21.56903076], [69.74819183, 21.56930923], [69.74791718, 21.56930923], [69.74791718, 21.56986046], [69.74764252, 21.56986046], [69.74764252, 21.57014084], [69.74736023, 21.57014084], [69.74736023, 21.57097244], [69.74708557, 21.57097244], [69.74708557, 21.57125092], [69.74736023, 21.57125092], [69.74736023, 21.57152939], [69.7470932, 21.57152939], [69.7470932, 21.57292175], [69.74736023, 21.57291603], [69.74736023, 21.57347107], [69.74764252, 21.57347107], [69.74764252, 21.57403183], [69.74791718, 21.57402802], [69.74791718, 21.57486153], [69.74847412, 21.57486153], [69.74847412, 21.57458115], [69.74874878, 21.57458115], [69.74874878, 21.57402802], [69.74903107, 21.57403183], [69.74903107, 21.57347107], [69.74930573, 21.57347107], [69.74930573, 21.5731945], [69.75096893, 21.5731945], [69.75096893, 21.57347107], [69.75152588, 21.57347107], [69.75152588, 21.57625008], [69.75180817, 21.57625008], [69.75180817, 21.57653046], [69.75208282, 21.57653046], [69.75208282, 21.57681084], [69.75235748, 21.57680321], [69.75235748, 21.57708549], [69.75263977, 21.57707977], [69.75263977, 21.57736015], [69.75347137, 21.57736015], [69.75347137, 21.57764053], [69.75430298, 21.57764053], [69.75430298, 21.57792091], [69.75624847, 21.57792091], [69.75624847, 21.57764053], [69.75653076, 21.57764053], [69.75653076, 21.57736015], [69.75708008, 21.57736015], [69.75708008, 21.57707977], [69.75818634, 21.57707977], [69.75818634, 21.57792091], [69.75846863, 21.57792091], [69.75846863, 21.57903099], [69.75875092, 21.57903099], [69.75875092, 21.57930946], [69.75930786, 21.57930756], [69.75930786, 21.57958412], [69.75958252, 21.57958412], [69.75958252, 21.57930756], [69.75985718, 21.57930946], [69.75985718, 21.57903099], [69.76013947, 21.57903099], [69.76013947, 21.57930946], [69.76125336, 21.57930756], [69.76125336, 21.57958412], [69.76208496, 21.57958412], [69.76208496, 21.57930756], [69.76235962, 21.57930946], [69.76235962, 21.57903099], [69.76264191, 21.57903099], [69.76264191, 21.57875061], [69.76291656, 21.57875061], [69.76291656, 21.57847023], [69.76403046, 21.57847214], [69.76403046, 21.57875061], [69.76431274, 21.57875061], [69.76431274, 21.58014107], [69.76403046, 21.58013916], [69.76403046, 21.58208275], [69.76374817, 21.58208084], [69.76374817, 21.58402824], [69.76403046, 21.58402824], [69.76403046, 21.58458328], [69.76431274, 21.58457756], [69.76431274, 21.58514023], [69.76457977, 21.58514023], [69.76457977, 21.58625031], [69.76486206, 21.58625031], [69.76486206, 21.58903122], [69.76431274, 21.58903122], [69.76431274, 21.58930969], [69.76374817, 21.58930969], [69.76374817, 21.59013939], [69.76347351, 21.59013939], [69.76347351, 21.59208488], [69.76374817, 21.59208107], [69.76374817, 21.59375], [69.76403046, 21.59375], [69.76403046, 21.59486198], [69.76374817, 21.59486198], [69.76374817, 21.59597206], [69.76347351, 21.59597206], [69.76347351, 21.59569359], [69.76235962, 21.59569359], [69.76235962, 21.59597206], [69.76125336, 21.59597206], [69.76125336, 21.59569359], [69.75958252, 21.59569359], [69.75958252, 21.59541893], [69.7590332, 21.59542084], [69.7590332, 21.59514046], [69.75818634, 21.59514046], [69.75818634, 21.59431076], [69.75763702, 21.59431076], [69.75763702, 21.59375], [69.75791168, 21.59375], [69.75791168, 21.59263992], [69.75708008, 21.59263992], [69.75708008, 21.5929203], [69.75681305, 21.5929203], [69.75681305, 21.59320068], [69.75653076, 21.59320068], [69.75653076, 21.59348106], [69.75681305, 21.59348106], [69.75681305, 21.59403038], [69.75653076, 21.59403038], [69.75653076, 21.59375], [69.75624847, 21.59375], [69.75624847, 21.59348106], [69.75596619, 21.59348106], [69.75596619, 21.59375], [69.75569153, 21.59375], [69.75569153, 21.59431076], [69.75597382, 21.59430695], [69.75597382, 21.59458351], [69.75569153, 21.5945797], [69.75569153, 21.59542084], [69.75624847, 21.59541893], [69.75624847, 21.59569359], [69.75597382, 21.59569359], [69.75597382, 21.59819412], [69.75569153, 21.5981884], [69.75569153, 21.59902954], [69.75541687, 21.59902954], [69.75541687, 21.59931183], [69.75569153, 21.59931183], [69.75569153, 21.60013962], [69.75514221, 21.60013962], [69.75514221, 21.60042191], [69.75541687, 21.60042191], [69.75541687, 21.60153008], [69.75569153, 21.60152817], [69.75569153, 21.60569572], [69.75541687, 21.60569572], [69.75541687, 21.60708427], [69.75430298, 21.60708046], [69.75430298, 21.60736084], [69.75402832, 21.60736084], [69.75402832, 21.60764122], [69.75374603, 21.60764122], [69.75374603, 21.60791969], [69.75347137, 21.60791779], [69.75347137, 21.60819435], [69.75319672, 21.60819054], [69.75319672, 21.60848045], [69.75235748, 21.60848045], [69.75235748, 21.60874939], [69.75180817, 21.60874939], [69.75180817, 21.60902977], [69.75208282, 21.60902977], [69.75208282, 21.6095829], [69.75180817, 21.6095829], [69.75180817, 21.60986137], [69.75152588, 21.60985947], [69.75152588, 21.61013985], [69.75096893, 21.61013985], [69.75096893, 21.61041832], [69.75069427, 21.61041641], [69.75069427, 21.61208344], [69.75096893, 21.61208344], [69.75096893, 21.6131916], [69.75013733, 21.61319542], [69.75013733, 21.61347008], [69.74958038, 21.61347008], [69.74958038, 21.61431122], [69.74986267, 21.61431122], [69.74986267, 21.61680984], [69.75013733, 21.61680412], [69.75013733, 21.6170826], [69.75041962, 21.61708069], [69.75041962, 21.61736107], [69.75096893, 21.61736107], [69.75096893, 21.61765099], [69.75125122, 21.61765099], [69.75125122, 21.61791992], [69.75152588, 21.6179142], [69.75152588, 21.61819649], [69.75180817, 21.61819649], [69.75180817, 21.61847305], [69.75152588, 21.61847115], [69.75152588, 21.61874962], [69.75068665, 21.61874962], [69.75068665, 21.61847115], [69.75013733, 21.61847305], [69.75013733, 21.61819649], [69.74986267, 21.61819649], [69.74986267, 21.61763954], [69.74958038, 21.61763954], [69.74958038, 21.61819649], [69.74930573, 21.61819649], [69.74930573, 21.61847305], [69.74903107, 21.61847115], [69.74903107, 21.61874962], [69.74846649, 21.61874962], [69.74846649, 21.61903], [69.74819183, 21.61902618], [69.74819183, 21.61930656], [69.74791718, 21.61930656], [69.74791718, 21.6198616], [69.74764252, 21.6198597], [69.74764252, 21.62042046], [69.74736023, 21.62041855], [69.74736023, 21.62097168], [69.7470932, 21.62096977], [69.7470932, 21.62153053], [69.74680328, 21.62152863], [69.74680328, 21.62208366], [69.74652863, 21.62207985], [69.74652863, 21.62291908], [69.74624634, 21.62291908], [69.74624634, 21.62375069], [69.74597168, 21.62375069], [69.74597168, 21.62431145], [69.74569702, 21.62431145], [69.74569702, 21.62513924], [69.74541473, 21.62513924], [69.74541473, 21.6273613], [69.74569702, 21.6273613], [69.74569702, 21.63097191], [69.7454071, 21.63097], [69.7454071, 21.63265038], [69.74514008, 21.63263893], [69.74514008, 21.63319588], [69.74485779, 21.63319016], [69.74485779, 21.63375092], [69.74458313, 21.63375092], [69.74458313, 21.63430977], [69.74430847, 21.63430977], [69.74430847, 21.63486099], [69.74402618, 21.63486099], [69.74402618, 21.63541985], [69.74375153, 21.63541794], [69.74375153, 21.63597298], [69.74346924, 21.63597107], [69.74346924, 21.63624954], [69.74318695, 21.63624954], [69.74318695, 21.63652992], [69.74291992, 21.63652992], [69.74291992, 21.63708305], [69.74263763, 21.63708305], [69.74263763, 21.63736153], [69.74236298, 21.63735962], [69.74236298, 21.63763809], [69.74208069, 21.63763809], [69.74208069, 21.63820267], [69.74180603, 21.63819504], [69.74180603, 21.6384716], [69.74153137, 21.63845825], [69.74153137, 21.63875008], [69.74124908, 21.63875008], [69.74124908, 21.63903046], [69.7409668, 21.63903046], [69.7409668, 21.63931274], [69.74069214, 21.63930511], [69.74069214, 21.63958359], [69.73902893, 21.63958359], [69.73902893, 21.63930511], [69.73764038, 21.63930511], [69.73764038, 21.63986015], [69.73735809, 21.63986015], [69.73735809, 21.64042282], [69.73708344, 21.6404171], [69.73708344, 21.64208221], [69.73680878, 21.64208221], [69.73680878, 21.64347458], [69.73707581, 21.64347076], [69.73707581, 21.64375114], [69.73764038, 21.64375114], [69.73764038, 21.64347076], [69.73792267, 21.64347076], [69.73792267, 21.64402962], [69.73735809, 21.64402962], [69.73735809, 21.64459038], [69.73708344, 21.64458275], [69.73708344, 21.6459713], [69.73680878, 21.6459713], [69.73680878, 21.64736176], [69.73707581, 21.64735985], [69.73707581, 21.64792061], [69.73735809, 21.6479187], [69.73735809, 21.64847183], [69.73764038, 21.64846992], [69.73764038, 21.65041924], [69.73680878, 21.65041733], [69.73680878, 21.65069389], [69.73625183, 21.65069389], [69.73625183, 21.65097237], [69.73569489, 21.65097237], [69.73569489, 21.65069389], [69.73430634, 21.65069389], [69.73430634, 21.64986038], [69.73401642, 21.64986038], [69.73401642, 21.64930916], [69.73430634, 21.64930916], [69.73430634, 21.64875031], [69.73458099, 21.64875031], [69.73458099, 21.64819908], [69.73513794, 21.64819908], [69.73513794, 21.64764977], [69.73486328, 21.64764977], [69.73486328, 21.64735985], [69.73458099, 21.64736176], [69.73458099, 21.64680672], [69.73430634, 21.64680672], [69.73430634, 21.64652824], [69.73401642, 21.64653015], [69.73401642, 21.64624977], [69.73374176, 21.64624977], [69.73374176, 21.64596939], [69.73347473, 21.6459713], [69.73347473, 21.64569664], [69.73319244, 21.64569664], [69.73319244, 21.64541435], [69.73264313, 21.64542007], [69.73264313, 21.64513969], [69.73236084, 21.64513969], [69.73236084, 21.64431], [69.73208618, 21.64431], [69.73208618, 21.64319038], [69.73152924, 21.64319229], [69.73152924, 21.64291573], [69.73179626, 21.64291954], [69.73179626, 21.64236069], [69.73152924, 21.64236069], [69.73152924, 21.6415329], [69.73124695, 21.6415329], [69.73124695, 21.64125061], [69.73069763, 21.64125061], [69.73069763, 21.64097023], [69.73041534, 21.64097023], [69.73041534, 21.64069366], [69.72958374, 21.64069366], [69.72958374, 21.64097023], [69.72902679, 21.64097023], [69.72902679, 21.64125061], [69.72820282, 21.64125061], [69.72820282, 21.6415329], [69.72763824, 21.6415329], [69.72763824, 21.64180946], [69.72680664, 21.64180946], [69.72680664, 21.6415329], [69.72651672, 21.6415329], [69.72651672, 21.64069176], [69.72680664, 21.64069366], [69.72680664, 21.63986015], [69.7270813, 21.63986015], [69.7270813, 21.63931274], [69.72735596, 21.63931274], [69.72735596, 21.63845825], [69.72763824, 21.6384716], [69.72763824, 21.63819504], [69.72820282, 21.63820267], [69.72820282, 21.63791847], [69.7298584, 21.63791847], [69.7298584, 21.63763809], [69.73014069, 21.63763809], [69.73014069, 21.63735962], [69.73041534, 21.63736153], [69.73041534, 21.63708305], [69.73069763, 21.63708305], [69.73069763, 21.63652992], [69.73014069, 21.63652992], [69.73014069, 21.63597107], [69.7298584, 21.63597298], [69.7298584, 21.6356945], [69.72930908, 21.6356945], [69.72930908, 21.63541794], [69.72902679, 21.63541985], [69.72902679, 21.63402939], [69.72846985, 21.63402939], [69.72846985, 21.63375092], [69.72819519, 21.63375092], [69.72819519, 21.63347244], [69.7279129, 21.63347244], [69.7279129, 21.63319588], [69.7270813, 21.63319588], [69.7270813, 21.6329174], [69.72624969, 21.63292122], [69.72624969, 21.63265038], [69.72541809, 21.63265038], [69.72541809, 21.63236046], [69.72458649, 21.63236046], [69.72458649, 21.63265038], [69.72429657, 21.63265038], [69.72429657, 21.63292122], [69.72402954, 21.6329174], [69.72402954, 21.63319588], [69.72374725, 21.63319588], [69.72374725, 21.63347244], [69.7234726, 21.63347054], [69.7234726, 21.63375092], [69.72319794, 21.63375092], [69.72319794, 21.63402939], [69.72292328, 21.63402939], [69.72292328, 21.63430977], [69.7223587, 21.63430786], [69.7223587, 21.63458252], [69.72180176, 21.63458061], [69.72180176, 21.63486099], [69.7215271, 21.63486099], [69.7215271, 21.63513947], [69.72097015, 21.63513947], [69.72097015, 21.63541985], [69.72013855, 21.63541794], [69.72013855, 21.6356945], [69.7195816, 21.6356945], [69.7195816, 21.63597298], [69.71875, 21.63597298], [69.71875763, 21.63624954], [69.71819305, 21.63624954], [69.71819305, 21.6368084], [69.7179184, 21.6368084], [69.7179184, 21.63763809], [69.71819305, 21.63763809], [69.71819305, 21.63903046], [69.7179184, 21.63902855], [69.7179184, 21.63986015], [69.71736145, 21.63986015], [69.71736145, 21.64014053], [69.71485901, 21.64014053], [69.71485901, 21.63986015], [69.71458435, 21.63986015], [69.71458435, 21.63819504], [69.71485901, 21.63820267], [69.71485901, 21.6368084], [69.7151413, 21.63680077], [69.7151413, 21.63624954], [69.71541595, 21.63624954], [69.71541595, 21.63597107], [69.71569061, 21.63597298], [69.71569824, 21.63541794], [69.7159729, 21.63541985], [69.7159729, 21.63513947], [69.71736145, 21.63513947], [69.71736145, 21.63319016], [69.71708679, 21.63319588], [69.71708679, 21.6329174], [69.71679688, 21.63292122], [69.71679688, 21.63265038], [69.71652985, 21.63265038], [69.71652985, 21.63236046], [69.71457672, 21.63236046], [69.71457672, 21.63208008], [69.71347046, 21.63208008], [69.71347046, 21.63292122], [69.71375275, 21.63292122], [69.71375275, 21.63402939], [69.71347046, 21.63402939], [69.71347046, 21.63430977], [69.7131958, 21.63430977], [69.7131958, 21.63486099], [69.71347046, 21.63486099], [69.71347046, 21.63513947], [69.7131958, 21.63513947], [69.7131958, 21.63541985], [69.71291351, 21.63541794], [69.71291351, 21.6356945], [69.71263885, 21.63569069], [69.71263885, 21.63624954], [69.71235657, 21.63624954], [69.71235657, 21.6368084], [69.71208191, 21.63680649], [69.71208191, 21.63708305], [69.71180725, 21.63708115], [69.71180725, 21.63763809], [69.70986176, 21.63763809], [69.70986176, 21.63735962], [69.7095871, 21.63736153], [69.7095871, 21.63708305], [69.70929718, 21.63708115], [69.70929718, 21.63791847], [69.70903015, 21.63791847], [69.70903015, 21.63820267], [69.70929718, 21.63820267], [69.70929718, 21.63903046], [69.7095871, 21.63903046], [69.7095871, 21.63875008], [69.70986176, 21.63875008], [69.70986176, 21.63986015], [69.7095871, 21.63986015], [69.7095871, 21.64014053], [69.70986176, 21.64014053], [69.70986176, 21.64042282], [69.7095871, 21.6404171], [69.7095871, 21.64069366], [69.70874786, 21.64069176], [69.70874786, 21.6415329], [69.70680237, 21.64152718], [69.70680237, 21.64319229], [69.7076416, 21.64319229], [69.7076416, 21.64347458], [69.70819092, 21.64347076], [69.70819092, 21.64375114], [69.70847321, 21.64375114], [69.70847321, 21.64431], [69.70791626, 21.64431], [69.70791626, 21.64459038], [69.70735931, 21.64459038], [69.70735931, 21.64513969], [69.70708466, 21.64513969], [69.70708466, 21.64569664], [69.70680237, 21.64569092], [69.70680237, 21.64624977], [69.70625305, 21.64624977], [69.70625305, 21.64653015], [69.70597076, 21.64652824], [69.70597076, 21.64680672], [69.70541382, 21.64680672], [69.70541382, 21.64708328], [69.70513916, 21.64708328], [69.70513916, 21.64736176], [69.70375061, 21.64736176], [69.70375061, 21.64708328], [69.70347595, 21.64708328], [69.70347595, 21.64680672], [69.70319366, 21.64680672], [69.70319366, 21.64652824], [69.70291901, 21.64653015], [69.70291901, 21.64624977], [69.70263672, 21.64624977], [69.70263672, 21.64596939], [69.70207977, 21.6459713], [69.70207977, 21.64569664], [69.70124817, 21.64569664], [69.70124817, 21.64541435], [69.70069885, 21.64542007], [69.70069885, 21.64513969], [69.69985962, 21.64513969], [69.69985962, 21.64486122], [69.69875336, 21.64486122], [69.69875336, 21.64459038], [69.69819641, 21.64459038], [69.69819641, 21.64431], [69.69763184, 21.64431], [69.69763184, 21.64402962], [69.69735718, 21.64402962], [69.69735718, 21.64347076], [69.69708252, 21.64347458], [69.69708252, 21.64319229], [69.69680786, 21.64319229], [69.69680786, 21.64263916], [69.6965332, 21.64264107], [69.6965332, 21.64236069], [69.69625092, 21.64236069], [69.69625092, 21.64208031], [69.69569397, 21.64208221], [69.69569397, 21.64152718], [69.69541931, 21.6415329], [69.69541931, 21.64097023], [69.69569397, 21.64097023], [69.69569397, 21.64069366], [69.69625092, 21.64069366], [69.69625092, 21.6404171], [69.6965332, 21.64042282], [69.6965332, 21.63986015], [69.69625092, 21.63986015], [69.69625092, 21.63958359], [69.69403076, 21.63958359], [69.69403076, 21.63930511], [69.69374847, 21.63931274], [69.69374847, 21.63903046], [69.69346619, 21.63903046], [69.69346619, 21.63875008], [69.69235992, 21.63875008], [69.69235992, 21.63903046], [69.6920929, 21.63903046], [69.6920929, 21.64042282], [69.6904068, 21.64042282], [69.6904068, 21.64014053], [69.69013977, 21.64014053], [69.69013977, 21.63986015], [69.68985748, 21.63986015], [69.68985748, 21.63958359], [69.68958282, 21.63958359], [69.68958282, 21.63930511], [69.68930817, 21.63931274], [69.68930817, 21.63903046], [69.68875885, 21.63903046], [69.68875885, 21.63875008], [69.68791962, 21.63875008], [69.68791962, 21.63845825], [69.68763733, 21.6384716], [69.68763733, 21.63791656], [69.68736267, 21.63791847], [69.68736267, 21.63763809], [69.68708038, 21.63763809], [69.68708038, 21.63735962], [69.68680573, 21.63736153], [69.68680573, 21.63708305], [69.68653107, 21.63708305], [69.68653107, 21.63680649], [69.68624878, 21.6368084], [69.68624878, 21.63652992], [69.68319702, 21.63652992], [69.68319702, 21.63624954], [69.68208313, 21.63624954], [69.68208313, 21.63569069], [69.68152618, 21.6356945], [69.68152618, 21.63597298], [69.68068695, 21.63597107], [69.68068695, 21.63624954], [69.68013763, 21.63624954], [69.68013763, 21.6368084], [69.67986298, 21.63680649], [69.67986298, 21.63736153], [69.67958832, 21.63735962], [69.67958832, 21.63791847], [69.67930603, 21.63791847], [69.67930603, 21.63820267], [69.67903137, 21.63819504], [69.67903137, 21.6384716], [69.6784668, 21.63845825], [69.6784668, 21.63875008], [69.67819214, 21.63875008], [69.67819214, 21.63903046], [69.67791748, 21.63903046], [69.67791748, 21.63931274], [69.67652893, 21.63931274], [69.67652893, 21.63845825], [69.67624664, 21.63845825], [69.67624664, 21.63875008], [69.67569733, 21.63875008], [69.67569733, 21.63845825], [69.67597198, 21.6384716], [69.67597198, 21.63819504], [69.67652893, 21.63820267], [69.67652893, 21.63791847], [69.67679596, 21.63791847], [69.67679596, 21.63763809], [69.67708588, 21.63763809], [69.67708588, 21.63708115], [69.67736053, 21.63708305], [69.67736053, 21.63680649], [69.67791748, 21.63680077], [69.67791748, 21.63652992], [69.6784668, 21.63652992], [69.6784668, 21.63597107], [69.67874908, 21.63597298], [69.67874908, 21.63513947], [69.67903137, 21.63513947], [69.67903137, 21.6356945], [69.67930603, 21.6356945], [69.67930603, 21.63541794], [69.67958832, 21.63541985], [69.67958832, 21.63513947], [69.67986298, 21.63513947], [69.67986298, 21.63458061], [69.68013763, 21.63458252], [69.68013763, 21.63430786], [69.68041992, 21.63430977], [69.68041992, 21.63402939], [69.68096924, 21.63402939], [69.68096924, 21.63375092], [69.68125153, 21.63375092], [69.68125153, 21.63347054], [69.68180847, 21.63347244], [69.68180847, 21.63319588], [69.68208313, 21.63319588], [69.68208313, 21.6329174], [69.68235779, 21.63292122], [69.68235779, 21.63265038], [69.6829071, 21.63265038], [69.6829071, 21.63236046], [69.68319702, 21.63236046], [69.68319702, 21.63208008], [69.68347168, 21.6320858], [69.68347168, 21.63180351], [69.68402863, 21.63181114], [69.68402863, 21.63167953], [69.68402863, 21.63152695], [69.68430328, 21.63153076], [69.68430328, 21.63125038], [69.68486023, 21.63125038], [69.68486023, 21.63097], [69.68541718, 21.63097191], [69.68541718, 21.63069344], [69.68596649, 21.63070107], [69.68596649, 21.63042068], [69.68653107, 21.63042068], [69.68653107, 21.6301403], [69.68763733, 21.6301403], [69.68763733, 21.62985992], [69.68875122, 21.62986374], [69.68875122, 21.62958336], [69.69152832, 21.62959099], [69.69152832, 21.62930107], [69.69180298, 21.62930489], [69.69180298, 21.62902832], [69.6920929, 21.62903023], [69.6920929, 21.62846947], [69.69235992, 21.62847137], [69.69235992, 21.62819481], [69.69264221, 21.62819481], [69.69264221, 21.62791634], [69.69291687, 21.62792015], [69.69291687, 21.62735939], [69.69319153, 21.6273613], [69.69319153, 21.62708282], [69.69347382, 21.62708282], [69.69347382, 21.62652779], [69.69374847, 21.62652779], [69.69374847, 21.62597275], [69.69403076, 21.62597275], [69.69403076, 21.62569427], [69.69430542, 21.62569427], [69.69430542, 21.62513924], [69.69457245, 21.62513924], [69.69457245, 21.62486076], [69.69486237, 21.62486076], [69.69486237, 21.62431145], [69.69513702, 21.62431145], [69.69513702, 21.62346077], [69.69541931, 21.62347221], [69.69541931, 21.62319374], [69.69569397, 21.62319374], [69.69569397, 21.6226387], [69.69596863, 21.62264061], [69.69596863, 21.62236023], [69.69625092, 21.62236023], [69.69625092, 21.62207985], [69.69652557, 21.62208366], [69.69652557, 21.62152863], [69.69680786, 21.62153053], [69.69680786, 21.62125015], [69.69708252, 21.62125015], [69.69708252, 21.62096977], [69.69736481, 21.62097168], [69.69736481, 21.62041855], [69.69763184, 21.62042046], [69.69763184, 21.62014008], [69.69790649, 21.62014008], [69.69790649, 21.6198597], [69.69819641, 21.6198616], [69.69819641, 21.61930656], [69.69847107, 21.61930656], [69.69847107, 21.61902618], [69.69875336, 21.61903], [69.69875336, 21.61874962], [69.69902802, 21.61874962], [69.69902802, 21.61819077], [69.69930267, 21.61819649], [69.69930267, 21.6179142], [69.69957733, 21.61791992], [69.69957733, 21.61765099], [69.69985962, 21.61765099], [69.69985962, 21.61708069], [69.70014191, 21.6170826], [69.70014191, 21.61680412], [69.70041656, 21.61680984], [69.70041656, 21.61652946], [69.70096588, 21.61652946], [69.70096588, 21.6162529], [69.70153046, 21.6162529], [69.70153046, 21.61597061], [69.70207977, 21.61597252], [69.70207977, 21.61569214], [69.70291901, 21.61569214], [69.70291901, 21.61541748], [69.70347595, 21.61541939], [69.70347595, 21.61514282], [69.7040329, 21.61514282], [69.7040329, 21.61458015], [69.70430756, 21.61458206], [69.70430756, 21.61375046], [69.70458221, 21.61375046], [69.70458221, 21.6131916], [69.70513916, 21.61319351], [69.70513916, 21.61291695], [69.70540619, 21.61292267], [69.70540619, 21.61264038], [69.70597076, 21.61264038], [69.70597076, 21.61236191], [69.70625305, 21.61236191], [69.70625305, 21.61208344], [69.70680237, 21.61208344], [69.70680237, 21.61180496], [69.70707703, 21.61181259], [69.70707703, 21.61152077], [69.7076416, 21.6115284], [69.7076416, 21.61124992], [69.70847321, 21.61124992], [69.70847321, 21.61096764], [69.7095871, 21.61097145], [69.7095871, 21.61069489], [69.7104187, 21.61069489], [69.7104187, 21.61041641], [69.71069336, 21.61041832], [69.71069336, 21.61013985], [69.71153259, 21.61013985], [69.71153259, 21.60985947], [69.7123642, 21.60986137], [69.7123642, 21.60930634], [69.71290588, 21.60930824], [69.71290588, 21.60902977], [69.7131958, 21.60902977], [69.7131958, 21.60848045], [69.71347046, 21.60848045], [69.71347046, 21.60791969], [69.71375275, 21.60791969], [69.71375275, 21.60764122], [69.7140274, 21.60764122], [69.7140274, 21.60708046], [69.71430206, 21.60708237], [69.71430206, 21.60680771], [69.71457672, 21.60680962], [69.71457672, 21.60653114], [69.71485901, 21.60653114], [69.71485901, 21.60625076], [69.7151413, 21.60625076], [69.7151413, 21.60569], [69.71541595, 21.60569572], [69.71541595, 21.60541534], [69.71569824, 21.60542107], [69.71569824, 21.60514069], [69.7159729, 21.60514069], [69.7159729, 21.60486031], [69.71624756, 21.60486031], [69.71624756, 21.60431099], [69.71652985, 21.60431099], [69.71652985, 21.60375023], [69.71679688, 21.60375023], [69.71679688, 21.60320091], [69.71708679, 21.60320091], [69.71708679, 21.60264015], [69.71736145, 21.60264015], [69.71736145, 21.60207939], [69.71708679, 21.6020813], [69.71708679, 21.60124969], [69.71679688, 21.60124969], [69.71679688, 21.60042191], [69.71652985, 21.60042191], [69.71652985, 21.59958076], [69.71624756, 21.59958267], [69.71624756, 21.59902763], [69.71430206, 21.59902954], [69.71430206, 21.59931183], [69.7131958, 21.59930611], [69.7131958, 21.59958267], [69.71208191, 21.59958076], [69.71208191, 21.59986115], [69.71125031, 21.59986115], [69.71125031, 21.60013962], [69.7104187, 21.60013962], [69.7104187, 21.60042191], [69.7095871, 21.60041618], [69.7095871, 21.60069466], [69.70874786, 21.60069466], [69.70874786, 21.60097122], [69.70819092, 21.60097122], [69.70819092, 21.60124969], [69.70735931, 21.60124969], [69.70735931, 21.60153008], [69.70652771, 21.60152817], [69.70652771, 21.60180473], [69.70430756, 21.60180473], [69.70430756, 21.6020813], [69.70291901, 21.6020813], [69.70291901, 21.60180473], [69.70236206, 21.60180473], [69.70236206, 21.60152817], [69.70153046, 21.60153008], [69.70153046, 21.60097122], [69.70097351, 21.60097122], [69.70097351, 21.60041618], [69.70069885, 21.60042191], [69.70069885, 21.60013962], [69.70014191, 21.60013962], [69.70014191, 21.59986115], [69.69985962, 21.59986115], [69.69985962, 21.59958076], [69.69930267, 21.59958267], [69.69930267, 21.59930611], [69.69902802, 21.59931183], [69.69902802, 21.59874916], [69.69875336, 21.59874916], [69.69875336, 21.59763908], [69.69847107, 21.59763908], [69.69847107, 21.59680939], [69.69819641, 21.59680939], [69.69819641, 21.59486008], [69.69791412, 21.59486198], [69.69791412, 21.59347153], [69.69763184, 21.59348106], [69.69763184, 21.59320068], [69.69680786, 21.59320068], [69.69680786, 21.5929203], [69.69541931, 21.5929203], [69.69541931, 21.59320068], [69.69457245, 21.59320068], [69.69457245, 21.59348106], [69.69431305, 21.59348106], [69.69431305, 21.59403038], [69.69403076, 21.59403038], [69.69403076, 21.59431076], [69.69347382, 21.59430695], [69.69347382, 21.59486198], [69.69374847, 21.59486198], [69.69374847, 21.59569359], [69.69346619, 21.59568977], [69.69346619, 21.59625053], [69.69291687, 21.59625053], [69.69291687, 21.59654236], [69.69319153, 21.59654236], [69.69319153, 21.59680939], [69.69346619, 21.59680939], [69.69346619, 21.59736061], [69.69319153, 21.59736061], [69.69319153, 21.59763908], [69.69291687, 21.59763908], [69.69291687, 21.5984726], [69.69319153, 21.5984726], [69.69319153, 21.60236168], [69.69346619, 21.60235023], [69.69346619, 21.60292053], [69.69374847, 21.60291672], [69.69374847, 21.60347176], [69.69403076, 21.60346985], [69.69403076, 21.60375023], [69.69541931, 21.60375023], [69.69541931, 21.60346985], [69.69596863, 21.60347176], [69.69596863, 21.60319328], [69.6965332, 21.60320091], [69.6965332, 21.60292053], [69.69735718, 21.60292053], [69.69735718, 21.60264015], [69.69790649, 21.60264015], [69.69790649, 21.60207939], [69.69819641, 21.6020813], [69.69819641, 21.60097122], [69.69847107, 21.60097122], [69.69847107, 21.60041618], [69.69902802, 21.60041618], [69.69902802, 21.60069466], [69.69958496, 21.60069466], [69.69958496, 21.60097122], [69.69985962, 21.60097122], [69.69985962, 21.60124969], [69.70041656, 21.60124969], [69.70041656, 21.60153008], [69.70069122, 21.60152817], [69.70069122, 21.6020813], [69.70096588, 21.60207939], [69.70096588, 21.60264015], [69.70124817, 21.60264015], [69.70124817, 21.60320091], [69.70097351, 21.60319328], [69.70097351, 21.60347176], [69.70069122, 21.60347176], [69.70069885, 21.60375023], [69.70041656, 21.60375023], [69.70041656, 21.60403061], [69.70014191, 21.6040287], [69.70014191, 21.60458565], [69.69985962, 21.60457993], [69.69985962, 21.60486031], [69.69957733, 21.60486031], [69.69957733, 21.60514069], [69.69930267, 21.60514069], [69.69930267, 21.60542107], [69.69847107, 21.60541534], [69.69847107, 21.60569572], [69.69736481, 21.60569572], [69.69736481, 21.60597229], [69.69708252, 21.60597038], [69.69708252, 21.60625076], [69.69680786, 21.60625076], [69.69680786, 21.60653114], [69.6965332, 21.60653114], [69.6965332, 21.60680962], [69.69625092, 21.60680771], [69.69625092, 21.60708427], [69.69596863, 21.60708046], [69.69596863, 21.60764122], [69.69569397, 21.60763931], [69.69569397, 21.60819435], [69.69541931, 21.60819054], [69.69541931, 21.60848045], [69.69513702, 21.60848045], [69.69513702, 21.60874939], [69.69486237, 21.60874939], [69.69486237, 21.6095829], [69.69457245, 21.60957909], [69.69457245, 21.61041832], [69.69403076, 21.61041641], [69.69403076, 21.61069489], [69.69374847, 21.61069489], [69.69374847, 21.61097145], [69.69346619, 21.61096764], [69.69346619, 21.61181259], [69.69319153, 21.61180496], [69.69319153, 21.61208344], [69.69291687, 21.61208344], [69.69291687, 21.61236191], [69.69264221, 21.61236191], [69.69264221, 21.61292267], [69.69235992, 21.61291695], [69.69235992, 21.61347008], [69.6920929, 21.61347008], [69.6920929, 21.61403275], [69.69180298, 21.61403275], [69.69180298, 21.61431122], [69.69125366, 21.6143055], [69.69125366, 21.61458206], [69.69097137, 21.61458015], [69.69097137, 21.61486053], [69.6904068, 21.61486053], [69.6904068, 21.61514282], [69.68958282, 21.61514282], [69.68958282, 21.61541939], [69.68902588, 21.61541748], [69.68902588, 21.61597252], [69.68818665, 21.61597061], [69.68818665, 21.6162529], [69.68791962, 21.6162529], [69.68791962, 21.61652946], [69.68736267, 21.61652946], [69.68736267, 21.61680984], [69.68680573, 21.61680412], [69.68680573, 21.6170826], [69.68653107, 21.6170826], [69.68653107, 21.61680412], [69.68624878, 21.61680412], [69.68624878, 21.6170826], [69.68569183, 21.61708069], [69.68569183, 21.61736107], [69.68514252, 21.61736107], [69.68514252, 21.61765099], [69.68430328, 21.61765099], [69.68430328, 21.61791992], [69.68402863, 21.6179142], [69.68402863, 21.61819649], [69.68374634, 21.61819649], [69.68374634, 21.61847305], [69.68347168, 21.61847115], [69.68347168, 21.61903], [69.68291473, 21.61902618], [69.68291473, 21.61930656], [69.68264008, 21.61930656], [69.68264008, 21.61958313], [69.68208313, 21.61958313], [69.68208313, 21.6198616], [69.68180847, 21.6198597], [69.68180847, 21.62014008], [69.68152618, 21.62014008], [69.68152618, 21.62042046], [69.68096924, 21.62042046], [69.68096924, 21.62070847], [69.68069458, 21.62069511], [69.68069458, 21.62097168], [69.68041992, 21.62096977], [69.68041992, 21.62125015], [69.68013763, 21.62125015], [69.68013763, 21.62153053], [69.67986298, 21.62153053], [69.67986298, 21.62181091], [69.67958069, 21.62180519], [69.67958069, 21.62208366], [69.67874908, 21.62207985], [69.67874908, 21.62236023], [69.67736053, 21.62236023], [69.67736053, 21.62291908], [69.67597198, 21.62291718], [69.67597198, 21.62319374], [69.67541504, 21.62319374], [69.67541504, 21.62347221], [69.67457581, 21.62346077], [69.67457581, 21.62375069], [69.67402649, 21.62375069], [69.67402649, 21.62402916], [69.67346191, 21.62402916], [69.67346191, 21.62431145], [69.67263794, 21.62430573], [69.67263794, 21.6245842], [69.67208099, 21.62457848], [69.67208099, 21.62486076], [69.67124939, 21.62486076], [69.67124939, 21.62513924], [69.67041779, 21.62513924], [69.67041779, 21.62541962], [69.66986084, 21.6254158], [69.66986084, 21.62569427], [69.66902924, 21.62569427], [69.66902924, 21.62597275], [69.66402435, 21.62597275], [69.66402435, 21.62569427], [69.66374969, 21.62569427], [69.66374969, 21.6254158], [69.66348267, 21.62541962], [69.66348267, 21.62513924], [69.66319275, 21.62513924], [69.66319275, 21.62486076], [69.66291809, 21.62486076], [69.66291809, 21.62457848], [69.6609726, 21.62457848], [69.6609726, 21.62486076], [69.66152191, 21.62486076], [69.66152191, 21.62541962], [69.6609726, 21.6254158], [69.6609726, 21.62597275], [69.66014099, 21.62597275], [69.66014099, 21.62569427], [69.6598587, 21.62569427], [69.6598587, 21.62597275], [69.65930939, 21.62597084], [69.65930176, 21.62625122], [69.6590271, 21.62624931], [69.6590271, 21.62652779], [69.65791321, 21.62652779], [69.65791321, 21.62708282], [69.65763855, 21.62708282], [69.65763855, 21.6273613], [69.65735626, 21.62735939], [69.65735626, 21.62763977], [69.6570816, 21.62763977], [69.6570816, 21.62792015], [69.65680695, 21.62791634], [69.65680695, 21.62847137], [69.65651703, 21.62846947], [69.65651703, 21.62874985], [69.65625, 21.62874985], [69.65625, 21.62903023], [69.65597534, 21.62902832], [69.65597534, 21.62930489], [69.65569305, 21.62930107], [69.65569305, 21.62959099], [69.6554184, 21.62959099], [69.6554184, 21.6301403], [69.65513611, 21.6301403], [69.65513611, 21.63042068], [69.65486145, 21.63042068], [69.65486145, 21.63070107], [69.65458679, 21.63069344], [69.65458679, 21.63097191], [69.65429688, 21.63097], [69.65429688, 21.63125038], [69.65374756, 21.63125038], [69.65374756, 21.63153076], [69.65319824, 21.63153076], [69.65319824, 21.63181114], [69.6526413, 21.63180351], [69.6526413, 21.6320858], [69.6515274, 21.63208008], [69.6515274, 21.63236046], [69.65040588, 21.63236046], [69.65040588, 21.63265038], [69.64958191, 21.63265038], [69.64958191, 21.63292122], [69.64847565, 21.6329174], [69.64847565, 21.63319588], [69.6479187, 21.63319588], [69.6479187, 21.63347244], [69.64763641, 21.63347054], [69.64763641, 21.63375092], [69.6470871, 21.63375092], [69.6470871, 21.63402939], [69.64652252, 21.63402939], [69.64652252, 21.63430977], [69.64624786, 21.63430786], [69.64624786, 21.63458252], [69.64569092, 21.63458061], [69.64569092, 21.63486099], [69.64541626, 21.63486099], [69.64541626, 21.63513947], [69.64485931, 21.63513947], [69.64485931, 21.63541985], [69.64458466, 21.63541794], [69.64458466, 21.6356945], [69.64402771, 21.6356945], [69.64402771, 21.63597298], [69.64375305, 21.63597107], [69.64375305, 21.63624954], [69.64319611, 21.63624954], [69.64319611, 21.63652992], [69.64290619, 21.63652992], [69.64290619, 21.6368084], [69.6423645, 21.63680649], [69.6423645, 21.63708305], [69.64208221, 21.63708305], [69.64208221, 21.63736153], [69.6415329, 21.63735962], [69.6415329, 21.63763809], [69.64125061, 21.63763809], [69.64125061, 21.63791847], [69.64068604, 21.63791847], [69.64068604, 21.63820267], [69.64041901, 21.63819504], [69.64041901, 21.6384716], [69.63986206, 21.63845825], [69.63986206, 21.63875008], [69.63957977, 21.63875008], [69.63957977, 21.63903046], [69.63931274, 21.63903046], [69.63931274, 21.63931274], [69.63903046, 21.63930511], [69.63903046, 21.63958359], [69.63874817, 21.63958359], [69.63874817, 21.63986015], [69.63846588, 21.63986015], [69.63846588, 21.64014053], [69.63819122, 21.64014053], [69.63819122, 21.64042282], [69.63791656, 21.6404171], [69.63791656, 21.64069366], [69.63764191, 21.64069366], [69.63764191, 21.64097023], [69.63735199, 21.64097023], [69.63735199, 21.64125061], [69.63707733, 21.64125061], [69.63707733, 21.6415329], [69.63680267, 21.6415329], [69.63680267, 21.64180946], [69.63652802, 21.64180565], [69.63652802, 21.64208221], [69.63625336, 21.64208031], [69.63625336, 21.64264107], [69.63597107, 21.64264107], [69.63597107, 21.64291954], [69.63569641, 21.64291763], [69.63569641, 21.64319229], [69.63541412, 21.64319229], [69.63541412, 21.64347458], [69.63291931, 21.64347458], [69.63291931, 21.64291763], [69.63263702, 21.64291954], [69.63263702, 21.64208031], [69.63291931, 21.64208221], [69.63291931, 21.64152718], [69.63318634, 21.6415329], [69.63318634, 21.64125061], [69.63346863, 21.64125061], [69.63346863, 21.64069176], [69.63375092, 21.64069366], [69.63375092, 21.6404171], [69.6340332, 21.64042282], [69.6340332, 21.64014053], [69.63430786, 21.64014053], [69.63430786, 21.63986015], [69.63458252, 21.63986015], [69.63458252, 21.63958168], [69.63486481, 21.63958359], [69.63486481, 21.63930511], [69.63513947, 21.63931274], [69.63513947, 21.63903046], [69.63569641, 21.63903046], [69.63569641, 21.63875008], [69.63597107, 21.63875008], [69.63597107, 21.63845825], [69.63625336, 21.6384716], [69.63625336, 21.63819504], [69.63652802, 21.63820267], [69.63652802, 21.63791847], [69.63680267, 21.63791847], [69.63680267, 21.63763809], [69.63707733, 21.63763809], [69.63707733, 21.63735962], [69.63735962, 21.63736153], [69.63735962, 21.63708305], [69.63791656, 21.63708305], [69.63791656, 21.63680649], [69.63819122, 21.63680077], [69.63819122, 21.63652992], [69.63846588, 21.63652992], [69.63846588, 21.63624954], [69.63903046, 21.63624954], [69.63903046, 21.63597107], [69.63930511, 21.63597298], [69.63930511, 21.6356945], [69.63957977, 21.6356945], [69.63957977, 21.63541794], [69.64013672, 21.63541985], [69.64013672, 21.63513947], [69.64041901, 21.63513947], [69.64041901, 21.63486099], [69.64097595, 21.63486099], [69.64097595, 21.63458061], [69.64125061, 21.63458252], [69.64125061, 21.63430786], [69.6415329, 21.63430977], [69.6415329, 21.63402939], [69.64208221, 21.63402939], [69.64208221, 21.63375092], [69.64235687, 21.63375092], [69.64235687, 21.63347054], [69.64291382, 21.63347244], [69.64291382, 21.63319588], [69.64375305, 21.63319588], [69.64375305, 21.6329174], [69.64402771, 21.63292122], [69.64402771, 21.63265038], [69.64430237, 21.63265038], [69.64430237, 21.63236046], [69.64457703, 21.63236046], [69.64457703, 21.63208008], [69.64485931, 21.6320858], [69.64485931, 21.63180351], [69.6451416, 21.63181114], [69.6451416, 21.63153076], [69.64541626, 21.63153076], [69.64541626, 21.63125038], [69.64569092, 21.63125038], [69.64569092, 21.63097], [69.64597321, 21.63097191], [69.64597321, 21.63069344], [69.64624786, 21.63070107], [69.64624786, 21.63042068], [69.64652252, 21.63042068], [69.64652252, 21.6301403], [69.64679718, 21.6301403], [69.64679718, 21.62985992], [69.6470871, 21.62986374], [69.6470871, 21.62902832], [69.6479187, 21.62903023], [69.6479187, 21.62874985], [69.64819336, 21.62874985], [69.64819336, 21.62846947], [69.64847565, 21.62847137], [69.64847565, 21.62819481], [69.64875031, 21.62819481], [69.64875031, 21.62791634], [69.64903259, 21.62792015], [69.64903259, 21.62763977], [69.64930725, 21.62763977], [69.64930725, 21.62735939], [69.64958191, 21.6273613], [69.64958191, 21.62708282], [69.6498642, 21.62708282], [69.6498642, 21.62680626], [69.6506958, 21.62681007], [69.6506958, 21.62652016], [69.6515274, 21.62652779], [69.6515274, 21.62624931], [69.65207672, 21.62625122], [69.65207672, 21.62597084], [69.6526413, 21.62597275], [69.6526413, 21.62569427], [69.65291595, 21.62569427], [69.65291595, 21.6254158], [69.6534729, 21.62541962], [69.6534729, 21.62513924], [69.65458679, 21.62513924], [69.65458679, 21.62457848], [69.65513611, 21.62457848], [69.65513611, 21.62486076], [69.6554184, 21.62486076], [69.6554184, 21.62457848], [69.65597534, 21.6245842], [69.65597534, 21.62430573], [69.65651703, 21.62431145], [69.65651703, 21.62402916], [69.65735626, 21.62402916], [69.65735626, 21.62375069], [69.65791321, 21.62375069], [69.65791321, 21.62346077], [69.6590271, 21.62347221], [69.6590271, 21.62319374], [69.66041565, 21.62319374], [69.66041565, 21.62291718], [69.66069794, 21.62291908], [69.66069794, 21.62264061], [69.66291809, 21.62264061], [69.66291809, 21.62236023], [69.66319275, 21.62236023], [69.66319275, 21.62207985], [69.66374969, 21.62208366], [69.66374969, 21.62180519], [69.66430664, 21.62181091], [69.66430664, 21.62153053], [69.66458893, 21.62153053], [69.66458893, 21.62125015], [69.66513824, 21.62125015], [69.66513824, 21.62096977], [69.6654129, 21.62097168], [69.6654129, 21.62069511], [69.66596985, 21.62070847], [69.66596985, 21.62042046], [69.66625214, 21.62042046], [69.66625214, 21.62014008], [69.66680908, 21.62014008], [69.66680908, 21.6198597], [69.66708374, 21.6198616], [69.66708374, 21.61958313], [69.6673584, 21.61958313], [69.6673584, 21.61902618], [69.66764832, 21.61903], [69.66764832, 21.61874962], [69.66791534, 21.61874962], [69.66791534, 21.61819649], [69.66819763, 21.61819649], [69.66819763, 21.6179142], [69.66847229, 21.61791992], [69.66847229, 21.61765099], [69.66874695, 21.61765099], [69.66874695, 21.61708069], [69.66902924, 21.6170826], [69.66902924, 21.61680412], [69.66929626, 21.61680984], [69.66929626, 21.6162529], [69.66958618, 21.6162529], [69.66958618, 21.61569023], [69.66986084, 21.61569214], [69.66986084, 21.61513901], [69.67014313, 21.61514282], [69.67014313, 21.61458015], [69.67041779, 21.61458206], [69.67041779, 21.61402702], [69.67069244, 21.61403275], [69.67069244, 21.61347008], [69.67097473, 21.61347008], [69.67097473, 21.61291695], [69.67124939, 21.61292267], [69.67124939, 21.61236191], [69.67152405, 21.61236191], [69.67152405, 21.61208344], [69.67208099, 21.61208344], [69.67208099, 21.61180496], [69.67319489, 21.61180496], [69.67319489, 21.61236191], [69.67346191, 21.61236191], [69.67346191, 21.61264038], [69.67375183, 21.61264038], [69.67375183, 21.61292267], [69.67402649, 21.61291695], [69.67402649, 21.61347008], [69.67430878, 21.61347008], [69.67430878, 21.61263847], [69.67485809, 21.61264038], [69.67485809, 21.61152077], [69.67597198, 21.6115284], [69.67597198, 21.61124992], [69.67624664, 21.61124992], [69.67624664, 21.61068916], [69.67652893, 21.61069489], [69.67652893, 21.61013985], [69.67679596, 21.61013985], [69.67679596, 21.60985947], [69.67708588, 21.60986137], [69.67708588, 21.6095829], [69.67680359, 21.6095829], [69.67680359, 21.60930634], [69.67736053, 21.60930824], [69.67736053, 21.60902977], [69.67679596, 21.60902977], [69.67679596, 21.60874939], [69.67624664, 21.60874939], [69.67624664, 21.60764122], [69.67597198, 21.60764122], [69.67597198, 21.60653114], [69.67624664, 21.60653114], [69.67624664, 21.60597038], [69.67652893, 21.60597229], [69.67652893, 21.60541534], [69.67679596, 21.60542107], [69.67679596, 21.60486031], [69.67708588, 21.60486031], [69.67708588, 21.60457993], [69.67736053, 21.60458565], [69.67736053, 21.6040287], [69.67764282, 21.60403061], [69.67764282, 21.60346985], [69.67791748, 21.60347176], [69.67791748, 21.60319328], [69.6784668, 21.60320091], [69.6784668, 21.60292053], [69.67874908, 21.60292053], [69.67874908, 21.60264015], [69.67930603, 21.60264015], [69.67930603, 21.60235023], [69.67958069, 21.60236168], [69.67958069, 21.6020813], [69.68013763, 21.6020813], [69.68013763, 21.60180473], [69.68041992, 21.60180473], [69.68041992, 21.60152817], [69.68096924, 21.60153008], [69.68096924, 21.60124969], [69.68125153, 21.60124969], [69.68125153, 21.60097122], [69.68180847, 21.60097122], [69.68180847, 21.60013962], [69.68208313, 21.60013962], [69.68208313, 21.59958076], [69.68235779, 21.59958267], [69.68235779, 21.59930611], [69.68263245, 21.59931183], [69.68263245, 21.59902954], [69.6829071, 21.59902954], [69.6829071, 21.59874916], [69.68319702, 21.59874916], [69.68319702, 21.59847069], [69.68347168, 21.5984726], [69.68347168, 21.59819412], [69.68374634, 21.59819412], [69.68374634, 21.59791756], [69.68402863, 21.59791946], [69.68402863, 21.59763908], [69.68430328, 21.59763908], [69.68430328, 21.59736061], [69.6845932, 21.59736061], [69.68458557, 21.59708405], [69.68486023, 21.59708405], [69.68486023, 21.59680557], [69.68514252, 21.59680939], [69.68514252, 21.59654236], [69.68541718, 21.59654236], [69.68541718, 21.59625053], [69.68569183, 21.59625053], [69.68569183, 21.59596825], [69.68597412, 21.59597206], [69.68597412, 21.59569359], [69.68708038, 21.59569359], [69.68708038, 21.59541893], [69.68791962, 21.59542084], [69.68791962, 21.59514046], [69.68902588, 21.59514046], [69.68902588, 21.59486008], [69.69013977, 21.59486198], [69.69013977, 21.59458351], [69.69041443, 21.59458351], [69.69041443, 21.59486198], [69.69069672, 21.59486008], [69.69069672, 21.59514046], [69.69097137, 21.59514046], [69.69097137, 21.59486008], [69.69124603, 21.59486008], [69.69124603, 21.59514046], [69.69152832, 21.59514046], [69.69152832, 21.59542084], [69.6920929, 21.59542084], [69.6920929, 21.59431076], [69.69235992, 21.59431076], [69.69235992, 21.59348106], [69.6920929, 21.59348106], [69.6920929, 21.5929203], [69.69291687, 21.5929203], [69.69291687, 21.59263992], [69.69319153, 21.59263992], [69.69319153, 21.59235954], [69.69347382, 21.59236145], [69.69347382, 21.5918045], [69.69513702, 21.59181023], [69.69513702, 21.59152985], [69.69568634, 21.59152985], [69.69568634, 21.59124947], [69.69680786, 21.59124947], [69.69680786, 21.59097099], [69.69763184, 21.59097099], [69.69763184, 21.59124947], [69.69790649, 21.59124947], [69.69790649, 21.58986092], [69.69875336, 21.58986092], [69.69875336, 21.58958054], [69.70458221, 21.58958244], [69.70458221, 21.58930588], [69.70513916, 21.58930969], [69.70513916, 21.58903122], [69.70569611, 21.58903122], [69.70569611, 21.58875084], [69.70625305, 21.58875084], [69.70625305, 21.58847046], [69.70680237, 21.58847237], [69.70680237, 21.58819389], [69.70735931, 21.58819389], [69.70735931, 21.58791733], [69.7076416, 21.58792114], [69.7076416, 21.58764267], [69.70791626, 21.58764267], [69.70791626, 21.58735085], [69.70819092, 21.58736038], [69.70819092, 21.58680534], [69.70847321, 21.58681107], [69.70847321, 21.58653259], [69.70874786, 21.58653259], [69.70874786, 21.58625031], [69.70903015, 21.58625031], [69.70903015, 21.58597183], [69.70930481, 21.58597183], [69.70930481, 21.58569527], [69.7095871, 21.5857029], [69.7095871, 21.58542252], [69.70986176, 21.58542252], [69.70986176, 21.58514023], [69.71013641, 21.58514023], [69.71013641, 21.58457756], [69.7104187, 21.58458328], [69.7104187, 21.58430481], [69.71069336, 21.58430862], [69.71069336, 21.58402824], [69.71098328, 21.58402824], [69.71098328, 21.58374977], [69.71125031, 21.58374977], [69.71125031, 21.58346748], [69.71152496, 21.5834713], [69.71152496, 21.58319473], [69.71180725, 21.58319473], [69.71180725, 21.58291626], [69.71208191, 21.58291817], [69.71208191, 21.58263969], [69.71235657, 21.58263969], [69.71235657, 21.58236122], [69.71263885, 21.58236122], [69.71263885, 21.58208084], [69.7131958, 21.58208275], [69.7131958, 21.58180618], [69.71347046, 21.58180809], [69.71347046, 21.58153915], [69.71375275, 21.58153915], [69.71375275, 21.58125114], [69.7140274, 21.58125114], [69.7140274, 21.58097076], [69.71430206, 21.58097267], [69.71430206, 21.5806942], [69.71458435, 21.5806942], [69.71458435, 21.58041763], [69.71485901, 21.58041954], [69.71485901, 21.58014107], [69.7151413, 21.58014107], [69.7151413, 21.57986069], [69.71541595, 21.57986069], [69.71541595, 21.57958031], [69.71569061, 21.57958412], [69.71569824, 21.57930756], [69.7159729, 21.57930946], [69.7159729, 21.57903099], [69.71624756, 21.57903099], [69.71624756, 21.57875061], [69.71652985, 21.57875061], [69.71652985, 21.57847023], [69.7168045, 21.57847214], [69.7168045, 21.57819557], [69.71736145, 21.57819557], [69.71736145, 21.57791519], [69.71763611, 21.57792091], [69.71763611, 21.57764053], [69.7179184, 21.57764053], [69.7179184, 21.57736015], [69.71819305, 21.57736015], [69.71819305, 21.57707977], [69.71847534, 21.57708549], [69.71847534, 21.57680321], [69.71875763, 21.57681084], [69.71875763, 21.57653046], [69.71901703, 21.57653046], [69.71901703, 21.57625008], [69.71930695, 21.57625008], [69.71930695, 21.5759697], [69.7195816, 21.5759716], [69.7195816, 21.57569313], [69.71985626, 21.57570076], [69.71985626, 21.57541275], [69.72013855, 21.57541656], [69.72013855, 21.57513809], [69.72041321, 21.57514], [69.72041321, 21.57485962], [69.7206955, 21.57486153], [69.7206955, 21.57458115], [69.72097015, 21.57458115], [69.72097015, 21.57430649], [69.7215271, 21.57430267], [69.7215271, 21.57402802], [69.72180176, 21.57403183], [69.72180176, 21.57374954], [69.72207642, 21.57374954], [69.72207642, 21.57347107], [69.7223587, 21.57347107], [69.7223587, 21.5731945], [69.72264099, 21.5731945], [69.72264099, 21.57291603], [69.72292328, 21.57292175], [69.72292328, 21.57263947], [69.72319794, 21.57263947], [69.72319794, 21.57237053], [69.7234726, 21.57237053], [69.7234726, 21.57181168], [69.72374725, 21.57181168], [69.72374725, 21.57152939], [69.72402954, 21.57152939], [69.72402954, 21.57125092], [69.72429657, 21.57125092], [69.72429657, 21.57068825], [69.72458649, 21.57069397], [69.72458649, 21.5704174], [69.72486115, 21.57041931], [69.72486115, 21.56986046], [69.72458649, 21.56986046], [69.72458649, 21.56930923], [69.72429657, 21.56930923], [69.72429657, 21.56846809], [69.72402954, 21.56847191], [69.72402954, 21.56791878], [69.72374725, 21.56792068], [69.72374725, 21.56596947], [69.7234726, 21.56597137], [69.7234726, 21.56624985], [69.72319794, 21.56624985], [69.72319794, 21.56597137], [69.72291565, 21.56597137], [69.72291565, 21.56569672], [69.72264099, 21.56569672], [69.72264099, 21.56541443], [69.7223587, 21.56542015], [69.7223587, 21.56513977], [69.72207642, 21.56513977], [69.72207642, 21.56485939], [69.7215271, 21.5648613], [69.7215271, 21.56458473], [69.72125244, 21.56458473], [69.72125244, 21.56430435], [69.72097015, 21.56431007], [69.72097015, 21.56375122], [69.72070313, 21.56375122], [69.72070313, 21.56347084], [69.72013855, 21.56347466], [69.72013855, 21.56319237], [69.71930695, 21.56319237], [69.71930695, 21.56236076], [69.71901703, 21.56236076], [69.71901703, 21.56180954], [69.71875763, 21.56180954], [69.71875763, 21.56097031], [69.71847534, 21.56097221], [69.71847534, 21.56069374], [69.71819305, 21.56069374], [69.71819305, 21.5601387], [69.7179184, 21.56014061], [69.7179184, 21.55958176], [69.71763611, 21.55958366], [69.71763611, 21.55930519], [69.71736145, 21.55931282], [69.71736145, 21.55875015], [69.71708679, 21.55875015], [69.71708679, 21.55820274], [69.71679688, 21.55820274], [69.71679688, 21.55763817], [69.71652985, 21.55763817], [69.71652985, 21.55708122], [69.71624756, 21.55708313], [69.71624756, 21.55597305], [69.7159729, 21.55597305], [69.7159729, 21.55486107], [69.71569824, 21.55486107], [69.71569824, 21.55402946], [69.71541595, 21.55402946], [69.71541595, 21.55124092], [69.71569061, 21.55125046], [69.71569824, 21.55097389], [69.7159729, 21.55097389], [69.7159729, 21.55069351], [69.71624756, 21.55069351], [69.71624756, 21.55041695], [69.71652985, 21.55042076], [69.71652985, 21.55014038], [69.71679688, 21.55014038], [69.71679688, 21.54986], [69.71708679, 21.54986382], [69.71708679, 21.54958534], [69.71736145, 21.54958534], [69.71736145, 21.5490284], [69.71763611, 21.5490303], [69.71763611, 21.54874992], [69.7179184, 21.54874992], [69.7179184, 21.54818153], [69.71819305, 21.54819489], [69.71819305, 21.54791641], [69.71848297, 21.54792023], [69.71848297, 21.5470829], [69.7195816, 21.5470829], [69.7195816, 21.54652786], [69.71985626, 21.54652977], [69.71985626, 21.54513931], [69.7195816, 21.54513931], [69.7195816, 21.54458046], [69.71986389, 21.54458237], [69.71986389, 21.54375076], [69.72013855, 21.54375076], [69.72013855, 21.54347038], [69.7195816, 21.54347229], [69.7195816, 21.54291725], [69.71930695, 21.54291916], [69.71930695, 21.54236031], [69.71875, 21.54236031], [69.71875, 21.54208374], [69.71847534, 21.54208374], [69.71847534, 21.54180527], [69.71819305, 21.54180527], [69.71819305, 21.54208374], [69.71763611, 21.54208374], [69.71763611, 21.54180527], [69.71736145, 21.54180908], [69.71736145, 21.54153061], [69.71708679, 21.54153061], [69.71708679, 21.54125023], [69.71652985, 21.54125023], [69.71652985, 21.54096985], [69.7159729, 21.54097176], [69.7159729, 21.54069519], [69.71569824, 21.54070091], [69.71569824, 21.54042053], [69.71530151, 21.54042053], [69.71457672, 21.54042053], [69.71457672, 21.54070091], [69.71430206, 21.54070091], [69.71430206, 21.54042053], [69.71290588, 21.54042053], [69.71290588, 21.54014015], [69.71235657, 21.54014015], [69.71235657, 21.54042053], [69.71208191, 21.54042053], [69.71208191, 21.53985977], [69.71180725, 21.53986168], [69.71180725, 21.53958321], [69.71069336, 21.53958321], [69.71069336, 21.53930664], [69.71013641, 21.53930664], [69.71013641, 21.53958321], [69.70930481, 21.53958321], [69.70930481, 21.53986168], [69.70819092, 21.53985977], [69.70819092, 21.54014015], [69.70735931, 21.54014015], [69.70735931, 21.53985977], [69.7076416, 21.53986168], [69.7076416, 21.53930664], [69.70708466, 21.53930664], [69.70708466, 21.53902817], [69.70680237, 21.53903008], [69.70680237, 21.53874969], [69.70625305, 21.53874969], [69.70625305, 21.53847122], [69.70597076, 21.53847122], [69.70597076, 21.53874969], [69.70569611, 21.53874969], [69.70569611, 21.53903008], [69.70513916, 21.53902817], [69.70513916, 21.53930664], [69.70458221, 21.53930664], [69.70458221, 21.53958321], [69.70430756, 21.53958321], [69.70430756, 21.53986168], [69.70375824, 21.53985977], [69.70375824, 21.54014015], [69.70318604, 21.54014015], [69.70318604, 21.54042053], [69.70263672, 21.54042053], [69.70263672, 21.54070091], [69.70236206, 21.54069519], [69.70236206, 21.54097176], [69.70207977, 21.54096985], [69.70207977, 21.54125023], [69.70181274, 21.54125023], [69.70181274, 21.54153061], [69.70124817, 21.54153061], [69.70124817, 21.54125023], [69.70096588, 21.54125023], [69.70096588, 21.54153061], [69.70069885, 21.54153061], [69.70069885, 21.54180908], [69.70041656, 21.54180527], [69.70041656, 21.54208374], [69.70014191, 21.54207993], [69.70014191, 21.54236031], [69.69957733, 21.54236031], [69.69957733, 21.54264069], [69.69930267, 21.54264069], [69.69930267, 21.54291916], [69.69902802, 21.54291725], [69.69902802, 21.54319382], [69.69875336, 21.54319382], [69.69875336, 21.54347229], [69.69819641, 21.54347038], [69.69819641, 21.54375076], [69.69790649, 21.54375076], [69.69790649, 21.54402924], [69.69763184, 21.54402924], [69.69763184, 21.54431152], [69.69736481, 21.5443058], [69.69736481, 21.54458427], [69.69708252, 21.54458046], [69.69708252, 21.54486084], [69.6965332, 21.54486084], [69.6965332, 21.54513931], [69.69625092, 21.54513931], [69.69625092, 21.54543114], [69.69596863, 21.54541588], [69.69596863, 21.54569435], [69.69569397, 21.54569435], [69.69569397, 21.54597282], [69.69541931, 21.54597092], [69.69541931, 21.54624939], [69.69486237, 21.54624939], [69.69486237, 21.54652977], [69.69457245, 21.54652977], [69.69457245, 21.54681015], [69.69430542, 21.54680634], [69.69430542, 21.5470829], [69.69403076, 21.5470829], [69.69403076, 21.54736137], [69.69291687, 21.54735947], [69.69291687, 21.54763985], [69.69264221, 21.54763985], [69.69264221, 21.54792023], [69.69235992, 21.54791641], [69.69235992, 21.54819489], [69.69208527, 21.54819489], [69.69208527, 21.54847145], [69.69180298, 21.54846954], [69.69180298, 21.54874992], [69.69124603, 21.54874992], [69.69124603, 21.5490303], [69.69097137, 21.5490303], [69.69097137, 21.54931068], [69.69041443, 21.54930305], [69.69041443, 21.54958534], [69.69013977, 21.54958534], [69.69013977, 21.54986382], [69.68958282, 21.54986], [69.68958282, 21.55014038], [69.68846893, 21.55013847], [69.68846893, 21.55125046], [69.68791962, 21.55124092], [69.68791962, 21.55153084], [69.68763733, 21.55153084], [69.68763733, 21.55181122], [69.68736267, 21.55180359], [69.68736267, 21.55208588], [69.68680573, 21.55208588], [69.68681335, 21.55236053], [69.68653107, 21.55236053], [69.68653107, 21.55291939], [69.68624878, 21.55291748], [69.68624878, 21.55319595], [69.68597412, 21.55319595], [69.68597412, 21.55347252], [69.68569183, 21.55347061], [69.68569183, 21.55375099], [69.68541718, 21.55375099], [69.68541718, 21.55402946], [69.68514252, 21.55402756], [69.68514252, 21.55430794], [69.68486023, 21.55430794], [69.68486023, 21.5545826], [69.68458557, 21.5545826], [69.6845932, 21.55486107], [69.68430328, 21.55486107], [69.68430328, 21.55513954], [69.68402863, 21.55513954], [69.68402863, 21.55541992], [69.68347168, 21.55541611], [69.68347168, 21.55569458], [69.68319702, 21.55569458], [69.68319702, 21.55597305], [69.6829071, 21.55597115], [69.6829071, 21.55624962], [69.68263245, 21.55624962], [69.68263245, 21.55652809], [69.68235779, 21.55652809], [69.68235779, 21.55680466], [69.68208313, 21.55680466], [69.68208313, 21.55708313], [69.68180847, 21.55708122], [69.68180847, 21.55736923], [69.68152618, 21.55736923], [69.68152618, 21.55763817], [69.68125153, 21.55763817], [69.68125153, 21.55792236], [69.68096924, 21.55792236], [69.68096924, 21.55820274], [69.68069458, 21.55819511], [69.68069458, 21.55847168], [69.68041992, 21.55847168], [69.68041992, 21.55875015], [69.68013763, 21.55875015], [69.68013763, 21.55903244], [69.67986298, 21.55903244], [69.67986298, 21.55931282], [69.67958069, 21.55930519], [69.67958069, 21.55958366], [69.67930603, 21.55958176], [69.67930603, 21.55986023], [69.67903137, 21.55986023], [69.67903137, 21.56014061], [69.67874908, 21.5601387], [69.67874908, 21.56069374], [69.67847443, 21.56069374], [69.67847443, 21.56097221], [69.67819214, 21.56097031], [69.67819214, 21.56125069], [69.67791748, 21.56125069], [69.67791748, 21.56153107], [69.67764282, 21.56153107], [69.67764282, 21.56180954], [69.67736053, 21.56180573], [69.67736053, 21.56208229], [69.67708588, 21.56208038], [69.67708588, 21.56236076], [69.67679596, 21.56236076], [69.67679596, 21.56264114], [69.67652893, 21.56264114], [69.67652893, 21.56291962], [69.67597198, 21.5629158], [69.67597198, 21.56319237], [69.67569733, 21.56319237], [69.67569733, 21.56347466], [69.67542267, 21.56347084], [69.67542267, 21.56375122], [69.67514038, 21.56375122], [69.67514038, 21.56402969], [69.67457581, 21.56402969], [69.67457581, 21.56431007], [69.67430878, 21.56430435], [69.67430878, 21.56458473], [69.67402649, 21.56458473], [69.67402649, 21.5648613], [69.67375183, 21.56485939], [69.67375183, 21.56513977], [69.67318726, 21.56513977], [69.67318726, 21.56542015], [69.67292023, 21.56541443], [69.67292023, 21.56569672], [69.67263794, 21.56569672], [69.67263794, 21.56597137], [69.67236328, 21.56597137], [69.67236328, 21.56624985], [69.67180634, 21.56624031], [69.67180634, 21.56653023], [69.67152405, 21.56652832], [69.67152405, 21.56680679], [69.67124939, 21.56680679], [69.67124939, 21.56708336], [69.67097473, 21.56708336], [69.67097473, 21.56736183], [69.67069244, 21.56735992], [69.67069244, 21.5676403], [69.67041779, 21.5676403], [69.67041779, 21.56792068], [69.67014313, 21.56792068], [69.67014313, 21.56819916], [69.66986084, 21.56819534], [69.66986084, 21.56847191], [69.66958618, 21.56846809], [69.66958618, 21.56875038], [69.66929626, 21.56875038], [69.66929626, 21.56903076], [69.66902924, 21.56903076], [69.66902924, 21.56930923], [69.66874695, 21.56930542], [69.66874695, 21.56958389], [69.66847229, 21.56957817], [69.66847229, 21.56986046], [69.66819763, 21.56986046], [69.66819763, 21.57014084], [69.66791534, 21.57014084], [69.66791534, 21.57069397], [69.66764069, 21.57069397], [69.66764069, 21.57097244], [69.6673584, 21.57097054], [69.6673584, 21.57125092], [69.66707611, 21.57125092], [69.66707611, 21.57152939], [69.66680908, 21.57152939], [69.66680908, 21.57181168], [69.66652679, 21.57180595], [69.66652679, 21.57208252], [69.66625214, 21.57208061], [69.66625214, 21.57237053], [69.66596985, 21.57237053], [69.66596985, 21.57263947], [69.66570282, 21.57263947], [69.66570282, 21.57292175], [69.6654129, 21.57291603], [69.6654129, 21.5731945], [69.66513824, 21.5731945], [69.66513824, 21.57347107], [69.66485596, 21.57347107], [69.66486359, 21.57374954], [69.66458893, 21.57374954], [69.66458893, 21.57403183], [69.66430664, 21.57403183], [69.66430664, 21.5743103], [69.66402435, 21.57430649], [69.66402435, 21.57458115], [69.66374969, 21.57458115], [69.66374969, 21.57486153], [69.66348267, 21.57485962], [69.66348267, 21.57514], [69.66319275, 21.57513809], [69.66319275, 21.57541656], [69.66291809, 21.57541275], [69.66291809, 21.57570076], [69.6626358, 21.57569313], [69.6626358, 21.5759716], [69.66236115, 21.5759697], [69.66236115, 21.57653046], [69.66208649, 21.57653046], [69.66208649, 21.57681084], [69.6618042, 21.57680321], [69.6618042, 21.57708549], [69.66152954, 21.57708549], [69.66152954, 21.57736206], [69.66124725, 21.57736015], [69.66124725, 21.57764053], [69.6609726, 21.57764053], [69.6609726, 21.57792091], [69.66069794, 21.57791519], [69.66069794, 21.57819557], [69.66041565, 21.57819557], [69.66041565, 21.57847214], [69.66014099, 21.57847023], [69.66014099, 21.57875061], [69.6598587, 21.57875061], [69.6598587, 21.57903099], [69.65957642, 21.57903099], [69.65957642, 21.57930946], [69.65930939, 21.57930756], [69.65930176, 21.57958412], [69.6590271, 21.57958031], [69.6590271, 21.57986069], [69.65875244, 21.57986069], [69.65875244, 21.58014107], [69.65846252, 21.58014107], [69.65846252, 21.58041954], [69.6581955, 21.58041763], [69.6581955, 21.5806942], [69.65791321, 21.58069038], [69.65791321, 21.58125114], [69.65763855, 21.58125114], [69.65763855, 21.58153915], [69.65735626, 21.58153915], [69.65735626, 21.58180809], [69.6570816, 21.58180618], [69.6570816, 21.58208275], [69.65680695, 21.58208084], [69.65680695, 21.58236122], [69.65651703, 21.58236122], [69.65651703, 21.58263969], [69.65625, 21.58263969], [69.65625, 21.58291817], [69.65597534, 21.58291626], [69.65597534, 21.58319473], [69.65569305, 21.58319473], [69.65569305, 21.5834713], [69.6554184, 21.58346748], [69.6554184, 21.58374977], [69.65513611, 21.58374977], [69.65513611, 21.58402824], [69.65486145, 21.58402824], [69.65486145, 21.58430862], [69.65458679, 21.58430481], [69.65458679, 21.58458328], [69.6543045, 21.58458328], [69.6543045, 21.58486176], [69.65402985, 21.58486176], [69.65402985, 21.58514023], [69.65374756, 21.58514023], [69.65374756, 21.5857029], [69.6534729, 21.58569527], [69.6534729, 21.58597183], [69.65319824, 21.58597183], [69.65319824, 21.58625031], [69.65291595, 21.58625031], [69.65291595, 21.58653259], [69.65264893, 21.58653259], [69.65264893, 21.58681107], [69.65235901, 21.58680534], [69.65235901, 21.58708382], [69.65208435, 21.58708382], [69.65208435, 21.58736038], [69.65180206, 21.58735085], [69.65180206, 21.58764267], [69.6515274, 21.58764267], [69.6515274, 21.58792114], [69.65125275, 21.58791733], [69.65125275, 21.58819389], [69.65097046, 21.58819389], [69.65097046, 21.58847237], [69.6506958, 21.58847046], [69.6506958, 21.58875084], [69.65040588, 21.58875084], [69.65040588, 21.58903122], [69.65013885, 21.58903122], [69.65013885, 21.58930969], [69.6498642, 21.58930588], [69.6498642, 21.58958244], [69.64958191, 21.58958054], [69.64958191, 21.58986092], [69.64930725, 21.58986092], [69.64930725, 21.59041405], [69.64902496, 21.59041405], [69.64902496, 21.59069633], [69.64875031, 21.59069633], [69.64875031, 21.59097481], [69.64847565, 21.59097481], [69.64848328, 21.59124947], [69.64819336, 21.59124947], [69.64819336, 21.59152985], [69.6479187, 21.59152794], [69.6479187, 21.59208488], [69.64763641, 21.59208488], [69.64763641, 21.59236145], [69.64736176, 21.59235954], [69.64736176, 21.59263992], [69.64679718, 21.59263992], [69.64679718, 21.5929203], [69.64652252, 21.5929203], [69.64652252, 21.59320068], [69.64624786, 21.59320068], [69.64624786, 21.59348106], [69.64597321, 21.59348106], [69.64597321, 21.59375], [69.64569092, 21.59375], [69.64569092, 21.59403038], [69.64541626, 21.59403038], [69.64541626, 21.59431076], [69.6451416, 21.59430695], [69.6451416, 21.59486198], [69.64485931, 21.59486008], [69.64485931, 21.59514046], [69.64457703, 21.59514046], [69.64457703, 21.59542084], [69.64430237, 21.59541893], [69.64430237, 21.59569359], [69.64402771, 21.59569359], [69.64402771, 21.59597206], [69.64375305, 21.59596825], [69.64375305, 21.59625053], [69.64347839, 21.59625053], [69.64347839, 21.59654236], [69.64319611, 21.59654236], [69.64319611, 21.59680939], [69.64291382, 21.59680557], [69.64291382, 21.59708405], [69.64263916, 21.59707832], [69.64263916, 21.59736061], [69.64235687, 21.59736061], [69.64235687, 21.59763908], [69.64208221, 21.59763908], [69.64208221, 21.59791946], [69.64180756, 21.59791756], [69.64180756, 21.59819412], [69.64152527, 21.59819412], [69.64152527, 21.5984726], [69.64125061, 21.59847069], [69.64125061, 21.59874916], [69.64068604, 21.59874916], [69.64068604, 21.59902954], [69.64041901, 21.59902954], [69.64041901, 21.59931183], [69.64013672, 21.59930611], [69.64013672, 21.59958267], [69.63986206, 21.59958076], [69.63986206, 21.59986115], [69.63957977, 21.59986115], [69.63957977, 21.60013962], [69.63931274, 21.60013962], [69.63931274, 21.60042191], [69.63903046, 21.60041618], [69.63903046, 21.60069466], [69.63874817, 21.60069466], [69.63874817, 21.60097122], [69.63846588, 21.60097122], [69.63846588, 21.60124969], [69.63819122, 21.60124969], [69.63819122, 21.60153008], [69.63791656, 21.60152817], [69.63791656, 21.60180473], [69.63764191, 21.60180473], [69.63764191, 21.6020813], [69.63735962, 21.6020813], [69.63735962, 21.60236168], [69.63707733, 21.60235023], [69.63707733, 21.60264015], [69.63680267, 21.60264015], [69.63680267, 21.60320091], [69.63652802, 21.60319328], [69.63652802, 21.60347176], [69.63625336, 21.60346985], [69.63625336, 21.60375023], [69.63597107, 21.60375023], [69.63597107, 21.60403061], [69.63569641, 21.60403061], [69.63569641, 21.60431099], [69.63541412, 21.60430336], [69.63541412, 21.60458565], [69.63513947, 21.60457993], [69.63513947, 21.60486031], [69.63485718, 21.60486031], [69.63485718, 21.60514069], [69.63458252, 21.60514069], [69.63458252, 21.60542107], [69.63430786, 21.60541534], [69.63430786, 21.60569572], [69.63402557, 21.60569572], [69.63402557, 21.60597229], [69.63375092, 21.60597038], [69.63375092, 21.60625076], [69.63346863, 21.60625076], [69.63346863, 21.60653114], [69.63319397, 21.60652542], [69.63319397, 21.60708427], [69.63291931, 21.60708046], [69.63291931, 21.60736084], [69.63263702, 21.60736084], [69.63263702, 21.60764122], [69.63236237, 21.60764122], [69.63236237, 21.60791969], [69.63208008, 21.60791779], [69.63208008, 21.60819435], [69.63181305, 21.60819054], [69.63181305, 21.60848045], [69.63153076, 21.60847282], [69.63153839, 21.60874939], [69.63124847, 21.60874939], [69.63124847, 21.60902977], [69.63096619, 21.60902977], [69.63096619, 21.60930824], [69.63069153, 21.60930634], [69.63069153, 21.6095829], [69.63041687, 21.6095829], [69.63041687, 21.60986137], [69.63014221, 21.60985947], [69.63014221, 21.61013985], [69.62985992, 21.61013985], [69.62985992, 21.61041832], [69.62958527, 21.61041641], [69.62958527, 21.61097145], [69.62930298, 21.61096764], [69.62930298, 21.61124992], [69.62902832, 21.61124992], [69.62902832, 21.6115284], [69.62874603, 21.61152077], [69.62874603, 21.61181259], [69.62847137, 21.61180496], [69.62847137, 21.61208344], [69.62819672, 21.61208344], [69.62819672, 21.61236191], [69.6279068, 21.61236191], [69.6279068, 21.61264038], [69.62763977, 21.61264038], [69.62763977, 21.61292267], [69.62735748, 21.61291695], [69.62735748, 21.6131916], [69.62708282, 21.61319542], [69.62708282, 21.61347008], [69.62680817, 21.61347008], [69.62680817, 21.61375046], [69.62652588, 21.61375046], [69.62652588, 21.61431122], [69.62625122, 21.61431122], [69.62625122, 21.61486053], [69.62596893, 21.61486053], [69.62596893, 21.61541939], [69.62569427, 21.61541748], [69.62569427, 21.61569214], [69.62541962, 21.61569214], [69.62541962, 21.61597252], [69.62486267, 21.61597061], [69.62486267, 21.6162529], [69.62458038, 21.6162529], [69.62458038, 21.61652946], [69.62431335, 21.61652946], [69.62431335, 21.61680984], [69.62403107, 21.61680412], [69.62403107, 21.6170826], [69.62346649, 21.61708069], [69.62346649, 21.61736107], [69.62319183, 21.61736107], [69.62319183, 21.61765099], [69.62291718, 21.61765099], [69.62291718, 21.61791992], [69.62264252, 21.6179142], [69.62264252, 21.61819649], [69.62208557, 21.61819649], [69.62208557, 21.61847305], [69.62180328, 21.61847115], [69.62180328, 21.61874962], [69.62152863, 21.61874962], [69.62152863, 21.61903], [69.62124634, 21.61902618], [69.62124634, 21.61930656], [69.62097168, 21.61930656], [69.62097168, 21.61958313], [69.62069702, 21.61958122], [69.62069702, 21.62014008], [69.6204071, 21.62014008], [69.6204071, 21.62042046], [69.62014008, 21.62042046], [69.62014008, 21.62070847], [69.61985779, 21.62069511], [69.61985779, 21.62097168], [69.61958313, 21.62096977], [69.61958313, 21.62125015], [69.61930847, 21.62125015], [69.61930847, 21.62181091], [69.61902618, 21.62180519], [69.61902618, 21.62208366], [69.61875153, 21.62207985], [69.61875153, 21.62236023], [69.61846924, 21.62236023], [69.61846924, 21.62264061], [69.61818695, 21.62264061], [69.61818695, 21.62291908], [69.61763763, 21.62291718], [69.61763763, 21.62319374], [69.61736298, 21.62319374], [69.61736298, 21.62347221], [69.61680603, 21.62346077], [69.61680603, 21.62375069], [69.616539, 21.62375069], [69.616539, 21.62402916], [69.61624908, 21.62402916], [69.61624908, 21.62431145], [69.61597443, 21.62430573], [69.61597443, 21.6245842], [69.61569214, 21.62457848], [69.61569214, 21.62486076], [69.61541748, 21.62486076], [69.61541748, 21.62513924], [69.61486053, 21.62513924], [69.61486053, 21.62541962], [69.61458588, 21.6254158], [69.61458588, 21.62597275], [69.61429596, 21.62597084], [69.61429596, 21.62625122], [69.61402893, 21.62625122], [69.61402893, 21.62681007], [69.61374664, 21.62680626], [69.61374664, 21.62708282], [69.61402893, 21.62708282], [69.61402893, 21.6273613], [69.61374664, 21.62735939], [69.61374664, 21.62763977], [69.61319733, 21.62763977], [69.61319733, 21.62792015], [69.61264038, 21.62791634], [69.61264038, 21.62819481], [69.61152649, 21.62819481], [69.61152649, 21.62847137], [69.61125183, 21.62846947], [69.61125183, 21.62874985], [69.6104126, 21.62874985], [69.6104126, 21.62846947], [69.61013794, 21.62846947], [69.61013794, 21.62903023], [69.60986328, 21.62902832], [69.60986328, 21.62930489], [69.60958099, 21.62930489], [69.60958099, 21.62986374], [69.60930634, 21.62986374], [69.60930634, 21.63010979], [69.60874939, 21.6301384], [69.60874939, 21.63043976], [69.60874939, 21.63070107], [69.60847473, 21.63069344], [69.60847473, 21.63097191], [69.60819244, 21.63097], [69.60819244, 21.63125038], [69.60791779, 21.63125038], [69.60791779, 21.63181114], [69.6076355, 21.63180351], [69.6076355, 21.6320858], [69.60735321, 21.63208008], [69.60735321, 21.63265038], [69.60624695, 21.63265038], [69.60624695, 21.63292122], [69.60569763, 21.6329174], [69.60569763, 21.63347244], [69.60514069, 21.63347054], [69.60514069, 21.63375092], [69.6048584, 21.63375092], [69.6048584, 21.63430977], [69.60402679, 21.63430786], [69.60402679, 21.63458252], [69.60319519, 21.63458252], [69.60320282, 21.63513947], [69.6029129, 21.63513947], [69.6029129, 21.63597298], [69.60263824, 21.63597107], [69.60263824, 21.63652992], [69.60235596, 21.63652992], [69.60235596, 21.6368084], [69.6020813, 21.63680649], [69.6020813, 21.63736153], [69.60069275, 21.63735962], [69.60069275, 21.63763809], [69.59902954, 21.63763809], [69.59902954, 21.63791847], [69.59784698, 21.63791847], [69.59485626, 21.63791847], [69.59485626, 21.63820267], [69.5945816, 21.63820267], [69.5945816, 21.63791847], [69.59430695, 21.63791847], [69.59430695, 21.63820267], [69.59263611, 21.63819504], [69.59263611, 21.6384716], [69.5909729, 21.6384716], [69.5909729, 21.63791656], [69.59069824, 21.63791847], [69.59069061, 21.63735962], [69.58985901, 21.63736153], [69.58985901, 21.63708305], [69.5901413, 21.63708305], [69.5901413, 21.63680649], [69.59041595, 21.63680077], [69.59041595, 21.63652992], [69.5909729, 21.63652992], [69.5909729, 21.63624954], [69.59124756, 21.63624954], [69.59124756, 21.63597107], [69.59152985, 21.63597298], [69.59152985, 21.6356945], [69.59236145, 21.6356945], [69.59236145, 21.63541794], [69.59263611, 21.63541985], [69.59263611, 21.63513947], [69.59319305, 21.63513947], [69.59319305, 21.63402939], [69.59348297, 21.63402939], [69.59348297, 21.63319016], [69.59319305, 21.63319588], [69.59319305, 21.6329174], [69.59236908, 21.63292122], [69.59236908, 21.63236046], [69.59208679, 21.63236046], [69.59208679, 21.63153076], [69.59236908, 21.63153076], [69.59236908, 21.63042068], [69.5929184, 21.63042068], [69.5929184, 21.62985992], [69.59319305, 21.62986374], [69.59319305, 21.62930489], [69.5918045, 21.62930489], [69.5918045, 21.62902832], [69.59152985, 21.62903023], [69.59152985, 21.62874985], [69.59124756, 21.62874985], [69.59124756, 21.62846947], [69.5909729, 21.62847137], [69.5909729, 21.62791634], [69.59069824, 21.62792015], [69.59069824, 21.62735939], [69.59124756, 21.6273613], [69.59124756, 21.62708282], [69.59152985, 21.62708282], [69.59152985, 21.62624931], [69.59179688, 21.62625122], [69.59179688, 21.62541962], [69.59124756, 21.6254158], [69.59124756, 21.62597275], [69.58930206, 21.62597275], [69.58930206, 21.62430573], [69.58985901, 21.62431145], [69.58985901, 21.62402916], [69.5901413, 21.62402916], [69.5901413, 21.62375069], [69.5909729, 21.62375069], [69.5909729, 21.62346077], [69.59069824, 21.62347221], [69.59069061, 21.62291718], [69.59041595, 21.62291908], [69.59041595, 21.62236023], [69.5901413, 21.62236023], [69.5901413, 21.62042046], [69.58957672, 21.62042046], [69.58957672, 21.62070847], [69.58930969, 21.62070847], [69.58930969, 21.62042046], [69.5890274, 21.62042046], [69.5890274, 21.62070847], [69.58847046, 21.62069511], [69.58847046, 21.62097168], [69.58763885, 21.62096977], [69.58763885, 21.62153053], [69.5873642, 21.62152863], [69.5873642, 21.62319374], [69.58763885, 21.62318993], [69.58763885, 21.62431145], [69.58790588, 21.62431145], [69.58790588, 21.62486076], [69.5881958, 21.62486076], [69.5881958, 21.62569427], [69.58847046, 21.62569427], [69.58847046, 21.62652779], [69.58875275, 21.62652779], [69.58875275, 21.6273613], [69.5890274, 21.6273613], [69.5890274, 21.62847137], [69.58930969, 21.62846947], [69.58930969, 21.62903023], [69.58957672, 21.62903023], [69.58957672, 21.62959099], [69.58985901, 21.62958336], [69.58985901, 21.62986374], [69.5901413, 21.62985992], [69.5901413, 21.6301403], [69.59041595, 21.6301403], [69.59041595, 21.63070107], [69.59069824, 21.63069344], [69.59069824, 21.63097191], [69.5909729, 21.63097], [69.5909729, 21.63153076], [69.59124756, 21.63153076], [69.59124756, 21.63236046], [69.59152985, 21.63236046], [69.59152985, 21.63319588], [69.59179688, 21.63319016], [69.59179688, 21.63430977], [69.59152985, 21.63430977], [69.59152985, 21.63486099], [69.59124756, 21.63486099], [69.59124756, 21.63513947], [69.5909729, 21.63513947], [69.5909729, 21.63541985], [69.59041595, 21.63541794], [69.59041595, 21.6356945], [69.58985901, 21.6356945], [69.58985901, 21.63597298], [69.58957672, 21.63597107], [69.58957672, 21.63624954], [69.58847046, 21.63624954], [69.58847046, 21.63652992], [69.58708191, 21.63652992], [69.58708191, 21.6368084], [69.58625031, 21.63680649], [69.58625031, 21.63708305], [69.58569336, 21.63708305], [69.58569336, 21.63736153], [69.58486176, 21.63735962], [69.58486176, 21.63763809], [69.5845871, 21.63763809], [69.5845871, 21.63791847], [69.58403015, 21.63791847], [69.58403015, 21.63820267], [69.58374786, 21.63819504], [69.58374786, 21.6384716], [69.58347321, 21.63845825], [69.58347321, 21.63875008], [69.58318329, 21.63875008], [69.58318329, 21.63903046], [69.58291626, 21.63903046], [69.58291626, 21.63931274], [69.5826416, 21.63930511], [69.5826416, 21.63958359], [69.58235931, 21.63958359], [69.58235931, 21.63986015], [69.58207703, 21.63986015], [69.58207703, 21.64014053], [69.58180237, 21.64014053], [69.58180237, 21.64042282], [69.58125305, 21.6404171], [69.58125305, 21.64069366], [69.58097076, 21.64069366], [69.58097076, 21.64097023], [69.58040619, 21.64097023], [69.58040619, 21.64125061], [69.58013916, 21.64125061], [69.58013916, 21.6415329], [69.57958221, 21.6415329], [69.57958221, 21.64180946], [69.57930756, 21.64180565], [69.57930756, 21.64208221], [69.57875061, 21.64208031], [69.57875061, 21.64236069], [69.57847595, 21.64236069], [69.57847595, 21.64264107], [69.57791901, 21.64264107], [69.57791901, 21.64291954], [69.57763672, 21.64291763], [69.57763672, 21.64319229], [69.57736206, 21.64319229], [69.57736206, 21.64347458], [69.57681274, 21.64347076], [69.57681274, 21.64375114], [69.57653046, 21.64375114], [69.57653046, 21.64402962], [69.57624817, 21.64402962], [69.57624817, 21.64431], [69.57596588, 21.64431], [69.57596588, 21.64459038], [69.57541656, 21.64459038], [69.57541656, 21.64486122], [69.57514191, 21.64486122], [69.57514191, 21.64624977], [69.57430267, 21.64624977], [69.57430267, 21.64596939], [69.57375336, 21.64596939], [69.57375336, 21.64624977], [69.57347107, 21.64624977], [69.57347107, 21.64653015], [69.57236481, 21.64652824], [69.57236481, 21.64680672], [69.57152557, 21.64680672], [69.57152557, 21.64708328], [69.57125092, 21.64708328], [69.57125092, 21.64736176], [69.57096863, 21.64735985], [69.57096863, 21.64764977], [69.57068634, 21.64764977], [69.57068634, 21.64819908], [69.57041931, 21.64819527], [69.57041931, 21.64847183], [69.57013702, 21.64846992], [69.57013702, 21.64875031], [69.56986237, 21.64875031], [69.56986237, 21.64903069], [69.56958008, 21.64903069], [69.56958008, 21.64930916], [69.56930542, 21.64930534], [69.56931305, 21.64986038], [69.56903076, 21.64986038], [69.56903076, 21.65014076], [69.56874847, 21.65014076], [69.56874847, 21.65041924], [69.56819153, 21.65041733], [69.56819153, 21.65069389], [69.56791687, 21.65069389], [69.56791687, 21.65097237], [69.56764221, 21.65097046], [69.56764221, 21.65125084], [69.56735992, 21.65125084], [69.56735992, 21.65152931], [69.5670929, 21.65152931], [69.5670929, 21.6518116], [69.56735992, 21.65180588], [69.56735992, 21.65208244], [69.56708527, 21.65208244], [69.5670929, 21.65236092], [69.56624603, 21.65236092], [69.56624603, 21.65263939], [69.5654068, 21.65263939], [69.5654068, 21.65292168], [69.56458282, 21.65291595], [69.56458282, 21.65319443], [69.56402588, 21.65319443], [69.56402588, 21.6534729], [69.56375122, 21.6534729], [69.56375122, 21.65374947], [69.56318665, 21.65374947], [69.56318665, 21.65402985], [69.56263733, 21.65402985], [69.56263733, 21.65431023], [69.56236267, 21.65430641], [69.56236267, 21.65458107], [69.56180573, 21.65458107], [69.56180573, 21.65486145], [69.56124878, 21.65485954], [69.56124878, 21.65513992], [69.56096649, 21.65513992], [69.56096649, 21.6554203], [69.56041718, 21.6554203], [69.56041718, 21.65570068], [69.56014252, 21.65570068], [69.56014252, 21.65625], [69.55986023, 21.65625], [69.55986023, 21.65653038], [69.5595932, 21.65653038], [69.5595932, 21.6568203], [69.55930328, 21.65680313], [69.55930328, 21.65736389], [69.55902863, 21.65736008], [69.55902863, 21.65764046], [69.55874634, 21.65764046], [69.55874634, 21.65792084], [69.55847168, 21.65791512], [69.55847168, 21.65847206], [69.55819702, 21.65847015], [69.55819702, 21.65875053], [69.5579071, 21.65875053], [69.5579071, 21.65903091], [69.55764008, 21.65903091], [69.55764008, 21.65930939], [69.55735779, 21.65930939], [69.55735779, 21.65958977], [69.55708313, 21.65958977], [69.55708313, 21.65986061], [69.55680847, 21.65986061], [69.55680847, 21.66014099], [69.55652618, 21.66013908], [69.55652618, 21.66069412], [69.55596924, 21.66069412], [69.55596924, 21.6609726], [69.55568695, 21.66097069], [69.55568695, 21.66125107], [69.55513763, 21.66125107], [69.55513763, 21.66152954], [69.55486298, 21.66152954], [69.55486298, 21.66180992], [69.55458069, 21.66180611], [69.55458069, 21.66208267], [69.55430603, 21.66208076], [69.55430603, 21.66236115], [69.55403137, 21.66236115], [69.55403137, 21.66263962], [69.5534668, 21.66263008], [69.5534668, 21.66291809], [69.55319214, 21.66291618], [69.55319214, 21.66319466], [69.55291748, 21.66319466], [69.55291748, 21.66347313], [69.55263519, 21.66347313], [69.55264282, 21.66374969], [69.55236053, 21.66374969], [69.55236053, 21.66402817], [69.55208588, 21.66402817], [69.55208588, 21.66430473], [69.55180359, 21.66430473], [69.55180359, 21.66458321], [69.55152893, 21.66458321], [69.55152893, 21.66486168], [69.55124664, 21.66485977], [69.55124664, 21.66514015], [69.55069733, 21.66514015], [69.55069733, 21.66542244], [69.55041504, 21.66541672], [69.55041504, 21.66569519], [69.55014038, 21.66569519], [69.55014038, 21.66597176], [69.54985809, 21.66597176], [69.54985809, 21.66625023], [69.54957581, 21.66625023], [69.54957581, 21.66653252], [69.54930878, 21.66653252], [69.54930878, 21.6668129], [69.54902649, 21.66680527], [69.54902649, 21.66708374], [69.54846954, 21.66708183], [69.54846954, 21.66736031], [69.54818726, 21.66736031], [69.54818726, 21.66764069], [69.54792023, 21.66764069], [69.54792023, 21.66792107], [69.54763794, 21.66791725], [69.54763794, 21.66819382], [69.54736328, 21.66819382], [69.54736328, 21.66847229], [69.54680634, 21.66847038], [69.54680634, 21.6687603], [69.54651642, 21.6687603], [69.54651642, 21.66903114], [69.54624939, 21.66903114], [69.54624939, 21.66930962], [69.54597473, 21.6693058], [69.54597473, 21.66958237], [69.54569244, 21.66958046], [69.54569244, 21.66986084], [69.54514313, 21.66986084], [69.54514313, 21.67014122], [69.54486084, 21.67014122], [69.54486084, 21.67041969], [69.54458618, 21.67041588], [69.54458618, 21.67069244], [69.54430389, 21.67069244], [69.54430389, 21.67097473], [69.54402924, 21.67097092], [69.54402924, 21.67124939], [69.54374695, 21.67124939], [69.54374695, 21.67152977], [69.54347229, 21.67152786], [69.54347229, 21.6720829], [69.54319763, 21.6720829], [69.54319763, 21.67236137], [69.54292297, 21.67235947], [69.54292297, 21.67263985], [69.54264069, 21.67263985], [69.54264069, 21.67292023], [69.5423584, 21.67291451], [69.5423584, 21.67319679], [69.54208374, 21.67319679], [69.54208374, 21.67347145], [69.54180908, 21.67346954], [69.54180908, 21.67374992], [69.54152679, 21.67374992], [69.54152679, 21.6740303], [69.54125977, 21.6740303], [69.54125977, 21.67431068], [69.5404129, 21.67430687], [69.5404129, 21.67458344], [69.53986359, 21.67458344], [69.53986359, 21.67486191], [69.5395813, 21.67485809], [69.5395813, 21.67514038], [69.53930664, 21.67514038], [69.53930664, 21.67542076], [69.53902435, 21.67541885], [69.53901672, 21.6756897], [69.53874969, 21.67569542], [69.53874969, 21.67597198], [69.53819275, 21.67596817], [69.53819275, 21.67625046], [69.5376358, 21.67625046], [69.5376358, 21.67653084], [69.53736115, 21.67653084], [69.53736115, 21.67680931], [69.53708649, 21.6768055], [69.53708649, 21.67708397], [69.53679657, 21.67707825], [69.53679657, 21.67736053], [69.53652954, 21.67736053], [69.53652954, 21.67764091], [69.53624725, 21.67762947], [69.53624725, 21.67791939], [69.5359726, 21.67791748], [69.5359726, 21.67819405], [69.53569794, 21.67819405], [69.53569794, 21.67847252], [69.53513336, 21.67847061], [69.53513336, 21.67874908], [69.5348587, 21.67874908], [69.5348587, 21.67902946], [69.53457642, 21.67902946], [69.53457642, 21.67931175], [69.53430939, 21.67931175], [69.53430176, 21.68013954], [69.5340271, 21.68013954], [69.5340271, 21.6807003], [69.53347015, 21.68069458], [69.53347015, 21.68097115], [69.53263855, 21.68097115], [69.53263855, 21.68124962], [69.53208923, 21.68124962], [69.53208923, 21.68153191], [69.53180695, 21.68152809], [69.53180695, 21.68180466], [69.53152466, 21.68180466], [69.53152466, 21.68208122], [69.53125, 21.68208122], [69.53125, 21.6823616], [69.53098297, 21.6823597], [69.53098297, 21.68264008], [69.53069305, 21.68264008], [69.53069305, 21.68292046], [69.5304184, 21.68292046], [69.5304184, 21.68320084], [69.53013611, 21.68319321], [69.53013611, 21.68347168], [69.52986145, 21.68346977], [69.52986145, 21.68375969], [69.52958679, 21.68375969], [69.52958679, 21.68403053], [69.52902985, 21.68403053], [69.52902985, 21.68431091], [69.52874756, 21.68430328], [69.52874756, 21.68458557], [69.5284729, 21.68457985], [69.5284729, 21.68486023], [69.52819824, 21.68486023], [69.52819824, 21.68514061], [69.52791595, 21.68514061], [69.52791595, 21.68542099], [69.5276413, 21.68541527], [69.5276413, 21.68569374], [69.52735901, 21.68569374], [69.52735901, 21.68597221], [69.52707672, 21.68597031], [69.52707672, 21.68625069], [69.52680206, 21.68625069], [69.52680206, 21.68653107], [69.5265274, 21.68652534], [69.5265274, 21.68680763], [69.52625275, 21.68680763], [69.52625275, 21.6870842], [69.52597046, 21.68708038], [69.52597046, 21.68736076], [69.5256958, 21.68736076], [69.5256958, 21.68764114], [69.52540588, 21.68764114], [69.52540588, 21.68791962], [69.5248642, 21.68791771], [69.5248642, 21.68819427], [69.52458191, 21.68819427], [69.52458191, 21.68847275], [69.52430725, 21.68847084], [69.52430725, 21.68875122], [69.52403259, 21.68875122], [69.52403259, 21.68902969], [69.52375031, 21.68902969], [69.52375031, 21.68930817], [69.52347565, 21.68930626], [69.52347565, 21.68958282], [69.52319336, 21.68958282], [69.52319336, 21.6898613], [69.5229187, 21.68985748], [69.5229187, 21.69013977], [69.52263641, 21.69013977], [69.52263641, 21.69041824], [69.52236176, 21.69041634], [69.52236176, 21.69069481], [69.5220871, 21.69069481], [69.5220871, 21.69097137], [69.52179718, 21.69096756], [69.52179718, 21.69124985], [69.52153015, 21.69124985], [69.52153015, 21.69153023], [69.52124786, 21.69152832], [69.52124786, 21.69180489], [69.52069092, 21.69180489], [69.52069092, 21.69208336], [69.52041626, 21.69208336], [69.52041626, 21.69236183], [69.52014923, 21.69236183], [69.52014923, 21.6926403], [69.51985931, 21.6926403], [69.51985931, 21.69293022], [69.51957703, 21.69293022], [69.51957703, 21.69320107], [69.51930237, 21.69319534], [69.51930237, 21.69347191], [69.51902771, 21.69347191], [69.51902771, 21.69375038], [69.51875305, 21.69375038], [69.51875305, 21.69403267], [69.51847076, 21.69403267], [69.51847076, 21.69431114], [69.51819611, 21.69430542], [69.51819611, 21.69458389], [69.51790619, 21.69458008], [69.51790619, 21.69486046], [69.51763916, 21.69486046], [69.51763916, 21.69514275], [69.51708984, 21.69514275], [69.51708984, 21.69542122], [69.51680756, 21.69542122], [69.51680756, 21.69569969], [69.51652527, 21.69569206], [69.51652527, 21.69597244], [69.51625061, 21.69597054], [69.51625061, 21.69625092], [69.51597595, 21.69625092], [69.51597595, 21.69652939], [69.51568604, 21.69652939], [69.51568604, 21.69680977], [69.51541901, 21.69680405], [69.51541901, 21.69708252], [69.51513672, 21.69708061], [69.51513672, 21.69736099], [69.51486206, 21.69736099], [69.51486206, 21.69763947], [69.51457977, 21.69763947], [69.51457977, 21.69791985], [69.51430511, 21.69791412], [69.51430511, 21.69819641], [69.51403046, 21.69819641], [69.51403046, 21.69847488], [69.51374817, 21.69847488], [69.51374817, 21.69874954], [69.51319122, 21.69874001], [69.51319122, 21.69902992], [69.51291656, 21.69902992], [69.51291656, 21.6993103], [69.51264191, 21.69930458], [69.51264191, 21.69958305], [69.51235962, 21.69958305], [69.51235962, 21.69986153], [69.51207733, 21.69985962], [69.51207733, 21.70014], [69.51180267, 21.70014], [69.51180267, 21.70042038], [69.51152802, 21.70042038], [69.51152802, 21.70070076], [69.51125336, 21.70069695], [69.51125336, 21.7009716], [69.51095581, 21.7009697], [69.51095581, 21.70125008], [69.51069641, 21.70125008], [69.51069641, 21.70153046], [69.51041412, 21.70152855], [69.51041412, 21.70180511], [69.51013947, 21.70180511], [69.51013947, 21.70208359], [69.50986481, 21.70208359], [69.50986481, 21.70236206], [69.50958252, 21.70236015], [69.50958252, 21.70292091], [69.50930786, 21.7029171], [69.50930786, 21.70319366], [69.50902557, 21.70319366], [69.50902557, 21.70347214], [69.50875092, 21.70346832], [69.50875092, 21.70375061], [69.50846863, 21.70375061], [69.50846863, 21.70402908], [69.50818634, 21.70402908], [69.50818634, 21.70430946], [69.50763702, 21.70430565], [69.50763702, 21.70458412], [69.50736237, 21.7045784], [69.50736237, 21.70487022], [69.50708008, 21.70487022], [69.50708008, 21.70513916], [69.50681305, 21.70513916], [69.50681305, 21.70541954], [69.50653076, 21.70541763], [69.50653076, 21.7056942], [69.50597382, 21.7056942], [69.50597382, 21.70597267], [69.50569153, 21.70597076], [69.50569153, 21.70624924], [69.50541687, 21.70624924], [69.50541687, 21.70652962], [69.50514984, 21.70652962], [69.50514984, 21.7068119], [69.50485992, 21.70680618], [69.50485992, 21.70708275], [69.50458527, 21.70708275], [69.5045929, 21.70736122], [69.50430298, 21.70736122], [69.50430298, 21.70763969], [69.50374603, 21.70763969], [69.50374603, 21.70792961], [69.50347137, 21.70791626], [69.50347137, 21.70819473], [69.50319672, 21.70819473], [69.50319672, 21.7084713], [69.5029068, 21.70846939], [69.5029068, 21.70874977], [69.50263977, 21.70874977], [69.50263977, 21.70903015], [69.50235748, 21.70902824], [69.50235748, 21.70930481], [69.50208282, 21.70930481], [69.50208282, 21.70958328], [69.50180817, 21.70958328], [69.50180817, 21.70986176], [69.50152588, 21.70985985], [69.50152588, 21.71014023], [69.50125122, 21.71014023], [69.50125122, 21.71042061], [69.50068665, 21.71042061], [69.50068665, 21.71070099], [69.50041962, 21.71069336], [69.50041962, 21.71097183], [69.50013733, 21.71096992], [69.50013733, 21.71125031], [69.49986267, 21.71125031], [69.49986267, 21.71153069], [69.49958038, 21.71153069], [69.49958038, 21.71181107], [69.49930573, 21.71180344], [69.49930573, 21.71208572], [69.49901581, 21.71208], [69.49901581, 21.71236038], [69.49874878, 21.71236038], [69.49874878, 21.71264076], [69.49846649, 21.71264076], [69.49846649, 21.71292114], [69.49819183, 21.71291542], [69.49819183, 21.7131958], [69.49791718, 21.7131958], [69.49791718, 21.71347237], [69.49764252, 21.71347237], [69.49764252, 21.71375084], [69.49736023, 21.7137394], [69.49736023, 21.71403122], [69.4970932, 21.71403122], [69.4970932, 21.71430969], [69.49680328, 21.71430779], [69.49680328, 21.71458244], [69.49652863, 21.71458054], [69.49652863, 21.71486092], [69.49624634, 21.71486092], [69.49624634, 21.71513939], [69.49595642, 21.71513939], [69.49595642, 21.71541977], [69.49569702, 21.71541786], [69.49569702, 21.71569443], [69.49541473, 21.71569443], [69.49541473, 21.7159729], [69.49514008, 21.71597099], [69.49514008, 21.71624947], [69.49485779, 21.71624947], [69.49485779, 21.71652985], [69.49458313, 21.71652985], [69.49458313, 21.71680832], [69.49430847, 21.71680641], [69.49430847, 21.71708298], [69.49402618, 21.71707916], [69.49402618, 21.71763992], [69.49375153, 21.71763992], [69.49375153, 21.7179184], [69.49346924, 21.7179184], [69.49346924, 21.71820259], [69.49319458, 21.71819496], [69.49319458, 21.71847153], [69.49291992, 21.71847153], [69.49291992, 21.71875191], [69.49263763, 21.71875191], [69.49263763, 21.71903038], [69.49236298, 21.71903038], [69.49236298, 21.71931267], [69.49208069, 21.71930504], [69.49208069, 21.71958351], [69.49180603, 21.7195816], [69.49180603, 21.71986961], [69.49153137, 21.71986961], [69.49153137, 21.72014046], [69.49124908, 21.72014046], [69.49124908, 21.72042274], [69.49097443, 21.72041702], [69.49097443, 21.72069359], [69.49069214, 21.72069359], [69.49069214, 21.72097015], [69.49041748, 21.72097015], [69.49041748, 21.72125053], [69.49014282, 21.72125053], [69.49014282, 21.72153282], [69.48986053, 21.72153282], [69.48986053, 21.72180939], [69.48958588, 21.72180557], [69.48958588, 21.72208214], [69.48929596, 21.72208023], [69.48929596, 21.72236061], [69.48902893, 21.72236061], [69.48902893, 21.7226429], [69.48874664, 21.72263908], [69.48874664, 21.72291756], [69.48847198, 21.72291756], [69.48847198, 21.7234726], [69.48819733, 21.72347069], [69.48819733, 21.72402954], [69.48791504, 21.72402763], [69.48791504, 21.72458267], [69.48764038, 21.72458076], [69.48764038, 21.72513962], [69.48735809, 21.72513962], [69.48735809, 21.72542], [69.48680878, 21.72541428], [69.48680878, 21.72569656], [69.48652649, 21.72569656], [69.48652649, 21.72597313], [69.48568726, 21.72597122], [69.48568726, 21.72624969], [69.48542023, 21.72624969], [69.48542023, 21.72653008], [69.48513794, 21.72652626], [69.48513794, 21.72680664], [69.48486328, 21.72680664], [69.48486328, 21.72708321], [69.48458099, 21.72708321], [69.48458099, 21.72736168], [69.48401642, 21.72735977], [69.48401642, 21.72764015], [69.48374939, 21.72764015], [69.48374939, 21.72792053], [69.4834671, 21.72792053], [69.4834671, 21.72820091], [69.48319244, 21.72819519], [69.48319244, 21.72847176], [69.48291779, 21.72846985], [69.48291779, 21.72875023], [69.48264313, 21.72875023], [69.48264313, 21.72903061], [69.48236084, 21.7290287], [69.48236084, 21.72958374], [69.48208618, 21.72957993], [69.48208618, 21.72986031], [69.48179626, 21.72986031], [69.48179626, 21.73014069], [69.48152924, 21.73014069], [69.48152924, 21.73069382], [69.48124695, 21.73069382], [69.48124695, 21.73097229], [69.48097229, 21.73097229], [69.48097992, 21.73125076], [69.48069763, 21.73125076], [69.48069763, 21.73152924], [69.48042297, 21.73152924], [69.48042297, 21.73181152], [69.48014069, 21.7318058], [69.48014069, 21.73208427], [69.4798584, 21.73207855], [69.4798584, 21.73236084], [69.47957611, 21.73236084], [69.47957611, 21.73291969], [69.47930908, 21.73291588], [69.47930908, 21.73319435], [69.47902679, 21.73319435], [69.47902679, 21.73347282], [69.47875214, 21.73347282], [69.47875214, 21.73374939], [69.47846985, 21.73374939], [69.47846985, 21.73402977], [69.47820282, 21.73402977], [69.47820282, 21.73431015], [69.4779129, 21.73430634], [69.4779129, 21.7345829], [69.47763824, 21.7345829], [69.47763824, 21.73486137], [69.4770813, 21.73485184], [69.4770813, 21.73513985], [69.47680664, 21.73513985], [69.47680664, 21.73542023], [69.47652435, 21.73541641], [69.47652435, 21.73569489], [69.47624969, 21.73569489], [69.47624969, 21.73597145], [69.47597504, 21.73597145], [69.47598267, 21.73624992], [69.47541809, 21.73624992], [69.47541809, 21.7365303], [69.4751358, 21.7365303], [69.4751358, 21.73681068], [69.47486115, 21.73680305], [69.47486115, 21.73708344], [69.47458649, 21.73708344], [69.47458649, 21.73736191], [69.47429657, 21.73736], [69.47429657, 21.73764038], [69.47402954, 21.73763847], [69.47402954, 21.73791695], [69.4734726, 21.73791695], [69.4734726, 21.7381897], [69.47319794, 21.73819351], [69.47319794, 21.73847198], [69.47291565, 21.73847198], [69.47292328, 21.73875046], [69.4723587, 21.73875046], [69.4723587, 21.73903084], [69.47207642, 21.73903084], [69.47207642, 21.73931122], [69.47180939, 21.7393074], [69.47180176, 21.73958588], [69.4715271, 21.73958015], [69.4715271, 21.74014091], [69.47125244, 21.74014091], [69.47125244, 21.74041939], [69.47097015, 21.74041748], [69.47097015, 21.74069595], [69.4706955, 21.74069595], [69.4706955, 21.74097252], [69.47013855, 21.74097061], [69.47013855, 21.74125099], [69.4695816, 21.74125099], [69.4695816, 21.74152946], [69.46930695, 21.74152946], [69.46930695, 21.74180984], [69.46875, 21.74180794], [69.46875, 21.7420826], [69.46819305, 21.74208069], [69.46819305, 21.74236107], [69.46763611, 21.74236107], [69.46763611, 21.74263954], [69.46708679, 21.74263954], [69.46708679, 21.74291992], [69.46652985, 21.74291611], [69.46652985, 21.74319458], [69.46624756, 21.74319458], [69.46624756, 21.74347305], [69.46569824, 21.74347115], [69.46569824, 21.74374962], [69.4651413, 21.74374962], [69.4651413, 21.74403954], [69.46458435, 21.74402809], [69.46458435, 21.74430466], [69.46430206, 21.74430466], [69.46430206, 21.74458313], [69.46375275, 21.74458313], [69.46375275, 21.7448616], [69.4631958, 21.7448597], [69.4631958, 21.74514008], [69.46290588, 21.74514008], [69.46290588, 21.74542236], [69.46235657, 21.74542236], [69.46235657, 21.74570274], [69.46180725, 21.74569511], [69.46180725, 21.74597168], [69.46152496, 21.74597168], [69.46152496, 21.74625015], [69.46098328, 21.74625015], [69.46098328, 21.74653053], [69.4604187, 21.74653053], [69.4604187, 21.74681282], [69.45986176, 21.74680519], [69.45986176, 21.74708366], [69.4595871, 21.74708176], [69.4595871, 21.74736023], [69.45903015, 21.74736023], [69.45903015, 21.74764061], [69.45847321, 21.74764061], [69.45847321, 21.7479229], [69.45819092, 21.74791718], [69.45819092, 21.74819374], [69.4576416, 21.74819374], [69.4576416, 21.74847221], [69.45707703, 21.74847031], [69.45708466, 21.74875069], [69.45681, 21.74875069], [69.45681, 21.74903107], [69.45625305, 21.74903107], [69.45625305, 21.74930954], [69.45569611, 21.74930573], [69.45569611, 21.74958229], [69.45541382, 21.74958229], [69.45541382, 21.74986076], [69.45485687, 21.74985123], [69.45485687, 21.75014114], [69.45458221, 21.75014114], [69.45458221, 21.75041962], [69.45402527, 21.7504158], [69.45402527, 21.75069237], [69.45375061, 21.75069237], [69.45375061, 21.75097275], [69.45318604, 21.75097084], [69.45318604, 21.75125122], [69.45291901, 21.75125122], [69.45291901, 21.75152969], [69.45236206, 21.75152969], [69.45236206, 21.75181007], [69.45207977, 21.75180435], [69.45207977, 21.75208282], [69.45153046, 21.75208282], [69.45153046, 21.7523613], [69.45124817, 21.75235939], [69.45124817, 21.75263977], [69.45069122, 21.75263977], [69.45069122, 21.75319672], [69.45041656, 21.75319672], [69.45041656, 21.75347137], [69.45014191, 21.75346947], [69.45014191, 21.75374985], [69.44985962, 21.75374985], [69.44985962, 21.75403023], [69.44958496, 21.75402832], [69.44958496, 21.75430679], [69.44930267, 21.75430679], [69.44930267, 21.75458336], [69.44902802, 21.75458336], [69.44902802, 21.75486183], [69.44875336, 21.75485992], [69.44875336, 21.7551403], [69.44847107, 21.7551403], [69.44847107, 21.75542068], [69.44819641, 21.75542068], [69.44819641, 21.75569916], [69.44790649, 21.75569916], [69.44790649, 21.75597763], [69.44735718, 21.75597763], [69.44735718, 21.75625038], [69.44708252, 21.75625038], [69.44708252, 21.75653076], [69.44680786, 21.75653076], [69.44680786, 21.75680923], [69.44652557, 21.75680542], [69.44652557, 21.75708389], [69.44625092, 21.75707817], [69.44625092, 21.75736046], [69.44568634, 21.75736046], [69.44568634, 21.75764084], [69.44541931, 21.75764084], [69.44541931, 21.75791931], [69.44513702, 21.7579174], [69.44513702, 21.75819397], [69.44486237, 21.75819397], [69.44487, 21.75875092], [69.44458008, 21.75875092], [69.44458008, 21.75904274], [69.44431305, 21.75904274], [69.44431305, 21.75931168], [69.44403076, 21.75931168], [69.44403076, 21.76013947], [69.44210052, 21.76013947], [69.44210052, 21.76042175], [69.44097137, 21.76041603], [69.44097137, 21.7606945], [69.44013977, 21.7606945], [69.44013977, 21.76097107], [69.43985748, 21.76097107], [69.43985748, 21.76124954], [69.43958282, 21.76124954], [69.43958282, 21.7618103], [69.43930817, 21.7618103], [69.43930817, 21.76264], [69.43818665, 21.76264], [69.43818665, 21.76292038], [69.43791962, 21.76292038], [69.43791962, 21.76320076], [69.43763733, 21.76319313], [69.43763733, 21.7634716], [69.43736267, 21.7634697], [69.43736267, 21.76403046], [69.43708038, 21.76403046], [69.43708038, 21.76431084], [69.43680573, 21.76430321], [69.43680573, 21.76458359], [69.43624878, 21.76458359], [69.43624878, 21.76486206], [69.43567657, 21.76486015], [69.43567657, 21.76514053], [69.43541718, 21.76514053], [69.43541718, 21.76542091], [69.43486023, 21.76541519], [69.43486023, 21.76569366], [69.43430328, 21.76569366], [69.43430328, 21.76597214], [69.43402863, 21.76597023], [69.43402863, 21.76625061], [69.43374634, 21.76625061], [69.43374634, 21.76653099], [69.43347168, 21.76653099], [69.43347168, 21.76680946], [69.43319702, 21.76680756], [69.43319702, 21.76708412], [69.4329071, 21.76708031], [69.4329071, 21.76736069], [69.43235779, 21.76736069], [69.43235779, 21.76764107], [69.43208313, 21.76764107], [69.43208313, 21.76791954], [69.43180847, 21.76791763], [69.43180847, 21.7681942], [69.43152618, 21.7681942], [69.43152618, 21.76847267], [69.43125153, 21.76847076], [69.43125153, 21.76875114], [69.43096924, 21.76875114], [69.43096924, 21.76902962], [69.43068695, 21.76902962], [69.43068695, 21.76930809], [69.43041992, 21.76930618], [69.43041992, 21.76958275], [69.43013763, 21.76958084], [69.43013763, 21.76986122], [69.42986298, 21.76986122], [69.42987061, 21.77013969], [69.42930603, 21.77013969], [69.42930603, 21.77041817], [69.42903137, 21.77041626], [69.42903137, 21.77069473], [69.42874908, 21.77069092], [69.42874908, 21.77098083], [69.4284668, 21.77098083], [69.4284668, 21.77124977], [69.42819214, 21.77124977], [69.42819214, 21.77152824], [69.42791748, 21.77152824], [69.42791748, 21.77180481], [69.42763519, 21.77180481], [69.42763519, 21.77208328], [69.42736053, 21.77208328], [69.42736053, 21.77236176], [69.42708588, 21.77236176], [69.42708588, 21.77264023], [69.42679596, 21.77264023], [69.42679596, 21.77292252], [69.42652893, 21.77292252], [69.42652893, 21.7732029], [69.42624664, 21.77319527], [69.42624664, 21.77347183], [69.42597198, 21.77347183], [69.42597198, 21.77375031], [69.42569733, 21.77375031], [69.42569733, 21.77402687], [69.42542267, 21.77401924], [69.42542267, 21.77431107], [69.42514038, 21.77431107], [69.42514038, 21.77486038], [69.42485809, 21.77486038], [69.42485809, 21.77514076], [69.42457581, 21.77514076], [69.42457581, 21.77542114], [69.42430878, 21.77541733], [69.42430878, 21.77569389], [69.42402649, 21.77569389], [69.42402649, 21.77597237], [69.42373657, 21.77597046], [69.42373657, 21.77625084], [69.42346954, 21.77625084], [69.42346954, 21.77653122], [69.42318726, 21.77653122], [69.42318726, 21.77680969], [69.42292023, 21.77680588], [69.42292023, 21.77708244], [69.42263794, 21.77708054], [69.42263794, 21.77736092], [69.42236328, 21.77736092], [69.42236328, 21.77763939], [69.42208099, 21.77763939], [69.42208099, 21.77791977], [69.42180634, 21.77791405], [69.42180634, 21.77819443], [69.42152405, 21.77819443], [69.42152405, 21.77847481], [69.42124939, 21.77847099], [69.42124939, 21.77874947], [69.4209671, 21.77874947], [69.4209671, 21.77902985], [69.42067719, 21.77902985], [69.42067719, 21.77931023], [69.42041779, 21.7793045], [69.42041779, 21.77958298], [69.4201355, 21.77958298], [69.4201355, 21.77986145], [69.41986084, 21.77985954], [69.41986084, 21.78014946], [69.41958618, 21.78014946], [69.41958618, 21.7804203], [69.41929626, 21.7804203], [69.41929626, 21.78070068], [69.41902924, 21.78069687], [69.41902924, 21.78097153], [69.41874695, 21.78096962], [69.41874695, 21.78125], [69.41847229, 21.78125], [69.41847229, 21.78153038], [69.41819763, 21.78153038], [69.41819763, 21.78181076], [69.41791534, 21.78180695], [69.41791534, 21.78208351], [69.41764069, 21.78208351], [69.41764069, 21.78236198], [69.4173584, 21.78235817], [69.4173584, 21.78264046], [69.41707611, 21.78264046], [69.41707611, 21.78292084], [69.41680908, 21.78291893], [69.41680908, 21.78319359], [69.41652679, 21.78319359], [69.41652679, 21.78347206], [69.41625214, 21.78346825], [69.41625214, 21.78375053], [69.41596985, 21.78375053], [69.41596985, 21.78403091], [69.41570282, 21.78403091], [69.41570282, 21.78430939], [69.4154129, 21.78430557], [69.4154129, 21.78458405], [69.41485596, 21.78457832], [69.41485596, 21.78486061], [69.4145813, 21.78486061], [69.4145813, 21.78513908], [69.41430664, 21.78513908], [69.41430664, 21.78541946], [69.41402435, 21.78541756], [69.41402435, 21.78569412], [69.41374969, 21.78569412], [69.41374969, 21.7859726], [69.41348267, 21.78596115], [69.41348267, 21.78624916], [69.41319275, 21.78624916], [69.41319275, 21.78652954], [69.41291809, 21.78652954], [69.41291809, 21.78681183], [69.4126358, 21.78680611], [69.4126358, 21.78708267], [69.41236115, 21.78708267], [69.41236115, 21.78736115], [69.41208649, 21.78736115], [69.41208649, 21.78763962], [69.41179657, 21.78763962], [69.41179657, 21.78792191], [69.41152954, 21.78791618], [69.41152954, 21.78819466], [69.4109726, 21.78819466], [69.4109726, 21.78847122], [69.41069794, 21.78847122], [69.41069794, 21.78874969], [69.41041565, 21.78874969], [69.41041565, 21.78902817], [69.41014099, 21.78902817], [69.41014099, 21.78930473], [69.4098587, 21.78930473], [69.4098587, 21.78958321], [69.40958405, 21.78958321], [69.40958405, 21.78986168], [69.4090271, 21.78985977], [69.4090271, 21.79014015], [69.40876007, 21.79014015], [69.40876007, 21.79042053], [69.40847015, 21.79042053], [69.40847015, 21.79070091], [69.4081955, 21.79069328], [69.4081955, 21.79097176], [69.40791321, 21.79096985], [69.40791321, 21.79125023], [69.40735626, 21.79125023], [69.40735626, 21.79153061], [69.4070816, 21.79153061], [69.4070816, 21.79181099], [69.40680695, 21.79181099], [69.40680695, 21.79208946], [69.40651703, 21.79208946], [69.40651703, 21.79236031], [69.40625, 21.79236031], [69.40625, 21.79264069], [69.4059906, 21.79264069], [69.4059906, 21.79292107], [69.4054184, 21.79291534], [69.4054184, 21.79319382], [69.40513611, 21.79319382], [69.40513611, 21.79347229], [69.40486145, 21.79347038], [69.40486145, 21.79375076], [69.40458679, 21.79375076], [69.40458679, 21.79403114], [69.40402985, 21.79403114], [69.40402985, 21.79430962], [69.40374756, 21.79430771], [69.40374756, 21.79458427], [69.4034729, 21.79458046], [69.4034729, 21.79486084], [69.40291595, 21.79486084], [69.40291595, 21.79515076], [69.4026413, 21.79515076], [69.4026413, 21.79541969], [69.40235901, 21.79541779], [69.40235901, 21.79569435], [69.40180206, 21.79569435], [69.40180206, 21.79597282], [69.4015274, 21.79597092], [69.4015274, 21.79624939], [69.40125275, 21.79624939], [69.40125275, 21.79652977], [69.4006958, 21.79652977], [69.4006958, 21.79680824], [69.40041351, 21.79680634], [69.40041351, 21.7970829], [69.40013885, 21.7970829], [69.40013885, 21.79736137], [69.39985657, 21.79735756], [69.39985657, 21.79763985], [69.39956665, 21.79763985], [69.39956665, 21.79791832], [69.39930725, 21.79791641], [69.39930725, 21.79819489], [69.39902496, 21.79819489], [69.39903259, 21.79875183], [69.39875031, 21.79875183], [69.39875031, 21.7990303], [69.39848328, 21.7990303], [69.39848328, 21.79931259], [69.39819336, 21.79930496], [69.39819336, 21.79958344], [69.3979187, 21.79958344], [69.3979187, 21.79986191], [69.39763641, 21.79986191], [69.39763641, 21.80014038], [69.39736176, 21.80014038], [69.39736176, 21.80042267], [69.3970871, 21.80041695], [69.3970871, 21.8006916], [69.39680481, 21.80069542], [69.39680481, 21.80097008], [69.39653015, 21.80095863], [69.39653015, 21.80125046], [69.39624786, 21.80125046], [69.39620209, 21.80181122], [69.39597321, 21.8018055], [69.39597321, 21.80208206], [69.39569092, 21.80208015], [69.39569092, 21.80236053], [69.39541626, 21.80236053], [69.39541626, 21.80264282], [69.3951416, 21.80264282], [69.3951416, 21.80291939], [69.39485931, 21.80291748], [69.39485931, 21.80319214], [69.39458466, 21.80319214], [69.39458466, 21.80347252], [69.39430237, 21.80347061], [69.39430237, 21.80402946], [69.39402771, 21.80402946], [69.39402771, 21.80431938], [69.39375305, 21.80430412], [69.39375305, 21.8045826], [69.39347076, 21.80458069], [69.39347076, 21.80486107], [69.39319611, 21.80486107], [69.39319611, 21.80513954], [69.39291382, 21.80513954], [69.39291382, 21.80569649], [69.39263916, 21.80569649], [69.39263916, 21.80597305], [69.39235687, 21.80597115], [69.39235687, 21.80624962], [69.39208221, 21.80624962], [69.39208221, 21.80653], [69.39180756, 21.80652618], [69.39180756, 21.80680466], [69.39152527, 21.80680466], [69.39152527, 21.8073616], [69.39125061, 21.8073597], [69.39125061, 21.80764008], [69.39097595, 21.80764008], [69.39097595, 21.80792046], [69.39070129, 21.80792046], [69.39070129, 21.80820084], [69.39041901, 21.80819511], [69.39041901, 21.80847168], [69.39013672, 21.80846977], [69.39013672, 21.80903053], [69.38986206, 21.80903053], [69.38986206, 21.80931091], [69.38957977, 21.80930519], [69.38957977, 21.80958366], [69.38930511, 21.80958366], [69.38931274, 21.80986023], [69.38903046, 21.80986023], [69.38903046, 21.8101387], [69.38874817, 21.8101387], [69.38874817, 21.81069374], [69.38847351, 21.81069374], [69.38847351, 21.81097221], [69.38819122, 21.8109684], [69.38819122, 21.81125069], [69.38791656, 21.81125069], [69.38791656, 21.81152916], [69.38762665, 21.81152916], [69.38762665, 21.81180954], [69.38735962, 21.81180954], [69.38735962, 21.81236076], [69.38707733, 21.81236076], [69.38707733, 21.81263924], [69.38680267, 21.81263924], [69.38680267, 21.81291962], [69.38652802, 21.8129158], [69.38652802, 21.81319427], [69.38625336, 21.81319427], [69.38625336, 21.81347275], [69.38597107, 21.81347275], [69.38597107, 21.81402969], [69.38569641, 21.81402969], [69.38569641, 21.81431007], [69.38541412, 21.81430626], [69.38541412, 21.81458282], [69.38513947, 21.81458282], [69.38513947, 21.8148613], [69.38485718, 21.81485939], [69.38485718, 21.81513977], [69.38458252, 21.81513977], [69.38458252, 21.81569481], [69.38430786, 21.81569481], [69.38430786, 21.81597137], [69.3840332, 21.81596947], [69.3840332, 21.81625938], [69.38375092, 21.81625938], [69.38375092, 21.81653023], [69.38346863, 21.81652832], [69.38346863, 21.81680489], [69.38319397, 21.81680489], [69.38319397, 21.81736183], [69.38291931, 21.81735992], [69.38291931, 21.8176403], [69.38263702, 21.8176403], [69.38263702, 21.81792068], [69.38236237, 21.81791687], [69.38236237, 21.81847191], [69.38208008, 21.81847], [69.38208008, 21.81875038], [69.38182068, 21.81875038], [69.38182068, 21.81903076], [69.38153076, 21.81902695], [69.38153076, 21.8195858], [69.38124847, 21.81958008], [69.38124847, 21.81986046], [69.38096619, 21.81986046], [69.38096619, 21.82014084], [69.38069153, 21.82013893], [69.38069153, 21.82069588], [69.38041687, 21.82069588], [69.38041687, 21.82097244], [69.38014221, 21.82097054], [69.38014221, 21.82125092], [69.37985992, 21.82125092], [69.37985992, 21.82152939], [69.37958527, 21.82152557], [69.37958527, 21.82208252], [69.37930298, 21.82207108], [69.37930298, 21.82236099], [69.37902832, 21.82236099], [69.37902832, 21.82263947], [69.37876129, 21.82263947], [69.37876129, 21.82291985], [69.37847137, 21.82291794], [69.37847137, 21.8231945], [69.37819672, 21.82319069], [69.37819672, 21.82374954], [69.3779068, 21.82374954], [69.3779068, 21.82402992], [69.37763977, 21.82402992], [69.37763977, 21.8243084], [69.37735748, 21.82430649], [69.37735748, 21.82458305], [69.37708282, 21.82458305], [69.37708282, 21.82513809], [69.37680817, 21.82513046], [69.37680817, 21.82542038], [69.37652588, 21.82542038], [69.37652588, 21.82570267], [69.37625122, 21.82569504], [69.37625122, 21.8259716], [69.37596893, 21.8259716], [69.37596893, 21.82625008], [69.37568665, 21.82625008], [69.37568665, 21.82653046], [69.37513733, 21.82653046], [69.37513733, 21.82681274], [69.37486267, 21.82680511], [69.37486267, 21.82708359], [69.37458038, 21.82708359], [69.37458038, 21.82736015], [69.37431335, 21.82736015], [69.37431335, 21.82764053], [69.37403107, 21.82764053], [69.37403107, 21.82792282], [69.37374878, 21.82792282], [69.37374878, 21.82819939], [69.37319183, 21.82819366], [69.37319183, 21.82847214], [69.37291718, 21.82847023], [69.37291718, 21.82875061], [69.37262726, 21.82875061], [69.37262726, 21.8290329], [69.37236023, 21.8290329], [69.37236023, 21.82930946], [69.37180328, 21.82930565], [69.37180328, 21.82958221], [69.37152863, 21.82958031], [69.37152863, 21.82986069], [69.37124634, 21.82986069], [69.37124634, 21.83014107], [69.37097168, 21.83014107], [69.37097168, 21.83041954], [69.37041473, 21.83041763], [69.37041473, 21.83069229], [69.37014008, 21.83069229], [69.37014008, 21.83097267], [69.36985779, 21.83097076], [69.36985779, 21.83126068], [69.36959076, 21.83126068], [69.36959076, 21.83152962], [69.36902618, 21.83152962], [69.36902618, 21.83181], [69.36875153, 21.83180428], [69.36875153, 21.83208275], [69.36846924, 21.83208084], [69.36846924, 21.83236122], [69.36791992, 21.83236122], [69.36791992, 21.83263969], [69.36736298, 21.83263969], [69.36736298, 21.83292007], [69.36680603, 21.83291435], [69.36680603, 21.83319664], [69.36624908, 21.83319664], [69.36624908, 21.8334713], [69.36569214, 21.83346939], [69.36569214, 21.83374977], [69.36514282, 21.83374977], [69.36514282, 21.83403015], [69.36458588, 21.83402634], [69.36458588, 21.83430672], [69.36402893, 21.83430672], [69.36402893, 21.83458328], [69.36347198, 21.83458328], [69.36347198, 21.83486176], [69.36292267, 21.83485985], [69.36292267, 21.83514023], [69.36152649, 21.83514023], [69.36152649, 21.83542061], [69.36096954, 21.83542061], [69.36096954, 21.83569908], [69.36042023, 21.83569908], [69.36042023, 21.83625031], [69.36013794, 21.83625031], [69.36013794, 21.83653069], [69.35958099, 21.83653069], [69.35958099, 21.83680916], [69.35902405, 21.83680534], [69.35902405, 21.83708382], [69.35819244, 21.83707047], [69.35819244, 21.83736038], [69.35597229, 21.83736038], [69.35597229, 21.83764076], [69.35514069, 21.83764076], [69.35514069, 21.83791924], [69.35430908, 21.83791733], [69.35430908, 21.83819389], [69.35375214, 21.83819389], [69.35375214, 21.83847237], [69.3529129, 21.83847046], [69.3529129, 21.83875084], [69.3520813, 21.83875084], [69.3520813, 21.83902931], [69.35180664, 21.83902931], [69.35180664, 21.8393116], [69.35152435, 21.83930588], [69.35152435, 21.83958244], [69.35097504, 21.83958244], [69.35098267, 21.83986092], [69.35069275, 21.83986092], [69.35069275, 21.84013939], [69.35041809, 21.84013939], [69.35041809, 21.84041977], [69.3501358, 21.84041595], [69.3501358, 21.84069443], [69.34958649, 21.84069443], [69.34958649, 21.8409729], [69.34929657, 21.8409729], [69.34929657, 21.84124947], [69.34902954, 21.84124947], [69.34902954, 21.84152985], [69.34874725, 21.84152985], [69.34874725, 21.84181023], [69.3484726, 21.84180641], [69.3484726, 21.84208107], [69.34791565, 21.84208107], [69.34791565, 21.84236145], [69.34764099, 21.84235954], [69.34764099, 21.84263992], [69.3473587, 21.84263992], [69.3473587, 21.8429203], [69.34707642, 21.8429203], [69.34707642, 21.84320068], [69.3465271, 21.84319305], [69.3465271, 21.84347153], [69.34625244, 21.84346962], [69.34625244, 21.84375], [69.34597015, 21.84375], [69.34597015, 21.84403038], [69.34571075, 21.84403038], [69.34571075, 21.84431076], [69.34541321, 21.84430313], [69.34541321, 21.84458351], [69.34486389, 21.84458351], [69.34486389, 21.84486198], [69.3445816, 21.84486008], [69.3445816, 21.84514046], [69.34430695, 21.84514046], [69.34430695, 21.84542084], [69.34402466, 21.84541512], [69.34402466, 21.84569359], [69.34375, 21.84569359], [69.34375, 21.84597206], [69.34319305, 21.84597206], [69.34319305, 21.84625053], [69.3429184, 21.846241], [69.3429184, 21.84653091], [69.34265137, 21.84653091], [69.34265137, 21.84680939], [69.34236145, 21.84680748], [69.34236145, 21.84708595], [69.34179688, 21.84708023], [69.34179688, 21.84736061], [69.34152985, 21.84736061], [69.34152985, 21.84764099], [69.34124756, 21.84764099], [69.34124756, 21.84791946], [69.3409729, 21.84791756], [69.3409729, 21.84819412], [69.34041595, 21.84819412], [69.34041595, 21.8484726], [69.3401413, 21.84847069], [69.3401413, 21.84875107], [69.33985901, 21.84875107], [69.33985901, 21.84902954], [69.33930206, 21.84902954], [69.33930206, 21.84930611], [69.3390274, 21.84930611], [69.3390274, 21.84958267], [69.33847046, 21.84958076], [69.33847046, 21.84986115], [69.3381958, 21.84986115], [69.3381958, 21.85013962], [69.33790588, 21.85013962], [69.33790588, 21.85041809], [69.3373642, 21.85041618], [69.3373642, 21.85069466], [69.33708191, 21.85069466], [69.33708191, 21.85097313], [69.33680725, 21.85097122], [69.33680725, 21.85124969], [69.33625031, 21.85124969], [69.33625031, 21.85152817], [69.33597565, 21.85152817], [69.33597565, 21.85180473], [69.33569336, 21.85180473], [69.33569336, 21.85208321], [69.33513641, 21.85208321], [69.33513641, 21.85236168], [69.33486176, 21.85236168], [69.33486176, 21.85264015], [69.33429718, 21.85264015], [69.33429718, 21.85292244], [69.33403015, 21.85292244], [69.33403015, 21.85320282], [69.33374786, 21.85319519], [69.33374786, 21.85347176], [69.33319092, 21.85347176], [69.33319092, 21.85375023], [69.33291626, 21.85375023], [69.33291626, 21.85403061], [69.3326416, 21.85403061], [69.3326416, 21.8543129], [69.33208466, 21.85430527], [69.33208466, 21.85458374], [69.33180237, 21.85458183], [69.33180237, 21.85486031], [69.33152771, 21.85486031], [69.33152771, 21.85514069], [69.33125305, 21.85514069], [69.33125305, 21.8554306], [69.33069611, 21.85541725], [69.33069611, 21.85569382], [69.33041382, 21.85569382], [69.33041382, 21.85597229], [69.33013916, 21.85597038], [69.33013916, 21.85625076], [69.32985687, 21.85625076], [69.32985687, 21.85653114], [69.32930756, 21.85653114], [69.32930756, 21.85680962], [69.32902527, 21.8568058], [69.32902527, 21.85708237], [69.32875061, 21.85708046], [69.32875061, 21.85736084], [69.32847595, 21.85736084], [69.32847595, 21.85764122], [69.32791901, 21.85764122], [69.32791901, 21.85791969], [69.32763672, 21.85791588], [69.32763672, 21.85819435], [69.32736206, 21.85819435], [69.32736206, 21.85847282], [69.32707977, 21.85847092], [69.32707977, 21.85874939], [69.32653046, 21.85874939], [69.32653046, 21.85902977], [69.32624817, 21.85902977], [69.32624817, 21.85931015], [69.32597351, 21.85930443], [69.32597351, 21.8595829], [69.32569122, 21.8595829], [69.32569122, 21.85986137], [69.32514191, 21.85985947], [69.32514191, 21.86013985], [69.32485962, 21.86013985], [69.32485962, 21.86042023], [69.32458496, 21.86041451], [69.32458496, 21.86069679], [69.32430267, 21.86069679], [69.32430267, 21.86097145], [69.32375336, 21.86097145], [69.32375336, 21.86124992], [69.32347107, 21.86124039], [69.32347107, 21.8615303], [69.32319641, 21.8615303], [69.32319641, 21.86181068], [69.32291412, 21.86180687], [69.32291412, 21.86208344], [69.32263947, 21.86208344], [69.32263947, 21.86236191], [69.32235718, 21.86235809], [69.32235718, 21.86264038], [69.32208252, 21.86264038], [69.32208252, 21.86292076], [69.32180786, 21.86291885], [69.32180786, 21.8631897], [69.32152557, 21.86319542], [69.32152557, 21.86347198], [69.32125092, 21.86346817], [69.32125092, 21.86375046], [69.32096863, 21.86375046], [69.32096863, 21.86403084], [69.32069397, 21.86402893], [69.32069397, 21.8643055], [69.32041931, 21.8643055], [69.32041931, 21.86458397], [69.31986237, 21.86457825], [69.31986237, 21.86486053], [69.31958008, 21.86486053], [69.31958008, 21.86514091], [69.31931305, 21.86514091], [69.31931305, 21.86541939], [69.31903076, 21.86541748], [69.31903076, 21.86569405], [69.31874847, 21.86569405], [69.31874847, 21.86597252], [69.31848145, 21.86597061], [69.31848145, 21.86624908], [69.31819153, 21.86624908], [69.31819153, 21.86652946], [69.31791687, 21.86652946], [69.31791687, 21.86681175], [69.31764221, 21.86680603], [69.31764221, 21.8670826], [69.31735992, 21.8670826], [69.31735992, 21.86737061], [69.31708527, 21.86736107], [69.3170929, 21.86763954], [69.31680298, 21.86763954], [69.31680298, 21.86792183], [69.31652832, 21.86791611], [69.31652832, 21.86819458], [69.31597137, 21.86819458], [69.31597137, 21.86847115], [69.31569672, 21.86847115], [69.31569672, 21.86874962], [69.3154068, 21.86874962], [69.3154068, 21.86903], [69.31513977, 21.86902809], [69.31513977, 21.86930466], [69.31458282, 21.86930466], [69.31458282, 21.86958122], [69.31430817, 21.86958122], [69.31430817, 21.8698616], [69.31402588, 21.8698597], [69.31402588, 21.87014008], [69.31346893, 21.87014008], [69.31346893, 21.87042999], [69.31318665, 21.87042999], [69.31318665, 21.87070084], [69.31291962, 21.87069321], [69.31291962, 21.87097168], [69.31263733, 21.87096977], [69.31263733, 21.87125015], [69.31208038, 21.87125015], [69.31208038, 21.87153053], [69.31181335, 21.87153053], [69.31181335, 21.87181091], [69.31153107, 21.87180328], [69.31153107, 21.87208366], [69.31124878, 21.87207985], [69.31124878, 21.87236023], [69.31069183, 21.87236023], [69.31069183, 21.87264061], [69.31041718, 21.87264061], [69.31041718, 21.87292099], [69.31014252, 21.87291527], [69.31014252, 21.87319374], [69.30958557, 21.87319374], [69.30958557, 21.87347221], [69.30928802, 21.87347031], [69.30928802, 21.87375069], [69.30902863, 21.87375069], [69.30902863, 21.87403107], [69.30819702, 21.87402534], [69.30819702, 21.8745842], [69.3079071, 21.87458038], [69.3079071, 21.87486076], [69.30764008, 21.87486076], [69.30764008, 21.87514114], [69.30735779, 21.87514114], [69.30735779, 21.87541962], [69.30680847, 21.87541771], [69.30680847, 21.87569427], [69.30652618, 21.87569427], [69.30652618, 21.87597275], [69.30625153, 21.87597275], [69.30625153, 21.87624741], [69.30596924, 21.87623978], [69.30596924, 21.87652969], [69.30568695, 21.87652969], [69.30568695, 21.87680817], [69.30513763, 21.87680626], [69.30513763, 21.87708282], [69.30486298, 21.87708282], [69.30486298, 21.8773613], [69.30458069, 21.87735748], [69.30458069, 21.87763977], [69.30430603, 21.87763977], [69.30430603, 21.87791824], [69.30403137, 21.87791634], [69.30403137, 21.87819481], [69.30374908, 21.87819481], [69.30374908, 21.87847137], [69.30319214, 21.87846756], [69.30319214, 21.87875175], [69.30291748, 21.87875175], [69.30291748, 21.87903023], [69.30264282, 21.87903023], [69.30264282, 21.87931252], [69.30236053, 21.87930489], [69.30236053, 21.87958336], [69.30208588, 21.87958336], [69.30208588, 21.87986183], [69.30179596, 21.87986183], [69.30179596, 21.8801403], [69.30152893, 21.8801403], [69.30152893, 21.88042259], [69.30097198, 21.88042259], [69.30097198, 21.88070107], [69.30069733, 21.88069534], [69.30069733, 21.88097191], [69.30040741, 21.88097191], [69.30040741, 21.88125038], [69.30014038, 21.88125038], [69.30014038, 21.88153267], [69.29985809, 21.88153267], [69.29985809, 21.88181114], [69.29958344, 21.88180542], [69.29958344, 21.88208389], [69.29930878, 21.88208389], [69.29930878, 21.88180542], [69.29875183, 21.88180542], [69.29875183, 21.88208389], [69.29846954, 21.88208008], [69.29846954, 21.88237], [69.29818726, 21.88237], [69.29818726, 21.88264084], [69.29846954, 21.88264084], [69.29846954, 21.88292122], [69.29819489, 21.8829174], [69.29819489, 21.88319206], [69.29792023, 21.88319206], [69.29792023, 21.88347244], [69.29763794, 21.88347054], [69.29763794, 21.88375092], [69.29734802, 21.88375092], [69.29734802, 21.88402939], [69.29708099, 21.88402939], [69.29708099, 21.88430977], [69.29624939, 21.88430405], [69.29624939, 21.88458252], [69.2959671, 21.88458061], [69.2959671, 21.88486099], [69.29569244, 21.88486099], [69.29569244, 21.88513947], [69.29541779, 21.88513947], [69.29541779, 21.8856945], [69.2951355, 21.8856945], [69.2951355, 21.88597488], [69.29486084, 21.88597107], [69.29486084, 21.88624954], [69.29460144, 21.88624954], [69.29460144, 21.88652992], [69.29431152, 21.88652992], [69.29431152, 21.8868103], [69.29402924, 21.88680458], [69.29402924, 21.88708305], [69.29347229, 21.88708305], [69.29347229, 21.88736153], [69.29319763, 21.88735962], [69.29319763, 21.88764], [69.29292297, 21.88764], [69.29292297, 21.88792038], [69.29264069, 21.88792038], [69.29264069, 21.88820076], [69.2923584, 21.88819695], [69.2923584, 21.8884716], [69.29207611, 21.8884697], [69.29207611, 21.88875008], [69.29180908, 21.88875008], [69.29180908, 21.88903046], [69.29125214, 21.88903046], [69.29125214, 21.88931084], [69.29096985, 21.88930511], [69.29096985, 21.88958359], [69.29069519, 21.88958359], [69.29069519, 21.88986206], [69.2904129, 21.88985825], [69.2904129, 21.89014053], [69.29013824, 21.89014053], [69.29013824, 21.89042091], [69.2895813, 21.8904171], [69.2895813, 21.89069366], [69.28930664, 21.89069366], [69.28930664, 21.89097214], [69.28874969, 21.89096832], [69.28874969, 21.89125061], [69.28846741, 21.89125061], [69.28846741, 21.89154053], [69.28791809, 21.89154053], [69.28791809, 21.89180946], [69.2876358, 21.89180565], [69.2876358, 21.89208412], [69.28708649, 21.8920784], [69.28708649, 21.89236069], [69.28679657, 21.89236069], [69.28679657, 21.89263916], [69.28624725, 21.89263916], [69.28624725, 21.89291954], [69.2859726, 21.89291763], [69.2859726, 21.8931942], [69.28569794, 21.8931942], [69.28569794, 21.89347267], [69.28514099, 21.89347267], [69.28514099, 21.89375114], [69.2848587, 21.89375114], [69.2848587, 21.89402962], [69.28430939, 21.89402962], [69.28430176, 21.8943119], [69.2840271, 21.89430618], [69.2840271, 21.89458275], [69.2831955, 21.89458275], [69.28320313, 21.89486122], [69.28291321, 21.89486122], [69.28291321, 21.89542007], [69.28263855, 21.89541626], [69.28263855, 21.89569473], [69.28236389, 21.89569473], [69.28237152, 21.89624977], [69.2820816, 21.89624977], [69.2820816, 21.89653015], [69.28180695, 21.89652824], [69.28180695, 21.89680481], [69.28152466, 21.89680481], [69.28152466, 21.89708328], [69.28125, 21.89708328], [69.28125, 21.89736176], [69.28098297, 21.89735031], [69.28098297, 21.89764023], [69.28069305, 21.89764023], [69.28069305, 21.89792061], [69.2804184, 21.89792061], [69.2804184, 21.89820099], [69.28013611, 21.89819336], [69.28013611, 21.89847183], [69.27986145, 21.89846992], [69.27986145, 21.89875031], [69.27958679, 21.89875031], [69.27958679, 21.89903069], [69.27931213, 21.89903069], [69.27931213, 21.89931107], [69.27902985, 21.89930534], [69.27902985, 21.89958572], [69.27874756, 21.89958], [69.27874756, 21.89986038], [69.2784729, 21.89986038], [69.2784729, 21.90014076], [69.27819824, 21.90013885], [69.27819824, 21.90041542], [69.27791595, 21.90041542], [69.27791595, 21.90069389], [69.2776413, 21.90069008], [69.2776413, 21.90125084], [69.27735901, 21.90125084], [69.27735901, 21.90153122], [69.27707672, 21.90153122], [69.27707672, 21.90180969], [69.27680206, 21.90180779], [69.27680206, 21.90208244], [69.2765274, 21.90208054], [69.2765274, 21.90236092], [69.27623749, 21.90236092], [69.27623749, 21.90263939], [69.27597046, 21.90263939], [69.27597046, 21.90291977], [69.2756958, 21.90291786], [69.2756958, 21.90319443], [69.27540588, 21.90319061], [69.27540588, 21.90348053], [69.27513885, 21.90348053], [69.27513885, 21.90374947], [69.27458191, 21.90374947], [69.27458191, 21.90402985], [69.27430725, 21.90402985], [69.27430725, 21.90430832], [69.27402496, 21.90430641], [69.27402496, 21.90458298], [69.27375031, 21.90458298], [69.27375031, 21.90486145], [69.27349091, 21.90485764], [69.27349091, 21.90513992], [69.2731781, 21.90513992], [69.2731781, 21.9054203], [69.2729187, 21.9054203], [69.2729187, 21.90570259], [69.27263641, 21.90569496], [69.27263641, 21.90597153], [69.2720871, 21.90597153], [69.2720871, 21.90625191], [69.27153015, 21.90625191], [69.27153015, 21.90653992], [69.27097321, 21.90653992], [69.27097321, 21.90681267], [69.27041626, 21.90680504], [69.27041626, 21.90708351], [69.26985931, 21.90708351], [69.26985931, 21.90736008], [69.26957703, 21.90736008], [69.26957703, 21.90764046], [69.26930237, 21.90764046], [69.26930237, 21.90792274], [69.26902771, 21.90791702], [69.26902771, 21.90819359], [69.26875305, 21.90819359], [69.26875305, 21.90847206], [69.26819611, 21.90847015], [69.26819611, 21.90875053], [69.26790619, 21.90875053], [69.26790619, 21.90903282], [69.26763916, 21.90903282], [69.26763916, 21.90930939], [69.2673645, 21.90930557], [69.2673645, 21.90958214], [69.26708221, 21.90958023], [69.26708221, 21.90986061], [69.26680756, 21.90986061], [69.26680756, 21.91014099], [69.2665329, 21.91014099], [69.2665329, 21.91041946], [69.26625061, 21.91041756], [69.26625061, 21.91069221], [69.26597595, 21.91069221], [69.26597595, 21.9109726], [69.26568604, 21.91097069], [69.26568604, 21.91125107], [69.26541901, 21.91125107], [69.26541901, 21.91152954], [69.26513672, 21.91152954], [69.26513672, 21.91180992], [69.26486206, 21.9118042], [69.26486206, 21.91208267], [69.26457977, 21.91208267], [69.26457977, 21.91236115], [69.26429749, 21.9123497], [69.26429749, 21.91263962], [69.26403046, 21.91263962], [69.26403046, 21.91319656], [69.26374817, 21.91319656], [69.26374817, 21.91347313], [69.26346588, 21.91347122], [69.26346588, 21.91374969], [69.26319122, 21.91374969], [69.26319122, 21.91403008], [69.26291656, 21.91402626], [69.26291656, 21.91430473], [69.26264191, 21.91430473], [69.26264191, 21.91458321], [69.26235962, 21.91458321], [69.26235962, 21.91486168], [69.26207733, 21.91485977], [69.26207733, 21.91514015], [69.26180267, 21.91514015], [69.26180267, 21.91542053], [69.2612381, 21.91542053], [69.2612381, 21.91570854], [69.26097107, 21.91570854], [69.26097107, 21.91625023], [69.26069641, 21.91625023], [69.26069641, 21.91653061], [69.26013947, 21.91653061], [69.26013947, 21.91680908], [69.25986481, 21.91680527], [69.25986481, 21.91708374], [69.25958252, 21.91707993], [69.25958252, 21.91736031], [69.25930786, 21.91736031], [69.25930786, 21.91764069], [69.25875092, 21.91764069], [69.25875092, 21.91791916], [69.25846863, 21.91791725], [69.25846863, 21.91819382], [69.2582016, 21.9181881], [69.2582016, 21.91848183], [69.25791931, 21.91848183], [69.25791931, 21.91875076], [69.25736237, 21.91875076], [69.25736237, 21.91930962], [69.25708008, 21.9193058], [69.25708008, 21.91958427], [69.25680542, 21.91958427], [69.25681305, 21.91986084], [69.25653076, 21.91986084], [69.25653076, 21.92014122], [69.25624847, 21.92014122], [69.25624847, 21.92041969], [69.25597382, 21.92041588], [69.25597382, 21.92097282], [69.25569153, 21.92097282], [69.25569153, 21.92124939], [69.25541687, 21.92124939], [69.25541687, 21.92152786], [69.25485992, 21.92152023], [69.25485992, 21.92181015], [69.25458527, 21.92180634], [69.25458527, 21.9220829], [69.25430298, 21.9220829], [69.25430298, 21.92236137], [69.25402832, 21.92235947], [69.25402832, 21.92263985], [69.25374603, 21.92263985], [69.25374603, 21.92292023], [69.25347137, 21.92291641], [69.25347137, 21.92319489], [69.25319672, 21.92319489], [69.25319672, 21.92347145], [69.2529068, 21.92346954], [69.2529068, 21.92374992], [69.25263977, 21.92374992], [69.25263977, 21.9240303], [69.25235748, 21.9240303], [69.25235748, 21.92431068], [69.25208282, 21.92430305], [69.25208282, 21.92458344], [69.25180817, 21.92458344], [69.25180817, 21.92486191], [69.25152588, 21.92486], [69.25152588, 21.92514038], [69.25125122, 21.92514038], [69.25125122, 21.92542076], [69.25096893, 21.92541695], [69.25096893, 21.9256897], [69.25068665, 21.92570114], [69.25068665, 21.92653084], [69.25041962, 21.92652512], [69.25041962, 21.92708588], [69.25013733, 21.92708015], [69.25013733, 21.92736053], [69.24986267, 21.92736053], [69.24986267, 21.92791939], [69.24958038, 21.92791557], [69.24958038, 21.92819595], [69.24930573, 21.92819595], [69.24930573, 21.92847252], [69.24903107, 21.92847061], [69.24903107, 21.92875099], [69.24874878, 21.92875099], [69.24874878, 21.92902946], [69.24846649, 21.92902946], [69.24846649, 21.92930984], [69.24819183, 21.92930794], [69.24819183, 21.9295826], [69.24791718, 21.92958069], [69.24791718, 21.92986107], [69.24736023, 21.92986107], [69.24736023, 21.93013954], [69.2470932, 21.93013954], [69.2470932, 21.93041992], [69.24680328, 21.93041611], [69.24680328, 21.93069458], [69.24652863, 21.93069458], [69.24652863, 21.93097305], [69.24624634, 21.93097305], [69.2462616, 21.93124962], [69.24569702, 21.93124962], [69.24569702, 21.93152809], [69.24541473, 21.93152809], [69.24541473, 21.93180466], [69.24514008, 21.93180466], [69.24514008, 21.93208313], [69.24485779, 21.93208313], [69.24485779, 21.9323616], [69.24458313, 21.9323616], [69.24458313, 21.93264008], [69.24402618, 21.93264008], [69.24402618, 21.93292046], [69.24375153, 21.93292046], [69.24375153, 21.93320274], [69.24346924, 21.93319511], [69.24346924, 21.93347168], [69.24319458, 21.93347168], [69.24320221, 21.93375015], [69.24263763, 21.93375015], [69.24263763, 21.93403053], [69.24236298, 21.93403053], [69.24236298, 21.93431282], [69.24208069, 21.93430519], [69.24208069, 21.93458366], [69.24124908, 21.93458176], [69.24124908, 21.93486023], [69.24069214, 21.93486023], [69.24069214, 21.93514061], [69.24041748, 21.93514061], [69.24041748, 21.9354229], [69.24013519, 21.93541718], [69.24013519, 21.93569374], [69.23986053, 21.93569183], [69.23986053, 21.93625069], [69.23958588, 21.93625069], [69.23958588, 21.93652725], [69.23929596, 21.93651962], [69.23929596, 21.93680954], [69.23902893, 21.93680573], [69.23902893, 21.93708229], [69.23874664, 21.93708038], [69.23874664, 21.93736076], [69.23819733, 21.93736076], [69.23819733, 21.93764114], [69.23792267, 21.93764114], [69.23792267, 21.93791962], [69.23708344, 21.9379158], [69.23708344, 21.93819427], [69.23652649, 21.93819427], [69.23652649, 21.93847275], [69.23625183, 21.93847084], [69.23625183, 21.93931007], [69.23596954, 21.93931007], [69.23596954, 21.93959045], [69.23568726, 21.93959045], [69.23568726, 21.94013977], [69.23486328, 21.94013977], [69.23486328, 21.94042015], [69.23458099, 21.94041443], [69.23458099, 21.94069672], [69.23430634, 21.94069672], [69.23430634, 21.94097137], [69.23402405, 21.94097137], [69.23403168, 21.94124985], [69.23374939, 21.94124985], [69.23374939, 21.94153023], [69.23347473, 21.94152641], [69.23347473, 21.94180679], [69.23319244, 21.94180679], [69.23319244, 21.94208336], [69.23291779, 21.94208336], [69.23291779, 21.94236183], [69.23264313, 21.94235992], [69.23264313, 21.94264984], [69.23208618, 21.94264984], [69.23208618, 21.94292068], [69.23179626, 21.94292068], [69.23179626, 21.94319916], [69.23152924, 21.94319534], [69.23152924, 21.94347191], [69.23124695, 21.94347191], [69.23126221, 21.94375038], [69.23097229, 21.94375038], [69.23097229, 21.94403076], [69.23069763, 21.94403076], [69.23069763, 21.94430923], [69.23041534, 21.94430542], [69.23042297, 21.94486046], [69.23014069, 21.94486046], [69.23014069, 21.94541931], [69.2298584, 21.9454174], [69.2298584, 21.94597244], [69.22957611, 21.94597054], [69.22957611, 21.94625092], [69.22930908, 21.94625092], [69.22930908, 21.94652939], [69.22902679, 21.94652939], [69.22902679, 21.94681168], [69.22875214, 21.94680595], [69.22875214, 21.94708252], [69.22846985, 21.94708252], [69.22846985, 21.9473629], [69.22818756, 21.9473629], [69.22818756, 21.94763947], [69.2279129, 21.94763947], [69.2279129, 21.94791985], [69.22763824, 21.94791603], [69.22763824, 21.9481945], [69.22736359, 21.9481945], [69.22736359, 21.94847107], [69.2270813, 21.94846153], [69.2270813, 21.94902992], [69.22680664, 21.94902992], [69.22680664, 21.9493103], [69.22652435, 21.94930649], [69.22652435, 21.94958115], [69.22624969, 21.94958115], [69.22624969, 21.94986153], [69.22598267, 21.94985962], [69.22598267, 21.95014], [69.22569275, 21.95014], [69.22569275, 21.95042038], [69.22541809, 21.95042038], [69.22541809, 21.95070076], [69.22486115, 21.95069313], [69.22486115, 21.9509716], [69.22458649, 21.9509697], [69.22458649, 21.95125008], [69.22429657, 21.95125008], [69.22429657, 21.95153046], [69.22402954, 21.95153046], [69.22402954, 21.95181084], [69.22374725, 21.95180321], [69.22374725, 21.95208359], [69.2234726, 21.95208359], [69.2234726, 21.95236206], [69.22319794, 21.95236015], [69.22319794, 21.95264053], [69.22292328, 21.95264053], [69.22292328, 21.95292091], [69.22264099, 21.95291519], [69.22264099, 21.95319366], [69.2223587, 21.95319366], [69.2223587, 21.95347214], [69.22208405, 21.95347214], [69.22209167, 21.95375061], [69.22180939, 21.95375061], [69.22180176, 21.95403099], [69.2215271, 21.95403099], [69.2215271, 21.95430946], [69.22125244, 21.95430946], [69.22125244, 21.95458984], [69.22097015, 21.95458984], [69.22097015, 21.95486069], [69.22070313, 21.95486069], [69.22070313, 21.95514107], [69.22041321, 21.95514107], [69.22041321, 21.95541954], [69.22013855, 21.95541763], [69.22013855, 21.9556942], [69.21986389, 21.9556942], [69.21986389, 21.95597267], [69.2195816, 21.95597076], [69.2195816, 21.95625114], [69.2193222, 21.95625114], [69.2193222, 21.95652962], [69.21903229, 21.95652962], [69.21903229, 21.95680809], [69.21875, 21.95680618], [69.21875, 21.95708275], [69.21847534, 21.95708275], [69.21848297, 21.95736122], [69.21819305, 21.95736122], [69.21819305, 21.95764923], [69.2179184, 21.95764923], [69.2179184, 21.95791817], [69.21763611, 21.95791626], [69.21763611, 21.95819473], [69.21679687, 21.95819092], [69.21679687, 21.95875168], [69.21652985, 21.95875168], [69.21652985, 21.95903015], [69.21624756, 21.95902824], [69.21624756, 21.95930481], [69.2159729, 21.95930481], [69.2159729, 21.95958328], [69.21569824, 21.95958328], [69.21569824, 21.95986176], [69.21541595, 21.95986176], [69.21541595, 21.96014023], [69.2151413, 21.96014023], [69.2151413, 21.96042252], [69.21485901, 21.96041679], [69.21485901, 21.96069527], [69.21458435, 21.96069527], [69.21458435, 21.96097183], [69.21430206, 21.96097183], [69.21430206, 21.96125031], [69.2140274, 21.96125031], [69.2140274, 21.96153069], [69.21375275, 21.96152687], [69.21375275, 21.96208382], [69.21347046, 21.96208191], [69.21347046, 21.96236038], [69.21318817, 21.96236038], [69.21318817, 21.96264076], [69.21289825, 21.96264076], [69.21289825, 21.96292114], [69.21263885, 21.96291733], [69.21263885, 21.96319389], [69.2123642, 21.96319389], [69.2123642, 21.96347237], [69.21208191, 21.96347046], [69.21208191, 21.96375084], [69.21153259, 21.96375084], [69.21153259, 21.96403122], [69.21125031, 21.96403122], [69.21125031, 21.96430969], [69.21097565, 21.96430588], [69.21098328, 21.96486092], [69.21069336, 21.96486092], [69.21069336, 21.96513939], [69.2104187, 21.96513939], [69.2104187, 21.96541977], [69.21013641, 21.96541405], [69.21013641, 21.96569443], [69.20986176, 21.96569443], [69.20986176, 21.9659729], [69.2095871, 21.96597099], [69.2095871, 21.96624947], [69.20929718, 21.96624947], [69.20929718, 21.96652985], [69.20903015, 21.96652794], [69.20903015, 21.96708298], [69.20874786, 21.96708298], [69.20874786, 21.96736145], [69.20847321, 21.96735954], [69.20847321, 21.96763992], [69.20819092, 21.96763992], [69.20819092, 21.96820068], [69.20791626, 21.96819687], [69.20791626, 21.96847153], [69.2076416, 21.96846962], [69.2076416, 21.96874809], [69.20735931, 21.96874809], [69.20735931, 21.96903038], [69.20709229, 21.96903038], [69.20709229, 21.96958923], [69.20680237, 21.96958351], [69.20680237, 21.96986198], [69.20652771, 21.96985817], [69.20652771, 21.97014046], [69.20625305, 21.97014046], [69.20625305, 21.97042084], [69.20597076, 21.97041893], [69.20597076, 21.97097206], [69.20569611, 21.97096825], [69.20569611, 21.97125053], [69.20540619, 21.97125053], [69.20540619, 21.97153091], [69.20513916, 21.9715271], [69.20513916, 21.97208405], [69.20485687, 21.97207832], [69.20485687, 21.97236061], [69.20458221, 21.97236061], [69.20458221, 21.97263908], [69.20430756, 21.97262955], [69.20430756, 21.97291946], [69.20402527, 21.97291756], [69.20402527, 21.9734726], [69.20375061, 21.97347069], [69.20375061, 21.97375107], [69.20347595, 21.97375107], [69.20347595, 21.97402954], [69.20319366, 21.97402763], [69.20319366, 21.97458267], [69.20291901, 21.97458267], [69.20291901, 21.97486115], [69.20263672, 21.97486115], [69.20263672, 21.97513962], [69.20236206, 21.97513962], [69.20236206, 21.97569466], [69.20207977, 21.97569466], [69.20207977, 21.97597122], [69.20198059, 21.97597122], [69.20180511, 21.97597122], [69.20181274, 21.97624969], [69.20153046, 21.97624969], [69.20153046, 21.97680473], [69.20124817, 21.97680473], [69.20124817, 21.97708321], [69.20095825, 21.97707939], [69.20095825, 21.97764015], [69.20069122, 21.97764015], [69.20069122, 21.97792053], [69.20041656, 21.97792053], [69.20041656, 21.97820091], [69.20014191, 21.97819328], [69.20014191, 21.97847176], [69.19985962, 21.97846985], [69.19985962, 21.97903061], [69.19959259, 21.97903061], [69.19959259, 21.97931099], [69.19930267, 21.97930336], [69.19930267, 21.97958374], [69.19902802, 21.97957993], [69.19902802, 21.97986031], [69.19875336, 21.97986031], [69.19875336, 21.98042107], [69.19847107, 21.98042107], [69.19847107, 21.98014069], [69.19821167, 21.98014069], [69.19821167, 21.98042107], [69.19763947, 21.98041534], [69.19763947, 21.98069382], [69.19736481, 21.98069382], [69.19736481, 21.98097229], [69.19763947, 21.98097038], [69.19763947, 21.98125076], [69.19789886, 21.98125076], [69.19789886, 21.98181915], [69.19847107, 21.98180771], [69.19847107, 21.98208237], [69.19875336, 21.98208046], [69.19875336, 21.98236084], [69.19902802, 21.98236084], [69.19902802, 21.98264122], [69.19930267, 21.98264122], [69.19930267, 21.98236084], [69.19985962, 21.98236084], [69.19985962, 21.98264122], [69.20041656, 21.98264122], [69.20041656, 21.98291969], [69.20097351, 21.98291779], [69.20097351, 21.98319435], [69.20124817, 21.98319054], [69.20124817, 21.98402977], [69.20153046, 21.98402977], [69.20153046, 21.9845829], [69.20124817, 21.9845829], [69.20124817, 21.98486137], [69.19985962, 21.98486137], [69.19985962, 21.9845829], [69.19930267, 21.9845829], [69.19930267, 21.98374748], [69.19902802, 21.98374748], [69.19902802, 21.98347092], [69.19789886, 21.98347092], [69.19789886, 21.98374748], [69.19708252, 21.98374748], [69.19708252, 21.98347092], [69.19568634, 21.98347092], [69.19568634, 21.98374748], [69.19291687, 21.98374748], [69.19291687, 21.98402977], [69.19264221, 21.98402977], [69.19264221, 21.98430824], [69.19235992, 21.98430634], [69.19235992, 21.9845829], [69.19208527, 21.9845829], [69.19208527, 21.98486137], [69.19180298, 21.98485756], [69.19180298, 21.98513985], [69.19152832, 21.98513985], [69.19152832, 21.98542023], [69.19125366, 21.98541641], [69.19125366, 21.98569489], [69.19097137, 21.98569489], [69.19097137, 21.98597145], [69.1904068, 21.98597145], [69.1904068, 21.98625183], [69.19013977, 21.98625183], [69.19013977, 21.9865303], [69.18985748, 21.9865303], [69.18985748, 21.98681259], [69.18958282, 21.98680496], [69.18958282, 21.98708344], [69.18930817, 21.98708344], [69.18930817, 21.98736191], [69.18902588, 21.98736191], [69.18902588, 21.98763847], [69.18875122, 21.98763084], [69.18875122, 21.98792267], [69.18846893, 21.98791695], [69.18846893, 21.9881897], [69.18819427, 21.98819542], [69.18819427, 21.98847389], [69.18791962, 21.98847008], [69.18791962, 21.98875046], [69.18763733, 21.98875046], [69.18763733, 21.98903084], [69.18736267, 21.98902702], [69.18736267, 21.98958206], [69.18708038, 21.98958015], [69.18708038, 21.98986053], [69.18681335, 21.98986053], [69.18681335, 21.99014091], [69.18653107, 21.99014091], [69.18653107, 21.99041939], [69.18624878, 21.99041939], [69.18624878, 21.99069977], [69.18597412, 21.99069214], [69.18597412, 21.99097252], [69.18569183, 21.99097061], [69.18569183, 21.99125099], [69.18541718, 21.99125099], [69.18541718, 21.99180984], [69.18514252, 21.99180412], [69.18514252, 21.9920826], [69.18486023, 21.99208069], [69.18486023, 21.99236107], [69.18458557, 21.99236107], [69.1845932, 21.99263954], [69.18430328, 21.99263954], [69.18430328, 21.99291992], [69.18402863, 21.9929142], [69.18402863, 21.99319458], [69.18374634, 21.99319077], [69.18374634, 21.99376106], [69.18347168, 21.99376106], [69.18347168, 21.99403], [69.18319702, 21.99402618], [69.18319702, 21.99430466], [69.18291473, 21.99430466], [69.18291473, 21.99458313], [69.18264008, 21.99458313], [69.18264008, 21.9948616], [69.18235779, 21.9948597], [69.18235779, 21.99514008], [69.18208313, 21.99514008], [69.18208313, 21.99542046], [69.18180847, 21.99542046], [69.18180847, 21.99570084], [69.18152618, 21.99569511], [69.18152618, 21.99597168], [69.18125153, 21.99596977], [69.18125153, 21.99625015], [69.18096924, 21.99625015], [69.18096924, 21.99653053], [69.18069458, 21.99652863], [69.18069458, 21.99708366], [69.18041992, 21.99707985], [69.18041992, 21.99735832], [69.18013763, 21.99735832], [69.18013763, 21.99764061], [69.17986298, 21.99764061], [69.17986298, 21.99791908], [69.17958069, 21.99791718], [69.17958069, 21.99819374], [69.17930603, 21.99819374], [69.17930603, 21.99847221], [69.17903137, 21.9984684], [69.17903137, 21.99875069], [69.17874908, 21.99875069], [69.17874908, 21.99902916], [69.1784668, 21.99902916], [69.1784668, 21.99930954], [69.17819214, 21.99930573], [69.17819214, 21.9995842], [69.17707825, 21.99957085], [69.17707825, 22.00014114], [69.17678833, 22.00014114], [69.17678833, 22.00041962], [69.17652893, 22.0004158], [69.17652893, 22.00097275], [69.17624664, 22.00097275], [69.17624664, 22.00125122], [69.17597198, 22.00125122], [69.17597198, 22.00152969], [69.17569733, 22.00152779], [69.17569733, 22.00208282], [69.17541504, 22.00208282], [69.17541504, 22.0023613], [69.17514038, 22.00235939], [69.17514038, 22.00263977], [69.17485809, 22.00263977], [69.17485809, 22.00319481], [69.17458344, 22.00319481], [69.17458344, 22.00347137], [69.17430878, 22.00346947], [69.17430878, 22.00374985], [69.17401886, 22.00374985], [69.17401886, 22.00403023], [69.17375183, 22.00402832], [69.17375183, 22.00430489], [69.17319489, 22.00430489], [69.17319489, 22.00458336], [69.17292023, 22.00458336], [69.17292023, 22.00486183], [69.17263794, 22.00485992], [69.17263794, 22.0051403], [69.17236328, 22.0051403], [69.17236328, 22.00542068], [69.17208099, 22.00542068], [69.17208099, 22.00570107], [69.17180634, 22.00569344], [69.17180634, 22.00597191], [69.17151642, 22.00597], [69.17151642, 22.00625038], [69.17124939, 22.00625038], [69.17124939, 22.00653076], [69.17098236, 22.00653076], [69.17098236, 22.00681114], [69.17069244, 22.00680542], [69.17069244, 22.0070858], [69.17041779, 22.00708008], [69.17041779, 22.00736046], [69.17014313, 22.00736046], [69.17014313, 22.00764084], [69.16986084, 22.00764084], [69.16986084, 22.00792122], [69.1701355, 22.0079155], [69.1701355, 22.00819397], [69.16986084, 22.00819397], [69.16986084, 22.00847244], [69.16958618, 22.00847244], [69.16958618, 22.00875092], [69.16929626, 22.00873947], [69.16929626, 22.00902939], [69.16902924, 22.00902939], [69.16902924, 22.00930977], [69.16874695, 22.00930786], [69.16874695, 22.00958252], [69.16847229, 22.00958061], [69.16847229, 22.00986099], [69.16819763, 22.00986099], [69.16819763, 22.01041985], [69.16791534, 22.01041794], [69.16791534, 22.01097298], [69.16764069, 22.01096916], [69.16764069, 22.01124954], [69.16680908, 22.01124954], [69.16680908, 22.01208305], [69.16652679, 22.01208305], [69.16652679, 22.01236153], [69.16625214, 22.01236153], [69.16625214, 22.01264191], [69.16596985, 22.01264191], [69.16596985, 22.01292038], [69.16570282, 22.01292038], [69.16570282, 22.01320267], [69.1654129, 22.01319504], [69.1654129, 22.0134716], [69.16513824, 22.0134716], [69.16513824, 22.01403046], [69.16484833, 22.01403046], [69.16484833, 22.01431274], [69.1645813, 22.01431274], [69.1645813, 22.01486969], [69.16430664, 22.01486969], [69.16430664, 22.01514053], [69.16348267, 22.01514053], [69.16348267, 22.01542282], [69.16291809, 22.0154171], [69.16291809, 22.01569366], [69.1626358, 22.01569366], [69.1626358, 22.01597214], [69.16236115, 22.01597023], [69.16236115, 22.01625061], [69.16207886, 22.01625061], [69.16207886, 22.0165329], [69.16178894, 22.0165329], [69.16178894, 22.01680946], [69.16152954, 22.01680565], [69.16152954, 22.01708221], [69.16124725, 22.01708031], [69.16124725, 22.01736069], [69.1609726, 22.01736069], [69.1609726, 22.01764107], [69.16069794, 22.01764107], [69.16069794, 22.01793098], [69.16041565, 22.01791763], [69.16041565, 22.0181942], [69.16014099, 22.0181942], [69.16014099, 22.01847267], [69.1598587, 22.01847076], [69.1598587, 22.01875114], [69.15958405, 22.01874924], [69.15958405, 22.01958275], [69.15930939, 22.01958084], [69.15930176, 22.01986122], [69.15904236, 22.01986122], [69.15904236, 22.02042007], [69.15875244, 22.02041435], [69.15875244, 22.02069664], [69.1581955, 22.02069664], [69.1581955, 22.0209713], [69.15791321, 22.02096939], [69.15791321, 22.02124977], [69.15763855, 22.02124977], [69.15763855, 22.02180481], [69.15736389, 22.02180481], [69.15736389, 22.02208328], [69.1570816, 22.02208328], [69.1570816, 22.02236176], [69.15680695, 22.02235985], [69.15680695, 22.02292061], [69.15651703, 22.02292061], [69.15651703, 22.02319908], [69.15625, 22.02319527], [69.15625, 22.02375031], [69.15598297, 22.02374077], [69.15598297, 22.02430916], [69.15569305, 22.02430916], [69.15569305, 22.02486038], [69.1554184, 22.02486038], [69.1554184, 22.02514076], [69.15513611, 22.02514076], [69.15513611, 22.02541924], [69.15486145, 22.02541733], [69.15486145, 22.02569389], [69.15458679, 22.02569389], [69.15458679, 22.02597237], [69.15429688, 22.02596855], [69.15429688, 22.02652931], [69.15402985, 22.02652931], [69.15402985, 22.02680969], [69.15319824, 22.02680588], [69.15319824, 22.02708244], [69.15207672, 22.02708244], [69.15207672, 22.02736282], [69.15180206, 22.02736282], [69.15180206, 22.02763939], [69.1515274, 22.02763939], [69.1515274, 22.02791977], [69.15125275, 22.02791595], [69.15125275, 22.02819443], [69.15097046, 22.02819443], [69.15097046, 22.0284729], [69.1506958, 22.0284729], [69.1506958, 22.02902985], [69.15040588, 22.02902985], [69.15040588, 22.02931023], [69.15013885, 22.02930641], [69.15013885, 22.02958107], [69.14984894, 22.02958107], [69.14984894, 22.02987099], [69.14958191, 22.02987099], [69.14958191, 22.03013992], [69.14930725, 22.03013992], [69.14930725, 22.0304203], [69.14903259, 22.0304203], [69.14903259, 22.03070068], [69.14875031, 22.03069305], [69.14875031, 22.03097153], [69.14847565, 22.03097153], [69.14848328, 22.03125], [69.14819336, 22.03125], [69.14819336, 22.03153038], [69.1479187, 22.03153038], [69.1479187, 22.03181076], [69.14763641, 22.03180313], [69.14763641, 22.03236198], [69.14736176, 22.03236008], [69.14736176, 22.03264046], [69.1470871, 22.03263855], [69.1470871, 22.03291512], [69.14680481, 22.03291512], [69.14680481, 22.03319359], [69.14653015, 22.03319359], [69.14653015, 22.03347206], [69.14624786, 22.03347015], [69.14624786, 22.03375053], [69.14597321, 22.03375053], [69.14597321, 22.03403091], [69.14569092, 22.03403091], [69.14569092, 22.03430939], [69.14541626, 22.03430748], [69.14541626, 22.03458595], [69.1451416, 22.03458023], [69.1451416, 22.03486061], [69.14485931, 22.03486061], [69.14485931, 22.03514099], [69.14457703, 22.03514099], [69.14457703, 22.03541946], [69.14430237, 22.03541565], [69.14430237, 22.03569412], [69.14402771, 22.03569412], [69.14402771, 22.0359726], [69.14375305, 22.03597069], [69.14375305, 22.03625107], [69.14347076, 22.03625107], [69.14347076, 22.03680992], [69.14319611, 22.03680611], [69.14319611, 22.03708267], [69.14290619, 22.03708076], [69.14290619, 22.03736115], [69.14263916, 22.03736115], [69.14263916, 22.03763962], [69.14235687, 22.03763962], [69.14235687, 22.03791809], [69.14208221, 22.03791618], [69.14208221, 22.03819466], [69.14180756, 22.03819466], [69.14180756, 22.03847313], [69.14152527, 22.03847313], [69.1415329, 22.03874969], [69.14125061, 22.03874969], [69.14125061, 22.03903008], [69.14097595, 22.03902817], [69.14097595, 22.03930473], [69.14069366, 22.03930473], [69.14069366, 22.03958321], [69.14041901, 22.03958321], [69.14041901, 22.03986168], [69.13986206, 22.03986168], [69.13986206, 22.04014015], [69.13957977, 22.04014015], [69.13957977, 22.04042053], [69.13931274, 22.04042053], [69.13931274, 22.04070282], [69.13903046, 22.04069519], [69.13903046, 22.04097176], [69.13874817, 22.04097176], [69.13874817, 22.04125023], [69.13846588, 22.04125023], [69.13846588, 22.0418129], [69.13819122, 22.04180527], [69.13819122, 22.04208374], [69.13790894, 22.04208183], [69.13790894, 22.04236031], [69.13764191, 22.04236031], [69.13764191, 22.04264069], [69.13735962, 22.04264069], [69.13735962, 22.04292107], [69.13680267, 22.04291725], [69.13680267, 22.04319382], [69.13652802, 22.04319191], [69.13652802, 22.04375076], [69.13625336, 22.04375076], [69.13625336, 22.04403114], [69.13597107, 22.04403114], [69.13597107, 22.04430962], [69.13569641, 22.0443058], [69.13569641, 22.04458237], [69.13540649, 22.04458046], [69.13540649, 22.04514122], [69.13513947, 22.04514122], [69.13513947, 22.04541969], [69.13486481, 22.04541588], [69.13486481, 22.04569435], [69.13458252, 22.04569435], [69.13458252, 22.04597282], [69.13430786, 22.04597092], [69.13430786, 22.04624939], [69.1340332, 22.04624939], [69.1340332, 22.04652977], [69.13375092, 22.04652977], [69.13375092, 22.04681015], [69.13346863, 22.04680443], [69.13346863, 22.0470829], [69.13318634, 22.04708099], [69.13318634, 22.04763985], [69.13291931, 22.04763985], [69.13291931, 22.04819679], [69.13263702, 22.04819679], [69.13263702, 22.04847145], [69.13236237, 22.04846954], [69.13236237, 22.04874992], [69.13208008, 22.04874992], [69.13208008, 22.0490303], [69.13181305, 22.0490303], [69.13181305, 22.04931068], [69.13153076, 22.04930687], [69.13153076, 22.04958344], [69.13124847, 22.04958344], [69.13124847, 22.04986191], [69.13069153, 22.04985809], [69.13069153, 22.05014038], [69.13041687, 22.05014038], [69.13041687, 22.05042076], [69.13014221, 22.05041885], [69.13014221, 22.0506897], [69.12985992, 22.05069542], [69.12985992, 22.05097198], [69.12958527, 22.05097198], [69.1295929, 22.05125046], [69.12930298, 22.05125046], [69.12930298, 22.05153084], [69.12902832, 22.05153084], [69.12902832, 22.05180931], [69.12875366, 22.0518055], [69.12875366, 22.05208397], [69.12847137, 22.05207825], [69.12847137, 22.05264091], [69.12819672, 22.05264091], [69.12819672, 22.05291939], [69.12791443, 22.05291748], [69.12791443, 22.05319405], [69.12763977, 22.05319405], [69.12763977, 22.05347252], [69.12735748, 22.0534687], [69.12735748, 22.0537529], [69.12680817, 22.0537529], [69.12680817, 22.05404282], [69.12652588, 22.05404282], [69.12652588, 22.05430984], [69.12625122, 22.05430603], [69.12625122, 22.0545826], [69.12596893, 22.0545826], [69.12596893, 22.05486107], [69.12569427, 22.05486107], [69.12569427, 22.05569458], [69.12541962, 22.05569458], [69.12541962, 22.05597115], [69.12513733, 22.05597115], [69.12513733, 22.05624962], [69.12486267, 22.05624962], [69.12486267, 22.05653], [69.12458038, 22.05652809], [69.12458038, 22.05680466], [69.12430573, 22.05680466], [69.12430573, 22.05708313], [69.12403107, 22.05708313], [69.12403107, 22.0573616], [69.12374878, 22.0573597], [69.12374878, 22.05764008], [69.12346649, 22.05764008], [69.12346649, 22.05792046], [69.12319183, 22.05792046], [69.12319183, 22.05820084], [69.12291718, 22.05819321], [69.12291718, 22.05847168], [69.12264252, 22.05846977], [69.12264252, 22.05903053], [69.12236023, 22.05903053], [69.12236023, 22.05931091], [69.12208557, 22.05930328], [69.12208557, 22.05958366], [69.12124634, 22.05958366], [69.12124634, 22.05986023], [69.12097168, 22.05985069], [69.12097168, 22.06014061], [69.12069702, 22.06014061], [69.12069702, 22.06042099], [69.12041473, 22.06041527], [69.12041473, 22.06069374], [69.12014008, 22.06068993], [69.12014008, 22.06125069], [69.11987305, 22.06125069], [69.11987305, 22.06153107], [69.11958313, 22.06153107], [69.11958313, 22.06180954], [69.11930847, 22.06180763], [69.11930847, 22.0620842], [69.11902618, 22.06208038], [69.11902618, 22.06236076], [69.11875153, 22.06236076], [69.11875153, 22.06264114], [69.11846924, 22.06264114], [69.11846924, 22.06291962], [69.11819458, 22.06291771], [69.11819458, 22.06319427], [69.11791992, 22.06319427], [69.11791992, 22.06347275], [69.11763763, 22.06347084], [69.11763763, 22.06375122], [69.11736298, 22.06374741], [69.11736298, 22.0648613], [69.11708069, 22.06485748], [69.11708069, 22.06513977], [69.1167984, 22.06513977], [69.1167984, 22.06542015], [69.11597443, 22.06541634], [69.11597443, 22.06569481], [69.11569214, 22.06568909], [69.11569214, 22.06598282], [69.11541748, 22.06598282], [69.11541748, 22.06625175], [69.11514282, 22.06625175], [69.11514282, 22.06653023], [69.11486053, 22.06652832], [69.11486053, 22.06680489], [69.11458588, 22.06680489], [69.11458588, 22.06708336], [69.11430359, 22.06708336], [69.11430359, 22.06736183], [69.11402893, 22.06736183], [69.11402893, 22.0676403], [69.11373901, 22.0676403], [69.11373901, 22.06792068], [69.11347198, 22.06792068], [69.11347198, 22.06820107], [69.11319733, 22.06820107], [69.11319733, 22.06875038], [69.11292267, 22.06875038], [69.11292267, 22.0690403], [69.11264038, 22.0690403], [69.11264038, 22.06931114], [69.11235809, 22.06930542], [69.11235809, 22.06958389], [69.11207581, 22.06958008], [69.11207581, 22.06986046], [69.11235809, 22.06986046], [69.11235809, 22.07014084], [69.11207581, 22.07014084], [69.11207581, 22.07042122], [69.11180878, 22.0704174], [69.11180878, 22.07097244], [69.11152649, 22.07097054], [69.11152649, 22.07125092], [69.11125183, 22.07125092], [69.11125183, 22.07097054], [69.11096954, 22.07097054], [69.11096954, 22.07125092], [69.11067963, 22.07125092], [69.11067963, 22.07180977], [69.11042023, 22.07180977], [69.11042023, 22.07236099], [69.11013794, 22.07236099], [69.11013794, 22.07263947], [69.10986328, 22.07263947], [69.10986328, 22.07291985], [69.10958099, 22.07291412], [69.10958099, 22.0731945], [69.10902405, 22.0731945], [69.10902405, 22.07291412], [69.10874939, 22.07291412], [69.10874939, 22.0731945], [69.10847473, 22.0731945], [69.10847473, 22.07347298], [69.10819244, 22.07347107], [69.10819244, 22.07402992], [69.10791779, 22.07402611], [69.10791779, 22.07458305], [69.1076355, 22.07458305], [69.1076355, 22.07486153], [69.10708618, 22.07485962], [69.10708618, 22.07514], [69.10679626, 22.07514], [69.10679626, 22.07570076], [69.10652924, 22.07570076], [69.10652924, 22.07624817], [69.10624695, 22.07624817], [69.10624695, 22.07653046], [69.10597229, 22.07652855], [69.10597229, 22.07708359], [69.10569763, 22.07708359], [69.10569763, 22.07736206], [69.10542297, 22.07735825], [69.10542297, 22.07764053], [69.10514069, 22.07764053], [69.10514069, 22.07792091], [69.1048584, 22.0779171], [69.1048584, 22.07847214], [69.10457611, 22.07846832], [69.10457611, 22.07875061], [69.10430908, 22.07875061], [69.10430908, 22.07902908], [69.10402679, 22.07902908], [69.10402679, 22.07930946], [69.10375214, 22.07930946], [69.10375214, 22.07986069], [69.10346985, 22.07986069], [69.10346985, 22.08013916], [69.10320282, 22.08013916], [69.10320282, 22.08041954], [69.1029129, 22.08041763], [69.1029129, 22.0806942], [69.10263824, 22.08069038], [69.10263824, 22.08125114], [69.10235596, 22.08125114], [69.10235596, 22.08152962], [69.1020813, 22.08152962], [69.1020813, 22.0818119], [69.10180664, 22.08180618], [69.10180664, 22.08208275], [69.10150909, 22.08208275], [69.10150909, 22.08263969], [69.10124969, 22.08263969], [69.10124969, 22.08292007], [69.10097504, 22.08291626], [69.10097504, 22.08319473], [69.10069275, 22.08319283], [69.10069275, 22.08374977], [69.10041809, 22.08374977], [69.10041809, 22.08402824], [69.1001358, 22.08402824], [69.1001358, 22.08430481], [69.09986115, 22.08430481], [69.09986115, 22.08486176], [69.09958649, 22.08485985], [69.09958649, 22.08514023], [69.09929657, 22.08514023], [69.09929657, 22.08570099], [69.09902954, 22.08569336], [69.09902954, 22.08597183], [69.09876251, 22.08596992], [69.09876251, 22.08653069], [69.0984726, 22.08653069], [69.0984726, 22.08681107], [69.09819794, 22.08680534], [69.09819794, 22.08708382], [69.09792328, 22.08708], [69.09792328, 22.08764076], [69.09764099, 22.08764076], [69.09764099, 22.08792114], [69.0973587, 22.08791542], [69.0973587, 22.08819389], [69.09708405, 22.08819389], [69.09708405, 22.08847237], [69.09680939, 22.08847046], [69.09680176, 22.08903122], [69.0965271, 22.08903122], [69.0965271, 22.08930969], [69.09625244, 22.08930779], [69.09625244, 22.08958244], [69.09597015, 22.08958054], [69.09597015, 22.08986092], [69.09570313, 22.08986092], [69.09570313, 22.09015083], [69.09541321, 22.09013939], [69.09541321, 22.09069443], [69.09513855, 22.09069443], [69.09513855, 22.0909729], [69.09485626, 22.09096909], [69.09485626, 22.09124756], [69.0945816, 22.09124756], [69.0945816, 22.09152985], [69.09430695, 22.09152985], [69.09430695, 22.09180832], [69.09402466, 22.09180641], [69.09402466, 22.09236145], [69.09375, 22.09236145], [69.09375, 22.09264183], [69.09348297, 22.09264183], [69.09348297, 22.0929203], [69.09319305, 22.09291649], [69.09319305, 22.09347153], [69.0929184, 22.09347153], [69.0929184, 22.09375191], [69.09263611, 22.09375191], [69.09263611, 22.09403038], [69.09236145, 22.09403038], [69.09236145, 22.09431267], [69.09208679, 22.09430504], [69.09208679, 22.09458351], [69.0918045, 22.09458351], [69.0918045, 22.09486008], [69.09152985, 22.09486008], [69.09152985, 22.09514046], [69.09124756, 22.09513855], [69.09124756, 22.09569359], [69.0909729, 22.09569359], [69.0909729, 22.09597206], [69.09069824, 22.09596252], [69.09069824, 22.09625053], [69.09041595, 22.09625053], [69.09041595, 22.09653091], [69.0901413, 22.09653091], [69.0901413, 22.09680939], [69.08985901, 22.09680557], [69.08985901, 22.09708214], [69.08956909, 22.09708023], [69.08956909, 22.09764099], [69.08930206, 22.09764099], [69.08930206, 22.09791946], [69.0890274, 22.09791756], [69.0890274, 22.09819412], [69.08875275, 22.09819412], [69.08875275, 22.0984726], [69.08847046, 22.09847069], [69.08847046, 22.09875107], [69.0881958, 22.09874916], [69.0881958, 22.09902763], [69.08790588, 22.09902], [69.08790588, 22.09930992], [69.08763885, 22.09930992], [69.08763885, 22.09986115], [69.08735657, 22.09986115], [69.08735657, 22.10013962], [69.08708191, 22.10013962], [69.08708191, 22.10042], [69.08680725, 22.10041428], [69.08680725, 22.10069466], [69.08652496, 22.10069466], [69.08652496, 22.10097313], [69.08625031, 22.10097122], [69.08625031, 22.10124969], [69.08598328, 22.10124969], [69.08598328, 22.10153008], [69.0854187, 22.10152626], [69.0854187, 22.10180473], [69.08513641, 22.10180092], [69.08513641, 22.10209084], [69.08486176, 22.10208321], [69.08486176, 22.10236168], [69.0845871, 22.10235977], [69.0845871, 22.10264015], [69.08429718, 22.10264015], [69.08429718, 22.10292053], [69.08403015, 22.10292053], [69.08403015, 22.10320091], [69.08374786, 22.10319519], [69.08374786, 22.10347176], [69.08347321, 22.10346985], [69.08347321, 22.10375023], [69.08291626, 22.10375023], [69.08291626, 22.10403061], [69.0826416, 22.10403061], [69.0826416, 22.10430908], [69.08235931, 22.10430527], [69.08235931, 22.10458374], [69.08207703, 22.10457993], [69.08207703, 22.1048584], [69.08180237, 22.1048584], [69.08180237, 22.10515022], [69.08152771, 22.10515022], [69.08152771, 22.10541916], [69.08125305, 22.10541725], [69.08125305, 22.10569382], [69.08097076, 22.10569382], [69.08097076, 22.10597229], [69.08040619, 22.10596848], [69.08040619, 22.10625076], [69.08013916, 22.10625076], [69.08013916, 22.10652924], [69.07985687, 22.10652924], [69.07985687, 22.10680962], [69.07958221, 22.1068058], [69.07958221, 22.10708427], [69.07930756, 22.10707855], [69.07930756, 22.10736275], [69.0790329, 22.10736275], [69.0790329, 22.10764122], [69.07875061, 22.10764122], [69.07875061, 22.10791969], [69.07847595, 22.10791588], [69.07847595, 22.10819435], [69.07791901, 22.10819435], [69.07791901, 22.10847282], [69.07762909, 22.10847282], [69.07762909, 22.10874939], [69.07736206, 22.10874939], [69.07736206, 22.10902977], [69.07707977, 22.10902977], [69.07707977, 22.10931015], [69.07680511, 22.10930634], [69.07680511, 22.1095829], [69.07653046, 22.1095829], [69.07653046, 22.10986137], [69.07624817, 22.10985947], [69.07624817, 22.11013985], [69.07596588, 22.11013985], [69.07596588, 22.11042023], [69.07541656, 22.11041641], [69.07541656, 22.11069489], [69.07514191, 22.11069489], [69.07514191, 22.11097145], [69.07485962, 22.11096191], [69.07485962, 22.11124992], [69.07459259, 22.11124992], [69.07459259, 22.1115303], [69.07430267, 22.1115303], [69.07430267, 22.11181068], [69.07402802, 22.11180305], [69.07402802, 22.11208344], [69.07375336, 22.11208344], [69.07375336, 22.11236191], [69.07347107, 22.11236], [69.07347107, 22.11264038], [69.07290649, 22.11264038], [69.07290649, 22.11292076], [69.07263947, 22.11291695], [69.07263947, 22.1131897], [69.07236481, 22.11319733], [69.07236481, 22.11347198], [69.07208252, 22.11347008], [69.07208252, 22.11375046], [69.07182312, 22.11375046], [69.07182312, 22.11403084], [69.0715332, 22.11403084], [69.0715332, 22.11432076], [69.07125092, 22.1143055], [69.07125092, 22.11458588], [69.07096863, 22.11458015], [69.07096863, 22.11486053], [69.07041931, 22.11486053], [69.07041931, 22.11514091], [69.07013702, 22.11514091], [69.07013702, 22.11541939], [69.06986237, 22.11541557], [69.06986237, 22.11569405], [69.06958008, 22.11569405], [69.06958008, 22.11597252], [69.06931305, 22.11597061], [69.06931305, 22.11625099], [69.06903076, 22.11625099], [69.06903076, 22.11652946], [69.0687561, 22.11652946], [69.0687561, 22.11680984], [69.06846619, 22.11680984], [69.06846619, 22.11708832], [69.06791687, 22.11708832], [69.06791687, 22.11736107], [69.06764221, 22.11736107], [69.06764221, 22.11763954], [69.06735992, 22.11763954], [69.06735992, 22.11791992], [69.06708527, 22.11791611], [69.06708527, 22.11819458], [69.06680298, 22.11819458], [69.06680298, 22.11847305], [69.06652832, 22.11846924], [69.06652832, 22.11874962], [69.06624603, 22.11874962], [69.06624603, 22.11903191], [69.06597137, 22.11902809], [69.06597137, 22.11930466], [69.06569672, 22.11930466], [69.06569672, 22.11958313], [69.06541443, 22.11958313], [69.06541443, 22.1198616], [69.06513977, 22.1198616], [69.06513977, 22.12013817], [69.06485748, 22.12013054], [69.06485748, 22.12070274], [69.06458282, 22.12069511], [69.06458282, 22.12097168], [69.06430817, 22.12097168], [69.06430817, 22.12125015], [69.06402588, 22.12125015], [69.06402588, 22.12153053], [69.06375122, 22.12153053], [69.06375122, 22.12181282], [69.06346893, 22.12180519], [69.06346893, 22.12208366], [69.06318665, 22.12208176], [69.06318665, 22.12236023], [69.06291962, 22.12236023], [69.06291962, 22.12264061], [69.0626297, 22.12264061], [69.0626297, 22.1229229], [69.06208038, 22.12291718], [69.06208038, 22.12319374], [69.06180573, 22.12319374], [69.06180573, 22.12347221], [69.06124878, 22.12347031], [69.06124878, 22.12375069], [69.06096649, 22.12375069], [69.06096649, 22.12403107], [69.06041718, 22.12403107], [69.06041718, 22.12430954], [69.06014252, 22.12430573], [69.06014252, 22.12458229], [69.05958557, 22.12458229], [69.0595932, 22.12486076], [69.05930328, 22.12486076], [69.05930328, 22.12514114], [69.05874634, 22.12514114], [69.05874634, 22.12541962], [69.05847168, 22.1254158], [69.05847168, 22.12569427], [69.05791473, 22.12569427], [69.05791473, 22.12597275], [69.05764008, 22.12597084], [69.05764008, 22.12626076], [69.05735779, 22.12626076], [69.05735779, 22.12652969], [69.05708313, 22.12652969], [69.05708313, 22.12681007], [69.05680847, 22.12680435], [69.05680847, 22.12708282], [69.05652618, 22.12708282], [69.05652618, 22.1273613], [69.05625153, 22.12735939], [69.05625153, 22.12763977], [69.05596924, 22.12763977], [69.05596924, 22.12792015], [69.05569458, 22.12791634], [69.05569458, 22.12819672], [69.05541992, 22.12819672], [69.05541992, 22.12847137], [69.05513763, 22.12846947], [69.05513763, 22.12903023], [69.05486298, 22.12902641], [69.05486298, 22.12930489], [69.05458069, 22.12930489], [69.05458069, 22.12958336], [69.05430603, 22.12957954], [69.05430603, 22.1301403], [69.05403137, 22.1301403], [69.05403137, 22.13069916], [69.05374908, 22.13069534], [69.05374908, 22.13097191], [69.05345917, 22.13096809], [69.05345917, 22.13125038], [69.05291748, 22.13125038], [69.05291748, 22.13180923], [69.05263519, 22.13180542], [69.05263519, 22.13208389], [69.05208588, 22.13207054], [69.05208588, 22.13235855], [69.05179596, 22.13235855], [69.05179596, 22.13291931], [69.05152893, 22.1329174], [69.05152893, 22.13319397], [69.05124664, 22.13318825], [69.05124664, 22.13375282], [69.05097198, 22.13375282], [69.05097198, 22.13402939], [69.05069733, 22.13402748], [69.05069733, 22.13458252], [69.05041504, 22.13458252], [69.05042267, 22.1348629], [69.05014038, 22.1348629], [69.05014038, 22.13513947], [69.04985809, 22.13513184], [69.04985809, 22.13541985], [69.04958344, 22.13541603], [69.04958344, 22.1356945], [69.04902649, 22.1356945], [69.04902649, 22.13597107], [69.04875183, 22.13597107], [69.04875183, 22.13624954], [69.04846954, 22.13624954], [69.04846954, 22.13652992], [69.04818726, 22.13652992], [69.04818726, 22.1368103], [69.04792023, 22.13680649], [69.04792023, 22.13708305], [69.0476532, 22.13708115], [69.0476532, 22.13764], [69.04736328, 22.13764], [69.04736328, 22.13820076], [69.04708099, 22.13820076], [69.04708099, 22.13875008], [69.04680634, 22.13875008], [69.04680634, 22.13903046], [69.04651642, 22.13903046], [69.04651642, 22.13931084], [69.04624939, 22.13931084], [69.04624939, 22.13903046], [69.0459671, 22.13903046], [69.0459671, 22.13931084], [69.04569244, 22.13930321], [69.04569244, 22.13958359], [69.04597473, 22.13958359], [69.04597473, 22.13986206], [69.04569244, 22.13986015], [69.04569244, 22.14014053], [69.04541779, 22.14014053], [69.04541779, 22.14042091], [69.0451355, 22.14041519], [69.0451355, 22.14097214], [69.04486084, 22.14097023], [69.04486084, 22.14126015], [69.04458618, 22.14126015], [69.04458618, 22.14153099], [69.04429626, 22.14153099], [69.04429626, 22.14180946], [69.04374695, 22.14180756], [69.04374695, 22.14208412], [69.04347229, 22.14208031], [69.04347229, 22.14236069], [69.04319763, 22.14236069], [69.04319763, 22.14264107], [69.04291534, 22.14263725], [69.04291534, 22.1431942], [69.04264069, 22.1431942], [69.04264069, 22.14347267], [69.0423584, 22.14347076], [69.0423584, 22.14402962], [69.04208374, 22.14402962], [69.04208374, 22.14430618], [69.04180908, 22.14430046], [69.04180908, 22.14486122], [69.04151917, 22.14486122], [69.04151917, 22.14513969], [69.04125214, 22.14513969], [69.04125214, 22.14541817], [69.04096985, 22.14541626], [69.04096985, 22.14569473], [69.04069519, 22.14569473], [69.04069519, 22.14596939], [69.0404129, 22.14596939], [69.0404129, 22.14625168], [69.04013824, 22.14625168], [69.04013824, 22.14736176], [69.03985596, 22.14736176], [69.03985596, 22.14764023], [69.0395813, 22.14764023], [69.0395813, 22.14792061], [69.03930664, 22.14792061], [69.03930664, 22.1482029], [69.03901672, 22.1482029], [69.03901672, 22.14903069], [69.03874969, 22.14903069], [69.03874969, 22.14931107], [69.03847504, 22.14930534], [69.03847504, 22.14958382], [69.03819275, 22.14958191], [69.03819275, 22.15014076], [69.03791809, 22.15014076], [69.03791809, 22.15042114], [69.0376358, 22.15041733], [69.0376358, 22.15069389], [69.03736115, 22.15069389], [69.03736115, 22.15097237], [69.03708649, 22.15097046], [69.03708649, 22.15125084], [69.03679657, 22.15125084], [69.03679657, 22.15153122], [69.03652954, 22.15153122], [69.03652954, 22.15180969], [69.0359726, 22.15180588], [69.0359726, 22.15208244], [69.03569794, 22.15208244], [69.03569794, 22.15236092], [69.03541565, 22.15236092], [69.03542328, 22.15263939], [69.03514099, 22.15263939], [69.03514099, 22.15291977], [69.0348587, 22.15291405], [69.0348587, 22.1534729], [69.03457642, 22.15347099], [69.03457642, 22.15374947], [69.03430939, 22.15374947], [69.03430176, 22.15402985], [69.03375244, 22.15402985], [69.03375244, 22.15431023], [69.03347015, 22.1543045], [69.03347015, 22.15458298], [69.03320313, 22.15458107], [69.03320313, 22.15513992], [69.03291321, 22.15513992], [69.03291321, 22.1554203], [69.03264618, 22.1554203], [69.03264618, 22.15570068], [69.03236389, 22.15569687], [69.03236389, 22.15597153], [69.0320816, 22.15597153], [69.0320816, 22.15624809], [69.03180695, 22.15624046], [69.03180695, 22.15653038], [69.03151703, 22.15653038], [69.03151703, 22.15681076], [69.03125, 22.15680695], [69.03125, 22.15708351], [69.03097534, 22.15708351], [69.03097534, 22.15736198], [69.03069305, 22.15735817], [69.03069305, 22.15764046], [69.0304184, 22.15764046], [69.0304184, 22.15847206], [69.03069305, 22.15846825], [69.03069305, 22.15903091], [69.0304184, 22.1590271], [69.0304184, 22.15930557], [69.02986145, 22.15930557], [69.02986145, 22.15958405], [69.02957916, 22.15957832], [69.02957916, 22.15986061], [69.02929688, 22.15986061], [69.02929688, 22.16013908], [69.02902985, 22.16013908], [69.02902985, 22.16041946], [69.02874756, 22.16041756], [69.02874756, 22.16069412], [69.0284729, 22.16069412], [69.0284729, 22.1609726], [69.02819824, 22.1609726], [69.02819824, 22.16125107], [69.02791595, 22.16125107], [69.02791595, 22.16152954], [69.0276413, 22.16152763], [69.0276413, 22.16208267], [69.02735901, 22.16208267], [69.02735901, 22.16236115], [69.02707672, 22.16236115], [69.02707672, 22.16263962], [69.02680206, 22.16263962], [69.02680206, 22.16292], [69.0265274, 22.16291618], [69.0265274, 22.16319466], [69.02625275, 22.16319466], [69.02625275, 22.16347313], [69.02597046, 22.16347122], [69.02597046, 22.16403008], [69.02541351, 22.16402817], [69.02541351, 22.16458321], [69.02513885, 22.16458321], [69.02513885, 22.16486168], [69.02485657, 22.16485977], [69.02485657, 22.16543007], [69.02458191, 22.16543007], [69.02458191, 22.16570091], [69.02430725, 22.16569328], [69.02430725, 22.16597176], [69.02402496, 22.16597176], [69.02403259, 22.16625023], [69.02375031, 22.16625023], [69.02375031, 22.16681099], [69.02347565, 22.16680527], [69.02347565, 22.16708374], [69.02319336, 22.16707993], [69.02319336, 22.16736031], [69.0229187, 22.16736031], [69.0229187, 22.16792107], [69.02263641, 22.16791534], [69.02263641, 22.16819382], [69.02236176, 22.16819382], [69.02236176, 22.16847229], [69.0220871, 22.16847038], [69.0220871, 22.16875076], [69.02179718, 22.16875076], [69.02179718, 22.16903114], [69.02153015, 22.16903114], [69.02153015, 22.16930962], [69.02124786, 22.16930771], [69.02124786, 22.16958427], [69.02097321, 22.16958046], [69.02097321, 22.16986084], [69.02069092, 22.16986084], [69.02069092, 22.17014122], [69.0201416, 22.17014122], [69.0201416, 22.17041969], [69.01985931, 22.17041779], [69.01985931, 22.17069435], [69.01958466, 22.17069435], [69.01958466, 22.17097282], [69.01930237, 22.17097282], [69.01930237, 22.17124748], [69.01902771, 22.17123985], [69.01902771, 22.17152977], [69.01875305, 22.17152977], [69.01875305, 22.17180824], [69.01847076, 22.17180634], [69.01847076, 22.1720829], [69.01819611, 22.17207909], [69.01819611, 22.17264175], [69.01790619, 22.17264175], [69.01790619, 22.17292023], [69.01763916, 22.17291641], [69.01763916, 22.17319489], [69.0173645, 22.17319489], [69.0173645, 22.17347145], [69.01708221, 22.17347145], [69.01708221, 22.17375183], [69.01680756, 22.17375183], [69.01680756, 22.17430496], [69.01652527, 22.17430496], [69.01652527, 22.17458344], [69.01625061, 22.17458344], [69.01625061, 22.17486191], [69.01597595, 22.17486191], [69.01597595, 22.17514038], [69.01513672, 22.17514038], [69.01513672, 22.17542076], [69.01457977, 22.17541695], [69.01457977, 22.1756897], [69.01403046, 22.17569542], [69.01403046, 22.17597389], [69.01374817, 22.17597008], [69.01374817, 22.17625046], [69.01346588, 22.17625046], [69.01346588, 22.17681122], [69.01319122, 22.1768055], [69.01319122, 22.17708206], [69.01291656, 22.17708015], [69.01291656, 22.17737007], [69.01264191, 22.17737007], [69.01264191, 22.17764091], [69.01235962, 22.17764091], [69.01235962, 22.17791939], [69.01208496, 22.17791748], [69.01208496, 22.17819214], [69.01180267, 22.17819214], [69.01180267, 22.17847252], [69.01154327, 22.17847061], [69.01154327, 22.17875099], [69.01097107, 22.17875099], [69.01097107, 22.17902946], [69.01069641, 22.17902946], [69.01069641, 22.17930984], [69.01041412, 22.17930412], [69.01041412, 22.1795826], [69.00985718, 22.17958069], [69.00985718, 22.17986107], [69.00958252, 22.17986107], [69.00958252, 22.18013954], [69.00930786, 22.18013954], [69.00930786, 22.18042946], [69.00875092, 22.1804142], [69.00875092, 22.18069458], [69.00846863, 22.18069458], [69.00846863, 22.18097305], [69.00818634, 22.18097115], [69.00818634, 22.18124962], [69.00791931, 22.18124962], [69.00791931, 22.18153], [69.00763702, 22.18152618], [69.00763702, 22.18208313], [69.00736237, 22.18208313], [69.00736237, 22.1823616], [69.00708008, 22.1823597], [69.00708008, 22.18264008], [69.00681305, 22.18264008], [69.00681305, 22.18292046], [69.00653076, 22.18292046], [69.00653076, 22.18320084], [69.00624847, 22.18319511], [69.00624847, 22.18347168], [69.00596619, 22.18346977], [69.00596619, 22.18374825], [69.00569153, 22.18374825], [69.00569153, 22.18431091], [69.00541687, 22.18430519], [69.00541687, 22.18458366], [69.00514221, 22.18457985], [69.00514221, 22.18485832], [69.00485992, 22.18485832], [69.00485992, 22.18514061], [69.0045929, 22.18514061], [69.0045929, 22.18541908], [69.00430298, 22.18541718], [69.00430298, 22.18597221], [69.00402832, 22.18597221], [69.00402832, 22.18625069], [69.00374603, 22.18624115], [69.00374603, 22.18652916], [69.00347137, 22.18652916], [69.00347137, 22.18680954], [69.00319672, 22.18680954], [69.00319672, 22.18736267], [69.0029068, 22.18736267], [69.0029068, 22.18764114], [69.00263977, 22.18764114], [69.00263977, 22.18791962], [69.00235748, 22.1879158], [69.00235748, 22.18819427], [69.00208282, 22.18819046], [69.00208282, 22.18875122], [69.00180817, 22.18875122], [69.00180817, 22.18902969], [69.00152588, 22.18902969], [69.00152588, 22.18931007], [69.00125122, 22.18930626], [69.00125122, 22.18958282], [69.00096893, 22.18958282], [69.00096893, 22.19013977], [69.00068665, 22.19013977], [69.00068665, 22.19042015], [69.00013733, 22.19042015], [68.99986267, 22.19041634], [68.99986267, 22.19069481], [68.99958038, 22.19069481], [68.99958038, 22.19097137], [68.99930573, 22.19097137], [68.99931335, 22.19124985], [68.99903107, 22.19124985], [68.99903107, 22.19180489], [68.99874878, 22.19180489], [68.99874878, 22.19208336], [68.99846649, 22.19207954], [68.99846649, 22.1926403], [68.99819183, 22.1926403], [68.99819183, 22.19292068], [68.99791718, 22.19292068], [68.99791718, 22.19320107], [68.99764252, 22.19319534], [68.99764252, 22.19347191], [68.99736023, 22.19347], [68.99736023, 22.19375038], [68.9970932, 22.19375038], [68.9970932, 22.19431114], [68.99680328, 22.19430542], [68.99680328, 22.19458389], [68.99652863, 22.19458389], [68.99653625, 22.19486046], [68.99624634, 22.19486046], [68.99624634, 22.19514084], [68.99597168, 22.19513893], [68.99597168, 22.1954155], [68.99569702, 22.1954155], [68.99569702, 22.19569397], [68.99541473, 22.19569397], [68.99541473, 22.19597244], [68.99514008, 22.19597054], [68.99514008, 22.19652939], [68.99485779, 22.19652939], [68.99485779, 22.19680977], [68.99458313, 22.19680786], [68.99458313, 22.19708252], [68.99430847, 22.19708061], [68.99430847, 22.19735909], [68.99402618, 22.19735909], [68.99402618, 22.19763947], [68.99375153, 22.19763947], [68.99375153, 22.19791985], [68.99346924, 22.19791794], [68.99346924, 22.1981945], [68.99319458, 22.1981945], [68.99319458, 22.19847298], [68.99291992, 22.19846916], [68.99291992, 22.19874763], [68.99263763, 22.19874763], [68.99263763, 22.19903183], [68.99236298, 22.19903183], [68.99236298, 22.1993103], [68.99208069, 22.19930649], [68.99208069, 22.19986153], [68.99180603, 22.19986153], [68.99180603, 22.20014191], [68.99153137, 22.20014191], [68.99153137, 22.20042038], [68.99124908, 22.20042038], [68.99124908, 22.20070267], [68.99097443, 22.20069504], [68.99097443, 22.2009716], [68.99069214, 22.2009716], [68.99069214, 22.20125008], [68.99040985, 22.20125008], [68.99040985, 22.20153999], [68.99014282, 22.20153999], [68.99014282, 22.20181274], [68.98986053, 22.20180511], [68.98986053, 22.20236206], [68.98958588, 22.20236015], [68.98958588, 22.20264053], [68.98929596, 22.20264053], [68.98929596, 22.20292282], [68.98902893, 22.2029171], [68.98902893, 22.20319366], [68.98874664, 22.20319366], [68.98874664, 22.20347214], [68.98847198, 22.20347023], [68.98847198, 22.20375061], [68.98819733, 22.20375061], [68.98819733, 22.20403099], [68.98791504, 22.20402718], [68.98791504, 22.20458221], [68.98764038, 22.20458031], [68.98764038, 22.20486069], [68.98735046, 22.20486069], [68.98735046, 22.20514107], [68.98707581, 22.20514107], [68.98707581, 22.20541954], [68.98652649, 22.20541763], [68.98652649, 22.2056942], [68.98625183, 22.20569038], [68.98625183, 22.20625114], [68.98596954, 22.20624924], [68.98596954, 22.20708275], [68.98569489, 22.20708275], [68.98569489, 22.20736122], [68.98542023, 22.20734978], [68.98542023, 22.20763969], [68.98513794, 22.20763969], [68.98513794, 22.20792007], [68.98486328, 22.20791435], [68.98486328, 22.2084713], [68.98458099, 22.20846939], [68.98458099, 22.20874977], [68.98402405, 22.20874977], [68.98402405, 22.20930481], [68.98347473, 22.20930481], [68.98347473, 22.20986176], [68.98291779, 22.20985985], [68.98291779, 22.21014023], [68.9826355, 22.21013641], [68.9826355, 22.2104187], [68.98236084, 22.21041107], [68.98236084, 22.21069908], [68.98208618, 22.21069527], [68.98208618, 22.21097183], [68.98179626, 22.21096992], [68.98179626, 22.21125031], [68.98152924, 22.21125031], [68.98152924, 22.21153069], [68.98124695, 22.21153069], [68.98124695, 22.21180916], [68.98097229, 22.21180916], [68.98097229, 22.21235847], [68.98069763, 22.21235847], [68.98069763, 22.21264076], [68.98041534, 22.21264076], [68.98041534, 22.21319389], [68.98014069, 22.21318817], [68.98014069, 22.21375084], [68.9798584, 22.21375084], [68.9798584, 22.21403122], [68.97957611, 22.21403122], [68.97957611, 22.21541977], [68.97930908, 22.21541595], [68.97930908, 22.21569443], [68.97902679, 22.21569252], [68.97902679, 22.21681023], [68.97875214, 22.21680641], [68.97875214, 22.21708488], [68.97846985, 22.21708488], [68.97846985, 22.21736145], [68.97820282, 22.21735954], [68.97820282, 22.21763992], [68.9779129, 22.21763992], [68.9779129, 22.21820068], [68.97763824, 22.21819305], [68.97763824, 22.21847153], [68.97735596, 22.21846962], [68.97735596, 22.21875], [68.9770813, 22.21875], [68.9770813, 22.21903038], [68.97680664, 22.21902847], [68.97680664, 22.21958351], [68.97652435, 22.21958351], [68.97652435, 22.21986198], [68.97624969, 22.21986008], [68.97624969, 22.22014046], [68.97597504, 22.22013855], [68.97597504, 22.22069359], [68.97569275, 22.22069359], [68.97569275, 22.22097206], [68.97541046, 22.22097015], [68.97541046, 22.22125053], [68.9751358, 22.22125053], [68.9751358, 22.22180939], [68.97486115, 22.22180557], [68.97486115, 22.22208595], [68.97458649, 22.22208595], [68.97458649, 22.22236061], [68.97429657, 22.22235107], [68.97429657, 22.22291946], [68.97402954, 22.22291946], [68.97402954, 22.22319412], [68.97374725, 22.22319412], [68.97374725, 22.2234726], [68.9734726, 22.22347069], [68.9734726, 22.22402954], [68.97319794, 22.22402954], [68.97319794, 22.22430992], [68.97291565, 22.22430611], [68.97291565, 22.22485924], [68.9723587, 22.22485924], [68.97236633, 22.22513962], [68.97207642, 22.22513962], [68.97207642, 22.22541809], [68.97180939, 22.22541618], [68.97180176, 22.22569466], [68.9715271, 22.22569466], [68.9715271, 22.22597313], [68.97125244, 22.22597313], [68.97125244, 22.22680473], [68.97097015, 22.22680092], [68.97097015, 22.22820282], [68.97070313, 22.22820282], [68.97070313, 22.22847939], [68.97041321, 22.22847939], [68.97041321, 22.22986031], [68.97013855, 22.22986031], [68.97013855, 22.23014069], [68.9695816, 22.23013878], [68.9695816, 22.23069382], [68.96930695, 22.23069191], [68.96930695, 22.23125076], [68.96901703, 22.23125076], [68.96901703, 22.23180962], [68.96819305, 22.23180962], [68.96819305, 22.23264122], [68.96763611, 22.23264122], [68.96763611, 22.23291969], [68.96736145, 22.23291588], [68.96736145, 22.23319435], [68.96708679, 22.23319435], [68.96708679, 22.23347282], [68.96679688, 22.23347092], [68.96679688, 22.23374939], [68.96652985, 22.23374939], [68.96652985, 22.23402977], [68.9659729, 22.23402977], [68.9659729, 22.23431015], [68.96569824, 22.23430443], [68.96569824, 22.2345829], [68.96541595, 22.2345829], [68.96541595, 22.23486137], [68.96485901, 22.23485947], [68.96485901, 22.23513985], [68.96458435, 22.23513985], [68.96458435, 22.23569679], [68.9640274, 22.23569107], [68.9640274, 22.23624992], [68.96375275, 22.23624992], [68.96375275, 22.2365303], [68.96347046, 22.23652649], [68.96347046, 22.23708344], [68.9631958, 22.23708344], [68.9631958, 22.23736191], [68.96235657, 22.23735809], [68.96235657, 22.23765182], [68.96153259, 22.23765182], [68.96153259, 22.23792076], [68.96069336, 22.23791885], [68.96069336, 22.23819351], [68.95930481, 22.23819351], [68.95930481, 22.23791885], [68.95903015, 22.23792076], [68.95903015, 22.23765182], [68.95847321, 22.23765182], [68.95847321, 22.23707962], [68.95819092, 22.23708344], [68.95819092, 22.23736191], [68.95791626, 22.23735809], [68.95791626, 22.23765182], [68.95736694, 22.23765182], [68.95736694, 22.23792076], [68.9576416, 22.23791885], [68.9576416, 22.23847008], [68.95735931, 22.23847008], [68.95736694, 22.23875046], [68.95707703, 22.23875046], [68.95707703, 22.23985863], [68.95680237, 22.23985863], [68.95680237, 22.24041939], [68.95625305, 22.24041748], [68.95625305, 22.24097252], [68.95597076, 22.24097252], [68.95597076, 22.24180984], [68.95569611, 22.24180984], [68.95569611, 22.24236107], [68.95540619, 22.24236107], [68.95540619, 22.24263954], [68.95513916, 22.24263954], [68.95513916, 22.24291992], [68.9548645, 22.24291611], [68.9548645, 22.24347115], [68.95458221, 22.24346161], [68.95458221, 22.24374962], [68.9540329, 22.24374962], [68.9540329, 22.24403], [68.95430756, 22.24402809], [68.95430756, 22.2448616], [68.9540329, 22.2448597], [68.9540329, 22.24542046], [68.95375061, 22.24541664], [68.95375061, 22.24597168], [68.95319366, 22.24597168], [68.95319366, 22.24708366], [68.95291901, 22.24708366], [68.95291901, 22.24847221], [68.95263672, 22.24847031], [68.95263672, 22.25125122], [68.95291901, 22.25124741], [68.95291901, 22.2523613], [68.95318604, 22.25235748], [68.95318604, 22.25265121], [68.95375061, 22.25265121], [68.95375061, 22.25292015], [68.95402527, 22.25291634], [68.95402527, 22.25319481], [68.95430756, 22.25319481], [68.95430756, 22.25346947], [68.95458221, 22.25346947], [68.95458221, 22.25375175], [68.95485687, 22.25375175], [68.95485687, 22.25403023], [68.95541382, 22.25402832], [68.95541382, 22.25458336], [68.95569611, 22.25457954], [68.95569611, 22.2551403], [68.95597076, 22.2551403], [68.95597076, 22.25542068], [68.95625305, 22.25542068], [68.95625305, 22.2557106], [68.95680237, 22.2557106], [68.95680237, 22.25542068], [68.95708466, 22.25541687], [68.95708466, 22.25597382], [68.9576416, 22.25597191], [68.9576416, 22.25736046], [68.95791626, 22.25736046], [68.95791626, 22.25792122], [68.9576416, 22.2579174], [68.9576416, 22.25819206], [68.95735931, 22.25819206], [68.95735931, 22.25847244], [68.95707703, 22.25846291], [68.95707703, 22.25930977], [68.95680237, 22.25930977], [68.95680237, 22.26013947], [68.95652771, 22.26013947], [68.95652771, 22.2606945], [68.95597076, 22.26069069], [68.95597076, 22.26152992], [68.95569611, 22.26152611], [68.95569611, 22.26208305], [68.95513916, 22.26208115], [68.95513916, 22.26263809], [68.95485687, 22.26263809], [68.95485687, 22.26292038], [68.95458221, 22.26292038], [68.95458221, 22.26374817], [68.95429993, 22.26374817], [68.95429993, 22.26403046], [68.9540329, 22.26403046], [68.9540329, 22.26458931], [68.95430756, 22.26458359], [68.95430756, 22.26486206], [68.9540329, 22.26485825], [68.9540329, 22.26514053], [68.95375061, 22.26514053], [68.95375061, 22.26569366], [68.95347595, 22.26568985], [68.95347595, 22.26625061], [68.95318604, 22.26625061], [68.95318604, 22.26680946], [68.95291901, 22.26680946], [68.95291901, 22.26736259], [68.95263672, 22.26736259], [68.95263672, 22.2681942], [68.95236206, 22.26819038], [68.95236206, 22.26875114], [68.95207977, 22.26875114], [68.95207977, 22.26931], [68.95181274, 22.26931], [68.95181274, 22.27042007], [68.95153046, 22.27041626], [68.95153046, 22.27069473], [68.95124054, 22.27069283], [68.95124054, 22.27153015], [68.95097351, 22.27152824], [68.95097351, 22.27236176], [68.95069122, 22.27235985], [68.95069122, 22.27320099], [68.95041656, 22.27319336], [68.95041656, 22.27347183], [68.95014191, 22.27346992], [68.95014191, 22.27375031], [68.94985962, 22.27375031], [68.94985962, 22.27403069], [68.94959259, 22.27403069], [68.94959259, 22.27431107], [68.94930267, 22.27431107], [68.94930267, 22.27514076], [68.94902802, 22.27513885], [68.94902802, 22.27569389], [68.94875336, 22.27569008], [68.94875336, 22.27625084], [68.94847107, 22.27625084], [68.94847107, 22.27681923], [68.94819641, 22.27681923], [68.94819641, 22.27736092], [68.94790649, 22.27736092], [68.94790649, 22.27791977], [68.94763947, 22.27791595], [68.94763947, 22.2784729], [68.94735718, 22.27846909], [68.94735718, 22.27902985], [68.94708252, 22.27902985], [68.94708252, 22.27959251], [68.94680786, 22.27958298], [68.94680786, 22.27986145], [68.9465332, 22.27986145], [68.9465332, 22.2804203], [68.94625092, 22.2804203], [68.94625092, 22.28070259], [68.94596863, 22.28069496], [68.94596863, 22.28097153], [68.94568634, 22.28097153], [68.94568634, 22.28153038], [68.94542694, 22.28153038], [68.94542694, 22.28181267], [68.94513702, 22.28180504], [68.94513702, 22.28236389], [68.94486237, 22.28236008], [68.94486237, 22.28292084], [68.94458008, 22.28291702], [68.94458008, 22.28347206], [68.94431305, 22.28347015], [68.94431305, 22.28403091], [68.94403076, 22.2840271], [68.94403076, 22.28458214], [68.94374847, 22.28458023], [68.94374847, 22.28514099], [68.94347382, 22.28513908], [68.94347382, 22.2859726], [68.94319153, 22.28597069], [68.94319153, 22.28680992], [68.94291687, 22.28680992], [68.94291687, 22.28792], [68.94264221, 22.28792], [68.94264221, 22.28876114], [68.94235992, 22.28874969], [68.94235992, 22.28930473], [68.94208527, 22.28930473], [68.9420929, 22.29124832], [68.94180298, 22.29124832], [68.94180298, 22.29182243], [68.94152832, 22.29182243], [68.94152832, 22.2923584], [68.94124603, 22.2923584], [68.94124603, 22.29291916], [68.94097137, 22.29291725], [68.94097137, 22.29319382], [68.94069672, 22.2931881], [68.94069672, 22.29403114], [68.9404068, 22.29403114], [68.9404068, 22.29486275], [68.94013977, 22.29486275], [68.94013977, 22.29597282], [68.93985748, 22.29597282], [68.93985748, 22.29652977], [68.93930817, 22.29652786], [68.93930817, 22.29708481], [68.93902588, 22.2970829], [68.93902588, 22.29931068], [68.93875122, 22.29931068], [68.93875122, 22.30042076], [68.93846893, 22.30042076], [68.93846893, 22.30070114], [68.93818665, 22.30070114], [68.93818665, 22.30125046], [68.93791962, 22.30125046], [68.93791962, 22.30181122], [68.93763733, 22.30181122], [68.93763733, 22.30264091], [68.93736267, 22.3026371], [68.93736267, 22.30319405], [68.93708038, 22.30319023], [68.93708038, 22.30430984], [68.93680573, 22.30430794], [68.93680573, 22.30597305], [68.93653107, 22.30596924], [68.93653107, 22.30764008], [68.93625641, 22.30764008], [68.93625641, 22.31014061], [68.93597412, 22.3101387], [68.93597412, 22.3120842], [68.93624878, 22.3120842], [68.93624878, 22.31319427], [68.93653107, 22.31319046], [68.93653107, 22.31431007], [68.93680573, 22.31430435], [68.93680573, 22.3148613], [68.93708038, 22.31485939], [68.93708038, 22.31542015], [68.93736267, 22.31542015], [68.93736267, 22.31570053], [68.93763733, 22.31570053], [68.93763733, 22.31624985], [68.93791962, 22.31624985], [68.93791962, 22.31653023], [68.93819427, 22.31652641], [68.93819427, 22.31708336], [68.93846893, 22.31708336], [68.93846893, 22.31847191], [68.93875122, 22.31846809], [68.93875122, 22.32041931], [68.93902588, 22.3204174], [68.93902588, 22.32097244], [68.93930054, 22.32097244], [68.93930054, 22.32125282], [68.93958282, 22.32125282], [68.93958282, 22.3223629], [68.93985748, 22.3223629], [68.93985748, 22.32374954], [68.94013977, 22.32374954], [68.94013977, 22.32487106], [68.94041443, 22.32486153], [68.94041443, 22.3259716], [68.94069672, 22.3259716], [68.94069672, 22.32708359], [68.94097137, 22.32708359], [68.94097137, 22.32819366], [68.94124603, 22.32818985], [68.94124603, 22.32930946], [68.94152832, 22.32930946], [68.94152832, 22.33041954], [68.94180298, 22.33041954], [68.94180298, 22.33125114], [68.9420929, 22.33125114], [68.9420929, 22.33180809], [68.94235992, 22.33180809], [68.94235992, 22.33235931], [68.94264221, 22.33235931], [68.94264221, 22.33292007], [68.94291687, 22.33291626], [68.94291687, 22.33319473], [68.94347382, 22.33319473], [68.94347382, 22.33291626], [68.94431305, 22.33292007], [68.94431305, 22.3326416], [68.94486237, 22.3326416], [68.94486237, 22.33235931], [68.94513702, 22.33235931], [68.94513702, 22.33208084], [68.94569397, 22.33208275], [68.94569397, 22.33180618], [68.94625092, 22.33180809], [68.94625092, 22.33152962], [68.94902802, 22.33152962], [68.94902802, 22.33180809], [68.95041656, 22.33180618], [68.95041656, 22.33208275], [68.95180511, 22.33208275], [68.95180511, 22.33235931], [68.95236206, 22.33235931], [68.95236206, 22.33292007], [68.95319366, 22.33291626], [68.95319366, 22.33319473], [68.95347595, 22.33319473], [68.95347595, 22.33346939], [68.95375061, 22.33346939], [68.95375061, 22.33375168], [68.9540329, 22.33373833], [68.9540329, 22.33403015], [68.95430756, 22.33402824], [68.95430756, 22.33430481], [68.95458221, 22.33430481], [68.95458221, 22.33458328], [68.95485687, 22.33457947], [68.95485687, 22.33514023], [68.95513916, 22.33513832], [68.95513916, 22.33597374], [68.95540619, 22.33597183], [68.95540619, 22.33625031], [68.95513916, 22.33625031], [68.95513916, 22.33708382], [68.95540619, 22.33708191], [68.95540619, 22.33764076], [68.95569611, 22.33764076], [68.95569611, 22.33792114], [68.95625305, 22.33791733], [68.95625305, 22.33819389], [68.95652771, 22.33819008], [68.95652771, 22.33930969], [68.95680237, 22.33930969], [68.95680237, 22.34124947], [68.95652771, 22.34124947], [68.95652771, 22.34263992], [68.95625305, 22.34263992], [68.95625305, 22.34320068], [68.95597076, 22.34320068], [68.95597076, 22.34514046], [68.95569611, 22.34514046], [68.95569611, 22.34569359], [68.95597076, 22.34568024], [68.95597076, 22.34625053], [68.95625305, 22.34625053], [68.95625305, 22.34680939], [68.95652771, 22.34680939], [68.95652771, 22.3473587], [68.95680237, 22.3473587], [68.95680237, 22.34791946], [68.95708466, 22.34791756], [68.95708466, 22.3484726], [68.95736694, 22.3484726], [68.95736694, 22.34902954], [68.9576416, 22.34902954], [68.9576416, 22.34930992], [68.95791626, 22.34930992], [68.95791626, 22.34986115], [68.95819092, 22.34986115], [68.95819092, 22.35013962], [68.95791626, 22.35013962], [68.95791626, 22.35097313], [68.95847321, 22.35097122], [68.95847321, 22.35153008], [68.95874786, 22.35153008], [68.95874786, 22.35181046], [68.95903015, 22.35180473], [68.95903015, 22.35347176], [68.95874786, 22.35346985], [68.95874786, 22.35431099], [68.95847321, 22.35430527], [68.95847321, 22.35458374], [68.95819092, 22.35457993], [68.95819092, 22.35514069], [68.95791626, 22.35513878], [68.95791626, 22.35569382], [68.95819092, 22.35569], [68.95819092, 22.35902977], [68.95791626, 22.35902977], [68.95791626, 22.35986137], [68.9576416, 22.35986137], [68.9576416, 22.36069489], [68.95735931, 22.36069489], [68.95736694, 22.36125183], [68.95708466, 22.36125183], [68.95708466, 22.36208344], [68.95680237, 22.36208344], [68.95680237, 22.36236382], [68.95708466, 22.36236382], [68.95707703, 22.3631897], [68.95680237, 22.36320114], [68.95680237, 22.36375046], [68.95652771, 22.36375046], [68.95652771, 22.36486053], [68.95680237, 22.36486053], [68.95680237, 22.36652946], [68.95708466, 22.36652756], [68.95708466, 22.3670826], [68.95735931, 22.3670826], [68.95735931, 22.36763954], [68.9576416, 22.36763954], [68.9576416, 22.36791992], [68.95791626, 22.3679142], [68.95791626, 22.36847305], [68.95819092, 22.36847115], [68.95819092, 22.36903], [68.95847321, 22.36902618], [68.95847321, 22.36930466], [68.95874786, 22.36930466], [68.95874786, 22.3698616], [68.95903015, 22.36985016], [68.95903015, 22.37042046], [68.95929718, 22.37042046], [68.95929718, 22.37070084], [68.9595871, 22.37070084], [68.9595871, 22.37124825], [68.95986176, 22.37124825], [68.95986176, 22.37181091], [68.96013641, 22.37181091], [68.96013641, 22.37235832], [68.96042633, 22.37235832], [68.96042633, 22.37291908], [68.96069336, 22.37291718], [68.96069336, 22.37347221], [68.96098328, 22.3734684], [68.96098328, 22.37402916], [68.96125031, 22.37402725], [68.96125031, 22.3745842], [68.96152496, 22.3745842], [68.96152496, 22.37486267], [68.96180725, 22.37486267], [68.96180725, 22.37541962], [68.96208191, 22.3754158], [68.96208191, 22.37569427], [68.96235657, 22.37569046], [68.96235657, 22.37625122], [68.96263885, 22.37625122], [68.96263885, 22.37652969], [68.96291351, 22.37652779], [68.96291351, 22.37708282], [68.9631958, 22.37708282], [68.9631958, 22.3773613], [68.96347046, 22.37735939], [68.96347046, 22.37792015], [68.96375275, 22.37791634], [68.96375275, 22.37819481], [68.9640274, 22.37819481], [68.9640274, 22.37847137], [68.96457672, 22.37846947], [68.96457672, 22.37874985], [68.96485901, 22.37874985], [68.96485901, 22.37903976], [68.9651413, 22.37902832], [68.9651413, 22.37986183], [68.96541595, 22.37985992], [68.96541595, 22.3801403], [68.96569824, 22.3801403], [68.96569824, 22.38042068], [68.9659729, 22.38042068], [68.9659729, 22.38070107], [68.96624756, 22.38069534], [68.96624756, 22.38097191], [68.96652985, 22.38097], [68.96652985, 22.38125038], [68.96679688, 22.38125038], [68.96679688, 22.38236046], [68.96708679, 22.38236046], [68.96708679, 22.38402748], [68.96736145, 22.38402748], [68.96736145, 22.38513756], [68.96763611, 22.38513756], [68.96763611, 22.38597298], [68.9679184, 22.38597298], [68.9679184, 22.38708305], [68.96819305, 22.38707924], [68.96819305, 22.38792038], [68.96848297, 22.38792038], [68.96848297, 22.38903046], [68.96875, 22.38903046], [68.96875, 22.38986015], [68.96901703, 22.38986015], [68.96901703, 22.39097977], [68.96930695, 22.39097977], [68.96930695, 22.39153099], [68.96985626, 22.39153099], [68.96985626, 22.39180946], [68.97013855, 22.39180565], [68.97013855, 22.39208412], [68.9706955, 22.39208412], [68.9706955, 22.39236069], [68.97097015, 22.39236069], [68.97097015, 22.39291954], [68.97125244, 22.39291573], [68.97125244, 22.3931942], [68.9715271, 22.39319038], [68.9715271, 22.39375114], [68.97180176, 22.39375114], [68.97180939, 22.39431], [68.97208405, 22.39430428], [68.97208405, 22.39458275], [68.9723587, 22.39458275], [68.9723587, 22.39513969], [68.97264099, 22.39513969], [68.97264099, 22.39542007], [68.97291565, 22.39541626], [68.97291565, 22.3959713], [68.97319794, 22.39596939], [68.97319794, 22.39624977], [68.9734726, 22.39624977], [68.9734726, 22.39680481], [68.97374725, 22.39680481], [68.97374725, 22.39736176], [68.97402954, 22.39735985], [68.97402954, 22.39763832], [68.97429657, 22.39763832], [68.97429657, 22.39819908], [68.97458649, 22.39819527], [68.97458649, 22.39847183], [68.9751358, 22.39846992], [68.9751358, 22.39903069], [68.97541809, 22.39902687], [68.97541809, 22.39958382], [68.97569275, 22.39957809], [68.97569275, 22.4001503], [68.97597504, 22.40014076], [68.97597504, 22.40069389], [68.97624969, 22.40068817], [68.97624969, 22.40125275], [68.97651672, 22.40125275], [68.97651672, 22.40153122], [68.97680664, 22.4015274], [68.97680664, 22.40208244], [68.9770813, 22.40208244], [68.9770813, 22.40236282], [68.97735596, 22.40236282], [68.97735596, 22.40291977], [68.97763824, 22.40291595], [68.97763824, 22.40319443], [68.9779129, 22.40319061], [68.9779129, 22.40374947], [68.97820282, 22.40374947], [68.97820282, 22.40431023], [68.97846985, 22.40430641], [68.97846985, 22.40458488], [68.97875214, 22.40458107], [68.97875214, 22.40513992], [68.97902679, 22.40513992], [68.97902679, 22.4054203], [68.97930908, 22.40541649], [68.97930908, 22.40597153], [68.97957611, 22.40596008], [68.97957611, 22.40625], [68.9798584, 22.40625], [68.9798584, 22.40681076], [68.98014069, 22.40680695], [68.98014069, 22.40708351], [68.98042297, 22.4070797], [68.98042297, 22.40764046], [68.98069763, 22.40764046], [68.98069763, 22.40792084], [68.98097229, 22.40791512], [68.98097229, 22.40847206], [68.98124695, 22.40847015], [68.98124695, 22.40875053], [68.98152924, 22.40875053], [68.98152924, 22.40930939], [68.98180389, 22.40930557], [68.98180389, 22.40958405], [68.98208618, 22.40958023], [68.98208618, 22.41014099], [68.98236084, 22.41014099], [68.98236084, 22.41041946], [68.9826355, 22.41041946], [68.9826355, 22.4109726], [68.98291779, 22.41097069], [68.98291779, 22.41124916], [68.98319244, 22.41124916], [68.98319244, 22.41180992], [68.9834671, 22.41180992], [68.9834671, 22.41235924], [68.98374939, 22.41235924], [68.98374939, 22.41263771], [68.98402405, 22.41263771], [68.98402405, 22.41319466], [68.98430634, 22.41319084], [68.98430634, 22.4137516], [68.98458099, 22.4137516], [68.98458099, 22.41430473], [68.98486328, 22.41430473], [68.98486328, 22.41458321], [68.98513794, 22.41458321], [68.98513794, 22.41486168], [68.98568726, 22.41486168], [68.98568726, 22.41514969], [68.98596954, 22.41514969], [68.98596954, 22.41542053], [68.98652649, 22.41542053], [68.98652649, 22.41570282], [68.98680878, 22.41569519], [68.98680878, 22.41597366], [68.98735046, 22.41597176], [68.98735046, 22.41625023], [68.98764038, 22.41625023], [68.98764038, 22.41653061], [68.98792267, 22.41653061], [68.98792267, 22.4168129], [68.98819733, 22.4168129], [68.98819733, 22.41653061], [68.98874664, 22.41653061], [68.98874664, 22.4168129], [68.98902893, 22.41680527], [68.98902893, 22.41708374], [68.98958588, 22.41708183], [68.98958588, 22.41764069], [68.98986053, 22.41764069], [68.98986053, 22.41792107], [68.99041748, 22.41791725], [68.99041748, 22.41819382], [68.99069214, 22.41819382], [68.99069214, 22.41847229], [68.99153137, 22.41847038], [68.99153137, 22.41903114], [68.99180603, 22.41903114], [68.99180603, 22.41930962], [68.99208069, 22.4193058], [68.99208069, 22.41958237], [68.99263763, 22.41958046], [68.99263763, 22.41986084], [68.99291992, 22.41986084], [68.99291992, 22.42041969], [68.99346924, 22.42041588], [68.99346924, 22.42097282], [68.99375153, 22.42095947], [68.99375153, 22.42152977], [68.99402618, 22.42152786], [68.99402618, 22.4220829], [68.99430847, 22.4220829], [68.99430847, 22.42236137], [68.99458313, 22.42236137], [68.99458313, 22.42319489], [68.99485779, 22.42319107], [68.99485779, 22.42374992], [68.99514008, 22.42374992], [68.99514008, 22.4240303], [68.99541473, 22.42402649], [68.99541473, 22.42458344], [68.99485779, 22.42458344], [68.99485779, 22.42486191], [68.99514008, 22.42485809], [68.99514008, 22.42514038], [68.9954071, 22.42514038], [68.9954071, 22.42542076], [68.99597168, 22.42541885], [68.99597168, 22.42569351], [68.99624634, 22.42569351], [68.99624634, 22.42597008], [68.99652863, 22.42597008], [68.99652863, 22.42624855], [68.99680328, 22.42624855], [68.99680328, 22.42653084], [68.9970932, 22.42653084], [68.9970932, 22.42680931], [68.99736023, 22.42680931], [68.99736023, 22.42708969], [68.99764252, 22.42708969], [68.99764252, 22.42735863], [68.99791718, 22.42735863], [68.99791718, 22.42764282], [68.99819183, 22.42764282], [68.99819183, 22.42791939], [68.99874878, 22.42791748], [68.99874878, 22.42819405], [68.99903107, 22.42819405], [68.99903107, 22.42847252], [68.99931335, 22.42847252], [68.99931335, 22.4287529], [68.99958038, 22.4287529], [68.99958038, 22.42902946], [68.99986267, 22.42902946], [68.99986267, 22.42930984], [69.00013733, 22.42930984], [69.00041962, 22.42930603], [69.00041962, 22.43013954], [69.00068665, 22.43013191], [69.00068665, 22.43041992], [69.00096893, 22.43041611], [69.00096893, 22.43069458], [69.00125122, 22.43069458], [69.00125122, 22.43097305], [69.00152588, 22.43097115], [69.00152588, 22.43124962], [69.00180817, 22.43124962], [69.00180817, 22.43180466], [69.00208282, 22.43180466], [69.00208282, 22.43208313], [69.00235748, 22.43208313], [69.00235748, 22.4323616], [69.00263977, 22.4323597], [69.00263977, 22.43264008], [69.00291443, 22.43263817], [69.00291443, 22.43319321], [69.00319672, 22.43319321], [69.00319672, 22.43347168], [69.00347137, 22.43346977], [69.00347137, 22.43403053], [69.00402832, 22.43403053], [69.00402832, 22.43375015], [69.00485992, 22.43375015], [69.00485992, 22.43403053], [69.00514221, 22.43403053], [69.00514221, 22.43542099], [69.00540924, 22.43542099], [69.00540924, 22.43653107], [69.00569153, 22.43653107], [69.00569153, 22.43764114], [69.00597382, 22.43763733], [69.00597382, 22.43819427], [69.00624847, 22.43819427], [69.00624847, 22.43847275], [69.00653076, 22.43847084], [69.00653076, 22.43875122], [69.00708008, 22.43875122], [69.00708008, 22.43902969], [69.00736237, 22.43902969], [69.00736237, 22.43931961], [69.00763702, 22.43930626], [69.00763702, 22.43958282], [69.00791931, 22.43958282], [69.00791931, 22.43985939], [69.00875092, 22.43985939], [69.00875092, 22.44014168], [69.0090332, 22.44014168], [69.0090332, 22.44042015], [69.00958252, 22.44041634], [69.00958252, 22.44069481], [69.01041412, 22.44069481], [69.01041412, 22.44096947], [69.01069641, 22.44096947], [69.01069641, 22.44125175], [69.01097107, 22.44125175], [69.01097107, 22.44180489], [69.01125336, 22.44180489], [69.01125336, 22.44208336], [69.01180267, 22.44208336], [69.01180267, 22.44236183], [69.01264191, 22.44236183], [69.01264191, 22.4426403], [69.01291656, 22.4426403], [69.01291656, 22.44292068], [69.01319122, 22.44292068], [69.01319122, 22.44320107], [69.01374817, 22.44319534], [69.01374817, 22.44347382], [69.01403046, 22.44347382], [69.01403046, 22.44319534], [69.01457977, 22.44319534], [69.01457977, 22.44347382], [69.01486206, 22.44347191], [69.01486206, 22.44403076], [69.01513672, 22.44403076], [69.01513672, 22.44431114], [69.01541901, 22.44430542], [69.01541901, 22.44458389], [69.01568604, 22.44458008], [69.01568604, 22.44486046], [69.01597595, 22.44486046], [69.01597595, 22.44513893], [69.01625061, 22.44512939], [69.01625061, 22.44542122], [69.0173645, 22.4454174], [69.0173645, 22.44569588], [69.01763916, 22.44569016], [69.01763916, 22.44652939], [69.01790619, 22.44652939], [69.01790619, 22.44680977], [69.01847076, 22.44680405], [69.01847076, 22.44708252], [69.0201416, 22.44708061], [69.0201416, 22.44736099], [69.02069092, 22.44736099], [69.02069092, 22.44763947], [69.02153015, 22.44763947], [69.02153015, 22.44791985], [69.0220871, 22.44791985], [69.0220871, 22.44820023], [69.0229187, 22.4481945], [69.0229187, 22.44847298], [69.02319336, 22.44847107], [69.02319336, 22.44874954], [69.02347565, 22.44874954], [69.02348328, 22.44930077], [69.02375031, 22.44930649], [69.02375031, 22.44958305], [69.0256958, 22.44958305], [69.0256958, 22.44986153], [69.02625275, 22.44985962], [69.02625275, 22.45013809], [69.02680206, 22.45013809], [69.02680206, 22.45042038], [69.02735901, 22.45042038], [69.02735901, 22.45070076], [69.02791595, 22.45070076], [69.02791595, 22.45126152], [69.02819824, 22.45126152], [69.02819824, 22.45153046], [69.0284729, 22.45153046], [69.0284729, 22.45208359], [69.02874756, 22.45207977], [69.02874756, 22.45235825], [69.02902985, 22.45235825], [69.02902985, 22.45264053], [69.02957916, 22.45264053], [69.02957916, 22.45292091], [69.03013611, 22.4529171], [69.03013611, 22.45319366], [69.0304184, 22.45319366], [69.0304184, 22.45347023], [69.03125, 22.45346832], [69.03125, 22.45375061], [69.03152466, 22.45375061], [69.03152466, 22.45430565], [69.03180695, 22.45430565], [69.03180695, 22.45458412], [69.0320816, 22.45458031], [69.0320816, 22.45486259], [69.0340271, 22.45486259], [69.0340271, 22.45514107], [69.03430176, 22.45514107], [69.03430939, 22.45541954], [69.03514099, 22.45541573], [69.03514099, 22.4556942], [69.03541565, 22.4556942], [69.03541565, 22.45597267], [69.0359726, 22.45597267], [69.0359726, 22.45625114], [69.03708649, 22.45625114], [69.03708649, 22.45652962], [69.03791809, 22.45652962], [69.03791809, 22.45681], [69.03847504, 22.45680618], [69.03847504, 22.45708275], [69.03874969, 22.4570694], [69.03874969, 22.45736122], [69.0395813, 22.45736122], [69.0395813, 22.45763969], [69.03985596, 22.45763969], [69.03985596, 22.45792007], [69.0404129, 22.45791626], [69.0404129, 22.45819473], [69.04096985, 22.45819473], [69.04096985, 22.4584713], [69.04151917, 22.45846939], [69.04151917, 22.45874977], [69.04180908, 22.45874977], [69.04180908, 22.45846939], [69.04207611, 22.45846939], [69.04207611, 22.45874977], [69.04264069, 22.45874977], [69.04264069, 22.45903015], [69.04291534, 22.45902824], [69.04291534, 22.45930481], [69.04319763, 22.45930481], [69.04319763, 22.45958328], [69.04374695, 22.45958328], [69.04374695, 22.45986176], [69.04402924, 22.45985985], [69.04402924, 22.46014023], [69.04458618, 22.46014023], [69.04458618, 22.46042061], [69.04514313, 22.46042061], [69.04514313, 22.46070099], [69.04569244, 22.46069527], [69.04569244, 22.46097183], [69.04651642, 22.46096992], [69.04651642, 22.46125031], [69.04680634, 22.46125031], [69.04680634, 22.46153069], [69.04708099, 22.46153069], [69.04708099, 22.46181107], [69.04763794, 22.46180534], [69.04763794, 22.46208382], [69.04846954, 22.46208], [69.04846954, 22.46236038], [69.04902649, 22.46236038], [69.04902649, 22.46264076], [69.04957581, 22.46264076], [69.04957581, 22.46292114], [69.05014038, 22.46292114], [69.05014038, 22.46319962], [69.05097198, 22.46319389], [69.05097198, 22.46347237], [69.05152893, 22.46347046], [69.05152893, 22.46375084], [69.05208588, 22.46375084], [69.05208588, 22.46403122], [69.05264282, 22.46403122], [69.05264282, 22.46430969], [69.05319214, 22.46430588], [69.05319214, 22.46458244], [69.05374908, 22.46458054], [69.05374908, 22.46486092], [69.05430603, 22.46486092], [69.05430603, 22.46513748], [69.05486298, 22.46513748], [69.05486298, 22.46541977], [69.05541992, 22.46541595], [69.05541992, 22.46569443], [69.05596924, 22.46569443], [69.05596924, 22.4659729], [69.05652618, 22.4659729], [69.05652618, 22.46625137], [69.05735779, 22.46623993], [69.05735779, 22.46653175], [69.05819702, 22.46653175], [69.05819702, 22.46681023], [69.05874634, 22.46680641], [69.05874634, 22.46708107], [69.05930328, 22.46708107], [69.05930328, 22.46736145], [69.05986023, 22.46736145], [69.05986023, 22.46764183], [69.06014252, 22.46764183], [69.06014252, 22.46875191], [69.06041718, 22.46875191], [69.06041718, 22.46903038], [69.06097412, 22.46902847], [69.06097412, 22.46930504], [69.06124878, 22.46930504], [69.06124878, 22.46958351], [69.06180573, 22.46958351], [69.06180573, 22.46986389], [69.06208038, 22.46986008], [69.06208038, 22.47014046], [69.0626297, 22.47014046], [69.0626297, 22.47042084], [69.06291962, 22.47041702], [69.06291962, 22.47069359], [69.06346893, 22.47068977], [69.06346893, 22.47153091], [69.06375122, 22.4715271], [69.06375122, 22.47208595], [69.06402588, 22.47208023], [69.06402588, 22.47264099], [69.06430817, 22.47263908], [69.06430817, 22.47319412], [69.06458282, 22.47319031], [69.06458282, 22.47375107], [69.06485748, 22.47375107], [69.06485748, 22.47402954], [69.06513977, 22.47402954], [69.06513977, 22.47430992], [69.06541443, 22.4743042], [69.06541443, 22.47458267], [69.06568909, 22.47458076], [69.06568909, 22.47486115], [69.06597137, 22.47486115], [69.06597137, 22.47513962], [69.06624603, 22.47513962], [69.06624603, 22.47542953], [69.06652832, 22.47542953], [69.06652832, 22.47624969], [69.06680298, 22.47624969], [69.06680298, 22.47680473], [69.06735992, 22.47680473], [69.06735992, 22.47708321], [69.06624603, 22.47707939], [69.06624603, 22.47763824], [69.06652832, 22.47763824], [69.06652832, 22.47903061], [69.06680298, 22.47903061], [69.06680298, 22.47930908], [69.06708527, 22.47930527], [69.06708527, 22.47958374], [69.06735992, 22.47957993], [69.06735992, 22.48014069], [69.06791687, 22.48014069], [69.06791687, 22.4798584], [69.0687561, 22.4798584], [69.06874847, 22.47930527], [69.06903076, 22.47930908], [69.06903076, 22.47820091], [69.06931305, 22.47820091], [69.06931305, 22.47792053], [69.06958008, 22.47792053], [69.06958008, 22.47763824], [69.06986237, 22.47763824], [69.06986237, 22.47735977], [69.07125092, 22.47735977], [69.07125092, 22.47763824], [69.07182312, 22.47763824], [69.07182312, 22.47792053], [69.07208252, 22.47792053], [69.07208252, 22.47820091], [69.07514191, 22.47819519], [69.07514191, 22.47847176], [69.07707977, 22.47846985], [69.07707977, 22.47874832], [69.07791901, 22.47874832], [69.07791901, 22.47903061], [69.07875061, 22.47903061], [69.07875061, 22.47930908], [69.07930756, 22.47930908], [69.07930756, 22.47903061], [69.07985687, 22.47903061], [69.07985687, 22.47846985], [69.08013916, 22.47847176], [69.08013916, 22.47819519], [69.07985687, 22.47820091], [69.07985687, 22.47792053], [69.08013916, 22.47792053], [69.08013916, 22.47680092], [69.08041382, 22.47680473], [69.08041382, 22.47569466], [69.08097076, 22.47569466], [69.08097076, 22.47541618], [69.08152771, 22.47542953], [69.08152771, 22.47513962], [69.08291626, 22.47513962], [69.08291626, 22.47458076], [69.08319092, 22.47458267], [69.08319092, 22.4743042], [69.08403015, 22.47430992], [69.08403015, 22.47402954], [69.08513641, 22.47402954], [69.08513641, 22.47291946], [69.0854187, 22.47291946], [69.0854187, 22.47236061], [69.08513641, 22.47236061], [69.08513641, 22.47180939], [69.08486176, 22.47180939], [69.08486176, 22.47153091], [69.08347321, 22.47153091], [69.08347321, 22.47125053], [69.08319092, 22.47125053], [69.08319092, 22.47097015], [69.08291626, 22.47097206], [69.08291626, 22.47069359], [69.0826416, 22.47069359], [69.0826416, 22.46986389], [69.08235931, 22.46986389], [69.08235931, 22.46930504], [69.08208466, 22.46930504], [69.08208466, 22.46902847], [69.08097076, 22.46903038], [69.08097076, 22.46875191], [69.08069611, 22.46875191], [69.08069611, 22.46846962], [69.08041382, 22.46846962], [69.08041382, 22.46791649], [69.08013916, 22.4679203], [69.08013916, 22.46764183], [69.07985687, 22.46764183], [69.07985687, 22.46736145], [69.07958221, 22.46736145], [69.07958221, 22.46708107], [69.07930756, 22.46708107], [69.07930756, 22.46680641], [69.0790329, 22.46681023], [69.0790329, 22.46653175], [69.07875061, 22.46653175], [69.07875061, 22.46596909], [69.07847595, 22.4659729], [69.07847595, 22.46569443], [69.07791901, 22.46569443], [69.07791901, 22.46541595], [69.07762909, 22.46541977], [69.07762909, 22.46513748], [69.07736206, 22.46513748], [69.07736206, 22.46486092], [69.07707977, 22.46486092], [69.07707977, 22.46458054], [69.07680511, 22.46458244], [69.07680511, 22.46319389], [69.07653046, 22.46319962], [69.07653046, 22.46264076], [69.07624817, 22.46264076], [69.07624817, 22.46181107], [69.07596588, 22.46181107], [69.07596588, 22.46096992], [69.07569122, 22.46097183], [69.07569122, 22.46013832], [69.07541656, 22.46014023], [69.07541656, 22.4593029], [69.07514191, 22.45930481], [69.07514191, 22.45874977], [69.07485962, 22.45874977], [69.07485962, 22.45792007], [69.07459259, 22.45792007], [69.07459259, 22.45736122], [69.07430267, 22.45736122], [69.07430267, 22.45681], [69.07459259, 22.45681], [69.07459259, 22.45541954], [69.07485962, 22.45541954], [69.07485962, 22.45429993], [69.07458496, 22.45430565], [69.07458496, 22.45402718], [69.07430267, 22.45402908], [69.07430267, 22.45375061], [69.07402802, 22.45375061], [69.07402802, 22.45346832], [69.07375336, 22.45347023], [69.07375336, 22.45264053], [69.07347107, 22.45264053], [69.07347107, 22.45207977], [69.07208252, 22.45208359], [69.07208252, 22.45180511], [69.07182312, 22.45181084], [69.07182312, 22.45153046], [69.0715332, 22.45153046], [69.0715332, 22.45126152], [69.06958008, 22.45126152], [69.06958008, 22.45153046], [69.06903076, 22.45153046], [69.06903076, 22.45181084], [69.06874847, 22.45180511], [69.06874847, 22.45208359], [69.06764221, 22.45208359], [69.06764221, 22.45180511], [69.0670929, 22.45181084], [69.0670929, 22.45153046], [69.06680298, 22.45153046], [69.06680298, 22.45126152], [69.06652832, 22.45126152], [69.06652832, 22.4509697], [69.06625366, 22.4509716], [69.06625366, 22.45069504], [69.06597137, 22.45070076], [69.06597137, 22.45013809], [69.06539917, 22.45013809], [69.06539917, 22.44985962], [69.06430817, 22.44986153], [69.06430817, 22.44958305], [69.06402588, 22.44958305], [69.06402588, 22.44930649], [69.06346893, 22.4493103], [69.06346893, 22.44902992], [69.06318665, 22.44902992], [69.06318665, 22.44874954], [69.06291962, 22.44874954], [69.06291962, 22.44847107], [69.06236267, 22.44847298], [69.06236267, 22.4481945], [69.06208038, 22.44820023], [69.06208038, 22.44791985], [69.06181335, 22.44791985], [69.06181335, 22.44763947], [69.06153107, 22.44763947], [69.06153107, 22.44708061], [69.06124878, 22.44708252], [69.06124878, 22.44652748], [69.06069183, 22.44652939], [69.06069183, 22.44597054], [69.06014252, 22.44597244], [69.06014252, 22.44569588], [69.05958557, 22.44569588], [69.05958557, 22.4454174], [69.05930328, 22.44542122], [69.05930328, 22.44512939], [69.05874634, 22.44513893], [69.05874634, 22.44486046], [69.05819702, 22.44486046], [69.05819702, 22.44458008], [69.05791473, 22.44458389], [69.05791473, 22.44430542], [69.05735779, 22.44431114], [69.05735779, 22.44403076], [69.05708313, 22.44403076], [69.05708313, 22.44375038], [69.05680847, 22.44375038], [69.05680847, 22.44347382], [69.05652618, 22.44347382], [69.05652618, 22.44319534], [69.05596924, 22.44320107], [69.05596924, 22.44292068], [69.05568695, 22.44292068], [69.05568695, 22.4426403], [69.05541992, 22.4426403], [69.05541992, 22.44236183], [69.05486298, 22.44236183], [69.05486298, 22.44208336], [69.05458069, 22.44208336], [69.05458069, 22.44180489], [69.05430603, 22.44180489], [69.05430603, 22.44152832], [69.05403137, 22.44153023], [69.05403137, 22.44125175], [69.05345917, 22.44125175], [69.05345917, 22.44096947], [69.05319214, 22.44096947], [69.05319214, 22.44069481], [69.05291748, 22.44069481], [69.05291748, 22.44041634], [69.05264282, 22.44042015], [69.05264282, 22.44014168], [69.05208588, 22.44014168], [69.05208588, 22.43985939], [69.05180359, 22.43985939], [69.05180359, 22.43958282], [69.05152893, 22.43958282], [69.05152893, 22.43902969], [69.05124664, 22.43902969], [69.05124664, 22.43875122], [69.05097198, 22.43875122], [69.05097198, 22.43819046], [69.05069733, 22.43819427], [69.05069733, 22.43763733], [69.05042267, 22.43764114], [69.05042267, 22.43736076], [69.05014038, 22.43736076], [69.05014038, 22.43680954], [69.04652405, 22.43680573], [69.04652405, 22.4370842], [69.04597473, 22.4370842], [69.04597473, 22.43680573], [69.04514313, 22.43680954], [69.04514313, 22.43653107], [69.04486084, 22.43653107], [69.04486084, 22.43597031], [69.04458618, 22.43597221], [69.04458618, 22.43569374], [69.04430389, 22.43569374], [69.04430389, 22.43541527], [69.04402924, 22.43542099], [69.04402924, 22.43457985], [69.04374695, 22.43458366], [69.04374695, 22.43263817], [69.04402924, 22.43264008], [69.04402924, 22.43213272], [69.04402924, 22.43124962], [69.04429626, 22.43124962], [69.04429626, 22.43041992], [69.04458618, 22.43041992], [69.04458618, 22.42986107], [69.04486084, 22.42986107], [69.04486084, 22.42930984], [69.04514313, 22.42930984], [69.04514313, 22.4287529], [69.04541779, 22.4287529], [69.04541779, 22.42819023], [69.04569244, 22.42819405], [69.04569244, 22.42764091], [69.0459671, 22.42764282], [69.0459671, 22.42708969], [69.04624939, 22.42708969], [69.04624939, 22.42653084], [69.04651642, 22.42653084], [69.04651642, 22.42596817], [69.04680634, 22.42597008], [69.04680634, 22.42541885], [69.04708099, 22.42542076], [69.04708099, 22.42485809], [69.04736328, 22.42486191], [69.04736328, 22.42430496], [69.0476532, 22.42432022], [69.0476532, 22.4240303], [69.04792023, 22.4240303], [69.04792023, 22.42346954], [69.04819489, 22.42347145], [69.04819489, 22.42291641], [69.04846954, 22.42292023], [69.04846954, 22.42263985], [69.04875183, 22.42263985], [69.04875183, 22.42208099], [69.04902649, 22.4220829], [69.04902649, 22.42180634], [69.04930878, 22.42181015], [69.04930878, 22.42124939], [69.04957581, 22.42124939], [69.04957581, 22.42095947], [69.04985809, 22.42097282], [69.04985809, 22.42041588], [69.05014038, 22.42041969], [69.05014038, 22.41986084], [69.05042267, 22.41986084], [69.05041504, 22.4193058], [69.0506897, 22.41930962], [69.0506897, 22.41875076], [69.05097198, 22.41875076], [69.05097198, 22.41847038], [69.05124664, 22.41847229], [69.05124664, 22.41791725], [69.05152893, 22.41792107], [69.05152893, 22.41736031], [69.05179596, 22.41736031], [69.05179596, 22.4168129], [69.05208588, 22.4168129], [69.05208588, 22.41625023], [69.05236053, 22.41625023], [69.05236053, 22.41570282], [69.05264282, 22.41570282], [69.05264282, 22.41486168], [69.05291748, 22.41486168], [69.05291748, 22.41430473], [69.05319214, 22.41430473], [69.05319214, 22.4137516], [69.05345917, 22.4137516], [69.05345917, 22.41319084], [69.05374908, 22.41319466], [69.05374908, 22.41263771], [69.05403137, 22.41263771], [69.05403137, 22.41235924], [69.05430603, 22.41235924], [69.05430603, 22.41180992], [69.05458069, 22.41180992], [69.05458069, 22.41124916], [69.05486298, 22.41124916], [69.05486298, 22.41069031], [69.05513763, 22.41069412], [69.05513763, 22.41041946], [69.05541992, 22.41041946], [69.05541992, 22.41014099], [69.05596924, 22.41014099], [69.05596924, 22.40986061], [69.05625153, 22.40986061], [69.05625153, 22.40958023], [69.05680847, 22.40958405], [69.05680847, 22.40930557], [69.05708313, 22.40930939], [69.05708313, 22.40901947], [69.05847168, 22.40902519], [69.05847168, 22.40875053], [69.05930328, 22.40875053], [69.05930328, 22.40847015], [69.05986023, 22.40847206], [69.05986023, 22.40819359], [69.06014252, 22.40819359], [69.06014252, 22.40791512], [69.06041718, 22.40792084], [69.06041718, 22.40764046], [69.06069183, 22.40764046], [69.06069183, 22.40736008], [69.06124878, 22.40736198], [69.06124878, 22.40652847], [69.06153107, 22.40653038], [69.06153107, 22.40513992], [69.06181335, 22.40513992], [69.06181335, 22.40402985], [69.06208038, 22.40402985], [69.06208038, 22.40208244], [69.06263733, 22.40208244], [69.06263733, 22.40180588], [69.06291962, 22.40180969], [69.06291962, 22.40153122], [69.06318665, 22.40153122], [69.06318665, 22.40125275], [69.06346893, 22.40125275], [69.06346893, 22.40097237], [69.06375122, 22.40097237], [69.06375122, 22.40069389], [69.06402588, 22.40069389], [69.06402588, 22.40041733], [69.06430817, 22.40041924], [69.06430817, 22.4001503], [69.06458282, 22.4001503], [69.06458282, 22.39985847], [69.06485748, 22.39985847], [69.06485748, 22.39957809], [69.06513977, 22.39958382], [69.06513977, 22.39930534], [69.06539917, 22.39930916], [69.06539917, 22.39903069], [69.06597137, 22.39903069], [69.06597137, 22.3987484], [69.06623077, 22.3987484], [69.06624603, 22.39846992], [69.06652832, 22.39847183], [69.06652832, 22.39819527], [69.06680298, 22.39819908], [69.06680298, 22.39792061], [69.0670929, 22.39792061], [69.0670929, 22.39763832], [69.06735992, 22.39763832], [69.06735992, 22.39735985], [69.06764221, 22.39736176], [69.06764221, 22.39708328], [69.06791687, 22.39708328], [69.06791687, 22.39680481], [69.06819153, 22.39680481], [69.06819153, 22.39652634], [69.06846619, 22.39653015], [69.06846619, 22.39624977], [69.0687561, 22.39624977], [69.06874847, 22.3959713], [69.06930542, 22.3959713], [69.06930542, 22.39569473], [69.07013702, 22.39569473], [69.07013702, 22.39541626], [69.07068634, 22.39542007], [69.07068634, 22.39513969], [69.07115173, 22.39513969], [69.07125092, 22.39513969], [69.07125092, 22.39486122], [69.07208252, 22.39486122], [69.07208252, 22.39458084], [69.07263947, 22.39458275], [69.07263947, 22.39430428], [69.07319641, 22.39431], [69.07319641, 22.39402008], [69.07402802, 22.39402771], [69.07402802, 22.39374924], [69.07459259, 22.39375114], [69.07459259, 22.39347076], [69.07597351, 22.39347267], [69.07597351, 22.3931942], [69.07736206, 22.3931942], [69.07736206, 22.39291573], [69.07847595, 22.39291954], [69.07847595, 22.39264107], [69.07985687, 22.39264107], [69.07985687, 22.39236069], [69.0826416, 22.39236069], [69.0826416, 22.39264107], [69.08376312, 22.39264107], [69.08376312, 22.39291954], [69.08486176, 22.39291573], [69.08486176, 22.3931942], [69.08597565, 22.3931942], [69.08597565, 22.39347267], [69.08682251, 22.39347076], [69.08682251, 22.39375114], [69.08791351, 22.39374924], [69.08791351, 22.39402771], [69.08875275, 22.39402008], [69.08875275, 22.39431], [69.08956909, 22.39431], [69.08956909, 22.39402008], [69.08985901, 22.39402008], [69.08985901, 22.39431], [69.09041595, 22.39430428], [69.09041595, 22.39458275], [69.09152985, 22.39458084], [69.09152985, 22.39486122], [69.09179688, 22.39486122], [69.09179688, 22.39513969], [69.09236145, 22.39513969], [69.09236145, 22.39542007], [69.0929184, 22.39541626], [69.0929184, 22.39569473], [69.09347534, 22.39569473], [69.09347534, 22.3959713], [69.09375, 22.39596939], [69.09375, 22.39653015], [69.09402466, 22.39652634], [69.09402466, 22.39708328], [69.09430695, 22.39708328], [69.09430695, 22.39736176], [69.09485626, 22.39735985], [69.09485626, 22.39763832], [69.09541321, 22.39763832], [69.09541321, 22.39792061], [69.0973587, 22.39792061], [69.0973587, 22.39819908], [69.09764099, 22.39819527], [69.09764099, 22.39847183], [69.09819794, 22.39846992], [69.09819794, 22.3987484], [69.0984726, 22.3987484], [69.0984726, 22.39903069], [69.09874725, 22.39902687], [69.09874725, 22.39958382], [69.09902954, 22.39957809], [69.09902954, 22.40041924], [69.0993042, 22.40041733], [69.0993042, 22.40097237], [69.09958649, 22.40097237], [69.09958649, 22.40208244], [69.09929657, 22.40208244], [69.09929657, 22.40291977], [69.09874725, 22.40291595], [69.09874725, 22.40319443], [69.0984726, 22.40319061], [69.0984726, 22.40374947], [69.09819794, 22.40374947], [69.09819794, 22.40431023], [69.0984726, 22.40431023], [69.0984726, 22.40513992], [69.09874725, 22.40513802], [69.09874725, 22.40819359], [69.0993042, 22.40819359], [69.0993042, 22.40847206], [69.09958649, 22.40847015], [69.09958649, 22.40875053], [69.1001358, 22.40875053], [69.1001358, 22.40902519], [69.10069275, 22.40901947], [69.10069275, 22.40930939], [69.10152435, 22.40930557], [69.10152435, 22.40958405], [69.1020813, 22.40958023], [69.1020813, 22.40986061], [69.10263824, 22.40986061], [69.10263824, 22.41014099], [69.1029129, 22.41014099], [69.1029129, 22.40986061], [69.10320282, 22.40986061], [69.10319519, 22.40958405], [69.10375214, 22.40958405], [69.10375214, 22.40930557], [69.10597229, 22.40930557], [69.10597229, 22.40958405], [69.10652924, 22.40958023], [69.10652924, 22.40986061], [69.10762024, 22.40986061], [69.10958099, 22.40986061], [69.10958099, 22.41014099], [69.10986328, 22.41014099], [69.10986328, 22.40986061], [69.11013794, 22.40986061], [69.11013794, 22.40958023], [69.11069489, 22.40958405], [69.11069489, 22.40930557], [69.11152649, 22.40930939], [69.11152649, 22.40901947], [69.11180878, 22.40902519], [69.11180878, 22.40875053], [69.11207581, 22.40875053], [69.11208344, 22.4072628], [69.11208344, 22.40708351], [69.11235809, 22.40708351], [69.11235809, 22.40652847], [69.11264038, 22.40653038], [69.11264038, 22.40625], [69.11292267, 22.40625], [69.11291504, 22.40597153], [69.11319733, 22.40597153], [69.11319733, 22.40569305], [69.11347198, 22.40570068], [69.11347198, 22.4054203], [69.11373901, 22.4054203], [69.11373901, 22.40513992], [69.11402893, 22.40513992], [69.11402893, 22.40485954], [69.11541748, 22.40485954], [69.11541748, 22.40513992], [69.11708069, 22.40513992], [69.11708069, 22.40485954], [69.11875153, 22.40486145], [69.11875153, 22.40458488], [69.11930847, 22.40458488], [69.11930847, 22.40430641], [69.11958313, 22.40431023], [69.11958313, 22.40402985], [69.11987305, 22.40402985], [69.11987305, 22.40374947], [69.12014008, 22.40374947], [69.12014008, 22.4034729], [69.12041473, 22.4034729], [69.12041473, 22.40319443], [69.12069702, 22.40319443], [69.12069702, 22.40291595], [69.12097168, 22.40291977], [69.12097168, 22.40263939], [69.12124634, 22.40263939], [69.12124634, 22.40208244], [69.12152863, 22.40208244], [69.12152863, 22.40180588], [69.12180328, 22.40180969], [69.12180328, 22.40153122], [69.12236023, 22.40153122], [69.12236023, 22.40125275], [69.12293243, 22.40125275], [69.12291718, 22.40097237], [69.12319183, 22.40097237], [69.12319183, 22.40069389], [69.12347412, 22.40069389], [69.12347412, 22.40041733], [69.12374878, 22.40041924], [69.12374878, 22.4001503], [69.12403107, 22.4001503], [69.12403107, 22.39985847], [69.12541962, 22.39985847], [69.12541962, 22.39957809], [69.12625122, 22.39958382], [69.12625122, 22.39930534], [69.12680817, 22.39930916], [69.12680817, 22.39903069], [69.12708282, 22.39903069], [69.12708282, 22.3987484], [69.12735748, 22.3987484], [69.12735748, 22.39846992], [69.12763977, 22.39847183], [69.12763977, 22.39819527], [69.12847137, 22.39819908], [69.12847137, 22.39792061], [69.12902832, 22.39792061], [69.12902832, 22.39819908], [69.12930298, 22.39819527], [69.12930298, 22.39847183], [69.1295929, 22.39846992], [69.1295929, 22.40041924], [69.12985992, 22.40041733], [69.12985992, 22.40069389], [69.13014221, 22.40069389], [69.13014221, 22.40097237], [69.13041687, 22.40097237], [69.13041687, 22.40153122], [69.13069153, 22.40153122], [69.13069153, 22.40291977], [69.13263702, 22.40291595], [69.13263702, 22.40319443], [69.13291931, 22.40319443], [69.13291931, 22.40291595], [69.13318634, 22.40291977], [69.13318634, 22.40236282], [69.13346863, 22.40236282], [69.13346863, 22.40208244], [69.13486481, 22.40208244], [69.13486481, 22.40236282], [69.13569641, 22.40236282], [69.13569641, 22.40263939], [69.13597107, 22.40263939], [69.13597107, 22.40291977], [69.13625336, 22.40291595], [69.13625336, 22.40319443], [69.13652802, 22.40319443], [69.13652802, 22.4034729], [69.13680267, 22.4034729], [69.13680267, 22.40374947], [69.13986206, 22.40374947], [69.13986206, 22.4034729], [69.1423645, 22.4034729], [69.1423645, 22.40319443], [69.14430237, 22.40319443], [69.14430237, 22.40291595], [69.14653015, 22.40291977], [69.14653015, 22.40263939], [69.14848328, 22.40263939], [69.14848328, 22.40291977], [69.14875031, 22.40291595], [69.14875031, 22.4034729], [69.14902496, 22.4034729], [69.14902496, 22.40374947], [69.14930725, 22.40374947], [69.14930725, 22.40402985], [69.14984894, 22.40402985], [69.14984894, 22.40431023], [69.15013885, 22.40430641], [69.15013885, 22.40458488], [69.1506958, 22.40458488], [69.1506958, 22.40486145], [69.15125275, 22.40485954], [69.15125275, 22.40513992], [69.1515274, 22.40513992], [69.1515274, 22.40570068], [69.15208435, 22.40569305], [69.15208435, 22.40597153], [69.15235901, 22.40596008], [69.15235901, 22.40625], [69.1526413, 22.40625], [69.1526413, 22.40653038], [69.15290833, 22.40653038], [69.15290833, 22.40681076], [69.1534729, 22.40680695], [69.1534729, 22.40708351], [69.15374756, 22.40708351], [69.15374756, 22.40736198], [69.15402985, 22.40736008], [69.15402985, 22.40764046], [69.1543045, 22.40763855], [69.1543045, 22.40819359], [69.15458679, 22.40819359], [69.15458679, 22.40847206], [69.15486145, 22.40847015], [69.15486145, 22.40875053], [69.15513611, 22.40875053], [69.15513611, 22.40930939], [69.1554184, 22.40930557], [69.1554184, 22.4109726], [69.15569305, 22.41097069], [69.15569305, 22.41180992], [69.15598297, 22.41180992], [69.15598297, 22.41208839], [69.15680695, 22.41208839], [69.15680695, 22.41235924], [69.15735626, 22.41235924], [69.15735626, 22.41263771], [69.15875244, 22.41263771], [69.15875244, 22.41319466], [69.15930176, 22.41319466], [69.15930939, 22.41347313], [69.15957642, 22.41346931], [69.15957642, 22.4137516], [69.16014099, 22.4137516], [69.16014099, 22.41403008], [69.16041565, 22.41402817], [69.16041565, 22.41430473], [69.1609726, 22.41430473], [69.1609726, 22.41458321], [69.16152954, 22.41458321], [69.16152954, 22.41486168], [69.16207886, 22.41486168], [69.16207886, 22.41514969], [69.16236115, 22.41514969], [69.16236115, 22.41486168], [69.1626358, 22.41486168], [69.1626358, 22.41458321], [69.16319275, 22.41458321], [69.16319275, 22.41430473], [69.16374969, 22.41430473], [69.16374969, 22.41402817], [69.16401672, 22.41403008], [69.16401672, 22.4137516], [69.1645813, 22.4137516], [69.1645813, 22.41346931], [69.16486359, 22.41347313], [69.16486359, 22.41319466], [69.16513824, 22.41319466], [69.16513824, 22.41291618], [69.1654129, 22.41292191], [69.1654129, 22.41263771], [69.16625214, 22.41263771], [69.16625214, 22.41292191], [69.16652679, 22.41292191], [69.16652679, 22.4137516], [69.16680908, 22.4137516], [69.16680908, 22.41403008], [69.16791534, 22.41402817], [69.16791534, 22.41430473], [69.16986084, 22.41430473], [69.16986084, 22.41597366], [69.17041779, 22.41597176], [69.17041779, 22.41625023], [69.17069244, 22.41625023], [69.17069244, 22.41653061], [69.17098236, 22.41653061], [69.17098236, 22.4168129], [69.17236328, 22.41680527], [69.17236328, 22.41708374], [69.17263794, 22.41708183], [69.17263794, 22.41736031], [69.17292023, 22.41736031], [69.17292023, 22.41792107], [69.17319489, 22.41791725], [69.17319489, 22.41819382], [69.17292023, 22.41819382], [69.17292023, 22.41847229], [69.17152405, 22.41847229], [69.17152405, 22.41958427], [69.17124939, 22.41958046], [69.17124939, 22.41986084], [69.16929626, 22.41986084], [69.16929626, 22.42014122], [69.16986084, 22.42014122], [69.16986084, 22.42041969], [69.1701355, 22.42041588], [69.1701355, 22.42097282], [69.17041779, 22.42095947], [69.17041779, 22.42181015], [69.17069244, 22.42180634], [69.17069244, 22.4220829], [69.17208099, 22.4220829], [69.17208099, 22.42180634], [69.17292023, 22.42180634], [69.17292023, 22.4220829], [69.17319489, 22.4220829], [69.17319489, 22.42180634], [69.17346954, 22.42180634], [69.17346954, 22.4220829], [69.17375183, 22.42208099], [69.17375183, 22.42263985], [69.17401886, 22.42263985], [69.17401886, 22.42292023], [69.17458344, 22.42291641], [69.17458344, 22.42319489], [69.17514038, 22.42319489], [69.17514038, 22.42347145], [69.17541504, 22.42347145], [69.17541504, 22.42374992], [69.17569733, 22.42374992], [69.17569733, 22.42432022], [69.17678833, 22.42432022], [69.17678833, 22.4240303], [69.17707825, 22.4240303], [69.17707825, 22.42374992], [69.17736053, 22.42374992], [69.17736053, 22.42346954], [69.17763519, 22.42347145], [69.17763519, 22.42236137], [69.17791748, 22.42236137], [69.17791748, 22.4220829], [69.17847443, 22.4220829], [69.17847443, 22.42180634], [69.17958069, 22.42181015], [69.17958069, 22.42152977], [69.18208313, 22.42152977], [69.18208313, 22.42124939], [69.18292236, 22.42124939], [69.18291473, 22.42097282], [69.18653107, 22.42095947], [69.18653107, 22.42124939], [69.18681335, 22.42124939], [69.18681335, 22.42152977], [69.18875122, 22.42152977], [69.18875122, 22.42181015], [69.19013977, 22.42180634], [69.19013977, 22.4220829], [69.19125366, 22.4220829], [69.19125366, 22.42236137], [69.19152832, 22.42235947], [69.19152832, 22.42263985], [69.19207764, 22.42263985], [69.19207764, 22.42292023], [69.19235992, 22.42291641], [69.19235992, 22.42319489], [69.19291687, 22.42319489], [69.19291687, 22.42347145], [69.19346619, 22.42346954], [69.19346619, 22.42374992], [69.19403076, 22.42374992], [69.19403076, 22.42319107], [69.19430542, 22.42319489], [69.19430542, 22.42152786], [69.19458008, 22.42152977], [69.19458008, 22.42124939], [69.19515228, 22.42124939], [69.19513702, 22.42069435], [69.19486237, 22.42069435], [69.19486237, 22.42041588], [69.19431305, 22.42041969], [69.19431305, 22.42014122], [69.19403076, 22.42014122], [69.19403076, 22.41958046], [69.19374847, 22.41958427], [69.19374847, 22.41875076], [69.19346619, 22.41875076], [69.19346619, 22.41847038], [69.19319153, 22.41847229], [69.19319153, 22.41819382], [69.19291687, 22.41819382], [69.19291687, 22.41736031], [69.19264221, 22.41736031], [69.19264221, 22.41625023], [69.19235992, 22.41625023], [69.19235992, 22.4137516], [69.19264221, 22.4137516], [69.19264221, 22.41235924], [69.19291687, 22.41235924], [69.19291687, 22.41097069], [69.19319153, 22.4109726], [69.19319153, 22.40986061], [69.19346619, 22.40986061], [69.19346619, 22.40875053], [69.19374847, 22.40875053], [69.19374847, 22.40818977], [69.19403076, 22.40819359], [69.19403076, 22.40763855], [69.19431305, 22.40764046], [69.19431305, 22.4070797], [69.19458008, 22.40708351], [69.19458008, 22.40680695], [69.19486237, 22.40681076], [69.19486237, 22.40625], [69.19515228, 22.40625], [69.19513702, 22.40597153], [69.19541931, 22.40597153], [69.19541931, 22.40541649], [69.19568634, 22.4054203], [69.19568634, 22.40485954], [69.19596863, 22.40486145], [69.19596863, 22.40458488], [69.19612122, 22.40458488], [69.19652557, 22.40458488], [69.19652557, 22.40430641], [69.19708252, 22.40431023], [69.19708252, 22.40402985], [69.19789886, 22.40402985], [69.19789886, 22.40374947], [69.19847107, 22.40374947], [69.19847107, 22.4034729], [69.19902802, 22.4034729], [69.19902802, 22.40319443], [69.19985962, 22.40319443], [69.19985962, 22.4034729], [69.20014191, 22.4034729], [69.20014191, 22.40458488], [69.20069122, 22.40458488], [69.20069122, 22.40430641], [69.20347595, 22.40431023], [69.20347595, 22.40402985], [69.20318604, 22.40402985], [69.20318604, 22.40374947], [69.20347595, 22.40374947], [69.20347595, 22.4034729], [69.20375061, 22.4034729], [69.20375061, 22.40319443], [69.20402527, 22.40319443], [69.20402527, 22.40308952], [69.20402527, 22.40291595], [69.20430756, 22.40291977], [69.20430756, 22.40180969], [69.20281219, 22.40180588], [69.20236206, 22.40180969], [69.20236206, 22.40153122], [69.20207977, 22.40153122], [69.20207977, 22.40125275], [69.20153046, 22.40125275], [69.20153046, 22.40097237], [69.20069122, 22.40097237], [69.20069122, 22.40069389], [69.19958496, 22.40069389], [69.19958496, 22.40014076], [69.19930267, 22.4001503], [69.19930267, 22.39957809], [69.19902802, 22.39958382], [69.19902802, 22.39902687], [69.19875336, 22.39903069], [69.19875336, 22.3987484], [69.19847107, 22.3987484], [69.19847107, 22.39819908], [69.19821167, 22.39819908], [69.19820404, 22.39792061], [69.19819641, 22.39763641], [69.19789886, 22.39763832], [69.19789886, 22.39747047], [69.19791412, 22.39652634], [69.19821167, 22.39653015], [69.19821167, 22.39596939], [69.19875336, 22.3959713], [69.19875336, 22.39486122], [69.19847107, 22.39486122], [69.19847107, 22.39458084], [69.19791412, 22.39458275], [69.19791412, 22.39402771], [69.19819641, 22.39402771], [69.19819641, 22.39374924], [69.19930267, 22.39375114], [69.19930267, 22.39347076], [69.19985962, 22.39347267], [69.19985962, 22.39236069], [69.20014191, 22.39236069], [69.20014191, 22.39180946], [69.20041656, 22.39180946], [69.20041656, 22.39068985], [69.20014191, 22.39069366], [69.20014191, 22.3904171], [69.19958496, 22.3904171], [69.19958496, 22.39069366], [69.19819641, 22.39069366], [69.19819641, 22.3904171], [69.19789886, 22.39042091], [69.19789886, 22.38957977], [69.19819641, 22.38958359], [69.19819641, 22.3884716], [69.19847107, 22.3884716], [69.19847107, 22.38791656], [69.19821167, 22.38792038], [69.19821167, 22.38764191], [69.19735718, 22.38764191], [69.19735718, 22.38736153], [69.19596863, 22.38736153], [69.19596863, 22.38708305], [69.19486237, 22.38708305], [69.19486237, 22.38680649], [69.19180298, 22.3868103], [69.19180298, 22.38653183], [69.19069672, 22.38653183], [69.19069672, 22.38625145], [69.18930817, 22.38625145], [69.18930817, 22.38596916], [69.18819427, 22.38597298], [69.18819427, 22.38541603], [69.18791962, 22.38541985], [69.18791962, 22.38513756], [69.18763733, 22.38513756], [69.18763733, 22.38485909], [69.18708038, 22.38485909], [69.18708038, 22.38458061], [69.18680573, 22.38458252], [69.18680573, 22.38430786], [69.18653107, 22.38430977], [69.18653107, 22.38402748], [69.18595886, 22.38402748], [69.18595886, 22.38375092], [69.18569183, 22.38375092], [69.18569183, 22.38347054], [69.18514252, 22.38347244], [69.18514252, 22.38319397], [69.18486023, 22.38319397], [69.18486023, 22.3829155], [69.1845932, 22.38292122], [69.1845932, 22.38264084], [69.18402863, 22.38264084], [69.18402863, 22.38236046], [69.18374634, 22.38236046], [69.18374634, 22.38181114], [69.18347168, 22.38181114], [69.18347168, 22.38153076], [69.18321228, 22.38153076], [69.18321228, 22.38097], [69.18291473, 22.38097191], [69.18291473, 22.38069534], [69.18264008, 22.38070107], [69.18264008, 22.3801403], [69.18235779, 22.3801403], [69.18235779, 22.37957954], [69.18208313, 22.37958336], [69.18208313, 22.37930489], [69.18180847, 22.37930489], [69.18180847, 22.37874985], [69.18152618, 22.37874985], [69.18152618, 22.37846947], [69.18041992, 22.37847137], [69.18041992, 22.37819481], [69.17958069, 22.37819481], [69.17958069, 22.37791634], [69.17874908, 22.37792015], [69.17874908, 22.37598038], [69.17903137, 22.37598038], [69.17903137, 22.37569046], [69.17930603, 22.37569427], [69.17930603, 22.3754158], [69.17986298, 22.37541962], [69.17986298, 22.37514114], [69.18013763, 22.37514114], [69.18013763, 22.37486267], [69.18180847, 22.37486267], [69.18180847, 22.37514114], [69.18208313, 22.37514114], [69.18208313, 22.37541962], [69.18235779, 22.37541962], [69.18235779, 22.37625122], [69.18292236, 22.37625122], [69.18292236, 22.37430954], [69.18321228, 22.37430954], [69.18321228, 22.37291908], [69.18292236, 22.37291908], [69.18292236, 22.37181091], [69.18264008, 22.37181091], [69.18264008, 22.37124825], [69.18235779, 22.37124825], [69.18235779, 22.37070084], [69.18180847, 22.37070084], [69.18180847, 22.37042046], [69.18125153, 22.37042046], [69.18125153, 22.36958122], [69.18096924, 22.36958313], [69.18096924, 22.36930466], [69.18069458, 22.36930466], [69.18069458, 22.36847305], [69.18041992, 22.36847305], [69.18041992, 22.36680412], [69.17986298, 22.36680412], [69.17986298, 22.3670826], [69.17930603, 22.36708069], [69.17930603, 22.36736107], [69.17874908, 22.36736107], [69.17874908, 22.36763954], [69.1784668, 22.36763954], [69.1784668, 22.36791992], [69.17736053, 22.36791992], [69.17736053, 22.36763954], [69.17707825, 22.36763954], [69.17707825, 22.36597061], [69.17680359, 22.36597252], [69.17680359, 22.36569595], [69.17624664, 22.36569595], [69.17624664, 22.36541748], [69.17652893, 22.36541939], [69.17652893, 22.36431122], [69.17624664, 22.36431122], [69.17624664, 22.36404037], [69.17569733, 22.36404037], [69.17569733, 22.36375046], [69.17485809, 22.36375046], [69.17485809, 22.36347008], [69.17402649, 22.36347389], [69.17402649, 22.36291695], [69.17375183, 22.36292076], [69.17375183, 22.36264038], [69.17346954, 22.36264038], [69.17346954, 22.36207962], [69.17375183, 22.36208344], [69.17375183, 22.36180496], [69.17430878, 22.36181068], [69.17430878, 22.36068916], [69.17402649, 22.36069489], [69.17402649, 22.3595829], [69.17292023, 22.3595829], [69.17292023, 22.35902977], [69.17263794, 22.35902977], [69.17263794, 22.35764122], [69.17292023, 22.35764122], [69.17292023, 22.35736084], [69.17318726, 22.35736084], [69.17318726, 22.35680962], [69.17375183, 22.35680962], [69.17375183, 22.35653114], [69.17401886, 22.35653114], [69.17401886, 22.35625076], [69.17485809, 22.35625076], [69.17485809, 22.35597038], [69.17569733, 22.35597038], [69.17569733, 22.35625076], [69.17652893, 22.35625076], [69.17652893, 22.35653114], [69.17764282, 22.35653114], [69.17764282, 22.35625076], [69.17791748, 22.35625076], [69.17791748, 22.35597038], [69.17763519, 22.35597229], [69.17763519, 22.35513878], [69.17736053, 22.35514069], [69.17736053, 22.35485077], [69.17708588, 22.35486031], [69.17708588, 22.35458374], [69.17680359, 22.35458374], [69.17680359, 22.3540287], [69.17652893, 22.35403061], [69.17652893, 22.35375023], [69.17624664, 22.35375023], [69.17624664, 22.35346985], [69.17597198, 22.35347176], [69.17597198, 22.35319328], [69.17569733, 22.35320091], [69.17569733, 22.35292053], [69.17514038, 22.35292053], [69.17514038, 22.35264015], [69.17485809, 22.35264015], [69.17485809, 22.35235977], [69.17458344, 22.35236168], [69.17458344, 22.35208321], [69.17430878, 22.35208321], [69.17430878, 22.35152817], [69.17401886, 22.35153008], [69.17401886, 22.35069275], [69.17375183, 22.35069466], [69.17375183, 22.3484726], [69.17402649, 22.3484726], [69.17402649, 22.34819412], [69.17624664, 22.34819412], [69.17624664, 22.34763908], [69.17597198, 22.3476429], [69.17597198, 22.3473587], [69.17569733, 22.3473587], [69.17569733, 22.34680939], [69.17541504, 22.34680557], [69.17541504, 22.34708405], [69.17514038, 22.34708405], [69.17514038, 22.34680557], [69.17457581, 22.34680939], [69.17457581, 22.34653091], [69.17346954, 22.34653091], [69.17346954, 22.34680939], [69.17263794, 22.34680557], [69.17263794, 22.34708405], [69.17180634, 22.34707832], [69.17180634, 22.3476429], [69.17152405, 22.34763908], [69.17152405, 22.34819412], [69.17124939, 22.34819412], [69.17124939, 22.3484726], [69.17041779, 22.3484726], [69.17041779, 22.34819412], [69.1701355, 22.34819412], [69.1701355, 22.34791756], [69.16986084, 22.34791946], [69.16986084, 22.3476429], [69.16958618, 22.3476429], [69.16958618, 22.34707832], [69.16930389, 22.34708405], [69.16930389, 22.34680557], [69.16902924, 22.34680939], [69.16902924, 22.34653091], [69.16874695, 22.34653091], [69.16874695, 22.34568024], [69.16819763, 22.34569359], [69.16819763, 22.34541893], [69.16792297, 22.34542084], [69.16792297, 22.34514046], [69.16764069, 22.34514046], [69.16764069, 22.34485817], [69.16791534, 22.34486198], [69.16791534, 22.34458351], [69.16819763, 22.34458351], [69.16819763, 22.34430504], [69.16847229, 22.34431076], [69.16847229, 22.34403038], [69.16874695, 22.34403038], [69.16874695, 22.34374809], [69.16902924, 22.34374809], [69.16902924, 22.34291077], [69.16930389, 22.34291649], [69.16930389, 22.34263611], [69.16958618, 22.34263992], [69.16958618, 22.34124947], [69.16929626, 22.34124947], [69.16929626, 22.34069061], [69.16902924, 22.34069443], [69.16902924, 22.33986092], [69.16874695, 22.33987045], [69.16874695, 22.33930969], [69.16847229, 22.33930969], [69.16847229, 22.33792114], [69.16902924, 22.33792114], [69.16902924, 22.33764076], [69.16986084, 22.33764076], [69.16986084, 22.33708191], [69.16958618, 22.33708382], [69.16958618, 22.33541679], [69.16929626, 22.33542061], [69.16929626, 22.33514023], [69.16902924, 22.33514023], [69.16902924, 22.33457947], [69.16874695, 22.33458328], [69.16874695, 22.33402824], [69.16902924, 22.33403015], [69.16902924, 22.3326416], [69.16874695, 22.3326416], [69.16874695, 22.33235931], [69.16847229, 22.33235931], [69.16847229, 22.33125114], [69.16819763, 22.33125114], [69.16819763, 22.33014107], [69.16792297, 22.33014107], [69.16792297, 22.32818985], [69.16819763, 22.32819366], [69.16819763, 22.32652855], [69.16764069, 22.32653046], [69.16764069, 22.32625008], [69.1673584, 22.32625008], [69.1673584, 22.3259697], [69.16680908, 22.3259716], [69.16680908, 22.32569313], [69.16652679, 22.32570076], [69.16652679, 22.32542038], [69.16625214, 22.32542038], [69.16625214, 22.32374954], [69.16596985, 22.32374954], [69.16596985, 22.3231926], [69.1654129, 22.3231945], [69.1654129, 22.32291603], [69.16430664, 22.32291985], [69.16430664, 22.32263947], [69.16401672, 22.32263947], [69.16401672, 22.32208252], [69.16374969, 22.32208252], [69.16374969, 22.32180595], [69.16347504, 22.32180595], [69.16347504, 22.32152748], [69.16319275, 22.32152939], [69.16319275, 22.32125282], [69.1626358, 22.32125282], [69.1626358, 22.32097244], [69.16236115, 22.32097244], [69.16236115, 22.3204174], [69.16207886, 22.32041931], [69.16207886, 22.32014084], [69.16178894, 22.32014084], [69.16178894, 22.31957817], [69.16124725, 22.31958389], [69.16124725, 22.31902885], [69.1609726, 22.31903076], [69.1609726, 22.31874084], [69.16069794, 22.31874847], [69.16069794, 22.31847191], [69.16041565, 22.31847191], [69.16041565, 22.31791878], [69.16014099, 22.31792068], [69.16014099, 22.3176403], [69.15957642, 22.3176403], [69.15957642, 22.31735992], [69.15930176, 22.31736183], [69.15930176, 22.31680489], [69.1590271, 22.31680489], [69.1590271, 22.31652641], [69.15875244, 22.31653023], [69.15875244, 22.31624985], [69.1581955, 22.31624985], [69.1581955, 22.31597137], [69.15791321, 22.31597137], [69.15791321, 22.3129158], [69.15820313, 22.31293106], [69.15820313, 22.31180954], [69.15847015, 22.31180954], [69.15847015, 22.31068993], [69.15875244, 22.31069374], [69.15875244, 22.30986023], [69.15904236, 22.30986023], [69.1590271, 22.30930519], [69.15930176, 22.30931282], [69.15930176, 22.30875015], [69.15957642, 22.30875015], [69.15957642, 22.30820274], [69.1598587, 22.30820274], [69.1598587, 22.30764008], [69.16014099, 22.30764008], [69.16014099, 22.30707932], [69.16041565, 22.30708313], [69.16041565, 22.30652809], [69.16069794, 22.30653191], [69.16069794, 22.30625153], [69.1609726, 22.30625153], [69.1609726, 22.30569077], [69.16124725, 22.30569458], [69.16124725, 22.30541611], [69.16152954, 22.30541992], [69.16152954, 22.30485916], [69.16178894, 22.30485916], [69.16178894, 22.30458069], [69.16208649, 22.3045826], [69.16208649, 22.30402946], [69.16236115, 22.30402946], [69.16236115, 22.30376053], [69.1626358, 22.30376053], [69.1626358, 22.30319023], [69.16291809, 22.30319405], [69.16291809, 22.30291939], [69.16319275, 22.30291939], [69.16319275, 22.30236053], [69.16348267, 22.30236053], [69.16347504, 22.30208397], [69.16374969, 22.30208397], [69.16374969, 22.3018055], [69.16401672, 22.30181122], [69.16401672, 22.30125046], [69.16430664, 22.30125046], [69.16430664, 22.30097008], [69.1645813, 22.30097198], [69.1645813, 22.30041695], [69.16484833, 22.30042076], [69.16484833, 22.30014038], [69.16513824, 22.30014038], [69.16513824, 22.29986], [69.1654129, 22.29986191], [69.1654129, 22.29930305], [69.16570282, 22.29931068], [69.16570282, 22.2990303], [69.16596985, 22.2990303], [69.16596985, 22.29874992], [69.16625214, 22.29874992], [69.16625214, 22.29846954], [69.16652679, 22.29847145], [69.16652679, 22.29819489], [69.16680908, 22.29819489], [69.16680908, 22.29763794], [69.16708374, 22.29763794], [69.16708374, 22.29736137], [69.1673584, 22.29736137], [69.1673584, 22.29708481], [69.16764069, 22.29708481], [69.16764069, 22.29680634], [69.16792297, 22.29681015], [69.16792297, 22.29652977], [69.16819763, 22.29652977], [69.16819763, 22.29597282], [69.16847229, 22.29597282], [69.16847229, 22.29569435], [69.16874695, 22.29569435], [69.16874695, 22.29541588], [69.16902924, 22.29541969], [69.16902924, 22.29514122], [69.16929626, 22.29514122], [69.16929626, 22.29486275], [69.16958618, 22.29486275], [69.16958618, 22.29430962], [69.16986084, 22.29430962], [69.16986084, 22.29403114], [69.17014313, 22.29403114], [69.17014313, 22.29375076], [69.17041779, 22.29375076], [69.17041779, 22.29346848], [69.17069244, 22.29347229], [69.17069244, 22.29319382], [69.17097473, 22.29319382], [69.17097473, 22.29291725], [69.17124939, 22.29291916], [69.17124939, 22.29264069], [69.17180634, 22.29264069], [69.17180634, 22.2923584], [69.17208099, 22.2923584], [69.17208099, 22.29207993], [69.17236328, 22.29208374], [69.17236328, 22.29180527], [69.17263794, 22.29182243], [69.17263794, 22.29153061], [69.17292023, 22.29153061], [69.17292023, 22.29124832], [69.17318726, 22.29124832], [69.17318726, 22.29096985], [69.17346954, 22.29097176], [69.17346954, 22.29069519], [69.17375183, 22.29070091], [69.17375183, 22.29042053], [69.17401886, 22.29042053], [69.17401886, 22.29014015], [69.17430878, 22.29014015], [69.17430878, 22.28985977], [69.17485809, 22.28986168], [69.17485809, 22.28958321], [69.17514038, 22.28958321], [69.17514038, 22.28930473], [69.17541504, 22.28930473], [69.17541504, 22.28902626], [69.17569733, 22.28903008], [69.17569733, 22.28876114], [69.17597198, 22.28876114], [69.17597198, 22.28847122], [69.17624664, 22.28847313], [69.17624664, 22.28819466], [69.17652893, 22.28819466], [69.17652893, 22.28791428], [69.17678833, 22.28792], [69.17678833, 22.28763962], [69.17707825, 22.28763962], [69.17707825, 22.28736115], [69.17736053, 22.28736115], [69.17736053, 22.28708076], [69.17763519, 22.28708267], [69.17763519, 22.2868042], [69.17819214, 22.28680992], [69.17819214, 22.28652954], [69.1784668, 22.28652954], [69.1784668, 22.28625107], [69.17874908, 22.28625107], [69.17874908, 22.28597069], [69.17903137, 22.2859726], [69.17903137, 22.28569412], [69.17930603, 22.28569412], [69.17930603, 22.28541756], [69.17958069, 22.28541946], [69.17958069, 22.28514099], [69.17986298, 22.28514099], [69.17986298, 22.28486061], [69.18013763, 22.28486061], [69.18013763, 22.28458023], [69.18069458, 22.28458214], [69.18069458, 22.28430557], [69.18096924, 22.28430939], [69.18096924, 22.28403091], [69.18125153, 22.28403091], [69.18125153, 22.28375053], [69.18152618, 22.28375053], [69.18152618, 22.28347015], [69.18180847, 22.28347206], [69.18180847, 22.28319359], [69.18208313, 22.28319359], [69.18208313, 22.28291702], [69.18235779, 22.28292084], [69.18235779, 22.28263283], [69.18264008, 22.28263855], [69.18264008, 22.28236389], [69.18319702, 22.28236389], [69.18319702, 22.28208351], [69.18347168, 22.28208351], [69.18347168, 22.28180504], [69.18374634, 22.28181267], [69.18374634, 22.28153038], [69.18402863, 22.28153038], [69.18402863, 22.28125191], [69.18430328, 22.28125191], [69.18430328, 22.28097153], [69.18458557, 22.28097153], [69.18458557, 22.28069496], [69.18474579, 22.28069496], [69.18486023, 22.28070259], [69.18486023, 22.2804203], [69.18514252, 22.2804203], [69.18514252, 22.28014183], [69.18541718, 22.28014183], [69.18541718, 22.27986145], [69.18569183, 22.27986145], [69.18569183, 22.27958298], [69.18595886, 22.27959251], [69.18595886, 22.27931023], [69.18653107, 22.27931023], [69.18653107, 22.27902985], [69.18681335, 22.27902985], [69.18681335, 22.27874756], [69.18763733, 22.27874756], [69.18763733, 22.27846909], [69.18791962, 22.2784729], [69.18791962, 22.27819443], [69.18846893, 22.27819443], [69.18846893, 22.27791595], [69.18875122, 22.27791977], [69.18875122, 22.27763748], [69.18901825, 22.27763748], [69.18901825, 22.27736092], [69.18958282, 22.27736092], [69.18958282, 22.27708054], [69.18985748, 22.27708244], [69.18985748, 22.27680779], [69.19013977, 22.27681923], [69.19013977, 22.27653122], [69.1904068, 22.27653122], [69.1904068, 22.27625084], [69.19069672, 22.27625084], [69.19069672, 22.27597046], [69.19125366, 22.27597237], [69.19125366, 22.27569389], [69.19152832, 22.27569389], [69.19152832, 22.27541542], [69.19180298, 22.27542114], [69.19180298, 22.27514076], [69.19207764, 22.27514076], [69.19207764, 22.27486038], [69.19235992, 22.27486038], [69.19235992, 22.27458], [69.19264221, 22.27458382], [69.19264221, 22.27430534], [69.19291687, 22.27431107], [69.19291687, 22.27403069], [69.19374847, 22.27403069], [69.19374847, 22.27375031], [69.19403076, 22.27375031], [69.19403076, 22.27346992], [69.19430542, 22.27347183], [69.19430542, 22.27319336], [69.19458008, 22.27320099], [69.19458008, 22.27292061], [69.19486237, 22.27292061], [69.19486237, 22.27264023], [69.19515228, 22.27264023], [69.19515228, 22.27235985], [69.19541931, 22.27236176], [69.19541931, 22.27208328], [69.19569397, 22.27208328], [69.19569397, 22.27180481], [69.19596863, 22.27180481], [69.19596863, 22.27152824], [69.19625092, 22.27153015], [69.19625092, 22.27124977], [69.19680786, 22.27124977], [69.19680786, 22.27096939], [69.19736481, 22.2709713], [69.19736481, 22.27069473], [69.19791412, 22.27069473], [69.19791412, 22.27041626], [69.19821167, 22.27042007], [69.19821167, 22.27013969], [69.19875336, 22.27013969], [69.19875336, 22.26986122], [69.19902802, 22.26986122], [69.19902802, 22.26958275], [69.19930267, 22.26958275], [69.19930267, 22.26930618], [69.19959259, 22.26931], [69.19959259, 22.26902962], [69.20014191, 22.26902962], [69.20014191, 22.26875114], [69.20041656, 22.26875114], [69.20041656, 22.26847267], [69.20069122, 22.26847267], [69.20069122, 22.2681942], [69.20097351, 22.2681942], [69.20097351, 22.26791573], [69.20124817, 22.26791954], [69.20124817, 22.2676506], [69.20181274, 22.2676506], [69.20181274, 22.26736259], [69.20207977, 22.26736259], [69.20207977, 22.2670784], [69.20236206, 22.26708412], [69.20236206, 22.26680565], [69.20263672, 22.26680946], [69.20263672, 22.26652908], [69.20318604, 22.26652908], [69.20318604, 22.26625061], [69.2040329, 22.26625061], [69.20402527, 22.26597214], [69.20430756, 22.26597214], [69.20430756, 22.26569366], [69.2048645, 22.26569366], [69.2048645, 22.2654171], [69.20513916, 22.26542091], [69.20513916, 22.26514053], [69.20569611, 22.26514053], [69.20569611, 22.26485825], [69.20597076, 22.26485825], [69.20597076, 22.26458931], [69.20652771, 22.26458931], [69.20652771, 22.26431084], [69.20819092, 22.26431084], [69.20819092, 22.26403046], [69.20874786, 22.26403046], [69.20874786, 22.26374817], [69.20929718, 22.26374817], [69.20929718, 22.2634697], [69.21013641, 22.2634716], [69.21013641, 22.26319695], [69.21069336, 22.26320076], [69.21069336, 22.26292038], [69.21125031, 22.26292038], [69.21125031, 22.26263809], [69.21180725, 22.26263809], [69.21180725, 22.26235962], [69.2123642, 22.26236153], [69.2123642, 22.26208305], [69.21291351, 22.26208305], [69.21291351, 22.2618084], [69.21347046, 22.26180077], [69.21347046, 22.26152611], [69.21430206, 22.26152992], [69.21430206, 22.26124954], [69.21485901, 22.26124954], [69.21485901, 22.26097107], [69.2151413, 22.26097298], [69.2151413, 22.2606945], [69.21624756, 22.2606945], [69.21624756, 22.26041412], [69.21708679, 22.26041985], [69.21708679, 22.26013947], [69.2179184, 22.26013947], [69.2179184, 22.25986099], [69.21875, 22.25986099], [69.21875, 22.25958061], [69.2195816, 22.25958252], [69.2195816, 22.25930405], [69.2201767, 22.25930405], [69.22041321, 22.25930977], [69.22041321, 22.25918007], [69.22041321, 22.25902748], [69.22068787, 22.25902748], [69.2215271, 22.25902939], [69.2215271, 22.25875092], [69.22180176, 22.25875092], [69.22180176, 22.25846291], [69.22264099, 22.25847244], [69.22264099, 22.25819206], [69.2234726, 22.25819206], [69.2234726, 22.2579174], [69.22652435, 22.2579174], [69.22652435, 22.25819206], [69.2279129, 22.25819206], [69.2279129, 22.2579174], [69.23124695, 22.2579174], [69.23124695, 22.25819206], [69.23180389, 22.25819206], [69.23180389, 22.2579174], [69.2326355, 22.2579174], [69.2326355, 22.25819206], [69.23374939, 22.25819206], [69.23374939, 22.25847244], [69.23513794, 22.25846291], [69.23513794, 22.25875092], [69.23652649, 22.25875092], [69.23652649, 22.25902939], [69.23764038, 22.25902939], [69.23764038, 22.25930977], [69.23874664, 22.25930977], [69.23874664, 22.25986099], [69.23902893, 22.25986099], [69.23902893, 22.26013947], [69.23929596, 22.26013947], [69.23929596, 22.26041985], [69.23986053, 22.26041412], [69.23986053, 22.2606945], [69.24013519, 22.2606945], [69.24013519, 22.26097298], [69.24041748, 22.26097107], [69.24041748, 22.26152992], [69.24069214, 22.26152611], [69.24069214, 22.26208305], [69.24124908, 22.26208115], [69.24124908, 22.26263809], [69.24069214, 22.26263809], [69.24069214, 22.26292038], [69.24041748, 22.26292038], [69.24041748, 22.26320076], [69.24069214, 22.26320076], [69.24069214, 22.26374817], [69.24153137, 22.26374817], [69.24153137, 22.26458931], [69.24208069, 22.26458931], [69.24208069, 22.26485825], [69.24320221, 22.26485825], [69.24319458, 22.26458359], [69.2454071, 22.26458931], [69.24541473, 22.26485825], [69.24569702, 22.26485825], [69.24569702, 22.26514053], [69.24652863, 22.26514053], [69.24652863, 22.26431084], [69.24680328, 22.26431084], [69.24680328, 22.26374817], [69.2470932, 22.26374817], [69.24708557, 22.2634716], [69.24736023, 22.2634716], [69.24736023, 22.26319695], [69.24764252, 22.26320076], [69.24764252, 22.26292038], [69.24791718, 22.26292038], [69.24791718, 22.26263809], [69.24819183, 22.26263809], [69.24819183, 22.26235962], [69.24874878, 22.26236153], [69.24874878, 22.26208305], [69.24930573, 22.26208305], [69.24930573, 22.2618084], [69.24958038, 22.26180077], [69.24958038, 22.26152611], [69.24986267, 22.26152992], [69.24986267, 22.26097107], [69.25041962, 22.26097107], [69.25041962, 22.26124954], [69.25069427, 22.26124954], [69.25069427, 22.26208305], [69.25096893, 22.26208115], [69.25096893, 22.26292038], [69.25125122, 22.26292038], [69.25125122, 22.26320076], [69.25152588, 22.26320076], [69.25152588, 22.26403046], [69.25180817, 22.26402664], [69.25180817, 22.26486206], [69.25069427, 22.26486206], [69.25069427, 22.26458359], [69.25013733, 22.26458931], [69.25013733, 22.26431084], [69.24958038, 22.26431084], [69.24958038, 22.26542091], [69.24930573, 22.2654171], [69.24930573, 22.26597214], [69.24903107, 22.26597214], [69.24903107, 22.26708412], [69.24986267, 22.26708412], [69.24986267, 22.26680565], [69.25068665, 22.26680946], [69.25068665, 22.26652908], [69.25152588, 22.26652908], [69.25152588, 22.26680946], [69.25235748, 22.26680565], [69.25235748, 22.26708412], [69.25263977, 22.2670784], [69.25263977, 22.26736259], [69.25319672, 22.26736259], [69.25319672, 22.2676506], [69.25402832, 22.2676506], [69.25402832, 22.26791954], [69.25458527, 22.26791573], [69.25458527, 22.2681942], [69.25541687, 22.2681942], [69.25541687, 22.26847267], [69.25653076, 22.26847267], [69.25653076, 22.26875114], [69.25708008, 22.26875114], [69.25708008, 22.26902962], [69.25791931, 22.26902962], [69.25791931, 22.26875114], [69.2582016, 22.26875114], [69.2582016, 22.26902962], [69.26152802, 22.26902962], [69.26152802, 22.26875114], [69.26319122, 22.26875114], [69.26319122, 22.26902962], [69.26346588, 22.26902962], [69.26346588, 22.26931], [69.26319122, 22.26931], [69.26319122, 22.26986122], [69.26346588, 22.26986122], [69.26346588, 22.27013969], [69.26790619, 22.27013969], [69.26790619, 22.27042007], [69.26902771, 22.27042007], [69.26902771, 22.27013969], [69.26985931, 22.27013969], [69.26985931, 22.27042007], [69.27124786, 22.27041626], [69.27124786, 22.27069473], [69.27236176, 22.27069473], [69.27236176, 22.2709713], [69.27347565, 22.2709713], [69.27347565, 22.27069473], [69.27375031, 22.27069473], [69.27375031, 22.27041626], [69.27403259, 22.27042007], [69.27403259, 22.26902962], [69.27540588, 22.26902962], [69.27540588, 22.26931], [69.2756958, 22.26931], [69.2756958, 22.26986122], [69.27597046, 22.26986122], [69.27597046, 22.27042007], [69.2765274, 22.27041626], [69.2765274, 22.2709713], [69.27707672, 22.27096939], [69.27707672, 22.27124977], [69.27738953, 22.27124977], [69.2776413, 22.27124977], [69.2776413, 22.27153015], [69.27819824, 22.27152824], [69.27819824, 22.27180481], [69.27874756, 22.27180481], [69.27874756, 22.27152824], [69.2793045, 22.27152824], [69.2793045, 22.27180481], [69.28013611, 22.27180481], [69.28013611, 22.27152824], [69.2804184, 22.27153015], [69.2804184, 22.27124977], [69.28125, 22.27124977], [69.28125, 22.27153015], [69.2820816, 22.27152824], [69.2820816, 22.27180481], [69.28291321, 22.27180481], [69.28291321, 22.27208328], [69.28375244, 22.27208328], [69.28375244, 22.27236176], [69.28430176, 22.27235985], [69.28430939, 22.27264023], [69.28457642, 22.27264023], [69.28457642, 22.27292061], [69.2848587, 22.27292061], [69.2848587, 22.27375031], [69.28514099, 22.27375031], [69.28514099, 22.27403069], [69.28679657, 22.27403069], [69.28679657, 22.27431107], [69.28708649, 22.27430534], [69.28708649, 22.27458382], [69.2876358, 22.27458], [69.2876358, 22.27486038], [69.28930664, 22.27486038], [69.28930664, 22.27514076], [69.29013824, 22.27514076], [69.29013824, 22.27542114], [69.2904129, 22.27541542], [69.2904129, 22.27569389], [69.29096985, 22.27569389], [69.29096985, 22.27597237], [69.29125214, 22.27597046], [69.29125214, 22.27625084], [69.29152679, 22.27625084], [69.29152679, 22.27653122], [69.29180908, 22.27653122], [69.29180908, 22.27681923], [69.29207611, 22.27681923], [69.29207611, 22.27736092], [69.2923584, 22.27736092], [69.2923584, 22.27763748], [69.29264069, 22.27763748], [69.29264069, 22.27791977], [69.29319763, 22.27791595], [69.29319763, 22.27819443], [69.29347229, 22.27819443], [69.29347229, 22.2784729], [69.29374695, 22.27846909], [69.29374695, 22.27874756], [69.29402924, 22.27874756], [69.29402924, 22.27902985], [69.29431152, 22.27902985], [69.29431152, 22.27931023], [69.29460144, 22.27931023], [69.29460144, 22.27959251], [69.29486084, 22.27958298], [69.29486084, 22.27986145], [69.29514313, 22.27986145], [69.29514313, 22.28181267], [69.29486084, 22.28180504], [69.29486084, 22.28208351], [69.29458618, 22.28208351], [69.29458618, 22.28236389], [69.29374695, 22.28236389], [69.29374695, 22.28319359], [69.29347229, 22.28318977], [69.29347229, 22.28403091], [69.29319763, 22.2840271], [69.29319763, 22.28458214], [69.29264069, 22.28458023], [69.29264069, 22.28541946], [69.2923584, 22.28541756], [69.2923584, 22.28569412], [69.29208374, 22.28569412], [69.29208374, 22.2859726], [69.2923584, 22.28597069], [69.2923584, 22.28625107], [69.29347229, 22.28625107], [69.29347229, 22.28597069], [69.29486084, 22.2859726], [69.29486084, 22.28569412], [69.2951355, 22.28569412], [69.2951355, 22.28513908], [69.29541779, 22.28514099], [69.29541779, 22.28430939], [69.29514313, 22.28430939], [69.29514313, 22.28375053], [69.29541779, 22.28375053], [69.29541779, 22.28347015], [69.29624939, 22.28347015], [69.29624939, 22.28403091], [69.29680634, 22.2840271], [69.29680634, 22.28458214], [69.29708099, 22.28458214], [69.29708099, 22.28569412], [69.29680634, 22.28569031], [69.29680634, 22.28625107], [69.29708099, 22.28625107], [69.29708099, 22.28652954], [69.29736328, 22.28652763], [69.29736328, 22.28708267], [69.29763794, 22.28708076], [69.29763794, 22.28736115], [69.29792023, 22.28736115], [69.29792023, 22.28763962], [69.29957581, 22.28763962], [69.29957581, 22.28792], [69.30097198, 22.28792], [69.30097198, 22.28763962], [69.3034668, 22.28763962], [69.3034668, 22.28792], [69.30374908, 22.28792], [69.30374908, 22.28763962], [69.30625153, 22.28763962], [69.30625153, 22.28736115], [69.30708313, 22.28736115], [69.30708313, 22.28708076], [69.30791473, 22.28708267], [69.30791473, 22.2868042], [69.30819702, 22.28680992], [69.30819702, 22.28652954], [69.30874634, 22.28652954], [69.30874634, 22.28680992], [69.30930328, 22.2868042], [69.30930328, 22.28708267], [69.31014252, 22.28708076], [69.31014252, 22.28736115], [69.31041718, 22.28736115], [69.31041718, 22.28763962], [69.31153107, 22.28763962], [69.31153107, 22.28736115], [69.31234741, 22.28736115], [69.31234741, 22.28763962], [69.31291962, 22.28763962], [69.31291962, 22.28792], [69.31319427, 22.28791428], [69.31319427, 22.28819466], [69.31375122, 22.28819466], [69.31375122, 22.28986168], [69.31318665, 22.28985977], [69.31318665, 22.29014015], [69.31291962, 22.29014015], [69.31291962, 22.29042053], [69.31263733, 22.29041862], [69.31263733, 22.29097176], [69.31234741, 22.29096985], [69.31234741, 22.29124832], [69.31208038, 22.29124832], [69.31208038, 22.29182243], [69.31375122, 22.29182243], [69.31375122, 22.29153061], [69.31402588, 22.29153061], [69.31402588, 22.29070091], [69.31541443, 22.29069519], [69.31541443, 22.29097176], [69.31652832, 22.29097176], [69.31652832, 22.29069519], [69.31847382, 22.29069519], [69.31847382, 22.29097176], [69.31874847, 22.29096985], [69.31874847, 22.29124832], [69.31986237, 22.29124832], [69.31986237, 22.29153061], [69.32013702, 22.29153061], [69.32013702, 22.29182243], [69.32041931, 22.29180527], [69.32041931, 22.29208374], [69.32068634, 22.29207993], [69.32068634, 22.2923584], [69.32125092, 22.2923584], [69.32125092, 22.29264069], [69.32154083, 22.29264069], [69.32154083, 22.29291916], [69.32180786, 22.29291725], [69.32180786, 22.29319382], [69.32208252, 22.29319382], [69.32208252, 22.29347229], [69.32235718, 22.29346848], [69.32235718, 22.29375076], [69.32263947, 22.29375076], [69.32263947, 22.29403114], [69.32290649, 22.29403114], [69.32290649, 22.29430962], [69.32347107, 22.2943058], [69.32347107, 22.29458237], [69.32402802, 22.29457092], [69.32402802, 22.29486275], [69.32428741, 22.29486275], [69.32428741, 22.29514122], [69.32457733, 22.29514122], [69.32457733, 22.29541969], [69.32485962, 22.29541969], [69.32485962, 22.29652977], [69.32458496, 22.29652786], [69.32458496, 22.29736137], [69.32430267, 22.29736137], [69.32430267, 22.29847145], [69.32457733, 22.29846954], [69.32457733, 22.29931068], [69.32541656, 22.29930305], [69.32541656, 22.29958344], [69.32569122, 22.29957962], [69.32569122, 22.30042076], [69.32597351, 22.30041695], [69.32597351, 22.30097198], [69.32624817, 22.30097008], [69.32624817, 22.30153084], [69.32541656, 22.30153084], [69.32541656, 22.30181122], [69.32430267, 22.3018055], [69.32430267, 22.30208397], [69.32402802, 22.30208015], [69.32402802, 22.30264091], [69.32375336, 22.3026371], [69.32375336, 22.30347252], [69.32402802, 22.30347061], [69.32402802, 22.30376053], [69.32428741, 22.30376053], [69.32428741, 22.30402946], [69.32596588, 22.30402946], [69.32596588, 22.30236053], [69.32624817, 22.30236053], [69.32624817, 22.30208015], [69.32653046, 22.30208015], [69.32653046, 22.30236053], [69.32681274, 22.30236053], [69.32681274, 22.30264091], [69.32707977, 22.30264091], [69.32707977, 22.30402946], [69.3290329, 22.30402946], [69.3290329, 22.30376053], [69.32985687, 22.30376053], [69.32985687, 22.30319023], [69.33013916, 22.30319405], [69.33013916, 22.30291939], [69.33125305, 22.30291939], [69.33125305, 22.30319405], [69.33208466, 22.30319405], [69.33208466, 22.30347252], [69.3326416, 22.30347061], [69.3326416, 22.30376053], [69.33319092, 22.30376053], [69.33319092, 22.30402946], [69.33348083, 22.30402946], [69.33348083, 22.30430984], [69.33403015, 22.30430794], [69.33403015, 22.3045826], [69.33429718, 22.30458069], [69.33429718, 22.30485916], [69.3345871, 22.30485916], [69.3345871, 22.30513763], [69.33486176, 22.30513763], [69.33486176, 22.30569458], [69.33513641, 22.30569458], [69.33513641, 22.30680466], [69.3354187, 22.30680466], [69.3354187, 22.30708313], [69.33569336, 22.30708313], [69.33569336, 22.3073616], [69.33598328, 22.3073616], [69.33598328, 22.30820274], [69.33625031, 22.30819511], [69.33625031, 22.30958366], [69.33651733, 22.30957031], [69.33651733, 22.31014061], [69.33680725, 22.3101387], [69.33680725, 22.31097221], [69.33708191, 22.31097031], [69.33708191, 22.31125069], [69.33735657, 22.31125069], [69.33735657, 22.31180954], [69.33763885, 22.31180573], [69.33763885, 22.31597137], [69.33791351, 22.31597137], [69.33791351, 22.31680489], [69.33763885, 22.31680107], [69.33763885, 22.3176403], [69.33735657, 22.3176403], [69.33735657, 22.31819916], [69.33708191, 22.31819534], [69.33708191, 22.31847191], [69.33680725, 22.31847191], [69.33680725, 22.31874847], [69.33651733, 22.31874084], [69.33651733, 22.31903076], [69.33625031, 22.31902885], [69.33625031, 22.31958389], [69.33598328, 22.31957817], [69.33598328, 22.32014084], [69.33569336, 22.32014084], [69.33569336, 22.32041931], [69.3354187, 22.32041931], [69.3354187, 22.32125282], [69.33513641, 22.32125282], [69.33513641, 22.32152939], [69.33319092, 22.32152939], [69.33319092, 22.32125282], [69.33235931, 22.32125282], [69.33235931, 22.32152939], [69.33207703, 22.32152939], [69.33207703, 22.32263947], [69.33180237, 22.32263947], [69.33180237, 22.3231945], [69.33152771, 22.3231945], [69.33152771, 22.32347107], [69.33097076, 22.32347107], [69.33097076, 22.3243103], [69.33071136, 22.3243103], [69.33071136, 22.32542038], [69.33097076, 22.32542038], [69.33097076, 22.32570076], [69.33125305, 22.32570076], [69.33125305, 22.32625008], [69.33152771, 22.32625008], [69.33152771, 22.32653046], [69.33180237, 22.32653046], [69.33180237, 22.32681084], [69.33097076, 22.32680511], [69.33097076, 22.32708359], [69.33071136, 22.32707977], [69.33071136, 22.32764053], [69.33041382, 22.32763863], [69.33041382, 22.32819366], [69.33069611, 22.32819366], [69.33069611, 22.32791519], [69.33097076, 22.32791519], [69.33097076, 22.32819366], [69.33208466, 22.32819366], [69.33208466, 22.32847214], [69.33291626, 22.32847023], [69.33291626, 22.32875061], [69.33348083, 22.32875061], [69.33348083, 22.32930946], [69.33374786, 22.32930946], [69.33374786, 22.32986069], [69.33403015, 22.32986069], [69.33403015, 22.33014107], [69.33429718, 22.33014107], [69.33429718, 22.33041954], [69.33569336, 22.33041954], [69.33569336, 22.33014107], [69.33625031, 22.33014107], [69.33625031, 22.32986069], [69.33875275, 22.32986069], [69.33875275, 22.33014107], [69.3390274, 22.33014107], [69.3390274, 22.33041954], [69.3401413, 22.33041954], [69.3401413, 22.33014107], [69.34041595, 22.33014107], [69.34041595, 22.32986069], [69.3409729, 22.32986069], [69.3409729, 22.32958031], [69.34152985, 22.32958412], [69.34152985, 22.32930565], [69.34179688, 22.32930946], [69.34179688, 22.32903099], [69.34236145, 22.32903099], [69.34236145, 22.32875061], [69.34265137, 22.32875061], [69.34263611, 22.32847214], [69.34402466, 22.32847214], [69.34402466, 22.32819366], [69.34541321, 22.32819366], [69.34541321, 22.32791519], [69.34680176, 22.32793045], [69.34680176, 22.32764053], [69.34819794, 22.32764053], [69.34819794, 22.32736015], [69.34958649, 22.32736015], [69.34958649, 22.32707977], [69.35069275, 22.32708359], [69.35069275, 22.32680511], [69.35320282, 22.32681084], [69.35320282, 22.32653046], [69.35375214, 22.32653046], [69.35375214, 22.32625008], [69.35402679, 22.32625008], [69.35402679, 22.3259697], [69.35430908, 22.3259716], [69.35430908, 22.32541656], [69.35459137, 22.32542038], [69.35459137, 22.32487106], [69.35542297, 22.32487106], [69.35542297, 22.32458115], [69.35624695, 22.32458305], [69.35624695, 22.32430649], [69.35708618, 22.32430077], [69.35708618, 22.32402802], [69.35791779, 22.32402992], [69.35791779, 22.32374954], [69.35874939, 22.32374954], [69.35874939, 22.32347107], [69.35930634, 22.32347107], [69.35930634, 22.3231945], [69.36013794, 22.3231945], [69.36013794, 22.32291603], [69.36096954, 22.32291985], [69.36096954, 22.32263947], [69.36180878, 22.32263947], [69.36180878, 22.3223629], [69.36264038, 22.3223629], [69.36264038, 22.32208252], [69.36653137, 22.32208252], [69.36653137, 22.32180595], [69.36708069, 22.32180595], [69.36708069, 22.32152748], [69.36736298, 22.32152939], [69.36736298, 22.31957817], [69.36708069, 22.31958389], [69.36708069, 22.31902885], [69.36682129, 22.31903076], [69.36682129, 22.31874084], [69.36653137, 22.31874847], [69.36653137, 22.31847191], [69.36624908, 22.31847191], [69.36624908, 22.31819534], [69.3659668, 22.31819916], [69.3659668, 22.31792068], [69.36541748, 22.31792068], [69.36541748, 22.3176403], [69.36429596, 22.3176403], [69.36429596, 22.31680107], [69.36458588, 22.31680489], [69.36458588, 22.31652641], [69.36680603, 22.31652641], [69.36680603, 22.31680489], [69.36763763, 22.31680489], [69.36763763, 22.31708336], [69.36875153, 22.31708336], [69.36875153, 22.31736183], [69.3704071, 22.31735992], [69.3704071, 22.3176403], [69.37097168, 22.3176403], [69.37097168, 22.31792068], [69.3720932, 22.31792068], [69.3720932, 22.31819916], [69.37291718, 22.31819534], [69.37291718, 22.31847191], [69.37347412, 22.31847191], [69.37347412, 22.31874847], [69.37403107, 22.31874084], [69.37403107, 22.31903076], [69.37458038, 22.31903076], [69.37458038, 22.31930923], [69.37513733, 22.31930542], [69.37513733, 22.31958389], [69.37568665, 22.31957817], [69.37568665, 22.31985855], [69.37625122, 22.31985855], [69.37625122, 22.32097244], [69.37596893, 22.32097244], [69.37596893, 22.32125282], [69.37569427, 22.32125282], [69.37569427, 22.32180595], [69.37596893, 22.32180595], [69.37596893, 22.32208252], [69.37735748, 22.32208252], [69.37735748, 22.32180595], [69.37902832, 22.32180595], [69.37902832, 22.32208252], [69.38041687, 22.32208252], [69.38041687, 22.3223629], [69.38318634, 22.3223629], [69.38318634, 22.32208252], [69.38402557, 22.32208252], [69.38402557, 22.32180595], [69.38513947, 22.32180595], [69.38513947, 22.32152748], [69.38540649, 22.32152939], [69.38540649, 22.32097244], [69.38569641, 22.32097244], [69.38569641, 22.31902885], [69.38597107, 22.31903076], [69.38597107, 22.31874084], [69.38625336, 22.31874847], [69.38625336, 22.31847191], [69.38680267, 22.31846809], [69.38680267, 22.31903076], [69.38707733, 22.31903076], [69.38707733, 22.31930923], [69.38735962, 22.31930923], [69.38735962, 22.31985855], [69.38762665, 22.31985855], [69.38762665, 22.32014084], [69.38791656, 22.32014084], [69.38791656, 22.32041931], [69.38819122, 22.3204174], [69.38819122, 22.32069397], [69.38847351, 22.32069397], [69.38847351, 22.32097244], [69.38903046, 22.32097244], [69.38903046, 22.32125282], [69.38986206, 22.32125282], [69.38986206, 22.32152939], [69.39013672, 22.32152939], [69.39013672, 22.32125282], [69.39070129, 22.32125282], [69.39069366, 22.32097244], [69.39680481, 22.32097244], [69.39680481, 22.32069397], [69.3979187, 22.32069397], [69.3979187, 22.3204174], [69.39903259, 22.32041931], [69.39903259, 22.32014084], [69.40013885, 22.32014084], [69.40013885, 22.31985855], [69.40040588, 22.31985855], [69.40040588, 22.31957817], [69.40097046, 22.31958389], [69.40097046, 22.31902885], [69.40125275, 22.31903076], [69.40125275, 22.31846809], [69.4015274, 22.31847191], [69.4015274, 22.31791878], [69.40180206, 22.31792068], [69.40180206, 22.31735992], [69.40208435, 22.31736183], [69.40208435, 22.31680489], [69.40235901, 22.31680489], [69.40235901, 22.31624985], [69.4026413, 22.31624985], [69.4026413, 22.31596947], [69.40319824, 22.31596947], [69.40319824, 22.31624985], [69.40930176, 22.31624985], [69.40930176, 22.31596947], [69.4173584, 22.31597137], [69.4173584, 22.31569481], [69.41930389, 22.31569481], [69.41930389, 22.31597137], [69.4201355, 22.31597137], [69.4201355, 22.31624985], [69.42124939, 22.31624985], [69.42124939, 22.31653023], [69.42263794, 22.31652641], [69.42263794, 22.31680489], [69.42346954, 22.31680489], [69.42346954, 22.31708336], [69.42402649, 22.31708336], [69.42402649, 22.31736183], [69.42457581, 22.31735992], [69.42457581, 22.3176403], [69.42485809, 22.3176403], [69.42485809, 22.31792068], [69.42542267, 22.31792068], [69.42542267, 22.31819916], [69.42597198, 22.31819534], [69.42597198, 22.31847191], [69.42652893, 22.31847191], [69.42652893, 22.31874847], [69.42679596, 22.31874084], [69.42679596, 22.31903076], [69.42764282, 22.31903076], [69.42764282, 22.31930923], [69.42819214, 22.31930542], [69.42819214, 22.31958389], [69.42874908, 22.31957817], [69.42874908, 22.31985855], [69.42930603, 22.31985855], [69.42930603, 22.32041931], [69.42958069, 22.3204174], [69.42958069, 22.32069397], [69.42986298, 22.32069397], [69.42986298, 22.32097244], [69.43041992, 22.32097244], [69.43041992, 22.32069397], [69.43069458, 22.32069397], [69.43069458, 22.32014084], [69.43125153, 22.32014084], [69.43125153, 22.32041931], [69.43180847, 22.3204174], [69.43180847, 22.32069397], [69.43208313, 22.32069397], [69.43208313, 22.32097244], [69.43235779, 22.32097244], [69.43235779, 22.32125282], [69.43319702, 22.32125282], [69.43319702, 22.32152939], [69.43402863, 22.32152748], [69.43402863, 22.32180595], [69.43486023, 22.32180595], [69.43486023, 22.32208252], [69.43567657, 22.32208252], [69.43567657, 22.3223629], [69.43596649, 22.3223629], [69.43596649, 22.32263947], [69.43653107, 22.32263947], [69.43653107, 22.32291985], [69.43708038, 22.32291603], [69.43708038, 22.3231945], [69.43736267, 22.3231926], [69.43736267, 22.32402992], [69.43708038, 22.32402802], [69.43708038, 22.32458305], [69.43736267, 22.32458115], [69.43736267, 22.32514], [69.43763733, 22.32514], [69.43763733, 22.32542038], [69.43791962, 22.32542038], [69.43791962, 22.32570076], [69.43846893, 22.32569313], [69.43846893, 22.3259716], [69.43873596, 22.3259697], [69.43873596, 22.32625008], [69.43902588, 22.32625008], [69.43902588, 22.32653046], [69.43930817, 22.32653046], [69.43930817, 22.32681084], [69.43958282, 22.32680511], [69.43958282, 22.32708359], [69.43985748, 22.32707977], [69.43985748, 22.32736015], [69.44013977, 22.32736015], [69.44013977, 22.32764053], [69.4404068, 22.32764053], [69.4404068, 22.32793045], [69.44069672, 22.32791519], [69.44069672, 22.32819366], [69.4404068, 22.32818985], [69.4404068, 22.32930946], [69.44152832, 22.32930946], [69.44152832, 22.32986069], [69.44181061, 22.32986069], [69.44181061, 22.33041954], [69.44235992, 22.33041573], [69.44235992, 22.3306942], [69.44291687, 22.3306942], [69.44291687, 22.33097267], [69.44625092, 22.33097076], [69.44625092, 22.33125114], [69.44735718, 22.33125114], [69.44735718, 22.33152962], [69.44875336, 22.33152962], [69.44875336, 22.33180809], [69.44930267, 22.33180618], [69.44930267, 22.33208275], [69.44985962, 22.33208084], [69.44985962, 22.33235931], [69.45041656, 22.33235931], [69.45041656, 22.3326416], [69.45124817, 22.3326416], [69.45124817, 22.33292007], [69.45153046, 22.33291626], [69.45153046, 22.33319473], [69.45207977, 22.33319473], [69.45207977, 22.33346939], [69.45236206, 22.33346939], [69.45236206, 22.33403015], [69.45263672, 22.33402824], [69.45263672, 22.33458328], [69.45291901, 22.33458328], [69.45291901, 22.33486176], [69.45318604, 22.33486176], [69.45318604, 22.33514023], [69.45375061, 22.33514023], [69.45375061, 22.33542061], [69.45430756, 22.33542061], [69.45430756, 22.3357029], [69.45485687, 22.3357029], [69.45485687, 22.33542061], [69.45513916, 22.33542061], [69.45513916, 22.33514023], [69.45540619, 22.33514023], [69.45540619, 22.33486176], [69.45569611, 22.33486176], [69.45569611, 22.33458328], [69.45597076, 22.33458328], [69.45597076, 22.33430481], [69.45625305, 22.33430481], [69.45625305, 22.33402824], [69.45652771, 22.33403015], [69.45652771, 22.33373833], [69.45680237, 22.33375168], [69.45680237, 22.33346939], [69.45708466, 22.33346939], [69.45708466, 22.33319473], [69.45735931, 22.33319473], [69.45735931, 22.33291626], [69.4576416, 22.33292007], [69.4576416, 22.33235931], [69.45847321, 22.33235931], [69.45847321, 22.33292007], [69.45903015, 22.33291626], [69.45903015, 22.33319473], [69.45930481, 22.33319473], [69.45930481, 22.33346939], [69.4595871, 22.33346939], [69.4595871, 22.33375168], [69.4604187, 22.33375168], [69.4604187, 22.33346939], [69.46069336, 22.33346939], [69.46069336, 22.33319473], [69.46097565, 22.33319473], [69.46097565, 22.33291626], [69.46125031, 22.33292007], [69.46125031, 22.33208084], [69.46152496, 22.33208275], [69.46152496, 22.33152962], [69.46180725, 22.33152962], [69.46180725, 22.33125114], [69.46235657, 22.33125114], [69.46235657, 22.33097076], [69.4631958, 22.33097267], [69.4631958, 22.3306942], [69.46458435, 22.3306942], [69.46458435, 22.33041573], [69.4651413, 22.33041954], [69.4651413, 22.33014107], [69.46736145, 22.33014107], [69.46736145, 22.33041954], [69.4679184, 22.33041573], [69.4679184, 22.3306942], [69.46819305, 22.3306942], [69.46819305, 22.33097267], [69.46875, 22.33097076], [69.46875, 22.33125114], [69.46901703, 22.33125114], [69.46901703, 22.33152962], [69.46930695, 22.33152962], [69.46930695, 22.33180809], [69.4695816, 22.33180618], [69.4695816, 22.33208275], [69.46985626, 22.33208084], [69.46985626, 22.33235931], [69.47013855, 22.33235931], [69.47013855, 22.3326416], [69.47041321, 22.3326416], [69.47041321, 22.33292007], [69.4734726, 22.33291626], [69.4734726, 22.33319473], [69.47486115, 22.33319473], [69.47486115, 22.33346939], [69.47597504, 22.33346939], [69.47597504, 22.33375168], [69.47680664, 22.33373833], [69.47680664, 22.33403015], [69.4770813, 22.33402824], [69.4770813, 22.33458328], [69.47735596, 22.33457947], [69.47735596, 22.33514023], [69.47792053, 22.33514023], [69.47792053, 22.33486176], [69.47875214, 22.33486176], [69.47875214, 22.33458328], [69.47902679, 22.33458328], [69.47902679, 22.33430481], [69.47958374, 22.33430481], [69.47958374, 22.33402824], [69.48041534, 22.33402824], [69.48041534, 22.33430481], [69.48069763, 22.33430481], [69.48069763, 22.33458328], [69.48208618, 22.33458328], [69.48208618, 22.33486176], [69.48264313, 22.33486176], [69.48264313, 22.33514023], [69.48319244, 22.33514023], [69.48319244, 22.33542061], [69.48401642, 22.33542061], [69.48401642, 22.3357029], [69.48458099, 22.33569527], [69.48458099, 22.33597374], [69.48513794, 22.33597183], [69.48513794, 22.33625031], [69.48542023, 22.33625031], [69.48542023, 22.33653069], [69.48568726, 22.33653069], [69.48568726, 22.33681107], [69.48596954, 22.33680534], [69.48596954, 22.33708382], [69.48625183, 22.33708191], [69.48625183, 22.33736038], [69.48680878, 22.33736038], [69.48680878, 22.33764076], [69.48764038, 22.33764076], [69.48764038, 22.33792114], [69.48791504, 22.33791733], [69.48791504, 22.33819389], [69.48819733, 22.33819389], [69.48819733, 22.33791733], [69.48847198, 22.33791733], [69.48847198, 22.33819389], [69.48874664, 22.33819389], [69.48874664, 22.33864975], [69.48874664, 22.33987045], [69.48847198, 22.33987045], [69.48847198, 22.34263992], [69.48819733, 22.34263992], [69.48819733, 22.3476429], [69.48791504, 22.34763908], [69.48791504, 22.3484726], [69.48819733, 22.3484726], [69.48819733, 22.34875107], [69.48847198, 22.34875107], [69.48847198, 22.34902954], [69.48874664, 22.34902954], [69.48874664, 22.34930992], [69.48902893, 22.34930992], [69.48902893, 22.35181046], [69.48929596, 22.35181046], [69.48929596, 22.35292053], [69.48958588, 22.35292053], [69.48958588, 22.35403061], [69.48986053, 22.3540287], [69.48986053, 22.35486031], [69.49013519, 22.35486031], [69.49013519, 22.35569382], [69.49041748, 22.35569382], [69.49041748, 22.35597229], [69.49069214, 22.35597038], [69.49069214, 22.35625076], [69.4909668, 22.35625076], [69.4909668, 22.35653114], [69.49124908, 22.35653114], [69.49124908, 22.35680962], [69.49180603, 22.3568058], [69.49180603, 22.35708237], [69.49208069, 22.35708046], [69.49208069, 22.35764122], [69.49236298, 22.35763741], [69.49236298, 22.35819435], [69.49263763, 22.35819054], [69.49263763, 22.35902977], [69.49318695, 22.35902977], [69.49318695, 22.35931015], [69.49346924, 22.35930634], [69.49346924, 22.3595829], [69.49375153, 22.35957909], [69.49375153, 22.36014175], [69.49402618, 22.36014175], [69.49402618, 22.36042023], [69.49430847, 22.36041641], [69.49430847, 22.36069489], [69.49485779, 22.36069489], [69.49485779, 22.36096954], [69.49514008, 22.36096954], [69.49514008, 22.36125183], [69.4954071, 22.36125183], [69.4954071, 22.3615303], [69.49569702, 22.3615284], [69.49569702, 22.36208344], [69.49595642, 22.36207962], [69.49595642, 22.36264038], [69.49624634, 22.36264038], [69.49624634, 22.36292076], [69.49652863, 22.36291695], [69.49652863, 22.36319351], [69.49680328, 22.3631897], [69.49680328, 22.36375046], [69.4970932, 22.36375046], [69.4970932, 22.36404037], [69.49736023, 22.36404037], [69.49736023, 22.36431122], [69.49764252, 22.3643055], [69.49764252, 22.36458206], [69.49791718, 22.36458015], [69.49791718, 22.36486053], [69.49819183, 22.36486053], [69.49819183, 22.36514091], [69.49846649, 22.36514091], [69.49846649, 22.36541939], [69.49874878, 22.36541748], [69.49874878, 22.36569595], [69.49903107, 22.36569595], [69.49903107, 22.36597252], [69.49958038, 22.36597061], [69.49958038, 22.36625099], [69.49986267, 22.36625099], [69.49986267, 22.36652946], [69.50041962, 22.36652946], [69.50041962, 22.36680984], [69.50069427, 22.36680412], [69.50069427, 22.3670826], [69.50152588, 22.36708069], [69.50152588, 22.36736107], [69.50235748, 22.36736107], [69.50235748, 22.36763954], [69.5029068, 22.36763954], [69.5029068, 22.36791992], [69.50375366, 22.3679142], [69.50375366, 22.36819458], [69.50514221, 22.36819458], [69.50514221, 22.36847305], [69.50596619, 22.36847115], [69.50596619, 22.36874962], [69.50708008, 22.36874962], [69.50708008, 22.36903], [69.50763702, 22.36902618], [69.50763702, 22.36930466], [69.50819397, 22.36930466], [69.50819397, 22.36958313], [69.50875092, 22.36958313], [69.50875092, 22.3698616], [69.50930786, 22.36985016], [69.50930786, 22.37013817], [69.50985718, 22.37013817], [69.50985718, 22.37042046], [69.51040649, 22.37042046], [69.51040649, 22.37070084], [69.51069641, 22.37069511], [69.51069641, 22.37097168], [69.51125336, 22.37096977], [69.51125336, 22.37124825], [69.51152802, 22.37124825], [69.51152802, 22.37153053], [69.51207733, 22.37153053], [69.51207733, 22.37181091], [69.51235962, 22.37180519], [69.51235962, 22.37208366], [69.51291656, 22.37207985], [69.51291656, 22.37235832], [69.51319122, 22.37235832], [69.51319122, 22.37264061], [69.51374817, 22.37264061], [69.51374817, 22.37291908], [69.51403046, 22.37291718], [69.51403046, 22.37347221], [69.51430511, 22.37347221], [69.51430511, 22.37375069], [69.51457977, 22.37375069], [69.51457977, 22.37402916], [69.51486206, 22.37402916], [69.51486206, 22.37430954], [69.51541901, 22.37430573], [69.51541901, 22.3745842], [69.51597595, 22.37458038], [69.51597595, 22.37486267], [69.51625061, 22.37486267], [69.51625061, 22.37514114], [69.5165329, 22.37514114], [69.5165329, 22.37541962], [69.51680756, 22.3754158], [69.51680756, 22.37569427], [69.51708984, 22.37569046], [69.51708984, 22.37598038], [69.51735687, 22.37598038], [69.51735687, 22.37625122], [69.51763916, 22.37625122], [69.51763916, 22.37652969], [69.51790619, 22.37652969], [69.51790619, 22.37681007], [69.51819611, 22.37680626], [69.51819611, 22.37708282], [69.51847076, 22.37708282], [69.51847076, 22.3773613], [69.51875305, 22.37735939], [69.51875305, 22.37792015], [69.51902771, 22.37791634], [69.51902771, 22.37819481], [69.51930237, 22.37819481], [69.51930237, 22.37847137], [69.51957703, 22.37846947], [69.51957703, 22.37874985], [69.51985931, 22.37874985], [69.51985931, 22.37903976], [69.5201416, 22.37902832], [69.5201416, 22.37930489], [69.52124786, 22.37930107], [69.52124786, 22.3801403], [69.52153015, 22.3801403], [69.52153015, 22.38070107], [69.52180481, 22.38069534], [69.52180481, 22.38208389], [69.5220871, 22.38208008], [69.5220871, 22.38236046], [69.52236176, 22.38236046], [69.52236176, 22.38292122], [69.52263641, 22.3829155], [69.52263641, 22.38347244], [69.5229187, 22.38347244], [69.5229187, 22.38458252], [69.52319336, 22.38458061], [69.52319336, 22.38485909], [69.52347565, 22.38485909], [69.52347565, 22.3856945], [69.52375031, 22.3856945], [69.52375031, 22.38736153], [69.52347565, 22.38736153], [69.52348328, 22.38875008], [69.52319336, 22.38875008], [69.52319336, 22.38903046], [69.5229187, 22.38903046], [69.5229187, 22.38931274], [69.52263641, 22.38930511], [69.52263641, 22.38958359], [69.52236176, 22.38958359], [69.52236176, 22.38986206], [69.5220871, 22.38986015], [69.5220871, 22.39014053], [69.52179718, 22.39014053], [69.52179718, 22.39042091], [69.52153015, 22.3904171], [69.52153015, 22.39069366], [69.52124786, 22.39068985], [69.52124786, 22.39097977], [69.52097321, 22.39097977], [69.52097321, 22.39125061], [69.52069092, 22.39125061], [69.52069092, 22.39153099], [69.52041626, 22.39153099], [69.52041626, 22.39180946], [69.5201416, 22.39180565], [69.5201416, 22.39208412], [69.51902771, 22.39208031], [69.51902771, 22.39236069], [69.51847076, 22.39236069], [69.51847076, 22.39264107], [69.51819611, 22.39264107], [69.51819611, 22.39291954], [69.51791382, 22.39291763], [69.51791382, 22.3931942], [69.51763916, 22.3931942], [69.51763916, 22.39347267], [69.51735687, 22.39347076], [69.51735687, 22.39375114], [69.51680756, 22.39375114], [69.51680756, 22.39431], [69.51652527, 22.39430428], [69.51652527, 22.39458275], [69.51625061, 22.39458084], [69.51625061, 22.39513969], [69.51597595, 22.39513969], [69.51597595, 22.39958382], [69.51569366, 22.39958382], [69.51569366, 22.40486145], [69.51597595, 22.40485954], [69.51597595, 22.4054203], [69.51568604, 22.4054203], [69.51568604, 22.40570068], [69.51625061, 22.40570068], [69.51625061, 22.40625], [69.5165329, 22.40625], [69.5165329, 22.40681076], [69.51680756, 22.40680695], [69.51680756, 22.40736198], [69.51708984, 22.40736008], [69.51708984, 22.40792084], [69.5173645, 22.40791512], [69.5173645, 22.40847206], [69.51763916, 22.40847206], [69.51763916, 22.40902519], [69.51791382, 22.40902519], [69.51791382, 22.4109726], [69.51763916, 22.41097069], [69.51763916, 22.41152954], [69.51735687, 22.41152954], [69.51735687, 22.41208839], [69.51708221, 22.41208267], [69.51708984, 22.41263771], [69.51680756, 22.41263771], [69.51680756, 22.41292191], [69.51652527, 22.41291618], [69.51652527, 22.41347313], [69.51625061, 22.41346931], [69.51625061, 22.41403008], [69.51597595, 22.41402817], [69.51597595, 22.41458321], [69.51569366, 22.41458321], [69.51569366, 22.41486168], [69.51541901, 22.41486168], [69.51541901, 22.41597366], [69.51513672, 22.41597176], [69.51513672, 22.4168129], [69.51457977, 22.41680527], [69.51457977, 22.41708374], [69.51403046, 22.41708183], [69.51403046, 22.41736031], [69.51152802, 22.41736031], [69.51152802, 22.41764069], [69.51095581, 22.41764069], [69.51095581, 22.41792107], [69.51069641, 22.41791725], [69.51069641, 22.41819382], [69.51041412, 22.41819382], [69.51041412, 22.41847229], [69.51013947, 22.41847038], [69.51013947, 22.41903114], [69.50986481, 22.41902733], [69.50986481, 22.41958237], [69.51013947, 22.41958046], [69.51013947, 22.42041969], [69.50986481, 22.42041588], [69.50986481, 22.42069435], [69.50958252, 22.42069435], [69.50958252, 22.42097282], [69.50930786, 22.42097282], [69.50930786, 22.42236137], [69.50708008, 22.42236137], [69.50708008, 22.4220829], [69.50653076, 22.4220829], [69.50653076, 22.42236137], [69.50624847, 22.42235947], [69.50624847, 22.42263985], [69.50541687, 22.42263985], [69.50541687, 22.42292023], [69.50514221, 22.42291641], [69.50514221, 22.42347145], [69.50485992, 22.42346954], [69.50485992, 22.42374992], [69.50402832, 22.42374992], [69.50402832, 22.42432022], [69.50347137, 22.42430496], [69.50347137, 22.42458344], [69.50319672, 22.42457962], [69.50319672, 22.42514038], [69.50291443, 22.42514038], [69.5029068, 22.4256897], [69.50263977, 22.42569923], [69.50263977, 22.42624855], [69.50235748, 22.42624855], [69.50235748, 22.42680931], [69.50209045, 22.42680931], [69.50209045, 22.4287529], [69.50180817, 22.42874908], [69.50180817, 22.4295826], [69.50152588, 22.4295826], [69.50152588, 22.43153], [69.50125122, 22.43152809], [69.50125122, 22.43180466], [69.50069427, 22.43180466], [69.50069427, 22.43208313], [69.50041962, 22.43208313], [69.50041962, 22.4323616], [69.50013733, 22.4323597], [69.50013733, 22.43264008], [69.49986267, 22.43264008], [69.49986267, 22.43292046], [69.49958038, 22.43291664], [69.49958038, 22.43319321], [69.49930573, 22.43319321], [69.49930573, 22.43347168], [69.49901581, 22.43346977], [69.49901581, 22.43375015], [69.49874878, 22.43375015], [69.49874878, 22.43403053], [69.49846649, 22.43403053], [69.49846649, 22.43514061], [69.49819183, 22.4351387], [69.49819183, 22.43569374], [69.49874878, 22.43569374], [69.49874878, 22.43541527], [69.49931335, 22.43542099], [69.49931335, 22.43514061], [69.49958038, 22.43514061], [69.49958038, 22.43486023], [69.49986267, 22.43486023], [69.49986267, 22.43457985], [69.50041962, 22.43458366], [69.50041962, 22.43430519], [69.50096893, 22.43431091], [69.50096893, 22.43403053], [69.50125122, 22.43403053], [69.50125122, 22.43375015], [69.50209045, 22.43375015], [69.50208282, 22.43347168], [69.50235748, 22.43347168], [69.50235748, 22.43319321], [69.50263977, 22.43319321], [69.50263977, 22.4323616], [69.50291443, 22.4323616], [69.50291443, 22.43208313], [69.50319672, 22.43208313], [69.50319672, 22.42986107], [69.50347137, 22.42986107], [69.50347137, 22.42791939], [69.50374603, 22.42791939], [69.50374603, 22.42735863], [69.50402832, 22.42735863], [69.50402832, 22.42653084], [69.5045929, 22.42653084], [69.5045929, 22.42680931], [69.50485992, 22.42680931], [69.50485992, 22.42708969], [69.50541687, 22.42708969], [69.50541687, 22.42735863], [69.50681305, 22.42735863], [69.50680542, 22.42624855], [69.50708008, 22.42624855], [69.50708008, 22.42596817], [69.50736237, 22.42597008], [69.50736237, 22.42541885], [69.50624847, 22.42542076], [69.50624847, 22.42485809], [69.50653076, 22.42486191], [69.50653076, 22.42458344], [69.50680542, 22.42458344], [69.50680542, 22.42402649], [69.50708008, 22.4240303], [69.50708008, 22.42374992], [69.50763702, 22.42374992], [69.50763702, 22.42432022], [69.50791931, 22.42430496], [69.50791931, 22.42486191], [69.50818634, 22.42485809], [69.50818634, 22.42514038], [69.50846863, 22.42514038], [69.50846863, 22.42542076], [69.50902557, 22.42541885], [69.50902557, 22.42569351], [69.51457977, 22.42569351], [69.51457977, 22.42541885], [69.51513672, 22.42541885], [69.51513672, 22.42569351], [69.51708221, 22.42569351], [69.51708221, 22.42597008], [69.51875305, 22.42596817], [69.51875305, 22.42624855], [69.51957703, 22.42624855], [69.51957703, 22.42653084], [69.5229187, 22.42653084], [69.5229187, 22.42624855], [69.52319336, 22.42624855], [69.52319336, 22.42485809], [69.52347565, 22.42486191], [69.52347565, 22.42458344], [69.52375031, 22.42458344], [69.52375031, 22.42430496], [69.52430725, 22.42432022], [69.52430725, 22.4240303], [69.52458191, 22.4240303], [69.52458191, 22.42374992], [69.52680206, 22.42374992], [69.52680206, 22.42346954], [69.52708435, 22.42347145], [69.52708435, 22.42319489], [69.5276413, 22.42319489], [69.5276413, 22.42291641], [69.52791595, 22.42292023], [69.52791595, 22.42263985], [69.5284729, 22.42263985], [69.5284729, 22.42235947], [69.52874756, 22.42236137], [69.52874756, 22.4220829], [69.52902985, 22.4220829], [69.52902985, 22.42180634], [69.52958679, 22.42181015], [69.52958679, 22.42152977], [69.52986145, 22.42152977], [69.52986145, 22.42124939], [69.5304184, 22.42124939], [69.5304184, 22.42095947], [69.53069305, 22.42097282], [69.53069305, 22.42069435], [69.53097534, 22.42069435], [69.53097534, 22.42041588], [69.53151703, 22.42041969], [69.53151703, 22.42014122], [69.53180695, 22.42014122], [69.53180695, 22.41986084], [69.53208923, 22.41986084], [69.5320816, 22.41958427], [69.53236389, 22.41958237], [69.53236389, 22.4193058], [69.53263855, 22.41930962], [69.53263855, 22.41903114], [69.53291321, 22.41903114], [69.53291321, 22.41847038], [69.5331955, 22.41847229], [69.5331955, 22.41819382], [69.53347015, 22.41819382], [69.53347015, 22.41763878], [69.53375244, 22.41764069], [69.53375244, 22.41708183], [69.5340271, 22.41708374], [69.5340271, 22.41680527], [69.53430176, 22.4168129], [69.53430176, 22.41597176], [69.53458405, 22.41597366], [69.53458405, 22.41513824], [69.5348587, 22.41514969], [69.5348587, 22.41486168], [69.53541565, 22.41486168], [69.53541565, 22.41458321], [69.53569794, 22.41458321], [69.53569794, 22.41402817], [69.5359726, 22.41403008], [69.5359726, 22.41349983], [69.5359726, 22.41319466], [69.53569794, 22.41319466], [69.53569794, 22.41180611], [69.53542328, 22.41180992], [69.53542328, 22.41069031], [69.53569794, 22.41069412], [69.53569794, 22.41041946], [69.5359726, 22.41041946], [69.5359726, 22.41014099], [69.53624725, 22.41014099], [69.53624725, 22.40986061], [69.53652954, 22.40986061], [69.53652954, 22.41014099], [69.53679657, 22.41014099], [69.53679657, 22.41041946], [69.53708649, 22.41041946], [69.53708649, 22.41014099], [69.53930664, 22.41014099], [69.53930664, 22.40958023], [69.5395813, 22.40958405], [69.5395813, 22.40902519], [69.53986359, 22.40902519], [69.53986359, 22.40875053], [69.54152679, 22.40875053], [69.54152679, 22.40847015], [69.54208374, 22.40847206], [69.54208374, 22.40819359], [69.5423584, 22.40819359], [69.5423584, 22.40791512], [69.54292297, 22.40792084], [69.54292297, 22.40764046], [69.54319763, 22.40764046], [69.54319763, 22.40736008], [69.54374695, 22.40736198], [69.54374695, 22.40708351], [69.54402924, 22.40708351], [69.54402924, 22.40680695], [69.54458618, 22.40681076], [69.54458618, 22.40653038], [69.54514313, 22.40653038], [69.54514313, 22.40625], [69.54541779, 22.40625], [69.54541779, 22.40596008], [69.54597473, 22.40597153], [69.54597473, 22.40569305], [69.54624939, 22.40570068], [69.54624939, 22.4054203], [69.54736328, 22.4054203], [69.54736328, 22.40513992], [69.54818726, 22.40513992], [69.54818726, 22.40485954], [69.54875183, 22.40486145], [69.54875183, 22.40458488], [69.54985809, 22.40458488], [69.54985809, 22.40486145], [69.55013275, 22.40485954], [69.55013275, 22.40513992], [69.55042267, 22.40513992], [69.55042267, 22.40485954], [69.55069733, 22.40486145], [69.55069733, 22.40430641], [69.55097198, 22.40431023], [69.55097198, 22.4034729], [69.55124664, 22.4034729], [69.55124664, 22.40291595], [69.55152893, 22.40291977], [69.55152893, 22.40236282], [69.55179596, 22.40236282], [69.55179596, 22.40208244], [69.55208588, 22.40208244], [69.55208588, 22.40125275], [69.55236053, 22.40125275], [69.55236053, 22.40068817], [69.55263519, 22.40069389], [69.55263519, 22.40014076], [69.55291748, 22.4001503], [69.55291748, 22.39957809], [69.55319214, 22.39958382], [69.55319214, 22.3987484], [69.55291748, 22.3987484], [69.55291748, 22.39792061], [69.55264282, 22.39792061], [69.55264282, 22.39707947], [69.55236053, 22.39708328], [69.55236053, 22.39624977], [69.55208588, 22.39624977], [69.55208588, 22.39542007], [69.55179596, 22.39542007], [69.55179596, 22.39458084], [69.55152893, 22.39458275], [69.55152893, 22.39374924], [69.55097198, 22.39374924], [69.55097198, 22.39402771], [69.55042267, 22.39402008], [69.55042267, 22.39431], [69.54958344, 22.39430428], [69.54958344, 22.39458275], [69.54875183, 22.39458275], [69.54875183, 22.39402771], [69.54902649, 22.39402771], [69.54902649, 22.39374924], [69.54930878, 22.39375114], [69.54930878, 22.39319038], [69.54958344, 22.3931942], [69.54958344, 22.39291573], [69.55013275, 22.39291954], [69.55013275, 22.39264107], [69.55042267, 22.39264107], [69.55042267, 22.39236069], [69.55069733, 22.39236069], [69.55069733, 22.39208031], [69.55097198, 22.39208412], [69.55097198, 22.39180565], [69.55124664, 22.39180946], [69.55124664, 22.39153099], [69.55152893, 22.39153099], [69.55152893, 22.39125061], [69.55179596, 22.39125061], [69.55179596, 22.39097977], [69.55208588, 22.39097977], [69.55208588, 22.39068985], [69.55236053, 22.39069366], [69.55236053, 22.39013863], [69.55264282, 22.39014053], [69.55264282, 22.38986015], [69.55291748, 22.38986015], [69.55291748, 22.38957977], [69.55319214, 22.38958359], [69.55319214, 22.38930511], [69.5534668, 22.38931274], [69.5534668, 22.38903046], [69.55374908, 22.38903046], [69.55374908, 22.38875008], [69.55486298, 22.38875008], [69.55486298, 22.38903046], [69.55513763, 22.38903046], [69.55513763, 22.38875008], [69.55568695, 22.38875008], [69.55568695, 22.3884716], [69.55596924, 22.3884716], [69.55596924, 22.38680649], [69.55625916, 22.38680077], [69.55625153, 22.38402748], [69.55652618, 22.38402748], [69.55652618, 22.38153076], [69.55680847, 22.38153076], [69.55680847, 22.38042068], [69.55708313, 22.38042068], [69.55708313, 22.37930107], [69.55735779, 22.37930489], [69.55735779, 22.37902832], [69.55708313, 22.37903976], [69.55708313, 22.37763977], [69.55735779, 22.37763977], [69.55735779, 22.37541962], [69.55069733, 22.37541962], [69.55069733, 22.37514114], [69.55042267, 22.37514114], [69.55042267, 22.37486267], [69.55013275, 22.37486267], [69.55013275, 22.37430954], [69.55042267, 22.37430954], [69.55042267, 22.37402916], [69.55097198, 22.37402916], [69.55097198, 22.37375069], [69.55152893, 22.37375069], [69.55152893, 22.3734684], [69.55124664, 22.37347221], [69.55124664, 22.37319374], [69.55069733, 22.37319374], [69.55069733, 22.37264061], [69.55042267, 22.37264061], [69.55042267, 22.37235832], [69.55069733, 22.37235832], [69.55069733, 22.37181091], [69.55124664, 22.37181091], [69.55124664, 22.37153053], [69.55179596, 22.37153053], [69.55179596, 22.37124825], [69.55236053, 22.37124825], [69.55236053, 22.37096977], [69.55291748, 22.37097168], [69.55291748, 22.37069511], [69.5534668, 22.37070084], [69.5534668, 22.37042046], [69.55430603, 22.37042046], [69.55430603, 22.37013817], [69.55486298, 22.37013817], [69.55486298, 22.36985016], [69.55541992, 22.3698616], [69.55541992, 22.36958313], [69.55596924, 22.36958313], [69.55596924, 22.36930466], [69.55652618, 22.36930466], [69.55652618, 22.36902618], [69.55708313, 22.36903], [69.55708313, 22.36874962], [69.55764008, 22.36874962], [69.55764008, 22.36847115], [69.55791473, 22.36847305], [69.55791473, 22.36819458], [69.55819702, 22.36819458], [69.55819702, 22.3679142], [69.55847168, 22.36791992], [69.55847168, 22.36763954], [69.55874634, 22.36763954], [69.55874634, 22.36736107], [69.55930328, 22.36736107], [69.55930328, 22.36708069], [69.55958557, 22.3670826], [69.55958557, 22.36680412], [69.55986023, 22.36680984], [69.55986023, 22.36404037], [69.5595932, 22.36404037], [69.5595932, 22.36375046], [69.55986023, 22.36375046], [69.55986023, 22.3631897], [69.56014252, 22.36319351], [69.56014252, 22.36263847], [69.56041718, 22.36264038], [69.56041718, 22.36236191], [69.56069183, 22.36236382], [69.56069183, 22.36180496], [69.56096649, 22.36181068], [69.56096649, 22.3615303], [69.56124878, 22.3615303], [69.56124878, 22.36096954], [69.56153107, 22.36096954], [69.56153107, 22.36041641], [69.56181335, 22.36042023], [69.56181335, 22.35986137], [69.56263733, 22.35986137], [69.56263733, 22.35930634], [69.56291962, 22.35931015], [69.56291962, 22.35902977], [69.56318665, 22.35902977], [69.56318665, 22.35819054], [69.56291962, 22.35819435], [69.56291962, 22.35791588], [69.56236267, 22.35791588], [69.56236267, 22.35736084], [69.56207275, 22.35736084], [69.56207275, 22.35680962], [69.56124878, 22.35680962], [69.56124878, 22.35653114], [69.56153107, 22.35653114], [69.56153107, 22.35625076], [69.56181335, 22.35625076], [69.56180573, 22.35569382], [69.56263733, 22.35569382], [69.56263733, 22.35597229], [69.56318665, 22.35597038], [69.56318665, 22.35625076], [69.56375122, 22.35625076], [69.56375122, 22.35653114], [69.56458282, 22.35653114], [69.56458282, 22.35680962], [69.56513977, 22.3568058], [69.56513977, 22.35708237], [69.56569672, 22.35708046], [69.56569672, 22.35736084], [69.56624603, 22.35736084], [69.56624603, 22.35764122], [69.56652832, 22.35763741], [69.56652832, 22.35791588], [69.56680298, 22.35791588], [69.56680298, 22.35819435], [69.56708527, 22.35819435], [69.56708527, 22.35874748], [69.56735992, 22.35874748], [69.56735992, 22.35902977], [69.56764221, 22.35902977], [69.56764221, 22.35931015], [69.56791687, 22.35930634], [69.56791687, 22.3595829], [69.56819153, 22.3595829], [69.56819153, 22.35986137], [69.56846619, 22.35986137], [69.56846619, 22.36042023], [69.56874847, 22.36042023], [69.56874847, 22.3615303], [69.5688858, 22.3615303], [69.56903076, 22.3615303], [69.56903076, 22.36292076], [69.56930542, 22.36291695], [69.56930542, 22.3631115], [69.56930542, 22.36347389], [69.56958008, 22.36347008], [69.56958008, 22.36375046], [69.56986237, 22.36375046], [69.56986237, 22.36404037], [69.57013702, 22.36404037], [69.57013702, 22.36431122], [69.57041931, 22.3643055], [69.57041931, 22.36458206], [69.57068634, 22.36458015], [69.57068634, 22.36486053], [69.57096863, 22.36486053], [69.57096863, 22.36514091], [69.57124329, 22.36514091], [69.57124329, 22.36541939], [69.57152557, 22.36541748], [69.57152557, 22.36569595], [69.57208252, 22.36569595], [69.57208252, 22.36597252], [69.57235718, 22.36597061], [69.57235718, 22.36625099], [69.57263947, 22.36625099], [69.57263947, 22.36652946], [69.57290649, 22.36652946], [69.57290649, 22.36680984], [69.57347107, 22.36680412], [69.57347107, 22.3670826], [69.57375336, 22.36708069], [69.57375336, 22.36736107], [69.57402802, 22.36736107], [69.57402802, 22.36791992], [69.57458496, 22.3679142], [69.57458496, 22.36819458], [69.57569122, 22.36819458], [69.57569122, 22.36847305], [69.57679749, 22.36847305], [69.57819366, 22.36847305], [69.57819366, 22.36819458], [69.57875061, 22.36819458], [69.57875061, 22.3679142], [69.5790329, 22.36791992], [69.5790329, 22.36763954], [69.57958221, 22.36763954], [69.57958221, 22.36736107], [69.58013916, 22.36736107], [69.58013916, 22.36708069], [69.58041382, 22.3670826], [69.58041382, 22.36680412], [69.58097076, 22.36680984], [69.58097076, 22.36597061], [69.58125305, 22.36597252], [69.58125305, 22.36541748], [69.58152771, 22.36541939], [69.58152771, 22.36486053], [69.58180237, 22.36486053], [69.58180237, 22.36458015], [69.58208466, 22.36458206], [69.58208466, 22.36402702], [69.58235931, 22.36404037], [69.58235931, 22.36347008], [69.5826416, 22.36347389], [69.5826416, 22.36319351], [69.58291626, 22.36319351], [69.58291626, 22.36263847], [69.58318329, 22.36264038], [69.58318329, 22.36207962], [69.58291626, 22.36208344], [69.58291626, 22.3615284], [69.58486176, 22.3615303], [69.58486176, 22.36181068], [69.58569336, 22.36181068], [69.58569336, 22.3615303], [69.58680725, 22.3615284], [69.58680725, 22.36208344], [69.58763885, 22.36208344], [69.58763885, 22.36236382], [69.58790588, 22.36236191], [69.58790588, 22.36264038], [69.58875275, 22.36264038], [69.58875275, 22.36236191], [69.5890274, 22.36236382], [69.5890274, 22.36208344], [69.58958435, 22.36208344], [69.58958435, 22.36180496], [69.58985901, 22.36181068], [69.58985901, 22.3615303], [69.59041595, 22.3615303], [69.59041595, 22.36125183], [69.59069061, 22.36125183], [69.59069824, 22.36096954], [69.59124756, 22.36096954], [69.59124756, 22.36041641], [69.59152985, 22.36042023], [69.59152985, 22.35986137], [69.5918045, 22.35986137], [69.5918045, 22.35930634], [69.59208679, 22.35931015], [69.59208679, 22.35874748], [69.59236908, 22.35874748], [69.59236145, 22.3568058], [69.59208679, 22.35680962], [69.59208679, 22.35625076], [69.59179688, 22.35625076], [69.59179688, 22.35597038], [69.59152985, 22.35597229], [69.59152985, 22.35541534], [69.59124756, 22.35542107], [69.59124756, 22.35485077], [69.5909729, 22.35486031], [69.5909729, 22.35458374], [69.59069824, 22.35458374], [69.59069061, 22.3540287], [69.59041595, 22.35403061], [69.59041595, 22.35375023], [69.5901413, 22.35375023], [69.5901413, 22.35346985], [69.58958435, 22.35347176], [69.58958435, 22.35319328], [69.58930969, 22.35320091], [69.58930969, 22.35292053], [69.58875275, 22.35292053], [69.58875275, 22.35264015], [69.58847046, 22.35264015], [69.58847046, 22.35235977], [69.58791351, 22.35236168], [69.58791351, 22.35208321], [69.5873642, 22.35208321], [69.5873642, 22.35180473], [69.58680725, 22.35181046], [69.58680725, 22.35153008], [69.58624268, 22.35153008], [69.58624268, 22.35124969], [69.58569336, 22.35124969], [69.58569336, 22.35097122], [69.58486176, 22.35097313], [69.58486176, 22.35069466], [69.58430481, 22.35069466], [69.58430481, 22.35041618], [69.58403015, 22.35042], [69.58403015, 22.35013962], [69.58374786, 22.35013962], [69.58374786, 22.34986115], [69.58347321, 22.34986115], [69.58347321, 22.34958267], [69.58319092, 22.34958267], [69.58319092, 22.34930611], [69.58291626, 22.34930992], [69.58291626, 22.34902954], [69.58235931, 22.34902954], [69.58235931, 22.34875107], [69.58207703, 22.34875107], [69.58207703, 22.3484726], [69.58180237, 22.3484726], [69.58180237, 22.34819412], [69.58125305, 22.34819412], [69.58125305, 22.34791756], [69.58097076, 22.34791946], [69.58097076, 22.3476429], [69.58040619, 22.3476429], [69.58040619, 22.3473587], [69.58013916, 22.3473587], [69.58013916, 22.34707832], [69.5798645, 22.34708405], [69.5798645, 22.34680557], [69.57958221, 22.34680939], [69.57958221, 22.34625053], [69.57930756, 22.34625053], [69.57930756, 22.3445797], [69.57902527, 22.34458351], [69.57902527, 22.34347153], [69.57875061, 22.34347153], [69.57875061, 22.34263611], [69.5790329, 22.34263992], [69.5790329, 22.34097099], [69.57930756, 22.3409729], [69.57930756, 22.33986092], [69.5790329, 22.33987045], [69.5790329, 22.33875084], [69.57875061, 22.33875084], [69.57875061, 22.33819008], [69.57819366, 22.33819389], [69.57819366, 22.33791733], [69.57763672, 22.33792114], [69.57763672, 22.33764076], [69.57707977, 22.33764076], [69.57707977, 22.33736038], [69.57596588, 22.33736038], [69.57596588, 22.33708191], [69.57458496, 22.33708382], [69.57458496, 22.33652687], [69.57430267, 22.33653069], [69.57430267, 22.33625031], [69.57375336, 22.33625031], [69.57375336, 22.33597183], [69.57347107, 22.33597374], [69.57347107, 22.33569527], [69.57319641, 22.3357029], [69.57319641, 22.33543968], [69.57290649, 22.33542061], [69.57290649, 22.33514023], [69.57235718, 22.33514023], [69.57235718, 22.33486176], [69.57208252, 22.33486176], [69.57208252, 22.33430481], [69.57180786, 22.33430481], [69.57180786, 22.33097267], [69.57208252, 22.33097267], [69.57208252, 22.33041573], [69.57235718, 22.33041954], [69.57235718, 22.32986069], [69.57263947, 22.32986069], [69.57263947, 22.32930946], [69.57290649, 22.32930946], [69.57290649, 22.32903099], [69.57319641, 22.32903099], [69.57319641, 22.32847023], [69.57347107, 22.32847214], [69.57347107, 22.32791519], [69.57375336, 22.32793045], [69.57375336, 22.32736015], [69.57402802, 22.32736015], [69.57402802, 22.32653046], [69.57430267, 22.32653046], [69.57430267, 22.32625008], [69.57457733, 22.32625008], [69.57457733, 22.32542038], [69.57485962, 22.32542038], [69.57485962, 22.3243103], [69.57514191, 22.32430077], [69.57514191, 22.32347107], [69.57541656, 22.32347107], [69.57541656, 22.3204174], [69.57514191, 22.32041931], [69.57514191, 22.31930923], [69.57485962, 22.31930923], [69.57485962, 22.31903076], [69.57569122, 22.31903076], [69.57569122, 22.31930923], [69.57597351, 22.31930542], [69.57597351, 22.31958389], [69.57624817, 22.31957817], [69.57624817, 22.32014084], [69.57653046, 22.32014084], [69.57653046, 22.32263947], [69.57681274, 22.32263947], [69.57681274, 22.32291985], [69.57653046, 22.32291985], [69.57653046, 22.32487106], [69.57624817, 22.32487106], [69.57624817, 22.32542038], [69.57596588, 22.32542038], [69.57596588, 22.32653046], [69.57569122, 22.32652855], [69.57569122, 22.32708359], [69.57541656, 22.32708359], [69.57541656, 22.32819366], [69.57514191, 22.32819366], [69.57514191, 22.32847214], [69.57485962, 22.32847023], [69.57485962, 22.32875061], [69.57457733, 22.32875061], [69.57457733, 22.32930946], [69.57430267, 22.32930565], [69.57430267, 22.32958412], [69.57402802, 22.32958031], [69.57402802, 22.33014107], [69.57375336, 22.33013725], [69.57375336, 22.33097267], [69.57347107, 22.33097076], [69.57347107, 22.33152962], [69.57319641, 22.33152962], [69.57319641, 22.33235931], [69.57291412, 22.33235931], [69.57291412, 22.33319473], [69.57319641, 22.33319473], [69.57319641, 22.33346939], [69.57347107, 22.33346939], [69.57347107, 22.33403015], [69.57375336, 22.33402824], [69.57375336, 22.33430481], [69.57402802, 22.33430481], [69.57402802, 22.33458328], [69.57458496, 22.33458328], [69.57458496, 22.33470917], [69.57457733, 22.33514023], [69.57514191, 22.33514023], [69.57514191, 22.33542061], [69.57541656, 22.33542061], [69.57541656, 22.3357029], [69.57569122, 22.33569527], [69.57569122, 22.33597374], [69.57596588, 22.33597183], [69.57596588, 22.33625031], [69.57681274, 22.33625031], [69.57681274, 22.33653069], [69.57875061, 22.33653069], [69.57875061, 22.33681107], [69.57930756, 22.33680534], [69.57930756, 22.33708382], [69.57958221, 22.33708191], [69.57958221, 22.33736038], [69.57985687, 22.33736038], [69.57985687, 22.33764076], [69.58013916, 22.33763885], [69.58013916, 22.33819389], [69.58041382, 22.33819389], [69.58041382, 22.33958244], [69.58069611, 22.33958054], [69.58069611, 22.34263992], [69.58040619, 22.34263992], [69.58040619, 22.34374809], [69.58069611, 22.34374809], [69.58069611, 22.34486198], [69.58097076, 22.34485817], [69.58097076, 22.34514046], [69.58125305, 22.34514046], [69.58125305, 22.34542084], [69.58152771, 22.34541893], [69.58152771, 22.34569359], [69.58180237, 22.34568024], [69.58180237, 22.34625053], [69.58235931, 22.34625053], [69.58235931, 22.34653091], [69.58291626, 22.34653091], [69.58291626, 22.34680939], [69.58347321, 22.34680557], [69.58347321, 22.34708405], [69.58403015, 22.34707832], [69.58403015, 22.3473587], [69.58513641, 22.3473587], [69.58513641, 22.3476429], [69.58569336, 22.3476429], [69.58569336, 22.34791946], [69.58652496, 22.34791756], [69.58652496, 22.34819412], [69.58708191, 22.34819412], [69.58708191, 22.3484726], [69.58763885, 22.3484726], [69.58763885, 22.34875107], [69.5881958, 22.34875107], [69.5881958, 22.34902954], [69.5890274, 22.34902954], [69.5890274, 22.34930992], [69.58958435, 22.34930611], [69.58958435, 22.34958267], [69.5901413, 22.34958267], [69.5901413, 22.34986115], [69.59069824, 22.34986115], [69.59069824, 22.35013962], [69.5909729, 22.35013962], [69.5909729, 22.35042], [69.59152985, 22.35041618], [69.59152985, 22.35069466], [69.59208679, 22.35069466], [69.59208679, 22.35097313], [69.59263611, 22.35097122], [69.59263611, 22.35124969], [69.5929184, 22.35124969], [69.5929184, 22.35153008], [69.59348297, 22.35153008], [69.59348297, 22.35181046], [69.59402466, 22.35180473], [69.59402466, 22.35208321], [69.59430695, 22.35208321], [69.59430695, 22.35236168], [69.59486389, 22.35236168], [69.59486389, 22.35208321], [69.59541321, 22.35208321], [69.59541321, 22.35152817], [69.59570313, 22.35153008], [69.59570313, 22.35097122], [69.59597015, 22.35097313], [69.59597015, 22.35013962], [69.59625244, 22.35013962], [69.59625244, 22.34791946], [69.59707642, 22.34791946], [69.59707642, 22.34875107], [69.5973587, 22.34875107], [69.5973587, 22.34902954], [69.59764099, 22.34902763], [69.59764099, 22.34958267], [69.59819794, 22.34958267], [69.59819794, 22.34986115], [69.5984726, 22.34986115], [69.5984726, 22.35013962], [69.59874725, 22.35013962], [69.59874725, 22.35042], [69.59902954, 22.35041618], [69.59902954, 22.35069466], [69.5993042, 22.35069466], [69.5993042, 22.35041618], [69.59986115, 22.35042], [69.59986115, 22.34958267], [69.6001358, 22.34958267], [69.6001358, 22.34874916], [69.60041809, 22.34875107], [69.60041809, 22.3484726], [69.60069275, 22.3484726], [69.60069275, 22.34819412], [69.60097504, 22.34819412], [69.60097504, 22.34763908], [69.60124969, 22.3476429], [69.60124969, 22.3473587], [69.60151672, 22.3473587], [69.60151672, 22.34707832], [69.6020813, 22.34707832], [69.6020813, 22.3473587], [69.60236359, 22.3473587], [69.60236359, 22.34819412], [69.6020813, 22.34819412], [69.6020813, 22.3484726], [69.60180664, 22.3484726], [69.60180664, 22.34902954], [69.60151672, 22.34902954], [69.60151672, 22.34986115], [69.60124969, 22.34986115], [69.60124969, 22.35042], [69.60151672, 22.35042], [69.60151672, 22.35124969], [69.6020813, 22.35124969], [69.6020813, 22.35097122], [69.60236359, 22.35097313], [69.60236359, 22.35069466], [69.60375214, 22.35069466], [69.60375214, 22.35097313], [69.60457611, 22.35097122], [69.60457611, 22.35124969], [69.6048584, 22.35124969], [69.6048584, 22.35097122], [69.60514069, 22.35097313], [69.60514069, 22.35069466], [69.60541534, 22.35069466], [69.60541534, 22.34986115], [69.60569763, 22.34986115], [69.60569763, 22.34958267], [69.60597229, 22.34958267], [69.60597229, 22.34708405], [69.60541534, 22.34708405], [69.60541534, 22.3465271], [69.60597229, 22.34653091], [69.60597229, 22.34625053], [69.60624695, 22.34625053], [69.60624695, 22.34374809], [69.60597229, 22.34374809], [69.60597229, 22.34235954], [69.60569763, 22.34236145], [69.60569763, 22.3409729], [69.60597229, 22.3409729], [69.60597229, 22.34069443], [69.60624695, 22.34069443], [69.60624695, 22.33986092], [69.60652924, 22.33987045], [69.60652924, 22.33974075], [69.60652924, 22.33875084], [69.60679626, 22.33875084], [69.60679626, 22.33847046], [69.60735321, 22.33847046], [69.60735321, 22.33930969], [69.60708618, 22.33930969], [69.60708618, 22.34013939], [69.60692596, 22.34013939], [69.60679626, 22.34013939], [69.60679626, 22.34181023], [69.60652924, 22.34180832], [69.60652924, 22.34347153], [69.60679626, 22.34346962], [69.60679626, 22.34791946], [69.60708618, 22.34791946], [69.60708618, 22.34902954], [69.60735321, 22.34902954], [69.60735321, 22.34930992], [69.60901642, 22.34930992], [69.60901642, 22.34819031], [69.60930634, 22.34819412], [69.60930634, 22.34763908], [69.60958099, 22.3476429], [69.60958099, 22.34707832], [69.60986328, 22.34708405], [69.60986328, 22.34625053], [69.61013794, 22.34625053], [69.61013794, 22.34568024], [69.61042023, 22.34569359], [69.61042023, 22.34515953], [69.61042023, 22.34486198], [69.61069489, 22.34486198], [69.61069489, 22.34430504], [69.61096954, 22.34431076], [69.61096954, 22.34374809], [69.61125183, 22.34374809], [69.61125183, 22.34291077], [69.61152649, 22.34291649], [69.61152649, 22.34236145], [69.61180878, 22.34236145], [69.61180878, 22.34180832], [69.61207581, 22.34181023], [69.61207581, 22.34152985], [69.61235809, 22.34152985], [69.61235809, 22.34085846], [69.61235809, 22.34041405], [69.61207581, 22.34041977], [69.61207581, 22.33958054], [69.61180878, 22.33958244], [69.61180878, 22.33875084], [69.61152649, 22.33875084], [69.61152649, 22.33819008], [69.61125183, 22.33819389], [69.61125183, 22.33763885], [69.61096954, 22.33764076], [69.61096954, 22.33681107], [69.61068726, 22.33681107], [69.61068726, 22.33597183], [69.61042023, 22.33597374], [69.61042023, 22.33486176], [69.61013794, 22.33486176], [69.61013794, 22.33235931], [69.60986328, 22.33235931], [69.60986328, 22.33152962], [69.60958099, 22.33152962], [69.60958099, 22.33097076], [69.60930634, 22.33097267], [69.60930634, 22.3306942], [69.60902405, 22.3306942], [69.60902405, 22.33013725], [69.6084671, 22.33014107], [69.6084671, 22.32958031], [69.60819244, 22.32958412], [69.60819244, 22.32930565], [69.60791779, 22.32930946], [69.60791779, 22.32875061], [69.6076355, 22.32875061], [69.6076355, 22.32819366], [69.60708618, 22.32819366], [69.60708618, 22.32763863], [69.60679626, 22.32764053], [69.60679626, 22.32736015], [69.60652924, 22.32736206], [69.60652924, 22.32708359], [69.60624695, 22.32708359], [69.60624695, 22.32569313], [69.60680389, 22.32569313], [69.60680389, 22.3259716], [69.60708618, 22.3259697], [69.60708618, 22.32625008], [69.60736084, 22.32625008], [69.60736084, 22.32708359], [69.6076355, 22.32708359], [69.6076355, 22.32736015], [69.60791779, 22.32736015], [69.60791779, 22.32793045], [69.60819244, 22.32791519], [69.60819244, 22.32819366], [69.60847473, 22.32819366], [69.60847473, 22.32847214], [69.60874939, 22.32847023], [69.60874939, 22.32875061], [69.60901642, 22.32875061], [69.60901642, 22.32903099], [69.60930634, 22.32903099], [69.60930634, 22.32930946], [69.60958099, 22.32930946], [69.60958099, 22.33041954], [69.60986328, 22.33041573], [69.60986328, 22.3306942], [69.61013794, 22.33068085], [69.61013794, 22.33125114], [69.61042023, 22.33124733], [69.61042023, 22.33208275], [69.61068726, 22.33208084], [69.61068726, 22.3326416], [69.61096954, 22.3326416], [69.61096954, 22.33458328], [69.61125183, 22.33457947], [69.61125183, 22.3357029], [69.61152649, 22.3357029], [69.61152649, 22.33625031], [69.61180878, 22.33625031], [69.61180878, 22.33681107], [69.61208344, 22.33680534], [69.61208344, 22.33708382], [69.61235809, 22.33708191], [69.61235809, 22.33764076], [69.61264038, 22.33764076], [69.61264038, 22.33792114], [69.61319733, 22.33792114], [69.61319733, 22.33764076], [69.61402893, 22.33764076], [69.61402893, 22.33792114], [69.61429596, 22.33792114], [69.61429596, 22.33903122], [69.61458588, 22.3390274], [69.61458588, 22.33958244], [69.61486053, 22.33958054], [69.61486053, 22.34013939], [69.61513519, 22.34013939], [69.61513519, 22.34069443], [69.61541748, 22.34069443], [69.61541748, 22.3409729], [69.61569214, 22.3409729], [69.61569214, 22.34208298], [69.61541748, 22.34208298], [69.61541748, 22.34236145], [69.61569214, 22.34235954], [69.61569214, 22.34320068], [69.6159668, 22.34320068], [69.6159668, 22.34431076], [69.616539, 22.34431076], [69.616539, 22.34514046], [69.61680603, 22.34514046], [69.61680603, 22.34569359], [69.61708069, 22.34568024], [69.61708069, 22.34625053], [69.61736298, 22.34625053], [69.61736298, 22.34680939], [69.61708069, 22.34680557], [69.61708069, 22.34708405], [69.61695862, 22.34708023], [69.61680603, 22.34707832], [69.61680603, 22.3476429], [69.616539, 22.3476429], [69.616539, 22.34791946], [69.61680603, 22.34791756], [69.61680603, 22.34819412], [69.61708069, 22.34819412], [69.61708069, 22.3484726], [69.61736298, 22.3484726], [69.61736298, 22.34875107], [69.61763763, 22.34875107], [69.61763763, 22.34930992], [69.61791992, 22.34930992], [69.61791992, 22.35042], [69.61763763, 22.35041618], [69.61763763, 22.35097313], [69.61736298, 22.35097122], [69.61736298, 22.35153008], [69.61708069, 22.35152817], [69.61708069, 22.35208321], [69.61680603, 22.35208321], [69.61680603, 22.35458374], [69.61708069, 22.35457993], [69.61708069, 22.35542107], [69.61736298, 22.35541534], [69.61736298, 22.35569382], [69.61763763, 22.35569], [69.61763763, 22.35625076], [69.61791992, 22.35625076], [69.61791992, 22.35653114], [69.61818695, 22.35653114], [69.61818695, 22.35680962], [69.61875153, 22.3568058], [69.61875153, 22.35708237], [69.61985779, 22.35708046], [69.61985779, 22.35764122], [69.61958313, 22.35763741], [69.61958313, 22.35847282], [69.61930847, 22.35847092], [69.61930847, 22.35902977], [69.61902618, 22.35902977], [69.61902618, 22.35931015], [69.61846924, 22.35930634], [69.61846924, 22.3595829], [69.61819458, 22.3595829], [69.61819458, 22.35986137], [69.61791992, 22.35986137], [69.61791992, 22.36181068], [69.61763763, 22.36181068], [69.61763763, 22.36375046], [69.61736298, 22.36375046], [69.61736298, 22.36458206], [69.61708069, 22.36458015], [69.61708069, 22.36514091], [69.61680603, 22.36514091], [69.61680603, 22.36680984], [69.61708069, 22.36680984], [69.61708069, 22.36736107], [69.61736298, 22.36736107], [69.61736298, 22.36763954], [69.61763763, 22.36763954], [69.61763763, 22.36819458], [69.61791992, 22.36819458], [69.61791992, 22.36847305], [69.62014008, 22.36847305], [69.62014008, 22.36819458], [69.62069702, 22.36819458], [69.62069702, 22.3679142], [69.62152863, 22.36791992], [69.62152863, 22.36763954], [69.62180328, 22.36763954], [69.62180328, 22.36736107], [69.6220932, 22.36736107], [69.62208557, 22.3670826], [69.62264252, 22.36708069], [69.62264252, 22.36736107], [69.62291718, 22.36736107], [69.62291718, 22.36708069], [69.62347412, 22.3670826], [69.62347412, 22.36652756], [69.62374878, 22.36652946], [69.62374878, 22.36486053], [69.62403107, 22.36486053], [69.62403107, 22.36458015], [69.62430573, 22.36458206], [69.62430573, 22.3643055], [69.62486267, 22.36431122], [69.62486267, 22.36404037], [69.62568665, 22.36404037], [69.62568665, 22.36375046], [69.62680817, 22.36375046], [69.62680817, 22.36347008], [69.62763977, 22.36347389], [69.62763977, 22.36319351], [69.62791443, 22.36319351], [69.62791443, 22.36291695], [69.62847137, 22.36291695], [69.62847137, 22.36319351], [69.62958527, 22.36319351], [69.62958527, 22.36291695], [69.63014221, 22.36292076], [69.63014221, 22.36264038], [69.63069153, 22.36264038], [69.63069153, 22.36236191], [69.63097382, 22.36236382], [69.63097382, 22.36208344], [69.63153076, 22.36208344], [69.63153076, 22.36180496], [69.63208008, 22.36181068], [69.63208008, 22.3615303], [69.63263702, 22.3615303], [69.63263702, 22.36125183], [69.63318634, 22.36125183], [69.63318634, 22.36096954], [69.63346863, 22.36096954], [69.63346863, 22.36069489], [69.63402557, 22.36069489], [69.63402557, 22.36041641], [69.63430786, 22.36042023], [69.63430786, 22.36014175], [69.63485718, 22.36014175], [69.63485718, 22.35986137], [69.63513947, 22.35986137], [69.63513947, 22.35930634], [69.63540649, 22.35931015], [69.63540649, 22.35902977], [69.63597107, 22.35902977], [69.63597107, 22.35874748], [69.63625336, 22.35874748], [69.63625336, 22.35847092], [69.63903046, 22.35847092], [69.63903046, 22.35874748], [69.63957977, 22.35874748], [69.63957977, 22.35902977], [69.64068604, 22.35902977], [69.64068604, 22.35874748], [69.64125061, 22.35874748], [69.64125061, 22.35847092], [69.64152527, 22.35847282], [69.64152527, 22.35819435], [69.64180756, 22.35819435], [69.64180756, 22.35763741], [69.64208221, 22.35764122], [69.64208221, 22.35736084], [69.64235687, 22.35736084], [69.64235687, 22.35708046], [69.64263916, 22.35708237], [69.64263916, 22.35652733], [69.64290619, 22.35653114], [69.64290619, 22.35625076], [69.64319611, 22.35625076], [69.64319611, 22.35597038], [69.64457703, 22.35597038], [69.64457703, 22.35653114], [69.64485931, 22.35653114], [69.64485931, 22.35680962], [69.6451416, 22.35680962], [69.6451416, 22.35736084], [69.64569092, 22.35736084], [69.64569092, 22.35791588], [69.64624786, 22.35791588], [69.64624786, 22.35736084], [69.64679718, 22.35736084], [69.64679718, 22.35764122], [69.64763641, 22.35763741], [69.64763641, 22.35819435], [69.64930725, 22.35819435], [69.64930725, 22.35847282], [69.65125275, 22.35847092], [69.65125275, 22.35874748], [69.65291595, 22.35874748], [69.65291595, 22.35902977], [69.65458679, 22.35902977], [69.65458679, 22.3595829], [69.65486145, 22.3595829], [69.65486145, 22.35986137], [69.65569305, 22.35986137], [69.65569305, 22.36014175], [69.65598297, 22.36014175], [69.65598297, 22.36042023], [69.65651703, 22.36042023], [69.65651703, 22.36181068], [69.65680695, 22.36181068], [69.65680695, 22.36375046], [69.6570816, 22.36375046], [69.6570816, 22.36458206], [69.65680695, 22.36458015], [69.65680695, 22.36486053], [69.65651703, 22.36486053], [69.65651703, 22.36514091], [69.65625, 22.36514091], [69.65625, 22.36541939], [69.65598297, 22.36541939], [69.65598297, 22.36625099], [69.65569305, 22.36625099], [69.65569305, 22.36736107], [69.6554184, 22.36736107], [69.6554184, 22.3698616], [69.65598297, 22.36985016], [69.65598297, 22.37013817], [69.65625, 22.37013817], [69.65625, 22.37042046], [69.65651703, 22.37042046], [69.65651703, 22.37070084], [69.65680695, 22.37070084], [69.65680695, 22.37181091], [69.6570816, 22.37181091], [69.6570816, 22.37430954], [69.65680695, 22.37430954], [69.65680695, 22.37486267], [69.65652466, 22.37486267], [69.65652466, 22.37569427], [69.65625, 22.37569046], [69.65625, 22.37625122], [69.65598297, 22.37625122], [69.65598297, 22.37681007], [69.65625, 22.37680626], [69.65625, 22.37708282], [69.65651703, 22.37708282], [69.65651703, 22.37763977], [69.65680695, 22.37763977], [69.65680695, 22.37792015], [69.6570816, 22.37791634], [69.6570816, 22.37819481], [69.65763855, 22.37819481], [69.65763855, 22.37847137], [69.65791321, 22.37846947], [69.65791321, 22.37874985], [69.65846252, 22.37874985], [69.65846252, 22.37903976], [69.65875244, 22.37902832], [69.65875244, 22.37930489], [69.6590271, 22.37930107], [69.6590271, 22.38264084], [69.65930176, 22.38263893], [69.65930939, 22.38319397], [69.65958405, 22.38319397], [69.65958405, 22.38347244], [69.6598587, 22.38347054], [69.6598587, 22.38402748], [69.66014099, 22.38402748], [69.66014099, 22.38458252], [69.66041565, 22.38458252], [69.66042328, 22.38485909], [69.66014099, 22.38485909], [69.66014099, 22.38792038], [69.66069794, 22.38792038], [69.66069794, 22.3882103], [69.66124725, 22.38819504], [69.66124725, 22.3884716], [69.6626358, 22.3884716], [69.6626358, 22.38875008], [69.66319275, 22.38875008], [69.66319275, 22.38903046], [69.66347504, 22.38902855], [69.66347504, 22.38958359], [69.66374969, 22.38957977], [69.66374969, 22.39042091], [69.66401672, 22.39042091], [69.66401672, 22.39375114], [69.66485596, 22.39375114], [69.66485596, 22.39347076], [69.6654129, 22.39347267], [69.6654129, 22.3931942], [69.66625214, 22.3931942], [69.66625214, 22.39291573], [69.66680908, 22.39291954], [69.66680908, 22.39264107], [69.6673584, 22.39264107], [69.6673584, 22.39291954], [69.66791534, 22.39291573], [69.66791534, 22.3931942], [69.66847229, 22.3931942], [69.66847229, 22.39347267], [69.66874695, 22.39347076], [69.66874695, 22.39375114], [69.66930389, 22.39374924], [69.66930389, 22.39402771], [69.66958618, 22.39402008], [69.66958618, 22.39431], [69.66986084, 22.39430428], [69.66986084, 22.39458275], [69.6701355, 22.39458275], [69.6701355, 22.39486122], [69.67069244, 22.39486122], [69.67069244, 22.39513969], [69.6709671, 22.39513969], [69.6709671, 22.39542007], [69.67124939, 22.39542007], [69.67124939, 22.39513969], [69.67151642, 22.39513969], [69.67151642, 22.39486122], [69.67180634, 22.39486122], [69.67180634, 22.39458084], [69.67208099, 22.39458084], [69.67208099, 22.39486122], [69.67236328, 22.39486122], [69.67236328, 22.39458084], [69.67263794, 22.39458275], [69.67263794, 22.39430428], [69.67292023, 22.39431], [69.67292023, 22.39402008], [69.67318726, 22.39402008], [69.67318726, 22.39431], [69.67375183, 22.39430428], [69.67375183, 22.39458275], [69.67430878, 22.39458084], [69.67430878, 22.39486122], [69.67514038, 22.39486122], [69.67514038, 22.39458084], [69.67652893, 22.39458275], [69.67652893, 22.39430428], [69.67708588, 22.39431], [69.67708588, 22.39402008], [69.67791748, 22.39402008], [69.67791748, 22.39431], [69.67930603, 22.39430428], [69.67930603, 22.39458275], [69.68013763, 22.39458084], [69.68013763, 22.39486122], [69.68041992, 22.39486122], [69.68041992, 22.39513969], [69.68125153, 22.39513969], [69.68125153, 22.39542007], [69.68681335, 22.39542007], [69.68681335, 22.39513969], [69.68875122, 22.39513969], [69.68875122, 22.39486122], [69.69346619, 22.39486122], [69.69346619, 22.39513969], [69.69568634, 22.39513969], [69.69568634, 22.39542007], [69.69736481, 22.39541626], [69.69736481, 22.39569473], [69.69902802, 22.39569473], [69.69902802, 22.3959713], [69.69930267, 22.39596939], [69.69930267, 22.39653015], [69.69958496, 22.39652634], [69.69958496, 22.39708328], [69.69985962, 22.39707947], [69.69985962, 22.39763832], [69.70014191, 22.39763641], [69.70014191, 22.39847183], [69.69958496, 22.39847183], [69.69958496, 22.3979187], [69.69930267, 22.39792061], [69.69930267, 22.39819908], [69.69902802, 22.39819527], [69.69902802, 22.39847183], [69.69847107, 22.39846992], [69.69847107, 22.3987484], [69.69819641, 22.3987484], [69.69819641, 22.39903069], [69.69791412, 22.39902687], [69.69791412, 22.4034729], [69.69763947, 22.4034729], [69.69763947, 22.40902519], [69.69736481, 22.40902519], [69.69736481, 22.40958405], [69.69708252, 22.40958405], [69.69708252, 22.4109726], [69.69680786, 22.41097069], [69.69680786, 22.41152954], [69.6965332, 22.41152954], [69.6965332, 22.41208839], [69.69625092, 22.41208839], [69.69625092, 22.41235924], [69.69596863, 22.41235924], [69.69596863, 22.41263771], [69.69568634, 22.41263771], [69.69568634, 22.4137516], [69.69513702, 22.4137516], [69.69513702, 22.41403008], [69.69486237, 22.41402817], [69.69486237, 22.41458321], [69.69457245, 22.41457939], [69.69457245, 22.41570282], [69.69430542, 22.41569519], [69.69430542, 22.41597366], [69.69403076, 22.41597176], [69.69403076, 22.41625023], [69.69374847, 22.41625023], [69.69374847, 22.4168129], [69.69403076, 22.41680527], [69.69403076, 22.41708374], [69.69374847, 22.41708183], [69.69374847, 22.41764069], [69.69346619, 22.41764069], [69.69346619, 22.41792107], [69.69319153, 22.41792107], [69.69319153, 22.41875076], [69.69291687, 22.41875076], [69.69291687, 22.41958427], [69.69264221, 22.41958046], [69.69264221, 22.41986084], [69.69235992, 22.41986084], [69.69235992, 22.42014122], [69.69264221, 22.42014122], [69.69264221, 22.42041969], [69.69235992, 22.42041969], [69.69235992, 22.42124939], [69.69264221, 22.42124939], [69.69264221, 22.42152977], [69.69291687, 22.42152977], [69.69291687, 22.42181015], [69.69347382, 22.42180634], [69.69347382, 22.4220829], [69.69374847, 22.42208099], [69.69374847, 22.42263985], [69.69403076, 22.42263794], [69.69403076, 22.42319489], [69.69430542, 22.42319489], [69.69430542, 22.42374992], [69.69457245, 22.42374992], [69.69457245, 22.42432022], [69.69486237, 22.42430496], [69.69486237, 22.42458344], [69.69513702, 22.42457962], [69.69513702, 22.42514038], [69.69541931, 22.42514038], [69.69541931, 22.42569351], [69.69568634, 22.4256897], [69.69568634, 22.42624855], [69.69596863, 22.42624855], [69.69596863, 22.42680931], [69.69625092, 22.42680931], [69.69625092, 22.42735863], [69.6965332, 22.42735863], [69.6965332, 22.42764282], [69.69680786, 22.42764091], [69.69680786, 22.42819405], [69.69708252, 22.42819405], [69.69708252, 22.42847252], [69.69735718, 22.42847252], [69.69735718, 22.4287529], [69.69763184, 22.4287529], [69.69763184, 22.42902946], [69.69790649, 22.42902946], [69.69790649, 22.42930984], [69.69847107, 22.42930603], [69.69847107, 22.4295826], [69.69875336, 22.4295826], [69.69875336, 22.43013954], [69.69902802, 22.43013191], [69.69902802, 22.43041992], [69.69930267, 22.43041611], [69.69930267, 22.43097305], [69.69957733, 22.43097115], [69.69957733, 22.43124962], [69.69985962, 22.43124962], [69.69985962, 22.43153], [69.70014191, 22.43152809], [69.70014191, 22.43208313], [69.70041656, 22.43208313], [69.70041656, 22.4323616], [69.70069885, 22.4323597], [69.70069885, 22.43264008], [69.70096588, 22.43264008], [69.70096588, 22.43292046], [69.70124817, 22.43291664], [69.70124817, 22.43319321], [69.70153046, 22.43319321], [69.70153046, 22.43347168], [69.70180511, 22.43347168], [69.70180511, 22.43375015], [69.70207977, 22.43375015], [69.70207977, 22.43403053], [69.70181274, 22.43403053], [69.70181274, 22.43431091], [69.70153046, 22.43430519], [69.70153046, 22.43458366], [69.70124817, 22.43457985], [69.70124817, 22.43514061], [69.70096588, 22.43514061], [69.70096588, 22.43542099], [69.70069122, 22.43541527], [69.70069122, 22.43569374], [69.70041656, 22.43569374], [69.70041656, 22.43597221], [69.70014191, 22.43597031], [69.70014191, 22.43653107], [69.69985962, 22.43652725], [69.69985962, 22.4370842], [69.69957733, 22.43708038], [69.69957733, 22.43764114], [69.69930267, 22.43763733], [69.69930267, 22.43819427], [69.69902802, 22.43819427], [69.69902802, 22.43847275], [69.69875336, 22.43847084], [69.69875336, 22.43902969], [69.69847107, 22.43902969], [69.69847107, 22.43958282], [69.69819641, 22.43958092], [69.69819641, 22.44014168], [69.69791412, 22.44014168], [69.69791412, 22.44069481], [69.69763947, 22.44069481], [69.69763947, 22.44096947], [69.69736481, 22.44096947], [69.69736481, 22.44236183], [69.69763184, 22.44236183], [69.69763184, 22.4426403], [69.69790649, 22.4426403], [69.69790649, 22.44292068], [69.69708252, 22.44292068], [69.69708252, 22.44320107], [69.68013763, 22.44320107], [69.68013763, 22.44292068], [69.67930603, 22.44292068], [69.67930603, 22.4426403], [69.67903137, 22.4426403], [69.67903137, 22.44236183], [69.67874908, 22.44236183], [69.67874908, 22.44208336], [69.67847443, 22.44208336], [69.67847443, 22.44180489], [69.67819214, 22.44180489], [69.67819214, 22.44125175], [69.67791748, 22.44125175], [69.67791748, 22.44068909], [69.67763519, 22.44069481], [69.67763519, 22.43958282], [69.67652893, 22.43958282], [69.67652893, 22.43930626], [69.67458344, 22.43930626], [69.67458344, 22.43985939], [69.67430878, 22.43985939], [69.67430878, 22.44014168], [69.67402649, 22.44014168], [69.67402649, 22.44042015], [69.67318726, 22.44042015], [69.67318726, 22.44014168], [69.67292023, 22.44014168], [69.67292023, 22.43958092], [69.67236328, 22.43958282], [69.67236328, 22.43930626], [69.67180634, 22.43930626], [69.67180634, 22.43958282], [69.67208099, 22.43958282], [69.67208099, 22.43985939], [69.67180634, 22.43985939], [69.67180634, 22.44042015], [69.67151642, 22.44042015], [69.67151642, 22.44125175], [69.67263794, 22.44125175], [69.67263794, 22.44153023], [69.67375183, 22.44152832], [69.67375183, 22.44180489], [69.67346954, 22.44180489], [69.67346954, 22.44236183], [69.67318726, 22.44236183], [69.67318726, 22.44292068], [69.67292023, 22.44291687], [69.67292023, 22.44347382], [69.67263794, 22.44347191], [69.67263794, 22.44403076], [69.67236328, 22.44402695], [69.67236328, 22.44458389], [69.67208099, 22.44458389], [69.67208099, 22.44513893], [69.67180634, 22.44512939], [69.67180634, 22.44680977], [69.67152405, 22.44680405], [69.67152405, 22.44958305], [69.67180634, 22.44958115], [69.67180634, 22.45070076], [69.67208099, 22.45070076], [69.67208099, 22.45042038], [69.67263794, 22.45042038], [69.67263794, 22.45013809], [69.67318726, 22.45013809], [69.67318726, 22.44985962], [69.67346954, 22.44986153], [69.67346954, 22.44902611], [69.67318726, 22.44902992], [69.67318726, 22.44847107], [69.67292023, 22.44847298], [69.67292023, 22.4481945], [69.67263794, 22.44820023], [69.67263794, 22.44512939], [69.67292023, 22.44513893], [69.67292023, 22.44486046], [69.67318726, 22.44486046], [69.67318726, 22.44431114], [69.67346191, 22.44431114], [69.67346191, 22.44403076], [69.67375183, 22.44403076], [69.67375183, 22.44320107], [69.67402649, 22.44320107], [69.67402649, 22.4426403], [69.67430878, 22.4426403], [69.67430878, 22.44236183], [69.67485809, 22.44236183], [69.67485809, 22.44208336], [69.67541504, 22.44208336], [69.67541504, 22.44236183], [69.67597198, 22.44236183], [69.67597198, 22.4426403], [69.67652893, 22.4426403], [69.67652893, 22.44292068], [69.67679596, 22.44292068], [69.67679596, 22.44320107], [69.67736053, 22.44319534], [69.67736053, 22.44347382], [69.67819214, 22.44347191], [69.67819214, 22.44375038], [69.67930603, 22.44375038], [69.67930603, 22.44403076], [69.68235779, 22.44403076], [69.68235779, 22.44431114], [69.68708038, 22.44430542], [69.68708038, 22.44458389], [69.68763733, 22.44458389], [69.68763733, 22.44430542], [69.68819427, 22.44430542], [69.68819427, 22.44458389], [69.68846893, 22.44458389], [69.68846893, 22.44513893], [69.68818665, 22.44512939], [69.68818665, 22.44542122], [69.68791962, 22.44542122], [69.68791962, 22.44652939], [69.68763733, 22.44652748], [69.68763733, 22.44708252], [69.68791962, 22.44708061], [69.68791962, 22.44736099], [69.68818665, 22.44736099], [69.68818665, 22.44763947], [69.68875885, 22.44763947], [69.68875885, 22.44820023], [69.68902588, 22.4481945], [69.68902588, 22.44847298], [69.68930817, 22.44847107], [69.68930817, 22.44902992], [69.68958282, 22.44902611], [69.68958282, 22.44930077], [69.68985748, 22.44930649], [69.68985748, 22.44958305], [69.69013977, 22.44958115], [69.69013977, 22.45013809], [69.6904068, 22.45013809], [69.6904068, 22.45042038], [69.69069672, 22.45041656], [69.69069672, 22.4509716], [69.69097137, 22.4509697], [69.69097137, 22.45126152], [69.69152832, 22.45126152], [69.69152832, 22.45153046], [69.69180298, 22.45153046], [69.69180298, 22.45181084], [69.69235992, 22.45180511], [69.69235992, 22.45208359], [69.69291687, 22.45207977], [69.69291687, 22.45235825], [69.69346619, 22.45235825], [69.69346619, 22.45264053], [69.69374847, 22.45264053], [69.69374847, 22.45292091], [69.69430542, 22.4529171], [69.69430542, 22.45319366], [69.69541931, 22.45319366], [69.69541931, 22.45347023], [69.69652557, 22.45347023], [69.69652557, 22.45375061], [69.69735718, 22.45375061], [69.69735718, 22.45402908], [69.69819641, 22.45402718], [69.69819641, 22.45458412], [69.69847107, 22.45458031], [69.69847107, 22.45486259], [69.69875336, 22.45486259], [69.69875336, 22.45514107], [69.69902802, 22.45513916], [69.69902802, 22.4556942], [69.69930267, 22.4556942], [69.69930267, 22.45597267], [69.69957733, 22.45597267], [69.69957733, 22.45625114], [69.69985962, 22.45625114], [69.69985962, 22.45652962], [69.70014191, 22.45652962], [69.70014191, 22.45681], [69.70041656, 22.45681], [69.70041656, 22.45736122], [69.70096588, 22.45736122], [69.70096588, 22.45625114], [69.70124817, 22.45625114], [69.70124817, 22.45541954], [69.70096588, 22.45541954], [69.70096588, 22.45486259], [69.70069122, 22.45486259], [69.70069122, 22.45458412], [69.70014191, 22.45458412], [69.70014191, 22.45347023], [69.70041656, 22.45347023], [69.70041656, 22.45236206], [69.70069122, 22.45235825], [69.70069122, 22.45153046], [69.70096588, 22.45153046], [69.70096588, 22.45042038], [69.70069885, 22.45042038], [69.70069885, 22.44958115], [69.70041656, 22.44958305], [69.70041656, 22.44874954], [69.69985962, 22.44874954], [69.69985962, 22.44791985], [69.70014191, 22.44791985], [69.70014191, 22.44763947], [69.70041656, 22.44763947], [69.70041656, 22.44708061], [69.70347595, 22.44708061], [69.70347595, 22.44736099], [69.70402527, 22.44736099], [69.70402527, 22.44763947], [69.70430756, 22.44763947], [69.70430756, 22.44820023], [69.70458221, 22.44820023], [69.70458221, 22.44874954], [69.70485687, 22.44874954], [69.70485687, 22.44902992], [69.70513916, 22.44902611], [69.70513916, 22.44958305], [69.70540619, 22.44958115], [69.70540619, 22.45013809], [69.70569611, 22.45013809], [69.70569611, 22.45126152], [69.70597076, 22.45124817], [69.70597076, 22.45208359], [69.70625305, 22.45207977], [69.70625305, 22.45235825], [69.70652771, 22.45235825], [69.70652771, 22.45292091], [69.70680237, 22.4529171], [69.70680237, 22.45319366], [69.70708466, 22.45319366], [69.70708466, 22.45347023], [69.70735931, 22.45346832], [69.70735931, 22.45402908], [69.7076416, 22.45402718], [69.7076416, 22.45458412], [69.70791626, 22.45458031], [69.70791626, 22.45486259], [69.70819092, 22.45486259], [69.70819092, 22.45514107], [69.70847321, 22.45514107], [69.70847321, 22.45541954], [69.70874786, 22.45541573], [69.70874786, 22.4556942], [69.70903015, 22.4556942], [69.70903015, 22.45597267], [69.70929718, 22.45597267], [69.70929718, 22.45625114], [69.7095871, 22.45625114], [69.7095871, 22.45681], [69.70986176, 22.45680618], [69.70986176, 22.45708275], [69.7104187, 22.4570694], [69.7104187, 22.45736122], [69.71069336, 22.45736122], [69.71069336, 22.45763969], [69.71098328, 22.45763969], [69.71098328, 22.45792007], [69.71152496, 22.45791626], [69.71152496, 22.45819473], [69.71180725, 22.45819473], [69.71180725, 22.4584713], [69.71208191, 22.45846939], [69.71208191, 22.45874977], [69.71235657, 22.45874977], [69.71235657, 22.45903015], [69.71291351, 22.45902824], [69.71291351, 22.45930481], [69.71347046, 22.45930481], [69.71347046, 22.45958328], [69.7140274, 22.45958328], [69.7140274, 22.45986176], [69.71430206, 22.45985985], [69.71430206, 22.46014023], [69.71485901, 22.46014023], [69.71485901, 22.46042061], [69.71541595, 22.46042061], [69.71541595, 22.46070099], [69.71652985, 22.46069527], [69.71652985, 22.46097183], [69.71736145, 22.46096992], [69.71736145, 22.46125031], [69.71848297, 22.46125031], [69.71848297, 22.46153069], [69.7195816, 22.46153069], [69.7195816, 22.46181107], [69.72041321, 22.46180534], [69.72041321, 22.46208382], [69.7206955, 22.46208382], [69.7206955, 22.46236038], [69.72097015, 22.46236038], [69.72097015, 22.46264076], [69.7215271, 22.46264076], [69.7215271, 22.46292114], [69.72207642, 22.46292114], [69.72207642, 22.46319962], [69.7223587, 22.46319962], [69.7223587, 22.46375084], [69.72264099, 22.46375084], [69.72264099, 22.46458244], [69.7251358, 22.46458054], [69.7251358, 22.46541977], [69.72541809, 22.46541977], [69.72541809, 22.46681023], [69.72458649, 22.46680641], [69.72458649, 22.46708107], [69.72374725, 22.46708107], [69.72374725, 22.46736145], [69.72292328, 22.46736145], [69.72292328, 22.46764183], [69.72264099, 22.46763992], [69.72264099, 22.46846962], [69.7223587, 22.46846962], [69.7223587, 22.46875191], [69.72264099, 22.46875191], [69.72264099, 22.46903038], [69.72319794, 22.46902847], [69.72319794, 22.46930504], [69.7234726, 22.46930504], [69.7234726, 22.46958351], [69.72402954, 22.46958351], [69.72402954, 22.46986389], [69.72458649, 22.46986008], [69.72458649, 22.47042084], [69.7251358, 22.47041702], [69.7251358, 22.47069359], [69.72541809, 22.47069359], [69.72541809, 22.47097206], [69.72569275, 22.47097015], [69.72569275, 22.47125053], [69.72598267, 22.47125053], [69.72598267, 22.47153091], [69.72624969, 22.47153091], [69.72624969, 22.47180939], [69.72652435, 22.47180557], [69.72652435, 22.47208595], [69.72680664, 22.47208023], [69.72680664, 22.47236061], [69.7270813, 22.47236061], [69.7270813, 22.47264099], [69.72736359, 22.47263908], [69.72736359, 22.47319412], [69.7279129, 22.47319412], [69.7279129, 22.4734726], [69.72820282, 22.47347069], [69.72820282, 22.47375107], [69.72902679, 22.47375107], [69.72902679, 22.47402954], [69.72930908, 22.47402954], [69.72930908, 22.47375107], [69.72957611, 22.47375107], [69.72957611, 22.47402954], [69.73014069, 22.47402954], [69.73014069, 22.47375107], [69.73069763, 22.47375107], [69.73069763, 22.47347069], [69.73097229, 22.4734726], [69.73097229, 22.47319412], [69.73124695, 22.47319412], [69.73124695, 22.47236061], [69.73152924, 22.47236061], [69.73152924, 22.47208023], [69.73180389, 22.47208595], [69.73180389, 22.47180557], [69.73208618, 22.47180939], [69.73208618, 22.47153091], [69.73236084, 22.47153091], [69.73236084, 22.47125053], [69.73264313, 22.47125053], [69.7326355, 22.47069359], [69.73291779, 22.47069359], [69.73291779, 22.47041702], [69.73374176, 22.47042084], [69.73374176, 22.47014046], [69.73401642, 22.47014046], [69.73401642, 22.46986008], [69.73430634, 22.46986389], [69.73430634, 22.46958351], [69.73486328, 22.46958351], [69.73486328, 22.46930504], [69.73542023, 22.46930504], [69.73542023, 22.46902847], [69.73568726, 22.46903038], [69.73568726, 22.46875191], [69.73596954, 22.46875191], [69.73596954, 22.4679203], [69.73625183, 22.4679203], [69.73625183, 22.46707916], [69.73652649, 22.46708107], [69.73652649, 22.46625137], [69.73680878, 22.46625137], [69.73680878, 22.4659729], [69.73708344, 22.4659729], [69.73708344, 22.46569443], [69.73735809, 22.46569443], [69.73735809, 22.46541595], [69.73764038, 22.46541977], [69.73764038, 22.46458054], [69.73791504, 22.46458244], [69.73791504, 22.46347237], [69.73819733, 22.46347237], [69.73819733, 22.46319389], [69.73847198, 22.46319962], [69.73847198, 22.46264076], [69.73874664, 22.46264076], [69.73874664, 22.46153069], [69.73902893, 22.46153069], [69.73902893, 22.46070099], [69.73929596, 22.46070099], [69.73929596, 22.46042061], [69.73958588, 22.46042061], [69.73958588, 22.45957947], [69.73986053, 22.45958328], [69.73986053, 22.45930481], [69.74013519, 22.45930481], [69.74013519, 22.45902824], [69.74041748, 22.45903015], [69.74041748, 22.45819283], [69.74069214, 22.45819473], [69.74069214, 22.45736122], [69.74085999, 22.45736122], [69.74097443, 22.45736122], [69.7409668, 22.45486259], [69.74069214, 22.45486259], [69.74069214, 22.4529171], [69.74041748, 22.45292091], [69.74041748, 22.45264053], [69.74014282, 22.45264053], [69.74014282, 22.44902992], [69.73986816, 22.44902992], [69.73986816, 22.44847107], [69.73764038, 22.44847298], [69.73764038, 22.4481945], [69.73735809, 22.44820023], [69.73735809, 22.44791985], [69.73764038, 22.44791985], [69.73764038, 22.44763947], [69.73792267, 22.44763947], [69.73791504, 22.44736099], [69.73819733, 22.44736099], [69.73819733, 22.44652939], [69.73847198, 22.44652939], [69.73847198, 22.44597054], [69.73819733, 22.44597244], [69.73819733, 22.44569588], [69.73791504, 22.44569588], [69.73791504, 22.4454174], [69.73735809, 22.44542122], [69.73735809, 22.44512939], [69.73708344, 22.44513893], [69.73708344, 22.44486046], [69.73652649, 22.44486046], [69.73652649, 22.44458008], [69.73542023, 22.44458389], [69.73542023, 22.44430542], [69.73486328, 22.44431114], [69.73486328, 22.44375038], [69.73513794, 22.44375038], [69.73513794, 22.44347191], [69.73795319, 22.44347382], [69.73819733, 22.44347382], [69.73819733, 22.44319534], [69.73874664, 22.44320107], [69.73874664, 22.44292068], [69.73929596, 22.44292068], [69.73929596, 22.44096947], [69.73958588, 22.44096947], [69.73958588, 22.44014168], [69.74069214, 22.44014168], [69.74069214, 22.43985939], [69.74153137, 22.43985939], [69.74153137, 22.43958282], [69.74236298, 22.43958282], [69.74236298, 22.43930626], [69.74263763, 22.43931961], [69.74263763, 22.43708038], [69.74375153, 22.4370842], [69.74375153, 22.43652725], [69.74402618, 22.43653107], [69.74402618, 22.43625832], [69.74430847, 22.43625832], [69.74430847, 22.43542099], [69.74458313, 22.43542099], [69.74458313, 22.43514061], [69.74485779, 22.43514061], [69.74485779, 22.43486023], [69.74514008, 22.43486023], [69.74514008, 22.43457985], [69.74569702, 22.43458366], [69.74569702, 22.43430519], [69.74597168, 22.43431091], [69.74597168, 22.43375015], [69.74624634, 22.43375015], [69.74624634, 22.43264008], [69.74597168, 22.43264008], [69.74597168, 22.4323597], [69.74569702, 22.4323616], [69.74569702, 22.43180466], [69.74514008, 22.43180466], [69.74514008, 22.43152809], [69.74485779, 22.43153], [69.74485779, 22.43124962], [69.74458313, 22.43124962], [69.74458313, 22.43069267], [69.74485779, 22.43069458], [69.74485779, 22.43041611], [69.74569702, 22.43041992], [69.74569702, 22.42986107], [69.74597168, 22.42986107], [69.74597168, 22.42930984], [69.74624634, 22.42930984], [69.74624634, 22.42902946], [69.74680328, 22.42902946], [69.74680328, 22.42930984], [69.74764252, 22.42930603], [69.74764252, 22.4295826], [69.74819183, 22.4295826], [69.74819183, 22.42986107], [69.74874878, 22.42986107], [69.74874878, 22.43013954], [69.74903107, 22.43013954], [69.74903107, 22.42986107], [69.74931335, 22.42986107], [69.74930573, 22.42902756], [69.74958038, 22.42902946], [69.74958038, 22.4287529], [69.74986267, 22.4287529], [69.74986267, 22.42819023], [69.75013733, 22.42819405], [69.75013733, 22.42791748], [69.75041962, 22.42791939], [69.75041962, 22.42764282], [69.75068665, 22.42764282], [69.75068665, 22.42735863], [69.75263977, 22.42735863], [69.75263977, 22.42708969], [69.75319672, 22.42708969], [69.75319672, 22.42680931], [69.75347137, 22.42680931], [69.75347137, 22.42653084], [69.75402832, 22.42653084], [69.75402832, 22.42624855], [69.75430298, 22.42624855], [69.75430298, 22.42596817], [69.75514221, 22.42596817], [69.75514221, 22.42624855], [69.75569153, 22.42624855], [69.75569153, 22.42653084], [69.75596619, 22.42653084], [69.75596619, 22.42735863], [69.75569153, 22.42735863], [69.75569153, 22.43013954], [69.75541687, 22.43013954], [69.75541687, 22.43180466], [69.75569153, 22.43180466], [69.75569153, 22.43208313], [69.75597382, 22.43208313], [69.75597382, 22.43347168], [69.75624847, 22.43347168], [69.75624847, 22.43458366], [69.75653076, 22.43458366], [69.75653076, 22.43569374], [69.75681305, 22.43568993], [69.75681305, 22.43680954], [69.75708008, 22.43680954], [69.75708008, 22.43764114], [69.75736237, 22.43764114], [69.75736237, 22.43791962], [69.75763702, 22.43791962], [69.75763702, 22.43931961], [69.75791168, 22.43931961], [69.75791168, 22.44042015], [69.75818634, 22.44042015], [69.75818634, 22.44153023], [69.75875092, 22.44152832], [69.75875092, 22.44180489], [69.75902557, 22.44180489], [69.75902557, 22.44152832], [69.75958252, 22.44153023], [69.75958252, 22.44125175], [69.75985718, 22.44125175], [69.75985718, 22.44096947], [69.76013947, 22.44096947], [69.76013947, 22.44069481], [69.76041412, 22.44069481], [69.76041412, 22.44041634], [69.76069641, 22.44042015], [69.76069641, 22.43985939], [69.76097107, 22.43985939], [69.76097107, 22.43902969], [69.76125336, 22.43902969], [69.76125336, 22.43764114], [69.76152802, 22.43764114], [69.76152802, 22.43597031], [69.76180267, 22.43597221], [69.76180267, 22.43263817], [69.76207733, 22.43264008], [69.76207733, 22.43208122], [69.76235962, 22.43208313], [69.76235962, 22.43180466], [69.76264191, 22.43180466], [69.76264191, 22.43152809], [69.76291656, 22.43153], [69.76291656, 22.43124962], [69.76319122, 22.43124962], [69.76319122, 22.43097115], [69.76347351, 22.43097305], [69.76347351, 22.43069458], [69.76374817, 22.43069458], [69.76374817, 22.43041611], [69.76403809, 22.43041992], [69.76403809, 22.43013191], [69.76430511, 22.43013954], [69.76430511, 22.42986107], [69.76457977, 22.42986107], [69.76457977, 22.4295826], [69.76486206, 22.4295826], [69.76486206, 22.42930603], [69.76513672, 22.42930984], [69.76513672, 22.42902946], [69.76568604, 22.42902946], [69.76568604, 22.4287529], [69.76597595, 22.4287529], [69.76597595, 22.42847252], [69.76625061, 22.42847252], [69.76625061, 22.42791748], [69.7665329, 22.42791939], [69.7665329, 22.42764282], [69.76680756, 22.42764282], [69.76680756, 22.42735863], [69.76708221, 22.42735863], [69.76708221, 22.42708969], [69.76735687, 22.42708969], [69.76735687, 22.42680931], [69.76819611, 22.42680931], [69.76819611, 22.42653084], [69.76847076, 22.42653084], [69.76847076, 22.42624855], [69.76875305, 22.42624855], [69.76875305, 22.42596817], [69.76930237, 22.42597008], [69.76930237, 22.42569351], [69.76958466, 22.42569351], [69.76958466, 22.42541885], [69.76985168, 22.42542076], [69.76985168, 22.42514038], [69.77041626, 22.42514038], [69.77041626, 22.42485809], [69.77069092, 22.42486191], [69.77069092, 22.42458344], [69.77097321, 22.42458344], [69.77097321, 22.42430496], [69.77153015, 22.42432022], [69.77153015, 22.4240303], [69.77179718, 22.4240303], [69.77179718, 22.42374992], [69.7720871, 22.42374992], [69.7720871, 22.42346954], [69.77263641, 22.42347145], [69.77263641, 22.42319489], [69.7729187, 22.42319489], [69.7729187, 22.42291641], [69.77319336, 22.42292023], [69.77319336, 22.42263985], [69.77348328, 22.42263985], [69.77348328, 22.42181015], [69.77375031, 22.42181015], [69.77375031, 22.42152977], [69.77403259, 22.42152977], [69.77403259, 22.42124939], [69.77430725, 22.42124939], [69.77430725, 22.42041969], [69.77458191, 22.42041969], [69.77458191, 22.41958046], [69.7748642, 22.41958237], [69.7748642, 22.41875076], [69.77513885, 22.41875076], [69.77513885, 22.41847038], [69.77597046, 22.41847229], [69.77597046, 22.41819382], [69.77625275, 22.41819382], [69.77625275, 22.41791725], [69.7765274, 22.41792107], [69.7765274, 22.41764069], [69.77680206, 22.41764069], [69.77680206, 22.41736031], [69.77707672, 22.41736031], [69.77707672, 22.41708183], [69.7776413, 22.41708374], [69.7776413, 22.41680527], [69.77791595, 22.4168129], [69.77791595, 22.41597176], [69.77819061, 22.41597366], [69.77819824, 22.41430473], [69.7784729, 22.41430473], [69.7784729, 22.41402817], [69.77874756, 22.41403008], [69.77874756, 22.41319084], [69.77902985, 22.41319466], [69.77902985, 22.41263771], [69.7793045, 22.41263771], [69.77929688, 22.41235924], [69.77986145, 22.41235924], [69.77986145, 22.41208839], [69.78151703, 22.41208839], [69.78151703, 22.41180992], [69.78235626, 22.41180992], [69.78235626, 22.41152954], [69.78320313, 22.41152954], [69.78320313, 22.41124916], [69.7840271, 22.41124916], [69.7840271, 22.41097069], [69.78430176, 22.4109726], [69.78430176, 22.41069412], [69.78458405, 22.41069412], [69.78458405, 22.41041946], [69.78485107, 22.41041946], [69.78485107, 22.41014099], [69.78514099, 22.41014099], [69.78514099, 22.40818977], [69.78541565, 22.40819359], [69.78541565, 22.40791512], [69.7859726, 22.40792084], [69.7859726, 22.40764046], [69.78679657, 22.40764046], [69.78679657, 22.40792084], [69.78736115, 22.40791512], [69.78736115, 22.40819359], [69.7876358, 22.40819359], [69.7876358, 22.40847206], [69.78791809, 22.40847015], [69.78791809, 22.40875053], [69.78930664, 22.40875053], [69.78930664, 22.40818977], [69.78902435, 22.40819359], [69.78902435, 22.40791512], [69.78874969, 22.40792084], [69.78874969, 22.40764046], [69.78848267, 22.40764046], [69.78848267, 22.4070797], [69.78819275, 22.40708351], [69.78819275, 22.40652847], [69.78848267, 22.40653038], [69.78848267, 22.40625], [69.78819275, 22.40625], [69.78819275, 22.40570068], [69.78901672, 22.40570068], [69.78901672, 22.4054203], [69.7895813, 22.4054203], [69.7895813, 22.40513992], [69.7904129, 22.40513992], [69.7904129, 22.40485954], [69.79125214, 22.40486145], [69.79125214, 22.40458488], [69.79180908, 22.40458488], [69.79180908, 22.40430641], [69.79207611, 22.40431023], [69.79207611, 22.40402985], [69.7923584, 22.40402985], [69.7923584, 22.40374947], [69.79264069, 22.40374947], [69.79264069, 22.4034729], [69.79360962, 22.4034729], [69.79458618, 22.4034729], [69.79458618, 22.40374947], [69.79486084, 22.40374947], [69.79486084, 22.40402985], [69.79569244, 22.40402985], [69.79569244, 22.40374947], [69.79624939, 22.40374947], [69.79624939, 22.40263939], [69.79651642, 22.40263939], [69.79651642, 22.40097237], [69.79680634, 22.40097237], [69.79680634, 22.40014076], [69.79708099, 22.4001503], [69.79708099, 22.39985847], [69.79763794, 22.39985847], [69.79763794, 22.4001503], [69.79792023, 22.4001503], [69.79792023, 22.40041924], [69.79819489, 22.40041733], [69.79819489, 22.40097237], [69.79846954, 22.40097237], [69.79846954, 22.40125275], [69.79875183, 22.40125275], [69.79875183, 22.40153122], [69.79902649, 22.4015274], [69.79902649, 22.40208244], [69.79930878, 22.40208244], [69.79930878, 22.40374947], [69.79957581, 22.40374947], [69.79957581, 22.40402985], [69.79985809, 22.40402985], [69.79985809, 22.40431023], [69.80041504, 22.40430641], [69.80041504, 22.40458488], [69.80124664, 22.40458488], [69.80124664, 22.40486145], [69.80152893, 22.40485954], [69.80152893, 22.40513992], [69.80208588, 22.40513992], [69.80208588, 22.40485954], [69.80347443, 22.40486145], [69.80347443, 22.40458488], [69.80458069, 22.40458488], [69.80458069, 22.40430641], [69.80486298, 22.40431023], [69.80486298, 22.40402985], [69.80541992, 22.40402985], [69.80541992, 22.40374947], [69.80568695, 22.40374947], [69.80568695, 22.40402985], [69.80596161, 22.40402985], [69.80596161, 22.40431023], [69.80625153, 22.40430641], [69.80625153, 22.40458488], [69.80647278, 22.40458488], [69.80680847, 22.40458488], [69.80680847, 22.40486145], [69.80708313, 22.40486145], [69.80708313, 22.40597153], [69.8079071, 22.40596008], [69.8079071, 22.40625], [69.80819702, 22.40625], [69.80819702, 22.40653038], [69.80847168, 22.40653038], [69.80847168, 22.40681076], [69.80874634, 22.40680695], [69.80874634, 22.40736198], [69.809021, 22.40736008], [69.809021, 22.40764046], [69.80930328, 22.40764046], [69.80930328, 22.40792084], [69.80958557, 22.40791512], [69.80958557, 22.40819359], [69.80986023, 22.40819359], [69.80986023, 22.40847206], [69.81014252, 22.40847206], [69.81014252, 22.40819359], [69.81069183, 22.40819359], [69.81069183, 22.40847206], [69.81097412, 22.40847206], [69.81097412, 22.40902519], [69.81069183, 22.40901947], [69.81069183, 22.40986061], [69.81096649, 22.40986061], [69.81096649, 22.41041946], [69.81124878, 22.41041946], [69.81124878, 22.41124916], [69.81153107, 22.41124916], [69.81153107, 22.41292191], [69.81180573, 22.41291618], [69.81180573, 22.41347313], [69.81208038, 22.41347313], [69.81208038, 22.4137516], [69.81236267, 22.4137516], [69.81236267, 22.41430473], [69.81291962, 22.41430473], [69.81291962, 22.41458321], [69.81375122, 22.41458321], [69.81375122, 22.41486168], [69.81430817, 22.41486168], [69.81430817, 22.41514969], [69.81485748, 22.41514969], [69.81485748, 22.41542053], [69.8151474, 22.41542053], [69.8151474, 22.41570282], [69.81541443, 22.41569519], [69.81541443, 22.41597366], [69.81569672, 22.41597176], [69.81569672, 22.4168129], [69.81597137, 22.41680527], [69.81597137, 22.41708374], [69.81624603, 22.41708183], [69.81624603, 22.41736031], [69.81652832, 22.41736031], [69.81652832, 22.41764069], [69.81680298, 22.41764069], [69.81680298, 22.41792107], [69.81708527, 22.41791725], [69.81708527, 22.41819382], [69.81764221, 22.41819], [69.81764221, 22.41930962], [69.81791687, 22.41930962], [69.81791687, 22.41986084], [69.81819153, 22.41986084], [69.81819153, 22.42041969], [69.81846619, 22.42041969], [69.81846619, 22.42152977], [69.81874847, 22.42152977], [69.81874847, 22.42181015], [69.81847382, 22.42180634], [69.81847382, 22.42236137], [69.81819153, 22.42235947], [69.81819153, 22.42263985], [69.81791687, 22.42263985], [69.81791687, 22.42292023], [69.81735992, 22.42291641], [69.81735992, 22.42347145], [69.81819153, 22.42347145], [69.81819153, 22.42319489], [69.81874847, 22.42319489], [69.81874847, 22.42291641], [69.81958008, 22.42291641], [69.81958008, 22.42347145], [69.81986237, 22.42346954], [69.81986237, 22.42542076], [69.82069397, 22.42541885], [69.82069397, 22.42569351], [69.82096863, 22.42569351], [69.82096863, 22.42597008], [69.82125092, 22.42596817], [69.82125092, 22.42624855], [69.82180786, 22.42624855], [69.82180786, 22.42653084], [69.82208252, 22.42653084], [69.82208252, 22.42680931], [69.82235718, 22.42680931], [69.82235718, 22.42708969], [69.82263947, 22.42708969], [69.82263947, 22.42735863], [69.82291412, 22.42735863], [69.82291412, 22.42847252], [69.82319641, 22.42847252], [69.82319641, 22.42930984], [69.82347107, 22.42930984], [69.82347107, 22.43041992], [69.82375336, 22.43041611], [69.82375336, 22.43097305], [69.82402802, 22.43097305], [69.82402802, 22.43208313], [69.82375336, 22.43208122], [69.82375336, 22.43264008], [69.82347107, 22.43263817], [69.82347107, 22.43319321], [69.82319641, 22.43318939], [69.82319641, 22.43403053], [69.82291412, 22.43402863], [69.82291412, 22.43458366], [69.82263947, 22.43457985], [69.82263947, 22.43514061], [69.82290649, 22.43514061], [69.82290649, 22.43542099], [69.82319641, 22.43541527], [69.82319641, 22.43569374], [69.82347107, 22.43569374], [69.82347107, 22.43597221], [69.82375336, 22.43597031], [69.82375336, 22.43653107], [69.82402802, 22.43653107], [69.82402802, 22.43680954], [69.82430267, 22.43680954], [69.82430267, 22.43764114], [69.82457733, 22.43764114], [69.82457733, 22.43791962], [69.82485962, 22.43791962], [69.82485962, 22.43902969], [69.82514191, 22.43902969], [69.82514191, 22.43958282], [69.82569122, 22.43958282], [69.82569122, 22.43930626], [69.82597351, 22.43930626], [69.82597351, 22.43958282], [69.82624817, 22.43958282], [69.82624817, 22.43985939], [69.82680511, 22.43985939], [69.82680511, 22.44014168], [69.8270874, 22.44014168], [69.8270874, 22.44042015], [69.82736206, 22.44041634], [69.82736206, 22.44069481], [69.82763672, 22.44068909], [69.82763672, 22.44125175], [69.82791901, 22.44125175], [69.82791901, 22.44153023], [69.82819366, 22.44152832], [69.82819366, 22.44208336], [69.82847595, 22.4420681], [69.82847595, 22.4426403], [69.82875061, 22.4426403], [69.82875061, 22.44292068], [69.82902527, 22.44291687], [69.8290329, 22.44486046], [69.82875061, 22.44486046], [69.82875061, 22.44542122], [69.82847595, 22.44542122], [69.82847595, 22.44625092], [69.82818604, 22.44625092], [69.82818604, 22.44680977], [69.82791901, 22.44680405], [69.82791901, 22.44708252], [69.82736206, 22.44708061], [69.82736206, 22.44763947], [69.8270874, 22.44763947], [69.8270874, 22.44791985], [69.82681274, 22.44791985], [69.82681274, 22.44820023], [69.82653046, 22.4481945], [69.82653046, 22.44847298], [69.82596588, 22.44847107], [69.82596588, 22.44874954], [69.82569122, 22.44874954], [69.82569122, 22.44902992], [69.82514191, 22.44902992], [69.82514191, 22.4493103], [69.82458496, 22.44930649], [69.82458496, 22.44958305], [69.82430267, 22.44958305], [69.82430267, 22.44986153], [69.82347107, 22.44985962], [69.82347107, 22.45013809], [69.82319641, 22.45013809], [69.82319641, 22.45042038], [69.82263947, 22.45042038], [69.82263947, 22.45070076], [69.82180786, 22.45069504], [69.82180786, 22.4509716], [69.82125092, 22.4509697], [69.82125092, 22.45126152], [69.82041931, 22.45126152], [69.82041931, 22.45153046], [69.81958008, 22.45153046], [69.81958008, 22.45181084], [69.81903076, 22.45180511], [69.81903076, 22.45208359], [69.81819153, 22.45208359], [69.81819153, 22.45236206], [69.81764221, 22.45235825], [69.81764221, 22.45264053], [69.81680298, 22.45264053], [69.81680298, 22.45292091], [69.81597137, 22.4529171], [69.81597137, 22.45319366], [69.81541443, 22.45319366], [69.81541443, 22.45347023], [69.81458282, 22.45346832], [69.81458282, 22.45375061], [69.81402588, 22.45375061], [69.81402588, 22.45402908], [69.81319427, 22.45402718], [69.81319427, 22.45430565], [69.81263733, 22.45430565], [69.81263733, 22.45458412], [69.81180573, 22.45458412], [69.81181335, 22.45486259], [69.81124878, 22.45486259], [69.81124878, 22.45514107], [69.81041718, 22.45514107], [69.81041718, 22.45541954], [69.80986023, 22.45541763], [69.80986023, 22.4556942], [69.80930328, 22.4556942], [69.80930328, 22.45597267], [69.80847168, 22.45597267], [69.80847168, 22.45625114], [69.8079071, 22.45625114], [69.8079071, 22.45652962], [69.80735779, 22.45652962], [69.80735779, 22.45681], [69.80652618, 22.45680618], [69.80652618, 22.45708275], [69.80596161, 22.4570694], [69.80596161, 22.45736122], [69.80513763, 22.45736122], [69.80513763, 22.45763969], [69.80319214, 22.45763969], [69.80319214, 22.45736122], [69.80152893, 22.45736122], [69.80152893, 22.4570694], [69.80069733, 22.45708275], [69.80069733, 22.45680618], [69.79957581, 22.45681], [69.79957581, 22.45652962], [69.79875183, 22.45652962], [69.79875183, 22.45569038], [69.79763794, 22.4556942], [69.79763794, 22.45597267], [69.79736328, 22.45597267], [69.79736328, 22.45652962], [69.79708099, 22.45652771], [69.79708099, 22.45708275], [69.79763794, 22.4570694], [69.79763794, 22.45736122], [69.79875183, 22.45736122], [69.79875183, 22.45763969], [69.80014038, 22.45763969], [69.80014038, 22.45792007], [69.80124664, 22.45791626], [69.80124664, 22.45819473], [69.80263519, 22.45819473], [69.80263519, 22.4584713], [69.80374908, 22.45846939], [69.80374908, 22.45874977], [69.80513763, 22.45874977], [69.80513763, 22.45846939], [69.80569458, 22.4584713], [69.80569458, 22.45819473], [69.80625153, 22.45819473], [69.80625153, 22.45791626], [69.80680847, 22.45792007], [69.80680847, 22.45763969], [69.80735779, 22.45763969], [69.80735779, 22.45736122], [69.80819702, 22.45736122], [69.80819702, 22.4570694], [69.80874634, 22.45708275], [69.80874634, 22.45680618], [69.80930328, 22.45681], [69.80930328, 22.45652962], [69.80986023, 22.45652962], [69.80986023, 22.45625114], [69.81069183, 22.45625114], [69.81069183, 22.45597267], [69.81124878, 22.45597267], [69.81124878, 22.4556942], [69.81180573, 22.4556942], [69.81180573, 22.45541573], [69.81263733, 22.45541954], [69.81263733, 22.45514107], [69.81318665, 22.45514107], [69.81318665, 22.45486259], [69.81402588, 22.45486259], [69.81402588, 22.45458031], [69.81485748, 22.45458412], [69.81485748, 22.45430565], [69.81541443, 22.45430565], [69.81541443, 22.45402718], [69.81624603, 22.45402908], [69.81624603, 22.45375061], [69.8170929, 22.45375061], [69.81708527, 22.45347023], [69.81791687, 22.45347023], [69.81791687, 22.45319366], [69.81847382, 22.45319366], [69.81847382, 22.4529171], [69.81931305, 22.45292091], [69.81931305, 22.45264053], [69.81986237, 22.45264053], [69.81986237, 22.45235825], [69.82069397, 22.45235825], [69.82068634, 22.45207977], [69.82125092, 22.45207977], [69.82125092, 22.45264053], [69.8215332, 22.45264053], [69.8215332, 22.45292091], [69.82180786, 22.4529171], [69.82180786, 22.45319366], [69.82208252, 22.45318985], [69.82208252, 22.45402908], [69.82235718, 22.45402908], [69.82235718, 22.45514107], [69.82263947, 22.45513916], [69.82263947, 22.4556942], [69.82319641, 22.4556942], [69.82319641, 22.45597267], [69.82347107, 22.45597267], [69.82347107, 22.45652962], [69.82375336, 22.45652962], [69.82375336, 22.45681], [69.82402802, 22.45680618], [69.82402802, 22.45708275], [69.82430267, 22.4570694], [69.82430267, 22.45736122], [69.82485962, 22.45736122], [69.82485962, 22.45763969], [69.82514191, 22.45763969], [69.82514191, 22.45792007], [69.82707977, 22.45791626], [69.82707977, 22.45819473], [69.82763672, 22.45819473], [69.82763672, 22.45652771], [69.82736206, 22.45652962], [69.82736206, 22.45597267], [69.82763672, 22.45597267], [69.82763672, 22.4556942], [69.82819366, 22.4556942], [69.82819366, 22.45375061], [69.82847595, 22.45375061], [69.82847595, 22.45153046], [69.8290329, 22.45153046], [69.8290329, 22.4509697], [69.82930756, 22.4509716], [69.82930756, 22.45069504], [69.82958221, 22.45070076], [69.82958221, 22.45013809], [69.82985687, 22.45013809], [69.82985687, 22.44985962], [69.83069611, 22.44986153], [69.83069611, 22.4509716], [69.8326416, 22.4509716], [69.8326416, 22.45208359], [69.83291626, 22.45207977], [69.83291626, 22.45235825], [69.83319092, 22.45235825], [69.83319092, 22.45264053], [69.83347321, 22.45264053], [69.83347321, 22.45292091], [69.83374786, 22.4529171], [69.83374786, 22.45319366], [69.83429718, 22.45318985], [69.83429718, 22.45402908], [69.8345871, 22.45402908], [69.8345871, 22.45541954], [69.83429718, 22.45541954], [69.83429718, 22.45652962], [69.83403015, 22.45652771], [69.83403015, 22.45708275], [69.83347321, 22.4570694], [69.83347321, 22.45792007], [69.83430481, 22.45791626], [69.83430481, 22.45930481], [69.8345871, 22.4593029], [69.8345871, 22.46764183], [69.83486176, 22.46763992], [69.83486176, 22.47097206], [69.83513641, 22.47097015], [69.83513641, 22.47291946], [69.83486176, 22.47291756], [69.83486176, 22.4734726], [69.8345871, 22.47347069], [69.8345871, 22.47375107], [69.83429718, 22.47375107], [69.83429718, 22.47430992], [69.83403015, 22.4743042], [69.83403015, 22.47458267], [69.83429718, 22.47458076], [69.83429718, 22.47486115], [69.8345871, 22.47486115], [69.8345871, 22.47542953], [69.8354187, 22.47542953], [69.8354187, 22.47513962], [69.83569336, 22.47513962], [69.83569336, 22.47458076], [69.83597565, 22.47458267], [69.83597565, 22.4743042], [69.83625031, 22.47430992], [69.83625031, 22.47236061], [69.83597565, 22.47236061], [69.83597565, 22.46430588], [69.83569336, 22.46430969], [69.83569336, 22.46014023], [69.8354187, 22.46014023], [69.8354187, 22.45792007], [69.83597565, 22.45791626], [69.83597565, 22.45819473], [69.83625031, 22.45819283], [69.83625031, 22.46014023], [69.83653259, 22.46014023], [69.83653259, 22.46292114], [69.83680725, 22.46291542], [69.83680725, 22.46458244], [69.83708191, 22.46458244], [69.83708191, 22.46625137], [69.83735657, 22.46623993], [69.83735657, 22.46820259], [69.83763885, 22.46819496], [69.83763885, 22.46986389], [69.83790588, 22.46986008], [69.83790588, 22.47180939], [69.8381958, 22.47180557], [69.8381958, 22.4734726], [69.83847046, 22.47347069], [69.83847046, 22.47513962], [69.83875275, 22.47513962], [69.83875275, 22.47708321], [69.8390274, 22.47707939], [69.8390274, 22.47874832], [69.83930206, 22.47874832], [69.83930206, 22.48069382], [69.83957672, 22.4806881], [69.83957672, 22.48236275], [69.83985901, 22.48236275], [69.83985901, 22.48402977], [69.8401413, 22.48402786], [69.8401413, 22.48597145], [69.84041595, 22.48596954], [69.84041595, 22.48764038], [69.84069824, 22.48763847], [69.84069824, 22.48958397], [69.8409729, 22.48958015], [69.8409729, 22.49124908], [69.84124756, 22.49124908], [69.84124756, 22.49292183], [69.84152985, 22.49292183], [69.84152985, 22.49403191], [69.84124756, 22.49402809], [69.84124756, 22.49430466], [69.8409729, 22.49430466], [69.8409729, 22.49458313], [69.84069824, 22.49458313], [69.84069824, 22.4948616], [69.84041595, 22.4948616], [69.84041595, 22.49514008], [69.8401413, 22.49514008], [69.8401413, 22.49542046], [69.83985901, 22.49542046], [69.83985901, 22.49570274], [69.83958435, 22.49569511], [69.83958435, 22.49597359], [69.83930206, 22.49597359], [69.83930206, 22.49625015], [69.8381958, 22.49624252], [69.8381958, 22.49681282], [69.83790588, 22.49681282], [69.83790588, 22.49736023], [69.83763885, 22.49736023], [69.83763885, 22.49764061], [69.83708191, 22.49764061], [69.83708191, 22.49736023], [69.83680725, 22.49736023], [69.83680725, 22.49764061], [69.83653259, 22.49764061], [69.83653259, 22.49792099], [69.83625031, 22.49791718], [69.83625031, 22.49819374], [69.83597565, 22.49819374], [69.83597565, 22.49847221], [69.83569336, 22.49847031], [69.83569336, 22.49875069], [69.8354187, 22.49875069], [69.8354187, 22.49903107], [69.83513641, 22.49903107], [69.83513641, 22.49930954], [69.83486176, 22.49930573], [69.83486176, 22.4995842], [69.8345871, 22.49958038], [69.8345871, 22.49986076], [69.83430481, 22.49986076], [69.83430481, 22.50069427], [69.83597565, 22.50069427], [69.83597565, 22.5004158], [69.83653259, 22.50041962], [69.83653259, 22.49958038], [69.83680725, 22.4995842], [69.83680725, 22.49930573], [69.83708191, 22.49930954], [69.83708191, 22.49903107], [69.83735657, 22.49903107], [69.83735657, 22.49875069], [69.83790588, 22.49875069], [69.83790588, 22.49847031], [69.83847046, 22.49847031], [69.83847046, 22.49875069], [69.8390274, 22.49875069], [69.8390274, 22.49847031], [69.83930206, 22.49847221], [69.83930206, 22.4976387], [69.83957672, 22.49764061], [69.83957672, 22.49736023], [69.8401413, 22.49736023], [69.8401413, 22.49707985], [69.84041595, 22.49708366], [69.84041595, 22.49680519], [69.8409729, 22.49681282], [69.8409729, 22.49597168], [69.84124756, 22.49597359], [69.84124756, 22.49569511], [69.84179688, 22.49570274], [69.84179688, 22.49542046], [69.84208679, 22.49542046], [69.84208679, 22.49514008], [69.84236145, 22.49514008], [69.84236145, 22.49542046], [69.84263611, 22.49542046], [69.84263611, 22.49514008], [69.8429184, 22.49514008], [69.8429184, 22.4948616], [69.84319305, 22.4948616], [69.84319305, 22.49430466], [69.8429184, 22.49430466], [69.8429184, 22.49402809], [69.84263611, 22.49403191], [69.84263611, 22.49292183], [69.84236145, 22.49292183], [69.84236145, 22.49124908], [69.84208679, 22.49124908], [69.84208679, 22.48958015], [69.8418045, 22.48958397], [69.8418045, 22.48847198], [69.84152985, 22.48847198], [69.84152985, 22.48819542], [69.84124756, 22.4881897], [69.84124756, 22.48430634], [69.8409729, 22.48430634], [69.8409729, 22.48236275], [69.84069824, 22.48236275], [69.84069061, 22.4806881], [69.84041595, 22.48069382], [69.84041595, 22.48041725], [69.8401413, 22.48041916], [69.8401413, 22.4798584], [69.84041595, 22.4798584], [69.84041595, 22.47930908], [69.8401413, 22.47930908], [69.8401413, 22.47707939], [69.83985901, 22.47708321], [69.83985901, 22.47541618], [69.83957672, 22.47542953], [69.83957672, 22.47375107], [69.83930206, 22.47375107], [69.83930206, 22.47180939], [69.8390274, 22.47180939], [69.8390274, 22.47014046], [69.83875275, 22.47014046], [69.83875275, 22.46846962], [69.83847046, 22.46846962], [69.83847046, 22.46625137], [69.8381958, 22.46625137], [69.8381958, 22.46486092], [69.83790588, 22.46486092], [69.83790588, 22.46264076], [69.83763885, 22.46264076], [69.83763885, 22.46125031], [69.83735657, 22.46125031], [69.83735657, 22.45957947], [69.83708191, 22.45958328], [69.83708191, 22.45819473], [69.83680725, 22.45819473], [69.83680725, 22.45708275], [69.83652496, 22.45708275], [69.83652496, 22.45513916], [69.83625031, 22.45514107], [69.83625031, 22.45402908], [69.83680725, 22.45402718], [69.83680725, 22.45458412], [69.83763885, 22.45458031], [69.83763885, 22.45486259], [69.83847046, 22.45486259], [69.83847046, 22.45458031], [69.83930206, 22.45458031], [69.83930206, 22.45486259], [69.83985901, 22.45486259], [69.83985901, 22.45514107], [69.84069824, 22.45513916], [69.84069824, 22.4556942], [69.8409729, 22.4556942], [69.8409729, 22.45597267], [69.8418045, 22.45597267], [69.8418045, 22.4556942], [69.84263611, 22.4556942], [69.84263611, 22.45541573], [69.84348297, 22.45541954], [69.84348297, 22.45514107], [69.84375, 22.45514107], [69.84375, 22.45486259], [69.84541321, 22.45486259], [69.84541321, 22.45429993], [69.8473587, 22.45430565], [69.8473587, 22.45458412], [69.84764099, 22.45458412], [69.84764099, 22.45430565], [69.84874725, 22.45430565], [69.84874725, 22.45402718], [69.84986115, 22.45402908], [69.84986115, 22.45375061], [69.85041809, 22.45375061], [69.85041809, 22.45346832], [69.85097504, 22.45347023], [69.85097504, 22.45319366], [69.85124969, 22.45319366], [69.85124969, 22.4529171], [69.85180664, 22.45292091], [69.85180664, 22.45264053], [69.85235596, 22.45264053], [69.85235596, 22.45207977], [69.85263824, 22.45208359], [69.85263824, 22.45180511], [69.85320282, 22.45181084], [69.85320282, 22.45153046], [69.85346985, 22.45153046], [69.85346985, 22.45126152], [69.85402679, 22.45126152], [69.85402679, 22.4509697], [69.85430908, 22.4509716], [69.85430908, 22.45069504], [69.8548584, 22.45070076], [69.8548584, 22.45042038], [69.85542297, 22.45042038], [69.85542297, 22.45013809], [69.85569763, 22.45013809], [69.85569763, 22.44985962], [69.85597229, 22.44986153], [69.85597229, 22.44958305], [69.85624695, 22.44958305], [69.85624695, 22.44930649], [69.85652924, 22.44930077], [69.85652924, 22.44902611], [69.85679626, 22.44902992], [69.85679626, 22.44874954], [69.85764313, 22.44874954], [69.8576355, 22.44847298], [69.85791779, 22.44847298], [69.85791779, 22.4481945], [69.85874939, 22.44820023], [69.85874939, 22.44791985], [69.85930634, 22.44791985], [69.85930634, 22.44763947], [69.85958099, 22.44763947], [69.85958099, 22.44736099], [69.86013031, 22.44736099], [69.86013031, 22.44708061], [69.86042023, 22.44708252], [69.86042023, 22.44680405], [69.86235809, 22.44680405], [69.86235809, 22.44708252], [69.86264038, 22.44708252], [69.86264038, 22.44680405], [69.86430359, 22.44680405], [69.86430359, 22.44708252], [69.86513519, 22.44708252], [69.86513519, 22.44736099], [69.86680603, 22.44736099], [69.86680603, 22.44708061], [69.86736298, 22.44708252], [69.86736298, 22.44680405], [69.86763763, 22.44680977], [69.86763763, 22.44652939], [69.87014008, 22.44652939], [69.87014008, 22.44680977], [69.87152863, 22.44680405], [69.87152863, 22.44708252], [69.87264252, 22.44708061], [69.87264252, 22.44736099], [69.87374878, 22.44736099], [69.87374878, 22.44820023], [69.87347412, 22.4481945], [69.87346649, 22.44930077], [69.87374878, 22.44930649], [69.87374878, 22.44958305], [69.87403107, 22.44958305], [69.87403107, 22.44930649], [69.87431335, 22.44930077], [69.87430573, 22.44874954], [69.87458038, 22.44874954], [69.87458038, 22.44820023], [69.87486267, 22.44820023], [69.87486267, 22.44791985], [69.87542725, 22.44791985], [69.87542725, 22.44820023], [69.87596893, 22.4481945], [69.87596893, 22.44847298], [69.87625122, 22.44847107], [69.87625122, 22.44874954], [69.87680817, 22.44874954], [69.87680817, 22.44902992], [69.87708282, 22.44902611], [69.87708282, 22.44930077], [69.87763977, 22.44930649], [69.87763977, 22.44958305], [69.87791443, 22.44958305], [69.87791443, 22.44986153], [69.87847137, 22.44985962], [69.87847137, 22.45013809], [69.87874603, 22.45013809], [69.87874603, 22.45042038], [69.87902832, 22.45042038], [69.87902832, 22.45070076], [69.87930298, 22.45069504], [69.87930298, 22.4509716], [69.8795929, 22.4509697], [69.8795929, 22.45126152], [69.87985992, 22.45126152], [69.87985992, 22.45181084], [69.88014221, 22.45180511], [69.88014221, 22.45208359], [69.88041687, 22.45207977], [69.88041687, 22.45235825], [69.88069153, 22.45235825], [69.88069153, 22.45264053], [69.88096619, 22.45264053], [69.88096619, 22.45292091], [69.88153076, 22.4529171], [69.88153076, 22.45319366], [69.88180542, 22.45319366], [69.88180542, 22.45347023], [69.88208008, 22.45346832], [69.88208008, 22.45375061], [69.88236237, 22.45375061], [69.88236237, 22.45402908], [69.88208008, 22.45402718], [69.88208008, 22.45430565], [69.88181305, 22.45429993], [69.88181305, 22.45541954], [69.88208008, 22.45541573], [69.88208008, 22.4556942], [69.88236237, 22.45569038], [69.88236237, 22.45625114], [69.88263702, 22.45625114], [69.88263702, 22.45652962], [69.88291931, 22.45652771], [69.88291931, 22.45708275], [69.88318634, 22.4570694], [69.88318634, 22.45763969], [69.88346863, 22.45763969], [69.88346863, 22.45792007], [69.88486481, 22.45791626], [69.88486481, 22.45819473], [69.88597107, 22.45819473], [69.88597107, 22.4584713], [69.88735962, 22.4584713], [69.88735962, 22.45874977], [69.88791656, 22.45874977], [69.88791656, 22.45903015], [69.88847351, 22.45902824], [69.88847351, 22.45930481], [69.88930511, 22.45930481], [69.88930511, 22.46097183], [69.88957977, 22.46096992], [69.88957977, 22.46125031], [69.89013672, 22.46125031], [69.89013672, 22.46153069], [69.89068604, 22.46153069], [69.89068604, 22.46181107], [69.89097595, 22.46181107], [69.89097595, 22.46236038], [69.89125061, 22.46236038], [69.89125061, 22.46292114], [69.8915329, 22.46292114], [69.8915329, 22.46319962], [69.89180756, 22.46319389], [69.89180756, 22.46347237], [69.89208221, 22.46347046], [69.89208221, 22.46375084], [69.89235687, 22.46375084], [69.89235687, 22.46403122], [69.89290619, 22.46403122], [69.89290619, 22.46430969], [69.89319611, 22.46430588], [69.89319611, 22.46458244], [69.89347076, 22.46458054], [69.89347076, 22.46486092], [69.89402771, 22.46486092], [69.89402771, 22.46513748], [69.89430237, 22.46513748], [69.89430237, 22.46541977], [69.8951416, 22.46541595], [69.8951416, 22.46569443], [69.89597321, 22.46569443], [69.89597321, 22.4659729], [69.8970871, 22.4659729], [69.8970871, 22.46625137], [69.89848328, 22.46623993], [69.89848328, 22.46653175], [69.89930725, 22.46652985], [69.89930725, 22.46736145], [69.89958191, 22.46736145], [69.89958191, 22.46764183], [69.90040588, 22.46764183], [69.90040588, 22.4679203], [69.90236664, 22.4679203], [69.90236664, 22.46764183], [69.90319824, 22.46764183], [69.90319824, 22.4679203], [69.90374756, 22.4679203], [69.90374756, 22.46736145], [69.9043045, 22.46736145], [69.9043045, 22.46708107], [69.90458679, 22.46708107], [69.90458679, 22.46680641], [69.90486145, 22.46681023], [69.90486145, 22.46623993], [69.9043045, 22.46625137], [69.9043045, 22.4659729], [69.90374756, 22.4659729], [69.90374756, 22.46430588], [69.90402985, 22.46430969], [69.90402985, 22.46403122], [69.90429688, 22.46403122], [69.90429688, 22.46319962], [69.90458679, 22.46319962], [69.90458679, 22.46292114], [69.90486145, 22.46292114], [69.90486145, 22.46264076], [69.90541077, 22.46264076], [69.90541077, 22.46292114], [69.90598297, 22.46292114], [69.90598297, 22.46264076], [69.90680695, 22.46264076], [69.90680695, 22.46236038], [69.90763855, 22.46236038], [69.90763855, 22.46208], [69.90791321, 22.46208382], [69.90791321, 22.46125031], [69.90763855, 22.46125031], [69.90763855, 22.46070099], [69.90735626, 22.46070099], [69.90735626, 22.46042061], [69.90791321, 22.46042061], [69.90791321, 22.46014023], [69.90820313, 22.46014023], [69.90820313, 22.45985985], [69.90847015, 22.45985985], [69.90847015, 22.46014023], [69.90875244, 22.46014023], [69.90875244, 22.45985985], [69.91014099, 22.45986176], [69.91014099, 22.45958328], [69.91041565, 22.45958328], [69.91041565, 22.45902824], [69.91069794, 22.45903015], [69.91069794, 22.45874977], [69.9109726, 22.45874977], [69.9109726, 22.45819283], [69.91124725, 22.45819473], [69.91124725, 22.45763969], [69.91152954, 22.45763969], [69.91152954, 22.45736122], [69.91179657, 22.45736122], [69.91179657, 22.4570694], [69.91208649, 22.45708275], [69.91208649, 22.45680618], [69.91236115, 22.45681], [69.91236115, 22.45652962], [69.9126358, 22.45652962], [69.9126358, 22.45625114], [69.91402435, 22.45624924], [69.91402435, 22.45708275], [69.91374969, 22.4570694], [69.91374969, 22.45736122], [69.91347504, 22.45736122], [69.91348267, 22.45763969], [69.91319275, 22.45763969], [69.91319275, 22.45792007], [69.91291809, 22.45791626], [69.91291809, 22.45819473], [69.9126358, 22.45819473], [69.9126358, 22.45930481], [69.91236115, 22.45930481], [69.91236115, 22.45986176], [69.91208649, 22.45985985], [69.91208649, 22.46014023], [69.9118042, 22.46013832], [69.9118042, 22.46097183], [69.91152954, 22.46097183], [69.91152954, 22.46208382], [69.91124725, 22.46208], [69.91124725, 22.46264076], [69.9109726, 22.46263885], [69.9109726, 22.46347237], [69.91069794, 22.46347046], [69.91069794, 22.46430969], [69.91042328, 22.46430969], [69.91042328, 22.46541977], [69.91014099, 22.46541595], [69.91014099, 22.46625137], [69.9098587, 22.46625137], [69.9098587, 22.46708107], [69.90957642, 22.46707916], [69.90957642, 22.4679203], [69.9098587, 22.4679203], [69.9098587, 22.46764183], [69.91014099, 22.46764183], [69.91014099, 22.46736145], [69.91041565, 22.46736145], [69.91041565, 22.46708107], [69.9109726, 22.46708107], [69.9109726, 22.46736145], [69.91124725, 22.46736145], [69.91124725, 22.46820259], [69.9109726, 22.46820259], [69.9109726, 22.47042084], [69.91124725, 22.47041702], [69.91124725, 22.47097206], [69.9109726, 22.47097015], [69.9109726, 22.47236061], [69.91069794, 22.47236061], [69.91069794, 22.47291946], [69.91041565, 22.47291756], [69.91041565, 22.47319412], [69.91014099, 22.47319031], [69.91014099, 22.47375107], [69.9098587, 22.47375107], [69.9098587, 22.47542953], [69.91014099, 22.47541618], [69.91014099, 22.47569466], [69.91069794, 22.47569466], [69.91069794, 22.47597313], [69.9109726, 22.47597122], [69.9109726, 22.47792053], [69.91124725, 22.47791672], [69.91124725, 22.47847176], [69.91152954, 22.47846985], [69.91152954, 22.47874832], [69.91179657, 22.47874832], [69.91179657, 22.47930908], [69.91208649, 22.47930527], [69.91208649, 22.48069382], [69.91179657, 22.4806881], [69.91179657, 22.48291969], [69.91208649, 22.48291969], [69.91208649, 22.48513985], [69.91236115, 22.48513985], [69.91236115, 22.4865303], [69.9126358, 22.4865284], [69.9126358, 22.48819351], [69.91291809, 22.4881897], [69.91291809, 22.48903084], [69.91319275, 22.48902512], [69.91319275, 22.48958397], [69.91374969, 22.48958015], [69.91374969, 22.48986053], [69.91401672, 22.48986053], [69.91401672, 22.49014091], [69.91430664, 22.49014091], [69.91430664, 22.49043083], [69.9145813, 22.49041939], [69.9145813, 22.49069405], [69.91486359, 22.49069405], [69.91486359, 22.49097252], [69.91513824, 22.49097061], [69.91513824, 22.49124908], [69.9154129, 22.49124908], [69.9154129, 22.49152756], [69.91570282, 22.49152756], [69.91570282, 22.49180984], [69.91596985, 22.49180794], [69.91596985, 22.4920826], [69.91625214, 22.49208069], [69.91625214, 22.49235916], [69.91680908, 22.49235916], [69.91680908, 22.49263763], [69.91735077, 22.49263763], [69.91735077, 22.49292183], [69.91791534, 22.49291611], [69.91791534, 22.49319458], [69.91819763, 22.49319458], [69.91819763, 22.49347305], [69.91847229, 22.49346924], [69.91847229, 22.49375153], [69.91874695, 22.49375153], [69.91874695, 22.49458313], [69.91847229, 22.49458313], [69.91847229, 22.4948616], [69.91874695, 22.4948616], [69.91874695, 22.49570274], [69.91902924, 22.49569511], [69.91902924, 22.49597359], [69.91930389, 22.49597359], [69.91930389, 22.49625015], [69.91986084, 22.49624252], [69.91986084, 22.49653053], [69.92014313, 22.49653053], [69.92014313, 22.49764061], [69.92041016, 22.49764061], [69.92041016, 22.49792099], [69.92069244, 22.49791718], [69.92069244, 22.49847221], [69.9209671, 22.49847031], [69.9209671, 22.49903107], [69.92124939, 22.49902725], [69.92124939, 22.4995842], [69.92151642, 22.49958038], [69.92151642, 22.50014114], [69.92180634, 22.50014114], [69.92180634, 22.50041962], [69.92208099, 22.5004158], [69.92208099, 22.50097275], [69.92236328, 22.50097084], [69.92236328, 22.50152969], [69.92263794, 22.50152779], [69.92263794, 22.50208282], [69.92292023, 22.50208092], [69.92292023, 22.50292015], [69.92319489, 22.50291634], [69.92319489, 22.50319481], [69.92346954, 22.50319481], [69.92346954, 22.50347137], [69.92375183, 22.50347137], [69.92375183, 22.50363159], [69.92375183, 22.50374985], [69.92402649, 22.50374985], [69.92402649, 22.50403023], [69.92430878, 22.50402641], [69.92430878, 22.50458336], [69.92458344, 22.50458336], [69.92458344, 22.50486183], [69.92485809, 22.50485992], [69.92485809, 22.5051384], [69.92514038, 22.5051384], [69.92514038, 22.50541878], [69.92569733, 22.50541115], [69.92569733, 22.50569916], [69.92597198, 22.50569534], [69.92597198, 22.50597191], [69.92624664, 22.50596809], [69.92624664, 22.50624847], [69.92653656, 22.50624847], [69.92653656, 22.50653076], [69.92708588, 22.50653076], [69.92708588, 22.50680923], [69.92736053, 22.50680542], [69.92736053, 22.50708389], [69.92763519, 22.50708389], [69.92763519, 22.50735855], [69.92791748, 22.50735855], [69.92791748, 22.50764275], [69.9284668, 22.50764275], [69.9284668, 22.50792122], [69.92874908, 22.5079174], [69.92874908, 22.50819397], [69.92903137, 22.50819397], [69.92903137, 22.50847244], [69.92958069, 22.50847244], [69.92958069, 22.50875282], [69.92986298, 22.50875282], [69.92986298, 22.50902939], [69.93041992, 22.50902939], [69.93041992, 22.50930977], [69.93069458, 22.50930595], [69.93069458, 22.50958252], [69.93125153, 22.50958252], [69.93125153, 22.5098629], [69.93152618, 22.5098629], [69.93152618, 22.51013947], [69.93264008, 22.51013947], [69.93264008, 22.51041985], [69.93319702, 22.51041985], [69.93319702, 22.51013947], [69.93374634, 22.51013947], [69.93374634, 22.51041985], [69.93402863, 22.51041603], [69.93402863, 22.51097488], [69.93430328, 22.51097107], [69.93430328, 22.51153946], [69.93458557, 22.51152802], [69.93458557, 22.51208305], [69.93486023, 22.51208115], [69.93486023, 22.51264], [69.93596649, 22.51264], [69.93596649, 22.51292038], [69.93681335, 22.51292038], [69.93681335, 22.51320076], [69.93736267, 22.51319313], [69.93736267, 22.5134716], [69.93818665, 22.5134697], [69.93818665, 22.51375008], [69.93958282, 22.51375008], [69.93958282, 22.5134697], [69.94069672, 22.5134716], [69.94069672, 22.51319313], [69.94124603, 22.51320076], [69.94124603, 22.51292038], [69.94153595, 22.51292038], [69.94153595, 22.51264], [69.9420929, 22.51264], [69.9420929, 22.51235962], [69.94235992, 22.51236153], [69.94235992, 22.51208305], [69.94291687, 22.51208305], [69.94291687, 22.51180649], [69.94346619, 22.51180077], [69.94347382, 22.51152802], [69.94374847, 22.51153946], [69.94374847, 22.51124954], [69.94403076, 22.51124954], [69.94403076, 22.51097107], [69.94430542, 22.51097488], [69.94430542, 22.5106945], [69.94458008, 22.5106945], [69.94458008, 22.51041603], [69.94486237, 22.51041985], [69.94486237, 22.51013947], [69.94513702, 22.51013947], [69.94513702, 22.5098629], [69.94541931, 22.5098629], [69.94541931, 22.50958252], [69.94569397, 22.50958252], [69.94569397, 22.50930595], [69.94596863, 22.50930977], [69.94596863, 22.50902939], [69.94625092, 22.50902939], [69.94625092, 22.50875282], [69.9465332, 22.50875282], [69.94652557, 22.50847244], [69.94680786, 22.50847244], [69.94680786, 22.50819397], [69.94708252, 22.50819397], [69.94708252, 22.5079174], [69.94734955, 22.50792122], [69.94734955, 22.50764275], [69.94745636, 22.50764275], [69.94763947, 22.50764275], [69.94763947, 22.50735855], [69.94790649, 22.50735855], [69.94790649, 22.50707817], [69.94875336, 22.50708389], [69.94875336, 22.50680542], [69.94902802, 22.50680923], [69.94902802, 22.50653076], [69.94957733, 22.50653076], [69.94957733, 22.50624847], [69.95014191, 22.50624847], [69.95014191, 22.50596809], [69.95097351, 22.50597191], [69.95097351, 22.50569534], [69.95153046, 22.50569916], [69.95153046, 22.50541115], [69.95291901, 22.50541878], [69.95291901, 22.5051384], [69.95318604, 22.5051384], [69.95318604, 22.50485992], [69.95375061, 22.50486183], [69.95375061, 22.50458336], [69.95402527, 22.50458336], [69.95402527, 22.50430489], [69.95430756, 22.50430489], [69.95430756, 22.50402641], [69.95513916, 22.50403023], [69.95513916, 22.50346947], [69.95541382, 22.50347137], [69.95541382, 22.5023613], [69.95569611, 22.50237083], [69.95569611, 22.50208092], [69.95597076, 22.50208282], [69.95597076, 22.50152779], [69.95625305, 22.50152969], [69.95625305, 22.50125122], [69.95597076, 22.50125122], [69.95597076, 22.5002594], [69.95597076, 22.50013924], [69.95625305, 22.50014114], [69.95625305, 22.49958038], [69.95652771, 22.4995842], [69.95652771, 22.49652863], [69.95625305, 22.49653053], [69.95625305, 22.49542046], [69.95735931, 22.49541664], [69.95735931, 22.49597359], [69.9576416, 22.49597168], [69.9576416, 22.50014114], [69.95735931, 22.50013924], [69.95735931, 22.50056076], [69.95735931, 22.50125122], [69.95708466, 22.50124931], [69.95708466, 22.50208282], [69.95680237, 22.50208092], [69.95680237, 22.50263977], [69.95652008, 22.50263977], [69.95652008, 22.50292015], [69.95625305, 22.50291634], [69.95625305, 22.50347137], [69.95597076, 22.50346947], [69.95597076, 22.50403023], [69.95569611, 22.50402641], [69.95569611, 22.50430489], [69.95541382, 22.50430489], [69.95541382, 22.50458336], [69.95569611, 22.50458336], [69.95569611, 22.50541878], [69.95597076, 22.50541878], [69.95597076, 22.50597191], [69.95625305, 22.50596809], [69.95625305, 22.50653076], [69.95652771, 22.50652695], [69.95652771, 22.50708389], [69.95680237, 22.50707817], [69.95680237, 22.50735855], [69.95707703, 22.50735855], [69.95707703, 22.50764275], [69.95791626, 22.50764275], [69.95791626, 22.50792122], [69.95874786, 22.5079174], [69.95874786, 22.50819397], [69.95903015, 22.50819016], [69.95903015, 22.50930977], [69.95874786, 22.50930595], [69.95874786, 22.50942039], [69.95874786, 22.50958252], [69.95819092, 22.50958252], [69.95819092, 22.50930595], [69.9576416, 22.50930977], [69.9576416, 22.50875282], [69.95707703, 22.50875282], [69.95707703, 22.50847244], [69.95625305, 22.50847244], [69.95625305, 22.50819397], [69.95569611, 22.50819397], [69.95569611, 22.50847244], [69.95347595, 22.50847244], [69.95347595, 22.50875282], [69.95291901, 22.50875282], [69.95291901, 22.50902939], [69.95181274, 22.50902939], [69.95181274, 22.50930977], [69.95124817, 22.50930595], [69.95124817, 22.50958252], [69.95096588, 22.50958252], [69.95096588, 22.5098629], [69.95069122, 22.5098629], [69.95069122, 22.51041985], [69.95041656, 22.51041985], [69.95041656, 22.51124954], [69.95014191, 22.51124954], [69.95014191, 22.51153946], [69.94985962, 22.51152802], [69.94985962, 22.51208305], [69.94958496, 22.51208305], [69.94958496, 22.51236153], [69.94930267, 22.51235962], [69.94930267, 22.51264], [69.94902802, 22.51264], [69.94902802, 22.51292038], [69.94790649, 22.51292038], [69.94790649, 22.51320076], [69.94736481, 22.51319313], [69.94736481, 22.5134716], [69.94708252, 22.5134697], [69.94708252, 22.51375008], [69.9465332, 22.51375008], [69.9465332, 22.51403046], [69.94625092, 22.51403046], [69.94625092, 22.51431084], [69.94569397, 22.51430511], [69.94569397, 22.51458359], [69.94541931, 22.51458359], [69.94541931, 22.51486206], [69.94486237, 22.51486015], [69.94486237, 22.51542091], [69.94458008, 22.51542091], [69.94458008, 22.51653099], [69.94430542, 22.51652527], [69.94430542, 22.51736069], [69.94458008, 22.51735115], [69.94458008, 22.51791954], [69.94486237, 22.51791573], [69.94486237, 22.51847267], [69.94513702, 22.51847076], [69.94513702, 22.51874924], [69.94541931, 22.51874924], [69.94541931, 22.51930809], [69.94568634, 22.51930809], [69.94568634, 22.51985931], [69.94596863, 22.51985931], [69.94596863, 22.5201416], [69.94625092, 22.5201416], [69.94625092, 22.51985931], [69.9465332, 22.51985931], [69.94652557, 22.51958275], [69.94736481, 22.51958275], [69.94736481, 22.52041626], [69.94708252, 22.52041626], [69.94708252, 22.52069473], [69.94680786, 22.52069473], [69.94680786, 22.52180481], [69.9465332, 22.52179909], [69.9465332, 22.52347946], [69.94625092, 22.52347374], [69.94625092, 22.52597237], [69.94596863, 22.52597237], [69.94596863, 22.5284729], [69.94652557, 22.5284729], [69.94652557, 22.52874947], [69.94734955, 22.52874947], [69.94734955, 22.52902985], [69.94847107, 22.52902985], [69.94847107, 22.52931023], [69.94930267, 22.52930641], [69.94930267, 22.52958298], [69.95014191, 22.52958298], [69.95014191, 22.52986145], [69.95265198, 22.52985954], [69.9540329, 22.52985954], [69.9540329, 22.53013992], [69.95430756, 22.53013992], [69.95430756, 22.53070068], [69.95458221, 22.53069496], [69.95458221, 22.53097153], [69.95513916, 22.53096962], [69.95513916, 22.53124809], [69.95540619, 22.53124809], [69.95540619, 22.53153038], [69.95597076, 22.53153038], [69.95597076, 22.53181076], [69.95625305, 22.53180504], [69.95625305, 22.53208351], [69.95652771, 22.53208351], [69.95652771, 22.53236008], [69.95707703, 22.53235054], [69.95707703, 22.53264046], [69.95735931, 22.53264046], [69.95735931, 22.53292084], [69.95749664, 22.53292084], [69.95791626, 22.53291893], [69.95791626, 22.53319359], [69.95819092, 22.53319359], [69.95819092, 22.53347015], [69.95847321, 22.53346825], [69.95847321, 22.53374863], [69.95903015, 22.53374863], [69.95903015, 22.53403091], [69.95929718, 22.53403091], [69.95929718, 22.53430939], [69.95986176, 22.53430557], [69.95986176, 22.53458405], [69.96013641, 22.53458023], [69.96013641, 22.53486252], [69.9604187, 22.53486252], [69.9604187, 22.5351429], [69.96098328, 22.5351429], [69.96098328, 22.53541946], [69.96125031, 22.53541756], [69.96125031, 22.53569412], [69.96152496, 22.53569412], [69.96152496, 22.5359726], [69.96208191, 22.5359726], [69.96208191, 22.53625107], [69.96235657, 22.53625107], [69.96235657, 22.53652954], [69.96263885, 22.53652763], [69.96263885, 22.53708267], [69.96290588, 22.53708267], [69.96290588, 22.53736115], [69.96375275, 22.53736115], [69.96375275, 22.53763962], [69.96430206, 22.53763962], [69.96430206, 22.53792], [69.9651413, 22.53791618], [69.9651413, 22.53819466], [69.96570587, 22.53819275], [69.96570587, 22.53848076], [69.96652985, 22.53848076], [69.96652985, 22.53874969], [69.96736145, 22.53874969], [69.96736145, 22.53903008], [69.96847534, 22.53902817], [69.96847534, 22.53930473], [69.9695816, 22.53930473], [69.9695816, 22.53958321], [69.97041321, 22.53958321], [69.97041321, 22.53986168], [69.97097015, 22.53985977], [69.97097015, 22.54014015], [69.97207642, 22.54014015], [69.97207642, 22.54042053], [69.97264862, 22.54042053], [69.9734726, 22.54042053], [69.9734726, 22.54070091], [69.97374725, 22.54070091], [69.97374725, 22.54042053], [69.97680664, 22.54042053], [69.97680664, 22.54014015], [69.97764587, 22.54014015], [69.97764587, 22.54042053], [69.97875214, 22.54042053], [69.97875214, 22.54014015], [69.9798584, 22.54014015], [69.9798584, 22.54042053], [69.98014069, 22.54042053], [69.98014069, 22.54070091], [69.98069763, 22.54069519], [69.98069763, 22.54097176], [69.98124695, 22.54096985], [69.98124695, 22.54125023], [69.98180389, 22.54125023], [69.98180389, 22.5415287], [69.98226166, 22.54152107], [69.98236084, 22.5415287], [69.98236084, 22.54181099], [69.98319244, 22.54180527], [69.98319244, 22.54208374], [69.98347473, 22.54208374], [69.98347473, 22.54180527], [69.98401642, 22.54181099], [69.98401642, 22.54152107], [69.98430634, 22.5415287], [69.98430634, 22.54097176], [69.98458099, 22.54097176], [69.98458099, 22.54069519], [69.98486328, 22.54070091], [69.98486328, 22.54043961], [69.98486328, 22.53958321], [69.98458099, 22.53958321], [69.98458099, 22.53874969], [69.98430634, 22.53874969], [69.98430634, 22.53819275], [69.98402405, 22.53819466], [69.98402405, 22.53763962], [69.98374939, 22.53763962], [69.98374939, 22.53736115], [69.98345947, 22.53736115], [69.98345947, 22.53708267], [69.98319244, 22.53708267], [69.98319244, 22.53652763], [69.98291779, 22.53652954], [69.98291779, 22.53625107], [69.98236084, 22.53625107], [69.98236084, 22.5359726], [69.98208618, 22.5359726], [69.98208618, 22.53569412], [69.98180389, 22.53569412], [69.98180389, 22.53541756], [69.98152924, 22.53541946], [69.98152924, 22.5351429], [69.98206329, 22.5351429], [69.98208618, 22.53486252], [69.98291779, 22.53486252], [69.98291779, 22.53513145], [69.98319244, 22.5351429], [69.98319244, 22.53541946], [69.98347473, 22.53541756], [69.98347473, 22.53569412], [69.98374939, 22.53569412], [69.98374939, 22.5359726], [69.98401642, 22.5359726], [69.98401642, 22.53652954], [69.98430634, 22.53652954], [69.98430634, 22.53680992], [69.98458099, 22.53680611], [69.98458099, 22.53708267], [69.98486328, 22.53708267], [69.98486328, 22.53763962], [69.98513794, 22.53763962], [69.98513794, 22.53792], [69.98542023, 22.53792], [69.98542023, 22.53848076], [69.98569489, 22.53847313], [69.98569489, 22.53930473], [69.98596954, 22.53930473], [69.98596954, 22.54031944], [69.98596954, 22.54042053], [69.98569489, 22.54041672], [69.98569489, 22.5415287], [69.98542023, 22.54152107], [69.98542023, 22.54181099], [69.98513794, 22.54180527], [69.98513794, 22.54208374], [69.98486328, 22.54207993], [69.98486328, 22.54236031], [69.98430634, 22.54236031], [69.98430634, 22.54264069], [69.98401642, 22.54264069], [69.98401642, 22.54292107], [69.98236084, 22.54292107], [69.98236084, 22.54264069], [69.98152924, 22.54264069], [69.98152924, 22.54236031], [69.98097229, 22.54236031], [69.98097229, 22.54222107], [69.98097229, 22.54208374], [69.98041534, 22.54208374], [69.98041534, 22.54180527], [69.98014069, 22.54181099], [69.98014069, 22.54152107], [69.9770813, 22.5415287], [69.9770813, 22.54125023], [69.97569275, 22.54125023], [69.97569275, 22.5415287], [69.97541809, 22.54152107], [69.97541809, 22.54181099], [69.9751358, 22.54180527], [69.9751358, 22.54208374], [69.97486115, 22.54207993], [69.97486115, 22.54236031], [69.9751358, 22.54236031], [69.9751358, 22.54264069], [69.97569275, 22.54264069], [69.97569275, 22.54292107], [69.97624969, 22.54291534], [69.97624969, 22.54319382], [69.9779129, 22.54319382], [69.9779129, 22.54347229], [69.97866821, 22.54347229], [69.97957611, 22.54347038], [69.97957611, 22.54375076], [69.98319244, 22.54375076], [69.98319244, 22.54403114], [69.98374939, 22.54403114], [69.98374939, 22.54430962], [69.98542023, 22.5443058], [69.98542023, 22.54458237], [69.98680878, 22.54458427], [69.98680878, 22.54486084], [69.98819733, 22.54486084], [69.98819733, 22.54514122], [69.98958588, 22.54514122], [69.98958588, 22.54541969], [69.99069214, 22.54541588], [69.99069214, 22.54569435], [69.99208069, 22.54569435], [69.99208069, 22.54597282], [69.99318695, 22.54597092], [69.99318695, 22.54624748], [69.99430847, 22.54624748], [69.99430847, 22.54653168], [69.99568939, 22.54653168], [69.99568939, 22.54681015], [69.99708557, 22.54680634], [69.99708557, 22.5470829], [69.99874878, 22.5470829], [69.99874878, 22.54735947], [70.0, 22.54735947], [70.00125122, 22.54735947], [70.00125122, 22.5470829], [70.00152588, 22.5470829], [70.00152588, 22.54680634], [70.00208282, 22.54681015], [70.00208282, 22.54653168], [70.00263977, 22.54653168], [70.00263977, 22.54597092], [70.00291443, 22.54597282], [70.00291443, 22.5443058], [70.00402832, 22.5443058], [70.00402832, 22.54569435], [70.00430298, 22.54569054], [70.00430298, 22.54653168], [70.00485992, 22.54653168], [70.00485992, 22.54681015], [70.00541687, 22.54680634], [70.00541687, 22.5470829], [70.00597382, 22.5470829], [70.00597382, 22.54735947], [70.00681305, 22.54735947], [70.00681305, 22.54764938], [70.00762939, 22.54764938], [70.00762939, 22.54792023], [70.00875092, 22.54791641], [70.00875092, 22.54819489], [70.00958252, 22.54819489], [70.00958252, 22.54846954], [70.01040649, 22.54846954], [70.01040649, 22.54875183], [70.01097107, 22.54875183], [70.01097107, 22.54846954], [70.01152802, 22.54846954], [70.01152802, 22.54819489], [70.01180267, 22.54819489], [70.01180267, 22.54791641], [70.01264191, 22.54792023], [70.01264191, 22.54764938], [70.01346588, 22.54764938], [70.01346588, 22.54735947], [70.01430511, 22.54735947], [70.01430511, 22.5470829], [70.01486206, 22.5470829], [70.01486206, 22.54680634], [70.01985931, 22.54680634], [70.01985931, 22.5470829], [70.02041626, 22.5470829], [70.02041626, 22.54735947], [70.02069092, 22.54735947], [70.02069092, 22.54764938], [70.02097321, 22.54764938], [70.02097321, 22.54792023], [70.02124786, 22.54791641], [70.02124786, 22.54819489], [70.02153015, 22.54819489], [70.02153015, 22.54846954], [70.0220871, 22.54846954], [70.0220871, 22.54875183], [70.02236176, 22.54875183], [70.02236176, 22.5490303], [70.02263641, 22.5490303], [70.02263641, 22.54931068], [70.02347565, 22.54930496], [70.02347565, 22.54958344], [70.02375031, 22.54958344], [70.02375031, 22.54986382], [70.02403259, 22.54986191], [70.02403259, 22.55042076], [70.02430725, 22.55041695], [70.02430725, 22.55069351], [70.0248642, 22.55069351], [70.0248642, 22.55097389], [70.02680206, 22.55097389], [70.02680206, 22.55069351], [70.02708435, 22.55069351], [70.02708435, 22.55041695], [70.02735901, 22.55042076], [70.02735901, 22.55014038], [70.02791595, 22.55014038], [70.02791595, 22.54986191], [70.02819061, 22.54986382], [70.02819824, 22.54958344], [70.0284729, 22.54958344], [70.0284729, 22.54819489], [70.02819824, 22.54819489], [70.02819061, 22.54680634], [70.02791595, 22.54681015], [70.02791595, 22.54653168], [70.0276413, 22.54653168], [70.0276413, 22.54624748], [70.02735901, 22.54624748], [70.02735901, 22.54597092], [70.02708435, 22.54597282], [70.02708435, 22.54569435], [70.0265274, 22.54569435], [70.0265274, 22.54541588], [70.02625275, 22.54541969], [70.02625275, 22.54514122], [70.02597046, 22.54514122], [70.02597046, 22.54486084], [70.0256958, 22.54486084], [70.0256958, 22.54458046], [70.02513885, 22.54458427], [70.02513885, 22.5443058], [70.02485657, 22.54430962], [70.02484894, 22.54404068], [70.02458191, 22.54403114], [70.02458191, 22.54388046], [70.02458191, 22.54375076], [70.02430725, 22.54375076], [70.02430725, 22.54347229], [70.02388763, 22.54347229], [70.02375031, 22.54347229], [70.02375031, 22.54319382], [70.02347565, 22.54319382], [70.02347565, 22.54263878], [70.02319336, 22.54264069], [70.02319336, 22.54207993], [70.0229187, 22.54208374], [70.0229187, 22.5415287], [70.02263641, 22.5415287], [70.02263641, 22.54097176], [70.02236176, 22.54097176], [70.02236176, 22.54041672], [70.0220871, 22.54042053], [70.0220871, 22.53957939], [70.02347565, 22.53958321], [70.02347565, 22.53986168], [70.02375031, 22.53985977], [70.02375031, 22.54042053], [70.02403259, 22.54042053], [70.02403259, 22.54070091], [70.02430725, 22.54069519], [70.02430725, 22.54097176], [70.02458191, 22.54096985], [70.02458191, 22.54125023], [70.0248642, 22.54125023], [70.0248642, 22.5415287], [70.02513885, 22.5415287], [70.02513885, 22.54208374], [70.02540588, 22.54207993], [70.02540588, 22.54236031], [70.0256958, 22.54236031], [70.0256958, 22.54264069], [70.02597046, 22.54264069], [70.02597046, 22.54292107], [70.02625275, 22.54291534], [70.02625275, 22.54319382], [70.02680206, 22.54319382], [70.02680206, 22.54347229], [70.02735901, 22.54347038], [70.02735901, 22.54375076], [70.02791595, 22.54375076], [70.02791595, 22.54403114], [70.02819824, 22.54403114], [70.02819824, 22.54430962], [70.02874756, 22.5443058], [70.02874756, 22.54458237], [70.02929688, 22.54458046], [70.02929688, 22.54514122], [70.02958679, 22.54513741], [70.02958679, 22.54569435], [70.02986145, 22.54569054], [70.02986145, 22.54624748], [70.03013611, 22.54624748], [70.03013611, 22.5471611], [70.03013611, 22.54792023], [70.0304184, 22.54792023], [70.0304184, 22.55181122], [70.03069305, 22.55181122], [70.03069305, 22.55236053], [70.03098297, 22.55236053], [70.03098297, 22.55291939], [70.03125, 22.55291748], [70.03125, 22.55347252], [70.0315094, 22.55346107], [70.0315094, 22.55375099], [70.03179932, 22.55375099], [70.03179932, 22.55430984], [70.0320816, 22.55430412], [70.0320816, 22.5545826], [70.03235626, 22.55458069], [70.03235626, 22.55486107], [70.03263855, 22.55486107], [70.03263855, 22.55541992], [70.03291321, 22.55541611], [70.03291321, 22.55569458], [70.0331955, 22.55569458], [70.0331955, 22.55597305], [70.03347015, 22.55597305], [70.03347015, 22.55652618], [70.03375244, 22.55652618], [70.03375244, 22.55680466], [70.0340271, 22.55680466], [70.0340271, 22.55708313], [70.03430176, 22.55708313], [70.03430939, 22.5573616], [70.03457642, 22.5573597], [70.03457642, 22.55763817], [70.03514099, 22.55763817], [70.03514099, 22.55792046], [70.03542328, 22.55792046], [70.03542328, 22.55820084], [70.03569794, 22.55819511], [70.03569794, 22.55847168], [70.0359726, 22.55846977], [70.0359726, 22.55874825], [70.03652954, 22.55874825], [70.03652954, 22.55903053], [70.04013824, 22.55903053], [70.04013824, 22.55958939], [70.03985596, 22.55958939], [70.03985596, 22.56041908], [70.0395813, 22.56041718], [70.0395813, 22.56069374], [70.03930664, 22.56069374], [70.03930664, 22.56097031], [70.03901672, 22.5609684], [70.03901672, 22.56291962], [70.0404129, 22.56291962], [70.0404129, 22.56236267], [70.04070282, 22.56236267], [70.04069519, 22.5620842], [70.04096985, 22.5620842], [70.04096985, 22.56180573], [70.04125214, 22.56180954], [70.04125214, 22.56125259], [70.04152679, 22.56125259], [70.04152679, 22.56041908], [70.04180908, 22.56041908], [70.04180908, 22.55985832], [70.04207611, 22.55985832], [70.04207611, 22.55931091], [70.0423584, 22.55931091], [70.0423584, 22.55874825], [70.04264069, 22.55874825], [70.04264069, 22.55820084], [70.04292297, 22.55820084], [70.04292297, 22.55792046], [70.04319763, 22.55792046], [70.04319763, 22.5573597], [70.04347229, 22.5573616], [70.04347229, 22.55708313], [70.04374695, 22.55708313], [70.04374695, 22.55680466], [70.04430389, 22.55680466], [70.04430389, 22.55652618], [70.04458618, 22.55652618], [70.04458618, 22.55624962], [70.04514313, 22.55624962], [70.0451355, 22.55597305], [70.04569244, 22.55597305], [70.04569244, 22.55569458], [70.04624939, 22.55569458], [70.04624939, 22.55541611], [70.04679871, 22.55541992], [70.04679871, 22.55513954], [70.04708099, 22.55513954], [70.04708099, 22.55486107], [70.04763794, 22.55486107], [70.04763794, 22.55458069], [70.04819489, 22.5545826], [70.04819489, 22.55430412], [70.04902649, 22.55430984], [70.04902649, 22.55402946], [70.04987335, 22.55402946], [70.04987335, 22.55375099], [70.05069733, 22.55375099], [70.05069733, 22.55346107], [70.05152893, 22.55347252], [70.05152893, 22.55319595], [70.05236053, 22.55319595], [70.05236053, 22.55291748], [70.05319214, 22.55291939], [70.05319214, 22.55264091], [70.05403137, 22.55264091], [70.05403137, 22.55236053], [70.05486298, 22.55236053], [70.05486298, 22.55208015], [70.05596924, 22.55208206], [70.05596924, 22.5518055], [70.05708313, 22.55181122], [70.05708313, 22.55153084], [70.05847168, 22.55153084], [70.05847168, 22.55125046], [70.0595932, 22.55125046], [70.05958557, 22.55097389], [70.06014252, 22.55097389], [70.06014252, 22.55069351], [70.06041718, 22.55069351], [70.06041718, 22.55041695], [70.06096649, 22.55042076], [70.06096649, 22.55014038], [70.06153107, 22.55014038], [70.06153107, 22.54986191], [70.06208038, 22.54986382], [70.06208038, 22.54958344], [70.06236267, 22.54958344], [70.06236267, 22.54930496], [70.06291962, 22.54931068], [70.06291962, 22.5490303], [70.06318665, 22.5490303], [70.06318665, 22.54875183], [70.06346893, 22.54875183], [70.06346893, 22.54846954], [70.06375122, 22.54846954], [70.06375122, 22.54791641], [70.06402588, 22.54792023], [70.06402588, 22.54735947], [70.06430817, 22.54735947], [70.06430817, 22.5470829], [70.06458282, 22.5470829], [70.06458282, 22.54680634], [70.06513977, 22.54680634], [70.06513977, 22.5470829], [70.06569672, 22.5470829], [70.06569672, 22.54735947], [70.06597137, 22.54735947], [70.06597137, 22.54764938], [70.06652832, 22.54764938], [70.06652832, 22.54792023], [70.06680298, 22.54791641], [70.06680298, 22.54819489], [70.06708527, 22.54819489], [70.06708527, 22.54846954], [70.06735992, 22.54846954], [70.06735992, 22.54875183], [70.06790924, 22.5487709], [70.06790924, 22.5490303], [70.06846619, 22.5490303], [70.06846619, 22.54931068], [70.06903076, 22.54930496], [70.06903076, 22.54958344], [70.06958008, 22.54958344], [70.06958008, 22.54986382], [70.07041931, 22.54986191], [70.07041931, 22.55014038], [70.07263947, 22.55014038], [70.07263947, 22.54986191], [70.07430267, 22.54986382], [70.07430267, 22.54958344], [70.07541656, 22.54958344], [70.07541656, 22.54930496], [70.07653046, 22.54931068], [70.07653046, 22.5490303], [70.07736206, 22.5490303], [70.07736206, 22.54875183], [70.07847595, 22.54875183], [70.07847595, 22.54846954], [70.07958221, 22.54846954], [70.07958221, 22.54819489], [70.08069611, 22.54819489], [70.08069611, 22.54791641], [70.08152771, 22.54792023], [70.08152771, 22.54764938], [70.0826416, 22.54764938], [70.0826416, 22.54735947], [70.08319092, 22.54735947], [70.08319092, 22.5470829], [70.08374786, 22.5470829], [70.08374786, 22.54680634], [70.08429718, 22.54681015], [70.08429718, 22.54597092], [70.0845871, 22.54597282], [70.0845871, 22.54541588], [70.08486176, 22.54541969], [70.08486176, 22.54514122], [70.08569336, 22.54514122], [70.08569336, 22.54486084], [70.08735657, 22.54486084], [70.08735657, 22.54541969], [70.08763885, 22.54541588], [70.08763885, 22.54597282], [70.08930206, 22.54597092], [70.08930206, 22.54624748], [70.09069824, 22.54624748], [70.09069824, 22.54653168], [70.09541321, 22.54653168], [70.09541321, 22.54681015], [70.0973587, 22.54680634], [70.0973587, 22.5470829], [70.10124969, 22.5470829], [70.10124969, 22.54680634], [70.10375214, 22.54681015], [70.10375214, 22.54653168], [70.10542297, 22.54653168], [70.10542297, 22.54597092], [70.10624695, 22.54597092], [70.10624695, 22.54624748], [70.10652924, 22.54624748], [70.10652924, 22.54653168], [70.10678864, 22.54653168], [70.10678864, 22.54681015], [70.11152649, 22.54680634], [70.11152649, 22.5470829], [70.11486053, 22.5470829], [70.11486053, 22.54735947], [70.11569214, 22.54735947], [70.11569214, 22.54764938], [70.11624908, 22.54764938], [70.11624908, 22.54792023], [70.11680603, 22.54791641], [70.11680603, 22.54819489], [70.11763763, 22.54819489], [70.11763763, 22.54791641], [70.11846924, 22.54792023], [70.11846924, 22.54764938], [70.11930847, 22.54764938], [70.11930847, 22.54735947], [70.11958313, 22.54735947], [70.11958313, 22.5470829], [70.11985779, 22.5470829], [70.11985779, 22.54652977], [70.12014008, 22.54653168], [70.12014008, 22.54624748], [70.1204071, 22.54624748], [70.1204071, 22.54597092], [70.12124634, 22.54597282], [70.12124634, 22.54569435], [70.12180328, 22.54569435], [70.12180328, 22.54597282], [70.12264252, 22.54597092], [70.12264252, 22.54624748], [70.12291718, 22.54624748], [70.12291718, 22.54653168], [70.12319183, 22.54653168], [70.12319183, 22.54681015], [70.12374878, 22.54680634], [70.12374878, 22.5470829], [70.12403107, 22.5470829], [70.12403107, 22.54735947], [70.12431335, 22.54735947], [70.12431335, 22.54764938], [70.12735748, 22.54764938], [70.12735748, 22.54792023], [70.12875366, 22.54791641], [70.12875366, 22.54819489], [70.12895203, 22.54819489], [70.13764191, 22.54819489], [70.13764191, 22.54846954], [70.13791656, 22.54846954], [70.13791656, 22.54875183], [70.13846588, 22.54875183], [70.13846588, 22.5490303], [70.13874817, 22.5490303], [70.13874817, 22.54931068], [70.13903046, 22.54930496], [70.13903046, 22.54958344], [70.13930511, 22.54958344], [70.13930511, 22.54986382], [70.13986206, 22.54986191], [70.13986206, 22.55014038], [70.14015198, 22.55014038], [70.14015198, 22.55042076], [70.14097595, 22.55042076], [70.14097595, 22.55014038], [70.14180756, 22.55014038], [70.14180756, 22.54986191], [70.14263916, 22.54986382], [70.14263916, 22.54958344], [70.14347076, 22.54957962], [70.14347076, 22.55042076], [70.14375305, 22.55042076], [70.14375305, 22.55153084], [70.14402771, 22.55152702], [70.14402771, 22.55208206], [70.14457703, 22.55208015], [70.14457703, 22.55236053], [70.14485931, 22.55236053], [70.14485931, 22.55264091], [70.14541626, 22.55264091], [70.14541626, 22.55291939], [70.14653015, 22.55291748], [70.14653015, 22.55319595], [70.14736176, 22.55319595], [70.14736176, 22.55347252], [70.14930725, 22.55347252], [70.14930725, 22.55319595], [70.1506958, 22.55319595], [70.1506958, 22.55291748], [70.15374756, 22.55291748], [70.15374756, 22.55319595], [70.15458679, 22.55319595], [70.15458679, 22.55347252], [70.15513611, 22.55347252], [70.15513611, 22.55319595], [70.15625, 22.55319595], [70.15625, 22.55291748], [70.15651703, 22.55291939], [70.15651703, 22.55264091], [70.1570816, 22.55264091], [70.1570816, 22.55236053], [70.15735626, 22.55236053], [70.15735626, 22.55208015], [70.15818787, 22.55208015], [70.15818787, 22.55264091], [70.15847015, 22.55264091], [70.15847015, 22.55291939], [70.15875244, 22.55291939], [70.15875244, 22.55264091], [70.15957642, 22.55264091], [70.15957642, 22.55236053], [70.16069794, 22.55236053], [70.16069794, 22.55208015], [70.16124725, 22.55208206], [70.16124725, 22.5518055], [70.16179657, 22.55181122], [70.16179657, 22.55153084], [70.16291809, 22.55153084], [70.16291809, 22.55181122], [70.16319275, 22.5518055], [70.16319275, 22.55208206], [70.16403198, 22.55208015], [70.16403198, 22.55291939], [70.1645813, 22.55291748], [70.1645813, 22.55319595], [70.16486359, 22.55319595], [70.16486359, 22.55347252], [70.1654129, 22.55346107], [70.1654129, 22.55375099], [70.16570282, 22.55375099], [70.16570282, 22.55402946], [70.16596985, 22.55402946], [70.16596985, 22.55430984], [70.16625214, 22.55430984], [70.16625214, 22.55486107], [70.16652679, 22.55486107], [70.16652679, 22.55513954], [70.16680908, 22.55513954], [70.16680908, 22.55541992], [70.16764069, 22.55541611], [70.16764069, 22.55569458], [70.16819763, 22.55569458], [70.16819763, 22.55597305], [70.16902924, 22.55597115], [70.16902924, 22.55624962], [70.16930389, 22.55624962], [70.16930389, 22.55652618], [70.16958618, 22.55652618], [70.16958618, 22.55680466], [70.16986084, 22.55680466], [70.16986084, 22.55708313], [70.17124939, 22.55708122], [70.17124939, 22.55763817], [70.17151642, 22.55763817], [70.17151642, 22.55792046], [70.17180634, 22.55791664], [70.17180634, 22.55847168], [70.17208099, 22.55846977], [70.17208099, 22.55903053], [70.17180634, 22.55903053], [70.17180634, 22.55958939], [70.17208099, 22.55958939], [70.17208099, 22.56014061], [70.17236328, 22.56014061], [70.17236328, 22.56069374], [70.17292023, 22.56069374], [70.17292023, 22.56097031], [70.17319489, 22.56097031], [70.17319489, 22.56125259], [70.17346954, 22.56125259], [70.17346954, 22.56153107], [70.17402649, 22.56153107], [70.17402649, 22.56180954], [70.17430878, 22.56180954], [70.17430878, 22.56236267], [70.17457581, 22.56236267], [70.17457581, 22.56291962], [70.17485809, 22.56291962], [70.17485809, 22.56375122], [70.17514038, 22.56375122], [70.17514038, 22.56431007], [70.17485809, 22.56430626], [70.17485809, 22.56458473], [70.17458344, 22.56458473], [70.17458344, 22.5648613], [70.17430878, 22.56485939], [70.17430878, 22.56513977], [70.17402649, 22.56513977], [70.17402649, 22.56542015], [70.17430878, 22.56541634], [70.17430878, 22.56569481], [70.17457581, 22.5656929], [70.17457581, 22.56624985], [70.17485809, 22.56624985], [70.17485809, 22.56708336], [70.17514038, 22.56707954], [70.17514038, 22.5676403], [70.17541504, 22.5676384], [70.17541504, 22.56847191], [70.17569733, 22.56846046], [70.17569733, 22.56903076], [70.17597198, 22.56903076], [70.17597198, 22.56931114], [70.17624664, 22.56930542], [70.17624664, 22.56986046], [70.17652893, 22.56986046], [70.17652893, 22.57014084], [70.17679596, 22.57014084], [70.17679596, 22.57042122], [70.17736053, 22.5704174], [70.17736053, 22.57069397], [70.17903137, 22.57069397], [70.17903137, 22.57097244], [70.1792984, 22.57097054], [70.1792984, 22.57125092], [70.17958069, 22.57125092], [70.17958069, 22.57180977], [70.17986298, 22.57180977], [70.17986298, 22.57263756], [70.18013763, 22.57263756], [70.18013763, 22.57375145], [70.18041992, 22.57375145], [70.18041992, 22.57459259], [70.18068695, 22.57459259], [70.18068695, 22.57542038], [70.18125153, 22.57542038], [70.18125153, 22.57514191], [70.18152618, 22.57514191], [70.18152618, 22.57486153], [70.18235779, 22.57486153], [70.18235779, 22.57514191], [70.18264008, 22.57514191], [70.18264008, 22.57570267], [70.1829071, 22.57570267], [70.1829071, 22.57625008], [70.18319702, 22.57625008], [70.18319702, 22.57681084], [70.18347168, 22.57681084], [70.18347168, 22.57736015], [70.18374634, 22.57736015], [70.18374634, 22.58041954], [70.18486023, 22.58041573], [70.18486023, 22.5806942], [70.18569183, 22.5806942], [70.18569183, 22.58097267], [70.18624878, 22.58097076], [70.18624878, 22.58125114], [70.18653107, 22.58125114], [70.18653107, 22.58152962], [70.18681335, 22.58152962], [70.18681335, 22.58181], [70.18708038, 22.58180428], [70.18708038, 22.58208275], [70.18736267, 22.58208084], [70.18736267, 22.58374977], [70.18846893, 22.58374977], [70.18846893, 22.58402824], [70.18819427, 22.58402634], [70.18819427, 22.58458328], [70.18791962, 22.58457947], [70.18791962, 22.58513832], [70.1882019, 22.58513832], [70.1882019, 22.58542061], [70.18985748, 22.58542061], [70.18985748, 22.58513832], [70.1904068, 22.58513832], [70.1904068, 22.58485985], [70.19069672, 22.58486176], [70.19069672, 22.58458328], [70.19097137, 22.58458328], [70.19097137, 22.58430481], [70.19125366, 22.58430481], [70.19125366, 22.58402634], [70.1920929, 22.58402824], [70.1920929, 22.58292007], [70.19430542, 22.58291626], [70.19430542, 22.58430481], [70.19458008, 22.58430481], [70.19458008, 22.58486176], [70.19486237, 22.58485985], [70.19486237, 22.58542061], [70.19513702, 22.58542061], [70.19513702, 22.5862484], [70.19541931, 22.5862484], [70.19541931, 22.5868206], [70.19568634, 22.5868206], [70.19568634, 22.58764076], [70.19596863, 22.58764076], [70.19596863, 22.58903122], [70.19458008, 22.58903122], [70.19458008, 22.58735847], [70.19429779, 22.58735847], [70.19429779, 22.5868206], [70.19403076, 22.5868206], [70.19403076, 22.58596992], [70.19319153, 22.58596992], [70.19319153, 22.58653069], [70.19291687, 22.58653069], [70.19291687, 22.58930969], [70.19319153, 22.58930588], [70.19319153, 22.59097481], [70.19347382, 22.59097481], [70.19347382, 22.59236145], [70.19374847, 22.59235954], [70.19374847, 22.5929203], [70.19403076, 22.59291649], [70.19403076, 22.59486198], [70.19374847, 22.59486198], [70.19374847, 22.59597206], [70.19346619, 22.59597015], [70.19346619, 22.59680939], [70.19319153, 22.59680557], [70.19319153, 22.59819412], [70.19346619, 22.59819031], [70.19346619, 22.5987606], [70.19458008, 22.5987606], [70.19458008, 22.59930992], [70.19430542, 22.59930611], [70.19430542, 22.59958267], [70.19458008, 22.59958076], [70.19458008, 22.60014153], [70.19486237, 22.60014153], [70.19486237, 22.60069466], [70.19458008, 22.60069466], [70.19458008, 22.60097313], [70.19429779, 22.60096931], [70.19429779, 22.6012516], [70.19403076, 22.6012516], [70.19403076, 22.60180473], [70.19430542, 22.60180473], [70.19430542, 22.60208321], [70.19486237, 22.60208321], [70.19486237, 22.60180473], [70.19569397, 22.60180473], [70.19569397, 22.60236168], [70.19541931, 22.60236168], [70.19541931, 22.60264015], [70.19486237, 22.60264015], [70.19486237, 22.60292053], [70.19458008, 22.60292053], [70.19458008, 22.60320282], [70.19429779, 22.60320282], [70.19429779, 22.60375023], [70.19513702, 22.60375023], [70.19513702, 22.6043129], [70.19541931, 22.6043129], [70.19541931, 22.60486031], [70.19568634, 22.60486031], [70.19568634, 22.60542107], [70.19541931, 22.60541725], [70.19541931, 22.60597229], [70.19625092, 22.60597229], [70.19625092, 22.60486031], [70.19680786, 22.60486031], [70.19680786, 22.60514069], [70.19737244, 22.60514069], [70.19737244, 22.60542107], [70.19791412, 22.60541725], [70.19791412, 22.60569572], [70.19847107, 22.60569572], [70.19847107, 22.60541725], [70.19875336, 22.60542107], [70.19875336, 22.60514069], [70.19930267, 22.60514069], [70.19930267, 22.60457039], [70.19958496, 22.60458374], [70.19958496, 22.60375023], [70.20069122, 22.60375023], [70.20069122, 22.60486031], [70.20041656, 22.60486031], [70.20041656, 22.60569572], [70.20097351, 22.60569572], [70.20097351, 22.60513878], [70.20124817, 22.60514069], [70.20124817, 22.60457039], [70.20207977, 22.60457039], [70.20207977, 22.60542107], [70.20236206, 22.60542107], [70.20236206, 22.60486031], [70.20291901, 22.60486031], [70.20291901, 22.60542107], [70.20317841, 22.60542107], [70.20317841, 22.60653114], [70.20291901, 22.60653114], [70.20291901, 22.60680962], [70.20263672, 22.60680962], [70.20263672, 22.60736084], [70.20236206, 22.60736084], [70.20236206, 22.60791969], [70.20153046, 22.60791969], [70.20153046, 22.60762978], [70.20069122, 22.60763931], [70.20069122, 22.60736084], [70.20014191, 22.60736084], [70.20014191, 22.60708046], [70.19985962, 22.60708427], [70.19985962, 22.6068058], [70.19875336, 22.60680962], [70.19875336, 22.60653114], [70.19847107, 22.60653114], [70.19847107, 22.60874939], [70.19902802, 22.60874939], [70.19902802, 22.60902977], [70.19930267, 22.60902977], [70.19930267, 22.60931015], [70.19958496, 22.60930634], [70.19958496, 22.6095829], [70.19985962, 22.6095829], [70.19985962, 22.60986137], [70.19959259, 22.60985947], [70.19959259, 22.61013985], [70.19902802, 22.61013985], [70.19902802, 22.61070061], [70.19875336, 22.61069489], [70.19875336, 22.61097145], [70.19819641, 22.61096954], [70.19819641, 22.61124992], [70.19763947, 22.61124992], [70.19763947, 22.6115303], [70.19680786, 22.6115303], [70.19680786, 22.61124992], [70.19596863, 22.61124992], [70.19596863, 22.61070061], [70.19513702, 22.61070061], [70.19513702, 22.61124992], [70.19486237, 22.61124992], [70.19486237, 22.61236191], [70.19513702, 22.61235809], [70.19513702, 22.61292076], [70.19569397, 22.61291885], [70.19569397, 22.61319351], [70.19625092, 22.61319351], [70.19625092, 22.61291885], [70.1965332, 22.61292076], [70.1965332, 22.61263847], [70.19680786, 22.61263847], [70.19680786, 22.61235809], [70.19737244, 22.61235809], [70.19737244, 22.61292076], [70.19847107, 22.61291885], [70.19847107, 22.6131897], [70.19819641, 22.61319923], [70.19819641, 22.6137619], [70.19790649, 22.6137619], [70.19790649, 22.61430931], [70.19819641, 22.61430931], [70.19819641, 22.61541939], [70.19791412, 22.61541748], [70.19791412, 22.61597252], [70.19763947, 22.61597252], [70.19763947, 22.6162529], [70.19736481, 22.61624908], [70.19736481, 22.61680603], [70.19763947, 22.61680603], [70.19763947, 22.6170826], [70.19791412, 22.6170826], [70.19791412, 22.61652756], [70.19819641, 22.61652946], [70.19819641, 22.61597252], [70.19875336, 22.61597252], [70.19875336, 22.61541748], [70.19958496, 22.61541748], [70.19958496, 22.61597252], [70.19930267, 22.61597252], [70.19930267, 22.6162529], [70.19902802, 22.61624908], [70.19902802, 22.61680603], [70.19930267, 22.61680031], [70.19930267, 22.61736107], [70.20014191, 22.61736107], [70.20014191, 22.61763954], [70.20069122, 22.61763954], [70.20069122, 22.61791992], [70.20097351, 22.61791611], [70.20097351, 22.61819458], [70.20153046, 22.61819458], [70.20153046, 22.61847305], [70.20181274, 22.61847115], [70.20181274, 22.61903], [70.20153046, 22.61902809], [70.20153046, 22.61958313], [70.20180511, 22.61958313], [70.20180511, 22.6198616], [70.20236206, 22.6198597], [70.20236206, 22.62014008], [70.20317841, 22.62014008], [70.20317841, 22.61956978], [70.2040329, 22.61956978], [70.2040329, 22.62014008], [70.20540619, 22.62014008], [70.20540619, 22.62042046], [70.20597076, 22.62042046], [70.20597076, 22.62070084], [70.20625305, 22.62069511], [70.20625305, 22.62097168], [70.20707703, 22.62096977], [70.20707703, 22.62125015], [70.2076416, 22.62125015], [70.2076416, 22.62153053], [70.20791626, 22.62153053], [70.20791626, 22.62181091], [70.20847321, 22.62180519], [70.20847321, 22.62208366], [70.20874786, 22.62207985], [70.20874786, 22.62236023], [70.20903015, 22.62236023], [70.20903015, 22.62319374], [70.20847321, 22.62318993], [70.20847321, 22.62403107], [70.20819092, 22.62403107], [70.20819092, 22.62430954], [70.20791626, 22.62430954], [70.20791626, 22.62514114], [70.20819092, 22.62514114], [70.20819092, 22.62541962], [70.20847321, 22.62541962], [70.20847321, 22.62514114], [70.21013641, 22.62514114], [70.21013641, 22.62486076], [70.20986176, 22.62486076], [70.20986176, 22.62403107], [70.21013641, 22.62403107], [70.21013641, 22.62375069], [70.2104187, 22.62375069], [70.2104187, 22.62318993], [70.21152496, 22.62319374], [70.21152496, 22.62347221], [70.21180725, 22.62347031], [70.21180725, 22.62403107], [70.21208191, 22.62402725], [70.21208191, 22.6245842], [70.2123642, 22.6245842], [70.2123642, 22.62486076], [70.21263885, 22.62486076], [70.21263885, 22.62624931], [70.21208191, 22.62624931], [70.21208191, 22.62597084], [70.21180725, 22.62597084], [70.21180725, 22.62624931], [70.21153259, 22.62624931], [70.21153259, 22.6265316], [70.21180725, 22.6265316], [70.21180725, 22.62681007], [70.21208191, 22.62681007], [70.21208191, 22.62764168], [70.21153259, 22.62764168], [70.21153259, 22.62792015], [70.21125031, 22.62792015], [70.21125031, 22.62903023], [70.21069336, 22.62902832], [70.21069336, 22.62930489], [70.21152496, 22.62930489], [70.21152496, 22.62986374], [70.21208191, 22.62986183], [70.21208191, 22.6301403], [70.21347046, 22.6301403], [70.21347046, 22.62986183], [70.21375275, 22.62986374], [70.21375275, 22.62930489], [70.2140274, 22.62930489], [70.2140274, 22.62791634], [70.21485901, 22.62791634], [70.21485901, 22.62819481], [70.2151413, 22.62819481], [70.2151413, 22.62791634], [70.21540833, 22.62792015], [70.21540833, 22.62764168], [70.21652985, 22.62764168], [70.21652985, 22.62792015], [70.21763611, 22.62791634], [70.21763611, 22.62930489], [70.2179184, 22.62929916], [70.2179184, 22.6301403], [70.21846771, 22.6301403], [70.21846771, 22.62986183], [70.21875, 22.62986374], [70.21875, 22.62958336], [70.21985626, 22.62957954], [70.21985626, 22.6301403], [70.2195816, 22.6301384], [70.2195816, 22.63208389], [70.21985626, 22.63208008], [70.21985626, 22.63236046], [70.22013855, 22.63236046], [70.22013855, 22.63402939], [70.22041321, 22.63402939], [70.22041321, 22.63430977], [70.22013855, 22.63430405], [70.22013855, 22.63458252], [70.21875, 22.63458252], [70.21875, 22.63430405], [70.2181778, 22.63430977], [70.2181778, 22.63402939], [70.21846771, 22.63402939], [70.21846771, 22.63347054], [70.2181778, 22.63347054], [70.2181778, 22.63375092], [70.2179184, 22.63375092], [70.2179184, 22.63402939], [70.21763611, 22.63402939], [70.21763611, 22.63430977], [70.21652985, 22.63430977], [70.21652985, 22.63487053], [70.2159729, 22.63487053], [70.2159729, 22.63458061], [70.21569824, 22.63458252], [70.21569061, 22.63430405], [70.21569061, 22.63402748], [70.21540833, 22.63402939], [70.21540833, 22.63347054], [70.21457672, 22.63347054], [70.21457672, 22.63375092], [70.21430206, 22.63375092], [70.21430206, 22.63402939], [70.21375275, 22.63402939], [70.21375275, 22.63430977], [70.2140274, 22.63430977], [70.2140274, 22.63487053], [70.21430206, 22.63487053], [70.21430206, 22.63541985], [70.21458435, 22.63541794], [70.21458435, 22.6356945], [70.21569824, 22.6356945], [70.21569824, 22.63597298], [70.21679688, 22.63597107], [70.21679688, 22.63624954], [70.21763611, 22.63624954], [70.21763611, 22.63652992], [70.2179184, 22.63652611], [70.2179184, 22.63736153], [70.21736145, 22.63735962], [70.21736145, 22.63820076], [70.21679688, 22.63820076], [70.21679688, 22.63793182], [70.21652985, 22.63793182], [70.21652985, 22.63903046], [70.2159729, 22.63903046], [70.2159729, 22.63931084], [70.21541595, 22.63930511], [70.21541595, 22.63958359], [70.21569824, 22.63957977], [70.21569824, 22.64042091], [70.2159729, 22.6404171], [70.2159729, 22.64097023], [70.21624756, 22.64096832], [70.21624756, 22.6415329], [70.21652985, 22.6415329], [70.21652985, 22.64096832], [70.2168045, 22.64097023], [70.2168045, 22.6404171], [70.21708679, 22.64042091], [70.21708679, 22.64014053], [70.21736145, 22.64014053], [70.21736145, 22.63957977], [70.21763611, 22.63958359], [70.21763611, 22.63874817], [70.21846771, 22.63874817], [70.21846771, 22.63820076], [70.21901703, 22.63820076], [70.21901703, 22.63931084], [70.21930695, 22.63931084], [70.21930695, 22.63903046], [70.2195816, 22.63903046], [70.2195816, 22.63874817], [70.21985626, 22.63874817], [70.21985626, 22.6384697], [70.2195816, 22.6384716], [70.2195816, 22.63819504], [70.21930695, 22.63820076], [70.21930695, 22.63735962], [70.22013855, 22.63735962], [70.22013855, 22.63793182], [70.22070313, 22.63793182], [70.22070313, 22.63820076], [70.22125244, 22.63819504], [70.22125244, 22.6384716], [70.2215271, 22.6384697], [70.2215271, 22.63874817], [70.22207642, 22.63874817], [70.22207642, 22.63903046], [70.2223587, 22.63903046], [70.2223587, 22.6384697], [70.2234726, 22.6384697], [70.2234726, 22.63874817], [70.22374725, 22.63874817], [70.22374725, 22.63903046], [70.22431183, 22.63903046], [70.22431183, 22.63931084], [70.22486115, 22.63930511], [70.22486115, 22.63958359], [70.2251358, 22.63957977], [70.2251358, 22.63985825], [70.22598267, 22.63985825], [70.22598267, 22.64042091], [70.22569275, 22.6404171], [70.22569275, 22.64069366], [70.22541809, 22.64069366], [70.22541809, 22.64097023], [70.2251358, 22.64097023], [70.2251358, 22.64208412], [70.22541809, 22.64208031], [70.22541809, 22.64264107], [70.22598267, 22.64264107], [70.22598267, 22.64291954], [70.22652435, 22.64291573], [70.22652435, 22.6431942], [70.2270813, 22.64319038], [70.2270813, 22.64402962], [70.22651672, 22.64402962], [70.22651672, 22.64431], [70.22680664, 22.64430618], [70.22680664, 22.64458466], [70.22734833, 22.64458275], [70.22734833, 22.64486122], [70.22763824, 22.64486122], [70.22763824, 22.64513969], [70.2279129, 22.64513969], [70.2279129, 22.64542007], [70.22819519, 22.64541626], [70.22819519, 22.6459713], [70.22875214, 22.6459713], [70.22875214, 22.64569473], [70.22930908, 22.64569473], [70.22930908, 22.6459713], [70.22958374, 22.6459713], [70.22958374, 22.64569473], [70.23014069, 22.64569283], [70.23014069, 22.64624977], [70.23040771, 22.64624977], [70.23040771, 22.64681053], [70.23069763, 22.64681053], [70.23069763, 22.64764023], [70.23040771, 22.64764023], [70.23040771, 22.64903069], [70.23069763, 22.64902687], [70.23069763, 22.64958382], [70.23097229, 22.64958], [70.23097229, 22.64986992], [70.23152924, 22.64986992], [70.23152924, 22.65014076], [70.23236084, 22.65014076], [70.23236084, 22.64986992], [70.23208618, 22.64986992], [70.23208618, 22.64958], [70.23180389, 22.64958382], [70.23180389, 22.64930534], [70.23236084, 22.64930534], [70.23236084, 22.64958382], [70.23291779, 22.64958382], [70.23291779, 22.64902687], [70.23458099, 22.64903069], [70.23458099, 22.64931107], [70.23486328, 22.64931107], [70.23486328, 22.64986992], [70.23513794, 22.64986992], [70.23513794, 22.65042114], [70.23486328, 22.65041733], [70.23486328, 22.65069389], [70.23430634, 22.65069389], [70.23430634, 22.65208244], [70.23401642, 22.65208054], [70.23401642, 22.65236092], [70.23374939, 22.65236092], [70.23374939, 22.65263748], [70.2326355, 22.65263748], [70.2326355, 22.6515274], [70.23208618, 22.65153122], [70.23208618, 22.65263748], [70.23124695, 22.65263748], [70.23124695, 22.6534729], [70.2298584, 22.65346909], [70.2298584, 22.65375137], [70.22957611, 22.65375137], [70.22957611, 22.65514183], [70.22930908, 22.65514183], [70.22930908, 22.6554203], [70.22902679, 22.65541649], [70.22902679, 22.65596962], [70.22930908, 22.65596962], [70.22930908, 22.65653038], [70.22902679, 22.65652847], [70.22902679, 22.65736389], [70.22930908, 22.65736389], [70.22930908, 22.65708351], [70.23014069, 22.65708351], [70.23014069, 22.65680504], [70.23069763, 22.65681076], [70.23069763, 22.65653038], [70.23124695, 22.65653038], [70.23124695, 22.65596962], [70.23208618, 22.65596962], [70.23208618, 22.65569496], [70.23236084, 22.65570068], [70.23236084, 22.6554203], [70.23264313, 22.6554203], [70.23264313, 22.65485954], [70.23401642, 22.65485954], [70.23401642, 22.65514183], [70.23458099, 22.65514183], [70.23458099, 22.6554203], [70.23486328, 22.6554203], [70.23486328, 22.65570068], [70.23569489, 22.65569496], [70.23569489, 22.65596962], [70.23596954, 22.65596962], [70.23596954, 22.65708351], [70.23569489, 22.65708351], [70.23569489, 22.65736389], [70.23542023, 22.65736008], [70.23542023, 22.65792084], [70.23513794, 22.65791702], [70.23513794, 22.65819359], [70.23486328, 22.65818977], [70.23486328, 22.65903091], [70.23458099, 22.6590271], [70.23458099, 22.65958595], [70.23486328, 22.65958023], [70.23486328, 22.65986061], [70.23542023, 22.65986061], [70.23542023, 22.66014099], [70.23568726, 22.66014099], [70.23568726, 22.66041946], [70.23625183, 22.66041756], [70.23625183, 22.66069412], [70.23652649, 22.66069412], [70.23652649, 22.6609726], [70.23791504, 22.6609726], [70.23791504, 22.66069412], [70.23847198, 22.66069412], [70.23847198, 22.6609726], [70.23874664, 22.66097069], [70.23874664, 22.66125107], [70.23902893, 22.66125107], [70.23902893, 22.66152954], [70.23928833, 22.66152954], [70.23928833, 22.66180992], [70.23958588, 22.6618042], [70.23958588, 22.66208267], [70.23986053, 22.66208076], [70.23986053, 22.66236115], [70.2409668, 22.66236115], [70.2409668, 22.66263962], [70.24291992, 22.66263962], [70.24291992, 22.66291809], [70.24263763, 22.66291618], [70.24263763, 22.66319466], [70.24236298, 22.66319466], [70.24236298, 22.66347313], [70.24208069, 22.66347122], [70.24208069, 22.66374969], [70.24180603, 22.66374969], [70.24180603, 22.66402817], [70.24153137, 22.66402626], [70.24153137, 22.66430473], [70.24124908, 22.66430473], [70.24124908, 22.66486168], [70.2409668, 22.66485023], [70.2409668, 22.66513824], [70.24069214, 22.66513824], [70.24069214, 22.66542053], [70.24041748, 22.66542053], [70.24041748, 22.66570091], [70.24014282, 22.66570091], [70.24014282, 22.66653061], [70.24041748, 22.66653061], [70.24041748, 22.66708374], [70.24069214, 22.66707993], [70.24069214, 22.6673584], [70.24097443, 22.6673584], [70.24097443, 22.66819382], [70.24069214, 22.66819382], [70.24069214, 22.66847038], [70.2409668, 22.66847038], [70.2409668, 22.66903114], [70.24124908, 22.66903114], [70.24124908, 22.66875267], [70.24153137, 22.66875267], [70.24153137, 22.66958046], [70.24208069, 22.66958046], [70.24208069, 22.6693058], [70.24236298, 22.6693058], [70.24236298, 22.66958046], [70.24263763, 22.66958046], [70.24263763, 22.6693058], [70.24346924, 22.66930962], [70.24346924, 22.66986275], [70.24375153, 22.66986275], [70.24375153, 22.67014122], [70.24458313, 22.67014122], [70.24458313, 22.67041969], [70.24485779, 22.67041969], [70.24485779, 22.66986275], [70.2454071, 22.66986275], [70.2454071, 22.67124939], [70.24514008, 22.67124939], [70.24514008, 22.67152977], [70.24485779, 22.67152977], [70.24485779, 22.67181015], [70.24458313, 22.67180634], [70.24458313, 22.67236137], [70.24485779, 22.67236137], [70.24485779, 22.67208481], [70.24541473, 22.67208481], [70.24541473, 22.67180634], [70.24569702, 22.67180634], [70.24569702, 22.67208481], [70.24597168, 22.67208481], [70.24597168, 22.67180634], [70.24624634, 22.67181015], [70.24624634, 22.67124939], [70.24652863, 22.67124939], [70.24652863, 22.67152977], [70.24680328, 22.67152977], [70.24680328, 22.67181015], [70.24652863, 22.67180634], [70.24652863, 22.67236137], [70.24624634, 22.67235947], [70.24624634, 22.67263985], [70.24597168, 22.67263985], [70.24597168, 22.67319489], [70.24541473, 22.67319489], [70.24541473, 22.67458344], [70.24485779, 22.67458344], [70.24485779, 22.67430687], [70.24430847, 22.67430687], [70.24430847, 22.67458344], [70.24375153, 22.67457962], [70.24375153, 22.67514038], [70.24402618, 22.67514038], [70.24402618, 22.67542076], [70.24430847, 22.67542076], [70.24430847, 22.67486], [70.24485779, 22.67486], [70.24485779, 22.67514038], [70.24514008, 22.67514038], [70.24514008, 22.67542076], [70.24485779, 22.67541695], [70.24485779, 22.67597198], [70.24375153, 22.67597198], [70.24375153, 22.67569542], [70.24318695, 22.6756897], [70.24319458, 22.67513847], [70.24291992, 22.67514038], [70.24291992, 22.67486], [70.24263763, 22.67486], [70.24263763, 22.67514038], [70.24208069, 22.67513847], [70.24208069, 22.6756897], [70.24124908, 22.67569542], [70.24124908, 22.67597198], [70.2409668, 22.67597008], [70.2409668, 22.67625046], [70.24069214, 22.67625046], [70.24069214, 22.67653084], [70.24041748, 22.67653084], [70.24041748, 22.67681122], [70.24013519, 22.6768055], [70.24013519, 22.67708397], [70.23874664, 22.67708397], [70.23874664, 22.67819405], [70.23930359, 22.67819405], [70.23930359, 22.67847252], [70.23960114, 22.67847061], [70.23960114, 22.67874908], [70.23986053, 22.67874908], [70.23986053, 22.67902756], [70.24013519, 22.67902756], [70.24013519, 22.6795826], [70.24041748, 22.67958069], [70.24041748, 22.68014145], [70.24069214, 22.68014145], [70.24069214, 22.67984962], [70.24124908, 22.67984962], [70.24124908, 22.68042183], [70.24153137, 22.68042183], [70.24153137, 22.68153191], [70.24180603, 22.68152809], [70.24180603, 22.68180466], [70.24291992, 22.68180466], [70.24291992, 22.68152809], [70.24318695, 22.68153191], [70.24318695, 22.68125153], [70.24291992, 22.68125153], [70.24291992, 22.68096924], [70.24263763, 22.68097305], [70.24263763, 22.68069458], [70.24236298, 22.68069458], [70.24236298, 22.68041611], [70.24208069, 22.68042183], [70.24208069, 22.67984962], [70.24291992, 22.67985916], [70.24291992, 22.67930603], [70.24318695, 22.67930984], [70.24318695, 22.67902756], [70.24375153, 22.67902756], [70.24375153, 22.67847061], [70.24458313, 22.67847061], [70.24458313, 22.67930984], [70.2454071, 22.67930984], [70.2454071, 22.68042183], [70.24514008, 22.68042183], [70.24514008, 22.68125153], [70.2454071, 22.68125153], [70.2454071, 22.68153191], [70.24514008, 22.68152809], [70.24514008, 22.6823616], [70.2454071, 22.6823616], [70.2454071, 22.68264008], [70.24569702, 22.68264008], [70.24569702, 22.68292046], [70.24597168, 22.68292046], [70.24597168, 22.68320274], [70.24624634, 22.68319511], [70.24624634, 22.68347359], [70.24819183, 22.68346977], [70.24819183, 22.68375015], [70.24874878, 22.68375015], [70.24874878, 22.68431091], [70.24903107, 22.68431091], [70.24903107, 22.68514061], [70.24931335, 22.68514061], [70.24931335, 22.68542099], [70.24903107, 22.68542099], [70.24903107, 22.68764114], [70.24931335, 22.68764114], [70.24931335, 22.68791962], [70.24958038, 22.6879158], [70.24958038, 22.68819427], [70.24986267, 22.68819046], [70.24986267, 22.68904114], [70.24847412, 22.68902779], [70.24847412, 22.6898613], [70.24930573, 22.6898613], [70.24930573, 22.69013977], [70.24958038, 22.69013977], [70.24958038, 22.68985939], [70.25068665, 22.68985939], [70.25068665, 22.69013977], [70.25096893, 22.69013977], [70.25096893, 22.69042015], [70.24930573, 22.69041634], [70.24930573, 22.69069481], [70.24903107, 22.69069481], [70.24903107, 22.69097137], [70.24986267, 22.69096947], [70.24986267, 22.69124985], [70.25013733, 22.69124985], [70.25013733, 22.69152832], [70.25125122, 22.69152641], [70.25125122, 22.69180489], [70.25152588, 22.69180489], [70.25152588, 22.69069481], [70.25180817, 22.69069481], [70.25180817, 22.69097137], [70.25235748, 22.69096947], [70.25235748, 22.69152832], [70.25208282, 22.69152641], [70.25208282, 22.69208336], [70.25263977, 22.69207954], [70.25263977, 22.6926384], [70.25319672, 22.6926384], [70.25319672, 22.69292068], [70.25208282, 22.69292068], [70.25208282, 22.69319916], [70.25180817, 22.69319534], [70.25180817, 22.69347191], [70.25208282, 22.69346809], [70.25208282, 22.69374847], [70.25180817, 22.69374847], [70.25180817, 22.69403076], [70.25154114, 22.69403076], [70.25154114, 22.69292068], [70.25125122, 22.69292068], [70.25125122, 22.69319916], [70.25096893, 22.69319534], [70.25096893, 22.69347191], [70.25068665, 22.69346809], [70.25068665, 22.69430923], [70.25041962, 22.69430923], [70.25041962, 22.69486237], [70.25068665, 22.69486237], [70.25068665, 22.69457817], [70.25096893, 22.69457817], [70.25096893, 22.69486237], [70.25125122, 22.69486237], [70.25125122, 22.69430923], [70.25152588, 22.69430542], [70.25152588, 22.69458389], [70.25180817, 22.69457817], [70.25180817, 22.69486237], [70.25208282, 22.69486237], [70.25208282, 22.69514275], [70.25180817, 22.69514275], [70.25180817, 22.69625282], [70.25152588, 22.69625282], [70.25152588, 22.69597244], [70.25125122, 22.69597244], [70.25125122, 22.69569206], [70.25096893, 22.69569206], [70.25096893, 22.6954174], [70.25068665, 22.69542122], [70.25068665, 22.69514275], [70.24986267, 22.69514275], [70.24986267, 22.69542122], [70.24930573, 22.6954174], [70.24930573, 22.69569206], [70.24903107, 22.69569016], [70.24903107, 22.69625282], [70.24874878, 22.69625282], [70.24874878, 22.69652939], [70.24848175, 22.69652939], [70.24848175, 22.69597244], [70.24764252, 22.69597244], [70.24764252, 22.69625282], [70.2470932, 22.69625282], [70.2470932, 22.69652939], [70.24652863, 22.69652939], [70.24652863, 22.69597244], [70.24597168, 22.69597244], [70.24597168, 22.69652939], [70.24569702, 22.69652939], [70.24569702, 22.69625282], [70.24485779, 22.69625282], [70.24485779, 22.69652939], [70.24514008, 22.69652939], [70.24514008, 22.69680977], [70.24458313, 22.69680977], [70.24458313, 22.69652939], [70.24318695, 22.69652939], [70.24318695, 22.69625282], [70.24208069, 22.69625282], [70.24208069, 22.69652939], [70.24153137, 22.69652939], [70.24153137, 22.69625282], [70.24069214, 22.69625282], [70.24069214, 22.69569016], [70.23958588, 22.69569206], [70.23958588, 22.69597244], [70.23902893, 22.69597244], [70.23902893, 22.69625282], [70.23874664, 22.69625282], [70.23874664, 22.69680977], [70.23902893, 22.69680977], [70.23902893, 22.69763947], [70.23928833, 22.69763947], [70.23928833, 22.69791985], [70.23960114, 22.69791985], [70.23960114, 22.69902992], [70.23930359, 22.69902802], [70.23930359, 22.69958305], [70.23902893, 22.69958115], [70.23902893, 22.70014], [70.23874664, 22.70014], [70.23874664, 22.70042038], [70.23847198, 22.70042038], [70.23847198, 22.70181084], [70.23874664, 22.70181084], [70.23874664, 22.70236015], [70.23928833, 22.70236015], [70.23928833, 22.70207977], [70.23958588, 22.70208359], [70.23958588, 22.70236015], [70.23986053, 22.70236015], [70.23986053, 22.70264053], [70.24041748, 22.70264053], [70.24041748, 22.70292091], [70.24124908, 22.70291519], [70.24124908, 22.70319366], [70.24236298, 22.70319366], [70.24236298, 22.70347214], [70.24291992, 22.70347214], [70.24291992, 22.70402718], [70.24319458, 22.70402718], [70.24319458, 22.70458412], [70.24346924, 22.70458031], [70.24346924, 22.70486069], [70.24430847, 22.70486069], [70.24430847, 22.70513916], [70.24485779, 22.70513725], [70.24485779, 22.70597267], [70.24514008, 22.70597076], [70.24514008, 22.70653152], [70.24485779, 22.70653152], [70.24485779, 22.7068119], [70.24375153, 22.7068119], [70.24375153, 22.70653152], [70.24346924, 22.70653152], [70.24346924, 22.70624924], [70.24318695, 22.70624924], [70.24318695, 22.70597076], [70.24291992, 22.70597267], [70.24291992, 22.7056942], [70.24236298, 22.7056942], [70.24236298, 22.70541954], [70.24208069, 22.70541954], [70.24208069, 22.70513916], [70.24180603, 22.70513916], [70.24180603, 22.70486069], [70.24153137, 22.70486069], [70.24153137, 22.70430946], [70.24124908, 22.70430946], [70.24124908, 22.70401955], [70.2409668, 22.70401955], [70.2409668, 22.70430946], [70.24069214, 22.70430565], [70.24069214, 22.70458412], [70.24041748, 22.70458031], [70.24041748, 22.70513916], [70.24069214, 22.70513725], [70.24069214, 22.70597267], [70.24124908, 22.70597076], [70.24124908, 22.70624924], [70.24153137, 22.70624924], [70.24153137, 22.7068119], [70.24124908, 22.7068119], [70.24124908, 22.70735931], [70.24153137, 22.70735931], [70.24153137, 22.70792007], [70.24180603, 22.70791626], [70.24180603, 22.70819473], [70.24208069, 22.70819473], [70.24208069, 22.70846939], [70.24263763, 22.70846939], [70.24263763, 22.70903015], [70.24291992, 22.70902824], [70.24291992, 22.70930481], [70.24319458, 22.70930481], [70.24319458, 22.70902824], [70.24346924, 22.70902824], [70.24346924, 22.70930481], [70.24375153, 22.70930481], [70.24375153, 22.70958328], [70.24402618, 22.70958328], [70.24402618, 22.70986366], [70.24430847, 22.70986176], [70.24430847, 22.71042061], [70.24597168, 22.71041679], [70.24597168, 22.71097374], [70.24624634, 22.71097183], [70.24624634, 22.71125031], [70.24652863, 22.71125031], [70.24652863, 22.71153069], [70.24764252, 22.71153069], [70.24764252, 22.71181107], [70.24874878, 22.71180534], [70.24874878, 22.71208382], [70.24930573, 22.71208382], [70.24930573, 22.71069527], [70.24903107, 22.7107029], [70.24903107, 22.70875168], [70.24958038, 22.70875168], [70.24958038, 22.70735931], [70.24930573, 22.70735931], [70.24930573, 22.70680618], [70.24903107, 22.7068119], [70.24903107, 22.70513916], [70.24931335, 22.70513916], [70.24931335, 22.70486069], [70.25013733, 22.70486069], [70.25013733, 22.70541954], [70.25041962, 22.70541573], [70.25041962, 22.70597267], [70.25069427, 22.70597267], [70.25069427, 22.7056942], [70.25096893, 22.7056942], [70.25096893, 22.70541573], [70.25125122, 22.70541954], [70.25125122, 22.70513916], [70.25180817, 22.70513916], [70.25180817, 22.70486069], [70.25319672, 22.70486069], [70.25319672, 22.70597267], [70.25428772, 22.70597076], [70.25428772, 22.70624924], [70.25485992, 22.70624924], [70.25485992, 22.70653152], [70.25514221, 22.70653152], [70.25514221, 22.70735931], [70.25485992, 22.70735931], [70.25485992, 22.7076416], [70.25514221, 22.7076416], [70.25514221, 22.70792007], [70.25541687, 22.70791626], [70.25541687, 22.70846939], [70.25514221, 22.70846939], [70.25514221, 22.71042061], [70.25485992, 22.71042061], [70.25485992, 22.71153069], [70.25514221, 22.71153069], [70.25514221, 22.71236038], [70.25541687, 22.71236038], [70.25541687, 22.71264076], [70.25485992, 22.71264076], [70.25485992, 22.71292114], [70.25402832, 22.71291733], [70.25402832, 22.7131958], [70.25347137, 22.7131958], [70.25347137, 22.71458244], [70.25402832, 22.71458054], [70.25402832, 22.71486092], [70.25428772, 22.71486092], [70.25428772, 22.71430969], [70.25514221, 22.71430969], [70.25514221, 22.71513939], [70.25485992, 22.71513939], [70.25485992, 22.7159729], [70.25458527, 22.7159729], [70.25458527, 22.71708298], [70.25428772, 22.71708107], [70.25428772, 22.71763992], [70.25402832, 22.71763611], [70.25402832, 22.71847153], [70.25374603, 22.71846962], [70.25374603, 22.71931076], [70.25347137, 22.71930504], [70.25347137, 22.71986008], [70.25374603, 22.71985817], [70.25374603, 22.72042084], [70.25402832, 22.72041893], [70.25402832, 22.72097015], [70.25428772, 22.72096825], [70.25428772, 22.72153282], [70.25485992, 22.72153282], [70.25485992, 22.72180939], [70.25541687, 22.72180939], [70.25541687, 22.72236252], [70.25514221, 22.72236252], [70.25514221, 22.7226429], [70.25458527, 22.72263908], [70.25458527, 22.72319412], [70.25485992, 22.72319031], [70.25485992, 22.72402954], [70.25514221, 22.72402954], [70.25514221, 22.72430992], [70.25541687, 22.72430992], [70.25541687, 22.72402954], [70.25569153, 22.72402954], [70.25569153, 22.72375107], [70.25596619, 22.72375107], [70.25596619, 22.7234726], [70.25791931, 22.7234726], [70.25791931, 22.72430992], [70.25846863, 22.72430992], [70.25846863, 22.72515106], [70.25875092, 22.72515106], [70.25875092, 22.72653008], [70.25819397, 22.72652817], [70.25819397, 22.72680473], [70.25736237, 22.72680473], [70.25736237, 22.72652817], [70.25653076, 22.72653008], [70.25653076, 22.72624969], [70.25457764, 22.72624969], [70.25457764, 22.72597122], [70.25430298, 22.72597313], [70.25430298, 22.72430611], [70.25402832, 22.72430992], [70.25402832, 22.72402954], [70.25374603, 22.72402954], [70.25374603, 22.72375107], [70.25208282, 22.72375107], [70.25208282, 22.72430992], [70.25125122, 22.72430611], [70.25125122, 22.72458458], [70.25096893, 22.72458458], [70.25096893, 22.72569466], [70.25152588, 22.72569466], [70.25152588, 22.72597313], [70.25180817, 22.72597122], [70.25180817, 22.72624969], [70.25208282, 22.72624969], [70.25208282, 22.72653008], [70.25291443, 22.72652817], [70.25291443, 22.72680473], [70.25375366, 22.72680473], [70.25375366, 22.72708321], [70.25402832, 22.72707939], [70.25402832, 22.72764015], [70.25430298, 22.72763824], [70.25430298, 22.72819519], [70.25402832, 22.72818947], [70.25402832, 22.72875023], [70.25374603, 22.72875023], [70.25374603, 22.72931099], [70.25319672, 22.72931099], [70.25319672, 22.73014069], [70.25347137, 22.73014069], [70.25347137, 22.72986031], [70.25374603, 22.72986031], [70.25374603, 22.72957993], [70.25402832, 22.72958374], [70.25402832, 22.72930527], [70.25428772, 22.72931099], [70.25428772, 22.72903061], [70.25457764, 22.72903061], [70.25457764, 22.72875023], [70.25541687, 22.72875023], [70.25541687, 22.72903061], [70.25569153, 22.72903061], [70.25569153, 22.72931099], [70.25541687, 22.72931099], [70.25541687, 22.72986031], [70.25458527, 22.72986031], [70.25458527, 22.73069382], [70.25430298, 22.73069382], [70.25430298, 22.73097229], [70.25402832, 22.73096085], [70.25402832, 22.73236084], [70.25319672, 22.73236084], [70.25319672, 22.73291969], [70.25291443, 22.73291588], [70.25291443, 22.73347282], [70.25319672, 22.73347092], [70.25319672, 22.73374939], [70.25402832, 22.73374939], [70.25402832, 22.73319054], [70.25430298, 22.73319435], [70.25430298, 22.73263741], [70.25457764, 22.73264122], [70.25457764, 22.73236084], [70.25514221, 22.73236084], [70.25514221, 22.73180962], [70.25541687, 22.73180962], [70.25541687, 22.73069], [70.25569153, 22.73069382], [70.25569153, 22.73041725], [70.25624847, 22.73042107], [70.25624847, 22.73014069], [70.25846863, 22.73014069], [70.25846863, 22.73042107], [70.25902557, 22.73041725], [70.25902557, 22.73069382], [70.25958252, 22.73069382], [70.25958252, 22.73097229], [70.25985718, 22.73096085], [70.25985718, 22.73125076], [70.26042175, 22.73125076], [70.26041412, 22.73097229], [70.26071167, 22.73096085], [70.26071167, 22.73264122], [70.26097107, 22.73264122], [70.26097107, 22.73291969], [70.26152802, 22.73291588], [70.26152802, 22.73319435], [70.26208496, 22.73319435], [70.26208496, 22.73347282], [70.26180267, 22.73347282], [70.26180267, 22.7345829], [70.26208496, 22.7345829], [70.26208496, 22.73485947], [70.26235962, 22.73485947], [70.26235962, 22.73513794], [70.26208496, 22.73514175], [70.26208496, 22.73569489], [70.26264191, 22.73569489], [70.26264191, 22.73736382], [70.26291656, 22.73736191], [70.26291656, 22.73764038], [70.26319122, 22.73764038], [70.26319122, 22.73792076], [70.26403046, 22.73791695], [70.26403046, 22.73819351], [70.26457977, 22.73819351], [70.26457977, 22.73763847], [70.26431274, 22.73764038], [70.26431274, 22.73736191], [70.26403046, 22.73736382], [70.26403046, 22.73680496], [70.26431274, 22.73681068], [70.26431274, 22.73625183], [70.26597595, 22.73625183], [70.26597595, 22.7365303], [70.26625061, 22.7365303], [70.26625061, 22.73681068], [70.26651764, 22.73681068], [70.26651764, 22.73709106], [70.26680756, 22.73708344], [70.26680756, 22.73736382], [70.2673645, 22.73736382], [70.2673645, 22.73708344], [70.26763916, 22.73709106], [70.26763916, 22.7365303], [70.26819611, 22.7365303], [70.26819611, 22.73625183], [70.26875305, 22.73625183], [70.26875305, 22.73596954], [70.26930237, 22.73596954], [70.26930237, 22.73569489], [70.26958466, 22.73569489], [70.26958466, 22.73541641], [70.26985931, 22.73542023], [70.26985931, 22.73485947], [70.26958466, 22.73485947], [70.26958466, 22.73430634], [70.26930237, 22.73431969], [70.26930237, 22.73403168], [70.2701416, 22.73403168], [70.2701416, 22.73374939], [70.27041626, 22.73374939], [70.27041626, 22.73319054], [70.27097321, 22.73319054], [70.27097321, 22.73374939], [70.27124786, 22.73374939], [70.27124786, 22.73347092], [70.27153015, 22.73347282], [70.27153015, 22.73263741], [70.2720871, 22.73263741], [70.2720871, 22.73319435], [70.27263641, 22.73319435], [70.27263641, 22.73347282], [70.27430725, 22.73347282], [70.27430725, 22.73319435], [70.27458191, 22.73319435], [70.27458191, 22.73236084], [70.27485657, 22.73236084], [70.27485657, 22.73208046], [70.27513885, 22.73208237], [70.27513885, 22.7318058], [70.27542114, 22.73180962], [70.27542114, 22.73125076], [70.27597046, 22.73125076], [70.27597046, 22.73208427], [70.2756958, 22.73208427], [70.2756958, 22.73347282], [70.27541351, 22.73347282], [70.27541351, 22.7345829], [70.27625275, 22.7345829], [70.27625275, 22.73485947], [70.2765274, 22.73485947], [70.2765274, 22.73514175], [70.27707672, 22.73514175], [70.27707672, 22.73542023], [70.27735901, 22.73541641], [70.27735901, 22.73569489], [70.2776413, 22.73568916], [70.2776413, 22.73681068], [70.27791595, 22.73680496], [70.27791595, 22.73736382], [70.27819824, 22.73736191], [70.27819824, 22.73764038], [70.27958679, 22.73764038], [70.27958679, 22.73792076], [70.27986145, 22.73791695], [70.27986145, 22.73847389], [70.27958679, 22.73847008], [70.27958679, 22.73931122], [70.27986145, 22.7393055], [70.27986145, 22.73958588], [70.28013611, 22.73958015], [70.28013611, 22.73986053], [70.2804184, 22.73986053], [70.2804184, 22.74013901], [70.28069305, 22.74013901], [70.28069305, 22.74069595], [70.28125, 22.74069595], [70.28125, 22.74013901], [70.28236389, 22.74013901], [70.28236389, 22.74069595], [70.28263855, 22.74069023], [70.28263855, 22.74125099], [70.28320312, 22.74125099], [70.28320312, 22.74152946], [70.28347015, 22.74152946], [70.28347015, 22.74180984], [70.2840271, 22.74180412], [70.2840271, 22.7420826], [70.28430176, 22.74208069], [70.28430939, 22.74263954], [70.2848587, 22.74263954], [70.2848587, 22.74291992], [70.28514099, 22.74291992], [70.28514099, 22.74263954], [70.28569794, 22.74263954], [70.28569794, 22.74319458], [70.2859726, 22.74319077], [70.2859726, 22.74374962], [70.28624725, 22.74374962], [70.28624725, 22.74430466], [70.28652954, 22.74430466], [70.28652954, 22.74458313], [70.2868042, 22.74458313], [70.2868042, 22.7448616], [70.28708649, 22.7448616], [70.28708649, 22.74430466], [70.28765106, 22.74430084], [70.28765106, 22.74513817], [70.28791809, 22.74513817], [70.28791809, 22.74542046], [70.28819275, 22.74542046], [70.28819275, 22.74570084], [70.28847504, 22.74569511], [70.28847504, 22.74597168], [70.28874969, 22.74596977], [70.28874969, 22.74681091], [70.28819275, 22.74681091], [70.28819275, 22.74653053], [70.28791809, 22.74653053], [70.28791809, 22.74596977], [70.28765106, 22.74596977], [70.28765106, 22.7462616], [70.28736115, 22.7462616], [70.28736115, 22.74653053], [70.28542328, 22.74653053], [70.28542328, 22.74681091], [70.28375244, 22.74680519], [70.28375244, 22.74708366], [70.28320312, 22.74707985], [70.28320312, 22.74764061], [70.28291321, 22.74764061], [70.28291321, 22.74791908], [70.2820816, 22.74791718], [70.2820816, 22.74819374], [70.28236389, 22.74819374], [70.28236389, 22.74847031], [70.28263855, 22.74847031], [70.28263855, 22.74875259], [70.28320312, 22.74875259], [70.2831955, 22.74847031], [70.2840271, 22.74847031], [70.2840271, 22.74819374], [70.28430176, 22.74819374], [70.28430176, 22.74791718], [70.2848587, 22.74791908], [70.2848587, 22.74764061], [70.28514099, 22.74764061], [70.28514099, 22.74735832], [70.28542328, 22.74735832], [70.28541565, 22.74708366], [70.28652954, 22.74707985], [70.28652954, 22.74735832], [70.28679657, 22.74735832], [70.28679657, 22.74764061], [70.28765106, 22.74764061], [70.28765106, 22.74791908], [70.28902435, 22.74791718], [70.28902435, 22.74819374], [70.28930664, 22.74819374], [70.28930664, 22.74847031], [70.2895813, 22.74847031], [70.2895813, 22.74875259], [70.28985596, 22.74875259], [70.28985596, 22.74847031], [70.29013824, 22.74847031], [70.29013824, 22.74819374], [70.29180908, 22.74818993], [70.29180908, 22.74875259], [70.2923584, 22.74875259], [70.2923584, 22.74932289], [70.29264069, 22.74932289], [70.29264069, 22.74903107], [70.29292297, 22.74903107], [70.29292297, 22.74875259], [70.29345703, 22.74875259], [70.29345703, 22.74932289], [70.29319763, 22.74930573], [70.29319763, 22.7495842], [70.29374695, 22.74958038], [70.29374695, 22.74986267], [70.29458618, 22.74986267], [70.29458618, 22.75041962], [70.29486084, 22.7504158], [70.29486084, 22.75097275], [70.29458618, 22.75097275], [70.29458618, 22.75125122], [70.29402924, 22.75125122], [70.29402924, 22.75263977], [70.29514313, 22.75263977], [70.29514313, 22.75292015], [70.29569244, 22.75292015], [70.29569244, 22.75235939], [70.29624939, 22.7523613], [70.29624939, 22.75208473], [70.29652405, 22.75208473], [70.29652405, 22.75180626], [70.29708099, 22.75181007], [70.29708099, 22.75263977], [70.29682159, 22.75263977], [70.29682159, 22.75292015], [70.29708099, 22.75291634], [70.29708099, 22.75347137], [70.29763794, 22.75346947], [70.29763794, 22.75374985], [70.29818726, 22.75374985], [70.29818726, 22.75403023], [70.29846954, 22.75403023], [70.29846954, 22.75374985], [70.29902649, 22.75374985], [70.29902649, 22.75458336], [70.29930878, 22.75458336], [70.29930878, 22.75486183], [70.29846954, 22.75486183], [70.29846954, 22.7551384], [70.29818726, 22.75513077], [70.29818726, 22.75542068], [70.29792023, 22.75542068], [70.29792023, 22.75653076], [70.29818726, 22.75653076], [70.29818726, 22.75736046], [70.29875183, 22.75736046], [70.29875183, 22.75681114], [70.29930878, 22.75680542], [70.29930878, 22.75708389], [70.29959106, 22.75708008], [70.29959106, 22.75764084], [70.29985809, 22.75763893], [70.29985809, 22.75847244], [70.30041504, 22.75847244], [70.30041504, 22.75875092], [70.30069733, 22.75875092], [70.30069733, 22.75930977], [70.30097198, 22.75930977], [70.30097198, 22.75985909], [70.30124664, 22.75985909], [70.30124664, 22.76014137], [70.30179596, 22.76014137], [70.30179596, 22.75930977], [70.30152893, 22.75930977], [70.30152893, 22.75847054], [70.30124664, 22.75847244], [70.30124664, 22.75763893], [70.30319214, 22.75763893], [70.30319214, 22.75847244], [70.30291748, 22.75847054], [70.30291748, 22.75985909], [70.30262756, 22.75985909], [70.30262756, 22.76042175], [70.30236053, 22.76041603], [70.30236053, 22.7606945], [70.30208588, 22.7606945], [70.30208588, 22.76097107], [70.30180359, 22.76097107], [70.30180359, 22.76235962], [70.30208588, 22.76235962], [70.30208588, 22.76430511], [70.30180359, 22.76430511], [70.30180359, 22.76458359], [70.30208588, 22.76457977], [70.30208588, 22.76514053], [70.30262756, 22.76514053], [70.30262756, 22.76542091], [70.30291748, 22.7654171], [70.30291748, 22.76597214], [70.30236053, 22.76597023], [70.30236053, 22.76625061], [70.30208588, 22.76625061], [70.30208588, 22.76653099], [70.30179596, 22.76653099], [70.30179596, 22.76680946], [70.30291748, 22.76680565], [70.30291748, 22.76708412], [70.30319214, 22.76708412], [70.30319214, 22.76680565], [70.3034668, 22.76680946], [70.3034668, 22.76597023], [70.30374908, 22.76597214], [70.30374908, 22.7654171], [70.30403137, 22.76542091], [70.30403137, 22.76514053], [70.30458069, 22.76513863], [70.30458069, 22.76569366], [70.30486298, 22.76569366], [70.30486298, 22.76597214], [70.30513763, 22.76597023], [70.30513763, 22.76625061], [70.30541992, 22.76625061], [70.30541992, 22.76680946], [70.30486298, 22.76680565], [70.30486298, 22.76708412], [70.30458069, 22.76707077], [70.30458069, 22.76736069], [70.30430603, 22.76736069], [70.30430603, 22.76764107], [70.30458069, 22.76763916], [70.30458069, 22.76847267], [70.30430603, 22.76847076], [70.30430603, 22.76875114], [70.30374908, 22.76875114], [70.30374908, 22.76847076], [70.30291748, 22.76847076], [70.30291748, 22.76931], [70.30263519, 22.76930618], [70.30263519, 22.76958275], [70.30124664, 22.76958275], [70.30124664, 22.76930618], [70.30069733, 22.76930618], [70.30069733, 22.76958275], [70.30041504, 22.76958275], [70.30041504, 22.77069473], [70.30097198, 22.77069473], [70.30097198, 22.7709713], [70.30124664, 22.77096939], [70.30124664, 22.77124977], [70.30097198, 22.77124977], [70.30097198, 22.77152824], [70.30124664, 22.77152634], [70.30124664, 22.77180481], [70.30152893, 22.77180481], [70.30152893, 22.77152634], [70.30263519, 22.77152634], [70.30263519, 22.77236176], [70.30291748, 22.77235985], [70.30291748, 22.77263832], [70.3034668, 22.77263832], [70.3034668, 22.77235985], [70.30403137, 22.77235985], [70.30403137, 22.77263832], [70.30374908, 22.77263832], [70.30374908, 22.77319908], [70.30430603, 22.77319908], [70.30430603, 22.7737484], [70.30458069, 22.7737484], [70.30458069, 22.77430916], [70.30513763, 22.77430534], [70.30513763, 22.77458382], [70.30568695, 22.77457809], [70.30568695, 22.77514267], [70.30541992, 22.77514267], [70.30541992, 22.77542114], [70.30569458, 22.77541733], [70.30569458, 22.77597046], [70.30596924, 22.77597046], [70.30596924, 22.77625275], [70.30680847, 22.7762394], [70.30680847, 22.77736282], [70.30708313, 22.77736282], [70.30708313, 22.77763939], [70.30680847, 22.77763939], [70.30680847, 22.77791977], [70.30708313, 22.77791595], [70.30708313, 22.77847481], [70.30680847, 22.7784729], [70.30680847, 22.78013992], [70.30568695, 22.78013992], [70.30568695, 22.77985954], [70.30541992, 22.77986145], [70.30541992, 22.77958488], [70.30486298, 22.77958488], [70.30486298, 22.77930641], [70.30403137, 22.77930641], [70.30403137, 22.77902794], [70.30374908, 22.77902985], [70.30374908, 22.77874947], [70.30319214, 22.77874947], [70.30319214, 22.7784729], [70.30263519, 22.77847481], [70.30263519, 22.77819443], [70.30152893, 22.77819443], [70.30152893, 22.77791595], [70.30124664, 22.77791977], [70.30124664, 22.77763939], [70.30097198, 22.77763939], [70.30097198, 22.77791977], [70.30041504, 22.77791595], [70.30041504, 22.77819443], [70.30097198, 22.77819443], [70.30097198, 22.77847481], [70.30152893, 22.7784729], [70.30152893, 22.77874947], [70.30179596, 22.77874947], [70.30179596, 22.77902985], [70.30208588, 22.77902794], [70.30208588, 22.77930641], [70.30236053, 22.77930641], [70.30236053, 22.77986145], [70.30262756, 22.77985954], [70.30262756, 22.7804203], [70.30319214, 22.7804203], [70.30319214, 22.78070068], [70.30403137, 22.78069305], [70.30403137, 22.78097153], [70.30458069, 22.78096962], [70.30458069, 22.78125], [70.30486298, 22.78125], [70.30486298, 22.78153038], [70.30541992, 22.78153038], [70.30541992, 22.78181076], [70.30569458, 22.78180695], [70.30569458, 22.78208351], [70.30596924, 22.78208351], [70.30596924, 22.78236198], [70.30764008, 22.78236198], [70.30764008, 22.78347206], [70.30735779, 22.78347015], [70.30735779, 22.78403091], [70.30764008, 22.78403091], [70.30764008, 22.78430939], [70.30874634, 22.78430557], [70.30874634, 22.78458405], [70.30902863, 22.78458023], [70.30902863, 22.78486061], [70.3095932, 22.78486061], [70.3095932, 22.78513908], [70.30986023, 22.78513718], [70.30986023, 22.7859726], [70.31014252, 22.78597069], [70.31014252, 22.78624916], [70.31041718, 22.78624916], [70.31041718, 22.78652763], [70.31069183, 22.78652763], [70.31069183, 22.78681183], [70.31182098, 22.78681183], [70.31182098, 22.78652763], [70.31208038, 22.78652763], [70.31208038, 22.78569031], [70.31291962, 22.78569412], [70.31291962, 22.78708267], [70.31263733, 22.78708076], [70.31263733, 22.78792191], [70.31236267, 22.78792191], [70.31236267, 22.7887516], [70.31208038, 22.7887516], [70.31208038, 22.78986359], [70.31180573, 22.78986359], [70.31180573, 22.79125023], [70.31124878, 22.7912426], [70.31124878, 22.79153061], [70.31097412, 22.7915287], [70.31097412, 22.79208374], [70.31069183, 22.79207993], [70.31069183, 22.79236031], [70.30986023, 22.79236031], [70.30986023, 22.79207993], [70.3095932, 22.79207993], [70.3095932, 22.79264069], [70.30986023, 22.79264069], [70.30986023, 22.79292107], [70.31014252, 22.79291725], [70.31014252, 22.79319572], [70.31069183, 22.79319572], [70.31069183, 22.79347229], [70.31096649, 22.79347038], [70.31096649, 22.79403114], [70.31069183, 22.79402733], [70.31069183, 22.7943058], [70.30986023, 22.79430008], [70.30986023, 22.79486084], [70.30930328, 22.79486084], [70.30930328, 22.79514122], [70.30902863, 22.79514122], [70.30902863, 22.79541969], [70.30930328, 22.79541588], [70.30930328, 22.79597282], [70.31041718, 22.79597092], [70.31041718, 22.79624939], [70.31096649, 22.79624939], [70.31096649, 22.79652977], [70.31208038, 22.79652977], [70.31208038, 22.79597092], [70.31236267, 22.79597282], [70.31236267, 22.79541588], [70.31319427, 22.79541588], [70.31319427, 22.79597282], [70.31375122, 22.79597092], [70.31375122, 22.79624939], [70.31485748, 22.79624939], [70.31485748, 22.79652977], [70.31569672, 22.79652786], [70.31569672, 22.7970829], [70.31625366, 22.7970829], [70.31625366, 22.79680634], [70.31652832, 22.79681015], [70.31652832, 22.79652977], [70.3170929, 22.79652977], [70.3170929, 22.79681015], [70.31735992, 22.79681015], [70.31735992, 22.79737091], [70.31791687, 22.79737091], [70.31791687, 22.79708099], [70.31819153, 22.7970829], [70.31819153, 22.79680634], [70.31846619, 22.79681015], [70.31846619, 22.79652977], [70.31986237, 22.79652977], [70.31986237, 22.79681015], [70.32013702, 22.79681015], [70.32013702, 22.79737091], [70.32041931, 22.79737091], [70.32041931, 22.79763985], [70.32069397, 22.79763794], [70.32069397, 22.79819489], [70.32096863, 22.79819107], [70.32096863, 22.79874992], [70.32013702, 22.79874992], [70.32013702, 22.7990284], [70.31819153, 22.7990284], [70.31819153, 22.79846954], [70.31791687, 22.79846954], [70.31791687, 22.7990284], [70.31762695, 22.7990284], [70.31762695, 22.79931068], [70.31680298, 22.79931068], [70.31680298, 22.79874992], [70.31625366, 22.79874992], [70.31625366, 22.79986191], [70.31652832, 22.79985809], [70.31652832, 22.8004303], [70.31680298, 22.80041695], [70.31680298, 22.80069351], [70.31762695, 22.8006897], [70.31762695, 22.80153275], [70.31708527, 22.80152702], [70.31708527, 22.80208397], [70.31735992, 22.80208015], [70.31735992, 22.80264282], [70.31762695, 22.80264282], [70.31762695, 22.80291939], [70.31791687, 22.80291939], [70.31791687, 22.8037529], [70.31819153, 22.80374908], [70.31819153, 22.8045845], [70.31846619, 22.80458069], [70.31846619, 22.80541992], [70.31874847, 22.80541611], [70.31874847, 22.80569458], [70.31903076, 22.80569458], [70.31903076, 22.80597305], [70.31986237, 22.80597115], [70.31986237, 22.80653], [70.32013702, 22.80652809], [70.32013702, 22.80708313], [70.32069397, 22.80708313], [70.32069397, 22.8073616], [70.32096863, 22.8073597], [70.32096863, 22.80764008], [70.32125092, 22.80764008], [70.32125092, 22.80792046], [70.3215332, 22.80792046], [70.3215332, 22.80541992], [70.32180786, 22.80541992], [70.32180786, 22.80513954], [70.32208252, 22.80513954], [70.32208252, 22.80486107], [70.32235718, 22.80486107], [70.32235718, 22.80458069], [70.32263947, 22.8045845], [70.32263947, 22.80319214], [70.32291412, 22.80319214], [70.32291412, 22.80291748], [70.32347107, 22.80291748], [70.32347107, 22.80319214], [70.32375336, 22.80319214], [70.32375336, 22.8045845], [70.32402802, 22.80458069], [70.32402802, 22.80513954], [70.32430267, 22.80513954], [70.32430267, 22.80541992], [70.32458496, 22.80541611], [70.32458496, 22.80569458], [70.32485962, 22.80569458], [70.32485962, 22.80597305], [70.32514191, 22.80597305], [70.32514191, 22.80680466], [70.32541656, 22.80680084], [70.32541656, 22.80792046], [70.32514191, 22.80791664], [70.32514191, 22.80847168], [70.32430267, 22.80846977], [70.32430267, 22.80903053], [70.32402802, 22.80903053], [70.32402802, 22.81014061], [70.32459259, 22.81014061], [70.32459259, 22.81042099], [70.32485962, 22.81041718], [70.32485962, 22.81069374], [70.32514191, 22.81069374], [70.32514191, 22.81041718], [70.32569122, 22.81041718], [70.32569122, 22.81097221], [70.32596588, 22.81097031], [70.32596588, 22.81153107], [70.32624817, 22.81153107], [70.32624817, 22.81236839], [70.32653046, 22.81236076], [70.32653046, 22.81319427], [70.32682037, 22.81319046], [70.32682037, 22.81374931], [70.32736206, 22.81374931], [70.32736206, 22.8140316], [70.32791901, 22.8140316], [70.32791901, 22.81431007], [70.32847595, 22.81430626], [70.32847595, 22.81458282], [70.32902527, 22.81458282], [70.32902527, 22.81485939], [70.32930756, 22.81485939], [70.32930756, 22.81541634], [70.33125305, 22.81541634], [70.33125305, 22.81596947], [70.33097076, 22.81596947], [70.33097076, 22.81653023], [70.33069611, 22.81653023], [70.33069611, 22.8176403], [70.33097076, 22.8176403], [70.33097076, 22.81792068], [70.33125305, 22.81792068], [70.33125305, 22.81820107], [70.33152771, 22.81819534], [70.33152771, 22.81847382], [70.33180237, 22.81847382], [70.33180237, 22.8195858], [70.33207703, 22.81958008], [70.33207703, 22.81986046], [70.33235931, 22.81986046], [70.33235931, 22.82014084], [70.3326416, 22.82013893], [70.3326416, 22.82069588], [70.33291626, 22.82069016], [70.33291626, 22.82180977], [70.3326416, 22.82180405], [70.3326416, 22.82208252], [70.33291626, 22.82208061], [70.33291626, 22.82236099], [70.33347321, 22.82236099], [70.33347321, 22.82208061], [70.33513641, 22.82208061], [70.33513641, 22.82236099], [70.3354187, 22.82236099], [70.3354187, 22.82263947], [70.33569336, 22.82263947], [70.33569336, 22.8231945], [70.33597565, 22.8231945], [70.33597565, 22.82347298], [70.33513641, 22.82347107], [70.33513641, 22.8243103], [70.3354187, 22.82430649], [70.3354187, 22.82458305], [70.33735657, 22.82458115], [70.33735657, 22.82542038], [70.33708191, 22.82542038], [70.33708191, 22.82624817], [70.3373642, 22.82624817], [70.3373642, 22.82708359], [70.33791351, 22.82708359], [70.33791351, 22.82735825], [70.3381958, 22.82735062], [70.3381958, 22.82763863], [70.33875275, 22.82763863], [70.33875275, 22.82819366], [70.33847046, 22.82818985], [70.33847046, 22.82930946], [70.33875275, 22.82930565], [70.33875275, 22.83041573], [70.3390274, 22.83041191], [70.3390274, 22.83152962], [70.33847046, 22.83152771], [70.33847046, 22.83208466], [70.33876038, 22.83208084], [70.33876038, 22.83292007], [70.3381958, 22.83291626], [70.3381958, 22.83319473], [70.33790588, 22.83319092], [70.33790588, 22.83348083], [70.33763885, 22.83348083], [70.33763885, 22.83374977], [70.3373642, 22.83374977], [70.3373642, 22.83430672], [70.33708191, 22.83430672], [70.33708191, 22.83486176], [70.33735657, 22.83485985], [70.33735657, 22.83542061], [70.33763885, 22.83541679], [70.33763885, 22.83597183], [70.33735657, 22.83596992], [70.33735657, 22.83736038], [70.33763885, 22.83736038], [70.33763885, 22.83903122], [70.33790588, 22.83903122], [70.33790588, 22.8401413], [70.3381958, 22.8401413], [70.3381958, 22.8409729], [70.33847046, 22.84096909], [70.33847046, 22.84181023], [70.33876038, 22.84181023], [70.33876038, 22.84264183], [70.3390274, 22.84263802], [70.3390274, 22.84347343], [70.33930206, 22.84346962], [70.33930206, 22.84403038], [70.33958435, 22.84402847], [70.33958435, 22.84458351], [70.33985901, 22.8445797], [70.33985901, 22.84542084], [70.3401413, 22.84541702], [70.3401413, 22.84597206], [70.34041595, 22.84597015], [70.34041595, 22.84680939], [70.34069824, 22.84680939], [70.34069824, 22.84736061], [70.3409729, 22.84736061], [70.3409729, 22.84791946], [70.34124756, 22.84791946], [70.34124756, 22.84848022], [70.34152985, 22.84848022], [70.34152985, 22.84875107], [70.34179688, 22.84875107], [70.34179688, 22.84902954], [70.34208679, 22.84902954], [70.34208679, 22.84930992], [70.34236145, 22.84930611], [70.34236145, 22.84958267], [70.3429184, 22.84958076], [70.3429184, 22.84986115], [70.34319305, 22.84986115], [70.34319305, 22.85013962], [70.34348297, 22.85013962], [70.34348297, 22.85041809], [70.34375, 22.85041618], [70.34375, 22.85069466], [70.34402466, 22.85069466], [70.34402466, 22.85097313], [70.34430695, 22.85097313], [70.34430695, 22.85152626], [70.3445816, 22.85152626], [70.3445816, 22.85208321], [70.34485626, 22.85207939], [70.34485626, 22.85263824], [70.34513855, 22.85263824], [70.34513855, 22.85320091], [70.34541321, 22.85320091], [70.34541321, 22.85374832], [70.34570313, 22.85374832], [70.34570313, 22.85403061], [70.34597015, 22.85403061], [70.34597015, 22.85430908], [70.34625244, 22.85430908], [70.34625244, 22.8548584], [70.3465271, 22.8548584], [70.3465271, 22.85514259], [70.34680176, 22.85514069], [70.34680939, 22.85569382], [70.34708405, 22.85569382], [70.34708405, 22.85597038], [70.3473587, 22.85597038], [70.3473587, 22.85625267], [70.34764099, 22.85625267], [70.34764099, 22.85680962], [70.34791565, 22.8568058], [70.34791565, 22.85708046], [70.34819794, 22.85708427], [70.34819794, 22.85847473], [70.3484726, 22.85847282], [70.3484726, 22.85931015], [70.34874725, 22.85930634], [70.34874725, 22.85958481], [70.3493042, 22.85958481], [70.3493042, 22.85986137], [70.34958649, 22.85985947], [70.34958649, 22.86013985], [70.34986115, 22.86013985], [70.34986115, 22.86042023], [70.35041809, 22.86042023], [70.35041809, 22.86181068], [70.35069275, 22.86180687], [70.35069275, 22.86236191], [70.3509903, 22.86236], [70.3509903, 22.86292076], [70.35124969, 22.86291695], [70.35124969, 22.86319351], [70.35151672, 22.8631897], [70.35151672, 22.86375046], [70.35180664, 22.86375046], [70.35180664, 22.86431122], [70.3520813, 22.86431122], [70.3520813, 22.86486053], [70.35235596, 22.86486053], [70.35235596, 22.86541748], [70.3529129, 22.86541748], [70.3529129, 22.86569405], [70.35319519, 22.86569405], [70.35319519, 22.86652756], [70.3529129, 22.86652756], [70.3529129, 22.8670826], [70.35319519, 22.8670826], [70.35319519, 22.86764145], [70.35346985, 22.86764145], [70.35346985, 22.86819458], [70.35373688, 22.86819077], [70.35373688, 22.86875153], [70.35402679, 22.86875153], [70.35402679, 22.86986351], [70.35373688, 22.8698597], [70.35373688, 22.87070084], [70.35430908, 22.87069511], [70.35430908, 22.87097359], [70.35457611, 22.87096977], [70.35457611, 22.87125015], [70.35597229, 22.87125015], [70.35597229, 22.87153053], [70.35624695, 22.87152863], [70.35624695, 22.87208366], [70.35679626, 22.87207985], [70.35679626, 22.87236023], [70.35708618, 22.87236023], [70.35708618, 22.87265015], [70.35736084, 22.87265015], [70.35736084, 22.87375069], [70.35764313, 22.87375069], [70.35764313, 22.87403107], [70.35791779, 22.87403107], [70.35791779, 22.87430954], [70.35819244, 22.87430573], [70.35819244, 22.8745842], [70.3584671, 22.87458038], [70.3584671, 22.87486076], [70.35874939, 22.87486076], [70.35874939, 22.87514114], [70.35902405, 22.87513924], [70.35902405, 22.87569427], [70.35930634, 22.87569427], [70.35930634, 22.87597275], [70.35958099, 22.87597084], [70.35958099, 22.87625122], [70.35987091, 22.87625122], [70.35987091, 22.87681007], [70.36013794, 22.87680626], [70.36013794, 22.87708282], [70.36042023, 22.87708282], [70.36042023, 22.8773613], [70.36068726, 22.87735939], [70.36068726, 22.87791824], [70.36096954, 22.87791634], [70.36096954, 22.87819481], [70.36125183, 22.87819099], [70.36125183, 22.87874985], [70.36152649, 22.87874985], [70.36152649, 22.87902832], [70.36180878, 22.87902832], [70.36180878, 22.87930489], [70.36208344, 22.87930489], [70.36208344, 22.87986183], [70.36235809, 22.87985992], [70.36235809, 22.8801384], [70.36264038, 22.8801384], [70.36264038, 22.88069916], [70.36291504, 22.88069534], [70.36291504, 22.88097191], [70.36319733, 22.88096809], [70.36319733, 22.88124847], [70.36347198, 22.88124847], [70.36347198, 22.88181114], [70.36374664, 22.88180542], [70.36374664, 22.88208389], [70.36402893, 22.88208008], [70.36402893, 22.88236237], [70.36429596, 22.88236237], [70.36429596, 22.88264275], [70.36458588, 22.88264084], [70.36458588, 22.88319206], [70.36486053, 22.88319206], [70.36486053, 22.88347054], [70.36513519, 22.88347054], [70.36513519, 22.88375282], [70.36541748, 22.88375282], [70.36541748, 22.88402939], [70.36567688, 22.88402939], [70.36567688, 22.88459015], [70.3659668, 22.88459015], [70.3659668, 22.8848629], [70.36624908, 22.8848629], [70.36624908, 22.88513947], [70.36653137, 22.88513947], [70.36653137, 22.8856945], [70.36680603, 22.8856945], [70.36680603, 22.88597488], [70.36708069, 22.88597107], [70.36708069, 22.88652992], [70.36736298, 22.88652802], [70.36736298, 22.88680077], [70.36763763, 22.88680649], [70.36763763, 22.88708305], [70.36791992, 22.88708115], [70.36791992, 22.88764954], [70.36818695, 22.88764954], [70.36818695, 22.88792038], [70.36846924, 22.88791656], [70.36846924, 22.8884716], [70.36873627, 22.8884697], [70.36873627, 22.88875008], [70.36902618, 22.88875008], [70.36902618, 22.88931084], [70.36930847, 22.88930511], [70.36930847, 22.88958359], [70.36958313, 22.88957977], [70.36958313, 22.89014053], [70.36985779, 22.89014053], [70.36985779, 22.89042091], [70.37014008, 22.89041519], [70.37014008, 22.89069366], [70.3704071, 22.89068985], [70.3704071, 22.89125061], [70.37069702, 22.89125061], [70.37069702, 22.89152908], [70.37097168, 22.89152908], [70.37097168, 22.89180946], [70.37124634, 22.89180946], [70.37124634, 22.89236069], [70.37152863, 22.89236069], [70.37152863, 22.89263916], [70.37180328, 22.89263725], [70.37180328, 22.8931942], [70.37208557, 22.8931942], [70.37208557, 22.89347267], [70.37236023, 22.89347076], [70.37236023, 22.89374924], [70.37264252, 22.89374924], [70.37264252, 22.8943119], [70.37291718, 22.89430618], [70.37291718, 22.89458275], [70.37319183, 22.89458084], [70.37319183, 22.89485931], [70.37346649, 22.89485931], [70.37346649, 22.89542007], [70.37374878, 22.89541626], [70.37374878, 22.89569473], [70.37403107, 22.89569473], [70.37403107, 22.89596939], [70.37431335, 22.89596939], [70.37431335, 22.89653015], [70.37458038, 22.89652824], [70.37458038, 22.89680481], [70.37486267, 22.89680481], [70.37486267, 22.89708138], [70.37513733, 22.89707947], [70.37513733, 22.89764023], [70.37541962, 22.89764023], [70.37541962, 22.89792061], [70.37568665, 22.89792061], [70.37568665, 22.8982029], [70.37596893, 22.8982029], [70.37596893, 22.89875031], [70.37625122, 22.89875031], [70.37625122, 22.89903069], [70.37652588, 22.89903069], [70.37652588, 22.89931107], [70.37680817, 22.89931107], [70.37680817, 22.89986038], [70.37708282, 22.89986038], [70.37708282, 22.90014076], [70.37735748, 22.90014076], [70.37735748, 22.90042114], [70.37763977, 22.90041733], [70.37763977, 22.9006958], [70.37791443, 22.9006958], [70.37791443, 22.90097237], [70.37819672, 22.90097046], [70.37819672, 22.90153122], [70.37847137, 22.90153122], [70.37847137, 22.90180969], [70.37875366, 22.90180588], [70.37875366, 22.90208244], [70.37902832, 22.90208054], [70.37902832, 22.90236092], [70.37930298, 22.90236092], [70.37930298, 22.90263939], [70.37958527, 22.90263939], [70.37958527, 22.90319443], [70.37985992, 22.90319443], [70.37985992, 22.9034729], [70.38014221, 22.90347099], [70.38014221, 22.90374947], [70.38041687, 22.90374947], [70.38041687, 22.90402985], [70.38067627, 22.90402985], [70.38067627, 22.90431023], [70.38097382, 22.90430641], [70.38097382, 22.90458298], [70.38124847, 22.90458298], [70.38124847, 22.90486145], [70.38153076, 22.90485954], [70.38153076, 22.90513992], [70.38181305, 22.90513992], [70.38181305, 22.9054203], [70.38208008, 22.90541649], [70.38208008, 22.90569496], [70.38236237, 22.90569496], [70.38236237, 22.90597153], [70.38263702, 22.90596962], [70.38263702, 22.90652847], [70.38291931, 22.90652847], [70.38291931, 22.90681076], [70.38319397, 22.90680504], [70.38319397, 22.90708351], [70.38346863, 22.9070797], [70.38346863, 22.90763855], [70.38375092, 22.90763855], [70.38375092, 22.90792084], [70.38402557, 22.90791702], [70.38402557, 22.90819359], [70.38430786, 22.90818977], [70.38430786, 22.90876007], [70.38458252, 22.90876007], [70.38458252, 22.90930939], [70.38486481, 22.90930557], [70.38486481, 22.90958405], [70.38513947, 22.90958023], [70.38513947, 22.90986252], [70.38597107, 22.90986252], [70.38597107, 22.90958023], [70.38652802, 22.90958405], [70.38652802, 22.90930557], [70.38761902, 22.90930557], [70.38791656, 22.90930557], [70.38791656, 22.90958405], [70.38846588, 22.90958023], [70.38846588, 22.90986252], [70.38903046, 22.90986252], [70.38903046, 22.9101429], [70.38957977, 22.9101429], [70.38957977, 22.91041946], [70.39013672, 22.91041756], [70.39013672, 22.91069221], [70.39069366, 22.91069221], [70.39069366, 22.91097069], [70.39125061, 22.91097069], [70.39125061, 22.91125107], [70.39180756, 22.91125107], [70.39180756, 22.91152954], [70.39235687, 22.91152954], [70.39235687, 22.91181946], [70.39291382, 22.91180611], [70.39291382, 22.91208458], [70.39347076, 22.91208076], [70.39347076, 22.91236115], [70.39402771, 22.91236115], [70.39402771, 22.91263962], [70.39457703, 22.91263962], [70.39457703, 22.91292], [70.39541626, 22.91291618], [70.39541626, 22.91319466], [70.39597321, 22.91319466], [70.39597321, 22.91347313], [70.39679718, 22.91347122], [70.39679718, 22.91374969], [70.39736176, 22.91374969], [70.39736176, 22.91403008], [70.39819336, 22.91402817], [70.39819336, 22.91430473], [70.39875031, 22.91430473], [70.39875031, 22.91458321], [70.39930725, 22.91458321], [70.39930725, 22.91486168], [70.40013885, 22.91485977], [70.40013885, 22.91514015], [70.4006958, 22.91514015], [70.4006958, 22.91542053], [70.4015274, 22.91542053], [70.4015274, 22.91570091], [70.40208435, 22.91569519], [70.40208435, 22.91597176], [70.40291595, 22.91596985], [70.40291595, 22.91625023], [70.4034729, 22.91625023], [70.4034729, 22.91653061], [70.40429688, 22.91653061], [70.40429688, 22.91681099], [70.40486145, 22.91680527], [70.40486145, 22.91708374], [70.40513611, 22.91707993], [70.40513611, 22.91736031], [70.40569305, 22.91736031], [70.40569305, 22.91763878], [70.40598297, 22.91763115], [70.40598297, 22.91792107], [70.40652466, 22.91791725], [70.40652466, 22.91819382], [70.40680695, 22.91819382], [70.40680695, 22.91791725], [70.40736389, 22.91791725], [70.40736389, 22.91819382], [70.40763855, 22.91819382], [70.40763855, 22.91847229], [70.4081955, 22.91847229], [70.4081955, 22.91875076], [70.40875244, 22.91875076], [70.40875244, 22.91903114], [70.4090271, 22.91903114], [70.4090271, 22.91930962], [70.40957642, 22.91930962], [70.40957642, 22.92070007], [70.41014099, 22.92070007], [70.41014099, 22.9204216], [70.41042328, 22.9204216], [70.41042328, 22.91986084], [70.4118042, 22.91986084], [70.41179657, 22.91930962], [70.41208649, 22.91930962], [70.41208649, 22.91875076], [70.41236115, 22.91875076], [70.41236115, 22.91819], [70.41347504, 22.91819382], [70.41347504, 22.91847229], [70.41319275, 22.91847038], [70.41319275, 22.91903114], [70.41291809, 22.91902733], [70.41291809, 22.91958427], [70.4126358, 22.91958046], [70.4126358, 22.92013931], [70.41236115, 22.92013741], [70.41236115, 22.92235947], [70.4126358, 22.92235947], [70.4126358, 22.92292023], [70.41319275, 22.92292023], [70.41319275, 22.92264175], [70.41374969, 22.92263794], [70.41374969, 22.92319489], [70.41402435, 22.92319489], [70.41402435, 22.92347336], [70.41430664, 22.92346954], [70.41430664, 22.92375946], [70.4145813, 22.92375946], [70.4145813, 22.9240303], [70.41485596, 22.9240303], [70.41485596, 22.92431068], [70.41513824, 22.92430305], [70.41513824, 22.92458153], [70.4154129, 22.92458153], [70.4154129, 22.92486382], [70.41570282, 22.92486191], [70.41570282, 22.92542076], [70.41596985, 22.92541695], [70.41596985, 22.9256916], [70.41625214, 22.9256916], [70.41625214, 22.92597389], [70.41652679, 22.92597008], [70.41652679, 22.92625046], [70.41680908, 22.92625046], [70.41680908, 22.92653084], [70.41708374, 22.92652702], [70.41708374, 22.9268055], [70.4173584, 22.9268055], [70.4173584, 22.92708588], [70.41791534, 22.92708588], [70.41791534, 22.92736053], [70.41819763, 22.92736053], [70.41819763, 22.92791939], [70.41847229, 22.92791748], [70.41847229, 22.92819595], [70.41874695, 22.92819595], [70.41874695, 22.92847252], [70.41902924, 22.92847061], [70.41902924, 22.92875099], [70.41929626, 22.92875099], [70.41929626, 22.92902946], [70.41958618, 22.92902756], [70.41958618, 22.9295826], [70.41986084, 22.92957115], [70.41986084, 22.92986107], [70.4201355, 22.92986107], [70.4201355, 22.93013954], [70.42041779, 22.93013954], [70.42041779, 22.93041992], [70.42069244, 22.93041611], [70.42069244, 22.93069458], [70.4209671, 22.93069077], [70.4209671, 22.93124962], [70.42124939, 22.93124962], [70.42124939, 22.93152809], [70.42180634, 22.93152618], [70.42180634, 22.93180466], [70.42208099, 22.93180466], [70.42208099, 22.93208313], [70.42236328, 22.93208313], [70.42236328, 22.9323616], [70.42318726, 22.9323597], [70.42318726, 22.93263817], [70.42346954, 22.93263817], [70.42346954, 22.93320084], [70.42375183, 22.93320084], [70.42375183, 22.93374825], [70.42402649, 22.93374825], [70.42402649, 22.93431091], [70.42430878, 22.93431091], [70.42430878, 22.93485832], [70.42457581, 22.93485832], [70.42457581, 22.9354229], [70.42485809, 22.93541718], [70.42485809, 22.93597031], [70.42514038, 22.93597031], [70.42514038, 22.93653107], [70.42541504, 22.93652725], [70.42541504, 22.9370842], [70.42569733, 22.93708038], [70.42569733, 22.93764114], [70.42597198, 22.93763924], [70.42597198, 22.93819237], [70.42624664, 22.93819046], [70.42624664, 22.93931007], [70.42652893, 22.93931007], [70.42652893, 22.94013977], [70.42680359, 22.94013977], [70.42680359, 22.94097137], [70.42652893, 22.94096947], [70.42652893, 22.94153023], [70.42624664, 22.94152832], [70.42624664, 22.94208336], [70.42595673, 22.94207954], [70.42595673, 22.94292068], [70.42624664, 22.94291687], [70.42624664, 22.94347191], [70.42652893, 22.94347], [70.42652893, 22.94431114], [70.42679596, 22.94431114], [70.42679596, 22.94486809], [70.42708588, 22.94486046], [70.42708588, 22.94569397], [70.42736053, 22.94569016], [70.42736053, 22.94681168], [70.42763519, 22.94680595], [70.42763519, 22.94764137], [70.42791748, 22.94764137], [70.42791748, 22.9481945], [70.42819214, 22.94819069], [70.42819214, 22.94874954], [70.42847443, 22.94874954], [70.42847443, 22.95097351], [70.42874908, 22.9509697], [70.42874908, 22.95292091], [70.42903137, 22.9529171], [70.42903137, 22.95347214], [70.42930603, 22.95347023], [70.42930603, 22.95403099], [70.42958069, 22.95403099], [70.42958069, 22.95486069], [70.42986298, 22.95486069], [70.42986298, 22.95597267], [70.43013763, 22.95597076], [70.43013763, 22.95680809], [70.43041992, 22.95680809], [70.43041992, 22.95791817], [70.43069458, 22.95791626], [70.43069458, 22.9584713], [70.43096924, 22.95846939], [70.43096924, 22.95902824], [70.43125153, 22.95902824], [70.43125153, 22.95930481], [70.43152618, 22.95930481], [70.43152618, 22.95958328], [70.43180847, 22.95957947], [70.43180847, 22.95986938], [70.43209076, 22.95986938], [70.43209076, 22.96042061], [70.43264008, 22.96042061], [70.43264008, 22.96069908], [70.43291473, 22.96069527], [70.43291473, 22.96097183], [70.43319702, 22.96096992], [70.43319702, 22.9612484], [70.43374634, 22.9612484], [70.43374634, 22.96153069], [70.43430328, 22.96153069], [70.43430328, 22.9612484], [70.43515015, 22.9612484], [70.43515015, 22.96181107], [70.43541718, 22.96181107], [70.43541718, 22.96236038], [70.43569183, 22.96236038], [70.43569183, 22.96291733], [70.43597412, 22.96291733], [70.43597412, 22.96347046], [70.43624878, 22.96347046], [70.43624878, 22.96375275], [70.43653107, 22.96377945], [70.43653107, 22.96430969], [70.43680573, 22.96430588], [70.43680573, 22.96486282], [70.43708038, 22.96486282], [70.43708038, 22.96541977], [70.43736267, 22.96541405], [70.43736267, 22.96597481], [70.43763733, 22.9659729], [70.43763733, 22.96624947], [70.43791962, 22.96624947], [70.43791962, 22.96681023], [70.43819427, 22.96680641], [70.43819427, 22.96736145], [70.43846893, 22.96735954], [70.43846893, 22.9679203], [70.43875122, 22.96791649], [70.43875122, 22.96847153], [70.43902588, 22.96846962], [70.43902588, 22.96875], [70.43930817, 22.96875], [70.43930817, 22.96931076], [70.43958282, 22.96930695], [70.43958282, 22.96986198], [70.43985748, 22.96986008], [70.43985748, 22.97042084], [70.44013977, 22.97041512], [70.44013977, 22.97097206], [70.4404068, 22.97097015], [70.4404068, 22.97153091], [70.44069672, 22.97153091], [70.44069672, 22.97180748], [70.44095612, 22.97180748], [70.44095612, 22.97236061], [70.44124603, 22.97236061], [70.44124603, 22.97291756], [70.44152832, 22.97291756], [70.44152832, 22.9734726], [70.44180298, 22.97347069], [70.44180298, 22.97403145], [70.4420929, 22.97403145], [70.4420929, 22.97431183], [70.44235992, 22.97430611], [70.44235992, 22.97485924], [70.44264221, 22.9748497], [70.44264221, 22.97514153], [70.44152832, 22.97514153], [70.44152832, 22.97542191], [70.44124603, 22.97542191], [70.44124603, 22.97514153], [70.43985748, 22.97514153], [70.43985748, 22.9748497], [70.43930817, 22.97485924], [70.43930817, 22.97458267], [70.43763733, 22.97458076], [70.43763733, 22.97514153], [70.43791962, 22.97514153], [70.43791962, 22.97542191], [70.43846893, 22.97541618], [70.43846893, 22.97569466], [70.43958282, 22.97569466], [70.43958282, 22.97597122], [70.44124603, 22.97596931], [70.44124603, 22.9762516], [70.44180298, 22.9762516], [70.44180298, 22.97653008], [70.44235992, 22.97652817], [70.44235992, 22.97680473], [70.44264221, 22.97680473], [70.44264221, 22.9770813], [70.44319153, 22.9770813], [70.44319153, 22.97736359], [70.44346619, 22.97735977], [70.44346619, 22.97764015], [70.44374847, 22.97763824], [70.44374847, 22.97791672], [70.44431305, 22.9779129], [70.44431305, 22.97820091], [70.44458008, 22.97819519], [70.44458008, 22.97847366], [70.44486237, 22.97846985], [70.44486237, 22.97875023], [70.44513702, 22.97875023], [70.44513702, 22.97903061], [70.44541931, 22.97903061], [70.44541931, 22.97931099], [70.44596863, 22.97930527], [70.44596863, 22.97958565], [70.44625092, 22.97957993], [70.44625092, 22.97986031], [70.4465332, 22.97986031], [70.4465332, 22.98014069], [70.44680786, 22.98014069], [70.44680786, 22.98042107], [70.44736481, 22.98041725], [70.44736481, 22.98069572], [70.44763947, 22.98069], [70.44763947, 22.98097992], [70.44819641, 22.98097992], [70.44819641, 22.98125076], [70.44875336, 22.98125076], [70.44875336, 22.98153114], [70.44902802, 22.98153114], [70.44902802, 22.98180962], [70.44930267, 22.9818058], [70.44930267, 22.98208237], [70.44958496, 22.98208427], [70.44958496, 22.98236084], [70.45014954, 22.98236084], [70.45014954, 22.98264122], [70.45041656, 22.98264122], [70.45041656, 22.98291969], [70.45124817, 22.98291779], [70.45124817, 22.98319435], [70.45180511, 22.98319435], [70.45180511, 22.98374939], [70.45236206, 22.98374939], [70.45236206, 22.98404121], [70.45263672, 22.98404121], [70.45263672, 22.98431015], [70.45319366, 22.98430634], [70.45319366, 22.9845829], [70.45375061, 22.9845829], [70.45375061, 22.98486137], [70.4540329, 22.98485947], [70.4540329, 22.98513985], [70.45430756, 22.98513794], [70.45430756, 22.98569489], [70.45458221, 22.98569489], [70.45458221, 22.98597145], [70.45485687, 22.98596954], [70.45485687, 22.98624992], [70.45513916, 22.98624992], [70.45513916, 22.9865284], [70.45540619, 22.9865284], [70.45540619, 22.98681068], [70.45569611, 22.98680496], [70.45569611, 22.98708344], [70.45597076, 22.98707962], [70.45597076, 22.98763847], [70.45625305, 22.98763847], [70.45625305, 22.98792076], [70.45652771, 22.98792076], [70.45652771, 22.98875237], [70.45680237, 22.98875237], [70.45680237, 22.98903275], [70.45707703, 22.98903275], [70.45707703, 22.98931122], [70.45735931, 22.9893055], [70.45735931, 22.98958206], [70.4576416, 22.98958015], [70.4576416, 22.99041939], [70.45791626, 22.99041939], [70.45791626, 22.9912529], [70.45819092, 22.9912529], [70.45819092, 22.99180984], [70.45847321, 22.99180984], [70.45847321, 22.99236107], [70.45874786, 22.99236107], [70.45874786, 22.99291992], [70.45903015, 22.99291611], [70.45903015, 22.99319458], [70.45929718, 22.99319077], [70.45929718, 22.99403], [70.4595871, 22.99402809], [70.4595871, 22.99458313], [70.45986176, 22.99458313], [70.45986176, 22.9948616], [70.46013641, 22.9948597], [70.46013641, 22.99542046], [70.4604187, 22.99542046], [70.4604187, 22.99570084], [70.46069336, 22.99570084], [70.46069336, 22.99653053], [70.46098328, 22.99653053], [70.46098328, 22.99681091], [70.46125031, 22.99681091], [70.46125031, 22.99736023], [70.46153259, 22.99736023], [70.46153259, 22.99764061], [70.46180725, 22.9976387], [70.46180725, 22.99819374], [70.46208954, 22.99818993], [70.46208954, 22.9990406], [70.4623642, 22.99902725], [70.4623642, 22.9995842], [70.46263885, 22.99958038], [70.46263885, 22.99986076], [70.46290588, 22.99986076], [70.46290588, 23.00042152], [70.46375275, 23.0004158], [70.46375275, 23.00069427], [70.4640274, 23.00069427], [70.4640274, 23.00097275], [70.46430206, 23.00097084], [70.46430206, 23.0015316], [70.46457672, 23.0015316], [70.46457672, 23.00181007], [70.46485901, 23.00180626], [70.46485901, 23.00235939], [70.46512604, 23.00235939], [70.46512604, 23.00264168], [70.46541595, 23.00264168], [70.46541595, 23.00319481], [70.46569824, 23.00318909], [70.46569824, 23.00375175], [70.4659729, 23.00375175], [70.4659729, 23.00430489], [70.46652985, 23.00430489], [70.46652985, 23.00458145], [70.46679688, 23.00457954], [70.46679688, 23.0051403], [70.46708679, 23.0051403], [70.46708679, 23.00570107], [70.46736145, 23.00570107], [70.46736145, 23.00625038], [70.46763611, 23.00625038], [70.46763611, 23.00681114], [70.4679184, 23.00681114], [70.4679184, 23.00736046], [70.46819305, 23.00736046], [70.46819305, 23.00792122], [70.46847534, 23.0079174], [70.46847534, 23.00819588], [70.46875, 23.00819016], [70.46875, 23.00875092], [70.46901703, 23.00875092], [70.46901703, 23.00902939], [70.46930695, 23.00902748], [70.46930695, 23.00958252], [70.4695816, 23.00958061], [70.4695816, 23.00986099], [70.46985626, 23.00986099], [70.46985626, 23.01013947], [70.47013855, 23.01013947], [70.47013855, 23.01041985], [70.47041321, 23.01041794], [70.47041321, 23.0106945], [70.4706955, 23.0106945], [70.4706955, 23.01124954], [70.47097015, 23.01124954], [70.47097015, 23.01180077], [70.47125244, 23.01180649], [70.47125244, 23.01236153], [70.4715271, 23.01235962], [70.4715271, 23.01320076], [70.47180176, 23.01319504], [70.47180939, 23.01402855], [70.47208405, 23.01402855], [70.47208405, 23.01458359], [70.4723587, 23.01457977], [70.4723587, 23.01542282], [70.47264099, 23.01542282], [70.47264099, 23.01625252], [70.47292328, 23.01625252], [70.47292328, 23.01680946], [70.47319794, 23.01680946], [70.47319794, 23.01764107], [70.4734726, 23.01763916], [70.4734726, 23.01819229], [70.47374725, 23.01819038], [70.47374725, 23.01875114], [70.47402954, 23.01875114], [70.47402954, 23.01931], [70.47429657, 23.01931], [70.47429657, 23.01986122], [70.47458649, 23.01986122], [70.47458649, 23.02042007], [70.47486115, 23.02041626], [70.47486115, 23.0209713], [70.4751358, 23.02096939], [70.4751358, 23.02153015], [70.47541809, 23.02152824], [70.47541809, 23.02236176], [70.47569275, 23.02235985], [70.47569275, 23.02321053], [70.47598267, 23.02321053], [70.47598267, 23.02403069], [70.47624969, 23.02403069], [70.47624969, 23.02486038], [70.47652435, 23.02486038], [70.47652435, 23.02569389], [70.47680664, 23.02569008], [70.47680664, 23.02653122], [70.47706604, 23.02653122], [70.47706604, 23.02736092], [70.47735596, 23.02736092], [70.47735596, 23.02792168], [70.47763824, 23.02791595], [70.47763824, 23.0284729], [70.4779129, 23.0284729], [70.4779129, 23.02902794], [70.47819519, 23.02902794], [70.47819519, 23.02958107], [70.47846985, 23.02957916], [70.47846985, 23.03014183], [70.47875214, 23.03014183], [70.47875214, 23.03070068], [70.47902679, 23.03070068], [70.47902679, 23.03125191], [70.47930908, 23.03125191], [70.47930908, 23.03209114], [70.47957611, 23.03209114], [70.47957611, 23.03292084], [70.4798584, 23.03292084], [70.4798584, 23.03403091], [70.48014069, 23.0340271], [70.48014069, 23.03458595], [70.48041534, 23.03458595], [70.48041534, 23.03486061], [70.48069763, 23.03486061], [70.48069763, 23.03515053], [70.48097229, 23.03515053], [70.48097229, 23.03541946], [70.48124695, 23.03541946], [70.48124695, 23.03625107], [70.48152924, 23.03625107], [70.48152924, 23.03736115], [70.48180389, 23.03736115], [70.48180389, 23.03819466], [70.48208618, 23.03819084], [70.48208618, 23.03902817], [70.48236084, 23.03902817], [70.48236084, 23.03986168], [70.48264313, 23.03985977], [70.48264313, 23.04042053], [70.48291779, 23.04042053], [70.48291779, 23.04124832], [70.48320007, 23.04124832], [70.48320007, 23.0418129], [70.4834671, 23.0418129], [70.4834671, 23.04236031], [70.48374939, 23.04236031], [70.48374939, 23.04319382], [70.48401642, 23.04319191], [70.48401642, 23.04375267], [70.48430634, 23.04375267], [70.48430634, 23.04432106], [70.48458099, 23.04432106], [70.48458099, 23.04486275], [70.48486328, 23.04486275], [70.48486328, 23.04569244], [70.48513794, 23.04569054], [70.48513794, 23.04681015], [70.48542023, 23.04680634], [70.48542023, 23.04736137], [70.48569489, 23.04736137], [70.48569489, 23.04819679], [70.48596954, 23.04819107], [70.48596954, 23.04874992], [70.48625946, 23.04874992], [70.48625946, 23.04931068], [70.48652649, 23.04930687], [70.48652649, 23.04986191], [70.48680878, 23.04986], [70.48680878, 23.05042076], [70.48707581, 23.05042076], [70.48707581, 23.05181122], [70.48735809, 23.0518055], [70.48735809, 23.05208397], [70.48764038, 23.05208397], [70.48764038, 23.05319405], [70.48791504, 23.05319405], [70.48791504, 23.0545826], [70.48819733, 23.05458069], [70.48819733, 23.05514145], [70.48847198, 23.05514145], [70.48847198, 23.05597115], [70.48874664, 23.05596924], [70.48874664, 23.05653191], [70.48902893, 23.05652809], [70.48902893, 23.05736351], [70.48929596, 23.0573597], [70.48929596, 23.05792046], [70.48958588, 23.05792046], [70.48958588, 23.05875015], [70.48986053, 23.05875015], [70.48986053, 23.05932045], [70.49014282, 23.05932045], [70.49014282, 23.06014061], [70.49041748, 23.0601387], [70.49041748, 23.06097221], [70.49069214, 23.06097221], [70.49069214, 23.06174088], [70.49093628, 23.06180954], [70.4909668, 23.06264114], [70.49124908, 23.06264114], [70.49124908, 23.06430817], [70.49153137, 23.06430626], [70.49153137, 23.06569481], [70.49180603, 23.06569099], [70.49180603, 23.06624985], [70.49208069, 23.06624985], [70.49208069, 23.06847191], [70.49236298, 23.06846809], [70.49236298, 23.0723629], [70.49263763, 23.0723629], [70.49263763, 23.07291985], [70.49291992, 23.07291412], [70.49291992, 23.07347488], [70.49318695, 23.07347107], [70.49318695, 23.07402992], [70.49346924, 23.07402992], [70.49346924, 23.07514], [70.49263763, 23.07514], [70.49263763, 23.07542038], [70.49153137, 23.07542038], [70.49153137, 23.07570076], [70.49041748, 23.07569695], [70.49041748, 23.0759716], [70.48929596, 23.0759697], [70.48929596, 23.07625008], [70.48819733, 23.07625008], [70.48819733, 23.07653046], [70.48707581, 23.07653046], [70.48707581, 23.07681084], [70.48596954, 23.07680511], [70.48596954, 23.07708359], [70.48486328, 23.07708359], [70.48486328, 23.07736206], [70.48458099, 23.07736206], [70.48458099, 23.07708359], [70.48458099, 23.07680511], [70.48430634, 23.07681084], [70.48430634, 23.07653046], [70.48401642, 23.07653046], [70.48401642, 23.0759697], [70.48374939, 23.0759716], [70.48374939, 23.07569695], [70.4834671, 23.07570076], [70.4834671, 23.07514], [70.48320007, 23.07514], [70.48320007, 23.07458115], [70.48291779, 23.07458305], [70.48291779, 23.07402802], [70.48264313, 23.07402992], [70.48264313, 23.07374954], [70.48236084, 23.07374954], [70.48236084, 23.07347107], [70.48208618, 23.07347488], [70.48208618, 23.0731945], [70.48180389, 23.0731945], [70.48180389, 23.07291412], [70.48152924, 23.07291985], [70.48152924, 23.0723629], [70.48124695, 23.0723629], [70.48124695, 23.07208061], [70.48069763, 23.07208443], [70.48069763, 23.07180595], [70.48042297, 23.07180977], [70.48042297, 23.07152939], [70.4798584, 23.07152939], [70.4798584, 23.07126045], [70.47930908, 23.07126045], [70.47930908, 23.07097054], [70.47875214, 23.07097054], [70.47875214, 23.07069206], [70.47819519, 23.07069206], [70.47819519, 23.0704174], [70.47735596, 23.07042122], [70.47735596, 23.07014275], [70.47680664, 23.07014275], [70.47680664, 23.06986046], [70.47597504, 23.06986046], [70.47597504, 23.06958389], [70.47486115, 23.06958389], [70.47486115, 23.06930542], [70.47374725, 23.06931114], [70.47374725, 23.06903267], [70.4723587, 23.06903267], [70.4723587, 23.06875229], [70.47125244, 23.06875229], [70.47125244, 23.06847191], [70.46875, 23.06847191], [70.46875, 23.06819534], [70.46763611, 23.06819916], [70.46763611, 23.06792068], [70.46652985, 23.06792068], [70.46652985, 23.0676384], [70.46512604, 23.0676384], [70.46512604, 23.06735992], [70.4640274, 23.06736183], [70.4640274, 23.06708336], [70.46263885, 23.06708336], [70.46263885, 23.06680489], [70.46069336, 23.06680489], [70.46069336, 23.06652832], [70.45874786, 23.06652832], [70.45874786, 23.06624985], [70.45458221, 23.06624985], [70.45458221, 23.06596947], [70.45402527, 23.06597137], [70.45402527, 23.06569481], [70.45375061, 23.06569481], [70.45375061, 23.06541634], [70.44875336, 23.06541824], [70.44875336, 23.06513023], [70.44625092, 23.06513977], [70.44625092, 23.0648613], [70.44596863, 23.0648613], [70.44596863, 23.06513977], [70.44569397, 23.06513977], [70.44569397, 23.0648613], [70.44486237, 23.0648613], [70.44486237, 23.06458282], [70.44319153, 23.06458282], [70.44319153, 23.06430626], [70.44264221, 23.06430817], [70.44264221, 23.06402969], [70.44180298, 23.06402969], [70.44180298, 23.06375122], [70.44095612, 23.06375122], [70.44095612, 23.06347084], [70.44013977, 23.06347275], [70.44013977, 23.06319427], [70.43930817, 23.06319427], [70.43930817, 23.06291771], [70.43875122, 23.06291962], [70.43875122, 23.06264114], [70.43791962, 23.06264114], [70.43791962, 23.06236076], [70.43736267, 23.06236076], [70.43736267, 23.06207085], [70.43708038, 23.0620842], [70.43708038, 23.06180573], [70.43653107, 23.06180954], [70.43653107, 23.06153107], [70.43624878, 23.06153107], [70.43624878, 23.06125069], [70.43569183, 23.06125069], [70.43569183, 23.06097031], [70.43541718, 23.06097221], [70.43541718, 23.06069565], [70.43514252, 23.06069565], [70.43514252, 23.06041718], [70.4345932, 23.06042099], [70.4345932, 23.06014061], [70.43430328, 23.06014061], [70.43430328, 23.05986023], [70.43374634, 23.05986023], [70.43374634, 23.05957985], [70.43319702, 23.05958366], [70.43319702, 23.05930328], [70.4329071, 23.05932045], [70.4329071, 23.05903053], [70.43264008, 23.05903053], [70.43264008, 23.05875015], [70.43235779, 23.05875015], [70.43235779, 23.05846977], [70.43180847, 23.05847359], [70.43180847, 23.05819511], [70.43152618, 23.05820084], [70.43152618, 23.05792046], [70.43125153, 23.05792046], [70.43125153, 23.05764008], [70.43096924, 23.05764008], [70.43096924, 23.0573597], [70.43041992, 23.05736351], [70.43041992, 23.05708122], [70.43013763, 23.05708122], [70.43013763, 23.05680466], [70.42986298, 23.05680466], [70.42986298, 23.05652809], [70.42930603, 23.05653191], [70.42930603, 23.05626106], [70.42901611, 23.05626106], [70.42901611, 23.05596924], [70.42874908, 23.05597115], [70.42874908, 23.05569458], [70.42847443, 23.05569458], [70.42847443, 23.05541611], [70.42791748, 23.05542183], [70.42791748, 23.05514145], [70.42763519, 23.05514145], [70.42763519, 23.05485916], [70.42736053, 23.05485916], [70.42736053, 23.05458069], [70.42708588, 23.0545826], [70.42708588, 23.05430603], [70.42679596, 23.05431175], [70.42679596, 23.05403137], [70.42652893, 23.05403137], [70.42652893, 23.05374908], [70.42595673, 23.05374908], [70.42595673, 23.05347061], [70.42569733, 23.05347252], [70.42569733, 23.05319405], [70.42541504, 23.05319405], [70.42541504, 23.05291748], [70.42514038, 23.05291748], [70.42514038, 23.05264091], [70.42485809, 23.05264091], [70.42485809, 23.05236053], [70.42402649, 23.05236053], [70.42402649, 23.05208015], [70.42375183, 23.05208397], [70.42375183, 23.0518055], [70.42346954, 23.05181122], [70.42346954, 23.05125046], [70.42318726, 23.05125046], [70.42318726, 23.05098915], [70.42263794, 23.05097008], [70.42263794, 23.05041695], [70.42180634, 23.05042076], [70.42180634, 23.04986], [70.42152405, 23.04986191], [70.42152405, 23.04958344], [70.42124939, 23.04958344], [70.42124939, 23.04930687], [70.4209671, 23.04931068], [70.4209671, 23.0490303], [70.42041779, 23.0490303], [70.42041779, 23.04874992], [70.4201355, 23.04874992], [70.4201355, 23.04847145], [70.41986084, 23.04847145], [70.41986084, 23.04819679], [70.41930389, 23.04819679], [70.41930389, 23.04763985], [70.41874695, 23.04763985], [70.41874695, 23.04681015], [70.41847229, 23.04681015], [70.41847229, 23.04652977], [70.41819763, 23.04652977], [70.41819763, 23.04624939], [70.41791534, 23.04624939], [70.41791534, 23.04597473], [70.41764069, 23.04597473], [70.41764069, 23.04569244], [70.4173584, 23.04569244], [70.4173584, 23.04513931], [70.41707611, 23.04514122], [70.41707611, 23.04486275], [70.41680908, 23.04486275], [70.41680908, 23.04458046], [70.41652679, 23.04458427], [70.41652679, 23.04402733], [70.41625214, 23.04403114], [70.41625214, 23.04375267], [70.41596985, 23.04375267], [70.41596985, 23.04347038], [70.41569519, 23.04347038], [70.41569519, 23.04291725], [70.4154129, 23.04292107], [70.4154129, 23.04264259], [70.41513824, 23.04264259], [70.41513824, 23.04236031], [70.41485596, 23.04236031], [70.41485596, 23.04208183], [70.4145813, 23.04208374], [70.4145813, 23.04180527], [70.41430664, 23.0418129], [70.41430664, 23.04153061], [70.41401672, 23.04153061], [70.41401672, 23.04124832], [70.41374969, 23.04124832], [70.41374969, 23.04096031], [70.41319275, 23.04097176], [70.41319275, 23.04069519], [70.41291809, 23.04070091], [70.41291809, 23.04013824], [70.4126358, 23.04013824], [70.4126358, 23.03957939], [70.41236115, 23.03958321], [70.41236115, 23.03930473], [70.41208649, 23.03930473], [70.41208649, 23.03902817], [70.41179657, 23.03902817], [70.41179657, 23.03874969], [70.41152954, 23.03874969], [70.41152954, 23.03847122], [70.4109726, 23.03847313], [70.4109726, 23.03791618], [70.41042328, 23.03791809], [70.41042328, 23.03763962], [70.41014099, 23.03763962], [70.41014099, 23.03736115], [70.4098587, 23.03736115], [70.4098587, 23.03708076], [70.40958405, 23.03708267], [70.40958405, 23.03680611], [70.4090271, 23.03680992], [70.4090271, 23.03652954], [70.40875244, 23.03652954], [70.40875244, 23.03625107], [70.40847015, 23.03625107], [70.40847015, 23.03597069], [70.4081955, 23.0359726], [70.4081955, 23.03569412], [70.40763855, 23.03569412], [70.40763855, 23.03541756], [70.40735626, 23.03541946], [70.40735626, 23.03515053], [70.40722656, 23.03515053], [70.4070816, 23.03515053], [70.4070816, 23.03486061], [70.40680695, 23.03486061], [70.40680695, 23.03458023], [70.40652466, 23.03458595], [70.40652466, 23.03430557], [70.40625, 23.03430939], [70.40625, 23.03403091], [70.40598297, 23.03403091], [70.40598297, 23.03375053], [70.40569305, 23.03375053], [70.40569305, 23.03347015], [70.4054184, 23.03347206], [70.4054184, 23.0331955], [70.40513611, 23.0331955], [70.40513611, 23.03263855], [70.40484619, 23.03264046], [70.40484619, 23.03209114], [70.40458679, 23.03209114], [70.40458679, 23.03181076], [70.40429688, 23.03181076], [70.40429688, 23.03125191], [70.40402985, 23.03125191], [70.40402985, 23.03096962], [70.40374756, 23.03097343], [70.40374756, 23.03069305], [70.4034729, 23.03070068], [70.4034729, 23.0304203], [70.40319824, 23.0304203], [70.40319061, 23.02985954], [70.40291595, 23.02985954], [70.40291595, 23.02958107], [70.4026413, 23.02958107], [70.4026413, 23.02930641], [70.40235901, 23.02931023], [70.40235901, 23.0290184], [70.40208435, 23.02902794], [70.40208435, 23.02958107], [70.4017868, 23.02957916], [70.4017868, 23.03014183], [70.4015274, 23.03014183], [70.4015274, 23.03070068], [70.40125275, 23.03070068], [70.40125275, 23.0304203], [70.40097046, 23.0304203], [70.40097046, 23.03014183], [70.4006958, 23.03014183], [70.4006958, 23.02985954], [70.40041351, 23.02985954], [70.40041351, 23.02930641], [70.40013885, 23.02931023], [70.40013885, 23.0290184], [70.3998642, 23.02902794], [70.3998642, 23.02874947], [70.39958191, 23.02874947], [70.39958191, 23.02846909], [70.39930725, 23.0284729], [70.39930725, 23.02819443], [70.39902496, 23.02819443], [70.39902496, 23.02791595], [70.39875031, 23.02792168], [70.39875031, 23.02763939], [70.39847565, 23.02763939], [70.39847565, 23.02736092], [70.39819336, 23.02736092], [70.39819336, 23.02708054], [70.3979187, 23.02708244], [70.3979187, 23.02680588], [70.39763641, 23.02680969], [70.39763641, 23.02653122], [70.39736176, 23.02653122], [70.39736176, 23.02625084], [70.3970871, 23.02625084], [70.3970871, 23.02596092], [70.39680481, 23.02597237], [70.39680481, 23.02569389], [70.39653015, 23.02569389], [70.39653015, 23.02541733], [70.39624786, 23.02542114], [70.39624786, 23.02458], [70.39653015, 23.02458382], [70.39653015, 23.02124977], [70.39624786, 23.02124977], [70.39624786, 23.02015114], [70.39598083, 23.02015114], [70.39598083, 23.01708031], [70.39624786, 23.01708221], [70.39624786, 23.01569366], [70.39597321, 23.01569366], [70.39597321, 23.01458359], [70.39569092, 23.01458359], [70.39569092, 23.01319504], [70.39541626, 23.01320076], [70.39541626, 23.01152992], [70.3951416, 23.01152992], [70.3951416, 23.00986099], [70.39485931, 23.00986099], [70.39485931, 23.00819016], [70.39458466, 23.00819588], [70.39458466, 23.00652695], [70.39430237, 23.00653076], [70.39430237, 23.0051403], [70.39402771, 23.0051403], [70.39402771, 23.00403023], [70.39375305, 23.00403023], [70.39375305, 23.00346947], [70.39347076, 23.00347137], [70.39347076, 23.00319481], [70.39319611, 23.00319481], [70.39319611, 23.00264168], [70.39347076, 23.00264168], [70.39347076, 23.00208092], [70.39375305, 23.00208282], [70.39375305, 23.00152779], [70.39290619, 23.0015316], [70.39290619, 23.00124931], [70.39235687, 23.00124931], [70.39235687, 23.00097084], [70.39208221, 23.00097275], [70.39208221, 23.00069427], [70.39125061, 23.00069427], [70.39125061, 23.0004158], [70.38957977, 23.00042152], [70.38957977, 23.00013924], [70.38957977, 22.99958038], [70.38930511, 22.9995842], [70.38930511, 22.99930573], [70.38874817, 22.99930954], [70.38874817, 22.9990406], [70.38819122, 22.9990406], [70.38819122, 22.99875069], [70.38764191, 22.99875069], [70.38764191, 22.99847031], [70.38680267, 22.99847221], [70.38680267, 22.99819374], [70.38513947, 22.99819374], [70.38513947, 22.99847221], [70.38402557, 22.99847221], [70.38402557, 22.99819374], [70.38291931, 22.99819374], [70.38291931, 22.99791718], [70.38263702, 22.99792099], [70.38263702, 22.99764061], [70.38291931, 22.99764061], [70.38291931, 22.99736023], [70.38404083, 22.99736023], [70.38404083, 22.99764061], [70.38513947, 22.99764061], [70.38513947, 22.99736023], [70.3868103, 22.99736023], [70.3868103, 22.99764061], [70.38874817, 22.99764061], [70.38874817, 22.99792099], [70.39235687, 22.99792099], [70.39235687, 22.99764061], [70.39263916, 22.99764061], [70.39263916, 22.99736023], [70.39290619, 22.99736023], [70.39290619, 22.99707985], [70.39319611, 22.99708366], [70.39319611, 22.99680519], [70.39347076, 22.99681091], [70.39347076, 22.99653053], [70.39375305, 22.99653053], [70.39375305, 22.99625015], [70.39402771, 22.99625015], [70.39402771, 22.99598122], [70.39430237, 22.99598122], [70.39430237, 22.99542046], [70.39457703, 22.99542046], [70.39457703, 22.99152946], [70.39485931, 22.99152946], [70.39485931, 22.98735809], [70.39458466, 22.98736191], [70.39458466, 22.9734726], [70.39430237, 22.9734726], [70.39430237, 22.96958351], [70.39402771, 22.96958351], [70.39402771, 22.96763802], [70.39375305, 22.96763992], [70.39375305, 22.96568108], [70.39347076, 22.96569443], [70.39347076, 22.96319389], [70.39319611, 22.96319389], [70.39319611, 22.96264076], [70.39290619, 22.96264267], [70.39290619, 22.96208191], [70.39263916, 22.96208382], [70.39263916, 22.96152687], [70.39235687, 22.96153069], [70.39235687, 22.96096992], [70.39208221, 22.96097183], [70.39208221, 22.96041679], [70.39180756, 22.96042061], [70.39180756, 22.95986938], [70.3915329, 22.95986938], [70.3915329, 22.95930099], [70.39125061, 22.95930481], [70.39125061, 22.95874977], [70.39097595, 22.95874977], [70.39097595, 22.95791817], [70.39068604, 22.95791817], [70.39068604, 22.95736122], [70.39041901, 22.95736122], [70.39041901, 22.95680809], [70.39013672, 22.95680809], [70.39013672, 22.95597076], [70.38986206, 22.95597267], [70.38986206, 22.95541763], [70.38957977, 22.95541954], [70.38957977, 22.95486069], [70.38930511, 22.95486069], [70.38930511, 22.95430565], [70.38903046, 22.95430946], [70.38903046, 22.95374107], [70.38874817, 22.95375061], [70.38874817, 22.95347214], [70.38847351, 22.95347214], [70.38847351, 22.9529171], [70.38819122, 22.95292091], [70.38819122, 22.95236015], [70.38791656, 22.95236206], [70.38791656, 22.95208359], [70.38764191, 22.95208359], [70.38764191, 22.95152855], [70.38735962, 22.95153046], [70.38735962, 22.9509697], [70.38708496, 22.95097351], [70.38708496, 22.94874954], [70.38680267, 22.94874954], [70.38680267, 22.9481945], [70.38652802, 22.9481945], [70.38652802, 22.94791603], [70.38625336, 22.94792938], [70.38625336, 22.94735909], [70.38597107, 22.94735909], [70.38597107, 22.94708061], [70.38569641, 22.94708252], [70.38569641, 22.94652748], [70.38540649, 22.94652748], [70.38540649, 22.94625092], [70.38513947, 22.94625092], [70.38513947, 22.94597054], [70.38486481, 22.94597244], [70.38486481, 22.94569397], [70.38458252, 22.94569397], [70.38458252, 22.9454174], [70.38430786, 22.94542122], [70.38430786, 22.94514084], [70.38404083, 22.94514084], [70.38404083, 22.94486809], [70.38375092, 22.94486809], [70.38375092, 22.94458008], [70.38319397, 22.94458389], [70.38319397, 22.94430542], [70.38291931, 22.94431114], [70.38291931, 22.94403076], [70.38236237, 22.94403076], [70.38236237, 22.94375038], [70.38180542, 22.94375038], [70.38180542, 22.94347191], [70.38124847, 22.94347191], [70.38124847, 22.94319534], [70.38067627, 22.94320107], [70.38067627, 22.94292068], [70.37874603, 22.94292068], [70.37874603, 22.9426403], [70.37819672, 22.9426403], [70.37819672, 22.94235992], [70.37763977, 22.94236183], [70.37763977, 22.94208336], [70.37708282, 22.94208336], [70.37708282, 22.94180679], [70.37652588, 22.94180679], [70.37652588, 22.94152832], [70.37596893, 22.94153023], [70.37596893, 22.94124985], [70.37513733, 22.94124985], [70.37513733, 22.94096947], [70.37458038, 22.94097137], [70.37458038, 22.94069481], [70.37374878, 22.94069481], [70.37374878, 22.94041634], [70.37319183, 22.94042015], [70.37319183, 22.94013977], [70.37236023, 22.94013977], [70.37236023, 22.93985939], [70.37208557, 22.9398613], [70.37208557, 22.93958473], [70.37152863, 22.93958473], [70.37152863, 22.93930626], [70.37124634, 22.93931007], [70.37124634, 22.93902969], [70.37069702, 22.93902969], [70.37069702, 22.93873978], [70.37041473, 22.93874931], [70.37041473, 22.93847466], [70.36985779, 22.93847466], [70.36985779, 22.93819237], [70.36958313, 22.93819237], [70.36958313, 22.9379158], [70.36873627, 22.93791962], [70.36873627, 22.93764114], [70.36818695, 22.93764114], [70.36818695, 22.93736267], [70.36736298, 22.93736267], [70.36736298, 22.93708038], [70.36680603, 22.9370842], [70.36680603, 22.93680573], [70.3659668, 22.93680954], [70.3659668, 22.93653107], [70.36541748, 22.93653107], [70.36541748, 22.93625259], [70.36486053, 22.93625259], [70.36486053, 22.93597031], [70.36402893, 22.93597031], [70.36402893, 22.93569374], [70.36347198, 22.93569946], [70.36347198, 22.9354229], [70.36235809, 22.9354229], [70.36235809, 22.93514252], [70.36096954, 22.93514252], [70.36096954, 22.93485832], [70.35986328, 22.93485832], [70.35986328, 22.93458366], [70.35847473, 22.93458366], [70.35847473, 22.93430519], [70.35791779, 22.93431091], [70.35791779, 22.93403053], [70.35708618, 22.93403053], [70.35708618, 22.93374825], [70.35652924, 22.93374825], [70.35652924, 22.93346977], [70.35597229, 22.93347168], [70.35597229, 22.93319511], [70.35514069, 22.93320084], [70.35514069, 22.9329319], [70.35457611, 22.9329319], [70.35457611, 22.93263817], [70.35402679, 22.93263817], [70.35402679, 22.9323597], [70.35319519, 22.9323616], [70.35319519, 22.93208313], [70.35263824, 22.93208313], [70.35263824, 22.93180466], [70.35180664, 22.93180466], [70.35180664, 22.93152618], [70.35124969, 22.93152809], [70.35124969, 22.93124962], [70.35067749, 22.93124962], [70.35067749, 22.93097115], [70.34764099, 22.93097305], [70.34764099, 22.93041611], [70.34513855, 22.93041611], [70.34513855, 22.93069458], [70.34347534, 22.93069458], [70.34347534, 22.93097305], [70.34208679, 22.93097115], [70.34208679, 22.93124962], [70.34041595, 22.93124962], [70.34041595, 22.93152809], [70.33958435, 22.93152618], [70.33958435, 22.93180466], [70.33875275, 22.93180466], [70.33875275, 22.93208313], [70.33763885, 22.93208313], [70.33763885, 22.9323616], [70.33680725, 22.9323597], [70.33680725, 22.93263817], [70.33599091, 22.93263817], [70.33599091, 22.9329319], [70.33513641, 22.9329319], [70.33513641, 22.93320084], [70.33430481, 22.93319511], [70.33430481, 22.93347168], [70.33347321, 22.93346977], [70.33347321, 22.93374825], [70.33235931, 22.93374825], [70.33235931, 22.93403053], [70.33152771, 22.93403053], [70.33152771, 22.93431091], [70.33069611, 22.93430519], [70.33069611, 22.93458366], [70.32956696, 22.93457985], [70.32956696, 22.93485832], [70.32847595, 22.93485832], [70.32847595, 22.93514252], [70.32763672, 22.93514252], [70.32763672, 22.9354229], [70.32653046, 22.9354229], [70.32653046, 22.93569946], [70.32541656, 22.93569374], [70.32541656, 22.93597031], [70.32458496, 22.93597031], [70.32458496, 22.93625259], [70.32376099, 22.93625259], [70.32376099, 22.93653107], [70.32290649, 22.93653107], [70.32290649, 22.93680954], [70.32208252, 22.93680573], [70.32208252, 22.9370842], [70.32152557, 22.9370842], [70.3215332, 22.93736267], [70.32096863, 22.93736267], [70.32096863, 22.93764114], [70.3207016, 22.93764114], [70.3207016, 22.93791962], [70.32013702, 22.9379158], [70.32013702, 22.93819237], [70.31986237, 22.93819237], [70.31986237, 22.93847466], [70.31930542, 22.93847466], [70.31930542, 22.93874931], [70.31903076, 22.93873978], [70.31903076, 22.93902969], [70.31680298, 22.93902969], [70.31680298, 22.93931007], [70.31652832, 22.93930626], [70.31652832, 22.93958473], [70.31625366, 22.93958473], [70.31625366, 22.9398613], [70.31597137, 22.93985939], [70.31597137, 22.94013977], [70.31569672, 22.94013977], [70.31569672, 22.94042015], [70.31541443, 22.94041634], [70.31541443, 22.94069481], [70.31485748, 22.94069481], [70.31485748, 22.94097137], [70.31456757, 22.94096947], [70.31456757, 22.94124985], [70.31318665, 22.94124985], [70.31318665, 22.94153023], [70.31291962, 22.94152832], [70.31291962, 22.94208336], [70.31153107, 22.94208336], [70.31153107, 22.94180679], [70.31124878, 22.94180679], [70.31124878, 22.94152832], [70.31014252, 22.94152832], [70.31014252, 22.94180679], [70.30986023, 22.94180679], [70.30986023, 22.94208336], [70.3095932, 22.94207954], [70.3095932, 22.9426403], [70.30930328, 22.9426384], [70.30930328, 22.94347191], [70.30902863, 22.94347], [70.30902863, 22.94375038], [70.3087616, 22.94375038], [70.3087616, 22.94403076], [70.30819702, 22.94403076], [70.30819702, 22.94431114], [70.30791473, 22.94430542], [70.30791473, 22.94458389], [70.30764008, 22.94458008], [70.30764008, 22.94486809], [70.30735779, 22.94486809], [70.30735779, 22.94514084], [70.30708313, 22.94514084], [70.30708313, 22.94542122], [70.30680847, 22.9454174], [70.30680847, 22.94597244], [70.30652618, 22.94597054], [70.30652618, 22.94625092], [70.30625153, 22.94625092], [70.30625153, 22.94681168], [70.30596924, 22.94681168], [70.30596924, 22.94874954], [70.30625153, 22.94874954], [70.30625153, 22.94930077], [70.30652618, 22.94930649], [70.30652618, 22.94958115], [70.30680847, 22.94958115], [70.30680847, 22.94985962], [70.30708313, 22.94985962], [70.30708313, 22.95042038], [70.30735779, 22.95042038], [70.30735779, 22.95125008], [70.30458069, 22.95125008], [70.30458069, 22.9509697], [70.30403137, 22.95097351], [70.30403137, 22.95069504], [70.3034668, 22.95070076], [70.3034668, 22.95042038], [70.30291748, 22.95042038], [70.30291748, 22.95014191], [70.30208588, 22.95014191], [70.30208588, 22.94985962], [70.30152893, 22.94985962], [70.30152893, 22.94958115], [70.30097198, 22.94958115], [70.30097198, 22.94930649], [70.30042267, 22.9493103], [70.30042267, 22.94903183], [70.29985809, 22.94903183], [70.29985809, 22.94874954], [70.29959106, 22.94874954], [70.29959106, 22.94903183], [70.29930878, 22.94903183], [70.29930878, 22.94874954], [70.29792023, 22.94874954], [70.29792023, 22.94846916], [70.29763794, 22.94847107], [70.29763794, 22.9481945], [70.29736328, 22.9481945], [70.29736328, 22.94791603], [70.29708099, 22.94792938], [70.29708099, 22.94764137], [70.29652405, 22.94764137], [70.29652405, 22.94735909], [70.29624939, 22.94735909], [70.29624939, 22.94708061], [70.29569244, 22.94708252], [70.29569244, 22.94680595], [70.29514313, 22.94681168], [70.29514313, 22.94652748], [70.29458618, 22.94652748], [70.29458618, 22.94625092], [70.29429626, 22.94625092], [70.29429626, 22.94597054], [70.29374695, 22.94597244], [70.29374695, 22.94569397], [70.29319763, 22.94569397], [70.29319763, 22.9454174], [70.29180908, 22.94542122], [70.29180908, 22.94514084], [70.29096985, 22.94514084], [70.29096985, 22.94486809], [70.2895813, 22.94486809], [70.2895813, 22.94514084], [70.28874969, 22.94514084], [70.28874969, 22.94542122], [70.28819275, 22.94542122], [70.28819275, 22.94514084], [70.28791809, 22.94514084], [70.28791809, 22.94542122], [70.28736115, 22.9454174], [70.28736115, 22.94569397], [70.28708649, 22.94569397], [70.28708649, 22.94597244], [70.28652954, 22.94597054], [70.28652954, 22.94625092], [70.28624725, 22.94625092], [70.28624725, 22.94652748], [70.2859726, 22.94652748], [70.2859726, 22.94681168], [70.28569794, 22.94680595], [70.28569794, 22.94708252], [70.28541565, 22.94708252], [70.28541565, 22.94680595], [70.28514099, 22.94680595], [70.28514099, 22.94708252], [70.28430939, 22.94708061], [70.28430176, 22.94735909], [70.2840271, 22.94735909], [70.2840271, 22.94764137], [70.28320312, 22.94764137], [70.28320312, 22.94792938], [70.28263855, 22.94791603], [70.28263855, 22.9481945], [70.2820816, 22.9481945], [70.2820816, 22.94847107], [70.28097534, 22.94847107], [70.28098297, 22.94874954], [70.27929688, 22.94874954], [70.27929688, 22.94903183], [70.27986145, 22.94903183], [70.27986145, 22.9493103], [70.27958679, 22.94930649], [70.27958679, 22.94985962], [70.27929688, 22.94985962], [70.27929688, 22.95070076], [70.27902985, 22.95069504], [70.27902985, 22.95097351], [70.2784729, 22.95097351], [70.2784729, 22.95041656], [70.27819824, 22.95041656], [70.27819824, 22.95097351], [70.2776413, 22.9509697], [70.2776413, 22.95125008], [70.27707672, 22.95125008], [70.27707672, 22.95153046], [70.27571106, 22.95153046], [70.27571106, 22.95181084], [70.27541351, 22.95180321], [70.27541351, 22.95208359], [70.2756958, 22.95208359], [70.2756958, 22.95236015], [70.27597046, 22.95236015], [70.27597046, 22.95264053], [70.27485657, 22.95264053], [70.27485657, 22.95236015], [70.27458191, 22.95236206], [70.27458191, 22.95180321], [70.27430725, 22.95180321], [70.27430725, 22.95236206], [70.27403259, 22.95236015], [70.27403259, 22.95264053], [70.27348328, 22.95264053], [70.27348328, 22.95292091], [70.27319336, 22.9529171], [70.27319336, 22.95319557], [70.2729187, 22.95319557], [70.2729187, 22.95347214], [70.27236176, 22.95347214], [70.27236176, 22.95375061], [70.2720871, 22.95374107], [70.2720871, 22.95403099], [70.27179718, 22.95403099], [70.27179718, 22.95430946], [70.27153015, 22.95430565], [70.27153015, 22.95458412], [70.27124786, 22.95458031], [70.27124786, 22.95514107], [70.2701416, 22.95514107], [70.2701416, 22.95541954], [70.26875305, 22.95541763], [70.26875305, 22.9556942], [70.26902771, 22.95569038], [70.26902771, 22.95625114], [70.26847076, 22.95625114], [70.26847076, 22.95652962], [70.26819611, 22.95652962], [70.26819611, 22.95625114], [70.26791382, 22.95624924], [70.26791382, 22.95708275], [70.26763916, 22.95708084], [70.26763916, 22.95736122], [70.26735687, 22.95736122], [70.26735687, 22.95763969], [70.26708221, 22.95763969], [70.26708221, 22.95819473], [70.26680756, 22.95819473], [70.26680756, 22.9584713], [70.26651764, 22.95846939], [70.26651764, 22.95902824], [70.26625061, 22.95902824], [70.26625061, 22.95930481], [70.26597595, 22.95930481], [70.26597595, 22.95958328], [70.26568604, 22.95957947], [70.26568604, 22.96013832], [70.26541901, 22.96013832], [70.26541901, 22.96042061], [70.26569366, 22.96041679], [70.26569366, 22.96097183], [70.26597595, 22.96096992], [70.26597595, 22.9612484], [70.26625061, 22.9612484], [70.26625061, 22.96153069], [70.26597595, 22.96153069], [70.26597595, 22.96181107], [70.26569366, 22.96180534], [70.26569366, 22.96208382], [70.26541901, 22.96208191], [70.26541901, 22.96236038], [70.26486206, 22.96236038], [70.26486206, 22.96264267], [70.26347351, 22.96264076], [70.26347351, 22.96291733], [70.26264191, 22.96291733], [70.26264191, 22.96319389], [70.26208496, 22.96319389], [70.26208496, 22.96347046], [70.26180267, 22.96347046], [70.26180267, 22.96375275], [70.26152802, 22.96375275], [70.26152802, 22.96403122], [70.26125336, 22.96403122], [70.26125336, 22.96430969], [70.26097107, 22.96430588], [70.26097107, 22.96458054], [70.26069641, 22.96458054], [70.26069641, 22.96486282], [70.26042175, 22.96486282], [70.26039124, 22.96513939], [70.26013947, 22.96513939], [70.26013947, 22.96541977], [70.25986481, 22.96541405], [70.25986481, 22.96569443], [70.25958252, 22.96569443], [70.25958252, 22.96597481], [70.25930786, 22.9659729], [70.25930786, 22.96624947], [70.2590332, 22.96624947], [70.2590332, 22.96652985], [70.25875092, 22.96652985], [70.25875092, 22.96681023], [70.25846863, 22.96680641], [70.25846863, 22.96708488], [70.25791931, 22.96708488], [70.25791931, 22.96736145], [70.25763702, 22.96735954], [70.25763702, 22.96763992], [70.25734711, 22.96763992], [70.25734711, 22.9679203], [70.25708008, 22.9679203], [70.25708008, 22.96820068], [70.25680542, 22.96819687], [70.25680542, 22.96847153], [70.25653076, 22.96846962], [70.25653076, 22.96875], [70.25624847, 22.96875], [70.25624847, 22.96903038], [70.25596619, 22.96903038], [70.25596619, 22.96931076], [70.25541687, 22.96930695], [70.25541687, 22.96958351], [70.25514221, 22.96958351], [70.25514221, 22.96986198], [70.25485992, 22.96986008], [70.25485992, 22.97014046], [70.25457764, 22.97014046], [70.25457764, 22.97042084], [70.25430298, 22.97041512], [70.25430298, 22.97069359], [70.25402832, 22.97069359], [70.25402832, 22.97097206], [70.25347137, 22.97097015], [70.25347137, 22.97125053], [70.25319672, 22.97125053], [70.25319672, 22.97153091], [70.2529068, 22.97153091], [70.2529068, 22.97180748], [70.25235748, 22.97180557], [70.25235748, 22.97208405], [70.25208282, 22.97208023], [70.25208282, 22.97236061], [70.25180817, 22.97236061], [70.25180817, 22.97263908], [70.25125122, 22.97263908], [70.25125122, 22.97291756], [70.25096893, 22.97291756], [70.25096893, 22.97319412], [70.25069427, 22.97319412], [70.25069427, 22.9734726], [70.24986267, 22.9734726], [70.24986267, 22.97319412], [70.24930573, 22.97319412], [70.24930573, 22.97291756], [70.24847412, 22.97291756], [70.24847412, 22.97306061], [70.24847412, 22.97319412], [70.24819183, 22.97319412], [70.24819183, 22.97348022], [70.24819183, 22.97374916], [70.24791718, 22.97374916], [70.24791718, 22.97388077], [70.24791718, 22.97403145], [70.24781036, 22.97402763], [70.24736023, 22.97403145], [70.24736023, 22.97431183], [70.24708557, 22.97430611], [70.24708557, 22.97458267], [70.24652863, 22.97458267], [70.24652863, 22.97485924], [70.24624634, 22.9748497], [70.24624634, 22.97514153], [70.24569702, 22.97514153], [70.24569702, 22.97542191], [70.24541473, 22.97541618], [70.24541473, 22.97569466], [70.24485779, 22.97569466], [70.24485779, 22.97597122], [70.24458313, 22.97596931], [70.24458313, 22.9762516], [70.24430847, 22.9762516], [70.24430847, 22.97653008], [70.24375153, 22.97652817], [70.24375153, 22.97680473], [70.24346924, 22.97680473], [70.24346924, 22.9770813], [70.24291992, 22.9770813], [70.24291992, 22.97736359], [70.24263763, 22.97735977], [70.24263763, 22.97764015], [70.24208069, 22.97763824], [70.24208069, 22.97791672], [70.24180603, 22.9779129], [70.24180603, 22.97820091], [70.24069214, 22.97819519], [70.24069214, 22.97847366], [70.23986053, 22.97846985], [70.23986053, 22.97875023], [70.23874664, 22.97875023], [70.23874664, 22.97903061], [70.23792267, 22.97903061], [70.23792267, 22.97931099], [70.23764038, 22.97930527], [70.23764038, 22.97958565], [70.23652649, 22.97958565], [70.23654175, 22.97986031], [70.23625183, 22.97986031], [70.23625183, 22.97957993], [70.23542023, 22.97958565], [70.23542023, 22.97930527], [70.23486328, 22.97931099], [70.23486328, 22.97903061], [70.23401642, 22.97903061], [70.23401642, 22.97875023], [70.2334671, 22.97875023], [70.2334671, 22.97846985], [70.2326355, 22.97847366], [70.2326355, 22.97819519], [70.23179626, 22.97820091], [70.23179626, 22.9779129], [70.23124695, 22.97791672], [70.23124695, 22.97763824], [70.23040771, 22.97764015], [70.23040771, 22.97735977], [70.2298584, 22.97736359], [70.2298584, 22.9770813], [70.22930908, 22.9770813], [70.22930908, 22.97569466], [70.22958374, 22.97569466], [70.22958374, 22.97458267], [70.2298584, 22.97458267], [70.2298584, 22.97208405], [70.23014069, 22.97208405], [70.23014069, 22.96986198], [70.2298584, 22.96986198], [70.2298584, 22.96819687], [70.22957611, 22.96820068], [70.22957611, 22.96681023], [70.22930908, 22.96681023], [70.22930908, 22.96624947], [70.22902679, 22.96624947], [70.22902679, 22.9659729], [70.2270813, 22.9659729], [70.2270813, 22.96624947], [70.22680664, 22.96624947], [70.22680664, 22.96652985], [70.22651672, 22.96652985], [70.22651672, 22.96681023], [70.22624969, 22.96680641], [70.22624969, 22.96708488], [70.22597504, 22.96708488], [70.22597504, 22.96736145], [70.22541809, 22.96735954], [70.22541809, 22.96763992], [70.2251358, 22.96763992], [70.2251358, 22.9679203], [70.22486115, 22.9679203], [70.22486115, 22.96820068], [70.22458649, 22.96819687], [70.22458649, 22.96847153], [70.2243042, 22.96847153], [70.22431183, 22.96875], [70.22402954, 22.96875], [70.22402954, 22.96903038], [70.22374725, 22.96903038], [70.22374725, 22.96931076], [70.2234726, 22.96930695], [70.2234726, 22.96958351], [70.22291565, 22.96958351], [70.22291565, 22.96986198], [70.22264099, 22.96986008], [70.22264099, 22.97014046], [70.2223587, 22.97014046], [70.2223587, 22.97042084], [70.22180939, 22.97041512], [70.22180176, 22.97069359], [70.2215271, 22.97069359], [70.2215271, 22.97097206], [70.22125244, 22.97097015], [70.22125244, 22.97125053], [70.22070313, 22.97125053], [70.22070313, 22.97153091], [70.22041321, 22.97153091], [70.22041321, 22.97180748], [70.22013855, 22.97180557], [70.22013855, 22.97208405], [70.2195816, 22.97208023], [70.2195816, 22.97236061], [70.21930695, 22.97236061], [70.21930695, 22.97263908], [70.21875, 22.97263908], [70.21875, 22.97291756], [70.21847534, 22.97291756], [70.21847534, 22.97319412], [70.2179184, 22.97319412], [70.2179184, 22.9734726], [70.21763611, 22.97347069], [70.21763611, 22.97374916], [70.21736145, 22.97374916], [70.21736145, 22.97403145], [70.21679688, 22.97403145], [70.21679688, 22.97431183], [70.21652985, 22.97430611], [70.21652985, 22.97458267], [70.2159729, 22.97458267], [70.2159729, 22.97485924], [70.21569824, 22.9748497], [70.21569824, 22.97514153], [70.2151413, 22.97514153], [70.2151413, 22.97542191], [70.21458435, 22.97541618], [70.21458435, 22.97569466], [70.2140274, 22.97569466], [70.2140274, 22.97597122], [70.21347046, 22.97596931], [70.21347046, 22.9762516], [70.2131958, 22.9762516], [70.2131958, 22.97653008], [70.21263885, 22.97652817], [70.21263885, 22.97680473], [70.21208191, 22.97680473], [70.21208191, 22.9770813], [70.21152496, 22.9770813], [70.21152496, 22.97736359], [70.21098328, 22.97735977], [70.21098328, 22.97764015], [70.2104187, 22.97763824], [70.2104187, 22.97791672], [70.20986176, 22.9779129], [70.20986176, 22.97820091], [70.2095871, 22.97819519], [70.2095871, 22.97847366], [70.20903015, 22.97846985], [70.20903015, 22.97875023], [70.20847321, 22.97875023], [70.20847321, 22.97903061], [70.20791626, 22.97903061], [70.20791626, 22.97931099], [70.2076416, 22.97930527], [70.2076416, 22.97958565], [70.20707703, 22.97957993], [70.20707703, 22.97986031], [70.20652771, 22.97986031], [70.20652771, 22.98014069], [70.20623779, 22.98014069], [70.20623779, 22.98042107], [70.20597076, 22.98041725], [70.20597076, 22.98069572], [70.20569611, 22.98069], [70.20569611, 22.98125076], [70.20540619, 22.98125076], [70.20540619, 22.98153114], [70.20513916, 22.98153114], [70.20513916, 22.98180962], [70.2048645, 22.9818058], [70.2048645, 22.98208427], [70.20458221, 22.98208046], [70.20458221, 22.98236084], [70.20430756, 22.98236084], [70.20430756, 22.98291969], [70.20402527, 22.98291779], [70.20402527, 22.98319435], [70.20375061, 22.98319435], [70.20375061, 22.98347282], [70.20349884, 22.98347092], [70.20346832, 22.98404121], [70.20319366, 22.98402786], [70.20319366, 22.98486137], [70.20291901, 22.98486137], [70.20291901, 22.98569489], [70.20263672, 22.98569107], [70.20263672, 22.9865284], [70.20236206, 22.9865284], [70.20236206, 22.98748016], [70.20236206, 22.98763847], [70.20207977, 22.98763847], [70.20207977, 22.98875237], [70.20181274, 22.98875237], [70.20181274, 22.99014282], [70.20153046, 22.99014282], [70.20153046, 22.99152946], [70.20124817, 22.99152946], [70.20124817, 22.99263954], [70.20097351, 22.99263954], [70.20097351, 22.99347305], [70.20069122, 22.99347115], [70.20069122, 22.99403], [70.20041656, 22.99402809], [70.20041656, 22.99458313], [70.20014191, 22.99458122], [70.20014191, 22.99514008], [70.19985962, 22.99514008], [70.19985962, 22.99542046], [70.19959259, 22.99542046], [70.19959259, 22.99570084], [70.19930267, 22.99570084], [70.19930267, 22.99598122], [70.19902802, 22.99598122], [70.19902802, 22.99653053], [70.19875336, 22.99653053], [70.19875336, 22.99681091], [70.19847107, 22.99681091], [70.19847107, 22.99736023], [70.19819641, 22.99736023], [70.19819641, 22.99792099], [70.19791412, 22.99791718], [70.19791412, 22.99847221], [70.19403076, 22.99847221], [70.19403076, 22.99819374], [70.19319153, 22.99819374], [70.19319153, 22.99791718], [70.1912384, 22.99792099], [70.1912384, 22.99764061], [70.18902588, 22.99764061], [70.18902588, 22.99736023], [70.18875122, 22.99736023], [70.18875122, 22.99707985], [70.18846893, 22.99708366], [70.18846893, 22.99680519], [70.1882019, 22.99681091], [70.1882019, 22.99653053], [70.18791962, 22.99653053], [70.18791962, 22.99625015], [70.18763733, 22.99625015], [70.18763733, 22.99570084], [70.18736267, 22.99570084], [70.18736267, 22.99542046], [70.18708038, 22.99542046], [70.18708038, 22.9948597], [70.18680573, 22.9948616], [70.18680573, 22.99430466], [70.18653107, 22.99430466], [70.18653107, 22.99374962], [70.18624878, 22.99374962], [70.18624878, 22.99180984], [70.18653107, 22.99180984], [70.18653107, 22.9912529], [70.18708038, 22.9912529], [70.18708038, 22.99180984], [70.18736267, 22.99180603], [70.18736267, 22.99347305], [70.18763733, 22.99347305], [70.18763733, 22.99458313], [70.18875122, 22.99458313], [70.18875122, 22.9948616], [70.18985748, 22.9948597], [70.18985748, 22.99514008], [70.19264221, 22.99514008], [70.19264221, 22.99542046], [70.19319916, 22.99542046], [70.19568634, 22.99542046], [70.19568634, 22.99514008], [70.19625092, 22.99514008], [70.19625092, 22.9948597], [70.19652557, 22.9948616], [70.19652557, 22.99458313], [70.19708252, 22.99458313], [70.19708252, 22.99430466], [70.19763947, 22.99430466], [70.19763947, 22.99402809], [70.19790649, 22.99403], [70.19790649, 22.99347115], [70.19819641, 22.99347305], [70.19819641, 22.99319458], [70.19847107, 22.99319458], [70.19847107, 22.99180603], [70.19819641, 22.99180984], [70.19819641, 22.99069023], [70.19791412, 22.99069214], [70.19791412, 22.98958206], [70.19819641, 22.98958206], [70.19819641, 22.98875237], [70.19847107, 22.98875237], [70.19847107, 22.98792076], [70.19875336, 22.98792076], [70.19875336, 22.98707962], [70.19902802, 22.98708344], [70.19902802, 22.98624992], [70.19930267, 22.98624992], [70.19930267, 22.98485947], [70.19958496, 22.98486137], [70.19958496, 22.98374939], [70.19985962, 22.98374939], [70.19985962, 22.98319054], [70.20014191, 22.98319435], [70.20014191, 22.98263931], [70.20043182, 22.98264122], [70.20043182, 22.98208046], [70.20069122, 22.98208237], [70.20069122, 22.98152733], [70.20096588, 22.98153114], [70.20096588, 22.98125076], [70.20124817, 22.98125076], [70.20124817, 22.98097992], [70.20153046, 22.98097992], [70.20153046, 22.98069], [70.20180511, 22.98069572], [70.20180511, 22.98041725], [70.20207977, 22.98042107], [70.20207977, 22.98014069], [70.20236206, 22.98014069], [70.20236206, 22.97957993], [70.20263672, 22.97958565], [70.20263672, 22.97930527], [70.20291901, 22.97931099], [70.20291901, 22.97903061], [70.20317841, 22.97903061], [70.20317841, 22.97875023], [70.20346832, 22.97875023], [70.20346832, 22.97846985], [70.20375061, 22.97847366], [70.20375061, 22.97819519], [70.2040329, 22.97820091], [70.2040329, 22.9779129], [70.20458221, 22.97791672], [70.20458221, 22.97763824], [70.20485687, 22.97764015], [70.20485687, 22.97735977], [70.20513916, 22.97736359], [70.20513916, 22.9770813], [70.20569611, 22.9770813], [70.20569611, 22.97680473], [70.20597076, 22.97680473], [70.20597076, 22.97652817], [70.20623779, 22.97653008], [70.20623779, 22.9762516], [70.20680237, 22.9762516], [70.20680237, 22.97596931], [70.20708466, 22.97597122], [70.20708466, 22.97569466], [70.20819092, 22.97569466], [70.20819092, 22.97541618], [70.20868683, 22.97541618], [70.20931244, 22.97542191], [70.20931244, 22.97514153], [70.2104187, 22.97514153], [70.2104187, 22.9748497], [70.21069336, 22.97485924], [70.21069336, 22.97458267], [70.21125031, 22.97458267], [70.21125031, 22.97430611], [70.21153259, 22.97431183], [70.21153259, 22.97403145], [70.21180725, 22.97403145], [70.21180725, 22.97374916], [70.21237183, 22.97374916], [70.21237183, 22.97347069], [70.21263885, 22.9734726], [70.21263885, 22.97319412], [70.21291351, 22.97319412], [70.21291351, 22.97291756], [70.21347046, 22.97291756], [70.21347046, 22.97263908], [70.21375275, 22.97263908], [70.21375275, 22.97236061], [70.21430206, 22.97236061], [70.21430206, 22.97208023], [70.21458435, 22.97208405], [70.21458435, 22.97180557], [70.21485901, 22.97180748], [70.21485901, 22.97153091], [70.21540833, 22.97153091], [70.21540833, 22.97125053], [70.21569061, 22.97125053], [70.21569824, 22.97097015], [70.2159729, 22.97097206], [70.2159729, 22.97069359], [70.21652985, 22.97069359], [70.21652985, 22.97041512], [70.21679688, 22.97042084], [70.21679688, 22.97014046], [70.21736145, 22.97014046], [70.21736145, 22.96986008], [70.21763611, 22.96986198], [70.21763611, 22.96958351], [70.2179184, 22.96958351], [70.2179184, 22.96930695], [70.21846771, 22.96931076], [70.21846771, 22.96903038], [70.21875, 22.96903038], [70.21875, 22.96875], [70.21901703, 22.96875], [70.21901703, 22.96846962], [70.2195816, 22.96847153], [70.2195816, 22.96819687], [70.22013855, 22.96820068], [70.22013855, 22.9679203], [70.22070313, 22.9679203], [70.22070313, 22.96735954], [70.22097015, 22.96736145], [70.22097015, 22.96708488], [70.22125244, 22.96708488], [70.22125244, 22.96680641], [70.2215271, 22.96681023], [70.2215271, 22.96652985], [70.22180176, 22.96652985], [70.22180176, 22.96624947], [70.22207642, 22.96624947], [70.22207642, 22.96568108], [70.2223587, 22.96569443], [70.2223587, 22.96541405], [70.22264099, 22.96541977], [70.22264099, 22.96513939], [70.22292328, 22.96513939], [70.22291565, 22.96458054], [70.22319794, 22.96458054], [70.22319794, 22.96430588], [70.2234726, 22.96430969], [70.2234726, 22.96403122], [70.22374725, 22.96403122], [70.22374725, 22.96347046], [70.22402954, 22.96347046], [70.22402954, 22.96319389], [70.2243042, 22.96319389], [70.2243042, 22.96264076], [70.22460175, 22.96264267], [70.22460175, 22.96153069], [70.22486115, 22.96153069], [70.22486115, 22.96069908], [70.2251358, 22.96069908], [70.2251358, 22.96013832], [70.22486115, 22.96013832], [70.22486115, 22.95986938], [70.22431183, 22.95986938], [70.22431183, 22.95957947], [70.22402954, 22.95958328], [70.22402954, 22.95930481], [70.2234726, 22.95930481], [70.2234726, 22.95902824], [70.22319794, 22.95902824], [70.22319794, 22.95874977], [70.22264099, 22.95874977], [70.22264099, 22.95846939], [70.2223587, 22.9584713], [70.2223587, 22.95819473], [70.22180176, 22.95819473], [70.22180176, 22.95791626], [70.2215271, 22.95791817], [70.2215271, 22.95763969], [70.22097015, 22.95763969], [70.22097015, 22.95736122], [70.22041321, 22.95736122], [70.22041321, 22.95708084], [70.22013855, 22.95708275], [70.22013855, 22.95680618], [70.21985626, 22.95680809], [70.21985626, 22.95652962], [70.21932983, 22.95652962], [70.2193222, 22.95642853], [70.21930695, 22.95624924], [70.21875, 22.95625114], [70.21875, 22.95597076], [70.21763611, 22.95597267], [70.21763611, 22.9556942], [70.21708679, 22.9556942], [70.21708679, 22.95541763], [70.21624756, 22.95541954], [70.21624756, 22.95486069], [70.2159729, 22.95486069], [70.2159729, 22.95458031], [70.21457672, 22.95458031], [70.21457672, 22.95486069], [70.21430206, 22.95486069], [70.21430206, 22.95514107], [70.21375275, 22.95514107], [70.21375275, 22.95458031], [70.21347046, 22.95458412], [70.21347046, 22.95402718], [70.21290588, 22.95403099], [70.21290588, 22.95374107], [70.2123642, 22.95375061], [70.2123642, 22.9529171], [70.21153259, 22.95292091], [70.21153259, 22.95264053], [70.2104187, 22.95264053], [70.2104187, 22.95236015], [70.2095871, 22.95236206], [70.2095871, 22.95208359], [70.20874786, 22.95208359], [70.20874786, 22.95180321], [70.20707703, 22.95181084], [70.20707703, 22.95153046], [70.20569611, 22.95153046], [70.20569611, 22.95125008], [70.20549011, 22.95125008], [70.20402527, 22.95125008], [70.20402527, 22.95097351], [70.20236206, 22.95097351], [70.20236206, 22.95069504], [70.20097351, 22.95069504], [70.20097351, 22.95097351], [70.19875336, 22.95097351], [70.19875336, 22.95069504], [70.19819641, 22.95070076], [70.19819641, 22.95042038], [70.19790649, 22.95042038], [70.19790649, 22.95014191], [70.19708252, 22.95014191], [70.19708252, 22.95042038], [70.19737244, 22.95042038], [70.19737244, 22.95070076], [70.19708252, 22.95069504], [70.19708252, 22.95097351], [70.19680786, 22.9509697], [70.19680786, 22.95125008], [70.19625092, 22.95125008], [70.19625092, 22.9509697], [70.19541931, 22.95097351], [70.19541931, 22.95069504], [70.19458008, 22.95070076], [70.19458008, 22.95042038], [70.19486237, 22.95042038], [70.19486237, 22.95014191], [70.18985748, 22.95014191], [70.18985748, 22.95070076], [70.18958282, 22.95069504], [70.18958282, 22.95097351], [70.18902588, 22.95097351], [70.18902588, 22.95069504], [70.18708038, 22.95070076], [70.18708038, 22.95042038], [70.18264008, 22.95042038], [70.18264008, 22.95070076], [70.18126678, 22.95069504], [70.18069458, 22.95069504], [70.18069458, 22.95097351], [70.17736053, 22.9509697], [70.17736053, 22.95125008], [70.17624664, 22.95125008], [70.17624664, 22.95097351], [70.17569733, 22.95097351], [70.17569733, 22.95069504], [70.17542267, 22.95070076], [70.17542267, 22.95014191], [70.17457581, 22.95014191], [70.17457581, 22.95042038], [70.17375183, 22.95042038], [70.17375183, 22.95070076], [70.17346954, 22.95070076], [70.17346954, 22.95042038], [70.17292023, 22.95042038], [70.17292023, 22.95014191], [70.17263794, 22.95014191], [70.17263794, 22.94985962], [70.17236328, 22.94985962], [70.17236328, 22.94958115], [70.17208099, 22.94958115], [70.17208099, 22.94930649], [70.17180634, 22.9493103], [70.17180634, 22.94903183], [70.17124939, 22.94903183], [70.17124939, 22.94874954], [70.1709671, 22.94874954], [70.1709671, 22.94846916], [70.17069244, 22.94847107], [70.17069244, 22.9481945], [70.17041779, 22.9481945], [70.17041779, 22.94791603], [70.16902924, 22.94791603], [70.16902924, 22.9481945], [70.16874695, 22.9481945], [70.16874695, 22.94791603], [70.16819763, 22.94792938], [70.16819763, 22.94764137], [70.16791534, 22.94764137], [70.16791534, 22.94735909], [70.16764069, 22.94735909], [70.16764069, 22.94708061], [70.1673584, 22.94708252], [70.1673584, 22.94652748], [70.16706848, 22.94652748], [70.16706848, 22.94625092], [70.16680908, 22.94625092], [70.16680908, 22.94569016], [70.16652679, 22.94569397], [70.16652679, 22.9454174], [70.16625214, 22.94542122], [70.16625214, 22.94514084], [70.16596985, 22.94514084], [70.16596985, 22.94486809], [70.16570282, 22.94486809], [70.16570282, 22.94458008], [70.1654129, 22.94458389], [70.1654129, 22.94402885], [70.16513824, 22.94403076], [70.16513824, 22.94347], [70.16347504, 22.94347191], [70.16347504, 22.94319534], [70.16319275, 22.94320107], [70.16319275, 22.94292068], [70.16291809, 22.94292068], [70.16291809, 22.9426403], [70.16179657, 22.9426403], [70.16179657, 22.94292068], [70.16126251, 22.94292068], [70.16126251, 22.94320107], [70.16069794, 22.94319534], [70.16069794, 22.94347191], [70.16041565, 22.94347191], [70.16041565, 22.94458389], [70.15957642, 22.94458008], [70.15957642, 22.94486809], [70.1598587, 22.94486809], [70.1598587, 22.94514084], [70.15957642, 22.94514084], [70.15957642, 22.94542122], [70.1590271, 22.9454174], [70.1590271, 22.94569397], [70.15875244, 22.94569397], [70.15875244, 22.94597244], [70.15847015, 22.94597054], [70.15847015, 22.94625092], [70.15791321, 22.94625092], [70.15791321, 22.94597054], [70.15763855, 22.94597054], [70.15763855, 22.94625092], [70.15680695, 22.94625092], [70.15680695, 22.94652748], [70.15625, 22.94652748], [70.15625, 22.94681168], [70.15486145, 22.94680595], [70.15486145, 22.94708252], [70.1543045, 22.94708252], [70.1543045, 22.94680595], [70.15374756, 22.94680595], [70.15374756, 22.94708252], [70.1534729, 22.94708061], [70.1534729, 22.94735909], [70.15319824, 22.94735909], [70.15319824, 22.94764137], [70.15291595, 22.94764137], [70.15291595, 22.94792938], [70.1526413, 22.94791603], [70.1526413, 22.94847107], [70.15208435, 22.94847107], [70.15209198, 22.94874954], [70.1515274, 22.94874954], [70.1515274, 22.94903183], [70.15097046, 22.94903183], [70.15097046, 22.9493103], [70.1506958, 22.94930649], [70.1506958, 22.94958115], [70.15013885, 22.94958115], [70.15013885, 22.94985962], [70.14985657, 22.94985962], [70.14985657, 22.95014191], [70.14932251, 22.95014191], [70.14932251, 22.95042038], [70.14903259, 22.95042038], [70.14903259, 22.95070076], [70.1451416, 22.95069504], [70.1451416, 22.95097351], [70.14457703, 22.9509697], [70.14457703, 22.95125008], [70.14375305, 22.95125008], [70.14375305, 22.95153046], [70.14318848, 22.95153046], [70.14318848, 22.95181084], [70.14263916, 22.95180321], [70.14263916, 22.95208359], [70.14208221, 22.95208359], [70.14208221, 22.95236206], [70.1415329, 22.95236015], [70.1415329, 22.95264053], [70.14125061, 22.95264053], [70.14125061, 22.95292091], [70.14097595, 22.9529171], [70.14097595, 22.95319557], [70.14069366, 22.95319557], [70.14069366, 22.95347214], [70.14041901, 22.95347214], [70.14041901, 22.95375061], [70.14015198, 22.95374107], [70.14015198, 22.95403099], [70.13986206, 22.95403099], [70.13986206, 22.95430946], [70.13957977, 22.95430565], [70.13957977, 22.95458412], [70.13930511, 22.95458412], [70.13931274, 22.95486069], [70.13903046, 22.95486069], [70.13903046, 22.95514107], [70.13874817, 22.95514107], [70.13874817, 22.95541954], [70.13847351, 22.95541763], [70.13847351, 22.9556942], [70.13819122, 22.9556942], [70.13819122, 22.95597267], [70.13791656, 22.95597076], [70.13791656, 22.95625114], [70.13764191, 22.95625114], [70.13764191, 22.95652962], [70.13735962, 22.95652962], [70.13735962, 22.95680809], [70.13708496, 22.95680618], [70.13708496, 22.95708275], [70.13680267, 22.95708084], [70.13680267, 22.95736122], [70.13652802, 22.95736122], [70.13652802, 22.95763969], [70.13625336, 22.95763969], [70.13625336, 22.95791817], [70.13569641, 22.95791626], [70.13569641, 22.95819473], [70.13541412, 22.95819473], [70.13541412, 22.9584713], [70.13513947, 22.95846939], [70.13513947, 22.95874977], [70.13485718, 22.95874977], [70.13485718, 22.95902824], [70.13458252, 22.95902824], [70.13458252, 22.95930481], [70.13430786, 22.95930481], [70.13430786, 22.95958328], [70.13375092, 22.95957947], [70.13375092, 22.95986938], [70.13346863, 22.95986938], [70.13346863, 22.96013832], [70.13318634, 22.96013832], [70.13318634, 22.96042061], [70.13263702, 22.96042061], [70.13263702, 22.96069908], [70.13236237, 22.96069527], [70.13236237, 22.96097183], [70.13180542, 22.96097183], [70.13181305, 22.9612484], [70.13014221, 22.9612484], [70.13014221, 22.96153069], [70.12902832, 22.96153069], [70.12902832, 22.9612484], [70.12680817, 22.9612484], [70.12680817, 22.96096992], [70.12652588, 22.96097183], [70.12652588, 22.96069527], [70.12319183, 22.96069527], [70.12319183, 22.96097183], [70.12291718, 22.96096992], [70.12291718, 22.9612484], [70.12236023, 22.9612484], [70.12236023, 22.96153069], [70.12180328, 22.96153069], [70.12180328, 22.96181107], [70.12124634, 22.96181107], [70.12124634, 22.96236038], [70.12097168, 22.96236038], [70.12097168, 22.96291733], [70.12069702, 22.96291733], [70.12069702, 22.96347046], [70.1204071, 22.96347046], [70.1204071, 22.96403122], [70.12014008, 22.9640274], [70.12014008, 22.96458054], [70.11985779, 22.96458054], [70.11985779, 22.96569443], [70.12014008, 22.96569443], [70.12014008, 22.96736145], [70.12041473, 22.96736145], [70.12041473, 22.96847153], [70.12069702, 22.96846962], [70.12069702, 22.96903038], [70.12097168, 22.96902847], [70.12097168, 22.96958351], [70.12124634, 22.96958351], [70.12124634, 22.96982193], [70.12124634, 22.97014046], [70.12152863, 22.97013855], [70.12152863, 22.97069359], [70.12180328, 22.97068977], [70.12180328, 22.97125053], [70.1220932, 22.97125053], [70.1220932, 22.97180748], [70.12236023, 22.97180748], [70.12236023, 22.97236061], [70.12264252, 22.97236061], [70.12264252, 22.97263908], [70.12319183, 22.97263908], [70.12319183, 22.97291756], [70.12374878, 22.97291756], [70.12374878, 22.97319412], [70.12403107, 22.97319412], [70.12403107, 22.9734726], [70.12458038, 22.97347069], [70.12458038, 22.97374916], [70.12515259, 22.97374916], [70.12515259, 22.97403145], [70.12541962, 22.97403145], [70.12541962, 22.97431183], [70.12596893, 22.97430611], [70.12596893, 22.97458267], [70.12625122, 22.97458267], [70.12625122, 22.97485924], [70.12680817, 22.9748497], [70.12680817, 22.97514153], [70.12708282, 22.97514153], [70.12708282, 22.97542191], [70.12763977, 22.97541618], [70.12763977, 22.97569466], [70.12791443, 22.97569466], [70.12791443, 22.97597122], [70.12847137, 22.97596931], [70.12847137, 22.9762516], [70.1287384, 22.97627068], [70.12874603, 22.97653008], [70.12889862, 22.97652817], [70.12930298, 22.97652817], [70.12930298, 22.97680473], [70.12958527, 22.97680473], [70.12958527, 22.9770813], [70.12985992, 22.97707939], [70.12985992, 22.97764015], [70.13014221, 22.97763824], [70.13014221, 22.97791672], [70.13041687, 22.97791672], [70.13041687, 22.97847366], [70.13069153, 22.97846985], [70.13069153, 22.97903061], [70.13095856, 22.97903061], [70.13095856, 22.97931099], [70.13124847, 22.97931099], [70.13124847, 22.97986031], [70.13153076, 22.97986031], [70.13153076, 22.98075294], [70.13153076, 22.98125076], [70.13181305, 22.98125076], [70.13181305, 22.98291969], [70.13236237, 22.98291779], [70.13236237, 22.98319435], [70.13291931, 22.98319435], [70.13291931, 22.98347282], [70.13318634, 22.98347092], [70.13318634, 22.98404121], [70.13346863, 22.98404121], [70.13346863, 22.98431015], [70.13375092, 22.98430634], [70.13375092, 22.98486137], [70.13402557, 22.98486137], [70.13402557, 22.98569489], [70.13319397, 22.98569489], [70.13319397, 22.98597145], [70.13263702, 22.98596954], [70.13263702, 22.98624992], [70.13208008, 22.98624992], [70.13208008, 22.9865284], [70.13153076, 22.9865284], [70.13153076, 22.98681068], [70.13097382, 22.98680496], [70.13097382, 22.98708344], [70.13041687, 22.98708344], [70.13041687, 22.98736191], [70.12985992, 22.98735809], [70.12985992, 22.98792076], [70.12958527, 22.98791695], [70.1295929, 22.9881897], [70.12930298, 22.98819923], [70.12930298, 22.98875237], [70.12902832, 22.98875237], [70.12902832, 22.98931122], [70.12874603, 22.98931122], [70.12874603, 22.99041939], [70.12902832, 22.99041748], [70.12902832, 22.9920845], [70.12930298, 22.99208069], [70.12930298, 22.99263954], [70.12958527, 22.99263954], [70.12958527, 22.99319458], [70.12985992, 22.99319077], [70.12985992, 22.99374962], [70.13014221, 22.99374962], [70.13014221, 22.99430466], [70.13041687, 22.99430466], [70.13041687, 22.9948616], [70.13069153, 22.9948597], [70.13069153, 22.99542046], [70.13095856, 22.99542046], [70.13095856, 22.99598122], [70.13124847, 22.99598122], [70.13124847, 22.99625015], [70.13153076, 22.99625015], [70.13153076, 22.99681091], [70.13180542, 22.99680519], [70.13180542, 22.99736023], [70.13208008, 22.99736023], [70.13208008, 22.99792099], [70.13236237, 22.99791718], [70.13236237, 22.99847221], [70.13263702, 22.99847031], [70.13263702, 22.99875069], [70.13291931, 22.99875069], [70.13291931, 22.9990406], [70.13319397, 22.99902725], [70.13319397, 22.9995842], [70.13291931, 22.9995842], [70.13291931, 22.99995041], [70.13291931, 23.00013924], [70.13318634, 23.00013924], [70.13318634, 23.00042152], [70.13375092, 23.0004158], [70.13375092, 23.00069427], [70.13402557, 23.00069427], [70.13402557, 23.00097275], [70.13430786, 23.00097084], [70.13430786, 23.00124931], [70.13485718, 23.00124931], [70.13485718, 23.0015316], [70.13513947, 23.0015316], [70.13513947, 23.00181007], [70.13541412, 23.00180626], [70.13541412, 23.00208282], [70.13569641, 23.00208282], [70.13569641, 23.00235939], [70.13597107, 23.00235939], [70.13597107, 23.00264168], [70.13625336, 23.00264168], [70.13625336, 23.00292015], [70.13652802, 23.00291634], [70.13652802, 23.00319481], [70.13680267, 23.00319481], [70.13680267, 23.00347137], [70.13735962, 23.00346947], [70.13735962, 23.00375175], [70.13764191, 23.00375175], [70.13764191, 23.00403023], [70.13791656, 23.00402832], [70.13791656, 23.00430489], [70.13819122, 23.00430489], [70.13819122, 23.00458145], [70.13847351, 23.00458145], [70.13847351, 23.00486374], [70.13874817, 23.00485992], [70.13874817, 23.0051403], [70.13903046, 23.0051403], [70.13903046, 23.00542068], [70.13931274, 23.00542068], [70.13931274, 23.00570107], [70.13957977, 23.00569534], [70.13957977, 23.00597382], [70.14013672, 23.00597382], [70.14013672, 23.00625038], [70.14041901, 23.00625038], [70.14041901, 23.00653076], [70.14068604, 23.00653076], [70.14068604, 23.00681114], [70.14097595, 23.00680542], [70.14097595, 23.0070858], [70.14152527, 23.0070858], [70.14152527, 23.00736046], [70.14180756, 23.00736046], [70.14180756, 23.00764084], [70.14208221, 23.00764084], [70.14208221, 23.00792122], [70.1423645, 23.0079174], [70.1423645, 23.00819588], [70.14263916, 23.00819588], [70.14263916, 23.00847244], [70.14289856, 23.00847054], [70.14289856, 23.00875092], [70.14318848, 23.00875092], [70.14318848, 23.00902939], [70.14347076, 23.00902939], [70.14347076, 23.01013947], [70.14375305, 23.01013947], [70.14375305, 23.01180077], [70.14402771, 23.0118103], [70.14402771, 23.01320076], [70.14430237, 23.01320076], [70.14430237, 23.01374817], [70.14457703, 23.01374817], [70.14457703, 23.01431084], [70.14485931, 23.01431084], [70.14485931, 23.01485825], [70.1451416, 23.01485825], [70.1451416, 23.01542282], [70.14541626, 23.0154171], [70.14541626, 23.01597023], [70.14569092, 23.01597023], [70.14569092, 23.0165329], [70.14597321, 23.01652718], [70.14597321, 23.01708221], [70.14653015, 23.01708031], [70.14653015, 23.01736259], [70.14679718, 23.01736259], [70.14679718, 23.01764107], [70.1470871, 23.01764107], [70.1470871, 23.01791954], [70.14736176, 23.01791573], [70.14736176, 23.01819229], [70.14763641, 23.01819229], [70.14763641, 23.01847458], [70.1479187, 23.01847076], [70.1479187, 23.01875114], [70.14819336, 23.01875114], [70.14819336, 23.01902962], [70.14848328, 23.01902962], [70.14848328, 23.01931], [70.14875031, 23.01930618], [70.14875031, 23.01958466], [70.14902496, 23.01958466], [70.14902496, 23.01986122], [70.14932251, 23.01986122], [70.14932251, 23.02015114], [70.14958191, 23.02015114], [70.14958191, 23.02042007], [70.1498642, 23.02041626], [70.1498642, 23.02069473], [70.15013885, 23.02069473], [70.15013885, 23.0209713], [70.15040588, 23.02096939], [70.15040588, 23.02124977], [70.1506958, 23.02124977], [70.1506958, 23.02153015], [70.15097046, 23.02152824], [70.15097046, 23.02180672], [70.15125275, 23.02180672], [70.15125275, 23.02236176], [70.1515274, 23.02235985], [70.1515274, 23.02292061], [70.15180206, 23.02292061], [70.15180206, 23.02321053], [70.15235901, 23.02319527], [70.15235901, 23.02347183], [70.1526413, 23.02346992], [70.1526413, 23.02431107], [70.15291595, 23.02431107], [70.15291595, 23.02514076], [70.15319824, 23.02514076], [70.15319824, 23.02625084], [70.1534729, 23.02625084], [70.1534729, 23.02708244], [70.15374756, 23.02708244], [70.15374756, 23.02819443], [70.15402985, 23.02819061], [70.15402985, 23.02931023], [70.15374756, 23.02930641], [70.15374756, 23.02958107], [70.15319824, 23.02958107], [70.15319824, 23.02930641], [70.15319061, 23.0290184], [70.15291595, 23.02902794], [70.15291595, 23.0284729], [70.1526413, 23.0284729], [70.1526413, 23.02791595], [70.15235901, 23.02792168], [70.15235901, 23.02708054], [70.15208435, 23.02708244], [70.15208435, 23.02597237], [70.15180206, 23.02597237], [70.15180206, 23.02513885], [70.1515274, 23.02514076], [70.1515274, 23.02458], [70.15041351, 23.02458382], [70.15041351, 23.02430534], [70.15013885, 23.02431107], [70.15013885, 23.02403069], [70.14985657, 23.02403069], [70.14985657, 23.02375031], [70.14930725, 23.02375031], [70.14930725, 23.02347183], [70.14902496, 23.02347183], [70.14902496, 23.02319527], [70.14875031, 23.02321053], [70.14875031, 23.02292061], [70.14848328, 23.02292061], [70.14848328, 23.02264023], [70.1479187, 23.02264023], [70.1479187, 23.02235985], [70.14763641, 23.02236176], [70.14763641, 23.02208328], [70.14736176, 23.02208328], [70.14736176, 23.02180672], [70.1470871, 23.02180672], [70.1470871, 23.02152824], [70.14653015, 23.02153015], [70.14653015, 23.02124977], [70.14624786, 23.02124977], [70.14624786, 23.02096939], [70.14597321, 23.0209713], [70.14597321, 23.02069473], [70.14569092, 23.02069473], [70.14569092, 23.02013969], [70.14541626, 23.02015114], [70.14541626, 23.01986122], [70.1451416, 23.01986122], [70.1451416, 23.01958084], [70.14485931, 23.01958466], [70.14485931, 23.01930618], [70.14457703, 23.01931], [70.14457703, 23.01902962], [70.14430237, 23.01902962], [70.14430237, 23.01847076], [70.14402771, 23.01847458], [70.14402771, 23.01819229], [70.14375305, 23.01819229], [70.14375305, 23.01791763], [70.14347076, 23.01791954], [70.14347076, 23.01736259], [70.14318848, 23.01736259], [70.14318848, 23.01680946], [70.14289856, 23.01680946], [70.14289856, 23.01625252], [70.14263916, 23.01625252], [70.14263916, 23.01542282], [70.14235687, 23.01542282], [70.14235687, 23.01485825], [70.14208221, 23.01486015], [70.14208221, 23.01430511], [70.14180756, 23.01431084], [70.14180756, 23.0134697], [70.14152527, 23.0134716], [70.14152527, 23.01263809], [70.14125061, 23.01263809], [70.14125061, 23.0118103], [70.14097595, 23.0118103], [70.14097595, 23.01098061], [70.14068604, 23.01098061], [70.14068604, 23.01013947], [70.14041901, 23.01013947], [70.14041901, 23.00930977], [70.14015198, 23.00930977], [70.14015198, 23.00875092], [70.13986206, 23.00875092], [70.13986206, 23.00847054], [70.13930511, 23.00847244], [70.13930511, 23.00819588], [70.13903046, 23.00819588], [70.13903046, 23.0079174], [70.13846588, 23.00792122], [70.13846588, 23.00764084], [70.13819122, 23.00764084], [70.13819122, 23.00736046], [70.13791656, 23.00736046], [70.13791656, 23.00708008], [70.13764191, 23.0070858], [70.13764191, 23.00680542], [70.13709259, 23.00681114], [70.13709259, 23.00653076], [70.13680267, 23.00653076], [70.13680267, 23.00625038], [70.13652802, 23.00625038], [70.13652802, 23.00597], [70.13625336, 23.00597382], [70.13625336, 23.00569534], [70.13597107, 23.00570107], [70.13597107, 23.00542068], [70.13540649, 23.00542068], [70.13540649, 23.0051403], [70.13485718, 23.0051403], [70.13485718, 23.00485992], [70.13402557, 23.00486374], [70.13402557, 23.00458145], [70.13375092, 23.00458145], [70.13375092, 23.00430489], [70.13346863, 23.00430489], [70.13346863, 23.00402832], [70.13318634, 23.00403023], [70.13318634, 23.00375175], [70.13263702, 23.00375175], [70.13263702, 23.00346947], [70.13208008, 23.00347137], [70.13208008, 23.00319481], [70.13180542, 23.00319481], [70.13180542, 23.00291634], [70.13153076, 23.00292015], [70.13153076, 23.00235939], [70.13124847, 23.00235939], [70.13124847, 23.00208282], [70.13097382, 23.00208282], [70.13097382, 23.00180626], [70.13069153, 23.00181007], [70.13069153, 23.00124931], [70.13041687, 23.00124931], [70.13041687, 23.00097084], [70.13014221, 23.00097275], [70.13014221, 23.00069427], [70.12985992, 23.00069427], [70.12985992, 23.00013733], [70.1295929, 23.00013924], [70.1295929, 22.99986076], [70.12958527, 22.99930573], [70.12930298, 22.99930954], [70.12930298, 22.99875069], [70.12902832, 22.99875069], [70.12902832, 22.99847031], [70.12875366, 22.99847221], [70.12875366, 22.99791718], [70.12847137, 22.99792099], [70.12847137, 22.99707985], [70.12819672, 22.99708366], [70.12819672, 22.99652863], [70.12789917, 22.99653053], [70.12789917, 22.99625015], [70.12763977, 22.99625015], [70.12763977, 22.99570084], [70.12735748, 22.99570084], [70.12735748, 22.99542046], [70.12708282, 22.99542046], [70.12708282, 22.99514008], [70.12680817, 22.99514008], [70.12680817, 22.9948597], [70.12652588, 22.9948616], [70.12652588, 22.99430466], [70.12625122, 22.99430466], [70.12625122, 22.99402809], [70.12596893, 22.99403], [70.12596893, 22.99374962], [70.12568665, 22.99374962], [70.12568665, 22.99319077], [70.12541962, 22.99319458], [70.12541962, 22.9920845], [70.12513733, 22.9920845], [70.12513733, 22.99152756], [70.12486267, 22.99152946], [70.12486267, 22.99014282], [70.12458038, 22.99014282], [70.12458038, 22.98735809], [70.12430573, 22.98736191], [70.12430573, 22.98624992], [70.12403107, 22.98624992], [70.12403107, 22.98513985], [70.12374878, 22.98513985], [70.12374878, 22.98374939], [70.12346649, 22.98374939], [70.12346649, 22.98264122], [70.12319183, 22.98264122], [70.12319183, 22.98208046], [70.12236023, 22.98208427], [70.12236023, 22.9818058], [70.12097168, 22.98180962], [70.12097168, 22.98097992], [70.12069702, 22.98097992], [70.12069702, 22.98042107], [70.1204071, 22.98042107], [70.1204071, 22.98014069], [70.12014008, 22.98014069], [70.12014008, 22.97957993], [70.11985779, 22.97958565], [70.11985779, 22.97930527], [70.11958313, 22.97931099], [70.11958313, 22.97903061], [70.11930847, 22.97903061], [70.11930847, 22.97875023], [70.11901855, 22.97875023], [70.11901855, 22.97846985], [70.11875153, 22.97847366], [70.11875153, 22.97791672], [70.11846924, 22.97791672], [70.11846924, 22.97763824], [70.11818695, 22.97764015], [70.11818695, 22.97735977], [70.11791992, 22.97736359], [70.11791992, 22.9770813], [70.11736298, 22.9770813], [70.11736298, 22.97680473], [70.11708069, 22.97680473], [70.11708069, 22.97652817], [70.11653137, 22.97653008], [70.11653137, 22.9762516], [70.11624908, 22.9762516], [70.11624908, 22.97596931], [70.11569214, 22.97597122], [70.11569214, 22.97569466], [70.11541748, 22.97569466], [70.11541748, 22.97541618], [70.11486053, 22.97542191], [70.11486053, 22.97514153], [70.11458588, 22.97514153], [70.11458588, 22.9748497], [70.11430359, 22.97485924], [70.11430359, 22.97458267], [70.11402893, 22.97458267], [70.11402893, 22.97430611], [70.11374664, 22.97431183], [70.11374664, 22.97403145], [70.11321259, 22.97403145], [70.11321259, 22.97374916], [70.11292267, 22.97374916], [70.11292267, 22.97347069], [70.11264038, 22.9734726], [70.11264038, 22.97263718], [70.11235809, 22.97263908], [70.11235809, 22.97153091], [70.11207581, 22.97153091], [70.11207581, 22.97014046], [70.11180878, 22.97014046], [70.11180878, 22.96875], [70.11152649, 22.96875], [70.11152649, 22.96805954], [70.11152649, 22.96763802], [70.11125183, 22.96763992], [70.11125183, 22.96624947], [70.11096954, 22.96624947], [70.11096954, 22.96486282], [70.11068726, 22.96486282], [70.11068726, 22.96347046], [70.11042023, 22.96347046], [70.11042023, 22.96208382], [70.11069489, 22.96208382], [70.11069489, 22.96097183], [70.11096954, 22.96097183], [70.11096954, 22.96013832], [70.11125183, 22.96013832], [70.11125183, 22.95986938], [70.11152649, 22.95986938], [70.11152649, 22.95930099], [70.11180878, 22.95930481], [70.11180878, 22.95902824], [70.11207581, 22.95902824], [70.11207581, 22.95874977], [70.11235809, 22.95874977], [70.11235809, 22.95819092], [70.11264038, 22.95819473], [70.11264038, 22.95791626], [70.11292267, 22.95791817], [70.11292267, 22.95763969], [70.11347198, 22.95763969], [70.11347198, 22.95736122], [70.11374664, 22.95736122], [70.11374664, 22.95708084], [70.11430359, 22.95708275], [70.11430359, 22.95680618], [70.11486053, 22.95680809], [70.11486053, 22.95652962], [70.11514282, 22.95652962], [70.11514282, 22.95625114], [70.11569214, 22.95625114], [70.11569214, 22.95597076], [70.11624908, 22.95597267], [70.11624908, 22.9556942], [70.11653137, 22.9556942], [70.11653137, 22.95541573], [70.11708069, 22.95541954], [70.11708069, 22.95514107], [70.11736298, 22.95514107], [70.11736298, 22.95486069], [70.11763763, 22.95486069], [70.11763763, 22.95458031], [70.11819458, 22.95458412], [70.11819458, 22.95430565], [70.11846924, 22.95430946], [70.11846924, 22.95403099], [70.11875153, 22.95403099], [70.11875153, 22.95374107], [70.11902618, 22.95375061], [70.11902618, 22.95347214], [70.11930847, 22.95347214], [70.11930847, 22.95319557], [70.11985779, 22.95319557], [70.11985779, 22.9529171], [70.12014008, 22.95292091], [70.12014008, 22.95264053], [70.1204071, 22.95264053], [70.1204071, 22.95236015], [70.12097168, 22.95236015], [70.12097168, 22.95207977], [70.12124634, 22.95208359], [70.12124634, 22.95180321], [70.12180328, 22.95181084], [70.12180328, 22.95153046], [70.12236023, 22.95153046], [70.12236023, 22.95125008], [70.12264252, 22.95125008], [70.12264252, 22.9509697], [70.12319183, 22.95097351], [70.12319183, 22.95069504], [70.12374878, 22.95070076], [70.12374878, 22.95042038], [70.12403107, 22.95042038], [70.12403107, 22.95014191], [70.12458038, 22.95014191], [70.12458038, 22.94985962], [70.12513733, 22.94985962], [70.12513733, 22.94958115], [70.12569427, 22.94958115], [70.12569427, 22.94930649], [70.12625122, 22.94930077], [70.12625122, 22.94680595], [70.12652588, 22.94681168], [70.12652588, 22.94652748], [70.12431335, 22.94652748], [70.12431335, 22.94681168], [70.12319183, 22.94680595], [70.12319183, 22.94708252], [70.12180328, 22.94708061], [70.12180328, 22.94735909], [70.12124634, 22.94735909], [70.12124634, 22.94764137], [70.12097168, 22.94764137], [70.12097168, 22.94792938], [70.12041473, 22.94791603], [70.12041473, 22.9481945], [70.11985779, 22.9481945], [70.11985779, 22.94847107], [70.11958313, 22.94846916], [70.11958313, 22.94874954], [70.11901855, 22.94874954], [70.11901855, 22.94903183], [70.11875153, 22.94903183], [70.11875153, 22.9493103], [70.11819458, 22.94930649], [70.11819458, 22.94958115], [70.11763763, 22.94958115], [70.11763763, 22.94985962], [70.11736298, 22.94985962], [70.11736298, 22.95014191], [70.11680603, 22.95014191], [70.11680603, 22.95042038], [70.11653137, 22.95042038], [70.11653137, 22.95070076], [70.11597443, 22.95069504], [70.11597443, 22.95097351], [70.11569214, 22.9509697], [70.11569214, 22.95125008], [70.11514282, 22.95125008], [70.11514282, 22.95153046], [70.11458588, 22.95153046], [70.11458588, 22.95181084], [70.11402893, 22.95180321], [70.11402893, 22.95208359], [70.11347198, 22.95208359], [70.11347198, 22.95236206], [70.11292267, 22.95236015], [70.11292267, 22.95264053], [70.11096954, 22.95264053], [70.11096954, 22.95236015], [70.10958099, 22.95236206], [70.10958099, 22.95208359], [70.10930634, 22.95208359], [70.10930634, 22.95180321], [70.10901642, 22.95181084], [70.10901642, 22.95153046], [70.10874939, 22.95153046], [70.10874939, 22.95125008], [70.10819244, 22.95125008], [70.10819244, 22.9509697], [70.10791779, 22.95097351], [70.10791779, 22.95069504], [70.10764313, 22.95070076], [70.10764313, 22.95042038], [70.10736084, 22.95042038], [70.10736084, 22.94985962], [70.10708618, 22.94985962], [70.10708618, 22.94902992], [70.10678864, 22.94903183], [70.10678864, 22.94819069], [70.10652924, 22.9481945], [70.10652924, 22.94764137], [70.10624695, 22.94764137], [70.10624695, 22.94708061], [70.10597229, 22.94708252], [70.10597229, 22.94625092], [70.10569763, 22.94625092], [70.10569763, 22.94569016], [70.10541534, 22.94569397], [70.10541534, 22.94513893], [70.10514069, 22.94514084], [70.10514069, 22.94458008], [70.1048584, 22.94458389], [70.1048584, 22.94375038], [70.10457611, 22.94375038], [70.10457611, 22.94320107], [70.10430908, 22.94320107], [70.10430908, 22.9426403], [70.10401917, 22.9426403], [70.10401917, 22.94207954], [70.10375214, 22.94208336], [70.10375214, 22.94180679], [70.10124969, 22.94180679], [70.10124969, 22.94208336], [70.09986115, 22.94208336], [70.09986115, 22.94236183], [70.09819794, 22.94235992], [70.09819794, 22.9426403], [70.09764099, 22.9426403], [70.09764099, 22.94292068], [70.0973587, 22.94292068], [70.0973587, 22.94375038], [70.09707642, 22.94375038], [70.09707642, 22.94542122], [70.09680939, 22.9454174], [70.09680176, 22.94708252], [70.0965271, 22.94708252], [70.0965271, 22.9481945], [70.09625244, 22.94819069], [70.09625244, 22.94874954], [70.09597015, 22.94874954], [70.09597015, 22.9493103], [70.0956955, 22.94930649], [70.0956955, 22.94958115], [70.09541321, 22.94957924], [70.09541321, 22.95014191], [70.09570312, 22.95014191], [70.09570312, 22.95042038], [70.09541321, 22.95041656], [70.09541321, 22.95097351], [70.09513855, 22.9509697], [70.09513855, 22.95125008], [70.0945816, 22.95125008], [70.0945816, 22.95153046], [70.09430695, 22.95153046], [70.09430695, 22.95181084], [70.09347534, 22.95180321], [70.09347534, 22.95208359], [70.09263611, 22.95208359], [70.09263611, 22.95236206], [70.09178925, 22.95236015], [70.09178925, 22.95264053], [70.0909729, 22.95264053], [70.0909729, 22.95207977], [70.09124756, 22.95208359], [70.09124756, 22.95180321], [70.09178925, 22.95181084], [70.09178925, 22.95153046], [70.09236145, 22.95153046], [70.09236145, 22.95125008], [70.09348297, 22.95125008], [70.09347534, 22.95097351], [70.09375, 22.95097351], [70.09375, 22.95041656], [70.09401703, 22.95042038], [70.09401703, 22.94903183], [70.09430695, 22.94903183], [70.09430695, 22.94652748], [70.0945816, 22.94652748], [70.0945816, 22.94542122], [70.09484863, 22.94542122], [70.09484863, 22.94514084], [70.09513855, 22.94514084], [70.09513855, 22.94486809], [70.09541321, 22.94486809], [70.09541321, 22.94431114], [70.09570312, 22.94431114], [70.09570312, 22.94403076], [70.09597015, 22.94403076], [70.09597015, 22.94375038], [70.09625244, 22.94375038], [70.09625244, 22.94347], [70.0965271, 22.94347191], [70.0965271, 22.94291687], [70.09680176, 22.94292068], [70.09680176, 22.9426403], [70.09707642, 22.9426403], [70.09707642, 22.94235992], [70.0973587, 22.94236183], [70.0973587, 22.94180679], [70.09764099, 22.94180679], [70.09764099, 22.94152832], [70.09792328, 22.94153023], [70.09792328, 22.94096947], [70.09819794, 22.94097137], [70.09819794, 22.94041634], [70.0984726, 22.94042015], [70.0984726, 22.94013977], [70.09874725, 22.94013977], [70.09874725, 22.93958092], [70.09902954, 22.93958473], [70.09902954, 22.93930626], [70.09929657, 22.93931007], [70.09929657, 22.93902969], [70.09958649, 22.93902969], [70.09958649, 22.93847275], [70.09986115, 22.93847466], [70.09986115, 22.93819237], [70.10097504, 22.93819237], [70.10097504, 22.93847466], [70.10180664, 22.93847466], [70.10180664, 22.93874931], [70.10235596, 22.93873978], [70.10235596, 22.93902969], [70.10263824, 22.93902969], [70.10263824, 22.93931007], [70.10319519, 22.93930626], [70.10319519, 22.93958473], [70.10346985, 22.93958473], [70.10346985, 22.9398613], [70.10375214, 22.93985939], [70.10375214, 22.94013977], [70.10401917, 22.94013977], [70.10401917, 22.94042015], [70.10458374, 22.94041634], [70.10458374, 22.94069481], [70.1048584, 22.94069481], [70.1048584, 22.94097137], [70.10514069, 22.94096947], [70.10514069, 22.94124985], [70.10541534, 22.94124985], [70.10541534, 22.94180679], [70.10569763, 22.94180679], [70.10569763, 22.94208336], [70.10597229, 22.94208336], [70.10597229, 22.94236183], [70.10624695, 22.94235992], [70.10624695, 22.9426403], [70.10652924, 22.9426403], [70.10652924, 22.94320107], [70.10680389, 22.94319534], [70.10680389, 22.94347191], [70.10707855, 22.94347], [70.10707855, 22.94375038], [70.10736084, 22.94375038], [70.10736084, 22.94431114], [70.1076355, 22.94430542], [70.1076355, 22.94458389], [70.10791779, 22.94458008], [70.10791779, 22.94486809], [70.10819244, 22.94486809], [70.10819244, 22.94542122], [70.10847473, 22.9454174], [70.10847473, 22.94569397], [70.10874939, 22.94569397], [70.10874939, 22.94597244], [70.10901642, 22.94597054], [70.10901642, 22.94652748], [70.10930634, 22.94652748], [70.10930634, 22.94681168], [70.10958099, 22.94681168], [70.10958099, 22.94735909], [70.10986328, 22.94735909], [70.10986328, 22.94764137], [70.11013794, 22.94764137], [70.11013794, 22.94792938], [70.11042023, 22.94791603], [70.11042023, 22.94847107], [70.11068726, 22.94846916], [70.11068726, 22.94874954], [70.11096954, 22.94874954], [70.11096954, 22.94930077], [70.11125183, 22.94930649], [70.11125183, 22.94958115], [70.11264038, 22.94958115], [70.11264038, 22.94930649], [70.11321259, 22.94930077], [70.11319733, 22.94902992], [70.11347198, 22.94903183], [70.11347198, 22.94874954], [70.11402893, 22.94874954], [70.11402893, 22.94846916], [70.11430359, 22.94847107], [70.11430359, 22.9481945], [70.11458588, 22.9481945], [70.11458588, 22.94791603], [70.11486053, 22.94792938], [70.11486053, 22.94764137], [70.11541748, 22.94764137], [70.11541748, 22.94735909], [70.11569214, 22.94735909], [70.11569214, 22.94708061], [70.11597443, 22.94708252], [70.11597443, 22.94680595], [70.11653137, 22.94681168], [70.11653137, 22.94652748], [70.11680603, 22.94652748], [70.11680603, 22.94625092], [70.11736298, 22.94625092], [70.11736298, 22.94597054], [70.11791992, 22.94597244], [70.11791992, 22.94569397], [70.11819458, 22.94569397], [70.11819458, 22.9454174], [70.11875153, 22.94542122], [70.11875153, 22.94514084], [70.11985779, 22.94514084], [70.11985779, 22.94486809], [70.12124634, 22.94486809], [70.12124634, 22.94458008], [70.12236023, 22.94458389], [70.12236023, 22.94430542], [70.12403107, 22.94431114], [70.12403107, 22.94403076], [70.12596893, 22.94403076], [70.12596893, 22.94375038], [70.13153076, 22.94375038], [70.13153076, 22.94347], [70.13458252, 22.94347191], [70.13458252, 22.94319534], [70.13513947, 22.94320107], [70.13513947, 22.94292068], [70.13569641, 22.94292068], [70.13569641, 22.9426403], [70.13625336, 22.9426403], [70.13625336, 22.94235992], [70.13680267, 22.94236183], [70.13680267, 22.94208336], [70.13735962, 22.94208336], [70.13735962, 22.94180679], [70.13764191, 22.94180679], [70.13764191, 22.94152832], [70.13819122, 22.94153023], [70.13819122, 22.94124985], [70.13903046, 22.94124985], [70.13903046, 22.94069099], [70.13930511, 22.94069481], [70.13930511, 22.93763924], [70.13903046, 22.93764114], [70.13903046, 22.93320084], [70.13874817, 22.93320084], [70.13874817, 22.9323597], [70.13847351, 22.9323616], [70.13847351, 22.93180466], [70.13819122, 22.93180466], [70.13819122, 22.93124962], [70.13791656, 22.93124962], [70.13791656, 22.93097115], [70.13764191, 22.93097305], [70.13764191, 22.93069458], [70.13735962, 22.93069458], [70.13735962, 22.93013954], [70.13708496, 22.93013954], [70.13708496, 22.9295826], [70.13680267, 22.9295826], [70.13680267, 22.92930794], [70.13652802, 22.92930984], [70.13652802, 22.92902946], [70.13625336, 22.92902946], [70.13625336, 22.92875099], [70.13597107, 22.92875099], [70.13597107, 22.92819023], [70.13569641, 22.92819595], [70.13569641, 22.92763901], [70.13540649, 22.92764091], [70.13540649, 22.92736053], [70.13485718, 22.92736053], [70.13485718, 22.92708015], [70.13458252, 22.92708588], [70.13458252, 22.9268055], [70.13402557, 22.9268055], [70.13402557, 22.92652702], [70.13375092, 22.92653084], [70.13375092, 22.92625046], [70.13346863, 22.92625046], [70.13346863, 22.92597008], [70.13319397, 22.92597389], [70.13319397, 22.92569542], [70.13291931, 22.9256897], [70.13291931, 22.92541695], [70.13263702, 22.92542076], [70.13263702, 22.92514038], [70.13236237, 22.92514038], [70.13236237, 22.92486191], [70.13208008, 22.92486382], [70.13208008, 22.92458153], [70.13153076, 22.92458153], [70.13153076, 22.92430305], [70.13095856, 22.92431068], [70.13095856, 22.9240303], [70.13014221, 22.9240303], [70.13014221, 22.92375946], [70.1295929, 22.92375946], [70.1295929, 22.92346954], [70.12902832, 22.92347336], [70.12902832, 22.92319489], [70.12847137, 22.92319489], [70.12847137, 22.92291641], [70.12789917, 22.92292023], [70.12789917, 22.92264175], [70.12735748, 22.92264175], [70.12735748, 22.92235947], [70.12680817, 22.92235947], [70.12680817, 22.9220829], [70.12596893, 22.9220829], [70.12596893, 22.92180634], [70.12541962, 22.92181015], [70.12541962, 22.92153168], [70.12486267, 22.92153168], [70.12486267, 22.92124939], [70.12430573, 22.92124939], [70.12430573, 22.92097282], [70.12319183, 22.92097282], [70.12319183, 22.92069435], [70.12264252, 22.92070007], [70.12264252, 22.9204216], [70.1220932, 22.9204216], [70.1220932, 22.92013931], [70.12180328, 22.92013931], [70.12180328, 22.91958046], [70.12152863, 22.91958427], [70.12152863, 22.9193058], [70.12124634, 22.91930962], [70.12124634, 22.91903114], [70.12097168, 22.91903114], [70.12097168, 22.91847038], [70.12069702, 22.91847229], [70.12069702, 22.91819382], [70.12041473, 22.91819382], [70.12041473, 22.91791725], [70.12014008, 22.91792107], [70.12014008, 22.91763115], [70.11985779, 22.91763878], [70.11985779, 22.91736031], [70.11958313, 22.91736031], [70.11958313, 22.91707993], [70.11819458, 22.91708374], [70.11819458, 22.91680527], [70.11791992, 22.91681099], [70.11791992, 22.91653061], [70.11763763, 22.91653061], [70.11763763, 22.91625023], [70.11736298, 22.91625023], [70.11736298, 22.91596985], [70.11708069, 22.91597176], [70.11708069, 22.91569519], [70.11680603, 22.91570091], [70.11680603, 22.91557121], [70.11680603, 22.91541672], [70.11624908, 22.91542053], [70.11624908, 22.91514015], [70.11595917, 22.91514015], [70.11595917, 22.91485977], [70.11458588, 22.91486168], [70.11458588, 22.91430473], [70.11430359, 22.91430473], [70.11430359, 22.91402817], [70.11374664, 22.91403008], [70.11374664, 22.91374969], [70.11291504, 22.91374969], [70.11291504, 22.91319466], [70.11264038, 22.91319466], [70.11264038, 22.91263962], [70.11207581, 22.91263962], [70.11207581, 22.91236115], [70.11152649, 22.91236115], [70.11152649, 22.91208076], [70.11096954, 22.91208458], [70.11096954, 22.91180611], [70.11068726, 22.91181946], [70.11068726, 22.91152954], [70.11013794, 22.91152954], [70.11013794, 22.91125107], [70.10958099, 22.91125107], [70.10958099, 22.91097069], [70.10902405, 22.91097069], [70.10902405, 22.91069221], [70.10847473, 22.91069221], [70.10847473, 22.91041756], [70.10819244, 22.91041946], [70.10819244, 22.9101429], [70.10764313, 22.9101429], [70.10764313, 22.90986252], [70.10707855, 22.90986252], [70.10707855, 22.90958023], [70.10652924, 22.90958405], [70.10652924, 22.90930557], [70.10597229, 22.90930939], [70.10597229, 22.90903282], [70.10457611, 22.90903282], [70.10457611, 22.90876007], [70.10346985, 22.90876007], [70.10346985, 22.90847015], [70.1020813, 22.90847015], [70.1020813, 22.90819359], [70.1001358, 22.90819359], [70.1001358, 22.90791702], [70.09792328, 22.90792084], [70.09792328, 22.90763855], [70.08875275, 22.90763855], [70.08875275, 22.90792084], [70.08708191, 22.90791702], [70.08708191, 22.90819359], [70.0854187, 22.90819359], [70.0854187, 22.90847015], [70.08429718, 22.90847015], [70.08429718, 22.90876007], [70.08403015, 22.90876007], [70.08403015, 22.90903282], [70.0826416, 22.90903282], [70.0826416, 22.90876007], [70.08180237, 22.90876007], [70.08180237, 22.90818977], [70.08208466, 22.90819359], [70.08208466, 22.90763855], [70.08235931, 22.90763855], [70.08235931, 22.90735817], [70.0826416, 22.90736008], [70.0826416, 22.90708351], [70.08291626, 22.90708351], [70.08291626, 22.90680504], [70.0826416, 22.90681076], [70.0826416, 22.90652847], [70.08235931, 22.90652847], [70.08235931, 22.90624809], [70.08207703, 22.90624809], [70.08207703, 22.90596962], [70.08152771, 22.90596962], [70.08152771, 22.90624809], [70.08125305, 22.90624809], [70.08125305, 22.90681076], [70.07847595, 22.90681076], [70.07847595, 22.90652847], [70.07791901, 22.90652847], [70.07791901, 22.90624809], [70.07736206, 22.90624809], [70.07736206, 22.90596962], [70.07624817, 22.90597153], [70.07624817, 22.90569496], [70.07597351, 22.90569496], [70.07597351, 22.90597153], [70.07569122, 22.90597153], [70.07569122, 22.90569496], [70.07541656, 22.90569496], [70.07541656, 22.90541649], [70.07290649, 22.9054203], [70.07290649, 22.90513992], [70.07208252, 22.90513992], [70.07208252, 22.90485954], [70.07125092, 22.90486145], [70.07125092, 22.90458298], [70.06930542, 22.90458298], [70.06930542, 22.90430641], [70.06903076, 22.90431023], [70.06903076, 22.90402985], [70.06764221, 22.90402985], [70.06764221, 22.90431023], [70.06652832, 22.90431023], [70.06652832, 22.90402985], [70.06624603, 22.90402985], [70.06624603, 22.90374947], [70.06597137, 22.90374947], [70.06597137, 22.90347099], [70.06485748, 22.9034729], [70.06487274, 22.90374947], [70.06458282, 22.90374947], [70.06458282, 22.90402985], [70.06375122, 22.90402985], [70.06375122, 22.90431023], [70.06236267, 22.90431023], [70.06236267, 22.90402985], [70.06041718, 22.90402985], [70.06041718, 22.90374947], [70.05708313, 22.90374947], [70.05708313, 22.90402985], [70.05596924, 22.90402985], [70.05596924, 22.90431023], [70.05458069, 22.90431023], [70.05458069, 22.90402985], [70.05374908, 22.90402985], [70.05374908, 22.90374947], [70.05319214, 22.90374947], [70.05319214, 22.90347099], [70.05263519, 22.9034729], [70.05263519, 22.90319443], [70.05236053, 22.90319443], [70.05236053, 22.90291786], [70.05179596, 22.90291977], [70.05179596, 22.90262985], [70.05152893, 22.90263939], [70.05152893, 22.90236092], [70.05097198, 22.90236092], [70.05097198, 22.90208054], [70.05014038, 22.90208244], [70.05014038, 22.90125084], [70.05042267, 22.90125084], [70.05041504, 22.9006958], [70.05014038, 22.9006958], [70.05014038, 22.90041733], [70.04987335, 22.90042114], [70.04987335, 22.90014076], [70.04957581, 22.90014076], [70.04957581, 22.89986038], [70.04902649, 22.89986038], [70.04902649, 22.89957047], [70.04846954, 22.89958572], [70.04846954, 22.89930534], [70.04458618, 22.89931107], [70.04458618, 22.89903069], [70.04373932, 22.89903069], [70.04373932, 22.89875031], [70.04291534, 22.89875031], [70.04291534, 22.89847374], [70.0423584, 22.89847374], [70.0423584, 22.89819527], [70.04152679, 22.8982029], [70.04152679, 22.89792061], [70.03901672, 22.89792061], [70.03901672, 22.89764023], [70.03569794, 22.89764023], [70.03569794, 22.89735985], [70.03430176, 22.89736366], [70.03430176, 22.89708138], [70.03347015, 22.89708138], [70.03347015, 22.89680481], [70.03291321, 22.89680481], [70.03291321, 22.89625168], [70.03263855, 22.89625168], [70.03263855, 22.89542007], [70.0320816, 22.89541626], [70.0320816, 22.89569473], [70.03180695, 22.89569473], [70.03180695, 22.89596939], [70.0315094, 22.89596939], [70.0315094, 22.89625168], [70.03125, 22.89625168], [70.03125, 22.89708138], [70.03097534, 22.89708138], [70.03097534, 22.89736366], [70.03013611, 22.89735985], [70.03013611, 22.89764023], [70.02958679, 22.89763832], [70.02958679, 22.89847374], [70.02929688, 22.89846992], [70.0293045, 22.89875031], [70.02876282, 22.89875031], [70.02876282, 22.89903069], [70.0276413, 22.89903069], [70.0276413, 22.89931107], [70.02735901, 22.89930534], [70.02735901, 22.89958572], [70.0265274, 22.89957047], [70.0265274, 22.89986038], [70.02625275, 22.89986038], [70.02625275, 22.90014076], [70.02597046, 22.90014076], [70.02597046, 22.90042114], [70.02541351, 22.90041733], [70.02541351, 22.9006958], [70.0248642, 22.9006958], [70.0248642, 22.90097237], [70.02458191, 22.90097237], [70.02458191, 22.90125084], [70.02403259, 22.90125084], [70.02403259, 22.90153122], [70.02124786, 22.90153122], [70.02124786, 22.90125084], [70.02069092, 22.90125084], [70.02069092, 22.90069008], [70.02097321, 22.9006958], [70.02097321, 22.90057945], [70.02097321, 22.90041733], [70.02069092, 22.90042114], [70.02069092, 22.90014076], [70.0201416, 22.90014076], [70.0201416, 22.89957047], [70.01985931, 22.89958572], [70.01985931, 22.89930534], [70.01902771, 22.89930534], [70.01902771, 22.89958572], [70.01847076, 22.89958572], [70.01847076, 22.89930534], [70.01791382, 22.89930534], [70.01791382, 22.89958572], [70.01763916, 22.89957047], [70.01763916, 22.90014076], [70.01819611, 22.90013885], [70.01819611, 22.9006958], [70.01847076, 22.90069008], [70.01847076, 22.90125084], [70.01819611, 22.90125084], [70.01819611, 22.90153122], [70.01735687, 22.90153122], [70.01735687, 22.90125084], [70.01708221, 22.90125084], [70.01708221, 22.90069008], [70.01680756, 22.9006958], [70.01680756, 22.90041733], [70.01569366, 22.90041733], [70.01569366, 22.9006958], [70.01541901, 22.90069008], [70.01541901, 22.90125084], [70.01513672, 22.90125084], [70.01513672, 22.90208244], [70.01486206, 22.90208244], [70.01486206, 22.90097237], [70.01346588, 22.90097046], [70.01346588, 22.90125084], [70.01264191, 22.90125084], [70.01264191, 22.90097046], [70.01235962, 22.90097237], [70.01235962, 22.9006958], [70.01291656, 22.9006958], [70.01291656, 22.90041733], [70.01319122, 22.90042114], [70.01319122, 22.89986038], [70.01264191, 22.89986038], [70.01264191, 22.89957047], [70.01208496, 22.89958572], [70.01209259, 22.89986038], [70.01180267, 22.89986038], [70.01180267, 22.90014076], [70.01125336, 22.90013885], [70.01125336, 22.9006958], [70.01069641, 22.90069008], [70.01069641, 22.90125084], [70.01125336, 22.90125084], [70.01125336, 22.90208244], [70.01041412, 22.90208244], [70.01041412, 22.90180588], [70.01013947, 22.90180969], [70.01013947, 22.90069008], [70.00958252, 22.9006958], [70.00958252, 22.90041733], [70.00875092, 22.90042114], [70.00875092, 22.90014076], [70.00846863, 22.90014076], [70.00846863, 22.89957047], [70.00819397, 22.89958572], [70.00819397, 22.89930534], [70.00736237, 22.89930534], [70.00736237, 22.89958572], [70.00624847, 22.89957047], [70.00624847, 22.89986038], [70.00569153, 22.89986038], [70.00569153, 22.90014076], [70.00514221, 22.90014076], [70.00514221, 22.90042114], [70.00485992, 22.90042114], [70.00485992, 22.90014076], [70.00402832, 22.90014076], [70.00402832, 22.89986038], [70.00374603, 22.89986038], [70.00374603, 22.90014076], [70.00235748, 22.90014076], [70.00235748, 22.89986038], [70.00121307, 22.89986038], [70.00068665, 22.89986038], [70.00068665, 22.90014076], [70.00041962, 22.90014076], [70.00041962, 22.90042114], [70.00013733, 22.90042114], [70.00013733, 22.90291977], [69.99986267, 22.90291977], [69.99597168, 22.90291977], [69.99597168, 22.90262985], [69.99541473, 22.90263939], [69.99541473, 22.90236092], [69.99485779, 22.90236092], [69.99485779, 22.90208054], [69.99430847, 22.90208244], [69.99430847, 22.90180588], [69.99346924, 22.90180969], [69.99346924, 22.90153122], [69.99291992, 22.90153122], [69.99291992, 22.90125084], [69.99208069, 22.90125084], [69.99208069, 22.90097046], [69.99153137, 22.90097237], [69.99153137, 22.9006958], [69.99069214, 22.9006958], [69.99069214, 22.90041733], [69.99014282, 22.90042114], [69.99014282, 22.90014076], [69.98958588, 22.90014076], [69.98958588, 22.89986038], [69.98791504, 22.89986038], [69.98791504, 22.89958572], [69.98596954, 22.89958572], [69.98596954, 22.89930534], [69.98542023, 22.89931107], [69.98542023, 22.89903069], [69.98401642, 22.89903069], [69.98401642, 22.89875031], [69.98291779, 22.89875031], [69.98291779, 22.89846992], [69.98152924, 22.89847374], [69.98152924, 22.89819527], [69.98014069, 22.8982029], [69.98014069, 22.89792061], [69.97820282, 22.89792061], [69.97820282, 22.89764023], [69.97624969, 22.89764023], [69.97624969, 22.89735985], [69.97402954, 22.89736366], [69.97402954, 22.89708138], [69.97208405, 22.89708138], [69.97208405, 22.89680481], [69.96986389, 22.89680481], [69.96986389, 22.89652824], [69.96875, 22.89653015], [69.96875, 22.89625168], [69.96736145, 22.89625168], [69.96736145, 22.89596939], [69.96624756, 22.89596939], [69.96624756, 22.89569473], [69.96485901, 22.89569473], [69.96485901, 22.89541626], [69.96347046, 22.89542007], [69.96347046, 22.8951416], [69.96180725, 22.8951416], [69.96180725, 22.89485931], [69.96013641, 22.89485931], [69.96013641, 22.8943119], [69.95903015, 22.89430618], [69.95903015, 22.89458275], [69.95847321, 22.89458084], [69.95847321, 22.89485931], [69.95819092, 22.89485931], [69.95819092, 22.8951416], [69.9576416, 22.8951416], [69.9576416, 22.89542007], [69.95735931, 22.89541626], [69.95735931, 22.89569473], [69.95625305, 22.89569473], [69.95625305, 22.89596939], [69.95597076, 22.89596939], [69.95597076, 22.89569473], [69.95569611, 22.89569473], [69.95569611, 22.89541626], [69.95540619, 22.89542007], [69.95540619, 22.8943119], [69.9540329, 22.8943119], [69.9540329, 22.89403152], [69.95153046, 22.89403152], [69.95153046, 22.89319038], [69.95124817, 22.8931942], [69.95124817, 22.89291763], [69.94790649, 22.89291763], [69.94790649, 22.89263916], [69.94680786, 22.89263916], [69.94680786, 22.89291763], [69.94596863, 22.89291763], [69.94596863, 22.89263916], [69.94458008, 22.89263916], [69.94458008, 22.89236069], [69.94403076, 22.89236069], [69.94403076, 22.89263916], [69.9404068, 22.89263916], [69.9404068, 22.89291763], [69.93736267, 22.89291763], [69.93736267, 22.8931942], [69.93708038, 22.8931942], [69.93708038, 22.89291763], [69.93681335, 22.89291763], [69.93681335, 22.89208031], [69.93653107, 22.89208412], [69.93653107, 22.89152718], [69.93624878, 22.89152908], [69.93624878, 22.89014053], [69.93596649, 22.89014053], [69.93596649, 22.88986015], [69.93569183, 22.88986206], [69.93569183, 22.88763809], [69.93540955, 22.88764954], [69.93540955, 22.88708115], [69.93514252, 22.88708305], [69.93514252, 22.88652802], [69.93486023, 22.88652992], [69.93486023, 22.88624954], [69.93458557, 22.88624954], [69.93458557, 22.8856945], [69.93430328, 22.8856945], [69.93430328, 22.88541603], [69.93402863, 22.88541985], [69.93402863, 22.88513947], [69.93347168, 22.88513947], [69.93347168, 22.8848629], [69.93319702, 22.8848629], [69.93319702, 22.88459015], [69.9329071, 22.88459015], [69.9329071, 22.88430977], [69.93235016, 22.88430977], [69.93235016, 22.88402939], [69.93208313, 22.88402939], [69.93208313, 22.88375282], [69.93180847, 22.88375282], [69.93180847, 22.88347054], [69.93152618, 22.88347054], [69.93152618, 22.88319206], [69.93096924, 22.88319206], [69.93096924, 22.8829174], [69.93068695, 22.88292122], [69.93068695, 22.88264275], [69.93041992, 22.88264275], [69.93041992, 22.88236237], [69.92986298, 22.88236237], [69.92986298, 22.88208008], [69.92958069, 22.88208389], [69.92958069, 22.88180542], [69.92930603, 22.88181114], [69.92930603, 22.88153076], [69.92903137, 22.88153076], [69.92903137, 22.88124847], [69.92874908, 22.88124847], [69.92874908, 22.88096809], [69.92847443, 22.88097191], [69.92847443, 22.88069534], [69.92819214, 22.88069916], [69.92819214, 22.88042068], [69.92791748, 22.88042068], [69.92791748, 22.8801384], [69.92679596, 22.8801384], [69.92679596, 22.87985992], [69.92624664, 22.87986183], [69.92624664, 22.87958336], [69.92597198, 22.87958336], [69.92597198, 22.87930489], [69.92569733, 22.87930489], [69.92569733, 22.87902832], [69.92542267, 22.87902832], [69.92542267, 22.87874985], [69.92485809, 22.87874985], [69.92485809, 22.87845993], [69.92458344, 22.87847137], [69.92458344, 22.87819481], [69.92402649, 22.87819481], [69.92402649, 22.87791634], [69.92375183, 22.87791824], [69.92375183, 22.87763977], [69.92346954, 22.87763977], [69.92346954, 22.87735939], [69.92319489, 22.8773613], [69.92319489, 22.87708282], [69.92292023, 22.87708282], [69.92292023, 22.87680626], [69.92236328, 22.87681007], [69.92236328, 22.87652969], [69.92208099, 22.87652969], [69.92208099, 22.87625122], [69.92151642, 22.87625122], [69.92151642, 22.87597084], [69.92124939, 22.87597275], [69.92124939, 22.87569427], [69.92069244, 22.87569427], [69.92069244, 22.8754158], [69.92041016, 22.87541962], [69.92041016, 22.87514114], [69.91986084, 22.87514114], [69.91986084, 22.87486076], [69.91958618, 22.87486076], [69.91958618, 22.87458038], [69.91902924, 22.8745842], [69.91902924, 22.87430573], [69.91874695, 22.87430954], [69.91874695, 22.87403107], [69.91847229, 22.87403107], [69.91847229, 22.87347031], [69.91819763, 22.87347221], [69.91819763, 22.87291718], [69.91764069, 22.87291718], [69.91764069, 22.87319565], [69.9126358, 22.87319565], [69.9126358, 22.87291718], [69.91179657, 22.87292099], [69.91179657, 22.87236023], [69.91152954, 22.87236023], [69.91152954, 22.87014008], [69.91124725, 22.87014008], [69.91124725, 22.86959267], [69.9109726, 22.86959267], [69.9109726, 22.86930084], [69.9098587, 22.86930466], [69.9098587, 22.86902809], [69.90930176, 22.86903191], [69.90930176, 22.86875153], [69.90875244, 22.86875153], [69.90875244, 22.86819077], [69.90847015, 22.86819458], [69.90847015, 22.86791611], [69.90820313, 22.86792183], [69.90820313, 22.86764145], [69.90791321, 22.86764145], [69.90791321, 22.86735916], [69.90735626, 22.86735916], [69.90735626, 22.86708069], [69.90652466, 22.8670826], [69.90652466, 22.86680603], [69.90569305, 22.86681175], [69.90569305, 22.86624908], [69.9043045, 22.86624718], [69.9043045, 22.86652756], [69.90291595, 22.86652756], [69.90291595, 22.86624718], [69.90236664, 22.86624908], [69.90236664, 22.86597061], [69.90208435, 22.86597252], [69.90208435, 22.86569405], [69.90180206, 22.86569405], [69.90180206, 22.86541748], [69.9015274, 22.86541748], [69.9015274, 22.86514091], [69.90040588, 22.86514091], [69.90040588, 22.86541748], [69.89736176, 22.86541748], [69.89736176, 22.86514091], [69.8970871, 22.86514091], [69.8970871, 22.86541748], [69.89541626, 22.86541748], [69.89541626, 22.86569405], [69.89291382, 22.86569405], [69.89291382, 22.86597252], [69.8915329, 22.86597061], [69.8915329, 22.86624908], [69.89041901, 22.86624718], [69.89041901, 22.86652756], [69.88986206, 22.86651993], [69.88986206, 22.86681175], [69.88957977, 22.86680603], [69.88957977, 22.8670826], [69.88903046, 22.86708069], [69.88903046, 22.86764145], [69.88874817, 22.86764145], [69.88874817, 22.86792183], [69.88847351, 22.86791611], [69.88847351, 22.86819458], [69.88791656, 22.86819458], [69.88791656, 22.86847115], [69.88764191, 22.86846924], [69.88764191, 22.86875153], [69.88736725, 22.86875153], [69.88736725, 22.86903191], [69.88709259, 22.86903191], [69.88709259, 22.86959267], [69.88652802, 22.86958122], [69.88652802, 22.86986351], [69.88597107, 22.8698597], [69.88597107, 22.87014008], [69.88513947, 22.87014008], [69.88513947, 22.87042046], [69.88458252, 22.87042046], [69.88458252, 22.87070084], [69.88375092, 22.87069511], [69.88375092, 22.87097359], [69.88180542, 22.87097359], [69.88181305, 22.87125015], [69.88069153, 22.87125015], [69.88069153, 22.87153053], [69.8795929, 22.87153053], [69.8795929, 22.87181091], [69.87847137, 22.87180519], [69.87847137, 22.87208366], [69.87735748, 22.87207985], [69.87735748, 22.87236023], [69.87568665, 22.87236023], [69.87568665, 22.87207985], [69.87347412, 22.87208366], [69.87347412, 22.87180519], [69.87124634, 22.87181091], [69.87124634, 22.87153053], [69.86875153, 22.87153053], [69.86875153, 22.87181091], [69.86819458, 22.87180519], [69.86819458, 22.87208366], [69.86791992, 22.87207985], [69.86791992, 22.87292099], [69.86680603, 22.87292099], [69.86680603, 22.87265015], [69.86569214, 22.87265015], [69.86569214, 22.87236023], [69.86513519, 22.87236023], [69.86513519, 22.87208366], [69.86458588, 22.87208366], [69.86458588, 22.87180519], [69.86374664, 22.87181091], [69.86374664, 22.87153053], [69.86292267, 22.87153053], [69.86292267, 22.87125015], [69.86207581, 22.87125015], [69.86207581, 22.87096977], [69.86125183, 22.87097359], [69.86125183, 22.87069511], [69.86068726, 22.87070084], [69.86068726, 22.87042046], [69.85986328, 22.87042046], [69.85986328, 22.87014008], [69.85901642, 22.87014008], [69.85901642, 22.8698597], [69.85819244, 22.86986351], [69.85819244, 22.86958122], [69.85736084, 22.86959267], [69.85736084, 22.86764145], [69.85764313, 22.86764145], [69.8576355, 22.86680603], [69.85819244, 22.86681175], [69.85819244, 22.86651993], [69.85847473, 22.86652756], [69.85847473, 22.86624718], [69.85874939, 22.86624908], [69.85874939, 22.86541748], [69.85901642, 22.86541748], [69.85901642, 22.86514091], [69.85958099, 22.86514091], [69.85958099, 22.86458015], [69.86013794, 22.86458397], [69.86013794, 22.86263847], [69.86042023, 22.86264038], [69.86042023, 22.8615303], [69.86068726, 22.8615303], [69.86068726, 22.86124992], [69.86096954, 22.86124992], [69.86096954, 22.86069107], [69.86125183, 22.86069489], [69.86125183, 22.86013794], [69.86152649, 22.86013985], [69.86152649, 22.8595829], [69.86180878, 22.85958481], [69.86180878, 22.85902786], [69.86207581, 22.85902977], [69.86207581, 22.85847282], [69.86125183, 22.85847282], [69.86125183, 22.85874939], [69.86096954, 22.85874939], [69.86096954, 22.85902977], [69.86068726, 22.85902977], [69.86068726, 22.85931015], [69.86042023, 22.85930634], [69.86042023, 22.85986137], [69.86013031, 22.85985947], [69.86013031, 22.86013985], [69.85986328, 22.86013985], [69.85986328, 22.86069489], [69.85958099, 22.86069107], [69.85958099, 22.8615303], [69.85930634, 22.8615284], [69.85930634, 22.86236191], [69.85901642, 22.86236], [69.85901642, 22.86264038], [69.85874939, 22.86264038], [69.85874939, 22.86375046], [69.8584671, 22.86375046], [69.8584671, 22.86403084], [69.85819244, 22.86402893], [69.85819244, 22.86458397], [69.85791779, 22.86458015], [69.85791779, 22.86541748], [69.8576355, 22.86541748], [69.8576355, 22.86569405], [69.85708618, 22.86569405], [69.85708618, 22.86597252], [69.85680389, 22.86597252], [69.85680389, 22.86652756], [69.85652924, 22.86652756], [69.85652924, 22.8670826], [69.85624695, 22.86708069], [69.85624695, 22.86764145], [69.85597229, 22.86764145], [69.85597229, 22.86792183], [69.85569763, 22.86791611], [69.85569763, 22.86819458], [69.85375214, 22.86819458], [69.85375214, 22.86791611], [69.8529129, 22.86792183], [69.8529129, 22.86764145], [69.8520813, 22.86764145], [69.8520813, 22.86735916], [69.85069275, 22.86735916], [69.85069275, 22.86708069], [69.84986115, 22.8670826], [69.84986115, 22.86680603], [69.84902954, 22.86681175], [69.84902954, 22.86651993], [69.84819794, 22.86652756], [69.84819794, 22.86624718], [69.8473587, 22.86624908], [69.8473587, 22.86597061], [69.8465271, 22.86597252], [69.8465271, 22.86569405], [69.8456955, 22.86569405], [69.8456955, 22.86541748], [69.84485626, 22.86541748], [69.84485626, 22.86514091], [69.84401703, 22.86514091], [69.84401703, 22.86486053], [69.84319305, 22.86486053], [69.84319305, 22.86458015], [69.84236145, 22.86458397], [69.84236145, 22.8643055], [69.84124756, 22.86431122], [69.84124756, 22.86403084], [69.8409729, 22.86403084], [69.8409729, 22.86375046], [69.84041595, 22.86375046], [69.84041595, 22.86346054], [69.83985901, 22.86347198], [69.83985901, 22.86319542], [69.83957672, 22.8631897], [69.83958435, 22.86291695], [69.83847046, 22.86292076], [69.83847046, 22.86264038], [69.83763885, 22.86264038], [69.83763885, 22.86236], [69.83708191, 22.86236191], [69.83708191, 22.86208344], [69.83652496, 22.86208344], [69.83652496, 22.86180687], [69.83598328, 22.86181068], [69.83598328, 22.8615303], [69.83513641, 22.8615303], [69.83513641, 22.86124992], [69.8345871, 22.86124992], [69.8345871, 22.86096954], [69.83403015, 22.86097145], [69.83403015, 22.86069489], [69.83347321, 22.86069489], [69.83347321, 22.86041641], [69.83291626, 22.86042023], [69.83291626, 22.86013985], [69.83235931, 22.86013985], [69.83235931, 22.85985947], [69.83180237, 22.85986137], [69.83180237, 22.85958481], [69.83125305, 22.85958481], [69.83125305, 22.85930634], [69.83040619, 22.85931015], [69.83040619, 22.85902977], [69.82985687, 22.85902977], [69.82985687, 22.85874939], [69.82930756, 22.85874939], [69.82930756, 22.85847282], [69.82875061, 22.85847473], [69.82875061, 22.85819435], [69.82819366, 22.85819435], [69.82819366, 22.85791588], [69.82791901, 22.85791969], [69.82791901, 22.85765076], [69.82736206, 22.85765076], [69.82736206, 22.85736275], [69.82680511, 22.85736275], [69.82680511, 22.85708427], [69.82624817, 22.85708427], [69.82624817, 22.8568058], [69.82596588, 22.85680962], [69.82596588, 22.85653114], [69.82541656, 22.85653114], [69.82541656, 22.85625267], [69.82485962, 22.85625267], [69.82485962, 22.85597038], [69.82430267, 22.85597038], [69.82430267, 22.85569382], [69.82402802, 22.85569382], [69.82402802, 22.85541725], [69.82347107, 22.85542107], [69.82347107, 22.85514259], [69.82290649, 22.85514259], [69.82290649, 22.8548584], [69.82235718, 22.8548584], [69.82235718, 22.85457993], [69.82208252, 22.85458374], [69.82208252, 22.85430527], [69.82125092, 22.85430908], [69.82125092, 22.85403061], [69.82013702, 22.85403061], [69.82013702, 22.85374832], [69.81903076, 22.85374832], [69.81903076, 22.85320091], [69.81846619, 22.85320091], [69.81846619, 22.85292053], [69.81819153, 22.85292053], [69.81819153, 22.85263824], [69.8170929, 22.85263824], [69.8170929, 22.85235977], [69.81680298, 22.85236168], [69.81680298, 22.85208321], [69.81485748, 22.85207939], [69.81485748, 22.85263824], [69.81318665, 22.85263824], [69.81318665, 22.85292053], [69.81096649, 22.85292053], [69.81096649, 22.85263824], [69.80930328, 22.85263824], [69.80930328, 22.85235977], [69.80735779, 22.85236168], [69.80735779, 22.85208321], [69.80569458, 22.85208321], [69.80569458, 22.85180473], [69.80374908, 22.85180473], [69.80374908, 22.85152626], [69.80208588, 22.85152626], [69.80208588, 22.85124969], [69.80014038, 22.85124969], [69.80014038, 22.85097122], [69.79930878, 22.85097313], [69.79930878, 22.85069466], [69.79846954, 22.85069466], [69.79846954, 22.85041618], [69.79792023, 22.85041809], [69.79792023, 22.84986115], [69.79763794, 22.84986115], [69.79763794, 22.84958076], [69.79708099, 22.84958267], [69.79708099, 22.84930611], [69.79680634, 22.84930992], [69.79680634, 22.84902954], [69.79651642, 22.84902954], [69.79651642, 22.84875107], [69.79624939, 22.84875107], [69.79624939, 22.84848022], [69.7959671, 22.84848022], [69.7959671, 22.84819031], [69.79541779, 22.84819412], [69.79541779, 22.84791756], [69.79514313, 22.84791946], [69.79514313, 22.84764099], [69.79486084, 22.84764099], [69.79486084, 22.84736061], [69.79458618, 22.84736061], [69.79458618, 22.84708023], [69.79430389, 22.84708595], [69.79430389, 22.84680557], [69.79402161, 22.84680939], [69.79402161, 22.84625053], [69.79374695, 22.84625053], [69.79374695, 22.84597015], [69.79347229, 22.84597206], [69.79347229, 22.84569168], [69.79319763, 22.84569168], [69.79319763, 22.84541702], [69.7923584, 22.84542084], [69.7923584, 22.84514046], [69.79207611, 22.84514046], [69.79207611, 22.84486008], [69.79152679, 22.84486389], [69.79152679, 22.84430504], [69.79125214, 22.84431076], [69.79125214, 22.84403038], [69.79070282, 22.84403038], [69.79070282, 22.84375191], [69.7904129, 22.84375191], [69.7904129, 22.84346962], [69.78930664, 22.84347343], [69.78930664, 22.84319496], [69.78848267, 22.84320068], [69.78848267, 22.8429203], [69.78819275, 22.8429203], [69.78819275, 22.84264183], [69.7876358, 22.84264183], [69.7876358, 22.8423481], [69.78736115, 22.84235954], [69.78736115, 22.84208107], [69.7868042, 22.84208107], [69.7868042, 22.84180641], [69.78652954, 22.84181023], [69.78652954, 22.84153175], [69.7859726, 22.84153175], [69.7859726, 22.84124947], [69.78569794, 22.84124947], [69.78569794, 22.84096909], [69.78514099, 22.8409729], [69.78514099, 22.84069443], [69.7848587, 22.84069443], [69.7848587, 22.84041595], [69.78430176, 22.84042168], [69.78430176, 22.8401413], [69.7840271, 22.8401413], [69.7840271, 22.83986092], [69.78347015, 22.83986092], [69.78347015, 22.83958054], [69.7831955, 22.83958244], [69.7831955, 22.83930588], [69.78263855, 22.83930969], [69.78263855, 22.83903122], [69.7820816, 22.83903122], [69.7820816, 22.83875084], [69.78180695, 22.83875084], [69.78180695, 22.83847046], [69.78125, 22.83847237], [69.78125, 22.83819389], [69.78069305, 22.83819389], [69.78069305, 22.83791733], [69.7804184, 22.83792114], [69.7804184, 22.83764076], [69.77986145, 22.83764076], [69.77986145, 22.83736038], [69.77929688, 22.83736038], [69.77929688, 22.83708], [69.77902985, 22.83708382], [69.77902985, 22.83680534], [69.7784729, 22.83681107], [69.7784729, 22.83653831], [69.77791595, 22.83653831], [69.77791595, 22.83625031], [69.7776413, 22.83625031], [69.7776413, 22.83596992], [69.77708435, 22.83597183], [69.77708435, 22.83569527], [69.7765274, 22.83570099], [69.7765274, 22.83542061], [69.77625275, 22.83542061], [69.77625275, 22.83514023], [69.7756958, 22.83514023], [69.7756958, 22.83485985], [69.77513885, 22.83486176], [69.77513885, 22.83458328], [69.7748642, 22.83458328], [69.7748642, 22.83430672], [69.77430725, 22.83430672], [69.77430725, 22.83402824], [69.77403259, 22.83403015], [69.77403259, 22.83374977], [69.77347565, 22.83374977], [69.77347565, 22.8334713], [69.77319336, 22.83348083], [69.77319336, 22.83292007], [69.77291107, 22.83292007], [69.77291107, 22.83236122], [69.77263641, 22.83236122], [69.77263641, 22.83152962], [69.77291107, 22.83152962], [69.77291107, 22.83125114], [69.77375031, 22.83125114], [69.77375031, 22.83152962], [69.77403259, 22.83152962], [69.77403259, 22.83181], [69.77458191, 22.83180618], [69.77458191, 22.83208466], [69.77540588, 22.83208084], [69.77540588, 22.83236122], [69.77625275, 22.83236122], [69.77625275, 22.83208084], [69.77597046, 22.83208466], [69.77597046, 22.83180618], [69.7756958, 22.83181], [69.7756958, 22.83152962], [69.77513885, 22.83152962], [69.77513885, 22.83125114], [69.77485657, 22.83125114], [69.77485657, 22.83097267], [69.77458191, 22.83097267], [69.77458191, 22.8306942], [69.77375031, 22.8306942], [69.77375031, 22.83041763], [69.77263641, 22.83041573], [69.77263641, 22.82986259], [69.77236176, 22.82986259], [69.77236176, 22.82958031], [69.77180481, 22.82958412], [69.77180481, 22.82930565], [69.77153015, 22.82930946], [69.77153015, 22.82875252], [69.77097321, 22.82875252], [69.77097321, 22.82847023], [69.77041626, 22.82847023], [69.77041626, 22.82819366], [69.76985931, 22.82819366], [69.76985931, 22.8279171], [69.76819611, 22.82792091], [69.76819611, 22.82763863], [69.76763916, 22.82763863], [69.76763916, 22.82735062], [69.7673645, 22.82736015], [69.7673645, 22.82708359], [69.76708221, 22.82708359], [69.76708221, 22.82653046], [69.76680756, 22.82653046], [69.76680756, 22.82624817], [69.76625061, 22.82624817], [69.76625061, 22.8259697], [69.76569366, 22.8259716], [69.76569366, 22.82569504], [69.76486206, 22.82570076], [69.76486206, 22.82542038], [69.76403809, 22.82542038], [69.76403809, 22.82513809], [69.76235962, 22.82513809], [69.76235962, 22.82485962], [69.76152802, 22.82486153], [69.76152802, 22.82458305], [69.76069641, 22.82458305], [69.76069641, 22.82430649], [69.75985718, 22.8243103], [69.75985718, 22.82402992], [69.7590332, 22.82402992], [69.7590332, 22.82374954], [69.75846863, 22.82374954], [69.75846863, 22.82347107], [69.75819397, 22.82347298], [69.75819397, 22.8231945], [69.75791931, 22.8231945], [69.75791931, 22.82291794], [69.75763702, 22.82291985], [69.75763702, 22.82263947], [69.75708008, 22.82263947], [69.75708008, 22.82236099], [69.75653076, 22.82236099], [69.75653076, 22.82208061], [69.75624847, 22.82208252], [69.75624847, 22.82180405], [69.75596619, 22.82180977], [69.75596619, 22.82154083], [69.75541687, 22.82154083], [69.75541687, 22.82125092], [69.75514221, 22.82125092], [69.75514221, 22.82097054], [69.75458527, 22.82097244], [69.75458527, 22.82069588], [69.75402832, 22.82069588], [69.75402832, 22.8204174], [69.75347137, 22.82042122], [69.75347137, 22.82014084], [69.75319672, 22.82014084], [69.75319672, 22.81986046], [69.75263977, 22.81986046], [69.75263977, 22.81958008], [69.75235748, 22.8195858], [69.75235748, 22.81902695], [69.75208282, 22.81903076], [69.75208282, 22.81847], [69.75180817, 22.81847382], [69.75180817, 22.81819534], [69.75152588, 22.81820107], [69.75152588, 22.8176403], [69.75125122, 22.8176403], [69.75125122, 22.81707954], [69.75096893, 22.81708336], [69.75096893, 22.81680489], [69.75069427, 22.81680489], [69.75069427, 22.81625175], [69.75041962, 22.81625175], [69.75041962, 22.81568909], [69.75013733, 22.81569481], [69.75013733, 22.81541634], [69.74986267, 22.81541634], [69.74986267, 22.81485939], [69.74958038, 22.81485939], [69.74958038, 22.81430626], [69.74931335, 22.81431007], [69.74931335, 22.81347084], [69.74903107, 22.81347275], [69.74903107, 22.8129158], [69.74874115, 22.81291962], [69.74874115, 22.81236839], [69.74846649, 22.81236839], [69.74846649, 22.81180954], [69.74819183, 22.81180954], [69.74819183, 22.81153107], [69.74791718, 22.81153107], [69.74791718, 22.81042099], [69.74764252, 22.81042099], [69.74764252, 22.80903053], [69.74736023, 22.80903053], [69.74736023, 22.80846977], [69.74708557, 22.80847168], [69.74708557, 22.80791664], [69.74680328, 22.80792046], [69.74680328, 22.8073597], [69.74652863, 22.8073616], [69.74652863, 22.80680466], [69.74624634, 22.80680466], [69.74624634, 22.80624962], [69.74597168, 22.80624962], [69.74597168, 22.80569458], [69.74569702, 22.80569458], [69.74569702, 22.80513954], [69.7454071, 22.80513954], [69.7454071, 22.80458069], [69.74514008, 22.8045845], [69.74514008, 22.80402756], [69.74485779, 22.80402946], [69.74485779, 22.80347252], [69.74458313, 22.80347252], [69.74458313, 22.80208397], [69.74485779, 22.80208397], [69.74485779, 22.8018055], [69.74514008, 22.80181122], [69.74514008, 22.80069923], [69.74485779, 22.8006897], [69.74485779, 22.80013847], [69.74514008, 22.80013847], [69.74514008, 22.79931068], [69.7454071, 22.79931068], [69.7454071, 22.79874992], [69.74569702, 22.79874992], [69.74569702, 22.79819107], [69.74597168, 22.79819489], [69.74597168, 22.79791641], [69.74624634, 22.79792023], [69.74624634, 22.79652977], [69.74652863, 22.79652977], [69.74652863, 22.79624939], [69.74680328, 22.79624939], [69.74680328, 22.79597092], [69.74652863, 22.79597282], [69.74652863, 22.79458427], [69.74680328, 22.79458237], [69.74680328, 22.79375076], [69.74624634, 22.79375076], [69.74624634, 22.79347038], [69.74597168, 22.79347229], [69.74597168, 22.79319572], [69.74569702, 22.79319572], [69.74569702, 22.79291725], [69.74514008, 22.79292107], [69.74514008, 22.79264069], [69.74485779, 22.79264069], [69.74485779, 22.79236031], [69.74458313, 22.79236031], [69.74458313, 22.79264069], [69.74430847, 22.79264069], [69.74430847, 22.79236031], [69.74402618, 22.79236031], [69.74402618, 22.7912426], [69.74375153, 22.79125023], [69.74375153, 22.79063034], [69.74375153, 22.79041672], [69.74346924, 22.79042053], [69.74346924, 22.78903008], [69.74318695, 22.78903008], [69.74318695, 22.7881794], [69.74291992, 22.78819466], [69.74291992, 22.78791618], [69.74263763, 22.78792191], [69.74263763, 22.78735924], [69.74236298, 22.78735924], [69.74236298, 22.78708076], [69.74208069, 22.78708267], [69.74208069, 22.78652763], [69.74180603, 22.78652763], [69.74180603, 22.78513908], [69.74153137, 22.78513908], [69.74153137, 22.78486061], [69.74069214, 22.78486061], [69.74069214, 22.78458023], [69.74041748, 22.78458405], [69.74041748, 22.78430557], [69.74014282, 22.78430939], [69.74014282, 22.78375053], [69.73986053, 22.78375053], [69.73986053, 22.78347206], [69.73958588, 22.78347206], [69.73958588, 22.78319359], [69.73930359, 22.78319359], [69.73930359, 22.78291512], [69.73902893, 22.78292084], [69.73902893, 22.78264046], [69.73874664, 22.78264046], [69.73874664, 22.78236008], [69.73847198, 22.78236198], [69.73847198, 22.78208351], [69.73819733, 22.78208351], [69.73819733, 22.78152847], [69.73792267, 22.78153038], [69.73792267, 22.78125], [69.73764038, 22.78125], [69.73764038, 22.78096962], [69.73735809, 22.78097153], [69.73735809, 22.78069305], [69.73569489, 22.78069305], [69.73569489, 22.78097153], [69.73542023, 22.78096962], [69.73542023, 22.78125], [69.73430634, 22.78125], [69.73430634, 22.78096962], [69.73402405, 22.78097153], [69.73402405, 22.77902794], [69.73374176, 22.77902985], [69.73374176, 22.77874947], [69.73361206, 22.77874947], [69.7334671, 22.77874947], [69.7334671, 22.77819061], [69.73319244, 22.77819443], [69.73319244, 22.77791595], [69.73291779, 22.77791977], [69.73291779, 22.77708054], [69.7326355, 22.77708054], [69.7326355, 22.77680588], [69.73236084, 22.77680969], [69.73236084, 22.77581978], [69.73236084, 22.77486229], [69.73208618, 22.77486229], [69.73208618, 22.77430916], [69.73179626, 22.77430916], [69.73179626, 22.7737484], [69.73152924, 22.7737484], [69.73152924, 22.77319908], [69.73124695, 22.77319908], [69.73124695, 22.77263832], [69.73097229, 22.77263832], [69.73097229, 22.77235985], [69.73041534, 22.77236176], [69.73041534, 22.77208328], [69.73014069, 22.77208328], [69.73014069, 22.77180481], [69.7298584, 22.77180481], [69.7298584, 22.77124977], [69.72957611, 22.77124977], [69.72957611, 22.77096939], [69.72902679, 22.7709713], [69.72902679, 22.77069473], [69.72875214, 22.77069473], [69.72875214, 22.77013969], [69.72846985, 22.77013969], [69.72846985, 22.76986122], [69.72819519, 22.76986122], [69.72819519, 22.76958275], [69.7279129, 22.76958275], [69.7279129, 22.76930618], [69.72763824, 22.76931], [69.72763824, 22.76875114], [69.72735596, 22.76875114], [69.72735596, 22.76847076], [69.7270813, 22.76847267], [69.7270813, 22.7681942], [69.72680664, 22.7681942], [69.72680664, 22.76736069], [69.72651672, 22.76736069], [69.72651672, 22.76707077], [69.72624969, 22.76708412], [69.72624969, 22.76652718], [69.72598267, 22.76653099], [69.72598267, 22.76625061], [69.72569275, 22.76625061], [69.72569275, 22.76597023], [69.72486115, 22.76597214], [69.72486115, 22.76569366], [69.72458649, 22.76569366], [69.72458649, 22.76513863], [69.72429657, 22.76514053], [69.72429657, 22.76403046], [69.72402954, 22.76403046], [69.72402954, 22.76375008], [69.7234726, 22.76375008], [69.7234726, 22.7634697], [69.72319794, 22.76347351], [69.72319794, 22.76291656], [69.72292328, 22.76292038], [69.72292328, 22.76264191], [69.72207642, 22.76264191], [69.72207642, 22.76292038], [69.72070313, 22.76292038], [69.72070313, 22.76264191], [69.72041321, 22.76264191], [69.72041321, 22.76235962], [69.72013855, 22.76235962], [69.72013855, 22.76014137], [69.71985626, 22.76014137], [69.71985626, 22.75930977], [69.7195816, 22.75930977], [69.7195816, 22.75875092], [69.71930695, 22.75875092], [69.71930695, 22.75819969], [69.71901703, 22.75819969], [69.71901703, 22.75792122], [69.71875763, 22.75792122], [69.71875763, 22.75708008], [69.71847534, 22.75708389], [69.71847534, 22.75652695], [69.71819305, 22.75653076], [69.71819305, 22.75625038], [69.7179184, 22.75625038], [69.7179184, 22.75597], [69.71763611, 22.75597191], [69.71763611, 22.75541687], [69.71736145, 22.75542068], [69.71736145, 22.75457954], [69.71708679, 22.75458336], [69.71708679, 22.75430679], [69.7168045, 22.75430679], [69.7168045, 22.75402832], [69.71652985, 22.75403023], [69.71652985, 22.75346947], [69.71624756, 22.75347137], [69.71624756, 22.75319481], [69.7159729, 22.75319481], [69.7159729, 22.75291634], [69.71569824, 22.75292015], [69.71569824, 22.75235939], [69.71541595, 22.7523613], [69.71541595, 22.75180626], [69.7151413, 22.75181007], [69.7151413, 22.75152969], [69.7140274, 22.75152969], [69.7140274, 22.75097275], [69.71430206, 22.75097275], [69.71430206, 22.75069427], [69.71485901, 22.75069427], [69.71485901, 22.7504158], [69.7151413, 22.75041962], [69.7151413, 22.75014114], [69.71541595, 22.75014114], [69.71541595, 22.74958038], [69.71569061, 22.7495842], [69.71569061, 22.74819374], [69.71541595, 22.74819374], [69.71541595, 22.74569511], [69.7151413, 22.74570084], [69.7151413, 22.7448597], [69.71541595, 22.7448616], [69.71541595, 22.74458313], [69.71569061, 22.74458313], [69.71569824, 22.74374962], [69.7159729, 22.74374962], [69.7159729, 22.74180984], [69.71624756, 22.74180984], [69.71624756, 22.74125099], [69.71569824, 22.74125099], [69.71569824, 22.74097061], [69.71457672, 22.74097061], [69.71457672, 22.74125099], [69.71347046, 22.74125099], [69.71347046, 22.74097061], [69.7131958, 22.74097252], [69.7131958, 22.74069595], [69.71347046, 22.74069595], [69.71347046, 22.74013901], [69.71375275, 22.74013901], [69.71375275, 22.7393055], [69.7131958, 22.73931122], [69.7131958, 22.73903084], [69.71208191, 22.73903084], [69.71208191, 22.73875046], [69.71152496, 22.73875046], [69.71152496, 22.73847389], [69.71125031, 22.73847389], [69.71125031, 22.73819542], [69.70930481, 22.73819542], [69.70930481, 22.73847389], [69.70874786, 22.73847008], [69.70874786, 22.73875046], [69.70847321, 22.73875046], [69.70847321, 22.73820114], [69.70819092, 22.7381897], [69.70819092, 22.73791695], [69.70791626, 22.73792076], [69.70791626, 22.73736191], [69.7076416, 22.73736382], [69.7076416, 22.73596954], [69.70735931, 22.73596954], [69.70735931, 22.73514175], [69.70707703, 22.73514175], [69.70707703, 22.73485947], [69.70680237, 22.73485947], [69.70680237, 22.73374939], [69.70652771, 22.73374939], [69.70652771, 22.73236084], [69.70680237, 22.73236084], [69.70683289, 22.73069], [69.70708466, 22.73069382], [69.70708466, 22.73041725], [69.70745087, 22.73041725], [69.70819092, 22.73041725], [69.70819092, 22.73069382], [69.70874786, 22.73069382], [69.70874786, 22.73097229], [69.70930481, 22.73097229], [69.70930481, 22.73069382], [69.71013641, 22.73069382], [69.71013641, 22.72986031], [69.7095871, 22.72986031], [69.7095871, 22.72957993], [69.7092514, 22.72958183], [69.70847321, 22.72958374], [69.70847321, 22.72930527], [69.70707703, 22.72931099], [69.70707703, 22.72903061], [69.70597076, 22.72903061], [69.70597076, 22.72875023], [69.70569611, 22.72875023], [69.70569611, 22.72846985], [69.70541382, 22.72847176], [69.70541382, 22.72819519], [69.70513916, 22.72819519], [69.70513916, 22.72791672], [69.70347595, 22.72791672], [69.70347595, 22.72819519], [69.70319366, 22.72819519], [69.70319366, 22.72847176], [69.70291901, 22.72846985], [69.70291901, 22.72903061], [69.70318604, 22.72903061], [69.70318604, 22.72931099], [69.70347595, 22.72930527], [69.70347595, 22.72958374], [69.70485687, 22.72957993], [69.70485687, 22.72986031], [69.70513916, 22.72986031], [69.70513916, 22.73014069], [69.70540619, 22.73014069], [69.70540619, 22.73042107], [69.70569611, 22.73041725], [69.70569611, 22.73124123], [69.70569611, 22.73347282], [69.70597076, 22.73347282], [69.70597076, 22.7345829], [69.70625305, 22.7345829], [69.70625305, 22.73569489], [69.70652771, 22.73568916], [69.70652771, 22.73986053], [69.70625305, 22.73986053], [69.70625305, 22.74013901], [69.70597076, 22.74012947], [69.70597076, 22.74041939], [69.70541382, 22.74041748], [69.70541382, 22.74069595], [69.70375061, 22.74069595], [69.70375061, 22.74097252], [69.70291901, 22.74097252], [69.70291901, 22.74069595], [69.70180511, 22.74069595], [69.70180511, 22.74097252], [69.70041656, 22.74097061], [69.70041656, 22.74125099], [69.69819641, 22.74125099], [69.69819641, 22.74152946], [69.69763184, 22.74152946], [69.69763184, 22.74180984], [69.69708252, 22.74180412], [69.69708252, 22.7420826], [69.69680786, 22.74208069], [69.69680786, 22.74236107], [69.69457245, 22.74236107], [69.69457245, 22.74263954], [69.69374847, 22.74263954], [69.69374847, 22.74291992], [69.69291687, 22.74291611], [69.69291687, 22.74319458], [69.69264221, 22.74319458], [69.69264221, 22.74347305], [69.69208527, 22.74347305], [69.6920929, 22.74374962], [69.69180298, 22.74374962], [69.69180298, 22.74402809], [69.69097137, 22.74402618], [69.69097137, 22.74430466], [69.69041443, 22.74430466], [69.69041443, 22.74458313], [69.68985748, 22.74458313], [69.68985748, 22.7448616], [69.68958282, 22.7448597], [69.68958282, 22.74513817], [69.68930817, 22.74513817], [69.68930817, 22.74542046], [69.68875885, 22.74542046], [69.68875885, 22.74570084], [69.68846893, 22.74569511], [69.68846893, 22.74597168], [69.68818665, 22.74596977], [69.68818665, 22.7462616], [69.68736267, 22.7462616], [69.68736267, 22.74653053], [69.68681335, 22.74653053], [69.68681335, 22.74681091], [69.68653107, 22.74680519], [69.68653107, 22.74708366], [69.68624878, 22.74707985], [69.68624878, 22.74764061], [69.68597412, 22.74764061], [69.68597412, 22.74819374], [69.68486023, 22.74819374], [69.68486023, 22.74847031], [69.68458557, 22.74847031], [69.6845932, 22.74875259], [69.68430328, 22.74875259], [69.68430328, 22.74903107], [69.68402863, 22.74903107], [69.68402863, 22.74932289], [69.68374634, 22.74930573], [69.68374634, 22.7495842], [69.68347168, 22.74958038], [69.68347168, 22.74986267], [69.68319702, 22.74986267], [69.68319702, 22.75014114], [69.6829071, 22.75014114], [69.6829071, 22.75041962], [69.68235779, 22.7504158], [69.68235779, 22.75069427], [69.68208313, 22.75069427], [69.68208313, 22.75097275], [69.68152618, 22.75097275], [69.68152618, 22.75125122], [69.68125153, 22.75125122], [69.68125153, 22.75152969], [69.68096924, 22.75152969], [69.68096924, 22.75181007], [69.68068695, 22.75181007], [69.68068695, 22.75152969], [69.68041992, 22.75152969], [69.68041992, 22.75125122], [69.67958832, 22.75125122], [69.67958832, 22.75152969], [69.67930603, 22.75152969], [69.67930603, 22.75181007], [69.67903137, 22.75180626], [69.67903137, 22.75208473], [69.67874908, 22.75206947], [69.67874908, 22.75263977], [69.6784668, 22.75263977], [69.6784668, 22.75374985], [69.67819214, 22.75374985], [69.67819214, 22.75403023], [69.67791748, 22.75402832], [69.67791748, 22.75430679], [69.67763519, 22.75430679], [69.67763519, 22.75458336], [69.67736053, 22.75458336], [69.67736053, 22.75486183], [69.67708588, 22.75486183], [69.67708588, 22.7551384], [69.67624664, 22.75513077], [69.67624664, 22.75542068], [69.67514038, 22.75542068], [69.67514038, 22.75570107], [69.67485809, 22.75569534], [69.67485809, 22.75597191], [69.67402649, 22.75597], [69.67402649, 22.75625038], [69.67346954, 22.75625038], [69.67346954, 22.75708389], [69.67152405, 22.75708389], [69.67152405, 22.75680542], [69.66986084, 22.75680542], [69.66986084, 22.75708389], [69.66902924, 22.75708389], [69.66902924, 22.75680542], [69.66847229, 22.75681114], [69.66847229, 22.75653076], [69.66792297, 22.75653076], [69.66792297, 22.75625038], [69.66764069, 22.75625038], [69.66764069, 22.75597191], [69.66596985, 22.75597], [69.66596985, 22.75625038], [69.66513824, 22.75625038], [69.66513824, 22.75597], [69.66374969, 22.75597], [69.66374969, 22.75625038], [69.66319275, 22.75625038], [69.66319275, 22.75653076], [69.6626358, 22.75653076], [69.6626358, 22.75681114], [69.66236115, 22.75680542], [69.66236115, 22.75958252], [69.6626358, 22.75958061], [69.6626358, 22.76042175], [69.66291809, 22.76041603], [69.66291809, 22.76097107], [69.66319275, 22.76096916], [69.66319275, 22.76126289], [69.66347504, 22.76125145], [69.66348267, 22.76180077], [69.66374969, 22.76180649], [69.66374969, 22.76208115], [69.66401672, 22.76207924], [69.66401672, 22.76264191], [69.66430664, 22.76264191], [69.66430664, 22.76320076], [69.66458893, 22.76320076], [69.66458893, 22.76403046], [69.66486359, 22.76402855], [69.66486359, 22.76458359], [69.66513824, 22.76458359], [69.66513824, 22.76597214], [69.6654129, 22.76597023], [69.6654129, 22.76653099], [69.66569519, 22.76652718], [69.66569519, 22.7709713], [69.66596985, 22.7709713], [69.66596985, 22.77236176], [69.66569519, 22.77236176], [69.66569519, 22.77347183], [69.66596985, 22.77346992], [69.66596985, 22.77403069], [69.66625214, 22.77403069], [69.66625214, 22.77486229], [69.66652679, 22.77486229], [69.66652679, 22.77569389], [69.66680908, 22.77569389], [69.66680908, 22.77597046], [69.66708374, 22.77597046], [69.66708374, 22.77625275], [69.6673584, 22.7762394], [69.6673584, 22.77653122], [69.66708374, 22.7765274], [69.66708374, 22.77708054], [69.66680908, 22.77708054], [69.66680908, 22.77736282], [69.66625214, 22.77736282], [69.66625214, 22.77708054], [69.66569519, 22.77708054], [69.66569519, 22.77680588], [69.6654129, 22.77680969], [69.6654129, 22.77653122], [69.66513824, 22.77653122], [69.66513824, 22.7762394], [69.6645813, 22.77625275], [69.6645813, 22.77597046], [69.66430664, 22.77597046], [69.66430664, 22.77402687], [69.66401672, 22.77403069], [69.66401672, 22.77069092], [69.66430664, 22.77069473], [69.66430664, 22.76874924], [69.66401672, 22.76875114], [69.66401672, 22.76653099], [69.66374969, 22.76653099], [69.66374969, 22.76568985], [69.66347504, 22.76569366], [69.66347504, 22.76486206], [69.66319275, 22.76486206], [69.66319275, 22.76402855], [69.66291809, 22.76403046], [69.66291809, 22.7634697], [69.6626358, 22.76347351], [69.6626358, 22.76291656], [69.66236115, 22.76292038], [69.66236115, 22.76235962], [69.66208649, 22.76235962], [69.66208649, 22.76180649], [69.66179657, 22.7618103], [69.66179657, 22.76153183], [69.66152191, 22.76153183], [69.66152191, 22.76096916], [69.66124725, 22.76097107], [69.66124725, 22.76041603], [69.6609726, 22.76042175], [69.6609726, 22.75985909], [69.66069794, 22.75985909], [69.66069794, 22.75847054], [69.66014099, 22.75847244], [69.66014099, 22.75819397], [69.6598587, 22.75819969], [69.6598587, 22.75792122], [69.65957642, 22.75792122], [69.65957642, 22.75708008], [69.65930176, 22.75708389], [69.65930176, 22.75652695], [69.65875244, 22.75653076], [69.65875244, 22.75681114], [69.65791321, 22.75680542], [69.65791321, 22.75708389], [69.65735626, 22.75708008], [69.65735626, 22.75736046], [69.65651703, 22.75736046], [69.65651703, 22.75764084], [69.65598297, 22.75764084], [69.65598297, 22.75792122], [69.6554184, 22.75792122], [69.6554184, 22.75819969], [69.65513611, 22.75819397], [69.65513611, 22.75847244], [69.65486145, 22.75847054], [69.65486145, 22.75902748], [69.65458679, 22.75902748], [69.65458679, 22.75930977], [69.65402985, 22.75930595], [69.65402985, 22.75958252], [69.6534729, 22.75958061], [69.6534729, 22.75985909], [69.65319824, 22.75985909], [69.65319824, 22.76014137], [69.65291595, 22.76014137], [69.65291595, 22.76042175], [69.6526413, 22.76041603], [69.6526413, 22.7606945], [69.65235901, 22.7606945], [69.65235901, 22.76097107], [69.65207672, 22.76096916], [69.65207672, 22.76126289], [69.65180206, 22.76126289], [69.65180206, 22.76153183], [69.6515274, 22.76153183], [69.6515274, 22.7618103], [69.65125275, 22.76180649], [69.65125275, 22.76208115], [69.65097046, 22.76208115], [69.65097046, 22.76235962], [69.64985657, 22.76235962], [69.64985657, 22.76264191], [69.64930725, 22.76264191], [69.64930725, 22.76292038], [69.64848328, 22.76292038], [69.64848328, 22.76320076], [69.6479187, 22.76319504], [69.6479187, 22.76347351], [69.6470871, 22.7634697], [69.6470871, 22.76403046], [69.64680481, 22.76402855], [69.64680481, 22.76458359], [69.64652252, 22.76457977], [69.64652252, 22.76542091], [69.64597321, 22.7654171], [69.64597321, 22.76597214], [69.64485931, 22.76597214], [69.64485931, 22.76569366], [69.64319611, 22.76569366], [69.64319611, 22.76597214], [69.64290619, 22.76597023], [69.64290619, 22.76625061], [69.64263916, 22.76625061], [69.64263916, 22.76653099], [69.64290619, 22.76653099], [69.64290619, 22.76680946], [69.64263916, 22.76680946], [69.64263916, 22.76736069], [69.64235687, 22.76736069], [69.64235687, 22.76791954], [69.64208221, 22.76791763], [69.64208221, 22.76847267], [69.64180756, 22.76847076], [69.64180756, 22.76902962], [69.64152527, 22.76902771], [69.64152527, 22.76958275], [69.64125061, 22.76958084], [69.64125061, 22.76986122], [69.64097595, 22.76986122], [69.64097595, 22.77041817], [69.64069366, 22.77041626], [69.64069366, 22.77069473], [69.64041901, 22.77069092], [69.64041901, 22.77124977], [69.64013672, 22.77124977], [69.64013672, 22.77152824], [69.63986206, 22.77152634], [69.63986206, 22.77208328], [69.63957977, 22.77207947], [69.63957977, 22.77263832], [69.63931274, 22.77263832], [69.63931274, 22.77319908], [69.63903046, 22.77319908], [69.63903046, 22.7737484], [69.63874817, 22.7737484], [69.63874817, 22.77569389], [69.63846588, 22.77569008], [69.63846588, 22.77680969], [69.63791656, 22.77680588], [69.63791656, 22.77958488], [69.63764191, 22.77958488], [69.63764191, 22.77986145], [69.63735199, 22.77985954], [69.63735199, 22.78013992], [69.63707733, 22.78013992], [69.63707733, 22.78181076], [69.63735962, 22.78180695], [69.63735962, 22.78319359], [69.63764191, 22.78318977], [69.63764191, 22.78403091], [69.63735962, 22.7840271], [69.63735962, 22.78458405], [69.63764191, 22.78458023], [69.63764191, 22.78681183], [69.63735199, 22.78681183], [69.63735199, 22.7887516], [69.63708496, 22.7887516], [69.63708496, 22.78986359], [69.63680267, 22.78986168], [69.63680267, 22.79042053], [69.63652802, 22.79042053], [69.63652802, 22.79070282], [69.63625336, 22.79069519], [69.63625336, 22.79097366], [69.63597107, 22.79096985], [69.63597107, 22.79181099], [69.63569641, 22.79181099], [69.63569641, 22.79236031], [69.63540649, 22.79236031], [69.63540649, 22.79292107], [69.63513947, 22.79291725], [69.63513947, 22.79319572], [69.63486481, 22.79319572], [69.63486481, 22.79347229], [69.63430786, 22.79347229], [69.63430786, 22.7943058], [69.63402557, 22.7943058], [69.63402557, 22.79458427], [69.63375092, 22.79458046], [69.63375092, 22.79541969], [69.63318634, 22.79541969], [69.63318634, 22.79430008], [69.63346863, 22.7943058], [69.63346863, 22.79402733], [69.63375092, 22.79403114], [69.63375092, 22.79347038], [69.63402557, 22.79347229], [69.63402557, 22.79319572], [69.63430786, 22.79319572], [69.63430786, 22.79236031], [69.63458252, 22.79236031], [69.63458252, 22.79181099], [69.63485718, 22.79181099], [69.63485718, 22.7912426], [69.63513947, 22.79125023], [69.63513947, 22.79097366], [69.63541412, 22.79097366], [69.63541412, 22.79041672], [69.63597107, 22.79042053], [69.63597107, 22.78986168], [69.63625336, 22.78986359], [69.63625336, 22.7887516], [69.63652802, 22.7887516], [69.63652802, 22.7881794], [69.63680267, 22.78819466], [69.63680267, 22.78458405], [69.63652802, 22.78458405], [69.63652802, 22.78430557], [69.63625336, 22.78430939], [69.63625336, 22.78403091], [69.63597107, 22.78403091], [69.63597107, 22.78292084], [69.63569641, 22.78292084], [69.63569641, 22.78236008], [69.63513947, 22.78236198], [69.63513947, 22.78208351], [69.63486481, 22.78208351], [69.63486481, 22.78152847], [69.63458252, 22.78153038], [69.63458252, 22.78070068], [69.63430786, 22.78070068], [69.63430786, 22.77902985], [69.63458252, 22.77902985], [69.63458252, 22.77736282], [69.63485718, 22.77736282], [69.63485718, 22.77653122], [69.63513947, 22.77653122], [69.63513947, 22.77597046], [69.63541412, 22.77597046], [69.63541412, 22.77569389], [69.63569641, 22.77569389], [69.63569641, 22.77541733], [69.63597107, 22.77542114], [69.63597107, 22.77486229], [69.63625336, 22.77486229], [69.63625336, 22.77403069], [69.63652802, 22.77403069], [69.63652802, 22.7737484], [69.63680267, 22.7737484], [69.63680267, 22.77346992], [69.63708496, 22.77347183], [69.63708496, 22.77319527], [69.63735199, 22.77319908], [69.63735199, 22.77263832], [69.63764191, 22.77263832], [69.63764191, 22.77235985], [69.63791656, 22.77236176], [69.63791656, 22.77208328], [69.63819122, 22.77208328], [69.63819122, 22.77180481], [69.63847351, 22.77180481], [69.63847351, 22.7709713], [69.63874817, 22.7709713], [69.63874817, 22.77069473], [69.63903046, 22.77069473], [69.63903046, 22.77041626], [69.63931274, 22.77041817], [69.63931274, 22.76986122], [69.63957977, 22.76986122], [69.63957977, 22.76958084], [69.63986206, 22.76958275], [69.63986206, 22.76902771], [69.64013672, 22.76902962], [69.64013672, 22.76875114], [69.64041901, 22.76875114], [69.64041901, 22.76819038], [69.64069366, 22.7681942], [69.64069366, 22.76791573], [69.64097595, 22.76791954], [69.64097595, 22.76764107], [69.64125061, 22.76764107], [69.64125061, 22.76653099], [69.64068604, 22.76653099], [69.64068604, 22.76625061], [69.63986206, 22.76625061], [69.63986206, 22.76597023], [69.63957977, 22.76597214], [69.63957977, 22.7654171], [69.63874817, 22.7654171], [69.63874817, 22.76569366], [69.63847351, 22.76569366], [69.63847351, 22.76597214], [69.63791656, 22.76597214], [69.63791656, 22.76569366], [69.63735962, 22.76569366], [69.63735962, 22.7654171], [69.63625336, 22.76542091], [69.63625336, 22.76514053], [69.63485718, 22.76514053], [69.63485718, 22.76486015], [69.63430786, 22.76486206], [69.63430786, 22.76458359], [69.63346863, 22.76458359], [69.63346863, 22.76430511], [69.63263702, 22.76430511], [69.63263702, 22.76402855], [69.63181305, 22.76403046], [69.63181305, 22.76375008], [69.63096619, 22.76375008], [69.63096619, 22.7634697], [69.62958527, 22.76347351], [69.6295929, 22.76375008], [69.62902832, 22.76375008], [69.62902832, 22.76403046], [69.62847137, 22.76402855], [69.62847137, 22.76430511], [69.62791443, 22.76430511], [69.62791443, 22.76458359], [69.62708282, 22.76458359], [69.62708282, 22.76486206], [69.62625122, 22.76486015], [69.62625122, 22.76514053], [69.62458038, 22.76514053], [69.62458038, 22.76486015], [69.6220932, 22.76486015], [69.6220932, 22.76514053], [69.62180328, 22.76513863], [69.62180328, 22.76597214], [69.6220932, 22.76597023], [69.6220932, 22.76680946], [69.62180328, 22.76680565], [69.62180328, 22.76708412], [69.62152863, 22.76707077], [69.62152863, 22.76736069], [69.61958313, 22.76736069], [69.61958313, 22.76764107], [69.61736298, 22.76764107], [69.61736298, 22.76736069], [69.61624908, 22.76736069], [69.61624908, 22.76707077], [69.61486053, 22.76708412], [69.61486053, 22.76680565], [69.61458588, 22.76680946], [69.61458588, 22.76653099], [69.61429596, 22.76653099], [69.61429596, 22.76625061], [69.61402893, 22.76625061], [69.61402893, 22.76597023], [69.61291504, 22.76597214], [69.61292267, 22.76625061], [69.61207581, 22.76625061], [69.61207581, 22.76653099], [69.61125183, 22.76653099], [69.61125183, 22.76680946], [69.61068726, 22.76680946], [69.61068726, 22.76653099], [69.6104126, 22.76653099], [69.6104126, 22.76680946], [69.61013794, 22.76680565], [69.61013794, 22.76708412], [69.60930634, 22.76708412], [69.60930634, 22.76680565], [69.60901642, 22.76680946], [69.60901642, 22.76568985], [69.60930634, 22.76569366], [69.60930634, 22.7654171], [69.60958099, 22.76542091], [69.60958099, 22.76514053], [69.60986328, 22.76514053], [69.60986328, 22.76429939], [69.61013794, 22.76430511], [69.61013794, 22.76347351], [69.60986328, 22.76347351], [69.60986328, 22.76319504], [69.60958099, 22.76320076], [69.60958099, 22.76292038], [69.60930634, 22.76292038], [69.60930634, 22.76264191], [69.60901642, 22.76264191], [69.60901642, 22.76235962], [69.60874939, 22.76235962], [69.60874939, 22.76180649], [69.6084671, 22.7618103], [69.6084671, 22.76153183], [69.60735321, 22.76153183], [69.60735321, 22.76126289], [69.60542297, 22.76126289], [69.60542297, 22.76096916], [69.6048584, 22.76097107], [69.6048584, 22.7606945], [69.60375214, 22.7606945], [69.60375214, 22.76041603], [69.6020813, 22.76042175], [69.6020813, 22.76014137], [69.60124969, 22.76014137], [69.60124969, 22.75958061], [69.60097504, 22.75958252], [69.60097504, 22.75902748], [69.60069275, 22.75902748], [69.60069275, 22.75930977], [69.5993042, 22.75930595], [69.5993042, 22.75958252], [69.5973587, 22.75958061], [69.5973587, 22.75985909], [69.59680939, 22.75985909], [69.59680176, 22.76014137], [69.59625244, 22.76014137], [69.59625244, 22.76042175], [69.59513855, 22.76041603], [69.59513855, 22.7606945], [69.59486389, 22.7606945], [69.59486389, 22.76097107], [69.5945816, 22.76096916], [69.5945816, 22.76126289], [69.59401703, 22.76126289], [69.59401703, 22.76153183], [69.59179688, 22.76153183], [69.59179688, 22.7618103], [69.59152985, 22.76180649], [69.59152985, 22.76208115], [69.5909729, 22.76208115], [69.5909729, 22.76180649], [69.58985901, 22.76180649], [69.58985901, 22.76208115], [69.58930969, 22.76207924], [69.58930969, 22.76292038], [69.58847046, 22.76292038], [69.58847046, 22.76264191], [69.58708191, 22.76264191], [69.58708191, 22.76292038], [69.58624268, 22.76292038], [69.58624268, 22.76320076], [69.58597565, 22.76319504], [69.58597565, 22.76347351], [69.58569336, 22.7634697], [69.58569336, 22.76375008], [69.58429718, 22.76375008], [69.58429718, 22.76403046], [69.58374786, 22.76402855], [69.58374786, 22.76430511], [69.58319092, 22.76430511], [69.58319092, 22.76458359], [69.58291626, 22.76458359], [69.58291626, 22.76430511], [69.58208466, 22.76430511], [69.58208466, 22.76458359], [69.58152771, 22.76457977], [69.58152771, 22.76542091], [69.58125305, 22.7654171], [69.58125305, 22.76569366], [69.58097076, 22.76569366], [69.58097076, 22.7654171], [69.58040619, 22.76542091], [69.58040619, 22.76514053], [69.58013916, 22.76514053], [69.58013916, 22.76486015], [69.57930756, 22.76486015], [69.57930756, 22.76514053], [69.57875061, 22.76514053], [69.57875061, 22.76542091], [69.57818604, 22.76542091], [69.57818604, 22.76625061], [69.57847595, 22.76625061], [69.57847595, 22.76680946], [69.57819366, 22.76680565], [69.57819366, 22.76708412], [69.57707977, 22.76707077], [69.57707977, 22.76736069], [69.57457733, 22.76736069], [69.57457733, 22.76791954], [69.57402802, 22.76791763], [69.57402802, 22.7681942], [69.57375336, 22.7681942], [69.57375336, 22.76847267], [69.5715332, 22.76847076], [69.5715332, 22.76875114], [69.57124329, 22.76875114], [69.57124329, 22.76902962], [69.5715332, 22.76902962], [69.5715332, 22.76931], [69.57125092, 22.76930618], [69.57125092, 22.76958275], [69.57041931, 22.76958084], [69.57041931, 22.76986122], [69.56958008, 22.76986122], [69.56958008, 22.77013969], [69.56874847, 22.77013969], [69.56874847, 22.77041817], [69.56819153, 22.77041626], [69.56819153, 22.7709713], [69.56791687, 22.77096939], [69.56791687, 22.77124977], [69.56764221, 22.77124977], [69.56764221, 22.77152824], [69.56708527, 22.77152634], [69.56708527, 22.77180481], [69.56625366, 22.77180481], [69.56625366, 22.77208328], [69.56569672, 22.77208328], [69.56569672, 22.77236176], [69.56513977, 22.77235985], [69.56513977, 22.77263832], [69.56485748, 22.77263832], [69.56485748, 22.77292061], [69.56458282, 22.77292061], [69.56458282, 22.77319908], [69.56430817, 22.77319527], [69.56430817, 22.77347183], [69.56375122, 22.77346992], [69.56375122, 22.7737484], [69.56318665, 22.7737484], [69.56318665, 22.77403069], [69.56291962, 22.77403069], [69.56291962, 22.77430916], [69.56263733, 22.77430534], [69.56263733, 22.77458382], [69.56236267, 22.77457809], [69.56236267, 22.77486229], [69.56207275, 22.77486229], [69.56207275, 22.77514267], [69.56181335, 22.77514267], [69.56181335, 22.77542114], [69.56124878, 22.77541733], [69.56124878, 22.77569389], [69.56096649, 22.77569008], [69.56096649, 22.77680969], [69.56069183, 22.77680588], [69.56069183, 22.77708054], [69.56041718, 22.77708054], [69.56041718, 22.77736282], [69.56014252, 22.77736282], [69.56014252, 22.77763939], [69.55986023, 22.77763939], [69.55986023, 22.77736282], [69.55958557, 22.77736282], [69.5595932, 22.77763939], [69.55930328, 22.77763939], [69.55930328, 22.77819443], [69.55874634, 22.77819443], [69.55874634, 22.77847481], [69.55847168, 22.7784729], [69.55847168, 22.77874947], [69.55819702, 22.77874947], [69.55819702, 22.77902985], [69.55791473, 22.77902794], [69.55791473, 22.77930641], [69.55764008, 22.77930641], [69.55764008, 22.77986145], [69.55735779, 22.77985954], [69.55735779, 22.78013992], [69.55708313, 22.78013992], [69.55708313, 22.7804203], [69.55680847, 22.7804203], [69.55680847, 22.78070068], [69.55652618, 22.78070068], [69.55652618, 22.78125], [69.55625916, 22.78125], [69.55625916, 22.78153038], [69.55596924, 22.78153038], [69.55596924, 22.78181076], [69.55569458, 22.78180695], [69.55569458, 22.78208351], [69.55541992, 22.7820797], [69.55541992, 22.78264046], [69.55513763, 22.78264046], [69.55513763, 22.78292084], [69.55486298, 22.78291512], [69.55486298, 22.78347206], [69.55458069, 22.78347015], [69.55458069, 22.78375053], [69.55430603, 22.78375053], [69.55430603, 22.78403091], [69.55403137, 22.7840271], [69.55403137, 22.78458405], [69.55374908, 22.78458023], [69.55374908, 22.78486061], [69.5534668, 22.78486061], [69.5534668, 22.78513908], [69.55319977, 22.78513908], [69.55319977, 22.78543091], [69.55291748, 22.78541756], [69.55291748, 22.78569412], [69.55264282, 22.78569031], [69.55264282, 22.78652763], [69.55236053, 22.78652763], [69.55236053, 22.78708267], [69.55208588, 22.78708267], [69.55208588, 22.78819466], [69.55263519, 22.78819466], [69.55263519, 22.78847313], [69.55319214, 22.78847313], [69.55319214, 22.7887516], [69.55374908, 22.7887516], [69.55374908, 22.78903008], [69.55430603, 22.78902817], [69.55430603, 22.78930473], [69.55441284, 22.78930473], [69.55541992, 22.78930473], [69.55541992, 22.78947067], [69.55541992, 22.78986359], [69.55568695, 22.78986168], [69.55568695, 22.79014015], [69.55596924, 22.79014015], [69.55596924, 22.79042053], [69.55625916, 22.79042053], [69.55625916, 22.79153061], [69.55596924, 22.79153061], [69.55596924, 22.79181099], [69.55569458, 22.79180527], [69.55569458, 22.79208374], [69.55513763, 22.79207993], [69.55513763, 22.79236031], [69.55458069, 22.79236031], [69.55458069, 22.79207993], [69.55403137, 22.79207993], [69.55403137, 22.79236031], [69.5534668, 22.79236031], [69.5534668, 22.79207993], [69.55291748, 22.79208374], [69.55291748, 22.7915287], [69.55264282, 22.79153061], [69.55264282, 22.7912426], [69.55208588, 22.79125023], [69.55208588, 22.79097366], [69.55180359, 22.79097366], [69.55180359, 22.79041672], [69.55152893, 22.79042053], [69.55152893, 22.78957939], [69.55097198, 22.7895813], [69.55097198, 22.78902817], [69.55069733, 22.78903008], [69.55069733, 22.78866959], [69.55069733, 22.78819466], [69.55041504, 22.78819466], [69.55041504, 22.78791618], [69.55013275, 22.78792191], [69.55013275, 22.78652763], [69.54985809, 22.78652763], [69.54985809, 22.78624916], [69.54902649, 22.78624916], [69.54902649, 22.78652763], [69.54763794, 22.78652763], [69.54763794, 22.78624916], [69.54736328, 22.78624916], [69.54736328, 22.78597069], [69.54624939, 22.78597069], [69.54624939, 22.78624916], [69.54514313, 22.78624916], [69.54514313, 22.78597069], [69.54458618, 22.7859726], [69.54458618, 22.78569412], [69.54347229, 22.78569412], [69.54347229, 22.7859726], [69.54264069, 22.78597069], [69.54264069, 22.78624916], [69.54207611, 22.78624916], [69.54207611, 22.78652763], [69.54070282, 22.78652763], [69.54070282, 22.78624916], [69.54013824, 22.78624916], [69.54013824, 22.78652763], [69.53985596, 22.78652763], [69.53985596, 22.78624916], [69.5395813, 22.78624916], [69.5395813, 22.78652763], [69.53624725, 22.78652763], [69.53624725, 22.78681183], [69.53569794, 22.78681183], [69.53569794, 22.78652763], [69.53542328, 22.78652763], [69.53542328, 22.78681183], [69.53375244, 22.78680611], [69.53375244, 22.78708267], [69.53291321, 22.78708076], [69.53291321, 22.78735924], [69.53180695, 22.78735924], [69.53180695, 22.78764153], [69.53152466, 22.78764153], [69.53152466, 22.78847313], [69.53125, 22.78846931], [69.53125, 22.7887516], [69.53013611, 22.7887516], [69.53013611, 22.7881794], [69.52986145, 22.78819466], [69.52986145, 22.78791618], [69.52874756, 22.78791618], [69.52874756, 22.78819466], [69.5284729, 22.78819466], [69.5284729, 22.78847313], [69.52791595, 22.78847313], [69.52791595, 22.78930473], [69.5276413, 22.78930473], [69.5276413, 22.7895813], [69.52708435, 22.7895813], [69.52708435, 22.78930473], [69.52680206, 22.78930473], [69.52680206, 22.7895813], [69.5265274, 22.7895813], [69.5265274, 22.78986359], [69.52485657, 22.78986168], [69.52485657, 22.79014015], [69.52348328, 22.79014015], [69.52348328, 22.79042053], [69.52124786, 22.79042053], [69.52124786, 22.79070282], [69.52041626, 22.79070282], [69.52041626, 22.79014015], [69.51790619, 22.79014015], [69.51790619, 22.79042053], [69.51680756, 22.79042053], [69.51680756, 22.79070282], [69.51597595, 22.79069519], [69.51597595, 22.79097366], [69.51541901, 22.79097366], [69.51541901, 22.79069519], [69.51513672, 22.79070282], [69.51513672, 22.79014015], [69.51486206, 22.79014015], [69.51486206, 22.78986168], [69.51403046, 22.78986359], [69.51403046, 22.7895813], [69.51374817, 22.7895813], [69.51374817, 22.78930473], [69.51319122, 22.78930473], [69.51319122, 22.78902817], [69.51291656, 22.78902817], [69.51291656, 22.78930473], [69.51235962, 22.78930473], [69.51235962, 22.78902817], [69.51152802, 22.78903008], [69.51152802, 22.7881794], [69.51097107, 22.78819466], [69.51097107, 22.78791618], [69.50930786, 22.78792191], [69.50930786, 22.78764153], [69.5041275, 22.78764153], [69.50096893, 22.78764153], [69.50096893, 22.78735924], [69.49736023, 22.78735924], [69.49736023, 22.78764153], [69.4970932, 22.78764153], [69.4970932, 22.78792191], [69.49595642, 22.78792191], [69.49595642, 22.78764153], [69.49569702, 22.78764153], [69.49569702, 22.78735924], [69.49485779, 22.78735924], [69.49485779, 22.78764153], [69.49458313, 22.78764153], [69.49458313, 22.78792191], [69.49291992, 22.78792191], [69.49291992, 22.78764153], [69.49236298, 22.78764153], [69.49236298, 22.78735924], [69.49180603, 22.78735924], [69.49180603, 22.78708076], [69.49124908, 22.78708267], [69.49124908, 22.78680611], [69.4909668, 22.78681183], [69.4909668, 22.78652763], [69.49069214, 22.78652763], [69.49069214, 22.78681183], [69.49013519, 22.78680611], [69.49014282, 22.78735924], [69.48986053, 22.78735924], [69.48986053, 22.78764153], [69.48819733, 22.78764153], [69.48819733, 22.78735924], [69.48596954, 22.78735924], [69.48596954, 22.78708076], [69.48542023, 22.78708076], [69.48542023, 22.78792191], [69.48458099, 22.78792191], [69.48458099, 22.78764153], [69.48430634, 22.78764153], [69.48430634, 22.78735924], [69.48401642, 22.78735924], [69.48401642, 22.78681183], [69.4834671, 22.78681183], [69.4834671, 22.78652763], [69.48319244, 22.78652763], [69.48319244, 22.78624916], [69.48291779, 22.78624916], [69.48291779, 22.78597069], [69.4826355, 22.7859726], [69.4826355, 22.78569412], [69.48402405, 22.78569412], [69.48402405, 22.7859726], [69.48458099, 22.78597069], [69.48458099, 22.78624916], [69.48542023, 22.78624916], [69.48542023, 22.78597069], [69.48625183, 22.78597069], [69.48625183, 22.78624916], [69.48707581, 22.78624916], [69.48707581, 22.78597069], [69.48735809, 22.7859726], [69.48735809, 22.78569412], [69.48764038, 22.78569412], [69.48764038, 22.78513718], [69.48792267, 22.78513908], [69.48792267, 22.78486061], [69.48819733, 22.78486061], [69.48819733, 22.78458023], [69.48874664, 22.78458405], [69.48874664, 22.78430557], [69.48902893, 22.78430939], [69.48902893, 22.78403091], [69.48986053, 22.78403091], [69.48986053, 22.78375053], [69.49041748, 22.78375053], [69.49041748, 22.78347015], [69.49263763, 22.78347206], [69.49263763, 22.78319359], [69.49319458, 22.78319359], [69.49319458, 22.78291512], [69.49346924, 22.78292084], [69.49346924, 22.78264046], [69.49375153, 22.78264046], [69.49375153, 22.7820797], [69.49402618, 22.78208351], [69.49402618, 22.78152847], [69.49375153, 22.78153038], [69.49375153, 22.78125], [69.49346924, 22.78125], [69.49346924, 22.78153038], [69.49291992, 22.78153038], [69.49291992, 22.78181076], [69.49263763, 22.78181076], [69.49263763, 22.78153038], [69.49180603, 22.78153038], [69.49180603, 22.78125], [69.49153137, 22.78125], [69.49153137, 22.78096962], [69.49069214, 22.78097153], [69.49069214, 22.78069305], [69.49014282, 22.78070068], [69.49014282, 22.7804203], [69.48958588, 22.7804203], [69.48958588, 22.78013992], [69.48792267, 22.78013992], [69.48792267, 22.77985954], [69.48764038, 22.77986145], [69.48764038, 22.77958488], [69.48735809, 22.77958488], [69.48735809, 22.77930641], [69.48652649, 22.77930641], [69.48652649, 22.77902794], [69.48596954, 22.77902985], [69.48596954, 22.77874947], [69.48568726, 22.77874947], [69.48568726, 22.77791977], [69.48486328, 22.77791977], [69.48486328, 22.77763939], [69.48374939, 22.77763939], [69.48374939, 22.77736282], [69.48179626, 22.77736282], [69.48179626, 22.77708054], [69.48152924, 22.77708054], [69.48152924, 22.77680588], [69.48097992, 22.77680969], [69.48097992, 22.77653122], [69.48069763, 22.77653122], [69.48069763, 22.7762394], [69.48041534, 22.77625275], [69.48041534, 22.77597046], [69.48014069, 22.77597046], [69.48014069, 22.77569389], [69.47958374, 22.77569389], [69.47958374, 22.77541733], [69.47930908, 22.77542114], [69.47930908, 22.77514267], [69.47846985, 22.77514267], [69.47846985, 22.77486229], [69.47735596, 22.77486229], [69.47735596, 22.77457809], [69.47458649, 22.77458382], [69.47458649, 22.77430534], [69.47402954, 22.77430916], [69.47402954, 22.77403069], [69.47374725, 22.77403069], [69.47374725, 22.77346992], [69.4723587, 22.77346992], [69.4723587, 22.7737484], [69.4715271, 22.7737484], [69.4715271, 22.77403069], [69.46985626, 22.77403069], [69.46985626, 22.7737484], [69.4695816, 22.7737484], [69.4695816, 22.77403069], [69.46930695, 22.77403069], [69.46930695, 22.77430916], [69.46875, 22.77430534], [69.46875, 22.77458382], [69.46847534, 22.77458382], [69.46848297, 22.77486229], [69.46819305, 22.77486229], [69.46819305, 22.77542114], [69.46763611, 22.77541733], [69.46763611, 22.77569389], [69.46708679, 22.77569389], [69.46708679, 22.77597046], [69.46569824, 22.77597046], [69.46569824, 22.77625275], [69.4651413, 22.7762394], [69.4651413, 22.77653122], [69.46457672, 22.77653122], [69.46457672, 22.77680969], [69.46430206, 22.77680969], [69.46430206, 22.77736282], [69.46347046, 22.77736282], [69.46347046, 22.77763939], [69.46290588, 22.77763939], [69.46290588, 22.77791977], [69.46208191, 22.77791595], [69.46208191, 22.77819443], [69.46152496, 22.77819443], [69.46152496, 22.77847481], [69.46125031, 22.7784729], [69.46125031, 22.77874947], [69.46069336, 22.77874947], [69.46069336, 22.77902985], [69.45986176, 22.77902794], [69.45986176, 22.77930641], [69.45735931, 22.77930641], [69.45735931, 22.77958488], [69.45569611, 22.77958488], [69.45569611, 22.77930641], [69.45513916, 22.77930641], [69.45513916, 22.77902794], [69.45430756, 22.77902794], [69.45430756, 22.77930641], [69.45263672, 22.77930641], [69.45263672, 22.77958488], [69.45097351, 22.77958488], [69.45097351, 22.77986145], [69.45014191, 22.77986145], [69.44930267, 22.77985954], [69.44930267, 22.78013992], [69.4465332, 22.78013992], [69.4465332, 22.7804203], [69.44625092, 22.7804203], [69.44625092, 22.78070068], [69.44596863, 22.78070068], [69.44596863, 22.78125], [69.44568634, 22.78125], [69.44568634, 22.78181076], [69.44541931, 22.78180695], [69.44541931, 22.78208351], [69.44513702, 22.78208351], [69.44513702, 22.78236198], [69.44487, 22.78236008], [69.44487, 22.78264046], [69.44458008, 22.78264046], [69.44458008, 22.78292084], [69.44430542, 22.78291512], [69.44430542, 22.78319359], [69.44374847, 22.78319359], [69.44374847, 22.78347206], [69.44319153, 22.78347015], [69.44319153, 22.78375053], [69.44291687, 22.78375053], [69.44291687, 22.78430939], [69.44208527, 22.78430557], [69.44208527, 22.78458405], [69.44180298, 22.78458405], [69.44181061, 22.78486061], [69.44152832, 22.78486061], [69.44152832, 22.78513908], [69.4404068, 22.78513908], [69.4404068, 22.78543091], [69.44013977, 22.78541756], [69.44013977, 22.78569412], [69.43958282, 22.78569412], [69.43958282, 22.7859726], [69.43930817, 22.78597069], [69.43930817, 22.78624916], [69.43873596, 22.78624916], [69.43873596, 22.78652763], [69.43846893, 22.78652763], [69.43846893, 22.78681183], [69.43819427, 22.78680611], [69.43819427, 22.78708267], [69.43763733, 22.78708076], [69.43763733, 22.78735924], [69.43736267, 22.78735924], [69.43736267, 22.78764153], [69.43681335, 22.78764153], [69.43681335, 22.78792191], [69.43653107, 22.78791618], [69.43653107, 22.78819466], [69.43569183, 22.78819466], [69.43569183, 22.78847313], [69.43514252, 22.78846931], [69.43514252, 22.7887516], [69.43430328, 22.7887516], [69.43430328, 22.78903008], [69.43347168, 22.78902817], [69.43347168, 22.78930473], [69.43291473, 22.78930473], [69.43291473, 22.7895813], [69.43208313, 22.7895813], [69.43208313, 22.78986359], [69.43152618, 22.78986168], [69.43152618, 22.79014015], [69.43096924, 22.79014015], [69.43096924, 22.79042053], [69.43068695, 22.79042053], [69.43068695, 22.79070282], [69.43013763, 22.79069519], [69.43013763, 22.79097366], [69.42958069, 22.79097366], [69.42958069, 22.79125023], [69.42930603, 22.7912426], [69.42930603, 22.79153061], [69.42903137, 22.79153061], [69.42903137, 22.79181099], [69.42874908, 22.79180527], [69.42874908, 22.79208374], [69.4284668, 22.79207993], [69.4284668, 22.79236031], [69.42819214, 22.79236031], [69.42819214, 22.79264069], [69.42791748, 22.79264069], [69.42791748, 22.79292107], [69.42763519, 22.79291725], [69.42763519, 22.79319572], [69.42736053, 22.79319572], [69.42736053, 22.79347229], [69.42708588, 22.79347038], [69.42708588, 22.79375076], [69.42679596, 22.79375076], [69.42679596, 22.79403114], [69.42652893, 22.79402733], [69.42652893, 22.7943058], [69.42624664, 22.7943058], [69.42624664, 22.79458427], [69.42597198, 22.79458046], [69.42597198, 22.79486084], [69.42569733, 22.79486084], [69.42569733, 22.79514122], [69.42542267, 22.79514122], [69.42542267, 22.79541969], [69.42485809, 22.79541588], [69.42485809, 22.79569435], [69.42458344, 22.79569435], [69.42458344, 22.79597282], [69.42402649, 22.79597092], [69.42402649, 22.79624939], [69.42373657, 22.79624939], [69.42373657, 22.79652977], [69.42318726, 22.79652977], [69.42318726, 22.79681015], [69.42292023, 22.79680634], [69.42292023, 22.7970829], [69.42236328, 22.79708099], [69.42236328, 22.79737091], [69.42208099, 22.79737091], [69.42208099, 22.79763985], [69.42151642, 22.79763985], [69.42151642, 22.79792023], [69.42124939, 22.79791641], [69.42124939, 22.79819489], [69.42069244, 22.79819489], [69.42069244, 22.79847145], [69.42041779, 22.79846954], [69.42041779, 22.79874992], [69.41986084, 22.79874992], [69.41986084, 22.7990284], [69.41958618, 22.7990284], [69.41958618, 22.79931068], [69.41874695, 22.79930496], [69.41874695, 22.79958344], [69.41819763, 22.79958344], [69.41819763, 22.79986191], [69.41764069, 22.79985809], [69.41764069, 22.80013847], [69.41596985, 22.80013847], [69.41596985, 22.8006897], [69.41569519, 22.80069542], [69.41569519, 22.80097008], [69.4154129, 22.80096817], [69.4154129, 22.80124855], [69.41513824, 22.80124855], [69.41513824, 22.80153275], [69.41485596, 22.80153275], [69.41485596, 22.80181122], [69.41430664, 22.8018055], [69.41430664, 22.80208397], [69.41374969, 22.80208015], [69.41374969, 22.80236244], [69.41291809, 22.80236244], [69.41291809, 22.80264282], [69.41208649, 22.80264282], [69.41208649, 22.80291939], [69.41152954, 22.80291748], [69.41152954, 22.80319214], [69.4109726, 22.80319214], [69.4109726, 22.80347252], [69.41069794, 22.80347252], [69.41069794, 22.8037529], [69.41042328, 22.8037529], [69.41042328, 22.80402946], [69.4098587, 22.80402946], [69.4098587, 22.80430984], [69.40958405, 22.80430603], [69.40958405, 22.8045845], [69.40930939, 22.80458069], [69.40930176, 22.80486107], [69.40847015, 22.80486107], [69.40847015, 22.80513954], [69.40791321, 22.80513954], [69.40791321, 22.80541992], [69.40736389, 22.80541611], [69.40736389, 22.80569458], [69.40680695, 22.80569458], [69.40680695, 22.80597305], [69.40652466, 22.80597305], [69.40652466, 22.80624962], [69.40570068, 22.80624008], [69.40570068, 22.80653], [69.40458679, 22.80652809], [69.40458679, 22.80680466], [69.40402985, 22.80680466], [69.40402985, 22.80708313], [69.4034729, 22.80708313], [69.4034729, 22.8073616], [69.40291595, 22.8073597], [69.40291595, 22.80764008], [69.40235901, 22.80764008], [69.40235901, 22.80820084], [69.40208435, 22.80819511], [69.40208435, 22.80847168], [69.40180206, 22.80846977], [69.40180206, 22.80875015], [69.4015274, 22.80875015], [69.4015274, 22.80903053], [69.40040588, 22.80903053], [69.40040588, 22.80931091], [69.39930725, 22.80930519], [69.39930725, 22.80958366], [69.39875031, 22.80957985], [69.39875031, 22.80986023], [69.39819336, 22.80986023], [69.39819336, 22.81014061], [69.39763641, 22.81014061], [69.39763641, 22.81042099], [69.3970871, 22.81041718], [69.3970871, 22.81069374], [69.39653015, 22.81069374], [69.39653015, 22.81097221], [69.39597321, 22.81097031], [69.39597321, 22.81125069], [69.39541626, 22.81125069], [69.39541626, 22.81153107], [69.39457703, 22.81153107], [69.39457703, 22.81180954], [69.39402771, 22.81180573], [69.39402771, 22.8120842], [69.39347076, 22.81208038], [69.39347076, 22.81236839], [69.39290619, 22.81236839], [69.39290619, 22.81263924], [69.39235687, 22.81263924], [69.39235687, 22.81291962], [69.39180756, 22.8129158], [69.39180756, 22.81319427], [69.39125061, 22.81319427], [69.39125061, 22.81347275], [69.39070129, 22.81347084], [69.39070129, 22.81374931], [69.38986206, 22.81374931], [69.38986206, 22.8140316], [69.38903046, 22.8140316], [69.38903046, 22.81431007], [69.38486481, 22.81430626], [69.38486481, 22.81458282], [69.38402557, 22.81458282], [69.38402557, 22.81485939], [69.38346863, 22.81485939], [69.38346863, 22.81514168], [69.38263702, 22.81514168], [69.38263702, 22.81541634], [69.38208008, 22.81541634], [69.38208008, 22.81569481], [69.38153076, 22.81569481], [69.38153076, 22.81596947], [69.38041687, 22.81596947], [69.38041687, 22.81625175], [69.3795929, 22.81625175], [69.3795929, 22.81653023], [69.37847137, 22.81652832], [69.37847137, 22.81680489], [69.37763977, 22.81680489], [69.37763977, 22.81708336], [69.37652588, 22.81708336], [69.37652588, 22.81736374], [69.37568665, 22.81736183], [69.37568665, 22.8176403], [69.37513733, 22.8176403], [69.37513733, 22.81792068], [69.37403107, 22.81792068], [69.37403107, 22.81820107], [69.37347412, 22.81819534], [69.37347412, 22.81847382], [69.37152863, 22.81847], [69.37152863, 22.81875038], [69.37097168, 22.81875038], [69.37097168, 22.81903076], [69.37069702, 22.81903076], [69.37069702, 22.81931114], [69.36875153, 22.81930542], [69.36875153, 22.8195858], [69.36736298, 22.81958008], [69.36736298, 22.81986046], [69.36653137, 22.81986046], [69.36653137, 22.82014084], [69.3659668, 22.82014084], [69.3659668, 22.82042122], [69.36514282, 22.82042122], [69.36514282, 22.82014084], [69.36486053, 22.82014084], [69.36486053, 22.82042122], [69.36430359, 22.8204174], [69.36430359, 22.82069588], [69.36374664, 22.82069588], [69.36374664, 22.82097244], [69.36264038, 22.82097054], [69.36264038, 22.82125092], [69.36208344, 22.82125092], [69.36208344, 22.82208252], [69.36180878, 22.82208061], [69.36180878, 22.82236099], [69.36125183, 22.82236099], [69.36125183, 22.82263947], [69.36068726, 22.82263947], [69.36068726, 22.82236099], [69.36013794, 22.82236099], [69.36013794, 22.82263947], [69.35819244, 22.82263947], [69.35819244, 22.82236099], [69.35791779, 22.82236099], [69.35791779, 22.82208061], [69.35652924, 22.82208252], [69.35652924, 22.82180405], [69.35597229, 22.82180977], [69.35597229, 22.82154083], [69.35542297, 22.82154083], [69.35542297, 22.82125092], [69.35514069, 22.82125092], [69.35514069, 22.81986046], [69.35458374, 22.81986046], [69.35458374, 22.8195858], [69.35430908, 22.8195858], [69.35430908, 22.81902695], [69.35402679, 22.81903076], [69.35402679, 22.81875038], [69.35375214, 22.81875038], [69.35375214, 22.81847], [69.35319519, 22.81847382], [69.35319519, 22.81819534], [69.3529129, 22.81820107], [69.3529129, 22.81792068], [69.35235596, 22.81792068], [69.35235596, 22.8176403], [69.3520813, 22.8176403], [69.3520813, 22.81820107], [69.35180664, 22.81820107], [69.35180664, 22.81903076], [69.35152435, 22.81902695], [69.35152435, 22.8195858], [69.35180664, 22.81958008], [69.35180664, 22.81986046], [69.3520813, 22.81986046], [69.3520813, 22.82014084], [69.35235596, 22.82014084], [69.35235596, 22.82042122], [69.35263824, 22.8204174], [69.35263824, 22.82069588], [69.3529129, 22.82069016], [69.3529129, 22.82125092], [69.35320282, 22.82125092], [69.35320282, 22.82154083], [69.35346985, 22.82154083], [69.35346985, 22.82180977], [69.35375214, 22.82180977], [69.35375214, 22.82291985], [69.35402679, 22.82291985], [69.35402679, 22.82374954], [69.35430908, 22.82374954], [69.35430908, 22.82486153], [69.35459137, 22.82485962], [69.35459137, 22.82570076], [69.3548584, 22.82570076], [69.3548584, 22.82624817], [69.35514069, 22.82624817], [69.35514069, 22.82653046], [69.35542297, 22.82653046], [69.35542297, 22.82681084], [69.35569763, 22.82680511], [69.35569763, 22.82735825], [69.35597229, 22.82736015], [69.35597229, 22.82847023], [69.35569763, 22.82847023], [69.35569763, 22.82875252], [69.35514069, 22.82875252], [69.35514069, 22.82847023], [69.3548584, 22.82847023], [69.3548584, 22.8279171], [69.35459137, 22.82792091], [69.35459137, 22.82763863], [69.35430908, 22.82763863], [69.35430908, 22.82735062], [69.35319519, 22.82736015], [69.35319519, 22.82680511], [69.3529129, 22.82681084], [69.3529129, 22.82653046], [69.35263824, 22.82653046], [69.35263824, 22.8259697], [69.35236359, 22.8259716], [69.35236359, 22.82374954], [69.3520813, 22.82374954], [69.3520813, 22.82347107], [69.35152435, 22.82347298], [69.35152435, 22.8231945], [69.35124969, 22.8231945], [69.35124969, 22.82236099], [69.35097504, 22.82236099], [69.35097504, 22.82180405], [69.35069275, 22.82180977], [69.35069275, 22.82069016], [69.3484726, 22.82069588], [69.3484726, 22.8204174], [69.34680939, 22.8204174], [69.34680176, 22.82069588], [69.34597015, 22.82069588], [69.34597015, 22.82097244], [69.3456955, 22.82097244], [69.34571075, 22.82125092], [69.34513855, 22.82125092], [69.34513855, 22.82154083], [69.3445816, 22.82154083], [69.3445816, 22.82180977], [69.34430695, 22.82180405], [69.34430695, 22.82208252], [69.34402466, 22.82208252], [69.34402466, 22.82180405], [69.34347534, 22.82180405], [69.34347534, 22.82208252], [69.3429184, 22.82208061], [69.3429184, 22.82236099], [69.34263611, 22.82236099], [69.34265137, 22.82263947], [69.34208679, 22.82263947], [69.34208679, 22.82291985], [69.3418045, 22.82291794], [69.3418045, 22.8231945], [69.34152985, 22.8231945], [69.34152985, 22.82347298], [69.34124756, 22.82347107], [69.34124756, 22.82374954], [69.34069824, 22.82374954], [69.34069824, 22.82402992], [69.3401413, 22.82402992], [69.3401413, 22.8243103], [69.33985901, 22.82430649], [69.33985901, 22.82458305], [69.33930206, 22.82458305], [69.33930206, 22.82486153], [69.33875275, 22.82485962], [69.33875275, 22.82513809], [69.3381958, 22.82513809], [69.3381958, 22.82542038], [69.33763885, 22.82542038], [69.33763885, 22.82570076], [69.33708191, 22.82569504], [69.33708191, 22.8259716], [69.33680725, 22.8259697], [69.33680725, 22.82624817], [69.33625031, 22.82624817], [69.33625031, 22.82653046], [69.33598328, 22.82653046], [69.33598328, 22.82681084], [69.3354187, 22.82680511], [69.3354187, 22.82708359], [69.33486176, 22.82708359], [69.33486176, 22.82736015], [69.33403015, 22.82735062], [69.33403015, 22.82763863], [69.33235931, 22.82763863], [69.33235931, 22.82792091], [69.33180237, 22.8279171], [69.33180237, 22.82819366], [69.33152771, 22.82819366], [69.33152771, 22.82847023], [69.33125305, 22.82847023], [69.33125305, 22.82875252], [69.32958221, 22.82875252], [69.32958221, 22.8290329], [69.32930756, 22.8290329], [69.32930756, 22.82930946], [69.32847595, 22.82930565], [69.32847595, 22.82958412], [69.32707977, 22.82958031], [69.32707977, 22.82986259], [69.32624817, 22.82986259], [69.32624817, 22.83014107], [69.32597351, 22.83013916], [69.32597351, 22.83041573], [69.32514191, 22.83041763], [69.32514191, 22.8306942], [69.32375336, 22.8306942], [69.32375336, 22.83097267], [69.32263947, 22.83097267], [69.32263947, 22.83125114], [69.32125092, 22.83125114], [69.32125092, 22.83152962], [69.32068634, 22.83152962], [69.32068634, 22.83125114], [69.32013702, 22.83125114], [69.32013702, 22.83152962], [69.31958008, 22.83152962], [69.31958008, 22.83181], [69.31930542, 22.83180618], [69.31930542, 22.83208466], [69.31874847, 22.83208084], [69.31874847, 22.83236122], [69.31430817, 22.83236122], [69.31430817, 22.83263969], [69.31402588, 22.83263969], [69.31402588, 22.83236122], [69.31263733, 22.83236122], [69.31263733, 22.83263969], [69.31153107, 22.83263969], [69.31153107, 22.83236122], [69.30374908, 22.83236122], [69.30374908, 22.83208084], [69.30319214, 22.83208084], [69.30319214, 22.83236122], [69.30263519, 22.83236122], [69.30263519, 22.83208466], [69.30236053, 22.83208084], [69.30236053, 22.83236122], [69.30069733, 22.83236122], [69.30069733, 22.83208084], [69.30041504, 22.83208466], [69.30041504, 22.83180618], [69.30014038, 22.83181], [69.30014038, 22.83152962], [69.29957581, 22.83152962], [69.29957581, 22.83125114], [69.29930878, 22.83125114], [69.29930878, 22.83097267], [69.29846954, 22.83097267], [69.29846954, 22.8306942], [69.29763794, 22.8306942], [69.29763794, 22.83041763], [69.29652405, 22.83041573], [69.29652405, 22.83013916], [69.2959671, 22.83014107], [69.2959671, 22.82986259], [69.29541779, 22.82986259], [69.29541779, 22.82958031], [69.29430389, 22.82958412], [69.29430389, 22.82930565], [69.29319763, 22.82930946], [69.29319763, 22.8290329], [69.29180908, 22.8290329], [69.29180908, 22.82875252], [69.29096985, 22.82875252], [69.29096985, 22.82847023], [69.2895813, 22.82847023], [69.2895813, 22.82819366], [69.28902435, 22.82819366], [69.28902435, 22.8279171], [69.28817749, 22.82792091], [69.28817749, 22.82763863], [69.28736115, 22.82763863], [69.28736115, 22.82735062], [69.28652954, 22.82736015], [69.28652954, 22.82708359], [69.28569794, 22.82708359], [69.28569794, 22.82680511], [69.28430176, 22.82681084], [69.28430176, 22.82653046], [69.28237152, 22.82653046], [69.28237152, 22.82624817], [69.28013611, 22.82624817], [69.28013611, 22.8259697], [69.2765274, 22.8259716], [69.2765274, 22.82569504], [69.27402496, 22.82569504], [69.27402496, 22.8259716], [69.27347565, 22.8259716], [69.27347565, 22.82569504], [69.2731781, 22.82570076], [69.2731781, 22.82542038], [69.27179718, 22.82542038], [69.27179718, 22.82513809], [69.27043152, 22.82513809], [69.27043152, 22.82485962], [69.26875305, 22.82486153], [69.26875305, 22.82458305], [69.26847076, 22.82458305], [69.26847076, 22.82430649], [69.26737213, 22.8243103], [69.26737213, 22.82402992], [69.26680756, 22.82402992], [69.26680756, 22.8243103], [69.26625061, 22.82430649], [69.26625061, 22.82458305], [69.26597595, 22.82458305], [69.26597595, 22.82486153], [69.26569366, 22.82486153], [69.26569366, 22.82458305], [69.26541901, 22.82458305], [69.26541901, 22.82486153], [69.26513672, 22.82485962], [69.26513672, 22.82513809], [69.26486206, 22.82513809], [69.26486206, 22.82542038], [69.26429749, 22.82542038], [69.26429749, 22.82570076], [69.26347351, 22.82569504], [69.26347351, 22.8259716], [69.26291656, 22.8259697], [69.26291656, 22.82624817], [69.26207733, 22.82624817], [69.26207733, 22.82653046], [69.26152802, 22.82653046], [69.26152802, 22.82681084], [69.26097107, 22.82680511], [69.26097107, 22.82708359], [69.26041412, 22.82708359], [69.26041412, 22.82736015], [69.26013947, 22.82736015], [69.26013947, 22.82748032], [69.26013947, 22.82763863], [69.25961304, 22.82763863], [69.25902557, 22.82763863], [69.2590332, 22.82781982], [69.2590332, 22.82792091], [69.25869751, 22.82792091], [69.25736237, 22.8279171], [69.25736237, 22.82819366], [69.25597382, 22.82819366], [69.25597382, 22.82847023], [69.25514221, 22.82847023], [69.25514221, 22.82875252], [69.25402832, 22.82875252], [69.25402832, 22.8290329], [69.2529068, 22.8290329], [69.2529068, 22.82930946], [69.25180817, 22.82930565], [69.25180817, 22.82958412], [69.25013733, 22.82958031], [69.25013733, 22.82986259], [69.24861908, 22.82986259], [69.2470932, 22.82986259], [69.2470932, 22.83014107], [69.24652863, 22.83013916], [69.24652863, 22.83041573], [69.24597168, 22.83041763], [69.24597168, 22.8306942], [69.24541473, 22.8306942], [69.24541473, 22.83097267], [69.24485779, 22.83097267], [69.24485779, 22.83125114], [69.24430847, 22.83125114], [69.24430847, 22.83152962], [69.24402618, 22.83152962], [69.24402618, 22.83125114], [69.24346924, 22.83125114], [69.24346924, 22.83152962], [69.24263763, 22.83152962], [69.24263763, 22.83181], [69.24153137, 22.83180618], [69.24153137, 22.83208466], [69.24069214, 22.83208084], [69.24069214, 22.83236122], [69.23986053, 22.83236122], [69.23986053, 22.83263969], [69.23929596, 22.83263969], [69.23929596, 22.83292007], [69.23819733, 22.83291626], [69.23819733, 22.83319473], [69.23764038, 22.83319092], [69.23764038, 22.83348083], [69.23652649, 22.83348083], [69.23652649, 22.83319092], [69.23625183, 22.83319092], [69.23625183, 22.83348083], [69.23542023, 22.83348083], [69.23542023, 22.83319092], [69.23513794, 22.83319092], [69.23513794, 22.83348083], [69.23458099, 22.83348083], [69.23458099, 22.83374977], [69.23432159, 22.83374977], [69.23432159, 22.83403015], [69.2326355, 22.83402824], [69.2326355, 22.83430672], [69.23208618, 22.83430672], [69.23208618, 22.83458328], [69.23069763, 22.83457947], [69.23069763, 22.83514023], [69.23041534, 22.83513832], [69.23041534, 22.83597183], [69.23014069, 22.83596992], [69.23014069, 22.83764076], [69.2298584, 22.83764076], [69.2298584, 22.83792114], [69.23014069, 22.83792114], [69.23014069, 22.83903122], [69.2298584, 22.83903122], [69.2298584, 22.83930969], [69.23014069, 22.83930969], [69.23014069, 22.84042168], [69.2298584, 22.84041595], [69.2298584, 22.84069443], [69.22958374, 22.84069443], [69.22958374, 22.8409729], [69.22930908, 22.84096909], [69.22930908, 22.84124947], [69.22902679, 22.84124947], [69.22902679, 22.84153175], [69.22875214, 22.84152985], [69.22875214, 22.84208107], [69.22846985, 22.84208107], [69.22846985, 22.84235954], [69.22819519, 22.84235954], [69.22819519, 22.84208107], [69.2279129, 22.84208107], [69.2279129, 22.84152985], [69.22763824, 22.84153175], [69.22763824, 22.84042168], [69.22735596, 22.84042168], [69.22735596, 22.83986092], [69.22763824, 22.83986092], [69.22763824, 22.83958054], [69.22736359, 22.83958244], [69.22736359, 22.83930588], [69.2270813, 22.83930969], [69.2270813, 22.83875084], [69.22651672, 22.83875084], [69.22651672, 22.83847046], [69.22597504, 22.83847237], [69.22597504, 22.83819389], [69.22541809, 22.83819389], [69.22541809, 22.83791733], [69.22486115, 22.83792114], [69.22486115, 22.83764076], [69.22458649, 22.83764076], [69.22458649, 22.83736038], [69.22402954, 22.83736038], [69.22402954, 22.83708], [69.22374725, 22.83708382], [69.22374725, 22.83652687], [69.2234726, 22.83653831], [69.2234726, 22.83625031], [69.22319794, 22.83625031], [69.22319794, 22.83596992], [69.22208405, 22.83597183], [69.22209167, 22.83625031], [69.22125244, 22.83625031], [69.22125244, 22.83653831], [69.21985626, 22.83653831], [69.21985626, 22.83681107], [69.21875, 22.83680534], [69.21875, 22.83708382], [69.21347046, 22.83708382], [69.21347046, 22.83680534], [69.21047211, 22.83680534], [69.20819092, 22.83680534], [69.20819092, 22.83708382], [69.20791626, 22.83708], [69.20791626, 22.83736038], [69.20735931, 22.83736038], [69.20735931, 22.83764076], [69.20708466, 22.83763885], [69.20708466, 22.83847237], [69.20735931, 22.83847046], [69.20735931, 22.83875084], [69.2076416, 22.83875084], [69.2076416, 22.83903122], [69.20780182, 22.83903122], [69.20791626, 22.83903122], [69.20791626, 22.83986092], [69.2076416, 22.83986092], [69.2076416, 22.8401413], [69.20646667, 22.8401413], [69.20597076, 22.8401413], [69.20597076, 22.83986092], [69.20458221, 22.83986092], [69.20458221, 22.83958054], [69.20347595, 22.83958244], [69.20347595, 22.83930588], [69.20263672, 22.83930588], [69.20263672, 22.83958244], [69.20236206, 22.83958054], [69.20236206, 22.83986092], [69.20180511, 22.83986092], [69.20181274, 22.8401413], [69.20153046, 22.8401413], [69.20153046, 22.83986092], [69.20041656, 22.83986092], [69.20041656, 22.8401413], [69.20014191, 22.8401413], [69.20014191, 22.83986092], [69.19985962, 22.83986092], [69.19985962, 22.83958054], [69.19958496, 22.83958244], [69.19958496, 22.83930588], [69.19930267, 22.83930969], [69.19930267, 22.83903122], [69.19902802, 22.83903122], [69.19902802, 22.83875084], [69.19847107, 22.83875084], [69.19847107, 22.83847046], [69.19735718, 22.83847046], [69.19735718, 22.83903122], [69.19708252, 22.83903122], [69.19708252, 22.83930969], [69.19652557, 22.83930588], [69.19652557, 22.83958244], [69.19625092, 22.83958054], [69.19625092, 22.83986092], [69.19596863, 22.83986092], [69.19596863, 22.8401413], [69.19568634, 22.8401413], [69.19568634, 22.84042168], [69.19513702, 22.84041595], [69.19513702, 22.84069443], [69.19486237, 22.84069443], [69.19486237, 22.8409729], [69.19374847, 22.8409729], [69.19374847, 22.84069443], [69.19208527, 22.84069443], [69.19208527, 22.8409729], [69.19152832, 22.84096909], [69.19152832, 22.84124947], [69.19069672, 22.84124947], [69.19069672, 22.84153175], [69.19013977, 22.84153175], [69.19013977, 22.84181023], [69.18985748, 22.84180641], [69.18985748, 22.84208107], [69.18930817, 22.84208107], [69.18930817, 22.84235954], [69.18901825, 22.8423481], [69.18901825, 22.84264183], [69.18818665, 22.84264183], [69.18818665, 22.8429203], [69.18763733, 22.8429203], [69.18763733, 22.84320068], [69.18736267, 22.84319496], [69.18736267, 22.84347343], [69.18653107, 22.84346962], [69.18653107, 22.84375191], [69.18624878, 22.84375191], [69.18624878, 22.84403038], [69.18595886, 22.84403038], [69.18595886, 22.84431076], [69.18569183, 22.84430504], [69.18569183, 22.84458351], [69.18541718, 22.84458351], [69.18541718, 22.84486389], [69.18514252, 22.84486008], [69.18514252, 22.84514046], [69.18402863, 22.84514046], [69.18402863, 22.84542084], [69.18374634, 22.84541702], [69.18374634, 22.84569168], [69.18319702, 22.84569168], [69.18319702, 22.84597206], [69.18235779, 22.84597015], [69.18235779, 22.84625053], [69.18152618, 22.84625053], [69.18152618, 22.84653091], [69.18096924, 22.84653091], [69.18096924, 22.84680939], [69.18041992, 22.84680557], [69.18041992, 22.84708595], [69.18013763, 22.84708023], [69.18013763, 22.84736061], [69.17986298, 22.84736061], [69.17986298, 22.84764099], [69.17958069, 22.84764099], [69.17958069, 22.84791946], [69.17930603, 22.84791756], [69.17930603, 22.84819412], [69.17903137, 22.84819031], [69.17903137, 22.84848022], [69.17874908, 22.84848022], [69.17874908, 22.84875107], [69.1784668, 22.84875107], [69.1784668, 22.84902954], [69.17819214, 22.84902954], [69.17819214, 22.84930992], [69.17791748, 22.84930611], [69.17791748, 22.84958267], [69.17763519, 22.84958267], [69.17764282, 22.84986115], [69.17736053, 22.84986115], [69.17736053, 22.85013962], [69.17708588, 22.85013962], [69.17707825, 22.85030174], [69.17707825, 22.85041809], [69.17685699, 22.85041618], [69.17652893, 22.85041618], [69.17652893, 22.85058022], [69.17652893, 22.85069466], [69.17624664, 22.85069466], [69.17624664, 22.85097313], [69.17597198, 22.85097122], [69.17597198, 22.85124969], [69.17541504, 22.85124969], [69.17541504, 22.85152626], [69.17514038, 22.85152626], [69.17514038, 22.85124969], [69.17485809, 22.85124969], [69.17485809, 22.85152626], [69.17469788, 22.85152626], [69.17375183, 22.85152626], [69.17375183, 22.85180473], [69.17346954, 22.85180473], [69.17346954, 22.85208321], [69.17319489, 22.85208321], [69.17319489, 22.85236168], [69.17308044, 22.85236168], [69.17292023, 22.85235977], [69.17292023, 22.85263824], [69.17263794, 22.85263824], [69.17263794, 22.85292053], [69.17236328, 22.85292053], [69.17236328, 22.85320091], [69.17180634, 22.85319519], [69.17180634, 22.85347176], [69.17124939, 22.85346985], [69.17124939, 22.85374832], [69.17098236, 22.85374832], [69.17098236, 22.85403061], [69.17069244, 22.85403061], [69.17069244, 22.85430908], [69.17041779, 22.85430527], [69.17041779, 22.85458374], [69.16986084, 22.85457993], [69.16986084, 22.8548584], [69.16958618, 22.8548584], [69.16958618, 22.85514259], [69.16902924, 22.85514259], [69.16902924, 22.85542107], [69.16874695, 22.85541725], [69.16874695, 22.85569382], [69.16819763, 22.85569191], [69.16819763, 22.85653114], [69.16707611, 22.85653114], [69.16707611, 22.85680962], [69.16625214, 22.8568058], [69.16625214, 22.85708427], [69.16569519, 22.85708427], [69.16570282, 22.85736275], [69.1654129, 22.85736275], [69.1654129, 22.85765076], [69.16486359, 22.85763931], [69.16486359, 22.85819435], [69.16430664, 22.85819435], [69.16430664, 22.85847473], [69.16401672, 22.85847282], [69.16401672, 22.85874939], [69.16374969, 22.85874939], [69.16374969, 22.85902977], [69.1626358, 22.85902977], [69.1626358, 22.85931015], [69.1618042, 22.85930634], [69.1618042, 22.85958481], [69.16152954, 22.8595829], [69.16152954, 22.86013985], [69.16124725, 22.86013985], [69.16124725, 22.86042023], [69.1598587, 22.86041641], [69.1598587, 22.86069489], [69.15958405, 22.86069489], [69.15958405, 22.86097145], [69.1590271, 22.86097145], [69.1590271, 22.86124992], [69.15820313, 22.86124992], [69.15820313, 22.8615303], [69.15791321, 22.8615303], [69.15791321, 22.86181068], [69.15736389, 22.86180687], [69.15736389, 22.86208344], [69.15680695, 22.86208344], [69.15680695, 22.86236191], [69.15598297, 22.86236], [69.15598297, 22.86264038], [69.1554184, 22.86264038], [69.1554184, 22.86292076], [69.15513611, 22.86291695], [69.15513611, 22.8631897], [69.15486145, 22.86319542], [69.15486145, 22.86347198], [69.15458679, 22.86346054], [69.15458679, 22.86375046], [69.1534729, 22.86375046], [69.1534729, 22.86403084], [69.15319824, 22.86403084], [69.15319824, 22.86431122], [69.15235901, 22.8643055], [69.15235901, 22.86458397], [69.15207672, 22.86458015], [69.15207672, 22.86486053], [69.1515274, 22.86486053], [69.1515274, 22.86514091], [69.15097046, 22.86514091], [69.15097046, 22.86541748], [69.15013885, 22.86541748], [69.15013885, 22.86569405], [69.14930725, 22.86569405], [69.14930725, 22.86597252], [69.14903259, 22.86597061], [69.14903259, 22.86624908], [69.1470871, 22.86624718], [69.1470871, 22.86652756], [69.14653015, 22.86652756], [69.14653015, 22.8670826], [69.14624786, 22.86708069], [69.14624786, 22.86735916], [69.14608002, 22.86735916], [69.14569092, 22.86735916], [69.14569092, 22.86709023], [69.14541626, 22.86708069], [69.14541626, 22.86735916], [69.14485931, 22.86735916], [69.14485931, 22.86764145], [69.14430237, 22.86764145], [69.14430237, 22.86792183], [69.14375305, 22.86791611], [69.14375305, 22.86819458], [69.14347076, 22.86819458], [69.14347076, 22.86847115], [69.14180756, 22.86846924], [69.14180756, 22.86875153], [69.14125061, 22.86875153], [69.14125061, 22.86903191], [69.14041901, 22.86902809], [69.14041901, 22.86930466], [69.13957977, 22.86930084], [69.13957977, 22.86959267], [69.13903046, 22.86958122], [69.13903046, 22.86986351], [69.13819122, 22.8698597], [69.13819122, 22.87014008], [69.13790894, 22.87014008], [69.13790894, 22.87042046], [69.13735962, 22.87042046], [69.13735962, 22.87070084], [69.13625336, 22.87069511], [69.13625336, 22.87097359], [69.13597107, 22.87096977], [69.13597107, 22.87125015], [69.13540649, 22.87125015], [69.13540649, 22.87153053], [69.13487244, 22.87153053], [69.13487244, 22.87181091], [69.13402557, 22.87180519], [69.13402557, 22.87208366], [69.13318634, 22.87207985], [69.13318634, 22.87236023], [69.13208008, 22.87236023], [69.13208008, 22.87265015], [69.13153076, 22.8726387], [69.13153076, 22.87319565], [69.13097382, 22.87319565], [69.13097382, 22.87347221], [69.13041687, 22.87347031], [69.13041687, 22.87375069], [69.1295929, 22.87375069], [69.1295929, 22.87403107], [69.12902832, 22.87403107], [69.12902832, 22.87430954], [69.12875366, 22.87430573], [69.12875366, 22.8745842], [69.12819672, 22.87458038], [69.12819672, 22.87486076], [69.1279068, 22.87486076], [69.1279068, 22.87514114], [69.12763977, 22.87514114], [69.12763977, 22.87541962], [69.12680817, 22.8754158], [69.12680817, 22.87569427], [69.12652588, 22.87569427], [69.12652588, 22.87597275], [69.12625122, 22.87597084], [69.12625122, 22.87625122], [69.12567902, 22.87625122], [69.12567902, 22.87652969], [69.12541962, 22.87652969], [69.12541962, 22.87681007], [69.12513733, 22.87680626], [69.12513733, 22.87708282], [69.12486267, 22.87708282], [69.12486267, 22.8773613], [69.12430573, 22.8773613], [69.12431335, 22.87763977], [69.12403107, 22.87763977], [69.12403107, 22.87791824], [69.12347412, 22.87791634], [69.12347412, 22.87819481], [69.12319183, 22.87819481], [69.12319183, 22.87847137], [69.12291718, 22.87847137], [69.12293243, 22.87874985], [69.12264252, 22.87874985], [69.12264252, 22.87902832], [69.12208557, 22.87902832], [69.12208557, 22.87930489], [69.12180328, 22.87930489], [69.12180328, 22.87958336], [69.12152863, 22.87958336], [69.12152863, 22.87986183], [69.12124634, 22.87985992], [69.12124634, 22.8801384], [69.12097168, 22.8801384], [69.12097168, 22.88042068], [69.12069702, 22.88042068], [69.12069702, 22.88069916], [69.1204071, 22.88069916], [69.1204071, 22.88124847], [69.12014008, 22.88124847], [69.12014008, 22.88181114], [69.11930847, 22.88180542], [69.11930847, 22.88208389], [69.11875153, 22.88208008], [69.11875153, 22.88236237], [69.11846924, 22.88236237], [69.11846924, 22.88264275], [69.11791992, 22.88264275], [69.11791992, 22.88292122], [69.11763763, 22.8829174], [69.11763763, 22.88319206], [69.11736298, 22.88319206], [69.11736298, 22.88347054], [69.11708069, 22.88347054], [69.11708069, 22.88375282], [69.1167984, 22.88375282], [69.1167984, 22.88402939], [69.11653137, 22.88402939], [69.11653137, 22.88430977], [69.11569214, 22.88430977], [69.11569214, 22.88459015], [69.11514282, 22.88459015], [69.11514282, 22.88541985], [69.11486053, 22.88541603], [69.11486053, 22.8856945], [69.11458588, 22.8856945], [69.11458588, 22.88597488], [69.11429596, 22.88597107], [69.11429596, 22.88624954], [69.11402893, 22.88624954], [69.11402893, 22.88652992], [69.11373901, 22.88652992], [69.11373901, 22.8868103], [69.11319733, 22.88680649], [69.11319733, 22.88708305], [69.11264038, 22.88708305], [69.11264038, 22.88736153], [69.11180878, 22.88735962], [69.11180878, 22.88764954], [69.11152649, 22.88764954], [69.11152649, 22.88792038], [69.11125183, 22.88792038], [69.11125183, 22.88820076], [69.11069489, 22.88819695], [69.11069489, 22.8884716], [69.11042023, 22.8884697], [69.11042023, 22.88903046], [69.10986328, 22.88903046], [69.10986328, 22.88931084], [69.10958099, 22.88930511], [69.10958099, 22.88958359], [69.10930634, 22.88958359], [69.10930634, 22.88986206], [69.10901642, 22.88986015], [69.10901642, 22.89014053], [69.10819244, 22.89014053], [69.10819244, 22.89042091], [69.1076355, 22.89041519], [69.1076355, 22.89069366], [69.10708618, 22.89069366], [69.10708618, 22.89097214], [69.10652924, 22.89097023], [69.10652924, 22.89125061], [69.10624695, 22.89125061], [69.10624695, 22.89146805], [69.10569763, 22.89152908], [69.10569763, 22.89180946], [69.10541534, 22.89180565], [69.10541534, 22.89208412], [69.10514069, 22.89208031], [69.10514069, 22.89236069], [69.1048584, 22.89236069], [69.1048584, 22.89263916], [69.10430908, 22.89263916], [69.10430908, 22.89291763], [69.10402679, 22.89291763], [69.10402679, 22.8931942], [69.10375214, 22.8931942], [69.10375214, 22.89347267], [69.10362244, 22.89347267], [69.10346985, 22.89347076], [69.10346985, 22.89374924], [69.10320282, 22.89374924], [69.10320282, 22.89403152], [69.1029129, 22.89403152], [69.1029129, 22.8943119], [69.10236359, 22.89430618], [69.10236359, 22.89458275], [69.1020813, 22.89458084], [69.1020813, 22.89485931], [69.10179901, 22.89485931], [69.10179901, 22.8951416], [69.10124969, 22.8951416], [69.10124969, 22.89542007], [69.10097504, 22.89541626], [69.10097504, 22.89569473], [69.10041809, 22.89569473], [69.10041809, 22.89596939], [69.09986115, 22.89596939], [69.09986115, 22.89625168], [69.09958649, 22.89625168], [69.09958649, 22.89653015], [69.0993042, 22.89652824], [69.0993042, 22.89680481], [69.09874725, 22.89680481], [69.09874725, 22.89708138], [69.0984726, 22.89708138], [69.0984726, 22.89736366], [69.0973587, 22.89735985], [69.0973587, 22.89764023], [69.09707642, 22.89764023], [69.09707642, 22.89792061], [69.09680939, 22.89792061], [69.09680176, 22.8982029], [69.09597015, 22.89819527], [69.09597015, 22.89847374], [69.0956955, 22.89847374], [69.09570313, 22.89875031], [69.09541321, 22.89875031], [69.09541321, 22.89903069], [69.09401703, 22.89903069], [69.09401703, 22.89931107], [69.09347534, 22.89930534], [69.09347534, 22.89958572], [69.09319305, 22.89957047], [69.09319305, 22.89986038], [69.09263611, 22.89986038], [69.09263611, 22.90014076], [69.09236145, 22.90014076], [69.09236145, 22.90042114], [69.0918045, 22.90041733], [69.0918045, 22.9006958], [69.09124756, 22.9006958], [69.09124756, 22.90097237], [69.0909729, 22.90097046], [69.0909729, 22.90125084], [69.09069824, 22.90125084], [69.09069824, 22.90153122], [69.09041595, 22.9015274], [69.09041595, 22.90167809], [69.09041595, 22.90180969], [69.08985901, 22.90180588], [69.08985901, 22.90208244], [69.08930206, 22.90208054], [69.08930206, 22.90236092], [69.0890274, 22.90236092], [69.0890274, 22.90263939], [69.08875275, 22.90262985], [69.08875275, 22.90291977], [69.08847046, 22.90291786], [69.08847046, 22.90319443], [69.0881958, 22.90319443], [69.0881958, 22.9034729], [69.08735657, 22.90347099], [69.08735657, 22.90374947], [69.08625031, 22.90374947], [69.08625031, 22.90402985], [69.08569336, 22.90402985], [69.08569336, 22.90431023], [69.0854187, 22.90430641], [69.0854187, 22.90486145], [69.08486176, 22.90485954], [69.08486176, 22.90513992], [69.08429718, 22.90513992], [69.08429718, 22.9054203], [69.08374786, 22.90541649], [69.08374786, 22.90569496], [69.08291626, 22.90569496], [69.08291626, 22.90597153], [69.0826416, 22.90596962], [69.0826416, 22.90624809], [69.08207703, 22.90624809], [69.08207703, 22.90652847], [69.08152771, 22.90652847], [69.08152771, 22.90681076], [69.08125305, 22.90680504], [69.08125305, 22.90708351], [69.08069611, 22.90708351], [69.08069611, 22.90736008], [69.08040619, 22.90735817], [69.08040619, 22.90763855], [69.08013916, 22.90763855], [69.08013916, 22.90792084], [69.07958221, 22.90791702], [69.07958221, 22.90819359], [69.07930756, 22.90819359], [69.07930756, 22.90847015], [69.07847595, 22.90847015], [69.07847595, 22.90876007], [69.07791901, 22.90876007], [69.07791901, 22.90903282], [69.07762909, 22.90903282], [69.07762909, 22.90930939], [69.07736206, 22.90930557], [69.07736206, 22.90958405], [69.07680511, 22.90958405], [69.07681274, 22.90986252], [69.07624817, 22.90986252], [69.07624817, 22.9101429], [69.07596588, 22.9101429], [69.07596588, 22.91041946], [69.07569122, 22.91041756], [69.07569122, 22.91069221], [69.07541656, 22.91069221], [69.07541656, 22.91097069], [69.07485962, 22.91097069], [69.07485962, 22.91125107], [69.07430267, 22.91125107], [69.07430267, 22.91152954], [69.07402802, 22.91152763], [69.07402802, 22.91208458], [69.07375336, 22.91208076], [69.07375336, 22.91236115], [69.07235718, 22.91236115], [69.07235718, 22.91263962], [69.07208252, 22.91263962], [69.07208252, 22.91292], [69.07152557, 22.91291618], [69.07152557, 22.91319466], [69.07096863, 22.91319466], [69.07096863, 22.91347313], [69.07041931, 22.91347122], [69.07041931, 22.91374969], [69.06958008, 22.91374969], [69.06958008, 22.91403008], [69.06930542, 22.91402817], [69.06930542, 22.91458321], [69.06903076, 22.91458321], [69.06903076, 22.91486168], [69.0687561, 22.91485977], [69.0687561, 22.91514015], [69.06846619, 22.91514015], [69.06846619, 22.91542053], [69.06819153, 22.91542053], [69.06819153, 22.91570091], [69.06791687, 22.91569519], [69.06791687, 22.91597176], [69.06735992, 22.91596985], [69.06735992, 22.91625023], [69.06680298, 22.91625023], [69.06680298, 22.91653061], [69.06652832, 22.91653061], [69.06652832, 22.91681099], [69.06569672, 22.91680527], [69.06569672, 22.91708374], [69.06485748, 22.91707993], [69.06485748, 22.91736031], [69.06319427, 22.91736031], [69.06319427, 22.91763878], [69.06291962, 22.91763115], [69.06291962, 22.91792107], [69.06263733, 22.91791725], [69.06263733, 22.91819382], [69.06208038, 22.91819382], [69.06208038, 22.91847229], [69.06153107, 22.91847038], [69.06153107, 22.91875076], [69.06041718, 22.91875076], [69.06041718, 22.91903114], [69.06014252, 22.91903114], [69.06014252, 22.91930962], [69.05986023, 22.9193058], [69.05986023, 22.91958427], [69.05930328, 22.91958046], [69.05930328, 22.91986084], [69.05874634, 22.91986084], [69.05874634, 22.92013931], [69.05847168, 22.92013931], [69.05847168, 22.9204216], [69.05819702, 22.9204216], [69.05819702, 22.92070007], [69.05791473, 22.92069435], [69.05791473, 22.92097282], [69.05764008, 22.92097092], [69.05764008, 22.92124939], [69.05708313, 22.92124939], [69.05708313, 22.92153168], [69.05652618, 22.92153168], [69.05652618, 22.92181015], [69.05625153, 22.92180634], [69.05625153, 22.9220829], [69.05569458, 22.9220829], [69.05569458, 22.92235947], [69.05513763, 22.92235947], [69.05513763, 22.92264175], [69.05458069, 22.92264175], [69.05458069, 22.92292023], [69.05403137, 22.92291641], [69.05403137, 22.92319489], [69.05319214, 22.92319489], [69.05319214, 22.92347336], [69.05236053, 22.92346954], [69.05236053, 22.9240303], [69.05208588, 22.9240284], [69.05208588, 22.92416191], [69.05208588, 22.92431068], [69.05152893, 22.92430305], [69.05152893, 22.92458153], [69.05124664, 22.92458153], [69.05124664, 22.92486382], [69.0506897, 22.92486191], [69.0506897, 22.92514038], [69.05042267, 22.92514038], [69.05042267, 22.92542076], [69.04985809, 22.92541695], [69.04985809, 22.9256897], [69.04930878, 22.92569542], [69.04930878, 22.92597389], [69.04875183, 22.92597008], [69.04875183, 22.92625046], [69.04846954, 22.92625046], [69.04846954, 22.92653084], [69.04819489, 22.92652702], [69.04819489, 22.9268055], [69.04792023, 22.9268055], [69.04792023, 22.92708588], [69.04708099, 22.92708015], [69.04708099, 22.92736053], [69.04651642, 22.92736053], [69.04651642, 22.92764091], [69.04624939, 22.92764091], [69.04624939, 22.92791939], [69.04597473, 22.92791748], [69.04597473, 22.92819595], [69.04569244, 22.92819595], [69.04569244, 22.92847252], [69.04541779, 22.92847061], [69.04541779, 22.92875099], [69.04514313, 22.92875099], [69.04514313, 22.92902946], [69.04486084, 22.92902946], [69.04486084, 22.92930984], [69.04458618, 22.92930794], [69.04458618, 22.9295826], [69.04402924, 22.92957115], [69.04402924, 22.92986107], [69.04264069, 22.92986107], [69.04264069, 22.93013954], [69.04151917, 22.93013954], [69.04151917, 22.93041992], [69.04125214, 22.93041611], [69.04125214, 22.93069458], [69.04069519, 22.93069458], [69.04069519, 22.93097305], [69.03930664, 22.93097115], [69.03930664, 22.93152809], [69.03902435, 22.93152618], [69.03902435, 22.93180466], [69.03847504, 22.93180466], [69.03847504, 22.93208313], [69.03819275, 22.93208313], [69.03819275, 22.9323616], [69.0376358, 22.9323597], [69.0376358, 22.93263817], [69.03679657, 22.93263817], [69.03679657, 22.9329319], [69.03624725, 22.9329319], [69.03624725, 22.93320084], [69.0348587, 22.93319511], [69.0348587, 22.93347168], [69.03375244, 22.93346977], [69.03375244, 22.93374825], [69.03264618, 22.93374825], [69.03264618, 22.93403053], [69.03235626, 22.93403053], [69.03235626, 22.93431091], [69.0320816, 22.93430519], [69.0320816, 22.93458366], [69.03180695, 22.93457985], [69.03180695, 22.93485832], [69.03098297, 22.93485832], [69.03098297, 22.93514252], [69.03069305, 22.93514252], [69.03069305, 22.9354229], [69.0304184, 22.9354229], [69.0304184, 22.93569946], [69.02902985, 22.93569374], [69.02902985, 22.93597031], [69.02874756, 22.93597031], [69.02874756, 22.93625259], [69.0284729, 22.93625259], [69.0284729, 22.93653107], [69.0276413, 22.93653107], [69.0276413, 22.93680954], [69.02708435, 22.93680573], [69.02708435, 22.9370842], [69.02625275, 22.93708038], [69.02625275, 22.93736267], [69.02597046, 22.93736267], [69.02597046, 22.93764114], [69.02540588, 22.93764114], [69.02540588, 22.93791962], [69.02513885, 22.9379158], [69.02513885, 22.93819237], [69.0248642, 22.93819237], [69.0248642, 22.93847466], [69.02430725, 22.93847466], [69.02430725, 22.93874931], [69.02375031, 22.93873978], [69.02375031, 22.93902969], [69.02348328, 22.93902969], [69.02348328, 22.93931007], [69.02319336, 22.93930626], [69.02319336, 22.93958473], [69.0229187, 22.93958473], [69.0229187, 22.9398613], [69.02263641, 22.93985939], [69.02263641, 22.94013977], [69.02236176, 22.94013977], [69.02236176, 22.94042015], [69.02180481, 22.94041634], [69.02180481, 22.94069481], [69.02124786, 22.94069481], [69.02124786, 22.94097137], [69.02097321, 22.94096947], [69.02097321, 22.94124985], [69.02041626, 22.94124985], [69.02041626, 22.94153023], [69.01958466, 22.94152832], [69.01958466, 22.94180679], [69.01875305, 22.94180679], [69.01875305, 22.94208336], [69.01791382, 22.94208336], [69.01791382, 22.94236183], [69.01734924, 22.94235992], [69.01734924, 22.9426403], [69.01708221, 22.9426403], [69.01708221, 22.94292068], [69.01680756, 22.94292068], [69.01680756, 22.94320107], [69.01541901, 22.94319534], [69.01541901, 22.94347191], [69.01513672, 22.94347], [69.01513672, 22.94375038], [69.01486206, 22.94375038], [69.01486206, 22.94403076], [69.01346588, 22.94403076], [69.01346588, 22.94431114], [69.01291656, 22.94430542], [69.01291656, 22.94458389], [69.01264191, 22.94458008], [69.01264191, 22.94486809], [69.01154327, 22.94486809], [69.01154327, 22.94514084], [69.01125336, 22.94513893], [69.01125336, 22.94569397], [69.01097107, 22.94569397], [69.01097107, 22.94597244], [69.01040649, 22.94597054], [69.01040649, 22.94625092], [69.00985718, 22.94625092], [69.00985718, 22.94652748], [69.00930786, 22.94652748], [69.00930786, 22.94681168], [69.00902557, 22.94680595], [69.00902557, 22.94708252], [69.00818634, 22.94708061], [69.00818634, 22.94735909], [69.00763702, 22.94735909], [69.00763702, 22.94764137], [69.00736237, 22.94764137], [69.00736237, 22.94792938], [69.00680542, 22.94791603], [69.00680542, 22.9481945], [69.00624847, 22.9481945], [69.00624847, 22.94847107], [69.00596619, 22.94846916], [69.00596619, 22.94874954], [69.00514221, 22.94874954], [69.00514221, 22.94903183], [69.0045929, 22.94903183], [69.0045929, 22.9493103], [69.00375366, 22.94930649], [69.00375366, 22.94958115], [69.00319672, 22.94958115], [69.00319672, 22.94985962], [69.00234985, 22.94985962], [69.00234985, 22.95014191], [69.00096893, 22.95014191], [69.00096893, 22.95042038], [69.00069427, 22.95041656], [69.00069427, 22.95097351], [69.00013733, 22.95097351], [68.99958038, 22.9509697], [68.99958038, 22.95125008], [68.99903107, 22.95125008], [68.99903107, 22.95153046], [68.99819183, 22.95153046], [68.99819183, 22.95181084], [68.99764252, 22.95180321], [68.99764252, 22.95208359], [68.99708557, 22.95208359], [68.99708557, 22.95236206], [68.99653625, 22.95236015], [68.99653625, 22.95264053], [68.99569702, 22.95264053], [68.99569702, 22.95292091], [68.99514008, 22.9529171], [68.99514008, 22.95319557], [68.99458313, 22.95319557], [68.99458313, 22.95347214], [68.99402618, 22.95347214], [68.99402618, 22.95375061], [68.99318695, 22.95374107], [68.99318695, 22.95403099], [68.99263763, 22.95403099], [68.99263763, 22.95430946], [68.99208069, 22.95430565], [68.99208069, 22.95458412], [68.99124908, 22.95458031], [68.99124908, 22.95486069], [68.99040985, 22.95486069], [68.99040985, 22.95514107], [68.98986053, 22.95514107], [68.98986053, 22.95541954], [68.98902893, 22.95541763], [68.98902893, 22.9556942], [68.98847198, 22.9556942], [68.98847198, 22.95597267], [68.98764038, 22.95597076], [68.98764038, 22.95625114], [68.98707581, 22.95625114], [68.98707581, 22.95652962], [68.98680878, 22.95652962], [68.98680878, 22.95680809], [68.98625183, 22.95680618], [68.98625183, 22.95708275], [68.98596954, 22.95708084], [68.98596954, 22.95736122], [68.98542023, 22.95736122], [68.98542023, 22.95763969], [68.98513794, 22.95763969], [68.98513794, 22.95791817], [68.98458099, 22.95791626], [68.98458099, 22.95819473], [68.98402405, 22.95819473], [68.98402405, 22.9584713], [68.98374939, 22.95846939], [68.98374939, 22.95874977], [68.98319244, 22.95874977], [68.98319244, 22.95902824], [68.9826355, 22.95902824], [68.9826355, 22.95930481], [68.98208618, 22.95930481], [68.98208618, 22.95958328], [68.98179626, 22.95957947], [68.98179626, 22.95986938], [68.98124695, 22.95986938], [68.98124695, 22.96013832], [68.98069763, 22.96013832], [68.98069763, 22.96042061], [68.98042297, 22.96042061], [68.98042297, 22.96069908], [68.9798584, 22.96069527], [68.9798584, 22.96097183], [68.97902679, 22.96096992], [68.97902679, 22.9612484], [68.97820282, 22.9612484], [68.97820282, 22.96153069], [68.97763824, 22.96153069], [68.97763824, 22.96181107], [68.97736359, 22.96180534], [68.97736359, 22.96208382], [68.97569275, 22.96208382], [68.97569275, 22.96180534], [68.97541809, 22.96180534], [68.97541809, 22.96208382], [68.9751358, 22.96208191], [68.9751358, 22.96236038], [68.97486115, 22.96236038], [68.97486115, 22.96264267], [68.97402954, 22.96264076], [68.97402954, 22.96291733], [68.97291565, 22.96291733], [68.97291565, 22.96319389], [68.97208405, 22.96319389], [68.97208405, 22.96347046], [68.97097015, 22.96347046], [68.97097015, 22.96375275], [68.97041321, 22.96375275], [68.97041321, 22.96430969], [68.9695816, 22.96430969], [68.9695816, 22.96541977], [68.96902466, 22.96541405], [68.96902466, 22.96597481], [68.96875, 22.9659729], [68.96875, 22.96652985], [68.96819305, 22.96652985], [68.96819305, 22.96681023], [68.9679184, 22.96680641], [68.9679184, 22.96708488], [68.96736145, 22.96708488], [68.96736145, 22.96736145], [68.96708679, 22.96735954], [68.96708679, 22.96763992], [68.96679688, 22.96763992], [68.96679688, 22.96820068], [68.96541595, 22.96819687], [68.96541595, 22.96847153], [68.96485901, 22.96846962], [68.96485901, 22.97014046], [68.96458435, 22.97013855], [68.96458435, 22.97069359], [68.96430206, 22.97069359], [68.96430206, 22.97097206], [68.96263885, 22.97097206], [68.96263885, 22.97069359], [68.96069336, 22.97069359], [68.96069336, 22.97097206], [68.96013641, 22.97097015], [68.96013641, 22.97125053], [68.9595871, 22.97125053], [68.9595871, 22.97180748], [68.95903015, 22.97180557], [68.95903015, 22.97208405], [68.95847321, 22.97208023], [68.95847321, 22.97236061], [68.95791626, 22.97236061], [68.95791626, 22.97291756], [68.9576416, 22.97291756], [68.9576416, 22.97319412], [68.95625305, 22.97319412], [68.95625305, 22.9734726], [68.95597076, 22.97347069], [68.95597076, 22.97374916], [68.95540619, 22.97374916], [68.95540619, 22.97403145], [68.95485687, 22.97403145], [68.95485687, 22.97431183], [68.95458221, 22.97430611], [68.95458221, 22.97458267], [68.95402527, 22.97458267], [68.95402527, 22.97485924], [68.95375061, 22.9748497], [68.95375061, 22.97514153], [68.95318604, 22.97514153], [68.95318604, 22.97542191], [68.95291901, 22.97541618], [68.95291901, 22.97569466], [68.95236206, 22.97569466], [68.95236206, 22.97597122], [68.95180511, 22.97597122], [68.95181274, 22.9762516], [68.95153046, 22.9762516], [68.95153046, 22.97653008], [68.95097351, 22.97652817], [68.95097351, 22.97680473], [68.95041656, 22.97680473], [68.95041656, 22.9770813], [68.95014191, 22.9770813], [68.95014191, 22.97736359], [68.94959259, 22.97735977], [68.94959259, 22.97764015], [68.94930267, 22.97763824], [68.94930267, 22.97791672], [68.94875336, 22.9779129], [68.94875336, 22.97820091], [68.94819641, 22.97819519], [68.94819641, 22.97847366], [68.94790649, 22.97846985], [68.94790649, 22.97875023], [68.94735718, 22.97875023], [68.94735718, 22.97903061], [68.94680786, 22.97903061], [68.94680786, 22.97931099], [68.94625092, 22.97930527], [68.94625092, 22.97958565], [68.94596863, 22.97957993], [68.94596863, 22.97986031], [68.94542694, 22.97986031], [68.94542694, 22.98014069], [68.94486237, 22.98014069], [68.94486237, 22.98042107], [68.94374847, 22.98041725], [68.94374847, 22.98069572], [68.94291687, 22.98069], [68.94291687, 22.98097992], [68.94127655, 22.98097229], [68.94069672, 22.98097229], [68.94069672, 22.98134995], [68.94069672, 22.98153114], [68.9404068, 22.98153114], [68.9404068, 22.98180962], [68.93997955, 22.9818058], [68.93958282, 22.9818058], [68.93958282, 22.98208427], [68.93902588, 22.98208046], [68.93902588, 22.98236084], [68.93875122, 22.98236084], [68.93875122, 22.98262024], [68.93846893, 22.98263931], [68.93846893, 22.98278046], [68.93846893, 22.98291969], [68.93826294, 22.98291779], [68.93791962, 22.98291779], [68.93791962, 22.98319435], [68.93763733, 22.98319435], [68.93763733, 22.9833107], [68.93763733, 22.98347282], [68.93739319, 22.98347282], [68.93708038, 22.98347282], [68.93708038, 22.98374939], [68.93695831, 22.98374939], [68.93680573, 22.98374939], [68.93680573, 22.98385048], [68.93681335, 22.98404121], [68.93653107, 22.98404121], [68.93653107, 22.98431015], [68.93624878, 22.98430634], [68.93624878, 22.9845829], [68.93597412, 22.9845829], [68.93597412, 22.98486137], [68.93569183, 22.98485947], [68.93569183, 22.98513985], [68.93514252, 22.98513985], [68.93514252, 22.98541832], [68.93486023, 22.98541641], [68.93486023, 22.98569489], [68.93458557, 22.98569489], [68.93458557, 22.98597145], [68.93430328, 22.98596954], [68.93430328, 22.98624992], [68.93402863, 22.98624992], [68.93402863, 22.9865284], [68.93374634, 22.9865284], [68.93374634, 22.98681068], [68.93319702, 22.98680496], [68.93319702, 22.98708344], [68.93291473, 22.98708344], [68.93291473, 22.98736191], [68.93235779, 22.98735809], [68.93235779, 22.98763847], [68.93208313, 22.98763847], [68.93208313, 22.98792076], [68.93152618, 22.98791695], [68.93152618, 22.9881897], [68.93125153, 22.98819542], [68.93125153, 22.98847008], [68.93096924, 22.98846817], [68.93096924, 22.98875237], [68.93068695, 22.98875237], [68.93068695, 22.98903275], [68.93041992, 22.98903275], [68.93041992, 22.98931122], [68.93013763, 22.9893055], [68.93013763, 22.98958206], [68.92986298, 22.98958206], [68.92986298, 22.98986053], [68.92958069, 22.98984909], [68.92958069, 22.99014282], [68.92930603, 22.99014091], [68.92930603, 22.99069214], [68.92903137, 22.99069214], [68.92903137, 22.99097061], [68.92874908, 22.99097061], [68.92874908, 22.9912529], [68.9284668, 22.9912529], [68.9284668, 22.99152946], [68.92819214, 22.99152946], [68.92819214, 22.99180984], [68.92791748, 22.99180603], [68.92791748, 22.9920845], [68.92763519, 22.9920845], [68.92764282, 22.99236107], [68.92652893, 22.99236107], [68.92652893, 22.99263954], [68.92569733, 22.99263954], [68.92569733, 22.99291992], [68.92541504, 22.99291611], [68.92541504, 22.99319458], [68.92485809, 22.99319458], [68.92485809, 22.99347305], [68.92457581, 22.99347115], [68.92458344, 22.99374962], [68.92431641, 22.99374962], [68.92431641, 22.99403], [68.92402649, 22.99402809], [68.92402649, 22.99430466], [68.92346954, 22.99430466], [68.92346954, 22.99458313], [68.92180634, 22.99458313], [68.92180634, 22.9948616], [68.92151642, 22.9948597], [68.92151642, 22.99514008], [68.92014313, 22.99514008], [68.92014313, 22.99542046], [68.91958618, 22.99542046], [68.91958618, 22.99570084], [68.91902924, 22.99570084], [68.91902924, 22.99598122], [68.91847229, 22.99598122], [68.91847229, 22.99625015], [68.91792297, 22.99625015], [68.91792297, 22.99653053], [68.9173584, 22.99653053], [68.9173584, 22.99681091], [68.91680908, 22.99680519], [68.91680908, 22.99708366], [68.91652679, 22.99707985], [68.91652679, 22.99736023], [68.91596985, 22.99736023], [68.91596985, 22.99764061], [68.91570282, 22.99764061], [68.91570282, 22.99792099], [68.9145813, 22.99791718], [68.9145813, 22.99819374], [68.91402435, 22.99819374], [68.91402435, 22.99847221], [68.91374969, 22.99847031], [68.91374969, 22.99875069], [68.91319275, 22.99875069], [68.91319275, 22.9990406], [68.91291809, 22.9990406], [68.91291809, 22.99930954], [68.9118042, 22.99930573], [68.9118042, 22.9995842], [68.91152954, 22.99958038], [68.91152954, 22.99986076], [68.91124725, 22.99986076], [68.91124725, 23.00013924], [68.9109726, 23.00013924], [68.9109726, 23.00042152], [68.91069794, 23.0004158], [68.91069794, 23.00069427], [68.91042328, 23.00069046], [68.91042328, 23.00124931], [68.91014099, 23.00124931], [68.91014099, 23.0015316], [68.9098587, 23.0015316], [68.9098587, 23.00181007], [68.90930939, 23.00180626], [68.90930176, 23.00208282], [68.9090271, 23.00208282], [68.9090271, 23.00235939], [68.90875244, 23.00235939], [68.90875244, 23.00292015], [68.90847015, 23.00291634], [68.90847015, 23.00347137], [68.9081955, 23.00347137], [68.90820313, 23.00375175], [68.90791321, 23.00375175], [68.90791321, 23.00403023], [68.90763855, 23.00402832], [68.90763855, 23.00430489], [68.90736389, 23.00430489], [68.90736389, 23.00458145], [68.9070816, 23.00458145], [68.9070816, 23.00486374], [68.90680695, 23.00485992], [68.90680695, 23.00542068], [68.90651703, 23.00542068], [68.90651703, 23.00570107], [68.90625, 23.00569534], [68.90625, 23.00597382], [68.90597534, 23.00597382], [68.90598297, 23.00625038], [68.90569305, 23.00625038], [68.90569305, 23.00653076], [68.90486145, 23.00653076], [68.90486145, 23.00681114], [68.9043045, 23.00680542], [68.9043045, 23.0070858], [68.90374756, 23.00708008], [68.90374756, 23.00736046], [68.9034729, 23.00736046], [68.9034729, 23.00764084], [68.90291595, 23.00764084], [68.90291595, 23.00792122], [68.9026413, 23.0079174], [68.9026413, 23.00819588], [68.90208435, 23.00819588], [68.90208435, 23.00847244], [68.90180206, 23.00847054], [68.90180206, 23.00875092], [68.90125275, 23.00875092], [68.90125275, 23.00902939], [68.90097046, 23.00902939], [68.90097046, 23.01098061], [68.89985657, 23.01098061], [68.89985657, 23.01013947], [68.90014648, 23.01013947], [68.90013885, 23.00930786], [68.90040588, 23.00930977], [68.90040588, 23.00875092], [68.90013885, 23.00875092], [68.90013885, 23.00847244], [68.90041351, 23.00847244], [68.90041351, 23.00819588], [68.90097046, 23.00819588], [68.90097046, 23.0079174], [68.90125275, 23.00792122], [68.90125275, 23.00764084], [68.90180206, 23.00764084], [68.90180206, 23.00736046], [68.90207672, 23.00736046], [68.90207672, 23.00708008], [68.90235901, 23.0070858], [68.90235901, 23.00680542], [68.9026413, 23.00681114], [68.9026413, 23.00653076], [68.90291595, 23.00653076], [68.90291595, 23.00625038], [68.90319061, 23.00625038], [68.90319061, 23.00597], [68.9034729, 23.00597382], [68.9034729, 23.00569534], [68.90374756, 23.00570107], [68.90374756, 23.00542068], [68.90235901, 23.00542068], [68.90235901, 23.00570107], [68.90208435, 23.00569534], [68.90208435, 23.00597382], [68.9015274, 23.00597], [68.9015274, 23.00625038], [68.90097046, 23.00625038], [68.90097046, 23.00653076], [68.90014648, 23.00653076], [68.90014648, 23.00681114], [68.89958191, 23.00680542], [68.89958191, 23.0070858], [68.89902496, 23.0070858], [68.89903259, 23.00736046], [68.89875031, 23.00736046], [68.89875031, 23.00764084], [68.89819336, 23.00764084], [68.89819336, 23.00792122], [68.8979187, 23.0079174], [68.8979187, 23.00819588], [68.89736176, 23.00819588], [68.89736176, 23.00847244], [68.8970871, 23.00847054], [68.8970871, 23.00875092], [68.89653015, 23.00875092], [68.89653015, 23.00902939], [68.89624786, 23.00902939], [68.89624786, 23.00930977], [68.89569092, 23.00930786], [68.89569092, 23.00958252], [68.89541626, 23.00958061], [68.89541626, 23.00986099], [68.89485931, 23.00986099], [68.89485931, 23.01013947], [68.89430237, 23.01013947], [68.89430237, 23.01041985], [68.89375305, 23.01041794], [68.89375305, 23.0106945], [68.89319611, 23.01069069], [68.89319611, 23.01098061], [68.89263916, 23.01098061], [68.89263916, 23.01124954], [68.89208221, 23.01124954], [68.89208221, 23.01152992], [68.89180756, 23.01152992], [68.89180756, 23.0118103], [68.89125061, 23.01180649], [68.89125061, 23.01208305], [68.89097595, 23.01208305], [68.89097595, 23.01236153], [68.89068604, 23.01235962], [68.89068604, 23.01263809], [68.89013672, 23.01263809], [68.89013672, 23.01292038], [68.88986206, 23.01292038], [68.88986206, 23.01320076], [68.88903046, 23.01319504], [68.88903046, 23.0134716], [68.88819122, 23.0134697], [68.88819122, 23.01374817], [68.88764191, 23.01374817], [68.88764191, 23.01402855], [68.88709259, 23.01402092], [68.88709259, 23.01431084], [68.88652802, 23.01430511], [68.88652802, 23.01458359], [68.88597107, 23.01458359], [68.88597107, 23.01486015], [68.88569641, 23.01485825], [68.88569641, 23.01514244], [68.88514709, 23.01514244], [68.88514709, 23.01542282], [68.88458252, 23.0154171], [68.88458252, 23.01569366], [68.88430786, 23.01569366], [68.88430786, 23.01597023], [68.88375092, 23.01597023], [68.88375092, 23.01625252], [68.88346863, 23.01625252], [68.88346863, 23.0165329], [68.88291931, 23.0165329], [68.88291931, 23.01680946], [68.88236237, 23.01680565], [68.88236237, 23.01708221], [68.88208008, 23.01708031], [68.88208008, 23.01736259], [68.88153076, 23.01736259], [68.88153076, 23.01764107], [68.88096619, 23.01764107], [68.88096619, 23.01791954], [68.88069153, 23.01791763], [68.88069153, 23.01819229], [68.88014221, 23.01819229], [68.88014221, 23.01847458], [68.8795929, 23.01847076], [68.8795929, 23.01875114], [68.87902069, 23.01875114], [68.87902069, 23.01902962], [68.87874603, 23.01902962], [68.87874603, 23.01931], [68.87819672, 23.01930618], [68.87819672, 23.01958466], [68.87763977, 23.01958084], [68.87763977, 23.01986122], [68.87708282, 23.01986122], [68.87708282, 23.02015114], [68.87652588, 23.02015114], [68.87652588, 23.02042007], [68.87596893, 23.02041626], [68.87596893, 23.02069473], [68.87569427, 23.02069473], [68.87569427, 23.0209713], [68.87513733, 23.02096939], [68.87513733, 23.02124977], [68.87458038, 23.02124977], [68.87458038, 23.02153015], [68.87403107, 23.02152824], [68.87403107, 23.02180672], [68.87347412, 23.02180672], [68.87347412, 23.02208328], [68.87319183, 23.02207947], [68.87319183, 23.02264023], [68.87291718, 23.02264023], [68.87291718, 23.02292061], [68.87264252, 23.02291679], [68.87264252, 23.02347183], [68.87236023, 23.02346992], [68.87236023, 23.02375031], [68.87180328, 23.02375031], [68.87180328, 23.02403069], [68.87152863, 23.02403069], [68.87152863, 23.02431107], [68.87097168, 23.02430534], [68.87097168, 23.02458382], [68.87069702, 23.02458], [68.87069702, 23.02486038], [68.87014008, 23.02486038], [68.87014008, 23.02514076], [68.86985779, 23.02514076], [68.86985779, 23.02542114], [68.86930847, 23.02541733], [68.86930847, 23.02569389], [68.86902618, 23.02569389], [68.86902618, 23.02597237], [68.86846924, 23.02596092], [68.86846924, 23.02625084], [68.86763763, 23.02625084], [68.86763763, 23.02653122], [68.86708069, 23.02653122], [68.86708069, 23.02680969], [68.86624908, 23.02680588], [68.86624908, 23.02708244], [68.86569214, 23.02708054], [68.86569214, 23.02736092], [68.86541748, 23.02736092], [68.86541748, 23.02763939], [68.86486053, 23.02763939], [68.86486053, 23.02792168], [68.86458588, 23.02791595], [68.86458588, 23.02819443], [68.86402893, 23.02819443], [68.86402893, 23.0284729], [68.86374664, 23.02846909], [68.86374664, 23.02874947], [68.86319733, 23.02874947], [68.86319733, 23.02902794], [68.86292267, 23.0290184], [68.86292267, 23.02931023], [68.86235809, 23.02930641], [68.86235809, 23.02958107], [68.86208344, 23.02958107], [68.86208344, 23.02985954], [68.86152649, 23.02985954], [68.86152649, 23.03014183], [68.86068726, 23.03014183], [68.86068726, 23.0304203], [68.86013794, 23.0304203], [68.86013794, 23.03070068], [68.85958099, 23.03069305], [68.85958099, 23.03097343], [68.85901642, 23.03096962], [68.85901642, 23.03125191], [68.85819244, 23.03125191], [68.85819244, 23.03153038], [68.85764313, 23.03153038], [68.85764313, 23.03181076], [68.85708618, 23.03181076], [68.85708618, 23.03209114], [68.85680389, 23.0320816], [68.85680389, 23.03236389], [68.85624695, 23.03236008], [68.85624695, 23.03264046], [68.85597229, 23.03264046], [68.85597229, 23.03292084], [68.85541534, 23.03291702], [68.85541534, 23.0331955], [68.85514069, 23.0331955], [68.85514069, 23.03347206], [68.85457611, 23.03347015], [68.85457611, 23.03375053], [68.85430908, 23.03375053], [68.85430908, 23.03403091], [68.85375214, 23.03403091], [68.85375214, 23.03430939], [68.85319519, 23.03430557], [68.85319519, 23.03458595], [68.85263824, 23.03458023], [68.85263824, 23.03486061], [68.8520813, 23.03486061], [68.8520813, 23.03515053], [68.85151672, 23.03515053], [68.85151672, 23.03541946], [68.85097504, 23.03541756], [68.85097504, 23.03569412], [68.85069275, 23.03569412], [68.85069275, 23.0359726], [68.8501358, 23.03597069], [68.8501358, 23.03625107], [68.84958649, 23.03625107], [68.84958649, 23.03652954], [68.84929657, 23.03652954], [68.84929657, 23.03680992], [68.84874725, 23.03680611], [68.84874725, 23.03708267], [68.8484726, 23.03708076], [68.8484726, 23.03736115], [68.84791565, 23.03736115], [68.84792328, 23.03763962], [68.8473587, 23.03763962], [68.8473587, 23.03791809], [68.84708405, 23.03791618], [68.84708405, 23.03819466], [68.8465271, 23.03819466], [68.8465271, 23.03847313], [68.84625244, 23.03847122], [68.84625244, 23.03874969], [68.84570313, 23.03874969], [68.84570313, 23.03902817], [68.84513855, 23.03902817], [68.84513855, 23.03930473], [68.84486389, 23.03930473], [68.84486389, 23.03958321], [68.84430695, 23.03958321], [68.84430695, 23.03986168], [68.84401703, 23.03985977], [68.84401703, 23.04013824], [68.84348297, 23.04013824], [68.84348297, 23.04042053], [68.84291077, 23.04042053], [68.84291077, 23.04070091], [68.84208679, 23.04069519], [68.84208679, 23.04097176], [68.84152985, 23.04096031], [68.84152985, 23.04124832], [68.84124756, 23.04124832], [68.84124756, 23.04153061], [68.8409729, 23.04153061], [68.8409729, 23.0418129], [68.83930206, 23.04180527], [68.83930206, 23.04208374], [68.83875275, 23.04208183], [68.83875275, 23.04236031], [68.83790588, 23.04236031], [68.83790588, 23.04264259], [68.8373642, 23.04263878], [68.8373642, 23.04347038], [68.83597565, 23.04347038], [68.83598328, 23.04375267], [68.83569336, 23.04375267], [68.83569336, 23.04403114], [68.83513641, 23.04403114], [68.83513641, 23.04432106], [68.83486176, 23.0443058], [68.83486176, 23.04458427], [68.83429718, 23.04458046], [68.83430481, 23.04486275], [68.83403778, 23.04486275], [68.83403778, 23.04514122], [68.83347321, 23.04514122], [68.83347321, 23.04541969], [68.83319092, 23.04541588], [68.83319092, 23.04569244], [68.83291626, 23.04569244], [68.83291626, 23.04597473], [68.83235931, 23.04597282], [68.83235931, 23.04624939], [68.83207703, 23.04624939], [68.83207703, 23.04652977], [68.83180237, 23.04652977], [68.83180237, 23.04681015], [68.83125305, 23.04681015], [68.83125305, 23.04709053], [68.83097076, 23.04708481], [68.83097076, 23.04736137], [68.83069611, 23.04735947], [68.83069611, 23.04763985], [68.83013916, 23.04763985], [68.83013916, 23.04792023], [68.8298645, 23.04791641], [68.8298645, 23.04819679], [68.82958221, 23.04819679], [68.82958221, 23.04847145], [68.82902527, 23.04847145], [68.8290329, 23.04874992], [68.82875061, 23.04874992], [68.82875061, 23.0490303], [68.82818604, 23.0490303], [68.82818604, 23.04931068], [68.82791901, 23.04930687], [68.82791901, 23.04958344], [68.82736206, 23.04958344], [68.82736206, 23.04986191], [68.82680511, 23.04986191], [68.82680511, 23.05013847], [68.82653046, 23.05013084], [68.82653046, 23.05042076], [68.82597351, 23.05041695], [68.82596588, 23.0506897], [68.82541656, 23.05069542], [68.82541656, 23.05097198], [68.82514191, 23.05097008], [68.82514191, 23.05125046], [68.82459259, 23.05125046], [68.82459259, 23.05153084], [68.82430267, 23.05153084], [68.82430267, 23.05181122], [68.82375336, 23.0518055], [68.82375336, 23.05208397], [68.82347107, 23.05208015], [68.82347107, 23.05236053], [68.82290649, 23.05236053], [68.82290649, 23.05264091], [68.82263947, 23.05264091], [68.82263947, 23.05291748], [68.82208252, 23.05291748], [68.82208252, 23.05319405], [68.82152557, 23.05319405], [68.82152557, 23.05347252], [68.82125092, 23.05347061], [68.82125092, 23.05374908], [68.82068634, 23.05374908], [68.82068634, 23.05403137], [68.82013702, 23.05403137], [68.82013702, 23.05431175], [68.81986237, 23.05430603], [68.81986237, 23.0545826], [68.81930542, 23.0545826], [68.81931305, 23.05514145], [68.81874084, 23.05514145], [68.81874084, 23.05542183], [68.81847382, 23.05541611], [68.81847382, 23.05569458], [68.81791687, 23.05569458], [68.81791687, 23.05597115], [68.81764221, 23.05596924], [68.81764221, 23.05626106], [68.8170929, 23.05626106], [68.8170929, 23.05653191], [68.81680298, 23.05652809], [68.81680298, 23.05680466], [68.81652832, 23.05680466], [68.81652832, 23.05708122], [68.81847382, 23.05708122], [68.81847382, 23.05680466], [68.81903076, 23.05680466], [68.81903076, 23.05652809], [68.81958008, 23.05653191], [68.81958008, 23.05626106], [68.81986237, 23.05626106], [68.81986237, 23.05596924], [68.82013702, 23.05597115], [68.82013702, 23.05569458], [68.82069397, 23.05569458], [68.82069397, 23.05514145], [68.82096863, 23.05514145], [68.82096863, 23.05485916], [68.8215332, 23.05485916], [68.82152557, 23.0545826], [68.82180786, 23.0545826], [68.82180786, 23.05430603], [68.82319641, 23.05430603], [68.82319641, 23.0545826], [68.82347107, 23.05458069], [68.82347107, 23.05485916], [68.82319641, 23.05485916], [68.82319641, 23.05514145], [68.82208252, 23.05514145], [68.82208252, 23.05542183], [68.82152557, 23.05541611], [68.82152557, 23.05569458], [68.82125092, 23.05569458], [68.82125092, 23.05597115], [68.82096863, 23.05596924], [68.82096863, 23.05626106], [68.82068634, 23.05626106], [68.82068634, 23.05653191], [68.82041931, 23.05652809], [68.82041931, 23.05680466], [68.82013702, 23.05680466], [68.82013702, 23.05708122], [68.81986237, 23.05708122], [68.81986237, 23.05736351], [68.81958008, 23.0573597], [68.81958008, 23.05764008], [68.81931305, 23.05764008], [68.81931305, 23.05792046], [68.81735992, 23.05792046], [68.81735992, 23.05820084], [68.81652832, 23.05820084], [68.81652832, 23.05792046], [68.81624603, 23.05792046], [68.81624603, 23.05820084], [68.81569672, 23.05819511], [68.81569672, 23.05847359], [68.8154068, 23.05846977], [68.8154068, 23.05875015], [68.81513977, 23.05875015], [68.81513977, 23.05903053], [68.81458282, 23.05903053], [68.81458282, 23.05932045], [68.81430817, 23.05932045], [68.81430817, 23.05986023], [68.81458282, 23.05986023], [68.81458282, 23.06069565], [68.81485748, 23.06068993], [68.81485748, 23.06125069], [68.81513977, 23.06125069], [68.81513977, 23.06153107], [68.8154068, 23.06153107], [68.8154068, 23.06180954], [68.81569672, 23.06180954], [68.81569672, 23.06291962], [68.81597137, 23.06291771], [68.81597137, 23.06347275], [68.81569672, 23.06347084], [68.81569672, 23.06375122], [68.81597137, 23.06375122], [68.81597137, 23.06430817], [68.81569672, 23.06430626], [68.81569672, 23.0648613], [68.8154068, 23.06485939], [68.8154068, 23.06541824], [68.81513977, 23.06541824], [68.81513977, 23.06624985], [68.81485748, 23.06624985], [68.81485748, 23.06680489], [68.81458282, 23.06680489], [68.81458282, 23.06736183], [68.81430817, 23.06736183], [68.81430817, 23.06708336], [68.81402588, 23.06708336], [68.81402588, 23.06652832], [68.81430817, 23.06652832], [68.81430817, 23.06624985], [68.81402588, 23.06624985], [68.81402588, 23.06541824], [68.81430817, 23.06541824], [68.81430817, 23.06485939], [68.81458282, 23.0648613], [68.81458282, 23.06458282], [68.81485748, 23.06458282], [68.81485748, 23.06319427], [68.81458282, 23.06319427], [68.81458282, 23.06291771], [68.81430817, 23.06291962], [68.81430817, 23.06264114], [68.81402588, 23.06264114], [68.81402588, 23.06236076], [68.81375122, 23.06236076], [68.81375122, 23.06207085], [68.81346893, 23.0620842], [68.81346893, 23.06180573], [68.81318665, 23.06180954], [68.81318665, 23.06153107], [68.81263733, 23.06153107], [68.81263733, 23.06125069], [68.81236267, 23.06125069], [68.81236267, 23.06097031], [68.81208038, 23.06097221], [68.81208038, 23.06069565], [68.80819702, 23.06069565], [68.80819702, 23.06097221], [68.80735779, 23.06097031], [68.80735779, 23.06125069], [68.80652618, 23.06125069], [68.80652618, 23.06153107], [68.80596924, 23.06153107], [68.80596924, 23.06180954], [68.80513763, 23.06180954], [68.80513763, 23.06236076], [68.80458069, 23.06236076], [68.80458069, 23.06264114], [68.80430603, 23.06264114], [68.80430603, 23.06291962], [68.80374908, 23.06291771], [68.80374908, 23.06319427], [68.80291748, 23.06319427], [68.80291748, 23.06347275], [68.80264282, 23.06347084], [68.80264282, 23.06375122], [68.80208588, 23.06375122], [68.80208588, 23.06402969], [68.80179596, 23.06402969], [68.80179596, 23.06430817], [68.80152893, 23.06430626], [68.80152893, 23.06458282], [68.80069733, 23.06458282], [68.80069733, 23.0648613], [68.80041504, 23.0648613], [68.80041504, 23.06513977], [68.79985809, 23.06513023], [68.79985809, 23.06541824], [68.79958344, 23.06541634], [68.79958344, 23.06569481], [68.79902649, 23.06569481], [68.79902649, 23.06597137], [68.79875183, 23.06596947], [68.79875183, 23.06624985], [68.79818726, 23.06624985], [68.79818726, 23.06652832], [68.79763794, 23.06652832], [68.79763794, 23.06680489], [68.79708099, 23.06680489], [68.79708099, 23.06708336], [68.79624939, 23.06708336], [68.79624939, 23.06736183], [68.79569244, 23.06735992], [68.79569244, 23.0676384], [68.79514313, 23.0676384], [68.79514313, 23.06792068], [68.79458618, 23.06792068], [68.79458618, 23.06819916], [68.79402924, 23.06819534], [68.79402924, 23.06847191], [68.79374695, 23.06846809], [68.79374695, 23.06875229], [68.79319763, 23.06875229], [68.79319763, 23.06903267], [68.79264069, 23.06903267], [68.79264069, 23.06931114], [68.79208374, 23.06930542], [68.79208374, 23.06958389], [68.79180145, 23.06958008], [68.79180145, 23.06986046], [68.79125214, 23.06986046], [68.79125214, 23.07014275], [68.79070282, 23.07014275], [68.79070282, 23.07042122], [68.79013824, 23.0704174], [68.79013824, 23.07069206], [68.7895813, 23.07069206], [68.7895813, 23.07097054], [68.78901672, 23.07097054], [68.78901672, 23.07126045], [68.78875732, 23.07126045], [68.78875732, 23.07152939], [68.78819275, 23.07152939], [68.78819275, 23.07180977], [68.7876358, 23.07180595], [68.7876358, 23.07208443], [68.78708649, 23.07208061], [68.78708649, 23.0723629], [68.78624725, 23.0723629], [68.78624725, 23.07263947], [68.78542328, 23.07263947], [68.78542328, 23.07291985], [68.7848587, 23.07291412], [68.7848587, 23.0731945], [68.7840271, 23.0731945], [68.7840271, 23.07347488], [68.7831955, 23.07347488], [68.78320313, 23.07374954], [68.78235626, 23.07374954], [68.78235626, 23.07402992], [68.78125, 23.07402802], [68.78125, 23.07430649], [68.7804184, 23.07430649], [68.7804184, 23.07458305], [68.77958679, 23.07458305], [68.77958679, 23.07486153], [68.77874756, 23.07485962], [68.77874756, 23.07514], [68.7776413, 23.07514], [68.7776413, 23.07542038], [68.77680206, 23.07542038], [68.77680206, 23.07570076], [68.7756958, 23.07569695], [68.7756958, 23.0759716], [68.77485657, 23.0759697], [68.7748642, 23.07625008], [68.77375793, 23.07625008], [68.77375793, 23.07653046], [68.77263641, 23.07653046], [68.77263641, 23.07681084], [68.77153015, 23.07680511], [68.77153015, 23.07708359], [68.77041626, 23.07708359], [68.77041626, 23.07736206], [68.76902771, 23.07736015], [68.76902771, 23.07764053], [68.76790619, 23.07764053], [68.76790619, 23.07792091], [68.76680756, 23.0779171], [68.76680756, 23.07819366], [68.76579285, 23.07819366], [68.76541901, 23.07819366], [68.76541901, 23.07847214], [68.76430511, 23.07847214], [68.76431274, 23.07875061], [68.76235962, 23.07875061], [68.76235962, 23.07902908], [68.76180267, 23.07902908], [68.76180267, 23.07930756], [68.76125336, 23.07930565], [68.76125336, 23.07958412], [68.76097107, 23.07958031], [68.76097107, 23.07986069], [68.76040649, 23.07986069], [68.76040649, 23.08013916], [68.75985718, 23.08013916], [68.75985718, 23.08042145], [68.75930786, 23.08041763], [68.75930786, 23.0806942], [68.75902557, 23.0806942], [68.75902557, 23.08097267], [68.75846863, 23.08097076], [68.75846863, 23.08124924], [68.75818634, 23.08124924], [68.75818634, 23.08153152], [68.75791931, 23.08153152], [68.75791931, 23.0818119], [68.75736237, 23.0818119], [68.75736237, 23.08235931], [68.75708008, 23.08235931], [68.75708008, 23.08292007], [68.75680542, 23.08291626], [68.75680542, 23.08346939], [68.75653076, 23.08346939], [68.75653076, 23.08403015], [68.75624847, 23.08402824], [68.75624847, 23.08430481], [68.75541687, 23.08430481], [68.75541687, 23.08458138], [68.75485992, 23.08458138], [68.75485992, 23.08486366], [68.75402832, 23.08485985], [68.75402832, 23.08514023], [68.75374603, 23.08514023], [68.75374603, 23.08542061], [68.75347137, 23.08541679], [68.75347137, 23.08597374], [68.75319672, 23.08597374], [68.75319672, 23.08625031], [68.7529068, 23.08624268], [68.7529068, 23.08653069], [68.75263214, 23.08653069], [68.75263214, 23.08681107], [68.75208282, 23.08680534], [68.75208282, 23.08708572], [68.75180817, 23.08708], [68.75180817, 23.08736038], [68.75152588, 23.08736038], [68.75152588, 23.08764076], [68.75125122, 23.08764076], [68.75125122, 23.08792114], [68.75069427, 23.08791733], [68.75069427, 23.0881958], [68.75041962, 23.0881958], [68.75041962, 23.08847237], [68.75013733, 23.08847046], [68.75013733, 23.08875084], [68.74986267, 23.08875084], [68.74986267, 23.08903122], [68.74958038, 23.0890274], [68.74958038, 23.08930588], [68.74930573, 23.08930588], [68.74931335, 23.08986092], [68.74903107, 23.08986092], [68.74903107, 23.09013939], [68.74874878, 23.09013939], [68.74874878, 23.09041977], [68.74847412, 23.09041786], [68.74847412, 23.09069443], [68.74819183, 23.09069443], [68.74819183, 23.0909729], [68.74791718, 23.09097099], [68.74791718, 23.09124947], [68.74736023, 23.09124947], [68.74736023, 23.09152985], [68.7470932, 23.09152985], [68.7470932, 23.09181023], [68.74652863, 23.09180641], [68.74652863, 23.09208298], [68.74624634, 23.09208298], [68.74624634, 23.09236145], [68.74597168, 23.09235954], [68.74597168, 23.09263992], [68.74569702, 23.09263992], [68.74569702, 23.0929184], [68.7454071, 23.0929184], [68.7454071, 23.09320068], [68.74514008, 23.09319496], [68.74514008, 23.09347153], [68.74485779, 23.09346962], [68.74485779, 23.09374809], [68.74458313, 23.09374809], [68.74458313, 23.09402847], [68.74430847, 23.09402847], [68.74430847, 23.09431076], [68.74402618, 23.09430504], [68.74402618, 23.09458351], [68.74375153, 23.09458351], [68.74375153, 23.09486008], [68.74402618, 23.09486008], [68.74402618, 23.09517097], [68.74402618, 23.09543037], [68.74375153, 23.09541702], [68.74375153, 23.09597015], [68.74346161, 23.09597015], [68.74346161, 23.09625244], [68.74291992, 23.09625244], [68.74291992, 23.09653282], [68.74236298, 23.09653282], [68.74236298, 23.09680939], [68.74180603, 23.09680557], [68.74180603, 23.09708214], [68.74153137, 23.09708023], [68.74153137, 23.09736061], [68.7409668, 23.09736061], [68.7409668, 23.0976429], [68.74041748, 23.0976429], [68.74041748, 23.09791946], [68.74013519, 23.09791756], [68.74013519, 23.09819221], [68.73986053, 23.09819221], [68.73986053, 23.0984745], [68.73958588, 23.09847069], [68.73958588, 23.09875107], [68.73929596, 23.09875107], [68.73929596, 23.09902954], [68.73874664, 23.09902954], [68.73874664, 23.09930992], [68.73847198, 23.09930611], [68.73847198, 23.09958458], [68.73819733, 23.09958076], [68.73819733, 23.09986115], [68.73791504, 23.09986115], [68.73791504, 23.10013962], [68.73764801, 23.10013962], [68.73764801, 23.10042], [68.73735809, 23.10041618], [68.73735809, 23.10069466], [68.73708344, 23.10069466], [68.73708344, 23.10097313], [68.73652649, 23.10097313], [68.73652649, 23.10124969], [68.73625183, 23.10124016], [68.73625183, 23.10153008], [68.73596954, 23.10152817], [68.73596954, 23.10180664], [68.73569489, 23.10180664], [68.73569489, 23.10208321], [68.73542023, 23.10208321], [68.73542023, 23.10236168], [68.73486328, 23.10235977], [68.73486328, 23.10264015], [68.73458862, 23.10264015], [68.73458862, 23.10292053], [68.73430634, 23.10292053], [68.73430634, 23.10320091], [68.73374939, 23.10319519], [68.73374939, 23.10347176], [68.7334671, 23.10346985], [68.7334671, 23.10375023], [68.73319244, 23.10375023], [68.73319244, 23.10403061], [68.7326355, 23.1040287], [68.7326355, 23.10430527], [68.73236084, 23.10430527], [68.73236084, 23.10458374], [68.73208618, 23.10457993], [68.73208618, 23.10486031], [68.73179626, 23.10486031], [68.73179626, 23.10514069], [68.73124695, 23.10514069], [68.73124695, 23.10542107], [68.73097229, 23.10541725], [68.73097229, 23.10569382], [68.73069763, 23.10569382], [68.73069763, 23.10597229], [68.73041534, 23.10597229], [68.73042297, 23.10625076], [68.7298584, 23.10625076], [68.7298584, 23.10652924], [68.72957611, 23.10652924], [68.72957611, 23.10680962], [68.72930908, 23.1068058], [68.72930908, 23.10708427], [68.72902679, 23.10708046], [68.72902679, 23.10737038], [68.72846222, 23.10737038], [68.72846222, 23.10763931], [68.72820282, 23.10763931], [68.72820282, 23.1079216], [68.72763824, 23.10791588], [68.72763824, 23.10819435], [68.72736359, 23.10819435], [68.72736359, 23.10847282], [68.72680664, 23.10847092], [68.72680664, 23.10874939], [68.72651672, 23.10874939], [68.72651672, 23.10903168], [68.72598267, 23.10903168], [68.72598267, 23.10931015], [68.72569275, 23.10930634], [68.72569275, 23.1095829], [68.7251358, 23.1095829], [68.7251358, 23.10985947], [68.72458649, 23.10985947], [68.72458649, 23.11014175], [68.72402954, 23.11014175], [68.72402954, 23.11042976], [68.72374725, 23.11041641], [68.72374725, 23.11069489], [68.72319794, 23.11069489], [68.72319794, 23.11097145], [68.72264099, 23.11097145], [68.72264862, 23.11125183], [68.72180939, 23.11125183], [68.72180176, 23.1115303], [68.72125244, 23.1115303], [68.72125244, 23.11181068], [68.72097015, 23.11180305], [68.72097015, 23.11236382], [68.72070312, 23.11236], [68.72070312, 23.11292076], [68.72041321, 23.11291695], [68.72041321, 23.11318016], [68.72013855, 23.11319542], [68.72013855, 23.11347389], [68.71985626, 23.11347008], [68.71985626, 23.11375046], [68.7195816, 23.11375046], [68.7195816, 23.11403084], [68.71901703, 23.11403084], [68.71901703, 23.11431122], [68.71847534, 23.1143055], [68.71847534, 23.11458588], [68.71819305, 23.11458015], [68.71819305, 23.11486053], [68.7179184, 23.11486053], [68.7179184, 23.11514091], [68.71736145, 23.11514091], [68.71736145, 23.11541939], [68.71708679, 23.11541748], [68.71708679, 23.11569595], [68.7168045, 23.11569595], [68.7168045, 23.11597252], [68.71652985, 23.11597252], [68.71652985, 23.11624908], [68.71624756, 23.11623955], [68.71624756, 23.11652946], [68.71569824, 23.11652946], [68.71569824, 23.11680984], [68.71541595, 23.11680794], [68.71541595, 23.1170826], [68.71485901, 23.11708069], [68.71485901, 23.11736107], [68.71457672, 23.11736107], [68.71457672, 23.11763954], [68.7140274, 23.11763954], [68.7140274, 23.11791992], [68.71375275, 23.11791611], [68.71375275, 23.11819458], [68.71347046, 23.11819458], [68.71347046, 23.11847305], [68.71290588, 23.11847115], [68.71290588, 23.11874962], [68.71263885, 23.11874962], [68.71263885, 23.11902809], [68.71208191, 23.11902809], [68.71208191, 23.11931038], [68.71180725, 23.11930466], [68.71180725, 23.11958313], [68.71125031, 23.11958313], [68.71125031, 23.1198616], [68.71098328, 23.1198597], [68.71098328, 23.12013817], [68.7104187, 23.12013817], [68.7104187, 23.12042046], [68.71013641, 23.12042046], [68.71013641, 23.12070084], [68.7095871, 23.12069511], [68.7095871, 23.12097168], [68.70929718, 23.12096977], [68.70929718, 23.12124825], [68.70819092, 23.12124825], [68.70819092, 23.12152863], [68.70791626, 23.12152863], [68.70791626, 23.12181091], [68.70735931, 23.12180519], [68.70735931, 23.12208366], [68.70707703, 23.12207985], [68.70707703, 23.12236977], [68.70680237, 23.12236977], [68.70680237, 23.12264252], [68.70625305, 23.12264252], [68.70625305, 23.1229229], [68.70597076, 23.12291718], [68.70597076, 23.12319374], [68.70569611, 23.12319374], [68.70569611, 23.12347031], [68.70513916, 23.12347031], [68.70513916, 23.12375259], [68.70485687, 23.12375259], [68.70485687, 23.12403107], [68.70430756, 23.12403107], [68.70430756, 23.12430954], [68.70402527, 23.12430573], [68.70402527, 23.12458229], [68.70347595, 23.12458038], [68.70347595, 23.12486267], [68.70318604, 23.12486267], [68.70318604, 23.12514114], [68.70291901, 23.12513924], [68.70291901, 23.1254158], [68.70236206, 23.1254158], [68.70236206, 23.12569237], [68.70207977, 23.12569237], [68.70207977, 23.12597466], [68.70181274, 23.12597084], [68.70181274, 23.12625122], [68.70153809, 23.12625122], [68.70153809, 23.12652969], [68.70096588, 23.12652969], [68.70096588, 23.12681007], [68.70069122, 23.12680626], [68.70069122, 23.12708473], [68.70014191, 23.12708473], [68.70014191, 23.1273613], [68.69985962, 23.12735939], [68.69985962, 23.12763977], [68.69930267, 23.12763977], [68.69930267, 23.12792015], [68.69902802, 23.12791634], [68.69902802, 23.12819672], [68.69847107, 23.12819672], [68.69847107, 23.12847137], [68.69763947, 23.12846947], [68.69763947, 23.12874985], [68.69680786, 23.12874985], [68.69680786, 23.12903023], [68.69652557, 23.12902832], [68.69652557, 23.12930679], [68.69596863, 23.12930679], [68.69596863, 23.12958336], [68.69541931, 23.12958336], [68.69541931, 23.12986183], [68.69513702, 23.12985992], [68.69513702, 23.1301403], [68.69458008, 23.1301403], [68.69458008, 23.13042068], [68.69403076, 23.13042068], [68.69403076, 23.13070107], [68.69374847, 23.13069534], [68.69374847, 23.13097191], [68.69319153, 23.13097], [68.69319153, 23.13125038], [68.69264221, 23.13125038], [68.69264221, 23.13153839], [68.69235229, 23.13153839], [68.69235229, 23.13181114], [68.69180298, 23.13180542], [68.69180298, 23.13208389], [68.69152832, 23.13208008], [68.69152832, 23.13236046], [68.69097137, 23.13236046], [68.69097137, 23.13264084], [68.6904068, 23.13264084], [68.6904068, 23.13292122], [68.69013977, 23.1329174], [68.69013977, 23.13319397], [68.68958282, 23.13319397], [68.68958282, 23.13347244], [68.68930817, 23.13347054], [68.68930817, 23.13375092], [68.68875122, 23.13375092], [68.68875122, 23.1340313], [68.68818665, 23.1340313], [68.68818665, 23.13431168], [68.68791962, 23.13430595], [68.68791962, 23.13458252], [68.68736267, 23.13458061], [68.68736267, 23.13485909], [68.68708038, 23.13485909], [68.68708038, 23.13513947], [68.6865387, 23.13513947], [68.6865387, 23.13542175], [68.68624878, 23.13541603], [68.68624878, 23.1356945], [68.68569183, 23.1356945], [68.68569183, 23.13597107], [68.68541718, 23.13596916], [68.68541718, 23.13624954], [68.68486023, 23.13624954], [68.68486023, 23.13653183], [68.6845932, 23.13653183], [68.6845932, 23.1368103], [68.68402863, 23.13680649], [68.68402863, 23.13708115], [68.68374634, 23.13708115], [68.68374634, 23.13736343], [68.68319702, 23.13735008], [68.68319702, 23.13764191], [68.6829071, 23.13764191], [68.6829071, 23.13792038], [68.68235779, 23.13792038], [68.68235779, 23.13820076], [68.68208313, 23.13819313], [68.68208313, 23.13847351], [68.68152618, 23.1384697], [68.68152618, 23.13875008], [68.68125153, 23.13875008], [68.68125153, 23.13903046], [68.68068695, 23.13903046], [68.68068695, 23.13931084], [68.68041992, 23.13930321], [68.68041992, 23.13958168], [68.67903137, 23.13958168], [68.67903137, 23.13986206], [68.67874908, 23.13986015], [68.67874908, 23.14014053], [68.67778015, 23.14013863], [68.67763519, 23.14013863], [68.67763519, 23.1402626], [68.67763519, 23.1404171], [68.6774292, 23.1404171], [68.67708588, 23.1404171], [68.67708588, 23.14069557], [68.67652893, 23.14069557], [68.67652893, 23.14097214], [68.67597198, 23.14097023], [68.67597198, 23.14125061], [68.67542267, 23.14125061], [68.67542267, 23.14153099], [68.67457581, 23.14153099], [68.67457581, 23.14180946], [68.67430878, 23.14180565], [68.67430878, 23.14208412], [68.67318726, 23.14208031], [68.67318726, 23.14236069], [68.67263794, 23.14236069], [68.67263794, 23.14264107], [68.67236328, 23.14264107], [68.67236328, 23.14291954], [68.67180634, 23.14291763], [68.67180634, 23.1431942], [68.67124939, 23.14319038], [68.67124939, 23.1434803], [68.67069244, 23.1434803], [68.67069244, 23.14375114], [68.67014313, 23.14375114], [68.67014313, 23.14402962], [68.66958618, 23.14402962], [68.66958618, 23.14430809], [68.66902924, 23.14430618], [68.66902924, 23.14458275], [68.66847229, 23.14458084], [68.66847229, 23.14486122], [68.66819763, 23.14486122], [68.66819763, 23.14513969], [68.66764069, 23.14513969], [68.66764069, 23.14541817], [68.66708374, 23.14541626], [68.66708374, 23.14569473], [68.66680908, 23.14569473], [68.66680908, 23.1459713], [68.66625214, 23.14596939], [68.66625214, 23.14624977], [68.66596985, 23.14624977], [68.66596985, 23.1465416], [68.6654129, 23.14652824], [68.6654129, 23.14680481], [68.66486359, 23.14680481], [68.66486359, 23.14708328], [68.66430664, 23.14708328], [68.66430664, 23.14736176], [68.66374969, 23.14735985], [68.66374969, 23.14763832], [68.66348267, 23.14763832], [68.66348267, 23.14792061], [68.66291809, 23.14792061], [68.66291809, 23.14819908], [68.66236115, 23.14819527], [68.66236115, 23.14847183], [68.66208649, 23.14846992], [68.66208649, 23.14875031], [68.66152954, 23.14875031], [68.66152954, 23.14903259], [68.6609726, 23.14903259], [68.6609726, 23.14931107], [68.66034698, 23.14930534], [68.66014099, 23.14930534], [68.66014099, 23.14948082], [68.66014099, 23.14958382], [68.65957642, 23.14958191], [68.65957642, 23.14986038], [68.6590271, 23.14986038], [68.6590271, 23.15014267], [68.65875244, 23.15014267], [68.65875244, 23.15042114], [68.65847015, 23.15041733], [68.65847015, 23.15069389], [68.6581955, 23.15069389], [68.6581955, 23.15097046], [68.65791321, 23.15097046], [68.65791321, 23.15125275], [68.65763855, 23.15125275], [68.65763855, 23.15153122], [68.65736389, 23.1515274], [68.65736389, 23.15208435], [68.6570816, 23.15208435], [68.6570816, 23.15236282], [68.65624237, 23.15234947], [68.65624237, 23.15263939], [68.65569305, 23.15263939], [68.65569305, 23.15291977], [68.6554184, 23.15291405], [68.6554184, 23.15319252], [68.65486145, 23.15319252], [68.65486145, 23.15347481], [68.65458679, 23.1534729], [68.65458679, 23.15374947], [68.65429688, 23.15374947], [68.65429688, 23.15402985], [68.65374756, 23.15402985], [68.65374756, 23.15431023], [68.6534729, 23.15430641], [68.6534729, 23.15458488], [68.65291595, 23.15458488], [68.65291595, 23.15486145], [68.6526413, 23.15485954], [68.6526413, 23.15513992], [68.65235901, 23.15513992], [68.65235901, 23.15571022], [68.65208435, 23.15569687], [68.65208435, 23.15597153], [68.65180206, 23.15596962], [68.65180206, 23.15625], [68.6515274, 23.15625], [68.6515274, 23.15681076], [68.65125275, 23.15680695], [68.65125275, 23.15708351], [68.65097046, 23.1570797], [68.65097046, 23.15764046], [68.6506958, 23.15764046], [68.6506958, 23.15792084], [68.65041351, 23.15791893], [68.65041351, 23.15819359], [68.65013885, 23.15818977], [68.65013885, 23.15847969], [68.64958191, 23.15847969], [68.64958191, 23.15875053], [68.64930725, 23.15875053], [68.64930725, 23.15903091], [68.64903259, 23.15903091], [68.64903259, 23.15930748], [68.64875031, 23.15930748], [68.64875031, 23.16013908], [68.6479187, 23.16013908], [68.6479187, 23.16041756], [68.64763641, 23.16041756], [68.64763641, 23.1609726], [68.64736176, 23.1609726], [68.64736176, 23.16152763], [68.6470871, 23.1615181], [68.6470871, 23.16181183], [68.64680481, 23.16180611], [68.64680481, 23.16208267], [68.64653015, 23.16208076], [68.64653015, 23.16235924], [68.64624786, 23.16235924], [68.64624786, 23.16263962], [68.64597321, 23.16263962], [68.64597321, 23.16292191], [68.64569092, 23.16291618], [68.64569092, 23.16319466], [68.64541626, 23.16319466], [68.64541626, 23.16347122], [68.6451416, 23.16346931], [68.6451416, 23.16403008], [68.64485931, 23.16402817], [68.64485931, 23.16430473], [68.64375305, 23.16430473], [68.64375305, 23.16486359], [68.64347076, 23.16485977], [68.64347076, 23.16514015], [68.64180756, 23.16514015], [68.64180756, 23.16542053], [68.64152527, 23.16541672], [68.64152527, 23.16597366], [68.64124298, 23.16596985], [68.64124298, 23.16653061], [68.64097595, 23.16653061], [68.64097595, 23.16681099], [68.64069366, 23.16680336], [68.64069366, 23.16708565], [68.64041901, 23.16707993], [68.64041901, 23.16736031], [68.63986206, 23.16736031], [68.63986206, 23.16765022], [68.63957977, 23.16765022], [68.63957977, 23.16792107], [68.63903046, 23.16791725], [68.63903046, 23.16819572], [68.63847351, 23.16819572], [68.63847351, 23.16847229], [68.63791656, 23.16847038], [68.63791656, 23.16875076], [68.63764191, 23.16875076], [68.63764191, 23.16903114], [68.63709259, 23.16903114], [68.63709259, 23.16930962], [68.63680267, 23.1693058], [68.63680267, 23.16958427], [68.63597107, 23.16958046], [68.63597107, 23.16986084], [68.63569641, 23.16986084], [68.63569641, 23.17014122], [68.63513947, 23.17014122], [68.63513947, 23.17041969], [68.63458252, 23.17041779], [68.63458252, 23.17069435], [68.63430786, 23.17069435], [68.63430786, 23.17097282], [68.63375092, 23.17097092], [68.63375092, 23.17124939], [68.63346863, 23.17124939], [68.63346863, 23.17152977], [68.63291931, 23.17152977], [68.63291931, 23.17180824], [68.63263702, 23.17180634], [68.63263702, 23.1720829], [68.63236237, 23.1720829], [68.63236237, 23.17236137], [68.63207245, 23.17235947], [68.63208008, 23.17263985], [68.63181305, 23.17263985], [68.63181305, 23.17291832], [68.63153076, 23.17291641], [68.63153076, 23.17319489], [68.63124847, 23.17319489], [68.63124847, 23.17347145], [68.63096619, 23.17346001], [68.63096619, 23.17374992], [68.63069153, 23.17374992], [68.63069153, 23.17431068], [68.63041687, 23.17430496], [68.63041687, 23.17597008], [68.63069153, 23.17597008], [68.63069153, 23.17652702], [68.63097382, 23.17652702], [68.63097382, 23.17708206], [68.63124847, 23.17708015], [68.63124847, 23.17736053], [68.63236237, 23.17736053], [68.63236237, 23.17764282], [68.63346863, 23.17764282], [68.63346863, 23.17736053], [68.6340332, 23.17736053], [68.63402557, 23.17708206], [68.63458252, 23.17708206], [68.63458252, 23.1768055], [68.63485718, 23.17681122], [68.63485718, 23.17625046], [68.63513947, 23.17625046], [68.63513947, 23.17597008], [68.63541412, 23.17597008], [68.63541412, 23.17569351], [68.63569641, 23.17569351], [68.63569641, 23.17541695], [68.63540649, 23.17542267], [68.63540649, 23.17513847], [68.63513947, 23.17513847], [68.63513947, 23.17485809], [68.63486481, 23.17486191], [68.63486481, 23.17458344], [68.63430786, 23.17458344], [68.63430786, 23.17430496], [68.63513947, 23.17431068], [68.63513947, 23.17291832], [68.63485718, 23.17291832], [68.63485718, 23.17263985], [68.63458252, 23.17263985], [68.63458252, 23.17208099], [68.63541412, 23.1720829], [68.63541412, 23.17236137], [68.63597107, 23.17235947], [68.63597107, 23.17263985], [68.63652802, 23.17263985], [68.63652802, 23.17235947], [68.63680267, 23.17236137], [68.63680267, 23.1720829], [68.63708496, 23.1720829], [68.63708496, 23.17180634], [68.63764191, 23.17180824], [68.63764191, 23.17152977], [68.63791656, 23.17152977], [68.63791656, 23.17124939], [68.63819885, 23.17124939], [68.63819122, 23.17097282], [68.63847351, 23.17097282], [68.63847351, 23.17069435], [68.63903046, 23.17069435], [68.63903046, 23.17041779], [68.63931274, 23.17041969], [68.63931274, 23.17014122], [68.63986206, 23.17014122], [68.63986206, 23.16986084], [68.64013672, 23.16986084], [68.64013672, 23.16958046], [68.64069366, 23.16958237], [68.64069366, 23.1693058], [68.64124298, 23.16930962], [68.64124298, 23.16903114], [68.64180756, 23.16903114], [68.64180756, 23.16875076], [68.64235687, 23.16875076], [68.64235687, 23.16847038], [68.64291382, 23.16847229], [68.64291382, 23.16819572], [68.64402771, 23.16819572], [68.64402771, 23.16791725], [68.64485931, 23.16792107], [68.64485931, 23.16765022], [68.64541626, 23.16765022], [68.64541626, 23.16736031], [68.64597321, 23.16736031], [68.64597321, 23.16707993], [68.64485931, 23.16708565], [68.64485931, 23.16680336], [68.64402771, 23.16681099], [68.64402771, 23.16653061], [68.64597321, 23.16653061], [68.64597321, 23.16625023], [68.64624786, 23.16625023], [68.64624786, 23.16596985], [68.64653015, 23.16597366], [68.64653015, 23.16569519], [68.64679718, 23.16570091], [68.64679718, 23.16542053], [68.64736938, 23.16542053], [68.64736938, 23.16485977], [68.64763641, 23.16486359], [68.64763641, 23.16430473], [68.6479187, 23.16430473], [68.6479187, 23.16374969], [68.64819336, 23.16374969], [68.64819336, 23.16346931], [68.64847565, 23.16347122], [68.64847565, 23.16291618], [68.64875031, 23.16292191], [68.64875031, 23.16263962], [68.64903259, 23.16263962], [68.64902496, 23.16208267], [68.64930725, 23.16208267], [68.64930725, 23.16180611], [68.64958191, 23.16181183], [68.64958191, 23.1615181], [68.6498642, 23.16152763], [68.6498642, 23.16124916], [68.65013885, 23.16124916], [68.65013885, 23.16097069], [68.65041351, 23.1609726], [68.65041351, 23.16069412], [68.6506958, 23.16069412], [68.6506958, 23.16041756], [68.65097046, 23.16041756], [68.65097046, 23.15930748], [68.65125275, 23.15930748], [68.65125275, 23.15903091], [68.6515274, 23.15903091], [68.6515274, 23.15847969], [68.65180206, 23.15847969], [68.65180206, 23.15818977], [68.65208435, 23.15819359], [68.65208435, 23.15791893], [68.65235901, 23.15792084], [68.65235901, 23.15764046], [68.6526413, 23.15764046], [68.6526413, 23.1570797], [68.65291595, 23.15708351], [68.65291595, 23.15680695], [68.65318298, 23.15681076], [68.65319824, 23.15653038], [68.6534729, 23.15653038], [68.6534729, 23.15596962], [68.65374756, 23.15597153], [68.65374756, 23.15569687], [68.65402985, 23.15571022], [68.65402985, 23.1554203], [68.65429688, 23.1554203], [68.65429688, 23.15513992], [68.65486145, 23.15513992], [68.65486145, 23.15485954], [68.65513611, 23.15486145], [68.65513611, 23.15430641], [68.6554184, 23.15431023], [68.6554184, 23.15374947], [68.65569305, 23.15374947], [68.65569305, 23.1534729], [68.65625, 23.15347481], [68.65625, 23.15319252], [68.65680695, 23.15319252], [68.65680695, 23.15291405], [68.65735626, 23.15291977], [68.65735626, 23.15263939], [68.65791321, 23.15263939], [68.65791321, 23.15234947], [68.65847015, 23.15236282], [68.65847015, 23.15208435], [68.65875244, 23.15208435], [68.65875244, 23.15180588], [68.65930939, 23.15180969], [68.65930939, 23.15153122], [68.65957642, 23.15153122], [68.65957642, 23.15125275], [68.66069794, 23.15125275], [68.66069794, 23.15153122], [68.66124725, 23.15153122], [68.66124725, 23.15180969], [68.66152954, 23.15180969], [68.66152954, 23.15153122], [68.66208649, 23.15153122], [68.66208649, 23.15125275], [68.66319275, 23.15125275], [68.66319275, 23.15097046], [68.66374969, 23.15097046], [68.66374969, 23.15069389], [68.66402435, 23.15069389], [68.66402435, 23.15041733], [68.6645813, 23.15042114], [68.6645813, 23.15014267], [68.66485596, 23.15014267], [68.66485596, 23.14986038], [68.66513824, 23.14986038], [68.66513824, 23.14958191], [68.6654129, 23.14958382], [68.6654129, 23.14930534], [68.66596985, 23.14931107], [68.66596985, 23.14903259], [68.66625214, 23.14903259], [68.66625214, 23.14875031], [68.66652679, 23.14875031], [68.66652679, 23.14846992], [68.66680908, 23.14847183], [68.66680908, 23.14819527], [68.66707611, 23.14819908], [68.66707611, 23.14792061], [68.6673584, 23.14792061], [68.6673584, 23.14763832], [68.66764069, 23.14763832], [68.66764069, 23.14735985], [68.66819763, 23.14736176], [68.66819763, 23.14708328], [68.66847229, 23.14708328], [68.66847229, 23.14680481], [68.66874695, 23.14680481], [68.66874695, 23.1459713], [68.67124939, 23.1459713], [68.67124939, 23.14569473], [68.67152405, 23.14569473], [68.67152405, 23.14541626], [68.67180634, 23.14541817], [68.67180634, 23.14486122], [68.67208099, 23.14486122], [68.67208099, 23.14430809], [68.67236328, 23.14430809], [68.67236328, 23.14402962], [68.67263794, 23.14402962], [68.67263794, 23.14375114], [68.67318726, 23.14375114], [68.67318726, 23.1434803], [68.67410278, 23.14347458], [68.67430878, 23.1434803], [68.67430878, 23.1431942], [68.67541504, 23.1431942], [68.67541504, 23.14291763], [68.67597198, 23.14291954], [68.67597198, 23.14264107], [68.67679596, 23.14264107], [68.67679596, 23.14236069], [68.67764282, 23.14236069], [68.67763519, 23.14208412], [68.67847443, 23.14208412], [68.67847443, 23.14180565], [68.67903137, 23.14180946], [68.67903137, 23.14153099], [68.67986298, 23.14153099], [68.67986298, 23.14180946], [68.68049622, 23.14180756], [68.68152618, 23.14180565], [68.68152618, 23.14208412], [68.68096924, 23.14208031], [68.68096924, 23.14236069], [68.68068695, 23.14236069], [68.68068695, 23.14264107], [68.68013763, 23.14264107], [68.68013763, 23.14291954], [68.67980194, 23.14291763], [68.67930603, 23.14291763], [68.67930603, 23.1431942], [68.67791748, 23.14319038], [68.67791748, 23.1434803], [68.67764282, 23.1434803], [68.67764282, 23.14402962], [68.67735291, 23.14402962], [68.67735291, 23.14486122], [68.67679596, 23.14486122], [68.67679596, 23.14513969], [68.67652893, 23.14513969], [68.67652893, 23.14541817], [68.67597198, 23.14541626], [68.67597198, 23.14569473], [68.67569733, 23.14569473], [68.67569733, 23.1459713], [68.67514038, 23.14596939], [68.67514038, 23.14624977], [68.67485809, 23.14624977], [68.67485809, 23.1465416], [68.67180634, 23.14652824], [68.67180634, 23.14680481], [68.67124939, 23.14680481], [68.67124939, 23.14708328], [68.6709671, 23.14707947], [68.6709671, 23.14763832], [68.67069244, 23.14763832], [68.67069244, 23.14819908], [68.67041779, 23.14819908], [68.67041779, 23.14875031], [68.67014313, 23.14875031], [68.67014313, 23.14931107], [68.66986084, 23.14930534], [68.66986084, 23.14958382], [68.66958618, 23.14958191], [68.66958618, 23.14986038], [68.66902924, 23.14986038], [68.66902924, 23.15014267], [68.66874695, 23.15014267], [68.66874695, 23.15042114], [68.66847229, 23.15041733], [68.66847229, 23.15069389], [68.66819763, 23.15069389], [68.66819763, 23.15097046], [68.66792297, 23.15097046], [68.66792297, 23.15153122], [68.66764069, 23.15153122], [68.66764069, 23.15180969], [68.6673584, 23.15180588], [68.6673584, 23.15208435], [68.66707611, 23.15208054], [68.66707611, 23.15263939], [68.66680908, 23.15263939], [68.66680908, 23.15291977], [68.66596985, 23.15291405], [68.66596985, 23.15319252], [68.66486359, 23.15319252], [68.66486359, 23.15347481], [68.66401672, 23.1534729], [68.66402435, 23.15374947], [68.66330719, 23.15374947], [68.66319275, 23.15374947], [68.66319275, 23.15385056], [68.66319275, 23.15402985], [68.66300964, 23.15402985], [68.65834808, 23.15402985], [68.65820313, 23.15402985], [68.65820313, 23.15431023], [68.65736389, 23.15430641], [68.65736389, 23.15458488], [68.6570816, 23.15458488], [68.6570816, 23.15486145], [68.65651703, 23.15485954], [68.65651703, 23.15513992], [68.65598297, 23.15513992], [68.65598297, 23.1554203], [68.65569305, 23.15541649], [68.65569305, 23.15597153], [68.65513611, 23.15596962], [68.65513611, 23.15625], [68.65486145, 23.15625], [68.65486145, 23.15736198], [68.65458679, 23.15736198], [68.65458679, 23.15958405], [68.65429688, 23.15958023], [68.65429688, 23.16013908], [68.65402985, 23.16013718], [68.65402985, 23.16069412], [68.65374756, 23.16069031], [68.65374756, 23.16124916], [68.6534729, 23.16124916], [68.6534729, 23.16181183], [68.65319824, 23.16181183], [68.65319824, 23.16235924], [68.65291595, 23.16235924], [68.65291595, 23.16263962], [68.6526413, 23.16263962], [68.6526413, 23.16292191], [68.65235901, 23.16291618], [68.65235901, 23.16347122], [68.65207672, 23.16346931], [68.65207672, 23.16374969], [68.65180206, 23.16374969], [68.65180206, 23.16403008], [68.6515274, 23.16402817], [68.6515274, 23.16430473], [68.65125275, 23.16430473], [68.65125275, 23.1645813], [68.65097046, 23.16457939], [68.65097046, 23.16514015], [68.6506958, 23.16514015], [68.6506958, 23.16542053], [68.65041351, 23.16541672], [68.65041351, 23.16597366], [68.6506958, 23.16597366], [68.6506958, 23.16708565], [68.65097046, 23.16707993], [68.65097046, 23.16736031], [68.6506958, 23.16736031], [68.6506958, 23.16765022], [68.65041351, 23.16763878], [68.65041351, 23.16819572], [68.65013885, 23.16819572], [68.65013885, 23.16847229], [68.64985657, 23.16847038], [68.64985657, 23.16903114], [68.64958191, 23.16902733], [68.64958191, 23.16922569], [68.64958191, 23.1693058], [68.64930725, 23.1693058], [68.64930725, 23.16942024], [68.64930725, 23.16986084], [68.64903259, 23.16986084], [68.64903259, 23.17014122], [68.64875031, 23.17013931], [68.64875031, 23.17069435], [68.64847565, 23.17069435], [68.64847565, 23.17097282], [68.64819336, 23.17097092], [68.64819336, 23.17124939], [68.6479187, 23.17124939], [68.6479187, 23.17097092], [68.64669037, 23.17097092], [68.64653015, 23.17097092], [68.64653015, 23.17124939], [68.6462326, 23.17124939], [68.64597321, 23.17124939], [68.64592743, 23.17147255], [68.64585876, 23.17152786], [68.6451416, 23.17152977], [68.6451416, 23.17180824], [68.64458466, 23.17180634], [68.64458466, 23.1720829], [68.64430237, 23.1720829], [68.64430237, 23.17236137], [68.64402771, 23.17235947], [68.64402771, 23.17263985], [68.64375305, 23.17263985], [68.64375305, 23.17319489], [68.64363098, 23.17319489], [68.64319611, 23.17319489], [68.64319611, 23.17347145], [68.64290619, 23.17346001], [68.64290619, 23.17374992], [68.64319611, 23.17374992], [68.64319611, 23.1740284], [68.64291382, 23.1740284], [68.64291382, 23.17486191], [68.64263916, 23.17486191], [68.64263916, 23.1756916], [68.6423645, 23.17569542], [68.6423645, 23.17652702], [68.64208221, 23.17651939], [68.64208221, 23.17736053], [68.64180756, 23.17736053], [68.64180756, 23.17819214], [68.6415329, 23.17819023], [68.6415329, 23.1787529], [68.64124298, 23.1787529], [68.64124298, 23.17930984], [68.64097595, 23.17930984], [68.64097595, 23.17959023], [68.64068604, 23.17959023], [68.64068604, 23.17986107], [68.64041901, 23.17986107], [68.64041901, 23.18041992], [68.64013672, 23.1804142], [68.64013672, 23.18069458], [68.63986206, 23.18069458], [68.63986206, 23.18097305], [68.63957977, 23.18097115], [68.63957977, 23.18153], [68.63930511, 23.18152809], [68.63930511, 23.18180656], [68.63903046, 23.18180656], [68.63903046, 23.18208313], [68.63847351, 23.18208313], [68.63847351, 23.1823616], [68.63819885, 23.1823597], [68.63819885, 23.18264961], [68.63764191, 23.18264961], [68.63764191, 23.18292046], [68.63735962, 23.18292046], [68.63735962, 23.18320084], [68.63708496, 23.18319511], [68.63708496, 23.18347168], [68.63652802, 23.18346977], [68.63652802, 23.18375015], [68.63625336, 23.18375015], [68.63625336, 23.18403053], [68.63540649, 23.18403053], [68.63540649, 23.18431091], [68.63486481, 23.18430519], [68.63486481, 23.18458366], [68.63402557, 23.18458366], [68.6340332, 23.18486023], [68.63263702, 23.18486023], [68.63263702, 23.18514061], [68.63096619, 23.18514061], [68.63096619, 23.18541908], [68.63070679, 23.18541718], [68.62958527, 23.18541718], [68.62958527, 23.18569374], [68.62652588, 23.18569374], [68.62652588, 23.18597221], [68.62680817, 23.18597031], [68.62680817, 23.18625069], [68.62652588, 23.18625069], [68.62652588, 23.18680763], [68.62625122, 23.18680573], [68.62625122, 23.1870842], [68.62513733, 23.18708038], [68.62513733, 23.18736076], [68.62486267, 23.18736076], [68.62486267, 23.18763924], [68.62458038, 23.18763924], [68.62458038, 23.18792152], [68.62430573, 23.1879158], [68.62430573, 23.18819427], [68.62374878, 23.18819427], [68.62374878, 23.18847275], [68.62346649, 23.1884594], [68.62346649, 23.1890316], [68.62319946, 23.1890316], [68.62319946, 23.18931007], [68.62208557, 23.18930626], [68.62208557, 23.18958282], [68.62180328, 23.18958092], [68.62180328, 23.19014168], [68.62152863, 23.19014168], [68.62152863, 23.19042015], [68.62124634, 23.19041634], [68.62124634, 23.19097137], [68.62097168, 23.19096947], [68.62097168, 23.19124985], [68.62069702, 23.19124985], [68.62069702, 23.19153023], [68.62041473, 23.19152832], [68.62041473, 23.19208145], [68.62014008, 23.19208145], [68.62014008, 23.19236374], [68.61985779, 23.19235992], [68.61985779, 23.1926403], [68.61958313, 23.1926403], [68.61958313, 23.19292068], [68.61930847, 23.19292068], [68.61930847, 23.19320107], [68.61902618, 23.19319534], [68.61902618, 23.19347382], [68.61875153, 23.19347], [68.61875153, 23.19375038], [68.61846924, 23.19375038], [68.61846924, 23.19403076], [68.61818695, 23.19403076], [68.61818695, 23.19458961], [68.61791992, 23.19458961], [68.61791992, 23.19514084], [68.61680603, 23.19514084], [68.61680603, 23.19542122], [68.61624908, 23.1954174], [68.61624908, 23.19569588], [68.61597443, 23.19569588], [68.61597443, 23.19597244], [68.61541748, 23.19597054], [68.61541748, 23.19625092], [68.61514282, 23.19625092], [68.61514282, 23.19652939], [68.61458588, 23.19652939], [68.61458588, 23.19680977], [68.61430359, 23.19680786], [68.61430359, 23.19708252], [68.61374664, 23.19708061], [68.61374664, 23.19736099], [68.61347198, 23.19736099], [68.61347198, 23.19765091], [68.61292267, 23.19765091], [68.61292267, 23.19791985], [68.61264038, 23.19791794], [68.61264038, 23.1981945], [68.61235809, 23.1981945], [68.61235809, 23.19847298], [68.61180878, 23.19847107], [68.61180878, 23.19902992], [68.61152649, 23.19902992], [68.61152649, 23.1993103], [68.61125183, 23.19930649], [68.61125183, 23.19958305], [68.61068726, 23.19958115], [68.61068726, 23.20013809], [68.61042023, 23.20013809], [68.61042023, 23.20041847], [68.61013794, 23.20041656], [68.61013794, 23.2009716], [68.60986328, 23.2009697], [68.60986328, 23.20124817], [68.60958099, 23.20124817], [68.60958099, 23.20152855], [68.60930634, 23.20152855], [68.60930634, 23.20181084], [68.60902405, 23.20180511], [68.60902405, 23.20208359], [68.60874939, 23.20208359], [68.60874939, 23.20236015], [68.6084671, 23.20236015], [68.6084671, 23.20264244], [68.60819244, 23.20264244], [68.60819244, 23.20292282], [68.60791779, 23.2029171], [68.60791779, 23.20319366], [68.6076355, 23.20319366], [68.6076355, 23.20347023], [68.60708618, 23.20347023], [68.60708618, 23.20375252], [68.60679626, 23.20375252], [68.60679626, 23.2040329], [68.60624695, 23.2040329], [68.60624695, 23.20430946], [68.60597229, 23.20430565], [68.60597229, 23.20458221], [68.60541534, 23.20458221], [68.60542297, 23.20486069], [68.60513306, 23.20486069], [68.60513306, 23.20514107], [68.60457611, 23.20514107], [68.60457611, 23.20541954], [68.60375214, 23.20541763], [68.60375214, 23.20569229], [68.60319519, 23.20569229], [68.60319519, 23.20597458], [68.6029129, 23.20597076], [68.6029129, 23.20625114], [68.60235596, 23.20625114], [68.60235596, 23.20652962], [68.60208893, 23.20652962], [68.60208893, 23.20681953], [68.60152435, 23.20680618], [68.60152435, 23.20708466], [68.60097504, 23.20708466], [68.60098267, 23.20736122], [68.60069275, 23.20736122], [68.60069275, 23.20763969], [68.60041809, 23.20763969], [68.60041809, 23.20819664], [68.59986115, 23.20819664], [68.59986115, 23.2084713], [68.59958649, 23.20846939], [68.59958649, 23.20874977], [68.59929657, 23.20874977], [68.59929657, 23.20903015], [68.59874725, 23.20902824], [68.59874725, 23.20930672], [68.5984726, 23.20930672], [68.5984726, 23.20958328], [68.59819794, 23.20958328], [68.59819794, 23.20986176], [68.59764099, 23.20985985], [68.59764099, 23.21014023], [68.5973587, 23.21014023], [68.5973587, 23.21042061], [68.59707642, 23.21042061], [68.59707642, 23.21070099], [68.5965271, 23.21069527], [68.5965271, 23.21097183], [68.59625244, 23.21096992], [68.59625244, 23.21125031], [68.59570313, 23.21125031], [68.59570313, 23.21153069], [68.59513855, 23.21153069], [68.59513855, 23.21181107], [68.5945816, 23.21180534], [68.5945816, 23.21208382], [68.59401703, 23.21208], [68.59401703, 23.21236038], [68.59375, 23.21236038], [68.59375, 23.21263885], [68.59348297, 23.21263123], [68.59348297, 23.21292114], [68.59319305, 23.21291733], [68.59319305, 23.21319389], [68.5929184, 23.21319389], [68.5929184, 23.21347237], [68.59263611, 23.21347046], [68.59263611, 23.21375084], [68.59208679, 23.21375084], [68.59208679, 23.21402931], [68.59152985, 23.21402931], [68.59152985, 23.2143116], [68.59124756, 23.2143116], [68.59124756, 23.21513939], [68.5909729, 23.21513939], [68.5909729, 23.21569443], [68.59069824, 23.21569443], [68.59069824, 23.2159729], [68.59041595, 23.21596909], [68.59041595, 23.21624947], [68.59014893, 23.21624947], [68.59014893, 23.21653175], [68.58985901, 23.21653175], [68.58985901, 23.21681023], [68.58958435, 23.21680641], [68.58958435, 23.21708107], [68.58930206, 23.21708107], [68.58930206, 23.21736336], [68.5890274, 23.21735954], [68.5890274, 23.21764183], [68.58875275, 23.21764183], [68.58875275, 23.2179203], [68.58847046, 23.21791649], [68.58847046, 23.21847153], [68.5881958, 23.21846962], [68.5881958, 23.21875954], [68.58790588, 23.21875954], [68.58790588, 23.21903038], [68.58763885, 23.21903038], [68.58763885, 23.21931076], [68.5873642, 23.21930313], [68.5873642, 23.2195816], [68.58708191, 23.2195816], [68.58708191, 23.21986389], [68.58680725, 23.21986008], [68.58680725, 23.22014046], [68.58653259, 23.22014046], [68.58653259, 23.22042084], [68.58625031, 23.22041702], [68.58625031, 23.22097206], [68.58597565, 23.22097206], [68.58598328, 23.22125053], [68.58569336, 23.22125053], [68.58569336, 23.22153091], [68.5854187, 23.22153091], [68.5854187, 23.22182083], [68.58513641, 23.22182083], [68.58513641, 23.22236061], [68.58486176, 23.22236061], [68.58486176, 23.22319412], [68.5845871, 23.22319031], [68.5845871, 23.22402954], [68.58429718, 23.22402954], [68.58429718, 23.22486115], [68.58403015, 23.22486115], [68.58403015, 23.22513962], [68.58430481, 23.22513962], [68.58430481, 23.22847176], [68.5845871, 23.22846985], [68.5845871, 23.22874832], [68.58486176, 23.22874832], [68.58486176, 23.2293129], [68.58513641, 23.22930527], [68.58513641, 23.22958374], [68.5854187, 23.22958183], [68.5854187, 23.23014259], [68.58513641, 23.23014259], [68.58513641, 23.23042107], [68.5845871, 23.23042107], [68.5845871, 23.23291969], [68.58486176, 23.23291588], [68.58486176, 23.23347473], [68.58513641, 23.23347092], [68.58513641, 23.23402977], [68.5854187, 23.23402786], [68.5854187, 23.23458481], [68.58569336, 23.23458481], [68.58569336, 23.23486137], [68.58598328, 23.23485947], [68.58598328, 23.23513985], [68.58625031, 23.23513985], [68.58625031, 23.23542023], [68.58680725, 23.23541641], [68.58680725, 23.23569679], [68.58708191, 23.23569679], [68.58708191, 23.23597145], [68.58735657, 23.23596954], [68.58735657, 23.23624992], [68.58763885, 23.23624992], [68.58763885, 23.2365303], [68.58791351, 23.2365284], [68.58791351, 23.23680687], [68.5881958, 23.23680687], [68.5881958, 23.23708344], [68.58847046, 23.23708344], [68.58847046, 23.23736191], [68.5890274, 23.23736], [68.5890274, 23.23764038], [68.58930206, 23.23764038], [68.58930206, 23.23792076], [68.58958435, 23.23791885], [68.58958435, 23.23819351], [68.58985901, 23.23819351], [68.58985901, 23.23847198], [68.59069824, 23.23847008], [68.59069824, 23.23875046], [68.59152985, 23.23875046], [68.59152985, 23.23903084], [68.59236145, 23.23903084], [68.59236145, 23.23931122], [68.59319305, 23.2393055], [68.59319305, 23.23958397], [68.59401703, 23.23957062], [68.59401703, 23.23986053], [68.59485626, 23.23986053], [68.59485626, 23.24014091], [68.59570313, 23.24014091], [68.59570313, 23.24041748], [68.59902954, 23.24041748], [68.59902954, 23.23931122], [68.59874725, 23.23931122], [68.59874725, 23.23764038], [68.5984726, 23.23764038], [68.5984726, 23.23624992], [68.59874725, 23.23624992], [68.59874725, 23.23569107], [68.59902954, 23.23569679], [68.59902954, 23.23458481], [68.5993042, 23.23458481], [68.5993042, 23.23430634], [68.6001358, 23.23431015], [68.6001358, 23.23291969], [68.60041809, 23.23291969], [68.60041809, 23.23264122], [68.60098267, 23.23264122], [68.60098267, 23.23208046], [68.60124969, 23.23208237], [68.60124969, 23.2318058], [68.60151672, 23.23180962], [68.60151672, 23.23153114], [68.60098267, 23.23153114], [68.60098267, 23.23125267], [68.6001358, 23.23125267], [68.6001358, 23.23097038], [68.59986115, 23.23097038], [68.59986115, 23.23041725], [68.59958649, 23.23042107], [68.59958649, 23.23014259], [68.59902954, 23.23014259], [68.59902954, 23.22903252], [68.59874725, 23.22903252], [68.59874725, 23.22874832], [68.60041809, 23.22874832], [68.60041809, 23.22846985], [68.60097504, 23.22847176], [68.60097504, 23.22791672], [68.60124969, 23.22791862], [68.60124969, 23.22707748], [68.60069275, 23.22708321], [68.60069275, 23.22680473], [68.6001358, 23.22680473], [68.6001358, 23.22652817], [68.59986115, 23.22652817], [68.59986115, 23.22375107], [68.59958649, 23.22375107], [68.59958649, 23.22291946], [68.59986115, 23.22291946], [68.59986115, 23.22236061], [68.6001358, 23.22236061], [68.6001358, 23.22182083], [68.60041809, 23.22182083], [68.60041809, 23.22125053], [68.60069275, 23.22125053], [68.60069275, 23.22068977], [68.60097504, 23.2206955], [68.60097504, 23.21875191], [68.60124969, 23.21875954], [68.60124969, 23.21846962], [68.60151672, 23.21846962], [68.60151672, 23.21875954], [68.60180664, 23.21875954], [68.60180664, 23.21903038], [68.60208893, 23.21903038], [68.60208893, 23.21931076], [68.60236359, 23.21930313], [68.60236359, 23.2195816], [68.60263824, 23.2195816], [68.60263824, 23.21986389], [68.60375214, 23.21986389], [68.60375214, 23.2195816], [68.60430908, 23.2195816], [68.60430908, 23.21930313], [68.60457611, 23.21931076], [68.60457611, 23.21903038], [68.60513306, 23.21903038], [68.60513306, 23.21875954], [68.60541534, 23.21875191], [68.60541534, 23.22043037], [68.60541534, 23.2206955], [68.60555267, 23.2206955], [68.60791779, 23.2206955], [68.60791779, 23.22097206], [68.60902405, 23.22097206], [68.60902405, 23.2206955], [68.60958099, 23.2206955], [68.60958099, 23.21847153], [68.60930634, 23.21847153], [68.60930634, 23.21791649], [68.60986328, 23.2179203], [68.60986328, 23.21764183], [68.61125946, 23.21764183], [68.61125946, 23.2179203], [68.61152649, 23.2179203], [68.61152649, 23.21820068], [68.61180878, 23.21819305], [68.61180878, 23.21847153], [68.61235809, 23.21846962], [68.61235809, 23.21875954], [68.61319733, 23.21875954], [68.61319733, 23.21820068], [68.61347198, 23.21820068], [68.61347198, 23.21708107], [68.61430359, 23.21708107], [68.61430359, 23.21736336], [68.61458588, 23.21735954], [68.61458588, 23.21764183], [68.61486053, 23.21764183], [68.61486053, 23.2179203], [68.61514282, 23.2179203], [68.61514282, 23.21820068], [68.61541748, 23.21819305], [68.61541748, 23.21847153], [68.61569214, 23.21846962], [68.61569214, 23.21875954], [68.61680603, 23.21875954], [68.61680603, 23.21903038], [68.61818695, 23.21903038], [68.61818695, 23.21653175], [68.62013245, 23.21653175], [68.62013245, 23.21624947], [68.6204071, 23.21624947], [68.6204071, 23.21596909], [68.62097168, 23.21596909], [68.62097168, 23.21681023], [68.62291718, 23.21681023], [68.62291718, 23.21653175], [68.62374878, 23.21653175], [68.62374878, 23.21569061], [68.62430573, 23.21569443], [68.62430573, 23.2159729], [68.62596893, 23.21596909], [68.62596893, 23.21624947], [68.62652588, 23.21624947], [68.62652588, 23.21596909], [68.62680817, 23.2159729], [68.62680817, 23.21569443], [68.62708282, 23.21569443], [68.62708282, 23.21513939], [68.62735748, 23.21513939], [68.62735748, 23.21486092], [68.62763977, 23.21486092], [68.62763977, 23.21458054], [68.62902832, 23.21458244], [68.62902832, 23.21430588], [68.62930298, 23.2143116], [68.62930298, 23.21402931], [68.6295929, 23.21402931], [68.6295929, 23.21375084], [68.62985992, 23.21375084], [68.62985992, 23.21347046], [68.63014221, 23.21347237], [68.63014221, 23.21319389], [68.63069153, 23.21319389], [68.63069153, 23.21347237], [68.63096619, 23.21347046], [68.63096619, 23.21402931], [68.63124847, 23.21402931], [68.63124847, 23.2143116], [68.63153076, 23.2143116], [68.63153076, 23.21542168], [68.63124847, 23.21541595], [68.63124847, 23.2159729], [68.62930298, 23.21596909], [68.62930298, 23.21624947], [68.62902832, 23.21624947], [68.62902832, 23.21653175], [68.62874603, 23.21653175], [68.62874603, 23.21681023], [68.62847137, 23.21680641], [68.62847137, 23.21736336], [68.62874603, 23.21735954], [68.62874603, 23.21764183], [68.62930298, 23.21764183], [68.62930298, 23.2179203], [68.6295929, 23.2179203], [68.6295929, 23.21820068], [68.63014221, 23.21819305], [68.63014221, 23.21847153], [68.63096619, 23.21846962], [68.63096619, 23.21875954], [68.63153076, 23.21875954], [68.63153076, 23.21903038], [68.6340332, 23.21903038], [68.6340332, 23.21931076], [68.63486481, 23.21930313], [68.63486481, 23.2195816], [68.63513947, 23.2195797], [68.63513947, 23.22014046], [68.63485718, 23.22014046], [68.63485718, 23.22042084], [68.63458252, 23.22041702], [68.63458252, 23.22097206], [68.63430786, 23.22097015], [68.63430786, 23.22125053], [68.6340332, 23.22125053], [68.6340332, 23.22153091], [68.63430786, 23.22153091], [68.63430786, 23.22182083], [68.63458252, 23.22182083], [68.63458252, 23.22153091], [68.63485718, 23.22153091], [68.63485718, 23.22125053], [68.63513947, 23.22125053], [68.63513947, 23.22097015], [68.63541412, 23.22097206], [68.63541412, 23.2206955], [68.63625336, 23.2206955], [68.63625336, 23.22041702], [68.63680267, 23.22042084], [68.63680267, 23.22153091], [68.63764191, 23.22153091], [68.63764191, 23.22182083], [68.63791656, 23.22180557], [68.63791656, 23.22208595], [68.63986206, 23.22208023], [68.63986206, 23.22236061], [68.63957977, 23.22236061], [68.63957977, 23.22264099], [68.63931274, 23.22264099], [68.63931274, 23.22291946], [68.63903046, 23.22291756], [68.63903046, 23.22319412], [68.63652802, 23.22319412], [68.63652802, 23.2234726], [68.63625336, 23.22347069], [68.63625336, 23.22375107], [68.63375092, 23.22375107], [68.63375092, 23.22402954], [68.63346863, 23.22402954], [68.63346863, 23.22430992], [68.63315582, 23.22430992], [68.63153076, 23.22430611], [68.63153076, 23.22458267], [68.63096619, 23.22457123], [68.63096619, 23.22486115], [68.62902832, 23.22486115], [68.62902832, 23.22457123], [68.62875366, 23.22458267], [68.62875366, 23.22430611], [68.62847137, 23.22430992], [68.62847137, 23.22402954], [68.62819672, 23.22402954], [68.62819672, 23.22375107], [68.6279068, 23.22375107], [68.6279068, 23.22319031], [68.62763977, 23.22319412], [68.62763977, 23.22291756], [68.62735748, 23.22291946], [68.62735748, 23.22264099], [68.62708282, 23.22264099], [68.62708282, 23.22236061], [68.62680817, 23.22236061], [68.62680817, 23.22182083], [68.62652588, 23.22182083], [68.62652588, 23.22153091], [68.62625885, 23.22153091], [68.62625885, 23.22125053], [68.62568665, 23.22125053], [68.62568665, 23.22097015], [68.62486267, 23.22097206], [68.62486267, 23.2206955], [68.62403107, 23.2206955], [68.62403107, 23.22097206], [68.62346649, 23.22097015], [68.62347412, 23.22125053], [68.62319183, 23.22125053], [68.62319183, 23.22171021], [68.62319183, 23.2234726], [68.62346649, 23.22347069], [68.62346649, 23.22402954], [68.62374878, 23.22402954], [68.62374878, 23.22430992], [68.62347412, 23.22430611], [68.62347412, 23.22458267], [68.62319183, 23.22458267], [68.62319183, 23.22486115], [68.62346649, 23.22486115], [68.62346649, 23.22513962], [68.62374878, 23.22513962], [68.62374878, 23.22541809], [68.62430573, 23.22541618], [68.62430573, 23.22569466], [68.62458038, 23.22569466], [68.62458038, 23.22597313], [68.62486267, 23.22597122], [68.62486267, 23.22624969], [68.62374878, 23.22624969], [68.62374878, 23.22597122], [68.62347412, 23.22597313], [68.62347412, 23.22569466], [68.62264252, 23.22569466], [68.62264252, 23.22458267], [68.62236023, 23.22458267], [68.62236023, 23.22374916], [68.6220932, 23.22375107], [68.6220932, 23.22319031], [68.62180328, 23.22319412], [68.62180328, 23.22291756], [68.62124634, 23.22291946], [68.62124634, 23.22265816], [68.62097168, 23.22264099], [68.62097168, 23.22236061], [68.62069702, 23.22236061], [68.62069702, 23.22264099], [68.62041473, 23.22263908], [68.62041473, 23.22313118], [68.6204071, 23.22402954], [68.62069702, 23.22402954], [68.62069702, 23.22430992], [68.62097168, 23.22430611], [68.62097168, 23.22458267], [68.62124634, 23.22457123], [68.62124634, 23.22486115], [68.61930847, 23.22486115], [68.61930847, 23.22513962], [68.61875153, 23.22513962], [68.61875153, 23.22486115], [68.61902618, 23.22486115], [68.61902618, 23.22384071], [68.61902618, 23.22208595], [68.61930847, 23.22208595], [68.61930847, 23.21986389], [68.61902618, 23.21986008], [68.61902618, 23.22014046], [68.61875153, 23.22013855], [68.61875153, 23.2206955], [68.61846924, 23.2206955], [68.61846924, 23.22097206], [68.61818695, 23.22097015], [68.61818695, 23.22125053], [68.61791992, 23.22125053], [68.61791992, 23.22182083], [68.61763763, 23.22182083], [68.61763763, 23.22236061], [68.61736298, 23.22236061], [68.61736298, 23.22319412], [68.61707306, 23.22319031], [68.61707306, 23.22375107], [68.61680603, 23.22375107], [68.61680603, 23.22402954], [68.61653137, 23.22402763], [68.61653137, 23.22458267], [68.61624908, 23.22458267], [68.61624908, 23.22528076], [68.61624908, 23.22569466], [68.61597443, 23.22569466], [68.61597443, 23.22597313], [68.61569214, 23.22597122], [68.61569214, 23.22624969], [68.61541748, 23.22624969], [68.61541748, 23.22652817], [68.61486053, 23.22652817], [68.61486053, 23.22680473], [68.61430359, 23.22680473], [68.61430359, 23.22708321], [68.61374664, 23.22708321], [68.61374664, 23.22763824], [68.61347198, 23.22763062], [68.61347198, 23.22791862], [68.61319733, 23.22791672], [68.61319733, 23.22847176], [68.61292267, 23.22846985], [68.61292267, 23.22903252], [68.61264038, 23.22903252], [68.61264038, 23.2293129], [68.61235809, 23.2293129], [68.61235809, 23.22986031], [68.61207581, 23.22986031], [68.61207581, 23.23014259], [68.61180878, 23.23014259], [68.61180878, 23.23069954], [68.61152649, 23.23069954], [68.61152649, 23.23125267], [68.61125946, 23.23125267], [68.61125946, 23.23180962], [68.61096954, 23.2318058], [68.61096954, 23.23208237], [68.61068726, 23.23208046], [68.61068726, 23.23264122], [68.61042023, 23.23263931], [68.61042023, 23.23319244], [68.61013794, 23.23319054], [68.61013794, 23.23376083], [68.60986328, 23.23376083], [68.60986328, 23.23402977], [68.60958099, 23.23402786], [68.60958099, 23.23458481], [68.60930634, 23.23458481], [68.60930634, 23.23486137], [68.60819244, 23.23485947], [68.60819244, 23.23513985], [68.60791779, 23.23513985], [68.60791779, 23.23542023], [68.60736084, 23.23541641], [68.60736084, 23.23569679], [68.60708618, 23.23569679], [68.60708618, 23.23597145], [68.60679626, 23.23596954], [68.60679626, 23.23624992], [68.60652924, 23.23624992], [68.60652924, 23.23680687], [68.60624695, 23.23680687], [68.60624695, 23.23708344], [68.60597229, 23.23708344], [68.60597229, 23.23736191], [68.60569763, 23.23736], [68.60569763, 23.23792076], [68.60541534, 23.23791885], [68.60542297, 23.2381897], [68.60513306, 23.23820114], [68.60513306, 23.23875046], [68.6048584, 23.23875046], [68.6048584, 23.23903084], [68.60458374, 23.23902893], [68.60458374, 23.23958397], [68.60430908, 23.23957062], [68.60430908, 23.23986053], [68.60457611, 23.23986053], [68.60457611, 23.24041748], [68.60513306, 23.24041748], [68.60513306, 23.24014091], [68.60569763, 23.2401371], [68.60569763, 23.24081993], [68.60569763, 23.24097252], [68.60542297, 23.24097061], [68.60542297, 23.24124908], [68.60513306, 23.24124908], [68.60513306, 23.24181175], [68.6048584, 23.24180603], [68.6048584, 23.2420826], [68.60430908, 23.24208069], [68.60430908, 23.24235916], [68.60375214, 23.24235916], [68.60375214, 23.24292946], [68.6048584, 23.24291611], [68.6048584, 23.24319458], [68.60541534, 23.24319458], [68.60541534, 23.24347115], [68.60624695, 23.24346924], [68.60624695, 23.24374962], [68.60708618, 23.24374962], [68.60708618, 23.24346924], [68.60736084, 23.24347115], [68.60736084, 23.24319458], [68.60930634, 23.24319458], [68.60930634, 23.24291611], [68.61096954, 23.24292946], [68.61096954, 23.24263954], [68.61292267, 23.24263954], [68.61291504, 23.24235916], [68.61513519, 23.24235916], [68.61513519, 23.24263954], [68.61791992, 23.24263954], [68.61791992, 23.24292946], [68.62264252, 23.24291611], [68.62264252, 23.24319458], [68.62458038, 23.24319458], [68.62458038, 23.24291611], [68.62486267, 23.24291611], [68.62486267, 23.24319458], [68.62541962, 23.24319458], [68.62541962, 23.24347115], [68.62596893, 23.24346924], [68.62596893, 23.24374962], [68.62680817, 23.24374962], [68.62680817, 23.24403191], [68.62735748, 23.24402809], [68.62735748, 23.24430466], [68.62791443, 23.24430466], [68.62791443, 23.24458122], [68.62930298, 23.24458122], [68.62930298, 23.24430466], [68.62958527, 23.24430466], [68.62958527, 23.24402809], [68.62985992, 23.24403191], [68.62985992, 23.24348068], [68.63014221, 23.24346924], [68.63014221, 23.24319458], [68.63069153, 23.24319458], [68.63069153, 23.24430466], [68.63054657, 23.24430275], [68.63041687, 23.24430275], [68.63041687, 23.24514008], [68.6279068, 23.24514008], [68.6279068, 23.24681091], [68.62819672, 23.24680328], [68.62819672, 23.24708557], [68.62985992, 23.24708557], [68.62985992, 23.24680328], [68.63014221, 23.24681091], [68.63014221, 23.24653053], [68.63041687, 23.24653053], [68.63041687, 23.24596977], [68.63124847, 23.24597359], [68.63124847, 23.24569321], [68.63153076, 23.24570084], [68.63153076, 23.24550056], [68.63153076, 23.24541664], [68.63236237, 23.24542046], [68.63236237, 23.24570084], [68.63263702, 23.24570084], [68.63263702, 23.24625015], [68.63430786, 23.24625015], [68.63430786, 23.24653053], [68.63513947, 23.24653053], [68.63513947, 23.24625015], [68.63597107, 23.24625015], [68.63597107, 23.24653053], [68.63709259, 23.24653053], [68.63709259, 23.24596977], [68.63735962, 23.24597359], [68.63735962, 23.24541664], [68.63791656, 23.24542046], [68.63791656, 23.24570084], [68.63847351, 23.24569321], [68.63847351, 23.24597359], [68.63874817, 23.24597359], [68.63874817, 23.24569321], [68.63931274, 23.24570084], [68.63931274, 23.2448597], [68.63957977, 23.24486351], [68.63957977, 23.24458122], [68.64041901, 23.24458122], [68.64041901, 23.24486351], [68.64068604, 23.2448597], [68.64068604, 23.24514008], [68.64097595, 23.24514008], [68.64097595, 23.24542046], [68.64124298, 23.24542046], [68.64124298, 23.24570084], [68.64263916, 23.24569321], [68.64263916, 23.24597359], [68.64290619, 23.24596977], [68.64290619, 23.24625015], [68.64319611, 23.24625015], [68.64319611, 23.24736023], [68.64290619, 23.24736023], [68.64290619, 23.24764061], [68.64263916, 23.24764061], [68.64263916, 23.24792099], [68.6423645, 23.24791718], [68.6423645, 23.24819565], [68.64125061, 23.24819565], [68.64125061, 23.24791718], [68.64097595, 23.24792099], [68.64097595, 23.24764061], [68.64041901, 23.24764061], [68.64041901, 23.24792099], [68.64013672, 23.24792099], [68.64013672, 23.24903107], [68.63903046, 23.24903107], [68.63903046, 23.24930954], [68.63930511, 23.24930573], [68.63930511, 23.24986076], [68.63957977, 23.24986076], [68.63957977, 23.24958038], [68.64180756, 23.24958038], [68.64180756, 23.24986076], [68.64263916, 23.24986076], [68.64263916, 23.25014114], [68.6423645, 23.25013924], [68.6423645, 23.25069427], [68.64263916, 23.25069046], [68.64263916, 23.25125122], [68.64375305, 23.25124931], [68.64375305, 23.25180626], [68.64430237, 23.25180626], [68.64430237, 23.25152779], [68.64457703, 23.25152969], [68.64457703, 23.25125122], [68.64485931, 23.25125122], [68.64485931, 23.25097084], [68.64569092, 23.25097084], [68.64569092, 23.25152969], [68.64597321, 23.25152779], [68.64597321, 23.25180626], [68.64624786, 23.25180626], [68.64624786, 23.25208282], [68.64653015, 23.25208282], [68.64653015, 23.2523613], [68.64679718, 23.25235939], [68.64679718, 23.25291824], [68.64653015, 23.25291634], [68.64653015, 23.25304031], [68.64653015, 23.25319481], [68.64597321, 23.25319481], [68.64597321, 23.25347137], [68.64626312, 23.25347137], [68.6470871, 23.25346947], [68.6470871, 23.25374985], [68.64848328, 23.25374985], [68.64848328, 23.25402832], [68.64819336, 23.25402832], [68.64819336, 23.25458336], [68.6479187, 23.25457954], [68.6479187, 23.25486946], [68.64763641, 23.25486946], [68.64763641, 23.2551384], [68.64679718, 23.2551384], [68.64679718, 23.25625038], [68.6470871, 23.25625038], [68.6470871, 23.25653267], [68.64736176, 23.25652695], [68.64736176, 23.25708389], [68.64763641, 23.25708008], [68.64763641, 23.25736046], [68.6479187, 23.25736046], [68.6479187, 23.25764275], [68.64848328, 23.25764275], [68.64848328, 23.25793076], [68.64875031, 23.2579174], [68.64875031, 23.25819206], [68.64958191, 23.25819206], [68.64958191, 23.25847054], [68.65040588, 23.25847054], [68.65040588, 23.25875282], [68.65180206, 23.25875282], [68.65180206, 23.25902939], [68.65319824, 23.25902939], [68.65319824, 23.25930977], [68.65402985, 23.25930405], [68.65402985, 23.25958443], [68.65513611, 23.25958061], [68.65513611, 23.2598629], [68.65597534, 23.2598629], [68.65597534, 23.26013947], [68.65624237, 23.26013947], [68.65624237, 23.26041985], [68.65652466, 23.26041412], [68.65652466, 23.2606926], [68.65763855, 23.2606926], [68.65763855, 23.26097488], [68.65847015, 23.26097107], [68.65847015, 23.26124954], [68.6590271, 23.26124954], [68.6590271, 23.26152992], [68.65930176, 23.26152802], [68.65930939, 23.26180077], [68.65958405, 23.26180649], [68.65958405, 23.26208305], [68.6598587, 23.26208115], [68.6598587, 23.26264], [68.66014099, 23.26264], [68.66014099, 23.26680756], [68.66041565, 23.26680565], [68.66041565, 23.26708412], [68.66069794, 23.26708031], [68.66069794, 23.26736069], [68.66124725, 23.26736069], [68.66124725, 23.26763916], [68.66152954, 23.26763916], [68.66152954, 23.26792145], [68.66236115, 23.26791573], [68.66236115, 23.2681942], [68.66291809, 23.2681942], [68.66291809, 23.26847267], [68.66374969, 23.26847076], [68.66374969, 23.26874924], [68.66430664, 23.26874924], [68.66430664, 23.26903152], [68.66513824, 23.26903152], [68.66513824, 23.2693119], [68.66569519, 23.26930618], [68.66569519, 23.26958275], [68.66707611, 23.26958084], [68.66707611, 23.26987267], [68.66874695, 23.26987267], [68.66874695, 23.26958084], [68.67041779, 23.26958084], [68.67041779, 23.26987267], [68.67180634, 23.26987267], [68.67180634, 23.27013969], [68.67151642, 23.27013969], [68.67151642, 23.27124977], [68.67124939, 23.27124977], [68.67124939, 23.27236366], [68.6709671, 23.27235985], [68.6709671, 23.27264023], [68.67014313, 23.27264023], [68.67014313, 23.27235985], [68.66930389, 23.27236366], [68.66930389, 23.27208138], [68.66874695, 23.27208138], [68.66874695, 23.27180481], [68.66791534, 23.27180481], [68.66791534, 23.27152824], [68.66707611, 23.27153015], [68.66707611, 23.27124977], [68.66347504, 23.27124977], [68.66347504, 23.27208138], [68.66124725, 23.27208138], [68.66124725, 23.27180481], [68.6581955, 23.27180481], [68.6581955, 23.27208138], [68.65625, 23.27208138], [68.65625, 23.27180481], [68.6554184, 23.27180481], [68.6554184, 23.27152824], [68.65235901, 23.27153015], [68.65235901, 23.27124977], [68.65207672, 23.27124977], [68.65207672, 23.27096939], [68.65180206, 23.2709713], [68.65180206, 23.27069473], [68.65125275, 23.27069473], [68.65125275, 23.27041626], [68.65097046, 23.27042007], [68.65097046, 23.27013969], [68.6506958, 23.27013969], [68.6506958, 23.26987267], [68.65013885, 23.26987267], [68.65013885, 23.26958084], [68.6498642, 23.26958275], [68.6498642, 23.26930618], [68.64930725, 23.2693119], [68.64930725, 23.26903152], [68.64736938, 23.26903152], [68.64736938, 23.26874924], [68.64597321, 23.26874924], [68.64597321, 23.26847076], [68.64458466, 23.26847267], [68.64458466, 23.2681942], [68.64402771, 23.2681942], [68.64402771, 23.26791763], [68.64375305, 23.26792145], [68.64375305, 23.26763916], [68.64319611, 23.26763916], [68.64319611, 23.26736069], [68.64290619, 23.26736069], [68.64290619, 23.26708031], [68.64263916, 23.26708412], [68.64263916, 23.26652718], [68.64232635, 23.26652718], [68.64068604, 23.26652908], [68.64068604, 23.26680756], [68.64041901, 23.26680565], [68.64041901, 23.26708412], [68.64013672, 23.26708031], [68.64013672, 23.26736069], [68.63986206, 23.26736069], [68.63986206, 23.26763916], [68.63957977, 23.26763916], [68.63957977, 23.26847267], [68.63791656, 23.26847076], [68.63791656, 23.26874924], [68.63764191, 23.26874924], [68.63764191, 23.2693119], [68.63735962, 23.2693119], [68.63735962, 23.27013969], [68.63708496, 23.27013969], [68.63708496, 23.27069473], [68.63680267, 23.27069283], [68.63680267, 23.27124977], [68.63652802, 23.27124977], [68.63652802, 23.27208138], [68.63625336, 23.27207947], [68.63625336, 23.27264023], [68.63597107, 23.27263832], [68.63597107, 23.27347374], [68.63625336, 23.27346992], [68.63625336, 23.27431107], [68.63597107, 23.27431107], [68.63597107, 23.27486038], [68.63569641, 23.27486038], [68.63569641, 23.2756958], [68.63540649, 23.27568054], [68.63540649, 23.27625084], [68.63513947, 23.27625084], [68.63513947, 23.27653122], [68.63485718, 23.27653122], [68.63485718, 23.27736092], [68.63458252, 23.27736092], [68.63458252, 23.27819443], [68.63430786, 23.27819061], [68.63430786, 23.27902985], [68.6340332, 23.27902985], [68.6340332, 23.28013992], [68.63375092, 23.28013992], [68.63375092, 23.28097153], [68.63346863, 23.28096962], [68.63346863, 23.28181076], [68.63318634, 23.28181076], [68.63318634, 23.28264236], [68.63291931, 23.28263855], [68.63291931, 23.28347015], [68.63263702, 23.28347015], [68.63263702, 23.28430939], [68.63236237, 23.28430557], [68.63236237, 23.28486061], [68.63207245, 23.28484917], [68.63207245, 23.28541946], [68.63180542, 23.28541756], [68.63180542, 23.28569221], [68.63153076, 23.28569031], [68.63153076, 23.28625107], [68.63124847, 23.28625107], [68.63124847, 23.28680992], [68.63096619, 23.28680992], [68.63096619, 23.28736115], [68.63069153, 23.28736115], [68.63069153, 23.28819466], [68.63041687, 23.28819084], [68.63041687, 23.28903008], [68.63014221, 23.28902817], [68.63014221, 23.28986168], [68.62985992, 23.28985977], [68.62985992, 23.29042053], [68.6295929, 23.29042053], [68.6295929, 23.29097939], [68.62930298, 23.29097939], [68.62930298, 23.29236031], [68.6295929, 23.29236031], [68.6295929, 23.29513931], [68.62985992, 23.29513931], [68.62985992, 23.2954216], [68.63014221, 23.29541588], [68.63014221, 23.29569435], [68.63153076, 23.29569435], [68.63153076, 23.29597282], [68.63291931, 23.29597092], [68.63291931, 23.29624939], [68.63318634, 23.29624939], [68.63318634, 23.29597092], [68.63458252, 23.29597282], [68.63458252, 23.29569435], [68.63680267, 23.29569435], [68.63680267, 23.29541588], [68.63791656, 23.29541588], [68.63791656, 23.29569435], [68.63847351, 23.29569435], [68.63847351, 23.29541588], [68.63903046, 23.29541588], [68.63903046, 23.29569435], [68.63957977, 23.29569435], [68.63957977, 23.29597282], [68.63986206, 23.29597092], [68.63986206, 23.29624939], [68.64041901, 23.29624939], [68.64041901, 23.29653168], [68.64903259, 23.29653168], [68.64903259, 23.29624939], [68.64958191, 23.29624939], [68.64958191, 23.29597092], [68.65041351, 23.29597282], [68.65041351, 23.29569435], [68.6506958, 23.29569435], [68.6506958, 23.29513931], [68.65097046, 23.29513931], [68.65097046, 23.29486084], [68.6515274, 23.29486084], [68.6515274, 23.29458046], [68.6526413, 23.29458046], [68.6526413, 23.29486084], [68.65319824, 23.29486084], [68.65319824, 23.29513931], [68.6534729, 23.29513931], [68.6534729, 23.2954216], [68.65458679, 23.2954216], [68.65458679, 23.29513931], [68.65513611, 23.29513931], [68.65513611, 23.29486084], [68.65569305, 23.29486084], [68.65569305, 23.29513931], [68.65624237, 23.29513931], [68.65624237, 23.29486084], [68.65680695, 23.29486084], [68.65680695, 23.29513931], [68.65791321, 23.29513931], [68.65791321, 23.2954216], [68.65930176, 23.29541588], [68.65930939, 23.29569435], [68.66069794, 23.29569435], [68.66069794, 23.29597282], [68.66152954, 23.29597092], [68.66152954, 23.29624939], [68.66208649, 23.29624939], [68.66208649, 23.29653168], [68.66291809, 23.29653168], [68.66291809, 23.29681015], [68.66347504, 23.29680634], [68.66347504, 23.2970829], [68.66430664, 23.2970829], [68.66430664, 23.29736137], [68.66485596, 23.29735947], [68.66485596, 23.29764175], [68.6654129, 23.29764175], [68.6654129, 23.29792023], [68.66569519, 23.29791641], [68.66569519, 23.29819489], [68.66625214, 23.29819489], [68.66625214, 23.29847145], [68.66680908, 23.29846954], [68.66680908, 23.29874992], [68.6673584, 23.29874992], [68.6673584, 23.2990303], [68.66902924, 23.2990303], [68.66902924, 23.29931068], [68.67041779, 23.29930305], [68.67041779, 23.29958153], [68.67208099, 23.29958153], [68.67208099, 23.29986382], [68.67402649, 23.29985046], [68.67402649, 23.30014038], [68.67457581, 23.30014038], [68.67457581, 23.29985046], [68.67819214, 23.29986382], [68.67819214, 23.29958153], [68.67903137, 23.29957962], [68.67903137, 23.30014038], [68.67930603, 23.30013847], [68.67930603, 23.30069542], [68.67958069, 23.30069542], [68.67958069, 23.30097389], [68.68264008, 23.30097389], [68.68264008, 23.30069542], [68.68319702, 23.30069542], [68.68319702, 23.30041695], [68.68430328, 23.30041695], [68.68430328, 23.30069542], [68.68458557, 23.30069542], [68.68458557, 23.30097389], [68.68486023, 23.30097008], [68.68486023, 23.30125046], [68.68514252, 23.30125046], [68.68514252, 23.30153084], [68.68569183, 23.30153084], [68.68569183, 23.30181122], [68.68597412, 23.3018055], [68.68597412, 23.30208588], [68.68624878, 23.30208015], [68.68624878, 23.30236053], [68.6865387, 23.30236053], [68.6865387, 23.30291939], [68.68791962, 23.30291748], [68.68791962, 23.30347252], [68.68818665, 23.30347061], [68.68818665, 23.30375099], [68.68875122, 23.30375099], [68.68875122, 23.30402946], [68.69097137, 23.30402756], [68.69097137, 23.3045826], [68.69124603, 23.30458069], [68.69124603, 23.30486107], [68.69180298, 23.30486107], [68.69180298, 23.30513954], [68.69264221, 23.30513954], [68.69264221, 23.30541992], [68.69319153, 23.30541611], [68.69319153, 23.30569458], [68.69374847, 23.30569077], [68.69374847, 23.30598068], [68.69403076, 23.30598068], [68.69403076, 23.30624962], [68.69458008, 23.30624962], [68.69458008, 23.30652809], [68.69541931, 23.30652809], [68.69541931, 23.30680466], [68.69569397, 23.30680466], [68.69569397, 23.3073616], [68.69596863, 23.3073616], [68.69596863, 23.30652809], [68.69819641, 23.30652809], [68.69819641, 23.30624962], [68.69875336, 23.30624962], [68.69875336, 23.30598068], [68.69930267, 23.30598068], [68.69930267, 23.30569077], [68.70207977, 23.30569458], [68.70207977, 23.30541611], [68.70458221, 23.30541992], [68.70458221, 23.30486107], [68.70430756, 23.30486107], [68.70430756, 23.30458069], [68.70513916, 23.3045826], [68.70513916, 23.30430794], [68.70540619, 23.30430984], [68.70540619, 23.30402946], [68.70569611, 23.30402946], [68.70569611, 23.30375099], [68.70707703, 23.30375099], [68.70707703, 23.30347061], [68.70735931, 23.30347252], [68.70735931, 23.30319595], [68.7076416, 23.30319595], [68.7076416, 23.30291748], [68.70791626, 23.30291939], [68.70791626, 23.30236053], [68.70819092, 23.30236053], [68.70819092, 23.30181122], [68.70847321, 23.30181122], [68.70847321, 23.30125046], [68.70874786, 23.30125046], [68.70874786, 23.30042076], [68.70903015, 23.30042076], [68.70903015, 23.29985046], [68.70791626, 23.29986382], [68.70791626, 23.29930305], [68.70819092, 23.29931068], [68.70819092, 23.2990303], [68.70903015, 23.2990303], [68.70903015, 23.29874992], [68.7104187, 23.29874992], [68.7104187, 23.29819107], [68.71069336, 23.29819489], [68.71069336, 23.29791641], [68.71180725, 23.29792023], [68.71180725, 23.29764175], [68.71208191, 23.29764175], [68.71208191, 23.29735947], [68.71263885, 23.29736137], [68.71263885, 23.2970829], [68.7140274, 23.2970829], [68.7140274, 23.29680634], [68.71679688, 23.29681015], [68.71679688, 23.29653168], [68.71763611, 23.29653168], [68.71763611, 23.29624939], [68.71985626, 23.29624939], [68.71985626, 23.29597092], [68.72097015, 23.29597282], [68.72097015, 23.29569435], [68.72208405, 23.29569435], [68.72208405, 23.29541588], [68.72402954, 23.29541588], [68.72402954, 23.29569435], [68.7251358, 23.29569435], [68.7251358, 23.29597282], [68.72597504, 23.29597282], [68.72597504, 23.29624939], [68.72651672, 23.29624939], [68.72651672, 23.29653168], [68.7270813, 23.29653168], [68.7270813, 23.29681015], [68.72763824, 23.29680634], [68.72763824, 23.2970829], [68.7279129, 23.2970829], [68.7279129, 23.29736137], [68.72846222, 23.29735947], [68.72846222, 23.29764175], [68.72875214, 23.29764175], [68.72875214, 23.29792023], [68.72930908, 23.29791641], [68.72930908, 23.29819489], [68.72958374, 23.29819489], [68.72958374, 23.29847145], [68.7298584, 23.29846954], [68.7298584, 23.29874992], [68.73014069, 23.29874992], [68.73014069, 23.2990303], [68.73041534, 23.2990284], [68.73041534, 23.29958153], [68.73069763, 23.29958153], [68.73069763, 23.29986382], [68.73097229, 23.29985046], [68.73097229, 23.30014038], [68.73124695, 23.30013847], [68.73124695, 23.30069542], [68.73152161, 23.3006897], [68.73152161, 23.30125046], [68.73179626, 23.30125046], [68.73179626, 23.30236053], [68.73208618, 23.30236053], [68.73208618, 23.30541992], [68.73236084, 23.30541992], [68.73236084, 23.30598068], [68.7326355, 23.30597305], [68.7326355, 23.30624962], [68.73291779, 23.30624962], [68.73291779, 23.30680466], [68.73319244, 23.30680466], [68.73319244, 23.30708313], [68.73347473, 23.30708313], [68.73347473, 23.3073616], [68.73401642, 23.3073597], [68.73401642, 23.30763817], [68.73430634, 23.30763817], [68.73430634, 23.30791855], [68.73486328, 23.30791855], [68.73486328, 23.30820084], [68.73513794, 23.30819511], [68.73513794, 23.30847168], [68.73568726, 23.30846977], [68.73568726, 23.30874825], [68.73735809, 23.30874825], [68.73735809, 23.30846977], [68.73847198, 23.30847168], [68.73847198, 23.30819511], [68.73929596, 23.30820084], [68.73929596, 23.30791855], [68.74014282, 23.30791855], [68.74014282, 23.30763817], [68.74069214, 23.30763817], [68.74069214, 23.3073597], [68.74097443, 23.3073616], [68.74097443, 23.30708313], [68.74153137, 23.30708313], [68.74153137, 23.30680466], [68.74208069, 23.30680466], [68.74208069, 23.30652809], [68.74263763, 23.30652809], [68.74263763, 23.30624962], [68.74346161, 23.30624962], [68.74346161, 23.30598068], [68.74375153, 23.30598068], [68.74375153, 23.30569077], [68.74402618, 23.30569458], [68.74402618, 23.30541611], [68.74430847, 23.30541992], [68.74430847, 23.30513954], [68.74458313, 23.30513954], [68.74458313, 23.30486107], [68.74514008, 23.30486107], [68.74514008, 23.30402946], [68.74819183, 23.30402946], [68.74819183, 23.30513954], [68.74846649, 23.30513954], [68.74846649, 23.30541992], [68.74874878, 23.30541611], [68.74874878, 23.30569458], [68.74930573, 23.30569458], [68.74930573, 23.30624962], [68.74958038, 23.30624962], [68.74958038, 23.30680466], [68.74986267, 23.30680466], [68.74986267, 23.3073616], [68.75013733, 23.3073597], [68.75013733, 23.30791855], [68.75041962, 23.30791664], [68.75041962, 23.30847168], [68.75068665, 23.30846977], [68.75068665, 23.30904007], [68.75096893, 23.30902863], [68.75096893, 23.30958366], [68.75125122, 23.30958176], [68.75125122, 23.31014252], [68.75152588, 23.3101387], [68.75152588, 23.31347466], [68.75180817, 23.31347466], [68.75180817, 23.31458473], [68.75208282, 23.31458473], [68.75208282, 23.31569672], [68.75235748, 23.31569672], [68.75235748, 23.31680679], [68.75263214, 23.31680107], [68.75263214, 23.3176403], [68.75291443, 23.3176384], [68.75291443, 23.31847191], [68.75319672, 23.31847], [68.75319672, 23.31931114], [68.75347137, 23.31931114], [68.75347137, 23.32014084], [68.75374603, 23.32014084], [68.75374603, 23.32098007], [68.75402832, 23.32098007], [68.75402832, 23.32181168], [68.75430298, 23.32181168], [68.75430298, 23.32263947], [68.75458527, 23.32263947], [68.75458527, 23.3231945], [68.75485992, 23.32319069], [68.75485992, 23.32374954], [68.75514221, 23.32374954], [68.75514221, 23.32430267], [68.75541687, 23.32430649], [68.75541687, 23.32486343], [68.75569153, 23.32485962], [68.75569153, 23.32542038], [68.75597382, 23.32541656], [68.75597382, 23.3259716], [68.75624847, 23.3259697], [68.75624847, 23.32653046], [68.75653076, 23.32652855], [68.75653076, 23.32708549], [68.75680542, 23.32708549], [68.75680542, 23.32736015], [68.75708008, 23.32736015], [68.75708008, 23.32764053], [68.75736237, 23.32763863], [68.75736237, 23.32819557], [68.75763702, 23.32818985], [68.75763702, 23.32875061], [68.75791931, 23.32875061], [68.75791931, 23.32986069], [68.75818634, 23.32986069], [68.75818634, 23.33041954], [68.75763702, 23.33041954], [68.75763702, 23.3301506], [68.75736237, 23.3301506], [68.75736237, 23.32958031], [68.75708008, 23.32958412], [68.75708008, 23.32902718], [68.75681305, 23.32903099], [68.75681305, 23.32875061], [68.75653076, 23.32875061], [68.75653076, 23.32818985], [68.75624847, 23.32819557], [68.75624847, 23.32763863], [68.75596619, 23.32764053], [68.75596619, 23.32736015], [68.75569153, 23.32736206], [68.75569153, 23.32680321], [68.75541687, 23.32681084], [68.75541687, 23.32625008], [68.75514221, 23.32625008], [68.75514221, 23.32570076], [68.75485992, 23.32570076], [68.75485992, 23.32514191], [68.7545929, 23.32514191], [68.7545929, 23.32458115], [68.75430298, 23.32458115], [68.75430298, 23.32402802], [68.75402832, 23.32402802], [68.75402832, 23.32347107], [68.75375366, 23.32347107], [68.75375366, 23.32291603], [68.75347137, 23.32292175], [68.75347137, 23.32235909], [68.75319672, 23.32235909], [68.75319672, 23.32181168], [68.7529068, 23.32181168], [68.7529068, 23.32125092], [68.75263214, 23.32125092], [68.75263214, 23.32041931], [68.75235748, 23.32041931], [68.75235748, 23.31957817], [68.75208282, 23.31958389], [68.75208282, 23.31875038], [68.75180817, 23.31875038], [68.75180817, 23.31792068], [68.75152588, 23.31792068], [68.75152588, 23.31707954], [68.75125122, 23.31708336], [68.75125122, 23.31652832], [68.75096893, 23.31653023], [68.75096893, 23.31569099], [68.75069427, 23.31569672], [68.75069427, 23.3148613], [68.75041962, 23.3148613], [68.75041962, 23.31374931], [68.75013733, 23.31375122], [68.75013733, 23.31291962], [68.74986267, 23.31291962], [68.74986267, 23.31208038], [68.74958038, 23.31208229], [68.74958038, 23.31152725], [68.74931335, 23.31153107], [68.74931335, 23.31097031], [68.74903107, 23.31097031], [68.74903107, 23.3101387], [68.74874878, 23.31014252], [68.74874878, 23.30958176], [68.74847412, 23.30958366], [68.74847412, 23.30874825], [68.74819183, 23.30874825], [68.74819183, 23.30791855], [68.74791718, 23.30791855], [68.74791718, 23.30680084], [68.74764252, 23.30680466], [68.74764252, 23.30652809], [68.74736023, 23.30652809], [68.74736023, 23.30624962], [68.74708557, 23.30624962], [68.74708557, 23.30597305], [68.74680328, 23.30598068], [68.74680328, 23.30569077], [68.7454071, 23.30569077], [68.7454071, 23.30598068], [68.74485779, 23.30598068], [68.74485779, 23.30624962], [68.74458313, 23.30624962], [68.74458313, 23.30652809], [68.74402618, 23.30652809], [68.74402618, 23.30680466], [68.74375153, 23.30680466], [68.74375153, 23.30708313], [68.74319458, 23.30708313], [68.74319458, 23.3073616], [68.74263763, 23.3073597], [68.74263763, 23.30763817], [68.74180603, 23.30763817], [68.74180603, 23.30791855], [68.74124908, 23.30791855], [68.74124908, 23.30820084], [68.74069214, 23.30819511], [68.74069214, 23.30847168], [68.74013519, 23.30847168], [68.74014282, 23.30874825], [68.73929596, 23.30874825], [68.73929596, 23.30904007], [68.73874664, 23.30904007], [68.73874664, 23.30931282], [68.73513794, 23.30931282], [68.73513794, 23.30904007], [68.73430634, 23.30904007], [68.73430634, 23.30874825], [68.73374939, 23.30874825], [68.73374939, 23.30846977], [68.73347473, 23.30847168], [68.73347473, 23.30819511], [68.73291779, 23.30820084], [68.73291779, 23.30791855], [68.73236084, 23.30791855], [68.73236084, 23.30763817], [68.73208618, 23.30763817], [68.73208618, 23.3073597], [68.73180389, 23.3073616], [68.73180389, 23.30708313], [68.73152924, 23.30708313], [68.73152924, 23.30652809], [68.73124695, 23.30652809], [68.73124695, 23.30569077], [68.73097229, 23.30569458], [68.73097229, 23.30402756], [68.73069763, 23.30402946], [68.73069763, 23.30264091], [68.73042297, 23.30264091], [68.73042297, 23.30208015], [68.73014069, 23.30208588], [68.73014069, 23.30152512], [68.7298584, 23.30153084], [68.7298584, 23.30125046], [68.72957611, 23.30125046], [68.72957611, 23.30097008], [68.72930908, 23.30097389], [68.72930908, 23.30041695], [68.72902679, 23.30042076], [68.72902679, 23.30014038], [68.72875214, 23.30014038], [68.72875214, 23.29985046], [68.72846985, 23.29986382], [68.72846985, 23.29958153], [68.72819519, 23.29958153], [68.72819519, 23.29930305], [68.72763824, 23.29931068], [68.72763824, 23.2990303], [68.72735596, 23.2990303], [68.72735596, 23.29874992], [68.72680664, 23.29874992], [68.72680664, 23.29846954], [68.72652435, 23.29847145], [68.72652435, 23.29819489], [68.72597504, 23.29819489], [68.72597504, 23.29791641], [68.7251358, 23.29792023], [68.7251358, 23.29764175], [68.72458649, 23.29764175], [68.72458649, 23.29735947], [68.72402954, 23.29736137], [68.72402954, 23.2970829], [68.7206955, 23.2970829], [68.7206955, 23.29736137], [68.71985626, 23.29735947], [68.71985626, 23.29764175], [68.71930695, 23.29764175], [68.71930695, 23.29792023], [68.7179184, 23.29791641], [68.7179184, 23.29819489], [68.71652985, 23.29819489], [68.71652985, 23.29847145], [68.7159729, 23.29846954], [68.7159729, 23.29874992], [68.71569824, 23.29874992], [68.71569824, 23.2990303], [68.7151413, 23.2990303], [68.7151413, 23.29931068], [68.71485901, 23.29930305], [68.71485901, 23.29958153], [68.71430206, 23.29958153], [68.71430206, 23.29986382], [68.7140274, 23.29985046], [68.7140274, 23.30042076], [68.71375275, 23.30041695], [68.71375275, 23.30097389], [68.71347046, 23.30097389], [68.71347809, 23.30125046], [68.7131958, 23.30125046], [68.7131958, 23.30347252], [68.71347809, 23.30347061], [68.71347809, 23.30430984], [68.71736145, 23.30430984], [68.71736145, 23.30402946], [68.71847534, 23.30402756], [68.71847534, 23.3045826], [68.71708679, 23.30458069], [68.71708679, 23.30486107], [68.7159729, 23.30486107], [68.7159729, 23.30513954], [68.71375275, 23.30513954], [68.71375275, 23.30541992], [68.71347809, 23.30541992], [68.71347809, 23.30598068], [68.7131958, 23.30597305], [68.7131958, 23.30680466], [68.71291351, 23.30680466], [68.71291351, 23.3073616], [68.71263885, 23.3073597], [68.71263885, 23.30791855], [68.7123642, 23.30791664], [68.7123642, 23.30847168], [68.71208191, 23.30846977], [68.71208191, 23.30904007], [68.71180725, 23.30902863], [68.71180725, 23.30958366], [68.71153259, 23.30958176], [68.71153259, 23.31014252], [68.71125031, 23.3101387], [68.71125031, 23.31069374], [68.7104187, 23.31069183], [68.7104187, 23.31264114], [68.70929718, 23.31264114], [68.70929718, 23.31291962], [68.70735931, 23.3129158], [68.70735931, 23.31319237], [68.7076416, 23.31319046], [68.7076416, 23.31375122], [68.70791626, 23.31375122], [68.70791626, 23.31402969], [68.70847321, 23.31402969], [68.70847321, 23.31431007], [68.70874786, 23.31430626], [68.70874786, 23.31458473], [68.70847321, 23.31458473], [68.70847321, 23.3148613], [68.7076416, 23.3148613], [68.7076416, 23.31458473], [68.70652771, 23.31458473], [68.70652771, 23.31430626], [68.70540619, 23.31431007], [68.70540619, 23.31402969], [68.70430756, 23.31402969], [68.70430756, 23.31375122], [68.70291901, 23.31375122], [68.70291901, 23.31347084], [68.70181274, 23.31347084], [68.70181274, 23.31375122], [68.69875336, 23.31375122], [68.69875336, 23.31347084], [68.69847107, 23.31347466], [68.69847107, 23.31319237], [68.69819641, 23.31319237], [68.69819641, 23.3129158], [68.69763947, 23.31291962], [68.69763947, 23.31264114], [68.69680786, 23.31264114], [68.69680786, 23.31069183], [68.69625092, 23.31069374], [68.69625092, 23.31041718], [68.69568634, 23.3104229], [68.69568634, 23.31014252], [68.69513702, 23.31014252], [68.69513702, 23.30986023], [68.69430542, 23.30986023], [68.69430542, 23.30958366], [68.69374847, 23.30958366], [68.69374847, 23.30930519], [68.69319153, 23.30931282], [68.69319153, 23.30904007], [68.69291687, 23.30904007], [68.69291687, 23.30874825], [68.69235229, 23.30874825], [68.69235229, 23.30846977], [68.69180298, 23.30846977], [68.69180298, 23.30874825], [68.69097137, 23.30874825], [68.69097137, 23.30904007], [68.68930817, 23.30904007], [68.68930817, 23.30874825], [68.68818665, 23.30874825], [68.68818665, 23.30846977], [68.68763733, 23.30847168], [68.68763733, 23.30819511], [68.68681335, 23.30820084], [68.68681335, 23.30791855], [68.68624878, 23.30791855], [68.68624878, 23.30763817], [68.68541718, 23.30763817], [68.68541718, 23.3073597], [68.68402863, 23.3073616], [68.68402863, 23.30708313], [68.68264008, 23.30708313], [68.68264008, 23.30680466], [68.68041992, 23.30680466], [68.68041992, 23.30708313], [68.68013763, 23.30708122], [68.68013763, 23.30791855], [68.67986298, 23.30791855], [68.67986298, 23.30820084], [68.67680359, 23.30819511], [68.67680359, 23.30847168], [68.67652893, 23.30847168], [68.67652893, 23.3073616], [68.67680359, 23.3073616], [68.67680359, 23.30708313], [68.67874908, 23.30708313], [68.67874908, 23.30652809], [68.6784668, 23.30652809], [68.6784668, 23.30569077], [68.67819214, 23.30569458], [68.67819214, 23.30541611], [68.67735291, 23.30541992], [68.67735291, 23.30513954], [68.67624664, 23.30513954], [68.67624664, 23.30541992], [68.67569733, 23.30541611], [68.67569733, 23.30569458], [68.67542267, 23.30569077], [68.67542267, 23.30652809], [68.67569733, 23.30652809], [68.67569733, 23.3073616], [68.67542267, 23.3073597], [68.67542267, 23.30820084], [68.67514038, 23.30820084], [68.67514038, 23.30763817], [68.67485809, 23.30763817], [68.67485809, 23.3073597], [68.67458344, 23.3073616], [68.67458344, 23.30708313], [68.67485809, 23.30708313], [68.67485809, 23.30680466], [68.67458344, 23.30680466], [68.67458344, 23.30624962], [68.67430878, 23.30624962], [68.67430878, 23.30458069], [68.67402649, 23.3045826], [68.67402649, 23.30402756], [68.67375183, 23.30402946], [68.67375183, 23.30375099], [68.67318726, 23.30375099], [68.67318726, 23.30402946], [68.67263794, 23.30402946], [68.67263794, 23.30430984], [68.67236328, 23.30430794], [68.67236328, 23.3045826], [68.67208099, 23.30458069], [68.67208099, 23.30486107], [68.67180634, 23.30486107], [68.67180634, 23.30541992], [68.67152405, 23.30541611], [68.67152405, 23.30569458], [68.67124939, 23.30569077], [68.67124939, 23.30624962], [68.6709671, 23.30624962], [68.6709671, 23.30652809], [68.67014313, 23.30652809], [68.67014313, 23.30624962], [68.66958618, 23.30624962], [68.66958618, 23.30598068], [68.66874695, 23.30598068], [68.66874695, 23.30513954], [68.66902924, 23.30513954], [68.66902924, 23.30375099], [68.66874695, 23.30375099], [68.66874695, 23.30347061], [68.66847229, 23.30347252], [68.66847229, 23.30319595], [68.66819763, 23.30319595], [68.66819763, 23.30291748], [68.66764069, 23.30291748], [68.66764069, 23.30319595], [68.6673584, 23.30319023], [68.6673584, 23.30430984], [68.66680908, 23.30430984], [68.66680908, 23.30402946], [68.66596985, 23.30402946], [68.66596985, 23.30375099], [68.6654129, 23.30375099], [68.6654129, 23.30347061], [68.66513824, 23.30347252], [68.66513824, 23.30319595], [68.6645813, 23.30319595], [68.6645813, 23.30291748], [68.66430664, 23.30291748], [68.66430664, 23.30319595], [68.66374969, 23.30319595], [68.66374969, 23.30347252], [68.66348267, 23.30347061], [68.66348267, 23.30375099], [68.66319275, 23.30375099], [68.66319275, 23.30402946], [68.66291809, 23.30402946], [68.66291809, 23.30430984], [68.6626358, 23.30430794], [68.6626358, 23.3045826], [68.66236115, 23.3045826], [68.66236877, 23.30513954], [68.66208649, 23.30513954], [68.66208649, 23.30569458], [68.66152954, 23.30569458], [68.66152954, 23.30541611], [68.66069794, 23.30541992], [68.66069794, 23.30513954], [68.66041565, 23.30513954], [68.66041565, 23.30486107], [68.66014099, 23.30486107], [68.66014099, 23.30458069], [68.6598587, 23.3045826], [68.6598587, 23.30430794], [68.65957642, 23.30430984], [68.65957642, 23.30375099], [68.65930939, 23.30375099], [68.65930939, 23.30347061], [68.65875244, 23.30347061], [68.65875244, 23.30375099], [68.65847015, 23.30375099], [68.65847015, 23.30402946], [68.6581955, 23.30402756], [68.6581955, 23.3045826], [68.65847015, 23.30458069], [68.65847015, 23.30513954], [68.65875244, 23.30513954], [68.65875244, 23.30598068], [68.6590271, 23.30598068], [68.6590271, 23.30652809], [68.65930176, 23.30652809], [68.65930939, 23.3073616], [68.65957642, 23.3073597], [68.65957642, 23.30820084], [68.6598587, 23.30820084], [68.6598587, 23.30904007], [68.66014099, 23.30904007], [68.66014099, 23.3104229], [68.66042328, 23.3104229], [68.66042328, 23.31903076], [68.66069794, 23.31903076], [68.66069794, 23.31986046], [68.6609726, 23.31986046], [68.6609726, 23.32014084], [68.66152954, 23.32014084], [68.66152954, 23.32041931], [68.6618042, 23.3204174], [68.6618042, 23.32069397], [68.66208649, 23.32068825], [68.66208649, 23.32098007], [68.6626358, 23.32098007], [68.6626358, 23.32125092], [68.66291809, 23.32125092], [68.66291809, 23.32152939], [68.66348267, 23.32152939], [68.66348267, 23.32181168], [68.66374969, 23.32180595], [68.66374969, 23.32208252], [68.66430664, 23.32208061], [68.66430664, 23.32235909], [68.66625214, 23.32235909], [68.66625214, 23.32263947], [68.6673584, 23.32263947], [68.6673584, 23.32292175], [68.66819763, 23.32291603], [68.66819763, 23.32347107], [68.66847229, 23.32347107], [68.66847229, 23.32402802], [68.66930389, 23.32402802], [68.66930389, 23.32486343], [68.66902924, 23.32485962], [68.66902924, 23.32514191], [68.66874695, 23.32514191], [68.66874695, 23.32542038], [68.66792297, 23.32542038], [68.66792297, 23.32514191], [68.66764069, 23.32514191], [68.66764069, 23.32485962], [68.66708374, 23.32486343], [68.66708374, 23.32458115], [68.66680908, 23.32458115], [68.66680908, 23.32430649], [68.66652679, 23.3243103], [68.66652679, 23.32401848], [68.66625214, 23.32402802], [68.66625214, 23.32374954], [68.66596985, 23.32374954], [68.66596985, 23.32346916], [68.66486359, 23.32347107], [68.66486359, 23.3231945], [68.66374969, 23.3231945], [68.66374969, 23.32291603], [68.6626358, 23.32291603], [68.6626358, 23.32347107], [68.66291809, 23.32347107], [68.66291809, 23.32402802], [68.66069794, 23.32402802], [68.66069794, 23.32347107], [68.66041565, 23.32347107], [68.66041565, 23.32291603], [68.65958405, 23.32291603], [68.65958405, 23.3231945], [68.6590271, 23.3231945], [68.6590271, 23.32291603], [68.65875244, 23.32292175], [68.65875244, 23.32235909], [68.6590271, 23.32235909], [68.6590271, 23.32181168], [68.65930939, 23.32181168], [68.65930939, 23.32152939], [68.65875244, 23.32152939], [68.65875244, 23.32125092], [68.6581955, 23.32125092], [68.6581955, 23.32097244], [68.65791321, 23.32098007], [68.65791321, 23.32041931], [68.65763855, 23.32041931], [68.65763855, 23.31986046], [68.65735626, 23.31986046], [68.65735626, 23.31957817], [68.65763855, 23.31958389], [68.65763855, 23.31930542], [68.65791321, 23.31931114], [68.65791321, 23.31875038], [68.65820313, 23.31875038], [68.6581955, 23.31791878], [68.65847015, 23.31792068], [68.65847015, 23.31680107], [68.65875244, 23.31680679], [68.65875244, 23.31541634], [68.6590271, 23.31542015], [68.6590271, 23.31431007], [68.65930939, 23.31431007], [68.65930939, 23.31319046], [68.6590271, 23.31319237], [68.6590271, 23.3129158], [68.65875244, 23.31291962], [68.65875244, 23.31264114], [68.6590271, 23.31264114], [68.6590271, 23.30986023], [68.65875244, 23.30986023], [68.65875244, 23.30874825], [68.65847015, 23.30874825], [68.65847015, 23.30820084], [68.65820313, 23.30820084], [68.65820313, 23.30763817], [68.65791321, 23.30763817], [68.65791321, 23.30708122], [68.65763855, 23.30708313], [68.65763855, 23.30652809], [68.65735626, 23.30652809], [68.65735626, 23.30541992], [68.6570816, 23.30541992], [68.6570816, 23.30458069], [68.65680695, 23.3045826], [68.65680695, 23.30319595], [68.65652466, 23.30319595], [68.65652466, 23.30291748], [68.65569305, 23.30291939], [68.65569305, 23.30264091], [68.6534729, 23.30264091], [68.6534729, 23.30291939], [68.65235901, 23.30291748], [68.65235901, 23.30319595], [68.6526413, 23.30319023], [68.6526413, 23.30430984], [68.65208435, 23.30430794], [68.65208435, 23.3045826], [68.65180206, 23.30458069], [68.65180206, 23.30513954], [68.65097046, 23.30513954], [68.65097046, 23.30486107], [68.6506958, 23.30486107], [68.6506958, 23.30430984], [68.65013885, 23.30430794], [68.65013885, 23.3045826], [68.64985657, 23.30458069], [68.64985657, 23.30486107], [68.64958191, 23.30486107], [68.64958191, 23.30541992], [68.64930725, 23.30541611], [68.64930725, 23.30569458], [68.64903259, 23.30569077], [68.64903259, 23.30652809], [68.64930725, 23.30652809], [68.64930725, 23.30763817], [68.64903259, 23.30763817], [68.64903259, 23.30791855], [68.64848328, 23.30791855], [68.64848328, 23.30820084], [68.64819336, 23.30819511], [68.64819336, 23.30847168], [68.6479187, 23.30846977], [68.6479187, 23.31014252], [68.64763641, 23.31014252], [68.64763641, 23.31153107], [68.64736176, 23.31152725], [68.64736176, 23.31319237], [68.6470871, 23.31319046], [68.6470871, 23.31431007], [68.64680481, 23.31430626], [68.64680481, 23.31458473], [68.6470871, 23.31458473], [68.6470871, 23.3148613], [68.64680481, 23.3148613], [68.64680481, 23.31569672], [68.64653015, 23.31569099], [68.64653015, 23.31624985], [68.64624786, 23.31624985], [68.64624786, 23.31736183], [68.64597321, 23.31736183], [68.64597321, 23.31847191], [68.64569092, 23.31847], [68.64569092, 23.31931114], [68.64541626, 23.31931114], [68.64541626, 23.31986046], [68.6451416, 23.31986046], [68.6451416, 23.32098007], [68.64485931, 23.32098007], [68.64485931, 23.32181168], [68.64457703, 23.32181168], [68.64457703, 23.32263947], [68.64430237, 23.32263947], [68.64430237, 23.32292175], [68.64402771, 23.32291603], [68.64402771, 23.3231945], [68.64375305, 23.3231945], [68.64375305, 23.32291603], [68.64347076, 23.32292175], [68.64347076, 23.32263947], [68.64290619, 23.32263947], [68.64290619, 23.32235909], [68.64263916, 23.32235909], [68.64263916, 23.32208061], [68.6423645, 23.32208252], [68.6423645, 23.32180595], [68.64208221, 23.32181168], [68.64208221, 23.32152939], [68.64180756, 23.32152939], [68.64180756, 23.32125092], [68.64152527, 23.32125092], [68.64152527, 23.32097244], [68.64124298, 23.32098007], [68.64124298, 23.32041931], [68.64097595, 23.32041931], [68.64097595, 23.32014084], [68.64068604, 23.32014084], [68.64068604, 23.31986046], [68.64041901, 23.31986046], [68.64041901, 23.31957817], [68.63986206, 23.31958389], [68.63986206, 23.31930542], [68.63903046, 23.31931114], [68.63903046, 23.31903076], [68.63819885, 23.31903076], [68.63819885, 23.31875038], [68.63791656, 23.31875038], [68.63791656, 23.31847], [68.63764191, 23.31847191], [68.63764191, 23.31819534], [68.63735962, 23.3182106], [68.63735962, 23.31792068], [68.63709259, 23.31792068], [68.63709259, 23.31735992], [68.63680267, 23.31736183], [68.63680267, 23.31680679], [68.63652802, 23.31680679], [68.63652802, 23.31652832], [68.63569641, 23.31652832], [68.63569641, 23.31680679], [68.63541412, 23.31680679], [68.63541412, 23.31708336], [68.63513947, 23.31708336], [68.63513947, 23.31736183], [68.63485718, 23.31735992], [68.63485718, 23.3176403], [68.63458252, 23.3176403], [68.63458252, 23.31792068], [68.6340332, 23.31792068], [68.6340332, 23.3182106], [68.63375092, 23.31819534], [68.63375092, 23.31847191], [68.63346863, 23.31847], [68.63346863, 23.31875038], [68.63318634, 23.31875038], [68.63318634, 23.31903076], [68.63291931, 23.31903076], [68.63291931, 23.31931114], [68.63318634, 23.31931114], [68.63318634, 23.32292175], [68.63291931, 23.32291603], [68.63291931, 23.32347107], [68.63263702, 23.32347107], [68.63263702, 23.32402802], [68.63291931, 23.32402802], [68.63291931, 23.32430267], [68.63319397, 23.32430649], [68.63319397, 23.32486343], [68.63346863, 23.32485962], [68.63346863, 23.32542038], [68.63375092, 23.32542038], [68.63375092, 23.32625008], [68.6340332, 23.32625008], [68.6340332, 23.32681084], [68.63430786, 23.32680321], [68.63430786, 23.32708549], [68.63458252, 23.32707977], [68.63458252, 23.32736015], [68.63485718, 23.32736015], [68.63485718, 23.32764053], [68.63513947, 23.32764053], [68.63513947, 23.32792091], [68.63541412, 23.3279171], [68.63541412, 23.32819557], [68.63569641, 23.32818985], [68.63569641, 23.32875061], [68.63597107, 23.32875061], [68.63597107, 23.32903099], [68.63625336, 23.32903099], [68.63625336, 23.32930946], [68.63652802, 23.32930946], [68.63652802, 23.32986069], [68.63680267, 23.32986069], [68.63680267, 23.3301506], [68.63709259, 23.3301506], [68.63709259, 23.33041954], [68.63735962, 23.33041763], [68.63735962, 23.33097267], [68.63764191, 23.33097076], [68.63764191, 23.33125114], [68.63735962, 23.33125114], [68.63735962, 23.33152962], [68.63652802, 23.33152962], [68.63652802, 23.33125114], [68.63625336, 23.33125114], [68.63625336, 23.33097076], [68.63597107, 23.33097267], [68.63597107, 23.3306942], [68.63569641, 23.3306942], [68.63569641, 23.33041763], [68.63540649, 23.33041954], [68.63540649, 23.3301506], [68.63513947, 23.3301506], [68.63513947, 23.32986069], [68.63485718, 23.32986069], [68.63485718, 23.32958031], [68.63430786, 23.32958412], [68.63430786, 23.32930565], [68.63346863, 23.32930565], [68.63346863, 23.32958412], [68.63318634, 23.32958031], [68.63318634, 23.3301506], [68.63291931, 23.33013916], [68.63291931, 23.33097267], [68.63263702, 23.33097076], [68.63263702, 23.33152962], [68.63375092, 23.33152962], [68.63375092, 23.33125114], [68.63486481, 23.33124924], [68.63486481, 23.33208275], [68.63458252, 23.33208084], [68.63458252, 23.33263969], [68.63430786, 23.33263969], [68.63430786, 23.33291817], [68.63402557, 23.33291626], [68.63402557, 23.3334713], [68.63430786, 23.33346939], [68.63430786, 23.33402824], [68.63402557, 23.33402824], [68.63402557, 23.33430481], [68.63375092, 23.33430481], [68.63375092, 23.33458328], [68.63346863, 23.33458328], [68.63346863, 23.33486176], [68.63207245, 23.33485985], [68.63207245, 23.33513832], [68.63096619, 23.33513832], [68.63096619, 23.3354187], [68.6279068, 23.3354187], [68.6279068, 23.3357029], [68.62652588, 23.33569527], [68.62652588, 23.33597183], [68.62596893, 23.33596039], [68.62596893, 23.33625031], [68.62568665, 23.33625031], [68.62568665, 23.33681107], [68.62541962, 23.33681107], [68.62541962, 23.33764267], [68.62513733, 23.33763885], [68.62513733, 23.33847046], [68.62486267, 23.33847046], [68.62486267, 23.3390274], [68.62458038, 23.3390274], [68.62458038, 23.33958244], [68.62486267, 23.33958054], [68.62486267, 23.33986282], [68.62513733, 23.33986282], [68.62513733, 23.34041977], [68.62541962, 23.34041977], [68.62541962, 23.34124947], [68.62568665, 23.34124947], [68.62568665, 23.34209061], [68.62541962, 23.34209061], [68.62541962, 23.34263992], [68.62568665, 23.34263992], [68.62568665, 23.34320068], [68.62596893, 23.34319687], [68.62596893, 23.34347153], [68.62652588, 23.34346962], [68.62652588, 23.34375], [68.62680817, 23.34375], [68.62680817, 23.34458351], [68.62568665, 23.3445797], [68.62568665, 23.34625053], [68.62680817, 23.34625053], [68.62680817, 23.34653091], [68.62708282, 23.34653091], [68.62708282, 23.34680748], [68.62735748, 23.34680748], [68.62735748, 23.34653091], [68.62763977, 23.34653091], [68.62763977, 23.34597015], [68.62735748, 23.34597206], [68.62735748, 23.34486198], [68.62763977, 23.34486198], [68.62763977, 23.34430695], [68.62930298, 23.34431076], [68.62930298, 23.34375], [68.6295929, 23.34375], [68.62958527, 23.34347153], [68.62875366, 23.34347153], [68.62875366, 23.34291649], [68.62902832, 23.3429203], [68.62902832, 23.34263992], [68.63014221, 23.34263992], [68.63014221, 23.34235954], [68.63180542, 23.34236145], [68.63180542, 23.34180641], [68.63153076, 23.34181023], [68.63153076, 23.34152985], [68.63124847, 23.34152985], [68.63124847, 23.34124947], [68.63096619, 23.34124947], [68.63096619, 23.34097099], [68.63319397, 23.34097481], [68.63319397, 23.34041405], [68.63346863, 23.34041977], [68.63346863, 23.33958054], [68.63375092, 23.33958244], [68.63375092, 23.33930588], [68.63485718, 23.33930969], [68.63485718, 23.33986282], [68.63458252, 23.33986282], [68.63458252, 23.34013939], [68.63430786, 23.34013939], [68.63430786, 23.34069252], [68.63402557, 23.34069252], [68.63402557, 23.34097481], [68.63485718, 23.34097099], [68.63485718, 23.34124947], [68.63540649, 23.34124947], [68.63540649, 23.34209061], [68.63569641, 23.34209061], [68.63569641, 23.3429203], [68.63652802, 23.3429203], [68.63652802, 23.34320068], [68.63680267, 23.34320068], [68.63680267, 23.34375], [68.63708496, 23.34375], [68.63708496, 23.34486198], [68.63680267, 23.34486008], [68.63680267, 23.34542084], [68.63708496, 23.34541893], [68.63709259, 23.34625053], [68.63680267, 23.34625053], [68.63680267, 23.34680748], [68.63458252, 23.34680557], [68.63458252, 23.34708405], [68.63430786, 23.34708023], [68.63430786, 23.34736061], [68.6340332, 23.34736061], [68.6340332, 23.34792137], [68.63375092, 23.34791756], [68.63375092, 23.34958267], [68.63346863, 23.34958076], [68.63346863, 23.35013962], [68.63319397, 23.35013962], [68.63319397, 23.3520813], [68.63236237, 23.3520813], [68.63236237, 23.35236359], [68.62958527, 23.35236359], [68.62958527, 23.3520813], [68.62930298, 23.3520813], [68.62930298, 23.35180473], [68.62847137, 23.35180473], [68.62847137, 23.35124969], [68.6279068, 23.35124969], [68.6279068, 23.35153008], [68.62735748, 23.35152817], [68.62735748, 23.35180473], [68.62680817, 23.35180283], [68.62680817, 23.35292053], [68.62652588, 23.35292053], [68.62652588, 23.35375023], [68.62625885, 23.35375023], [68.62625885, 23.35403061], [68.62541962, 23.35403061], [68.62541962, 23.35346985], [68.62513733, 23.35346985], [68.62513733, 23.35375023], [68.62458038, 23.35375023], [68.62458038, 23.35320091], [68.62431335, 23.35320091], [68.62431335, 23.35264015], [68.62346649, 23.35264015], [68.62346649, 23.35124969], [68.62374878, 23.35124969], [68.62374878, 23.35096169], [68.62403107, 23.35097122], [68.62403107, 23.35069466], [68.62374878, 23.35069466], [68.62374878, 23.35013962], [68.62346649, 23.35013962], [68.62346649, 23.35042191], [68.62291718, 23.35041618], [68.62291718, 23.35069466], [68.62264252, 23.35069275], [68.62264252, 23.35124969], [68.62236023, 23.35124969], [68.62236023, 23.35292053], [68.62264252, 23.35292053], [68.62264252, 23.35375023], [68.62291718, 23.35375023], [68.62291718, 23.35403061], [68.6220932, 23.35403061], [68.6220932, 23.35375023], [68.62152863, 23.35375023], [68.62152863, 23.35542107], [68.62208557, 23.35541725], [68.62208557, 23.35569572], [68.62236023, 23.35569], [68.62236023, 23.35709], [68.62208557, 23.35708427], [68.6220932, 23.35736084], [68.62180328, 23.35736084], [68.62180328, 23.35764122], [68.62152863, 23.35764122], [68.62152863, 23.35791969], [68.62124634, 23.35791779], [68.62124634, 23.35819435], [68.62069702, 23.35819435], [68.62069702, 23.35791779], [68.6204071, 23.35791969], [68.6204071, 23.35764122], [68.61985779, 23.35764122], [68.61985779, 23.35736084], [68.61707306, 23.35736084], [68.61707306, 23.35764122], [68.61653137, 23.35764122], [68.61653137, 23.35791969], [68.61597443, 23.35791779], [68.61597443, 23.35819435], [68.61569214, 23.35819435], [68.61569214, 23.35847282], [68.61513519, 23.35847282], [68.61514282, 23.35874939], [68.61486053, 23.35874939], [68.61486053, 23.35902977], [68.61458588, 23.35902786], [68.61458588, 23.3595829], [68.61429596, 23.35958099], [68.61429596, 23.36041832], [68.61458588, 23.36041641], [68.61458588, 23.36069489], [68.61486053, 23.36069489], [68.61486053, 23.36097145], [68.61513519, 23.36097145], [68.61514282, 23.36124992], [68.61486053, 23.36124992], [68.61486053, 23.36208344], [68.61458588, 23.36208344], [68.61458588, 23.36236191], [68.61430359, 23.36236191], [68.61430359, 23.36180496], [68.61402893, 23.36181068], [68.61402893, 23.3615284], [68.61319733, 23.3615284], [68.61319733, 23.36181068], [68.61291504, 23.36180496], [68.61291504, 23.36458206], [68.61319733, 23.36458015], [68.61319733, 23.36514282], [68.61429596, 23.36514282], [68.61429596, 23.36541939], [68.61513519, 23.36541748], [68.61513519, 23.36569214], [68.61624908, 23.36569214], [68.61624908, 23.36541748], [68.61653137, 23.36541939], [68.61653137, 23.36514282], [68.61680603, 23.36514282], [68.61680603, 23.36486053], [68.61736298, 23.36486053], [68.61736298, 23.36458015], [68.61819458, 23.36458206], [68.61819458, 23.3643055], [68.61930847, 23.3643055], [68.61930847, 23.36458206], [68.61958313, 23.36458015], [68.61958313, 23.36541939], [68.61902618, 23.36541748], [68.61902618, 23.36569214], [68.61875153, 23.36569214], [68.61875153, 23.36597443], [68.61818695, 23.36597061], [68.61818695, 23.36626053], [68.61707306, 23.36626053], [68.61707306, 23.36652946], [68.61653137, 23.36652946], [68.61653137, 23.36680984], [68.61569214, 23.36680412], [68.61569214, 23.3670845], [68.61291504, 23.3670845], [68.61292267, 23.36736107], [68.61264038, 23.36736107], [68.61264038, 23.36763954], [68.61207581, 23.36763954], [68.61207581, 23.36791992], [68.61180878, 23.3679142], [68.61180878, 23.36819267], [68.61152649, 23.36819077], [68.61152649, 23.36874962], [68.61125183, 23.36874962], [68.61125183, 23.36930656], [68.61096954, 23.36930656], [68.61096954, 23.3698616], [68.61068726, 23.3698597], [68.61068726, 23.37042046], [68.60901642, 23.37042046], [68.60901642, 23.37070084], [68.60874939, 23.37070084], [68.60874939, 23.37375069], [68.60819244, 23.37375069], [68.60819244, 23.37402916], [68.60791779, 23.37402916], [68.60791779, 23.37431145], [68.6076355, 23.37430573], [68.6076355, 23.3745842], [68.60708618, 23.37458038], [68.60708618, 23.37486076], [68.60569763, 23.37486076], [68.60569763, 23.37513924], [68.60542297, 23.3751297], [68.60542297, 23.37542152], [68.60514069, 23.3754158], [68.60514069, 23.37569427], [68.60542297, 23.37569046], [68.60542297, 23.37624931], [68.60624695, 23.37624931], [68.60624695, 23.3765316], [68.60652924, 23.3765316], [68.60652924, 23.37681007], [68.60430908, 23.37680626], [68.60430908, 23.37708282], [68.60320282, 23.37708092], [68.60320282, 23.37820053], [68.60375214, 23.37819481], [68.60375214, 23.37847137], [68.60430908, 23.37846947], [68.60430908, 23.37874985], [68.60458374, 23.37874985], [68.60458374, 23.37930489], [68.6048584, 23.37930489], [68.6048584, 23.37986374], [68.60569763, 23.37985992], [68.60569763, 23.38042068], [68.60597229, 23.38041687], [68.60597229, 23.38097382], [68.60513306, 23.38097], [68.60513306, 23.38125992], [68.60457611, 23.38125992], [68.60457611, 23.38153076], [68.60402679, 23.38153076], [68.60402679, 23.38181114], [68.60346985, 23.38180351], [68.60346985, 23.3820858], [68.60319519, 23.3820858], [68.60320282, 23.38236046], [68.60263824, 23.38236046], [68.60263824, 23.38264084], [68.60236359, 23.38263893], [68.60236359, 23.38319588], [68.6020813, 23.38319588], [68.6020813, 23.38347244], [68.60151672, 23.38347054], [68.60151672, 23.38375092], [68.60069275, 23.38375092], [68.60069275, 23.38402939], [68.60041809, 23.38402748], [68.60041809, 23.38430786], [68.6001358, 23.38430786], [68.6001358, 23.38458252], [68.5993042, 23.38458252], [68.5993042, 23.38430786], [68.59902954, 23.38430786], [68.59902954, 23.38402748], [68.59874725, 23.38402939], [68.59874725, 23.38375092], [68.5984726, 23.38375092], [68.5984726, 23.38347054], [68.59791565, 23.38347244], [68.59791565, 23.38319588], [68.5973587, 23.38319588], [68.5973587, 23.3829174], [68.59707642, 23.38292122], [68.59707642, 23.38264084], [68.59680176, 23.38264084], [68.59680176, 23.38236046], [68.59625244, 23.38236046], [68.59625244, 23.38208008], [68.59597015, 23.3820858], [68.59597015, 23.38152695], [68.59625244, 23.38153076], [68.59625244, 23.37903023], [68.5965271, 23.37903023], [68.5965271, 23.37846947], [68.59680176, 23.37847137], [68.59680176, 23.37819481], [68.59902954, 23.37820053], [68.59902954, 23.37763977], [68.59958649, 23.37763977], [68.59958649, 23.37735939], [68.6001358, 23.3773613], [68.6001358, 23.37680626], [68.59986115, 23.37681007], [68.59986115, 23.37624931], [68.59958649, 23.37624931], [68.59958649, 23.37347031], [68.59986115, 23.37347221], [68.59986115, 23.37291718], [68.6001358, 23.37291908], [68.6001358, 23.37264061], [68.60041809, 23.37264061], [68.60041809, 23.37236023], [68.60098267, 23.37236023], [68.60097504, 23.37208366], [68.60124969, 23.37208366], [68.60124969, 23.37180519], [68.60151672, 23.37181091], [68.60151672, 23.37125015], [68.60180664, 23.37125015], [68.60180664, 23.37096977], [68.6020813, 23.37097168], [68.6020813, 23.37069511], [68.60235596, 23.37070084], [68.60235596, 23.37042046], [68.6029129, 23.37042046], [68.6029129, 23.3698597], [68.60319519, 23.3698616], [68.60319519, 23.36902809], [68.6029129, 23.36903], [68.6029129, 23.36791992], [68.60263824, 23.36791992], [68.60263824, 23.36708069], [68.6029129, 23.3670845], [68.6029129, 23.36680412], [68.60320282, 23.36680984], [68.60320282, 23.36626053], [68.60346985, 23.36626053], [68.60346985, 23.36569023], [68.60375214, 23.36569214], [68.60375214, 23.36541748], [68.60402679, 23.36541939], [68.60402679, 23.36514282], [68.60457611, 23.36514282], [68.60457611, 23.36486053], [68.6048584, 23.36486053], [68.6048584, 23.36431122], [68.60513306, 23.36431122], [68.60513306, 23.36403275], [68.60542297, 23.36403275], [68.60542297, 23.36347008], [68.60569763, 23.36347008], [68.60569763, 23.36291695], [68.60542297, 23.36292267], [68.60542297, 23.36235809], [68.60402679, 23.36236191], [68.60402679, 23.36208344], [68.60346985, 23.36208344], [68.60346985, 23.36180496], [68.60235596, 23.36181068], [68.60235596, 23.3615284], [68.60263824, 23.3615284], [68.60263824, 23.36124992], [68.6029129, 23.36124992], [68.6029129, 23.36096954], [68.60319519, 23.36097145], [68.60319519, 23.36041641], [68.60346985, 23.36041832], [68.60346985, 23.35985947], [68.60319519, 23.35986137], [68.60319519, 23.35930634], [68.60236359, 23.35930634], [68.60236359, 23.3595829], [68.6020813, 23.3595829], [68.6020813, 23.36013985], [68.60098267, 23.36013031], [68.60098267, 23.36041832], [68.60069275, 23.36041641], [68.60069275, 23.36069489], [68.60041809, 23.36069489], [68.60041809, 23.36097145], [68.6001358, 23.36096954], [68.6001358, 23.3615284], [68.59986115, 23.3615284], [68.59986115, 23.36236191], [68.60041809, 23.36235809], [68.60041809, 23.36264038], [68.60069275, 23.36263847], [68.60069275, 23.36319351], [68.60097504, 23.36319351], [68.60097504, 23.36347008], [68.60069275, 23.36347008], [68.60069275, 23.36375046], [68.60041809, 23.36375046], [68.60041809, 23.36403275], [68.6001358, 23.36402702], [68.6001358, 23.36597443], [68.59986115, 23.36597061], [68.59986115, 23.36652946], [68.59958649, 23.36652756], [68.59958649, 23.3670845], [68.59929657, 23.36708069], [68.59929657, 23.36763954], [68.59902954, 23.36763954], [68.59902954, 23.36819267], [68.59874725, 23.36819077], [68.59874725, 23.36874962], [68.5984726, 23.36874962], [68.5984726, 23.36903], [68.59819794, 23.36902809], [68.59819794, 23.36958313], [68.59791565, 23.36958313], [68.59791565, 23.3698616], [68.59764099, 23.3698597], [68.59764099, 23.37014008], [68.5965271, 23.37014008], [68.5965271, 23.37042046], [68.59597015, 23.37042046], [68.59597015, 23.37070084], [68.5956955, 23.37069511], [68.5956955, 23.37097168], [68.59541321, 23.37096977], [68.59541321, 23.37125015], [68.59513855, 23.37125015], [68.59513855, 23.37153053], [68.59485626, 23.37153053], [68.59485626, 23.37181091], [68.5945816, 23.37181091], [68.5945816, 23.37236023], [68.59430695, 23.37236023], [68.59430695, 23.37319374], [68.59401703, 23.37318993], [68.59401703, 23.37375069], [68.59375, 23.37375069], [68.59375, 23.37431145], [68.59347534, 23.37430573], [68.59347534, 23.3745842], [68.5929184, 23.3745842], [68.5929184, 23.37430573], [68.59152985, 23.37430573], [68.59152985, 23.3745842], [68.59124756, 23.37458038], [68.59124756, 23.37486076], [68.59069824, 23.37486076], [68.59069824, 23.37513924], [68.59041595, 23.3751297], [68.59041595, 23.37542152], [68.5901413, 23.3754158], [68.5901413, 23.37569427], [68.58985901, 23.37569046], [68.58985901, 23.3765316], [68.58958435, 23.37652779], [68.58958435, 23.3773613], [68.58930206, 23.37735939], [68.58930206, 23.37763977], [68.5890274, 23.37763977], [68.5890274, 23.37792015], [68.58875275, 23.37792015], [68.58875275, 23.37820053], [68.58847046, 23.37819481], [68.58847046, 23.37986374], [68.58763885, 23.37985992], [68.58763885, 23.38042068], [68.58790588, 23.38042068], [68.58790588, 23.38070107], [68.58763885, 23.38069534], [68.58763885, 23.38097382], [68.58708954, 23.38097], [68.58708954, 23.38125992], [68.58653259, 23.38125992], [68.58653259, 23.38153076], [68.58597565, 23.38152695], [68.58597565, 23.38236046], [68.58625031, 23.38236046], [68.58625031, 23.38264084], [68.58569336, 23.38264084], [68.58569336, 23.38292122], [68.58430481, 23.3829174], [68.58430481, 23.38319588], [68.58374786, 23.38319016], [68.58374786, 23.38375092], [68.58403015, 23.38375092], [68.58403015, 23.38486099], [68.58374786, 23.38486099], [68.58374786, 23.3856945], [68.58347321, 23.38569069], [68.58347321, 23.38624954], [68.5845871, 23.38624954], [68.5845871, 23.3868084], [68.58403015, 23.38680649], [68.58403015, 23.38708305], [68.58291626, 23.38708305], [68.58291626, 23.38736153], [68.58235931, 23.38735962], [68.58235931, 23.38763809], [68.58180237, 23.38763809], [68.58180237, 23.38820076], [68.58152771, 23.38820076], [68.58152771, 23.38902855], [68.58125305, 23.38902855], [68.58125305, 23.38958359], [68.58097076, 23.38958359], [68.58097076, 23.38986015], [68.58013916, 23.38986015], [68.58013916, 23.38958359], [68.5798645, 23.38958359], [68.5798645, 23.38930511], [68.57958221, 23.38931274], [68.57958221, 23.38902855], [68.57930756, 23.38902855], [68.57930756, 23.38874817], [68.57875061, 23.38874817], [68.57875061, 23.3884697], [68.57847595, 23.3884716], [68.57847595, 23.38708305], [68.57875061, 23.38708305], [68.57875061, 23.38652992], [68.57847595, 23.38652992], [68.57847595, 23.38597107], [68.57791901, 23.38597107], [68.57791901, 23.38624954], [68.57763672, 23.38624954], [68.57763672, 23.38652992], [68.57707977, 23.38652992], [68.57707977, 23.3868084], [68.57680511, 23.38680649], [68.57680511, 23.38708305], [68.57624817, 23.38708305], [68.57624817, 23.38736153], [68.57596588, 23.38735962], [68.57596588, 23.38763809], [68.57514954, 23.38763809], [68.57514954, 23.38791847], [68.57402802, 23.38791847], [68.57402802, 23.38820076], [68.57375336, 23.38820076], [68.57375336, 23.38931274], [68.57402802, 23.38930511], [68.57402802, 23.38958359], [68.57430267, 23.38958168], [68.57430267, 23.39014244], [68.57290649, 23.39014244], [68.57290649, 23.39042282], [68.57263947, 23.39042282], [68.57263947, 23.39125061], [68.57290649, 23.39125061], [68.57290649, 23.39180946], [68.57180786, 23.39180946], [68.57180786, 23.3915329], [68.5715332, 23.3915329], [68.5715332, 23.39125061], [68.57096863, 23.39125061], [68.57096863, 23.39097023], [68.57041931, 23.39097023], [68.57041931, 23.39069366], [68.57013702, 23.39069366], [68.57013702, 23.39013863], [68.56986237, 23.39014244], [68.56986237, 23.38958168], [68.56958008, 23.38958359], [68.56958008, 23.38819504], [68.56930542, 23.38819504], [68.56930542, 23.3884716], [68.56903076, 23.3884716], [68.56903076, 23.38819504], [68.56819153, 23.38820076], [68.56819153, 23.38791847], [68.56874847, 23.38791847], [68.56874847, 23.38735962], [68.56930542, 23.38736153], [68.56930542, 23.38708305], [68.56958008, 23.38708305], [68.56958008, 23.38680649], [68.56986237, 23.38680077], [68.56986237, 23.38652992], [68.57013702, 23.38652992], [68.57013702, 23.38624954], [68.57041931, 23.38624954], [68.57041931, 23.38597107], [68.57069397, 23.38597298], [68.57069397, 23.3856945], [68.57096863, 23.3856945], [68.57096863, 23.38541794], [68.57125092, 23.38541985], [68.57125092, 23.38458061], [68.57152557, 23.38458252], [68.57152557, 23.38430786], [68.57180786, 23.38430786], [68.57180786, 23.38375092], [68.57208252, 23.38375092], [68.57208252, 23.38347054], [68.57236481, 23.38347244], [68.57236481, 23.3829174], [68.57319641, 23.38292122], [68.57319641, 23.38402939], [68.57291412, 23.38402748], [68.57291412, 23.38458252], [68.57263947, 23.38458061], [68.57263947, 23.38486099], [68.57208252, 23.38486099], [68.57208252, 23.38541985], [68.57180786, 23.38541985], [68.57180786, 23.38624954], [68.5715332, 23.38624954], [68.5715332, 23.38652992], [68.57125092, 23.38652992], [68.57125092, 23.38680458], [68.57208252, 23.38680458], [68.57208252, 23.38652992], [68.57235718, 23.38652992], [68.57235718, 23.38624954], [68.57319641, 23.38624954], [68.57319641, 23.38652992], [68.57375336, 23.38652992], [68.57375336, 23.38569069], [68.57402802, 23.3856945], [68.57402802, 23.38513947], [68.57430267, 23.38513947], [68.57430267, 23.38486099], [68.57459259, 23.38486099], [68.57458496, 23.38458252], [68.57485962, 23.38458252], [68.57485962, 23.38430786], [68.57541656, 23.38430786], [68.57541656, 23.38402748], [68.57569122, 23.38402939], [68.57569122, 23.38375092], [68.57596588, 23.38375092], [68.57596588, 23.38347054], [68.57680511, 23.38347244], [68.57680511, 23.38319588], [68.57736206, 23.38319588], [68.57736206, 23.38263893], [68.57763672, 23.38264084], [68.57763672, 23.38236046], [68.57791901, 23.38236046], [68.57791901, 23.38208008], [68.57819366, 23.3820858], [68.57819366, 23.38180351], [68.57847595, 23.38181114], [68.57847595, 23.38153076], [68.57875061, 23.38153076], [68.57875061, 23.38097], [68.57902527, 23.38097382], [68.57902527, 23.37986374], [68.57930756, 23.37986374], [68.57930756, 23.37958145], [68.57958221, 23.37958145], [68.57958221, 23.37902832], [68.58013916, 23.37903023], [68.58013916, 23.37792015], [68.57985687, 23.37792015], [68.57985687, 23.37735939], [68.57958221, 23.3773613], [68.57958221, 23.37708282], [68.5798645, 23.37708282], [68.5798645, 23.37652779], [68.58040619, 23.3765316], [68.58040619, 23.37624931], [68.57958221, 23.37624931], [68.57958221, 23.37597084], [68.57875061, 23.37597084], [68.57875061, 23.37624931], [68.57235718, 23.37624931], [68.57235718, 23.37597084], [68.57208252, 23.37597275], [68.57208252, 23.37569427], [68.57180786, 23.37569427], [68.57180786, 23.3754158], [68.57096863, 23.37542152], [68.57096863, 23.3751297], [68.57068634, 23.3751297], [68.57068634, 23.37542152], [68.57041931, 23.3754158], [68.57041931, 23.37569427], [68.57013702, 23.37569046], [68.57013702, 23.3765316], [68.57041931, 23.3765316], [68.57041931, 23.37681007], [68.57013702, 23.37680626], [68.57013702, 23.37708282], [68.56986237, 23.37708282], [68.56986237, 23.3773613], [68.56958008, 23.37735939], [68.56958008, 23.37763977], [68.56874847, 23.37763977], [68.56874847, 23.37792015], [68.56819153, 23.37792015], [68.56819153, 23.37820053], [68.56764221, 23.37819481], [68.56764221, 23.37847137], [68.56735992, 23.37847137], [68.56735992, 23.37930489], [68.56708527, 23.37930489], [68.56708527, 23.37986374], [68.56680298, 23.37985992], [68.56680298, 23.3801403], [68.56735992, 23.3801403], [68.56735992, 23.38042068], [68.56819153, 23.38042068], [68.56819153, 23.38125992], [68.56764221, 23.38125992], [68.56764221, 23.38153076], [68.5654068, 23.38153076], [68.5654068, 23.38181114], [68.56375122, 23.38180351], [68.56375122, 23.3820858], [68.56346893, 23.38208008], [68.56346893, 23.38236046], [68.56318665, 23.38236046], [68.56318665, 23.38264084], [68.56291962, 23.38264084], [68.56291962, 23.38292122], [68.56263733, 23.3829174], [68.56263733, 23.38319588], [68.56236267, 23.38319016], [68.56236267, 23.38375092], [68.56208038, 23.38375092], [68.56208038, 23.38458252], [68.56180573, 23.38458252], [68.56180573, 23.3856945], [68.56153107, 23.38569069], [68.56153107, 23.38624954], [68.5595932, 23.38624954], [68.5595932, 23.38652992], [68.55902863, 23.38652992], [68.55902863, 23.3868084], [68.55874634, 23.38680649], [68.55874634, 23.38708305], [68.55847168, 23.3870697], [68.55847168, 23.38763809], [68.55819702, 23.38763809], [68.55819702, 23.38820076], [68.5579071, 23.38820076], [68.5579071, 23.38874817], [68.55764008, 23.38874817], [68.55764008, 23.38902855], [68.55735779, 23.38902855], [68.55735779, 23.38958359], [68.55708313, 23.38958168], [68.55708313, 23.39264107], [68.55735779, 23.39264107], [68.55735779, 23.39375114], [68.55764008, 23.39375114], [68.55764008, 23.39431], [68.5579071, 23.39431], [68.5579071, 23.39513969], [68.55819702, 23.39513969], [68.55819702, 23.39569664], [68.55958557, 23.39569664], [68.55958557, 23.39486122], [68.55986023, 23.39486122], [68.55986023, 23.39431], [68.56014252, 23.39431], [68.56014252, 23.39375114], [68.56041718, 23.39375114], [68.56041718, 23.39319992], [68.56069183, 23.39319992], [68.56069183, 23.39291954], [68.56096649, 23.39291954], [68.56096649, 23.39236069], [68.56124878, 23.39236069], [68.56124878, 23.39180946], [68.56153107, 23.39180946], [68.56153107, 23.39125061], [68.56181335, 23.39125061], [68.56180573, 23.39097023], [68.56291962, 23.39097023], [68.56291962, 23.3915329], [68.56263733, 23.39152718], [68.56263733, 23.39208221], [68.56236267, 23.39208031], [68.56236267, 23.39264107], [68.56208038, 23.39264107], [68.56208038, 23.39319992], [68.56181335, 23.39319992], [68.56181335, 23.39375114], [68.56153107, 23.39375114], [68.56153107, 23.39431], [68.56124878, 23.39431], [68.56124878, 23.39486122], [68.56181335, 23.39486122], [68.56180573, 23.39458466], [68.56263733, 23.39458466], [68.56263733, 23.39430618], [68.56318665, 23.39431], [68.56318665, 23.39375114], [68.56375122, 23.39374924], [68.56375122, 23.39680672], [68.56402588, 23.39680672], [68.56402588, 23.39847183], [68.56430817, 23.39846992], [68.56430817, 23.40014076], [68.56458282, 23.40014076], [68.56458282, 23.40152931], [68.56430817, 23.40152931], [68.56430817, 23.4018116], [68.56402588, 23.4018116], [68.56402588, 23.40236092], [68.56375122, 23.40236092], [68.56375122, 23.40292168], [68.56346893, 23.40291595], [68.56346893, 23.4034729], [68.56318665, 23.40346909], [68.56318665, 23.40403175], [68.56291962, 23.40402794], [68.56291962, 23.40458107], [68.56263733, 23.40458107], [68.56263733, 23.40681076], [68.56236267, 23.40680313], [68.56236267, 23.41124916], [68.56208038, 23.41123962], [68.56208038, 23.41374969], [68.56180573, 23.41374969], [68.56180573, 23.41458321], [68.56153107, 23.41457748], [68.56153107, 23.41570282], [68.56124878, 23.41570282], [68.56124878, 23.41653252], [68.56096649, 23.41653252], [68.56096649, 23.41764259], [68.56069183, 23.41764259], [68.56069183, 23.41875267], [68.56041718, 23.41875267], [68.56041718, 23.41930962], [68.56014252, 23.4193058], [68.56014252, 23.41958237], [68.55958557, 23.41958237], [68.5595932, 23.41986084], [68.55930328, 23.41986084], [68.55930328, 23.42014122], [68.55874634, 23.42014122], [68.55874634, 23.42043114], [68.55652618, 23.42043114], [68.55652618, 23.42014122], [68.55513763, 23.42014122], [68.55513763, 23.41958046], [68.55541992, 23.41958237], [68.55541992, 23.41902733], [68.55568695, 23.41903114], [68.55568695, 23.41819191], [68.55541992, 23.41819382], [68.55541992, 23.41763878], [68.55513763, 23.41764259], [68.55513763, 23.41708183], [68.55486298, 23.41708374], [68.55486298, 23.41680527], [68.55458069, 23.4168129], [68.55458069, 23.41653252], [68.55401611, 23.41653252], [68.55401611, 23.41625023], [68.55319214, 23.41625023], [68.55319214, 23.41541862], [68.55264282, 23.41541862], [68.55264282, 23.41513824], [68.55208588, 23.41513824], [68.55208588, 23.41541862], [68.5510025, 23.41541862], [68.55097961, 23.41570282], [68.55041504, 23.41569519], [68.55041504, 23.41597176], [68.54846954, 23.41597176], [68.54846954, 23.41625023], [68.54792023, 23.41625023], [68.54792023, 23.41653252], [68.54736328, 23.41653252], [68.54736328, 23.4168129], [68.54708099, 23.4168129], [68.54708099, 23.41736984], [68.54651642, 23.41736984], [68.54651642, 23.41764259], [68.5459671, 23.41764259], [68.5459671, 23.41792107], [68.54569244, 23.41792107], [68.54569244, 23.41930962], [68.54541779, 23.4193058], [68.54541779, 23.41958237], [68.54485321, 23.41958046], [68.54485321, 23.42014122], [68.54402924, 23.42014122], [68.54402924, 23.42043114], [68.54374695, 23.42041588], [68.54374695, 23.42069244], [68.54430389, 23.42069244], [68.54430389, 23.42041588], [68.54486084, 23.42041588], [68.54486084, 23.42097473], [68.5451355, 23.42097473], [68.5451355, 23.42124939], [68.54541779, 23.42124939], [68.54541779, 23.42097092], [68.54569244, 23.42097473], [68.54569244, 23.42069244], [68.54597473, 23.42069244], [68.54597473, 23.42041588], [68.54651642, 23.42043114], [68.54651642, 23.42014122], [68.54708099, 23.42014122], [68.54708099, 23.41986084], [68.54792023, 23.41986084], [68.54792023, 23.42014122], [68.54819489, 23.42013931], [68.54819489, 23.42069244], [68.54846954, 23.42069054], [68.54846954, 23.42152977], [68.54875183, 23.42152977], [68.54875183, 23.42124939], [68.54958344, 23.42124939], [68.54958344, 23.42236137], [68.55042267, 23.42235947], [68.55042267, 23.42292023], [68.55014038, 23.42291641], [68.55014038, 23.42319679], [68.54875183, 23.42319679], [68.54875183, 23.42347145], [68.54846954, 23.42346954], [68.54846954, 23.42374992], [68.54763794, 23.42374992], [68.54763794, 23.42346954], [68.54708099, 23.42347145], [68.54708099, 23.42208481], [68.54680634, 23.42208481], [68.54680634, 23.42180634], [68.54624939, 23.42180634], [68.54624939, 23.42208481], [68.54569244, 23.42208481], [68.54569244, 23.42236137], [68.54374695, 23.42235947], [68.54374695, 23.42292023], [68.54347229, 23.42291641], [68.54347229, 23.42347145], [68.54264069, 23.42347145], [68.54264069, 23.42319679], [68.54208374, 23.42319679], [68.54208374, 23.42291641], [68.54180908, 23.42292023], [68.54180908, 23.42263985], [68.54096985, 23.42263985], [68.54096985, 23.42235947], [68.5404129, 23.42236137], [68.5404129, 23.42208481], [68.5395813, 23.42208481], [68.5395813, 23.42180634], [68.5376358, 23.42181015], [68.5376358, 23.42152977], [68.53679657, 23.42152977], [68.53679657, 23.42124939], [68.53569794, 23.42124939], [68.53569794, 23.42152977], [68.5359726, 23.42152786], [68.5359726, 23.42208481], [68.53624725, 23.42208481], [68.53624725, 23.42347145], [68.53430939, 23.42346954], [68.53430176, 23.42374992], [68.5340271, 23.42374992], [68.5340271, 23.42514038], [68.53457642, 23.42514038], [68.53457642, 23.42542076], [68.5348587, 23.42541885], [68.5348587, 23.42847252], [68.53457642, 23.42847061], [68.53457642, 23.42874908], [68.53430939, 23.42874908], [68.53430176, 23.43042183], [68.5340271, 23.43041611], [68.5340271, 23.43069458], [68.53375244, 23.43069458], [68.53375244, 23.43097115], [68.53347015, 23.43097115], [68.53347015, 23.43124962], [68.5331955, 23.43124962], [68.5331955, 23.43180466], [68.53291321, 23.43180275], [68.53291321, 23.43237114], [68.53263855, 23.43236351], [68.53263855, 23.43347168], [68.5331955, 23.43347168], [68.5331955, 23.43291664], [68.53347015, 23.43292046], [68.53347015, 23.43208122], [68.53375244, 23.43208122], [68.53375244, 23.43152809], [68.5340271, 23.43153191], [68.5340271, 23.43097115], [68.53430176, 23.43097115], [68.53430176, 23.43069458], [68.53458405, 23.43069458], [68.53458405, 23.43041611], [68.5348587, 23.43042183], [68.5348587, 23.43013954], [68.53514099, 23.43013954], [68.53514099, 23.42985916], [68.53542328, 23.42985916], [68.53541565, 23.4295826], [68.53569794, 23.4295826], [68.53569794, 23.42930603], [68.53598022, 23.42931175], [68.53598022, 23.42902946], [68.53624725, 23.42902946], [68.53624725, 23.42764091], [68.53736115, 23.42764091], [68.53736115, 23.42736053], [68.53708649, 23.42736053], [68.53708649, 23.42681122], [68.53679657, 23.42681122], [68.53679657, 23.42653084], [68.53708649, 23.42653084], [68.53708649, 23.42542076], [68.53736115, 23.42542076], [68.53736115, 23.42486], [68.5376358, 23.42486191], [68.5376358, 23.42458344], [68.53791809, 23.42458344], [68.53791809, 23.42430687], [68.53930664, 23.42430687], [68.53930664, 23.42458344], [68.54070282, 23.42457962], [68.54070282, 23.42514038], [68.54096985, 23.42513847], [68.54096985, 23.4256897], [68.54069519, 23.42569542], [68.54069519, 23.42597198], [68.5404129, 23.42597198], [68.5404129, 23.42625046], [68.54013824, 23.42624092], [68.54013824, 23.42681122], [68.53986359, 23.4268055], [68.53986359, 23.42708397], [68.5395813, 23.42707825], [68.5395813, 23.42736053], [68.53930664, 23.42736053], [68.53930664, 23.42764091], [68.53901672, 23.42764091], [68.53901672, 23.42791939], [68.53874969, 23.42791748], [68.53874969, 23.42819405], [68.53848267, 23.42818832], [68.53848267, 23.42874908], [68.53819275, 23.42874908], [68.53819275, 23.42902946], [68.53791809, 23.42902946], [68.53791809, 23.42931175], [68.5376358, 23.42930603], [68.5376358, 23.4295826], [68.53736115, 23.42958069], [68.53736115, 23.42985916], [68.53708649, 23.42985916], [68.53708649, 23.43013954], [68.53679657, 23.43013954], [68.53679657, 23.43042183], [68.53652954, 23.43041611], [68.53652954, 23.43069458], [68.53624725, 23.43069458], [68.53624725, 23.43097115], [68.53569794, 23.43097115], [68.53569794, 23.43124962], [68.53541565, 23.43124962], [68.53541565, 23.43180466], [68.53514099, 23.43180275], [68.53514099, 23.43264008], [68.5348587, 23.43264008], [68.5348587, 23.43320084], [68.53457642, 23.43320084], [68.53457642, 23.43375015], [68.53514099, 23.43375015], [68.53514099, 23.43486023], [68.5348587, 23.43486023], [68.5348587, 23.43541718], [68.53458405, 23.43541718], [68.53458405, 23.43569565], [68.53430939, 23.43568993], [68.53430176, 23.43625069], [68.5340271, 23.43625069], [68.5340271, 23.43653107], [68.53375244, 23.43652725], [68.53375244, 23.4370842], [68.53347015, 23.43708038], [68.53347015, 23.43764114], [68.5331955, 23.43763924], [68.5331955, 23.43819427], [68.53291321, 23.43819427], [68.53291321, 23.43847275], [68.53263855, 23.43847084], [68.53263855, 23.43902969], [68.53236389, 23.43902779], [68.53236389, 23.43958282], [68.5320816, 23.43958282], [68.5320816, 23.44097137], [68.53180695, 23.44097137], [68.53180695, 23.44236183], [68.53151703, 23.44235992], [68.53151703, 23.44292259], [68.53125, 23.44292259], [68.53125, 23.44320107], [68.53097534, 23.44319534], [68.53097534, 23.44347191], [68.53069305, 23.44347191], [68.53069305, 23.44403267], [68.5304184, 23.44403267], [68.5304184, 23.44486046], [68.53013611, 23.44486046], [68.53013611, 23.44597435], [68.52984619, 23.44597054], [68.52984619, 23.44680977], [68.53069305, 23.44680405], [68.53069305, 23.44708252], [68.53097534, 23.44708252], [68.53097534, 23.4473629], [68.53125, 23.44734955], [68.53125, 23.44791985], [68.53097534, 23.44791412], [68.53097534, 23.4481926], [68.5304184, 23.4481926], [68.5304184, 23.44847488], [68.52958679, 23.44847107], [68.52958679, 23.44874954], [68.52929688, 23.44874954], [68.52929688, 23.4493103], [68.52902985, 23.44930649], [68.52902985, 23.44986153], [68.52874756, 23.44985962], [68.52874756, 23.45014], [68.5284729, 23.45013809], [68.5284729, 23.45041656], [68.52819824, 23.45041084], [68.52819824, 23.45070076], [68.52791595, 23.45069695], [68.52791595, 23.4509716], [68.5276413, 23.4509697], [68.5276413, 23.45125008], [68.52735901, 23.45125008], [68.52735901, 23.45153046], [68.52707672, 23.45153046], [68.52707672, 23.45181084], [68.52680206, 23.45180511], [68.52680206, 23.45208359], [68.5265274, 23.45208359], [68.5265274, 23.45236206], [68.52625275, 23.45236015], [68.52625275, 23.45292091], [68.52597046, 23.45292091], [68.52597046, 23.45431137], [68.5256958, 23.45431137], [68.5256958, 23.45542145], [68.52541351, 23.45541763], [68.52541351, 23.4556942], [68.52513885, 23.4556942], [68.52513885, 23.45597267], [68.52485657, 23.45597076], [68.52485657, 23.45624924], [68.52458191, 23.45624924], [68.52458191, 23.45654106], [68.52430725, 23.45654106], [68.52430725, 23.4568119], [68.52402496, 23.45680618], [68.52402496, 23.45708275], [68.52375031, 23.45708084], [68.52375031, 23.45735931], [68.52347565, 23.45735931], [68.52348328, 23.45763969], [68.52319336, 23.45763969], [68.52319336, 23.45819473], [68.5229187, 23.45819473], [68.5229187, 23.4584713], [68.52263641, 23.45846939], [68.52263641, 23.45874977], [68.52236176, 23.45874977], [68.52236176, 23.45958138], [68.5220871, 23.45957947], [68.5220871, 23.46014023], [68.52179718, 23.46014023], [68.52179718, 23.46070099], [68.52153015, 23.46070099], [68.52153015, 23.46125031], [68.52124786, 23.46125031], [68.52124786, 23.46181107], [68.52097321, 23.46181107], [68.52097321, 23.46264076], [68.52179718, 23.46264076], [68.52179718, 23.46375084], [68.52153015, 23.46375084], [68.52153015, 23.46403122], [68.52124786, 23.4640274], [68.52124786, 23.46458244], [68.52097321, 23.46458054], [68.52097321, 23.46541977], [68.52124786, 23.46541977], [68.52124786, 23.46624947], [68.52153015, 23.46624947], [68.52153015, 23.46680832], [68.52180481, 23.46680641], [68.52180481, 23.46736145], [68.52068329, 23.46735954], [68.52068329, 23.46763992], [68.51957703, 23.46763992], [68.51957703, 23.46820068], [68.51930237, 23.46820068], [68.51930237, 23.46902847], [68.51902771, 23.46902847], [68.51902771, 23.47042274], [68.51930237, 23.47041702], [68.51930237, 23.47097015], [68.51902771, 23.47097015], [68.51902771, 23.47125053], [68.51791382, 23.47125053], [68.51791382, 23.4715271], [68.51763916, 23.47151947], [68.51763916, 23.47236061], [68.51735687, 23.47236061], [68.51735687, 23.47291946], [68.51708221, 23.47291756], [68.51708221, 23.4734745], [68.51680756, 23.47347069], [68.51680756, 23.47402954], [68.51652527, 23.47402763], [68.51652527, 23.47458458], [68.51625061, 23.47458076], [68.51625061, 23.47513962], [68.51597595, 23.47513962], [68.51597595, 23.47542], [68.51486969, 23.47542], [68.51486969, 23.47513962], [68.51457977, 23.47513962], [68.51457977, 23.47486115], [68.51430511, 23.47486115], [68.51430511, 23.47458458], [68.51403046, 23.47458458], [68.51403046, 23.47374916], [68.51457977, 23.47375107], [68.51457977, 23.47402954], [68.51568604, 23.47402954], [68.51568604, 23.47347069], [68.51597595, 23.4734745], [68.51597595, 23.47291756], [68.51625061, 23.47291946], [68.51625061, 23.47236061], [68.51597595, 23.47236061], [68.51597595, 23.47125053], [68.51568604, 23.47125053], [68.51568604, 23.47014046], [68.51541901, 23.47014046], [68.51541901, 23.46847916], [68.51457977, 23.46847916], [68.51457977, 23.46874809], [68.51431274, 23.46874809], [68.51431274, 23.46931267], [68.51403046, 23.46930504], [68.51403046, 23.46986008], [68.51374817, 23.46986008], [68.51374817, 23.47042274], [68.51347351, 23.47041702], [68.51347351, 23.47097015], [68.51319122, 23.47097015], [68.51319122, 23.47125053], [68.51291656, 23.47125053], [68.51291656, 23.47180939], [68.51235962, 23.47180939], [68.51235962, 23.47125053], [68.51208496, 23.47125053], [68.51208496, 23.47013855], [68.51235962, 23.47014046], [68.51235962, 23.4679184], [68.51264191, 23.4679184], [68.51264191, 23.46735954], [68.51319122, 23.46736145], [68.51319122, 23.46708298], [68.51403046, 23.46708298], [68.51403046, 23.46680641], [68.51568604, 23.46680832], [68.51568604, 23.46763992], [68.51597595, 23.46763992], [68.51597595, 23.46820068], [68.51735687, 23.46820068], [68.51735687, 23.46652985], [68.51708221, 23.46652985], [68.51708221, 23.46624947], [68.51735687, 23.46624947], [68.51735687, 23.46486092], [68.51763916, 23.46486092], [68.51763916, 23.46347046], [68.51791382, 23.46347237], [68.51791382, 23.46291733], [68.51819611, 23.46292114], [68.51819611, 23.46235085], [68.51847076, 23.46236038], [68.51847076, 23.46208572], [68.51875305, 23.46208572], [68.51875305, 23.46152687], [68.51902771, 23.46153069], [68.51902771, 23.46125031], [68.51930237, 23.46125031], [68.51930237, 23.46070099], [68.51957703, 23.46070099], [68.51957703, 23.45929146], [68.51902771, 23.45930481], [68.51902771, 23.45958138], [68.51875305, 23.45957947], [68.51875305, 23.46014023], [68.51847076, 23.46014023], [68.51847076, 23.46070099], [68.51819611, 23.46070099], [68.51819611, 23.46125031], [68.51790619, 23.46125031], [68.51790619, 23.46181107], [68.51763916, 23.46180344], [68.51763916, 23.46208572], [68.51735687, 23.46208], [68.51735687, 23.46292114], [68.51708221, 23.46292114], [68.51708221, 23.46375084], [68.51652527, 23.46375084], [68.51652527, 23.46347237], [68.51625061, 23.46347237], [68.51625061, 23.46236038], [68.51597595, 23.46236038], [68.51597595, 23.46180344], [68.51625061, 23.46181107], [68.51625061, 23.46125031], [68.5165329, 23.46125031], [68.51652527, 23.46013832], [68.51680756, 23.46014023], [68.51680756, 23.45846939], [68.51708221, 23.4584713], [68.51708221, 23.45763969], [68.51735687, 23.45763969], [68.5173645, 23.45726967], [68.5173645, 23.45708275], [68.51763916, 23.45708275], [68.51763916, 23.45680618], [68.51790619, 23.4568119], [68.51790619, 23.45624924], [68.51819611, 23.45624924], [68.51819611, 23.45597076], [68.51847076, 23.45597267], [68.51847076, 23.45541573], [68.51875305, 23.45542145], [68.51875305, 23.45513916], [68.51930237, 23.45513916], [68.51930237, 23.45486069], [68.51957703, 23.45486069], [68.51957703, 23.45458031], [68.5201416, 23.45458412], [68.5201416, 23.45430565], [68.52124786, 23.45431137], [68.52124786, 23.45486069], [68.52153015, 23.45486069], [68.52153015, 23.45542145], [68.52180481, 23.45541573], [68.52180481, 23.45597267], [68.52153015, 23.45597076], [68.52153015, 23.45654106], [68.52124786, 23.45652771], [68.52124786, 23.45708275], [68.52097321, 23.45708275], [68.52097321, 23.45930481], [68.52153015, 23.45930481], [68.52153015, 23.4584713], [68.52180481, 23.4584713], [68.52180481, 23.45819473], [68.5220871, 23.45819473], [68.5220871, 23.45791626], [68.52236176, 23.45792007], [68.52236176, 23.45735931], [68.52263641, 23.45735931], [68.52263641, 23.45708084], [68.5229187, 23.45708275], [68.5229187, 23.45680618], [68.52348328, 23.4568119], [68.52348328, 23.45624924], [68.52375031, 23.45624924], [68.52375031, 23.45597076], [68.52402496, 23.45597267], [68.52402496, 23.4556942], [68.52430725, 23.4556942], [68.52430725, 23.45541573], [68.52485657, 23.45542145], [68.52485657, 23.45486069], [68.52458191, 23.45486069], [68.52458191, 23.45431137], [68.52430725, 23.45431137], [68.52430725, 23.45375061], [68.52402496, 23.45375061], [68.52402496, 23.45125008], [68.52430725, 23.45125008], [68.52430725, 23.45041084], [68.52458191, 23.45041656], [68.52458191, 23.44958305], [68.5248642, 23.44958305], [68.5248642, 23.44847488], [68.52458191, 23.44847488], [68.52458191, 23.44791412], [68.52430725, 23.44791985], [68.52430725, 23.44763947], [68.52402496, 23.44763947], [68.52402496, 23.4473629], [68.52375031, 23.4473629], [68.52375031, 23.44708252], [68.52347565, 23.44708252], [68.52347565, 23.44680405], [68.52319336, 23.44680977], [68.52319336, 23.44652939], [68.5220871, 23.44652939], [68.5220871, 23.44680977], [68.52180481, 23.44680405], [68.52180481, 23.44708252], [68.52153015, 23.44708252], [68.52153015, 23.4473629], [68.52124786, 23.44734955], [68.52124786, 23.44763947], [68.52097321, 23.44763947], [68.52097321, 23.4481926], [68.52069092, 23.4481926], [68.52069092, 23.44847488], [68.52097321, 23.44847107], [68.52097321, 23.44874954], [68.52124786, 23.44874954], [68.52124786, 23.44902992], [68.52153015, 23.44902802], [68.52153015, 23.44930077], [68.52180481, 23.44930649], [68.52180481, 23.44958305], [68.51958466, 23.44958305], [68.51958466, 23.44986153], [68.51930237, 23.44985962], [68.51930237, 23.45014], [68.51875305, 23.45013809], [68.51875305, 23.45041656], [68.51847076, 23.45041084], [68.51847076, 23.45070076], [68.51875305, 23.45069695], [68.51875305, 23.4509716], [68.51902771, 23.4509716], [68.51902771, 23.45069695], [68.51930237, 23.45070076], [68.51930237, 23.45041084], [68.51985931, 23.45041656], [68.51985931, 23.45013809], [68.52041626, 23.45014], [68.52041626, 23.44985962], [68.52068329, 23.44985962], [68.52068329, 23.45014], [68.52097321, 23.45014], [68.52097321, 23.45070076], [68.52069092, 23.45069695], [68.52069092, 23.4509716], [68.5201416, 23.4509716], [68.5201416, 23.45208359], [68.51985931, 23.45208359], [68.51985931, 23.45236206], [68.51958466, 23.45236206], [68.51958466, 23.45208359], [68.51930237, 23.45208359], [68.51930237, 23.45180511], [68.51847076, 23.45181084], [68.51847076, 23.45236015], [68.51902771, 23.45236015], [68.51902771, 23.45264053], [68.51930237, 23.45263863], [68.51930237, 23.45319366], [68.51902771, 23.45318985], [68.51902771, 23.45347977], [68.51875305, 23.45347977], [68.51875305, 23.45375061], [68.51819611, 23.45375061], [68.51819611, 23.45402908], [68.51790619, 23.45402908], [68.51790619, 23.45431137], [68.5173645, 23.45430565], [68.5173645, 23.45458412], [68.51708221, 23.45458031], [68.51706696, 23.45486069], [68.51680756, 23.45486069], [68.51680756, 23.45513916], [68.51652527, 23.45513916], [68.51652527, 23.4556942], [68.51625061, 23.45568848], [68.51625061, 23.45624924], [68.51597595, 23.45624924], [68.51597595, 23.45682716], [68.51568604, 23.4568119], [68.51568604, 23.45735931], [68.51541901, 23.45735931], [68.51541901, 23.45792007], [68.51457977, 23.45792007], [68.51457977, 23.45735931], [68.51430511, 23.45735931], [68.51430511, 23.45652771], [68.51403046, 23.45654106], [68.51403046, 23.45640182], [68.51403046, 23.45541763], [68.51374817, 23.45542145], [68.51374817, 23.45431137], [68.51346588, 23.45431137], [68.51346588, 23.45347977], [68.51319122, 23.45347977], [68.51319122, 23.45292091], [68.51291656, 23.4529171], [68.51291656, 23.45319366], [68.51264191, 23.45318985], [68.51264191, 23.45347977], [68.51235962, 23.45347977], [68.51235962, 23.45375061], [68.51207733, 23.45375061], [68.51207733, 23.45402908], [68.5118103, 23.45402908], [68.5118103, 23.45431137], [68.51152802, 23.45430565], [68.51152802, 23.45458412], [68.51180267, 23.45458412], [68.51180267, 23.45486069], [68.51207733, 23.45486069], [68.51207733, 23.45513916], [68.51235962, 23.45513916], [68.51235962, 23.45597267], [68.51264191, 23.45597267], [68.51264191, 23.45635986], [68.51264191, 23.4568119], [68.51291656, 23.45680618], [68.51291656, 23.45708275], [68.51319122, 23.45708084], [68.51319122, 23.45735931], [68.51291656, 23.45735931], [68.51291656, 23.45763969], [68.51264191, 23.45763969], [68.51264191, 23.45735931], [68.51235962, 23.45735931], [68.51235962, 23.45708084], [68.51208496, 23.45708275], [68.51208496, 23.45680618], [68.5118103, 23.4568119], [68.5118103, 23.45667267], [68.51180267, 23.45597267], [68.51152802, 23.45597267], [68.51152802, 23.45541763], [68.51069641, 23.45542145], [68.51069641, 23.45513916], [68.51041412, 23.45513916], [68.51041412, 23.4556942], [68.51013947, 23.45568848], [68.51013947, 23.4568119], [68.51041412, 23.45680618], [68.51041412, 23.45717049], [68.51040649, 23.45735931], [68.51069641, 23.45735931], [68.51069641, 23.45819473], [68.51040649, 23.45819283], [68.51040649, 23.45874977], [68.50846863, 23.45874977], [68.50846863, 23.45930481], [68.50819397, 23.45930481], [68.50819397, 23.45986366], [68.50791931, 23.45985985], [68.50791931, 23.46042061], [68.50763702, 23.46041679], [68.50763702, 23.46097374], [68.50708008, 23.46096992], [68.50708008, 23.46153069], [68.50680542, 23.46152687], [68.50680542, 23.46208572], [68.50653076, 23.46208], [68.50653076, 23.46264076], [68.50624847, 23.46263885], [68.50624847, 23.4631958], [68.50596619, 23.46319008], [68.50596619, 23.46375084], [68.50541687, 23.46375084], [68.50541687, 23.46403122], [68.50485992, 23.46403122], [68.50485992, 23.46430969], [68.50430298, 23.46430779], [68.50430298, 23.46458244], [68.50374603, 23.46458054], [68.50374603, 23.46486092], [68.50319672, 23.46486092], [68.50319672, 23.46513939], [68.50263977, 23.46513939], [68.50263977, 23.46541977], [68.50235748, 23.46541977], [68.50235748, 23.46624947], [68.50263977, 23.46624947], [68.50263977, 23.46652985], [68.5029068, 23.46652985], [68.5029068, 23.46680832], [68.50319672, 23.46680641], [68.50319672, 23.46708298], [68.50347137, 23.46708298], [68.50347137, 23.46736145], [68.50402832, 23.46735954], [68.50402832, 23.46763992], [68.50485992, 23.46763992], [68.50485992, 23.46735954], [68.50514221, 23.46736145], [68.50514221, 23.46708298], [68.50541687, 23.46708298], [68.50541687, 23.46652985], [68.50567627, 23.46652985], [68.50567627, 23.46624947], [68.50596619, 23.46624947], [68.50596619, 23.46458054], [68.50624847, 23.46458244], [68.50624847, 23.46430779], [68.50653076, 23.46430969], [68.50653076, 23.46375084], [68.50681305, 23.46375084], [68.50680542, 23.46347237], [68.50708008, 23.46347237], [68.50708008, 23.46291733], [68.50736237, 23.46292114], [68.50736237, 23.46264076], [68.50846863, 23.46264076], [68.50846863, 23.46292114], [68.50902557, 23.46291733], [68.50902557, 23.4631958], [68.51041412, 23.4631958], [68.51041412, 23.46347237], [68.51152802, 23.46347046], [68.51152802, 23.46430969], [68.51180267, 23.46430779], [68.51180267, 23.4659729], [68.51208496, 23.4659729], [68.51208496, 23.46708298], [68.51152802, 23.46708298], [68.51152802, 23.46736145], [68.51125336, 23.46735954], [68.51125336, 23.46763992], [68.51097107, 23.46763992], [68.51097107, 23.4679184], [68.51040649, 23.4679184], [68.51040649, 23.46820068], [68.51013947, 23.46820068], [68.51013947, 23.46847916], [68.50985718, 23.46847916], [68.50985718, 23.46874809], [68.50958252, 23.46874809], [68.50958252, 23.46902847], [68.50930786, 23.46902847], [68.50930786, 23.46958351], [68.50902557, 23.46958351], [68.50902557, 23.46986008], [68.50985718, 23.46986008], [68.50985718, 23.47014046], [68.51013947, 23.47014046], [68.51013947, 23.47042274], [68.51041412, 23.47041702], [68.51041412, 23.47069359], [68.51069641, 23.47069359], [68.51069641, 23.4715271], [68.51040649, 23.47151947], [68.51040649, 23.47236061], [68.50985718, 23.47236061], [68.50985718, 23.4726429], [68.50958252, 23.4726429], [68.50958252, 23.47291946], [68.51152802, 23.47291946], [68.51152802, 23.47375107], [68.51097107, 23.47375107], [68.51097107, 23.47402954], [68.51040649, 23.47402954], [68.51040649, 23.47430992], [68.50958252, 23.4743042], [68.50958252, 23.47458458], [68.50846863, 23.47458458], [68.50846863, 23.4743042], [68.50791931, 23.47430992], [68.50791931, 23.47402954], [68.50763702, 23.47402954], [68.50763702, 23.47347069], [68.50791931, 23.4734745], [68.50791931, 23.47291756], [68.50763702, 23.47291946], [68.50763702, 23.47236061], [68.50736237, 23.47236061], [68.50736237, 23.47180939], [68.50708008, 23.47180939], [68.50708008, 23.47151947], [68.5045929, 23.47151947], [68.5045929, 23.47180939], [68.50402832, 23.47180557], [68.50402832, 23.47208214], [68.50374603, 23.47208023], [68.50374603, 23.47236061], [68.50347137, 23.47236061], [68.50347137, 23.47291946], [68.50291443, 23.47291756], [68.50291443, 23.47319221], [68.50263977, 23.47319221], [68.50263977, 23.4734745], [68.50208282, 23.47347069], [68.50208282, 23.47375107], [68.50180817, 23.47375107], [68.50180817, 23.47430992], [68.50152588, 23.4743042], [68.50152588, 23.47458458], [68.50125122, 23.47458076], [68.50125122, 23.47513962], [68.50096893, 23.47513962], [68.50096893, 23.47542], [68.50069427, 23.47541428], [68.50069427, 23.47597313], [68.50041962, 23.47597122], [68.50041962, 23.47653008], [68.50068665, 23.47653008], [68.50068665, 23.47903061], [68.50013733, 23.4790287], [68.50013733, 23.47958374], [68.50041962, 23.47957993], [68.50041962, 23.48014069], [68.50069427, 23.48013878], [68.50069427, 23.48069382], [68.50096893, 23.4806881], [68.50096893, 23.48181152], [68.50068665, 23.48181152], [68.50068665, 23.4829216], [68.50041962, 23.48291588], [68.50041962, 23.48347282], [68.50013733, 23.48345757], [68.50013733, 23.48431015], [68.4998703, 23.48431015], [68.4998703, 23.48542023], [68.50013733, 23.48541641], [68.50013733, 23.48597145], [68.50041962, 23.48596954], [68.50041962, 23.48624992], [68.50068665, 23.48624992], [68.50068665, 23.48681068], [68.50096893, 23.48680305], [68.50096893, 23.48708534], [68.50069427, 23.48708534], [68.50069427, 23.48819542], [68.50096893, 23.48819542], [68.50096893, 23.48847389], [68.50125122, 23.48847008], [68.50125122, 23.48903084], [68.50152588, 23.48903084], [68.50152588, 23.49014091], [68.50180817, 23.49013901], [68.50180817, 23.49069595], [68.50208282, 23.49069023], [68.50208282, 23.49125099], [68.50235748, 23.49125099], [68.50235748, 23.49180984], [68.50319672, 23.49180984], [68.50319672, 23.49152946], [68.50347137, 23.49152946], [68.50347137, 23.49125099], [68.50374603, 23.49125099], [68.50374603, 23.49069023], [68.50402832, 23.49069595], [68.50402832, 23.49041748], [68.50430298, 23.49041939], [68.50430298, 23.49014091], [68.5045929, 23.49014091], [68.5045929, 23.48986053], [68.50485992, 23.48986053], [68.50485992, 23.48958969], [68.50681305, 23.48958969], [68.50681305, 23.48931122], [68.50818634, 23.48931122], [68.50818634, 23.48903084], [68.50985718, 23.48903084], [68.50985718, 23.48847008], [68.51013947, 23.48847389], [68.51013947, 23.48791695], [68.51040649, 23.48792076], [68.51040649, 23.48736], [68.51069641, 23.48736382], [68.51069641, 23.48708534], [68.51097107, 23.48708534], [68.51097107, 23.48680305], [68.51125336, 23.48681068], [68.51125336, 23.48624992], [68.51152802, 23.48624992], [68.51152802, 23.48596954], [68.51180267, 23.48597145], [68.51180267, 23.48569489], [68.51208496, 23.48569489], [68.51208496, 23.48541641], [68.51264191, 23.48542023], [68.51264191, 23.48513985], [68.51291656, 23.48513985], [68.51291656, 23.48485947], [68.51457977, 23.48485947], [68.51457977, 23.48513985], [68.51541901, 23.48513985], [68.51541901, 23.48542023], [68.51597595, 23.48541641], [68.51597595, 23.48569489], [68.51652527, 23.48569489], [68.51652527, 23.48597145], [68.51708221, 23.48596954], [68.51708221, 23.48624992], [68.51735687, 23.48624992], [68.51735687, 23.48681068], [68.51763916, 23.48680305], [68.51763916, 23.48736382], [68.51790619, 23.48736], [68.51790619, 23.48792076], [68.51819611, 23.48791695], [68.51819611, 23.48819542], [68.51875305, 23.48819542], [68.51875305, 23.48847389], [68.51902771, 23.48847008], [68.51902771, 23.48903084], [68.51875305, 23.48903084], [68.51875305, 23.48958969], [68.51680756, 23.48958969], [68.51680756, 23.48931122], [68.51625061, 23.48931122], [68.51625061, 23.48903084], [68.51568604, 23.48903084], [68.51568604, 23.48875046], [68.51541901, 23.48875046], [68.51541901, 23.48847008], [68.51486206, 23.48847389], [68.51486206, 23.48819542], [68.51431274, 23.4881897], [68.51430511, 23.48791695], [68.51374817, 23.48792076], [68.51374817, 23.48764038], [68.51291656, 23.48764038], [68.51291656, 23.48792076], [68.51264191, 23.48791695], [68.51264191, 23.48847389], [68.51235962, 23.48847008], [68.51235962, 23.48903084], [68.51264191, 23.48903084], [68.51264191, 23.48875046], [68.51291656, 23.48875046], [68.51291656, 23.48847008], [68.51374817, 23.48847008], [68.51374817, 23.48903084], [68.51346588, 23.48903084], [68.51346588, 23.48931122], [68.51319122, 23.48931122], [68.51319122, 23.48958969], [68.51291656, 23.48958969], [68.51291656, 23.49125099], [68.51319122, 23.49125099], [68.51319122, 23.49180984], [68.51403046, 23.49180984], [68.51403046, 23.49152946], [68.51431274, 23.49152946], [68.51431274, 23.49125099], [68.51486969, 23.49125099], [68.51486969, 23.49180984], [68.51541901, 23.49180984], [68.51541901, 23.49236107], [68.51513672, 23.49236107], [68.51513672, 23.49264908], [68.51457977, 23.49264908], [68.51457977, 23.49291992], [68.51208496, 23.49291611], [68.51208496, 23.49319458], [68.51152802, 23.49319458], [68.51152802, 23.49347305], [68.51069641, 23.49347115], [68.51069641, 23.49374962], [68.50818634, 23.49374962], [68.50818634, 23.49402809], [68.50485992, 23.49402809], [68.50485992, 23.49374962], [68.50263977, 23.49374962], [68.50263977, 23.49402809], [68.50208282, 23.49402809], [68.50208282, 23.49419975], [68.50208282, 23.49430466], [68.50180817, 23.49430466], [68.50180817, 23.49458313], [68.50125122, 23.49458313], [68.50125122, 23.49430466], [68.49986267, 23.49430466], [68.49986267, 23.49402809], [68.49903107, 23.49402809], [68.49903107, 23.49430466], [68.49930573, 23.49430466], [68.49930573, 23.4948616], [68.49958038, 23.4948597], [68.49958038, 23.49541855], [68.49986267, 23.49541664], [68.49986267, 23.49625015], [68.50013733, 23.49625015], [68.50013733, 23.49653244], [68.50041962, 23.49653244], [68.50041962, 23.49681282], [68.50068665, 23.49681282], [68.50068665, 23.49736023], [68.50041962, 23.49736023], [68.50041962, 23.4979229], [68.50125122, 23.49791718], [68.50125122, 23.49819374], [68.50208282, 23.49819374], [68.50208282, 23.49847031], [68.50235748, 23.49846077], [68.50235748, 23.49875069], [68.5029068, 23.49875069], [68.5029068, 23.49903107], [68.50347137, 23.49903107], [68.50347137, 23.49930954], [68.50375366, 23.49930573], [68.50375366, 23.49958229], [68.50402832, 23.49958229], [68.50402832, 23.50006294], [68.50402832, 23.50041962], [68.50375366, 23.5004158], [68.50375366, 23.50069237], [68.50347137, 23.50069237], [68.50347137, 23.50097466], [68.50319672, 23.50097084], [68.50319672, 23.50125122], [68.5029068, 23.50125122], [68.5029068, 23.50181007], [68.50263977, 23.50180626], [68.50263977, 23.50208473], [68.50152588, 23.50208092], [68.50152588, 23.50292015], [68.50180817, 23.50291443], [68.50180817, 23.50347137], [68.50208282, 23.50346947], [68.50208282, 23.50374985], [68.50319672, 23.50374985], [68.50319672, 23.50346947], [68.50514221, 23.50346947], [68.50514221, 23.50374985], [68.50485992, 23.50374985], [68.50485992, 23.50430679], [68.50458527, 23.50430679], [68.50458527, 23.50486183], [68.50430298, 23.50485992], [68.50430298, 23.50542068], [68.50402832, 23.50542068], [68.50402832, 23.50570107], [68.50375366, 23.50569534], [68.50375366, 23.50597191], [68.50152588, 23.50597191], [68.50152588, 23.50486183], [68.50096893, 23.50486183], [68.50096893, 23.50458336], [68.50041962, 23.50459099], [68.50041962, 23.50430107], [68.50013733, 23.50430679], [68.50013733, 23.50402832], [68.4998703, 23.50403023], [68.4998703, 23.50319099], [68.50013733, 23.50319672], [68.50013733, 23.50263977], [68.50068665, 23.50263977], [68.50068665, 23.50125122], [68.50096893, 23.50125122], [68.50096893, 23.50097084], [68.50125122, 23.50097466], [68.50125122, 23.50069237], [68.50208282, 23.50069237], [68.50208282, 23.50097466], [68.50235748, 23.50097466], [68.50235748, 23.5004158], [68.50263977, 23.50041962], [68.50263977, 23.50014114], [68.50235748, 23.50011063], [68.50235748, 23.49986076], [68.50208282, 23.49986076], [68.50208282, 23.49958038], [68.50152588, 23.49958229], [68.50152588, 23.49930573], [68.50096893, 23.49930954], [68.50096893, 23.49903107], [68.50068665, 23.49903107], [68.50068665, 23.49875069], [68.50013733, 23.49875069], [68.50013733, 23.49846077], [68.49874878, 23.49847031], [68.49874878, 23.49819374], [68.49708557, 23.49819374], [68.49708557, 23.49847031], [68.49680328, 23.49846077], [68.49680328, 23.49875069], [68.496521, 23.49875069], [68.49569702, 23.49875069], [68.49569702, 23.49903107], [68.4954071, 23.49903107], [68.4954071, 23.49930954], [68.49514008, 23.49930573], [68.49514008, 23.49958229], [68.49485779, 23.49958038], [68.49485779, 23.50014114], [68.49458313, 23.50014114], [68.49458313, 23.50041962], [68.49208069, 23.5004158], [68.49208069, 23.50097466], [68.49180603, 23.50097084], [68.49180603, 23.50263977], [68.49208069, 23.50263977], [68.49208069, 23.50319672], [68.49236298, 23.50319099], [68.49236298, 23.50374985], [68.49263763, 23.50374985], [68.49263763, 23.50403023], [68.49291992, 23.50403023], [68.49291992, 23.50374985], [68.49318695, 23.50374985], [68.49318695, 23.50319099], [68.49346924, 23.50319672], [68.49346924, 23.50291443], [68.49430847, 23.50291443], [68.49430847, 23.50319672], [68.49458313, 23.50319672], [68.49458313, 23.50430679], [68.49430847, 23.50430107], [68.49430847, 23.50653076], [68.49458313, 23.50653076], [68.49458313, 23.50736046], [68.4954071, 23.50736046], [68.4954071, 23.50707817], [68.49597168, 23.50708389], [68.49597168, 23.50680542], [68.49652863, 23.50680542], [68.49652863, 23.50708389], [68.49680328, 23.50707817], [68.49680328, 23.50791931], [68.49652863, 23.50791931], [68.49652863, 23.51042175], [68.49680328, 23.51041603], [68.49680328, 23.51097107], [68.4970932, 23.51097107], [68.4970932, 23.51153183], [68.49736023, 23.51152802], [68.49736023, 23.51208115], [68.49764252, 23.51208115], [68.49764252, 23.51264191], [68.49791718, 23.51264191], [68.49791718, 23.51320076], [68.49819183, 23.51320076], [68.49819183, 23.51375008], [68.49846649, 23.51375008], [68.49846649, 23.51431084], [68.49874878, 23.51431084], [68.49874878, 23.51486015], [68.49903107, 23.51486015], [68.49903107, 23.51514053], [68.49846649, 23.51514053], [68.49846649, 23.51486015], [68.49819183, 23.51486206], [68.49819183, 23.51458549], [68.49791718, 23.51458549], [68.49791718, 23.51486206], [68.49764252, 23.51486015], [68.49764252, 23.51514053], [68.49736023, 23.51514053], [68.49736023, 23.51542091], [68.49680328, 23.5154171], [68.49680328, 23.51569557], [68.49624634, 23.51569557], [68.49624634, 23.51597214], [68.49569702, 23.51597023], [68.49569702, 23.51625061], [68.49514008, 23.51625061], [68.49514008, 23.51653099], [68.49458313, 23.51653099], [68.49458313, 23.51764107], [68.49485779, 23.51764107], [68.49485779, 23.51930809], [68.49514008, 23.51930809], [68.49514008, 23.52152824], [68.4954071, 23.52152824], [68.4954071, 23.52375031], [68.49569702, 23.52375031], [68.49569702, 23.52486038], [68.4954071, 23.52486038], [68.4954071, 23.52514267], [68.49514008, 23.52514267], [68.49514008, 23.52542114], [68.49485779, 23.52541733], [68.49485779, 23.52597237], [68.49458313, 23.52597046], [68.49458313, 23.52625275], [68.49430847, 23.52625275], [68.49430847, 23.52680969], [68.49402618, 23.52680588], [68.49402618, 23.52708244], [68.49373627, 23.52708054], [68.49373627, 23.52736092], [68.49346924, 23.52736092], [68.49346924, 23.52763939], [68.49318695, 23.52763939], [68.49318695, 23.52791977], [68.49291992, 23.52791405], [68.49291992, 23.52819252], [68.49263763, 23.52819252], [68.49263763, 23.52847481], [68.49236298, 23.52847099], [68.49236298, 23.52902985], [68.49208069, 23.52902794], [68.49208069, 23.52958488], [68.49180603, 23.52958107], [68.49180603, 23.53013992], [68.49153137, 23.53013611], [68.49153137, 23.53097153], [68.49124908, 23.53096962], [68.49124908, 23.53153038], [68.49097443, 23.53152847], [68.49097443, 23.53208351], [68.49069977, 23.5320797], [68.49069977, 23.53264046], [68.49041748, 23.53264046], [68.49041748, 23.53375053], [68.49014282, 23.53375053], [68.49014282, 23.53513908], [68.48986053, 23.53513908], [68.48986053, 23.5359726], [68.49014282, 23.53597069], [68.49014282, 23.53624916], [68.49041748, 23.53624916], [68.49041748, 23.53652954], [68.49069977, 23.53652954], [68.49069977, 23.53681183], [68.49097443, 23.53680611], [68.49097443, 23.53708267], [68.49124908, 23.53708076], [68.49124908, 23.53735924], [68.49097443, 23.53735924], [68.49097443, 23.53763962], [68.49041748, 23.53762817], [68.49041748, 23.53792191], [68.48986053, 23.53791618], [68.48986053, 23.5395813], [68.48958588, 23.53957939], [68.48958588, 23.54042053], [68.48930359, 23.54041672], [68.48930359, 23.54097176], [68.48902893, 23.54096985], [68.48902893, 23.54125023], [68.48874664, 23.54125023], [68.48874664, 23.54153061], [68.48847198, 23.5415287], [68.48847198, 23.54208565], [68.48819733, 23.54207993], [68.48819733, 23.54264069], [68.48791504, 23.54263878], [68.48791504, 23.54319572], [68.48764038, 23.54319], [68.48764038, 23.5437603], [68.48735809, 23.5437603], [68.48735809, 23.54403114], [68.48708344, 23.54402542], [68.48708344, 23.54458427], [68.48680878, 23.54458046], [68.48680878, 23.54514122], [68.48652649, 23.54514122], [68.48652649, 23.54541969], [68.48625183, 23.54541779], [68.48625183, 23.54597282], [68.48596954, 23.54597092], [68.48596954, 23.54652977], [68.48569489, 23.54652977], [68.48569489, 23.54680634], [68.48542023, 23.54680634], [68.48542023, 23.54736137], [68.48513794, 23.54735947], [68.48513794, 23.54791832], [68.48458099, 23.54791641], [68.48458099, 23.54819489], [68.48401642, 23.54818916], [68.48401642, 23.54931259], [68.48625183, 23.54931259], [68.48625183, 23.5490284], [68.48707581, 23.5490284], [68.48707581, 23.54874992], [68.48764038, 23.54874992], [68.48764038, 23.54846954], [68.48874664, 23.54846954], [68.48874664, 23.5490284], [68.49014282, 23.5490284], [68.49014282, 23.54874992], [68.49124908, 23.54874992], [68.49124908, 23.54846954], [68.49208069, 23.54846954], [68.49208069, 23.5490284], [68.49180603, 23.5490284], [68.49180603, 23.54931259], [68.49153137, 23.54930496], [68.49153137, 23.54958344], [68.49208069, 23.54958344], [68.49208069, 23.54930496], [68.49263763, 23.54931259], [68.49263763, 23.54818916], [68.49291992, 23.54819489], [68.49291992, 23.54763985], [68.49318695, 23.54763985], [68.49318695, 23.54735947], [68.49375153, 23.54736137], [68.49375153, 23.5470829], [68.49402618, 23.5470829], [68.49402618, 23.54680634], [68.49430847, 23.54680634], [68.49430847, 23.54652977], [68.49458313, 23.54652977], [68.49458313, 23.54624939], [68.49514008, 23.54624939], [68.49514008, 23.54652977], [68.49541473, 23.54652977], [68.49541473, 23.5470829], [68.49597168, 23.5470829], [68.49597168, 23.54736137], [68.49736023, 23.54735947], [68.49736023, 23.54791832], [68.49708557, 23.54791641], [68.49708557, 23.54847145], [68.49680328, 23.54847145], [68.49680328, 23.54958344], [68.49624634, 23.54956818], [68.49624634, 23.55014038], [68.49597168, 23.55013847], [68.49597168, 23.55069351], [68.49514008, 23.55069351], [68.49514008, 23.54958344], [68.49485779, 23.54958344], [68.49485779, 23.54874992], [68.49402618, 23.54874992], [68.49402618, 23.54931259], [68.49375153, 23.54930496], [68.49375153, 23.54986191], [68.49402618, 23.54986191], [68.49402618, 23.55097008], [68.49430847, 23.55097008], [68.49430847, 23.55264282], [68.49402618, 23.55264282], [68.49402618, 23.55293083], [68.49373627, 23.55293083], [68.49373627, 23.5537529], [68.49402618, 23.5537529], [68.49402618, 23.55430984], [68.49430847, 23.55430412], [68.49430847, 23.5545826], [68.49458313, 23.55458069], [68.49458313, 23.55513954], [68.49485779, 23.55513954], [68.49485779, 23.55624962], [68.49514008, 23.55624962], [68.49514008, 23.5573616], [68.49485779, 23.5573616], [68.49485779, 23.55875015], [68.49514008, 23.55875015], [68.49514008, 23.55958366], [68.49485779, 23.55957985], [68.49485779, 23.55986023], [68.49318695, 23.55986023], [68.49318695, 23.56041908], [68.49346924, 23.56041718], [68.49346924, 23.5620842], [68.49373627, 23.56208038], [68.49373627, 23.56402969], [68.49346924, 23.56402969], [68.49346924, 23.56653023], [68.49318695, 23.56653023], [68.49318695, 23.56903076], [68.49291992, 23.56903076], [68.49291992, 23.57152939], [68.49263763, 23.57152748], [68.49263763, 23.5731945], [68.49236298, 23.57319069], [68.49236298, 23.5743084], [68.49208069, 23.57430649], [68.49208069, 23.57458305], [68.49153137, 23.57458305], [68.49153137, 23.57486153], [68.49124908, 23.57486153], [68.49124908, 23.5759716], [68.4909668, 23.5759697], [68.49097443, 23.57625008], [68.49069977, 23.57625008], [68.49069977, 23.57653236], [68.49041748, 23.57652855], [68.49041748, 23.57736015], [68.48958588, 23.57736015], [68.48958588, 23.57764053], [68.48764038, 23.57764053], [68.48764038, 23.57792282], [68.48735809, 23.5779171], [68.48735809, 23.57847023], [68.48764038, 23.57847023], [68.48764038, 23.5790329], [68.4879303, 23.5790329], [68.4879303, 23.57987022], [68.48764038, 23.57987022], [68.48764038, 23.58125114], [68.48735809, 23.58125114], [68.48735809, 23.58736038], [68.48708344, 23.58736038], [68.48708344, 23.58847237], [68.48735809, 23.58847237], [68.48735809, 23.59069443], [68.48707581, 23.59069061], [68.48707581, 23.59181023], [68.48680878, 23.59181023], [68.48680878, 23.5929203], [68.48652649, 23.59291649], [68.48652649, 23.59597206], [68.48680878, 23.59597015], [68.48680878, 23.59653091], [68.48707581, 23.59653091], [68.48707581, 23.59680939], [68.48764038, 23.59680939], [68.48764038, 23.59736061], [68.4879303, 23.59736061], [68.4879303, 23.59764099], [68.48819733, 23.59763908], [68.48819733, 23.59791756], [68.48847198, 23.59791756], [68.48847198, 23.59819412], [68.48874664, 23.59819412], [68.48874664, 23.5984726], [68.48986053, 23.59847069], [68.48986053, 23.59902954], [68.49013519, 23.59902763], [68.49013519, 23.59958267], [68.49041748, 23.59958076], [68.49041748, 23.59986115], [68.49069214, 23.59986115], [68.49069214, 23.60013962], [68.49097443, 23.60013962], [68.49097443, 23.60069466], [68.49124908, 23.60069466], [68.49124908, 23.6020298], [68.49124908, 23.60263824], [68.49153137, 23.60263824], [68.49153137, 23.60292244], [68.49180603, 23.60292244], [68.49180603, 23.60320282], [68.49208069, 23.60320282], [68.49208069, 23.60404015], [68.49236298, 23.60404015], [68.49236298, 23.60486031], [68.49263763, 23.60486031], [68.49263763, 23.60597229], [68.49291992, 23.60597038], [68.49291992, 23.60653114], [68.49318695, 23.60653114], [68.49318695, 23.60680962], [68.49375153, 23.6068058], [68.49375153, 23.60708237], [68.49430847, 23.60708046], [68.49430847, 23.60736084], [68.49458313, 23.60736084], [68.49458313, 23.60764122], [68.49485779, 23.60763931], [68.49485779, 23.60819244], [68.49458313, 23.60819054], [68.49458313, 23.60874939], [68.49346924, 23.60874939], [68.49346924, 23.60902977], [68.49236298, 23.60902786], [68.49236298, 23.60958481], [68.49208069, 23.60958481], [68.49208069, 23.61136055], [68.49208069, 23.61181068], [68.49180603, 23.61181068], [68.49180603, 23.61375046], [68.49153137, 23.61375046], [68.49153137, 23.61486053], [68.49124908, 23.61486053], [68.49124908, 23.61598015], [68.4909668, 23.61598015], [68.4909668, 23.61763954], [68.49124908, 23.61763954], [68.49124908, 23.61903954], [68.49153137, 23.61902809], [68.49153137, 23.61930466], [68.49180603, 23.61930275], [68.49180603, 23.62014008], [68.49208069, 23.62014008], [68.49208069, 23.62181091], [68.49236298, 23.62180328], [68.49236298, 23.62347221], [68.49208069, 23.62347031], [68.49208069, 23.62375069], [68.49153137, 23.62375069], [68.49153137, 23.6245842], [68.49124908, 23.62458038], [68.49124908, 23.62541962], [68.49097443, 23.62541771], [68.49097443, 23.62597275], [68.49014282, 23.62597084], [68.49014282, 23.62625122], [68.48986053, 23.62625122], [68.48986053, 23.62652969], [68.48902893, 23.62652969], [68.48902893, 23.62791824], [68.48930359, 23.62791634], [68.48930359, 23.62819481], [68.48986053, 23.62819481], [68.48986053, 23.62847137], [68.49014282, 23.62846756], [68.49014282, 23.62902832], [68.48958588, 23.62902832], [68.48958588, 23.62930489], [68.48902893, 23.62930489], [68.48902893, 23.62958336], [68.48874664, 23.62957764], [68.48874664, 23.63070107], [68.48902893, 23.63070107], [68.48902893, 23.63153267], [68.48874664, 23.63153267], [68.48874664, 23.63236046], [68.48902893, 23.63236046], [68.48902893, 23.63292122], [68.48930359, 23.6329174], [68.48930359, 23.63319206], [68.48958588, 23.63319016], [68.48958588, 23.63375282], [68.48929596, 23.63375282], [68.48929596, 23.63513947], [68.48902893, 23.63513947], [68.48902893, 23.63541985], [68.48986053, 23.63541412], [68.48986053, 23.63569641], [68.49013519, 23.63569641], [68.49013519, 23.63597488], [68.49041748, 23.63597107], [68.49041748, 23.63624954], [68.49069977, 23.63624954], [68.49069977, 23.63652992], [68.49097443, 23.63652611], [68.49097443, 23.63708305], [68.49124908, 23.63708305], [68.49124908, 23.63736153], [68.49180603, 23.63735962], [68.49180603, 23.63764], [68.49208069, 23.63764], [68.49208069, 23.63735962], [68.49236298, 23.63736153], [68.49236298, 23.63708305], [68.49291992, 23.63708115], [68.49291992, 23.63764], [68.49318695, 23.63764], [68.49318695, 23.63792038], [68.49346924, 23.63792038], [68.49346924, 23.63820076], [68.49319458, 23.63819695], [68.49319458, 23.6384716], [68.49291992, 23.6384697], [68.49291992, 23.63931084], [68.49319458, 23.63930511], [68.49319458, 23.63958359], [68.49346924, 23.63957977], [68.49346924, 23.63986015], [68.49373627, 23.63986015], [68.49373627, 23.64014816], [68.49402618, 23.64014816], [68.49402618, 23.64042091], [68.49430847, 23.6404171], [68.49430847, 23.64097214], [68.49458313, 23.64097023], [68.49458313, 23.64152908], [68.49485779, 23.64152718], [68.49485779, 23.64208412], [68.49514008, 23.6420784], [68.49514008, 23.64236069], [68.4954071, 23.64236069], [68.4954071, 23.64291954], [68.49569702, 23.64291573], [68.49569702, 23.6431942], [68.49624634, 23.6431942], [68.49624634, 23.64347267], [68.49652863, 23.64347076], [68.49652863, 23.64374924], [68.4970932, 23.64374924], [68.4970932, 23.64402962], [68.49736023, 23.64402771], [68.49736023, 23.64418983], [68.49736023, 23.6443119], [68.49781036, 23.64430809], [68.49903107, 23.64430618], [68.49903107, 23.64458275], [68.49886322, 23.64458275], [68.49874878, 23.64458275], [68.49874878, 23.64486122], [68.49847412, 23.64486122], [68.49847412, 23.64569473], [68.49874878, 23.64569283], [68.49874878, 23.64764023], [68.49903107, 23.64763832], [68.49903107, 23.64847183], [68.49874878, 23.64846992], [68.49874878, 23.64931107], [68.49846649, 23.64931107], [68.49846649, 23.64986038], [68.49736023, 23.64986038], [68.49736023, 23.65014076], [68.4970932, 23.65014076], [68.4970932, 23.65042114], [68.49680328, 23.65042114], [68.49680328, 23.65291977], [68.49736023, 23.65291786], [68.49736023, 23.65319443], [68.49764252, 23.65319443], [68.49764252, 23.6534729], [68.49819183, 23.65347099], [68.49819183, 23.65374947], [68.49874878, 23.65374947], [68.49874878, 23.65402985], [68.49903107, 23.65402985], [68.49903107, 23.65430832], [68.49930573, 23.65430641], [68.49930573, 23.65486145], [68.49958038, 23.65485954], [68.49958038, 23.65514946], [68.4998703, 23.65514946], [68.4998703, 23.65570068], [68.50013733, 23.65570068], [68.50013733, 23.65625191], [68.50041962, 23.65625191], [68.50041962, 23.65681267], [68.50069427, 23.65680504], [68.50069427, 23.65708351], [68.50263977, 23.65708351], [68.50263977, 23.65680504], [68.50430298, 23.65680504], [68.50430298, 23.65736008], [68.50458527, 23.65736008], [68.50458527, 23.65819359], [68.50541687, 23.65819359], [68.50541687, 23.65847015], [68.50567627, 23.65847015], [68.50567627, 23.65903282], [68.50681305, 23.65903282], [68.50681305, 23.65875053], [68.50763702, 23.65875053], [68.50763702, 23.65847015], [68.50791931, 23.65847015], [68.50791931, 23.65819359], [68.50846863, 23.65819359], [68.50846863, 23.65791702], [68.5090332, 23.65792274], [68.5090332, 23.65764046], [68.51013947, 23.65763855], [68.51013947, 23.65847015], [68.51040649, 23.65847015], [68.51040649, 23.65930939], [68.51069641, 23.65930939], [68.51069641, 23.65986061], [68.51097107, 23.65986061], [68.51097107, 23.66041946], [68.51180267, 23.66041756], [68.51180267, 23.66069221], [68.51264191, 23.66069221], [68.51264191, 23.66041756], [68.51597595, 23.66041756], [68.51597595, 23.66069221], [68.5173645, 23.66069221], [68.5173645, 23.66041756], [68.51763916, 23.66041946], [68.51763916, 23.6601429], [68.51875305, 23.6601429], [68.51875305, 23.65819168], [68.51902771, 23.65819359], [68.51902771, 23.65736008], [68.51930237, 23.65736008], [68.51930237, 23.65319443], [68.51958466, 23.65319443], [68.51958466, 23.65263939], [68.51985931, 23.65263939], [68.51985931, 23.65236092], [68.5201416, 23.65236092], [68.5201416, 23.65180969], [68.52041626, 23.65180969], [68.52041626, 23.65153122], [68.52179718, 23.65153122], [68.52179718, 23.65125084], [68.52319336, 23.65125084], [68.52319336, 23.65153122], [68.52404022, 23.65153122], [68.52404022, 23.65180969], [68.52513885, 23.65180969], [68.52513885, 23.65208817], [68.52540588, 23.65208817], [68.52540588, 23.65263939], [68.5256958, 23.65263939], [68.5256958, 23.65319443], [68.52597046, 23.65319061], [68.52597046, 23.65374947], [68.52625275, 23.65374947], [68.52625275, 23.6554184], [68.5265274, 23.65541649], [68.5265274, 23.65597153], [68.52680206, 23.65597153], [68.52680206, 23.65736008], [68.52707672, 23.65736008], [68.52707672, 23.65764046], [68.52735901, 23.65763855], [68.52735901, 23.65819359], [68.5276413, 23.65819359], [68.5276413, 23.65847015], [68.52791595, 23.65847015], [68.52791595, 23.65875053], [68.52819824, 23.65875053], [68.52819824, 23.65903282], [68.5284729, 23.65903282], [68.5284729, 23.65930939], [68.52874756, 23.65930557], [68.52874756, 23.65958214], [68.52902985, 23.65958214], [68.52902985, 23.65930557], [68.53152466, 23.65930557], [68.53152466, 23.65958214], [68.5320816, 23.65958023], [68.5320816, 23.65986061], [68.53347015, 23.65986061], [68.53347015, 23.65958023], [68.5359726, 23.65958214], [68.5359726, 23.65986061], [68.53624725, 23.65986061], [68.53624725, 23.66041946], [68.53652954, 23.66041756], [68.53652954, 23.66069221], [68.53736115, 23.66069221], [68.53736115, 23.6609745], [68.53791809, 23.66096115], [68.53791809, 23.66125107], [68.53819275, 23.66125107], [68.53819275, 23.66152954], [68.53847504, 23.66152763], [68.53847504, 23.66208267], [68.53874969, 23.66208076], [68.53874969, 23.66236115], [68.53901672, 23.66236115], [68.53902435, 23.66263962], [68.53848267, 23.66263962], [68.53848267, 23.66292], [68.53652954, 23.66292], [68.53652954, 23.66263962], [68.53624725, 23.66263962], [68.53624725, 23.66236115], [68.5359726, 23.66236115], [68.5359726, 23.66208267], [68.53569794, 23.66208267], [68.53569794, 23.6618042], [68.5348587, 23.66180992], [68.5348587, 23.66152954], [68.5340271, 23.66152954], [68.5340271, 23.66125107], [68.53263855, 23.66125107], [68.53263855, 23.66152954], [68.53235626, 23.66152954], [68.53235626, 23.66180992], [68.53125, 23.6618042], [68.53125, 23.66208267], [68.52986145, 23.66208267], [68.52986145, 23.6618042], [68.52929688, 23.66180992], [68.52929688, 23.66152954], [68.52874756, 23.66152954], [68.52874756, 23.66125107], [68.52819824, 23.66125107], [68.52819061, 23.66096115], [68.52791595, 23.6609745], [68.52791595, 23.66069221], [68.5276413, 23.66069221], [68.5276413, 23.66041756], [68.52735901, 23.66041946], [68.52735901, 23.65986061], [68.52707672, 23.65986061], [68.52707672, 23.65958023], [68.52680206, 23.65958214], [68.52680206, 23.65930557], [68.5265274, 23.65930939], [68.5265274, 23.65875053], [68.52625275, 23.65875053], [68.52625275, 23.65819168], [68.52597046, 23.65819359], [68.52597046, 23.65708351], [68.5256958, 23.65708351], [68.5256958, 23.65541649], [68.52540588, 23.6554184], [68.52540588, 23.65430832], [68.52458191, 23.65430832], [68.52458191, 23.65402985], [68.52430725, 23.65402985], [68.52430725, 23.65347099], [68.52402496, 23.6534729], [68.52402496, 23.65319443], [68.52347565, 23.65319443], [68.52347565, 23.6534729], [68.5220871, 23.65347099], [68.5220871, 23.65402985], [68.52179718, 23.65402985], [68.52179718, 23.65430832], [68.52041626, 23.65430641], [68.52041626, 23.65458298], [68.5201416, 23.65458298], [68.5201416, 23.65486145], [68.52041626, 23.65485954], [68.52041626, 23.65570068], [68.52068329, 23.65570068], [68.52068329, 23.65653038], [68.52041626, 23.65652847], [68.52041626, 23.65708351], [68.5201416, 23.6570816], [68.5201416, 23.65764046], [68.51985931, 23.65763855], [68.51985931, 23.65847015], [68.51957703, 23.65847015], [68.51957703, 23.6601429], [68.51930237, 23.6601429], [68.51930237, 23.66125107], [68.51875305, 23.66125107], [68.51875305, 23.66152954], [68.51847076, 23.66152954], [68.51847076, 23.66180992], [68.51791382, 23.6618042], [68.51791382, 23.66208267], [68.5173645, 23.66208267], [68.5173645, 23.66347313], [68.51763916, 23.66347122], [68.51763916, 23.66374969], [68.51790619, 23.66374969], [68.51790619, 23.66403008], [68.51819611, 23.66402817], [68.51819611, 23.66458321], [68.51847076, 23.66458321], [68.51847076, 23.66486168], [68.51875305, 23.66485977], [68.51875305, 23.66542053], [68.51847076, 23.66542053], [68.51847076, 23.66680908], [68.51875305, 23.66680908], [68.51875305, 23.66791916], [68.51902771, 23.66791725], [68.51902771, 23.66847229], [68.51930237, 23.66847038], [68.51930237, 23.66875076], [68.51957703, 23.66875076], [68.51957703, 23.66931152], [68.51985931, 23.6693058], [68.51985931, 23.66958237], [68.5201416, 23.66958046], [68.5201416, 23.66986084], [68.52069092, 23.66986084], [68.52069092, 23.67013931], [68.52097321, 23.67012978], [68.52097321, 23.6704216], [68.52153015, 23.67041588], [68.52153015, 23.67069435], [68.52180481, 23.67069435], [68.52180481, 23.67097282], [68.5220871, 23.67097092], [68.5220871, 23.67124939], [68.52236176, 23.67124939], [68.52236176, 23.6720829], [68.52263641, 23.6720829], [68.52263641, 23.67292023], [68.5229187, 23.67291641], [68.5229187, 23.67347145], [68.52319336, 23.67346954], [68.52319336, 23.6740303], [68.52348328, 23.6740303], [68.52348328, 23.67431068], [68.52375031, 23.67430305], [68.52375031, 23.67486382], [68.52404022, 23.67486], [68.52404022, 23.67514038], [68.52458191, 23.67514038], [68.52458191, 23.67542076], [68.5248642, 23.67541695], [68.5248642, 23.67569351], [68.52541351, 23.67569351], [68.52541351, 23.67597198], [68.5256958, 23.67597008], [68.5256958, 23.67625999], [68.52625275, 23.67625046], [68.52625275, 23.67708588], [68.5265274, 23.67708015], [68.5265274, 23.67875099], [68.52680969, 23.67875099], [68.52680969, 23.68152809], [68.52708435, 23.68152809], [68.52708435, 23.68347168], [68.52735901, 23.68347168], [68.52735901, 23.68680954], [68.52707672, 23.68680954], [68.52708435, 23.68736076], [68.52680969, 23.68736076], [68.52680969, 23.68791962], [68.5265274, 23.68791962], [68.5265274, 23.6882], [68.52625275, 23.68819237], [68.52625275, 23.68847466], [68.52597046, 23.68847084], [68.52597046, 23.68875122], [68.5256958, 23.68875122], [68.5256958, 23.68902969], [68.52513885, 23.68902969], [68.52513885, 23.68931007], [68.5248642, 23.68930435], [68.5248642, 23.68958282], [68.52458191, 23.68958092], [68.52458191, 23.69042015], [68.5248642, 23.69041443], [68.5248642, 23.69069672], [68.52541351, 23.69069672], [68.52541351, 23.69041443], [68.52597046, 23.69042015], [68.52597046, 23.69013977], [68.52625275, 23.69013977], [68.52625275, 23.68985939], [68.5265274, 23.6898613], [68.5265274, 23.68958282], [68.52680206, 23.68958282], [68.52680206, 23.68930435], [68.52735901, 23.68931007], [68.52735901, 23.68902969], [68.5276413, 23.68902969], [68.5276413, 23.68875122], [68.52791595, 23.68875122], [68.52791595, 23.68847084], [68.52958679, 23.68847084], [68.52958679, 23.68875122], [68.52984619, 23.68875122], [68.52984619, 23.68902969], [68.53013611, 23.68902969], [68.53013611, 23.68931007], [68.53069305, 23.68931007], [68.53069305, 23.68902969], [68.5320816, 23.68902969], [68.5320816, 23.68931007], [68.53236389, 23.68930435], [68.53236389, 23.68958282], [68.53263855, 23.68958282], [68.53263855, 23.6898613], [68.53291321, 23.68985939], [68.53291321, 23.69013977], [68.53320312, 23.69013977], [68.5331955, 23.68958282], [68.53347015, 23.68958282], [68.53347015, 23.68930435], [68.53569794, 23.68930435], [68.53569794, 23.68958282], [68.5359726, 23.68958282], [68.5359726, 23.69013977], [68.53679657, 23.69013977], [68.53679657, 23.69042015], [68.53736115, 23.69041443], [68.53736115, 23.69069672], [68.53819275, 23.69069672], [68.53819275, 23.69097137], [68.53874969, 23.69096947], [68.53874969, 23.69153023], [68.53902435, 23.69152832], [68.53902435, 23.69208336], [68.53930664, 23.69207954], [68.53930664, 23.69292068], [68.5395813, 23.69291878], [68.5395813, 23.69347191], [68.53985596, 23.69346809], [68.53985596, 23.69403076], [68.54152679, 23.69402885], [68.54152679, 23.69430542], [68.54180908, 23.6942997], [68.54180908, 23.69486046], [68.54207611, 23.69486046], [68.54207611, 23.69514084], [68.5423584, 23.69514084], [68.5423584, 23.69541931], [68.54291534, 23.6954174], [68.54291534, 23.69569397], [68.54319763, 23.69569397], [68.54319763, 23.69597244], [68.54347229, 23.69597054], [68.54347229, 23.69625092], [68.54429626, 23.69625092], [68.54429626, 23.69652939], [68.54541779, 23.69652939], [68.54541779, 23.69681168], [68.54624939, 23.69681168], [68.54624939, 23.69735909], [68.54652405, 23.69735909], [68.54652405, 23.6981945], [68.54680634, 23.6981926], [68.54680634, 23.69874954], [68.54708099, 23.69874954], [68.54708099, 23.69930267], [68.54736328, 23.69930649], [68.54736328, 23.69986153], [68.54763794, 23.69985962], [68.54763794, 23.70070076], [68.54792023, 23.70070076], [68.54792023, 23.70125008], [68.54818726, 23.70125008], [68.54818726, 23.70181084], [68.54846954, 23.70181084], [68.54846954, 23.70236015], [68.54875183, 23.70236015], [68.54875183, 23.70292091], [68.54902649, 23.70292091], [68.54902649, 23.70375061], [68.54930878, 23.70375061], [68.54930878, 23.70430946], [68.54957581, 23.70430946], [68.54957581, 23.70486069], [68.54985809, 23.70486069], [68.54985809, 23.70541954], [68.55014038, 23.70541763], [68.55014038, 23.70624924], [68.55042267, 23.7062397], [68.55042267, 23.70680809], [68.55069733, 23.70680809], [68.55069733, 23.70736122], [68.55097961, 23.70736122], [68.55097961, 23.70791817], [68.55124664, 23.70791817], [68.55124664, 23.70874977], [68.55152893, 23.70874977], [68.55152893, 23.70930481], [68.55180359, 23.70930481], [68.55180359, 23.70986176], [68.55208588, 23.70986176], [68.55208588, 23.71042252], [68.55236053, 23.71041679], [68.55236053, 23.71097183], [68.55264282, 23.71097183], [68.55264282, 23.71153259], [68.55291748, 23.71152687], [68.55291748, 23.71208382], [68.55319214, 23.71208191], [68.55319214, 23.71236038], [68.5534668, 23.71236038], [68.5534668, 23.71292114], [68.55374908, 23.71291733], [68.55374908, 23.71347237], [68.55401611, 23.71347046], [68.55401611, 23.71375084], [68.55430603, 23.71375084], [68.55430603, 23.71403122], [68.55458069, 23.7140274], [68.55458069, 23.71458244], [68.55486298, 23.71458054], [68.55486298, 23.71486092], [68.55513763, 23.71486092], [68.55513763, 23.71513939], [68.55541992, 23.71513939], [68.55541992, 23.71569633], [68.55569458, 23.71569633], [68.55569458, 23.71597481], [68.55596924, 23.71597099], [68.55596924, 23.71624947], [68.55625153, 23.71624947], [68.55625153, 23.71652985], [68.55652618, 23.71652794], [68.55652618, 23.71708488], [68.55680847, 23.71708488], [68.55680847, 23.71736145], [68.55708313, 23.71735954], [68.55708313, 23.71763992], [68.55735779, 23.71763992], [68.55735779, 23.7179203], [68.55764008, 23.7179203], [68.55764008, 23.71820068], [68.5579071, 23.71820068], [68.5579071, 23.71875], [68.55819702, 23.71875], [68.55819702, 23.71903038], [68.55847168, 23.71903038], [68.55847168, 23.71931076], [68.55902863, 23.71930695], [68.55902863, 23.71958351], [68.55986023, 23.71958351], [68.55986023, 23.71986198], [68.56041718, 23.71986008], [68.56041718, 23.72014046], [68.56096649, 23.72014046], [68.56096649, 23.72042084], [68.56153107, 23.72041893], [68.56153107, 23.72069359], [68.56208038, 23.72069359], [68.56208038, 23.72097206], [68.56263733, 23.72097206], [68.56263733, 23.72125053], [68.56318665, 23.721241], [68.56318665, 23.72153091], [68.56375122, 23.72153091], [68.56375122, 23.72180939], [68.56430817, 23.72180557], [68.56430817, 23.72208405], [68.56569672, 23.72207832], [68.56569672, 23.72236061], [68.56680298, 23.72236061], [68.56680298, 23.72263908], [68.56735992, 23.72263908], [68.56735992, 23.72291946], [68.56791687, 23.72291756], [68.56791687, 23.72319412], [68.56847382, 23.72319412], [68.56847382, 23.7234726], [68.56902313, 23.72347069], [68.56902313, 23.72374916], [68.56958008, 23.72374916], [68.56958008, 23.72402954], [68.57013702, 23.72402763], [68.57013702, 23.72430611], [68.57069397, 23.72430611], [68.57069397, 23.72458267], [68.57125092, 23.72458267], [68.57125092, 23.72486115], [68.57263947, 23.72486115], [68.57263947, 23.72458267], [68.57319641, 23.72458267], [68.57319641, 23.72430611], [68.57375336, 23.72430611], [68.57375336, 23.72402763], [68.57402802, 23.72402954], [68.57402802, 23.72374916], [68.57430267, 23.72374916], [68.57430267, 23.7231884], [68.57458496, 23.72319412], [68.57458496, 23.72291756], [68.57485962, 23.72291946], [68.57485962, 23.72263908], [68.57514954, 23.72263908], [68.57514954, 23.72207832], [68.57541656, 23.72208405], [68.57541656, 23.72180557], [68.57569122, 23.72180939], [68.57569122, 23.721241], [68.57597351, 23.72125053], [68.57597351, 23.72097206], [68.57624817, 23.72097206], [68.57624817, 23.72069359], [68.57653046, 23.72069359], [68.57653046, 23.72041893], [68.57707977, 23.72042084], [68.57707977, 23.72014046], [68.57763672, 23.72014046], [68.57763672, 23.72042084], [68.57736206, 23.72041893], [68.57736206, 23.72125053], [68.57707977, 23.721241], [68.57707977, 23.72180939], [68.57681274, 23.72180939], [68.57681274, 23.72263908], [68.57653046, 23.72263908], [68.57653046, 23.72374916], [68.57624817, 23.72374916], [68.57624817, 23.72458267], [68.57680511, 23.72458267], [68.57680511, 23.72486115], [68.57736206, 23.72486115], [68.57736206, 23.72513962], [68.57763672, 23.72513962], [68.57763672, 23.72542191], [68.57819366, 23.72541618], [68.57819366, 23.72569466], [68.57847595, 23.72569466], [68.57847595, 23.72597122], [68.57875061, 23.72597122], [68.57875061, 23.72653008], [68.57902527, 23.72652817], [68.57902527, 23.7270813], [68.57930756, 23.72707939], [68.57930756, 23.72764015], [68.57958221, 23.72764015], [68.57958221, 23.72820091], [68.5798645, 23.72819328], [68.5798645, 23.72847176], [68.58040619, 23.72846985], [68.58040619, 23.72875023], [68.58096313, 23.72875023], [68.58096313, 23.72903061], [68.58207703, 23.72903061], [68.58207703, 23.72931099], [68.58319092, 23.72930336], [68.58319092, 23.72958565], [68.58486176, 23.72957993], [68.58486176, 23.72986031], [68.58653259, 23.72986031], [68.58653259, 23.73014069], [68.58763885, 23.73014069], [68.58763885, 23.7304306], [68.58875275, 23.73041534], [68.58875275, 23.73069572], [68.58958435, 23.73069572], [68.58958435, 23.73097229], [68.59041595, 23.73097038], [68.59041595, 23.73125076], [68.59124756, 23.73125076], [68.59124756, 23.73153114], [68.59208679, 23.73153114], [68.59208679, 23.73125076], [68.59236145, 23.73125076], [68.59236145, 23.73097038], [68.59263611, 23.73097229], [68.59263611, 23.73069572], [68.59347534, 23.73069572], [68.59347534, 23.73041534], [68.59430695, 23.7304306], [68.59430695, 23.73014069], [68.59541321, 23.73013878], [68.59541321, 23.73097229], [68.59513855, 23.73097038], [68.59513855, 23.73180962], [68.59541321, 23.73180962], [68.59541321, 23.73236084], [68.59570313, 23.73236084], [68.59570313, 23.73264122], [68.59597015, 23.73264122], [68.59597015, 23.73291969], [68.59625244, 23.73291779], [68.59625244, 23.73319435], [68.5965271, 23.73319435], [68.5965271, 23.73347282], [68.59680176, 23.73347092], [68.59680939, 23.73374939], [68.59707642, 23.73374939], [68.59707642, 23.73402977], [68.59764099, 23.73402977], [68.59764099, 23.73430824], [68.59791565, 23.73430634], [68.59791565, 23.7345829], [68.59819794, 23.7345829], [68.59819794, 23.73569489], [68.5984726, 23.73568916], [68.5984726, 23.7365303], [68.59874725, 23.7365303], [68.59874725, 23.73681259], [68.59902954, 23.73680496], [68.59902954, 23.73736191], [68.59929657, 23.73736191], [68.59929657, 23.73764038], [68.59902954, 23.73763847], [68.59902954, 23.7381916], [68.59874725, 23.73820114], [68.59874725, 23.73875046], [68.5984726, 23.73875046], [68.5984726, 23.73903275], [68.59792328, 23.73903275], [68.59792328, 23.73931122], [68.59764099, 23.7393055], [68.59764099, 23.73958206], [68.59792328, 23.73958015], [68.59792328, 23.74014282], [68.59819794, 23.74014282], [68.59819794, 23.74041939], [68.60124969, 23.74041939], [68.60124969, 23.74570084], [68.60151672, 23.74570084], [68.60151672, 23.74625015], [68.60180664, 23.74625015], [68.60180664, 23.74681091], [68.6020813, 23.74680519], [68.6020813, 23.74708366], [68.60235596, 23.74707985], [68.60235596, 23.74736023], [68.60263824, 23.74736023], [68.60263824, 23.74764061], [68.6029129, 23.7476387], [68.6029129, 23.74819374], [68.60319519, 23.74819374], [68.60319519, 23.74847221], [68.60346985, 23.74847031], [68.60346985, 23.74875069], [68.60402679, 23.74875069], [68.60402679, 23.74847031], [68.60736084, 23.74847031], [68.60736084, 23.74875069], [68.6076355, 23.74875069], [68.6076355, 23.74986076], [68.61152649, 23.74986076], [68.61152649, 23.75013924], [68.61207581, 23.75013924], [68.61207581, 23.75041962], [68.61235809, 23.7504158], [68.61235809, 23.75069427], [68.61264038, 23.75069427], [68.61264038, 23.75097275], [68.61319733, 23.75097084], [68.61319733, 23.75125122], [68.61347198, 23.75125122], [68.61347198, 23.75154114], [68.61374664, 23.75154114], [68.61374664, 23.75181007], [68.61486053, 23.75180626], [68.61486053, 23.75208282], [68.61597443, 23.75208282], [68.61597443, 23.7523613], [68.61707306, 23.75235939], [68.61707306, 23.75263977], [68.61902618, 23.75263977], [68.61902618, 23.75292015], [68.62097168, 23.75291634], [68.62097168, 23.75319481], [68.62124634, 23.75319481], [68.62124634, 23.75347137], [68.62152863, 23.75346947], [68.62152863, 23.75403023], [68.62180328, 23.75403023], [68.62180328, 23.75431061], [68.62403107, 23.75430489], [68.62403107, 23.75458336], [68.62431335, 23.75457954], [68.62431335, 23.75542068], [68.62458038, 23.75542068], [68.62458038, 23.75570107], [68.62486267, 23.75569344], [68.62486267, 23.75597191], [68.62541962, 23.75597], [68.62541962, 23.75625038], [68.62568665, 23.75625038], [68.62568665, 23.75653076], [68.62596893, 23.75653076], [68.62596893, 23.75681114], [68.62652588, 23.75680351], [68.62652588, 23.7570858], [68.62708282, 23.7570858], [68.62708282, 23.75736046], [68.62763977, 23.75735092], [68.62763977, 23.75764084], [68.62819672, 23.75764084], [68.62819672, 23.75792122], [68.62847137, 23.7579174], [68.62847137, 23.75819588], [68.62902832, 23.75819588], [68.62902832, 23.75847244], [68.62930298, 23.75847054], [68.62930298, 23.75875092], [68.6295929, 23.75875092], [68.6295929, 23.75902939], [68.63069153, 23.75902939], [68.63069153, 23.75875092], [68.63096619, 23.75875092], [68.63096619, 23.75847054], [68.63124847, 23.75847244], [68.63124847, 23.75819588], [68.63153076, 23.75819588], [68.63153076, 23.7579174], [68.63263702, 23.7579174], [68.63263702, 23.75847244], [68.63291931, 23.75847054], [68.63291931, 23.75902939], [68.63263702, 23.75902939], [68.63263702, 23.75986099], [68.63236237, 23.75986099], [68.63236237, 23.76097298], [68.63208008, 23.76097298], [68.63207245, 23.76180077], [68.63236237, 23.76180649], [68.63236237, 23.76236153], [68.63263702, 23.76235962], [68.63263702, 23.76291847], [68.63291931, 23.76291847], [68.63291931, 23.76348114], [68.63318634, 23.76348114], [68.63318634, 23.76403046], [68.63346863, 23.76403046], [68.63346863, 23.76431274], [68.63375092, 23.76431274], [68.63375092, 23.76486015], [68.6340332, 23.76486015], [68.6340332, 23.76542282], [68.63430786, 23.7654171], [68.63430786, 23.76597023], [68.63458252, 23.76597023], [68.63458252, 23.76654053], [68.63486481, 23.76652718], [68.63486481, 23.76708221], [68.63513947, 23.76708031], [68.63513947, 23.76764107], [68.63541412, 23.76763916], [68.63541412, 23.76819229], [68.63569641, 23.76819038], [68.63569641, 23.76875114], [68.63597107, 23.76875114], [68.63597107, 23.76931], [68.63625336, 23.76930428], [68.63625336, 23.76958275], [68.63652802, 23.76958084], [68.63652802, 23.77013969], [68.63680267, 23.77013969], [68.63680267, 23.77069664], [68.63708496, 23.77069664], [68.63708496, 23.77124977], [68.63735962, 23.77124977], [68.63735962, 23.77153015], [68.63764191, 23.77152824], [68.63764191, 23.77208328], [68.63791656, 23.77208328], [68.63791656, 23.77236176], [68.63819885, 23.77235031], [68.63819885, 23.77292061], [68.63846588, 23.77292061], [68.63846588, 23.77319908], [68.63874817, 23.77319908], [68.63874817, 23.77375031], [68.63903046, 23.77375031], [68.63903046, 23.77430916], [68.63930511, 23.77430534], [68.63930511, 23.77458382], [68.63957977, 23.77457809], [68.63957977, 23.77514076], [68.63986206, 23.77514076], [68.63986206, 23.77541924], [68.64013672, 23.77541733], [68.64013672, 23.77597237], [68.64041901, 23.77597046], [68.64041901, 23.77625084], [68.64068604, 23.77625084], [68.64068604, 23.7768116], [68.64097595, 23.77680588], [68.64097595, 23.77708244], [68.64124298, 23.77708054], [68.64124298, 23.77763939], [68.6415329, 23.77763939], [68.6415329, 23.77792168], [68.64180756, 23.77792168], [68.64180756, 23.77848053], [68.64208221, 23.77848053], [68.64208221, 23.77874947], [68.64235687, 23.77874947], [68.64235687, 23.77902985], [68.64263916, 23.77902794], [68.64263916, 23.77958107], [68.64291382, 23.77958107], [68.64291382, 23.77986145], [68.64319611, 23.77985954], [68.64319611, 23.78013992], [68.64347076, 23.78013992], [68.64347076, 23.78070068], [68.64375305, 23.78069305], [68.64375305, 23.78097153], [68.64402771, 23.78096962], [68.64402771, 23.78125], [68.64430237, 23.78125], [68.64430237, 23.78181076], [68.64458466, 23.78180313], [68.64458466, 23.78208351], [68.64485931, 23.78208351], [68.64485931, 23.78236389], [68.6451416, 23.78236008], [68.6451416, 23.78292084], [68.64541626, 23.78291512], [68.64541626, 23.78347206], [68.64569092, 23.78347015], [68.64569092, 23.78375053], [68.64597321, 23.78375053], [68.64597321, 23.78430939], [68.64624786, 23.78430939], [68.64624786, 23.78486061], [68.64653015, 23.78486061], [68.64653015, 23.78541946], [68.64680481, 23.78541756], [68.64680481, 23.78569412], [68.6470871, 23.78569031], [68.6470871, 23.78625107], [68.64736938, 23.78625107], [68.64736938, 23.78680992], [68.64763641, 23.78680611], [68.64763641, 23.78708267], [68.6479187, 23.78708076], [68.6479187, 23.78764915], [68.64819336, 23.78764915], [68.64819336, 23.78791809], [68.64847565, 23.78791618], [68.64847565, 23.78847313], [68.64875031, 23.78847122], [68.64875031, 23.78874969], [68.64902496, 23.78874969], [68.64902496, 23.78930473], [68.64930725, 23.78930473], [68.64930725, 23.78958321], [68.64958191, 23.78957748], [68.64958191, 23.79014015], [68.64985657, 23.79014015], [68.64985657, 23.79071045], [68.65013885, 23.79071045], [68.65013885, 23.79153252], [68.65041351, 23.7915287], [68.65041351, 23.79208374], [68.6506958, 23.79208183], [68.6506958, 23.79292107], [68.65097046, 23.79291725], [68.65097046, 23.79347229], [68.6506958, 23.79346275], [68.6506958, 23.79375076], [68.65097046, 23.79375076], [68.65097046, 23.79403114], [68.65125275, 23.79403114], [68.65125275, 23.79430962], [68.65180206, 23.7943058], [68.65180206, 23.79458237], [68.65207672, 23.79458046], [68.65207672, 23.79514122], [68.65235901, 23.79514122], [68.65235901, 23.79541969], [68.6526413, 23.79541588], [68.6526413, 23.79569244], [68.65291595, 23.79569244], [68.65291595, 23.79597473], [68.65319824, 23.79597473], [68.65319824, 23.79652786], [68.6534729, 23.79652023], [68.6534729, 23.79681015], [68.65374756, 23.79680443], [68.65374756, 23.7970829], [68.65402985, 23.7970829], [68.65402985, 23.79736137], [68.65429688, 23.79735947], [68.65429688, 23.79763985], [68.65458679, 23.79763985], [68.65458679, 23.79792023], [68.65486145, 23.79791451], [68.65486145, 23.79819679], [68.65513611, 23.79819107], [68.65513611, 23.79874992], [68.6554184, 23.79874992], [68.6554184, 23.7990303], [68.65569305, 23.7990303], [68.65569305, 23.79931068], [68.65598297, 23.79931068], [68.65598297, 23.79959106], [68.65625, 23.79958344], [68.65625, 23.79986191], [68.65651703, 23.79985809], [68.65651703, 23.80014038], [68.65680695, 23.80014038], [68.65680695, 23.80042076], [68.6570816, 23.80041885], [68.6570816, 23.80069351], [68.65736389, 23.80069351], [68.65736389, 23.80097198], [68.65763855, 23.80096817], [68.65763855, 23.80125046], [68.65791321, 23.80125046], [68.65791321, 23.80153084], [68.65820313, 23.80153084], [68.65820313, 23.80180931], [68.65847015, 23.8018055], [68.65847015, 23.80208397], [68.65875244, 23.80207825], [68.65875244, 23.80265045], [68.6590271, 23.80265045], [68.6590271, 23.80291939], [68.65930176, 23.80291748], [68.65930939, 23.80319405], [68.6598587, 23.80319405], [68.6598587, 23.80347252], [68.66042328, 23.80347061], [68.66042328, 23.80374908], [68.6609726, 23.80374908], [68.6609726, 23.80402946], [68.66152954, 23.80402946], [68.66152954, 23.80431175], [68.66208649, 23.80430603], [68.66208649, 23.8045826], [68.66236115, 23.8045826], [68.66236115, 23.80486107], [68.6626358, 23.80486107], [68.6626358, 23.80542183], [68.66291809, 23.80541611], [68.66291809, 23.80569458], [68.66319275, 23.80569458], [68.66319275, 23.80597115], [68.66374969, 23.80597115], [68.66374969, 23.80624962], [68.66401672, 23.80624962], [68.66401672, 23.80653191], [68.66430664, 23.80652809], [68.66430664, 23.80680466], [68.6645813, 23.80680466], [68.6645813, 23.80708122], [68.66486359, 23.80708122], [68.66486359, 23.8073616], [68.6654129, 23.8073597], [68.6654129, 23.80764008], [68.66570282, 23.80764008], [68.66570282, 23.80792046], [68.66596985, 23.80792046], [68.66596985, 23.80820084], [68.66625214, 23.80819321], [68.66625214, 23.80847168], [68.66680908, 23.80846024], [68.66680908, 23.80875015], [68.66764069, 23.80875015], [68.66764069, 23.80903053], [68.66819763, 23.80903053], [68.66819763, 23.80931091], [68.66902924, 23.80930328], [68.66902924, 23.80958557], [68.66958618, 23.80957985], [68.66958618, 23.80986023], [68.66986084, 23.80986023], [68.66986084, 23.81042099], [68.6701355, 23.81041527], [68.6701355, 23.81069374], [68.67124939, 23.81069374], [68.67124939, 23.81097221], [68.67236328, 23.81097221], [68.67236328, 23.81069374], [68.67430878, 23.81069374], [68.67430878, 23.81097221], [68.67541504, 23.81097221], [68.67541504, 23.81069374], [68.67569733, 23.81069374], [68.67569733, 23.8101387], [68.67597198, 23.81014061], [68.67597198, 23.80931091], [68.67624664, 23.80931091], [68.67624664, 23.80875015], [68.67652893, 23.80875015], [68.67652893, 23.80820084], [68.67679596, 23.80820084], [68.67679596, 23.80764008], [68.67791748, 23.80764008], [68.67791748, 23.80875015], [68.67763519, 23.80875015], [68.67763519, 23.80958557], [68.67735291, 23.80957985], [68.67735291, 23.81014061], [68.67708588, 23.81014061], [68.67708588, 23.81125069], [68.67680359, 23.81125069], [68.67680359, 23.8120842], [68.67708588, 23.8120842], [68.67708588, 23.81319427], [68.67735291, 23.81319046], [68.67735291, 23.81430817], [68.67791748, 23.81430817], [68.67791748, 23.81459045], [68.67819214, 23.81458282], [68.67819214, 23.8148613], [68.67874908, 23.81485748], [68.67874908, 23.81513977], [68.67930603, 23.81513977], [68.67930603, 23.81541824], [68.67958069, 23.81541634], [68.67958069, 23.81569481], [68.68013763, 23.81569481], [68.68013763, 23.81597137], [68.68041229, 23.81596756], [68.68041229, 23.81624985], [68.68096924, 23.81624985], [68.68096924, 23.81653023], [68.68152618, 23.81652832], [68.68152618, 23.81680489], [68.68180847, 23.81680489], [68.68180847, 23.81708336], [68.68235779, 23.81708336], [68.68235779, 23.81736183], [68.68264008, 23.81736183], [68.68264008, 23.81792259], [68.6829071, 23.81792259], [68.6829071, 23.81875038], [68.68264008, 23.81875038], [68.68264008, 23.81931114], [68.68347168, 23.81930542], [68.68347168, 23.81958389], [68.68402863, 23.81958008], [68.68402863, 23.81986046], [68.6845932, 23.81986046], [68.6845932, 23.82014275], [68.68486023, 23.82014275], [68.68486023, 23.82042122], [68.68541718, 23.8204174], [68.68541718, 23.82069206], [68.68597412, 23.82069206], [68.68597412, 23.82097244], [68.68653107, 23.82097244], [68.68653107, 23.82125092], [68.68681335, 23.82125092], [68.68681335, 23.82152939], [68.68736267, 23.82152939], [68.68736267, 23.82180977], [68.68846893, 23.82180405], [68.68846893, 23.82208252], [68.68930817, 23.82208061], [68.68930817, 23.82236099], [68.6904068, 23.82236099], [68.6904068, 23.82263947], [68.69458008, 23.82263947], [68.69458008, 23.82291985], [68.69680786, 23.82291412], [68.69680786, 23.82319641], [68.69847107, 23.82319641], [68.69847107, 23.82347488], [68.69985962, 23.82347107], [68.69985962, 23.82374954], [68.70153809, 23.82374954], [68.70153809, 23.82402992], [68.70319366, 23.82402611], [68.70318604, 23.82430077], [68.7048645, 23.82430458], [68.7048645, 23.82458305], [68.70625305, 23.82458305], [68.70625305, 23.82486153], [68.7076416, 23.82485962], [68.7076416, 23.82514], [68.70903015, 23.82514], [68.70903015, 23.82542038], [68.71098328, 23.82542038], [68.71098328, 23.82570076], [68.71736145, 23.82569695], [68.71736145, 23.8259716], [68.71847534, 23.8259716], [68.71847534, 23.82625008], [68.71930695, 23.82625008], [68.71930695, 23.82653046], [68.72013855, 23.82653046], [68.72013855, 23.82681847], [68.72097015, 23.82680511], [68.72097015, 23.82708359], [68.72180176, 23.82707977], [68.72180939, 23.82736015], [68.72264862, 23.82736015], [68.72264862, 23.82764053], [68.7234726, 23.82764053], [68.7234726, 23.82792091], [68.7243042, 23.8279171], [68.7243042, 23.82819366], [68.72486115, 23.82819366], [68.72486115, 23.82847214], [68.72569275, 23.82846832], [68.72569275, 23.82875061], [68.72624969, 23.82875061], [68.72624969, 23.82902908], [68.72651672, 23.82902908], [68.72651672, 23.82930946], [68.7270813, 23.82930565], [68.7270813, 23.82958412], [68.72735596, 23.82957077], [68.72735596, 23.82986069], [68.7279129, 23.82986069], [68.7279129, 23.83013916], [68.72820282, 23.83013916], [68.72820282, 23.83041954], [68.72875214, 23.83041573], [68.72875214, 23.8306942], [68.7298584, 23.8306942], [68.7298584, 23.83097267], [68.73069763, 23.83097076], [68.73069763, 23.83124924], [68.73124695, 23.83124924], [68.73124695, 23.83152962], [68.73179626, 23.83152962], [68.73179626, 23.8318119], [68.73236084, 23.83180618], [68.73236084, 23.83208275], [68.7326355, 23.83208275], [68.7326355, 23.83236122], [68.73319244, 23.83236122], [68.73319244, 23.83263969], [68.73374939, 23.83263016], [68.73374939, 23.83292007], [68.73430634, 23.83291626], [68.73430634, 23.83319473], [68.73486328, 23.83319473], [68.73486328, 23.8334713], [68.73542023, 23.83346939], [68.73542023, 23.83374977], [68.73596954, 23.83374977], [68.73596954, 23.83403015], [68.73652649, 23.83402824], [68.73652649, 23.83430481], [68.73708344, 23.83430481], [68.73708344, 23.83458328], [68.73735809, 23.83458328], [68.73735809, 23.83486176], [68.73764801, 23.83485985], [68.73764801, 23.83542061], [68.73791504, 23.83541679], [68.73791504, 23.83569336], [68.73819733, 23.83569336], [68.73819733, 23.83597183], [68.73902893, 23.83596992], [68.73902893, 23.83625031], [68.73986053, 23.83625031], [68.73986053, 23.83653069], [68.7409668, 23.83653069], [68.7409668, 23.83681107], [68.74180603, 23.83680344], [68.74180603, 23.83708572], [68.74263763, 23.83708], [68.74263763, 23.83903122], [68.74318695, 23.83903122], [68.74318695, 23.83930969], [68.74375153, 23.83930969], [68.74375153, 23.83986092], [68.74402618, 23.83986092], [68.74402618, 23.84182167], [68.74375153, 23.84180641], [68.74375153, 23.84236145], [68.74318695, 23.84235954], [68.74318695, 23.84263992], [68.74291992, 23.84263992], [68.74291992, 23.84347153], [68.74318695, 23.84347153], [68.74318695, 23.84375191], [68.74263763, 23.84375191], [68.74263763, 23.84347153], [68.74236298, 23.84347153], [68.74236298, 23.84319496], [68.74208069, 23.84320259], [68.74208069, 23.8429184], [68.74153137, 23.8429184], [68.74153137, 23.84263992], [68.74124908, 23.84263992], [68.74124908, 23.84235954], [68.74097443, 23.84236145], [68.74097443, 23.84208298], [68.74069214, 23.84208298], [68.74069214, 23.84180641], [68.74014282, 23.84182167], [68.74014282, 23.84152985], [68.73986053, 23.84152985], [68.73986053, 23.84124947], [68.73958588, 23.84124947], [68.73958588, 23.84097099], [68.73930359, 23.8409729], [68.73930359, 23.84069443], [68.73902893, 23.84069443], [68.73902893, 23.84041786], [68.73847198, 23.84041977], [68.73847198, 23.84013939], [68.73819733, 23.84013939], [68.73819733, 23.83986092], [68.73791504, 23.83986092], [68.73791504, 23.83958244], [68.73764038, 23.83958244], [68.73764038, 23.83930779], [68.73707581, 23.83930969], [68.73707581, 23.83903122], [68.73680878, 23.83903122], [68.73680878, 23.83876038], [68.73652649, 23.83876038], [68.73652649, 23.83847046], [68.73625183, 23.83847237], [68.73625183, 23.8381958], [68.73596954, 23.8381958], [68.73596954, 23.83791542], [68.73542023, 23.83792114], [68.73542023, 23.83764076], [68.73513794, 23.83764076], [68.73513794, 23.83736038], [68.73486328, 23.83736038], [68.73486328, 23.83708], [68.73458099, 23.83708572], [68.73458099, 23.83680344], [68.73401642, 23.83681107], [68.73401642, 23.83653069], [68.73374939, 23.83653069], [68.73374939, 23.83625031], [68.7334671, 23.83625031], [68.7334671, 23.83596992], [68.73319244, 23.83597183], [68.73319244, 23.83569336], [68.7326355, 23.83569336], [68.7326355, 23.83541679], [68.73236084, 23.83542061], [68.73236084, 23.83514023], [68.73208618, 23.83514023], [68.73208618, 23.83485985], [68.73152924, 23.83486176], [68.73152924, 23.83458328], [68.73124695, 23.83458328], [68.73124695, 23.83430481], [68.73097229, 23.83430481], [68.73097229, 23.83402824], [68.73042297, 23.83403015], [68.73042297, 23.83374977], [68.73014069, 23.83374977], [68.73014069, 23.83346939], [68.7298584, 23.8334713], [68.7298584, 23.83319473], [68.72958374, 23.83319473], [68.72958374, 23.83291626], [68.72930908, 23.83292007], [68.72930908, 23.83263016], [68.72902679, 23.83263969], [68.72902679, 23.83236122], [68.72875214, 23.83236122], [68.72875214, 23.83208275], [68.72846985, 23.83208275], [68.72846985, 23.83180618], [68.72820282, 23.8318119], [68.72820282, 23.83152962], [68.7279129, 23.83152962], [68.7279129, 23.83124924], [68.72763824, 23.83124924], [68.72763824, 23.83097076], [68.72319794, 23.83097076], [68.72319794, 23.83124924], [68.72292328, 23.83124924], [68.72292328, 23.83152962], [68.7223587, 23.83152962], [68.7223587, 23.8318119], [68.72208405, 23.83180618], [68.72208405, 23.83208275], [68.7223587, 23.83208275], [68.7223587, 23.83236122], [68.72319794, 23.83236122], [68.72319794, 23.83263969], [68.72402954, 23.83263016], [68.72402954, 23.83292007], [68.72486115, 23.83291626], [68.72486115, 23.83319473], [68.72541809, 23.83319473], [68.72541809, 23.8334713], [68.72624969, 23.83346939], [68.72624969, 23.83374977], [68.7270813, 23.83374977], [68.7270813, 23.83403015], [68.72763824, 23.83402824], [68.72763824, 23.83430481], [68.72819519, 23.83430481], [68.72819519, 23.83458328], [68.72846985, 23.83458328], [68.72846985, 23.83486176], [68.72902679, 23.83485985], [68.72902679, 23.83514023], [68.72957611, 23.83514023], [68.72957611, 23.83542061], [68.73014069, 23.83541679], [68.73014069, 23.83569336], [68.73041534, 23.83569336], [68.73041534, 23.83597183], [68.73097229, 23.83596992], [68.73097229, 23.83625031], [68.73152161, 23.83625031], [68.73152161, 23.83653069], [68.73208618, 23.83653069], [68.73208618, 23.83681107], [68.73236084, 23.83680344], [68.73236084, 23.83708572], [68.73291779, 23.83708], [68.73291779, 23.83736038], [68.73264313, 23.83736038], [68.73264313, 23.83764076], [68.73208618, 23.83764076], [68.73208618, 23.83792114], [68.73180389, 23.83791542], [68.73180389, 23.8381958], [68.73124695, 23.8381958], [68.73124695, 23.83847237], [68.73097229, 23.83847046], [68.73097229, 23.83876038], [68.73069763, 23.83876038], [68.73069763, 23.83903122], [68.73014069, 23.83903122], [68.73014069, 23.83930969], [68.7298584, 23.83930779], [68.7298584, 23.83958244], [68.73014069, 23.83958054], [68.73014069, 23.83986092], [68.73097229, 23.83986092], [68.73097229, 23.83958054], [68.73152924, 23.83958244], [68.73152924, 23.83930779], [68.73208618, 23.83930969], [68.73208618, 23.83903122], [68.73236084, 23.83903122], [68.73236084, 23.83876038], [68.73291779, 23.83876038], [68.73291779, 23.83847046], [68.73347473, 23.83847237], [68.73347473, 23.8381958], [68.73402405, 23.8381958], [68.73402405, 23.83791542], [68.73486328, 23.83791542], [68.73486328, 23.8381958], [68.73513794, 23.83819008], [68.73513794, 23.83876038], [68.73542023, 23.83876038], [68.73542023, 23.83930969], [68.73568726, 23.83930969], [68.73568726, 23.84124947], [68.73596954, 23.84124947], [68.73596954, 23.84182167], [68.73625183, 23.84180641], [68.73625183, 23.84236145], [68.73652649, 23.84235954], [68.73652649, 23.84263992], [68.73680878, 23.84263992], [68.73680878, 23.84320259], [68.73707581, 23.84320259], [68.73707581, 23.84375191], [68.73596954, 23.84375191], [68.73596954, 23.84347153], [68.73513794, 23.84347153], [68.73513794, 23.84319496], [68.73374939, 23.84319496], [68.73374939, 23.84347153], [68.7334671, 23.84347153], [68.7334671, 23.84375191], [68.73319244, 23.84375191], [68.73319244, 23.84403038], [68.73291779, 23.84403038], [68.73291779, 23.84431267], [68.7326355, 23.84430504], [68.7326355, 23.84458351], [68.73236084, 23.84456825], [68.73236084, 23.84514046], [68.73208618, 23.84514046], [68.73208618, 23.84542274], [68.73124695, 23.84541702], [68.73124695, 23.84569359], [68.73097229, 23.84569359], [68.73097229, 23.84597015], [68.73041534, 23.84597015], [68.73042297, 23.84625053], [68.72569275, 23.84625053], [68.72569275, 23.84680939], [68.72541809, 23.84680939], [68.72541809, 23.84736061], [68.7251358, 23.84736061], [68.7251358, 23.84791946], [68.72541809, 23.84791756], [68.72541809, 23.84819221], [68.72569275, 23.84819221], [68.72569275, 23.8484726], [68.72598267, 23.84847069], [68.72598267, 23.84875107], [68.72624969, 23.84875107], [68.72624969, 23.84930992], [68.72652435, 23.8493042], [68.72652435, 23.84958267], [68.72680664, 23.84958076], [68.72680664, 23.84986115], [68.7270813, 23.84986115], [68.7270813, 23.85013962], [68.72735596, 23.85013962], [68.72735596, 23.85070038], [68.72763824, 23.85070038], [68.72763824, 23.85124969], [68.7279129, 23.85124969], [68.7279129, 23.85208321], [68.72820282, 23.85207939], [68.72820282, 23.85292053], [68.72846985, 23.85291862], [68.72846985, 23.85347176], [68.72875214, 23.85346985], [68.72875214, 23.85430908], [68.72902679, 23.85430908], [68.72902679, 23.85486031], [68.72957611, 23.85486031], [68.72957611, 23.85514069], [68.7298584, 23.85514069], [68.7298584, 23.85541916], [68.73041534, 23.85541725], [68.73041534, 23.85569382], [68.73097229, 23.85569382], [68.73097229, 23.85597229], [68.73152161, 23.85597038], [68.73152161, 23.85625076], [68.73179626, 23.85625076], [68.73179626, 23.85652924], [68.73236084, 23.85652733], [68.73236084, 23.8568058], [68.73291779, 23.8568058], [68.73291779, 23.85708237], [68.7334671, 23.85707855], [68.7334671, 23.85736084], [68.73374939, 23.85736084], [68.73374939, 23.85763931], [68.73430634, 23.85763931], [68.73430634, 23.85791969], [68.73486328, 23.85791588], [68.73486328, 23.85819435], [68.73542023, 23.85819435], [68.73542023, 23.85847282], [68.73568726, 23.85847282], [68.73568726, 23.85874939], [68.73625183, 23.85874939], [68.73625183, 23.85902977], [68.73680878, 23.85902977], [68.73680878, 23.85931015], [68.73708344, 23.85930634], [68.73708344, 23.8595829], [68.73735809, 23.8595829], [68.73735809, 23.85986137], [68.73792267, 23.85985947], [68.73792267, 23.86013985], [68.73847198, 23.86013985], [68.73847198, 23.86042023], [68.73930359, 23.86041641], [68.73930359, 23.86069489], [68.73986053, 23.86069489], [68.73986053, 23.86097145], [68.74013519, 23.86097145], [68.74013519, 23.86069489], [68.74041748, 23.86069489], [68.74041748, 23.86097145], [68.74236298, 23.86097145], [68.74236298, 23.86069489], [68.74346924, 23.86069489], [68.74346924, 23.86041641], [68.74402618, 23.86042023], [68.74402618, 23.86013985], [68.74569702, 23.86013985], [68.74569702, 23.85985947], [68.74680328, 23.85985947], [68.74680328, 23.86013985], [68.74708557, 23.86013794], [68.74708557, 23.86069489], [68.74736023, 23.86069107], [68.74736023, 23.86181068], [68.74764252, 23.86180305], [68.74764252, 23.86208344], [68.74791718, 23.86208344], [68.74791718, 23.86236191], [68.74819183, 23.86236], [68.74819183, 23.86264038], [68.74847412, 23.86263847], [68.74847412, 23.86319351], [68.74874878, 23.86319351], [68.74874878, 23.86347198], [68.74903107, 23.86347008], [68.74903107, 23.86375046], [68.74846649, 23.86375046], [68.74846649, 23.86347008], [68.74791718, 23.86347198], [68.74791718, 23.86319351], [68.7470932, 23.8631897], [68.74708557, 23.86291695], [68.74652863, 23.86291695], [68.74652863, 23.8631897], [68.74624634, 23.86319351], [68.74624634, 23.86347198], [68.74597168, 23.86347008], [68.74597168, 23.86375046], [68.74569702, 23.86375046], [68.74569702, 23.86541939], [68.74597168, 23.86541748], [68.74597168, 23.86597252], [68.74624634, 23.86597061], [68.74624634, 23.86625099], [68.74680328, 23.86625099], [68.74680328, 23.86652946], [68.7470932, 23.86652946], [68.7470932, 23.86680984], [68.74764252, 23.86680794], [68.74764252, 23.8670826], [68.74791718, 23.86708069], [68.74791718, 23.86736107], [68.74819183, 23.86736107], [68.74819183, 23.86763954], [68.74874878, 23.86763954], [68.74874878, 23.86791992], [68.74903107, 23.86791611], [68.74903107, 23.86819458], [68.74930573, 23.86819458], [68.74930573, 23.86847305], [68.74958038, 23.86847305], [68.74958038, 23.86874962], [68.75013733, 23.86874008], [68.75013733, 23.86902809], [68.75041962, 23.86902809], [68.75041962, 23.86930466], [68.75096893, 23.86930466], [68.75096893, 23.86958313], [68.75125122, 23.86958313], [68.75125122, 23.8698616], [68.75180817, 23.8698597], [68.75180817, 23.87014008], [68.75208282, 23.87014008], [68.75208282, 23.87042236], [68.75263214, 23.87042236], [68.75263214, 23.87070274], [68.75291443, 23.87069511], [68.75291443, 23.87097168], [68.75319672, 23.87097168], [68.75319672, 23.87125015], [68.75374603, 23.87125015], [68.75374603, 23.87153053], [68.75402832, 23.87152863], [68.75402832, 23.87180519], [68.75430298, 23.87180519], [68.75430298, 23.87208366], [68.75458527, 23.87208366], [68.75458527, 23.87236023], [68.75514221, 23.87236023], [68.75514221, 23.87264061], [68.75541687, 23.87264061], [68.75541687, 23.8729229], [68.75569153, 23.87291718], [68.75569153, 23.87319374], [68.75624847, 23.87319374], [68.75624847, 23.87347221], [68.75680542, 23.87347221], [68.75680542, 23.87375069], [68.75708008, 23.87375069], [68.75708008, 23.87403107], [68.75763702, 23.87403107], [68.75763702, 23.87430954], [68.75846863, 23.87430573], [68.75846863, 23.87458229], [68.7590332, 23.87458038], [68.7590332, 23.8748703], [68.76125336, 23.8748703], [68.76125336, 23.87541962], [68.75902557, 23.8754158], [68.75902557, 23.87569237], [68.75653076, 23.87569237], [68.75653076, 23.8754158], [68.75541687, 23.87541962], [68.75541687, 23.87514114], [68.75430298, 23.87514114], [68.75430298, 23.8748703], [68.75402832, 23.8748703], [68.75402832, 23.87430954], [68.75374603, 23.87430954], [68.75374603, 23.87403107], [68.75347137, 23.87403107], [68.75347137, 23.87347031], [68.75319672, 23.87347221], [68.75319672, 23.87319374], [68.75291443, 23.87319374], [68.75291443, 23.87291718], [68.75263214, 23.8729229], [68.75263214, 23.87264061], [68.75208282, 23.87264061], [68.75208282, 23.87236023], [68.75180817, 23.87236023], [68.75180817, 23.87208176], [68.75152588, 23.87208366], [68.75152588, 23.87180519], [68.75125122, 23.87180519], [68.75125122, 23.87152863], [68.75096893, 23.87153053], [68.75096893, 23.87125015], [68.75041962, 23.87125015], [68.75041962, 23.87097168], [68.74986267, 23.87097168], [68.74986267, 23.87069511], [68.74903107, 23.87070274], [68.74903107, 23.87042236], [68.74846649, 23.87042236], [68.74846649, 23.87014008], [68.74819183, 23.87014008], [68.74819183, 23.8698597], [68.74764252, 23.8698616], [68.74764252, 23.86958313], [68.74736023, 23.86958313], [68.74736023, 23.86930466], [68.74680328, 23.86930466], [68.74680328, 23.86902809], [68.74652863, 23.86902809], [68.74652863, 23.86874008], [68.74624634, 23.86874962], [68.74624634, 23.86847305], [68.74569702, 23.86847305], [68.74569702, 23.86819458], [68.74541473, 23.86819458], [68.74541473, 23.86791611], [68.74514008, 23.86791992], [68.74514008, 23.86763954], [68.74485779, 23.86763954], [68.74485779, 23.86736107], [68.74430847, 23.86736107], [68.74430847, 23.86708069], [68.74319458, 23.8670826], [68.74319458, 23.86680794], [68.74208069, 23.86680984], [68.74208069, 23.86625099], [68.74180603, 23.86625099], [68.74180603, 23.86597061], [68.74153137, 23.86597252], [68.74153137, 23.86569595], [68.74124908, 23.86569977], [68.74124908, 23.86541939], [68.7409668, 23.86541939], [68.7409668, 23.86514091], [68.74041748, 23.86514091], [68.74041748, 23.86486053], [68.74013519, 23.86486053], [68.74013519, 23.86458588], [68.73986053, 23.86458588], [68.73986053, 23.8643074], [68.73929596, 23.86431122], [68.73929596, 23.86403084], [68.73874664, 23.86403084], [68.73874664, 23.86375046], [68.73819733, 23.86375046], [68.73819733, 23.86347008], [68.73764038, 23.86347198], [68.73764038, 23.86319351], [68.73707581, 23.8631897], [68.73708344, 23.86291695], [68.73652649, 23.8629303], [68.73652649, 23.86264038], [68.73568726, 23.86264038], [68.73568726, 23.86236], [68.73486328, 23.86236191], [68.73486328, 23.86208344], [68.73014069, 23.86208344], [68.73014069, 23.86180305], [68.7298584, 23.86181068], [68.7298584, 23.86124992], [68.72957611, 23.86124992], [68.72957611, 23.86096954], [68.72930908, 23.86097145], [68.72930908, 23.86069489], [68.72902679, 23.86069489], [68.72902679, 23.86041641], [68.72875214, 23.86042023], [68.72875214, 23.86013985], [68.72846222, 23.86013985], [68.72846222, 23.85985947], [68.7279129, 23.85986137], [68.7279129, 23.8595829], [68.7270813, 23.8595829], [68.7270813, 23.85930634], [68.71848297, 23.85931015], [68.71848297, 23.85902977], [68.71819305, 23.85902977], [68.71819305, 23.85874939], [68.7179184, 23.85874939], [68.7179184, 23.85847282], [68.71763611, 23.85847282], [68.71763611, 23.85819435], [68.71708679, 23.85819435], [68.71708679, 23.85791588], [68.71679688, 23.85791969], [68.71679688, 23.85763931], [68.71624756, 23.85763931], [68.71624756, 23.85736084], [68.71208191, 23.85736084], [68.71208191, 23.85763931], [68.70903015, 23.85763931], [68.70903015, 23.85791969], [68.70708466, 23.85791588], [68.70708466, 23.85819435], [68.7048645, 23.85819435], [68.7048645, 23.85791588], [68.70347595, 23.85791969], [68.70347595, 23.85763931], [68.70318604, 23.85763931], [68.70318604, 23.85736084], [68.70291901, 23.85736084], [68.70291901, 23.85679817], [68.70180511, 23.8568058], [68.70180511, 23.85708427], [68.70096588, 23.85707855], [68.70096588, 23.85736084], [68.70041656, 23.85736084], [68.70041656, 23.85763931], [68.69985962, 23.85763931], [68.69985962, 23.85791969], [68.69930267, 23.85791588], [68.69930267, 23.85819435], [68.69875336, 23.85819435], [68.69875336, 23.85847282], [68.69819641, 23.85847282], [68.69819641, 23.85874939], [68.6965332, 23.85874939], [68.6965332, 23.85902977], [68.69596863, 23.85902977], [68.69596863, 23.85931015], [68.69541931, 23.85930634], [68.69541931, 23.8595829], [68.69486237, 23.8595829], [68.69486237, 23.85986137], [68.69431305, 23.85985947], [68.69431305, 23.86013985], [68.69374847, 23.86013985], [68.69374847, 23.86042023], [68.69347382, 23.86041641], [68.69347382, 23.86069489], [68.69291687, 23.86069489], [68.69291687, 23.86097145], [68.68902588, 23.86096954], [68.68902588, 23.86124992], [68.68736267, 23.86124992], [68.68736267, 23.8615303], [68.68374634, 23.8615303], [68.68374634, 23.86181068], [68.67791748, 23.86181068], [68.67791748, 23.8615303], [68.67679596, 23.8615303], [68.67679596, 23.86124992], [68.67485809, 23.86124992], [68.67485809, 23.8615303], [68.67180634, 23.8615303], [68.67180634, 23.86124992], [68.6709671, 23.86124992], [68.6709671, 23.86096954], [68.67041779, 23.86097145], [68.67041779, 23.86069489], [68.66958618, 23.86069489], [68.66958618, 23.86041641], [68.66902924, 23.86042023], [68.66902924, 23.86013985], [68.66874695, 23.86013985], [68.66874695, 23.85985947], [68.66819763, 23.85986137], [68.66819763, 23.8595829], [68.66791534, 23.8595829], [68.66791534, 23.85930634], [68.6673584, 23.85931015], [68.6673584, 23.85902977], [68.66707611, 23.85902977], [68.66707611, 23.85874939], [68.66680908, 23.85874939], [68.66680908, 23.85847282], [68.66625214, 23.85847282], [68.66625214, 23.85819435], [68.66569519, 23.85819435], [68.66569519, 23.85791588], [68.66513824, 23.85791969], [68.66513824, 23.85763931], [68.66430664, 23.85763931], [68.66430664, 23.85791969], [68.66236115, 23.85791588], [68.66236115, 23.85819435], [68.66152954, 23.85819435], [68.66152954, 23.85847282], [68.66014099, 23.85847282], [68.66014099, 23.85791588], [68.66042328, 23.85791969], [68.66042328, 23.85763931], [68.66069794, 23.85763931], [68.66069794, 23.85736084], [68.6609726, 23.85736084], [68.6609726, 23.85707855], [68.66124725, 23.85708237], [68.66124725, 23.8568058], [68.66152954, 23.8568058], [68.66152954, 23.85652733], [68.66236115, 23.85652733], [68.66236115, 23.8568058], [68.6626358, 23.8568058], [68.6626358, 23.85708237], [68.66374969, 23.85708237], [68.66374969, 23.8568058], [68.66402435, 23.8568058], [68.66402435, 23.85652733], [68.66430664, 23.85652733], [68.66430664, 23.8568058], [68.6654129, 23.8568058], [68.6654129, 23.85597229], [68.66513824, 23.85597229], [68.66513824, 23.85541725], [68.66485596, 23.85541916], [68.66485596, 23.85486031], [68.66513824, 23.85486031], [68.66513824, 23.85457993], [68.6654129, 23.85458374], [68.6654129, 23.85430527], [68.66570282, 23.85430908], [68.66570282, 23.85403061], [68.66596985, 23.85403061], [68.66596985, 23.85346985], [68.66625214, 23.85347176], [68.66625214, 23.85263634], [68.66596985, 23.85264015], [68.66596985, 23.85207939], [68.66569519, 23.85208321], [68.66569519, 23.85180664], [68.66486359, 23.85180664], [68.66486359, 23.85152626], [68.66430664, 23.85153008], [68.66430664, 23.85124969], [68.66401672, 23.85124969], [68.66401672, 23.85097122], [68.66347504, 23.85097313], [68.66347504, 23.85069656], [68.66291809, 23.85070038], [68.66291809, 23.85042], [68.66236877, 23.85042], [68.66236877, 23.85013962], [68.66208649, 23.85013962], [68.66208649, 23.84986115], [68.66152954, 23.84986115], [68.66152954, 23.84958076], [68.6609726, 23.84958267], [68.6609726, 23.8493042], [68.66069794, 23.84930992], [68.66069794, 23.84902954], [68.66014099, 23.84902954], [68.66014099, 23.84875107], [68.6598587, 23.84875107], [68.6598587, 23.84847069], [68.65930176, 23.8484726], [68.65930176, 23.84819221], [68.6590271, 23.84819221], [68.6590271, 23.84791756], [68.65847015, 23.84791946], [68.65847015, 23.84762955], [68.6581955, 23.84763908], [68.6581955, 23.84736061], [68.65763855, 23.84736061], [68.65763855, 23.84708023], [68.65736389, 23.84708214], [68.65736389, 23.84680557], [68.65680695, 23.84680939], [68.65680695, 23.84653282], [68.65624237, 23.84653282], [68.65624237, 23.84625053], [68.6554184, 23.84625053], [68.6554184, 23.84597015], [68.65374756, 23.84597015], [68.65374756, 23.84625053], [68.6526413, 23.84625053], [68.6526413, 23.84653282], [68.65180206, 23.84653282], [68.65180206, 23.84680939], [68.65041351, 23.84680557], [68.65041351, 23.84708214], [68.64985657, 23.84708023], [68.64985657, 23.84736061], [68.64958191, 23.84736061], [68.64958191, 23.84791946], [68.64819336, 23.84791946], [68.64819336, 23.84762955], [68.6479187, 23.84763908], [68.6479187, 23.84708214], [68.64819336, 23.84708214], [68.64819336, 23.8465271], [68.64848328, 23.84653282], [68.64848328, 23.84597015], [68.64875031, 23.84597015], [68.64875031, 23.84569359], [68.64902496, 23.84569359], [68.64902496, 23.84541702], [68.64930725, 23.84542274], [68.64930725, 23.84514046], [68.64958191, 23.84514046], [68.64958191, 23.84486008], [68.6498642, 23.84486008], [68.6498642, 23.84458351], [68.65013885, 23.84458351], [68.65013885, 23.84430504], [68.64985657, 23.84431267], [68.64985657, 23.84403038], [68.64958191, 23.84403038], [68.64958191, 23.84431267], [68.64902496, 23.84430504], [68.64902496, 23.84458351], [68.64847565, 23.84458351], [68.64847565, 23.84486008], [68.64819336, 23.84486008], [68.64819336, 23.84514046], [68.6479187, 23.84514046], [68.6479187, 23.84542274], [68.6470871, 23.84541702], [68.6470871, 23.84569359], [68.64653015, 23.84569359], [68.64653015, 23.84597015], [68.64624786, 23.84597015], [68.64624786, 23.84625053], [68.64485931, 23.84625053], [68.64485931, 23.84597015], [68.64458466, 23.84597015], [68.64458466, 23.84569359], [68.64485931, 23.84569359], [68.64485931, 23.84513855], [68.6451416, 23.84514046], [68.6451416, 23.84486008], [68.64624786, 23.84486008], [68.64624786, 23.84458351], [68.64653015, 23.84458351], [68.64653015, 23.84430504], [68.64736938, 23.84431267], [68.64736938, 23.84375191], [68.64763641, 23.84375191], [68.64763641, 23.84347153], [68.6479187, 23.84347153], [68.6479187, 23.84319496], [68.64848328, 23.84320259], [68.64848328, 23.8429184], [68.6479187, 23.8429184], [68.6479187, 23.84263992], [68.64736938, 23.84263992], [68.64736938, 23.84235954], [68.6470871, 23.84236145], [68.6470871, 23.84180641], [68.64679718, 23.84182167], [68.64679718, 23.83958054], [68.64653015, 23.83958244], [68.64653015, 23.83930779], [68.64624786, 23.83930969], [68.64624786, 23.83903122], [68.64597321, 23.83903122], [68.64597321, 23.83876038], [68.64569092, 23.83876038], [68.64569092, 23.83847046], [68.64541626, 23.83847237], [68.64541626, 23.8381958], [68.6451416, 23.8381958], [68.6451416, 23.83791542], [68.64430237, 23.83792114], [68.64430237, 23.83764076], [68.64347076, 23.83764076], [68.64347076, 23.83736038], [68.64263916, 23.83736038], [68.64263916, 23.83708], [68.64125061, 23.83708572], [68.64125061, 23.83680344], [68.64013672, 23.83681107], [68.64013672, 23.83653069], [68.63874817, 23.83653069], [68.63874817, 23.83625031], [68.63735962, 23.83625031], [68.63735962, 23.83596992], [68.63458252, 23.83597183], [68.63458252, 23.83569336], [68.63180542, 23.83569336], [68.63180542, 23.83541679], [68.62708282, 23.83541679], [68.62708282, 23.83569336], [68.62541962, 23.83569336], [68.62541962, 23.83597183], [68.62403107, 23.83596992], [68.62403107, 23.83625031], [68.62236023, 23.83625031], [68.62236023, 23.83653069], [68.62069702, 23.83653069], [68.62069702, 23.83681107], [68.61930847, 23.83680344], [68.61930847, 23.83708572], [68.61818695, 23.83708], [68.61818695, 23.83736038], [68.61680603, 23.83736038], [68.61680603, 23.83764076], [68.61514282, 23.83764076], [68.61514282, 23.83792114], [68.61486053, 23.83792114], [68.61486053, 23.83876038], [68.61458588, 23.83876038], [68.61458588, 23.83903122], [68.61429596, 23.83903122], [68.61429596, 23.83876038], [68.61402893, 23.83876038], [68.61402893, 23.83819008], [68.61374664, 23.8381958], [68.61374664, 23.83791542], [68.61347198, 23.83792114], [68.61347198, 23.83764076], [68.61235809, 23.83764076], [68.61235809, 23.83792114], [68.61208344, 23.83791542], [68.61208344, 23.8381958], [68.61180878, 23.8381958], [68.61180878, 23.83847237], [68.61096954, 23.83847237], [68.61096954, 23.8381958], [68.6048584, 23.8381958], [68.6048584, 23.83847237], [68.60430908, 23.83847046], [68.60430908, 23.83876038], [68.60375214, 23.83876038], [68.60375214, 23.83903122], [68.60320282, 23.83903122], [68.60320282, 23.83930969], [68.60263824, 23.83930779], [68.60263824, 23.83958244], [68.6020813, 23.83958244], [68.6020813, 23.83986092], [68.60235596, 23.83986092], [68.60235596, 23.84041977], [68.6020813, 23.84041786], [68.6020813, 23.8409729], [68.60180664, 23.84097099], [68.60180664, 23.84182167], [68.6020813, 23.84180641], [68.60208893, 23.84375191], [68.60180664, 23.84375191], [68.60180664, 23.84403038], [68.60152435, 23.84402847], [68.60152435, 23.84458351], [68.60124969, 23.84458351], [68.60124969, 23.84486008], [68.60098267, 23.84486008], [68.60098267, 23.84514046], [68.60069275, 23.84514046], [68.60069275, 23.84542274], [68.6001358, 23.84542274], [68.6001358, 23.84653282], [68.60041809, 23.8465271], [68.60041809, 23.84708214], [68.60180664, 23.84708023], [68.60180664, 23.84736061], [68.60236359, 23.84736061], [68.60236359, 23.84763908], [68.60263824, 23.84762955], [68.60263824, 23.84791946], [68.6029129, 23.84791756], [68.6029129, 23.84819221], [68.60319519, 23.84819221], [68.60319519, 23.8484726], [68.60346985, 23.84847069], [68.60346985, 23.84875107], [68.60375214, 23.84875107], [68.60375214, 23.84902954], [68.60402679, 23.84902954], [68.60402679, 23.84930992], [68.60430908, 23.8493042], [68.60430908, 23.84958267], [68.60457611, 23.84958076], [68.60457611, 23.84986115], [68.60430908, 23.84986115], [68.60430908, 23.85013962], [68.60375214, 23.85013962], [68.60375214, 23.84986115], [68.60346985, 23.84986115], [68.60346985, 23.84958076], [68.60319519, 23.84958267], [68.60319519, 23.84902763], [68.60263824, 23.84902954], [68.60263824, 23.84875107], [68.60235596, 23.84875107], [68.60235596, 23.84847069], [68.6020813, 23.8484726], [68.6020813, 23.84819221], [68.60180664, 23.84819221], [68.60180664, 23.84791756], [68.59986115, 23.84791946], [68.59986115, 23.84762955], [68.59902954, 23.84763908], [68.59902954, 23.84736061], [68.59874725, 23.84736061], [68.59874725, 23.84569168], [68.59902954, 23.84569359], [68.59902954, 23.84513855], [68.59929657, 23.84514046], [68.59929657, 23.84486008], [68.59958649, 23.84486008], [68.59958649, 23.84458351], [68.60041809, 23.84458351], [68.60041809, 23.84430504], [68.60069275, 23.84431267], [68.60069275, 23.84403038], [68.60098267, 23.84403038], [68.60098267, 23.84263992], [68.60069275, 23.84263992], [68.60069275, 23.84124947], [68.60041809, 23.84124947], [68.60041809, 23.84041977], [68.6001358, 23.84041977], [68.6001358, 23.83958054], [68.59708405, 23.83958244], [68.59708405, 23.83930779], [68.59597015, 23.83930969], [68.59597015, 23.83903122], [68.59485626, 23.83903122], [68.59485626, 23.83876038], [68.59375, 23.83876038], [68.59375, 23.83847046], [68.59263611, 23.83847237], [68.59263611, 23.8381958], [68.5918045, 23.8381958], [68.5918045, 23.83791542], [68.59041595, 23.83792114], [68.59041595, 23.83764076], [68.59014893, 23.83764076], [68.59014893, 23.83736038], [68.58985901, 23.83736038], [68.58985901, 23.83708], [68.58930206, 23.83708572], [68.58930206, 23.83680344], [68.58875275, 23.83681107], [68.58875275, 23.83653069], [68.5881958, 23.83653069], [68.5881958, 23.83625031], [68.58790588, 23.83625031], [68.58790588, 23.83596992], [68.58763885, 23.83597183], [68.58763885, 23.83541679], [68.58735657, 23.83542061], [68.58735657, 23.83514023], [68.58680725, 23.83514023], [68.58680725, 23.83457947], [68.58652496, 23.83458328], [68.58652496, 23.83430481], [68.58625031, 23.83430481], [68.58625031, 23.83402824], [68.58598328, 23.83403015], [68.58598328, 23.83374977], [68.5854187, 23.83374977], [68.5854187, 23.83346939], [68.58513641, 23.8334713], [68.58513641, 23.83319473], [68.58486176, 23.83319473], [68.58486176, 23.83263969], [68.5845871, 23.83263969], [68.5845871, 23.83236122], [68.58429718, 23.83236122], [68.58429718, 23.83208275], [68.58403015, 23.83208275], [68.58403015, 23.83180618], [68.58374786, 23.8318119], [68.58374786, 23.83152962], [68.58347321, 23.83152962], [68.58347321, 23.83097076], [68.58319092, 23.83097267], [68.58319092, 23.8306942], [68.58291626, 23.8306942], [68.58291626, 23.83041763], [68.5826416, 23.83041954], [68.5826416, 23.83013916], [68.58235931, 23.83013916], [68.58235931, 23.82986069], [68.58207703, 23.82986069], [68.58207703, 23.82957077], [68.58180237, 23.82958412], [68.58180237, 23.82930565], [68.58152771, 23.82930946], [68.58152771, 23.82902908], [68.58125305, 23.82902908], [68.58125305, 23.82875061], [68.58096313, 23.82875061], [68.58096313, 23.82846832], [68.58069611, 23.82847214], [68.58069611, 23.82819366], [68.58041382, 23.82819366], [68.58041382, 23.82763863], [68.58013916, 23.82764053], [68.58013916, 23.82707977], [68.5798645, 23.82708359], [68.5798645, 23.82652855], [68.57958221, 23.82653046], [68.57958221, 23.8259697], [68.57875061, 23.8259716], [68.57875061, 23.82569695], [68.57847595, 23.82570076], [68.57847595, 23.82542038], [68.57791901, 23.82542038], [68.57791901, 23.82514], [68.57763672, 23.82514], [68.57763672, 23.82485962], [68.57736206, 23.82486153], [68.57736206, 23.82430458], [68.57707977, 23.8243103], [68.57707977, 23.82402992], [68.57681274, 23.82402992], [68.57681274, 23.82374954], [68.57653046, 23.82374954], [68.57653046, 23.82347107], [68.57624817, 23.82347488], [68.57624817, 23.82291412], [68.57596588, 23.82291985], [68.57596588, 23.82263947], [68.57569122, 23.82263947], [68.57569122, 23.82236099], [68.57541656, 23.82236099], [68.57541656, 23.82180977], [68.57514954, 23.82180977], [68.57514954, 23.82152939], [68.57485962, 23.82152939], [68.57485962, 23.82125092], [68.57458496, 23.82125092], [68.57458496, 23.82069206], [68.57430267, 23.82069206], [68.57430267, 23.82013893], [68.57402802, 23.82014275], [68.57402802, 23.81958008], [68.57375336, 23.81958389], [68.57375336, 23.81902695], [68.57347107, 23.81903267], [68.57347107, 23.81847191], [68.57319641, 23.81847191], [68.57319641, 23.81791687], [68.57290649, 23.81792259], [68.57290649, 23.81736183], [68.57263947, 23.81736183], [68.57263947, 23.81680489], [68.57236481, 23.81680489], [68.57236481, 23.81624985], [68.57208252, 23.81624985], [68.57208252, 23.81568909], [68.57180786, 23.81569481], [68.57180786, 23.81541634], [68.5715332, 23.81541824], [68.5715332, 23.81485748], [68.57125092, 23.8148613], [68.57125092, 23.81458282], [68.57096863, 23.81459045], [68.57096863, 23.81402969], [68.57068634, 23.81402969], [68.57068634, 23.81319046], [68.57041931, 23.81319427], [68.57041931, 23.8120842], [68.57013702, 23.8120842], [68.57013702, 23.81097221], [68.56986237, 23.81097221], [68.56986237, 23.81041527], [68.56958008, 23.81042099], [68.56958008, 23.80957985], [68.56930542, 23.80958557], [68.56930542, 23.80902863], [68.56902313, 23.80903053], [68.56902313, 23.80820084], [68.56874847, 23.80820084], [68.56874847, 23.80764008], [68.56846619, 23.80764008], [68.56846619, 23.80708122], [68.56819153, 23.80708122], [68.56819153, 23.80652809], [68.56791687, 23.80653191], [68.56791687, 23.80569267], [68.56764221, 23.80569458], [68.56764221, 23.80486107], [68.56735992, 23.80486107], [68.56735992, 23.80431175], [68.5670929, 23.80431175], [68.5670929, 23.80347061], [68.56680298, 23.80347252], [68.56680298, 23.80291748], [68.56652832, 23.80291939], [68.56652832, 23.80236053], [68.56624603, 23.80236053], [68.56624603, 23.80153084], [68.56595612, 23.80153084], [68.56595612, 23.80096817], [68.56569672, 23.80097198], [68.56569672, 23.80013847], [68.5654068, 23.80014038], [68.5654068, 23.79959106], [68.56513977, 23.79959106], [68.56513977, 23.7990303], [68.56485748, 23.7990303], [68.56485748, 23.79846954], [68.56458282, 23.79847145], [68.56458282, 23.79791451], [68.56430817, 23.79792023], [68.56430817, 23.79763985], [68.56402588, 23.79763985], [68.56402588, 23.79735947], [68.56375122, 23.79736137], [68.56375122, 23.79680443], [68.56346893, 23.79681015], [68.56346893, 23.79652023], [68.56319427, 23.79652786], [68.56319427, 23.79624939], [68.56291962, 23.79624939], [68.56291962, 23.79569054], [68.56263733, 23.79569244], [68.56263733, 23.79541588], [68.56236267, 23.79541969], [68.56236267, 23.79514122], [68.56208038, 23.79514122], [68.56208038, 23.79458046], [68.56180573, 23.79458237], [68.56180573, 23.7943058], [68.56153107, 23.79430962], [68.56153107, 23.79403114], [68.56124878, 23.79403114], [68.56124878, 23.79375076], [68.56096649, 23.79375076], [68.56096649, 23.79319191], [68.56069183, 23.79319382], [68.56069183, 23.79291725], [68.56041718, 23.79292107], [68.56041718, 23.79264069], [68.56014252, 23.79264069], [68.56014252, 23.79236031], [68.55986023, 23.79236031], [68.55986023, 23.79208183], [68.55930328, 23.79208374], [68.55930328, 23.79180527], [68.55902863, 23.7918129], [68.55902863, 23.79153252], [68.55874634, 23.79153252], [68.55874634, 23.79125023], [68.55847168, 23.79125023], [68.55847168, 23.79071045], [68.55819702, 23.79071045], [68.55819702, 23.79042244], [68.5579071, 23.79042244], [68.5579071, 23.79014015], [68.55764008, 23.79014015], [68.55764008, 23.78957748], [68.55735779, 23.78958321], [68.55735779, 23.78930473], [68.55708313, 23.78930473], [68.55708313, 23.78902817], [68.55680847, 23.78902817], [68.55680847, 23.78847122], [68.55652618, 23.78847313], [68.55652618, 23.78819466], [68.55625153, 23.78819466], [68.55625153, 23.78791618], [68.55596924, 23.78791809], [68.55596924, 23.78736115], [68.55568695, 23.78736115], [68.55568695, 23.78680992], [68.55541992, 23.78680992], [68.55541992, 23.78625107], [68.55513763, 23.78625107], [68.55513763, 23.78569031], [68.55486298, 23.78569412], [68.55486298, 23.78513908], [68.55458069, 23.78514099], [68.55458069, 23.78486061], [68.55430603, 23.78486061], [68.55430603, 23.78430939], [68.55401611, 23.78430939], [68.55401611, 23.78403091], [68.55374908, 23.78403091], [68.55374908, 23.78375053], [68.55319214, 23.78375053], [68.55319214, 23.78347015], [68.55291748, 23.78347206], [68.55291748, 23.78291512], [68.55264282, 23.78292084], [68.55264282, 23.78264046], [68.55291748, 23.78264046], [68.55291748, 23.78236008], [68.55263519, 23.78236389], [68.55263519, 23.78180313], [68.55236053, 23.78181076], [68.55236053, 23.78125], [68.55208588, 23.78125], [68.55208588, 23.78070068], [68.55179596, 23.78070068], [68.55179596, 23.7804203], [68.55152893, 23.7804203], [68.55152893, 23.78013992], [68.55124664, 23.78013992], [68.55124664, 23.77985954], [68.55097198, 23.77986145], [68.55097198, 23.77958107], [68.55069733, 23.77958107], [68.55069733, 23.77930641], [68.55042267, 23.77931023], [68.55042267, 23.77902985], [68.55014038, 23.77902985], [68.55014038, 23.77874947], [68.54985809, 23.77874947], [68.54985809, 23.77848053], [68.54957581, 23.77848053], [68.54957581, 23.77819252], [68.54930878, 23.77819443], [68.54930878, 23.77791595], [68.54902649, 23.77792168], [68.54902649, 23.77763939], [68.54875183, 23.77763939], [68.54875183, 23.77736092], [68.54846954, 23.77736092], [68.54846954, 23.77708054], [68.54819489, 23.77708244], [68.54819489, 23.77680588], [68.54792023, 23.7768116], [68.54792023, 23.77625084], [68.54763794, 23.77625084], [68.54763794, 23.77597046], [68.54736328, 23.77597237], [68.54736328, 23.77541733], [68.54708099, 23.77541924], [68.54708099, 23.77486038], [68.54680634, 23.77486038], [68.54680634, 23.77457809], [68.54652405, 23.77458382], [68.54652405, 23.77402878], [68.54624939, 23.77403069], [68.54624939, 23.77375031], [68.5459671, 23.77375031], [68.5459671, 23.77319908], [68.54569244, 23.77319908], [68.54569244, 23.77264023], [68.54541779, 23.77264023], [68.54541779, 23.77207947], [68.5451355, 23.77208328], [68.5451355, 23.77152824], [68.54485321, 23.77153015], [68.54485321, 23.77096939], [68.54458618, 23.7709713], [68.54458618, 23.77069664], [68.54430389, 23.77069664], [68.54430389, 23.77041435], [68.54402924, 23.77042007], [68.54402924, 23.77013969], [68.54374695, 23.77013969], [68.54374695, 23.76986122], [68.54319763, 23.76986122], [68.54319763, 23.76902962], [68.54292297, 23.76902962], [68.54292297, 23.76847076], [68.54264069, 23.76847267], [68.54264069, 23.76819229], [68.5423584, 23.76819229], [68.5423584, 23.76763916], [68.54207611, 23.76764107], [68.54207611, 23.76736069], [68.54180908, 23.76736069], [68.54180908, 23.76708031], [68.54152679, 23.76708221], [68.54152679, 23.76652718], [68.54125214, 23.76654053], [68.54125214, 23.76625061], [68.54096985, 23.76625061], [68.54096985, 23.76597023], [68.54069519, 23.76597023], [68.54069519, 23.7654171], [68.5404129, 23.76542282], [68.5404129, 23.76486015], [68.54013824, 23.76486015], [68.54013824, 23.76430511], [68.53985596, 23.76431274], [68.53985596, 23.76403046], [68.5395813, 23.76403046], [68.5395813, 23.76348114], [68.53930664, 23.76348114], [68.53930664, 23.76291847], [68.53901672, 23.76291847], [68.53901672, 23.76263809], [68.53874969, 23.76263809], [68.53874969, 23.76208115], [68.53847504, 23.76208305], [68.53847504, 23.76180649], [68.53819275, 23.7618084], [68.53819275, 23.76152992], [68.53791809, 23.76152992], [68.53791809, 23.76097107], [68.5376358, 23.76097298], [68.5376358, 23.76041794], [68.53736115, 23.76041794], [68.53736115, 23.76013947], [68.53708649, 23.76013947], [68.53708649, 23.75986099], [68.53679657, 23.75986099], [68.53679657, 23.75958061], [68.53652954, 23.75958252], [68.53652954, 23.75902557], [68.53624725, 23.75902939], [68.53624725, 23.75875092], [68.5359726, 23.75875092], [68.5359726, 23.75847244], [68.53569794, 23.75847244], [68.53569794, 23.7579174], [68.53542328, 23.75792122], [68.53542328, 23.75764084], [68.53514099, 23.75764084], [68.53514099, 23.75708008], [68.5348587, 23.7570858], [68.5348587, 23.75680351], [68.53457642, 23.75681114], [68.53457642, 23.75653076], [68.5340271, 23.75653076], [68.5340271, 23.75625038], [68.53347015, 23.75625038], [68.53347015, 23.75597], [68.5320816, 23.75597], [68.5320816, 23.75625038], [68.53069305, 23.75625038], [68.53069305, 23.75597], [68.5304184, 23.75597191], [68.5304184, 23.75569344], [68.52984619, 23.75570107], [68.52984619, 23.75542068], [68.52902985, 23.75542068], [68.52902985, 23.75570107], [68.52874756, 23.75569344], [68.52874756, 23.75597191], [68.5284729, 23.75597], [68.5284729, 23.75625038], [68.52791595, 23.75625038], [68.52791595, 23.75653076], [68.5276413, 23.75653076], [68.5276413, 23.75681114], [68.52708435, 23.75680351], [68.52708435, 23.7570858], [68.52680206, 23.7570858], [68.52680206, 23.75736046], [68.52625275, 23.75735092], [68.52625275, 23.75792122], [68.52597046, 23.7579174], [68.52597046, 23.75819588], [68.5256958, 23.75819016], [68.5256958, 23.75875092], [68.52540588, 23.75875092], [68.52540588, 23.75902939], [68.52513885, 23.75902557], [68.52513885, 23.7606945], [68.52540588, 23.76069069], [68.52540588, 23.76124954], [68.5256958, 23.76124954], [68.5256958, 23.76263809], [68.52597046, 23.76263809], [68.52597046, 23.76375008], [68.52625275, 23.76375008], [68.52625275, 23.76625061], [68.5265274, 23.76625061], [68.5265274, 23.76680946], [68.52680969, 23.76680946], [68.52680969, 23.76875114], [68.5265274, 23.76874924], [68.5265274, 23.76958275], [68.52680206, 23.76958275], [68.52680969, 23.77124977], [68.5265274, 23.77124977], [68.5265274, 23.77264023], [68.52625275, 23.77263641], [68.52625275, 23.77347183], [68.52597046, 23.77346992], [68.52597046, 23.77375031], [68.5256958, 23.77375031], [68.5256958, 23.77430916], [68.52540588, 23.77430916], [68.52540588, 23.77514076], [68.52513885, 23.77514076], [68.52513885, 23.77569389], [68.5248642, 23.77569389], [68.5248642, 23.77597237], [68.52458191, 23.77597046], [68.52458191, 23.77625084], [68.52430725, 23.77625084], [68.52430725, 23.7768116], [68.52402496, 23.77680588], [68.52402496, 23.77708244], [68.52347565, 23.77708244], [68.52348328, 23.77736092], [68.5229187, 23.77736092], [68.5229187, 23.77763939], [68.52236176, 23.77763939], [68.52236176, 23.77819443], [68.5220871, 23.77819252], [68.5220871, 23.77848053], [68.52153015, 23.77848053], [68.52153015, 23.77874947], [68.52097321, 23.77874947], [68.52097321, 23.77902985], [68.5201416, 23.77902985], [68.5201416, 23.77931023], [68.51902771, 23.77930641], [68.51902771, 23.77958107], [68.51875305, 23.77958107], [68.51875305, 23.77986145], [68.51847076, 23.77985954], [68.51847076, 23.78013992], [68.51819611, 23.78013992], [68.51819611, 23.7804203], [68.51790619, 23.7804203], [68.51790619, 23.78070068], [68.51735687, 23.78070068], [68.51735687, 23.78181076], [68.51708221, 23.78180313], [68.51708221, 23.78208351], [68.51680756, 23.7820797], [68.51680756, 23.78264046], [68.51652527, 23.78263855], [68.51652527, 23.78319359], [68.51625061, 23.78318977], [68.51625061, 23.78403091], [68.51652527, 23.78402519], [68.51652527, 23.78458595], [68.51625061, 23.78458023], [68.51625061, 23.78486061], [68.51541901, 23.78486061], [68.51541901, 23.78541946], [68.51569366, 23.78541756], [68.51569366, 23.7859726], [68.51597595, 23.78597069], [68.51597595, 23.78652954], [68.51625061, 23.78652763], [68.51625061, 23.78847313], [68.5165329, 23.78847122], [68.5165329, 23.79042244], [68.51680756, 23.79042244], [68.51680756, 23.79071045], [68.51708221, 23.79069519], [68.51708221, 23.79097176], [68.51790619, 23.79097176], [68.51790619, 23.79125023], [68.51763916, 23.79125023], [68.51763916, 23.79236031], [68.51735687, 23.79236031], [68.51735687, 23.79375076], [68.51763916, 23.79375076], [68.51763916, 23.79486084], [68.51790619, 23.79486084], [68.51790619, 23.79541969], [68.51819611, 23.79541588], [68.51819611, 23.79569244], [68.51875305, 23.79569244], [68.51875305, 23.79597473], [68.51902771, 23.79597092], [68.51902771, 23.79624939], [68.51930237, 23.79624939], [68.51930237, 23.79652786], [68.51985931, 23.79652023], [68.51985931, 23.79681015], [68.5201416, 23.79680443], [68.5201416, 23.79736137], [68.52068329, 23.79735947], [68.52068329, 23.79763985], [68.52153015, 23.79763985], [68.52153015, 23.79792023], [68.5220871, 23.79791451], [68.5220871, 23.79819679], [68.52263641, 23.79819679], [68.52263641, 23.79847145], [68.5229187, 23.79846954], [68.5229187, 23.79874992], [68.52348328, 23.79874992], [68.52348328, 23.7990303], [68.52404022, 23.7990303], [68.52404022, 23.79931068], [68.52430725, 23.79931068], [68.52430725, 23.79959106], [68.5248642, 23.79958344], [68.5248642, 23.79986191], [68.52513885, 23.79985809], [68.52513885, 23.80014038], [68.52540588, 23.80014038], [68.52540588, 23.80042076], [68.52791595, 23.80042076], [68.52791595, 23.80014038], [68.53098297, 23.80014038], [68.53098297, 23.80042076], [68.53125, 23.80041885], [68.53125, 23.80097198], [68.53151703, 23.80096817], [68.53151703, 23.80153084], [68.53180695, 23.80153084], [68.53180695, 23.80180931], [68.5320816, 23.80180931], [68.5320816, 23.80236053], [68.53235626, 23.80236053], [68.53235626, 23.80291939], [68.53263855, 23.80291748], [68.53263855, 23.80319405], [68.53291321, 23.80318832], [68.53291321, 23.80374908], [68.53320312, 23.80374908], [68.53320312, 23.80402946], [68.53347015, 23.80402946], [68.53347015, 23.80431175], [68.53375244, 23.80431175], [68.53375244, 23.80486107], [68.5340271, 23.80486107], [68.5340271, 23.80569458], [68.53430176, 23.80569458], [68.53430939, 23.80597115], [68.5348587, 23.80597115], [68.5348587, 23.80624962], [68.53514099, 23.80624962], [68.53514099, 23.80792046], [68.5348587, 23.80792046], [68.5348587, 23.80903053], [68.53458405, 23.80902863], [68.53458405, 23.80958557], [68.53430939, 23.80957985], [68.53430939, 23.81125069], [68.53457642, 23.81125069], [68.53457642, 23.81153107], [68.5348587, 23.81153107], [68.5348587, 23.81180954], [68.53514099, 23.81180954], [68.53514099, 23.81236076], [68.53542328, 23.81236076], [68.53542328, 23.81264114], [68.53569794, 23.81263924], [68.53569794, 23.81319427], [68.53624725, 23.81319427], [68.53624725, 23.81347275], [68.53652954, 23.81347084], [68.53652954, 23.81402969], [68.53679657, 23.81402969], [68.53679657, 23.81459045], [68.53708649, 23.81458282], [68.53708649, 23.8148613], [68.53736115, 23.81485748], [68.53736115, 23.81513977], [68.53708649, 23.81513977], [68.53708649, 23.81541824], [68.53652954, 23.81541824], [68.53652954, 23.81513977], [68.53624725, 23.81513977], [68.53624725, 23.81459045], [68.53598022, 23.81459045], [68.53598022, 23.81402969], [68.53542328, 23.81402969], [68.53542328, 23.81375122], [68.53514099, 23.81375122], [68.53514099, 23.81319046], [68.5348587, 23.81319427], [68.5348587, 23.81263924], [68.53457642, 23.81264114], [68.53457642, 23.81236076], [68.53430176, 23.81236076], [68.53430176, 23.81180954], [68.53375244, 23.81180954], [68.53375244, 23.81153107], [68.53347015, 23.81153107], [68.53347015, 23.80957985], [68.53375244, 23.80958557], [68.53375244, 23.80902863], [68.5340271, 23.80903053], [68.5340271, 23.80792046], [68.53430176, 23.80792046], [68.53430176, 23.8073597], [68.5340271, 23.8073616], [68.5340271, 23.80708122], [68.53375244, 23.80708122], [68.53375244, 23.80652809], [68.53347015, 23.80653191], [68.53347015, 23.80624962], [68.5331955, 23.80624962], [68.5331955, 23.80597115], [68.53291321, 23.80597115], [68.53291321, 23.80513954], [68.53263855, 23.80513954], [68.53263855, 23.80458069], [68.53236389, 23.8045826], [68.53236389, 23.80430603], [68.5320816, 23.80431175], [68.5320816, 23.80374908], [68.53180695, 23.80374908], [68.53180695, 23.80347061], [68.53152466, 23.80347252], [68.53152466, 23.80291748], [68.53125, 23.80291939], [68.53125, 23.80265045], [68.53098297, 23.80265045], [68.53098297, 23.80207825], [68.53069305, 23.80208397], [68.53069305, 23.8018055], [68.5304184, 23.80180931], [68.5304184, 23.80153084], [68.53013611, 23.80153084], [68.53013611, 23.80125046], [68.52902985, 23.80125046], [68.52902985, 23.80153084], [68.52819824, 23.80153084], [68.52819824, 23.80180931], [68.52708435, 23.8018055], [68.52708435, 23.80208397], [68.52597046, 23.80207825], [68.52597046, 23.80236053], [68.5256958, 23.80236053], [68.5256958, 23.80265045], [68.52540588, 23.80265045], [68.52540588, 23.80374908], [68.52513885, 23.80374908], [68.52513885, 23.80513954], [68.5248642, 23.80513954], [68.5248642, 23.80569458], [68.52458191, 23.80569458], [68.52458191, 23.80597115], [68.52430725, 23.80597115], [68.52430725, 23.80624962], [68.52402496, 23.80624962], [68.52402496, 23.80680466], [68.52375031, 23.80680466], [68.52375031, 23.8073616], [68.52348328, 23.8073597], [68.52348328, 23.80764008], [68.52319336, 23.80764008], [68.52319336, 23.80792046], [68.5229187, 23.80791664], [68.5229187, 23.80847168], [68.52263641, 23.80846024], [68.52263641, 23.80875015], [68.52236176, 23.80875015], [68.52236176, 23.80931091], [68.5220871, 23.80931091], [68.5220871, 23.81014061], [68.52180481, 23.8101387], [68.52180481, 23.81097221], [68.52153015, 23.81097031], [68.52153015, 23.81153107], [68.52179718, 23.81153107], [68.52179718, 23.81236076], [68.5220871, 23.81236076], [68.5220871, 23.81291962], [68.52236176, 23.81291962], [68.52236176, 23.81375122], [68.52263641, 23.81375122], [68.52263641, 23.81459045], [68.5229187, 23.81458282], [68.5229187, 23.81597137], [68.52319336, 23.81596756], [68.52319336, 23.81624985], [68.5229187, 23.81624985], [68.5229187, 23.81708336], [68.52263641, 23.81708145], [68.52263641, 23.81764984], [68.52236176, 23.81764984], [68.52236176, 23.81792259], [68.52179718, 23.81792259], [68.52179718, 23.81820107], [68.52153015, 23.81819534], [68.52153015, 23.81847191], [68.52124786, 23.81847191], [68.52124786, 23.81875038], [68.52097321, 23.81875038], [68.52097321, 23.81903267], [68.52068329, 23.81903267], [68.52068329, 23.81931114], [68.5201416, 23.81930542], [68.5201416, 23.81958389], [68.51957703, 23.81958008], [68.51957703, 23.81986046], [68.51902771, 23.81986046], [68.51902771, 23.82014275], [68.51875305, 23.82014275], [68.51875305, 23.82042122], [68.51819611, 23.8204174], [68.51819611, 23.82069206], [68.51790619, 23.82069016], [68.51790619, 23.82125092], [68.51708221, 23.82125092], [68.51708221, 23.82152939], [68.51625061, 23.82152939], [68.51625061, 23.82180977], [68.51569366, 23.82180405], [68.51569366, 23.82208252], [68.51541901, 23.82208061], [68.51541901, 23.82236099], [68.51486206, 23.82236099], [68.51486206, 23.82263947], [68.51541901, 23.82263947], [68.51541901, 23.82291985], [68.51513672, 23.82291412], [68.51513672, 23.82347488], [68.51486969, 23.82347107], [68.51486969, 23.82402992], [68.51513672, 23.82402611], [68.51513672, 23.82486153], [68.51597595, 23.82485962], [68.51597595, 23.82514], [68.5165329, 23.82514], [68.5165329, 23.82542038], [68.51735687, 23.82542038], [68.51735687, 23.82570076], [68.51791382, 23.82569695], [68.51791382, 23.8259716], [68.51847076, 23.8259697], [68.51847076, 23.82625008], [68.51930237, 23.82625008], [68.51930237, 23.82653046], [68.52236176, 23.82653046], [68.52236176, 23.82681847], [68.52319336, 23.82680511], [68.52319336, 23.82708359], [68.52402496, 23.82708359], [68.52402496, 23.82736015], [68.52680969, 23.82736015], [68.52680969, 23.82764053], [68.53125, 23.82764053], [68.53125, 23.82792091], [68.53430176, 23.8279171], [68.53430939, 23.82819366], [68.5348587, 23.82819366], [68.5348587, 23.82847214], [68.53569794, 23.82846832], [68.53569794, 23.82875061], [68.53624725, 23.82875061], [68.53624725, 23.82902908], [68.53679657, 23.82902908], [68.53679657, 23.82930946], [68.53736115, 23.82930565], [68.53736115, 23.82958412], [68.5376358, 23.82957077], [68.5376358, 23.82986069], [68.53791809, 23.82986069], [68.53791809, 23.83041954], [68.53819275, 23.83041573], [68.53819275, 23.83097267], [68.53848267, 23.83097076], [68.53848267, 23.83124924], [68.53930664, 23.83124924], [68.53930664, 23.83152962], [68.53985596, 23.83152962], [68.53985596, 23.8318119], [68.54013824, 23.83180618], [68.54013824, 23.83208275], [68.54069519, 23.83208275], [68.54069519, 23.83236122], [68.54096985, 23.83236122], [68.54096985, 23.83263969], [68.54152679, 23.83263016], [68.54152679, 23.83292007], [68.54208374, 23.83291626], [68.54208374, 23.83319473], [68.54264069, 23.83319473], [68.54264069, 23.8334713], [68.54291534, 23.8334713], [68.54291534, 23.83374977], [68.54319763, 23.83374977], [68.54319763, 23.83403015], [68.54458618, 23.83402824], [68.54458618, 23.83430481], [68.54486084, 23.83430481], [68.54486084, 23.83458328], [68.5451355, 23.83458328], [68.5451355, 23.83486176], [68.54541779, 23.83485985], [68.54541779, 23.83514023], [68.54569244, 23.83514023], [68.54569244, 23.83542061], [68.54597473, 23.83541679], [68.54597473, 23.83569336], [68.54652405, 23.83569336], [68.54652405, 23.83597183], [68.54680634, 23.83596992], [68.54680634, 23.83625031], [68.54708099, 23.83625031], [68.54708099, 23.83653069], [68.54736328, 23.83653069], [68.54736328, 23.83681107], [68.54763794, 23.83680344], [68.54763794, 23.83708572], [68.54792023, 23.83708], [68.54792023, 23.83736038], [68.54818726, 23.83736038], [68.54818726, 23.83764076], [68.54846954, 23.83764076], [68.54846954, 23.83792114], [68.54875183, 23.83791542], [68.54875183, 23.8381958], [68.54902649, 23.8381958], [68.54902649, 23.83847237], [68.54930878, 23.83847046], [68.54930878, 23.83876038], [68.54957581, 23.83876038], [68.54957581, 23.83903122], [68.54985809, 23.83903122], [68.54985809, 23.83930969], [68.55014038, 23.83930969], [68.55014038, 23.83986092], [68.55041504, 23.83986092], [68.55041504, 23.84013939], [68.55069733, 23.84013939], [68.55069733, 23.84069443], [68.55097198, 23.84069443], [68.55097198, 23.84124947], [68.55124664, 23.84124947], [68.55124664, 23.84236145], [68.55152893, 23.84235954], [68.55152893, 23.84320259], [68.55179596, 23.84320259], [68.55179596, 23.84403038], [68.55208588, 23.84402847], [68.55208588, 23.84458351], [68.55236053, 23.84456825], [68.55236053, 23.84514046], [68.55263519, 23.84513855], [68.55263519, 23.84569359], [68.55291748, 23.84569168], [68.55291748, 23.84625053], [68.55319214, 23.84625053], [68.55319214, 23.84680939], [68.5534668, 23.84680939], [68.5534668, 23.84736061], [68.55374908, 23.84736061], [68.55374908, 23.8484726], [68.55401611, 23.84847069], [68.55401611, 23.84930992], [68.55430603, 23.84930992], [68.55430603, 23.85013962], [68.55458069, 23.85013962], [68.55458069, 23.85070038], [68.55486298, 23.85070038], [68.55486298, 23.85124969], [68.55513763, 23.85124969], [68.55513763, 23.85180664], [68.55541992, 23.85180092], [68.55541992, 23.85264015], [68.55568695, 23.85264015], [68.55568695, 23.85320091], [68.55596924, 23.85320091], [68.55596924, 23.85403061], [68.55625153, 23.8540287], [68.55625153, 23.85458374], [68.55652618, 23.85457993], [68.55652618, 23.85486031], [68.55680847, 23.85486031], [68.55680847, 23.85541916], [68.55708313, 23.85541725], [68.55708313, 23.85569382], [68.55735779, 23.8556881], [68.55735779, 23.85625076], [68.55764008, 23.85625076], [68.55764008, 23.85652924], [68.55791473, 23.85652733], [68.55791473, 23.8568058], [68.55819702, 23.8568058], [68.55819702, 23.85708237], [68.55847168, 23.85707855], [68.55847168, 23.85736084], [68.55902863, 23.85736084], [68.55902863, 23.85763931], [68.55930328, 23.85763931], [68.55930328, 23.85791969], [68.55958557, 23.85791588], [68.55958557, 23.85819435], [68.56041718, 23.85819435], [68.56041718, 23.85847282], [68.56096649, 23.85847282], [68.56096649, 23.85874939], [68.56124878, 23.85874939], [68.56124878, 23.85902977], [68.56181335, 23.85902977], [68.56181335, 23.85931015], [68.56208038, 23.85930634], [68.56208038, 23.8595829], [68.56236267, 23.8595829], [68.56236267, 23.85986137], [68.56263733, 23.85985947], [68.56263733, 23.86013985], [68.56291962, 23.86013985], [68.56291962, 23.86042023], [68.56319427, 23.86041641], [68.56319427, 23.86069489], [68.56346893, 23.86069489], [68.56346893, 23.86097145], [68.56375122, 23.86096954], [68.56375122, 23.86124992], [68.56402588, 23.86124992], [68.56402588, 23.8615303], [68.56430817, 23.8615303], [68.56430817, 23.86181068], [68.56458282, 23.86180305], [68.56458282, 23.86208344], [68.56485748, 23.86208344], [68.56485748, 23.86236191], [68.56513977, 23.86236], [68.56513977, 23.86264038], [68.5654068, 23.86264038], [68.5654068, 23.8629303], [68.56569672, 23.86291695], [68.56569672, 23.86319351], [68.56595612, 23.8631897], [68.56595612, 23.86375046], [68.56625366, 23.86375046], [68.56625366, 23.86458588], [68.56652832, 23.86458015], [68.56652832, 23.86514091], [68.56680298, 23.86514091], [68.56680298, 23.86625099], [68.56708527, 23.86624718], [68.56708527, 23.86763954], [68.56735992, 23.86763954], [68.56735992, 23.86819458], [68.56764221, 23.86819458], [68.56764221, 23.86958313], [68.56791687, 23.86958313], [68.56791687, 23.87097168], [68.56819153, 23.87097168], [68.56819153, 23.87208366], [68.56847382, 23.87208366], [68.56847382, 23.87319374], [68.56874847, 23.87319183], [68.56874847, 23.87403107], [68.56903076, 23.87402725], [68.56903076, 23.87458229], [68.56931305, 23.87458038], [68.56931305, 23.87514114], [68.56958008, 23.87513924], [68.56958008, 23.87597275], [68.56986237, 23.87597084], [68.56986237, 23.87652969], [68.57013702, 23.87652779], [68.57013702, 23.87708282], [68.57041931, 23.87708092], [68.57041931, 23.87763977], [68.57069397, 23.87763977], [68.57069397, 23.87819672], [68.57096863, 23.87819099], [68.57096863, 23.87874985], [68.57125092, 23.87874985], [68.57125092, 23.87930679], [68.57152557, 23.87930679], [68.57152557, 23.87986183], [68.57180786, 23.87985992], [68.57180786, 23.8801403], [68.57235718, 23.8801403], [68.57235718, 23.88042068], [68.57263947, 23.88042068], [68.57263947, 23.88069916], [68.57291412, 23.88069534], [68.57291412, 23.88097191], [68.57347107, 23.88096809], [68.57347107, 23.88125038], [68.57430267, 23.88125038], [68.57430267, 23.88153076], [68.57459259, 23.88153076], [68.57459259, 23.88180923], [68.57514191, 23.88180542], [68.57514191, 23.88208389], [68.57569122, 23.88207817], [68.57569122, 23.88236046], [68.57681274, 23.88236046], [68.57681274, 23.88264084], [68.57736206, 23.88264084], [68.57736206, 23.88319397], [68.57791901, 23.88319397], [68.57791901, 23.88347244], [68.57875061, 23.88347244], [68.57875061, 23.88375092], [68.58013916, 23.88373947], [68.58013916, 23.88402939], [68.58152771, 23.88402939], [68.58152771, 23.88431168], [68.58235931, 23.88430595], [68.58235931, 23.88458252], [68.58347321, 23.88458061], [68.58347321, 23.8848629], [68.58429718, 23.8848629], [68.58429718, 23.88513947], [68.58513641, 23.88513947], [68.58513641, 23.88542175], [68.5854187, 23.88541603], [68.5854187, 23.8856945], [68.58597565, 23.8856945], [68.58597565, 23.88597107], [68.58625031, 23.88597107], [68.58625031, 23.88624954], [68.58653259, 23.88624954], [68.58653259, 23.88652992], [68.58708954, 23.88652992], [68.58708954, 23.8868103], [68.5873642, 23.88680649], [68.5873642, 23.88708115], [68.58763885, 23.88708115], [68.58763885, 23.88736153], [68.5881958, 23.88735962], [68.5881958, 23.88764], [68.58847046, 23.88764], [68.58847046, 23.88792038], [68.5890274, 23.88792038], [68.5890274, 23.88820076], [68.58958435, 23.88819313], [68.58958435, 23.8884716], [68.5901413, 23.8884716], [68.5901413, 23.88875008], [68.59041595, 23.88875008], [68.59041595, 23.88903046], [68.5909729, 23.88903046], [68.5909729, 23.88931084], [68.59152985, 23.88930321], [68.59152985, 23.88958359], [68.59208679, 23.88957977], [68.59208679, 23.88986969], [68.59263611, 23.88986969], [68.59263611, 23.89014053], [68.59319305, 23.89014053], [68.59319305, 23.89042091], [68.59375, 23.89041519], [68.59375, 23.89069366], [68.59430695, 23.89069366], [68.59430695, 23.89097214], [68.59485626, 23.89097023], [68.59485626, 23.89125061], [68.59570313, 23.89125061], [68.59570313, 23.89153099], [68.59625244, 23.89153099], [68.59625244, 23.89180946], [68.59680176, 23.89180756], [68.59680176, 23.89194679], [68.59680939, 23.89208412], [68.59791565, 23.89208412], [68.59791565, 23.89236069], [68.5984726, 23.89236069], [68.5984726, 23.89291763], [68.59874725, 23.89291763], [68.59874725, 23.89347267], [68.59902954, 23.89347076], [68.59902954, 23.89375114], [68.59929657, 23.89375114], [68.59929657, 23.89402962], [68.59958649, 23.89402962], [68.59958649, 23.89430809], [68.59986115, 23.89430618], [68.59986115, 23.89458275], [68.6001358, 23.89458084], [68.6001358, 23.89486122], [68.60041809, 23.89486122], [68.60041809, 23.89513969], [68.60069275, 23.89513969], [68.60069275, 23.89541817], [68.60097504, 23.89541626], [68.60097504, 23.89569473], [68.60124969, 23.89569473], [68.60124969, 23.8959713], [68.60151672, 23.89596748], [68.60151672, 23.89624977], [68.60180664, 23.89624977], [68.60180664, 23.89652824], [68.60236359, 23.89652824], [68.60236359, 23.89680481], [68.60263824, 23.89680481], [68.60263824, 23.89708328], [68.6029129, 23.89708328], [68.6029129, 23.89736176], [68.60320282, 23.89736176], [68.60320282, 23.89764023], [68.60346985, 23.89764023], [68.60346985, 23.89792252], [68.60375214, 23.89792252], [68.60375214, 23.8982029], [68.60402679, 23.89819527], [68.60402679, 23.89847183], [68.60430908, 23.89847183], [68.60430908, 23.89875031], [68.60457611, 23.89875031], [68.60457611, 23.89903259], [68.60513306, 23.89903259], [68.60513306, 23.89931107], [68.60569763, 23.89930534], [68.60569763, 23.89958382], [68.60624695, 23.89958191], [68.60624695, 23.89986038], [68.60652924, 23.89986038], [68.60652924, 23.90014076], [68.60708618, 23.90014076], [68.60708618, 23.90042114], [68.6076355, 23.90041733], [68.6076355, 23.90069389], [68.60819244, 23.90069389], [68.60819244, 23.90097237], [68.60901642, 23.90097046], [68.60901642, 23.90125084], [68.60958099, 23.90125084], [68.60958099, 23.90153122], [68.61042023, 23.90153122], [68.61042023, 23.90180969], [68.61096954, 23.90180588], [68.61096954, 23.90208244], [68.61180878, 23.90208054], [68.61180878, 23.90236092], [68.61235809, 23.90236092], [68.61235809, 23.90263939], [68.61292267, 23.90263939], [68.61292267, 23.90291977], [68.61347198, 23.90291405], [68.61347198, 23.90319443], [68.61597443, 23.90319443], [68.61597443, 23.90291405], [68.61624908, 23.90291977], [68.61624908, 23.90263939], [68.61680603, 23.90263939], [68.61680603, 23.90236092], [68.61736298, 23.90236092], [68.61736298, 23.90208054], [68.61819458, 23.90208244], [68.61819458, 23.90180588], [68.61875153, 23.90180969], [68.61875153, 23.90153122], [68.61985779, 23.90153122], [68.61985779, 23.90125084], [68.62264252, 23.90125084], [68.62264252, 23.90097046], [68.62486267, 23.90097237], [68.62486267, 23.90069389], [68.62596893, 23.90069389], [68.62596893, 23.90041733], [68.62652588, 23.90042114], [68.62652588, 23.90014076], [68.62708282, 23.90014076], [68.62708282, 23.89986038], [68.62763977, 23.89986038], [68.62763977, 23.89958191], [68.62791443, 23.89958382], [68.62791443, 23.89930534], [68.62847137, 23.89931107], [68.62847137, 23.89903259], [68.6295929, 23.89903259], [68.6295929, 23.89875031], [68.63014221, 23.89875031], [68.63014221, 23.89847183], [68.63069153, 23.89847183], [68.63069153, 23.89819527], [68.63153076, 23.8982029], [68.63153076, 23.89792252], [68.63207245, 23.89792252], [68.63207245, 23.89764023], [68.6340332, 23.89764023], [68.6340332, 23.89736176], [68.63458252, 23.89736176], [68.63458252, 23.89708328], [68.63486481, 23.89708328], [68.63486481, 23.89680481], [68.63513947, 23.89680481], [68.63513947, 23.89652824], [68.63540649, 23.89652824], [68.63540649, 23.89624977], [68.63597107, 23.89624977], [68.63597107, 23.89596748], [68.63625336, 23.8959713], [68.63625336, 23.89569473], [68.63680267, 23.89569473], [68.63680267, 23.89541626], [68.63764191, 23.89541817], [68.63764191, 23.89513969], [68.63819885, 23.89513969], [68.63819122, 23.89486122], [68.63846588, 23.89486122], [68.63846588, 23.89513969], [68.63874817, 23.89513969], [68.63874817, 23.89541817], [68.63847351, 23.89541626], [68.63847351, 23.89569473], [68.63819122, 23.89569473], [68.63819122, 23.8959713], [68.63764191, 23.89596748], [68.63764191, 23.89624977], [68.63709259, 23.89624977], [68.63709259, 23.89652824], [68.63680267, 23.89652824], [68.63680267, 23.89680481], [68.63625336, 23.89680481], [68.63625336, 23.89708328], [68.63597107, 23.89708328], [68.63597107, 23.89736176], [68.63625336, 23.89736176], [68.63625336, 23.89764023], [68.63791656, 23.89764023], [68.63791656, 23.89792252], [68.63874817, 23.89791679], [68.63874817, 23.89847183], [68.63903046, 23.89847183], [68.63903046, 23.89903259], [68.63931274, 23.89903259], [68.63931274, 23.89931107], [68.63986206, 23.89930534], [68.63986206, 23.89958382], [68.64013672, 23.89958191], [68.64013672, 23.89986038], [68.64068604, 23.89986038], [68.64068604, 23.90014076], [68.64097595, 23.90014076], [68.64097595, 23.90042114], [68.64125061, 23.90041733], [68.64125061, 23.90069389], [68.64152527, 23.90069389], [68.64152527, 23.90097237], [68.64208221, 23.90097046], [68.64208221, 23.90125084], [68.64235687, 23.90125084], [68.64235687, 23.90153122], [68.64263916, 23.90153122], [68.64263916, 23.90180969], [68.64291382, 23.90180588], [68.64291382, 23.90208244], [68.64319611, 23.90208054], [68.64319611, 23.90236092], [68.64347076, 23.90236092], [68.64347076, 23.90263939], [68.64402771, 23.90263939], [68.64402771, 23.90291977], [68.64430237, 23.90291405], [68.64430237, 23.90319443], [68.64458466, 23.90319443], [68.64458466, 23.90347481], [68.64485931, 23.90347099], [68.64485931, 23.90374947], [68.6451416, 23.90374947], [68.6451416, 23.90402985], [68.64541626, 23.90402985], [68.64541626, 23.90431023], [68.64597321, 23.9043045], [68.64597321, 23.90458298], [68.64653015, 23.90458298], [68.64653015, 23.90486145], [68.64679718, 23.90485001], [68.64679718, 23.90513992], [68.6470871, 23.90513992], [68.6470871, 23.9054203], [68.64736938, 23.9054203], [68.64736938, 23.90570068], [68.6479187, 23.90569687], [68.6479187, 23.90597153], [68.64819336, 23.90596962], [68.64819336, 23.90625], [68.64875031, 23.90625], [68.64875031, 23.90653038], [68.64903259, 23.90653038], [68.64903259, 23.90681076], [68.64930725, 23.90680695], [68.64930725, 23.90708351], [68.6498642, 23.90708351], [68.6498642, 23.90736198], [68.65013885, 23.90735817], [68.65013885, 23.90764046], [68.65041351, 23.90763855], [68.65041351, 23.90819359], [68.6506958, 23.90818977], [68.6506958, 23.90875053], [68.65097046, 23.90875053], [68.65097046, 23.90903091], [68.65125275, 23.9090271], [68.65125275, 23.90958405], [68.6515274, 23.90957832], [68.6515274, 23.91013908], [68.65180206, 23.91013908], [68.65180206, 23.91041946], [68.65208435, 23.91041756], [68.65208435, 23.91069412], [68.65235901, 23.9106884], [68.65235901, 23.91098022], [68.6526413, 23.91098022], [68.6526413, 23.91124916], [68.65291595, 23.91124916], [68.65291595, 23.91152954], [68.65319824, 23.91152954], [68.65319824, 23.91181183], [68.6534729, 23.91180611], [68.6534729, 23.91208267], [68.65374756, 23.91208267], [68.65374756, 23.91236115], [68.65402985, 23.91236115], [68.65402985, 23.91263962], [68.65429688, 23.91263962], [68.65429688, 23.91292191], [68.65458679, 23.91291618], [68.65458679, 23.91319466], [68.65486145, 23.91319466], [68.65486145, 23.91347122], [68.65513611, 23.91347122], [68.65513611, 23.91374969], [68.65569305, 23.91374969], [68.65569305, 23.91403961], [68.65625, 23.91402817], [68.65625, 23.91430473], [68.65652466, 23.91430473], [68.65652466, 23.91458321], [68.6570816, 23.91458321], [68.6570816, 23.91486168], [68.6590271, 23.91485977], [68.6590271, 23.91514015], [68.65930939, 23.91514015], [68.65930939, 23.91570091], [68.65958405, 23.91569328], [68.65958405, 23.91597176], [68.6598587, 23.91596985], [68.6598587, 23.91625023], [68.66014099, 23.91625023], [68.66014099, 23.91681099], [68.66041565, 23.91680336], [68.66041565, 23.91708565], [68.6609726, 23.91707993], [68.6609726, 23.91736031], [68.66152954, 23.91736031], [68.66152954, 23.91707993], [68.66291809, 23.91707993], [68.66291809, 23.91736031], [68.66319275, 23.91736031], [68.66319275, 23.91792107], [68.6626358, 23.91792107], [68.6626358, 23.92041969], [68.66236877, 23.92041969], [68.66236877, 23.92263985], [68.66179657, 23.92263985], [68.66179657, 23.92235756], [68.6609726, 23.92236137], [68.6609726, 23.9220829], [68.66014099, 23.9220829], [68.66014099, 23.92180634], [68.65957642, 23.92180824], [68.65957642, 23.92152977], [68.6598587, 23.92152977], [68.6598587, 23.91958046], [68.65958405, 23.91958427], [68.65958405, 23.91930771], [68.65930939, 23.91930962], [68.65930939, 23.91875076], [68.6590271, 23.91875076], [68.6590271, 23.91847038], [68.65875244, 23.91847229], [68.65875244, 23.91819382], [68.65847015, 23.91819382], [68.65847015, 23.91791534], [68.65820313, 23.91792107], [68.65820313, 23.91764069], [68.65763855, 23.91764069], [68.65763855, 23.91736031], [68.65735626, 23.91736031], [68.65735626, 23.91707993], [68.6554184, 23.91708565], [68.6554184, 23.91680336], [68.65402985, 23.91681099], [68.65402985, 23.91653061], [68.65374756, 23.91653061], [68.65374756, 23.91625023], [68.6534729, 23.91625023], [68.6534729, 23.91596985], [68.65291595, 23.91597176], [68.65291595, 23.91569328], [68.65207672, 23.91570091], [68.65207672, 23.91542053], [68.65180206, 23.91542053], [68.65180206, 23.91485977], [68.6515274, 23.91486168], [68.6515274, 23.91458321], [68.65125275, 23.91458321], [68.65125275, 23.91430473], [68.6506958, 23.91430473], [68.6506958, 23.91402817], [68.65040588, 23.91403961], [68.65040588, 23.91374969], [68.65013885, 23.91374969], [68.65013885, 23.91347122], [68.64958191, 23.91347122], [68.64958191, 23.91319466], [68.64930725, 23.91319466], [68.64930725, 23.91263962], [68.64902496, 23.91263962], [68.64902496, 23.91208267], [68.64875031, 23.91208267], [68.64875031, 23.91180611], [68.64848328, 23.91181183], [68.64848328, 23.91152954], [68.6479187, 23.91152954], [68.6479187, 23.91124916], [68.64763641, 23.91124916], [68.64763641, 23.91098022], [68.6470871, 23.91098022], [68.6470871, 23.9106884], [68.64680481, 23.91069412], [68.64680481, 23.91041756], [68.64653015, 23.91041946], [68.64653015, 23.91013908], [68.64597321, 23.91013908], [68.64597321, 23.90986061], [68.64569092, 23.90986061], [68.64569092, 23.90957832], [68.64541626, 23.90958405], [68.64541626, 23.90930557], [68.64485931, 23.90930939], [68.64485931, 23.90903091], [68.64457703, 23.90903091], [68.64457703, 23.90875053], [68.64430237, 23.90875053], [68.64430237, 23.90818977], [68.64402771, 23.90819359], [68.64402771, 23.90763855], [68.64375305, 23.90764046], [68.64375305, 23.90735817], [68.64347076, 23.90736198], [68.64347076, 23.90708351], [68.64319611, 23.90708351], [68.64319611, 23.90680695], [68.64290619, 23.90681076], [68.64290619, 23.90653038], [68.64263916, 23.90653038], [68.64263916, 23.90625], [68.64235687, 23.90625], [68.64235687, 23.90570068], [68.64208221, 23.90570068], [68.64208221, 23.9054203], [68.64180756, 23.9054203], [68.64180756, 23.90513992], [68.6415329, 23.90513992], [68.6415329, 23.90485001], [68.64125061, 23.90486145], [68.64125061, 23.90458298], [68.64097595, 23.90458298], [68.64097595, 23.9043045], [68.64041901, 23.90431023], [68.64041901, 23.90402985], [68.63986206, 23.90402985], [68.63986206, 23.90374947], [68.63903046, 23.90374947], [68.63903046, 23.90347099], [68.63819122, 23.90347481], [68.63819122, 23.90319443], [68.63402557, 23.90319443], [68.63402557, 23.90347481], [68.63318634, 23.90347099], [68.63318634, 23.90374947], [68.63207245, 23.90374947], [68.63207245, 23.90402985], [68.63124847, 23.90402985], [68.63124847, 23.90431023], [68.63041687, 23.9043045], [68.63041687, 23.90458298], [68.62985992, 23.90458298], [68.62985992, 23.90486145], [68.62902832, 23.90485001], [68.62902832, 23.90513992], [68.62847137, 23.90513992], [68.62847137, 23.9054203], [68.62763977, 23.9054203], [68.62763977, 23.90570068], [68.62708282, 23.90569687], [68.62708282, 23.90597153], [68.62513733, 23.90596962], [68.62513733, 23.90625], [68.62097168, 23.90625], [68.62097168, 23.90653038], [68.61985779, 23.90653038], [68.61985779, 23.90681076], [68.61958313, 23.90680695], [68.61958313, 23.90708351], [68.61930847, 23.9070797], [68.61930847, 23.90764046], [68.61902618, 23.90763855], [68.61902618, 23.90791893], [68.61875153, 23.90791893], [68.61875153, 23.90819359], [68.61763763, 23.90818977], [68.61763763, 23.90930939], [68.61736298, 23.90930939], [68.61736298, 23.91041946], [68.61763763, 23.91041946], [68.61763763, 23.91292191], [68.61791992, 23.91291618], [68.61791992, 23.91347122], [68.61818695, 23.91347122], [68.61818695, 23.91374969], [68.61846924, 23.91374969], [68.61846924, 23.91430473], [68.61875153, 23.91430473], [68.61875153, 23.91486168], [68.61902618, 23.91485977], [68.61902618, 23.91542053], [68.61930847, 23.91542053], [68.61930847, 23.91625023], [68.61958313, 23.91625023], [68.61958313, 23.91819382], [68.61985779, 23.91819382], [68.61985779, 23.92069435], [68.61958313, 23.92069435], [68.61958313, 23.92236137], [68.61985779, 23.92236137], [68.61985779, 23.92319489], [68.62013245, 23.92318916], [68.62013245, 23.9240303], [68.62041473, 23.9240284], [68.62041473, 23.92458344], [68.62069702, 23.92458344], [68.62069702, 23.92486191], [68.62097168, 23.92486191], [68.62097168, 23.92514038], [68.62124634, 23.92514038], [68.62124634, 23.92542267], [68.62180328, 23.92541695], [68.62180328, 23.92569351], [68.6220932, 23.9256916], [68.6220932, 23.92597961], [68.62236023, 23.92597961], [68.62236023, 23.9256916], [68.62264252, 23.9256916], [68.62264252, 23.92597961], [68.62291718, 23.92597961], [68.62291718, 23.92625046], [68.62264252, 23.92625046], [68.62264252, 23.92681122], [68.62236023, 23.92681122], [68.62236023, 23.92736053], [68.62097168, 23.92736053], [68.62097168, 23.92708015], [68.61958313, 23.92708206], [68.61958313, 23.9268055], [68.61930847, 23.92681122], [68.61930847, 23.92653275], [68.61902618, 23.92653275], [68.61902618, 23.92625046], [68.61846924, 23.92625046], [68.61846924, 23.92597961], [68.61818695, 23.92597961], [68.61818695, 23.92458153], [68.61791992, 23.92458344], [68.61791992, 23.9240284], [68.61763763, 23.9240303], [68.61763763, 23.92375183], [68.61736298, 23.92375183], [68.61736298, 23.92347145], [68.61708069, 23.92347145], [68.61708069, 23.92319489], [68.61680603, 23.92319489], [68.61680603, 23.92291641], [68.61653137, 23.92291832], [68.61653137, 23.92263985], [68.61624908, 23.92263985], [68.61624908, 23.92235756], [68.61597443, 23.92236137], [68.61597443, 23.9220829], [68.61541748, 23.9220829], [68.61541748, 23.92236137], [68.61514282, 23.92235756], [68.61514282, 23.92263985], [68.61429596, 23.92263985], [68.61429596, 23.92291832], [68.61402893, 23.92291641], [68.61402893, 23.92319489], [68.61374664, 23.92318916], [68.61374664, 23.92375183], [68.61347198, 23.92375183], [68.61347198, 23.92486191], [68.61319733, 23.92486191], [68.61319733, 23.92653275], [68.61292267, 23.92653275], [68.61292267, 23.92791939], [68.61264038, 23.92791939], [68.61264038, 23.92875099], [68.61235809, 23.92875099], [68.61235809, 23.92930984], [68.61207581, 23.92930984], [68.61207581, 23.92986107], [68.61180878, 23.92986107], [68.61180878, 23.93013954], [68.61152649, 23.93013954], [68.61152649, 23.93069649], [68.61125183, 23.93069649], [68.61125183, 23.93097305], [68.61096954, 23.93097115], [68.61096954, 23.93153], [68.61069489, 23.93152618], [68.61069489, 23.93180466], [68.61042023, 23.93180466], [68.61042023, 23.9323616], [68.61013794, 23.9323597], [68.61013794, 23.93264008], [68.60986328, 23.93264008], [68.60986328, 23.93292046], [68.60958099, 23.93292046], [68.60958099, 23.93320084], [68.60930634, 23.93320084], [68.60930634, 23.93375015], [68.60901642, 23.93375015], [68.60901642, 23.93403053], [68.60874939, 23.93403053], [68.60874939, 23.93431091], [68.60847473, 23.93430519], [68.60847473, 23.93458366], [68.60819244, 23.93457985], [68.60819244, 23.93486023], [68.60791779, 23.93486023], [68.60791779, 23.93514061], [68.60764313, 23.93514061], [68.60764313, 23.93541908], [68.60708618, 23.93541718], [68.60708618, 23.93569374], [68.60680389, 23.93569374], [68.60680389, 23.93597221], [68.60652924, 23.9359684], [68.60652924, 23.93625069], [68.60624695, 23.93625069], [68.60624695, 23.93652916], [68.60597229, 23.93652916], [68.60597229, 23.93680954], [68.60514069, 23.93680573], [68.60514069, 23.9370842], [68.60430908, 23.93707848], [68.60430908, 23.93736076], [68.60320282, 23.93736076], [68.60320282, 23.93763924], [68.60208893, 23.93763924], [68.60208893, 23.93791962], [68.59986115, 23.9379158], [68.59986115, 23.93819427], [68.5993042, 23.93819427], [68.5993042, 23.93847275], [68.59874725, 23.93847275], [68.59874725, 23.93875122], [68.59819794, 23.93875122], [68.59819794, 23.93902969], [68.59764099, 23.93902969], [68.59764099, 23.93931007], [68.59708405, 23.93930626], [68.59708405, 23.93958282], [68.59680939, 23.93958282], [68.59680176, 23.94013977], [68.5965271, 23.94013977], [68.5965271, 23.94069481], [68.59625244, 23.9406929], [68.59625244, 23.94124985], [68.59597015, 23.94124985], [68.59597015, 23.94180489], [68.59402466, 23.94180489], [68.59402466, 23.94152832], [68.59208679, 23.94153023], [68.59208679, 23.94124985], [68.59041595, 23.94124985], [68.59041595, 23.94098091], [68.58847046, 23.94098091], [68.58847046, 23.9406929], [68.5873642, 23.94069481], [68.5873642, 23.93930626], [68.58763885, 23.93931007], [68.58763885, 23.93875122], [68.58790588, 23.93875122], [68.58790588, 23.93707848], [68.58763885, 23.9370842], [68.58763885, 23.93430519], [68.58735657, 23.93431091], [68.58735657, 23.93346977], [68.58763885, 23.93347168], [68.58763885, 23.93291855], [68.58790588, 23.93292046], [68.58790588, 23.93153], [68.58763885, 23.93153], [68.58763885, 23.93124962], [68.58735657, 23.93124962], [68.58735657, 23.93097115], [68.58708191, 23.93097305], [68.58708191, 23.93069649], [68.5873642, 23.93069649], [68.5873642, 23.9304142], [68.58763885, 23.93041992], [68.58763885, 23.93013954], [68.58790588, 23.93013954], [68.58790588, 23.92904091], [68.5881958, 23.92904091], [68.5881958, 23.92875099], [68.58790588, 23.92875099], [68.58790588, 23.92653275], [68.5881958, 23.92653275], [68.5881958, 23.92625046], [68.58847046, 23.92625046], [68.58847046, 23.92514038], [68.58875275, 23.92514038], [68.58875275, 23.92375183], [68.58847046, 23.92375183], [68.58847046, 23.92235756], [68.58598328, 23.92235756], [68.58598328, 23.92263985], [68.5854187, 23.92263985], [68.5854187, 23.92291832], [68.58486176, 23.92291641], [68.58486176, 23.92319489], [68.58403015, 23.92319489], [68.58403015, 23.92347145], [68.5826416, 23.92347145], [68.5826416, 23.92375183], [68.58096313, 23.92375183], [68.58096313, 23.9240303], [68.57958221, 23.9240303], [68.57958221, 23.92431259], [68.57235718, 23.92431259], [68.57235718, 23.9240303], [68.57125092, 23.9240303], [68.57125092, 23.92375183], [68.56458282, 23.92375183], [68.56458282, 23.92347145], [68.56153107, 23.92347145], [68.56153107, 23.92375183], [68.5595932, 23.92375183], [68.5595932, 23.9240303], [68.55874634, 23.9240284], [68.55874634, 23.92458344], [68.55902863, 23.92458153], [68.55902863, 23.92625046], [68.55930328, 23.92625046], [68.55930328, 23.92736053], [68.5595932, 23.92736053], [68.5595932, 23.92904091], [68.55986023, 23.92904091], [68.55986023, 23.93041992], [68.55958557, 23.9304142], [68.5595932, 23.93124962], [68.55930328, 23.93124962], [68.55930328, 23.93180466], [68.55902863, 23.93180466], [68.55902863, 23.93208313], [68.55847168, 23.93208313], [68.55847168, 23.9323616], [68.55819702, 23.9323597], [68.55819702, 23.93264008], [68.55764008, 23.93264008], [68.55764008, 23.93292046], [68.55568695, 23.93292046], [68.55568695, 23.93320084], [68.55541992, 23.93319511], [68.55541992, 23.93347168], [68.55458069, 23.93347168], [68.55458069, 23.93319511], [68.55291748, 23.93319511], [68.55291748, 23.93347168], [68.55263519, 23.93347168], [68.55263519, 23.93375015], [68.55291748, 23.93375015], [68.55291748, 23.93403053], [68.55179596, 23.93403053], [68.55179596, 23.93375015], [68.55152893, 23.93375015], [68.55152893, 23.93346977], [68.55097198, 23.93347168], [68.55097198, 23.93319511], [68.54819489, 23.93319511], [68.54819489, 23.93347168], [68.54763794, 23.93346977], [68.54763794, 23.93375015], [68.54708099, 23.93375015], [68.54708099, 23.93403053], [68.54624939, 23.93403053], [68.54624939, 23.93431091], [68.54569244, 23.93430519], [68.54569244, 23.93458366], [68.5451355, 23.93458366], [68.54514313, 23.93486023], [68.54458618, 23.93486023], [68.54458618, 23.93514061], [68.54374695, 23.93514061], [68.54374695, 23.93541908], [68.54347229, 23.93541718], [68.54347229, 23.93597221], [68.54402924, 23.9359684], [68.54402924, 23.93625069], [68.54429626, 23.93625069], [68.54429626, 23.93652916], [68.54402924, 23.93652725], [68.54402924, 23.9370842], [68.54264069, 23.93707848], [68.54264069, 23.93763924], [68.5423584, 23.93763924], [68.5423584, 23.93791962], [68.54208374, 23.9379158], [68.54208374, 23.93847275], [68.54180908, 23.93847275], [68.54180908, 23.93875122], [68.54152679, 23.93875122], [68.54152679, 23.93931007], [68.54125214, 23.93930626], [68.54125214, 23.9398613], [68.54096985, 23.93985939], [68.54096985, 23.94042015], [68.54070282, 23.94042015], [68.54070282, 23.94098091], [68.5404129, 23.94097137], [68.5404129, 23.94208336], [68.54013824, 23.94207954], [68.54013824, 23.94320107], [68.5395813, 23.94319344], [68.5395813, 23.94347191], [68.53930664, 23.94347191], [68.53930664, 23.94402695], [68.53901672, 23.94402122], [68.53901672, 23.94431114], [68.53874969, 23.94431114], [68.53874969, 23.94486046], [68.53848267, 23.94486046], [68.53848267, 23.94514084], [68.53819275, 23.94514084], [68.53819275, 23.94542122], [68.53791809, 23.94542122], [68.53791809, 23.94625092], [68.5376358, 23.94625092], [68.5376358, 23.94680977], [68.53736115, 23.94680977], [68.53736115, 23.94736099], [68.53791809, 23.94736099], [68.53791809, 23.94763947], [68.53848267, 23.94763947], [68.53848267, 23.94791985], [68.53902435, 23.94791794], [68.53902435, 23.94847298], [68.53930664, 23.94847298], [68.53930664, 23.94930077], [68.53986359, 23.94930649], [68.53986359, 23.94955063], [68.53986359, 23.95041656], [68.54013824, 23.95041656], [68.54013824, 23.95236015], [68.5404129, 23.95236015], [68.5404129, 23.9529171], [68.54069519, 23.9529171], [68.54069519, 23.95347214], [68.54096985, 23.95347214], [68.54096985, 23.95402718], [68.54125214, 23.95402718], [68.54125214, 23.95486069], [68.54152679, 23.95486069], [68.54152679, 23.95513916], [68.54180908, 23.95513916], [68.54180908, 23.95569229], [68.54208374, 23.95569229], [68.54208374, 23.95624924], [68.5423584, 23.95624924], [68.5423584, 23.95680428], [68.54264069, 23.95680428], [68.54264069, 23.95736122], [68.54291534, 23.95736122], [68.54291534, 23.95819664], [68.54319763, 23.95819664], [68.54319763, 23.95874977], [68.54347229, 23.95874977], [68.54347229, 23.95930672], [68.54374695, 23.95930672], [68.54374695, 23.95986176], [68.54402924, 23.95986176], [68.54402924, 23.96013641], [68.54430389, 23.96013641], [68.54430389, 23.9604187], [68.54458618, 23.9604187], [68.54458618, 23.96069527], [68.54486084, 23.96069527], [68.54486084, 23.96097183], [68.5451355, 23.96097183], [68.5451355, 23.96125031], [68.54541779, 23.96125031], [68.54541779, 23.96152878], [68.54569244, 23.96152878], [68.54569244, 23.96180534], [68.54597473, 23.96180534], [68.54597473, 23.96236038], [68.54624939, 23.96236038], [68.54624939, 23.96264076], [68.54652405, 23.96264076], [68.54652405, 23.96291733], [68.54680634, 23.96291733], [68.54680634, 23.96319389], [68.54708099, 23.96318626], [68.68630981, 23.96240044], [68.72147369, 23.96220207], [68.74924469, 23.96204567], [68.75092316, 23.99999809], [68.75955963, 24.03582191], [68.76139832, 24.10002327], [68.7614212, 24.10292435], [68.7618103, 24.16122246], [68.76216125, 24.19102859], [68.76306915, 24.2066288], [68.76417542, 24.23598862], [68.76412201, 24.28412247], [68.76750183, 24.2896862], [68.771492, 24.29313469], [68.77265167, 24.29413605], [68.7922821, 24.29999352], [68.80521393, 24.3032074], [68.80619049, 24.30344772], [68.82635498, 24.30839539], [68.83205414, 24.29932785], [68.83172607, 24.29557037], [68.83104706, 24.28784943], [68.83585358, 24.24988365], [68.84030914, 24.22818756], [68.84772491, 24.20837975], [68.85253143, 24.20571136], [68.86403656, 24.20522308], [68.86750793, 24.20620346], [68.86820984, 24.20713806], [68.86962891, 24.20903587], [68.87068939, 24.20487022], [68.87124634, 24.20351982], [68.87242126, 24.20066071], [68.87409973, 24.19979095], [68.87458038, 24.19955254], [68.87529755, 24.19919205], [68.87841034, 24.19763947], [68.87844849, 24.19693947], [68.88595581, 24.19605064], [68.88754272, 24.19585037], [68.89099121, 24.19593811], [68.89317322, 24.19655991], [68.89507294, 24.19720268], [68.89794922, 24.19886017], [68.90405273, 24.20916939], [68.91278839, 24.24113083], [68.91335297, 24.24266052], [68.91409302, 24.24526978], [68.91822815, 24.25312042], [68.92196655, 24.25864983], [68.93360138, 24.26857185], [68.94724274, 24.27662659], [68.94780731, 24.27565575], [68.95734406, 24.26137543], [68.95999908, 24.25362968], [68.9705658, 24.23752975], [68.98149109, 24.22854424], [68.98628235, 24.22633171], [68.99700928, 24.2259903], [68.99835205, 24.22594833], [69.00053406, 24.22587967], [69.00415039, 24.22675705], [69.01371765, 24.22907448], [69.0394516, 24.24210167], [69.07009125, 24.26024055], [69.07927704, 24.26527405], [69.08544159, 24.26827812], [69.09292603, 24.26908302], [69.10547638, 24.26607323], [69.11463928, 24.26342964], [69.11829376, 24.26237679], [69.12142181, 24.26085091], [69.13696289, 24.25326538], [69.14826965, 24.25000572], [69.14828491, 24.24908638], [69.15553284, 24.24897003], [69.15808868, 24.24625778], [69.17288971, 24.2413826], [69.1900177, 24.23574066], [69.19976807, 24.23519897], [69.22229004, 24.24745178], [69.22897339, 24.2512207], [69.23642731, 24.25183868], [69.24340057, 24.25532722], [69.26774597, 24.26370239], [69.27073669, 24.26420403], [69.27144623, 24.26673508], [69.27490997, 24.26884842], [69.29256439, 24.27391434], [69.31027222, 24.27668762], [69.33081055, 24.27399635], [69.36193848, 24.26617432], [69.38218689, 24.26599503], [69.39188385, 24.26910591], [69.3951416, 24.26869011], [69.40036774, 24.27092552], [69.41162872, 24.27385139], [69.43157959, 24.27365303], [69.43832397, 24.27270508], [69.44284821, 24.27093124], [69.44874573, 24.26940727], [69.45854187, 24.26687622], [69.46820068, 24.26438522], [69.47042847, 24.2641468], [69.48419189, 24.25741005], [69.49796295, 24.2554512], [69.5011673, 24.25502014], [69.52818298, 24.25904083], [69.55194092, 24.26459122], [69.55635071, 24.26492119], [69.57974243, 24.27038956], [69.60067749, 24.27784729], [69.61287689, 24.26755524], [69.61747742, 24.26027489], [69.66956329, 24.21664619], [69.67511749, 24.21235657], [69.68121338, 24.20509148], [69.6930542, 24.19789124], [69.70240021, 24.1904335], [69.70866394, 24.1889019], [69.71652985, 24.17959213], [69.72457886, 24.17509651], [69.72839355, 24.17487717], [69.73886871, 24.17427635], [69.74132538, 24.17413521], [69.75081635, 24.17400932], [69.7665863, 24.17165756], [69.82532501, 24.1674614], [69.83480835, 24.16755867], [69.85804749, 24.16641617], [69.86580658, 24.16535187], [69.87030792, 24.16470718], [69.87378693, 24.16611671], [69.89876556, 24.16521645], [69.90599823, 24.16620255], [69.91226196, 24.16419983], [69.97868347, 24.16505051], [70.0, 24.16635513], [70.00064087, 24.16639519], [70.01186371, 24.16764069], [70.01858521, 24.16976357], [70.024086, 24.16935349], [70.03203583, 24.17309189], [70.04890442, 24.18354607], [70.05930328, 24.19280243], [70.07730865, 24.21564293], [70.08834839, 24.23521233], [70.10400391, 24.26972198], [70.11009979, 24.28489685], [70.11904144, 24.29069901], [70.1439743, 24.29800224], [70.15045166, 24.30057335], [70.19087982, 24.308218], [70.23081207, 24.31653595], [70.23706055, 24.31726646], [70.24752808, 24.32123756], [70.27071381, 24.32987976], [70.29689026, 24.33991432], [70.30712128, 24.34204483], [70.32559204, 24.34743881], [70.35756683, 24.35199547], [70.37031555, 24.35345078], [70.45963287, 24.38697624], [70.46614075, 24.38678169], [70.48313141, 24.39077187], [70.53155518, 24.41004372], [70.56012726, 24.41859436], [70.57486725, 24.42031479], [70.59319305, 24.41173172], [70.5936203, 24.4099369], [70.59993744, 24.40730286], [70.60653687, 24.40358925], [70.60681915, 24.40343285], [70.61149597, 24.40151978], [70.61186981, 24.4005394], [70.610672, 24.3960495], [70.60840607, 24.39157104], [70.60616302, 24.38610077], [70.60394287, 24.38059807], [70.60269165, 24.37811089], [70.59939575, 24.37210846], [70.59658051, 24.36762047], [70.59378815, 24.36211967], [70.59204865, 24.35863113], [70.59082794, 24.35710907], [70.58641052, 24.35309982], [70.58516693, 24.35209274], [70.57684326, 24.34843063], [70.57446289, 24.34648132], [70.57206726, 24.34454918], [70.57280731, 24.34073067], [70.57681274, 24.32741928], [70.5796814, 24.31983185], [70.58115387, 24.31597328], [70.5874176, 24.31014633], [70.58560944, 24.30858994], [70.57348633, 24.29816437], [70.572258, 24.29357719], [70.57403564, 24.28968811], [70.5878067, 24.28539658], [70.5828476, 24.27872849], [70.57736969, 24.27388954], [70.57242584, 24.26492882], [70.57220459, 24.25919914], [70.57424927, 24.25233269], [70.58428955, 24.24412918], [70.59355164, 24.24027443], [70.59710693, 24.24012947], [70.60850525, 24.23966408], [70.61380005, 24.23944855], [70.63357544, 24.23265648], [70.65530396, 24.22508812], [70.68983459, 24.22325516], [70.72582245, 24.22086525], [70.76379395, 24.22076035], [70.79102325, 24.22199249], [70.80576324, 24.22272682], [70.81624603, 24.22504616], [70.83370972, 24.23288536], [70.83718872, 24.23450089], [70.84169006, 24.23794746], [70.84616852, 24.24300194], [70.85365295, 24.24737549], [70.86563873, 24.25084305], [70.88287354, 24.2536335], [70.894104, 24.25709724], [70.90106201, 24.26270676], [70.89482117, 24.26497269], [70.88907623, 24.26885986], [70.88713837, 24.27238083], [70.88576508, 24.27517319], [70.88537598, 24.27597046], [70.88426208, 24.28094292], [70.8842392, 24.28391075], [70.88471222, 24.28673172], [70.88513947, 24.2907505], [70.88777161, 24.29355812], [70.89041901, 24.29636955], [70.89308929, 24.29824829], [70.89972687, 24.30110168], [70.90540314, 24.30302048], [70.90670776, 24.30425072], [70.90983582, 24.30577087], [70.91034698, 24.30677986], [70.91171265, 24.30734062], [70.91539764, 24.30952072], [70.91755676, 24.31213951], [70.9212265, 24.31483841], [70.9212265, 24.31574059], [70.92488098, 24.31715965], [70.92547607, 24.31843948], [70.92687225, 24.31944084], [70.929039, 24.32324982], [70.93289185, 24.3261795], [70.93786621, 24.32932091], [70.94451141, 24.33403015], [70.94815063, 24.33685112], [70.95281219, 24.33969116], [70.95645142, 24.34342003], [70.95974731, 24.346241], [70.96746063, 24.34725189], [70.97413635, 24.34826088], [70.98179626, 24.35205078], [70.98744202, 24.3558197], [70.99209595, 24.35864067], [70.99475861, 24.35959816], [70.99633789, 24.36001968], [70.99842834, 24.36057091], [71.00112915, 24.35876083], [71.00153351, 24.35809135], [71.00233459, 24.35678291], [71.00282288, 24.35598946], [71.00453949, 24.35323906], [71.00926971, 24.34958839], [71.01299286, 24.34686089], [71.01667786, 24.34597969], [71.02539825, 24.34514046], [71.02906036, 24.34519005], [71.03369141, 24.34539986], [71.04718781, 24.34733963], [71.06093597, 24.35385323], [71.06269836, 24.35469055], [71.06642914, 24.35567093], [71.06732178, 24.35682106], [71.06784058, 24.35709], [71.07540894, 24.36843109], [71.07710266, 24.37228012], [71.08687592, 24.38040924], [71.08828735, 24.38145256], [71.09339905, 24.38355064], [71.0995636, 24.38512421], [71.12146759, 24.39071274], [71.1220932, 24.39087105], [71.12502289, 24.39293289], [71.13176727, 24.40180016], [71.13282776, 24.40572929], [71.13368988, 24.40893936], [71.13410187, 24.41381073], [71.13237, 24.41493988], [71.12415314, 24.42770958], [71.11894989, 24.43104935], [71.11009216, 24.43165207], [71.10736847, 24.43319321], [71.09309387, 24.43593407], [71.07557678, 24.43362808], [71.02857971, 24.43337822], [71.02320099, 24.43509102], [71.01738739, 24.43717957], [71.0134964, 24.43861008], [71.00998688, 24.44134712], [71.00783539, 24.44200134], [71.00756836, 24.44224167], [71.00701141, 24.44687271], [71.00752258, 24.46664047], [71.01165771, 24.49151039], [71.01420593, 24.50196075], [71.01534271, 24.52276993], [71.009758, 24.52884102], [70.99826813, 24.54133987], [71.00340271, 24.56645966], [71.00345612, 24.57009125], [71.00257111, 24.57218933], [71.00118256, 24.57503128], [70.99862671, 24.58473015], [71.00055695, 24.59921265], [71.01019287, 24.61557961], [71.01526642, 24.62035179], [71.01663208, 24.62162018], [71.01719666, 24.62244034], [71.02047729, 24.63051033], [71.02470398, 24.63188934], [71.03446198, 24.63507271], [71.0460968, 24.63881111], [71.06077576, 24.64644814], [71.07299805, 24.65402985], [71.08496094, 24.66142082], [71.09224701, 24.6677494], [71.09941864, 24.67396355], [71.10713959, 24.68065071], [71.11334229, 24.67362976], [71.11927795, 24.66864967], [71.14673615, 24.65801048], [71.17164612, 24.64886093], [71.19709778, 24.64292908], [71.2073288, 24.63954926], [71.23789215, 24.62850952], [71.24154663, 24.6266098], [71.25298309, 24.62363052], [71.26095581, 24.62053108], [71.28714752, 24.61271095], [71.29773712, 24.60764122], [71.30745697, 24.61987114], [71.31006622, 24.62108994], [71.31777191, 24.63591957], [71.32164001, 24.64031982], [71.32649231, 24.64292908], [71.34276581, 24.6482296], [71.35103607, 24.65321922], [71.35671234, 24.65405083], [71.36196899, 24.64160919], [71.36702728, 24.63190079], [71.36765289, 24.62726021], [71.37269592, 24.62576103], [71.37518311, 24.62305069], [71.3807373, 24.62138176], [71.38305664, 24.62168121], [71.38835144, 24.62393951], [71.38977051, 24.6282196], [71.39451599, 24.62701035], [71.39962769, 24.62696075], [71.40280151, 24.63153076], [71.40703583, 24.63467026], [71.41295624, 24.63531113], [71.42230988, 24.63810158], [71.42897034, 24.64256096], [71.43241882, 24.64616013], [71.4453125, 24.65397072], [71.45146942, 24.65884018], [71.45889282, 24.66127968], [71.4668808, 24.66076279], [71.47424316, 24.66320038], [71.4883194, 24.67385101], [71.50353241, 24.67380905], [71.51618958, 24.67634964], [71.52092743, 24.67548943], [71.52275085, 24.67526054], [71.52731323, 24.67716026], [71.53697205, 24.67892075], [71.54364014, 24.67358017], [71.55142212, 24.67063141], [71.5684433, 24.67352104], [71.57717896, 24.67740059], [71.58309937, 24.67653084], [71.58965302, 24.67016983], [71.592453, 24.66558838], [71.59783173, 24.66385078], [71.60486603, 24.66553116], [71.61003876, 24.66854095], [71.61659241, 24.670681], [71.61833191, 24.66836166], [71.62081909, 24.66698265], [71.62338257, 24.66424942], [71.62711334, 24.66193008], [71.6307373, 24.66255951], [71.6341629, 24.65805054], [71.64057159, 24.65608025], [71.64494324, 24.65254021], [71.64836121, 24.64640999], [71.65122223, 24.64315987], [71.65027618, 24.63993073], [71.66156006, 24.63326073], [71.66977692, 24.6365509], [71.68599701, 24.63984108], [71.71631622, 24.6543293], [71.73734283, 24.65344048], [71.74577332, 24.65427971], [71.75830841, 24.66027069], [71.78450775, 24.66885948], [71.79094696, 24.67012024], [71.79898834, 24.67052078], [71.80459595, 24.66905975], [71.80912781, 24.66592026], [71.81292725, 24.66087914], [71.81508636, 24.65468025], [71.81738281, 24.64587975], [71.81259155, 24.63252068], [71.81153107, 24.62593079], [71.81176758, 24.62182045], [71.8155365, 24.61832809], [71.82141113, 24.61658096], [71.83860779, 24.61638069], [71.84657288, 24.61486053], [71.85553741, 24.60609055], [71.85839081, 24.60416985], [71.8609314, 24.61405945], [71.86470032, 24.6195507], [71.86868286, 24.62347984], [71.867836, 24.63002014], [71.86255646, 24.64948082], [71.86276245, 24.65475273], [71.86495972, 24.66291046], [71.87110138, 24.67221832], [71.87647247, 24.67515945], [71.8813324, 24.67567062], [71.89095306, 24.67008972], [71.89379883, 24.6657505], [71.90416718, 24.66904068], [71.91210175, 24.66959953], [71.92008209, 24.66735077], [71.92592621, 24.66208267], [71.92597961, 24.65871048], [71.92405701, 24.65448189], [71.92137909, 24.65223122], [71.91723633, 24.65089035], [71.91879272, 24.64620018], [71.92800903, 24.63381195], [71.93450928, 24.62685013], [71.93952179, 24.62760162], [71.94419098, 24.62677956], [71.94744873, 24.62758064], [71.95079041, 24.6325798], [71.96218109, 24.63845062], [71.96740723, 24.63793945], [71.97914886, 24.64696121], [71.98282623, 24.65085983], [71.99077606, 24.65139961], [71.99324799, 24.65312958], [71.99339294, 24.65670967], [71.98987579, 24.66704941], [71.99407959, 24.67755127], [72.001091, 24.68297005], [72.00730896, 24.68598175], [72.03161621, 24.69181061], [72.04087067, 24.69547081], [72.05249023, 24.70578957], [72.07958221, 24.70033836], [72.08525085, 24.69700813], [72.0923233, 24.67476082], [72.08239746, 24.66847038], [72.08547974, 24.65872002], [72.0848999, 24.65275192], [72.09091187, 24.64869118], [72.10186005, 24.64333916], [72.11654663, 24.63336945], [72.12100983, 24.63196182], [72.12529755, 24.63163948], [72.13475037, 24.63380051], [72.14595032, 24.63487053], [72.15072632, 24.63410187], [72.15357971, 24.63110924], [72.16101074, 24.61944962], [72.16166687, 24.61581039], [72.16539764, 24.61450005], [72.17559052, 24.61271095], [72.18589783, 24.60943031], [72.20144653, 24.6161499], [72.20697021, 24.61207008], [72.21063995, 24.61256981], [72.20828247, 24.61725044], [72.21096802, 24.61901093], [72.21637726, 24.62021255], [72.2299881, 24.63288116], [72.23362732, 24.63080978], [72.24202728, 24.62334061], [72.24893188, 24.62078094], [72.25421906, 24.62138939], [72.26059723, 24.62074089], [72.27414703, 24.62214279], [72.27474976, 24.62223053], [72.29366302, 24.61320114], [72.29969788, 24.61619949], [72.30619812, 24.61497116], [72.30932617, 24.6119709], [72.31505585, 24.60887146], [72.3237381, 24.60894012], [72.33100891, 24.61188126], [72.34020233, 24.62298965], [72.34797668, 24.62132263], [72.35378265, 24.61810112], [72.35309601, 24.61624908], [72.35011292, 24.6146698], [72.34896851, 24.61199188], [72.34915161, 24.60231018], [72.34546661, 24.59945107], [72.34221649, 24.59352112], [72.3259964, 24.58686066], [72.31784821, 24.58496094], [72.31402588, 24.58539009], [72.30890656, 24.5908699], [72.30458069, 24.59727287], [72.30033112, 24.60015106], [72.29305267, 24.59708977], [72.27925873, 24.60000038], [72.27671051, 24.59918022], [72.25099945, 24.58016014], [72.27168274, 24.55015945], [72.28508759, 24.55743027], [72.29003906, 24.55828094], [72.29170227, 24.55528069], [72.29191589, 24.55046082], [72.29393005, 24.54491043], [72.29338837, 24.53999138], [72.29512024, 24.5384407], [72.30182648, 24.54055977], [72.33241272, 24.54244041], [72.33701324, 24.5441494], [72.33362579, 24.55583954], [72.3348999, 24.55867958], [72.34057617, 24.55751038], [72.34327698, 24.55496979], [72.34860992, 24.55348969], [72.35793304, 24.55251122], [72.3615799, 24.54331017], [72.36546326, 24.53934097], [72.36860657, 24.5365181], [72.373909, 24.53735924], [72.37419891, 24.53354073], [72.37523651, 24.53164291], [72.37486267, 24.5299511], [72.37088013, 24.52876091], [72.38632202, 24.50051117], [72.39052582, 24.49884987], [72.39772034, 24.50028038], [72.42111206, 24.50806808], [72.4260025, 24.50832939], [72.4360199, 24.50536919], [72.44248962, 24.50424957], [72.44561005, 24.49962044], [72.44815063, 24.49332047], [72.44558716, 24.4877491], [72.43863678, 24.47907257], [72.43667603, 24.46051025], [72.44616699, 24.44826126], [72.45623779, 24.43812943], [72.45761871, 24.43285179], [72.46127319, 24.42685127], [72.46375275, 24.42094994], [72.4646759, 24.40711975], [72.48744202, 24.4054203], [72.50099945, 24.4073391], [72.50771332, 24.40993118], [72.51000214, 24.41834259], [72.50441742, 24.43089104], [72.50055695, 24.45029068], [72.51174164, 24.4473896], [72.51387787, 24.46455956], [72.51877594, 24.47299194], [72.54213715, 24.50486946], [72.54457855, 24.5068512], [72.54772186, 24.50559235], [72.55181122, 24.50032806], [72.55914307, 24.49464035], [72.57422638, 24.48814011], [72.5823822, 24.47746086], [72.58850098, 24.47250175], [72.60412598, 24.46910858], [72.63932037, 24.46146011], [72.658638, 24.45643044], [72.67443085, 24.45696259], [72.68460846, 24.45919991], [72.69301605, 24.46016121], [72.69725037, 24.45721054], [72.69753265, 24.452631], [72.69264221, 24.4414196], [72.69346619, 24.41928101], [72.70664215, 24.39133263], [72.71747589, 24.37555122], [72.73253632, 24.3612709], [72.73928833, 24.35884094], [72.74871826, 24.35752106], [72.77282715, 24.36074066], [72.79325104, 24.36016083], [72.81534576, 24.35819054], [72.82924652, 24.36498833], [72.83905029, 24.36478043], [72.85367584, 24.36601067], [72.86811829, 24.36581039], [72.8842926, 24.36084938], [72.90055847, 24.35144806], [72.91002655, 24.34049988], [72.91557312, 24.33280945], [72.9210968, 24.32723999], [72.92391205, 24.32632256], [72.92903137, 24.33265114], [72.9337616, 24.33618927], [72.94602203, 24.33928108], [72.96177673, 24.34877014], [72.96537018, 24.35110855], [72.97749329, 24.35884094], [72.99146271, 24.36397171], [72.99201202, 24.3682003], [72.98748016, 24.37511063], [72.98127747, 24.38005066], [72.974617, 24.38343048], [72.9661026, 24.38303185], [72.96327972, 24.38373947], [72.96418762, 24.39222145], [72.97245026, 24.40192986], [72.97939301, 24.40563965], [72.99061584, 24.42089081], [72.98931122, 24.43272972], [72.98324585, 24.44029808], [72.98100281, 24.4510498], [72.98912048, 24.45700073], [72.9980011, 24.46804047], [73.00034332, 24.47063065], [73.00676727, 24.47628021], [73.01278687, 24.48240089], [73.02185059, 24.46511269], [73.02719879, 24.46511269], [73.03320313, 24.46371078], [73.05104065, 24.46525955], [73.0533905, 24.4664917], [73.05728149, 24.4726181], [73.06713867, 24.47458267], [73.07006073, 24.48088074], [73.07485962, 24.48269081], [73.08381653, 24.49020958], [73.09438324, 24.49472809], [73.09892273, 24.49149132], [73.098526, 24.47261047], [73.10719299, 24.45681953], [73.10762787, 24.45181084], [73.1065979, 24.44536972], [73.10883331, 24.43241119], [73.10832977, 24.42632103], [73.10624695, 24.42032051], [73.09673309, 24.41720963], [73.0930481, 24.41312981], [73.09072113, 24.40878105], [73.08862305, 24.40008926], [73.08442688, 24.39764977], [73.08496094, 24.39447021], [73.09825897, 24.38552094], [73.10865021, 24.38746262], [73.11119843, 24.38680077], [73.11863708, 24.37574005], [73.127388, 24.36882973], [73.13730621, 24.36444092], [73.14531708, 24.36305046], [73.15455627, 24.35642815], [73.16200256, 24.35268021], [73.16996765, 24.35066986], [73.18017578, 24.35066986], [73.19039154, 24.35577011], [73.20072937, 24.36679077], [73.21098328, 24.37541962], [73.23147583, 24.36466026], [73.22561646, 24.35647964], [73.21644592, 24.35046959], [73.21105957, 24.33423042], [73.20140076, 24.33409119], [73.19792938, 24.33977127], [73.19294739, 24.34357071], [73.18701172, 24.33494949], [73.18612671, 24.32697105], [73.18643951, 24.3201828], [73.18479919, 24.30911064], [73.18062592, 24.30149078], [73.1733017, 24.30105019], [73.15123749, 24.31079292], [73.1449585, 24.30785751], [73.14385223, 24.29948044], [73.13894653, 24.28005028], [73.11606598, 24.26259041], [73.10987854, 24.25399017], [73.10690308, 24.24895287], [73.10575867, 24.24431038], [73.10090637, 24.23771095], [73.10193634, 24.23485184], [73.10617065, 24.23238945], [73.11120605, 24.23111153], [73.10600281, 24.22615051], [73.10119629, 24.22327042], [73.09172821, 24.22088051], [73.08722687, 24.20079994], [73.08196259, 24.19664955], [73.08130646, 24.19185829], [73.08268738, 24.18498039], [73.09095001, 24.17527962], [73.10243988, 24.16519928], [73.11303711, 24.15779114], [73.11650848, 24.15286064], [73.11416626, 24.13858986], [73.12339783, 24.14030075], [73.13846588, 24.12807083], [73.14715576, 24.12255096], [73.1554718, 24.12186813], [73.16114807, 24.12005997], [73.16755676, 24.11628914], [73.17173004, 24.1113224], [73.18686676, 24.10770035], [73.19190216, 24.10654831], [73.19386292, 24.10518265], [73.19760132, 24.11079025], [73.19999695, 24.10839081], [73.21227264, 24.10414124], [73.21578979, 24.10169983], [73.22381592, 24.09822083], [73.22264862, 24.09350967], [73.22041321, 24.08930016], [73.21672058, 24.08526039], [73.21438599, 24.08019066], [73.21366882, 24.07578087], [73.20910645, 24.06664085], [73.20108795, 24.05739021], [73.19893646, 24.05146027], [73.20063782, 24.0452404], [73.20812225, 24.03948021], [73.2232666, 24.03239059], [73.22933197, 24.02811813], [73.22940063, 24.02403069], [73.23513794, 24.02011108], [73.24032593, 24.01831818], [73.2425766, 24.01279831], [73.24582672, 24.01070976], [73.25254059, 24.01111984], [73.25637817, 24.01317978], [73.26390839, 24.02009964], [73.2753067, 24.02802086], [73.28275299, 24.02881813], [73.29103088, 24.02740288], [73.2979126, 24.03676987], [73.3068161, 24.05145073], [73.31140137, 24.05461121], [73.31845856, 24.0567894], [73.32656097, 24.0625], [73.33249664, 24.07368279], [73.33451843, 24.08256912], [73.33188629, 24.10400963], [73.33518219, 24.1151104], [73.34276581, 24.11582947], [73.36081696, 24.11409187], [73.37346649, 24.1281395], [73.36962128, 24.11249161], [73.36962891, 24.08798027], [73.37475586, 24.08708191], [73.37979126, 24.08415031], [73.38526917, 24.07958031], [73.39659119, 24.07253075], [73.40419006, 24.06520081], [73.41375732, 24.05106926], [73.41140747, 24.03484154], [73.41146851, 24.02518272], [73.40925598, 24.01585007], [73.41081238, 24.00255013], [73.41060638, 23.99833107], [73.40505981, 23.99054909], [73.41396332, 23.98843193], [73.41957855, 23.98266029], [73.42146301, 23.97467041], [73.41912842, 23.95379829], [73.42038727, 23.93644905], [73.42468262, 23.93106079], [73.42346954, 23.92760086], [73.42012024, 23.92340088], [73.40775299, 23.91612053], [73.40225983, 23.91822052], [73.39611053, 23.91679192], [73.3864975, 23.90577126], [73.38237762, 23.89500046], [73.37695313, 23.88879967], [73.37124634, 23.87585068], [73.36606598, 23.86907005], [73.36207581, 23.86186981], [73.35984802, 23.85462952], [73.36952209, 23.83855057], [73.3719101, 23.83208275], [73.37267303, 23.8219223], [73.37042236, 23.81438065], [73.36283112, 23.79775047], [73.36112976, 23.79165077], [73.36264801, 23.78742981], [73.36769867, 23.78364944], [73.37133789, 23.77787018], [73.37590027, 23.76667023], [73.3898468, 23.76926041], [73.39391327, 23.77846146], [73.40000916, 23.78397751], [73.408638, 23.78359032], [73.41349792, 23.78110123], [73.42048645, 23.77933121], [73.42765808, 23.7664299], [73.43218994, 23.76208115], [73.45082092, 23.75259018], [73.45128632, 23.74884033], [73.45493317, 23.73971939], [73.46276855, 23.73430824], [73.47289276, 23.72578049], [73.47661591, 23.72103119], [73.47927094, 23.70897293], [73.48561096, 23.70500946], [73.50192261, 23.70664978], [73.50853729, 23.70333099], [73.51035309, 23.69697952], [73.51122284, 23.68008041], [73.51094055, 23.67338943], [73.50779724, 23.66263008], [73.50720978, 23.6577301], [73.50052643, 23.65073013], [73.5116272, 23.64508057], [73.50845337, 23.63939095], [73.50137329, 23.63544083], [73.50109863, 23.63383102], [73.50569153, 23.62885094], [73.51024628, 23.62068939], [73.51348877, 23.61681175], [73.52672577, 23.6106205], [73.53224182, 23.61354065], [73.54141998, 23.62265015], [73.55297852, 23.63134956], [73.57074738, 23.65351105], [73.57727051, 23.65536118], [73.60853577, 23.65430832], [73.61901855, 23.6514225], [73.63295746, 23.63853073], [73.64225769, 23.63126945], [73.65039825, 23.62688065], [73.66073608, 23.62290192], [73.64998627, 23.60769272], [73.64804077, 23.59864044], [73.64872742, 23.59067917], [73.65120697, 23.58086967], [73.6497879, 23.57534027], [73.64286804, 23.56962013], [73.63825989, 23.56254959], [73.63713074, 23.54801941], [73.63700104, 23.53112984], [73.65219879, 23.52140236], [73.65733337, 23.51618004], [73.65844727, 23.51415253], [73.65841675, 23.50411987], [73.65258789, 23.50093079], [73.64491272, 23.49873924], [73.64382172, 23.4967804], [73.64064789, 23.47304153], [73.63275146, 23.45239258], [73.63806915, 23.45034027], [73.65320587, 23.44049072], [73.66081238, 23.44725037], [73.6687088, 23.451931], [73.68190765, 23.45708084], [73.69394684, 23.45890045], [73.704216, 23.45578194], [73.70960236, 23.44449043], [73.71356201, 23.43367958], [73.71721649, 23.41884041], [73.7203064, 23.4148407], [73.72614288, 23.41266251], [73.72881317, 23.41829109], [73.7339859, 23.42489243], [73.7513504, 23.44246101], [73.7565918, 23.4495697], [73.76065063, 23.4568119], [73.7647171, 23.45857811], [73.77099609, 23.45257759], [73.7739563, 23.44586945], [73.77784729, 23.44231987], [73.7830658, 23.43461037], [73.79416656, 23.43556976], [73.82688904, 23.44684029], [73.83213043, 23.44675064], [73.83679962, 23.44013977], [73.8364563, 23.43069077], [73.85743713, 23.40479279], [73.86676025, 23.39577103], [73.87708282, 23.37833023], [73.87944031, 23.36811066], [73.89118195, 23.35860062], [73.89492798, 23.35258102], [73.89427185, 23.33713913], [73.90122986, 23.3359127], [73.91398621, 23.33597946], [73.92784119, 23.33788109], [73.93889618, 23.34141922], [73.94262695, 23.34593964], [73.9438324, 23.35359955], [73.94371033, 23.36634064], [73.94729614, 23.3735199], [73.95691681, 23.37763977], [73.96247101, 23.38138962], [73.97103119, 23.37713814], [73.97889709, 23.36783981], [73.98348999, 23.35984039], [73.98446655, 23.34945107], [73.98696899, 23.34123993], [73.99077606, 23.33762932], [74.00380707, 23.33620071], [74.02361298, 23.33288193], [74.03266144, 23.33234978], [74.03006744, 23.31994057], [74.03592682, 23.31261063], [74.03759766, 23.30574036], [74.04138184, 23.30700111], [74.04769897, 23.31093979], [74.04968262, 23.30709076], [74.04447174, 23.29609108], [74.04873657, 23.29506111], [74.07652283, 23.29819107], [74.08973694, 23.29799271], [74.10166168, 23.29574966], [74.10658264, 23.2941227], [74.11106873, 23.28572083], [74.11387634, 23.27734947], [74.11856079, 23.27536964], [74.12989044, 23.27272034], [74.13378143, 23.26945114], [74.1361084, 23.26472092], [74.13652039, 23.24480057], [74.1388092, 23.23637962], [74.13865662, 23.23092079], [74.13948059, 23.2268219], [74.13510132, 23.22006989], [74.13391113, 23.21517944], [74.12470245, 23.20656967], [74.12349701, 23.20170021], [74.12252045, 23.19157028], [74.12452698, 23.19044113], [74.1244812, 23.18799973], [74.12702179, 23.17885017], [74.13051605, 23.17764282], [74.13617706, 23.17770958], [74.14569092, 23.17523003], [74.14845276, 23.17205048], [74.15516663, 23.15775108], [74.16069031, 23.15554047], [74.16493988, 23.15648079], [74.18299103, 23.15221977], [74.18660736, 23.15252113], [74.18914795, 23.15790939], [74.18953705, 23.17184067], [74.19412231, 23.17856026], [74.20008087, 23.18374062], [74.2041626, 23.18909073], [74.20754242, 23.19205093], [74.2293396, 23.184021], [74.2370224, 23.18270111], [74.24603271, 23.18825912], [74.24977875, 23.17843056], [74.25242615, 23.17616844], [74.25701904, 23.17472076], [74.26185608, 23.17160034], [74.26706696, 23.16596985], [74.2718277, 23.15600967], [74.27661896, 23.13977242], [74.27762604, 23.13397026], [74.27954102, 23.12997055], [74.28491211, 23.12458038], [74.28814697, 23.11873055], [74.2820282, 23.10643005], [74.28077698, 23.10098076], [74.28253937, 23.09501266], [74.28678131, 23.0916996], [74.30391693, 23.08389282], [74.31017303, 23.07954025], [74.31552124, 23.07212067], [74.31829071, 23.06725121], [74.32277679, 23.06269073], [74.32531738, 23.04817009], [74.32772064, 23.04269028], [74.33191681, 23.03919029], [74.33886719, 23.03582954], [74.3467865, 23.03394127], [74.34919739, 23.03024101], [74.35066223, 23.01552963], [74.35536194, 23.00307083], [74.35771179, 23.00037193], [74.36546326, 22.98981094], [74.3687973, 22.98355103], [74.3707962, 22.98005295], [74.3707962, 22.97723007], [74.36805725, 22.97653008], [74.36297607, 22.97793007], [74.35713959, 22.97722054], [74.35481262, 22.97511101], [74.34971619, 22.96876907], [74.34163666, 22.96469116], [74.34438324, 22.95836258], [74.34792328, 22.95344925], [74.35417938, 22.9471302], [74.36003876, 22.94222069], [74.3620224, 22.93309021], [74.36553955, 22.92957115], [74.37140656, 22.92605972], [74.37454987, 22.9225502], [74.37769318, 22.91553116], [74.38160706, 22.90990829], [74.38826752, 22.90710258], [74.39293671, 22.90219116], [74.400383, 22.89937973], [74.40817261, 22.90431023], [74.41243744, 22.91274834], [74.41870117, 22.9183712], [74.42375946, 22.91978073], [74.42843628, 22.91978073], [74.4319458, 22.92258072], [74.43585968, 22.92048073], [74.43859863, 22.9176712], [74.44406128, 22.92259979], [74.45147705, 22.92399979], [74.45500946, 22.91838074], [74.45812988, 22.91628265], [74.46282196, 22.91345978], [74.46360016, 22.90714073], [74.466362, 22.90081024], [74.46636963, 22.8944912], [74.46871185, 22.88746071], [74.47146606, 22.88043976], [74.47380066, 22.87479973], [74.47421265, 22.86778069], [74.47540283, 22.86497116], [74.47891998, 22.85864067], [74.4719162, 22.83265114], [74.46881866, 22.82351112], [74.46494293, 22.81508064], [74.45947266, 22.81225967], [74.45168304, 22.81085968], [74.4438858, 22.81014061], [74.4391861, 22.80944061], [74.43881989, 22.80521965], [74.44078064, 22.79961014], [74.44039917, 22.79327965], [74.43923187, 22.78555107], [74.43534851, 22.77922249], [74.43107605, 22.77008057], [74.42523956, 22.76024055], [74.42057037, 22.75743103], [74.41707611, 22.75111008], [74.41438293, 22.74477959], [74.40851593, 22.73705101], [74.40307617, 22.73070908], [74.40078735, 22.72017097], [74.40117645, 22.71244049], [74.40080261, 22.70681953], [74.39691162, 22.70050049], [74.39692688, 22.69207001], [74.39424133, 22.68573952], [74.38994598, 22.67801285], [74.38490295, 22.66957092], [74.38414001, 22.66043091], [74.38456726, 22.65057945], [74.38418579, 22.64356995], [74.38108826, 22.63863945], [74.37288666, 22.63652992], [74.36395264, 22.63652039], [74.35224915, 22.63932037], [74.34406281, 22.6421299], [74.33705139, 22.64071274], [74.33434296, 22.64141083], [74.33081055, 22.64351082], [74.32807922, 22.64421082], [74.32653046, 22.64211082], [74.32537079, 22.63858986], [74.32227325, 22.63647842], [74.31720734, 22.63646126], [74.31328583, 22.63858032], [74.3094101, 22.63928032], [74.30433655, 22.63997078], [74.29888153, 22.64067078], [74.29458618, 22.64136124], [74.28991699, 22.64344978], [74.27822113, 22.64766121], [74.27472687, 22.64274025], [74.27355194, 22.64063263], [74.27160645, 22.64133263], [74.26925659, 22.64344025], [74.26535797, 22.6448307], [74.26342773, 22.64272118], [74.26226807, 22.63850975], [74.25914764, 22.63639069], [74.25641632, 22.63568115], [74.25644684, 22.63076019], [74.25840759, 22.62655067], [74.25763702, 22.62444115], [74.25374603, 22.62302971], [74.24986267, 22.62302017], [74.24754333, 22.61740112], [74.24365997, 22.61387062], [74.23665619, 22.61387062], [74.23432922, 22.6068306], [74.23008728, 22.59699059], [74.22737122, 22.59065819], [74.22622681, 22.5850296], [74.22274017, 22.58152008], [74.2184906, 22.58151054], [74.21652222, 22.57798958], [74.21383667, 22.56744003], [74.20955658, 22.5667305], [74.20332336, 22.56812096], [74.19941711, 22.57022095], [74.19007874, 22.56740189], [74.19519043, 22.56248856], [74.19557953, 22.56038094], [74.19519806, 22.55686951], [74.19171143, 22.55335045], [74.18431854, 22.54981041], [74.17887115, 22.54840088], [74.1726532, 22.54486847], [74.16802216, 22.54134941], [74.16295624, 22.53712082], [74.15869141, 22.53429985], [74.15753937, 22.53219032], [74.15795135, 22.52656937], [74.15680695, 22.52094078], [74.15332031, 22.51741982], [74.14788818, 22.51811028], [74.14321136, 22.51880074], [74.13852692, 22.52019119], [74.13347626, 22.51877975], [74.12995911, 22.52158928], [74.12760925, 22.52437973], [74.12484741, 22.53000069], [74.12211609, 22.53560829], [74.11859894, 22.53981018], [74.11351776, 22.54120064], [74.10964966, 22.53839111], [74.10575104, 22.53767014], [74.10069275, 22.54117012], [74.09327698, 22.54465103], [74.08428955, 22.54955101], [74.07805634, 22.55162811], [74.06674957, 22.55089951], [74.05628204, 22.5477829], [74.0500412, 22.54565048], [74.04463959, 22.54212189], [74.04231262, 22.53718948], [74.04078674, 22.5301609], [74.04315948, 22.52384949], [74.04358673, 22.51682091], [74.0389328, 22.51400185], [74.03466797, 22.50836945], [74.03511047, 22.50274277], [74.03591919, 22.49641991], [74.03708649, 22.49151039], [74.04293823, 22.49082947], [74.04566956, 22.49294281], [74.04640961, 22.49715996], [74.0499115, 22.49998283], [74.0545578, 22.50139809], [74.05609894, 22.50562859], [74.05879974, 22.51054955], [74.06188965, 22.51126099], [74.0650177, 22.51057053], [74.06968689, 22.50988007], [74.07396698, 22.51059914], [74.07865143, 22.50921059], [74.08136749, 22.50851822], [74.08526611, 22.50851822], [74.08644867, 22.50502014], [74.08570099, 22.4987011], [74.08727264, 22.49378014], [74.08963776, 22.48887062], [74.09043884, 22.48254967], [74.08889771, 22.47973251], [74.08538818, 22.48182106], [74.08344269, 22.48463058], [74.08030701, 22.48603058], [74.07878876, 22.48111153], [74.07843018, 22.47339058], [74.07808685, 22.46564293], [74.08583832, 22.46707916], [74.09050751, 22.46920013], [74.0951767, 22.46920967], [74.10024261, 22.46923256], [74.10334778, 22.46783066], [74.10610962, 22.4622097], [74.10573578, 22.45589066], [74.10225677, 22.4509697], [74.10073853, 22.44534111], [74.10270691, 22.4397316], [74.10507202, 22.43341064], [74.11051941, 22.42921066], [74.11637115, 22.42642021], [74.1230011, 22.4208107], [74.12689972, 22.42012978], [74.13037872, 22.42154121], [74.13037872, 22.42505074], [74.1307373, 22.42996979], [74.13111115, 22.43629074], [74.13417816, 22.44262123], [74.13728333, 22.44824982], [74.14074707, 22.4538784], [74.14424896, 22.45671082], [74.15122986, 22.45671844], [74.15628815, 22.4567318], [74.15672302, 22.45041084], [74.15596008, 22.44548988], [74.15598297, 22.43987274], [74.15873718, 22.43494987], [74.16107178, 22.43215942], [74.1672821, 22.43217087], [74.17077637, 22.4335804], [74.17153931, 22.43779182], [74.17267609, 22.44201279], [74.18280029, 22.44275093], [74.18667603, 22.44415092], [74.18743134, 22.44767189], [74.18624878, 22.45259285], [74.18430328, 22.45609093], [74.18234253, 22.46030045], [74.18270874, 22.46453094], [74.18541718, 22.46944046], [74.19082642, 22.47788048], [74.19785309, 22.47509956], [74.20252991, 22.47229958], [74.20449066, 22.46668053], [74.20450592, 22.46105003], [74.20493317, 22.45474052], [74.2045517, 22.44701004], [74.20459747, 22.44067955], [74.20461273, 22.43717194], [74.21160126, 22.43437004], [74.21626282, 22.43439102], [74.21663666, 22.43931961], [74.21856689, 22.4428196], [74.22054291, 22.4421196], [74.22364044, 22.44001007], [74.22831726, 22.44003105], [74.23725891, 22.43934059], [74.24659729, 22.4365406], [74.25402069, 22.43305969], [74.25945282, 22.42885017], [74.26412201, 22.42464066], [74.26648712, 22.4183197], [74.26999664, 22.41481018], [74.2700119, 22.41059113], [74.27120972, 22.40498161], [74.27471161, 22.40357971], [74.27820587, 22.40287971], [74.28172302, 22.40007973], [74.28830719, 22.39797974], [74.29418182, 22.39446831], [74.29106903, 22.39166069], [74.2871933, 22.39306068], [74.28135681, 22.39375114], [74.27394867, 22.3930397], [74.26850891, 22.39443016], [74.26345062, 22.39653969], [74.25798798, 22.40003014], [74.25723267, 22.39511108], [74.25685883, 22.39019966], [74.25611115, 22.38599014], [74.25300598, 22.38387108], [74.24951935, 22.38315964], [74.24600983, 22.38315964], [74.24563599, 22.37753105], [74.24019623, 22.37681961], [74.2351532, 22.37821007], [74.23085022, 22.37962151], [74.22543335, 22.37820053], [74.22582245, 22.37540054], [74.22737885, 22.37259293], [74.22738647, 22.36907005], [74.22663116, 22.36485291], [74.22704315, 22.35853958], [74.22355652, 22.35783005], [74.21656036, 22.35781288], [74.21344757, 22.35921097], [74.21111298, 22.36273003], [74.20993042, 22.36621094], [74.20680237, 22.36762047], [74.20603943, 22.36341095], [74.20565796, 22.35989952], [74.20609283, 22.35357094], [74.20533752, 22.34794998], [74.2022171, 22.34303093], [74.198349, 22.34301949], [74.1979599, 22.34793282], [74.19754028, 22.35073853], [74.19483185, 22.34934044], [74.19484711, 22.34371948], [74.19644165, 22.33390045], [74.19568634, 22.32543945], [74.19106293, 22.32192993], [74.18406677, 22.32261086], [74.17588806, 22.32471275], [74.16384125, 22.32678986], [74.15409851, 22.32887077], [74.14362335, 22.33026123], [74.1342926, 22.3323307], [74.13153076, 22.33794975], [74.13034821, 22.34355927], [74.12914276, 22.35268974], [74.12445831, 22.35830116], [74.11709595, 22.35757065], [74.1162796, 22.36108971], [74.11508942, 22.36740112], [74.11196136, 22.37161255], [74.10534668, 22.37299156], [74.09989929, 22.37297821], [74.09836578, 22.36876106], [74.09527588, 22.36244011], [74.08985901, 22.36241913], [74.08364105, 22.36239052], [74.07702637, 22.36238098], [74.07198334, 22.36024094], [74.07084656, 22.35462952], [74.07164764, 22.34901047], [74.0743866, 22.34621048], [74.07596588, 22.34130287], [74.07405853, 22.33638191], [74.06826782, 22.33073044], [74.06828308, 22.32582283], [74.06674194, 22.31739044], [74.06680298, 22.31105995], [74.06643677, 22.30544281], [74.06254578, 22.3068409], [74.05905151, 22.30541039], [74.0579071, 22.29980087], [74.05832672, 22.29348183], [74.05989075, 22.29067039], [74.0591507, 22.28574944], [74.06149292, 22.28084183], [74.06463623, 22.2759304], [74.06891632, 22.27243042], [74.07242584, 22.26893044], [74.07826996, 22.2682476], [74.07943726, 22.26333809], [74.07987213, 22.25842094], [74.07872772, 22.25278091], [74.08067322, 22.24999046], [74.08535004, 22.24790001], [74.08922577, 22.24720955], [74.09158325, 22.24370003], [74.0892868, 22.24019051], [74.08460999, 22.23805809], [74.07842255, 22.23735809], [74.07454681, 22.2345295], [74.07338715, 22.22960091], [74.07578278, 22.22187805], [74.08159637, 22.22050095], [74.08744049, 22.22051048], [74.09440613, 22.221241], [74.10177612, 22.22056007], [74.10761261, 22.22056961], [74.11383057, 22.21918106], [74.11927032, 22.21638107], [74.12277985, 22.21290016], [74.12240601, 22.20866013], [74.12124634, 22.2051506], [74.12245941, 22.19812965], [74.12364197, 22.19252014], [74.12211609, 22.18760109], [74.12291718, 22.18198013], [74.12409973, 22.17776108], [74.12490845, 22.17215919], [74.1264801, 22.16654015], [74.13189697, 22.16444016], [74.13504028, 22.1616497], [74.13349152, 22.15813065], [74.13314056, 22.15321922], [74.13355255, 22.14619255], [74.12967682, 22.14266014], [74.12738037, 22.13774109], [74.12663269, 22.13212013], [74.12782288, 22.12721062], [74.13130951, 22.12441063], [74.13134766, 22.1201992], [74.13020325, 22.11387062], [74.12905884, 22.10825157], [74.12906647, 22.10333824], [74.13027191, 22.09770966], [74.13259125, 22.09632111], [74.13800049, 22.09845161], [74.14382172, 22.10126114], [74.15000916, 22.10408974], [74.15466309, 22.10550117], [74.15621185, 22.10409927], [74.15856171, 22.10200119], [74.16204834, 22.10271072], [74.1655426, 22.10271835], [74.17021179, 22.1013298], [74.17214203, 22.09852982], [74.17411041, 22.09641075], [74.17215729, 22.09360123], [74.17527008, 22.09151077], [74.17875671, 22.09011078], [74.18070984, 22.08660126], [74.17646027, 22.08449173], [74.17064667, 22.08447075], [74.16755676, 22.08236122], [74.16602325, 22.07814026], [74.16487885, 22.07393265], [74.16179657, 22.07110977], [74.16336823, 22.06409073], [74.16298676, 22.06056976], [74.15447998, 22.0577507], [74.14906311, 22.05632019], [74.13783264, 22.05350113], [74.13939667, 22.0506897], [74.14404297, 22.04788971], [74.14523315, 22.04368019], [74.14100647, 22.04086113], [74.13208008, 22.03873062], [74.1251297, 22.03589058], [74.12088776, 22.03026962], [74.11664581, 22.02464104], [74.10890198, 22.02181053], [74.10118866, 22.01828003], [74.09770203, 22.01545906], [74.10045624, 22.01055908], [74.1003418, 22.00159264], [74.10500336, 21.99893951], [74.1082077, 21.99835968], [74.11688995, 21.99863052], [74.12773132, 21.99376106], [74.14198303, 21.99123192], [74.14959717, 21.98880959], [74.15384674, 21.98641968], [74.1518631, 21.98089027], [74.15320587, 21.97557068], [74.14560699, 21.97400093], [74.14366913, 21.97222137], [74.14335632, 21.96988106], [74.1453476, 21.96461105], [74.14890289, 21.96071053], [74.14467621, 21.95656967], [74.14601898, 21.9540596], [74.13816071, 21.95337105], [74.11364746, 21.94470024], [74.09867096, 21.9376297], [74.07151031, 21.92960167], [74.06162262, 21.92805099], [74.056427, 21.92641068], [74.04666901, 21.9228096], [74.03560638, 21.9160099], [74.02304077, 21.90597153], [74.01168823, 21.9005394], [74.00489044, 21.89936066], [73.97973633, 21.88750076], [73.9608078, 21.87599182], [73.9491806, 21.87034035], [73.93636322, 21.86314964], [73.92192841, 21.85658264], [73.90666962, 21.85363007], [73.89951324, 21.85449028], [73.87960052, 21.83864021], [73.86374664, 21.83665085], [73.84152222, 21.83850098], [73.82792664, 21.83485985], [73.8162384, 21.82856941], [73.81051636, 21.82333755], [73.81356812, 21.81011963], [73.81759644, 21.80850029], [73.82759857, 21.81193924], [73.83210754, 21.81085014], [73.83351898, 21.80516052], [73.83893585, 21.8001709], [73.83421326, 21.79661179], [73.83567047, 21.79347992], [73.84496307, 21.79068184], [73.8441391, 21.78711128], [73.83837891, 21.7841301], [73.84294891, 21.77213097], [73.84129333, 21.76865005], [73.83120728, 21.76288986], [73.84635925, 21.74200058], [73.85633087, 21.73464012], [73.86029816, 21.73301125], [73.86511993, 21.72937965], [73.87123108, 21.72191811], [73.8783493, 21.71693039], [73.88504791, 21.71442986], [73.8902359, 21.71064949], [73.89396667, 21.70314026], [73.8963623, 21.70028114], [73.89810181, 21.66727066], [73.89444733, 21.6570797], [73.89126587, 21.65151024], [73.88562775, 21.64505959], [73.87026978, 21.63879013], [73.86025238, 21.64184761], [73.8530426, 21.63586998], [73.84523773, 21.63315964], [73.83854675, 21.63537979], [73.8290329, 21.63978958], [73.80882263, 21.63571167], [73.80013275, 21.63463974], [73.79086304, 21.6287899], [73.78761292, 21.62504959], [73.78952789, 21.62091064], [73.79057312, 21.61850929], [73.80683899, 21.60237122], [73.81845093, 21.60233116], [73.82315063, 21.6006794], [73.82450104, 21.59828949], [73.82905579, 21.57295036], [73.83376312, 21.55348015], [73.84015656, 21.5369091], [73.84503174, 21.5215683], [73.84989166, 21.51098061], [73.85401154, 21.50726128], [73.86078644, 21.49582291], [73.87030029, 21.49725914], [73.87684631, 21.50118828], [73.88020325, 21.5078907], [73.88256836, 21.50978279], [73.8866272, 21.50468063], [73.89707184, 21.50604248], [73.9036026, 21.50875282], [73.91004944, 21.51330185], [73.91047668, 21.52017021], [73.9260788, 21.51959991], [73.92839813, 21.52062988], [73.93099213, 21.52299118], [73.93377686, 21.52359009], [73.93614197, 21.52244949], [73.93762207, 21.5206604], [73.93940735, 21.51011086], [73.95358276, 21.51580048], [73.95728302, 21.51647186], [73.96111298, 21.51929855], [73.96276093, 21.53787994], [73.96631622, 21.53907013], [73.96985626, 21.5385685], [73.97335815, 21.53141022], [73.97445679, 21.52408028], [73.98219299, 21.5218029], [73.98568726, 21.5213604], [73.9875412, 21.52240944], [73.98252106, 21.53573036], [73.98178864, 21.53977013], [73.98352051, 21.54204178], [74.00534058, 21.54076958], [74.0190506, 21.55051041], [74.02555847, 21.55261993], [74.04168701, 21.55134964], [74.04714966, 21.54968071], [74.0542984, 21.5521698], [74.05905914, 21.55568123], [74.05993652, 21.5560894], [74.06082916, 21.55652046], [74.0617218, 21.55695152], [74.06260681, 21.55738068], [74.06349945, 21.55779266], [74.06440735, 21.55817986], [74.06534576, 21.55852127], [74.06626892, 21.55886078], [74.06723022, 21.55914116], [74.06822205, 21.55937195], [74.06920624, 21.55950928], [74.06978607, 21.55953026], [74.07019043, 21.55953979], [74.07118988, 21.55953979], [74.07218933, 21.55953979], [74.07285309, 21.55953026], [74.07318115, 21.55953026], [74.07367706, 21.55952263], [74.07418823, 21.55949974], [74.07483673, 21.55948067], [74.07518768, 21.55945969], [74.07621002, 21.55941963], [74.07727051, 21.55933952], [74.07818604, 21.55927086], [74.07920837, 21.55919075], [74.08019257, 21.55907822], [74.08117676, 21.5589695], [74.08216095, 21.5588398], [74.08315277, 21.55869293], [74.08407593, 21.55842972], [74.08502197, 21.55804062], [74.08522797, 21.5579319], [74.08592987, 21.55758286], [74.08683014, 21.55714035], [74.08776855, 21.55677032], [74.08872223, 21.55657005], [74.08914185, 21.55657005], [74.08970642, 21.55656052], [74.09068298, 21.55655289], [74.09168243, 21.55657959], [74.09266663, 21.55661964], [74.09321594, 21.55665016], [74.09365082, 21.55668259], [74.09416199, 21.5567112], [74.0946579, 21.55673981], [74.09564972, 21.55682182], [74.0966568, 21.55690956], [74.09764862, 21.55700111], [74.09866333, 21.5571003], [74.09966278, 21.55721092], [74.10064697, 21.55731964], [74.10166931, 21.55742836], [74.10264587, 21.55754089], [74.10367584, 21.55763817], [74.10463715, 21.55774117], [74.10566711, 21.55784035], [74.10665894, 21.55792236], [74.10765839, 21.55798912], [74.10813904, 21.55801964], [74.10864258, 21.55804825], [74.10913849, 21.55808067], [74.10964203, 21.55811119], [74.11062622, 21.55813026], [74.11160278, 21.55815125], [74.11260986, 21.55815125], [74.11358643, 21.55809975], [74.11453247, 21.55783081], [74.11546326, 21.55744171], [74.11637115, 21.5569706], [74.11728668, 21.55652809], [74.11821747, 21.55615044], [74.11917114, 21.55590057], [74.12016296, 21.55586052], [74.12114716, 21.55584908], [74.12216949, 21.55590057], [74.12319183, 21.55598068], [74.1242218, 21.55607986], [74.12526703, 21.55622101], [74.12631989, 21.55636024], [74.12734985, 21.55649948], [74.12840271, 21.55665016], [74.12940979, 21.5567894], [74.13041687, 21.55689049], [74.13143921, 21.5569706], [74.13240051, 21.55701828], [74.13288116, 21.55701828], [74.13334656, 21.55702972], [74.13430786, 21.55698013], [74.1352005, 21.55688095], [74.13609314, 21.55669975], [74.13677216, 21.55623055], [74.13729858, 21.55548096], [74.1377182, 21.55450058], [74.13809967, 21.55348015], [74.1385498, 21.55251122], [74.13910675, 21.55173111], [74.13983917, 21.5512104], [74.14071655, 21.55085945], [74.14170074, 21.55060959], [74.14274597, 21.55046082], [74.14380646, 21.55038071], [74.14444733, 21.55035973], [74.14483643, 21.55034065], [74.14582825, 21.55034065], [74.14681244, 21.55038071], [74.14782715, 21.55045128], [74.14879608, 21.55056953], [74.14980316, 21.55070114], [74.15078735, 21.5508709], [74.15180206, 21.55105019], [74.15276337, 21.55122948], [74.1537323, 21.55143166], [74.15473938, 21.55171967], [74.15563965, 21.55212975], [74.15632629, 21.55273056], [74.15686035, 21.5535202], [74.15735626, 21.55438042], [74.15789795, 21.55517006], [74.15854645, 21.55587959], [74.15921021, 21.55665016], [74.15988922, 21.55741119], [74.16057587, 21.55813026], [74.16133118, 21.55875969], [74.16213989, 21.55927086], [74.16301727, 21.55960083], [74.16394806, 21.55986023], [74.16488647, 21.56010056], [74.16584778, 21.5603199], [74.16681671, 21.56052971], [74.1678009, 21.56072044], [74.16879272, 21.56088066], [74.16945648, 21.56098938], [74.1697998, 21.56104279], [74.17034149, 21.56112099], [74.17079926, 21.56118011], [74.17182159, 21.56132126], [74.17282104, 21.56142807], [74.17383575, 21.56153107], [74.17485809, 21.56161118], [74.1758728, 21.56167984], [74.17687988, 21.56175041], [74.1778717, 21.56178093], [74.17888641, 21.56182098], [74.17984772, 21.56183052], [74.18081665, 21.56183815], [74.18183136, 21.56176949], [74.18286896, 21.56155968], [74.18387604, 21.56121063], [74.18483734, 21.5607605], [74.18569183, 21.56021118], [74.18634033, 21.55960083], [74.1867981, 21.55887032], [74.18704987, 21.5580101], [74.18718719, 21.55706024], [74.18725586, 21.5560627], [74.18736267, 21.55505943], [74.18750763, 21.55409813], [74.18782806, 21.55321121], [74.18821716, 21.552351], [74.18863678, 21.55150032], [74.18910217, 21.55065918], [74.18933105, 21.55027962], [74.18961334, 21.54982758], [74.19011688, 21.54902267], [74.19068146, 21.54823112], [74.19122314, 21.54746819], [74.19184875, 21.54673958], [74.19251251, 21.54603958], [74.1932373, 21.5453701], [74.19391632, 21.54470825], [74.19464111, 21.54402924], [74.19532013, 21.54334068], [74.19595337, 21.54261971], [74.19654083, 21.54186058], [74.19711304, 21.54107285], [74.19758606, 21.5402298], [74.19801331, 21.53938103], [74.19831848, 21.53849983], [74.19850159, 21.53759956], [74.19860077, 21.5366497], [74.19866943, 21.53570938], [74.19869995, 21.5352211], [74.19873047, 21.53475952], [74.1987915, 21.53420067], [74.19882965, 21.53383064], [74.19890594, 21.53342056], [74.19901276, 21.53290939], [74.19930267, 21.53193855], [74.19969177, 21.53100014], [74.20030975, 21.53033829], [74.20115662, 21.5299511], [74.20211792, 21.52963066], [74.20314789, 21.52939034], [74.204216, 21.52924919], [74.20523834, 21.52921104], [74.20617676, 21.52930069], [74.2069397, 21.52975082], [74.20726013, 21.53009987], [74.20762634, 21.53050995], [74.20797729, 21.5309124], [74.20831299, 21.53128052], [74.20897675, 21.53168106], [74.20915222, 21.53178024], [74.21009064, 21.53211021], [74.21054077, 21.53222084], [74.21108246, 21.53236008], [74.21208954, 21.53261948], [74.21304321, 21.53293037], [74.21386719, 21.53334999], [74.21444702, 21.53405952], [74.21478271, 21.53508949], [74.21514893, 21.53600121], [74.21586609, 21.53647041], [74.21673584, 21.5367012], [74.21769714, 21.53685188], [74.21820831, 21.53689957], [74.21869659, 21.53693962], [74.21974182, 21.53698921], [74.22077942, 21.53703117], [74.2218399, 21.53707123], [74.22283173, 21.53716087], [74.22383118, 21.53730965], [74.2248764, 21.53745079], [74.22595215, 21.53762054], [74.2269516, 21.53787994], [74.2277832, 21.53827095], [74.22834015, 21.53890038], [74.22856903, 21.53982162], [74.22866058, 21.5408802], [74.22875977, 21.54187965], [74.22910309, 21.54269981], [74.22994995, 21.54304123], [74.23111725, 21.54305077], [74.23213196, 21.54322052], [74.23233032, 21.54356194], [74.2325058, 21.54387093], [74.2325058, 21.54482079], [74.2323761, 21.54588127], [74.23232269, 21.54691124], [74.23246765, 21.54737091], [74.23258972, 21.54771996], [74.23323822, 21.54833031], [74.23406982, 21.54883957], [74.23506927, 21.54924011], [74.23607635, 21.54959106], [74.23668671, 21.54976082], [74.23705292, 21.54985046], [74.23810577, 21.5501194], [74.23919678, 21.55029106], [74.24017334, 21.5502491], [74.24093628, 21.54989815], [74.24125671, 21.54951286], [74.24147797, 21.54919815], [74.24194336, 21.54829979], [74.24237061, 21.54730988], [74.24279022, 21.54640961], [74.2434082, 21.54574013], [74.24429321, 21.54549026], [74.24539185, 21.54556274], [74.24646759, 21.54561043], [74.24732208, 21.5452404], [74.24796295, 21.54462051], [74.2485733, 21.54391289], [74.24916077, 21.54314041], [74.24936676, 21.54282951], [74.24970245, 21.54232979], [74.25025177, 21.54150963], [74.25078583, 21.54068947], [74.25138092, 21.53989983], [74.25197601, 21.53915024], [74.25267029, 21.53844261], [74.25335693, 21.53770065], [74.25414276, 21.53701019], [74.25496674, 21.53646088], [74.25583649, 21.53611946], [74.25679779, 21.53595161], [74.2578125, 21.53580093], [74.2588501, 21.53564072], [74.25992584, 21.5354805], [74.26098633, 21.53534126], [74.26209259, 21.53520012], [74.26319122, 21.53510094], [74.26368713, 21.53507042], [74.26426697, 21.53502083], [74.26535034, 21.53499031], [74.26638031, 21.53499985], [74.26737213, 21.53507042], [74.26834106, 21.53517914], [74.26924133, 21.53536987], [74.27011108, 21.53563118], [74.27086639, 21.53597069], [74.27155304, 21.53642082], [74.27211761, 21.53701973], [74.27258301, 21.53775024], [74.27297974, 21.5385685], [74.27332306, 21.53950119], [74.27361298, 21.5404911], [74.27387238, 21.54150009], [74.27413177, 21.5425396], [74.27440643, 21.54356956], [74.27469635, 21.54455948], [74.27501678, 21.54552078], [74.2754364, 21.54639053], [74.27590942, 21.54718018], [74.27651215, 21.54780006], [74.27735138, 21.54816818], [74.27839661, 21.54833031], [74.27951813, 21.54841995], [74.28063202, 21.54850006], [74.28163147, 21.54868126], [74.2824173, 21.54906845], [74.28282166, 21.54981041], [74.28292084, 21.5508194], [74.28305817, 21.55185127], [74.28327179, 21.552351], [74.28343201, 21.55270958], [74.28396606, 21.5535202], [74.28460693, 21.55428123], [74.28534698, 21.5549202], [74.28617096, 21.55540085], [74.28656006, 21.55549049], [74.28713226, 21.55562973], [74.28819275, 21.55574989], [74.28916931, 21.5559597], [74.2899704, 21.55641174], [74.29052734, 21.55725288], [74.29103088, 21.55817032], [74.2917099, 21.55878067], [74.2926178, 21.55898094], [74.29360962, 21.55909157], [74.29464722, 21.55914116], [74.29516602, 21.55912971], [74.2957077, 21.55912971], [74.29633331, 21.55912018], [74.29677582, 21.55909157], [74.29785156, 21.55904007], [74.29892731, 21.55901909], [74.29995728, 21.55903244], [74.30052185, 21.55906105], [74.30095673, 21.55909157], [74.30190277, 21.55922127], [74.30275726, 21.55945969], [74.30354309, 21.55982018], [74.30409241, 21.56043053], [74.30451202, 21.56126976], [74.30478668, 21.5622406], [74.30504608, 21.56328011], [74.30523682, 21.56398964], [74.30532837, 21.56429291], [74.30568695, 21.56520081], [74.30623627, 21.56595993], [74.30706024, 21.56656265], [74.30805969, 21.56705284], [74.30909729, 21.56732178], [74.30996704, 21.56732178], [74.31066895, 21.56688118], [74.31127167, 21.56604958], [74.31175995, 21.56507111], [74.31212616, 21.56417084], [74.31246185, 21.56328964], [74.3127594, 21.56240082], [74.3130188, 21.56149101], [74.3132782, 21.56056023], [74.31346893, 21.55965042], [74.31363678, 21.55871964], [74.31369781, 21.55828285], [74.31378174, 21.55779266], [74.3138504, 21.55685043], [74.31387329, 21.55655289], [74.31391144, 21.55589104], [74.3139801, 21.5549202], [74.31401062, 21.55395126], [74.31401062, 21.55298042], [74.31401825, 21.55200958], [74.31402588, 21.55103111], [74.31404877, 21.55055046], [74.3140564, 21.55006981], [74.31410217, 21.54911995], [74.3141861, 21.54818153], [74.31430054, 21.54726982], [74.31443024, 21.54636955], [74.31461334, 21.54551125], [74.31484985, 21.54466248], [74.31520081, 21.54385948], [74.31581879, 21.54317093], [74.31665802, 21.54259109], [74.31764984, 21.54211998], [74.31867218, 21.54175949], [74.31968689, 21.54152107], [74.32064819, 21.54137039], [74.32161713, 21.54125023], [74.32260895, 21.54117966], [74.32357788, 21.54113007], [74.32406616, 21.54112053], [74.32457733, 21.54111099], [74.32559204, 21.54109955], [74.32659149, 21.54111099], [74.32727051, 21.54112053], [74.32762146, 21.54112053], [74.32861328, 21.54115105], [74.32962036, 21.54116058], [74.33065033, 21.54117966], [74.33164978, 21.54117966], [74.33274078, 21.54116058], [74.33551788, 21.5402298], [74.33335876, 21.51980972], [74.3320694, 21.51402092], [74.33165741, 21.51222992], [74.33125305, 21.51037979], [74.33082581, 21.50855064], [74.33039093, 21.50672913], [74.32995605, 21.50488281], [74.32950592, 21.50306129], [74.32907104, 21.50123024], [74.32859802, 21.49939919], [74.32821655, 21.4975605], [74.32772064, 21.49575043], [74.32624054, 21.49454117], [74.32443237, 21.4937706], [74.32253265, 21.49319267], [74.32061005, 21.4926796], [74.3187027, 21.49217033], [74.31678009, 21.49156952], [74.31497955, 21.49078178], [74.3134079, 21.48962021], [74.31236267, 21.48805809], [74.31173706, 21.48625946], [74.31125641, 21.48443985], [74.31057739, 21.48266029], [74.30943298, 21.48118019], [74.30776215, 21.48011971], [74.30591583, 21.4793911], [74.30400848, 21.47887039], [74.30204773, 21.47850037], [74.30005646, 21.47824097], [74.29807281, 21.4780407], [74.2960968, 21.47788048], [74.2940979, 21.47774124], [74.29210663, 21.4776001], [74.29013062, 21.47747993], [74.28811646, 21.4773407], [74.28613281, 21.47717285], [74.28414154, 21.47696114], [74.28217316, 21.47672081], [74.28018188, 21.47649956], [74.27819824, 21.47631073], [74.27620697, 21.4761219], [74.27423096, 21.47590065], [74.27224731, 21.47562027], [74.27028656, 21.47525024], [74.26837921, 21.47473907], [74.26654053, 21.47402], [74.26502991, 21.47284126], [74.26454926, 21.47101021], [74.26439667, 21.46915245], [74.26415253, 21.46729279], [74.26319122, 21.46570015], [74.26138306, 21.46491051], [74.2594986, 21.46426964], [74.25759125, 21.46375084], [74.25563812, 21.46333122], [74.25367737, 21.4630394], [74.2516861, 21.46286964], [74.24967194, 21.46286964], [74.24769592, 21.46310043], [74.24581909, 21.46370125], [74.24430084, 21.46491051], [74.24333191, 21.46653938], [74.24269104, 21.46831131], [74.24215698, 21.47013283], [74.24169922, 21.47195053], [74.24121094, 21.47376823], [74.24059296, 21.47555923], [74.23873138, 21.47841263], [74.23696136, 21.4792881], [74.23501587, 21.47970772], [74.23303223, 21.47986984], [74.23103333, 21.47982025], [74.22904968, 21.47960091], [74.22709656, 21.4791584], [74.22525024, 21.47846031], [74.22374725, 21.47726059], [74.22303009, 21.47552109], [74.22290039, 21.47365952], [74.22302246, 21.47178268], [74.22323608, 21.46990967], [74.22350311, 21.46805954], [74.22373199, 21.46618271], [74.22383118, 21.4643116], [74.22376251, 21.46241951], [74.22358704, 21.46056747], [74.22263336, 21.4589901], [74.22065735, 21.45877838], [74.21868896, 21.45895004], [74.21671295, 21.45927048], [74.21475983, 21.4596405], [74.21279144, 21.45998001], [74.21082306, 21.46018982], [74.2088089, 21.46014023], [74.20684052, 21.45988083], [74.20485687, 21.45959091], [74.20287323, 21.45944023], [74.20091248, 21.45969963], [74.19940186, 21.46090126], [74.19815063, 21.46236038], [74.19661713, 21.46355247], [74.19497681, 21.4646492], [74.19328308, 21.46562195], [74.19145203, 21.46636963], [74.1894989, 21.46681023], [74.18752289, 21.46702957], [74.18553925, 21.46702194], [74.18395996, 21.46590042], [74.18274689, 21.46442032], [74.18154907, 21.46291924], [74.18017578, 21.4615612], [74.1783371, 21.46087074], [74.17650604, 21.46145058], [74.17507172, 21.46273994], [74.17325592, 21.46352005], [74.17128754, 21.46371078], [74.16931915, 21.4634304], [74.16786957, 21.46222115], [74.16723633, 21.46044159], [74.16664124, 21.4586525], [74.1652298, 21.4574604], [74.16322327, 21.45759964], [74.16159821, 21.45683098], [74.16127777, 21.4549675], [74.16046906, 21.45335007], [74.15847015, 21.45308113], [74.15648651, 21.45313072], [74.15450287, 21.45334053], [74.15252686, 21.45360947], [74.1505661, 21.45388985], [74.14858246, 21.45409012], [74.14659119, 21.45428085], [74.14465332, 21.45471954], [74.14318085, 21.45593071], [74.14258575, 21.4577198], [74.14187622, 21.46099091], [74.14076996, 21.46249008], [74.13887024, 21.4630394], [74.1368866, 21.46339035], [74.13491058, 21.46360016], [74.13292694, 21.46370125], [74.1309433, 21.46367073], [74.12892151, 21.46352005], [74.12697601, 21.46320152], [74.12506104, 21.46267128], [74.12332916, 21.46170998], [74.122612, 21.46000099], [74.12255859, 21.45812988], [74.12269592, 21.45625114], [74.1228714, 21.45438004], [74.12290192, 21.45251274], [74.12245941, 21.45070076], [74.12081909, 21.4496994], [74.11885834, 21.4493084], [74.11688995, 21.44896126], [74.1149292, 21.44861031], [74.11297607, 21.44831085], [74.11097717, 21.44810104], [74.1089859, 21.44802284], [74.106987, 21.44812012], [74.10560608, 21.44922066], [74.10558319, 21.45108986], [74.10536194, 21.45293999], [74.10372925, 21.45388985], [74.10175323, 21.45420074], [74.09976959, 21.45449066], [74.09778595, 21.45474052], [74.09581757, 21.45500946], [74.09382629, 21.45524025], [74.09185791, 21.45548058], [74.0898819, 21.4557209], [74.08789825, 21.45597076], [74.08592224, 21.45625114], [74.08394623, 21.45652962], [74.08197784, 21.45684052], [74.08001709, 21.45720291], [74.07814789, 21.45781136], [74.07704926, 21.45934105], [74.0770874, 21.46121025], [74.07740784, 21.46305847], [74.07758331, 21.46494293], [74.07752228, 21.46681023], [74.07740021, 21.46867943], [74.07701111, 21.47051811], [74.07624054, 21.47224808], [74.07527161, 21.4738903], [74.07418823, 21.47546959], [74.07301331, 21.47698021], [74.07176971, 21.47845078], [74.07042694, 21.47986031], [74.06891632, 21.48106956], [74.06716156, 21.48193169], [74.06598663, 21.4811306], [74.06642914, 21.47930145], [74.06665802, 21.47744179], [74.06648254, 21.47557068], [74.06616974, 21.47372055], [74.06569672, 21.47190094], [74.06497192, 21.47014999], [74.06413269, 21.46842957], [74.0632782, 21.4667511], [74.0623703, 21.46508026], [74.06082916, 21.46236992], [74.05988312, 21.4607296], [74.05893707, 21.45907021], [74.0580368, 21.45738983], [74.05716705, 21.45570946], [74.05634308, 21.45399094], [74.05565643, 21.45223999], [74.05513, 21.45041847], [74.05471802, 21.44860077], [74.05444336, 21.44672966], [74.05432129, 21.44485092], [74.05426025, 21.44297028], [74.05417633, 21.44110107], [74.05396271, 21.43923187], [74.05371094, 21.4373703], [74.05343628, 21.43551064], [74.05316925, 21.43366051], [74.05285645, 21.4317894], [74.05251312, 21.42995071], [74.05208588, 21.42811012], [74.05162811, 21.42628098], [74.05110168, 21.42448997], [74.05046082, 21.42270088], [74.0496521, 21.42098045], [74.04854584, 21.41942978], [74.04679108, 21.41852188], [74.04479218, 21.41852951], [74.04280853, 21.41876984], [74.04081726, 21.41896057], [74.03885651, 21.41930008], [74.03690338, 21.41966057], [74.03491211, 21.41981125], [74.03292084, 21.41958046], [74.03098297, 21.41916084], [74.02908325, 21.41862106], [74.0271759, 21.41804123], [74.0252533, 21.41751099], [74.02332306, 21.41710091], [74.02133942, 21.4170208], [74.01959991, 21.41798019], [74.0177002, 21.41855812], [74.01579285, 21.41798019], [74.0140686, 21.41703033], [74.01251984, 21.41584015], [74.01107788, 21.4145298], [74.00949097, 21.41337013], [74.00765991, 21.41257286], [74.00547791, 21.4118309], [73.98883057, 21.40448952], [73.98529053, 21.40191078], [73.98155975, 21.39733124], [73.97741699, 21.39496994], [73.97193909, 21.39479828], [73.96869659, 21.39206123], [73.96193695, 21.39311028], [73.95545959, 21.4025383], [73.95284271, 21.40237045], [73.95562744, 21.39001083], [73.95530701, 21.37425995], [73.95658875, 21.36161041], [73.95700836, 21.3444519], [73.9519577, 21.33060074], [73.95127869, 21.31500816], [73.95015717, 21.30805016], [73.94992065, 21.30658913], [73.94848633, 21.2975502], [73.93358612, 21.28532982], [73.92354584, 21.28101921], [73.89199066, 21.26241112], [73.88432312, 21.26263046], [73.87174225, 21.26737976], [73.85840607, 21.26995087], [73.83213806, 21.26745033], [73.83223724, 21.25830269], [73.83650208, 21.245821], [73.83634949, 21.24234009], [73.8274765, 21.23314095], [73.82316589, 21.22756958], [73.82013702, 21.22186089], [73.81841278, 21.21372032], [73.81859589, 21.20857048], [73.81877899, 21.20385933], [73.81951141, 21.19960976], [73.82134247, 21.19532013], [73.83405304, 21.19719124], [73.83590698, 21.19518089], [73.83232117, 21.1853981], [73.83048248, 21.18439293], [73.82917786, 21.18234062], [73.82254791, 21.17192078], [73.81793976, 21.17143822], [73.81212616, 21.17206764], [73.80753326, 21.1746006], [73.80253601, 21.1785717], [73.79631042, 21.18173027], [73.7911377, 21.17622948], [73.78975677, 21.16867828], [73.78720093, 21.1663208], [73.78366089, 21.16506004], [73.77966309, 21.16455269], [73.75306702, 21.16818047], [73.74162292, 21.16711044], [73.7407608, 21.16039848], [73.74619293, 21.15483093], [73.74797058, 21.15153122], [73.74603271, 21.14760971], [73.74318695, 21.1468029], [73.73983765, 21.14016151], [73.73668671, 21.13828087], [73.72235107, 21.13924026], [73.71707153, 21.1417408], [73.71517944, 21.14310074], [73.7131958, 21.1504612], [73.69824219, 21.15011024], [73.68943024, 21.15116119], [73.68131256, 21.15212059], [73.67460632, 21.15102005], [73.67150879, 21.14513969], [73.63639832, 21.13265991], [73.63897705, 21.14734077], [73.63745117, 21.15313911], [73.61969757, 21.15794945], [73.61470032, 21.16348076], [73.61384583, 21.16797066], [73.61418915, 21.17245102], [73.61316681, 21.17605972], [73.60991669, 21.17667961], [73.60691833, 21.17846107], [73.59819794, 21.17472076], [73.58830261, 21.16790009], [73.58875275, 21.16086006], [73.58751678, 21.15674019], [73.58879852, 21.15419006], [73.59229279, 21.15294075], [73.59667969, 21.15273094], [73.60027313, 21.15433121], [73.60491943, 21.15505981], [73.61147308, 21.15446091], [73.61258698, 21.15219116], [73.61345673, 21.15043068], [73.61422729, 21.14698029], [73.61885071, 21.14417267], [73.62908173, 21.14166069], [73.62634277, 21.1398201], [73.62359619, 21.13799095], [73.62872314, 21.12014961], [73.63802338, 21.12170982], [73.64546204, 21.12295914], [73.64924622, 21.12274933], [73.6530304, 21.12254143], [73.65537262, 21.12179947], [73.6577301, 21.12104988], [73.65994263, 21.10837936], [73.67890167, 21.10925102], [73.68937683, 21.10598946], [73.69338989, 21.1009903], [73.70323944, 21.10896111], [73.71058655, 21.11902237], [73.70897675, 21.11234093], [73.71478271, 21.10719109], [73.7358017, 21.10322952], [73.7388916, 21.1013298], [73.74337006, 21.10824966], [73.75260925, 21.11408997], [73.74946594, 21.1077404], [73.73906708, 21.0948391], [73.74046326, 21.08486938], [73.74224091, 21.08156967], [73.744133, 21.08167076], [73.74079895, 21.07287025], [73.74373627, 21.0641613], [73.7421875, 21.05550003], [73.747612, 21.03997993], [73.7569809, 21.03917122], [73.76300049, 21.03864098], [73.7660675, 21.04005051], [73.7756424, 21.02760124], [73.77392578, 21.0216198], [73.76944733, 21.01452065], [73.77485657, 21.01045036], [73.78470612, 21.0195694], [73.79382324, 21.01976967], [73.80770111, 21.02255821], [73.81208038, 21.01066017], [73.81404877, 21.00080109], [73.81640625, 20.99605179], [73.82050323, 20.99504089], [73.82752991, 20.99607086], [73.83769226, 20.99483109], [73.84078217, 20.99313927], [73.84683228, 20.99398994], [73.85012817, 21.00141907], [73.8537674, 20.99911118], [73.85721588, 20.99770927], [73.87268829, 20.99073029], [73.87918854, 20.98647118], [73.89863586, 20.98222923], [73.90644836, 20.98315048], [73.91116333, 20.97542953], [73.91396332, 20.96996117], [73.91538239, 20.96482086], [73.91123199, 20.96235275], [73.9017868, 20.96170044], [73.89694214, 20.95255089], [73.89509583, 20.94652176], [73.89501953, 20.94013977], [73.89633942, 20.93300056], [73.90396118, 20.92536926], [73.90956116, 20.92140007], [73.91221619, 20.91794014], [73.91681671, 20.91505051], [73.92032623, 20.91123009], [73.92273712, 20.90774918], [73.92443848, 20.90283966], [73.92732239, 20.89911079], [73.9310379, 20.88591766], [73.93123627, 20.8766098], [73.92967987, 20.86887169], [73.9316864, 20.86473274], [73.93013, 20.86011124], [73.9315567, 20.85250282], [73.93106079, 20.84839058], [73.93373108, 20.8449707], [73.93589783, 20.8434391], [73.94509888, 20.84013176], [73.94760895, 20.82939911], [73.94763947, 20.82509041], [73.94626617, 20.81867027], [73.94019318, 20.80886078], [73.94114685, 20.80378151], [73.93811798, 20.78967094], [73.94056702, 20.76885986], [73.93834686, 20.76078987], [73.9471817, 20.76078033], [73.94750214, 20.75247002], [73.94523621, 20.74929047], [73.94845581, 20.74670029], [73.94953156, 20.74230957], [73.93596649, 20.73150063], [73.93506622, 20.73461914], [73.92756653, 20.73044014], [73.92090607, 20.72352982], [73.90875244, 20.72522926], [73.90379333, 20.73064041], [73.88886261, 20.73108101], [73.88556671, 20.72961044], [73.88194275, 20.72687912], [73.87728119, 20.72133064], [73.87362671, 20.7077198], [73.86360168, 20.6942997], [73.84275818, 20.70211983], [73.83917999, 20.70190048], [73.83362579, 20.69960976], [73.82874298, 20.69646072], [73.82264709, 20.69382095], [73.82543182, 20.67361832], [73.83425903, 20.67353821], [73.84150696, 20.67513847], [73.84535217, 20.66707039], [73.84707642, 20.65636253], [73.8434906, 20.65032959], [73.84310913, 20.64441109], [73.84641266, 20.6235199], [73.83828735, 20.6157608], [73.83390808, 20.61412048], [73.83068848, 20.61491966], [73.82538605, 20.61401939], [73.81656647, 20.60936928], [73.80596161, 20.60152054], [73.80237579, 20.60579109], [73.79273224, 20.60431099], [73.78705597, 20.60225868], [73.78135681, 20.59507942], [73.77997589, 20.59185982], [73.7756958, 20.58876038], [73.76906586, 20.58716965], [73.76394653, 20.58333015], [73.74820709, 20.56735992], [73.74154663, 20.57261848], [73.73766327, 20.57398987], [73.72902679, 20.5741291], [73.72428131, 20.57580185], [73.71985626, 20.57632065], [73.70964813, 20.57450294], [73.70101929, 20.57838058], [73.69243622, 20.57534981], [73.68550873, 20.57168961], [73.68136597, 20.56767082], [73.67617798, 20.56415939], [73.6707077, 20.56233978], [73.66584015, 20.5628109], [73.6618576, 20.56574059], [73.65705109, 20.57219124], [73.65093994, 20.57641029], [73.64710236, 20.57749939], [73.64328766, 20.57715988], [73.63949585, 20.57790947], [73.63677216, 20.57929039], [73.63448334, 20.58229065], [73.63506317, 20.59165955], [73.63217163, 20.60223961], [73.63038635, 20.60602951], [73.62948608, 20.61230087], [73.62594604, 20.62111092], [73.62219238, 20.62529945], [73.60730743, 20.63630104], [73.60275269, 20.63786125], [73.59120941, 20.64511108], [73.58418274, 20.64789963], [73.57419586, 20.65105057], [73.56732941, 20.64791107], [73.5629425, 20.64739037], [73.55365753, 20.65533066], [73.54476166, 20.6692009], [73.53837585, 20.67386055], [73.53040314, 20.6731205], [73.52697754, 20.67012978], [73.52516174, 20.66714287], [73.51998901, 20.66633987], [73.51780701, 20.67014122], [73.5123291, 20.66302109], [73.50788116, 20.65864944], [73.50087738, 20.65274048], [73.49843597, 20.65341949], [73.49547577, 20.66269112], [73.49336243, 20.66555977], [73.49250793, 20.66843033], [73.4895401, 20.66963959], [73.48777771, 20.67212105], [73.4874115, 20.67555046], [73.48918915, 20.67850113], [73.49205017, 20.68033028], [73.4972229, 20.6809597], [73.49729156, 20.6860199], [73.49375916, 20.68952942], [73.49336243, 20.6942997], [73.48873901, 20.70660019], [73.48416901, 20.70907021], [73.48261261, 20.71722984], [73.48049927, 20.71965027], [73.47518921, 20.72167015], [73.45868683, 20.71431923], [73.4536972, 20.7104702], [73.44729614, 20.70111084], [73.45654297, 20.69339943], [73.45452881, 20.68605042], [73.45288086, 20.68300056], [73.4500885, 20.68075943], [73.443573, 20.6779995], [73.44325256, 20.67437935], [73.43991852, 20.6648407], [73.43551636, 20.66237259], [73.43035889, 20.66088104], [73.41916656, 20.66047096], [73.41752625, 20.65789032], [73.41496277, 20.65604019], [73.40983582, 20.65501022], [73.40364838, 20.65237045], [73.40158081, 20.64920998], [73.40273285, 20.64259911], [73.41134644, 20.63858032], [73.414711, 20.63570023], [73.41797638, 20.63047028], [73.41512299, 20.62805939], [73.41596222, 20.62616158], [73.42764282, 20.62449074], [73.43078613, 20.62053108], [73.43382263, 20.61471939], [73.43908691, 20.60126114], [73.4375, 20.59747124], [73.44036102, 20.59511948], [73.45482635, 20.59458923], [73.46855927, 20.58876991], [73.47670746, 20.58630943], [73.4808197, 20.58359909], [73.4837265, 20.57843018], [73.48584747, 20.56405067], [73.48179626, 20.54335976], [73.49327087, 20.54220009], [73.50074005, 20.54024124], [73.49729919, 20.53622246], [73.48474121, 20.52570915], [73.47690582, 20.52203751], [73.47380829, 20.51531982], [73.47226715, 20.51404953], [73.47413635, 20.50106049], [73.47593689, 20.49501991], [73.46983337, 20.49233055], [73.46669769, 20.48830032], [73.46523285, 20.48415947], [73.46109009, 20.47813034], [73.45594025, 20.47537041], [73.45204163, 20.47140121], [73.44901276, 20.4666996], [73.43792725, 20.44572258], [73.43585968, 20.43606949], [73.43080902, 20.42881966], [73.42928314, 20.41996956], [73.42974091, 20.41439056], [73.42288971, 20.41432953], [73.41633606, 20.41065979], [73.41583252, 20.40619087], [73.41461182, 20.40566063], [73.41306305, 20.40784836], [73.40879059, 20.40422058], [73.40952301, 20.40134811], [73.40762329, 20.39628983], [73.39772797, 20.39923286], [73.39550781, 20.39801979], [73.39134979, 20.39019966], [73.39025116, 20.3801899], [73.39157867, 20.37289047], [73.39454651, 20.3729496], [73.39807892, 20.3747406], [73.40310669, 20.3817997], [73.4076767, 20.38392067], [73.41200256, 20.38352966], [73.41478729, 20.38157082], [73.42173767, 20.35560036], [73.4234314, 20.35209084], [73.42373657, 20.34181023], [73.42539978, 20.33767128], [73.42531586, 20.32072067], [73.42611694, 20.31592941], [73.42854309, 20.31191063], [73.43076324, 20.29804993], [73.43694305, 20.28212166], [73.436203, 20.27902031], [73.42462158, 20.27683067], [73.42314148, 20.27368927], [73.42442322, 20.26914024], [73.42180634, 20.26356125], [73.42041016, 20.25699997], [73.42160797, 20.25371933], [73.42227936, 20.24809074], [73.42032623, 20.24228096], [73.42280579, 20.23676109], [73.42237854, 20.23176193], [73.42607117, 20.22359848], [73.42788696, 20.21543121], [73.43031311, 20.21232033], [73.42991638, 20.20623016], [73.42682648, 20.20157051], [73.41681671, 20.20030975], [73.40920258, 20.20049095], [73.4054718, 20.19796944], [73.40281677, 20.19502068], [73.39807892, 20.19600105], [73.39626312, 20.20163155], [73.39736176, 20.20594025], [73.39528656, 20.20916939], [73.38851929, 20.20630074], [73.38366699, 20.20239067], [73.37632751, 20.20532036], [73.37528992, 20.20290947], [73.37594604, 20.19497108], [73.37431335, 20.19265938], [73.36691284, 20.19634056], [73.3647995, 20.20099831], [73.36760712, 20.20940018], [73.36923981, 20.21170807], [73.36759949, 20.21337128], [73.36178589, 20.21198845], [73.35930634, 20.20911026], [73.35721588, 20.20249939], [73.35481262, 20.1996212], [73.35285187, 20.19847107], [73.34806061, 20.1990509], [73.33642578, 20.20409966], [73.32787323, 20.20249939], [73.32047272, 20.20433235], [73.31416321, 20.20767021], [73.3111496, 20.20721054], [73.29821777, 20.19616127], [73.2948761, 20.19621086], [73.29405975, 20.19386101], [73.29374695, 20.18597984], [73.29073334, 20.177351], [73.29065704, 20.17440987], [73.29321289, 20.16216087], [73.29363251, 20.15388107], [73.28907776, 20.14956284], [73.28347015, 20.14575958], [73.26846313, 20.13928986], [73.2649765, 20.13376045], [73.26280975, 20.12795067], [73.2612915, 20.12559128], [73.25946808, 20.12463951], [73.25614929, 20.12788963], [73.25361633, 20.12852097], [73.24391937, 20.12903976], [73.23812103, 20.12811089], [73.23667908, 20.1297226], [73.23690796, 20.13692284], [73.23548889, 20.14099121], [73.23264313, 20.1406002], [73.23046875, 20.13771057], [73.22952271, 20.13315964], [73.23033142, 20.12816048], [73.22672272, 20.12257957], [73.22148895, 20.12079811], [73.21631622, 20.12199974], [73.21095276, 20.12360001], [73.20069122, 20.12969971], [73.19597626, 20.13994026], [73.19532776, 20.15093994], [73.19609833, 20.15611267], [73.19924164, 20.16164017], [73.21775055, 20.16813278], [73.2220993, 20.17142105], [73.22673035, 20.17636108], [73.22833252, 20.18009949], [73.22915649, 20.18429947], [73.2277832, 20.18704987], [73.21936798, 20.19043922], [73.21615601, 20.19278908], [73.20993042, 20.19735146], [73.20440674, 20.19832039], [73.19586945, 20.19752121], [73.19132996, 20.19860268], [73.1885376, 20.20062065], [73.18113708, 20.20240021], [73.18017578, 20.20860863], [73.17298126, 20.20132065], [73.16895294, 20.19968987], [73.16351318, 20.20146942], [73.15364075, 20.20222092], [73.15284729, 20.2027607], [73.15223694, 20.20318985], [73.14981842, 20.20560074], [73.14575195, 20.20697975], [73.1421814, 20.20438957], [73.14157104, 20.20186996], [73.14602661, 20.18739128], [73.14839935, 20.18548012], [73.15213013, 20.17974281], [73.1523819, 20.17605972], [73.15007019, 20.17284012], [73.14702606, 20.17105293], [73.13947296, 20.1731205], [73.13582611, 20.17231941], [73.13260651, 20.16777039], [73.12606049, 20.16362762], [73.12555695, 20.16109276], [73.12802887, 20.15711975], [73.12494659, 20.15666008], [73.12259674, 20.15775108], [73.11974335, 20.15906906], [73.1167984, 20.15879059], [73.11302948, 20.1584301], [73.10910034, 20.15920067], [73.10514069, 20.15996933], [73.10334015, 20.16134834], [73.10182953, 20.16410828], [73.0994873, 20.17257118], [73.09790802, 20.17334938], [73.09616089, 20.17424011], [73.09348297, 20.17389107], [73.08991241, 20.17043114], [73.08790588, 20.16575813], [73.08648682, 20.1570015], [73.08244324, 20.15658951], [73.07553101, 20.16007996], [73.07244873, 20.16345024], [73.07422638, 20.17728043], [73.07435608, 20.19252014], [73.07303619, 20.19613075], [73.07048035, 20.19737053], [73.0703125, 20.19745064], [73.0666275, 20.19787979], [73.0642395, 20.20316124], [73.07036591, 20.22145081], [73.07685852, 20.22980118], [73.08187866, 20.23281288], [73.0875473, 20.23397255], [73.10192871, 20.22894287], [73.110466, 20.23213005], [73.10852051, 20.23855019], [73.11331177, 20.24418068], [73.12458038, 20.25671959], [73.1280365, 20.25850105], [73.13684845, 20.26046944], [73.14095306, 20.26523018], [73.14260101, 20.26863098], [73.14270782, 20.27528954], [73.14628601, 20.28053093], [73.1469574, 20.28104973], [73.14987183, 20.28012276], [73.15254211, 20.27667999], [73.15355682, 20.2770195], [73.1542511, 20.27934837], [73.15513611, 20.28236008], [73.15519714, 20.28541946], [73.15625763, 20.28742981], [73.15820313, 20.29048157], [73.16129303, 20.29179192], [73.1654129, 20.28703117], [73.16680145, 20.28341103], [73.1690979, 20.28231812], [73.17195129, 20.28250122], [73.17578888, 20.28417015], [73.17887878, 20.28646088], [73.17954254, 20.28986168], [73.17698669, 20.30088043], [73.17710876, 20.30759811], [73.17753601, 20.30907059], [73.17801666, 20.31071091], [73.17710114, 20.31232262], [73.17073822, 20.31052971], [73.16838074, 20.31380081], [73.16551971, 20.31592941], [73.16139984, 20.31719017], [73.15242004, 20.31747055], [73.14731598, 20.31682968], [73.1417923, 20.31746101], [73.14015198, 20.31468964], [73.13931274, 20.30957985], [73.1342926, 20.30532837], [73.1291275, 20.30578041], [73.11566162, 20.30404091], [73.11286926, 20.30494118], [73.11440277, 20.3106308], [73.11650848, 20.31270981], [73.11888123, 20.32620049], [73.12195587, 20.33287811], [73.12145996, 20.3364296], [73.11801147, 20.34287071], [73.11638641, 20.34716034], [73.11425018, 20.35279083], [73.11138153, 20.35609818], [73.1073761, 20.36071014], [73.10542297, 20.36054039], [73.10338593, 20.3603611], [73.10253143, 20.35967064], [73.10212708, 20.35845947], [73.10132599, 20.35603905], [73.09916687, 20.33993912], [73.09741211, 20.33509827], [73.09089661, 20.32683945], [73.08863068, 20.32648277], [73.08628845, 20.32611084], [73.08273315, 20.32912064], [73.07525635, 20.3296299], [73.07151031, 20.32716942], [73.06668091, 20.32608032], [73.06204224, 20.32574081], [73.05512238, 20.32524109], [73.05047607, 20.32299805], [73.04767609, 20.31661034], [73.0475769, 20.3044529], [73.04586029, 20.29243279], [73.04416656, 20.2911129], [73.04197693, 20.2902298], [73.03726959, 20.29059982], [73.02979279, 20.29226112], [73.02651978, 20.29412079], [73.02696228, 20.30380058], [73.02469635, 20.31279945], [73.02226257, 20.31585121], [73.01983643, 20.31739807], [73.01760101, 20.31549263], [73.02053833, 20.30751991], [73.02056885, 20.30207825], [73.02217102, 20.29706955], [73.02179718, 20.2927475], [73.02049255, 20.29090118], [73.01728821, 20.29053116], [73.01048279, 20.29236984], [73.00357056, 20.29314041], [72.99046326, 20.29208946], [72.98947144, 20.27753067], [72.98779297, 20.27466965], [72.98409271, 20.27168083], [72.98005676, 20.27075005], [72.9744873, 20.27178001], [72.96977997, 20.27474022], [72.95749664, 20.28770065], [72.95078278, 20.2920208], [72.94597626, 20.29343033], [72.94142151, 20.29212761], [72.93811035, 20.28800964], [72.930336, 20.28397942], [72.92459106, 20.27865982], [72.92230988, 20.27440071], [72.92375183, 20.26819992], [72.9408493, 20.24682045], [72.94367218, 20.24488068], [72.95146942, 20.24357033], [72.95778656, 20.24115181], [72.96534729, 20.23718071], [72.96962738, 20.23394012], [72.9744873, 20.22583961], [72.97543335, 20.21920013], [72.97437286, 20.21497154], [72.97042847, 20.21232986], [72.96924591, 20.2109108], [72.96082306, 20.21404076], [72.95101929, 20.21598053], [72.94181061, 20.21780968], [72.92842865, 20.2233696], [72.92218781, 20.22359848], [72.91680908, 20.22476959], [72.91086578, 20.22606087], [72.90538025, 20.22623253], [72.89984131, 20.22167015], [72.88873291, 20.22582054], [72.88432312, 20.22657967], [72.87454224, 20.2258091], [72.87188721, 20.22256088], [72.87287903, 20.21251106], [72.87200165, 20.20824051], [72.86438751, 20.20862961], [72.85508728, 20.20911026], [72.85028839, 20.20794106], [72.846138, 20.20356941], [72.8441391, 20.19779015], [72.84571838, 20.19413948], [72.84905243, 20.19094276], [72.84967041, 20.18925095], [72.84352112, 20.19004059], [72.84220123, 20.18886948], [72.83725739, 20.18868065], [72.83553314, 20.18766022], [72.8346405, 20.18577003], [72.83361816, 20.18357086], [72.82884216, 20.15657043], [72.83416748, 20.14973068], [72.83534241, 20.14464188], [72.83229828, 20.14402008], [72.82604218, 20.14628029], [72.81585693, 20.15328026], [72.81195068, 20.15242004], [72.80912781, 20.15180016], [72.80536652, 20.15003014], [72.80206299, 20.14846992], [72.80148315, 20.14711761], [72.80066681, 20.14526939], [72.8012619, 20.13780975], [72.80519867, 20.12701035], [72.80352783, 20.12601089], [72.80184937, 20.12501907], [72.79447174, 20.12817955], [72.78761292, 20.13008118], [72.7745285, 20.13080025], [72.7618103, 20.13149834], [72.7546463, 20.13303947], [72.74830627, 20.13441086], [72.74106598, 20.13595963], [72.73764038, 20.13653946], [72.73764038, 20.13736153], [72.73792267, 20.13735962], [72.73792267, 20.13820076], [72.73819733, 20.13819695], [72.73819733, 20.13958359], [72.73847198, 20.13958359], [72.73847198, 20.14069366], [72.73874664, 20.14068985], [72.73874664, 20.14236259], [72.73902893, 20.14236259], [72.73902893, 20.14375114], [72.73929596, 20.14375114], [72.73929596, 20.14542007], [72.73958588, 20.14541626], [72.73958588, 20.14708328], [72.73986053, 20.14708328], [72.73986053, 20.14875031], [72.74014282, 20.14874077], [72.74014282, 20.15014076], [72.74041748, 20.15013885], [72.74041748, 20.15319443], [72.74069214, 20.15319443], [72.74069214, 20.15847206], [72.74041748, 20.15847015], [72.74041748, 20.15903091], [72.74069214, 20.15903091], [72.74069214, 20.15930939], [72.7409668, 20.15930939], [72.7409668, 20.16014099], [72.74124908, 20.16013908], [72.74124908, 20.16374969], [72.74153137, 20.16374969], [72.74153137, 20.16430473], [72.74180603, 20.16430473], [72.74180603, 20.16486168], [72.74208069, 20.16486168], [72.74208069, 20.16847229], [72.74236298, 20.16846848], [72.74236298, 20.16930962], [72.74263763, 20.16930962], [72.74263763, 20.17124939], [72.74291992, 20.17124939], [72.74291992, 20.17236137], [72.74319458, 20.17236137], [72.74319458, 20.17819405], [72.74291992, 20.17819023], [72.74291992, 20.17985916], [72.74263763, 20.17985916], [72.74263763, 20.18292046], [72.74291992, 20.18291664], [72.74291992, 20.18347168], [72.74318695, 20.18347168], [72.74318695, 20.18403053], [72.74346924, 20.18402863], [72.74346924, 20.18458366], [72.74375153, 20.18458176], [72.74375153, 20.1854229], [72.74402618, 20.1854229], [72.74402618, 20.18625069], [72.74430847, 20.18625069], [72.74430847, 20.18680954], [72.74458313, 20.18680573], [72.74458313, 20.1879158], [72.74485779, 20.18791008], [72.74485779, 20.18902969], [72.74514008, 20.18902779], [72.74514008, 20.1898613], [72.7454071, 20.18985939], [72.7454071, 20.19153023], [72.74569702, 20.19153023], [72.74569702, 20.19292068], [72.74597168, 20.19291878], [72.74597168, 20.19708252], [72.74624634, 20.19708252], [72.74624634, 20.19847107], [72.74652863, 20.19847107], [72.74652863, 20.19958305], [72.74680328, 20.19958305], [72.74680328, 20.19986153], [72.7470932, 20.19985008], [72.7470932, 20.20070076], [72.74736023, 20.20069313], [72.74736023, 20.2009716], [72.74764252, 20.2009697], [72.74764252, 20.20125008], [72.74791718, 20.20125008], [72.74791718, 20.20153046], [72.74819183, 20.20153046], [72.74819183, 20.20430946], [72.74791718, 20.20430946], [72.74791718, 20.20486069], [72.74764252, 20.20486069], [72.74764252, 20.20597839], [72.74791718, 20.20597267], [72.74791718, 20.20846939], [72.74764252, 20.20846939], [72.74764252, 20.20930481], [72.74736023, 20.20930481], [72.74736023, 20.20958328], [72.7470932, 20.20957947], [72.7470932, 20.21042061], [72.74680328, 20.21041679], [72.74680328, 20.21319389], [72.74652863, 20.21319389], [72.74652863, 20.2159729], [72.74624634, 20.21597099], [72.74624634, 20.21681023], [72.74597168, 20.21681023], [72.74597168, 20.22180939], [72.74569702, 20.22180939], [72.74569702, 20.2226429], [72.7454071, 20.2226429], [72.7454071, 20.22764015], [72.74569702, 20.22764015], [72.74569702, 20.22986031], [72.7454071, 20.22986031], [72.7454071, 20.23125076], [72.74514008, 20.23125076], [72.74514008, 20.23153114], [72.74458313, 20.23153114], [72.74458313, 20.23180962], [72.74430847, 20.23180962], [72.74430847, 20.23236084], [72.74402618, 20.23236084], [72.74402618, 20.23291969], [72.74375153, 20.23291969], [72.74375153, 20.23402977], [72.74347687, 20.23402977], [72.74347687, 20.23431015], [72.74319458, 20.23430634], [72.74319458, 20.2345829], [72.74291992, 20.2345829], [72.74291992, 20.23569489], [72.74263763, 20.23569489], [72.74263763, 20.23596954], [72.74236298, 20.2359581], [72.74236298, 20.2365303], [72.74208069, 20.2365303], [72.74208069, 20.23681068], [72.74180603, 20.23681068], [72.74180603, 20.23792076], [72.74153137, 20.23791695], [72.74153137, 20.2381897], [72.74124908, 20.23820114], [72.74124908, 20.23875046], [72.7409668, 20.23875046], [72.7409668, 20.23931122], [72.74069214, 20.2393055], [72.74069214, 20.24097252], [72.74041748, 20.24097061], [72.74041748, 20.24291992], [72.74069214, 20.24291992], [72.74069214, 20.24403], [72.74097443, 20.24402618], [72.74097443, 20.24458313], [72.74180603, 20.24458313], [72.74180603, 20.2448616], [72.74208069, 20.2448616], [72.74208069, 20.24597168], [72.74236298, 20.24596977], [72.74236298, 20.24653053], [72.74263763, 20.24653053], [72.74263763, 20.24735832], [72.74291992, 20.24735832], [72.74291992, 20.24764061], [72.74319458, 20.24764061], [72.74319458, 20.24819374], [72.74346924, 20.24819374], [72.74346924, 20.24875069], [72.74375153, 20.24875069], [72.74375153, 20.24902916], [72.74402618, 20.24902916], [72.74402618, 20.24930954], [72.74430847, 20.24930573], [72.74430847, 20.2495842], [72.74458313, 20.24958038], [72.74458313, 20.24986267], [72.74485779, 20.24986267], [72.74485779, 20.25014114], [72.74514008, 20.25014114], [72.74514008, 20.25041962], [72.74541473, 20.2504158], [72.74541473, 20.25069427], [72.74569702, 20.25069427], [72.74569702, 20.25097275], [72.74597168, 20.2509594], [72.74597168, 20.25125122], [72.74624634, 20.25125122], [72.74624634, 20.25152969], [72.746521, 20.25152969], [72.746521, 20.25181007], [72.74680328, 20.25180626], [72.74680328, 20.2523613], [72.74708557, 20.2523613], [72.74708557, 20.25263977], [72.74736023, 20.25263977], [72.74736023, 20.25292015], [72.74764252, 20.25291634], [72.74764252, 20.25319481], [72.74791718, 20.25319481], [72.74791718, 20.25347137], [72.74819183, 20.25346947], [72.74819183, 20.25403023], [72.74847412, 20.25402832], [72.74847412, 20.25430489], [72.74874878, 20.25430489], [72.74874878, 20.25458336], [72.74903107, 20.25458336], [72.74903107, 20.25486183], [72.74931335, 20.25485992], [72.74931335, 20.2551403], [72.74958038, 20.2551403], [72.74958038, 20.25542068], [72.74986267, 20.25541687], [72.74986267, 20.25597191], [72.75013733, 20.25597], [72.75013733, 20.25653076], [72.75041962, 20.25653076], [72.75041962, 20.25708961], [72.75069427, 20.25708389], [72.75069427, 20.25819397], [72.75096893, 20.25819016], [72.75096893, 20.25875092], [72.75125122, 20.25875092], [72.75125122, 20.25958252], [72.75152588, 20.25958252], [72.75152588, 20.2606945], [72.75180817, 20.2606945], [72.75180817, 20.26208305], [72.75208282, 20.26208305], [72.75208282, 20.26319504], [72.75235748, 20.26318932], [72.75235748, 20.26431274], [72.75263977, 20.26430511], [72.75263977, 20.26458359], [72.7529068, 20.26457977], [72.75291443, 20.26486015], [72.75319672, 20.26486015], [72.75319672, 20.26736069], [72.75347137, 20.26736069], [72.75347137, 20.26931953], [72.75375366, 20.26930428], [72.75375366, 20.2709713], [72.75402832, 20.27096939], [72.75402832, 20.27403069], [72.75430298, 20.27402687], [72.75430298, 20.2784729], [72.75458527, 20.2784729], [72.75458527, 20.28236198], [72.75485992, 20.28236008], [72.75485992, 20.28541946], [72.75514221, 20.28541946], [72.75514221, 20.28903008], [72.75541687, 20.28903008], [72.75541687, 20.29042053], [72.75569153, 20.29041672], [72.75569153, 20.29208374], [72.75596619, 20.29208183], [72.75596619, 20.29236031], [72.75624847, 20.29236031], [72.75624847, 20.29292107], [72.75653076, 20.29291725], [72.75653076, 20.29347229], [72.75708008, 20.29347038], [72.75708008, 20.29403114], [72.75736237, 20.29403114], [72.75736237, 20.29430962], [72.75763702, 20.2943058], [72.75763702, 20.29458237], [72.75791931, 20.29458046], [72.75791931, 20.29486084], [72.75818634, 20.29486084], [72.75818634, 20.29514122], [72.75875092, 20.29514122], [72.75875092, 20.29541969], [72.75958252, 20.29541588], [72.75958252, 20.29569435], [72.75986481, 20.29569435], [72.75986481, 20.29624939], [72.76013947, 20.29624939], [72.76013947, 20.2970829], [72.76040649, 20.29708099], [72.76040649, 20.29763985], [72.76069641, 20.29763985], [72.76069641, 20.29792023], [72.76097107, 20.29791641], [72.76097107, 20.29819489], [72.76152802, 20.29819489], [72.76152802, 20.29847145], [72.76180267, 20.29847145], [72.76180267, 20.29930496], [72.76207733, 20.29930115], [72.76207733, 20.30014038], [72.76264191, 20.30014038], [72.76264191, 20.29985809], [72.76374817, 20.29985809], [72.76374817, 20.30014038], [72.76431274, 20.30014038], [72.76431274, 20.29985809], [72.76486206, 20.29986191], [72.76486206, 20.29958344], [72.76513672, 20.29958344], [72.76513672, 20.29930496], [72.76541901, 20.29930496], [72.76541901, 20.29902649], [72.76568604, 20.2990303], [72.76568604, 20.29874992], [72.76634216, 20.29874992], [72.76708221, 20.29874992], [72.76708221, 20.2990303], [72.7673645, 20.29902649], [72.7673645, 20.29930496], [72.76819611, 20.29930496], [72.76819611, 20.29958344], [72.76930237, 20.29958344], [72.76930237, 20.29986191], [72.76985931, 20.29985809], [72.76985931, 20.30014038], [72.7701416, 20.30014038], [72.7701416, 20.30042076], [72.77041626, 20.30041885], [72.77041626, 20.30097008], [72.77069092, 20.30096817], [72.77069092, 20.30124855], [72.77124786, 20.30124855], [72.77124786, 20.30153084], [72.77153015, 20.30153084], [72.77153015, 20.30180931], [72.77180481, 20.3018055], [72.77180481, 20.30208397], [72.7720871, 20.30207825], [72.7720871, 20.30235863], [72.77236176, 20.30235863], [72.77236176, 20.30264282], [72.77263641, 20.30264282], [72.77263641, 20.30291939], [72.77319336, 20.30291748], [72.77319336, 20.30319405], [72.77402496, 20.30319405], [72.77402496, 20.30347252], [72.77430725, 20.30347252], [72.77430725, 20.3037529], [72.77458191, 20.3037529], [72.77458191, 20.30486107], [72.77485657, 20.30486107], [72.77485657, 20.30653], [72.77513885, 20.30653], [72.77513885, 20.30764008], [72.7748642, 20.30763817], [72.7748642, 20.30847168], [72.77430725, 20.30846977], [72.77430725, 20.31180954], [72.77458191, 20.31180954], [72.77458191, 20.31514168], [72.77485657, 20.31514168], [72.77485657, 20.31986046], [72.77458191, 20.31986046], [72.77458191, 20.32513809], [72.7748642, 20.32513618], [72.7748642, 20.32847023], [72.77513885, 20.32846832], [72.77513885, 20.33014107], [72.77541351, 20.33013916], [72.77541351, 20.33208275], [72.7756958, 20.33208275], [72.7756958, 20.3334713], [72.7765274, 20.33346939], [72.7765274, 20.33374977], [72.7776413, 20.33374977], [72.7776413, 20.33403015], [72.77791595, 20.33402824], [72.77791595, 20.33486176], [72.77819824, 20.33486176], [72.77819824, 20.33597183], [72.77874756, 20.33596992], [72.77874756, 20.33681107], [72.77902985, 20.33681107], [72.77902985, 20.33764076], [72.7793045, 20.33763885], [72.7793045, 20.33819389], [72.77958679, 20.33819389], [72.77958679, 20.33847237], [72.77986145, 20.33847046], [72.77986145, 20.33875084], [72.78013611, 20.33875084], [72.78013611, 20.33903122], [72.7804184, 20.33903122], [72.7804184, 20.33930969], [72.78069305, 20.33930588], [72.78069305, 20.33958244], [72.7820816, 20.33958054], [72.7820816, 20.33986092], [72.78235626, 20.33986092], [72.78235626, 20.34013748], [72.78263092, 20.34013748], [72.78263092, 20.34041977], [72.78291321, 20.34041595], [72.78291321, 20.34069443], [72.7831955, 20.34069443], [72.7831955, 20.34125137], [72.78375244, 20.34125137], [72.78375244, 20.34153938], [72.7840271, 20.34153938], [72.7840271, 20.34181023], [72.78430176, 20.34181023], [72.78430939, 20.34264183], [72.78457642, 20.34264183], [72.78457642, 20.34320259], [72.7848587, 20.34319496], [72.7848587, 20.34346962], [72.78457642, 20.34346962], [72.78457642, 20.34375191], [72.7848587, 20.34375191], [72.7848587, 20.34431076], [72.78514099, 20.34430504], [72.78514099, 20.34458351], [72.78542328, 20.3445797], [72.78542328, 20.34514046], [72.78569794, 20.34513855], [72.78569794, 20.34569359], [72.7859726, 20.34569359], [72.7859726, 20.34597206], [72.78624725, 20.34597015], [72.78624725, 20.34625053], [72.78652954, 20.34625053], [72.78652954, 20.34680939], [72.7868042, 20.34680557], [72.7868042, 20.34736061], [72.78708649, 20.34735107], [72.78708649, 20.34764099], [72.7876358, 20.34763908], [72.7876358, 20.34819412], [72.78791809, 20.34819412], [72.78791809, 20.3484726], [72.78848267, 20.34847069], [72.78848267, 20.34902954], [72.78875732, 20.34902954], [72.78875732, 20.34930992], [72.78901672, 20.34930992], [72.78901672, 20.34986115], [72.7895813, 20.34986115], [72.7895813, 20.35013962], [72.79069519, 20.35013962], [72.79069519, 20.35041618], [72.79096985, 20.35041618], [72.79096985, 20.35069466], [72.79125214, 20.35069466], [72.79125214, 20.35097313], [72.79180908, 20.35097313], [72.79180908, 20.35124969], [72.7923584, 20.35124969], [72.7923584, 20.35153008], [72.79264069, 20.35152626], [72.79264069, 20.35180473], [72.79458618, 20.35180473], [72.79458618, 20.35152626], [72.79486084, 20.35153008], [72.79486084, 20.35124969], [72.7959671, 20.35124969], [72.7959671, 20.35097122], [72.79680634, 20.35097313], [72.79680634, 20.35069466], [72.80097198, 20.35069466], [72.80097198, 20.35097313], [72.8034668, 20.35097122], [72.8034668, 20.35124969], [72.80430603, 20.35124969], [72.80430603, 20.35153008], [72.80513763, 20.35152626], [72.80513763, 20.35180473], [72.80569458, 20.35180473], [72.80569458, 20.35208321], [72.80652618, 20.35208321], [72.80652618, 20.35236168], [72.80735779, 20.35235977], [72.80735779, 20.35263824], [72.80764008, 20.35263824], [72.80764008, 20.35292053], [72.80819702, 20.35292053], [72.80819702, 20.35320091], [72.80847168, 20.35320091], [72.80847168, 20.35347939], [72.80874634, 20.35347939], [72.80874634, 20.35374832], [72.80930328, 20.35374832], [72.80930328, 20.35403061], [72.8095932, 20.35403061], [72.8095932, 20.35430908], [72.80986023, 20.35430527], [72.80986023, 20.35458374], [72.81041718, 20.35457993], [72.81041718, 20.3548584], [72.81069183, 20.3548584], [72.81069183, 20.35514069], [72.81096649, 20.35514069], [72.81096649, 20.35541916], [72.81124878, 20.35541725], [72.81124878, 20.35569382], [72.81180573, 20.35569382], [72.81180573, 20.35597229], [72.81208038, 20.35596848], [72.81208038, 20.35625267], [72.81236267, 20.35625267], [72.81236267, 20.35654068], [72.81291962, 20.35654068], [72.81291962, 20.35680962], [72.81319427, 20.3568058], [72.81319427, 20.35708046], [72.81346893, 20.35708046], [72.81346893, 20.35736275], [72.81375122, 20.35736275], [72.81375122, 20.35764122], [72.81402588, 20.35764122], [72.81402588, 20.35791969], [72.81430817, 20.35791588], [72.81430817, 20.35819435], [72.81458282, 20.35819435], [72.81458282, 20.35847282], [72.81485748, 20.35847282], [72.81485748, 20.35874939], [72.81513977, 20.35874939], [72.81513977, 20.35931015], [72.81541443, 20.35930634], [72.81541443, 20.35958481], [72.81597137, 20.3595829], [72.81597137, 20.36013985], [72.81624603, 20.36013985], [72.81624603, 20.36042023], [72.81652832, 20.36041641], [72.81652832, 20.36069489], [72.81680298, 20.36069489], [72.81680298, 20.36097145], [72.81708527, 20.36097145], [72.81708527, 20.36124992], [72.81735992, 20.36124992], [72.81735992, 20.3615303], [72.81764221, 20.3615284], [72.81764221, 20.36208344], [72.81791687, 20.36207962], [72.81791687, 20.36264038], [72.81819153, 20.36263847], [72.81819153, 20.36319351], [72.81846619, 20.3631897], [72.81846619, 20.36375046], [72.81874084, 20.36375046], [72.81874084, 20.36431122], [72.81903076, 20.3643055], [72.81903076, 20.36458397], [72.81931305, 20.36458015], [72.81931305, 20.36514091], [72.81958008, 20.3651371], [72.81958008, 20.36569405], [72.81986237, 20.36569023], [72.81986237, 20.36624908], [72.82013702, 20.36624908], [72.82013702, 20.36680984], [72.82041931, 20.36680984], [72.82041931, 20.36735916], [72.82235718, 20.36735916], [72.82235718, 20.36763763], [72.82263947, 20.36763763], [72.82263947, 20.36819458], [72.82235718, 20.36819077], [72.82235718, 20.36848259], [72.82208252, 20.36848259], [72.82208252, 20.36903191], [72.82180786, 20.36902809], [72.82180786, 20.3698616], [72.82152557, 20.3698616], [72.8215332, 20.3710804], [72.82649231, 20.36676025], [72.83132935, 20.36873817], [72.8353653, 20.37371254], [72.85894775, 20.37434006], [72.86501312, 20.37241173], [72.87520599, 20.3728199], [72.87988281, 20.3707695], [72.88378143, 20.370224], [72.89354706, 20.37214661], [72.89637756, 20.37669563], [72.89564514, 20.38036346], [72.88873291, 20.38420105], [72.88685608, 20.38718224], [72.88632202, 20.39336777], [72.88951111, 20.3982811], [72.90042114, 20.40526772], [72.90330505, 20.41033745], [72.90261078, 20.41524124], [72.89962769, 20.41921425], [72.89583588, 20.42136002], [72.88889313, 20.41911316], [72.87956238, 20.41846848], [72.8688736, 20.41582489], [72.86510468, 20.41617584], [72.86031342, 20.41961479], [72.85932159, 20.42437363], [72.86154938, 20.42836952], [72.86811066, 20.434412], [72.87340546, 20.44420815], [72.87704468, 20.44462204], [72.88488007, 20.44006157], [72.88877869, 20.43915558], [72.89280701, 20.44166946], [72.89334869, 20.44538689], [72.89000702, 20.44886017], [72.88744354, 20.45333099], [72.88564301, 20.45907021], [72.88248444, 20.46276665], [72.87428284, 20.46296692], [72.8664093, 20.46469688], [72.86589813, 20.46751022], [72.86340332, 20.46883965], [72.86013794, 20.47096062], [72.86013794, 20.47153091], [72.86042023, 20.47153091], [72.86042023, 20.47180939], [72.86013794, 20.47180557], [72.86013794, 20.47208405], [72.86042023, 20.47208023], [72.86042023, 20.47236061], [72.86067963, 20.47236061], [72.86067963, 20.47291946], [72.86096954, 20.47291946], [72.86096954, 20.4734726], [72.86125183, 20.4734726], [72.86125183, 20.47569466], [72.86152649, 20.47569084], [72.86152649, 20.47681046], [72.86180878, 20.47680473], [72.86180878, 20.47708321], [72.86207581, 20.47707939], [72.86207581, 20.47764015], [72.86180878, 20.47763824], [72.86180878, 20.47847366], [72.86207581, 20.47847176], [72.86207581, 20.47903061], [72.86235809, 20.4790287], [72.86235809, 20.47958374], [72.86264038, 20.47957993], [72.86264038, 20.48014069], [72.86291504, 20.48013878], [72.86291504, 20.48069382], [72.86319733, 20.48069382], [72.86319733, 20.48097229], [72.86347198, 20.48097038], [72.86347198, 20.48153114], [72.86374664, 20.48153114], [72.86374664, 20.48180962], [72.86402893, 20.4818058], [72.86402893, 20.48236084], [72.86430359, 20.48236084], [72.86430359, 20.48291588], [72.86458588, 20.48291588], [72.86458588, 20.48319435], [72.86486053, 20.48319054], [72.86486053, 20.48374939], [72.86514282, 20.48374939], [72.86514282, 20.48431015], [72.86541748, 20.48430634], [72.86541748, 20.48486137], [72.86569214, 20.48485947], [72.86569214, 20.48513985], [72.8659668, 20.48513985], [72.8659668, 20.48542023], [72.86624908, 20.48541641], [72.86624908, 20.48597145], [72.86653137, 20.48597145], [72.86653137, 20.48639107], [72.86653137, 20.4865303], [72.8666687, 20.48652649], [72.86680603, 20.48652649], [72.86680603, 20.4866581], [72.86680603, 20.48681068], [72.86694336, 20.48681068], [72.86708069, 20.48680496], [72.86708069, 20.48694992], [72.86708069, 20.48763847], [72.86736298, 20.48763847], [72.86736298, 20.48792076], [72.86763763, 20.48791885], [72.86763763, 20.48847008], [72.86791992, 20.48846817], [72.86791992, 20.48874855], [72.86818695, 20.48874855], [72.86818695, 20.48903084], [72.86850739, 20.48902702], [72.86875153, 20.48902702], [72.86875153, 20.48938179], [72.86875153, 20.48957825], [72.8690033, 20.48958969], [72.86902618, 20.48986244], [72.86930084, 20.48987961], [72.86930847, 20.49014282], [72.86956024, 20.49014282], [72.86958313, 20.49041939], [72.86985779, 20.49041748], [72.86985779, 20.49069405], [72.87014008, 20.49069405], [72.87014008, 20.49097252], [72.8704071, 20.49097252], [72.8704071, 20.49152946], [72.87069702, 20.49152946], [72.87069702, 20.49180984], [72.87097168, 20.49180603], [72.87097168, 20.4920826], [72.87124634, 20.4920826], [72.87124634, 20.49236107], [72.87152863, 20.49236107], [72.87152863, 20.49263954], [72.87180328, 20.49263954], [72.87180328, 20.49291992], [72.87208557, 20.49291611], [72.87208557, 20.49347305], [72.87236023, 20.49347115], [72.87236023, 20.49403], [72.87319183, 20.49402809], [72.87319183, 20.49430466], [72.87403107, 20.49430466], [72.87403107, 20.49458313], [72.87432098, 20.49458313], [72.87458038, 20.49458313], [72.87458038, 20.49430466], [72.87486267, 20.49430466], [72.87486267, 20.49458313], [72.87625122, 20.49458313], [72.87625122, 20.4948616], [72.87652588, 20.49485016], [72.87652588, 20.49514008], [72.87847137, 20.49514008], [72.87847137, 20.49542046], [72.87903595, 20.49542046], [72.87903595, 20.49570084], [72.87958527, 20.49569511], [72.87958527, 20.49597168], [72.87985992, 20.49596977], [72.87985992, 20.49625015], [72.88041687, 20.49625015], [72.88041687, 20.49653053], [72.88096619, 20.49653053], [72.88096619, 20.49681091], [72.88124847, 20.49680519], [72.88124847, 20.49708366], [72.88153076, 20.49707985], [72.88153076, 20.49736023], [72.88181305, 20.49736023], [72.88181305, 20.49764061], [72.88263702, 20.4976387], [72.88263702, 20.49791527], [72.88319397, 20.49791527], [72.88319397, 20.49819374], [72.88375092, 20.49819374], [72.88375092, 20.49847221], [72.8840332, 20.49847031], [72.8840332, 20.49903107], [72.88430786, 20.49902725], [72.88430786, 20.4995842], [72.88458252, 20.49958038], [72.88458252, 20.49986076], [72.88484955, 20.49986076], [72.88484955, 20.50041962], [72.88458252, 20.5004158], [72.88458252, 20.50069427], [72.88430786, 20.50069046], [72.88430786, 20.50124931], [72.88458252, 20.50124931], [72.88458252, 20.5015316], [72.88486481, 20.50152969], [72.88486481, 20.50208282], [72.88513947, 20.50208092], [72.88513947, 20.50292015], [72.88540649, 20.50292015], [72.88540649, 20.5051403], [72.88569641, 20.5051384], [72.88569641, 20.50597382], [72.88597107, 20.50597191], [72.88597107, 20.50625038], [72.88625336, 20.50625038], [72.88625336, 20.50736046], [72.88652802, 20.50736046], [72.88652802, 20.50847244], [72.88680267, 20.50847244], [72.88680267, 20.51291656], [72.88707733, 20.51291084], [72.88707733, 20.51374817], [72.88735962, 20.51374817], [72.88735962, 20.51458359], [72.88764191, 20.51457977], [72.88764191, 20.51904106], [72.88791656, 20.51902771], [72.88791656, 20.51958466], [72.88764191, 20.51958275], [72.88764191, 20.51986122], [72.88735962, 20.51986122], [72.88735962, 20.52013969], [72.88708496, 20.52013969], [72.88708496, 20.52069473], [72.88735962, 20.52069283], [72.88735962, 20.52124977], [72.88764191, 20.52124977], [72.88764191, 20.52264023], [72.88735962, 20.52264023], [72.88735962, 20.52292061], [72.88707733, 20.52292061], [72.88707733, 20.52320099], [72.88680267, 20.52320099], [72.88680267, 20.52514076], [72.88652802, 20.52513885], [72.88652802, 20.5284729], [72.88625336, 20.52846909], [72.88625336, 20.52875137], [72.88597107, 20.52875137], [72.88597107, 20.52958107], [72.88625336, 20.52957916], [72.88625336, 20.53014183], [72.88652802, 20.53014183], [72.88652802, 20.5304203], [72.88680267, 20.5304203], [72.88680267, 20.53070068], [72.88791656, 20.53070068], [72.88791656, 20.53098106], [72.88819122, 20.53098106], [72.88819122, 20.53125191], [72.88931274, 20.53125191], [72.88930511, 20.53096962], [72.89013672, 20.53098106], [72.89013672, 20.53070068], [72.89125061, 20.53070068], [72.89125061, 20.53098106], [72.89152527, 20.53096962], [72.89152527, 20.53125191], [72.89180756, 20.53125191], [72.89180756, 20.53236389], [72.8915329, 20.53236008], [72.89154053, 20.53267288], [72.89125061, 20.53263855], [72.89125061, 20.53273392], [72.89125061, 20.53319359], [72.89152527, 20.53319359], [72.89152527, 20.53347206], [72.89125061, 20.53347015], [72.89125061, 20.53375053], [72.89097595, 20.53375053], [72.89097595, 20.5340271], [72.89068604, 20.53401947], [72.89068604, 20.53430939], [72.89013672, 20.53430939], [72.89013672, 20.53401947], [72.88931274, 20.53401947], [72.88931274, 20.53430939], [72.88903046, 20.53430939], [72.88903046, 20.53514099], [72.88874817, 20.53513908], [72.88874817, 20.5359726], [72.88846588, 20.53597069], [72.88846588, 20.53625107], [72.88819122, 20.53625107], [72.88820648, 20.53654099], [72.88764191, 20.53652954], [72.88768768, 20.53688431], [72.88735962, 20.53680992], [72.88736725, 20.53709984], [72.88708496, 20.53708267], [72.88708496, 20.53736115], [72.88697815, 20.53736115], [72.88680267, 20.53736115], [72.88680267, 20.53746033], [72.88680267, 20.53763962], [72.88652802, 20.53763962], [72.88625336, 20.53763962], [72.88625336, 20.53782082], [72.88625336, 20.53958321], [72.88597107, 20.53958321], [72.88597107, 20.53986168], [72.88569641, 20.53985977], [72.88569641, 20.5401516], [72.88540649, 20.5401516], [72.88540649, 20.54070091], [72.88513947, 20.54070091], [72.88513947, 20.54624939], [72.88540649, 20.54624939], [72.88540649, 20.54792023], [72.88569641, 20.54791641], [72.88569641, 20.54847145], [72.88597107, 20.54846954], [72.88597107, 20.54931068], [72.88625336, 20.54930687], [72.88625336, 20.54986191], [72.88597107, 20.54986], [72.88597107, 20.55042076], [72.88625336, 20.55041695], [72.88625336, 20.55097198], [72.88652802, 20.55097008], [72.88652802, 20.55125046], [72.88680267, 20.55125046], [72.88680267, 20.55319405], [72.88735962, 20.55319023], [72.88735962, 20.55374908], [72.88764191, 20.55374908], [72.88764191, 20.55430984], [72.88791656, 20.55430984], [72.88791656, 20.55485916], [72.88819122, 20.55485916], [72.88819122, 20.55542183], [72.88846588, 20.55542183], [72.88846588, 20.55625153], [72.88874817, 20.55625153], [72.88874817, 20.55653191], [72.88903046, 20.55652809], [72.88903046, 20.55680466], [72.88930511, 20.55680466], [72.88930511, 20.5573616], [72.88957977, 20.5573616], [72.88957977, 20.55847359], [72.88986206, 20.55846977], [72.88986206, 20.55903053], [72.89013672, 20.55903053], [72.89013672, 20.55986023], [72.89041901, 20.55986023], [72.89041901, 20.56042099], [72.89097595, 20.56042099], [72.89097595, 20.56125069], [72.89125061, 20.56125069], [72.89125061, 20.56153107], [72.8915329, 20.56153107], [72.8915329, 20.56180954], [72.89180756, 20.56180954], [72.89180756, 20.56236076], [72.89208221, 20.56236076], [72.89208221, 20.56291962], [72.8923645, 20.5629158], [72.8923645, 20.56347275], [72.89319611, 20.56347084], [72.89319611, 20.56402969], [72.89347076, 20.56402969], [72.89347076, 20.56431961], [72.89375305, 20.56430626], [72.89375305, 20.56458282], [72.89457703, 20.56458092], [72.89457703, 20.56513977], [72.89485931, 20.56513977], [72.89485931, 20.56569481], [72.8951416, 20.56569099], [72.8951416, 20.56624985], [72.89541626, 20.56624985], [72.89541626, 20.56680489], [72.89569092, 20.56680489], [72.89569092, 20.56736183], [72.89597321, 20.56735992], [72.89597321, 20.56819916], [72.89624786, 20.56819916], [72.89624786, 20.56930923], [72.89653015, 20.56930542], [72.89653015, 20.57069206], [72.89678955, 20.57069016], [72.89678955, 20.57180977], [72.8970871, 20.57180595], [72.8970871, 20.5731945], [72.89736176, 20.5731945], [72.89736176, 20.57430077], [72.89763641, 20.5743103], [72.89763641, 20.57653046], [72.89736176, 20.57653046], [72.89736176, 20.57681084], [72.89763641, 20.57681084], [72.89763641, 20.57903099], [72.89736176, 20.57902718], [72.89736176, 20.57958412], [72.89763641, 20.57958412], [72.89763641, 20.58708382], [72.89736176, 20.58708382], [72.89736176, 20.58847237], [72.89707947, 20.58847046], [72.89707947, 20.58930969], [72.89678955, 20.58930969], [72.89678955, 20.59126091], [72.89653015, 20.59126091], [72.89653015, 20.59181023], [72.89624786, 20.59180641], [72.89624786, 20.59208298], [72.89597321, 20.59208298], [72.89597321, 20.59347153], [72.89569092, 20.59347153], [72.89569092, 20.59458351], [72.89541626, 20.5945797], [72.89541626, 20.59542084], [72.8951416, 20.59541893], [72.8951416, 20.5984726], [72.89485931, 20.5984726], [72.89485931, 20.59902954], [72.89457703, 20.59902954], [72.89457703, 20.59930992], [72.89430237, 20.59930992], [72.89430237, 20.60042], [72.89402771, 20.60041618], [72.89402771, 20.60180473], [72.89375305, 20.60180473], [72.89375305, 20.60208321], [72.89402008, 20.60207939], [72.89402008, 20.60292053], [72.89375305, 20.60292053], [72.89375305, 20.60375023], [72.89347076, 20.60375023], [72.89347076, 20.60458374], [72.89319611, 20.60457993], [72.89319611, 20.60653114], [72.89290619, 20.60653114], [72.89290619, 20.60680962], [72.89263916, 20.6068058], [72.89263916, 20.60708427], [72.89235687, 20.60708046], [72.89235687, 20.60903168], [72.89208221, 20.60902977], [72.89208221, 20.6095829], [72.89180756, 20.60957909], [72.89180756, 20.61042023], [72.89152527, 20.61041641], [72.8915329, 20.61125183], [72.89125061, 20.61125183], [72.89125061, 20.6115303], [72.8915329, 20.6115303], [72.8915329, 20.61181068], [72.89125061, 20.61180496], [72.89125061, 20.61236382], [72.89097595, 20.61236382], [72.89097595, 20.61458588], [72.89068604, 20.61458015], [72.89068604, 20.61486053], [72.89041901, 20.61486053], [72.89041901, 20.61514091], [72.89069366, 20.61513901], [72.89069366, 20.61569595], [72.89041901, 20.61569023], [72.89041901, 20.61652946], [72.89013672, 20.61652946], [72.89013672, 20.61763954], [72.88986206, 20.61763954], [72.88986206, 20.61819458], [72.88957977, 20.61818123], [72.88957977, 20.61874962], [72.88931274, 20.61874962], [72.88931274, 20.61902809], [72.88957977, 20.61902618], [72.88957977, 20.61930466], [72.88931274, 20.61930084], [72.88931274, 20.62013817], [72.88903046, 20.62013626], [72.88903046, 20.62124825], [72.88874817, 20.62124825], [72.88874817, 20.62208366], [72.88846588, 20.62207985], [72.88846588, 20.62291908], [72.88874817, 20.62291718], [72.88874817, 20.62319374], [72.88819122, 20.62318993], [72.88819122, 20.62403107], [72.88791656, 20.62402725], [72.88791656, 20.62430573], [72.88819122, 20.62430191], [72.88819122, 20.62486267], [72.88791656, 20.62486267], [72.88791656, 20.62514114], [72.88764191, 20.62514114], [72.88764191, 20.62541962], [72.88735962, 20.62541962], [72.88735962, 20.62681007], [72.88707733, 20.62681007], [72.88707733, 20.62737083], [72.88680267, 20.62737083], [72.88680267, 20.62874985], [72.88652802, 20.62874985], [72.88652802, 20.63097191], [72.88625336, 20.63097191], [72.88625336, 20.63208389], [72.88735962, 20.63208389], [72.88735962, 20.63180542], [72.89125061, 20.63180542], [72.89125061, 20.63208389], [72.8923645, 20.63208389], [72.8923645, 20.63319397], [72.89152527, 20.63319397], [72.89152527, 20.63347244], [72.89097595, 20.63347054], [72.89097595, 20.63375092], [72.88957977, 20.63375092], [72.88957977, 20.63402748], [72.88931274, 20.63402748], [72.88931274, 20.63430977], [72.88903046, 20.63430595], [72.88903046, 20.63458252], [72.88846588, 20.63458061], [72.88846588, 20.63485909], [72.88819122, 20.63485909], [72.88819122, 20.63514137], [72.88764191, 20.63514137], [72.88764191, 20.63542175], [72.88735962, 20.63541603], [72.88735962, 20.6356945], [72.88708496, 20.6356945], [72.88708496, 20.63597107], [72.88680267, 20.63597107], [72.88680267, 20.63625145], [72.88652802, 20.6362381], [72.88652802, 20.63792038], [72.88680267, 20.63792038], [72.88680267, 20.64153099], [72.88597107, 20.64153099], [72.88597107, 20.64237022], [72.88569641, 20.64237022], [72.88569641, 20.64264107], [72.88541412, 20.64263916], [72.88541412, 20.64347267], [72.88569641, 20.64347076], [72.88569641, 20.64431], [72.88597107, 20.64431], [72.88597107, 20.64486122], [72.88569641, 20.64486122], [72.88569641, 20.64513969], [72.88540649, 20.64513969], [72.88540649, 20.64486122], [72.88513947, 20.64486122], [72.88513947, 20.64431], [72.88484955, 20.64431], [72.88484955, 20.64375114], [72.88458252, 20.64375114], [72.88458252, 20.64347076], [72.88430786, 20.64347267], [72.88430786, 20.64291763], [72.88375092, 20.64291954], [72.88375092, 20.64237022], [72.88346863, 20.64237022], [72.88346863, 20.64208031], [72.88319397, 20.64208412], [72.88319397, 20.64180565], [72.88291931, 20.64180565], [72.88291931, 20.64208412], [72.88208008, 20.64208031], [72.88208008, 20.64264107], [72.88181305, 20.64264107], [72.88181305, 20.64291954], [72.88153076, 20.64291763], [72.88153076, 20.64347267], [72.88124847, 20.64347076], [72.88124847, 20.64375114], [72.88096619, 20.64375114], [72.88096619, 20.64402962], [72.88069153, 20.64402771], [72.88069153, 20.64458275], [72.88041687, 20.64458084], [72.88041687, 20.64513969], [72.87985992, 20.64513969], [72.87985992, 20.64541626], [72.87930298, 20.64541626], [72.87930298, 20.64569473], [72.87902832, 20.64569473], [72.87902832, 20.6459713], [72.87874603, 20.64596939], [72.87874603, 20.64624977], [72.87847137, 20.64624977], [72.87847137, 20.64652824], [72.87819672, 20.64652634], [72.87819672, 20.64680481], [72.8779068, 20.64680099], [72.8779068, 20.64763832], [72.87763977, 20.64763832], [72.87763977, 20.64792061], [72.87735748, 20.64792061], [72.87735748, 20.64819908], [72.87708282, 20.64819527], [72.87708282, 20.64847183], [72.87680817, 20.64846992], [72.87680817, 20.6487484], [72.87652588, 20.6487484], [72.87652588, 20.64930916], [72.87625122, 20.64930916], [72.87625122, 20.64985847], [72.87596893, 20.64985847], [72.87596893, 20.65069389], [72.87568665, 20.65069008], [72.87568665, 20.65125275], [72.87541962, 20.65125275], [72.87541962, 20.65208054], [72.87513733, 20.65208054], [72.87513733, 20.65291977], [72.87486267, 20.65291595], [72.87486267, 20.65347481], [72.87458038, 20.65347481], [72.87458038, 20.65486145], [72.87431335, 20.65485954], [72.87431335, 20.6554203], [72.87403107, 20.6554203], [72.87403107, 20.65653038], [72.87374878, 20.65652847], [72.87374878, 20.65736198], [72.87346649, 20.65735054], [72.87346649, 20.65764046], [72.87319183, 20.65763855], [72.87319183, 20.65847206], [72.87290955, 20.65847015], [72.87290955, 20.65930939], [72.87264252, 20.65930557], [72.87264252, 20.6609726], [72.87236023, 20.66097069], [72.87236023, 20.66235924], [72.8720932, 20.66235924], [72.8720932, 20.66348267], [72.87180328, 20.66347313], [72.87180328, 20.66430473], [72.87152863, 20.66430092], [72.87152863, 20.66514015], [72.87124634, 20.66513824], [72.87124634, 20.66597366], [72.87097168, 20.66596985], [72.87097168, 20.66930962], [72.87069702, 20.6693058], [72.87069702, 20.66958427], [72.8704071, 20.66958046], [72.8704071, 20.67041969], [72.87014008, 20.67041969], [72.87014008, 20.67181015], [72.86985779, 20.67180634], [72.86985779, 20.6720829], [72.86958313, 20.67208099], [72.86958313, 20.67374992], [72.86930847, 20.67374992], [72.86930847, 20.67431068], [72.86902618, 20.67430496], [72.86902618, 20.6756897], [72.86875153, 20.67569923], [72.86875153, 20.67624855], [72.86846924, 20.67624855], [72.86846924, 20.67708397], [72.86818695, 20.67708015], [72.86818695, 20.67791939], [72.86791992, 20.67791939], [72.86791992, 20.67986107], [72.86763763, 20.67986107], [72.86763763, 20.68124962], [72.86736298, 20.68124962], [72.86736298, 20.68264008], [72.86708069, 20.68264008], [72.86708069, 20.68375015], [72.86680603, 20.68375015], [72.86680603, 20.68431091], [72.86653137, 20.68430519], [72.86653137, 20.68458366], [72.86624908, 20.68457985], [72.86624908, 20.68514061], [72.86597443, 20.6851387], [72.86597443, 20.68569374], [72.86569214, 20.68568993], [72.86569214, 20.68680954], [72.86541748, 20.68680954], [72.86541748, 20.68791962], [72.86514282, 20.68791962], [72.86514282, 20.6890316], [72.86486053, 20.6890316], [72.86486053, 20.69014168], [72.86458588, 20.69014168], [72.86458588, 20.69096947], [72.86430359, 20.69096947], [72.86430359, 20.69180489], [72.86402893, 20.69180489], [72.86402893, 20.69236374], [72.86374664, 20.69236183], [72.86374664, 20.69320107], [72.86347198, 20.69320107], [72.86347198, 20.69403076], [72.86319733, 20.69402695], [72.86319733, 20.6945858], [72.86292267, 20.69458008], [72.86292267, 20.69542122], [72.86264038, 20.69542122], [72.86264038, 20.69625092], [72.86235809, 20.69625092], [72.86235809, 20.69680977], [72.86207581, 20.69680977], [72.86207581, 20.69763947], [72.86180878, 20.69763947], [72.86180878, 20.69847298], [72.86152649, 20.69847107], [72.86152649, 20.69959068], [72.86125183, 20.69959068], [72.86125183, 20.70042038], [72.86096954, 20.70042038], [72.86096954, 20.70153046], [72.86067963, 20.70153046], [72.86067963, 20.70265007], [72.86042023, 20.70263863], [72.86042023, 20.70347023], [72.86013794, 20.70347023], [72.86013794, 20.70458412], [72.85986328, 20.70458031], [72.85986328, 20.70514107], [72.85958099, 20.70514107], [72.85958099, 20.70625114], [72.85930634, 20.70625114], [72.85930634, 20.70736122], [72.85902405, 20.70736122], [72.85902405, 20.7084713], [72.85874939, 20.7084713], [72.85874939, 20.70958328], [72.8584671, 20.70957947], [72.8584671, 20.71042061], [72.85819244, 20.71042061], [72.85819244, 20.71125031], [72.85791779, 20.71125031], [72.85791779, 20.71208382], [72.85764313, 20.71208], [72.85764313, 20.71264076], [72.85736084, 20.71263885], [72.85736084, 20.71319389], [72.85708618, 20.71319008], [72.85708618, 20.71430969], [72.85679626, 20.71430969], [72.85679626, 20.71542168], [72.85652924, 20.71542168], [72.85652924, 20.71653175], [72.85624695, 20.71652985], [72.85624695, 20.71735954], [72.85597229, 20.71735954], [72.85597229, 20.71820068], [72.85569763, 20.71820068], [72.85569763, 20.71903038], [72.85541534, 20.71902847], [72.85541534, 20.71986389], [72.85514069, 20.71986389], [72.85514069, 20.72097206], [72.85486603, 20.72097015], [72.85486603, 20.72264099], [72.85457611, 20.72264099], [72.85457611, 20.72430992], [72.85430908, 20.72430992], [72.85430908, 20.72652817], [72.85402679, 20.72652817], [72.85402679, 20.72874832], [72.85375214, 20.72874832], [72.85375214, 20.72958946], [72.85346985, 20.72958946], [72.85346985, 20.73042107], [72.85319519, 20.73041725], [72.85319519, 20.73097038], [72.8529129, 20.73097038], [72.8529129, 20.73263931], [72.85263824, 20.73263931], [72.85263824, 20.73347473], [72.85235596, 20.73347282], [72.85235596, 20.73402977], [72.8520813, 20.73402977], [72.8520813, 20.73792076], [72.85235596, 20.73792076], [72.85235596, 20.74041748], [72.85180664, 20.74041748], [72.85180664, 20.74097252], [72.85151672, 20.74097061], [72.85151672, 20.74152756], [72.85098267, 20.74152756], [72.85098267, 20.74292183], [72.85124969, 20.74291611], [72.85124969, 20.74458122], [72.85152435, 20.74458122], [72.85152435, 20.74486351], [72.85263824, 20.74486351], [72.85263824, 20.74458122], [72.85319519, 20.74458122], [72.85319519, 20.74430466], [72.85346985, 20.74430466], [72.85346985, 20.74402809], [72.85375214, 20.74403191], [72.85375214, 20.74375153], [72.85402679, 20.74375153], [72.85402679, 20.74346924], [72.85430908, 20.74347115], [72.85430908, 20.74291611], [72.85457611, 20.74292183], [72.85457611, 20.74264145], [72.85486603, 20.74264145], [72.8548584, 20.74180603], [72.85514069, 20.74181938], [72.85514069, 20.74152756], [72.85542297, 20.74152756], [72.85542297, 20.74124908], [72.85569763, 20.74124908], [72.85569763, 20.74097061], [72.85597229, 20.74097252], [72.85597229, 20.74069405], [72.85624695, 20.74069405], [72.85624695, 20.74041748], [72.85652924, 20.74041748], [72.85652924, 20.74014091], [72.85679626, 20.74014091], [72.85679626, 20.73986053], [72.85708618, 20.73986053], [72.85708618, 20.73931122], [72.85736084, 20.73931122], [72.85736084, 20.73875809], [72.85764313, 20.73875809], [72.85764313, 20.73847008], [72.85819244, 20.73847198], [72.85819244, 20.73819351], [72.85847473, 20.73819351], [72.85847473, 20.73791695], [72.85874939, 20.73791695], [72.85874939, 20.73819351], [72.85902405, 20.73819351], [72.85902405, 20.73736191], [72.85930634, 20.73736191], [72.85930634, 20.7365284], [72.85958099, 20.7365303], [72.85958099, 20.73624992], [72.85986328, 20.73624992], [72.85986328, 20.73542023], [72.86013794, 20.73542023], [72.86013794, 20.73513985], [72.86096954, 20.73513985], [72.86096954, 20.73542023], [72.86125183, 20.73541641], [72.86125183, 20.73597145], [72.86152649, 20.73596954], [72.86152649, 20.73624992], [72.86207581, 20.73624992], [72.86207581, 20.73596954], [72.86235809, 20.73597145], [72.86235809, 20.73569489], [72.86264038, 20.73569489], [72.86264038, 20.73597145], [72.86291504, 20.73597145], [72.86291504, 20.73569489], [72.86319733, 20.73569489], [72.86319733, 20.73541641], [72.86347198, 20.73542023], [72.86347198, 20.73513985], [72.86708069, 20.73513985], [72.86708069, 20.73542023], [72.86791992, 20.73541641], [72.86791992, 20.73569489], [72.86902618, 20.73569489], [72.86902618, 20.73541641], [72.86930847, 20.73542023], [72.86930847, 20.73485947], [72.86958313, 20.73486137], [72.86958313, 20.73319435], [72.86930847, 20.73319435], [72.86930847, 20.73291588], [72.86902618, 20.73291969], [72.86902618, 20.73263168], [72.87014008, 20.73263168], [72.87014008, 20.73291969], [72.87041473, 20.73291588], [72.87041473, 20.73319435], [72.87152863, 20.73319435], [72.87152863, 20.73347473], [72.87180328, 20.73347282], [72.87180328, 20.73374939], [72.8720932, 20.73374939], [72.8720932, 20.73402977], [72.87236023, 20.73402977], [72.87236023, 20.73431015], [72.87403107, 20.73430634], [72.87403107, 20.73458481], [72.87458038, 20.73458481], [72.87458038, 20.73486137], [72.87486267, 20.73485947], [72.87486267, 20.73513985], [72.87513733, 20.73513794], [72.87513733, 20.73569489], [72.87569427, 20.73569489], [72.87569427, 20.73597145], [72.87735748, 20.73596954], [72.87735748, 20.73624992], [72.87763977, 20.73624992], [72.87763977, 20.7365303], [72.87847137, 20.7365303], [72.87847137, 20.73681068], [72.87875366, 20.73680687], [72.87875366, 20.73736191], [72.8795929, 20.73736], [72.8795929, 20.73764038], [72.88014221, 20.73764038], [72.88014221, 20.73792076], [72.88124847, 20.73791695], [72.88124847, 20.73819351], [72.88458252, 20.73819351], [72.88458252, 20.73847198], [72.88597107, 20.73847008], [72.88597107, 20.73875809], [72.88874817, 20.73875809], [72.88874817, 20.73903084], [72.88986206, 20.73903084], [72.88986206, 20.74041748], [72.88957977, 20.74041748], [72.88957977, 20.74069405], [72.88903046, 20.74069405], [72.88903046, 20.74097252], [72.88874817, 20.74097061], [72.88874817, 20.74124908], [72.88819122, 20.74124908], [72.88819122, 20.74152756], [72.88791656, 20.74152756], [72.88791656, 20.74181938], [72.88764191, 20.74180603], [72.88764191, 20.7420826], [72.88819122, 20.74208069], [72.88819122, 20.74235916], [72.88846588, 20.74235916], [72.88846588, 20.74264145], [72.88874817, 20.74264145], [72.88874817, 20.74292183], [72.88903046, 20.74291611], [72.88903046, 20.74347115], [72.88874817, 20.74346924], [72.88874817, 20.74375153], [72.88846588, 20.74375153], [72.88846588, 20.74403191], [72.88819122, 20.74402809], [72.88819122, 20.74597359], [72.88846588, 20.74596977], [72.88846588, 20.74653053], [72.88874817, 20.74653053], [72.88874817, 20.74681091], [72.88903046, 20.74680519], [72.88903046, 20.74708366], [72.88930511, 20.74708366], [72.88930511, 20.74736023], [72.88957977, 20.74736023], [72.88957977, 20.74819565], [72.88930511, 20.74819565], [72.88930511, 20.74847221], [72.88903046, 20.74847221], [72.88903046, 20.74819565], [72.88874817, 20.74819565], [72.88874817, 20.74791718], [72.88846588, 20.74792099], [72.88846588, 20.74763107], [72.88819122, 20.7476387], [72.88819122, 20.74736023], [72.88791656, 20.74736023], [72.88791656, 20.74653053], [72.88764191, 20.74653053], [72.88764191, 20.74625015], [72.88735962, 20.74625015], [72.88735962, 20.74596977], [72.88708496, 20.74597359], [72.88708496, 20.74541664], [72.88680267, 20.74542046], [72.88680267, 20.7448597], [72.88652802, 20.74486351], [72.88652802, 20.74430466], [72.88625336, 20.74430466], [72.88625336, 20.74402809], [72.88597107, 20.74403191], [72.88597107, 20.74319077], [72.88569641, 20.74319458], [72.88569641, 20.74291611], [72.88513947, 20.74292183], [72.88513947, 20.74264145], [72.88484955, 20.74264145], [72.88484955, 20.74235916], [72.88430786, 20.74235916], [72.88430786, 20.74208069], [72.88096619, 20.74208069], [72.88097382, 20.74235916], [72.87958527, 20.74235916], [72.87958527, 20.74347115], [72.88041687, 20.74347115], [72.88041687, 20.74430466], [72.87735748, 20.74430466], [72.87735748, 20.74402809], [72.87708282, 20.74402809], [72.87708282, 20.74430466], [72.87680817, 20.74430466], [72.87680817, 20.74458122], [72.87569427, 20.74458122], [72.87569427, 20.74486351], [72.87403107, 20.7448597], [72.87403107, 20.74514008], [72.87319183, 20.74514008], [72.87319183, 20.74542046], [72.87264252, 20.74542046], [72.87264252, 20.74570084], [72.87208557, 20.74569511], [72.87208557, 20.74597359], [72.87097168, 20.74596977], [72.87097168, 20.74625015], [72.87014008, 20.74625015], [72.87014008, 20.74653053], [72.86958313, 20.74653053], [72.86958313, 20.74681091], [72.86930847, 20.74680519], [72.86930847, 20.74708366], [72.86902618, 20.74707985], [72.86902618, 20.74736023], [72.86846924, 20.74736023], [72.86846924, 20.7476387], [72.86818695, 20.74763107], [72.86818695, 20.74792099], [72.86736298, 20.74791718], [72.86736298, 20.74819565], [72.86680603, 20.74818993], [72.86680603, 20.74930954], [72.86653137, 20.74930573], [72.86653137, 20.7495842], [72.86624908, 20.74958038], [72.86624908, 20.75041962], [72.86597443, 20.7504158], [72.86597443, 20.75097275], [72.86569214, 20.75097084], [72.86569214, 20.75152969], [72.86541748, 20.75152969], [72.86541748, 20.75181007], [72.86513519, 20.75180626], [72.86514282, 20.75263977], [72.86486053, 20.75263977], [72.86486053, 20.75291824], [72.86458588, 20.75291634], [72.86458588, 20.75319481], [72.86430359, 20.75319481], [72.86430359, 20.75347137], [72.86403656, 20.75346947], [72.86403656, 20.75375938], [72.86374664, 20.75375938], [72.86374664, 20.75402832], [72.86347198, 20.75402832], [72.86347198, 20.75430489], [72.86319733, 20.75430489], [72.86319733, 20.75458336], [72.86292267, 20.75457954], [72.86292267, 20.7551384], [72.86264038, 20.7551384], [72.86264038, 20.75542068], [72.86235809, 20.75542068], [72.86235809, 20.75764275], [72.86207581, 20.75764275], [72.86207581, 20.75875282], [72.86180878, 20.75875282], [72.86180878, 20.76041985], [72.86208344, 20.76041603], [72.86208344, 20.76097488], [72.86180878, 20.76097107], [72.86180878, 20.76124954], [72.86152649, 20.76124954], [72.86152649, 20.76152992], [72.86125183, 20.76152992], [72.86125183, 20.7618103], [72.86096954, 20.76180649], [72.86096954, 20.76208305], [72.86067963, 20.76208115], [72.86067963, 20.76264], [72.86042023, 20.76264], [72.86042023, 20.76292992], [72.86013794, 20.76292992], [72.86013794, 20.76320076], [72.85986328, 20.76319695], [72.85986328, 20.7634716], [72.85958099, 20.7634697], [72.85958099, 20.76375008], [72.85930634, 20.76375008], [72.85930634, 20.76431084], [72.85902405, 20.76430511], [72.85902405, 20.76458359], [72.85874939, 20.76458359], [72.85874939, 20.76486206], [72.85791016, 20.76486015], [72.85791016, 20.76514053], [72.85736084, 20.76514053], [72.85736084, 20.76542091], [72.85708618, 20.76542091], [72.85708618, 20.76569939], [72.85680389, 20.76569366], [72.85680389, 20.76597214], [72.85624695, 20.76597023], [72.85624695, 20.76625061], [72.85486603, 20.76625061], [72.85486603, 20.76652908], [72.85346985, 20.76652908], [72.85346985, 20.76680946], [72.8520813, 20.76680565], [72.8520813, 20.76708412], [72.85180664, 20.76708031], [72.85180664, 20.76736069], [72.85098267, 20.76736069], [72.85098267, 20.76763916], [72.84986115, 20.76763916], [72.84986115, 20.76791763], [72.84902954, 20.76791763], [72.84902954, 20.7681942], [72.84819794, 20.7681942], [72.84819794, 20.76847267], [72.84708405, 20.76847267], [72.84708405, 20.76874924], [72.8465271, 20.7687397], [72.8465271, 20.76903152], [72.84625244, 20.76903152], [72.84625244, 20.7693119], [72.84597015, 20.76930618], [72.84597015, 20.76958275], [72.84541321, 20.76958084], [72.84541321, 20.76985931], [72.84513855, 20.76985931], [72.84513855, 20.77042007], [72.84485626, 20.77042007], [72.84485626, 20.77125168], [72.8445816, 20.77125168], [72.8445816, 20.77236366], [72.84430695, 20.77236176], [72.84430695, 20.77264023], [72.84348297, 20.77264023], [72.84348297, 20.77292061], [72.84319305, 20.77292061], [72.84319305, 20.7732029], [72.8429184, 20.77319527], [72.8429184, 20.77347374], [72.84263611, 20.77346992], [72.84263611, 20.77431107], [72.84236145, 20.77431107], [72.84236145, 20.77486992], [72.84208679, 20.77486992], [72.84208679, 20.77514076], [72.8418045, 20.77513885], [72.8418045, 20.7756958], [72.84152985, 20.7756958], [72.84152985, 20.77597237], [72.84124756, 20.77597046], [72.84124756, 20.77625084], [72.84069824, 20.77625084], [72.84069824, 20.77653122], [72.84041595, 20.77653122], [72.84041595, 20.77680969], [72.83985901, 20.77680588], [72.83985901, 20.77708244], [72.83930206, 20.77708054], [72.83930206, 20.77736092], [72.8390274, 20.77736092], [72.8390274, 20.77763939], [72.83875275, 20.77763939], [72.83875275, 20.77793121], [72.83847046, 20.77791786], [72.83847046, 20.7784729], [72.8381958, 20.77847099], [72.8381958, 20.77902985], [72.83791351, 20.77902794], [72.83791351, 20.77958298], [72.83763885, 20.77958298], [72.83763885, 20.77986145], [72.83735657, 20.77985954], [72.83735657, 20.7804203], [72.83679962, 20.7804203], [72.83679962, 20.78070068], [72.83651733, 20.78070068], [72.83652496, 20.7805481], [72.83652496, 20.78041649], [72.83598328, 20.7804203], [72.83598328, 20.78070068], [72.8354187, 20.78069496], [72.8354187, 20.78097153], [72.83513641, 20.78096962], [72.83513641, 20.78152847], [72.83486176, 20.78152847], [72.83486176, 20.78181076], [72.8345871, 20.78180504], [72.8345871, 20.78347015], [72.83486176, 20.78347015], [72.83486176, 20.78430939], [72.83513641, 20.78430557], [72.83513641, 20.78458405], [72.83569336, 20.78458023], [72.83569336, 20.78486252], [72.83589935, 20.78486252], [72.83597565, 20.78486252], [72.83598328, 20.78541946], [72.83625031, 20.78541946], [72.83625031, 20.78680992], [72.83597565, 20.78680611], [72.83597565, 20.78819466], [72.83569336, 20.78819466], [72.83569336, 20.78958321], [72.8354187, 20.78957939], [72.8354187, 20.79070091], [72.83569336, 20.79070091], [72.83569336, 20.79125023], [72.83651733, 20.79125023], [72.83651733, 20.79153061], [72.83679962, 20.79153061], [72.83679962, 20.79181099], [72.8373642, 20.79180527], [72.8373642, 20.79208374], [72.83763885, 20.79207993], [72.83763885, 20.79264069], [72.83790588, 20.79264069], [72.83790588, 20.79430962], [72.83763885, 20.7943058], [72.83763885, 20.79597282], [72.83790588, 20.79597092], [72.83790588, 20.79681015], [72.8381958, 20.79680634], [72.8381958, 20.79735947], [72.83847046, 20.79735947], [72.83847046, 20.79792023], [72.83875275, 20.79792023], [72.83875275, 20.79875183], [72.83986664, 20.79875183], [72.83986664, 20.7990303], [72.84069061, 20.7990303], [72.84069824, 20.79875183], [72.8409729, 20.79875183], [72.8409729, 20.79818916], [72.84124756, 20.79819489], [72.84124756, 20.79791641], [72.84152985, 20.79792023], [72.84152985, 20.79764175], [72.84208679, 20.79764175], [72.84208679, 20.79735947], [72.84263611, 20.79735947], [72.84263611, 20.7970829], [72.84347534, 20.7970829], [72.84347534, 20.79735947], [72.84390259, 20.79735947], [72.84401703, 20.79735947], [72.84401703, 20.79764175], [72.84430695, 20.79764175], [72.84430695, 20.79792023], [72.84513855, 20.79791641], [72.84513855, 20.79847336], [72.8473587, 20.79847336], [72.8473587, 20.79819489], [72.84819794, 20.79819489], [72.84819794, 20.79791641], [72.84958649, 20.79791641], [72.84958649, 20.79819489], [72.85041809, 20.79819489], [72.85041809, 20.79847336], [72.85069275, 20.79846954], [72.85069275, 20.7990303], [72.85041809, 20.7990303], [72.85041809, 20.79931068], [72.84986115, 20.79930305], [72.84986115, 20.79958344], [72.84958649, 20.79958344], [72.84958649, 20.79986382], [72.84902954, 20.79986191], [72.84902954, 20.80014038], [72.84873962, 20.80014038], [72.84873962, 20.80042076], [72.8484726, 20.80041695], [72.8484726, 20.8006897], [72.84819794, 20.80070114], [72.84819794, 20.80125046], [72.84764099, 20.80125046], [72.84764099, 20.80153084], [72.8473587, 20.80153084], [72.8473587, 20.80264091], [72.84708405, 20.80263901], [72.84708405, 20.80335045], [72.84708405, 20.80347252], [72.84680939, 20.80347061], [72.84680176, 20.80375099], [72.8456955, 20.80374908], [72.8456955, 20.80347252], [72.84348297, 20.80347061], [72.84348297, 20.80375099], [72.84319305, 20.80375099], [72.84319305, 20.80402946], [72.84263611, 20.80402946], [72.84263611, 20.80430984], [72.84208679, 20.80430794], [72.84208679, 20.8045826], [72.84152985, 20.8045826], [72.84152985, 20.80471992], [72.84152985, 20.80486107], [72.84111786, 20.80485535], [72.84069824, 20.80484962], [72.84069824, 20.80513954], [72.8390274, 20.80513954], [72.8390274, 20.80484962], [72.83763885, 20.80486107], [72.83763885, 20.8045826], [72.8373642, 20.8045826], [72.8373642, 20.80430794], [72.83597565, 20.80430794], [72.83597565, 20.8045826], [72.8354187, 20.8045826], [72.8354187, 20.80486107], [72.8345871, 20.80486107], [72.8345871, 20.80569458], [72.83429718, 20.80569077], [72.83429718, 20.80624962], [72.83403015, 20.80624962], [72.83403015, 20.80597115], [72.83347321, 20.80597115], [72.83347321, 20.80652809], [72.83291626, 20.80652618], [72.83291626, 20.80680466], [72.83235931, 20.80680466], [72.83235931, 20.80708313], [72.83208466, 20.80708313], [72.83208466, 20.8073616], [72.83152771, 20.8073597], [72.83152771, 20.80763817], [72.83125305, 20.80763817], [72.83125305, 20.80791664], [72.83097076, 20.80791092], [72.83097076, 20.80820084], [72.83069611, 20.80819511], [72.83069611, 20.80847168], [72.83040619, 20.80846977], [72.83040619, 20.80874825], [72.83013916, 20.80874825], [72.83013916, 20.80903053], [72.82985687, 20.80903053], [72.82985687, 20.80931091], [72.82958221, 20.80930519], [72.82958221, 20.80958366], [72.82875061, 20.80957985], [72.82875061, 20.80985832], [72.82847595, 20.80985832], [72.82847595, 20.8104229], [72.82819366, 20.81041718], [72.82819366, 20.81097031], [72.82792664, 20.81097031], [72.82792664, 20.81180954], [72.82763672, 20.81180954], [72.82763672, 20.81236267], [72.82736206, 20.81236267], [72.82736206, 20.81264114], [72.82707977, 20.81264114], [72.82707977, 20.81291962], [72.82680511, 20.8129158], [72.82680511, 20.81319427], [72.82653046, 20.81319427], [72.82653046, 20.81347466], [72.82624817, 20.81347275], [72.82624817, 20.81404114], [72.82596588, 20.81404114], [72.82596588, 20.81431007], [72.82569122, 20.81431007], [72.82569122, 20.81624985], [72.82597351, 20.81624985], [72.82597351, 20.81708336], [72.82569122, 20.81707954], [72.82569122, 20.81792068], [72.82541656, 20.81792068], [72.82541656, 20.81903076], [72.82514191, 20.81903076], [72.82514191, 20.82014084], [72.82485962, 20.82013893], [72.82485962, 20.82069397], [72.82458496, 20.82069397], [72.82458496, 20.82097244], [72.82430267, 20.82097054], [72.82430267, 20.82180977], [72.82402802, 20.82180977], [72.82402802, 20.82235909], [72.82375336, 20.82235909], [72.82375336, 20.8231945], [72.82347107, 20.82319069], [72.82347107, 20.82403183], [72.82319641, 20.82402992], [72.82319641, 20.82458115], [72.82290649, 20.82457924], [72.82290649, 20.82542038], [72.82263947, 20.82542038], [72.82263947, 20.82625008], [72.82235718, 20.82625008], [72.82235718, 20.82681084], [72.82208252, 20.82681084], [72.82208252, 20.82764053], [72.82180023, 20.82764053], [72.82180023, 20.82792091], [72.82208252, 20.8279171], [72.82208252, 20.82847214], [72.82180023, 20.82847023], [72.82180023, 20.82930946], [72.82152557, 20.82930565], [72.8215332, 20.82986069], [72.82125092, 20.82986069], [72.82125092, 20.83097267], [72.82096863, 20.83097076], [72.82096863, 20.83180809], [72.82068634, 20.83180809], [72.82068634, 20.83263969], [72.82041931, 20.83263969], [72.82041931, 20.83291817], [72.82013702, 20.83291626], [72.82013702, 20.8334713], [72.81986237, 20.83346939], [72.81986237, 20.83542061], [72.81958008, 20.83542061], [72.81958008, 20.83569908], [72.81931305, 20.83569908], [72.81931305, 20.83681107], [72.81903076, 20.83681107], [72.81903076, 20.83792114], [72.81874847, 20.83791733], [72.81874847, 20.83847046], [72.81846619, 20.83847046], [72.81846619, 20.83875275], [72.81819153, 20.83875275], [72.81819153, 20.83958054], [72.81791687, 20.83958054], [72.81791687, 20.84013939], [72.81764221, 20.84013939], [72.81764221, 20.84124947], [72.81735992, 20.84124947], [72.81735992, 20.84181023], [72.8170929, 20.84181023], [72.8170929, 20.84263992], [72.81680298, 20.84263992], [72.81680298, 20.84320068], [72.81652832, 20.84320068], [72.81652832, 20.84375], [72.81624603, 20.84375], [72.81624603, 20.84431076], [72.81597137, 20.84430695], [72.81597137, 20.84458351], [72.81569672, 20.8445797], [72.81569672, 20.84514046], [72.81541443, 20.84513855], [72.81541443, 20.84569359], [72.81513977, 20.84568977], [72.81513977, 20.84653091], [72.81485748, 20.8465271], [72.81485748, 20.84708405], [72.81458282, 20.84708023], [72.81458282, 20.84791756], [72.81430817, 20.84791756], [72.81430817, 20.8484726], [72.81402588, 20.84847069], [72.81402588, 20.84931183], [72.81375122, 20.84931183], [72.81375122, 20.84985924], [72.81346893, 20.84985924], [72.81346893, 20.85069466], [72.81318665, 20.85069084], [72.81318665, 20.8512516], [72.81291962, 20.8512516], [72.81291962, 20.8520813], [72.81263733, 20.85207939], [72.81263733, 20.85264015], [72.81236267, 20.85263824], [72.81236267, 20.85347366], [72.81208038, 20.85346985], [72.81208038, 20.85403061], [72.81180573, 20.8540287], [72.81181335, 20.85486031], [72.81153107, 20.85486031], [72.81153107, 20.85569572], [72.81124878, 20.85569], [72.81124878, 20.85625076], [72.81097412, 20.85625076], [72.81097412, 20.85708427], [72.81069183, 20.85708046], [72.81069183, 20.85764122], [72.81041718, 20.85764122], [72.81041718, 20.85791969], [72.81014252, 20.85791779], [72.81014252, 20.85819435], [72.80986023, 20.85819435], [72.80986023, 20.85847282], [72.8095932, 20.85847092], [72.8095932, 20.86013985], [72.80930328, 20.86013985], [72.80930328, 20.86069489], [72.80902863, 20.86069107], [72.80902863, 20.86124992], [72.80874634, 20.86124992], [72.80874634, 20.86181068], [72.80847168, 20.86180496], [72.80847168, 20.86236191], [72.80819702, 20.86235809], [72.80819702, 20.86292076], [72.80791473, 20.86291695], [72.80791473, 20.86347008], [72.80764008, 20.86346817], [72.80764008, 20.86403275], [72.80735779, 20.86402702], [72.80735779, 20.86458206], [72.80708313, 20.86458015], [72.80708313, 20.86515045], [72.80680847, 20.86514091], [72.80680847, 20.86569214], [72.80652618, 20.86569023], [72.80652618, 20.86652946], [72.80625153, 20.86652756], [72.80625153, 20.8670845], [72.80596924, 20.86708069], [72.80596924, 20.86763954], [72.80569458, 20.86763954], [72.80569458, 20.86819458], [72.80541992, 20.86819077], [72.80541992, 20.86874962], [72.80513763, 20.86874962], [72.80513763, 20.86958313], [72.80486298, 20.86958122], [72.80486298, 20.87014008], [72.80458069, 20.87014008], [72.80458069, 20.87070084], [72.80430603, 20.87070084], [72.80430603, 20.87125015], [72.80403137, 20.87125015], [72.80403137, 20.87181091], [72.80375671, 20.87181091], [72.80375671, 20.87264061], [72.80347443, 20.8726387], [72.80347443, 20.87319374], [72.80319214, 20.87318993], [72.80319214, 20.87402916], [72.80291748, 20.87402725], [72.80291748, 20.8745842], [72.80264282, 20.87458038], [72.80264282, 20.87542152], [72.80236053, 20.8754158], [72.80236053, 20.87597275], [72.80208588, 20.87597084], [72.80208588, 20.8765316], [72.80179596, 20.8765316], [72.80179596, 20.87681007], [72.80152893, 20.87681007], [72.80152893, 20.87709045], [72.80124664, 20.87708282], [72.80124664, 20.87847328], [72.80097198, 20.87846947], [72.80097198, 20.87903023], [72.80069733, 20.87902832], [72.80069733, 20.87986374], [72.80042267, 20.87985992], [72.80042267, 20.88042068], [72.80014038, 20.88041687], [72.80014038, 20.88097382], [72.79985809, 20.88097], [72.79985809, 20.88153076], [72.79958344, 20.88152695], [72.79958344, 20.8820858], [72.79930878, 20.88208008], [72.79930878, 20.88264084], [72.79902649, 20.88263893], [72.79902649, 20.88319588], [72.79875183, 20.88319016], [72.79875183, 20.88375092], [72.79846954, 20.88375092], [72.79846954, 20.88430977], [72.79818726, 20.88430977], [72.79818726, 20.88486099], [72.79792023, 20.88486099], [72.79792023, 20.88513947], [72.79763794, 20.88513947], [72.79763794, 20.88597298], [72.79736328, 20.88597107], [72.79736328, 20.88652992], [72.79708099, 20.88652992], [72.79708099, 20.8868103], [72.79680634, 20.88680649], [72.79680634, 20.88736153], [72.79651642, 20.88735962], [72.79651642, 20.88792038], [72.79624939, 20.88791656], [72.79624939, 20.8884716], [72.7959671, 20.8884697], [72.7959671, 20.88902855], [72.79569244, 20.88902855], [72.79569244, 20.88958359], [72.79541779, 20.88957977], [72.79541779, 20.89013863], [72.7951355, 20.89013863], [72.7951355, 20.89097023], [72.79486084, 20.89097023], [72.79486084, 20.89125252], [72.79458618, 20.89125252], [72.79458618, 20.89180946], [72.79429626, 20.89180946], [72.79429626, 20.89236259], [72.79402924, 20.89236259], [72.79402924, 20.89291954], [72.79374695, 20.89291763], [72.79374695, 20.89347458], [72.79347229, 20.89347076], [72.79347229, 20.89402962], [72.79319763, 20.89402771], [72.79319763, 20.89458466], [72.79291534, 20.89458466], [72.79291534, 20.89513969], [72.79264069, 20.89513016], [72.79264069, 20.89542007], [72.7923584, 20.89541626], [72.7923584, 20.8959713], [72.79207611, 20.89596939], [72.79207611, 20.89653015], [72.79181671, 20.89653015], [72.79181671, 20.89792061], [72.79152679, 20.89792061], [72.79152679, 20.89875031], [72.79181671, 20.89875031], [72.79181671, 20.89903069], [72.79152679, 20.89902687], [72.79152679, 20.89958382], [72.79125214, 20.89958], [72.79125214, 20.90125847], [72.79096985, 20.90125847], [72.79096985, 20.90263939], [72.79070282, 20.90263939], [72.79070282, 20.90431976], [72.7904129, 20.90431976], [72.7904129, 20.91320038], [72.79013824, 20.91320038], [72.79013824, 20.91402817], [72.78986359, 20.91402817], [72.78986359, 20.91458321], [72.7895813, 20.91458321], [72.7895813, 20.91597176], [72.78930664, 20.91596985], [72.78930664, 20.91653061], [72.78901672, 20.91653061], [72.78901672, 20.9168129], [72.78874969, 20.91680527], [72.78874969, 20.91708374], [72.78848267, 20.91708183], [72.78848267, 20.91764259], [72.78819275, 20.91763878], [72.78819275, 20.91819382], [72.78791809, 20.91819191], [72.78791809, 20.91903114], [72.78736115, 20.91902733], [72.78736115, 20.9193058], [72.78708649, 20.9193058], [72.78708649, 20.91958427], [72.7868042, 20.91958427], [72.7868042, 20.92069244], [72.78652954, 20.92069244], [72.78652954, 20.92097473], [72.78624725, 20.92097282], [72.78624725, 20.92152977], [72.7859726, 20.92152977], [72.7859726, 20.92181015], [72.78569794, 20.92180634], [72.78569794, 20.92208481], [72.78541565, 20.92208481], [72.78541565, 20.92319679], [72.78569794, 20.92319679], [72.78569794, 20.92291641], [72.78679657, 20.92292023], [72.78679657, 20.92263985], [72.78847504, 20.92263794], [72.78847504, 20.92319679], [72.78791809, 20.92319679], [72.78791809, 20.92347145], [72.78736115, 20.92346954], [72.78736115, 20.92374992], [72.78708649, 20.92374992], [72.78708649, 20.9240303], [72.7868042, 20.9240284], [72.7868042, 20.92486191], [72.78624725, 20.92486], [72.78624725, 20.92514038], [72.7859726, 20.92514038], [72.7859726, 20.9254303], [72.78569031, 20.9254303], [72.78569031, 20.92791748], [72.7859726, 20.92791748], [72.7859726, 20.92819405], [72.78624725, 20.92818069], [72.78624725, 20.92903137], [72.78652954, 20.92903137], [72.78652954, 20.92985916], [72.7868042, 20.92985916], [72.7868042, 20.93069458], [72.78708649, 20.93069458], [72.78708649, 20.93124962], [72.78736115, 20.93123817], [72.78736115, 20.93153191], [72.7876358, 20.93152809], [72.7876358, 20.93180466], [72.78847504, 20.93180466], [72.78847504, 20.93208122], [72.7895813, 20.93208122], [72.7895813, 20.93180466], [72.79125214, 20.93180466], [72.79125214, 20.93152809], [72.79402924, 20.93153191], [72.79402924, 20.93320084], [72.79430389, 20.93319511], [72.79430389, 20.93569565], [72.79402924, 20.93569565], [72.79402924, 20.93597221], [72.79374695, 20.93597221], [72.79374695, 20.9370842], [72.79347229, 20.93708038], [72.79347229, 20.9373703], [72.79319763, 20.9373703], [72.79319763, 20.93791962], [72.79291534, 20.93791771], [72.79291534, 20.93819427], [72.79013824, 20.93819427], [72.79013824, 20.93847275], [72.78901672, 20.93847084], [72.78901672, 20.93875122], [72.78848267, 20.93875122], [72.78848267, 20.93902969], [72.78875732, 20.93902969], [72.78875732, 20.93930817], [72.78902435, 20.93930626], [72.78902435, 20.93958282], [72.78930664, 20.93958282], [72.78930664, 20.94069481], [72.78902435, 20.94069481], [72.78902435, 20.94097137], [72.78875732, 20.94096947], [72.78875732, 20.94152832], [72.78902435, 20.94152832], [72.78902435, 20.94180489], [72.7895813, 20.94180489], [72.7895813, 20.94208336], [72.78986359, 20.94208336], [72.78986359, 20.94236183], [72.7904129, 20.94235992], [72.7904129, 20.9426384], [72.79070282, 20.9426384], [72.79070282, 20.94319916], [72.79125214, 20.94319534], [72.79125214, 20.94347191], [72.79152679, 20.94346809], [72.79152679, 20.94375229], [72.79181671, 20.94375229], [72.79181671, 20.94403267], [72.79264069, 20.94403267], [72.79264069, 20.94431114], [72.79374695, 20.94431114], [72.79374695, 20.94514275], [72.79181671, 20.94514275], [72.79181671, 20.94486046], [72.79125214, 20.94486046], [72.79125214, 20.94458008], [72.79096985, 20.94458389], [72.79096985, 20.94430542], [72.7904129, 20.94431114], [72.7904129, 20.94403267], [72.7895813, 20.94403267], [72.7895813, 20.94375229], [72.78874969, 20.94375229], [72.78874969, 20.94347191], [72.78819275, 20.94347191], [72.78819275, 20.94319534], [72.7876358, 20.94319916], [72.7876358, 20.94292068], [72.78736115, 20.94292068], [72.78736115, 20.9426384], [72.78708649, 20.9426384], [72.78708649, 20.94235992], [72.78624725, 20.94236183], [72.78624725, 20.94208336], [72.78458405, 20.94208336], [72.78458405, 20.94180489], [72.78375244, 20.94180489], [72.78375244, 20.94152832], [72.78320313, 20.94152832], [72.78320313, 20.94124985], [72.78235626, 20.94124985], [72.78235626, 20.94152832], [72.7820816, 20.94152832], [72.7820816, 20.94124985], [72.78097534, 20.94124985], [72.78097534, 20.94097137], [72.78013611, 20.94097137], [72.78013611, 20.94069481], [72.7793045, 20.94069481], [72.7793045, 20.94041634], [72.7784729, 20.94043159], [72.7784729, 20.94013977], [72.77819824, 20.94013977], [72.77819061, 20.93985939], [72.7776413, 20.9398613], [72.7776413, 20.93958282], [72.77708435, 20.93958282], [72.77708435, 20.93930626], [72.7765274, 20.93930817], [72.7765274, 20.93902969], [72.77597046, 20.93902969], [72.77597046, 20.93875122], [72.7756958, 20.93875122], [72.7756958, 20.93847084], [72.7748642, 20.93847275], [72.7748642, 20.93819427], [72.77430725, 20.93819427], [72.77430725, 20.93791771], [72.77403259, 20.93791962], [72.77403259, 20.93764114], [72.77348328, 20.93764114], [72.77348328, 20.9373703], [72.77319336, 20.9373703], [72.77319336, 20.93708038], [72.7729187, 20.9370842], [72.7729187, 20.93680573], [72.77263641, 20.93680954], [72.77263641, 20.93653107], [72.77236176, 20.93653107], [72.77236176, 20.93625069], [72.7720871, 20.93625069], [72.7720871, 20.93542099], [72.77179718, 20.93542099], [72.77179718, 20.93486023], [72.77153015, 20.93486023], [72.77153015, 20.93429947], [72.77124786, 20.93430328], [72.77124786, 20.93375015], [72.77153015, 20.93375015], [72.77153015, 20.93346977], [72.77124786, 20.93347359], [72.77124786, 20.93208122], [72.77153015, 20.93208122], [72.77153015, 20.92569542], [72.77124786, 20.9256897], [72.77124786, 20.92541695], [72.77097321, 20.9254303], [72.77097321, 20.92441177], [72.77097321, 20.92152786], [72.77124786, 20.92152977], [72.77124786, 20.92041969], [72.77153015, 20.92041969], [72.77153015, 20.91986275], [72.77179718, 20.91986275], [72.77179718, 20.91958046], [72.7720871, 20.91958046], [72.7720871, 20.91902733], [72.77236176, 20.91903114], [72.77236176, 20.91819191], [72.77263641, 20.91819382], [72.77263641, 20.91791725], [72.77319336, 20.91792107], [72.77319336, 20.91764259], [72.77348328, 20.91764259], [72.77348328, 20.91736031], [72.77430725, 20.91736031], [72.77430725, 20.91708183], [72.77735901, 20.91708374], [72.77735901, 20.91680527], [72.7776413, 20.9168129], [72.7776413, 20.91653061], [72.77791595, 20.91653061], [72.77791595, 20.91624069], [72.77819061, 20.91624832], [72.77819061, 20.91486168], [72.77680206, 20.91485977], [72.77680206, 20.91513824], [72.77597046, 20.91513824], [72.77597046, 20.91542053], [72.77319336, 20.91542053], [72.77319336, 20.91570091], [72.77236176, 20.91569519], [72.77236176, 20.91597176], [72.77180481, 20.91597176], [72.77180481, 20.91624832], [72.77124786, 20.91624069], [72.77124786, 20.91653061], [72.77097321, 20.91653061], [72.77097321, 20.91708374], [72.77069092, 20.91708183], [72.77069092, 20.91736031], [72.77041626, 20.91736031], [72.77041626, 20.91792107], [72.7701416, 20.91791725], [72.7701416, 20.91819382], [72.76985931, 20.91819382], [72.76985931, 20.91847038], [72.76957703, 20.91847038], [72.76957703, 20.91875267], [72.76930237, 20.91875267], [72.76930237, 20.91903114], [72.76902771, 20.91902733], [72.76902771, 20.9193058], [72.76847076, 20.91930008], [72.76847076, 20.91986275], [72.76819611, 20.91986275], [72.76819611, 20.92014122], [72.76791382, 20.92013931], [72.76791382, 20.92069244], [72.76763916, 20.92069244], [72.76764679, 20.92124939], [72.76735687, 20.92124939], [72.76735687, 20.92152977], [72.76708221, 20.92152977], [72.76708221, 20.92181015], [72.76680756, 20.92180634], [72.76680756, 20.92236137], [72.7665329, 20.92235947], [72.7665329, 20.92292023], [72.76625061, 20.92291641], [72.76625061, 20.92347145], [72.76597595, 20.92346954], [72.76597595, 20.92374992], [72.76568604, 20.92374992], [72.76568604, 20.9240303], [72.76541901, 20.9240303], [72.76541901, 20.92514038], [72.76513672, 20.92513847], [72.76513672, 20.9256897], [72.76486206, 20.92570114], [72.76486206, 20.92625046], [72.7645874, 20.92625046], [72.7645874, 20.92681122], [72.76430511, 20.9268055], [72.76430511, 20.92708397], [72.76403046, 20.92708015], [72.76403046, 20.92736053], [72.76374817, 20.92736053], [72.76374817, 20.92791748], [72.76347351, 20.92791748], [72.76347351, 20.92847252], [72.76319122, 20.92847061], [72.76319122, 20.92903137], [72.76291656, 20.92903137], [72.76291656, 20.92931175], [72.76264191, 20.92930603], [72.76264191, 20.9295826], [72.76235962, 20.92958069], [72.76235962, 20.92985916], [72.76209259, 20.92985916], [72.76209259, 20.93042183], [72.76180267, 20.93041611], [72.76180267, 20.93097115], [72.76097107, 20.93097115], [72.76097107, 20.93124962], [72.76069641, 20.93124962], [72.76069641, 20.93180466], [72.76041412, 20.93180466], [72.76041412, 20.93236351], [72.76013947, 20.9323597], [72.76013947, 20.93292046], [72.75986481, 20.93291664], [72.75986481, 20.93347359], [72.75958252, 20.93346977], [72.75958252, 20.93403053], [72.75930786, 20.93402863], [72.75930786, 20.93458366], [72.7590332, 20.93457985], [72.7590332, 20.93514061], [72.75875092, 20.9351387], [72.75875092, 20.93569565], [72.75846863, 20.93569565], [72.75846863, 20.93597221], [72.75818634, 20.93597031], [72.75818634, 20.93653107], [72.75791931, 20.93652725], [72.75791931, 20.9370842], [72.75763702, 20.93708038], [72.75763702, 20.93764114], [72.75736237, 20.93763924], [72.75736237, 20.93819427], [72.75708008, 20.93819427], [72.75708008, 20.93847275], [72.75681305, 20.93847084], [72.75681305, 20.93902969], [72.75653076, 20.93902969], [72.75653076, 20.93930817], [72.75624847, 20.93930626], [72.75624847, 20.9398613], [72.75596619, 20.93985939], [72.75596619, 20.94043159], [72.75569153, 20.94041634], [72.75569153, 20.94069481], [72.75541687, 20.94069099], [72.75541687, 20.94124985], [72.75514221, 20.94124985], [72.75514221, 20.94152832], [72.75485992, 20.94152832], [72.75485992, 20.94208336], [72.7545929, 20.94207954], [72.7545929, 20.9426384], [72.75430298, 20.9426384], [72.75430298, 20.94292068], [72.75402832, 20.94291687], [72.75402832, 20.94347191], [72.75374603, 20.94346809], [72.75374603, 20.94403267], [72.75347137, 20.94402695], [72.75347137, 20.94458389], [72.75319672, 20.94458008], [72.75319672, 20.94514275], [72.7529068, 20.94514275], [72.7529068, 20.94542122], [72.75263977, 20.9454174], [72.75263977, 20.94597054], [72.75235748, 20.94597054], [72.75235748, 20.94652939], [72.75208282, 20.94652939], [72.75208282, 20.9473629], [72.75180817, 20.9473629], [72.75180817, 20.94847488], [72.75152588, 20.94847107], [72.75152588, 20.9493103], [72.75125122, 20.94930649], [72.75125122, 20.94958305], [72.75096893, 20.94958115], [72.75096893, 20.95042038], [72.75069427, 20.95041656], [72.75069427, 20.9509716], [72.75041962, 20.9509716], [72.75041962, 20.95208359], [72.75013733, 20.95207977], [72.75013733, 20.95236969], [72.74986267, 20.95236969], [72.74986267, 20.95264053], [72.74958038, 20.95264053], [72.74958038, 20.95375061], [72.74930573, 20.95375061], [72.74931335, 20.95486069], [72.74903107, 20.95486069], [72.74903107, 20.95541573], [72.74874878, 20.95541763], [72.74874878, 20.95597267], [72.74846649, 20.95597076], [72.74846649, 20.95653152], [72.74819183, 20.95652771], [72.74819183, 20.95708275], [72.74791718, 20.95708084], [72.74791718, 20.9576416], [72.74764252, 20.9576416], [72.74764252, 20.95819473], [72.74736023, 20.95817757], [72.74736023, 20.95903015], [72.74708557, 20.95902824], [72.74708557, 20.95986366], [72.74680328, 20.95985985], [72.74680328, 20.96042061], [72.746521, 20.96042061], [72.746521, 20.96125031], [72.74624634, 20.96125031], [72.74624634, 20.96208572], [72.74597168, 20.96208], [72.74597168, 20.96292114], [72.74569702, 20.96292114], [72.74569702, 20.96375084], [72.7454071, 20.96375084], [72.7454071, 20.96486092], [72.74514008, 20.96486092], [72.74514008, 20.96569443], [72.74485779, 20.96569061], [72.74485779, 20.96652985], [72.74458313, 20.96652794], [72.74458313, 20.96708298], [72.74430847, 20.96708107], [72.74430847, 20.9679184], [72.74402618, 20.9679184], [72.74402618, 20.96874809], [72.74375153, 20.96874809], [72.74375153, 20.96986008], [72.74346924, 20.96986008], [72.74346924, 20.97097015], [72.74318695, 20.97097015], [72.74318695, 20.97125244], [72.74291992, 20.97125244], [72.74291992, 20.97153282], [72.74263763, 20.97153282], [72.74263763, 20.97236061], [72.74236298, 20.97236061], [72.74236298, 20.97319221], [72.74208069, 20.97319031], [72.74208069, 20.97402954], [72.74180603, 20.97402954], [72.74180603, 20.97486115], [72.74153137, 20.97486115], [72.74153137, 20.97653961], [72.74124908, 20.97653961], [72.74124908, 20.97764015], [72.7409668, 20.97764015], [72.7409668, 20.97792053], [72.74069214, 20.97792053], [72.74069214, 20.97820091], [72.74041748, 20.97820091], [72.74041748, 20.97875023], [72.74014282, 20.97875023], [72.74014282, 20.97931099], [72.73986053, 20.97931099], [72.73986053, 20.97986031], [72.73958588, 20.97986031], [72.73958588, 20.98069382], [72.73929596, 20.9806881], [72.73929596, 20.98152924], [72.73958588, 20.98152924], [72.73958588, 20.98180962], [72.73930359, 20.9818058], [72.73930359, 20.98208427], [72.73902893, 20.98208427], [72.73902893, 20.98236084], [72.73874664, 20.98236084], [72.73874664, 20.98319435], [72.73847198, 20.98319054], [72.73847198, 20.98374939], [72.73819733, 20.98374939], [72.73819733, 20.98431015], [72.73792267, 20.98431015], [72.73792267, 20.98542023], [72.73764038, 20.98542023], [72.73764038, 20.9865303], [72.73735809, 20.9865303], [72.73735809, 20.98764038], [72.73707581, 20.98764038], [72.73707581, 20.98875046], [72.73680878, 20.98875046], [72.73680878, 20.98986053], [72.73652649, 20.98986053], [72.73652649, 20.99069595], [72.73625183, 20.99069023], [72.73625183, 20.99180984], [72.73596954, 20.99180984], [72.73596954, 20.99263954], [72.73569489, 20.99263954], [72.73569489, 20.99347305], [72.73542023, 20.99347305], [72.73542023, 20.99430466], [72.73513794, 20.9942894], [72.73513794, 20.99570084], [72.73486328, 20.99569511], [72.73486328, 20.99708366], [72.73458099, 20.99708366], [72.73458099, 20.99819374], [72.73430634, 20.99819183], [72.73430634, 20.99930954], [72.73402405, 20.99930573], [72.73401642, 20.99992943], [72.73401642, 21.00014114], [72.73458099, 21.00014114], [72.73458099, 21.00041962], [72.73430634, 21.00041962], [72.73430634, 21.00125122], [72.73401642, 21.00125122], [72.73401642, 21.00152969], [72.73374939, 21.00152779], [72.73374939, 21.0023613], [72.73401642, 21.00235939], [72.73401642, 21.0051403], [72.73374939, 21.0051384], [72.73374939, 21.00597191], [72.73347473, 21.00597191], [72.73347473, 21.00652885], [72.73319244, 21.00652122], [72.73319244, 21.00681114], [72.73291779, 21.00680542], [72.73291779, 21.00819397], [72.73264313, 21.00819016], [72.73264313, 21.0090313], [72.73236084, 21.0090313], [72.73236084, 21.01042175], [72.73208618, 21.01041603], [72.73208618, 21.01097107], [72.73179626, 21.01096916], [72.73179626, 21.0118103], [72.73153687, 21.0118103], [72.73153687, 21.01320076], [72.73124695, 21.01320076], [72.73124695, 21.01375008], [72.73097229, 21.01375008], [72.73097229, 21.01597214], [72.73069763, 21.01597023], [72.73069763, 21.01653099], [72.73041534, 21.01652718], [72.73042297, 21.01736069], [72.7298584, 21.01736069], [72.7298584, 21.01875114], [72.72957611, 21.01875114], [72.72957611, 21.01930809], [72.72930908, 21.01930809], [72.72930908, 21.01986122], [72.72902679, 21.01986122], [72.72902679, 21.02041817], [72.72875214, 21.02041626], [72.72875214, 21.0209713], [72.72847748, 21.02096939], [72.72847748, 21.02152824], [72.72820282, 21.02152824], [72.72820282, 21.02263832], [72.7279129, 21.02263832], [72.7279129, 21.02292061], [72.72763824, 21.02292061], [72.72763824, 21.02542114], [72.72735596, 21.02542114], [72.72735596, 21.02625275], [72.7270813, 21.02625275], [72.7270813, 21.02680969], [72.72680664, 21.02680969], [72.72680664, 21.02736282], [72.72651672, 21.02736282], [72.72651672, 21.02931023], [72.72624969, 21.02930641], [72.72624969, 21.02986145], [72.72597504, 21.02986145], [72.72597504, 21.03069687], [72.72569275, 21.03069115], [72.72569275, 21.03153038], [72.72541809, 21.03152847], [72.72541809, 21.03208351], [72.7251358, 21.03208351], [72.7251358, 21.03319359], [72.72486115, 21.03319359], [72.72486115, 21.03347206], [72.72458649, 21.03347015], [72.72458649, 21.03403091], [72.7243042, 21.0340271], [72.7243042, 21.0359726], [72.72402954, 21.03597069], [72.72402954, 21.03624916], [72.72374725, 21.03624916], [72.72374725, 21.04042053], [72.72402954, 21.04042053], [72.72402954, 21.04125023], [72.72429657, 21.04125023], [72.72429657, 21.04181099], [72.72458649, 21.04181099], [72.72458649, 21.04403114], [72.7243042, 21.04402733], [72.7243042, 21.04458427], [72.72402954, 21.04458046], [72.72402954, 21.04624939], [72.72374725, 21.04624939], [72.72374725, 21.04736137], [72.7234726, 21.04735947], [72.7234726, 21.04791832], [72.72319794, 21.04791832], [72.72319794, 21.0490284], [72.7234726, 21.0490284], [72.7234726, 21.04958344], [72.72374725, 21.04957962], [72.72374725, 21.05013847], [72.72402954, 21.05013847], [72.72402954, 21.05042267], [72.7243042, 21.05041695], [72.7243042, 21.05069351], [72.72458649, 21.05069351], [72.72458649, 21.05097008], [72.72486115, 21.05097008], [72.72486115, 21.05125046], [72.7251358, 21.05125046], [72.7251358, 21.05153275], [72.72541809, 21.05152702], [72.72541809, 21.05208206], [72.72569275, 21.05208015], [72.72569275, 21.05264282], [72.72598267, 21.05264282], [72.72598267, 21.05291939], [72.72624969, 21.05291748], [72.72624969, 21.05319214], [72.72652435, 21.05319214], [72.72652435, 21.05347443], [72.7270813, 21.05347443], [72.7270813, 21.05319214], [72.72763824, 21.05319214], [72.72763824, 21.05263901], [72.72820282, 21.05264282], [72.72820282, 21.05236053], [72.72875214, 21.05236053], [72.72875214, 21.05208015], [72.72902679, 21.05208206], [72.72902679, 21.05152702], [72.72930908, 21.05153275], [72.72930908, 21.05125046], [72.7298584, 21.05125046], [72.7298584, 21.0506916], [72.73014069, 21.05069351], [72.73014069, 21.05041695], [72.73097229, 21.05042267], [72.73097229, 21.05013847], [72.73124695, 21.05013847], [72.73124695, 21.04985809], [72.73152924, 21.04986191], [72.73152924, 21.04958344], [72.73180389, 21.04958344], [72.73180389, 21.04930496], [72.73208618, 21.04931068], [72.73208618, 21.0490284], [72.73236084, 21.0490284], [72.73236084, 21.04875946], [72.73319244, 21.04875946], [72.73319244, 21.04846954], [72.73347473, 21.04847145], [72.73347473, 21.04829979], [72.73347473, 21.04819489], [72.73374939, 21.04819489], [72.73374939, 21.04791641], [72.73401642, 21.04791832], [72.73401642, 21.04763985], [72.73568726, 21.04763985], [72.73568726, 21.04735947], [72.73792267, 21.04735947], [72.73792267, 21.04763985], [72.73819733, 21.04763985], [72.73819733, 21.04735947], [72.73874664, 21.04735947], [72.73874664, 21.04763985], [72.73958588, 21.04763985], [72.73958588, 21.04791832], [72.73986053, 21.04791641], [72.73986053, 21.04819489], [72.74041748, 21.04819489], [72.74041748, 21.04847145], [72.7409668, 21.04846954], [72.7409668, 21.04875946], [72.74124908, 21.04875946], [72.74124908, 21.0490284], [72.74208069, 21.0490284], [72.74208069, 21.04931068], [72.74263763, 21.04930496], [72.74263763, 21.04986191], [72.74318695, 21.04985809], [72.74318695, 21.05013847], [72.74402618, 21.05013847], [72.74402618, 21.05042267], [72.74485779, 21.05041695], [72.74485779, 21.05069351], [72.74764252, 21.05069351], [72.74764252, 21.05097008], [72.74930573, 21.05097008], [72.74930573, 21.05125046], [72.74958038, 21.05125046], [72.74958038, 21.05097008], [72.75013733, 21.05097008], [72.75013733, 21.05125046], [72.75152588, 21.05125046], [72.75152588, 21.05153275], [72.75319672, 21.05153275], [72.75319672, 21.05182076], [72.76069641, 21.0518055], [72.76069641, 21.05208206], [72.76125336, 21.05208015], [72.76125336, 21.05236053], [72.76152802, 21.05236053], [72.76152802, 21.05319214], [72.76125336, 21.05319023], [72.76125336, 21.05402946], [72.76097107, 21.05402946], [72.76097107, 21.05430984], [72.76040649, 21.05430984], [72.76040649, 21.05486107], [72.76069641, 21.05486107], [72.76069641, 21.05513954], [72.76097107, 21.05513954], [72.76097107, 21.05541992], [72.76125336, 21.0554142], [72.76125336, 21.05569458], [72.76152802, 21.05569458], [72.76152802, 21.05597305], [72.76180267, 21.05597115], [72.76180267, 21.05653], [72.76208496, 21.05652809], [72.76208496, 21.05680656], [72.76235962, 21.05680656], [72.76235962, 21.05708313], [72.76291656, 21.05708313], [72.76291656, 21.05763817], [72.76319122, 21.05763054], [72.76319122, 21.05792046], [72.76346588, 21.05792046], [72.76346588, 21.05820084], [72.76430511, 21.05819511], [72.76430511, 21.05847168], [72.76457977, 21.05847168], [72.76457977, 21.05819511], [72.76486206, 21.05820084], [72.76486206, 21.05792046], [72.76568604, 21.05792046], [72.76568604, 21.05820084], [72.76625061, 21.05819511], [72.76625061, 21.05847168], [72.76680756, 21.05846977], [72.76680756, 21.05875015], [72.76847076, 21.05875015], [72.76847076, 21.06097221], [72.76819611, 21.06097031], [72.76819611, 21.06263924], [72.76847076, 21.06263924], [72.76847076, 21.06319427], [72.76875305, 21.06319427], [72.76875305, 21.06347275], [72.76930237, 21.06347084], [72.76930237, 21.06431007], [72.76958466, 21.06430626], [72.76958466, 21.06485939], [72.76985931, 21.06485939], [72.76985931, 21.06569481], [72.7701416, 21.0656929], [72.7701416, 21.06624985], [72.77041626, 21.06624985], [72.77041626, 21.06680489], [72.7701416, 21.06680489], [72.7701416, 21.06708145], [72.76985931, 21.06708145], [72.76985931, 21.06736374], [72.76957703, 21.06735992], [72.76957703, 21.0676403], [72.76930237, 21.0676403], [72.76930237, 21.06792068], [72.76902771, 21.06792068], [72.76902771, 21.06820107], [72.76875305, 21.06819534], [72.76875305, 21.06847382], [72.76763916, 21.06847382], [72.76763916, 21.06819534], [72.76735687, 21.06820107], [72.76735687, 21.06792068], [72.76680756, 21.06792068], [72.76680756, 21.0676403], [72.76541901, 21.0676403], [72.76541901, 21.06735992], [72.76513672, 21.06736374], [72.76513672, 21.06708145], [72.76457977, 21.06708145], [72.76457977, 21.06680489], [72.76430511, 21.06680489], [72.76430511, 21.06652832], [72.76374817, 21.06653023], [72.76374817, 21.06624985], [72.76291656, 21.06624985], [72.76291656, 21.06596947], [72.76208496, 21.06597137], [72.76208496, 21.06569481], [72.76180267, 21.06569481], [72.76180267, 21.06541634], [72.76125336, 21.06542015], [72.76125336, 21.06514168], [72.76069641, 21.06514168], [72.76069641, 21.06485939], [72.76041412, 21.06485939], [72.76041412, 21.06458282], [72.76013947, 21.06458282], [72.76013947, 21.06430626], [72.75985718, 21.06431007], [72.75985718, 21.06376266], [72.75958252, 21.06376266], [72.75958252, 21.06347084], [72.75846863, 21.06347275], [72.75846863, 21.06319427], [72.75763702, 21.06319427], [72.75763702, 21.0629158], [72.75736237, 21.06292152], [72.75736237, 21.06263924], [72.75653076, 21.06263924], [72.75653076, 21.06236076], [72.75624847, 21.06236076], [72.75624847, 21.06208038], [72.75208282, 21.06208038], [72.75208282, 21.06236076], [72.75125122, 21.06236076], [72.75125122, 21.06208038], [72.75096893, 21.06208038], [72.75096893, 21.06236076], [72.75068665, 21.06236076], [72.75068665, 21.06263924], [72.74931335, 21.06263924], [72.74931335, 21.06292152], [72.74819183, 21.0629158], [72.74819183, 21.06319427], [72.74764252, 21.06319427], [72.74764252, 21.06347275], [72.74680328, 21.06347084], [72.74680328, 21.06376266], [72.746521, 21.06376266], [72.746521, 21.0640316], [72.74597168, 21.0640316], [72.74597168, 21.06431007], [72.74514008, 21.06430626], [72.74514008, 21.06458282], [72.74458313, 21.06458092], [72.74458313, 21.06514168], [72.74430847, 21.06514168], [72.74430847, 21.06542015], [72.74402618, 21.06541634], [72.74402618, 21.06569481], [72.74319458, 21.06569481], [72.74319458, 21.06597137], [72.74291992, 21.06596947], [72.74291992, 21.06624985], [72.74236298, 21.06624985], [72.74236298, 21.06653023], [72.74208069, 21.06652832], [72.74208069, 21.06680489], [72.74180603, 21.06680489], [72.74180603, 21.06652832], [72.74153137, 21.06652832], [72.74153137, 21.06708145], [72.73902893, 21.06708145], [72.73902893, 21.06736374], [72.73792267, 21.06735992], [72.73792267, 21.0676403], [72.73652649, 21.0676403], [72.73652649, 21.06820107], [72.73569489, 21.06819534], [72.73569489, 21.06847382], [72.73486328, 21.06847], [72.73486328, 21.06875038], [72.73458099, 21.06875038], [72.73458099, 21.06903076], [72.7334671, 21.06903076], [72.7334671, 21.06931114], [72.7326355, 21.06930542], [72.7326355, 21.0695858], [72.73179626, 21.06957054], [72.73180389, 21.06986046], [72.73153687, 21.06986046], [72.73153687, 21.07014084], [72.72930908, 21.07014084], [72.72930908, 21.07042122], [72.72846985, 21.0704174], [72.72846985, 21.07069588], [72.72651672, 21.07069016], [72.72651672, 21.07125092], [72.72541809, 21.07125092], [72.72541809, 21.07152939], [72.72429657, 21.07152939], [72.72429657, 21.07180977], [72.72291565, 21.07180786], [72.72291565, 21.07208252], [72.72041321, 21.07208061], [72.72041321, 21.07236099], [72.72013855, 21.07236099], [72.72013855, 21.07263947], [72.71875, 21.07263947], [72.71875, 21.07292747], [72.71708679, 21.07291794], [72.71708679, 21.0731945], [72.71125031, 21.0731945], [72.71125031, 21.07291794], [72.71097565, 21.07291794], [72.71097565, 21.0731945], [72.7104187, 21.0731945], [72.7104187, 21.07291794], [72.70874786, 21.07291794], [72.70874786, 21.0731945], [72.7076416, 21.0731945], [72.7076416, 21.07347298], [72.70597076, 21.07347107], [72.70597076, 21.07374954], [72.70569611, 21.07374954], [72.70569611, 21.07402992], [72.70513916, 21.07402992], [72.70513916, 21.0743103], [72.7048645, 21.07430649], [72.7048645, 21.07458305], [72.70458221, 21.07458305], [72.70458221, 21.07486153], [72.70430756, 21.07485962], [72.70430756, 21.07624817], [72.7040329, 21.07624817], [72.7040329, 21.07652855], [72.70375061, 21.07652855], [72.70375061, 21.08014107], [72.7040329, 21.08014107], [72.7040329, 21.08542061], [72.70375061, 21.08542061], [72.70375061, 21.08793068], [72.70347595, 21.08793068], [72.70347595, 21.08875084], [72.70318604, 21.08875084], [72.70318604, 21.09042168], [72.70291901, 21.09041595], [72.70291901, 21.0909729], [72.70263672, 21.09096909], [72.70263672, 21.09124947], [72.70236206, 21.09124947], [72.70236206, 21.09236336], [72.70207977, 21.09235954], [72.70207977, 21.09320068], [72.70181274, 21.09320068], [72.70181274, 21.09403038], [72.70153046, 21.09402847], [72.70153046, 21.0956955], [72.70124817, 21.09568977], [72.70124817, 21.09736061], [72.70096588, 21.09736061], [72.70096588, 21.09791946], [72.70069122, 21.09791946], [72.70069122, 21.09987068], [72.70041656, 21.09987068], [72.70041656, 21.10041809], [72.70014191, 21.10041618], [72.70014191, 21.10097313], [72.70041656, 21.10097122], [72.70041656, 21.10152817], [72.70069122, 21.10152817], [72.70069122, 21.10263824], [72.70097351, 21.10263824], [72.70097351, 21.10291672], [72.70124817, 21.10290909], [72.70124817, 21.10320091], [72.70153046, 21.10319519], [72.70153046, 21.10347176], [72.70181274, 21.10346985], [72.70181274, 21.10403252], [72.70207977, 21.1040287], [72.70207977, 21.10458374], [72.70236206, 21.10458183], [72.70236206, 21.10514259], [72.70291901, 21.10514259], [72.70291901, 21.10542107], [72.70319366, 21.10541725], [72.70319366, 21.10569382], [72.70347595, 21.10568047], [72.70347595, 21.10625267], [72.70458221, 21.10625267], [72.70458221, 21.10680962], [72.70485687, 21.10680962], [72.70485687, 21.10736275], [72.70541382, 21.10736275], [72.70541382, 21.10958481], [72.70569611, 21.10958099], [72.70569611, 21.11181068], [72.70597076, 21.11181068], [72.70597076, 21.11264038], [72.70625305, 21.11263847], [72.70625305, 21.11458397], [72.70652771, 21.11458015], [72.70652771, 21.11514091], [72.70625305, 21.11514091], [72.70625305, 21.11541748], [72.70652771, 21.11541748], [72.70652771, 21.11597252], [72.70625305, 21.11597252], [72.70625305, 21.1170826], [72.70597076, 21.1170826], [72.70597076, 21.11819458], [72.70569611, 21.11819077], [72.70569611, 21.12181091], [72.70597076, 21.12181091], [72.70597076, 21.12292099], [72.70625305, 21.12292099], [72.70625305, 21.12486076], [72.70652771, 21.12486076], [72.70652771, 21.1273613], [72.70680237, 21.12735939], [72.70680237, 21.12791824], [72.70707703, 21.12791824], [72.70707703, 21.12874985], [72.70735931, 21.12874985], [72.70735931, 21.12958336], [72.7076416, 21.12957954], [72.7076416, 21.13042068], [72.70791626, 21.13041687], [72.70791626, 21.13097191], [72.70819092, 21.13097191], [72.70819092, 21.13125038], [72.70847321, 21.13125038], [72.70847321, 21.13181114], [72.70874786, 21.13181114], [72.70874786, 21.13236046], [72.70903015, 21.13236046], [72.70903015, 21.13292122], [72.7095871, 21.1329174], [72.7095871, 21.13319206], [72.71013641, 21.13319206], [72.71013641, 21.13347054], [72.70986176, 21.13347054], [72.70986176, 21.13375282], [72.71013641, 21.13375282], [72.71013641, 21.13402939], [72.71069336, 21.13402939], [72.71069336, 21.13430977], [72.71097565, 21.13430405], [72.71097565, 21.1348629], [72.71125031, 21.1348629], [72.71125031, 21.13513947], [72.71151733, 21.13513947], [72.71151733, 21.13541985], [72.71180725, 21.13541412], [72.71180725, 21.1356926], [72.71235657, 21.13569069], [72.71235657, 21.13598061], [72.71263885, 21.13598061], [72.71263885, 21.13624954], [72.71290588, 21.13624954], [72.71290588, 21.13652992], [72.7131958, 21.13652802], [72.7131958, 21.13708305], [72.71347046, 21.13708305], [72.71347046, 21.13736153], [72.71375275, 21.13735962], [72.71375275, 21.13764], [72.7140274, 21.13764], [72.7140274, 21.13820076], [72.71430206, 21.13820076], [72.71430206, 21.13931084], [72.71457672, 21.13931084], [72.71458435, 21.13986015], [72.7151413, 21.13986015], [72.7151413, 21.14014053], [72.71569824, 21.14014053], [72.71569824, 21.14042091], [72.7159729, 21.1404171], [72.7159729, 21.14069366], [72.7168045, 21.14069366], [72.7168045, 21.14097214], [72.71708679, 21.14097214], [72.71708679, 21.14069366], [72.7195816, 21.14069366], [72.7195816, 21.1404171], [72.72041321, 21.1404171], [72.72041321, 21.14069366], [72.7206955, 21.14069366], [72.7206955, 21.1431942], [72.72013855, 21.1431942], [72.72013855, 21.14347267], [72.71930695, 21.14347076], [72.71930695, 21.14374924], [72.71875, 21.14374924], [72.71875, 21.14403152], [72.7159729, 21.14403152], [72.7159729, 21.1443119], [72.71485901, 21.14430618], [72.71485901, 21.14458275], [72.7140274, 21.14458084], [72.7140274, 21.14485931], [72.71347046, 21.14485931], [72.71347046, 21.14513969], [72.71235657, 21.14513969], [72.71235657, 21.14542007], [72.71013641, 21.14541626], [72.71013641, 21.14569473], [72.70986176, 21.14569473], [72.70986176, 21.1459713], [72.70874786, 21.14596939], [72.70874786, 21.14653015], [72.70791626, 21.14652824], [72.70791626, 21.14680481], [72.70652771, 21.14680481], [72.70652771, 21.14708138], [72.70597076, 21.14708138], [72.70597076, 21.14736366], [72.70540619, 21.14735985], [72.70540619, 21.14792061], [72.70430756, 21.14792061], [72.70430756, 21.14821053], [72.70375061, 21.14819527], [72.70375061, 21.14847374], [72.70347595, 21.14846992], [72.70347595, 21.14875031], [72.70318604, 21.14875031], [72.70318604, 21.14903069], [72.70263672, 21.14903069], [72.70263672, 21.14931107], [72.70180511, 21.14930344], [72.70180511, 21.14958572], [72.70124817, 21.14958], [72.70124817, 21.14986038], [72.70096588, 21.14986038], [72.70096588, 21.15014076], [72.70069122, 21.15014076], [72.70069122, 21.15042114], [72.69985962, 21.15041733], [72.69985962, 21.1506958], [72.69957733, 21.15069008], [72.69957733, 21.15098], [72.69875336, 21.15098], [72.69875336, 21.15125084], [72.69847107, 21.15125084], [72.69847107, 21.15153122], [72.69790649, 21.15153122], [72.69790649, 21.15180969], [72.69736481, 21.15180779], [72.69736481, 21.15208244], [72.69680786, 21.15208054], [72.69680786, 21.15236092], [72.69625092, 21.15236092], [72.69625092, 21.15291977], [72.69596863, 21.15291786], [72.69596863, 21.15319443], [72.69569397, 21.15319443], [72.69569397, 21.1534729], [72.69513702, 21.15347099], [72.69513702, 21.15374947], [72.69458008, 21.15374947], [72.69458008, 21.15402794], [72.69403076, 21.15402794], [72.69403076, 21.15458298], [72.69347382, 21.15458298], [72.69347382, 21.15486145], [72.69264221, 21.15485954], [72.69264221, 21.15513992], [72.6920929, 21.15513992], [72.6920929, 21.1554184], [72.6904068, 21.1554184], [72.6904068, 21.15570068], [72.68985748, 21.15569496], [72.68985748, 21.15597153], [72.68930817, 21.15596962], [72.68930817, 21.15624809], [72.68846893, 21.15624809], [72.68846893, 21.15652847], [72.68680573, 21.15652847], [72.68680573, 21.15708351], [72.68569183, 21.15708351], [72.68569183, 21.15736008], [72.68486023, 21.15735817], [72.68486023, 21.15764236], [72.68347168, 21.15764236], [72.68347168, 21.15792274], [72.68264008, 21.15791702], [72.68264008, 21.15819359], [72.68125153, 21.15819359], [72.68125153, 21.15847015], [72.67874908, 21.15847015], [72.67874908, 21.15819359], [72.67819214, 21.15819359], [72.67819214, 21.15763855], [72.67736816, 21.15764236], [72.67736816, 21.15735817], [72.67680359, 21.15736008], [72.67680359, 21.15708351], [72.67652893, 21.15708351], [72.67652893, 21.15736008], [72.67318726, 21.15735817], [72.67318726, 21.15764236], [72.67124176, 21.15764236], [72.67124176, 21.15735817], [72.67069244, 21.15736008], [72.67069244, 21.15708351], [72.67041779, 21.15708351], [72.67041779, 21.15652847], [72.67014313, 21.15652847], [72.67014313, 21.15624809], [72.66986084, 21.15624809], [72.66986084, 21.15596962], [72.66930389, 21.15597153], [72.66930389, 21.15569496], [72.66874695, 21.15570068], [72.66874695, 21.1554184], [72.66707611, 21.1554184], [72.66707611, 21.15485954], [72.66680908, 21.15486145], [72.66680908, 21.15458298], [72.66625214, 21.15458298], [72.66625214, 21.15430641], [72.66596985, 21.15430832], [72.66596985, 21.15402031], [72.66569519, 21.15402794], [72.66569519, 21.15374947], [72.6654129, 21.15374947], [72.6654129, 21.15347099], [72.66513824, 21.1534729], [72.66513824, 21.15291786], [72.66485596, 21.15291977], [72.66485596, 21.15236092], [72.6645813, 21.15236092], [72.6645813, 21.15180969], [72.66430664, 21.15180969], [72.66430664, 21.15069008], [72.66402435, 21.1506958], [72.66402435, 21.15041733], [72.66374969, 21.15042114], [72.66374969, 21.14958], [72.66319275, 21.14958572], [72.66319275, 21.14930344], [72.66291809, 21.14931107], [72.66291809, 21.14903069], [72.6626358, 21.14903069], [72.6626358, 21.14846992], [72.66236115, 21.14847374], [72.66236115, 21.14819527], [72.66208649, 21.14821053], [72.66208649, 21.14764023], [72.66179657, 21.14764023], [72.66179657, 21.1468029], [72.66152954, 21.14680481], [72.66152954, 21.14541626], [72.66124725, 21.14542007], [72.66124725, 21.1443119], [72.6609726, 21.1443119], [72.6609726, 21.14347076], [72.66069794, 21.14347267], [72.66069794, 21.14263916], [72.66042328, 21.14263916], [72.66042328, 21.13986015], [72.66014099, 21.13986206], [72.66014099, 21.13875008], [72.6598587, 21.13875008], [72.6598587, 21.13125038], [72.66014099, 21.13125038], [72.66014099, 21.12985039], [72.66041565, 21.12986183], [72.66041565, 21.12791634], [72.66069794, 21.12791824], [72.66069794, 21.12735939], [72.6609726, 21.1273613], [72.6609726, 21.12680626], [72.66124725, 21.12680817], [72.66124725, 21.12541962], [72.65930176, 21.12541962], [72.65930176, 21.12514114], [72.6590271, 21.12514114], [72.6590271, 21.12486076], [72.65875244, 21.12486076], [72.65875244, 21.12458038], [72.65847015, 21.1245842], [72.65847015, 21.12347221], [72.6581955, 21.12347221], [72.6581955, 21.12013817], [72.65791321, 21.12014008], [72.65791321, 21.11930275], [72.6581955, 21.11930466], [72.6581955, 21.11652756], [72.65847015, 21.11653137], [72.65847015, 21.11514091], [72.65875244, 21.11514091], [72.65875244, 21.11375046], [72.6590271, 21.11375046], [72.6590271, 21.1131897], [72.65930176, 21.11319351], [72.65930176, 21.11263847], [72.65957642, 21.11264038], [72.65957642, 21.11207962], [72.6598587, 21.11208344], [72.6598587, 21.11180687], [72.66014099, 21.11181068], [72.66014099, 21.1115303], [72.66042328, 21.1115303], [72.66042328, 21.11069107], [72.66014099, 21.11069679], [72.66014099, 21.11013794], [72.66042328, 21.11013985], [72.66042328, 21.10985947], [72.66069794, 21.10986137], [72.66069794, 21.10791588], [72.66042328, 21.10791969], [72.66042328, 21.10680962], [72.66014099, 21.10680962], [72.66014099, 21.10625267], [72.6598587, 21.10625267], [72.6598587, 21.10597038], [72.65958405, 21.10597038], [72.65958405, 21.1040287], [72.65930176, 21.10403252], [72.65930176, 21.10207939], [72.6590271, 21.10208321], [72.6590271, 21.10180473], [72.65875244, 21.10180473], [72.65875244, 21.10097313], [72.65847015, 21.10097313], [72.65847015, 21.10041618], [72.65791321, 21.10041809], [72.65791321, 21.10013962], [72.65763855, 21.10013962], [72.65763855, 21.09987068], [72.6570816, 21.09987068], [72.6570816, 21.09958076], [72.65680695, 21.09958267], [72.65680695, 21.09930611], [72.65651703, 21.09930992], [72.65651703, 21.09736061], [72.65680695, 21.09736061], [72.65680695, 21.09708023], [72.6570816, 21.09708595], [72.6570816, 21.09680557], [72.65735626, 21.09680939], [72.65735626, 21.09431076], [72.6570816, 21.09431076], [72.6570816, 21.09264183], [72.65763855, 21.09264183], [72.65763855, 21.09207916], [72.65791321, 21.09208107], [72.65791321, 21.09180641], [72.65820313, 21.09181023], [72.65820313, 21.09124947], [72.65791321, 21.09124947], [72.65791321, 21.09068108], [72.65763855, 21.09069443], [72.65763855, 21.09013939], [72.65791321, 21.09013939], [72.65791321, 21.08958054], [72.65847015, 21.08958244], [72.65847015, 21.08930588], [72.6590271, 21.0893116], [72.6590271, 21.08793068], [72.65875244, 21.08793068], [72.65875244, 21.08764076], [72.65847015, 21.08764076], [72.65847015, 21.08736038], [72.65791321, 21.08736038], [72.65791321, 21.08708], [72.65736389, 21.08708382], [72.65736389, 21.08680534], [72.6570816, 21.08681107], [72.6570816, 21.08653069], [72.65680695, 21.08653069], [72.65680695, 21.08570099], [72.65625763, 21.08570099], [72.65625763, 21.08542061], [72.65598297, 21.08542061], [72.65598297, 21.08514023], [72.6554184, 21.08514023], [72.6554184, 21.08542061], [72.65458679, 21.08542061], [72.65458679, 21.08457947], [72.6543045, 21.08458328], [72.6543045, 21.08180618], [72.65402985, 21.08180618], [72.65402985, 21.08124924], [72.65374756, 21.08125114], [72.65374756, 21.08069038], [72.6534729, 21.08069229], [72.6534729, 21.08041763], [72.65319824, 21.08041954], [72.65319824, 21.07958031], [72.65291595, 21.07958221], [72.65291595, 21.07902718], [72.6526413, 21.0790329], [72.6526413, 21.07819176], [72.65208435, 21.07819366], [72.65208435, 21.07786942], [72.65208435, 21.07763863], [72.65180206, 21.07764244], [72.65180206, 21.07707977], [72.6515274, 21.07708359], [72.6515274, 21.07680511], [72.65041351, 21.07680511], [72.65041351, 21.07708359], [72.64985657, 21.07707977], [72.64985657, 21.07764244], [72.64958191, 21.07764244], [72.64958191, 21.07792282], [72.64930725, 21.0779171], [72.64930725, 21.07847023], [72.64875031, 21.07847023], [72.64875031, 21.07875252], [72.6479187, 21.07873917], [72.6479187, 21.0790329], [72.64736176, 21.07902718], [72.64736176, 21.07930183], [72.6470871, 21.07930565], [72.6470871, 21.07958221], [72.64653015, 21.07958031], [72.64653015, 21.07986069], [72.64624786, 21.07986069], [72.64624786, 21.08041954], [72.6451416, 21.08041763], [72.6451416, 21.08069229], [72.64458466, 21.08069229], [72.64458466, 21.08097458], [72.64247894, 21.08097458], [72.64013672, 21.08097458], [72.64013672, 21.08069229], [72.63708496, 21.08069229], [72.63708496, 21.08041763], [72.63597107, 21.08041954], [72.63597107, 21.08014107], [72.63540649, 21.08014107], [72.63540649, 21.07986069], [72.63485718, 21.07986069], [72.63485718, 21.07958031], [72.63430786, 21.07958221], [72.63430786, 21.07930565], [72.63346863, 21.07930946], [72.63346863, 21.0790329], [72.63291931, 21.0790329], [72.63291931, 21.07873917], [72.63263702, 21.07875252], [72.63263702, 21.07847023], [72.63180542, 21.07847023], [72.63180542, 21.07819366], [72.63153076, 21.07819366], [72.63153076, 21.0779171], [72.63124847, 21.07792282], [72.63124847, 21.07764244], [72.63069153, 21.07764244], [72.63069153, 21.07736015], [72.63014221, 21.07736015], [72.63014221, 21.07708359], [72.62985992, 21.07708359], [72.62985992, 21.07680511], [72.6295929, 21.07681084], [72.6295929, 21.07652855], [72.62930298, 21.07652855], [72.62930298, 21.07624817], [72.62902832, 21.07624817], [72.62902832, 21.0759697], [72.62875366, 21.0759716], [72.62875366, 21.07569504], [72.62735748, 21.07569504], [72.62735748, 21.0759716], [72.62708282, 21.0759697], [72.62708282, 21.07652855], [72.62680817, 21.07652855], [72.62680817, 21.07708359], [72.62708282, 21.07707977], [72.62708282, 21.07736015], [72.62735748, 21.07736015], [72.62735748, 21.07764244], [72.62847137, 21.07764244], [72.62847137, 21.07792282], [72.62902832, 21.0779171], [72.62902832, 21.07819366], [72.62930298, 21.07819366], [72.62930298, 21.07847023], [72.63014221, 21.07847023], [72.63014221, 21.07875252], [72.63041687, 21.07873917], [72.63041687, 21.0790329], [72.63153076, 21.07902718], [72.63153076, 21.07958221], [72.63208008, 21.07958221], [72.63208008, 21.07986069], [72.63236237, 21.07986069], [72.63236237, 21.08014107], [72.63263702, 21.08014107], [72.63263702, 21.08152962], [72.63236237, 21.08152771], [72.63236237, 21.08208466], [72.63263702, 21.08208084], [72.63263702, 21.08236122], [72.63318634, 21.08236122], [72.63318634, 21.08208084], [72.63346863, 21.08208466], [72.63346863, 21.08180618], [72.63430786, 21.08180618], [72.63430786, 21.08208466], [72.63402557, 21.08208466], [72.6340332, 21.08263969], [72.63375092, 21.08263969], [72.63375092, 21.08292007], [72.63319397, 21.08291626], [72.63319397, 21.08319664], [72.63291931, 21.08319664], [72.63291931, 21.0834713], [72.63263702, 21.08346939], [72.63263702, 21.08374977], [72.63236237, 21.08374977], [72.63236237, 21.08430672], [72.63208008, 21.08430672], [72.63208008, 21.08458328], [72.63181305, 21.08457947], [72.63181305, 21.08514023], [72.63153076, 21.08514023], [72.63153076, 21.08542061], [72.63124847, 21.08542061], [72.63124847, 21.08570099], [72.63097382, 21.08569527], [72.63097382, 21.08597183], [72.63069153, 21.08596992], [72.63069153, 21.08625031], [72.63014221, 21.08625031], [72.63014221, 21.08708382], [72.62985992, 21.08708], [72.62985992, 21.08736038], [72.62930298, 21.08736038], [72.62930298, 21.08764076], [72.62902832, 21.08764076], [72.62902832, 21.08793068], [72.62847137, 21.08791733], [72.62847137, 21.08847237], [72.62819672, 21.08847046], [72.62819672, 21.08875084], [72.6279068, 21.08875084], [72.6279068, 21.08902931], [72.62763977, 21.0890274], [72.62763977, 21.08958244], [72.62708282, 21.08958054], [72.62708282, 21.08986092], [72.62625122, 21.08986092], [72.62625122, 21.09124947], [72.62541962, 21.09124947], [72.62541962, 21.09153175], [72.62486267, 21.09153175], [72.62486267, 21.09181023], [72.62458038, 21.09181023], [72.62458038, 21.09264183], [72.62486267, 21.09264183], [72.62486267, 21.0929203], [72.62541962, 21.0929203], [72.62541962, 21.09320068], [72.62596893, 21.09320068], [72.62596893, 21.09431076], [72.62625122, 21.09430313], [72.62625122, 21.0945816], [72.62652588, 21.0945797], [72.62652588, 21.09625053], [72.62568665, 21.09625053], [72.62568665, 21.09653091], [72.62541962, 21.09653091], [72.62541962, 21.09680939], [72.62513733, 21.09680939], [72.62513733, 21.09764099], [72.62569427, 21.09763908], [72.62569427, 21.09819412], [72.62596893, 21.09819412], [72.62596893, 21.09958267], [72.62625122, 21.09958076], [72.62625122, 21.09987068], [72.62652588, 21.09986115], [72.62652588, 21.10180473], [72.62680817, 21.10180473], [72.62680817, 21.10236168], [72.62652588, 21.10236168], [72.62652588, 21.10347176], [72.62625122, 21.10346985], [72.62625122, 21.10374832], [72.62596893, 21.10374832], [72.62596893, 21.10458374], [72.62625122, 21.10458183], [72.62625122, 21.10514259], [72.62596893, 21.10514259], [72.62596893, 21.10625267], [72.62568665, 21.10625267], [72.62568665, 21.10653114], [72.62513733, 21.10653114], [72.62513733, 21.10625267], [72.62486267, 21.10625267], [72.62486267, 21.10653114], [72.62374878, 21.10653114], [72.62374878, 21.10680962], [72.62346649, 21.10680962], [72.62346649, 21.10736275], [72.62319183, 21.10736275], [72.62319183, 21.10986137], [72.62291718, 21.10985947], [72.62291718, 21.11181068], [72.62319183, 21.11181068], [72.62319183, 21.11292076], [72.62291718, 21.11291885], [72.62291718, 21.11319351], [72.62346649, 21.1131897], [72.62346649, 21.11375046], [72.62319183, 21.11375046], [72.62319183, 21.11431122], [72.62347412, 21.1143055], [72.62347412, 21.11458397], [72.62541962, 21.11458015], [72.62541962, 21.11514091], [72.62568665, 21.11514091], [72.62568665, 21.11541748], [72.62596893, 21.11541748], [72.62596893, 21.11569405], [72.62625122, 21.11569023], [72.62625122, 21.11624908], [72.62652588, 21.11624908], [72.62652588, 21.11653137], [72.62680817, 21.11652756], [72.62680817, 21.11791611], [72.62708282, 21.11790848], [72.62708282, 21.11874962], [72.62735748, 21.11874962], [72.62735748, 21.11986351], [72.62625122, 21.11986351], [72.62625122, 21.11958122], [72.62541962, 21.11958122], [72.62541962, 21.11930466], [72.62458038, 21.11930466], [72.62458038, 21.11958122], [72.62403107, 21.11958122], [72.62403107, 21.11986351], [72.62346649, 21.1198597], [72.62346649, 21.12042046], [72.62374878, 21.12042046], [72.62374878, 21.12125015], [72.62403107, 21.12125015], [72.62403107, 21.12153053], [72.62458038, 21.12153053], [72.62458038, 21.12292099], [72.62430573, 21.12291718], [72.62430573, 21.12319565], [72.62403107, 21.12319565], [72.62403107, 21.12347221], [72.62346649, 21.12347031], [72.62346649, 21.1240406], [72.62319183, 21.12402725], [72.62319183, 21.1245842], [72.62346649, 21.12458038], [72.62346649, 21.12486076], [72.62374878, 21.12486076], [72.62374878, 21.12541962], [72.62403107, 21.12541771], [72.62403107, 21.12597275], [72.62431335, 21.12597084], [72.62431335, 21.12625122], [72.62458038, 21.12625122], [72.62458038, 21.12652969], [72.62568665, 21.12652969], [72.62568665, 21.12680817], [72.62596893, 21.12680817], [72.62596893, 21.12791824], [72.62568665, 21.12791824], [72.62568665, 21.12874985], [72.62541962, 21.12874985], [72.62541962, 21.12902832], [72.62430573, 21.12902832], [72.62430573, 21.12986183], [72.62403107, 21.12985039], [72.62403107, 21.13181114], [72.62374878, 21.13180542], [72.62374878, 21.13208389], [72.62346649, 21.13208008], [72.62346649, 21.13236046], [72.62374878, 21.13236046], [72.62374878, 21.13319206], [72.62347412, 21.13319206], [72.62347412, 21.13347054], [72.62291718, 21.13347054], [72.62291718, 21.13375282], [72.62264252, 21.13375282], [72.62264252, 21.13458443], [72.62291718, 21.13458061], [72.62291718, 21.13513947], [72.62319183, 21.13513947], [72.62319183, 21.13541985], [72.62347412, 21.13541412], [72.62347412, 21.1356926], [72.62374878, 21.13569069], [72.62374878, 21.13598061], [72.62403107, 21.13597488], [72.62403107, 21.13736153], [72.62431335, 21.13735962], [72.62431335, 21.13764], [72.62486267, 21.13764], [72.62486267, 21.13820076], [72.62513733, 21.13819695], [72.62513733, 21.13958359], [72.62486267, 21.13958359], [72.62486267, 21.13986206], [72.62403107, 21.13986015], [72.62403107, 21.14014053], [72.62236023, 21.14014053], [72.62236023, 21.14042091], [72.62208557, 21.1404171], [72.62208557, 21.14097214], [72.62180328, 21.14097023], [72.62180328, 21.14125061], [72.62152863, 21.14125061], [72.62152863, 21.14180756], [72.62124634, 21.14180756], [72.62124634, 21.14292145], [72.62097168, 21.14292145], [72.62097168, 21.14513969], [72.62069702, 21.14513969], [72.62069702, 21.14624977], [72.62041473, 21.14624977], [72.62041473, 21.14736366], [72.62014771, 21.14735985], [72.62014771, 21.14764023], [72.61985779, 21.14764023], [72.61985779, 21.14792061], [72.61958313, 21.14792061], [72.61958313, 21.14875031], [72.61985779, 21.14875031], [72.61985779, 21.14846992], [72.62014008, 21.14847374], [72.62014008, 21.14819527], [72.62069702, 21.14821053], [72.62069702, 21.14792061], [72.62152863, 21.14792061], [72.62152863, 21.14821053], [72.62180328, 21.14819527], [72.62180328, 21.14847374], [72.62152863, 21.14846992], [72.62152863, 21.14903069], [72.62124634, 21.14903069], [72.62124634, 21.14931107], [72.62097168, 21.14930344], [72.62097168, 21.14958572], [72.62069702, 21.14958], [72.62069702, 21.14986038], [72.62041473, 21.14986038], [72.62041473, 21.1506958], [72.62014008, 21.1506958], [72.62014771, 21.15236092], [72.61985779, 21.15236092], [72.61985779, 21.15402794], [72.62014771, 21.15402031], [72.62014771, 21.15430832], [72.62069702, 21.15430832], [72.62069702, 21.15402031], [72.62124634, 21.15402031], [72.62124634, 21.15513992], [72.62097168, 21.15513992], [72.62097168, 21.15708351], [72.62069702, 21.1570797], [72.62069702, 21.15764236], [72.6204071, 21.15764236], [72.6204071, 21.15792274], [72.62014771, 21.15792274], [72.62014771, 21.15903282], [72.6204071, 21.15903282], [72.6204071, 21.15930939], [72.62014008, 21.15930557], [72.62014008, 21.15986061], [72.6204071, 21.15986061], [72.6204071, 21.16041946], [72.62069702, 21.16041756], [72.62069702, 21.16208458], [72.62014008, 21.16208458], [72.62014771, 21.16236115], [72.61985779, 21.16236115], [72.61985779, 21.16292], [72.61958313, 21.16291428], [72.61958313, 21.16319466], [72.61930847, 21.16319466], [72.61930847, 21.16347313], [72.61846924, 21.16347313], [72.61846924, 21.16319466], [72.61791992, 21.16319466], [72.61791992, 21.16347313], [72.61763763, 21.16347122], [72.61763763, 21.16403008], [72.61791992, 21.16402817], [72.61791992, 21.16430664], [72.61819458, 21.16430664], [72.61819458, 21.16458321], [72.61875153, 21.16457939], [72.61875153, 21.16514015], [72.61902618, 21.16514015], [72.61902618, 21.16542053], [72.61930847, 21.16542053], [72.61930847, 21.16570091], [72.61958313, 21.16569519], [72.61958313, 21.16597176], [72.61985779, 21.16596031], [72.61985779, 21.17013931], [72.61958313, 21.17013931], [72.61958313, 21.17347145], [72.61985779, 21.17346954], [72.61985779, 21.17431068], [72.61958313, 21.17431068], [72.61958313, 21.17542076], [72.61985779, 21.17541695], [72.61985779, 21.17597389], [72.61958313, 21.17597008], [72.61958313, 21.17875099], [72.61930847, 21.17875099], [72.61930847, 21.17930984], [72.61958313, 21.17930984], [72.61958313, 21.17986107], [72.61985779, 21.17986107], [72.61985779, 21.18097305], [72.61958313, 21.1809597], [72.61958313, 21.18124962], [72.61985779, 21.18124962], [72.61985779, 21.1823616], [72.62014771, 21.1823597], [72.62014771, 21.18291855], [72.61985779, 21.18291664], [72.61985779, 21.18347168], [72.61958313, 21.18346977], [72.61958313, 21.18432045], [72.61930847, 21.18432045], [72.61930847, 21.18486023], [72.61902618, 21.18486023], [72.61902618, 21.18625259], [72.61875153, 21.18625259], [72.61875153, 21.18653107], [72.61846924, 21.18653107], [72.61846924, 21.18736076], [72.61818695, 21.18736076], [72.61818695, 21.18791962], [72.61791992, 21.18791962], [72.61791992, 21.18902969], [72.61818695, 21.18902969], [72.61818695, 21.18931007], [72.61846924, 21.18930626], [72.61846924, 21.18958473], [72.61819458, 21.18958473], [72.61819458, 21.19097137], [72.61846924, 21.19097137], [72.61846924, 21.19236183], [72.61875153, 21.19235992], [72.61875153, 21.1926403], [72.61846924, 21.1926403], [72.61846924, 21.19431114], [72.61819458, 21.19430542], [72.61819458, 21.19708252], [72.61846924, 21.19708252], [72.61846924, 21.19958115], [72.61875153, 21.19958115], [72.61875153, 21.20014191], [72.61902618, 21.20013809], [72.61902618, 21.2009716], [72.61930847, 21.2009697], [72.61930847, 21.20264053], [72.61958313, 21.20263863], [72.61958313, 21.20347214], [72.61930847, 21.20347214], [72.61930847, 21.20513916], [72.61902618, 21.20512962], [72.61902618, 21.20541954], [72.61846924, 21.20541763], [72.61846924, 21.20597267], [72.61875153, 21.20597076], [72.61875153, 21.20625114], [72.61985779, 21.20625114], [72.61985779, 21.20652962], [72.62014008, 21.20652771], [72.62014008, 21.20708275], [72.62069702, 21.20708084], [72.62069702, 21.20736122], [72.62097168, 21.20736122], [72.62097168, 21.2084713], [72.62069702, 21.20846939], [72.62069702, 21.20902824], [72.62097168, 21.20902824], [72.62097168, 21.20930481], [72.62124634, 21.20930481], [72.62124634, 21.20966148], [72.62124634, 21.2104187], [72.62152863, 21.2104187], [72.62152863, 21.2107029], [72.62180328, 21.2107029], [72.62180328, 21.2104187], [72.62236023, 21.2104187], [72.62236023, 21.21013832], [72.62346649, 21.21013832], [72.62346649, 21.2104187], [72.62374878, 21.2104187], [72.62374878, 21.2107029], [72.62403107, 21.21069527], [72.62403107, 21.21208382], [72.62374878, 21.21208191], [72.62374878, 21.21236038], [72.62236023, 21.21236038], [72.62236023, 21.21208191], [72.62152863, 21.21208191], [72.62152863, 21.21236038], [72.62097168, 21.21236038], [72.62097168, 21.21264267], [72.6204071, 21.21264267], [72.6204071, 21.21292114], [72.62014008, 21.21291733], [72.62014771, 21.21513939], [72.61985779, 21.21513939], [72.61985779, 21.21736145], [72.62014771, 21.21735954], [72.62014771, 21.21763992], [72.62041473, 21.21763802], [72.62041473, 21.21847153], [72.62014771, 21.21846962], [72.62014771, 21.21903038], [72.62069702, 21.21902847], [72.62069702, 21.21958351], [72.62041473, 21.21958351], [72.62041473, 21.21986198], [72.62014771, 21.21986008], [72.62014771, 21.22014046], [72.61985779, 21.22014046], [72.61985779, 21.22042084], [72.61958313, 21.22041893], [72.61958313, 21.22068977], [72.61875153, 21.22069359], [72.61875153, 21.22097206], [72.61846924, 21.22097015], [72.61846924, 21.22263908], [72.61875153, 21.22263908], [72.61875153, 21.22292137], [72.61968231, 21.22291756], [72.62180328, 21.22292137], [72.62180328, 21.22320175], [72.62236023, 21.22319412], [72.62236023, 21.2234726], [72.62264252, 21.22347069], [72.62264252, 21.22374916], [72.62374878, 21.22374916], [72.62374878, 21.22402954], [72.62486267, 21.22402954], [72.62486267, 21.22431183], [72.63041687, 21.22431183], [72.63041687, 21.22402954], [72.63124847, 21.22402954], [72.63124847, 21.22374916], [72.63181305, 21.22374916], [72.63181305, 21.22347069], [72.63236237, 21.2234726], [72.63236237, 21.22291756], [72.63263702, 21.22292137], [72.63263702, 21.22263908], [72.63291931, 21.22263908], [72.63291931, 21.22208023], [72.63319397, 21.22208405], [72.63319397, 21.2215271], [72.63346863, 21.22153091], [72.63346863, 21.22125053], [72.63375092, 21.22125053], [72.63375092, 21.22068977], [72.63458252, 21.22069359], [72.63458252, 21.22041893], [72.63485718, 21.22042084], [72.63485718, 21.22014046], [72.63540649, 21.22014046], [72.63540649, 21.21986008], [72.63569641, 21.21986198], [72.63569641, 21.21958351], [72.63652802, 21.21958351], [72.63652802, 21.21930695], [72.63735962, 21.21931076], [72.63735962, 21.21903038], [72.63764191, 21.21903038], [72.63764191, 21.21875], [72.63791656, 21.21875], [72.63791656, 21.21846962], [72.63819122, 21.21847153], [72.63819122, 21.21791649], [72.63874817, 21.2179203], [72.63874817, 21.21735954], [72.63930511, 21.21736145], [72.63930511, 21.21708488], [72.64125061, 21.21708488], [72.64125824, 21.21735954], [72.64680481, 21.21736145], [72.64680481, 21.21743965], [72.64679718, 21.21763992], [72.6479187, 21.21763992], [72.6479187, 21.2179203], [72.64875031, 21.2179203], [72.64875031, 21.21820068], [72.64930725, 21.21819687], [72.64930725, 21.21847153], [72.64985657, 21.21846962], [72.64985657, 21.21875], [72.65040588, 21.21875], [72.65040588, 21.21903038], [72.65097046, 21.21902847], [72.65097046, 21.21958351], [72.6515274, 21.21958351], [72.6515274, 21.21986198], [72.65180206, 21.21986008], [72.65180206, 21.22014046], [72.65235901, 21.22013855], [72.65235901, 21.22069359], [72.6526413, 21.22068977], [72.6526413, 21.22320175], [72.65235901, 21.22319412], [72.65235901, 21.2234726], [72.65207672, 21.22347069], [72.65207672, 21.22485924], [72.65235901, 21.22485924], [72.65235901, 21.22542191], [72.6526413, 21.22541618], [72.6526413, 21.22597122], [72.65291595, 21.22597122], [72.65291595, 21.22624969], [72.65319824, 21.22624969], [72.65319824, 21.22680473], [72.65235901, 21.22680473], [72.65235901, 21.22624969], [72.65208435, 21.22624969], [72.65208435, 21.22597122], [72.65180206, 21.22597122], [72.65180206, 21.22541618], [72.6515274, 21.22542191], [72.6515274, 21.22485924], [72.65125275, 21.22485924], [72.65125275, 21.22458076], [72.65097046, 21.22458267], [72.65097046, 21.22430611], [72.6506958, 21.22431183], [72.6506958, 21.22374916], [72.65040588, 21.22374916], [72.65040588, 21.22320175], [72.65013123, 21.22320175], [72.65013123, 21.22263908], [72.64985657, 21.22263908], [72.64985657, 21.22097015], [72.64958191, 21.22097206], [72.64958191, 21.22041893], [72.64901733, 21.22042084], [72.64901733, 21.22014046], [72.64875031, 21.22014046], [72.64875031, 21.21986008], [72.64819336, 21.21986198], [72.64819336, 21.21958351], [72.64653015, 21.21958351], [72.64653015, 21.21986198], [72.64597321, 21.21986008], [72.64597321, 21.22014046], [72.64541626, 21.22014046], [72.64541626, 21.22042084], [72.64458466, 21.22041893], [72.64458466, 21.22069359], [72.64375305, 21.22069359], [72.64375305, 21.22097206], [72.64347076, 21.22097015], [72.64347076, 21.22125053], [72.64290619, 21.22125053], [72.64290619, 21.22153091], [72.6423645, 21.2215271], [72.6423645, 21.22208405], [72.64208221, 21.22208023], [72.64208221, 21.22236061], [72.6415329, 21.22236061], [72.6415329, 21.22263908], [72.64125824, 21.22263908], [72.64125824, 21.22292137], [72.64097595, 21.22292137], [72.64097595, 21.22374916], [72.64041901, 21.22374916], [72.64041901, 21.22431183], [72.63957977, 21.22430611], [72.63957977, 21.22458267], [72.63903046, 21.22458076], [72.63903046, 21.22513962], [72.63846588, 21.22513962], [72.63846588, 21.22542191], [72.63791656, 21.22541618], [72.63791656, 21.22569466], [72.63708496, 21.22569466], [72.63708496, 21.22597122], [72.63680267, 21.22597122], [72.63680267, 21.22624969], [72.63569641, 21.22624016], [72.63569641, 21.22653008], [72.63458252, 21.22652817], [72.63458252, 21.22680473], [72.63402557, 21.22680473], [72.63402557, 21.2270813], [72.63319397, 21.2270813], [72.63319397, 21.22736359], [72.63236237, 21.22735977], [72.63236237, 21.22792053], [72.63181305, 21.22792053], [72.63181305, 21.22820091], [72.63124847, 21.22819328], [72.63124847, 21.22847366], [72.63069153, 21.22846985], [72.63069153, 21.22875023], [72.62930298, 21.22875023], [72.62930298, 21.22903061], [72.62735748, 21.2290287], [72.62735748, 21.22912407], [72.62735748, 21.22930336], [72.62625122, 21.22930336], [72.62625122, 21.2290287], [72.62596893, 21.2290287], [72.62596893, 21.22930336], [72.62569427, 21.22930336], [72.62569427, 21.22958565], [72.62513733, 21.22957993], [72.62513733, 21.22986031], [72.62486267, 21.22986031], [72.62486267, 21.23014069], [72.62430573, 21.23013878], [72.62430573, 21.23097229], [72.62374878, 21.23097038], [72.62374878, 21.23125076], [72.62346649, 21.23125076], [72.62346649, 21.23153114], [72.62319183, 21.23153114], [72.62319183, 21.23180962], [72.62291718, 21.23180771], [72.62291718, 21.23208427], [72.62264252, 21.23208046], [72.62264252, 21.23264122], [72.62236023, 21.23264122], [72.62236023, 21.23291969], [72.62208557, 21.23291779], [72.62208557, 21.23347282], [72.62124634, 21.23347282], [72.62124634, 21.23208427], [72.62097168, 21.23208427], [72.62097168, 21.23180771], [72.6204071, 21.23180962], [72.6204071, 21.23153114], [72.62014771, 21.23153114], [72.62014771, 21.23125076], [72.61902618, 21.23125076], [72.61902618, 21.23097038], [72.61846924, 21.23097229], [72.61846924, 21.23069572], [72.61736298, 21.23069572], [72.61736298, 21.23097229], [72.61653137, 21.23097229], [72.61653137, 21.23069572], [72.61624908, 21.23069572], [72.61624908, 21.23041725], [72.61541748, 21.23042107], [72.61541748, 21.23014069], [72.61514282, 21.23014069], [72.61514282, 21.22986031], [72.61486053, 21.22986031], [72.61486053, 21.22957993], [72.61458588, 21.22958565], [72.61458588, 21.22930336], [72.61374664, 21.22930336], [72.61374664, 21.2290287], [72.61347198, 21.22903061], [72.61347198, 21.22875023], [72.61235809, 21.22875023], [72.61235809, 21.22846985], [72.61180878, 21.22846985], [72.61180878, 21.22903061], [72.61096954, 21.2290287], [72.61096954, 21.22930336], [72.61069489, 21.22930336], [72.61069489, 21.22958565], [72.61013794, 21.22957993], [72.61013794, 21.22986031], [72.60958099, 21.22986031], [72.60958099, 21.23069572], [72.60930634, 21.23069572], [72.60930634, 21.23097229], [72.60901642, 21.23097038], [72.60901642, 21.23125076], [72.60874939, 21.23125076], [72.60874939, 21.23208237], [72.60930634, 21.23208046], [72.60930634, 21.23236084], [72.60958099, 21.23236084], [72.60958099, 21.23291969], [72.60930634, 21.23291969], [72.60930634, 21.23374939], [72.60901642, 21.23374939], [72.60901642, 21.23430824], [72.60819244, 21.23430824], [72.60819244, 21.23402977], [72.60764313, 21.23402977], [72.60764313, 21.23430824], [72.60708618, 21.23430634], [72.60708618, 21.2345829], [72.60680389, 21.2345829], [72.60680389, 21.23486137], [72.60652924, 21.23485947], [72.60652924, 21.23513985], [72.60597229, 21.23513985], [72.60597229, 21.23543167], [72.60569763, 21.23541641], [72.60569763, 21.23569489], [72.60541534, 21.23569489], [72.60541534, 21.23597145], [72.60514069, 21.23597145], [72.60514832, 21.23624992], [72.6048584, 21.23624992], [72.6048584, 21.2365284], [72.60457611, 21.2365284], [72.60457611, 21.23681068], [72.60430908, 21.23680496], [72.60430908, 21.23708344], [72.60402679, 21.23707962], [72.60402679, 21.23764038], [72.60375214, 21.23764038], [72.60375214, 21.23792267], [72.60346985, 21.23791695], [72.60346985, 21.23847008], [72.60319519, 21.23847008], [72.60320282, 21.23875046], [72.6029129, 21.23875046], [72.6029129, 21.23903275], [72.60263824, 21.23902702], [72.60263824, 21.23958206], [72.6029129, 21.23958015], [72.6029129, 21.24041939], [72.60319519, 21.24041748], [72.60319519, 21.24097443], [72.60236359, 21.24097443], [72.60236359, 21.24124908], [72.60208893, 21.24123955], [72.60208893, 21.24152946], [72.60180664, 21.24152946], [72.60180664, 21.24180984], [72.60124969, 21.24180412], [72.60124969, 21.2420845], [72.60097504, 21.2420845], [72.60098267, 21.24263954], [72.60069275, 21.24263954], [72.60069275, 21.24347305], [72.60041809, 21.24347115], [72.60041809, 21.24403], [72.6001358, 21.24403], [72.6001358, 21.24514008], [72.60041809, 21.24514008], [72.60041809, 21.24653053], [72.6001358, 21.24653053], [72.6001358, 21.24681091], [72.59986115, 21.24680519], [72.59986115, 21.24819374], [72.59958649, 21.24818993], [72.59958649, 21.24875069], [72.59929657, 21.24875069], [72.59929657, 21.24931145], [72.59902954, 21.24930573], [72.59902954, 21.2495842], [72.59764099, 21.24958038], [72.59764099, 21.24986076], [72.5973587, 21.24986076], [72.5973587, 21.25013924], [72.59708405, 21.25013924], [72.59708405, 21.25319481], [72.5973587, 21.25319481], [72.5973587, 21.25430489], [72.59708405, 21.25430489], [72.59708405, 21.25458145], [72.5973587, 21.25457954], [72.5973587, 21.25542068], [72.59707642, 21.25542068], [72.59707642, 21.25681114], [72.5973587, 21.25681114], [72.5973587, 21.25764084], [72.59764099, 21.25764084], [72.59764099, 21.25792122], [72.59791565, 21.2579174], [72.59792328, 21.26013947], [72.59764099, 21.26013947], [72.59764099, 21.26097298], [72.5973587, 21.26097107], [72.5973587, 21.2618084], [72.59707642, 21.2618084], [72.59707642, 21.26291847], [72.5973587, 21.26291847], [72.5973587, 21.26374817], [72.59764099, 21.26374817], [72.59764099, 21.26458359], [72.59791565, 21.26458359], [72.59791565, 21.26597023], [72.59819794, 21.26597023], [72.59819794, 21.26625061], [72.5984726, 21.26625061], [72.5984726, 21.26680946], [72.59791565, 21.26680565], [72.59791565, 21.26736069], [72.59819794, 21.26736069], [72.59819794, 21.26764107], [72.5984726, 21.26764107], [72.5984726, 21.26791954], [72.59874725, 21.26791954], [72.59874725, 21.26902962], [72.5984726, 21.26902771], [72.5984726, 21.26958466], [72.59819794, 21.26958084], [72.59819794, 21.26986122], [72.59791565, 21.26986122], [72.59792328, 21.27013969], [72.59764099, 21.27013969], [72.59764099, 21.27069664], [72.5973587, 21.27069092], [72.5973587, 21.27124977], [72.59680939, 21.27124977], [72.59680176, 21.27153969], [72.5965271, 21.27152824], [72.5965271, 21.27180672], [72.59680176, 21.27180672], [72.59680939, 21.27208328], [72.59791565, 21.27208328], [72.59791565, 21.27236176], [72.5984726, 21.27235985], [72.5984726, 21.27264023], [72.59929657, 21.27264023], [72.59929657, 21.27292061], [72.59958649, 21.27292061], [72.59958649, 21.27320099], [72.59986115, 21.27320099], [72.59986115, 21.27375031], [72.60041809, 21.27375031], [72.60041809, 21.27403069], [72.60069275, 21.27403069], [72.60069275, 21.27431107], [72.60180664, 21.27430534], [72.60180664, 21.27458382], [72.60235596, 21.27457809], [72.60235596, 21.27486038], [72.60263824, 21.27486038], [72.60263824, 21.27514076], [72.6029129, 21.27514076], [72.6029129, 21.27541924], [72.60319519, 21.27541733], [72.60319519, 21.27625084], [72.60457611, 21.27625084], [72.60457611, 21.2768116], [72.6048584, 21.27680588], [72.6048584, 21.27736092], [72.6029129, 21.27736092], [72.6029129, 21.27708244], [72.60236359, 21.27708244], [72.60236359, 21.27680588], [72.60152435, 21.27680588], [72.60152435, 21.27708244], [72.60041809, 21.27708244], [72.60041809, 21.27736092], [72.59986115, 21.27734947], [72.59986115, 21.27763939], [72.59929657, 21.27763939], [72.59929657, 21.27792168], [72.59874725, 21.27791595], [72.59874725, 21.27819443], [72.5973587, 21.27819443], [72.5973587, 21.27791595], [72.59513855, 21.27792168], [72.59513855, 21.27763939], [72.59401703, 21.27763939], [72.59401703, 21.27792168], [72.59348297, 21.27792168], [72.59348297, 21.27763939], [72.59041595, 21.27763939], [72.59041595, 21.27792168], [72.58985901, 21.27792168], [72.58985901, 21.27763939], [72.58930206, 21.27763939], [72.58930206, 21.27708054], [72.5890274, 21.27708244], [72.5890274, 21.27625084], [72.58875275, 21.27625084], [72.58875275, 21.27597046], [72.58847046, 21.27597237], [72.58847046, 21.27569389], [72.58735657, 21.27568817], [72.58735657, 21.27652931], [72.58763885, 21.27652931], [72.58763885, 21.2768116], [72.58790588, 21.2768116], [72.58790588, 21.27763939], [72.5881958, 21.27763939], [72.5881958, 21.27819443], [72.58847046, 21.27819061], [72.58847046, 21.27874947], [72.58875275, 21.27874947], [72.58875275, 21.28097153], [72.5890274, 21.28096962], [72.5890274, 21.28153038], [72.58930206, 21.28152847], [72.58930206, 21.28236389], [72.5909729, 21.28236389], [72.5909729, 21.28180313], [72.59124756, 21.28181076], [72.59124756, 21.28153038], [72.59179688, 21.28153038], [72.59179688, 21.28125], [72.59348297, 21.28125], [72.59347534, 21.28097153], [72.59513855, 21.28096962], [72.59513855, 21.28125], [72.59596252, 21.28125], [72.59596252, 21.28153038], [72.59625244, 21.28153038], [72.59625244, 21.28125], [72.5965271, 21.28125], [72.5965271, 21.28070068], [72.59680176, 21.28070068], [72.59680176, 21.28041267], [72.59708405, 21.28041649], [72.59708405, 21.28013802], [72.5973587, 21.28014183], [72.5973587, 21.27985954], [72.5984726, 21.27985954], [72.5984726, 21.28070068], [72.59819794, 21.28069305], [72.59819794, 21.28097153], [72.59764099, 21.28096962], [72.59764099, 21.28125], [72.5973587, 21.28125], [72.5973587, 21.28153038], [72.5965271, 21.28152847], [72.5965271, 21.28208542], [72.59597015, 21.28208542], [72.59597015, 21.28236389], [72.59570313, 21.28236008], [72.59570313, 21.28264046], [72.59541321, 21.28264046], [72.59541321, 21.28292084], [72.59486389, 21.28291702], [72.59486389, 21.2831955], [72.5945816, 21.2831955], [72.5945816, 21.28291702], [72.59319305, 21.28291702], [72.59319305, 21.2831955], [72.5929184, 21.2831955], [72.5929184, 21.28291702], [72.59124756, 21.28291702], [72.59124756, 21.2831955], [72.59069824, 21.28318977], [72.59069824, 21.28347969], [72.59041595, 21.28347969], [72.59041595, 21.28375053], [72.59014893, 21.28375053], [72.59014893, 21.28403091], [72.58930206, 21.28403091], [72.58930206, 21.28430939], [72.5890274, 21.28430557], [72.5890274, 21.28458595], [72.58875275, 21.28458595], [72.58875275, 21.28569412], [72.58847046, 21.28569031], [72.58847046, 21.28736115], [72.58875275, 21.28736115], [72.58875275, 21.28819466], [72.58847046, 21.28819084], [72.58847046, 21.28874969], [72.5881958, 21.28874969], [72.5881958, 21.28930473], [72.58847046, 21.28928947], [72.58847046, 21.29041862], [72.5881958, 21.29041862], [72.5881958, 21.29070282], [72.58790588, 21.29070282], [72.58790588, 21.29125023], [72.5881958, 21.29125023], [72.5881958, 21.29153252], [72.58847046, 21.2915287], [72.58847046, 21.29319382], [72.58875275, 21.29319191], [72.58875275, 21.29375267], [72.58930206, 21.29375267], [72.58930206, 21.29403114], [72.58957672, 21.29403114], [72.58957672, 21.29486084], [72.58930206, 21.29486084], [72.58930206, 21.29569244], [72.58957672, 21.29569054], [72.58957672, 21.29652977], [72.58985901, 21.29652786], [72.58985901, 21.29736137], [72.58957672, 21.29735947], [72.58957672, 21.29763985], [72.58930206, 21.29763985], [72.58930206, 21.29792023], [72.5890274, 21.29792023], [72.5890274, 21.29848099], [72.58930206, 21.29848099], [72.58930206, 21.29874992], [72.58957672, 21.29874992], [72.58957672, 21.2990303], [72.58985901, 21.2990303], [72.58985901, 21.30014038], [72.59014893, 21.30014038], [72.59014893, 21.30042076], [72.59041595, 21.30041885], [72.59041595, 21.30069351], [72.5909729, 21.30069351], [72.5909729, 21.30097198], [72.59124756, 21.30097198], [72.59124756, 21.30208397], [72.59152985, 21.30208397], [72.59152985, 21.30347252], [72.59179688, 21.30347061], [72.59179688, 21.30402946], [72.59208679, 21.30402946], [72.59208679, 21.30431175], [72.59236145, 21.30431175], [72.59236145, 21.30485916], [72.59263611, 21.30485916], [72.59263611, 21.30542183], [72.5929184, 21.30541611], [72.5929184, 21.30569458], [72.59347534, 21.30569458], [72.59347534, 21.30624962], [72.59375, 21.30624962], [72.59375, 21.30653191], [72.59319305, 21.30652809], [72.59319305, 21.30680466], [72.5929184, 21.30680275], [72.5929184, 21.30792046], [72.59319305, 21.30792046], [72.59319305, 21.30820084], [72.59347534, 21.30819321], [72.59347534, 21.30847168], [72.59375, 21.30846977], [72.59375, 21.30875015], [72.59319305, 21.30875015], [72.59319305, 21.30903053], [72.5929184, 21.30903053], [72.5929184, 21.31014061], [72.59319305, 21.3101387], [72.59319305, 21.3120842], [72.59347534, 21.3120842], [72.59347534, 21.31236076], [72.59375, 21.31236076], [72.59375, 21.31264114], [72.59402466, 21.31263924], [72.59402466, 21.31347275], [72.59430695, 21.3134594], [72.59430695, 21.31375122], [72.5945816, 21.31375122], [72.5945816, 21.31430817], [72.59486389, 21.31430626], [72.59486389, 21.31458282], [72.59541321, 21.31458092], [72.59541321, 21.31513977], [72.5956955, 21.31513977], [72.5956955, 21.31597137], [72.59625244, 21.31596947], [72.59625244, 21.31624985], [72.59680176, 21.31624985], [72.59680939, 21.31680489], [72.59708405, 21.31680489], [72.59708405, 21.31708336], [72.5973587, 21.31707764], [72.5973587, 21.3176403], [72.59764099, 21.3176403], [72.59764099, 21.31820107], [72.59791565, 21.31819534], [72.59791565, 21.31847191], [72.59819794, 21.31847191], [72.59819794, 21.31903267], [72.5984726, 21.31903267], [72.5984726, 21.31931114], [72.59929657, 21.31931114], [72.59929657, 21.31958961], [72.59958649, 21.31958961], [72.59958649, 21.31986046], [72.59986115, 21.31986046], [72.59986115, 21.32042122], [72.6001358, 21.3204174], [72.6001358, 21.32069206], [72.60041809, 21.32069206], [72.60041809, 21.32097435], [72.60098267, 21.32097054], [72.60098267, 21.32152939], [72.60124969, 21.32152939], [72.60124969, 21.32180977], [72.60151672, 21.32180977], [72.60151672, 21.3223629], [72.60180664, 21.3223629], [72.60180664, 21.32265091], [72.60263824, 21.32265091], [72.60263824, 21.32291985], [72.6029129, 21.32291412], [72.6029129, 21.3231926], [72.60319519, 21.3231926], [72.60319519, 21.32347488], [72.60346985, 21.32347107], [72.60346985, 21.32374954], [72.60375214, 21.32374954], [72.60375214, 21.32430077], [72.60430908, 21.32430649], [72.60430908, 21.32458305], [72.60458374, 21.32458305], [72.60458374, 21.32486153], [72.60624695, 21.32485962], [72.60624695, 21.32514], [72.60679626, 21.32514], [72.60679626, 21.32542038], [72.6076355, 21.32541656], [72.6076355, 21.32625008], [72.60874939, 21.32625008], [72.60874939, 21.32902908], [72.60901642, 21.32902908], [72.60901642, 21.32930756], [72.60874939, 21.32930565], [72.60874939, 21.3306942], [72.60902405, 21.3306942], [72.60902405, 21.33097267], [72.60930634, 21.33097076], [72.60930634, 21.33124924], [72.60958099, 21.33124924], [72.60958099, 21.33208275], [72.60986328, 21.33208084], [72.60986328, 21.33235931], [72.61042023, 21.33235931], [72.61042023, 21.33263969], [72.61068726, 21.33263969], [72.61068726, 21.33292007], [72.61096954, 21.33291626], [72.61096954, 21.33319473], [72.61125183, 21.33319283], [72.61125183, 21.33374977], [72.61152649, 21.33374977], [72.61152649, 21.33403015], [72.61180878, 21.33402824], [72.61180878, 21.33430481], [72.61207581, 21.3343029], [72.61207581, 21.33459091], [72.61235809, 21.33459091], [72.61235809, 21.33514023], [72.61264038, 21.33514023], [72.61264038, 21.33542061], [72.61292267, 21.33542061], [72.61292267, 21.33570099], [72.61319733, 21.33569336], [72.61319733, 21.33597374], [72.61347198, 21.33596992], [72.61347198, 21.33653069], [72.61374664, 21.33653069], [72.61374664, 21.33681107], [72.61402893, 21.33680344], [72.61402893, 21.33708572], [72.61458588, 21.33708], [72.61458588, 21.33736038], [72.61541748, 21.33736038], [72.61541748, 21.3376503], [72.61597443, 21.33763885], [72.61597443, 21.33847237], [72.61624908, 21.33847046], [72.61624908, 21.33875084], [72.61653137, 21.33875084], [72.61653137, 21.33903122], [72.61708069, 21.3390274], [72.61708069, 21.33958244], [72.61736298, 21.33958054], [72.61736298, 21.33986092], [72.61763763, 21.33986092], [72.61763763, 21.34013939], [72.61736298, 21.34013939], [72.61736298, 21.34041977], [72.61763763, 21.34041786], [72.61763763, 21.34069443], [72.61791992, 21.34069443], [72.61791992, 21.3409729], [72.61818695, 21.34097099], [72.61818695, 21.34124947], [72.61875153, 21.34124947], [72.61875153, 21.34180832], [72.61902618, 21.34180641], [72.61902618, 21.34208298], [72.61875153, 21.34208298], [72.61875153, 21.34236145], [72.61930847, 21.34235954], [72.61930847, 21.34263992], [72.61958313, 21.34263992], [72.61958313, 21.3429184], [72.6204071, 21.3429184], [72.6204071, 21.34374809], [72.62069702, 21.34374809], [72.62069702, 21.34431267], [72.62097168, 21.34430504], [72.62097168, 21.34458351], [72.62124634, 21.3445816], [72.62124634, 21.34514046], [72.62152863, 21.34514046], [72.62152863, 21.34542274], [72.62208557, 21.34541702], [72.62208557, 21.34569359], [72.62236023, 21.34569359], [72.62236023, 21.34597015], [72.62264252, 21.34597015], [72.62264252, 21.34625053], [72.62180328, 21.34625053], [72.62180328, 21.34682083], [72.62236023, 21.34680557], [72.62236023, 21.34708214], [72.62264252, 21.34708023], [72.62264252, 21.34791946], [72.62291718, 21.34791756], [72.62291718, 21.3484745], [72.62319183, 21.34847069], [72.62319183, 21.34875107], [72.62346649, 21.34875107], [72.62346649, 21.34930992], [72.62403107, 21.34930992], [72.62403107, 21.35013962], [72.62430573, 21.35013962], [72.62430573, 21.35069656], [72.62458038, 21.35069084], [72.62458038, 21.35292053], [72.62431335, 21.35292053], [72.62431335, 21.35320091], [72.62403107, 21.35320091], [72.62403107, 21.35375023], [72.62374878, 21.35375023], [72.62374878, 21.35403061], [72.62346649, 21.35403061], [72.62346649, 21.35486031], [72.62374878, 21.35486031], [72.62374878, 21.35514069], [72.62403107, 21.35514069], [72.62403107, 21.35541916], [72.62458038, 21.35541725], [72.62458038, 21.35597229], [72.62513733, 21.35597038], [72.62513733, 21.35625076], [72.62541962, 21.35625076], [72.62541962, 21.35652924], [72.62596893, 21.35652924], [72.62596893, 21.35681152], [72.62652588, 21.3568058], [72.62652588, 21.35708237], [72.62708282, 21.35708046], [72.62708282, 21.35736084], [72.62763977, 21.35736084], [72.62763977, 21.3579216], [72.62791443, 21.35791588], [72.62791443, 21.35819435], [72.62819672, 21.35819435], [72.62819672, 21.35847282], [72.62874603, 21.35847092], [72.62874603, 21.35876274], [72.62902832, 21.35876274], [72.62902832, 21.35903168], [72.62930298, 21.35903168], [72.62930298, 21.35931015], [72.62985992, 21.35930634], [72.62985992, 21.3595829], [72.63041687, 21.3595829], [72.63041687, 21.35986137], [72.63153076, 21.35985947], [72.63153076, 21.36013985], [72.63181305, 21.36013985], [72.63181305, 21.36042023], [72.63236237, 21.36041641], [72.63236237, 21.36069489], [72.63263702, 21.36069489], [72.63263702, 21.36097145], [72.63346863, 21.36096954], [72.63346863, 21.36124992], [72.6340332, 21.36124992], [72.6340332, 21.3615303], [72.63430786, 21.3615303], [72.63430786, 21.36182022], [72.63458252, 21.36180305], [72.63458252, 21.36208153], [72.63486481, 21.36208153], [72.63486481, 21.36236382], [72.63540649, 21.36236], [72.63540649, 21.36292076], [72.63569641, 21.36292076], [72.63569641, 21.36375046], [72.63597107, 21.36375046], [72.63597107, 21.36514091], [72.63569641, 21.36514091], [72.63569641, 21.36625099], [72.63541412, 21.36624908], [72.63541412, 21.3670826], [72.63513947, 21.3670826], [72.63513947, 21.36763954], [72.63486481, 21.36763954], [72.63486481, 21.36819458], [72.63458252, 21.36819077], [72.63458252, 21.36874962], [72.63430786, 21.36874962], [72.63430786, 21.36902809], [72.63458252, 21.36902809], [72.63458252, 21.3698616], [72.63485718, 21.3698597], [72.63485718, 21.37013817], [72.63513184, 21.37013817], [72.63513184, 21.37041855], [72.63540649, 21.37041855], [72.63540649, 21.37070084], [72.63569641, 21.37069511], [72.63569641, 21.37097168], [72.63597107, 21.37096977], [72.63597107, 21.37153244], [72.63625336, 21.37153244], [72.63625336, 21.37181282], [72.63652802, 21.37180519], [72.63652802, 21.37208366], [72.63680267, 21.37208176], [72.63680267, 21.37236023], [72.63707733, 21.37236023], [72.63707733, 21.37264252], [72.63735962, 21.37264252], [72.63735962, 21.3729229], [72.63764191, 21.37291718], [72.63764191, 21.37319374], [72.63791656, 21.37319374], [72.63791656, 21.37347031], [72.63874817, 21.37347031], [72.63874817, 21.37403107], [72.63903046, 21.37403107], [72.63903046, 21.37430954], [72.63931274, 21.37430954], [72.63931274, 21.37403107], [72.64180756, 21.37403107], [72.64180756, 21.37376022], [72.64319611, 21.37376022], [72.64319611, 21.37347031], [72.64402771, 21.37347031], [72.64402771, 21.37319374], [72.64624786, 21.37319374], [72.64624786, 21.37291718], [72.6470871, 21.3729229], [72.6470871, 21.37264252], [72.64763641, 21.37264252], [72.64763641, 21.37236023], [72.6479187, 21.37236023], [72.6479187, 21.37125015], [72.64819336, 21.37125015], [72.64819336, 21.36958122], [72.6479187, 21.36958313], [72.6479187, 21.36902809], [72.64763641, 21.36902809], [72.64763641, 21.36847115], [72.64736176, 21.36847305], [72.64736176, 21.36791611], [72.6470871, 21.36791992], [72.6470871, 21.36763], [72.64680481, 21.36763954], [72.64680481, 21.36680794], [72.64653015, 21.36680984], [72.64653015, 21.36569023], [72.64624786, 21.36569595], [72.64624786, 21.36486053], [72.64597321, 21.36486053], [72.64597321, 21.36403084], [72.64569092, 21.36403084], [72.64569092, 21.36320114], [72.64541626, 21.3631897], [72.64541626, 21.36208153], [72.6451416, 21.36208153], [72.6451416, 21.36180305], [72.64485931, 21.36182022], [72.64485931, 21.36124992], [72.64430237, 21.36124992], [72.64430237, 21.36042023], [72.64402771, 21.36042023], [72.64402771, 21.35985947], [72.64375305, 21.35986137], [72.64375305, 21.35930634], [72.64347076, 21.35931015], [72.64347076, 21.35847092], [72.64430237, 21.35847092], [72.64430237, 21.35903168], [72.64458466, 21.35902786], [72.64458466, 21.3595829], [72.64485931, 21.3595829], [72.64485931, 21.35986137], [72.6451416, 21.35985947], [72.6451416, 21.36042023], [72.64541626, 21.36041641], [72.64541626, 21.36097145], [72.64569092, 21.36096954], [72.64569092, 21.36124992], [72.64597321, 21.36124992], [72.64597321, 21.36208153], [72.64624786, 21.36208153], [72.64624786, 21.36236382], [72.64653015, 21.36236], [72.64653015, 21.36264038], [72.6470871, 21.36263847], [72.6470871, 21.36319542], [72.64736176, 21.3631897], [72.64736176, 21.36375046], [72.64763641, 21.36375046], [72.64763641, 21.36458588], [72.6479187, 21.36457062], [72.6479187, 21.36514091], [72.64819336, 21.36514091], [72.64819336, 21.36541939], [72.64848328, 21.36541939], [72.64848328, 21.36625099], [72.64875031, 21.36624908], [72.64875031, 21.3670826], [72.64901733, 21.36708069], [72.64901733, 21.36736107], [72.64930725, 21.36736107], [72.64930725, 21.36819458], [72.64958191, 21.36819458], [72.64958191, 21.3698616], [72.64930725, 21.3698597], [72.64930725, 21.37070084], [72.64958191, 21.37069511], [72.64958191, 21.37097168], [72.64930725, 21.37096977], [72.64930725, 21.37181282], [72.64901733, 21.37181282], [72.64901733, 21.37376022], [72.64875031, 21.37376022], [72.64875031, 21.37430954], [72.64847565, 21.37430573], [72.64847565, 21.37458229], [72.64819336, 21.37458038], [72.64819336, 21.37486076], [72.6479187, 21.37486076], [72.6479187, 21.37514114], [72.64763641, 21.37514114], [72.64763641, 21.37541962], [72.64736176, 21.3754158], [72.64736176, 21.37569237], [72.64541626, 21.37569237], [72.64541626, 21.3754158], [72.64485931, 21.37541962], [72.64485931, 21.37514114], [72.64457703, 21.37514114], [72.64457703, 21.37486076], [72.64347076, 21.37486076], [72.64347076, 21.37458038], [72.64235687, 21.37458038], [72.64235687, 21.37486076], [72.64208221, 21.37486076], [72.64208221, 21.37514114], [72.64125824, 21.37514114], [72.64125824, 21.37541962], [72.64069366, 21.3754158], [72.64069366, 21.37569237], [72.64013672, 21.37569237], [72.64013672, 21.37597466], [72.63957977, 21.37597466], [72.63957977, 21.37569237], [72.63735962, 21.37569237], [72.63735962, 21.3754158], [72.63652802, 21.37541962], [72.63652802, 21.37514114], [72.63625336, 21.37514114], [72.63625336, 21.37486076], [72.63597107, 21.37486076], [72.63597107, 21.37458038], [72.63569641, 21.37458229], [72.63569641, 21.37430573], [72.63540649, 21.37430954], [72.63540649, 21.37376022], [72.63513184, 21.37376022], [72.63513184, 21.3729229], [72.63485718, 21.3729229], [72.63485718, 21.37264252], [72.63458252, 21.37264252], [72.63458252, 21.37208176], [72.63430786, 21.37208366], [72.63430786, 21.37180519], [72.6340332, 21.37181282], [72.6340332, 21.37153244], [72.63375092, 21.37153244], [72.63375092, 21.37096977], [72.63346863, 21.37097168], [72.63346863, 21.37069511], [72.63318634, 21.37070084], [72.63318634, 21.37013817], [72.63291931, 21.37013817], [72.63291931, 21.36958122], [72.63263702, 21.36958313], [72.63263702, 21.36930466], [72.63236237, 21.36930466], [72.63236237, 21.36874962], [72.63208008, 21.36874962], [72.63208008, 21.36847305], [72.63153076, 21.36847305], [72.63153076, 21.36652756], [72.63124847, 21.36652946], [72.63124847, 21.36625099], [72.63096619, 21.36625099], [72.63096619, 21.36597061], [72.63124847, 21.36597252], [72.63124847, 21.36513901], [72.63069153, 21.36514091], [72.63069153, 21.36486053], [72.62985992, 21.36486053], [72.62985992, 21.36514091], [72.62930298, 21.36514091], [72.62930298, 21.36541939], [72.62847137, 21.36541748], [72.62847137, 21.36569595], [72.62791443, 21.36569595], [72.62791443, 21.36541748], [72.62763977, 21.36541939], [72.62763977, 21.36514091], [72.62319183, 21.36513901], [72.62319183, 21.36597252], [72.62346649, 21.36597061], [72.62346649, 21.36625099], [72.62374878, 21.36625099], [72.62374878, 21.36680984], [72.62403107, 21.36680794], [72.62403107, 21.3670826], [72.62430573, 21.3670826], [72.62431335, 21.36736107], [72.62374878, 21.36736107], [72.62374878, 21.36791992], [72.62403107, 21.36791611], [72.62403107, 21.36819458], [72.62430573, 21.36819458], [72.62430573, 21.36930466], [72.62403107, 21.36930466], [72.62403107, 21.36958313], [72.62347412, 21.36958313], [72.62347412, 21.3698616], [72.62319183, 21.3698597], [72.62319183, 21.37236023], [72.62291718, 21.37236023], [72.62291718, 21.37376022], [72.62264252, 21.37376022], [72.62264252, 21.37403107], [72.62291718, 21.37403107], [72.62291718, 21.37514114], [72.62319183, 21.37513924], [72.62319183, 21.37569237], [72.62346649, 21.37569046], [72.62346649, 21.37652969], [72.62374878, 21.37652779], [72.62374878, 21.37708473], [72.62347412, 21.37708473], [72.62347412, 21.3773613], [72.62403107, 21.3773613], [72.62403107, 21.37819672], [72.62430573, 21.37819672], [72.62430573, 21.37847137], [72.62458038, 21.37846947], [72.62458038, 21.37903023], [72.62486267, 21.37903023], [72.62486267, 21.3801403], [72.62513733, 21.3801384], [72.62513733, 21.38097191], [72.62541962, 21.38096809], [72.62541962, 21.38153076], [72.62568665, 21.38153076], [72.62568665, 21.38180923], [72.62596893, 21.38180542], [72.62596893, 21.38208389], [72.62625122, 21.38207817], [72.62625122, 21.38236046], [72.62652588, 21.38236046], [72.62652588, 21.38293266], [72.62680817, 21.3829174], [72.62680817, 21.38347244], [72.62708282, 21.38347054], [72.62708282, 21.38375092], [72.62735748, 21.38375092], [72.62735748, 21.38402939], [72.62763977, 21.38402939], [72.62763977, 21.38431168], [72.62847137, 21.38431168], [72.62847137, 21.38485909], [72.62874603, 21.38485909], [72.62874603, 21.38513947], [72.62902832, 21.38513947], [72.62902832, 21.38542175], [72.6295929, 21.38542175], [72.6295929, 21.38570023], [72.62985992, 21.38570023], [72.62985992, 21.38624954], [72.63014221, 21.38624954], [72.63014221, 21.38680267], [72.63041687, 21.38680649], [72.63041687, 21.38736153], [72.63069153, 21.38735962], [72.63069153, 21.38764191], [72.63181305, 21.38764191], [72.63181305, 21.38820076], [72.63208008, 21.38819313], [72.63208008, 21.3884716], [72.63236237, 21.3884697], [72.63236237, 21.38903046], [72.63291931, 21.38902855], [72.63291931, 21.38958549], [72.63346863, 21.38957977], [72.63346863, 21.38986015], [72.63375092, 21.38986015], [72.63375092, 21.39014053], [72.63430786, 21.39014053], [72.63430786, 21.39042091], [72.63458252, 21.3904171], [72.63458252, 21.39069557], [72.63513947, 21.39069557], [72.63513947, 21.39097214], [72.63540649, 21.39097023], [72.63540649, 21.39153099], [72.63569641, 21.39152527], [72.63569641, 21.39180756], [72.63597107, 21.39180756], [72.63597107, 21.39208412], [72.63625336, 21.39208031], [72.63625336, 21.39236069], [72.63652802, 21.39236069], [72.63652802, 21.39264107], [72.63680267, 21.39264107], [72.63680267, 21.39291954], [72.63708496, 21.39291763], [72.63708496, 21.3931942], [72.63735962, 21.39319038], [72.63735962, 21.39375114], [72.63764191, 21.39375114], [72.63764191, 21.39402962], [72.63791656, 21.39402962], [72.63791656, 21.39430809], [72.63819122, 21.39430618], [72.63819122, 21.39458275], [72.63847351, 21.39458275], [72.63847351, 21.39569473], [72.63874817, 21.39569092], [72.63874817, 21.39624977], [72.63903046, 21.39624977], [72.63903046, 21.39652824], [72.63930511, 21.39652824], [72.63930511, 21.39680481], [72.63957977, 21.39680481], [72.63957977, 21.39708328], [72.63986206, 21.39708328], [72.63986206, 21.39736176], [72.64041901, 21.39735985], [72.64041901, 21.39763832], [72.64068604, 21.39763832], [72.64068604, 21.39793015], [72.64125824, 21.39793015], [72.64125824, 21.3982029], [72.64152527, 21.39819527], [72.64152527, 21.39847183], [72.64208221, 21.39847183], [72.64208221, 21.39875031], [72.64235687, 21.39875031], [72.64235687, 21.39903259], [72.64290619, 21.39903259], [72.64290619, 21.39931107], [72.64319611, 21.39930534], [72.64319611, 21.39958382], [72.64375305, 21.39958191], [72.64375305, 21.39986038], [72.64402771, 21.39986038], [72.64402771, 21.40097237], [72.64430237, 21.40097046], [72.64430237, 21.40180969], [72.64458466, 21.40180588], [72.64458466, 21.40208244], [72.6451416, 21.40208244], [72.6451416, 21.40180588], [72.64624786, 21.40180588], [72.64624786, 21.40208244], [72.64653015, 21.40208054], [72.64653015, 21.40236092], [72.64679718, 21.40236092], [72.64679718, 21.40291977], [72.6470871, 21.40291405], [72.6470871, 21.40319252], [72.64736176, 21.40319061], [72.64736176, 21.40402985], [72.6470871, 21.40402794], [72.6470871, 21.40458488], [72.64736176, 21.40458488], [72.64736176, 21.40486145], [72.64763641, 21.40486145], [72.64763641, 21.40458488], [72.6479187, 21.40458488], [72.6479187, 21.40430641], [72.64875031, 21.40430641], [72.64875031, 21.40486145], [72.64901733, 21.40485954], [72.64901733, 21.4054203], [72.64930725, 21.40541649], [72.64930725, 21.40597153], [72.64958191, 21.40596962], [72.64958191, 21.40625], [72.64985657, 21.40625], [72.64985657, 21.40596962], [72.6506958, 21.40596962], [72.6506958, 21.40625], [72.65097046, 21.40625], [72.65097046, 21.40653038], [72.6506958, 21.40653038], [72.6506958, 21.40681076], [72.65097046, 21.40680695], [72.65097046, 21.40819359], [72.65125275, 21.40819359], [72.65125275, 21.40958405], [72.6515274, 21.40957832], [72.6515274, 21.40987015], [72.65180206, 21.40987015], [72.65180206, 21.41013908], [72.65207672, 21.41013908], [72.65207672, 21.41124916], [72.65235901, 21.41124916], [72.65235901, 21.41181183], [72.6526413, 21.41180611], [72.6526413, 21.41208267], [72.65291595, 21.41208076], [72.65291595, 21.41235924], [72.65319824, 21.41235924], [72.65319824, 21.41291618], [72.6534729, 21.41291618], [72.6534729, 21.41319466], [72.65374756, 21.41319466], [72.65374756, 21.41347122], [72.65458679, 21.41347122], [72.65458679, 21.41374969], [72.65486145, 21.41374969], [72.65486145, 21.41403008], [72.65513611, 21.41402817], [72.65513611, 21.4145813], [72.6554184, 21.4145813], [72.6554184, 21.41486359], [72.65569305, 21.41485977], [72.65569305, 21.41514015], [72.65598297, 21.41514015], [72.65598297, 21.41542053], [72.65625763, 21.41542053], [72.65625763, 21.41570091], [72.65652466, 21.41569328], [72.65652466, 21.41597176], [72.65680695, 21.41596985], [72.65680695, 21.41625023], [72.6570816, 21.41625023], [72.6570816, 21.41653061], [72.65735626, 21.41653061], [72.65735626, 21.41681099], [72.65763855, 21.41680336], [72.65763855, 21.41708565], [72.6581955, 21.41708565], [72.6581955, 21.41736031], [72.65847015, 21.41736031], [72.65847015, 21.41764069], [72.65875244, 21.41764069], [72.65875244, 21.41792107], [72.6590271, 21.41791725], [72.6590271, 21.41847229], [72.65957642, 21.41847038], [72.65957642, 21.41903114], [72.6598587, 21.41903114], [72.6598587, 21.41930962], [72.66014099, 21.41930962], [72.66014099, 21.41986084], [72.66042328, 21.41986084], [72.66042328, 21.42041969], [72.66069794, 21.42041779], [72.66069794, 21.42097282], [72.6609726, 21.42097092], [72.6609726, 21.42152977], [72.66124725, 21.42152977], [72.66124725, 21.4220829], [72.66152954, 21.42208099], [72.66152954, 21.42263985], [72.66124725, 21.42263985], [72.66124725, 21.42291832], [72.66152954, 21.42291641], [72.66152954, 21.42319489], [72.6618042, 21.42319489], [72.6618042, 21.42347145], [72.66208649, 21.42346954], [72.66208649, 21.4240284], [72.66236115, 21.4240284], [72.66236115, 21.42431259], [72.6626358, 21.42430496], [72.6626358, 21.42486191], [72.66291809, 21.42485046], [72.66291809, 21.42542267], [72.66319275, 21.42541695], [72.66319275, 21.42569351], [72.66347504, 21.42569351], [72.66347504, 21.42597008], [72.66374969, 21.42597008], [72.66374969, 21.42625046], [72.66401672, 21.42625046], [72.66401672, 21.42653275], [72.66430664, 21.42653275], [72.66430664, 21.42681122], [72.6645813, 21.4268055], [72.6645813, 21.42708206], [72.66485596, 21.42708015], [72.66485596, 21.42736053], [72.66596985, 21.42736053], [72.66596985, 21.42764282], [72.66625214, 21.42763901], [72.66625214, 21.42791748], [72.66680908, 21.42791748], [72.66680908, 21.42819214], [72.66764069, 21.42819214], [72.66764069, 21.42847443], [72.66847229, 21.42847061], [72.66847229, 21.4287529], [72.67041779, 21.4287529], [72.67041779, 21.42902946], [72.67124176, 21.42902946], [72.67124176, 21.42930984], [72.67236328, 21.42930412], [72.67236328, 21.4295826], [72.67318726, 21.42958069], [72.67318726, 21.42986107], [72.67402649, 21.42986107], [72.67402649, 21.43013954], [72.67457581, 21.43013954], [72.67457581, 21.43041992], [72.67514038, 21.4304142], [72.67514038, 21.43069649], [72.67541504, 21.43069649], [72.67541504, 21.43097305], [72.67624664, 21.43097115], [72.67624664, 21.43153], [72.67680359, 21.43152809], [72.67680359, 21.43180656], [72.67708588, 21.43180656], [72.67708588, 21.43208313], [72.67791748, 21.43208313], [72.67791748, 21.4323616], [72.6784668, 21.4323597], [72.6784668, 21.43264008], [72.67874908, 21.43264008], [72.67874908, 21.43292046], [72.67930603, 21.43292046], [72.67930603, 21.43320084], [72.67958069, 21.43320084], [72.67958069, 21.43375015], [72.68013763, 21.43375015], [72.68013763, 21.43431091], [72.68041992, 21.43430519], [72.68041992, 21.43458366], [72.68068695, 21.43457985], [72.68068695, 21.43541908], [72.68096924, 21.43541718], [72.68096924, 21.43597221], [72.68125153, 21.43597031], [72.68125153, 21.43652916], [72.68152618, 21.43652916], [72.68152618, 21.43736076], [72.68180847, 21.43736076], [72.68180847, 21.43792152], [72.68208313, 21.43792152], [72.68208313, 21.43931007], [72.68235779, 21.43930626], [72.68235779, 21.43958282], [72.68264008, 21.43958282], [72.68264008, 21.4398613], [72.6829071, 21.43985176], [72.6829071, 21.44013977], [72.68319702, 21.44013977], [72.68319702, 21.44042015], [72.68347168, 21.44041634], [72.68347168, 21.44097137], [72.68374634, 21.44096947], [72.68374634, 21.44124985], [72.68402863, 21.44124985], [72.68402863, 21.44153023], [72.68430328, 21.44152832], [72.68430328, 21.44208145], [72.6845932, 21.44207954], [72.6845932, 21.44292068], [72.68486023, 21.44292068], [72.68486023, 21.44403076], [72.68514252, 21.44403076], [72.68514252, 21.44431114], [72.68541718, 21.44430351], [72.68541718, 21.4445858], [72.68569183, 21.4445858], [72.68569183, 21.44486046], [72.68596649, 21.44486046], [72.68596649, 21.44514084], [72.68624115, 21.44514084], [72.68624115, 21.44542122], [72.68653107, 21.44542122], [72.68653107, 21.44598007], [72.68681335, 21.44598007], [72.68681335, 21.44680977], [72.68624115, 21.44680977], [72.68624115, 21.44736099], [72.68653107, 21.44736099], [72.68653107, 21.44763947], [72.68680573, 21.44763947], [72.68680573, 21.44847298], [72.68708038, 21.44847298], [72.68708038, 21.44958305], [72.68736267, 21.44958115], [72.68736267, 21.45125008], [72.68763733, 21.45125008], [72.68763733, 21.45236015], [72.68791962, 21.45236015], [72.68791962, 21.45319366], [72.68818665, 21.45319176], [72.68818665, 21.45375061], [72.68875122, 21.45375061], [72.68875122, 21.45486069], [72.68902588, 21.45486069], [72.68902588, 21.45541954], [72.68930817, 21.45541573], [72.68930817, 21.45597458], [72.68958282, 21.45597076], [72.68958282, 21.45625114], [72.68985748, 21.45625114], [72.68985748, 21.45681], [72.69013977, 21.45681], [72.69013977, 21.45763969], [72.6904068, 21.45763969], [72.6904068, 21.45792007], [72.69069672, 21.45791435], [72.69069672, 21.4584713], [72.69097137, 21.45846939], [72.69097137, 21.45903015], [72.69125366, 21.45902824], [72.69125366, 21.45930672], [72.69152832, 21.45930672], [72.69152832, 21.45958328], [72.69180298, 21.45958328], [72.69180298, 21.45986176], [72.6920929, 21.45985985], [72.6920929, 21.46042061], [72.69236755, 21.46042061], [72.69236755, 21.46069908], [72.69264221, 21.46069908], [72.69264221, 21.46097946], [72.69291687, 21.46097946], [72.69291687, 21.46180916], [72.69346619, 21.46180916], [72.69346619, 21.46236038], [72.69374847, 21.46236038], [72.69374847, 21.46291924], [72.69403076, 21.46291733], [72.69403076, 21.46319389], [72.69430542, 21.46319389], [72.69430542, 21.46375084], [72.69486237, 21.46375084], [72.69486237, 21.4640274], [72.69541168, 21.46401978], [72.69541168, 21.4643116], [72.69625092, 21.46430588], [72.69625092, 21.46458244], [72.69680786, 21.46458054], [72.69680786, 21.46513939], [72.69625092, 21.46513939], [72.69625092, 21.46542168], [72.69596863, 21.46541595], [72.69596863, 21.46569443], [72.69569397, 21.46569443], [72.69569397, 21.4659729], [72.69541168, 21.46596909], [72.69541931, 21.46624947], [72.69430542, 21.46624947], [72.69430542, 21.4659729], [72.69403076, 21.4659729], [72.69403076, 21.46569443], [72.69347382, 21.46569443], [72.69347382, 21.46541595], [72.69319153, 21.46542168], [72.69319153, 21.46513939], [72.69291687, 21.46513939], [72.69291687, 21.46486092], [72.69264221, 21.46486092], [72.69264221, 21.46458054], [72.69180298, 21.46458244], [72.69180298, 21.46430588], [72.69152832, 21.4643116], [72.69152832, 21.46401978], [72.69125366, 21.4640274], [72.69125366, 21.46375084], [72.69097137, 21.46375084], [72.69097137, 21.46347046], [72.69069672, 21.46347237], [72.69069672, 21.46319389], [72.69013977, 21.46319389], [72.69013977, 21.46263885], [72.68985748, 21.46264076], [72.68985748, 21.46236038], [72.68958282, 21.46236038], [72.68958282, 21.46207809], [72.68930817, 21.46208382], [72.68930817, 21.46180534], [72.68902588, 21.46180916], [72.68902588, 21.46153069], [72.68875122, 21.46153069], [72.68875122, 21.46069908], [72.68846893, 21.46069908], [72.68846893, 21.46014023], [72.68818665, 21.46014023], [72.68818665, 21.45985985], [72.68791962, 21.45986176], [72.68791962, 21.45958328], [72.68736267, 21.45958328], [72.68736267, 21.45902824], [72.68708038, 21.45903015], [72.68708038, 21.45874977], [72.68680573, 21.45874977], [72.68680573, 21.45819664], [72.68653107, 21.45819664], [72.68653107, 21.45791435], [72.68624115, 21.45792007], [72.68624115, 21.45736122], [72.68596649, 21.45736122], [72.68596649, 21.45708084], [72.68541718, 21.45708466], [72.68541718, 21.45680428], [72.68514252, 21.45681], [72.68514252, 21.45652962], [72.68486023, 21.45652962], [72.68486023, 21.45569038], [72.68458557, 21.45569229], [72.68458557, 21.45541763], [72.68430328, 21.45541954], [72.68430328, 21.45458031], [72.68402863, 21.45458221], [72.68402863, 21.45430565], [72.68374634, 21.45430946], [72.68374634, 21.45375061], [72.68347168, 21.45375061], [72.68347168, 21.45347023], [72.68319702, 21.45347023], [72.68319702, 21.4529171], [72.6829071, 21.45292282], [72.6829071, 21.45264053], [72.68264008, 21.45264053], [72.68264008, 21.45181274], [72.68235779, 21.45181274], [72.68235779, 21.45153236], [72.68208313, 21.45153236], [72.68208313, 21.45070076], [72.68235779, 21.45070076], [72.68235779, 21.4493084], [72.68208313, 21.4493084], [72.68208313, 21.44903946], [72.68180847, 21.44903946], [72.68180847, 21.44874954], [72.68125153, 21.44874954], [72.68125153, 21.44847107], [72.68041992, 21.44847298], [72.68041992, 21.4481945], [72.68013763, 21.4481945], [72.68013763, 21.44791794], [72.67986298, 21.44791985], [72.67986298, 21.44763947], [72.67930603, 21.44763947], [72.67930603, 21.44736099], [72.67903137, 21.44736099], [72.67903137, 21.44763947], [72.6784668, 21.44763947], [72.6784668, 21.44736099], [72.67819214, 21.44736099], [72.67819214, 21.44708061], [72.67763519, 21.44708252], [72.67764282, 21.44736099], [72.67652893, 21.44736099], [72.67652893, 21.44763947], [72.67624664, 21.44763947], [72.67624664, 21.44791985], [72.67263794, 21.44791985], [72.67263794, 21.44763947], [72.67180634, 21.44763947], [72.67180634, 21.44736099], [72.6709671, 21.44736099], [72.6709671, 21.44708061], [72.66930389, 21.44708252], [72.66930389, 21.44680786], [72.66902924, 21.44680977], [72.66902924, 21.44652939], [72.66874695, 21.44652939], [72.66874695, 21.44625092], [72.66847229, 21.44625092], [72.66847229, 21.44569016], [72.66764069, 21.44569588], [72.66764069, 21.4454174], [72.66707611, 21.44542122], [72.66707611, 21.44514084], [72.66625214, 21.44514084], [72.66625214, 21.44486046], [72.66596985, 21.44486046], [72.66596985, 21.44458008], [72.66569519, 21.4445858], [72.66569519, 21.44430351], [72.66513824, 21.44431114], [72.66513824, 21.44403076], [72.6645813, 21.44403076], [72.6645813, 21.44375038], [72.66430664, 21.44375038], [72.66430664, 21.44347], [72.66374969, 21.44347382], [72.66374969, 21.44319344], [72.66319275, 21.44320107], [72.66319275, 21.44292068], [72.6626358, 21.44292068], [72.6626358, 21.4426403], [72.66236115, 21.4426403], [72.66236115, 21.44235992], [72.66208649, 21.44236374], [72.66208649, 21.44208145], [72.6618042, 21.44208145], [72.6618042, 21.44180489], [72.66152954, 21.44180489], [72.66152954, 21.44152832], [72.66069794, 21.44153023], [72.66069794, 21.44124985], [72.66041565, 21.44124985], [72.66041565, 21.44097137], [72.65930176, 21.44097137], [72.65930176, 21.44069481], [72.6590271, 21.44069481], [72.6590271, 21.44041634], [72.65847015, 21.44042015], [72.65847015, 21.44013977], [72.65791321, 21.44013977], [72.65791321, 21.43985176], [72.65736389, 21.4398613], [72.65736389, 21.43958282], [72.65652466, 21.43958282], [72.65652466, 21.43930626], [72.65625763, 21.43931007], [72.65625763, 21.43902969], [72.65569305, 21.43902969], [72.65569305, 21.43874931], [72.65513611, 21.43874931], [72.65513611, 21.43847084], [72.65486145, 21.43847275], [72.65486145, 21.43819427], [72.6543045, 21.43819427], [72.6543045, 21.4379158], [72.6534729, 21.43792152], [72.6534729, 21.43763924], [72.65291595, 21.43763924], [72.65291595, 21.43736076], [72.6526413, 21.43736076], [72.6526413, 21.4371624], [72.6526413, 21.43680573], [72.65235901, 21.43681145], [72.65235901, 21.43625069], [72.65180206, 21.43625069], [72.65180206, 21.43597031], [72.6506958, 21.43597031], [72.6506958, 21.43625069], [72.64985657, 21.43625069], [72.64985657, 21.43652916], [72.6479187, 21.43652916], [72.6479187, 21.43597031], [72.64680481, 21.43597221], [72.64680481, 21.43541718], [72.64653015, 21.43541908], [72.64653015, 21.43514061], [72.64624786, 21.43514061], [72.64624786, 21.43486023], [72.64597321, 21.43486023], [72.64597321, 21.43457985], [72.64569092, 21.43458366], [72.64569092, 21.43375015], [72.6451416, 21.43375015], [72.6451416, 21.43541908], [72.64485931, 21.43541718], [72.64485931, 21.43597221], [72.64457703, 21.43597031], [72.64457703, 21.43625069], [72.64430237, 21.43625069], [72.64430237, 21.43792152], [72.64402771, 21.4379158], [72.64402771, 21.43847275], [72.64375305, 21.43847084], [72.64375305, 21.43874931], [72.64402771, 21.43874931], [72.64402771, 21.43931007], [72.64375305, 21.43930626], [72.64375305, 21.43958282], [72.64319611, 21.43958282], [72.64319611, 21.44124985], [72.64347076, 21.44124985], [72.64347076, 21.44153023], [72.64375305, 21.44152832], [72.64375305, 21.44180489], [72.64402771, 21.44180489], [72.64402771, 21.44208145], [72.64430237, 21.44207954], [72.64430237, 21.4426403], [72.64457703, 21.4426403], [72.64457703, 21.44320107], [72.64485931, 21.44319344], [72.64485931, 21.44347382], [72.6451416, 21.44347], [72.6451416, 21.44375038], [72.64569092, 21.44375038], [72.64569092, 21.44431114], [72.64597321, 21.44430351], [72.64597321, 21.4445858], [72.64624786, 21.44458008], [72.64624786, 21.44486046], [72.64736176, 21.44486046], [72.64737701, 21.44514084], [72.6479187, 21.44513893], [72.6479187, 21.44569588], [72.64819336, 21.44569016], [72.64819336, 21.44598007], [72.64848328, 21.44598007], [72.64848328, 21.44652939], [72.64875031, 21.44652748], [72.64875031, 21.44708252], [72.64901733, 21.44708061], [72.64901733, 21.44763947], [72.64958191, 21.44763947], [72.64958191, 21.4481945], [72.6498642, 21.4481945], [72.64985657, 21.44930077], [72.65013123, 21.4493084], [72.65013123, 21.45070076], [72.65041351, 21.45069504], [72.65041351, 21.4509716], [72.6506958, 21.4509697], [72.6506958, 21.45153236], [72.65097046, 21.45152855], [72.65097046, 21.45319366], [72.65125275, 21.45319176], [72.65125275, 21.45763969], [72.6515274, 21.45763969], [72.6515274, 21.45986176], [72.65180206, 21.45985985], [72.65180206, 21.46014023], [72.65207672, 21.46014023], [72.65207672, 21.46042061], [72.65235901, 21.46042061], [72.65235901, 21.46097946], [72.6526413, 21.46097946], [72.6526413, 21.46125031], [72.65235901, 21.46125031], [72.65235901, 21.46208382], [72.6526413, 21.46207809], [72.6526413, 21.46236038], [72.6534729, 21.46236038], [72.6534729, 21.46264076], [72.65402985, 21.46263885], [72.65402985, 21.46319389], [72.65429688, 21.46318817], [72.65429688, 21.46375084], [72.65458679, 21.46375084], [72.65458679, 21.4640274], [72.65486145, 21.46401978], [72.65486145, 21.4643116], [72.65513611, 21.4643116], [72.65513611, 21.46375084], [72.65569305, 21.46375084], [72.65569305, 21.4643116], [72.65597534, 21.46430588], [72.65597534, 21.46486092], [72.65625763, 21.46486092], [72.65625763, 21.46542168], [72.65597534, 21.46541595], [72.65597534, 21.46569443], [72.6543045, 21.46569443], [72.6543045, 21.46541595], [72.65374756, 21.46542168], [72.65374756, 21.46513939], [72.6534729, 21.46513939], [72.6534729, 21.46486092], [72.65235901, 21.46486092], [72.65235901, 21.46513939], [72.65207672, 21.46513939], [72.65207672, 21.46542168], [72.65235901, 21.46541595], [72.65235901, 21.46569443], [72.65291595, 21.46569443], [72.65291595, 21.4659729], [72.6534729, 21.46596909], [72.6534729, 21.46624947], [72.65402985, 21.46624947], [72.65402985, 21.46653175], [72.6543045, 21.46652794], [72.6543045, 21.46708107], [72.65458679, 21.46708107], [72.65458679, 21.46736145], [72.65486145, 21.46735954], [72.65486145, 21.4679203], [72.65513611, 21.4679203], [72.65513611, 21.46820068], [72.6554184, 21.46819305], [72.6554184, 21.46847153], [72.65597534, 21.46847153], [72.65597534, 21.46875], [72.65625763, 21.46875], [72.65625763, 21.46903038], [72.6570816, 21.46903038], [72.6570816, 21.46931076], [72.65736389, 21.46930313], [72.65736389, 21.46958542], [72.65763855, 21.4695797], [72.65763855, 21.47014999], [72.65791321, 21.47013855], [72.65791321, 21.47097206], [72.65820313, 21.47097015], [72.65820313, 21.47180939], [72.65847015, 21.47180367], [72.65847015, 21.47208595], [72.6590271, 21.47208023], [72.6590271, 21.47236061], [72.65930176, 21.47236061], [72.65930176, 21.47264099], [72.65957642, 21.47264099], [72.65957642, 21.47291946], [72.6598587, 21.47291756], [72.6598587, 21.47319412], [72.66014099, 21.47319412], [72.66014099, 21.4734726], [72.66041565, 21.4734726], [72.66041565, 21.47513962], [72.66179657, 21.47513962], [72.66179657, 21.47541809], [72.66208649, 21.47541618], [72.66208649, 21.47569466], [72.66236115, 21.47569084], [72.66236115, 21.47624969], [72.6626358, 21.47624969], [72.6626358, 21.47652817], [72.66291809, 21.47652817], [72.66291809, 21.47708321], [72.66319275, 21.47707748], [72.66319275, 21.47763824], [72.66348267, 21.47763824], [72.66348267, 21.47792244], [72.66401672, 21.47792244], [72.66401672, 21.47763824], [72.6645813, 21.47763824], [72.6645813, 21.47792244], [72.66485596, 21.47792244], [72.66485596, 21.47875023], [72.66513824, 21.47875023], [72.66513824, 21.47986031], [72.6654129, 21.47986031], [72.6654129, 21.48069382], [72.66570282, 21.48069191], [72.66570282, 21.48180962], [72.66596985, 21.48180962], [72.66596985, 21.48236084], [72.66625214, 21.48236084], [72.66625214, 21.48374939], [72.66652679, 21.48374939], [72.66652679, 21.48458481], [72.66680908, 21.48458481], [72.66680908, 21.48642159], [72.66680908, 21.48847198], [72.66707611, 21.48846817], [72.66707611, 21.48903084], [72.6673584, 21.48902893], [72.6673584, 21.4920826], [72.66707611, 21.49208069], [72.66707611, 21.49235916], [72.6673584, 21.49235916], [72.6673584, 21.49292183], [72.66764069, 21.49291611], [72.66764069, 21.49347115], [72.66791534, 21.49347115], [72.66791534, 21.49374962], [72.66819763, 21.49374962], [72.66819763, 21.49681091], [72.66847229, 21.49680328], [72.66847229, 21.49819565], [72.66874695, 21.49818993], [72.66874695, 21.49875069], [72.66902924, 21.49875069], [72.66902924, 21.50097275], [72.66874695, 21.50097275], [72.66874695, 21.50208282], [72.66902924, 21.50208282], [72.66902924, 21.5023613], [72.66929626, 21.50235939], [72.66929626, 21.50263977], [72.66986084, 21.50263977], [72.66986084, 21.50291824], [72.67041779, 21.50291634], [72.67041779, 21.50319481], [72.67069244, 21.50319481], [72.67069244, 21.50486183], [72.6709671, 21.50486183], [72.6709671, 21.50542259], [72.67124176, 21.50542259], [72.67124176, 21.50681114], [72.6709671, 21.50681114], [72.6709671, 21.50792122], [72.67069244, 21.50792122], [72.67069244, 21.50902939], [72.67041779, 21.50902939], [72.67041779, 21.50932121], [72.67069244, 21.50932121], [72.67069244, 21.51013947], [72.6709671, 21.51013947], [72.6709671, 21.51124954], [72.67124939, 21.51124954], [72.67124176, 21.51180077], [72.67152405, 21.51180649], [72.67152405, 21.51236153], [72.67180634, 21.51235962], [72.67180634, 21.51292038], [72.67346954, 21.51292038], [72.67346954, 21.51320076], [72.67541504, 21.51319695], [72.67541504, 21.5134716], [72.67736053, 21.5134716], [72.67736053, 21.51375008], [72.67764282, 21.51375008], [72.67764282, 21.51403046], [72.6784668, 21.51403046], [72.6784668, 21.51375008], [72.67930603, 21.51375008], [72.67930603, 21.51403046], [72.67986298, 21.51403046], [72.67986298, 21.51431084], [72.68041992, 21.51430511], [72.68041992, 21.51458359], [72.68068695, 21.51457977], [72.68069458, 21.51486015], [72.68096924, 21.51486206], [72.68096924, 21.51513863], [72.68125153, 21.515131], [72.68125153, 21.51542091], [72.68152618, 21.5154171], [72.68152618, 21.51569366], [72.68180847, 21.51569366], [72.68180847, 21.51597214], [72.68208313, 21.51597023], [72.68208313, 21.51763916], [72.68152618, 21.51763916], [72.68152618, 21.51736069], [72.68125153, 21.51736069], [72.68125153, 21.5170784], [72.68096924, 21.51708412], [72.68096924, 21.51652718], [72.68042755, 21.51652908], [72.68042755, 21.51625061], [72.67986298, 21.51625061], [72.67986298, 21.51597023], [72.67958069, 21.51597214], [72.67958069, 21.51569366], [72.67847443, 21.51569366], [72.67847443, 21.5154171], [72.67791748, 21.5154171], [72.67791748, 21.51569366], [72.67652893, 21.51569366], [72.67652893, 21.5154171], [72.67624664, 21.51542091], [72.67624664, 21.515131], [72.67597198, 21.51513863], [72.67597198, 21.51486206], [72.67541504, 21.51486206], [72.67541504, 21.51458359], [72.67402649, 21.51458359], [72.67402649, 21.51430511], [72.67236328, 21.51430511], [72.67236328, 21.51458359], [72.6709671, 21.51457977], [72.67097473, 21.51486015], [72.67124939, 21.51486206], [72.67124939, 21.51513863], [72.67151642, 21.515131], [72.67151642, 21.51542091], [72.67180634, 21.5154171], [72.67180634, 21.51569366], [72.67208099, 21.51568985], [72.67208099, 21.51625061], [72.67236328, 21.51625061], [72.67236328, 21.51652908], [72.67292023, 21.51652908], [72.67292023, 21.51681137], [72.67318726, 21.51681137], [72.67318726, 21.51791954], [72.67346954, 21.51791954], [72.67346954, 21.51820183], [72.67375183, 21.51820183], [72.67375183, 21.51874924], [72.67402649, 21.51874924], [72.67402649, 21.52042007], [72.67430878, 21.52041626], [72.67430878, 21.52069473], [72.67457581, 21.52069283], [72.67457581, 21.52126122], [72.67542267, 21.52126122], [72.67542267, 21.52153015], [72.67569733, 21.52152824], [72.67569733, 21.52180481], [72.67624664, 21.52180481], [72.67624664, 21.52208138], [72.67652893, 21.52208138], [72.67652893, 21.52236366], [72.67679596, 21.52235985], [72.67679596, 21.52264023], [72.67708588, 21.52264023], [72.67708588, 21.52292061], [72.67736816, 21.52292061], [72.67736816, 21.52320099], [72.67791748, 21.52319336], [72.67791748, 21.52347183], [72.67819214, 21.52346992], [72.67819214, 21.52375031], [72.6784668, 21.52375031], [72.6784668, 21.52403069], [72.67874908, 21.52402687], [72.67874908, 21.52458572], [72.67930603, 21.52458], [72.67930603, 21.52486038], [72.67986298, 21.52486038], [72.67986298, 21.52514076], [72.68042755, 21.52514076], [72.68042755, 21.52542114], [72.68096924, 21.52541733], [72.68096924, 21.5256958], [72.68125153, 21.5256958], [72.68125153, 21.52597237], [72.68152618, 21.52597046], [72.68152618, 21.52625084], [72.68208313, 21.52625084], [72.68208313, 21.52653122], [72.68264008, 21.52653122], [72.68264008, 21.52680969], [72.68458557, 21.52680779], [72.68458557, 21.52708244], [72.68486023, 21.527071], [72.68486023, 21.52736092], [72.68514252, 21.52736092], [72.68514252, 21.52763939], [72.68541718, 21.52763939], [72.68541718, 21.52791977], [72.68569183, 21.52791786], [72.68569183, 21.52819443], [72.68653107, 21.52819443], [72.68653107, 21.5284729], [72.68819427, 21.5284729], [72.68819427, 21.52819443], [72.68902588, 21.52819443], [72.68902588, 21.52791786], [72.68985748, 21.52791786], [72.68985748, 21.52819443], [72.69013977, 21.52819443], [72.69013977, 21.52791786], [72.69180298, 21.52791977], [72.69180298, 21.52763939], [72.69264221, 21.52763939], [72.69264221, 21.52736092], [72.69568634, 21.52736092], [72.69568634, 21.527071], [72.69875336, 21.527071], [72.69875336, 21.52736092], [72.69930267, 21.52736092], [72.69930267, 21.527071], [72.70041656, 21.527071], [72.70041656, 21.52736092], [72.70236206, 21.52736092], [72.70236206, 21.52763939], [72.7040329, 21.52763939], [72.7040329, 21.52791977], [72.70569611, 21.52791786], [72.70569611, 21.52819443], [72.70597076, 21.52819443], [72.70597076, 21.5284729], [72.70652771, 21.52847099], [72.70652771, 21.52874947], [72.70680237, 21.52874947], [72.70680237, 21.52902985], [72.70707703, 21.52902985], [72.70707703, 21.52930832], [72.7076416, 21.52930641], [72.7076416, 21.52958298], [72.70903015, 21.52958298], [72.70903015, 21.52986145], [72.7095871, 21.52985954], [72.7095871, 21.53013992], [72.71041107, 21.53013992], [72.71041107, 21.5304184], [72.71125031, 21.5304184], [72.71125031, 21.53070068], [72.71208191, 21.53069496], [72.71208191, 21.53097153], [72.71290588, 21.53096962], [72.71290588, 21.53124809], [72.71430206, 21.53124809], [72.71430206, 21.53153038], [72.71457672, 21.53153038], [72.71457672, 21.53181267], [72.71569824, 21.53180504], [72.71569824, 21.53208351], [72.71624756, 21.53208351], [72.71624756, 21.53236008], [72.71671295, 21.53236008], [72.71708679, 21.53236008], [72.71708679, 21.53264046], [72.71763611, 21.53264046], [72.71763611, 21.53292274], [72.71819305, 21.53292274], [72.71819305, 21.53320122], [72.71902466, 21.53319359], [72.71902466, 21.53347015], [72.71985626, 21.53347015], [72.71985626, 21.53375053], [72.72070313, 21.53375053], [72.72070313, 21.53403282], [72.7215271, 21.53403282], [72.7215271, 21.53430939], [72.72180176, 21.53430557], [72.72180939, 21.53458214], [72.72208405, 21.53458214], [72.72208405, 21.53430557], [72.7223587, 21.53430557], [72.7223587, 21.53458214], [72.72429657, 21.53458023], [72.72429657, 21.53486061], [72.72486115, 21.53486061], [72.72486115, 21.5351429], [72.72624969, 21.5351429], [72.72624969, 21.53486061], [72.72680664, 21.53486061], [72.72680664, 21.5351429], [72.72735596, 21.5351429], [72.72735596, 21.53541946], [72.7279129, 21.53541756], [72.7279129, 21.53569221], [72.72902679, 21.53569221], [72.72902679, 21.5359745], [72.7298584, 21.5359745], [72.7298584, 21.53624916], [72.73069763, 21.53623962], [72.73069763, 21.53652954], [72.73208618, 21.53652954], [72.73208618, 21.53680992], [72.73236084, 21.53680992], [72.73236084, 21.53652954], [72.73291779, 21.53652763], [72.73291779, 21.53708267], [72.73374939, 21.53708076], [72.73374939, 21.53736115], [72.73430634, 21.53736115], [72.73430634, 21.53763962], [72.73486328, 21.53763962], [72.73486328, 21.53792], [72.73569489, 21.53791428], [72.73569489, 21.53819656], [72.73680878, 21.53819656], [72.73680878, 21.53847313], [72.73707581, 21.53847122], [72.73707581, 21.53874969], [72.73735809, 21.53874969], [72.73735809, 21.53903008], [72.73764038, 21.53902817], [72.73764038, 21.53958321], [72.73791504, 21.53958321], [72.73791504, 21.53986168], [72.73819733, 21.53985977], [72.73819733, 21.54014015], [72.73874664, 21.54014015], [72.73874664, 21.54042053], [72.73902893, 21.54041862], [72.73902893, 21.54097176], [72.73929596, 21.54096985], [72.73929596, 21.54125023], [72.73958588, 21.54125023], [72.73958588, 21.54153061], [72.74014282, 21.54153061], [72.74014282, 21.54180908], [72.74069214, 21.54180908], [72.74069214, 21.54264069], [72.74097443, 21.54263878], [72.74097443, 21.54319382], [72.74153137, 21.54319382], [72.74153137, 21.54347229], [72.74180603, 21.54347229], [72.74180603, 21.54569435], [72.74263763, 21.54569435], [72.74263763, 21.5470829], [72.74236298, 21.5470829], [72.74236298, 21.54847145], [72.74208069, 21.54846954], [72.74208069, 21.54874992], [72.74236298, 21.54874992], [72.74236298, 21.55014038], [72.74208069, 21.55014038], [72.74208069, 21.55042076], [72.74180603, 21.55041695], [72.74180603, 21.5506897], [72.74153137, 21.55069351], [72.74153137, 21.55097389], [72.74124908, 21.55097389], [72.74124908, 21.55125046], [72.7409668, 21.55124092], [72.7409668, 21.55153084], [72.74069214, 21.55153084], [72.74069214, 21.55181122], [72.74041748, 21.55180359], [72.74041748, 21.55208588], [72.73986053, 21.55208015], [72.73986053, 21.55236053], [72.73958588, 21.55236053], [72.73958588, 21.55264091], [72.73874664, 21.55264091], [72.73874664, 21.55291939], [72.73819733, 21.55291748], [72.73819733, 21.55319595], [72.73735809, 21.55319595], [72.73735809, 21.55291748], [72.73680878, 21.55291748], [72.73680878, 21.55319595], [72.73596954, 21.55319595], [72.73596954, 21.55347252], [72.73568726, 21.55347061], [72.73568726, 21.55402946], [72.73542023, 21.55402946], [72.73542023, 21.55486107], [72.73568726, 21.55486107], [72.73568726, 21.55513954], [72.73625183, 21.55513954], [72.73625183, 21.55541992], [72.73652649, 21.55541611], [72.73652649, 21.55597305], [72.73680878, 21.55597305], [72.73680878, 21.55680466], [72.73625183, 21.55680466], [72.73625183, 21.55652809], [72.73568726, 21.55652809], [72.73568726, 21.55624962], [72.73486328, 21.55624962], [72.73486328, 21.55597115], [72.73458099, 21.55597305], [72.73458099, 21.55569458], [72.73374939, 21.55569458], [72.73374939, 21.55541611], [72.7334671, 21.55541992], [72.7334671, 21.55486107], [72.73319244, 21.55486107], [72.73319244, 21.55402946], [72.73291779, 21.55402946], [72.73291779, 21.55264091], [72.73319244, 21.55264091], [72.73319244, 21.55208015], [72.73374939, 21.55208588], [72.73374939, 21.55180359], [72.73401642, 21.55181122], [72.73401642, 21.55153084], [72.73430634, 21.55153084], [72.73430634, 21.55124092], [72.73458099, 21.55125046], [72.73458099, 21.55097389], [72.73483276, 21.55097389], [72.73596954, 21.55097389], [72.73596954, 21.55069351], [72.73652649, 21.55069351], [72.73652649, 21.55097389], [72.73680878, 21.55097389], [72.73680878, 21.55069351], [72.73764038, 21.55069351], [72.73764038, 21.55041695], [72.73874664, 21.55042076], [72.73874664, 21.55014038], [72.73986053, 21.55014038], [72.73986053, 21.54986], [72.74013519, 21.54986382], [72.74013519, 21.54652786], [72.73986053, 21.54652977], [72.73986053, 21.54624939], [72.73958588, 21.54624939], [72.73958588, 21.54568863], [72.73986053, 21.54569435], [72.73986053, 21.54486084], [72.73958588, 21.54486084], [72.73958588, 21.54375076], [72.73929596, 21.54375076], [72.73929596, 21.54347038], [72.73902893, 21.54347229], [72.73902893, 21.54263878], [72.73874664, 21.54264069], [72.73874664, 21.54236031], [72.73847198, 21.54236031], [72.73847198, 21.54207993], [72.73819733, 21.54208374], [72.73819733, 21.54180527], [72.73792267, 21.54180908], [72.73792267, 21.54125023], [72.73764038, 21.54125023], [72.73764038, 21.54096985], [72.73735809, 21.54097176], [72.73735809, 21.54069519], [72.73707581, 21.54070091], [72.73707581, 21.54042053], [72.73568726, 21.54042053], [72.73568726, 21.54014015], [72.73513794, 21.54014015], [72.73513794, 21.53985977], [72.73430634, 21.53986168], [72.73430634, 21.53958321], [72.7326355, 21.53958321], [72.7326355, 21.53902817], [72.73208618, 21.53903008], [72.73208618, 21.53874969], [72.73041534, 21.53874969], [72.73041534, 21.53847313], [72.72875214, 21.53847313], [72.72875214, 21.53819656], [72.72680664, 21.53819656], [72.72680664, 21.53791428], [72.72598267, 21.53792], [72.72598267, 21.53763962], [72.72486115, 21.53763962], [72.72486115, 21.53736115], [72.72458649, 21.53736115], [72.72458649, 21.53763962], [72.72319794, 21.53763962], [72.72319794, 21.53736115], [72.72157288, 21.53736115], [72.72125244, 21.53736115], [72.72125244, 21.53708076], [72.71930695, 21.53708267], [72.71930695, 21.5368042], [72.71875, 21.53680992], [72.71875, 21.53652954], [72.71819305, 21.53652954], [72.71819305, 21.53623962], [72.7168045, 21.53624916], [72.7168045, 21.5359745], [72.7159729, 21.5359745], [72.7159729, 21.53569221], [72.71458435, 21.53569221], [72.71458435, 21.53541756], [72.71290588, 21.53541946], [72.71290588, 21.5351429], [72.71208191, 21.5351429], [72.71208191, 21.53486061], [72.71125031, 21.53486061], [72.71125031, 21.53458023], [72.71097565, 21.53458214], [72.71097565, 21.5340271], [72.71013641, 21.53403282], [72.71013641, 21.53375053], [72.7095871, 21.53375053], [72.7095871, 21.53347015], [72.70930481, 21.53347015], [72.70930481, 21.53319359], [72.70874786, 21.53319359], [72.70874786, 21.53347015], [72.70847321, 21.53347015], [72.70847321, 21.53319359], [72.70791626, 21.53320122], [72.70791626, 21.53292274], [72.70707703, 21.53292274], [72.70707703, 21.53264046], [72.70652771, 21.53264046], [72.70652771, 21.53236008], [72.70597076, 21.53236008], [72.70597076, 21.53208351], [72.7048645, 21.53208351], [72.7048645, 21.53236008], [72.70402527, 21.53236008], [72.70402527, 21.53208351], [72.70347595, 21.53208351], [72.70347595, 21.53236008], [72.70236206, 21.53236008], [72.70236206, 21.53264046], [72.70181274, 21.53264046], [72.70181274, 21.53292274], [72.70096588, 21.53292274], [72.70096588, 21.53320122], [72.69875336, 21.53319359], [72.69875336, 21.53347015], [72.69847107, 21.53347015], [72.69847107, 21.53375053], [72.69790649, 21.53375053], [72.69790649, 21.53403282], [72.69708252, 21.53403282], [72.69708252, 21.53430939], [72.69596863, 21.53430557], [72.69596863, 21.53458214], [72.69486237, 21.53458214], [72.69486237, 21.53430557], [72.69430542, 21.53430557], [72.69430542, 21.53458214], [72.69319153, 21.53458023], [72.69319153, 21.53486061], [72.69264221, 21.53486061], [72.69264221, 21.53458023], [72.69235992, 21.53458214], [72.69236755, 21.53486061], [72.69124603, 21.53486061], [72.69124603, 21.53541946], [72.69069672, 21.53541756], [72.69069672, 21.53569221], [72.69013977, 21.53569221], [72.69013977, 21.5359745], [72.68958282, 21.5359745], [72.68958282, 21.53624916], [72.68902588, 21.53623962], [72.68902588, 21.53652954], [72.68846893, 21.53652763], [72.68846893, 21.53708267], [72.68818665, 21.53708076], [72.68818665, 21.53736115], [72.68763733, 21.53736115], [72.68763733, 21.53763962], [72.68736267, 21.53763962], [72.68736267, 21.53819656], [72.68708038, 21.53819656], [72.68708038, 21.53847313], [72.68680573, 21.53847313], [72.68681335, 21.53874969], [72.68653107, 21.53874969], [72.68653107, 21.53930664], [72.68624878, 21.53930664], [72.68624878, 21.53958321], [72.68569183, 21.53957939], [72.68569183, 21.54014015], [72.68541718, 21.54014015], [72.68541718, 21.54070091], [72.68514252, 21.54069519], [72.68514252, 21.54097176], [72.68458557, 21.54097176], [72.6845932, 21.54125023], [72.68430328, 21.54125023], [72.68430328, 21.54153061], [72.68402863, 21.54153061], [72.68402863, 21.54291916], [72.68319702, 21.54291916], [72.68319702, 21.54264069], [72.6829071, 21.54264069], [72.6829071, 21.54236031], [72.68264008, 21.54236031], [72.68264008, 21.54207993], [72.68235779, 21.54208374], [72.68235779, 21.54125023], [72.68208313, 21.54125023], [72.68208313, 21.54070091], [72.68180847, 21.54070091], [72.68180847, 21.54042053], [72.68152618, 21.54042053], [72.68152618, 21.54014015], [72.68096924, 21.54014015], [72.68096924, 21.53985977], [72.67847443, 21.53986168], [72.67847443, 21.53958321], [72.67791748, 21.53958321], [72.67791748, 21.53930664], [72.67736053, 21.53930664], [72.67736053, 21.53874969], [72.67624664, 21.53874969], [72.67624664, 21.53847122], [72.67597198, 21.53847313], [72.67597198, 21.53819656], [72.67569733, 21.53819656], [72.67569733, 21.53791428], [72.67542267, 21.53792], [72.67542267, 21.53763962], [72.67375183, 21.53763962], [72.67375183, 21.53736115], [72.67292023, 21.53736115], [72.67292023, 21.53708076], [72.67180634, 21.53708267], [72.67180634, 21.5368042], [72.67124176, 21.53680992], [72.67124176, 21.53652954], [72.67069244, 21.53652954], [72.67069244, 21.53597069], [72.67041779, 21.5359745], [72.67041779, 21.53569221], [72.66930389, 21.53569221], [72.66930389, 21.53513908], [72.66902924, 21.5351429], [72.66902924, 21.53486061], [72.66819763, 21.53486061], [72.66819763, 21.53458023], [72.66791534, 21.53458214], [72.66791534, 21.53430557], [72.6673584, 21.53430939], [72.6673584, 21.53375053], [72.66680908, 21.53375053], [72.66680908, 21.53347015], [72.66652679, 21.53347015], [72.66652679, 21.53319359], [72.66570282, 21.53320122], [72.66570282, 21.53264046], [72.6654129, 21.53264046], [72.6654129, 21.53236008], [72.66513824, 21.53236008], [72.66513824, 21.53208351], [72.66486359, 21.53208351], [72.66486359, 21.53180504], [72.6645813, 21.53181267], [72.6645813, 21.53153038], [72.66430664, 21.53153038], [72.66430664, 21.53070068], [72.66401672, 21.53070068], [72.66401672, 21.5304184], [72.66374969, 21.5304184], [72.66374969, 21.52985954], [72.66347504, 21.52986145], [72.66347504, 21.52958298], [72.66319275, 21.52958298], [72.66319275, 21.52902985], [72.6626358, 21.52902985], [72.6626358, 21.52874947], [72.66236115, 21.52874947], [72.66236115, 21.52847099], [72.66208649, 21.5284729], [72.66208649, 21.52819443], [72.6618042, 21.52819443], [72.6618042, 21.52791786], [72.66124725, 21.52791977], [72.66124725, 21.52763939], [72.6609726, 21.52763939], [72.6609726, 21.52736092], [72.66041565, 21.52736092], [72.66041565, 21.52708244], [72.65930176, 21.52708244], [72.65930176, 21.52680779], [72.6590271, 21.52680969], [72.6590271, 21.52653122], [72.65875244, 21.52653122], [72.65875244, 21.52625084], [72.65847015, 21.52625084], [72.65847015, 21.52597046], [72.6581955, 21.52597237], [72.6581955, 21.5256958], [72.65791321, 21.5256958], [72.65791321, 21.52541733], [72.65763855, 21.52542114], [72.65763855, 21.52514076], [72.65735626, 21.52514076], [72.65735626, 21.52486038], [72.6570816, 21.52486038], [72.6570816, 21.52458], [72.65680695, 21.52458572], [72.65680695, 21.52430344], [72.65652466, 21.52430344], [72.65652466, 21.52458572], [72.65486145, 21.52458572], [72.65486145, 21.52430344], [72.65458679, 21.52430344], [72.65458679, 21.52402687], [72.65429688, 21.52403069], [72.65429688, 21.52375031], [72.65402985, 21.52375031], [72.65402985, 21.52346992], [72.65374756, 21.52347183], [72.65374756, 21.52319336], [72.6534729, 21.52320099], [72.6534729, 21.52292061], [72.65319824, 21.52292061], [72.65319824, 21.51986122], [72.65207672, 21.51986122], [72.65207672, 21.51958275], [72.6515274, 21.51958275], [72.6515274, 21.51930618], [72.65125275, 21.5193119], [72.65125275, 21.51874924], [72.65097046, 21.51874924], [72.65097046, 21.51820183], [72.6506958, 21.51820183], [72.6506958, 21.51736069], [72.65040588, 21.51736069], [72.65040588, 21.51681137], [72.64985657, 21.51681137], [72.64985657, 21.51652908], [72.64958191, 21.51652908], [72.64958191, 21.51625061], [72.64930725, 21.51625061], [72.64930725, 21.51597023], [72.64902496, 21.51597214], [72.64902496, 21.51569366], [72.64875031, 21.51569366], [72.64875031, 21.5154171], [72.64848328, 21.51542091], [72.64848328, 21.515131], [72.64819336, 21.51513863], [72.64819336, 21.51486206], [72.6479187, 21.51486206], [72.6479187, 21.51458359], [72.64763641, 21.51458359], [72.64763641, 21.51430511], [72.64736176, 21.51431084], [72.64736176, 21.51403046], [72.6470871, 21.51403046], [72.6470871, 21.5134697], [72.64680481, 21.5134716], [72.64680481, 21.51291466], [72.64653015, 21.51292038], [72.64653015, 21.51264], [72.64624786, 21.51264], [72.64624786, 21.51235962], [72.64597321, 21.51236153], [72.64597321, 21.51180649], [72.64569092, 21.5118103], [72.64569092, 21.51152992], [72.64541626, 21.51152992], [72.64541626, 21.51097107], [72.6451416, 21.51097488], [72.6451416, 21.51041412], [72.64485931, 21.51041985], [72.64485931, 21.51013947], [72.64457703, 21.51013947], [72.64457703, 21.50932121], [72.64430237, 21.50932121], [72.64430237, 21.50902939], [72.64402771, 21.50902939], [72.64402771, 21.50847054], [72.64375305, 21.50847244], [72.64375305, 21.50819206], [72.64347076, 21.50819206], [72.64347076, 21.5079174], [72.64319611, 21.50792122], [72.64319611, 21.50764275], [72.64290619, 21.50764275], [72.64290619, 21.50708008], [72.64263916, 21.50708389], [72.64263916, 21.50680542], [72.64235687, 21.50681114], [72.64235687, 21.50625992], [72.64208221, 21.50625992], [72.64208221, 21.50570107], [72.64180756, 21.50570107], [72.64180756, 21.50486183], [72.64152527, 21.50486183], [72.64152527, 21.50430489], [72.64125061, 21.50430489], [72.64125061, 21.50347137], [72.64097595, 21.50347137], [72.64097595, 21.50291634], [72.64068604, 21.50291824], [72.64068604, 21.50208092], [72.64041901, 21.50208282], [72.64041901, 21.50152779], [72.64013672, 21.50152969], [72.64013672, 21.50069046], [72.63986206, 21.50069427], [72.63986206, 21.50013924], [72.63957977, 21.50013924], [72.63957977, 21.4995842], [72.63930511, 21.4995842], [72.63930511, 21.49875069], [72.63903046, 21.49875069], [72.63903046, 21.49818993], [72.63791656, 21.49819565], [72.63791656, 21.49791718], [72.63764191, 21.49792099], [72.63764191, 21.49736023], [72.63735962, 21.49736023], [72.63735962, 21.49653053], [72.63707733, 21.49653053], [72.63707733, 21.49596977], [72.63680267, 21.49597168], [72.63680267, 21.49569321], [72.63652802, 21.49570084], [72.63652802, 21.49542046], [72.63597107, 21.49542046], [72.63597107, 21.49514008], [72.63540649, 21.49514008], [72.63540649, 21.4948597], [72.63513947, 21.4948616], [72.63513947, 21.49458122], [72.63458252, 21.49458122], [72.63458252, 21.49430466], [72.63402557, 21.49430466], [72.63402557, 21.49402809], [72.63291931, 21.49403191], [72.63291931, 21.49374962], [72.63208008, 21.49374962], [72.63208008, 21.49347115], [72.63124847, 21.49347115], [72.63124847, 21.49319458], [72.63014221, 21.49319458], [72.63014221, 21.49291611], [72.62930298, 21.49292183], [72.62930298, 21.49263954], [72.62819672, 21.49263954], [72.62819672, 21.49235916], [72.62568665, 21.49235916], [72.62568665, 21.49263954], [72.62541962, 21.49263954], [72.62541962, 21.49319458], [72.62513733, 21.49319267], [72.62513733, 21.49374962], [72.62486267, 21.49374962], [72.62486267, 21.49430466], [72.62458038, 21.49430466], [72.62458038, 21.4948616], [72.62431335, 21.4948597], [72.62431335, 21.49542046], [72.62403107, 21.49541664], [72.62403107, 21.49597168], [72.62374878, 21.49596977], [72.62374878, 21.49625015], [72.62403107, 21.49625015], [72.62403107, 21.49653053], [72.62431335, 21.49653053], [72.62431335, 21.49681091], [72.62458038, 21.49681091], [72.62458038, 21.49708939], [72.62486267, 21.49708939], [72.62486267, 21.49736023], [72.62513733, 21.49736023], [72.62513733, 21.49764061], [72.62541962, 21.49764061], [72.62541962, 21.49792099], [72.62569427, 21.49791718], [72.62569427, 21.4995842], [72.62596893, 21.49958038], [72.62596893, 21.50041962], [72.62625122, 21.50041962], [72.62625122, 21.50152969], [72.62652588, 21.50152779], [72.62652588, 21.50208282], [72.62680817, 21.50208282], [72.62680817, 21.50458336], [72.62652588, 21.50457764], [72.62652588, 21.50542259], [72.62625122, 21.50541687], [72.62625122, 21.50597191], [72.62596893, 21.50597191], [72.62596893, 21.50625992], [72.62180328, 21.50625992], [72.62180328, 21.50653267], [72.62124634, 21.50652695], [72.62124634, 21.50819206], [72.62097168, 21.50819206], [72.62097168, 21.50847244], [72.62069702, 21.50847054], [72.62069702, 21.50875282], [72.6204071, 21.50875282], [72.62041473, 21.50986099], [72.62014008, 21.50986099], [72.62014771, 21.51013947], [72.61985779, 21.51013947], [72.61985779, 21.51041985], [72.61958313, 21.51041412], [72.61958313, 21.51097488], [72.61930847, 21.51097107], [72.61930847, 21.51124954], [72.61902618, 21.51124954], [72.61902618, 21.51180077], [72.61930847, 21.51180649], [72.61930847, 21.51236153], [72.61958313, 21.51235962], [72.61958313, 21.51292038], [72.62014771, 21.51292038], [72.62014771, 21.51320076], [72.62069702, 21.51319695], [72.62069702, 21.5134716], [72.6204071, 21.5134697], [72.6204071, 21.51403046], [72.62014008, 21.51402855], [72.62014008, 21.51458359], [72.61985779, 21.51458359], [72.61985779, 21.51513863], [72.61958313, 21.515131], [72.61958313, 21.51542091], [72.61846924, 21.51542091], [72.61846924, 21.51625061], [72.61818695, 21.51625061], [72.61818695, 21.51652908], [72.61791992, 21.51652908], [72.61791992, 21.51681137], [72.61763763, 21.51680565], [72.61763763, 21.51708412], [72.61736298, 21.5170784], [72.61736298, 21.51736069], [72.61708832, 21.51736069], [72.61708832, 21.51763916], [72.61680603, 21.51763916], [72.61680603, 21.51791954], [72.61653137, 21.51791954], [72.61653137, 21.51820183], [72.61624908, 21.51820183], [72.61624908, 21.51902962], [72.6159668, 21.51902962], [72.6159668, 21.5193119], [72.61569214, 21.51930618], [72.61569214, 21.51958275], [72.61458588, 21.51958275], [72.61458588, 21.51930618], [72.61429596, 21.5193119], [72.61429596, 21.52042007], [72.61402893, 21.52041626], [72.61402893, 21.52180481], [72.61374664, 21.52180481], [72.61374664, 21.52208138], [72.61347198, 21.52207947], [72.61347198, 21.52264023], [72.61319733, 21.52264023], [72.61319733, 21.52292061], [72.61291504, 21.52291679], [72.61291504, 21.52347183], [72.61264038, 21.52346992], [72.61264038, 21.52375031], [72.61235809, 21.52375031], [72.61235809, 21.52403069], [72.61208344, 21.52402687], [72.61208344, 21.52430344], [72.61235809, 21.52429962], [72.61235809, 21.52542114], [72.61264038, 21.52541733], [72.61264038, 21.5256958], [72.61291504, 21.5256958], [72.61291504, 21.52597237], [72.61347198, 21.52597046], [72.61347198, 21.52625084], [72.61374664, 21.52625084], [72.61374664, 21.52597046], [72.61458588, 21.52597237], [72.61458588, 21.5256958], [72.61597443, 21.5256958], [72.61597443, 21.52541733], [72.61708069, 21.52541733], [72.61708069, 21.5256958], [72.61763763, 21.5256958], [72.61763763, 21.52597237], [72.61791992, 21.52597237], [72.61791992, 21.52708244], [72.61818695, 21.527071], [72.61818695, 21.52736092], [72.61846924, 21.52736092], [72.61846924, 21.52791977], [72.61875153, 21.52791977], [72.61875153, 21.53013992], [72.62069702, 21.53013992], [72.62069702, 21.5304184], [72.61985779, 21.5304184], [72.61985779, 21.53070068], [72.61902618, 21.53069496], [72.61902618, 21.53097153], [72.61653137, 21.53096962], [72.61653137, 21.53124809], [72.61347198, 21.53124809], [72.61347198, 21.53096962], [72.61319733, 21.53097153], [72.61319733, 21.53013992], [72.61207581, 21.53013992], [72.61207581, 21.52985954], [72.61125183, 21.52986145], [72.61125183, 21.52958298], [72.61013794, 21.52958298], [72.61013794, 21.52902985], [72.60986328, 21.52902985], [72.60986328, 21.52874947], [72.60930634, 21.52874947], [72.60930634, 21.52902985], [72.60901642, 21.52902985], [72.60901642, 21.52930832], [72.60847473, 21.52930641], [72.60847473, 21.52958298], [72.60819244, 21.52958298], [72.60819244, 21.52986145], [72.60791779, 21.52985954], [72.60791779, 21.53181267], [72.60819244, 21.53180504], [72.60819244, 21.53236008], [72.6084671, 21.53236008], [72.6084671, 21.53320122], [72.60874939, 21.53320122], [72.60874939, 21.53375053], [72.60901642, 21.53375053], [72.60901642, 21.53430939], [72.60930634, 21.53430939], [72.60930634, 21.5351429], [72.60958099, 21.53513908], [72.60958099, 21.53569221], [72.60986328, 21.53569031], [72.60986328, 21.53680992], [72.61013794, 21.5368042], [72.61013794, 21.53819656], [72.61042023, 21.53819656], [72.61042023, 21.53986168], [72.61068726, 21.53985977], [72.61068726, 21.54125023], [72.61042023, 21.54125023], [72.61042023, 21.54208374], [72.60958099, 21.54207993], [72.60958099, 21.54236031], [72.60901642, 21.54236031], [72.60901642, 21.54264069], [72.60764313, 21.54264069], [72.60764313, 21.54153061], [72.60736084, 21.54153061], [72.60736084, 21.53957939], [72.60708618, 21.53958321], [72.60708618, 21.53791428], [72.60679626, 21.53792], [72.60679626, 21.53680992], [72.60514069, 21.5368042], [72.60514069, 21.53708267], [72.6048584, 21.53708076], [72.6048584, 21.53736115], [72.60457611, 21.53736115], [72.60457611, 21.53763962], [72.60430908, 21.53763962], [72.60430908, 21.53792], [72.60402679, 21.53791428], [72.60402679, 21.53819656], [72.60375214, 21.53819656], [72.60375214, 21.53847313], [72.60346985, 21.53847122], [72.60346985, 21.53874969], [72.60320282, 21.53874969], [72.60320282, 21.53903008], [72.6029129, 21.53903008], [72.6029129, 21.54014015], [72.60319519, 21.54013634], [72.60319519, 21.54125023], [72.60346985, 21.54125023], [72.60346985, 21.54874992], [72.60319519, 21.54874992], [72.60319519, 21.54986382], [72.6029129, 21.54986382], [72.6029129, 21.54958534], [72.60263824, 21.54958534], [72.60263824, 21.54930305], [72.60235596, 21.54931068], [72.60235596, 21.54846954], [72.6020813, 21.54847145], [72.6020813, 21.54736137], [72.60180664, 21.54736137], [72.60180664, 21.54597282], [72.60152435, 21.54597282], [72.60152435, 21.54486084], [72.60124969, 21.54486084], [72.60124969, 21.5431881], [72.60097504, 21.54319382], [72.60097504, 21.54236031], [72.60041809, 21.54236031], [72.60041809, 21.54264069], [72.6001358, 21.54264069], [72.6001358, 21.54291916], [72.59958649, 21.54291725], [72.59958649, 21.54319382], [72.5993042, 21.54319382], [72.5993042, 21.54347229], [72.59874725, 21.54347038], [72.59874725, 21.54375076], [72.5984726, 21.54375076], [72.5984726, 21.54431152], [72.59819794, 21.5443058], [72.59819794, 21.54597282], [72.5984726, 21.54597092], [72.5984726, 21.54763985], [72.59874725, 21.54763794], [72.59874725, 21.54847145], [72.59902191, 21.54846954], [72.59902191, 21.5490303], [72.5993042, 21.5490284], [72.5993042, 21.54958534], [72.59958649, 21.54957962], [72.59958649, 21.55014038], [72.59986115, 21.55013847], [72.59986115, 21.55069351], [72.6001358, 21.55069351], [72.6001358, 21.55125046], [72.60041809, 21.55124092], [72.60041809, 21.55181122], [72.60069275, 21.55181122], [72.60069275, 21.55236053], [72.60098267, 21.55236053], [72.60098267, 21.55291939], [72.60124969, 21.55291748], [72.60124969, 21.55430794], [72.60041809, 21.55430794], [72.60041809, 21.55402756], [72.6001358, 21.55402946], [72.6001358, 21.55347061], [72.59986115, 21.55347252], [72.59986115, 21.55263901], [72.59958649, 21.55264091], [72.59958649, 21.55208015], [72.5993042, 21.55208588], [72.5993042, 21.55152512], [72.59874725, 21.55153084], [72.59874725, 21.55124092], [72.59764099, 21.55124092], [72.59764099, 21.55181122], [72.5973587, 21.55181122], [72.5973587, 21.55236053], [72.59764099, 21.55236053], [72.59764099, 21.55319595], [72.59792328, 21.55319023], [72.59792328, 21.55375099], [72.59819794, 21.55375099], [72.59819794, 21.55402946], [72.5984726, 21.55402756], [72.5984726, 21.55430794], [72.59874725, 21.55430794], [72.59874725, 21.5545826], [72.59902191, 21.55458069], [72.59902191, 21.55486107], [72.59929657, 21.55486107], [72.59929657, 21.55541992], [72.59958649, 21.55541611], [72.59958649, 21.55569458], [72.59986115, 21.55569458], [72.59986115, 21.55597305], [72.6001358, 21.55597115], [72.6001358, 21.55624962], [72.60041809, 21.55624962], [72.60041809, 21.55652809], [72.60069275, 21.55652809], [72.60069275, 21.55736923], [72.60097504, 21.5573616], [72.60097504, 21.55847168], [72.60124969, 21.55847168], [72.60124969, 21.55875015], [72.60151672, 21.55875015], [72.60151672, 21.55903244], [72.60208893, 21.55903244], [72.60208893, 21.55931282], [72.60236359, 21.55930519], [72.60236359, 21.55958366], [72.60319519, 21.55958366], [72.60319519, 21.55902863], [72.60346985, 21.55903244], [72.60346985, 21.55875015], [72.60375214, 21.55875015], [72.60375214, 21.55820274], [72.60402679, 21.55820274], [72.60402679, 21.55792236], [72.60430908, 21.55792236], [72.60430908, 21.55763817], [72.60457611, 21.55763817], [72.60457611, 21.55708122], [72.6048584, 21.55708313], [72.6048584, 21.55680466], [72.60514069, 21.55680466], [72.60514069, 21.55624962], [72.60541534, 21.55624962], [72.60541534, 21.55597305], [72.60569763, 21.55597305], [72.60569763, 21.55541611], [72.60597229, 21.55541992], [72.60597229, 21.55513954], [72.60624695, 21.55513954], [72.60624695, 21.55486107], [72.60652924, 21.55486107], [72.60652924, 21.55430031], [72.60680389, 21.55430794], [72.60680389, 21.55402756], [72.60708618, 21.55402946], [72.60708618, 21.55347061], [72.60736084, 21.55347252], [72.60736084, 21.55319595], [72.6076355, 21.55319595], [72.6076355, 21.55291748], [72.60791779, 21.55291939], [72.60791779, 21.55264091], [72.6084671, 21.55264091], [72.6084671, 21.55236053], [72.60874939, 21.55236053], [72.60874939, 21.55208015], [72.60930634, 21.55208015], [72.60930634, 21.55291939], [72.60901642, 21.55291939], [72.60901642, 21.55820274], [72.60930634, 21.55820274], [72.60930634, 21.55875015], [72.60958099, 21.55875015], [72.60958099, 21.55958366], [72.60986328, 21.55958176], [72.60986328, 21.56014061], [72.61013794, 21.5601387], [72.61013794, 21.56097221], [72.61042023, 21.56097031], [72.61042023, 21.56153107], [72.61069489, 21.56152725], [72.61069489, 21.56208229], [72.61042023, 21.56208038], [72.61042023, 21.56264114], [72.61013794, 21.56264114], [72.61013794, 21.56291962], [72.60986328, 21.5629158], [72.60986328, 21.56347466], [72.60958099, 21.56347084], [72.60958099, 21.56402969], [72.60930634, 21.56402969], [72.60930634, 21.56431007], [72.60902405, 21.56430435], [72.60902405, 21.5648613], [72.60874939, 21.56485939], [72.60874939, 21.56513977], [72.60847473, 21.56513977], [72.60847473, 21.56569672], [72.60819244, 21.56569672], [72.60819244, 21.56597137], [72.60791779, 21.56596947], [72.60791779, 21.56653023], [72.6076355, 21.56652832], [72.6076355, 21.56708336], [72.60736084, 21.56708336], [72.60736084, 21.56736183], [72.60708618, 21.56735992], [72.60708618, 21.56792068], [72.60679626, 21.56792068], [72.60679626, 21.56819916], [72.60624695, 21.56819534], [72.60624695, 21.56847191], [72.60597229, 21.56846809], [72.60597229, 21.56875038], [72.60569763, 21.56875038], [72.60569763, 21.56903076], [72.60514832, 21.56903076], [72.60514832, 21.56930923], [72.6048584, 21.56930542], [72.6048584, 21.56958389], [72.60457611, 21.56957817], [72.60457611, 21.56986046], [72.60430908, 21.56986046], [72.60430908, 21.57181168], [72.60458374, 21.57180595], [72.60458374, 21.5731945], [72.6048584, 21.5731945], [72.6048584, 21.57458115], [72.60514069, 21.57458115], [72.60514069, 21.5759716], [72.60541534, 21.5759716], [72.60541534, 21.57736015], [72.60569763, 21.57736015], [72.60569763, 21.57875061], [72.60597229, 21.57875061], [72.60597229, 21.57958412], [72.60680389, 21.57958412], [72.60680389, 21.57930756], [72.60708618, 21.57930946], [72.60708618, 21.57903099], [72.60791779, 21.57903099], [72.60791779, 21.58180809], [72.6076355, 21.58180618], [72.6076355, 21.58263969], [72.60791779, 21.58263969], [72.60791779, 21.58319473], [72.60819244, 21.58319092], [72.60819244, 21.58374977], [72.6084671, 21.58374977], [72.6084671, 21.58402824], [72.60874939, 21.58402824], [72.60874939, 21.58458328], [72.60902405, 21.58458328], [72.60902405, 21.58486176], [72.60930634, 21.58486176], [72.60930634, 21.58542252], [72.60958099, 21.58541679], [72.60958099, 21.58597183], [72.60986328, 21.58597183], [72.60986328, 21.58625031], [72.61013794, 21.58625031], [72.61013794, 21.58653259], [72.61042023, 21.58653259], [72.61042023, 21.58681107], [72.61069489, 21.58680534], [72.61069489, 21.58708382], [72.61096954, 21.58708382], [72.61096954, 21.58736038], [72.61125183, 21.58735085], [72.61125183, 21.58764267], [72.61152649, 21.58764267], [72.61152649, 21.58792114], [72.61180878, 21.58791733], [72.61180878, 21.58819389], [72.61207581, 21.58819008], [72.61207581, 21.58875084], [72.61235809, 21.58875084], [72.61235809, 21.58930969], [72.61264038, 21.58930588], [72.61264038, 21.58958244], [72.61291504, 21.58958244], [72.61291504, 21.58986092], [72.61347198, 21.58986092], [72.61347198, 21.59013939], [72.61374664, 21.59013939], [72.61374664, 21.59041405], [72.61402893, 21.59041405], [72.61402893, 21.59097481], [72.61429596, 21.59097099], [72.61429596, 21.59152985], [72.61458588, 21.59152985], [72.61458588, 21.59181023], [72.61486053, 21.5918045], [72.61486053, 21.59208488], [72.61514282, 21.59208107], [72.61514282, 21.59263992], [72.6159668, 21.59263992], [72.6159668, 21.5929203], [72.61680603, 21.5929203], [72.61680603, 21.59348106], [72.61708069, 21.59347153], [72.61708069, 21.59458351], [72.61736298, 21.5945797], [72.61736298, 21.59514046], [72.61763763, 21.59514046], [72.61763763, 21.59542084], [72.61819458, 21.59541893], [72.61819458, 21.59569359], [72.61875153, 21.59569359], [72.61875153, 21.59597206], [72.61958313, 21.59596825], [72.61958313, 21.59625053], [72.62069702, 21.59625053], [72.62069702, 21.59680939], [72.62097168, 21.59680939], [72.62097168, 21.59736061], [72.62124634, 21.59736061], [72.62124634, 21.59931183], [72.62152863, 21.59931183], [72.62152863, 21.60042191], [72.62180328, 21.60041618], [72.62180328, 21.6020813], [72.6220932, 21.60207939], [72.6220932, 21.60320091], [72.62236023, 21.60320091], [72.62236023, 21.60375023], [72.62264252, 21.60375023], [72.62264252, 21.60403061], [72.62291718, 21.60403061], [72.62291718, 21.60431099], [72.62319183, 21.60430336], [72.62319183, 21.60458565], [72.62346649, 21.60457993], [72.62346649, 21.60486031], [72.62374878, 21.60486031], [72.62374878, 21.60542107], [72.62403107, 21.60541534], [72.62403107, 21.60569572], [72.62431335, 21.60569], [72.62431335, 21.60653114], [72.62486267, 21.60652542], [72.62486267, 21.60708237], [72.62513733, 21.60708046], [72.62513733, 21.60764122], [72.62541962, 21.60764122], [72.62541962, 21.60848045], [72.62596893, 21.60848045], [72.62596893, 21.60874939], [72.62625122, 21.60874939], [72.62625122, 21.6095829], [72.62652588, 21.60957909], [72.62652588, 21.61041832], [72.62680817, 21.61041832], [72.62680817, 21.61124992], [72.62708282, 21.61124992], [72.62708282, 21.61181259], [72.62735748, 21.61180496], [72.62735748, 21.61236191], [72.62708282, 21.61236191], [72.62708282, 21.61347008], [72.62735748, 21.61347008], [72.62735748, 21.61431122], [72.62763977, 21.6143055], [72.62763977, 21.61458206], [72.6279068, 21.61458015], [72.6279068, 21.61541939], [72.62819672, 21.61541939], [72.62819672, 21.61680984], [72.62875366, 21.61680412], [72.62875366, 21.6170826], [72.62930298, 21.61708069], [72.62930298, 21.61765099], [72.63014221, 21.61765099], [72.63014221, 21.61791992], [72.63097382, 21.6179142], [72.63097382, 21.61819649], [72.63208008, 21.61819649], [72.63208008, 21.61847305], [72.63263702, 21.61847115], [72.63263702, 21.61874962], [72.63346863, 21.61874962], [72.63346863, 21.61903], [72.63402557, 21.61902618], [72.63402557, 21.61930656], [72.63458252, 21.61930656], [72.63458252, 21.6198616], [72.63485718, 21.6198597], [72.63485718, 21.62014008], [72.63513184, 21.62014008], [72.63513184, 21.62042046], [72.63846588, 21.62042046], [72.63846588, 21.62014008], [72.63931274, 21.62014008], [72.63931274, 21.6198597], [72.63957977, 21.6198616], [72.63957977, 21.61958313], [72.64069366, 21.61958313], [72.64069366, 21.61930656], [72.64125061, 21.61930656], [72.64125061, 21.61902618], [72.6415329, 21.61903], [72.6415329, 21.61874962], [72.64208221, 21.61874962], [72.64208221, 21.61847115], [72.6423645, 21.61847305], [72.6423645, 21.61819649], [72.64319611, 21.61819649], [72.64319611, 21.6179142], [72.64347076, 21.61791992], [72.64347076, 21.61765099], [72.64402771, 21.61765099], [72.64402771, 21.61736107], [72.64541626, 21.61736107], [72.64541626, 21.61708069], [72.6479187, 21.61708069], [72.6479187, 21.61736107], [72.64848328, 21.61736107], [72.64848328, 21.61765099], [72.64875031, 21.61765099], [72.64875031, 21.61791992], [72.64902496, 21.6179142], [72.64902496, 21.61819649], [72.64930725, 21.61819649], [72.64930725, 21.61847305], [72.64958191, 21.61847115], [72.64958191, 21.61903], [72.64985657, 21.61903], [72.64985657, 21.62014008], [72.65013123, 21.62014008], [72.65013123, 21.62042046], [72.65041351, 21.62041855], [72.65041351, 21.62097168], [72.6506958, 21.62096977], [72.6506958, 21.62125015], [72.65097046, 21.62125015], [72.65097046, 21.62181091], [72.65125275, 21.62180519], [72.65125275, 21.62208366], [72.65180206, 21.62208366], [72.65180206, 21.62319374], [72.65208435, 21.62319374], [72.65208435, 21.62347221], [72.65235901, 21.62346077], [72.65235901, 21.62375069], [72.6526413, 21.62375069], [72.6526413, 21.62346077], [72.65291595, 21.62347221], [72.65291595, 21.62319374], [72.65319824, 21.62319374], [72.65319824, 21.62347221], [72.65374756, 21.62346077], [72.65374756, 21.62375069], [72.6554184, 21.62375069], [72.6554184, 21.62402916], [72.65569305, 21.62402916], [72.65569305, 21.62431145], [72.65597534, 21.62430573], [72.65597534, 21.6245842], [72.65680695, 21.62457848], [72.65680695, 21.62486076], [72.65763855, 21.62486076], [72.65763855, 21.62513924], [72.65791321, 21.62513924], [72.65791321, 21.62541962], [72.6581955, 21.6254158], [72.6581955, 21.62597275], [72.65735626, 21.62597084], [72.65735626, 21.62625122], [72.6570816, 21.62625122], [72.6570816, 21.62681007], [72.65736389, 21.62680626], [72.65736389, 21.62708282], [72.65763855, 21.62708282], [72.65763855, 21.6273613], [72.65791321, 21.62735939], [72.65791321, 21.62763977], [72.65957642, 21.62763977], [72.65957642, 21.62792015], [72.66041565, 21.62791634], [72.66041565, 21.62819481], [72.66319275, 21.62819481], [72.66319275, 21.62791634], [72.66485596, 21.62792015], [72.66485596, 21.62763977], [72.6654129, 21.62763977], [72.6654129, 21.62735939], [72.66570282, 21.62735939], [72.66570282, 21.62792015], [72.66596985, 21.62791634], [72.66596985, 21.62819481], [72.66708374, 21.62819481], [72.66708374, 21.62791634], [72.67263794, 21.62791634], [72.67263794, 21.62819481], [72.67319489, 21.62819481], [72.67319489, 21.62847137], [72.67346954, 21.62846947], [72.67346954, 21.62874985], [72.67430115, 21.62874985], [72.67430115, 21.62903023], [72.67514038, 21.62902832], [72.67514038, 21.62986374], [72.67569733, 21.62985992], [72.67569733, 21.6301403], [72.67652893, 21.6301403], [72.67652893, 21.63042068], [72.67679596, 21.63042068], [72.67679596, 21.63070107], [72.67708588, 21.63069344], [72.67708588, 21.63097191], [72.67764282, 21.63097], [72.67764282, 21.63153076], [72.67791748, 21.63152695], [72.67791748, 21.6320858], [72.6784668, 21.63208008], [72.6784668, 21.63265038], [72.67903137, 21.63265038], [72.67903137, 21.63292122], [72.68041992, 21.6329174], [72.68041992, 21.63319588], [72.68069458, 21.63319588], [72.68069458, 21.63347244], [72.68125153, 21.63347054], [72.68125153, 21.63402939], [72.68152618, 21.63402939], [72.68152618, 21.63430977], [72.68235779, 21.63430786], [72.68235779, 21.63458252], [72.68264008, 21.63458061], [72.68264008, 21.63486099], [72.68319702, 21.63486099], [72.68319702, 21.63513947], [72.68402863, 21.63513947], [72.68402863, 21.63541985], [72.68458557, 21.63541794], [72.68458557, 21.6356945], [72.68486023, 21.6356945], [72.68486023, 21.63597298], [72.68541718, 21.63597107], [72.68541718, 21.63624954], [72.68569183, 21.63624954], [72.68569183, 21.63652992], [72.68597412, 21.63652992], [72.68596649, 21.63680077], [72.68653107, 21.63680649], [72.68653107, 21.63708305], [72.68708038, 21.63708305], [72.68708038, 21.63736153], [72.68736267, 21.63735962], [72.68736267, 21.63763809], [72.68791962, 21.63763809], [72.68791962, 21.63791847], [72.68819427, 21.63791656], [72.68819427, 21.6384716], [72.68846893, 21.63845825], [72.68846893, 21.63875008], [72.68875122, 21.63875008], [72.68875122, 21.63903046], [72.68930817, 21.63903046], [72.68930817, 21.63931274], [72.68958282, 21.63931274], [72.68958282, 21.63986015], [72.6904068, 21.63986015], [72.6904068, 21.64014053], [72.69124603, 21.64014053], [72.69124603, 21.64042282], [72.69180298, 21.6404171], [72.69180298, 21.64069366], [72.69236755, 21.64069176], [72.69236755, 21.6415329], [72.69264221, 21.6415329], [72.69264221, 21.64180946], [72.69291687, 21.64180565], [72.69291687, 21.64208221], [72.69319153, 21.64208031], [72.69319153, 21.64264107], [72.69347382, 21.64263916], [72.69347382, 21.64319229], [72.69319153, 21.64319229], [72.69319153, 21.64347458], [72.69346619, 21.64347076], [72.69346619, 21.64402962], [72.69374847, 21.64402962], [72.69374847, 21.64431], [72.69403076, 21.64431], [72.69403076, 21.64486122], [72.69430542, 21.64486122], [72.69430542, 21.64513969], [72.69458008, 21.64513969], [72.69458008, 21.64569664], [72.69486237, 21.64569092], [72.69486237, 21.64624977], [72.69513702, 21.64624977], [72.69513702, 21.64653015], [72.69541931, 21.64652824], [72.69541931, 21.64680672], [72.69569397, 21.64680672], [72.69569397, 21.64736176], [72.69596863, 21.64735985], [72.69596863, 21.64764977], [72.69625092, 21.64764977], [72.69625092, 21.64819908], [72.69652557, 21.64819527], [72.69652557, 21.64847183], [72.69680786, 21.64846992], [72.69680786, 21.64875031], [72.6965332, 21.64875031], [72.6965332, 21.64903069], [72.69708252, 21.64903069], [72.69708252, 21.64930916], [72.69736481, 21.64930534], [72.69736481, 21.64958382], [72.69763947, 21.64957809], [72.69763947, 21.64986038], [72.69819641, 21.64986038], [72.69819641, 21.65014076], [72.69847107, 21.65014076], [72.69847107, 21.65041924], [72.69875336, 21.65041733], [72.69875336, 21.65069389], [72.69902802, 21.65069389], [72.69902802, 21.65097237], [72.69957733, 21.65097046], [72.69957733, 21.65125084], [72.70041656, 21.65125084], [72.70041656, 21.65152931], [72.70096588, 21.65152931], [72.70096588, 21.6518116], [72.70236206, 21.65180588], [72.70236206, 21.65208244], [72.7048645, 21.65208244], [72.7048645, 21.65180588], [72.70540619, 21.6518116], [72.70540619, 21.65152931], [72.70569611, 21.65152931], [72.70569611, 21.65125084], [72.70597076, 21.65125084], [72.70597076, 21.65097046], [72.70625305, 21.65097237], [72.70625305, 21.65041733], [72.70680237, 21.65041733], [72.70680237, 21.65069389], [72.70708466, 21.65069389], [72.70708466, 21.65041733], [72.70735168, 21.65041924], [72.70735168, 21.65014076], [72.7076416, 21.65014076], [72.7076416, 21.64957809], [72.70847321, 21.64958382], [72.70847321, 21.64902878], [72.70903015, 21.64903069], [72.70903015, 21.64875031], [72.70929718, 21.64875031], [72.70929718, 21.64846992], [72.70986176, 21.64847183], [72.70986176, 21.64819527], [72.71041107, 21.64819908], [72.71041107, 21.64764977], [72.71069336, 21.64764977], [72.71069336, 21.64707947], [72.71097565, 21.64708328], [72.71097565, 21.64652824], [72.71125031, 21.64653015], [72.71125031, 21.64624977], [72.71151733, 21.64624977], [72.71151733, 21.64596939], [72.71180725, 21.6459713], [72.71180725, 21.64513969], [72.71235657, 21.64513969], [72.71235657, 21.64459038], [72.71263885, 21.64459038], [72.71263885, 21.64431], [72.71290588, 21.64431], [72.71290588, 21.64375114], [72.71375275, 21.64375114], [72.71375275, 21.64319038], [72.7140274, 21.64319229], [72.7140274, 21.64263916], [72.71430206, 21.64264107], [72.71430206, 21.64236069], [72.71485901, 21.64236069], [72.71485901, 21.64180946], [72.7151413, 21.64180946], [72.7151413, 21.6415329], [72.71541595, 21.6415329], [72.71541595, 21.64097023], [72.71624756, 21.64097023], [72.71624756, 21.64069366], [72.7168045, 21.64069366], [72.7168045, 21.6404171], [72.71736145, 21.64042282], [72.71736145, 21.64014053], [72.71763611, 21.64014053], [72.71763611, 21.63986015], [72.71819305, 21.63986015], [72.71819305, 21.63958168], [72.71930695, 21.63958359], [72.71930695, 21.63930511], [72.72041321, 21.63931274], [72.72041321, 21.63903046], [72.72319794, 21.63903046], [72.72319794, 21.63875008], [72.72624969, 21.63875008], [72.72624969, 21.63903046], [72.72820282, 21.63903046], [72.72820282, 21.63931274], [72.72875214, 21.63930511], [72.72875214, 21.63958359], [72.72930908, 21.63958168], [72.72930908, 21.63986015], [72.73124695, 21.63986015], [72.73124695, 21.64014053], [72.73264313, 21.64014053], [72.73264313, 21.63986015], [72.73291779, 21.63986015], [72.73291779, 21.63958168], [72.73347473, 21.63958359], [72.73347473, 21.63930511], [72.73486328, 21.63930511], [72.73486328, 21.63958359], [72.73568726, 21.63958168], [72.73568726, 21.64014053], [72.73596954, 21.64013863], [72.73596954, 21.64069366], [72.73930359, 21.64069366], [72.73930359, 21.64097023], [72.73986053, 21.64097023], [72.73986053, 21.64125061], [72.74014282, 21.64125061], [72.74014282, 21.64180946], [72.74041748, 21.64180565], [72.74041748, 21.64208221], [72.74236298, 21.64208031], [72.74236298, 21.64236069], [72.74291992, 21.64236069], [72.74291992, 21.64208031], [72.74402618, 21.64208221], [72.74402618, 21.64180565], [72.74458313, 21.64180565], [72.74458313, 21.64208221], [72.7454071, 21.64208031], [72.7454071, 21.64236069], [72.74736023, 21.64236069], [72.74736023, 21.64264107], [72.74791718, 21.64264107], [72.74791718, 21.64291954], [72.74819183, 21.64291573], [72.74819183, 21.64319229], [72.74847412, 21.64319229], [72.74847412, 21.64347458], [72.74874878, 21.64347076], [72.74874878, 21.64402962], [72.74903107, 21.64402962], [72.74903107, 21.64459038], [72.74930573, 21.64458275], [72.74930573, 21.6459713], [72.74958038, 21.64596939], [72.74958038, 21.64653015], [72.74986267, 21.64652824], [72.74986267, 21.64708328], [72.74958038, 21.64707947], [72.74958038, 21.64764977], [72.74986267, 21.64764977], [72.74986267, 21.64792061], [72.75013733, 21.64792061], [72.75013733, 21.64819908], [72.75041962, 21.64819527], [72.75041962, 21.64847183], [72.75068665, 21.64846992], [72.75068665, 21.64875031], [72.75096893, 21.64875031], [72.75096893, 21.64903069], [72.75125122, 21.64903069], [72.75125122, 21.64930916], [72.75096893, 21.64930534], [72.75096893, 21.64958382], [72.75152588, 21.64957809], [72.75152588, 21.64986038], [72.75208282, 21.64986038], [72.75208282, 21.65014076], [72.75235748, 21.65014076], [72.75235748, 21.64986038], [72.75374603, 21.64986038], [72.75374603, 21.65014076], [72.75681305, 21.65014076], [72.75681305, 21.64986038], [72.75736237, 21.64986038], [72.75736237, 21.64957809], [72.75819397, 21.64958382], [72.75819397, 21.64930534], [72.7590332, 21.64930916], [72.7590332, 21.64903069], [72.75958252, 21.64903069], [72.75958252, 21.64875031], [72.76040649, 21.64875031], [72.76040649, 21.64792061], [72.76346588, 21.64792061], [72.76346588, 21.64764977], [72.76403046, 21.64764977], [72.76403046, 21.64735985], [72.76625061, 21.64736176], [72.76625061, 21.64708328], [72.76791382, 21.64708328], [72.76791382, 21.64680672], [72.76958466, 21.64680672], [72.76958466, 21.64652824], [72.7701416, 21.64653015], [72.7701416, 21.64624977], [72.77097321, 21.64624977], [72.77097321, 21.64596939], [72.77375031, 21.6459713], [72.77375031, 21.64569664], [72.77625275, 21.64569664], [72.77625275, 21.64541435], [72.7804184, 21.64542007], [72.7804184, 21.64513969], [72.78430176, 21.64513969], [72.78430176, 21.64486122], [72.78457642, 21.64486122], [72.78457642, 21.64513969], [72.78736115, 21.64513969], [72.78736115, 21.64542007], [72.78874969, 21.64541435], [72.78874969, 21.64569664], [72.78986359, 21.64569664], [72.78986359, 21.6459713], [72.79096985, 21.64596939], [72.79096985, 21.64624977], [72.79264069, 21.64624977], [72.79264069, 21.64653015], [72.79319763, 21.64652824], [72.79319763, 21.64680672], [72.79402924, 21.64680672], [72.79402924, 21.64708328], [72.7951355, 21.64708328], [72.7951355, 21.64736176], [72.7959671, 21.64735985], [72.7959671, 21.64764977], [72.79680634, 21.64764977], [72.79680634, 21.64792061], [72.79708099, 21.64792061], [72.79708099, 21.64764977], [72.79763031, 21.64764977], [72.79763031, 21.64792061], [72.79846954, 21.64792061], [72.79846954, 21.64819908], [72.79875183, 21.64819527], [72.79875183, 21.64847183], [72.80042267, 21.64846992], [72.80042267, 21.64903069], [72.80152893, 21.64903069], [72.80152893, 21.64930916], [72.80208588, 21.64930534], [72.80208588, 21.64958382], [72.80319214, 21.64957809], [72.80319214, 21.64986038], [72.80403137, 21.64986038], [72.80403137, 21.65014076], [72.80486298, 21.65014076], [72.80486298, 21.65041924], [72.80541992, 21.65041733], [72.80541992, 21.65069389], [72.80625153, 21.65069389], [72.80625153, 21.65097237], [72.80680084, 21.65097046], [72.80680084, 21.65125084], [72.80735779, 21.65125084], [72.80735779, 21.65152931], [72.8079071, 21.65152931], [72.8079071, 21.6518116], [72.80902863, 21.65180588], [72.80902863, 21.65208244], [72.80958557, 21.65208244], [72.80958557, 21.65236092], [72.80986023, 21.65236092], [72.80986023, 21.65263939], [72.81041718, 21.65263939], [72.81041718, 21.65292168], [72.81097412, 21.65291595], [72.81097412, 21.65319443], [72.81128693, 21.65319443], [72.81153107, 21.65319443], [72.81153107, 21.6534729], [72.81208038, 21.6534729], [72.81208038, 21.65374947], [72.81236267, 21.65374947], [72.81236267, 21.65402985], [72.81291962, 21.65402985], [72.81291962, 21.65431023], [72.81375122, 21.65430641], [72.81375122, 21.65458107], [72.81430817, 21.65458107], [72.81430817, 21.65486145], [72.81458282, 21.65485954], [72.81458282, 21.65513992], [72.81485748, 21.65513992], [72.81485748, 21.6554203], [72.81513977, 21.6554203], [72.81513977, 21.65570068], [72.81569672, 21.65569305], [72.81569672, 21.65597153], [72.81597137, 21.65596962], [72.81597137, 21.65625], [72.81624603, 21.65625], [72.81624603, 21.65653038], [72.81652832, 21.65653038], [72.81652832, 21.6568203], [72.81735992, 21.65680313], [72.81735992, 21.65708542], [72.81791687, 21.65708542], [72.81791687, 21.65736389], [72.81819153, 21.65736008], [72.81819153, 21.65764046], [72.81846619, 21.65764046], [72.81846619, 21.65792084], [72.81903076, 21.65791512], [72.81903076, 21.65819359], [72.81945801, 21.65819359], [72.81954956, 21.65814018], [72.81958008, 21.65847206], [72.81986237, 21.65847015], [72.81986237, 21.65875053], [72.82068634, 21.65875053], [72.82068634, 21.65903091], [72.82096863, 21.65903091], [72.82096863, 21.65930939], [72.82125092, 21.65930939], [72.82125092, 21.65958977], [72.82180023, 21.65958977], [72.82180023, 21.65986061], [72.82235718, 21.65986061], [72.82235718, 21.66041946], [72.82291412, 21.66041756], [72.82291412, 21.66069412], [72.82319641, 21.66069412], [72.82319641, 21.6609726], [72.82347107, 21.66097069], [72.82347107, 21.66125107], [72.82402802, 21.66125107], [72.82402802, 21.66152954], [72.82485962, 21.66152763], [72.82485962, 21.66208267], [72.82541656, 21.66208076], [72.82541656, 21.66236115], [72.82624817, 21.66236115], [72.82624817, 21.66263962], [72.82653046, 21.66263008], [72.82653046, 21.66291809], [72.82707977, 21.66291618], [72.82707977, 21.66319466], [72.82736206, 21.66319466], [72.82736206, 21.66347313], [72.82763672, 21.66347122], [72.82763672, 21.66374969], [72.82818604, 21.66374969], [72.82818604, 21.66402817], [72.82847595, 21.66402817], [72.82847595, 21.66430473], [72.82902527, 21.66430473], [72.82902527, 21.66458321], [72.82930756, 21.66458321], [72.82930756, 21.66486168], [72.82958221, 21.66485977], [72.82958221, 21.66514015], [72.83040619, 21.66514015], [72.83040619, 21.66542244], [72.83069611, 21.66541672], [72.83069611, 21.66569519], [72.83125305, 21.66569519], [72.83125305, 21.66597176], [72.83180237, 21.66597176], [72.83180237, 21.66625023], [72.83235931, 21.66625023], [72.83235931, 21.66653252], [72.83319092, 21.66653252], [72.83319092, 21.6668129], [72.83347321, 21.66680527], [72.83347321, 21.66708374], [72.83403015, 21.66708183], [72.83403015, 21.66736031], [72.83513641, 21.66736031], [72.83513641, 21.66792107], [72.83486176, 21.66792107], [72.83486176, 21.6687603], [72.8345871, 21.6687603], [72.8345871, 21.66930962], [72.83429718, 21.66930962], [72.83429718, 21.67014122], [72.83403015, 21.67013931], [72.83403015, 21.67069244], [72.83374023, 21.67069054], [72.83374023, 21.67152977], [72.83347321, 21.67152786], [72.83347321, 21.67236137], [72.83319092, 21.67236137], [72.83319092, 21.67251968], [72.83319092, 21.67292023], [72.83291626, 21.67291451], [72.83291626, 21.67319679], [72.83235931, 21.67319679], [72.83235931, 21.67291451], [72.83180237, 21.67292023], [72.83180237, 21.67263985], [72.83125305, 21.67263985], [72.83125305, 21.67235947], [72.83069611, 21.67236137], [72.83069611, 21.6720829], [72.83013916, 21.6720829], [72.83013916, 21.67180443], [72.82930756, 21.67181969], [72.82930756, 21.67152977], [72.82818604, 21.67152977], [72.82818604, 21.67124939], [72.82736206, 21.67124939], [72.82736206, 21.67097092], [72.82653046, 21.67097473], [72.82653046, 21.67069244], [72.82569122, 21.67069244], [72.82569122, 21.67041588], [72.82430267, 21.67041969], [72.82430267, 21.67014122], [72.82319641, 21.67014122], [72.82319641, 21.66958046], [72.82263947, 21.66958237], [72.82263947, 21.6693058], [72.8215332, 21.66930962], [72.8215332, 21.66903114], [72.82125092, 21.66903114], [72.82125092, 21.6687603], [72.82041931, 21.6687603], [72.82041931, 21.66847038], [72.81958008, 21.66847229], [72.81958008, 21.66819382], [72.81874847, 21.66819382], [72.81874847, 21.66791725], [72.81764221, 21.66792107], [72.81764221, 21.66764069], [72.8170929, 21.66764069], [72.8170929, 21.66736031], [72.81569672, 21.66736031], [72.81569672, 21.66708183], [72.81513977, 21.66708374], [72.81513977, 21.66680527], [72.81430817, 21.6668129], [72.81430817, 21.66656113], [72.81430817, 21.66625023], [72.81318665, 21.66625023], [72.81318665, 21.66597176], [72.81236267, 21.66597176], [72.81236267, 21.66569519], [72.81180573, 21.66569519], [72.81180573, 21.66541672], [72.81069183, 21.66542244], [72.81069183, 21.66514015], [72.8095932, 21.66514015], [72.8095932, 21.66485977], [72.80874634, 21.66486168], [72.80874634, 21.66458321], [72.80764008, 21.66458321], [72.80764008, 21.66430473], [72.80708313, 21.66430473], [72.80708313, 21.66402817], [72.80596924, 21.66402817], [72.80596924, 21.66374969], [72.80486298, 21.66374969], [72.80486298, 21.66347122], [72.80403137, 21.66347313], [72.80403137, 21.66319466], [72.80319214, 21.66319466], [72.80319214, 21.66291618], [72.80208588, 21.66291809], [72.80208588, 21.66263008], [72.80124664, 21.66263962], [72.80124664, 21.66236115], [72.79985809, 21.66236115], [72.79985809, 21.66208076], [72.79930878, 21.66208267], [72.79930878, 21.66180611], [72.79818726, 21.66180992], [72.79818726, 21.66152954], [72.79680634, 21.66152954], [72.79680634, 21.66180992], [72.79486084, 21.66180992], [72.79486084, 21.66152954], [72.79402924, 21.66152954], [72.79402924, 21.66180992], [72.79374695, 21.66180611], [72.79374695, 21.66208267], [72.78708649, 21.66208076], [72.78708649, 21.66236115], [72.7859726, 21.66236115], [72.7859726, 21.66263962], [72.78375244, 21.66263008], [72.78375244, 21.66291809], [72.78236389, 21.66291618], [72.78236389, 21.66319466], [72.77986145, 21.66319466], [72.77986145, 21.66347313], [72.77902985, 21.66347122], [72.77902985, 21.66374969], [72.77819824, 21.66374969], [72.77819824, 21.66402817], [72.77735901, 21.66402817], [72.77735901, 21.66430473], [72.7765274, 21.66430473], [72.7765274, 21.66458321], [72.7756958, 21.66458321], [72.7756958, 21.66486168], [72.77401733, 21.66485977], [72.77401733, 21.66514015], [72.77348328, 21.66514015], [72.77348328, 21.66542244], [72.77263641, 21.66541672], [72.77263641, 21.66569519], [72.77180481, 21.66569519], [72.77180481, 21.66597176], [72.77124786, 21.66597176], [72.77124786, 21.66625023], [72.77076721, 21.66625023], [72.76930237, 21.66625023], [72.76930237, 21.66653252], [72.76902771, 21.66653252], [72.76902771, 21.6668129], [72.76847076, 21.66680527], [72.76847076, 21.66708374], [72.76763916, 21.66708374], [72.76764679, 21.66736031], [72.76680756, 21.66736031], [72.76680756, 21.66764069], [72.76597595, 21.66764069], [72.76597595, 21.66792107], [72.76513672, 21.66791725], [72.76513672, 21.66819382], [72.76403046, 21.66819382], [72.76403046, 21.66847229], [72.76374817, 21.66847038], [72.76374817, 21.6687603], [72.76346588, 21.6687603], [72.76346588, 21.66903114], [72.76264191, 21.66903114], [72.76264191, 21.66930962], [72.76251984, 21.66930962], [72.76180267, 21.6693058], [72.76180267, 21.66958237], [72.76152039, 21.66958046], [72.76152039, 21.66986084], [72.76125336, 21.66986084], [72.76125336, 21.67014122], [72.76069641, 21.67014122], [72.76069641, 21.67041969], [72.76041412, 21.67041588], [72.76041412, 21.67069244], [72.76013947, 21.67069244], [72.76013947, 21.67097473], [72.75985718, 21.67097092], [72.75985718, 21.67124939], [72.75930786, 21.67124939], [72.75930786, 21.67152977], [72.75875092, 21.67152977], [72.75875092, 21.67181969], [72.75791931, 21.67180443], [72.75791931, 21.6720829], [72.75763702, 21.6720829], [72.75763702, 21.67236137], [72.75681305, 21.67235947], [72.75681305, 21.67292023], [72.75653076, 21.67291451], [72.75653076, 21.67319679], [72.75597382, 21.67319679], [72.75597382, 21.67347145], [72.75569153, 21.67346954], [72.75569153, 21.67374992], [72.75514221, 21.67374992], [72.75514221, 21.6740303], [72.7545929, 21.6740303], [72.7545929, 21.67431068], [72.75402832, 21.67430687], [72.75402832, 21.67458344], [72.75375366, 21.67458344], [72.75375366, 21.67486191], [72.75347137, 21.67485809], [72.75347137, 21.67514038], [72.75319672, 21.67514038], [72.75319672, 21.67542076], [72.75291443, 21.67541885], [72.7529068, 21.6756897], [72.75235748, 21.67569923], [72.75235748, 21.67653084], [72.75180817, 21.67653084], [72.75180817, 21.67680931], [72.75152588, 21.6768055], [72.75152588, 21.67708397], [72.75125122, 21.67708397], [72.75125122, 21.67764091], [72.75096893, 21.67762947], [72.75096893, 21.67791939], [72.75069427, 21.67791748], [72.75069427, 21.67847252], [72.75041962, 21.67847061], [72.75041962, 21.67874908], [72.74986267, 21.67874908], [72.74986267, 21.67986107], [72.74958038, 21.67986107], [72.74958038, 21.6807003], [72.74930573, 21.68069458], [72.74931335, 21.68124962], [72.74903107, 21.68124962], [72.74903107, 21.68180466], [72.74874878, 21.68180466], [72.74874878, 21.6823616], [72.74846649, 21.6823597], [72.74846649, 21.68320084], [72.74819183, 21.68320084], [72.74819183, 21.68375969], [72.74791718, 21.68375969], [72.74791718, 21.68403053], [72.74764252, 21.68403053], [72.74764252, 21.68431091], [72.74736023, 21.68430328], [72.74736023, 21.68458557], [72.74764252, 21.68457985], [72.74764252, 21.68486023], [72.74736023, 21.68486023], [72.74736023, 21.68514061], [72.74680328, 21.68514061], [72.74680328, 21.68542099], [72.74652863, 21.68541527], [72.74652863, 21.68597221], [72.74597168, 21.68597031], [72.74597168, 21.68625069], [72.74569702, 21.68625069], [72.74569702, 21.68653107], [72.74541473, 21.68652534], [72.74541473, 21.68680763], [72.74514008, 21.68680763], [72.74514008, 21.6870842], [72.74458313, 21.68708038], [72.74458313, 21.68736076], [72.74430847, 21.68736076], [72.74430847, 21.68764114], [72.74375153, 21.68764114], [72.74375153, 21.68791962], [72.74346924, 21.68791771], [72.74346924, 21.68819427], [72.74319458, 21.68819427], [72.74319458, 21.68847275], [72.74236298, 21.68847084], [72.74236298, 21.68875122], [72.74208069, 21.68875122], [72.74208069, 21.68902969], [72.7409668, 21.68902969], [72.7409668, 21.68930817], [72.73986053, 21.68930626], [72.73986053, 21.68958282], [72.73625183, 21.68958282], [72.73625183, 21.68930626], [72.73542023, 21.68930817], [72.73542023, 21.68902969], [72.73486328, 21.68902969], [72.73486328, 21.68875122], [72.73401642, 21.68875122], [72.73401642, 21.68847084], [72.73374939, 21.68847275], [72.73374939, 21.68819427], [72.73291779, 21.68819427], [72.73291779, 21.68791771], [72.73264313, 21.68791962], [72.73264313, 21.68764114], [72.73208618, 21.68764114], [72.73208618, 21.68736076], [72.73152924, 21.68736076], [72.73152924, 21.6870842], [72.73097229, 21.6870842], [72.73097229, 21.68680763], [72.73069763, 21.68680763], [72.73069763, 21.68652534], [72.7298584, 21.68653107], [72.7298584, 21.68625069], [72.72930908, 21.68625069], [72.72930908, 21.68597031], [72.72875214, 21.68597221], [72.72875214, 21.68569374], [72.72819519, 21.68569374], [72.72819519, 21.68541527], [72.72763824, 21.68542099], [72.72763824, 21.68514061], [72.72680664, 21.68514061], [72.72680664, 21.68486023], [72.72486115, 21.68486023], [72.72486115, 21.68457985], [72.72374725, 21.68458557], [72.72374725, 21.68430328], [72.72292328, 21.68431091], [72.72292328, 21.68403053], [72.72235107, 21.68403053], [72.72235107, 21.68375969], [72.72180176, 21.68375969], [72.72180176, 21.68349075], [72.72097015, 21.68346977], [72.72097015, 21.68319321], [72.72070313, 21.68320084], [72.72070313, 21.68292046], [72.72013855, 21.68292046], [72.72013855, 21.68264008], [72.71930695, 21.68264008], [72.71930695, 21.6823597], [72.71902466, 21.6823616], [72.71902466, 21.68180466], [72.71847534, 21.68180466], [72.71847534, 21.68152809], [72.71819305, 21.68153191], [72.71819305, 21.68124962], [72.71763611, 21.68124962], [72.71763611, 21.68097115], [72.7168045, 21.68097115], [72.7168045, 21.68069458], [72.7159729, 21.6807003], [72.7159729, 21.68042183], [72.71541595, 21.68042183], [72.71541595, 21.68013954], [72.71485901, 21.68013954], [72.71485901, 21.67986107], [72.71457672, 21.67986107], [72.71457672, 21.67958069], [72.71347046, 21.6795826], [72.71347046, 21.67930603], [72.71235657, 21.67931175], [72.71235657, 21.67902946], [72.71180725, 21.67902946], [72.71180725, 21.67874908], [72.71125031, 21.67874908], [72.71125031, 21.67847061], [72.70819092, 21.67847061], [72.70819092, 21.67874908], [72.70707703, 21.67874908], [72.70707703, 21.67902946], [72.70513916, 21.67902756], [72.70513916, 21.6795826], [72.70485687, 21.67958069], [72.70485687, 21.67986107], [72.70458221, 21.67986107], [72.70458221, 21.68013954], [72.70318604, 21.68013954], [72.70318604, 21.68042183], [72.70263672, 21.68042183], [72.70263672, 21.68013954], [72.70207977, 21.68013954], [72.70207977, 21.67986107], [72.70181274, 21.67986107], [72.70181274, 21.68042183], [72.70041656, 21.68042183], [72.70041656, 21.68013954], [72.69985962, 21.68013954], [72.69985962, 21.68042183], [72.69930267, 21.68041611], [72.69930267, 21.68097115], [72.69902802, 21.68097115], [72.69902802, 21.68124962], [72.69847107, 21.68124962], [72.69847107, 21.68153191], [72.69790649, 21.68153191], [72.69790649, 21.68124962], [72.69708252, 21.68124962], [72.69708252, 21.68153191], [72.69625092, 21.68153191], [72.69625092, 21.68124962], [72.69568634, 21.68124962], [72.69568634, 21.68097115], [72.69458008, 21.68097115], [72.69458008, 21.68069458], [72.69403076, 21.6807003], [72.69403076, 21.68042183], [72.6920929, 21.68042183], [72.6920929, 21.68013954], [72.69124603, 21.68013954], [72.69124603, 21.67986107], [72.68902588, 21.67986107], [72.68902588, 21.67958069], [72.68763733, 21.67958069], [72.68763733, 21.67986107], [72.68653107, 21.67986107], [72.68653107, 21.67958069], [72.68624878, 21.6795826], [72.68624878, 21.67930603], [72.68402863, 21.67930603], [72.68402863, 21.6795826], [72.68125153, 21.67958069], [72.68125153, 21.67986107], [72.68068695, 21.67986107], [72.68068695, 21.68013954], [72.67930603, 21.68013954], [72.67930603, 21.68042183], [72.67874908, 21.68042183], [72.67874908, 21.6807003], [72.67736053, 21.68069458], [72.67736053, 21.68097115], [72.67708588, 21.68097115], [72.67708588, 21.68124962], [72.67679596, 21.68124962], [72.67679596, 21.68153191], [72.67597198, 21.68152809], [72.67597198, 21.68180466], [72.67430878, 21.68180466], [72.67430878, 21.68208122], [72.67375183, 21.68208122], [72.67375183, 21.6823616], [72.67292023, 21.6823597], [72.67292023, 21.68264008], [72.67180634, 21.68264008], [72.67180634, 21.68292046], [72.66958618, 21.68292046], [72.66958618, 21.68320084], [72.66707611, 21.68320084], [72.66707611, 21.68292046], [72.66625214, 21.68292046], [72.66625214, 21.68264008], [72.66555786, 21.68264008], [72.6654129, 21.68264008], [72.6654129, 21.6823597], [72.66430664, 21.6823616], [72.66430664, 21.68208122], [72.66402435, 21.68208122], [72.66402435, 21.68180466], [72.66374969, 21.68180466], [72.66374969, 21.68152809], [72.66348267, 21.68153191], [72.66348267, 21.68124962], [72.66319275, 21.68124962], [72.66319275, 21.68097115], [72.66208649, 21.68097115], [72.66208649, 21.68069458], [72.66179657, 21.6807003], [72.66179657, 21.68042946], [72.66152954, 21.68042183], [72.66152954, 21.68013954], [72.66124725, 21.68013954], [72.66124725, 21.67986107], [72.6609726, 21.67986107], [72.6609726, 21.67958069], [72.66069794, 21.6795826], [72.66069794, 21.67930603], [72.66014099, 21.67931175], [72.66014099, 21.67902946], [72.65957642, 21.67902946], [72.65957642, 21.67847061], [72.6590271, 21.67847252], [72.6590271, 21.67819405], [72.65736389, 21.67819405], [72.65736389, 21.67791748], [72.65651703, 21.67791939], [72.65651703, 21.67762947], [72.65625, 21.67764091], [72.65625, 21.67736053], [72.65597534, 21.67736053], [72.65597534, 21.67708397], [72.6554184, 21.67707825], [72.6554184, 21.67736053], [72.65291595, 21.67736053], [72.65291595, 21.67764091], [72.65235901, 21.67764091], [72.65235901, 21.67736053], [72.65208435, 21.67736053], [72.65208435, 21.67764091], [72.65180206, 21.67762947], [72.65180206, 21.67791939], [72.65097046, 21.67791748], [72.65097046, 21.67819405], [72.65013885, 21.67819405], [72.65013885, 21.67847252], [72.64624786, 21.67847061], [72.64624786, 21.67874908], [72.64597321, 21.67874908], [72.64597321, 21.67847061], [72.64485931, 21.67847061], [72.64485931, 21.67874908], [72.64125824, 21.67874908], [72.64125824, 21.67902946], [72.63791656, 21.67902946], [72.63791656, 21.67931175], [72.63680267, 21.67931175], [72.63680267, 21.67902946], [72.63540649, 21.67902946], [72.63540649, 21.67931175], [72.6340332, 21.67931175], [72.6340332, 21.67902946], [72.63236237, 21.67902946], [72.63236237, 21.67931175], [72.63097382, 21.67930603], [72.63097382, 21.6795826], [72.62930298, 21.67958069], [72.62930298, 21.67986107], [72.62486267, 21.67986107], [72.62486267, 21.68013954], [72.62458038, 21.68013954], [72.62458038, 21.67986107], [72.62430573, 21.67986107], [72.62431335, 21.68013954], [72.62180328, 21.68013954], [72.62180328, 21.68042183], [72.61624908, 21.68042183], [72.61624908, 21.68013954], [72.6159668, 21.68013954], [72.6159668, 21.68042183], [72.61541748, 21.68042183], [72.61541748, 21.6807003], [72.61486053, 21.68069458], [72.61486053, 21.68097115], [72.61374664, 21.68097115], [72.61374664, 21.68124962], [72.61292267, 21.68124962], [72.61292267, 21.68153191], [72.61235809, 21.68152809], [72.61235809, 21.68180466], [72.61180878, 21.68180466], [72.61180878, 21.68208122], [72.60945892, 21.68208122], [72.60847473, 21.68208122], [72.60847473, 21.68180466], [72.60819244, 21.68180466], [72.60819244, 21.68152809], [72.60597229, 21.68153191], [72.60597229, 21.68124962], [72.60375214, 21.68124962], [72.60375214, 21.68097115], [72.60319519, 21.68097115], [72.60320282, 21.68124962], [72.6029129, 21.68124962], [72.6029129, 21.68097115], [72.60236359, 21.68097115], [72.60236359, 21.68069458], [72.60124969, 21.68069458], [72.60124969, 21.68097115], [72.60097504, 21.68097115], [72.60098267, 21.68124962], [72.60069275, 21.68124962], [72.60069275, 21.68153191], [72.60041809, 21.68153191], [72.60041809, 21.68124962], [72.6001358, 21.68124962], [72.6001358, 21.68097115], [72.59958649, 21.68097115], [72.59958649, 21.68069458], [72.5984726, 21.6807003], [72.5984726, 21.68042183], [72.59792328, 21.68042183], [72.59792328, 21.6807003], [72.5973587, 21.6807003], [72.5973587, 21.68042183], [72.59680176, 21.68042183], [72.59680176, 21.68013954], [72.5965271, 21.68013954], [72.5965271, 21.67986107], [72.59596252, 21.67986107], [72.59596252, 21.67958069], [72.59486389, 21.6795826], [72.59486389, 21.67930603], [72.5945816, 21.67931175], [72.5945816, 21.67902946], [72.59430695, 21.67902946], [72.59430695, 21.67874908], [72.59401703, 21.67874908], [72.59401703, 21.67847061], [72.59375, 21.67847252], [72.59375, 21.67819405], [72.59319305, 21.67819405], [72.59319305, 21.67791748], [72.5929184, 21.67791939], [72.5929184, 21.67762947], [72.59263611, 21.67764091], [72.59263611, 21.67708397], [72.59236145, 21.67708397], [72.59236145, 21.6768055], [72.59179688, 21.67680931], [72.59179688, 21.67653084], [72.59152985, 21.67653084], [72.59152985, 21.67625046], [72.59069824, 21.67625046], [72.59069061, 21.67596817], [72.59041595, 21.67597198], [72.59041595, 21.67541885], [72.59014893, 21.67542076], [72.59014893, 21.67514038], [72.5890274, 21.67514038], [72.5890274, 21.67485809], [72.58875275, 21.67486191], [72.58875275, 21.67430687], [72.58763885, 21.67430687], [72.58763885, 21.67458344], [72.58680725, 21.67458344], [72.58680725, 21.6740284], [72.58651733, 21.6740303], [72.58651733, 21.67374992], [72.58625031, 21.67374992], [72.58625031, 21.67346954], [72.5854187, 21.67347145], [72.5854187, 21.67319679], [72.58513641, 21.67319679], [72.58513641, 21.67291451], [72.58402252, 21.67292023], [72.58402252, 21.67263985], [72.58374786, 21.67263985], [72.58374786, 21.67235947], [72.58347321, 21.67236137], [72.58347321, 21.6720829], [72.5826416, 21.6720829], [72.5826416, 21.67236137], [72.58235931, 21.67235947], [72.58235931, 21.67292023], [72.58207703, 21.67292023], [72.58207703, 21.67263985], [72.58152771, 21.67263985], [72.58152771, 21.67235947], [72.58125305, 21.67236137], [72.58125305, 21.67180443], [72.58097839, 21.67181969], [72.58097839, 21.67124939], [72.58069611, 21.67124939], [72.58069611, 21.67097092], [72.58013916, 21.67097473], [72.58013916, 21.67069244], [72.57930756, 21.67069244], [72.57930756, 21.67041588], [72.57736206, 21.67041969], [72.57736206, 21.67014122], [72.57681274, 21.67014122], [72.57681274, 21.66986084], [72.57624817, 21.66986084], [72.57624817, 21.66958046], [72.57597351, 21.66958237], [72.57597351, 21.6693058], [72.57569122, 21.66930962], [72.57569122, 21.66903114], [72.57541656, 21.66903114], [72.57541656, 21.6687603], [72.57485199, 21.6687603], [72.57485199, 21.66847038], [72.57430267, 21.66847229], [72.57430267, 21.66819382], [72.57347107, 21.66819382], [72.57347107, 21.66791725], [72.57263947, 21.66792107], [72.57263947, 21.66764069], [72.57235718, 21.66764069], [72.57235718, 21.66736031], [72.57208252, 21.66736031], [72.57208252, 21.66708183], [72.57180786, 21.66708374], [72.57180786, 21.66680527], [72.57096863, 21.6668129], [72.57096863, 21.66653252], [72.57041931, 21.66653252], [72.57041931, 21.66625023], [72.56958008, 21.66625023], [72.56958008, 21.66653252], [72.56903839, 21.66653252], [72.56903839, 21.66625023], [72.56846619, 21.66625023], [72.56846619, 21.66597176], [72.56791687, 21.66597176], [72.56791687, 21.66569519], [72.56735992, 21.66569519], [72.56735992, 21.66513824], [72.5670929, 21.66514015], [72.5670929, 21.66485977], [72.56597137, 21.66486168], [72.56597137, 21.66458321], [72.56541443, 21.66458321], [72.56541443, 21.66430473], [72.56513977, 21.66430473], [72.56513977, 21.66374969], [72.56485748, 21.66374969], [72.56485748, 21.66263008], [72.56458282, 21.66263962], [72.56458282, 21.66208267], [72.56485748, 21.66208267], [72.56485748, 21.66180611], [72.56402588, 21.66180992], [72.56402588, 21.66152954], [72.56375122, 21.66152954], [72.56375122, 21.66180992], [72.56291199, 21.66180992], [72.56291199, 21.66152954], [72.56263733, 21.66152954], [72.56263733, 21.65930939], [72.56291199, 21.65930939], [72.56291199, 21.65903091], [72.56263733, 21.65903091], [72.56263733, 21.65875053], [72.56180573, 21.65875053], [72.56180573, 21.65847206], [72.56153107, 21.65847015], [72.56153107, 21.65875053], [72.56069183, 21.65875053], [72.56069183, 21.66069412], [72.55986023, 21.66069412], [72.55986023, 21.66041756], [72.5595932, 21.66041946], [72.5595932, 21.66014099], [72.55930328, 21.66014099], [72.55930328, 21.65986061], [72.55902863, 21.65986061], [72.55902863, 21.65958977], [72.55874634, 21.65958977], [72.55874634, 21.65930939], [72.55652618, 21.65930939], [72.55652618, 21.65903091], [72.55374908, 21.65903091], [72.55374908, 21.65875053], [72.55152893, 21.65875053], [72.55152893, 21.65903091], [72.55042267, 21.65903091], [72.55042267, 21.65875053], [72.54985809, 21.65875053], [72.54985809, 21.65847015], [72.54736328, 21.65847015], [72.54736328, 21.65875053], [72.54680634, 21.65875053], [72.54680634, 21.65903091], [72.54651642, 21.65903091], [72.54651642, 21.65958977], [72.5459671, 21.65958977], [72.5459671, 21.65986061], [72.54429626, 21.65986061], [72.54429626, 21.66014099], [72.54319763, 21.66014099], [72.54319763, 21.66041946], [72.54264069, 21.66041756], [72.54264069, 21.6609726], [72.54207611, 21.66097069], [72.54207611, 21.66125107], [72.54180908, 21.66125107], [72.54180908, 21.66152954], [72.54152679, 21.66152954], [72.54152679, 21.66180992], [72.54125214, 21.66180992], [72.54125214, 21.66236115], [72.54069519, 21.66236115], [72.54069519, 21.66263962], [72.53985596, 21.66263008], [72.53985596, 21.66291809], [72.53930664, 21.66291618], [72.53930664, 21.66319466], [72.53902435, 21.66319466], [72.53902435, 21.66347313], [72.53874207, 21.66347122], [72.53874207, 21.66402817], [72.53819275, 21.66402817], [72.53819275, 21.66430473], [72.5376358, 21.66430473], [72.5376358, 21.66486168], [72.53736115, 21.66485977], [72.53736115, 21.66514015], [72.53679657, 21.66514015], [72.53679657, 21.66542244], [72.53652954, 21.66541672], [72.53652954, 21.66569519], [72.53624725, 21.66569138], [72.53624725, 21.6668129], [72.5359726, 21.6668129], [72.5359726, 21.66736031], [72.53569794, 21.66736031], [72.53569794, 21.66764069], [72.53541565, 21.66763878], [72.53541565, 21.66819382], [72.53514099, 21.66819382], [72.53514099, 21.66847229], [72.5348587, 21.66847038], [72.5348587, 21.6687603], [72.53457642, 21.6687603], [72.53457642, 21.66903114], [72.53430939, 21.66902733], [72.53430176, 21.66958237], [72.5340271, 21.66958046], [72.5340271, 21.67014122], [72.53375244, 21.67014122], [72.53375244, 21.67041969], [72.53347015, 21.67041588], [72.53347015, 21.67069244], [72.53291321, 21.67069054], [72.53291321, 21.67124939], [72.53235626, 21.67124939], [72.53235626, 21.67152977], [72.5320816, 21.67152786], [72.5320816, 21.67236137], [72.53235626, 21.67235947], [72.53235626, 21.67263985], [72.53263855, 21.67263794], [72.53263855, 21.67319679], [72.53291321, 21.67319679], [72.53291321, 21.67347145], [72.53263855, 21.67346954], [72.53263855, 21.67431068], [72.53235626, 21.67431068], [72.53235626, 21.67514038], [72.5320816, 21.67514038], [72.5320816, 21.67485809], [72.53152466, 21.67486191], [72.53152466, 21.67458344], [72.53125, 21.67458344], [72.53125, 21.67430687], [72.53097534, 21.67430687], [72.53097534, 21.67486191], [72.53069305, 21.67485809], [72.5306778, 21.67514038], [72.5304184, 21.67514038], [72.5304184, 21.67457008], [72.53013611, 21.67458344], [72.53013611, 21.67486191], [72.52958679, 21.67485809], [72.52958679, 21.67514038], [72.52929687, 21.67514038], [72.52929687, 21.67542076], [72.52902985, 21.67541885], [72.52902985, 21.6756897], [72.52874756, 21.67569542], [72.52874756, 21.67597198], [72.5284729, 21.67596817], [72.5284729, 21.67625046], [72.52819824, 21.67625046], [72.52819824, 21.67680931], [72.5276413, 21.6768055], [72.5276413, 21.67708397], [72.52707672, 21.67707825], [72.52707672, 21.67736053], [72.52680206, 21.67736053], [72.52680206, 21.67764091], [72.52625275, 21.67762947], [72.52625275, 21.67791939], [72.5256958, 21.67791748], [72.5256958, 21.67819405], [72.52540588, 21.67818832], [72.52540588, 21.67902946], [72.52513885, 21.67902946], [72.52513885, 21.67931175], [72.5248642, 21.67930603], [72.5248642, 21.6795826], [72.52458191, 21.67958069], [72.52458191, 21.67986107], [72.52430725, 21.67986107], [72.52430725, 21.68013954], [72.52402496, 21.68013954], [72.52402496, 21.68180466], [72.52374268, 21.68180275], [72.52375031, 21.68486023], [72.52348328, 21.68486023], [72.52348328, 21.68514061], [72.52375031, 21.6851387], [72.52375031, 21.6870842], [72.52401733, 21.68708038], [72.52401733, 21.68736076], [72.52319336, 21.68736076], [72.52319336, 21.68764114], [72.5229187, 21.68763924], [72.5229187, 21.68819427], [72.52263641, 21.68819046], [72.52263641, 21.68875122], [72.52236176, 21.68875122], [72.52236176, 21.68902969], [72.5220871, 21.68902969], [72.5220871, 21.68958282], [72.52180481, 21.68958282], [72.52180481, 21.6898613], [72.52124786, 21.68985748], [72.52124786, 21.69013977], [72.52097321, 21.69013977], [72.52097321, 21.69041824], [72.52041626, 21.69041634], [72.52041626, 21.69069481], [72.51958466, 21.69069481], [72.51958466, 21.69041634], [72.51403046, 21.69041824], [72.51403046, 21.69013977], [72.51040649, 21.69013977], [72.51040649, 21.68985748], [72.51013947, 21.6898613], [72.51013947, 21.68958282], [72.50875092, 21.68958282], [72.50875092, 21.6898613], [72.50818634, 21.68985748], [72.50818634, 21.69041824], [72.50791931, 21.69041634], [72.50791931, 21.69180489], [72.50819397, 21.69180489], [72.50819397, 21.69236183], [72.50874329, 21.69236183], [72.50874329, 21.6926403], [72.50985718, 21.6926403], [72.50985718, 21.69236183], [72.51013947, 21.69236183], [72.51013947, 21.69208336], [72.51041412, 21.69208336], [72.51041412, 21.69180489], [72.51069641, 21.69180489], [72.51069641, 21.69152832], [72.52180481, 21.69152832], [72.52180481, 21.69180489], [72.5220871, 21.69180489], [72.5220871, 21.69236183], [72.52236176, 21.69236183], [72.52236176, 21.69320107], [72.52263641, 21.69320107], [72.52263641, 21.69403267], [72.52236176, 21.69403267], [72.52236176, 21.69431114], [72.52263641, 21.69431114], [72.52263641, 21.69486046], [72.5229187, 21.69486046], [72.5229187, 21.69569969], [72.52319336, 21.69569206], [72.52319336, 21.69597244], [72.52263641, 21.69597054], [72.52263641, 21.69625092], [72.52236176, 21.69625092], [72.52236176, 21.69652939], [72.5220871, 21.69652939], [72.5220871, 21.69680977], [72.52180481, 21.69680405], [72.52180481, 21.69708252], [72.52124786, 21.69708252], [72.52124786, 21.69680405], [72.52097321, 21.69680405], [72.52097321, 21.69819641], [72.52124786, 21.69819641], [72.52124786, 21.69847488], [72.52097321, 21.69847488], [72.52097321, 21.69874954], [72.52068329, 21.69874001], [72.52068329, 21.69902992], [72.52041626, 21.69902992], [72.52041626, 21.70014], [72.51902771, 21.70014], [72.51902771, 21.70042038], [72.51875305, 21.70042038], [72.51875305, 21.70070076], [72.50958252, 21.70070076], [72.50958252, 21.70042038], [72.50930786, 21.70042038], [72.50930786, 21.70014], [72.50958252, 21.70014], [72.50958252, 21.6993103], [72.50930786, 21.6993103], [72.50930786, 21.69902992], [72.5090332, 21.69902992], [72.5090332, 21.69874001], [72.50791931, 21.69874001], [72.50791931, 21.69902992], [72.50736237, 21.69902992], [72.50736237, 21.70125008], [72.50763702, 21.70125008], [72.50763702, 21.70153046], [72.50791931, 21.70152855], [72.50791931, 21.70180511], [72.51847076, 21.70180511], [72.51847076, 21.70208359], [72.51875305, 21.70207977], [72.51875305, 21.70292091], [72.51902771, 21.7029171], [72.51902771, 21.70319366], [72.51930237, 21.70318985], [72.51930237, 21.70375061], [72.51957703, 21.70375061], [72.51957703, 21.70402908], [72.51985931, 21.70402718], [72.51985931, 21.70458412], [72.51957703, 21.7045784], [72.51957703, 21.70513916], [72.51875305, 21.70513916], [72.51875305, 21.70541954], [72.51847076, 21.70541763], [72.51847076, 21.7056942], [72.51819611, 21.7056942], [72.51819611, 21.70597267], [72.51790619, 21.70597076], [72.51790619, 21.7068119], [72.51763916, 21.7068119], [72.51763916, 21.70763969], [72.51790619, 21.70763969], [72.51790619, 21.71042061], [72.51763916, 21.71042061], [72.51763916, 21.71264076], [72.51790619, 21.71264076], [72.51790619, 21.71292114], [72.51763916, 21.71291542], [72.51763916, 21.71347237], [72.51791382, 21.71347237], [72.51791382, 21.71458244], [72.51875305, 21.71458244], [72.51875305, 21.7140255], [72.51902771, 21.71403122], [72.51902771, 21.71347046], [72.51930237, 21.71347237], [72.51930237, 21.7131958], [72.51958466, 21.7131958], [72.51958466, 21.71125031], [72.51930237, 21.71125031], [72.51930237, 21.71096992], [72.51958466, 21.71097183], [72.51958466, 21.71069336], [72.51930237, 21.71070099], [72.51930237, 21.70957947], [72.51902771, 21.70958328], [72.51902771, 21.70874977], [72.51930237, 21.70874977], [72.51930237, 21.70792961], [72.51957703, 21.70792961], [72.51957703, 21.70763969], [72.51985931, 21.70763969], [72.51985931, 21.70736122], [72.5201416, 21.70736122], [72.5201416, 21.70708275], [72.52069092, 21.70708275], [72.52069092, 21.70652771], [72.52153015, 21.70652771], [72.52153015, 21.7084713], [72.52179718, 21.70846939], [72.52179718, 21.70903015], [72.52153015, 21.70902824], [72.52153015, 21.70930481], [72.52124786, 21.70930481], [72.52124786, 21.70958328], [72.52097321, 21.70957947], [72.52097321, 21.71014023], [72.52068329, 21.71014023], [72.52068329, 21.71070099], [72.52041626, 21.71070099], [72.52041626, 21.71125031], [72.5201416, 21.71125031], [72.5201416, 21.71153069], [72.51985931, 21.71153069], [72.51985931, 21.71181107], [72.5201416, 21.71180344], [72.5201416, 21.71208572], [72.52041626, 21.71208], [72.52041626, 21.71236038], [72.52069092, 21.71236038], [72.52069092, 21.71347237], [72.52041626, 21.71347237], [72.52041626, 21.71375084], [72.52068329, 21.7137394], [72.52068329, 21.71403122], [72.52097321, 21.7140255], [72.52097321, 21.71458244], [72.52153015, 21.71458054], [72.52153015, 21.71486092], [72.52179718, 21.71486092], [72.52179718, 21.71624947], [72.52236176, 21.71624947], [72.52236176, 21.71652985], [72.52263641, 21.71652985], [72.52263641, 21.71680832], [72.5229187, 21.71680641], [72.5229187, 21.71708298], [72.52319336, 21.71708298], [72.52319336, 21.71736145], [72.52348328, 21.71735954], [72.52348328, 21.71763992], [72.52401733, 21.71763992], [72.52401733, 21.7179184], [72.52430725, 21.7179184], [72.52430725, 21.71820259], [72.52458191, 21.71819496], [72.52458191, 21.71847153], [72.52485657, 21.71847153], [72.52485657, 21.71875191], [72.52513885, 21.71875191], [72.52513885, 21.71903038], [72.52541351, 21.71902847], [72.52541351, 21.71958351], [72.5256958, 21.7195816], [72.5256958, 21.72014046], [72.52597046, 21.72014046], [72.52597046, 21.72042274], [72.52625275, 21.72041702], [72.52625275, 21.72097015], [72.5265274, 21.72097015], [72.5265274, 21.72125053], [72.52680206, 21.72125053], [72.52680206, 21.72153282], [72.52708435, 21.7215271], [72.52708435, 21.72208214], [72.52735901, 21.72208214], [72.52735901, 21.7234726], [72.5276413, 21.72347069], [72.5276413, 21.72430992], [72.52791595, 21.72430992], [72.52791595, 21.72486115], [72.52819824, 21.72486115], [72.52819824, 21.72513962], [72.5284729, 21.72513962], [72.5284729, 21.72569656], [72.52874756, 21.7256794], [72.52874756, 21.72624969], [72.5293045, 21.72624969], [72.5293045, 21.72736168], [72.52958679, 21.72735977], [72.52958679, 21.72792053], [72.52986145, 21.72791862], [72.52986145, 21.72847176], [72.53013611, 21.72846985], [72.53013611, 21.72875023], [72.53069305, 21.72875023], [72.53069305, 21.72903061], [72.53098297, 21.72903061], [72.53098297, 21.72930908], [72.53125, 21.72930908], [72.53125, 21.73014069], [72.53151703, 21.73014069], [72.53151703, 21.73041916], [72.53180695, 21.73041725], [72.53180695, 21.73069382], [72.5320816, 21.7306881], [72.5320816, 21.73125076], [72.53235626, 21.73125076], [72.53235626, 21.73152924], [72.53263855, 21.73152924], [72.53263855, 21.73181152], [72.53291321, 21.7318058], [72.53291321, 21.73208237], [72.53347015, 21.73207855], [72.53347015, 21.73236084], [72.53375244, 21.73236084], [72.53375244, 21.73263931], [72.53430176, 21.73263931], [72.53430939, 21.73291969], [72.5348587, 21.73291588], [72.5348587, 21.73319435], [72.53514099, 21.73318863], [72.53514099, 21.73374939], [72.53542328, 21.73374939], [72.53542328, 21.73402977], [72.53569794, 21.73402786], [72.53569794, 21.7345829], [72.5359726, 21.7345829], [72.5359726, 21.73486137], [72.53736115, 21.73485184], [72.53736115, 21.73513985], [72.53901672, 21.73513985], [72.53901672, 21.73542023], [72.53930664, 21.73541641], [72.53930664, 21.73569489], [72.5404129, 21.73569107], [72.5404129, 21.73931122], [72.54069519, 21.7393074], [72.54069519, 21.73958588], [72.54096985, 21.73958015], [72.54096985, 21.73986053], [72.54125214, 21.73986053], [72.54125214, 21.74014091], [72.54152679, 21.74014091], [72.54152679, 21.74041939], [72.54180908, 21.74041748], [72.54180908, 21.74069595], [72.54207611, 21.74069023], [72.54207611, 21.74125099], [72.54264069, 21.74125099], [72.54264069, 21.74180984], [72.54291534, 21.74180794], [72.54291534, 21.74236107], [72.54319763, 21.74236107], [72.54319763, 21.74291992], [72.54347229, 21.74291992], [72.54347229, 21.74403954], [72.54319763, 21.74402809], [72.54319763, 21.7448616], [72.54264069, 21.7448597], [72.54264069, 21.74570274], [72.54291534, 21.74569511], [72.54291534, 21.74708366], [72.54319763, 21.74708176], [72.54319763, 21.74736023], [72.54347229, 21.74736023], [72.54347229, 21.7479229], [72.54374695, 21.74791718], [72.54374695, 21.74847221], [72.54402924, 21.74847031], [72.54402924, 21.74930954], [72.54374695, 21.74930573], [72.54374695, 21.74958229], [72.54347229, 21.74958038], [72.54347229, 21.75014114], [72.54319763, 21.75013924], [72.54319763, 21.75069237], [72.54291534, 21.75069237], [72.54291534, 21.75458336], [72.54319763, 21.75457954], [72.54319763, 21.7551403], [72.54347229, 21.7551403], [72.54347229, 21.75597763], [72.54402924, 21.75597763], [72.54402924, 21.75736046], [72.54430389, 21.75736046], [72.54430389, 21.75847244], [72.54402924, 21.75847054], [72.54402924, 21.75875092], [72.54347229, 21.75875092], [72.54347229, 21.75931168], [72.54319763, 21.75931168], [72.54319763, 21.76042175], [72.54292297, 21.76042175], [72.54292297, 21.76152992], [72.54347229, 21.76152802], [72.54347229, 21.76178932], [72.5451355, 21.76180649], [72.5451355, 21.76208115], [72.54541779, 21.76208115], [72.54541779, 21.76236153], [72.54569244, 21.76235962], [72.54569244, 21.76264], [72.5459671, 21.76264], [72.5459671, 21.76375008], [72.54624939, 21.76375008], [72.54624939, 21.76625061], [72.54651642, 21.76625061], [72.54651642, 21.76653099], [72.54708099, 21.76653099], [72.54708099, 21.76680946], [72.54736328, 21.76680946], [72.54736328, 21.76736069], [72.54763794, 21.76736069], [72.54763794, 21.76791954], [72.54736328, 21.76791763], [72.54736328, 21.76847267], [72.54708099, 21.76847076], [72.54708099, 21.76875114], [72.54736328, 21.76875114], [72.54736328, 21.76930809], [72.54763794, 21.76930809], [72.54763794, 21.76986122], [72.5479126, 21.76986122], [72.5479126, 21.77041817], [72.54819489, 21.77041626], [72.54819489, 21.77236176], [72.54846954, 21.77236176], [72.54846954, 21.77264023], [72.54875183, 21.77264023], [72.54875183, 21.7732029], [72.54902649, 21.77319527], [72.54902649, 21.77347183], [72.54930878, 21.77347183], [72.54930878, 21.77514076], [72.54957581, 21.77514076], [72.54957581, 21.77791977], [72.54985809, 21.77791977], [72.54985809, 21.77874947], [72.55014038, 21.77874947], [72.55014038, 21.77931023], [72.55042267, 21.77931023], [72.55042267, 21.78181076], [72.55069733, 21.78180695], [72.55069733, 21.78319359], [72.55097198, 21.78318977], [72.55097198, 21.78624916], [72.55124664, 21.78624916], [72.55124664, 21.78736115], [72.55152893, 21.78736115], [72.55152893, 21.78792191], [72.55179596, 21.78792191], [72.55179596, 21.79014015], [72.55208588, 21.79014015], [72.55208588, 21.79236031], [72.55236053, 21.79236031], [72.55236053, 21.79292107], [72.55263519, 21.79291534], [72.55263519, 21.79347229], [72.55291748, 21.79347038], [72.55291748, 21.79430962], [72.55319214, 21.79430771], [72.55319214, 21.79458237], [72.5534668, 21.79458046], [72.5534668, 21.79515076], [72.55374908, 21.79513931], [72.55374908, 21.79597282], [72.554039, 21.79597092], [72.554039, 21.79652977], [72.55430603, 21.79652977], [72.55430603, 21.7970829], [72.55458069, 21.79707909], [72.55458069, 21.79763985], [72.55486298, 21.79763985], [72.55486298, 21.79847145], [72.55513763, 21.79846764], [72.55513763, 21.7990303], [72.55541992, 21.7990284], [72.55541992, 21.79958344], [72.55568695, 21.79958153], [72.55568695, 21.80014038], [72.55596924, 21.80013847], [72.55596924, 21.80069351], [72.55625153, 21.8006916], [72.55625153, 21.80153275], [72.55652618, 21.80152702], [72.55652618, 21.80208206], [72.55680847, 21.80208015], [72.55680847, 21.80236053], [72.55708313, 21.80236053], [72.55708313, 21.80264282], [72.55735779, 21.80263901], [72.55735779, 21.80319214], [72.55764008, 21.80319214], [72.55764008, 21.80347252], [72.5579071, 21.80347061], [72.5579071, 21.80375099], [72.55819702, 21.80375099], [72.55819702, 21.80402946], [72.55847168, 21.80402946], [72.55847168, 21.80431938], [72.55874634, 21.80430412], [72.55874634, 21.8045826], [72.55902863, 21.80458069], [72.55902863, 21.80513954], [72.55930328, 21.80513954], [72.55930328, 21.80541992], [72.55958557, 21.8054142], [72.55958557, 21.80569649], [72.55986023, 21.80569649], [72.55986023, 21.80597305], [72.56014252, 21.80597115], [72.56014252, 21.80653], [72.56041718, 21.80653], [72.56041718, 21.80709076], [72.56069183, 21.80709076], [72.56069183, 21.80764008], [72.56096649, 21.80764008], [72.56096649, 21.80820084], [72.56124878, 21.80820084], [72.56124878, 21.80875015], [72.56153107, 21.80875015], [72.56153107, 21.80931091], [72.56180573, 21.80930519], [72.56180573, 21.80958366], [72.56208038, 21.80958366], [72.56208038, 21.8101387], [72.56236267, 21.81013107], [72.56236267, 21.81041908], [72.56263733, 21.81041718], [72.56263733, 21.81097221], [72.56291199, 21.8109684], [72.56291199, 21.81152916], [72.56318665, 21.81152916], [72.56318665, 21.81180954], [72.56346893, 21.81180573], [72.56346893, 21.8120842], [72.56375122, 21.81207848], [72.56375122, 21.81236076], [72.56402588, 21.81236076], [72.56402588, 21.81291962], [72.56430817, 21.8129158], [72.56430817, 21.81347275], [72.56458282, 21.81347275], [72.56458282, 21.81375122], [72.56485748, 21.81375122], [72.56485748, 21.81402969], [72.56513977, 21.81402779], [72.56513977, 21.81458282], [72.5654068, 21.81458282], [72.5654068, 21.81513977], [72.56569672, 21.81513977], [72.56569672, 21.81542015], [72.56597137, 21.81541634], [72.56597137, 21.81597137], [72.56624603, 21.81596947], [72.56624603, 21.81625938], [72.56652832, 21.81624985], [72.56652832, 21.81680489], [72.56680298, 21.81680489], [72.56680298, 21.81708336], [72.5670929, 21.81707954], [72.5670929, 21.8176403], [72.56735992, 21.8176403], [72.56735992, 21.81820107], [72.56708527, 21.81819344], [72.56708527, 21.81847191], [72.56652832, 21.81847], [72.56652832, 21.81875038], [72.56624603, 21.81875038], [72.56624603, 21.81903076], [72.565979, 21.81903076], [72.565979, 21.82014084], [72.56569672, 21.82014084], [72.56569672, 21.82152939], [72.565979, 21.82152939], [72.565979, 21.82180977], [72.56625366, 21.82180786], [72.56625366, 21.82208252], [72.56652832, 21.82207108], [72.56652832, 21.82263947], [72.5670929, 21.82263947], [72.5670929, 21.82291985], [72.56764221, 21.82291794], [72.56764221, 21.8231945], [72.56791687, 21.8231945], [72.56791687, 21.82347298], [72.56819153, 21.82347107], [72.56819153, 21.82374954], [72.56846619, 21.82374954], [72.56846619, 21.82402992], [72.56986237, 21.82402992], [72.56986237, 21.8243084], [72.56930542, 21.82430649], [72.56930542, 21.82458305], [72.56874847, 21.82458305], [72.56874847, 21.82486153], [72.56819153, 21.82485962], [72.56819153, 21.82513809], [72.56791687, 21.82513809], [72.56791687, 21.82522011], [72.56791687, 21.82542038], [72.56735992, 21.82542038], [72.56735992, 21.82570267], [72.56680298, 21.82569504], [72.56680298, 21.8259716], [72.56624603, 21.8259716], [72.56624603, 21.82625008], [72.56569672, 21.82625008], [72.56569672, 21.82653046], [72.5654068, 21.82653046], [72.5654068, 21.82681274], [72.56485748, 21.82680511], [72.56485748, 21.82708359], [72.56430817, 21.82708359], [72.56430817, 21.82736015], [72.56375122, 21.82736015], [72.56375122, 21.82764053], [72.56346893, 21.82764053], [72.56346893, 21.82792282], [72.56291199, 21.82792282], [72.56291199, 21.82819939], [72.56319427, 21.82819366], [72.56319427, 21.82847214], [72.56291199, 21.82847023], [72.56291199, 21.82875061], [72.56263733, 21.82875061], [72.56263733, 21.8290329], [72.56208038, 21.8290329], [72.56208038, 21.82930946], [72.56180573, 21.82930565], [72.56180573, 21.82958221], [72.56124878, 21.82958031], [72.56124878, 21.82986069], [72.56096649, 21.82986069], [72.56096649, 21.83014107], [72.56041718, 21.83014107], [72.56041718, 21.83041954], [72.56014252, 21.83041763], [72.56014252, 21.83069229], [72.55958557, 21.83069229], [72.55958557, 21.83097267], [72.55930328, 21.83097076], [72.55930328, 21.83126068], [72.55874634, 21.83126068], [72.55874634, 21.83152962], [72.55847168, 21.83152962], [72.55847168, 21.83181], [72.55791473, 21.83180428], [72.55791473, 21.83208275], [72.55764008, 21.83208084], [72.55764008, 21.83236122], [72.55708313, 21.83236122], [72.55708313, 21.83263969], [72.55652618, 21.83263969], [72.55652618, 21.83292007], [72.55625153, 21.83291435], [72.55625153, 21.83319664], [72.55569458, 21.83319664], [72.55569458, 21.8334713], [72.55541992, 21.83346939], [72.55541992, 21.83374977], [72.55486298, 21.83374977], [72.55486298, 21.83403015], [72.55458069, 21.83402634], [72.55458069, 21.83430672], [72.55403137, 21.83430672], [72.55403137, 21.83458328], [72.55374908, 21.83458328], [72.55374908, 21.83486176], [72.55319214, 21.83485985], [72.55319214, 21.83514023], [72.55291748, 21.83514023], [72.55291748, 21.83542061], [72.55236053, 21.83542061], [72.55236053, 21.83569908], [72.55208588, 21.83569527], [72.55208588, 21.83597183], [72.55152893, 21.83596992], [72.55152893, 21.83625031], [72.55097198, 21.83625031], [72.55097198, 21.83653069], [72.55069733, 21.83653069], [72.55069733, 21.83680916], [72.55014038, 21.83680534], [72.55014038, 21.83708382], [72.54985809, 21.83707047], [72.54985809, 21.83736038], [72.54930878, 21.83736038], [72.54930878, 21.83764076], [72.54902649, 21.83764076], [72.54902649, 21.83791924], [72.54846954, 21.83791733], [72.54846954, 21.83819389], [72.54819489, 21.83819389], [72.54819489, 21.83847237], [72.54763794, 21.83847046], [72.54763794, 21.83875084], [72.54736328, 21.83875084], [72.54736328, 21.83902931], [72.54680634, 21.83902931], [72.54680634, 21.8393116], [72.54652405, 21.83930588], [72.54652405, 21.83958244], [72.5459671, 21.83957863], [72.5459671, 21.83986092], [72.54569244, 21.83986092], [72.54569244, 21.84013939], [72.54514313, 21.84013939], [72.54514313, 21.84041977], [72.54458618, 21.84041595], [72.54458618, 21.84069443], [72.54430389, 21.84069443], [72.54430389, 21.8409729], [72.54374695, 21.8409729], [72.54374695, 21.84124947], [72.54347229, 21.84124947], [72.54347229, 21.84152985], [72.54292297, 21.84152985], [72.54292297, 21.84181023], [72.54264069, 21.84180641], [72.54264069, 21.84208107], [72.54208374, 21.84208107], [72.54208374, 21.84236145], [72.54180908, 21.84235954], [72.54180908, 21.84263992], [72.54125214, 21.84263992], [72.54125214, 21.8429203], [72.54096985, 21.8429203], [72.54096985, 21.84320068], [72.5404129, 21.84319305], [72.5404129, 21.84347153], [72.54013824, 21.84346962], [72.54013824, 21.84375], [72.5395813, 21.84375], [72.5395813, 21.84403038], [72.53930664, 21.84403038], [72.53930664, 21.84431076], [72.53874969, 21.84430313], [72.53874969, 21.84458351], [72.53819275, 21.84458351], [72.53819275, 21.84486198], [72.53791809, 21.84486008], [72.53791809, 21.84514046], [72.53736115, 21.84514046], [72.53736115, 21.84542084], [72.53708649, 21.84541512], [72.53708649, 21.84569359], [72.53652954, 21.84569359], [72.53652954, 21.84597206], [72.53624725, 21.84597206], [72.53624725, 21.84625053], [72.53569794, 21.846241], [72.53569794, 21.84653091], [72.53542328, 21.84653091], [72.53542328, 21.84680939], [72.5348587, 21.84680748], [72.5348587, 21.84708595], [72.53457642, 21.84708023], [72.53457642, 21.84736061], [72.5340271, 21.84736061], [72.5340271, 21.84764099], [72.5276413, 21.84764099], [72.5276413, 21.84791946], [72.52708435, 21.84791756], [72.52708435, 21.84819412], [72.52625275, 21.84819412], [72.52625275, 21.8484726], [72.5256958, 21.84847069], [72.5256958, 21.84875107], [72.52513885, 21.84875107], [72.52513885, 21.84902954], [72.52458191, 21.84902954], [72.52458191, 21.84930611], [72.52375031, 21.84930611], [72.52375031, 21.84958267], [72.52319336, 21.84958076], [72.52319336, 21.84986115], [72.52374268, 21.84986115], [72.52375031, 21.85013962], [72.52348328, 21.85013962], [72.52348328, 21.85041809], [72.5229187, 21.85041618], [72.5229187, 21.85069466], [72.52263641, 21.85069466], [72.52263641, 21.85097313], [72.5229187, 21.85097122], [72.5229187, 21.85152817], [72.52319336, 21.85152817], [72.52319336, 21.85208321], [72.52347565, 21.85208321], [72.52347565, 21.85236168], [72.52374268, 21.85236168], [72.52374268, 21.85264015], [72.52403259, 21.85264015], [72.52403259, 21.85292244], [72.52430725, 21.85291672], [72.52430725, 21.85347176], [72.52374268, 21.85347176], [72.52375031, 21.85375023], [72.52348328, 21.85375023], [72.52348328, 21.8543129], [72.52374268, 21.8543129], [72.52374268, 21.85486031], [72.52403259, 21.85486031], [72.52403259, 21.8554306], [72.52430725, 21.85541725], [72.52430725, 21.85597229], [72.52458191, 21.85597038], [72.52458191, 21.85653114], [72.5248642, 21.85652733], [72.5248642, 21.85708237], [72.52513885, 21.85708046], [72.52513885, 21.85764122], [72.52540588, 21.85764122], [72.52540588, 21.85791969], [72.52430725, 21.85791969], [72.52430725, 21.85764122], [72.52374268, 21.85764122], [72.52374268, 21.85736084], [72.52347565, 21.85736084], [72.52347565, 21.85708237], [72.5229187, 21.85708237], [72.5229187, 21.8568058], [72.52236176, 21.85680962], [72.52236176, 21.85653114], [72.5220871, 21.85653114], [72.5220871, 21.85680962], [72.52180481, 21.8568058], [72.52180481, 21.85708237], [72.52153015, 21.85708046], [72.52153015, 21.85764122], [72.52124786, 21.85764122], [72.52124786, 21.85791969], [72.52097321, 21.85791588], [72.52097321, 21.85819435], [72.51902771, 21.85819435], [72.51902771, 21.85763931], [72.51875305, 21.85764122], [72.51875305, 21.85708046], [72.51847076, 21.85708237], [72.51847076, 21.8568058], [72.51819611, 21.8568058], [72.51819611, 21.85708237], [72.51790619, 21.85708046], [72.51790619, 21.85736084], [72.51763916, 21.85736084], [72.51763916, 21.85791969], [72.5173645, 21.85791588], [72.5173645, 21.85847282], [72.51708221, 21.85847282], [72.51708221, 21.8595829], [72.51680756, 21.8595829], [72.51680756, 21.86124992], [72.5165329, 21.86124039], [72.5165329, 21.86264038], [72.51902771, 21.86264038], [72.51902771, 21.86292076], [72.51875305, 21.86291885], [72.51875305, 21.86847115], [72.51847076, 21.86847115], [72.51847076, 21.87403107], [72.51819611, 21.87403107], [72.51819611, 21.87486076], [72.51680756, 21.87486076], [72.51680756, 21.87458038], [72.51625061, 21.87458038], [72.51625061, 21.87486076], [72.51597595, 21.87486076], [72.51597595, 21.87680817], [72.51625061, 21.87680817], [72.51625061, 21.87791824], [72.5165329, 21.87791824], [72.5165329, 21.87903023], [72.51625061, 21.87902832], [72.51625061, 21.87958336], [72.51597595, 21.87958336], [72.51597595, 21.88097191], [72.51568604, 21.88097191], [72.51568604, 21.88237], [72.51541901, 21.88237], [72.51541901, 21.88375092], [72.51513672, 21.88375092], [72.51513672, 21.88541412], [72.51486206, 21.88541412], [72.51486206, 21.88597488], [72.51457977, 21.88597107], [72.51457977, 21.88820076], [72.51513672, 21.88819695], [72.51513672, 21.8884716], [72.51680756, 21.8884697], [72.51680756, 21.88931084], [72.51625061, 21.88930511], [72.51625061, 21.88958359], [72.51597595, 21.88958359], [72.51597595, 21.88986206], [72.51568604, 21.88985825], [72.51568604, 21.89014053], [72.51541901, 21.89014053], [72.51541901, 21.89042091], [72.51513672, 21.8904171], [72.51513672, 21.89069366], [72.51486206, 21.89069366], [72.51486206, 21.89097214], [72.51457977, 21.89096832], [72.51457977, 21.89125061], [72.51431274, 21.89125061], [72.51431274, 21.89154053], [72.51374817, 21.89154053], [72.51374817, 21.89180946], [72.51347351, 21.89180565], [72.51347351, 21.89208412], [72.51319122, 21.8920784], [72.51319122, 21.89236069], [72.51291656, 21.89236069], [72.51291656, 21.89263916], [72.51264191, 21.89263916], [72.51264191, 21.89291954], [72.51208496, 21.89291763], [72.51208496, 21.89347267], [72.51180267, 21.89347267], [72.51180267, 21.89402962], [72.51152802, 21.89402962], [72.51152802, 21.8943119], [72.51097107, 21.89430618], [72.51097107, 21.89458275], [72.51069641, 21.89458275], [72.51069641, 21.89486122], [72.51040649, 21.89486122], [72.51040649, 21.89542007], [72.51013947, 21.89541626], [72.51013947, 21.89569473], [72.50958252, 21.89569473], [72.50958252, 21.8959713], [72.50930786, 21.89596939], [72.50930786, 21.89624977], [72.50902557, 21.89624977], [72.50902557, 21.89680481], [72.50875092, 21.89680481], [72.50875092, 21.89708328], [72.50846863, 21.89708328], [72.50846863, 21.89736176], [72.50818634, 21.89735031], [72.50818634, 21.89764023], [72.50791931, 21.89764023], [72.50791931, 21.89792061], [72.50763702, 21.89791679], [72.50763702, 21.90041542], [72.50736237, 21.90041542], [72.50736237, 21.90069389], [72.50708008, 21.90069008], [72.50708008, 21.90125084], [72.50680542, 21.90125084], [72.50680542, 21.90263939], [72.50708008, 21.90263939], [72.50708008, 21.90319443], [72.50736237, 21.90319443], [72.50736237, 21.90458298], [72.50708008, 21.90458298], [72.50708008, 21.90486145], [72.50681305, 21.90485764], [72.50681305, 21.90513992], [72.50653076, 21.90513992], [72.50653076, 21.90570259], [72.50624847, 21.90570259], [72.50624847, 21.90681267], [72.50597382, 21.90680504], [72.50597382, 21.90736008], [72.50569153, 21.90736008], [72.50569153, 21.90819359], [72.50541687, 21.90819168], [72.50541687, 21.90903282], [72.50514221, 21.9090271], [72.50514221, 21.90958214], [72.50485992, 21.90958214], [72.50485992, 21.91236115], [72.50514221, 21.9123497], [72.50514221, 21.91263962], [72.50541687, 21.91263962], [72.50541687, 21.91319656], [72.50569153, 21.91319656], [72.50569153, 21.91374969], [72.50596619, 21.91374969], [72.50596619, 21.91625023], [72.50624847, 21.91625023], [72.50624847, 21.92152786], [72.50596619, 21.92152023], [72.50596619, 21.92514038], [72.50569916, 21.92514038], [72.50569916, 21.92542076], [72.50485992, 21.92541695], [72.50485992, 21.9256897], [72.50458527, 21.92569351], [72.50458527, 21.92847252], [72.50430298, 21.92847061], [72.50430298, 21.92930984], [72.50402832, 21.92930984], [72.50402832, 21.93124962], [72.50375366, 21.93124962], [72.50375366, 21.93180466], [72.50347137, 21.93180084], [72.50347137, 21.93264008], [72.50319672, 21.93263817], [72.50319672, 21.93347168], [72.50291443, 21.93347168], [72.50291443, 21.93458366], [72.50263977, 21.93458176], [72.50263977, 21.93514061], [72.50235748, 21.93514061], [72.50235748, 21.93680954], [72.50291443, 21.93680573], [72.50291443, 21.93708229], [72.50319672, 21.93708038], [72.50319672, 21.93736076], [72.5029068, 21.93736076], [72.5029068, 21.93764114], [72.50319672, 21.93764114], [72.50319672, 21.93875122], [72.5029068, 21.93875122], [72.5029068, 21.93902969], [72.50319672, 21.93902969], [72.50319672, 21.94042015], [72.50291443, 21.94041443], [72.50291443, 21.94069672], [72.50263977, 21.94069672], [72.50263977, 21.94097137], [72.50235748, 21.94096947], [72.50235748, 21.94153023], [72.50208282, 21.94152641], [72.50208282, 21.94180679], [72.50235748, 21.94180679], [72.50235748, 21.94847107], [72.50263977, 21.94846153], [72.50263977, 21.95070076], [72.50291443, 21.95069313], [72.50291443, 21.95208359], [72.50263977, 21.95208359], [72.50263977, 21.95347214], [72.50235748, 21.95347023], [72.50235748, 21.95514107], [72.50263977, 21.95513725], [72.50263977, 21.95597267], [72.5029068, 21.95597076], [72.5029068, 21.95903015], [72.50319672, 21.95903015], [72.50319672, 21.96042252], [72.50347137, 21.96041679], [72.50347137, 21.96208382], [72.50319672, 21.96208191], [72.50319672, 21.96264076], [72.50347137, 21.96264076], [72.50347137, 21.96375084], [72.50374603, 21.96375084], [72.50374603, 21.96403122], [72.50402832, 21.9640274], [72.50402832, 21.96569443], [72.50430298, 21.96569061], [72.50430298, 21.96624947], [72.50402832, 21.96624947], [72.50402832, 21.96681976], [72.50430298, 21.9668045], [72.50430298, 21.96736145], [72.5045929, 21.96735954], [72.5045929, 21.9679203], [72.50485992, 21.9679184], [72.50485992, 21.96847153], [72.5045929, 21.96846962], [72.5045929, 21.97291946], [72.50485992, 21.97291756], [72.50485992, 21.9734726], [72.50458527, 21.9734726], [72.50458527, 21.97458267], [72.50485992, 21.97458267], [72.50485992, 21.97486115], [72.5045929, 21.97486115], [72.5045929, 21.97653008], [72.50485992, 21.97652817], [72.50485992, 21.97708321], [72.50514221, 21.97708321], [72.50514221, 21.97736168], [72.50485992, 21.97735977], [72.50485992, 21.97931099], [72.50514221, 21.97931099], [72.50514221, 21.97986031], [72.50541687, 21.97986031], [72.50541687, 21.98042107], [72.50514221, 21.98041534], [72.50514221, 21.98069382], [72.50485992, 21.98069382], [72.50485992, 21.98097229], [72.50514221, 21.98097038], [72.50514221, 21.98125076], [72.50541687, 21.98125076], [72.50541687, 21.98181915], [72.50569916, 21.98181915], [72.50569916, 21.98264122], [72.50541687, 21.98264122], [72.50541687, 21.98291969], [72.50569153, 21.98291779], [72.50569153, 21.98347282], [72.50596619, 21.98347092], [72.50596619, 21.98430824], [72.50624847, 21.98430634], [72.50624847, 21.98569489], [72.50596619, 21.98568916], [72.50596619, 21.98625183], [72.50624847, 21.98625183], [72.50624847, 21.98681259], [72.50653076, 21.98681259], [72.50653076, 21.98792267], [72.50680542, 21.98791695], [72.50680542, 21.98875046], [72.50708008, 21.98875046], [72.50708008, 21.99097252], [72.50736237, 21.99097061], [72.50736237, 21.99180984], [72.50708008, 21.99180984], [72.50708008, 21.99263954], [72.50736237, 21.99263954], [72.50736237, 21.99430466], [72.50763702, 21.99430084], [72.50763702, 21.99514008], [72.50791931, 21.99514008], [72.50791931, 21.99735832], [72.50818634, 21.99735832], [72.50818634, 21.99764061], [72.50846863, 21.99764061], [72.50846863, 21.99819374], [72.50875092, 21.99819374], [72.50875092, 21.9995842], [72.50902557, 21.9995842], [72.5090332, 21.99986076], [72.5090332, 22.00041962], [72.50930786, 22.00041962], [72.50930786, 22.00152969], [72.50958252, 22.00152969], [72.50958252, 22.00263977], [72.50986481, 22.00263977], [72.50986481, 22.00347137], [72.51013947, 22.00347137], [72.51013947, 22.00458336], [72.51040649, 22.00457954], [72.51040649, 22.00542068], [72.51069641, 22.00542068], [72.51069641, 22.00653076], [72.51097107, 22.00653076], [72.51097107, 22.00764084], [72.51125336, 22.00763893], [72.51125336, 22.00847244], [72.51152802, 22.00847244], [72.51152802, 22.00958252], [72.51180267, 22.00958061], [72.51180267, 22.01041985], [72.51209259, 22.01041985], [72.51209259, 22.01152992], [72.51235962, 22.01152992], [72.51235962, 22.01264191], [72.51264191, 22.01263809], [72.51264191, 22.0134716], [72.51291656, 22.0134716], [72.51291656, 22.01458359], [72.51319122, 22.01458168], [72.51319122, 22.01542282], [72.51346588, 22.01542282], [72.51346588, 22.0165329], [72.51374817, 22.0165329], [72.51374817, 22.01764107], [72.51403046, 22.01763916], [72.51403046, 22.01847267], [72.51431274, 22.01847076], [72.51431274, 22.01931], [72.51457977, 22.01931], [72.51457977, 22.02013969], [72.51486206, 22.02013969], [72.51486206, 22.0209713], [72.51513672, 22.02096939], [72.51513672, 22.02153015], [72.51541901, 22.02152634], [72.51541901, 22.02236176], [72.51568604, 22.02235985], [72.51568604, 22.02319908], [72.51597595, 22.02319908], [72.51597595, 22.02403069], [72.51625061, 22.02403069], [72.51625061, 22.02486038], [72.51652527, 22.02486038], [72.51652527, 22.02569389], [72.51680756, 22.02568817], [72.51680756, 22.02652931], [72.51708221, 22.0265274], [72.51708221, 22.02708244], [72.51735687, 22.02708244], [72.51735687, 22.02791977], [72.51763916, 22.02791977], [72.51763916, 22.02874947], [72.51791382, 22.02874947], [72.51791382, 22.02958107], [72.51819611, 22.02958107], [72.51819611, 22.03097153], [72.51847076, 22.03096962], [72.51847076, 22.03264046], [72.51875305, 22.03264046], [72.51875305, 22.03430939], [72.51902771, 22.03430939], [72.51902771, 22.03541946], [72.51930237, 22.03541946], [72.51930237, 22.03652954], [72.51957703, 22.03652954], [72.51957703, 22.03763962], [72.51985931, 22.03763962], [72.51985931, 22.03874969], [72.5201416, 22.03874969], [72.5201416, 22.04042053], [72.52041626, 22.04041672], [72.52041626, 22.04208374], [72.52068329, 22.04208183], [72.52068329, 22.04403114], [72.52097321, 22.04402733], [72.52097321, 22.04569435], [72.52124786, 22.04569435], [72.52124786, 22.04736137], [72.52153015, 22.04735947], [72.52153015, 22.0490303], [72.52180481, 22.04902649], [72.52180481, 22.05069351], [72.5220871, 22.0506897], [72.5220871, 22.05236053], [72.52236176, 22.05236053], [72.52236176, 22.05404282], [72.52263641, 22.05402756], [72.52263641, 22.05597115], [72.5229187, 22.05597115], [72.5229187, 22.05820084], [72.52319336, 22.05819321], [72.52319336, 22.05986023], [72.52347565, 22.05986023], [72.52347565, 22.06125069], [72.52374268, 22.06125069], [72.52374268, 22.06264114], [72.52403259, 22.06264114], [72.52403259, 22.06402969], [72.52430725, 22.06402969], [72.52430725, 22.06542015], [72.52458191, 22.06541634], [72.52458191, 22.06680489], [72.52485657, 22.06679916], [72.52485657, 22.06820107], [72.52513885, 22.06819534], [72.52513885, 22.06958389], [72.52541351, 22.06958389], [72.52541351, 22.07097244], [72.5256958, 22.07097054], [72.5256958, 22.07263947], [72.52597046, 22.07263947], [72.52597046, 22.07402992], [72.52625275, 22.07402992], [72.52625275, 22.07542038], [72.5265274, 22.07542038], [72.5265274, 22.07624817], [72.52625275, 22.07624817], [72.52625275, 22.07681084], [72.5265274, 22.07681084], [72.5265274, 22.07764053], [72.52680206, 22.07764053], [72.52680206, 22.07847214], [72.52707672, 22.07846832], [72.52707672, 22.07930946], [72.52735901, 22.07930946], [72.52735901, 22.08013916], [72.5276413, 22.08013916], [72.5276413, 22.08125114], [72.52791595, 22.08124924], [72.52791595, 22.08208275], [72.52819824, 22.08208275], [72.52819824, 22.08292007], [72.5284729, 22.08291626], [72.5284729, 22.08402824], [72.52874756, 22.08402061], [72.52874756, 22.08514023], [72.52902985, 22.08514023], [72.52902985, 22.08625031], [72.52929687, 22.08625031], [72.52929687, 22.08736038], [72.52958679, 22.08736038], [72.52958679, 22.08819389], [72.52986908, 22.08819008], [72.52986908, 22.08930969], [72.53013611, 22.08930969], [72.53013611, 22.09015083], [72.5304184, 22.09013939], [72.5304184, 22.0909729], [72.53069305, 22.0909729], [72.53069305, 22.09236145], [72.53097534, 22.09236145], [72.53097534, 22.09347153], [72.53125, 22.09347153], [72.53125, 22.09431267], [72.53151703, 22.09431267], [72.53151703, 22.09542274], [72.53180695, 22.09542274], [72.53180695, 22.09625053], [72.5320816, 22.09625053], [72.5320816, 22.09680939], [72.53236389, 22.09680557], [72.53236389, 22.09819412], [72.53263855, 22.09819412], [72.53263855, 22.09902763], [72.53291321, 22.09902], [72.53291321, 22.10013962], [72.5331955, 22.10013962], [72.5331955, 22.10097313], [72.53347015, 22.10097122], [72.53347015, 22.10209084], [72.53375244, 22.10209084], [72.53375244, 22.10320091], [72.5340271, 22.10320091], [72.5340271, 22.10430908], [72.53430176, 22.10430908], [72.53430939, 22.10541916], [72.53457642, 22.10541916], [72.53457642, 22.10652924], [72.5348587, 22.10652924], [72.5348587, 22.10764122], [72.53514099, 22.10764122], [72.53514099, 22.10874939], [72.53541565, 22.10874939], [72.53541565, 22.1095829], [72.53569794, 22.1095829], [72.53569794, 22.11013985], [72.5359726, 22.11013794], [72.5359726, 22.11097145], [72.53624725, 22.11096191], [72.53624725, 22.11181068], [72.53652954, 22.11180305], [72.53652954, 22.11236191], [72.5368042, 22.11236191], [72.5368042, 22.11319351], [72.53708649, 22.1131897], [72.53708649, 22.11403084], [72.53736115, 22.11402512], [72.53736115, 22.11458588], [72.5376358, 22.11458588], [72.5376358, 22.11597252], [72.53791809, 22.11597061], [72.53791809, 22.11791992], [72.53819275, 22.11791611], [72.53819275, 22.11958313], [72.53847504, 22.11958313], [72.53847504, 22.12013817], [72.53874969, 22.12013817], [72.53874969, 22.12097168], [72.53901672, 22.12097168], [72.53901672, 22.12181282], [72.53930664, 22.12181282], [72.53930664, 22.12236023], [72.5395813, 22.12236023], [72.5395813, 22.12319374], [72.53985596, 22.12319183], [72.53985596, 22.12403107], [72.54013824, 22.12403107], [72.54013824, 22.12514114], [72.5404129, 22.12513924], [72.5404129, 22.12597275], [72.54069519, 22.12597275], [72.54069519, 22.12708282], [72.54096985, 22.12708092], [72.54096985, 22.12792015], [72.54125214, 22.12792015], [72.54125214, 22.12903023], [72.54152679, 22.12903023], [72.54152679, 22.1301403], [72.54180908, 22.1301403], [72.54180908, 22.13125038], [72.54207611, 22.13125038], [72.54207611, 22.13235855], [72.5423584, 22.13235855], [72.5423584, 22.13347244], [72.54264069, 22.13347244], [72.54264069, 22.13458252], [72.54291534, 22.13458252], [72.54291534, 22.1356945], [72.54319763, 22.1356926], [72.54319763, 22.13652992], [72.54347229, 22.13652802], [72.54347229, 22.13736153], [72.54374695, 22.13735962], [72.54374695, 22.13820076], [72.54402924, 22.13820076], [72.54402924, 22.13903046], [72.54429626, 22.13903046], [72.54430389, 22.13986015], [72.54458618, 22.13986015], [72.54458618, 22.14042091], [72.54486084, 22.14041519], [72.54486084, 22.14097214], [72.54514313, 22.14097023], [72.54514313, 22.14180946], [72.54541779, 22.14180946], [72.54541779, 22.14236069], [72.54569244, 22.14236069], [72.54569244, 22.1431942], [72.54597473, 22.1431942], [72.54597473, 22.14430618], [72.54624939, 22.14430046], [72.54624939, 22.14541817], [72.54651642, 22.14541817], [72.54651642, 22.14653015], [72.54680634, 22.14653015], [72.54680634, 22.14764023], [72.54708099, 22.14764023], [72.54708099, 22.14875031], [72.54736328, 22.14875031], [72.54736328, 22.14986038], [72.54763794, 22.14986038], [72.54763794, 22.15069389], [72.5479126, 22.15069008], [72.5479126, 22.15125084], [72.54818726, 22.15125084], [72.54818726, 22.15180969], [72.54846954, 22.15180969], [72.54846954, 22.15236092], [72.54875183, 22.15236092], [72.54875183, 22.15320015], [72.54902649, 22.15320015], [72.54902649, 22.15374947], [72.54930878, 22.15374947], [72.54930878, 22.15431023], [72.54958344, 22.1543045], [72.54958344, 22.15486145], [72.54985809, 22.15485954], [72.54985809, 22.15570068], [72.55014038, 22.15569687], [72.55014038, 22.15624809], [72.55042267, 22.15624046], [72.55042267, 22.15681076], [72.55069733, 22.15680695], [72.55069733, 22.15736198], [72.55097198, 22.15736198], [72.55097198, 22.15819359], [72.55124664, 22.15818977], [72.55124664, 22.15875053], [72.55152893, 22.15875053], [72.55152893, 22.15930557], [72.55179596, 22.15929985], [72.55179596, 22.15986061], [72.55208588, 22.15986061], [72.55208588, 22.16041946], [72.55236053, 22.16041756], [72.55236053, 22.1609726], [72.55264282, 22.1609726], [72.55264282, 22.16152954], [72.55291748, 22.16152763], [72.55291748, 22.16208267], [72.55319214, 22.16208267], [72.55319214, 22.16263962], [72.55347443, 22.16263962], [72.55347443, 22.16347313], [72.55374908, 22.16347122], [72.55374908, 22.16403008], [72.55403137, 22.16402817], [72.55403137, 22.16458321], [72.55430603, 22.16457939], [72.55430603, 22.16514015], [72.55458069, 22.16514015], [72.55458069, 22.16570091], [72.55486298, 22.16570091], [72.55486298, 22.16625023], [72.55513763, 22.16625023], [72.55513763, 22.16681099], [72.55541992, 22.16681099], [72.55541992, 22.16736031], [72.55568695, 22.16736031], [72.55568695, 22.16792107], [72.55596924, 22.16791534], [72.55596924, 22.16847229], [72.55625153, 22.16847038], [72.55625153, 22.16875076], [72.55652618, 22.16875076], [72.55652618, 22.16930962], [72.55680847, 22.16930771], [72.55680847, 22.16958237], [72.55708313, 22.16958046], [72.55708313, 22.17014122], [72.55735779, 22.17014122], [72.55735779, 22.17041969], [72.55764008, 22.17041779], [72.55764008, 22.17097282], [72.55791473, 22.17097282], [72.55791473, 22.17124748], [72.55819702, 22.17123985], [72.55819702, 22.17180824], [72.55847168, 22.17180634], [72.55847168, 22.1720829], [72.55874634, 22.17207909], [72.55874634, 22.17264175], [72.55902863, 22.17264175], [72.55902863, 22.17292023], [72.55930328, 22.17291641], [72.55930328, 22.17347145], [72.55958557, 22.17347145], [72.55958557, 22.17375183], [72.55986023, 22.17375183], [72.55986023, 22.17430496], [72.56014252, 22.17430496], [72.56014252, 22.17458344], [72.56041718, 22.17457962], [72.56041718, 22.17514038], [72.56069183, 22.17514038], [72.56069183, 22.17542076], [72.56097412, 22.17541695], [72.56097412, 22.17597389], [72.56124878, 22.17597008], [72.56124878, 22.17625046], [72.56153107, 22.17625046], [72.56153107, 22.17681122], [72.56180573, 22.1768055], [72.56180573, 22.17708206], [72.56208038, 22.17708015], [72.56208038, 22.17764091], [72.56236267, 22.17764091], [72.56236267, 22.17791939], [72.56263733, 22.17791748], [72.56263733, 22.17847252], [72.56291199, 22.17847061], [72.56291199, 22.17875099], [72.56318665, 22.17875099], [72.56318665, 22.17930984], [72.56346893, 22.17930412], [72.56346893, 22.1795826], [72.56375122, 22.17958069], [72.56375122, 22.18013954], [72.56402588, 22.18013954], [72.56402588, 22.18042946], [72.56430817, 22.1804142], [72.56430817, 22.18097305], [72.56458282, 22.18097115], [72.56458282, 22.18124962], [72.56485748, 22.18124962], [72.56485748, 22.18180466], [72.56513977, 22.18180466], [72.56513977, 22.18208313], [72.5654068, 22.18208122], [72.5654068, 22.18264008], [72.56569672, 22.18264008], [72.56569672, 22.18292046], [72.56597137, 22.18291855], [72.56597137, 22.18347168], [72.56624603, 22.18346977], [72.56624603, 22.18374825], [72.56652832, 22.18374825], [72.56652832, 22.18431091], [72.56680298, 22.18430519], [72.56680298, 22.18458366], [72.5670929, 22.18457985], [72.5670929, 22.18514061], [72.56735992, 22.18514061], [72.56735992, 22.18541908], [72.56764221, 22.18541718], [72.56764221, 22.18597221], [72.56791687, 22.18597221], [72.56791687, 22.18625069], [72.56819153, 22.18624115], [72.56819153, 22.18680954], [72.56847382, 22.18680573], [72.56847382, 22.1870842], [72.56874847, 22.18707848], [72.56874847, 22.18764114], [72.56903839, 22.18764114], [72.56903839, 22.18791962], [72.56930542, 22.1879158], [72.56930542, 22.18819427], [72.56958008, 22.18819427], [72.56958008, 22.18847275], [72.56986237, 22.18847275], [72.56986237, 22.18875122], [72.57013702, 22.18875122], [72.57013702, 22.18902969], [72.57041931, 22.18902969], [72.57041931, 22.18931007], [72.57069397, 22.18930626], [72.57069397, 22.18958282], [72.57096863, 22.18958282], [72.57096863, 22.1898613], [72.57125092, 22.18985939], [72.57125092, 22.19042015], [72.57152557, 22.19041634], [72.57152557, 22.19069481], [72.57180786, 22.19069481], [72.57180786, 22.19097137], [72.57208252, 22.19096947], [72.57208252, 22.19124985], [72.57235718, 22.19124985], [72.57235718, 22.19153023], [72.57263947, 22.19152832], [72.57263947, 22.19180489], [72.57291412, 22.19180489], [72.57291412, 22.19208336], [72.57319641, 22.19207954], [72.57319641, 22.19236946], [72.57347107, 22.19236946], [72.57347107, 22.1926403], [72.57375336, 22.1926403], [72.57375336, 22.19292068], [72.57402802, 22.19292068], [72.57402802, 22.19320107], [72.57430267, 22.19319534], [72.57430267, 22.19347191], [72.57458496, 22.19347191], [72.57458496, 22.19375038], [72.57514191, 22.19375038], [72.57514191, 22.19403076], [72.57541656, 22.19403076], [72.57541656, 22.19431114], [72.57569122, 22.19430542], [72.57569122, 22.19458389], [72.57596588, 22.19458008], [72.57596588, 22.19486046], [72.57624817, 22.19486046], [72.57624817, 22.19514084], [72.57653046, 22.19513893], [72.57653046, 22.1954155], [72.57680511, 22.1954155], [72.57680511, 22.19569397], [72.57707977, 22.19569397], [72.57707977, 22.19597244], [72.57736206, 22.19597054], [72.57736206, 22.19625092], [72.57763672, 22.19625092], [72.57763672, 22.19652939], [72.57791901, 22.19652939], [72.57791901, 22.19680977], [72.57819366, 22.19680786], [72.57819366, 22.19708252], [72.57847595, 22.19708061], [72.57847595, 22.19735909], [72.57875061, 22.19735909], [72.57875061, 22.19763947], [72.5790329, 22.19763947], [72.5790329, 22.19791985], [72.57930756, 22.19791794], [72.57930756, 22.1981945], [72.57958221, 22.1981945], [72.57958221, 22.19847298], [72.57985687, 22.19846916], [72.57985687, 22.19874763], [72.58013916, 22.19874763], [72.58013916, 22.19903183], [72.58041382, 22.19902992], [72.58040619, 22.19930077], [72.58069611, 22.19930649], [72.58069611, 22.19958305], [72.58097076, 22.19958305], [72.58097076, 22.19986153], [72.58125305, 22.19986153], [72.58125305, 22.20014191], [72.58152771, 22.20014191], [72.58152771, 22.20042038], [72.58180237, 22.20042038], [72.58180237, 22.20070267], [72.58208466, 22.20069504], [72.58208466, 22.2009716], [72.5826416, 22.2009716], [72.5826416, 22.20125008], [72.58291626, 22.20125008], [72.58291626, 22.20153999], [72.58319092, 22.20153999], [72.58319092, 22.20181274], [72.58374786, 22.20180511], [72.58374786, 22.20208359], [72.58402252, 22.20208168], [72.58403015, 22.20236015], [72.5845871, 22.20236015], [72.5845871, 22.20264053], [72.58486176, 22.20264053], [72.58486176, 22.20292282], [72.58513641, 22.2029171], [72.58513641, 22.20319366], [72.58569336, 22.20319366], [72.58569336, 22.20347214], [72.58597565, 22.20347214], [72.58597565, 22.20375061], [72.58625031, 22.20375061], [72.58625031, 22.20403099], [72.58680725, 22.20403099], [72.58680725, 22.20430946], [72.58708191, 22.20430565], [72.58708191, 22.20458221], [72.58735657, 22.20458031], [72.58735657, 22.20486069], [72.58790588, 22.20486069], [72.58790588, 22.20514107], [72.5881958, 22.20514107], [72.5881958, 22.20541954], [72.58847046, 22.20541573], [72.58847046, 22.2056942], [72.5890274, 22.2056942], [72.5890274, 22.20597267], [72.58930206, 22.20597076], [72.58930206, 22.20625114], [72.58985901, 22.20625114], [72.58985901, 22.20652962], [72.59014893, 22.20652962], [72.59014893, 22.20681], [72.59041595, 22.20680428], [72.59041595, 22.20708275], [72.5909729, 22.20708275], [72.5909729, 22.20736122], [72.59124756, 22.20734978], [72.59124756, 22.20763969], [72.59152985, 22.20763969], [72.59152985, 22.20792007], [72.59208679, 22.20791435], [72.59208679, 22.20819473], [72.59236145, 22.20819473], [72.59236145, 22.2084713], [72.5929184, 22.20846939], [72.5929184, 22.20874977], [72.59348297, 22.20874977], [72.59348297, 22.20903015], [72.59375, 22.20902634], [72.59375, 22.20930481], [72.59430695, 22.20930481], [72.59430695, 22.20958328], [72.59486389, 22.20958328], [72.59486389, 22.20986176], [72.59541321, 22.20985985], [72.59541321, 22.21014023], [72.5956955, 22.21013641], [72.5956955, 22.2104187], [72.59625244, 22.21041107], [72.59625244, 22.21069908], [72.59680176, 22.21069908], [72.59680939, 22.21097183], [72.5973587, 22.21096992], [72.5973587, 22.21125031], [72.59792328, 22.21125031], [72.59792328, 22.21153069], [72.59819794, 22.21153069], [72.59819794, 22.21180916], [72.59874725, 22.21180534], [72.59874725, 22.21208382], [72.59929657, 22.21207809], [72.59929657, 22.21235847], [72.59986115, 22.21235847], [72.59986115, 22.21264076], [72.6001358, 22.21264076], [72.6001358, 22.21291924], [72.60069275, 22.21291733], [72.60069275, 22.21319389], [72.60124969, 22.21318817], [72.60124969, 22.2134819], [72.60235596, 22.2134819], [72.60235596, 22.21375084], [72.60346985, 22.21375084], [72.60346985, 22.21403122], [72.60430908, 22.21403122], [72.60430908, 22.21430969], [72.60541534, 22.21430588], [72.60541534, 22.21458244], [72.60652924, 22.21458244], [72.60652924, 22.21486282], [72.6076355, 22.21486282], [72.6076355, 22.21513939], [72.6084671, 22.21513939], [72.6084671, 22.21541977], [72.60958099, 22.21541595], [72.60958099, 22.21569443], [72.61069489, 22.21569443], [72.61069489, 22.2159729], [72.61125183, 22.2159729], [72.61125183, 22.21624947], [72.61180878, 22.21624947], [72.61180878, 22.21653938], [72.61264038, 22.21653938], [72.61264038, 22.21681023], [72.61319733, 22.21680641], [72.61319733, 22.21708488], [72.61374664, 22.21708488], [72.61374664, 22.21736145], [72.61486053, 22.21735954], [72.61486053, 22.21763992], [72.61569214, 22.21763992], [72.61569214, 22.21735954], [72.62097168, 22.21735954], [72.62097168, 22.21763992], [72.62541962, 22.21763992], [72.62541962, 22.2179203], [72.63957977, 22.2179203], [72.63957977, 22.21763992], [72.63986206, 22.21763992], [72.63986206, 22.21735954], [72.64208221, 22.21736145], [72.64208221, 22.21708488], [72.6423645, 22.21708488], [72.6423645, 22.21680641], [72.64291382, 22.21680641], [72.64291382, 22.21736145], [72.64485931, 22.21736145], [72.64485931, 22.21708488], [72.64736176, 22.21708488], [72.64736176, 22.21680641], [72.64848328, 22.21681023], [72.64848328, 22.21653938], [72.64875031, 22.21653938], [72.64875031, 22.21624947], [72.64930725, 22.21624947], [72.64930725, 22.2159729], [72.65041351, 22.2159729], [72.65041351, 22.21569443], [72.6506958, 22.21569443], [72.6506958, 22.21541595], [72.65207672, 22.21541977], [72.65207672, 22.21513939], [72.6526413, 22.21513939], [72.6526413, 22.21486282], [72.6534729, 22.21486282], [72.6534729, 22.21458244], [72.65402985, 22.21458244], [72.65402985, 22.21430588], [72.65458679, 22.21430969], [72.65458679, 22.21403122], [72.65513611, 22.21403122], [72.65513611, 22.21375084], [72.65598297, 22.21375084], [72.65597534, 22.21347237], [72.65651703, 22.2134819], [72.65651703, 22.21318817], [72.6570816, 22.21319389], [72.6570816, 22.21291733], [72.65763855, 22.21291924], [72.65763855, 22.21265984], [72.6579361, 22.2126503], [72.65847015, 22.21264076], [72.65847015, 22.21253967], [72.65847015, 22.21235847], [72.6590271, 22.21235847], [72.6590271, 22.21207809], [72.65930176, 22.21208382], [72.65930176, 22.21180534], [72.65957642, 22.21180916], [72.65957642, 22.21153069], [72.66014099, 22.21153069], [72.66014099, 22.21125031], [72.66042328, 22.21125031], [72.66041565, 22.21097183], [72.6609726, 22.21097183], [72.6609726, 22.21069527], [72.66124725, 22.21069908], [72.66124725, 22.21041107], [72.6618042, 22.2104187], [72.6618042, 22.21013641], [72.66208649, 22.21014023], [72.66208649, 22.20985985], [72.66236115, 22.20986176], [72.66236115, 22.20958328], [72.6626358, 22.20958328], [72.6626358, 22.20902634], [72.66291809, 22.20903015], [72.66291809, 22.20874977], [72.66319275, 22.20874977], [72.66319275, 22.20846939], [72.66347504, 22.2084713], [72.66347504, 22.20819473], [72.66374969, 22.20819473], [72.66374969, 22.20791435], [72.66430664, 22.20792007], [72.66430664, 22.20763969], [72.66485596, 22.20763969], [72.66485596, 22.20734978], [72.6654129, 22.20736122], [72.6654129, 22.20708275], [72.66569519, 22.20708275], [72.66569519, 22.20680428], [72.66596985, 22.20681], [72.66596985, 22.20652962], [72.66625214, 22.20652962], [72.66625214, 22.20625114], [72.66652679, 22.20625114], [72.66652679, 22.20597076], [72.66680908, 22.20597267], [72.66680908, 22.2056942], [72.6673584, 22.2056942], [72.6673584, 22.20541573], [72.66847229, 22.20541954], [72.66847229, 22.20514107], [72.66874695, 22.20514107], [72.66874695, 22.20486069], [72.66902924, 22.20486069], [72.66902924, 22.20458031], [72.66930389, 22.20458221], [72.66930389, 22.20430565], [72.67014313, 22.20430946], [72.67014313, 22.20375061], [72.67041779, 22.20375061], [72.67041779, 22.20347023], [72.67097473, 22.20347214], [72.67097473, 22.2029171], [72.67124176, 22.20292282], [72.67124176, 22.20264053], [72.67151642, 22.20264053], [72.67151642, 22.20236015], [72.67263794, 22.20236015], [72.67263794, 22.20208168], [72.67346954, 22.20208359], [72.67346954, 22.20152855], [72.67375183, 22.20153999], [72.67375183, 22.20125008], [72.67402649, 22.20125008], [72.67402649, 22.2009716], [72.67430878, 22.2009716], [72.67430878, 22.20069504], [72.67485809, 22.20070267], [72.67485809, 22.20042038], [72.67542267, 22.20042038], [72.67542267, 22.20014191], [72.67597198, 22.20014191], [72.67597198, 22.19986153], [72.67652893, 22.19986153], [72.67652893, 22.19958305], [72.67791748, 22.19958305], [72.67791748, 22.19930649], [72.67930603, 22.19930077], [72.67930603, 22.19902992], [72.67986298, 22.19903183], [72.67986298, 22.19874763], [72.68068695, 22.19874763], [72.68068695, 22.19846916], [72.68125153, 22.19847298], [72.68125153, 22.1981945], [72.68180847, 22.1981945], [72.68180847, 22.19791794], [72.68208313, 22.19791985], [72.68208313, 22.19763947], [72.68264008, 22.19763947], [72.68264008, 22.19735909], [72.68319702, 22.19735909], [72.68319702, 22.19708061], [72.68374634, 22.19708252], [72.68374634, 22.19680786], [72.68402863, 22.19680977], [72.68402863, 22.19652939], [72.6845932, 22.19652939], [72.6845932, 22.19625092], [72.68514252, 22.19625092], [72.68514252, 22.19597054], [72.68569183, 22.19597244], [72.68569183, 22.19569397], [72.68597412, 22.19569397], [72.68597412, 22.1954155], [72.68653107, 22.1954155], [72.68653107, 22.19513893], [72.68708038, 22.19514084], [72.68708038, 22.19486046], [72.68763733, 22.19486046], [72.68763733, 22.19458008], [72.68791962, 22.19458389], [72.68791962, 22.19430542], [72.68846893, 22.19431114], [72.68846893, 22.19403076], [72.68875122, 22.19403076], [72.68875122, 22.19375038], [72.68930817, 22.19375038], [72.68930817, 22.19320107], [72.68958282, 22.19320107], [72.68958282, 22.19292068], [72.69013977, 22.19292068], [72.69013977, 22.19236946], [72.6904068, 22.19236946], [72.6904068, 22.19207954], [72.69069672, 22.19208336], [72.69069672, 22.19180489], [72.69097137, 22.19180489], [72.69097137, 22.19124985], [72.69124603, 22.19124985], [72.69124603, 22.19096947], [72.69180298, 22.19097137], [72.69180298, 22.19041634], [72.6920929, 22.19042015], [72.6920929, 22.19013977], [72.69235992, 22.19013977], [72.69235992, 22.1898613], [72.69264221, 22.1898613], [72.69264221, 22.18958282], [72.69319153, 22.18958282], [72.69319153, 22.18930626], [72.69346619, 22.18931007], [72.69346619, 22.18875122], [72.69403076, 22.18875122], [72.69403076, 22.18847275], [72.69486237, 22.18847275], [72.69486237, 22.18819427], [72.69541931, 22.18819427], [72.69541931, 22.18763924], [72.69596863, 22.18764114], [72.69596863, 22.18736267], [72.69625092, 22.18736267], [72.69625092, 22.18707848], [72.69708252, 22.1870842], [72.69708252, 22.18680573], [72.69790649, 22.18680954], [72.69790649, 22.18652916], [72.69819641, 22.18652916], [72.69819641, 22.18624115], [72.69875336, 22.18625069], [72.69875336, 22.18597221], [72.69902802, 22.18597221], [72.69902802, 22.18569374], [72.69930267, 22.18569374], [72.69930267, 22.18514061], [72.69959259, 22.18514061], [72.69959259, 22.18457985], [72.70014191, 22.18458366], [72.70014191, 22.18430519], [72.70124817, 22.18431091], [72.70124817, 22.18403053], [72.70347595, 22.18403053], [72.70347595, 22.18374825], [72.70540619, 22.18374825], [72.70540619, 22.18403053], [72.70625305, 22.18403053], [72.70625305, 22.18431091], [72.70652771, 22.18431091], [72.70652771, 22.18485832], [72.70707703, 22.18485832], [72.70707703, 22.18514061], [72.70735931, 22.18514061], [72.70735931, 22.18569374], [72.7076416, 22.18569374], [72.7076416, 22.18597221], [72.7095871, 22.18597221], [72.7095871, 22.18569374], [72.71152496, 22.18569374], [72.71152496, 22.18541718], [72.7131958, 22.18541908], [72.7131958, 22.18514061], [72.71485901, 22.18514061], [72.71485901, 22.18485832], [72.71569061, 22.18485832], [72.71569824, 22.18457985], [72.7159729, 22.18458366], [72.7159729, 22.18430519], [72.71653748, 22.18431091], [72.71653748, 22.18403053], [72.71736145, 22.18403053], [72.71736145, 22.18374825], [72.72013855, 22.18374825], [72.72013855, 22.18346977], [72.72125244, 22.18347168], [72.72125244, 22.18319511], [72.72292328, 22.18320084], [72.72292328, 22.18292046], [72.7234726, 22.18292046], [72.7234726, 22.18264008], [72.72458649, 22.18264008], [72.72458649, 22.1823597], [72.72569275, 22.1823616], [72.72569275, 22.18208313], [72.72597504, 22.18208313], [72.72597504, 22.18180466], [72.72736359, 22.18180466], [72.72736359, 22.18152618], [72.72763824, 22.18153], [72.72763824, 22.18124962], [72.7279129, 22.18124962], [72.7279129, 22.18097115], [72.72902679, 22.18097305], [72.72902679, 22.18069458], [72.72930908, 22.18069458], [72.72930908, 22.1804142], [72.73014069, 22.18042946], [72.73014069, 22.18013954], [72.73042297, 22.18013954], [72.73041534, 22.1795826], [72.73097229, 22.1795826], [72.73097229, 22.17930412], [72.73124695, 22.17930984], [72.73124695, 22.17902946], [72.73153687, 22.17902946], [72.73153687, 22.17875099], [72.73208618, 22.17875099], [72.73208618, 22.17847061], [72.73291779, 22.17847252], [72.73291779, 22.17791748], [72.7334671, 22.17791939], [72.7334671, 22.17764091], [72.73430634, 22.17764091], [72.73430634, 22.17737007], [72.73513794, 22.17737007], [72.73513794, 22.17708015], [72.73625183, 22.17708206], [72.73625183, 22.1768055], [72.73652649, 22.17681122], [72.73652649, 22.17653084], [72.73680878, 22.17653084], [72.73680878, 22.17625046], [72.73792267, 22.17625046], [72.73792267, 22.17653084], [72.73847198, 22.17653084], [72.73847198, 22.17625046], [72.73929596, 22.17625046], [72.73929596, 22.17597008], [72.73986053, 22.17597389], [72.73986053, 22.17569351], [72.74041748, 22.17569351], [72.74041748, 22.17541695], [72.7409668, 22.17542076], [72.7409668, 22.17514038], [72.74180603, 22.17514038], [72.74180603, 22.17486191], [72.74236298, 22.17486191], [72.74236298, 22.17458344], [72.74346924, 22.17458344], [72.74346924, 22.17430496], [72.74458313, 22.17430496], [72.74458313, 22.1740284], [72.74597168, 22.1740303], [72.74597168, 22.17375183], [72.7470932, 22.17375183], [72.74708557, 22.17347145], [72.74819183, 22.17347145], [72.74819183, 22.17319489], [72.75208282, 22.17319489], [72.75402832, 22.17319489], [72.75402832, 22.17347145], [72.75514221, 22.17347145], [72.75514221, 22.17375183], [72.75624847, 22.17375183], [72.75624847, 22.1740303], [72.75763702, 22.1740284], [72.75763702, 22.17430496], [72.75819397, 22.17430496], [72.75819397, 22.17458344], [72.75875092, 22.17458344], [72.75875092, 22.17486191], [72.75930786, 22.17486191], [72.75930786, 22.17514038], [72.75985718, 22.17514038], [72.75985718, 22.17542076], [72.76013947, 22.17541695], [72.76013947, 22.17597389], [72.76040649, 22.17597008], [72.76040649, 22.17625046], [72.76069641, 22.17625046], [72.76069641, 22.17653084], [72.76097107, 22.17653084], [72.76097107, 22.17681122], [72.76125336, 22.1768055], [72.76125336, 22.17708206], [72.76152039, 22.17708015], [72.76152039, 22.17737007], [72.76180267, 22.17737007], [72.76180267, 22.17764091], [72.76209259, 22.17764091], [72.76209259, 22.17791939], [72.76235962, 22.17791748], [72.76235962, 22.17819214], [72.76209259, 22.17819023], [72.76209259, 22.17902946], [72.76180267, 22.17902946], [72.76180267, 22.17930984], [72.76208496, 22.17930412], [72.76208496, 22.1795826], [72.76235962, 22.17958069], [72.76235962, 22.17986107], [72.76264191, 22.17986107], [72.76264191, 22.18042946], [72.76291656, 22.1804142], [72.76291656, 22.18069458], [72.76319122, 22.18069458], [72.76319122, 22.18097305], [72.76346588, 22.18097115], [72.76346588, 22.18124962], [72.76374817, 22.18124962], [72.76374817, 22.18153], [72.76403046, 22.18152618], [72.76403046, 22.18180466], [72.76430511, 22.18180466], [72.76430511, 22.18208313], [72.7645874, 22.18208122], [72.7645874, 22.18264008], [72.76513672, 22.18264008], [72.76513672, 22.18292046], [72.76541901, 22.18291855], [72.76541901, 22.18347168], [72.76568604, 22.18346977], [72.76568604, 22.18403053], [72.76597595, 22.18403053], [72.76597595, 22.18431091], [72.76625061, 22.18430519], [72.76625061, 22.18458366], [72.76680756, 22.18457985], [72.76680756, 22.18485832], [72.76708221, 22.18485832], [72.76708221, 22.18514061], [72.76735687, 22.18514061], [72.76735687, 22.18541908], [72.76763916, 22.18541718], [72.76763916, 22.18597221], [72.76790619, 22.1859684], [72.76790619, 22.18680954], [72.76819611, 22.18680573], [72.76819611, 22.1870842], [72.76847076, 22.18707848], [72.76847076, 22.18736267], [72.76875305, 22.18736267], [72.76875305, 22.18764114], [72.76902771, 22.18763924], [72.76902771, 22.18819427], [72.76930237, 22.18819427], [72.76930237, 22.18847275], [72.76957703, 22.18847275], [72.76957703, 22.18875122], [72.7701416, 22.18875122], [72.7701416, 22.18902969], [72.77041626, 22.18902779], [72.77041626, 22.1898613], [72.77069092, 22.18985939], [72.77069092, 22.19042015], [72.77097321, 22.19041634], [72.77097321, 22.19069481], [72.77124786, 22.19069481], [72.77124786, 22.19097137], [72.77153015, 22.19096947], [72.77153015, 22.19124985], [72.77180481, 22.19124985], [72.77180481, 22.19180489], [72.7720871, 22.19180489], [72.7720871, 22.19208336], [72.77236176, 22.19207954], [72.77236176, 22.19236946], [72.77263641, 22.19236946], [72.77263641, 22.19292068], [72.7729187, 22.19292068], [72.7729187, 22.19320107], [72.77319336, 22.19319534], [72.77319336, 22.19347191], [72.77347565, 22.19347191], [72.77347565, 22.19375038], [72.77375031, 22.19375038], [72.77375031, 22.19403076], [72.77403259, 22.19403076], [72.77403259, 22.19431114], [72.77430725, 22.19431114], [72.77430725, 22.19486046], [72.77458191, 22.19486046], [72.77458191, 22.1954155], [72.7748642, 22.1954155], [72.7748642, 22.19569397], [72.77513885, 22.19569016], [72.77513885, 22.19625092], [72.77540588, 22.19625092], [72.77540588, 22.19680977], [72.7756958, 22.19680786], [72.7756958, 22.19708252], [72.77597046, 22.19708061], [72.77597046, 22.19763947], [72.77625275, 22.19763947], [72.77625275, 22.1981945], [72.7765274, 22.19818115], [72.7765274, 22.19874763], [72.77680206, 22.19874763], [72.77680206, 22.19903183], [72.77735901, 22.19902992], [72.77735901, 22.19986153], [72.7776413, 22.19986153], [72.7776413, 22.20014191], [72.77791595, 22.20013809], [72.77791595, 22.2009716], [72.77819824, 22.2009716], [72.77819824, 22.20125008], [72.7784729, 22.20125008], [72.7784729, 22.20236015], [72.77874756, 22.20236015], [72.77874756, 22.20292282], [72.77902985, 22.2029171], [72.77902985, 22.20319366], [72.77929688, 22.20318985], [72.77929688, 22.20375061], [72.77958679, 22.20375061], [72.77958679, 22.2056942], [72.77986145, 22.20569038], [72.77986145, 22.20625114], [72.78013611, 22.20625114], [72.78013611, 22.20652962], [72.7804184, 22.20652771], [72.7804184, 22.20736122], [72.78069305, 22.20736122], [72.78069305, 22.20819473], [72.78097534, 22.20819473], [72.78097534, 22.2084713], [72.78125, 22.20846939], [72.78125, 22.20874977], [72.78152466, 22.20874977], [72.78152466, 22.20958328], [72.78180695, 22.20957947], [72.78180695, 22.21014023], [72.7820816, 22.21013641], [72.7820816, 22.2104187], [72.78235626, 22.21041107], [72.78235626, 22.21264076], [72.78263092, 22.21264076], [72.78263092, 22.21291924], [72.78291321, 22.21291924], [72.78291321, 22.2134819], [72.7831955, 22.21347237], [72.7831955, 22.21375084], [72.78347015, 22.21375084], [72.78347015, 22.21430969], [72.78375244, 22.21430588], [72.78375244, 22.21458244], [72.7840271, 22.21458244], [72.7840271, 22.21513939], [72.78430176, 22.21513939], [72.78430939, 22.21541977], [72.78458405, 22.21541595], [72.78458405, 22.2159729], [72.7848587, 22.2159729], [72.7848587, 22.21653938], [72.78514099, 22.21653938], [72.78514099, 22.21681023], [72.78541565, 22.21680641], [72.78541565, 22.21736145], [72.78569031, 22.21735954], [72.78569031, 22.21763992], [72.7859726, 22.21763992], [72.7859726, 22.21820068], [72.78624725, 22.21819305], [72.78624725, 22.21847153], [72.78652954, 22.21846962], [72.78652954, 22.21903038], [72.78679657, 22.21903038], [72.78679657, 22.21931076], [72.78708649, 22.21930313], [72.78708649, 22.21986198], [72.78736115, 22.21986008], [72.78736115, 22.22042084], [72.7876358, 22.22041512], [72.7876358, 22.22069359], [72.78791809, 22.22068977], [72.78791809, 22.22125053], [72.78848267, 22.22125053], [72.78848267, 22.22153091], [72.78875732, 22.22153091], [72.78875732, 22.22180939], [72.78902435, 22.22180557], [72.78902435, 22.22208595], [72.78930664, 22.22208595], [72.78930664, 22.22236061], [72.7895813, 22.22235107], [72.7895813, 22.22264099], [72.78986359, 22.22263718], [72.78986359, 22.2234726], [72.79013824, 22.22347069], [72.79013824, 22.22375107], [72.7904129, 22.22375107], [72.7904129, 22.22430992], [72.79069519, 22.22430611], [72.79069519, 22.22513962], [72.79096985, 22.22513962], [72.79096985, 22.22541809], [72.79125214, 22.22541618], [72.79125214, 22.22569466], [72.79152679, 22.22569084], [72.79152679, 22.2262516], [72.79180908, 22.2262516], [72.79180908, 22.22708321], [72.79208374, 22.22708321], [72.79208374, 22.22736168], [72.79264069, 22.22736168], [72.79264069, 22.22764015], [72.79292297, 22.22764015], [72.79292297, 22.2293129], [72.79319763, 22.22930527], [72.79319763, 22.22958374], [72.79347229, 22.22958183], [72.79347229, 22.22986031], [72.79374695, 22.22986031], [72.79374695, 22.23042107], [72.79402924, 22.23041725], [72.79402924, 22.23069382], [72.79430389, 22.23069382], [72.79430389, 22.23097229], [72.79458618, 22.23097229], [72.79458618, 22.23152733], [72.79486084, 22.2315197], [72.79486084, 22.23180962], [72.7951355, 22.2318058], [72.7951355, 22.23236084], [72.79541779, 22.23236084], [72.79541779, 22.23264122], [72.79569244, 22.23264122], [72.79569244, 22.23291969], [72.79597473, 22.23291588], [72.79597473, 22.23347282], [72.79624939, 22.23347092], [72.79624939, 22.23374939], [72.79651642, 22.23374939], [72.79651642, 22.23402977], [72.79680634, 22.23402786], [72.79680634, 22.2345829], [72.79708099, 22.2345829], [72.79708099, 22.23486137], [72.79736328, 22.23485947], [72.79736328, 22.23542023], [72.79763794, 22.23541641], [72.79763794, 22.23569679], [72.79792023, 22.23569679], [72.79792023, 22.23597145], [72.79818726, 22.23596954], [72.79818726, 22.2365303], [72.79846954, 22.2365303], [72.79846954, 22.23681068], [72.79875183, 22.23680496], [72.79875183, 22.23736191], [72.79902649, 22.23735809], [72.79902649, 22.23765182], [72.79930878, 22.23765182], [72.79930878, 22.23792076], [72.79958344, 22.23791885], [72.79958344, 22.23847008], [72.79985809, 22.23846817], [72.79985809, 22.23875046], [72.80042267, 22.23875046], [72.80042267, 22.23903084], [72.80069733, 22.23902893], [72.80069733, 22.23958397], [72.80097198, 22.23957825], [72.80097198, 22.23985863], [72.80152893, 22.23985863], [72.80152893, 22.24014091], [72.80179596, 22.24014091], [72.80179596, 22.24041939], [72.80208588, 22.24041748], [72.80208588, 22.24069405], [72.80263519, 22.24069405], [72.80263519, 22.24097252], [72.80291748, 22.24097252], [72.80291748, 22.24152946], [72.80319214, 22.24152946], [72.80319214, 22.24180984], [72.80374908, 22.24180603], [72.80374908, 22.2420826], [72.80430603, 22.2420826], [72.80430603, 22.24236107], [72.80513763, 22.24236107], [72.80513763, 22.24263954], [72.80568695, 22.24263954], [72.80568695, 22.24291992], [72.80596924, 22.24291611], [72.80596924, 22.24347115], [72.80625153, 22.24346161], [72.80625153, 22.24374962], [72.80652618, 22.24374962], [72.80652618, 22.24430466], [72.80680847, 22.24430466], [72.80680847, 22.24458313], [72.80735779, 22.24458313], [72.80735779, 22.2448616], [72.80764008, 22.2448597], [72.80764008, 22.24514008], [72.8079071, 22.24514008], [72.8079071, 22.24542046], [72.80847168, 22.24542046], [72.80847168, 22.24570084], [72.80874634, 22.24569321], [72.80874634, 22.24597168], [72.80930328, 22.24596977], [72.80930328, 22.24625015], [72.81014252, 22.24625015], [72.81014252, 22.24652863], [72.81069183, 22.246521], [72.81069183, 22.24681091], [72.81124878, 22.24680519], [72.81124878, 22.24708366], [72.81208038, 22.24707985], [72.81208038, 22.24736023], [72.81263733, 22.24736023], [72.81263733, 22.24764061], [72.81375122, 22.24764061], [72.81375122, 22.24792099], [72.81597137, 22.24792099], [72.81597137, 22.24764061], [72.8170929, 22.24764061], [72.8170929, 22.24792099], [72.81735992, 22.24792099], [72.81735992, 22.24764061], [72.81819153, 22.24764061], [72.81819153, 22.24707985], [72.81847382, 22.24708366], [72.81847382, 22.24680519], [72.81903076, 22.24681091], [72.81903076, 22.246521], [72.81986237, 22.24652863], [72.81986237, 22.24597168], [72.82041931, 22.24597168], [72.82041931, 22.24569321], [72.82096863, 22.24570084], [72.82096863, 22.24542046], [72.82125092, 22.24542046], [72.82125092, 22.24514008], [72.82180023, 22.24514008], [72.82180023, 22.24458122], [72.82208252, 22.24458313], [72.82208252, 22.24430466], [72.82236481, 22.24430466], [72.82236481, 22.24374962], [72.82290649, 22.24374962], [72.82290649, 22.24346161], [72.82347107, 22.24347115], [72.82347107, 22.24263954], [72.82430267, 22.24263954], [72.82430267, 22.2420826], [72.82485962, 22.2420826], [72.82485962, 22.24180603], [72.82541656, 22.24180984], [72.82541656, 22.24152946], [72.82569122, 22.24152946], [72.82569122, 22.2412529], [72.82624817, 22.2412529], [72.82624817, 22.24068832], [72.82707977, 22.24069405], [72.82707977, 22.24041748], [72.82792664, 22.24041939], [72.82792664, 22.24014091], [72.83013916, 22.24014091], [72.83013916, 22.23985863], [72.83040619, 22.23985863], [72.83040619, 22.23957825], [72.83097076, 22.23958397], [72.83097076, 22.2393055], [72.83152771, 22.23930931], [72.83152771, 22.23903084], [72.83347321, 22.23903084], [72.83347321, 22.23875046], [72.83429718, 22.23875046], [72.83429718, 22.23846817], [72.83486176, 22.23847008], [72.83486176, 22.23819351], [72.83625031, 22.23819351], [72.83625031, 22.23847008], [72.83652496, 22.23847008], [72.83652496, 22.23819351], [72.8381958, 22.23819351], [72.8381958, 22.23791885], [72.8390274, 22.23792076], [72.8390274, 22.23765182], [72.83986664, 22.23765182], [72.83986664, 22.23735809], [72.8418045, 22.23736191], [72.8418045, 22.23708344], [72.84402466, 22.23708344], [72.84402466, 22.23680496], [72.84625244, 22.23681068], [72.84625244, 22.2365303], [72.84792328, 22.2365303], [72.84792328, 22.23624992], [72.8484726, 22.23624992], [72.8484726, 22.23596954], [72.8493042, 22.23597145], [72.8493042, 22.23569679], [72.84986115, 22.23569679], [72.84986115, 22.23513794], [72.85041809, 22.23513985], [72.85041809, 22.23485947], [72.85124969, 22.23486137], [72.85124969, 22.2345829], [72.85152435, 22.2345829], [72.85152435, 22.23430443], [72.8520813, 22.23431015], [72.8520813, 22.23402977], [72.85235596, 22.23402977], [72.85235596, 22.23374939], [72.85263824, 22.23374939], [72.85263824, 22.23347092], [72.85319519, 22.23347282], [72.85319519, 22.23319435], [72.85346985, 22.23319435], [72.85346985, 22.23291588], [72.85402679, 22.23291969], [72.85402679, 22.23264122], [72.85457611, 22.23264122], [72.85457611, 22.23236084], [72.85514069, 22.23236084], [72.85514069, 22.23208046], [72.85541534, 22.23208237], [72.85541534, 22.2318058], [72.85569763, 22.23180962], [72.85569763, 22.2315197], [72.85597229, 22.23152733], [72.85597229, 22.23125076], [72.85652924, 22.23125076], [72.85652924, 22.23097038], [72.85708618, 22.23097229], [72.85708618, 22.23069382], [72.85736084, 22.23069382], [72.85736084, 22.23041725], [72.85791016, 22.23042107], [72.85791016, 22.23014069], [72.8584671, 22.23014069], [72.8584671, 22.22986031], [72.85874939, 22.22986031], [72.85874939, 22.22958183], [72.85902405, 22.22958374], [72.85902405, 22.22930527], [72.85930634, 22.2293129], [72.85930634, 22.22903061], [72.85986328, 22.22903061], [72.85986328, 22.22875023], [72.86042023, 22.22875023], [72.86042023, 22.22820282], [72.86067963, 22.22820282], [72.86067963, 22.22792053], [72.86125183, 22.22792053], [72.86125183, 22.22764015], [72.86152649, 22.22764015], [72.86152649, 22.22736168], [72.86180878, 22.22736168], [72.86180878, 22.22708321], [72.86208344, 22.22708321], [72.86208344, 22.22680473], [72.86235809, 22.22680473], [72.86235809, 22.22652817], [72.86264038, 22.22653008], [72.86264038, 22.2262516], [72.86292267, 22.2262516], [72.86291504, 22.22597313], [72.86402893, 22.22597313], [72.86402893, 22.22569466], [72.86513519, 22.22569466], [72.86513519, 22.22541618], [72.86569214, 22.22541809], [72.86569214, 22.22513962], [72.86653137, 22.22513962], [72.86653137, 22.22485924], [72.86708069, 22.22485924], [72.86708069, 22.22458076], [72.86846924, 22.22458267], [72.86846924, 22.22430611], [72.86875153, 22.22430992], [72.86875153, 22.22375107], [72.86958313, 22.22375107], [72.86958313, 22.22347069], [72.8720932, 22.22347069], [72.8720932, 22.22375107], [72.87391663, 22.22374725], [72.8779068, 22.22375107], [72.8779068, 22.22430992], [72.87847137, 22.22430611], [72.87847137, 22.22458267], [72.87930298, 22.22458076], [72.87930298, 22.22485924], [72.87985992, 22.22485924], [72.87985992, 22.22513962], [72.88054657, 22.22513962], [72.88069153, 22.22513962], [72.88069153, 22.22525978], [72.88069153, 22.22541809], [72.88083649, 22.22541809], [72.88097382, 22.22541618], [72.88097382, 22.22554016], [72.88097382, 22.22569466], [72.88124847, 22.22569466], [72.88124847, 22.22597313], [72.88153076, 22.22596931], [72.88153076, 22.2262516], [72.88208008, 22.2262516], [72.88208008, 22.22653008], [72.88236237, 22.22652817], [72.88236237, 22.22680473], [72.88263702, 22.22680473], [72.88263702, 22.22708321], [72.88291931, 22.22708321], [72.88291931, 22.22736168], [72.88375092, 22.22736168], [72.88375092, 22.22792053], [72.8840332, 22.22792053], [72.8840332, 22.22820282], [72.88430786, 22.22820282], [72.88430786, 22.22847939], [72.88458252, 22.22847939], [72.88458252, 22.22875023], [72.88513947, 22.22875023], [72.88513947, 22.22903061], [72.88540649, 22.22903061], [72.88540649, 22.2293129], [72.88569641, 22.22930527], [72.88569641, 22.22958374], [72.88597107, 22.22958183], [72.88597107, 22.23014069], [72.88625336, 22.23013878], [72.88625336, 22.23069382], [72.88791656, 22.23069382], [72.88791656, 22.23097229], [72.89041901, 22.23097229], [72.89041901, 22.23069382], [72.89069366, 22.23069382], [72.89069366, 22.23097229], [72.89208221, 22.23097038], [72.89208221, 22.23125076], [72.89347076, 22.23125076], [72.89347076, 22.23152733], [72.8941803, 22.2315464], [72.89430237, 22.23155022], [72.89430237, 22.23180962], [72.89569092, 22.2318058], [72.89569092, 22.23208237], [72.89821625, 22.23208427], [72.89930725, 22.23208427], [72.89930725, 22.23221016], [72.89930725, 22.23236084], [72.89985657, 22.23236084], [72.89985657, 22.23264122], [72.90014648, 22.23264122], [72.90014648, 22.23291969], [72.90097046, 22.23291588], [72.90097046, 22.23347282], [72.9015274, 22.23347092], [72.9015274, 22.23402977], [72.90180206, 22.23402977], [72.90180206, 22.23431015], [72.90235901, 22.23430443], [72.90235901, 22.2345829], [72.9026413, 22.23458099], [72.9026413, 22.23513985], [72.90291595, 22.23513985], [72.90291595, 22.23542023], [72.90319824, 22.23541641], [72.90319824, 22.23624992], [72.9034729, 22.23624992], [72.9034729, 22.2365303], [72.90374756, 22.23652649], [72.90374756, 22.23708344], [72.90402985, 22.23707962], [72.90402985, 22.23765182], [72.90429688, 22.23765182], [72.90429688, 22.23792076], [72.90486145, 22.23791885], [72.90486145, 22.23819351], [72.90513611, 22.2381897], [72.90513611, 22.23875046], [72.9054184, 22.23875046], [72.9054184, 22.23903084], [72.90569305, 22.23903084], [72.90569305, 22.23930931], [72.90597534, 22.2393055], [72.90597534, 22.23985863], [72.90651703, 22.23985863], [72.90651703, 22.24014091], [72.9070816, 22.24014091], [72.9070816, 22.24069405], [72.90763855, 22.24069405], [72.90763855, 22.24097252], [72.90791321, 22.24097252], [72.90791321, 22.2412529], [72.90820313, 22.2412529], [72.90820313, 22.24180984], [72.90847015, 22.24180603], [72.90847015, 22.2420826], [72.90901947, 22.2420826], [72.90901947, 22.24263954], [72.90957642, 22.24263954], [72.90957642, 22.24291992], [72.91014099, 22.24291611], [72.91014099, 22.24319458], [72.91042328, 22.24319267], [72.91042328, 22.24403], [72.91069794, 22.24402809], [72.91069794, 22.24458313], [72.91124725, 22.24458122], [72.91124725, 22.24514008], [72.91152954, 22.24514008], [72.91152954, 22.24542046], [72.9118042, 22.24541664], [72.9118042, 22.24597168], [72.91208649, 22.24597168], [72.91208649, 22.24652863], [72.91236115, 22.246521], [72.91236115, 22.24681091], [72.9126358, 22.24681091], [72.9126358, 22.24736023], [72.91291809, 22.24736023], [72.91291809, 22.24764061], [72.91319275, 22.2476387], [72.91319275, 22.24819374], [72.91347504, 22.24819374], [72.91347504, 22.24847221], [72.91374969, 22.24847031], [72.91374969, 22.24875069], [72.91401672, 22.24875069], [72.91401672, 22.24930954], [72.91430664, 22.24930954], [72.91430664, 22.24986076], [72.9145813, 22.24986076], [72.9145813, 22.25041962], [72.91486359, 22.2504158], [72.91486359, 22.25097275], [72.91514587, 22.25097084], [72.91514587, 22.25152969], [72.9154129, 22.25152969], [72.9154129, 22.25265121], [72.91569519, 22.25264168], [72.91569519, 22.25319481], [72.91596985, 22.25319481], [72.91596985, 22.25346947], [72.91625214, 22.25346947], [72.91625214, 22.25375175], [72.91652679, 22.25375175], [72.91652679, 22.25430489], [72.91680908, 22.25430489], [72.91680908, 22.25458336], [72.91707611, 22.25457954], [72.91707611, 22.25542068], [72.9173584, 22.25542068], [72.9173584, 22.2557106], [72.91764069, 22.2557106], [72.91764069, 22.25625038], [72.91791534, 22.25625038], [72.91791534, 22.25708389], [72.91821289, 22.25708008], [72.91821289, 22.25792122], [72.91847229, 22.2579174], [72.91847229, 22.25847244], [72.91874695, 22.25846291], [72.91874695, 22.25930977], [72.91902924, 22.25930977], [72.91902924, 22.25986099], [72.91930389, 22.25986099], [72.91930389, 22.2606945], [72.91958618, 22.26069069], [72.91958618, 22.26263809], [72.91930389, 22.26263618], [72.91930389, 22.2666111], [72.91930389, 22.2681942], [72.91958618, 22.2681942], [72.91958618, 22.26958275], [72.91929626, 22.26958275], [72.91929626, 22.27042007], [72.91902924, 22.27042007], [72.91902924, 22.27124977], [72.91874695, 22.27124977], [72.91874695, 22.27264023], [72.91847229, 22.27263832], [72.91847229, 22.27347183], [72.91821289, 22.27346992], [72.91821289, 22.27403069], [72.91791534, 22.27402687], [72.91791534, 22.27458382], [72.91764069, 22.27458], [72.91764069, 22.27486038], [72.9173584, 22.27486038], [72.9173584, 22.27542114], [72.91708374, 22.27541542], [72.91708374, 22.27597237], [72.91680908, 22.27597046], [72.91680908, 22.27653122], [72.91652679, 22.27652931], [72.91652679, 22.27708244], [72.91625214, 22.27708054], [72.91625214, 22.27763748], [72.91596985, 22.27763748], [72.91596985, 22.27819443], [72.91513824, 22.27819443], [72.91513824, 22.27791595], [72.9145813, 22.27791977], [72.9145813, 22.27763748], [72.91430664, 22.27763748], [72.91430664, 22.27736092], [72.91401672, 22.27736092], [72.91401672, 22.27708054], [72.91374969, 22.27708244], [72.91374969, 22.27680779], [72.91348267, 22.27681923], [72.91348267, 22.27653122], [72.91319275, 22.27653122], [72.91319275, 22.27597046], [72.91291809, 22.27597237], [72.91291809, 22.27569389], [72.9126358, 22.27569389], [72.9126358, 22.27541542], [72.91236115, 22.27542114], [72.91236115, 22.27514076], [72.91208649, 22.27514076], [72.91208649, 22.27292061], [72.91236115, 22.27292061], [72.91236115, 22.26931], [72.91208649, 22.26931], [72.91208649, 22.2670784], [72.9118042, 22.26708412], [72.9118042, 22.26625061], [72.91152954, 22.26625061], [72.91152954, 22.26614952], [72.91152954, 22.2654171], [72.91124725, 22.26542091], [72.91124725, 22.26458931], [72.9109726, 22.26458931], [72.9109726, 22.26374817], [72.91069794, 22.26374817], [72.91069794, 22.26263809], [72.91042328, 22.26263809], [72.91042328, 22.2618103], [72.91014099, 22.2618103], [72.91014099, 22.26097107], [72.9098587, 22.26097298], [72.9098587, 22.26013947], [72.90957642, 22.26013947], [72.90957642, 22.25930977], [72.90930176, 22.25930977], [72.90930176, 22.25875092], [72.90901947, 22.25875092], [72.90901947, 22.25846291], [72.90875244, 22.25847244], [72.90875244, 22.25819206], [72.90847015, 22.25819206], [72.90847015, 22.2579174], [72.90820313, 22.25792122], [72.90820313, 22.25736046], [72.90791321, 22.25736046], [72.90791321, 22.25708008], [72.90763855, 22.25708389], [72.90763855, 22.25680542], [72.90735626, 22.25681114], [72.90735626, 22.25653076], [72.9070816, 22.25653076], [72.9070816, 22.25625038], [72.90680695, 22.25625038], [72.90680695, 22.2557106], [72.90651703, 22.2557106], [72.90651703, 22.25542068], [72.90625, 22.25542068], [72.90625, 22.2551403], [72.90598297, 22.2551403], [72.90598297, 22.25457954], [72.90569305, 22.25458336], [72.90569305, 22.25430489], [72.9054184, 22.25430489], [72.9054184, 22.25402832], [72.90513611, 22.25403023], [72.90513611, 22.25346947], [72.90486145, 22.25346947], [72.90486145, 22.25319481], [72.90458679, 22.25319481], [72.90458679, 22.25291634], [72.90429688, 22.25292015], [72.90429688, 22.25235748], [72.90402985, 22.2523613], [72.90402985, 22.25208282], [72.90374756, 22.25208282], [72.90374756, 22.25180626], [72.9034729, 22.25180817], [72.9034729, 22.25152969], [72.90320587, 22.25152969], [72.90319061, 22.25125122], [72.90291595, 22.25125122], [72.90291595, 22.25097084], [72.9026413, 22.25097275], [72.9026413, 22.25069427], [72.90208435, 22.25069427], [72.90208435, 22.2504158], [72.90180206, 22.25041962], [72.90180206, 22.25014114], [72.9015274, 22.25014114], [72.9015274, 22.24986076], [72.90125275, 22.24986076], [72.90125275, 22.24958992], [72.90097046, 22.24958992], [72.90097046, 22.24930954], [72.9006958, 22.24930954], [72.9006958, 22.24903107], [72.90014648, 22.24903107], [72.90014648, 22.24875069], [72.89958191, 22.24875069], [72.89958191, 22.24847031], [72.89930725, 22.24847221], [72.89930725, 22.24819374], [72.89875031, 22.24819374], [72.89875031, 22.24791527], [72.89819336, 22.24792099], [72.89819336, 22.24764061], [72.89763641, 22.24764061], [72.89763641, 22.24736023], [72.89707947, 22.24736023], [72.89707947, 22.24707985], [72.89653015, 22.24708366], [72.89653015, 22.24680519], [72.89624786, 22.24681091], [72.89624786, 22.246521], [72.89569092, 22.24652863], [72.89569092, 22.24625015], [72.8951416, 22.24625015], [72.8951416, 22.24596977], [72.89458466, 22.24597168], [72.89458466, 22.24569321], [72.89375305, 22.24570084], [72.89375305, 22.24542046], [72.89290619, 22.24542046], [72.89290619, 22.24514008], [72.89180756, 22.24514008], [72.89180756, 22.2448597], [72.89097595, 22.2448616], [72.89097595, 22.24458313], [72.89013672, 22.24458313], [72.89013672, 22.24430466], [72.88930511, 22.24430466], [72.88930511, 22.24402809], [72.88819122, 22.24403], [72.88819122, 22.24374962], [72.88625336, 22.24374962], [72.88625336, 22.24346161], [72.88541412, 22.24347115], [72.88541412, 22.24319458], [72.88486481, 22.24319458], [72.88486481, 22.24291611], [72.8840332, 22.24291992], [72.8840332, 22.24263954], [72.88346863, 22.24263954], [72.88346863, 22.24236107], [72.87264252, 22.24236107], [72.87264252, 22.24263954], [72.86680603, 22.24263954], [72.86680603, 22.24291992], [72.86597443, 22.24291611], [72.86597443, 22.24319458], [72.86569214, 22.24319458], [72.86569214, 22.24347115], [72.86514282, 22.24346161], [72.86514282, 22.24403], [72.86458588, 22.24402809], [72.86458588, 22.24430466], [72.86430359, 22.24430466], [72.86430359, 22.2448616], [72.86403656, 22.2448597], [72.86403656, 22.24542046], [72.86374664, 22.24542046], [72.86374664, 22.24625015], [72.86347198, 22.24625015], [72.86347198, 22.24652863], [72.86319733, 22.246521], [72.86319733, 22.24764061], [72.86291504, 22.2476387], [72.86291504, 22.24819374], [72.86264038, 22.24818993], [72.86264038, 22.24903107], [72.86235809, 22.24903107], [72.86235809, 22.24930954], [72.86207581, 22.24930954], [72.86207581, 22.25014114], [72.86152649, 22.25014114], [72.86152649, 22.25041962], [72.86125183, 22.2504158], [72.86125183, 22.25069427], [72.86096954, 22.25069427], [72.86096954, 22.25097275], [72.86067963, 22.25097084], [72.86067963, 22.25152969], [72.86042023, 22.25152969], [72.86042023, 22.25208282], [72.86013794, 22.25208282], [72.86013794, 22.2523613], [72.85958099, 22.25235748], [72.85958099, 22.25403023], [72.85930634, 22.25402832], [72.85930634, 22.25458336], [72.85901642, 22.25457954], [72.85901642, 22.25542068], [72.85874939, 22.25542068], [72.85874939, 22.25625038], [72.8584671, 22.25625038], [72.8584671, 22.25681114], [72.85819244, 22.25681114], [72.85819244, 22.25764084], [72.85791779, 22.25763893], [72.85791779, 22.25819206], [72.8576355, 22.25819206], [72.8576355, 22.25958252], [72.85736084, 22.25958061], [72.85736084, 22.26041985], [72.85708618, 22.26041985], [72.85708618, 22.26152992], [72.85679626, 22.26152992], [72.85679626, 22.2618103], [72.85652924, 22.2618103], [72.85652924, 22.26292038], [72.85624695, 22.26291847], [72.85624695, 22.2634716], [72.85597229, 22.2634697], [72.85597229, 22.26431084], [72.85569763, 22.26431084], [72.85569763, 22.26680946], [72.85542297, 22.26680946], [72.85542297, 22.26875114], [72.85514069, 22.26874924], [72.85514069, 22.27069473], [72.8548584, 22.27069473], [72.8548584, 22.27180481], [72.85514069, 22.2718029], [72.85514069, 22.27264023], [72.8548584, 22.27263832], [72.8548584, 22.27297974], [72.85486603, 22.27431107], [72.85458374, 22.27430534], [72.85458374, 22.27569389], [72.85430908, 22.27569008], [72.85430908, 22.27736092], [72.85402679, 22.27736092], [72.85402679, 22.27819443], [72.85375214, 22.27819061], [72.85375214, 22.27902985], [72.85346985, 22.27902985], [72.85346985, 22.27939987], [72.85346985, 22.27959251], [72.85320282, 22.27959251], [72.85320282, 22.2804203], [72.8529129, 22.2804203], [72.8529129, 22.28125191], [72.85263824, 22.28125191], [72.85263824, 22.28181267], [72.85041809, 22.28180504], [72.85041809, 22.28208351], [72.8484726, 22.28208351], [72.8484726, 22.28236389], [72.84375, 22.28236389], [72.84375, 22.28208351], [72.84319305, 22.28208351], [72.84319305, 22.28180504], [72.84263611, 22.28181267], [72.84263611, 22.28153038], [72.84179688, 22.28153038], [72.84179688, 22.28125191], [72.84124756, 22.28125191], [72.84124756, 22.28097153], [72.84069824, 22.28097153], [72.84069061, 22.28069496], [72.8401413, 22.28070259], [72.8401413, 22.2804203], [72.83957672, 22.2804203], [72.83957672, 22.28014183], [72.83875275, 22.28014183], [72.83875275, 22.27986145], [72.8381958, 22.27986145], [72.8381958, 22.27958298], [72.83763885, 22.27959251], [72.83763885, 22.27931023], [72.83735657, 22.27931023], [72.83735657, 22.27902985], [72.83679962, 22.27902985], [72.83679962, 22.27874756], [72.83651733, 22.27874756], [72.83651733, 22.27846909], [72.83597565, 22.2784729], [72.83597565, 22.27819443], [72.83513641, 22.27819443], [72.83513641, 22.27791595], [72.83486176, 22.27791977], [72.83486176, 22.27763748], [72.8345871, 22.27763748], [72.8345871, 22.27736092], [72.83403015, 22.27736092], [72.83403015, 22.27708054], [72.83347321, 22.27708244], [72.83347321, 22.27680779], [72.83319092, 22.27681923], [72.83319092, 22.27653122], [72.8326416, 22.27653122], [72.8326416, 22.27625084], [72.83235931, 22.27625084], [72.83235931, 22.27597046], [72.83208466, 22.27597237], [72.83208466, 22.27569389], [72.83180237, 22.27569389], [72.83180237, 22.27541542], [72.83125305, 22.27542114], [72.83125305, 22.27514076], [72.83097076, 22.27514076], [72.83097076, 22.27486038], [72.83069611, 22.27486038], [72.83069611, 22.27458], [72.83013916, 22.27458382], [72.83013916, 22.27430534], [72.82985687, 22.27431107], [72.82985687, 22.27403069], [72.82930756, 22.27403069], [72.82930756, 22.27375031], [72.82875061, 22.27375031], [72.82875061, 22.27346992], [72.82819366, 22.27347183], [72.82819366, 22.27319336], [72.82763672, 22.27320099], [72.82763672, 22.27292061], [72.82736206, 22.27292061], [72.82736206, 22.27264023], [72.82681274, 22.27264023], [72.82681274, 22.27235985], [72.82624817, 22.27236176], [72.82624817, 22.27208328], [72.82569122, 22.27208328], [72.82569122, 22.27180481], [72.82514191, 22.27180481], [72.82514191, 22.27152824], [72.82457733, 22.27153015], [72.82457733, 22.27124977], [72.82402802, 22.27124977], [72.82402802, 22.27096939], [72.82319641, 22.2709713], [72.82319641, 22.27069473], [72.82263947, 22.27069473], [72.82263947, 22.27041626], [72.82180023, 22.27042007], [72.82180023, 22.27013969], [72.82125092, 22.27013969], [72.82125092, 22.26986122], [72.82041931, 22.26986122], [72.82041931, 22.26958275], [72.81986237, 22.26958275], [72.81986237, 22.26930618], [72.81903076, 22.26931], [72.81903076, 22.26902962], [72.81819153, 22.26902962], [72.81819153, 22.26875114], [72.81735992, 22.26875114], [72.81735992, 22.26847267], [72.81708527, 22.26847267], [72.81708527, 22.2681942], [72.81625366, 22.2681942], [72.81625366, 22.26791763], [72.81569672, 22.26791954], [72.81569672, 22.2676506], [72.81513977, 22.2676506], [72.81513977, 22.26736259], [72.81485748, 22.26736259], [72.81485748, 22.2670784], [72.81458282, 22.26708412], [72.81458282, 22.26680565], [72.81430817, 22.26680946], [72.81430817, 22.26652908], [72.81346893, 22.26652908], [72.81346893, 22.26625061], [72.81263733, 22.26625061], [72.81263733, 22.26596832], [72.81208038, 22.26597214], [72.81208038, 22.26569366], [72.81180573, 22.26569366], [72.81180573, 22.2654171], [72.81124878, 22.26542091], [72.81124878, 22.26514053], [72.81041718, 22.26514053], [72.81041718, 22.26485825], [72.81014252, 22.26486206], [72.81014252, 22.26458359], [72.80986023, 22.26458931], [72.80986023, 22.26431084], [72.8095932, 22.26431084], [72.8095932, 22.26403046], [72.80902863, 22.26403046], [72.80902863, 22.26374817], [72.80874634, 22.26374817], [72.80874634, 22.26320076], [72.80847168, 22.26320076], [72.80847168, 22.26292038], [72.8079071, 22.26292038], [72.8079071, 22.26263809], [72.80764008, 22.26263809], [72.80764008, 22.26208115], [72.80708313, 22.26208305], [72.80708313, 22.26152611], [72.80680084, 22.26152992], [72.80680084, 22.26124954], [72.80652618, 22.26124954], [72.80652618, 22.26097107], [72.80596924, 22.26097298], [72.80596924, 22.2606945], [72.80569458, 22.2606945], [72.80569458, 22.26041412], [72.80430603, 22.26041985], [72.80430603, 22.26013947], [72.8034668, 22.26013947], [72.8034668, 22.25986099], [72.80291748, 22.25986099], [72.80291748, 22.25958061], [72.80236053, 22.25958252], [72.80236053, 22.25930405], [72.80208588, 22.25930977], [72.80208588, 22.25902939], [72.80179596, 22.25902939], [72.80179596, 22.25875092], [72.80152893, 22.25875092], [72.80152893, 22.25846291], [72.80097198, 22.25847244], [72.80097198, 22.25819206], [72.80069733, 22.25819206], [72.80069733, 22.2579174], [72.79930878, 22.25792122], [72.79930878, 22.25764084], [72.79902649, 22.25764084], [72.79902649, 22.25736046], [72.79875183, 22.25736046], [72.79875183, 22.25681114], [72.79736328, 22.25681114], [72.79736328, 22.25653076], [72.79708099, 22.25653076], [72.79708099, 22.25625038], [72.79680634, 22.25625038], [72.79680634, 22.25597191], [72.79624939, 22.25597382], [72.79624939, 22.25569534], [72.79541779, 22.2557106], [72.79541779, 22.25541687], [72.79532623, 22.25541878], [72.79514313, 22.25542068], [72.79514313, 22.2551403], [72.79486084, 22.2551403], [72.79486084, 22.25457954], [72.79458618, 22.25458336], [72.79458618, 22.25430489], [72.79402924, 22.25430489], [72.79402924, 22.25402832], [72.79292297, 22.25403023], [72.79292297, 22.25375175], [72.79264069, 22.25375175], [72.79264069, 22.25346947], [72.7923584, 22.25346947], [72.7923584, 22.25319481], [72.79208374, 22.25319481], [72.79208374, 22.25291634], [72.79181671, 22.25292015], [72.79181671, 22.25265121], [72.79152679, 22.25265121], [72.79152679, 22.25235748], [72.79125214, 22.2523613], [72.79125214, 22.25208282], [72.79069519, 22.25208282], [72.79069519, 22.25180626], [72.7904129, 22.25180817], [72.7904129, 22.25152969], [72.7895813, 22.25152969], [72.7895813, 22.25125122], [72.78930664, 22.25125122], [72.78930664, 22.25097084], [72.78902435, 22.25097275], [72.78902435, 22.25069427], [72.78847504, 22.25069427], [72.78847504, 22.2504158], [72.78819275, 22.25041962], [72.78819275, 22.24986076], [72.78791809, 22.24986076], [72.78791809, 22.24958992], [72.7876358, 22.24958992], [72.7876358, 22.24930954], [72.78708649, 22.24930954], [72.78708649, 22.24875069], [72.78679657, 22.24875069], [72.78679657, 22.24847031], [72.78624725, 22.24847221], [72.78624725, 22.24819374], [72.7859726, 22.24819374], [72.7859726, 22.24791527], [72.78569031, 22.24792099], [72.78569031, 22.24764061], [72.7848587, 22.24764061], [72.7848587, 22.24736023], [72.78457642, 22.24736023], [72.78457642, 22.24707985], [72.78430176, 22.24708366], [72.78430176, 22.24680519], [72.7840271, 22.24681091], [72.7840271, 22.246521], [72.78347015, 22.24652863], [72.78347015, 22.24625015], [72.7831955, 22.24625015], [72.7831955, 22.24597168], [72.78291321, 22.24597168], [72.78291321, 22.24569321], [72.78263092, 22.24570084], [72.78263092, 22.24542046], [72.78235626, 22.24542046], [72.78235626, 22.2448597], [72.7820816, 22.2448616], [72.7820816, 22.24458313], [72.78152466, 22.24458313], [72.78152466, 22.24430466], [72.78125, 22.24430466], [72.78125, 22.24402809], [72.78069305, 22.24403], [72.78069305, 22.24374962], [72.7804184, 22.24374962], [72.7804184, 22.24346161], [72.77902985, 22.24347115], [72.77902985, 22.24291611], [72.77874756, 22.24291992], [72.77874756, 22.24263954], [72.77791595, 22.24263954], [72.77791595, 22.24236107], [72.7776413, 22.24236107], [72.7776413, 22.2420826], [72.77708435, 22.2420826], [72.77708435, 22.24180603], [72.77680206, 22.24180984], [72.77680206, 22.24152946], [72.77625275, 22.24152946], [72.77625275, 22.2412529], [72.77597046, 22.2412529], [72.77597046, 22.24097252], [72.77513885, 22.24097252], [72.77513885, 22.24069405], [72.77458191, 22.24069405], [72.77458191, 22.24041748], [72.77403259, 22.24041939], [72.77403259, 22.24014091], [72.77375031, 22.24014091], [72.77375031, 22.23985863], [72.77319336, 22.23985863], [72.77319336, 22.23957825], [72.7729187, 22.23958397], [72.7729187, 22.2393055], [72.77236176, 22.23930931], [72.77236176, 22.23903084], [72.7720871, 22.23903084], [72.7720871, 22.23875046], [72.77179718, 22.23875046], [72.77179718, 22.23846817], [72.77153015, 22.23847008], [72.77153015, 22.23819542], [72.77069092, 22.2381897], [72.77069092, 22.23791885], [72.76985931, 22.23792076], [72.76985931, 22.23765182], [72.76957703, 22.23765182], [72.76957703, 22.23735809], [72.76930237, 22.23736191], [72.76930237, 22.23708344], [72.76847076, 22.23708344], [72.76847076, 22.23680496], [72.76790619, 22.23681068], [72.76790619, 22.2365303], [72.76764679, 22.2365303], [72.76764679, 22.23624992], [72.76735687, 22.23624992], [72.76735687, 22.23596954], [72.76708221, 22.23597145], [72.76708221, 22.23569679], [72.76652527, 22.23569679], [72.76652527, 22.23541641], [72.76625061, 22.23542023], [72.76625061, 22.23513985], [72.76597595, 22.23513985], [72.76597595, 22.23485947], [72.76541901, 22.23486137], [72.76541901, 22.2345829], [72.76513672, 22.2345829], [72.76513672, 22.23430443], [72.7645874, 22.23431015], [72.7645874, 22.23402977], [72.76403046, 22.23402977], [72.76403046, 22.23374939], [72.76346588, 22.23374939], [72.76346588, 22.23347092], [72.76319122, 22.23347282], [72.76319122, 22.23319435], [72.76264191, 22.23319435], [72.76264191, 22.23291588], [72.76209259, 22.23291969], [72.76209259, 22.23264122], [72.76152039, 22.23264122], [72.76152039, 22.23236084], [72.76069641, 22.23236084], [72.76069641, 22.23208046], [72.76013947, 22.23208427], [72.76013947, 22.2318058], [72.75930786, 22.23180962], [72.75930786, 22.2315197], [72.75736237, 22.23152733], [72.75736237, 22.23125076], [72.75596619, 22.23125076], [72.75596619, 22.23097038], [72.75208282, 22.23097038], [72.75208282, 22.23125076], [72.75096893, 22.23125076], [72.75096893, 22.23152733], [72.74958038, 22.2315197], [72.74958038, 22.23180962], [72.74930573, 22.2318058], [72.74930573, 22.23208427], [72.74736023, 22.23208046], [72.74736023, 22.23236084], [72.74402618, 22.23236084], [72.74402618, 22.23208046], [72.74375153, 22.23208046], [72.74375153, 22.23236084], [72.74291992, 22.23236084], [72.74291992, 22.23264122], [72.74153137, 22.23264122], [72.74153137, 22.23291969], [72.74124908, 22.23291969], [72.74124908, 22.23264122], [72.74069214, 22.23264122], [72.74069214, 22.23291969], [72.73986053, 22.23291588], [72.73986053, 22.23319435], [72.73902893, 22.23319435], [72.73902893, 22.23347282], [72.73735809, 22.23347092], [72.73735809, 22.23374939], [72.73625183, 22.23374939], [72.73625183, 22.23402977], [72.73513794, 22.23402977], [72.73513794, 22.23431015], [72.7326355, 22.23430443], [72.7326355, 22.2345829], [72.7298584, 22.2345829], [72.7298584, 22.23486137], [72.72902679, 22.23486137], [72.72902679, 22.2345829], [72.72875214, 22.2345829], [72.72875214, 22.23486137], [72.72735596, 22.23485947], [72.72735596, 22.23513985], [72.72680664, 22.23513985], [72.72680664, 22.23485947], [72.72624969, 22.23485947], [72.72624969, 22.23513985], [72.72458649, 22.23513985], [72.72458649, 22.23542023], [72.72208405, 22.23541641], [72.72208405, 22.23569679], [72.72041321, 22.23569679], [72.72041321, 22.23597145], [72.71847534, 22.23597145], [72.71848297, 22.23624992], [72.71457672, 22.23624992], [72.71457672, 22.2365303], [72.71180725, 22.2365303], [72.71180725, 22.23681068], [72.71153259, 22.23681068], [72.71153259, 22.2365303], [72.70903015, 22.2365303], [72.70903015, 22.23681068], [72.69625092, 22.23680496], [72.69625092, 22.23708344], [72.69152832, 22.23708344], [72.69152832, 22.23736191], [72.69097137, 22.23735809], [72.69097137, 22.23765182], [72.69013977, 22.23765182], [72.69013977, 22.23792076], [72.68930817, 22.23791885], [72.68930817, 22.2381897], [72.68875122, 22.23819542], [72.68875122, 22.23847008], [72.68791962, 22.23846817], [72.68791962, 22.23875046], [72.68763733, 22.23875046], [72.68763733, 22.23903084], [72.68736267, 22.23903084], [72.68736267, 22.23930931], [72.68708038, 22.2393055], [72.68708038, 22.23958397], [72.68680573, 22.23958397], [72.68681335, 22.23985863], [72.68653107, 22.23985863], [72.68653107, 22.24014091], [72.68624878, 22.24014091], [72.68624878, 22.24069405], [72.68597412, 22.24069405], [72.68597412, 22.24097252], [72.68569183, 22.24097252], [72.68569183, 22.2412529], [72.68541718, 22.2412529], [72.68541718, 22.24152946], [72.68514252, 22.24152946], [72.68514252, 22.24180984], [72.68486023, 22.24180603], [72.68486023, 22.2420826], [72.68458557, 22.2420826], [72.6845932, 22.24236107], [72.68430328, 22.24236107], [72.68430328, 22.24291992], [72.68402863, 22.24291611], [72.68402863, 22.24319458], [72.68374634, 22.24319267], [72.68374634, 22.24374962], [72.68347168, 22.24374962], [72.68347168, 22.24430466], [72.68319702, 22.24430466], [72.68319702, 22.2448616], [72.68235779, 22.2448597], [72.68235779, 22.24514008], [72.68208313, 22.24514008], [72.68208313, 22.24542046], [72.68180847, 22.24542046], [72.68180847, 22.24570084], [72.68152618, 22.24570084], [72.68152618, 22.24625015], [72.68125153, 22.24625015], [72.68125153, 22.24652863], [72.68096924, 22.246521], [72.68096924, 22.24681091], [72.68069458, 22.24680519], [72.68069458, 22.24708366], [72.68013763, 22.24707985], [72.68013763, 22.24736023], [72.67986298, 22.24736023], [72.67986298, 22.24764061], [72.67958069, 22.24764061], [72.67958069, 22.24792099], [72.67903137, 22.24791527], [72.67903137, 22.24819374], [72.67874908, 22.24819374], [72.67874908, 22.24847221], [72.6784668, 22.24847031], [72.6784668, 22.24875069], [72.67819214, 22.24875069], [72.67819214, 22.24903107], [72.67764282, 22.24903107], [72.67764282, 22.24930954], [72.67736816, 22.24930954], [72.67736816, 22.24958992], [72.67708588, 22.24958992], [72.67708588, 22.24986076], [72.67679596, 22.24986076], [72.67679596, 22.25014114], [72.67652893, 22.25014114], [72.67652893, 22.25041962], [72.67514038, 22.2504158], [72.67514038, 22.25069427], [72.67485809, 22.25069046], [72.67485809, 22.25125122], [72.67457581, 22.25125122], [72.67457581, 22.25152969], [72.67430115, 22.25152969], [72.67430115, 22.25180817], [72.67346954, 22.25180626], [72.67346954, 22.25208282], [72.67318726, 22.25208092], [72.67318726, 22.25265121], [72.67292023, 22.25265121], [72.67292023, 22.25292015], [72.67263794, 22.25291634], [72.67263794, 22.25319481], [72.67236328, 22.25319481], [72.67236328, 22.25346947], [72.67208099, 22.25346947], [72.67208099, 22.25403023], [72.67180634, 22.25402832], [72.67180634, 22.25430489], [72.67152405, 22.25430489], [72.67152405, 22.25458336], [72.67124939, 22.25458336], [72.67124939, 22.25486183], [72.67069244, 22.25486183], [72.67069244, 22.25542068], [72.67041779, 22.25541687], [72.67041779, 22.25597382], [72.67014313, 22.25597191], [72.67014313, 22.25653076], [72.66986084, 22.25653076], [72.66986084, 22.25681114], [72.66958618, 22.25680542], [72.66958618, 22.25708389], [72.66902924, 22.25708008], [72.66902924, 22.25764084], [72.66874695, 22.25764084], [72.66874695, 22.25792122], [72.66847229, 22.2579174], [72.66847229, 22.25819206], [72.66819763, 22.25819206], [72.66819763, 22.25847244], [72.66791534, 22.25847244], [72.66792297, 22.25875092], [72.66764069, 22.25875092], [72.66764069, 22.25902939], [72.6673584, 22.25902939], [72.6673584, 22.25930977], [72.66708374, 22.25930405], [72.66708374, 22.25958252], [72.66680908, 22.25958061], [72.66680908, 22.26013947], [72.66652679, 22.26013947], [72.66652679, 22.26041985], [72.66625214, 22.26041412], [72.66625214, 22.2606945], [72.66569519, 22.2606945], [72.66569519, 22.26097298], [72.6654129, 22.26097107], [72.6654129, 22.26124954], [72.66513824, 22.26124954], [72.66513824, 22.2618103], [72.66486359, 22.2618084], [72.66486359, 22.26236153], [72.6645813, 22.26235962], [72.6645813, 22.26292038], [72.66430664, 22.26292038], [72.66430664, 22.26320076], [72.66401672, 22.26320076], [72.66401672, 22.26374817], [72.66374969, 22.26374817], [72.66374969, 22.26403046], [72.66348267, 22.26403046], [72.66348267, 22.26431084], [72.66291809, 22.26431084], [72.66291809, 22.26458931], [72.6626358, 22.26458359], [72.6626358, 22.26486206], [72.66236115, 22.26485825], [72.66236115, 22.26514053], [72.66208649, 22.26514053], [72.66208649, 22.26542091], [72.6618042, 22.2654171], [72.6618042, 22.26597214], [72.66152954, 22.26596832], [72.66152954, 22.26625061], [72.6609726, 22.26625061], [72.6609726, 22.26680946], [72.66041565, 22.26680565], [72.66042328, 22.26736259], [72.66014099, 22.26736259], [72.66014099, 22.2676506], [72.6598587, 22.26763916], [72.6598587, 22.2681942], [72.65930939, 22.2681942], [72.65930176, 22.26847267], [72.6590271, 22.26847267], [72.6590271, 22.26875114], [72.65875244, 22.26875114], [72.65875244, 22.26931], [72.65847015, 22.26931], [72.65847015, 22.26986122], [72.65820313, 22.26986122], [72.65820313, 22.27403069], [72.65847015, 22.27403069], [72.65847015, 22.27431107], [72.65820313, 22.27431107], [72.65820313, 22.27542114], [72.65791321, 22.27541542], [72.65791321, 22.27569389], [72.6581955, 22.27569389], [72.6581955, 22.27597237], [72.65791321, 22.27597046], [72.65791321, 22.27653122], [72.65763855, 22.27653122], [72.65763855, 22.27681923], [72.65735626, 22.27681923], [72.65735626, 22.27736092], [72.6570816, 22.27736092], [72.6570816, 22.27791977], [72.65680695, 22.27791595], [72.65680695, 22.27819443], [72.65651703, 22.27819061], [72.65652466, 22.27874756], [72.65625763, 22.27874756], [72.65625763, 22.27902985], [72.65569305, 22.27902985], [72.65569305, 22.27931023], [72.65513611, 22.27931023], [72.65513611, 22.27959251], [72.65458679, 22.27958298], [72.65458679, 22.27986145], [72.65402985, 22.27986145], [72.65402985, 22.28014183], [72.65291595, 22.28014183], [72.65291595, 22.2804203], [72.65180206, 22.2804203], [72.65180206, 22.28070259], [72.65097046, 22.28069496], [72.65097046, 22.28097153], [72.64985657, 22.28097153], [72.6498642, 22.28125191], [72.64903259, 22.28125191], [72.64903259, 22.28153038], [72.6479187, 22.28153038], [72.6479187, 22.28181267], [72.64736176, 22.28180504], [72.64736176, 22.28208351], [72.64541626, 22.28208351], [72.64541626, 22.28236389], [72.64375305, 22.28236389], [72.64375305, 22.28263855], [72.64263916, 22.28263283], [72.64263916, 22.28292084], [72.6423645, 22.28291702], [72.6423645, 22.28319359], [72.64214325, 22.28319359], [72.64152527, 22.28319359], [72.64152527, 22.28347206], [72.64097595, 22.28347206], [72.64097595, 22.28335953], [72.64097595, 22.28319359], [72.64041901, 22.28319359], [72.64041901, 22.28347206], [72.64025879, 22.28347206], [72.63930511, 22.28347206], [72.63930511, 22.28360939], [72.63931274, 22.28375053], [72.63874817, 22.28375053], [72.63874817, 22.28403091], [72.63709259, 22.28403091], [72.63709259, 22.28430939], [72.63541412, 22.28430557], [72.63541412, 22.28458214], [72.63430786, 22.28458214], [72.63430786, 22.28430557], [72.63291931, 22.28430557], [72.63291931, 22.28458214], [72.63153076, 22.28458214], [72.63153076, 22.28430557], [72.62985992, 22.28430939], [72.62985992, 22.28403091], [72.62763977, 22.28403091], [72.62763977, 22.28375053], [72.62708282, 22.28375053], [72.62708282, 22.28347015], [72.62652588, 22.28347206], [72.62652588, 22.28319359], [72.62513733, 22.28319359], [72.62513733, 22.28291702], [72.62374878, 22.28292084], [72.62374878, 22.28263283], [72.62319183, 22.28263855], [72.62319183, 22.28236389], [72.62236023, 22.28236389], [72.62236023, 22.28208351], [72.62152863, 22.28208351], [72.62152863, 22.28180504], [72.62069702, 22.28181267], [72.62069702, 22.28153038], [72.61985779, 22.28153038], [72.61985779, 22.28125191], [72.61902618, 22.28125191], [72.61902618, 22.28097153], [72.61736298, 22.28097153], [72.61736298, 22.28069496], [72.61569214, 22.28070259], [72.61569214, 22.2804203], [72.61402893, 22.2804203], [72.61402893, 22.28014183], [72.61292267, 22.28014183], [72.61292267, 22.2804203], [72.61264038, 22.2804203], [72.61264038, 22.28014183], [72.61207581, 22.28014183], [72.61207581, 22.27986145], [72.61042023, 22.27986145], [72.61042023, 22.27958298], [72.60986328, 22.27959251], [72.60986328, 22.27931023], [72.6084671, 22.27931023], [72.6084671, 22.27902985], [72.60764313, 22.27902985], [72.60764313, 22.27874756], [72.60736084, 22.27874756], [72.60736084, 22.27846909], [72.60680389, 22.2784729], [72.60680389, 22.27819443], [72.60624695, 22.27819443], [72.60624695, 22.27791595], [72.60597229, 22.27791977], [72.60597229, 22.27763748], [72.60541534, 22.27763748], [72.60541534, 22.27736092], [72.6048584, 22.27736092], [72.6048584, 22.27708054], [72.60430908, 22.27708244], [72.60430908, 22.27680779], [72.60375214, 22.27681923], [72.60375214, 22.27653122], [72.60346985, 22.27653122], [72.60346985, 22.27625084], [72.60319519, 22.27625084], [72.60319519, 22.27597237], [72.6029129, 22.27597237], [72.6029129, 22.27569389], [72.60236359, 22.27569389], [72.60236359, 22.27513885], [72.60151672, 22.27514076], [72.60151672, 22.27486038], [72.6001358, 22.27486038], [72.6001358, 22.27458], [72.5993042, 22.27458382], [72.5993042, 22.27430534], [72.5984726, 22.27431107], [72.5984726, 22.27403069], [72.5973587, 22.27403069], [72.5973587, 22.27375031], [72.5965271, 22.27375031], [72.5965271, 22.27346992], [72.59597015, 22.27347183], [72.59597015, 22.27319336], [72.59570313, 22.27320099], [72.59570313, 22.27292061], [72.59541321, 22.27292061], [72.59541321, 22.27264023], [72.59485626, 22.27264023], [72.59485626, 22.27235985], [72.5945816, 22.27236176], [72.5945816, 22.27208328], [72.59402466, 22.27208328], [72.59402466, 22.27180481], [72.59347534, 22.27180481], [72.59347534, 22.27152824], [72.59319305, 22.27153015], [72.59319305, 22.27124977], [72.5929184, 22.27124977], [72.5929184, 22.27096939], [72.59263611, 22.2709713], [72.59263611, 22.27069473], [72.59236145, 22.27069473], [72.59236145, 22.27041626], [72.59208679, 22.27042007], [72.59208679, 22.27013969], [72.59152985, 22.27013969], [72.59152985, 22.26986122], [72.59124756, 22.26986122], [72.59124756, 22.26958275], [72.5909729, 22.26958275], [72.5909729, 22.26902771], [72.59069824, 22.26902962], [72.59069061, 22.26847267], [72.59041595, 22.26847267], [72.59041595, 22.2681942], [72.5901413, 22.2681942], [72.5901413, 22.26791763], [72.58957672, 22.26791954], [72.58957672, 22.2676506], [72.58930206, 22.2676506], [72.58930206, 22.26736259], [72.5890274, 22.26736259], [72.5890274, 22.26680946], [72.58875275, 22.26680946], [72.58875275, 22.26652908], [72.58790588, 22.26652908], [72.58790588, 22.26625061], [72.58735657, 22.26625061], [72.58735657, 22.26596832], [72.58708191, 22.26597214], [72.58708191, 22.26569366], [72.58625031, 22.26569366], [72.58625031, 22.2654171], [72.58598328, 22.26542091], [72.58598328, 22.26514053], [72.5854187, 22.26514053], [72.5854187, 22.26485825], [72.58513641, 22.26486206], [72.58513641, 22.26458359], [72.58486176, 22.26458931], [72.58486176, 22.26403046], [72.5845871, 22.26403046], [72.5845871, 22.26374817], [72.58429718, 22.26374817], [72.58429718, 22.26320076], [72.58402252, 22.26320076], [72.58402252, 22.26292038], [72.58374786, 22.26292038], [72.58374786, 22.26263809], [72.58319092, 22.26263809], [72.58319092, 22.26235962], [72.58291626, 22.26236153], [72.58291626, 22.26208305], [72.5826416, 22.26208305], [72.5826416, 22.2618084], [72.58235931, 22.2618103], [72.58235931, 22.26152992], [72.58180237, 22.26152992], [72.58180237, 22.26124954], [72.58152771, 22.26124954], [72.58152771, 22.26097107], [72.58125305, 22.26097298], [72.58125305, 22.2606945], [72.58097076, 22.2606945], [72.58097076, 22.26041412], [72.58040619, 22.26041985], [72.58040619, 22.26013947], [72.58013916, 22.26013947], [72.58013916, 22.25986099], [72.57958221, 22.25986099], [72.57958221, 22.25958061], [72.57930756, 22.25958252], [72.57930756, 22.25930405], [72.5790329, 22.25930977], [72.5790329, 22.25902939], [72.57847595, 22.25902939], [72.57847595, 22.25846291], [72.57819366, 22.25847244], [72.57819366, 22.25819206], [72.57763672, 22.25819206], [72.57763672, 22.2579174], [72.57736206, 22.25792122], [72.57736206, 22.25764084], [72.57681274, 22.25764084], [72.57681274, 22.25736046], [72.57653046, 22.25736046], [72.57653046, 22.25708008], [72.57624817, 22.25708389], [72.57624817, 22.25680542], [72.57596588, 22.25681114], [72.57596588, 22.25653076], [72.57541656, 22.25653076], [72.57541656, 22.25625038], [72.57514191, 22.25625038], [72.57514191, 22.25597191], [72.57485962, 22.25597382], [72.57485962, 22.25569534], [72.57459259, 22.2557106], [72.57459259, 22.25542068], [72.57402802, 22.25542068], [72.57402802, 22.2551403], [72.57347107, 22.2551403], [72.57347107, 22.25486183], [72.57319641, 22.25486183], [72.57319641, 22.25458336], [72.57125092, 22.25458336], [72.57125092, 22.25486183], [72.57096863, 22.25486183], [72.57096863, 22.25681114], [72.57125092, 22.25681114], [72.57125092, 22.25764084], [72.57096863, 22.25764084], [72.57096863, 22.25792122], [72.57068634, 22.25792122], [72.57068634, 22.25764084], [72.57041931, 22.25764084], [72.57041931, 22.25597191], [72.57013702, 22.25597382], [72.57013702, 22.25541687], [72.56958008, 22.25542068], [72.56958008, 22.2551403], [72.56846619, 22.2551403], [72.56846619, 22.25486183], [72.56819153, 22.25486183], [72.56819153, 22.25458336], [72.56764221, 22.25458336], [72.56764221, 22.25430489], [72.56735992, 22.25430489], [72.56735992, 22.25402832], [72.56680298, 22.25403023], [72.56680298, 22.25375175], [72.56652832, 22.25375175], [72.56652832, 22.25346947], [72.56625366, 22.25346947], [72.56625366, 22.25319481], [72.56597137, 22.25319481], [72.56597137, 22.25291634], [72.56569672, 22.25292015], [72.56569672, 22.25180817], [72.5654068, 22.25180817], [72.5654068, 22.25152969], [72.56458282, 22.25152969], [72.56458282, 22.25125122], [72.56430817, 22.25125122], [72.56430817, 22.25069046], [72.56402588, 22.25069427], [72.56402588, 22.25013733], [72.56375122, 22.25014114], [72.56375122, 22.24986076], [72.56346893, 22.24986076], [72.56346893, 22.24958992], [72.56318665, 22.24958992], [72.56318665, 22.24930954], [72.56236267, 22.24930954], [72.56236267, 22.24903107], [72.56208038, 22.24903107], [72.56208038, 22.24875069], [72.56180573, 22.24875069], [72.56180573, 22.24847221], [72.56153107, 22.24847221], [72.56153107, 22.24819374], [72.56124878, 22.24819374], [72.56124878, 22.2476387], [72.56096649, 22.24764061], [72.56096649, 22.24681091], [72.56041718, 22.24681091], [72.56041718, 22.246521], [72.56014252, 22.24652863], [72.56014252, 22.24625015], [72.5598526, 22.24625015], [72.5598526, 22.24596977], [72.55958557, 22.24597168], [72.55958557, 22.24875069], [72.5598526, 22.24875069], [72.5598526, 22.24930954], [72.56014252, 22.24930954], [72.56014252, 22.24958992], [72.56096649, 22.24958992], [72.56096649, 22.25152969], [72.56069183, 22.25152969], [72.56069183, 22.25346947], [72.56096649, 22.25346947], [72.56096649, 22.25625038], [72.56124878, 22.25625038], [72.56124878, 22.25653076], [72.56153107, 22.25653076], [72.56153107, 22.25764084], [72.56124878, 22.25763893], [72.56124878, 22.25847244], [72.56096649, 22.25846291], [72.56096649, 22.25902939], [72.56014252, 22.25902939], [72.56014252, 22.25930977], [72.55980682, 22.25930405], [72.55735779, 22.25930977], [72.55735779, 22.25877953], [72.55708313, 22.25875092], [72.55708313, 22.25846291], [72.55735779, 22.25847244], [72.55735779, 22.25819206], [72.55708313, 22.25819206], [72.55708313, 22.25708389], [72.55680847, 22.25708389], [72.55680847, 22.25625038], [72.55652618, 22.25625038], [72.55652618, 22.25597191], [72.55625153, 22.25597382], [72.55625153, 22.25541687], [72.55486298, 22.25542068], [72.55486298, 22.2551403], [72.554039, 22.2551403], [72.554039, 22.25542068], [72.55319214, 22.25542068], [72.55319214, 22.2551403], [72.55264282, 22.2551403], [72.55264282, 22.25486183], [72.55236053, 22.25486183], [72.55236053, 22.25402832], [72.55179596, 22.25403023], [72.55179596, 22.25292015], [72.55152893, 22.25292015], [72.55152893, 22.25265121], [72.55097198, 22.25265121], [72.55097198, 22.25235748], [72.55014038, 22.2523613], [72.55014038, 22.25208282], [72.54985809, 22.25208282], [72.54985809, 22.2504158], [72.54957581, 22.25041962], [72.54957581, 22.25014114], [72.54930878, 22.25014114], [72.54930878, 22.24986076], [72.54902649, 22.24986076], [72.54902649, 22.24958992], [72.54875183, 22.24958992], [72.54875183, 22.24930954], [72.54846954, 22.24930954], [72.54846954, 22.24903107], [72.5479126, 22.24903107], [72.5479126, 22.24875069], [72.54763794, 22.24875069], [72.54763794, 22.24847031], [72.54736328, 22.24847221], [72.54736328, 22.24819374], [72.54680634, 22.24819374], [72.54680634, 22.24791527], [72.54651642, 22.24792099], [72.54651642, 22.24764061], [72.54624939, 22.24764061], [72.54624939, 22.24707985], [72.54597473, 22.24708366], [72.54597473, 22.24569321], [72.54541779, 22.24570084], [72.54541779, 22.24514008], [72.54514313, 22.24514008], [72.54514313, 22.24458122], [72.54486084, 22.24458313], [72.54486084, 22.24402809], [72.54458618, 22.24403], [72.54458618, 22.24374962], [72.54347229, 22.24374962], [72.54347229, 22.24346161], [72.54264069, 22.24347115], [72.54264069, 22.24319458], [72.54125214, 22.24319458], [72.54125214, 22.24347115], [72.54096985, 22.24346161], [72.54096985, 22.24374962], [72.54069519, 22.24374962], [72.54069519, 22.2448616], [72.54096985, 22.2448597], [72.54096985, 22.24542046], [72.54125214, 22.24541664], [72.54125214, 22.24597168], [72.54152679, 22.24597168], [72.54152679, 22.24652863], [72.54180908, 22.246521], [72.54180908, 22.24875069], [72.54125214, 22.24875069], [72.54125214, 22.24847031], [72.54069519, 22.24847221], [72.54069519, 22.24819374], [72.5404129, 22.24819374], [72.5404129, 22.24791527], [72.53985596, 22.24792099], [72.53985596, 22.24764061], [72.5395813, 22.24764061], [72.5395813, 22.24736023], [72.53874207, 22.24736023], [72.53874207, 22.24707985], [72.53847504, 22.24708366], [72.53847504, 22.24680519], [72.53819275, 22.24681091], [72.53819275, 22.246521], [72.53791809, 22.24652863], [72.53791809, 22.24625015], [72.5376358, 22.24625015], [72.5376358, 22.24596977], [72.53736115, 22.24597168], [72.53736115, 22.24569321], [72.5348587, 22.24569321], [72.5348587, 22.24597168], [72.53430939, 22.24596977], [72.53430176, 22.24625015], [72.53320313, 22.24625015], [72.53320313, 22.24681091], [72.53347015, 22.24681091], [72.53347015, 22.24736023], [72.53375244, 22.24736023], [72.53375244, 22.24792099], [72.5340271, 22.24791527], [72.5340271, 22.24847221], [72.53457642, 22.24847031], [72.53457642, 22.24875069], [72.53514099, 22.24875069], [72.53514099, 22.24903107], [72.53569794, 22.24903107], [72.53569794, 22.24958992], [72.5359726, 22.24958992], [72.5359726, 22.24986076], [72.53624725, 22.24986076], [72.53624725, 22.25014114], [72.53708649, 22.25014114], [72.53708649, 22.25041962], [72.5376358, 22.25041962], [72.5376358, 22.25125122], [72.53708649, 22.25125122], [72.53708649, 22.25152969], [72.53652954, 22.25152969], [72.53652954, 22.25125122], [72.53624725, 22.25125122], [72.53624725, 22.25097084], [72.5359726, 22.25097275], [72.5359726, 22.25069427], [72.53541565, 22.25069427], [72.53541565, 22.2504158], [72.5348587, 22.25041962], [72.5348587, 22.25014114], [72.53375244, 22.25014114], [72.53375244, 22.25041962], [72.53347015, 22.2504158], [72.53347015, 22.25069427], [72.5331955, 22.25069427], [72.5331955, 22.25097275], [72.53291321, 22.25097084], [72.53291321, 22.25180817], [72.5331955, 22.25180626], [72.5331955, 22.25208282], [72.53347015, 22.25208092], [72.53347015, 22.25265121], [72.53375244, 22.25265121], [72.53375244, 22.25292015], [72.5340271, 22.25291634], [72.5340271, 22.25319481], [72.53430176, 22.25319481], [72.53430939, 22.25346947], [72.53457642, 22.25346947], [72.53457642, 22.25375175], [72.5348587, 22.25375175], [72.5348587, 22.25403023], [72.53514099, 22.25402832], [72.53514099, 22.25458336], [72.53542328, 22.25457954], [72.53542328, 22.2551403], [72.5359726, 22.2551403], [72.5359726, 22.25542068], [72.53708649, 22.25542068], [72.53708649, 22.2557106], [72.5376358, 22.2557106], [72.5376358, 22.25542068], [72.53819275, 22.25542068], [72.53819275, 22.25429916], [72.53902435, 22.25430489], [72.53902435, 22.25486183], [72.53930664, 22.25486183], [72.53930664, 22.25542068], [72.5395813, 22.25541687], [72.5395813, 22.25597382], [72.53985596, 22.25597191], [72.53985596, 22.25625038], [72.54013824, 22.25625038], [72.54013824, 22.25681114], [72.5404129, 22.25680542], [72.5404129, 22.25708389], [72.54096985, 22.25708008], [72.54096985, 22.25764084], [72.54070282, 22.25764084], [72.54070282, 22.25792122], [72.5404129, 22.2579174], [72.5404129, 22.25819206], [72.54013824, 22.25819206], [72.54013824, 22.25847244], [72.5395813, 22.25847244], [72.5395813, 22.25819206], [72.53902435, 22.25819206], [72.53902435, 22.2579174], [72.53791809, 22.2579174], [72.53791809, 22.25819206], [72.5376358, 22.25819206], [72.5376358, 22.25847244], [72.53736115, 22.25846291], [72.53736115, 22.25875092], [72.53679657, 22.25875092], [72.53679657, 22.25930977], [72.53652954, 22.25930405], [72.53652954, 22.25958252], [72.5359726, 22.25958061], [72.5359726, 22.26041985], [72.5348587, 22.26041412], [72.5348587, 22.26236153], [72.53514099, 22.26235962], [72.53514099, 22.26292038], [72.5348587, 22.26292038], [72.5348587, 22.26320076], [72.53514099, 22.26320076], [72.53514099, 22.26374817], [72.53542328, 22.26374817], [72.53542328, 22.26431084], [72.53569794, 22.26431084], [72.53569794, 22.26458931], [72.5359726, 22.26458931], [72.5359726, 22.26514053], [72.53624725, 22.26514053], [72.53624725, 22.26847267], [72.53652954, 22.26847267], [72.53652954, 22.26931], [72.5368042, 22.26930618], [72.5368042, 22.27037811], [72.5368042, 22.27069473], [72.5376358, 22.27069283], [72.5376358, 22.27124977], [72.53736115, 22.27124977], [72.53736115, 22.27180481], [72.53708649, 22.2718029], [72.53708649, 22.27264023], [72.53736115, 22.27264023], [72.53736115, 22.27375031], [72.5376358, 22.27375031], [72.5376358, 22.27431107], [72.53791809, 22.27430534], [72.53791809, 22.27458382], [72.53847504, 22.27458382], [72.53847504, 22.27486038], [72.53874207, 22.27486038], [72.53874207, 22.27514076], [72.54096985, 22.27514076], [72.54096985, 22.27542114], [72.54125214, 22.27542114], [72.54125214, 22.27514076], [72.54374695, 22.27514076], [72.54374695, 22.27542114], [72.54652405, 22.27541542], [72.54652405, 22.27569389], [72.54680634, 22.27569389], [72.54680634, 22.27597237], [72.54846954, 22.27597046], [72.54846954, 22.27625084], [72.54930878, 22.27625084], [72.54930878, 22.27653122], [72.54985809, 22.27653122], [72.54985809, 22.27681923], [72.55041504, 22.27680779], [72.55041504, 22.27708244], [72.55124664, 22.27708054], [72.55124664, 22.27736092], [72.55179596, 22.27736092], [72.55179596, 22.27763748], [72.55236053, 22.27763748], [72.55236053, 22.27791977], [72.55319214, 22.27791595], [72.55319214, 22.27819443], [72.55374908, 22.27819061], [72.55374908, 22.27959251], [72.55347443, 22.27958298], [72.55347443, 22.28097153], [72.55263519, 22.28097153], [72.55263519, 22.28069496], [72.55236053, 22.28070259], [72.55236053, 22.2804203], [72.55042267, 22.2804203], [72.55042267, 22.28070259], [72.54902649, 22.28069496], [72.54902649, 22.28097153], [72.54264069, 22.28097153], [72.54264069, 22.28069496], [72.54125214, 22.28070259], [72.54125214, 22.2804203], [72.53985596, 22.2804203], [72.53985596, 22.28014183], [72.5395813, 22.28014183], [72.5395813, 22.27986145], [72.53930664, 22.27986145], [72.53930664, 22.27958298], [72.53848267, 22.27959251], [72.53848267, 22.27931023], [72.5376358, 22.27931023], [72.5376358, 22.27902985], [72.53708649, 22.27902985], [72.53708649, 22.27874756], [72.53679657, 22.27874756], [72.53679657, 22.27819061], [72.53624725, 22.27819443], [72.53624725, 22.27791595], [72.53569794, 22.27791977], [72.53569794, 22.27763748], [72.53514099, 22.27763748], [72.53514099, 22.27736092], [72.5348587, 22.27736092], [72.5348587, 22.27708054], [72.53457642, 22.27708054], [72.53457642, 22.27736092], [72.53430939, 22.27736092], [72.53430176, 22.27763748], [72.5340271, 22.27763748], [72.5340271, 22.27736092], [72.5331955, 22.27736092], [72.5331955, 22.27708244], [72.53263855, 22.27708244], [72.53263855, 22.27652931], [72.53291321, 22.27653122], [72.53291321, 22.27597046], [72.5331955, 22.27597237], [72.5331955, 22.27541542], [72.53291321, 22.27542114], [72.53291321, 22.27486038], [72.53263855, 22.27486038], [72.53263855, 22.27458], [72.53236389, 22.27458382], [72.53236389, 22.27430534], [72.5320816, 22.27431107], [72.5320816, 22.27403069], [72.53180695, 22.27403069], [72.53180695, 22.27375031], [72.53151703, 22.27375031], [72.53151703, 22.27346992], [72.53097534, 22.27347183], [72.53097534, 22.27319336], [72.53070068, 22.27320099], [72.53069305, 22.27292061], [72.5304184, 22.27292061], [72.5304184, 22.27264023], [72.53013611, 22.27264023], [72.53013611, 22.27235985], [72.52986145, 22.27236176], [72.52986145, 22.27208328], [72.52958679, 22.27208328], [72.52958679, 22.27180481], [72.52902985, 22.27180481], [72.52902985, 22.27152824], [72.52874756, 22.27153015], [72.52874756, 22.27124977], [72.5284729, 22.27124977], [72.5284729, 22.27096939], [72.52791595, 22.2709713], [72.52791595, 22.27069473], [72.5276413, 22.27069473], [72.5276413, 22.27041626], [72.52735901, 22.27042007], [72.52735901, 22.26986122], [72.52680206, 22.26986122], [72.52680206, 22.26958275], [72.5265274, 22.26958275], [72.5265274, 22.26930618], [72.52597046, 22.26931], [72.52597046, 22.26847267], [72.52541351, 22.26847267], [72.52541351, 22.26791763], [72.52513885, 22.26791954], [72.52513885, 22.26736259], [72.52485657, 22.26736259], [72.52485657, 22.26680946], [72.52458191, 22.26680946], [72.52458191, 22.26652908], [72.52430725, 22.26652908], [72.52430725, 22.26431084], [72.52403259, 22.26431084], [72.52403259, 22.2634697], [72.52375031, 22.2634716], [72.52375031, 22.26236153], [72.52347565, 22.26236153], [72.52347565, 22.26097298], [72.52375031, 22.26097298], [72.52375031, 22.25958252], [72.52347565, 22.25958252], [72.52347565, 22.25930405], [72.52374268, 22.25930977], [72.52374268, 22.2557106], [72.52403259, 22.2557106], [72.52403259, 22.2551403], [72.52430725, 22.2551403], [72.52430725, 22.25014114], [72.52458191, 22.25014114], [72.52458191, 22.24792099], [72.52430725, 22.24792099], [72.52430725, 22.24542046], [72.52403259, 22.24542046], [72.52403259, 22.2448597], [72.52375031, 22.2448616], [72.52375031, 22.24458313], [72.52347565, 22.24458313], [72.52347565, 22.24430466], [72.52319336, 22.24430466], [72.52319336, 22.24374962], [72.5229187, 22.24374962], [72.5229187, 22.24346161], [72.52263641, 22.24347115], [72.52263641, 22.24319458], [72.52236176, 22.24319458], [72.52236176, 22.24263954], [72.5220871, 22.24263954], [72.5220871, 22.24236107], [72.52179718, 22.24236107], [72.52179718, 22.2420826], [72.52153015, 22.2420826], [72.52153015, 22.24180603], [72.52124786, 22.24180984], [72.52124786, 22.24152946], [72.52097321, 22.24152946], [72.52097321, 22.2412529], [72.52068329, 22.2412529], [72.52068329, 22.24097252], [72.52041626, 22.24097252], [72.52041626, 22.24069405], [72.5201416, 22.24069405], [72.5201416, 22.24041748], [72.51957703, 22.24041939], [72.51957703, 22.24014091], [72.51930237, 22.24014091], [72.51930237, 22.23985863], [72.51902771, 22.23985863], [72.51902771, 22.23957825], [72.51875305, 22.23958397], [72.51875305, 22.2393055], [72.51847076, 22.23930931], [72.51847076, 22.23903084], [72.51819611, 22.23903084], [72.51819611, 22.23875046], [72.51790619, 22.23875046], [72.51790619, 22.23846817], [72.5173645, 22.23847008], [72.5173645, 22.23791885], [72.51708221, 22.23792076], [72.51708221, 22.23735809], [72.51680756, 22.23736191], [72.51680756, 22.23708344], [72.51625061, 22.23708344], [72.51625061, 22.23680496], [72.51597595, 22.23681068], [72.51597595, 22.2365303], [72.51541901, 22.2365303], [72.51541901, 22.23624992], [72.51513672, 22.23624992], [72.51513672, 22.23596954], [72.51457977, 22.23597145], [72.51457977, 22.23569679], [72.51430511, 22.23569679], [72.51430511, 22.23541641], [72.51374817, 22.23542023], [72.51374817, 22.23513985], [72.51291656, 22.23513985], [72.51291656, 22.23458099], [72.51264191, 22.2345829], [72.51264191, 22.23430443], [72.51235962, 22.23431015], [72.51235962, 22.23402977], [72.51180267, 22.23402977], [72.51180267, 22.23374939], [72.51152802, 22.23374939], [72.51152802, 22.23347092], [72.51097107, 22.23347282], [72.51097107, 22.23319435], [72.51069641, 22.23319435], [72.51069641, 22.23291588], [72.51013947, 22.23291969], [72.51013947, 22.23264122], [72.50985718, 22.23264122], [72.50985718, 22.23236084], [72.50958252, 22.23236084], [72.50958252, 22.23208046], [72.50875092, 22.23208427], [72.50875092, 22.2318058], [72.50846863, 22.23180962], [72.50846863, 22.2315197], [72.50791931, 22.23152733], [72.50791931, 22.23125076], [72.50763702, 22.23125076], [72.50763702, 22.23097038], [72.50736237, 22.23097229], [72.50736237, 22.23041725], [72.50708008, 22.23042107], [72.50708008, 22.23014069], [72.50681305, 22.23014069], [72.50681305, 22.22986031], [72.50653076, 22.22986031], [72.50653076, 22.22958183], [72.50624847, 22.22958374], [72.50624847, 22.22930527], [72.50596619, 22.2293129], [72.50596619, 22.22903061], [72.50569916, 22.22903061], [72.50569916, 22.22847939], [72.50541687, 22.22847939], [72.50541687, 22.22820282], [72.50514221, 22.22820282], [72.50514221, 22.22764015], [72.50485992, 22.22764015], [72.50485992, 22.22680092], [72.50458527, 22.22680473], [72.50458527, 22.22513962], [72.50430298, 22.22513962], [72.50430298, 22.22430992], [72.50402832, 22.22430992], [72.50402832, 22.22347069], [72.50430298, 22.2234726], [72.50430298, 22.22180557], [72.50402832, 22.22180939], [72.50402832, 22.22042084], [72.50263977, 22.22042084], [72.50263977, 22.22014046], [72.50235748, 22.22014046], [72.50235748, 22.21986008], [72.50208282, 22.21986198], [72.50208282, 22.21958351], [72.50180817, 22.21958351], [72.50180817, 22.21930313], [72.50096893, 22.21931076], [72.50096893, 22.21903038], [72.50068665, 22.21903038], [72.50068665, 22.21846962], [72.50041962, 22.21847153], [72.50041962, 22.21819305], [72.50013733, 22.21820068], [72.50013733, 22.2179203], [72.49986267, 22.2179203], [72.49986267, 22.21763992], [72.49957275, 22.21763992], [72.49957275, 22.21735954], [72.49903107, 22.21736145], [72.49903107, 22.21680641], [72.4985733, 22.21681023], [72.49846649, 22.21681023], [72.49846649, 22.21653938], [72.49819183, 22.21653938], [72.49819183, 22.21569252], [72.49791718, 22.21569443], [72.49791718, 22.21486282], [72.49764252, 22.21486282], [72.49764252, 22.21458244], [72.49736023, 22.21458244], [72.49736023, 22.2140274], [72.4970932, 22.21403122], [72.4970932, 22.21375084], [72.49680328, 22.21375084], [72.49680328, 22.2134819], [72.49652863, 22.2134819], [72.49652863, 22.21318817], [72.49624634, 22.21319389], [72.49624634, 22.21291733], [72.49597168, 22.21291924], [72.49597168, 22.21235847], [72.49569702, 22.21235847], [72.49569702, 22.21207809], [72.49541473, 22.21208382], [72.49541473, 22.21180534], [72.49514008, 22.21180916], [72.49514008, 22.21153069], [72.49485779, 22.21153069], [72.49485779, 22.21125031], [72.49458313, 22.21125031], [72.49458313, 22.21069908], [72.49430847, 22.21069908], [72.49430847, 22.21041107], [72.49402618, 22.2104187], [72.49402618, 22.21013641], [72.49375916, 22.21014023], [72.49375916, 22.20985985], [72.49346924, 22.20986176], [72.49346924, 22.20958328], [72.49319458, 22.20958328], [72.49319458, 22.20902634], [72.49291992, 22.20903015], [72.49291992, 22.20874977], [72.49263763, 22.20874977], [72.49263763, 22.20846939], [72.49236298, 22.2084713], [72.49236298, 22.20791435], [72.49208069, 22.20792007], [72.49208069, 22.20763969], [72.49180603, 22.20763969], [72.49180603, 22.20734978], [72.49153137, 22.20736122], [72.49153137, 22.20680428], [72.49124908, 22.20681], [72.49124908, 22.20652962], [72.4909668, 22.20652962], [72.4909668, 22.20625114], [72.49124908, 22.20625114], [72.49124908, 22.20597076], [72.49153137, 22.20597267], [72.49153137, 22.2056942], [72.49180603, 22.2056942], [72.49180603, 22.20541573], [72.49208069, 22.20541954], [72.49208069, 22.20499039], [72.49208069, 22.20458221], [72.49180603, 22.20458221], [72.49180603, 22.20319366], [72.49153137, 22.20319366], [72.49153137, 22.20263863], [72.49124908, 22.20264053], [72.49124908, 22.20236015], [72.48986053, 22.20236206], [72.48986053, 22.20208359], [72.48930359, 22.20208359], [72.48930359, 22.20152855], [72.48902893, 22.20153999], [72.48902893, 22.20125008], [72.48874664, 22.20125008], [72.48874664, 22.20042038], [72.48902893, 22.20042038], [72.48902893, 22.20014191], [72.48874664, 22.20014191], [72.48874664, 22.19986153], [72.48847198, 22.19986153], [72.48847198, 22.19930649], [72.48819733, 22.1993103], [72.48819733, 22.19903183], [72.48792267, 22.19903183], [72.48792267, 22.19874763], [72.48763275, 22.19874763], [72.48763275, 22.19735909], [72.48596954, 22.19735909], [72.48596954, 22.19763947], [72.48542023, 22.19763947], [72.48542023, 22.19791985], [72.48513794, 22.19791794], [72.48513794, 22.1981945], [72.48486328, 22.1981945], [72.48486328, 22.19847298], [72.48430634, 22.19846916], [72.48430634, 22.19874763], [72.48236084, 22.19874763], [72.48236084, 22.19903183], [72.48179626, 22.19903183], [72.48179626, 22.1993103], [72.48124695, 22.19930649], [72.48124695, 22.19958305], [72.48069763, 22.19958305], [72.48069763, 22.19986153], [72.4798584, 22.19986153], [72.4798584, 22.20014191], [72.47902679, 22.20014191], [72.47902679, 22.20042038], [72.47891235, 22.20041656], [72.47569275, 22.20042038], [72.47569275, 22.20070267], [72.4743042, 22.20069504], [72.4743042, 22.2009716], [72.47374725, 22.2009716], [72.47374725, 22.20125008], [72.47402954, 22.20125008], [72.47402954, 22.20208359], [72.47429657, 22.20208168], [72.47429657, 22.20264053], [72.47458649, 22.20263863], [72.47458649, 22.20319366], [72.47486115, 22.20318985], [72.47486115, 22.20375061], [72.4751358, 22.20375061], [72.4751358, 22.20486069], [72.47541809, 22.20486069], [72.47541809, 22.2056942], [72.47624969, 22.2056942], [72.47624969, 22.20541573], [72.47652435, 22.20541573], [72.47652435, 22.2056942], [72.47680664, 22.2056942], [72.47680664, 22.20597267], [72.4770813, 22.20597076], [72.4770813, 22.20625114], [72.47735596, 22.20625114], [72.47735596, 22.20652962], [72.47763824, 22.20652962], [72.47763824, 22.20681], [72.4779129, 22.20680428], [72.4779129, 22.20736122], [72.47819519, 22.20736122], [72.47819519, 22.20763969], [72.47846985, 22.20763969], [72.47846985, 22.20792007], [72.47875214, 22.20791435], [72.47875214, 22.20819473], [72.47902679, 22.20819473], [72.47902679, 22.2084713], [72.47930908, 22.20846939], [72.47930908, 22.20874977], [72.47958374, 22.20874977], [72.47958374, 22.20930481], [72.4798584, 22.20930481], [72.4798584, 22.20986176], [72.48014069, 22.20986176], [72.48014069, 22.2104187], [72.48041534, 22.2104187], [72.48041534, 22.21097183], [72.48069763, 22.21096992], [72.48069763, 22.21153069], [72.48097229, 22.21152878], [72.48097229, 22.21208382], [72.48124695, 22.21208382], [72.48124695, 22.21319389], [72.48097229, 22.21318817], [72.48097229, 22.21430969], [72.48014069, 22.21430588], [72.48014069, 22.21458244], [72.4798584, 22.21458244], [72.4798584, 22.21513939], [72.48014069, 22.21513939], [72.48014069, 22.21541977], [72.48097229, 22.21541595], [72.48097229, 22.21569443], [72.4813385, 22.21569252], [72.48152924, 22.21569252], [72.48152924, 22.21624947], [72.48179626, 22.21624947], [72.48179626, 22.21681023], [72.48208618, 22.21680641], [72.48208618, 22.21736145], [72.48236084, 22.21735954], [72.48236084, 22.2179203], [72.4826355, 22.21791649], [72.4826355, 22.21847153], [72.48291779, 22.21846962], [72.48291779, 22.21875], [72.48319244, 22.21875], [72.48319244, 22.21931076], [72.48347473, 22.21930313], [72.48347473, 22.21986198], [72.48374939, 22.21986008], [72.48374939, 22.22042084], [72.48402405, 22.22041512], [72.48402405, 22.22097206], [72.48430634, 22.22097015], [72.48430634, 22.22153091], [72.48458099, 22.22152519], [72.48458099, 22.22208595], [72.48486328, 22.22208023], [72.48486328, 22.22264099], [72.48513794, 22.22263718], [72.48513794, 22.22319412], [72.48458099, 22.22319412], [72.48458099, 22.2234726], [72.48401642, 22.22347069], [72.48401642, 22.22375107], [72.48374939, 22.22375107], [72.48374939, 22.22402954], [72.48319244, 22.22402954], [72.48319244, 22.22430992], [72.48291779, 22.22430611], [72.48291779, 22.22458267], [72.48236084, 22.22458076], [72.48236084, 22.22485924], [72.48208618, 22.22485924], [72.48208618, 22.22513962], [72.48152924, 22.22513962], [72.48152924, 22.22541809], [72.48097229, 22.22541618], [72.48097229, 22.22569466], [72.48069763, 22.22569466], [72.48069763, 22.22597313], [72.48014069, 22.22596931], [72.48014069, 22.2262516], [72.47957611, 22.2262516], [72.47957611, 22.22653008], [72.47902679, 22.22652817], [72.47902679, 22.22680473], [72.47846985, 22.22680092], [72.47846985, 22.22764015], [72.47875977, 22.22764015], [72.47875977, 22.22847939], [72.4798584, 22.22847939], [72.4798584, 22.22820282], [72.48152924, 22.22820282], [72.48152924, 22.22792053], [72.48208618, 22.22792053], [72.48208618, 22.22820282], [72.48542023, 22.22820282], [72.48542023, 22.22847939], [72.48568726, 22.22847939], [72.48568726, 22.22875023], [72.48625183, 22.22875023], [72.48625183, 22.22903061], [72.48902893, 22.22903061], [72.48902893, 22.2293129], [72.48958588, 22.22930527], [72.48958588, 22.22958374], [72.49013519, 22.22958374], [72.49013519, 22.22986031], [72.49069977, 22.22986031], [72.49069977, 22.23014069], [72.49124908, 22.23013878], [72.49124908, 22.23097229], [72.49153137, 22.23097038], [72.49153137, 22.23236084], [72.49180603, 22.23236084], [72.49180603, 22.23347282], [72.49208069, 22.23347282], [72.49208069, 22.23486137], [72.49236298, 22.23485947], [72.49236298, 22.23624992], [72.49263763, 22.23624992], [72.49263763, 22.23708344], [72.49208069, 22.23708344], [72.49208069, 22.23736191], [72.49097443, 22.23736191], [72.49097443, 22.23708344], [72.49069214, 22.23708344], [72.49069214, 22.23680496], [72.49041748, 22.23681068], [72.49041748, 22.2365303], [72.49014282, 22.2365303], [72.49014282, 22.23624992], [72.48958588, 22.23624992], [72.48958588, 22.23596954], [72.48930359, 22.23597145], [72.48930359, 22.23569679], [72.48902893, 22.23569679], [72.48902893, 22.23541641], [72.48291779, 22.23542023], [72.48291779, 22.23513985], [72.48236084, 22.23513985], [72.48236084, 22.23485947], [72.48124695, 22.23486137], [72.48124695, 22.2345829], [72.4798584, 22.2345829], [72.4798584, 22.23430443], [72.47846985, 22.23430443], [72.47846985, 22.2345829], [72.4779129, 22.2345829], [72.4779129, 22.23486137], [72.47763824, 22.23485947], [72.47763824, 22.23513985], [72.47875977, 22.23513985], [72.47875977, 22.23542023], [72.47958374, 22.23541641], [72.47958374, 22.23569679], [72.48069763, 22.23569679], [72.48069763, 22.23597145], [72.48152924, 22.23596954], [72.48152924, 22.23624992], [72.48319244, 22.23624992], [72.48319244, 22.23596954], [72.48568726, 22.23596954], [72.48568726, 22.23624992], [72.48652649, 22.23624992], [72.48652649, 22.2365303], [72.48735809, 22.2365303], [72.48735809, 22.23681068], [72.48819733, 22.23680496], [72.48819733, 22.23708344], [72.48902893, 22.23708344], [72.48902893, 22.23736191], [72.48986053, 22.23735809], [72.48986053, 22.23765182], [72.49041748, 22.23765182], [72.49041748, 22.23792076], [72.49097443, 22.23791885], [72.49097443, 22.23819351], [72.49124908, 22.23819351], [72.49124908, 22.23847008], [72.49180603, 22.23846817], [72.49180603, 22.23875046], [72.49236298, 22.23875046], [72.49236298, 22.23903084], [72.49263763, 22.23902893], [72.49263763, 22.23958397], [72.49291992, 22.23957825], [72.49291992, 22.24014091], [72.49319458, 22.24014091], [72.49319458, 22.24069405], [72.49346924, 22.24068832], [72.49346924, 22.2412529], [72.49375916, 22.2412529], [72.49375916, 22.24180984], [72.49402618, 22.24180984], [72.49402618, 22.24236107], [72.49430847, 22.24236107], [72.49430847, 22.24319458], [72.49402618, 22.24319458], [72.49402618, 22.24458313], [72.49375916, 22.24458122], [72.49375916, 22.24542046], [72.49346924, 22.24541664], [72.49346924, 22.24652863], [72.49318695, 22.246521], [72.49318695, 22.24764061], [72.49291992, 22.2476387], [72.49291992, 22.24819374], [72.49236298, 22.24819374], [72.49236298, 22.2476387], [72.49208069, 22.24764061], [72.49208069, 22.24736023], [72.49180603, 22.24736023], [72.49180603, 22.24681091], [72.49153137, 22.24681091], [72.49153137, 22.246521], [72.49124908, 22.24652863], [72.49124908, 22.24597168], [72.49097443, 22.24597168], [72.49097443, 22.24569321], [72.49069977, 22.24570084], [72.49069977, 22.24542046], [72.49014282, 22.24542046], [72.49014282, 22.24514008], [72.48986053, 22.24514008], [72.48986053, 22.2448597], [72.48930359, 22.2448616], [72.48930359, 22.24458313], [72.48902893, 22.24458313], [72.48902893, 22.24430466], [72.48847198, 22.24430466], [72.48847198, 22.24402809], [72.48819733, 22.24403], [72.48819733, 22.24374962], [72.48763275, 22.24374962], [72.48763275, 22.24346161], [72.48735809, 22.24347115], [72.48735809, 22.24319458], [72.48680878, 22.24319458], [72.48680878, 22.24291611], [72.48430634, 22.24291992], [72.48430634, 22.24263954], [72.48401642, 22.24263954], [72.48401642, 22.24236107], [72.48374939, 22.24236107], [72.48374939, 22.2420826], [72.48347473, 22.2420826], [72.48347473, 22.24180603], [72.48319244, 22.24180984], [72.48319244, 22.24152946], [72.48291779, 22.24152946], [72.48291779, 22.2412529], [72.48264313, 22.2412529], [72.48264313, 22.24097252], [72.48236084, 22.24097252], [72.48236084, 22.24069405], [72.48097229, 22.24069405], [72.48097229, 22.24041748], [72.47957611, 22.24041939], [72.47957611, 22.24014091], [72.47820282, 22.24014091], [72.47820282, 22.23985863], [72.4770813, 22.23985863], [72.4770813, 22.23957825], [72.47652435, 22.23958397], [72.47652435, 22.2393055], [72.47458649, 22.23930931], [72.47458649, 22.23903084], [72.4734726, 22.23903084], [72.4734726, 22.23875046], [72.4706955, 22.23875046], [72.4706955, 22.23958397], [72.47041321, 22.23958397], [72.47041321, 22.24069405], [72.47013855, 22.24068832], [72.47013855, 22.2412529], [72.47041321, 22.2412529], [72.47041321, 22.24152946], [72.4706955, 22.24152756], [72.47070313, 22.24263954], [72.47041321, 22.24263954], [72.47041321, 22.24347115], [72.4695816, 22.24347115], [72.46958923, 22.24374962], [72.46930695, 22.24374962], [72.46930695, 22.24430466], [72.46902466, 22.24430466], [72.46902466, 22.2448616], [72.46875, 22.2448597], [72.46875, 22.24570084], [72.46847534, 22.24569321], [72.46848297, 22.24625015], [72.46819305, 22.24625015], [72.46819305, 22.24681091], [72.4679184, 22.24681091], [72.4679184, 22.24736023], [72.46763611, 22.24736023], [72.46763611, 22.24792099], [72.46736145, 22.24791527], [72.46736145, 22.24819374], [72.46708679, 22.24819374], [72.46708679, 22.24847221], [72.46679688, 22.24847031], [72.46679688, 22.24903107], [72.46652985, 22.24903107], [72.46652985, 22.24930954], [72.46624756, 22.24930954], [72.46624756, 22.24986076], [72.4659729, 22.24986076], [72.4659729, 22.25014114], [72.46569824, 22.25014114], [72.46569824, 22.25041962], [72.46541595, 22.2504158], [72.46541595, 22.25097275], [72.4651413, 22.25097084], [72.4651413, 22.25125122], [72.46485901, 22.25125122], [72.46485901, 22.25180817], [72.46458435, 22.25180626], [72.46458435, 22.25208282], [72.46430206, 22.25208092], [72.46430206, 22.25265121], [72.4640274, 22.25265121], [72.4640274, 22.25292015], [72.46375275, 22.25291634], [72.46375275, 22.25319481], [72.46346283, 22.25318909], [72.46346283, 22.25375175], [72.4631958, 22.25375175], [72.4631958, 22.25403023], [72.46291351, 22.25402832], [72.46291351, 22.25458336], [72.46263885, 22.25458336], [72.46263885, 22.25486183], [72.46235657, 22.25486183], [72.46235657, 22.25542068], [72.46208191, 22.25542068], [72.46208191, 22.2557106], [72.46180725, 22.25569534], [72.46180725, 22.25597382], [72.46153259, 22.25597191], [72.46153259, 22.25653076], [72.46098328, 22.25653076], [72.46098328, 22.25681114], [72.46069336, 22.25680542], [72.46069336, 22.25708389], [72.4604187, 22.25708008], [72.4604187, 22.25764084], [72.46013641, 22.25763893], [72.46013641, 22.25819206], [72.45986176, 22.25819206], [72.45986176, 22.25847244], [72.4595871, 22.25846291], [72.4595871, 22.25902939], [72.45930481, 22.25902748], [72.45930481, 22.25958252], [72.45903015, 22.25958061], [72.45903015, 22.26013947], [72.45874786, 22.26013947], [72.45874786, 22.26041985], [72.45847321, 22.26041412], [72.45847321, 22.26097298], [72.45819092, 22.26097107], [72.45819092, 22.26152992], [72.45791626, 22.26152992], [72.45791626, 22.2618103], [72.4576416, 22.2618084], [72.4576416, 22.26236153], [72.45735931, 22.26235962], [72.45735931, 22.26292038], [72.45708466, 22.26291847], [72.45708466, 22.2634716], [72.45680237, 22.2634697], [72.45680237, 22.26403046], [72.45652771, 22.26403046], [72.45652771, 22.26458931], [72.45625305, 22.26458931], [72.45625305, 22.26514053], [72.45597076, 22.26514053], [72.45597076, 22.26569366], [72.45569611, 22.26568985], [72.45569611, 22.26625061], [72.45540619, 22.26625061], [72.45540619, 22.26680946], [72.45513916, 22.26680946], [72.45513916, 22.26736259], [72.45485687, 22.26736259], [72.45485687, 22.26791954], [72.45458221, 22.26791763], [72.45458221, 22.26847267], [72.45430756, 22.26847267], [72.45430756, 22.26902962], [72.45402527, 22.26902771], [72.45402527, 22.26958275], [72.45375061, 22.26958275], [72.45375061, 22.27013969], [72.45347595, 22.27013969], [72.45347595, 22.27042007], [72.45319366, 22.27041626], [72.45319366, 22.2709713], [72.45291901, 22.27096939], [72.45291901, 22.27124977], [72.45263672, 22.27124977], [72.45263672, 22.27153015], [72.45236206, 22.27152824], [72.45236206, 22.27208328], [72.45207977, 22.27208328], [72.45207977, 22.27236176], [72.45181274, 22.27235985], [72.45181274, 22.27292061], [72.45152283, 22.27292061], [72.45152283, 22.27320099], [72.45124817, 22.27320099], [72.45124817, 22.27375031], [72.45096588, 22.27375031], [72.45096588, 22.27403069], [72.45069122, 22.27403069], [72.45069122, 22.27431107], [72.45041656, 22.27431107], [72.45041656, 22.27486038], [72.45014191, 22.27486038], [72.45014191, 22.27514076], [72.44985962, 22.27513885], [72.44985962, 22.27569389], [72.44958496, 22.27569389], [72.44958496, 22.27597237], [72.44930267, 22.27597046], [72.44930267, 22.27653122], [72.44902802, 22.27652931], [72.44902802, 22.27708244], [72.44875336, 22.27708054], [72.44875336, 22.27763748], [72.44847107, 22.27763748], [72.44847107, 22.27819443], [72.44819641, 22.27819061], [72.44819641, 22.27874756], [72.44790649, 22.27874756], [72.44790649, 22.27931023], [72.44763947, 22.27930641], [72.44763947, 22.27986145], [72.44735718, 22.27986145], [72.44735718, 22.2804203], [72.44708252, 22.28041649], [72.44708252, 22.28097153], [72.44625092, 22.28097153], [72.44625092, 22.28347206], [72.44568634, 22.28347015], [72.44568634, 22.28375053], [72.44541931, 22.28375053], [72.44541931, 22.28403091], [72.44486237, 22.28403091], [72.44486237, 22.28430939], [72.44458008, 22.28430939], [72.44458008, 22.28486061], [72.44486237, 22.28486061], [72.44486237, 22.28541946], [72.44513702, 22.28541946], [72.44513702, 22.28625107], [72.44541931, 22.28625107], [72.44541931, 22.28652954], [72.44513702, 22.28652763], [72.44513702, 22.28708267], [72.44486237, 22.28708076], [72.44486237, 22.28763962], [72.44458008, 22.28763962], [72.44458008, 22.28819466], [72.44431305, 22.28819084], [72.44431305, 22.28876114], [72.44403076, 22.28876114], [72.44403076, 22.28903008], [72.44374847, 22.28902626], [72.44374847, 22.28930473], [72.44347382, 22.28930473], [72.44347382, 22.28958321], [72.44319153, 22.28958321], [72.44319153, 22.28986168], [72.44291687, 22.28985977], [72.44291687, 22.29014015], [72.44264984, 22.29014015], [72.44264984, 22.29042053], [72.44235992, 22.29042053], [72.44235992, 22.29182243], [72.44208527, 22.29180527], [72.44208527, 22.29208374], [72.44180298, 22.29207993], [72.44180298, 22.29264069], [72.44152832, 22.29264069], [72.44152832, 22.29291916], [72.44125366, 22.29291725], [72.44125366, 22.29319382], [72.44097137, 22.2931881], [72.44097137, 22.29375076], [72.44069672, 22.29375076], [72.44069672, 22.29403114], [72.4404068, 22.29403114], [72.4404068, 22.29430962], [72.44013977, 22.2943058], [72.44013977, 22.29458427], [72.43985748, 22.29457092], [72.43985748, 22.29514122], [72.43958282, 22.29514122], [72.43958282, 22.29541969], [72.43930817, 22.29541588], [72.43930817, 22.29569435], [72.43902588, 22.29569054], [72.43902588, 22.29624939], [72.43875122, 22.29624939], [72.43875122, 22.29652977], [72.43846893, 22.29652977], [72.43846893, 22.29681015], [72.43819427, 22.29680634], [72.43819427, 22.29708481], [72.43791962, 22.29708481], [72.43791962, 22.29763794], [72.43763733, 22.29763031], [72.43763733, 22.29792023], [72.43736267, 22.29791641], [72.43736267, 22.29819489], [72.43708038, 22.29819489], [72.43708038, 22.29847145], [72.43681335, 22.29846954], [72.43681335, 22.2990303], [72.43651581, 22.2990303], [72.43651581, 22.29931068], [72.43624878, 22.29930305], [72.43624878, 22.29958344], [72.43597412, 22.29958344], [72.43597412, 22.29986191], [72.43569183, 22.29986], [72.43569183, 22.30042076], [72.43541718, 22.30042076], [72.43541718, 22.30070114], [72.43514252, 22.30070114], [72.43514252, 22.30125046], [72.4345932, 22.30125046], [72.4345932, 22.30153084], [72.43402863, 22.30153084], [72.43402863, 22.30181122], [72.43319702, 22.3018055], [72.43319702, 22.30208397], [72.43235779, 22.30208015], [72.43235779, 22.30236053], [72.43180847, 22.30236053], [72.43180847, 22.30264091], [72.43096924, 22.30264091], [72.43096924, 22.30291939], [72.42958069, 22.30291939], [72.42958069, 22.30319405], [72.42874908, 22.30319405], [72.42874908, 22.30347252], [72.42764282, 22.30347061], [72.42764282, 22.30376053], [72.42652893, 22.30376053], [72.42652893, 22.30402946], [72.42542267, 22.30402946], [72.42542267, 22.30430984], [72.42430878, 22.30430794], [72.42430878, 22.3045826], [72.42346954, 22.30458069], [72.42346954, 22.30485916], [72.42236328, 22.30485916], [72.42236328, 22.30513763], [72.42124939, 22.30513763], [72.42124939, 22.30485916], [72.4209671, 22.30485916], [72.4209671, 22.30513763], [72.41958618, 22.30513763], [72.41958618, 22.30569458], [72.41764069, 22.30569458], [72.41764069, 22.30597305], [72.41708374, 22.30597305], [72.41708374, 22.30569458], [72.41680908, 22.30569458], [72.41680908, 22.30597305], [72.41625214, 22.30596924], [72.41625214, 22.30625153], [72.41596985, 22.30625153], [72.41596985, 22.30653191], [72.4154129, 22.30652809], [72.4154129, 22.30680466], [72.41486359, 22.30680466], [72.41486359, 22.30708313], [72.4145813, 22.30708313], [72.4145813, 22.3073616], [72.41319275, 22.3073616], [72.41319275, 22.30764008], [72.4126358, 22.30764008], [72.4126358, 22.30792046], [72.41179657, 22.30792046], [72.41179657, 22.30820274], [72.4109726, 22.30819511], [72.4109726, 22.30847168], [72.41041565, 22.30847168], [72.41042328, 22.30875015], [72.4098587, 22.30875015], [72.4098587, 22.30903053], [72.40930939, 22.30903053], [72.4092865, 22.30931282], [72.40847015, 22.30930519], [72.40847015, 22.30958366], [72.40651703, 22.30957031], [72.40652466, 22.30986023], [72.40598297, 22.30986023], [72.40598297, 22.31014061], [72.40513611, 22.31014061], [72.40513611, 22.30957031], [72.4043045, 22.30958366], [72.4043045, 22.30930519], [72.40374756, 22.30931282], [72.40374756, 22.30903053], [72.40319824, 22.30903053], [72.40319061, 22.30875015], [72.40235901, 22.30875015], [72.40235901, 22.30847168], [72.40180206, 22.30847168], [72.40180206, 22.30819511], [72.4015274, 22.30820274], [72.4015274, 22.30792046], [72.40097046, 22.30792046], [72.40097046, 22.30764008], [72.4006958, 22.30764008], [72.4006958, 22.3073616], [72.40013885, 22.3073616], [72.40013885, 22.30764008], [72.39875031, 22.30764008], [72.39875031, 22.3073616], [72.39819336, 22.3073616], [72.39819336, 22.30708313], [72.39736176, 22.30708313], [72.39736176, 22.3073616], [72.39679718, 22.3073616], [72.39679718, 22.30764008], [72.39541626, 22.30764008], [72.39541626, 22.3073616], [72.39402771, 22.3073616], [72.39402771, 22.30764008], [72.39347076, 22.30764008], [72.39347076, 22.30792046], [72.39319611, 22.30792046], [72.39319611, 22.30820274], [72.39263916, 22.30819511], [72.39263916, 22.30847168], [72.39208221, 22.30847168], [72.39208221, 22.30875015], [72.3915329, 22.30875015], [72.3915329, 22.30903053], [72.39125061, 22.30903053], [72.39125061, 22.30931282], [72.39069366, 22.30930519], [72.39069366, 22.30958366], [72.39013672, 22.30957031], [72.39013672, 22.30986023], [72.38957977, 22.30986023], [72.38957977, 22.31014061], [72.38931274, 22.31014061], [72.38928986, 22.3104229], [72.38874817, 22.31041718], [72.38874817, 22.31097221], [72.38846588, 22.31097031], [72.38846588, 22.31153107], [72.38819122, 22.31152725], [72.38819122, 22.3120842], [72.38791656, 22.31208038], [72.38791656, 22.31264114], [72.38764191, 22.31263924], [72.38764191, 22.31319427], [72.38791656, 22.31319427], [72.38791656, 22.31347275], [72.38817596, 22.31347084], [72.38817596, 22.31402969], [72.38847351, 22.31402779], [72.38847351, 22.31458282], [72.38874817, 22.31458282], [72.38874817, 22.3148613], [72.38903046, 22.31485939], [72.38903046, 22.31542015], [72.38931274, 22.31542015], [72.38931274, 22.31570053], [72.38957977, 22.31569481], [72.38957977, 22.31597137], [72.38986206, 22.31596947], [72.38986206, 22.31653023], [72.39013672, 22.31652641], [72.39013672, 22.31680489], [72.39041901, 22.31680489], [72.39041901, 22.31708336], [72.39069366, 22.31708336], [72.39069366, 22.31736183], [72.39097595, 22.31735992], [72.39097595, 22.3176403], [72.39125061, 22.3176403], [72.39125061, 22.31792068], [72.3915329, 22.31792068], [72.3915329, 22.31819916], [72.39180756, 22.31819534], [72.39180756, 22.31847191], [72.39208221, 22.31847191], [72.39208221, 22.31874847], [72.39235687, 22.31874084], [72.39235687, 22.31903076], [72.39263916, 22.31903076], [72.39263916, 22.31930923], [72.39291382, 22.31930542], [72.39291382, 22.31958389], [72.39319611, 22.31957817], [72.39319611, 22.31985855], [72.39347076, 22.31985855], [72.39347076, 22.32014084], [72.39402771, 22.32014084], [72.39402771, 22.32041931], [72.39430237, 22.3204174], [72.39430237, 22.32069397], [72.39458466, 22.32069397], [72.39458466, 22.32097244], [72.39485931, 22.32097244], [72.39485931, 22.32125282], [72.3951416, 22.32125282], [72.3951416, 22.32152939], [72.39541626, 22.32152748], [72.39541626, 22.32180595], [72.39569092, 22.32180595], [72.39569092, 22.32208252], [72.39597321, 22.32208252], [72.39597321, 22.3223629], [72.39653015, 22.3223629], [72.39653015, 22.32263947], [72.39679718, 22.32263947], [72.39679718, 22.32291985], [72.3970871, 22.32291603], [72.3970871, 22.3231945], [72.39736176, 22.3231945], [72.39736176, 22.32347107], [72.39763641, 22.32347107], [72.39763641, 22.32374954], [72.3979187, 22.32374954], [72.3979187, 22.32402992], [72.39847565, 22.32402802], [72.39848328, 22.32430077], [72.39875031, 22.32430649], [72.39875031, 22.32458305], [72.39903259, 22.32458115], [72.39903259, 22.32487106], [72.39930725, 22.32487106], [72.39930725, 22.32514], [72.39958191, 22.32514], [72.39958191, 22.32542038], [72.39985657, 22.32542038], [72.39985657, 22.32570076], [72.40013885, 22.32569313], [72.40013885, 22.3259716], [72.40027618, 22.3259716], [72.40041351, 22.3259716], [72.40041351, 22.32625008], [72.4006958, 22.32625008], [72.4006958, 22.32653046], [72.40097046, 22.32653046], [72.40097046, 22.32681084], [72.40125275, 22.32680511], [72.40125275, 22.32708359], [72.4015274, 22.32707977], [72.4015274, 22.32736015], [72.40180206, 22.32736015], [72.40180206, 22.32764053], [72.40208435, 22.32763863], [72.40208435, 22.32819366], [72.40235901, 22.32819366], [72.40235901, 22.32847214], [72.4026413, 22.32847023], [72.4026413, 22.32903099], [72.40291595, 22.32902527], [72.40291595, 22.32958412], [72.40319824, 22.32958031], [72.40319824, 22.32986069], [72.4034729, 22.32986069], [72.4034729, 22.33041954], [72.40374756, 22.33041573], [72.40374756, 22.3306942], [72.40402985, 22.33068085], [72.40402985, 22.33125114], [72.40429688, 22.33125114], [72.40429688, 22.33180809], [72.40458679, 22.33180618], [72.40458679, 22.33226013], [72.40458679, 22.33235931], [72.40486145, 22.33235931], [72.40486145, 22.33266068], [72.40486145, 22.33292007], [72.40513611, 22.33291626], [72.40513611, 22.33305931], [72.40513611, 22.33346939], [72.4054184, 22.33346939], [72.4054184, 22.33403015], [72.40569305, 22.33402824], [72.40569305, 22.33486176], [72.40598297, 22.33486176], [72.40598297, 22.33542061], [72.40625, 22.33541679], [72.40625, 22.33597374], [72.40651703, 22.33597183], [72.40651703, 22.33653069], [72.40680695, 22.33653069], [72.40680695, 22.33736038], [72.4070816, 22.33736038], [72.4070816, 22.33792114], [72.40735626, 22.33792114], [72.40735626, 22.33875084], [72.40763855, 22.33875084], [72.40763855, 22.33958244], [72.40791321, 22.33958054], [72.40791321, 22.34013939], [72.4081955, 22.34013939], [72.4081955, 22.3409729], [72.40847015, 22.34097099], [72.40847015, 22.34152985], [72.40875244, 22.34152794], [72.40875244, 22.34236145], [72.4090271, 22.34236145], [72.4090271, 22.34291649], [72.40930176, 22.34291649], [72.40930939, 22.34347153], [72.40957642, 22.34346962], [72.40957642, 22.34431076], [72.4098587, 22.34430504], [72.4098587, 22.34486198], [72.41014099, 22.34486198], [72.41014099, 22.34569359], [72.41041565, 22.34569359], [72.41041565, 22.34625053], [72.41069794, 22.34625053], [72.41069794, 22.34708405], [72.4109726, 22.34707832], [72.4109726, 22.3476429], [72.41124725, 22.34763908], [72.41124725, 22.3484726], [72.41152954, 22.3484726], [72.41152954, 22.34930992], [72.41179657, 22.34930992], [72.41179657, 22.34986115], [72.41208649, 22.34986115], [72.41208649, 22.35124969], [72.41236115, 22.35124969], [72.41236115, 22.35347176], [72.4126358, 22.35346985], [72.4126358, 22.35625076], [72.41236115, 22.35625076], [72.41236115, 22.35736084], [72.41236115, 22.35847282], [72.41208649, 22.35847092], [72.41208649, 22.35874748], [72.41179657, 22.35874748], [72.41179657, 22.35902977], [72.41152954, 22.35904121], [72.41152954, 22.35931015], [72.41124725, 22.35930634], [72.41124725, 22.3595829], [72.4109726, 22.3595829], [72.4109726, 22.35986137], [72.41069794, 22.35986137], [72.41069794, 22.36013985], [72.41042328, 22.36014175], [72.41042328, 22.36042023], [72.41014099, 22.36041641], [72.41014099, 22.36069489], [72.4098587, 22.36069489], [72.4098587, 22.36096954], [72.40957642, 22.36096954], [72.40957642, 22.36125183], [72.40930939, 22.36125183], [72.4092865, 22.3615303], [72.40898132, 22.3615303], [72.40875244, 22.3615303], [72.40875244, 22.36181068], [72.40847015, 22.36180496], [72.40847015, 22.36208344], [72.40791321, 22.36208344], [72.40791321, 22.36236382], [72.40763855, 22.36236191], [72.40763855, 22.36264038], [72.40735626, 22.36264038], [72.40735626, 22.36292076], [72.40680695, 22.36291695], [72.40680695, 22.3631897], [72.40652466, 22.36319542], [72.40652466, 22.36347389], [72.40625, 22.36347008], [72.40625, 22.36375046], [72.40569305, 22.36375046], [72.40569305, 22.36404037], [72.4054184, 22.36404037], [72.4054184, 22.36431122], [72.40486145, 22.3643055], [72.40486145, 22.36458206], [72.40458679, 22.36458015], [72.40458679, 22.36486053], [72.40429688, 22.36486053], [72.40429688, 22.36514091], [72.40402985, 22.36514091], [72.40402985, 22.36541939], [72.40374756, 22.36541748], [72.40374756, 22.36569595], [72.4034729, 22.36569595], [72.4034729, 22.36597252], [72.40319824, 22.36597061], [72.40319824, 22.36625099], [72.40291595, 22.36625099], [72.40291595, 22.36652946], [72.4026413, 22.36652946], [72.4026413, 22.36680984], [72.40235901, 22.36680412], [72.40235901, 22.3670826], [72.40180206, 22.36708069], [72.40180206, 22.36736107], [72.40125275, 22.36736107], [72.40125275, 22.36763954], [72.4006958, 22.36763954], [72.4006958, 22.36791992], [72.40041351, 22.3679142], [72.40041351, 22.36819458], [72.3998642, 22.36819458], [72.3998642, 22.36847305], [72.39930725, 22.36847115], [72.39930725, 22.36874962], [72.39902496, 22.36874962], [72.39902496, 22.36930466], [72.39875031, 22.36930466], [72.39875031, 22.36958313], [72.39848328, 22.36958122], [72.39848328, 22.37013817], [72.39819336, 22.37013817], [72.39819336, 22.37070084], [72.3979187, 22.37070084], [72.3979187, 22.37124825], [72.39763641, 22.37124825], [72.39763641, 22.37181091], [72.3973465, 22.37181091], [72.3973465, 22.37235832], [72.3970871, 22.37235832], [72.3970871, 22.37291908], [72.39679718, 22.37291908], [72.39679718, 22.37375069], [72.39653015, 22.37375069], [72.39653015, 22.3745842], [72.39624786, 22.3745842], [72.39624786, 22.37569427], [72.39597321, 22.37569046], [72.39597321, 22.37652969], [72.39569092, 22.37652779], [72.39569092, 22.3773613], [72.39541626, 22.3773613], [72.39541626, 22.37819481], [72.39530945, 22.37819481], [72.3951416, 22.37819481], [72.3951416, 22.3783226], [72.3951416, 22.37903976], [72.39485931, 22.37902832], [72.39485931, 22.37986183], [72.39457703, 22.37985992], [72.39457703, 22.38070107], [72.39430237, 22.38069534], [72.39431, 22.38150024], [72.39414978, 22.3815403], [72.39402771, 22.38154984], [72.39402771, 22.38236046], [72.39375305, 22.38236046], [72.39375305, 22.38264084], [72.39319611, 22.38264084], [72.39319611, 22.38236046], [72.39263916, 22.38236046], [72.39263916, 22.38220024], [72.39263916, 22.38208389], [72.3923645, 22.38208389], [72.3923645, 22.38180542], [72.39180756, 22.38181114], [72.39180756, 22.38153076], [72.3915329, 22.38153076], [72.3915329, 22.38181114], [72.39069366, 22.38180542], [72.39069366, 22.38208389], [72.38986206, 22.38208008], [72.38986206, 22.38236046], [72.38903046, 22.38236046], [72.38903046, 22.38264084], [72.38846588, 22.38264084], [72.38846588, 22.38292122], [72.38764191, 22.3829155], [72.38764191, 22.38319397], [72.38708496, 22.38319397], [72.38708496, 22.38347244], [72.38652802, 22.38347054], [72.38652802, 22.38375092], [72.38597107, 22.38375092], [72.38597107, 22.38402748], [72.38513947, 22.38402748], [72.38513947, 22.38430977], [72.38458252, 22.38430786], [72.38458252, 22.38458252], [72.38346863, 22.38458061], [72.38346863, 22.38485909], [72.38263702, 22.38485909], [72.38263702, 22.38513756], [72.38153076, 22.38513756], [72.38153076, 22.38541985], [72.37931061, 22.38541985], [72.37931061, 22.38513756], [72.37623596, 22.38513756], [72.37623596, 22.38485909], [72.37568665, 22.38485909], [72.37568665, 22.38458061], [72.37541962, 22.38458252], [72.37541962, 22.38430786], [72.37486267, 22.38430977], [72.37486267, 22.38402748], [72.37431335, 22.38402748], [72.37431335, 22.38375092], [72.37403107, 22.38375092], [72.37403107, 22.38347054], [72.37347412, 22.38347244], [72.37347412, 22.38319397], [72.37291718, 22.38319397], [72.37291718, 22.3829155], [72.37264252, 22.38292122], [72.37264252, 22.38264084], [72.3720932, 22.38264084], [72.3720932, 22.38236046], [72.37180328, 22.38236046], [72.37180328, 22.38208008], [72.37124634, 22.38208389], [72.37124634, 22.38180542], [72.37069702, 22.38180542], [72.37069702, 22.38152695], [72.3704071, 22.38153076], [72.3704071, 22.38125038], [72.36985779, 22.38125038], [72.36985779, 22.38097], [72.36930847, 22.38097191], [72.36930847, 22.38069534], [72.36902618, 22.38070107], [72.36902618, 22.38042068], [72.36846924, 22.38042068], [72.36846924, 22.3801403], [72.36818695, 22.3801403], [72.36818695, 22.37985992], [72.36763763, 22.37986183], [72.36763763, 22.37958336], [72.36736298, 22.37958336], [72.36736298, 22.37930489], [72.36680603, 22.37930489], [72.36680603, 22.37902832], [72.36653137, 22.37903976], [72.36653137, 22.37874985], [72.3659668, 22.37874985], [72.3659668, 22.37846947], [72.36569214, 22.37847137], [72.36569214, 22.37819481], [72.36513519, 22.37819481], [72.36513519, 22.37791634], [72.36486053, 22.37792015], [72.36486053, 22.37763977], [72.36429596, 22.37763977], [72.36429596, 22.37735939], [72.36402893, 22.3773613], [72.36402893, 22.37708282], [72.36374664, 22.37708282], [72.36374664, 22.37680626], [72.36319733, 22.37681007], [72.36319733, 22.37652969], [72.36292267, 22.37652969], [72.36292267, 22.37625122], [72.36235809, 22.37625122], [72.36235809, 22.37598038], [72.36207581, 22.37598038], [72.36207581, 22.37569046], [72.36180878, 22.37566948], [72.36180878, 22.37513924], [72.36152649, 22.37514114], [72.36152649, 22.37486267], [72.36123657, 22.37486267], [72.36123657, 22.37402916], [72.36096954, 22.37402916], [72.36096954, 22.37291908], [72.36068726, 22.37291908], [72.36068726, 22.37207985], [72.36096954, 22.37208366], [72.36096954, 22.37153053], [72.36207581, 22.37153053], [72.36207581, 22.37181091], [72.36374664, 22.37180519], [72.36374664, 22.37194061], [72.36374664, 22.37208366], [72.36402893, 22.37207985], [72.36402893, 22.37235832], [72.36429596, 22.37235832], [72.36429596, 22.37264061], [72.36458588, 22.37264061], [72.36458588, 22.37291908], [72.36513519, 22.37291718], [72.36513519, 22.37319374], [72.36541748, 22.37319374], [72.36541748, 22.37347221], [72.36569214, 22.37347221], [72.36569214, 22.37319374], [72.36958313, 22.37319374], [72.36958313, 22.37347221], [72.37152863, 22.3734684], [72.37152863, 22.37375069], [72.37291718, 22.37375069], [72.37291718, 22.3734684], [72.37458038, 22.37347221], [72.37458038, 22.37319374], [72.37569427, 22.37319374], [72.37569427, 22.37347221], [72.37650299, 22.3734684], [72.37708282, 22.3734684], [72.37708282, 22.37375069], [72.37763977, 22.37375069], [72.37763977, 22.37402916], [72.3779068, 22.37402916], [72.3779068, 22.37430954], [72.37847137, 22.37430573], [72.37847137, 22.3745842], [72.37874603, 22.37458038], [72.37874603, 22.37486267], [72.37931061, 22.37486267], [72.37931061, 22.37514114], [72.3795929, 22.37514114], [72.3795929, 22.37541962], [72.38014221, 22.3754158], [72.38014221, 22.37569427], [72.38153076, 22.37569427], [72.38153076, 22.3754158], [72.38237, 22.37541962], [72.38237, 22.37514114], [72.38208008, 22.37514114], [72.38208008, 22.37486267], [72.38237, 22.37486267], [72.38236237, 22.3745842], [72.38263702, 22.3745842], [72.38263702, 22.37430573], [72.38291931, 22.37430954], [72.38291931, 22.37402916], [72.38318634, 22.37402916], [72.38318634, 22.37375069], [72.38346863, 22.37375069], [72.38346863, 22.37318993], [72.38375092, 22.37319374], [72.38375092, 22.37291718], [72.3840332, 22.37291908], [72.3840332, 22.37264061], [72.38430786, 22.37264061], [72.38430786, 22.37231064], [72.38430786, 22.37208366], [72.38458252, 22.37208366], [72.38458252, 22.37180519], [72.38485718, 22.37181091], [72.38485718, 22.37153053], [72.38513947, 22.37153053], [72.38513947, 22.37124825], [72.38540649, 22.37124825], [72.38540649, 22.37096977], [72.38569641, 22.37097168], [72.38569641, 22.37069511], [72.38597107, 22.37070084], [72.38597107, 22.37042046], [72.38625336, 22.37042046], [72.38625336, 22.37013817], [72.38652802, 22.37013817], [72.38652802, 22.36985016], [72.38680267, 22.3698616], [72.38680267, 22.36958313], [72.38708496, 22.36958313], [72.38708496, 22.36930466], [72.38735962, 22.36930466], [72.38735962, 22.36902618], [72.38764191, 22.36903], [72.38764191, 22.36847115], [72.38791656, 22.36847305], [72.38791656, 22.3679142], [72.38817596, 22.36791992], [72.38817596, 22.36708069], [72.38847351, 22.3670826], [72.38847351, 22.36624908], [72.38903046, 22.36625099], [72.38903046, 22.36597061], [72.38957977, 22.36597252], [72.38957977, 22.36569595], [72.39041901, 22.36569595], [72.39041901, 22.36541748], [72.39097595, 22.36541939], [72.39097595, 22.36514091], [72.39125061, 22.36514091], [72.39125061, 22.36486053], [72.39180756, 22.36486053], [72.39180756, 22.36458015], [72.39208221, 22.36458206], [72.39208221, 22.3643055], [72.39263916, 22.36431122], [72.39263916, 22.36404037], [72.39290619, 22.36404037], [72.39290619, 22.36375046], [72.39347076, 22.36375046], [72.39347076, 22.36347008], [72.39375305, 22.36347389], [72.39375305, 22.36319351], [72.39430237, 22.36319351], [72.39430237, 22.36263847], [72.39457703, 22.36264038], [72.39457703, 22.36207962], [72.39485931, 22.36208344], [72.39485931, 22.3615284], [72.3951416, 22.3615303], [72.3951416, 22.36096954], [72.39541626, 22.36096954], [72.39541626, 22.36041641], [72.39569092, 22.36042023], [72.39569092, 22.35986137], [72.39597321, 22.35986137], [72.39597321, 22.35930634], [72.39624786, 22.35931015], [72.39624786, 22.35902977], [72.3970871, 22.35902977], [72.3970871, 22.35847092], [72.39736176, 22.35847282], [72.39736176, 22.35819435], [72.39763641, 22.35819435], [72.39763641, 22.35791588], [72.3979187, 22.35791588], [72.3979187, 22.35736084], [72.39819336, 22.35736084], [72.39819336, 22.35680962], [72.39848328, 22.35680962], [72.39848328, 22.35625076], [72.39875031, 22.35625076], [72.39875031, 22.35597038], [72.39902496, 22.35597229], [72.39902496, 22.35541534], [72.4005661, 22.35541534], [72.40125275, 22.35541534], [72.40125275, 22.35569382], [72.40180206, 22.35569382], [72.40180206, 22.35541534], [72.40207672, 22.35542107], [72.40207672, 22.35485077], [72.40235901, 22.35486031], [72.40235901, 22.35458374], [72.4026413, 22.35458374], [72.4026413, 22.3540287], [72.40319061, 22.35403061], [72.40319824, 22.35375023], [72.40374756, 22.35375023], [72.40374756, 22.35320091], [72.40402985, 22.35320091], [72.40402985, 22.35235977], [72.4043045, 22.35236168], [72.4043045, 22.35152817], [72.40402985, 22.35153008], [72.40402985, 22.35124969], [72.40374756, 22.35124969], [72.40374756, 22.35069275], [72.4034729, 22.35069466], [72.4034729, 22.34986115], [72.40319824, 22.34986115], [72.40319061, 22.34902954], [72.40291595, 22.34902954], [72.40291595, 22.34875107], [72.40235901, 22.34875107], [72.40235901, 22.3484726], [72.40208435, 22.3484726], [72.40208435, 22.34819412], [72.4015274, 22.34819412], [72.4015274, 22.34791756], [72.40125275, 22.34791946], [72.40125275, 22.3476429], [72.40097046, 22.3476429], [72.40097046, 22.3473587], [72.40040588, 22.3473587], [72.40040588, 22.34707832], [72.40013885, 22.34708405], [72.40013885, 22.34680557], [72.39958191, 22.34680939], [72.39958191, 22.34653091], [72.39930725, 22.34653091], [72.39930725, 22.34625053], [72.39875031, 22.34625053], [72.39875031, 22.34597015], [72.39847565, 22.34597015], [72.39847565, 22.34569359], [72.3970871, 22.34569359], [72.3970871, 22.34541893], [72.39597321, 22.34542084], [72.39597321, 22.34514046], [72.39541626, 22.34514046], [72.39541626, 22.34485817], [72.39485931, 22.34486198], [72.39485931, 22.34458351], [72.39430237, 22.34458351], [72.39430237, 22.34430504], [72.39375305, 22.34430504], [72.39375305, 22.34458351], [72.3923645, 22.34458351], [72.3923645, 22.34430504], [72.39125061, 22.34431076], [72.39125061, 22.34403038], [72.38931274, 22.34403038], [72.38931274, 22.34374809], [72.38903046, 22.34374809], [72.38903046, 22.34346962], [72.38847351, 22.34347153], [72.38847351, 22.34319687], [72.38791656, 22.34320068], [72.38791656, 22.34291077], [72.38764191, 22.34291649], [72.38764191, 22.34263611], [72.38707733, 22.34263992], [72.38707733, 22.34235954], [72.38652802, 22.34236145], [72.38652802, 22.34208298], [72.38597107, 22.34208298], [72.38597107, 22.34180832], [72.38569641, 22.34181023], [72.38569641, 22.34152985], [72.38513947, 22.34152985], [72.38513947, 22.34124947], [72.38458252, 22.34124947], [72.38458252, 22.34097099], [72.38430786, 22.3409729], [72.38430786, 22.34069443], [72.38375092, 22.34069443], [72.38375092, 22.33986092], [72.38346863, 22.33987045], [72.38346863, 22.33930969], [72.38237, 22.33930969], [72.38237, 22.33903122], [72.38208008, 22.33903122], [72.38208008, 22.33875084], [72.38180542, 22.33875084], [72.38180542, 22.33847237], [72.38153076, 22.33847237], [72.38153076, 22.33819389], [72.38124847, 22.33819389], [72.38124847, 22.33791733], [72.38096619, 22.33792114], [72.38096619, 22.33764076], [72.38069153, 22.33764076], [72.38069153, 22.33736038], [72.38041687, 22.33736038], [72.38041687, 22.33708191], [72.38014221, 22.33708382], [72.38014221, 22.33680534], [72.37985992, 22.33681107], [72.37985992, 22.33653069], [72.3795929, 22.33653069], [72.3795929, 22.33625031], [72.37930298, 22.33625031], [72.37930298, 22.33597374], [72.37902832, 22.33597374], [72.37902832, 22.33541679], [72.37874603, 22.33542061], [72.37874603, 22.33514023], [72.37847137, 22.33514023], [72.37847137, 22.33457947], [72.37819672, 22.33458328], [72.37819672, 22.33402824], [72.3779068, 22.33403015], [72.3779068, 22.33373833], [72.37763977, 22.33375168], [72.37763977, 22.33319473], [72.37735748, 22.33319473], [72.37735748, 22.3326416], [72.37708282, 22.3326416], [72.37708282, 22.33208084], [72.37680817, 22.33208275], [72.37680817, 22.33180618], [72.37652588, 22.33180809], [72.37652588, 22.33125114], [72.37623596, 22.33125114], [72.37623596, 22.33068085], [72.37596893, 22.3306942], [72.37596893, 22.33041954], [72.37568665, 22.33041954], [72.37568665, 22.32986069], [72.37541962, 22.32986069], [72.37541962, 22.32930946], [72.37513733, 22.32930946], [72.37513733, 22.32875061], [72.37486267, 22.32875061], [72.37486267, 22.32793045], [72.37458038, 22.32793045], [72.37458038, 22.32707977], [72.37430573, 22.32708359], [72.37430573, 22.32625008], [72.37403107, 22.32625008], [72.37403107, 22.32570076], [72.37374878, 22.32570076], [72.37374878, 22.32487106], [72.3735733, 22.32487106], [72.37346649, 22.32487106], [72.37347412, 22.32434845], [72.37347412, 22.32402802], [72.37317657, 22.32402992], [72.37317657, 22.3231926], [72.37291718, 22.3231945], [72.37288666, 22.32125282], [72.37264252, 22.32125282], [72.37264252, 22.32018089], [72.37264252, 22.31847191], [72.37236023, 22.31847191], [72.37236023, 22.31652641], [72.37264252, 22.31653023], [72.37264252, 22.31513977], [72.37291718, 22.31513977], [72.37291718, 22.31375122], [72.37317657, 22.31375122], [72.37317657, 22.31264114], [72.37346649, 22.31264114], [72.37346649, 22.31208038], [72.37374878, 22.3120842], [72.37374878, 22.31125069], [72.37403107, 22.31125069], [72.37403107, 22.3104229], [72.37431335, 22.3104229], [72.37431335, 22.30986023], [72.37458038, 22.30986023], [72.37458038, 22.30903053], [72.37486267, 22.30903053], [72.3748703, 22.30847168], [72.37513733, 22.30847168], [72.37513733, 22.30791664], [72.37541962, 22.30792046], [72.37541962, 22.30707932], [72.37569427, 22.30708313], [72.37569427, 22.30652809], [72.37596893, 22.30653191], [72.37596893, 22.30596924], [72.37625122, 22.30597305], [72.37625122, 22.30541611], [72.37652588, 22.30541992], [72.37652588, 22.30513763], [72.37680817, 22.30513763], [72.37680817, 22.30485916], [72.37708282, 22.30485916], [72.37708282, 22.30458069], [72.37763977, 22.3045826], [72.37763977, 22.30430794], [72.3779068, 22.30430984], [72.3779068, 22.30402946], [72.37819672, 22.30402946], [72.37819672, 22.30376053], [72.37847137, 22.30376053], [72.37847137, 22.30347061], [72.37875366, 22.30347252], [72.37875366, 22.30319405], [72.37902832, 22.30319405], [72.37902832, 22.30291939], [72.3795929, 22.30291939], [72.3795929, 22.30264091], [72.37985992, 22.30264091], [72.37985992, 22.30236053], [72.38014221, 22.30236053], [72.38014221, 22.30208015], [72.38041687, 22.30208397], [72.38041687, 22.3018055], [72.38096619, 22.30181122], [72.38096619, 22.30153084], [72.38124847, 22.30153084], [72.38124847, 22.30125046], [72.38153076, 22.30125046], [72.38153076, 22.30097008], [72.38208008, 22.30097198], [72.38208008, 22.30069351], [72.38237, 22.30070114], [72.38237, 22.30042076], [72.38291931, 22.30042076], [72.38291931, 22.30014038], [72.38318634, 22.30014038], [72.38318634, 22.29986], [72.38430786, 22.29986191], [72.38430786, 22.29958344], [72.38541412, 22.29958344], [72.38541412, 22.29930305], [72.38652802, 22.29931068], [72.38652802, 22.2990303], [72.38671112, 22.2990303], [72.38764191, 22.2990303], [72.38764191, 22.29874992], [72.39290619, 22.29874992], [72.39290619, 22.2990303], [72.39639282, 22.2990303], [72.39848328, 22.2990303], [72.39848328, 22.29931068], [72.4109726, 22.29931068], [72.4109726, 22.2990303], [72.41124725, 22.2990303], [72.41124725, 22.29874992], [72.41179657, 22.29874992], [72.41179657, 22.29846954], [72.41236115, 22.29847145], [72.41236115, 22.29819489], [72.41291809, 22.29819489], [72.41291809, 22.29791641], [72.41319275, 22.29792023], [72.41319275, 22.29763031], [72.41374969, 22.29763794], [72.41374969, 22.29708481], [72.41402435, 22.29708481], [72.41402435, 22.29597282], [72.41430664, 22.29597282], [72.41430664, 22.29513931], [72.4145813, 22.29514122], [72.4145813, 22.29430962], [72.41485596, 22.29430962], [72.41485596, 22.2931881], [72.41513824, 22.29319382], [72.41513824, 22.29180527], [72.41542053, 22.29182243], [72.41542053, 22.28957939], [72.41569519, 22.28958321], [72.41569519, 22.28736115], [72.41596985, 22.28736115], [72.41596985, 22.28458023], [72.41625214, 22.28458214], [72.41625214, 22.28180504], [72.41652679, 22.28181267], [72.41652679, 22.27959251], [72.41625214, 22.27959251], [72.41625214, 22.27514076], [72.41596985, 22.27514076], [72.41596985, 22.27096939], [72.41569519, 22.2709713], [72.41569519, 22.26847267], [72.4154129, 22.26847267], [72.4154129, 22.26736259], [72.41513824, 22.26736259], [72.41513824, 22.26652908], [72.41485596, 22.26652908], [72.41485596, 22.26542091], [72.4145813, 22.26542091], [72.4145813, 22.26431084], [72.41430664, 22.26431084], [72.41430664, 22.2634697], [72.41402435, 22.2634716], [72.41402435, 22.26236153], [72.41374969, 22.26236153], [72.41374969, 22.2618084], [72.41348267, 22.2618103], [72.41348267, 22.25958061], [72.41319275, 22.25958252], [72.41319275, 22.25708389], [72.41291809, 22.25708389], [72.41291809, 22.25430489], [72.4126358, 22.25430489], [72.4126358, 22.25402832], [72.41291809, 22.25403023], [72.41291809, 22.25375175], [72.41319275, 22.25375175], [72.41319275, 22.25041962], [72.41348267, 22.25041962], [72.41348267, 22.24986076], [72.41319275, 22.24986076], [72.41319275, 22.24930954], [72.41348267, 22.24930954], [72.41348267, 22.24792099], [72.41374969, 22.24792099], [72.41374969, 22.24625015], [72.41401672, 22.24625015], [72.41401672, 22.2448597], [72.41430664, 22.2448616], [72.41430664, 22.24347115], [72.4145813, 22.24347115], [72.4145813, 22.24180603], [72.41485596, 22.24180984], [72.41485596, 22.23707962], [72.41513824, 22.23708344], [72.41513824, 22.23513794], [72.41542053, 22.23513985], [72.41542053, 22.23319054], [72.41569519, 22.23319435], [72.41569519, 22.23152733], [72.41596985, 22.23152733], [72.41596985, 22.22986031], [72.41625214, 22.22986031], [72.41625214, 22.22820282], [72.41652679, 22.22820282], [72.41652679, 22.22736168], [72.41402435, 22.22736168], [72.41402435, 22.22708321], [72.41152954, 22.22708321], [72.41152954, 22.2262516], [72.41179657, 22.2262516], [72.41179657, 22.22513962], [72.41208649, 22.22513962], [72.41208649, 22.22375107], [72.41234589, 22.22375107], [72.41234589, 22.22264099], [72.4126358, 22.22264099], [72.4126358, 22.22125053], [72.41234589, 22.22125053], [72.41234589, 22.22020721], [72.41208649, 22.22014046], [72.41208649, 22.21903038], [72.41179657, 22.21903038], [72.41179657, 22.2179203], [72.41152954, 22.2179203], [72.41152954, 22.21681023], [72.41124725, 22.21681023], [72.41124725, 22.21569252], [72.4109726, 22.21569443], [72.4109726, 22.21513939], [72.41014099, 22.21513939], [72.41014099, 22.21486282], [72.4092865, 22.21486282], [72.4092865, 22.21458244], [72.40847015, 22.21458244], [72.40847015, 22.21430588], [72.40820313, 22.21430969], [72.40820313, 22.21403122], [72.40791321, 22.21403122], [72.40791321, 22.21375084], [72.40763855, 22.21375084], [72.40763855, 22.2134819], [72.40735626, 22.2134819], [72.40735626, 22.21318817], [72.40680695, 22.21318817], [72.40680695, 22.21375084], [72.4054184, 22.21375084], [72.4054184, 22.21180916], [72.40513611, 22.21180916], [72.40513611, 22.20957947], [72.40458679, 22.20958328], [72.40458679, 22.20930481], [72.4034729, 22.20930481], [72.4034729, 22.20958328], [72.4026413, 22.20958328], [72.4026413, 22.20902634], [72.40235901, 22.20903015], [72.40235901, 22.20846939], [72.40208435, 22.2084713], [72.40208435, 22.20763969], [72.40180206, 22.20763969], [72.40180206, 22.20597076], [72.4015274, 22.20597267], [72.4015274, 22.20458221], [72.40125275, 22.20458221], [72.40125275, 22.20347214], [72.40097046, 22.20347214], [72.40097046, 22.20236206], [72.4006958, 22.20236206], [72.4006958, 22.20152855], [72.40040588, 22.20153999], [72.40040588, 22.20070267], [72.40013885, 22.20070267], [72.40013885, 22.19957924], [72.3998642, 22.19958305], [72.3998642, 22.19930649], [72.39958191, 22.19930649], [72.39958191, 22.19958305], [72.39930725, 22.19957924], [72.39930725, 22.20042038], [72.39901733, 22.20042038], [72.39901733, 22.20125008], [72.39875031, 22.20125008], [72.39875031, 22.20181274], [72.39848328, 22.20181274], [72.39848328, 22.20264053], [72.39819336, 22.20264053], [72.39819336, 22.20375061], [72.3979187, 22.20375061], [72.3979187, 22.20430946], [72.39763641, 22.20430946], [72.39763641, 22.20486069], [72.39736176, 22.20486069], [72.39736176, 22.2056942], [72.3970871, 22.20569038], [72.3970871, 22.20625114], [72.39679718, 22.20625114], [72.39679718, 22.20681], [72.39653015, 22.20680428], [72.39653015, 22.20708275], [72.39624786, 22.20708275], [72.39624786, 22.20736122], [72.39597321, 22.20734978], [72.39597321, 22.20763969], [72.39569092, 22.20763969], [72.39569092, 22.20792007], [72.39541626, 22.20791435], [72.39541626, 22.20819473], [72.3951416, 22.20819473], [72.3951416, 22.2084713], [72.39485931, 22.20846939], [72.39485931, 22.20874977], [72.39458466, 22.20874977], [72.39458466, 22.20930481], [72.39430237, 22.20930481], [72.39430237, 22.20986176], [72.39402771, 22.20986176], [72.39402771, 22.2104187], [72.39375305, 22.2104187], [72.39375305, 22.21097183], [72.39347076, 22.21096992], [72.39347076, 22.21153069], [72.39319611, 22.21152878], [72.39319611, 22.21208382], [72.39290619, 22.21207809], [72.39290619, 22.21264076], [72.39263916, 22.21264076], [72.39263916, 22.21319389], [72.39235687, 22.21318817], [72.39235687, 22.2134819], [72.39208221, 22.2134819], [72.39208221, 22.21375084], [72.3915329, 22.21375084], [72.3915329, 22.21403122], [72.39125061, 22.21403122], [72.39125061, 22.21430969], [72.39097595, 22.21430588], [72.39097595, 22.21458244], [72.39068604, 22.21458244], [72.39068604, 22.21486282], [72.39041901, 22.21486282], [72.39041901, 22.21513939], [72.38957977, 22.21513939], [72.38957977, 22.21541977], [72.38930511, 22.21541595], [72.38930511, 22.21569443], [72.38847351, 22.21569443], [72.38847351, 22.2159729], [72.38791656, 22.2159729], [72.38791656, 22.21624947], [72.38707733, 22.21624947], [72.38707733, 22.21653938], [72.38652802, 22.21653938], [72.38652802, 22.21681023], [72.38569641, 22.21680641], [72.38569641, 22.21708488], [72.38513947, 22.21708488], [72.38513947, 22.21736145], [72.38430786, 22.21735954], [72.38430786, 22.21763992], [72.38375092, 22.21763992], [72.38375092, 22.2179203], [72.38291931, 22.2179203], [72.38291931, 22.21820068], [72.38236237, 22.21819305], [72.38236237, 22.21847153], [72.38208008, 22.21846962], [72.38208008, 22.21903038], [72.38181305, 22.21903038], [72.38181305, 22.21931076], [72.38153076, 22.21930313], [72.38153076, 22.21986198], [72.38124847, 22.21986008], [72.38124847, 22.22042084], [72.38097382, 22.22041512], [72.38097382, 22.22069359], [72.38069153, 22.22068977], [72.38069153, 22.22125053], [72.38041687, 22.22125053], [72.38041687, 22.22153091], [72.38014221, 22.22152519], [72.38014221, 22.22208595], [72.37985992, 22.22208023], [72.37985992, 22.22264099], [72.3795929, 22.22264099], [72.3795929, 22.22291946], [72.37930298, 22.22291946], [72.37930298, 22.2234726], [72.37902832, 22.22347069], [72.37902832, 22.22375107], [72.37874603, 22.22375107], [72.37874603, 22.22430992], [72.37847137, 22.22430992], [72.37847137, 22.22485924], [72.37819672, 22.22485924], [72.37819672, 22.22513962], [72.37791443, 22.22513962], [72.37791443, 22.22569466], [72.37763977, 22.22569084], [72.37763977, 22.2262516], [72.37735748, 22.2262516], [72.37735748, 22.22736168], [72.37708282, 22.22736168], [72.37708282, 22.22820282], [72.37680817, 22.22819519], [72.37680817, 22.22850037], [72.37680817, 22.22863007], [72.37680817, 22.22903061], [72.37652588, 22.22903061], [72.37652588, 22.23014069], [72.37625122, 22.23013878], [72.37625122, 22.23097229], [72.37596893, 22.23097229], [72.37596893, 22.23208427], [72.37569427, 22.23208427], [72.37569427, 22.23597145], [72.37596893, 22.23596954], [72.37596893, 22.2365303], [72.37625122, 22.23652649], [72.37625122, 22.23736191], [72.37652588, 22.23735809], [72.37652588, 22.23792076], [72.37680817, 22.23792076], [72.37680817, 22.23875046], [72.37708282, 22.23875046], [72.37708282, 22.23930931], [72.37735748, 22.23930931], [72.37735748, 22.24014091], [72.37763977, 22.24014091], [72.37763977, 22.24041939], [72.37819672, 22.24041748], [72.37819672, 22.24069405], [72.37875366, 22.24069405], [72.37875366, 22.24097252], [72.37902832, 22.24097252], [72.37902832, 22.2412529], [72.37931061, 22.2412529], [72.37931061, 22.24152946], [72.3795929, 22.24152946], [72.3795929, 22.24180984], [72.37985992, 22.24180603], [72.37985992, 22.2420826], [72.38014221, 22.2420826], [72.38014221, 22.24263954], [72.38069153, 22.24263954], [72.38069153, 22.24319458], [72.38097382, 22.24319458], [72.38097382, 22.24347115], [72.38124847, 22.24346161], [72.38124847, 22.24403], [72.38153076, 22.24402809], [72.38153076, 22.24430466], [72.38208008, 22.24430466], [72.38208008, 22.24458313], [72.38236237, 22.24458313], [72.38236237, 22.2448616], [72.38263702, 22.2448597], [72.38263702, 22.24514008], [72.38291931, 22.24514008], [72.38291931, 22.24542046], [72.38318634, 22.24542046], [72.38318634, 22.24570084], [72.38346863, 22.24570084], [72.38346863, 22.24681091], [72.38208008, 22.24681091], [72.38208008, 22.24736023], [72.38180542, 22.24736023], [72.38180542, 22.24819374], [72.38153076, 22.24818993], [72.38153076, 22.24875069], [72.38124847, 22.24875069], [72.38124847, 22.24986076], [72.38153076, 22.24986076], [72.38153076, 22.25069427], [72.38181305, 22.25069046], [72.38181305, 22.25265121], [72.38208008, 22.25264168], [72.38208008, 22.25346947], [72.38153076, 22.25346947], [72.38153076, 22.25403023], [72.38124847, 22.25402832], [72.38124847, 22.25458336], [72.38096619, 22.25457954], [72.38096619, 22.2551403], [72.38069153, 22.2551403], [72.38069153, 22.2557106], [72.38041687, 22.2557106], [72.38041687, 22.25625038], [72.38014221, 22.25625038], [72.38014221, 22.25681114], [72.37985992, 22.25681114], [72.37985992, 22.25736046], [72.3795929, 22.25736046], [72.3795929, 22.25764084], [72.37930298, 22.25763893], [72.37930298, 22.25819206], [72.37902832, 22.25819206], [72.37902832, 22.25847244], [72.37874603, 22.25846291], [72.37874603, 22.25902939], [72.37847137, 22.25902939], [72.37847137, 22.25930977], [72.37819672, 22.25930977], [72.37819672, 22.25986099], [72.3779068, 22.25986099], [72.3779068, 22.26013947], [72.37763977, 22.26013947], [72.37763977, 22.2606945], [72.37735748, 22.2606945], [72.37735748, 22.26097298], [72.37680817, 22.26097107], [72.37680817, 22.26124954], [72.37623596, 22.26124954], [72.37623596, 22.26152992], [72.37568665, 22.26152992], [72.37568665, 22.2618103], [72.37513733, 22.2618084], [72.37513733, 22.26208305], [72.37430573, 22.26208305], [72.37430573, 22.26236153], [72.37374878, 22.26235962], [72.37374878, 22.26263809], [72.37291718, 22.26263809], [72.37291718, 22.26292038], [72.37236023, 22.26292038], [72.37236023, 22.26320076], [72.37152863, 22.26319695], [72.37152863, 22.2634716], [72.37097168, 22.2634697], [72.37097168, 22.26374817], [72.37014008, 22.26374817], [72.37014008, 22.26403046], [72.36958313, 22.26403046], [72.36958313, 22.26431084], [72.36818695, 22.26431084], [72.36818695, 22.26458931], [72.36680603, 22.26458931], [72.36680603, 22.26652908], [72.36541748, 22.26652908], [72.36541748, 22.26680946], [72.36374664, 22.26680565], [72.36374664, 22.26708412], [72.36235809, 22.2670784], [72.36235809, 22.26736259], [72.36180878, 22.26736259], [72.36180878, 22.2676506], [72.36152649, 22.2676506], [72.36152649, 22.26791954], [72.36096954, 22.26791763], [72.36096954, 22.2681942], [72.36013794, 22.2681942], [72.36013794, 22.26791763], [72.36003113, 22.26791763], [72.35986328, 22.26791954], [72.35986328, 22.2676506], [72.35930634, 22.2676506], [72.35930634, 22.26736259], [72.35901642, 22.26736259], [72.35901642, 22.2676506], [72.35874939, 22.26763916], [72.35874939, 22.2681942], [72.3584671, 22.26819038], [72.3584671, 22.27042007], [72.35819244, 22.27041626], [72.35819244, 22.2709713], [72.3576355, 22.2709713], [72.35764313, 22.27124977], [72.35624695, 22.27124977], [72.35624695, 22.27013969], [72.35597229, 22.27013969], [72.35597229, 22.26847267], [72.35624695, 22.26847267], [72.35624695, 22.26625061], [72.35652924, 22.26625061], [72.35652924, 22.26431084], [72.35679626, 22.26431084], [72.35679626, 22.26320076], [72.35708618, 22.26320076], [72.35708618, 22.26292038], [72.35736084, 22.26292038], [72.35736084, 22.26263809], [72.35764313, 22.26263809], [72.35764313, 22.26235962], [72.35791779, 22.26236153], [72.35791779, 22.26208305], [72.35819244, 22.26208305], [72.35819244, 22.2618084], [72.35874939, 22.26180077], [72.35874939, 22.26152611], [72.35901642, 22.26152992], [72.35901642, 22.26124954], [72.35913849, 22.26124954], [72.35930634, 22.26124954], [72.35930634, 22.26097107], [72.35958099, 22.26097298], [72.35958099, 22.2606945], [72.35986328, 22.2606945], [72.35986328, 22.26041412], [72.36069489, 22.26041412], [72.36069489, 22.2606945], [72.36096954, 22.2606945], [72.36096954, 22.26097298], [72.36180878, 22.26097298], [72.36180878, 22.2606945], [72.36235809, 22.2606945], [72.36235809, 22.26041412], [72.36319733, 22.26041985], [72.36319733, 22.25986099], [72.36347198, 22.25986099], [72.36347198, 22.25930977], [72.36374664, 22.25930977], [72.36374664, 22.25875092], [72.36402893, 22.25875092], [72.36402893, 22.25819016], [72.36430359, 22.25819206], [72.36430359, 22.25680542], [72.36402893, 22.25681114], [72.36402893, 22.2557106], [72.36429596, 22.2557106], [72.36429596, 22.2551403], [72.36458588, 22.2551403], [72.36458588, 22.25457954], [72.36486053, 22.25458336], [72.36486053, 22.25430489], [72.36513519, 22.25430489], [72.36513519, 22.25375175], [72.36541748, 22.25375175], [72.36541748, 22.25318909], [72.36569214, 22.25319481], [72.36569214, 22.2523613], [72.36597443, 22.2523613], [72.36597443, 22.25152969], [72.36624908, 22.25152969], [72.36624908, 22.25097084], [72.36653137, 22.25097275], [72.36653137, 22.25013733], [72.36680603, 22.25014114], [72.36680603, 22.24958992], [72.36708069, 22.24958992], [72.36708069, 22.24903107], [72.36737061, 22.24903107], [72.36737061, 22.24875069], [72.36763763, 22.24875069], [72.36763763, 22.24847031], [72.36791992, 22.24847221], [72.36791992, 22.24791527], [72.36818695, 22.24792099], [72.36818695, 22.24764061], [72.36846924, 22.24764061], [72.36846924, 22.24736023], [72.36875153, 22.24736023], [72.36875153, 22.24681091], [72.36902618, 22.24681091], [72.36902618, 22.246521], [72.36930847, 22.24652863], [72.36930847, 22.24625015], [72.36985779, 22.24625015], [72.36985779, 22.24596977], [72.37014008, 22.24597168], [72.37014008, 22.24569321], [72.3704071, 22.24570084], [72.3704071, 22.24542046], [72.37069702, 22.24542046], [72.37069702, 22.24514008], [72.37097168, 22.24514008], [72.37097168, 22.24403], [72.37069702, 22.24403], [72.37069702, 22.24263954], [72.3704071, 22.24263954], [72.3704071, 22.2420826], [72.37014008, 22.2420826], [72.37014008, 22.24152756], [72.36985779, 22.24152946], [72.36985779, 22.24097252], [72.36958313, 22.24097252], [72.36958313, 22.24041748], [72.36930847, 22.24041939], [72.36930847, 22.23985863], [72.36902618, 22.23985863], [72.36902618, 22.23957825], [72.36875153, 22.23958397], [72.36875153, 22.2393055], [72.36846924, 22.23930931], [72.36846924, 22.23875046], [72.36818695, 22.23875046], [72.36818695, 22.23846817], [72.36791992, 22.23847008], [72.36791992, 22.23819542], [72.36763763, 22.2381897], [72.36763763, 22.23791885], [72.36737061, 22.23792076], [72.36737061, 22.23765182], [72.36708069, 22.23765182], [72.36708069, 22.23707962], [72.36680603, 22.23708344], [72.36680603, 22.23652649], [72.36653137, 22.2365303], [72.36653137, 22.23624992], [72.36624908, 22.23624992], [72.36624908, 22.23569107], [72.36597443, 22.23569679], [72.36597443, 22.23541641], [72.36569214, 22.23542023], [72.36569214, 22.23485947], [72.36541748, 22.23486137], [72.36541748, 22.23430443], [72.36514282, 22.23431015], [72.36514282, 22.23402977], [72.36486053, 22.23402977], [72.36486053, 22.23347092], [72.36458588, 22.23347282], [72.36458588, 22.23319435], [72.36430359, 22.23319435], [72.36430359, 22.23291588], [72.36402893, 22.23291969], [72.36402893, 22.23236084], [72.36374664, 22.23236084], [72.36374664, 22.23208046], [72.36347198, 22.23208427], [72.36347198, 22.2318058], [72.36319733, 22.23180962], [72.36319733, 22.23125076], [72.36291504, 22.23125076], [72.36291504, 22.23097229], [72.36264038, 22.23097229], [72.36264038, 22.23041725], [72.36235809, 22.23042107], [72.36235809, 22.23014069], [72.36207581, 22.23014069], [72.36207581, 22.22958183], [72.36180878, 22.22958374], [72.36180878, 22.2290287], [72.36152649, 22.22903061], [72.36152649, 22.22875023], [72.36123657, 22.22875023], [72.36123657, 22.22820282], [72.36096954, 22.22820282], [72.36096954, 22.22736168], [72.36069489, 22.22736168], [72.36069489, 22.2262516], [72.36042023, 22.2262516], [72.36042023, 22.22513962], [72.36013794, 22.22513962], [72.36013794, 22.22235107], [72.36042023, 22.22236061], [72.36042023, 22.22069359], [72.36013794, 22.22069359], [72.36013794, 22.22041512], [72.36042023, 22.22042084], [72.36042023, 22.2179203], [72.36068726, 22.2179203], [72.36068726, 22.21513939], [72.36096954, 22.21513939], [72.36096954, 22.21235847], [72.36123657, 22.21235847], [72.36123657, 22.21014023], [72.36096954, 22.21014023], [72.36096954, 22.20930099], [72.36125183, 22.20930481], [72.36125183, 22.20819473], [72.36152649, 22.20819473], [72.36152649, 22.20708275], [72.36180878, 22.20708275], [72.36180878, 22.20624924], [72.36207581, 22.20625114], [72.36207581, 22.20514107], [72.36235809, 22.20514107], [72.36235809, 22.20458031], [72.36264038, 22.20458221], [72.36264038, 22.20375061], [72.36292267, 22.20375061], [72.36291504, 22.20319366], [72.36319733, 22.20319366], [72.36319733, 22.2029171], [72.36347198, 22.20292282], [72.36347198, 22.20264053], [72.36374664, 22.20264053], [72.36374664, 22.20208168], [72.36402893, 22.20208359], [72.36402893, 22.20180511], [72.36429596, 22.20181274], [72.36429596, 22.20153999], [72.36486053, 22.20153999], [72.36486053, 22.2009716], [72.36541748, 22.2009716], [72.36541748, 22.20069504], [72.3659668, 22.20070267], [72.3659668, 22.20042038], [72.36653137, 22.20042038], [72.36653137, 22.20014191], [72.36737061, 22.20014191], [72.36737061, 22.19986153], [72.36763763, 22.19986153], [72.36763763, 22.19958305], [72.36846924, 22.19958305], [72.36846924, 22.19930649], [72.36930847, 22.19930077], [72.36930847, 22.19902992], [72.36985779, 22.19903183], [72.36985779, 22.19874763], [72.37069702, 22.19874763], [72.37069702, 22.19846916], [72.37124634, 22.19847298], [72.37124634, 22.1981945], [72.37208557, 22.1981945], [72.37208557, 22.19763947], [72.37403107, 22.19763947], [72.37403107, 22.19735909], [72.37513733, 22.19735909], [72.37513733, 22.19708061], [72.37652588, 22.19708252], [72.37652588, 22.19680786], [72.37735748, 22.19680977], [72.37735748, 22.19652939], [72.3779068, 22.19652939], [72.3779068, 22.19625092], [72.37847137, 22.19625092], [72.37847137, 22.19597054], [72.37902832, 22.19597244], [72.37902832, 22.19569397], [72.37958527, 22.19569397], [72.37958527, 22.1954155], [72.37985992, 22.1954155], [72.37985992, 22.19513893], [72.38041687, 22.19514084], [72.38041687, 22.19486046], [72.38069153, 22.19486046], [72.38069153, 22.19458008], [72.38097382, 22.19458389], [72.38097382, 22.19430542], [72.38124847, 22.19431114], [72.38124847, 22.19403076], [72.38153076, 22.19403076], [72.38153076, 22.19375038], [72.38181305, 22.19375038], [72.38180542, 22.19347191], [72.38236237, 22.19347191], [72.38236237, 22.19319534], [72.38263702, 22.19320107], [72.38263702, 22.19292068], [72.38291931, 22.19292068], [72.38291931, 22.1926403], [72.38318634, 22.1926403], [72.38318634, 22.19236946], [72.38346863, 22.19236946], [72.38346863, 22.19207954], [72.38375092, 22.19208336], [72.38375092, 22.19180489], [72.38402557, 22.19180489], [72.38402557, 22.19152832], [72.38430786, 22.19153023], [72.38430786, 22.19124985], [72.38458252, 22.19124985], [72.38458252, 22.19096947], [72.38486481, 22.19097137], [72.38486481, 22.19041634], [72.38513947, 22.19042015], [72.38513947, 22.19013977], [72.38540649, 22.19013977], [72.38540649, 22.18985939], [72.38569641, 22.1898613], [72.38569641, 22.18958282], [72.38597107, 22.18958282], [72.38597107, 22.18930626], [72.38625336, 22.18931007], [72.38625336, 22.18902969], [72.38652802, 22.18902969], [72.38652802, 22.18847275], [72.38680267, 22.18847275], [72.38680267, 22.18819427], [72.38708496, 22.18819427], [72.38708496, 22.18763924], [72.38735962, 22.18764114], [72.38735962, 22.18736267], [72.38764191, 22.18736267], [72.38764191, 22.18680954], [72.38791656, 22.18680954], [72.38791656, 22.18652916], [72.38817596, 22.18652916], [72.38817596, 22.18624115], [72.38847351, 22.18625069], [72.38847351, 22.18569374], [72.38874817, 22.18569374], [72.38874817, 22.18541718], [72.38903046, 22.18541908], [72.38903046, 22.18488121], [72.38931274, 22.18485832], [72.38930511, 22.18430519], [72.38957977, 22.18431091], [72.38957977, 22.18403053], [72.38986206, 22.18403053], [72.38986206, 22.18346977], [72.39013672, 22.18347168], [72.39013672, 22.18263626], [72.38986206, 22.18264008], [72.38986206, 22.1823597], [72.39013672, 22.1823616], [72.39013672, 22.18180466], [72.39041901, 22.18180466], [72.39041901, 22.18152618], [72.39068604, 22.18153], [72.39068604, 22.18097115], [72.39097595, 22.18097305], [72.39097595, 22.18069458], [72.39125061, 22.18069458], [72.39125061, 22.18013954], [72.3915329, 22.18013954], [72.39152527, 22.1795826], [72.39125061, 22.1795826], [72.39125061, 22.17930412], [72.39013672, 22.17930984], [72.39013672, 22.17875099], [72.38986206, 22.17875099], [72.38986206, 22.17764091], [72.38957977, 22.17764091], [72.38957977, 22.17653084], [72.38931274, 22.17653084], [72.38931274, 22.17542076], [72.38903046, 22.17542076], [72.38903046, 22.17429924], [72.38930511, 22.17430496], [72.38930511, 22.17319489], [72.38957977, 22.17319489], [72.38957977, 22.1720829], [72.38986206, 22.1720829], [72.38986206, 22.17097282], [72.39013672, 22.17097282], [72.39013672, 22.17041779], [72.39041901, 22.17041969], [72.39041901, 22.16986084], [72.39068604, 22.16986084], [72.39068604, 22.16930962], [72.39097595, 22.16930962], [72.39097595, 22.16875076], [72.39125061, 22.16875076], [72.39125061, 22.16818047], [72.39152527, 22.16819382], [72.39152527, 22.16791534], [72.39097595, 22.16792107], [72.39097595, 22.16764069], [72.39068604, 22.16764069], [72.39068604, 22.16736031], [72.39013672, 22.16736031], [72.39013672, 22.16707993], [72.38986206, 22.16708374], [72.38986206, 22.16680527], [72.38957977, 22.16681099], [72.38957977, 22.16764069], [72.38930511, 22.16763878], [72.38931274, 22.16986084], [72.38903046, 22.16986084], [72.38903046, 22.17097282], [72.38874817, 22.17097282], [72.38874817, 22.17124748], [72.38846588, 22.17123985], [72.38846588, 22.17152977], [72.38791656, 22.17152977], [72.38791656, 22.17180824], [72.38764191, 22.17180634], [72.38764191, 22.1720829], [72.38735962, 22.1720829], [72.38735962, 22.17236137], [72.38652802, 22.17236137], [72.38652802, 22.17180634], [72.38625336, 22.17180824], [72.38625336, 22.17123985], [72.38597107, 22.17124748], [72.38597107, 22.17097282], [72.38569641, 22.17097282], [72.38569641, 22.17041779], [72.38540649, 22.17041969], [72.38540649, 22.17014122], [72.38569641, 22.17014122], [72.38569641, 22.16958046], [72.38597107, 22.16958237], [72.38597107, 22.16930771], [72.38625336, 22.16930962], [72.38625336, 22.16875076], [72.38652802, 22.16875076], [72.38652802, 22.16764069], [72.38625336, 22.16764069], [72.38625336, 22.16543007], [72.38597107, 22.16543007], [72.38597107, 22.16319275], [72.38625336, 22.16319466], [72.38625336, 22.16180611], [72.38652802, 22.16180992], [72.38652802, 22.1609726], [72.38680267, 22.1609726], [72.38680267, 22.16041756], [72.38707733, 22.16041946], [72.38707733, 22.15986061], [72.38680267, 22.15986061], [72.38680267, 22.15957832], [72.38652802, 22.15958405], [72.38652802, 22.1590271], [72.38625336, 22.15903091], [72.38625336, 22.15875053], [72.38597107, 22.15875053], [72.38597107, 22.15846825], [72.38569641, 22.15847206], [72.38569641, 22.15819359], [72.38541412, 22.15819359], [72.38541412, 22.15764046], [72.38513947, 22.15764046], [72.38513947, 22.15735817], [72.38486481, 22.15736198], [72.38486481, 22.15708351], [72.38458252, 22.15708351], [72.38458252, 22.15680695], [72.38430786, 22.15681076], [72.38430786, 22.15624046], [72.38402557, 22.15624809], [72.38402557, 22.15597153], [72.38346863, 22.15597153], [72.38346863, 22.15624809], [72.38291931, 22.15624046], [72.38291931, 22.15653038], [72.38237, 22.15653038], [72.38237, 22.15681076], [72.38180542, 22.15680695], [72.38180542, 22.15708351], [72.38124847, 22.15708351], [72.38124847, 22.15736198], [72.38069153, 22.15735817], [72.38069153, 22.15764046], [72.38014221, 22.15764046], [72.38014221, 22.15792084], [72.37958527, 22.15791893], [72.37958527, 22.15819359], [72.37902832, 22.15819359], [72.37902832, 22.15847206], [72.37735748, 22.15847206], [72.37735748, 22.15819359], [72.37708282, 22.15819359], [72.37708282, 22.15680695], [72.37735748, 22.15681076], [72.37735748, 22.15653038], [72.37763977, 22.15653038], [72.37763977, 22.15570068], [72.3779068, 22.15570068], [72.3779068, 22.15402985], [72.37819672, 22.15402985], [72.37819672, 22.15347099], [72.37847137, 22.1534729], [72.37847137, 22.15208244], [72.37875366, 22.15208244], [72.37875366, 22.1515274], [72.37847137, 22.15153122], [72.37847137, 22.15097046], [72.37819672, 22.15097237], [72.37819672, 22.15069389], [72.37791443, 22.15069389], [72.37791443, 22.15041733], [72.37680817, 22.15042114], [72.37680817, 22.14986038], [72.37596893, 22.14986038], [72.37596893, 22.15042114], [72.37541962, 22.15041733], [72.37541962, 22.15069389], [72.37513733, 22.15069389], [72.37513733, 22.15097237], [72.37486267, 22.15097046], [72.37486267, 22.15153122], [72.37458038, 22.15153122], [72.37458038, 22.15180969], [72.37430573, 22.15180588], [72.37430573, 22.15708351], [72.37403107, 22.1570797], [72.37403107, 22.15792084], [72.37431335, 22.15792084], [72.37431335, 22.16013908], [72.37403107, 22.16013908], [72.37403107, 22.16180992], [72.37430573, 22.16180611], [72.37430573, 22.16347313], [72.37458038, 22.16347122], [72.37458038, 22.16514015], [72.37486267, 22.16514015], [72.37486267, 22.16653061], [72.37458038, 22.1665287], [72.37458038, 22.16708374], [72.37431335, 22.16707993], [72.37431335, 22.16764069], [72.37403107, 22.16763878], [72.37403107, 22.16819382], [72.37374878, 22.16818047], [72.37374878, 22.16875076], [72.37346649, 22.16875076], [72.37346649, 22.16930962], [72.37317657, 22.16930962], [72.37317657, 22.16986084], [72.37291718, 22.16986084], [72.37291718, 22.17041969], [72.37264252, 22.17041779], [72.37264252, 22.17097282], [72.37236023, 22.17097282], [72.37236023, 22.17124748], [72.3720932, 22.17123985], [72.3720932, 22.17180824], [72.37180328, 22.17180634], [72.37180328, 22.1720829], [72.37124634, 22.1720829], [72.37124634, 22.17236137], [72.37069702, 22.17235756], [72.37069702, 22.17264175], [72.36958313, 22.17264175], [72.36958313, 22.17235756], [72.36818695, 22.17235756], [72.36818695, 22.17264175], [72.36708069, 22.17264175], [72.36708069, 22.17292023], [72.36597443, 22.17291641], [72.36597443, 22.17319489], [72.36486053, 22.17319489], [72.36486053, 22.17347145], [72.36235809, 22.17347145], [72.36235809, 22.17319489], [72.36125183, 22.17319489], [72.36125183, 22.17291641], [72.35986328, 22.17292023], [72.35986328, 22.17264175], [72.35901642, 22.17264175], [72.35901642, 22.1740303], [72.35930634, 22.1740284], [72.35930634, 22.17486191], [72.35902405, 22.17486191], [72.35902405, 22.17597389], [72.35930634, 22.17597389], [72.35930634, 22.17708206], [72.35958099, 22.17708206], [72.35958099, 22.17819214], [72.35986328, 22.17819023], [72.35986328, 22.17902946], [72.36013794, 22.17902756], [72.36013794, 22.1795826], [72.36042023, 22.17958069], [72.36042023, 22.18013954], [72.36068726, 22.18013954], [72.36068726, 22.18042946], [72.36096954, 22.1804142], [72.36096954, 22.18097305], [72.36123657, 22.18097115], [72.36123657, 22.18124962], [72.36152649, 22.18124962], [72.36152649, 22.18153], [72.36180878, 22.18152618], [72.36180878, 22.18208313], [72.36208344, 22.18208313], [72.36208344, 22.1823616], [72.36235809, 22.1823597], [72.36235809, 22.18292046], [72.36264038, 22.18291855], [72.36264038, 22.18347168], [72.36291504, 22.18347168], [72.36291504, 22.18458366], [72.36319733, 22.18458366], [72.36319733, 22.18625069], [72.36347198, 22.18624115], [72.36347198, 22.18791962], [72.36374664, 22.18791962], [72.36374664, 22.18902969], [72.36319733, 22.18902969], [72.36319733, 22.18931007], [72.36264038, 22.18930626], [72.36264038, 22.18958282], [72.36208344, 22.18958282], [72.36208344, 22.1898613], [72.36152649, 22.18985939], [72.36152649, 22.19013977], [72.36123657, 22.19013977], [72.36123657, 22.19042015], [72.36096954, 22.19041634], [72.36096954, 22.19069481], [72.36068726, 22.1906929], [72.36068726, 22.19124985], [72.36042023, 22.19124985], [72.36042023, 22.19153023], [72.36013794, 22.19152832], [72.36013794, 22.19180489], [72.35986328, 22.19180489], [72.35986328, 22.19208336], [72.35958099, 22.19207954], [72.35958099, 22.19236946], [72.35930634, 22.19236946], [72.35930634, 22.19292068], [72.35901642, 22.19292068], [72.35901642, 22.19320107], [72.35820007, 22.19320107], [72.35820007, 22.19292068], [72.35764313, 22.19292068], [72.35764313, 22.1926403], [72.35791779, 22.1926403], [72.35791779, 22.19207954], [72.35819244, 22.19208336], [72.35819244, 22.19180489], [72.35847473, 22.19180489], [72.35847473, 22.19124985], [72.35874939, 22.19124985], [72.35874939, 22.19096947], [72.35902405, 22.19097137], [72.35902405, 22.19069481], [72.35930634, 22.19069481], [72.35930634, 22.19013977], [72.35958099, 22.19013977], [72.35958099, 22.18985939], [72.35986328, 22.1898613], [72.35986328, 22.18930626], [72.36013794, 22.18931007], [72.36013794, 22.18791962], [72.35986328, 22.18791962], [72.35986328, 22.18652916], [72.35958099, 22.18652916], [72.35958099, 22.1859684], [72.35930634, 22.18597221], [72.35930634, 22.18569374], [72.35902405, 22.18569374], [72.35902405, 22.18541718], [72.35874939, 22.18541908], [72.35874939, 22.18485832], [72.3584671, 22.18485832], [72.3584671, 22.18457985], [72.35819244, 22.18458366], [72.35819244, 22.18430519], [72.35791779, 22.18431091], [72.35791779, 22.18403053], [72.35764313, 22.18403053], [72.35764313, 22.18374825], [72.35736084, 22.18374825], [72.35736084, 22.18346977], [72.35708618, 22.18347168], [72.35708618, 22.18319511], [72.35679626, 22.18320084], [72.35679626, 22.18292046], [72.35652924, 22.18292046], [72.35652924, 22.1823597], [72.35624695, 22.1823616], [72.35624695, 22.18208313], [72.35597229, 22.18208313], [72.35597229, 22.18180466], [72.35541534, 22.18180466], [72.35541534, 22.18208313], [72.35514069, 22.18208313], [72.35514069, 22.1823616], [72.35375214, 22.1823597], [72.35375214, 22.18264008], [72.35206604, 22.18264008], [72.35206604, 22.18208122], [72.35180664, 22.18208313], [72.35180664, 22.18152618], [72.35206604, 22.18153], [72.35206604, 22.18124962], [72.35263824, 22.18124962], [72.35263824, 22.18097115], [72.3529129, 22.18097305], [72.3529129, 22.18069458], [72.35346985, 22.18069458], [72.35346985, 22.1804142], [72.35375214, 22.18042946], [72.35375214, 22.17764091], [72.35402679, 22.17764091], [72.35402679, 22.17457962], [72.35430908, 22.17458344], [72.35430908, 22.17236137], [72.35458374, 22.17236137], [72.35458374, 22.17013741], [72.35402679, 22.17014122], [72.35402679, 22.16764069], [72.35375214, 22.16764069], [72.35375214, 22.16720009], [72.35375214, 22.16625023], [72.35346985, 22.16625023], [72.35346985, 22.16514015], [72.35320282, 22.16514015], [72.35320282, 22.16457939], [72.35152435, 22.16458321], [72.35152435, 22.16486168], [72.35098267, 22.16485977], [72.35098267, 22.16514015], [72.35069275, 22.16514015], [72.35069275, 22.16543007], [72.3501358, 22.16543007], [72.3501358, 22.16570091], [72.34986115, 22.16569328], [72.34986115, 22.16597176], [72.34929657, 22.16596985], [72.34929657, 22.16625023], [72.34902954, 22.16625023], [72.34902954, 22.16653061], [72.3484726, 22.16653061], [72.3484726, 22.16681099], [72.34819794, 22.16680527], [72.34819794, 22.16708374], [72.34791565, 22.16708374], [72.34792328, 22.16736031], [72.34764099, 22.16736031], [72.34764099, 22.16764069], [72.34707642, 22.16764069], [72.34707642, 22.16792107], [72.34680939, 22.16791534], [72.34680176, 22.16819382], [72.3465271, 22.16819382], [72.3465271, 22.16847229], [72.34402466, 22.16847229], [72.34402466, 22.16819382], [72.34430695, 22.16819382], [72.34430695, 22.16763878], [72.3445816, 22.16764069], [72.3445816, 22.16707993], [72.34486389, 22.16708374], [72.34486389, 22.16680527], [72.34513855, 22.16681099], [72.34513855, 22.16625023], [72.34541321, 22.16625023], [72.34541321, 22.16570091], [72.34570313, 22.16570091], [72.34570313, 22.16543007], [72.34597015, 22.16543007], [72.34597015, 22.16485977], [72.34625244, 22.16486168], [72.34625244, 22.16458321], [72.3465271, 22.16458321], [72.3465271, 22.16402817], [72.34680176, 22.16403008], [72.34680176, 22.16347122], [72.34708405, 22.16347313], [72.34708405, 22.16319466], [72.34791565, 22.16319466], [72.34791565, 22.16291618], [72.34819794, 22.16292], [72.34819794, 22.16263962], [72.34902954, 22.16263962], [72.34902954, 22.16236115], [72.35069275, 22.16236115], [72.35069275, 22.16208267], [72.35152435, 22.16208267], [72.35152435, 22.16180611], [72.35206604, 22.16180992], [72.35206604, 22.16152954], [72.3529129, 22.16152954], [72.3529129, 22.16125107], [72.35375214, 22.16125107], [72.35375214, 22.16069031], [72.35402679, 22.16069412], [72.35402679, 22.15958405], [72.35430908, 22.15958405], [72.35430908, 22.15847206], [72.35458374, 22.15847206], [72.35458374, 22.15764046], [72.3548584, 22.15764046], [72.3548584, 22.15653038], [72.35514069, 22.15653038], [72.35514069, 22.15570068], [72.3554306, 22.15570068], [72.3554306, 22.15458107], [72.35569763, 22.15458298], [72.35569763, 22.1534729], [72.35597229, 22.1534729], [72.35597229, 22.15263939], [72.35624695, 22.15263939], [72.35624695, 22.15153122], [72.35652924, 22.15153122], [72.35652924, 22.15042114], [72.35679626, 22.15042114], [72.35679626, 22.15014076], [72.35652924, 22.15014076], [72.35652924, 22.1482029], [72.35624695, 22.1482029], [72.35624695, 22.14736176], [72.35597229, 22.14736176], [72.35597229, 22.14680481], [72.35569763, 22.14680481], [72.35569763, 22.14652824], [72.3529129, 22.14652824], [72.3529129, 22.14708328], [72.35263824, 22.14706993], [72.35263824, 22.14792061], [72.35151672, 22.14792061], [72.35151672, 22.14764023], [72.35124969, 22.14764023], [72.35124969, 22.14736176], [72.35069275, 22.14736176], [72.35069275, 22.14652824], [72.35041809, 22.14653015], [72.35041809, 22.14513969], [72.3501358, 22.14513969], [72.3501358, 22.14486122], [72.35041809, 22.14486122], [72.35041809, 22.14458084], [72.35069275, 22.14458275], [72.35069275, 22.14430618], [72.35097504, 22.14430618], [72.35097504, 22.14402962], [72.35124969, 22.14402962], [72.35124969, 22.14347076], [72.35152435, 22.14347267], [72.35152435, 22.14291573], [72.35180664, 22.14291954], [72.35180664, 22.14236069], [72.35206604, 22.14236069], [72.35206604, 22.14153099], [72.35235596, 22.14153099], [72.35235596, 22.13652992], [72.35206604, 22.13652992], [72.35206604, 22.13597107], [72.35180664, 22.13597107], [72.35180664, 22.1356945], [72.35152435, 22.1356945], [72.35152435, 22.13541603], [72.35098267, 22.13541985], [72.35098267, 22.1348629], [72.35069275, 22.1348629], [72.35069275, 22.13402939], [72.35041809, 22.13402939], [72.35041809, 22.13291931], [72.3501358, 22.13291931], [72.3501358, 22.13235855], [72.34986115, 22.13235855], [72.34986115, 22.13125038], [72.34958649, 22.13125038], [72.34958649, 22.12985992], [72.34986115, 22.12986183], [72.34986115, 22.12847137], [72.3501358, 22.12847137], [72.3501358, 22.12680435], [72.34986115, 22.12681007], [72.34986115, 22.12652969], [72.34874725, 22.12652969], [72.34874725, 22.12626076], [72.34764099, 22.12626076], [72.34764099, 22.12597084], [72.3465271, 22.12597275], [72.3465271, 22.12569427], [72.34513855, 22.12569427], [72.34513855, 22.1254158], [72.34375, 22.12541962], [72.34375, 22.12514114], [72.3434906, 22.12514114], [72.3434906, 22.12486076], [72.34179687, 22.12486076], [72.34179687, 22.12458038], [72.34124756, 22.12458038], [72.34124756, 22.12486076], [72.3409729, 22.12486076], [72.3409729, 22.12597275], [72.34124756, 22.12597084], [72.34124756, 22.12652969], [72.34152985, 22.12652779], [72.34152985, 22.12708282], [72.34179687, 22.12708092], [72.34179687, 22.12763977], [72.34208679, 22.12763977], [72.34208679, 22.12847137], [72.34236145, 22.12847137], [72.34236145, 22.12958336], [72.34263611, 22.12958336], [72.34263611, 22.13319397], [72.34236145, 22.13319397], [72.34236145, 22.13513947], [72.34208679, 22.13513947], [72.34208679, 22.1356945], [72.3418045, 22.1356945], [72.3418045, 22.13597107], [72.34152985, 22.13597107], [72.34152985, 22.13624954], [72.34124756, 22.13624954], [72.34124756, 22.1368103], [72.3409729, 22.13680649], [72.3409729, 22.13708305], [72.34069824, 22.13708115], [72.34069824, 22.13764], [72.34041595, 22.13764], [72.34041595, 22.13792038], [72.34012604, 22.13792038], [72.34012604, 22.13820076], [72.33985901, 22.13819313], [72.33985901, 22.1384716], [72.33957672, 22.1384697], [72.33957672, 22.13875008], [72.33875275, 22.13875008], [72.33875275, 22.13903046], [72.33651733, 22.13903046], [72.33651733, 22.13875008], [72.33486176, 22.13875008], [72.33486176, 22.13903046], [72.3345871, 22.13902855], [72.3345871, 22.13958359], [72.33430481, 22.13958359], [72.33430481, 22.14069366], [72.33403015, 22.14069366], [72.33403015, 22.14097214], [72.33291626, 22.14097023], [72.33291626, 22.14126015], [72.3326416, 22.14126015], [72.3326416, 22.14153099], [72.33235931, 22.14153099], [72.33235931, 22.14180946], [72.33152771, 22.14180756], [72.33152771, 22.14208412], [72.33069611, 22.14208031], [72.33069611, 22.14236069], [72.33040619, 22.14238167], [72.33040619, 22.14291954], [72.33022308, 22.14291573], [72.3298645, 22.14291954], [72.3298645, 22.1431942], [72.32958221, 22.1431942], [72.32958221, 22.14347267], [72.3290329, 22.14347076], [72.3290329, 22.14375114], [72.32875061, 22.14375114], [72.32875061, 22.14402962], [72.32847595, 22.14402962], [72.32847595, 22.14458275], [72.32818604, 22.14458084], [72.32818604, 22.14486122], [72.32791901, 22.14486122], [72.32791901, 22.14513969], [72.32707977, 22.14513969], [72.32707977, 22.14541817], [72.32653046, 22.14541626], [72.32653046, 22.14569473], [72.32597351, 22.14569473], [72.32597351, 22.14596939], [72.32541656, 22.14596939], [72.32541656, 22.14625168], [72.32485962, 22.14625168], [72.32485962, 22.14653015], [72.32458496, 22.14652824], [72.32458496, 22.14680481], [72.32375336, 22.14680481], [72.32375336, 22.14708328], [72.32236481, 22.14708328], [72.32236481, 22.14680481], [72.32180786, 22.14680481], [72.32180786, 22.14652824], [72.32096863, 22.14653015], [72.32096863, 22.14625168], [72.31986237, 22.14625168], [72.31986237, 22.14653015], [72.31958008, 22.14652824], [72.31958008, 22.14680481], [72.31930542, 22.14680481], [72.31930542, 22.14736176], [72.31903076, 22.14736176], [72.31903076, 22.14792061], [72.31819153, 22.14792061], [72.31819153, 22.14764023], [72.31764221, 22.14764023], [72.31764221, 22.14736176], [72.31735992, 22.14736176], [72.31735992, 22.14708328], [72.31680298, 22.14708328], [72.31680298, 22.14680481], [72.31652832, 22.14680481], [72.31652832, 22.14652824], [72.31624603, 22.14653015], [72.31624603, 22.15125084], [72.31597137, 22.15125084], [72.31597137, 22.15153122], [72.31624603, 22.15153122], [72.31624603, 22.15263939], [72.31597137, 22.15263939], [72.31597137, 22.1554203], [72.31624603, 22.1554203], [72.31624603, 22.15653038], [72.31652832, 22.15652657], [72.31652832, 22.15736198], [72.31625366, 22.15736198], [72.31625366, 22.15930557], [72.31597137, 22.15930557], [72.31597137, 22.15958405], [72.31624603, 22.15957832], [72.31624603, 22.16013908], [72.31652832, 22.16013908], [72.31652832, 22.1609726], [72.31680298, 22.1609726], [72.31680298, 22.16236115], [72.31708527, 22.16236115], [72.31708527, 22.16347313], [72.31735992, 22.16347313], [72.31735992, 22.16486168], [72.31764221, 22.16486168], [72.31764221, 22.16708374], [72.31791687, 22.16707993], [72.31791687, 22.16792107], [72.31819153, 22.16792107], [72.31819153, 22.16875076], [72.31846619, 22.16875076], [72.31846619, 22.16930962], [72.31874847, 22.16930962], [72.31874847, 22.17014122], [72.31887054, 22.17014122], [72.31903076, 22.17013741], [72.31903076, 22.17097282], [72.31932068, 22.17097092], [72.31932068, 22.17180824], [72.31958008, 22.17180824], [72.31958008, 22.17292023], [72.31932068, 22.17292023], [72.31932068, 22.1740303], [72.31909943, 22.1740303], [72.31903076, 22.17514038], [72.31874847, 22.17514038], [72.31874847, 22.17625046], [72.31846619, 22.17625046], [72.31846619, 22.17737007], [72.31819153, 22.17736053], [72.31819153, 22.17847252], [72.31791687, 22.17847252], [72.31791687, 22.1795826], [72.31764221, 22.1795826], [72.31764221, 22.18069458], [72.31735992, 22.18069077], [72.31735992, 22.18124962], [72.31708527, 22.18124962], [72.31708527, 22.18208313], [72.31680298, 22.18208122], [72.31680298, 22.18264008], [72.31652832, 22.18264008], [72.31652832, 22.18320084], [72.31624603, 22.18320084], [72.31624603, 22.18403053], [72.31597137, 22.18402863], [72.31597137, 22.18458366], [72.31569672, 22.18457985], [72.31569672, 22.18514061], [72.31513977, 22.18514061], [72.31513977, 22.18541908], [72.31485748, 22.18541718], [72.31485748, 22.18569374], [72.31430817, 22.18569374], [72.31430817, 22.18597221], [72.31375122, 22.18597221], [72.31375122, 22.18625069], [72.31346893, 22.18624115], [72.31346893, 22.18652916], [72.31291962, 22.18652916], [72.31291962, 22.18680954], [72.31263733, 22.18680573], [72.31263733, 22.1870842], [72.31208038, 22.18707848], [72.31208038, 22.18736267], [72.31124878, 22.18736267], [72.31124878, 22.18764114], [72.31069183, 22.18764114], [72.31069183, 22.18791962], [72.30986023, 22.1879158], [72.30986023, 22.18819427], [72.30930328, 22.18819427], [72.30930328, 22.18847275], [72.30874634, 22.18847275], [72.30874634, 22.18875122], [72.30819702, 22.18875122], [72.30819702, 22.18902969], [72.3079071, 22.18902969], [72.3079071, 22.18931007], [72.30735779, 22.18930626], [72.30735779, 22.18958282], [72.30708313, 22.18958282], [72.30708313, 22.1898613], [72.30680847, 22.18985939], [72.30680847, 22.19013977], [72.30652618, 22.19013977], [72.30652618, 22.19042015], [72.30625153, 22.19041634], [72.30625153, 22.19069481], [72.30596924, 22.19069481], [72.30596924, 22.19097137], [72.30568695, 22.19096947], [72.30568695, 22.19124985], [72.30513763, 22.19124985], [72.30513763, 22.19153023], [72.30486298, 22.19152832], [72.30486298, 22.19180489], [72.30458069, 22.19180489], [72.30458069, 22.19208336], [72.30430603, 22.19207954], [72.30430603, 22.19236946], [72.30403137, 22.19236946], [72.30403137, 22.1926403], [72.30374908, 22.1926403], [72.30374908, 22.19292068], [72.3034668, 22.19292068], [72.3034668, 22.19320107], [72.30208588, 22.19320107], [72.30208588, 22.19292068], [72.30095673, 22.19292068], [72.30095673, 22.1926403], [72.29985809, 22.1926403], [72.29985809, 22.19292068], [72.29957581, 22.19292068], [72.29957581, 22.19320107], [72.29985809, 22.19320107], [72.29985809, 22.19375038], [72.30014038, 22.19375038], [72.30014038, 22.19458389], [72.29985809, 22.19458389], [72.29985809, 22.1954155], [72.29958344, 22.1954155], [72.29958344, 22.19597244], [72.29930878, 22.19597054], [72.29930878, 22.19680977], [72.29902649, 22.19680977], [72.29902649, 22.19763947], [72.29875183, 22.19763947], [72.29875183, 22.19847298], [72.29846954, 22.19846916], [72.29846954, 22.1993103], [72.29819489, 22.19930649], [72.29819489, 22.19986153], [72.29792023, 22.19986153], [72.29792023, 22.20070267], [72.29763794, 22.20070267], [72.29763794, 22.20125008], [72.29708099, 22.20125008], [72.29708099, 22.20153999], [72.29651642, 22.20153999], [72.29651642, 22.20181274], [72.29624939, 22.20180511], [72.29624939, 22.20208359], [72.29569244, 22.20208359], [72.29569244, 22.20236206], [72.29430389, 22.20236206], [72.29430389, 22.20152855], [72.29458618, 22.20153999], [72.29458618, 22.20125008], [72.29486084, 22.20125008], [72.29486084, 22.20070267], [72.29515076, 22.20070267], [72.29515076, 22.20042038], [72.29541779, 22.20042038], [72.29541779, 22.20014191], [72.29569244, 22.20014191], [72.29569244, 22.19986153], [72.29597473, 22.19986153], [72.29597473, 22.19958305], [72.29624939, 22.19958305], [72.29624939, 22.19930649], [72.29651642, 22.19930077], [72.29652405, 22.19902992], [72.29680634, 22.19903183], [72.29680634, 22.19874763], [72.29708099, 22.19874763], [72.29708099, 22.19292068], [72.29680634, 22.19292068], [72.29680634, 22.19124985], [72.29708099, 22.19124985], [72.29708099, 22.1906929], [72.29736328, 22.19069481], [72.29736328, 22.19013977], [72.29763794, 22.19013977], [72.29763794, 22.18958282], [72.29792023, 22.18958282], [72.29792023, 22.18930626], [72.29818726, 22.18931007], [72.29818726, 22.18875122], [72.29846954, 22.18875122], [72.29846954, 22.18819046], [72.29875183, 22.18819427], [72.29875183, 22.18763924], [72.29902649, 22.18764114], [72.29902649, 22.18736267], [72.29930878, 22.18736267], [72.29930878, 22.18707848], [72.29958344, 22.1870842], [72.29958344, 22.18680573], [72.29985809, 22.18680954], [72.29985809, 22.18652916], [72.30014038, 22.18652916], [72.30014038, 22.1859684], [72.30041504, 22.18597221], [72.30041504, 22.18569374], [72.30069733, 22.18569374], [72.30069733, 22.18541718], [72.30095673, 22.18541908], [72.30095673, 22.18514061], [72.30124664, 22.18514061], [72.30124664, 22.18485832], [72.30152893, 22.18485832], [72.30152893, 22.18457985], [72.30180359, 22.18458366], [72.30180359, 22.18430519], [72.30208588, 22.18431091], [72.30208588, 22.18374825], [72.30236053, 22.18374825], [72.30236053, 22.18346977], [72.30263519, 22.18347168], [72.30263519, 22.18319511], [72.30291748, 22.18320084], [72.30291748, 22.18292046], [72.30430603, 22.18292046], [72.30430603, 22.18320084], [72.30486298, 22.18319511], [72.30486298, 22.18347168], [72.30568695, 22.18346977], [72.30568695, 22.18374825], [72.30652618, 22.18374825], [72.30652618, 22.18403053], [72.30709076, 22.18403053], [72.30709076, 22.18431091], [72.30819702, 22.18431091], [72.30819702, 22.18403053], [72.30847168, 22.18403053], [72.30847168, 22.18374825], [72.30902863, 22.18374825], [72.30902863, 22.18346977], [72.30930328, 22.18347168], [72.30930328, 22.18319511], [72.30986023, 22.18320084], [72.30986023, 22.18292046], [72.31041718, 22.18292046], [72.31041718, 22.18264008], [72.31069183, 22.18264008], [72.31069183, 22.1823597], [72.31124878, 22.1823616], [72.31124878, 22.18208313], [72.31153107, 22.18208313], [72.31153107, 22.18180466], [72.31180573, 22.18180466], [72.31180573, 22.18124962], [72.31208038, 22.18124962], [72.31208038, 22.18097115], [72.31236267, 22.18097305], [72.31236267, 22.18069458], [72.31263733, 22.18069458], [72.31263733, 22.1795826], [72.31291962, 22.1795826], [72.31291962, 22.17791748], [72.31318665, 22.17791939], [72.31318665, 22.17625046], [72.31346893, 22.17625046], [72.31346893, 22.17152977], [72.31318665, 22.17152977], [72.31318665, 22.17123985], [72.31291962, 22.17124748], [72.31291962, 22.17097282], [72.31263733, 22.17097282], [72.31263733, 22.17069435], [72.31208038, 22.17069435], [72.31208038, 22.17041779], [72.31181335, 22.17041969], [72.31181335, 22.17014122], [72.31153107, 22.17014122], [72.31153107, 22.16958046], [72.31180573, 22.16958237], [72.31180573, 22.16875076], [72.31208038, 22.16875076], [72.31208038, 22.16792107], [72.31236267, 22.16792107], [72.31236267, 22.16707993], [72.31208038, 22.16708374], [72.31208038, 22.16625023], [72.31180573, 22.16625023], [72.31180573, 22.16569328], [72.31153107, 22.16570091], [72.31153107, 22.16485977], [72.31124878, 22.16486168], [72.31124878, 22.16402817], [72.31096649, 22.16403008], [72.31096649, 22.16347122], [72.31069183, 22.16347313], [72.31069183, 22.16124916], [72.31041718, 22.16125107], [72.31041718, 22.15735817], [72.31014252, 22.15736198], [72.31014252, 22.15624809], [72.30986023, 22.15624809], [72.30986023, 22.15180588], [72.3095932, 22.15180969], [72.3095932, 22.14875031], [72.30986023, 22.14875031], [72.30986023, 22.1482029], [72.31015015, 22.1482029], [72.31015015, 22.14625168], [72.31041718, 22.14625168], [72.31041718, 22.14458084], [72.31069183, 22.14458275], [72.31069183, 22.14430618], [72.31097412, 22.14430618], [72.31097412, 22.14347267], [72.31124878, 22.14347267], [72.31124878, 22.1431942], [72.31153107, 22.1431942], [72.31153107, 22.14208412], [72.31180573, 22.14208412], [72.31180573, 22.14152527], [72.31208038, 22.14153099], [72.31208038, 22.14068985], [72.31236267, 22.14069366], [72.31236267, 22.13986206], [72.31263733, 22.13986015], [72.31263733, 22.13957977], [72.31291962, 22.13958359], [72.31291962, 22.13902855], [72.31318665, 22.13903046], [72.31318665, 22.1384697], [72.31346893, 22.1384716], [72.31346893, 22.13708305], [72.31402588, 22.13708305], [72.31402588, 22.13736153], [72.31430817, 22.13736153], [72.31430817, 22.13708305], [72.31458282, 22.13708305], [72.31458282, 22.13652802], [72.31485748, 22.13652992], [72.31485748, 22.13624954], [72.31513977, 22.13624954], [72.31513977, 22.13597107], [72.31541443, 22.13597107], [72.31541443, 22.1356945], [72.31569672, 22.1356945], [72.31569672, 22.13541603], [72.31597137, 22.13541985], [72.31597137, 22.13513184], [72.31652832, 22.13513947], [72.31652832, 22.1348629], [72.31680298, 22.1348629], [72.31680298, 22.13458252], [72.31735992, 22.13458252], [72.31735992, 22.13430595], [72.31846619, 22.13430977], [72.31846619, 22.13402939], [72.31958008, 22.13402939], [72.31958008, 22.13375282], [72.32041931, 22.13375282], [72.32041931, 22.13346863], [72.32069397, 22.13347244], [72.32069397, 22.13319397], [72.32125092, 22.13319397], [72.32125092, 22.1329174], [72.32180786, 22.13291931], [72.32180786, 22.13264084], [72.32235718, 22.13264084], [72.32235718, 22.13235855], [72.32263947, 22.13235855], [72.32263947, 22.13207054], [72.32291412, 22.13208389], [72.32291412, 22.13180542], [72.32319641, 22.13180923], [72.32319641, 22.13153076], [72.32347107, 22.13153076], [72.32347107, 22.13096809], [72.32375336, 22.13097191], [72.32375336, 22.13013649], [72.32347107, 22.1301403], [72.32347107, 22.12985992], [72.32291412, 22.12986183], [72.32291412, 22.12958336], [72.32263947, 22.12958336], [72.32263947, 22.12930489], [72.32208252, 22.12930489], [72.32208252, 22.12902641], [72.32180786, 22.12902641], [72.32180786, 22.12930489], [72.32096863, 22.12930489], [72.32096863, 22.12902641], [72.32041931, 22.12903023], [72.32041931, 22.12874985], [72.32013702, 22.12874985], [72.32013702, 22.12792015], [72.32041931, 22.12792015], [72.32041931, 22.12763977], [72.3215332, 22.12763977], [72.32152557, 22.1273613], [72.32180786, 22.1273613], [72.32180786, 22.12708282], [72.32152557, 22.12708282], [72.32152557, 22.12624931], [72.32125092, 22.12626076], [72.32125092, 22.12597084], [72.32069397, 22.12597275], [72.32069397, 22.1254158], [72.32096863, 22.12541962], [72.32096863, 22.12514114], [72.32125092, 22.12514114], [72.32125092, 22.12430954], [72.3215332, 22.12430954], [72.3215332, 22.12347031], [72.32208252, 22.12347221], [72.32208252, 22.12319374], [72.32263947, 22.12319374], [72.32263947, 22.12291718], [72.32319641, 22.1229229], [72.32319641, 22.12264061], [72.32290649, 22.12264061], [72.32290649, 22.12236023], [72.32263947, 22.12236023], [72.32263947, 22.12208176], [72.32236481, 22.12208366], [72.32236481, 22.12152863], [72.32209015, 22.12153053], [72.32209015, 22.12125015], [72.32180786, 22.12125015], [72.32180786, 22.12097168], [72.32152557, 22.12097168], [72.32152557, 22.12069511], [72.32125092, 22.12070274], [72.32125092, 22.12042046], [72.32096863, 22.12042046], [72.32096863, 22.1198616], [72.32069397, 22.1198616], [72.32069397, 22.11958313], [72.32041931, 22.11958313], [72.32041931, 22.11930466], [72.32013702, 22.11930466], [72.32013702, 22.11902809], [72.31986237, 22.11903191], [72.31986237, 22.11874962], [72.31958008, 22.11874962], [72.31958008, 22.11819077], [72.31930542, 22.11819458], [72.31930542, 22.11791611], [72.31903076, 22.11791992], [72.31903076, 22.11763954], [72.31874847, 22.11763954], [72.31874847, 22.11708832], [72.31846619, 22.11708832], [72.31846619, 22.11680984], [72.31819153, 22.11680984], [72.31819153, 22.11652946], [72.31791687, 22.11652946], [72.31791687, 22.11597061], [72.31764221, 22.11597252], [72.31764221, 22.11569405], [72.31485748, 22.11569405], [72.31485748, 22.11597252], [72.31430817, 22.11597252], [72.31430817, 22.1151371], [72.31402588, 22.11514091], [72.31402588, 22.11458015], [72.31375122, 22.11458588], [72.31375122, 22.1143055], [72.31346893, 22.11432076], [72.31346893, 22.11403084], [72.31318665, 22.11403084], [72.31318665, 22.11375046], [72.31291962, 22.11375046], [72.31291962, 22.11347008], [72.31263733, 22.11347198], [72.31263733, 22.11319733], [72.31236267, 22.1131897], [72.31236267, 22.11263847], [72.31208038, 22.11264038], [72.31208038, 22.11236], [72.31180573, 22.11236191], [72.31180573, 22.11208344], [72.31153107, 22.11208344], [72.31153107, 22.1115284], [72.31124878, 22.1115303], [72.31124878, 22.11042023], [72.31153107, 22.11042023], [72.31153107, 22.1095829], [72.31124878, 22.1095829], [72.31124878, 22.10847282], [72.31153107, 22.10847282], [72.31153107, 22.10708427], [72.31180573, 22.10708237], [72.31180573, 22.10514069], [72.31208038, 22.10515022], [72.31208038, 22.1048584], [72.31236267, 22.1048584], [72.31236267, 22.10457993], [72.31263733, 22.10458374], [72.31263733, 22.1040287], [72.31291962, 22.10403061], [72.31291962, 22.10375023], [72.31346893, 22.10375023], [72.31346893, 22.10346985], [72.31375122, 22.10347176], [72.31375122, 22.10291862], [72.31402588, 22.10292053], [72.31402588, 22.10264015], [72.31485748, 22.10264015], [72.31485748, 22.10235977], [72.31513977, 22.10236168], [72.31513977, 22.10069466], [72.31541443, 22.10069466], [72.31541443, 22.09958267], [72.31513977, 22.09958267], [72.31513977, 22.09902763], [72.31485748, 22.09902763], [72.31485748, 22.0984726], [72.31458282, 22.0984726], [72.31458282, 22.09819412], [72.31430817, 22.09819412], [72.31430817, 22.09791756], [72.31402588, 22.09791946], [72.31402588, 22.09764099], [72.31375122, 22.09764099], [72.31375122, 22.09736061], [72.31346893, 22.09736061], [72.31346893, 22.09680939], [72.31318665, 22.09680939], [72.31318665, 22.09653091], [72.31291962, 22.09653091], [72.31291962, 22.09596252], [72.31319427, 22.09597206], [72.31319427, 22.09513855], [72.31291962, 22.09514046], [72.31291962, 22.0945816], [72.31263733, 22.09458351], [72.31263733, 22.09430504], [72.31236267, 22.09431267], [72.31236267, 22.09403038], [72.31208038, 22.09403038], [72.31208038, 22.09321022], [72.31181335, 22.09321022], [72.31181335, 22.09207916], [72.31153107, 22.09208298], [72.31153107, 22.0909729], [72.31124878, 22.0909729], [72.31124878, 22.09069443], [72.31097412, 22.09069443], [72.31097412, 22.08930779], [72.31069183, 22.08930969], [72.31069183, 22.08875084], [72.31041718, 22.08875084], [72.31041718, 22.08764076], [72.31015015, 22.08764076], [72.31015015, 22.08708], [72.30958557, 22.08708382], [72.30958557, 22.08680534], [72.30930328, 22.08681107], [72.30930328, 22.08542061], [72.30902863, 22.08542061], [72.30902863, 22.08374977], [72.30874634, 22.08374977], [72.30874634, 22.08263969], [72.30847168, 22.08263969], [72.30847168, 22.0809803], [72.30819702, 22.0809803], [72.30819702, 22.08041954], [72.3079071, 22.08041954], [72.3079071, 22.07930946], [72.30764008, 22.07930946], [72.30764008, 22.07846832], [72.30735779, 22.07847214], [72.30735779, 22.0779171], [72.30709076, 22.07792091], [72.30709076, 22.07764053], [72.30680847, 22.07764053], [72.30680847, 22.07735825], [72.30652618, 22.07736206], [72.30652618, 22.07680511], [72.30680847, 22.07681084], [72.30680847, 22.07180977], [72.30652618, 22.07180977], [72.30652618, 22.07042122], [72.30625153, 22.07042122], [72.30625153, 22.06847191], [72.30596924, 22.06847382], [72.30596924, 22.0676384], [72.30568695, 22.0676403], [72.30568695, 22.06513977], [72.30541992, 22.06513977], [72.30541992, 22.06485748], [72.30513763, 22.0648613], [72.30513763, 22.06430626], [72.30486298, 22.06430817], [72.30486298, 22.06375122], [72.30458069, 22.06375122], [72.30458069, 22.06208038], [72.30430603, 22.0620842], [72.30430603, 22.06152534], [72.30403137, 22.06153107], [72.30403137, 22.05931091], [72.30374908, 22.05931091], [72.30374908, 22.05875015], [72.3034668, 22.05875015], [72.3034668, 22.05764008], [72.30319214, 22.05764008], [72.30319214, 22.05653], [72.3034668, 22.05653], [72.3034668, 22.05624962], [72.30319214, 22.05624962], [72.30319214, 22.05569267], [72.30291748, 22.05569458], [72.30291748, 22.0545826], [72.30263519, 22.0545826], [72.30263519, 22.05374908], [72.30236053, 22.0537529], [72.30236053, 22.0534687], [72.30208588, 22.05347252], [72.30208588, 22.05208397], [72.30180359, 22.05208397], [72.30180359, 22.05125046], [72.30152893, 22.05125046], [72.30152893, 22.05042076], [72.30124664, 22.05042076], [72.30124664, 22.04931068], [72.30095673, 22.04931068], [72.30095673, 22.0490303], [72.30069733, 22.0490303], [72.30069733, 22.04819107], [72.30041504, 22.04819679], [72.30041504, 22.04791832], [72.30014038, 22.04791832], [72.30014038, 22.04763985], [72.29985809, 22.04763985], [72.29985809, 22.04597092], [72.29958344, 22.04597282], [72.29958344, 22.04458237], [72.29930878, 22.04458237], [72.29930878, 22.04402733], [72.29902649, 22.04403114], [72.29902649, 22.04319191], [72.29875183, 22.04319382], [72.29875183, 22.04263878], [72.29902649, 22.04264069], [72.29902649, 22.04208183], [72.29875183, 22.04208374], [72.29875183, 22.04125023], [72.29846954, 22.04125023], [72.29846954, 22.04070282], [72.29875183, 22.04070282], [72.29875183, 22.03986168], [72.29846954, 22.03986168], [72.29846954, 22.03958321], [72.29819489, 22.03958321], [72.29819489, 22.03902817], [72.29792023, 22.03903008], [72.29792023, 22.03791809], [72.29818726, 22.03791809], [72.29818726, 22.03763962], [72.29792023, 22.03763962], [72.29792023, 22.03680992], [72.29763794, 22.03680992], [72.29763794, 22.03597069], [72.29736328, 22.0359726], [72.29736328, 22.03569412], [72.29708099, 22.03569412], [72.29708099, 22.03541565], [72.29680634, 22.03541946], [72.29680634, 22.03375053], [72.29708099, 22.03375053], [72.29708099, 22.03347015], [72.29680634, 22.03347206], [72.29680634, 22.03263855], [72.29651642, 22.03264046], [72.29651642, 22.0320797], [72.29624939, 22.03208351], [72.29624939, 22.03097153], [72.29597473, 22.03097153], [72.29597473, 22.02930641], [72.29569244, 22.02931023], [72.29569244, 22.02736282], [72.29541779, 22.02736282], [72.29541779, 22.02596855], [72.2951355, 22.02597237], [72.2951355, 22.02514076], [72.29486084, 22.02514076], [72.29486084, 22.02430916], [72.29458618, 22.02430916], [72.29458618, 22.02264023], [72.29429626, 22.02264023], [72.29429626, 22.02153015], [72.29402924, 22.02153015], [72.29402924, 22.02067947], [72.29374695, 22.02069664], [72.29374695, 22.02013969], [72.29347229, 22.02013969], [72.29347229, 22.01847076], [72.29319763, 22.01847267], [72.29319763, 22.01736069], [72.29291534, 22.01736069], [72.29291534, 22.01625061], [72.29264069, 22.01625061], [72.29264069, 22.01542282], [72.2923584, 22.01542282], [72.2923584, 22.0134716], [72.29208374, 22.0134716], [72.29208374, 22.01319504], [72.29180908, 22.01320267], [72.29180908, 22.01264191], [72.29152679, 22.01264191], [72.29152679, 22.01180077], [72.29125214, 22.01180649], [72.29125214, 22.01041794], [72.29096985, 22.01041985], [72.29096985, 22.01013947], [72.29069519, 22.01013947], [72.29069519, 22.00930786], [72.2904129, 22.00930977], [72.2904129, 22.00792122], [72.29013824, 22.00792122], [72.29013824, 22.00708008], [72.28986359, 22.0070858], [72.28986359, 22.00597191], [72.2895813, 22.00597191], [72.2895813, 22.00569344], [72.28930664, 22.00570107], [72.28930664, 22.00485992], [72.28902435, 22.00486183], [72.28902435, 22.00402832], [72.28874969, 22.00403023], [72.28874969, 22.00292969], [72.28848267, 22.00292969], [72.28848267, 22.00263977], [72.28819275, 22.00263977], [72.28819275, 22.00235939], [72.28791809, 22.0023613], [72.28791809, 22.00180626], [72.2876358, 22.00181007], [72.2876358, 22.00014114], [72.2876358, 21.99957085], [72.28708649, 21.9995842], [72.28708649, 21.99791718], [72.28679657, 21.99791908], [72.28679657, 21.99653053], [72.28652954, 21.99653053], [72.28652954, 21.99514008], [72.28624725, 21.99514008], [72.28624725, 21.99014091], [72.28595734, 21.99014091], [72.28595734, 21.98847008], [72.28569794, 21.98847389], [72.28569794, 21.98680496], [72.28542328, 21.98681259], [72.28542328, 21.98542023], [72.28514099, 21.98542023], [72.28514099, 21.98402977], [72.2848587, 21.98402977], [72.2848587, 21.98208046], [72.28458405, 21.98208427], [72.28458405, 21.98097229], [72.28430176, 21.98097229], [72.28430176, 21.97986031], [72.2840271, 21.97986031], [72.2840271, 21.97903061], [72.28375244, 21.97903061], [72.28375244, 21.97820091], [72.28347015, 21.97820091], [72.28347015, 21.97707939], [72.2831955, 21.97708321], [72.2831955, 21.97624969], [72.28291321, 21.97624969], [72.28291321, 21.97569466], [72.28263855, 21.97569466], [72.28263855, 21.97486115], [72.28235626, 21.97486115], [72.28235626, 21.9731884], [72.2820816, 21.97319412], [72.2820816, 21.97291756], [72.28180695, 21.97291946], [72.28180695, 21.97236061], [72.28151703, 21.97236061], [72.28151703, 21.97180939], [72.28125, 21.97180939], [72.28125, 21.97125053], [72.28097534, 21.97125053], [72.28097534, 21.97041893], [72.28069305, 21.97042084], [72.28069305, 21.96931076], [72.2804184, 21.96931076], [72.2804184, 21.96846962], [72.28013611, 21.96847153], [72.28013611, 21.96736145], [72.27986145, 21.96736145], [72.27986145, 21.96430588], [72.2793045, 21.96430588], [72.2793045, 21.96458244], [72.27874756, 21.96458054], [72.27874756, 21.96486092], [72.27791595, 21.96486092], [72.27791595, 21.96513939], [72.2767868, 21.96513939], [72.2767868, 21.96541977], [72.27597046, 21.96541405], [72.27597046, 21.96569443], [72.2748642, 21.96569443], [72.2748642, 21.9659729], [72.27401733, 21.96597099], [72.27402496, 21.96624947], [72.27348328, 21.96624947], [72.27348328, 21.96652985], [72.2729187, 21.96652985], [72.2729187, 21.96681976], [72.27236176, 21.9668045], [72.27236176, 21.96708298], [72.27180481, 21.96708298], [72.27180481, 21.96736145], [72.27124786, 21.96735954], [72.27124786, 21.96763992], [72.27098083, 21.96763992], [72.27098083, 21.96541977], [72.27124786, 21.96541977], [72.27124786, 21.96513939], [72.27179718, 21.96513939], [72.27179718, 21.96486092], [72.2720871, 21.96486092], [72.2720871, 21.96458054], [72.27236176, 21.96458244], [72.27236176, 21.96430588], [72.27263641, 21.96430969], [72.27263641, 21.96375084], [72.2729187, 21.96375084], [72.2729187, 21.96319008], [72.27319336, 21.96319389], [72.27319336, 21.96236038], [72.27348328, 21.96236038], [72.27347565, 21.96125031], [72.27375031, 21.96125031], [72.27375031, 21.96097183], [72.27402496, 21.96097183], [72.27402496, 21.96069527], [72.27430725, 21.96069527], [72.27430725, 21.96013832], [72.27458191, 21.96014023], [72.27458191, 21.95986176], [72.2748642, 21.95986176], [72.2748642, 21.95958328], [72.27541351, 21.95958328], [72.27541351, 21.95930481], [72.2756958, 21.95930481], [72.2756958, 21.95902824], [72.27625275, 21.95903015], [72.27625275, 21.95875168], [72.2765274, 21.95875168], [72.2765274, 21.95846748], [72.27708435, 21.9584713], [72.27708435, 21.95819473], [72.27735901, 21.95819473], [72.27735901, 21.95791626], [72.2776413, 21.95791817], [72.2776413, 21.95764923], [72.27791595, 21.95764923], [72.27791595, 21.95708084], [72.27819061, 21.95708275], [72.27819824, 21.95680618], [72.2784729, 21.95680809], [72.2784729, 21.95597076], [72.27874756, 21.95597267], [72.27874756, 21.95486069], [72.27902985, 21.95486069], [72.27902985, 21.94708252], [72.27874756, 21.94708252], [72.27874756, 21.94569397], [72.2784729, 21.94569397], [72.2784729, 21.94458389], [72.27819824, 21.94458389], [72.27819061, 21.94375038], [72.27791595, 21.94375038], [72.27791595, 21.94124985], [72.27819061, 21.94124985], [72.27819061, 21.93959045], [72.27791595, 21.93959045], [72.27791595, 21.93931007], [72.2776413, 21.93931007], [72.2776413, 21.93875122], [72.27735901, 21.93875122], [72.27735901, 21.93847084], [72.27708435, 21.93847275], [72.27708435, 21.93625069], [72.27735901, 21.93625069], [72.27735901, 21.93569183], [72.2776413, 21.93569374], [72.2776413, 21.93458366], [72.27791595, 21.93458366], [72.27791595, 21.93375015], [72.27819061, 21.93375015], [72.27819824, 21.93292046], [72.2784729, 21.93292046], [72.2784729, 21.93207932], [72.27819824, 21.93208313], [72.27819061, 21.93180466], [72.2776413, 21.93180466], [72.2776413, 21.93152809], [72.27735901, 21.93152809], [72.27735901, 21.93124962], [72.27707672, 21.93124962], [72.27707672, 21.93097115], [72.2765274, 21.93097305], [72.2765274, 21.93069458], [72.27625275, 21.93069458], [72.27625275, 21.93013954], [72.27597046, 21.93013954], [72.27597046, 21.92986107], [72.27513885, 21.92986107], [72.27513885, 21.93013954], [72.27485657, 21.93013954], [72.27485657, 21.93041992], [72.27458191, 21.93041611], [72.27458191, 21.93069458], [72.27430725, 21.93069458], [72.27430725, 21.93097305], [72.27401733, 21.93097115], [72.27401733, 21.93124962], [72.27375031, 21.93124962], [72.27375031, 21.93152809], [72.27347565, 21.93152809], [72.27347565, 21.93180466], [72.27319336, 21.93180466], [72.27319336, 21.93208313], [72.27263641, 21.93208313], [72.27263641, 21.9323616], [72.2720871, 21.9323616], [72.2720871, 21.93264008], [72.27179718, 21.93264008], [72.27179718, 21.93292046], [72.27153015, 21.93291664], [72.27153015, 21.93347168], [72.27124786, 21.93345833], [72.27124786, 21.93375015], [72.27098083, 21.93375015], [72.27098083, 21.93403053], [72.27041626, 21.93403053], [72.27041626, 21.93431282], [72.26985931, 21.93430519], [72.26985931, 21.93458366], [72.26930237, 21.93458176], [72.26930237, 21.93486023], [72.26902771, 21.93486023], [72.26902771, 21.93514061], [72.26875305, 21.93514061], [72.26875305, 21.9354229], [72.26847076, 21.93541718], [72.26847076, 21.93569374], [72.26819611, 21.93569183], [72.26819611, 21.93625069], [72.26791382, 21.93625069], [72.26791382, 21.93652725], [72.26763916, 21.93651962], [72.26763916, 21.93680954], [72.2673645, 21.93680573], [72.2673645, 21.93708229], [72.26708221, 21.93708038], [72.26708221, 21.93736076], [72.26680756, 21.93736076], [72.26680756, 21.93791962], [72.26652527, 21.9379158], [72.26652527, 21.93847275], [72.26625061, 21.93847084], [72.26625061, 21.93902969], [72.26597595, 21.93902779], [72.26597595, 21.94069672], [72.26569366, 21.94069672], [72.26569366, 21.94097137], [72.26541901, 21.94096947], [72.26541901, 21.94124985], [72.26513672, 21.94124985], [72.26513672, 21.94208336], [72.2648468, 21.94207954], [72.2648468, 21.94264984], [72.26457977, 21.94263649], [72.26457977, 21.94347191], [72.26431274, 21.94346809], [72.26431274, 21.94430923], [72.26403046, 21.94430923], [72.26403046, 21.94541931], [72.26374817, 21.9454174], [72.26374817, 21.94597244], [72.26346588, 21.94597054], [72.26346588, 21.94652939], [72.26319122, 21.94652939], [72.26319122, 21.95264053], [72.26291656, 21.95263863], [72.26291656, 21.95319366], [72.26264191, 21.95318985], [72.26264191, 21.95375061], [72.26235962, 21.95375061], [72.26235962, 21.95430946], [72.26207733, 21.95430946], [72.26207733, 21.95486069], [72.26180267, 21.95486069], [72.26180267, 21.9556942], [72.26152802, 21.95569038], [72.26152802, 21.95625114], [72.26125336, 21.95624733], [72.26125336, 21.95708275], [72.26097107, 21.95708275], [72.26097107, 21.9584713], [72.26069641, 21.9584713], [72.26069641, 21.95958328], [72.26040649, 21.95958138], [72.26040649, 21.96820068], [72.26069641, 21.96820068], [72.26069641, 21.97153091], [72.26041412, 21.9715271], [72.26041412, 21.97263908], [72.26013947, 21.97262955], [72.26013947, 21.97431183], [72.26040649, 21.97431183], [72.26040649, 21.97513962], [72.26069641, 21.97513962], [72.26069641, 21.97624969], [72.26097107, 21.97624969], [72.26097107, 21.97764015], [72.26125336, 21.97764015], [72.26125336, 21.97875977], [72.26152802, 21.97875023], [72.26152802, 21.98097229], [72.26125336, 21.98097038], [72.26125336, 21.98153114], [72.26097107, 21.98152542], [72.26097107, 21.98208427], [72.25985718, 21.98208046], [72.25986481, 21.98236084], [72.25556183, 21.98236084], [72.25514221, 21.98236084], [72.25514221, 21.98264122], [72.25485992, 21.98264122], [72.25485992, 21.98291969], [72.25458527, 21.98291779], [72.25458527, 21.98347282], [72.25430298, 21.98347092], [72.25430298, 21.98374748], [72.25402832, 21.98374748], [72.25402832, 21.98402977], [72.25374603, 21.98402977], [72.25374603, 21.98430824], [72.25347137, 21.98430634], [72.25347137, 21.98486137], [72.25319672, 21.98485756], [72.25319672, 21.98513985], [72.2529068, 21.98513985], [72.2529068, 21.98542023], [72.25263977, 21.98541641], [72.25263977, 21.98597145], [72.25235748, 21.98597145], [72.25235748, 21.9865303], [72.25208282, 21.9865284], [72.25208282, 21.98736191], [72.25180817, 21.98736191], [72.25180817, 21.98958206], [72.25208282, 21.98958015], [72.25208282, 21.99152946], [72.25180817, 21.99152946], [72.25180817, 21.99291992], [72.25208282, 21.9929142], [72.25208282, 21.99430466], [72.25235748, 21.99430466], [72.25235748, 21.9948616], [72.25263977, 21.9948597], [72.25263977, 21.99542046], [72.25291443, 21.99541855], [72.25291443, 21.99597168], [72.25319672, 21.99597168], [72.25319672, 21.99847221], [72.25291443, 21.99847221], [72.25291443, 21.99913025], [72.25291443, 21.9995842], [72.25347137, 21.99957085], [72.25347137, 21.99986076], [72.25347137, 22.00014114], [72.25319672, 22.00014114], [72.25319672, 22.00125122], [72.25347137, 22.00124931], [72.25347137, 22.00208282], [72.25374603, 22.00208282], [72.25374603, 22.00292969], [72.25402832, 22.00292969], [72.25402832, 22.00374985], [72.25430298, 22.00374985], [72.25430298, 22.00458336], [72.2545929, 22.00457954], [72.2545929, 22.00542068], [72.25485992, 22.00542068], [72.25485992, 22.00625038], [72.25514221, 22.00625038], [72.25514221, 22.0070858], [72.25541687, 22.00708008], [72.25541687, 22.00764084], [72.25569153, 22.00763893], [72.25569153, 22.00819397], [72.25597382, 22.00819397], [72.25597382, 22.00875092], [72.25624847, 22.00873947], [72.25624847, 22.00902939], [72.25653076, 22.00902557], [72.25653076, 22.00958252], [72.25680542, 22.00958252], [72.25680542, 22.00986099], [72.25708008, 22.00986099], [72.25708008, 22.01041985], [72.25736237, 22.01041794], [72.25736237, 22.01097298], [72.25763702, 22.01096916], [72.25763702, 22.01124954], [72.25791931, 22.01124954], [72.25791931, 22.01152992], [72.25819397, 22.01152992], [72.25819397, 22.01180458], [72.25846863, 22.01180649], [72.25846863, 22.01208305], [72.25875092, 22.01208305], [72.25875092, 22.01236153], [72.25904083, 22.01236153], [72.25904083, 22.01264191], [72.25930786, 22.01264191], [72.25930786, 22.01292038], [72.25958252, 22.01292038], [72.25958252, 22.01320267], [72.25985718, 22.01320267], [72.25985718, 22.01375008], [72.26013947, 22.01375008], [72.26013947, 22.01458359], [72.26040649, 22.01458168], [72.26040649, 22.01514053], [72.26069641, 22.01513863], [72.26069641, 22.01597214], [72.26097107, 22.01597023], [72.26097107, 22.01764107], [72.26069641, 22.01764107], [72.26069641, 22.01931], [72.26040649, 22.01931], [72.26040649, 22.01986122], [72.26013947, 22.01986122], [72.26013947, 22.02013969], [72.25986481, 22.02013969], [72.25986481, 22.02069664], [72.25958252, 22.02069664], [72.25958252, 22.02100182], [72.25958252, 22.02124977], [72.25930786, 22.02124977], [72.25930786, 22.02153015], [72.25902557, 22.02152634], [72.25902557, 22.02208328], [72.25875092, 22.02207947], [72.25875092, 22.02264023], [72.25846863, 22.02264023], [72.25846863, 22.02292061], [72.25819397, 22.0229187], [72.25819397, 22.02347183], [72.25791931, 22.02346992], [72.25791931, 22.02403069], [72.25763702, 22.02402878], [72.25763702, 22.02458382], [72.25736237, 22.02457809], [72.25736237, 22.02541924], [72.25708008, 22.02541733], [72.25708008, 22.02597237], [72.25653076, 22.02596855], [72.25653076, 22.02625084], [72.25598145, 22.02625084], [72.25598145, 22.02680969], [72.25569153, 22.02680588], [72.25569153, 22.02708244], [72.25541687, 22.02708244], [72.25541687, 22.02736282], [72.25514221, 22.02736282], [72.25514221, 22.02791977], [72.25430298, 22.02791595], [72.25430298, 22.02819443], [72.25402832, 22.02819443], [72.25402832, 22.0284729], [72.25347137, 22.0284729], [72.25347137, 22.02874947], [72.25319672, 22.02874947], [72.25319672, 22.02902985], [72.2529068, 22.02902985], [72.2529068, 22.02931023], [72.24986267, 22.02930641], [72.24986267, 22.02958107], [72.24846649, 22.02958107], [72.24846649, 22.02987099], [72.24819183, 22.02987099], [72.24819183, 22.03013992], [72.24791718, 22.03013992], [72.24791718, 22.0304203], [72.24764252, 22.0304203], [72.24764252, 22.03070068], [72.24736023, 22.03069305], [72.24736023, 22.03097153], [72.24708557, 22.03097153], [72.24708557, 22.03125], [72.24681091, 22.03125], [72.24681091, 22.03153038], [72.24652863, 22.03153038], [72.24652863, 22.03181076], [72.24624634, 22.03180313], [72.24624634, 22.03208351], [72.24597168, 22.03208351], [72.24597168, 22.03236198], [72.24569702, 22.03236008], [72.24569702, 22.03264046], [72.24541473, 22.03263855], [72.24541473, 22.03291512], [72.24514008, 22.03291512], [72.24514008, 22.03347206], [72.24485779, 22.03347015], [72.24485779, 22.03430939], [72.24458313, 22.03430939], [72.24458313, 22.03514099], [72.24430847, 22.03514099], [72.24430847, 22.03763962], [72.24402618, 22.03763962], [72.24402618, 22.03958321], [72.24375153, 22.03957939], [72.24375153, 22.04070282], [72.24318695, 22.04070282], [72.24318695, 22.04125023], [72.24291992, 22.04125023], [72.24291992, 22.04153061], [72.24263763, 22.04153061], [72.24263763, 22.04403114], [72.24291992, 22.04403114], [72.24291992, 22.04430962], [72.24263763, 22.04430962], [72.24263763, 22.04514122], [72.24236298, 22.04514122], [72.24236298, 22.04541969], [72.24208069, 22.04541588], [72.24208069, 22.04569435], [72.24180603, 22.04569435], [72.24180603, 22.0470829], [72.24153137, 22.0470829], [72.24153137, 22.04958344], [72.24180603, 22.04958344], [72.24180603, 22.05069351], [72.24236298, 22.05069351], [72.24236298, 22.05097198], [72.24263763, 22.05096817], [72.24263763, 22.05125046], [72.24318695, 22.05125046], [72.24318695, 22.05153084], [72.24346924, 22.05153084], [72.24346924, 22.05180931], [72.24375153, 22.0518055], [72.24375153, 22.05208397], [72.24402618, 22.05208397], [72.24402618, 22.05236053], [72.24430847, 22.05236053], [72.24430847, 22.05264091], [72.24458313, 22.05264091], [72.24458313, 22.05291939], [72.24514008, 22.05291748], [72.24514008, 22.05319405], [72.24541473, 22.05319405], [72.24541473, 22.05347252], [72.24569702, 22.0534687], [72.24569702, 22.0537529], [72.24624634, 22.0537529], [72.24624634, 22.05404282], [72.24681091, 22.05404282], [72.24681091, 22.05430984], [72.24708557, 22.05430603], [72.24708557, 22.0545826], [72.24764252, 22.0545826], [72.24764252, 22.05486107], [72.24819183, 22.05486107], [72.24819183, 22.05513954], [72.24874878, 22.05513954], [72.24874878, 22.05541992], [72.24903107, 22.05541611], [72.24903107, 22.05569458], [72.24958038, 22.05569458], [72.24958038, 22.05597115], [72.25013733, 22.05597115], [72.25013733, 22.05624962], [72.25068665, 22.05624962], [72.25068665, 22.05653], [72.25152588, 22.05652809], [72.25152588, 22.05680466], [72.25208282, 22.05680466], [72.25208282, 22.05708313], [72.25263977, 22.05708313], [72.25263977, 22.0573616], [72.25319672, 22.0573597], [72.25319672, 22.05764008], [72.25402832, 22.05764008], [72.25402832, 22.05792046], [72.2545929, 22.05792046], [72.2545929, 22.05820084], [72.25514221, 22.05819321], [72.25514221, 22.05847168], [72.25569153, 22.05846977], [72.25569153, 22.05875015], [72.25653076, 22.05875015], [72.25653076, 22.05903053], [72.25708008, 22.05903053], [72.25708008, 22.05931091], [72.25763702, 22.05930328], [72.25763702, 22.05958366], [72.25846863, 22.05958366], [72.25846863, 22.05986023], [72.25930786, 22.05985069], [72.25930786, 22.06014061], [72.25985718, 22.06014061], [72.25985718, 22.06042099], [72.26069641, 22.06041527], [72.26069641, 22.06069374], [72.26152802, 22.06069374], [72.26152802, 22.06097221], [72.26235962, 22.06097031], [72.26235962, 22.06125069], [72.26291656, 22.06125069], [72.26291656, 22.06153107], [72.26374817, 22.06153107], [72.26374817, 22.06180954], [72.26430511, 22.06180763], [72.26430511, 22.0620842], [72.26513672, 22.06208038], [72.26513672, 22.06236076], [72.26568604, 22.06236076], [72.26568604, 22.06264114], [72.26625061, 22.06264114], [72.26625061, 22.06291962], [72.26680756, 22.06291771], [72.26680756, 22.06319427], [72.26763916, 22.06319427], [72.26763916, 22.06347275], [72.26819611, 22.06347084], [72.26819611, 22.06375122], [72.26875305, 22.06375122], [72.26875305, 22.06402969], [72.26930237, 22.06402969], [72.26930237, 22.06430817], [72.26985931, 22.06430626], [72.26985931, 22.06458282], [72.27041626, 22.06458282], [72.27041626, 22.0648613], [72.27097321, 22.0648613], [72.27097321, 22.06513977], [72.27153015, 22.06513977], [72.27153015, 22.06542015], [72.2720871, 22.06541634], [72.2720871, 22.06569481], [72.27236176, 22.06568909], [72.27236176, 22.06598282], [72.2729187, 22.06598282], [72.2729187, 22.06625175], [72.27348328, 22.06625175], [72.27348328, 22.06653023], [72.27402496, 22.06652832], [72.27402496, 22.06680489], [72.27430725, 22.06680489], [72.27430725, 22.06708336], [72.2748642, 22.06708336], [72.2748642, 22.06736183], [72.27540588, 22.06736183], [72.27540588, 22.0676403], [72.2756958, 22.0676403], [72.2756958, 22.06792068], [72.27625275, 22.06792068], [72.27625275, 22.06820107], [72.27680206, 22.06819534], [72.27680206, 22.06847382], [72.27735901, 22.06847191], [72.27735901, 22.06875038], [72.2776413, 22.06875038], [72.2776413, 22.0690403], [72.27819824, 22.0690403], [72.27819824, 22.06931114], [72.27874756, 22.06930542], [72.27874756, 22.06958389], [72.27902985, 22.06958008], [72.27902985, 22.06986046], [72.27958679, 22.06986046], [72.27958679, 22.07014084], [72.27986145, 22.07014084], [72.27986145, 22.07042122], [72.2804184, 22.0704174], [72.2804184, 22.07069206], [72.28069305, 22.07069206], [72.28069305, 22.07097244], [72.28125, 22.07097054], [72.28125, 22.07125092], [72.28151703, 22.07125092], [72.28151703, 22.07152939], [72.2820816, 22.07152939], [72.2820816, 22.07180977], [72.28236389, 22.07180405], [72.28236389, 22.07208252], [72.28291321, 22.07208252], [72.28291321, 22.07236099], [72.2831955, 22.07236099], [72.2831955, 22.07263947], [72.28430176, 22.07263947], [72.28430939, 22.07291985], [72.28514099, 22.07291412], [72.28514099, 22.07347298], [72.28595734, 22.07347107], [72.28595734, 22.07374954], [72.28624725, 22.07374954], [72.28624725, 22.07402992], [72.28652954, 22.07402611], [72.28652954, 22.07430458], [72.2868042, 22.07430458], [72.2868042, 22.07374954], [72.28708649, 22.07374954], [72.28708649, 22.07347107], [72.28736115, 22.07347298], [72.28736115, 22.0731945], [72.2876358, 22.0731945], [72.2876358, 22.07291412], [72.28791809, 22.07291985], [72.28791809, 22.07263947], [72.28819275, 22.07263947], [72.28819275, 22.07236099], [72.28848267, 22.07236099], [72.28847504, 22.07208252], [72.28874969, 22.07208252], [72.28874969, 22.07097244], [72.28902435, 22.07097244], [72.28902435, 22.07013893], [72.28930664, 22.07014084], [72.28930664, 22.06986046], [72.28985596, 22.06986046], [72.28985596, 22.06958008], [72.29013824, 22.06958389], [72.29013824, 22.06930542], [72.2904129, 22.06931114], [72.2904129, 22.0690403], [72.29096985, 22.0690403], [72.29096985, 22.06875038], [72.29125214, 22.06875038], [72.29125214, 22.06847191], [72.29180908, 22.06847382], [72.29180908, 22.06819534], [72.29209137, 22.06820107], [72.29209137, 22.06736183], [72.2923584, 22.06736183], [72.2923584, 22.06625175], [72.29264069, 22.06625175], [72.29264069, 22.06568909], [72.29291534, 22.06569481], [72.29291534, 22.06513977], [72.29319763, 22.06513977], [72.29319763, 22.06458092], [72.29347229, 22.06458282], [72.29347229, 22.06402969], [72.29374695, 22.06402969], [72.29374695, 22.06347084], [72.29402924, 22.06347275], [72.29402924, 22.06319427], [72.29445648, 22.06319427], [72.29763794, 22.06319427], [72.29763794, 22.06347275], [72.29792023, 22.06347084], [72.29792023, 22.06375122], [72.29818726, 22.06375122], [72.29818726, 22.06430817], [72.29846954, 22.06430626], [72.29846954, 22.06458282], [72.29875183, 22.06458282], [72.29875183, 22.0648613], [72.29902649, 22.06485748], [72.29902649, 22.06513977], [72.29930878, 22.06513977], [72.29930878, 22.06569481], [72.29957581, 22.06568909], [72.29957581, 22.06598282], [72.29985809, 22.06598282], [72.29985809, 22.06625175], [72.30014038, 22.06625175], [72.30014038, 22.06653023], [72.30041504, 22.06652832], [72.30041504, 22.06680489], [72.30069733, 22.06680489], [72.30069733, 22.06736183], [72.30095673, 22.06736183], [72.30095673, 22.0676403], [72.30124664, 22.0676403], [72.30124664, 22.06792068], [72.30152893, 22.06792068], [72.30152893, 22.06820107], [72.30179596, 22.06820107], [72.30179596, 22.06875038], [72.30208588, 22.06875038], [72.30208588, 22.0690403], [72.30236053, 22.0690403], [72.30236053, 22.06931114], [72.30263519, 22.06930542], [72.30263519, 22.06986046], [72.30291748, 22.06986046], [72.30291748, 22.07042122], [72.30319214, 22.0704174], [72.30319214, 22.07097244], [72.3034668, 22.07097054], [72.3034668, 22.07152939], [72.30374908, 22.07152748], [72.30374908, 22.07208252], [72.30403137, 22.07208061], [72.30403137, 22.07291985], [72.30374908, 22.07291985], [72.30374908, 22.07514], [72.30403137, 22.07514], [72.30403137, 22.07681084], [72.30347443, 22.07680511], [72.30347443, 22.07708359], [72.30291748, 22.07708359], [72.30291748, 22.07736206], [72.30264282, 22.07735825], [72.30264282, 22.07764053], [72.30208588, 22.07764053], [72.30208588, 22.07792091], [72.30152893, 22.0779171], [72.30152893, 22.07819366], [72.30097198, 22.07819366], [72.30097198, 22.07847214], [72.30069733, 22.07846832], [72.30069733, 22.07875061], [72.30014038, 22.07875061], [72.30014038, 22.07930946], [72.29930878, 22.07930565], [72.29930878, 22.07958412], [72.29875183, 22.0795784], [72.29875183, 22.07986069], [72.29818726, 22.07986069], [72.29818726, 22.08013916], [72.29736328, 22.08013916], [72.29736328, 22.08041954], [72.29652405, 22.08041763], [72.29652405, 22.0806942], [72.29515076, 22.08069038], [72.29515076, 22.08125114], [72.29541779, 22.08125114], [72.29541779, 22.0818119], [72.2959671, 22.0818119], [72.2959671, 22.08152962], [72.29680634, 22.08152962], [72.29680634, 22.08125114], [72.29792023, 22.08125114], [72.29792023, 22.08152962], [72.29819489, 22.08152771], [72.29819489, 22.08208275], [72.29846954, 22.08208275], [72.29846954, 22.08292007], [72.29875183, 22.08291626], [72.29875183, 22.08458328], [72.29957581, 22.08457947], [72.29957581, 22.08570099], [72.29985809, 22.08570099], [72.29985809, 22.08625031], [72.30014038, 22.08625031], [72.30014038, 22.08653069], [72.30042267, 22.08653069], [72.30042267, 22.08681107], [72.30069733, 22.08680534], [72.30069733, 22.08708382], [72.30095673, 22.08708], [72.30095673, 22.08736038], [72.30124664, 22.08736038], [72.30124664, 22.08764076], [72.30152893, 22.08763885], [72.30152893, 22.08819389], [72.30180359, 22.08819389], [72.30180359, 22.08847237], [72.30208588, 22.08847046], [72.30208588, 22.08875084], [72.30236053, 22.08875084], [72.30236053, 22.08903122], [72.30263519, 22.0890255], [72.30264282, 22.08986092], [72.30236053, 22.08986092], [72.30236053, 22.0909729], [72.30208588, 22.0909729], [72.30208588, 22.09208298], [72.30236053, 22.09207916], [72.30236053, 22.0929203], [72.30263519, 22.09291649], [72.30263519, 22.09375191], [72.30291748, 22.09375191], [72.30291748, 22.09458351], [72.30319214, 22.0945816], [72.30319214, 22.09542274], [72.30291748, 22.09541702], [72.30291748, 22.09597206], [72.30264282, 22.09596252], [72.30264282, 22.09653091], [72.30236053, 22.09653091], [72.30236053, 22.09736061], [72.30208588, 22.09736061], [72.30208588, 22.09791946], [72.30180359, 22.09791756], [72.30180359, 22.0984726], [72.30069733, 22.0984726], [72.30069733, 22.09902763], [72.30097198, 22.09902763], [72.30097198, 22.09958267], [72.30124664, 22.09958267], [72.30124664, 22.10069466], [72.30152893, 22.10069084], [72.30152893, 22.10209084], [72.30179596, 22.10209084], [72.30179596, 22.10375023], [72.30152893, 22.10375023], [72.30152893, 22.10569382], [72.30179596, 22.1056881], [72.30179596, 22.10680962], [72.30152893, 22.1068058], [72.30152893, 22.10708427], [72.30124664, 22.10707855], [72.30124664, 22.10736275], [72.30095673, 22.10736275], [72.30095673, 22.10764122], [72.30069733, 22.10763931], [72.30069733, 22.10819435], [72.30041504, 22.10819435], [72.30041504, 22.10847282], [72.30014038, 22.10847282], [72.30014038, 22.10874939], [72.29930878, 22.10874939], [72.29930878, 22.10847282], [72.29902649, 22.10847282], [72.29902649, 22.10819435], [72.29875183, 22.10819435], [72.29875183, 22.10791588], [72.29846954, 22.10791969], [72.29846954, 22.10764122], [72.29818726, 22.10764122], [72.29818726, 22.10736275], [72.29792023, 22.10736275], [72.29792023, 22.10707855], [72.29763794, 22.10708427], [72.29763794, 22.1068058], [72.29736328, 22.10680962], [72.29736328, 22.10652924], [72.29708099, 22.10652924], [72.29708099, 22.10625076], [72.29680634, 22.10625076], [72.29680634, 22.10596848], [72.29652405, 22.10597229], [72.29652405, 22.10569382], [72.29624939, 22.10569382], [72.29624939, 22.10541725], [72.2959671, 22.10541916], [72.2959671, 22.10515022], [72.29569244, 22.10515022], [72.29569244, 22.1048584], [72.29541779, 22.1048584], [72.29541779, 22.10430908], [72.29515076, 22.10430908], [72.29515076, 22.10346985], [72.29486084, 22.10347176], [72.29486084, 22.10291862], [72.29429626, 22.10292053], [72.29429626, 22.10264015], [72.29347229, 22.10264015], [72.29347229, 22.10235977], [72.29291534, 22.10236168], [72.29291534, 22.10208321], [72.29209137, 22.10209084], [72.29209137, 22.10180092], [72.29152679, 22.10180473], [72.29152679, 22.10152626], [72.2904129, 22.10153008], [72.2904129, 22.10124969], [72.28930664, 22.10124969], [72.28930664, 22.10097122], [72.28874969, 22.10097313], [72.28874969, 22.10069466], [72.28791809, 22.10069466], [72.28791809, 22.10041428], [72.2876358, 22.10042], [72.2876358, 22.10013962], [72.28736115, 22.10013962], [72.28736115, 22.09986115], [72.28679657, 22.09986115], [72.28679657, 22.09958076], [72.28652954, 22.09958267], [72.28652954, 22.0984726], [72.28624725, 22.0984726], [72.28624725, 22.09680557], [72.28595734, 22.09680939], [72.28595734, 22.09596252], [72.28708649, 22.09597206], [72.28708649, 22.09541702], [72.28679657, 22.09542274], [72.28679657, 22.09486008], [72.28652954, 22.09486008], [72.28652954, 22.09430504], [72.28624725, 22.09431267], [72.28624725, 22.09403038], [72.28595734, 22.09403038], [72.28595734, 22.09375191], [72.28569794, 22.09375191], [72.28569794, 22.09347153], [72.28541565, 22.09347153], [72.28541565, 22.09319496], [72.28514099, 22.09321022], [72.28514099, 22.0929203], [72.2848587, 22.0929203], [72.2848587, 22.09264183], [72.28430939, 22.09264183], [72.28430176, 22.09321022], [72.2840271, 22.09319496], [72.2840271, 22.09347153], [72.28375244, 22.09347153], [72.28375244, 22.09375191], [72.28291321, 22.09375191], [72.28291321, 22.09347153], [72.28263855, 22.09347153], [72.28263855, 22.09291649], [72.28235626, 22.0929203], [72.28235626, 22.09264183], [72.2820816, 22.09264183], [72.2820816, 22.09236145], [72.28180695, 22.09236145], [72.28180695, 22.09208298], [72.28125, 22.09208298], [72.28125, 22.09180641], [72.28098297, 22.09180832], [72.28098297, 22.09152985], [72.27791595, 22.09152985], [72.27791595, 22.09124756], [72.2776413, 22.09124756], [72.2776413, 22.09096909], [72.27735901, 22.0909729], [72.27735901, 22.09069443], [72.27707672, 22.09069061], [72.27707672, 22.09124756], [72.2767868, 22.09124756], [72.2767868, 22.09180832], [72.2765274, 22.09180832], [72.2765274, 22.09653091], [72.27680206, 22.0965271], [72.27680206, 22.09819412], [72.27625275, 22.09819412], [72.27625275, 22.0984726], [72.27597046, 22.09847069], [72.27597046, 22.09875107], [72.27541351, 22.09874916], [72.27541351, 22.09902763], [72.27513885, 22.09902], [72.27513885, 22.09930992], [72.27485657, 22.09930992], [72.27485657, 22.09986115], [72.27458191, 22.09986115], [72.27458191, 22.10013962], [72.27430725, 22.10013962], [72.27430725, 22.10042], [72.27348328, 22.10042], [72.27348328, 22.10013962], [72.2729187, 22.10013962], [72.2729187, 22.09986115], [72.27097321, 22.09986115], [72.27098083, 22.10013962], [72.2701416, 22.10013962], [72.2701416, 22.10042], [72.26985931, 22.10041428], [72.26985931, 22.10069466], [72.26930237, 22.10069084], [72.26930237, 22.10124969], [72.26902771, 22.10124969], [72.26902771, 22.10153008], [72.26875305, 22.10153008], [72.26875305, 22.10209084], [72.26847076, 22.10209084], [72.26847076, 22.10320091], [72.26819611, 22.10320091], [72.26819611, 22.10625076], [72.26792145, 22.10625076], [72.26792145, 22.10652924], [72.26763916, 22.10652924], [72.26763916, 22.10680962], [72.26708221, 22.10680962], [72.26708221, 22.10652924], [72.26680756, 22.10652924], [72.26680756, 22.10625076], [72.26625061, 22.10625076], [72.26625061, 22.10596848], [72.26597595, 22.10597229], [72.26597595, 22.10569382], [72.26569366, 22.10569382], [72.26569366, 22.10541725], [72.26541901, 22.10541916], [72.26541901, 22.10403061], [72.26597595, 22.10403061], [72.26597595, 22.10346985], [72.26625061, 22.10347176], [72.26625061, 22.10263634], [72.26597595, 22.10264015], [72.26597595, 22.10235977], [72.26569366, 22.10236168], [72.26569366, 22.10180473], [72.26597595, 22.10180473], [72.26597595, 22.10152626], [72.2665329, 22.10153008], [72.2665329, 22.10124969], [72.26680756, 22.10124969], [72.26680756, 22.10097122], [72.2673645, 22.10097313], [72.2673645, 22.10069466], [72.26763916, 22.10069466], [72.26763916, 22.10041428], [72.26847076, 22.10042], [72.26847076, 22.10013962], [72.26875305, 22.10013962], [72.26875305, 22.09986115], [72.26930237, 22.09986115], [72.26930237, 22.09958076], [72.2701416, 22.09958267], [72.2701416, 22.0993042], [72.27069092, 22.09930992], [72.27069092, 22.09902], [72.27097321, 22.09902763], [72.27097321, 22.09874916], [72.27153015, 22.09875107], [72.27153015, 22.09847069], [72.27180481, 22.0984726], [72.27180481, 22.09819412], [72.2720871, 22.09819412], [72.2720871, 22.09791756], [72.2729187, 22.09791946], [72.2729187, 22.09764099], [72.27401733, 22.09764099], [72.27401733, 22.09736061], [72.27485657, 22.09736061], [72.27485657, 22.09568977], [72.27513885, 22.09569359], [72.27513885, 22.09402847], [72.27485657, 22.09403038], [72.27485657, 22.09321022], [72.27458191, 22.09321022], [72.27458191, 22.09264183], [72.27430725, 22.09264183], [72.27430725, 22.09180832], [72.27458191, 22.09180832], [72.27458191, 22.09069061], [72.2748642, 22.09069443], [72.2748642, 22.08958244], [72.27513885, 22.08958244], [72.27513885, 22.08875084], [72.27540588, 22.08875084], [72.27540588, 22.08764076], [72.2756958, 22.08764076], [72.2756958, 22.08708], [72.27597046, 22.08708382], [72.27597046, 22.08680534], [72.27625275, 22.08681107], [72.27625275, 22.08653069], [72.2765274, 22.08653069], [72.2765274, 22.08570099], [72.27625275, 22.08570099], [72.27625275, 22.08457947], [72.2765274, 22.08458328], [72.2765274, 22.08402824], [72.27680206, 22.08402824], [72.27680206, 22.0834713], [72.27819061, 22.0834713], [72.27819824, 22.08263969], [72.2784729, 22.08263969], [72.2784729, 22.08152962], [72.27819824, 22.08152962], [72.27819061, 22.08041954], [72.27791595, 22.08041954], [72.27791595, 22.07986069], [72.27735901, 22.07986069], [72.27735901, 22.0795784], [72.27708435, 22.07958412], [72.27708435, 22.07930565], [72.2765274, 22.07930946], [72.2765274, 22.07902908], [72.2756958, 22.07902908], [72.2756958, 22.07875061], [72.27485657, 22.07875061], [72.27485657, 22.07846832], [72.27375031, 22.07847214], [72.27375031, 22.07819366], [72.2729187, 22.07819366], [72.2729187, 22.0779171], [72.27263641, 22.07792091], [72.27263641, 22.07764053], [72.27179718, 22.07764053], [72.27179718, 22.07735825], [72.27124786, 22.07736206], [72.27124786, 22.07708359], [72.27041626, 22.07708359], [72.27041626, 22.07680511], [72.26957703, 22.07681084], [72.26957703, 22.07653046], [72.26902771, 22.07653046], [72.26902771, 22.07624817], [72.26819611, 22.07624817], [72.26819611, 22.0759697], [72.26763916, 22.0759716], [72.26763916, 22.07569695], [72.26708221, 22.07570076], [72.26708221, 22.07542038], [72.26680756, 22.07542038], [72.26680756, 22.07514], [72.26625061, 22.07514], [72.26625061, 22.07485962], [72.26569366, 22.07486153], [72.26569366, 22.07458305], [72.26513672, 22.07458305], [72.26513672, 22.07430458], [72.2648468, 22.0743103], [72.2648468, 22.07402992], [72.26457977, 22.07402992], [72.26457977, 22.07374954], [72.26430511, 22.07374954], [72.26430511, 22.07347298], [72.26403046, 22.07347298], [72.26403046, 22.0731945], [72.26374817, 22.0731945], [72.26374817, 22.07291412], [72.26346588, 22.07291985], [72.26346588, 22.07263947], [72.26319122, 22.07263947], [72.26319122, 22.07236099], [72.26291656, 22.07236099], [72.26291656, 22.07208061], [72.26235962, 22.07208252], [72.26235962, 22.07180405], [72.26207733, 22.07180977], [72.26207733, 22.07152939], [72.26178741, 22.07152939], [72.26178741, 22.07125092], [72.26152802, 22.07125092], [72.26152802, 22.07097054], [72.26125336, 22.07097244], [72.26125336, 22.07069206], [72.26097107, 22.07069206], [72.26097107, 22.0704174], [72.26069641, 22.07042122], [72.26069641, 22.07014084], [72.26040649, 22.07014084], [72.26040649, 22.06986046], [72.25985718, 22.06986046], [72.25985718, 22.06958008], [72.25958252, 22.06958389], [72.25958252, 22.06930542], [72.25930786, 22.06931114], [72.25930786, 22.0690403], [72.25904083, 22.0690403], [72.25904083, 22.06875038], [72.25875092, 22.06875038], [72.25875092, 22.06847191], [72.25819397, 22.06847382], [72.25819397, 22.06819534], [72.25791931, 22.06820107], [72.25791931, 22.06792068], [72.25763702, 22.06792068], [72.25763702, 22.0676403], [72.25736237, 22.0676403], [72.25736237, 22.06736183], [72.25680542, 22.06736183], [72.25680542, 22.06708336], [72.25653076, 22.06708336], [72.25653076, 22.06680489], [72.25624847, 22.06680489], [72.25624847, 22.06652832], [72.25569153, 22.06653023], [72.25569153, 22.06625175], [72.25541687, 22.06625175], [72.25541687, 22.06598282], [72.25485992, 22.06598282], [72.25485992, 22.06568909], [72.25430298, 22.06569481], [72.25430298, 22.06541634], [72.25347137, 22.06542015], [72.25347137, 22.06513977], [72.2529068, 22.06513977], [72.2529068, 22.06485748], [72.25235748, 22.0648613], [72.25235748, 22.06458282], [72.25180817, 22.06458282], [72.25180817, 22.06430626], [72.25096893, 22.06430817], [72.25096893, 22.06402969], [72.25041962, 22.06402969], [72.25041962, 22.06375122], [72.24874878, 22.06375122], [72.24874878, 22.06347084], [72.24764252, 22.06347275], [72.24764252, 22.06319427], [72.24708557, 22.06319427], [72.24708557, 22.06263733], [72.24652863, 22.06264114], [72.24652863, 22.06236076], [72.24597168, 22.06236076], [72.24597168, 22.06208038], [72.24514008, 22.0620842], [72.24514008, 22.06180763], [72.24430847, 22.06180954], [72.24430847, 22.06153107], [72.24375153, 22.06153107], [72.24375153, 22.06125069], [72.24291992, 22.06125069], [72.24291992, 22.06097031], [72.24180603, 22.06097221], [72.24180603, 22.06069374], [72.24124908, 22.06069374], [72.24124908, 22.06041527], [72.24067688, 22.06042099], [72.24067688, 22.06014061], [72.24014282, 22.06014061], [72.24014282, 22.05985069], [72.23930359, 22.05986023], [72.23930359, 22.05958366], [72.23874664, 22.05958366], [72.23874664, 22.05930328], [72.23790741, 22.05931091], [72.23790741, 22.05875015], [72.23764038, 22.05875015], [72.23764038, 22.05846977], [72.23735809, 22.05847168], [72.23735809, 22.05819321], [72.23707581, 22.05820084], [72.23707581, 22.05792046], [72.23652649, 22.05792046], [72.23652649, 22.05764008], [72.23625183, 22.05764008], [72.23625183, 22.05708122], [72.23596954, 22.05708313], [72.23596954, 22.05680466], [72.23569489, 22.05680466], [72.23569489, 22.05597115], [72.23542023, 22.05597115], [72.23542023, 22.05569458], [72.23513794, 22.05569458], [72.23513794, 22.05541611], [72.23458099, 22.05541992], [72.23458099, 22.05513954], [72.23430634, 22.05513954], [72.23430634, 22.05486107], [72.23401642, 22.05486107], [72.23401642, 22.05430984], [72.23374939, 22.05430984], [72.23374939, 22.05404282], [72.2334671, 22.05404282], [72.2334671, 22.0537529], [72.23319244, 22.0537529], [72.23319244, 22.05318832], [72.23291779, 22.05319405], [72.23291779, 22.05291748], [72.23264313, 22.05291939], [72.23264313, 22.05207825], [72.23236084, 22.05208397], [72.23236084, 22.05152893], [72.23210144, 22.05153084], [72.23210144, 22.05096817], [72.23180389, 22.05097198], [72.23180389, 22.05069542], [72.23152924, 22.0506897], [72.23152924, 22.05013657], [72.23124695, 22.05014038], [72.23124695, 22.04931068], [72.23097229, 22.04931068], [72.23097229, 22.04874992], [72.23069763, 22.04874992], [72.23069763, 22.04681015], [72.23042297, 22.04681015], [72.23042297, 22.0448494], [72.23014069, 22.04486084], [72.23014069, 22.04236031], [72.2298584, 22.04236031], [72.2298584, 22.04208183], [72.23014069, 22.04208374], [72.23014069, 22.03902817], [72.23042297, 22.03903008], [72.23042297, 22.03680992], [72.23069763, 22.03680992], [72.23069763, 22.03568077], [72.23097229, 22.03569412], [72.23097229, 22.03375053], [72.23124695, 22.03375053], [72.23124695, 22.03264046], [72.23152924, 22.03264046], [72.23152924, 22.0320797], [72.23180389, 22.03208351], [72.23180389, 22.03013802], [72.23210144, 22.03013992], [72.23210144, 22.02987099], [72.23236084, 22.02987099], [72.23236084, 22.02902985], [72.23264313, 22.02902985], [72.23264313, 22.02763939], [72.23291779, 22.02763939], [72.23291779, 22.02680969], [72.23319244, 22.02680969], [72.23319244, 22.02514076], [72.2334671, 22.02514076], [72.2334671, 22.02374077], [72.23374939, 22.02375031], [72.23374939, 22.02236176], [72.23347473, 22.02236176], [72.23347473, 22.0209713], [72.23319244, 22.0209713], [72.23319244, 22.01958275], [72.23291779, 22.01958275], [72.23291779, 22.0181942], [72.2326355, 22.0181942], [72.2326355, 22.01763916], [72.23181152, 22.01764107], [72.23181152, 22.01793098], [72.23097229, 22.01791763], [72.23097229, 22.0181942], [72.23041534, 22.0181942], [72.23041534, 22.01847267], [72.22957611, 22.01847076], [72.22957611, 22.01875114], [72.22873688, 22.01875114], [72.22873688, 22.01902962], [72.2270813, 22.01902962], [72.2270813, 22.01931], [72.22541809, 22.01930428], [72.22541809, 22.01958275], [72.2251358, 22.01958084], [72.2251358, 22.01986122], [72.22486115, 22.01986122], [72.22486115, 22.02013969], [72.22458649, 22.02013969], [72.22458649, 22.02042007], [72.2243042, 22.02041435], [72.2243042, 22.02069664], [72.2234726, 22.02069664], [72.2234726, 22.0209713], [72.22319794, 22.0209713], [72.22319794, 22.02069664], [72.22291565, 22.02069664], [72.22291565, 22.01986122], [72.22264099, 22.01986122], [72.22264099, 22.01931], [72.22207642, 22.01931], [72.22207642, 22.01902962], [72.22180176, 22.01902962], [72.22180176, 22.01875114], [72.22125244, 22.01875114], [72.22125244, 22.01819038], [72.22097015, 22.0181942], [72.22097015, 22.01763916], [72.22070313, 22.01764107], [72.22070313, 22.01736069], [72.22041321, 22.01736069], [72.22041321, 22.01680946], [72.22013855, 22.01680946], [72.22013855, 22.0165329], [72.21996307, 22.01652908], [72.21986389, 22.01652718], [72.21987152, 22.01625061], [72.21930695, 22.01625061], [72.21930695, 22.01597023], [72.21902466, 22.01597214], [72.21902466, 22.01569366], [72.21875, 22.01569366], [72.21875, 22.0154171], [72.21848297, 22.01542282], [72.21848297, 22.01514053], [72.21819305, 22.01514053], [72.21819305, 22.01458168], [72.2179184, 22.01458359], [72.2179184, 22.01402855], [72.21736145, 22.01403046], [72.21736145, 22.01375008], [72.21708679, 22.01375008], [72.21708679, 22.01292038], [72.21679688, 22.01292038], [72.21679688, 22.01207924], [72.2166748, 22.01210213], [72.2165451, 22.01212883], [72.21652985, 22.01180077], [72.21569824, 22.01180649], [72.21569061, 22.01152992], [72.21485901, 22.01152992], [72.21485901, 22.01124954], [72.21457672, 22.01124954], [72.21457672, 22.01096916], [72.21430206, 22.01097298], [72.21430206, 22.0106945], [72.2123642, 22.0106945], [72.2123642, 22.01041794], [72.2095871, 22.01041794], [72.2095871, 22.0106945], [72.20903015, 22.0106945], [72.20903015, 22.01097298], [72.20793152, 22.01096916], [72.20793152, 22.01152992], [72.2076416, 22.01152992], [72.2076416, 22.01180649], [72.20735931, 22.01180649], [72.20735931, 22.01208305], [72.20708466, 22.01208305], [72.20708466, 22.01236153], [72.20680237, 22.01236153], [72.20680237, 22.01292038], [72.20652771, 22.01292038], [72.20652771, 22.01320267], [72.20625305, 22.01319504], [72.20625305, 22.0134716], [72.20597076, 22.0134716], [72.20597076, 22.01375008], [72.20540619, 22.01375008], [72.20540619, 22.01403046], [72.20513916, 22.01402855], [72.20513916, 22.01458359], [72.20458221, 22.01458168], [72.20458221, 22.01514053], [72.20430756, 22.01514053], [72.20430756, 22.01542282], [72.20402527, 22.0154171], [72.20402527, 22.01569366], [72.20375061, 22.01569366], [72.20375061, 22.01597214], [72.20347595, 22.01597023], [72.20347595, 22.01625061], [72.20318604, 22.01625061], [72.20318604, 22.0165329], [72.20291901, 22.0165329], [72.20291901, 22.01680946], [72.20263672, 22.01680565], [72.20263672, 22.01708221], [72.20236206, 22.01708031], [72.20236206, 22.01736069], [72.20207977, 22.01736069], [72.20207977, 22.01764107], [72.20179749, 22.01764107], [72.20179749, 22.01793098], [72.20153046, 22.01791763], [72.20153046, 22.0181942], [72.20096588, 22.01819038], [72.20096588, 22.01875114], [72.20069122, 22.01875114], [72.20069122, 22.01902962], [72.20014191, 22.01902771], [72.20014191, 22.01958275], [72.19985962, 22.01958084], [72.19985962, 22.01986122], [72.19930267, 22.01986122], [72.19930267, 22.02069664], [72.19902802, 22.02069664], [72.19902802, 22.0209713], [72.19847107, 22.02096939], [72.19847107, 22.02124977], [72.19819641, 22.02124977], [72.19819641, 22.02153015], [72.19763947, 22.02152634], [72.19763947, 22.02180481], [72.19680786, 22.02180481], [72.19680786, 22.02208328], [72.19652557, 22.02208328], [72.19652557, 22.02236176], [72.19596863, 22.02235985], [72.19596863, 22.02264023], [72.19486237, 22.02264023], [72.19486237, 22.02235985], [72.19374847, 22.02236176], [72.19374847, 22.02208328], [72.19235992, 22.02208328], [72.19235992, 22.02180481], [72.19180298, 22.02180481], [72.19180298, 22.02152634], [72.1904068, 22.02153015], [72.1904068, 22.02124977], [72.19013977, 22.02124977], [72.19013977, 22.02096939], [72.18958282, 22.0209713], [72.18958282, 22.02069664], [72.18902588, 22.02069664], [72.18902588, 22.02041435], [72.18875122, 22.02042007], [72.18875122, 22.01986122], [72.18846893, 22.01986122], [72.18846893, 22.01958084], [72.18791962, 22.01958275], [72.18791962, 22.01930428], [72.18763733, 22.01930428], [72.18763733, 22.01958275], [72.18596649, 22.01958084], [72.18596649, 22.01986122], [72.18569183, 22.01986122], [72.18569183, 22.02013969], [72.18541718, 22.02013969], [72.18541718, 22.02042007], [72.18514252, 22.02041435], [72.18514252, 22.02069664], [72.18486023, 22.02067947], [72.18486023, 22.02264023], [72.1845932, 22.02264023], [72.1845932, 22.02430916], [72.18486023, 22.02430916], [72.18486023, 22.02514076], [72.18514252, 22.02514076], [72.18514252, 22.02569389], [72.18541718, 22.02569389], [72.18541718, 22.02708244], [72.18430328, 22.02708244], [72.18430328, 22.02736282], [72.1845932, 22.02736282], [72.1845932, 22.02791977], [72.18486023, 22.02791595], [72.18486023, 22.0284729], [72.1845932, 22.0284729], [72.1845932, 22.02902985], [72.18430328, 22.02902985], [72.18430328, 22.02987099], [72.18402863, 22.02987099], [72.18402863, 22.03070068], [72.18374634, 22.03069305], [72.1837616, 22.03125], [72.18347168, 22.03125], [72.18347168, 22.03208351], [72.18319702, 22.03208351], [72.18319702, 22.03291512], [72.18291473, 22.03291512], [72.18291473, 22.03347206], [72.18264008, 22.03347015], [72.18264008, 22.03403091], [72.18235779, 22.03402519], [72.18235779, 22.03458595], [72.18208313, 22.03458023], [72.18208313, 22.03514099], [72.18096924, 22.03514099], [72.18096924, 22.03541946], [72.17986298, 22.03541565], [72.17986298, 22.03569412], [72.17958069, 22.03569412], [72.17958069, 22.0359726], [72.17903137, 22.03597069], [72.17903137, 22.03625107], [72.17819214, 22.03625107], [72.17819214, 22.03652954], [72.17791748, 22.03652954], [72.17791748, 22.03680992], [72.17762756, 22.03680992], [72.17762756, 22.03791809], [72.17736053, 22.03791809], [72.17736053, 22.03903008], [72.17708588, 22.03902817], [72.17708588, 22.03930473], [72.17652893, 22.03930473], [72.17652893, 22.03958321], [72.17624664, 22.03958321], [72.17624664, 22.03986168], [72.17597198, 22.03986168], [72.17597198, 22.04014015], [72.17569733, 22.04014015], [72.17569733, 22.04042053], [72.17514038, 22.04042053], [72.17514038, 22.04070282], [72.17485809, 22.04069519], [72.17485809, 22.04097176], [72.17456818, 22.04097176], [72.17456818, 22.04125023], [72.17430878, 22.04125023], [72.17430878, 22.04153061], [72.17236328, 22.04153061], [72.17236328, 22.04070282], [72.17263794, 22.04070282], [72.17263794, 22.03986168], [72.17346954, 22.03986168], [72.17346954, 22.03958321], [72.17402649, 22.03958321], [72.17402649, 22.03930473], [72.17485809, 22.03930473], [72.17485809, 22.03902817], [72.17514038, 22.03903008], [72.17514038, 22.03847122], [72.17541504, 22.03847313], [72.17541504, 22.03819466], [72.17569733, 22.03819466], [72.17569733, 22.03763962], [72.17597198, 22.03763962], [72.17597198, 22.03708076], [72.17624664, 22.03708267], [72.17624664, 22.03680611], [72.17652893, 22.03680992], [72.17652893, 22.03625107], [72.17679596, 22.03625107], [72.17679596, 22.03597069], [72.17708588, 22.0359726], [72.17708588, 22.03541565], [72.17819214, 22.03541946], [72.17819214, 22.03514099], [72.17874908, 22.03514099], [72.17874908, 22.03486061], [72.17958069, 22.03486061], [72.17958069, 22.03458023], [72.17986298, 22.03458595], [72.17986298, 22.03430748], [72.18013763, 22.03430939], [72.18013763, 22.03375053], [72.18041992, 22.03375053], [72.18041992, 22.03347015], [72.18069458, 22.03347206], [72.18069458, 22.03319359], [72.18096924, 22.03319359], [72.18096924, 22.03180313], [72.18070221, 22.03181076], [72.18070221, 22.03070068], [72.18096924, 22.03070068], [72.18096924, 22.03013992], [72.18152618, 22.03013992], [72.18152618, 22.02987099], [72.18125153, 22.02987099], [72.18125153, 22.02958107], [72.18069458, 22.02958107], [72.18069458, 22.02930641], [72.18096924, 22.02931023], [72.18096924, 22.02874947], [72.18125153, 22.02874947], [72.18125153, 22.02819252], [72.18152618, 22.02819443], [72.18152618, 22.02763939], [72.18180847, 22.02763939], [72.18180847, 22.02403069], [72.18152618, 22.02403069], [72.18152618, 22.02292061], [72.18125153, 22.02292061], [72.18125153, 22.02207947], [72.18096924, 22.02208328], [72.18096924, 22.02152634], [72.18070221, 22.02153015], [72.18070221, 22.02096939], [72.18041992, 22.0209713], [72.18041992, 22.02013969], [72.18013763, 22.02013969], [72.18013763, 22.01958084], [72.17986298, 22.01958275], [72.17986298, 22.01902771], [72.18013763, 22.01902962], [72.18013763, 22.01875114], [72.18041992, 22.01875114], [72.18041992, 22.01847076], [72.18069458, 22.01847267], [72.18069458, 22.0181942], [72.18235779, 22.0181942], [72.18235779, 22.01736069], [72.18264008, 22.01736069], [72.18264008, 22.01680946], [72.18319702, 22.01680946], [72.18319702, 22.0165329], [72.1837616, 22.0165329], [72.1837616, 22.01625061], [72.18541718, 22.01625061], [72.18541718, 22.01597023], [72.18569183, 22.01597214], [72.18569183, 22.0154171], [72.19041443, 22.0154171], [72.19041443, 22.01569366], [72.19125366, 22.01569366], [72.19125366, 22.01597214], [72.19264221, 22.01597214], [72.19264221, 22.01569366], [72.19291687, 22.01569366], [72.19291687, 22.01597214], [72.19346619, 22.01597023], [72.19346619, 22.01625061], [72.19513702, 22.01625061], [72.19513702, 22.0165329], [72.1957016, 22.0165329], [72.1957016, 22.01680946], [72.19708252, 22.01680946], [72.19708252, 22.0165329], [72.19735718, 22.0165329], [72.19735718, 22.01625061], [72.19763947, 22.01625061], [72.19763947, 22.01597023], [72.19791412, 22.01597214], [72.19791412, 22.0154171], [72.19819641, 22.01542282], [72.19819641, 22.01458168], [72.19847107, 22.01458359], [72.19847107, 22.01430511], [72.19819641, 22.01431274], [72.19819641, 22.01292038], [72.19790649, 22.01292038], [72.19790649, 22.01236153], [72.19763947, 22.01236153], [72.19763947, 22.01124954], [72.19790649, 22.01124954], [72.19790649, 22.01069069], [72.19763947, 22.0106945], [72.19763947, 22.00958252], [72.19736481, 22.00958252], [72.19736481, 22.00819397], [72.19763947, 22.00819397], [72.19763947, 22.00763893], [72.19790649, 22.00764084], [72.19790649, 22.00681114], [72.19819641, 22.00681114], [72.19819641, 22.00625038], [72.19847107, 22.00625038], [72.19847107, 22.00597], [72.19902802, 22.00597191], [72.19902802, 22.00569344], [72.19930267, 22.00570107], [72.19930267, 22.00542068], [72.19985962, 22.00542068], [72.19985962, 22.0051403], [72.20014191, 22.0051403], [72.20014191, 22.00457954], [72.20041656, 22.00458336], [72.20041656, 22.00430489], [72.20124817, 22.00430489], [72.20124817, 22.00402832], [72.20179749, 22.00403023], [72.20179749, 22.00374985], [72.20236206, 22.00374985], [72.20236206, 22.00346947], [72.20375061, 22.00346947], [72.20375061, 22.00374985], [72.20485687, 22.00374985], [72.20485687, 22.00346947], [72.20569611, 22.00347137], [72.20569611, 22.00319481], [72.20652771, 22.00319481], [72.20652771, 22.00291634], [72.20735931, 22.00292969], [72.20735931, 22.00263977], [72.2076416, 22.00263977], [72.2076416, 22.00235939], [72.20791626, 22.0023613], [72.20791626, 22.00208282], [72.20819092, 22.00208282], [72.20819092, 22.00180626], [72.20847321, 22.00181007], [72.20847321, 22.00125122], [72.20874786, 22.00125122], [72.20874786, 22.00097275], [72.20903015, 22.00097275], [72.20903015, 22.00069427], [72.20930481, 22.00069427], [72.20930481, 22.0004158], [72.2095871, 22.00041962], [72.2095871, 22.00014114], [72.20986176, 22.00014114], [72.20986176, 21.99986076], [72.20986176, 21.99957085], [72.21097565, 21.9995842], [72.21097565, 21.99930573], [72.21125031, 21.99930954], [72.21125031, 21.99902916], [72.21152496, 21.99902725], [72.21152496, 21.9995842], [72.2123642, 21.9995842], [72.2123642, 21.99930573], [72.21290588, 21.99930954], [72.21290588, 21.99902916], [72.21373749, 21.99902916], [72.21373749, 21.99930954], [72.21430206, 21.99930573], [72.21430206, 21.9995842], [72.21485901, 21.9995842], [72.21485901, 21.99930573], [72.2151413, 21.99930573], [72.2151413, 21.9995842], [72.21624756, 21.99957085], [72.21624756, 21.99986076], [72.21624756, 22.00014114], [72.21652985, 22.00014114], [72.21652985, 22.00041962], [72.2168045, 22.0004158], [72.2168045, 22.00069427], [72.21708679, 22.00069427], [72.21708679, 22.00097275], [72.21736145, 22.00097275], [72.21736145, 22.00125122], [72.21763611, 22.00125122], [72.21763611, 22.00152969], [72.21848297, 22.00152969], [72.21848297, 22.00181007], [72.21902466, 22.00180626], [72.21902466, 22.00208282], [72.21930695, 22.00208282], [72.21930695, 22.0023613], [72.2195816, 22.00235939], [72.2195816, 22.00263977], [72.21987152, 22.00263977], [72.21987152, 22.00292969], [72.22013855, 22.00291634], [72.22013855, 22.00319481], [72.22041321, 22.00319481], [72.22041321, 22.00347137], [72.22097015, 22.00346947], [72.22097015, 22.00374985], [72.22125244, 22.00374985], [72.22125244, 22.00403023], [72.2215271, 22.00402832], [72.2215271, 22.00430489], [72.22180176, 22.00430489], [72.22180939, 22.00458336], [72.22208405, 22.00458336], [72.22208405, 22.00486183], [72.2223587, 22.00485992], [72.2223587, 22.0051403], [72.22264099, 22.0051403], [72.22264099, 22.00542068], [72.22293091, 22.00542068], [72.22293091, 22.00570107], [72.2234726, 22.00569344], [72.2234726, 22.00597191], [72.22374725, 22.00597], [72.22374725, 22.00625038], [72.22402954, 22.00625038], [72.22402954, 22.00653076], [72.22429657, 22.00653076], [72.22429657, 22.00681114], [72.22624969, 22.00680542], [72.22624969, 22.0070858], [72.2270813, 22.00708008], [72.2270813, 22.00736046], [72.22735596, 22.00736046], [72.22735596, 22.00792122], [72.22763824, 22.0079155], [72.22763824, 22.00819397], [72.22819519, 22.00819397], [72.22819519, 22.00847244], [72.23014069, 22.00847244], [72.23014069, 22.00819397], [72.23041534, 22.00819397], [72.23041534, 22.0079155], [72.23069763, 22.00792122], [72.23069763, 22.00764084], [72.23097229, 22.00764084], [72.23097229, 22.00653076], [72.23124695, 22.00653076], [72.23124695, 22.00570107], [72.23152924, 22.00570107], [72.23152924, 22.00346947], [72.23124695, 22.00347137], [72.23124695, 22.00319481], [72.23097229, 22.00319481], [72.23097229, 22.00291634], [72.23014069, 22.00292969], [72.23014069, 22.00263977], [72.2298584, 22.00263977], [72.2298584, 22.00235939], [72.23014069, 22.0023613], [72.23014069, 22.00180626], [72.2298584, 22.00181007], [72.2298584, 22.00152969], [72.22957611, 22.00152969], [72.22957611, 22.00125122], [72.22930908, 22.00125122], [72.22930908, 22.00097275], [72.22902679, 22.00097275], [72.22902679, 22.00069427], [72.22875214, 22.00069427], [72.22875214, 22.00013924], [72.22846985, 22.00014114], [72.22846985, 21.99986076], [72.22846985, 21.99957085], [72.22930908, 21.9995842], [72.22930908, 21.99930573], [72.23014069, 21.99930954], [72.23014069, 21.99875069], [72.23042297, 21.99875069], [72.23041534, 21.99625015], [72.23014069, 21.99625015], [72.23014069, 21.99458122], [72.2298584, 21.99458313], [72.2298584, 21.99402618], [72.22957611, 21.99403], [72.22957611, 21.99376106], [72.22902679, 21.99376106], [72.22902679, 21.99319077], [72.22875214, 21.99319458], [72.22875214, 21.9929142], [72.22846985, 21.99291992], [72.22846985, 21.99208069], [72.22819519, 21.9920826], [72.22819519, 21.99152756], [72.2279129, 21.99152946], [72.2279129, 21.99041939], [72.22763824, 21.99041939], [72.22763824, 21.98931122], [72.22735596, 21.98931122], [72.22735596, 21.98763084], [72.2270813, 21.98763847], [72.2270813, 21.98541641], [72.22680664, 21.98542023], [72.22680664, 21.98402977], [72.22651672, 21.98402977], [72.22651672, 21.98319054], [72.22624969, 21.98319435], [72.22624969, 21.98263931], [72.22596741, 21.98264122], [72.22596741, 21.98097038], [72.22569275, 21.98097229], [72.22569275, 21.98013878], [72.22541809, 21.98014069], [72.22541809, 21.97875977], [72.2251358, 21.97875977], [72.2251358, 21.97792053], [72.22486115, 21.97792053], [72.22486115, 21.97707939], [72.22458649, 21.97708321], [72.22458649, 21.97597122], [72.2243042, 21.97597122], [72.2243042, 21.97541618], [72.22402954, 21.97542], [72.22402954, 21.97458267], [72.22374725, 21.97458267], [72.22374725, 21.97430611], [72.2234726, 21.97431183], [72.2234726, 21.97375107], [72.22319794, 21.97375107], [72.22319794, 21.9731884], [72.22291565, 21.97319412], [72.22291565, 21.97263908], [72.22264099, 21.97263908], [72.22264099, 21.97236061], [72.2223587, 21.97236061], [72.2223587, 21.97153091], [72.22207642, 21.97153091], [72.22207642, 21.97042084], [72.22180176, 21.97042084], [72.22180176, 21.96931076], [72.2215271, 21.96931076], [72.2215271, 21.96820068], [72.22125244, 21.96820068], [72.22125244, 21.96763992], [72.22097015, 21.96763992], [72.22097015, 21.96430969], [72.22125244, 21.96430969], [72.22125244, 21.96292114], [72.22097015, 21.96292114], [72.22097015, 21.96236038], [72.22125244, 21.96236038], [72.22125244, 21.96153069], [72.2215271, 21.96153069], [72.2215271, 21.95708084], [72.22125244, 21.95708275], [72.22125244, 21.95652962], [72.22097015, 21.95652962], [72.22097015, 21.95625114], [72.2151413, 21.95625114], [72.2151413, 21.95597076], [72.21375275, 21.95597267], [72.21375275, 21.9556942], [72.21263885, 21.9556942], [72.21263885, 21.95541763], [72.21208191, 21.95541954], [72.21208191, 21.95514107], [72.21153259, 21.95514107], [72.21153259, 21.95486069], [72.2106781, 21.95486069], [72.2106781, 21.95458984], [72.2095871, 21.95458984], [72.2095871, 21.95430946], [72.20874786, 21.95430946], [72.20874786, 21.95403099], [72.20819092, 21.95403099], [72.20819092, 21.95375061], [72.20791626, 21.95375061], [72.20791626, 21.95347214], [72.20735931, 21.95347214], [72.20735931, 21.95319366], [72.20680237, 21.95319366], [72.20680237, 21.95291519], [72.20625305, 21.95292091], [72.20625305, 21.95264053], [72.20569611, 21.95264053], [72.20569611, 21.95236015], [72.20541382, 21.95236206], [72.20541382, 21.95208359], [72.2048645, 21.95208359], [72.2048645, 21.95180321], [72.20430756, 21.95181084], [72.20430756, 21.95153046], [72.20375061, 21.95153046], [72.20375061, 21.95125008], [72.20318604, 21.95125008], [72.20318604, 21.9509697], [72.20291901, 21.9509716], [72.20291901, 21.95069313], [72.20263672, 21.95070076], [72.20263672, 21.95042038], [72.20207977, 21.95042038], [72.20207977, 21.95014], [72.20153046, 21.95014], [72.20153046, 21.94985962], [72.20097351, 21.94986153], [72.20097351, 21.94958115], [72.20069122, 21.94958115], [72.20069122, 21.94930649], [72.19985962, 21.9493103], [72.19985962, 21.94902992], [72.19959259, 21.94902992], [72.19959259, 21.94874954], [72.19930267, 21.94874954], [72.19930267, 21.9481926], [72.19875336, 21.9481945], [72.19875336, 21.94791603], [72.19847107, 21.94791985], [72.19847107, 21.94763947], [72.19819641, 21.94763947], [72.19819641, 21.9473629], [72.19790649, 21.9473629], [72.19790649, 21.94708252], [72.19736481, 21.94708252], [72.19736481, 21.94680595], [72.19708252, 21.94681168], [72.19708252, 21.94652939], [72.19680786, 21.94652939], [72.19680786, 21.94625092], [72.19652557, 21.94625092], [72.19652557, 21.94597244], [72.19596863, 21.94597244], [72.19596863, 21.94569397], [72.19541931, 21.94569397], [72.19541931, 21.9454174], [72.19513702, 21.94541931], [72.19513702, 21.94514084], [72.19486237, 21.94514084], [72.19486237, 21.94486046], [72.19430542, 21.94486046], [72.19430542, 21.94458389], [72.19374847, 21.94458389], [72.19374847, 21.94430542], [72.19319153, 21.94430923], [72.19319153, 21.94375038], [72.19291687, 21.94375038], [72.19291687, 21.94346809], [72.19264221, 21.94347191], [72.19264221, 21.94319534], [72.19235992, 21.94319916], [72.19235992, 21.94292068], [72.1920929, 21.94292068], [72.1920929, 21.94264984], [72.19180298, 21.94264984], [72.19180298, 21.94235992], [72.19069672, 21.94235992], [72.19069672, 21.94264984], [72.1904068, 21.94264984], [72.1904068, 21.94292068], [72.19013977, 21.94292068], [72.19013977, 21.94319916], [72.18985748, 21.94319534], [72.18985748, 21.94347191], [72.18875122, 21.94346809], [72.18875122, 21.94375038], [72.18818665, 21.94375038], [72.18818665, 21.94403076], [72.18736267, 21.94403076], [72.18736267, 21.94430923], [72.18708038, 21.94430542], [72.18708038, 21.94458389], [72.18680573, 21.94458389], [72.18682098, 21.94486046], [72.18624878, 21.94486046], [72.18624878, 21.94541931], [72.18597412, 21.9454174], [72.18597412, 21.94569397], [72.18569183, 21.94569397], [72.18569183, 21.94597244], [72.18541718, 21.94597054], [72.18541718, 21.94625092], [72.1845932, 21.94625092], [72.1845932, 21.94652939], [72.18430328, 21.94652939], [72.18430328, 21.94763947], [72.18402863, 21.94763947], [72.18402863, 21.94791985], [72.18374634, 21.94791603], [72.18374634, 21.9481945], [72.18347168, 21.9481945], [72.18347168, 21.94847107], [72.1829071, 21.94846153], [72.1829071, 21.94902992], [72.18264008, 21.94902992], [72.18264008, 21.9493103], [72.18235779, 21.94930649], [72.18235779, 21.94986153], [72.18208313, 21.94985962], [72.18208313, 21.95042038], [72.18152618, 21.95042038], [72.18152618, 21.95070076], [72.18125153, 21.95069313], [72.18125153, 21.9509716], [72.18096924, 21.9509697], [72.18096924, 21.95125008], [72.18069458, 21.95125008], [72.18069458, 21.95208359], [72.18041992, 21.95208359], [72.18041992, 21.95236206], [72.18013763, 21.95236015], [72.18013763, 21.95264053], [72.17930603, 21.95264053], [72.17930603, 21.95292091], [72.17874908, 21.95291519], [72.17874908, 21.95319366], [72.17847443, 21.95319366], [72.17847443, 21.95347214], [72.17819214, 21.95347023], [72.17819214, 21.95403099], [72.17791748, 21.95403099], [72.17791748, 21.95430946], [72.17762756, 21.95430946], [72.17762756, 21.95458984], [72.17736053, 21.95458984], [72.17736053, 21.95486069], [72.17708588, 21.95486069], [72.17708588, 21.95514107], [72.17680359, 21.95513725], [72.17680359, 21.9556942], [72.17652893, 21.95569038], [72.17652893, 21.95625114], [72.17624664, 21.95625114], [72.17624664, 21.95652962], [72.17597198, 21.95652962], [72.17597198, 21.95680809], [72.17569733, 21.95680618], [72.17569733, 21.95708275], [72.17541504, 21.95708275], [72.17542267, 21.95736122], [72.17514038, 21.95736122], [72.17514038, 21.95764923], [72.17485809, 21.95764923], [72.17485809, 21.95791817], [72.17458344, 21.95791626], [72.17458344, 21.95819473], [72.17430878, 21.95819473], [72.17430878, 21.9584713], [72.17402649, 21.95846748], [72.17402649, 21.95875168], [72.17346954, 21.95875168], [72.17346954, 21.95903015], [72.1709671, 21.95903015], [72.1709671, 21.95875168], [72.17041779, 21.95875168], [72.17041779, 21.95903015], [72.16986084, 21.95903015], [72.16986084, 21.95875168], [72.16958618, 21.95875168], [72.16958618, 21.95846748], [72.16902924, 21.9584713], [72.16902924, 21.95819473], [72.16680908, 21.95819473], [72.16680908, 21.9584713], [72.16625214, 21.95846748], [72.16625214, 21.95875168], [72.16596985, 21.95875168], [72.16596985, 21.95903015], [72.16569519, 21.95902824], [72.16569519, 21.95930481], [72.1654129, 21.95930481], [72.1654129, 21.95958328], [72.16486359, 21.95958328], [72.16486359, 21.95986176], [72.16401672, 21.95986176], [72.16401672, 21.96014023], [72.16374969, 21.96014023], [72.16374969, 21.96125031], [72.16348267, 21.96125031], [72.16348267, 21.96181107], [72.16291809, 21.96180534], [72.16291809, 21.96208382], [72.16236115, 21.96208191], [72.16236115, 21.96236038], [72.16208649, 21.96236038], [72.16208649, 21.96264076], [72.1618042, 21.96263885], [72.1618042, 21.96319389], [72.16152954, 21.96319389], [72.16152954, 21.96347237], [72.16124725, 21.96347046], [72.16124725, 21.96375084], [72.1609726, 21.96375084], [72.1609726, 21.96403122], [72.16069794, 21.96403122], [72.16069794, 21.96541977], [72.16041565, 21.96541405], [72.16041565, 21.96569443], [72.16014099, 21.96569443], [72.16014099, 21.9659729], [72.1598587, 21.96597099], [72.1598587, 21.96624947], [72.15959167, 21.96624947], [72.15959167, 21.96652985], [72.1590271, 21.96652794], [72.1590271, 21.96708298], [72.15875244, 21.96708298], [72.15875244, 21.96736145], [72.15847015, 21.96736145], [72.15847015, 21.96847153], [72.1581955, 21.96847153], [72.15820313, 21.96874809], [72.15791321, 21.96874809], [72.15791321, 21.96903038], [72.15763855, 21.96902847], [72.15763855, 21.97097206], [72.15735626, 21.97096825], [72.15735626, 21.97153091], [72.1570816, 21.97153091], [72.1570816, 21.97431183], [72.15680695, 21.97430611], [72.15680695, 21.97486115], [72.15652466, 21.97486115], [72.15653229, 21.97513962], [72.15625, 21.97513962], [72.15625, 21.97569466], [72.15597534, 21.97569466], [72.15597534, 21.97597122], [72.15569305, 21.97597122], [72.15569305, 21.97624969], [72.1554184, 21.97624969], [72.1554184, 21.97653008], [72.15458679, 21.97652817], [72.15458679, 21.97680473], [72.15374756, 21.97680473], [72.15374756, 21.97708321], [72.15291595, 21.97708321], [72.15291595, 21.97736168], [72.1526413, 21.97735977], [72.1526413, 21.97764015], [72.15235901, 21.97764015], [72.15235901, 21.97792053], [72.15207672, 21.97792053], [72.15207672, 21.97820091], [72.15180206, 21.97819328], [72.15180206, 21.97847176], [72.1515274, 21.97846985], [72.1515274, 21.97875977], [72.15125275, 21.97875977], [72.15125275, 21.97903061], [72.15097046, 21.97903061], [72.15097046, 21.97931099], [72.1506958, 21.97930336], [72.1506958, 21.97958374], [72.15039825, 21.97957993], [72.15039825, 21.98014069], [72.15013885, 21.98013878], [72.15013885, 21.98069382], [72.14958191, 21.98069382], [72.14958191, 21.98097229], [72.14930725, 21.98097038], [72.14930725, 21.98125076], [72.14903259, 21.98125076], [72.14903259, 21.98153114], [72.14875031, 21.98153114], [72.14875031, 21.98181915], [72.14847565, 21.98180771], [72.14847565, 21.98208427], [72.14819336, 21.98208046], [72.14819336, 21.98236084], [72.1479187, 21.98236084], [72.1479187, 21.98264122], [72.14765167, 21.98264122], [72.14765167, 21.98291969], [72.1470871, 21.98291779], [72.1470871, 21.98319435], [72.14680481, 21.98319435], [72.14680481, 21.98347282], [72.14653015, 21.98347282], [72.14653015, 21.98291779], [72.14679718, 21.98291969], [72.14679718, 21.98236084], [72.14736176, 21.98236084], [72.14736176, 21.98208046], [72.14763641, 21.98208237], [72.14763641, 21.98152542], [72.14819336, 21.98153114], [72.14819336, 21.98125076], [72.14848328, 21.98125076], [72.14847565, 21.98069382], [72.14902496, 21.98069382], [72.14902496, 21.98041534], [72.14930725, 21.98042107], [72.14930725, 21.98014069], [72.14958191, 21.98014069], [72.14958191, 21.97986031], [72.14985657, 21.97986031], [72.14985657, 21.97957993], [72.15013885, 21.97958374], [72.15013885, 21.9790287], [72.15068817, 21.97903061], [72.15068817, 21.97846985], [72.15097046, 21.97847176], [72.15097046, 21.97763824], [72.15125275, 21.97764015], [72.15125275, 21.97735977], [72.15180206, 21.97736168], [72.15180206, 21.97708321], [72.15208435, 21.97708321], [72.15208435, 21.97680473], [72.15291595, 21.97680473], [72.15291595, 21.97652817], [72.15319061, 21.97653008], [72.15319824, 21.97624969], [72.15345764, 21.97624969], [72.15345764, 21.97597122], [72.15402985, 21.97597122], [72.15402985, 21.97569466], [72.1543045, 21.97569466], [72.1543045, 21.97541618], [72.15458679, 21.97542], [72.15458679, 21.97513962], [72.15486145, 21.97513962], [72.15486145, 21.97486115], [72.15513611, 21.97486115], [72.15513611, 21.97458267], [72.1554184, 21.97458267], [72.1554184, 21.97430611], [72.15569305, 21.97431183], [72.15569305, 21.97402954], [72.15598297, 21.97402954], [72.15598297, 21.9731884], [72.15625, 21.97319412], [72.15625, 21.97263908], [72.15652466, 21.97263908], [72.15652466, 21.97180557], [72.1568222, 21.97180939], [72.1568222, 21.97014046], [72.1570816, 21.97014046], [72.1570816, 21.96874809], [72.15735626, 21.96874809], [72.15735626, 21.96763992], [72.15763855, 21.96763992], [72.15763855, 21.96735954], [72.15791321, 21.96736145], [72.15791321, 21.96652794], [72.15820313, 21.96652985], [72.15820313, 21.96597099], [72.15847015, 21.9659729], [72.15847015, 21.96541405], [72.15875244, 21.96541977], [72.15875244, 21.96513939], [72.15930176, 21.96513939], [72.15930176, 21.96458054], [72.15958405, 21.96458244], [72.15958405, 21.9640274], [72.1598587, 21.96403122], [72.1598587, 21.96347046], [72.16014099, 21.96347237], [72.16014099, 21.96319389], [72.16041565, 21.96319389], [72.16041565, 21.96263885], [72.16069794, 21.96264076], [72.16069794, 21.96181107], [72.1609726, 21.96181107], [72.1609726, 21.96068954], [72.16069794, 21.96069527], [72.16069794, 21.95986176], [72.16041565, 21.95986176], [72.16041565, 21.95930481], [72.15930176, 21.95930481], [72.15930176, 21.95902824], [72.1590271, 21.95902824], [72.1590271, 21.95930481], [72.15875244, 21.95930481], [72.15875244, 21.95902824], [72.15598297, 21.95903015], [72.15598297, 21.95875168], [72.15374756, 21.95875168], [72.15374756, 21.95846748], [72.1526413, 21.9584713], [72.1526413, 21.95819473], [72.15180206, 21.95819473], [72.15180206, 21.95791626], [72.1515274, 21.95791817], [72.1515274, 21.95764923], [72.15097046, 21.95764923], [72.15097046, 21.95736122], [72.15039825, 21.95736122], [72.15039825, 21.95708084], [72.1498642, 21.95708275], [72.1498642, 21.95680618], [72.14903259, 21.95680809], [72.14903259, 21.95652962], [72.14848328, 21.95652962], [72.14848328, 21.95625114], [72.14819336, 21.95625114], [72.14819336, 21.95597076], [72.1479187, 21.95597267], [72.1479187, 21.9556942], [72.14736176, 21.9556942], [72.14736176, 21.95541763], [72.1470871, 21.95541954], [72.1470871, 21.95486069], [72.14765167, 21.95486069], [72.14765167, 21.95514107], [72.14875031, 21.95514107], [72.14875031, 21.95541954], [72.14958191, 21.95541763], [72.14958191, 21.9556942], [72.1498642, 21.9556942], [72.1498642, 21.95597267], [72.15125275, 21.95597076], [72.15125275, 21.95625114], [72.15180206, 21.95625114], [72.15180206, 21.95652962], [72.15235901, 21.95652962], [72.15235901, 21.95680809], [72.15319824, 21.95680618], [72.15319824, 21.95708275], [72.15374756, 21.95708084], [72.15374756, 21.95736122], [72.1554184, 21.95736122], [72.1554184, 21.95708084], [72.15597534, 21.95708275], [72.15597534, 21.95736122], [72.1598587, 21.95736122], [72.1598587, 21.95708084], [72.16124725, 21.95708275], [72.16124725, 21.95680618], [72.16179657, 21.95680809], [72.16179657, 21.95652962], [72.16208649, 21.95652962], [72.16208649, 21.95625114], [72.16319275, 21.95625114], [72.16319275, 21.95597076], [72.16374969, 21.95597267], [72.16374969, 21.9556942], [72.16486359, 21.9556942], [72.16486359, 21.95541763], [72.16568756, 21.95541954], [72.16568756, 21.95514107], [72.16625214, 21.95514107], [72.16625214, 21.95486069], [72.16707611, 21.95486069], [72.16707611, 21.95458984], [72.16764069, 21.95458984], [72.16764069, 21.95430946], [72.16819763, 21.95430946], [72.16819763, 21.95403099], [72.16847229, 21.95403099], [72.16847229, 21.95375061], [72.16902924, 21.95375061], [72.16902924, 21.95347023], [72.16958618, 21.95347214], [72.16958618, 21.95319366], [72.1701355, 21.95319366], [72.1701355, 21.95291519], [72.17069244, 21.95292091], [72.17069244, 21.95264053], [72.17153168, 21.95264053], [72.17153168, 21.95236015], [72.17180634, 21.95236015], [72.17180634, 21.95208359], [72.17208099, 21.95208359], [72.17208099, 21.95180321], [72.17236328, 21.95181084], [72.17236328, 21.95153046], [72.17263794, 21.95153046], [72.17263794, 21.95125008], [72.17292023, 21.95125008], [72.17292023, 21.9509697], [72.17346954, 21.9509716], [72.17346954, 21.95069313], [72.17375183, 21.95070076], [72.17375183, 21.95042038], [72.17402649, 21.95042038], [72.17402649, 21.94985962], [72.17430878, 21.94986153], [72.17430878, 21.94958115], [72.17458344, 21.94958115], [72.17458344, 21.94930649], [72.17485809, 21.94930267], [72.17485809, 21.94902802], [72.17514038, 21.94902992], [72.17514038, 21.94874954], [72.17542267, 21.94874954], [72.17541504, 21.94847107], [72.17569733, 21.94847107], [72.17569733, 21.9481945], [72.17597198, 21.9481945], [72.17597198, 21.94791603], [72.17652893, 21.94791985], [72.17652893, 21.94763947], [72.17708588, 21.94763947], [72.17708588, 21.9473629], [72.17736053, 21.9473629], [72.17736053, 21.94708252], [72.17763519, 21.94708252], [72.17763519, 21.94680595], [72.17791748, 21.94681168], [72.17791748, 21.94625092], [72.17874908, 21.94625092], [72.17874908, 21.94568825], [72.17903137, 21.94569397], [72.17903137, 21.9454174], [72.17930603, 21.94541931], [72.17930603, 21.94486046], [72.17986298, 21.94486046], [72.17986298, 21.94457817], [72.18013763, 21.94458389], [72.18013763, 21.94430542], [72.18041992, 21.94430923], [72.18041992, 21.94403076], [72.18096924, 21.94403076], [72.18096924, 21.94375038], [72.18125153, 21.94375038], [72.18125153, 21.94346809], [72.18152618, 21.94347191], [72.18152618, 21.94319534], [72.18180847, 21.94319916], [72.18180847, 21.94292068], [72.18208313, 21.94292068], [72.18208313, 21.94180107], [72.18235779, 21.94180679], [72.18235779, 21.94124985], [72.18264008, 21.94124985], [72.18264008, 21.94069099], [72.18291473, 21.94069672], [72.18291473, 21.94041443], [72.18319702, 21.94042015], [72.18319702, 21.94013977], [72.18347168, 21.94013977], [72.18347168, 21.93985939], [72.18402863, 21.9398613], [72.18402863, 21.93958282], [72.18486023, 21.93959045], [72.18486023, 21.93902969], [72.18514252, 21.93902969], [72.18514252, 21.93875122], [72.18541718, 21.93875122], [72.18541718, 21.93847084], [72.18624878, 21.93847275], [72.18624878, 21.93819427], [72.18736267, 21.93819427], [72.18736267, 21.9379158], [72.18818665, 21.93791962], [72.18818665, 21.93764114], [72.18930817, 21.93764114], [72.18930817, 21.93736076], [72.19013977, 21.93736076], [72.19013977, 21.93708038], [72.19319153, 21.93708038], [72.19319153, 21.93736076], [72.19374847, 21.93736076], [72.19374847, 21.93764114], [72.19430542, 21.93763924], [72.19430542, 21.93847275], [72.19458008, 21.93847275], [72.19458008, 21.93819427], [72.19708252, 21.93819427], [72.19708252, 21.93847275], [72.19735718, 21.93847084], [72.19735718, 21.93875122], [72.19790649, 21.93875122], [72.19790649, 21.93902969], [72.19847107, 21.93902969], [72.19847107, 21.93931007], [72.1987381, 21.93931007], [72.1987381, 21.93959045], [72.19985962, 21.93958282], [72.19985962, 21.9398613], [72.20124817, 21.9398613], [72.20124817, 21.93958282], [72.20180511, 21.93958282], [72.20180511, 21.9398613], [72.20236206, 21.93985939], [72.20236206, 21.94042015], [72.20263672, 21.94041443], [72.20263672, 21.94069672], [72.20402527, 21.94069672], [72.20402527, 21.94097137], [72.20430756, 21.94096947], [72.20430756, 21.94124985], [72.20485687, 21.94124985], [72.20485687, 21.94153023], [72.20541382, 21.94152641], [72.20541382, 21.94180679], [72.20569611, 21.94180679], [72.20569611, 21.94208336], [72.20597076, 21.94208336], [72.20597076, 21.94236183], [72.20625305, 21.94235992], [72.20625305, 21.94264984], [72.20652771, 21.94264984], [72.20652771, 21.94292068], [72.20680237, 21.94292068], [72.20680237, 21.94319916], [72.20735931, 21.94319534], [72.20735931, 21.94347191], [72.20791626, 21.94347191], [72.20791626, 21.94375038], [72.20874786, 21.94375038], [72.20874786, 21.94430923], [72.20930481, 21.94430542], [72.20930481, 21.94458389], [72.2095871, 21.94457817], [72.2095871, 21.94486046], [72.21013641, 21.94486046], [72.21013641, 21.94514084], [72.2104187, 21.94514084], [72.2104187, 21.94541931], [72.21013641, 21.9454174], [72.21013641, 21.94569397], [72.2104187, 21.94569397], [72.2104187, 21.94597244], [72.2106781, 21.94597054], [72.2106781, 21.94652939], [72.21125031, 21.94652748], [72.21125031, 21.94708252], [72.21152496, 21.94708252], [72.21152496, 21.9473629], [72.21208191, 21.9473629], [72.21208191, 21.94763947], [72.21235657, 21.94763947], [72.21235657, 21.94791985], [72.21291351, 21.94791603], [72.21291351, 21.9481945], [72.2131958, 21.9481945], [72.2131958, 21.94847107], [72.21373749, 21.94846153], [72.21373749, 21.94874954], [72.2140274, 21.94874954], [72.2140274, 21.94846153], [72.2179184, 21.94847107], [72.2179184, 21.94791603], [72.21902466, 21.94791603], [72.21902466, 21.9481945], [72.2195816, 21.9481945], [72.2195816, 21.94791603], [72.22013855, 21.94791985], [72.22013855, 21.94763947], [72.22041321, 21.94763947], [72.22041321, 21.9473629], [72.22097015, 21.9473629], [72.22097015, 21.94652939], [72.22125244, 21.94652939], [72.22125244, 21.94625092], [72.2215271, 21.94625092], [72.2215271, 21.94597054], [72.22180176, 21.94597244], [72.22180176, 21.94569397], [72.22208405, 21.94569397], [72.22208405, 21.9454174], [72.2223587, 21.94541931], [72.2223587, 21.94486046], [72.22264099, 21.94486046], [72.22264099, 21.94430923], [72.22293091, 21.94430923], [72.22293091, 21.94403076], [72.22319794, 21.94403076], [72.22319794, 21.94346809], [72.2234726, 21.94347191], [72.2234726, 21.94319534], [72.22374725, 21.94319916], [72.22374725, 21.94292068], [72.22402954, 21.94292068], [72.22402954, 21.94264984], [72.22429657, 21.94264984], [72.22429657, 21.94207954], [72.22458649, 21.94208336], [72.22458649, 21.94180679], [72.22486115, 21.94180679], [72.22486115, 21.94152641], [72.2251358, 21.94153023], [72.2251358, 21.94124985], [72.22541809, 21.94124985], [72.22541809, 21.94096947], [72.22569275, 21.94097137], [72.22569275, 21.9398613], [72.22597504, 21.9398613], [72.22597504, 21.93930435], [72.22624969, 21.93931007], [72.22624969, 21.93847084], [72.22652435, 21.93847275], [72.22652435, 21.93763924], [72.22680664, 21.93764114], [72.22680664, 21.93736076], [72.2270813, 21.93736076], [72.2270813, 21.93625069], [72.22735596, 21.93625069], [72.22735596, 21.93569183], [72.22763824, 21.93569374], [72.22763824, 21.9351387], [72.2279129, 21.93514061], [72.2279129, 21.93486023], [72.22820282, 21.93486023], [72.22819519, 21.93347168], [72.2279129, 21.93347168], [72.2279129, 21.93319511], [72.22820282, 21.93320274], [72.22820282, 21.93292046], [72.22846985, 21.93292046], [72.22846985, 21.9323616], [72.22875214, 21.9323616], [72.22875214, 21.93152809], [72.22902679, 21.93152809], [72.22902679, 21.93097115], [72.22930908, 21.93097305], [72.22930908, 21.93069458], [72.22958374, 21.93069458], [72.22958374, 21.93041611], [72.2298584, 21.93041992], [72.2298584, 21.92930984], [72.23014069, 21.92930984], [72.23014069, 21.92902946], [72.23042297, 21.92902946], [72.23042297, 21.92847061], [72.23069763, 21.92847252], [72.23069763, 21.9268074], [72.23097229, 21.92681122], [72.23097229, 21.92653084], [72.23181152, 21.92653084], [72.23181152, 21.92625046], [72.23208618, 21.92625046], [72.23208618, 21.92597198], [72.23236084, 21.92597198], [72.23236084, 21.92569351], [72.2326355, 21.92569351], [72.2326355, 21.92541695], [72.23291779, 21.92542076], [72.23291779, 21.92514038], [72.23319244, 21.92514038], [72.23319244, 21.92457962], [72.23347473, 21.92458344], [72.23347473, 21.92374992], [72.23374939, 21.92374992], [72.23374939, 21.92346954], [72.23402405, 21.92347145], [72.23402405, 21.92319489], [72.23430634, 21.92319489], [72.23430634, 21.92291641], [72.23458099, 21.92292023], [72.23458099, 21.92263985], [72.23487091, 21.92263985], [72.23487091, 21.92235947], [72.23513794, 21.92236137], [72.23513794, 21.9220829], [72.23542023, 21.9220829], [72.23542023, 21.92152786], [72.23569489, 21.92152786], [72.23569489, 21.92124939], [72.23625183, 21.92124939], [72.23625183, 21.92097282], [72.23652649, 21.92097282], [72.23652649, 21.92069435], [72.23680878, 21.92069435], [72.23680878, 21.92041588], [72.23764038, 21.92041969], [72.23764038, 21.91986084], [72.23819733, 21.91986084], [72.23819733, 21.91957855], [72.23847198, 21.91958237], [72.23847198, 21.9193058], [72.23874664, 21.91930962], [72.23874664, 21.91902924], [72.23902893, 21.91902924], [72.23902893, 21.91875076], [72.23958588, 21.91875076], [72.23958588, 21.91848183], [72.24041748, 21.91848183], [72.24041748, 21.91791916], [72.2409668, 21.91791916], [72.2409668, 21.91764069], [72.24124908, 21.91764069], [72.24124908, 21.91736031], [72.24153137, 21.91736031], [72.24153137, 21.91707993], [72.24180603, 21.91708374], [72.24180603, 21.91680527], [72.24208069, 21.91680908], [72.24208069, 21.91653061], [72.24236298, 21.91653061], [72.24236298, 21.91596985], [72.24263763, 21.91597176], [72.24263763, 21.91541862], [72.24291992, 21.91542053], [72.24291992, 21.91485977], [72.24319458, 21.91486168], [72.24319458, 21.91430473], [72.24346924, 21.91430473], [72.24346924, 21.91402626], [72.24375153, 21.91403008], [72.24375153, 21.91374969], [72.24404144, 21.91374969], [72.24402618, 21.91319656], [72.24430847, 21.91319656], [72.24430847, 21.91291428], [72.24458313, 21.91292], [72.24458313, 21.91263962], [72.24485779, 21.91263962], [72.24485779, 21.9123497], [72.24514008, 21.91236115], [72.24514008, 21.91152763], [72.2454071, 21.91152954], [72.2454071, 21.91097069], [72.24569702, 21.9109726], [72.24569702, 21.91069221], [72.24597168, 21.91069221], [72.24597168, 21.91041756], [72.24624634, 21.91041946], [72.24624634, 21.91014099], [72.24652863, 21.91014099], [72.24652863, 21.90986061], [72.24681091, 21.90986061], [72.24680328, 21.90930557], [72.24710083, 21.90930939], [72.24710083, 21.90847015], [72.24736023, 21.90847206], [72.24736023, 21.90791702], [72.24764252, 21.90792274], [72.24764252, 21.90764046], [72.24791718, 21.90764046], [72.24791718, 21.90681267], [72.24819183, 21.90681267], [72.24819183, 21.90597153], [72.24847412, 21.90597153], [72.24847412, 21.90513992], [72.24874878, 21.90513992], [72.24874878, 21.90457916], [72.24903107, 21.90458298], [72.24903107, 21.90319443], [72.24930573, 21.90319443], [72.24930573, 21.90263939], [72.24958038, 21.90263939], [72.24958038, 21.90236092], [72.24984741, 21.90236092], [72.24984741, 21.90180969], [72.25013733, 21.90180969], [72.25013733, 21.90153122], [72.25041962, 21.90153122], [72.25041962, 21.90125084], [72.25068665, 21.90125084], [72.25068665, 21.90097046], [72.25096893, 21.90097237], [72.25096893, 21.90069389], [72.25125122, 21.90069389], [72.25125122, 21.90013885], [72.25152588, 21.90014076], [72.25152588, 21.89958], [72.25208282, 21.89958572], [72.25208282, 21.89902687], [72.25235748, 21.89903069], [72.25235748, 21.89846992], [72.25263977, 21.89847183], [72.25263977, 21.89791679], [72.2529068, 21.89792061], [72.2529068, 21.89735031], [72.25319672, 21.89736176], [72.25319672, 21.89652824], [72.25347137, 21.89653015], [72.25347137, 21.89569283], [72.25375366, 21.89569473], [72.25375366, 21.89458275], [72.25402832, 21.89458275], [72.25402832, 21.89402771], [72.25430298, 21.89402962], [72.25430298, 21.89347267], [72.25458527, 21.89347267], [72.25458527, 21.8931942], [72.25485992, 21.8931942], [72.25485992, 21.89263916], [72.25514221, 21.89263916], [72.25514221, 21.8920784], [72.25541687, 21.89208412], [72.25541687, 21.89125061], [72.25569153, 21.89125061], [72.25569153, 21.89068985], [72.25597382, 21.89069366], [72.25597382, 21.89013863], [72.25624847, 21.89014053], [72.25624847, 21.88875008], [72.25653076, 21.88875008], [72.25653076, 21.88735962], [72.25680542, 21.88736153], [72.25680542, 21.88624954], [72.25708008, 21.88624954], [72.25708008, 21.88513947], [72.25736237, 21.88513947], [72.25736237, 21.88486099], [72.25708008, 21.88486099], [72.25708008, 21.88402939], [72.25736237, 21.88402939], [72.25736237, 21.88347054], [72.25763702, 21.88347244], [72.25763702, 21.88319206], [72.25791931, 21.88319206], [72.25791931, 21.88236046], [72.25818634, 21.88237], [72.25818634, 21.88097191], [72.25791931, 21.88097191], [72.25791931, 21.88069534], [72.25818634, 21.88070107], [72.25818634, 21.87735748], [72.25791931, 21.8773613], [72.25791931, 21.87624741], [72.25763702, 21.87624741], [72.25763702, 21.87541771], [72.25736237, 21.87541962], [72.25736237, 21.87430954], [72.25763702, 21.87430954], [72.25763702, 21.87375069], [72.25736237, 21.87375069], [72.25736237, 21.87318039], [72.25708008, 21.87319374], [72.25708008, 21.87208366], [72.25680542, 21.87208366], [72.25680542, 21.87152863], [72.25653076, 21.87153053], [72.25653076, 21.87096977], [72.25624847, 21.87097168], [72.25624847, 21.87013817], [72.25598145, 21.87014008], [72.25598145, 21.8698597], [72.25569153, 21.8698616], [72.25569153, 21.86930466], [72.25597382, 21.86930466], [72.25597382, 21.8670826], [72.25569153, 21.8670826], [72.25569153, 21.86486053], [72.25541687, 21.86486053], [72.25541687, 21.86403084], [72.25514221, 21.86403084], [72.25514221, 21.86292076], [72.25485992, 21.86292076], [72.25485992, 21.86264038], [72.25514221, 21.86264038], [72.25514221, 21.85931015], [72.25485992, 21.85931015], [72.25485992, 21.85902977], [72.25514221, 21.85902977], [72.25514221, 21.85764122], [72.25485992, 21.85764122], [72.25485992, 21.85680962], [72.25514221, 21.85680962], [72.25514221, 21.85625076], [72.25541687, 21.85625076], [72.25541687, 21.85486031], [72.25569153, 21.85486031], [72.25569153, 21.85264015], [72.25598145, 21.85264015], [72.25598145, 21.85236168], [72.25624847, 21.85236168], [72.25624847, 21.85208321], [72.25597382, 21.85208321], [72.25597382, 21.85180473], [72.25624847, 21.85180473], [72.25624847, 21.85097313], [72.25597382, 21.85097313], [72.25597382, 21.85069466], [72.25624847, 21.85069466], [72.25624847, 21.84930611], [72.25597382, 21.84930611], [72.25597382, 21.84902954], [72.25624847, 21.84902954], [72.25624847, 21.84791946], [72.25653076, 21.84791946], [72.25653076, 21.84680939], [72.25681305, 21.84680939], [72.25681305, 21.84542084], [72.25708008, 21.84542084], [72.25708008, 21.84403038], [72.25736237, 21.84403038], [72.25736237, 21.84346962], [72.25708008, 21.84347153], [72.25708008, 21.84291649], [72.25736237, 21.8429203], [72.25736237, 21.84208107], [72.25763702, 21.84208107], [72.25763702, 21.84041595], [72.25791931, 21.84041977], [72.25791931, 21.8393116], [72.25818634, 21.8393116], [72.25818634, 21.83818817], [72.25846863, 21.83819389], [72.25846863, 21.83708382], [72.25875092, 21.83708382], [72.25875092, 21.83263969], [72.25904083, 21.83263969], [72.25902557, 21.83236122], [72.25875092, 21.83236122], [72.25875092, 21.83126068], [72.25904083, 21.83126068], [72.25904083, 21.82986069], [72.25875092, 21.82986069], [72.25875092, 21.82930946], [72.25904083, 21.82930946], [72.25904083, 21.8290329], [72.25930786, 21.8290329], [72.25930786, 21.82457924], [72.25902557, 21.82458305], [72.25902557, 21.82236099], [72.25930786, 21.82236099], [72.25930786, 21.81625938], [72.25904083, 21.81625938], [72.25904083, 21.81431007], [72.25930786, 21.81431007], [72.25930786, 21.81347275], [72.25902557, 21.81347275], [72.25902557, 21.8129158], [72.25875092, 21.81291962], [72.25875092, 21.81236076], [72.25846863, 21.81236076], [72.25846863, 21.81180954], [72.25904083, 21.81180954], [72.25904083, 21.80957985], [72.25875092, 21.80958366], [72.25875092, 21.80708313], [72.25904083, 21.80709076], [72.25904083, 21.80680084], [72.25875092, 21.80680466], [72.25875092, 21.8054142], [72.25846863, 21.80541992], [72.25846863, 21.80513954], [72.25875092, 21.80513954], [72.25875092, 21.80402946], [72.25846863, 21.80402946], [72.25846863, 21.8006916], [72.25875092, 21.80069351], [72.25875092, 21.79652977], [72.25904083, 21.79652977], [72.25904083, 21.79430962], [72.25930786, 21.79430962], [72.25930786, 21.79403114], [72.25904083, 21.79403114], [72.25904083, 21.79375076], [72.25930786, 21.79375076], [72.25930786, 21.79236031], [72.25958252, 21.79236031], [72.25958252, 21.79014015], [72.25985718, 21.79014015], [72.25985718, 21.78736115], [72.26013947, 21.78736115], [72.26013947, 21.78430939], [72.26040649, 21.78430939], [72.26040649, 21.78346825], [72.26069641, 21.78347206], [72.26069641, 21.78236198], [72.26097107, 21.78236198], [72.26097107, 21.78152847], [72.26125336, 21.78153038], [72.26125336, 21.78014946], [72.26152802, 21.78014946], [72.26152802, 21.77874947], [72.26178741, 21.77874947], [72.26178741, 21.77819061], [72.26208496, 21.77819443], [72.26208496, 21.77736092], [72.26235962, 21.77736092], [72.26235962, 21.77653122], [72.26264191, 21.77653122], [72.26264191, 21.77569008], [72.26291656, 21.77569389], [72.26291656, 21.77458382], [72.26319122, 21.77458382], [72.26319122, 21.77375031], [72.26346588, 21.77375031], [72.26346588, 21.77292252], [72.26374817, 21.77292252], [72.26374817, 21.77208138], [72.26403046, 21.77208328], [72.26403046, 21.7709713], [72.26431274, 21.77098083], [72.26431274, 21.77069092], [72.26457977, 21.77069473], [72.26457977, 21.76986122], [72.2648468, 21.76986122], [72.2648468, 21.76902962], [72.26513672, 21.76902962], [72.26513672, 21.76791954], [72.26541901, 21.76791954], [72.26541901, 21.76653099], [72.26568604, 21.76653099], [72.26568604, 21.76597023], [72.26597595, 21.76597214], [72.26597595, 21.76569366], [72.26625061, 21.76569366], [72.26625061, 21.76513863], [72.2665329, 21.76514053], [72.2665329, 21.76457977], [72.26680756, 21.76458359], [72.26680756, 21.76402855], [72.26708221, 21.76403046], [72.26708221, 21.76355934], [72.26708221, 21.7634716], [72.2673645, 21.7634716], [72.2673645, 21.76263809], [72.26763916, 21.76264], [72.26763916, 21.76208115], [72.26791382, 21.76208115], [72.26791382, 21.76180649], [72.26819611, 21.76178932], [72.26819611, 21.76124954], [72.26847076, 21.76124954], [72.26847076, 21.76042175], [72.26875305, 21.76042175], [72.26875305, 21.75958061], [72.26902771, 21.75958252], [72.26902771, 21.75902748], [72.26930237, 21.75904274], [72.26930237, 21.75818825], [72.26958466, 21.75819397], [72.26958466, 21.75764084], [72.26985931, 21.75764084], [72.26985931, 21.75707817], [72.2701416, 21.75708389], [72.2701416, 21.75541878], [72.27041626, 21.75542068], [72.27041626, 21.75346947], [72.2701416, 21.75347137], [72.2701416, 21.75319672], [72.27041626, 21.75319672], [72.27041626, 21.75291443], [72.2701416, 21.75292015], [72.2701416, 21.75235939], [72.27041626, 21.7523613], [72.27041626, 21.75180435], [72.27069092, 21.75181007], [72.27069092, 21.75152969], [72.27098083, 21.75152969], [72.27098083, 21.75041962], [72.27069092, 21.75041962], [72.27069092, 21.74985123], [72.27041626, 21.74986076], [72.27041626, 21.74819374], [72.2701416, 21.74819374], [72.2701416, 21.7476387], [72.26985931, 21.74764061], [72.26985931, 21.74708176], [72.26958466, 21.74708366], [72.26958466, 21.74652863], [72.26930237, 21.74653053], [72.26930237, 21.74625015], [72.26902771, 21.74625015], [72.26902771, 21.74597168], [72.26875305, 21.74597168], [72.26875305, 21.74569511], [72.26847076, 21.74570274], [72.26847076, 21.74514008], [72.26819611, 21.74514008], [72.26819611, 21.7448597], [72.26791382, 21.7448616], [72.26791382, 21.74430466], [72.26763916, 21.74430466], [72.26763916, 21.74402809], [72.26735687, 21.74403954], [72.26735687, 21.74374962], [72.26708221, 21.74374962], [72.26708221, 21.74347115], [72.26680756, 21.74347305], [72.26680756, 21.74319458], [72.26625061, 21.74319458], [72.26625061, 21.74291611], [72.26597595, 21.74291992], [72.26597595, 21.74180984], [72.26568604, 21.74180984], [72.26568604, 21.74152946], [72.26541901, 21.74152946], [72.26541901, 21.74125099], [72.26513672, 21.74125099], [72.26513672, 21.74097061], [72.26486206, 21.74097252], [72.26486206, 21.74069595], [72.26457977, 21.74069595], [72.26457977, 21.74041748], [72.26347351, 21.74041748], [72.26347351, 21.74069595], [72.26319122, 21.74069023], [72.26319122, 21.74125099], [72.26291656, 21.74125099], [72.26291656, 21.74180984], [72.26264191, 21.74180984], [72.26264191, 21.74236107], [72.26235962, 21.74236107], [72.26235962, 21.74263954], [72.26208496, 21.74263954], [72.26208496, 21.74319458], [72.26180267, 21.74319458], [72.26180267, 21.74347305], [72.26152802, 21.74347115], [72.26152802, 21.74403954], [72.26125336, 21.74402809], [72.26125336, 21.74430466], [72.26113892, 21.74430466], [72.26097107, 21.74430466], [72.26097107, 21.7448616], [72.26069641, 21.7448597], [72.26069641, 21.74514008], [72.26041412, 21.74513817], [72.26041412, 21.74708366], [72.26013947, 21.74708366], [72.26013947, 21.74819374], [72.25985718, 21.74819183], [72.25985718, 21.74930954], [72.25958252, 21.74930573], [72.25958252, 21.74986076], [72.25930786, 21.74985123], [72.25930786, 21.75041962], [72.25902557, 21.7504158], [72.25902557, 21.75069237], [72.25846863, 21.75069046], [72.25846863, 21.75125122], [72.25819397, 21.75124931], [72.25819397, 21.75208282], [72.25791931, 21.75208282], [72.25791931, 21.7523613], [72.25763702, 21.7523613], [72.25763702, 21.75319672], [72.25736237, 21.75319099], [72.25736237, 21.75374985], [72.25708008, 21.75374985], [72.25708008, 21.75403023], [72.25653076, 21.75402832], [72.25653076, 21.75430679], [72.25624847, 21.75430679], [72.25624847, 21.75458336], [72.25653076, 21.75457954], [72.25653076, 21.7551403], [72.25624847, 21.7551403], [72.25624847, 21.75542068], [72.25598145, 21.75542068], [72.25598145, 21.75569916], [72.25569153, 21.75569916], [72.25569153, 21.75597763], [72.25598145, 21.75597763], [72.25598145, 21.75680923], [72.25569153, 21.75680542], [72.25569153, 21.75708389], [72.25541687, 21.75708389], [72.25541687, 21.75819397], [72.25514221, 21.75818825], [72.25514221, 21.75875092], [72.25485992, 21.75875092], [72.25485992, 21.75904274], [72.2545929, 21.75904274], [72.2545929, 21.75931168], [72.25430298, 21.75931168], [72.25430298, 21.76013947], [72.25402832, 21.76013947], [72.25402832, 21.76042175], [72.25319672, 21.76041603], [72.25319672, 21.7606945], [72.25291443, 21.7606945], [72.25291443, 21.76097107], [72.25263977, 21.76097107], [72.25263977, 21.76292038], [72.25235748, 21.76291656], [72.25235748, 21.7634716], [72.25208282, 21.7634697], [72.25208282, 21.76403046], [72.25180817, 21.76403046], [72.25180817, 21.76680946], [72.25152588, 21.76680756], [72.25152588, 21.76708412], [72.25125122, 21.76708031], [72.25125122, 21.76764107], [72.25096893, 21.76763916], [72.25096893, 21.7681942], [72.25068665, 21.76819038], [72.25068665, 21.76902962], [72.25041962, 21.76902962], [72.25041962, 21.77069473], [72.25013733, 21.77069473], [72.25013733, 21.77180481], [72.24986267, 21.77180481], [72.24986267, 21.77347183], [72.24958038, 21.77347183], [72.24958038, 21.77402687], [72.24930573, 21.77402687], [72.24931335, 21.77486038], [72.24903107, 21.77486038], [72.24903107, 21.77569389], [72.24930573, 21.77569389], [72.24931335, 21.77763939], [72.24903107, 21.77763939], [72.24903107, 21.77958298], [72.24874878, 21.77958107], [72.24874878, 21.78375053], [72.24847412, 21.78375053], [72.24847412, 21.78458405], [72.24874878, 21.78458405], [72.24874878, 21.7859726], [72.24846649, 21.78596115], [72.24846649, 21.78763962], [72.24819183, 21.78763962], [72.24819183, 21.78930473], [72.24764252, 21.78930283], [72.24764252, 21.79014015], [72.24736023, 21.79014015], [72.24736023, 21.79042053], [72.24708557, 21.79041672], [72.24708557, 21.79097176], [72.24652863, 21.79096985], [72.24652863, 21.79153061], [72.24624634, 21.79153061], [72.24624634, 21.79181099], [72.24569702, 21.79181099], [72.24569702, 21.79236031], [72.24514008, 21.79236031], [72.24514008, 21.79264069], [72.24458313, 21.79264069], [72.24458313, 21.79292107], [72.24402618, 21.79291534], [72.24402618, 21.79319382], [72.24346924, 21.79319382], [72.24346924, 21.79347229], [72.24263763, 21.79347038], [72.24263763, 21.79375076], [72.24180603, 21.79375076], [72.24180603, 21.79403114], [72.24067688, 21.79403114], [72.24067688, 21.79430962], [72.23986053, 21.79430771], [72.23986053, 21.79458427], [72.23929596, 21.79458046], [72.23929596, 21.79486084], [72.23874664, 21.79486084], [72.23874664, 21.79515076], [72.23790741, 21.79515076], [72.23790741, 21.79541969], [72.23735809, 21.79541779], [72.23735809, 21.79569435], [72.23708344, 21.79569435], [72.23708344, 21.79597282], [72.23680878, 21.79597092], [72.23680878, 21.79624939], [72.23652649, 21.79624939], [72.23652649, 21.79652977], [72.23596954, 21.79652977], [72.23596954, 21.79597092], [72.23625183, 21.79597282], [72.23625183, 21.79541779], [72.23596954, 21.79541969], [72.23596954, 21.79458046], [72.23430634, 21.79458427], [72.23430634, 21.79430771], [72.23402405, 21.79430771], [72.23402405, 21.79458427], [72.23291779, 21.79458046], [72.23291779, 21.79486084], [72.23236084, 21.79486084], [72.23236084, 21.79515076], [72.23210144, 21.79515076], [72.23210144, 21.79541969], [72.23180389, 21.79541779], [72.23180389, 21.79569435], [72.23041534, 21.79569435], [72.23041534, 21.79597282], [72.22957611, 21.79597092], [72.22957611, 21.79624939], [72.22902679, 21.79624939], [72.22902679, 21.79652977], [72.22846985, 21.79652977], [72.22846985, 21.79680824], [72.2279129, 21.79680634], [72.2279129, 21.7970829], [72.22736359, 21.7970829], [72.22736359, 21.79736137], [72.2270813, 21.79735756], [72.2270813, 21.79763985], [72.22624969, 21.79763985], [72.22624969, 21.79791832], [72.22597504, 21.79791641], [72.22597504, 21.79819489], [72.22541809, 21.79819489], [72.22541809, 21.79847145], [72.22486115, 21.79846764], [72.22486115, 21.79875183], [72.22458649, 21.79875183], [72.22458649, 21.7990303], [72.22402954, 21.7990303], [72.22402954, 21.79931259], [72.22374725, 21.79930496], [72.22374725, 21.79958344], [72.22319794, 21.79958344], [72.22319794, 21.79986191], [72.22293091, 21.79986191], [72.22293091, 21.80014038], [72.22264099, 21.80014038], [72.22264099, 21.80042267], [72.22208405, 21.80041695], [72.22207642, 21.8006916], [72.2215271, 21.80069542], [72.2215271, 21.80097008], [72.2206955, 21.80097008], [72.22070313, 21.80125046], [72.22041321, 21.80125046], [72.22041321, 21.80153275], [72.22013855, 21.80153275], [72.22013855, 21.80181122], [72.21875, 21.8018055], [72.21875, 21.80208206], [72.21847534, 21.80208206], [72.21848297, 21.80236053], [72.21819305, 21.80236053], [72.21819305, 21.80264282], [72.2179184, 21.80264282], [72.2179184, 21.80291939], [72.21763611, 21.80291748], [72.21763611, 21.80347252], [72.21708679, 21.80347061], [72.21708679, 21.80375099], [72.21652985, 21.80375099], [72.21652985, 21.80402946], [72.21624756, 21.80402946], [72.21624756, 21.80431938], [72.2159729, 21.80430412], [72.2159729, 21.8045826], [72.21569824, 21.80458069], [72.21569824, 21.80486107], [72.21541595, 21.80486107], [72.21541595, 21.80513954], [72.2151413, 21.80513954], [72.2151413, 21.80541992], [72.21485901, 21.8054142], [72.21485901, 21.80569649], [72.21457672, 21.80569077], [72.21457672, 21.80624962], [72.21430206, 21.80624962], [72.21430206, 21.80653], [72.2140274, 21.80653], [72.2140274, 21.80709076], [72.21375275, 21.80708313], [72.21375275, 21.8073616], [72.21347046, 21.8073597], [72.21347046, 21.80764008], [72.2131958, 21.80764008], [72.2131958, 21.80792046], [72.21290588, 21.80792046], [72.21290588, 21.80903053], [72.21263885, 21.80903053], [72.21263885, 21.80986023], [72.2123642, 21.80986023], [72.2123642, 21.81097221], [72.21208191, 21.8109684], [72.21208191, 21.81431007], [72.21180725, 21.81430626], [72.21180725, 21.8148613], [72.21152496, 21.8148613], [72.21152496, 21.81569481], [72.21125031, 21.8156929], [72.21125031, 21.81653023], [72.21097565, 21.81652832], [72.21097565, 21.81736183], [72.2106781, 21.81735992], [72.2106781, 21.8176403], [72.2104187, 21.8176403], [72.2104187, 21.81820107], [72.21013641, 21.81819344], [72.21013641, 21.81847191], [72.20986176, 21.81847], [72.20986176, 21.81903076], [72.2095871, 21.81903076], [72.2095871, 21.81932068], [72.20929718, 21.81932068], [72.20929718, 21.81986046], [72.20903015, 21.81986046], [72.20903015, 21.82069588], [72.20874786, 21.82069588], [72.20874786, 21.82097244], [72.20735931, 21.82097054], [72.20735931, 21.82125092], [72.20707703, 21.82125092], [72.20707703, 21.82152939], [72.20680237, 21.82152557], [72.20680237, 21.82208252], [72.20652771, 21.82207108], [72.20652771, 21.82236099], [72.20597076, 21.82236099], [72.20597076, 21.82263947], [72.20540619, 21.82263947], [72.20540619, 21.82291985], [72.2048645, 21.82291794], [72.2048645, 21.8231945], [72.20458221, 21.8231945], [72.20458221, 21.82347298], [72.20430756, 21.82347107], [72.20430756, 21.82374954], [72.2040329, 21.82374954], [72.2040329, 21.82402992], [72.20347595, 21.82402992], [72.20347595, 21.8243084], [72.20319366, 21.82430649], [72.20319366, 21.82486153], [72.20263672, 21.82486153], [72.20263672, 21.82513809], [72.20153046, 21.82513046], [72.20153046, 21.82542038], [72.20096588, 21.82542038], [72.20096588, 21.82570267], [72.20041656, 21.82569504], [72.20041656, 21.8259716], [72.20014191, 21.8259716], [72.20014191, 21.82625008], [72.19985962, 21.82625008], [72.19985962, 21.82653046], [72.1987381, 21.82653046], [72.1987381, 21.82681274], [72.19819641, 21.82680511], [72.19819641, 21.82708359], [72.19708252, 21.82708359], [72.19708252, 21.82736015], [72.1957016, 21.82736015], [72.1957016, 21.82764053], [72.19431305, 21.82764053], [72.19431305, 21.82792282], [72.1920929, 21.82792282], [72.1920929, 21.82819939], [72.18930817, 21.82819939], [72.18930817, 21.82792282], [72.18708038, 21.82792282], [72.18708038, 21.82764053], [72.18653107, 21.82764053], [72.18653107, 21.82736015], [72.18541718, 21.82736015], [72.18541718, 21.82680511], [72.18514252, 21.82681274], [72.18514252, 21.82653046], [72.1845932, 21.82653046], [72.1845932, 21.82625008], [72.18402863, 21.82625008], [72.18402863, 21.8259716], [72.18374634, 21.8259716], [72.18374634, 21.82569504], [72.18347168, 21.82570267], [72.18347168, 21.82513046], [72.18319702, 21.82513809], [72.18319702, 21.82486153], [72.18291473, 21.82486153], [72.18291473, 21.82374954], [72.1837616, 21.82374954], [72.1837616, 21.82402992], [72.18430328, 21.82402992], [72.18430328, 21.82458305], [72.18458557, 21.82458305], [72.18458557, 21.82513809], [72.18486023, 21.82513046], [72.18486023, 21.82570267], [72.18514252, 21.82569504], [72.18514252, 21.8259716], [72.18541718, 21.8259716], [72.18541718, 21.82625008], [72.18624878, 21.82625008], [72.18624878, 21.82653046], [72.18763733, 21.82653046], [72.18763733, 21.82681274], [72.18930817, 21.82680511], [72.18930817, 21.82708359], [72.19486237, 21.82708359], [72.19486237, 21.82680511], [72.19596863, 21.82681274], [72.19596863, 21.82653046], [72.19680786, 21.82653046], [72.19680786, 21.82625008], [72.19735718, 21.82625008], [72.19735718, 21.8259716], [72.19791412, 21.8259716], [72.19791412, 21.82569504], [72.19902802, 21.82570267], [72.19902802, 21.82542038], [72.19959259, 21.82542038], [72.19959259, 21.82513046], [72.20014191, 21.82513809], [72.20014191, 21.82486153], [72.20069122, 21.82486153], [72.20069122, 21.82458305], [72.20097351, 21.82458305], [72.20097351, 21.82430649], [72.20153046, 21.82430077], [72.20153046, 21.82402992], [72.20179749, 21.82402992], [72.20179749, 21.82374954], [72.20236206, 21.82374954], [72.20236206, 21.82347107], [72.20291901, 21.82347298], [72.20291901, 21.8231945], [72.20319366, 21.8231945], [72.20319366, 21.82291794], [72.2040329, 21.82291985], [72.2040329, 21.82263947], [72.20458221, 21.82263947], [72.20458221, 21.82236099], [72.20513916, 21.82236099], [72.20513916, 21.82207108], [72.20541382, 21.82208252], [72.20541382, 21.82180786], [72.20569611, 21.82180977], [72.20569611, 21.82152939], [72.20597076, 21.82152939], [72.20597076, 21.82125092], [72.20625305, 21.82125092], [72.20625305, 21.82097054], [72.20680237, 21.82097244], [72.20680237, 21.8204155], [72.20707703, 21.82042122], [72.20707703, 21.82014084], [72.20735931, 21.82014084], [72.20735931, 21.81986046], [72.2076416, 21.81986046], [72.2076416, 21.81958008], [72.20791626, 21.8195858], [72.20791626, 21.81930733], [72.20819092, 21.81932068], [72.20819092, 21.81820107], [72.20847321, 21.81820107], [72.20847321, 21.8176403], [72.20874786, 21.8176403], [72.20874786, 21.81707954], [72.20903015, 21.81708336], [72.20903015, 21.81652832], [72.20929718, 21.81653023], [72.20929718, 21.81458282], [72.2095871, 21.81458282], [72.2095871, 21.81263924], [72.20986176, 21.81263924], [72.20986176, 21.8109684], [72.21013641, 21.81097221], [72.21013641, 21.8101387], [72.2104187, 21.8101387], [72.2104187, 21.80958366], [72.21069336, 21.80958366], [72.21069336, 21.80791855], [72.21099091, 21.80792046], [72.21099091, 21.8073597], [72.21125031, 21.8073616], [72.21125031, 21.80652618], [72.21153259, 21.80653], [72.21153259, 21.80597115], [72.21208191, 21.80597305], [72.21208191, 21.80569649], [72.2123642, 21.80569649], [72.2123642, 21.80513954], [72.21263885, 21.80513954], [72.21263885, 21.80486107], [72.21290588, 21.80486107], [72.21290588, 21.80458069], [72.2131958, 21.8045826], [72.2131958, 21.80430412], [72.21347046, 21.80431938], [72.21347046, 21.80402946], [72.21373749, 21.80402946], [72.21373749, 21.80375099], [72.2140274, 21.80375099], [72.2140274, 21.80347061], [72.21430206, 21.80347252], [72.21430206, 21.80319214], [72.21458435, 21.80319214], [72.21458435, 21.80291748], [72.21485901, 21.80291939], [72.21485901, 21.80264282], [72.2151413, 21.80264282], [72.2151413, 21.80236053], [72.21541595, 21.80236053], [72.21541595, 21.80208015], [72.21624756, 21.80208206], [72.21624756, 21.8018055], [72.21652985, 21.80181122], [72.21652985, 21.80125046], [72.21708679, 21.80125046], [72.21708679, 21.80095863], [72.21736145, 21.80097008], [72.21736145, 21.80069351], [72.21819305, 21.80069351], [72.21819305, 21.80041695], [72.21875, 21.80042267], [72.21875, 21.80014038], [72.21930695, 21.80014038], [72.21930695, 21.79986191], [72.21986389, 21.79986191], [72.21986389, 21.79958344], [72.22013855, 21.79958344], [72.22013855, 21.79930496], [72.22041321, 21.79931259], [72.22041321, 21.7990303], [72.22070313, 21.7990303], [72.22070313, 21.79875183], [72.22097015, 21.79875183], [72.22097015, 21.79818916], [72.2215271, 21.79819489], [72.2215271, 21.79791641], [72.22180176, 21.79791832], [72.22180176, 21.79763985], [72.22207642, 21.79763985], [72.22207642, 21.79735756], [72.22291565, 21.79736137], [72.22291565, 21.7970829], [72.22319794, 21.7970829], [72.22319794, 21.79680634], [72.2234726, 21.79680824], [72.2234726, 21.79652977], [72.22402954, 21.79652977], [72.22402954, 21.79624939], [72.22458649, 21.79624939], [72.22458649, 21.79569054], [72.2251358, 21.79569435], [72.2251358, 21.79541779], [72.22541809, 21.79541969], [72.22541809, 21.79515076], [72.22596741, 21.79515076], [72.22596741, 21.79486084], [72.22624969, 21.79486084], [72.22624969, 21.79458046], [72.22680664, 21.79458237], [72.22680664, 21.79430771], [72.2270813, 21.79430962], [72.2270813, 21.79403114], [72.22763824, 21.79403114], [72.22763824, 21.79375076], [72.22820282, 21.79375076], [72.22819519, 21.79347229], [72.22902679, 21.79347229], [72.22902679, 21.79319382], [72.22958374, 21.79319382], [72.22958374, 21.79291534], [72.23042297, 21.79292107], [72.23042297, 21.79264069], [72.23097229, 21.79264069], [72.23097229, 21.79236031], [72.23319244, 21.79236031], [72.23319244, 21.79208946], [72.2334671, 21.79208946], [72.2334671, 21.79181099], [72.23542023, 21.79181099], [72.23542023, 21.79153061], [72.23568726, 21.79153061], [72.23568726, 21.79125023], [72.23625183, 21.79125023], [72.23625183, 21.79096985], [72.23652649, 21.79097176], [72.23652649, 21.79069328], [72.23707581, 21.79070091], [72.23707581, 21.79042053], [72.23764038, 21.79042053], [72.23764038, 21.79014015], [72.23819733, 21.79014015], [72.23819733, 21.78985977], [72.23847198, 21.78986168], [72.23847198, 21.78958321], [72.23874664, 21.78958321], [72.23874664, 21.78930473], [72.23930359, 21.78930473], [72.23930359, 21.78902817], [72.23958588, 21.78902817], [72.23958588, 21.78874969], [72.23986053, 21.78874969], [72.23986053, 21.78847122], [72.24013519, 21.78847122], [72.24013519, 21.78819466], [72.24041748, 21.78819466], [72.24041748, 21.78791618], [72.24067688, 21.78792191], [72.24067688, 21.78763962], [72.2409668, 21.78763962], [72.2409668, 21.78736115], [72.24124908, 21.78736115], [72.24124908, 21.78681183], [72.24153137, 21.78681183], [72.24153137, 21.7856884], [72.24180603, 21.78569412], [72.24180603, 21.78486061], [72.24208069, 21.78486061], [72.24208069, 21.78430939], [72.24236298, 21.78430939], [72.24236298, 21.78096962], [72.24263763, 21.78097153], [72.24263763, 21.77847481], [72.24291992, 21.77847481], [72.24291992, 21.77791405], [72.24263763, 21.77791977], [72.24263763, 21.77708054], [72.24291992, 21.77708244], [72.24291992, 21.77680588], [72.24263763, 21.77680969], [72.24263763, 21.77597046], [72.24291992, 21.77597237], [72.24291992, 21.77458382], [72.24319458, 21.77458382], [72.24319458, 21.77319527], [72.24346924, 21.7732029], [72.24346924, 21.77179909], [72.24375153, 21.77180481], [72.24375153, 21.77041626], [72.24430847, 21.77041817], [72.24430847, 21.77013969], [72.24402618, 21.77013969], [72.24402618, 21.76986122], [72.24430847, 21.76986122], [72.24430847, 21.76708031], [72.24458313, 21.76708412], [72.24458313, 21.76513863], [72.24430847, 21.76514053], [72.24430847, 21.76486015], [72.24402618, 21.76486206], [72.24402618, 21.76458359], [72.24375153, 21.76458359], [72.24375153, 21.76430321], [72.24346924, 21.76431084], [72.24346924, 21.76375008], [72.24430847, 21.76375008], [72.24430847, 21.7634697], [72.24485779, 21.7634716], [72.24485779, 21.76319313], [72.24514008, 21.76320076], [72.24514008, 21.76235962], [72.24541473, 21.76236153], [72.24541473, 21.76152802], [72.24569702, 21.76152992], [72.24569702, 21.76124954], [72.24597168, 21.76124954], [72.24597168, 21.76042175], [72.24569702, 21.76042175], [72.24569702, 21.75958061], [72.24597168, 21.75958252], [72.24597168, 21.75902748], [72.24624634, 21.75904274], [72.24624634, 21.75875092], [72.24652863, 21.75875092], [72.24652863, 21.75818825], [72.24624634, 21.75819397], [72.24624634, 21.75764084], [72.24652863, 21.75764084], [72.24652863, 21.75707817], [72.24680328, 21.75708389], [72.24680328, 21.75680542], [72.24710083, 21.75680923], [72.24710083, 21.75542068], [72.24736023, 21.75542068], [72.24736023, 21.75457954], [72.24764252, 21.75458336], [72.24764252, 21.75347137], [72.24736023, 21.75347137], [72.24736023, 21.7523613], [72.24708557, 21.7523613], [72.24708557, 21.75124931], [72.24736023, 21.75125122], [72.24736023, 21.75097084], [72.24791718, 21.75097275], [72.24791718, 21.7504158], [72.24819183, 21.75041962], [72.24819183, 21.75014114], [72.24846649, 21.75014114], [72.24846649, 21.74985123], [72.24874878, 21.74986076], [72.24874878, 21.74902725], [72.24903107, 21.74903107], [72.24903107, 21.74847031], [72.24930573, 21.74847221], [72.24930573, 21.74819374], [72.24958038, 21.74819374], [72.24958038, 21.7476387], [72.24984741, 21.74764061], [72.24984741, 21.74625015], [72.25013733, 21.74625015], [72.25013733, 21.74570274], [72.25041962, 21.74570274], [72.25041962, 21.74542236], [72.25068665, 21.74542236], [72.25068665, 21.74514008], [72.25096893, 21.74514008], [72.25096893, 21.74430084], [72.25125122, 21.74430466], [72.25125122, 21.74291611], [72.25152588, 21.74291992], [72.25152588, 21.74236107], [72.25180817, 21.74236107], [72.25180817, 21.74180984], [72.25208282, 21.74180984], [72.25208282, 21.74069023], [72.25235748, 21.74069595], [72.25235748, 21.7393074], [72.25263977, 21.73931122], [72.25263977, 21.73903084], [72.2529068, 21.73903084], [72.2529068, 21.73847008], [72.25319672, 21.73847198], [72.25319672, 21.73791695], [72.25347137, 21.73791695], [72.25347137, 21.73763847], [72.25374603, 21.73764038], [72.25374603, 21.73707962], [72.25402832, 21.73708344], [72.25402832, 21.7365284], [72.25430298, 21.7365303], [72.25430298, 21.73513985], [72.2545929, 21.73513985], [72.2545929, 21.73485184], [72.25485992, 21.73486137], [72.25485992, 21.73430634], [72.25514221, 21.73431015], [72.25514221, 21.73402977], [72.25541687, 21.73402977], [72.25541687, 21.73347282], [72.25569153, 21.73347282], [72.25569153, 21.73236084], [72.25598145, 21.73236084], [72.25597382, 21.7318058], [72.25624847, 21.73181152], [72.25624847, 21.73125076], [72.25653076, 21.73125076], [72.25653076, 21.72986031], [72.25681305, 21.72986031], [72.25680542, 21.72930527], [72.25708008, 21.72930908], [72.25708008, 21.72903061], [72.25736237, 21.72903061], [72.25736237, 21.72846985], [72.25763702, 21.72847176], [72.25763702, 21.72819519], [72.25791931, 21.72820091], [72.25791931, 21.72764015], [72.25818634, 21.72764015], [72.25818634, 21.72707939], [72.25846863, 21.72708321], [72.25846863, 21.72652626], [72.25875092, 21.72653008], [72.25875092, 21.7256794], [72.25902557, 21.72569656], [72.25902557, 21.72513962], [72.25930786, 21.72513962], [72.25930786, 21.72430992], [72.25958252, 21.72430992], [72.25958252, 21.72347069], [72.25986481, 21.7234726], [72.25986481, 21.72319221], [72.26013947, 21.72319221], [72.26013947, 21.72263908], [72.26040649, 21.7226429], [72.26040649, 21.72236061], [72.26069641, 21.72236061], [72.26069641, 21.72180939], [72.26097107, 21.72180939], [72.26097107, 21.72153282], [72.26125336, 21.72153282], [72.26125336, 21.72097015], [72.26152802, 21.72097015], [72.26152802, 21.72041702], [72.26178741, 21.72042274], [72.26178741, 21.72014046], [72.26207733, 21.72014046], [72.26207733, 21.7195816], [72.26235962, 21.71958351], [72.26235962, 21.71930504], [72.26264191, 21.71931267], [72.26264191, 21.71875191], [72.26291656, 21.71875191], [72.26291656, 21.71820259], [72.26319122, 21.71820259], [72.26319122, 21.7179184], [72.26346588, 21.7179184], [72.26346588, 21.71763992], [72.26374817, 21.71763992], [72.26374817, 21.71707916], [72.26403046, 21.71708298], [72.26403046, 21.71680641], [72.26431274, 21.71680832], [72.26431274, 21.71624947], [72.26457977, 21.71624947], [72.26457977, 21.71569061], [72.26486206, 21.71569443], [72.26486206, 21.71541786], [72.26541901, 21.71541977], [72.26541901, 21.71458054], [72.26597595, 21.71458244], [72.26597595, 21.71347237], [72.26625061, 21.71347237], [72.26625061, 21.71291542], [72.2665329, 21.71292114], [72.2665329, 21.71264076], [72.26680756, 21.71264076], [72.26680756, 21.71236038], [72.26708221, 21.71236038], [72.26708221, 21.71181107], [72.26735687, 21.71181107], [72.26735687, 21.71153069], [72.26763916, 21.71153069], [72.26763916, 21.71096992], [72.26791382, 21.71097183], [72.26791382, 21.71041679], [72.26819611, 21.71042061], [72.26819611, 21.70957947], [72.26847076, 21.70958328], [72.26847076, 21.70902824], [72.26875305, 21.70903015], [72.26875305, 21.70874977], [72.26902771, 21.70874977], [72.26902771, 21.70819283], [72.26930237, 21.70819473], [72.26930237, 21.70708275], [72.26902771, 21.70708275], [72.26902771, 21.70680618], [72.26819611, 21.7068119], [72.26819611, 21.70624924], [72.26902771, 21.70624924], [72.26902771, 21.70597076], [72.26930237, 21.70597267], [72.26930237, 21.7056942], [72.26958466, 21.7056942], [72.26958466, 21.70541573], [72.26985931, 21.70541954], [72.26985931, 21.70513916], [72.2701416, 21.70513916], [72.2701416, 21.7045784], [72.27041626, 21.70458412], [72.27041626, 21.70430565], [72.27069092, 21.70430946], [72.27069092, 21.70402908], [72.27098083, 21.70402908], [72.27098083, 21.70346832], [72.27124786, 21.70347214], [72.27124786, 21.70208359], [72.27153015, 21.70208359], [72.27153015, 21.70152855], [72.27179718, 21.70153046], [72.27179718, 21.7009697], [72.2720871, 21.7009716], [72.2720871, 21.70069695], [72.27263641, 21.70070076], [72.27263641, 21.70042038], [72.2729187, 21.70042038], [72.2729187, 21.70014], [72.27319336, 21.70014], [72.27319336, 21.69985962], [72.27347565, 21.69986153], [72.27347565, 21.69930458], [72.27375031, 21.69930077], [72.27375031, 21.69874954], [72.27402496, 21.69874954], [72.27402496, 21.69847488], [72.27430725, 21.69847488], [72.27430725, 21.69791412], [72.27485657, 21.69791985], [72.27485657, 21.69736099], [72.27513885, 21.69736099], [72.27513885, 21.69708061], [72.27541351, 21.69708252], [72.27541351, 21.69652748], [72.2756958, 21.69652939], [72.2756958, 21.69597054], [72.27625275, 21.69597244], [72.27625275, 21.69569206], [72.2765274, 21.69569969], [72.2765274, 21.69514275], [72.2767868, 21.69514275], [72.2767868, 21.69486046], [72.27707672, 21.69486046], [72.27707672, 21.69458008], [72.27735901, 21.69458389], [72.27735901, 21.69430542], [72.2776413, 21.69431114], [72.2776413, 21.69347191], [72.27791595, 21.69347191], [72.27791595, 21.6926384], [72.27819061, 21.6926403], [72.27819824, 21.69236946], [72.2784729, 21.69236183], [72.2784729, 21.69208336], [72.27874756, 21.69208336], [72.27874756, 21.69152832], [72.27902985, 21.69153023], [72.27902985, 21.69124985], [72.27929688, 21.69124985], [72.27929688, 21.69096756], [72.27958679, 21.69097137], [72.27958679, 21.69013977], [72.27986145, 21.69013977], [72.27986145, 21.68985748], [72.28013611, 21.6898613], [72.28013611, 21.68763924], [72.2804184, 21.68764114], [72.2804184, 21.68708038], [72.28097534, 21.6870842], [72.28097534, 21.68680763], [72.28125, 21.68680763], [72.28125, 21.68625069], [72.28151703, 21.68625069], [72.28151703, 21.68568993], [72.28180695, 21.68569374], [72.28180695, 21.68541527], [72.2820816, 21.68542099], [72.2820816, 21.68486023], [72.28235626, 21.68486023], [72.28235626, 21.68403053], [72.28292084, 21.68403053], [72.28292084, 21.68292046], [72.28321075, 21.68292046], [72.28321075, 21.68264008], [72.28347015, 21.68264008], [72.28347015, 21.68097115], [72.28375244, 21.68097115], [72.28375244, 21.67986107], [72.2840271, 21.67986107], [72.2840271, 21.67931175], [72.28430176, 21.67931175], [72.28430176, 21.67902946], [72.2848587, 21.67902946], [72.2848587, 21.67874908], [72.28514099, 21.67874908], [72.28514099, 21.67653084], [72.28542328, 21.67653084], [72.28542328, 21.67514038], [72.2848587, 21.67514038], [72.2848587, 21.67431068], [72.28514099, 21.67431068], [72.28514099, 21.67319107], [72.2848587, 21.67319679], [72.2848587, 21.66708374], [72.28514099, 21.66708374], [72.28514099, 21.66625023], [72.28542328, 21.66625023], [72.28541565, 21.66486168], [72.28569794, 21.66486168], [72.28569794, 21.66458321], [72.28624725, 21.66458321], [72.28624725, 21.66374969], [72.28679657, 21.66374969], [72.28679657, 21.66319084], [72.28708649, 21.66319466], [72.28708649, 21.66263962], [72.28736115, 21.66263962], [72.28736115, 21.66236115], [72.2876358, 21.66236115], [72.2876358, 21.66208076], [72.28791809, 21.66208267], [72.28791809, 21.66152763], [72.28819275, 21.66152954], [72.28819275, 21.66125107], [72.28848267, 21.66125107], [72.28848267, 21.66097069], [72.28874969, 21.6609726], [72.28874969, 21.66069412], [72.28902435, 21.66069412], [72.28902435, 21.66041756], [72.28930664, 21.66041946], [72.28930664, 21.66014099], [72.28952026, 21.66014099], [72.28956604, 21.65986061], [72.28985596, 21.65986061], [72.28985596, 21.65958977], [72.29013824, 21.65958977], [72.29013824, 21.65903091], [72.2904129, 21.65903091], [72.2904129, 21.65875053], [72.29070282, 21.65875053], [72.29069519, 21.65819359], [72.29096985, 21.65819359], [72.29096985, 21.65763855], [72.29125214, 21.65761185], [72.29125214, 21.65708542], [72.29152679, 21.65708542], [72.29152679, 21.65680313], [72.29180908, 21.6568203], [72.29180908, 21.65653038], [72.29209137, 21.65653038], [72.29209137, 21.65625], [72.2923584, 21.65625], [72.2923584, 21.65596962], [72.29264069, 21.65597153], [72.29264069, 21.65569305], [72.29292297, 21.65570068], [72.29292297, 21.6554203], [72.29347229, 21.6554203], [72.29347229, 21.65513992], [72.29402924, 21.65513992], [72.29402924, 21.65485954], [72.29458618, 21.65486145], [72.29458618, 21.65458107], [72.29486084, 21.65458107], [72.29486084, 21.65430641], [72.29541779, 21.65431023], [72.29541779, 21.65374947], [72.29569244, 21.65374947], [72.29569244, 21.6534729], [72.29597473, 21.6534729], [72.29597473, 21.65319443], [72.29624939, 21.65319443], [72.29624939, 21.65291595], [72.29651642, 21.65292168], [72.29651642, 21.65236092], [72.29680634, 21.65236092], [72.29680634, 21.65208054], [72.29708099, 21.65208244], [72.29708099, 21.65180588], [72.29736328, 21.6518116], [72.29736328, 21.65125084], [72.29792023, 21.65125084], [72.29792023, 21.65068817], [72.29819489, 21.65069389], [72.29819489, 21.65014076], [72.29846954, 21.65014076], [72.29846954, 21.64986038], [72.29875183, 21.64986038], [72.29875183, 21.64957809], [72.29902649, 21.64958382], [72.29902649, 21.64902878], [72.29930878, 21.64903069], [72.29930878, 21.64792061], [72.29957581, 21.64792061], [72.29957581, 21.64764977], [72.30014038, 21.64764977], [72.30014038, 21.64735985], [72.30041504, 21.64736176], [72.30041504, 21.64652824], [72.30069733, 21.64653015], [72.30069733, 21.64596939], [72.30097198, 21.6459713], [72.30097198, 21.64569664], [72.30124664, 21.64569664], [72.30124664, 21.64541435], [72.30152893, 21.64542007], [72.30152893, 21.64513969], [72.30179596, 21.64513969], [72.30179596, 21.64486122], [72.30208588, 21.64486122], [72.30208588, 21.64431], [72.30236053, 21.64431], [72.30236053, 21.64402962], [72.30264282, 21.64402962], [72.30264282, 21.64319038], [72.30291748, 21.64319229], [72.30291748, 21.64097023], [72.30319214, 21.64097023], [72.30319214, 21.63958359], [72.30347443, 21.63958359], [72.30347443, 21.63652992], [72.30374908, 21.63652992], [72.30374908, 21.63624954], [72.30403137, 21.63624954], [72.30403137, 21.63597107], [72.30486298, 21.63597298], [72.30486298, 21.63513947], [72.30513763, 21.63513947], [72.30513763, 21.63458061], [72.30541992, 21.63458252], [72.30541992, 21.63375092], [72.30568695, 21.63375092], [72.30568695, 21.63181114], [72.30596924, 21.63181114], [72.30596924, 21.62846947], [72.30569458, 21.62847137], [72.30569458, 21.6273613], [72.30541992, 21.6273613], [72.30541992, 21.62680626], [72.30513763, 21.62681007], [72.30513763, 21.62625122], [72.30486298, 21.62625122], [72.30486298, 21.62568855], [72.30458069, 21.62569427], [72.30458069, 21.62513924], [72.30430603, 21.62513924], [72.30430603, 21.62431145], [72.30403137, 21.62431145], [72.30403137, 21.62402916], [72.30374908, 21.62402916], [72.30374908, 21.62291908], [72.3034668, 21.62291908], [72.3034668, 21.62207985], [72.30319214, 21.62208366], [72.30319214, 21.62152863], [72.30291748, 21.62153053], [72.30291748, 21.62096977], [72.30263519, 21.62097168], [72.30263519, 21.62041855], [72.30236053, 21.62042046], [72.30236053, 21.6198597], [72.30208588, 21.6198616], [72.30208588, 21.61930656], [72.30152893, 21.61930656], [72.30152893, 21.61902618], [72.30124664, 21.61903], [72.30124664, 21.61847115], [72.30097198, 21.61847305], [72.30097198, 21.61763954], [72.30069733, 21.61765099], [72.30069733, 21.61736107], [72.30041504, 21.61736107], [72.30041504, 21.6170826], [72.30014038, 21.6170826], [72.30014038, 21.61680412], [72.29985809, 21.61680984], [72.29985809, 21.61652946], [72.29957581, 21.61652946], [72.29957581, 21.61597061], [72.29930878, 21.61597252], [72.29930878, 21.61569214], [72.29902649, 21.61569214], [72.29902649, 21.61541748], [72.29846954, 21.61541939], [72.29846954, 21.61514282], [72.29818726, 21.61514282], [72.29818726, 21.61486053], [72.29792023, 21.61486053], [72.29792023, 21.61458015], [72.29763794, 21.61458206], [72.29763794, 21.61402702], [72.29736328, 21.61403275], [72.29736328, 21.61375046], [72.29708099, 21.61375046], [72.29708099, 21.61347008], [72.29680634, 21.61347008], [72.29680634, 21.61319542], [72.29651642, 21.6131916], [72.29652405, 21.61291695], [72.29624939, 21.61292267], [72.29624939, 21.61264038], [72.29569244, 21.61264038], [72.29569244, 21.61236191], [72.29541779, 21.61236191], [72.29541779, 21.61208344], [72.2951355, 21.61208344], [72.2951355, 21.6115284], [72.29486084, 21.6115284], [72.29486084, 21.61124992], [72.29458618, 21.61124992], [72.29458618, 21.61096764], [72.29430389, 21.61097145], [72.29430389, 21.61069489], [72.29402924, 21.61069489], [72.29402924, 21.61041641], [72.29374695, 21.61041832], [72.29374695, 21.61013985], [72.29347229, 21.61013985], [72.29347229, 21.60957909], [72.29319763, 21.6095829], [72.29319763, 21.60930634], [72.29292297, 21.60930824], [72.29292297, 21.60874939], [72.29264069, 21.60874939], [72.29264069, 21.60848045], [72.2923584, 21.60848045], [72.2923584, 21.60819054], [72.29208374, 21.60819435], [72.29208374, 21.60791779], [72.29180908, 21.60791969], [72.29180908, 21.60764122], [72.29152679, 21.60764122], [72.29152679, 21.60736084], [72.29125214, 21.60736084], [72.29125214, 21.60708046], [72.29096985, 21.60708427], [72.29096985, 21.60652542], [72.29070282, 21.60653114], [72.29070282, 21.60569], [72.2904129, 21.60569572], [72.2904129, 21.60513878], [72.29013824, 21.60514069], [72.29013824, 21.60486031], [72.28985596, 21.60486031], [72.28985596, 21.60431099], [72.2895813, 21.60431099], [72.2895813, 21.60403061], [72.28930664, 21.60403061], [72.28930664, 21.60375023], [72.28874969, 21.60375023], [72.28874969, 21.60320091], [72.28848267, 21.60320091], [72.28848267, 21.60264015], [72.28819275, 21.60264015], [72.28819275, 21.60235023], [72.28791809, 21.60236168], [72.28791809, 21.6020813], [72.2876358, 21.6020813], [72.2876358, 21.60152817], [72.28708649, 21.60153008], [72.28708649, 21.60124969], [72.28679657, 21.60124969], [72.28679657, 21.60069275], [72.28652954, 21.60069466], [72.28652954, 21.60041618], [72.28624725, 21.60042191], [72.28624725, 21.60013962], [72.28595734, 21.60013962], [72.28595734, 21.59986115], [72.28569794, 21.59986115], [72.28569794, 21.59931183], [72.28542328, 21.59931183], [72.28542328, 21.59874916], [72.28514099, 21.59874916], [72.28514099, 21.5981884], [72.2848587, 21.59819412], [72.2848587, 21.59791756], [72.28457642, 21.59791946], [72.28457642, 21.59763908], [72.28430176, 21.59763908], [72.28430176, 21.59707832], [72.2840271, 21.59708405], [72.2840271, 21.5965271], [72.28375244, 21.59654236], [72.28375244, 21.59596825], [72.28347015, 21.59597206], [72.28347015, 21.59513855], [72.28321075, 21.59514046], [72.28321075, 21.59486008], [72.28291321, 21.59486198], [72.28291321, 21.59458351], [72.28263855, 21.59458351], [72.28263855, 21.59402847], [72.28235626, 21.59403038], [72.28235626, 21.59348106], [72.2820816, 21.59348106], [72.2820816, 21.59320068], [72.28180695, 21.59320068], [72.28180695, 21.5929203], [72.28151703, 21.5929203], [72.28151703, 21.59235954], [72.28125, 21.59236145], [72.28125, 21.5918045], [72.28098297, 21.59181023], [72.28098297, 21.59152985], [72.28069305, 21.59152985], [72.28069305, 21.59097099], [72.2804184, 21.59097481], [72.2804184, 21.59041405], [72.27986145, 21.59041405], [72.27986145, 21.59013939], [72.27958679, 21.59013939], [72.27958679, 21.58958054], [72.2793045, 21.58958244], [72.2793045, 21.58875084], [72.27902985, 21.58875084], [72.27902985, 21.58847046], [72.27874756, 21.58847237], [72.27874756, 21.58819389], [72.2784729, 21.58819389], [72.2784729, 21.58791733], [72.27819824, 21.58792114], [72.27819061, 21.58735085], [72.27791595, 21.58736038], [72.27791595, 21.58680534], [72.2776413, 21.58681107], [72.2776413, 21.58653259], [72.27735901, 21.58653259], [72.27735901, 21.58625031], [72.27707672, 21.58625031], [72.27707672, 21.58597183], [72.27680206, 21.58597183], [72.27680206, 21.58541679], [72.2765274, 21.58542252], [72.2765274, 21.58514023], [72.27625275, 21.58514023], [72.27625275, 21.58486176], [72.27597046, 21.58486176], [72.27597046, 21.58458328], [72.2756958, 21.58458328], [72.2756958, 21.58430481], [72.27540588, 21.58430862], [72.27540588, 21.58374977], [72.27513885, 21.58374977], [72.27513885, 21.58319092], [72.27458191, 21.58319473], [72.27458191, 21.58291626], [72.27430725, 21.58291817], [72.27430725, 21.58263969], [72.27401733, 21.58263969], [72.27401733, 21.58208084], [72.27375031, 21.58208275], [72.27375031, 21.58180618], [72.27348328, 21.58180809], [72.27348328, 21.58125114], [72.27319336, 21.58125114], [72.27319336, 21.58097076], [72.2729187, 21.58097267], [72.2729187, 21.5806942], [72.27263641, 21.5806942], [72.27263641, 21.58013916], [72.27236176, 21.58014107], [72.27236176, 21.57958031], [72.2720871, 21.57958412], [72.2720871, 21.57875061], [72.27179718, 21.57875061], [72.27179718, 21.57818031], [72.27153015, 21.57819557], [72.27153015, 21.57791519], [72.27124786, 21.57792091], [72.27124786, 21.57736015], [72.27097321, 21.57736206], [72.27097321, 21.57680321], [72.27069092, 21.57681084], [72.27069092, 21.57625008], [72.27041626, 21.57625008], [72.27041626, 21.57570076], [72.2701416, 21.57570076], [72.2701416, 21.57514], [72.26985931, 21.57514], [72.26985931, 21.57458115], [72.26958466, 21.57458115], [72.26958466, 21.57402802], [72.26930237, 21.57403183], [72.26930237, 21.57374954], [72.26902771, 21.57374954], [72.26902771, 21.57292175], [72.26875305, 21.57292175], [72.26875305, 21.57208061], [72.26847076, 21.57208252], [72.26847076, 21.56986046], [72.26819611, 21.56986046], [72.26819611, 21.56875038], [72.26791382, 21.56875038], [72.26791382, 21.56597137], [72.26763916, 21.56597137], [72.26763916, 21.56458473], [72.2673645, 21.56458473], [72.2673645, 21.56319237], [72.26708221, 21.56319237], [72.26708221, 21.56236076], [72.26680756, 21.56236076], [72.26680756, 21.56208038], [72.26652527, 21.56208229], [72.26652527, 21.56152725], [72.26625061, 21.56153107], [72.26625061, 21.56069183], [72.26597595, 21.56069374], [72.26597595, 21.55930519], [72.26568604, 21.55931282], [72.26568604, 21.55903244], [72.26541901, 21.55903244], [72.26541901, 21.55847168], [72.26513672, 21.55847168], [72.26513672, 21.55819511], [72.2648468, 21.55820274], [72.2648468, 21.55763817], [72.26457977, 21.55763817], [72.26457977, 21.55708122], [72.26430511, 21.55708313], [72.26430511, 21.55652809], [72.26403046, 21.55652809], [72.26403046, 21.55430031], [72.26430511, 21.55430794], [72.26430511, 21.54791641], [72.26457977, 21.54792023], [72.26457977, 21.54735947], [72.26486206, 21.54736137], [72.26486206, 21.54680634], [72.26513672, 21.54681015], [72.26513672, 21.54153061], [72.2648468, 21.54153061], [72.2648468, 21.54014015], [72.26457977, 21.54014015], [72.26457977, 21.53957939], [72.26430511, 21.53958321], [72.26430511, 21.53847313], [72.26403046, 21.53847313], [72.26403046, 21.53736115], [72.26374817, 21.53736115], [72.26374817, 21.53652954], [72.26346588, 21.53652954], [72.26346588, 21.53569031], [72.26319122, 21.53569221], [72.26319122, 21.53541756], [72.26291656, 21.53541946], [72.26291656, 21.53292274], [72.26264191, 21.53292274], [72.26264191, 21.53181267], [72.26235962, 21.53181267], [72.26235962, 21.53070068], [72.26207733, 21.53070068], [72.26207733, 21.53013992], [72.26178741, 21.53013992], [72.26178741, 21.52958107], [72.26152802, 21.52958298], [72.26152802, 21.52930641], [72.26125336, 21.52930832], [72.26125336, 21.52874947], [72.26097107, 21.52874947], [72.26097107, 21.52847099], [72.26069641, 21.5284729], [72.26069641, 21.52819443], [72.26041412, 21.52819443], [72.26041412, 21.52708244], [72.26013947, 21.52708244], [72.26013947, 21.5265255], [72.25985718, 21.52653122], [72.25985718, 21.52542114], [72.25958252, 21.52542114], [72.25958252, 21.52458], [72.25930786, 21.52458572], [72.25930786, 21.52375031], [72.25902557, 21.52375031], [72.25902557, 21.52291679], [72.25875092, 21.52292061], [72.25875092, 21.52126122], [72.25846863, 21.52126122], [72.25846863, 21.52069283], [72.25819397, 21.52069473], [72.25819397, 21.51930618], [72.25846863, 21.5193119], [72.25846863, 21.51791954], [72.25818634, 21.51791954], [72.25818634, 21.51736069], [72.25791931, 21.51736069], [72.25791931, 21.5170784], [72.25763702, 21.51708412], [72.25763702, 21.51680565], [72.25736237, 21.51681137], [72.25736237, 21.51652908], [72.25708008, 21.51652908], [72.25708008, 21.51431084], [72.25681305, 21.51431084], [72.25681305, 21.51403046], [72.25653076, 21.51403046], [72.25653076, 21.51375008], [72.25624847, 21.51375008], [72.25624847, 21.51320076], [72.25598145, 21.51320076], [72.25598145, 21.51292038], [72.25569153, 21.51292038], [72.25569153, 21.5118103], [72.25541687, 21.5118103], [72.25541687, 21.51013947], [72.25514221, 21.51013947], [72.25514221, 21.50932121], [72.25485992, 21.50932121], [72.25485992, 21.50792122], [72.2545929, 21.50792122], [72.2545929, 21.50570107], [72.25430298, 21.50570107], [72.25430298, 21.50291824], [72.25402832, 21.50291824], [72.25402832, 21.50180817], [72.25374603, 21.50180817], [72.25375366, 21.50140953], [72.25375366, 21.50124931], [72.25347137, 21.50125122], [72.25347137, 21.50041962], [72.25319672, 21.50041962], [72.25319672, 21.49986076], [72.2529068, 21.49986076], [72.2529068, 21.49958038], [72.25263977, 21.4995842], [72.25263977, 21.49902534], [72.25235748, 21.49903107], [72.25235748, 21.49818993], [72.25208282, 21.49819565], [72.25208282, 21.49736023], [72.25180817, 21.49736023], [72.25180817, 21.49708939], [72.25152588, 21.49708939], [72.25152588, 21.49570084], [72.25125122, 21.49570084], [72.25125122, 21.4948597], [72.25152588, 21.4948616], [72.25152588, 21.49458122], [72.25125122, 21.49458122], [72.25125122, 21.49402809], [72.25096893, 21.49403191], [72.25096893, 21.49374962], [72.25068665, 21.49374962], [72.25068665, 21.49319267], [72.25041962, 21.49319458], [72.25041962, 21.49235916], [72.25013733, 21.49235916], [72.25013733, 21.49181175], [72.24984741, 21.49181175], [72.24984741, 21.49096107], [72.24958038, 21.49097252], [72.24958038, 21.49069405], [72.24930573, 21.49069405], [72.24930573, 21.49041748], [72.24903107, 21.49041939], [72.24903107, 21.48986053], [72.24874878, 21.48986053], [72.24874878, 21.48957825], [72.24847412, 21.48958397], [72.24847412, 21.48875046], [72.24819183, 21.48875046], [72.24819183, 21.48764038], [72.24791718, 21.48764038], [72.24791718, 21.48707962], [72.24764252, 21.48708344], [72.24764252, 21.4865284], [72.24736023, 21.4865303], [72.24736023, 21.48624992], [72.24708557, 21.48624992], [72.24708557, 21.48569679], [72.24680328, 21.48569679], [72.24680328, 21.48347473], [72.24652863, 21.48347473], [72.24652863, 21.48319244], [72.24624634, 21.48319244], [72.24624634, 21.48263931], [72.24597168, 21.48264122], [72.24597168, 21.48236084], [72.24569702, 21.48236084], [72.24569702, 21.48209], [72.2454071, 21.48209], [72.2454071, 21.48125076], [72.24514008, 21.48125076], [72.24514008, 21.48069191], [72.24485779, 21.48069382], [72.24485779, 21.47958374], [72.24458313, 21.47958374], [72.24458313, 21.4790287], [72.24430847, 21.4790287], [72.24430847, 21.47847176], [72.24402618, 21.47847176], [72.24402618, 21.47791672], [72.24375153, 21.47792244], [72.24375153, 21.47735977], [72.24346924, 21.47736168], [72.24346924, 21.47708321], [72.24319458, 21.47708321], [72.24319458, 21.47680473], [72.24291992, 21.47680473], [72.24291992, 21.47597313], [72.24263763, 21.47597313], [72.24263763, 21.47374916], [72.24236298, 21.47375107], [72.24236298, 21.47319031], [72.24208069, 21.47319412], [72.24208069, 21.47263908], [72.24180603, 21.47264099], [72.24180603, 21.47208023], [72.24153137, 21.47208595], [72.24153137, 21.47152519], [72.24124908, 21.47153091], [72.24124908, 21.47125053], [72.2409668, 21.47125053], [72.2409668, 21.47068977], [72.24069214, 21.4706955], [72.24069214, 21.47041512], [72.24041748, 21.47042084], [72.24041748, 21.47014999], [72.24014282, 21.47014999], [72.24014282, 21.46986008], [72.23986053, 21.46986389], [72.23986053, 21.46958542], [72.23958588, 21.46958542], [72.23958588, 21.46902847], [72.23929596, 21.46903038], [72.23929596, 21.46875], [72.23902893, 21.46875], [72.23902893, 21.46846962], [72.23847198, 21.46847153], [72.23847198, 21.46791649], [72.23819733, 21.4679203], [72.23819733, 21.46763992], [72.23790741, 21.46763992], [72.23790741, 21.46708107], [72.23764038, 21.46708107], [72.23764038, 21.46680641], [72.23707581, 21.46681023], [72.23707581, 21.46653175], [72.23680878, 21.46653175], [72.23680878, 21.46542168], [72.23652649, 21.46542168], [72.23652649, 21.46458054], [72.23625183, 21.46458244], [72.23625183, 21.46430588], [72.23568726, 21.4643116], [72.23568726, 21.46347046], [72.23542023, 21.46347237], [72.23542023, 21.46236038], [72.23513794, 21.46236038], [72.23513794, 21.46153069], [72.23487091, 21.46153069], [72.23487091, 21.46014023], [72.23513794, 21.46014023], [72.23513794, 21.45930099], [72.23542023, 21.45930672], [72.23542023, 21.45708466], [72.23513794, 21.45708466], [72.23513794, 21.45652771], [72.23487091, 21.45652962], [72.23487091, 21.45625114], [72.23458099, 21.45625114], [72.23458099, 21.45597076], [72.23430634, 21.45597458], [72.23430634, 21.45569229], [72.23402405, 21.45569229], [72.23402405, 21.45513916], [72.23374939, 21.45514107], [72.23374939, 21.45458031], [72.23347473, 21.45458221], [72.23347473, 21.45430565], [72.23319244, 21.45430946], [72.23319244, 21.45375061], [72.2326355, 21.45375061], [72.2326355, 21.45319366], [72.23208618, 21.45319366], [72.23208618, 21.45263863], [72.23124695, 21.45264053], [72.23124695, 21.45236015], [72.23097229, 21.45236015], [72.23097229, 21.45208359], [72.23069763, 21.45208359], [72.23069763, 21.45180511], [72.23042297, 21.45181274], [72.23042297, 21.45153236], [72.23014069, 21.45153236], [72.23014069, 21.45125008], [72.2298584, 21.45125008], [72.2298584, 21.4509697], [72.22958374, 21.4509716], [72.22958374, 21.45069504], [72.22930908, 21.45070076], [72.22930908, 21.45013809], [72.22902679, 21.45013809], [72.22902679, 21.44958115], [72.22875214, 21.44958305], [72.22875214, 21.44930649], [72.22846985, 21.4493084], [72.22846985, 21.44903946], [72.22820282, 21.44903946], [72.22820282, 21.44874954], [72.2279129, 21.44874954], [72.2279129, 21.44847107], [72.22763824, 21.44847298], [72.22763824, 21.4481945], [72.22736359, 21.4481945], [72.22736359, 21.44763947], [72.2270813, 21.44763947], [72.2270813, 21.44736099], [72.22680664, 21.44736099], [72.22680664, 21.44708061], [72.22652435, 21.44708252], [72.22652435, 21.44680786], [72.22624969, 21.44680977], [72.22624969, 21.44652939], [72.22596741, 21.44652939], [72.22596741, 21.44598007], [72.22567749, 21.44598007], [72.22567749, 21.44569016], [72.22541809, 21.44569588], [72.22541809, 21.44513893], [72.2251358, 21.44514084], [72.2251358, 21.44458008], [72.22486115, 21.4445858], [72.22486115, 21.44430351], [72.22458649, 21.44431114], [72.22458649, 21.44403076], [72.22429657, 21.44403076], [72.22429657, 21.44375038], [72.22402954, 21.44375038], [72.22402954, 21.44180107], [72.2243042, 21.44180489], [72.2243042, 21.44041634], [72.22402954, 21.44042015], [72.22402954, 21.44013977], [72.22374725, 21.44013977], [72.22374725, 21.43958282], [72.2234726, 21.43958282], [72.2234726, 21.43930626], [72.22319794, 21.43931007], [72.22319794, 21.43874931], [72.22264099, 21.43874931], [72.22264099, 21.43847084], [72.2223587, 21.43847275], [72.2223587, 21.43819427], [72.22180176, 21.43819427], [72.22180176, 21.4379158], [72.2215271, 21.43792152], [72.2215271, 21.43736076], [72.22125244, 21.43736076], [72.22125244, 21.43681145], [72.22097015, 21.43681145], [72.22097015, 21.43652916], [72.22041321, 21.43652916], [72.22041321, 21.43625069], [72.22013855, 21.43625069], [72.22013855, 21.43597031], [72.21986389, 21.43597221], [72.21986389, 21.43569374], [72.21930695, 21.43569374], [72.21930695, 21.43486023], [72.21901703, 21.43486023], [72.21901703, 21.43457985], [72.21875, 21.43458366], [72.21875, 21.43430519], [72.21848297, 21.43431091], [72.21848297, 21.43403816], [72.21819305, 21.43403816], [72.21819305, 21.43375015], [72.21763611, 21.43375015], [72.21763611, 21.43346977], [72.21736145, 21.43347168], [72.21736145, 21.43291664], [72.21708679, 21.43292046], [72.21708679, 21.43264008], [72.21679688, 21.43264008], [72.21679688, 21.4323597], [72.21624756, 21.4323616], [72.21624756, 21.43208313], [72.2159729, 21.43208313], [72.2159729, 21.43097305], [72.21569824, 21.43097305], [72.21569061, 21.4304142], [72.21541595, 21.43041992], [72.21541595, 21.42986107], [72.21485901, 21.42986107], [72.21485901, 21.42958069], [72.21430206, 21.4295826], [72.21430206, 21.42930412], [72.2140274, 21.42930984], [72.2140274, 21.42791176], [72.21430206, 21.42791748], [72.21430206, 21.42763901], [72.2140274, 21.42764282], [72.2140274, 21.42708015], [72.21347046, 21.42708206], [72.21347046, 21.4268055], [72.21290588, 21.42681122], [72.21290588, 21.42653275], [72.21263885, 21.42653275], [72.21263885, 21.42625046], [72.21235657, 21.42625046], [72.21235657, 21.42597008], [72.21152496, 21.42597008], [72.21152496, 21.42569542], [72.21125031, 21.4256916], [72.21125031, 21.42513847], [72.2104187, 21.42514038], [72.2104187, 21.42374992], [72.21013641, 21.42374992], [72.21013641, 21.42318916], [72.20986176, 21.42319489], [72.20986176, 21.42291641], [72.2095871, 21.42291832], [72.2095871, 21.42263985], [72.20903015, 21.42263985], [72.20903015, 21.42235947], [72.20874786, 21.42236137], [72.20874786, 21.4220829], [72.20819092, 21.4220829], [72.20819092, 21.42180634], [72.2076416, 21.42180824], [72.2076416, 21.42152977], [72.20707703, 21.42152977], [72.20707703, 21.42124939], [72.20680237, 21.42124939], [72.20680237, 21.42097092], [72.20652771, 21.42097282], [72.20652771, 21.42041779], [72.20540619, 21.42041969], [72.20540619, 21.41986084], [72.20485687, 21.41986084], [72.20485687, 21.41930962], [72.20458221, 21.41930962], [72.20458221, 21.41875076], [72.20430756, 21.41875076], [72.20430756, 21.41847038], [72.20375061, 21.41847229], [72.20375061, 21.41819572], [72.20347595, 21.41819572], [72.20347595, 21.41791725], [72.20263672, 21.41792107], [72.20263672, 21.41764069], [72.20236206, 21.41764069], [72.20236206, 21.41736031], [72.20207977, 21.41736031], [72.20207977, 21.41681099], [72.20179749, 21.41681099], [72.20179749, 21.41653061], [72.20153046, 21.41653061], [72.20153046, 21.41485977], [72.20124817, 21.41486359], [72.20124817, 21.41430473], [72.20069122, 21.41430473], [72.20069122, 21.41347122], [72.20097351, 21.41347122], [72.20097351, 21.41319466], [72.20124817, 21.41319466], [72.20124817, 21.41291618], [72.20097351, 21.41291618], [72.20097351, 21.41263962], [72.20041656, 21.41263962], [72.20041656, 21.41235924], [72.19902802, 21.41235924], [72.19902802, 21.41208076], [72.19847107, 21.41208267], [72.19847107, 21.41180611], [72.19763947, 21.41181183], [72.19763947, 21.41152954], [72.19708252, 21.41152954], [72.19708252, 21.41124916], [72.1965332, 21.41124916], [72.1965332, 21.41097069], [72.19625092, 21.4109726], [72.19625092, 21.41069412], [72.19569397, 21.41069412], [72.19569397, 21.41041756], [72.19541931, 21.41041946], [72.19541931, 21.40987015], [72.19513702, 21.40987015], [72.19513702, 21.40957832], [72.19458008, 21.40958405], [72.19458008, 21.40930557], [72.19431305, 21.40930748], [72.19431305, 21.40903091], [72.19403076, 21.40903091], [72.19403076, 21.40875053], [72.19374847, 21.40875053], [72.19374847, 21.40847015], [72.19347382, 21.40847206], [72.19347382, 21.40819359], [72.19319153, 21.40819359], [72.19319153, 21.40791893], [72.19291687, 21.40792084], [72.19291687, 21.40764046], [72.19235992, 21.40764046], [72.19235992, 21.40736008], [72.19208527, 21.40736198], [72.19208527, 21.40708351], [72.19180298, 21.40708351], [72.19180298, 21.40680695], [72.19152832, 21.40681076], [72.19152832, 21.40653038], [72.19097137, 21.40653038], [72.19097137, 21.40625], [72.18985748, 21.40625], [72.18985748, 21.40596962], [72.18902588, 21.40597153], [72.18902588, 21.40569687], [72.18875122, 21.40570068], [72.18875122, 21.4054203], [72.18846893, 21.4054203], [72.18846893, 21.40513992], [72.18818665, 21.40513992], [72.18818665, 21.40485954], [72.18791962, 21.40486145], [72.18791962, 21.40458488], [72.18736267, 21.40458488], [72.18736267, 21.40430641], [72.18682098, 21.40431023], [72.18682098, 21.40402985], [72.18653107, 21.40402985], [72.18653107, 21.40347099], [72.18624878, 21.40347481], [72.18624878, 21.40319252], [72.18597412, 21.40319252], [72.18597412, 21.40263939], [72.18541718, 21.40263939], [72.18541718, 21.40236092], [72.18514252, 21.40236092], [72.18514252, 21.40208054], [72.18486023, 21.40208244], [72.18486023, 21.40180588], [72.1845932, 21.40180969], [72.1845932, 21.40153122], [72.18430328, 21.40153122], [72.18430328, 21.40125275], [72.18402863, 21.40125275], [72.18402863, 21.40097046], [72.18374634, 21.40097237], [72.18374634, 21.40041733], [72.1829071, 21.40042114], [72.1829071, 21.40014267], [72.18235779, 21.40014267], [72.18235779, 21.39986038], [72.18208313, 21.39986038], [72.18208313, 21.39958191], [72.18152618, 21.39958382], [72.18152618, 21.39930534], [72.18096924, 21.39931107], [72.18096924, 21.39903259], [72.18070221, 21.39903259], [72.18070221, 21.39875031], [72.18041992, 21.39875031], [72.18041992, 21.39847183], [72.18013763, 21.39847183], [72.18013763, 21.39819527], [72.17986298, 21.3982029], [72.17986298, 21.39793015], [72.17958069, 21.39793015], [72.17958069, 21.39763832], [72.17930603, 21.39763832], [72.17930603, 21.39735985], [72.17819214, 21.39736176], [72.17819214, 21.39708328], [72.17736053, 21.39708328], [72.17736053, 21.39680481], [72.17680359, 21.39680481], [72.17680359, 21.39652824], [72.17652893, 21.39652824], [72.17652893, 21.39596748], [72.17624664, 21.3959713], [72.17624664, 21.39569473], [72.17597198, 21.39569473], [72.17597198, 21.39541626], [72.17569733, 21.39541817], [72.17569733, 21.39487076], [72.17542267, 21.39487076], [72.17542267, 21.39458084], [72.17514038, 21.39458275], [72.17514038, 21.39430618], [72.17485809, 21.39430809], [72.17485809, 21.39375114], [72.17456818, 21.39375114], [72.17456818, 21.39319038], [72.17430878, 21.3931942], [72.17430878, 21.39236069], [72.17402649, 21.39236069], [72.17402649, 21.39208031], [72.17375183, 21.39208412], [72.17375183, 21.39180756], [72.17346954, 21.39180756], [72.17346954, 21.39152527], [72.17318726, 21.39153099], [72.17318726, 21.39125061], [72.17263794, 21.39125061], [72.17263794, 21.39097023], [72.17236328, 21.39097214], [72.17236328, 21.39069557], [72.17208099, 21.39069557], [72.17208099, 21.39013863], [72.17153168, 21.39014053], [72.17153168, 21.38986015], [72.17097473, 21.38986206], [72.17097473, 21.38875008], [72.17069244, 21.38875008], [72.17069244, 21.38763809], [72.17041779, 21.38764191], [72.17041779, 21.38708115], [72.1701355, 21.38708115], [72.1701355, 21.38597107], [72.16986084, 21.38597107], [72.16986084, 21.3856945], [72.16958618, 21.38570023], [72.16958618, 21.38542175], [72.16929626, 21.38542175], [72.16929626, 21.38485909], [72.16902924, 21.38485909], [72.16902924, 21.38431168], [72.16876221, 21.38431168], [72.16876221, 21.38402939], [72.16819763, 21.38402939], [72.16819763, 21.38318825], [72.16764069, 21.38319397], [72.16764069, 21.3829174], [72.16707611, 21.38293266], [72.16707611, 21.38236046], [72.16680908, 21.38236046], [72.16680908, 21.38096809], [72.16708374, 21.38097191], [72.16708374, 21.38041878], [72.1673584, 21.38042068], [72.1673584, 21.3801403], [72.16764069, 21.3801403], [72.16764069, 21.37985992], [72.1673584, 21.37986183], [72.1673584, 21.37930679], [72.16708374, 21.37930679], [72.16708374, 21.37847137], [72.16680908, 21.37847137], [72.16680908, 21.37652779], [72.16652679, 21.37652969], [72.16652679, 21.37625122], [72.16625214, 21.37625122], [72.16625214, 21.37597084], [72.16596985, 21.37597466], [72.16596985, 21.37569237], [72.16569519, 21.37569237], [72.16569519, 21.3754158], [72.16539764, 21.37541962], [72.16539764, 21.37486076], [72.16513824, 21.37486076], [72.16513824, 21.37458038], [72.1645813, 21.37458229], [72.1645813, 21.37430573], [72.16430664, 21.37430954], [72.16430664, 21.37403107], [72.16401672, 21.37403107], [72.16401672, 21.37347031], [72.16374969, 21.37347031], [72.16374969, 21.37291718], [72.16319275, 21.3729229], [72.16319275, 21.37264252], [72.16291809, 21.37264252], [72.16291809, 21.37236023], [72.16262817, 21.37236023], [72.16262817, 21.37208176], [72.16236115, 21.37208366], [72.16236115, 21.37180519], [72.16208649, 21.37181282], [72.16208649, 21.37153244], [72.16152954, 21.37153244], [72.16152954, 21.37125015], [72.16124725, 21.37125015], [72.16124725, 21.37096977], [72.16069794, 21.37097168], [72.16069794, 21.37069511], [72.16042328, 21.37070084], [72.16042328, 21.37041855], [72.16014099, 21.37041855], [72.16014099, 21.37013817], [72.1598587, 21.37013817], [72.1598587, 21.36930084], [72.15958405, 21.36930466], [72.15958405, 21.36902809], [72.1590271, 21.36902809], [72.1590271, 21.36874962], [72.15875244, 21.36874962], [72.15875244, 21.36819077], [72.15847015, 21.36819458], [72.15847015, 21.36791611], [72.15820313, 21.36791992], [72.15820313, 21.36763], [72.15791321, 21.36763954], [72.15791321, 21.36736107], [72.15763855, 21.36736107], [72.15763855, 21.36680984], [72.15735626, 21.36680984], [72.15735626, 21.36652946], [72.1570816, 21.36652946], [72.1570816, 21.36625099], [72.1568222, 21.36625099], [72.1568222, 21.36569023], [72.15652466, 21.36569595], [72.15652466, 21.36541748], [72.15625, 21.36541939], [72.15625, 21.36514091], [72.15598297, 21.36514091], [72.15598297, 21.36457062], [72.15569305, 21.36458588], [72.15569305, 21.36402512], [72.1554184, 21.36403084], [72.1554184, 21.36347008], [72.15513611, 21.36347389], [72.15513611, 21.36319542], [72.15486145, 21.3631897], [72.15486145, 21.36291695], [72.15458679, 21.36292076], [72.15458679, 21.36264038], [72.15429688, 21.36264038], [72.15429688, 21.36182022], [72.15402985, 21.36182022], [72.15402985, 21.3615303], [72.15374756, 21.3615303], [72.15374756, 21.36124992], [72.15345764, 21.36124992], [72.15345764, 21.36096954], [72.15319824, 21.36097145], [72.15319061, 21.36069489], [72.15291595, 21.36069489], [72.15291595, 21.36041641], [72.1526413, 21.36042023], [72.1526413, 21.36013985], [72.15235901, 21.36013985], [72.15235901, 21.3595829], [72.15180206, 21.3595829], [72.15180206, 21.35930634], [72.1515274, 21.35931015], [72.1515274, 21.35903168], [72.15125275, 21.35903168], [72.15125275, 21.35876274], [72.15068817, 21.35876274], [72.15068817, 21.35819054], [72.15041351, 21.35819435], [72.15041351, 21.35736084], [72.15013885, 21.35736084], [72.15013885, 21.35681152], [72.14985657, 21.35681152], [72.14985657, 21.35625076], [72.14958191, 21.35625076], [72.14958191, 21.35597038], [72.14930725, 21.35597229], [72.14930725, 21.35569382], [72.14902496, 21.35569382], [72.14902496, 21.35541725], [72.14848328, 21.35541916], [72.14848328, 21.35514069], [72.14819336, 21.35514069], [72.14819336, 21.35486031], [72.1479187, 21.35486031], [72.1479187, 21.35457993], [72.14736176, 21.35458374], [72.14736176, 21.3540287], [72.1470871, 21.35403061], [72.1470871, 21.35375023], [72.14679718, 21.35375023], [72.14679718, 21.35320091], [72.14653015, 21.35320091], [72.14653015, 21.35292053], [72.14624786, 21.35292053], [72.14624786, 21.35263062], [72.14597321, 21.35263824], [72.14597321, 21.35236168], [72.14569092, 21.35236168], [72.14569092, 21.35208321], [72.14541626, 21.35208321], [72.14541626, 21.35180664], [72.14485931, 21.35180664], [72.14485931, 21.35124969], [72.14458466, 21.35124969], [72.14458466, 21.35097313], [72.14430237, 21.35097313], [72.14430237, 21.35069656], [72.14402771, 21.35069656], [72.14402771, 21.35041428], [72.14347076, 21.35042], [72.14347076, 21.34986115], [72.14319611, 21.34986115], [72.14319611, 21.3495903], [72.14290619, 21.3495903], [72.14290619, 21.34930992], [72.14263916, 21.34930992], [72.14263916, 21.34902954], [72.14235687, 21.34902954], [72.14235687, 21.34875107], [72.14208221, 21.34875107], [72.14208221, 21.34847069], [72.14180756, 21.3484745], [72.14180756, 21.34819221], [72.14152527, 21.34819221], [72.14152527, 21.34791756], [72.14125061, 21.34791946], [72.14125061, 21.3476429], [72.14097595, 21.3476429], [72.14097595, 21.34736061], [72.14041901, 21.34736061], [72.14041901, 21.34708023], [72.14013672, 21.34708214], [72.14013672, 21.3465271], [72.13986206, 21.34653282], [72.13986206, 21.34625053], [72.13957977, 21.34625053], [72.13957977, 21.34597015], [72.13930511, 21.34597015], [72.13930511, 21.34569359], [72.13903046, 21.34569359], [72.13903046, 21.34541702], [72.13874817, 21.34542274], [72.13874817, 21.34514046], [72.13845825, 21.34514046], [72.13845825, 21.34486008], [72.13819122, 21.34486008], [72.13819122, 21.34458351], [72.13791656, 21.34458351], [72.13791656, 21.34430504], [72.13764191, 21.34431267], [72.13764191, 21.34402847], [72.13709259, 21.34402847], [72.13709259, 21.34374809], [72.13680267, 21.34374809], [72.13680267, 21.34346962], [72.13652802, 21.34347153], [72.13652802, 21.34291649], [72.13625336, 21.3429184], [72.13625336, 21.34263992], [72.13597107, 21.34263992], [72.13597107, 21.34235954], [72.13569641, 21.34236145], [72.13569641, 21.34208298], [72.13541412, 21.34208298], [72.13541412, 21.34180641], [72.13485718, 21.34180832], [72.13485718, 21.34152985], [72.13458252, 21.34152985], [72.13458252, 21.34124947], [72.13430786, 21.34124947], [72.13430786, 21.34097099], [72.13402557, 21.3409729], [72.13402557, 21.34069443], [72.13375092, 21.34069443], [72.13375092, 21.34013939], [72.13346863, 21.34013939], [72.13346863, 21.33986092], [72.13318634, 21.33986092], [72.13318634, 21.33958054], [72.13291931, 21.33958244], [72.13291931, 21.33930779], [72.13265228, 21.33930969], [72.13265228, 21.33875084], [72.13236237, 21.33875084], [72.13236237, 21.33847046], [72.13208008, 21.33847237], [72.13208008, 21.3381958], [72.13180542, 21.3381958], [72.13180542, 21.33791733], [72.13153076, 21.33792114], [72.13153076, 21.3376503], [72.13124847, 21.3376503], [72.13124847, 21.33708], [72.13097382, 21.33708572], [72.13097382, 21.33680344], [72.13069153, 21.33681107], [72.13069153, 21.33653069], [72.13041687, 21.33653069], [72.13041687, 21.33625031], [72.13014221, 21.33625031], [72.13014221, 21.33596992], [72.12985992, 21.33597374], [72.12985992, 21.33569336], [72.12957764, 21.33570099], [72.12957764, 21.33542061], [72.12930298, 21.33542061], [72.12930298, 21.33514023], [72.12902832, 21.33514023], [72.12902832, 21.33459091], [72.12874603, 21.33459091], [72.12874603, 21.33403015], [72.12847137, 21.33403015], [72.12847137, 21.33374977], [72.12819672, 21.33374977], [72.12819672, 21.33346939], [72.12791443, 21.3334713], [72.12791443, 21.33319473], [72.12763977, 21.33319473], [72.12763977, 21.33263969], [72.12735748, 21.33263969], [72.12735748, 21.33235931], [72.12708282, 21.33235931], [72.12708282, 21.33208084], [72.12680817, 21.33208275], [72.12680817, 21.33152771], [72.12651825, 21.33152962], [72.12651825, 21.33124924], [72.12596893, 21.33124924], [72.12596893, 21.33068848], [72.12569427, 21.3306942], [72.12569427, 21.33041763], [72.12541962, 21.33042145], [72.12541962, 21.33013916], [72.12513733, 21.33013916], [72.12513733, 21.32930756], [72.12458038, 21.32930756], [72.12458038, 21.32875061], [72.12430573, 21.32875061], [72.12430573, 21.32847214], [72.12403107, 21.32847214], [72.12403107, 21.3279171], [72.12374878, 21.32792091], [72.12374878, 21.32736015], [72.12319183, 21.32736206], [72.12319183, 21.32680511], [72.12291718, 21.32681084], [72.12291718, 21.32653046], [72.12264252, 21.32653046], [72.12264252, 21.32625008], [72.12236023, 21.32625008], [72.12236023, 21.3259697], [72.12208557, 21.3259716], [72.12208557, 21.32569695], [72.12180328, 21.3257103], [72.12180328, 21.32542038], [72.12152863, 21.32542038], [72.12152863, 21.32485962], [72.12124634, 21.32486153], [72.12124634, 21.32374954], [72.12097168, 21.32374954], [72.12097168, 21.32319069], [72.12069702, 21.3231926], [72.12069702, 21.32291412], [72.12042236, 21.32291985], [72.12042236, 21.32265091], [72.12014008, 21.32265091], [72.12014008, 21.32208061], [72.11985779, 21.32208252], [72.11985779, 21.32152748], [72.11958313, 21.32152939], [72.11958313, 21.32097054], [72.11930847, 21.32097435], [72.11930847, 21.32069206], [72.11902618, 21.32069206], [72.11902618, 21.32013893], [72.11875153, 21.32014275], [72.11875153, 21.31986046], [72.11846924, 21.31986046], [72.11846924, 21.31931114], [72.11818695, 21.31931114], [72.11818695, 21.31875038], [72.11791992, 21.31875038], [72.11791992, 21.31847191], [72.11763763, 21.31847191], [72.11763763, 21.3176384], [72.11736298, 21.3176403], [72.11736298, 21.31707764], [72.11680603, 21.31708336], [72.11680603, 21.31680489], [72.11653137, 21.31680489], [72.11653137, 21.31624985], [72.11624908, 21.31624985], [72.11624908, 21.31568909], [72.11597443, 21.31569481], [72.11597443, 21.3148613], [72.11569214, 21.3148613], [72.11569214, 21.31458282], [72.11541748, 21.31458282], [72.11541748, 21.31402779], [72.11514282, 21.31402969], [72.11514282, 21.3134594], [72.11486053, 21.31347275], [72.11486053, 21.31319427], [72.11458588, 21.31319427], [72.11458588, 21.31263924], [72.11428833, 21.31264114], [72.11428833, 21.31236076], [72.11402893, 21.31236076], [72.11402893, 21.31153107], [72.11374664, 21.31153107], [72.11374664, 21.31097031], [72.11347198, 21.31097221], [72.11347198, 21.31041718], [72.11319733, 21.31042099], [72.11319733, 21.31014061], [72.11292267, 21.31014061], [72.11292267, 21.30957985], [72.11264038, 21.30958557], [72.11264038, 21.30902863], [72.11235809, 21.30903053], [72.11235809, 21.30764961], [72.11207581, 21.30764961], [72.11207581, 21.3073597], [72.11180878, 21.30736351], [72.11180878, 21.30597115], [72.11152649, 21.30597115], [72.11152649, 21.30513954], [72.11125183, 21.30513954], [72.11125183, 21.30458069], [72.11096954, 21.3045826], [72.11096954, 21.30402756], [72.11068726, 21.30402946], [72.11068726, 21.30374908], [72.11042023, 21.30374908], [72.11042023, 21.30318832], [72.11013794, 21.30319405], [72.11013794, 21.30291748], [72.10986328, 21.30291939], [72.10986328, 21.30264091], [72.10958099, 21.30264091], [72.10958099, 21.30236053], [72.10930634, 21.30236053], [72.10930634, 21.30151939], [72.10902405, 21.30152893], [72.10902405, 21.30069351], [72.10930634, 21.30069351], [72.10930634, 21.30041885], [72.10958099, 21.30042076], [72.10958099, 21.30014038], [72.10986328, 21.30014038], [72.10986328, 21.29957962], [72.11013794, 21.29958344], [72.11013794, 21.29930687], [72.11042023, 21.29931068], [72.11042023, 21.29874992], [72.11068726, 21.29874992], [72.11068726, 21.29681015], [72.11096954, 21.29681015], [72.11096954, 21.29624939], [72.11125183, 21.29624939], [72.11125183, 21.29597092], [72.11180878, 21.29597473], [72.11180878, 21.29347038], [72.11152649, 21.29347038], [72.11152649, 21.29319382], [72.11125183, 21.29319382], [72.11125183, 21.29263878], [72.11096954, 21.29264259], [72.11096954, 21.29070282], [72.11068726, 21.29070282], [72.11068726, 21.28957748], [72.11096954, 21.28958321], [72.11096954, 21.28874969], [72.11068726, 21.28874969], [72.11068726, 21.28819084], [72.11042023, 21.28819466], [72.11042023, 21.28763962], [72.11068726, 21.28763962], [72.11068726, 21.28708076], [72.11096954, 21.28708267], [72.11096954, 21.28680611], [72.11068726, 21.28680992], [72.11068726, 21.28653908], [72.11013794, 21.28653908], [72.11013794, 21.28597069], [72.10986328, 21.2859726], [72.10986328, 21.28569412], [72.10958099, 21.28569412], [72.10958099, 21.28541756], [72.10920715, 21.28541946], [72.10901642, 21.28541946], [72.10901642, 21.28458023], [72.10847473, 21.28458595], [72.10847473, 21.28375053], [72.10874939, 21.28375053], [72.10874939, 21.28347969], [72.10901642, 21.28347969], [72.10901642, 21.28292084], [72.10874939, 21.28291702], [72.10874939, 21.2831955], [72.10791779, 21.2831955], [72.10791779, 21.28291702], [72.10679626, 21.28292084], [72.10679626, 21.28264046], [72.10652924, 21.28264046], [72.10652924, 21.2820797], [72.10624695, 21.28208542], [72.10624695, 21.28180313], [72.10569763, 21.28181076], [72.10569763, 21.28153038], [72.10540771, 21.28153038], [72.10540771, 21.28125], [72.10514069, 21.28125], [72.10514069, 21.28070068], [72.1048584, 21.28070068], [72.1048584, 21.27985954], [72.10458374, 21.27986145], [72.10458374, 21.27930641], [72.10430908, 21.27931023], [72.10430908, 21.27903175], [72.10402679, 21.27903175], [72.10402679, 21.27874947], [72.10375214, 21.27874947], [72.10375214, 21.27846909], [72.10263824, 21.2784729], [72.10263824, 21.27819443], [72.1020813, 21.27819443], [72.1020813, 21.27791595], [72.10180664, 21.27791595], [72.10180664, 21.2784729], [72.10151672, 21.27846909], [72.10151672, 21.27874947], [72.10124969, 21.27874947], [72.10124969, 21.27931023], [72.10097504, 21.27930641], [72.10097504, 21.27986145], [72.10041809, 21.27985954], [72.10041809, 21.28014183], [72.09989166, 21.28014183], [72.09986115, 21.28070068], [72.09958649, 21.28069305], [72.09958649, 21.28097153], [72.09928894, 21.28096962], [72.09928894, 21.28153038], [72.09902954, 21.28152847], [72.09902954, 21.28208542], [72.09874725, 21.2820797], [72.09874725, 21.28264046], [72.0984726, 21.28263855], [72.0984726, 21.2831955], [72.09758759, 21.28319168], [72.09654236, 21.28318977], [72.09654236, 21.28347969], [72.09625244, 21.28347969], [72.09625244, 21.28403091], [72.09597015, 21.28402519], [72.09597015, 21.28458595], [72.0956955, 21.28458595], [72.09570313, 21.28486061], [72.09541321, 21.28486061], [72.09541321, 21.28514099], [72.09513855, 21.28514099], [72.09513855, 21.28541946], [72.09486389, 21.28541756], [72.09486389, 21.28569412], [72.0945816, 21.28569031], [72.0945816, 21.28625107], [72.09485626, 21.28625107], [72.09485626, 21.28736115], [72.0945816, 21.28736115], [72.0945816, 21.28763962], [72.09430695, 21.28763962], [72.09430695, 21.28791809], [72.09375, 21.28791809], [72.09375, 21.28763962], [72.09319305, 21.28763962], [72.09319305, 21.28736115], [72.09263611, 21.28736115], [72.09263611, 21.28708076], [72.09208679, 21.28708076], [72.09208679, 21.28736115], [72.09179688, 21.28736115], [72.09179688, 21.28763962], [72.09152985, 21.28763962], [72.09152985, 21.28791809], [72.09124756, 21.28791618], [72.09124756, 21.28847313], [72.0909729, 21.28847122], [72.0909729, 21.28874969], [72.09069824, 21.28874969], [72.09069824, 21.28902817], [72.09041595, 21.28902817], [72.09041595, 21.28958321], [72.0901413, 21.28957748], [72.0901413, 21.29041862], [72.08985901, 21.29041672], [72.08985901, 21.29097176], [72.08957672, 21.29097176], [72.08957672, 21.2918129], [72.08930206, 21.29180527], [72.08930206, 21.29208374], [72.0890274, 21.29208183], [72.0890274, 21.29264259], [72.08875275, 21.29263878], [72.08875275, 21.29319382], [72.08847046, 21.29319191], [72.08847046, 21.29403114], [72.0881958, 21.29402733], [72.0881958, 21.29458237], [72.08790588, 21.29458046], [72.08790588, 21.29514122], [72.08763885, 21.29513931], [72.08763885, 21.29597473], [72.08791351, 21.29597473], [72.08791351, 21.29708481], [72.08847046, 21.29708481], [72.08847046, 21.29736137], [72.08875275, 21.29735947], [72.08875275, 21.29763985], [72.0890274, 21.29763985], [72.0890274, 21.29848099], [72.08875275, 21.29848099], [72.08875275, 21.2990303], [72.08847046, 21.2990303], [72.08847046, 21.30014038], [72.08708191, 21.30014038], [72.08708191, 21.30042076], [72.08680725, 21.30041885], [72.08680725, 21.30319405], [72.08652496, 21.30319405], [72.08652496, 21.30347252], [72.08625031, 21.30347061], [72.08625031, 21.30431175], [72.08569336, 21.30430603], [72.08569336, 21.3045826], [72.08513641, 21.3045826], [72.08513641, 21.30430603], [72.08460236, 21.30431175], [72.08460236, 21.30374908], [72.08431244, 21.30374908], [72.08431244, 21.30347061], [72.08403015, 21.30347252], [72.08403015, 21.30291748], [72.08374786, 21.30291939], [72.08374786, 21.30236053], [72.08403015, 21.30236053], [72.08403015, 21.30151939], [72.08430481, 21.30152893], [72.08430481, 21.30125046], [72.08486176, 21.30125046], [72.08486176, 21.3006897], [72.08513641, 21.30069351], [72.08513641, 21.29930687], [72.0854187, 21.29931068], [72.0854187, 21.29848099], [72.08569336, 21.29848099], [72.08569336, 21.29819107], [72.08597565, 21.29819679], [72.08597565, 21.29736137], [72.08347321, 21.29736137], [72.08347321, 21.29624939], [72.08319092, 21.29624939], [72.08319092, 21.29597092], [72.08291626, 21.29597473], [72.08291626, 21.29569244], [72.0826416, 21.29569244], [72.0826416, 21.29541588], [72.08180237, 21.29541588], [72.08180237, 21.29569244], [72.08152771, 21.29569244], [72.08152771, 21.29597473], [72.08125305, 21.29597092], [72.08125305, 21.29652977], [72.08097076, 21.29652786], [72.08097076, 21.29708481], [72.08069611, 21.29708481], [72.08069611, 21.29736137], [72.08097076, 21.29735947], [72.08097076, 21.29874992], [72.08040619, 21.29874992], [72.08040619, 21.2990303], [72.08013916, 21.2990303], [72.08013916, 21.29931068], [72.0798645, 21.29930687], [72.07985687, 21.3006897], [72.07958221, 21.30069542], [72.07958221, 21.30097198], [72.07930756, 21.30097198], [72.07930756, 21.30152893], [72.07846832, 21.30151939], [72.07846832, 21.30181122], [72.07819366, 21.3018055], [72.07819366, 21.30208397], [72.07791901, 21.30207825], [72.07791901, 21.30236053], [72.07763672, 21.30236053], [72.07763672, 21.30264091], [72.07624817, 21.30264091], [72.07624817, 21.30207825], [72.07597351, 21.30208397], [72.07597351, 21.30069542], [72.07569122, 21.3006897], [72.07569122, 21.29930687], [72.07596588, 21.29931068], [72.07596588, 21.2990303], [72.07707977, 21.2990303], [72.07707977, 21.29931068], [72.07791901, 21.29931068], [72.07791901, 21.2990303], [72.0790329, 21.2990303], [72.0790329, 21.29848099], [72.07930756, 21.29848099], [72.07930756, 21.29763985], [72.07958221, 21.29763985], [72.07958221, 21.29652977], [72.07985687, 21.29652977], [72.07985687, 21.29569054], [72.08013916, 21.29569244], [72.08013916, 21.29486084], [72.07985687, 21.29486084], [72.07985687, 21.29403114], [72.08097076, 21.29403114], [72.08097076, 21.29375267], [72.08125305, 21.29375267], [72.08125305, 21.29347038], [72.08097076, 21.29347038], [72.08097076, 21.29319382], [72.08069611, 21.29319382], [72.08069611, 21.29263878], [72.08040619, 21.29264259], [72.08040619, 21.29235077], [72.08013916, 21.29236031], [72.08013916, 21.29208374], [72.0798645, 21.29208374], [72.0798645, 21.29180527], [72.07930756, 21.2918129], [72.07930756, 21.29153252], [72.0790329, 21.29153252], [72.0790329, 21.29125023], [72.07846832, 21.29125023], [72.07846832, 21.29153252], [72.07819366, 21.2915287], [72.07819366, 21.29208374], [72.07763672, 21.29208374], [72.07763672, 21.29236031], [72.07736206, 21.29236031], [72.07736206, 21.29180527], [72.07707977, 21.2918129], [72.07707977, 21.29153252], [72.07681274, 21.29153252], [72.07681274, 21.29097176], [72.07653046, 21.29097176], [72.07653046, 21.29069519], [72.07624817, 21.29070282], [72.07624817, 21.29041862], [72.07485962, 21.29041862], [72.07485962, 21.28957748], [72.07514191, 21.28958321], [72.07514191, 21.28874969], [72.07540894, 21.28874969], [72.07540894, 21.28847122], [72.07597351, 21.28847313], [72.07597351, 21.28819466], [72.07707977, 21.28819466], [72.07707977, 21.28847313], [72.07817841, 21.28847122], [72.07817841, 21.28874969], [72.07875061, 21.28874969], [72.07875061, 21.28902817], [72.07902527, 21.28902817], [72.07902527, 21.28930473], [72.07930756, 21.28930473], [72.07930756, 21.28958321], [72.0798645, 21.28958321], [72.0798645, 21.28986168], [72.08013916, 21.28985977], [72.08013916, 21.29013824], [72.08040619, 21.29013824], [72.08040619, 21.29041862], [72.08069611, 21.29041862], [72.08069611, 21.29070282], [72.08180237, 21.29069519], [72.08180237, 21.29097176], [72.08235931, 21.29097176], [72.08235931, 21.29125023], [72.0826416, 21.29125023], [72.0826416, 21.29153252], [72.08291626, 21.29153252], [72.08291626, 21.29125023], [72.08319092, 21.29125023], [72.08319092, 21.29070282], [72.08347321, 21.29070282], [72.08347321, 21.29041862], [72.08374786, 21.29041862], [72.08374786, 21.29013824], [72.08431244, 21.29013824], [72.08431244, 21.29041862], [72.08486176, 21.29041862], [72.08486176, 21.29013824], [72.08513641, 21.29013824], [72.08513641, 21.28874969], [72.08486176, 21.28874969], [72.08486176, 21.28680992], [72.08513641, 21.28680992], [72.08513641, 21.28597069], [72.0854187, 21.2859726], [72.0854187, 21.28430557], [72.08569336, 21.28430939], [72.08569336, 21.28403091], [72.08598328, 21.28403091], [72.08598328, 21.28236008], [72.08625031, 21.28236389], [72.08625031, 21.28152847], [72.08653259, 21.28153038], [72.08653259, 21.28070068], [72.08680725, 21.28070068], [72.08680725, 21.28014183], [72.08708191, 21.28014183], [72.08708191, 21.27931023], [72.08734894, 21.27931023], [72.08734894, 21.27903175], [72.08763885, 21.27903175], [72.08763885, 21.27874947], [72.08790588, 21.27874947], [72.08790588, 21.27819061], [72.08847046, 21.27819443], [72.08847046, 21.27763939], [72.08875275, 21.27763939], [72.08875275, 21.27734947], [72.08930206, 21.27736092], [72.08930206, 21.27708244], [72.08958435, 21.27708244], [72.08958435, 21.27680588], [72.09152985, 21.2768116], [72.09152985, 21.27625084], [72.09179688, 21.27625084], [72.09179688, 21.27597046], [72.09236145, 21.27597237], [72.09236145, 21.27541733], [72.0929184, 21.27541924], [72.0929184, 21.27486038], [72.09319305, 21.27486038], [72.09319305, 21.27457809], [72.09347534, 21.27458382], [72.09347534, 21.27430534], [72.0945816, 21.27431107], [72.0945816, 21.27514076], [72.09486389, 21.27513885], [72.09486389, 21.27569389], [72.09513855, 21.27568817], [72.09513855, 21.27652931], [72.09541321, 21.2765274], [72.09541321, 21.27736092], [72.0956955, 21.27736092], [72.0956955, 21.27763939], [72.09597015, 21.27763939], [72.09597015, 21.27792168], [72.09654236, 21.27792168], [72.09654236, 21.27734947], [72.09708405, 21.27736092], [72.09708405, 21.27708244], [72.0973587, 21.27708244], [72.0973587, 21.27597237], [72.09708405, 21.27597237], [72.09708405, 21.27541733], [72.09680176, 21.27541924], [72.09680176, 21.27457809], [72.09708405, 21.27458382], [72.09708405, 21.27347183], [72.0973587, 21.27347183], [72.0973587, 21.27319527], [72.09707642, 21.27320099], [72.09707642, 21.27207947], [72.0973587, 21.27208328], [72.0973587, 21.27152824], [72.09764099, 21.27153969], [72.09764099, 21.27124977], [72.09792328, 21.27124977], [72.09791565, 21.26958466], [72.09764099, 21.26958466], [72.09764099, 21.26625061], [72.0973587, 21.26625061], [72.0973587, 21.26458168], [72.09791565, 21.26458359], [72.09791565, 21.26430511], [72.09819794, 21.26431274], [72.09819794, 21.26402855], [72.09792328, 21.26402855], [72.09792328, 21.26374817], [72.09764099, 21.26374817], [72.09764099, 21.2634697], [72.0973587, 21.2634716], [72.0973587, 21.26319504], [72.09707642, 21.26320076], [72.09707642, 21.26263809], [72.09680176, 21.26263809], [72.09680176, 21.26236916], [72.09597015, 21.26236916], [72.09597015, 21.26208115], [72.0956955, 21.26208305], [72.0956955, 21.26180649], [72.09541321, 21.2618084], [72.09541321, 21.26152992], [72.0945816, 21.26152992], [72.0945816, 21.26124954], [72.09430695, 21.26124954], [72.09430695, 21.26152992], [72.09375, 21.26152992], [72.09375, 21.2618084], [72.09263611, 21.2618084], [72.09263611, 21.26152992], [72.09236145, 21.26152992], [72.09236145, 21.26013947], [72.09208679, 21.26013947], [72.09208679, 21.25958061], [72.0918045, 21.25958252], [72.0918045, 21.25902748], [72.09152985, 21.25902939], [72.09152985, 21.25847054], [72.09124756, 21.25847244], [72.09124756, 21.25819588], [72.0909729, 21.25819588], [72.0909729, 21.25763893], [72.09069824, 21.25764084], [72.09069061, 21.25708008], [72.09041595, 21.2570858], [72.09041595, 21.25652695], [72.0901413, 21.25653076], [72.0901413, 21.25624275], [72.08985901, 21.25625038], [72.08985901, 21.25569534], [72.08957672, 21.25570107], [72.08957672, 21.25542068], [72.08930206, 21.25542068], [72.08930206, 21.2551403], [72.0890274, 21.2551403], [72.0890274, 21.25457954], [72.08875275, 21.25458145], [72.08875275, 21.25430489], [72.08847046, 21.25430489], [72.08847046, 21.25374985], [72.0881958, 21.25374985], [72.0881958, 21.25346947], [72.08791351, 21.25347137], [72.08791351, 21.25319481], [72.08763885, 21.25319481], [72.08763885, 21.25263977], [72.08734894, 21.25263977], [72.08734894, 21.25235939], [72.08708191, 21.2523613], [72.08708191, 21.25208282], [72.08680725, 21.25208282], [72.08680725, 21.25152779], [72.08653259, 21.2515316], [72.08653259, 21.25124931], [72.08625031, 21.25124931], [72.08625031, 21.25069046], [72.08597565, 21.25069427], [72.08597565, 21.2504158], [72.0854187, 21.25043106], [72.0854187, 21.24986076], [72.08513641, 21.24986076], [72.08513641, 21.24931145], [72.08486176, 21.24930573], [72.08486176, 21.2495842], [72.0845871, 21.2495842], [72.0845871, 21.25069427], [72.08431244, 21.25069046], [72.08431244, 21.25124931], [72.08403015, 21.25124931], [72.08403015, 21.2515316], [72.08374786, 21.2515316], [72.08374786, 21.25181007], [72.08347321, 21.25180626], [72.08347321, 21.25208282], [72.08208466, 21.25208282], [72.08208466, 21.25180626], [72.08152771, 21.25181007], [72.08152771, 21.25097084], [72.08125305, 21.25097275], [72.08125305, 21.24847221], [72.08152771, 21.24847221], [72.08152771, 21.2476387], [72.08180237, 21.24764061], [72.08180237, 21.24653053], [72.08207703, 21.24653053], [72.08207703, 21.24570084], [72.0826416, 21.24570084], [72.0826416, 21.24542046], [72.08291626, 21.24542046], [72.08291626, 21.24514008], [72.08347321, 21.24514008], [72.08347321, 21.2448597], [72.08374786, 21.2448616], [72.08374786, 21.24430656], [72.08430481, 21.24430656], [72.08430481, 21.24402809], [72.08460236, 21.24403], [72.08460236, 21.24374962], [72.08513641, 21.24374962], [72.08513641, 21.24291992], [72.0854187, 21.24291992], [72.0854187, 21.24263954], [72.08569336, 21.24263954], [72.08569336, 21.24180984], [72.08598328, 21.24180984], [72.08598328, 21.23847008], [72.08625031, 21.23847008], [72.08625031, 21.23624992], [72.08653259, 21.23624992], [72.08652496, 21.23541641], [72.08680725, 21.23543167], [72.08680725, 21.23458099], [72.08708191, 21.2345829], [72.08708191, 21.23347282], [72.0873642, 21.23347282], [72.0873642, 21.23291779], [72.08763885, 21.23291969], [72.08763885, 21.23180962], [72.08790588, 21.23180962], [72.08790588, 21.23097038], [72.0881958, 21.23097229], [72.0881958, 21.23041725], [72.08847046, 21.23042107], [72.08847046, 21.22986031], [72.08875275, 21.22986031], [72.08875275, 21.22903061], [72.0890274, 21.22903061], [72.0890274, 21.22875023], [72.08930206, 21.22875023], [72.08930206, 21.22846985], [72.08958435, 21.22847366], [72.08958435, 21.22791672], [72.0901413, 21.22792053], [72.0901413, 21.22764015], [72.09040833, 21.22764015], [72.09040833, 21.22735977], [72.09069061, 21.22736359], [72.09069824, 21.2270813], [72.0909729, 21.2270813], [72.0909729, 21.22652817], [72.09179688, 21.22653008], [72.09179688, 21.22624016], [72.0929184, 21.22624969], [72.0929184, 21.22597122], [72.09319305, 21.22597122], [72.09319305, 21.22569466], [72.09347534, 21.22569466], [72.09347534, 21.22541618], [72.09401703, 21.22542191], [72.09401703, 21.22513962], [72.09485626, 21.22513962], [72.09485626, 21.22485924], [72.09513855, 21.22485924], [72.09513855, 21.22458076], [72.09541321, 21.22458267], [72.09541321, 21.22402763], [72.09570313, 21.22402954], [72.09570313, 21.22374916], [72.09597015, 21.22374916], [72.09597015, 21.22347069], [72.09625244, 21.2234726], [72.09625244, 21.22291756], [72.10124969, 21.22292137], [72.10124969, 21.22320175], [72.10180664, 21.22319412], [72.10180664, 21.2234726], [72.1020813, 21.22347069], [72.1020813, 21.22374916], [72.10234833, 21.22374916], [72.10234833, 21.22402954], [72.1029129, 21.22402954], [72.1029129, 21.22431183], [72.10346985, 21.22430611], [72.10346985, 21.22458267], [72.10402679, 21.22458076], [72.10402679, 21.22485924], [72.10430908, 21.22485924], [72.10430908, 21.22431183], [72.10457611, 21.22431183], [72.10457611, 21.22374916], [72.1048584, 21.22374916], [72.1048584, 21.22320175], [72.10514069, 21.22320175], [72.10514069, 21.22236061], [72.10540771, 21.22236061], [72.10540771, 21.22180748], [72.10597229, 21.22180748], [72.10597229, 21.22153091], [72.10624695, 21.22153091], [72.10624695, 21.22125053], [72.10679626, 21.22125053], [72.10679626, 21.22097015], [72.10847473, 21.22097206], [72.10847473, 21.22069359], [72.10902405, 21.22069359], [72.10902405, 21.22097206], [72.10930634, 21.22097206], [72.10930634, 21.22113037], [72.10930634, 21.2234726], [72.10902405, 21.2234726], [72.10902405, 21.22458267], [72.10874939, 21.22458076], [72.10874939, 21.22485924], [72.10901642, 21.22485924], [72.10901642, 21.22513962], [72.10986328, 21.22513962], [72.10986328, 21.22485924], [72.11042023, 21.22485924], [72.11042023, 21.22431183], [72.11096954, 21.22431183], [72.11096954, 21.22402954], [72.11125183, 21.22402954], [72.11125183, 21.22374916], [72.11154175, 21.22374916], [72.11154175, 21.22263908], [72.11235809, 21.22263908], [72.11235809, 21.22153091], [72.11180878, 21.22153091], [72.11180878, 21.22125053], [72.11152649, 21.22125053], [72.11152649, 21.22041893], [72.11125183, 21.22042084], [72.11125183, 21.21986008], [72.11096954, 21.21986198], [72.11096954, 21.21957016], [72.11096954, 21.21930695], [72.11042023, 21.21931076], [72.11042023, 21.21903038], [72.10930634, 21.21903038], [72.10930634, 21.21820068], [72.10848236, 21.21820068], [72.10848236, 21.2179203], [72.10679626, 21.2179203], [72.10679626, 21.21763992], [72.10624695, 21.21763992], [72.10624695, 21.21735954], [72.10597229, 21.21736145], [72.10597229, 21.21708488], [72.10541534, 21.21708488], [72.10541534, 21.21624947], [72.10514069, 21.21624947], [72.10514069, 21.21541977], [72.10540771, 21.21541977], [72.10540771, 21.21513939], [72.10569763, 21.21513939], [72.10569763, 21.21486282], [72.10624695, 21.21486282], [72.10624695, 21.21458054], [72.10791779, 21.21458054], [72.10791779, 21.21486282], [72.10930634, 21.21486282], [72.10930634, 21.21458054], [72.11042023, 21.21458244], [72.11042023, 21.21430588], [72.11096954, 21.21432114], [72.11096954, 21.21403122], [72.11125183, 21.21403122], [72.11125183, 21.21375275], [72.11154175, 21.21375275], [72.11152649, 21.21347046], [72.11208344, 21.21347046], [72.11208344, 21.21263885], [72.11235809, 21.21264267], [72.11235809, 21.21181107], [72.11319733, 21.21180534], [72.11319733, 21.21208382], [72.11374664, 21.21208382], [72.11374664, 21.21180534], [72.11428833, 21.21181107], [72.11428833, 21.21125984], [72.11374664, 21.21125984], [72.11374664, 21.21097183], [72.11347198, 21.21097183], [72.11347198, 21.21069527], [72.11292267, 21.2107029], [72.11292267, 21.2104187], [72.11264038, 21.2104187], [72.11264038, 21.20929909], [72.11291504, 21.20930481], [72.11291504, 21.20708275], [72.11264038, 21.20708275], [72.11264038, 21.20680618], [72.11235809, 21.20680809], [72.11235809, 21.20652962], [72.11207581, 21.20652962], [72.11207581, 21.20625114], [72.11180878, 21.20625114], [72.11180878, 21.20597076], [72.11096954, 21.20597267], [72.11096954, 21.2056942], [72.11069489, 21.2056942], [72.11069489, 21.20541763], [72.11042023, 21.20541954], [72.11042023, 21.20458031], [72.11096954, 21.20458412], [72.11096954, 21.20430565], [72.11180878, 21.20430946], [72.11180878, 21.20347023], [72.11264038, 21.20347023], [72.11264038, 21.20375061], [72.11292267, 21.20375061], [72.11292267, 21.20403099], [72.11319733, 21.20403099], [72.11319733, 21.20292091], [72.11486053, 21.20292091], [72.11486053, 21.20264053], [72.11514282, 21.20264053], [72.11514282, 21.20207024], [72.11541748, 21.20208549], [72.11541748, 21.2009716], [72.11513519, 21.2009716], [72.11513519, 21.20013809], [72.11486053, 21.20014191], [72.11486053, 21.19985962], [72.11458588, 21.19986343], [72.11458588, 21.1981945], [72.11430359, 21.1981945], [72.11430359, 21.19763947], [72.11402893, 21.19763947], [72.11402893, 21.19708061], [72.11374664, 21.19708252], [72.11374664, 21.19652748], [72.11319733, 21.19652939], [72.11319733, 21.19626236], [72.11235809, 21.19626236], [72.11235809, 21.19652939], [72.11125183, 21.19652939], [72.11125183, 21.19681168], [72.11042023, 21.19681168], [72.11042023, 21.19652939], [72.11013794, 21.19652939], [72.11013794, 21.19626236], [72.10930634, 21.19626236], [72.10930634, 21.19597054], [72.10847473, 21.19597244], [72.10847473, 21.19569397], [72.10791779, 21.19569397], [72.10791779, 21.1954174], [72.10764313, 21.19542122], [72.10764313, 21.19514084], [72.10680389, 21.19513893], [72.10680389, 21.19569397], [72.10708618, 21.19569397], [72.10708618, 21.19597244], [72.10764313, 21.19597054], [72.10764313, 21.19626236], [72.10819244, 21.19626236], [72.10819244, 21.19652939], [72.10847473, 21.19652748], [72.10847473, 21.19708252], [72.1076355, 21.19708252], [72.1076355, 21.19680595], [72.10569763, 21.19681168], [72.10569763, 21.19626236], [72.10514069, 21.19626236], [72.10514069, 21.19597054], [72.1048584, 21.19597244], [72.1048584, 21.19569397], [72.10319519, 21.19569397], [72.10319519, 21.1954174], [72.1029129, 21.19542122], [72.1029129, 21.19514084], [72.10234833, 21.19514084], [72.10234833, 21.19486046], [72.10180664, 21.19486046], [72.10180664, 21.19458008], [72.10124969, 21.19458389], [72.10124969, 21.19430542], [72.10098267, 21.19431114], [72.10098267, 21.19403076], [72.10069275, 21.19403076], [72.10069275, 21.19347], [72.10041809, 21.19347191], [72.10041809, 21.19319534], [72.09986115, 21.19319534], [72.09986115, 21.19347191], [72.0984726, 21.19347191], [72.0984726, 21.19319534], [72.09791565, 21.19319534], [72.09791565, 21.19291687], [72.09764099, 21.19292068], [72.09764099, 21.1926403], [72.09707642, 21.1926403], [72.09707642, 21.19235992], [72.09654236, 21.19235992], [72.09654236, 21.1926403], [72.09625244, 21.1926403], [72.09625244, 21.19292068], [72.09541321, 21.19292068], [72.09541321, 21.19235992], [72.09513855, 21.19236183], [72.09513855, 21.19208336], [72.0945816, 21.19208336], [72.0945816, 21.19180679], [72.09263611, 21.19180679], [72.09263611, 21.19152832], [72.09208679, 21.19153023], [72.09208679, 21.19124985], [72.09179688, 21.19124985], [72.09179688, 21.19096947], [72.0901413, 21.19097137], [72.0901413, 21.19069672], [72.08958435, 21.19069672], [72.08958435, 21.19013977], [72.08930206, 21.19013023], [72.08930206, 21.19042015], [72.08708191, 21.19042015], [72.08708191, 21.18875122], [72.08734894, 21.18875122], [72.08734894, 21.18736076], [72.08708191, 21.18736076], [72.08708191, 21.18708992], [72.08625031, 21.18708992], [72.08625031, 21.18680954], [72.08431244, 21.18680954], [72.08431244, 21.18653107], [72.08403015, 21.18653107], [72.08403015, 21.18625259], [72.08235931, 21.18625259], [72.08235931, 21.18653107], [72.08207703, 21.18653107], [72.08207703, 21.18625259], [72.08180237, 21.18625259], [72.08180237, 21.18597031], [72.08152771, 21.18597031], [72.08152771, 21.18569374], [72.08097076, 21.18569374], [72.08097076, 21.18541718], [72.08040619, 21.1854229], [72.08040619, 21.18514252], [72.08013916, 21.18514252], [72.08013916, 21.18486023], [72.07958221, 21.18486023], [72.07958221, 21.18432045], [72.07930756, 21.18432045], [72.07930756, 21.18374825], [72.07902527, 21.18374825], [72.07902527, 21.18319511], [72.07875061, 21.18320084], [72.07875061, 21.18291855], [72.07846832, 21.18291855], [72.07846832, 21.1823597], [72.07736206, 21.1823616], [72.07736206, 21.18180466], [72.07624817, 21.18180466], [72.07624817, 21.18124962], [72.07596588, 21.18124962], [72.07596588, 21.18069077], [72.07569122, 21.18069458], [72.07569122, 21.18041611], [72.07540894, 21.18041992], [72.07540894, 21.18013954], [72.07514191, 21.18013954], [72.07514191, 21.17958069], [72.07485962, 21.1795826], [72.07485962, 21.17930794], [72.07430267, 21.17930984], [72.07430267, 21.17902946], [72.07319641, 21.17902946], [72.07319641, 21.17875099], [72.07237244, 21.17875099], [72.07237244, 21.17902946], [72.07180786, 21.17902946], [72.07180786, 21.17930984], [72.07096863, 21.17930794], [72.07096863, 21.1795826], [72.07041931, 21.17958069], [72.07041931, 21.17986107], [72.07013702, 21.17986107], [72.07013702, 21.17958069], [72.06903076, 21.1795826], [72.06903076, 21.17930794], [72.06874847, 21.17930984], [72.06874847, 21.17902946], [72.06846619, 21.17902946], [72.06846619, 21.17764091], [72.06791687, 21.17764091], [72.06791687, 21.17736053], [72.06764221, 21.17736053], [72.06764221, 21.17708015], [72.06735992, 21.17708015], [72.06735992, 21.17736053], [72.06680298, 21.17736053], [72.06680298, 21.17764091], [72.06652832, 21.17764091], [72.06652832, 21.17791939], [72.06597137, 21.17791748], [72.06597137, 21.17819595], [72.06541443, 21.17819595], [72.06541443, 21.17763901], [72.06458282, 21.17764091], [72.06458282, 21.17736053], [72.06402588, 21.17736053], [72.06402588, 21.17681122], [72.06375122, 21.17681122], [72.06375122, 21.17431068], [72.06346893, 21.17431068], [72.06346893, 21.17374992], [72.06317902, 21.17374992], [72.06317902, 21.17319107], [72.06291962, 21.17319489], [72.06291962, 21.17264175], [72.06208038, 21.17264175], [72.06208038, 21.17235947], [72.06181335, 21.17235947], [72.06181335, 21.17264175], [72.06153107, 21.17264175], [72.06153107, 21.17292023], [72.06069183, 21.17291641], [72.06069183, 21.17319489], [72.05986023, 21.17319489], [72.05986023, 21.17291641], [72.05958557, 21.17291641], [72.05958557, 21.17319489], [72.05902863, 21.17319107], [72.05902863, 21.17431068], [72.05930328, 21.17430305], [72.05930328, 21.17486382], [72.05847168, 21.17486382], [72.05847168, 21.17458153], [72.05680847, 21.17458153], [72.05680847, 21.17430305], [72.05625153, 21.17431068], [72.05625153, 21.1740303], [72.05568695, 21.1740303], [72.05568695, 21.17374992], [72.05541992, 21.17374992], [72.05541992, 21.17346954], [72.05513763, 21.17347145], [72.05513763, 21.17263794], [72.05541992, 21.17264175], [72.05541992, 21.17235947], [72.05625153, 21.17236137], [72.05625153, 21.17124939], [72.05568695, 21.17124939], [72.05568695, 21.17097092], [72.05513763, 21.17097282], [72.05513763, 21.17069435], [72.05486298, 21.17069435], [72.05486298, 21.17041588], [72.05458069, 21.1704216], [72.05458069, 21.17013931], [72.0542984, 21.17013931], [72.0542984, 21.16931152], [72.05374908, 21.16931152], [72.05374908, 21.1690197], [72.05347443, 21.16902733], [72.05347443, 21.16847229], [72.05319214, 21.16847229], [72.05319214, 21.16791725], [72.05291748, 21.16791916], [72.05291748, 21.16736031], [72.05263519, 21.16736031], [72.05263519, 21.16708374], [72.05208588, 21.16708374], [72.05208588, 21.16680527], [72.05179596, 21.16681099], [72.05179596, 21.16596031], [72.05152893, 21.16597176], [72.05152893, 21.16569519], [72.05123901, 21.16570091], [72.05123901, 21.16542053], [72.05097198, 21.16542053], [72.05097198, 21.16485977], [72.05069733, 21.16486168], [72.05069733, 21.16458321], [72.05041504, 21.16458321], [72.05041504, 21.16430664], [72.05014038, 21.16430664], [72.05014038, 21.16402817], [72.04875183, 21.16403008], [72.04875183, 21.16292], [72.04846954, 21.16292], [72.04846954, 21.16208076], [72.04819489, 21.16208458], [72.04819489, 21.16180611], [72.04792023, 21.16180992], [72.04792023, 21.16069031], [72.04763794, 21.16069221], [72.04763794, 21.16041756], [72.04680634, 21.16041946], [72.04680634, 21.15930939], [72.04651642, 21.15930939], [72.04651642, 21.15903282], [72.04541779, 21.1590271], [72.04543304, 21.15986061], [72.04458618, 21.15986061], [72.04458618, 21.15958023], [72.04429626, 21.15958023], [72.04429626, 21.15986061], [72.04347229, 21.15986061], [72.04347229, 21.15958023], [72.04264069, 21.15958023], [72.04264069, 21.15986061], [72.0423584, 21.15986061], [72.0423584, 21.16069221], [72.04208374, 21.16069221], [72.04208374, 21.1609745], [72.0423584, 21.16097069], [72.0423584, 21.16180992], [72.04264069, 21.16180611], [72.04264069, 21.16208458], [72.0423584, 21.16208076], [72.0423584, 21.16236115], [72.04206848, 21.16236115], [72.04206848, 21.16263962], [72.04152679, 21.16263962], [72.04152679, 21.16236115], [72.04180908, 21.16236115], [72.04180908, 21.16208076], [72.04152679, 21.16208458], [72.04152679, 21.16180611], [72.04125214, 21.16180992], [72.04125214, 21.16152954], [72.04070282, 21.16152954], [72.04070282, 21.16180992], [72.03874969, 21.16180992], [72.03874969, 21.16152954], [72.03848267, 21.16152954], [72.03848267, 21.16041946], [72.03819275, 21.16041946], [72.03819275, 21.15986061], [72.03791809, 21.15986061], [72.03791809, 21.15958023], [72.0376358, 21.15958214], [72.0376358, 21.15930557], [72.03736115, 21.15930939], [72.03736115, 21.15903282], [72.03708649, 21.15903282], [72.03708649, 21.15875053], [72.03679657, 21.15875053], [72.03679657, 21.15847015], [72.03569794, 21.15847015], [72.03569794, 21.15819359], [72.03541565, 21.15819359], [72.03541565, 21.15791702], [72.03457642, 21.15792274], [72.03457642, 21.15764236], [72.0340271, 21.15764236], [72.0340271, 21.15735817], [72.03375244, 21.15736008], [72.03375244, 21.15708351], [72.03347015, 21.15708351], [72.03347015, 21.15680504], [72.03291321, 21.15680504], [72.03291321, 21.15708351], [72.0320816, 21.15708351], [72.0320816, 21.15680504], [72.03125, 21.15681076], [72.03125, 21.15652847], [72.0304184, 21.15652847], [72.0304184, 21.15624809], [72.03012848, 21.15624809], [72.03012848, 21.15596962], [72.02986145, 21.15597153], [72.02986145, 21.15569496], [72.02902985, 21.15570068], [72.02902985, 21.1554184], [72.02874756, 21.1554184], [72.02874756, 21.15513992], [72.02791595, 21.15513992], [72.02791595, 21.15485954], [72.02735901, 21.15486145], [72.02735901, 21.15458298], [72.02680206, 21.15458298], [72.02680206, 21.15430641], [72.02625275, 21.15430832], [72.02625275, 21.15402031], [72.02346039, 21.15402794], [72.02319336, 21.15402794], [72.02319336, 21.15374947], [72.02153015, 21.15374947], [72.02153015, 21.15458298], [72.0220871, 21.15458298], [72.0220871, 21.15486145], [72.02236176, 21.15485954], [72.02236176, 21.15513992], [72.02263641, 21.15513992], [72.02263641, 21.15570068], [72.02179718, 21.15570068], [72.02179718, 21.1554184], [72.02069092, 21.1554184], [72.02069092, 21.15513992], [72.0201416, 21.15513992], [72.0201416, 21.15485954], [72.01930237, 21.15486145], [72.01930237, 21.15458298], [72.01902771, 21.15458298], [72.01902771, 21.15430641], [72.01818848, 21.15430832], [72.01818848, 21.15402031], [72.01791382, 21.15402794], [72.01791382, 21.1534729], [72.01763916, 21.1534729], [72.01763916, 21.15319443], [72.0173645, 21.15319443], [72.0173645, 21.15263939], [72.01763916, 21.15263939], [72.01763916, 21.15153122], [72.01790619, 21.15153122], [72.01790619, 21.15125084], [72.01763916, 21.15125084], [72.01763916, 21.15042114], [72.01735687, 21.15042114], [72.01735687, 21.14986038], [72.01680756, 21.14986038], [72.01680756, 21.14958], [72.01652527, 21.14958572], [72.01652527, 21.14902687], [72.01597595, 21.14903069], [72.01597595, 21.14875031], [72.01541901, 21.14875031], [72.01541901, 21.14846992], [72.01486206, 21.14847374], [72.01486206, 21.14819527], [72.01264191, 21.14821053], [72.01264191, 21.14792061], [72.01209259, 21.14792061], [72.01209259, 21.14764023], [72.01180267, 21.14764023], [72.01180267, 21.14735985], [72.01125336, 21.14736366], [72.01125336, 21.14708138], [72.01097107, 21.14708138], [72.01097107, 21.14652824], [72.01069641, 21.14653015], [72.01069641, 21.14624977], [72.01040649, 21.14624977], [72.01040649, 21.14596939], [72.01013947, 21.1459713], [72.01013947, 21.14569473], [72.00986481, 21.14569473], [72.00986481, 21.14458275], [72.01013947, 21.14458275], [72.01013947, 21.14291763], [72.00985718, 21.14292145], [72.00985718, 21.14208031], [72.00958252, 21.14208412], [72.00958252, 21.14152718], [72.00932312, 21.14152908], [72.00932312, 21.14097023], [72.00958252, 21.14097214], [72.00958252, 21.14069366], [72.00986481, 21.14069366], [72.00986481, 21.13958359], [72.01013947, 21.13958359], [72.01013947, 21.13930511], [72.01097107, 21.13931084], [72.01097107, 21.13903809], [72.01125336, 21.13903809], [72.01125336, 21.1384697], [72.01097107, 21.1384716], [72.01097107, 21.13652802], [72.01125336, 21.13652992], [72.01125336, 21.13513947], [72.01097107, 21.13513947], [72.01097107, 21.1348629], [72.01069641, 21.1348629], [72.01069641, 21.13458061], [72.01041412, 21.13458443], [72.01041412, 21.13430405], [72.01013947, 21.13430977], [72.01013947, 21.13375282], [72.00958252, 21.13375282], [72.00958252, 21.13347054], [72.00875092, 21.13347054], [72.00875092, 21.1329174], [72.00818634, 21.13292122], [72.00818634, 21.13264275], [72.00763702, 21.13264275], [72.00763702, 21.13292122], [72.00736237, 21.1329174], [72.00736237, 21.13319206], [72.00708008, 21.13319016], [72.00708008, 21.13402939], [72.00624847, 21.13402748], [72.00624847, 21.13458443], [72.00596619, 21.13458061], [72.00596619, 21.1348629], [72.00624847, 21.1348629], [72.00624847, 21.13598061], [72.00680542, 21.13597488], [72.00680542, 21.13624954], [72.00708008, 21.13624954], [72.00708008, 21.13680077], [72.00736237, 21.13680649], [72.00736237, 21.13736153], [72.00708008, 21.13735962], [72.00708008, 21.13764], [72.00596619, 21.13764], [72.00596619, 21.13735962], [72.00541687, 21.13736153], [72.00541687, 21.13680649], [72.00485992, 21.1368103], [72.00485992, 21.13652992], [72.0032196, 21.13652992], [72.00318909, 21.1368103], [72.00263977, 21.13680649], [72.00263977, 21.13708305], [72.00235748, 21.13708305], [72.00235748, 21.1384716], [72.00263977, 21.1384697], [72.00263977, 21.13931084], [72.00289917, 21.13931084], [72.00291443, 21.13986015], [72.00357056, 21.13986015], [72.00430298, 21.13986206], [72.00430298, 21.14097214], [72.00374603, 21.14097023], [72.00373077, 21.14152908], [72.00208282, 21.14152908], [72.00208282, 21.14180756], [72.00041962, 21.14180756], [72.00041962, 21.14152908], [71.99986267, 21.14152908], [71.99986267, 21.14125061], [71.99846649, 21.14125061], [71.99846649, 21.14152908], [71.99791718, 21.14152908], [71.99791718, 21.14180756], [71.99736023, 21.14180565], [71.99736023, 21.14208412], [71.99708557, 21.14208412], [71.99708557, 21.14680481], [71.99680328, 21.14680481], [71.99680328, 21.14736366], [71.9970932, 21.14735985], [71.9970932, 21.14792061], [71.99736023, 21.14792061], [71.99736023, 21.14821053], [71.99764252, 21.14821053], [71.99764252, 21.14792061], [71.99874878, 21.14792061], [71.99874878, 21.14821053], [71.99903107, 21.14819527], [71.99903107, 21.14882088], [71.99903107, 21.1506958], [71.99930573, 21.1506958], [71.99930573, 21.15236092], [71.99958038, 21.15236092], [71.99958038, 21.1534729], [72.0, 21.1534729], [72.00041962, 21.1534729], [72.00041962, 21.15319443], [72.00069427, 21.15319443], [72.00069427, 21.15291786], [72.00125122, 21.15291786], [72.00125122, 21.1534729], [72.00180817, 21.15347099], [72.00180817, 21.15374947], [72.00235748, 21.15374947], [72.00235748, 21.15291977], [72.00289917, 21.15291977], [72.00289917, 21.15263939], [72.00347137, 21.15263939], [72.00347137, 21.15236092], [72.00430298, 21.15236092], [72.00430298, 21.15263939], [72.0045929, 21.15263939], [72.0045929, 21.15291977], [72.00485992, 21.15291786], [72.00485992, 21.15319443], [72.00514221, 21.15319061], [72.00514221, 21.15374947], [72.00541687, 21.15374947], [72.00541687, 21.15458298], [72.00569153, 21.15458298], [72.00569153, 21.15486145], [72.00624847, 21.15485954], [72.00624847, 21.15513992], [72.00653076, 21.15513992], [72.00653076, 21.1554184], [72.00708008, 21.1554184], [72.00708008, 21.15570068], [72.00736237, 21.15569496], [72.00736237, 21.15597153], [72.00791931, 21.15596962], [72.00791931, 21.15624809], [72.00846863, 21.15624809], [72.00846863, 21.15681076], [72.00875092, 21.15680504], [72.00875092, 21.15736008], [72.0090332, 21.15735817], [72.0090332, 21.15792274], [72.00875092, 21.15791702], [72.00875092, 21.15819359], [72.00846863, 21.15819359], [72.00846863, 21.15847015], [72.00818634, 21.15847015], [72.00818634, 21.15875053], [72.00791931, 21.15875053], [72.00791931, 21.15903282], [72.00736237, 21.1590271], [72.00736237, 21.15958214], [72.00653076, 21.15958023], [72.00653076, 21.15986061], [72.00624847, 21.15986061], [72.00624847, 21.16060066], [72.00624847, 21.16125107], [72.00653076, 21.16124916], [72.00653076, 21.1614418], [72.00653076, 21.16152763], [72.00680542, 21.16152763], [72.00680542, 21.16208458], [72.00736237, 21.16208076], [72.00736237, 21.16236115], [72.00846863, 21.16236115], [72.00846863, 21.16263962], [72.0090332, 21.16263962], [72.0090332, 21.16292], [72.00930786, 21.16291428], [72.00930786, 21.16319466], [72.00986481, 21.16319466], [72.00986481, 21.16347313], [72.01069641, 21.16347122], [72.01069641, 21.16374969], [72.01097107, 21.16374969], [72.01097107, 21.16403008], [72.01208496, 21.16402817], [72.01208496, 21.16430664], [72.01235962, 21.16430664], [72.01235962, 21.16458321], [72.01374817, 21.16458321], [72.01374817, 21.16486168], [72.01430511, 21.16486168], [72.01430511, 21.16597176], [72.01457977, 21.16596031], [72.01457977, 21.16764069], [72.01430511, 21.16763878], [72.01430511, 21.16819382], [72.01208496, 21.16819382], [72.01208496, 21.16847229], [72.01180267, 21.16847038], [72.01180267, 21.17013931], [72.01208496, 21.17013931], [72.01208496, 21.17069435], [72.01235962, 21.17069435], [72.01235962, 21.17080116], [72.01235962, 21.17097282], [72.01264954, 21.17095947], [72.01264191, 21.17124939], [72.01319885, 21.17123985], [72.01319122, 21.17153168], [72.0137558, 21.17152786], [72.01403046, 21.17153168], [72.01403046, 21.17124939], [72.01486206, 21.17124939], [72.01486206, 21.17097092], [72.01513672, 21.17097282], [72.01513672, 21.17069435], [72.01541901, 21.17069435], [72.01541901, 21.17041588], [72.01597595, 21.17041588], [72.01597595, 21.17069435], [72.01680756, 21.17069054], [72.01680756, 21.17124939], [72.01708221, 21.17124939], [72.01708221, 21.17181015], [72.0173645, 21.17180634], [72.0173645, 21.17236137], [72.01763916, 21.17235947], [72.01763916, 21.17292023], [72.01791382, 21.17291641], [72.01791382, 21.17319489], [72.01818848, 21.17319107], [72.01818848, 21.17374992], [72.01847076, 21.17374992], [72.01847076, 21.17430305], [72.01856995, 21.17431068], [72.01875305, 21.17430305], [72.01875305, 21.17443275], [72.01875305, 21.17542076], [72.01902771, 21.17541695], [72.01902771, 21.17569542], [72.01930237, 21.1756897], [72.01930237, 21.17625046], [72.01985931, 21.17625046], [72.01985931, 21.17653084], [72.0201416, 21.17653084], [72.0201416, 21.17681122], [72.02041626, 21.1768055], [72.02041626, 21.17708588], [72.02097321, 21.17708015], [72.02097321, 21.17791939], [72.02153015, 21.17791748], [72.02153015, 21.17847252], [72.02179718, 21.17847061], [72.02179718, 21.17875099], [72.0220871, 21.17875099], [72.0220871, 21.17902946], [72.02319336, 21.17902756], [72.02319336, 21.1795826], [72.02347565, 21.1795826], [72.02347565, 21.17986107], [72.02375031, 21.17986107], [72.02375031, 21.18097305], [72.02348328, 21.1809597], [72.02348328, 21.18152809], [72.0229187, 21.18152809], [72.0229187, 21.18180466], [72.02180481, 21.18180466], [72.02180481, 21.18208313], [72.02153015, 21.18208122], [72.02153015, 21.18263817], [72.0220871, 21.18263817], [72.0220871, 21.18374825], [72.02124786, 21.18374825], [72.02124786, 21.18347168], [72.02069092, 21.18346977], [72.02069092, 21.18432045], [72.02124786, 21.18430519], [72.02126312, 21.18486023], [72.02097321, 21.18486023], [72.02097321, 21.1854229], [72.02069092, 21.1854229], [72.02069092, 21.18653107], [72.02041626, 21.18653107], [72.02041626, 21.18680954], [72.01847076, 21.18680954], [72.01847076, 21.18736076], [72.01819611, 21.18736076], [72.01819611, 21.18819237], [72.01763916, 21.18819237], [72.01763916, 21.1879158], [72.01735687, 21.18791962], [72.01735687, 21.18764114], [72.01708221, 21.18764114], [72.01708221, 21.18708992], [72.01680756, 21.18708992], [72.01680756, 21.18625259], [72.01652527, 21.18625259], [72.01652527, 21.18597031], [72.01512909, 21.18597031], [72.01512909, 21.18708992], [72.01457977, 21.18708992], [72.01457977, 21.18680954], [72.01431274, 21.18680954], [72.01431274, 21.18653107], [72.01374817, 21.18653107], [72.01374817, 21.18625259], [72.01346588, 21.18625259], [72.01346588, 21.18597031], [72.01319122, 21.18597031], [72.01319122, 21.18569374], [72.01235962, 21.18569374], [72.01235962, 21.18541718], [72.01208496, 21.18541718], [72.01208496, 21.18569374], [72.01152802, 21.18569374], [72.01152802, 21.18597031], [72.01069641, 21.18597031], [72.01069641, 21.18541718], [72.01040649, 21.1854229], [72.01040649, 21.18486023], [72.01013947, 21.18486023], [72.01013947, 21.18320084], [72.01040649, 21.18320084], [72.01040649, 21.18291855], [72.01013947, 21.18291855], [72.01013947, 21.18208122], [72.00902557, 21.18208313], [72.00902557, 21.1823616], [72.00875092, 21.1823597], [72.00875092, 21.18263817], [72.00818634, 21.18263817], [72.00818634, 21.1823597], [72.00791931, 21.1823616], [72.00791931, 21.18208313], [72.00763702, 21.18208313], [72.00763702, 21.18180466], [72.00736237, 21.18180466], [72.00736237, 21.18152809], [72.00708008, 21.18152809], [72.00708008, 21.18124962], [72.00680542, 21.18124962], [72.00680542, 21.18097305], [72.00624847, 21.18097305], [72.00624847, 21.18069458], [72.00541687, 21.18069458], [72.00541687, 21.18097305], [72.00402832, 21.18097305], [72.00402832, 21.18013954], [72.00374603, 21.18013954], [72.00374603, 21.17930984], [72.00402832, 21.17930984], [72.00402832, 21.17875099], [72.00430298, 21.17875099], [72.00430298, 21.17791939], [72.00402832, 21.17791939], [72.00402832, 21.17764091], [72.00374603, 21.17764091], [72.00374603, 21.17542076], [72.00402832, 21.17542076], [72.00402832, 21.17486], [72.00430298, 21.17486382], [72.00430298, 21.17458153], [72.00485992, 21.17458153], [72.00485992, 21.17374992], [72.00514221, 21.17374992], [72.00514221, 21.17319107], [72.00485992, 21.17319489], [72.00485992, 21.17236137], [72.00458527, 21.17236137], [72.00458527, 21.1720829], [72.00430298, 21.17209053], [72.00430298, 21.17181015], [72.00402832, 21.17181015], [72.00402832, 21.17153168], [72.00374603, 21.17153168], [72.00374603, 21.1690197], [72.00347137, 21.16902733], [72.00347137, 21.16875076], [72.00318909, 21.16875076], [72.00318909, 21.16847038], [72.00291443, 21.16847229], [72.00291443, 21.16819382], [72.00235748, 21.16819382], [72.00235748, 21.16791725], [72.00208282, 21.16791916], [72.00208282, 21.16764069], [72.00180817, 21.16764069], [72.00180817, 21.16707993], [72.00096893, 21.16708374], [72.00096893, 21.16680527], [72.00041962, 21.16681099], [72.00041962, 21.16653061], [71.99986267, 21.16653061], [71.99986267, 21.16625023], [71.99874878, 21.16625023], [71.99874878, 21.16596031], [71.99847412, 21.16597176], [71.99847412, 21.16486168], [71.99736023, 21.16485977], [71.99736023, 21.16542053], [71.99708557, 21.16541672], [71.99708557, 21.16597176], [71.99680328, 21.16596031], [71.99680328, 21.16736031], [71.99652863, 21.16736031], [71.99652863, 21.16764069], [71.99680328, 21.16763878], [71.99680328, 21.16958427], [71.99652863, 21.16958046], [71.99652863, 21.16986084], [71.99597168, 21.16986084], [71.99597168, 21.16958046], [71.99569702, 21.16958427], [71.99569702, 21.16902733], [71.99541473, 21.16902733], [71.99541473, 21.16875076], [71.99514008, 21.16875076], [71.99514008, 21.16931152], [71.99485779, 21.1693058], [71.99485779, 21.16958427], [71.99458313, 21.16958046], [71.99458313, 21.16986084], [71.99402618, 21.16986084], [71.99402618, 21.16958046], [71.99319458, 21.16958427], [71.99319458, 21.1693058], [71.99291992, 21.16931152], [71.99291992, 21.16875076], [71.99318695, 21.16875076], [71.99318695, 21.16847038], [71.99346924, 21.16847229], [71.99346924, 21.16819382], [71.99375153, 21.16819382], [71.99375153, 21.16791725], [71.99430847, 21.16791916], [71.99430847, 21.16736031], [71.99402618, 21.16736031], [71.99402618, 21.16653061], [71.99430847, 21.16653061], [71.99430847, 21.16625023], [71.99569702, 21.16625023], [71.99569702, 21.16570091], [71.99597168, 21.16570091], [71.99597168, 21.16514015], [71.99514008, 21.16514015], [71.99514008, 21.16485977], [71.99485779, 21.16486168], [71.99485779, 21.16458321], [71.99458313, 21.16458321], [71.99458313, 21.16430664], [71.99430847, 21.16430664], [71.99430847, 21.16347313], [71.99458313, 21.16347313], [71.99458313, 21.16263962], [71.99485779, 21.16263962], [71.99485779, 21.16152954], [71.99514008, 21.16152954], [71.99514008, 21.16097069], [71.99458313, 21.1609745], [71.99458313, 21.16069221], [71.99430847, 21.16069221], [71.99430847, 21.16041756], [71.99402618, 21.16041946], [71.99402618, 21.16015053], [71.99375153, 21.16015053], [71.99375153, 21.15986061], [71.99346924, 21.15986061], [71.99346924, 21.15958023], [71.99236298, 21.15958214], [71.99236298, 21.15930557], [71.99097443, 21.15930557], [71.99097443, 21.15958214], [71.99013519, 21.15958214], [71.99013519, 21.15930557], [71.98902893, 21.15930939], [71.98902893, 21.15903282], [71.98847198, 21.15903282], [71.98847198, 21.15875053], [71.98819733, 21.15875053], [71.98819733, 21.15819359], [71.98791504, 21.15819359], [71.98791504, 21.15791702], [71.98764038, 21.15792274], [71.98764038, 21.15764236], [71.98735809, 21.15764236], [71.98735809, 21.15735817], [71.98708344, 21.15736008], [71.98708344, 21.15708351], [71.98671722, 21.15708351], [71.98596954, 21.15708351], [71.98596954, 21.15680504], [71.98568726, 21.15681076], [71.98568726, 21.15624809], [71.98596954, 21.15624809], [71.98596954, 21.15485954], [71.98569489, 21.15486145], [71.98569489, 21.15319443], [71.98596954, 21.15319443], [71.98596954, 21.15291786], [71.98680878, 21.15291786], [71.98680878, 21.15319443], [71.98708344, 21.15319443], [71.98708344, 21.15402794], [71.98680878, 21.15402031], [71.98680878, 21.15430832], [71.98750305, 21.15430832], [71.98958588, 21.15430832], [71.98958588, 21.15402031], [71.98986053, 21.15402794], [71.98986053, 21.15374947], [71.99014282, 21.15374947], [71.99013519, 21.1534729], [71.99041748, 21.1534729], [71.99041748, 21.15319443], [71.99069214, 21.15319443], [71.99069214, 21.15263939], [71.99095917, 21.15263939], [71.99095917, 21.14875031], [71.99124908, 21.14875031], [71.99124908, 21.14792061], [71.99153137, 21.14792061], [71.99153137, 21.14729118], [71.99153137, 21.14708138], [71.99180603, 21.14708138], [71.99180603, 21.14513969], [71.99153137, 21.14513969], [71.99153137, 21.14263916], [71.99124908, 21.14263916], [71.99124908, 21.14236069], [71.99069214, 21.14236069], [71.99069214, 21.14208031], [71.99041748, 21.14208412], [71.99041748, 21.14180565], [71.99014282, 21.14180756], [71.99014282, 21.14152908], [71.98986053, 21.14152908], [71.98986053, 21.14125061], [71.98929596, 21.14125061], [71.98929596, 21.14097023], [71.98874664, 21.14097214], [71.98874664, 21.14069366], [71.98819733, 21.14069366], [71.98819733, 21.1404171], [71.98792267, 21.14042091], [71.98792267, 21.14014053], [71.98764038, 21.14014053], [71.98764038, 21.13986015], [71.98652649, 21.13986015], [71.98652649, 21.14014053], [71.98596954, 21.14014053], [71.98596954, 21.13986015], [71.98569489, 21.13986206], [71.98569489, 21.13930511], [71.98542023, 21.13931084], [71.98542023, 21.13903809], [71.9851532, 21.13903809], [71.9851532, 21.13875008], [71.98486328, 21.13875008], [71.98486328, 21.1384697], [71.98430634, 21.1384716], [71.98430634, 21.13819695], [71.98401642, 21.13820076], [71.98401642, 21.13792038], [71.98319244, 21.13792038], [71.98319244, 21.13764], [71.98179626, 21.13764], [71.98179626, 21.13735962], [71.98124695, 21.13736153], [71.98124695, 21.13708305], [71.98097229, 21.13708305], [71.98097229, 21.13680649], [71.98042297, 21.1368103], [71.98042297, 21.13652992], [71.98014069, 21.13652992], [71.98014069, 21.13624954], [71.97930908, 21.13624954], [71.97930908, 21.13598061], [71.97901917, 21.13598061], [71.97901917, 21.13569069], [71.97875214, 21.1356926], [71.97875214, 21.13541412], [71.97846985, 21.13541985], [71.97846985, 21.13513947], [71.97875214, 21.13513947], [71.97875214, 21.1348629], [71.98041534, 21.1348629], [71.98041534, 21.13513947], [71.98152924, 21.13513947], [71.98152924, 21.13541985], [71.98208618, 21.13541985], [71.98208618, 21.13513947], [71.98236084, 21.13513947], [71.98236084, 21.13541985], [71.98319244, 21.13541985], [71.98319244, 21.13513947], [71.98401642, 21.13513947], [71.98401642, 21.1348629], [71.98486328, 21.1348629], [71.98486328, 21.13458061], [71.98513794, 21.13458443], [71.98513794, 21.13430405], [71.98568726, 21.13430977], [71.98568726, 21.13402939], [71.98596954, 21.13402939], [71.98596954, 21.13347054], [71.98569489, 21.13347054], [71.98569489, 21.13319206], [71.98513794, 21.13319206], [71.98513794, 21.1329174], [71.98486328, 21.13292122], [71.98486328, 21.13264275], [71.98430634, 21.13264275], [71.98430634, 21.13236046], [71.9834671, 21.13236046], [71.9834671, 21.13208008], [71.98291779, 21.13208389], [71.98291779, 21.13180542], [71.98208618, 21.13181114], [71.98208618, 21.13153267], [71.98179626, 21.13153267], [71.98179626, 21.13125038], [71.98097229, 21.13125038], [71.98097229, 21.13097191], [71.98041534, 21.13097191], [71.98042297, 21.13125038], [71.98014069, 21.13125038], [71.98014069, 21.13097191], [71.97901917, 21.13097191], [71.97901917, 21.13125038], [71.9779129, 21.13125038], [71.9779129, 21.13097191], [71.9770813, 21.13097191], [71.9770813, 21.1301384], [71.97680664, 21.1301384], [71.97680664, 21.12985039], [71.97652435, 21.12986183], [71.97652435, 21.12958336], [71.97624969, 21.12958336], [71.97624969, 21.12930489], [71.9751358, 21.12930489], [71.9751358, 21.12902832], [71.97402954, 21.12902832], [71.97402954, 21.12846947], [71.9743042, 21.12847137], [71.9743042, 21.12819481], [71.97486115, 21.12819481], [71.97486115, 21.12847137], [71.97624969, 21.12846947], [71.97624969, 21.12874985], [71.97680664, 21.12874985], [71.97680664, 21.12846947], [71.9770813, 21.12847137], [71.9770813, 21.12791634], [71.97680664, 21.12791824], [71.97680664, 21.12763977], [71.97651672, 21.12763977], [71.97651672, 21.12735939], [71.97597504, 21.1273613], [71.97597504, 21.12708282], [71.97569275, 21.12708282], [71.97569275, 21.12652779], [71.97541809, 21.12652969], [71.97541809, 21.12597084], [71.9751358, 21.12597275], [71.9751358, 21.12541771], [71.97458649, 21.12541962], [71.97458649, 21.12514114], [71.9751358, 21.12514114], [71.9751358, 21.12486076], [71.97680664, 21.12486076], [71.97680664, 21.12458038], [71.9770813, 21.1245842], [71.9770813, 21.12402725], [71.97735596, 21.1240406], [71.97735596, 21.12430954], [71.97763824, 21.12430954], [71.97763824, 21.1240406], [71.9779129, 21.1240406], [71.9779129, 21.12375069], [71.97820282, 21.12375069], [71.97819519, 21.12291718], [71.9779129, 21.12292099], [71.9779129, 21.12236023], [71.97763824, 21.12236023], [71.97763824, 21.12207985], [71.97736359, 21.12208557], [71.97736359, 21.12180328], [71.9770813, 21.12181091], [71.9770813, 21.12153053], [71.97680664, 21.12153053], [71.97680664, 21.12096977], [71.9743042, 21.12097359], [71.9743042, 21.12069321], [71.97374725, 21.12070084], [71.97374725, 21.12042046], [71.9715271, 21.12042046], [71.9715271, 21.12070084], [71.97125244, 21.12069321], [71.97125244, 21.12097359], [71.97041321, 21.12097359], [71.97041321, 21.12069321], [71.97013855, 21.12069321], [71.97013855, 21.12097359], [71.96985626, 21.12096977], [71.96985626, 21.12125015], [71.9695816, 21.12125015], [71.9695816, 21.12153053], [71.96985626, 21.12153053], [71.96985626, 21.12181091], [71.97013855, 21.12180328], [71.97013855, 21.12236023], [71.97041321, 21.12236023], [71.97041321, 21.12264061], [71.97097015, 21.12264061], [71.97097015, 21.12292099], [71.97125244, 21.12291718], [71.97125244, 21.12319565], [71.9706955, 21.12319565], [71.9706955, 21.12291718], [71.97014618, 21.12292099], [71.97014618, 21.12264061], [71.96985626, 21.12264061], [71.96985626, 21.12236023], [71.96930695, 21.12236023], [71.96930695, 21.12207985], [71.96902466, 21.12208557], [71.96902466, 21.12180328], [71.96848297, 21.12181091], [71.96848297, 21.12153053], [71.96736145, 21.12153053], [71.96736145, 21.12181091], [71.9668045, 21.12180328], [71.9668045, 21.12208557], [71.96652985, 21.12207985], [71.96652985, 21.12236023], [71.96569824, 21.12236023], [71.96569824, 21.12207985], [71.9659729, 21.12208557], [71.9659729, 21.12097359], [71.96541595, 21.12097359], [71.96541595, 21.12069321], [71.96485901, 21.12070084], [71.96485901, 21.12042046], [71.96430206, 21.12041664], [71.96430206, 21.12097359], [71.96457672, 21.12096977], [71.96457672, 21.12181091], [71.96485901, 21.12181091], [71.96485901, 21.12236023], [71.9651413, 21.12236023], [71.9651413, 21.12264061], [71.9659729, 21.12264061], [71.9659729, 21.12292099], [71.96652985, 21.12291718], [71.96652985, 21.12319565], [71.9651413, 21.12319565], [71.9651413, 21.12347221], [71.96347046, 21.12347031], [71.96347046, 21.12430954], [71.96097565, 21.12430573], [71.96097565, 21.1245842], [71.96013641, 21.1245842], [71.96013641, 21.12430573], [71.95986176, 21.12430954], [71.95986176, 21.12375069], [71.95929718, 21.12375069], [71.95929718, 21.12347031], [71.95847321, 21.12347221], [71.95847321, 21.12319565], [71.95819092, 21.12319565], [71.95819092, 21.12291718], [71.95791626, 21.12292099], [71.95791626, 21.12264061], [71.9576416, 21.12264061], [71.9576416, 21.12236023], [71.95735931, 21.12236023], [71.95735931, 21.12207985], [71.95708466, 21.12208557], [71.95708466, 21.12180328], [71.95680237, 21.12181091], [71.95680237, 21.12153053], [71.95652771, 21.12153053], [71.95652771, 21.12181091], [71.95597076, 21.12180328], [71.95597076, 21.12208557], [71.95569611, 21.12207985], [71.95569611, 21.12236023], [71.95597076, 21.12236023], [71.95597076, 21.12264061], [71.95625305, 21.1226387], [71.95625305, 21.12319565], [71.95513916, 21.12319565], [71.95513916, 21.12291718], [71.9540329, 21.12292099], [71.9540329, 21.12153053], [71.95375061, 21.12153053], [71.95375061, 21.12014008], [71.95347595, 21.12014008], [71.95347595, 21.11958122], [71.95319366, 21.11958122], [71.95319366, 21.11902809], [71.95263672, 21.11903191], [71.95263672, 21.11874962], [71.95207977, 21.11874962], [71.95207977, 21.11846924], [71.95124817, 21.11847115], [71.95124817, 21.11819458], [71.95069122, 21.11819458], [71.95069122, 21.11847115], [71.95041656, 21.11846924], [71.95041656, 21.11874962], [71.94819641, 21.11874962], [71.94819641, 21.11846924], [71.94763947, 21.11847115], [71.94763947, 21.11819458], [71.94708252, 21.11819458], [71.94708252, 21.11791611], [71.94652557, 21.11791611], [71.94652557, 21.11763954], [71.94541931, 21.11763954], [71.94541931, 21.11791611], [71.94458008, 21.11791611], [71.94458008, 21.11819458], [71.94403076, 21.11819077], [71.94403076, 21.12042046], [71.94346619, 21.12042046], [71.94346619, 21.12014008], [71.94319153, 21.12014008], [71.94319153, 21.1198597], [71.94291687, 21.11986351], [71.94291687, 21.11958122], [71.94264221, 21.11958122], [71.94264221, 21.11930466], [71.94235992, 21.11930466], [71.94235992, 21.11902809], [71.9420929, 21.11903191], [71.9420929, 21.11874962], [71.94180298, 21.11874962], [71.94180298, 21.11846924], [71.94152832, 21.11847115], [71.94152832, 21.11791611], [71.94180298, 21.11791611], [71.94180298, 21.11735916], [71.9420929, 21.11735916], [71.94208527, 21.1170826], [71.94180298, 21.1170826], [71.94180298, 21.11680603], [71.94152832, 21.11681175], [71.94152832, 21.11653137], [71.94124603, 21.11653137], [71.94124603, 21.11624908], [71.94069672, 21.11624908], [71.94069672, 21.11597061], [71.94041443, 21.11597252], [71.94041443, 21.11569405], [71.94013977, 21.11569405], [71.94013977, 21.1151371], [71.93846893, 21.11514091], [71.93846893, 21.11541748], [71.93569183, 21.11541748], [71.93569183, 21.11514091], [71.93486023, 21.11514091], [71.93486023, 21.11541748], [71.93319702, 21.11541748], [71.93319702, 21.11514091], [71.93264008, 21.11514091], [71.93264008, 21.11541748], [71.93235779, 21.11541748], [71.93235779, 21.11597252], [71.93180847, 21.11597252], [71.93180847, 21.11458397], [71.93041992, 21.11458397], [71.93041992, 21.1143055], [71.93013763, 21.11431122], [71.93013763, 21.11403084], [71.92986298, 21.11403084], [71.92986298, 21.11431122], [71.92930603, 21.1143055], [71.92930603, 21.11458397], [71.92847443, 21.11458397], [71.92847443, 21.11319542], [71.92819214, 21.1131897], [71.92819214, 21.11263847], [71.92708588, 21.11264038], [71.92708588, 21.11207962], [71.92680359, 21.11208344], [71.92680359, 21.11180687], [71.92652893, 21.11181068], [71.92652893, 21.11124992], [71.92624664, 21.11124992], [71.92624664, 21.11096954], [71.92569733, 21.11096954], [71.92569733, 21.11124992], [71.92542267, 21.11124992], [71.92542267, 21.1115303], [71.92457581, 21.1115303], [71.92457581, 21.11124992], [71.92430878, 21.11124992], [71.92430878, 21.11096954], [71.92402649, 21.11096954], [71.92402649, 21.11124992], [71.92375183, 21.11124992], [71.92375183, 21.1115303], [71.92208099, 21.1115303], [71.92208099, 21.11181068], [71.9201355, 21.11180687], [71.9201355, 21.11208344], [71.91986084, 21.11207962], [71.91986084, 21.11264038], [71.91958618, 21.11264038], [71.91958618, 21.11292076], [71.91902924, 21.11292076], [71.91902924, 21.11264038], [71.91873932, 21.11264038], [71.91873932, 21.11236], [71.91847229, 21.11236191], [71.91847229, 21.11208344], [71.91596985, 21.11208344], [71.91596985, 21.11180687], [71.91570282, 21.11181068], [71.91570282, 21.1115303], [71.91513824, 21.1115303], [71.91513824, 21.11124992], [71.91485596, 21.11124992], [71.91485596, 21.11096954], [71.91430664, 21.11097145], [71.91430664, 21.11069679], [71.91402435, 21.11069679], [71.91402435, 21.11041641], [71.91319275, 21.11041641], [71.91319275, 21.11069679], [71.90958405, 21.11069679], [71.90958405, 21.11041641], [71.9090271, 21.11042023], [71.9090271, 21.11013985], [71.90847015, 21.11013985], [71.90847015, 21.10985947], [71.90763855, 21.10986137], [71.90763855, 21.10958481], [71.90680695, 21.10958481], [71.90680695, 21.10930634], [71.90402985, 21.10931015], [71.90402985, 21.10902977], [71.9034729, 21.10902977], [71.9034729, 21.10874939], [71.90319824, 21.10874939], [71.90319061, 21.10847092], [71.90097046, 21.10847092], [71.90097046, 21.10902977], [71.9006958, 21.10902977], [71.9006958, 21.10931015], [71.89930725, 21.10931015], [71.89930725, 21.10902977], [71.89903259, 21.10902977], [71.89903259, 21.10847092], [71.89875031, 21.10847473], [71.89875031, 21.10819244], [71.89847565, 21.10819244], [71.89847565, 21.10736275], [71.89819336, 21.10736275], [71.89819336, 21.10680962], [71.89792633, 21.10680962], [71.89792633, 21.10653114], [71.89763641, 21.10653114], [71.89763641, 21.10625267], [71.89736176, 21.10625267], [71.89736176, 21.10597038], [71.89680481, 21.10597038], [71.89680481, 21.10569382], [71.89569092, 21.10569382], [71.89569092, 21.10541725], [71.89541626, 21.10542107], [71.89541626, 21.10514259], [71.8951416, 21.10514259], [71.8951416, 21.10486031], [71.89430237, 21.10486031], [71.89430237, 21.10458183], [71.89402771, 21.10458374], [71.89402771, 21.10430527], [71.89375305, 21.1043129], [71.89375305, 21.10403252], [71.89263916, 21.10403252], [71.89263916, 21.10374832], [71.89125061, 21.10374832], [71.89125061, 21.10346985], [71.89097595, 21.10347176], [71.89097595, 21.10291672], [71.89069366, 21.10291672], [71.89069366, 21.10263824], [71.89041901, 21.10263824], [71.89041901, 21.10235977], [71.88986206, 21.10236168], [71.88986206, 21.10208321], [71.88903046, 21.10208321], [71.88903046, 21.10180473], [71.88874817, 21.10180473], [71.88874817, 21.10152817], [71.88846588, 21.10152817], [71.88846588, 21.10069084], [71.88819122, 21.10069466], [71.88819122, 21.10013962], [71.88791656, 21.10013962], [71.88791656, 21.09847069], [71.88764191, 21.0984726], [71.88764191, 21.09819412], [71.88735962, 21.09819412], [71.88735962, 21.09791756], [71.88709259, 21.09791946], [71.88709259, 21.09764099], [71.88680267, 21.09764099], [71.88680267, 21.09736061], [71.88652802, 21.09736061], [71.88652802, 21.09708023], [71.88625336, 21.09708595], [71.88625336, 21.09680557], [71.88597107, 21.09680939], [71.88597107, 21.09653091], [71.88569641, 21.09653091], [71.88569641, 21.09597015], [71.88541412, 21.09597206], [71.88541412, 21.09513855], [71.88513947, 21.09514046], [71.88513947, 21.0945797], [71.88486481, 21.0945816], [71.88486481, 21.09430313], [71.88430786, 21.09431076], [71.88430786, 21.09403038], [71.88375092, 21.09403038], [71.88375092, 21.09374046], [71.88346863, 21.09375191], [71.88346863, 21.09347153], [71.88291931, 21.09347153], [71.88291931, 21.09319305], [71.88236237, 21.09320068], [71.88236237, 21.0929203], [71.88208008, 21.0929203], [71.88208008, 21.09235954], [71.88153076, 21.09236336], [71.88153076, 21.09208107], [71.88124847, 21.09208107], [71.88124847, 21.09180641], [71.88069153, 21.09181023], [71.88069153, 21.09153175], [71.88041687, 21.09153175], [71.88041687, 21.09096909], [71.88014221, 21.0909729], [71.88014221, 21.09041595], [71.87985992, 21.09042168], [71.87985992, 21.09013939], [71.87958527, 21.09013939], [71.87958527, 21.08986092], [71.87902832, 21.08986092], [71.87902832, 21.08958054], [71.87819672, 21.08958244], [71.87819672, 21.08930588], [71.87652588, 21.0893116], [71.87652588, 21.08902931], [71.87625122, 21.08902931], [71.87625122, 21.08875084], [71.87596893, 21.08875084], [71.87596893, 21.08847046], [71.87458038, 21.08847046], [71.87458038, 21.08902931], [71.87430573, 21.0890274], [71.87431335, 21.08986092], [71.87403107, 21.08986092], [71.87403107, 21.09013939], [71.86958313, 21.09013939], [71.86958313, 21.08958054], [71.86985779, 21.08958244], [71.86985779, 21.08930588], [71.87014008, 21.0893116], [71.87014008, 21.08902931], [71.8704071, 21.08902931], [71.8704071, 21.08875084], [71.87014008, 21.08875084], [71.87014008, 21.08847046], [71.86958313, 21.08847237], [71.86958313, 21.08819389], [71.86902618, 21.08819389], [71.86902618, 21.08791733], [71.86875153, 21.08793068], [71.86875153, 21.08764076], [71.86846924, 21.08764076], [71.86846924, 21.08708], [71.86819458, 21.08708382], [71.86819458, 21.08597183], [71.86791992, 21.08596992], [71.86791992, 21.08625031], [71.86763, 21.08625031], [71.86763, 21.08653069], [71.86680603, 21.08653069], [71.86680603, 21.08681107], [71.86374664, 21.08681107], [71.86374664, 21.08653069], [71.86319733, 21.08653069], [71.86319733, 21.08625031], [71.86291504, 21.08625031], [71.86291504, 21.08597183], [71.86264038, 21.08597183], [71.86264038, 21.08569527], [71.86152649, 21.08570099], [71.86152649, 21.08542061], [71.86068726, 21.08542061], [71.86068726, 21.08514023], [71.86042023, 21.08514023], [71.86042023, 21.08486938], [71.85986328, 21.08486938], [71.85986328, 21.08457947], [71.85930634, 21.08458328], [71.85930634, 21.08430672], [71.85902405, 21.08430672], [71.85902405, 21.08402824], [71.85875702, 21.08403015], [71.85875702, 21.08374977], [71.8584671, 21.08374977], [71.8584671, 21.08346939], [71.85819244, 21.0834713], [71.85819244, 21.08319664], [71.85791779, 21.08319664], [71.85791779, 21.08291626], [71.85764313, 21.08292007], [71.85764313, 21.08263969], [71.85736084, 21.08263969], [71.85736084, 21.08236122], [71.85708618, 21.08236122], [71.85708618, 21.08125114], [71.85652924, 21.08125114], [71.85652924, 21.08097076], [71.85588837, 21.08097076], [71.85569, 21.08097076], [71.85569, 21.08125114], [71.8548584, 21.08125114], [71.8548584, 21.08097076], [71.85458374, 21.08097458], [71.85458374, 21.08069229], [71.85402679, 21.08069229], [71.85402679, 21.08041763], [71.85320282, 21.08041954], [71.85320282, 21.08014107], [71.85263062, 21.08014107], [71.85263062, 21.07986069], [71.85235596, 21.07986069], [71.85235596, 21.07958031], [71.8520813, 21.07958221], [71.8520813, 21.07930565], [71.85180664, 21.07930946], [71.85180664, 21.0790329], [71.85151672, 21.0790329], [71.85151672, 21.07873917], [71.85124969, 21.07875252], [71.85124969, 21.07847023], [71.85097504, 21.07847023], [71.85097504, 21.07819366], [71.85069275, 21.07819366], [71.85069275, 21.07763863], [71.85041809, 21.07764244], [71.85041809, 21.07736015], [71.84986115, 21.07736015], [71.84986115, 21.07708359], [71.84958649, 21.07708359], [71.84958649, 21.07680511], [71.84929657, 21.07681084], [71.84929657, 21.07652855], [71.84812164, 21.07652855], [71.84680939, 21.07652855], [71.84680939, 21.07708359], [71.84708405, 21.07708359], [71.84707642, 21.07767105], [71.84707642, 21.07792282], [71.8473587, 21.0779171], [71.8473587, 21.07847023], [71.84486389, 21.07847023], [71.84486389, 21.07811928], [71.84486389, 21.0779171], [71.84263611, 21.07792282], [71.84263611, 21.07764244], [71.84236145, 21.07764244], [71.84236145, 21.07736015], [71.84208679, 21.07736015], [71.84208679, 21.07708359], [71.8409729, 21.07708359], [71.8409729, 21.07652855], [71.84124756, 21.07652855], [71.84124756, 21.07624817], [71.84208679, 21.07624817], [71.84208679, 21.07485962], [71.84179688, 21.07485962], [71.84179688, 21.07513809], [71.83930206, 21.07513809], [71.83930206, 21.07485962], [71.83875275, 21.07486153], [71.83875275, 21.07458305], [71.83847046, 21.07458305], [71.83847046, 21.07430649], [71.8381958, 21.0743103], [71.8381958, 21.07374954], [71.83790588, 21.07374954], [71.83790588, 21.07347107], [71.83735657, 21.07347107], [71.8373642, 21.07374954], [71.83652496, 21.07374954], [71.83652496, 21.07347298], [71.83625031, 21.07347298], [71.83625031, 21.0731945], [71.83597565, 21.0731945], [71.83597565, 21.07291794], [71.83569336, 21.07292747], [71.83569336, 21.07263947], [71.83235931, 21.07263947], [71.83235931, 21.07236099], [71.83207703, 21.07236099], [71.83207703, 21.07208061], [71.83180237, 21.07208252], [71.83180237, 21.07180786], [71.83125305, 21.07180977], [71.83125305, 21.07152939], [71.83069611, 21.07152939], [71.83069611, 21.07125092], [71.83040619, 21.07125092], [71.83040619, 21.07097054], [71.83013916, 21.07097244], [71.83013916, 21.07069588], [71.82958221, 21.07069588], [71.82958221, 21.0704174], [71.82930756, 21.07042122], [71.82930756, 21.07014084], [71.82875061, 21.07014084], [71.82875061, 21.06986046], [71.82847595, 21.06986046], [71.82847595, 21.06957054], [71.82819366, 21.0695858], [71.82819366, 21.06930542], [71.82736206, 21.06931114], [71.82736206, 21.06903076], [71.82569122, 21.06903076], [71.82569122, 21.06875038], [71.82458496, 21.06875038], [71.82458496, 21.06847382], [71.82375336, 21.06847382], [71.82375336, 21.06819534], [71.82319641, 21.06820107], [71.82319641, 21.06875038], [71.82347107, 21.06875038], [71.82347107, 21.07014084], [71.82319641, 21.07014084], [71.82319641, 21.07042122], [71.82291412, 21.0704174], [71.82291412, 21.07069588], [71.82236481, 21.07069588], [71.82236481, 21.07097244], [71.82208252, 21.07097054], [71.82208252, 21.07152939], [71.82180786, 21.07152939], [71.82180786, 21.07180977], [71.82152557, 21.07180786], [71.82152557, 21.07208252], [71.82096863, 21.07208252], [71.82096863, 21.07180786], [71.82069397, 21.07180786], [71.82069397, 21.07208252], [71.81986237, 21.07208252], [71.81986237, 21.07180786], [71.81958008, 21.07180977], [71.81958008, 21.07152939], [71.81903076, 21.07152939], [71.81903076, 21.07125092], [71.81874847, 21.07125092], [71.81874847, 21.07097054], [71.81819153, 21.07097244], [71.81819153, 21.07069588], [71.81791687, 21.07069588], [71.81791687, 21.0704174], [71.81764221, 21.07042122], [71.81764221, 21.07014084], [71.81735992, 21.07014084], [71.81735992, 21.06986046], [71.81708527, 21.06986046], [71.81708527, 21.0695858], [71.81652832, 21.0695858], [71.81652832, 21.06930542], [71.81513977, 21.06931114], [71.81513977, 21.06903076], [71.81430817, 21.06903076], [71.81430817, 21.06875038], [71.81375122, 21.06875038], [71.81375122, 21.06847], [71.81343842, 21.06847382], [71.81319427, 21.06847382], [71.81319427, 21.06819534], [71.81263733, 21.06820107], [71.81263733, 21.06792068], [71.81208038, 21.06792068], [71.81208038, 21.0676403], [71.81153107, 21.0676403], [71.81153107, 21.06735992], [71.81124878, 21.06736374], [71.81124878, 21.06708145], [71.81097412, 21.06708145], [71.81097412, 21.06680489], [71.81041718, 21.06680489], [71.81041718, 21.06652832], [71.80986023, 21.06653023], [71.80986023, 21.06624985], [71.80902863, 21.06624985], [71.80902863, 21.0656929], [71.80874634, 21.06569481], [71.80874634, 21.06541634], [71.80819702, 21.06542015], [71.80819702, 21.06514168], [71.80764008, 21.06514168], [71.80764008, 21.06485939], [71.80735779, 21.06485939], [71.80735779, 21.06458282], [71.80708313, 21.06458282], [71.80708313, 21.06430626], [71.80680847, 21.06431007], [71.80680847, 21.0640316], [71.80652618, 21.0640316], [71.80652618, 21.06376266], [71.80568695, 21.06376266], [71.80568695, 21.0640316], [71.80486298, 21.0640316], [71.80486298, 21.06376266], [71.80403137, 21.06376266], [71.80403137, 21.06347084], [71.80347443, 21.06347275], [71.80347443, 21.06319427], [71.80263519, 21.06319427], [71.80263519, 21.0629158], [71.80208588, 21.06292152], [71.80208588, 21.06263924], [71.80179596, 21.06263924], [71.80179596, 21.06236076], [71.80152893, 21.06236076], [71.80152893, 21.0620842], [71.80124664, 21.0620842], [71.80124664, 21.06180573], [71.80069733, 21.06180763], [71.80069733, 21.06152916], [71.80042267, 21.06152916], [71.80042267, 21.06125069], [71.80014038, 21.06125069], [71.80014038, 21.06069946], [71.79985809, 21.06069946], [71.79985809, 21.06041908], [71.79957581, 21.06041908], [71.79957581, 21.06014061], [71.79930878, 21.06014061], [71.79930878, 21.05986023], [71.79902649, 21.05986023], [71.79902649, 21.05957985], [71.79875183, 21.05958366], [71.79875183, 21.05930519], [71.79847717, 21.05931091], [71.79847717, 21.05903053], [71.79818726, 21.05903053], [71.79818726, 21.05875015], [71.79763794, 21.05875015], [71.79763794, 21.05846977], [71.79736328, 21.05847168], [71.79736328, 21.05819511], [71.79708099, 21.05820084], [71.79708099, 21.05792046], [71.79680634, 21.05792046], [71.79680634, 21.05708122], [71.79708099, 21.05708313], [71.79708099, 21.05652809], [71.79736328, 21.05653], [71.79736328, 21.05597115], [71.79708099, 21.05597305], [71.79708099, 21.05513954], [71.79680634, 21.05513954], [71.79680634, 21.05486107], [71.79651642, 21.05486107], [71.79651642, 21.05430984], [71.79624939, 21.05430984], [71.79624939, 21.05319023], [71.79652405, 21.05319214], [71.79652405, 21.05291748], [71.79708099, 21.05291748], [71.79708099, 21.05319214], [71.79736328, 21.05319214], [71.79736328, 21.05291748], [71.79763794, 21.05291939], [71.79763794, 21.05264282], [71.79792023, 21.05264282], [71.79792023, 21.05208015], [71.79819489, 21.05208206], [71.79819489, 21.0518055], [71.79902649, 21.05182076], [71.79902649, 21.05153275], [71.79930878, 21.05153275], [71.79930878, 21.05097008], [71.79958344, 21.05097008], [71.79958344, 21.05069351], [71.79985809, 21.05069351], [71.79985809, 21.05041695], [71.80014038, 21.05042267], [71.80014038, 21.04875946], [71.80042267, 21.04875946], [71.80042267, 21.04819107], [71.80069733, 21.04819489], [71.80069733, 21.04801369], [71.80069733, 21.04791641], [71.80108643, 21.04791641], [71.80152893, 21.04791641], [71.80152893, 21.04819489], [71.80236053, 21.04819489], [71.80236053, 21.04757118], [71.80236053, 21.04736137], [71.80263519, 21.04736137], [71.80263519, 21.0470829], [71.80291748, 21.0470829], [71.80291748, 21.04652786], [71.80319214, 21.04652977], [71.80319214, 21.04624939], [71.80263519, 21.04624939], [71.80263519, 21.04597282], [71.80236053, 21.04597282], [71.80236053, 21.04541779], [71.80264282, 21.04541969], [71.80264282, 21.04514122], [71.80291748, 21.04514122], [71.80291748, 21.04486084], [71.8034668, 21.04486084], [71.8034668, 21.04514122], [71.80374908, 21.04514122], [71.80374908, 21.04541969], [71.80403137, 21.04541779], [71.80403137, 21.04569435], [71.80430603, 21.04569435], [71.80430603, 21.0443058], [71.80403137, 21.04430962], [71.80403137, 21.04403114], [71.80374908, 21.04403114], [71.80374908, 21.04319], [71.80403137, 21.04319572], [71.80403137, 21.04291725], [71.80513763, 21.04292107], [71.80513763, 21.04263115], [71.80541992, 21.04263878], [71.80541992, 21.04208565], [71.80569458, 21.04208565], [71.80569458, 21.0415287], [71.80541992, 21.04153061], [71.80541992, 21.04096985], [71.80569458, 21.04097366], [71.80569458, 21.04069519], [71.80625153, 21.04070091], [71.80625153, 21.04014015], [71.80652618, 21.04014015], [71.80652618, 21.03985977], [71.80680847, 21.03986359], [71.80680847, 21.03930473], [71.80652618, 21.03930473], [71.80652618, 21.03902817], [71.80680847, 21.03903008], [71.80680847, 21.03886986], [71.80680847, 21.03791618], [71.80625153, 21.03791618], [71.80625153, 21.03819466], [71.80541992, 21.03819466], [71.80541992, 21.03847122], [71.80486298, 21.03846931], [71.80486298, 21.03874969], [71.80291748, 21.03874969], [71.80291748, 21.03846931], [71.80263519, 21.03847122], [71.80263519, 21.03791618], [71.80236053, 21.03792191], [71.80236053, 21.03764153], [71.80069733, 21.03764153], [71.80069733, 21.03792191], [71.80041504, 21.03791618], [71.80041504, 21.03819466], [71.80014038, 21.03819084], [71.80014038, 21.03874969], [71.79985809, 21.03874969], [71.79985809, 21.03903008], [71.79958344, 21.03902817], [71.79958344, 21.03930473], [71.79875183, 21.03930473], [71.79875183, 21.03902817], [71.79847717, 21.03903008], [71.79847717, 21.03846931], [71.79819489, 21.03847122], [71.79819489, 21.03791618], [71.79651642, 21.03792191], [71.79651642, 21.03764153], [71.79624939, 21.03764153], [71.79624939, 21.03819466], [71.79597473, 21.03819466], [71.79597473, 21.03847122], [71.7951355, 21.03847122], [71.7951355, 21.03819466], [71.79486084, 21.03819466], [71.79486084, 21.03791618], [71.79458618, 21.03792191], [71.79458618, 21.03764153], [71.79429626, 21.03764153], [71.79429626, 21.03735924], [71.79402924, 21.03735924], [71.79402924, 21.03708076], [71.79347229, 21.03708267], [71.79347229, 21.03680611], [71.79264069, 21.03681946], [71.79264069, 21.03653145], [71.79235077, 21.03653145], [71.79235077, 21.03597069], [71.79208374, 21.0359726], [71.79208374, 21.03569412], [71.79180908, 21.03569412], [71.79180908, 21.0359726], [71.79152679, 21.03597069], [71.79152679, 21.03624916], [71.79125214, 21.03624916], [71.79125214, 21.03653145], [71.79069519, 21.03652763], [71.79069519, 21.03764153], [71.79096985, 21.03764153], [71.79096985, 21.03847122], [71.79125214, 21.03846931], [71.79125214, 21.03874969], [71.79152679, 21.03874969], [71.79152679, 21.03930473], [71.79125214, 21.03930283], [71.79125214, 21.03959084], [71.79070282, 21.03959084], [71.79070282, 21.03930283], [71.78985596, 21.03930283], [71.78985596, 21.03959084], [71.7895813, 21.0395813], [71.7895813, 21.03986359], [71.78901672, 21.03985977], [71.78901672, 21.04014015], [71.78874969, 21.04014015], [71.78874969, 21.03985977], [71.78819275, 21.03986359], [71.78819275, 21.0395813], [71.78791809, 21.03959084], [71.78791809, 21.03846931], [71.7876358, 21.03847122], [71.7876358, 21.03819466], [71.78736115, 21.03819466], [71.78736115, 21.03791618], [71.78708649, 21.03792191], [71.78708649, 21.03764153], [71.7859726, 21.03764153], [71.7859726, 21.03847122], [71.78624725, 21.03846931], [71.78624725, 21.03903008], [71.78652954, 21.03902817], [71.78652954, 21.03930473], [71.78679657, 21.03930283], [71.78679657, 21.03959084], [71.78736115, 21.03959084], [71.78736115, 21.04014015], [71.78708649, 21.04014015], [71.78708649, 21.04042053], [71.78624725, 21.04042053], [71.78624725, 21.04014015], [71.7859726, 21.04014015], [71.7859726, 21.03985977], [71.78569794, 21.03986359], [71.78569794, 21.0395813], [71.78542328, 21.03959084], [71.78542328, 21.03930283], [71.78514099, 21.03930473], [71.78514099, 21.03902817], [71.7848587, 21.03903008], [71.7848587, 21.03874969], [71.78430939, 21.03874969], [71.78430176, 21.03903008], [71.78375244, 21.03902817], [71.78375244, 21.03930473], [71.78347015, 21.03930283], [71.78347015, 21.03959084], [71.78291321, 21.03959084], [71.78291321, 21.03930283], [71.78236389, 21.03930473], [71.78236389, 21.03902817], [71.78041077, 21.03903008], [71.78041077, 21.03874969], [71.77986145, 21.03874969], [71.77986145, 21.03846931], [71.77902985, 21.03847122], [71.77902985, 21.03930473], [71.77874756, 21.03930473], [71.77874756, 21.03986359], [71.77819824, 21.03986359], [71.77819061, 21.0395813], [71.77791595, 21.03959084], [71.77791595, 21.03930283], [71.7776413, 21.03930473], [71.7776413, 21.03902817], [71.77735138, 21.03903008], [71.77735138, 21.03819084], [71.7776413, 21.03819466], [71.7776413, 21.03764153], [71.77791595, 21.03764153], [71.77791595, 21.03735924], [71.77819061, 21.03735924], [71.77819824, 21.03681946], [71.7784729, 21.03681946], [71.7784729, 21.03653145], [71.77958679, 21.03653145], [71.77958679, 21.03624916], [71.78041077, 21.03624916], [71.78041077, 21.03597069], [71.78069305, 21.0359726], [71.78069305, 21.03569412], [71.78097534, 21.03569412], [71.78097534, 21.03541756], [71.78125, 21.03541756], [71.78125, 21.03458023], [71.78152466, 21.03458405], [71.78152466, 21.03430557], [71.7820816, 21.03430557], [71.7820816, 21.03458405], [71.78236389, 21.03458405], [71.78236389, 21.0340271], [71.78263855, 21.03403091], [71.78263855, 21.03375053], [71.78291321, 21.03375053], [71.78291321, 21.03264046], [71.78320313, 21.03264046], [71.78320313, 21.03236008], [71.7840271, 21.03236008], [71.7840271, 21.03264046], [71.78542328, 21.03264046], [71.78542328, 21.03292084], [71.78569794, 21.03292084], [71.78569794, 21.03181076], [71.78542328, 21.03181076], [71.78542328, 21.03153038], [71.7848587, 21.03153038], [71.7848587, 21.03125], [71.78430176, 21.03125], [71.78430176, 21.03096962], [71.7840271, 21.03096962], [71.7840271, 21.03125], [71.78347015, 21.03125], [71.78347015, 21.03153038], [71.78263855, 21.03153038], [71.78263855, 21.03125], [71.78235626, 21.03125], [71.78235626, 21.03096962], [71.7820816, 21.03097153], [71.7820816, 21.03069687], [71.78180695, 21.03069687], [71.78180695, 21.03041649], [71.78151703, 21.0304203], [71.78151703, 21.02985954], [71.7804184, 21.02986145], [71.7804184, 21.02958488], [71.77902985, 21.02958488], [71.77902985, 21.02986145], [71.77625275, 21.02986145], [71.77625275, 21.02958488], [71.77597046, 21.02958488], [71.77597046, 21.02930641], [71.7756958, 21.02931023], [71.7756958, 21.02902985], [71.77513885, 21.02902985], [71.77513885, 21.02874947], [71.77153015, 21.02874947], [71.77153015, 21.0284729], [71.77124786, 21.02847481], [71.77124786, 21.02791405], [71.77153015, 21.02791977], [71.77153015, 21.02708054], [71.77124786, 21.02708435], [71.77124786, 21.02680588], [71.76957703, 21.02680969], [71.76957703, 21.02653122], [71.76875305, 21.02653122], [71.76875305, 21.02625275], [71.76847076, 21.02625275], [71.76847076, 21.02597046], [71.76819611, 21.02597046], [71.76819611, 21.02625275], [71.76513672, 21.02625275], [71.76513672, 21.02597046], [71.76457977, 21.02597046], [71.76457977, 21.02569389], [71.76430511, 21.02569389], [71.76430511, 21.02541733], [71.76403046, 21.02542114], [71.76403046, 21.02514267], [71.76374817, 21.02514267], [71.76374817, 21.02319908], [71.76403046, 21.02319908], [71.76403046, 21.02263832], [71.76431274, 21.02263832], [71.76431274, 21.02235985], [71.76457977, 21.02236176], [71.76457977, 21.02180481], [71.76430511, 21.02180481], [71.76430511, 21.02152824], [71.76403046, 21.02152824], [71.76403046, 21.02124977], [71.76319122, 21.02124977], [71.76319122, 21.02096939], [71.76208496, 21.0209713], [71.76208496, 21.02069473], [71.76152802, 21.02069473], [71.76152802, 21.02041626], [71.76069641, 21.02041817], [71.76069641, 21.02013969], [71.75958252, 21.02013969], [71.75958252, 21.02041817], [71.75930786, 21.02041626], [71.75930786, 21.02069473], [71.75644684, 21.02069473], [71.75569153, 21.02069473], [71.75569153, 21.02083969], [71.75569153, 21.0209713], [71.75541687, 21.0209713], [71.75541687, 21.02180481], [71.75514221, 21.02180481], [71.75514221, 21.02208328], [71.75430298, 21.02208328], [71.75430298, 21.02236176], [71.75347137, 21.02235985], [71.75347137, 21.02263832], [71.75319672, 21.02263832], [71.75319672, 21.02292061], [71.75263977, 21.02292061], [71.75263977, 21.02263832], [71.75235748, 21.02263832], [71.75235748, 21.02207947], [71.75208282, 21.02208328], [71.75208282, 21.02180481], [71.75180817, 21.02180481], [71.75180817, 21.02152824], [71.75152588, 21.02152824], [71.75152588, 21.02124977], [71.75125122, 21.02124977], [71.75125122, 21.02069092], [71.75096893, 21.02069473], [71.75096893, 21.02041626], [71.75042725, 21.02041817], [71.75042725, 21.02013969], [71.75013733, 21.02013969], [71.75013733, 21.01986122], [71.74903107, 21.01986122], [71.74903107, 21.02013969], [71.74846649, 21.02013969], [71.74846649, 21.02041817], [71.74791718, 21.02041626], [71.74791718, 21.02069473], [71.74708557, 21.02069473], [71.74708557, 21.02041626], [71.74680328, 21.02041817], [71.74680328, 21.02013969], [71.74652863, 21.02013969], [71.74652863, 21.01986122], [71.74624634, 21.01986122], [71.74624634, 21.01958084], [71.74569702, 21.01958275], [71.74569702, 21.01930618], [71.7454071, 21.01930809], [71.7454071, 21.01902962], [71.74430084, 21.01902962], [71.74430084, 21.01930809], [71.74375153, 21.01930618], [71.74375153, 21.01958275], [71.74346924, 21.01958084], [71.74346924, 21.01986122], [71.74318695, 21.01986122], [71.74318695, 21.02013969], [71.74263763, 21.02013969], [71.74263763, 21.01986122], [71.74236298, 21.01986122], [71.74236298, 21.01958084], [71.74208069, 21.01958275], [71.74208069, 21.01930618], [71.74180603, 21.01930809], [71.74180603, 21.01902962], [71.74153137, 21.01902962], [71.74153137, 21.01819038], [71.74097443, 21.0181942], [71.74097443, 21.01791763], [71.73986053, 21.01791954], [71.73986053, 21.01764107], [71.73929596, 21.01764107], [71.73929596, 21.01736069], [71.73874664, 21.01736069], [71.73874664, 21.01791954], [71.73847198, 21.01791763], [71.73847198, 21.0181942], [71.73819733, 21.0181942], [71.73819733, 21.01847267], [71.73792267, 21.01846123], [71.73792267, 21.01875114], [71.73764038, 21.01875114], [71.73764038, 21.01902962], [71.73735809, 21.01902962], [71.73735809, 21.01930809], [71.73707581, 21.01930809], [71.73707581, 21.01986122], [71.73680878, 21.01986122], [71.73680878, 21.02013969], [71.73667145, 21.02013969], [71.73652649, 21.02013969], [71.73652649, 21.02041817], [71.73625183, 21.02041626], [71.73625183, 21.02069473], [71.73569489, 21.02069473], [71.73569489, 21.02041626], [71.73542786, 21.02041817], [71.73542786, 21.02013969], [71.73430634, 21.02013969], [71.73430634, 21.01986122], [71.73401642, 21.01986122], [71.73401642, 21.01958084], [71.73347473, 21.01958275], [71.73347473, 21.01930618], [71.73319244, 21.01930809], [71.73319244, 21.01902962], [71.73291779, 21.01902962], [71.73291779, 21.01884079], [71.73291779, 21.01874924], [71.73264313, 21.01875114], [71.73264313, 21.01846123], [71.73236084, 21.01847267], [71.73236084, 21.01736069], [71.73041534, 21.01736069], [71.73041534, 21.01708412], [71.73014069, 21.01708412], [71.73014069, 21.01652718], [71.73042297, 21.01653099], [71.73042297, 21.01597023], [71.73014069, 21.01597214], [71.73014069, 21.0154171], [71.7298584, 21.01542091], [71.7298584, 21.01431084], [71.73014069, 21.01431084], [71.73014069, 21.01403046], [71.7298584, 21.01403046], [71.7298584, 21.01375008], [71.72930145, 21.01375008], [71.72930145, 21.0134697], [71.72875214, 21.0134697], [71.72875214, 21.01375008], [71.72846985, 21.01375008], [71.72846985, 21.01431084], [71.72875214, 21.01430321], [71.72875214, 21.01458168], [71.72902679, 21.01457977], [71.72902679, 21.01514053], [71.72875214, 21.01514053], [71.72875214, 21.01542091], [71.7279129, 21.01542091], [71.7279129, 21.01514053], [71.72763824, 21.01514053], [71.72763824, 21.01457977], [71.7270813, 21.01458168], [71.7270813, 21.01486206], [71.72680664, 21.01486015], [71.72680664, 21.01542091], [71.7270813, 21.01542091], [71.7270813, 21.01680946], [71.72736359, 21.01680565], [71.72736359, 21.01692963], [71.72736359, 21.01708412], [71.72763824, 21.01708031], [71.72763824, 21.01791954], [71.7279129, 21.01791954], [71.7279129, 21.01902962], [71.72819519, 21.01902771], [71.72819519, 21.01958275], [71.7279129, 21.01958275], [71.7279129, 21.02069473], [71.72763824, 21.02069473], [71.72763824, 21.0209713], [71.72735596, 21.02096939], [71.72736359, 21.02124977], [71.72625732, 21.02124977], [71.72625732, 21.02152824], [71.72541809, 21.02152824], [71.72541809, 21.02180481], [71.72402954, 21.02180481], [71.72402954, 21.02152824], [71.7223587, 21.02152824], [71.7223587, 21.02180481], [71.7206955, 21.02180481], [71.7206955, 21.02152824], [71.71930695, 21.02152824], [71.71930695, 21.02124977], [71.71875, 21.02124977], [71.71875, 21.02096939], [71.71708679, 21.0209713], [71.71708679, 21.02069473], [71.71624756, 21.02069473], [71.71624756, 21.02041626], [71.7151413, 21.02041817], [71.7151413, 21.02013969], [71.71485901, 21.02013969], [71.71485901, 21.01986122], [71.7140274, 21.01986122], [71.7140274, 21.01958084], [71.71347046, 21.01958275], [71.71347046, 21.01930618], [71.71235657, 21.01930809], [71.71235657, 21.01902962], [71.71180725, 21.01902962], [71.71180725, 21.01875114], [71.71125793, 21.01875114], [71.71125793, 21.01846123], [71.71069336, 21.01847267], [71.71069336, 21.0181942], [71.7104187, 21.0181942], [71.7104187, 21.01791763], [71.70986176, 21.01791954], [71.70986176, 21.01764107], [71.70929718, 21.01764107], [71.70929718, 21.01736069], [71.70874786, 21.01736069], [71.70874786, 21.01708031], [71.70847321, 21.01708412], [71.70847321, 21.01680565], [71.70791626, 21.01680946], [71.70791626, 21.01653099], [71.7076416, 21.01653099], [71.7076416, 21.01625061], [71.70735931, 21.01625061], [71.70735931, 21.01597023], [71.70680237, 21.01597214], [71.70680237, 21.01569557], [71.70652771, 21.01569557], [71.70652771, 21.0154171], [71.70625305, 21.01542091], [71.70625305, 21.01514053], [71.70569611, 21.01514053], [71.70569611, 21.01486015], [71.70541382, 21.01486206], [71.70541382, 21.01458168], [71.70513916, 21.01458168], [71.70513916, 21.01430321], [71.70485687, 21.01431084], [71.70485687, 21.01403046], [71.70430756, 21.01403046], [71.70430756, 21.01375008], [71.70375061, 21.01375008], [71.70375061, 21.0134697], [71.70347595, 21.01347351], [71.70347595, 21.01319313], [71.70318604, 21.01320076], [71.70318604, 21.01292038], [71.70263672, 21.01292038], [71.70263672, 21.01264954], [71.70236206, 21.01264954], [71.70236206, 21.01235962], [71.70180511, 21.01236343], [71.70180511, 21.01208115], [71.70153046, 21.01208115], [71.70153046, 21.01180649], [71.70096588, 21.0118103], [71.70096588, 21.01153183], [71.70069122, 21.01153183], [71.70069122, 21.01124954], [71.70014191, 21.01124954], [71.70014191, 21.01096916], [71.69930267, 21.01097107], [71.69930267, 21.0106945], [71.69875336, 21.0106945], [71.69875336, 21.01013947], [71.69819641, 21.01013947], [71.69819641, 21.00985909], [71.69735718, 21.00985909], [71.69735718, 21.00959015], [71.69680786, 21.00959015], [71.69680786, 21.00931168], [71.6965332, 21.00931168], [71.6965332, 21.0090313], [71.69374847, 21.0090313], [71.69374847, 21.00875092], [71.69235992, 21.00875092], [71.69235992, 21.00847054], [71.69041443, 21.00847244], [71.69041443, 21.00819397], [71.68902588, 21.00819397], [71.68902588, 21.00792122], [71.68846893, 21.00792122], [71.68846893, 21.00764084], [71.68818665, 21.00764084], [71.68818665, 21.00736046], [71.68763733, 21.00736046], [71.68763733, 21.00708008], [71.68736267, 21.00708389], [71.68736267, 21.00680542], [71.68653107, 21.00681114], [71.68653107, 21.00652122], [71.68624878, 21.00652885], [71.68624878, 21.00625038], [71.68596649, 21.00625038], [71.68596649, 21.00597], [71.68514252, 21.00597191], [71.68514252, 21.00569534], [71.6845932, 21.00570107], [71.6845932, 21.00542068], [71.68430328, 21.00542068], [71.68430328, 21.00485992], [71.68374634, 21.00486183], [71.68374634, 21.00458336], [71.68291473, 21.00458336], [71.68291473, 21.00430679], [71.68208313, 21.00430679], [71.68208313, 21.00374985], [71.68180847, 21.00374985], [71.68180847, 21.00319099], [71.68096924, 21.00319672], [71.68096924, 21.00291634], [71.68041992, 21.00292015], [71.68041992, 21.00263977], [71.68013763, 21.00263977], [71.68013763, 21.00235939], [71.67986298, 21.0023613], [71.67986298, 21.00180626], [71.67958069, 21.00181007], [71.67958069, 21.00125122], [71.67930603, 21.00125122], [71.67930603, 21.00069046], [71.67958069, 21.00069237], [71.67958069, 20.99986267], [71.67958069, 20.99930954], [71.67986298, 20.99930954], [71.67986298, 20.99872017], [71.67986298, 20.99791718], [71.67958069, 20.9979229], [71.67958069, 20.99736023], [71.67736053, 20.99736023], [71.67736053, 20.99707985], [71.67680359, 20.99708366], [71.67680359, 20.99680519], [71.67514038, 20.99680519], [71.67514038, 20.99708366], [71.67457581, 20.99707985], [71.67458344, 20.99736023], [71.67436981, 20.99736023], [71.67402649, 20.99736023], [71.67402649, 20.99765015], [71.67346954, 20.99765015], [71.67346954, 20.9979229], [71.67292023, 20.99791718], [71.67292023, 20.99819374], [71.67236328, 20.99819374], [71.67236328, 20.99847031], [71.67180634, 20.99847031], [71.67180634, 20.99875259], [71.67124939, 20.99875259], [71.67124939, 20.99903107], [71.66874695, 20.99903107], [71.66874695, 20.99930954], [71.66499329, 20.99930573], [71.66374969, 20.99930954], [71.66374969, 20.99903107], [71.6609726, 20.99903107], [71.6609726, 20.99875259], [71.65930176, 20.99875259], [71.65930176, 20.99847031], [71.65763855, 20.99847031], [71.65763855, 20.99819374], [71.65569305, 20.99819374], [71.65569305, 20.99791718], [71.65486145, 20.9979229], [71.65486145, 20.99765015], [71.65374756, 20.99765015], [71.65374756, 20.99736023], [71.65291595, 20.99736023], [71.65291595, 20.99707985], [71.65180206, 20.99708366], [71.65180206, 20.99680519], [71.65125275, 20.99681091], [71.65125275, 20.99652863], [71.65040588, 20.99652863], [71.65040588, 20.99624825], [71.64985657, 20.99624825], [71.64985657, 20.99596977], [71.64902496, 20.99597168], [71.64902496, 20.99569511], [71.64848328, 20.99570084], [71.64848328, 20.99542046], [71.64763641, 20.99542046], [71.64763641, 20.99513817], [71.6470871, 20.99513817], [71.6470871, 20.9948597], [71.64653015, 20.9948616], [71.64653015, 20.99458313], [71.64624786, 20.99458313], [71.64624786, 20.99430466], [71.64569092, 20.99430466], [71.64569092, 20.99402618], [71.64541626, 20.99402809], [71.64541626, 20.99374962], [71.64485168, 20.99374962], [71.64485168, 20.99347115], [71.64458466, 20.99347305], [71.64458466, 20.99319458], [71.64402771, 20.99319458], [71.64402771, 20.99291611], [71.64347076, 20.99291992], [71.64347076, 20.99263954], [71.64319611, 20.99263954], [71.64319611, 20.99236107], [71.64263916, 20.99236107], [71.64263916, 20.99208069], [71.6423645, 20.9920826], [71.6423645, 20.99180794], [71.64180756, 20.99180984], [71.64180756, 20.99151993], [71.64152527, 20.99152756], [71.64152527, 20.99124908], [71.64097595, 20.99125099], [71.64097595, 20.99097061], [71.64041901, 20.99097252], [71.64041901, 20.99069595], [71.63986206, 20.99069595], [71.63986206, 20.99041748], [71.63957977, 20.99041939], [71.63957977, 20.99014091], [71.63903809, 20.99014091], [71.63903809, 20.98986053], [71.63846588, 20.98986053], [71.63846588, 20.98903084], [71.63819122, 20.98903084], [71.63819122, 20.98792076], [71.63791656, 20.98792076], [71.63791656, 20.98681068], [71.63764191, 20.98681068], [71.63764191, 20.98569107], [71.63735962, 20.98569489], [71.63735962, 20.9845829], [71.63708496, 20.9845829], [71.63708496, 20.98347282], [71.63680267, 20.98347282], [71.63680267, 20.98291588], [71.63625336, 20.9829216], [71.63625336, 20.98097038], [71.63597107, 20.98097229], [71.63597107, 20.97847176], [71.63625336, 20.97847176], [71.63625336, 20.97791672], [71.63680267, 20.97792053], [71.63680267, 20.97764015], [71.63791656, 20.97764015], [71.63791656, 20.97707939], [71.63819122, 20.97708321], [71.63819122, 20.97680664], [71.63847351, 20.97680664], [71.63847351, 20.97624969], [71.63874817, 20.97624969], [71.63874817, 20.97597122], [71.63847351, 20.97597313], [71.63847351, 20.97569466], [71.63819122, 20.97569466], [71.63819122, 20.97513962], [71.63791656, 20.97513962], [71.63791656, 20.97486115], [71.63764191, 20.97486115], [71.63764191, 20.97458076], [71.63735962, 20.97458458], [71.63735962, 20.97430611], [71.63707733, 20.97430992], [71.63707733, 20.97402954], [71.63680267, 20.97402954], [71.63680267, 20.97375107], [71.63652802, 20.97375107], [71.63652802, 20.97348022], [71.6359787, 20.97348022], [71.6359787, 20.97319031], [71.63513947, 20.97319221], [71.63513947, 20.97291756], [71.63458252, 20.97291946], [71.63458252, 20.9726429], [71.63375092, 20.9726429], [71.63375092, 20.97236061], [71.63318634, 20.97236061], [71.63318634, 20.97208023], [71.63236237, 20.97208214], [71.63236237, 20.97180557], [71.63181305, 20.97180939], [71.63181305, 20.97153282], [71.63096619, 20.97153282], [71.63096619, 20.97125244], [71.63014221, 20.97125244], [71.63014221, 20.97097015], [71.62930298, 20.97097015], [71.62930298, 20.97069359], [71.62847137, 20.97069359], [71.62847137, 20.97013855], [71.62819672, 20.97013855], [71.62819672, 20.9695797], [71.62791443, 20.96958351], [71.62791443, 20.96930504], [71.62652588, 20.96931076], [71.62652588, 20.96902847], [71.62523651, 20.96902847], [71.62513733, 20.96902847], [71.62513733, 20.96874809], [71.62430573, 20.96874809], [71.62430573, 20.96847153], [71.62347412, 20.96847153], [71.62347412, 20.96819496], [71.62291718, 20.96820068], [71.62291718, 20.9679184], [71.6220932, 20.9679184], [71.6220932, 20.96763992], [71.62097168, 20.96763992], [71.62097168, 20.96902847], [71.62069702, 20.96902847], [71.62069702, 20.96958351], [71.62041473, 20.96958351], [71.62041473, 20.96986008], [71.61902618, 20.96986008], [71.61902618, 20.96930504], [71.61875153, 20.96931076], [71.61875153, 20.96902847], [71.61680603, 20.96902847], [71.61680603, 20.96931076], [71.61708069, 20.96931076], [71.61708069, 20.97013855], [71.61736298, 20.97013855], [71.61736298, 20.97069359], [71.61763763, 20.97069359], [71.61763763, 20.97102928], [71.61763763, 20.97125244], [71.61791229, 20.97125244], [71.61791229, 20.97153282], [71.61818695, 20.97153282], [71.61818695, 20.97180939], [71.61846924, 20.97180939], [71.61846924, 20.97236061], [71.61875153, 20.97236061], [71.61875153, 20.97291946], [71.61846924, 20.97291946], [71.61846924, 20.97402954], [71.61819458, 20.97402763], [71.61819458, 20.97458458], [71.61763763, 20.97458076], [71.61763763, 20.97486115], [71.61708069, 20.97486115], [71.61708069, 20.97513962], [71.61653137, 20.97513962], [71.61653137, 20.97542], [71.61597443, 20.97541618], [71.61597443, 20.97569466], [71.61264038, 20.97569466], [71.61264038, 20.97541618], [71.61235809, 20.97542], [71.61235809, 20.97513962], [71.61207581, 20.97513962], [71.61207581, 20.97486115], [71.61180878, 20.97486115], [71.61180878, 20.97458076], [71.61152649, 20.97458458], [71.61152649, 20.97402763], [71.61125183, 20.97402954], [71.61125183, 20.97348022], [71.61096954, 20.97348022], [71.61096954, 20.97291946], [71.61068726, 20.97291946], [71.61068726, 20.97236061], [71.61042023, 20.97236061], [71.61042023, 20.97180939], [71.61013794, 20.97180939], [71.61013794, 20.97153282], [71.61042023, 20.97153282], [71.61042023, 20.97097015], [71.61069489, 20.97097015], [71.61069489, 20.97041702], [71.61096954, 20.97041702], [71.61096954, 20.97013855], [71.61125183, 20.97013855], [71.61125183, 20.9695797], [71.61152649, 20.96958351], [71.61152649, 20.96941948], [71.61152649, 20.96847153], [71.61180878, 20.96847153], [71.61180878, 20.96736145], [71.61125183, 20.96736145], [71.61125183, 20.96708298], [71.61042023, 20.96708298], [71.61042023, 20.96680641], [71.60958099, 20.96681023], [71.60958099, 20.96652985], [71.6084671, 20.96652985], [71.6084671, 20.96624947], [71.60819244, 20.96624947], [71.60819244, 20.96597099], [71.60791779, 20.9659729], [71.60791779, 20.96569443], [71.60736084, 20.96569443], [71.60736084, 20.96541786], [71.60708618, 20.96541977], [71.60708618, 20.96513939], [71.60679626, 20.96513939], [71.60679626, 20.96486092], [71.60457611, 20.96486092], [71.60457611, 20.96458054], [71.60346985, 20.96458244], [71.60346985, 20.96430588], [71.60097504, 20.96430588], [71.60097504, 20.96458244], [71.59999847, 20.96458244], [71.59986115, 20.96458244], [71.59986877, 20.96486092], [71.59902954, 20.96486092], [71.59902954, 20.96708298], [71.59819794, 20.96708298], [71.59819794, 20.96736145], [71.5973587, 20.96736145], [71.5973587, 20.96680641], [71.59707642, 20.96681023], [71.59707642, 20.96652985], [71.59680176, 20.96652985], [71.59680176, 20.96597099], [71.5965271, 20.9659729], [71.5965271, 20.96569443], [71.59625244, 20.96569443], [71.59625244, 20.96513939], [71.59597015, 20.96513939], [71.59597015, 20.96486092], [71.5956955, 20.96486092], [71.5956955, 20.96430588], [71.59541321, 20.96430969], [71.59541321, 20.96403122], [71.59513855, 20.96403122], [71.59513855, 20.96347046], [71.59486389, 20.96347237], [71.59486389, 20.9631958], [71.5945816, 20.9631958], [71.5945816, 20.96263885], [71.59430695, 20.96264076], [71.59430695, 20.96236038], [71.59401703, 20.96236038], [71.59402466, 20.96208], [71.59402466, 20.96180534], [71.59374237, 20.96181107], [71.59374237, 20.96154022], [71.59348297, 20.96154022], [71.59348297, 20.96125031], [71.5929184, 20.96125031], [71.5929184, 20.96096992], [71.59263611, 20.96097374], [71.59263611, 20.96069527], [71.59208679, 20.96070099], [71.59208679, 20.96042061], [71.58911896, 20.96042061], [71.58735657, 20.96042061], [71.58735657, 20.96070099], [71.58680725, 20.96070099], [71.58680725, 20.96042061], [71.58651733, 20.96042061], [71.58651733, 20.96014023], [71.58598328, 20.96014023], [71.58598328, 20.95985985], [71.5854187, 20.95986366], [71.5854187, 20.95969009], [71.5854187, 20.95958138], [71.58513641, 20.95958138], [71.58513641, 20.95930481], [71.58486176, 20.95930481], [71.58486176, 20.95902824], [71.58204651, 20.95903015], [71.58097076, 20.95903015], [71.58097076, 20.95878029], [71.58069611, 20.95874977], [71.58069611, 20.95846939], [71.58041382, 20.95846939], [71.58041382, 20.95819473], [71.58013916, 20.95819473], [71.58013916, 20.95791626], [71.57958221, 20.95792007], [71.57958221, 20.9576416], [71.57930756, 20.9576416], [71.57930756, 20.95735931], [71.57902527, 20.95735931], [71.57902527, 20.95708275], [71.57875061, 20.95708275], [71.57875061, 20.95680618], [71.5790329, 20.9568119], [71.5790329, 20.95624924], [71.57930756, 20.95624924], [71.57930756, 20.95597076], [71.57958221, 20.95597267], [71.57958221, 20.9556942], [71.5798645, 20.9556942], [71.5798645, 20.95513725], [71.58013916, 20.95513916], [71.58013916, 20.95486069], [71.57985687, 20.95486069], [71.57985687, 20.95430756], [71.57958221, 20.95430756], [71.57958221, 20.95402908], [71.57624817, 20.95402908], [71.57624817, 20.95430756], [71.57457733, 20.95430756], [71.57457733, 20.95402908], [71.57319641, 20.95402908], [71.57319641, 20.95375061], [71.57263947, 20.95375061], [71.57263947, 20.95347023], [71.57236481, 20.95347214], [71.57236481, 20.95319366], [71.57096863, 20.95319366], [71.57096863, 20.95347214], [71.57068634, 20.95347023], [71.57068634, 20.95375061], [71.57013702, 20.95375061], [71.57013702, 20.95402908], [71.56846619, 20.95402908], [71.56846619, 20.95375061], [71.56819153, 20.95375061], [71.56819153, 20.95318985], [71.56791687, 20.95319366], [71.56791687, 20.95263863], [71.56764221, 20.95264053], [71.56764221, 20.95207977], [71.56735992, 20.95208359], [71.56735992, 20.95152855], [71.5670929, 20.95153046], [71.5670929, 20.9509697], [71.56680298, 20.9509716], [71.56680298, 20.95069695], [71.56652832, 20.95070076], [71.56652832, 20.95042038], [71.56597137, 20.95042038], [71.56597137, 20.95014], [71.56569672, 20.95014], [71.56569672, 20.94985962], [71.56513977, 20.94986153], [71.56513977, 20.94958305], [71.56319427, 20.94958305], [71.56319427, 20.94986153], [71.56124878, 20.94985962], [71.56124878, 20.95014], [71.55652618, 20.95014], [71.55652618, 20.95042038], [71.55430603, 20.95042038], [71.55430603, 20.95014], [71.55403137, 20.95014], [71.55403137, 20.94985962], [71.55347443, 20.94986153], [71.55347443, 20.94958305], [71.54792023, 20.94958305], [71.54792023, 20.94986153], [71.54763794, 20.94985962], [71.54763794, 20.95014], [71.54736328, 20.95013809], [71.54736328, 20.95039177], [71.54708099, 20.95042038], [71.54708099, 20.95070076], [71.54569244, 20.95070076], [71.54569244, 20.95042038], [71.54541779, 20.95042038], [71.54541779, 20.94985962], [71.5451355, 20.94986153], [71.5451355, 20.94958305], [71.54486084, 20.94958305], [71.54486084, 20.94930649], [71.54374695, 20.9493103], [71.54374695, 20.94902992], [71.54347229, 20.94902992], [71.54347229, 20.94874954], [71.54291534, 20.94874954], [71.54291534, 20.94847488], [71.54264069, 20.94847488], [71.54264069, 20.9481945], [71.5423584, 20.9481945], [71.5423584, 20.94791412], [71.54180908, 20.94791985], [71.54180908, 20.94763947], [71.54152679, 20.94763947], [71.54152679, 20.9473629], [71.54125214, 20.9473629], [71.54125214, 20.94680977], [71.54096985, 20.94680977], [71.54096985, 20.94652939], [71.54013824, 20.94652939], [71.54013824, 20.94623947], [71.53902435, 20.94625282], [71.53902435, 20.94597054], [71.53819275, 20.94597054], [71.53819275, 20.94569206], [71.5376358, 20.94569206], [71.5376358, 20.9454174], [71.53679657, 20.94542122], [71.53679657, 20.94514275], [71.5359726, 20.94514275], [71.5359726, 20.94486046], [71.53569794, 20.94486046], [71.53569794, 20.94458008], [71.53541565, 20.94458389], [71.53541565, 20.94430542], [71.53514099, 20.94431114], [71.53514099, 20.94403267], [71.53457642, 20.94403267], [71.53457642, 20.94375229], [71.53430176, 20.94375229], [71.53430176, 20.94346809], [71.5340271, 20.94347191], [71.5340271, 20.94319534], [71.53013611, 20.94319534], [71.53013611, 20.94347191], [71.52986145, 20.94347191], [71.52986145, 20.94390106], [71.52986145, 20.94403267], [71.52929688, 20.94403267], [71.52929688, 20.94431114], [71.52874756, 20.94430542], [71.52874756, 20.94458389], [71.52819824, 20.94458008], [71.52819824, 20.94486046], [71.52764893, 20.94486046], [71.52764893, 20.94514275], [71.52707672, 20.94514275], [71.52707672, 20.94542122], [71.52680206, 20.9454174], [71.52680206, 20.94569206], [71.52625275, 20.94569206], [71.52625275, 20.94597054], [71.5256958, 20.94597054], [71.5256958, 20.94625282], [71.52513885, 20.94623947], [71.52513885, 20.94652939], [71.52458954, 20.94652939], [71.52458954, 20.94680977], [71.52401733, 20.94680977], [71.52401733, 20.94652939], [71.52348328, 20.94652939], [71.52348328, 20.94680977], [71.52319336, 20.94680977], [71.52319336, 20.94763947], [71.5229187, 20.94763947], [71.5229187, 20.94847488], [71.52263641, 20.94847107], [71.52263641, 20.94902992], [71.52069092, 20.94902992], [71.52069092, 20.9493103], [71.51790619, 20.9493103], [71.51790619, 20.94902992], [71.51708221, 20.94902992], [71.51708221, 20.94874954], [71.51652527, 20.94874954], [71.51652527, 20.94847488], [71.51569366, 20.94847488], [71.51569366, 20.9481945], [71.51486206, 20.9481945], [71.51486206, 20.94791412], [71.51457977, 20.94791985], [71.51457977, 20.94763947], [71.51403046, 20.94763947], [71.51403046, 20.9473629], [71.51374817, 20.9473629], [71.51374817, 20.94708061], [71.51319122, 20.94708443], [71.51319122, 20.94680595], [71.51291656, 20.94680977], [71.51291656, 20.94652939], [71.51264954, 20.94652939], [71.51264954, 20.94597054], [71.51235962, 20.94597054], [71.51235962, 20.9454174], [71.51207733, 20.94542122], [71.51207733, 20.94514275], [71.51152802, 20.94514275], [71.51152802, 20.94486046], [71.51097107, 20.94486046], [71.51097107, 20.94458008], [71.51041412, 20.94458389], [71.51041412, 20.94430542], [71.50985718, 20.94431114], [71.50985718, 20.94403267], [71.50958252, 20.94403267], [71.50958252, 20.94346809], [71.50930786, 20.94347191], [71.50930786, 20.94319534], [71.5090332, 20.94319916], [71.5090332, 20.9426384], [71.50875092, 20.9426384], [71.50875092, 20.94207954], [71.50846863, 20.94208336], [71.50846863, 20.94152832], [71.50875092, 20.94152832], [71.50875092, 20.94124985], [71.5090332, 20.94124985], [71.50902557, 20.94097137], [71.50930786, 20.94097137], [71.50930786, 20.94041634], [71.50958252, 20.94043159], [71.50958252, 20.94013977], [71.50985718, 20.94013977], [71.50985718, 20.93985939], [71.51013947, 20.9398613], [71.51013947, 20.93958282], [71.51041412, 20.93958282], [71.51041412, 20.93930626], [71.51097107, 20.93930817], [71.51097107, 20.93902969], [71.51125336, 20.93902969], [71.51125336, 20.93847084], [71.51097107, 20.93847275], [71.51097107, 20.93736076], [71.51069641, 20.9373703], [71.51069641, 20.93625069], [71.51040649, 20.93625069], [71.51040649, 20.93568993], [71.51013947, 20.93569565], [71.51013947, 20.93541718], [71.50985718, 20.93542099], [71.50985718, 20.93514061], [71.50958252, 20.93514061], [71.50958252, 20.93486023], [71.50930786, 20.93486023], [71.50930786, 20.93457985], [71.50902557, 20.93458366], [71.50902557, 20.93430328], [71.50875092, 20.93430328], [71.50875092, 20.93402863], [71.50846863, 20.93403053], [71.50846863, 20.93375015], [71.50818634, 20.93375015], [71.50818634, 20.93346977], [71.50791931, 20.93347359], [71.50791931, 20.93319511], [71.50763702, 20.93320084], [71.50763702, 20.93292046], [71.50736237, 20.93292046], [71.50736237, 20.93264008], [71.50708008, 20.93264008], [71.50708008, 20.9323597], [71.50680542, 20.93236351], [71.50680542, 20.93208122], [71.50653076, 20.93208122], [71.50653076, 20.93180466], [71.50680542, 20.93180466], [71.50680542, 20.93152809], [71.50708008, 20.93153191], [71.50708008, 20.93123817], [71.50736237, 20.93124962], [71.50736237, 20.93097115], [71.50763702, 20.93097115], [71.50763702, 20.93041611], [71.50791931, 20.93042183], [71.50791931, 20.93014145], [71.50818634, 20.93014145], [71.50818634, 20.92985916], [71.50846863, 20.92985916], [71.50846863, 20.92958069], [71.50875092, 20.9295826], [71.50875092, 20.92930603], [71.5090332, 20.92931175], [71.5090332, 20.92903137], [71.50930786, 20.92903137], [71.50930786, 20.92874908], [71.50958252, 20.92874908], [71.50958252, 20.92847061], [71.50986481, 20.92847252], [71.50986481, 20.92819405], [71.51013947, 20.92819405], [71.51013947, 20.9276371], [71.51040649, 20.92764091], [71.51040649, 20.92736053], [71.51069641, 20.92736053], [71.51069641, 20.92708015], [71.51097107, 20.92708397], [71.51097107, 20.9268055], [71.51125336, 20.92681122], [71.51125336, 20.92625046], [71.51097107, 20.92625046], [71.51097107, 20.92514038], [71.51069641, 20.92514038], [71.51069641, 20.92431068], [71.51097107, 20.92431068], [71.51097107, 20.92374992], [71.51235962, 20.92374992], [71.51235962, 20.9240303], [71.51319122, 20.9240303], [71.51319122, 20.92431068], [71.51403046, 20.92430687], [71.51403046, 20.92441177], [71.51403046, 20.92458344], [71.51486206, 20.92458344], [71.51486206, 20.92486191], [71.51541901, 20.92486191], [71.51541901, 20.92458344], [71.51569366, 20.92458344], [71.51569366, 20.9240284], [71.51597595, 20.9240303], [71.51597595, 20.92346954], [71.51652527, 20.92347145], [71.51652527, 20.92319679], [71.51625061, 20.92319679], [71.51625061, 20.92291641], [71.51597595, 20.92292023], [71.51597595, 20.92235947], [71.51569366, 20.92236137], [71.51569366, 20.92208481], [71.51541901, 20.92208481], [71.51541901, 20.92180634], [71.51513672, 20.92181015], [71.51513672, 20.92152977], [71.51486206, 20.92152977], [71.51486206, 20.92124939], [71.51430511, 20.92124939], [71.51430511, 20.92097473], [71.51374817, 20.92097473], [71.51374817, 20.92069244], [71.51319122, 20.92069244], [71.51319122, 20.92041588], [71.51291656, 20.92041969], [71.51291656, 20.92014122], [71.51235962, 20.92014122], [71.51235962, 20.91958046], [71.51180267, 20.91958427], [71.51180267, 20.9193058], [71.51125336, 20.9193058], [71.51125336, 20.91875267], [71.51069641, 20.91875267], [71.51069641, 20.91847038], [71.51013947, 20.91847038], [71.51013947, 20.91819382], [71.50986481, 20.91819382], [71.50986481, 20.91791725], [71.50930786, 20.91792107], [71.50930786, 20.91764259], [71.5090332, 20.91764259], [71.5090332, 20.91736031], [71.50875092, 20.91736031], [71.50875092, 20.9168129], [71.50846863, 20.9168129], [71.50846863, 20.91653061], [71.50818634, 20.91653061], [71.50818634, 20.91624069], [71.50763702, 20.91624451], [71.50708008, 20.91624832], [71.50708008, 20.91597176], [71.50541687, 20.91597176], [71.50541687, 20.91624832], [71.5045929, 20.91624069], [71.5045929, 20.91653061], [71.50235748, 20.91653061], [71.50235748, 20.91736031], [71.50208282, 20.91736031], [71.50208282, 20.91764259], [71.50068665, 20.91764259], [71.50068665, 20.91792107], [71.49931335, 20.91792107], [71.49931335, 20.91764259], [71.49903107, 20.91764259], [71.49903107, 20.91708183], [71.49874878, 20.91708374], [71.49874878, 20.91680527], [71.49819183, 20.91680527], [71.49819183, 20.91708374], [71.49764252, 20.91708183], [71.49764252, 20.91736031], [71.4970932, 20.91736031], [71.4970932, 20.91764259], [71.49680328, 20.91764259], [71.49680328, 20.91792107], [71.49318695, 20.91792107], [71.49318695, 20.91764259], [71.49291992, 20.91764259], [71.49291992, 20.91736031], [71.49263763, 20.91736031], [71.49263763, 20.91708183], [71.49208069, 20.91708374], [71.49208069, 20.91680527], [71.49180603, 20.9168129], [71.49180603, 20.91653061], [71.491539, 20.91653061], [71.491539, 20.91624069], [71.49124908, 20.91624832], [71.49124908, 20.91597176], [71.49069214, 20.91597176], [71.49069214, 20.91569519], [71.49041748, 20.91570091], [71.49041748, 20.91542053], [71.48958588, 20.91542053], [71.48958588, 20.91513824], [71.48902893, 20.91513824], [71.48902893, 20.91485977], [71.48819733, 20.91486168], [71.48819733, 20.91458321], [71.48791504, 20.91458321], [71.48791504, 20.91402817], [71.48764038, 20.91402817], [71.48764038, 20.91347122], [71.48791504, 20.91347313], [71.48791504, 20.91291618], [71.48819733, 20.91291809], [71.48819733, 20.91236115], [71.48847961, 20.91236115], [71.48847198, 20.91208267], [71.48652649, 20.91208267], [71.48652649, 20.91180611], [71.48625183, 20.91180992], [71.48625183, 20.91152954], [71.48596954, 20.91152954], [71.48596954, 20.91125107], [71.4854126, 20.91125107], [71.4854126, 20.91097069], [71.48513794, 20.9109726], [71.48513794, 20.91069412], [71.48596954, 20.91069412], [71.48596954, 20.91041756], [71.48707581, 20.91041946], [71.48707581, 20.91014099], [71.48792267, 20.91014099], [71.48792267, 20.90986061], [71.48819733, 20.90986061], [71.48819733, 20.90930939], [71.48847961, 20.90930939], [71.48847961, 20.90903091], [71.49041748, 20.90903091], [71.49041748, 20.90875053], [71.49236298, 20.90875053], [71.49236298, 20.90847015], [71.49430847, 20.90847206], [71.49430847, 20.9081955], [71.49458313, 20.9081955], [71.49458313, 20.90791702], [71.49514008, 20.90792084], [71.49514008, 20.90764046], [71.48430634, 20.90764046], [71.48430634, 20.90736008], [71.48402405, 20.90736389], [71.48402405, 20.9070816], [71.48347473, 20.9070816], [71.48347473, 20.90680313], [71.48319244, 20.90681076], [71.48319244, 20.90653038], [71.48264313, 20.90653038], [71.48264313, 20.90625191], [71.48235321, 20.90625191], [71.48235321, 20.90570068], [71.48208618, 20.90570068], [71.48208618, 20.90514183], [71.48179626, 20.90514183], [71.48179626, 20.90457916], [71.48152924, 20.90458107], [71.48152924, 20.90374947], [71.48179626, 20.90374947], [71.48179626, 20.90236092], [71.48208618, 20.90236092], [71.48208618, 20.90097046], [71.48236084, 20.90097237], [71.48236084, 20.90013885], [71.48179626, 20.90014076], [71.48179626, 20.89986038], [71.48097229, 20.89986038], [71.48097229, 20.89958], [71.48069763, 20.89958382], [71.48069763, 20.89902687], [71.48042297, 20.89903069], [71.48042297, 20.89846992], [71.48014069, 20.89847183], [71.48014069, 20.89819527], [71.4798584, 20.89820099], [71.4798584, 20.89764023], [71.47957611, 20.89764023], [71.47957611, 20.89707947], [71.47930908, 20.89708328], [71.47930908, 20.89680672], [71.47902679, 20.89680672], [71.47902679, 20.89652824], [71.47875214, 20.89653015], [71.47875214, 20.89624977], [71.47846985, 20.89624977], [71.47846985, 20.89596939], [71.47819519, 20.8959713], [71.47819519, 20.89374924], [71.47846985, 20.89375114], [71.47846985, 20.89285278], [71.47846985, 20.89263916], [71.47820282, 20.89264107], [71.47820282, 20.8915329], [71.4779129, 20.8915329], [71.4779129, 20.89069176], [71.47763824, 20.89069366], [71.47763824, 20.8904171], [71.47735596, 20.89042282], [71.47735596, 20.89013863], [71.4770813, 20.89013863], [71.4770813, 20.88985825], [71.47458649, 20.88986015], [71.47458649, 20.88958359], [71.47402954, 20.88958359], [71.47402954, 20.88930511], [71.4734726, 20.88932037], [71.4734726, 20.88902855], [71.47264099, 20.88902855], [71.47264099, 20.88874817], [71.47207642, 20.88874817], [71.47207642, 20.8884697], [71.47180176, 20.8884716], [71.47180176, 20.88819504], [71.4715271, 20.88820076], [71.4715271, 20.88763809], [71.47125244, 20.88763809], [71.47125244, 20.88735962], [71.47097015, 20.88736153], [71.47097015, 20.88708305], [71.46986389, 20.88708305], [71.46986389, 20.88680649], [71.4695816, 20.8868103], [71.4695816, 20.88652992], [71.46930695, 20.88652992], [71.46930695, 20.88597107], [71.46902466, 20.88597298], [71.46902466, 20.8856945], [71.46875, 20.8856945], [71.46875, 20.88541794], [71.46848297, 20.88541985], [71.46848297, 20.88513947], [71.4679184, 20.88513947], [71.4679184, 20.88486099], [71.4651413, 20.88486099], [71.4651413, 20.88458061], [71.46485901, 20.88458252], [71.46485901, 20.88402748], [71.46457672, 20.88402939], [71.46457672, 20.88375092], [71.46430206, 20.88375092], [71.46430206, 20.88319588], [71.4640274, 20.88319588], [71.4640274, 20.88263893], [71.46375275, 20.88264084], [71.46375275, 20.88236046], [71.46347046, 20.88236046], [71.46347046, 20.88181114], [71.4631958, 20.88181114], [71.4631958, 20.88153076], [71.46290588, 20.88153076], [71.46290588, 20.88125038], [71.46263885, 20.88125038], [71.46263885, 20.88097], [71.45986176, 20.88097], [71.45986176, 20.88125038], [71.45874786, 20.88125038], [71.45874786, 20.88097], [71.4576416, 20.88097382], [71.4576416, 20.88069534], [71.45569611, 20.88069534], [71.45569611, 20.88097382], [71.45513916, 20.88097], [71.45513916, 20.88125038], [71.45236969, 20.88125038], [71.45236969, 20.88153076], [71.44847107, 20.88153076], [71.44847107, 20.88097], [71.44819641, 20.88097382], [71.44819641, 20.88041687], [71.44790649, 20.88042068], [71.44790649, 20.87709045], [71.44652557, 20.87708282], [71.44652557, 20.87735939], [71.44596863, 20.87735939], [71.44596863, 20.87708282], [71.44568634, 20.87709045], [71.44568634, 20.87681007], [71.44541931, 20.87681007], [71.44541931, 20.8765316], [71.44513702, 20.8765316], [71.44513702, 20.87624931], [71.44431305, 20.87624931], [71.44431305, 20.87597084], [71.44403076, 20.87597275], [71.44403076, 20.8754158], [71.44374847, 20.87542152], [71.44374847, 20.87513924], [71.44346619, 20.87513924], [71.44346619, 20.87486076], [71.44317627, 20.87486076], [71.44317627, 20.87431908], [71.44291687, 20.87431908], [71.44291687, 20.87402916], [71.44264221, 20.87402916], [71.44264221, 20.87375069], [71.44235992, 20.87375069], [71.44235992, 20.87318993], [71.44208527, 20.87319374], [71.44208527, 20.87291718], [71.44180298, 20.87292099], [71.44180298, 20.87207985], [71.44152832, 20.87208366], [71.44152832, 20.87125015], [71.44124603, 20.87125015], [71.44124603, 20.87096024], [71.44097137, 20.87097168], [71.44097137, 20.87069511], [71.44069672, 20.87070084], [71.44069672, 20.87014008], [71.4404068, 20.87014008], [71.4404068, 20.8698597], [71.44013977, 20.8698616], [71.44013977, 20.86958313], [71.43958282, 20.86958313], [71.43958282, 20.86930466], [71.43875122, 20.86930466], [71.43875122, 20.86902809], [71.43818665, 20.86903], [71.43818665, 20.86874962], [71.43736267, 20.86874962], [71.43736267, 20.86847305], [71.43569183, 20.86847115], [71.43569183, 20.86903], [71.43486023, 20.86903], [71.43486023, 20.86874962], [71.43374634, 20.86874962], [71.43374634, 20.86847115], [71.43235779, 20.86847305], [71.43235779, 20.86819458], [71.43180847, 20.86819458], [71.43180847, 20.86791611], [71.43123627, 20.86791992], [71.43123627, 20.86763954], [71.43068695, 20.86763954], [71.43068695, 20.86736107], [71.42819214, 20.86736107], [71.42819214, 20.86763954], [71.42764282, 20.86763954], [71.42764282, 20.86791992], [71.42652893, 20.86791992], [71.42652893, 20.86763954], [71.42624664, 20.86763954], [71.42624664, 20.86736107], [71.42485809, 20.86736107], [71.42485809, 20.86763954], [71.42430878, 20.86763954], [71.42430878, 20.86791992], [71.42346954, 20.86791992], [71.42346954, 20.86763954], [71.42292023, 20.86763954], [71.42292023, 20.86736107], [71.42263794, 20.86736107], [71.42263794, 20.86708069], [71.42236328, 20.8670845], [71.42236328, 20.86680603], [71.42151642, 20.86680984], [71.42151642, 20.86652946], [71.4209671, 20.86652946], [71.42097473, 20.86636925], [71.42097473, 20.86624908], [71.42069244, 20.8662529], [71.42069244, 20.86597061], [71.4201355, 20.86597061], [71.42014313, 20.86652184], [71.42041779, 20.86652946], [71.42041779, 20.86680984], [71.42069244, 20.86680603], [71.42069244, 20.8670845], [71.42151642, 20.86708069], [71.42151642, 20.86736107], [71.42180634, 20.86736107], [71.42180634, 20.86847305], [71.42097473, 20.86847305], [71.42097473, 20.86819458], [71.42069244, 20.86819458], [71.42069244, 20.86791611], [71.41986084, 20.86791992], [71.41986084, 20.86874962], [71.41958618, 20.86874962], [71.41958618, 20.86903], [71.41929626, 20.86903], [71.41929626, 20.86874962], [71.41847229, 20.86874962], [71.41847229, 20.86847115], [71.41791534, 20.86847305], [71.41791534, 20.86819458], [71.41708374, 20.86819458], [71.41708374, 20.86791611], [71.41569519, 20.86791611], [71.41569519, 20.86763954], [71.41401672, 20.86763954], [71.41401672, 20.86736107], [71.41347504, 20.86736107], [71.41347504, 20.8670845], [71.41291809, 20.8670845], [71.41291809, 20.86680603], [71.4118042, 20.86680603], [71.4118042, 20.8670845], [71.41152954, 20.86708069], [71.41152954, 20.86736107], [71.4109726, 20.86736107], [71.4109726, 20.86763954], [71.41069794, 20.86763954], [71.41069794, 20.86791992], [71.41041565, 20.86791611], [71.41041565, 20.86819458], [71.4081955, 20.86819458], [71.4081955, 20.86791611], [71.40625, 20.86791611], [71.40625, 20.86819458], [71.40569305, 20.86819458], [71.40569305, 20.86847305], [71.40458679, 20.86847305], [71.40458679, 20.86819458], [71.4043045, 20.86819458], [71.4043045, 20.86791611], [71.40374756, 20.86791992], [71.40374756, 20.86763954], [71.40319824, 20.86763954], [71.40319061, 20.86736107], [71.4026413, 20.86736107], [71.4026413, 20.86708069], [71.40235901, 20.8670845], [71.40235901, 20.86680603], [71.40180206, 20.86680984], [71.40180206, 20.86652946], [71.40126038, 20.86652946], [71.40126038, 20.8662529], [71.40097046, 20.8662529], [71.40097046, 20.86597061], [71.40041351, 20.86597061], [71.40041351, 20.86569214], [71.40013885, 20.86569214], [71.40013885, 20.86541748], [71.3970871, 20.86541939], [71.3970871, 20.86515045], [71.39597321, 20.86514091], [71.39597321, 20.86569214], [71.39569092, 20.86569023], [71.39569092, 20.8662529], [71.39541626, 20.8662529], [71.39541626, 20.86680984], [71.3951416, 20.86680603], [71.3951416, 20.8670845], [71.39263916, 20.8670845], [71.39263916, 20.86680603], [71.39180756, 20.86680984], [71.39180756, 20.86652946], [71.39068604, 20.86652946], [71.39068604, 20.8662529], [71.38874817, 20.8662529], [71.38874817, 20.86736107], [71.38957977, 20.86736107], [71.38957977, 20.86763954], [71.39013672, 20.86763954], [71.39013672, 20.86819458], [71.39041901, 20.86819077], [71.39041901, 20.86874962], [71.39069366, 20.86874962], [71.39069366, 20.86930466], [71.39097595, 20.86930084], [71.39097595, 20.87014008], [71.39069366, 20.87013817], [71.39069366, 20.87097168], [71.39041901, 20.87096024], [71.39041901, 20.87181091], [71.39013672, 20.87181091], [71.39013672, 20.87236023], [71.38986206, 20.87236023], [71.38986206, 20.87292099], [71.38957977, 20.87291718], [71.38957977, 20.87319374], [71.38930511, 20.87319374], [71.38930511, 20.87347221], [71.38903046, 20.87347031], [71.38903046, 20.87402916], [71.38874817, 20.87402916], [71.38874817, 20.87431908], [71.38819122, 20.87430573], [71.38819122, 20.8745842], [71.38791656, 20.87458038], [71.38791656, 20.87486076], [71.38735962, 20.87486076], [71.38735962, 20.87513924], [71.38707733, 20.87513924], [71.38707733, 20.87542152], [71.38652802, 20.8754158], [71.38652802, 20.87569427], [71.38625336, 20.87569427], [71.38625336, 20.87597275], [71.38513947, 20.87597275], [71.38513947, 20.87569427], [71.38430786, 20.87569427], [71.38430786, 20.8754158], [71.38318634, 20.87542152], [71.38318634, 20.87513924], [71.38208008, 20.87513924], [71.38208008, 20.87486076], [71.38096619, 20.87486076], [71.38096619, 20.87458038], [71.38014221, 20.8745842], [71.38014221, 20.87430573], [71.37902832, 20.87431908], [71.37902832, 20.87402916], [71.3779068, 20.87402916], [71.3779068, 20.87375069], [71.37763977, 20.87375069], [71.37763977, 20.87347031], [71.37735748, 20.87347221], [71.37735748, 20.87291718], [71.37709045, 20.87292099], [71.37709045, 20.87264061], [71.37680817, 20.87264061], [71.37680817, 20.87236023], [71.37652588, 20.87236023], [71.37652588, 20.87207985], [71.37625122, 20.87208366], [71.37625122, 20.87152863], [71.37596893, 20.87153053], [71.37594604, 20.87125015], [71.37568665, 20.87125015], [71.37568665, 20.87070084], [71.37596893, 20.87070084], [71.37596893, 20.87014008], [71.37625122, 20.87014008], [71.37625122, 20.86958122], [71.37652588, 20.86958313], [71.37652588, 20.86902809], [71.37680817, 20.86903], [71.37680817, 20.86847115], [71.37708282, 20.86847305], [71.37708282, 20.86791611], [71.37735748, 20.86791992], [71.37735748, 20.86736107], [71.37763977, 20.86736107], [71.37763977, 20.86708069], [71.37791443, 20.8670845], [71.37791443, 20.86680603], [71.37847137, 20.86680984], [71.37847137, 20.86652946], [71.37902832, 20.86652946], [71.37902832, 20.8662529], [71.37930298, 20.8662529], [71.37930298, 20.86597061], [71.37985992, 20.86597061], [71.37985992, 20.86569214], [71.38014221, 20.86569214], [71.38014221, 20.86541748], [71.38069153, 20.86541939], [71.38069153, 20.86515045], [71.38124847, 20.86515045], [71.38124847, 20.86486244], [71.38153076, 20.86486244], [71.38153076, 20.86431122], [71.38181305, 20.86431122], [71.38181305, 20.86375237], [71.38208008, 20.86375237], [71.38208008, 20.8631897], [71.38236237, 20.86319351], [71.38236237, 20.86291695], [71.38208008, 20.86292076], [71.38208008, 20.86263847], [71.38181305, 20.86263847], [71.38181305, 20.86235809], [71.38153076, 20.86236191], [71.38153076, 20.86097145], [71.38180542, 20.86097145], [71.38180542, 20.85986137], [71.38263702, 20.85986137], [71.38263702, 20.8595829], [71.38375092, 20.8595829], [71.38375092, 20.85986137], [71.38458252, 20.85985947], [71.38458252, 20.86013985], [71.38513947, 20.86013985], [71.38513947, 20.86041832], [71.38597107, 20.86041641], [71.38597107, 20.86069489], [71.38735962, 20.86069489], [71.38735962, 20.86041641], [71.38791656, 20.86041832], [71.38791656, 20.86013985], [71.38735962, 20.86013985], [71.38735962, 20.85985947], [71.38652802, 20.85986137], [71.38652802, 20.8595829], [71.38569641, 20.8595829], [71.38569641, 20.85930634], [71.38513947, 20.85931015], [71.38513947, 20.85902023], [71.38458252, 20.85902786], [71.38458252, 20.85708427], [71.38346863, 20.85708427], [71.38346863, 20.8568058], [71.38236237, 20.85680962], [71.38236237, 20.85653114], [71.38124847, 20.85653114], [71.38124847, 20.85625076], [71.38014221, 20.85625076], [71.38014221, 20.85597229], [71.37902832, 20.85597229], [71.37902832, 20.85569572], [71.37875366, 20.85569572], [71.37875366, 20.85597229], [71.3779068, 20.85596085], [71.3779068, 20.85625076], [71.37625122, 20.85625076], [71.37625122, 20.85596085], [71.37569427, 20.85597229], [71.37569427, 20.85569572], [71.37513733, 20.85569572], [71.37513733, 20.85541725], [71.37486267, 20.85542107], [71.37486267, 20.85514069], [71.37431335, 20.85514069], [71.37431335, 20.85486031], [71.37374878, 20.85486031], [71.37374878, 20.85457993], [71.37347412, 20.85458374], [71.37347412, 20.85430527], [71.37291718, 20.85431099], [71.37291718, 20.85403061], [71.37236023, 20.85403061], [71.37236023, 20.85375023], [71.37208557, 20.85375023], [71.37208557, 20.85347366], [71.36958313, 20.85346985], [71.36958313, 20.85375023], [71.36902618, 20.85375023], [71.36902618, 20.85346985], [71.36846924, 20.85347366], [71.36846924, 20.85319519], [71.36763763, 20.85321045], [71.36763763, 20.85292053], [71.36708069, 20.85292053], [71.36708069, 20.85264015], [71.36680603, 20.85264015], [71.36680603, 20.85235977], [71.36653137, 20.85236359], [71.36653137, 20.8520813], [71.36486053, 20.8520813], [71.36486053, 20.85236359], [71.36235809, 20.85236359], [71.36235809, 20.8520813], [71.36152649, 20.8520813], [71.36152649, 20.85180473], [71.36042023, 20.85180473], [71.36042023, 20.8520813], [71.35986328, 20.8520813], [71.35986328, 20.85180473], [71.35902405, 20.85180473], [71.35902405, 20.85152817], [71.3584671, 20.85153008], [71.3584671, 20.8512516], [71.35791779, 20.8512516], [71.35791779, 20.85096931], [71.35597229, 20.85097122], [71.35597229, 20.85069466], [71.35346985, 20.85069466], [71.35346985, 20.85097122], [71.35319519, 20.85097122], [71.35321045, 20.8512516], [71.35180664, 20.8512516], [71.35180664, 20.85096931], [71.35152435, 20.85097122], [71.35152435, 20.85069466], [71.35124969, 20.85069466], [71.35124969, 20.85041618], [71.35069275, 20.85042191], [71.35069275, 20.85015106], [71.34874725, 20.85015106], [71.34874725, 20.84985924], [71.34792328, 20.84985924], [71.34792328, 20.85015106], [71.3473587, 20.85015106], [71.3473587, 20.85042191], [71.34708405, 20.85041618], [71.34708405, 20.85097122], [71.3465271, 20.85096931], [71.3465271, 20.8512516], [71.34485626, 20.8512516], [71.34485626, 20.85096931], [71.34402466, 20.85097122], [71.34402466, 20.85069466], [71.34347534, 20.85069466], [71.34347534, 20.85041618], [71.34263611, 20.85042191], [71.34263611, 20.85015106], [71.34236145, 20.85015106], [71.34236145, 20.85042191], [71.34179688, 20.85042191], [71.34179688, 20.84985924], [71.34152985, 20.84985924], [71.34152985, 20.84958076], [71.34124756, 20.84958267], [71.34124756, 20.84902763], [71.34098053, 20.84903145], [71.34098053, 20.84874916], [71.34069824, 20.84874916], [71.34069061, 20.84847069], [71.3390274, 20.8484726], [71.3390274, 20.84819412], [71.33875275, 20.84819412], [71.33875275, 20.8484726], [71.33597565, 20.8484726], [71.33597565, 20.84819412], [71.3345871, 20.84819412], [71.3345871, 20.84791756], [71.33374786, 20.84791756], [71.33374786, 20.84763908], [71.33319092, 20.84763908], [71.33319092, 20.84708023], [71.3326416, 20.84708405], [71.3326416, 20.84680557], [71.33207703, 20.84680748], [71.33207703, 20.84653091], [71.33040619, 20.84653091], [71.33040619, 20.84625053], [71.33013916, 20.84625053], [71.33013916, 20.84653091], [71.32736206, 20.84653091], [71.32736206, 20.84625053], [71.32707977, 20.84625053], [71.32707977, 20.84653091], [71.32653046, 20.84653091], [71.32653046, 20.84625053], [71.32597351, 20.84625053], [71.32597351, 20.84597206], [71.32430267, 20.84597015], [71.32430267, 20.84625053], [71.32263947, 20.84625053], [71.32263947, 20.84597015], [71.32208252, 20.84597206], [71.32208252, 20.84569359], [71.32180786, 20.84569359], [71.32180786, 20.84541512], [71.32068634, 20.84542084], [71.32068634, 20.84514046], [71.31958008, 20.84514046], [71.31958008, 20.84486008], [71.31930542, 20.84486198], [71.31930542, 20.84458351], [71.31903076, 20.84458351], [71.31903076, 20.84430695], [71.31874847, 20.84431076], [71.31874847, 20.84402084], [71.31819153, 20.84402847], [71.31819153, 20.84375], [71.31764221, 20.84375], [71.31764221, 20.84346962], [71.31708527, 20.84347153], [71.31708527, 20.84319687], [71.31652832, 20.84320068], [71.31652832, 20.8429203], [71.31597137, 20.8429203], [71.31597137, 20.84263992], [71.3154068, 20.84263992], [71.3154068, 20.84235954], [71.31485748, 20.84236145], [71.31485748, 20.84208488], [71.31402588, 20.84208488], [71.31402588, 20.84180641], [71.31346893, 20.84181023], [71.31346893, 20.84152985], [71.31291962, 20.84152985], [71.31291962, 20.84124947], [71.31208038, 20.84124947], [71.31208038, 20.84098053], [71.31153107, 20.84098053], [71.31153107, 20.84069061], [71.31069183, 20.84069443], [71.31069183, 20.84041405], [71.3095932, 20.84041977], [71.3095932, 20.84013939], [71.30930328, 20.84013939], [71.30930328, 20.83986282], [71.30874634, 20.83986282], [71.30874634, 20.83958054], [71.30847168, 20.83958054], [71.30847168, 20.83930588], [71.3079071, 20.83930969], [71.3079071, 20.83903122], [71.30764008, 20.83903122], [71.30764008, 20.83875275], [71.30708313, 20.83875275], [71.30708313, 20.83847046], [71.30486298, 20.83847046], [71.30486298, 20.83819389], [71.30458069, 20.83819389], [71.30458069, 20.83791733], [71.30403137, 20.83792114], [71.30403137, 20.83764267], [71.3034668, 20.83764267], [71.3034668, 20.83736038], [71.30291748, 20.83736038], [71.30291748, 20.83708191], [71.30263519, 20.83708382], [71.30263519, 20.83680534], [71.30210114, 20.83681107], [71.30210114, 20.83653069], [71.30152893, 20.83653069], [71.30152893, 20.83596992], [71.30124664, 20.83597183], [71.30124664, 20.83541679], [71.30097198, 20.83542061], [71.30097198, 20.83513832], [71.30042267, 20.83513832], [71.30042267, 20.83542061], [71.29624939, 20.83542061], [71.29624939, 20.83513832], [71.2959671, 20.83513832], [71.2959671, 20.83485985], [71.29541779, 20.83486176], [71.29541779, 20.83458328], [71.2951355, 20.83458328], [71.2951355, 20.83430481], [71.29486084, 20.83430481], [71.29486084, 20.83402824], [71.29458618, 20.83402824], [71.29458618, 20.83374977], [71.29402924, 20.83374977], [71.29402924, 20.83346939], [71.29374695, 20.8334713], [71.29374695, 20.83236122], [71.29347229, 20.83236122], [71.29347229, 20.83125114], [71.2929306, 20.83125114], [71.2929306, 20.83097076], [71.29264069, 20.83097267], [71.29264069, 20.8306942], [71.29208374, 20.8306942], [71.29208374, 20.83041763], [71.29180908, 20.83041954], [71.29180908, 20.82875061], [71.29125214, 20.82875061], [71.29125214, 20.82904053], [71.29013824, 20.82904053], [71.29013824, 20.82930946], [71.28874969, 20.82930946], [71.28874969, 20.82904053], [71.28819275, 20.82904053], [71.28819275, 20.82875061], [71.28736115, 20.82875061], [71.28736115, 20.82847023], [71.2868042, 20.82847214], [71.2868042, 20.82819557], [71.28624725, 20.82819557], [71.28624725, 20.8279171], [71.28569794, 20.82792091], [71.28569794, 20.82764053], [71.28457642, 20.82764053], [71.28457642, 20.82736015], [71.2840271, 20.82736206], [71.2840271, 20.82708359], [71.28347015, 20.82708359], [71.28347015, 20.82680321], [71.28263855, 20.82681084], [71.28263855, 20.82653046], [71.2809906, 20.82653046], [71.2809906, 20.82681084], [71.2806778, 20.82681084], [71.2806778, 20.82792091], [71.2804184, 20.8279171], [71.2804184, 20.82819557], [71.28013611, 20.82819557], [71.28013611, 20.8279171], [71.27986145, 20.82792091], [71.27986145, 20.82764053], [71.27958679, 20.82764053], [71.27958679, 20.82736015], [71.2793045, 20.82736206], [71.2793045, 20.82708359], [71.27874756, 20.82708359], [71.27874756, 20.82680321], [71.2784729, 20.82681084], [71.2784729, 20.82653046], [71.27819824, 20.82653046], [71.27819061, 20.82625008], [71.27791595, 20.82625008], [71.27791595, 20.82597351], [71.2776413, 20.82598114], [71.2776413, 20.82570076], [71.27735901, 20.82570076], [71.27735901, 20.82542038], [71.27680206, 20.82542038], [71.27680206, 20.82514191], [71.2765274, 20.82514191], [71.2765274, 20.82485962], [71.27625275, 20.82485962], [71.27625275, 20.82542038], [71.2756958, 20.82542038], [71.2756958, 20.82485962], [71.27541351, 20.82485962], [71.27541351, 20.82458115], [71.2748642, 20.82458115], [71.2748642, 20.82430649], [71.27401733, 20.8243103], [71.27401733, 20.82403183], [71.27375031, 20.82403183], [71.27375031, 20.82374954], [71.27347565, 20.82374954], [71.27347565, 20.82347107], [71.27319336, 20.82347107], [71.27319336, 20.8231945], [71.2729187, 20.8231945], [71.2729187, 20.82291603], [71.27263641, 20.82291603], [71.27263641, 20.82264137], [71.27179718, 20.82264137], [71.27179718, 20.82235909], [71.26819611, 20.82235909], [71.26819611, 20.82208061], [71.26763916, 20.82208252], [71.26763916, 20.82180595], [71.26735687, 20.82180977], [71.26735687, 20.82152748], [71.26680756, 20.82152748], [71.26680756, 20.82125092], [71.26597595, 20.82125092], [71.26597595, 20.82097244], [71.26513672, 20.82097244], [71.26513672, 20.8204174], [71.26431274, 20.82042122], [71.26431274, 20.82014084], [71.26403046, 20.82014084], [71.26403046, 20.81958008], [71.26374817, 20.81958389], [71.26374817, 20.81930542], [71.26346588, 20.81931114], [71.26346588, 20.81903076], [71.26319122, 20.81903076], [71.26319122, 20.81875038], [71.26264191, 20.81875038], [71.26264191, 20.81847], [71.26235962, 20.81847191], [71.26235962, 20.81819534], [71.26207733, 20.81820107], [71.26207733, 20.81792068], [71.26125336, 20.81792068], [71.26125336, 20.8176403], [71.26069641, 20.8176403], [71.26069641, 20.81735992], [71.26013947, 20.81736183], [71.26013947, 20.81708336], [71.25986481, 20.81708336], [71.25986481, 20.81680679], [71.25958252, 20.81680679], [71.25958252, 20.81652832], [71.25875092, 20.81653023], [71.25875092, 20.81624985], [71.25846863, 20.81624985], [71.25846863, 20.81596947], [71.25791931, 20.81597137], [71.25791931, 20.81569481], [71.25708008, 20.81569481], [71.25708008, 20.81541634], [71.25624847, 20.81542015], [71.25624847, 20.81513977], [71.25347137, 20.81513977], [71.25347137, 20.81485939], [71.25291443, 20.8148613], [71.25291443, 20.81458473], [71.25235748, 20.81458473], [71.25235748, 20.81430626], [71.25180817, 20.81431007], [71.25180817, 20.81404114], [71.25108337, 20.81402969], [71.25096893, 20.81404114], [71.25096893, 20.81392097], [71.25096893, 20.81374931], [71.2507782, 20.81374931], [71.25041962, 20.81375122], [71.25041962, 20.81347275], [71.24903107, 20.81347466], [71.24903107, 20.81319427], [71.24819183, 20.81319427], [71.24819183, 20.8129158], [71.2470932, 20.81291962], [71.2470932, 20.81264114], [71.24680328, 20.81264114], [71.24680328, 20.81180954], [71.24597168, 20.81180954], [71.24597168, 20.81153107], [71.24485779, 20.81153107], [71.24485779, 20.81180954], [71.24430847, 20.81180954], [71.24430847, 20.81236267], [71.24263763, 20.81236267], [71.24263763, 20.81208038], [71.24124908, 20.8120842], [71.24124908, 20.81180573], [71.24014282, 20.81180954], [71.24014282, 20.81153107], [71.2387619, 20.81153107], [71.2387619, 20.81069183], [71.23847198, 20.81069374], [71.23847198, 20.81041718], [71.23819733, 20.8104229], [71.23819733, 20.81014252], [71.23792267, 20.81014252], [71.23792267, 20.80957985], [71.23764038, 20.80958366], [71.23764038, 20.80930519], [71.23735809, 20.80931091], [71.23735809, 20.80903053], [71.23707581, 20.80903053], [71.23707581, 20.80846977], [71.23680878, 20.80847168], [71.23680878, 20.80819511], [71.23652649, 20.80820084], [71.23652649, 20.80791092], [71.23625183, 20.80791664], [71.23625183, 20.8073616], [71.23596954, 20.8073616], [71.23596954, 20.80708313], [71.23569489, 20.80708313], [71.23569489, 20.80680466], [71.23542023, 20.80680466], [71.23542023, 20.80652618], [71.23513794, 20.80652809], [71.23513794, 20.80624962], [71.23486328, 20.80624962], [71.23486328, 20.80597115], [71.23458099, 20.80597305], [71.23458099, 20.80569458], [71.23430634, 20.80569458], [71.23430634, 20.80541611], [71.23374939, 20.80541992], [71.23374939, 20.80513954], [71.2334671, 20.80513954], [71.2334671, 20.80484962], [71.2326355, 20.80486107], [71.2326355, 20.80402756], [71.23236084, 20.80402946], [71.23236084, 20.80430984], [71.23152924, 20.80430794], [71.23152924, 20.8045826], [71.23041534, 20.8045826], [71.23041534, 20.80430794], [71.22959137, 20.80430984], [71.22959137, 20.80402946], [71.22875214, 20.80402946], [71.22875214, 20.80375099], [71.22846985, 20.80375099], [71.22846985, 20.80347061], [71.22569275, 20.80347061], [71.22569275, 20.80375099], [71.21985626, 20.80375099], [71.21985626, 20.80347061], [71.21847534, 20.80347252], [71.21847534, 20.80319595], [71.21708679, 20.80319595], [71.21708679, 20.80291748], [71.21569824, 20.80291939], [71.21569061, 20.80264091], [71.21069336, 20.80264091], [71.21069336, 20.80236053], [71.20986176, 20.80236053], [71.20986176, 20.80208015], [71.20903015, 20.80208588], [71.20903015, 20.80125046], [71.20874786, 20.80125046], [71.20874786, 20.80070114], [71.20845795, 20.8006897], [71.20847321, 20.80041695], [71.20791626, 20.80042076], [71.20791626, 20.80014038], [71.2076416, 20.80014038], [71.2076416, 20.79986191], [71.20708466, 20.79986382], [71.20708466, 20.7990284], [71.20680237, 20.7990303], [71.20680237, 20.79875183], [71.20625305, 20.79875183], [71.20625305, 20.79818916], [71.20541382, 20.79819489], [71.20541382, 20.79791641], [71.20513916, 20.79792023], [71.20513916, 20.79735947], [71.2048645, 20.79735947], [71.2048645, 20.7970829], [71.20513916, 20.7970829], [71.20513916, 20.79624939], [71.20542145, 20.79624939], [71.20541382, 20.79569435], [71.20513916, 20.79569435], [71.20513916, 20.79486084], [71.20485687, 20.79486084], [71.20485687, 20.79430962], [71.2076416, 20.79430962], [71.2076416, 20.79403114], [71.20735931, 20.79403114], [71.20735931, 20.79374123], [71.20735931, 20.79347229], [71.20680237, 20.79347229], [71.20680237, 20.79319382], [71.20625305, 20.79319382], [71.20625305, 20.79291725], [71.20569611, 20.79291725], [71.20569611, 20.79263878], [71.20542145, 20.79264069], [71.20542145, 20.79236031], [71.20485687, 20.79236031], [71.20485687, 20.79207993], [71.20458221, 20.79208374], [71.20458221, 20.79180527], [71.20430756, 20.79181099], [71.20430756, 20.79153061], [71.20375061, 20.79153061], [71.20375061, 20.79125023], [71.20347595, 20.79125023], [71.20347595, 20.79096985], [71.20319366, 20.79097176], [71.20319366, 20.79041672], [71.20291901, 20.79042053], [71.20291901, 20.79014015], [71.20375061, 20.79014015], [71.20375061, 20.78930092], [71.20319366, 20.78930473], [71.20319366, 20.78902817], [71.20265198, 20.78903008], [71.20265198, 20.78874969], [71.20207977, 20.78874969], [71.20207977, 20.78847122], [71.19958496, 20.78847313], [71.19958496, 20.78819466], [71.19791412, 20.78819466], [71.19791412, 20.78791618], [71.19763947, 20.78792], [71.19763947, 20.78763962], [71.19735718, 20.78763962], [71.19735718, 20.78736115], [71.19680786, 20.78736115], [71.19680786, 20.78708076], [71.19652557, 20.78708458], [71.19652557, 20.78680611], [71.19541931, 20.78680992], [71.19541931, 20.78652954], [71.19431305, 20.78652954], [71.19431305, 20.78625107], [71.19319153, 20.78625107], [71.19319153, 20.7859726], [71.18958282, 20.7859726], [71.18958282, 20.78569221], [71.18930817, 20.78569221], [71.18930817, 20.78541756], [71.18681335, 20.78541946], [71.18681335, 20.7851429], [71.18428802, 20.7851429], [71.18428802, 20.78486252], [71.18319702, 20.78486252], [71.18319702, 20.78458023], [71.18180847, 20.78458405], [71.18180847, 20.78430557], [71.18068695, 20.78430939], [71.18068695, 20.78403282], [71.17930603, 20.78403282], [71.17930603, 20.78373909], [71.17736053, 20.78375244], [71.17736053, 20.78347015], [71.17569733, 20.78347015], [71.17569733, 20.78319359], [71.17375183, 20.78319359], [71.17375183, 20.78291702], [71.17180634, 20.78292084], [71.17180634, 20.78263855], [71.17041779, 20.78263855], [71.17041779, 20.78235817], [71.16928864, 20.78235817], [71.16928864, 20.78263855], [71.16764069, 20.78263855], [71.16764069, 20.78235817], [71.16596985, 20.78236008], [71.16596985, 20.78208351], [71.16430664, 20.78208351], [71.16430664, 20.78180504], [71.16346741, 20.78181076], [71.16346741, 20.78152847], [71.16319275, 20.78152847], [71.16319275, 20.78124809], [71.16236115, 20.78124809], [71.16236115, 20.78096962], [71.1609726, 20.78097153], [71.1609726, 20.78069496], [71.16040802, 20.78070068], [71.16040802, 20.7804203], [71.16014099, 20.78038025], [71.16014099, 20.78013611], [71.1598587, 20.78013992], [71.1598587, 20.77985954], [71.15847015, 20.77986145], [71.15847015, 20.77958298], [71.15791321, 20.77958298], [71.15791321, 20.77930641], [71.15734863, 20.77931023], [71.15734863, 20.77902985], [71.15680695, 20.77902985], [71.15680695, 20.77874947], [71.15625, 20.77874947], [71.15625, 20.77847099], [71.15569305, 20.7784729], [71.15569305, 20.77791786], [71.1554184, 20.77793121], [71.1554184, 20.77763939], [71.15513611, 20.77763939], [71.15513611, 20.77708054], [71.15486145, 20.77708244], [71.15486145, 20.77680588], [71.15431213, 20.77680969], [71.15431213, 20.77653122], [71.15402985, 20.77653122], [71.15402985, 20.77625084], [71.1534729, 20.77625084], [71.1534729, 20.77597046], [71.15291595, 20.77597237], [71.15291595, 20.7756958], [71.1526413, 20.7756958], [71.1526413, 20.77513885], [71.15235901, 20.77514076], [71.15235901, 20.77458], [71.15208435, 20.77458572], [71.15208435, 20.77430534], [71.15180206, 20.77431107], [71.15180206, 20.77375031], [71.1515274, 20.77375031], [71.1515274, 20.7732029], [71.15125275, 20.7732029], [71.15125275, 20.77292061], [71.15097046, 20.77292061], [71.15097046, 20.77236176], [71.1506958, 20.77236366], [71.1506958, 20.77222061], [71.1506958, 20.77180481], [71.15041351, 20.77180481], [71.15041351, 20.77096939], [71.15013885, 20.77096939], [71.15013885, 20.76847267], [71.1498642, 20.76847267], [71.1498642, 20.76736069], [71.14958191, 20.76736069], [71.14958191, 20.76708031], [71.14930725, 20.76708412], [71.14930725, 20.76680565], [71.14903259, 20.76680946], [71.14903259, 20.76652908], [71.14875031, 20.76652908], [71.14875031, 20.76625061], [71.14846802, 20.76625061], [71.14846802, 20.76569939], [71.1481781, 20.76569939], [71.1481781, 20.76514053], [71.14846802, 20.76514053], [71.14846802, 20.76457977], [71.14875031, 20.76458359], [71.14875031, 20.76402855], [71.14903259, 20.76403046], [71.14903259, 20.7634697], [71.14930725, 20.7634716], [71.14930725, 20.76319695], [71.14985657, 20.76320076], [71.14985657, 20.76292992], [71.15039063, 20.76292992], [71.15040588, 20.76264], [71.15097046, 20.76264], [71.15097046, 20.76235962], [71.1515274, 20.76236153], [71.1515274, 20.76208305], [71.15208435, 20.76208305], [71.15208435, 20.76180649], [71.15402985, 20.76180649], [71.15402985, 20.76208305], [71.1554184, 20.76208305], [71.1554184, 20.76236153], [71.15680695, 20.76236153], [71.15680695, 20.76124954], [71.15651703, 20.76124954], [71.15651703, 20.76041985], [71.15625, 20.76041985], [71.15625, 20.76013947], [71.15569305, 20.76013947], [71.15569305, 20.7598629], [71.1554184, 20.7598629], [71.1554184, 20.75956917], [71.15486145, 20.75958061], [71.15486145, 20.75930595], [71.15291595, 20.75930977], [71.15291595, 20.75902939], [71.15207672, 20.75902939], [71.15207672, 20.75875282], [71.15125275, 20.75875282], [71.15125275, 20.75854111], [71.15074158, 20.75849915], [71.15041351, 20.75847054], [71.15041351, 20.75819206], [71.1498642, 20.75819206], [71.1498642, 20.7579174], [71.14958191, 20.75792122], [71.14958191, 20.75764275], [71.14903259, 20.75764275], [71.14903259, 20.75736237], [71.14763641, 20.75736237], [71.14763641, 20.75764275], [71.14679718, 20.75764275], [71.14679718, 20.75736237], [71.14597321, 20.75736237], [71.14597321, 20.75708008], [71.14457703, 20.75708008], [71.14457703, 20.75736237], [71.14263916, 20.75736237], [71.14263916, 20.75708008], [71.14069366, 20.75708389], [71.14069366, 20.75680542], [71.13791656, 20.75680542], [71.13791656, 20.75652695], [71.13291931, 20.75652695], [71.13291931, 20.75680542], [71.13124847, 20.75680542], [71.13124847, 20.75708389], [71.13041687, 20.75708389], [71.13043213, 20.75736237], [71.1279068, 20.75736237], [71.1279068, 20.75708008], [71.12763977, 20.75708389], [71.12763977, 20.75680542], [71.12735748, 20.75680542], [71.12735748, 20.75652695], [71.12708282, 20.75653076], [71.12708282, 20.75624847], [71.12680817, 20.75624847], [71.12680817, 20.75596809], [71.12652588, 20.75597191], [71.12652588, 20.75569534], [71.12596893, 20.75569916], [71.12596893, 20.75542068], [71.12568665, 20.75542068], [71.12568665, 20.7551384], [71.12541962, 20.7551384], [71.12541962, 20.75485992], [71.12513733, 20.75486183], [71.12513733, 20.75458336], [71.12486267, 20.75458336], [71.12486267, 20.75430489], [71.12347412, 20.75430489], [71.12347412, 20.75402832], [71.12014008, 20.75402832], [71.12014008, 20.75430489], [71.11958313, 20.75430489], [71.11958313, 20.75458336], [71.11930847, 20.75458336], [71.11930847, 20.75486183], [71.11875153, 20.75485992], [71.11875153, 20.75542068], [71.11846924, 20.75541687], [71.11846924, 20.75597191], [71.11820221, 20.75596809], [71.11820221, 20.75653076], [71.11846924, 20.75652695], [71.11846924, 20.75680542], [71.11875153, 20.75680542], [71.11875153, 20.75708389], [71.11902618, 20.75708008], [71.11902618, 20.75736237], [71.11930847, 20.75736237], [71.11930847, 20.75764275], [71.11680603, 20.75764275], [71.11680603, 20.75792122], [71.11667633, 20.7579174], [71.1159668, 20.75792122], [71.1159668, 20.75875282], [71.11624908, 20.75875282], [71.11624908, 20.75930977], [71.11680603, 20.75930595], [71.11680603, 20.75958061], [71.11708069, 20.75956917], [71.11708069, 20.7598629], [71.11653137, 20.7598629], [71.11653137, 20.76013947], [71.1159668, 20.76013947], [71.1159668, 20.76041985], [71.11541748, 20.76041603], [71.11541748, 20.7606945], [71.11180878, 20.7606945], [71.11180878, 20.76041603], [71.11125183, 20.76041985], [71.11125183, 20.76013947], [71.11068726, 20.76013947], [71.11068726, 20.7598629], [71.11013794, 20.7598629], [71.11013794, 20.75956917], [71.10958099, 20.75958061], [71.10958099, 20.75930595], [71.10900879, 20.75930977], [71.10900879, 20.75902939], [71.10819244, 20.75902939], [71.10819244, 20.75875282], [71.10541534, 20.75875282], [71.10541534, 20.75847054], [71.1048584, 20.75847054], [71.1048584, 20.75819206], [71.10458374, 20.75819206], [71.10458374, 20.7579174], [71.10402679, 20.75792122], [71.10402679, 20.75764275], [71.10346985, 20.75764275], [71.10346985, 20.75736237], [71.09874725, 20.75736237], [71.09874725, 20.75764275], [71.09902954, 20.75764084], [71.09902954, 20.75819206], [71.09430695, 20.75819206], [71.09430695, 20.7579174], [71.0929184, 20.75792122], [71.0929184, 20.75764275], [71.09126282, 20.75764275], [71.09126282, 20.75736237], [71.08985901, 20.75736237], [71.08985901, 20.75708008], [71.0890274, 20.75708389], [71.0890274, 20.75680542], [71.08791351, 20.75680542], [71.08791351, 20.75652695], [71.08708191, 20.75653076], [71.08708191, 20.75624847], [71.08597565, 20.75624847], [71.08597565, 20.75597191], [71.08569336, 20.75597191], [71.08569336, 20.75569534], [71.08512878, 20.75569916], [71.08512878, 20.75542068], [71.08486176, 20.75542068], [71.08486176, 20.7551384], [71.08429718, 20.7551384], [71.08429718, 20.75485992], [71.08403015, 20.75486183], [71.08403015, 20.75458336], [71.08347321, 20.75458336], [71.08347321, 20.75430489], [71.08319092, 20.75430489], [71.08319092, 20.75402832], [71.0826416, 20.75402832], [71.0826416, 20.75375938], [71.08235931, 20.75375938], [71.08235931, 20.75346947], [71.08180237, 20.75347137], [71.08180237, 20.75319481], [71.08152771, 20.75319481], [71.08152771, 20.75291634], [71.08125305, 20.75291824], [71.08125305, 20.75263977], [71.08069611, 20.75263977], [71.08069611, 20.75235939], [71.08041382, 20.7523613], [71.08041382, 20.75208282], [71.08013916, 20.75208282], [71.08013916, 20.75180626], [71.07985687, 20.75181007], [71.07985687, 20.75152969], [71.07932281, 20.75152969], [71.07932281, 20.75125122], [71.0790329, 20.75125122], [71.0790329, 20.75097084], [71.07875061, 20.75097275], [71.07875061, 20.75069427], [71.07847595, 20.7507], [71.07847595, 20.75041962], [71.07791901, 20.75041962], [71.07791901, 20.75014114], [71.07763672, 20.75014114], [71.07763672, 20.74903107], [71.07736206, 20.74903107], [71.07736206, 20.74818993], [71.07707977, 20.74819565], [71.07707977, 20.7476387], [71.07680511, 20.7476387], [71.07680511, 20.74736023], [71.07653046, 20.74736023], [71.07653046, 20.74707985], [71.07624817, 20.74708366], [71.07624817, 20.74652863], [71.07596588, 20.74653053], [71.07596588, 20.74625015], [71.07569122, 20.74625015], [71.07569122, 20.74596977], [71.07541656, 20.74597359], [71.07541656, 20.74541664], [71.07514191, 20.74542046], [71.07514191, 20.74514008], [71.07569122, 20.74514008], [71.07569122, 20.7448597], [71.07597351, 20.74486351], [71.07597351, 20.74458122], [71.07653046, 20.74458122], [71.07653046, 20.74430466], [71.07680511, 20.74430466], [71.07680511, 20.74402809], [71.07736206, 20.74403191], [71.07736206, 20.74375153], [71.07818604, 20.74375153], [71.07818604, 20.74292183], [71.07847595, 20.74292183], [71.07847595, 20.74235916], [71.07875061, 20.74235916], [71.07875061, 20.74208069], [71.07902527, 20.7420826], [71.07902527, 20.74152756], [71.07932281, 20.74152756], [71.07932281, 20.74124908], [71.07958221, 20.74124908], [71.07958221, 20.74069023], [71.0798645, 20.74069405], [71.0798645, 20.74041748], [71.08013916, 20.74041748], [71.08013916, 20.74014091], [71.08040619, 20.74014091], [71.08040619, 20.73958015], [71.08069611, 20.73958397], [71.08069611, 20.7393055], [71.08097076, 20.73931122], [71.08097076, 20.73875809], [71.08152771, 20.73875809], [71.08152771, 20.73847008], [71.08097076, 20.73847198], [71.08097076, 20.73819542], [71.08040619, 20.7381897], [71.08041382, 20.73791695], [71.07985687, 20.73792076], [71.07985687, 20.73764038], [71.07932281, 20.73764038], [71.07932281, 20.73736], [71.07875061, 20.73736191], [71.07875061, 20.73708344], [71.07819366, 20.73708344], [71.07819366, 20.73680687], [71.07763672, 20.73681068], [71.07763672, 20.7365303], [71.07569122, 20.7365303], [71.07569122, 20.73624992], [71.07514191, 20.73624992], [71.07514191, 20.73596954], [71.07430267, 20.73597145], [71.07430267, 20.73569489], [71.07375336, 20.73569489], [71.07375336, 20.73541641], [71.07068634, 20.73542023], [71.07068634, 20.73513985], [71.06958008, 20.73513985], [71.06958008, 20.73485947], [71.0670929, 20.73485947], [71.0670929, 20.73513985], [71.06652832, 20.73513985], [71.06652832, 20.73485947], [71.06625366, 20.73486137], [71.06625366, 20.73458481], [71.06597137, 20.73458481], [71.06597137, 20.73430634], [71.06569672, 20.73431015], [71.06569672, 20.73402977], [71.0654068, 20.73402977], [71.0654068, 20.73374939], [71.06291962, 20.73374939], [71.06291962, 20.73569489], [71.06236267, 20.73569489], [71.06236267, 20.73597145], [71.06208038, 20.73596954], [71.06208038, 20.73624992], [71.06069183, 20.73624992], [71.06069183, 20.73596954], [71.06041718, 20.73597145], [71.06041718, 20.73569489], [71.06014252, 20.73569489], [71.06014252, 20.73541641], [71.05902863, 20.73542023], [71.05902863, 20.73513985], [71.05789948, 20.73513985], [71.05789948, 20.73485947], [71.05735779, 20.73486137], [71.05735779, 20.73458481], [71.05652618, 20.73458481], [71.05652618, 20.73430634], [71.05596924, 20.73431015], [71.05596924, 20.73402977], [71.05541992, 20.73402977], [71.05541992, 20.73374939], [71.05513763, 20.73374939], [71.05513763, 20.73347473], [71.05486298, 20.73347473], [71.05486298, 20.73319435], [71.05430603, 20.73319435], [71.05430603, 20.73291588], [71.0534668, 20.73291969], [71.0534668, 20.73263168], [71.05291748, 20.73263931], [71.05291748, 20.73236275], [71.05236053, 20.73236275], [71.05236053, 20.73208046], [71.05180359, 20.73208427], [71.05180359, 20.7318058], [71.05124664, 20.73180962], [71.05124664, 20.73153114], [71.05097198, 20.73153114], [71.05097198, 20.73125267], [71.05041504, 20.73125267], [71.05041504, 20.73097038], [71.04569244, 20.73097038], [71.04569244, 20.73153114], [71.04541779, 20.73152733], [71.04541779, 20.73208427], [71.0451355, 20.73208427], [71.04514313, 20.73236275], [71.04486084, 20.73236275], [71.04486084, 20.73263931], [71.04514313, 20.73263168], [71.04514313, 20.73291969], [71.04486084, 20.73291588], [71.04486084, 20.73347473], [71.04458618, 20.73347282], [71.04458618, 20.73374939], [71.04429626, 20.73374939], [71.04429626, 20.73402977], [71.04402924, 20.73402977], [71.04402924, 20.73431015], [71.04374695, 20.73430634], [71.04374695, 20.73486137], [71.04347229, 20.73485947], [71.04347229, 20.73513794], [71.04292297, 20.73513985], [71.04292297, 20.73542023], [71.0423584, 20.73541641], [71.0423584, 20.73569489], [71.04125214, 20.73569489], [71.04125214, 20.73597145], [71.04096985, 20.73596954], [71.04096985, 20.73624992], [71.0404129, 20.73624992], [71.0404129, 20.7365303], [71.04013824, 20.7365303], [71.04013824, 20.73681068], [71.0395813, 20.73680687], [71.0395813, 20.73708344], [71.03930664, 20.73708344], [71.03930664, 20.73736191], [71.03874969, 20.73736], [71.03874969, 20.73764038], [71.03848267, 20.73764038], [71.03848267, 20.73792076], [71.03791809, 20.73791695], [71.03791809, 20.7381897], [71.0376358, 20.73819542], [71.0376358, 20.73847198], [71.03624725, 20.73847008], [71.03624725, 20.73875809], [71.03542328, 20.73875809], [71.03542328, 20.73903084], [71.0348587, 20.73903084], [71.0348587, 20.73931122], [71.03236389, 20.7393055], [71.03236389, 20.73958397], [71.03152466, 20.73958397], [71.03152466, 20.7393055], [71.03013611, 20.73931122], [71.03013611, 20.73903084], [71.02902985, 20.73903084], [71.02902985, 20.73875809], [71.02884674, 20.73875809], [71.0276413, 20.73875809], [71.0276413, 20.73903084], [71.02484894, 20.73903084], [71.02484894, 20.73875809], [71.02353668, 20.73875427], [71.02263641, 20.73875809], [71.02263641, 20.73847008], [71.02153015, 20.73847198], [71.02153015, 20.73819542], [71.02041626, 20.73819542], [71.02041626, 20.73847198], [71.01957703, 20.73847008], [71.01957703, 20.73875809], [71.01904297, 20.73875809], [71.01904297, 20.73903084], [71.01819611, 20.73903084], [71.01819611, 20.73931122], [71.01763916, 20.7393055], [71.01763916, 20.73958397], [71.01680756, 20.73958015], [71.01680756, 20.73986053], [71.0151062, 20.73986053], [71.01457977, 20.73986053], [71.01457977, 20.73958015], [71.01319122, 20.73958015], [71.01319122, 20.73986053], [71.01097107, 20.73986053], [71.01097107, 20.73958015], [71.01069641, 20.73958397], [71.01069641, 20.7393055], [71.0090332, 20.73931122], [71.0090332, 20.73875809], [71.00791931, 20.73875809], [71.00791931, 20.73847008], [71.00680542, 20.73847198], [71.00680542, 20.73791695], [71.00653076, 20.73792076], [71.00653076, 20.73764038], [71.00569153, 20.73764038], [71.00569153, 20.73736], [71.00485992, 20.73736191], [71.00485992, 20.73708344], [71.00402832, 20.73708344], [71.00402832, 20.73680687], [71.00319672, 20.73681068], [71.00319672, 20.7365303], [71.00263977, 20.7365303], [71.00263977, 20.73624992], [71.00235748, 20.73624992], [71.00235748, 20.73596954], [71.00180817, 20.73597145], [71.00180817, 20.73569489], [71.00152588, 20.73569489], [71.00152588, 20.73541641], [71.00096893, 20.73542023], [71.00096893, 20.73513985], [70.99986267, 20.73513985], [70.99931335, 20.73513985], [70.99931335, 20.73485947], [70.99874878, 20.73486137], [70.99874878, 20.73458481], [70.99847412, 20.73458481], [70.99847412, 20.73430634], [70.99819183, 20.73431015], [70.99819183, 20.73402977], [70.99764252, 20.73402977], [70.99764252, 20.73374939], [70.99736023, 20.73374939], [70.99736023, 20.73347282], [70.99708557, 20.73347473], [70.99708557, 20.73319435], [70.99652863, 20.73319435], [70.99652863, 20.73291588], [70.99597168, 20.73291969], [70.99597168, 20.73263168], [70.99514008, 20.73263931], [70.99514008, 20.73236275], [70.99402618, 20.73236275], [70.99402618, 20.73180962], [70.99375153, 20.73180962], [70.99375153, 20.73125267], [70.99346924, 20.73125267], [70.99346924, 20.73097038], [70.99291992, 20.73097038], [70.99291992, 20.73069382], [70.99263763, 20.73069382], [70.99263763, 20.73014069], [70.99236298, 20.73014259], [70.99236298, 20.72958946], [70.99208069, 20.72958946], [70.99208069, 20.72930908], [70.99153137, 20.72930908], [70.99153137, 20.72874832], [70.99124908, 20.72874832], [70.99124908, 20.72820091], [70.9909668, 20.72820091], [70.9909668, 20.72735977], [70.99069214, 20.72736168], [70.99069214, 20.72597313], [70.99041748, 20.72597313], [70.99041748, 20.72569466], [70.99013519, 20.72569466], [70.99013519, 20.72513962], [70.98986053, 20.72513962], [70.98986053, 20.72458076], [70.98958588, 20.72458267], [70.98958588, 20.72402763], [70.98929596, 20.72402954], [70.98929596, 20.72347069], [70.98902893, 20.7234726], [70.98902893, 20.72319412], [70.98847198, 20.72319412], [70.98847198, 20.72291756], [70.98819733, 20.72291946], [70.98819733, 20.72264099], [70.98792267, 20.72264099], [70.98792267, 20.72236061], [70.98764038, 20.72236061], [70.98764038, 20.72208023], [70.98680878, 20.72208023], [70.98680878, 20.72236061], [70.98652649, 20.72236061], [70.98652649, 20.72264099], [70.98625183, 20.72264099], [70.98625183, 20.72402954], [70.98596954, 20.72402954], [70.98596954, 20.72430992], [70.98569489, 20.72430611], [70.98569489, 20.72458267], [70.98542023, 20.72458076], [70.98542023, 20.72486115], [70.98486328, 20.72486115], [70.98486328, 20.72513962], [70.98458099, 20.72513962], [70.98458099, 20.72541809], [70.98402405, 20.72541618], [70.98402405, 20.72569466], [70.98374939, 20.72569084], [70.98374939, 20.72624969], [70.98430634, 20.72624969], [70.98430634, 20.72652817], [70.98486328, 20.72652626], [70.98486328, 20.72680473], [70.98513794, 20.72680473], [70.98513794, 20.72708321], [70.98569489, 20.72708321], [70.98569489, 20.72736168], [70.98596954, 20.72735977], [70.98596954, 20.72763824], [70.98625183, 20.72763824], [70.98625183, 20.72792053], [70.98652649, 20.72792053], [70.98652649, 20.72820091], [70.98680878, 20.72820091], [70.98680878, 20.72874832], [70.98707581, 20.72874832], [70.98707581, 20.72958946], [70.98735809, 20.72958374], [70.98735809, 20.73097038], [70.98791504, 20.73097038], [70.98791504, 20.73069382], [70.98819733, 20.73069382], [70.98819733, 20.73041725], [70.98847198, 20.73042107], [70.98847198, 20.73014259], [70.98986053, 20.73014259], [70.98986053, 20.73042107], [70.99013519, 20.73041725], [70.99013519, 20.73069382], [70.99041748, 20.73069191], [70.99041748, 20.73125267], [70.99097443, 20.73125267], [70.99097443, 20.73137856], [70.9909668, 20.73153114], [70.99124908, 20.73153114], [70.99124908, 20.73180962], [70.99153137, 20.73180962], [70.99153137, 20.73236275], [70.99180603, 20.73236275], [70.99180603, 20.73402977], [70.99208069, 20.73402977], [70.99208069, 20.73431015], [70.99236298, 20.73430634], [70.99236298, 20.73458481], [70.99263763, 20.73458481], [70.99263763, 20.73486137], [70.99318695, 20.73485947], [70.99318695, 20.73513985], [70.99346924, 20.73513794], [70.99346924, 20.73569489], [70.99402618, 20.73569489], [70.99402618, 20.73597145], [70.99430847, 20.73596954], [70.99430847, 20.73624992], [70.99458313, 20.73624992], [70.99458313, 20.73681068], [70.99485779, 20.73680687], [70.99485779, 20.73708344], [70.99514008, 20.73707962], [70.99514008, 20.73764038], [70.9954071, 20.73764038], [70.9954071, 20.73792076], [70.99597168, 20.73791695], [70.99597168, 20.73819351], [70.99624634, 20.7381897], [70.99624634, 20.73875809], [70.99680328, 20.73875809], [70.99680328, 20.73903084], [70.9970932, 20.73903084], [70.9970932, 20.73931122], [70.99736023, 20.73931122], [70.99736023, 20.73986053], [70.99764252, 20.73986053], [70.99764252, 20.74041748], [70.99819183, 20.74041748], [70.99819183, 20.74064255], [70.99819183, 20.74152756], [70.99847412, 20.74152756], [70.99847412, 20.7420826], [70.99874878, 20.74208069], [70.99874878, 20.74235916], [70.99903107, 20.74235916], [70.99903107, 20.74264145], [70.99874878, 20.74264145], [70.99874878, 20.74292183], [70.99819183, 20.74292183], [70.99819183, 20.74264145], [70.99569702, 20.74264145], [70.99569702, 20.74235916], [70.99430847, 20.74235916], [70.99430847, 20.74264145], [70.99402618, 20.74264145], [70.99402618, 20.74292183], [70.99375153, 20.74292183], [70.99375153, 20.74375153], [70.99346924, 20.74375153], [70.99346924, 20.74430466], [70.99319458, 20.74430466], [70.99319458, 20.74458122], [70.99291992, 20.74458122], [70.99291992, 20.74486351], [70.99263763, 20.7448597], [70.99263763, 20.74514008], [70.99236298, 20.74514008], [70.99236298, 20.74542046], [70.99180603, 20.74542046], [70.99180603, 20.74570084], [70.99124908, 20.74569511], [70.99124908, 20.74597359], [70.99013519, 20.74597359], [70.99013519, 20.74569511], [70.98958588, 20.74570084], [70.98958588, 20.74542046], [70.98847198, 20.74542046], [70.98847198, 20.74570084], [70.98735809, 20.74570084], [70.98735809, 20.74542046], [70.98680878, 20.74542046], [70.98680878, 20.74514008], [70.98625183, 20.74514008], [70.98625183, 20.7448597], [70.98596954, 20.74486351], [70.98596954, 20.74458122], [70.98542023, 20.74458122], [70.98542023, 20.74430466], [70.98486328, 20.74430466], [70.98486328, 20.74402809], [70.98402405, 20.74402809], [70.98402405, 20.74430466], [70.98374939, 20.74430466], [70.98374939, 20.74486351], [70.9826355, 20.74486351], [70.9826355, 20.74458122], [70.98236084, 20.74458122], [70.98236084, 20.74430466], [70.98208618, 20.74430466], [70.98208618, 20.74402809], [70.98179626, 20.74403191], [70.98179626, 20.74375153], [70.98069763, 20.74375153], [70.98069763, 20.74346924], [70.98014069, 20.74347115], [70.98014069, 20.74319458], [70.9798584, 20.74319458], [70.9798584, 20.74291611], [70.97930908, 20.74292183], [70.97930908, 20.74264145], [70.97902679, 20.74264145], [70.97902679, 20.74235916], [70.97846985, 20.74235916], [70.97846985, 20.74208069], [70.9779129, 20.7420826], [70.9779129, 20.74180603], [70.97763824, 20.74181938], [70.97763824, 20.74152756], [70.97735596, 20.74152756], [70.97735596, 20.74124908], [70.97624969, 20.74124908], [70.97624969, 20.74097061], [70.97569275, 20.74097252], [70.97569275, 20.74069405], [70.97541809, 20.74069405], [70.97541809, 20.74041748], [70.9751358, 20.74041748], [70.9751358, 20.74014091], [70.97486115, 20.74014091], [70.97486115, 20.73986053], [70.97429657, 20.73986053], [70.97429657, 20.74014091], [70.97373962, 20.74014091], [70.97373962, 20.73986053], [70.97319794, 20.73986053], [70.97319794, 20.73958015], [70.9723587, 20.73958397], [70.9723587, 20.7393055], [70.97207642, 20.73931122], [70.97207642, 20.73903084], [70.97180176, 20.73903084], [70.97180176, 20.73875809], [70.9715271, 20.73875809], [70.9715271, 20.73847008], [70.9695816, 20.73847008], [70.9695816, 20.73875809], [70.96930695, 20.73875809], [70.96930695, 20.73931122], [70.96902466, 20.7393055], [70.96902466, 20.73958397], [70.96875, 20.73958015], [70.96875, 20.73986053], [70.96848297, 20.73986053], [70.96848297, 20.74014091], [70.96652985, 20.7401371], [70.96652985, 20.74069405], [70.96624756, 20.74069023], [70.96624756, 20.74124908], [70.9659729, 20.74124908], [70.9659729, 20.74152756], [70.96569824, 20.74152756], [70.96569824, 20.74181938], [70.96523285, 20.74181175], [70.96457672, 20.74181938], [70.96457672, 20.74152756], [70.9640274, 20.74152756], [70.9640274, 20.74181938], [70.9631958, 20.74181938], [70.9631958, 20.74152756], [70.96235657, 20.74152756], [70.96235657, 20.74124908], [70.96153259, 20.74124908], [70.96153259, 20.74097061], [70.96097565, 20.74097252], [70.96097565, 20.74069405], [70.96069336, 20.74069405], [70.96069336, 20.74041748], [70.9604187, 20.74041748], [70.9604187, 20.74014091], [70.96013641, 20.74014091], [70.96013641, 20.73986053], [70.9595871, 20.73986053], [70.9595871, 20.73958015], [70.95930481, 20.73958397], [70.95930481, 20.7393055], [70.95903015, 20.73931122], [70.95903015, 20.73903084], [70.95847321, 20.73903084], [70.95847321, 20.73875809], [70.95819092, 20.73875809], [70.95819092, 20.73792076], [70.95791626, 20.73792076], [70.95791626, 20.73764038], [70.9576416, 20.73764038], [70.9576416, 20.73736], [70.95708466, 20.73736191], [70.95708466, 20.73708344], [70.95652771, 20.73708344], [70.95652771, 20.73680687], [70.95625305, 20.73681068], [70.95625305, 20.7365303], [70.95597076, 20.7365303], [70.95597076, 20.73624992], [70.95569611, 20.73624992], [70.95569611, 20.73596954], [70.95541382, 20.73597145], [70.95541382, 20.73569489], [70.9548645, 20.73569489], [70.9548645, 20.73541641], [70.95458221, 20.73542023], [70.95458221, 20.73485947], [70.9548645, 20.73486137], [70.9548645, 20.73458481], [70.95625305, 20.73458481], [70.95625305, 20.73486137], [70.95680237, 20.73485947], [70.95680237, 20.73513985], [70.95707703, 20.73513985], [70.95707703, 20.73542023], [70.9576416, 20.73541641], [70.9576416, 20.73569489], [70.95819092, 20.73569489], [70.95819092, 20.73597145], [70.9595871, 20.73596954], [70.9595871, 20.73624992], [70.96013641, 20.73624992], [70.96013641, 20.73596954], [70.9604187, 20.73597145], [70.9604187, 20.73569489], [70.96069336, 20.73569489], [70.96069336, 20.73541641], [70.96125031, 20.73542023], [70.96125031, 20.73513985], [70.96208191, 20.73513985], [70.96208191, 20.7345829], [70.96263885, 20.73458481], [70.96263885, 20.73374939], [70.96290588, 20.73374939], [70.96290588, 20.73347282], [70.9631958, 20.73347473], [70.9631958, 20.73319435], [70.96291351, 20.73319435], [70.96291351, 20.73291588], [70.96375275, 20.73291969], [70.96375275, 20.73208046], [70.96347046, 20.73208427], [70.96347046, 20.73152733], [70.9631958, 20.73153114], [70.9631958, 20.73069191], [70.96291351, 20.73069382], [70.96291351, 20.7298584], [70.96263885, 20.7298584], [70.96263885, 20.72938156], [70.96203613, 20.7292099], [70.94854736, 20.73374176], [70.93889618, 20.73648834], [70.93403625, 20.73595047], [70.92965698, 20.73192024], [70.92093658, 20.72891045], [70.90487671, 20.72652817], [70.89965057, 20.7238903], [70.89689636, 20.72000122], [70.89295959, 20.71302032], [70.89208221, 20.70819092], [70.89069366, 20.70819473], [70.89069366, 20.7084713], [70.88986206, 20.70845985], [70.88986206, 20.70874977], [70.88854218, 20.70874977], [70.88853455, 20.70903206], [70.88764191, 20.70902824], [70.88764191, 20.70930672], [70.88569641, 20.70930672], [70.88569641, 20.70958328], [70.88541412, 20.70958328], [70.88541412, 20.70930672], [70.88430786, 20.70930672], [70.88430786, 20.70958328], [70.88069153, 20.70958328], [70.88069153, 20.70930672], [70.87680817, 20.70930672], [70.87680817, 20.70902824], [70.87458038, 20.70902824], [70.87458038, 20.70930672], [70.87403107, 20.70930672], [70.87403107, 20.70958328], [70.87374878, 20.70958328], [70.87374878, 20.70982933], [70.87347412, 20.70986176], [70.87347412, 20.71208382], [70.87319183, 20.71208], [70.87319183, 20.71264076], [70.87346649, 20.71264076], [70.87346649, 20.71292114], [70.87374878, 20.71292114], [70.87374878, 20.71486092], [70.87346649, 20.71486092], [70.87346649, 20.7151413], [70.87374878, 20.7151413], [70.87374878, 20.71569443], [70.87346649, 20.71569061], [70.87346649, 20.7179203], [70.87374878, 20.7179203], [70.87374878, 20.71875191], [70.87431335, 20.71875191], [70.87431335, 20.71903038], [70.87458038, 20.71903038], [70.87458038, 20.71931076], [70.87513733, 20.71930504], [70.87513733, 20.71958351], [70.87541962, 20.71958351], [70.87541962, 20.71986389], [70.87596893, 20.71986008], [70.87596893, 20.72014046], [70.87625122, 20.72014046], [70.87625122, 20.72042084], [70.87652588, 20.72041702], [70.87652588, 20.72069359], [70.87680817, 20.72068977], [70.87680817, 20.72125053], [70.87708282, 20.72125053], [70.87708282, 20.72153091], [70.87763977, 20.72153091], [70.87763977, 20.72180939], [70.8779068, 20.72180939], [70.8779068, 20.72236061], [70.87819672, 20.72236061], [70.87819672, 20.72264099], [70.87847137, 20.72264099], [70.87847137, 20.72291946], [70.87902832, 20.72291756], [70.87902832, 20.72319412], [70.87930298, 20.72319412], [70.87930298, 20.7234726], [70.8795929, 20.72347069], [70.8795929, 20.72375107], [70.87985992, 20.72375107], [70.87985992, 20.72402954], [70.88014221, 20.72402954], [70.88014221, 20.72513962], [70.88041687, 20.72513962], [70.88041687, 20.72541809], [70.88097382, 20.72541618], [70.88097382, 20.72569466], [70.88069153, 20.72569084], [70.88069153, 20.72624969], [70.88097382, 20.72624969], [70.88097382, 20.72680473], [70.88124847, 20.72680473], [70.88124847, 20.72708321], [70.88180542, 20.72708321], [70.88180542, 20.72736168], [70.88208008, 20.72735977], [70.88208008, 20.72792053], [70.88236237, 20.72792053], [70.88236237, 20.72874832], [70.88291931, 20.72874832], [70.88291931, 20.72903061], [70.88347626, 20.72903061], [70.88347626, 20.72930908], [70.8840332, 20.72930908], [70.8840332, 20.72958946], [70.88485718, 20.72958946], [70.88485718, 20.7298584], [70.88791656, 20.7298584], [70.88791656, 20.73014259], [70.88874817, 20.73014259], [70.88874817, 20.73042107], [70.89041901, 20.73041725], [70.89041901, 20.73069382], [70.89152527, 20.73069382], [70.89152527, 20.73097038], [70.89208221, 20.73097038], [70.89208221, 20.73125267], [70.89290619, 20.73125267], [70.89290619, 20.73153114], [70.89347076, 20.73153114], [70.89347076, 20.73180962], [70.89624786, 20.7318058], [70.89624786, 20.73208046], [70.89763641, 20.73208046], [70.89763641, 20.73236275], [70.89902496, 20.73236275], [70.89902496, 20.73263931], [70.89930725, 20.73263931], [70.89930725, 20.73236275], [70.89958191, 20.73236275], [70.89958191, 20.73263931], [70.9006958, 20.73263931], [70.9006958, 20.73236275], [70.90125275, 20.73236275], [70.90125275, 20.73263931], [70.90151978, 20.73263168], [70.90151978, 20.73291969], [70.90208435, 20.73291588], [70.90208435, 20.73319435], [70.90291595, 20.73319054], [70.90291595, 20.73374939], [70.90319824, 20.73374939], [70.90319824, 20.73402977], [70.90429688, 20.73402977], [70.90429688, 20.73431015], [70.90513611, 20.73430634], [70.90513611, 20.73458481], [70.90569305, 20.73458481], [70.90569305, 20.73486137], [70.90652466, 20.73486137], [70.90652466, 20.73458481], [70.90791321, 20.73458481], [70.90791321, 20.73486137], [70.90820313, 20.73485947], [70.90820313, 20.73513985], [70.9090271, 20.73513985], [70.9090271, 20.73542023], [70.91014099, 20.73541641], [70.91014099, 20.73569489], [70.91060638, 20.73569489], [70.9118042, 20.73569489], [70.9118042, 20.73541641], [70.91152954, 20.73542023], [70.91152954, 20.73513985], [70.91236115, 20.73513794], [70.91236115, 20.73569489], [70.91402435, 20.73569489], [70.91402435, 20.73541641], [70.91683197, 20.73541641], [70.91764069, 20.73541641], [70.91764069, 20.73569489], [70.91819763, 20.73569489], [70.91819763, 20.73597145], [70.91902924, 20.73596954], [70.91902924, 20.73624992], [70.91958618, 20.73624992], [70.91958618, 20.7365303], [70.92014313, 20.7365303], [70.92014313, 20.73681068], [70.92041779, 20.73680687], [70.92041779, 20.73708344], [70.9201355, 20.73708344], [70.9201355, 20.73736191], [70.91986084, 20.73736], [70.91986084, 20.73792076], [70.91958618, 20.73792076], [70.91958618, 20.73736], [70.91930389, 20.73736191], [70.91930389, 20.73680687], [70.91902924, 20.73681068], [70.91902924, 20.7365303], [70.91765594, 20.7365303], [70.91513824, 20.7365303], [70.91513824, 20.73681068], [70.91486359, 20.73680687], [70.91486359, 20.73708344], [70.9145813, 20.73708344], [70.9145813, 20.73736191], [70.91401672, 20.73736], [70.91401672, 20.73764038], [70.91374969, 20.73763847], [70.91374969, 20.73819351], [70.91402435, 20.73819351], [70.91402435, 20.73847198], [70.91430664, 20.73847008], [70.91430664, 20.73903084], [70.9145813, 20.73903084], [70.9145813, 20.73931122], [70.91486359, 20.7393055], [70.91486359, 20.73958397], [70.91513824, 20.73958015], [70.91513824, 20.73986053], [70.9154129, 20.73986053], [70.9154129, 20.74041748], [70.91569519, 20.74041748], [70.91569519, 20.74069405], [70.91596985, 20.74069405], [70.91596985, 20.74097252], [70.91652679, 20.74097061], [70.91652679, 20.74124908], [70.91681671, 20.74124908], [70.91681671, 20.74152756], [70.9173584, 20.74152756], [70.9173584, 20.74181938], [70.91764069, 20.74180603], [70.91764069, 20.7420826], [70.91819763, 20.74208069], [70.91819763, 20.74235916], [70.91902924, 20.74235916], [70.91902924, 20.74264145], [70.91958618, 20.74264145], [70.91958618, 20.74292183], [70.91986084, 20.74291611], [70.91986084, 20.74347115], [70.91902924, 20.74346924], [70.91902924, 20.74375153], [70.91791534, 20.74375153], [70.91791534, 20.74347115], [70.91680908, 20.74347115], [70.91680908, 20.74319458], [70.91652679, 20.74319458], [70.91652679, 20.74291611], [70.91570282, 20.74292183], [70.91570282, 20.74264145], [70.9154129, 20.74264145], [70.9154129, 20.74235916], [70.91513824, 20.74235916], [70.91513824, 20.74208069], [70.9145813, 20.7420826], [70.9145813, 20.74180603], [70.91430664, 20.74181938], [70.91430664, 20.74152756], [70.91374969, 20.74152756], [70.91374969, 20.74097061], [70.91347504, 20.74097252], [70.91347504, 20.74041748], [70.91319275, 20.74041748], [70.91319275, 20.73986053], [70.91291809, 20.73986053], [70.91291809, 20.73958015], [70.9126358, 20.73958397], [70.9126358, 20.73902893], [70.91236115, 20.73903084], [70.91236115, 20.73875809], [70.91208649, 20.73875809], [70.91208649, 20.73847008], [70.9118042, 20.73847198], [70.9118042, 20.73791695], [70.91152954, 20.73792076], [70.91152954, 20.73764038], [70.91124725, 20.73764038], [70.91124725, 20.73736], [70.91041565, 20.73736191], [70.91041565, 20.73708344], [70.90846252, 20.73708344], [70.90763855, 20.73708344], [70.90763855, 20.73680687], [70.90458679, 20.73681068], [70.90458679, 20.7365303], [70.90374756, 20.7365303], [70.90374756, 20.73624992], [70.90319824, 20.73624992], [70.90319061, 20.73596954], [70.90291595, 20.73597145], [70.90291595, 20.73541641], [70.9026413, 20.73542023], [70.9026413, 20.73513985], [70.90207672, 20.73513985], [70.90207672, 20.73542023], [70.90180206, 20.73542023], [70.90180206, 20.73513985], [70.9006958, 20.73513985], [70.9006958, 20.73485947], [70.89958191, 20.73486137], [70.89958191, 20.73458481], [70.89875031, 20.73458481], [70.89875031, 20.73430634], [70.89653015, 20.73431015], [70.89653015, 20.73402977], [70.89597321, 20.73402977], [70.89597321, 20.73374939], [70.89569092, 20.73374939], [70.89569092, 20.73347282], [70.89180756, 20.73347282], [70.89180756, 20.73374939], [70.88819122, 20.73374939], [70.88819122, 20.73347282], [70.88597107, 20.73347473], [70.88597107, 20.73319435], [70.88541412, 20.73319435], [70.88541412, 20.73291588], [70.88485718, 20.73291969], [70.88485718, 20.73263168], [70.88430786, 20.73263931], [70.88430786, 20.73236275], [70.88375092, 20.73236275], [70.88375092, 20.73208046], [70.88208008, 20.73208427], [70.88208008, 20.7318058], [70.88181305, 20.73180962], [70.88181305, 20.73153114], [70.88153076, 20.73153114], [70.88153076, 20.73125267], [70.88041687, 20.73125267], [70.88041687, 20.73153114], [70.88014221, 20.73153114], [70.88014221, 20.73125267], [70.87930298, 20.73125267], [70.87930298, 20.73097038], [70.87875366, 20.73097038], [70.87875366, 20.73069382], [70.87819672, 20.73069382], [70.87819672, 20.73041725], [70.8779068, 20.73042107], [70.8779068, 20.73014259], [70.87763977, 20.73014259], [70.87763977, 20.7298584], [70.87735748, 20.7298584], [70.87735748, 20.72930908], [70.87708282, 20.72930908], [70.87708282, 20.72846985], [70.87680817, 20.72847176], [70.87680817, 20.72819519], [70.87652588, 20.72820091], [70.87652588, 20.72792053], [70.87625122, 20.72792053], [70.87625122, 20.72763824], [70.87596893, 20.72763824], [70.87596893, 20.72735977], [70.87569427, 20.72736168], [70.87569427, 20.72708321], [70.87513733, 20.72708321], [70.87513733, 20.72680473], [70.87486267, 20.72680473], [70.87486267, 20.72708321], [70.87374878, 20.72708321], [70.87374878, 20.72736168], [70.87346649, 20.72735977], [70.87346649, 20.72792053], [70.87291718, 20.72792053], [70.87291718, 20.72820091], [70.87264252, 20.72819519], [70.87264252, 20.72847176], [70.87208557, 20.72847176], [70.8720932, 20.72874832], [70.87180328, 20.72874832], [70.87180328, 20.72903061], [70.87153625, 20.72903061], [70.87153625, 20.72930908], [70.87124634, 20.72930908], [70.87124634, 20.72958946], [70.87097168, 20.72958946], [70.87097168, 20.73014259], [70.8704071, 20.73014259], [70.8704071, 20.73042107], [70.87014008, 20.73041725], [70.87014008, 20.73069382], [70.86985779, 20.73069191], [70.86985779, 20.73125267], [70.86958313, 20.73125267], [70.86958313, 20.73153114], [70.86930847, 20.73153114], [70.86930847, 20.73236275], [70.86902618, 20.73236275], [70.86902618, 20.73291969], [70.86846924, 20.73291588], [70.86846924, 20.73347473], [70.86818695, 20.73347282], [70.86818695, 20.73374939], [70.86791992, 20.73374939], [70.86791992, 20.73431015], [70.86763763, 20.73430634], [70.86763763, 20.73458481], [70.86736298, 20.7345829], [70.86736298, 20.73513985], [70.86708069, 20.73513985], [70.86708069, 20.73597145], [70.86653137, 20.73596954], [70.86653137, 20.73624992], [70.86624908, 20.73624992], [70.86624908, 20.73681068], [70.86597443, 20.73680687], [70.86597443, 20.73708344], [70.86541748, 20.73708344], [70.86541748, 20.73736191], [70.86514282, 20.73736], [70.86514282, 20.73764038], [70.86458588, 20.73763847], [70.86458588, 20.7381897], [70.86429596, 20.73820114], [70.86429596, 20.73903084], [70.86402893, 20.73902893], [70.86402893, 20.73958397], [70.86374664, 20.73958015], [70.86374664, 20.73986053], [70.86347198, 20.73986053], [70.86347198, 20.74014091], [70.86374664, 20.7401371], [70.86374664, 20.74069405], [70.86347198, 20.74069405], [70.86347198, 20.7420826], [70.86291504, 20.7420826], [70.86291504, 20.74319458], [70.86264038, 20.74319458], [70.86264038, 20.74486351], [70.86292267, 20.7448597], [70.86292267, 20.74542046], [70.86319733, 20.74542046], [70.86319733, 20.74570084], [70.86347198, 20.74570084], [70.86347198, 20.74625015], [70.86374664, 20.74625015], [70.86374664, 20.74681091], [70.86402893, 20.74680519], [70.86402893, 20.74708366], [70.86429596, 20.74707985], [70.86429596, 20.74736023], [70.86458588, 20.74736023], [70.86458588, 20.74930954], [70.86429596, 20.74930954], [70.86429596, 20.74986076], [70.86402893, 20.74986076], [70.86402893, 20.75041962], [70.86374664, 20.75041962], [70.86374664, 20.7507], [70.86347198, 20.7507], [70.86347198, 20.75125122], [70.86319733, 20.75124931], [70.86319733, 20.75208282], [70.86291504, 20.75208282], [70.86291504, 20.75263977], [70.86319733, 20.75263977], [70.86319733, 20.75319481], [70.86347198, 20.75319099], [70.86347198, 20.75402832], [70.86319733, 20.75402832], [70.86319733, 20.75486183], [70.86292267, 20.75485992], [70.86292267, 20.7551384], [70.86180878, 20.7551384], [70.86180878, 20.75485992], [70.85930634, 20.75486183], [70.85930634, 20.75458336], [70.85847473, 20.75458336], [70.85847473, 20.75430489], [70.85819244, 20.75430489], [70.85819244, 20.75374985], [70.85764313, 20.75375938], [70.85764313, 20.75346947], [70.85736084, 20.75347137], [70.85736084, 20.75319481], [70.85458374, 20.75319481], [70.85458374, 20.75347137], [70.85441589, 20.75347137], [70.85375214, 20.75346947], [70.85375214, 20.75375938], [70.85346985, 20.75375938], [70.85346985, 20.75402832], [70.8529129, 20.75402832], [70.8529129, 20.75319099], [70.85319519, 20.75319481], [70.85319519, 20.75291634], [70.85346985, 20.75291824], [70.85346985, 20.75263977], [70.85375214, 20.75263977], [70.85375214, 20.75235939], [70.85430908, 20.7523613], [70.85430908, 20.75208282], [70.85456085, 20.75208282]]], [[[69.64263916, 22.76486206], [69.64263916, 22.76458359], [69.64402771, 22.76458359], [69.64402771, 22.76430511], [69.64430237, 22.76430511], [69.64430237, 22.76402855], [69.64485931, 22.76403046], [69.64485931, 22.76375008], [69.6451416, 22.76375008], [69.6451416, 22.7634697], [69.64541626, 22.76347351], [69.64541626, 22.76319504], [69.64597321, 22.76320076], [69.64597321, 22.76292038], [69.64624786, 22.76292038], [69.64624786, 22.76264191], [69.64652252, 22.76264191], [69.64652252, 22.76235962], [69.64680481, 22.76235962], [69.64680481, 22.76208115], [69.6470871, 22.76208115], [69.6470871, 22.76180649], [69.64736176, 22.7618103], [69.64736176, 22.76153183], [69.64763641, 22.76153183], [69.64763641, 22.76126289], [69.6479187, 22.76126289], [69.6479187, 22.76096916], [69.64819336, 22.76097107], [69.64819336, 22.7606945], [69.64847565, 22.7606945], [69.64847565, 22.76041603], [69.64875031, 22.76042175], [69.64875031, 22.76014137], [69.64930725, 22.76014137], [69.64930725, 22.75985909], [69.64958191, 22.75985909], [69.64958191, 22.75958061], [69.65013885, 22.75958252], [69.65013885, 22.75930595], [69.65040588, 22.75930977], [69.65040588, 22.75902748], [69.65097046, 22.75902748], [69.65097046, 22.75875092], [69.65125275, 22.75875092], [69.65125275, 22.75847054], [69.6515274, 22.75847244], [69.6515274, 22.75819397], [69.65207672, 22.75819969], [69.65207672, 22.75792122], [69.65235901, 22.75792122], [69.65235901, 22.75764084], [69.65264893, 22.75764084], [69.65264893, 22.75736046], [69.65319824, 22.75736046], [69.65319824, 22.75708008], [69.6534729, 22.75708389], [69.6534729, 22.75680542], [69.65402985, 22.75681114], [69.65402985, 22.75653076], [69.65429688, 22.75653076], [69.65429688, 22.75625038], [69.65486145, 22.75625038], [69.65486145, 22.75597], [69.65569305, 22.75597191], [69.65569305, 22.75569534], [69.65625, 22.75570107], [69.65625, 22.75542068], [69.6570816, 22.75542068], [69.6570816, 22.75513077], [69.65958405, 22.7551384], [69.65958405, 22.75486183], [69.66069794, 22.75486183], [69.66069794, 22.7551384], [69.6626358, 22.7551384], [69.6626358, 22.75486183], [69.66291809, 22.75486183], [69.66291809, 22.75458336], [69.66319275, 22.75458336], [69.66319275, 22.75430679], [69.66347504, 22.75430679], [69.66347504, 22.75402832], [69.66374969, 22.75403023], [69.66374969, 22.75374985], [69.66485596, 22.75374985], [69.66485596, 22.75346947], [69.66569519, 22.75347137], [69.66569519, 22.75319481], [69.66652679, 22.75319481], [69.66652679, 22.75291634], [69.66680908, 22.75292015], [69.66680908, 22.75235939], [69.66708374, 22.7523613], [69.66708374, 22.75180626], [69.66680908, 22.75181007], [69.66680908, 22.75152969], [69.66652679, 22.75152969], [69.66652679, 22.75069046], [69.66569519, 22.75069427], [69.66569519, 22.7504158], [69.6645813, 22.7504158], [69.6645813, 22.75069427], [69.66430664, 22.75069427], [69.66430664, 22.7504158], [69.66374969, 22.7504158], [69.66374969, 22.75069427], [69.66208649, 22.75069427], [69.66208649, 22.75097275], [69.66152191, 22.75097275], [69.66152191, 22.75125122], [69.66124725, 22.75125122], [69.66124725, 22.75152969], [69.66069794, 22.75152969], [69.66069794, 22.75181007], [69.65930176, 22.75180626], [69.65930176, 22.75208473], [69.65847015, 22.75208473], [69.65847015, 22.7523613], [69.65763855, 22.75235939], [69.65763855, 22.75263977], [69.65680695, 22.75263977], [69.65680695, 22.75292015], [69.65625, 22.75291634], [69.65625, 22.75319481], [69.65513611, 22.75319481], [69.65513611, 22.75347137], [69.65374756, 22.75346947], [69.65374756, 22.75374985], [69.65291595, 22.75374985], [69.65291595, 22.75403023], [69.65235901, 22.75402832], [69.65235901, 22.75430679], [69.6515274, 22.75430679], [69.6515274, 22.75458336], [69.6506958, 22.75457954], [69.6506958, 22.75542068], [69.65040588, 22.75542068], [69.65040588, 22.75570107], [69.6498642, 22.75569534], [69.6498642, 22.75597191], [69.64930725, 22.75597], [69.64930725, 22.75625038], [69.64819336, 22.75625038], [69.64819336, 22.75597], [69.64763641, 22.75597191], [69.64763641, 22.75569534], [69.64736176, 22.75570107], [69.64736176, 22.75513077], [69.6470871, 22.75513077], [69.6470871, 22.75542068], [69.64679718, 22.75542068], [69.64679718, 22.75570107], [69.64652252, 22.75570107], [69.64652252, 22.75653076], [69.64624786, 22.75653076], [69.64624786, 22.75792122], [69.64652252, 22.75792122], [69.64652252, 22.75819969], [69.64624786, 22.75819397], [69.64624786, 22.75847244], [69.64541626, 22.75847054], [69.64541626, 22.75875092], [69.6451416, 22.75875092], [69.6451416, 22.75902748], [69.64485931, 22.75902748], [69.64485931, 22.75875092], [69.64430237, 22.75875092], [69.64430237, 22.75847054], [69.64263916, 22.75847054], [69.64263916, 22.75875092], [69.64235687, 22.75875092], [69.64235687, 22.75902748], [69.64068604, 22.75902748], [69.64068604, 22.75930977], [69.64013672, 22.75930977], [69.64013672, 22.76014137], [69.63986206, 22.76014137], [69.63986206, 22.76097107], [69.63957977, 22.76096916], [69.63957977, 22.76126289], [69.63846588, 22.76126289], [69.63846588, 22.76096916], [69.63735199, 22.76096916], [69.63735199, 22.76126289], [69.63707733, 22.76126289], [69.63707733, 22.76096916], [69.63680267, 22.76097107], [69.63680267, 22.76041603], [69.63430786, 22.76041603], [69.63430786, 22.7606945], [69.63346863, 22.7606945], [69.63346863, 22.76097107], [69.63263702, 22.76097107], [69.63263702, 22.7606945], [69.63236237, 22.7606945], [69.63236237, 22.76041603], [69.63180542, 22.76041603], [69.63180542, 22.7606945], [69.63153076, 22.7606945], [69.63153076, 22.76097107], [69.63124847, 22.76096916], [69.63124847, 22.76126289], [69.63097382, 22.76125145], [69.63097382, 22.76235962], [69.63124847, 22.76235962], [69.63124847, 22.76264191], [69.63181305, 22.76264191], [69.63181305, 22.76292038], [69.63208008, 22.76292038], [69.63208008, 22.76320076], [69.63319397, 22.76319504], [69.63319397, 22.76347351], [69.63402557, 22.76347351], [69.63402557, 22.76375008], [69.63513947, 22.76375008], [69.63513947, 22.76403046], [69.63597107, 22.76402855], [69.63597107, 22.76430511], [69.63680267, 22.76430511], [69.63680267, 22.76458359], [69.63764191, 22.76458359], [69.63764191, 22.76486206], [69.63847351, 22.76486206], [69.63847351, 22.76458359], [69.64152527, 22.76458359], [69.64152527, 22.76486206], [69.64263916, 22.76486206]]], [[[69.63652802, 22.77986145], [69.63652802, 22.77958488], [69.63680267, 22.77958488], [69.63680267, 22.77930641], [69.63708496, 22.77930641], [69.63708496, 22.77874947], [69.63735199, 22.77874947], [69.63735199, 22.77653122], [69.63764191, 22.77653122], [69.63764191, 22.77569008], [69.63625336, 22.77569389], [69.63625336, 22.77597046], [69.63597107, 22.77597046], [69.63597107, 22.77653122], [69.63569641, 22.7765274], [69.63569641, 22.77708054], [69.63540649, 22.77708054], [69.63540649, 22.77791977], [69.63513947, 22.77791595], [69.63513947, 22.77930641], [69.63541412, 22.77930641], [69.63541412, 22.77958488], [69.63625336, 22.77958488], [69.63625336, 22.77986145], [69.63652802, 22.77986145]]], [[[70.23569489, 22.68458366], [70.23569489, 22.68430519], [70.23596954, 22.68431091], [70.23596954, 22.68403053], [70.23568726, 22.68403053], [70.23568726, 22.68375015], [70.23654175, 22.68375015], [70.23652649, 22.68347359], [70.23708344, 22.68347359], [70.23708344, 22.68319511], [70.23847198, 22.68320274], [70.23847198, 22.6823616], [70.23819733, 22.6823616], [70.23819733, 22.68208122], [70.23764038, 22.68208122], [70.23764038, 22.6823616], [70.23735809, 22.6823616], [70.23735809, 22.68264008], [70.23542023, 22.68264008], [70.23542023, 22.6823616], [70.23513794, 22.6823616], [70.23513794, 22.68320274], [70.23486328, 22.68320274], [70.23486328, 22.68403053], [70.23458099, 22.68403053], [70.23458099, 22.68431091], [70.23486328, 22.68430519], [70.23486328, 22.68458366], [70.23569489, 22.68458366]]], [[[70.24263763, 22.68458366], [70.24263763, 22.68430519], [70.24375153, 22.68431091], [70.24375153, 22.68320274], [70.24346924, 22.68320274], [70.24346924, 22.6823616], [70.24291992, 22.6823616], [70.24291992, 22.68292046], [70.24319458, 22.68291664], [70.24319458, 22.68347359], [70.24291992, 22.68346977], [70.24291992, 22.68375015], [70.24234772, 22.68375015], [70.24234772, 22.68292046], [70.24180603, 22.68292046], [70.24180603, 22.68207932], [70.24124908, 22.68208122], [70.24124908, 22.6823616], [70.24013519, 22.6823616], [70.24013519, 22.68208122], [70.23986053, 22.68208122], [70.23986053, 22.68180466], [70.23930359, 22.68180466], [70.23930359, 22.68208122], [70.23902893, 22.68207932], [70.23902893, 22.68320274], [70.23874664, 22.68319511], [70.23874664, 22.68347359], [70.23902893, 22.68346977], [70.23902893, 22.68375015], [70.23960114, 22.68375015], [70.23960114, 22.68403053], [70.24014282, 22.68403053], [70.24014282, 22.68375015], [70.24041748, 22.68375015], [70.24041748, 22.68346977], [70.24069214, 22.68346977], [70.24069214, 22.68403053], [70.2409668, 22.68403053], [70.2409668, 22.68431091], [70.24208069, 22.68430519], [70.24208069, 22.68458366], [70.24263763, 22.68458366]]], [[[70.24680328, 22.69180489], [70.24680328, 22.69152641], [70.24736023, 22.69152832], [70.24736023, 22.69124985], [70.24764252, 22.69124985], [70.24764252, 22.68985939], [70.24791718, 22.6898613], [70.24791718, 22.68930626], [70.24736023, 22.68931007], [70.24736023, 22.68904114], [70.24680328, 22.68904114], [70.24680328, 22.68875122], [70.24736023, 22.68875122], [70.24736023, 22.68819046], [70.24680328, 22.68819427], [70.24680328, 22.6879158], [70.24597168, 22.68791962], [70.24597168, 22.68764114], [70.24569702, 22.68764114], [70.24569702, 22.68791962], [70.2454071, 22.68791962], [70.2454071, 22.68708038], [70.24485779, 22.6870842], [70.24485779, 22.68680573], [70.24430847, 22.68680954], [70.24430847, 22.68736076], [70.24402618, 22.68736076], [70.24402618, 22.68680954], [70.24346924, 22.68680573], [70.24346924, 22.6870842], [70.24319458, 22.6870842], [70.24319458, 22.68680573], [70.24263763, 22.68680954], [70.24263763, 22.68764114], [70.24375153, 22.68764114], [70.24375153, 22.68791962], [70.24402618, 22.6879158], [70.24402618, 22.68819427], [70.24430847, 22.68819427], [70.24430847, 22.68847275], [70.24291992, 22.68847275], [70.24291992, 22.68819427], [70.24208069, 22.68819046], [70.24208069, 22.68931007], [70.24180603, 22.68930626], [70.24180603, 22.68958282], [70.24236298, 22.68958282], [70.24236298, 22.68930626], [70.24263763, 22.68930626], [70.24263763, 22.6898613], [70.24319458, 22.6898613], [70.24319458, 22.68958282], [70.24346924, 22.68958282], [70.24346924, 22.69069481], [70.24375153, 22.69069099], [70.24375153, 22.69124985], [70.24430847, 22.69124985], [70.24430847, 22.69152832], [70.24514008, 22.69152832], [70.24514008, 22.69124985], [70.24569702, 22.69124985], [70.24569702, 22.69069099], [70.24597168, 22.69069481], [70.24597168, 22.69041634], [70.24624634, 22.69041634], [70.24624634, 22.69097137], [70.24652863, 22.69096947], [70.24652863, 22.69124985], [70.24624634, 22.69124985], [70.24624634, 22.69180489], [70.24680328, 22.69180489]]], [[[70.24402618, 22.72013855], [70.24402618, 22.71902084], [70.24430847, 22.71903038], [70.24430847, 22.71763611], [70.24458313, 22.71763992], [70.24458313, 22.71708107], [70.24485779, 22.71708298], [70.24485779, 22.71652794], [70.24514008, 22.71652985], [70.24514008, 22.71569061], [70.24569702, 22.71569443], [70.24569702, 22.71513939], [70.24597168, 22.71513939], [70.24597168, 22.71486092], [70.24624634, 22.71486092], [70.24624634, 22.71458054], [70.24652863, 22.71458244], [70.24652863, 22.7131958], [70.24624634, 22.7131958], [70.24624634, 22.71291733], [70.24597168, 22.71292114], [70.24597168, 22.71264076], [70.24569702, 22.71264076], [70.24569702, 22.71208], [70.24541473, 22.71208382], [70.24541473, 22.71180534], [70.24514008, 22.71181107], [70.24514008, 22.71236038], [70.24346924, 22.71236038], [70.24346924, 22.7131958], [70.24375153, 22.71319008], [70.24375153, 22.71681023], [70.24346924, 22.71681023], [70.24346924, 22.71931076], [70.24318695, 22.71931076], [70.24318695, 22.72013855], [70.24402618, 22.72013855]]]]}}, {\\\"id\\\": \\\"10\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.12_1\\\", \\\"HASC_1\\\": \\\"IN.HR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Haryana\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 97.2, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1742.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1178.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2920.0, \\\"geo-id\\\": 10, \\\"hpm25_child_popweighted\\\": 170.3, \\\"hpm25_female_popweighted\\\": 195.7, \\\"hpm25_male_popweighted\\\": 140.9, \\\"location\\\": \\\"Haryana\\\", \\\"mort_apm25_6cod_mean_total\\\": 16361.0, \\\"mort_hpm25_6cod_mean_total\\\": 10805.0, \\\"mort_tpm25_6cod_mean_total\\\": 27166.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[76.08009338, 27.8510704], [76.06002808, 27.85717964], [76.05478668, 27.8518219], [76.04962921, 27.84786034], [76.04368591, 27.84885025], [76.03839874, 27.85250092], [76.03383636, 27.85418129], [76.02961731, 27.85388947], [76.0207901, 27.85752106], [76.00930786, 27.86260986], [76.00524902, 27.85744095], [75.99662018, 27.86016846], [75.99447632, 27.86091995], [75.98427582, 27.86286926], [75.97544861, 27.86462975], [75.96308136, 27.86473083], [75.96425629, 27.87150955], [75.97345734, 27.87745285], [75.97280121, 27.88537979], [75.97518921, 27.8930912], [75.96724701, 27.89931107], [75.97738647, 27.9092598], [75.96753693, 27.91537094], [75.95588684, 27.91954994], [75.94174957, 27.91908073], [75.92883301, 27.91680908], [75.9287796, 27.92648125], [75.92362213, 27.93309021], [75.92858887, 27.94174957], [75.93850708, 27.95109177], [75.94169617, 27.94634056], [75.9446106, 27.94008827], [75.95394897, 27.93943977], [75.96317291, 27.93695068], [75.97319794, 27.95800018], [75.96833038, 27.96231079], [75.97384644, 27.96993828], [75.98182678, 27.97831154], [75.98647308, 27.98110962], [75.98690796, 27.98463058], [75.98207855, 27.98698044], [75.97316742, 27.98396111], [75.9656601, 27.98657036], [75.95546722, 27.98863983], [75.95527649, 27.99418068], [75.95639801, 28.00102043], [75.96051788, 28.00209999], [75.96452332, 28.00266075], [75.96687317, 28.00222969], [75.97226715, 28.00134087], [75.97988892, 28.00145149], [75.98911285, 28.00432968], [75.99053955, 28.01017189], [75.98581696, 28.01474953], [75.97915649, 28.01545906], [75.97267914, 28.01814079], [75.97083282, 28.02375031], [75.96998596, 28.03094864], [75.9743576, 28.03693962], [75.9805069, 28.03870964], [75.99105072, 28.03991127], [76.01007843, 28.03671074], [76.01088715, 28.04704094], [76.00995636, 28.04990959], [76.00535583, 28.0545311], [76.01667023, 28.05611038], [76.01924133, 28.0589447], [76.02229309, 28.06230927], [76.0331192, 28.0686512], [76.03562927, 28.07398033], [76.03420258, 28.07995033], [76.03121185, 28.08389282], [76.01564789, 28.08885193], [76.01486206, 28.08107948], [76.01242828, 28.07635117], [76.00192261, 28.06073189], [75.99957275, 28.0589447], [75.99762726, 28.05746841], [75.99106598, 28.0564518], [75.98455048, 28.0507412], [75.97740936, 28.05220032], [75.97458649, 28.0570507], [75.97640991, 28.0589447], [75.98763275, 28.07058907], [75.98206329, 28.08022118], [75.97706604, 28.08418083], [75.95896912, 28.08406067], [75.93608856, 28.09353065], [75.94249725, 28.10563087], [75.94740295, 28.10968971], [75.95749664, 28.11555099], [75.96761322, 28.11939049], [75.97706604, 28.12720108], [75.99111176, 28.12817955], [75.99429321, 28.13111115], [75.99571991, 28.13532066], [75.99466705, 28.15060043], [75.99975586, 28.15644073], [76.00602722, 28.15656281], [76.01119995, 28.15767288], [76.0161972, 28.16107941], [76.02774811, 28.17272186], [76.06072998, 28.169981], [76.06635284, 28.16777039], [76.0654068, 28.15564919], [76.0636673, 28.1498909], [76.06505585, 28.14447021], [76.07491302, 28.14195061], [76.08319855, 28.14225006], [76.0879364, 28.14353943], [76.09179688, 28.14641953], [76.09287262, 28.15162086], [76.09288788, 28.15521812], [76.08042908, 28.16810989], [76.07480621, 28.17242813], [76.07157135, 28.17922974], [76.06929779, 28.19425011], [76.06561279, 28.19894981], [76.05665588, 28.201231], [76.04506683, 28.20293045], [76.04382324, 28.20549011], [76.04975128, 28.20983124], [76.05227661, 28.21443939], [76.05300903, 28.22422981], [76.03634644, 28.22710991], [76.02577972, 28.23591995], [76.01119232, 28.24175072], [76.00740051, 28.25315285], [76.01872253, 28.28095818], [75.99124146, 28.29519081], [75.98657227, 28.29589081], [75.97933197, 28.30633163], [75.97470856, 28.31586075], [75.96762848, 28.32409286], [75.95466614, 28.31853104], [75.95449066, 28.32870865], [75.95143127, 28.33349991], [75.95659637, 28.33558083], [75.95630646, 28.33837128], [75.92740631, 28.3451004], [75.92840576, 28.35601997], [75.92498016, 28.36469841], [75.92237854, 28.36890984], [75.90467072, 28.37606049], [75.89713287, 28.38008118], [75.89686584, 28.38999939], [75.88922882, 28.39365959], [75.88353729, 28.39199066], [75.88315582, 28.38669968], [75.87213135, 28.39085007], [75.84120178, 28.39727974], [75.83508301, 28.39770126], [75.82823944, 28.40907288], [75.81813812, 28.40588951], [75.81671143, 28.41150093], [75.80258942, 28.41422844], [75.79405212, 28.40987968], [75.78759003, 28.40444183], [75.78256226, 28.40723038], [75.77031708, 28.40761948], [75.76544952, 28.42078018], [75.77683258, 28.43047142], [75.78513336, 28.43921089], [75.78515625, 28.45074081], [75.77822876, 28.45761108], [75.74713898, 28.46937943], [75.73500061, 28.47264099], [75.73654938, 28.48720169], [75.72395325, 28.49129295], [75.70069122, 28.49533081], [75.69007874, 28.49909973], [75.6710968, 28.51692963], [75.6639328, 28.52086067], [75.6654892, 28.53327942], [75.66333008, 28.53611183], [75.65355682, 28.54057121], [75.64351654, 28.54290962], [75.63665009, 28.54751015], [75.62909698, 28.54597092], [75.6252594, 28.55850983], [75.61904907, 28.58872986], [75.62001801, 28.59922981], [75.61804962, 28.60220909], [75.60933685, 28.60588074], [75.58495331, 28.60638046], [75.57699585, 28.61667061], [75.55570984, 28.6145916], [75.54901123, 28.64312172], [75.53956604, 28.64887047], [75.54071808, 28.65527916], [75.53793335, 28.66128922], [75.53980255, 28.67601967], [75.53663635, 28.68217087], [75.53547668, 28.68839073], [75.53148651, 28.71729088], [75.53093719, 28.73282051], [75.52603149, 28.74291992], [75.52892303, 28.75028038], [75.5219574, 28.7561512], [75.51608276, 28.77222824], [75.50502777, 28.78279114], [75.49854279, 28.7876606], [75.50392151, 28.79673958], [75.50312042, 28.80928993], [75.50878906, 28.81529045], [75.5133667, 28.83658981], [75.51049805, 28.84342003], [75.50267792, 28.84597969], [75.49915314, 28.85036087], [75.49771881, 28.85618973], [75.48799133, 28.85964966], [75.48842621, 28.89831924], [75.48462677, 28.90166092], [75.46707916, 28.92625046], [75.46888733, 28.93799019], [75.49756622, 28.94148827], [75.50354767, 28.95182037], [75.50293732, 28.96148109], [75.50891876, 28.9657383], [75.51651764, 28.97538948], [75.51525116, 28.99105072], [75.51113892, 29.00332069], [75.51107025, 29.00414085], [75.51110077, 29.01082993], [75.50511932, 29.01515007], [75.48362732, 29.01885033], [75.47342682, 29.02020073], [75.4586792, 29.02015114], [75.43473816, 29.01654053], [75.43264008, 29.02206993], [75.44055939, 29.04152107], [75.4375, 29.05047989], [75.42975616, 29.05617905], [75.4302597, 29.06472015], [75.39025116, 29.06822968], [75.38065338, 29.07032013], [75.38218689, 29.08359909], [75.3813858, 29.08967018], [75.38315582, 29.09537125], [75.38130188, 29.10256958], [75.38069916, 29.11071968], [75.39134216, 29.11931992], [75.39620972, 29.12844086], [75.38508606, 29.134161], [75.37380981, 29.13706017], [75.36115265, 29.14262009], [75.36763, 29.15042114], [75.36895752, 29.16995811], [75.37845612, 29.17152023], [75.38857269, 29.17070007], [75.39438629, 29.17427063], [75.40065002, 29.18890953], [75.39985657, 29.20148277], [75.39646149, 29.21342087], [75.39229584, 29.21807098], [75.38611603, 29.2212429], [75.38729858, 29.22904015], [75.3936615, 29.23423958], [75.39936829, 29.24027061], [75.39968109, 29.24677849], [75.39868927, 29.25498962], [75.39570618, 29.26194], [75.3879776, 29.2643528], [75.37954712, 29.26393127], [75.37246704, 29.26003075], [75.35797882, 29.25461006], [75.35016632, 29.24738121], [75.34719849, 29.23011971], [75.3453064, 29.22616005], [75.33454132, 29.22883034], [75.31492615, 29.23596001], [75.32318115, 29.25175095], [75.32537079, 29.27831078], [75.32424927, 29.29018974], [75.31926727, 29.29343987], [75.30857849, 29.28891754], [75.29969025, 29.28198051], [75.28968811, 29.27770042], [75.27937317, 29.27682114], [75.27671814, 29.27345085], [75.27172852, 29.25436974], [75.24946594, 29.25646019], [75.23522949, 29.25193977], [75.22345734, 29.23495102], [75.21195984, 29.2345295], [75.1953125, 29.24422073], [75.18850708, 29.25863075], [75.17999268, 29.26861954], [75.16401672, 29.2643795], [75.16082001, 29.25374985], [75.1474762, 29.24584961], [75.12467194, 29.24496078], [75.11374664, 29.24290085], [75.10817719, 29.2267704], [75.09250641, 29.22911263], [75.07807922, 29.23245049], [75.06270599, 29.23892021], [75.06532288, 29.24661064], [75.06062317, 29.25331116], [75.05094147, 29.26371193], [75.05066681, 29.26888084], [75.05047607, 29.2723999], [75.03991699, 29.28714943], [75.02385712, 29.29153061], [75.005867, 29.28380966], [74.99104309, 29.2717495], [74.98291779, 29.27826118], [74.97690582, 29.28111839], [74.96806335, 29.28244019], [74.95996094, 29.28015137], [74.95310974, 29.28194046], [74.94753265, 29.28815842], [74.94256592, 29.29518127], [74.94010925, 29.30481911], [74.94584656, 29.31102753], [74.95056915, 29.31851006], [74.95096588, 29.32607079], [74.94608307, 29.33280945], [74.93592072, 29.33794975], [74.92714691, 29.36463928], [74.92196655, 29.36603165], [74.91021729, 29.37115288], [74.89907074, 29.3782196], [74.89530945, 29.3841095], [74.88848114, 29.38667107], [74.87058258, 29.38511276], [74.86656952, 29.38846016], [74.86393738, 29.39635086], [74.85719299, 29.39937019], [74.84951782, 29.40279007], [74.84113312, 29.4040699], [74.8351059, 29.40147972], [74.80954742, 29.39847946], [74.79878235, 29.38465118], [74.78578186, 29.37054062], [74.77591705, 29.36015129], [74.75663757, 29.35596085], [74.73169708, 29.35378838], [74.72255707, 29.36084938], [74.71688843, 29.36635971], [74.71124268, 29.36890984], [74.68868256, 29.36515999], [74.67601776, 29.36817169], [74.65851593, 29.36997986], [74.650177, 29.37236977], [74.64370728, 29.35440063], [74.64412689, 29.33534813], [74.64182281, 29.33119965], [74.60603333, 29.3275795], [74.59577942, 29.32831192], [74.60003662, 29.35433006], [74.59671783, 29.36219025], [74.59053802, 29.37067032], [74.57978058, 29.37873077], [74.57289886, 29.38644981], [74.56909943, 29.39730072], [74.57003021, 29.40615845], [74.56439972, 29.41077995], [74.55780792, 29.4186306], [74.5521698, 29.42240143], [74.5411377, 29.42314911], [74.53129578, 29.42498016], [74.52955627, 29.43499947], [74.52910614, 29.44953918], [74.53074646, 29.45754814], [74.53462982, 29.46503258], [74.54280853, 29.4665699], [74.55037689, 29.46447945], [74.55947113, 29.46437073], [74.57170868, 29.46230125], [74.57891083, 29.45862007], [74.58042145, 29.46349907], [74.58553314, 29.4689827], [74.59156036, 29.47985077], [74.59030914, 29.48612976], [74.592659, 29.49212265], [74.60074615, 29.50354958], [74.60452271, 29.51044083], [74.61168671, 29.52000809], [74.61440277, 29.52711105], [74.61142731, 29.53149986], [74.5994873, 29.53686905], [74.59117889, 29.54342079], [74.58178711, 29.54768944], [74.57174683, 29.55558014], [74.56653595, 29.56349945], [74.57060242, 29.56854057], [74.57028198, 29.58591843], [74.57467651, 29.6144104], [74.57699585, 29.62082291], [74.57536316, 29.62732124], [74.58127594, 29.63054085], [74.58603668, 29.63525963], [74.58203888, 29.64406967], [74.57852173, 29.65475273], [74.58513641, 29.67502975], [74.59085083, 29.68272018], [74.59387207, 29.69143295], [74.59287262, 29.70071983], [74.59902954, 29.70621109], [74.60037994, 29.71310806], [74.60347748, 29.72142982], [74.60161591, 29.74066925], [74.60598755, 29.7466507], [74.60540009, 29.7528801], [74.59751129, 29.75797081], [74.59253693, 29.76671982], [74.5866394, 29.76851082], [74.57816315, 29.76696014], [74.57139587, 29.75324821], [74.56402588, 29.75461006], [74.54933167, 29.7548008], [74.53778839, 29.75386047], [74.53185272, 29.74934959], [74.52583313, 29.74136925], [74.51155853, 29.7406826], [74.49680328, 29.74182129], [74.48319244, 29.74403], [74.47200012, 29.74403], [74.46911621, 29.75823975], [74.46526337, 29.78754997], [74.4705658, 29.80200005], [74.48060608, 29.8152504], [74.4916687, 29.82650948], [74.50588989, 29.83258057], [74.53253174, 29.83928108], [74.54747009, 29.85692024], [74.55356598, 29.86564064], [74.55179596, 29.8735199], [74.54521942, 29.88072968], [74.54345703, 29.88871956], [74.53369141, 29.90262032], [74.5255127, 29.90256119], [74.51091003, 29.90429115], [74.50502777, 29.90776062], [74.51278687, 29.93003845], [74.51906586, 29.94334984], [74.52464294, 29.95156097], [74.53024292, 29.94497108], [74.54901886, 29.93316269], [74.55200195, 29.92922974], [74.56183624, 29.92930984], [74.57295227, 29.92588806], [74.58084869, 29.91830254], [74.58580017, 29.91476059], [74.62201691, 29.90777969], [74.62638855, 29.90600967], [74.63263702, 29.90566254], [74.63963318, 29.90394974], [74.64697266, 29.90467072], [74.63886261, 29.91444969], [74.63986206, 29.92249107], [74.64892578, 29.93092918], [74.66570282, 29.94169044], [74.68096161, 29.94919014], [74.68319702, 29.96107292], [74.69078827, 29.96927071], [74.69550323, 29.97153091], [74.69737244, 29.97114944], [74.70613861, 29.96887016], [74.72400665, 29.96186066], [74.73723602, 29.96904945], [74.75071716, 29.97122955], [74.75868225, 29.97363091], [74.76737213, 29.9727211], [74.77599335, 29.97439957], [74.78421783, 29.98042107], [74.79440308, 29.98961067], [74.80117798, 29.99257278], [74.80902863, 29.99047089], [74.81668091, 29.98451996], [74.81968689, 29.97945976], [74.82138824, 29.97305107], [74.82898712, 29.96947098], [74.83660889, 29.96416092], [74.84963226, 29.95912933], [74.85935974, 29.9611702], [74.86566162, 29.95889091], [74.87195587, 29.95912933], [74.87741089, 29.96256828], [74.88149261, 29.96834946], [74.88543701, 29.9623394], [74.88976288, 29.95903015], [74.89435577, 29.95293999], [74.89309692, 29.9472599], [74.88960266, 29.94501114], [74.88523865, 29.9391098], [74.89437866, 29.93944168], [74.91573334, 29.94915962], [74.92408752, 29.94153023], [74.9285965, 29.92916107], [74.93192291, 29.92277908], [74.93566895, 29.9154129], [74.94317627, 29.9025383], [74.95786285, 29.89773941], [74.96988678, 29.88992119], [74.96946716, 29.88067055], [74.9899292, 29.85646057], [74.99411011, 29.86320114], [75.00566101, 29.86757088], [75.01412964, 29.86462975], [75.02348328, 29.87286949], [75.03749847, 29.88178062], [75.05175781, 29.87486076], [75.06040192, 29.87611961], [75.06548309, 29.87903976], [75.07000732, 29.8933506], [75.0777359, 29.91230965], [75.08480072, 29.91514015], [75.08978271, 29.91171074], [75.09475708, 29.90507126], [75.10267639, 29.89702034], [75.10309601, 29.87677956], [75.1042099, 29.87319183], [75.10058594, 29.8678894], [75.08468628, 29.85859108], [75.08098602, 29.85414124], [75.08125305, 29.84937286], [75.08574677, 29.84481049], [75.09895325, 29.84142113], [75.10408783, 29.83801079], [75.1071167, 29.82653046], [75.09333801, 29.81931114], [75.08905029, 29.81282997], [75.09017944, 29.80666161], [75.09552765, 29.8043499], [75.10228729, 29.80255127], [75.12491608, 29.80562019], [75.13141632, 29.78486061], [75.1354599, 29.78038025], [75.141716, 29.77700806], [75.15405273, 29.78101921], [75.15918732, 29.78421974], [75.15486145, 29.78910065], [75.14951324, 29.79164124], [75.14894867, 29.79611969], [75.15130615, 29.80183983], [75.15542603, 29.81981087], [75.15995789, 29.82364082], [75.16699982, 29.82495117], [75.1751709, 29.82951927], [75.17603302, 29.83506966], [75.17855835, 29.83690834], [75.18234253, 29.83870125], [75.18860626, 29.83457947], [75.20091248, 29.82999992], [75.20250702, 29.8213501], [75.19777679, 29.81344032], [75.19645691, 29.80511093], [75.1979599, 29.79622078], [75.20536041, 29.79000092], [75.21238708, 29.78652], [75.21617889, 29.7798996], [75.21673584, 29.77149963], [75.22328186, 29.76353836], [75.22733307, 29.75612068], [75.23097992, 29.75206757], [75.22136688, 29.73307037], [75.21660614, 29.72999001], [75.21067047, 29.73089027], [75.2061615, 29.73525047], [75.19809723, 29.73080063], [75.19368744, 29.72520065], [75.18724823, 29.71191978], [75.1884079, 29.70374107], [75.19243622, 29.69952965], [75.19766998, 29.69647026], [75.19528198, 29.6877594], [75.18888855, 29.68082809], [75.17986298, 29.67830276], [75.17531586, 29.67805099], [75.16783905, 29.67327118], [75.15892029, 29.66936111], [75.15783691, 29.66271019], [75.16275787, 29.65802956], [75.16854858, 29.65423012], [75.1733017, 29.64948082], [75.1724472, 29.63862991], [75.17333984, 29.63008118], [75.18473053, 29.62254143], [75.19937134, 29.6226902], [75.22123718, 29.60655022], [75.2232132, 29.5988903], [75.21936798, 29.59250259], [75.21118927, 29.58239937], [75.21788788, 29.57846069], [75.2217865, 29.57028008], [75.2281723, 29.55855751], [75.22432709, 29.55002975], [75.22348022, 29.54617119], [75.23806763, 29.55154037], [75.25453949, 29.55418015], [75.26748657, 29.55928993], [75.27503204, 29.56110954], [75.29064941, 29.56176186], [75.29606628, 29.5680809], [75.30304718, 29.57905006], [75.30486298, 29.58361053], [75.30451202, 29.58847809], [75.30203247, 29.59198952], [75.29361725, 29.59767151], [75.28034973, 29.6032505], [75.28056335, 29.61010933], [75.28785706, 29.61976814], [75.30105591, 29.62709045], [75.30753326, 29.63256073], [75.31169891, 29.64875984], [75.31623077, 29.66082191], [75.31772614, 29.67070007], [75.32260895, 29.67240906], [75.33014679, 29.67227936], [75.3414917, 29.66213036], [75.34680939, 29.65888977], [75.34850311, 29.65907097], [75.35044861, 29.65928078], [75.34932709, 29.66563988], [75.34603882, 29.67142105], [75.33384705, 29.68805122], [75.33535004, 29.69384956], [75.34121704, 29.69524002], [75.35269165, 29.70449066], [75.35855865, 29.70576096], [75.36194611, 29.71289063], [75.37003326, 29.71306038], [75.37877655, 29.7112999], [75.3835907, 29.72030258], [75.38218689, 29.72705841], [75.3837204, 29.7340107], [75.39087677, 29.73859978], [75.39679718, 29.74867058], [75.39723206, 29.76102066], [75.40999603, 29.77532005], [75.41976929, 29.77437973], [75.42720795, 29.77794075], [75.43463898, 29.78028107], [75.44378662, 29.7861805], [75.44315338, 29.79417038], [75.43547058, 29.79884911], [75.44426727, 29.80784988], [75.4983902, 29.77775002], [75.5063324, 29.77407074], [75.51171112, 29.76004982], [75.52397919, 29.76724052], [75.53019714, 29.7727108], [75.54418182, 29.77176094], [75.55639648, 29.7658329], [75.56308746, 29.74423981], [75.56878662, 29.74262047], [75.59274292, 29.74915123], [75.60048676, 29.74740028], [75.61322784, 29.74645805], [75.62261963, 29.75362015], [75.6235199, 29.76688957], [75.62535858, 29.7732296], [75.64087677, 29.77111053], [75.6496582, 29.77456093], [75.65638733, 29.7760601], [75.66616821, 29.77270126], [75.67830658, 29.75706291], [75.68743134, 29.75177956], [75.69744873, 29.75521088], [75.70593262, 29.80862045], [75.70987701, 29.81225967], [75.7259903, 29.81151962], [75.73272705, 29.81126022], [75.74839783, 29.81212044], [75.76059723, 29.81866074], [75.76342773, 29.82196045], [75.76698303, 29.82345009], [75.7716217, 29.82538986], [75.77243805, 29.82467079], [75.78320313, 29.81532097], [75.79605103, 29.80712128], [75.81997681, 29.8153801], [75.82901764, 29.81232071], [75.82927704, 29.80070114], [75.83338928, 29.79066086], [75.84124756, 29.78083992], [75.84362793, 29.77596092], [75.85459137, 29.76966095], [75.86377716, 29.75233078], [75.87201691, 29.75012016], [75.87928009, 29.74707031], [75.89068604, 29.75321007], [75.89723206, 29.7555294], [75.90313721, 29.74628258], [75.91394806, 29.73876953], [75.92314911, 29.73491096], [75.9289093, 29.73365021], [75.93401337, 29.7325325], [75.93662262, 29.73308182], [75.9386673, 29.73351288], [75.94235229, 29.73427963], [75.9500885, 29.73391151], [75.95748901, 29.73212051], [75.96485901, 29.73138046], [75.97045898, 29.73210907], [75.97254944, 29.73237038], [75.98000336, 29.73616982], [75.98927307, 29.74230957], [76.00382996, 29.75093079], [76.01127625, 29.75282097], [76.01759338, 29.75607109], [76.02424622, 29.75560188], [76.03170776, 29.7508812], [76.03292084, 29.74959946], [76.03565216, 29.74668121], [76.04148102, 29.7487812], [76.0584259, 29.77314949], [76.0632019, 29.7774601], [76.06990051, 29.77602005], [76.07434082, 29.78124046], [76.07543945, 29.78790092], [76.07557678, 29.79704857], [76.07766724, 29.80577278], [76.08605957, 29.80989838], [76.09056091, 29.81083107], [76.09438324, 29.81156158], [76.10321045, 29.80841064], [76.11026764, 29.80331993], [76.11638641, 29.79640007], [76.12140656, 29.7994709], [76.12718201, 29.80542946], [76.13210297, 29.81205177], [76.13926697, 29.81676292], [76.15312958, 29.81627274], [76.16665649, 29.81832123], [76.18582153, 29.83123016], [76.18936157, 29.84047127], [76.19418335, 29.8449707], [76.2022171, 29.84530067], [76.20964813, 29.84274292], [76.21111298, 29.8432312], [76.20965576, 29.8501606], [76.21176147, 29.85314941], [76.21582794, 29.85470963], [76.22290039, 29.85559082], [76.22852325, 29.85452843], [76.2318573, 29.85637093], [76.23522949, 29.85980988], [76.23795319, 29.86545944], [76.24201202, 29.86902809], [76.23869324, 29.87590027], [76.23245239, 29.88132095], [76.22529602, 29.88506126], [76.21694946, 29.88385963], [76.20812988, 29.88651085], [76.19740295, 29.88401985], [76.18463898, 29.88858032], [76.18270874, 29.89388084], [76.18358612, 29.91571808], [76.18199158, 29.92324066], [76.1714859, 29.92323112], [76.16629028, 29.92865944], [76.1696167, 29.93655968], [76.1789093, 29.94626808], [76.18480682, 29.94627953], [76.19087219, 29.94445992], [76.20387268, 29.94412041], [76.2050705, 29.94750023], [76.20345306, 29.95206833], [76.19473267, 29.96567917], [76.19901276, 29.97317123], [76.19748688, 29.97981071], [76.19713593, 29.98511124], [76.19577789, 29.9904995], [76.19303131, 29.99662018], [76.18937683, 30.00419044], [76.1896286, 30.00632286], [76.18981171, 30.00838089], [76.18998718, 30.01044846], [76.19020844, 30.01249123], [76.19050598, 30.01449013], [76.19091797, 30.01641273], [76.19156647, 30.01823044], [76.19346619, 30.01938057], [76.19581604, 30.02006149], [76.19803619, 30.02052116], [76.2003479, 30.02085114], [76.20263672, 30.02120018], [76.20490265, 30.02166939], [76.20720673, 30.02211952], [76.20947266, 30.02272987], [76.21140289, 30.02373123], [76.21354675, 30.02530861], [76.21543884, 30.02713013], [76.21613312, 30.0286808], [76.21514893, 30.0296402], [76.21333313, 30.03035164], [76.21098328, 30.03092957], [76.20838928, 30.03144836], [76.20580292, 30.03203011], [76.20345306, 30.03273964], [76.20111847, 30.03367233], [76.19890594, 30.03482819], [76.19793701, 30.03625107], [76.19838715, 30.03792953], [76.19962311, 30.03977966], [76.20111084, 30.04164124], [76.20252991, 30.04331017], [76.20404053, 30.04483986], [76.2056427, 30.04628944], [76.20723724, 30.04779053], [76.20864105, 30.04939079], [76.20987701, 30.05106926], [76.21102905, 30.05282021], [76.2121582, 30.05458832], [76.21330261, 30.05633163], [76.2144928, 30.05808067], [76.21566772, 30.05981064], [76.21681976, 30.06155014], [76.21798706, 30.06329918], [76.21916199, 30.06502914], [76.22035217, 30.06674957], [76.2215271, 30.06848907], [76.22273254, 30.0702076], [76.22395325, 30.07194138], [76.22509766, 30.07366943], [76.22632599, 30.0753994], [76.22749329, 30.07713127], [76.22869873, 30.07886124], [76.22991943, 30.08056831], [76.23116302, 30.08226013], [76.23246002, 30.08394051], [76.23381042, 30.08558083], [76.2351532, 30.08719826], [76.23660278, 30.08884811], [76.23808289, 30.09046173], [76.23963165, 30.09203911], [76.24120331, 30.09353065], [76.242836, 30.09490967], [76.24455261, 30.09614944], [76.24672699, 30.09638977], [76.2492218, 30.09603119], [76.25093079, 30.09706116], [76.25237274, 30.0986824], [76.25358582, 30.10053062], [76.2545929, 30.10239983], [76.25499725, 30.10457993], [76.25377655, 30.10602951], [76.2517395, 30.1067028], [76.2494812, 30.1072197], [76.2470932, 30.10762024], [76.24469757, 30.10792923], [76.24238586, 30.10819054], [76.24006653, 30.10827827], [76.23771667, 30.10823059], [76.23539734, 30.108181], [76.233078, 30.10822105], [76.23082733, 30.10852051], [76.2286911, 30.10933113], [76.22667694, 30.11040115], [76.2248764, 30.11165047], [76.22316742, 30.11301994], [76.22123718, 30.11412048], [76.21920013, 30.11512184], [76.2171402, 30.11610985], [76.21518707, 30.11717987], [76.21343994, 30.11845016], [76.21193695, 30.11996269], [76.21058655, 30.12161064], [76.20928955, 30.12330055], [76.20791626, 30.12495995], [76.20639801, 30.12648964], [76.20471191, 30.12786102], [76.20262909, 30.12865829], [76.20038605, 30.12930107], [76.19837189, 30.13025093], [76.19632721, 30.13126945], [76.1943512, 30.13235092], [76.19249725, 30.13351059], [76.19061279, 30.13496017], [76.18962097, 30.13669014], [76.19055176, 30.13862991], [76.19230652, 30.14045906], [76.19410706, 30.1407795], [76.19590759, 30.13999176], [76.19777679, 30.13870049], [76.19969177, 30.13721085], [76.20162964, 30.13582993], [76.20365143, 30.13473129], [76.20580292, 30.13376045], [76.20794678, 30.13314819], [76.21008301, 30.13360977], [76.21192932, 30.13506126], [76.21266174, 30.13683128], [76.21156311, 30.1384716], [76.2100296, 30.1400795], [76.20851898, 30.14172173], [76.20744324, 30.14348984], [76.20706177, 30.14550018], [76.20632172, 30.14740944], [76.20511627, 30.14924049], [76.20375824, 30.15103912], [76.20259857, 30.15281105], [76.20195007, 30.15457153], [76.20236206, 30.15671158], [76.20387268, 30.15890121], [76.20558929, 30.15934944], [76.20720673, 30.15851021], [76.20884705, 30.15739059], [76.21053314, 30.15607834], [76.21224976, 30.15460968], [76.21395111, 30.1530304], [76.21565247, 30.15139008], [76.2173233, 30.1497612], [76.21897888, 30.14817047], [76.2205658, 30.14668083], [76.22202301, 30.14509964], [76.22336578, 30.14343834], [76.2247467, 30.14180946], [76.22628784, 30.14031029], [76.2280426, 30.1390419], [76.22997284, 30.1378994], [76.23191833, 30.13677979], [76.23375702, 30.13556862], [76.23539734, 30.13414955], [76.23680115, 30.13255119], [76.23816681, 30.13091087], [76.24095917, 30.12865829], [76.24299622, 30.12746811], [76.24458313, 30.1218605], [76.25115967, 30.11899948], [76.26551056, 30.11769295], [76.27202606, 30.11433983], [76.27984619, 30.11365128], [76.28636169, 30.11682129], [76.29308319, 30.11862946], [76.31275177, 30.10851288], [76.32289886, 30.10822105], [76.32837677, 30.10951042], [76.33790588, 30.11585045], [76.34892273, 30.12766075], [76.34829712, 30.13166046], [76.33570862, 30.13926125], [76.3286972, 30.14476967], [76.32588196, 30.14924049], [76.34306335, 30.1534481], [76.3483429, 30.15052032], [76.35816193, 30.13330269], [76.36374664, 30.12754059], [76.37471771, 30.12372971], [76.3843689, 30.1238327], [76.39000702, 30.12754059], [76.38845062, 30.13396835], [76.38832855, 30.13832855], [76.38456726, 30.14581108], [76.3861618, 30.14824104], [76.39251709, 30.15026093], [76.39951324, 30.15517044], [76.40164185, 30.1577282], [76.38861847, 30.17410088], [76.38304138, 30.17902946], [76.3809967, 30.18324089], [76.38674164, 30.18699074], [76.39100647, 30.19225121], [76.39884186, 30.1989994], [76.41020203, 30.20228958], [76.4200058, 30.19787979], [76.42858124, 30.1797924], [76.42900848, 30.1729908], [76.42642975, 30.16757965], [76.42243195, 30.16357994], [76.42227173, 30.15870094], [76.42488861, 30.15462112], [76.42604065, 30.14756012], [76.43135071, 30.14071083], [76.43631744, 30.13702965], [76.44104004, 30.13595963], [76.44645691, 30.1371212], [76.44618988, 30.12895966], [76.4444809, 30.12288094], [76.44664001, 30.11123085], [76.44909668, 30.10480118], [76.4520874, 30.10070992], [76.46157074, 30.09900093], [76.48348999, 30.09955978], [76.49082947, 30.0971508], [76.49517059, 30.09238815], [76.49501038, 30.08708191], [76.49713898, 30.08156967], [76.50112152, 30.07662964], [76.50894165, 30.07953072], [76.52554321, 30.0808506], [76.533638, 30.08278084], [76.55487061, 30.0987606], [76.55916595, 30.09804916], [76.56143951, 30.09763908], [76.56363678, 30.09711075], [76.56575012, 30.09626007], [76.56767273, 30.09511948], [76.5694809, 30.0938797], [76.57124329, 30.09255981], [76.57301331, 30.09123993], [76.57478333, 30.08995819], [76.57663727, 30.08876038], [76.57879639, 30.08784294], [76.58080292, 30.08685112], [76.5819397, 30.08521271], [76.58194733, 30.08312988], [76.58104706, 30.08127975], [76.57977295, 30.07953072], [76.57787323, 30.07771111], [76.57637787, 30.07611084], [76.57676697, 30.07509995], [76.57917023, 30.07459068], [76.58194733, 30.07467079], [76.58399963, 30.07543945], [76.58583069, 30.07674026], [76.58763885, 30.07814026], [76.58953094, 30.07929993], [76.59168243, 30.07974052], [76.59406281, 30.0795517], [76.59642029, 30.07947159], [76.59877777, 30.07970047], [76.60105133, 30.08023071], [76.60286713, 30.08131981], [76.6044693, 30.08272171], [76.60595703, 30.08428955], [76.60742188, 30.08589935], [76.60896301, 30.08745956], [76.61061096, 30.08886909], [76.61235046, 30.09020996], [76.61411285, 30.09150124], [76.6158905, 30.09278107], [76.61769867, 30.09406281], [76.61947632, 30.09536171], [76.62515259, 30.10184097], [76.62667084, 30.10564995], [76.62755585, 30.11048126], [76.62663269, 30.11396027], [76.62474823, 30.11688995], [76.62520599, 30.12103081], [76.62872314, 30.13019943], [76.62940216, 30.13476944], [76.62309265, 30.14466095], [76.62326813, 30.14940262], [76.62763977, 30.1551075], [76.6227417, 30.17029953], [76.63925171, 30.18521118], [76.641716, 30.18925095], [76.64198303, 30.19366837], [76.63716888, 30.19695091], [76.63891602, 30.20594025], [76.63282013, 30.21001053], [76.61675262, 30.21105957], [76.60941315, 30.21277046], [76.60427856, 30.21517181], [76.60627747, 30.22001076], [76.61186981, 30.22562981], [76.61199951, 30.23096848], [76.60930634, 30.23488045], [76.59942627, 30.24032974], [76.59590912, 30.24394035], [76.59031677, 30.25412178], [76.58399963, 30.25653076], [76.57588959, 30.25586128], [76.56904602, 30.2513504], [76.54766846, 30.23444176], [76.54438019, 30.23085976], [76.53253174, 30.22713089], [76.53292084, 30.23207855], [76.54219818, 30.23637962], [76.5459671, 30.24353981], [76.54692841, 30.24953079], [76.54582214, 30.25863075], [76.54763794, 30.26492119], [76.55792999, 30.26426125], [76.58094025, 30.26987076], [76.60449982, 30.27226067], [76.6098175, 30.27061081], [76.61437988, 30.27527046], [76.61969757, 30.28784943], [76.62283325, 30.29138947], [76.626297, 30.28392982], [76.65128326, 30.2993412], [76.66242981, 30.29955101], [76.67307281, 30.31277084], [76.67088318, 30.31917], [76.67462921, 30.32595062], [76.67949677, 30.32137108], [76.68846893, 30.32598114], [76.69767761, 30.32485771], [76.70025635, 30.32985115], [76.70475006, 30.33168983], [76.71096039, 30.32987022], [76.71515656, 30.33291054], [76.71515656, 30.33990097], [76.72392273, 30.34436989], [76.72901154, 30.34843254], [76.73462677, 30.35393906], [76.73853302, 30.35964966], [76.73501587, 30.36491013], [76.73039246, 30.36744118], [76.71135712, 30.36512947], [76.7089386, 30.36816978], [76.71808624, 30.37710953], [76.71572113, 30.38026047], [76.70487976, 30.38083267], [76.70168304, 30.38482857], [76.70014954, 30.39361191], [76.71289063, 30.39824295], [76.72654724, 30.40500069], [76.72516632, 30.42041969], [76.73786163, 30.42486954], [76.74887085, 30.42663193], [76.7543869, 30.43280983], [76.75786591, 30.43889046], [76.76332855, 30.43972969], [76.76674652, 30.43600082], [76.764328, 30.42501068], [76.77082062, 30.41830063], [76.78069305, 30.4150219], [76.79728699, 30.41512108], [76.80845642, 30.41185951], [76.82314301, 30.42254829], [76.82789612, 30.43033028], [76.8324585, 30.43388176], [76.83972931, 30.42074966], [76.84726715, 30.41489983], [76.86473083, 30.40879059], [76.86756134, 30.40151978], [76.86624146, 30.3948307], [76.87441254, 30.39128113], [76.88022614, 30.38622284], [76.88043213, 30.38298988], [76.87571716, 30.36954117], [76.87644196, 30.36333847], [76.88022614, 30.35970116], [76.88722229, 30.35838127], [76.89227295, 30.35967827], [76.89776611, 30.36260033], [76.90348816, 30.36750984], [76.91699219, 30.38275909], [76.92077637, 30.38478279], [76.9272995, 30.38863945], [76.93026733, 30.39258957], [76.93139648, 30.39707184], [76.92904663, 30.3998909], [76.92579651, 30.40159035], [76.91947174, 30.4030304], [76.90925598, 30.40327072], [76.90518188, 30.40468979], [76.90384674, 30.40670967], [76.90392303, 30.40995026], [76.90524292, 30.41319084], [76.90370178, 30.41823006], [76.90370941, 30.42488098], [76.90167999, 30.42832947], [76.88993073, 30.43669128], [76.88884735, 30.44111061], [76.89071655, 30.45106125], [76.89518738, 30.45556831], [76.8980484, 30.46778107], [76.89663696, 30.47537994], [76.8898468, 30.47932816], [76.88891602, 30.48458862], [76.89385986, 30.48964119], [76.90114594, 30.48884964], [76.9078064, 30.49078941], [76.91236877, 30.49365997], [76.91590881, 30.49942017], [76.91828918, 30.50723076], [76.92032623, 30.51802063], [76.92006683, 30.52469063], [76.91429901, 30.52655029], [76.90724945, 30.5298996], [76.89821625, 30.53470039], [76.88775635, 30.53815079], [76.88504028, 30.54042053], [76.89218903, 30.54444122], [76.90223694, 30.55104065], [76.90592957, 30.55838966], [76.90384674, 30.56171989], [76.89888763, 30.56402969], [76.89888763, 30.56671906], [76.90390778, 30.57518005], [76.90453339, 30.58057022], [76.89855957, 30.5884304], [76.9072113, 30.59140968], [76.91342926, 30.59970284], [76.91060638, 30.60582924], [76.90154266, 30.60840988], [76.89959717, 30.62002945], [76.89453888, 30.62333107], [76.88360596, 30.62709045], [76.88063049, 30.6330719], [76.87709045, 30.63702011], [76.87267303, 30.64002037], [76.86795807, 30.64163971], [76.86194611, 30.64027023], [76.85858154, 30.64063072], [76.85897064, 30.65155983], [76.86186218, 30.65971947], [76.86310577, 30.6715107], [76.86222839, 30.6792717], [76.85540771, 30.67320251], [76.84983826, 30.66485977], [76.83985901, 30.65678024], [76.83479309, 30.65582085], [76.83499908, 30.66411018], [76.83006287, 30.66493034], [76.82694244, 30.66333008], [76.82409668, 30.66007042], [76.81881714, 30.66059113], [76.818367, 30.67296028], [76.81980896, 30.68582916], [76.81770325, 30.69062996], [76.82110596, 30.69678116], [76.82829285, 30.70594978], [76.83629608, 30.71426964], [76.8343811, 30.72439957], [76.82480621, 30.7308197], [76.82274628, 30.74008179], [76.82818604, 30.76379013], [76.83081818, 30.76793289], [76.8467865, 30.79252052], [76.84134674, 30.79908943], [76.83351135, 30.80457115], [76.83335876, 30.81589127], [76.83209991, 30.82542038], [76.82775116, 30.83256912], [76.81894684, 30.83710098], [76.8065567, 30.84025192], [76.80121613, 30.84252167], [76.78494263, 30.8612709], [76.77333832, 30.87115097], [76.76904297, 30.87652969], [76.76254272, 30.89340973], [76.76985931, 30.90639114], [76.79876709, 30.92464066], [76.81018829, 30.93037987], [76.81339264, 30.92732048], [76.8143692, 30.92134094], [76.80979919, 30.90680122], [76.81575775, 30.89600945], [76.82266235, 30.88809967], [76.83715057, 30.87887192], [76.85243225, 30.87068939], [76.86178589, 30.87355042], [76.86962891, 30.87816048], [76.87858582, 30.88598251], [76.8865509, 30.88829994], [76.90216064, 30.89722824], [76.90706635, 30.89099121], [76.91584015, 30.86932945], [76.92661285, 30.85444069], [76.92780304, 30.84814072], [76.92751312, 30.83735275], [76.93370056, 30.83196259], [76.94283295, 30.8291893], [76.94764709, 30.82316971], [76.95375061, 30.81121063], [76.96180725, 30.80899048], [76.96864319, 30.80796051], [76.97910309, 30.79881287], [76.98264313, 30.80430031], [76.98477173, 30.81047249], [76.98652649, 30.81324959], [76.98845673, 30.81500053], [76.99266052, 30.81830025], [76.99584198, 30.81670952], [76.99796295, 30.814291], [76.9985199, 30.80973053], [76.9997406, 30.80490112], [77.00035095, 30.79762268], [76.99973297, 30.79397964], [77.00003052, 30.78902054], [76.99487305, 30.78507042], [76.99095917, 30.78065109], [76.98860168, 30.777071], [76.99121094, 30.77345276], [76.99524689, 30.77103996], [76.9988327, 30.76915169], [77.002388, 30.76795006], [77.0044632, 30.76634979], [77.00582123, 30.76175117], [77.00466156, 30.75735283], [77.00470734, 30.75248909], [77.00644684, 30.74950981], [77.00939178, 30.74571037], [77.01309967, 30.74220848], [77.01805115, 30.74044991], [77.02401733, 30.74162102], [77.02828979, 30.74344063], [77.03037262, 30.7463398], [77.03032684, 30.75176048], [77.03370667, 30.75542068], [77.03801727, 30.7531395], [77.04705811, 30.74867058], [77.05497742, 30.74674034], [77.06170654, 30.74612808], [77.06971741, 30.74698257], [77.07684326, 30.74476051], [77.08627319, 30.73994255], [77.09111786, 30.73621178], [77.09613037, 30.73462105], [77.10056305, 30.73238754], [77.10234833, 30.73077965], [77.1002121, 30.72639084], [77.09990692, 30.7222805], [77.1031723, 30.72044945], [77.10957336, 30.72268295], [77.1174469, 30.71791077], [77.12223816, 30.71216011], [77.12512207, 30.70709991], [77.13381958, 30.70215988], [77.14037323, 30.6975708], [77.14743805, 30.69347954], [77.15177155, 30.6905098], [77.15352631, 30.6887207], [77.15020752, 30.68455124], [77.15068817, 30.68119812], [77.153862, 30.67694283], [77.15519714, 30.6680603], [77.1526413, 30.65876007], [77.15273285, 30.6541996], [77.15619659, 30.64792061], [77.16044617, 30.64240074], [77.16236115, 30.63865089], [77.15986633, 30.63148117], [77.15863037, 30.61380959], [77.15847778, 30.60746002], [77.158638, 30.60314178], [77.15748596, 30.59955025], [77.15409851, 30.59632111], [77.15122223, 30.59283066], [77.14692688, 30.58896065], [77.1398468, 30.58320045], [77.1326828, 30.57845116], [77.12587738, 30.57369041], [77.12378693, 30.57269287], [77.12059021, 30.57118034], [77.11514282, 30.56984138], [77.11289215, 30.56824112], [77.11149597, 30.56728935], [77.11370087, 30.56244087], [77.11650848, 30.5574398], [77.12233734, 30.54823112], [77.13105774, 30.54150963], [77.13758087, 30.53857994], [77.14553833, 30.53779984], [77.15203857, 30.53691292], [77.16368866, 30.53412056], [77.16953278, 30.53288078], [77.17455292, 30.53051949], [77.18534851, 30.52588081], [77.19082642, 30.51932907], [77.19589233, 30.51177025], [77.19966125, 30.50659943], [77.19957733, 30.49913979], [77.20030975, 30.48904991], [77.19904327, 30.48454285], [77.2026062, 30.48034096], [77.21190643, 30.48187065], [77.21885681, 30.48598289], [77.22676849, 30.48861122], [77.23345947, 30.48747063], [77.24186707, 30.4853611], [77.25177765, 30.48441124], [77.2565918, 30.48142052], [77.26084137, 30.47612], [77.26193237, 30.47104073], [77.26358032, 30.46667099], [77.27455902, 30.46404076], [77.28244019, 30.46191978], [77.29373932, 30.45913124], [77.30069733, 30.45659828], [77.31069946, 30.45362091], [77.31677246, 30.45762062], [77.3223877, 30.46211815], [77.3262558, 30.46318245], [77.33267975, 30.46422958], [77.33937836, 30.46360016], [77.34607697, 30.46190071], [77.34970093, 30.45728111], [77.35349274, 30.44856071], [77.35679626, 30.44206047], [77.36965179, 30.44584274], [77.37621307, 30.44625092], [77.38038635, 30.44614029], [77.38186646, 30.43927193], [77.39409637, 30.43427086], [77.39679718, 30.43046951], [77.39546204, 30.4209404], [77.40061188, 30.41875076], [77.40763855, 30.42788124], [77.41723633, 30.4338398], [77.42620087, 30.44111824], [77.43559265, 30.45100975], [77.44568634, 30.46566963], [77.45053864, 30.46523094], [77.4562912, 30.45819092], [77.45677185, 30.45155907], [77.45429993, 30.44606018], [77.45334625, 30.44036102], [77.44204712, 30.42988968], [77.43972015, 30.42440033], [77.42569733, 30.42000008], [77.42092896, 30.41682243], [77.41590118, 30.41283035], [77.41644287, 30.40839195], [77.43041229, 30.40747833], [77.43495178, 30.40367126], [77.44301605, 30.40460014], [77.45311737, 30.40480042], [77.46098328, 30.40538025], [77.4679718, 30.4117794], [77.47751617, 30.41334915], [77.4825592, 30.41521835], [77.48683167, 30.41261292], [77.49134827, 30.41735077], [77.49118805, 30.42498016], [77.49294281, 30.43304825], [77.50115204, 30.44367981], [77.50534058, 30.44836044], [77.50984955, 30.44882965], [77.51436615, 30.43942261], [77.51803589, 30.43087006], [77.52577209, 30.41714096], [77.52925873, 30.41350174], [77.5356369, 30.40905952], [77.53874207, 30.40191269], [77.54289246, 30.39723015], [77.5524826, 30.39336014], [77.55792236, 30.39036942], [77.56534576, 30.3848896], [77.57489014, 30.38451958], [77.58444214, 30.38136101], [77.59012604, 30.37726021], [77.59201813, 30.37086105], [77.58278656, 30.35843849], [77.57463074, 30.34695053], [77.56989288, 30.33711052], [77.57009888, 30.3315506], [77.57501221, 30.32607079], [77.5738678, 30.3189106], [77.57035065, 30.31122971], [77.56355286, 30.30608177], [77.55577087, 30.30257034], [77.5453186, 30.29413986], [77.54042053, 30.29096985], [77.53218079, 30.2868576], [77.52677917, 30.28231239], [77.52468109, 30.2779808], [77.52250671, 30.26619911], [77.51983643, 30.26013184], [77.50550842, 30.24224091], [77.49598694, 30.23363113], [77.49372101, 30.2274704], [77.48853302, 30.21874046], [77.48390198, 30.2100811], [77.47997284, 30.20215988], [77.47677612, 30.19501114], [77.4732666, 30.188591], [77.46021271, 30.1837883], [77.45598602, 30.18096161], [77.45153809, 30.17362976], [77.44684601, 30.16860962], [77.44033813, 30.16920853], [77.43517303, 30.16995811], [77.43061066, 30.16642952], [77.42354584, 30.16847992], [77.41532135, 30.1566906], [77.41142273, 30.14969063], [77.41082764, 30.14587975], [77.41490173, 30.1434803], [77.41783905, 30.14118195], [77.41552734, 30.13349915], [77.41261292, 30.12771034], [77.40865326, 30.12320137], [77.40326691, 30.12105942], [77.39800262, 30.11872292], [77.40061188, 30.11326027], [77.40603638, 30.11130905], [77.41008759, 30.11108971], [77.4141922, 30.11111069], [77.41442871, 30.10713005], [77.40857697, 30.10255241], [77.39673615, 30.09576035], [77.39245605, 30.09441185], [77.38034058, 30.09304047], [77.37342834, 30.09301949], [77.36849976, 30.09155846], [77.35697937, 30.08415031], [77.34842682, 30.0766983], [77.33716583, 30.06824112], [77.33174133, 30.06445122], [77.32480621, 30.06180191], [77.31291199, 30.06053925], [77.30290985, 30.06058121], [77.29759216, 30.0603199], [77.29184723, 30.05849075], [77.28610992, 30.0574894], [77.2804184, 30.05251122], [77.27625275, 30.05047035], [77.27040863, 30.04833984], [77.2698822, 30.04422951], [77.27176666, 30.03991127], [77.27313995, 30.03404045], [77.26969147, 30.02746964], [77.26759338, 30.02210999], [77.26544189, 30.01803017], [77.26434326, 30.01305962], [77.26191711, 30.0073204], [77.26154327, 30.00561905], [77.26316071, 30.00214958], [77.25512695, 29.99596977], [77.25476074, 29.99316025], [77.25047302, 29.988451], [77.23548126, 29.98117256], [77.23310852, 29.97363091], [77.23194885, 29.96632195], [77.22957611, 29.96190262], [77.22489929, 29.95858955], [77.22373962, 29.95475006], [77.21112823, 29.94071007], [77.20256805, 29.9310894], [77.1955719, 29.92727089], [77.18913269, 29.92204285], [77.18689728, 29.91748047], [77.18591309, 29.91305161], [77.18016815, 29.90621185], [77.1795578, 29.90226936], [77.1848526, 29.89490128], [77.18496704, 29.89030838], [77.18229675, 29.88158989], [77.18245697, 29.87327957], [77.18006134, 29.86914063], [77.17810822, 29.86215973], [77.16758728, 29.84638977], [77.16703796, 29.84370995], [77.16903687, 29.82958031], [77.16526794, 29.82448959], [77.15564728, 29.81678963], [77.15396881, 29.81378174], [77.15209961, 29.80766106], [77.15171814, 29.80347061], [77.15400696, 29.79768944], [77.1523819, 29.79327965], [77.14222717, 29.78757095], [77.13743591, 29.78220177], [77.13199615, 29.77898026], [77.12349701, 29.7778492], [77.11828613, 29.77555084], [77.11704254, 29.77090073], [77.11889648, 29.76422119], [77.11785889, 29.76043129], [77.11421967, 29.75429153], [77.11295319, 29.74860001], [77.11515808, 29.74496078], [77.12256622, 29.74282074], [77.12255859, 29.73603821], [77.14021301, 29.7172718], [77.14332581, 29.70597076], [77.14260101, 29.70163918], [77.13987732, 29.70022964], [77.13218689, 29.69948006], [77.12552643, 29.69691086], [77.12110138, 29.69156075], [77.11917114, 29.68584061], [77.11997986, 29.6802597], [77.13114166, 29.66634941], [77.13130188, 29.66299057], [77.12941742, 29.65859032], [77.12180328, 29.65353966], [77.10970306, 29.64723969], [77.10782623, 29.63996124], [77.10489655, 29.63557816], [77.10106659, 29.63307953], [77.10160065, 29.62491989], [77.10047913, 29.62227249], [77.0945282, 29.61776924], [77.09388733, 29.61297035], [77.09218597, 29.60867119], [77.08561707, 29.60079956], [77.08680725, 29.59646988], [77.08989716, 29.59043121], [77.09378052, 29.5872097], [77.10198212, 29.57699966], [77.10675812, 29.56636047], [77.10971832, 29.55298996], [77.10443115, 29.54891014], [77.09529877, 29.54764938], [77.0894165, 29.54469109], [77.08622742, 29.53949928], [77.08490753, 29.53359032], [77.08648682, 29.52826118], [77.09761047, 29.51201248], [77.10340881, 29.50954056], [77.11451721, 29.50315857], [77.11989594, 29.49732971], [77.12332153, 29.4860611], [77.12039185, 29.48006058], [77.115448, 29.47540283], [77.1140213, 29.47029114], [77.11429596, 29.46186066], [77.117836, 29.45646095], [77.12413788, 29.45294189], [77.1319809, 29.45049095], [77.13774872, 29.44659042], [77.13938904, 29.44210052], [77.13845062, 29.43686295], [77.13577271, 29.43222046], [77.12487793, 29.42217064], [77.12586975, 29.41064072], [77.12908936, 29.40249062], [77.133461, 29.39843941], [77.14006805, 29.39472008], [77.14597321, 29.39248085], [77.14679718, 29.38977051], [77.13864899, 29.38390923], [77.13105011, 29.38070107], [77.12046814, 29.37877083], [77.11694336, 29.37668037], [77.11669922, 29.37257957], [77.11884308, 29.36195946], [77.11752319, 29.35715103], [77.12003326, 29.34979057], [77.12368774, 29.34498978], [77.12757874, 29.34433937], [77.14644623, 29.34506035], [77.1518631, 29.33929062], [77.15394592, 29.33547974], [77.15001678, 29.33169174], [77.15104675, 29.32551956], [77.1536026, 29.3222599], [77.15421295, 29.31692123], [77.1423111, 29.30151176], [77.14437103, 29.2961998], [77.13761902, 29.28746986], [77.12948608, 29.27279091], [77.13498688, 29.26649284], [77.14247894, 29.25160027], [77.14402008, 29.24333191], [77.14279938, 29.23779106], [77.12722015, 29.22814178], [77.12522125, 29.22487068], [77.12770081, 29.21842003], [77.13262939, 29.21311951], [77.1361618, 29.20745087], [77.13813782, 29.20106125], [77.13999176, 29.18208122], [77.13240814, 29.17181015], [77.12734222, 29.16291046], [77.12661743, 29.15402031], [77.13858032, 29.13476944], [77.13620758, 29.12784004], [77.12441254, 29.11346054], [77.12204742, 29.1057682], [77.12438202, 29.10148811], [77.13176727, 29.09464836], [77.14160156, 29.08681107], [77.14929962, 29.08324051], [77.15718842, 29.07753181], [77.162323, 29.06537247], [77.16163635, 29.05244064], [77.1626358, 29.04857063], [77.1765213, 29.03647041], [77.19159698, 29.02129173], [77.20379639, 29.01671982], [77.21113586, 29.01138115], [77.21404266, 29.00669098], [77.21418762, 29.00596046], [77.20790863, 28.99106026], [77.20375061, 28.9822998], [77.19095612, 28.96165085], [77.19013977, 28.95566177], [77.19078827, 28.94686127], [77.204422, 28.93997955], [77.20536804, 28.93646049], [77.19676971, 28.92093086], [77.20204926, 28.91555977], [77.21602631, 28.91143036], [77.22149658, 28.90813065], [77.22119141, 28.90413284], [77.21687317, 28.90034294], [77.20530701, 28.89460945], [77.19909668, 28.89268112], [77.18177032, 28.88980103], [77.17803955, 28.8855629], [77.17829132, 28.88004112], [77.18318939, 28.87177086], [77.18686676, 28.86681938], [77.18363953, 28.86230087], [77.16458893, 28.86063004], [77.1595993, 28.85744286], [77.15065002, 28.84844971], [77.14237976, 28.84247017], [77.1391983, 28.84166908], [77.13381195, 28.84472275], [77.1355896, 28.85268974], [77.13508606, 28.85848999], [77.12854004, 28.86539078], [77.10970306, 28.86613274], [77.10713196, 28.86845016], [77.09945679, 28.87244034], [77.08335114, 28.87461853], [77.07585144, 28.88451195], [77.07013702, 28.8800106], [77.06565857, 28.8730011], [77.04975891, 28.87318993], [77.03766632, 28.85277748], [77.03153992, 28.83679008], [77.02466583, 28.83628082], [77.01880646, 28.83706284], [77.00662994, 28.83526039], [76.98972321, 28.83916092], [76.98349762, 28.83908081], [76.97955322, 28.83670044], [76.97368622, 28.82583046], [76.9705658, 28.82510185], [76.96083069, 28.83167076], [76.95800781, 28.8303299], [76.95578003, 28.82002068], [76.94822693, 28.81766129], [76.94230652, 28.82068062], [76.93736267, 28.8091507], [76.93746948, 28.80350113], [76.94309235, 28.79512024], [76.94233704, 28.78775978], [76.94396973, 28.77853012], [76.94657135, 28.77403069], [76.93820953, 28.75962067], [76.9474411, 28.75113106], [76.95031738, 28.7466507], [76.94919586, 28.74150276], [76.95066071, 28.73645973], [76.94126129, 28.71702957], [76.95095825, 28.70976067], [76.95459747, 28.70537186], [76.954216, 28.7005291], [76.94999695, 28.69412994], [76.94838715, 28.68799019], [76.94595337, 28.68348122], [76.94725037, 28.67716026], [76.94255066, 28.67511177], [76.92973328, 28.6744194], [76.92310333, 28.66921043], [76.9174881, 28.65727043], [76.91821289, 28.65327072], [76.93390656, 28.63764954], [76.92597961, 28.62924957], [76.92366028, 28.62865067], [76.91034698, 28.63783073], [76.90400696, 28.63793945], [76.8972702, 28.63280106], [76.89367676, 28.63275146], [76.87793732, 28.63763046], [76.86090088, 28.60251045], [76.85481262, 28.59235191], [76.85022736, 28.59011841], [76.8350296, 28.59140015], [76.83291626, 28.58250809], [76.83761597, 28.55698967], [76.85674286, 28.54782104], [76.85920715, 28.54191971], [76.87631226, 28.52840042], [76.8794632, 28.52399826], [76.87380981, 28.51439095], [76.87937164, 28.50905037], [76.8868103, 28.51122856], [76.89372253, 28.51614189], [76.89745331, 28.51777077], [76.90847778, 28.51490974], [76.9226532, 28.51926994], [76.93321991, 28.5160408], [76.94462585, 28.51362991], [76.96846771, 28.52758026], [76.97653198, 28.52380943], [76.99027252, 28.51978111], [77.00554657, 28.51444054], [77.01093292, 28.51803017], [77.01139832, 28.52411079], [77.00499725, 28.52873993], [76.99820709, 28.53215027], [76.99594879, 28.53689957], [77.00020599, 28.54199982], [77.00609589, 28.54277992], [77.01566315, 28.53331947], [77.01963806, 28.53327179], [77.03314209, 28.52833939], [77.04165649, 28.51896095], [77.04876709, 28.51524162], [77.05696106, 28.5138607], [77.06746674, 28.52065086], [77.07247925, 28.52028084], [77.08598328, 28.51086044], [77.09031677, 28.5054512], [77.10352325, 28.49745941], [77.10766602, 28.49386978], [77.10334015, 28.48310852], [77.10154724, 28.47647858], [77.10273743, 28.47044945], [77.10604858, 28.46590042], [77.10874939, 28.45735168], [77.11251068, 28.45023155], [77.11830139, 28.4424305], [77.12407684, 28.43923759], [77.1313858, 28.43870163], [77.14243317, 28.43571091], [77.1518631, 28.42831993], [77.15434265, 28.4213028], [77.16577148, 28.40846062], [77.17948914, 28.41237068], [77.19522095, 28.4125309], [77.20590973, 28.41340065], [77.21530914, 28.41574097], [77.2227478, 28.41897011], [77.24061584, 28.42885971], [77.24318695, 28.43367958], [77.24430084, 28.44166946], [77.2432785, 28.44749069], [77.23986816, 28.45360756], [77.23311615, 28.45944977], [77.2264328, 28.46026039], [77.22574615, 28.46401024], [77.22763062, 28.46974945], [77.23239899, 28.47579956], [77.23673248, 28.47969055], [77.24265289, 28.48460007], [77.25396729, 28.48554039], [77.26010132, 28.48842812], [77.27111053, 28.49703026], [77.27805328, 28.49814987], [77.28578949, 28.49627113], [77.29627228, 28.4911499], [77.3009491, 28.49011993], [77.30686951, 28.49068069], [77.31488037, 28.49456978], [77.32170105, 28.49938965], [77.32668304, 28.50345039], [77.32898712, 28.50831985], [77.33447266, 28.51108932], [77.33773804, 28.50897026], [77.34319305, 28.50361061], [77.36048126, 28.49785995], [77.36396027, 28.49290085], [77.36412048, 28.48565102], [77.36936188, 28.4806881], [77.37600708, 28.47616005], [77.38816833, 28.47281837], [77.39789581, 28.47117043], [77.40003204, 28.4666996], [77.39483643, 28.46279907], [77.39779663, 28.45864105], [77.40828705, 28.45560074], [77.4181366, 28.45578957], [77.42578125, 28.45454025], [77.42829895, 28.44406128], [77.43599701, 28.43161011], [77.44399261, 28.42897034], [77.45147705, 28.42485809], [77.45610046, 28.42098808], [77.46869659, 28.41753006], [77.47455597, 28.41351128], [77.47386169, 28.40381241], [77.46684265, 28.39968109], [77.46953583, 28.39430046], [77.48589325, 28.37970161], [77.4920578, 28.36952019], [77.49423981, 28.35826111], [77.48517609, 28.35021019], [77.46640778, 28.34120941], [77.46375275, 28.33801079], [77.46592712, 28.33394051], [77.47355652, 28.32788086], [77.4818573, 28.32361984], [77.49578857, 28.30704117], [77.49417114, 28.30026054], [77.49476624, 28.29261017], [77.49273682, 28.28063011], [77.48808289, 28.27911949], [77.47225189, 28.28120995], [77.46481323, 28.27742958], [77.46730042, 28.26972008], [77.48707581, 28.26176071], [77.50206757, 28.25784111], [77.51062012, 28.25489044], [77.51159668, 28.25455093], [77.51225281, 28.25432968], [77.52501678, 28.25342941], [77.53878021, 28.25440979], [77.54120636, 28.2477417], [77.53562164, 28.24052048], [77.51557922, 28.22976112], [77.51703644, 28.22138977], [77.52157593, 28.21739006], [77.52327728, 28.20717049], [77.51911926, 28.20178032], [77.51281738, 28.20168114], [77.51056671, 28.20633125], [77.49759674, 28.21302032], [77.48912048, 28.21199036], [77.49061584, 28.19305992], [77.49211884, 28.18510056], [77.50151825, 28.18719101], [77.50566101, 28.19547081], [77.52082062, 28.19174004], [77.53018951, 28.1929493], [77.53794861, 28.19089127], [77.54236603, 28.1816597], [77.5317688, 28.17025948], [77.51159668, 28.16489029], [77.498909, 28.16300964], [77.49636841, 28.15987015], [77.49529266, 28.14581108], [77.48986816, 28.14438057], [77.48725128, 28.14143181], [77.48796082, 28.13878059], [77.49846649, 28.1356926], [77.49964142, 28.12735939], [77.49939728, 28.12259102], [77.49137115, 28.11271095], [77.49324036, 28.10817909], [77.49373627, 28.10227013], [77.49230957, 28.09801102], [77.49014282, 28.09529114], [77.48602295, 28.09739113], [77.48278046, 28.10785294], [77.47823334, 28.10797119], [77.47479248, 28.10428047], [77.47306824, 28.10371971], [77.46887207, 28.08601189], [77.47001648, 28.0837307], [77.47173309, 28.07875061], [77.47683716, 28.07331276], [77.48290253, 28.06071091], [77.48287201, 28.0589447], [77.48284912, 28.05764961], [77.47763824, 28.04910088], [77.47911072, 28.04416275], [77.48970795, 28.0393219], [77.49517059, 28.03429985], [77.49743652, 28.03063965], [77.50177002, 28.02737999], [77.50652313, 28.02234077], [77.50937653, 28.01772118], [77.5118866, 28.01025009], [77.52011108, 28.00654984], [77.53521729, 27.99333], [77.53215027, 27.98884964], [77.52667999, 27.98402023], [77.51344299, 27.97743988], [77.50958252, 27.97333145], [77.51059723, 27.96820831], [77.51502991, 27.9654808], [77.52900696, 27.96624947], [77.53591919, 27.96554947], [77.53733826, 27.95776939], [77.53613281, 27.94930267], [77.53137207, 27.94181824], [77.51921082, 27.93188095], [77.5137558, 27.93634033], [77.51116943, 27.9374218], [77.50585938, 27.93614006], [77.49777985, 27.93141174], [77.49537659, 27.93077087], [77.49225616, 27.93180847], [77.49060059, 27.93394852], [77.48796082, 27.94145012], [77.48474884, 27.94391251], [77.47766113, 27.94021034], [77.46872711, 27.93291092], [77.46845245, 27.93188095], [77.47059631, 27.92789268], [77.47086334, 27.92061043], [77.47245026, 27.9192009], [77.474617, 27.91206169], [77.4724884, 27.90120125], [77.46981812, 27.89472961], [77.45848846, 27.88529968], [77.44584656, 27.87840843], [77.44219971, 27.87848091], [77.430336, 27.88884163], [77.42220306, 27.89447975], [77.41423035, 27.89652061], [77.41229248, 27.89615822], [77.41104126, 27.89501953], [77.40709686, 27.88912964], [77.40409088, 27.88661003], [77.40155029, 27.88190079], [77.40453339, 27.8758297], [77.40512848, 27.87174988], [77.40629578, 27.86967087], [77.41369629, 27.86260033], [77.41442108, 27.86069107], [77.41239166, 27.85907173], [77.40377808, 27.85824013], [77.39282227, 27.85894966], [77.38208008, 27.86309052], [77.37388611, 27.86370277], [77.37001038, 27.86313057], [77.36483002, 27.86059189], [77.35264587, 27.8564415], [77.34406281, 27.85898972], [77.33933258, 27.85959053], [77.33265686, 27.85489082], [77.33120728, 27.85268021], [77.32924652, 27.85198975], [77.32406616, 27.8408699], [77.32733154, 27.83772087], [77.32211304, 27.83472061], [77.31719208, 27.83324051], [77.31292725, 27.83005142], [77.30632019, 27.83200073], [77.3048172, 27.83123016], [77.29915619, 27.83138275], [77.28888702, 27.82913971], [77.29062653, 27.81970978], [77.28970337, 27.81783295], [77.28347778, 27.81591988], [77.27934265, 27.8119812], [77.27707672, 27.80673981], [77.27577972, 27.80654907], [77.26748657, 27.81196022], [77.26249695, 27.81611061], [77.25805664, 27.80929947], [77.25699615, 27.80525017], [77.25284576, 27.79763985], [77.24794769, 27.79375076], [77.24088287, 27.7903595], [77.23455811, 27.78581047], [77.23174286, 27.78580093], [77.22724915, 27.78865814], [77.22870636, 27.79310036], [77.22685242, 27.79610062], [77.22215271, 27.79764938], [77.21684265, 27.7954998], [77.20677185, 27.80105972], [77.20571136, 27.80548096], [77.20210266, 27.81257057], [77.19676208, 27.81944084], [77.19384766, 27.82193947], [77.18747711, 27.81504822], [77.18659973, 27.81048012], [77.18894196, 27.79842949], [77.17556, 27.78722191], [77.16870117, 27.78490067], [77.16400909, 27.78691101], [77.16216278, 27.79059029], [77.16660309, 27.79591942], [77.16924286, 27.80056953], [77.17814636, 27.80252075], [77.18044281, 27.80443192], [77.18065643, 27.80865288], [77.1758728, 27.81445122], [77.17237854, 27.81632042], [77.16108704, 27.81318855], [77.15666199, 27.81360054], [77.15209961, 27.8157711], [77.15061951, 27.81555939], [77.14972687, 27.81243134], [77.15354156, 27.80243111], [77.15329742, 27.79785919], [77.15142822, 27.79181099], [77.14727783, 27.78665924], [77.14142609, 27.78623009], [77.13535309, 27.78395081], [77.12652588, 27.77646065], [77.12520599, 27.77693176], [77.12467194, 27.78483963], [77.12210846, 27.7883091], [77.11997223, 27.78947067], [77.11741638, 27.79019165], [77.11476898, 27.78988075], [77.10748291, 27.78665924], [77.10263062, 27.78518105], [77.10116577, 27.78549194], [77.09362793, 27.78970146], [77.08023071, 27.80039024], [77.07663727, 27.8014698], [77.07427216, 27.80435181], [77.07241058, 27.80952072], [77.06848145, 27.81157112], [77.06529236, 27.81258011], [77.05625153, 27.81146049], [77.05182648, 27.81516075], [77.04682159, 27.81809044], [77.04514313, 27.81698036], [77.03827667, 27.82004166], [77.03504944, 27.81666183], [77.03539276, 27.81410027], [77.03457642, 27.81252289], [77.03038025, 27.81142998], [77.02398682, 27.79817009], [77.0230484, 27.78718948], [77.0197525, 27.78032112], [77.02066803, 27.77812004], [77.02276611, 27.77794838], [77.024086, 27.77700996], [77.02672577, 27.77791023], [77.02841187, 27.78029823], [77.03943634, 27.77490044], [77.04692841, 27.76798058], [77.05010223, 27.76104164], [77.05422974, 27.76189995], [77.05603027, 27.7643795], [77.06181335, 27.76568985], [77.06733704, 27.76375961], [77.0707016, 27.75884056], [77.07118988, 27.75192261], [77.07253265, 27.74909973], [77.07840729, 27.74287987], [77.07943726, 27.74019051], [77.079216, 27.73841095], [77.07797241, 27.73734093], [77.07113647, 27.73574066], [77.06572723, 27.73241043], [77.05944824, 27.73135948], [77.0532074, 27.7278595], [77.05065918, 27.72811127], [77.04427338, 27.73224068], [77.04271698, 27.73590279], [77.0402832, 27.73835945], [77.0393219, 27.7415905], [77.03649902, 27.74462128], [77.03196716, 27.74841118], [77.02894592, 27.74937057], [77.02485657, 27.74712944], [77.01680756, 27.74776077], [77.01140594, 27.74651909], [77.00502014, 27.73913956], [77.00337219, 27.73855019], [77.00099182, 27.73851967], [76.99437714, 27.74204254], [76.9935379, 27.74170113], [76.9913559, 27.73642921], [76.98912811, 27.73377991], [76.98744965, 27.72928047], [76.98277283, 27.71850014], [76.97910309, 27.70615959], [76.97608185, 27.69285011], [76.97312927, 27.68042183], [76.97229767, 27.67287064], [76.97033691, 27.66545105], [76.97049713, 27.65714264], [76.96022797, 27.66242027], [76.95153809, 27.66625023], [76.94478607, 27.67057037], [76.93844604, 27.67366982], [76.93419647, 27.67510033], [76.93028259, 27.67170906], [76.92684174, 27.66543007], [76.92385101, 27.66073036], [76.91899109, 27.66148186], [76.91382599, 27.65960121], [76.90947723, 27.65680122], [76.90540314, 27.65596962], [76.90262604, 27.65851974], [76.90052795, 27.6634407], [76.90009308, 27.66803932], [76.89715576, 27.67243004], [76.89322662, 27.67687988], [76.89164734, 27.67988968], [76.89401245, 27.68333054], [76.89673615, 27.68596077], [76.89473724, 27.68965912], [76.8886261, 27.69284058], [76.88311768, 27.69549942], [76.88092041, 27.69936943], [76.88284302, 27.70337105], [76.88802338, 27.70167923], [76.89350891, 27.69826126], [76.9003067, 27.69462967], [76.90600586, 27.69584084], [76.91036224, 27.69664955], [76.91456604, 27.70082092], [76.91220093, 27.70610046], [76.90830994, 27.71208954], [76.90278625, 27.7164402], [76.89539337, 27.71850967], [76.88854218, 27.71955109], [76.88334656, 27.72442245], [76.88407898, 27.73090935], [76.88786316, 27.73721123], [76.89060974, 27.74201965], [76.8914032, 27.76119041], [76.89232635, 27.77203178], [76.89363861, 27.7792511], [76.89560699, 27.78614044], [76.89865112, 27.79108047], [76.90392303, 27.79488945], [76.90280151, 27.80128098], [76.90660095, 27.80765915], [76.90524292, 27.81255913], [76.900383, 27.82114983], [76.90106964, 27.82541847], [76.90377808, 27.83266068], [76.90788269, 27.83591843], [76.91499329, 27.83461952], [76.92193604, 27.83183098], [76.92664337, 27.83422089], [76.92809296, 27.84398079], [76.92990875, 27.85523033], [76.92829895, 27.86713028], [76.9247818, 27.876791], [76.92610931, 27.88837051], [76.92608643, 27.89442062], [76.93817902, 27.89599037], [76.93673706, 27.90754128], [76.93881989, 27.91902924], [76.92993927, 27.92136002], [76.92127991, 27.92105293], [76.9190979, 27.92486], [76.91909027, 27.94082069], [76.91954041, 27.95283127], [76.92276764, 27.96577072], [76.92492676, 27.97836113], [76.9223175, 27.9858284], [76.91864777, 27.99761009], [76.92163086, 28.00568962], [76.92658234, 28.01250076], [76.93074036, 28.03050041], [76.93186188, 28.04202271], [76.93364716, 28.04813004], [76.93777466, 28.0589447], [76.93802643, 28.05961037], [76.94252777, 28.06682014], [76.94655609, 28.07134056], [76.94806671, 28.0786705], [76.95107269, 28.09608841], [76.955513, 28.11174965], [76.95582581, 28.12371826], [76.96176147, 28.14401054], [76.95654297, 28.14600945], [76.94174194, 28.14870071], [76.94052887, 28.15092087], [76.94156647, 28.15517044], [76.93781281, 28.15534973], [76.92753601, 28.15891266], [76.92105103, 28.16225052], [76.91204834, 28.17185974], [76.8991394, 28.17932129], [76.89009094, 28.18782806], [76.88404846, 28.19165993], [76.88387299, 28.19473076], [76.88574219, 28.1967411], [76.89984894, 28.20476913], [76.89668274, 28.20763016], [76.88668823, 28.21049118], [76.8792572, 28.21038055], [76.86618042, 28.21152115], [76.86580658, 28.21795845], [76.8636322, 28.22463989], [76.85772705, 28.22317123], [76.8543396, 28.22524071], [76.85048676, 28.22666931], [76.83342743, 28.2248497], [76.82724762, 28.21749115], [76.82382965, 28.2147007], [76.8189621, 28.21469116], [76.81323242, 28.21631241], [76.80580902, 28.21589088], [76.80136871, 28.21160126], [76.80246735, 28.20463181], [76.80560303, 28.20038033], [76.8026123, 28.19607162], [76.79788971, 28.19437981], [76.79384613, 28.19955063], [76.79309845, 28.19832993], [76.79025269, 28.19375992], [76.79225922, 28.18292046], [76.79228973, 28.17566109], [76.79614258, 28.17048073], [76.79148865, 28.15724182], [76.7830658, 28.1556797], [76.77294159, 28.15142059], [76.76216888, 28.1500206], [76.75508118, 28.14661026], [76.73912811, 28.12903976], [76.73295593, 28.12857246], [76.7315979, 28.12845039], [76.720047, 28.13153076], [76.70996094, 28.13236046], [76.708992, 28.13138008], [76.70543671, 28.12772751], [76.69876099, 28.11571121], [76.69494629, 28.11529922], [76.69024658, 28.11478996], [76.6894989, 28.1135006], [76.68564606, 28.10688019], [76.68218231, 28.09777069], [76.67790985, 28.09781075], [76.6639328, 28.0978508], [76.6579895, 28.0990715], [76.65122986, 28.0967598], [76.64785004, 28.09221077], [76.64697266, 28.08510971], [76.64804077, 28.07908058], [76.64792633, 28.06767082], [76.64892578, 28.06171036], [76.6501236, 28.0589447], [76.65162659, 28.05548286], [76.65099335, 28.0444603], [76.65341949, 28.03992081], [76.65962219, 28.03367043], [76.66146088, 28.0293026], [76.66240692, 28.02294159], [76.66007233, 28.0190506], [76.65455627, 28.01556969], [76.64671326, 28.01262093], [76.63687897, 28.01066017], [76.62534332, 28.01046944], [76.6159668, 28.0112896], [76.60389709, 28.01079178], [76.59896851, 28.00984001], [76.59523773, 28.00614929], [76.59175873, 28.00365829], [76.58381653, 28.0003109], [76.57727051, 27.99487114], [76.57382965, 27.98901939], [76.56749725, 27.98357964], [76.55979156, 27.98178291], [76.55343628, 27.9750309], [76.54659271, 27.9713707], [76.53819275, 27.970541], [76.53350067, 27.97372818], [76.53103638, 27.97932816], [76.53193665, 27.98570061], [76.53553772, 27.99306107], [76.53640747, 28.00473022], [76.53845215, 28.00537109], [76.53774261, 28.00751114], [76.53862, 28.01206017], [76.53855133, 28.01670074], [76.53553009, 28.02571106], [76.53852081, 28.03911972], [76.53124237, 28.0431118], [76.52585602, 28.0454483], [76.51859283, 28.03896141], [76.51140594, 28.03536034], [76.50522614, 28.03503036], [76.49949646, 28.03635979], [76.49848938, 28.04018021], [76.49604797, 28.04364014], [76.49221802, 28.04709816], [76.48307037, 28.0463295], [76.47570801, 28.04405975], [76.46170044, 28.04457283], [76.45574188, 28.04648018], [76.45372772, 28.04966927], [76.4540329, 28.05507278], [76.45624542, 28.0589447], [76.45797729, 28.06197166], [76.47129822, 28.06110954], [76.48087311, 28.0589447], [76.48381805, 28.05828094], [76.48780823, 28.0589447], [76.48957825, 28.05924034], [76.49453735, 28.0610714], [76.49765778, 28.0647316], [76.49537659, 28.0676403], [76.48590088, 28.07512093], [76.46988678, 28.08632088], [76.46360779, 28.0840683], [76.45881653, 28.08500099], [76.45343018, 28.08778954], [76.44857025, 28.09317017], [76.45121765, 28.09766006], [76.4539032, 28.10589027], [76.45688629, 28.11038971], [76.46092987, 28.11190033], [76.4662323, 28.11297035], [76.47254181, 28.11271095], [76.47728729, 28.10598946], [76.48874664, 28.10473061], [76.49780273, 28.10662079], [76.49729156, 28.11597824], [76.49809265, 28.12253952], [76.4868927, 28.12281036], [76.48574066, 28.12812042], [76.48972321, 28.13367844], [76.48509216, 28.13490105], [76.48329163, 28.13484764], [76.47722626, 28.13467026], [76.47319031, 28.13573074], [76.46996307, 28.13850021], [76.47233582, 28.14960098], [76.47099304, 28.15474129], [76.46517944, 28.15561104], [76.46109009, 28.15237045], [76.45604706, 28.15142822], [76.43712616, 28.15215111], [76.43135834, 28.14757156], [76.42729187, 28.14594078], [76.4122467, 28.1474781], [76.39704132, 28.14779282], [76.39302826, 28.14105034], [76.38851166, 28.13952065], [76.3840332, 28.13986015], [76.37677002, 28.13807106], [76.35983276, 28.14338112], [76.35740662, 28.14785194], [76.35597229, 28.1597805], [76.3532486, 28.1661911], [76.34259796, 28.17393112], [76.33590698, 28.17734146], [76.32595825, 28.17743111], [76.30871582, 28.18336105], [76.30496216, 28.18386078], [76.29802704, 28.18287086], [76.28885651, 28.1826725], [76.27906799, 28.17872047], [76.2767868, 28.17276001], [76.27818298, 28.16857147], [76.2930069, 28.16527939], [76.29852295, 28.16254807], [76.29846954, 28.15944862], [76.29506683, 28.15705109], [76.29590607, 28.15467072], [76.30155945, 28.15100098], [76.30821228, 28.15088081], [76.31111908, 28.15467072], [76.31732941, 28.15306091], [76.32274628, 28.14921761], [76.33100891, 28.13896942], [76.33759308, 28.13484764], [76.34321594, 28.13277054], [76.34934235, 28.13215065], [76.35560608, 28.12845039], [76.34350586, 28.11321831], [76.3395462, 28.10969925], [76.33188629, 28.10671806], [76.31417847, 28.11212921], [76.30802917, 28.11128044], [76.30132294, 28.10620117], [76.29740143, 28.10104942], [76.30716705, 28.09645271], [76.31344604, 28.09467125], [76.32054901, 28.09431267], [76.32488251, 28.09215927], [76.32879639, 28.08776093], [76.33126831, 28.08164978], [76.33213806, 28.07678986], [76.33734894, 28.07306099], [76.34436798, 28.07386971], [76.35048676, 28.07578087], [76.354599, 28.07420158], [76.35328674, 28.06557274], [76.35081482, 28.0589447], [76.34591675, 28.04578972], [76.34126282, 28.0360508], [76.33679962, 28.02966118], [76.32995605, 28.02487946], [76.32367706, 28.02384186], [76.31659698, 28.02099037], [76.29715729, 28.02596092], [76.29012299, 28.0298996], [76.28811646, 28.04204941], [76.29007721, 28.04911041], [76.28200531, 28.0589447], [76.27178955, 28.06638908], [76.2649231, 28.06874084], [76.25109863, 28.07092094], [76.24356842, 28.06893921], [76.23542786, 28.0589447], [76.23336792, 28.05642128], [76.22593689, 28.05518913], [76.20833588, 28.05556107], [76.20431519, 28.0589447], [76.20363617, 28.05952072], [76.19991302, 28.06075096], [76.19284821, 28.05981064], [76.17733765, 28.05925941], [76.17722321, 28.0589447], [76.17545319, 28.05425072], [76.17688751, 28.04895973], [76.18318176, 28.04302025], [76.19342804, 28.03523064], [76.19818115, 28.03494835], [76.2041626, 28.04224968], [76.21356201, 28.04018021], [76.21382904, 28.03168106], [76.20346069, 28.03036118], [76.20038605, 28.02567101], [76.19587708, 28.02173805], [76.19068146, 28.02141953], [76.1838913, 28.0235405], [76.1795578, 28.02329254], [76.174263, 28.02190971], [76.16938782, 28.01685905], [76.15872192, 28.00455093], [76.15493774, 27.99899101], [76.15386963, 27.99253082], [76.16246796, 27.98830986], [76.16098022, 27.98010063], [76.16703796, 27.97915268], [76.17421722, 27.97521019], [76.17946625, 27.97284126], [76.17817688, 27.96747017], [76.17629242, 27.96105957], [76.17693329, 27.95506096], [76.17636871, 27.94831085], [76.17476654, 27.94124985], [76.17037201, 27.93329048], [76.16765594, 27.92835045], [76.16607666, 27.92098999], [76.16645813, 27.91506958], [76.1697464, 27.90974998], [76.17516327, 27.90710068], [76.18261719, 27.90507126], [76.19095612, 27.90269089], [76.19863892, 27.89899063], [76.20012665, 27.8923111], [76.19975281, 27.88809967], [76.19444275, 27.88394165], [76.19032288, 27.88157845], [76.18901062, 27.87636948], [76.19135284, 27.86942863], [76.1931076, 27.86391258], [76.19895172, 27.85967064], [76.2050705, 27.85552025], [76.20594788, 27.84799004], [76.21063232, 27.84481812], [76.22328186, 27.84093094], [76.21380615, 27.8325882], [76.20773315, 27.82849121], [76.20054626, 27.82891083], [76.19412994, 27.83121109], [76.1904068, 27.82676125], [76.18624115, 27.81904984], [76.18041992, 27.81241035], [76.17292023, 27.80746078], [76.16734314, 27.80914116], [76.1628418, 27.81484032], [76.15319061, 27.82129288], [76.14267731, 27.82783127], [76.12776947, 27.83320045], [76.12822723, 27.83784103], [76.12845612, 27.84692192], [76.12213898, 27.85440063], [76.11258698, 27.85858154], [76.10334778, 27.86237907], [76.09577179, 27.8647995], [76.0880661, 27.86844826], [76.08563995, 27.86522293], [76.08476257, 27.85639], [76.08009338, 27.8510704]]]}}, {\\\"id\\\": \\\"11\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.13_1\\\", \\\"HASC_1\\\": \\\"IN.HP\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Himachal Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 37.6, \\\"dalys_apm25_rate_6cod_mean_total\\\": 916.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1423.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2339.0, \\\"geo-id\\\": 11, \\\"hpm25_child_popweighted\\\": 143.3, \\\"hpm25_female_popweighted\\\": 164.7, \\\"hpm25_male_popweighted\\\": 118.6, \\\"location\\\": \\\"Himachal Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 2453.0, \\\"mort_hpm25_6cod_mean_total\\\": 2862.0, \\\"mort_tpm25_6cod_mean_total\\\": 5315.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[77.80056, 30.51316071], [77.79917908, 30.51139069], [77.79389954, 30.50860023], [77.78819275, 30.5060997], [77.76761627, 30.5043602], [77.76344299, 30.50024986], [77.75504303, 30.49832916], [77.74752808, 30.49404907], [77.73658752, 30.48725128], [77.72927856, 30.48233986], [77.72144318, 30.47776985], [77.71122742, 30.47727013], [77.70466614, 30.47340012], [77.69918823, 30.4686985], [77.69008636, 30.46294022], [77.68219757, 30.45769119], [77.67906952, 30.45173073], [77.66160583, 30.44878006], [77.65320587, 30.44954109], [77.64665222, 30.45245934], [77.6402359, 30.45235062], [77.63783264, 30.44948769], [77.63568115, 30.44433975], [77.63333893, 30.43976974], [77.63054657, 30.43615913], [77.61672211, 30.43623161], [77.61200714, 30.43840027], [77.60375214, 30.43744087], [77.59041595, 30.43378067], [77.58106995, 30.43029976], [77.57463074, 30.42651939], [77.56790161, 30.4217186], [77.56288147, 30.41707993], [77.5622406, 30.41006279], [77.56305695, 30.40448952], [77.56785583, 30.39875984], [77.57292175, 30.3930912], [77.57615662, 30.38989067], [77.57489014, 30.38451958], [77.56534576, 30.3848896], [77.55792236, 30.39036942], [77.5524826, 30.39336014], [77.54289246, 30.39723015], [77.53874207, 30.40191269], [77.5356369, 30.40905952], [77.52925873, 30.41350174], [77.52577209, 30.41714096], [77.51803589, 30.43087006], [77.51436615, 30.43942261], [77.50984955, 30.44882965], [77.50534058, 30.44836044], [77.50115204, 30.44367981], [77.49294281, 30.43304825], [77.49118805, 30.42498016], [77.49134827, 30.41735077], [77.48683167, 30.41261292], [77.4825592, 30.41521835], [77.47751617, 30.41334915], [77.4679718, 30.4117794], [77.46098328, 30.40538025], [77.45311737, 30.40480042], [77.44301605, 30.40460014], [77.43495178, 30.40367126], [77.43041229, 30.40747833], [77.41644287, 30.40839195], [77.41590118, 30.41283035], [77.42092896, 30.41682243], [77.42569733, 30.42000008], [77.43972015, 30.42440033], [77.44204712, 30.42988968], [77.45334625, 30.44036102], [77.45429993, 30.44606018], [77.45677185, 30.45155907], [77.4562912, 30.45819092], [77.45053864, 30.46523094], [77.44568634, 30.46566963], [77.43559265, 30.45100975], [77.42620087, 30.44111824], [77.41723633, 30.4338398], [77.40763855, 30.42788124], [77.40061188, 30.41875076], [77.39546204, 30.4209404], [77.39679718, 30.43046951], [77.39409637, 30.43427086], [77.38186646, 30.43927193], [77.38038635, 30.44614029], [77.37621307, 30.44625092], [77.36965179, 30.44584274], [77.35679626, 30.44206047], [77.35349274, 30.44856071], [77.34970093, 30.45728111], [77.34607697, 30.46190071], [77.33937836, 30.46360016], [77.33267975, 30.46422958], [77.3262558, 30.46318245], [77.3223877, 30.46211815], [77.31677246, 30.45762062], [77.31069946, 30.45362091], [77.30069733, 30.45659828], [77.29373932, 30.45913124], [77.28244019, 30.46191978], [77.27455902, 30.46404076], [77.26358032, 30.46667099], [77.26193237, 30.47104073], [77.26084137, 30.47612], [77.2565918, 30.48142052], [77.25177765, 30.48441124], [77.24186707, 30.4853611], [77.23345947, 30.48747063], [77.22676849, 30.48861122], [77.21885681, 30.48598289], [77.21190643, 30.48187065], [77.2026062, 30.48034096], [77.19904327, 30.48454285], [77.20030975, 30.48904991], [77.19957733, 30.49913979], [77.19966125, 30.50659943], [77.19589233, 30.51177025], [77.19082642, 30.51932907], [77.18534851, 30.52588081], [77.17455292, 30.53051949], [77.16953278, 30.53288078], [77.16368866, 30.53412056], [77.15203857, 30.53691292], [77.14553833, 30.53779984], [77.13758087, 30.53857994], [77.13105774, 30.54150963], [77.12233734, 30.54823112], [77.11650848, 30.5574398], [77.11370087, 30.56244087], [77.11149597, 30.56728935], [77.11289215, 30.56824112], [77.11514282, 30.56984138], [77.12059021, 30.57118034], [77.12378693, 30.57269287], [77.12587738, 30.57369041], [77.1326828, 30.57845116], [77.1398468, 30.58320045], [77.14692688, 30.58896065], [77.15122223, 30.59283066], [77.15409851, 30.59632111], [77.15748596, 30.59955025], [77.158638, 30.60314178], [77.15847778, 30.60746002], [77.15863037, 30.61380959], [77.15986633, 30.63148117], [77.16236115, 30.63865089], [77.16044617, 30.64240074], [77.15619659, 30.64792061], [77.15273285, 30.6541996], [77.1526413, 30.65876007], [77.15519714, 30.6680603], [77.153862, 30.67694283], [77.15068817, 30.68119812], [77.15020752, 30.68455124], [77.15352631, 30.6887207], [77.15177155, 30.6905098], [77.14743805, 30.69347954], [77.14037323, 30.6975708], [77.13381958, 30.70215988], [77.12512207, 30.70709991], [77.12223816, 30.71216011], [77.1174469, 30.71791077], [77.10957336, 30.72268295], [77.1031723, 30.72044945], [77.09990692, 30.7222805], [77.1002121, 30.72639084], [77.10234833, 30.73077965], [77.10056305, 30.73238754], [77.09613037, 30.73462105], [77.09111786, 30.73621178], [77.08627319, 30.73994255], [77.07684326, 30.74476051], [77.06971741, 30.74698257], [77.06170654, 30.74612808], [77.05497742, 30.74674034], [77.04705811, 30.74867058], [77.03801727, 30.7531395], [77.03370667, 30.75542068], [77.03032684, 30.75176048], [77.03037262, 30.7463398], [77.02828979, 30.74344063], [77.02401733, 30.74162102], [77.01805115, 30.74044991], [77.01309967, 30.74220848], [77.00939178, 30.74571037], [77.00644684, 30.74950981], [77.00470734, 30.75248909], [77.00466156, 30.75735283], [77.00582123, 30.76175117], [77.0044632, 30.76634979], [77.002388, 30.76795006], [76.9988327, 30.76915169], [76.99524689, 30.77103996], [76.99121094, 30.77345276], [76.98860168, 30.777071], [76.99095917, 30.78065109], [76.99487305, 30.78507042], [77.00003052, 30.78902054], [76.99973297, 30.79397964], [77.00035095, 30.79762268], [76.9997406, 30.80490112], [76.9985199, 30.80973053], [76.99796295, 30.814291], [76.99584198, 30.81670952], [76.99266052, 30.81830025], [76.98845673, 30.81500053], [76.98652649, 30.81324959], [76.98477173, 30.81047249], [76.98264313, 30.80430031], [76.97910309, 30.79881287], [76.96864319, 30.80796051], [76.96180725, 30.80899048], [76.95375061, 30.81121063], [76.94764709, 30.82316971], [76.94283295, 30.8291893], [76.93370056, 30.83196259], [76.92751312, 30.83735275], [76.92780304, 30.84814072], [76.92661285, 30.85444069], [76.91584015, 30.86932945], [76.90706635, 30.89099121], [76.90216064, 30.89722824], [76.8865509, 30.88829994], [76.87858582, 30.88598251], [76.86962891, 30.87816048], [76.86178589, 30.87355042], [76.85243225, 30.87068939], [76.83715057, 30.87887192], [76.82266235, 30.88809967], [76.81575775, 30.89600945], [76.80979919, 30.90680122], [76.8143692, 30.92134094], [76.81339264, 30.92732048], [76.81018829, 30.93037987], [76.79876709, 30.92464066], [76.76985931, 30.90639114], [76.75383759, 30.91781807], [76.75411987, 30.92295265], [76.74868774, 30.92379951], [76.74862671, 30.92916107], [76.74382019, 30.92904091], [76.7383728, 30.93005943], [76.72602081, 30.93933105], [76.72547913, 30.9425106], [76.72413635, 30.9505825], [76.71260071, 30.96342087], [76.70507813, 30.9633007], [76.69837952, 30.96889114], [76.69615936, 30.97179031], [76.69423676, 30.97249031], [76.66819, 30.96988106], [76.6626358, 30.97113037], [76.65306091, 30.98180962], [76.63334656, 30.99072266], [76.62592316, 30.9924984], [76.62094879, 30.99830055], [76.61241913, 31.0020504], [76.61006927, 31.0042305], [76.61360168, 31.02198982], [76.60518646, 31.03351974], [76.60151672, 31.04356194], [76.59896851, 31.05355072], [76.60952759, 31.06067085], [76.60489655, 31.07837868], [76.60782623, 31.08350182], [76.61184692, 31.09638977], [76.62573242, 31.11024284], [76.62371063, 31.11800957], [76.61559296, 31.12158012], [76.60727692, 31.11964035], [76.59744263, 31.12619972], [76.58931732, 31.12770081], [76.59395599, 31.1364994], [76.59874725, 31.15117073], [76.59467316, 31.15134048], [76.59007263, 31.15726852], [76.5914917, 31.16032028], [76.58943939, 31.16476059], [76.59246826, 31.1722908], [76.59039307, 31.18285942], [76.59831238, 31.18647957], [76.60066223, 31.1910305], [76.6057663, 31.19712067], [76.61221313, 31.20264053], [76.61869812, 31.20390129], [76.62011719, 31.20666122], [76.63542175, 31.21298027], [76.63414764, 31.21533966], [76.62452698, 31.22104073], [76.62594604, 31.22709084], [76.61625671, 31.22944069], [76.5867691, 31.21606064], [76.58061218, 31.21635246], [76.57935333, 31.2204895], [76.57596588, 31.22578812], [76.58252716, 31.2309494], [76.58470917, 31.23964119], [76.59268188, 31.24615097], [76.60161591, 31.25090981], [76.57050323, 31.28014946], [76.55224609, 31.26485252], [76.54592133, 31.25588036], [76.53495026, 31.25535011], [76.53264618, 31.26651192], [76.53481293, 31.27233124], [76.53717041, 31.28395081], [76.53122711, 31.28354073], [76.52789307, 31.2699604], [76.51811218, 31.26231003], [76.51428223, 31.26450157], [76.5165863, 31.27738953], [76.51426697, 31.28307915], [76.51091003, 31.28261948], [76.50340271, 31.27788925], [76.49823761, 31.27329063], [76.48858643, 31.27340126], [76.4832077, 31.28427124], [76.4797287, 31.28910255], [76.47564697, 31.29220009], [76.47505951, 31.29899979], [76.47245026, 31.30669975], [76.46671295, 31.31021118], [76.46208954, 31.30681038], [76.45101166, 31.29620934], [76.44577789, 31.28970909], [76.43113708, 31.28284073], [76.42849731, 31.28923035], [76.43580627, 31.29463959], [76.44558716, 31.30041122], [76.44827271, 31.30599022], [76.43744659, 31.31742287], [76.42801666, 31.32518005], [76.41816711, 31.33731079], [76.41284943, 31.34765816], [76.40883636, 31.35374832], [76.39924622, 31.36547089], [76.39105225, 31.37863159], [76.37924957, 31.3911705], [76.39039612, 31.39733124], [76.38162994, 31.41061974], [76.37303162, 31.41364861], [76.37526703, 31.4221611], [76.36917114, 31.42814064], [76.36313629, 31.44135094], [76.35677338, 31.4296093], [76.35914612, 31.41563034], [76.35312653, 31.41246033], [76.34689331, 31.40571022], [76.33460236, 31.40373993], [76.32952118, 31.40113831], [76.31584167, 31.40237808], [76.31877136, 31.38817978], [76.3182373, 31.3810997], [76.32958221, 31.37951851], [76.33001709, 31.36771011], [76.33129883, 31.35909271], [76.33666229, 31.35301971], [76.33007813, 31.34527969], [76.32446289, 31.34711075], [76.31783295, 31.35222054], [76.3157959, 31.34749985], [76.29991913, 31.34383011], [76.2959671, 31.34222984], [76.30226898, 31.3263607], [76.2960968, 31.31920052], [76.29039001, 31.31563187], [76.28439331, 31.31356049], [76.27735901, 31.3099308], [76.26840973, 31.30660057], [76.26116943, 31.30583], [76.25562286, 31.31495094], [76.24414063, 31.31371117], [76.22319031, 31.31306076], [76.21495819, 31.30764008], [76.20639801, 31.30526161], [76.18569946, 31.3046608], [76.17282867, 31.30673981], [76.16845703, 31.31412125], [76.16607666, 31.3261795], [76.1663208, 31.34145927], [76.1580658, 31.34694099], [76.14774323, 31.34814835], [76.13961029, 31.3531208], [76.13503265, 31.36175919], [76.13408661, 31.38264275], [76.1386261, 31.38685989], [76.14713287, 31.39190292], [76.15303802, 31.39725113], [76.15674591, 31.4045105], [76.15349579, 31.41401291], [76.14707184, 31.41884041], [76.14713287, 31.42560959], [76.14346313, 31.43229103], [76.13507843, 31.43750954], [76.12824249, 31.44375992], [76.122612, 31.45372963], [76.12127686, 31.46097946], [76.11551666, 31.46544075], [76.11472321, 31.47354126], [76.10795593, 31.48221016], [76.10816193, 31.49510956], [76.10410309, 31.5023098], [76.09455109, 31.51420975], [76.09062195, 31.51898956], [76.08895874, 31.52763939], [76.08399963, 31.53718185], [76.07681274, 31.54595947], [76.07158661, 31.55414963], [76.06601715, 31.56051826], [76.06490326, 31.56179047], [76.05150604, 31.58179092], [76.04315948, 31.59197044], [76.04268646, 31.59588051], [76.04402924, 31.60303116], [76.03997803, 31.60845947], [76.03671265, 31.60679817], [76.03140259, 31.60946083], [76.02319336, 31.61547089], [76.01760101, 31.62167168], [76.00274658, 31.64657021], [76.00624847, 31.65142822], [76.00392151, 31.65689087], [76.00473022, 31.66303062], [75.99736023, 31.66888046], [75.99742126, 31.6760006], [75.99469757, 31.68154907], [75.99214935, 31.68452072], [75.99098969, 31.68575096], [75.99066162, 31.6847496], [75.98562622, 31.68539047], [75.97579193, 31.69532967], [75.97737122, 31.70499992], [75.97257996, 31.71515274], [75.96936798, 31.71967125], [75.96602631, 31.73345947], [75.96100616, 31.73677254], [75.95755005, 31.7404995], [75.95974731, 31.74430275], [75.9595108, 31.74953842], [75.95189667, 31.76301956], [75.94506073, 31.78128052], [75.93644714, 31.78434944], [75.93582153, 31.78974915], [75.93300629, 31.7971096], [75.92722321, 31.80514908], [75.92182922, 31.81718063], [75.92675018, 31.81644058], [75.92932892, 31.81524086], [75.93325043, 31.81501961], [75.9360733, 31.81826019], [75.94877625, 31.8231411], [75.95289612, 31.82396126], [75.96031189, 31.81847954], [75.96697998, 31.81488991], [75.97146606, 31.81454849], [75.97091675, 31.81921005], [75.96762848, 31.82351112], [75.95575714, 31.83237076], [75.95358276, 31.83995056], [75.94972992, 31.84810066], [75.94425201, 31.85751915], [75.93840027, 31.8678894], [75.93144226, 31.88383102], [75.92617035, 31.88979149], [75.91268921, 31.91657829], [75.90276337, 31.92791939], [75.89595795, 31.94025993], [75.89454651, 31.94980049], [75.87771606, 31.96198082], [75.86972046, 31.96597099], [75.8685379, 31.96690941], [75.86617279, 31.96882057], [75.85679626, 31.96945953], [75.8513031, 31.97253036], [75.84162903, 31.97361946], [75.83637238, 31.9816494], [75.81404877, 31.98340034], [75.80560303, 31.98501968], [75.79512024, 31.9885807], [75.7842865, 31.99432945], [75.77429962, 32.00078964], [75.76644897, 32.00764084], [75.76154327, 32.01390076], [75.75380707, 32.0198822], [75.74836731, 32.02716064], [75.74003601, 32.03448105], [75.73800659, 32.03580093], [75.73397827, 32.03733063], [75.72322845, 32.03617096], [75.71048737, 32.03602219], [75.70040894, 32.04359055], [75.692276, 32.05945206], [75.68981934, 32.06153107], [75.67310333, 32.06692123], [75.64936066, 32.07717133], [75.6400528, 32.07674026], [75.62532043, 32.07266998], [75.60955811, 32.06946945], [75.598526, 32.06600952], [75.57875824, 32.0816803], [75.61055756, 32.09960937], [75.6312027, 32.11949921], [75.64787292, 32.13766098], [75.65547943, 32.14606094], [75.66182709, 32.16466904], [75.65615845, 32.17662048], [75.64958954, 32.17969131], [75.62021637, 32.18516922], [75.6194458, 32.18984985], [75.61833191, 32.19702148], [75.62011719, 32.22021103], [75.62177277, 32.23003006], [75.62254333, 32.23468018], [75.63407898, 32.24473953], [75.64092255, 32.2473793], [75.65244293, 32.25543976], [75.65487671, 32.25585175], [75.67584229, 32.26401901], [75.68489075, 32.26501846], [75.70487976, 32.26723862], [75.73639679, 32.27376175], [75.75183868, 32.28417206], [75.75467682, 32.28607941], [75.76185608, 32.29611206], [75.7633667, 32.30215073], [75.78314209, 32.32220078], [75.78549194, 32.3237915], [75.79371643, 32.3323822], [75.79927826, 32.33737183], [75.81391907, 32.35055923], [75.81887054, 32.35503006], [75.83740234, 32.37302017], [75.8438797, 32.37931061], [75.86631012, 32.39456177], [75.87193298, 32.39844894], [75.91110992, 32.40919113], [75.91542053, 32.41025925], [75.92592621, 32.41178131], [75.93216705, 32.41682053], [75.93463135, 32.42475891], [75.93141174, 32.43078995], [75.92443848, 32.4389801], [75.91549683, 32.44869995], [75.89541626, 32.46186066], [75.88712311, 32.47203064], [75.86876678, 32.48868179], [75.85527802, 32.49958038], [75.85096741, 32.50786972], [75.85138702, 32.5213089], [75.85636902, 32.53768921], [75.87030029, 32.55876923], [75.87545013, 32.57086182], [75.87254333, 32.57619095], [75.8862915, 32.59191895], [75.90458679, 32.61521912], [75.90776062, 32.61914063], [75.92362213, 32.64369965], [75.92543793, 32.65427017], [75.92405701, 32.6582222], [75.91475677, 32.6659317], [75.90540314, 32.67224884], [75.89885712, 32.6806221], [75.89657593, 32.69105911], [75.89906311, 32.70024872], [75.90486145, 32.70936203], [75.90983582, 32.72093964], [75.91404724, 32.74201965], [75.91248322, 32.75712204], [75.90006256, 32.76985931], [75.88568115, 32.79547882], [75.87378693, 32.81369019], [75.85523987, 32.82614136], [75.83738708, 32.8367691], [75.82752991, 32.84037018], [75.82106018, 32.84276199], [75.81581116, 32.84706116], [75.80831146, 32.85319901], [75.80551147, 32.85614014], [75.79537201, 32.86925888], [75.79464722, 32.87018967], [75.78983307, 32.88140106], [75.78917694, 32.88462067], [75.78742218, 32.89332199], [75.78987885, 32.89398193], [75.79380798, 32.89731216], [75.7983551, 32.90216446], [75.80000305, 32.90391922], [75.80175781, 32.91027069], [75.79830933, 32.91942215], [75.80332184, 32.92354965], [75.80795288, 32.9297905], [75.82142639, 32.93347168], [75.82811737, 32.93408203], [75.83389282, 32.93460083], [75.85006714, 32.93115997], [75.86711884, 32.93021011], [75.88089752, 32.92477036], [75.90011597, 32.91569901], [75.91356659, 32.90621185], [75.92323303, 32.89809036], [75.93377686, 32.88431168], [75.93955231, 32.88422012], [75.94577026, 32.88513947], [75.98320007, 32.90040207], [75.98741913, 32.90058136], [75.99752808, 32.90937042], [76.00463104, 32.91400909], [76.01351166, 32.91593933], [76.01718903, 32.91764069], [76.02117157, 32.92443085], [76.02365112, 32.93157959], [76.02807617, 32.93743896], [76.04260254, 32.94023895], [76.05039978, 32.94427109], [76.05446625, 32.9509697], [76.06587982, 32.95798111], [76.06999969, 32.96221924], [76.07834625, 32.96607208], [76.08220673, 32.96879959], [76.08567047, 32.97500992], [76.09123993, 32.99275208], [76.09455872, 33.00032043], [76.09368896, 33.00482941], [76.10732269, 33.00788879], [76.1159668, 33.0085907], [76.12049103, 33.01042175], [76.12819672, 33.01008224], [76.14389038, 33.01647949], [76.15223694, 33.02289963], [76.18830109, 33.02758026], [76.21615601, 33.02857208], [76.2294693, 33.03026199], [76.22978973, 33.03083038], [76.23728943, 33.03258896], [76.25524139, 33.05228043], [76.26751709, 33.08610916], [76.2712326, 33.09635925], [76.27584076, 33.09803009], [76.27687073, 33.10063171], [76.27500153, 33.10398865], [76.28800201, 33.11315918], [76.29194641, 33.12020874], [76.30692291, 33.12722015], [76.3155365, 33.13019943], [76.33558655, 33.14627075], [76.35212708, 33.15483856], [76.35578918, 33.15460205], [76.3588562, 33.15750122], [76.36080933, 33.16275024], [76.36615753, 33.16804123], [76.37351227, 33.17346191], [76.37985229, 33.17646027], [76.38455963, 33.18289185], [76.39167786, 33.18669128], [76.40067291, 33.18656158], [76.40769196, 33.18841934], [76.42177582, 33.18180847], [76.42977142, 33.18281174], [76.44181061, 33.18046951], [76.45020294, 33.18291855], [76.45555115, 33.18331909], [76.46614075, 33.17988205], [76.46906281, 33.17990875], [76.48877716, 33.19015884], [76.49597168, 33.19602966], [76.4988327, 33.19668961], [76.50576019, 33.19578171], [76.52023315, 33.20040894], [76.53417969, 33.19934845], [76.54196167, 33.20677185], [76.54747772, 33.20952988], [76.55589294, 33.20685196], [76.56295013, 33.20618057], [76.56761932, 33.20705032], [76.57673645, 33.2057991], [76.58190155, 33.20687103], [76.58618927, 33.20421982], [76.58470154, 33.19956207], [76.58403778, 33.19306946], [76.58799744, 33.18999863], [76.59253693, 33.19063187], [76.59732819, 33.18803024], [76.59886169, 33.18391037], [76.5984726, 33.17650986], [76.59958649, 33.17375946], [76.61255646, 33.16596985], [76.62700653, 33.1624794], [76.64074707, 33.16468048], [76.65110779, 33.17182922], [76.65873718, 33.17116928], [76.65944672, 33.17111206], [76.66055298, 33.17134857], [76.66947937, 33.17332077], [76.68527222, 33.17404175], [76.69365692, 33.17760086], [76.69671631, 33.18148041], [76.70847321, 33.18130112], [76.71418762, 33.17744064], [76.72986603, 33.17943192], [76.73060608, 33.18527985], [76.73435211, 33.19311905], [76.74212646, 33.19749069], [76.74558258, 33.20434952], [76.75055695, 33.21012878], [76.75605011, 33.21982193], [76.75988007, 33.22467041], [76.76235962, 33.2395401], [76.75756836, 33.2431221], [76.75520325, 33.24740982], [76.75534058, 33.24948883], [76.75688171, 33.25054169], [76.75997162, 33.25297928], [76.76355743, 33.25432968], [76.77826691, 33.2557106], [76.78543854, 33.25358963], [76.79693604, 33.24121094], [76.80275726, 33.23666], [76.8062973, 33.23622894], [76.80845642, 33.24232101], [76.80916595, 33.24430084], [76.81394196, 33.24744034], [76.817276, 33.24850082], [76.8219223, 33.24835205], [76.82354736, 33.24785995], [76.82717133, 33.24674988], [76.82834625, 33.24639893], [76.82887268, 33.2425499], [76.82319641, 33.23738098], [76.81785583, 33.23114014], [76.81304932, 33.2227211], [76.81108093, 33.21546173], [76.81716156, 33.21223068], [76.81858826, 33.20557022], [76.80330658, 33.19385147], [76.80661011, 33.18473053], [76.80517578, 33.18225861], [76.80042267, 33.17779922], [76.79812622, 33.1733017], [76.799263, 33.1694603], [76.80201721, 33.16603088], [76.80143738, 33.16154099], [76.80345917, 33.15568924], [76.80948639, 33.14855194], [76.81495667, 33.14617157], [76.81725311, 33.14200211], [76.82296753, 33.14128876], [76.82917023, 33.13772202], [76.82808685, 33.13167953], [76.83740234, 33.12638855], [76.83410645, 33.12055969], [76.8391571, 33.11529922], [76.84443665, 33.11230087], [76.85256958, 33.11154938], [76.86044312, 33.11637878], [76.86869049, 33.12022018], [76.87719727, 33.11423874], [76.87741852, 33.1072197], [76.88477325, 33.09743881], [76.89431, 33.09513855], [76.89498901, 33.09141922], [76.89093018, 33.08459854], [76.89074707, 33.08076096], [76.89639282, 33.07580948], [76.89694214, 33.07099152], [76.90011597, 33.06414032], [76.9102478, 33.05020905], [76.91332245, 33.04420853], [76.91461182, 33.03882217], [76.91751099, 33.03367996], [76.92414856, 33.02896881], [76.93266296, 33.02845001], [76.94832611, 33.01848984], [76.95677948, 33.01673889], [76.96212769, 33.01393127], [76.96370697, 33.01004028], [76.96652222, 33.00720978], [76.98082733, 33.00146103], [76.98693848, 32.99592209], [76.99147034, 32.99285889], [76.99401855, 32.9922905], [76.99846649, 32.98957062], [77.0112381, 32.99324036], [77.01992035, 32.99174881], [77.02442169, 32.99695969], [77.03531647, 32.99967957], [77.05237579, 32.9908905], [77.05847168, 32.98608017], [77.06593323, 32.98553085], [77.07167053, 32.97623062], [77.07489777, 32.97335052], [77.08418274, 32.97367096], [77.09712219, 32.97758102], [77.10315704, 32.98720169], [77.11238098, 32.98413086], [77.12007141, 32.98271179], [77.12750244, 32.98384094], [77.13639069, 32.98046112], [77.13585663, 32.97444916], [77.13430786, 32.96949005], [77.13553619, 32.96467972], [77.13527679, 32.96094131], [77.13638306, 32.9577713], [77.14612579, 32.95639038], [77.14611053, 32.94277191], [77.14878082, 32.94137955], [77.14855194, 32.93791199], [77.14694977, 32.93437958], [77.15072632, 32.92023087], [77.14618683, 32.91402054], [77.15743256, 32.91323853], [77.16043091, 32.91608047], [77.16156769, 32.92111969], [77.16372681, 32.92510986], [77.1665802, 32.92805099], [77.17385864, 32.93112946], [77.18180084, 32.91545105], [77.18895721, 32.91006088], [77.20453644, 32.90637207], [77.21798706, 32.89731216], [77.22825623, 32.89556885], [77.22930145, 32.88679886], [77.22746277, 32.88393021], [77.22408295, 32.88270187], [77.224823, 32.88002014], [77.22782898, 32.8769722], [77.23626709, 32.87229919], [77.23802948, 32.86901093], [77.23887634, 32.8651619], [77.24758148, 32.8649292], [77.25831604, 32.87636185], [77.27009583, 32.86640167], [77.27433777, 32.85976028], [77.28128052, 32.85565186], [77.28874207, 32.85261917], [77.29795837, 32.85401154], [77.30516052, 32.85404968], [77.3125, 32.84630966], [77.31086731, 32.83766937], [77.31651306, 32.82975006], [77.32065582, 32.82810211], [77.32161713, 32.82239151], [77.32789612, 32.81988144], [77.33596039, 32.81890869], [77.34046173, 32.82054138], [77.3483963, 32.82120132], [77.35647583, 32.82527161], [77.35955048, 32.83816147], [77.36184692, 32.84260941], [77.3626709, 32.84659958], [77.35980988, 32.85161972], [77.35871887, 32.85639954], [77.35968018, 32.85958099], [77.36306763, 32.86352921], [77.37124634, 32.8674202], [77.3793869, 32.88082886], [77.38746643, 32.88552094], [77.39541626, 32.8873291], [77.39733124, 32.88698959], [77.39917755, 32.88393021], [77.40312195, 32.88145065], [77.41013336, 32.8782196], [77.4177475, 32.87921143], [77.42572021, 32.88367081], [77.43122101, 32.87582016], [77.43224335, 32.87044907], [77.43617249, 32.8658905], [77.448349, 32.86167908], [77.45522308, 32.86174011], [77.47318268, 32.87879181], [77.48455048, 32.88653946], [77.49434662, 32.88151169], [77.50623322, 32.8830719], [77.5112915, 32.88542938], [77.51956177, 32.88737869], [77.52320099, 32.88978195], [77.52700043, 32.89228058], [77.53531647, 32.90229034], [77.54471588, 32.91173172], [77.54949188, 32.9133606], [77.55384827, 32.91310883], [77.56964874, 32.92166138], [77.57966614, 32.93167877], [77.58096313, 32.93450165], [77.58152771, 32.93923187], [77.58392334, 32.94380188], [77.58637238, 32.93989944], [77.59343719, 32.94153976], [77.60614777, 32.94240952], [77.61071014, 32.94231033], [77.61296082, 32.94141006], [77.61725616, 32.94400024], [77.62336731, 32.94454193], [77.6384964, 32.95613861], [77.64334869, 32.95785141], [77.64987946, 32.9582901], [77.65331268, 32.95940018], [77.65637207, 32.96596146], [77.6599884, 32.96895981], [77.66307831, 32.97592926], [77.66520691, 32.98603058], [77.67086029, 32.9862709], [77.6780014, 32.98072052], [77.67948914, 32.97777939], [77.69087219, 32.97941971], [77.69500732, 32.97782135], [77.69670868, 32.97335052], [77.69988251, 32.96903992], [77.70368958, 32.9661293], [77.70832825, 32.96731949], [77.71248627, 32.97180176], [77.7231369, 32.96435928], [77.7273407, 32.95755005], [77.73412323, 32.9503212], [77.73641968, 32.94787216], [77.73895264, 32.94726944], [77.74478912, 32.94586945], [77.74717712, 32.94221115], [77.74745941, 32.9405098], [77.74762726, 32.93941879], [77.75099182, 32.93603134], [77.75956726, 32.92741013], [77.7780304, 32.91577911], [77.78174591, 32.91003036], [77.79016876, 32.90542984], [77.79250336, 32.89807892], [77.7869873, 32.8916893], [77.77274323, 32.8909111], [77.76597595, 32.88029099], [77.76142883, 32.86483002], [77.76772308, 32.85847092], [77.77578735, 32.854702], [77.78087616, 32.85409927], [77.78774261, 32.84976196], [77.79187775, 32.84926987], [77.79899597, 32.84584045], [77.80821228, 32.8360405], [77.8143158, 32.8361702], [77.81881714, 32.83853149], [77.8250885, 32.83987045], [77.83138275, 32.83504105], [77.84760284, 32.8284111], [77.85254669, 32.82518005], [77.85497284, 32.82118988], [77.86126709, 32.81616211], [77.86383057, 32.81145096], [77.86454773, 32.80651855], [77.8690033, 32.80036926], [77.86696625, 32.79029083], [77.87224579, 32.78625107], [77.876297, 32.78001022], [77.88089752, 32.7754097], [77.88748169, 32.77526093], [77.89087677, 32.77450943], [77.89949799, 32.77532196], [77.90349579, 32.77289963], [77.90892792, 32.77212143], [77.91227722, 32.76716995], [77.91513062, 32.76605988], [77.91689301, 32.76272964], [77.9179306, 32.75691986], [77.91716003, 32.75188065], [77.91440582, 32.74454117], [77.9143219, 32.74177933], [77.91182709, 32.73651123], [77.91562653, 32.73369217], [77.91847229, 32.73078918], [77.91203308, 32.72576904], [77.90943909, 32.72138977], [77.90847778, 32.7163887], [77.90625763, 32.71234894], [77.90566254, 32.70359039], [77.90239716, 32.69841003], [77.90325165, 32.69309998], [77.9109726, 32.68817902], [77.92021179, 32.67951202], [77.9262085, 32.66680908], [77.92716217, 32.66262054], [77.93229675, 32.65620041], [77.93891144, 32.6480217], [77.9464798, 32.64273071], [77.95265961, 32.64039993], [77.95510101, 32.63481903], [77.95424652, 32.6259613], [77.95947266, 32.62073898], [77.96222687, 32.61380005], [77.96784973, 32.60797882], [77.9749527, 32.5963707], [77.97669983, 32.59194183], [77.9825592, 32.58652878], [77.98705292, 32.58819962], [78.01743317, 32.5870285], [78.02744293, 32.58864975], [78.03579712, 32.59194946], [78.04161072, 32.59923935], [78.04146576, 32.6053009], [78.03675842, 32.61085892], [78.03443146, 32.61565018], [78.03244019, 32.62839127], [78.03273773, 32.63375092], [78.0338974, 32.63560867], [78.0440979, 32.6288414], [78.05901337, 32.62458038], [78.06533051, 32.62427902], [78.06745911, 32.6256218], [78.07293701, 32.64440155], [78.07900238, 32.65279007], [78.08851624, 32.659832], [78.09337616, 32.66215134], [78.09926605, 32.65996933], [78.106987, 32.64974213], [78.11615753, 32.64241028], [78.12149811, 32.64234924], [78.12666321, 32.64910126], [78.13066101, 32.66006088], [78.13600159, 32.6703186], [78.14444733, 32.67660141], [78.15254211, 32.67901993], [78.15841675, 32.67913055], [78.17047882, 32.67721176], [78.17951202, 32.67041016], [78.18395233, 32.66387177], [78.19499207, 32.6673317], [78.20163727, 32.66519928], [78.2129364, 32.66918945], [78.22496796, 32.67556], [78.23326111, 32.68370056], [78.23658752, 32.69467163], [78.25911713, 32.70291901], [78.27274323, 32.70293045], [78.28486633, 32.70677948], [78.29572296, 32.71281052], [78.2985611, 32.71974182], [78.29811096, 32.72483063], [78.2946167, 32.73160934], [78.28765869, 32.73783112], [78.31394958, 32.74898148], [78.34474182, 32.76343155], [78.3642807, 32.76298141], [78.37135315, 32.76182938], [78.37277222, 32.76015091], [78.3707428, 32.74584961], [78.37121582, 32.7336998], [78.37494659, 32.72264862], [78.37782288, 32.71931076], [78.36756897, 32.69952011], [78.36367798, 32.68553162], [78.36315155, 32.67198944], [78.3709259, 32.63816071], [78.3759079, 32.62961197], [78.38881683, 32.62322998], [78.37706757, 32.61487961], [78.34062195, 32.59305954], [78.33175659, 32.58486938], [78.31799316, 32.58021164], [78.30236816, 32.57870102], [78.29662323, 32.57751083], [78.29917145, 32.52927017], [78.29503632, 32.52246094], [78.27851868, 32.50793076], [78.30623627, 32.47774887], [78.31040955, 32.47592926], [78.35636139, 32.51266098], [78.3766861, 32.52605057], [78.38243103, 32.52965164], [78.39438629, 32.52853012], [78.3979187, 32.52706909], [78.39906311, 32.526371], [78.4002533, 32.52368164], [78.40141296, 32.51818085], [78.40525818, 32.51512146], [78.40522766, 32.51422882], [78.40892029, 32.51271057], [78.40917206, 32.51202011], [78.41075897, 32.51174164], [78.41497803, 32.51100159], [78.41651917, 32.51115036], [78.42565918, 32.51203156], [78.4316864, 32.51028061], [78.43557739, 32.50774002], [78.43637085, 32.507061], [78.43839264, 32.50535202], [78.43998718, 32.50320053], [78.44064331, 32.50054169], [78.44352722, 32.49930191], [78.44503784, 32.49790955], [78.44763947, 32.49240875], [78.44872284, 32.49013901], [78.44867706, 32.48921967], [78.448349, 32.48719025], [78.44795227, 32.48635864], [78.44577026, 32.48207855], [78.44327545, 32.47946167], [78.44159698, 32.47769928], [78.44100952, 32.47677994], [78.43733215, 32.47106171], [78.43579865, 32.46606064], [78.43543243, 32.46257019], [78.43662262, 32.45936966], [78.43714142, 32.4591217], [78.43710327, 32.45800018], [78.4381485, 32.45705032], [78.43811035, 32.45639038], [78.4414978, 32.45471191], [78.44315338, 32.45431137], [78.44599915, 32.45351028], [78.45474243, 32.45055008], [78.46199036, 32.44797897], [78.46611786, 32.44515991], [78.46681976, 32.44311142], [78.46761322, 32.44285202], [78.46817017, 32.44282913], [78.46813965, 32.442379], [78.46868134, 32.44213104], [78.47087097, 32.43733978], [78.47102356, 32.43727112], [78.47135925, 32.43711853], [78.47190857, 32.43687057], [78.47299957, 32.43291855], [78.47360229, 32.43252945], [78.47486877, 32.4311409], [78.47509766, 32.43022919], [78.47663879, 32.42905045], [78.47659302, 32.42747879], [78.4779129, 32.42673874], [78.47814178, 32.42586136], [78.4836731, 32.42501068], [78.48732758, 32.42525864], [78.50258636, 32.42621994], [78.51151276, 32.42370224], [78.51445007, 32.42193985], [78.51876068, 32.41849899], [78.51721954, 32.41313934], [78.5166626, 32.41249847], [78.50498962, 32.40293121], [78.5038681, 32.40182114], [78.50211334, 32.40050888], [78.50171661, 32.40005875], [78.49762726, 32.39524078], [78.49588013, 32.39076996], [78.49397278, 32.37731171], [78.49172211, 32.37329865], [78.48503876, 32.36769104], [78.48403168, 32.36685944], [78.48291779, 32.36587906], [78.47731018, 32.36291504], [78.46798706, 32.35799026], [78.46460724, 32.35316086], [78.46407318, 32.35223007], [78.462883, 32.34957123], [78.46129608, 32.34296036], [78.46069336, 32.33721924], [78.46124268, 32.3370018], [78.46465302, 32.32064056], [78.46533203, 32.31230927], [78.46697998, 32.29190063], [78.46615601, 32.28401947], [78.46431732, 32.27777863], [78.46273041, 32.27613068], [78.45915222, 32.27070999], [78.45844269, 32.26914978], [78.45649719, 32.26784897], [78.45397186, 32.26409149], [78.45291138, 32.26364136], [78.45083618, 32.26189041], [78.45053101, 32.26142883], [78.44835663, 32.25823975], [78.4471817, 32.25712204], [78.4454422, 32.25576019], [78.44503021, 32.25535965], [78.44168091, 32.25183105], [78.44090271, 32.25162125], [78.43942261, 32.24827194], [78.43920898, 32.24645996], [78.4467392, 32.24580002], [78.44790649, 32.24568939], [78.4590683, 32.24544144], [78.46013641, 32.24518204], [78.46411896, 32.24596024], [78.4776001, 32.24392319], [78.48284912, 32.24312973], [78.50154114, 32.24571991], [78.50588226, 32.24784088], [78.51389313, 32.24943161], [78.52024078, 32.2501297], [78.52075958, 32.25017929], [78.52374268, 32.25045013], [78.53569794, 32.24982071], [78.53942108, 32.24998093], [78.54308319, 32.24874115], [78.56223297, 32.23731995], [78.57392883, 32.23133087], [78.59291077, 32.21866989], [78.59339905, 32.21775055], [78.59430695, 32.21712875], [78.59509277, 32.21667862], [78.59516144, 32.21575928], [78.59513092, 32.21147919], [78.59111786, 32.20394135], [78.59049988, 32.19763184], [78.59126282, 32.19738007], [78.59420013, 32.18848038], [78.59369659, 32.18241882], [78.5922699, 32.17996216], [78.58950806, 32.17396164], [78.58876038, 32.17150116], [78.58531952, 32.16894913], [78.58409882, 32.16847992], [78.57802582, 32.16553116], [78.57784271, 32.16508102], [78.57728577, 32.16508102], [78.57457733, 32.16154099], [78.5743103, 32.15861893], [78.57467651, 32.1577301], [78.57572174, 32.15768051], [78.57623291, 32.15655136], [78.57968903, 32.15446854], [78.58830261, 32.14736938], [78.58878326, 32.14598846], [78.58953094, 32.14554977], [78.58994293, 32.14234924], [78.59121704, 32.1411705], [78.59249878, 32.14001083], [78.59420776, 32.13566971], [78.59448242, 32.13188934], [78.59632874, 32.12340927], [78.59713745, 32.12295151], [78.59733582, 32.12203217], [78.59928894, 32.12091064], [78.59947205, 32.12034988], [78.6062088, 32.11748886], [78.6101532, 32.11779022], [78.61593628, 32.11581039], [78.61646271, 32.1160202], [78.61709595, 32.11621857], [78.62861633, 32.11495209], [78.63961029, 32.11212158], [78.64787292, 32.10713196], [78.64839935, 32.10643005], [78.64900208, 32.1053009], [78.64965057, 32.09870911], [78.65106201, 32.09334946], [78.65241241, 32.08826065], [78.65672302, 32.08383179], [78.65740967, 32.08132172], [78.65796661, 32.08087921], [78.65976715, 32.07947159], [78.65985107, 32.07901001], [78.66079712, 32.0782814], [78.67437744, 32.06927872], [78.68080139, 32.0638504], [78.68132019, 32.06343079], [78.68205261, 32.0622406], [78.68255615, 32.0608902], [78.68482971, 32.05857086], [78.68611145, 32.05762863], [78.68760681, 32.05335999], [78.68814087, 32.0531311], [78.68882751, 32.05257034], [78.68940735, 32.05097198], [78.69011688, 32.04573059], [78.69076538, 32.04523087], [78.6934433, 32.04315948], [78.69394684, 32.04270935], [78.69391632, 32.04179001], [78.69548798, 32.04130936], [78.69593048, 32.03990936], [78.69696808, 32.0392189], [78.69747162, 32.03874207], [78.70517731, 32.03369904], [78.70540619, 32.03306961], [78.71192932, 32.02927017], [78.71691132, 32.02524948], [78.7171402, 32.02460098], [78.72258759, 32.02040863], [78.72283936, 32.01976013], [78.72547913, 32.0175209], [78.72593689, 32.01626968], [78.72688293, 32.0132103], [78.72766113, 32.01295853], [78.72808838, 32.01264572], [78.72894287, 32.01202011], [78.72915649, 32.01110077], [78.72969818, 32.01087952], [78.73017883, 32.00951004], [78.73014069, 32.00881958], [78.73117828, 32.0083313], [78.73140717, 32.00764847], [78.73706818, 32.00408173], [78.73948669, 32.00447083], [78.75055695, 32.00363922], [78.75314331, 32.00302887], [78.76055908, 32.00123215], [78.76837921, 31.99989128], [78.76995087, 31.99938965], [78.77102661, 31.99981117], [78.77099609, 31.99641991], [78.77057648, 31.99494171], [78.77039337, 31.99451065], [78.76918793, 31.99131966], [78.76106262, 31.96377945], [78.75750732, 31.95465851], [78.75608063, 31.95028877], [78.75258636, 31.93956947], [78.75026703, 31.93465042], [78.7454071, 31.9250412], [78.74027252, 31.9199791], [78.73953247, 31.9197998], [78.73751068, 31.91740036], [78.73596954, 31.91605186], [78.7352066, 31.91584969], [78.73490143, 31.91513062], [78.73454285, 31.91476059], [78.73275757, 31.91303062], [78.73235321, 31.90962982], [78.73127747, 31.90888977], [78.73015594, 31.90814972], [78.72944641, 31.90658951], [78.72927094, 31.90571022], [78.73104858, 31.9043026], [78.73137665, 31.90293121], [78.7315979, 31.89818001], [78.7283783, 31.89001274], [78.72764587, 31.88948059], [78.72720337, 31.88865089], [78.72476196, 31.88500023], [78.72450256, 31.88433266], [78.7243576, 31.88396072], [78.72409821, 31.8832798], [78.72377014, 31.88150024], [78.72402954, 31.87516975], [78.7233963, 31.84698105], [78.72193909, 31.83798981], [78.7217865, 31.83732986], [78.72052765, 31.83533096], [78.71969604, 31.83492088], [78.71835327, 31.83426285], [78.70378876, 31.82682991], [78.70205688, 31.82576942], [78.70149994, 31.82579041], [78.70134735, 31.82533073], [78.70095825, 31.82447052], [78.70041656, 31.82449913], [78.69468689, 31.81719017], [78.69297028, 31.81431961], [78.69242859, 31.81264114], [78.69081116, 31.80672073], [78.69120789, 31.79692841], [78.69135284, 31.79335022], [78.69322205, 31.78652954], [78.69386292, 31.78593826], [78.69429779, 31.78375053], [78.69626617, 31.77878189], [78.69703674, 31.77806664], [78.70083618, 31.77453995], [78.70184326, 31.77362061], [78.70332336, 31.77040863], [78.71383667, 31.76739311], [78.71555328, 31.76690292], [78.72183228, 31.76506805], [78.72466278, 31.7638607], [78.72402191, 31.76005173], [78.71985626, 31.75636482], [78.71688843, 31.75374031], [78.71627808, 31.75254059], [78.71514893, 31.75032997], [78.7141571, 31.74924088], [78.7117691, 31.7448597], [78.71134186, 31.74126244], [78.71187592, 31.74103928], [78.71237946, 31.74078941], [78.71259308, 31.73896027], [78.71334076, 31.73851013], [78.71409607, 31.73802948], [78.71430969, 31.73665047], [78.71845245, 31.73450279], [78.72007751, 31.7319603], [78.7206192, 31.73195076], [78.72146606, 31.73032951], [78.72310638, 31.72544289], [78.72367859, 31.72373962], [78.72567749, 31.71780014], [78.72860718, 31.70236015], [78.73195648, 31.69771004], [78.73324585, 31.69597054], [78.73439789, 31.69198036], [78.7351532, 31.69153023], [78.7352829, 31.69094086], [78.7360611, 31.69046021], [78.73995972, 31.68803978], [78.74752808, 31.68510056], [78.74843597, 31.68514061], [78.74990082, 31.68472099], [78.75211334, 31.68491745], [78.7536087, 31.68505096], [78.75463867, 31.68478966], [78.76481628, 31.68617058], [78.77139282, 31.68787193], [78.77316284, 31.68841171], [78.77964783, 31.68984032], [78.78022003, 31.68756104], [78.78065491, 31.67563248], [78.7807312, 31.67350769], [78.78076172, 31.67266273], [78.78423309, 31.66126251], [78.786026, 31.65983009], [78.78650665, 31.65846062], [78.78674316, 31.65755081], [78.78749847, 31.65707016], [78.78927612, 31.65476036], [78.79235077, 31.65221024], [78.79305267, 31.65113068], [78.79458618, 31.65031815], [78.79457855, 31.64986992], [78.79534912, 31.64915848], [78.80890656, 31.63991165], [78.80967712, 31.63957024], [78.81669617, 31.63648033], [78.81987, 31.63379097], [78.82364655, 31.6307106], [78.8240509, 31.63038254], [78.82483673, 31.62935066], [78.82688904, 31.62799072], [78.82724762, 31.6273098], [78.82762146, 31.62658119], [78.82759857, 31.62569046], [78.82832336, 31.62507057], [78.82852173, 31.62467957], [78.8306427, 31.62045097], [78.83117676, 31.61988258], [78.83109283, 31.61526108], [78.82756042, 31.60722923], [78.82447052, 31.60281181], [78.8237915, 31.60238838], [78.82280731, 31.60062027], [78.81893158, 31.59753036], [78.81794739, 31.59621048], [78.81501007, 31.59365082], [78.81394958, 31.59325981], [78.81297302, 31.59215927], [78.81224823, 31.59082985], [78.81099701, 31.58904839], [78.81027222, 31.58839035], [78.80948639, 31.58819008], [78.80918121, 31.5874691], [78.80513, 31.58324051], [78.79728699, 31.5761528], [78.79136658, 31.57364845], [78.78475189, 31.57139015], [78.76811981, 31.56574059], [78.76808929, 31.56505966], [78.76374054, 31.56213951], [78.76119232, 31.55750275], [78.75759888, 31.55356026], [78.75000763, 31.54883003], [78.74658203, 31.54771996], [78.73008728, 31.54426956], [78.72126007, 31.54095078], [78.71916199, 31.53675079], [78.71716309, 31.53046989], [78.71644592, 31.52992058], [78.71562958, 31.52975082], [78.71533966, 31.52907944], [78.70868683, 31.52396965], [78.70677185, 31.52110291], [78.70664215, 31.51839256], [78.70807648, 31.5149498], [78.71514893, 31.50773048], [78.71605682, 31.5038681], [78.71604919, 31.48717117], [78.71658325, 31.48488235], [78.71917725, 31.48411942], [78.72357941, 31.48595428], [78.72376251, 31.48603058], [78.72901154, 31.48713684], [78.7441864, 31.49032974], [78.74680328, 31.49045944], [78.74814606, 31.49087906], [78.74893188, 31.49061966], [78.75150299, 31.48894119], [78.7545929, 31.48072052], [78.76048279, 31.47648048], [78.76122284, 31.47577286], [78.76120758, 31.47521973], [78.76119232, 31.47487259], [78.76229858, 31.47425461], [78.76557159, 31.47243118], [78.76611328, 31.47212982], [78.76635742, 31.47144127], [78.76818085, 31.47093964], [78.77147675, 31.46914291], [78.7730484, 31.46751022], [78.77419281, 31.46620941], [78.77909851, 31.46301079], [78.78018188, 31.46197128], [78.79245758, 31.45535088], [78.79547882, 31.4527626], [78.79693604, 31.44908905], [78.79727173, 31.44458961], [78.79601288, 31.43964195], [78.79579926, 31.43447113], [78.79563904, 31.43063927], [78.79248047, 31.41785812], [78.78972626, 31.41547012], [78.78357697, 31.41296005], [78.78242493, 31.41224861], [78.78185272, 31.41189003], [78.78166962, 31.41098976], [78.78112793, 31.41054153], [78.77648163, 31.40665817], [78.77603912, 31.40237808], [78.77632904, 31.40154648], [78.77643585, 31.40122986], [78.77783966, 31.40143013], [78.78202057, 31.40037918], [78.79450226, 31.39653969], [78.80172729, 31.39384079], [78.80796051, 31.39229965], [78.81128693, 31.39081955], [78.81671906, 31.38841057], [78.82103729, 31.38418961], [78.82102203, 31.38329124], [78.82668304, 31.38107109], [78.8272171, 31.3812809], [78.83013153, 31.37553024], [78.83422852, 31.37247086], [78.8347702, 31.37114906], [78.83474731, 31.37046814], [78.83577728, 31.36939049], [78.83757019, 31.36444092], [78.83805847, 31.36423111], [78.84028625, 31.35444069], [78.84014893, 31.3506012], [78.8377533, 31.34502983], [78.83174133, 31.33892059], [78.82871246, 31.3324604], [78.82901001, 31.3302002], [78.83347321, 31.3291111], [78.83506012, 31.32930183], [78.837883, 31.32876015], [78.83867645, 31.32840157], [78.84008026, 31.32769966], [78.84555817, 31.32417107], [78.84838104, 31.32234001], [78.84937286, 31.32096291], [78.85063934, 31.32002068], [78.8506012, 31.31909943], [78.85161591, 31.31839943], [78.85211945, 31.31793022], [78.85340118, 31.31698036], [78.85336304, 31.31607056], [78.85389709, 31.31606102], [78.85824585, 31.31298065], [78.86035156, 31.30913162], [78.86081696, 31.30828094], [78.86135864, 31.30825996], [78.86142731, 31.30766106], [78.86419678, 31.30533028], [78.86463928, 31.30432129], [78.86469269, 31.30372047], [78.86746979, 31.30137825], [78.87005615, 31.29136848], [78.87058258, 31.29112053], [78.87101746, 31.28951263], [78.87152863, 31.2892704], [78.87834167, 31.27287292], [78.87886047, 31.27263069], [78.87953949, 31.27071953], [78.88495636, 31.26679993], [78.88542175, 31.26646042], [78.88955688, 31.26517105], [78.9008255, 31.26128006], [78.90688324, 31.25918961], [78.90585327, 31.2501812], [78.90991211, 31.23388863], [78.91564941, 31.2251606], [78.9196167, 31.22309113], [78.93512726, 31.22236252], [78.93506622, 31.2191906], [78.9332428, 31.21455193], [78.93585205, 31.20568085], [78.94168091, 31.20080185], [78.94486237, 31.19693947], [78.94621277, 31.19355965], [78.95284271, 31.1898098], [78.96092224, 31.18643188], [78.96615601, 31.18599129], [78.96845245, 31.18346977], [78.97187042, 31.18237114], [78.97466278, 31.17810059], [78.97747803, 31.17016029], [78.97767639, 31.15483093], [78.97579956, 31.15070915], [78.97808838, 31.1456604], [78.98480988, 31.14093971], [78.98706055, 31.14060974], [78.98919678, 31.13735962], [78.99077606, 31.13087845], [78.99669647, 31.11758995], [78.99669647, 31.11618042], [78.99658203, 31.11533928], [78.99079895, 31.11709023], [78.98486328, 31.11647034], [78.96565247, 31.1153698], [78.95582581, 31.1108799], [78.95243073, 31.10840988], [78.94211578, 31.10502815], [78.93752289, 31.10534286], [78.93257141, 31.10697937], [78.92047119, 31.10758972], [78.91265869, 31.11618042], [78.90779114, 31.11631966], [78.90379333, 31.11547089], [78.90058136, 31.11206055], [78.89942932, 31.10759926], [78.89679718, 31.10563087], [78.89074707, 31.1060791], [78.88417816, 31.10423279], [78.88004303, 31.10383987], [78.87139893, 31.10732079], [78.86225128, 31.11240959], [78.85202026, 31.12621117], [78.84432983, 31.12804031], [78.83777618, 31.13068962], [78.82897949, 31.13633919], [78.82472229, 31.14355087], [78.81873322, 31.14721107], [78.81587219, 31.15393066], [78.81021881, 31.16386032], [78.81170654, 31.16941071], [78.80050659, 31.1782608], [78.7975769, 31.18250275], [78.7980423, 31.18894958], [78.80111694, 31.1939106], [78.80316925, 31.19923019], [78.8001709, 31.20237923], [78.79503632, 31.20503998], [78.78881073, 31.20445061], [78.77088928, 31.19729996], [78.76460266, 31.1959095], [78.75759125, 31.1946907], [78.74945068, 31.1943512], [78.72038269, 31.19701958], [78.71302795, 31.1966629], [78.70746613, 31.19497108], [78.70069885, 31.19639015], [78.6955719, 31.19629097], [78.67608643, 31.20318985], [78.66575623, 31.20247269], [78.65983582, 31.20325089], [78.65067291, 31.19785118], [78.64769745, 31.19466972], [78.64549255, 31.20251846], [78.63800812, 31.20838928], [78.63600159, 31.2195797], [78.63445282, 31.2218895], [78.62831879, 31.22191811], [78.61711121, 31.22524834], [78.61329651, 31.22743988], [78.61004639, 31.23105049], [78.6006012, 31.23585129], [78.59536743, 31.23639107], [78.58392334, 31.23430061], [78.57939911, 31.23500252], [78.56658173, 31.23373985], [78.56189728, 31.22960091], [78.55632782, 31.22738075], [78.55024719, 31.21849251], [78.537117, 31.20671082], [78.51413727, 31.20392036], [78.48657227, 31.20417023], [78.47698212, 31.20510292], [78.47010803, 31.20375061], [78.46721649, 31.21184921], [78.46656799, 31.22093964], [78.45722198, 31.22781181], [78.44413757, 31.24419975], [78.4316864, 31.24959946], [78.42706299, 31.25597954], [78.41945648, 31.25988007], [78.41438293, 31.25090981], [78.4050827, 31.24867058], [78.3975296, 31.24779129], [78.39134979, 31.25299072], [78.39308167, 31.2622776], [78.38619232, 31.26963043], [78.38327026, 31.2743206], [78.38136292, 31.28147125], [78.37346649, 31.27920914], [78.3692627, 31.28790092], [78.36335754, 31.2901001], [78.35632324, 31.29087067], [78.3474884, 31.29011917], [78.34247589, 31.28897285], [78.33609009, 31.2874794], [78.32663727, 31.28824043], [78.31693268, 31.28507805], [78.30632782, 31.28623962], [78.29836273, 31.28820992], [78.29680634, 31.2844696], [78.29551697, 31.27285957], [78.29341888, 31.2660408], [78.28845978, 31.26420021], [78.27815247, 31.26666069], [78.26902008, 31.2713604], [78.25814056, 31.26036263], [78.25495911, 31.25659943], [78.25324249, 31.25287056], [78.2497406, 31.25055122], [78.24820709, 31.24665833], [78.24263, 31.24336243], [78.23751068, 31.24394035], [78.23764801, 31.2397995], [78.23258972, 31.23501968], [78.21843719, 31.23871994], [78.21209717, 31.23855019], [78.20681763, 31.2372303], [78.20398712, 31.23409081], [78.20027161, 31.22571945], [78.19284058, 31.22291183], [78.18756104, 31.22221947], [78.18492126, 31.22332954], [78.17648315, 31.23003006], [78.17141724, 31.23180962], [78.16581726, 31.23106194], [78.16308594, 31.23150063], [78.16044617, 31.23192024], [78.15542603, 31.23028755], [78.15313721, 31.23068047], [78.14782715, 31.2315712], [78.14583588, 31.22688103], [78.14360809, 31.22407913], [78.137146, 31.22242165], [78.13490295, 31.21611977], [78.11915588, 31.21404076], [78.11380005, 31.20623016], [78.10984802, 31.2056694], [78.10688019, 31.20248985], [78.10079193, 31.19979095], [78.09237671, 31.19283104], [78.08773804, 31.19079971], [78.08007813, 31.19070816], [78.07549286, 31.19291115], [78.07110596, 31.19276047], [78.05915833, 31.19236946], [78.05383301, 31.19293022], [78.03967285, 31.18750954], [78.03874969, 31.18715096], [78.029953, 31.18531036], [78.02688599, 31.18019104], [78.01622009, 31.1715126], [78.01528168, 31.16615105], [78.01654816, 31.15850067], [78.01423645, 31.15493965], [78.00772095, 31.1570797], [77.9925766, 31.16703033], [77.98522949, 31.16802025], [77.97896576, 31.16644096], [77.96938324, 31.1651516], [77.95475769, 31.1787796], [77.94602203, 31.17617035], [77.9412384, 31.17116165], [77.93921661, 31.16730118], [77.93443298, 31.16729164], [77.91468811, 31.15657806], [77.9094162, 31.15550041], [77.9021759, 31.15882111], [77.89279175, 31.15726852], [77.88748932, 31.15470123], [77.88970947, 31.14896965], [77.88575745, 31.14307022], [77.88040161, 31.13743019], [77.87905884, 31.13158989], [77.87872314, 31.12467194], [77.87275696, 31.12321091], [77.85787201, 31.11623955], [77.85153198, 31.11096954], [77.8501358, 31.10420036], [77.85037994, 31.09516907], [77.84282684, 31.0812912], [77.83746338, 31.07751083], [77.8310318, 31.07703972], [77.82472992, 31.07443047], [77.81954956, 31.06491089], [77.81469727, 31.06090164], [77.80947876, 31.05973244], [77.80960846, 31.06137085], [77.8068924, 31.06233025], [77.80060577, 31.06208038], [77.80491638, 31.05877113], [77.80502319, 31.05406952], [77.81067657, 31.04359055], [77.81511688, 31.03392982], [77.81880951, 31.03230095], [77.82160187, 31.02992058], [77.82106018, 31.02108002], [77.81884766, 31.01579094], [77.82270813, 31.01180077], [77.82533264, 31.00813293], [77.82470703, 31.0051899], [77.81005096, 31.00521088], [77.81028748, 31.00213051], [77.81360626, 30.99892044], [77.81091309, 30.9953804], [77.80754089, 30.99384117], [77.80621338, 30.98806], [77.80648041, 30.98503113], [77.80621338, 30.98348045], [77.80523682, 30.98163986], [77.80319214, 30.97970963], [77.79872131, 30.97611809], [77.79728699, 30.97295952], [77.79641724, 30.96982002], [77.79740143, 30.96775818], [77.80158234, 30.96356964], [77.80462646, 30.96099091], [77.81324768, 30.96244812], [77.81639099, 30.96198273], [77.81891632, 30.96009064], [77.81932068, 30.95684052], [77.8171463, 30.95356941], [77.81260681, 30.95279121], [77.80754089, 30.95371056], [77.80227661, 30.95510101], [77.79659271, 30.95843124], [77.78761292, 30.96572113], [77.77838135, 30.97232056], [77.77094269, 30.97566032], [77.76387787, 30.97698975], [77.75392151, 30.97684288], [77.74196625, 30.96764183], [77.73634338, 30.96359062], [77.73457336, 30.95956993], [77.73327637, 30.94950104], [77.73487854, 30.94401169], [77.73568726, 30.94202042], [77.73665619, 30.9396019], [77.73924255, 30.93667984], [77.74357605, 30.93522835], [77.74649811, 30.9339695], [77.74736786, 30.92872047], [77.74559784, 30.92230988], [77.75219727, 30.92095947], [77.75824738, 30.92038155], [77.76317596, 30.92015076], [77.76725769, 30.92048073], [77.7716217, 30.92419052], [77.77449036, 30.92533112], [77.78185272, 30.92621994], [77.78874207, 30.92628098], [77.79102325, 30.92613029], [77.79337311, 30.92598152], [77.79561615, 30.92379951], [77.79498291, 30.92043114], [77.79741669, 30.91674995], [77.80084991, 30.91274071], [77.7989502, 30.90879059], [77.79463196, 30.90348053], [77.79088593, 30.90067101], [77.78639984, 30.8960495], [77.78543854, 30.89335823], [77.78443909, 30.88837051], [77.78412628, 30.88215065], [77.78362274, 30.87865067], [77.78350067, 30.87206078], [77.78705597, 30.86812019], [77.7889328, 30.86495972], [77.78936768, 30.85854912], [77.77852631, 30.86000061], [77.77359772, 30.86103058], [77.76899719, 30.86295128], [77.76516724, 30.86517906], [77.76278687, 30.86816025], [77.76177979, 30.87508965], [77.76026917, 30.87784195], [77.75820923, 30.88047981], [77.75454712, 30.88244057], [77.75105286, 30.88272095], [77.74774933, 30.88227081], [77.74452209, 30.88119125], [77.74178314, 30.87828064], [77.74085236, 30.87433052], [77.74101257, 30.86992073], [77.74167633, 30.86420059], [77.73958588, 30.86018944], [77.73573303, 30.85704994], [77.73336792, 30.85420036], [77.73146057, 30.85077095], [77.73338318, 30.8474884], [77.74089813, 30.84015083], [77.74407196, 30.83624268], [77.74440765, 30.82985115], [77.74038696, 30.82766914], [77.73744965, 30.82629967], [77.73403168, 30.82406807], [77.73088837, 30.81939125], [77.7265625, 30.8144207], [77.72408295, 30.81104088], [77.71942139, 30.80830956], [77.71806335, 30.80509949], [77.71710205, 30.79949951], [77.71539307, 30.79421806], [77.70864868, 30.78450966], [77.70452881, 30.77902031], [77.69843292, 30.77342033], [77.69265747, 30.77141953], [77.68828583, 30.76866913], [77.69148254, 30.76025963], [77.69300842, 30.75785065], [77.6917572, 30.75505066], [77.6904068, 30.75132942], [77.69158936, 30.74831009], [77.69394684, 30.74617004], [77.69770813, 30.74496841], [77.700737, 30.74496841], [77.70435333, 30.74570084], [77.70723724, 30.74552917], [77.70928192, 30.74415016], [77.71163177, 30.7420826], [77.71289062, 30.73945236], [77.71533966, 30.73826027], [77.71765137, 30.73886108], [77.72033691, 30.7382412], [77.72171021, 30.73635292], [77.72249603, 30.73335838], [77.72219086, 30.73061943], [77.7252121, 30.72734833], [77.73068237, 30.72447968], [77.73227692, 30.72070122], [77.73432922, 30.71669006], [77.7372818, 30.71346855], [77.7410965, 30.71066093], [77.74038696, 30.7071228], [77.73690033, 30.70500946], [77.73574066, 30.70157814], [77.73358154, 30.69745255], [77.73339844, 30.69350052], [77.73340607, 30.68582916], [77.7365799, 30.68284988], [77.74275208, 30.68056107], [77.74788666, 30.67814064], [77.75419617, 30.67605972], [77.75881195, 30.67238998], [77.76294708, 30.66843033], [77.76590729, 30.66527939], [77.76950073, 30.66419029], [77.77220917, 30.66539192], [77.77423096, 30.66566086], [77.77706146, 30.66558838], [77.77905273, 30.66377068], [77.7749176, 30.65845108], [77.77025604, 30.65514946], [77.76830292, 30.65147972], [77.77217102, 30.64496994], [77.77497864, 30.64112091], [77.77545166, 30.63746834], [77.77231598, 30.63237953], [77.77127838, 30.62848091], [77.77645874, 30.62613106], [77.77960968, 30.62268066], [77.78199005, 30.61935806], [77.77864838, 30.61787987], [77.7722168, 30.61783028], [77.76711273, 30.61818123], [77.76132965, 30.61944962], [77.75660706, 30.62032127], [77.75563049, 30.61619949], [77.7572403, 30.60479927], [77.75444031, 30.60074997], [77.74971008, 30.60136986], [77.74246979, 30.6071701], [77.73832703, 30.60808945], [77.73478699, 30.60816002], [77.73210907, 30.60712814], [77.73159027, 30.6047802], [77.73126984, 30.60152054], [77.72952271, 30.59838295], [77.73192596, 30.5961895], [77.73863983, 30.59287071], [77.74362946, 30.58975983], [77.74619293, 30.5844326], [77.74948883, 30.57996941], [77.75187683, 30.57458115], [77.75353241, 30.57023048], [77.75727081, 30.56558037], [77.76184845, 30.56298828], [77.7665329, 30.56349945], [77.77091217, 30.56240082], [77.77459717, 30.55890083], [77.77826691, 30.5573597], [77.78637695, 30.56139946], [77.79058838, 30.56025124], [77.7951889, 30.5611496], [77.79827118, 30.56413078], [77.80323792, 30.56377983], [77.80586243, 30.56073952], [77.80687714, 30.55426025], [77.80680847, 30.5493412], [77.80995941, 30.5440197], [77.81220245, 30.5380497], [77.81064606, 30.53318024], [77.80502319, 30.52478027], [77.80412292, 30.52037048], [77.80197144, 30.51538086], [77.80056, 30.51316071]]]}}, {\\\"id\\\": \\\"12\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.14_1\\\", \\\"HASC_1\\\": \\\"IN.JK\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Jammu and Kashmir\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 29.6, \\\"dalys_apm25_rate_6cod_mean_total\\\": 546.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 2178.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2725.0, \\\"geo-id\\\": 12, \\\"hpm25_child_popweighted\\\": 260.0, \\\"hpm25_female_popweighted\\\": 299.0, \\\"hpm25_male_popweighted\\\": 215.0, \\\"location\\\": \\\"Jammu and Kashmir\\\", \\\"mort_apm25_6cod_mean_total\\\": 2931.0, \\\"mort_hpm25_6cod_mean_total\\\": 8708.0, \\\"mort_tpm25_6cod_mean_total\\\": 11639.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[75.78742218, 32.89332199], [75.78917694, 32.88462067], [75.78983307, 32.88140106], [75.79464722, 32.87018967], [75.79537201, 32.86925888], [75.80551147, 32.85614014], [75.80831146, 32.85319901], [75.81581116, 32.84706116], [75.82106018, 32.84276199], [75.82752991, 32.84037018], [75.83738708, 32.8367691], [75.85523987, 32.82614136], [75.87378693, 32.81369019], [75.88568115, 32.79547882], [75.90006256, 32.76985931], [75.91248322, 32.75712204], [75.91404724, 32.74201965], [75.90983582, 32.72093964], [75.90486145, 32.70936203], [75.89906311, 32.70024872], [75.89657593, 32.69105911], [75.89885712, 32.6806221], [75.90540314, 32.67224884], [75.91475677, 32.6659317], [75.92405701, 32.6582222], [75.92543793, 32.65427017], [75.92362213, 32.64369965], [75.90776062, 32.61914063], [75.90458679, 32.61521912], [75.8862915, 32.59191895], [75.87254333, 32.57619095], [75.87177277, 32.57529068], [75.85653687, 32.55842209], [75.83783722, 32.5376091], [75.83055115, 32.52450943], [75.82892609, 32.51996994], [75.82504272, 32.50922012], [75.82357788, 32.50764084], [75.81569672, 32.4992218], [75.80433655, 32.48706055], [75.79014587, 32.47879028], [75.77886963, 32.47504044], [75.77246857, 32.47510147], [75.75296021, 32.4752388], [75.7459259, 32.47634888], [75.74505615, 32.47426224], [75.74373627, 32.46910858], [75.73532104, 32.45468903], [75.72970581, 32.44506073], [75.72515106, 32.43832016], [75.71974945, 32.43032074], [75.71534729, 32.42383194], [75.71153259, 32.41815948], [75.69822693, 32.40953064], [75.68495941, 32.40061951], [75.66274261, 32.39350891], [75.64807129, 32.3888092], [75.63697815, 32.38737869], [75.59263611, 32.38169861], [75.56700134, 32.37184143], [75.55731964, 32.36695862], [75.54515076, 32.36082077], [75.52921295, 32.34888077], [75.5242691, 32.34004974], [75.51582336, 32.29798889], [75.50559998, 32.28134155], [75.50450134, 32.27952957], [75.50123596, 32.27605057], [75.49894714, 32.27532959], [75.49472046, 32.27690887], [75.49002075, 32.28797913], [75.49212646, 32.30279922], [75.49111938, 32.30672073], [75.49022675, 32.31021118], [75.48475647, 32.31029129], [75.47992706, 32.31034851], [75.47142029, 32.31465149], [75.46775818, 32.3175621], [75.473526, 32.33919907], [75.47223663, 32.34004974], [75.46660614, 32.33885193], [75.45635223, 32.33351898], [75.45178986, 32.33176041], [75.44859314, 32.33132172], [75.43257904, 32.32669067], [75.43107605, 32.32648849], [75.41499329, 32.32427216], [75.39745331, 32.32625198], [75.38595581, 32.32769012], [75.37853241, 32.3288002], [75.37346649, 32.33057022], [75.35919189, 32.33491898], [75.34526825, 32.33916092], [75.3440094, 32.34020996], [75.33177948, 32.34469986], [75.32530212, 32.3428421], [75.32440186, 32.34165955], [75.32232666, 32.33732605], [75.31148529, 32.344841], [75.2890625, 32.35757446], [75.28033447, 32.36726379], [75.27822876, 32.36825562], [75.26676178, 32.37366486], [75.25331116, 32.3800087], [75.2371521, 32.39577866], [75.23152924, 32.399189], [75.2305069, 32.39929199], [75.22384644, 32.39995956], [75.20024872, 32.40232086], [75.19740295, 32.40409088], [75.19547272, 32.40531158], [75.19272614, 32.41807175], [75.19234467, 32.41984177], [75.18852997, 32.42448044], [75.17954254, 32.42544174], [75.17195892, 32.42190552], [75.16040039, 32.41651154], [75.14763641, 32.41337967], [75.13945007, 32.41460419], [75.12792969, 32.42116928], [75.12090302, 32.44149017], [75.11888123, 32.44377136], [75.11444092, 32.44878387], [75.10978699, 32.45404053], [75.10675049, 32.45503998], [75.09818268, 32.4658699], [75.08262634, 32.48004532], [75.0716095, 32.48296356], [75.06268311, 32.48212814], [75.06140137, 32.48200989], [75.03663635, 32.49206924], [75.03016663, 32.49176025], [75.02140808, 32.48537064], [75.01174927, 32.47618103], [75.00608826, 32.46904373], [75.00154114, 32.46330261], [75.0, 32.4591217], [74.98786926, 32.44956207], [74.97934723, 32.44776917], [74.97310638, 32.44792938], [74.96386719, 32.45252991], [74.94889832, 32.4540863], [74.943573, 32.46070862], [74.9336319, 32.46757126], [74.92411804, 32.46825027], [74.8996582, 32.4661293], [74.89681244, 32.46741867], [74.89099884, 32.47005844], [74.88523102, 32.47840881], [74.88291931, 32.4817543], [74.88287354, 32.48181915], [74.88274384, 32.48189926], [74.87919617, 32.48408127], [74.87666321, 32.48564148], [74.86151123, 32.48947906], [74.85642242, 32.49267197], [74.84618378, 32.49438858], [74.83532715, 32.49621201], [74.818573, 32.49605942], [74.79885864, 32.48405838], [74.76138306, 32.4821701], [74.75802612, 32.47993851], [74.74822998, 32.47924042], [74.74698639, 32.47915268], [74.74357605, 32.48149872], [74.72109985, 32.48173904], [74.69841766, 32.48493958], [74.68673706, 32.4930687], [74.68225861, 32.50204849], [74.68138123, 32.50381088], [74.67917633, 32.51541138], [74.68302917, 32.52960205], [74.68051147, 32.53818893], [74.66195679, 32.55147171], [74.65999603, 32.55324936], [74.65239716, 32.56016159], [74.64802551, 32.5718689], [74.64330292, 32.59595108], [74.64221191, 32.61104965], [74.64924622, 32.62586975], [74.65844727, 32.63735962], [74.66921234, 32.64593887], [74.6762085, 32.65800095], [74.67563629, 32.66577911], [74.67499542, 32.66672516], [74.66928101, 32.67509079], [74.66210938, 32.68046951], [74.65419006, 32.69245148], [74.65013885, 32.71841049], [74.66188049, 32.75482178], [74.66805267, 32.76340103], [74.66752625, 32.76659012], [74.67776489, 32.78157043], [74.68768311, 32.79608154], [74.69458008, 32.80952072], [74.70038605, 32.82703018], [74.69702148, 32.83971405], [74.68083191, 32.83819962], [74.66146088, 32.82802963], [74.64199829, 32.82289886], [74.63800049, 32.81809998], [74.63722992, 32.81081009], [74.64154053, 32.79188919], [74.63279724, 32.77766037], [74.61423492, 32.75773239], [74.60831451, 32.75747299], [74.5941391, 32.75684357], [74.57919312, 32.75331497], [74.57360077, 32.75555038], [74.56710815, 32.75521088], [74.54310608, 32.74544144], [74.54120636, 32.74467087], [74.53153229, 32.74073029], [74.50269318, 32.75986862], [74.47973633, 32.77267075], [74.47792053, 32.77532959], [74.47195435, 32.77836227], [74.46605682, 32.78136063], [74.46202087, 32.79088974], [74.46166992, 32.7917099], [74.45748901, 32.80157089], [74.45423126, 32.80506897], [74.45063782, 32.81682205], [74.44522858, 32.82556915], [74.44321442, 32.82882309], [74.43006134, 32.84465408], [74.42635345, 32.85777283], [74.42933655, 32.87950897], [74.42848969, 32.88360214], [74.42505646, 32.89305878], [74.41389465, 32.90394974], [74.40605164, 32.90697479], [74.3886795, 32.90841293], [74.38579559, 32.90864944], [74.36832428, 32.90845108], [74.36471558, 32.90840912], [74.3477478, 32.90821075], [74.3272171, 32.913311], [74.31803131, 32.91970062], [74.31613922, 32.93016052], [74.32071686, 32.94142914], [74.33489227, 32.95476151], [74.34635925, 32.96554947], [74.35317993, 32.98313141], [74.35282898, 32.9902916], [74.35169983, 33.01313019], [74.34983063, 33.01625061], [74.33792114, 33.02593994], [74.32647705, 33.02946091], [74.30787659, 33.03052139], [74.2831955, 33.04319], [74.25496674, 33.04877472], [74.24203491, 33.04729462], [74.22039795, 33.04481506], [74.21644592, 33.04299164], [74.20524597, 33.04330063], [74.19927216, 33.04687881], [74.19064331, 33.07670975], [74.17624664, 33.10715103], [74.1570282, 33.12586212], [74.14878082, 33.13388443], [74.14485168, 33.13526917], [74.11170197, 33.16444016], [74.09986877, 33.17250824], [74.08283997, 33.18074036], [74.05643463, 33.18661499], [74.03366852, 33.18809891], [74.02625275, 33.188591], [74.01822662, 33.19319153], [74.0142746, 33.19824982], [74.01125336, 33.21875], [74.01101685, 33.23849869], [74.0131073, 33.2498703], [74.01397705, 33.25094223], [74.02030182, 33.25878143], [74.02438354, 33.26245499], [74.03649902, 33.2647438], [74.04799652, 33.26447296], [74.06503296, 33.2599144], [74.06829071, 33.25999069], [74.07894135, 33.26023102], [74.08810425, 33.26289749], [74.09069061, 33.26364899], [74.10298157, 33.27054214], [74.11579895, 33.28113174], [74.11763, 33.28559875], [74.16685486, 33.3441391], [74.16944122, 33.34580994], [74.17074585, 33.34664917], [74.18508148, 33.38351059], [74.18421173, 33.3910408], [74.18006134, 33.40206909], [74.17929077, 33.42568588], [74.18165588, 33.43040085], [74.18292999, 33.44197083], [74.18707275, 33.45552063], [74.18564606, 33.46646881], [74.18502808, 33.46773911], [74.17813873, 33.48168182], [74.16460419, 33.49564743], [74.15810394, 33.50235367], [74.14263916, 33.51831818], [74.1233902, 33.54320908], [74.09696198, 33.56917953], [74.09571075, 33.57039642], [74.08835602, 33.57320404], [74.07447052, 33.56852341], [74.0743866, 33.56943893], [74.05390167, 33.56507874], [74.04535675, 33.56575012], [74.02844238, 33.57468033], [74.01468658, 33.59836578], [74.01066589, 33.60528946], [74.0, 33.62366867], [73.9996109, 33.62478256], [73.97570038, 33.69363403], [73.95625305, 33.72029114], [73.96646118, 33.74032211], [74.0, 33.75257874], [74.02397919, 33.77204132], [74.0283432, 33.77595901], [74.03833008, 33.79513931], [74.04134369, 33.79899216], [74.04904938, 33.80883026], [74.05276489, 33.81134033], [74.06572723, 33.82009888], [74.0900116, 33.82627869], [74.12979889, 33.82756042], [74.14334106, 33.83013916], [74.17008972, 33.83988953], [74.192276, 33.85142136], [74.20762634, 33.8594017], [74.21967316, 33.86717606], [74.24555969, 33.89500046], [74.26112366, 33.92479706], [74.26358032, 33.94261932], [74.26325226, 33.95523071], [74.26274109, 33.97428894], [74.25457764, 33.99725723], [74.24868774, 34.01382065], [74.24652863, 34.01602936], [74.23722076, 34.02553177], [74.22556305, 34.03340149], [74.2146759, 34.03855515], [74.1963501, 34.04008484], [74.18143463, 34.03956604], [74.16142273, 34.03887177], [74.14922333, 34.04302597], [74.13244629, 34.05267334], [74.12688446, 34.05426407], [74.12369537, 34.0551796], [74.1149826, 34.05378342], [74.10046387, 34.04562759], [74.09591675, 34.04032135], [74.0870285, 34.03776169], [74.0610733, 34.03470993], [74.05665588, 34.03124619], [74.04405975, 34.02972031], [74.03890228, 34.02910995], [74.006073, 34.02244186], [74.0, 34.03018951], [73.90898895, 34.03253937], [73.89817047, 34.03282166], [73.88980865, 34.04240417], [73.88321686, 34.04994965], [73.88432312, 34.06135941], [73.88565063, 34.07511902], [73.9043808, 34.09689331], [73.90408325, 34.1222496], [73.91707611, 34.14210892], [73.94477081, 34.1701889], [73.97657776, 34.21180344], [73.98203278, 34.23907852], [73.97622681, 34.26480865], [73.94097137, 34.30173874], [73.9199295, 34.34231186], [73.91334534, 34.34792709], [73.89940643, 34.35981369], [73.8894043, 34.35702515], [73.87940979, 34.3542366], [73.8417511, 34.33832169], [73.80739594, 34.35671997], [73.77339172, 34.34975052], [73.76322174, 34.35963058], [73.76432037, 34.37107086], [73.77698517, 34.41630173], [73.78965759, 34.42703629], [73.80725861, 34.44194794], [73.85481262, 34.47335052], [73.89874268, 34.4957695], [73.88668823, 34.51499939], [73.89533997, 34.54666901], [73.94806671, 34.5730896], [73.94155884, 34.59195709], [73.92733002, 34.64588928], [73.94155884, 34.67720032], [73.96022034, 34.69668198], [73.98607635, 34.70415878], [74.0, 34.70821762], [74.01289368, 34.70985413], [74.03363037, 34.69364166], [74.04171753, 34.68731689], [74.0491333, 34.68495941], [74.05970001, 34.68508911], [74.08130646, 34.69202042], [74.08653259, 34.69371033], [74.09313965, 34.69451904], [74.09716034, 34.69290161], [74.11676788, 34.6912117], [74.13269806, 34.69023895], [74.1417923, 34.69120026], [74.14897156, 34.69527054], [74.17473602, 34.71735001], [74.20295715, 34.7365799], [74.21050262, 34.74018097], [74.22574615, 34.74745941], [74.22749329, 34.75008011], [74.2390213, 34.75207901], [74.26989746, 34.7626915], [74.27974701, 34.76826859], [74.28679657, 34.77416992], [74.30278015, 34.79753876], [74.30729675, 34.80030441], [74.31509399, 34.80025864], [74.33094788, 34.79248047], [74.33159637, 34.79216766], [74.34126282, 34.78969193], [74.34621429, 34.79040909], [74.36753845, 34.80256271], [74.37554169, 34.80344391], [74.47396851, 34.79063416], [74.4771347, 34.78964996], [74.48536682, 34.7870903], [74.50657654, 34.77553177], [74.51470184, 34.77480316], [74.5381012, 34.77618408], [74.54406738, 34.77653885], [74.56149292, 34.77444077], [74.56529236, 34.77186966], [74.57715607, 34.76948929], [74.58017731, 34.77009964], [74.61242676, 34.74637222], [74.61815643, 34.74214935], [74.63154602, 34.73799896], [74.63883209, 34.73353958], [74.64798737, 34.7226181], [74.65805817, 34.71060181], [74.6713028, 34.70069885], [74.70300293, 34.6930809], [74.72807312, 34.68858337], [74.73931885, 34.68722153], [74.76312256, 34.68433762], [74.7664032, 34.68519211], [74.7721405, 34.68270874], [74.78659058, 34.68273163], [74.83560181, 34.67755127], [74.85389709, 34.67819977], [74.88981628, 34.68387222], [74.89375305, 34.6844902], [74.9105072, 34.68320847], [74.92781067, 34.67831039], [74.94671631, 34.66635132], [74.99780273, 34.65108109], [75.0, 34.64945602], [75.00364685, 34.64675903], [75.01874542, 34.64149857], [75.02990723, 34.64147186], [75.04180145, 34.64141846], [75.05079651, 34.6439209], [75.05449677, 34.6466217], [75.08472443, 34.65538025], [75.10555267, 34.65565872], [75.11119843, 34.6579895], [75.14229584, 34.66241074], [75.16467285, 34.66044998], [75.17727661, 34.65745926], [75.17849731, 34.65717697], [75.20671844, 34.64628983], [75.23575592, 34.64829254], [75.24971008, 34.64731216], [75.25963593, 34.64408112], [75.26605988, 34.63954926], [75.26693726, 34.63454056], [75.25807953, 34.61759949], [75.26185608, 34.61088181], [75.27915192, 34.60174942], [75.33519745, 34.57213211], [75.35054779, 34.5622406], [75.37782288, 34.55242157], [75.39497375, 34.54880905], [75.41396332, 34.54734039], [75.46463776, 34.54338837], [75.478508, 34.5393486], [75.50609589, 34.53733063], [75.51687622, 34.53779221], [75.52120209, 34.53958893], [75.55179596, 34.53813934], [75.56463623, 34.53874969], [75.57888794, 34.53944016], [75.59188843, 34.54006958], [75.61556244, 34.53853989], [75.64414978, 34.53353882], [75.69230652, 34.52153015], [75.71383667, 34.5184021], [75.72923279, 34.51615906], [75.74920654, 34.51583099], [75.76877594, 34.5221405], [75.79302979, 34.53392029], [75.81047821, 34.548172], [75.82064819, 34.55891037], [75.84107971, 34.57310104], [75.84327698, 34.57463074], [75.8814621, 34.5907402], [75.91192627, 34.60113144], [75.91864777, 34.60483932], [75.93221283, 34.62443161], [75.94625092, 34.63117981], [75.96720886, 34.63360214], [75.96821594, 34.63333893], [75.98327637, 34.62940979], [75.99185181, 34.62997055], [76.0003891, 34.63581085], [76.01436615, 34.65357208], [76.02542877, 34.66410065], [76.03646088, 34.67026901], [76.05502319, 34.67602921], [76.07444, 34.67631149], [76.08582306, 34.6714592], [76.09295654, 34.66656113], [76.12193298, 34.64665222], [76.13075256, 34.64352036], [76.13909149, 34.64247894], [76.15791321, 34.64340973], [76.19278717, 34.65526962], [76.19785309, 34.6591301], [76.22737885, 34.67214203], [76.23429871, 34.67309952], [76.26004791, 34.68437195], [76.27511597, 34.69364166], [76.28330231, 34.70151901], [76.28994751, 34.71232224], [76.30150604, 34.72444153], [76.31613922, 34.73163223], [76.32872009, 34.73305511], [76.33988953, 34.73431778], [76.35073853, 34.73470306], [76.38593292, 34.73595047], [76.40953827, 34.75216675], [76.42761993, 34.76243973], [76.43695831, 34.76438141], [76.46920013, 34.79166794], [76.47177124, 34.79302216], [76.47434235, 34.79437256], [76.47732544, 34.79398727], [76.48973846, 34.79238129], [76.51409149, 34.78380203], [76.5453186, 34.76559067], [76.56181335, 34.75833893], [76.57097626, 34.75842285], [76.58001709, 34.75551605], [76.61804199, 34.75606918], [76.65249634, 34.75656128], [76.67163849, 34.75741959], [76.6818161, 34.75959015], [76.68719482, 34.7632103], [76.69670105, 34.77912903], [76.70619202, 34.80125046], [76.72728729, 34.82089996], [76.73784637, 34.83074188], [76.74324036, 34.84009933], [76.74468994, 34.84473038], [76.74343872, 34.86489105], [76.73886108, 34.90192795], [76.74337006, 34.91814041], [76.74936676, 34.92660141], [76.76242828, 34.93299103], [76.76419067, 34.93312073], [76.79933929, 34.93577194], [76.80442047, 34.93432999], [76.81105042, 34.93545532], [76.82552338, 34.94165421], [76.84815216, 34.95796967], [76.85315704, 34.963871], [76.86315155, 34.97084045], [76.87004089, 34.97243118], [76.88350677, 34.97032928], [76.89846802, 34.9642601], [76.90140533, 34.96307373], [76.90843201, 34.96168518], [76.95034027, 34.94094086], [76.9703598, 34.93558121], [76.98874664, 34.93521881], [76.99748993, 34.93915176], [77.01013947, 34.95628738], [77.01145172, 34.96670914], [77.01130676, 34.9727211], [77.01065826, 35.0], [77.01029968, 35.01618195], [77.01094818, 35.02759171], [77.01378632, 35.03512192], [77.01809692, 35.03846359], [77.0269165, 35.04079437], [77.03677368, 35.03236389], [77.068367, 35.02412033], [77.08137512, 35.02633667], [77.10980225, 35.03932953], [77.1568222, 35.05469894], [77.17558289, 35.06679153], [77.19481659, 35.0791893], [77.28079224, 35.13828659], [77.2951889, 35.14562988], [77.30075073, 35.14847946], [77.37944031, 35.19789124], [77.38440704, 35.19916916], [77.41883087, 35.22006989], [77.44252014, 35.23443985], [77.48542023, 35.26654053], [77.53961182, 35.29777908], [77.58502197, 35.3239212], [77.6505661, 35.36708069], [77.66091919, 35.37522888], [77.73551178, 35.43384171], [77.76036835, 35.45117569], [77.77467346, 35.4601593], [77.81465149, 35.48524857], [77.81929016, 35.49328995], [77.82392883, 35.50133133], [77.84082031, 35.50111008], [77.84307861, 35.50098419], [77.84677887, 35.50078201], [77.85018921, 35.49172974], [77.85131836, 35.48873901], [77.8626709, 35.45859146], [77.86872101, 35.45051956], [77.87941742, 35.43624878], [77.88477325, 35.43195724], [77.8886261, 35.42887115], [77.89956665, 35.42789459], [77.90296936, 35.42758942], [77.91018677, 35.42935944], [77.9198761, 35.43433762], [77.92092896, 35.4348793], [77.92801666, 35.44054031], [77.94377899, 35.46295547], [77.94458771, 35.46411133], [77.95128632, 35.47364044], [77.96172333, 35.48006058], [77.9668808, 35.48131561], [77.99064636, 35.48711014], [78.00999451, 35.48918915], [78.01998138, 35.49026108], [78.04535675, 35.49108887], [78.06375122, 35.49169159], [78.06481934, 35.49172592], [78.07935333, 35.49219894], [78.08194733, 35.49169922], [78.08769989, 35.49058914], [78.09429932, 35.48929977], [78.10398865, 35.48445892], [78.10704803, 35.4804306], [78.10983276, 35.47676849], [78.1108017, 35.47266006], [78.10769653, 35.46456909], [78.10449982, 35.4618187], [78.09732819, 35.45563889], [78.07964325, 35.44815063], [78.07183075, 35.44684982], [78.07019043, 35.44464111], [78.06887817, 35.44287872], [78.0316925, 35.42306137], [78.03009796, 35.42046738], [78.02983093, 35.42002869], [78.02845764, 35.41928101], [78.02459717, 35.41717148], [78.02120209, 35.41688156], [78.02076721, 35.41646957], [78.0194931, 35.41526031], [77.99707031, 35.39408875], [77.99028778, 35.37903214], [77.98995972, 35.36363983], [77.99185181, 35.34854889], [77.99434662, 35.34492874], [78.00151062, 35.29796982], [78.00202179, 35.29462051], [78.00636292, 35.29035187], [78.01370239, 35.26418686], [78.01774597, 35.24975204], [78.03183746, 35.2202301], [78.04276276, 35.20233154], [78.04360962, 35.20132828], [78.05221558, 35.19109726], [78.05755615, 35.1847496], [78.0597229, 35.18310928], [78.06902313, 35.17604065], [78.07740021, 35.1727066], [78.07834625, 35.17232895], [78.11605072, 35.14535141], [78.11843872, 35.14243698], [78.12417603, 35.13542175], [78.12605286, 35.12903976], [78.12531281, 35.12599182], [78.12431335, 35.12189102], [78.11709595, 35.11164093], [78.11102295, 35.10734177], [78.09771729, 35.09793091], [78.08894348, 35.09582901], [78.08831787, 35.09568024], [78.08428192, 35.09077072], [78.08287048, 35.08248901], [78.09494781, 35.05690002], [78.11483002, 35.01475906], [78.1182785, 35.00664902], [78.12110901, 35.0], [78.13031006, 34.97834015], [78.13347626, 34.97087097], [78.16731262, 34.91213989], [78.17359924, 34.90629959], [78.17515564, 34.90280533], [78.18464661, 34.88151932], [78.18833923, 34.86278152], [78.20732117, 34.76610947], [78.21039581, 34.75893402], [78.21868896, 34.73955917], [78.22104645, 34.73403168], [78.23156738, 34.71680069], [78.23176575, 34.71653748], [78.24803162, 34.69509888], [78.26570129, 34.67938995], [78.27259827, 34.67494583], [78.27404785, 34.67401123], [78.28436279, 34.66736221], [78.30033875, 34.66193008], [78.30680084, 34.660923], [78.31733704, 34.65927887], [78.32353973, 34.65658188], [78.32492065, 34.65597916], [78.38717651, 34.6516304], [78.39552307, 34.64939117], [78.39836121, 34.64863205], [78.39872742, 34.64835358], [78.40458679, 34.6439209], [78.40701294, 34.63663101], [78.40689087, 34.6210289], [78.40931702, 34.61349869], [78.41812897, 34.60540009], [78.42511749, 34.60346222], [78.43546295, 34.6028595], [78.44315338, 34.60240173], [78.45915222, 34.60278702], [78.48223114, 34.60334015], [78.51154327, 34.60911179], [78.537117, 34.614151], [78.5581665, 34.61474991], [78.56933594, 34.61194992], [78.58207703, 34.60314941], [78.61109161, 34.58306122], [78.62100983, 34.57427979], [78.63762665, 34.5522995], [78.64382935, 34.5478096], [78.65248871, 34.5381546], [78.66005707, 34.52972031], [78.68061829, 34.51560211], [78.68618774, 34.51276016], [78.69631958, 34.50759125], [78.71663666, 34.50100708], [78.73007965, 34.4966507], [78.7361145, 34.4916687], [78.73826599, 34.48989105], [78.74935913, 34.47698975], [78.75035095, 34.47505188], [78.75283813, 34.47016907], [78.75405121, 34.46901321], [78.76302338, 34.46046066], [78.78847504, 34.44142151], [78.79937744, 34.4332695], [78.82495117, 34.41413116], [78.83725739, 34.40701675], [78.83809662, 34.40652847], [78.87568665, 34.39465332], [78.89155579, 34.38964081], [78.91503906, 34.3788414], [78.92254639, 34.3753891], [78.92743683, 34.37163544], [78.92917633, 34.37030029], [78.93989563, 34.36207962], [78.96073914, 34.34609985], [78.96884918, 34.34162903], [78.97673798, 34.33393097], [78.98146057, 34.33285141], [78.98922729, 34.31926727], [78.99005127, 34.31782913], [78.99421692, 34.30252075], [78.99340057, 34.28874207], [78.98499298, 34.26779175], [78.9750061, 34.24285889], [78.95619965, 34.21783066], [78.94211578, 34.20479202], [78.93534088, 34.19961166], [78.91036224, 34.18050003], [78.89435577, 34.17002106], [78.88887787, 34.16643143], [78.87904358, 34.16132736], [78.87114716, 34.15723038], [78.85883331, 34.15180206], [78.81531525, 34.13261032], [78.77426147, 34.11450958], [78.77094269, 34.11373901], [78.76389313, 34.11210632], [78.76066589, 34.11135864], [78.75946045, 34.11108017], [78.72923279, 34.09569931], [78.7244339, 34.09140396], [78.71331787, 34.08145905], [78.70638275, 34.0721817], [78.70614624, 34.05863953], [78.71212006, 34.05047989], [78.73184967, 34.04253006], [78.75953674, 34.03633881], [78.75987244, 34.03626633], [78.76064301, 34.03609848], [78.76595306, 34.03250885], [78.76828766, 34.02574921], [78.77036285, 34.01972961], [78.76841736, 34.01446915], [78.7636261, 34.00151062], [78.74289703, 33.9872818], [78.72841644, 33.9773407], [78.71578979, 33.96453094], [78.71425629, 33.95946884], [78.71615601, 33.94894028], [78.71724701, 33.94895935], [78.71665955, 33.93909073], [78.71492767, 33.93344879], [78.71156311, 33.92250061], [78.71724701, 33.89048004], [78.72566986, 33.87112045], [78.74178314, 33.84017944], [78.76132202, 33.81734085], [78.76203156, 33.81650925], [78.77506256, 33.80125046], [78.7805481, 33.7891922], [78.78398895, 33.77043152], [78.77529144, 33.74640274], [78.77522278, 33.74621964], [78.76239777, 33.73065948], [78.75756073, 33.7264595], [78.73731995, 33.70888138], [78.73724365, 33.70881653], [78.73175049, 33.70404053], [78.70929718, 33.67961121], [78.70842743, 33.67610931], [78.70678711, 33.66947937], [78.70935059, 33.66054916], [78.71098328, 33.65486908], [78.72727966, 33.62277603], [78.72992706, 33.61756897], [78.74223328, 33.59741211], [78.74347687, 33.59537506], [78.75811005, 33.57139206], [78.76319885, 33.56304932], [78.77068329, 33.55204391], [78.78386688, 33.53264999], [78.79115295, 33.52518845], [78.80387115, 33.50680923], [78.81859589, 33.48907852], [78.82073212, 33.48651505], [78.82325745, 33.48348999], [78.87039948, 33.43970108], [78.87152863, 33.43907928], [78.87565613, 33.43680191], [78.89539337, 33.42031097], [78.92125702, 33.39870071], [78.94110107, 33.3900795], [78.9548111, 33.37417984], [78.97268677, 33.36732101], [78.97953033, 33.35877609], [78.98866272, 33.34737015], [78.998703, 33.34022522], [79.00415039, 33.33634949], [79.01954651, 33.3307991], [79.03379822, 33.31357956], [79.03656769, 33.31208801], [79.0476532, 33.30611038], [79.06659698, 33.29589081], [79.07079315, 33.29092026], [79.07311249, 33.28359985], [79.06926727, 33.27310944], [79.0661087, 33.26448059], [79.06684875, 33.25462341], [79.06720734, 33.24983215], [79.07147217, 33.23816299], [79.07496643, 33.22861099], [79.09298706, 33.22045898], [79.11328125, 33.21128082], [79.12773132, 33.20473862], [79.14144135, 33.20009995], [79.15701294, 33.19791031], [79.1647644, 33.19681931], [79.18049622, 33.1946106], [79.1829834, 33.19292068], [79.18546295, 33.19123077], [79.20622253, 33.19395065], [79.21237183, 33.19475937], [79.31517029, 33.18880081], [79.35584259, 33.18952942], [79.3772583, 33.18991089], [79.39362335, 33.18893051], [79.399086, 33.18714905], [79.40197754, 33.18489456], [79.40983582, 33.17877197], [79.41683197, 33.16669083], [79.4175415, 33.15523911], [79.41546631, 33.1476593], [79.41320038, 33.14191437], [79.41075134, 33.13570023], [79.39853668, 33.11471176], [79.39726257, 33.10943222], [79.39502716, 33.10720062], [79.39328003, 33.10544586], [79.39055634, 33.10271072], [79.37358856, 33.07342911], [79.37328339, 33.0719986], [79.37230682, 33.06745911], [79.36760712, 33.06161118], [79.36618042, 33.05984116], [79.35492706, 33.03060913], [79.35301971, 33.02259064], [79.35186768, 33.01774216], [79.35002899, 32.99618149], [79.3507309, 32.99126053], [79.3509903, 32.98942184], [79.35121918, 32.98781586], [79.3524704, 32.97903061], [79.36211395, 32.96205902], [79.36503601, 32.95692062], [79.38111115, 32.93956757], [79.38313293, 32.93738937], [79.38712311, 32.93307877], [79.39096069, 32.930439], [79.39906311, 32.92486954], [79.41867065, 32.91139984], [79.43206024, 32.90510941], [79.4348526, 32.90032959], [79.44185638, 32.89466095], [79.44621277, 32.89113998], [79.44857788, 32.88922882], [79.45439911, 32.88035202], [79.45506287, 32.87805939], [79.45697021, 32.87142944], [79.46452332, 32.81674194], [79.47122955, 32.80282211], [79.47782135, 32.79624176], [79.48442078, 32.78966141], [79.49630737, 32.78411102], [79.5152359, 32.77528], [79.52672577, 32.76758957], [79.52893066, 32.76501465], [79.53334045, 32.75986099], [79.54052734, 32.74869156], [79.54402924, 32.73950195], [79.54541016, 32.73586655], [79.5473938, 32.73065186], [79.55539703, 32.7096405], [79.56124878, 32.68402863], [79.56259155, 32.67816925], [79.56429291, 32.67076111], [79.55776978, 32.63061905], [79.55355835, 32.62026978], [79.54982758, 32.61439133], [79.54535675, 32.60736084], [79.52404785, 32.59589005], [79.52200317, 32.59479141], [79.51436615, 32.59286499], [79.50878906, 32.59146118], [79.48854065, 32.59283066], [79.48497009, 32.59307098], [79.47812653, 32.59293365], [79.46414948, 32.59265137], [79.44801331, 32.58607864], [79.43630981, 32.57990265], [79.43031311, 32.57674026], [79.40381622, 32.55768967], [79.36222076, 32.53755951], [79.36148834, 32.5370369], [79.35997009, 32.53594971], [79.35324097, 32.53112793], [79.34697723, 32.52664185], [79.32025146, 32.49129868], [79.31373596, 32.48788834], [79.31221771, 32.48709106], [79.30493164, 32.48654938], [79.29734039, 32.48852921], [79.27011871, 32.5177803], [79.2607193, 32.52227783], [79.25840759, 32.52338028], [79.2579422, 32.5233345], [79.2532196, 32.52285767], [79.24816132, 32.52235031], [79.23497772, 32.51898956], [79.23309326, 32.51850891], [79.22310638, 32.51596069], [79.22088623, 32.51539612], [79.21382904, 32.5135994], [79.20693207, 32.51184082], [79.20295715, 32.51082993], [79.18330383, 32.50102234], [79.16506958, 32.49192047], [79.14885712, 32.4838295], [79.1289444, 32.46642685], [79.12652588, 32.46430969], [79.12172699, 32.45611191], [79.12024689, 32.45357895], [79.12007904, 32.45328903], [79.1181488, 32.45000076], [79.11978149, 32.43832016], [79.12187958, 32.42324066], [79.12133789, 32.41762161], [79.12119293, 32.41613007], [79.11180115, 32.39929199], [79.10912323, 32.38322067], [79.1044693, 32.37171173], [79.09564209, 32.367939], [79.09185028, 32.36903], [79.07662964, 32.37901688], [79.06754303, 32.38497925], [79.0642395, 32.3852272], [79.05970001, 32.38557053], [79.04921722, 32.38336945], [79.04904938, 32.383255], [79.04654694, 32.38156891], [79.02498627, 32.36701202], [78.99375916, 32.36429977], [78.98252869, 32.34582138], [78.97720337, 32.34276962], [78.97373199, 32.34360886], [78.97096252, 32.34428024], [78.92399597, 32.3633194], [78.91886139, 32.36539841], [78.91467285, 32.36709213], [78.91413879, 32.36771011], [78.90232849, 32.38139343], [78.90001678, 32.38407135], [78.88800049, 32.39237213], [78.88582611, 32.39597702], [78.87457275, 32.41461945], [78.8674469, 32.41909027], [78.85692596, 32.4189415], [78.83602142, 32.42528152], [78.8212204, 32.43627167], [78.81980896, 32.43732071], [78.81790161, 32.43873978], [78.81636047, 32.44062042], [78.79792786, 32.46318054], [78.79641724, 32.46427536], [78.78118134, 32.47529984], [78.77667236, 32.48392868], [78.77542877, 32.49055099], [78.77558136, 32.51635361], [78.77559662, 32.51966095], [78.7726059, 32.54434967], [78.76792145, 32.55327225], [78.76675415, 32.5554924], [78.76555634, 32.55776215], [78.76425171, 32.56484222], [78.76371002, 32.56781006], [78.76516724, 32.57493973], [78.77649689, 32.58818054], [78.78032684, 32.59832001], [78.77929687, 32.60224533], [78.77578735, 32.61562729], [78.77056885, 32.63552094], [78.76805878, 32.66297913], [78.76521301, 32.6736908], [78.76456451, 32.67609406], [78.76391602, 32.67848969], [78.76027679, 32.68416977], [78.7459259, 32.69607925], [78.74214172, 32.69601822], [78.7364502, 32.69593048], [78.71703339, 32.68072891], [78.66426849, 32.65649033], [78.65442657, 32.64923096], [78.65162659, 32.64442062], [78.63233948, 32.6110611], [78.62567139, 32.60705185], [78.60328674, 32.60438156], [78.59976959, 32.60525894], [78.5947113, 32.60652161], [78.58695221, 32.60845947], [78.55927277, 32.61233902], [78.54985046, 32.61231995], [78.54950714, 32.61231995], [78.54519653, 32.6123085], [78.5449295, 32.6123085], [78.53894043, 32.61042786], [78.53704834, 32.60983276], [78.53675079, 32.60974121], [78.53108215, 32.60795975], [78.52641296, 32.60649109], [78.50885773, 32.59471893], [78.50328064, 32.58956146], [78.49591064, 32.58274841], [78.48561096, 32.5732193], [78.47966003, 32.57312012], [78.47274017, 32.57786179], [78.47249603, 32.57802963], [78.47151947, 32.57823944], [78.47027588, 32.57850266], [78.46161652, 32.58034897], [78.45272064, 32.57950211], [78.44332886, 32.57207489], [78.4378891, 32.56777191], [78.41223907, 32.55606079], [78.41145325, 32.55430984], [78.40432739, 32.53873062], [78.40522766, 32.52523041], [78.41125488, 32.51982498], [78.41204834, 32.51911545], [78.41652679, 32.51509857], [78.41333771, 32.51324081], [78.41075897, 32.51174164], [78.40917206, 32.51202011], [78.40892029, 32.51271057], [78.40522766, 32.51422882], [78.40525818, 32.51512146], [78.40141296, 32.51818085], [78.4002533, 32.52368164], [78.39906311, 32.526371], [78.3979187, 32.52706909], [78.39438629, 32.52853012], [78.38243103, 32.52965164], [78.3766861, 32.52605057], [78.35636139, 32.51266098], [78.31040955, 32.47592926], [78.30623627, 32.47774887], [78.27851868, 32.50793076], [78.29503632, 32.52246094], [78.29917145, 32.52927017], [78.29662323, 32.57751083], [78.30236816, 32.57870102], [78.31799316, 32.58021164], [78.33175659, 32.58486938], [78.34062195, 32.59305954], [78.37706757, 32.61487961], [78.38881683, 32.62322998], [78.3759079, 32.62961197], [78.3709259, 32.63816071], [78.36315155, 32.67198944], [78.36367798, 32.68553162], [78.36756897, 32.69952011], [78.37782288, 32.71931076], [78.37494659, 32.72264862], [78.37121582, 32.7336998], [78.3707428, 32.74584961], [78.37277222, 32.76015091], [78.37135315, 32.76182938], [78.3642807, 32.76298141], [78.34474182, 32.76343155], [78.31394958, 32.74898148], [78.28765869, 32.73783112], [78.2946167, 32.73160934], [78.29811096, 32.72483063], [78.2985611, 32.71974182], [78.29572296, 32.71281052], [78.28486633, 32.70677948], [78.27274323, 32.70293045], [78.25911713, 32.70291901], [78.23658752, 32.69467163], [78.23326111, 32.68370056], [78.22496796, 32.67556], [78.2129364, 32.66918945], [78.20163727, 32.66519928], [78.19499207, 32.6673317], [78.18395233, 32.66387177], [78.17951202, 32.67041016], [78.17047882, 32.67721176], [78.15841675, 32.67913055], [78.15254211, 32.67901993], [78.14444733, 32.67660141], [78.13600159, 32.6703186], [78.13066101, 32.66006088], [78.12666321, 32.64910126], [78.12149811, 32.64234924], [78.11615753, 32.64241028], [78.106987, 32.64974213], [78.09926605, 32.65996933], [78.09337616, 32.66215134], [78.08851624, 32.659832], [78.07900238, 32.65279007], [78.07293701, 32.64440155], [78.06745911, 32.6256218], [78.06533051, 32.62427902], [78.05901337, 32.62458038], [78.0440979, 32.6288414], [78.0338974, 32.63560867], [78.03273773, 32.63375092], [78.03244019, 32.62839127], [78.03443146, 32.61565018], [78.03675842, 32.61085892], [78.04146576, 32.6053009], [78.04161072, 32.59923935], [78.03579712, 32.59194946], [78.02744293, 32.58864975], [78.01743317, 32.5870285], [77.98705292, 32.58819962], [77.9825592, 32.58652878], [77.97669983, 32.59194183], [77.9749527, 32.5963707], [77.96784973, 32.60797882], [77.96222687, 32.61380005], [77.95947266, 32.62073898], [77.95424652, 32.6259613], [77.95510101, 32.63481903], [77.95265961, 32.64039993], [77.9464798, 32.64273071], [77.93891144, 32.6480217], [77.93229675, 32.65620041], [77.92716217, 32.66262054], [77.9262085, 32.66680908], [77.92021179, 32.67951202], [77.9109726, 32.68817902], [77.90325165, 32.69309998], [77.90239716, 32.69841003], [77.90566254, 32.70359039], [77.90625763, 32.71234894], [77.90847778, 32.7163887], [77.90943909, 32.72138977], [77.91203308, 32.72576904], [77.91847229, 32.73078918], [77.91562653, 32.73369217], [77.91182709, 32.73651123], [77.9143219, 32.74177933], [77.91440582, 32.74454117], [77.91716003, 32.75188065], [77.9179306, 32.75691986], [77.91689301, 32.76272964], [77.91513062, 32.76605988], [77.91227722, 32.76716995], [77.90892792, 32.77212143], [77.90349579, 32.77289963], [77.89949799, 32.77532196], [77.89087677, 32.77450943], [77.88748169, 32.77526093], [77.88089752, 32.7754097], [77.876297, 32.78001022], [77.87224579, 32.78625107], [77.86696625, 32.79029083], [77.8690033, 32.80036926], [77.86454773, 32.80651855], [77.86383057, 32.81145096], [77.86126709, 32.81616211], [77.85497284, 32.82118988], [77.85254669, 32.82518005], [77.84760284, 32.8284111], [77.83138275, 32.83504105], [77.8250885, 32.83987045], [77.81881714, 32.83853149], [77.8143158, 32.8361702], [77.80821228, 32.8360405], [77.79899597, 32.84584045], [77.79187775, 32.84926987], [77.78774261, 32.84976196], [77.78087616, 32.85409927], [77.77578735, 32.854702], [77.76772308, 32.85847092], [77.76142883, 32.86483002], [77.76597595, 32.88029099], [77.77274323, 32.8909111], [77.7869873, 32.8916893], [77.79250336, 32.89807892], [77.79016876, 32.90542984], [77.78174591, 32.91003036], [77.7780304, 32.91577911], [77.75956726, 32.92741013], [77.75099182, 32.93603134], [77.74762726, 32.93941879], [77.74745941, 32.9405098], [77.74717712, 32.94221115], [77.74478912, 32.94586945], [77.73895264, 32.94726944], [77.73641968, 32.94787216], [77.73412323, 32.9503212], [77.7273407, 32.95755005], [77.7231369, 32.96435928], [77.71248627, 32.97180176], [77.70832825, 32.96731949], [77.70368958, 32.9661293], [77.69988251, 32.96903992], [77.69670868, 32.97335052], [77.69500732, 32.97782135], [77.69087219, 32.97941971], [77.67948914, 32.97777939], [77.6780014, 32.98072052], [77.67086029, 32.9862709], [77.66520691, 32.98603058], [77.66307831, 32.97592926], [77.6599884, 32.96895981], [77.65637207, 32.96596146], [77.65331268, 32.95940018], [77.64987946, 32.9582901], [77.64334869, 32.95785141], [77.6384964, 32.95613861], [77.62336731, 32.94454193], [77.61725616, 32.94400024], [77.61296082, 32.94141006], [77.61071014, 32.94231033], [77.60614777, 32.94240952], [77.59343719, 32.94153976], [77.58637238, 32.93989944], [77.58392334, 32.94380188], [77.58152771, 32.93923187], [77.58096313, 32.93450165], [77.57966614, 32.93167877], [77.56964874, 32.92166138], [77.55384827, 32.91310883], [77.54949188, 32.9133606], [77.54471588, 32.91173172], [77.53531647, 32.90229034], [77.52700043, 32.89228058], [77.52320099, 32.88978195], [77.51956177, 32.88737869], [77.5112915, 32.88542938], [77.50623322, 32.8830719], [77.49434662, 32.88151169], [77.48455048, 32.88653946], [77.47318268, 32.87879181], [77.45522308, 32.86174011], [77.448349, 32.86167908], [77.43617249, 32.8658905], [77.43224335, 32.87044907], [77.43122101, 32.87582016], [77.42572021, 32.88367081], [77.4177475, 32.87921143], [77.41013336, 32.8782196], [77.40312195, 32.88145065], [77.39917755, 32.88393021], [77.39733124, 32.88698959], [77.39541626, 32.8873291], [77.38746643, 32.88552094], [77.3793869, 32.88082886], [77.37124634, 32.8674202], [77.36306763, 32.86352921], [77.35968018, 32.85958099], [77.35871887, 32.85639954], [77.35980988, 32.85161972], [77.3626709, 32.84659958], [77.36184692, 32.84260941], [77.35955048, 32.83816147], [77.35647583, 32.82527161], [77.3483963, 32.82120132], [77.34046173, 32.82054138], [77.33596039, 32.81890869], [77.32789612, 32.81988144], [77.32161713, 32.82239151], [77.32065582, 32.82810211], [77.31651306, 32.82975006], [77.31086731, 32.83766937], [77.3125, 32.84630966], [77.30516052, 32.85404968], [77.29795837, 32.85401154], [77.28874207, 32.85261917], [77.28128052, 32.85565186], [77.27433777, 32.85976028], [77.27009583, 32.86640167], [77.25831604, 32.87636185], [77.24758148, 32.8649292], [77.23887634, 32.8651619], [77.23802948, 32.86901093], [77.23626709, 32.87229919], [77.22782898, 32.8769722], [77.224823, 32.88002014], [77.22408295, 32.88270187], [77.22746277, 32.88393021], [77.22930145, 32.88679886], [77.22825623, 32.89556885], [77.21798706, 32.89731216], [77.20453644, 32.90637207], [77.18895721, 32.91006088], [77.18180084, 32.91545105], [77.17385864, 32.93112946], [77.1665802, 32.92805099], [77.16372681, 32.92510986], [77.16156769, 32.92111969], [77.16043091, 32.91608047], [77.15743256, 32.91323853], [77.14618683, 32.91402054], [77.15072632, 32.92023087], [77.14694977, 32.93437958], [77.14855194, 32.93791199], [77.14878082, 32.94137955], [77.14611053, 32.94277191], [77.14612579, 32.95639038], [77.13638306, 32.9577713], [77.13527679, 32.96094131], [77.13553619, 32.96467972], [77.13430786, 32.96949005], [77.13585663, 32.97444916], [77.13639069, 32.98046112], [77.12750244, 32.98384094], [77.12007141, 32.98271179], [77.11238098, 32.98413086], [77.10315704, 32.98720169], [77.09712219, 32.97758102], [77.08418274, 32.97367096], [77.07489777, 32.97335052], [77.07167053, 32.97623062], [77.06593323, 32.98553085], [77.05847168, 32.98608017], [77.05237579, 32.9908905], [77.03531647, 32.99967957], [77.02442169, 32.99695969], [77.01992035, 32.99174881], [77.0112381, 32.99324036], [76.99846649, 32.98957062], [76.99401855, 32.9922905], [76.99147034, 32.99285889], [76.98693848, 32.99592209], [76.98082733, 33.00146103], [76.96652222, 33.00720978], [76.96370697, 33.01004028], [76.96212769, 33.01393127], [76.95677948, 33.01673889], [76.94832611, 33.01848984], [76.93266296, 33.02845001], [76.92414856, 33.02896881], [76.91751099, 33.03367996], [76.91461182, 33.03882217], [76.91332245, 33.04420853], [76.9102478, 33.05020905], [76.90011597, 33.06414032], [76.89694214, 33.07099152], [76.89639282, 33.07580948], [76.89074707, 33.08076096], [76.89093018, 33.08459854], [76.89498901, 33.09141922], [76.89431, 33.09513855], [76.88477325, 33.09743881], [76.87741852, 33.1072197], [76.87719727, 33.11423874], [76.86869049, 33.12022018], [76.86044312, 33.11637878], [76.85256958, 33.11154938], [76.84443665, 33.11230087], [76.8391571, 33.11529922], [76.83410645, 33.12055969], [76.83740234, 33.12638855], [76.82808685, 33.13167953], [76.82917023, 33.13772202], [76.82296753, 33.14128876], [76.81725311, 33.14200211], [76.81495667, 33.14617157], [76.80948639, 33.14855194], [76.80345917, 33.15568924], [76.80143738, 33.16154099], [76.80201721, 33.16603088], [76.799263, 33.1694603], [76.79812622, 33.1733017], [76.80042267, 33.17779922], [76.80517578, 33.18225861], [76.80661011, 33.18473053], [76.80330658, 33.19385147], [76.81858826, 33.20557022], [76.81716156, 33.21223068], [76.81108093, 33.21546173], [76.81304932, 33.2227211], [76.81785583, 33.23114014], [76.82319641, 33.23738098], [76.82887268, 33.2425499], [76.82834625, 33.24639893], [76.82717133, 33.24674988], [76.82354736, 33.24785995], [76.8219223, 33.24835205], [76.817276, 33.24850082], [76.81394196, 33.24744034], [76.80916595, 33.24430084], [76.80845642, 33.24232101], [76.8062973, 33.23622894], [76.80275726, 33.23666], [76.79693604, 33.24121094], [76.78543854, 33.25358963], [76.77826691, 33.2557106], [76.76355743, 33.25432968], [76.75997162, 33.25297928], [76.75688171, 33.25054169], [76.75534058, 33.24948883], [76.75520325, 33.24740982], [76.75756836, 33.2431221], [76.76235962, 33.2395401], [76.75988007, 33.22467041], [76.75605011, 33.21982193], [76.75055695, 33.21012878], [76.74558258, 33.20434952], [76.74212646, 33.19749069], [76.73435211, 33.19311905], [76.73060608, 33.18527985], [76.72986603, 33.17943192], [76.71418762, 33.17744064], [76.70847321, 33.18130112], [76.69671631, 33.18148041], [76.69365692, 33.17760086], [76.68527222, 33.17404175], [76.66947937, 33.17332077], [76.66055298, 33.17134857], [76.65944672, 33.17111206], [76.65873718, 33.17116928], [76.65110779, 33.17182922], [76.64074707, 33.16468048], [76.62700653, 33.1624794], [76.61255646, 33.16596985], [76.59958649, 33.17375946], [76.5984726, 33.17650986], [76.59886169, 33.18391037], [76.59732819, 33.18803024], [76.59253693, 33.19063187], [76.58799744, 33.18999863], [76.58403778, 33.19306946], [76.58470154, 33.19956207], [76.58618927, 33.20421982], [76.58190155, 33.20687103], [76.57673645, 33.2057991], [76.56761932, 33.20705032], [76.56295013, 33.20618057], [76.55589294, 33.20685196], [76.54747772, 33.20952988], [76.54196167, 33.20677185], [76.53417969, 33.19934845], [76.52023315, 33.20040894], [76.50576019, 33.19578171], [76.4988327, 33.19668961], [76.49597168, 33.19602966], [76.48877716, 33.19015884], [76.46906281, 33.17990875], [76.46614075, 33.17988205], [76.45555115, 33.18331909], [76.45020294, 33.18291855], [76.44181061, 33.18046951], [76.42977142, 33.18281174], [76.42177582, 33.18180847], [76.40769196, 33.18841934], [76.40067291, 33.18656158], [76.39167786, 33.18669128], [76.38455963, 33.18289185], [76.37985229, 33.17646027], [76.37351227, 33.17346191], [76.36615753, 33.16804123], [76.36080933, 33.16275024], [76.3588562, 33.15750122], [76.35578918, 33.15460205], [76.35212708, 33.15483856], [76.33558655, 33.14627075], [76.3155365, 33.13019943], [76.30692291, 33.12722015], [76.29194641, 33.12020874], [76.28800201, 33.11315918], [76.27500153, 33.10398865], [76.27687073, 33.10063171], [76.27584076, 33.09803009], [76.2712326, 33.09635925], [76.26751709, 33.08610916], [76.25524139, 33.05228043], [76.23728943, 33.03258896], [76.22978973, 33.03083038], [76.2294693, 33.03026199], [76.21615601, 33.02857208], [76.18830109, 33.02758026], [76.15223694, 33.02289963], [76.14389038, 33.01647949], [76.12819672, 33.01008224], [76.12049103, 33.01042175], [76.1159668, 33.0085907], [76.10732269, 33.00788879], [76.09368896, 33.00482941], [76.09455872, 33.00032043], [76.09123993, 32.99275208], [76.08567047, 32.97500992], [76.08220673, 32.96879959], [76.07834625, 32.96607208], [76.06999969, 32.96221924], [76.06587982, 32.95798111], [76.05446625, 32.9509697], [76.05039978, 32.94427109], [76.04260254, 32.94023895], [76.02807617, 32.93743896], [76.02365112, 32.93157959], [76.02117157, 32.92443085], [76.01718903, 32.91764069], [76.01351166, 32.91593933], [76.00463104, 32.91400909], [75.99752808, 32.90937042], [75.98741913, 32.90058136], [75.98320007, 32.90040207], [75.94577026, 32.88513947], [75.93955231, 32.88422012], [75.93377686, 32.88431168], [75.92323303, 32.89809036], [75.91356659, 32.90621185], [75.90011597, 32.91569901], [75.88089752, 32.92477036], [75.86711884, 32.93021011], [75.85006714, 32.93115997], [75.83389282, 32.93460083], [75.82811737, 32.93408203], [75.82142639, 32.93347168], [75.80795288, 32.9297905], [75.80332184, 32.92354965], [75.79830933, 32.91942215], [75.80175781, 32.91027069], [75.80000305, 32.90391922], [75.7983551, 32.90216446], [75.79380798, 32.89731216], [75.78987885, 32.89398193], [75.78742218, 32.89332199]]]}}, {\\\"id\\\": \\\"13\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.15_1\\\", \\\"HASC_1\\\": \\\"IN.JH\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Jharkhand\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Vananchal\\\", \\\"apm25_popweighted\\\": 100.0, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1347.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1833.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3180.0, \\\"geo-id\\\": 13, \\\"hpm25_child_popweighted\\\": 224.8, \\\"hpm25_female_popweighted\\\": 258.4, \\\"hpm25_male_popweighted\\\": 186.0, \\\"location\\\": \\\"Jharkhand\\\", \\\"mort_apm25_6cod_mean_total\\\": 15705.0, \\\"mort_hpm25_6cod_mean_total\\\": 21325.0, \\\"mort_tpm25_6cod_mean_total\\\": 37030.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[86.72278595, 22.21524811], [86.72097015, 22.21684074], [86.71147156, 22.21772003], [86.69178772, 22.2173996], [86.68216705, 22.21951103], [86.67399597, 22.22496986], [86.66995239, 22.23010063], [86.66989136, 22.2368412], [86.66514587, 22.23855972], [86.66269684, 22.23748016], [86.66034698, 22.2342205], [86.65114594, 22.23320007], [86.6481781, 22.23569107], [86.64729309, 22.24969292], [86.64833832, 22.25323105], [86.64589691, 22.25728035], [86.64557648, 22.26136971], [86.64227295, 22.26184273], [86.64137268, 22.26419258], [86.63761902, 22.26309013], [86.63729095, 22.26620293], [86.63465881, 22.26914978], [86.63025665, 22.26902962], [86.62715149, 22.26683044], [86.61605835, 22.27600288], [86.60851288, 22.27876091], [86.60263062, 22.27843285], [86.59845734, 22.27437973], [86.59092712, 22.27483177], [86.58992767, 22.28214073], [86.58561707, 22.28663063], [86.58560181, 22.29088974], [86.58217621, 22.29101944], [86.58130646, 22.29491806], [86.57846069, 22.29781914], [86.5752182, 22.2963295], [86.57433319, 22.29393959], [86.57068634, 22.29294968], [86.56771088, 22.29700279], [86.561203, 22.29701042], [86.55206299, 22.29528999], [86.54573822, 22.29892921], [86.53988647, 22.30373001], [86.53237915, 22.29819107], [86.52455139, 22.30285072], [86.52320099, 22.30783844], [86.52083588, 22.31148911], [86.52509308, 22.3123703], [86.52365112, 22.31857109], [86.51957703, 22.32057953], [86.50798798, 22.32402039], [86.50125885, 22.33146095], [86.49994659, 22.34095192], [86.48371887, 22.34441948], [86.48171234, 22.34201813], [86.47853088, 22.33446121], [86.47457886, 22.33422089], [86.46842194, 22.33228111], [86.4670105, 22.32891083], [86.46395874, 22.32699966], [86.46026611, 22.32641983], [86.45823669, 22.32211113], [86.44954681, 22.3230629], [86.44181824, 22.32534027], [86.43839264, 22.32336807], [86.43881226, 22.31645966], [86.44019318, 22.3114109], [86.4393158, 22.30578041], [86.43335724, 22.30154037], [86.42437744, 22.3062706], [86.42469788, 22.30920982], [86.42169189, 22.31389046], [86.41137695, 22.31555939], [86.40130615, 22.31941032], [86.39060974, 22.32528114], [86.37552643, 22.33711815], [86.36303711, 22.33960915], [86.35273743, 22.34542084], [86.35266113, 22.35153008], [86.34736633, 22.35900116], [86.33931732, 22.36605072], [86.32534027, 22.37308121], [86.31986237, 22.38035965], [86.31770325, 22.39059067], [86.30979919, 22.39726067], [86.30223846, 22.40520287], [86.30065155, 22.41531944], [86.29292297, 22.42014122], [86.28795624, 22.42536163], [86.2798233, 22.4455204], [86.27137756, 22.44282913], [86.2651825, 22.43954086], [86.25956726, 22.44127083], [86.2425766, 22.44453049], [86.22849274, 22.44958115], [86.22103119, 22.45059967], [86.22038269, 22.44909096], [86.21150208, 22.45971107], [86.21694946, 22.46403122], [86.21820831, 22.46821022], [86.2175827, 22.46824837], [86.21653748, 22.46504974], [86.20913696, 22.46284103], [86.20239258, 22.47027969], [86.19668579, 22.46774101], [86.17370605, 22.47643089], [86.16602325, 22.47674751], [86.1555481, 22.4790802], [86.14514923, 22.47513962], [86.1462326, 22.47914124], [86.11992645, 22.48555946], [86.11192322, 22.48293114], [86.10733032, 22.48489761], [86.10137939, 22.49015045], [86.0981369, 22.49563026], [86.09350586, 22.50822067], [86.09155273, 22.50915909], [86.07834625, 22.53041077], [86.06920624, 22.54306984], [86.06182861, 22.5485096], [86.05813599, 22.55342102], [86.0533905, 22.55465126], [86.04664612, 22.55788994], [86.0384903, 22.5635891], [86.01834106, 22.5436306], [86.02826691, 22.53433037], [86.02202606, 22.52054977], [86.01544952, 22.52448082], [86.00868225, 22.51855087], [86.00179291, 22.51486015], [85.9998703, 22.51497269], [85.99591827, 22.50896263], [85.99297333, 22.50892067], [85.98413849, 22.51062012], [85.98071289, 22.50974083], [85.96924591, 22.49978065], [85.96637726, 22.49381065], [85.96560669, 22.4901619], [85.9670105, 22.48601151], [85.9667511, 22.48216057], [85.96079254, 22.47861862], [85.95813751, 22.47618103], [85.9593277, 22.47038078], [85.95826721, 22.46590042], [85.95350647, 22.45597267], [85.96140289, 22.45269966], [85.96311188, 22.44512177], [85.96697998, 22.44122124], [85.98213196, 22.42898941], [85.99297333, 22.42214012], [85.99685669, 22.4216404], [86.00002289, 22.42264748], [86.00283813, 22.42506027], [86.0059967, 22.42536163], [86.00874329, 22.42432022], [86.00974274, 22.42165947], [86.00961304, 22.41889], [86.01204681, 22.41473007], [86.01365662, 22.40388107], [86.01226807, 22.39899063], [86.01477814, 22.39705086], [86.01574707, 22.39334106], [86.01802063, 22.39324188], [86.01906586, 22.39066124], [86.0175705, 22.38612175], [86.02050781, 22.38420105], [86.02149963, 22.38176155], [86.0196228, 22.37815094], [86.02124786, 22.37504005], [86.01891327, 22.37475967], [86.01841736, 22.37153053], [86.01596832, 22.37297058], [86.01526642, 22.36600113], [86.01686096, 22.3622303], [86.0061264, 22.34875107], [85.99288177, 22.33815956], [85.99582672, 22.33311844], [85.99842834, 22.33107948], [86.00476074, 22.33564949], [86.01399994, 22.33450127], [86.02043152, 22.32939911], [86.01918793, 22.32713127], [86.01328278, 22.32396126], [86.00589752, 22.31591034], [86.008461, 22.31324005], [86.00842285, 22.30995941], [86.01117706, 22.31056976], [86.01139832, 22.30939102], [86.01777649, 22.30455017], [86.02040863, 22.30554008], [86.02471924, 22.30417061], [86.02816772, 22.30768967], [86.03230286, 22.30523109], [86.03407288, 22.30793953], [86.03930664, 22.30865097], [86.04225922, 22.30824089], [86.04328918, 22.30619049], [86.03996277, 22.30355072], [86.03031921, 22.30298805], [86.0293808, 22.30076027], [86.02732086, 22.29949951], [86.02339172, 22.29767036], [86.0197525, 22.29781914], [86.01605988, 22.29652977], [86.00849915, 22.2926712], [86.00023651, 22.28437042], [86.00222015, 22.28146172], [86.00074005, 22.27933121], [85.99752808, 22.27534103], [85.99304199, 22.2732811], [85.98519135, 22.2672081], [85.98544312, 22.25745964], [85.98181152, 22.2520504], [85.9697876, 22.24340057], [85.97135925, 22.23838043], [85.97779083, 22.23554993], [85.98513031, 22.22384262], [85.992836, 22.21548271], [86.01738739, 22.19876289], [86.0255661, 22.18921089], [86.02671814, 22.18522263], [86.01477814, 22.17264175], [86.01257324, 22.16785812], [86.01312256, 22.16361046], [86.01140594, 22.15765953], [86.00385284, 22.15105057], [85.99923706, 22.14492989], [85.99968719, 22.14240074], [85.99909973, 22.13710976], [85.99462891, 22.13178062], [85.99508667, 22.12356949], [85.99608612, 22.12065125], [86.00258636, 22.11302185], [86.00047302, 22.10897064], [85.99259949, 22.10025024], [85.98919678, 22.09345055], [85.97899628, 22.08336067], [85.97731781, 22.08003998], [85.97738647, 22.07673836], [85.97528839, 22.0717907], [85.97122955, 22.06682014], [85.96737671, 22.05978012], [85.96331024, 22.0544281], [85.95797729, 22.04251099], [85.95358276, 22.03610039], [85.95153809, 22.0316391], [85.94470978, 22.02326965], [85.94258118, 22.01913071], [85.93856049, 22.01662064], [85.93309021, 22.0174408], [85.92877197, 22.01935959], [85.92488861, 22.01735115], [85.92340088, 22.01407814], [85.91954041, 22.00979042], [85.91223907, 22.0048008], [85.91306305, 21.9966507], [85.90924835, 21.99012947], [85.90725708, 21.98130989], [85.90966797, 21.97758102], [85.90921021, 21.97554016], [85.90445709, 21.9726696], [85.90599823, 21.96809006], [85.90542603, 21.96663094], [85.90284729, 21.96659088], [85.89417267, 21.97829056], [85.89115143, 21.97851944], [85.88613129, 21.97542], [85.88175201, 21.97483063], [85.87132263, 21.97475052], [85.8469696, 21.97707939], [85.84041595, 21.97648048], [85.82859802, 21.97294044], [85.82227325, 21.97013092], [85.81832886, 21.97001076], [85.81558228, 21.97130013], [85.81606293, 21.9753418], [85.81539154, 21.98013115], [85.81265259, 21.98096085], [85.80515289, 21.98022079], [85.80097961, 21.98166084], [85.78427887, 21.97859955], [85.78218842, 21.9793911], [85.78050232, 21.98104095], [85.77140045, 21.98371124], [85.76074982, 21.98971939], [85.76052094, 21.99694061], [85.7561264, 22.00839043], [85.75869751, 22.01480293], [85.76184845, 22.01794052], [85.77217102, 22.02470016], [85.77559662, 22.02827072], [85.77893829, 22.0362606], [85.77330017, 22.04330826], [85.7712326, 22.04714966], [85.77033234, 22.05128288], [85.78511047, 22.07191086], [85.78794098, 22.0771904], [85.79676056, 22.07450104], [85.80272675, 22.07176018], [85.8143692, 22.07007027], [85.83075714, 22.07697105], [85.82808685, 22.08266068], [85.82491302, 22.08712959], [85.8189621, 22.08963013], [85.81542206, 22.09282112], [85.80870819, 22.09184074], [85.81521606, 22.09902], [85.81474304, 22.10211182], [85.80204773, 22.11083031], [85.79718018, 22.10630035], [85.79397583, 22.10536957], [85.79091644, 22.10038948], [85.78425598, 22.09898758], [85.77903748, 22.09342003], [85.77339172, 22.09024048], [85.76502228, 22.08820915], [85.75782013, 22.08498192], [85.75213623, 22.0792408], [85.7504425, 22.07439041], [85.74606323, 22.06987953], [85.73381805, 22.06452942], [85.72235107, 22.05813026], [85.71755981, 22.05772972], [85.71277618, 22.0564003], [85.70780182, 22.05628967], [85.70465088, 22.05433083], [85.69600677, 22.0568409], [85.68788147, 22.05607986], [85.6815033, 22.04878044], [85.67195129, 22.05147171], [85.67236328, 22.05972099], [85.66757202, 22.06102943], [85.66472626, 22.06657028], [85.65750885, 22.07427979], [85.65532684, 22.07781029], [85.65033722, 22.08130074], [85.64805603, 22.08681107], [85.64460754, 22.09028053], [85.6400528, 22.09023285], [85.63639069, 22.08576965], [85.63124847, 22.08154106], [85.62623596, 22.0796299], [85.61958313, 22.07784081], [85.61110687, 22.07679939], [85.6085968, 22.07895088], [85.60732269, 22.08179092], [85.60359955, 22.0792408], [85.60176086, 22.07634163], [85.59664917, 22.07472038], [85.59108734, 22.07444], [85.5867691, 22.07681847], [85.58223724, 22.08098984], [85.57110596, 22.08605957], [85.56623077, 22.08703995], [85.56022644, 22.08490944], [85.55433655, 22.09082031], [85.54862213, 22.08855057], [85.53954315, 22.08658981], [85.53734589, 22.09029961], [85.53604889, 22.09440994], [85.53350067, 22.09679985], [85.52873993, 22.0987606], [85.52416992, 22.10305023], [85.5148468, 22.10820961], [85.50567627, 22.11145973], [85.4858017, 22.11648941], [85.47940063, 22.12177086], [85.47173309, 22.12413979], [85.46517944, 22.1312027], [85.45700836, 22.1357708], [85.43578339, 22.14417076], [85.41781616, 22.15335846], [85.41028595, 22.15608025], [85.40236664, 22.15653038], [85.3944397, 22.15859985], [85.39035034, 22.15513039], [85.38536835, 22.15234184], [85.37931824, 22.15168953], [85.37217712, 22.15244102], [85.36937714, 22.15521049], [85.36319733, 22.15456963], [85.36242676, 22.15004921], [85.36292267, 22.14657974], [85.35807037, 22.1379509], [85.35865784, 22.13280106], [85.36171722, 22.12475967], [85.36138153, 22.12144089], [85.35813141, 22.1196003], [85.35356903, 22.12057114], [85.34536743, 22.12699127], [85.33850098, 22.12471962], [85.32301331, 22.12499046], [85.31536865, 22.11584091], [85.30970001, 22.11338997], [85.30007935, 22.10705948], [85.28742218, 22.0931797], [85.28089905, 22.08764076], [85.27416229, 22.08008957], [85.26995087, 22.06896019], [85.26545715, 22.06025124], [85.25998688, 22.05285263], [85.25609589, 22.04245949], [85.24652863, 22.0254097], [85.24105835, 22.01251984], [85.23094177, 22.00027084], [85.22212982, 22.00344849], [85.21835327, 22.00667], [85.21488953, 22.01071167], [85.21383667, 22.01628113], [85.21389771, 22.02716064], [85.21460724, 22.03728104], [85.21074677, 22.04318047], [85.19232178, 22.05115128], [85.18699646, 22.05273056], [85.18345642, 22.05492973], [85.17913055, 22.06479073], [85.17675018, 22.06671906], [85.17246246, 22.06818962], [85.16960907, 22.06609917], [85.16436768, 22.06522942], [85.16983032, 22.05310059], [85.17080688, 22.04819107], [85.16720581, 22.0486908], [85.16374969, 22.0529995], [85.15896606, 22.06192017], [85.1578064, 22.06698036], [85.1555481, 22.07045937], [85.14891052, 22.07263947], [85.14083862, 22.07355118], [85.13506317, 22.07114029], [85.12539673, 22.06912041], [85.11888123, 22.0664711], [85.11329651, 22.07107925], [85.1102829, 22.07586288], [85.10897064, 22.0800209], [85.10447693, 22.08278084], [85.09970856, 22.08453941], [85.09900665, 22.09612083], [85.0954361, 22.09945107], [85.08409882, 22.10043907], [85.07623291, 22.10297012], [85.06945038, 22.10712814], [85.04389954, 22.11070061], [85.03513336, 22.1081295], [85.03118134, 22.10247993], [85.0271225, 22.10113907], [85.01995087, 22.10337067], [85.0140686, 22.09370995], [85.00901794, 22.09065056], [85.00720215, 22.08312988], [85.00231934, 22.0799427], [84.99359894, 22.07720947], [84.98742676, 22.07673836], [84.98104095, 22.08242035], [84.97982025, 22.08468056], [84.98049927, 22.09126091], [84.9834671, 22.09148979], [84.98586273, 22.09256935], [84.99362946, 22.09794807], [85.0194931, 22.10839081], [85.02374268, 22.11199188], [85.02429199, 22.11794281], [85.02735138, 22.1225605], [85.03115082, 22.13735962], [85.03031158, 22.14246178], [85.02619934, 22.14845085], [85.02539825, 22.15400124], [85.02802277, 22.15735817], [85.03322601, 22.1608429], [85.0414505, 22.17066002], [85.04779053, 22.17429924], [85.04960632, 22.17930984], [85.04692078, 22.18579292], [85.05879974, 22.20595169], [85.06253815, 22.21615982], [85.0694809, 22.23064995], [85.0681076, 22.24344063], [85.07206726, 22.24571991], [85.07431793, 22.25094032], [85.06990051, 22.26029015], [85.06941986, 22.26758194], [85.07051086, 22.27215958], [85.08235168, 22.27770805], [85.09857178, 22.28792], [85.10529327, 22.2911396], [85.10836029, 22.28947258], [85.11445618, 22.2904892], [85.11483765, 22.30038071], [85.11218262, 22.30507088], [85.11403656, 22.3142128], [85.10772705, 22.31523132], [85.10122681, 22.31432915], [85.09512329, 22.31239128], [85.08795929, 22.31408119], [85.08590698, 22.31698036], [85.09046173, 22.32487106], [85.09295654, 22.34109116], [85.08216095, 22.34132957], [85.07990265, 22.34439087], [85.07405853, 22.34859085], [85.07549286, 22.35577965], [85.07504272, 22.36096954], [85.07788086, 22.3691597], [85.08307648, 22.37844086], [85.08068085, 22.39546013], [85.07720184, 22.4030304], [85.07726288, 22.40830994], [85.07459259, 22.41345978], [85.06809235, 22.41806984], [85.06369019, 22.42322159], [85.06289673, 22.43608284], [85.05815125, 22.4397316], [85.05703735, 22.44470978], [85.06048584, 22.44951057], [85.07110596, 22.45590019], [85.07093811, 22.46116066], [85.07363892, 22.46668053], [85.07319641, 22.47286987], [85.06249237, 22.47841072], [85.05139923, 22.47941971], [85.04672241, 22.47739029], [85.04223633, 22.47694016], [85.03733063, 22.47508049], [85.03544617, 22.47729111], [85.03330994, 22.47692108], [85.03156281, 22.46978188], [85.02810669, 22.46820259], [85.02157593, 22.46710968], [85.00049591, 22.45836067], [84.994133, 22.45827103], [84.97779083, 22.45092964], [84.96024323, 22.44371986], [84.95728302, 22.44185829], [84.95458221, 22.4389019], [84.95243835, 22.43944931], [84.95336151, 22.4455204], [84.95244598, 22.45277023], [84.94728088, 22.45108032], [84.94077301, 22.44742966], [84.93136597, 22.43964958], [84.92533875, 22.43660927], [84.91739655, 22.43437958], [84.91815186, 22.42856979], [84.91986847, 22.42599106], [84.91639709, 22.4233799], [84.90770721, 22.41963959], [84.89379883, 22.41801071], [84.88024902, 22.41759109], [84.88198853, 22.42624855], [84.88150024, 22.42943954], [84.87947083, 22.43219948], [84.87779999, 22.4425106], [84.87652588, 22.44325066], [84.87525177, 22.44117928], [84.87124634, 22.43822289], [84.86371613, 22.43453026], [84.85534668, 22.43197823], [84.84780121, 22.43441963], [84.84136963, 22.43486977], [84.83946991, 22.43403053], [84.83574677, 22.42755127], [84.83254242, 22.42637825], [84.83162689, 22.4299202], [84.82842255, 22.42917061], [84.81269073, 22.43161011], [84.81047821, 22.43522835], [84.81047058, 22.44125175], [84.80779266, 22.44686127], [84.80124664, 22.44371033], [84.79128265, 22.4428196], [84.77805328, 22.44354057], [84.75269318, 22.44201279], [84.74385071, 22.41475105], [84.72614288, 22.41664124], [84.7113266, 22.41390038], [84.69149017, 22.41251183], [84.6815033, 22.41492081], [84.67282104, 22.41493034], [84.66934967, 22.41629982], [84.66160583, 22.41391945], [84.63210297, 22.4286499], [84.6255188, 22.42758942], [84.61364746, 22.42757988], [84.5953064, 22.4249382], [84.59395599, 22.42884064], [84.58907318, 22.42537117], [84.57215881, 22.42301178], [84.54329681, 22.41719818], [84.54065704, 22.42058945], [84.52662659, 22.42002106], [84.52101135, 22.41489029], [84.50582886, 22.41620064], [84.50179291, 22.41531944], [84.48126984, 22.40569115], [84.47666931, 22.40598106], [84.47447968, 22.40173149], [84.47595978, 22.39353943], [84.47572327, 22.39018822], [84.48020935, 22.38723946], [84.47759247, 22.38368034], [84.47280884, 22.38269043], [84.45565033, 22.37522125], [84.44785309, 22.37907982], [84.44207764, 22.37302017], [84.42694092, 22.36465073], [84.42719269, 22.36198044], [84.43144226, 22.36001015], [84.42584229, 22.3520298], [84.42608643, 22.3488102], [84.41911316, 22.35077095], [84.3944931, 22.34385109], [84.38786316, 22.34642029], [84.37758636, 22.34590912], [84.37200165, 22.34905052], [84.36741638, 22.34956932], [84.36171722, 22.34852982], [84.35909271, 22.34504128], [84.35328674, 22.34510994], [84.34496307, 22.34404945], [84.33838654, 22.34209824], [84.333992, 22.34291077], [84.32396698, 22.33892059], [84.31874847, 22.34049988], [84.31461334, 22.33892059], [84.28922272, 22.33732033], [84.28501892, 22.34211159], [84.27324677, 22.34509277], [84.26616669, 22.34782982], [84.26088715, 22.35370064], [84.25141144, 22.37041092], [84.24655914, 22.3737011], [84.24046326, 22.3744812], [84.22612762, 22.37412071], [84.19410706, 22.37181091], [84.18344116, 22.38368034], [84.17516327, 22.38894081], [84.15248871, 22.4009304], [84.14229584, 22.41539955], [84.13587952, 22.42068291], [84.13310242, 22.44531059], [84.13522339, 22.4490509], [84.13751984, 22.45718956], [84.13743591, 22.46710014], [84.13492584, 22.47094917], [84.13069153, 22.47001076], [84.12914276, 22.47348976], [84.12557983, 22.47359276], [84.117836, 22.47142029], [84.10611725, 22.47384834], [84.10211945, 22.47731018], [84.10347748, 22.47933006], [84.1029129, 22.48129082], [84.0998764, 22.48033905], [84.0877533, 22.48493004], [84.07920837, 22.48885155], [84.07164001, 22.49419022], [84.0670929, 22.49812126], [84.06900024, 22.49954987], [84.06668854, 22.50223923], [84.06047821, 22.50502014], [84.05758667, 22.51015091], [84.05065918, 22.51235962], [84.0330658, 22.5120697], [84.02472687, 22.51621246], [84.01914978, 22.52107048], [84.01554108, 22.52168083], [84.00963593, 22.52029037], [84.00250244, 22.52086067], [84.00518036, 22.52473068], [84.00489807, 22.53013039], [84.00157928, 22.53399086], [83.99944305, 22.53950119], [84.00212097, 22.54659843], [84.00417328, 22.55486107], [84.00392914, 22.56192017], [84.00505066, 22.56956291], [84.01103973, 22.57500267], [84.01777649, 22.5789299], [84.02002716, 22.58279037], [84.02134705, 22.58723259], [84.03359222, 22.59127045], [84.04193115, 22.59218025], [84.04812622, 22.59414291], [84.05287933, 22.60260963], [84.05930328, 22.6074028], [84.08039093, 22.6365509], [84.09395599, 22.63264084], [84.09764099, 22.63301086], [84.1072464, 22.63667107], [84.11531067, 22.63525963], [84.13210297, 22.63578033], [84.14993286, 22.63442039], [84.15743256, 22.64093971], [84.16483307, 22.64532089], [84.18035126, 22.6498394], [84.19161987, 22.66025162], [84.1969986, 22.66378021], [84.20160675, 22.66518974], [84.20717621, 22.66506004], [84.20967102, 22.6629982], [84.21479034, 22.66456032], [84.22061157, 22.66891098], [84.22775269, 22.67699051], [84.23223877, 22.68857956], [84.22769165, 22.6979599], [84.22944641, 22.70523262], [84.22763062, 22.72315025], [84.22471619, 22.72735023], [84.22535706, 22.73516083], [84.2297287, 22.74015045], [84.2416687, 22.74835014], [84.25158691, 22.75807953], [84.25370789, 22.76072121], [84.25422668, 22.76297951], [84.26010132, 22.76494026], [84.27403259, 22.76559067], [84.27877808, 22.76136017], [84.28144836, 22.76011086], [84.28528595, 22.76337051], [84.28768921, 22.77090073], [84.28710938, 22.77671051], [84.29030609, 22.78716278], [84.29627991, 22.79363823], [84.30181885, 22.79507065], [84.3034668, 22.79846954], [84.30996704, 22.79898262], [84.31169128, 22.80330086], [84.31252289, 22.81035042], [84.31770325, 22.81718063], [84.32038116, 22.83603096], [84.31858826, 22.83513069], [84.31839752, 22.84375191], [84.3203125, 22.84942055], [84.32946014, 22.85955048], [84.33500671, 22.86024094], [84.33835602, 22.85904121], [84.34217834, 22.85917091], [84.34789276, 22.86316109], [84.35793304, 22.86059952], [84.36988831, 22.86450005], [84.36995697, 22.86890984], [84.37145996, 22.87212944], [84.3759613, 22.87363815], [84.37692261, 22.87589073], [84.37587738, 22.88140106], [84.37818909, 22.88786125], [84.37825775, 22.8931427], [84.37670898, 22.89772987], [84.37278748, 22.8984108], [84.37085724, 22.90160942], [84.37619019, 22.90920067], [84.38629913, 22.9168396], [84.38964844, 22.92374039], [84.38905334, 22.93873978], [84.38645935, 22.94238091], [84.38195038, 22.94573021], [84.37922668, 22.94890022], [84.37779236, 22.95191765], [84.37773132, 22.96171951], [84.37638092, 22.96630287], [84.3733902, 22.97214127], [84.3705368, 22.97507095], [84.36149597, 22.97455025], [84.34823608, 22.97587013], [84.34361267, 22.97372055], [84.33181, 22.97913933], [84.32515717, 22.97933006], [84.3182373, 22.97657967], [84.31449127, 22.97223091], [84.3067627, 22.96751022], [84.28933716, 22.9616394], [84.27857208, 22.9612484], [84.27192688, 22.97093964], [84.26888275, 22.97903061], [84.27111053, 22.98415947], [84.27140045, 22.98884964], [84.26789093, 22.98791122], [84.2620697, 22.9800415], [84.25461578, 22.97369957], [84.2509079, 22.97142982], [84.24150848, 22.97287941], [84.2374115, 22.98040009], [84.22680664, 22.98007011], [84.21705627, 22.97647285], [84.21494293, 22.97743034], [84.21202087, 22.98638916], [84.20107269, 22.99882126], [84.1967926, 23.00410271], [84.19993591, 23.01511955], [84.19824982, 23.01898956], [84.18992615, 23.02371979], [84.17904663, 23.02256012], [84.17668152, 23.02051926], [84.17537689, 23.01190186], [84.17259979, 23.00720024], [84.17397308, 23.00035095], [84.17314911, 22.99875069], [84.16860199, 22.99500084], [84.17059326, 22.98518944], [84.1713562, 22.97707939], [84.16786194, 22.97096062], [84.15458679, 22.96437263], [84.14800262, 22.96386909], [84.14356995, 22.97511101], [84.14511108, 22.98257065], [84.14421082, 22.9881897], [84.13835907, 22.99848938], [84.13733673, 23.00626945], [84.13169861, 23.01826286], [84.12664795, 23.02601051], [84.1246109, 23.03074837], [84.12367249, 23.03661919], [84.12335968, 23.04499245], [84.12483215, 23.05347824], [84.12587738, 23.05688286], [84.13076782, 23.06336021], [84.13170624, 23.0674305], [84.13092041, 23.07748985], [84.12937927, 23.08154106], [84.12647247, 23.08514977], [84.11618805, 23.08613968], [84.11244965, 23.08718109], [84.11026001, 23.09208107], [84.10492706, 23.09922028], [84.09736633, 23.10482025], [84.08786774, 23.10948944], [84.07646179, 23.10984993], [84.06671143, 23.10711288], [84.0614624, 23.10989952], [84.05893707, 23.11259079], [84.05560303, 23.12070084], [84.0528717, 23.12446976], [84.04527283, 23.13052177], [84.03997803, 23.1321106], [84.03595734, 23.13495064], [84.03367615, 23.13844109], [84.03336334, 23.14273071], [84.03026581, 23.14936829], [84.02909088, 23.15388107], [84.03112793, 23.16113281], [84.03380585, 23.16784096], [84.03932953, 23.1785183], [84.04399109, 23.18460083], [84.05090332, 23.18958092], [84.05612183, 23.19640923], [84.05834961, 23.20359993], [84.05802917, 23.20800018], [84.0535965, 23.21317101], [84.05236816, 23.21643066], [84.05223846, 23.2212429], [84.05400848, 23.23418045], [84.05045319, 23.24094963], [84.05126953, 23.2466011], [84.05906677, 23.27412033], [84.05906677, 23.28232002], [84.06005859, 23.28628922], [84.06304169, 23.28964043], [84.06381989, 23.29224014], [84.05938721, 23.30430031], [84.05995178, 23.30820084], [84.07025146, 23.32999039], [84.06797028, 23.33409119], [84.06051636, 23.3431797], [84.04995728, 23.35186005], [84.04860687, 23.35416031], [84.04734039, 23.36365128], [84.04444885, 23.36712074], [84.04345703, 23.36972046], [84.04722595, 23.37121964], [84.04338837, 23.37401009], [84.03803253, 23.3761692], [84.02648163, 23.37692833], [84.02073669, 23.37545967], [84.01715088, 23.37158966], [84.01145172, 23.36339951], [84.00653076, 23.35280037], [83.99276733, 23.35588264], [83.98301697, 23.35955048], [83.97486115, 23.36479187], [83.97025299, 23.36939812], [83.96688843, 23.37422943], [83.96582794, 23.38121033], [83.96778107, 23.39299011], [83.97616577, 23.40752029], [83.97805786, 23.4141407], [83.97815704, 23.42093086], [83.97944641, 23.42669106], [83.97775269, 23.4314518], [83.96972656, 23.44766808], [83.9695282, 23.4554081], [83.97914886, 23.46058083], [83.98462677, 23.47559166], [83.98889923, 23.48178101], [83.99272156, 23.4851799], [83.99724579, 23.49311066], [84.00563812, 23.49646187], [84.00875854, 23.49958038], [84.01228333, 23.5081501], [84.01274872, 23.52081108], [84.01539612, 23.52563286], [84.02266693, 23.54424095], [84.02128601, 23.54992867], [84.02511597, 23.56579018], [84.02291107, 23.57459068], [84.02411652, 23.58788109], [84.02194214, 23.59221077], [84.02233887, 23.59736061], [84.02030182, 23.60017967], [84.01257324, 23.60548019], [84.0018692, 23.62043953], [84.00177765, 23.62290955], [84.0036087, 23.62631989], [84.00771332, 23.62852097], [84.00702667, 23.63231087], [83.99267578, 23.63305283], [83.97545624, 23.63083076], [83.962677, 23.62618828], [83.94861603, 23.62431908], [83.9378891, 23.6224308], [83.93152618, 23.6114006], [83.92958832, 23.59367943], [83.93525696, 23.56303978], [83.92249298, 23.56504822], [83.91467285, 23.56874084], [83.9052887, 23.56950951], [83.89849091, 23.57116127], [83.89009094, 23.5759201], [83.88292694, 23.57277107], [83.85959625, 23.5783329], [83.84616089, 23.58092117], [83.83763123, 23.58135986], [83.8212204, 23.58485031], [83.81088257, 23.58885956], [83.80634308, 23.58230972], [83.80047607, 23.58317947], [83.79772186, 23.5900898], [83.78614807, 23.59818077], [83.77488708, 23.59950066], [83.76776886, 23.60908127], [83.76573944, 23.61754036], [83.76493835, 23.62148094], [83.74778748, 23.62664986], [83.74302673, 23.64046097], [83.74462128, 23.64565086], [83.75208282, 23.64898109], [83.75094604, 23.65332985], [83.74404144, 23.65913963], [83.72891235, 23.66740036], [83.72132874, 23.67374039], [83.71472931, 23.68254089], [83.71507263, 23.69024086], [83.72257996, 23.69413948], [83.72431183, 23.69678116], [83.73213959, 23.70466995], [83.73471832, 23.71355057], [83.73246002, 23.72398949], [83.72934723, 23.7318306], [83.73000336, 23.74368095], [83.72940063, 23.75473022], [83.72709656, 23.75990105], [83.71235657, 23.77233124], [83.71250153, 23.78083992], [83.71080017, 23.7895298], [83.70775604, 23.79495049], [83.69989777, 23.80163002], [83.69558716, 23.80759811], [83.69859314, 23.81646156], [83.69538879, 23.82066917], [83.68849182, 23.82393265], [83.68200684, 23.82580185], [83.67772675, 23.82266808], [83.67220306, 23.8200798], [83.66649628, 23.8259182], [83.65833282, 23.82781982], [83.65528107, 23.83201027], [83.65759277, 23.83697128], [83.65624237, 23.84364128], [83.64955139, 23.84806061], [83.63790131, 23.84703064], [83.62998962, 23.84736061], [83.61148834, 23.85336113], [83.60057068, 23.85347748], [83.59044647, 23.85649109], [83.58116913, 23.8619194], [83.57177734, 23.86306], [83.56121063, 23.86295128], [83.55760956, 23.86952972], [83.56369781, 23.87306023], [83.57302856, 23.87706947], [83.57615662, 23.88438034], [83.57015228, 23.89035988], [83.56050873, 23.89265823], [83.54936981, 23.89283943], [83.54284668, 23.89824104], [83.537323, 23.91463089], [83.53894043, 23.93350029], [83.53373718, 23.94174004], [83.5226059, 23.95216942], [83.51243591, 23.96699905], [83.50772095, 23.97945976], [83.50654602, 23.99134064], [83.50750732, 24.00139046], [83.51655579, 24.01062012], [83.51483154, 24.01576042], [83.5096283, 24.02540016], [83.50670624, 24.0282402], [83.50122833, 24.03068924], [83.4789505, 24.03854942], [83.46840668, 24.04067039], [83.45813751, 24.04191971], [83.45307922, 24.04142189], [83.44758606, 24.04248047], [83.4332428, 24.05470085], [83.43132019, 24.0579319], [83.42920685, 24.06202126], [83.43061066, 24.06904984], [83.43013, 24.07401085], [83.42858887, 24.07977295], [83.42536926, 24.08376122], [83.42137909, 24.08378029], [83.41467285, 24.08121109], [83.40895081, 24.08047104], [83.40309143, 24.08077812], [83.4006958, 24.08177948], [83.39240265, 24.09495163], [83.38326263, 24.09987068], [83.36197662, 24.10196114], [83.35723114, 24.10169029], [83.3457489, 24.09707069], [83.32759857, 24.09964943], [83.32356262, 24.1013298], [83.33904266, 24.11045074], [83.34279633, 24.11425018], [83.34355164, 24.11878967], [83.34900665, 24.12643814], [83.34992218, 24.13709259], [83.35250092, 24.14030075], [83.35607147, 24.14773941], [83.35735321, 24.15683937], [83.36560059, 24.17196083], [83.36936188, 24.18058968], [83.37049866, 24.18675041], [83.37834167, 24.20079041], [83.37822723, 24.2052803], [83.37621307, 24.21013069], [83.37602997, 24.213871], [83.37840271, 24.21685982], [83.37930298, 24.22019958], [83.37689972, 24.23093033], [83.37734222, 24.23566055], [83.38085938, 24.24002075], [83.39111328, 24.24464989], [83.39343262, 24.2471199], [83.39338684, 24.25266075], [83.40188599, 24.26600075], [83.40291595, 24.27613068], [83.4005127, 24.28524017], [83.39615631, 24.29339027], [83.39050293, 24.29652023], [83.38656616, 24.29756927], [83.38182831, 24.29988098], [83.38063812, 24.30046844], [83.38027191, 24.3047905], [83.37561035, 24.31344986], [83.37593842, 24.31454086], [83.37861633, 24.31552124], [83.38530731, 24.32034111], [83.3914032, 24.32677078], [83.40332794, 24.3373909], [83.40689087, 24.33899117], [83.41118622, 24.33955002], [83.42352295, 24.33870125], [83.42661285, 24.3399601], [83.43004608, 24.34495926], [83.43431091, 24.34747124], [83.44104767, 24.3608799], [83.44567108, 24.36327171], [83.45139313, 24.36474991], [83.45144653, 24.36700058], [83.44763947, 24.36844826], [83.44320679, 24.37278938], [83.44278717, 24.37764168], [83.4397583, 24.38013077], [83.43995667, 24.38698006], [83.43884277, 24.38899994], [83.43470764, 24.39063072], [83.43292999, 24.39404106], [83.43048859, 24.39600754], [83.42988586, 24.40378952], [83.4262085, 24.40604973], [83.41652679, 24.40947914], [83.41197205, 24.41025162], [83.40013885, 24.40867996], [83.3989563, 24.41208076], [83.40067291, 24.43713951], [83.39248657, 24.43642044], [83.38978577, 24.43758965], [83.38140869, 24.45565033], [83.3842392, 24.46140099], [83.38713074, 24.46457291], [83.38820648, 24.4681282], [83.38816833, 24.47326279], [83.39256287, 24.48027992], [83.39346313, 24.48476982], [83.39360809, 24.48891068], [83.39160156, 24.49283981], [83.39212799, 24.49711037], [83.393013, 24.50119019], [83.39546967, 24.50377083], [83.39997864, 24.50605965], [83.42636108, 24.51278114], [83.43563843, 24.5135994], [83.45308685, 24.51711082], [83.46186829, 24.51787758], [83.48139191, 24.52391052], [83.48671722, 24.52435112], [83.49816895, 24.52705956], [83.50950623, 24.52754021], [83.52384186, 24.52592087], [83.53504181, 24.52557945], [83.54244232, 24.52618027], [83.54725647, 24.52403069], [83.57121277, 24.51700974], [83.59240723, 24.51489067], [83.60015869, 24.51324081], [83.64483643, 24.51618004], [83.66252899, 24.51568031], [83.67080688, 24.51477051], [83.68245697, 24.51558113], [83.69567871, 24.51061058], [83.70236969, 24.50733948], [83.71669006, 24.50494957], [83.73073578, 24.50879097], [83.74865723, 24.51053047], [83.78174591, 24.52358055], [83.78803253, 24.52717018], [83.794487, 24.52944946], [83.79901123, 24.52988052], [83.80895233, 24.52894974], [83.81623077, 24.53125954], [83.82740021, 24.53314972], [83.8414917, 24.53450012], [83.84807587, 24.5363102], [83.8576889, 24.53755951], [83.86804199, 24.53288078], [83.87885284, 24.53650093], [83.90274811, 24.54244041], [83.9179306, 24.54578972], [83.92407227, 24.54620934], [83.92845917, 24.54791069], [83.93300629, 24.55174255], [83.93649292, 24.55591965], [83.94818115, 24.56651115], [83.95758057, 24.57632828], [83.9648819, 24.58764076], [83.97235107, 24.59662819], [83.97924042, 24.61512947], [83.99221039, 24.63803291], [84.00196838, 24.63540077], [84.01452637, 24.63163948], [84.01566315, 24.62760162], [84.01963806, 24.62681961], [84.02416992, 24.62906075], [84.0267868, 24.62774277], [84.0289917, 24.62264061], [84.03205109, 24.62157822], [84.0332489, 24.61895943], [84.03823853, 24.61940956], [84.04673767, 24.61228943], [84.0448761, 24.6069603], [84.04785919, 24.60650826], [84.05311584, 24.59469986], [84.05142212, 24.59152031], [84.05293274, 24.5879612], [84.05808258, 24.58836174], [84.06136322, 24.58937073], [84.06265259, 24.58371925], [84.05974579, 24.57698059], [84.06526184, 24.57505989], [84.06774139, 24.57102966], [84.07247925, 24.56960106], [84.07467651, 24.56475067], [84.07367706, 24.55758095], [84.07723999, 24.5524807], [84.07833862, 24.54500961], [84.08429718, 24.5387001], [84.08870697, 24.53607941], [84.08969116, 24.53392982], [84.086586, 24.51463127], [84.08909607, 24.5041275], [84.0969696, 24.49572182], [84.10092163, 24.48790169], [84.10977936, 24.48139954], [84.12258148, 24.48666954], [84.12490845, 24.49831963], [84.12901306, 24.50068092], [84.13654327, 24.50254059], [84.13996124, 24.5048008], [84.1370163, 24.51818085], [84.1362915, 24.52936172], [84.14605713, 24.54030037], [84.14955902, 24.54030037], [84.16065979, 24.53824043], [84.16440582, 24.53371239], [84.15571594, 24.52433968], [84.15589142, 24.51948166], [84.15364075, 24.51764107], [84.16114044, 24.51258278], [84.17137146, 24.50979042], [84.17926025, 24.51041985], [84.18226624, 24.51563072], [84.18225861, 24.51834106], [84.18641663, 24.52249908], [84.18239594, 24.52360916], [84.17282104, 24.54198074], [84.17288208, 24.54713058], [84.18158722, 24.54706001], [84.18695831, 24.54930115], [84.18830109, 24.55532074], [84.19991302, 24.55702019], [84.20050049, 24.54944038], [84.20620728, 24.54533005], [84.20892334, 24.53716087], [84.21749115, 24.5351696], [84.22068024, 24.55033112], [84.23500824, 24.55318069], [84.23426056, 24.5435791], [84.24108887, 24.54322052], [84.24829865, 24.53876114], [84.24994659, 24.5357399], [84.24852753, 24.53158951], [84.25714111, 24.53075027], [84.25846863, 24.53769112], [84.26274109, 24.53711128], [84.26474762, 24.54057121], [84.26944733, 24.54136848], [84.26859283, 24.54685974], [84.27828217, 24.54747009], [84.28009033, 24.55191994], [84.27189636, 24.55402184], [84.26922607, 24.56425285], [84.27997589, 24.56336021], [84.29297638, 24.56599045], [84.29743195, 24.56314278], [84.30200958, 24.54725266], [84.30944824, 24.53954124], [84.3119278, 24.53375816], [84.31284332, 24.52676964], [84.31910706, 24.52231026], [84.32168579, 24.51317978], [84.32634735, 24.50271988], [84.32565308, 24.49670982], [84.32170868, 24.48975754], [84.3082428, 24.48690033], [84.29418945, 24.48076057], [84.28526306, 24.46591949], [84.29022217, 24.45808029], [84.29321289, 24.45082283], [84.31498718, 24.44750977], [84.33039856, 24.43119049], [84.33065796, 24.42843056], [84.32749176, 24.42772865], [84.31939697, 24.42925072], [84.31505585, 24.42345238], [84.3182373, 24.42021942], [84.32486725, 24.42366982], [84.32778931, 24.4221611], [84.32779694, 24.41657066], [84.3258667, 24.41093063], [84.33162689, 24.40464973], [84.33798218, 24.40129089], [84.33586121, 24.39583015], [84.34696198, 24.39207077], [84.3553009, 24.39096069], [84.36136627, 24.38663292], [84.36725616, 24.38695908], [84.37377167, 24.39099121], [84.38221741, 24.38969994], [84.3850174, 24.37934113], [84.39202881, 24.37574959], [84.39766693, 24.37741089], [84.3997879, 24.37463951], [84.39494324, 24.36779022], [84.42253876, 24.35914993], [84.41816711, 24.34235954], [84.41742706, 24.33136177], [84.44491577, 24.33418083], [84.4466629, 24.3397007], [84.45453644, 24.33864975], [84.46196747, 24.31755066], [84.46511078, 24.30838966], [84.46839905, 24.30529022], [84.47534943, 24.30256271], [84.47856903, 24.30289078], [84.48706055, 24.30483246], [84.48874664, 24.3021698], [84.48751068, 24.29883957], [84.48420715, 24.29692078], [84.4935379, 24.28704071], [84.49688721, 24.29272079], [84.50229645, 24.29454994], [84.50123596, 24.29880905], [84.50454712, 24.30590057], [84.50319672, 24.31541061], [84.51069641, 24.3171711], [84.51419067, 24.3236084], [84.51741028, 24.33366966], [84.52548981, 24.33947945], [84.51937866, 24.34584045], [84.51882172, 24.35316086], [84.52671051, 24.36102104], [84.52796173, 24.36483002], [84.52406311, 24.36876106], [84.52152252, 24.37626076], [84.54167938, 24.37671089], [84.54585266, 24.37369919], [84.5560379, 24.3797226], [84.56578064, 24.38393974], [84.56430817, 24.38989067], [84.55912018, 24.39710808], [84.56121826, 24.40184021], [84.56539154, 24.4074707], [84.57247925, 24.41234016], [84.58006287, 24.41041946], [84.58184814, 24.40146065], [84.58992004, 24.4043808], [84.59420013, 24.40401077], [84.60096741, 24.40097809], [84.61251068, 24.40121269], [84.61521149, 24.4038105], [84.61929321, 24.40205956], [84.62288666, 24.40394974], [84.62885284, 24.40017128], [84.64305115, 24.39861107], [84.65825653, 24.39374161], [84.6601181, 24.39598083], [84.66294861, 24.4106102], [84.66779327, 24.41296005], [84.66838837, 24.42629051], [84.66584778, 24.42843056], [84.66622925, 24.43119049], [84.67401123, 24.44114113], [84.67891693, 24.4563427], [84.68405914, 24.45919991], [84.69407654, 24.46179962], [84.70652771, 24.4723587], [84.71292877, 24.46863174], [84.71750641, 24.4688282], [84.72490692, 24.47294998], [84.74006653, 24.48826981], [84.74201965, 24.49645805], [84.7629776, 24.50176811], [84.7798996, 24.50485039], [84.78367615, 24.51770973], [84.78970337, 24.52154922], [84.79532623, 24.52949142], [84.80164337, 24.52111816], [84.81949615, 24.52482033], [84.83262634, 24.51148033], [84.82792664, 24.48600006], [84.82718658, 24.47011948], [84.83345795, 24.46958923], [84.83273315, 24.46116066], [84.83062744, 24.45920944], [84.83439636, 24.45252037], [84.84198761, 24.45547104], [84.84748077, 24.46593094], [84.85733795, 24.46076965], [84.85703278, 24.45758247], [84.85974884, 24.45664024], [84.8629303, 24.4576416], [84.8674469, 24.46692085], [84.87271881, 24.46582031], [84.87625122, 24.46278954], [84.88017273, 24.46280098], [84.87805176, 24.44379044], [84.88004303, 24.43204117], [84.87789917, 24.42263031], [84.88234711, 24.41710281], [84.89190674, 24.39853096], [84.8981781, 24.39381981], [84.9005127, 24.38208008], [84.89441681, 24.37504005], [84.89803314, 24.37212944], [84.90331268, 24.37231064], [84.91297913, 24.37565041], [84.92533875, 24.37804031], [84.93495178, 24.37645912], [84.94793701, 24.37177086], [84.96856689, 24.37594986], [84.99040222, 24.41222954], [85.01069641, 24.41608047], [85.01460266, 24.41912079], [85.02066803, 24.42201996], [85.03209686, 24.42535019], [85.03573608, 24.42311287], [85.03954315, 24.42412758], [85.04223633, 24.41827965], [85.05329132, 24.41513062], [85.05748749, 24.41648293], [85.06040955, 24.42460823], [85.06461334, 24.43058968], [85.06906891, 24.43565941], [85.07615662, 24.43987083], [85.07567596, 24.42175102], [85.07375336, 24.4129982], [85.07454681, 24.40846252], [85.07302094, 24.40653992], [85.07038879, 24.40517998], [85.06919861, 24.40119934], [85.07100677, 24.39969254], [85.06548309, 24.38676071], [85.08068085, 24.38075066], [85.0894165, 24.37919998], [85.092453, 24.38152122], [85.09594727, 24.39077187], [85.09867096, 24.3939209], [85.10932922, 24.39882088], [85.1150589, 24.40901947], [85.11898804, 24.40913963], [85.1206665, 24.40843964], [85.12693024, 24.41151047], [85.14795685, 24.4181881], [85.15529633, 24.41801071], [85.1578598, 24.42416], [85.16439056, 24.42769051], [85.16938019, 24.42947006], [85.1688385, 24.4317894], [85.16625977, 24.43349075], [85.1648407, 24.43580055], [85.16372681, 24.4414196], [85.16133118, 24.44329071], [85.15872955, 24.45125008], [85.15260315, 24.45375061], [85.14990997, 24.45585251], [85.14927673, 24.45928001], [85.15067291, 24.46286964], [85.15289307, 24.46414948], [85.16323853, 24.46718979], [85.16750336, 24.46735954], [85.1698761, 24.46609116], [85.17632294, 24.46797943], [85.18260193, 24.46866035], [85.19052124, 24.46858025], [85.19924927, 24.46739006], [85.20326233, 24.47294998], [85.21578217, 24.47254944], [85.22392273, 24.4711895], [85.22853851, 24.47941017], [85.23532867, 24.47985077], [85.23941803, 24.48882294], [85.24649811, 24.49529076], [85.25444031, 24.49793053], [85.26956177, 24.49837112], [85.28196716, 24.49720001], [85.28103638, 24.49975014], [85.28237152, 24.50375938], [85.28192902, 24.509161], [85.27980804, 24.51388168], [85.27935791, 24.51910019], [85.28251648, 24.52668953], [85.28804779, 24.52840042], [85.29734802, 24.52864075], [85.31253052, 24.52658081], [85.31855774, 24.52462959], [85.32250214, 24.52557945], [85.3315506, 24.5262413], [85.33790588, 24.52799034], [85.34581757, 24.52799988], [85.36116028, 24.52971268], [85.37026978, 24.52958107], [85.38278198, 24.53253174], [85.38336945, 24.53519058], [85.38860321, 24.53708076], [85.39517212, 24.54128075], [85.40305328, 24.54494095], [85.40661621, 24.54566193], [85.411026, 24.54511261], [85.42753601, 24.53729057], [85.43327332, 24.53607941], [85.44213104, 24.53938484], [85.44230652, 24.53944969], [85.44655609, 24.53997993], [85.45658875, 24.53921127], [85.47215271, 24.54779053], [85.4809494, 24.5481205], [85.48648071, 24.55075073], [85.48944092, 24.54915047], [85.49446106, 24.55061913], [85.49752045, 24.54850006], [85.49746704, 24.54688072], [85.49997711, 24.54389], [85.50254822, 24.5428791], [85.50319672, 24.53572273], [85.50241852, 24.53142929], [85.50435638, 24.52972984], [85.51481628, 24.52782822], [85.51830292, 24.52454948], [85.53418732, 24.53219032], [85.53646088, 24.53601074], [85.54035187, 24.55034828], [85.53987122, 24.5561409], [85.53820038, 24.56145096], [85.53646088, 24.56380081], [85.53679657, 24.56524086], [85.53901672, 24.56587029], [85.54380798, 24.56447983], [85.55233002, 24.5594101], [85.55461121, 24.55612946], [85.55625916, 24.55681992], [85.55658722, 24.56064034], [85.56445313, 24.56184959], [85.56829071, 24.56520081], [85.56575775, 24.571661], [85.56711578, 24.57822037], [85.56221771, 24.58098984], [85.56138611, 24.58366966], [85.56285095, 24.59127045], [85.56520081, 24.59666061], [85.56989288, 24.60021973], [85.57657623, 24.60301018], [85.58196259, 24.60009956], [85.59114075, 24.59705925], [85.59825134, 24.59757042], [85.60787964, 24.59078979], [85.60852051, 24.58503914], [85.615448, 24.58292961], [85.62198639, 24.58385849], [85.63279724, 24.58056068], [85.64427948, 24.57829094], [85.66470337, 24.58193016], [85.67031097, 24.5880928], [85.67324829, 24.59294128], [85.67352295, 24.59563065], [85.67238617, 24.59818077], [85.670578, 24.59943008], [85.67212677, 24.61940002], [85.66895294, 24.6305294], [85.66570282, 24.63626099], [85.66432953, 24.6410408], [85.66364288, 24.64447021], [85.66118622, 24.64664078], [85.66069794, 24.65060234], [85.66371918, 24.66098022], [85.66333008, 24.66471291], [85.66079712, 24.66757965], [85.65975952, 24.67031288], [85.65997314, 24.6747303], [85.65046692, 24.67924118], [85.64826202, 24.68188095], [85.6495285, 24.68704033], [85.67965698, 24.69376755], [85.6870575, 24.70089149], [85.6966629, 24.71347237], [85.69639587, 24.71725082], [85.69875336, 24.72106934], [85.70343781, 24.72537041], [85.70477295, 24.72872925], [85.70533752, 24.74005127], [85.70812988, 24.7476902], [85.70553589, 24.75162125], [85.70355988, 24.7574501], [85.70346832, 24.76349258], [85.70478058, 24.76883125], [85.709198, 24.77563858], [85.70980072, 24.7809906], [85.71231079, 24.78333282], [85.72099304, 24.7869606], [85.72296906, 24.79890823], [85.72830963, 24.80066109], [85.72978973, 24.80849075], [85.73252106, 24.81648254], [85.73500824, 24.82138252], [85.73674011, 24.82265091], [85.74727631, 24.81991959], [85.75827789, 24.81508827], [85.76074982, 24.81507111], [85.76544952, 24.81250954], [85.76879883, 24.80881119], [85.76859283, 24.80404091], [85.76940155, 24.8028717], [85.77723694, 24.7989502], [85.77923584, 24.80048943], [85.78572845, 24.79868126], [85.81066132, 24.79449844], [85.81260681, 24.79936028], [85.81803131, 24.80696106], [85.82257843, 24.80895042], [85.8272171, 24.80964279], [85.84194183, 24.80805969], [85.85381317, 24.80764008], [85.86402893, 24.80542946], [85.8777771, 24.80029106], [85.88967896, 24.79165077], [85.88717651, 24.78558922], [85.90168762, 24.76986122], [85.90457153, 24.76128006], [85.9105072, 24.75366974], [85.9209671, 24.74456024], [85.92767334, 24.7404995], [85.94270325, 24.73442078], [85.95030212, 24.73211861], [85.96064758, 24.7317009], [85.96613312, 24.73229027], [85.97016907, 24.73357964], [85.97271729, 24.73628998], [85.97589111, 24.74596977], [85.97725677, 24.74763107], [85.99997711, 24.75138092], [86.00611115, 24.76568031], [86.00956726, 24.76799965], [86.01397705, 24.7689991], [86.01967621, 24.76776123], [86.02275848, 24.76938057], [86.02778625, 24.77029037], [86.03179169, 24.77275276], [86.03443909, 24.77617073], [86.03897858, 24.77667046], [86.04305267, 24.77740097], [86.04788208, 24.77828979], [86.05058289, 24.77954102], [86.05264282, 24.77318954], [86.05288696, 24.76770973], [86.0530014, 24.76174927], [86.04984283, 24.75578117], [86.04535675, 24.75191116], [86.04154968, 24.74790001], [86.03601074, 24.74734116], [86.03681946, 24.74382973], [86.03907013, 24.74131966], [86.04270935, 24.74387169], [86.05503845, 24.74634933], [86.06041718, 24.74768066], [86.06318665, 24.75167084], [86.08657837, 24.74632072], [86.10553741, 24.73596954], [86.10929871, 24.73224068], [86.11094666, 24.72402763], [86.1159668, 24.7188797], [86.11863708, 24.71165085], [86.12444305, 24.70516014], [86.12909698, 24.69003105], [86.13201141, 24.6803894], [86.13359833, 24.67551041], [86.13002777, 24.6714592], [86.12594604, 24.67080116], [86.12848663, 24.66597939], [86.12631989, 24.65422058], [86.1231308, 24.64793015], [86.11824799, 24.64189148], [86.12185669, 24.63005066], [86.12200928, 24.62393188], [86.12322998, 24.61968994], [86.12558746, 24.61182022], [86.13076019, 24.60893059], [86.13329315, 24.60354042], [86.14463043, 24.60305977], [86.15226746, 24.59971046], [86.15696716, 24.58923912], [86.16565704, 24.58368111], [86.19493866, 24.58516121], [86.21570587, 24.59117126], [86.21656036, 24.60280037], [86.21737671, 24.61177063], [86.23026276, 24.60227013], [86.23874664, 24.59679985], [86.24288177, 24.59213829], [86.24855042, 24.58513069], [86.25747681, 24.58312988], [86.26152802, 24.57690048], [86.26413727, 24.57583809], [86.26625824, 24.58195114], [86.26970673, 24.57780075], [86.27348328, 24.57562065], [86.27688599, 24.57419968], [86.27612305, 24.57908058], [86.27378845, 24.58274841], [86.28040314, 24.58418083], [86.28835297, 24.58433914], [86.29263306, 24.58609009], [86.30166626, 24.58315086], [86.31005096, 24.58156013], [86.31223297, 24.58588028], [86.32286072, 24.58409119], [86.32269287, 24.58056068], [86.318573, 24.57892036], [86.31936646, 24.57445908], [86.31098938, 24.56818008], [86.30809784, 24.5657196], [86.30982208, 24.56310081], [86.30404663, 24.55829048], [86.30983734, 24.54734039], [86.3081665, 24.54083252], [86.3013382, 24.53197861], [86.30330658, 24.52773094], [86.30751801, 24.52635956], [86.31056213, 24.51382256], [86.31241608, 24.50847054], [86.30973053, 24.50636292], [86.30349731, 24.49827194], [86.30162811, 24.49353981], [86.29824066, 24.48899841], [86.29773712, 24.48252106], [86.29387665, 24.47643089], [86.28557587, 24.47680283], [86.28183746, 24.47047806], [86.27913666, 24.4620018], [86.30090332, 24.45680046], [86.2988205, 24.45426178], [86.29957581, 24.44898987], [86.30375671, 24.44483948], [86.31555939, 24.4439106], [86.31949615, 24.44016075], [86.33273315, 24.44019127], [86.34781647, 24.44049835], [86.35072327, 24.44371033], [86.35350037, 24.44206047], [86.36271667, 24.42679024], [86.36789703, 24.42424965], [86.37326813, 24.41585159], [86.38123322, 24.4123497], [86.3986969, 24.40028954], [86.40101624, 24.39627075], [86.41558838, 24.37920952], [86.42514801, 24.37811852], [86.43070221, 24.37613106], [86.4341507, 24.37685966], [86.44632721, 24.36844063], [86.45220947, 24.36862946], [86.45504761, 24.37396812], [86.46179962, 24.37672043], [86.46568298, 24.38500023], [86.46711731, 24.39516068], [86.46366882, 24.40775108], [86.46568298, 24.41378975], [86.46367645, 24.4185009], [86.46582794, 24.42188072], [86.4733963, 24.42276192], [86.48207855, 24.42498016], [86.48858643, 24.42500114], [86.48819733, 24.43386078], [86.49194336, 24.43930054], [86.49098969, 24.44695282], [86.49112701, 24.45405006], [86.48448944, 24.45882034], [86.48974609, 24.46760178], [86.48877716, 24.47426987], [86.49080658, 24.47875023], [86.49028015, 24.48437119], [86.49532318, 24.48527908], [86.49812317, 24.48727036], [86.49752808, 24.49797821], [86.50572205, 24.5177002], [86.52352905, 24.53574944], [86.53044891, 24.53293037], [86.53614807, 24.5364399], [86.54057312, 24.53662109], [86.54669189, 24.5350399], [86.5513382, 24.54342079], [86.55792999, 24.54847908], [86.55464172, 24.55927086], [86.55831909, 24.55928993], [86.56170654, 24.56311035], [86.56804657, 24.56279945], [86.57823944, 24.56787109], [86.58315277, 24.57278061], [86.58389282, 24.58531952], [86.58976746, 24.59268951], [86.59485626, 24.59707069], [86.59998322, 24.59949112], [86.60292053, 24.60506821], [86.60929871, 24.60741043], [86.60968018, 24.60252953], [86.60936737, 24.60192108], [86.60791779, 24.59931946], [86.60691833, 24.59435081], [86.61885834, 24.59469986], [86.61828613, 24.58449173], [86.62716675, 24.57962036], [86.63420105, 24.57667923], [86.64126587, 24.57611847], [86.64575958, 24.5672226], [86.65593719, 24.56319809], [86.668396, 24.56064034], [86.67767334, 24.56611252], [86.68151855, 24.5650692], [86.68663788, 24.57044029], [86.69536591, 24.5689106], [86.70990753, 24.57353973], [86.7186203, 24.57821274], [86.73158264, 24.57579994], [86.7350769, 24.58084106], [86.73950958, 24.58649254], [86.74565125, 24.58950043], [86.74459839, 24.60288048], [86.75086212, 24.61797905], [86.75405121, 24.61475945], [86.76912689, 24.61648178], [86.7755127, 24.61557961], [86.77519226, 24.61951065], [86.7771225, 24.61976051], [86.78085327, 24.61483955], [86.78407288, 24.61028099], [86.78647614, 24.60457993], [86.78690338, 24.59937096], [86.79437256, 24.59683037], [86.79429626, 24.60070038], [86.79251099, 24.60518074], [86.79032135, 24.60844994], [86.78736115, 24.61092949], [86.78585052, 24.61309242], [86.78560638, 24.61720085], [86.79184723, 24.61531067], [86.7943573, 24.61209106], [86.79660797, 24.60852051], [86.79749298, 24.60573959], [86.79808807, 24.60346985], [86.79866791, 24.60114288], [86.80018616, 24.59857941], [86.8017807, 24.59745979], [86.8057785, 24.5945015], [86.80446625, 24.59065056], [86.80488586, 24.58538055], [86.80625916, 24.58114052], [86.80761719, 24.57685089], [86.80322266, 24.57435989], [86.80120087, 24.57196808], [86.80033875, 24.56870079], [86.80018616, 24.56592941], [86.80029297, 24.5646019], [86.80499268, 24.56412125], [86.80871582, 24.56377029], [86.81358337, 24.56820107], [86.81825256, 24.56933975], [86.82147217, 24.56831932], [86.82559204, 24.56599998], [86.83152771, 24.56805038], [86.83705139, 24.56828117], [86.83857727, 24.56278038], [86.83869171, 24.55862045], [86.83880615, 24.55406952], [86.84710693, 24.55297089], [86.85463715, 24.55046082], [86.85745239, 24.55661011], [86.86161041, 24.56027031], [86.86949158, 24.56138039], [86.87320709, 24.56497955], [86.87639618, 24.56731987], [86.87909698, 24.56305122], [86.88398743, 24.56035805], [86.88414001, 24.5544796], [86.88672638, 24.55402946], [86.89308929, 24.55483818], [86.89842224, 24.54975128], [86.90117645, 24.54449272], [86.90583038, 24.54097176], [86.91117859, 24.53867912], [86.9071579, 24.54338074], [86.90629578, 24.54926109], [86.90650177, 24.55529976], [86.90644073, 24.55989075], [86.90635681, 24.56336975], [86.90122223, 24.56679916], [86.90322113, 24.57152939], [86.90065765, 24.57615089], [86.89795685, 24.58053017], [86.89807892, 24.58654022], [86.90123749, 24.5915699], [86.90467834, 24.59514046], [86.90895081, 24.59698868], [86.91001892, 24.60114288], [86.91786194, 24.61079025], [86.9189682, 24.61347961], [86.91893768, 24.61940956], [86.92386627, 24.62433052], [86.92926788, 24.62644005], [86.93414307, 24.62652016], [86.93605804, 24.63037109], [86.93344116, 24.63572121], [86.93009186, 24.64282036], [86.93884277, 24.64307022], [86.94861603, 24.64276123], [86.94754791, 24.63586807], [86.94474792, 24.63117027], [86.94550323, 24.62656021], [86.95347595, 24.62765121], [86.95842743, 24.62943077], [86.96556091, 24.63186836], [86.97119141, 24.63030052], [86.9801178, 24.62467003], [86.98549652, 24.62162971], [86.98815155, 24.6201992], [86.99008942, 24.62002945], [86.99014282, 24.62071037], [86.99260712, 24.61918068], [87.0102005, 24.6062603], [87.01291656, 24.60909271], [87.01558685, 24.61330032], [87.01670074, 24.61779976], [87.02144623, 24.61962128], [87.02435303, 24.62109947], [87.02635193, 24.62008286], [87.02646637, 24.61605072], [87.02643585, 24.61123276], [87.02751923, 24.60931969], [87.03011322, 24.60951996], [87.0326004, 24.60989761], [87.03497314, 24.61010933], [87.03592682, 24.61177063], [87.03671265, 24.61325073], [87.03872681, 24.6125412], [87.04086304, 24.61104965], [87.0430069, 24.60893059], [87.04463196, 24.60539818], [87.05046844, 24.60676956], [87.04834747, 24.61014938], [87.04673004, 24.61421013], [87.04670715, 24.61740112], [87.04592133, 24.62017059], [87.04440308, 24.62403107], [87.04580688, 24.63089752], [87.04881287, 24.63701057], [87.05039978, 24.64344025], [87.05101013, 24.64927101], [87.05237579, 24.65551186], [87.05475616, 24.66069031], [87.05532074, 24.66509056], [87.05473328, 24.67060089], [87.05892181, 24.67225075], [87.06017303, 24.67721939], [87.06131744, 24.68152046], [87.06381226, 24.68503952], [87.0670166, 24.68847275], [87.06932831, 24.69124985], [87.07063293, 24.69449997], [87.07087708, 24.69885063], [87.07138062, 24.70313072], [87.07125092, 24.70734978], [87.07264709, 24.7109108], [87.07367706, 24.7125206], [87.07660675, 24.71459961], [87.07772064, 24.71879959], [87.08029175, 24.7219696], [87.08185577, 24.72454071], [87.08235168, 24.72699928], [87.08138275, 24.72925949], [87.08119202, 24.73265076], [87.08132172, 24.73594284], [87.08040619, 24.73698044], [87.07847595, 24.73615074], [87.07704926, 24.73566055], [87.0756073, 24.73641968], [87.07576752, 24.73814964], [87.07636261, 24.7399292], [87.07398987, 24.74054909], [87.07359314, 24.7430706], [87.07454681, 24.74472046], [87.07646179, 24.74549103], [87.07982635, 24.74658966], [87.08161163, 24.74834061], [87.08120728, 24.75075912], [87.08097076, 24.75168991], [87.08309174, 24.7536602], [87.08508301, 24.75580978], [87.08631134, 24.75831985], [87.08486938, 24.7614994], [87.08339691, 24.76452065], [87.08254242, 24.76798248], [87.08254242, 24.7729702], [87.0828476, 24.77922821], [87.08560181, 24.7824707], [87.08804321, 24.78523827], [87.0912323, 24.78811073], [87.09288025, 24.79229164], [87.09568024, 24.79759979], [87.09667206, 24.80149269], [87.09660339, 24.80402756], [87.09395599, 24.80441093], [87.09072876, 24.80266953], [87.08886719, 24.8040905], [87.0863266, 24.80591011], [87.08345032, 24.80658913], [87.08138275, 24.80738068], [87.08078003, 24.80951118], [87.07730103, 24.80834961], [87.07713318, 24.81182098], [87.0776062, 24.81422043], [87.07730103, 24.81814194], [87.0785675, 24.82225037], [87.08036041, 24.8243618], [87.08423615, 24.82322121], [87.0877533, 24.82304192], [87.09121704, 24.82356071], [87.0949707, 24.82620049], [87.09754944, 24.82985115], [87.0996933, 24.83476067], [87.10240936, 24.83925819], [87.10462189, 24.84445953], [87.10604858, 24.84733009], [87.10949707, 24.85078812], [87.11447144, 24.85552979], [87.11915588, 24.85396957], [87.12333679, 24.8529911], [87.12731934, 24.85448265], [87.12980652, 24.85749054], [87.13273621, 24.85957909], [87.13881683, 24.85926056], [87.14451599, 24.8592205], [87.15097809, 24.85843086], [87.15168762, 24.86308098], [87.14733887, 24.86240768], [87.14792633, 24.86786842], [87.14964294, 24.87240028], [87.15453339, 24.87647057], [87.15653992, 24.88070107], [87.1581192, 24.88563156], [87.15822601, 24.88955116], [87.15695953, 24.89608955], [87.15432739, 24.90011024], [87.15023041, 24.90316963], [87.14877319, 24.90509033], [87.14774323, 24.9081707], [87.14650726, 24.91286278], [87.14762878, 24.9178009], [87.14971161, 24.92122269], [87.15268707, 24.9239502], [87.15461731, 24.92651749], [87.15531158, 24.93168068], [87.15213013, 24.93653107], [87.14859009, 24.9421196], [87.14877319, 24.94938087], [87.15075684, 24.95574951], [87.15258026, 24.96299934], [87.1519165, 24.96861267], [87.15203094, 24.97443962], [87.15299225, 24.9831295], [87.15368652, 24.99097061], [87.14647675, 24.9998703], [87.14597321, 25.00355911], [87.1444931, 25.00642967], [87.14388275, 25.01078987], [87.14420319, 25.01797104], [87.14676666, 25.02431107], [87.14904785, 25.0262394], [87.15232086, 25.02651978], [87.15834045, 25.03100014], [87.1649704, 25.04281998], [87.16503906, 25.04586983], [87.16847992, 25.0489502], [87.17325592, 25.05647087], [87.17384338, 25.05800247], [87.17664337, 25.06402016], [87.18431854, 25.06701088], [87.18776703, 25.06699944], [87.19747162, 25.07365036], [87.19986725, 25.07944107], [87.20832062, 25.08332062], [87.21071625, 25.08525085], [87.21135712, 25.08959961], [87.21563721, 25.09019089], [87.21795654, 25.08854294], [87.22708893, 25.08757019], [87.23387909, 25.08582115], [87.23986053, 25.0994606], [87.24106598, 25.10079956], [87.24533081, 25.09908104], [87.24923706, 25.1053791], [87.25055695, 25.10585022], [87.25875092, 25.10461044], [87.26307678, 25.10082054], [87.26444244, 25.09777832], [87.27024841, 25.09363937], [87.27488708, 25.09218979], [87.28560638, 25.09091949], [87.29110718, 25.08926964], [87.29535675, 25.09970093], [87.29280853, 25.10469055], [87.29486847, 25.1119194], [87.2948761, 25.11381912], [87.2932663, 25.11435127], [87.2979126, 25.13466072], [87.29988098, 25.13459015], [87.30342865, 25.13814163], [87.30239105, 25.14059067], [87.30343628, 25.14320946], [87.30171967, 25.14389992], [87.30229187, 25.14532089], [87.30797577, 25.15029144], [87.30963898, 25.1535511], [87.31041718, 25.16032982], [87.3143692, 25.16275978], [87.31503296, 25.16504097], [87.31437683, 25.16736984], [87.31301117, 25.16926003], [87.31064606, 25.16982079], [87.31601715, 25.18630028], [87.31711578, 25.18868065], [87.31574249, 25.19298935], [87.315979, 25.19695091], [87.31833649, 25.20124054], [87.32345581, 25.22309113], [87.33053589, 25.22219086], [87.33045197, 25.21706963], [87.34777832, 25.21317291], [87.35507965, 25.21340942], [87.35801697, 25.21121979], [87.36846161, 25.20689964], [87.36988831, 25.20504951], [87.37394714, 25.21853065], [87.37713623, 25.2226181], [87.38330078, 25.22347069], [87.38648224, 25.22570992], [87.39177704, 25.22751808], [87.3966217, 25.22571945], [87.40215302, 25.22141075], [87.40764618, 25.2190094], [87.40949249, 25.21513939], [87.41660309, 25.21491051], [87.45511627, 25.19750023], [87.45783234, 25.19779968], [87.46192932, 25.19515038], [87.46685791, 25.1956501], [87.46763611, 25.19314194], [87.47216034, 25.19466972], [87.47181702, 25.22237968], [87.47305298, 25.23143005], [87.47264099, 25.24088287], [87.48755646, 25.26199913], [87.49484253, 25.25969124], [87.49571991, 25.26247978], [87.49559021, 25.26530075], [87.49195862, 25.27143097], [87.49447632, 25.27543068], [87.48757935, 25.27761078], [87.48150635, 25.29517174], [87.48638153, 25.2960701], [87.49006653, 25.30520058], [87.49887085, 25.29228973], [87.51287079, 25.29214287], [87.52552032, 25.28098106], [87.52942657, 25.27961922], [87.53562927, 25.28010941], [87.53974915, 25.28161812], [87.53849792, 25.29623032], [87.54112244, 25.30425072], [87.54412079, 25.32290077], [87.54680634, 25.32365036], [87.5474472, 25.33094025], [87.56710815, 25.33389091], [87.57144165, 25.34050941], [87.57948303, 25.3439312], [87.57891846, 25.34678268], [87.5800705, 25.34839058], [87.58766174, 25.34054756], [87.58046722, 25.33232117], [87.5811615, 25.32803917], [87.5892868, 25.3237896], [87.58925629, 25.32188988], [87.59989166, 25.31466293], [87.60688019, 25.31138039], [87.61361694, 25.31553841], [87.62267303, 25.31080055], [87.6262207, 25.3157196], [87.62597656, 25.31861115], [87.63179016, 25.31186104], [87.6340332, 25.31235123], [87.6517868, 25.30724907], [87.65878296, 25.30973053], [87.6841507, 25.31013107], [87.68409729, 25.30805016], [87.68087006, 25.30767059], [87.6806488, 25.30427933], [87.68824005, 25.30476952], [87.6934967, 25.3030529], [87.69140625, 25.29860115], [87.69478607, 25.29541016], [87.69030762, 25.29121971], [87.68907166, 25.28494072], [87.69130707, 25.28139114], [87.69641113, 25.27886963], [87.70096588, 25.2777729], [87.70591736, 25.27457047], [87.70796967, 25.2713604], [87.70687103, 25.25978088], [87.70778656, 25.25640869], [87.72106171, 25.25344086], [87.73087311, 25.25315094], [87.76283264, 25.24928856], [87.76911926, 25.24665833], [87.78330994, 25.24617767], [87.78367615, 25.24299049], [87.78520203, 25.24045944], [87.78544617, 25.23631287], [87.78753662, 25.22862053], [87.7875824, 25.2204895], [87.78518677, 25.20907974], [87.78466797, 25.19960022], [87.7804718, 25.18527031], [87.77900696, 25.17692947], [87.77275085, 25.15961838], [87.77104187, 25.15227127], [87.77120972, 25.138731], [87.76928711, 25.12700081], [87.76983643, 25.11470985], [87.77266693, 25.09909821], [87.7765274, 25.09127045], [87.77986145, 25.08735085], [87.7928772, 25.07573128], [87.79989624, 25.07123947], [87.8201828, 25.06150055], [87.83493805, 25.05701828], [87.84262085, 25.05220032], [87.8550415, 25.04623985], [87.86434174, 25.03985023], [87.87697601, 25.02803993], [87.88117981, 25.02150917], [87.88082123, 25.02053833], [87.89292145, 25.00894928], [87.90242004, 24.99945068], [87.90336609, 24.99839973], [87.90648651, 24.98581123], [87.91352844, 24.97890282], [87.91851044, 24.9728508], [87.92444611, 24.96718025], [87.930336, 24.96179962], [87.93904877, 24.95573044], [87.94621277, 24.94889069], [87.9502182, 24.94534111], [87.95627594, 24.94141006], [87.96169281, 24.93593025], [87.9664917, 24.92959976], [87.9699707, 24.92358017], [87.97041321, 24.91607094], [87.97123718, 24.91003036], [87.97228241, 24.9033699], [87.9733429, 24.89648247], [87.97220612, 24.89142036], [87.96936798, 24.88512039], [87.96650696, 24.88129997], [87.96124268, 24.87905121], [87.9523468, 24.87685966], [87.94464111, 24.87267113], [87.93644714, 24.86961174], [87.92874146, 24.86588287], [87.92154694, 24.86024094], [87.91124725, 24.85593987], [87.89701843, 24.85435295], [87.88897705, 24.85293961], [87.89135742, 24.84815979], [87.89466858, 24.84775925], [87.89776611, 24.84278107], [87.89724731, 24.84174919], [87.89569092, 24.83959007], [87.8949585, 24.83389282], [87.89391327, 24.82917023], [87.89591217, 24.82756996], [87.89842224, 24.82452965], [87.8961792, 24.82259941], [87.89070892, 24.82287979], [87.88655853, 24.81966019], [87.88170624, 24.8203907], [87.87471771, 24.82271957], [87.86924744, 24.8234005], [87.86766815, 24.82298279], [87.86631012, 24.82074928], [87.8681488, 24.81811905], [87.87029266, 24.81524277], [87.87210846, 24.81186295], [87.87271881, 24.8075695], [87.87284851, 24.8052597], [87.87583923, 24.80311012], [87.87760925, 24.80101013], [87.87751007, 24.79800034], [87.87666321, 24.79368973], [87.87475586, 24.78980064], [87.87291718, 24.78977013], [87.87233734, 24.79193115], [87.87005615, 24.79087067], [87.86810303, 24.7870903], [87.86654663, 24.78244972], [87.86486053, 24.7785511], [87.86650848, 24.77614975], [87.86538696, 24.7743206], [87.85999298, 24.77200127], [87.8584671, 24.76781082], [87.85453796, 24.76431084], [87.85022736, 24.76127052], [87.84677887, 24.7610302], [87.84246826, 24.76285934], [87.83885956, 24.76536179], [87.83524323, 24.76323128], [87.83376312, 24.7658596], [87.83378601, 24.76968002], [87.833992, 24.77464104], [87.83687592, 24.77734947], [87.83899689, 24.78014183], [87.83847046, 24.78470993], [87.83753204, 24.78780174], [87.83368683, 24.78786087], [87.83001709, 24.78297043], [87.82836914, 24.77670288], [87.82785034, 24.77192116], [87.82565308, 24.76931], [87.82209015, 24.76671982], [87.81806183, 24.76598167], [87.81603241, 24.75960922], [87.81389618, 24.75336075], [87.81607819, 24.75204086], [87.82050323, 24.75206947], [87.82533264, 24.75221062], [87.83970642, 24.7381897], [87.85234833, 24.73493958], [87.86103821, 24.73125076], [87.86738586, 24.72940063], [87.87088013, 24.73002815], [87.87493896, 24.73508835], [87.8777771, 24.73908043], [87.88244629, 24.73627281], [87.88423157, 24.73347092], [87.88545227, 24.72929955], [87.8871994, 24.72544289], [87.89077759, 24.72258949], [87.89565277, 24.72302055], [87.90083313, 24.72159958], [87.90215302, 24.71849823], [87.9033432, 24.71455956], [87.90313721, 24.71190071], [87.90291595, 24.70993805], [87.90091705, 24.71050262], [87.89884949, 24.7098999], [87.89750671, 24.70647049], [87.8961792, 24.7024498], [87.8990097, 24.69968033], [87.897789, 24.69497108], [87.89656067, 24.69066048], [87.89274597, 24.68574905], [87.88941193, 24.68177986], [87.88625336, 24.67808914], [87.88661957, 24.67410278], [87.89038086, 24.67033005], [87.89507294, 24.66850281], [87.89990997, 24.6693306], [87.90319824, 24.66695976], [87.90647888, 24.66436005], [87.91159821, 24.66229057], [87.91340637, 24.6585598], [87.91013336, 24.65493011], [87.90886688, 24.65130997], [87.90785217, 24.64682961], [87.90796661, 24.64208984], [87.9076767, 24.63678169], [87.90629578, 24.63264275], [87.90428925, 24.63042068], [87.90200806, 24.62943077], [87.90000153, 24.62942123], [87.8968811, 24.6303997], [87.89227295, 24.63204956], [87.88886261, 24.63142014], [87.8868103, 24.62949944], [87.88461304, 24.62664986], [87.887146, 24.62446976], [87.89177704, 24.62368011], [87.89539337, 24.62449265], [87.89885712, 24.62574005], [87.90225983, 24.62592125], [87.90180206, 24.62257004], [87.90139008, 24.62002945], [87.90213013, 24.61650085], [87.90161133, 24.61258125], [87.89948273, 24.6114006], [87.89631653, 24.61186981], [87.89383698, 24.61296272], [87.89118195, 24.61219978], [87.88828278, 24.61133003], [87.88552094, 24.61178017], [87.88215637, 24.61359024], [87.87911224, 24.61475182], [87.87700653, 24.61629105], [87.87483215, 24.61552048], [87.87346649, 24.61347008], [87.8727417, 24.61071968], [87.87354279, 24.60931969], [87.87528992, 24.60990906], [87.87596893, 24.60885811], [87.87799835, 24.60944939], [87.88118744, 24.60696983], [87.88613129, 24.60514069], [87.88802338, 24.60532951], [87.88871002, 24.60820961], [87.89348602, 24.60834122], [87.8986969, 24.60807037], [87.90290833, 24.60804176], [87.9081192, 24.60817909], [87.90773773, 24.60436821], [87.90762329, 24.59939766], [87.90912628, 24.5963726], [87.90997314, 24.59386826], [87.90873718, 24.5911808], [87.90683746, 24.58735085], [87.90544891, 24.58380127], [87.90326691, 24.58238983], [87.89940643, 24.58357048], [87.89737701, 24.58245087], [87.89608765, 24.58062172], [87.89148712, 24.57962036], [87.89025879, 24.57472992], [87.88989258, 24.57191086], [87.88732147, 24.56270981], [87.8807373, 24.56295967], [87.87661743, 24.56108284], [87.86863708, 24.5612812], [87.86585999, 24.56083107], [87.86443329, 24.55870819], [87.86389923, 24.55657959], [87.860466, 24.55526161], [87.85632324, 24.55459023], [87.85378265, 24.55603027], [87.85047913, 24.55783272], [87.84921265, 24.5569191], [87.84996033, 24.5537281], [87.8482132, 24.55105019], [87.84497833, 24.55278015], [87.84111023, 24.55441093], [87.83480072, 24.55632973], [87.82698822, 24.55816078], [87.82450867, 24.55948257], [87.82388306, 24.56335258], [87.82327271, 24.56655121], [87.82015228, 24.5683918], [87.81685638, 24.57007027], [87.81420898, 24.57261276], [87.81166077, 24.57444], [87.80899811, 24.576231], [87.80500793, 24.57752037], [87.80224609, 24.57802963], [87.79889679, 24.57781029], [87.79505157, 24.57966995], [87.79067993, 24.58107948], [87.78536224, 24.5823307], [87.77966309, 24.58209038], [87.76940918, 24.58176041], [87.76792145, 24.57602119], [87.76757813, 24.57156944], [87.77317047, 24.57188034], [87.77774811, 24.57138062], [87.78572845, 24.56858063], [87.79158783, 24.56568909], [87.7961731, 24.56238174], [87.79936981, 24.55890083], [87.80261993, 24.55428123], [87.8048172, 24.54922104], [87.80634308, 24.54520035], [87.8057785, 24.54244041], [87.8035965, 24.54010963], [87.79985046, 24.54116058], [87.79749298, 24.53866959], [87.79798126, 24.53535843], [87.79712677, 24.53001022], [87.79756927, 24.52462959], [87.79901886, 24.52091026], [87.80121613, 24.51769066], [87.80116272, 24.51463127], [87.79972076, 24.51172066], [87.79850006, 24.50942993], [87.79850769, 24.50699997], [87.79994202, 24.50424957], [87.79823303, 24.50242996], [87.7939682, 24.50032043], [87.79260254, 24.49722862], [87.79380035, 24.49426079], [87.79515076, 24.49105072], [87.79853058, 24.49185944], [87.80101776, 24.49481964], [87.80298615, 24.49864006], [87.80342865, 24.50164032], [87.80374146, 24.50476074], [87.80391693, 24.50723076], [87.80526733, 24.50963974], [87.80667114, 24.51060104], [87.80758667, 24.5093708], [87.80734253, 24.50619125], [87.80831146, 24.50456047], [87.81021881, 24.50204086], [87.81178284, 24.49900055], [87.81111145, 24.49641991], [87.81001282, 24.49452972], [87.81021118, 24.49209023], [87.81225586, 24.4915905], [87.81555939, 24.4928093], [87.81867981, 24.49205971], [87.82022095, 24.49347115], [87.8197403, 24.49591064], [87.82190704, 24.49644089], [87.82287598, 24.49440956], [87.82244873, 24.49234009], [87.82145691, 24.49008942], [87.82099152, 24.48843002], [87.82025909, 24.48584938], [87.81685638, 24.48608017], [87.8130188, 24.48512077], [87.81035614, 24.48037148], [87.80909729, 24.47659111], [87.81138611, 24.47480965], [87.8137207, 24.47274017], [87.81478882, 24.47006035], [87.81784821, 24.46845055], [87.81659698, 24.46547127], [87.81772614, 24.46232033], [87.81735992, 24.4589901], [87.81614685, 24.45531273], [87.81524658, 24.45359993], [87.81494904, 24.45134926], [87.81125641, 24.4518795], [87.80687714, 24.45259857], [87.80251312, 24.45014], [87.80094147, 24.4473896], [87.79972076, 24.44544983], [87.79988098, 24.44371986], [87.79688263, 24.44186974], [87.79595184, 24.43939972], [87.79290009, 24.43980026], [87.79103851, 24.4377594], [87.78978729, 24.43465996], [87.7881012, 24.43209267], [87.79038239, 24.42939949], [87.79226685, 24.42687035], [87.79220581, 24.4238205], [87.79003143, 24.42167091], [87.78620911, 24.41862106], [87.78475189, 24.41454124], [87.78790283, 24.41152954], [87.79297638, 24.41063118], [87.79862976, 24.41122246], [87.80134583, 24.41341972], [87.80522156, 24.41814041], [87.80639648, 24.41472054], [87.80847931, 24.41213036], [87.80899048, 24.40923119], [87.81002045, 24.40662003], [87.80745697, 24.40435982], [87.80425262, 24.40354919], [87.8015213, 24.40192032], [87.79821014, 24.39973068], [87.79476929, 24.40007973], [87.79257965, 24.39644051], [87.79263306, 24.3930912], [87.79469299, 24.39217949], [87.7973175, 24.39229965], [87.79811096, 24.3907795], [87.7975769, 24.38606071], [87.79750824, 24.38218117], [87.79376984, 24.38076019], [87.78994751, 24.37701035], [87.78765106, 24.37166977], [87.78494263, 24.36763191], [87.78235626, 24.3602314], [87.77922821, 24.35705948], [87.77658844, 24.35341072], [87.77262878, 24.34938049], [87.76941681, 24.34539986], [87.7678833, 24.34045982], [87.76451874, 24.3385601], [87.7612381, 24.33331108], [87.76055908, 24.32817078], [87.76420593, 24.32522011], [87.76448059, 24.32279015], [87.76248169, 24.32068062], [87.76007843, 24.31952095], [87.75946045, 24.31688118], [87.76035309, 24.31303978], [87.75849915, 24.30783081], [87.75627899, 24.30359268], [87.75209808, 24.30465126], [87.74819946, 24.30148125], [87.7457428, 24.29980278], [87.74312592, 24.29772186], [87.74046326, 24.29272842], [87.73620605, 24.29199982], [87.73638153, 24.28894043], [87.73304749, 24.28791046], [87.73015594, 24.2876091], [87.72718811, 24.28622055], [87.72395325, 24.28749275], [87.71977234, 24.28803062], [87.71573639, 24.29001045], [87.71031952, 24.29207039], [87.71008301, 24.28657913], [87.7094574, 24.28290939], [87.70833588, 24.28038979], [87.70617676, 24.2781105], [87.70461273, 24.2745018], [87.70543671, 24.27170944], [87.70598602, 24.2678299], [87.70452881, 24.26375961], [87.70263672, 24.25992012], [87.69740295, 24.25972939], [87.69301605, 24.25739098], [87.6886673, 24.25560951], [87.68496704, 24.25284958], [87.68309784, 24.24855042], [87.68135834, 24.24644089], [87.67791748, 24.24645233], [87.67384338, 24.24670029], [87.67067719, 24.24427986], [87.66876984, 24.24274063], [87.6654129, 24.24349022], [87.66190338, 24.24495125], [87.66028595, 24.2419796], [87.6590271, 24.23835754], [87.65703583, 24.23539925], [87.65429688, 24.23658943], [87.6519165, 24.24015045], [87.64985657, 24.24365997], [87.64929962, 24.24662018], [87.64714813, 24.24855995], [87.64173126, 24.24986076], [87.64002991, 24.24603081], [87.63571167, 24.24253082], [87.63658142, 24.23818016], [87.63951874, 24.23472023], [87.643013, 24.23010063], [87.64315796, 24.22459984], [87.64151001, 24.21960068], [87.63844299, 24.21614075], [87.63772583, 24.21158028], [87.64509583, 24.20799065], [87.65278625, 24.20618248], [87.65901947, 24.20740128], [87.6661377, 24.20611191], [87.67095184, 24.20573807], [87.67378998, 24.20049095], [87.67460632, 24.1952095], [87.67830658, 24.19111061], [87.68353271, 24.18905258], [87.68891144, 24.18514061], [87.69255829, 24.18618011], [87.69399261, 24.18197823], [87.69378662, 24.1784687], [87.69667816, 24.17534828], [87.69641113, 24.17131042], [87.69645691, 24.16721153], [87.6932373, 24.16434097], [87.69364166, 24.15917015], [87.69248199, 24.15447044], [87.68956757, 24.1498394], [87.68435669, 24.14916992], [87.68016815, 24.14797974], [87.67353058, 24.15134048], [87.66777802, 24.15143967], [87.66361237, 24.15427971], [87.6569519, 24.15591049], [87.65054321, 24.15452957], [87.6457901, 24.15379906], [87.64067078, 24.15493011], [87.63632965, 24.15738106], [87.63162994, 24.16028976], [87.62754059, 24.16313171], [87.62166595, 24.16386986], [87.61605835, 24.1646595], [87.6104126, 24.16488075], [87.60415649, 24.16399956], [87.59957886, 24.16050911], [87.5955658, 24.15980911], [87.59037781, 24.1600914], [87.58407593, 24.16146088], [87.57975006, 24.16153908], [87.5766983, 24.15888023], [87.56938171, 24.15565109], [87.57142639, 24.15440941], [87.57646942, 24.15275955], [87.58087158, 24.15044022], [87.58602142, 24.14752007], [87.59004211, 24.14410019], [87.59391785, 24.14147949], [87.59794617, 24.1379509], [87.60119629, 24.13517952], [87.6049118, 24.1321106], [87.60761261, 24.12894249], [87.60481262, 24.12656975], [87.60041046, 24.12537003], [87.59541321, 24.12487984], [87.59262085, 24.12424088], [87.58172607, 24.12339973], [87.57952118, 24.11951065], [87.57965088, 24.11501122], [87.57779694, 24.11042023], [87.5748291, 24.1089592], [87.57211304, 24.10971069], [87.5692215, 24.10675049], [87.56949615, 24.10098076], [87.57064819, 24.09547043], [87.5743103, 24.09015083], [87.57644653, 24.08710098], [87.57615662, 24.08526039], [87.57316589, 24.0862999], [87.57021332, 24.08762169], [87.56672668, 24.08641052], [87.56344604, 24.08450127], [87.5597229, 24.08288956], [87.55628204, 24.08230972], [87.55261993, 24.0845108], [87.54825592, 24.08546066], [87.54419708, 24.0865612], [87.53916931, 24.08780098], [87.53449249, 24.09140968], [87.53096771, 24.09486961], [87.53069305, 24.09921074], [87.52986145, 24.10240936], [87.52693939, 24.10378075], [87.52406311, 24.10370827], [87.52130127, 24.10423088], [87.51991272, 24.1058712], [87.51889038, 24.10872078], [87.516922, 24.11100006], [87.51367188, 24.11082077], [87.51052856, 24.1103611], [87.50717926, 24.11128044], [87.50293732, 24.1128006], [87.49951172, 24.11458015], [87.49659729, 24.11580086], [87.49359894, 24.11520958], [87.49310303, 24.11193085], [87.49384308, 24.10815048], [87.49536896, 24.10547066], [87.49656677, 24.1026783], [87.49694824, 24.0993309], [87.49584961, 24.0971508], [87.49365234, 24.09724045], [87.49281311, 24.09547043], [87.49353027, 24.09309006], [87.48964691, 24.09004021], [87.48892212, 24.08819962], [87.49001312, 24.08546829], [87.49324036, 24.08460045], [87.4980011, 24.08435059], [87.50216675, 24.0832901], [87.50578308, 24.08208084], [87.50535583, 24.07942963], [87.50357056, 24.07766914], [87.50260162, 24.07526016], [87.50123596, 24.07331848], [87.49978638, 24.07254028], [87.49685669, 24.07369041], [87.49318695, 24.07473946], [87.48973083, 24.07323074], [87.48890686, 24.06966019], [87.49075317, 24.06657028], [87.49252319, 24.06470108], [87.49423218, 24.06265068], [87.49331665, 24.05924988], [87.49185181, 24.05553055], [87.4912262, 24.05202103], [87.49539185, 24.04997063], [87.50137329, 24.04751015], [87.5042572, 24.04618263], [87.50784302, 24.04566956], [87.50845337, 24.0425396], [87.51055145, 24.03983116], [87.5090332, 24.03467941], [87.50670624, 24.03199959], [87.50393677, 24.03009033], [87.50196075, 24.02815056], [87.50131226, 24.02609062], [87.5013504, 24.02232933], [87.49649048, 24.02316093], [87.49476624, 24.02435112], [87.4912262, 24.02337074], [87.48847961, 24.01933098], [87.48642731, 24.01595116], [87.48275757, 24.0136528], [87.47915649, 24.0141201], [87.47619629, 24.01301193], [87.47345734, 24.01143265], [87.4713974, 24.01089096], [87.46924591, 24.01156235], [87.46733856, 24.01217842], [87.46393585, 24.01262093], [87.46209717, 24.01311111], [87.45926666, 24.01297951], [87.45691681, 24.01406288], [87.45490265, 24.01496124], [87.45226288, 24.01506042], [87.44851685, 24.01634026], [87.44625092, 24.01428986], [87.44316101, 24.01375961], [87.43872833, 24.01251984], [87.43650055, 24.01094246], [87.43383026, 24.00832176], [87.43464661, 24.00686073], [87.43678284, 24.00781059], [87.43844604, 24.00904083], [87.44087219, 24.00946045], [87.44423676, 24.00909996], [87.44676971, 24.00835037], [87.44610596, 24.00696945], [87.44487762, 24.00576019], [87.44246674, 24.00530052], [87.44139862, 24.00323105], [87.44330597, 24.00094032], [87.44676971, 24.00062943], [87.45018768, 23.99999046], [87.45067596, 23.99924088], [87.45487976, 23.99689102], [87.45835876, 23.99349976], [87.45980072, 23.98483276], [87.45796967, 23.98142052], [87.45359802, 23.98339081], [87.44898224, 23.98429108], [87.44547272, 23.98146057], [87.43910217, 23.97813034], [87.43656158, 23.97915077], [87.43398285, 23.98168945], [87.4292984, 23.98186111], [87.42758942, 23.98397064], [87.42735291, 23.98792839], [87.42637634, 23.99032021], [87.42212677, 23.99080086], [87.4185791, 23.98935127], [87.41452789, 23.99084282], [87.4003067, 23.99392128], [87.39427185, 23.99653053], [87.39389038, 23.99924088], [87.38976288, 24.00196266], [87.38234711, 24.00270081], [87.37687683, 24.00317001], [87.37400818, 24.00657845], [87.36479187, 24.00677109], [87.36038971, 24.00734138], [87.35663605, 24.00918961], [87.35484314, 24.00559807], [87.35334778, 24.00225067], [87.35098267, 23.99920273], [87.3502121, 23.99697113], [87.34810638, 23.99579048], [87.3372879, 23.99495125], [87.32787323, 23.99599075], [87.32395935, 23.99706268], [87.31989288, 23.99917984], [87.31788635, 24.00152016], [87.31539154, 24.00442123], [87.31581116, 24.00708961], [87.31828308, 24.00687027], [87.32054138, 24.00927925], [87.32225037, 24.01316261], [87.32417297, 24.01748085], [87.32743073, 24.01662064], [87.3323288, 24.01753998], [87.33319092, 24.0222702], [87.33550262, 24.02386284], [87.33235931, 24.03100967], [87.32628632, 24.03013039], [87.31997681, 24.03144073], [87.31373596, 24.03239059], [87.30877686, 24.0319519], [87.30368042, 24.02937126], [87.29654694, 24.03016281], [87.28956604, 24.03030968], [87.28621674, 24.02717972], [87.28264618, 24.02692986], [87.27915955, 24.02935982], [87.27427673, 24.03184128], [87.26918793, 24.03301048], [87.26387024, 24.03469086], [87.2578125, 24.0354805], [87.25345612, 24.03734016], [87.2490387, 24.04012108], [87.24359894, 24.04211998], [87.23797607, 24.04121971], [87.23480225, 24.03731918], [87.23348236, 24.03268814], [87.23265076, 24.02459908], [87.23536682, 24.01754951], [87.23922729, 24.01478004], [87.24034882, 24.01066017], [87.24059296, 24.00572014], [87.24356842, 24.00101089], [87.24539948, 23.99855042], [87.24581146, 23.99802017], [87.24616241, 23.99765015], [87.24687195, 23.99702072], [87.24727631, 23.99677086], [87.24769592, 23.99653053], [87.24816132, 23.99632072], [87.24862671, 23.99612999], [87.24909973, 23.99599075], [87.24960327, 23.99587059], [87.25009918, 23.99578094], [87.25060272, 23.99572754], [87.251091, 23.99571037], [87.25157928, 23.99572754], [87.25208282, 23.99578094], [87.25260162, 23.99587059], [87.25311279, 23.99599075], [87.25363159, 23.99614906], [87.25408936, 23.99636078], [87.2545166, 23.99661064], [87.25493622, 23.99689102], [87.25531006, 23.99716949], [87.25565338, 23.99751091], [87.25595856, 23.99788094], [87.25621033, 23.99827003], [87.25640869, 23.99909019], [87.25718689, 23.99978065], [87.26081848, 24.00290108], [87.26271057, 23.99912071], [87.26206207, 23.99509048], [87.26692963, 23.98777962], [87.26802826, 23.98463058], [87.26602173, 23.9818306], [87.26072693, 23.97809029], [87.25953674, 23.96992111], [87.26154327, 23.96616936], [87.26452637, 23.9634819], [87.26925659, 23.96532059], [87.27805328, 23.95755959], [87.28666687, 23.95749092], [87.29181671, 23.95569992], [87.2904892, 23.94745255], [87.29193115, 23.93875122], [87.28513336, 23.93388939], [87.28782654, 23.9259491], [87.28768921, 23.92023087], [87.29454803, 23.89857101], [87.2906723, 23.89870071], [87.29258728, 23.89014053], [87.28552246, 23.88361168], [87.28129578, 23.88420105], [87.27832031, 23.88194847], [87.27041626, 23.87294006], [87.26493073, 23.87482834], [87.26174927, 23.87817192], [87.26412964, 23.87997055], [87.26088715, 23.89217949], [87.25630951, 23.89814949], [87.25987244, 23.90211105], [87.25920105, 23.90420151], [87.25666046, 23.90759277], [87.25242615, 23.91011047], [87.24822235, 23.90701103], [87.2443161, 23.90039063], [87.24608612, 23.89493942], [87.24311066, 23.8848629], [87.24530029, 23.88060951], [87.24442291, 23.87807846], [87.24487305, 23.86840057], [87.24904633, 23.86582947], [87.24608612, 23.85658073], [87.24742889, 23.85131073], [87.25152588, 23.84766006], [87.25270081, 23.84286118], [87.25521851, 23.83930016], [87.24572754, 23.82807159], [87.24272919, 23.82616043], [87.23880005, 23.82485008], [87.23375702, 23.82534981], [87.22912598, 23.82300949], [87.21975708, 23.82720947], [87.21855927, 23.83080101], [87.22235107, 23.83483124], [87.22410583, 23.84268951], [87.22796631, 23.84290123], [87.23174286, 23.84456062], [87.23513794, 23.84824181], [87.23623657, 23.85306931], [87.22782898, 23.85530281], [87.22248077, 23.85763931], [87.21675873, 23.85094261], [87.21282196, 23.85027122], [87.2073288, 23.85301018], [87.20302582, 23.84617233], [87.19944763, 23.84749985], [87.19433594, 23.84212112], [87.19164276, 23.84044266], [87.18856812, 23.84083748], [87.18869781, 23.84631157], [87.19541931, 23.8508606], [87.19565582, 23.85425949], [87.18736267, 23.85717964], [87.18427277, 23.852911], [87.18060303, 23.85153008], [87.17662048, 23.85246277], [87.17295074, 23.85622025], [87.16911316, 23.8577919], [87.16668701, 23.8604908], [87.1566925, 23.86488914], [87.1529007, 23.86559105], [87.14750671, 23.86268234], [87.14076996, 23.86510086], [87.13860321, 23.86740112], [87.13581848, 23.86813927], [87.13092804, 23.86696053], [87.12786102, 23.86244011], [87.12963104, 23.8581295], [87.12944031, 23.85490036], [87.13033295, 23.85091019], [87.13772583, 23.84580994], [87.14581299, 23.83661079], [87.15399933, 23.82574081], [87.15912628, 23.82830048], [87.16220856, 23.82761955], [87.16644287, 23.81958961], [87.15592957, 23.80372047], [87.15364838, 23.79845047], [87.14874268, 23.79437065], [87.14354706, 23.79636192], [87.13920593, 23.80006027], [87.13362885, 23.79634094], [87.12416077, 23.79503822], [87.11299896, 23.79681015], [87.11025238, 23.79906273], [87.1146698, 23.80008125], [87.11633301, 23.80196953], [87.1160965, 23.80480194], [87.11258698, 23.80553818], [87.10771179, 23.80187035], [87.10592651, 23.79952049], [87.09572601, 23.80948067], [87.09130096, 23.80961037], [87.08840179, 23.80780983], [87.0845108, 23.80526924], [87.07660675, 23.80911064], [87.07276917, 23.81233978], [87.06423187, 23.81349945], [87.0569458, 23.81625938], [87.03440857, 23.83682823], [87.02243042, 23.84052277], [87.01345825, 23.8469429], [87.00205994, 23.85248947], [86.99455261, 23.85353088], [86.98013306, 23.85638046], [86.97187805, 23.86283112], [86.96691132, 23.86529922], [86.96304321, 23.8647728], [86.95957184, 23.86231041], [86.95771027, 23.85913086], [86.95575714, 23.84961128], [86.95123291, 23.84587097], [86.94319916, 23.84286118], [86.93637848, 23.84486008], [86.92813873, 23.84995842], [86.92540741, 23.85384178], [86.92415619, 23.86588097], [86.90688324, 23.87951088], [86.90365601, 23.8789711], [86.8950119, 23.87995148], [86.89138031, 23.87639046], [86.88461304, 23.87335014], [86.88008881, 23.86650085], [86.87526703, 23.86238098], [86.8753891, 23.85745049], [86.88226318, 23.85661125], [86.88017273, 23.84220123], [86.88478851, 23.83436966], [86.88474274, 23.83049011], [86.88690948, 23.82732964], [86.88768768, 23.82216072], [86.88437653, 23.81920052], [86.88226318, 23.81447983], [86.87693024, 23.81344986], [86.87693024, 23.82133102], [86.87329102, 23.82723045], [86.87309265, 23.83448029], [86.87121582, 23.84418106], [86.86084747, 23.84217262], [86.85704803, 23.83950043], [86.8544693, 23.83247757], [86.84442902, 23.82185173], [86.83500671, 23.81925964], [86.82591248, 23.81319809], [86.82077026, 23.81130981], [86.813797, 23.81216049], [86.80930328, 23.81413078], [86.80702209, 23.81814957], [86.80786896, 23.82455254], [86.80647278, 23.8281002], [86.80367279, 23.83068085], [86.80018616, 23.83263016], [86.79738617, 23.83186913], [86.79283905, 23.83138084], [86.79220581, 23.82726288], [86.79747009, 23.82403946], [86.80097198, 23.8133297], [86.79769135, 23.79771805], [86.80841064, 23.78827095], [86.81671906, 23.77614975], [86.81977081, 23.76107025], [86.81933594, 23.75226974], [86.81610107, 23.74483109], [86.81163025, 23.74480057], [86.80800629, 23.74381065], [86.80451202, 23.73985291], [86.79837036, 23.71634102], [86.79351044, 23.70601273], [86.79093933, 23.69849968], [86.79305267, 23.69502258], [86.79567719, 23.69347954], [86.79203796, 23.6873703], [86.77269745, 23.68188095], [86.75850677, 23.67848015], [86.73812866, 23.6776104], [86.73591614, 23.6790905], [86.73654938, 23.68876076], [86.73169708, 23.69379044], [86.71100616, 23.69722939], [86.69384766, 23.69452095], [86.68334961, 23.68974113], [86.66873169, 23.68605042], [86.64884949, 23.68287086], [86.63334656, 23.6757412], [86.62444305, 23.67276955], [86.61580658, 23.6716404], [86.59160614, 23.67115021], [86.58796692, 23.66908073], [86.58850861, 23.66544151], [86.59062195, 23.66224098], [86.58310699, 23.65884018], [86.56524658, 23.64627075], [86.55201721, 23.64009285], [86.53743744, 23.63462067], [86.52865601, 23.62898064], [86.5236969, 23.62836075], [86.51187897, 23.62906075], [86.50171661, 23.63157845], [86.48129272, 23.63503838], [86.47162628, 23.6312809], [86.46642303, 23.6296196], [86.44490814, 23.63153267], [86.43988037, 23.62961006], [86.43847656, 23.62779236], [86.43791962, 23.62417984], [86.43959808, 23.61667252], [86.43963623, 23.60910034], [86.43456268, 23.60845184], [86.43045807, 23.61111069], [86.42727661, 23.61033058], [86.42466736, 23.60491943], [86.41821289, 23.60341263], [86.41356659, 23.60133171], [86.41036987, 23.59802246], [86.40622711, 23.58798027], [86.40019226, 23.58945274], [86.38941956, 23.58877945], [86.38697052, 23.58535957], [86.38092804, 23.58436012], [86.38220215, 23.5789299], [86.38176727, 23.57550049], [86.38288116, 23.57201958], [86.37812042, 23.56883812], [86.37486267, 23.56851959], [86.37304688, 23.5613308], [86.36789703, 23.55920982], [86.36480713, 23.55705261], [86.36422729, 23.55134964], [86.36160278, 23.54966164], [86.36048126, 23.54612923], [86.35797119, 23.5430603], [86.36048126, 23.53848076], [86.3587265, 23.53363991], [86.35965729, 23.53067017], [86.36383057, 23.52807045], [86.36495209, 23.52548981], [86.36765289, 23.52255821], [86.36701202, 23.51885986], [86.36503601, 23.51543808], [86.35690308, 23.51288986], [86.35706329, 23.51025009], [86.35370636, 23.49641991], [86.3585968, 23.48958969], [86.36205292, 23.49188995], [86.37059784, 23.49026108], [86.37214661, 23.48607826], [86.37194824, 23.48266029], [86.37052155, 23.48163986], [86.36850739, 23.48396111], [86.36440277, 23.48214912], [86.35549927, 23.48155975], [86.34897614, 23.47249985], [86.35222626, 23.46819115], [86.35183716, 23.46363068], [86.34703827, 23.46116257], [86.33789825, 23.46109009], [86.33834076, 23.45697975], [86.34041595, 23.45239258], [86.33135986, 23.44724083], [86.32926941, 23.44824028], [86.32863617, 23.45498085], [86.32621002, 23.45756149], [86.3212204, 23.45448112], [86.31511688, 23.45267105], [86.31208801, 23.44860077], [86.30647278, 23.44820976], [86.30014801, 23.44371033], [86.30034637, 23.4406395], [86.30578613, 23.43618011], [86.30998993, 23.43761063], [86.31227875, 23.43732071], [86.31286621, 23.43143082], [86.3142395, 23.42828941], [86.3133316, 23.42606163], [86.30000305, 23.42006111], [86.28967285, 23.42287064], [86.28237152, 23.42745972], [86.28115082, 23.43544769], [86.2806778, 23.43960953], [86.2784729, 23.44112015], [86.27348328, 23.43894958], [86.26719666, 23.44000053], [86.26629639, 23.43795967], [86.26374817, 23.43657112], [86.25784302, 23.43821907], [86.25244141, 23.43749046], [86.25006104, 23.43559074], [86.2466507, 23.4341526], [86.24794769, 23.43083954], [86.25305176, 23.42485046], [86.25083923, 23.42221069], [86.24646759, 23.41918945], [86.24317932, 23.41958046], [86.23989105, 23.42258072], [86.2390976, 23.42571068], [86.23954773, 23.43168068], [86.23110962, 23.42951965], [86.22466278, 23.43568039], [86.22502136, 23.4428196], [86.22735596, 23.44960976], [86.23517609, 23.45598984], [86.23874664, 23.46969032], [86.23226929, 23.47072029], [86.22532654, 23.46988106], [86.22319794, 23.46480751], [86.22406006, 23.4572506], [86.22097778, 23.4559803], [86.20970917, 23.45923042], [86.20326233, 23.45868111], [86.19956207, 23.46404839], [86.19536591, 23.46347046], [86.19180298, 23.46442032], [86.18676758, 23.46837044], [86.18102264, 23.46692085], [86.1787796, 23.46772957], [86.17914581, 23.47512054], [86.17233276, 23.47854042], [86.16792297, 23.47608948], [86.15296173, 23.47698975], [86.1455307, 23.47307014], [86.14267731, 23.47733116], [86.14331055, 23.4812603], [86.14585876, 23.48612976], [86.14517975, 23.49398994], [86.15511322, 23.5042305], [86.15328979, 23.50975037], [86.15455627, 23.51914978], [86.14292908, 23.52734184], [86.14427948, 23.53524017], [86.14969635, 23.54117966], [86.15273285, 23.5482502], [86.15326691, 23.55159187], [86.14846802, 23.55550957], [86.14628601, 23.55866051], [86.14842987, 23.56393051], [86.14819336, 23.56542015], [86.14476776, 23.56777191], [86.13861084, 23.57002068], [86.13607025, 23.56926918], [86.13172913, 23.56623077], [86.1266861, 23.56674957], [86.11943817, 23.57391167], [86.1102066, 23.57073021], [86.10485077, 23.57196045], [86.10154724, 23.57389832], [86.09835815, 23.570961], [86.09358215, 23.57001114], [86.08795929, 23.5676403], [86.08268738, 23.56857109], [86.07276917, 23.56822014], [86.07144165, 23.57847977], [86.06530762, 23.58073044], [86.05133057, 23.57889938], [86.04686737, 23.58386993], [86.0373764, 23.58345985], [86.03533936, 23.57509041], [86.03009796, 23.57476044], [86.02511597, 23.57229805], [86.01760864, 23.56361008], [86.01100922, 23.56124115], [86.01077271, 23.55164909], [86.02110291, 23.54549026], [86.01854706, 23.54243088], [86.02506256, 23.53174973], [86.02703857, 23.52425003], [86.03156281, 23.52096748], [86.03269196, 23.51802254], [86.03276825, 23.50484085], [86.04860687, 23.5026207], [86.0508728, 23.50155067], [86.05150604, 23.49900055], [86.04722595, 23.49364281], [86.04136658, 23.49024963], [86.03575134, 23.49032021], [86.02906799, 23.48715973], [86.02559662, 23.48808098], [86.02037048, 23.48791122], [86.01545715, 23.48516083], [86.01023102, 23.48315048], [86.00557709, 23.48269081], [86.00137329, 23.47879982], [85.99475098, 23.47553253], [85.99037933, 23.47637939], [85.97566223, 23.47072983], [85.96781921, 23.46537018], [85.95717621, 23.46193123], [85.95289612, 23.45962906], [85.94979858, 23.45545006], [85.94390869, 23.45462036], [85.9379425, 23.45513916], [85.91752625, 23.46235085], [85.91269684, 23.46729851], [85.90637207, 23.47175026], [85.89125061, 23.47598076], [85.87757874, 23.4758606], [85.87412262, 23.47623062], [85.87007904, 23.47480011], [85.86602783, 23.4702301], [85.86354828, 23.45948982], [85.86206055, 23.45496941], [85.85954285, 23.45095062], [85.85975647, 23.44161987], [85.86089325, 23.42818069], [85.86287689, 23.40997124], [85.8722229, 23.40853119], [85.87419891, 23.41050911], [85.87845612, 23.40802956], [85.8817215, 23.40372086], [85.8782959, 23.4021492], [85.87731171, 23.40043068], [85.88478088, 23.38734055], [85.88212585, 23.38371086], [85.88247681, 23.3810997], [85.89057922, 23.38103294], [85.89434814, 23.37968063], [85.89585876, 23.37697983], [85.89569092, 23.37059021], [85.89337921, 23.36953926], [85.88527679, 23.37375832], [85.87503052, 23.36828041], [85.86625671, 23.36484909], [85.8666687, 23.36148071], [85.87301636, 23.35689926], [85.87277985, 23.35527992], [85.8708725, 23.35251999], [85.87159729, 23.33015823], [85.87535095, 23.32874107], [85.87751007, 23.32625961], [85.87798309, 23.32370949], [85.87523651, 23.32067108], [85.86830139, 23.31587982], [85.86077118, 23.31497955], [85.86149597, 23.30332947], [85.85785675, 23.3010807], [85.85240936, 23.2944603], [85.84446716, 23.28956985], [85.84173584, 23.28432083], [85.83912659, 23.2820797], [85.83365631, 23.2806797], [85.82636261, 23.26312065], [85.83067322, 23.24323082], [85.83184052, 23.21783066], [85.83068848, 23.21397018], [85.83072662, 23.21063995], [85.83281708, 23.20614052], [85.83371735, 23.20190048], [85.83155823, 23.19511986], [85.83241272, 23.1926403], [85.83500671, 23.19210052], [85.84391022, 23.19412994], [85.85192108, 23.19255066], [85.85752106, 23.19436264], [85.85984802, 23.19239044], [85.87721252, 23.17296028], [85.87780762, 23.17101288], [85.87657928, 23.16127968], [85.87731171, 23.15866089], [85.88640594, 23.15335083], [85.88916016, 23.1517601], [85.900383, 23.1480999], [85.90673828, 23.14207077], [85.91160583, 23.13358116], [85.91499329, 23.12952995], [85.91781616, 23.1311512], [85.91957092, 23.12695122], [85.92147064, 23.12593079], [85.92202759, 23.12939835], [85.92581177, 23.13065147], [85.93628693, 23.1296711], [85.94380951, 23.12947083], [85.9467392, 23.13088036], [85.94790649, 23.13396072], [85.95155334, 23.13816071], [85.95629883, 23.13947105], [85.9593277, 23.13977242], [85.97048187, 23.14002991], [85.98194122, 23.14590073], [85.99006653, 23.14628029], [85.99555969, 23.14442062], [86.00258636, 23.14616966], [86.00609589, 23.14490128], [86.00971985, 23.14497948], [86.01389313, 23.14164162], [86.01799774, 23.14048958], [86.0247879, 23.14319992], [86.02835846, 23.1457119], [86.03227234, 23.1450901], [86.03692627, 23.14361], [86.04199219, 23.13596916], [86.04839325, 23.12916946], [86.04897308, 23.12484932], [86.04653931, 23.12068748], [86.04424286, 23.11186028], [86.047966, 23.10868073], [86.05928802, 23.1055603], [86.07000732, 23.1014328], [86.08096313, 23.10429955], [86.08322144, 23.10093117], [86.08358765, 23.09859085], [86.09179688, 23.09077072], [86.09710693, 23.09166908], [86.10476685, 23.08889961], [86.10640717, 23.09028816], [86.11418152, 23.09196091], [86.11569214, 23.09363174], [86.12735748, 23.08908081], [86.12864685, 23.0857296], [86.13656616, 23.08310127], [86.13803864, 23.08048058], [86.13363647, 23.06990051], [86.13456726, 23.0629406], [86.1381073, 23.05932999], [86.14604187, 23.05572128], [86.14833069, 23.05266953], [86.15001678, 23.04089928], [86.15365601, 23.03722954], [86.16015625, 23.03906059], [86.162323, 23.03380966], [86.1667099, 23.02695084], [86.17249298, 23.02305031], [86.17562866, 23.01299095], [86.17838287, 23.01172066], [86.18118286, 23.01296043], [86.2008667, 23.01514244], [86.20436096, 23.0132103], [86.20024109, 23.00974846], [86.20381165, 22.99785805], [86.20642853, 22.99407005], [86.21247864, 22.9918499], [86.21697235, 22.99160957], [86.22706604, 22.99287033], [86.23095703, 22.99214172], [86.23448181, 22.99336815], [86.2386322, 22.99488831], [86.24508667, 22.99546051], [86.25086212, 22.99497986], [86.2612915, 22.99553108], [86.26378632, 22.99802971], [86.26328278, 22.99936104], [86.26500702, 23.00040054], [86.26972198, 23.00443077], [86.27350616, 23.00653076], [86.27552032, 23.00860023], [86.27937317, 23.0107193], [86.28475952, 23.01086044], [86.29199219, 23.0100708], [86.29191589, 23.00905037], [86.29400635, 23.00811005], [86.29482269, 23.00914192], [86.29638672, 23.0102005], [86.29751587, 23.01325989], [86.29825592, 23.01328278], [86.30030823, 23.01234055], [86.30069733, 23.01035118], [86.30042267, 23.00831985], [86.30020142, 23.00630188], [86.30211639, 23.00335121], [86.3059082, 23.00248909], [86.30992889, 23.00065041], [86.30989075, 22.9981308], [86.31217957, 22.99521065], [86.31529236, 22.99555969], [86.32585907, 22.9924202], [86.33215332, 22.98890114], [86.3347168, 22.98935127], [86.34133148, 22.99328041], [86.34648895, 22.9930191], [86.35048676, 22.98917961], [86.35160828, 22.99491119], [86.35997772, 22.99668121], [86.3632431, 22.99274826], [86.36949921, 22.99431038], [86.38044739, 22.99074936], [86.38096619, 22.98441124], [86.38360596, 22.98013115], [86.38730621, 22.97673035], [86.39303589, 22.97423935], [86.3968811, 22.97781944], [86.4003067, 22.98314095], [86.41052246, 22.98701859], [86.41628265, 22.99479103], [86.43170166, 22.99032974], [86.44056702, 22.99007988], [86.44168854, 22.98732948], [86.44522858, 22.98509026], [86.44779205, 22.9871006], [86.45108795, 22.98760986], [86.46308899, 22.98521805], [86.46618652, 22.98863029], [86.4749527, 22.98566055], [86.47936249, 22.98884964], [86.4973526, 22.98990822], [86.49730682, 22.98314857], [86.50401306, 22.97801971], [86.50762177, 22.97277069], [86.49991608, 22.96854019], [86.51223755, 22.96626091], [86.51876068, 22.96811295], [86.52271271, 22.97215843], [86.52076721, 22.97282982], [86.5341568, 22.98135948], [86.5402832, 22.9872303], [86.54203033, 22.97434044], [86.53774261, 22.96583939], [86.53851318, 22.96186829], [86.53244781, 22.96223259], [86.52662659, 22.96087074], [86.52757263, 22.95792961], [86.52339172, 22.94868088], [86.51835632, 22.94433022], [86.51272583, 22.94619179], [86.50757599, 22.94535828], [86.49868774, 22.94774055], [86.49662018, 22.94754028], [86.49772644, 22.94512939], [86.49577332, 22.94129181], [86.49401093, 22.94148827], [86.49246979, 22.94423103], [86.48943329, 22.94406128], [86.48680115, 22.93554115], [86.48452759, 22.9342804], [86.4838028, 22.93824959], [86.47872162, 22.9405899], [86.47344971, 22.94408035], [86.4743576, 22.94882965], [86.47042084, 22.94944954], [86.47012329, 22.94662285], [86.46206665, 22.94423103], [86.4580307, 22.93879128], [86.45820618, 22.93296051], [86.45104218, 22.93046951], [86.43708801, 22.92728996], [86.43282318, 22.92340279], [86.43113708, 22.92013931], [86.43241882, 22.91576958], [86.44845581, 22.90192032], [86.46234894, 22.89898109], [86.46304321, 22.89663124], [86.45101929, 22.88297081], [86.44696045, 22.8834095], [86.44928741, 22.87705994], [86.44667053, 22.86944962], [86.44769287, 22.86173058], [86.44687653, 22.85877991], [86.43283844, 22.8604908], [86.43126678, 22.84638023], [86.43321991, 22.84058952], [86.43300629, 22.83533287], [86.43390656, 22.82859039], [86.42159271, 22.80882072], [86.41796875, 22.78981972], [86.4126358, 22.78643036], [86.41615295, 22.77650833], [86.42198944, 22.7741909], [86.42887115, 22.76843071], [86.43982697, 22.76268005], [86.4438858, 22.7585907], [86.45401001, 22.75963974], [86.46604156, 22.74645042], [86.46666718, 22.74023056], [86.47001648, 22.73740768], [86.47898102, 22.72239113], [86.48162079, 22.72474098], [86.48774719, 22.72328949], [86.48993683, 22.71981049], [86.49653625, 22.7154808], [86.50035858, 22.7110405], [86.5065918, 22.70152092], [86.50955963, 22.70226288], [86.50805664, 22.70816994], [86.50995636, 22.71606064], [86.51644897, 22.71478081], [86.52017975, 22.71790123], [86.53369904, 22.71657944], [86.53925323, 22.72064972], [86.54634857, 22.71528816], [86.5495224, 22.7109108], [86.55510712, 22.70788002], [86.57401276, 22.69463921], [86.58078003, 22.68899155], [86.59121704, 22.68864059], [86.59670258, 22.68544006], [86.6029129, 22.67983055], [86.61016083, 22.67741966], [86.61786652, 22.67338943], [86.62236786, 22.66631126], [86.63037872, 22.66250992], [86.63668823, 22.65512085], [86.63548279, 22.64719963], [86.6367569, 22.63081932], [86.63510132, 22.62265968], [86.63239288, 22.60997963], [86.63400269, 22.60401154], [86.63432312, 22.59725952], [86.63897705, 22.59375], [86.64827728, 22.59160995], [86.65109253, 22.58426285], [86.64932251, 22.58204079], [86.65170288, 22.57579041], [86.65727997, 22.57270813], [86.66139984, 22.57443047], [86.67279816, 22.57238007], [86.67388916, 22.57349014], [86.68340302, 22.57676125], [86.70601654, 22.58036041], [86.72767639, 22.57463837], [86.75598907, 22.57427025], [86.7599411, 22.57242966], [86.76344299, 22.5646286], [86.76741791, 22.56088829], [86.76696014, 22.55603027], [86.76348114, 22.55252075], [86.76451874, 22.55063057], [86.77126312, 22.54831123], [86.77137756, 22.54583931], [86.77630615, 22.54700851], [86.77789307, 22.54541016], [86.78407288, 22.54424095], [86.78617096, 22.53741074], [86.78279114, 22.5357399], [86.78531647, 22.53244019], [86.78520966, 22.52931023], [86.7828064, 22.52437019], [86.789711, 22.52038002], [86.79139709, 22.51666069], [86.79177856, 22.51343918], [86.78930664, 22.50965118], [86.78962708, 22.50757027], [86.79860687, 22.49882126], [86.79096222, 22.49362946], [86.79296112, 22.49060059], [86.79701233, 22.48875809], [86.797966, 22.48699188], [86.79801178, 22.48398972], [86.79556274, 22.47968292], [86.78922272, 22.47451019], [86.7855072, 22.47665024], [86.78251648, 22.47735023], [86.77571106, 22.47730064], [86.76953125, 22.4759407], [86.76066589, 22.47891045], [86.75332642, 22.48011971], [86.74826813, 22.47866058], [86.7454071, 22.4756794], [86.74513245, 22.47053909], [86.74900055, 22.46033287], [86.7514801, 22.45067978], [86.75744629, 22.44638062], [86.75707245, 22.44244957], [86.75794983, 22.43565941], [86.76226044, 22.42523193], [86.76389313, 22.42288971], [86.76925659, 22.42158127], [86.77867889, 22.42149162], [86.78897858, 22.41825294], [86.8052597, 22.41649055], [86.81841278, 22.41230011], [86.83090973, 22.40637016], [86.83875275, 22.40135956], [86.84393311, 22.39606094], [86.8449173, 22.39232826], [86.84359741, 22.38764191], [86.84047699, 22.3842392], [86.83822632, 22.37861061], [86.84094238, 22.36902046], [86.83634186, 22.36087036], [86.82894135, 22.34150124], [86.83006287, 22.33839989], [86.82853699, 22.32949066], [86.82919312, 22.32459068], [86.8368988, 22.31675148], [86.84066772, 22.31381035], [86.84719086, 22.31315041], [86.86295319, 22.30381966], [86.86808014, 22.30458069], [86.87121582, 22.30266953], [86.87258911, 22.2987709], [86.88080597, 22.29640961], [86.88511658, 22.29670906], [86.88623047, 22.29412079], [86.88684845, 22.28668976], [86.88845062, 22.28141022], [86.88860321, 22.27569962], [86.88796234, 22.26958275], [86.88562775, 22.26890945], [86.88555908, 22.26342964], [86.88667297, 22.25900078], [86.88568115, 22.25212097], [86.87313843, 22.25447083], [86.86904907, 22.25464058], [86.86460876, 22.25348282], [86.85835266, 22.25443077], [86.85423279, 22.25678062], [86.85069275, 22.26049042], [86.85015106, 22.25926971], [86.84127045, 22.2571106], [86.83605194, 22.26078987], [86.83371735, 22.25959969], [86.82842255, 22.25922966], [86.82280731, 22.26132965], [86.82034302, 22.26061058], [86.81912231, 22.25354958], [86.81633759, 22.2493], [86.81382751, 22.2580204], [86.81256104, 22.25928116], [86.81186676, 22.26393127], [86.8113327, 22.25948143], [86.80919647, 22.25379944], [86.80996704, 22.24954987], [86.80895233, 22.2464695], [86.80744171, 22.24582291], [86.80660248, 22.24378014], [86.80394745, 22.24397087], [86.80242157, 22.24180984], [86.79960632, 22.24097252], [86.79691315, 22.24306107], [86.79650879, 22.24508095], [86.79846191, 22.24544907], [86.79641724, 22.24991035], [86.80062866, 22.26192284], [86.79026794, 22.26280022], [86.79068756, 22.25323105], [86.79316711, 22.24398994], [86.79283142, 22.23872948], [86.79756165, 22.23394966], [86.7995224, 22.23518944], [86.80137634, 22.23863029], [86.80986786, 22.23800278], [86.8091507, 22.2331028], [86.80011749, 22.21363068], [86.79136658, 22.21754074], [86.78594208, 22.21405029], [86.78356934, 22.21165085], [86.77906036, 22.21152115], [86.77601624, 22.21377945], [86.77892303, 22.22171974], [86.78250122, 22.22536278], [86.79115295, 22.22030067], [86.79220581, 22.22384262], [86.78681946, 22.2293396], [86.77996826, 22.23172188], [86.77588654, 22.23154068], [86.77275085, 22.23034286], [86.77207184, 22.22768021], [86.77455902, 22.2233696], [86.77522278, 22.21462822], [86.76992035, 22.21455002], [86.76703644, 22.21134186], [86.75509644, 22.20798111], [86.74780273, 22.20798111], [86.74106598, 22.21080971], [86.73375702, 22.21121979], [86.72534943, 22.21350098], [86.72278595, 22.21524811]]]}}, {\\\"id\\\": \\\"14\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.16_1\\\", \\\"HASC_1\\\": \\\"IN.KA\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Karnataka\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Maisur|Mysore\\\", \\\"apm25_popweighted\\\": 55.0, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1418.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1244.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2662.0, \\\"geo-id\\\": 14, \\\"hpm25_child_popweighted\\\": 127.2, \\\"hpm25_female_popweighted\\\": 146.2, \\\"hpm25_male_popweighted\\\": 105.3, \\\"location\\\": \\\"Karnataka\\\", \\\"mort_apm25_6cod_mean_total\\\": 27801.0, \\\"mort_hpm25_6cod_mean_total\\\": 25021.0, \\\"mort_tpm25_6cod_mean_total\\\": 52822.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[74.67069244, 13.3829174], [74.67069244, 13.38319302], [74.67152405, 13.38319302], [74.67152405, 13.3829174], [74.67180634, 13.3829174], [74.67180634, 13.38263893], [74.67208099, 13.38264084], [74.67208099, 13.38236141], [74.67236328, 13.38236141], [74.67236328, 13.38208294], [74.67272186, 13.38208294], [74.67346954, 13.38208294], [74.67346954, 13.38180542], [74.67363739, 13.38180542], [74.67375183, 13.38180542], [74.67375183, 13.38152695], [74.67391205, 13.38152885], [74.67402649, 13.38153172], [74.67402649, 13.38126945], [74.67430878, 13.38125134], [74.67430878, 13.38097095], [74.67458344, 13.38097095], [74.67458344, 13.38069534], [74.67485809, 13.38069534], [74.67485809, 13.37959194], [74.67485809, 13.37791729], [74.67457581, 13.3779192], [74.67457581, 13.3773613], [74.67485809, 13.3773613], [74.67485809, 13.37652874], [74.67514038, 13.37653065], [74.67514038, 13.37569046], [74.67346954, 13.37569046], [74.67346954, 13.37597275], [74.67318726, 13.37597275], [74.67318726, 13.37653065], [74.67292023, 13.37653065], [74.67292023, 13.37681103], [74.67263794, 13.37680531], [74.67263794, 13.37708282], [74.67236328, 13.37708282], [74.67236328, 13.3773613], [74.67208099, 13.3773613], [74.67208099, 13.3779192], [74.67180634, 13.37791729], [74.67180634, 13.37847328], [74.67151642, 13.37847137], [74.67151642, 13.37903118], [74.67124939, 13.37903118], [74.67124939, 13.37931156], [74.67097473, 13.37930489], [74.67097473, 13.37958336], [74.67041779, 13.37958336], [74.67041779, 13.37986088], [74.67014313, 13.37985039], [74.67014313, 13.38014126], [74.67041779, 13.38013935], [74.67041779, 13.38069534], [74.6701355, 13.38069534], [74.6701355, 13.38097095], [74.6709671, 13.38097095], [74.6709671, 13.38153172], [74.67069244, 13.38152695], [74.67069244, 13.38171196], [74.67069244, 13.38208294], [74.67041779, 13.38208294], [74.67041779, 13.3829174], [74.67069244, 13.3829174]]], [[[74.68958282, 13.33375168], [74.68958282, 13.33403015], [74.69069672, 13.33403015], [74.69069672, 13.33375168], [74.69097137, 13.33375168], [74.69097137, 13.33319092], [74.69125366, 13.33319569], [74.69125366, 13.33291531], [74.69152832, 13.33292198], [74.69152832, 13.33235931], [74.69180298, 13.33236122], [74.69180298, 13.33208275], [74.69208527, 13.33208275], [74.69208527, 13.3316412], [74.69208527, 13.33152676], [74.69235992, 13.33152962], [74.69235992, 13.33069134], [74.68985748, 13.33069324], [74.68985748, 13.33250046], [74.68985748, 13.33375168], [74.68958282, 13.33375168]]], [[[74.68763733, 13.34069443], [74.68763733, 13.34097195], [74.68902588, 13.34097195], [74.68902588, 13.33930588], [74.68930817, 13.33931065], [74.68930817, 13.33875179], [74.68958282, 13.33875179], [74.68958282, 13.33819103], [74.68985748, 13.33819389], [74.68985748, 13.33720016], [74.68985748, 13.33541775], [74.68902588, 13.33541965], [74.68902588, 13.33514023], [74.6886673, 13.33514023], [74.68763733, 13.33514023], [74.68763733, 13.33569431], [74.68819427, 13.33569431], [74.68819427, 13.33597183], [74.68846893, 13.33597183], [74.68846893, 13.33681011], [74.68791962, 13.3368063], [74.68791962, 13.33708382], [74.68736267, 13.33708382], [74.68736267, 13.3368063], [74.68569183, 13.3368063], [74.68569183, 13.33708382], [74.68597412, 13.33708382], [74.68597412, 13.33736229], [74.68653107, 13.33736038], [74.68653107, 13.33763981], [74.68681335, 13.33763981], [74.68681335, 13.33903027], [74.68708038, 13.33903027], [74.68708038, 13.34042263], [74.68736267, 13.34041595], [74.68736267, 13.34069443], [74.68763733, 13.34069443]]], [[[74.68152618, 13.34735966], [74.68152618, 13.3484726], [74.68264008, 13.3484726], [74.68264008, 13.34819508], [74.68291473, 13.34819508], [74.68291473, 13.34763908], [74.68319702, 13.34764099], [74.68319702, 13.34708023], [74.68347168, 13.34708214], [74.68347168, 13.34652901], [74.68374634, 13.34653091], [74.68374634, 13.34589005], [74.68374634, 13.34569359], [74.68402863, 13.34569359], [74.68402863, 13.3451376], [74.68486023, 13.34514141], [74.68486023, 13.34486008], [74.68514252, 13.34486008], [74.68514252, 13.3445797], [74.68541718, 13.34458447], [74.68541718, 13.34402847], [74.68569183, 13.34403133], [74.68569183, 13.34374142], [74.68597412, 13.34375], [74.68597412, 13.34347153], [74.68624878, 13.34347153], [74.68624878, 13.34319401], [74.68653107, 13.34319401], [74.68653107, 13.34291553], [74.68681335, 13.34292126], [74.68681335, 13.34235954], [74.68708038, 13.3423624], [74.68708038, 13.34208202], [74.68736267, 13.34208202], [74.68736267, 13.34152794], [74.68708038, 13.34153271], [74.68708038, 13.34125042], [74.68653107, 13.34125042], [74.68653107, 13.34097195], [74.68569183, 13.34097195], [74.68569183, 13.34069443], [74.68486023, 13.34068012], [74.68486023, 13.34153271], [74.68514252, 13.34152794], [74.68514252, 13.3423624], [74.68374634, 13.34235954], [74.68374634, 13.34263992], [74.68347168, 13.34263992], [74.68347168, 13.34292126], [74.68282318, 13.34291553], [74.68152618, 13.34291553], [74.68152618, 13.34319401], [74.68180084, 13.34319019], [74.68180084, 13.34403133], [74.68152618, 13.34403133], [74.68152618, 13.34431076], [74.68125153, 13.34430599], [74.68125153, 13.34458447], [74.68096924, 13.3445797], [74.68096924, 13.34486008], [74.68235779, 13.34486008], [74.68235779, 13.34514141], [74.68208313, 13.3451376], [74.68208313, 13.34569359], [74.68180084, 13.34568977], [74.68180847, 13.34735966], [74.68152618, 13.34735966]]], [[[74.32624817, 14.02069473], [74.32624817, 14.02041721], [74.32682037, 14.02042103], [74.32682037, 14.01986027], [74.32707977, 14.01986027], [74.32707977, 14.01958466], [74.32736206, 14.01958466], [74.32736206, 14.01930428], [74.32763672, 14.01931095], [74.32763672, 14.01903057], [74.32791901, 14.01903057], [74.32791901, 14.01875114], [74.32958984, 14.01875114], [74.32958221, 14.01847172], [74.3298645, 14.01847172], [74.3298645, 14.0181942], [74.33041382, 14.0181942], [74.33041382, 14.01680565], [74.33013916, 14.01681137], [74.33013916, 14.01653099], [74.32985687, 14.01653099], [74.32985687, 14.01542091], [74.32958984, 14.01542091], [74.32958984, 14.01513958], [74.32930756, 14.01513958], [74.32930756, 14.01485062], [74.32902527, 14.01486015], [74.32902527, 14.01458359], [74.32847595, 14.01458359], [74.32847595, 14.01375008], [74.32875061, 14.01375008], [74.32875061, 14.01292038], [74.32847595, 14.01292038], [74.32847595, 14.01264], [74.32875061, 14.01264], [74.32875061, 14.01235962], [74.32847595, 14.01236153], [74.32847595, 14.01180553], [74.32791901, 14.01181126], [74.32791901, 14.01152992], [74.32763672, 14.01152992], [74.32763672, 14.01124954], [74.32653046, 14.01124954], [74.32653046, 14.01152992], [74.32596588, 14.01152992], [74.32596588, 14.01181126], [74.32569122, 14.01180553], [74.32569122, 14.01236153], [74.32541656, 14.01235962], [74.32541656, 14.01292038], [74.32569122, 14.01291561], [74.32569122, 14.01319408], [74.32541656, 14.01318932], [74.32541656, 14.01375008], [74.32514191, 14.01375008], [74.32514191, 14.01431084], [74.32458496, 14.01430607], [74.32458496, 14.01458359], [74.32430267, 14.01458168], [74.32430267, 14.01513958], [74.32375336, 14.01513958], [74.32375336, 14.01542091], [74.32345581, 14.01542091], [74.32345581, 14.01735973], [74.32319641, 14.01735973], [74.32319641, 14.01764107], [74.32347107, 14.01763821], [74.32347107, 14.01847172], [74.32375336, 14.01847172], [74.32375336, 14.01958466], [74.32402802, 14.01958179], [74.32402802, 14.02042103], [74.32458496, 14.02041721], [74.32458496, 14.02069473], [74.32624817, 14.02069473]]], [[[74.48291779, 14.01124954], [74.48291779, 14.01097202], [74.48319244, 14.01097202], [74.48319244, 14.01041794], [74.4834671, 14.01041985], [74.4834671, 14.00930977], [74.48319244, 14.00930977], [74.48319244, 14.00792027], [74.48264313, 14.00792027], [74.4826355, 14.00771046], [74.48290253, 14.00764179], [74.48291779, 14.00652981], [74.48264313, 14.00652981], [74.48264313, 14.00624943], [74.48208618, 14.00624943], [74.48208618, 14.00541973], [74.48152924, 14.00541973], [74.48152924, 14.00486088], [74.48042297, 14.00486088], [74.48042297, 14.0051403], [74.4798584, 14.0051403], [74.4798584, 14.00541973], [74.47958374, 14.00541782], [74.47958374, 14.00569344], [74.47930908, 14.00569057], [74.47930908, 14.00624943], [74.47902679, 14.00624943], [74.47902679, 14.00736237], [74.47875214, 14.00735855], [74.47875214, 14.00792027], [74.47846985, 14.00792027], [74.47846985, 14.00930977], [74.47875214, 14.00930977], [74.47875214, 14.00986195], [74.47902679, 14.00986195], [74.47902679, 14.01069355], [74.4798584, 14.01069355], [74.4798584, 14.01097202], [74.48042297, 14.01097202], [74.48041534, 14.01124954], [74.48052216, 14.01124954], [74.48291779, 14.01124954]]], [[[74.6701355, 13.19958401], [74.6701355, 13.19986153], [74.67097473, 13.19986153], [74.67097473, 13.19958401], [74.67152405, 13.19958401], [74.67152405, 13.19930553], [74.67208099, 13.1993103], [74.67208099, 13.19902992], [74.67263794, 13.19902992], [74.67263794, 13.19874859], [74.67292023, 13.19874859], [74.67292023, 13.19792175], [74.67263794, 13.19792175], [74.67263794, 13.19680977], [74.67318726, 13.19680977], [74.67318726, 13.19736099], [74.67375183, 13.19736099], [74.67375183, 13.19792175], [74.67402649, 13.19792175], [74.67402649, 13.19763947], [74.67430878, 13.19763947], [74.67430878, 13.19708061], [74.67458344, 13.19708347], [74.67458344, 13.19652653], [74.67485809, 13.19653034], [74.67485809, 13.19597054], [74.67514038, 13.1959734], [74.67514038, 13.19569492], [74.67542267, 13.19569111], [74.67541504, 13.1954174], [74.67569733, 13.19542027], [74.67569733, 13.19514179], [74.67597198, 13.19514179], [74.67597198, 13.19486141], [74.67624664, 13.19486141], [74.67624664, 13.19375134], [74.67652893, 13.19375134], [74.67652893, 13.19292164], [74.67624664, 13.19292164], [74.67624664, 13.19208145], [74.67597198, 13.19208336], [74.67597198, 13.19152737], [74.67569733, 13.19152737], [74.67569733, 13.19208336], [74.67542267, 13.19208145], [74.67542267, 13.19264126], [74.67514038, 13.19264126], [74.67514038, 13.19292164], [74.67485809, 13.19291687], [74.67485809, 13.19347095], [74.67457581, 13.19347095], [74.67457581, 13.19403172], [74.67430878, 13.19403172], [74.67430878, 13.19431019], [74.67402649, 13.19430542], [74.67402649, 13.19486141], [74.67375183, 13.19486141], [74.67375183, 13.19542027], [74.67346954, 13.1954174], [74.67346954, 13.19569302], [74.67208099, 13.19569302], [74.67208099, 13.19624901], [74.67180634, 13.19624043], [74.67180634, 13.19653034], [74.67152405, 13.19652653], [74.67152405, 13.19708347], [74.67124939, 13.19708061], [74.67124939, 13.19736099], [74.6709671, 13.19736099], [74.6709671, 13.19763947], [74.67069244, 13.19763947], [74.67069244, 13.19819641], [74.67041779, 13.19819641], [74.67041779, 13.19847107], [74.67014313, 13.19847107], [74.67014313, 13.19902992], [74.66986084, 13.19902706], [74.66986084, 13.19958401], [74.6701355, 13.19958401]]], [[[74.69986725, 13.28402996], [74.69986725, 13.28431034], [74.70041656, 13.28431034], [74.70041656, 13.28345966], [74.70069122, 13.28347206], [74.70069122, 13.28291798], [74.70097351, 13.28291798], [74.70097351, 13.28319359], [74.70124817, 13.28319359], [74.70124817, 13.27930546], [74.70096588, 13.27931023], [74.70096588, 13.27874947], [74.69930267, 13.27874947], [74.69930267, 13.27903175], [74.69902802, 13.27902699], [74.69902802, 13.27958393], [74.69875336, 13.27958107], [74.69875336, 13.28153038], [74.69958496, 13.28152847], [74.69958496, 13.28208447], [74.69930267, 13.28208447], [74.69930267, 13.28319359], [74.69957733, 13.28319073], [74.69957733, 13.28402996], [74.69986725, 13.28402996]]], [[[74.7279129, 13.28264046], [74.7279129, 13.28292179], [74.72846985, 13.28292179], [74.72846985, 13.28264046], [74.72875214, 13.28264046], [74.72875214, 13.28208065], [74.72846985, 13.28208447], [74.72846985, 13.28180599], [74.72820282, 13.28180981], [74.72820282, 13.28153038], [74.72763824, 13.28153038], [74.72763824, 13.28125191], [74.72735596, 13.28125191], [74.72735596, 13.28069115], [74.72763824, 13.28069305], [74.72763824, 13.28013992], [74.7279129, 13.28014183], [74.7279129, 13.27958107], [74.72819519, 13.27958393], [74.72819519, 13.27902699], [74.7279129, 13.27903175], [74.7279129, 13.27847099], [74.72735596, 13.27847099], [74.72735596, 13.27874947], [74.72680664, 13.27874947], [74.72680664, 13.27903175], [74.72651672, 13.27903175], [74.72651672, 13.27931023], [74.72597504, 13.27930546], [74.72597504, 13.27958393], [74.72569275, 13.27958393], [74.72569275, 13.2798624], [74.7251358, 13.2798624], [74.7251358, 13.28014183], [74.72541809, 13.28014183], [74.72541809, 13.2804203], [74.72569275, 13.28041458], [74.72569275, 13.28069305], [74.72597504, 13.28069305], [74.72597504, 13.28097153], [74.72624969, 13.28097153], [74.72624969, 13.28125191], [74.72651672, 13.28125191], [74.72651672, 13.28153038], [74.72680664, 13.28152847], [74.72680664, 13.28197193], [74.72680664, 13.28208447], [74.7270813, 13.28208065], [74.7270813, 13.28236198], [74.72735596, 13.28236198], [74.72738647, 13.28264046], [74.7279129, 13.28264046]]], [[[74.72319794, 13.28931141], [74.72319794, 13.28959084], [74.72374725, 13.28959084], [74.72374725, 13.28931141], [74.72429657, 13.28931141], [74.72429657, 13.28903103], [74.72486115, 13.28903103], [74.72486115, 13.28874969], [74.72541809, 13.28874969], [74.72541809, 13.28847027], [74.72569275, 13.28847218], [74.72569275, 13.2881937], [74.72624969, 13.2881937], [74.72624969, 13.28791618], [74.72680664, 13.28792095], [74.72680664, 13.28763962], [74.72735596, 13.28763962], [74.72735596, 13.28736019], [74.72763824, 13.2873621], [74.72763824, 13.28708363], [74.7280426, 13.28708363], [74.72846985, 13.28708363], [74.72846985, 13.28652763], [74.72820282, 13.28652954], [74.72820282, 13.28596973], [74.72793579, 13.28597164], [74.72763824, 13.28597164], [74.72763824, 13.28569412], [74.72652435, 13.28569412], [74.72652435, 13.28541565], [74.72624969, 13.28542042], [74.72624969, 13.28514004], [74.72541809, 13.28514004], [74.72541809, 13.28542042], [74.72486115, 13.28542042], [74.72486115, 13.28514004], [74.72458649, 13.28514004], [74.72458649, 13.28542042], [74.7243042, 13.28541565], [74.7243042, 13.28597164], [74.72403717, 13.28596973], [74.72403717, 13.28625011], [74.72374725, 13.28625011], [74.72374725, 13.28652954], [74.7234726, 13.28652954], [74.7234726, 13.28682041], [74.72319794, 13.28680611], [74.72319794, 13.28708363], [74.72291565, 13.28708363], [74.72291565, 13.2873621], [74.72270203, 13.28736019], [74.72264099, 13.28763962], [74.7223587, 13.28763962], [74.7223587, 13.28931141], [74.72265625, 13.28931141], [74.72319794, 13.28931141]]], [[[74.05652618, 14.81708431], [74.05652618, 14.81680584], [74.05680847, 14.81680965], [74.05680847, 14.81653023], [74.05652618, 14.81653023], [74.05652618, 14.81624985], [74.05625153, 14.81624985], [74.05625153, 14.81596947], [74.05596924, 14.81596947], [74.05596924, 14.81624985], [74.05569458, 14.81624985], [74.05569458, 14.81597233], [74.05458069, 14.81596947], [74.05458069, 14.81624985], [74.05430603, 14.81624985], [74.05430603, 14.81653023], [74.05458069, 14.81653023], [74.05458069, 14.81680965], [74.05486298, 14.81680584], [74.05486298, 14.81708431], [74.05652618, 14.81708431]]], [[[74.06402588, 14.82124996], [74.06402588, 14.82096958], [74.06458282, 14.82097244], [74.06458282, 14.82069397], [74.06513977, 14.8206892], [74.06513977, 14.82041645], [74.0654068, 14.82042122], [74.0654068, 14.82014179], [74.06569672, 14.82014179], [74.06569672, 14.81986046], [74.06541443, 14.81986237], [74.06541443, 14.81958199], [74.06485748, 14.81958199], [74.06485748, 14.81930637], [74.06291962, 14.81930637], [74.06291962, 14.81958199], [74.06263733, 14.81958199], [74.06263733, 14.8206892], [74.06291962, 14.82069397], [74.06291962, 14.82097244], [74.06318665, 14.82096958], [74.06318665, 14.82124996], [74.06402588, 14.82124996]]], [[[74.05930328, 14.82152843], [74.05930328, 14.82124996], [74.0617981, 14.82124996], [74.0617981, 14.82070065], [74.06208038, 14.8206892], [74.06208038, 14.82041645], [74.0617981, 14.82042122], [74.0617981, 14.82014179], [74.06153107, 14.82014179], [74.06153107, 14.81986046], [74.06097412, 14.81986237], [74.06097412, 14.81958199], [74.05958557, 14.81958199], [74.05958557, 14.81930637], [74.05819702, 14.81931114], [74.05819702, 14.81902981], [74.05735779, 14.8190279], [74.05735779, 14.81958199], [74.05708313, 14.81958199], [74.05708313, 14.82014179], [74.05735779, 14.82014179], [74.05735779, 14.82042122], [74.05791473, 14.82041645], [74.0579071, 14.8206892], [74.05819702, 14.82070065], [74.05819702, 14.82124996], [74.05847168, 14.82124996], [74.05847168, 14.82152843], [74.05930328, 14.82152843]]], [[[74.08791351, 14.79597187], [74.08791351, 14.79569435], [74.08875275, 14.79569435], [74.08875275, 14.79541588], [74.0890274, 14.79542065], [74.0890274, 14.79375172], [74.08735657, 14.79375172], [74.08735657, 14.79431057], [74.08708191, 14.7943058], [74.08708191, 14.79458427], [74.08680725, 14.79458046], [74.08680725, 14.79486179], [74.08625031, 14.79485989], [74.08625031, 14.79569435], [74.08652496, 14.79569435], [74.08652496, 14.79597187], [74.08791351, 14.79597187]]], [[[74.11125183, 14.76154137], [74.11125183, 14.76124954], [74.11152649, 14.76124954], [74.11152649, 14.75958061], [74.11180878, 14.75958443], [74.11180878, 14.75902653], [74.11207581, 14.75903034], [74.11207581, 14.75875187], [74.11235809, 14.75875187], [74.11235809, 14.75847054], [74.11264038, 14.75847054], [74.11264038, 14.75819588], [74.11290741, 14.75817966], [74.11291504, 14.75791836], [74.11347198, 14.75792027], [74.11347198, 14.75764179], [74.11374664, 14.75764179], [74.11374664, 14.75736141], [74.11402893, 14.75736141], [74.11402893, 14.75708294], [74.11430359, 14.75708294], [74.11430359, 14.75680542], [74.11486053, 14.75681019], [74.11486053, 14.75653172], [74.11541748, 14.75653172], [74.11541748, 14.75625134], [74.11569214, 14.75625134], [74.11569214, 14.75569057], [74.11597443, 14.75569534], [74.11597443, 14.75541687], [74.11653137, 14.75541687], [74.11653137, 14.75513935], [74.11875153, 14.75513935], [74.11875153, 14.75486088], [74.11975098, 14.75486088], [74.11985779, 14.75486088], [74.11985779, 14.75470161], [74.11985779, 14.75430489], [74.12014008, 14.75430965], [74.12014008, 14.75347137], [74.11985779, 14.75347328], [74.11985779, 14.75319481], [74.11902618, 14.75319481], [74.11902618, 14.75347328], [74.11875153, 14.75347137], [74.11875153, 14.75374889], [74.11650848, 14.75374889], [74.11458588, 14.75374889], [74.11458588, 14.75402927], [74.11402893, 14.75402927], [74.11402893, 14.75430965], [74.11347198, 14.75430489], [74.11347198, 14.75458336], [74.11290741, 14.75458145], [74.11290741, 14.75486088], [74.11264038, 14.75486088], [74.11264038, 14.75513935], [74.11152649, 14.75513935], [74.11152649, 14.75458145], [74.11096954, 14.75458336], [74.11096954, 14.75430489], [74.11068726, 14.75430965], [74.11068726, 14.75402927], [74.10984802, 14.75402927], [74.10984802, 14.75486088], [74.11013794, 14.75486088], [74.11013794, 14.75513935], [74.11042023, 14.75513935], [74.11042023, 14.75653172], [74.11013794, 14.75653172], [74.11013794, 14.75681019], [74.10986328, 14.75680542], [74.10986328, 14.75708294], [74.10958099, 14.75708294], [74.10958099, 14.75736141], [74.10901642, 14.75736141], [74.10901642, 14.75764179], [74.10874939, 14.75764179], [74.10874939, 14.75875187], [74.10791779, 14.75874901], [74.10791779, 14.75958443], [74.10819244, 14.75958061], [74.10819244, 14.75986195], [74.1084671, 14.75986195], [74.1084671, 14.76014042], [74.10874939, 14.76014042], [74.10874939, 14.76042175], [74.10902405, 14.76041794], [74.10902405, 14.7606926], [74.10930634, 14.7606926], [74.10930634, 14.76097202], [74.10958099, 14.76097202], [74.10958099, 14.76124954], [74.11013794, 14.76124954], [74.11013794, 14.76154137], [74.11125183, 14.76154137]]], [[[74.09708405, 14.87847233], [74.09708405, 14.87791634], [74.0973587, 14.8779211], [74.0973587, 14.87707996], [74.09680939, 14.87708378], [74.09680176, 14.87680626], [74.09625244, 14.87681103], [74.09625244, 14.87653065], [74.09570313, 14.87653065], [74.09570313, 14.87625027], [74.09513855, 14.87625027], [74.09513855, 14.87597179], [74.09430695, 14.87597179], [74.09430695, 14.87653065], [74.09402466, 14.87652779], [74.09402466, 14.87708378], [74.09430695, 14.87707996], [74.09430695, 14.87764072], [74.0945816, 14.87764072], [74.0945816, 14.8779211], [74.09513855, 14.87791634], [74.09513855, 14.87819386], [74.0956955, 14.87819386], [74.0956955, 14.87847233], [74.09708405, 14.87847233]]], [[[74.09402466, 14.83847141], [74.09402466, 14.8381958], [74.09430695, 14.8381958], [74.09430695, 14.83763885], [74.0945816, 14.83764172], [74.0945816, 14.83708096], [74.09486389, 14.83708286], [74.09486389, 14.83680534], [74.09401703, 14.8368206], [74.09401703, 14.83625126], [74.09375, 14.83625126], [74.09375, 14.83597088], [74.0929184, 14.83597088], [74.0929184, 14.83708286], [74.09319305, 14.83708286], [74.09319305, 14.8381958], [74.09347534, 14.8381958], [74.09347534, 14.83847141], [74.09402466, 14.83847141]]], [[[74.0984726, 14.84597206], [74.0984726, 14.84569359], [74.09874725, 14.84569359], [74.09874725, 14.84541798], [74.09929657, 14.84542274], [74.09929657, 14.84514046], [74.09986115, 14.84514046], [74.09986115, 14.84486198], [74.10041809, 14.84486198], [74.10041809, 14.8445816], [74.1020813, 14.84458447], [74.1020813, 14.84319401], [74.10190582, 14.84319401], [74.10180664, 14.84319401], [74.10180664, 14.84291553], [74.10151672, 14.8429203], [74.10151672, 14.84263134], [74.10097504, 14.84263992], [74.10097504, 14.84208393], [74.10041809, 14.84208393], [74.10041809, 14.84180641], [74.09874725, 14.84180641], [74.09874725, 14.84208393], [74.09791565, 14.84208393], [74.09791565, 14.8423624], [74.09764099, 14.8423624], [74.09764099, 14.84263992], [74.0973587, 14.84263134], [74.0973587, 14.8429203], [74.09708405, 14.84291553], [74.09708405, 14.84347153], [74.09680176, 14.84347153], [74.09680176, 14.84486198], [74.0965271, 14.84486198], [74.0965271, 14.84597206], [74.0984726, 14.84597206]]], [[[74.1554184, 14.7418108], [74.1554184, 14.74153137], [74.15598297, 14.74153137], [74.15598297, 14.74125004], [74.15651703, 14.74125004], [74.15651703, 14.74096966], [74.15680695, 14.74097157], [74.15680695, 14.74041557], [74.1570816, 14.74043179], [74.1570816, 14.74013996], [74.15735626, 14.74013996], [74.15735626, 14.73985958], [74.15763855, 14.73986244], [74.15763855, 14.73958397], [74.15791321, 14.73958397], [74.15791321, 14.73930645], [74.15821075, 14.73931122], [74.15821075, 14.73875046], [74.15789795, 14.73875046], [74.15789795, 14.7381916], [74.15763855, 14.73819447], [74.15763855, 14.73791599], [74.15735626, 14.73791981], [74.15735626, 14.73764038], [74.15651703, 14.73764038], [74.15651703, 14.73791981], [74.15625, 14.73791599], [74.15625, 14.73819447], [74.15598297, 14.7381916], [74.15598297, 14.73875046], [74.15569305, 14.73875046], [74.15569305, 14.73903275], [74.1554184, 14.73903275], [74.1554184, 14.73931122], [74.15486145, 14.73930645], [74.15486145, 14.73958397], [74.1543045, 14.73958397], [74.1543045, 14.73986244], [74.15402985, 14.73985958], [74.15402985, 14.74013996], [74.15319824, 14.74013996], [74.15319824, 14.74125004], [74.1534729, 14.74125004], [74.1534729, 14.74153137], [74.15374756, 14.74153137], [74.15374756, 14.7418108], [74.1554184, 14.7418108]]], [[[74.24069214, 14.71125031], [74.24069214, 14.71097183], [74.24097443, 14.71097183], [74.24097443, 14.70986176], [74.24041748, 14.70986176], [74.24041748, 14.70930576], [74.24014282, 14.70930958], [74.24014282, 14.70903015], [74.23958588, 14.70903015], [74.23958588, 14.70874977], [74.23847198, 14.70874977], [74.23847198, 14.70903015], [74.23792267, 14.70903015], [74.23792267, 14.71041965], [74.23819733, 14.71041584], [74.23819733, 14.71069431], [74.23874664, 14.71069431], [74.23874664, 14.71097183], [74.23958588, 14.71097183], [74.23958588, 14.71125031], [74.24069214, 14.71125031]]], [[[74.25375366, 14.70597363], [74.25375366, 14.70569324], [74.25430298, 14.70569324], [74.25430298, 14.70541763], [74.25541687, 14.70541954], [74.25541687, 14.70514202], [74.25514221, 14.70514202], [74.25514221, 14.70486164], [74.25485992, 14.70486164], [74.25485992, 14.70432091], [74.25514221, 14.70432091], [74.25514221, 14.70375156], [74.25374603, 14.70375156], [74.25374603, 14.70432091], [74.25347137, 14.70432091], [74.25347137, 14.70403194], [74.25319672, 14.70403194], [74.25319672, 14.70375156], [74.25235748, 14.70375156], [74.25235748, 14.70403194], [74.25180817, 14.70403194], [74.25180817, 14.70432091], [74.25152588, 14.70432091], [74.25152588, 14.70486164], [74.25180817, 14.70486164], [74.25180817, 14.70514202], [74.25208282, 14.70514202], [74.25208282, 14.70541954], [74.25235748, 14.70541763], [74.25235748, 14.70569324], [74.25263977, 14.70569324], [74.25263977, 14.70597363], [74.25375366, 14.70597363]]], [[[74.40319824, 14.31540108], [74.40319824, 14.31513786], [74.40402985, 14.31514072], [74.40402985, 14.31486034], [74.4043045, 14.31486034], [74.4043045, 14.31458473], [74.40458679, 14.31458473], [74.40458679, 14.31430435], [74.40486908, 14.31431103], [74.40486908, 14.31403065], [74.40513611, 14.31403065], [74.40513611, 14.31319046], [74.40486145, 14.31319427], [74.40486145, 14.3129158], [74.40458679, 14.3129158], [74.40458679, 14.31263828], [74.40402985, 14.31263828], [74.40402985, 14.3129158], [74.40374756, 14.3129158], [74.40374756, 14.31263828], [74.40291595, 14.31264019], [74.40291595, 14.31236172], [74.40235901, 14.31236172], [74.40235901, 14.31208038], [74.40013885, 14.31208038], [74.40013885, 14.31236172], [74.39971924, 14.31236172], [74.39930725, 14.31236172], [74.39930725, 14.31264019], [74.39901733, 14.31264019], [74.39901733, 14.31347179], [74.39958191, 14.31347179], [74.39958191, 14.31375027], [74.40010071, 14.31375027], [74.40040588, 14.31375027], [74.40040588, 14.31403065], [74.4006958, 14.31403065], [74.4006958, 14.31431103], [74.40097046, 14.31430435], [74.40097046, 14.31486034], [74.4015274, 14.31486034], [74.4015274, 14.31513786], [74.40164948, 14.31514835], [74.40180969, 14.31516075], [74.40180969, 14.3154211], [74.40245056, 14.3154211], [74.40299225, 14.3154211], [74.40319824, 14.31540108]]], [[[76.60787201, 11.60044193], [76.60144043, 11.60122108], [76.59671021, 11.6033802], [76.58827972, 11.60435963], [76.58615875, 11.60799026], [76.58096313, 11.60940075], [76.5748291, 11.60571957], [76.56006622, 11.61012077], [76.55362701, 11.61291981], [76.55322266, 11.61953163], [76.54968262, 11.62697124], [76.54705811, 11.6357708], [76.54521942, 11.64825058], [76.54308319, 11.65648079], [76.5430069, 11.66296959], [76.54042053, 11.67050934], [76.53531647, 11.67704105], [76.52468872, 11.68601036], [76.51307678, 11.69419193], [76.50421143, 11.69804096], [76.48781586, 11.68545055], [76.48532104, 11.68234921], [76.47934723, 11.68240166], [76.47377777, 11.68422031], [76.47367859, 11.67813969], [76.46660614, 11.67232132], [76.45136261, 11.6551199], [76.4312973, 11.65657043], [76.42346191, 11.65932083], [76.41757965, 11.66342068], [76.41020966, 11.66456985], [76.40740204, 11.66953087], [76.40219879, 11.68311977], [76.40293884, 11.69948196], [76.39640808, 11.70107937], [76.40310669, 11.70677853], [76.40628815, 11.70359993], [76.40867615, 11.70414925], [76.41108704, 11.70995045], [76.41793823, 11.71358013], [76.41889191, 11.71708107], [76.41899109, 11.7215004], [76.41726685, 11.72593117], [76.41197968, 11.73429108], [76.40558624, 11.73336124], [76.40661621, 11.74063969], [76.4108429, 11.7464819], [76.4076767, 11.75333118], [76.40441895, 11.74985027], [76.39071655, 11.74286938], [76.38376617, 11.74504089], [76.37233734, 11.73620129], [76.35604858, 11.73991108], [76.35114288, 11.73443031], [76.34625244, 11.73050117], [76.34091949, 11.73110008], [76.3349762, 11.73062992], [76.32434845, 11.73873138], [76.31758118, 11.7403717], [76.3105011, 11.7438612], [76.30311584, 11.76957035], [76.29995728, 11.77615166], [76.29469299, 11.7780714], [76.28365326, 11.78486919], [76.27509308, 11.80076027], [76.2720108, 11.80354023], [76.26544952, 11.80041122], [76.25312805, 11.79979992], [76.2443924, 11.79531002], [76.23210907, 11.79646969], [76.21852875, 11.80003929], [76.21431732, 11.80420971], [76.21199036, 11.81427002], [76.205513, 11.81958103], [76.20720673, 11.83176041], [76.20510864, 11.83865929], [76.20342255, 11.84906101], [76.20088959, 11.85412979], [76.19608307, 11.85554123], [76.18403625, 11.8637619], [76.1736908, 11.86244202], [76.16259003, 11.86003113], [76.14942169, 11.86101055], [76.13902283, 11.85711098], [76.1256485, 11.84477043], [76.12043762, 11.84429073], [76.11653137, 11.84304047], [76.10806274, 11.85118103], [76.10932159, 11.85859013], [76.10874939, 11.87059021], [76.10743713, 11.87633991], [76.10865021, 11.9280901], [76.10791016, 11.97063923], [76.09127045, 11.96158886], [76.08100128, 11.96067047], [76.07280731, 11.96128082], [76.06674957, 11.95827103], [76.04775238, 11.94447041], [76.04194641, 11.9433012], [76.03851318, 11.93900013], [76.02958679, 11.93278122], [76.02301788, 11.93465042], [76.01843262, 11.9350214], [76.01390076, 11.93326187], [76.00396729, 11.93192101], [75.99819183, 11.92362118], [75.9944458, 11.9233017], [75.98336792, 11.92544174], [75.9798584, 11.92466927], [75.97627258, 11.92496967], [75.97264862, 11.92755032], [75.9679184, 11.92697144], [75.95887756, 11.92860985], [75.95490265, 11.93151093], [75.94838715, 11.93391132], [75.93718719, 11.93283081], [75.93112183, 11.93111038], [75.92518616, 11.93287182], [75.91963196, 11.93562126], [75.91543579, 11.93402958], [75.90379333, 11.93476963], [75.89444733, 11.9365406], [75.88968658, 11.93814087], [75.88330078, 11.93891239], [75.87674713, 11.94071198], [75.86589813, 11.94563007], [75.85108948, 11.95704174], [75.84657288, 11.96465015], [75.84443665, 11.97027016], [75.83969116, 11.97281075], [75.83058929, 11.97463036], [75.82697296, 11.97797108], [75.8243866, 11.98427963], [75.82359314, 11.99456978], [75.82375336, 11.99456978], [75.82752228, 12.00284958], [75.82662964, 12.00579071], [75.8235321, 12.00933933], [75.81191254, 12.01611042], [75.81199646, 12.02196121], [75.81019592, 12.02406025], [75.79995728, 12.0302906], [75.79815674, 12.03267097], [75.79857635, 12.03966999], [75.79785919, 12.04164124], [75.79325867, 12.04751015], [75.79618073, 12.04949093], [75.80169678, 12.06797886], [75.79968262, 12.0711813], [75.79534912, 12.07423115], [75.7895813, 12.07461071], [75.78370667, 12.07643032], [75.7678833, 12.07752037], [75.76296234, 12.07858181], [75.75813293, 12.07721043], [75.75190735, 12.07740974], [75.74758911, 12.0734396], [75.74294281, 12.07178116], [75.73890686, 12.0721817], [75.73435974, 12.06770134], [75.72805023, 12.06410027], [75.71705627, 12.06208992], [75.71465302, 12.06534195], [75.71420288, 12.06921196], [75.71753693, 12.07745075], [75.71714783, 12.07843113], [75.70652771, 12.08280945], [75.70066071, 12.08353043], [75.70033264, 12.08803082], [75.70159912, 12.10033131], [75.6919632, 12.10258961], [75.68419647, 12.10224056], [75.681633, 12.09657955], [75.67830658, 12.09306145], [75.67273712, 12.09066963], [75.66760254, 12.09000015], [75.66242981, 12.0911808], [75.65822601, 12.09430122], [75.65278625, 12.10130024], [75.65155029, 12.10396194], [75.64807892, 12.10558033], [75.64745331, 12.11475086], [75.64298248, 12.11993027], [75.64433289, 12.12371063], [75.64385223, 12.12707043], [75.64250946, 12.13077164], [75.64068604, 12.13315105], [75.63761902, 12.13377953], [75.63678741, 12.14042091], [75.63508606, 12.1423912], [75.62937164, 12.14161968], [75.6268692, 12.14505005], [75.61708832, 12.14893246], [75.61131287, 12.14586163], [75.60814667, 12.1486702], [75.6020813, 12.1467514], [75.59760284, 12.1465292], [75.59471893, 12.14535999], [75.5931778, 12.14295959], [75.59144592, 12.14304924], [75.58715057, 12.14829063], [75.58271027, 12.15043068], [75.57684326, 12.15075016], [75.57038879, 12.16545963], [75.56384277, 12.16683197], [75.55961609, 12.16867065], [75.55525208, 12.17633057], [75.55240631, 12.17614174], [75.5511322, 12.18444061], [75.54875183, 12.18838978], [75.54386139, 12.19197083], [75.54036713, 12.19237041], [75.53791809, 12.19539165], [75.53373718, 12.19609165], [75.5329895, 12.19909096], [75.53688049, 12.20352173], [75.53804779, 12.20678139], [75.53793335, 12.21105194], [75.52532959, 12.21963024], [75.52482605, 12.22503185], [75.52336121, 12.22887039], [75.51850128, 12.23060036], [75.51994324, 12.23317146], [75.51928711, 12.23593998], [75.51667023, 12.24375057], [75.51307678, 12.24932098], [75.51140594, 12.25043964], [75.5111084, 12.25332069], [75.5038681, 12.25970173], [75.50392914, 12.26315975], [75.50200653, 12.2640419], [75.4940033, 12.265131], [75.49252319, 12.26681995], [75.48670197, 12.28146076], [75.48272705, 12.28618145], [75.46720886, 12.29537964], [75.45836639, 12.28855228], [75.44140625, 12.29001045], [75.43608093, 12.29181099], [75.43073273, 12.29200172], [75.42737579, 12.29067135], [75.42366791, 12.28703976], [75.41912842, 12.28639984], [75.42164612, 12.29096127], [75.43039703, 12.29952145], [75.42990875, 12.30223083], [75.42308044, 12.30814075], [75.41996002, 12.31446075], [75.41985321, 12.31946087], [75.41633606, 12.32147121], [75.41436768, 12.33375072], [75.41117859, 12.33782196], [75.41005707, 12.34134102], [75.41427612, 12.34393024], [75.4177475, 12.34843063], [75.4193573, 12.35254955], [75.4214325, 12.36190128], [75.42138672, 12.36672974], [75.41886902, 12.36952019], [75.41146088, 12.37457085], [75.40336609, 12.37255955], [75.40113831, 12.37570095], [75.39711761, 12.37524128], [75.39433289, 12.37983131], [75.39071655, 12.38344097], [75.38578796, 12.3855896], [75.38117218, 12.38479042], [75.37858582, 12.38667107], [75.3761673, 12.39246178], [75.37219238, 12.39573002], [75.36972046, 12.4017992], [75.36560059, 12.4070406], [75.3705368, 12.42894173], [75.36943817, 12.44563198], [75.3658905, 12.44908047], [75.36662292, 12.45166016], [75.38582611, 12.45070076], [75.39192963, 12.44508934], [75.40349579, 12.44756889], [75.40908051, 12.44985008], [75.41467285, 12.45409203], [75.41677094, 12.45888042], [75.42250824, 12.46006107], [75.42428589, 12.46625137], [75.42053986, 12.4715414], [75.42018127, 12.47966194], [75.41448975, 12.49671173], [75.40892029, 12.49419117], [75.40423584, 12.48960114], [75.40099335, 12.49057198], [75.39731598, 12.49781036], [75.39492798, 12.49755955], [75.39187622, 12.49254131], [75.38656616, 12.49192142], [75.3830719, 12.49265957], [75.381073, 12.49149036], [75.37950897, 12.48787975], [75.37721252, 12.48643112], [75.37223816, 12.48550987], [75.37000275, 12.48346996], [75.37055206, 12.48099041], [75.3730011, 12.47716141], [75.37206268, 12.46878147], [75.36273956, 12.46489143], [75.35941315, 12.45998096], [75.3556366, 12.45802116], [75.34086609, 12.45604992], [75.33676147, 12.45778179], [75.3405304, 12.46463108], [75.33833313, 12.47334194], [75.3393631, 12.47964954], [75.33898926, 12.48294067], [75.33557892, 12.48504925], [75.3348465, 12.49024105], [75.32805634, 12.49177074], [75.32064056, 12.49125099], [75.3141861, 12.49202061], [75.31009674, 12.495821], [75.30735016, 12.49741173], [75.3049469, 12.49675274], [75.30430603, 12.49751186], [75.30465698, 12.51729012], [75.30004883, 12.51689053], [75.29611969, 12.51966], [75.29177094, 12.52069092], [75.28581238, 12.51986122], [75.28114319, 12.51813984], [75.27961731, 12.52338028], [75.27240753, 12.53988075], [75.2709198, 12.55354023], [75.27258301, 12.55886173], [75.27683258, 12.56408978], [75.28349304, 12.56417179], [75.28676605, 12.56499004], [75.29139709, 12.57488155], [75.29496765, 12.57492924], [75.30314636, 12.57349968], [75.30977631, 12.57163239], [75.31619263, 12.56866169], [75.31936646, 12.57374191], [75.3263092, 12.57444191], [75.32846069, 12.57711124], [75.32785797, 12.58518124], [75.31852722, 12.58514023], [75.30825043, 12.58786964], [75.30561829, 12.59492016], [75.30149078, 12.59906101], [75.29833984, 12.59841061], [75.29390717, 12.59554195], [75.2911377, 12.59661961], [75.28885651, 12.60458088], [75.28103638, 12.60802937], [75.27672577, 12.61166], [75.27031708, 12.60898018], [75.26785278, 12.60568047], [75.262146, 12.59300137], [75.25881958, 12.59097004], [75.25617981, 12.58572102], [75.25019836, 12.5791893], [75.24948883, 12.57488155], [75.24003601, 12.57396984], [75.23867798, 12.57250023], [75.2381897, 12.56411266], [75.23629761, 12.56184006], [75.23129272, 12.56082153], [75.22290039, 12.56264019], [75.21691132, 12.57107067], [75.21404266, 12.57341194], [75.21084595, 12.58397961], [75.20752716, 12.58299065], [75.20340729, 12.58057022], [75.2045517, 12.58665085], [75.20749664, 12.58850193], [75.20897675, 12.59154034], [75.20954132, 12.59727192], [75.20729828, 12.59994984], [75.20244598, 12.60272121], [75.19870758, 12.60616016], [75.19946289, 12.61312103], [75.20279694, 12.62307167], [75.20143127, 12.62511063], [75.19438171, 12.62543106], [75.18985748, 12.62705135], [75.18257904, 12.62744141], [75.1774826, 12.62220955], [75.1700058, 12.61655998], [75.16279602, 12.61763954], [75.15917206, 12.61705017], [75.15487671, 12.61958027], [75.14766693, 12.62865067], [75.14296722, 12.63331032], [75.14122009, 12.63782024], [75.15032959, 12.64188957], [75.15123749, 12.64344025], [75.15164948, 12.64936066], [75.1550827, 12.65367985], [75.16129303, 12.66407108], [75.16113281, 12.66567993], [75.15571594, 12.66603088], [75.1506958, 12.66885853], [75.1506424, 12.67634201], [75.14450836, 12.6729002], [75.1391983, 12.67275047], [75.13667297, 12.67117119], [75.13188934, 12.67084026], [75.12689972, 12.67331123], [75.12078857, 12.67356968], [75.1126709, 12.67591095], [75.10865784, 12.68494129], [75.10441589, 12.69155121], [75.09925842, 12.69335079], [75.09163666, 12.69471169], [75.08609772, 12.69778156], [75.08242798, 12.69322968], [75.0849762, 12.68968201], [75.08743286, 12.67596054], [75.08670044, 12.67085075], [75.08490753, 12.67047977], [75.08309174, 12.66640854], [75.079422, 12.6665802], [75.07520294, 12.66543198], [75.07026672, 12.65802002], [75.06600952, 12.65795231], [75.0608902, 12.66148186], [75.05827332, 12.65863132], [75.05531311, 12.66006184], [75.04780579, 12.66008854], [75.04476166, 12.66330147], [75.04309082, 12.67057133], [75.04467773, 12.68744087], [75.04859924, 12.68832111], [75.05213165, 12.6870079], [75.05455017, 12.6835804], [75.05679321, 12.68672085], [75.0521698, 12.69817066], [75.05574799, 12.7034111], [75.05285645, 12.7098217], [75.04966736, 12.71469975], [75.04624176, 12.7163496], [75.04308319, 12.71552944], [75.03811646, 12.71858978], [75.0313797, 12.71695232], [75.0256958, 12.71431923], [75.02295685, 12.71562099], [75.01905823, 12.71475029], [75.01429749, 12.70780087], [75.00708008, 12.70920944], [75.00402832, 12.71172142], [75.00306702, 12.71369171], [75.01085663, 12.71928978], [75.01216888, 12.72284126], [75.00023651, 12.72740078], [74.99304962, 12.73313999], [74.99015045, 12.73110008], [74.98838043, 12.73192978], [74.98693848, 12.72879791], [74.98477936, 12.72988129], [74.98442841, 12.73594093], [74.9860611, 12.73847961], [74.98986053, 12.73728085], [74.99175262, 12.73816967], [74.99529266, 12.74484062], [75.0002594, 12.75155067], [75.00427246, 12.75399017], [75.0071106, 12.75706196], [75.00860596, 12.76043129], [75.00779724, 12.76509094], [75.00522614, 12.76933098], [75.0041275, 12.77355194], [75.00527954, 12.78549194], [75.00393677, 12.78561974], [75.00029755, 12.7834816], [74.9960022, 12.78798103], [74.99228668, 12.79045963], [74.98945618, 12.79081059], [74.98883057, 12.78923035], [74.9925766, 12.78362083], [74.98729706, 12.77792072], [74.98192596, 12.77523994], [74.97067261, 12.77256012], [74.96900177, 12.77292919], [74.96862793, 12.77626133], [74.96726227, 12.77685165], [74.96536255, 12.77480125], [74.96337128, 12.77482986], [74.96025848, 12.77904034], [74.95420074, 12.77928066], [74.93733215, 12.77219105], [74.92935181, 12.77133179], [74.90911102, 12.76303101], [74.90804291, 12.76257133], [74.90509796, 12.75993061], [74.90141296, 12.75953007], [74.89776611, 12.75540066], [74.89453125, 12.7560997], [74.89176178, 12.75452995], [74.8886795, 12.75237179], [74.88559723, 12.74877071], [74.87991333, 12.74927044], [74.87802887, 12.75024128], [74.87766266, 12.7523489], [74.87589264, 12.75529099], [74.86708069, 12.75445175], [74.86708069, 12.75458241], [74.86736298, 12.75457954], [74.86736298, 12.75625134], [74.86708069, 12.75625134], [74.86708069, 12.75764084], [74.86680603, 12.75763893], [74.86680603, 12.75819016], [74.86653137, 12.7582016], [74.86653137, 12.75875092], [74.86624908, 12.75875092], [74.86624908, 12.75931168], [74.86597443, 12.75930691], [74.86597443, 12.75986099], [74.86569214, 12.75984859], [74.86569214, 12.76041889], [74.86541748, 12.76041698], [74.86541748, 12.76069546], [74.86486053, 12.76069546], [74.86486053, 12.76013947], [74.86458588, 12.76014137], [74.86458588, 12.75984859], [74.86429596, 12.75984859], [74.86429596, 12.76041889], [74.86374664, 12.76041698], [74.86374664, 12.76097298], [74.86347198, 12.76097107], [74.86347198, 12.76180935], [74.86319733, 12.76180935], [74.86319733, 12.76264095], [74.86291504, 12.76263905], [74.86291504, 12.76319504], [74.86264038, 12.76319122], [74.86264038, 12.76402855], [74.86235809, 12.76402664], [74.86235809, 12.76458263], [74.86207581, 12.76458073], [74.86207581, 12.76542187], [74.86180878, 12.76542187], [74.86180878, 12.76597977], [74.86152649, 12.76597118], [74.86152649, 12.76615143], [74.86152649, 12.76681042], [74.86125183, 12.7668047], [74.86125183, 12.76705074], [74.86125183, 12.76764202], [74.86096954, 12.76764011], [74.86096954, 12.76796055], [74.86096954, 12.76819324], [74.86069489, 12.76819324], [74.86066437, 12.76885891], [74.86065674, 12.76904106], [74.86042023, 12.76902676], [74.86042023, 12.76935959], [74.86042023, 12.76958084], [74.8601532, 12.76959038], [74.86013794, 12.77042007], [74.85986328, 12.77041531], [74.85986328, 12.77097225], [74.85958099, 12.77096939], [74.85958099, 12.77180958], [74.85930634, 12.77180576], [74.85930634, 12.77236176], [74.85902405, 12.77236176], [74.85902405, 12.77319431], [74.85874939, 12.77319145], [74.85874939, 12.77402973], [74.85847473, 12.77402782], [74.85847473, 12.77458191], [74.85819244, 12.77458191], [74.85819244, 12.77542019], [74.85791779, 12.77542019], [74.85791779, 12.77625179], [74.85764313, 12.77625179], [74.85764313, 12.77681065], [74.85736084, 12.77681065], [74.85736084, 12.77764034], [74.85708618, 12.77764034], [74.85708618, 12.77819443], [74.85679626, 12.77818966], [74.85679626, 12.77875042], [74.85652924, 12.77875042], [74.85652924, 12.77958202], [74.85623932, 12.77958202], [74.85623932, 12.78014088], [74.85597229, 12.78014088], [74.85597229, 12.78098202], [74.85569763, 12.78098202], [74.85569763, 12.78153133], [74.85541534, 12.78152943], [74.85541534, 12.7820816], [74.85514069, 12.7820797], [74.85514069, 12.78264141], [74.8548584, 12.7826376], [74.8548584, 12.78319454], [74.85457611, 12.78318977], [74.85457611, 12.78375053], [74.85430908, 12.78375053], [74.85430908, 12.78431129], [74.85402679, 12.78430462], [74.85402679, 12.78486061], [74.85375214, 12.78486061], [74.85375214, 12.78542137], [74.85346985, 12.7854166], [74.85346985, 12.7859726], [74.85320282, 12.78597069], [74.85320282, 12.78653145], [74.8529129, 12.78652668], [74.8529129, 12.78708267], [74.85263824, 12.7870779], [74.85263824, 12.78764057], [74.85235596, 12.78764057], [74.85235596, 12.78792191], [74.8520813, 12.78791714], [74.8520813, 12.78819466], [74.85180664, 12.78819275], [74.85180664, 12.78875065], [74.85151672, 12.78875065], [74.85151672, 12.78903103], [74.85098267, 12.78903103], [74.85098267, 12.78931046], [74.85069275, 12.78930473], [74.85069275, 12.78958321], [74.85043335, 12.7895813], [74.85043335, 12.79015064], [74.8501358, 12.79015064], [74.8501358, 12.79041862], [74.84958649, 12.79041672], [74.84958649, 12.7909708], [74.8493042, 12.79097271], [74.8493042, 12.79208279], [74.84902954, 12.79208279], [74.84902954, 12.79236126], [74.84874725, 12.79236126], [74.84874725, 12.79264164], [74.8484726, 12.79263878], [74.8484726, 12.79319477], [74.84792328, 12.79319096], [74.84792328, 12.79375172], [74.84764099, 12.79375172], [74.84764099, 12.79403019], [74.84736633, 12.79403019], [74.84736633, 12.79430962], [74.84708405, 12.79430485], [74.84708405, 12.79458332], [74.8465271, 12.79458141], [74.8465271, 12.79514027], [74.84625244, 12.79514027], [74.84625244, 12.79597092], [74.84597015, 12.79596043], [74.84597015, 12.79652977], [74.84570313, 12.79652977], [74.84570313, 12.79681015], [74.84541321, 12.79680634], [74.84541321, 12.79708385], [74.8456955, 12.79708385], [74.8456955, 12.79736233], [74.84541321, 12.79735947], [74.84541321, 12.79763985], [74.84513855, 12.79763985], [74.84513855, 12.79819584], [74.84486389, 12.79819584], [74.84486389, 12.7990284], [74.8445816, 12.79901886], [74.8445816, 12.80014038], [74.84429932, 12.80014038], [74.84429932, 12.80041981], [74.84402466, 12.8004179], [74.84402466, 12.80097198], [74.84375, 12.80097198], [74.84375, 12.80209064], [74.84348297, 12.80209064], [74.84348297, 12.80375004], [74.84319305, 12.80375004], [74.84319305, 12.80458355], [74.8429184, 12.80457973], [74.8429184, 12.80542088], [74.84263611, 12.80541611], [74.84263611, 12.8059721], [74.84236145, 12.80597019], [74.84236145, 12.80681133], [74.84208679, 12.80681133], [74.84208679, 12.80764103], [74.8418045, 12.80763817], [74.8418045, 12.80847168], [74.84152985, 12.80846977], [74.84152985, 12.80903053], [74.84124756, 12.80902863], [74.84124756, 12.80958462], [74.8409729, 12.80957985], [74.8409729, 12.81014061], [74.84069824, 12.8101387], [74.84069824, 12.81097317], [74.84041595, 12.81096077], [74.84041595, 12.81153107], [74.8401413, 12.81152916], [74.8401413, 12.81208324], [74.83985901, 12.81208324], [74.83985901, 12.81236076], [74.8401413, 12.8123579], [74.8401413, 12.81292057], [74.83985901, 12.81292057], [74.83985901, 12.81347275], [74.83957672, 12.81347275], [74.83957672, 12.81375122], [74.83930206, 12.81375122], [74.83930206, 12.8148613], [74.8390274, 12.8148613], [74.8390274, 12.81652927], [74.83875275, 12.81652927], [74.83875275, 12.81763935], [74.8381958, 12.81763935], [74.8381958, 12.81792164], [74.83790588, 12.81792164], [74.83790588, 12.81903172], [74.83763885, 12.81902695], [74.83763885, 12.81986141], [74.83735657, 12.81986141], [74.83735657, 12.82042027], [74.83708191, 12.82042027], [74.83708191, 12.82125187], [74.83680725, 12.82125187], [74.83680725, 12.82153034], [74.83653259, 12.82153034], [74.83653259, 12.82292175], [74.83625031, 12.82292175], [74.83625031, 12.82402992], [74.83597565, 12.82402802], [74.83597565, 12.82458401], [74.83569336, 12.82457924], [74.83569336, 12.82542038], [74.8354187, 12.82541561], [74.8354187, 12.8259716], [74.83513641, 12.8259716], [74.83513641, 12.82625198], [74.83542633, 12.82625198], [74.83542633, 12.82653046], [74.83513641, 12.8265276], [74.83513641, 12.82736206], [74.83486176, 12.82736206], [74.83486176, 12.82847214], [74.8345871, 12.82847023], [74.8345871, 12.82932186], [74.83429718, 12.82932186], [74.83429718, 12.82985973], [74.83403015, 12.82985973], [74.83403015, 12.8306942], [74.83374786, 12.8306942], [74.83374786, 12.8312912], [74.83374786, 12.83181095], [74.83347321, 12.83180618], [74.83347321, 12.8320837], [74.83325195, 12.83211231], [74.83319092, 12.83226204], [74.83319092, 12.83319378], [74.83291626, 12.83319187], [74.83291626, 12.83403111], [74.8326416, 12.83402824], [74.8326416, 12.83458233], [74.8320694, 12.83458042], [74.8320694, 12.83542061], [74.83152771, 12.83541584], [74.83152771, 12.83597279], [74.83125305, 12.83597279], [74.83125305, 12.83736134], [74.83097076, 12.83736134], [74.83097076, 12.83764076], [74.83069611, 12.83763885], [74.83069611, 12.83819485], [74.83040619, 12.83819008], [74.83040619, 12.83931065], [74.83013916, 12.83931065], [74.83013916, 12.8401413], [74.82958221, 12.84013939], [74.82958221, 12.84069538], [74.82929993, 12.84068966], [74.82929993, 12.84125996], [74.8290329, 12.84125996], [74.8290329, 12.84180927], [74.82875061, 12.84180546], [74.82875061, 12.84319496], [74.82847595, 12.84319496], [74.82847595, 12.84347343], [74.82902527, 12.84347343], [74.82902527, 12.84319496], [74.82930756, 12.84319496], [74.82930756, 12.84263897], [74.82985687, 12.84264088], [74.82985687, 12.84291935], [74.82958221, 12.84291935], [74.82958221, 12.84402943], [74.82929993, 12.84402943], [74.82930756, 12.84486103], [74.82902527, 12.84486103], [74.82902527, 12.84569454], [74.82875061, 12.84569073], [74.82875061, 12.84653187], [74.8290329, 12.84653187], [74.8290329, 12.84681034], [74.82763672, 12.84680462], [74.82763672, 12.84708309], [74.82653046, 12.84708309], [74.82653046, 12.84736061], [74.82563782, 12.84736061], [74.82541656, 12.84736061], [74.82541656, 12.84708309], [74.82485962, 12.84708309], [74.82485962, 12.84680462], [74.82430267, 12.84681034], [74.82430267, 12.84653187], [74.82375336, 12.8465271], [74.82375336, 12.84708309], [74.82347107, 12.84708309], [74.82347107, 12.84819317], [74.82319641, 12.84819126], [74.82319641, 12.84930992], [74.82291412, 12.84930515], [74.82291412, 12.84958363], [74.82263947, 12.84957886], [74.82263947, 12.85042], [74.82236481, 12.85041809], [74.82236481, 12.85097218], [74.82180786, 12.85096931], [74.82180786, 12.85124969], [74.82152557, 12.85124969], [74.82152557, 12.85208416], [74.82125092, 12.8520813], [74.82125092, 12.85236168], [74.82096863, 12.85236168], [74.82096863, 12.85291958], [74.82125092, 12.85291958], [74.82125092, 12.85681057], [74.82096863, 12.8568058], [74.82096863, 12.85847187], [74.82069397, 12.85847187], [74.82069397, 12.85930634], [74.82041931, 12.85929871], [74.82041931, 12.86042118], [74.82013702, 12.86041641], [74.82013702, 12.8609724], [74.81986237, 12.86096954], [74.81986237, 12.86264133], [74.81958008, 12.86264133], [74.81958008, 12.86292076], [74.81986237, 12.86291599], [74.81986237, 12.86319542], [74.81958008, 12.8631897], [74.81958008, 12.86375141], [74.81930542, 12.86375141], [74.81930542, 12.86458302], [74.81903076, 12.86458015], [74.81903076, 12.86680889], [74.81874847, 12.86680698], [74.81874847, 12.8670826], [74.81846619, 12.86707973], [74.81846619, 12.86764145], [74.81819153, 12.86764145], [74.81819153, 12.86875057], [74.81838226, 12.86874866], [74.81847382, 12.86874866], [74.81846619, 12.87014103], [74.81819153, 12.87014103], [74.81819153, 12.87041855], [74.81791687, 12.87041664], [74.81791687, 12.87069511], [74.81819153, 12.87069511], [74.81819153, 12.87208271], [74.81791687, 12.87208271], [74.81791687, 12.87236118], [74.81764221, 12.87236118], [74.81764221, 12.87292194], [74.81735992, 12.87292194], [74.81735992, 12.87375069], [74.81764221, 12.87374878], [74.81764221, 12.87569332], [74.81735992, 12.87569332], [74.81735992, 12.87662983], [74.81735992, 12.87681007], [74.81708527, 12.87680626], [74.8170929, 12.87721062], [74.8170929, 12.87737083], [74.81680298, 12.87737083], [74.81680298, 12.87763977], [74.81652832, 12.87763977], [74.81652832, 12.87837124], [74.81652832, 12.87903023], [74.81624603, 12.87903023], [74.81624603, 12.8801403], [74.81597137, 12.8801403], [74.81597137, 12.88208389], [74.81569672, 12.88208199], [74.81569672, 12.88431072], [74.8154068, 12.88431072], [74.8154068, 12.8854208], [74.81513977, 12.88541603], [74.81513977, 12.88569355], [74.81541443, 12.88569355], [74.81541443, 12.88597202], [74.81513977, 12.88597202], [74.81513977, 12.88624954], [74.81485748, 12.88624096], [74.81485748, 12.88681126], [74.81458282, 12.88680553], [74.81458282, 12.88736153], [74.8143158, 12.88735962], [74.8143158, 12.88764095], [74.81402588, 12.88763809], [74.81402588, 12.88958454], [74.81375122, 12.88957977], [74.81375122, 12.89042091], [74.81402588, 12.8904171], [74.81402588, 12.89097309], [74.81375122, 12.89097309], [74.81375122, 12.89208317], [74.81346893, 12.89208317], [74.81346893, 12.89347267], [74.81318665, 12.8934679], [74.81318665, 12.89403057], [74.81291962, 12.89403057], [74.81291962, 12.8965292], [74.81263733, 12.8965292], [74.81263733, 12.89763927], [74.81236267, 12.89763927], [74.81236267, 12.89819527], [74.81208038, 12.89818192], [74.81208038, 12.89903164], [74.81180573, 12.89902687], [74.81180573, 12.90069485], [74.81153107, 12.90069103], [74.81153107, 12.90180969], [74.81124878, 12.90180492], [74.81124878, 12.9020834], [74.81096649, 12.90208054], [74.81096649, 12.90264034], [74.81069183, 12.90264034], [74.81069183, 12.90347099], [74.81096649, 12.90347099], [74.81096649, 12.90374947], [74.81069183, 12.90374947], [74.81069183, 12.90513992], [74.81097412, 12.90513992], [74.81097412, 12.90597153], [74.81041718, 12.90597153], [74.81041718, 12.90736198], [74.80986023, 12.90736198], [74.80986023, 12.91097164], [74.8095932, 12.91096973], [74.8095932, 12.91125011], [74.80930328, 12.91125011], [74.80930328, 12.91181087], [74.80902863, 12.91181087], [74.80902863, 12.91348076], [74.80874634, 12.91348076], [74.80874634, 12.91374969], [74.80847168, 12.91374969], [74.80847168, 12.91485977], [74.80818939, 12.91485977], [74.80818939, 12.91625118], [74.80791473, 12.91625118], [74.80791473, 12.91708469], [74.80764008, 12.91708469], [74.80764008, 12.91736031], [74.80791473, 12.91736031], [74.80791473, 12.91819477], [74.80764008, 12.91819], [74.80764008, 12.91875076], [74.80735779, 12.91875076], [74.80735779, 12.91903114], [74.80708313, 12.91903114], [74.80708313, 12.91931057], [74.80680847, 12.91930676], [74.80680847, 12.92097282], [74.80708313, 12.92097092], [74.80708313, 12.9212513], [74.80735779, 12.9212513], [74.80735779, 12.92153072], [74.80764008, 12.92152691], [74.80764008, 12.9220829], [74.80791473, 12.9220829], [74.80791473, 12.92236137], [74.80764008, 12.92236137], [74.80764008, 12.92458344], [74.80902863, 12.92458344], [74.80902863, 12.92430496], [74.8095932, 12.92430973], [74.8095932, 12.92402935], [74.80986023, 12.92402935], [74.80986023, 12.92347145], [74.81041718, 12.92347336], [74.81041718, 12.92263889], [74.81069183, 12.92263889], [74.81069183, 12.92208099], [74.81097412, 12.9220829], [74.81097412, 12.92152691], [74.81125641, 12.92153072], [74.81125641, 12.92068958], [74.81153107, 12.9206953], [74.81153107, 12.92013931], [74.81181335, 12.92014122], [74.81181335, 12.91958046], [74.81208038, 12.91958332], [74.81208038, 12.91902733], [74.81236267, 12.91903114], [74.81236267, 12.91875076], [74.81291962, 12.91875076], [74.81291962, 12.91847038], [74.81375122, 12.91847038], [74.81375122, 12.91903114], [74.81402588, 12.91902733], [74.81402588, 12.9206953], [74.81430817, 12.9206953], [74.8143158, 12.9212513], [74.81402588, 12.9212513], [74.81402588, 12.92153072], [74.81375122, 12.92152691], [74.81375122, 12.92236137], [74.8143158, 12.92235184], [74.8143158, 12.92291927], [74.81541443, 12.92291737], [74.81541443, 12.92319489], [74.81569672, 12.92319489], [74.81569672, 12.92347336], [74.81597137, 12.92347145], [74.81597137, 12.92375088], [74.81624603, 12.92375088], [74.81624603, 12.92402935], [74.81652832, 12.92402935], [74.81652832, 12.92430973], [74.81680298, 12.92430496], [74.81680298, 12.92458344], [74.81735992, 12.92458057], [74.81735992, 12.92486095], [74.81764221, 12.92486095], [74.81764221, 12.92514133], [74.81791687, 12.92514133], [74.81791687, 12.92542171], [74.81819153, 12.92541695], [74.81819153, 12.92569542], [74.81847382, 12.92569542], [74.81847382, 12.92597103], [74.81874847, 12.92597103], [74.81874847, 12.92625141], [74.81931305, 12.92625141], [74.81931305, 12.92653179], [74.81958008, 12.92653179], [74.81958008, 12.92681026], [74.81986237, 12.92680454], [74.81986237, 12.92708302], [74.82013702, 12.92708302], [74.82013702, 12.92736053], [74.82041931, 12.92736053], [74.82041931, 12.92764187], [74.82068634, 12.92764187], [74.82068634, 12.92792034], [74.82096863, 12.92792034], [74.82096863, 12.92931175], [74.82068634, 12.92931175], [74.82068634, 12.92986202], [74.82041931, 12.92986202], [74.82041931, 12.93041992], [74.82013702, 12.93041801], [74.82013702, 12.93069553], [74.81930542, 12.93069553], [74.81930542, 12.93041801], [74.81819153, 12.93041801], [74.81819153, 12.93097115], [74.81791687, 12.93096924], [74.81791687, 12.93124962], [74.81735992, 12.93124962], [74.81735992, 12.93096924], [74.81708527, 12.93097115], [74.81708527, 12.93069553], [74.81680298, 12.93069553], [74.81680298, 12.93041801], [74.8170929, 12.93041992], [74.8170929, 12.92986202], [74.81680298, 12.92986202], [74.81680298, 12.92958069], [74.81624603, 12.92958069], [74.81624603, 12.92986202], [74.8154068, 12.92986202], [74.8154068, 12.93013954], [74.81485748, 12.93013954], [74.81485748, 12.93041992], [74.81458282, 12.93041801], [74.81458282, 12.93069553], [74.81375122, 12.93069553], [74.81375122, 12.93097115], [74.81319427, 12.93097115], [74.81319427, 12.93069553], [74.81236267, 12.93069553], [74.81236267, 12.93041801], [74.81153107, 12.93041992], [74.81153107, 12.93013954], [74.81096649, 12.93013954], [74.81096649, 12.92986202], [74.81069183, 12.92986202], [74.81069183, 12.92958069], [74.80902863, 12.9295826], [74.80902863, 12.92930508], [74.80847168, 12.92931175], [74.80847168, 12.92903042], [74.80764008, 12.92903042], [74.80764008, 12.92875195], [74.80708313, 12.92875195], [74.80708313, 12.92819118], [74.80680847, 12.92819118], [74.80680847, 12.92848015], [74.80652618, 12.92848015], [74.80652618, 12.92903042], [74.80625153, 12.92903042], [74.80625153, 12.92986202], [74.80596924, 12.92986202], [74.80596924, 12.93069553], [74.80569458, 12.93069553], [74.80569458, 12.93097115], [74.80513, 12.93096924], [74.80513, 12.93124962], [74.80430603, 12.93124962], [74.80430603, 12.93096924], [74.80347443, 12.93097115], [74.80347443, 12.93069553], [74.80291748, 12.93068886], [74.80291748, 12.93124962], [74.80236053, 12.93124962], [74.80236053, 12.93181038], [74.80291748, 12.93180561], [74.80291748, 12.93208408], [74.80319214, 12.93207932], [74.80319214, 12.9323616], [74.80347443, 12.9323616], [74.80347443, 12.93319416], [74.80374908, 12.93319416], [74.80374908, 12.93347168], [74.80403137, 12.93347168], [74.80403137, 12.93375015], [74.80430603, 12.93375015], [74.80430603, 12.93513966], [74.80403137, 12.93513775], [74.80403137, 12.9370842], [74.80374908, 12.93708038], [74.80374908, 12.93875027], [74.8034668, 12.93875027], [74.8034668, 12.94013977], [74.80319214, 12.94013977], [74.80319214, 12.94153118], [74.80291748, 12.94152832], [74.80291748, 12.94319439], [74.80263519, 12.94319439], [74.80263519, 12.94458199], [74.80236053, 12.94458199], [74.80236053, 12.9459734], [74.80208588, 12.94596958], [74.80208588, 12.94764137], [74.80179596, 12.94764137], [74.80179596, 12.94903088], [74.80152893, 12.94902897], [74.80152893, 12.95069504], [74.80124664, 12.95069504], [74.80124664, 12.95208263], [74.80097198, 12.95208263], [74.80097198, 12.95347118], [74.80069733, 12.95347118], [74.80069733, 12.95397854], [74.80069733, 12.95514202], [74.80041504, 12.95513916], [74.80041504, 12.95555019], [74.80042267, 12.95652962], [74.80014038, 12.95652676], [74.80014038, 12.95678043], [74.80014038, 12.95792007], [74.79985809, 12.95791531], [74.79985809, 12.95804977], [74.79985809, 12.95958424], [74.79958344, 12.95958424], [74.79958344, 12.96097183], [74.79931641, 12.96097183], [74.79931641, 12.96263981], [74.79902649, 12.96263981], [74.79902649, 12.96403027], [74.79875183, 12.96402836], [74.79875183, 12.96569443], [74.79846954, 12.96569443], [74.79846954, 12.96708202], [74.79819489, 12.96708202], [74.79819489, 12.96847153], [74.79792023, 12.96846962], [74.79792023, 12.97014141], [74.79763794, 12.97014141], [74.79763794, 12.97153091], [74.79736328, 12.97152901], [74.79736328, 12.97319508], [74.79708099, 12.97319031], [74.79708099, 12.97431183], [74.79680634, 12.97431183], [74.79680634, 12.97514057], [74.79652405, 12.97513866], [74.79652405, 12.97597313], [74.79624939, 12.97597313], [74.79624939, 12.97708321], [74.79597473, 12.97708321], [74.79597473, 12.9784708], [74.79569244, 12.9784708], [74.79569244, 12.97931194], [74.79541779, 12.97930527], [74.79541779, 12.98097134], [74.7951355, 12.98097134], [74.7951355, 12.98263931], [74.79486084, 12.98262978], [74.79486084, 12.98431015], [74.79458618, 12.98430634], [74.79458618, 12.9859724], [74.79430389, 12.9859724], [74.79430389, 12.98819447], [74.79402924, 12.98819065], [74.79402924, 12.98903179], [74.79374695, 12.98903179], [74.79374695, 12.99013996], [74.79347229, 12.99013996], [74.79347229, 12.99125004], [74.79319, 12.99125004], [74.79319763, 12.99236012], [74.79291534, 12.99236012], [74.79291534, 12.99319363], [74.79264069, 12.99319172], [74.79264069, 12.99431133], [74.79250336, 12.99430561], [74.7923584, 12.99431133], [74.7923584, 12.99542141], [74.79207611, 12.99542141], [74.79207611, 12.99625015], [74.79180908, 12.99625015], [74.79180908, 12.99736023], [74.79152679, 12.99736023], [74.79152679, 12.99847317], [74.79125214, 12.99847317], [74.79125214, 12.99958324], [74.79096985, 12.99958038], [74.79096985, 13.00014114], [74.79070282, 13.00014114], [74.79070282, 13.00042057], [74.7904129, 13.00042057], [74.7904129, 13.0007019], [74.79014587, 13.0007019], [74.79014587, 13.00153065], [74.7904129, 13.00152683], [74.7904129, 13.0023613], [74.79013824, 13.0023613], [74.79013824, 13.00347328], [74.7895813, 13.00347137], [74.7895813, 13.00376034], [74.78930664, 13.00374889], [74.78930664, 13.00569534], [74.78901672, 13.00569057], [74.78901672, 13.00764179], [74.78874969, 13.00764179], [74.78874969, 13.00875187], [74.78847504, 13.00874901], [74.78847504, 13.0106926], [74.78791809, 13.0106926], [74.78791809, 13.0134716], [74.7876358, 13.0134716], [74.7876358, 13.01403046], [74.78775787, 13.01403046], [74.78791809, 13.0140276], [74.78791809, 13.01458359], [74.7876358, 13.01458168], [74.7876358, 13.01570129], [74.78736115, 13.01569366], [74.78736115, 13.01708412], [74.78708649, 13.01708031], [74.78708649, 13.01764011], [74.78679657, 13.01764011], [74.78679657, 13.01931095], [74.78652954, 13.01930618], [74.78652954, 13.01986217], [74.78624725, 13.01986217], [74.78624725, 13.02208233], [74.7859726, 13.02208042], [74.7859726, 13.02292061], [74.78569794, 13.02291584], [74.78569794, 13.02458191], [74.78542328, 13.02458], [74.78542328, 13.02625084], [74.78514099, 13.02625084], [74.78514099, 13.02736092], [74.7848587, 13.02736092], [74.7848587, 13.02875137], [74.78458405, 13.02875137], [74.78458405, 13.03069496], [74.78430939, 13.03068066], [74.78430176, 13.03181171], [74.7840271, 13.03181171], [74.7840271, 13.03292179], [74.78375244, 13.03292179], [74.78375244, 13.03403187], [74.78347015, 13.0340271], [74.78347015, 13.03486061], [74.78320312, 13.03486061], [74.78320312, 13.03652954], [74.78291321, 13.03652668], [74.78291321, 13.03847122], [74.78263855, 13.03847122], [74.78263855, 13.03958416], [74.78235626, 13.0395813], [74.78235626, 13.04041958], [74.7820816, 13.04041767], [74.7820816, 13.04097176], [74.78180695, 13.04096889], [74.78180695, 13.04125023], [74.7820816, 13.04125023], [74.7820816, 13.04152966], [74.78180695, 13.04152966], [74.78180695, 13.04181004], [74.7820816, 13.04180622], [74.7820816, 13.04208374], [74.78180695, 13.04208374], [74.78180695, 13.04347229], [74.78152466, 13.04347229], [74.78152466, 13.04458427], [74.78125, 13.04458046], [74.78125, 13.04514027], [74.78098297, 13.04514027], [74.78098297, 13.04542065], [74.78125, 13.04541588], [74.78125, 13.04569435], [74.78097534, 13.04569435], [74.78097534, 13.04708195], [74.78069305, 13.04708195], [74.78069305, 13.04819393], [74.7804184, 13.04819202], [74.7804184, 13.04986], [74.78013611, 13.04986], [74.78013611, 13.05069447], [74.77986145, 13.05069447], [74.77986145, 13.05097294], [74.78013611, 13.05097294], [74.78013611, 13.05236053], [74.77958679, 13.05236053], [74.77958679, 13.05264091], [74.77929688, 13.05264091], [74.77929688, 13.0529213], [74.77986145, 13.05291653], [74.77986145, 13.05347347], [74.77958679, 13.05346966], [74.77958679, 13.05403137], [74.77929688, 13.05403137], [74.77929688, 13.05430889], [74.77902985, 13.05430698], [74.77902985, 13.0570507], [74.77902985, 13.05791664], [74.77874756, 13.05791664], [74.77874756, 13.05847263], [74.7784729, 13.05847073], [74.7784729, 13.06042194], [74.77819824, 13.06041718], [74.77819824, 13.06208324], [74.77791595, 13.06208134], [74.77791595, 13.06263924], [74.77820587, 13.06263924], [74.77820587, 13.06431007], [74.77791595, 13.06430531], [74.77791595, 13.06486225], [74.7776413, 13.06485939], [74.7776413, 13.06542015], [74.77735901, 13.06541538], [74.77735901, 13.06597233], [74.77707672, 13.06597233], [74.77707672, 13.06653023], [74.77680206, 13.06653023], [74.77680206, 13.0676403], [74.7765274, 13.0676403], [74.7765274, 13.06931019], [74.77625275, 13.06930637], [74.77625275, 13.0707798], [74.77625275, 13.07097244], [74.77597046, 13.07097244], [74.77597046, 13.07116127], [74.77597046, 13.07319355], [74.7756958, 13.07319164], [74.7756958, 13.07374954], [74.77541351, 13.07374954], [74.77541351, 13.07569408], [74.77513885, 13.07569408], [74.77513885, 13.07708454], [74.77485657, 13.07707977], [74.77485657, 13.07764053], [74.77458191, 13.07763767], [74.77458191, 13.07819462], [74.7765274, 13.07819462], [74.7765274, 13.07736015], [74.77680206, 13.07736015], [74.77680206, 13.07708454], [74.7765274, 13.07708454], [74.7765274, 13.0765276], [74.77680206, 13.07653141], [74.77680206, 13.07625008], [74.77707672, 13.07625008], [74.77707672, 13.07514], [74.77735901, 13.07514], [74.77735901, 13.07403088], [74.7776413, 13.07403088], [74.7776413, 13.07319164], [74.77791595, 13.07319355], [74.77791595, 13.07263756], [74.77819061, 13.07264042], [74.77820587, 13.07236004], [74.7784729, 13.07236004], [74.7784729, 13.07207966], [74.77874756, 13.07208443], [74.77874756, 13.07152843], [74.77902985, 13.07153034], [74.77902985, 13.07124996], [74.77929688, 13.07124996], [74.77929688, 13.0706892], [74.77958679, 13.07069397], [74.77958679, 13.06492138], [74.77958679, 13.06458378], [74.77971649, 13.06458378], [74.77986145, 13.06458378], [74.77986145, 13.06419182], [74.77986145, 13.06263924], [74.78013611, 13.06263924], [74.78013611, 13.06208134], [74.7804184, 13.06208324], [74.7804184, 13.06152725], [74.78069305, 13.06153202], [74.78069305, 13.06125069], [74.78096008, 13.06122017], [74.78097534, 13.06097126], [74.78125, 13.06097126], [74.78125, 13.06041718], [74.78180695, 13.06042194], [74.78180695, 13.06014061], [74.7820816, 13.06014061], [74.7820816, 13.05986118], [74.78236389, 13.05986118], [74.78236389, 13.05958271], [74.78263855, 13.05958271], [74.78263855, 13.05930519], [74.78320312, 13.05931187], [74.78320312, 13.05903244], [74.78424072, 13.05903244], [74.78430939, 13.05931187], [74.78457642, 13.05931187], [74.78457642, 13.06042194], [74.78443146, 13.06041718], [74.78430939, 13.06041718], [74.78430176, 13.06097126], [74.7840271, 13.06097126], [74.7840271, 13.06125069], [74.78375244, 13.06125069], [74.78375244, 13.06153202], [74.78320312, 13.06153202], [74.78320312, 13.06180954], [74.78291321, 13.06180954], [74.78291321, 13.06236076], [74.78263855, 13.06236076], [74.78263855, 13.06263924], [74.78236389, 13.06263924], [74.78236389, 13.06319332], [74.7820816, 13.06319141], [74.7820816, 13.06374931], [74.78151703, 13.06374931], [74.78151703, 13.06404114], [74.78098297, 13.06404114], [74.78098297, 13.06431007], [74.78069305, 13.06431007], [74.78069305, 13.06513977], [74.78125, 13.06513977], [74.78125, 13.06597233], [74.78152466, 13.06597233], [74.78152466, 13.06708431], [74.78125, 13.06708145], [74.78125, 13.0676403], [74.78097534, 13.0676403], [74.78097534, 13.06847191], [74.78069305, 13.06847191], [74.78069305, 13.06986237], [74.7804184, 13.06986237], [74.7804184, 13.07097244], [74.78013611, 13.07096958], [74.78013611, 13.07153034], [74.77986145, 13.07152843], [74.77986145, 13.07208443], [74.77958679, 13.07207966], [74.77958679, 13.07264042], [74.7793045, 13.07263756], [74.7793045, 13.07319355], [74.77958679, 13.07319355], [74.77958679, 13.07347202], [74.77929688, 13.07347202], [74.77929688, 13.07431126], [74.77902985, 13.07430553], [74.77902985, 13.07569408], [74.77874756, 13.07569027], [74.77874756, 13.07597923], [74.7784729, 13.0759716], [74.7784729, 13.07819462], [74.77874756, 13.07819462], [74.77874756, 13.07847309], [74.77902985, 13.07847309], [74.77902985, 13.07958317], [74.77929688, 13.07958031], [74.77929688, 13.07986069], [74.77902985, 13.07986069], [74.77902985, 13.08125114], [74.7793045, 13.08125114], [74.7793045, 13.08208275], [74.77902985, 13.08208275], [74.77902985, 13.08236122], [74.7793045, 13.08236122], [74.7793045, 13.08319473], [74.77958679, 13.08319473], [74.77958679, 13.08347321], [74.77986145, 13.0834713], [74.77986145, 13.08375072], [74.78013611, 13.08374882], [74.78013611, 13.08458328], [74.7804184, 13.08458328], [74.7804184, 13.0848608], [74.78069305, 13.0848608], [74.78069305, 13.08597088], [74.78098297, 13.08597088], [74.78098297, 13.08653164], [74.7811203, 13.08652878], [74.78125, 13.08652687], [74.78125, 13.08708286], [74.78152466, 13.08708286], [74.78152466, 13.08736134], [74.78180695, 13.08736134], [74.78180695, 13.08792019], [74.7820816, 13.08791733], [74.7820816, 13.08819485], [74.78236389, 13.08819485], [74.78235626, 13.0890913], [74.78235626, 13.08986092], [74.7820816, 13.08986092], [74.7820816, 13.09097958], [74.78180695, 13.09097958], [74.78180695, 13.09124947], [74.78151703, 13.09124947], [74.78151703, 13.09181023], [74.78125, 13.09180641], [74.78125, 13.0923624], [74.78098297, 13.0923624], [74.78098297, 13.09264183], [74.7804184, 13.09263992], [74.7804184, 13.09319401], [74.78013611, 13.09319401], [74.78013611, 13.09347153], [74.77986145, 13.09347153], [74.77986145, 13.09458447], [74.77958679, 13.0945816], [74.77958679, 13.09681129], [74.77986145, 13.09681129], [74.77986145, 13.09792042], [74.78013611, 13.09791565], [74.78013611, 13.09819412], [74.7804184, 13.09818935], [74.7804184, 13.09875011], [74.78069305, 13.09875011], [74.78069305, 13.09908962], [74.78069305, 13.09931087], [74.78125, 13.09930611], [74.78125, 13.09958363], [74.78272247, 13.09958363], [74.78391266, 13.09958363], [74.78430176, 13.09958363], [74.78430176, 13.09930611], [74.7848587, 13.09931087], [74.7848587, 13.09902954], [74.78542328, 13.09902954], [74.78542328, 13.09875011], [74.78624725, 13.09875011], [74.78624725, 13.09846973], [74.7868042, 13.09847164], [74.7868042, 13.09819412], [74.78736115, 13.09819412], [74.78736115, 13.09791565], [74.7895813, 13.09792042], [74.7895813, 13.09875011], [74.78736115, 13.09875011], [74.78736115, 13.09902954], [74.78679657, 13.09902954], [74.78679657, 13.09931087], [74.78624725, 13.09930611], [74.78624725, 13.09957123], [74.78541565, 13.09958363], [74.78541565, 13.0998621], [74.7848587, 13.09986019], [74.7848587, 13.10015202], [74.78430939, 13.10015202], [74.78430176, 13.10042095], [74.78125, 13.10042095], [74.78125, 13.10015202], [74.78069305, 13.10015202], [74.78069305, 13.09986019], [74.78013611, 13.0998621], [74.78013611, 13.09958363], [74.77986145, 13.09958363], [74.77986145, 13.09930611], [74.7784729, 13.09931087], [74.7784729, 13.09875011], [74.77820587, 13.09875011], [74.77819061, 13.09818935], [74.77791595, 13.09819412], [74.77791595, 13.09736156], [74.77803802, 13.09736156], [74.77819061, 13.09735966], [74.77819061, 13.09624958], [74.77791595, 13.09624958], [74.77791595, 13.09514046], [74.77819061, 13.09514046], [74.77819061, 13.09486198], [74.77791595, 13.09486198], [74.77791595, 13.09319115], [74.77819061, 13.09319401], [74.77819824, 13.09263992], [74.7784729, 13.09264183], [74.7784729, 13.09208107], [74.77902985, 13.09208393], [74.77902985, 13.09180641], [74.77929688, 13.09181023], [74.77929688, 13.09097958], [74.77958679, 13.09097958], [74.77958679, 13.09069061], [74.77986145, 13.09069347], [74.77986145, 13.08986092], [74.78013611, 13.08986092], [74.78013611, 13.08958054], [74.77986145, 13.0895834], [74.77986145, 13.08930492], [74.77958679, 13.08930969], [74.77958679, 13.08819103], [74.7793045, 13.08819485], [74.7793045, 13.08625126], [74.77902985, 13.08625126], [74.77902985, 13.08569145], [74.7784729, 13.08569527], [74.7784729, 13.08541679], [74.77819824, 13.08541679], [74.77819824, 13.08569527], [74.77791595, 13.08569527], [74.77791595, 13.08597088], [74.77708435, 13.08597088], [74.77708435, 13.08541679], [74.7765274, 13.08542156], [74.7765274, 13.08458138], [74.77625275, 13.08458328], [74.77625275, 13.08152676], [74.77597046, 13.08153057], [74.77597046, 13.0818119], [74.7756958, 13.08180523], [74.7756958, 13.08208275], [74.77514648, 13.08208275], [74.77514648, 13.08264065], [74.77430725, 13.08263874], [74.77430725, 13.08283043], [74.77430725, 13.08291721], [74.77402496, 13.08291721], [74.77402496, 13.08319473], [74.77348328, 13.08318996], [74.77348328, 13.08375072], [74.77319336, 13.08374882], [74.77319336, 13.08458328], [74.7729187, 13.08458138], [74.7729187, 13.08542156], [74.77263641, 13.08542156], [74.77263641, 13.08625126], [74.77236176, 13.08625126], [74.77236176, 13.08736134], [74.7720871, 13.08736134], [74.7720871, 13.0895834], [74.77179718, 13.08958054], [74.77179718, 13.09013939], [74.77153015, 13.09013939], [74.77153015, 13.09069347], [74.77124786, 13.09069061], [74.77124786, 13.09181023], [74.77097321, 13.09180641], [74.77097321, 13.0923624], [74.77069092, 13.0923624], [74.77069092, 13.09375191], [74.77041626, 13.09375191], [74.77041626, 13.09430981], [74.7701416, 13.09430981], [74.7701416, 13.09486198], [74.76985931, 13.09486198], [74.76985931, 13.09542274], [74.76958466, 13.09541798], [74.76958466, 13.09708405], [74.76930237, 13.09707928], [74.76930237, 13.09931087], [74.76902008, 13.09931087], [74.76902008, 13.10042095], [74.76875305, 13.10042095], [74.76875305, 13.10124969], [74.76847076, 13.10124969], [74.76847076, 13.10153103], [74.76819611, 13.10152817], [74.76819611, 13.10208225], [74.76847076, 13.10208225], [74.76847076, 13.10319424], [74.76819611, 13.10319042], [74.76819611, 13.10375023], [74.76790619, 13.10375023], [74.76790619, 13.10514069], [74.76763916, 13.10513783], [74.76763916, 13.10708332], [74.7673645, 13.10708332], [74.7673645, 13.1081953], [74.76708221, 13.10818958], [74.76708221, 13.1093092], [74.76680756, 13.10930538], [74.76680756, 13.11069489], [74.7665329, 13.11069012], [74.7665329, 13.11181164], [74.76625061, 13.11180496], [74.76625061, 13.11319542], [74.76597595, 13.11319065], [74.76597595, 13.11431026], [74.76568604, 13.11431026], [74.76568604, 13.11542034], [74.76541901, 13.11541653], [74.76541901, 13.11597347], [74.76513672, 13.11597061], [74.76513672, 13.11681175], [74.76486206, 13.11681175], [74.76486206, 13.11736107], [74.76457977, 13.11736107], [74.76457977, 13.11958408], [74.76431274, 13.11958122], [74.76431274, 13.12180996], [74.76403046, 13.12180996], [74.76403046, 13.12263966], [74.76374817, 13.12263966], [74.76374817, 13.12374973], [74.76347351, 13.12374973], [74.76347351, 13.1245842], [74.76319122, 13.12457943], [74.76319122, 13.12541962], [74.76291656, 13.12541962], [74.76291656, 13.12652969], [74.76264191, 13.12652779], [74.76264191, 13.12736225], [74.76235962, 13.12736225], [74.76235962, 13.13069439], [74.76208496, 13.13069439], [74.76208496, 13.13097191], [74.76180267, 13.13097], [74.76180267, 13.13125134], [74.76152802, 13.13125134], [74.76152802, 13.1334734], [74.76125336, 13.13346958], [74.76125336, 13.13431072], [74.76097107, 13.13431072], [74.76097107, 13.13486099], [74.76069641, 13.13486099], [74.76069641, 13.13625145], [74.76040649, 13.13625145], [74.76040649, 13.13875103], [74.76014709, 13.13875103], [74.76014709, 13.13932133], [74.75986481, 13.13930511], [74.75986481, 13.14097118], [74.75958252, 13.14097118], [74.75958252, 13.14208317], [74.75930786, 13.14208317], [74.75930786, 13.14319324], [74.7590332, 13.14319134], [74.7590332, 13.14402962], [74.75875092, 13.14402676], [74.75875092, 13.14458275], [74.75846863, 13.14458275], [74.75846863, 13.14708424], [74.75791931, 13.14708424], [74.75791931, 13.15069389], [74.75763702, 13.15069199], [74.75763702, 13.15153027], [74.75736237, 13.15153027], [74.75736237, 13.15235996], [74.75708008, 13.15235996], [74.75708008, 13.15254021], [74.75708008, 13.15347195], [74.75695801, 13.15347195], [74.75680542, 13.15347195], [74.75680542, 13.15468025], [74.75680542, 13.1548624], [74.75653076, 13.1548624], [74.75653076, 13.15569401], [74.75624847, 13.15569019], [74.75624847, 13.15653133], [74.75596619, 13.15653133], [74.75596619, 13.15792084], [74.75569153, 13.15792084], [74.75569153, 13.15875053], [74.75541687, 13.15875053], [74.75541687, 13.15986061], [74.75514221, 13.15986061], [74.75514221, 13.16069508], [74.75485992, 13.16069031], [74.75485992, 13.16292095], [74.7545929, 13.16292095], [74.7545929, 13.16375065], [74.75430298, 13.16374874], [74.75430298, 13.16458321], [74.75402069, 13.1645813], [74.75402069, 13.16542244], [74.75374603, 13.16542244], [74.75374603, 13.16625977], [74.75347137, 13.16625118], [74.75347137, 13.16736126], [74.75319672, 13.16736126], [74.75319672, 13.16819477], [74.75291443, 13.16819477], [74.75291443, 13.16930485], [74.75263977, 13.16930103], [74.75263977, 13.16986084], [74.75235748, 13.16986084], [74.75235748, 13.17013931], [74.75208282, 13.17013931], [74.75208282, 13.17236233], [74.75180817, 13.17236233], [74.75180817, 13.17319584], [74.75152588, 13.17319107], [74.75152588, 13.17430973], [74.75125122, 13.17430973], [74.75125122, 13.17514038], [74.75097656, 13.17514038], [74.75097656, 13.17653179], [74.75041962, 13.17653179], [74.75041962, 13.17681026], [74.75013733, 13.17681026], [74.75013733, 13.17903042], [74.74986267, 13.17902756], [74.74986267, 13.17958355], [74.74958038, 13.17957973], [74.74958038, 13.17986012], [74.74931335, 13.17986012], [74.74931335, 13.18153095], [74.74903107, 13.18152809], [74.74903107, 13.18208218], [74.74874878, 13.18208027], [74.74874878, 13.18264008], [74.74847412, 13.18263817], [74.74846649, 13.18346119], [74.74846649, 13.18375015], [74.74819183, 13.18375015], [74.74819183, 13.18430424], [74.74791718, 13.18430042], [74.74791718, 13.18514061], [74.74764252, 13.18513775], [74.74764252, 13.18597317], [74.74736023, 13.18597031], [74.74736023, 13.18653107], [74.7470932, 13.18653107], [74.7470932, 13.18681145], [74.74680328, 13.18681145], [74.74680328, 13.1873703], [74.74652863, 13.18738079], [74.74652863, 13.18792057], [74.74635315, 13.18791676], [74.74624634, 13.18791676], [74.74624634, 13.18819523], [74.74597168, 13.18819046], [74.74597168, 13.18875122], [74.74569702, 13.18875122], [74.74569702, 13.18958282], [74.74541473, 13.18958282], [74.74541473, 13.18976974], [74.7454071, 13.19014072], [74.74514008, 13.19013882], [74.74514008, 13.19024086], [74.74514008, 13.19069481], [74.74497986, 13.19069481], [74.74485779, 13.19069481], [74.74485779, 13.19097328], [74.74458313, 13.19097137], [74.74458313, 13.19124889], [74.74430847, 13.19124889], [74.74430847, 13.19181156], [74.74402618, 13.19181156], [74.74402618, 13.19292164], [74.74375153, 13.19292164], [74.74375153, 13.19375134], [74.74346924, 13.19375134], [74.74346924, 13.194911], [74.74346924, 13.19819641], [74.74318695, 13.19819069], [74.74318695, 13.20014191], [74.74291992, 13.20014191], [74.74291992, 13.20153046], [74.74263763, 13.20153046], [74.74263763, 13.20263958], [74.74236298, 13.20263958], [74.74236298, 13.20374966], [74.74208069, 13.20374966], [74.74208069, 13.20458412], [74.74180603, 13.20458412], [74.74180603, 13.2056942], [74.74153137, 13.20568943], [74.74153137, 13.20681095], [74.74124908, 13.20681095], [74.74124908, 13.20763969], [74.74097443, 13.20763779], [74.74097443, 13.20847225], [74.74069214, 13.20847034], [74.74069214, 13.20903111], [74.74041748, 13.20903111], [74.74041748, 13.20931053], [74.74013519, 13.20930576], [74.74013519, 13.21208191], [74.73986053, 13.21208], [74.73986053, 13.21375084], [74.73958588, 13.21375084], [74.73958588, 13.21486092], [74.73930359, 13.21486092], [74.73930359, 13.21569538], [74.73902893, 13.21569538], [74.73902893, 13.21708298], [74.73874664, 13.21708012], [74.73874664, 13.21875095], [74.73847198, 13.21875095], [74.73847198, 13.22014141], [74.73819733, 13.22013855], [74.73819733, 13.22069454], [74.73792267, 13.22069073], [74.73792267, 13.22153187], [74.73764038, 13.2215271], [74.73764038, 13.22236061], [74.73735809, 13.22236061], [74.73735809, 13.22264194], [74.73707581, 13.22264194], [74.73707581, 13.22292042], [74.73680878, 13.2229166], [74.73680878, 13.22319317], [74.73652649, 13.22319126], [74.73652649, 13.22348022], [74.73625183, 13.22348022], [74.73625183, 13.22375202], [74.73597717, 13.22375202], [74.73597717, 13.22402954], [74.73569489, 13.22402668], [74.73569489, 13.22847176], [74.73542023, 13.22846889], [74.73542023, 13.22931004], [74.73513794, 13.22931004], [74.73513794, 13.23042011], [74.73486328, 13.23042011], [74.73486328, 13.23153019], [74.73458099, 13.23153019], [74.73458099, 13.23264027], [74.73430634, 13.23264027], [74.73430634, 13.23375034], [74.73401642, 13.23375034], [74.73401642, 13.23513985], [74.73374939, 13.23513794], [74.73374939, 13.23569393], [74.73401642, 13.23569202], [74.73401642, 13.23624992], [74.73374939, 13.23624992], [74.73374939, 13.23708439], [74.7334671, 13.23707962], [74.7334671, 13.23875141], [74.73319244, 13.23875141], [74.73319244, 13.2404213], [74.73291016, 13.2404213], [74.73291016, 13.24180889], [74.7326355, 13.24180698], [74.7326355, 13.24347305], [74.73236084, 13.24347115], [74.73236084, 13.24514103], [74.73208618, 13.24513912], [74.73208618, 13.24736118], [74.73179626, 13.24736118], [74.73179626, 13.24930954], [74.73152924, 13.24930954], [74.73152924, 13.25041962], [74.73124695, 13.25041962], [74.73124695, 13.25152969], [74.73097229, 13.25152969], [74.73097229, 13.25264168], [74.73069763, 13.25264168], [74.73069763, 13.25374985], [74.73041534, 13.25374985], [74.73042297, 13.25486183], [74.73014069, 13.25486183], [74.73014069, 13.25625038], [74.72985077, 13.25625038], [74.72985077, 13.25764179], [74.72957611, 13.25764179], [74.72957611, 13.25874996], [74.72930908, 13.25874996], [74.72930908, 13.26014042], [74.72902679, 13.26014042], [74.72902679, 13.26124954], [74.72875214, 13.26124954], [74.72875214, 13.26236153], [74.72846985, 13.26236153], [74.72846985, 13.2634716], [74.72819519, 13.2634716], [74.72819519, 13.26458454], [74.7279129, 13.26458454], [74.7279129, 13.26569366], [74.72763824, 13.26568985], [74.72763824, 13.26681137], [74.72735596, 13.26681137], [74.72735596, 13.26792145], [74.7270813, 13.26792145], [74.7270813, 13.26903057], [74.72680664, 13.26903057], [74.72680664, 13.27014065], [74.72652435, 13.27013874], [74.72652435, 13.27069473], [74.72624969, 13.27068996], [74.72624969, 13.27125072], [74.72598267, 13.27125072], [74.72598267, 13.27181244], [74.72569275, 13.27180481], [74.72569275, 13.2723608], [74.72541809, 13.2723608], [74.72541809, 13.27292156], [74.7251358, 13.27291679], [74.7251358, 13.27347088], [74.72486115, 13.27347088], [74.72486115, 13.27403164], [74.72458649, 13.27403164], [74.72458649, 13.27458954], [74.72429657, 13.27458954], [74.72429657, 13.27542019], [74.72403717, 13.27542019], [74.72403717, 13.27652931], [74.72374725, 13.27652931], [74.72374725, 13.27736092], [74.7234726, 13.27736092], [74.7234726, 13.27819633], [74.72319794, 13.27819061], [74.72319794, 13.27874947], [74.72292328, 13.27874947], [74.72292328, 13.27931023], [74.72264099, 13.27931023], [74.72264099, 13.28014183], [74.7223587, 13.28013992], [74.7223587, 13.28069305], [74.72207642, 13.28069115], [74.72207642, 13.28125191], [74.72180939, 13.28125191], [74.72180176, 13.28180981], [74.7215271, 13.28180981], [74.7215271, 13.28264046], [74.72125244, 13.2826376], [74.72125244, 13.28319359], [74.72097015, 13.28319073], [74.72097015, 13.28402996], [74.7206955, 13.28402805], [74.7206955, 13.28708363], [74.72041321, 13.28707981], [74.72041321, 13.28763962], [74.72013855, 13.28763771], [74.72013855, 13.2881937], [74.71986389, 13.2881937], [74.71986389, 13.29069424], [74.7195816, 13.29069042], [74.7195816, 13.29431057], [74.71985626, 13.29431057], [74.71985626, 13.2962513], [74.7195816, 13.2962513], [74.7195816, 13.2968092], [74.71930695, 13.29680538], [74.71930695, 13.29736137], [74.71902466, 13.29736137], [74.71902466, 13.29958344], [74.71875, 13.29958344], [74.71875, 13.30236053], [74.71848297, 13.30236053], [74.71848297, 13.30375099], [74.71819305, 13.30375099], [74.71819305, 13.30513859], [74.71791077, 13.30513859], [74.71791077, 13.30681038], [74.71763611, 13.30680561], [74.71763611, 13.30819416], [74.71736145, 13.3081913], [74.71736145, 13.30930996], [74.71763611, 13.30930614], [74.71763611, 13.30986214], [74.71736145, 13.30986023], [74.71736145, 13.31042004], [74.71708679, 13.31041622], [74.71708679, 13.31097221], [74.71679688, 13.31096935], [74.71679688, 13.31180954], [74.71652985, 13.31180954], [74.71652985, 13.31264019], [74.71624756, 13.31264019], [74.71624756, 13.31376076], [74.7159729, 13.31375027], [74.7159729, 13.31458378], [74.71569824, 13.31458378], [74.71569824, 13.31569386], [74.71541595, 13.31569386], [74.71541595, 13.31680584], [74.7151413, 13.31680202], [74.7151413, 13.31735992], [74.71486664, 13.31735992], [74.71486664, 13.31792068], [74.71458435, 13.31791592], [74.71458435, 13.31847191], [74.71430206, 13.31847], [74.71430206, 13.31903076], [74.7140274, 13.31903076], [74.7140274, 13.3215313], [74.71375275, 13.32152557], [74.71375275, 13.32208347], [74.71347046, 13.32207966], [74.71347046, 13.32264137], [74.7131958, 13.32263947], [74.7131958, 13.32319546], [74.71290588, 13.32318974], [74.71290588, 13.32375145], [74.71263885, 13.32375145], [74.71263885, 13.32430935], [74.71235657, 13.32430935], [74.71235657, 13.32542133], [74.71208191, 13.32541656], [74.71208191, 13.32708263], [74.71180725, 13.32708263], [74.71180725, 13.32819462], [74.71151733, 13.3281908], [74.71151733, 13.32903194], [74.71125031, 13.32902718], [74.71125031, 13.32958317], [74.71098328, 13.32958126], [74.71098328, 13.33014202], [74.71069336, 13.33013916], [74.71069336, 13.33069324], [74.7104187, 13.33069134], [74.7104187, 13.33124924], [74.71013641, 13.33124924], [74.71013641, 13.33180523], [74.70986176, 13.33180523], [74.70986176, 13.33236122], [74.7095871, 13.33235931], [74.7095871, 13.33292198], [74.70930481, 13.33291531], [74.70930481, 13.33319569], [74.70903015, 13.33319092], [74.70903015, 13.33375168], [74.70874023, 13.33375168], [74.70874023, 13.33403015], [74.70847321, 13.33403015], [74.70847321, 13.33430958], [74.70819092, 13.33430958], [74.70819092, 13.33487129], [74.70791626, 13.33487129], [74.70791626, 13.33514023], [74.7076416, 13.33514023], [74.7076416, 13.33569431], [74.70735931, 13.33569145], [74.70735931, 13.33625031], [74.70707703, 13.33625031], [74.70707703, 13.33652973], [74.70680237, 13.33652782], [74.70680237, 13.33708382], [74.70652771, 13.33708382], [74.70652771, 13.33736229], [74.70625305, 13.33736038], [74.70625305, 13.33763981], [74.70597076, 13.33763981], [74.70597076, 13.33793163], [74.70569611, 13.33791637], [74.70569611, 13.33819389], [74.70541382, 13.33819389], [74.70541382, 13.33847237], [74.70513916, 13.33847046], [74.70513916, 13.33875179], [74.70485687, 13.33875179], [74.70485687, 13.33903027], [74.70469666, 13.33903027], [74.70458221, 13.33903027], [74.70458221, 13.33931065], [74.70402527, 13.33930588], [74.70402527, 13.33958435], [74.70375061, 13.33957863], [74.70375061, 13.33985996], [74.70318604, 13.33985996], [74.70318604, 13.34014034], [74.70292664, 13.34014034], [74.70292664, 13.34042263], [74.70236206, 13.34041595], [74.70236206, 13.34069443], [74.70180511, 13.34069443], [74.70180511, 13.34097195], [74.70153046, 13.34097195], [74.70153046, 13.34125042], [74.70096588, 13.34125042], [74.70096588, 13.34153271], [74.70069122, 13.34153271], [74.70069122, 13.34181118], [74.70014191, 13.34180641], [74.70014191, 13.34208202], [74.69958496, 13.34208202], [74.69958496, 13.3423624], [74.69930267, 13.34235954], [74.69930267, 13.34263992], [74.69875336, 13.34263992], [74.69875336, 13.34292126], [74.69847107, 13.34291553], [74.69847107, 13.34319401], [74.69791412, 13.34319401], [74.69791412, 13.34347153], [74.69736481, 13.34347153], [74.69736481, 13.34375], [74.69708252, 13.34374142], [74.69708252, 13.34403133], [74.6965332, 13.34403133], [74.6965332, 13.34431076], [74.69596863, 13.34430599], [74.69596863, 13.34458447], [74.69568634, 13.3445797], [74.69568634, 13.34486008], [74.69513702, 13.34486008], [74.69513702, 13.34514141], [74.69486237, 13.34514141], [74.69486237, 13.34542084], [74.69458008, 13.34541607], [74.69458008, 13.34569359], [74.69430542, 13.34569359], [74.69430542, 13.34597206], [74.69403076, 13.34597015], [74.69403076, 13.34625053], [74.69374084, 13.34625053], [74.69374084, 13.34653091], [74.69346619, 13.34653091], [74.69346619, 13.34681129], [74.69291687, 13.34680653], [74.69291687, 13.34708214], [74.69264221, 13.34708214], [74.69264221, 13.34735966], [74.69235992, 13.34735966], [74.69235992, 13.34764099], [74.69180298, 13.34764099], [74.69180298, 13.34792137], [74.69125366, 13.3479166], [74.69125366, 13.34819508], [74.69097137, 13.34819508], [74.69097137, 13.3484726], [74.6904068, 13.34846973], [74.6904068, 13.34903145], [74.69124603, 13.34903145], [74.69124603, 13.34875107], [74.69180298, 13.34875107], [74.69180298, 13.34846973], [74.69235992, 13.3484726], [74.69235992, 13.34819508], [74.69291687, 13.34819508], [74.69291687, 13.3479166], [74.69319153, 13.34792137], [74.69319153, 13.34764099], [74.69374084, 13.34764099], [74.69374084, 13.34735966], [74.69430542, 13.34735966], [74.69430542, 13.34708214], [74.69486237, 13.34708214], [74.69486237, 13.34680653], [74.69541931, 13.34681129], [74.69541931, 13.34653091], [74.69596863, 13.34653091], [74.69596863, 13.34625053], [74.6965332, 13.34625053], [74.6965332, 13.34597015], [74.69680786, 13.34597206], [74.69680786, 13.34569359], [74.69736481, 13.34569359], [74.69736481, 13.34541607], [74.69763947, 13.34542084], [74.69763947, 13.34514141], [74.69819641, 13.34514141], [74.69819641, 13.34486008], [74.69847107, 13.34486008], [74.69847107, 13.3445797], [74.69902802, 13.34458447], [74.69902802, 13.34430599], [74.69930267, 13.34431076], [74.69930267, 13.34403133], [74.69986725, 13.34403133], [74.69986725, 13.34374142], [74.70014191, 13.34375], [74.70014191, 13.34347153], [74.70069122, 13.34347153], [74.70069122, 13.34319401], [74.70124817, 13.34319401], [74.70124817, 13.34291553], [74.70181274, 13.34292126], [74.70181274, 13.34263992], [74.70236206, 13.34263992], [74.70236206, 13.34235954], [74.70263672, 13.3423624], [74.70263672, 13.34208202], [74.70319366, 13.34208202], [74.70319366, 13.34180641], [74.70375061, 13.34181118], [74.70375061, 13.34153271], [74.70430756, 13.34153271], [74.70430756, 13.34125042], [74.70513916, 13.34125042], [74.70513916, 13.34014034], [74.70526123, 13.34014034], [74.70540619, 13.34014034], [74.70540619, 13.33957863], [74.70597076, 13.33958435], [74.70597076, 13.33930588], [74.70614624, 13.33930779], [74.70625305, 13.33931065], [74.70625305, 13.33912086], [74.70625305, 13.33902836], [74.70652771, 13.33903027], [74.70652771, 13.33875179], [74.70707703, 13.33875179], [74.70707703, 13.33847046], [74.70652771, 13.33847237], [74.70652771, 13.33819389], [74.70680237, 13.33819389], [74.70680237, 13.33791637], [74.70691681, 13.33792019], [74.70735931, 13.33793163], [74.70735931, 13.33763981], [74.7076416, 13.33763981], [74.7076416, 13.33736038], [74.70819092, 13.33736229], [74.70819092, 13.33708382], [74.70847321, 13.33708382], [74.70847321, 13.3368063], [74.70903015, 13.33681011], [74.70903015, 13.33652973], [74.70929718, 13.33652973], [74.70929718, 13.33514023], [74.7095871, 13.33514023], [74.7095871, 13.33487129], [74.70986176, 13.33487129], [74.70986176, 13.33430958], [74.71013641, 13.33430958], [74.71013641, 13.33403015], [74.7104187, 13.33403015], [74.7104187, 13.33375168], [74.71069336, 13.33375168], [74.71069336, 13.3334713], [74.71097565, 13.3334713], [74.71097565, 13.33319569], [74.71125031, 13.33319569], [74.71125031, 13.33263969], [74.71151733, 13.33263969], [74.71151733, 13.33235931], [74.71180725, 13.33236122], [74.71180725, 13.33208275], [74.71208191, 13.33208275], [74.71208191, 13.33180523], [74.7123642, 13.33180523], [74.7123642, 13.33152676], [74.71263885, 13.33152962], [74.71263885, 13.33097076], [74.71291351, 13.33097076], [74.71290588, 13.33069134], [74.7131958, 13.33069324], [74.7131958, 13.32958317], [74.71347046, 13.32958317], [74.71347046, 13.32847309], [74.71375275, 13.32847309], [74.71375275, 13.32763863], [74.7140274, 13.32764053], [74.7140274, 13.32653141], [74.71430206, 13.32653141], [74.71430206, 13.32625103], [74.71457672, 13.32625103], [74.71457672, 13.32570171], [74.71486664, 13.32570171], [74.71486664, 13.32542133], [74.7151413, 13.32542133], [74.7151413, 13.32486057], [74.71541595, 13.32486057], [74.71541595, 13.32374859], [74.71569061, 13.32375145], [74.71569824, 13.32293034], [74.7159729, 13.32293034], [74.7159729, 13.32238102], [74.71624756, 13.32236099], [74.71624756, 13.32184982], [74.71624756, 13.32125092], [74.71649933, 13.32125092], [74.71649933, 13.32113934], [74.71652985, 13.31958199], [74.7168045, 13.31958199], [74.7168045, 13.31791592], [74.71708679, 13.31792068], [74.71708679, 13.31458187], [74.71736145, 13.31458378], [74.71736145, 13.31347179], [74.71763611, 13.31347179], [74.71763611, 13.31180954], [74.71791077, 13.31180954], [74.71791077, 13.31096935], [74.71819305, 13.31097221], [74.71819305, 13.31069374], [74.71791077, 13.31070137], [74.71791077, 13.30986023], [74.71819305, 13.30986214], [74.71819305, 13.30902767], [74.71848297, 13.30902958], [74.71848297, 13.3081913], [74.71875, 13.30819416], [74.71875, 13.30708408], [74.71902466, 13.30708408], [74.71902466, 13.30597115], [74.71930695, 13.30597115], [74.71930695, 13.30513859], [74.7195816, 13.30513859], [74.7195816, 13.3045702], [74.71986389, 13.3045826], [74.71986389, 13.30125141], [74.7195816, 13.30125141], [74.7195816, 13.30014133], [74.71985626, 13.30014133], [74.71985626, 13.29847145], [74.72013855, 13.29847336], [74.72013855, 13.29652882], [74.72041321, 13.29653072], [74.72041321, 13.29125023], [74.72070313, 13.29125023], [74.7206955, 13.28902817], [74.72097015, 13.28903103], [74.72097015, 13.28736019], [74.72125244, 13.2873621], [74.72125244, 13.28625011], [74.7215271, 13.28625011], [74.7215271, 13.28514004], [74.72180176, 13.28514004], [74.72180176, 13.28402996], [74.72207642, 13.28402996], [74.72207642, 13.28345966], [74.7223587, 13.28347206], [74.7223587, 13.28319359], [74.72264099, 13.28319359], [74.72264099, 13.2826376], [74.72292328, 13.28264046], [74.72292328, 13.28208065], [74.72319794, 13.28208447], [74.72319794, 13.28152847], [74.7234726, 13.28153038], [74.7234726, 13.28069115], [74.72374725, 13.28069305], [74.72374725, 13.2798624], [74.72402954, 13.2798624], [74.72402954, 13.27958393], [74.7243042, 13.27958393], [74.7243042, 13.27902699], [74.72458649, 13.27903175], [74.72458649, 13.27874947], [74.72486115, 13.27874947], [74.72486115, 13.27847099], [74.7251358, 13.27847099], [74.7251358, 13.27819633], [74.72569275, 13.27819633], [74.72569275, 13.27791691], [74.72598267, 13.27791977], [74.72598267, 13.27765083], [74.72651672, 13.27765083], [74.72651672, 13.27736092], [74.72680664, 13.27736092], [74.72680664, 13.27708054], [74.7270813, 13.2770834], [74.7270813, 13.27680492], [74.72846985, 13.27680492], [74.72846985, 13.2770834], [74.72902679, 13.27708054], [74.72902679, 13.27791977], [74.72875214, 13.27791977], [74.72875214, 13.27903175], [74.72902679, 13.27903175], [74.72902679, 13.2804203], [74.72930908, 13.2804203], [74.72930908, 13.28153038], [74.72957611, 13.28153038], [74.72957611, 13.28236198], [74.73014069, 13.28236198], [74.73014069, 13.28319359], [74.73041534, 13.28319359], [74.73041534, 13.28347206], [74.73014069, 13.28345966], [74.73014069, 13.28431034], [74.7298584, 13.28430557], [74.7298584, 13.28458405], [74.72930908, 13.28458405], [74.72930908, 13.28486156], [74.72902679, 13.28485966], [74.72902679, 13.28542042], [74.72930908, 13.28541565], [74.72930908, 13.28569412], [74.73014069, 13.28569412], [74.73014069, 13.28597164], [74.73152924, 13.28596973], [74.73152924, 13.28625011], [74.73208618, 13.28625011], [74.73208618, 13.28652954], [74.73236084, 13.28652954], [74.73236084, 13.28682041], [74.73291779, 13.28680611], [74.73291779, 13.28708363], [74.73347473, 13.28708363], [74.73347473, 13.2873621], [74.73374939, 13.28736019], [74.73374939, 13.28763962], [74.73401642, 13.28763962], [74.73401642, 13.28792095], [74.73430634, 13.28791618], [74.73430634, 13.2881937], [74.73486328, 13.2881937], [74.73486328, 13.28847218], [74.73542023, 13.28847027], [74.73542023, 13.28874969], [74.73568726, 13.28874969], [74.73568726, 13.28931141], [74.73597717, 13.28931141], [74.73597717, 13.28959084], [74.73568726, 13.28959084], [74.73568726, 13.29014015], [74.73513794, 13.29014015], [74.73513794, 13.29042053], [74.73374939, 13.29042053], [74.73374939, 13.29014015], [74.73291016, 13.29014015], [74.73291016, 13.28985977], [74.7326355, 13.28985977], [74.7326355, 13.28958225], [74.73236084, 13.28959084], [74.73236084, 13.28931141], [74.73208618, 13.28931141], [74.73208618, 13.28874969], [74.73179626, 13.28874969], [74.73179626, 13.2881918], [74.73152924, 13.2881937], [74.73152924, 13.28763771], [74.73124695, 13.28763962], [74.73124695, 13.28736019], [74.72930908, 13.28736019], [74.72930908, 13.28763962], [74.72957611, 13.28763962], [74.72957611, 13.28792095], [74.72875214, 13.28791618], [74.72875214, 13.2881937], [74.7279129, 13.2881937], [74.7279129, 13.28847218], [74.72759247, 13.28847218], [74.72735596, 13.28847027], [74.72735596, 13.28874969], [74.72651672, 13.28874969], [74.72651672, 13.28903103], [74.72598267, 13.28903103], [74.72598267, 13.28931141], [74.7251358, 13.28931141], [74.7251358, 13.28959084], [74.72458649, 13.28959084], [74.72458649, 13.28985977], [74.72429657, 13.28985977], [74.72429657, 13.29014015], [74.72374725, 13.29013824], [74.72374725, 13.29097176], [74.7234726, 13.29096985], [74.7234726, 13.29181099], [74.72319794, 13.29180431], [74.72319794, 13.29263783], [74.72291565, 13.29263783], [74.72291565, 13.29347324], [74.72264099, 13.29347038], [74.72264099, 13.29403114], [74.7223587, 13.29403114], [74.7223587, 13.29514122], [74.72251892, 13.29514122], [74.72264099, 13.29514122], [74.72264099, 13.29653072], [74.72292328, 13.29653072], [74.72292328, 13.29763889], [74.72319794, 13.29763889], [74.72319794, 13.29876041], [74.7234726, 13.29876041], [74.7234726, 13.29903126], [74.72319794, 13.29902744], [74.72319794, 13.29958344], [74.72291565, 13.29958344], [74.72292328, 13.29986095], [74.72264099, 13.29986095], [74.72264099, 13.30042171], [74.72291565, 13.30041695], [74.72291565, 13.30097103], [74.72319794, 13.30097103], [74.72319794, 13.30182076], [74.7234726, 13.30180454], [74.7234726, 13.30208302], [74.72319794, 13.30208111], [74.72319794, 13.30292034], [74.72291565, 13.30291653], [74.72291565, 13.30347347], [74.72264099, 13.30347347], [74.72264099, 13.3045826], [74.7223587, 13.3045702], [74.7223587, 13.30486107], [74.72180939, 13.30486107], [74.72180939, 13.30500031], [74.72180176, 13.30513859], [74.7215271, 13.30513859], [74.7215271, 13.30569553], [74.72175598, 13.30569553], [74.72208405, 13.30569553], [74.72208405, 13.30597115], [74.7223587, 13.30596924], [74.7223587, 13.30625153], [74.72207642, 13.30625153], [74.72207642, 13.30653191], [74.7223587, 13.30653191], [74.7223587, 13.3073616], [74.72208405, 13.3073616], [74.72208405, 13.30819416], [74.72180939, 13.3081913], [74.72180176, 13.30875015], [74.7215271, 13.30875015], [74.7215271, 13.30930996], [74.72125244, 13.30930996], [74.72125244, 13.31013966], [74.72097015, 13.31013775], [74.72097015, 13.31235981], [74.7206955, 13.31235981], [74.72070313, 13.31347179], [74.72041321, 13.31347179], [74.72041321, 13.31458378], [74.72013855, 13.31458187], [74.72013855, 13.3154211], [74.71986389, 13.31541634], [74.71986389, 13.31569386], [74.72013855, 13.31569386], [74.72013855, 13.31597233], [74.71986389, 13.31597233], [74.71986389, 13.31680584], [74.7195816, 13.31680202], [74.7195816, 13.31903076], [74.71930695, 13.31903076], [74.71930695, 13.32014084], [74.71901703, 13.32014084], [74.71901703, 13.32042122], [74.71875, 13.32042122], [74.71875, 13.3215313], [74.71847534, 13.32152557], [74.71847534, 13.32208347], [74.71875, 13.32208347], [74.71875, 13.32319546], [74.71848297, 13.32318974], [74.71848297, 13.32375145], [74.71875, 13.32375145], [74.71875, 13.32430935], [74.71847534, 13.32430458], [74.71847534, 13.32458305], [74.71875, 13.32458305], [74.71875, 13.32486057], [74.71848297, 13.32486057], [74.71848297, 13.32542133], [74.71819305, 13.32541656], [74.71819305, 13.32597256], [74.71763611, 13.32597256], [74.71763611, 13.32736111], [74.71736145, 13.32736111], [74.71736145, 13.32764053], [74.71708679, 13.32763863], [74.71708679, 13.32819462], [74.71679688, 13.3281908], [74.71679688, 13.32903194], [74.71652985, 13.32902718], [74.71652985, 13.32958317], [74.7159729, 13.32958126], [74.7159729, 13.32986069], [74.71569824, 13.32986069], [74.71569824, 13.33014202], [74.7151413, 13.33013916], [74.7151413, 13.33069324], [74.71485901, 13.33069324], [74.71486664, 13.33124924], [74.71458435, 13.33124924], [74.71458435, 13.33208275], [74.71430206, 13.33208084], [74.71430206, 13.33263969], [74.7140274, 13.33263969], [74.7140274, 13.33319569], [74.71430206, 13.33319569], [74.71430206, 13.33458424], [74.7140274, 13.33458138], [74.7140274, 13.33487129], [74.71375275, 13.33487129], [74.71375275, 13.33541965], [74.71347046, 13.33541775], [74.71347046, 13.33569431], [74.71290588, 13.33569145], [74.71290588, 13.33625031], [74.71263885, 13.33625031], [74.71263885, 13.33652973], [74.71208191, 13.33652782], [74.71208191, 13.33708382], [74.71180725, 13.33708191], [74.71180725, 13.33763981], [74.71152496, 13.33763981], [74.71152496, 13.33819389], [74.71125031, 13.33819103], [74.71125031, 13.34042263], [74.71151733, 13.34042263], [74.71151733, 13.34125042], [74.71125031, 13.34125042], [74.71125031, 13.34181118], [74.7104187, 13.34181118], [74.7104187, 13.34153271], [74.70986176, 13.34153271], [74.70986176, 13.34097195], [74.7095871, 13.34097195], [74.7095871, 13.34041595], [74.70929718, 13.34042263], [74.70929718, 13.34014034], [74.70903015, 13.34014034], [74.70903015, 13.34042263], [74.70874786, 13.34041595], [74.70874786, 13.34069443], [74.70819092, 13.34069443], [74.70819092, 13.34097195], [74.70791626, 13.34097195], [74.70791626, 13.34125042], [74.70735931, 13.34125042], [74.70735931, 13.34153271], [74.70680237, 13.34153271], [74.70680237, 13.34181118], [74.70625305, 13.34180641], [74.70625305, 13.34208202], [74.70597076, 13.34208202], [74.70597076, 13.34263992], [74.70540619, 13.34263992], [74.70540619, 13.34292126], [74.70513916, 13.34291553], [74.70513916, 13.34319401], [74.7048645, 13.34319401], [74.7048645, 13.34347153], [74.70458221, 13.34347153], [74.70458221, 13.34375], [74.70430756, 13.34374142], [74.70430756, 13.34431076], [74.70319366, 13.34430599], [74.70319366, 13.34458447], [74.70180511, 13.34458447], [74.70181274, 13.34486008], [74.70069122, 13.34486008], [74.70069122, 13.34514141], [74.69957733, 13.34514141], [74.69957733, 13.34542084], [74.69902802, 13.34541607], [74.69902802, 13.34569359], [74.69847107, 13.34569359], [74.69847107, 13.34597206], [74.69819641, 13.34597015], [74.69819641, 13.34625053], [74.69763947, 13.34625053], [74.69763947, 13.34653091], [74.69708252, 13.34653091], [74.69708252, 13.34681129], [74.69652557, 13.34680653], [74.69652557, 13.34708214], [74.69625092, 13.34708214], [74.69625092, 13.34735966], [74.69568634, 13.34735966], [74.69568634, 13.34764099], [74.69513702, 13.34764099], [74.69513702, 13.34792137], [74.69541931, 13.3479166], [74.69541931, 13.34819508], [74.69596863, 13.34819508], [74.69596863, 13.3484726], [74.69625092, 13.34846973], [74.69625092, 13.34875107], [74.6965332, 13.34875107], [74.6965332, 13.34931087], [74.69680786, 13.34930515], [74.69680786, 13.34958267], [74.69735718, 13.3495779], [74.69735718, 13.34986973], [74.69763947, 13.34986115], [74.69763947, 13.35097313], [74.69785309, 13.35097122], [74.69790649, 13.35264111], [74.69819641, 13.3526392], [74.69819641, 13.35458279], [74.69790649, 13.35458088], [74.69790649, 13.35652924], [74.69763947, 13.35652924], [74.69763947, 13.35902977], [74.69791412, 13.35902691], [74.69791412, 13.3595829], [74.69819641, 13.3595829], [74.69819641, 13.35986233], [74.69847107, 13.35986233], [74.69847107, 13.36013985], [74.69875336, 13.36013985], [74.69875336, 13.36097145], [74.69847107, 13.36097145], [74.69847107, 13.36208439], [74.69819641, 13.36208057], [74.69819641, 13.36236191], [74.69790649, 13.36236191], [74.69790649, 13.36403179], [74.69763947, 13.36403179], [74.69763947, 13.36736202], [74.69736481, 13.36736202], [74.69736481, 13.37069416], [74.69708252, 13.37069035], [74.69708252, 13.37403965], [74.69680786, 13.37402916], [74.69680786, 13.37458229], [74.69652557, 13.37458229], [74.69652557, 13.37569523], [74.69625092, 13.37569046], [74.69625092, 13.37681103], [74.69596863, 13.37681103], [74.69596863, 13.37903118], [74.69569397, 13.37902737], [74.69569397, 13.3829174], [74.69596863, 13.3829174], [74.69596863, 13.38708401], [74.69625092, 13.38708115], [74.69625092, 13.39041996], [74.6965332, 13.39041996], [74.6965332, 13.39291954], [74.69680786, 13.39291573], [74.69680786, 13.39305019], [74.69680023, 13.39513969], [74.69708252, 13.39513969], [74.69708252, 13.39764023], [74.69735718, 13.39764023], [74.69735718, 13.40236092], [74.69708252, 13.40236092], [74.69708252, 13.40653133], [74.69680023, 13.40653133], [74.69680023, 13.40931034], [74.69652557, 13.40930462], [74.69652557, 13.41208267], [74.69625092, 13.41208267], [74.69625092, 13.41708374], [74.69596863, 13.41708374], [74.69596863, 13.41847229], [74.69569397, 13.41847229], [74.69569397, 13.41958427], [74.69541931, 13.41958427], [74.69541931, 13.42097187], [74.69513702, 13.42097187], [74.69513702, 13.42319393], [74.69486237, 13.42319202], [74.69486237, 13.42625046], [74.69458008, 13.42625046], [74.69458008, 13.4295826], [74.69430542, 13.4295826], [74.69431305, 13.43847084], [74.69403076, 13.43847084], [74.69403076, 13.44612026], [74.69403076, 13.44653034], [74.69384766, 13.44652843], [74.69374847, 13.44652843], [74.69374847, 13.44675064], [74.69374084, 13.44764042], [74.69403076, 13.44763756], [74.69403076, 13.44847202], [74.69431305, 13.44847202], [74.69431305, 13.44932175], [74.69458008, 13.44930553], [74.69458008, 13.44986153], [74.69431305, 13.44985962], [74.69431305, 13.45403099], [74.69403076, 13.45402908], [74.69403076, 13.45458221], [74.69374084, 13.45458031], [74.69374084, 13.45485973], [74.69346619, 13.45485973], [74.69346619, 13.45542145], [74.69319153, 13.45541668], [74.69319153, 13.45597267], [74.69291687, 13.4559679], [74.69291687, 13.45653057], [74.69264221, 13.45652866], [74.69264221, 13.45708275], [74.69235992, 13.45708275], [74.69235992, 13.45736122], [74.6920929, 13.45736122], [74.6920929, 13.45792103], [74.69180298, 13.45792103], [74.69180298, 13.45819855], [74.69152832, 13.45819855], [74.69152832, 13.45875072], [74.69124603, 13.45875072], [74.69124603, 13.45903111], [74.69097137, 13.4590292], [74.69097137, 13.45958328], [74.69069672, 13.45958328], [74.69069672, 13.46069527], [74.69041443, 13.46069527], [74.6904068, 13.46286011], [74.69013977, 13.46291733], [74.69013977, 13.4636097], [74.69013977, 13.46486092], [74.68985748, 13.46486092], [74.68985748, 13.46708298], [74.68958282, 13.46706963], [74.68958282, 13.46903038], [74.68930817, 13.46903038], [74.68930817, 13.47124958], [74.68902588, 13.47124958], [74.68902588, 13.47431087], [74.68875122, 13.47431087], [74.68875122, 13.47875023], [74.68846893, 13.47875023], [74.68846893, 13.48292065], [74.68818665, 13.48292065], [74.68818665, 13.48625088], [74.68791962, 13.48625088], [74.68791962, 13.48986053], [74.68763733, 13.48986053], [74.68763733, 13.49263859], [74.68736267, 13.49263859], [74.68736267, 13.49458313], [74.68708038, 13.49458122], [74.68708038, 13.49680996], [74.68681335, 13.49680996], [74.68681335, 13.49874973], [74.68653107, 13.49874973], [74.68653107, 13.50069427], [74.68624878, 13.50069237], [74.68624878, 13.5029211], [74.68597412, 13.50291634], [74.68597412, 13.50569439], [74.68569183, 13.50568962], [74.68569183, 13.50931072], [74.68541718, 13.50930691], [74.68541718, 13.51347256], [74.68514252, 13.51347256], [74.68514252, 13.51708317], [74.68486023, 13.51708126], [74.68486023, 13.51874924], [74.6845932, 13.51874924], [74.6845932, 13.52042198], [74.68430328, 13.52042198], [74.68430328, 13.52291965], [74.68402863, 13.52291775], [74.68402863, 13.5256958], [74.68374634, 13.5256958], [74.68374634, 13.52847195], [74.68347168, 13.52847195], [74.68347168, 13.53069401], [74.68319702, 13.53069019], [74.68319702, 13.53181076], [74.6829071, 13.53181076], [74.6829071, 13.53374958], [74.68264008, 13.53374958], [74.68264008, 13.53654003], [74.68235779, 13.53652859], [74.68235779, 13.53822041], [74.68235779, 13.53931236], [74.68208313, 13.53930473], [74.68208313, 13.54208279], [74.68180084, 13.54208088], [74.68180084, 13.54486084], [74.68152618, 13.54486084], [74.68152618, 13.54736137], [74.68125153, 13.54736137], [74.68125153, 13.5490303], [74.68096924, 13.54902744], [74.68096924, 13.55069447], [74.68068695, 13.55069065], [74.68068695, 13.55263996], [74.68041992, 13.55263996], [74.68041992, 13.5543108], [74.68013763, 13.55430603], [74.68013763, 13.5559721], [74.67986298, 13.55597019], [74.67986298, 13.55792141], [74.67958069, 13.55791569], [74.67958069, 13.55958366], [74.67930603, 13.55957985], [74.67930603, 13.56124973], [74.67903137, 13.56124973], [74.67903137, 13.56319523], [74.67874146, 13.56319046], [74.67874146, 13.56514072], [74.67847443, 13.56513882], [74.67847443, 13.56708336], [74.67819214, 13.56708145], [74.67819214, 13.56903076], [74.67791748, 13.56902695], [74.67791748, 13.5709734], [74.67764282, 13.57097054], [74.67764282, 13.57292175], [74.67736053, 13.57291698], [74.67736053, 13.57486057], [74.67708588, 13.57486057], [74.67708588, 13.57653046], [74.67680359, 13.5765276], [74.67680359, 13.57847214], [74.67652893, 13.57845974], [74.67652893, 13.58041954], [74.67624664, 13.58041573], [74.67624664, 13.58086014], [74.67624664, 13.58236217], [74.67610931, 13.58236217], [74.67597198, 13.58236217], [74.67595673, 13.58393002], [74.6759491, 13.58431053], [74.67569733, 13.58431053], [74.67569733, 13.58625031], [74.67541504, 13.58625031], [74.67541504, 13.58819389], [74.67514038, 13.58819199], [74.67514038, 13.58985996], [74.67485809, 13.58985996], [74.67485809, 13.59152889], [74.67457581, 13.59152889], [74.67457581, 13.59292126], [74.67430878, 13.59291744], [74.67430878, 13.59458256], [74.67402649, 13.59458256], [74.67402649, 13.59597301], [74.67375183, 13.59597301], [74.67375183, 13.59736061], [74.67346954, 13.59736061], [74.67346954, 13.59902859], [74.67318726, 13.59902859], [74.67318726, 13.60042191], [74.67292023, 13.60041714], [74.67292023, 13.60208321], [74.67263794, 13.60208321], [74.67263794, 13.6034708], [74.67236328, 13.60346889], [74.67236328, 13.60513973], [74.67208099, 13.60513973], [74.67208099, 13.60624123], [74.67208099, 13.60653019], [74.67180634, 13.60652828], [74.67180634, 13.60720921], [74.67180634, 13.60819435], [74.67152405, 13.60819435], [74.67152405, 13.60859966], [74.67152405, 13.60958195], [74.67124939, 13.60958195], [74.67124939, 13.61000061], [74.67124939, 13.61124992], [74.67106628, 13.61124992], [74.67097473, 13.61124992], [74.6709671, 13.61264038], [74.67069244, 13.61264038], [74.67069244, 13.61403084], [74.67041779, 13.61402798], [74.67041779, 13.61569405], [74.6701355, 13.61569405], [74.6701355, 13.61708164], [74.67002106, 13.61708164], [74.66986084, 13.61708164], [74.66986084, 13.61757946], [74.66986084, 13.61875057], [74.66958618, 13.61875057], [74.66958618, 13.62014103], [74.66929626, 13.62014103], [74.66929626, 13.62181187], [74.66902924, 13.62180519], [74.66902924, 13.62319469], [74.66874695, 13.62319088], [74.66874695, 13.62486076], [74.66847229, 13.62486076], [74.66847229, 13.6265316], [74.66819763, 13.62652683], [74.66819763, 13.62801075], [74.66819763, 13.62819576], [74.66792297, 13.62819099], [74.66792297, 13.62930965], [74.66819763, 13.62930965], [74.66819763, 13.62986183], [74.66847229, 13.62986183], [74.66847229, 13.63041973], [74.66874695, 13.63041782], [74.66874695, 13.63097191], [74.66902924, 13.63097191], [74.66902924, 13.63152981], [74.66930389, 13.6315279], [74.66930389, 13.63208389], [74.66958618, 13.63208389], [74.66958618, 13.63236237], [74.66986084, 13.63236046], [74.66986084, 13.63264179], [74.67041779, 13.63264179], [74.67041779, 13.63293171], [74.67069244, 13.63293171], [74.67069244, 13.63374996], [74.67041779, 13.63374996], [74.67041779, 13.63486195], [74.6701355, 13.63486195], [74.6701355, 13.63597202], [74.66986084, 13.63597202], [74.66986084, 13.63708401], [74.66958618, 13.63708401], [74.66958618, 13.63819408], [74.66930389, 13.63819408], [74.66930389, 13.6384716], [74.66819763, 13.6384716], [74.66819763, 13.63875008], [74.66792297, 13.63874054], [74.66792297, 13.63931084], [74.66764069, 13.63930416], [74.66764069, 13.63958359], [74.6673584, 13.63958359], [74.6673584, 13.63986015], [74.66708374, 13.63986015], [74.66708374, 13.64069366], [74.66680145, 13.64068985], [74.66680145, 13.64124966], [74.66652679, 13.64124966], [74.66652679, 13.64153099], [74.66625214, 13.64152813], [74.66625214, 13.6418066], [74.66569519, 13.6418066], [74.66569519, 13.64208221], [74.6654129, 13.64208031], [74.6654129, 13.64235973], [74.66513824, 13.64235973], [74.66513824, 13.64292145], [74.66485596, 13.64292145], [74.66485596, 13.64403057], [74.6645813, 13.64402866], [74.6645813, 13.64819527], [74.66430664, 13.64818954], [74.66430664, 13.64903069], [74.66402435, 13.64902687], [74.66402435, 13.64958286], [74.66375732, 13.64958096], [74.66375732, 13.65041924], [74.66348267, 13.65041924], [74.66348267, 13.65125084], [74.66319275, 13.65124893], [74.66319275, 13.6520834], [74.66291809, 13.65208054], [74.66291809, 13.65291977], [74.6626358, 13.65291691], [74.6626358, 13.65347099], [74.66236115, 13.65347099], [74.66236115, 13.65431023], [74.66208649, 13.65430546], [74.66208649, 13.65486145], [74.66179657, 13.65486145], [74.66179657, 13.6554203], [74.66152954, 13.6554184], [74.66152954, 13.65569305], [74.66124725, 13.65569305], [74.66124725, 13.65597057], [74.6609726, 13.65597057], [74.6609726, 13.65653038], [74.66069794, 13.65653038], [74.66069794, 13.65680981], [74.6598587, 13.65680599], [74.6598587, 13.65708447], [74.65957642, 13.65708065], [74.65957642, 13.65736198], [74.65930939, 13.65736198], [74.65930176, 13.65764046], [74.6590271, 13.65764046], [74.6590271, 13.65792179], [74.65875244, 13.65791798], [74.65875244, 13.65819359], [74.65847015, 13.65819359], [74.65847015, 13.65847206], [74.65820313, 13.6584692], [74.65820313, 13.65874958], [74.65791321, 13.65874958], [74.65791321, 13.65902996], [74.65763855, 13.65902805], [74.65763855, 13.65958405], [74.65735626, 13.65957928], [74.65735626, 13.6598711], [74.6570816, 13.6598711], [74.6570816, 13.66014004], [74.65680695, 13.66014004], [74.65680695, 13.66042042], [74.65652466, 13.66041565], [74.65652466, 13.66069412], [74.65625, 13.66068935], [74.65625, 13.66125202], [74.65598297, 13.66125202], [74.65598297, 13.66152954], [74.65569305, 13.66152954], [74.65569305, 13.66181087], [74.6554184, 13.66180611], [74.6554184, 13.66208363], [74.65513611, 13.66208363], [74.65513611, 13.6623621], [74.65486145, 13.66236019], [74.65486145, 13.66292953], [74.65458679, 13.66291809], [74.65458679, 13.6631937], [74.6543045, 13.6631937], [74.6543045, 13.66347218], [74.65402985, 13.66347027], [74.65402985, 13.66374969], [74.65374756, 13.66374969], [74.65374756, 13.66403008], [74.6534729, 13.66402817], [74.6534729, 13.66458416], [74.65319824, 13.66458035], [74.65319824, 13.66486168], [74.65291595, 13.66486168], [74.65291595, 13.66514015], [74.65208435, 13.66514015], [74.65208435, 13.66569424], [74.65180206, 13.66569424], [74.65180206, 13.66597176], [74.6515274, 13.66596985], [74.6515274, 13.66625023], [74.65125275, 13.66625023], [74.65125275, 13.66681099], [74.65097046, 13.66681099], [74.65097046, 13.66764069], [74.6506958, 13.66764069], [74.6506958, 13.66931057], [74.65041351, 13.66930676], [74.65041351, 13.67097282], [74.65013885, 13.67097282], [74.65013885, 13.6720829], [74.64985657, 13.67208004], [74.64985657, 13.6726408], [74.64958191, 13.67263889], [74.64958191, 13.67319489], [74.64930725, 13.67319012], [74.64930725, 13.67375088], [74.64901733, 13.67375088], [74.64901733, 13.67431164], [74.64875793, 13.67431164], [74.64875793, 13.67486954], [74.64848328, 13.67486954], [74.64848328, 13.67542171], [74.64819336, 13.67541695], [74.64819336, 13.67597294], [74.6479187, 13.67597103], [74.6479187, 13.67653084], [74.64763641, 13.67652702], [74.64763641, 13.67708302], [74.64736176, 13.67708111], [74.64736176, 13.67764091], [74.6470871, 13.67763901], [74.6470871, 13.67819309], [74.64679718, 13.67819118], [74.64679718, 13.67875099], [74.64653015, 13.67875099], [74.64653015, 13.67931175], [74.64624786, 13.67931175], [74.64624786, 13.6801424], [74.64597321, 13.6801424], [74.64597321, 13.68125153], [74.64569092, 13.68124866], [74.64569092, 13.68208313], [74.64541626, 13.68208122], [74.64541626, 13.68292046], [74.6451416, 13.68292046], [74.6451416, 13.68404102], [74.64485931, 13.68402767], [74.64485931, 13.68486214], [74.64458466, 13.68486214], [74.64458466, 13.68597221], [74.64430237, 13.68597221], [74.64430237, 13.68958378], [74.64402771, 13.68958378], [74.64402771, 13.6915102], [74.64402771, 13.69375038], [74.64375305, 13.69375038], [74.64375305, 13.69542122], [74.64347076, 13.69541645], [74.64347076, 13.69708157], [74.64319611, 13.69708157], [74.64318848, 13.69757938], [74.64317322, 13.69875145], [74.64290619, 13.69875145], [74.64290619, 13.70042133], [74.64263916, 13.70041656], [74.64263916, 13.70208263], [74.64235687, 13.70208073], [74.64235687, 13.70375061], [74.64208221, 13.7037487], [74.64208221, 13.70569515], [74.64180756, 13.70569515], [74.64180756, 13.70736122], [74.6415329, 13.70736122], [74.6415329, 13.70930958], [74.64125061, 13.70930958], [74.64125061, 13.71098137], [74.64097595, 13.71098137], [74.64097595, 13.71292019], [74.64069366, 13.71291637], [74.64069366, 13.71458435], [74.64041901, 13.71458244], [74.64041901, 13.71625042], [74.64013672, 13.71625042], [74.64013672, 13.71708202], [74.64013672, 13.71792126], [74.63986206, 13.71791553], [74.63986206, 13.71958447], [74.6395874, 13.7195797], [74.6395874, 13.72124958], [74.63931274, 13.72124958], [74.63931274, 13.72292137], [74.63903046, 13.72291565], [74.63903046, 13.72458458], [74.63874817, 13.7245779], [74.63874817, 13.72625065], [74.63846588, 13.72625065], [74.63846588, 13.72792053], [74.63819122, 13.72791672], [74.63819122, 13.72958279], [74.63791656, 13.72958088], [74.63791656, 13.73125076], [74.63764191, 13.73125076], [74.63764191, 13.73291969], [74.63735962, 13.73291683], [74.63735962, 13.7345829], [74.63707733, 13.73458099], [74.63707733, 13.73625183], [74.63680267, 13.73624897], [74.63680267, 13.73819256], [74.63652802, 13.73819256], [74.63652802, 13.73986244], [74.63625336, 13.73985958], [74.63625336, 13.74153042], [74.63597107, 13.74152756], [74.63597107, 13.7434721], [74.63569641, 13.74347019], [74.63569641, 13.74514008], [74.63540649, 13.74514008], [74.63540649, 13.74681091], [74.63513947, 13.74681091], [74.63513947, 13.74792099], [74.63485718, 13.74792099], [74.63485718, 13.74931145], [74.63458252, 13.74930668], [74.63458252, 13.75069523], [74.63430786, 13.75069046], [74.63430786, 13.75181103], [74.63402557, 13.75180435], [74.63402557, 13.75319481], [74.63375092, 13.75319481], [74.63375092, 13.75458336], [74.63346863, 13.75458336], [74.633461, 13.75568962], [74.63319397, 13.75569534], [74.63319397, 13.75708294], [74.63291931, 13.75708294], [74.63291931, 13.75753021], [74.63291931, 13.7584734], [74.63276672, 13.7584734], [74.63263702, 13.7584734], [74.63263702, 13.75938034], [74.63263702, 13.75958347], [74.63236237, 13.75958347], [74.63236237, 13.76119041], [74.63236237, 13.76292038], [74.63208008, 13.76291847], [74.63206482, 13.76378059], [74.63205719, 13.76403046], [74.63180542, 13.76402664], [74.63180542, 13.76458359], [74.63153076, 13.76458359], [74.63153076, 13.76513958], [74.63124847, 13.76513958], [74.63124847, 13.76569366], [74.63096619, 13.7656889], [74.63096619, 13.76681042], [74.63069153, 13.76680565], [74.63069153, 13.76847172], [74.63041687, 13.76846981], [74.63041687, 13.77013969], [74.63014221, 13.77013969], [74.63014221, 13.77181053], [74.62985992, 13.77180576], [74.62985992, 13.77347183], [74.6295929, 13.77346992], [74.6295929, 13.77514267], [74.62930298, 13.77514267], [74.62930298, 13.77681065], [74.62902832, 13.77681065], [74.62902832, 13.78042126], [74.62875366, 13.78041744], [74.62875366, 13.78069496], [74.62847137, 13.78069019], [74.62847137, 13.78153133], [74.62819672, 13.78153133], [74.62819672, 13.78320026], [74.62791443, 13.78319454], [74.62791443, 13.78486061], [74.62763977, 13.78486061], [74.62763977, 13.7859726], [74.62735748, 13.78597069], [74.62735748, 13.78681183], [74.62708282, 13.78681183], [74.62708282, 13.78792191], [74.62680817, 13.78792191], [74.62680817, 13.7887516], [74.62652588, 13.78874874], [74.62652588, 13.78958321], [74.62625122, 13.7895813], [74.62625122, 13.79041958], [74.62596893, 13.79041958], [74.62596893, 13.79152966], [74.62569427, 13.79152775], [74.62569427, 13.79236221], [74.62541962, 13.79236221], [74.62541962, 13.79319572], [74.62568665, 13.79319096], [74.62568665, 13.79430962], [74.62596893, 13.7943058], [74.62596893, 13.79526138], [74.62596893, 13.79542923], [74.62625122, 13.79542923], [74.62625122, 13.79625034], [74.62596893, 13.79625034], [74.62596893, 13.79708195], [74.62569427, 13.79708195], [74.62569427, 13.79652786], [74.62538147, 13.79652977], [74.62513733, 13.79653263], [74.62513733, 13.7968111], [74.62458038, 13.79680634], [74.62458038, 13.79708195], [74.62431335, 13.79708195], [74.62431335, 13.79820061], [74.62403107, 13.79820061], [74.62403107, 13.79874992], [74.62374878, 13.79874992], [74.62374878, 13.7990303], [74.62346649, 13.7990303], [74.62346649, 13.80014038], [74.62319183, 13.80013847], [74.62319183, 13.80125046], [74.62291718, 13.80124092], [74.62291718, 13.80264091], [74.62264252, 13.80264091], [74.62264252, 13.80403137], [74.62236023, 13.80403137], [74.62236023, 13.80542088], [74.6220932, 13.80542088], [74.6220932, 13.80681133], [74.62180328, 13.80680466], [74.62180328, 13.80819511], [74.62152863, 13.80819511], [74.62152863, 13.80958271], [74.62124634, 13.80958271], [74.62124634, 13.81097317], [74.62097168, 13.81097126], [74.62097168, 13.81236076], [74.62069702, 13.81236076], [74.62069702, 13.81375122], [74.6204071, 13.81375122], [74.6204071, 13.81514168], [74.62014008, 13.81514168], [74.62014008, 13.81653023], [74.61985779, 13.81653023], [74.61985779, 13.81791973], [74.61958313, 13.81791973], [74.61958313, 13.81931019], [74.61930847, 13.81930637], [74.61930847, 13.8206892], [74.61902618, 13.82069588], [74.61902618, 13.82208443], [74.61875153, 13.82208443], [74.61875153, 13.82347202], [74.61846924, 13.82347202], [74.61846924, 13.82486153], [74.61818695, 13.82485962], [74.61818695, 13.82625008], [74.61791992, 13.82625008], [74.61791992, 13.82681084], [74.61708069, 13.82681084], [74.61708069, 13.82792091], [74.61680603, 13.82792091], [74.61680603, 13.83014107], [74.61653137, 13.83014107], [74.61653137, 13.83181095], [74.61624908, 13.83181095], [74.61624908, 13.83292103], [74.6159668, 13.83292103], [74.6159668, 13.83403111], [74.61569214, 13.83403111], [74.61569214, 13.83514118], [74.61541748, 13.83513927], [74.61541748, 13.83597279], [74.61513519, 13.83597279], [74.61513519, 13.83708286], [74.61486053, 13.83708286], [74.61486053, 13.83819485], [74.61458588, 13.83819103], [74.61458588, 13.83902931], [74.61429596, 13.83902931], [74.61429596, 13.84013939], [74.61402893, 13.84013939], [74.61402893, 13.84125137], [74.61374664, 13.84125137], [74.61374664, 13.84224129], [74.61374664, 13.84236145], [74.61347198, 13.84236145], [74.61347198, 13.84319305], [74.61319733, 13.84319305], [74.61318207, 13.84418011], [74.61318207, 13.84430981], [74.61291504, 13.84430504], [74.61292267, 13.84517193], [74.61292267, 13.84542179], [74.61264038, 13.84541798], [74.61264801, 13.84613991], [74.61264801, 13.8465414], [74.61252594, 13.84652805], [74.61235809, 13.84652805], [74.61235809, 13.84713173], [74.61235809, 13.84764194], [74.61219788, 13.84764004], [74.61208344, 13.84764004], [74.61208344, 13.84809971], [74.61207581, 13.84875202], [74.61180878, 13.84875011], [74.61180878, 13.84907055], [74.61180878, 13.8498621], [74.61152649, 13.8498621], [74.61152649, 13.85006046], [74.61152649, 13.85097218], [74.61125183, 13.85097218], [74.61125183, 13.85208416], [74.61096954, 13.85208416], [74.61096954, 13.85319424], [74.61068726, 13.85319042], [74.61068726, 13.85403061], [74.61042023, 13.85402775], [74.61042023, 13.85486031], [74.61013794, 13.85486031], [74.61013794, 13.85509014], [74.61013794, 13.85597229], [74.60986328, 13.85597038], [74.60986328, 13.85681057], [74.60958099, 13.85681057], [74.60958099, 13.85764122], [74.60930634, 13.85764122], [74.60930634, 13.8587513], [74.60902405, 13.8587513], [74.60902405, 13.8595829], [74.60874939, 13.85958004], [74.60874939, 13.86042118], [74.6084671, 13.86042118], [74.6084671, 13.86125088], [74.60819244, 13.86125088], [74.60819244, 13.86236095], [74.60791779, 13.86236095], [74.60791779, 13.86319542], [74.60764313, 13.8631897], [74.60764313, 13.86403084], [74.60736084, 13.86403084], [74.60736084, 13.86514091], [74.60708618, 13.86513901], [74.60708618, 13.86597347], [74.60679626, 13.86597061], [74.60679626, 13.86652946], [74.60791779, 13.86652946], [74.60791779, 13.86597061], [74.60819244, 13.86597347], [74.60819244, 13.86513901], [74.6084671, 13.86514091], [74.6084671, 13.86430931], [74.60874939, 13.86430931], [74.60874939, 13.86347103], [74.60902405, 13.86347294], [74.60902405, 13.86263943], [74.60930634, 13.86264133], [74.60930634, 13.86207962], [74.60958099, 13.86208344], [74.60958099, 13.86180687], [74.60986328, 13.86181164], [74.60986328, 13.86125088], [74.61013794, 13.86125088], [74.61013794, 13.86097145], [74.61042023, 13.86097336], [74.61042023, 13.86069489], [74.61096954, 13.86069489], [74.61096954, 13.86041737], [74.61125183, 13.86042118], [74.61125183, 13.8601408], [74.61180878, 13.8601408], [74.61180878, 13.85847855], [74.61207581, 13.85847855], [74.61207581, 13.85513973], [74.61235809, 13.85513973], [74.61235809, 13.85486031], [74.61264038, 13.85486031], [74.61264038, 13.85458374], [74.61291504, 13.85458374], [74.61291504, 13.85402775], [74.61319733, 13.85403061], [74.61319733, 13.85346985], [74.61347198, 13.85347176], [74.61347198, 13.8531599], [74.61347198, 13.85291576], [74.61374664, 13.85292053], [74.61374664, 13.85235119], [74.61402893, 13.85235977], [74.61402893, 13.85208416], [74.61430359, 13.85208416], [74.61430359, 13.85152817], [74.61458588, 13.85153008], [74.61458588, 13.85124969], [74.61541748, 13.85124969], [74.61541748, 13.85097027], [74.61624908, 13.85097218], [74.61624908, 13.8506937], [74.61714935, 13.8506937], [74.61736298, 13.8506937], [74.61736298, 13.85052967], [74.61736298, 13.85041809], [74.61749268, 13.85041809], [74.61846161, 13.85042], [74.61846161, 13.85013962], [74.61902618, 13.85013962], [74.61902618, 13.84986019], [74.61985779, 13.8498621], [74.61985779, 13.84958363], [74.62097168, 13.84958363], [74.62097168, 13.84930611], [74.62180328, 13.84930992], [74.62180328, 13.84902954], [74.62291718, 13.84902954], [74.62291718, 13.84875202], [74.62403107, 13.84875202], [74.62403107, 13.84847164], [74.62541962, 13.84847164], [74.62541962, 13.84819412], [74.62652588, 13.84819412], [74.62652588, 13.84791565], [74.62770081, 13.84791565], [74.63041687, 13.84791565], [74.63041687, 13.84819412], [74.63124847, 13.84819412], [74.63124847, 13.84847164], [74.63208008, 13.84847164], [74.63208008, 13.84875202], [74.63318634, 13.84875202], [74.63318634, 13.84902954], [74.63291931, 13.84902763], [74.63291931, 13.8498621], [74.63069153, 13.8498621], [74.63069153, 13.84958363], [74.63014221, 13.84958363], [74.63014221, 13.84930611], [74.62930298, 13.84930992], [74.62930298, 13.84902954], [74.62874603, 13.84902954], [74.62874603, 13.84875202], [74.62819672, 13.84875202], [74.62819672, 13.84902954], [74.6279068, 13.84902954], [74.6279068, 13.84930992], [74.62741089, 13.84930611], [74.62486267, 13.84930611], [74.62486267, 13.84958363], [74.62458038, 13.84958363], [74.62458038, 13.8498621], [74.62403107, 13.84986019], [74.62403107, 13.85013962], [74.62374878, 13.85013962], [74.62374878, 13.85042], [74.62319183, 13.85041809], [74.62319183, 13.8506937], [74.62291718, 13.8506937], [74.62291718, 13.85097218], [74.62124634, 13.85097218], [74.62124634, 13.8506937], [74.62097168, 13.8506937], [74.62097168, 13.85041809], [74.61985779, 13.85041809], [74.61985779, 13.8506937], [74.61930847, 13.8506937], [74.61930847, 13.85097218], [74.61846161, 13.85097027], [74.61846161, 13.85153008], [74.61708069, 13.85153008], [74.61708069, 13.85181141], [74.61579895, 13.85180569], [74.61569214, 13.85180569], [74.61569214, 13.85208416], [74.61541748, 13.85208035], [74.61541748, 13.85264015], [74.61513519, 13.85264015], [74.61513519, 13.85319424], [74.61486053, 13.85319424], [74.61486053, 13.85347176], [74.61458588, 13.85346985], [74.61458588, 13.85403061], [74.61429596, 13.85403061], [74.61429596, 13.85431099], [74.61402893, 13.85430622], [74.61402893, 13.85486031], [74.61429596, 13.85486031], [74.61429596, 13.85542107], [74.61402893, 13.8554163], [74.61402893, 13.85569382], [74.61374664, 13.85569382], [74.61374664, 13.85597229], [74.61347198, 13.85597038], [74.61347198, 13.85625267], [74.61319733, 13.85625267], [74.61319733, 13.85764122], [74.61292267, 13.85764122], [74.61292267, 13.85903072], [74.61347198, 13.85903072], [74.61347198, 13.8593092], [74.61763763, 13.85930443], [74.61763763, 13.8595829], [74.61736298, 13.8595829], [74.61736298, 13.85971928], [74.61736298, 13.85986137], [74.61605072, 13.85986137], [74.61264801, 13.85986137], [74.61264801, 13.86042118], [74.61235809, 13.86041737], [74.61235809, 13.86097336], [74.61180878, 13.86097145], [74.61180878, 13.86181164], [74.61208344, 13.86180687], [74.61207581, 13.86265945], [74.61207581, 13.86292076], [74.61180878, 13.86291695], [74.61180878, 13.86347294], [74.61152649, 13.86347103], [74.61152649, 13.86375141], [74.61125183, 13.86375141], [74.61125183, 13.86427116], [74.61096954, 13.86430454], [74.61096954, 13.86447144], [74.61096954, 13.86486053], [74.61069489, 13.86486053], [74.61069489, 13.86597347], [74.61042023, 13.86597061], [74.61042023, 13.86736107], [74.61013794, 13.86736107], [74.61013794, 13.8676424], [74.60986328, 13.8676424], [74.60986328, 13.86792183], [74.60902405, 13.86791706], [74.60902405, 13.86819458], [74.60847473, 13.86819458], [74.60847473, 13.86847115], [74.60764313, 13.86847115], [74.60764313, 13.86875057], [74.60708618, 13.86875057], [74.60708618, 13.86903191], [74.60668182, 13.86903191], [74.60597229, 13.86903191], [74.60597229, 13.86931038], [74.60569763, 13.86930466], [74.60569763, 13.86958313], [74.60541534, 13.86958313], [74.60541534, 13.86986065], [74.60514069, 13.86986065], [74.60514069, 13.87014198], [74.6048584, 13.87013912], [74.6048584, 13.87069321], [74.60458374, 13.87069321], [74.60458374, 13.87097359], [74.60430908, 13.87097073], [74.60430908, 13.8712492], [74.60402679, 13.8712492], [74.60402679, 13.87208366], [74.60319519, 13.87208366], [74.60319519, 13.87236214], [74.60263824, 13.87235928], [74.60263824, 13.87263966], [74.60180664, 13.87263966], [74.60180664, 13.87403011], [74.60151672, 13.87403011], [74.60151672, 13.87486172], [74.60124969, 13.87486172], [74.60124969, 13.87569427], [74.60097504, 13.87569427], [74.60097504, 13.87652779], [74.60069275, 13.87652779], [74.60069275, 13.87736225], [74.60041809, 13.87736034], [74.60041809, 13.87792015], [74.6001358, 13.87791634], [74.6001358, 13.87847233], [74.59986115, 13.87847042], [74.59986115, 13.87903023], [74.59958649, 13.87902832], [74.59958649, 13.87958431], [74.59929657, 13.87957954], [74.59929657, 13.87985992], [74.59902954, 13.87985992], [74.59902954, 13.88042068], [74.59874725, 13.88041592], [74.59874725, 13.88097191], [74.5984726, 13.88097], [74.5984726, 13.88153076], [74.59819794, 13.8815279], [74.59819794, 13.88208199], [74.59791565, 13.88208199], [74.59791565, 13.88236237], [74.59764099, 13.88236046], [74.59764099, 13.88292122], [74.5973587, 13.88291645], [74.5973587, 13.88347244], [74.59707642, 13.88346958], [74.59707642, 13.8840313], [74.59680939, 13.88402939], [74.59680176, 13.88458157], [74.5965271, 13.88457966], [74.5965271, 13.88514137], [74.59625244, 13.88513756], [74.59625244, 13.88569546], [74.59597015, 13.88568974], [74.59597015, 13.88625145], [74.59570313, 13.88625145], [74.59570313, 13.88681126], [74.59541321, 13.88680458], [74.59541321, 13.88736057], [74.59513855, 13.88736057], [74.59513855, 13.88792133], [74.59486389, 13.88791656], [74.59486389, 13.88847256], [74.5945816, 13.88845921], [74.5945816, 13.89014053], [74.59430695, 13.89013863], [74.59430695, 13.89208317], [74.59402466, 13.89208317], [74.59402466, 13.89319515], [74.59375, 13.89319134], [74.59375, 13.89403152], [74.59348297, 13.89403152], [74.59348297, 13.8951416], [74.59319305, 13.8951416], [74.59319305, 13.89625168], [74.5929184, 13.89625168], [74.5929184, 13.89765072], [74.59263611, 13.89765072], [74.59263611, 13.89931011], [74.59236145, 13.8993063], [74.59236145, 13.90097237], [74.59208679, 13.90096855], [74.59208679, 13.90264034], [74.59179688, 13.90264034], [74.59179688, 13.90431118], [74.59152985, 13.90430641], [74.59152985, 13.90597153], [74.59124756, 13.90597153], [74.59124756, 13.90708447], [74.5909729, 13.9070797], [74.5909729, 13.90764046], [74.59069824, 13.9076376], [74.59069824, 13.90847206], [74.59041595, 13.90847015], [74.59041595, 13.90931129], [74.5901413, 13.90930557], [74.5901413, 13.90986347], [74.58985901, 13.90986347], [74.58985901, 13.91069412], [74.58957672, 13.91069031], [74.58957672, 13.91125107], [74.58930206, 13.91125107], [74.58930206, 13.91208458], [74.5890274, 13.91208458], [74.5890274, 13.91263866], [74.58875275, 13.91263199], [74.58875275, 13.91375065], [74.58847809, 13.91375065], [74.58847809, 13.91431141], [74.5881958, 13.91431141], [74.5881958, 13.91486073], [74.58791351, 13.91486073], [74.58791351, 13.91569519], [74.58763885, 13.91569042], [74.58763885, 13.91653061], [74.5873642, 13.91652679], [74.5873642, 13.91736126], [74.58708191, 13.91736126], [74.58708191, 13.91819477], [74.58680725, 13.91819], [74.58680725, 13.9187603], [74.58651733, 13.9187603], [74.58651733, 13.91930962], [74.58625031, 13.91930962], [74.58625031, 13.91986084], [74.58598328, 13.91986084], [74.58598328, 13.9204216], [74.58569336, 13.92041683], [74.58569336, 13.92097092], [74.5854187, 13.92097092], [74.5854187, 13.92153168], [74.58513641, 13.92152691], [74.58513641, 13.9220829], [74.58486176, 13.92208099], [74.58486176, 13.92264175], [74.5845871, 13.92263889], [74.5845871, 13.92319489], [74.58430481, 13.92319489], [74.58430481, 13.92347431], [74.58403015, 13.92347431], [74.58403015, 13.92360115], [74.58403015, 13.9240303], [74.58374786, 13.9240303], [74.58374786, 13.92430973], [74.58347321, 13.92430496], [74.58347321, 13.92458344], [74.58319092, 13.92457199], [74.58319092, 13.92486191], [74.58300781, 13.92486191], [74.58291626, 13.92486191], [74.58291626, 13.92514038], [74.58235168, 13.92514038], [74.58235168, 13.92541981], [74.57930756, 13.9254179], [74.57930756, 13.92569256], [74.57902527, 13.92569256], [74.5790329, 13.92625046], [74.57875061, 13.92625046], [74.57875061, 13.92708397], [74.57847595, 13.92708397], [74.57847595, 13.92763996], [74.57819366, 13.92763996], [74.57819366, 13.92847157], [74.57791901, 13.92847157], [74.57791901, 13.92903042], [74.57763672, 13.92903042], [74.57763672, 13.92986202], [74.57736206, 13.92986202], [74.57736206, 13.93041992], [74.57707977, 13.93041992], [74.57707977, 13.93124962], [74.57681274, 13.93124962], [74.57681274, 13.93181133], [74.57653809, 13.93181133], [74.57653809, 13.93264008], [74.57624817, 13.93264008], [74.57624817, 13.93319416], [74.57596588, 13.93318939], [74.57596588, 13.9337616], [74.57569122, 13.9337616], [74.57569122, 13.93431091], [74.57541656, 13.93430614], [74.57541656, 13.93486023], [74.57514191, 13.93486023], [74.57514191, 13.93542099], [74.57485962, 13.93541622], [74.57485962, 13.93597221], [74.57459259, 13.93597031], [74.57459259, 13.93653107], [74.57430267, 13.93652821], [74.57430267, 13.93708229], [74.57402802, 13.93708038], [74.57402802, 13.93764114], [74.57375336, 13.93763828], [74.57375336, 13.93819427], [74.57347107, 13.93819427], [74.5734787, 13.93875122], [74.57319641, 13.93875122], [74.57319641, 13.93931103], [74.57291412, 13.93930435], [74.57291412, 13.9398613], [74.57263947, 13.9398613], [74.57263947, 13.9404211], [74.57236481, 13.94041729], [74.57236481, 13.94097328], [74.57208252, 13.94097042], [74.57208252, 13.94153118], [74.57180786, 13.94152737], [74.57180786, 13.94208336], [74.5715332, 13.94207954], [74.5715332, 13.94293118], [74.57125092, 13.94293118], [74.57125092, 13.94375134], [74.57096863, 13.94375134], [74.57096863, 13.94430923], [74.57068634, 13.94430923], [74.57068634, 13.94514084], [74.57041931, 13.94513893], [74.57041931, 13.94526196], [74.57041931, 13.9459734], [74.57013702, 13.94597054], [74.57013702, 13.94652939], [74.56986237, 13.94652939], [74.56986237, 13.94680977], [74.56958008, 13.946805], [74.56958008, 13.94708347], [74.56903076, 13.94708061], [74.56903076, 13.94764137], [74.56846619, 13.94764137], [74.56846619, 13.94792175], [74.56819153, 13.94791698], [74.56819153, 13.94819546], [74.56791687, 13.94819546], [74.56791687, 13.94847107], [74.56735992, 13.94847107], [74.56735992, 13.94874859], [74.56680298, 13.94874001], [74.56680298, 13.94903183], [74.56597137, 13.94903183], [74.56597137, 13.94874001], [74.56569672, 13.94874859], [74.56569672, 13.94847107], [74.56513977, 13.94847107], [74.56513977, 13.94819546], [74.56485748, 13.94819546], [74.56485748, 13.94791698], [74.56430817, 13.94792175], [74.56430817, 13.94764137], [74.56402588, 13.94764137], [74.56402588, 13.94716072], [74.56402588, 13.94708347], [74.56375122, 13.94708347], [74.56375122, 13.94624901], [74.56346893, 13.94625092], [74.56346893, 13.94569969], [74.56318665, 13.94569969], [74.56318665, 13.94541931], [74.56153107, 13.94541931], [74.56153107, 13.94569969], [74.56041718, 13.94569492], [74.56041718, 13.9459734], [74.56014252, 13.94597054], [74.56014252, 13.94625092], [74.56041718, 13.94625092], [74.56041718, 13.94652939], [74.56014252, 13.94652939], [74.56014252, 13.94736099], [74.55986023, 13.94736099], [74.55986023, 13.9482317], [74.55986023, 13.94903183], [74.5595932, 13.94903183], [74.5595932, 13.9493103], [74.55930328, 13.94930458], [74.55930328, 13.94958305], [74.55902863, 13.94958305], [74.55902863, 13.94986057], [74.55874634, 13.94986057], [74.55874634, 13.95014191], [74.55847168, 13.95014191], [74.55847168, 13.95042038], [74.55819702, 13.95041656], [74.55819702, 13.95069313], [74.55791473, 13.95069313], [74.55791473, 13.95097446], [74.55764008, 13.95097065], [74.55764008, 13.95125198], [74.55541229, 13.95125198], [74.55541229, 13.95097065], [74.55430603, 13.95097446], [74.55430603, 13.95069313], [74.55319214, 13.95069313], [74.55319214, 13.95041656], [74.55291748, 13.95042038], [74.55291748, 13.95014191], [74.55264282, 13.95014191], [74.55263519, 13.95004845], [74.55261993, 13.94986057], [74.55208588, 13.94986057], [74.55208588, 13.94958305], [74.55180359, 13.94958305], [74.55180359, 13.94930458], [74.55152893, 13.9493103], [74.55152893, 13.94903183], [74.55124664, 13.94903183], [74.55124664, 13.94874001], [74.55069733, 13.94874859], [74.55069733, 13.94847107], [74.55041504, 13.94847107], [74.55041504, 13.94819546], [74.54985809, 13.94819546], [74.54985809, 13.94847107], [74.54875183, 13.94847107], [74.54875183, 13.94874859], [74.54846954, 13.94875145], [74.54846954, 13.95097446], [74.54819489, 13.95097446], [74.54819489, 13.95180511], [74.54792023, 13.95180511], [74.54792023, 13.95282173], [74.54792023, 13.95291805], [74.5477829, 13.95291996], [74.54763794, 13.95291996], [74.54763794, 13.95374966], [74.54736328, 13.95374966], [74.54736328, 13.95431042], [74.54708099, 13.95431042], [74.54708099, 13.95487118], [74.54680634, 13.95487118], [74.54680634, 13.95541954], [74.54652405, 13.95541573], [74.54652405, 13.95597172], [74.54624176, 13.95596886], [74.54624176, 13.95652962], [74.54486084, 13.95652962], [74.54486084, 13.95681], [74.54347229, 13.95680618], [74.54347229, 13.9570837], [74.54208374, 13.9570837], [74.54208374, 13.95736217], [74.54180908, 13.95736027], [74.54180908, 13.95763969], [74.54152679, 13.95763969], [74.54152679, 13.95792866], [74.54141998, 13.95792866], [74.54125214, 13.95792866], [74.54125214, 13.95875168], [74.54096985, 13.95874977], [74.54096985, 13.95958424], [74.54069519, 13.95958424], [74.54069519, 13.96177197], [74.54069519, 13.96236229], [74.54058075, 13.96236229], [74.5404129, 13.96236038], [74.5404129, 13.96292114], [74.53986359, 13.96291637], [74.53986359, 13.96347237], [74.5395813, 13.96347046], [74.5395813, 13.96431065], [74.53901672, 13.96431065], [74.53901672, 13.96485996], [74.53874969, 13.96485996], [74.53874969, 13.9651413], [74.53848267, 13.9651413], [74.53848267, 13.96542072], [74.53791809, 13.96541595], [74.53791809, 13.96569538], [74.5376358, 13.96569538], [74.5376358, 13.9659729], [74.53708649, 13.96597004], [74.53708649, 13.96625137], [74.53679657, 13.96625137], [74.53679657, 13.9665308], [74.5359726, 13.9665308], [74.5359726, 13.96681118], [74.53542328, 13.96681118], [74.53542328, 13.9665308], [74.5348587, 13.9665308], [74.5348587, 13.96625137], [74.53457642, 13.96625137], [74.53457642, 13.96568966], [74.53430176, 13.96569538], [74.53430176, 13.96513844], [74.5340271, 13.9651413], [74.5340271, 13.96457958], [74.53180695, 13.96457958], [74.53180695, 13.96485996], [74.53151703, 13.96485996], [74.53151703, 13.96903133], [74.53124237, 13.96903133], [74.53124237, 13.96986961], [74.53098297, 13.96986961], [74.53098297, 13.97014141], [74.53069305, 13.97014141], [74.53069305, 13.97042084], [74.5304184, 13.97041702], [74.5304184, 13.97097301], [74.53013611, 13.97097111], [74.53013611, 13.97125053], [74.52986145, 13.97125053], [74.52986145, 13.97180939], [74.52958679, 13.97180462], [74.52958679, 13.97208309], [74.5293045, 13.97208309], [74.5293045, 13.97236061], [74.52902985, 13.97236061], [74.52902985, 13.97264099], [74.52874756, 13.97264099], [74.52874756, 13.97293091], [74.52819824, 13.9729166], [74.52819824, 13.97319508], [74.52735901, 13.97319508], [74.52735901, 13.9734726], [74.5265274, 13.97347069], [74.5265274, 13.97375107], [74.52540588, 13.97375107], [74.52540588, 13.97431183], [74.52513885, 13.97430515], [74.52513885, 13.97458267], [74.52485657, 13.97458076], [74.52485657, 13.97514153], [74.52458191, 13.97514153], [74.52458191, 13.97542191], [74.52430725, 13.97541714], [74.52430725, 13.97569466], [74.52403259, 13.9756794], [74.52403259, 13.97625065], [74.52375031, 13.97625065], [74.52375031, 13.97653198], [74.52348328, 13.97653198], [74.52348328, 13.9776392], [74.5229187, 13.9776392], [74.5229187, 13.97791958], [74.52263641, 13.97791767], [74.52263641, 13.9784708], [74.5220871, 13.97846889], [74.5220871, 13.97902966], [74.52180481, 13.97902679], [74.52180481, 13.97958374], [74.52153015, 13.97958374], [74.52153015, 13.97986221], [74.52124786, 13.97985935], [74.52124786, 13.98042011], [74.52097321, 13.98041534], [74.52097321, 13.98097229], [74.52069092, 13.98096943], [74.52069092, 13.98125172], [74.52041626, 13.98125172], [74.52041626, 13.98180962], [74.5201416, 13.98180962], [74.5201416, 13.98236179], [74.51985931, 13.98236179], [74.51985931, 13.98264027], [74.51902771, 13.98264027], [74.51902771, 13.98291969], [74.51819611, 13.98291779], [74.51819611, 13.98319435], [74.51791382, 13.98319435], [74.51791382, 13.98347187], [74.51763916, 13.98347187], [74.51763916, 13.98402977], [74.51735687, 13.98402977], [74.51735687, 13.98431015], [74.51708221, 13.98430634], [74.51708221, 13.98458385], [74.5165329, 13.98458195], [74.5165329, 13.98487091], [74.51625824, 13.98487091], [74.51625824, 13.98513985], [74.51597595, 13.98513985], [74.51597595, 13.98542023], [74.51569366, 13.98541641], [74.51569366, 13.98569393], [74.51513672, 13.98569393], [74.51513672, 13.9859724], [74.51486206, 13.98596954], [74.51486206, 13.98624992], [74.51457977, 13.98624992], [74.51457977, 13.98764038], [74.51431274, 13.98764038], [74.51431274, 13.99014091], [74.51403046, 13.99014091], [74.51403046, 13.9918108], [74.51374817, 13.9918108], [74.51374817, 13.99236012], [74.51346588, 13.99236012], [74.51346588, 13.99292088], [74.51319122, 13.99291706], [74.51319122, 13.99569511], [74.51291656, 13.99569035], [74.51291656, 13.99625111], [74.51264191, 13.99625111], [74.51264191, 13.99681187], [74.51235962, 13.99680519], [74.51235962, 13.99708271], [74.51208496, 13.99708271], [74.51208496, 13.99736118], [74.51180267, 13.99736118], [74.51180267, 13.99792099], [74.51152802, 13.99792099], [74.51152802, 13.99875069], [74.51125336, 13.99875069], [74.51125336, 13.99903107], [74.51097107, 13.99903107], [74.51097107, 13.99930859], [74.50985718, 13.99930859], [74.50985718, 13.99992943], [74.50985718, 14.00013924], [74.51013184, 14.00013924], [74.51013184, 14.00097084], [74.50985718, 14.00097084], [74.50985718, 14.00125122], [74.50958252, 14.00125122], [74.50958252, 14.00181198], [74.50930786, 14.00180531], [74.50930786, 14.00208282], [74.5090332, 14.00208092], [74.5090332, 14.00264168], [74.50875092, 14.00263882], [74.50875092, 14.00458336], [74.50902557, 14.00458336], [74.50902557, 14.00708389], [74.50875092, 14.00708103], [74.50875092, 14.00764179], [74.50846863, 14.00763988], [74.50846863, 14.00819111], [74.50818634, 14.00819969], [74.50818634, 14.00904083], [74.50791931, 14.00902843], [74.50791931, 14.00958443], [74.50763702, 14.00958157], [74.50763702, 14.01014042], [74.50736237, 14.01013756], [74.50736237, 14.01097202], [74.50707245, 14.01097202], [74.50707245, 14.01152992], [74.50680542, 14.01152802], [74.50680542, 14.01236153], [74.50653076, 14.01235962], [74.50653076, 14.01292038], [74.50624847, 14.01291561], [74.50624847, 14.0134716], [74.50596619, 14.0134697], [74.50596619, 14.01431084], [74.50569153, 14.01430607], [74.50569153, 14.01486015], [74.50541687, 14.01485062], [74.50541687, 14.01542091], [74.50514221, 14.01541615], [74.50514221, 14.01597214], [74.50485992, 14.01597023], [74.50485992, 14.01653099], [74.50458527, 14.01652813], [74.50458527, 14.01708221], [74.50430298, 14.01708031], [74.50430298, 14.01764107], [74.50402832, 14.01763821], [74.50402832, 14.0181942], [74.50374603, 14.01819038], [74.50374603, 14.01875114], [74.50347137, 14.01875114], [74.50347137, 14.01931095], [74.50319672, 14.01930428], [74.50319672, 14.01986027], [74.5029068, 14.01986027], [74.5029068, 14.02042103], [74.50263977, 14.02042103], [74.50263977, 14.02098179], [74.50235748, 14.02098179], [74.50235748, 14.02153111], [74.50208282, 14.0215292], [74.50208282, 14.02208328], [74.50180817, 14.02208042], [74.50180817, 14.02264118], [74.50152588, 14.02264118], [74.50152588, 14.02375126], [74.50125122, 14.02375126], [74.50125122, 14.02486134], [74.50152588, 14.02486134], [74.50152588, 14.02514076], [74.50208282, 14.02514076], [74.50208282, 14.02541924], [74.50235748, 14.02541924], [74.50235748, 14.02625084], [74.5029068, 14.02625084], [74.5029068, 14.02652931], [74.50485992, 14.02652931], [74.50485992, 14.02625084], [74.50569153, 14.02625084], [74.50569153, 14.02652931], [74.50596619, 14.02652931], [74.50596619, 14.02680969], [74.50624847, 14.02680492], [74.50624847, 14.0270834], [74.50653076, 14.02708054], [74.50653076, 14.02736092], [74.50681305, 14.02736092], [74.50681305, 14.0276413], [74.50763702, 14.0276413], [74.50763702, 14.02792168], [74.51097107, 14.02792168], [74.51097107, 14.0276413], [74.51125336, 14.0276413], [74.51125336, 14.02792168], [74.5118866, 14.02791691], [74.51209259, 14.02792168], [74.51210022, 14.0276413], [74.51346588, 14.0276413], [74.51346588, 14.02736092], [74.51403046, 14.02736092], [74.51403046, 14.02708054], [74.51457977, 14.0270834], [74.51457977, 14.02680492], [74.51513672, 14.02680969], [74.51513672, 14.02652931], [74.51568604, 14.02652931], [74.51568604, 14.02625084], [74.51763916, 14.02625084], [74.51763916, 14.02680969], [74.51791382, 14.02680492], [74.51791382, 14.0270834], [74.51763916, 14.02708054], [74.51763916, 14.02736092], [74.51735687, 14.02736092], [74.51735687, 14.0276413], [74.51680756, 14.0276413], [74.51680756, 14.02792168], [74.51652527, 14.02791691], [74.51652527, 14.02819538], [74.51597595, 14.02819538], [74.51597595, 14.02847099], [74.51568604, 14.02847099], [74.51568604, 14.02875137], [74.51541901, 14.02875137], [74.51541901, 14.02903175], [74.51513672, 14.02903175], [74.51513672, 14.02931023], [74.51457977, 14.02930546], [74.51457977, 14.02958298], [74.51374817, 14.02958298], [74.51374817, 14.02986145], [74.51345825, 14.02986145], [74.51291656, 14.02986145], [74.51291656, 14.03015137], [74.51235962, 14.03015137], [74.51235962, 14.0304203], [74.51180267, 14.03041744], [74.51180267, 14.03069305], [74.51152802, 14.03069305], [74.51152802, 14.03097439], [74.51097107, 14.03097057], [74.51097107, 14.03125191], [74.51040649, 14.03125191], [74.51040649, 14.03153038], [74.5090332, 14.03153038], [74.5090332, 14.03180981], [74.50846863, 14.03180504], [74.50846863, 14.03208256], [74.50814819, 14.03208065], [74.50791931, 14.03208065], [74.50791931, 14.03236198], [74.50736237, 14.03236198], [74.50736237, 14.03292179], [74.50708008, 14.03291798], [74.50708008, 14.03319645], [74.50681305, 14.03319073], [74.50681305, 14.03374958], [74.50653076, 14.03374958], [74.50653076, 14.03431034], [74.50708008, 14.03430557], [74.50708008, 14.03458405], [74.50736237, 14.03457928], [74.50736237, 14.03542042], [74.50763702, 14.03542042], [74.50763702, 14.03625202], [74.50791931, 14.03625011], [74.50791931, 14.03708363], [74.50818634, 14.03707886], [74.50818634, 14.03792], [74.50846863, 14.03791809], [74.50846863, 14.0381937], [74.50875092, 14.0381918], [74.50875092, 14.03874969], [74.50902557, 14.03874969], [74.50902557, 14.03902817], [74.50708008, 14.03902817], [74.50708008, 14.0381937], [74.50680542, 14.0381937], [74.50680542, 14.03763771], [74.50624847, 14.03763962], [74.50624847, 14.03736019], [74.50596619, 14.03736019], [74.50596619, 14.03763962], [74.50569153, 14.03763771], [74.50569153, 14.0381937], [74.50541687, 14.0381918], [74.50541687, 14.03874969], [74.50514221, 14.03874969], [74.50514221, 14.03931141], [74.50485992, 14.03930569], [74.50485992, 14.03959084], [74.50485992, 14.03986168], [74.50458527, 14.03985977], [74.50458527, 14.04064178], [74.5045929, 14.04181099], [74.50428009, 14.04180622], [74.50402832, 14.04181099], [74.50402832, 14.04125023], [74.50374603, 14.04125023], [74.50374603, 14.04068947], [74.50347137, 14.04069424], [74.50347137, 14.03902817], [74.50375366, 14.03902817], [74.50375366, 14.03763771], [74.50402832, 14.03763962], [74.50402832, 14.03736019], [74.50430298, 14.0373621], [74.50430298, 14.03680611], [74.5045929, 14.03680992], [74.5045929, 14.03652954], [74.50485992, 14.03652954], [74.50485992, 14.0359602], [74.50458527, 14.03597164], [74.50458527, 14.03541565], [74.50430298, 14.03542042], [74.50430298, 14.03402996], [74.50485992, 14.03402996], [74.50485992, 14.0334692], [74.50569153, 14.03347111], [74.50569153, 14.03291798], [74.50596619, 14.03292179], [74.50596619, 14.03264046], [74.50514221, 14.03264046], [74.50514221, 14.03208065], [74.50541687, 14.03208256], [74.50541687, 14.03152657], [74.50569153, 14.03153038], [74.50569153, 14.03125191], [74.50596619, 14.03125191], [74.50596619, 14.0304203], [74.50624847, 14.0304203], [74.50624847, 14.02986145], [74.50569153, 14.02986145], [74.50569153, 14.02958298], [74.50541687, 14.02958298], [74.50541687, 14.02930546], [74.50485992, 14.02931023], [74.50485992, 14.02903175], [74.50430298, 14.02903175], [74.50430298, 14.02875137], [74.50402832, 14.02875137], [74.50402832, 14.02847099], [74.50347137, 14.02847099], [74.50347137, 14.02819538], [74.50319672, 14.02819538], [74.50319672, 14.02791691], [74.50263977, 14.02792168], [74.50263977, 14.0276413], [74.50235748, 14.0276413], [74.50235748, 14.02736092], [74.50208282, 14.02736092], [74.50208282, 14.02708054], [74.50180817, 14.02708054], [74.50180817, 14.02736092], [74.50125122, 14.02736092], [74.50125122, 14.0270834], [74.50096893, 14.02708054], [74.50096893, 14.02903175], [74.50068665, 14.02903175], [74.50068665, 14.03180981], [74.50096893, 14.03180981], [74.50096893, 14.03652954], [74.50069427, 14.03652763], [74.50069427, 14.04069424], [74.50041962, 14.04069424], [74.50041962, 14.04319382], [74.50013733, 14.04319191], [74.50013733, 14.04486275], [74.49986267, 14.04486275], [74.49986267, 14.04653072], [74.49958038, 14.04652882], [74.49958038, 14.04819489], [74.49930573, 14.04819489], [74.49931335, 14.04986095], [74.49903107, 14.04986095], [74.49903107, 14.05125141], [74.49874878, 14.05125141], [74.49874878, 14.05236053], [74.49847412, 14.05236053], [74.49847412, 14.05347347], [74.49819183, 14.05347347], [74.49819183, 14.0545826], [74.49791718, 14.0545826], [74.49791718, 14.05569458], [74.49764252, 14.05569077], [74.49764252, 14.05681038], [74.49736023, 14.05681038], [74.49736023, 14.05792046], [74.4970932, 14.05792046], [74.4970932, 14.05902958], [74.49680328, 14.05902672], [74.49680328, 14.06013966], [74.49652863, 14.06013012], [74.49652863, 14.06124973], [74.49624634, 14.06124973], [74.49624634, 14.06236172], [74.49597168, 14.06236172], [74.49597168, 14.06347179], [74.49569702, 14.06347179], [74.49569702, 14.06431007], [74.4954071, 14.06431007], [74.4954071, 14.06542015], [74.49513245, 14.06542015], [74.49513245, 14.06653023], [74.49485779, 14.06653023], [74.49485779, 14.0676403], [74.49458313, 14.0676403], [74.49458313, 14.06903267], [74.49430847, 14.06903267], [74.49430847, 14.07042122], [74.49402618, 14.07042122], [74.49402618, 14.07181072], [74.49375153, 14.07180691], [74.49375153, 14.07319546], [74.49346924, 14.07318974], [74.49346924, 14.07431126], [74.49319458, 14.07430363], [74.49319458, 14.07569504], [74.49291992, 14.07569504], [74.49291992, 14.07708263], [74.49263763, 14.07708263], [74.49263763, 14.07847309], [74.49236298, 14.07847118], [74.49236298, 14.07930946], [74.49207306, 14.07930946], [74.49207306, 14.07986069], [74.49180603, 14.07986069], [74.49180603, 14.08041859], [74.49153137, 14.08041668], [74.49153137, 14.08097267], [74.49124908, 14.08096886], [74.49124908, 14.08153152], [74.49097443, 14.08152676], [74.49097443, 14.08208275], [74.49069214, 14.08208084], [74.49069214, 14.0826416], [74.49041748, 14.0826416], [74.49041748, 14.08292198], [74.49013519, 14.08291721], [74.49013519, 14.0834713], [74.48986053, 14.0834713], [74.48986053, 14.08403015], [74.48958588, 14.08402729], [74.48958588, 14.08458328], [74.48929596, 14.08458138], [74.48929596, 14.08513927], [74.48902893, 14.08513927], [74.48902893, 14.08569336], [74.48874664, 14.08569145], [74.48874664, 14.08624935], [74.48847198, 14.08624935], [74.48847198, 14.08681011], [74.48819733, 14.08680534], [74.48819733, 14.08847237], [74.48847198, 14.08847237], [74.48847198, 14.09069443], [74.48819733, 14.09069061], [74.48819733, 14.09181023], [74.48792267, 14.09181023], [74.48792267, 14.09263992], [74.48735809, 14.09263992], [74.48735809, 14.0929203], [74.48707581, 14.0929203], [74.48707581, 14.09320068], [74.48652649, 14.09319401], [74.48652649, 14.09347153], [74.48458099, 14.09347153], [74.48458099, 14.09291553], [74.48430634, 14.0929203], [74.48430634, 14.09208202], [74.48374939, 14.09208393], [74.48374939, 14.0923624], [74.4834671, 14.09235954], [74.4834671, 14.09263992], [74.48291779, 14.09263992], [74.48291779, 14.0929203], [74.48264313, 14.0929203], [74.48264313, 14.09320068], [74.48152924, 14.09320068], [74.48152924, 14.0929203], [74.48069763, 14.0929203], [74.48069763, 14.09320068], [74.48042297, 14.09320068], [74.48042297, 14.09375], [74.48069763, 14.09375], [74.48069763, 14.09431076], [74.48097229, 14.09431076], [74.48097229, 14.09486008], [74.48264313, 14.09486008], [74.48264313, 14.09514046], [74.48291779, 14.09514046], [74.48291779, 14.09542274], [74.48319244, 14.09542274], [74.48319244, 14.09514046], [74.48374939, 14.09514046], [74.48374939, 14.09486008], [74.48513794, 14.09486008], [74.48513794, 14.0945797], [74.48596954, 14.0945797], [74.48596954, 14.09514046], [74.48625183, 14.0951376], [74.48625183, 14.09597206], [74.48652649, 14.09597015], [74.48652649, 14.09653091], [74.48680878, 14.09653091], [74.48680878, 14.09735966], [74.48708344, 14.09736156], [74.48708344, 14.09958458], [74.48735809, 14.09958172], [74.48735809, 14.10264111], [74.48764038, 14.10264111], [74.48764038, 14.1054306], [74.48792267, 14.1054306], [74.48792267, 14.11042023], [74.48764038, 14.11042023], [74.48764038, 14.11180973], [74.48680878, 14.11180973], [74.48680878, 14.11069107], [74.48652649, 14.11069489], [74.48652649, 14.10986137], [74.48625183, 14.10986137], [74.48625183, 14.11042023], [74.48596954, 14.11041737], [74.48596954, 14.11097336], [74.48568726, 14.11097145], [74.48568726, 14.11180973], [74.48542023, 14.11180973], [74.48542023, 14.11236095], [74.48513794, 14.11236095], [74.48513794, 14.11347103], [74.48486328, 14.11347103], [74.48486328, 14.11514187], [74.48458099, 14.11514187], [74.48458099, 14.11653042], [74.48430634, 14.11652756], [74.48430634, 14.11819363], [74.48401642, 14.11818886], [74.48402405, 14.1198597], [74.48374939, 14.1198597], [74.48374939, 14.12125015], [74.4834671, 14.12125015], [74.4834671, 14.12292099], [74.48319244, 14.12292099], [74.48319244, 14.12431145], [74.48291779, 14.12431145], [74.48291779, 14.12597179], [74.48264313, 14.12597179], [74.48264313, 14.12764072], [74.48236084, 14.12764072], [74.48236084, 14.12903118], [74.48208618, 14.12902641], [74.48208618, 14.13069534], [74.48179626, 14.13068962], [74.48179626, 14.13180923], [74.48152924, 14.13180923], [74.48152924, 14.13264084], [74.48124695, 14.13263893], [74.48124695, 14.1334734], [74.48097229, 14.13347054], [74.48097229, 14.13431168], [74.48069763, 14.13431168], [74.48069763, 14.13514137], [74.48042297, 14.13514137], [74.48041534, 14.13624859], [74.48014069, 14.13625145], [74.48014069, 14.13695145], [74.48014069, 14.13708305], [74.4798584, 14.13708115], [74.4798584, 14.13792038], [74.47957611, 14.13792038], [74.47957611, 14.13875198], [74.47930908, 14.13875198], [74.47930908, 14.13931179], [74.47902679, 14.13930511], [74.47902679, 14.13986111], [74.47820282, 14.1398592], [74.47820282, 14.14013958], [74.47735596, 14.14013958], [74.47735596, 14.14041996], [74.47652435, 14.14041805], [74.47652435, 14.14069557], [74.47680664, 14.14069557], [74.47680664, 14.14097118], [74.47708893, 14.14096928], [74.47708893, 14.14154053], [74.47736359, 14.14152813], [74.47736359, 14.14208412], [74.47763824, 14.14208126], [74.47763824, 14.14264202], [74.4779129, 14.14264011], [74.4779129, 14.1431942], [74.47819519, 14.1431942], [74.47819519, 14.14375019], [74.47846985, 14.14375019], [74.47846985, 14.14735985], [74.47820282, 14.14735126], [74.47820282, 14.14902973], [74.4779129, 14.14902782], [74.4779129, 14.14986229], [74.47846985, 14.14986229], [74.47846985, 14.14958191], [74.47902679, 14.14958191], [74.47902679, 14.15014267], [74.47875214, 14.1501379], [74.47875214, 14.15069389], [74.47846985, 14.15069199], [74.47846985, 14.15125275], [74.47820282, 14.15125275], [74.47820282, 14.15181065], [74.4779129, 14.15181065], [74.4779129, 14.15235996], [74.47763824, 14.15235996], [74.47763824, 14.15292072], [74.47735596, 14.15292072], [74.47735596, 14.15348244], [74.47708893, 14.15348244], [74.47708893, 14.1540308], [74.47680664, 14.1540308], [74.47680664, 14.15514088], [74.47651672, 14.15514088], [74.47651672, 14.15653992], [74.47624969, 14.15653992], [74.47624969, 14.15792084], [74.47598267, 14.15792084], [74.47598267, 14.15930939], [74.47569275, 14.15930939], [74.47569275, 14.16041946], [74.47541809, 14.16041946], [74.47541809, 14.16181183], [74.4751358, 14.16180515], [74.4751358, 14.16319466], [74.47486115, 14.16319466], [74.47486115, 14.16458321], [74.47458649, 14.1645813], [74.47458649, 14.16541958], [74.4743042, 14.16541672], [74.4743042, 14.1659708], [74.47402954, 14.16597366], [74.47402954, 14.16708279], [74.47429657, 14.16708088], [74.47429657, 14.16875172], [74.47402954, 14.16875172], [74.47402954, 14.16930962], [74.47374725, 14.16930962], [74.47374725, 14.16986179], [74.4734726, 14.16986179], [74.4734726, 14.17097187], [74.47319794, 14.17097187], [74.47319794, 14.17208385], [74.47291565, 14.17208385], [74.47291565, 14.17319393], [74.47264099, 14.17319202], [74.47264099, 14.17431068], [74.4723587, 14.17431068], [74.4723587, 14.17542267], [74.47207642, 14.17542267], [74.47207642, 14.17653275], [74.47180939, 14.17652798], [74.47180176, 14.17736244], [74.4715271, 14.17735958], [74.4715271, 14.1779213], [74.47125244, 14.17791557], [74.47125244, 14.17847157], [74.47097015, 14.17847157], [74.47097015, 14.18069363], [74.4706955, 14.18069363], [74.4706955, 14.18319511], [74.47097015, 14.18319511], [74.47097015, 14.18347263], [74.4706955, 14.18347263], [74.47070313, 14.18375111], [74.47041321, 14.18375111], [74.47041321, 14.18431091], [74.47013855, 14.18431091], [74.47013855, 14.18542099], [74.46985626, 14.18542099], [74.46985626, 14.18625069], [74.4695816, 14.18624878], [74.4695816, 14.18708324], [74.46930695, 14.18708324], [74.46930695, 14.18819523], [74.46901703, 14.18819141], [74.46901703, 14.18875122], [74.46875, 14.18875122], [74.46875, 14.1890316], [74.46847534, 14.18902683], [74.46847534, 14.18958282], [74.46819305, 14.18958092], [74.46819305, 14.19014168], [74.4679184, 14.19013882], [74.4679184, 14.19097328], [74.46763611, 14.19097137], [74.46763611, 14.19153023], [74.46736145, 14.19152737], [74.46736145, 14.19208336], [74.46708679, 14.19208145], [74.46708679, 14.19291973], [74.4668045, 14.19291687], [74.4668045, 14.19347095], [74.46652985, 14.19347095], [74.46652985, 14.19625187], [74.46679688, 14.19625187], [74.46679688, 14.19680977], [74.46652985, 14.19680977], [74.46652985, 14.19736195], [74.46624756, 14.19736195], [74.46624756, 14.19764042], [74.4659729, 14.19763756], [74.4659729, 14.19819355], [74.46569824, 14.19819355], [74.46569824, 14.19847202], [74.46541595, 14.19845963], [74.4654007, 14.19902992], [74.46514893, 14.19902992], [74.46514893, 14.1993103], [74.46485901, 14.19930553], [74.46485901, 14.19958401], [74.46458435, 14.19958401], [74.46458435, 14.19986153], [74.4640274, 14.19985962], [74.4640274, 14.20014], [74.46375275, 14.20014], [74.46375275, 14.20042038], [74.46347046, 14.20041561], [74.46347046, 14.20069408], [74.4631958, 14.20069408], [74.4631958, 14.2009716], [74.46013641, 14.2009716], [74.46013641, 14.20083141], [74.46013641, 14.20069408], [74.45986176, 14.20069408], [74.45986176, 14.20014], [74.4595871, 14.20014], [74.4595871, 14.19985962], [74.45930481, 14.19986153], [74.45930481, 14.19958401], [74.45903015, 14.19958401], [74.45903015, 14.19930553], [74.45874786, 14.1993103], [74.45874786, 14.19902992], [74.45847321, 14.19902992], [74.45847321, 14.19874954], [74.45819092, 14.19874954], [74.45819092, 14.19845963], [74.45791626, 14.19845963], [74.45791626, 14.19874954], [74.4576416, 14.19874954], [74.4576416, 14.19902992], [74.45707703, 14.19902992], [74.45707703, 14.1993103], [74.45680237, 14.19930553], [74.45680237, 14.19958401], [74.45625305, 14.19958401], [74.45625305, 14.19986153], [74.45596313, 14.19985962], [74.45596313, 14.20014], [74.45485687, 14.20014], [74.45485687, 14.19985962], [74.45458221, 14.19986153], [74.45458221, 14.19958401], [74.45430756, 14.19958401], [74.45430756, 14.19930553], [74.45402527, 14.19930553], [74.45402527, 14.19986153], [74.45375061, 14.19985962], [74.45375061, 14.20042038], [74.45347595, 14.20041561], [74.45347595, 14.2009716], [74.45319366, 14.2009716], [74.45319366, 14.2015276], [74.45347595, 14.20152092], [74.45347595, 14.20181084], [74.45375061, 14.20180607], [74.45375061, 14.20236206], [74.4540329, 14.20236015], [74.4540329, 14.20263958], [74.45430756, 14.20263958], [74.45430756, 14.20292091], [74.45402527, 14.20291615], [74.45402527, 14.20319366], [74.45375061, 14.20319366], [74.45375061, 14.20347214], [74.45347595, 14.20347023], [74.45347595, 14.20374966], [74.45318604, 14.20374966], [74.45318604, 14.20403099], [74.45291901, 14.20403099], [74.45291901, 14.20431137], [74.45263672, 14.20431137], [74.45263672, 14.20485973], [74.45236206, 14.20485973], [74.45236206, 14.20542145], [74.45263672, 14.20542145], [74.45263672, 14.20653057], [74.45291901, 14.20652771], [74.45291901, 14.20736027], [74.45236206, 14.20736027], [74.45236206, 14.20765018], [74.45153046, 14.20765018], [74.45153046, 14.20792103], [74.45097351, 14.20791626], [74.45097351, 14.20819473], [74.45069122, 14.20818996], [74.45069122, 14.20875072], [74.45041656, 14.20875072], [74.45041656, 14.2098608], [74.45069122, 14.2098608], [74.45069122, 14.21014118], [74.45097351, 14.21013927], [74.45097351, 14.21069527], [74.45069122, 14.21069527], [74.45069122, 14.21097279], [74.45041656, 14.21097088], [74.45041656, 14.21153069], [74.45014954, 14.21153069], [74.45014954, 14.21181202], [74.44902802, 14.21181202], [74.44902802, 14.21291924], [74.44930267, 14.21291733], [74.44930267, 14.21347332], [74.44958496, 14.21347332], [74.44958496, 14.21569538], [74.44930267, 14.21569061], [74.44930267, 14.21653175], [74.44847107, 14.21652699], [74.44847107, 14.21736145], [74.44875336, 14.21736145], [74.44875336, 14.21819305], [74.44819641, 14.21819305], [74.44819641, 14.21847343], [74.44790649, 14.21847057], [74.44790649, 14.21875191], [74.44763947, 14.21875191], [74.44763947, 14.21903038], [74.44735718, 14.21903038], [74.44735718, 14.21930981], [74.44708252, 14.21930981], [74.44708252, 14.21959019], [74.44596863, 14.21959019], [74.44596863, 14.21986103], [74.44541931, 14.21986103], [74.44541931, 14.22013855], [74.44458008, 14.22013855], [74.44458008, 14.22042179], [74.44403076, 14.22041798], [74.44403076, 14.22236156], [74.44374847, 14.22236156], [74.44374847, 14.22264004], [74.44346619, 14.22263145], [74.44346619, 14.22292042], [74.44319153, 14.2229147], [74.44319153, 14.22319412], [74.44291687, 14.22319412], [74.44291687, 14.22347164], [74.44264221, 14.22347164], [74.44264221, 14.22375202], [74.44180298, 14.22375011], [74.44180298, 14.2248621], [74.44152832, 14.22486019], [74.44152832, 14.22624969], [74.4420929, 14.22624969], [74.4420929, 14.22653008], [74.44235992, 14.22653008], [74.44235992, 14.22681141], [74.44264221, 14.22680569], [74.44264221, 14.22708416], [74.44291687, 14.22707939], [74.44291687, 14.22791958], [74.44264221, 14.22791958], [74.44264221, 14.22902966], [74.44235992, 14.22902775], [74.44235992, 14.22986221], [74.44208527, 14.22986221], [74.44208527, 14.23069382], [74.44180298, 14.23069191], [74.44180298, 14.23153114], [74.44152832, 14.23153114], [74.44152832, 14.23236179], [74.44125366, 14.23235989], [74.44125366, 14.23319435], [74.440979, 14.23318958], [74.440979, 14.23403072], [74.44069672, 14.23402882], [74.44069672, 14.23486042], [74.44041443, 14.23486042], [74.44041443, 14.23569489], [74.44013977, 14.23569012], [74.44013977, 14.23653126], [74.43985748, 14.23653126], [74.43985748, 14.23736095], [74.43958282, 14.23736095], [74.43958282, 14.23819542], [74.43930817, 14.2381897], [74.43930817, 14.23903084], [74.43902588, 14.23902893], [74.43902588, 14.23986053], [74.43875122, 14.23986053], [74.43875122, 14.24070168], [74.43846893, 14.24070168], [74.43846893, 14.24125099], [74.43819427, 14.24125099], [74.43819427, 14.2420826], [74.43791962, 14.24208069], [74.43791962, 14.24292183], [74.43763733, 14.24291706], [74.43763733, 14.24347115], [74.43736267, 14.24347115], [74.43736267, 14.24431038], [74.43708038, 14.24431038], [74.43708038, 14.24514198], [74.43680573, 14.24513912], [74.43680573, 14.24569321], [74.43653107, 14.2456913], [74.43653107, 14.24652958], [74.43624878, 14.24652958], [74.43624878, 14.24763966], [74.43596649, 14.24763966], [74.43596649, 14.24875164], [74.43569183, 14.24874878], [74.43569183, 14.2495842], [74.43541718, 14.2495842], [74.43541718, 14.25069427], [74.43514252, 14.25069141], [74.43514252, 14.25152969], [74.4348526, 14.25152969], [74.4348526, 14.25263977], [74.43458557, 14.25263786], [74.4345932, 14.25374985], [74.43430328, 14.25374985], [74.43430328, 14.25458431], [74.43402863, 14.25457954], [74.43402863, 14.25542068], [74.43374634, 14.25541592], [74.43374634, 14.25597191], [74.43347168, 14.25597191], [74.43347168, 14.25681114], [74.43319702, 14.25681114], [74.43319702, 14.25764275], [74.43291473, 14.25763798], [74.4329071, 14.25819016], [74.43264008, 14.25820065], [74.43264008, 14.2590313], [74.43235779, 14.2590313], [74.43235779, 14.26014137], [74.43208313, 14.26014137], [74.43208313, 14.26153088], [74.43180847, 14.26152897], [74.43180847, 14.2620821], [74.43152618, 14.26208019], [74.43152618, 14.26264095], [74.43125153, 14.26263905], [74.43125153, 14.26319504], [74.43096924, 14.26319027], [74.43096924, 14.26375103], [74.43069458, 14.26375103], [74.43069458, 14.26458263], [74.43041992, 14.26457977], [74.43041992, 14.26514053], [74.43013763, 14.26513863], [74.43013763, 14.26569462], [74.42986298, 14.26568985], [74.42986298, 14.26625061], [74.42958069, 14.2662487], [74.42958069, 14.26708317], [74.42930603, 14.26708317], [74.42930603, 14.26819515], [74.429039, 14.26819134], [74.429039, 14.26903152], [74.42874908, 14.26902676], [74.42874908, 14.26986122], [74.42847443, 14.26986122], [74.42847443, 14.27097321], [74.42819214, 14.2709713], [74.42819214, 14.27180958], [74.42791748, 14.27180958], [74.42791748, 14.27263927], [74.42763519, 14.27263927], [74.42763519, 14.27374935], [74.42736053, 14.27374935], [74.42736053, 14.27458286], [74.42708588, 14.27458286], [74.42708588, 14.2756958], [74.42679596, 14.27569103], [74.42679596, 14.27653027], [74.42652893, 14.27653027], [74.42652893, 14.27736187], [74.42624664, 14.27736187], [74.42624664, 14.27847195], [74.42597961, 14.27847195], [74.42597961, 14.27931023], [74.42624664, 14.27931023], [74.42624664, 14.28013992], [74.42652893, 14.28013992], [74.42652893, 14.28125], [74.42624664, 14.28125], [74.42624664, 14.28236008], [74.42597961, 14.28236008], [74.42597961, 14.28264046], [74.42569733, 14.28264046], [74.42569733, 14.28293037], [74.42541504, 14.28291607], [74.42541504, 14.28347206], [74.42514038, 14.28347015], [74.42514038, 14.28374958], [74.42485809, 14.28374958], [74.42485809, 14.28486156], [74.42457581, 14.28485966], [74.42457581, 14.28625011], [74.42430878, 14.28625011], [74.42430878, 14.28736019], [74.42402649, 14.28736019], [74.42402649, 14.28847313], [74.42375183, 14.28847313], [74.42375183, 14.28958225], [74.42346954, 14.28958225], [74.42346954, 14.29069519], [74.42375183, 14.29069042], [74.42375183, 14.29181099], [74.42402649, 14.29181099], [74.42402649, 14.29264069], [74.42430878, 14.29263878], [74.42430878, 14.29347324], [74.42458344, 14.29347324], [74.42458344, 14.29458332], [74.42485809, 14.29458141], [74.42485809, 14.2954216], [74.42457581, 14.2954216], [74.42457581, 14.29653168], [74.42430878, 14.29652691], [74.42430878, 14.2970829], [74.42402649, 14.29708099], [74.42402649, 14.29764175], [74.42375183, 14.29763889], [74.42375183, 14.29783058], [74.42375183, 14.29819489], [74.42362976, 14.29819489], [74.42346954, 14.29819489], [74.42346954, 14.29868126], [74.4229126, 14.29875088], [74.4229126, 14.29902935], [74.42208099, 14.29902935], [74.42208099, 14.29930973], [74.42124939, 14.29930496], [74.42124939, 14.29958344], [74.4209671, 14.29958057], [74.4209671, 14.30013943], [74.42069244, 14.30013943], [74.42069244, 14.30069637], [74.42041779, 14.30069065], [74.42041779, 14.30124855], [74.42014313, 14.30124855], [74.42014313, 14.30153179], [74.41986084, 14.30152702], [74.41986084, 14.30208397], [74.41958618, 14.30208111], [74.41958618, 14.30264187], [74.41930389, 14.30263996], [74.41930389, 14.30319309], [74.41902924, 14.30319118], [74.41902924, 14.30375195], [74.41874695, 14.30375195], [74.41874695, 14.30430984], [74.41847229, 14.30430603], [74.41847229, 14.30458355], [74.41819763, 14.30458069], [74.41819763, 14.30513954], [74.41791534, 14.30513763], [74.41791534, 14.30569363], [74.41764069, 14.30568886], [74.41764069, 14.30624962], [74.4173584, 14.30624962], [74.4173584, 14.30681038], [74.41707611, 14.30681038], [74.41708374, 14.3073597], [74.41680908, 14.3073597], [74.41680908, 14.30792046], [74.41652679, 14.30791569], [74.41652679, 14.30847168], [74.41625214, 14.30846977], [74.41625214, 14.30931091], [74.41652679, 14.30930614], [74.41652679, 14.30958366], [74.41625214, 14.30958366], [74.41625214, 14.31069374], [74.41596985, 14.31069183], [74.41596985, 14.31124973], [74.41570282, 14.31124973], [74.41570282, 14.31181145], [74.4154129, 14.31181145], [74.4154129, 14.31236172], [74.41513824, 14.31236172], [74.41513824, 14.31264019], [74.41486359, 14.31263828], [74.41486359, 14.31319427], [74.4145813, 14.31319046], [74.4145813, 14.31375027], [74.41430664, 14.31375027], [74.41430664, 14.31431103], [74.41402435, 14.31430435], [74.41402435, 14.31486034], [74.41374969, 14.31486034], [74.41374969, 14.31569481], [74.41347504, 14.31569481], [74.41348267, 14.31736088], [74.41319275, 14.31736088], [74.41319275, 14.32208347], [74.41348267, 14.32208061], [74.41348267, 14.32514191], [74.41319275, 14.32513905], [74.41319275, 14.32736111], [74.41291809, 14.32736111], [74.41291809, 14.32958412], [74.4126358, 14.32958126], [74.4126358, 14.33098125], [74.41236115, 14.33098125], [74.41236115, 14.33181], [74.41208649, 14.33180618], [74.41208649, 14.33236217], [74.4118042, 14.33236217], [74.4118042, 14.33319378], [74.41152954, 14.33319378], [74.41152954, 14.33402824], [74.41124725, 14.33402824], [74.41124725, 14.33485985], [74.4109726, 14.33485985], [74.4109726, 14.33541965], [74.41069794, 14.33541965], [74.41069794, 14.33625031], [74.41041565, 14.33625031], [74.41041565, 14.33708191], [74.41014099, 14.33708382], [74.41014099, 14.33819389], [74.4098587, 14.33819199], [74.4098587, 14.33931065], [74.40957642, 14.33931065], [74.40957642, 14.34015179], [74.40930939, 14.34013844], [74.40930176, 14.34107018], [74.40930176, 14.34125042], [74.4090271, 14.34125042], [74.4090271, 14.34235954], [74.40875244, 14.34235954], [74.40875244, 14.34347343], [74.40847015, 14.34346962], [74.40847015, 14.34486103], [74.40820313, 14.34486103], [74.40820313, 14.34680939], [74.40791321, 14.34680939], [74.40791321, 14.34875107], [74.40763855, 14.34875107], [74.40763855, 14.3526392], [74.40735626, 14.3526392], [74.40735626, 14.35374928], [74.4070816, 14.35374928], [74.4070816, 14.35486126], [74.40680695, 14.35485935], [74.40680695, 14.35542202], [74.40652466, 14.35541534], [74.40652466, 14.35569572], [74.40625, 14.35569572], [74.40625, 14.35597134], [74.40598297, 14.35597134], [74.40598297, 14.35625172], [74.4054184, 14.35625172], [74.4054184, 14.35653019], [74.40513611, 14.35653019], [74.40513611, 14.35680962], [74.40486145, 14.3568058], [74.40486145, 14.35708427], [74.40458679, 14.35708427], [74.40458679, 14.35819435], [74.40513611, 14.35819435], [74.40513611, 14.35847187], [74.4054184, 14.35847187], [74.4054184, 14.35875034], [74.40569305, 14.35875034], [74.40569305, 14.35902977], [74.40598297, 14.35902977], [74.40598297, 14.35931015], [74.40625, 14.35930634], [74.40625, 14.36069393], [74.40598297, 14.36069202], [74.40598297, 14.36124992], [74.4054184, 14.36124992], [74.4054184, 14.3615303], [74.40513611, 14.3615284], [74.40513611, 14.36208439], [74.40486908, 14.36207962], [74.40486908, 14.36264038], [74.40458679, 14.36264038], [74.40458679, 14.36375046], [74.40486908, 14.36375046], [74.40486908, 14.3654213], [74.40569305, 14.3654213], [74.40569305, 14.36513996], [74.40625, 14.36513996], [74.40625, 14.36709118], [74.40569305, 14.36709118], [74.40569305, 14.3668108], [74.4054184, 14.3668108], [74.4054184, 14.36653137], [74.40513611, 14.36653137], [74.40513611, 14.36625004], [74.40486908, 14.36625004], [74.40486908, 14.36596966], [74.40458679, 14.36596966], [74.40458679, 14.36625004], [74.40429688, 14.36625004], [74.40429688, 14.36653137], [74.40402985, 14.36653137], [74.40402985, 14.3668108], [74.4034729, 14.3668108], [74.4034729, 14.36709118], [74.40319824, 14.36709118], [74.40319824, 14.36736012], [74.40291595, 14.36736012], [74.40291595, 14.36792088], [74.4026413, 14.36791611], [74.4026413, 14.3684721], [74.40235901, 14.36847019], [74.40235901, 14.36931133], [74.4026413, 14.36930656], [74.4026413, 14.37013912], [74.40291595, 14.37013912], [74.40291595, 14.37097263], [74.40319824, 14.37096977], [74.40319824, 14.37153053], [74.40513611, 14.37152863], [74.40513611, 14.37208271], [74.4054184, 14.37207985], [74.4054184, 14.37292099], [74.40513611, 14.37292099], [74.40513611, 14.37403107], [74.40486145, 14.37402916], [74.40486908, 14.37486076], [74.40458679, 14.37486076], [74.40458679, 14.37597084], [74.40429688, 14.37597084], [74.40429688, 14.37681198], [74.40402985, 14.37681198], [74.40402985, 14.37764072], [74.40374756, 14.37763882], [74.40374756, 14.37847328], [74.4034729, 14.37847328], [74.4034729, 14.37958336], [74.40319824, 14.37958145], [74.40319824, 14.38041973], [74.40291595, 14.38041973], [74.40291595, 14.38124943], [74.4026413, 14.38124943], [74.4026413, 14.38236237], [74.40235901, 14.38236237], [74.40235901, 14.38347054], [74.40208435, 14.38347054], [74.40208435, 14.38458443], [74.40180206, 14.38458443], [74.40180206, 14.38597202], [74.4015274, 14.38597202], [74.4015274, 14.38708401], [74.40125275, 14.38708401], [74.40125275, 14.3884716], [74.40097046, 14.3884716], [74.40097046, 14.38958359], [74.4006958, 14.38958359], [74.4006958, 14.39069366], [74.40040588, 14.3906889], [74.40040588, 14.39181137], [74.40013885, 14.39181137], [74.40013885, 14.39292145], [74.39985657, 14.39292145], [74.39985657, 14.39403057], [74.39958191, 14.39402771], [74.39958191, 14.39486027], [74.39930725, 14.39486027], [74.39930725, 14.39597321], [74.39901733, 14.39597034], [74.39901733, 14.39681053], [74.39874268, 14.39681053], [74.39874268, 14.39792061], [74.39848328, 14.39792061], [74.39848328, 14.39903069], [74.39819336, 14.39902878], [74.39819336, 14.39986134], [74.3979187, 14.39986134], [74.3979187, 14.40069485], [74.39763641, 14.40069008], [74.39763641, 14.4018116], [74.39736176, 14.4018116], [74.39736176, 14.4026413], [74.3970871, 14.40263939], [74.3970871, 14.40347099], [74.39680481, 14.40347099], [74.39680481, 14.40458298], [74.39653015, 14.40458107], [74.39653015, 14.4054203], [74.39624786, 14.4054203], [74.39624786, 14.40626144], [74.39597321, 14.40626144], [74.39597321, 14.40681171], [74.39568329, 14.40681171], [74.39568329, 14.40763855], [74.39597321, 14.40763855], [74.39597321, 14.40875244], [74.39624786, 14.40874863], [74.39624786, 14.40958405], [74.39597321, 14.40958118], [74.39597321, 14.41014194], [74.39569092, 14.41014004], [74.39569092, 14.41069317], [74.39541626, 14.41069126], [74.39541626, 14.41125202], [74.3951416, 14.41125202], [74.3951416, 14.41180992], [74.39485931, 14.41180992], [74.39485931, 14.41263962], [74.39458466, 14.41263771], [74.39458466, 14.4131937], [74.39430237, 14.41319084], [74.39430237, 14.41374969], [74.39402771, 14.41374969], [74.39402771, 14.41485977], [74.39375305, 14.41485977], [74.39375305, 14.41625023], [74.39347076, 14.41625023], [74.39347076, 14.41681099], [74.39319611, 14.41681099], [74.39319611, 14.41763973], [74.39291382, 14.41763783], [74.39289093, 14.41812611], [74.39263916, 14.41820145], [74.39263916, 14.41875172], [74.39212036, 14.41874981], [74.38819122, 14.41875172], [74.38819122, 14.41847038], [74.38708496, 14.41847229], [74.38708496, 14.41819382], [74.38735962, 14.41820145], [74.38735962, 14.41792107], [74.38764191, 14.41792107], [74.38764191, 14.41763973], [74.38791656, 14.41763973], [74.38791656, 14.41736031], [74.38819122, 14.41736221], [74.38819122, 14.41708374], [74.38680267, 14.41708374], [74.38680267, 14.41736221], [74.38652802, 14.41736031], [74.38652802, 14.41763973], [74.38597107, 14.41763973], [74.38597107, 14.41792107], [74.38569641, 14.41792107], [74.38569641, 14.41820145], [74.38541412, 14.41819382], [74.38541412, 14.41847229], [74.3840332, 14.41847038], [74.3840332, 14.41875172], [74.38346863, 14.41874981], [74.38346863, 14.41958427], [74.38318634, 14.41958046], [74.38318634, 14.42042065], [74.38236237, 14.42041588], [74.38236237, 14.42069435], [74.38208008, 14.42069435], [74.38208008, 14.42125034], [74.38180542, 14.42125034], [74.38180542, 14.42236042], [74.38153076, 14.42236042], [74.38153076, 14.42292118], [74.38124847, 14.42291641], [74.38124847, 14.42347336], [74.38096619, 14.42346954], [74.38096619, 14.42403126], [74.38124847, 14.42402554], [74.38124847, 14.42458344], [74.38180542, 14.42458344], [74.38180542, 14.42486095], [74.38236237, 14.42486095], [74.38236237, 14.42457962], [74.38291931, 14.42458344], [74.38291931, 14.42430687], [74.38402557, 14.42430687], [74.38402557, 14.42486095], [74.38430786, 14.42486095], [74.38430786, 14.42625141], [74.38458252, 14.42625141], [74.38458252, 14.4279213], [74.38430786, 14.42791653], [74.38430786, 14.428195], [74.38375092, 14.428195], [74.38375092, 14.42847347], [74.38346863, 14.42847061], [74.38346863, 14.42875099], [74.38318634, 14.42875099], [74.38318634, 14.42903137], [74.38263702, 14.42903137], [74.38263702, 14.42930889], [74.38236237, 14.42930698], [74.38236237, 14.4295826], [74.3795929, 14.42958069], [74.3795929, 14.43153191], [74.38014221, 14.43153191], [74.38014221, 14.43181038], [74.38041687, 14.43180466], [74.38041687, 14.43208313], [74.38096619, 14.43208122], [74.38096619, 14.43236065], [74.38124847, 14.43236065], [74.38124847, 14.43208122], [74.38153076, 14.43208313], [74.38153076, 14.43180466], [74.38181305, 14.43181038], [74.38181305, 14.43153191], [74.38263702, 14.43152714], [74.38263702, 14.43208313], [74.38291931, 14.43208313], [74.38291931, 14.43319321], [74.38318634, 14.4331789], [74.38318634, 14.43402958], [74.38291931, 14.43402958], [74.38291931, 14.43430996], [74.38263702, 14.43430519], [74.38263702, 14.43486118], [74.38236237, 14.43486118], [74.38236237, 14.43597126], [74.38208008, 14.43597126], [74.38208008, 14.43680954], [74.38180542, 14.43680573], [74.38180542, 14.4370842], [74.38208008, 14.43708134], [74.38208008, 14.43764019], [74.38236237, 14.43764019], [74.38236237, 14.43986225], [74.38208008, 14.43986034], [74.38208008, 14.44181061], [74.38181305, 14.44181061], [74.38181305, 14.44237137], [74.38153076, 14.44237137], [74.38153076, 14.44291973], [74.38124847, 14.44291592], [74.38124847, 14.44347191], [74.38096619, 14.44347191], [74.38096619, 14.44403267], [74.38069153, 14.4440279], [74.38069153, 14.44458199], [74.38041687, 14.44458199], [74.38041687, 14.44569397], [74.38069153, 14.44569397], [74.38069153, 14.44708443], [74.38041687, 14.44707966], [74.38041687, 14.4479208], [74.38014221, 14.4479208], [74.38014221, 14.44874954], [74.37985992, 14.44874954], [74.37985992, 14.4495821], [74.3795929, 14.44958019], [74.3795929, 14.45014095], [74.37930298, 14.45013809], [74.37930298, 14.45097256], [74.37902832, 14.4509697], [74.37902832, 14.45181084], [74.37875366, 14.45180511], [74.37875366, 14.45236111], [74.37847137, 14.45236111], [74.37847137, 14.45319462], [74.37819672, 14.45318985], [74.37819672, 14.45403099], [74.37791443, 14.45402908], [74.37791443, 14.45458317], [74.37763977, 14.45458126], [74.37763977, 14.45514107], [74.37735748, 14.45513916], [74.37735748, 14.45569515], [74.37708282, 14.45569038], [74.37708282, 14.45625114], [74.37680817, 14.45625114], [74.37680817, 14.4568119], [74.37652588, 14.45680523], [74.37652588, 14.45736122], [74.37625122, 14.45734978], [74.37625122, 14.45875072], [74.37596893, 14.45874882], [74.37596893, 14.46069527], [74.37568665, 14.46069145], [74.37568665, 14.46152973], [74.37541962, 14.46152687], [74.37541962, 14.46208286], [74.37513733, 14.46208096], [74.37513733, 14.46292019], [74.37486267, 14.46292019], [74.37486267, 14.46375179], [74.37458038, 14.46374893], [74.37458038, 14.46458435], [74.37431335, 14.46458054], [74.37431335, 14.46541977], [74.37403107, 14.46541977], [74.37403107, 14.46654129], [74.37374878, 14.46652794], [74.37374878, 14.4673624], [74.37347412, 14.4673624], [74.37347412, 14.46819401], [74.37319183, 14.46818924], [74.37319183, 14.46903038], [74.37291718, 14.46903038], [74.37291718, 14.46986198], [74.37264252, 14.46986198], [74.37264252, 14.47042274], [74.37236023, 14.47041607], [74.37236023, 14.47097206], [74.3720932, 14.47097015], [74.3720932, 14.47152996], [74.37180328, 14.47152805], [74.37180328, 14.47236156], [74.37152863, 14.47235107], [74.37152863, 14.47292137], [74.37124634, 14.47291565], [74.37124634, 14.47347164], [74.37097168, 14.47346973], [74.37097168, 14.47403145], [74.37069702, 14.47402763], [74.37069702, 14.47486019], [74.3704071, 14.47486019], [74.3704071, 14.47542095], [74.37014008, 14.47541618], [74.37014008, 14.47597218], [74.36985779, 14.47597027], [74.36985779, 14.47681141], [74.36958313, 14.47681141], [74.36958313, 14.47735977], [74.36930847, 14.47735977], [74.36930847, 14.47792053], [74.36902618, 14.47792053], [74.36902618, 14.47848034], [74.36873627, 14.47848034], [74.36873627, 14.47931099], [74.36846924, 14.47930527], [74.36846924, 14.47986126], [74.36818695, 14.47986126], [74.36818695, 14.48042107], [74.36791992, 14.48041725], [74.36791992, 14.48097324], [74.36763763, 14.48097134], [74.36763763, 14.48181152], [74.36736298, 14.48181152], [74.36736298, 14.48236084], [74.36708069, 14.48236084], [74.36708069, 14.4829216], [74.36680603, 14.4829216], [74.36680603, 14.4837513], [74.36653137, 14.4837513], [74.36653137, 14.48431015], [74.36624908, 14.48431015], [74.36624908, 14.4851408], [74.36597443, 14.48513889], [74.36597443, 14.48569489], [74.36569977, 14.48569107], [74.36569977, 14.48625088], [74.36541748, 14.48624897], [74.36541748, 14.48708344], [74.36514282, 14.48708057], [74.36514282, 14.48763943], [74.36486053, 14.48763943], [74.36486053, 14.48847103], [74.36458588, 14.48847103], [74.36458588, 14.48903179], [74.36430359, 14.48902702], [74.36430359, 14.48958302], [74.36402893, 14.48958111], [74.36402893, 14.49042034], [74.36374664, 14.49041843], [74.36374664, 14.49097061], [74.36347198, 14.49097061], [74.36347198, 14.49180984], [74.36319733, 14.49180984], [74.36319733, 14.49236202], [74.36292267, 14.49236202], [74.36292267, 14.49291992], [74.36264038, 14.49291992], [74.36264038, 14.49374962], [74.36235809, 14.49374962], [74.36235809, 14.49431038], [74.36207581, 14.49431038], [74.36207581, 14.49514008], [74.36180878, 14.49514008], [74.36180878, 14.49597168], [74.36152649, 14.49597168], [74.36152649, 14.49652767], [74.36125183, 14.49652767], [74.36125183, 14.49736214], [74.36096954, 14.49736214], [74.36096954, 14.49819374], [74.36068726, 14.49819183], [74.36068726, 14.49903011], [74.36042023, 14.49903011], [74.36042023, 14.49986172], [74.36013794, 14.49986172], [74.36013794, 14.50042057], [74.35986328, 14.50042057], [74.35986328, 14.50125027], [74.35957336, 14.50125027], [74.35957336, 14.50181103], [74.35847473, 14.50180435], [74.35847473, 14.50208473], [74.3576355, 14.50208473], [74.3576355, 14.50180435], [74.35736084, 14.50181103], [74.35736084, 14.50125027], [74.35708618, 14.50125027], [74.35708618, 14.50097179], [74.35541534, 14.50097179], [74.35542297, 14.50125027], [74.35514069, 14.50125027], [74.35514069, 14.50153065], [74.3548584, 14.50153065], [74.3548584, 14.50181103], [74.35458374, 14.50180435], [74.35458374, 14.50208473], [74.35430908, 14.50208473], [74.35430908, 14.50236034], [74.35402679, 14.50236034], [74.35402679, 14.5029211], [74.35375977, 14.5029211], [74.35375977, 14.50375271], [74.35402679, 14.5037508], [74.35402679, 14.50458241], [74.35430908, 14.50457954], [74.35430908, 14.50486088], [74.35402679, 14.50486088], [74.35402679, 14.50708294], [74.35430908, 14.50708294], [74.35430908, 14.50736141], [74.3548584, 14.50736141], [74.3548584, 14.50819016], [74.35457611, 14.5082016], [74.35457611, 14.50875092], [74.35514069, 14.50875092], [74.35514069, 14.5090313], [74.35597229, 14.5090313], [74.35597229, 14.50931168], [74.35652924, 14.509305], [74.35652924, 14.50958347], [74.35708618, 14.50958061], [74.35708618, 14.50986099], [74.35764313, 14.50986099], [74.35764313, 14.51014137], [74.35819244, 14.51014137], [74.35819244, 14.51041889], [74.35930634, 14.51041698], [74.35930634, 14.51097298], [74.35902405, 14.51097298], [74.35902405, 14.51208305], [74.35874939, 14.51208305], [74.35874939, 14.51319313], [74.3584671, 14.51319122], [74.3584671, 14.51542187], [74.35874939, 14.5154171], [74.35874939, 14.51597118], [74.35901642, 14.51597118], [74.35901642, 14.51653194], [74.35930634, 14.51653194], [74.35930634, 14.51681042], [74.35957336, 14.51681042], [74.35957336, 14.51736164], [74.35986328, 14.51736164], [74.35986328, 14.5176506], [74.36013794, 14.51764011], [74.36013794, 14.51819324], [74.36042023, 14.51819134], [74.36042023, 14.51875019], [74.36068726, 14.51875019], [74.36068726, 14.51902962], [74.36125183, 14.51902962], [74.36125183, 14.51931], [74.36069489, 14.51930618], [74.36069489, 14.51986217], [74.36096954, 14.51986027], [74.36096954, 14.52013969], [74.36152649, 14.52013969], [74.36152649, 14.52042007], [74.36208344, 14.52041626], [74.36208344, 14.52069378], [74.36264038, 14.52069378], [74.36264038, 14.52097225], [74.36319733, 14.52096939], [74.36319733, 14.52124977], [74.36429596, 14.52124977], [74.36429596, 14.52153015], [74.36458588, 14.52152824], [74.36458588, 14.52208424], [74.36486053, 14.52208424], [74.36486053, 14.52235985], [74.36514282, 14.52235985], [74.36514282, 14.52264023], [74.36541748, 14.52264023], [74.36541748, 14.52291965], [74.36597443, 14.52291584], [74.36597443, 14.52319431], [74.36624908, 14.52319431], [74.36624908, 14.52347183], [74.36736298, 14.52346134], [74.36736298, 14.52402973], [74.36763763, 14.52402973], [74.36763763, 14.52431107], [74.36791992, 14.52431107], [74.36791992, 14.52514267], [74.36819458, 14.5251379], [74.36819458, 14.52569389], [74.36846924, 14.52569199], [74.36846924, 14.52625179], [74.36873627, 14.52625179], [74.36873627, 14.52682018], [74.36902618, 14.52682018], [74.36902618, 14.52735996], [74.36930847, 14.52735996], [74.36930847, 14.52764034], [74.37069702, 14.52764034], [74.37069702, 14.52792072], [74.37236023, 14.52792072], [74.37236023, 14.52764034], [74.37264252, 14.52764034], [74.37264252, 14.52735996], [74.37291718, 14.52735996], [74.37291718, 14.52707958], [74.37319183, 14.52708435], [74.37319183, 14.52680588], [74.37346649, 14.52682018], [74.37346649, 14.52653122], [74.37374878, 14.52653122], [74.37374878, 14.52597046], [74.37403107, 14.52597237], [74.37403107, 14.52569389], [74.37430573, 14.52569389], [74.37430573, 14.52541637], [74.37458038, 14.52542114], [74.37458038, 14.52486038], [74.37486267, 14.52486229], [74.37486267, 14.52458191], [74.37513733, 14.52458191], [74.37513733, 14.5243063], [74.37541962, 14.52431107], [74.37541962, 14.52375031], [74.37568665, 14.52375031], [74.37568665, 14.52346134], [74.37596893, 14.52347183], [74.37596893, 14.52291584], [74.37625122, 14.52291965], [74.37625122, 14.52235985], [74.37652588, 14.52235985], [74.37652588, 14.52264023], [74.37680817, 14.52264023], [74.37680817, 14.52291965], [74.37735748, 14.52291584], [74.37735748, 14.52319431], [74.37763977, 14.52319431], [74.37763977, 14.52347183], [74.3779068, 14.52346134], [74.3779068, 14.52375031], [74.37847137, 14.52375031], [74.37847137, 14.52402973], [74.37874603, 14.52402973], [74.37874603, 14.52431107], [74.37930298, 14.5243063], [74.37930298, 14.52458191], [74.3795929, 14.52458191], [74.3795929, 14.52542114], [74.37930298, 14.52541637], [74.37930298, 14.52597237], [74.37902832, 14.52597046], [74.37902832, 14.52625179], [74.37874603, 14.52625179], [74.37874603, 14.52682018], [74.37847137, 14.52680588], [74.37847137, 14.52708435], [74.37819672, 14.52707958], [74.37819672, 14.52764034], [74.37791443, 14.52764034], [74.37791443, 14.52819443], [74.37763977, 14.52818966], [74.37763977, 14.52875042], [74.37735748, 14.52875042], [74.37735748, 14.52985954], [74.37708282, 14.52985954], [74.37708282, 14.53097343], [74.37680817, 14.53096962], [74.37680817, 14.53153133], [74.37652588, 14.53152561], [74.37652588, 14.53208256], [74.37625122, 14.53208256], [74.37625122, 14.53263855], [74.37596893, 14.53263855], [74.37596893, 14.53319454], [74.37568665, 14.53318977], [74.37568665, 14.53375053], [74.37541962, 14.53375053], [74.37541962, 14.53430939], [74.37486267, 14.53430462], [74.37486267, 14.53458309], [74.37458038, 14.53458309], [74.37458038, 14.53486061], [74.37431335, 14.53486061], [74.37431335, 14.53542137], [74.37374878, 14.5354166], [74.37374878, 14.53569508], [74.37346649, 14.53569031], [74.37346649, 14.53625107], [74.37319183, 14.53625107], [74.37319183, 14.53708267], [74.37374878, 14.53708267], [74.37374878, 14.53736115], [74.37458038, 14.53736115], [74.37458038, 14.53680515], [74.37486267, 14.53681183], [74.37486267, 14.53625107], [74.37513733, 14.53625107], [74.37513733, 14.53569031], [74.37541962, 14.53569508], [74.37541962, 14.53513908], [74.37568665, 14.53514099], [74.37568665, 14.53458023], [74.37596893, 14.53458309], [74.37596893, 14.53402901], [74.37625122, 14.53403091], [74.37625122, 14.53375053], [74.37652588, 14.53375053], [74.37652588, 14.53347111], [74.37680817, 14.53347301], [74.37680817, 14.53319454], [74.37708282, 14.53319454], [74.37708282, 14.53291702], [74.37735748, 14.53292084], [74.37735748, 14.53263187], [74.37930298, 14.53263855], [74.37930298, 14.53236103], [74.3795929, 14.53236103], [74.37958527, 14.53180695], [74.37985992, 14.53181076], [74.37985992, 14.53153133], [74.38014221, 14.53153133], [74.38014221, 14.53125095], [74.38041687, 14.53125095], [74.38041687, 14.53069019], [74.38069153, 14.53069496], [74.38069153, 14.53041553], [74.38096619, 14.53042126], [74.38096619, 14.53014088], [74.38124847, 14.53014088], [74.38124847, 14.52959061], [74.38153076, 14.52959061], [74.38153076, 14.52931118], [74.38181305, 14.52931118], [74.38181305, 14.5290308], [74.38208008, 14.5290308], [74.38208008, 14.52847004], [74.38236237, 14.52847195], [74.38236237, 14.52819443], [74.38263702, 14.52819443], [74.38263702, 14.52763844], [74.38291931, 14.52764034], [74.38291931, 14.52707958], [74.38319397, 14.52708435], [74.38319397, 14.52624989], [74.38346863, 14.52625179], [74.38346863, 14.52569199], [74.38375092, 14.52569389], [74.38375092, 14.52486229], [74.38402557, 14.52486229], [74.38402557, 14.5243063], [74.38430786, 14.52431107], [74.38430786, 14.52375031], [74.38652802, 14.52375031], [74.38652802, 14.52479172], [74.38652802, 14.52875042], [74.38707733, 14.52875042], [74.38707733, 14.5290308], [74.38735962, 14.5290308], [74.38735962, 14.52931118], [74.38791656, 14.52931118], [74.38791656, 14.52959061], [74.38931274, 14.52959061], [74.38931274, 14.52931118], [74.39068604, 14.52931118], [74.39068604, 14.5290308], [74.39290619, 14.5290308], [74.39290619, 14.52931118], [74.39347076, 14.52931118], [74.39347076, 14.53042126], [74.39319611, 14.53042126], [74.39319611, 14.53125095], [74.39068604, 14.53125095], [74.39068604, 14.53153133], [74.39041901, 14.53152561], [74.39041901, 14.53208256], [74.39013672, 14.53208256], [74.39013672, 14.53263855], [74.38986206, 14.53263855], [74.38986206, 14.53319454], [74.38957977, 14.53318977], [74.38957977, 14.53375053], [74.38931274, 14.53375053], [74.38931274, 14.53403091], [74.38735962, 14.53403091], [74.38735962, 14.53375053], [74.38707733, 14.53375053], [74.38707733, 14.53318977], [74.38680267, 14.53319454], [74.38680267, 14.53291702], [74.38652802, 14.53292084], [74.38652802, 14.53236103], [74.38625336, 14.53236103], [74.38625336, 14.53181076], [74.38597107, 14.53181076], [74.38597107, 14.53153133], [74.38569641, 14.53153133], [74.38569641, 14.53096962], [74.38541412, 14.53097343], [74.38541412, 14.53069496], [74.3840332, 14.53069019], [74.3840332, 14.53125095], [74.38430786, 14.53125095], [74.38430786, 14.53181076], [74.38458252, 14.53181076], [74.38458252, 14.53236103], [74.38485718, 14.53236103], [74.38485718, 14.53292084], [74.38513947, 14.53291702], [74.38513947, 14.53347301], [74.38540649, 14.53347111], [74.38540649, 14.53430939], [74.38513947, 14.53430939], [74.38513947, 14.53514099], [74.38458252, 14.53514099], [74.38458252, 14.53542137], [74.38430786, 14.5354166], [74.38430786, 14.53569508], [74.38375092, 14.53569508], [74.38375092, 14.5359726], [74.38346863, 14.53597069], [74.38346863, 14.53625107], [74.38321686, 14.53625107], [74.38291931, 14.53625107], [74.38291931, 14.53708267], [74.38304901, 14.53708076], [74.38318634, 14.5370779], [74.38318634, 14.53876019], [74.38346863, 14.53876019], [74.38346863, 14.54041958], [74.38375092, 14.54041672], [74.38375092, 14.54347134], [74.38513947, 14.54347134], [74.38513947, 14.54375172], [74.38540649, 14.54375172], [74.38540649, 14.54403019], [74.38597107, 14.54403019], [74.38597107, 14.54430962], [74.38625336, 14.5443058], [74.38625336, 14.54458427], [74.38652802, 14.54456997], [74.38652802, 14.54486179], [74.38680267, 14.54486179], [74.38680267, 14.54514027], [74.38708496, 14.54514027], [74.38708496, 14.54569435], [74.38735962, 14.54569054], [74.38735962, 14.54681015], [74.38708496, 14.54680634], [74.38708496, 14.54708385], [74.38680267, 14.54708385], [74.38680267, 14.54736233], [74.38652802, 14.54736233], [74.38652802, 14.54763985], [74.38625336, 14.54763126], [74.38625336, 14.54792023], [74.38597107, 14.54791641], [74.38597107, 14.5484724], [74.38569641, 14.54846859], [74.38569641, 14.54874992], [74.38540649, 14.54874992], [74.38540649, 14.5490303], [74.38513947, 14.5490303], [74.38513947, 14.54930973], [74.38485718, 14.54930973], [74.38485718, 14.54986191], [74.38458252, 14.54986191], [74.38458252, 14.55014038], [74.38430786, 14.55014038], [74.38430786, 14.55041981], [74.3840332, 14.55041981], [74.3840332, 14.55070114], [74.38375092, 14.55069447], [74.38375092, 14.55097198], [74.38346863, 14.55097198], [74.38346863, 14.55153275], [74.38318634, 14.55153275], [74.38318634, 14.55181122], [74.38236237, 14.55181122], [74.38236237, 14.55125046], [74.38208008, 14.55125046], [74.38208008, 14.55097198], [74.38180542, 14.55097198], [74.38180542, 14.55041599], [74.38153076, 14.55041981], [74.38153076, 14.55014038], [74.38124847, 14.55014038], [74.38124847, 14.54986191], [74.38096619, 14.54986191], [74.38096619, 14.54930973], [74.3795929, 14.54930973], [74.3795929, 14.5490303], [74.37902832, 14.5490303], [74.37902832, 14.54874992], [74.37847137, 14.54874992], [74.37847137, 14.54846859], [74.3779068, 14.54846859], [74.3779068, 14.5490303], [74.37763977, 14.5490303], [74.37763977, 14.54930973], [74.37735748, 14.54930592], [74.37735748, 14.54958439], [74.37708282, 14.54957867], [74.37708282, 14.55014038], [74.37680817, 14.55014038], [74.37680817, 14.55041981], [74.37652588, 14.55041981], [74.37652588, 14.55070114], [74.37625122, 14.55070114], [74.37625122, 14.55125046], [74.37596893, 14.55125046], [74.37596893, 14.55153275], [74.37541962, 14.55153275], [74.37541962, 14.55181122], [74.37513733, 14.55180645], [74.37513733, 14.55208206], [74.37458038, 14.55208206], [74.37458038, 14.55236244], [74.37403107, 14.55235958], [74.37403107, 14.55263996], [74.37374878, 14.55263996], [74.37374878, 14.5529213], [74.37319183, 14.55291557], [74.37319183, 14.55319405], [74.37291718, 14.55319405], [74.37291718, 14.55347157], [74.37264252, 14.55346966], [74.37264252, 14.55376244], [74.37152863, 14.55376244], [74.37152863, 14.55346966], [74.37124634, 14.55347157], [74.37124634, 14.55319405], [74.37069702, 14.55319405], [74.37069702, 14.55291557], [74.37014008, 14.5529213], [74.37014008, 14.55263996], [74.36791992, 14.55263996], [74.36653137, 14.55263996], [74.36653137, 14.5529213], [74.36597443, 14.55291557], [74.36597443, 14.55319405], [74.36541748, 14.55319405], [74.36541748, 14.55347157], [74.36486053, 14.55346966], [74.36486053, 14.55376244], [74.36458588, 14.55376244], [74.36458588, 14.55403137], [74.36486053, 14.55402756], [74.36486053, 14.55458355], [74.36514282, 14.55457973], [74.36514282, 14.55514145], [74.36541748, 14.55514145], [74.36541748, 14.55542088], [74.36569214, 14.55541611], [74.36569214, 14.55569363], [74.36624908, 14.55569363], [74.36624908, 14.5559721], [74.36653137, 14.55597019], [74.36653137, 14.55624962], [74.36680603, 14.55624962], [74.36680603, 14.55653095], [74.36708069, 14.55652905], [74.36708069, 14.55680656], [74.36736298, 14.55680656], [74.36736298, 14.55708218], [74.36763763, 14.55708027], [74.36763763, 14.5573597], [74.36818695, 14.5573597], [74.36818695, 14.55764103], [74.36846924, 14.55764103], [74.36846924, 14.55792141], [74.36875153, 14.55791664], [74.36875153, 14.55847263], [74.36902618, 14.55846977], [74.36902618, 14.55931091], [74.36930847, 14.55931091], [74.36930847, 14.56014061], [74.36958313, 14.5601387], [74.36958313, 14.56097317], [74.36985779, 14.56097126], [74.36985779, 14.5618124], [74.37014008, 14.5618124], [74.37014008, 14.56236076], [74.3704071, 14.56236076], [74.3704071, 14.56264114], [74.37097168, 14.56264114], [74.37097168, 14.56293106], [74.37124634, 14.56291676], [74.37124634, 14.56319523], [74.37152863, 14.56319046], [74.37152863, 14.56347084], [74.37180328, 14.56347084], [74.37180328, 14.56375122], [74.37236023, 14.56375122], [74.37236023, 14.56403065], [74.37264252, 14.56403065], [74.37264252, 14.56431198], [74.37346649, 14.56431198], [74.37346649, 14.56403065], [74.37403107, 14.56403065], [74.37403107, 14.56375122], [74.37486267, 14.56375122], [74.37486267, 14.56347084], [74.37596893, 14.56347084], [74.37596893, 14.56375122], [74.37625122, 14.56375122], [74.37625122, 14.56431198], [74.37569427, 14.56430531], [74.37569427, 14.56458282], [74.37513733, 14.56458282], [74.37513733, 14.5648613], [74.37458038, 14.5648613], [74.37458038, 14.56514072], [74.37486267, 14.56514072], [74.37486267, 14.56569958], [74.37513733, 14.56569958], [74.37513733, 14.56652927], [74.37541962, 14.56652927], [74.37541962, 14.56763935], [74.37569427, 14.56763935], [74.37569427, 14.56819534], [74.37596893, 14.56819534], [74.37596893, 14.56874943], [74.37625122, 14.56874943], [74.37625122, 14.57097054], [74.37763977, 14.57097054], [74.37763977, 14.57236195], [74.37735748, 14.57236195], [74.37735748, 14.57264042], [74.37708282, 14.57264042], [74.37708282, 14.57291985], [74.37652588, 14.57291794], [74.37652588, 14.57319355], [74.37625122, 14.57319355], [74.37625122, 14.57347202], [74.37596893, 14.57347202], [74.37596893, 14.57374954], [74.37374878, 14.57374954], [74.37374878, 14.57347202], [74.37152863, 14.57347202], [74.37152863, 14.57319355], [74.37124634, 14.57319355], [74.37124634, 14.57291794], [74.37097168, 14.57291985], [74.37097168, 14.57236195], [74.37069702, 14.57236195], [74.37069702, 14.57208061], [74.37041473, 14.57208443], [74.37041473, 14.57180595], [74.37014008, 14.57180595], [74.37014008, 14.57152843], [74.36985779, 14.57153034], [74.36985779, 14.57097054], [74.36958313, 14.57097054], [74.36958313, 14.57069588], [74.36930847, 14.57069111], [74.36930847, 14.57041836], [74.36902618, 14.57042027], [74.36902618, 14.57014179], [74.36873627, 14.57014179], [74.36873627, 14.56958103], [74.36846924, 14.56958294], [74.36846924, 14.56930542], [74.36818695, 14.56931019], [74.36818695, 14.56903172], [74.36736298, 14.56903172], [74.36736298, 14.5687418], [74.36653137, 14.56874943], [74.36653137, 14.56847095], [74.36569214, 14.56847095], [74.36569214, 14.56791687], [74.3659668, 14.56791973], [74.3659668, 14.56763935], [74.36569977, 14.56763935], [74.36569977, 14.56736088], [74.36541748, 14.56736088], [74.36541748, 14.56680965], [74.36514282, 14.56680965], [74.36514282, 14.56652927], [74.36486053, 14.56652927], [74.36486053, 14.5662508], [74.36068726, 14.5662508], [74.36068726, 14.56597137], [74.36042023, 14.56597328], [74.36042023, 14.56569481], [74.36013794, 14.56569958], [74.36013794, 14.5654192], [74.35986328, 14.5654192], [74.35986328, 14.56514072], [74.35957336, 14.56514072], [74.35957336, 14.5648613], [74.35930634, 14.5648613], [74.35930634, 14.56430531], [74.35901642, 14.56431198], [74.35901642, 14.56403065], [74.35874939, 14.56403065], [74.35874939, 14.56375122], [74.3584671, 14.56375122], [74.3584671, 14.56347084], [74.35819244, 14.56347084], [74.35819244, 14.56319046], [74.35791779, 14.56319523], [74.35791779, 14.56291676], [74.35736084, 14.56293106], [74.35736084, 14.56264114], [74.35652924, 14.56264114], [74.35652924, 14.56208038], [74.35680389, 14.56208324], [74.35680389, 14.56152916], [74.35708618, 14.56153107], [74.35708618, 14.56097126], [74.35736084, 14.56097317], [74.35736084, 14.56041718], [74.35764313, 14.56042099], [74.35764313, 14.55986118], [74.35791779, 14.55986118], [74.35791779, 14.55930519], [74.35819244, 14.55931091], [74.35819244, 14.55875111], [74.3584671, 14.55875111], [74.3584671, 14.55819035], [74.35874939, 14.55819511], [74.35874939, 14.55763817], [74.35901642, 14.55764103], [74.35901642, 14.55708027], [74.35930634, 14.55708218], [74.35930634, 14.55652905], [74.35957336, 14.55653095], [74.35957336, 14.55597019], [74.35986328, 14.5559721], [74.35986328, 14.55319405], [74.35958099, 14.55319405], [74.35958099, 14.55180645], [74.35986328, 14.55181122], [74.35986328, 14.55070114], [74.36013794, 14.55070114], [74.36013794, 14.55041981], [74.36042023, 14.55041981], [74.36042023, 14.55014038], [74.36013794, 14.55014038], [74.36013794, 14.54957867], [74.35986328, 14.54958439], [74.35986328, 14.5490284], [74.35957336, 14.5490303], [74.35957336, 14.54846859], [74.35930634, 14.5484724], [74.35930634, 14.54791641], [74.35901642, 14.54792023], [74.35901642, 14.54736042], [74.35874939, 14.54736233], [74.35874939, 14.54680634], [74.3584671, 14.54681015], [74.3584671, 14.54625034], [74.35819244, 14.54625034], [74.35819244, 14.54597187], [74.3576355, 14.54597187], [74.3576355, 14.54569435], [74.35708618, 14.54569435], [74.35708618, 14.54541779], [74.35652924, 14.54541969], [74.35652924, 14.54514027], [74.35597229, 14.54514027], [74.35597229, 14.54486179], [74.35542297, 14.54486179], [74.35542297, 14.54456997], [74.35514069, 14.54458427], [74.35514069, 14.5443058], [74.3548584, 14.54430962], [74.3548584, 14.54375172], [74.35457611, 14.54375172], [74.35457611, 14.54347134], [74.35430908, 14.54347134], [74.35430908, 14.54291534], [74.35402679, 14.54291534], [74.35402679, 14.54319572], [74.35346985, 14.54319572], [74.35346985, 14.54347134], [74.3529129, 14.54347134], [74.3529129, 14.54375172], [74.35235596, 14.54375172], [74.35235596, 14.54403019], [74.35180664, 14.54403019], [74.35180664, 14.54430962], [74.35124969, 14.5443058], [74.35124969, 14.54458427], [74.35070038, 14.54456997], [74.35070038, 14.54486179], [74.3501358, 14.54486179], [74.3501358, 14.54514027], [74.34958649, 14.54514027], [74.34958649, 14.54625034], [74.34929657, 14.54625034], [74.34929657, 14.54681015], [74.34902954, 14.54680634], [74.34902954, 14.54736233], [74.34874725, 14.54736042], [74.34874725, 14.54792023], [74.3484726, 14.54791641], [74.3484726, 14.5484724], [74.34819794, 14.54846859], [74.34819794, 14.5490303], [74.34791565, 14.5490284], [74.34791565, 14.54958439], [74.34763336, 14.54957867], [74.34763336, 14.54986191], [74.3473587, 14.54986191], [74.3473587, 14.55041981], [74.34708405, 14.55041599], [74.34708405, 14.55097198], [74.34680939, 14.55097198], [74.34680176, 14.55153275], [74.3465271, 14.55152798], [74.3465271, 14.55208206], [74.34625244, 14.55208015], [74.34625244, 14.55263996], [74.34597015, 14.55263805], [74.34597015, 14.55319405], [74.34570313, 14.55319023], [74.34570313, 14.5543108], [74.34541321, 14.5543108], [74.34541321, 14.55653095], [74.34513855, 14.55653095], [74.34513855, 14.55792141], [74.34541321, 14.55791664], [74.34541321, 14.55819511], [74.3456955, 14.55819511], [74.3456955, 14.55875111], [74.34597015, 14.55875111], [74.34597015, 14.55903053], [74.34625244, 14.55903053], [74.34625244, 14.55931091], [74.3465271, 14.55930519], [74.3465271, 14.55986118], [74.34680176, 14.55986118], [74.34680176, 14.56069469], [74.3465271, 14.56069469], [74.3465271, 14.56097317], [74.34597015, 14.56097126], [74.34597015, 14.56125069], [74.34570313, 14.56125069], [74.34570313, 14.56153107], [74.34513855, 14.56153107], [74.34513855, 14.5618124], [74.34486389, 14.56180477], [74.34486389, 14.56208324], [74.34430695, 14.56208038], [74.34430695, 14.56236076], [74.34401703, 14.56236076], [74.34401703, 14.56264114], [74.34375, 14.56264114], [74.34375, 14.56293106], [74.34319305, 14.56291676], [74.34319305, 14.56319523], [74.3429184, 14.56319046], [74.3429184, 14.56347084], [74.34236145, 14.56347084], [74.34236145, 14.56375122], [74.34208679, 14.56375122], [74.34208679, 14.56431198], [74.34179688, 14.56431198], [74.34179688, 14.56514072], [74.34152985, 14.56513882], [74.34152985, 14.56597328], [74.34124756, 14.56597137], [74.34124756, 14.56652927], [74.3409729, 14.56652927], [74.3409729, 14.56736088], [74.34069824, 14.56736088], [74.34069824, 14.56819534], [74.34041595, 14.56819534], [74.34041595, 14.56874943], [74.3373642, 14.56874943], [74.3373642, 14.56819534], [74.33708191, 14.56819534], [74.33708191, 14.56763935], [74.33680725, 14.56763935], [74.33680725, 14.56708145], [74.33652496, 14.56708336], [74.33652496, 14.56652737], [74.33625031, 14.56652927], [74.33625031, 14.56597137], [74.33597565, 14.56597328], [74.33597565, 14.56541729], [74.33569336, 14.5654192], [74.33569336, 14.5648613], [74.3354187, 14.5648613], [74.3354187, 14.56375122], [74.33513641, 14.56375122], [74.33513641, 14.56264114], [74.3354187, 14.56264114], [74.3354187, 14.56208038], [74.33569336, 14.56208324], [74.33569336, 14.56180477], [74.33598328, 14.5618124], [74.33598328, 14.56125069], [74.33625031, 14.56125069], [74.33625031, 14.56068993], [74.33652496, 14.56069469], [74.33652496, 14.56041718], [74.33680725, 14.56042099], [74.33680725, 14.55986118], [74.33708191, 14.55986118], [74.33708191, 14.55958271], [74.3373642, 14.55958271], [74.3373642, 14.55902863], [74.33763885, 14.55903053], [74.33763885, 14.55846977], [74.33791351, 14.55847263], [74.33791351, 14.55819511], [74.3381958, 14.55819511], [74.3381958, 14.55763817], [74.33847046, 14.55764103], [74.33847046, 14.5568018], [74.33875275, 14.55680656], [74.33875275, 14.55541611], [74.3390274, 14.55542088], [74.3390274, 14.55457973], [74.33875275, 14.55458355], [74.33875275, 14.55402756], [74.33847046, 14.55403137], [74.33847046, 14.55376244], [74.3381958, 14.55376244], [74.3381958, 14.55346966], [74.33847046, 14.55347157], [74.33847046, 14.55319405], [74.33875275, 14.55319405], [74.33875275, 14.55291557], [74.33930206, 14.5529213], [74.33930206, 14.55263996], [74.33957672, 14.55263996], [74.33957672, 14.55235958], [74.3401413, 14.55236244], [74.3401413, 14.55208206], [74.34041595, 14.55208206], [74.34041595, 14.55180645], [74.3409729, 14.55181122], [74.3409729, 14.55153275], [74.34124756, 14.55153275], [74.34124756, 14.55125046], [74.34152985, 14.55125046], [74.34152985, 14.55097198], [74.3418045, 14.55097198], [74.3418045, 14.55041599], [74.34208679, 14.55041981], [74.34208679, 14.55014038], [74.34236145, 14.55014038], [74.34236145, 14.54986191], [74.34263611, 14.54986191], [74.34263611, 14.54957867], [74.3429184, 14.54958439], [74.3429184, 14.54930592], [74.34319305, 14.54930973], [74.34319305, 14.54874992], [74.34348297, 14.54874992], [74.34348297, 14.54846859], [74.34375, 14.5484724], [74.34375, 14.54819584], [74.34402466, 14.54819584], [74.34402466, 14.54763985], [74.34430695, 14.54763985], [74.34430695, 14.54736233], [74.3445816, 14.54736233], [74.3445816, 14.54708385], [74.34486389, 14.54708385], [74.34486389, 14.54652786], [74.34513855, 14.54652977], [74.34513855, 14.54625034], [74.34541321, 14.54625034], [74.34541321, 14.54597187], [74.3456955, 14.54597187], [74.3456955, 14.54541779], [74.34625244, 14.54541969], [74.34625244, 14.54681015], [74.3465271, 14.54680634], [74.3465271, 14.54708385], [74.34680176, 14.54708385], [74.34680939, 14.54736233], [74.3473587, 14.54736233], [74.3473587, 14.54763985], [74.34791565, 14.54763985], [74.34791565, 14.54652786], [74.34819794, 14.54652977], [74.34819794, 14.54625034], [74.34707642, 14.54625034], [74.34707642, 14.54486179], [74.3473587, 14.54486179], [74.3473587, 14.54403019], [74.34986115, 14.54403019], [74.34986115, 14.54347134], [74.3501358, 14.54347134], [74.3501358, 14.54236126], [74.35041809, 14.54236126], [74.35041809, 14.54180527], [74.35098267, 14.54182053], [74.35098267, 14.54152966], [74.35151672, 14.54152966], [74.35151672, 14.54124928], [74.3520813, 14.54124928], [74.3520813, 14.54096889], [74.35263824, 14.5409708], [74.35263824, 14.54069519], [74.35236359, 14.54069519], [74.35236359, 14.5401392], [74.3520813, 14.5401392], [74.3520813, 14.53986073], [74.35180664, 14.53986073], [74.35180664, 14.53931046], [74.35151672, 14.53931046], [74.35151672, 14.53876019], [74.35180664, 14.53876019], [74.35180664, 14.53792191], [74.3520813, 14.53792191], [74.3520813, 14.53764057], [74.35180664, 14.53764057], [74.35180664, 14.53736115], [74.35152435, 14.53736115], [74.35152435, 14.53625107], [74.35124969, 14.53625107], [74.35124969, 14.53347111], [74.35152435, 14.53347301], [74.35152435, 14.53291702], [74.35180664, 14.53292084], [74.35180664, 14.5320797], [74.35236359, 14.53208256], [74.35236359, 14.53152561], [74.3529129, 14.53153133], [74.3529129, 14.53125095], [74.35320282, 14.53125095], [74.35320282, 14.53069019], [74.35346985, 14.53069496], [74.35346985, 14.53013802], [74.35375977, 14.53014088], [74.35375977, 14.52959061], [74.35402679, 14.52959061], [74.35402679, 14.5290308], [74.35430908, 14.5290308], [74.35430908, 14.52847004], [74.35458374, 14.52847195], [74.35458374, 14.52819443], [74.3548584, 14.52819443], [74.3548584, 14.52763844], [74.35514069, 14.52764034], [74.35514069, 14.52682018], [74.35542297, 14.52682018], [74.35542297, 14.52625179], [74.35569763, 14.52625179], [74.35569763, 14.52514267], [74.35597229, 14.52514267], [74.35597229, 14.52402973], [74.35624695, 14.52402973], [74.35624695, 14.52291965], [74.35597229, 14.52291965], [74.35597229, 14.52207947], [74.35541534, 14.52208424], [74.35541534, 14.52180576], [74.35457611, 14.52180958], [74.35457611, 14.52153015], [74.35402679, 14.52153015], [74.35402679, 14.52124977], [74.34986115, 14.52124977], [74.34986115, 14.52153015], [74.34958649, 14.52153015], [74.34958649, 14.52124977], [74.34929657, 14.52124977], [74.34929657, 14.52069092], [74.34902954, 14.52069378], [74.34902954, 14.52041626], [74.34513855, 14.52042007], [74.34513855, 14.52013969], [74.34485626, 14.52013969], [74.34485626, 14.51986027], [74.3445816, 14.51986217], [74.3445816, 14.5195837], [74.34430695, 14.5195837], [74.34430695, 14.51875019], [74.34401703, 14.51875019], [74.34401703, 14.5176506], [74.34375, 14.5176506], [74.34375, 14.51736164], [74.34347534, 14.51736164], [74.34347534, 14.51708412], [74.34319305, 14.51708412], [74.34319305, 14.51652718], [74.3429184, 14.51653194], [74.3429184, 14.51597118], [74.34263611, 14.51597118], [74.34263611, 14.5154171], [74.34236145, 14.51542187], [74.34236145, 14.5148592], [74.34208679, 14.51486111], [74.34208679, 14.51430511], [74.34179688, 14.51431179], [74.34179688, 14.51402855], [74.34124756, 14.51402855], [74.34124756, 14.51375103], [74.33985901, 14.51375103], [74.33985901, 14.51402855], [74.33957672, 14.51402855], [74.33957672, 14.51431179], [74.33930206, 14.51431179], [74.33930206, 14.51459026], [74.3390274, 14.51458263], [74.3390274, 14.51486111], [74.33876038, 14.5148592], [74.33876038, 14.51513863], [74.33847046, 14.51513863], [74.33847046, 14.51542187], [74.3381958, 14.5154171], [74.3381958, 14.51569557], [74.33791351, 14.51569557], [74.33791351, 14.51708412], [74.3381958, 14.51708126], [74.3381958, 14.51736164], [74.33763885, 14.51736164], [74.33763885, 14.5176506], [74.33735657, 14.5176506], [74.33735657, 14.51791954], [74.33319092, 14.51791954], [74.33319092, 14.51736164], [74.33291626, 14.51736164], [74.33291626, 14.51708126], [74.33235931, 14.51708126], [74.33235931, 14.51736164], [74.33180237, 14.51736164], [74.33180237, 14.5176506], [74.33013916, 14.5176506], [74.33013916, 14.51625156], [74.32785034, 14.5162487], [74.32763672, 14.51625156], [74.32763672, 14.51597118], [74.32736206, 14.51597118], [74.32736206, 14.51569557], [74.32707977, 14.51569557], [74.32707977, 14.5154171], [74.32682037, 14.51542187], [74.32682037, 14.51513863], [74.32653046, 14.51513863], [74.32653046, 14.5148592], [74.32624817, 14.51486111], [74.32624817, 14.51458263], [74.32597351, 14.51458263], [74.32597351, 14.51486111], [74.32569122, 14.51486111], [74.32569122, 14.51693058], [74.32569122, 14.5176506], [74.32541656, 14.5176506], [74.32541656, 14.51875019], [74.32514191, 14.51875019], [74.32514191, 14.5195837], [74.32291412, 14.5195837], [74.32291412, 14.51736164], [74.32180786, 14.51736164], [74.32180786, 14.51791954], [74.32208252, 14.51791954], [74.32208252, 14.51875019], [74.32180786, 14.51875019], [74.32180786, 14.51931], [74.32152557, 14.51930618], [74.32152557, 14.5195837], [74.31874847, 14.5195837], [74.31874847, 14.51902771], [74.31846619, 14.51902962], [74.31846619, 14.51847172], [74.31874847, 14.51847172], [74.31874847, 14.51819324], [74.31903076, 14.51819324], [74.31903076, 14.51791763], [74.31931305, 14.51791954], [74.31931305, 14.51708126], [74.31903076, 14.51708412], [74.31903076, 14.5162487], [74.31874847, 14.51625156], [74.31874847, 14.51681042], [74.31846619, 14.51681042], [74.31846619, 14.5176506], [74.31819153, 14.51764011], [74.31819153, 14.51847363], [74.31791687, 14.51847172], [74.31791687, 14.51902962], [74.31624603, 14.51902962], [74.31624603, 14.51931], [74.31597137, 14.51930618], [74.31597137, 14.5195837], [74.31569672, 14.5195837], [74.31569672, 14.51986217], [74.3154068, 14.51986027], [74.3154068, 14.52013969], [74.31513977, 14.52013969], [74.31513977, 14.52042007], [74.31485748, 14.52041626], [74.31485748, 14.52069092], [74.31430817, 14.52069378], [74.31430817, 14.52097225], [74.31402588, 14.52096939], [74.31402588, 14.52124977], [74.31208038, 14.52124977], [74.31208038, 14.52096939], [74.31041718, 14.52097225], [74.31041718, 14.52069378], [74.3095932, 14.52069092], [74.3095932, 14.52124977], [74.30986023, 14.52124977], [74.30986023, 14.52208424], [74.31014252, 14.52207947], [74.31014252, 14.52264023], [74.31041718, 14.52264023], [74.31041718, 14.52319431], [74.31014252, 14.52319241], [74.31014252, 14.52375031], [74.31041718, 14.52375031], [74.31041718, 14.52402973], [74.31069183, 14.52402782], [74.31069183, 14.52458191], [74.31097412, 14.52458191], [74.31097412, 14.52486229], [74.31151581, 14.52486038], [74.31151581, 14.52514267], [74.31236267, 14.52514267], [74.31236267, 14.52542114], [74.31291962, 14.52541637], [74.31291962, 14.52569389], [74.31458282, 14.52569389], [74.31458282, 14.52597237], [74.31485748, 14.52597046], [74.31485748, 14.52625179], [74.31513977, 14.52625179], [74.31513977, 14.52682018], [74.3154068, 14.52682018], [74.3154068, 14.52735996], [74.31569672, 14.52735996], [74.31569672, 14.52875042], [74.31541443, 14.52875042], [74.31539917, 14.53040123], [74.31485748, 14.53041553], [74.31485748, 14.53069496], [74.31430817, 14.53069496], [74.31430817, 14.53097343], [74.31318665, 14.53096962], [74.31318665, 14.53125095], [74.31236267, 14.53125095], [74.31236267, 14.53153133], [74.31181335, 14.53153133], [74.31181335, 14.53181076], [74.31153107, 14.53180695], [74.31153107, 14.53208256], [74.31097412, 14.53208256], [74.31097412, 14.53347301], [74.31069183, 14.53347111], [74.31069183, 14.53625107], [74.31041718, 14.53625107], [74.31041718, 14.53764057], [74.31014252, 14.53763866], [74.31014252, 14.53819466], [74.30986023, 14.53819275], [74.30986023, 14.53876019], [74.31014252, 14.53876019], [74.31014252, 14.53903198], [74.31041718, 14.53903198], [74.31041718, 14.53931046], [74.31069183, 14.53930473], [74.31069183, 14.53958321], [74.31124878, 14.5395813], [74.31124878, 14.53986073], [74.31181335, 14.53986073], [74.31181335, 14.5401392], [74.31375122, 14.5401392], [74.31375122, 14.54041958], [74.31402588, 14.54041672], [74.31402588, 14.54236126], [74.31375122, 14.54236126], [74.31375122, 14.54458427], [74.31346893, 14.54456997], [74.31346893, 14.54541969], [74.31318665, 14.54541969], [74.31318665, 14.54625034], [74.31291962, 14.54625034], [74.31291962, 14.54708385], [74.31263733, 14.54708385], [74.31263733, 14.54763985], [74.31236267, 14.54763985], [74.31236267, 14.5484724], [74.31208038, 14.54846859], [74.31208038, 14.54930973], [74.31181335, 14.54930973], [74.31181335, 14.55014038], [74.31153107, 14.55013847], [74.31153107, 14.55097198], [74.31124878, 14.55097198], [74.31124878, 14.55181122], [74.31097412, 14.55180645], [74.31097412, 14.55236244], [74.31069183, 14.55235958], [74.31069183, 14.5529213], [74.31041718, 14.55291557], [74.31041718, 14.55347157], [74.31014252, 14.55346966], [74.31014252, 14.55403137], [74.30986023, 14.55402756], [74.30986023, 14.55458355], [74.3095932, 14.55457973], [74.3095932, 14.55514145], [74.30930328, 14.55513763], [74.30930328, 14.5559721], [74.30902863, 14.55597019], [74.30902863, 14.55653095], [74.30874634, 14.55652905], [74.30874634, 14.55708218], [74.30845642, 14.55708027], [74.30845642, 14.55764103], [74.30819702, 14.55763817], [74.30819702, 14.55819511], [74.3079071, 14.55819035], [74.3079071, 14.55875111], [74.30764008, 14.55875111], [74.30764008, 14.55931091], [74.30735779, 14.55931091], [74.30735779, 14.56014061], [74.30708313, 14.5601387], [74.30708313, 14.56069469], [74.30680847, 14.56068993], [74.30680847, 14.56125069], [74.30652618, 14.56125069], [74.30652618, 14.5618124], [74.30625153, 14.5618124], [74.30625153, 14.56264114], [74.30596924, 14.56263924], [74.30596924, 14.56319523], [74.30568695, 14.56319046], [74.30568695, 14.56375122], [74.30541992, 14.56375122], [74.30541992, 14.56431198], [74.30513763, 14.56431198], [74.30513763, 14.56514072], [74.30486298, 14.56514072], [74.30486298, 14.56569958], [74.30458069, 14.56569958], [74.30458069, 14.5662508], [74.30430603, 14.5662508], [74.30430603, 14.56680965], [74.30403137, 14.56680965], [74.30403137, 14.56736088], [74.30374908, 14.56736088], [74.30374908, 14.56819534], [74.30347443, 14.56819534], [74.30347443, 14.56874943], [74.30319214, 14.5687418], [74.30319214, 14.56931019], [74.30291748, 14.56930542], [74.30291748, 14.56986141], [74.30263519, 14.56986141], [74.30265045, 14.57069111], [74.30236053, 14.57069969], [74.30236053, 14.57125187], [74.30208588, 14.57124901], [74.30208588, 14.57208443], [74.30179596, 14.57208061], [74.30179596, 14.57236195], [74.30152893, 14.57236195], [74.30152893, 14.57347202], [74.30124664, 14.57347202], [74.30124664, 14.57374954], [74.30097198, 14.57374954], [74.30097198, 14.5743103], [74.30069733, 14.5743103], [74.30069733, 14.57487106], [74.30041504, 14.57486153], [74.30041504, 14.57708359], [74.30014038, 14.57708168], [74.30014038, 14.57763958], [74.29985809, 14.57763767], [74.29985809, 14.57819366], [74.29957581, 14.5781889], [74.29957581, 14.57874966], [74.29930878, 14.57874966], [74.29930878, 14.57958412], [74.29902649, 14.57958031], [74.29902649, 14.58014011], [74.29875183, 14.58013821], [74.29875183, 14.5806942], [74.29846954, 14.58068085], [74.29846954, 14.58125019], [74.29818726, 14.58125019], [74.29818726, 14.58181095], [74.29792023, 14.58180428], [74.29792023, 14.58236027], [74.29763794, 14.58236027], [74.29763794, 14.58292103], [74.29736328, 14.58291626], [74.29736328, 14.58347225], [74.29708099, 14.58347034], [74.29708099, 14.58403111], [74.29680634, 14.5840292], [74.29680634, 14.58458233], [74.29651642, 14.58458042], [74.29651642, 14.58514118], [74.29624939, 14.58513927], [74.29624939, 14.58569527], [74.2959671, 14.58568954], [74.2959671, 14.58625126], [74.29569244, 14.58625126], [74.29569244, 14.58681107], [74.29541779, 14.58680534], [74.29541779, 14.58736134], [74.29514313, 14.58736134], [74.29514313, 14.58791924], [74.29486084, 14.58791733], [74.29486084, 14.58847332], [74.29458618, 14.58847141], [74.29458618, 14.58903122], [74.29429626, 14.58903122], [74.29429626, 14.58987045], [74.29402924, 14.58987045], [74.29402924, 14.59042168], [74.29374695, 14.59042168], [74.29374695, 14.59125137], [74.29347992, 14.59125137], [74.29347992, 14.59181023], [74.29319763, 14.59180546], [74.29319763, 14.59236145], [74.29292297, 14.59236145], [74.29292297, 14.59293079], [74.2923584, 14.59291744], [74.2923584, 14.59347343], [74.29207611, 14.59347057], [74.29207611, 14.59402943], [74.29180908, 14.59402657], [74.29180908, 14.59458256], [74.29152679, 14.59458065], [74.29152679, 14.59486103], [74.29125214, 14.59486103], [74.29125214, 14.59542179], [74.29096985, 14.59541702], [74.29096985, 14.59597111], [74.29069519, 14.59597111], [74.29069519, 14.59708309], [74.29096985, 14.59708118], [74.29096985, 14.59792042], [74.29292297, 14.59792042], [74.29292297, 14.59764194], [74.29347992, 14.59764194], [74.29347992, 14.59736156], [74.29402924, 14.59736156], [74.29402924, 14.59708118], [74.29486084, 14.59708309], [74.29486084, 14.59736156], [74.29458618, 14.59736156], [74.29458618, 14.60060024], [74.29458618, 14.60153008], [74.29319763, 14.60153008], [74.29319763, 14.60181046], [74.29180908, 14.60180569], [74.29180908, 14.60208416], [74.29125214, 14.60207939], [74.29125214, 14.60235977], [74.29096985, 14.60235977], [74.29096985, 14.60264015], [74.29042053, 14.60264015], [74.29042053, 14.60291958], [74.28986359, 14.60291576], [74.28986359, 14.60319424], [74.2895813, 14.60319424], [74.2895813, 14.60347176], [74.28901672, 14.60346985], [74.28902435, 14.60375023], [74.28848267, 14.60375023], [74.28848267, 14.60402966], [74.28819275, 14.60402966], [74.28819275, 14.60431099], [74.2876358, 14.60430622], [74.2876358, 14.60458374], [74.28736115, 14.60458183], [74.28736115, 14.6048708], [74.28679657, 14.6048708], [74.28679657, 14.60513973], [74.28652954, 14.60513973], [74.28652954, 14.60542107], [74.28624725, 14.6054163], [74.28624725, 14.60569382], [74.28569794, 14.60569382], [74.28569794, 14.60597229], [74.28542328, 14.60597038], [74.28542328, 14.60625172], [74.2848587, 14.60625172], [74.2848587, 14.60653019], [74.28457642, 14.60653019], [74.28457642, 14.60681057], [74.28430939, 14.6068058], [74.28430176, 14.60708427], [74.28375244, 14.60708046], [74.28375244, 14.60736179], [74.28347015, 14.60736179], [74.28347015, 14.60764027], [74.2831955, 14.60764027], [74.2831955, 14.60791588], [74.28263855, 14.60791588], [74.28263855, 14.60819435], [74.28236389, 14.60819435], [74.28236389, 14.60847187], [74.2820816, 14.60846996], [74.2820816, 14.60875034], [74.28180695, 14.60875034], [74.28180695, 14.60903072], [74.28151703, 14.60903072], [74.28151703, 14.6093111], [74.28097534, 14.60930634], [74.28097534, 14.60958195], [74.28069305, 14.60958195], [74.28069305, 14.60986042], [74.2804184, 14.60986042], [74.2804184, 14.6101408], [74.28013611, 14.6101408], [74.28013611, 14.61042118], [74.27986145, 14.61041641], [74.27986145, 14.61097336], [74.27958679, 14.61096954], [74.27958679, 14.61181068], [74.27929688, 14.61181068], [74.27929688, 14.61292076], [74.27902985, 14.61292076], [74.27902985, 14.61375141], [74.27874756, 14.61375141], [74.27874756, 14.61681175], [74.2784729, 14.61680698], [74.27848053, 14.61736107], [74.27819824, 14.61736107], [74.27819824, 14.61792183], [74.27791595, 14.61792183], [74.27791595, 14.61875057], [74.2776413, 14.61875057], [74.2776413, 14.61931038], [74.27735901, 14.61931038], [74.27735901, 14.62014103], [74.27708435, 14.62013912], [74.27708435, 14.62069321], [74.27680206, 14.6206913], [74.27680206, 14.6212492], [74.27625275, 14.6212492], [74.27625275, 14.62152863], [74.27597046, 14.62152672], [74.27597046, 14.62236118], [74.2756958, 14.62236118], [74.2756958, 14.62291527], [74.27542114, 14.62291145], [74.27542114, 14.62375164], [74.27513885, 14.62375164], [74.27513885, 14.62403202], [74.27485657, 14.62403202], [74.27485657, 14.62430954], [74.27458191, 14.62430477], [74.27458191, 14.6245842], [74.27401733, 14.62458134], [74.27401733, 14.62486172], [74.27375031, 14.62486172], [74.27375031, 14.62652969], [74.27347565, 14.62652779], [74.27347565, 14.62708378], [74.27263641, 14.62708378], [74.27263641, 14.62680626], [74.27179718, 14.62681007], [74.27179718, 14.62652969], [74.27153015, 14.62652969], [74.27153015, 14.62625027], [74.27041626, 14.62625027], [74.27041626, 14.62652969], [74.26985931, 14.62652969], [74.26985931, 14.62681007], [74.26957703, 14.62681007], [74.26957703, 14.62874985], [74.26985931, 14.62874985], [74.26985931, 14.62904167], [74.2701416, 14.62902832], [74.2701416, 14.62958431], [74.27069092, 14.62957859], [74.27069092, 14.6301403], [74.27041626, 14.6301403], [74.27041626, 14.63069439], [74.27069092, 14.63069439], [74.27069092, 14.63097191], [74.2720871, 14.63097191], [74.2720871, 14.63041592], [74.2723465, 14.63041973], [74.2723465, 14.6301403], [74.2729187, 14.6301403], [74.2729187, 14.62986183], [74.27319336, 14.62986183], [74.27319336, 14.62957859], [74.27347565, 14.62958431], [74.27347565, 14.62930584], [74.27375031, 14.62930965], [74.27375031, 14.62904167], [74.27430725, 14.62904167], [74.27430725, 14.62874985], [74.27542114, 14.62874985], [74.27541351, 14.62847233], [74.27625275, 14.62847233], [74.27625275, 14.62819576], [74.2765274, 14.62819576], [74.2765274, 14.62791634], [74.27707672, 14.62792015], [74.27707672, 14.62763977], [74.27791595, 14.62763977], [74.27791595, 14.62735939], [74.2784729, 14.62736225], [74.2784729, 14.62708378], [74.27902985, 14.62708378], [74.27902985, 14.62680626], [74.28013611, 14.62680626], [74.28013611, 14.62708378], [74.28125, 14.62708378], [74.28125, 14.62736225], [74.28151703, 14.62735939], [74.28151703, 14.62792015], [74.28180695, 14.62791634], [74.28180695, 14.62847233], [74.2820816, 14.62846947], [74.2820816, 14.62904167], [74.28236389, 14.62902832], [74.28236389, 14.62958431], [74.28263855, 14.62957859], [74.28263855, 14.6301403], [74.28291321, 14.6301403], [74.28291321, 14.63041973], [74.2831955, 14.63041592], [74.2831955, 14.63069439], [74.28375244, 14.63069439], [74.28375244, 14.63097191], [74.2840271, 14.63097191], [74.2840271, 14.6340313], [74.28430176, 14.63402843], [74.28430939, 14.63597202], [74.28458405, 14.63597202], [74.28458405, 14.63819504], [74.2848587, 14.63819027], [74.2848587, 14.64014053], [74.28457642, 14.64014053], [74.28457642, 14.64236069], [74.28430939, 14.64236069], [74.2842865, 14.6443119], [74.2840271, 14.6443119], [74.2840271, 14.64542198], [74.28375244, 14.64541721], [74.28375244, 14.64597321], [74.28347015, 14.6459713], [74.28347015, 14.6465292], [74.28320313, 14.6465292], [74.28320313, 14.64680958], [74.28263855, 14.64680481], [74.28263855, 14.6473608], [74.28236389, 14.6473608], [74.28236389, 14.64847088], [74.2820816, 14.64847088], [74.2820816, 14.64903164], [74.27902985, 14.64902687], [74.27902985, 14.64958286], [74.2793045, 14.64958286], [74.2793045, 14.64986134], [74.27986145, 14.64986134], [74.27986145, 14.65015125], [74.28013611, 14.65015125], [74.28013611, 14.65042019], [74.28069305, 14.65041542], [74.28069305, 14.6506958], [74.28097534, 14.6506958], [74.28097534, 14.65097141], [74.28125, 14.65097141], [74.28125, 14.65125179], [74.28151703, 14.65125179], [74.28151703, 14.65153027], [74.28180695, 14.6515274], [74.28180695, 14.65208435], [74.2820816, 14.65208054], [74.2820816, 14.65236187], [74.28235626, 14.65236187], [74.28235626, 14.65264034], [74.2820816, 14.65264034], [74.2820816, 14.65319443], [74.28180695, 14.65319443], [74.28180695, 14.65347195], [74.28151703, 14.65347195], [74.28151703, 14.65402985], [74.28125, 14.65402794], [74.28125, 14.65458393], [74.28097534, 14.65458393], [74.28097534, 14.6548624], [74.28069305, 14.65485954], [74.28069305, 14.6554203], [74.2804184, 14.65541553], [74.2804184, 14.65569401], [74.28013611, 14.65569401], [74.28013611, 14.65597153], [74.27986145, 14.65596008], [74.27986145, 14.65625], [74.27958679, 14.65625], [74.27958679, 14.65653038], [74.27902985, 14.65653038], [74.27902985, 14.65625], [74.27874756, 14.65625], [74.27874756, 14.65680981], [74.27848053, 14.65680981], [74.27848053, 14.65764046], [74.27819824, 14.65764046], [74.27819824, 14.65792274], [74.27791595, 14.65791798], [74.27791595, 14.65819359], [74.27819824, 14.65819168], [74.27819824, 14.65874958], [74.27848053, 14.65874958], [74.27848053, 14.65931129], [74.27874756, 14.65931129], [74.27874756, 14.65985966], [74.27902985, 14.65985966], [74.27902985, 14.66042137], [74.27958679, 14.66041565], [74.27958679, 14.66069412], [74.28013611, 14.66069412], [74.28013611, 14.66097164], [74.28125, 14.66096973], [74.28125, 14.66125011], [74.28151703, 14.66125011], [74.28151703, 14.66181087], [74.28180695, 14.6618309], [74.28180695, 14.66209126], [74.2820816, 14.66209126], [74.2820816, 14.66264057], [74.28235626, 14.66264057], [74.28235626, 14.66292095], [74.28291321, 14.66291618], [74.28291321, 14.66347218], [74.28263855, 14.66347027], [74.28263855, 14.66374969], [74.28098297, 14.66374969], [74.28098297, 14.6631918], [74.2808609, 14.6631918], [74.28069305, 14.6631937], [74.28069305, 14.66291618], [74.2804184, 14.66292095], [74.2804184, 14.66264057], [74.28013611, 14.66264057], [74.28013611, 14.66209126], [74.27986145, 14.66209126], [74.27986145, 14.66181087], [74.27958679, 14.66181087], [74.27958679, 14.66153145], [74.27902985, 14.66153145], [74.27902985, 14.66125011], [74.27848053, 14.66125011], [74.27848053, 14.66096973], [74.27791595, 14.66097164], [74.27791595, 14.66069412], [74.27735901, 14.66069412], [74.27735901, 14.66041565], [74.27707672, 14.66042137], [74.27707672, 14.66014004], [74.2765274, 14.66014004], [74.2765274, 14.65985966], [74.27625275, 14.65985966], [74.27625275, 14.66014004], [74.2756958, 14.66014004], [74.2756958, 14.66042137], [74.27541351, 14.66041565], [74.27541351, 14.66069412], [74.2756958, 14.66069412], [74.2756958, 14.66097164], [74.27625275, 14.66096973], [74.27625275, 14.66125011], [74.2765274, 14.66125011], [74.2765274, 14.66153145], [74.27680206, 14.66153145], [74.27680206, 14.66181087], [74.27848053, 14.66181087], [74.27848053, 14.66209126], [74.27902985, 14.66209126], [74.27902985, 14.66264057], [74.27874756, 14.66264057], [74.27874756, 14.66374969], [74.27848053, 14.66374969], [74.27848053, 14.66431141], [74.27819824, 14.66431141], [74.27819824, 14.66485977], [74.27791595, 14.66485977], [74.27791595, 14.66542053], [74.2776413, 14.66541672], [74.2776413, 14.66569519], [74.27708435, 14.66569519], [74.27708435, 14.66597271], [74.27541351, 14.66597271], [74.27541351, 14.66625118], [74.2756958, 14.66625118], [74.2756958, 14.66681099], [74.27597046, 14.66680527], [74.27597046, 14.66708469], [74.27625275, 14.66708469], [74.27625275, 14.66736126], [74.2765274, 14.66736126], [74.2765274, 14.66764069], [74.27680206, 14.66764069], [74.27680206, 14.66792107], [74.27708435, 14.66791725], [74.27708435, 14.66847324], [74.27735901, 14.66847134], [74.27735901, 14.66875076], [74.2776413, 14.66875076], [74.2776413, 14.66903114], [74.27735901, 14.66902924], [74.27735901, 14.66958332], [74.2765274, 14.66958046], [74.2765274, 14.66986084], [74.27597046, 14.66986084], [74.27597046, 14.67014122], [74.27625275, 14.67013931], [74.27625275, 14.6706953], [74.2765274, 14.67068958], [74.2765274, 14.6712513], [74.27680206, 14.6712513], [74.27680206, 14.6718092], [74.27708435, 14.67180538], [74.27708435, 14.67236137], [74.27735901, 14.67236137], [74.27735901, 14.67263889], [74.2776413, 14.67263889], [74.2776413, 14.67236137], [74.27791595, 14.67236137], [74.27791595, 14.6720829], [74.27819061, 14.6720829], [74.27819824, 14.67180538], [74.27874756, 14.6718092], [74.27874756, 14.67153072], [74.27902985, 14.67153072], [74.27902985, 14.6712513], [74.27929688, 14.6712513], [74.27929688, 14.67095947], [74.2804184, 14.67095947], [74.2804184, 14.6712513], [74.28069305, 14.6712513], [74.28069305, 14.6718092], [74.28097534, 14.67180538], [74.28097534, 14.6720829], [74.28125, 14.67208099], [74.28125, 14.67263889], [74.28152466, 14.67263889], [74.28152466, 14.67319489], [74.28180695, 14.67319107], [74.28180695, 14.67792034], [74.28152466, 14.67791843], [74.28152466, 14.67847061], [74.28125, 14.67847061], [74.28125, 14.67903042], [74.28097534, 14.67902756], [74.28097534, 14.67958355], [74.28069305, 14.67958355], [74.28069305, 14.68013954], [74.2804184, 14.68013954], [74.2804184, 14.68069363], [74.28013611, 14.68068886], [74.28013611, 14.68124962], [74.27986145, 14.68124962], [74.27986145, 14.68208408], [74.27958679, 14.68207932], [74.27958679, 14.68264008], [74.2793045, 14.68264008], [74.2793045, 14.68319416], [74.27902985, 14.68318939], [74.27902985, 14.68375015], [74.27874756, 14.68375015], [74.27874756, 14.68431091], [74.2784729, 14.68430614], [74.2784729, 14.68486214], [74.27819824, 14.68486023], [74.27819824, 14.68542004], [74.27791595, 14.68541622], [74.27791595, 14.68597221], [74.2776413, 14.68597031], [74.2776413, 14.68653011], [74.27735901, 14.68653011], [74.27735901, 14.68681145], [74.27707672, 14.68681145], [74.27707672, 14.68736172], [74.27680206, 14.68736172], [74.27680206, 14.68792057], [74.2765274, 14.6879158], [74.2765274, 14.68819427], [74.27625275, 14.68819046], [74.27625275, 14.68875027], [74.27597046, 14.68875027], [74.27597046, 14.68931961], [74.2756958, 14.68930626], [74.2756958, 14.68986034], [74.27542114, 14.68986034], [74.27542114, 14.6904211], [74.27513885, 14.69041634], [74.27513885, 14.69097233], [74.27485657, 14.69097042], [74.27485657, 14.69153118], [74.27458191, 14.69153118], [74.27458191, 14.69235992], [74.27430725, 14.69235992], [74.27430725, 14.69292068], [74.27402496, 14.69291687], [74.27402496, 14.69347286], [74.27375031, 14.69347], [74.27375031, 14.69403076], [74.27347565, 14.69402885], [74.27347565, 14.69458294], [74.27319336, 14.69458294], [74.27319336, 14.69486141], [74.2729187, 14.69486141], [74.2729187, 14.69513893], [74.27263641, 14.69513035], [74.27263641, 14.69542122], [74.27236176, 14.6954174], [74.27236176, 14.6959734], [74.2720871, 14.6959734], [74.2720871, 14.69640064], [74.2720871, 14.6965313], [74.27180481, 14.69652653], [74.27180481, 14.69708347], [74.27153015, 14.69708061], [74.27153015, 14.69764137], [74.27124786, 14.69764137], [74.27124786, 14.69820023], [74.27097321, 14.69820023], [74.27097321, 14.69875145], [74.27069092, 14.69875145], [74.27069092, 14.69958305], [74.27041626, 14.69958115], [74.27041626, 14.70014095], [74.2701416, 14.70013905], [74.2701416, 14.70069313], [74.26985931, 14.70069122], [74.26985931, 14.70125961], [74.26957703, 14.70125961], [74.26957703, 14.70181179], [74.26930237, 14.70180511], [74.26930237, 14.70236111], [74.26902771, 14.7023592], [74.26902771, 14.70264244], [74.26875305, 14.70264244], [74.26875305, 14.70292187], [74.26847076, 14.7029171], [74.26847076, 14.70319462], [74.26819611, 14.70319462], [74.26819611, 14.70347118], [74.26790619, 14.70347118], [74.26790619, 14.70375156], [74.26763916, 14.70375156], [74.26763916, 14.70403194], [74.26735687, 14.70403194], [74.26735687, 14.70432091], [74.26708221, 14.7043047], [74.26708221, 14.70458317], [74.26680756, 14.70458126], [74.26680756, 14.70486164], [74.26654053, 14.70486164], [74.26654053, 14.70514202], [74.26374817, 14.70514202], [74.26374817, 14.70486164], [74.26291656, 14.70486164], [74.26291656, 14.70541954], [74.26264191, 14.70541763], [74.26264191, 14.70569324], [74.26208496, 14.70569324], [74.26208496, 14.70597363], [74.26180267, 14.70597076], [74.26180267, 14.70625019], [74.26125336, 14.70625019], [74.26125336, 14.70652962], [74.26097107, 14.70652771], [74.26097107, 14.7070837], [74.25958252, 14.7070837], [74.25958252, 14.70680618], [74.25875092, 14.70681], [74.25875092, 14.70652962], [74.25846863, 14.70652962], [74.25846863, 14.70681], [74.25763702, 14.70681], [74.25763702, 14.70652962], [74.25734711, 14.70652962], [74.25734711, 14.70625019], [74.25708008, 14.70625019], [74.25708008, 14.70597076], [74.25681305, 14.70597076], [74.25681305, 14.70652962], [74.25653076, 14.70652962], [74.25653076, 14.70792007], [74.25846863, 14.70792007], [74.25846863, 14.70874977], [74.25985718, 14.70874977], [74.25985718, 14.70903015], [74.26040649, 14.70903015], [74.26040649, 14.70930958], [74.26069641, 14.70930576], [74.26069641, 14.70958424], [74.26097107, 14.70958424], [74.26097107, 14.70986176], [74.26152802, 14.70985985], [74.26152802, 14.71014023], [74.26180267, 14.71014023], [74.26180267, 14.71041965], [74.26235962, 14.71041584], [74.26235962, 14.71069431], [74.26264191, 14.71069431], [74.26264191, 14.71097183], [74.26319122, 14.71097183], [74.26319122, 14.71125031], [74.26348114, 14.71125031], [74.26348114, 14.71152973], [74.26403046, 14.71152973], [74.26403046, 14.71181107], [74.26457977, 14.7118063], [74.26457977, 14.71208191], [74.26597595, 14.71208191], [74.26597595, 14.71236229], [74.26708221, 14.71236038], [74.26708221, 14.71263981], [74.26735687, 14.71263981], [74.26735687, 14.71320057], [74.26708221, 14.71320057], [74.26708221, 14.71375179], [74.26680756, 14.71375179], [74.26680756, 14.71431065], [74.26652527, 14.71430588], [74.26654053, 14.71485996], [74.26625061, 14.71485996], [74.26625061, 14.71514034], [74.26597595, 14.71514034], [74.26597595, 14.71542072], [74.26569366, 14.71541595], [74.26569366, 14.71569443], [74.26486206, 14.71569443], [74.26486206, 14.71430588], [74.26457977, 14.71431065], [74.26457977, 14.71403027], [74.26374817, 14.71402836], [74.26374817, 14.71708202], [74.26348114, 14.71708012], [74.26348114, 14.71764088], [74.26319122, 14.71764088], [74.26319122, 14.71792126], [74.26291656, 14.71791553], [74.26291656, 14.71847343], [74.26264191, 14.71846962], [74.26264191, 14.71875095], [74.26235962, 14.71875095], [74.26235962, 14.71930695], [74.26208496, 14.71930695], [74.26208496, 14.7195816], [74.26180267, 14.7195797], [74.26180267, 14.72014141], [74.26152802, 14.72014141], [74.26152802, 14.72042084], [74.26125336, 14.72041702], [74.26125336, 14.72097301], [74.26097107, 14.72097015], [74.26097107, 14.72153091], [74.26069641, 14.72152901], [74.26069641, 14.72208309], [74.26041412, 14.72208309], [74.26041412, 14.72236061], [74.26013947, 14.72236061], [74.26013947, 14.72292137], [74.25986481, 14.7229166], [74.25986481, 14.7234726], [74.25958252, 14.72347069], [74.25958252, 14.72403145], [74.25930786, 14.72403145], [74.25930786, 14.72431183], [74.25902557, 14.72430515], [74.25902557, 14.72486115], [74.25875092, 14.72486115], [74.25875092, 14.72543144], [74.25846863, 14.72541714], [74.25846863, 14.72597313], [74.25818634, 14.72597122], [74.25818634, 14.72625065], [74.25791931, 14.72625065], [74.25791931, 14.72681046], [74.25763702, 14.72680473], [74.25763702, 14.72708321], [74.25734711, 14.7270813], [74.25734711, 14.72736073], [74.25708008, 14.72736073], [74.25708008, 14.72791958], [74.25681305, 14.72791958], [74.25681305, 14.72819996], [74.25653076, 14.72819996], [74.25653076, 14.72874928], [74.25624847, 14.72874928], [74.25624847, 14.72903156], [74.25597382, 14.72902679], [74.25597382, 14.72958279], [74.25569153, 14.72958279], [74.25569153, 14.72986126], [74.25541687, 14.72986126], [74.25541687, 14.73014164], [74.25514221, 14.73013878], [74.25514221, 14.73069572], [74.25485992, 14.73069572], [74.25485992, 14.73097134], [74.25458527, 14.73097134], [74.25460052, 14.73152065], [74.25431061, 14.73153019], [74.25431061, 14.73180962], [74.25402832, 14.73180485], [74.25402832, 14.73208427], [74.25374603, 14.73208141], [74.25374603, 14.73236179], [74.25319672, 14.73236179], [74.25319672, 14.73264027], [74.2529068, 14.73264027], [74.2529068, 14.73291969], [74.25263977, 14.73291779], [74.25263977, 14.7331934], [74.25235748, 14.7331934], [74.25235748, 14.73347092], [74.25180817, 14.73347092], [74.25180817, 14.73375034], [74.25152588, 14.73375034], [74.25152588, 14.73402977], [74.25125122, 14.73402786], [74.25125122, 14.73430634], [74.25096893, 14.73430634], [74.25096893, 14.73458385], [74.25069427, 14.73458385], [74.25069427, 14.73486233], [74.25013733, 14.73485947], [74.25013733, 14.73513985], [74.24986267, 14.73513985], [74.24986267, 14.73542023], [74.24958038, 14.73541641], [74.24958038, 14.73922157], [74.24958038, 14.73958397], [74.24913788, 14.73958397], [74.24903107, 14.73958397], [74.24903107, 14.73985958], [74.24874878, 14.73987961], [74.24874878, 14.74013996], [74.24845123, 14.74013805], [74.24819183, 14.74013805], [74.24819183, 14.74033928], [74.24819183, 14.74041557], [74.24791718, 14.74041557], [74.24791718, 14.74069405], [74.24736023, 14.74069405], [74.24736023, 14.74097157], [74.2470932, 14.74096966], [74.2470932, 14.74125004], [74.24652863, 14.74125004], [74.24652863, 14.74153137], [74.24624634, 14.74153137], [74.24624634, 14.7418108], [74.24569702, 14.74180603], [74.24569702, 14.74208355], [74.2454071, 14.74207973], [74.2454071, 14.74236012], [74.24485779, 14.74236012], [74.24485779, 14.74263954], [74.24458313, 14.74263954], [74.24458313, 14.74292088], [74.24430847, 14.74291611], [74.24430847, 14.74319363], [74.24375153, 14.74319363], [74.24375153, 14.7434721], [74.24318695, 14.74347019], [74.24318695, 14.74374962], [74.24291992, 14.74374962], [74.24291992, 14.74403095], [74.24237061, 14.74403095], [74.24237061, 14.74431133], [74.24208069, 14.74430656], [74.24208069, 14.74458218], [74.24153137, 14.74458218], [74.24153137, 14.7448597], [74.24124908, 14.7448597], [74.24124908, 14.74514103], [74.24069214, 14.74514103], [74.24069214, 14.74542141], [74.24013519, 14.74541569], [74.24013519, 14.74569511], [74.23958588, 14.74569511], [74.23958588, 14.74597263], [74.23930359, 14.74597263], [74.23930359, 14.74625111], [74.23874664, 14.74624062], [74.23874664, 14.74653053], [74.23819733, 14.74653053], [74.23819733, 14.74681091], [74.23791504, 14.74680424], [74.23791504, 14.74708462], [74.23735809, 14.74708462], [74.23735809, 14.74736118], [74.23596954, 14.74736118], [74.23596954, 14.74764061], [74.23458099, 14.74764061], [74.23458099, 14.74792099], [74.23264313, 14.74792099], [74.23264313, 14.74764061], [74.23208618, 14.74764061], [74.23208618, 14.74736118], [74.23124695, 14.74736118], [74.23124695, 14.74708462], [74.23069763, 14.74708462], [74.23069763, 14.74680424], [74.2298584, 14.74681091], [74.2298584, 14.74653053], [74.22930908, 14.74653053], [74.22930908, 14.74624062], [74.22875214, 14.74625111], [74.22875214, 14.74597263], [74.22819519, 14.74597263], [74.22819519, 14.74569511], [74.22763824, 14.74569511], [74.22763824, 14.74513817], [74.22737122, 14.74514103], [74.22737122, 14.74458027], [74.22763824, 14.74458218], [74.22763824, 14.74430656], [74.22737122, 14.74431133], [74.22737122, 14.74403095], [74.22763824, 14.74403095], [74.22763824, 14.74318123], [74.2279129, 14.74319363], [74.2279129, 14.74263763], [74.22820282, 14.74263954], [74.22820282, 14.74236012], [74.22846985, 14.74236012], [74.22846985, 14.74125004], [74.22902679, 14.74125004], [74.22902679, 14.74096966], [74.22875214, 14.74097157], [74.22875214, 14.74069405], [74.22902679, 14.74069405], [74.22902679, 14.74041557], [74.22875214, 14.74043179], [74.22875214, 14.73931122], [74.22846985, 14.73931122], [74.22846985, 14.7381916], [74.22875214, 14.73819447], [74.22875214, 14.73763847], [74.22820282, 14.73764038], [74.22820282, 14.73708153], [74.22624969, 14.73708439], [74.22624969, 14.73680592], [74.22319794, 14.73680973], [74.22319794, 14.7365303], [74.22292328, 14.7365303], [74.22292328, 14.73596859], [74.22264099, 14.7359724], [74.22264099, 14.73541641], [74.2215271, 14.73541641], [74.2215271, 14.73569584], [74.22125244, 14.73569584], [74.22125244, 14.7359724], [74.22070313, 14.73596859], [74.22070313, 14.73624992], [74.22013855, 14.73624992], [74.22013855, 14.7365303], [74.2195816, 14.7365303], [74.2195816, 14.73680973], [74.21820068, 14.73680973], [74.21820068, 14.7365303], [74.21763611, 14.7365303], [74.21763611, 14.73624992], [74.21652985, 14.73624992], [74.21652985, 14.73596859], [74.21624756, 14.7359724], [74.21624756, 14.73541641], [74.21569824, 14.73542023], [74.21569061, 14.73513985], [74.2151413, 14.73513985], [74.2151413, 14.73485947], [74.21485901, 14.73486233], [74.21485901, 14.73458385], [74.21291351, 14.73458385], [74.21291351, 14.73430634], [74.21263885, 14.73430634], [74.21263885, 14.73402786], [74.21235657, 14.73402977], [74.21235657, 14.73375034], [74.21206665, 14.73375034], [74.21206665, 14.73347092], [74.21180725, 14.73347092], [74.21180725, 14.7331934], [74.21125031, 14.7331934], [74.21125031, 14.73291779], [74.21097565, 14.73291779], [74.21097565, 14.7331934], [74.2104187, 14.7331934], [74.2104187, 14.73347092], [74.20986176, 14.73347092], [74.20986176, 14.73375034], [74.2095871, 14.73375034], [74.2095871, 14.73402977], [74.20930481, 14.73402786], [74.20930481, 14.73486233], [74.20903015, 14.73485947], [74.20903015, 14.73680973], [74.20874786, 14.73680592], [74.20874786, 14.73708439], [74.20847321, 14.73708153], [74.20847321, 14.73737144], [74.20735931, 14.73737144], [74.20735931, 14.73764038], [74.20707703, 14.73764038], [74.20707703, 14.73737144], [74.20652771, 14.73737144], [74.20652771, 14.73708153], [74.20597076, 14.73708439], [74.20597076, 14.73680592], [74.20569611, 14.73680973], [74.20569611, 14.7365303], [74.20513916, 14.7365303], [74.20513916, 14.73596859], [74.2048645, 14.7359724], [74.2048645, 14.73541641], [74.20430756, 14.73542023], [74.20430756, 14.73513985], [74.2040329, 14.73513985], [74.2040329, 14.73485947], [74.20375061, 14.73486233], [74.20375061, 14.73458385], [74.20347595, 14.73458385], [74.20347595, 14.73291779], [74.20320129, 14.73291969], [74.20320129, 14.73264027], [74.20349121, 14.73264027], [74.20349121, 14.73236179], [74.20375061, 14.73236179], [74.20375061, 14.73124027], [74.20402527, 14.73124886], [74.20402527, 14.73097134], [74.20458221, 14.73097134], [74.20458221, 14.73069572], [74.20513916, 14.73069572], [74.20513916, 14.73013878], [74.20569611, 14.73014164], [74.20569611, 14.72986126], [74.20597076, 14.72986126], [74.20597076, 14.72930527], [74.20626068, 14.72931194], [74.20626068, 14.72736073], [74.20652771, 14.72736073], [74.20652771, 14.72625065], [74.20680237, 14.72625065], [74.20680237, 14.72514057], [74.20707703, 14.72514057], [74.20707703, 14.72431183], [74.20735931, 14.72431183], [74.20735931, 14.72375107], [74.2076416, 14.72375107], [74.2076416, 14.72347069], [74.20735931, 14.7234726], [74.20735931, 14.72319508], [74.20791626, 14.72319508], [74.20791626, 14.72208309], [74.20819092, 14.72208309], [74.20819092, 14.72152901], [74.20791626, 14.72153091], [74.20791626, 14.72125053], [74.20819092, 14.72125053], [74.20819092, 14.72097015], [74.20847321, 14.72097301], [74.20847321, 14.71986008], [74.20874786, 14.71986008], [74.20874786, 14.71764088], [74.20847321, 14.71764088], [74.20847321, 14.71735954], [74.20819092, 14.71735954], [74.20819092, 14.71764088], [74.20791626, 14.71764088], [74.20791626, 14.71735954], [74.2076416, 14.71735954], [74.2076416, 14.71764088], [74.20652771, 14.71764088], [74.20652771, 14.71792126], [74.2059021, 14.71791935], [74.2048645, 14.71791553], [74.2048645, 14.71819401], [74.20458221, 14.71819401], [74.20458221, 14.71847343], [74.2040329, 14.71846962], [74.2040329, 14.71875095], [74.20347595, 14.71875095], [74.20347595, 14.71930695], [74.20319366, 14.71930695], [74.20319366, 14.7195816], [74.20263672, 14.7195797], [74.20263672, 14.71986008], [74.20207977, 14.71986008], [74.20207977, 14.72014141], [74.20153046, 14.72014141], [74.20153046, 14.72042084], [74.20124817, 14.72041702], [74.20124817, 14.72069454], [74.20069122, 14.72068977], [74.20069122, 14.72125053], [74.20012665, 14.72125053], [74.20012665, 14.72181129], [74.19985962, 14.72180462], [74.19985962, 14.72208309], [74.19958496, 14.72208309], [74.19958496, 14.72236061], [74.19930267, 14.72236061], [74.19930267, 14.72264099], [74.19902802, 14.72263908], [74.19902802, 14.72319508], [74.19847107, 14.72319508], [74.19847107, 14.7234726], [74.19819641, 14.72347069], [74.19819641, 14.72403145], [74.19763947, 14.72403145], [74.19763947, 14.72431183], [74.19735718, 14.72431183], [74.19735718, 14.72403145], [74.19706726, 14.72403145], [74.19706726, 14.72431183], [74.19652557, 14.72430515], [74.19652557, 14.72458267], [74.19541931, 14.72458267], [74.19541931, 14.72486115], [74.19403076, 14.72486115], [74.19403076, 14.72514057], [74.19374847, 14.72514057], [74.19374847, 14.72543144], [74.19319153, 14.72541714], [74.19319153, 14.72569466], [74.19235992, 14.72569275], [74.19235992, 14.72736073], [74.19264221, 14.72736073], [74.19264221, 14.72791958], [74.19291687, 14.72791958], [74.19291687, 14.72819996], [74.19319153, 14.72819519], [74.19319153, 14.7284708], [74.19346619, 14.72846889], [74.19346619, 14.72874928], [74.19374847, 14.72874928], [74.19374847, 14.72903156], [74.19403076, 14.72902679], [74.19403076, 14.72958279], [74.19430542, 14.72958279], [74.19430542, 14.72986126], [74.19458008, 14.72986126], [74.19458008, 14.73014164], [74.19430542, 14.73013878], [74.19430542, 14.73069572], [74.19403076, 14.73069572], [74.19403076, 14.73124886], [74.19374847, 14.73124027], [74.19374847, 14.73153019], [74.19347382, 14.73152733], [74.19347382, 14.73188972], [74.19346619, 14.73513985], [74.19291687, 14.73513985], [74.19291687, 14.73569584], [74.19264221, 14.73569107], [74.19264221, 14.73624992], [74.19235992, 14.73624992], [74.19235992, 14.7365303], [74.1920929, 14.7365303], [74.1920929, 14.73680973], [74.19180298, 14.73680592], [74.19180298, 14.73708439], [74.19152832, 14.73708153], [74.19152832, 14.73764038], [74.19126129, 14.73764038], [74.19126129, 14.73791981], [74.19097137, 14.73791599], [74.19097137, 14.73819447], [74.19069672, 14.73819447], [74.19069672, 14.73847198], [74.1904068, 14.73847198], [74.1904068, 14.73875046], [74.19013977, 14.73875046], [74.19013977, 14.73903275], [74.18985748, 14.73902798], [74.18985748, 14.73958397], [74.18958282, 14.73958397], [74.18958282, 14.73986244], [74.18930817, 14.73985958], [74.18930817, 14.74013996], [74.18902588, 14.74013996], [74.18902588, 14.74043179], [74.18875122, 14.74041557], [74.18875122, 14.74097157], [74.18846893, 14.74096966], [74.18846893, 14.74125004], [74.18818665, 14.74125004], [74.18818665, 14.74153137], [74.18791962, 14.74152756], [74.18791962, 14.74208355], [74.18763733, 14.74207973], [74.18763733, 14.74236012], [74.18708038, 14.74236012], [74.18708038, 14.74263954], [74.18653107, 14.74263954], [74.18653107, 14.74292088], [74.18605804, 14.74291897], [74.18597412, 14.74291611], [74.18597412, 14.74319363], [74.18575287, 14.74319363], [74.18541718, 14.74319363], [74.18541718, 14.74349976], [74.18541718, 14.74374962], [74.18514252, 14.74374962], [74.18514252, 14.74458218], [74.18486023, 14.74458027], [74.18486023, 14.7448597], [74.1845932, 14.7448597], [74.1845932, 14.74514103], [74.18430328, 14.74514103], [74.18430328, 14.74542141], [74.18402863, 14.74541569], [74.18402863, 14.74569511], [74.18374634, 14.74569511], [74.18374634, 14.74597263], [74.18347168, 14.74597263], [74.18347168, 14.74625111], [74.18319702, 14.74624062], [74.18319702, 14.74653053], [74.1829071, 14.74653053], [74.1829071, 14.74681091], [74.18264008, 14.74680424], [74.18264008, 14.74708462], [74.18235779, 14.74708462], [74.18235779, 14.74736118], [74.18206787, 14.74736118], [74.18206787, 14.74764061], [74.18180847, 14.74764061], [74.18180847, 14.74792099], [74.18152618, 14.74791718], [74.18152618, 14.74819469], [74.18125153, 14.74819469], [74.18125153, 14.74847317], [74.18068695, 14.74847031], [74.18068695, 14.74875069], [74.18041992, 14.74875069], [74.18041992, 14.74903107], [74.18013763, 14.74903107], [74.18013763, 14.74931145], [74.17958069, 14.74930477], [74.17958069, 14.74958324], [74.17930603, 14.74958324], [74.17932129, 14.74986076], [74.17624664, 14.74986076], [74.17624664, 14.74958038], [74.17569733, 14.74958038], [74.17569733, 14.75014114], [74.17542267, 14.75014114], [74.17542267, 14.75042057], [74.17514038, 14.75041676], [74.17514038, 14.75069523], [74.17485809, 14.75069046], [74.17485809, 14.75097084], [74.17457581, 14.75097084], [74.17458344, 14.75125122], [74.17318726, 14.75125122], [74.17263794, 14.75125122], [74.17263794, 14.75097084], [74.17180634, 14.75097084], [74.17180634, 14.75125122], [74.17151642, 14.75125122], [74.17151642, 14.75153065], [74.1709671, 14.75153065], [74.1709671, 14.75181198], [74.17069244, 14.75180531], [74.17069244, 14.75208282], [74.17041779, 14.75208092], [74.17041779, 14.75237179], [74.16819763, 14.75237179], [74.16819763, 14.75264072], [74.1673584, 14.75264072], [74.1673584, 14.7529192], [74.16668701, 14.7529192], [74.16374969, 14.75291729], [74.16374969, 14.75319481], [74.16347504, 14.75319481], [74.16347504, 14.75374889], [74.16374969, 14.75374889], [74.16374969, 14.75402927], [74.16403198, 14.75402927], [74.16403198, 14.75430965], [74.16430664, 14.75430489], [74.16430664, 14.75458336], [74.1645813, 14.75458145], [74.1645813, 14.75486088], [74.16486359, 14.75486088], [74.16486359, 14.75569534], [74.16513824, 14.75569534], [74.16513824, 14.75597095], [74.1654129, 14.75597095], [74.1654129, 14.75681019], [74.16513824, 14.75680542], [74.16513824, 14.75708294], [74.1654129, 14.75708103], [74.1654129, 14.75930977], [74.16513824, 14.75930977], [74.16513824, 14.76014042], [74.16486359, 14.7601366], [74.16486359, 14.76097202], [74.16513824, 14.76097202], [74.16513824, 14.76154137], [74.1654129, 14.76152802], [74.1654129, 14.76208401], [74.16570282, 14.76207924], [74.16570282, 14.76264], [74.16596985, 14.76264], [74.16596985, 14.76292038], [74.16625214, 14.76291561], [74.16625214, 14.76319408], [74.16708374, 14.76319408], [74.16708374, 14.7634716], [74.1673584, 14.7634716], [74.1673584, 14.76291561], [74.16791534, 14.76291561], [74.16791534, 14.76319408], [74.16819763, 14.76319408], [74.16819763, 14.7634716], [74.16847229, 14.7634716], [74.16847229, 14.76403046], [74.16874695, 14.76403046], [74.16874695, 14.76431274], [74.16847229, 14.76430607], [74.16847229, 14.76458359], [74.16819763, 14.76458359], [74.16819763, 14.76486206], [74.16792297, 14.76486015], [74.16792297, 14.76513958], [74.16764069, 14.76513958], [74.16764069, 14.76541996], [74.1673584, 14.76541805], [74.1673584, 14.76569366], [74.16709137, 14.7656889], [74.16709137, 14.76624966], [74.16680908, 14.76624966], [74.16680908, 14.76653004], [74.16625214, 14.76653004], [74.16625214, 14.76624966], [74.16570282, 14.76624966], [74.16570282, 14.76597023], [74.1654129, 14.76597214], [74.1654129, 14.76569366], [74.16513824, 14.76569366], [74.16513824, 14.76458359], [74.16486359, 14.76458359], [74.16486359, 14.76319408], [74.1645813, 14.76319408], [74.1645813, 14.76291561], [74.16430664, 14.76292038], [74.16430664, 14.76235962], [74.16402435, 14.76236153], [74.16402435, 14.76180553], [74.16374969, 14.7618103], [74.16374969, 14.76014042], [74.16403198, 14.76014042], [74.16403198, 14.75958061], [74.16374969, 14.75958443], [74.16374969, 14.75736141], [74.16402435, 14.75736141], [74.16402435, 14.75597095], [74.16374969, 14.75597095], [74.16374969, 14.75541687], [74.16347504, 14.75541687], [74.16347504, 14.75486088], [74.16319275, 14.75486088], [74.16319275, 14.75458145], [74.1626358, 14.75458145], [74.1626358, 14.75486088], [74.1598587, 14.75486088], [74.1598587, 14.75458145], [74.15958405, 14.75458336], [74.15958405, 14.75430489], [74.1590271, 14.75430965], [74.1590271, 14.75402927], [74.15875244, 14.75402927], [74.15875244, 14.7529192], [74.15847015, 14.7529192], [74.15847015, 14.75208092], [74.16013336, 14.75208282], [74.16041565, 14.75208282], [74.16041565, 14.75180531], [74.16014862, 14.75181198], [74.16014099, 14.75153065], [74.1598587, 14.75153065], [74.1598587, 14.75125122], [74.15957642, 14.75125122], [74.15957642, 14.75097084], [74.15930176, 14.75097084], [74.15930176, 14.75069046], [74.1590271, 14.75069523], [74.1590271, 14.75041676], [74.15875244, 14.75042057], [74.15875244, 14.74903107], [74.1590271, 14.74903107], [74.1590271, 14.74624062], [74.15875244, 14.74625111], [74.15875244, 14.74569511], [74.15791321, 14.74569511], [74.15791321, 14.74541569], [74.15735626, 14.74542141], [74.15735626, 14.74514103], [74.15680695, 14.74514103], [74.15680695, 14.74542141], [74.15597534, 14.74541569], [74.15597534, 14.74569511], [74.1554184, 14.74569511], [74.1554184, 14.74597263], [74.15319824, 14.74596977], [74.15319824, 14.74653053], [74.15291595, 14.74652863], [74.15291595, 14.74708462], [74.15208435, 14.74708462], [74.15208435, 14.74736118], [74.15180206, 14.74736118], [74.15180206, 14.74764061], [74.1515274, 14.74764061], [74.1515274, 14.74792099], [74.15097046, 14.74791718], [74.15097046, 14.74819469], [74.1506958, 14.74818993], [74.1506958, 14.74875069], [74.15097046, 14.74875069], [74.15097046, 14.74986076], [74.1506958, 14.74986076], [74.1506958, 14.75153065], [74.15097046, 14.75153065], [74.15097046, 14.75181198], [74.15125275, 14.75180531], [74.15125275, 14.75208282], [74.15097046, 14.75208092], [74.15097046, 14.75237179], [74.15125275, 14.75237179], [74.15125275, 14.7529192], [74.1515274, 14.75291729], [74.1515274, 14.75347328], [74.15180206, 14.75347137], [74.15180206, 14.75374889], [74.15209198, 14.75374889], [74.15209198, 14.75430965], [74.15235901, 14.75430965], [74.15235901, 14.75486088], [74.15291595, 14.75486088], [74.15291595, 14.75569534], [74.15319824, 14.75569534], [74.15319824, 14.75597095], [74.1534729, 14.75597095], [74.1534729, 14.75653172], [74.15402985, 14.75653172], [74.15402985, 14.75681019], [74.1543045, 14.75680542], [74.1543045, 14.75736141], [74.15458679, 14.75736141], [74.15458679, 14.75792027], [74.15486145, 14.75791836], [74.15486145, 14.75847054], [74.15597534, 14.75847054], [74.15597534, 14.75819302], [74.15652466, 14.75819302], [74.15652466, 14.75847054], [74.1570816, 14.75847054], [74.1570816, 14.75875187], [74.15736389, 14.75874901], [74.15736389, 14.7606926], [74.1570816, 14.76069069], [74.1570816, 14.76124954], [74.15680695, 14.76124954], [74.15680695, 14.7618103], [74.15652466, 14.76180553], [74.15652466, 14.76236153], [74.15625, 14.76235962], [74.15625, 14.76292038], [74.15597534, 14.76291561], [74.15597534, 14.76319408], [74.15569305, 14.76319408], [74.15569305, 14.7634716], [74.1554184, 14.7634716], [74.1554184, 14.76375198], [74.15515137, 14.76375198], [74.15515137, 14.76403046], [74.15486145, 14.76403046], [74.15486145, 14.76431274], [74.15458679, 14.76430607], [74.15458679, 14.76458359], [74.1543045, 14.76458359], [74.1543045, 14.76486206], [74.15402985, 14.76486015], [74.15402985, 14.76513958], [74.15374756, 14.76513958], [74.15374756, 14.76541996], [74.1534729, 14.76541805], [74.1534729, 14.76569366], [74.15319824, 14.76569366], [74.15319824, 14.76597214], [74.15291595, 14.76597023], [74.15291595, 14.76624966], [74.1526413, 14.76624966], [74.1526413, 14.76653004], [74.15235901, 14.76653004], [74.15235901, 14.76681137], [74.15208435, 14.76680565], [74.15208435, 14.76708412], [74.15180206, 14.76708412], [74.15180206, 14.76735973], [74.1515274, 14.76735115], [74.1515274, 14.76764011], [74.15125275, 14.76764011], [74.15125275, 14.76792145], [74.15097046, 14.76791573], [74.15097046, 14.7681942], [74.1506958, 14.7681942], [74.1506958, 14.76847172], [74.15040588, 14.76847172], [74.15040588, 14.76903057], [74.15013885, 14.76903057], [74.15013885, 14.76931095], [74.1498642, 14.76930618], [74.1498642, 14.7695837], [74.14958191, 14.7695837], [74.14958191, 14.76986027], [74.14930725, 14.76986027], [74.14930725, 14.77014065], [74.14902496, 14.77013779], [74.14902496, 14.77041626], [74.14875031, 14.77041626], [74.14875031, 14.77069378], [74.14847565, 14.77069378], [74.14847565, 14.77097225], [74.14819336, 14.77097034], [74.14819336, 14.77124977], [74.1479187, 14.77124977], [74.1479187, 14.77153111], [74.14763641, 14.77153111], [74.14763641, 14.77181053], [74.14736176, 14.77180672], [74.14736176, 14.77208233], [74.1470871, 14.77208233], [74.1470871, 14.77235985], [74.14679718, 14.77235985], [74.14679718, 14.77292061], [74.14653015, 14.77291584], [74.14653015, 14.77319527], [74.14624786, 14.77318954], [74.14624786, 14.77347946], [74.14569092, 14.77347279], [74.14569092, 14.77378941], [74.14569092, 14.77431107], [74.14541626, 14.77430439], [74.14541626, 14.77486134], [74.1451416, 14.77486134], [74.1451416, 14.77514076], [74.14485931, 14.77514076], [74.14485931, 14.77542114], [74.14458466, 14.77541733], [74.14458466, 14.77597332], [74.14402771, 14.77597141], [74.14402771, 14.7768116], [74.14375305, 14.77680683], [74.14375305, 14.7770834], [74.14319611, 14.7770834], [74.14319611, 14.77736092], [74.14292145, 14.77736092], [74.14292145, 14.77792072], [74.1423645, 14.77791691], [74.1423645, 14.77819538], [74.14180756, 14.77819538], [74.14180756, 14.7784729], [74.1415329, 14.77847099], [74.1415329, 14.77902889], [74.14097595, 14.77902889], [74.14097595, 14.77930927], [74.14041901, 14.77930546], [74.14041901, 14.77958298], [74.14015198, 14.77958107], [74.14015198, 14.78014088], [74.13957977, 14.78014088], [74.13957977, 14.78041935], [74.13874817, 14.78041744], [74.13874817, 14.78069305], [74.13847351, 14.78069305], [74.13847351, 14.78041744], [74.13791656, 14.78041935], [74.13791656, 14.78014088], [74.13764191, 14.78014088], [74.13764191, 14.77986145], [74.13735962, 14.77986145], [74.13735962, 14.77958298], [74.13708496, 14.77958298], [74.13708496, 14.77930546], [74.13678741, 14.77930927], [74.13678741, 14.77875137], [74.13652802, 14.77875137], [74.13652802, 14.77847099], [74.13597107, 14.7784729], [74.13597107, 14.77819538], [74.13569641, 14.77819538], [74.13569641, 14.77791691], [74.13540649, 14.77792072], [74.13540649, 14.7776413], [74.13458252, 14.7776413], [74.13458252, 14.77792072], [74.13402557, 14.77791691], [74.13402557, 14.7784729], [74.13375092, 14.77847099], [74.13375092, 14.77902889], [74.13346863, 14.77902699], [74.13346863, 14.77958298], [74.13319397, 14.77958298], [74.13319397, 14.77986145], [74.13263702, 14.77986145], [74.13263702, 14.78014088], [74.13236237, 14.78014088], [74.13236237, 14.78041935], [74.12821198, 14.78041935], [74.12821198, 14.78014088], [74.12763977, 14.78014088], [74.12763977, 14.77958107], [74.12735748, 14.77958298], [74.12735748, 14.77930546], [74.12708282, 14.77930927], [74.12708282, 14.77902889], [74.1268692, 14.77902889], [74.12652588, 14.77902889], [74.12652588, 14.77847099], [74.12625122, 14.7784729], [74.12625122, 14.77791691], [74.12596893, 14.77792072], [74.12596893, 14.7776413], [74.12568665, 14.7776413], [74.12568665, 14.7768116], [74.12541962, 14.7768116], [74.12541962, 14.77654266], [74.12568665, 14.77654266], [74.12568665, 14.77625084], [74.12541962, 14.77625084], [74.12541962, 14.77597141], [74.12569427, 14.77597332], [74.12569427, 14.77486134], [74.12541962, 14.77486134], [74.12541962, 14.77458477], [74.12180328, 14.77458286], [74.12180328, 14.77430439], [74.12152863, 14.77430439], [74.12152863, 14.77458286], [74.12014008, 14.77458477], [74.12014008, 14.77486134], [74.11904144, 14.77486134], [74.11904144, 14.77542114], [74.11875153, 14.77541733], [74.11875153, 14.77569485], [74.11902618, 14.77569485], [74.11902618, 14.77597332], [74.11875153, 14.77597141], [74.11875153, 14.77625084], [74.11904144, 14.77625084], [74.11904144, 14.77654266], [74.11875153, 14.77654266], [74.11875153, 14.77792072], [74.11902618, 14.77791691], [74.11902618, 14.77819538], [74.11958313, 14.77819538], [74.11958313, 14.7784729], [74.12014008, 14.77847099], [74.12014008, 14.77902889], [74.12041473, 14.77902699], [74.12041473, 14.77958298], [74.12097168, 14.77958107], [74.12097168, 14.78014088], [74.12124634, 14.78013897], [74.12124634, 14.78069305], [74.12152863, 14.78069115], [74.12152863, 14.78152943], [74.12124634, 14.78155041], [74.12124634, 14.78181171], [74.12097168, 14.78180504], [74.12097168, 14.78236103], [74.12069702, 14.78234959], [74.12069702, 14.78292179], [74.12041473, 14.78291702], [74.12041473, 14.78347111], [74.12014008, 14.78347111], [74.12014008, 14.78375244], [74.11985779, 14.78375244], [74.11985779, 14.78431034], [74.11958313, 14.78430462], [74.11958313, 14.78486061], [74.11930847, 14.78486061], [74.11930847, 14.78542042], [74.11902618, 14.78541756], [74.11902618, 14.78597355], [74.11875153, 14.78597069], [74.11875153, 14.78625202], [74.11846924, 14.78625202], [74.11846924, 14.78652954], [74.11818695, 14.78652954], [74.11818695, 14.78680992], [74.11763763, 14.78680611], [74.11763763, 14.78708363], [74.11736298, 14.78708363], [74.11736298, 14.7873621], [74.11708069, 14.78735924], [74.11708069, 14.78763962], [74.11680603, 14.78763962], [74.11680603, 14.78792], [74.11653137, 14.78791809], [74.11653137, 14.7881937], [74.11597443, 14.7881937], [74.11597443, 14.78791809], [74.1149826, 14.78792], [74.11458588, 14.78792], [74.11458588, 14.78763962], [74.11402893, 14.78763962], [74.11402893, 14.78707886], [74.11374664, 14.78708363], [74.11374664, 14.78652668], [74.11319733, 14.78652954], [74.11319733, 14.78625202], [74.11290741, 14.78625202], [74.11290741, 14.78597069], [74.11235809, 14.78597355], [74.11235809, 14.78569317], [74.11208344, 14.78569317], [74.11208344, 14.78486061], [74.11096954, 14.78486061], [74.11096954, 14.78458309], [74.11013794, 14.78458309], [74.11013794, 14.78486061], [74.10984802, 14.78486061], [74.10984802, 14.78514194], [74.10958099, 14.78514004], [74.10958099, 14.78708363], [74.10986328, 14.78708363], [74.10986328, 14.7881937], [74.11013794, 14.78819084], [74.11013794, 14.78903008], [74.11042023, 14.78903008], [74.11042023, 14.78985977], [74.11013794, 14.78985977], [74.11013794, 14.79041958], [74.10986328, 14.79041576], [74.10986328, 14.79069424], [74.10958099, 14.79069424], [74.10958099, 14.79097176], [74.10930634, 14.79097176], [74.10930634, 14.79143047], [74.10930634, 14.79181099], [74.10902405, 14.79180622], [74.10902405, 14.79319382], [74.10847473, 14.79319382], [74.10847473, 14.79347229], [74.10736084, 14.79347229], [74.10736084, 14.79319382], [74.10652924, 14.79319382], [74.10652924, 14.7929163], [74.10597229, 14.79292011], [74.10597229, 14.79263973], [74.10549927, 14.79263973], [74.1048584, 14.79263973], [74.1048584, 14.79236031], [74.10346985, 14.79236031], [74.10346985, 14.79263973], [74.10320282, 14.79263973], [74.10320282, 14.79236031], [74.1029129, 14.79236031], [74.1029129, 14.79263973], [74.1020813, 14.79263973], [74.1020813, 14.79292011], [74.10180664, 14.7929163], [74.10180664, 14.79347229], [74.1020813, 14.79347038], [74.1020813, 14.79375172], [74.1029129, 14.79375172], [74.1029129, 14.79403019], [74.10263824, 14.79402828], [74.10263824, 14.79419041], [74.10263824, 14.79458427], [74.10235596, 14.79458046], [74.10235596, 14.79514027], [74.1020813, 14.79514027], [74.1020813, 14.79542065], [74.10180664, 14.79541588], [74.10180664, 14.79569435], [74.10152435, 14.79569435], [74.10152435, 14.79597187], [74.10124969, 14.79596996], [74.10124969, 14.79625034], [74.10096741, 14.79625034], [74.10096741, 14.79653072], [74.10069275, 14.79652786], [74.10069275, 14.79736328], [74.10041809, 14.79736042], [74.10041809, 14.79764271], [74.1001358, 14.79763794], [74.1001358, 14.79819393], [74.09986115, 14.79819393], [74.09986115, 14.7984724], [74.09958649, 14.7984724], [74.09958649, 14.79819393], [74.0993042, 14.79819393], [74.0993042, 14.7984724], [74.09874725, 14.79846954], [74.09874725, 14.79875088], [74.09707642, 14.79875088], [74.09707642, 14.79846954], [74.0965271, 14.79846954], [74.0965271, 14.79875088], [74.09541321, 14.79875088], [74.09541321, 14.79931068], [74.09513855, 14.79931068], [74.09513855, 14.79986], [74.09487152, 14.79986], [74.09487152, 14.80014133], [74.0945816, 14.80014133], [74.0945816, 14.80042076], [74.09430695, 14.80041695], [74.09430695, 14.80097294], [74.09401703, 14.80097008], [74.09401703, 14.80125141], [74.09375, 14.80125141], [74.09375, 14.80153084], [74.09347534, 14.80152893], [74.09347534, 14.80236053], [74.09319305, 14.80236053], [74.09319305, 14.80264091], [74.0929184, 14.80263901], [74.0929184, 14.803195], [74.09263611, 14.80319023], [74.09263611, 14.80403137], [74.0929184, 14.80403137], [74.0929184, 14.80514145], [74.09319305, 14.80514145], [74.09319305, 14.80542183], [74.09347534, 14.80541706], [74.09347534, 14.80597305], [74.09401703, 14.80597115], [74.09401703, 14.80625057], [74.0945816, 14.80624866], [74.0945816, 14.80652905], [74.09625244, 14.80652046], [74.09625244, 14.80681038], [74.09680176, 14.80681038], [74.09680176, 14.80652046], [74.09764099, 14.80652046], [74.09764099, 14.80681038], [74.09986115, 14.80680466], [74.09986115, 14.80708313], [74.1001358, 14.80708313], [74.1001358, 14.80680466], [74.10041809, 14.80680466], [74.10041809, 14.80708313], [74.10151672, 14.80708122], [74.10151672, 14.80736065], [74.1020813, 14.80736065], [74.1020813, 14.80708122], [74.10236359, 14.80708313], [74.10236359, 14.80680466], [74.10263824, 14.80681038], [74.10263824, 14.80652046], [74.1029129, 14.80652905], [74.1029129, 14.80597305], [74.10346985, 14.80597305], [74.10346985, 14.80569458], [74.10430908, 14.80569458], [74.10430908, 14.80541706], [74.10458374, 14.80541706], [74.10458374, 14.80569458], [74.10514069, 14.80569458], [74.10514069, 14.80597305], [74.10542297, 14.80597115], [74.10542297, 14.80625057], [74.10624695, 14.80625057], [74.10624695, 14.80681038], [74.10791779, 14.80680466], [74.10791779, 14.80708313], [74.10847473, 14.80708313], [74.10847473, 14.80652905], [74.10930634, 14.80652905], [74.10930634, 14.80624866], [74.10984802, 14.80625057], [74.10984802, 14.80597115], [74.11042023, 14.80597305], [74.11042023, 14.80569458], [74.11069489, 14.80569458], [74.11069489, 14.80541706], [74.11208344, 14.80541706], [74.11208344, 14.80597305], [74.11235809, 14.80597115], [74.11235809, 14.80736065], [74.11264038, 14.80736065], [74.11264038, 14.80764103], [74.11319733, 14.80764103], [74.11319733, 14.80652046], [74.11347198, 14.80652905], [74.11347198, 14.80513859], [74.11402893, 14.80514145], [74.11402893, 14.80458069], [74.11430359, 14.8045826], [74.11430359, 14.80430698], [74.11458588, 14.80431175], [74.11458588, 14.80208015], [74.11402893, 14.80208302], [74.11402893, 14.80125141], [74.11374664, 14.80125141], [74.11374664, 14.80097008], [74.11347198, 14.80097294], [74.11347198, 14.80069542], [74.11319733, 14.80069542], [74.11319733, 14.80041695], [74.11290741, 14.80042076], [74.11290741, 14.80014133], [74.11264038, 14.80014133], [74.11264038, 14.79993057], [74.11264038, 14.79958153], [74.11235809, 14.79958153], [74.11235809, 14.79930687], [74.11207581, 14.79931068], [74.11207581, 14.79903126], [74.11152649, 14.79903126], [74.11152649, 14.79875088], [74.11125183, 14.79875088], [74.11125183, 14.79846954], [74.11096954, 14.7984724], [74.11096954, 14.79819393], [74.11125183, 14.79819393], [74.11125183, 14.79763794], [74.11152649, 14.79764271], [74.11152649, 14.79708004], [74.11180878, 14.79708195], [74.11180878, 14.79680634], [74.11347198, 14.7968111], [74.11347198, 14.79792118], [74.11291504, 14.79791641], [74.11291504, 14.7984724], [74.11319733, 14.79846954], [74.11319733, 14.79903126], [74.11347198, 14.79903126], [74.11347198, 14.79931068], [74.11374664, 14.79930687], [74.11374664, 14.79958153], [74.11402893, 14.79957962], [74.11402893, 14.79986], [74.11429596, 14.79986], [74.11429596, 14.80014133], [74.11458588, 14.80014133], [74.11458588, 14.80042076], [74.11486053, 14.80041695], [74.11486053, 14.80069542], [74.11513519, 14.80069542], [74.11513519, 14.80097294], [74.11541748, 14.80097008], [74.11541748, 14.80125141], [74.11569214, 14.80125141], [74.11569214, 14.80153084], [74.11597443, 14.80152893], [74.11597443, 14.80208302], [74.11624908, 14.80208302], [74.11624908, 14.80236053], [74.11736298, 14.80236053], [74.11736298, 14.80208302], [74.11763763, 14.80208302], [74.11763763, 14.80180454], [74.11846924, 14.80181122], [74.11846924, 14.80153084], [74.12014008, 14.80153084], [74.12014008, 14.80181122], [74.12041473, 14.80180454], [74.12041473, 14.80208302], [74.12097168, 14.80208302], [74.12097168, 14.80236053], [74.12124634, 14.80236053], [74.12124634, 14.80264091], [74.12152863, 14.80263901], [74.12152863, 14.803195], [74.12178802, 14.80319023], [74.12178802, 14.80375099], [74.12207794, 14.80375099], [74.12207794, 14.80431175], [74.12236023, 14.80430698], [74.12236023, 14.8045826], [74.12264252, 14.80458069], [74.12264252, 14.80486107], [74.12346649, 14.80486107], [74.12346649, 14.80542183], [74.12374878, 14.80541706], [74.12374878, 14.80569458], [74.12403107, 14.8056879], [74.12403107, 14.80625057], [74.12430573, 14.80624866], [74.12430573, 14.80652905], [74.12458038, 14.80652046], [74.12458038, 14.80764103], [74.12431335, 14.80764103], [74.12431335, 14.80791855], [74.12458038, 14.80791664], [74.12458038, 14.80819511], [74.12431335, 14.8081913], [74.12431335, 14.80931187], [74.12458038, 14.80930519], [74.12458038, 14.80986118], [74.12486267, 14.80986118], [74.12486267, 14.81097126], [74.12541962, 14.81097126], [74.12541962, 14.81180954], [74.12568665, 14.81180954], [74.12568665, 14.81374931], [74.12596893, 14.81374931], [74.12596893, 14.81597233], [74.12625122, 14.81597233], [74.12625122, 14.81986237], [74.12596893, 14.81986046], [74.12596893, 14.82459068], [74.12568665, 14.82459068], [74.12568665, 14.82514095], [74.12541962, 14.82513809], [74.12541962, 14.82569408], [74.12513733, 14.82569027], [74.12513733, 14.82625103], [74.12541962, 14.82625103], [74.12541962, 14.82681084], [74.12569427, 14.82680416], [74.12569427, 14.82736015], [74.12541962, 14.82736015], [74.12541962, 14.82819462], [74.12513733, 14.82818985], [74.12513733, 14.82931137], [74.12484741, 14.82931137], [74.12484741, 14.8318119], [74.12458038, 14.83180523], [74.12458038, 14.83736134], [74.12541962, 14.83736134], [74.12541962, 14.83749104], [74.12541962, 14.83764172], [74.12568665, 14.83764172], [74.12568665, 14.83792019], [74.12596893, 14.83791733], [74.12596893, 14.8381958], [74.12625122, 14.8381958], [74.12625122, 14.83847141], [74.12652588, 14.83847141], [74.12652588, 14.83903027], [74.12680817, 14.83903027], [74.12680817, 14.83930969], [74.12708282, 14.83930969], [74.12708282, 14.83959007], [74.12735748, 14.83959007], [74.12735748, 14.83986187], [74.12792206, 14.83986187], [74.12792206, 14.84014034], [74.1295929, 14.84014034], [74.1295929, 14.83986187], [74.13041687, 14.83986187], [74.13041687, 14.84015083], [74.13041687, 14.8423624], [74.13069153, 14.8423624], [74.13069153, 14.8444109], [74.13069153, 14.84458447], [74.13091278, 14.8445816], [74.13098145, 14.84624958], [74.12821198, 14.84624958], [74.12821198, 14.84652996], [74.12792206, 14.84652996], [74.12792206, 14.84681129], [74.12763977, 14.84680557], [74.12763977, 14.84708405], [74.12569427, 14.84708405], [74.12569427, 14.84736156], [74.12458038, 14.84735966], [74.12458038, 14.84764004], [74.12431335, 14.84764004], [74.12431335, 14.84792137], [74.12374878, 14.84791565], [74.12374878, 14.84819412], [74.12347412, 14.84819412], [74.12347412, 14.84847164], [74.12291718, 14.84846973], [74.12291718, 14.84876156], [74.12264252, 14.84876156], [74.12264252, 14.84903145], [74.12236023, 14.84903145], [74.12236023, 14.84931087], [74.12180328, 14.84930611], [74.12180328, 14.84958363], [74.12124634, 14.84958363], [74.12124634, 14.84986019], [74.12097168, 14.84986019], [74.12097168, 14.85013962], [74.11985779, 14.85013962], [74.11985779, 14.85042095], [74.11930847, 14.85041618], [74.11930847, 14.8506937], [74.11875153, 14.8506937], [74.11875153, 14.85097218], [74.11818695, 14.85097027], [74.11818695, 14.85124969], [74.11763763, 14.85124969], [74.11763763, 14.85153103], [74.11715698, 14.85152817], [74.11708069, 14.85152817], [74.11708069, 14.85181999], [74.11653137, 14.85180664], [74.11653137, 14.85208225], [74.11597443, 14.85208225], [74.11598206, 14.85235977], [74.11541748, 14.85235977], [74.11541748, 14.85264111], [74.11486053, 14.85264111], [74.11486053, 14.85292053], [74.11458588, 14.85291576], [74.11458588, 14.85319424], [74.11402893, 14.85319424], [74.11402893, 14.85291576], [74.11429596, 14.85292053], [74.11429596, 14.85264111], [74.11402893, 14.85264111], [74.11402893, 14.85235977], [74.11429596, 14.85235977], [74.11429596, 14.85208035], [74.11458588, 14.85208225], [74.11458588, 14.85180664], [74.11486053, 14.85181999], [74.11486053, 14.85153103], [74.11541748, 14.85153103], [74.11541748, 14.85124969], [74.11569214, 14.85124969], [74.11569214, 14.85097027], [74.11597443, 14.85097218], [74.11597443, 14.8506937], [74.11624908, 14.8506937], [74.11624908, 14.85041618], [74.11680603, 14.85042095], [74.11680603, 14.85013962], [74.11708069, 14.85013962], [74.11708069, 14.84986019], [74.11763763, 14.84986019], [74.11763763, 14.84976196], [74.11763763, 14.84958363], [74.11791992, 14.84958363], [74.11791992, 14.84930611], [74.11846924, 14.84931087], [74.11846924, 14.84903145], [74.11875153, 14.84903145], [74.11875153, 14.84876156], [74.11904144, 14.84876156], [74.11904144, 14.84846973], [74.11958313, 14.84847164], [74.11958313, 14.84819412], [74.12014008, 14.84819412], [74.12014008, 14.84791565], [74.12069702, 14.84792137], [74.12069702, 14.84764004], [74.12178802, 14.84764004], [74.12178802, 14.84735966], [74.12236023, 14.84735966], [74.12236023, 14.84708023], [74.12319183, 14.84708405], [74.12319183, 14.84680557], [74.12374878, 14.84681129], [74.12374878, 14.84652996], [74.12431335, 14.84652996], [74.12431335, 14.84624958], [74.12484741, 14.84624958], [74.12484741, 14.84597015], [74.12458038, 14.84597206], [74.12458038, 14.8451376], [74.12403107, 14.84514046], [74.12403107, 14.84486198], [74.12291718, 14.84486198], [74.12291718, 14.8445816], [74.12264252, 14.84458447], [74.12264252, 14.84430599], [74.12207794, 14.84430981], [74.12207794, 14.84403038], [74.1204071, 14.84403038], [74.1204071, 14.84375191], [74.11923981, 14.84375191], [74.11680603, 14.84375191], [74.11680603, 14.84403038], [74.11624908, 14.84403038], [74.11624908, 14.84430981], [74.11541748, 14.84430599], [74.11541748, 14.84458447], [74.11486053, 14.8445816], [74.11486053, 14.84486198], [74.11402893, 14.84486198], [74.11402893, 14.84514046], [74.11347198, 14.84514046], [74.11347198, 14.84542274], [74.11319733, 14.84541798], [74.11319733, 14.84569359], [74.11291504, 14.84569359], [74.11291504, 14.84597206], [74.11264038, 14.84597015], [74.11264038, 14.84652996], [74.11235809, 14.84652996], [74.11235809, 14.84681129], [74.11207581, 14.84681129], [74.11207581, 14.84764004], [74.11180878, 14.84764004], [74.11180878, 14.84876156], [74.11152649, 14.84876156], [74.11152649, 14.85181999], [74.11180878, 14.85180664], [74.11180878, 14.85597324], [74.11152649, 14.85597038], [74.11152649, 14.8587513], [74.11125183, 14.8587513], [74.11125183, 14.8595829], [74.11096954, 14.85958099], [74.11096954, 14.86041927], [74.11068726, 14.86041927], [74.11068726, 14.86125088], [74.11042023, 14.86125088], [74.11042023, 14.86180973], [74.11013794, 14.86180973], [74.11013794, 14.86264229], [74.10986328, 14.86263943], [74.10986328, 14.86347103], [74.10958099, 14.86347103], [74.10958099, 14.86403179], [74.10930634, 14.86402702], [74.10930634, 14.86458302], [74.10901642, 14.86458111], [74.10901642, 14.86514187], [74.10874939, 14.86513901], [74.10874939, 14.86569309], [74.1084671, 14.86569118], [74.1084671, 14.86653042], [74.10819244, 14.86653042], [74.10819244, 14.86736202], [74.10791779, 14.86736202], [74.10791779, 14.86819267], [74.10764313, 14.86818886], [74.10764313, 14.86903], [74.10736084, 14.86903], [74.10736084, 14.8698597], [74.10708618, 14.8698616], [74.10708618, 14.87069416], [74.10680389, 14.87069416], [74.10681152, 14.87125015], [74.10652924, 14.87125015], [74.10652924, 14.87152958], [74.10624695, 14.87152958], [74.10624695, 14.87180996], [74.10597229, 14.87180614], [74.10597229, 14.87236214], [74.10569763, 14.87236023], [74.10569763, 14.87263966], [74.10542297, 14.87263966], [74.10542297, 14.87292957], [74.10514069, 14.87291622], [74.10514069, 14.87319374], [74.1048584, 14.87319374], [74.1048584, 14.87347221], [74.10457611, 14.87347031], [74.10457611, 14.87403011], [74.10430908, 14.87403011], [74.10430908, 14.87431145], [74.10404205, 14.87431145], [74.10404205, 14.87542057], [74.10375214, 14.87542057], [74.10375214, 14.87681103], [74.10346985, 14.87680626], [74.10346985, 14.87708378], [74.10319519, 14.87708378], [74.10319519, 14.87736034], [74.1029129, 14.87736034], [74.1029129, 14.87764072], [74.10263824, 14.87764072], [74.10263824, 14.8779211], [74.10236359, 14.87791634], [74.10236359, 14.87819386], [74.1020813, 14.87819386], [74.1020813, 14.87847233], [74.10180664, 14.87847233], [74.10180664, 14.87874985], [74.10151672, 14.87874126], [74.10151672, 14.87903118], [74.10124969, 14.87903118], [74.10124969, 14.87931061], [74.10069275, 14.87930679], [74.10069275, 14.87958241], [74.10041809, 14.87957954], [74.10041809, 14.87985992], [74.1001358, 14.87985992], [74.1001358, 14.88014126], [74.09958649, 14.88014126], [74.09958649, 14.88042068], [74.09929657, 14.88042068], [74.09929657, 14.88125134], [74.09958649, 14.88125134], [74.09958649, 14.88236141], [74.09986115, 14.88236141], [74.09986115, 14.88319492], [74.1001358, 14.88319492], [74.1001358, 14.88708305], [74.10041809, 14.88708305], [74.10041809, 14.89097118], [74.1001358, 14.89097118], [74.1001358, 14.89153194], [74.09986115, 14.89152718], [74.09986115, 14.89186001], [74.09986115, 14.89208317], [74.09958649, 14.89208126], [74.09958649, 14.89264202], [74.0993042, 14.89263916], [74.0993042, 14.89319324], [74.09902954, 14.89319324], [74.09902954, 14.89374924], [74.09874725, 14.8937397], [74.09874725, 14.89431], [74.0984726, 14.89430618], [74.0984726, 14.89486217], [74.09790802, 14.89485931], [74.09790802, 14.89513969], [74.09764099, 14.89513969], [74.09764099, 14.89542007], [74.0973587, 14.89541531], [74.0973587, 14.89565945], [74.10331726, 14.90147972], [74.10417175, 14.90375042], [74.11308289, 14.91116047], [74.11733246, 14.9096117], [74.1227417, 14.91264057], [74.12652588, 14.91321087], [74.13204193, 14.91265011], [74.13342285, 14.91594791], [74.13622284, 14.91966057], [74.13939667, 14.9204607], [74.14570618, 14.91743183], [74.14922333, 14.91852093], [74.15389252, 14.91726971], [74.16339111, 14.91325188], [74.16982269, 14.90927029], [74.17539215, 14.90891933], [74.17735291, 14.91320038], [74.17516327, 14.91615105], [74.17383575, 14.91794014], [74.16596222, 14.9367609], [74.16609955, 14.93944168], [74.16966248, 14.94218063], [74.16989899, 14.94729996], [74.17215729, 14.95100975], [74.18036652, 14.95304966], [74.18656158, 14.95338058], [74.1902771, 14.95171928], [74.19248199, 14.94500923], [74.19741821, 14.94326973], [74.2041626, 14.93785095], [74.20405579, 14.9321003], [74.20308685, 14.92742062], [74.21183777, 14.9214201], [74.2192688, 14.93138027], [74.22471619, 14.94134045], [74.24167633, 14.94645023], [74.24386597, 14.95748997], [74.24639893, 14.95866108], [74.25100708, 14.9608202], [74.25659943, 14.95842171], [74.2620697, 14.95755196], [74.26434326, 14.96324921], [74.2665863, 14.96682072], [74.27011871, 14.96664143], [74.27095032, 14.97153187], [74.27391052, 14.97522163], [74.27095795, 14.98042965], [74.26171112, 14.9907608], [74.26644135, 14.99295139], [74.27065277, 14.99489117], [74.27159119, 14.9977417], [74.27126312, 14.9977417], [74.27102661, 14.99880791], [74.27291107, 15.00146103], [74.27184296, 15.00249195], [74.27641296, 15.00964069], [74.28186035, 15.01557159], [74.28978729, 15.02161121], [74.28936768, 15.02656174], [74.2890625, 15.0301218], [74.29310608, 15.03374958], [74.30233765, 15.03985977], [74.30120087, 15.04407024], [74.29499054, 15.05429173], [74.29525757, 15.06269264], [74.28900909, 15.0658493], [74.28721619, 15.06936073], [74.28379059, 15.09401035], [74.2783432, 15.09589958], [74.28106689, 15.10182953], [74.28572845, 15.10373116], [74.28824615, 15.10558128], [74.2906189, 15.11663055], [74.29309082, 15.11996269], [74.29144287, 15.12329865], [74.289711, 15.1299696], [74.29122925, 15.13538074], [74.28956604, 15.1431303], [74.29258728, 15.14767933], [74.29782867, 15.14630985], [74.30142975, 15.14988136], [74.31086731, 15.16203117], [74.31813049, 15.17533016], [74.32190704, 15.18406963], [74.31697083, 15.1910696], [74.31577301, 15.19631195], [74.31555939, 15.20321274], [74.31445313, 15.20561028], [74.31163025, 15.20705128], [74.31066132, 15.20895195], [74.31005859, 15.2134304], [74.30670929, 15.21899986], [74.3066864, 15.2232008], [74.30213165, 15.22814178], [74.29427338, 15.23198032], [74.27867126, 15.23719025], [74.27075195, 15.2385006], [74.26351929, 15.24188137], [74.26174927, 15.24372196], [74.25926208, 15.24999046], [74.25752258, 15.25762939], [74.26793671, 15.25839138], [74.27024078, 15.26093197], [74.27275085, 15.26777172], [74.27661896, 15.27444935], [74.28295898, 15.28129959], [74.28914642, 15.27907181], [74.29554749, 15.28310966], [74.30002594, 15.28230095], [74.30230713, 15.28586102], [74.30980682, 15.28323078], [74.31841278, 15.28192043], [74.33412933, 15.28286171], [74.34165192, 15.2929306], [74.34044647, 15.29680061], [74.32797241, 15.31326962], [74.32334137, 15.3295908], [74.32840729, 15.3434], [74.32595062, 15.34724045], [74.32261658, 15.35725021], [74.32364655, 15.36203194], [74.32859802, 15.36547089], [74.32836914, 15.3672514], [74.31282806, 15.37488174], [74.30568695, 15.38050175], [74.28996277, 15.38121986], [74.28624725, 15.38260078], [74.28263855, 15.38862038], [74.2845459, 15.40151119], [74.28144836, 15.4090414], [74.27735901, 15.41486931], [74.27561951, 15.4239006], [74.2826767, 15.43329144], [74.27999878, 15.43593121], [74.28295898, 15.43748093], [74.28251648, 15.44312096], [74.2798996, 15.45076084], [74.27255249, 15.46523952], [74.2563324, 15.48952007], [74.25724792, 15.49676132], [74.26082611, 15.50084114], [74.2681427, 15.50592136], [74.2818985, 15.51295185], [74.28375244, 15.51945019], [74.28279877, 15.52054119], [74.28727722, 15.52600002], [74.28559875, 15.5341711], [74.28292847, 15.54157066], [74.27894592, 15.54870033], [74.27258301, 15.55426121], [74.26988983, 15.56115055], [74.26763916, 15.56343937], [74.26457977, 15.56079102], [74.25431061, 15.56583023], [74.25441742, 15.57250118], [74.25741577, 15.57549953], [74.25637054, 15.58256054], [74.26515961, 15.59016037], [74.26545715, 15.60160065], [74.26854706, 15.60958862], [74.26747131, 15.61704922], [74.26249695, 15.62291145], [74.25942993, 15.62446117], [74.25435638, 15.62313175], [74.25253296, 15.6238203], [74.2545166, 15.62961197], [74.25723267, 15.63393974], [74.25647736, 15.64680099], [74.25525665, 15.65421009], [74.24504089, 15.66563129], [74.24191284, 15.66585922], [74.23683929, 15.66189098], [74.23158264, 15.66652012], [74.22405243, 15.6588707], [74.2284317, 15.65445042], [74.22879791, 15.65296078], [74.22409058, 15.65031147], [74.21324921, 15.64902973], [74.20986176, 15.65413094], [74.21196747, 15.65849972], [74.21154022, 15.66097927], [74.19632721, 15.66491127], [74.19447327, 15.67214012], [74.19811249, 15.67365074], [74.19769287, 15.67893028], [74.19013214, 15.68098068], [74.18302917, 15.67735004], [74.17867279, 15.6714201], [74.17543793, 15.67016029], [74.1734314, 15.65205193], [74.16593933, 15.65237999], [74.1632309, 15.64859009], [74.15497589, 15.64977074], [74.14685059, 15.64866066], [74.14277649, 15.64711094], [74.12896729, 15.65023994], [74.12602997, 15.65028954], [74.12136841, 15.65367031], [74.11205292, 15.6550312], [74.10453033, 15.65920162], [74.09802246, 15.6659708], [74.0965271, 15.6708498], [74.10056305, 15.67234993], [74.10624695, 15.67064095], [74.11752319, 15.67078018], [74.12700653, 15.67374039], [74.13359833, 15.67840099], [74.13887787, 15.68622971], [74.14042664, 15.69456005], [74.13889313, 15.69903183], [74.1415329, 15.70036125], [74.13891602, 15.70634079], [74.13553619, 15.70925236], [74.13475037, 15.71603203], [74.13062286, 15.71792126], [74.13485718, 15.72218132], [74.14045715, 15.7216711], [74.14186859, 15.72317886], [74.14296722, 15.72719097], [74.14737701, 15.73007107], [74.1505127, 15.7317009], [74.1553421, 15.73228168], [74.16013336, 15.73434925], [74.16226959, 15.74207115], [74.1676712, 15.74925041], [74.17115021, 15.74995041], [74.19706726, 15.75022125], [74.20439911, 15.7534008], [74.2113266, 15.75858974], [74.2146225, 15.76599121], [74.21570587, 15.77387047], [74.21740723, 15.77876091], [74.22247314, 15.78170109], [74.22734833, 15.78567123], [74.23549652, 15.7868309], [74.23892975, 15.78454018], [74.24034119, 15.78075027], [74.23516846, 15.75961113], [74.23523712, 15.75397015], [74.23898315, 15.75214005], [74.24386597, 15.74440002], [74.25006866, 15.74118042], [74.25892639, 15.74339104], [74.2660675, 15.74702072], [74.27086639, 15.75191021], [74.2740097, 15.75312042], [74.28494263, 15.74331093], [74.29216766, 15.73931122], [74.31299591, 15.7482996], [74.31465149, 15.75214863], [74.31864929, 15.75341034], [74.32408142, 15.75652981], [74.32495117, 15.76130009], [74.32756805, 15.76820087], [74.32975006, 15.77038002], [74.33454132, 15.76767921], [74.34227753, 15.76552105], [74.34677124, 15.76311016], [74.35093689, 15.76336002], [74.36485291, 15.77365112], [74.36789703, 15.7816], [74.37084198, 15.78218174], [74.37551117, 15.79671955], [74.37580109, 15.80120087], [74.37454987, 15.80452156], [74.37400818, 15.81044102], [74.36915588, 15.81216145], [74.36637115, 15.81549072], [74.3707428, 15.81722069], [74.37336731, 15.82583237], [74.37454987, 15.82750034], [74.38626862, 15.83326244], [74.38944244, 15.83631134], [74.38931274, 15.84414005], [74.38741302, 15.8471117], [74.3537674, 15.84810066], [74.3463974, 15.84934998], [74.34453583, 15.85205078], [74.35340118, 15.85573196], [74.35295868, 15.85924053], [74.3640976, 15.87016106], [74.36702728, 15.87109089], [74.36743164, 15.87321854], [74.36997986, 15.87568092], [74.3706131, 15.88000202], [74.37052155, 15.8903904], [74.37412262, 15.89161015], [74.3744812, 15.88994122], [74.37277985, 15.88768959], [74.3765564, 15.8849411], [74.38313293, 15.87776184], [74.38556671, 15.87323093], [74.38794708, 15.86394119], [74.3884964, 15.8572197], [74.39228821, 15.85744953], [74.39343262, 15.8517704], [74.40312195, 15.84895992], [74.4065094, 15.8519001], [74.41158295, 15.85259056], [74.41221619, 15.85763931], [74.39919281, 15.87434959], [74.40254974, 15.87826061], [74.40164185, 15.88726997], [74.39930725, 15.89577103], [74.39836121, 15.8977108], [74.39234924, 15.89926147], [74.39186859, 15.90115929], [74.40203857, 15.9110508], [74.41226959, 15.92520046], [74.43522644, 15.95116997], [74.44229126, 15.9654789], [74.44394684, 15.9743309], [74.4499588, 15.98323059], [74.44847107, 15.9864006], [74.44843292, 15.98829079], [74.45017242, 15.99260139], [74.44966888, 15.99853134], [74.45336914, 16.00580978], [74.45643616, 16.00890923], [74.46391296, 16.02256012], [74.46710205, 16.03026962], [74.467659, 16.03364944], [74.47027588, 16.0405407], [74.46795654, 16.04669952], [74.46383667, 16.0477314], [74.45587158, 16.05216026], [74.44803619, 16.05240059], [74.44048309, 16.05702019], [74.4363327, 16.05673027], [74.43213654, 16.05513191], [74.4229126, 16.05319023], [74.4155426, 16.05105972], [74.41121674, 16.04901123], [74.40960693, 16.04709816], [74.40931702, 16.04533005], [74.39607239, 16.03960037], [74.3900528, 16.03512955], [74.37858582, 16.03662109], [74.37822723, 16.03926086], [74.37888336, 16.04339981], [74.38173676, 16.05356979], [74.38014221, 16.05476761], [74.37075043, 16.05101967], [74.36815643, 16.05295944], [74.37098694, 16.05957031], [74.37510681, 16.06336975], [74.38008118, 16.06958008], [74.3806076, 16.07302094], [74.3795929, 16.07682037], [74.3809967, 16.07826042], [74.38680267, 16.07809067], [74.39045715, 16.07992935], [74.39724731, 16.07838821], [74.39830017, 16.08011818], [74.39731598, 16.08712959], [74.40406036, 16.09097862], [74.40760803, 16.09069824], [74.41520691, 16.09181976], [74.41607666, 16.09600067], [74.41845703, 16.10089111], [74.42276001, 16.10256958], [74.4345932, 16.1106205], [74.43795013, 16.10816002], [74.44452667, 16.10518074], [74.45491028, 16.10267067], [74.46000671, 16.102911], [74.4645462, 16.10211182], [74.47796631, 16.09189987], [74.47891235, 16.08789063], [74.4818573, 16.08696938], [74.48908997, 16.08732033], [74.490448, 16.09037018], [74.49279785, 16.09283829], [74.49263, 16.09553909], [74.49349976, 16.09859276], [74.49640656, 16.10157967], [74.49710846, 16.11236954], [74.49095154, 16.1420002], [74.48710632, 16.1430912], [74.48580933, 16.14698982], [74.48996735, 16.14722252], [74.49466705, 16.15504074], [74.49532318, 16.16900063], [74.49781799, 16.18133926], [74.50177002, 16.18543053], [74.50908661, 16.18783951], [74.51287842, 16.18826294], [74.51288605, 16.18939972], [74.51252747, 16.19584084], [74.51081085, 16.19881821], [74.51322937, 16.19922066], [74.51329803, 16.2012291], [74.5031662, 16.2115612], [74.50211334, 16.21413994], [74.50296021, 16.21622086], [74.50772095, 16.22128105], [74.5083313, 16.22294044], [74.50311279, 16.23104095], [74.49507141, 16.23596954], [74.49482727, 16.23801994], [74.48412323, 16.2467308], [74.48079681, 16.24432945], [74.47606659, 16.23903084], [74.47318268, 16.23851967], [74.46343231, 16.24183083], [74.4614563, 16.24377823], [74.46122742, 16.24843025], [74.44277954, 16.2495594], [74.44184113, 16.25415039], [74.44094086, 16.25266075], [74.4363327, 16.25476837], [74.42253113, 16.2574501], [74.42082214, 16.26387978], [74.42159271, 16.27145958], [74.4212265, 16.28059006], [74.41802216, 16.28092957], [74.40075684, 16.27625084], [74.39126587, 16.27560043], [74.39038086, 16.29024124], [74.38742065, 16.29034805], [74.38006592, 16.2935009], [74.37377167, 16.29031944], [74.36960602, 16.29072189], [74.36257172, 16.28713989], [74.35853577, 16.28880119], [74.35611725, 16.29092026], [74.35459137, 16.28976059], [74.35328674, 16.2918396], [74.35169983, 16.28820992], [74.3603363, 16.28190994], [74.35986328, 16.27960968], [74.35514069, 16.27449036], [74.35212708, 16.27448273], [74.35074615, 16.27625847], [74.3493576, 16.27506065], [74.34945679, 16.27326965], [74.34390259, 16.27212143], [74.34041595, 16.2675705], [74.33705139, 16.26572037], [74.33383942, 16.26807022], [74.33065796, 16.27293968], [74.32868958, 16.27943039], [74.32932281, 16.28106117], [74.33215332, 16.28409958], [74.33178711, 16.2861805], [74.33637238, 16.29017067], [74.34268188, 16.28877068], [74.34871674, 16.29146957], [74.34484863, 16.30326843], [74.34115601, 16.30282021], [74.34012604, 16.30398941], [74.34233093, 16.30509186], [74.34059143, 16.31162071], [74.33210754, 16.3107605], [74.33101654, 16.31502151], [74.33152008, 16.31641006], [74.33569336, 16.31500053], [74.3400116, 16.31693077], [74.33727264, 16.32339287], [74.33335876, 16.32374191], [74.32993317, 16.3223629], [74.32302094, 16.32512283], [74.32401276, 16.32742119], [74.32727814, 16.32920074], [74.32911682, 16.3325901], [74.32480621, 16.33666992], [74.32345581, 16.33989143], [74.32823181, 16.34110069], [74.33439636, 16.34052277], [74.33156586, 16.34649086], [74.32370758, 16.35361099], [74.33152008, 16.35556984], [74.33223724, 16.35695076], [74.32762909, 16.36811066], [74.32776642, 16.37034035], [74.32546234, 16.37924957], [74.33255005, 16.3755703], [74.33474731, 16.38285828], [74.33500671, 16.38871956], [74.33596039, 16.38964272], [74.34033203, 16.3909626], [74.34306335, 16.39067078], [74.34577179, 16.38952065], [74.34771729, 16.38601112], [74.34858704, 16.38038254], [74.35108185, 16.37676048], [74.35189819, 16.36630058], [74.36165619, 16.36474991], [74.35961151, 16.37882042], [74.36868286, 16.3911705], [74.36911011, 16.39432907], [74.36782074, 16.39846992], [74.36457062, 16.4032383], [74.35954285, 16.40398979], [74.34916687, 16.4039402], [74.34928131, 16.39940071], [74.34265137, 16.40049171], [74.34194183, 16.40521049], [74.33818054, 16.41337013], [74.33728027, 16.42020988], [74.34375, 16.42554092], [74.34052277, 16.43297958], [74.34062195, 16.43617058], [74.34223175, 16.43956947], [74.34246063, 16.44232941], [74.33904266, 16.44486046], [74.33876038, 16.44664192], [74.33998871, 16.44812965], [74.33886719, 16.45216179], [74.33555603, 16.45308113], [74.33052826, 16.45279121], [74.32193756, 16.45004082], [74.31482697, 16.45319939], [74.30709076, 16.45959091], [74.30464935, 16.46079063], [74.30239868, 16.46108055], [74.30139923, 16.45906067], [74.29631805, 16.45901108], [74.2964325, 16.46671104], [74.29483795, 16.47435188], [74.2975769, 16.48161125], [74.30055237, 16.49963188], [74.29989624, 16.50263023], [74.28894806, 16.50378036], [74.28330994, 16.49603271], [74.28051758, 16.48936081], [74.28099823, 16.48579025], [74.28253937, 16.48257065], [74.27842712, 16.47963905], [74.26877594, 16.47603035], [74.26516724, 16.48240089], [74.26452637, 16.48545074], [74.262146, 16.48867035], [74.26008606, 16.49090767], [74.25315857, 16.49488068], [74.25570679, 16.49677086], [74.26313019, 16.49895287], [74.27864075, 16.50102043], [74.28575897, 16.50337029], [74.28668976, 16.50677109], [74.28440094, 16.51647949], [74.28190613, 16.52055168], [74.27662659, 16.52061081], [74.2755127, 16.52515984], [74.27197266, 16.5334301], [74.27155304, 16.53866005], [74.27636719, 16.54453278], [74.28431702, 16.54309273], [74.28822327, 16.53947067], [74.28672791, 16.52940941], [74.28713226, 16.52732086], [74.28955841, 16.52526283], [74.28961945, 16.52256966], [74.29483795, 16.52929115], [74.29447937, 16.53154182], [74.29762268, 16.53193092], [74.30692291, 16.52917099], [74.30892181, 16.52399826], [74.30845642, 16.52187157], [74.31157684, 16.50692749], [74.31346893, 16.50325966], [74.31411743, 16.50209808], [74.32145691, 16.50267029], [74.32390594, 16.50629807], [74.32267761, 16.51900101], [74.3232193, 16.5322094], [74.32216644, 16.53905106], [74.32222748, 16.54450035], [74.32377625, 16.55146027], [74.32940674, 16.55347061], [74.33215332, 16.55369949], [74.34020233, 16.55013275], [74.34612274, 16.54644966], [74.35507202, 16.55311012], [74.35974884, 16.55368996], [74.36308289, 16.55620193], [74.36561584, 16.55706978], [74.36923218, 16.55327034], [74.36287689, 16.5485611], [74.36464691, 16.54368019], [74.36258698, 16.53874016], [74.36611938, 16.53763962], [74.37110138, 16.53765106], [74.38543701, 16.52740288], [74.3899231, 16.5279007], [74.39289856, 16.53107071], [74.39565277, 16.53567123], [74.39550018, 16.55952263], [74.40113068, 16.56088829], [74.40077209, 16.56347275], [74.39839935, 16.56542969], [74.40120697, 16.57094002], [74.40216064, 16.57472992], [74.40348053, 16.5786705], [74.41371918, 16.58023834], [74.42228699, 16.58350182], [74.42883301, 16.58272934], [74.43354034, 16.59436035], [74.44081879, 16.59869194], [74.44698334, 16.60033989], [74.47245789, 16.60481071], [74.47080231, 16.61495018], [74.47136688, 16.6217804], [74.46981049, 16.62347984], [74.46446991, 16.63398933], [74.46283722, 16.64448929], [74.46518707, 16.64689827], [74.46479797, 16.65295029], [74.47013855, 16.65518951], [74.47738647, 16.66077995], [74.4813385, 16.6540699], [74.48587036, 16.6391201], [74.48983765, 16.63607025], [74.49178314, 16.63233948], [74.49550629, 16.62767029], [74.49800873, 16.62664032], [74.50167084, 16.62713814], [74.51029205, 16.63145065], [74.53009033, 16.63060951], [74.55143738, 16.63321114], [74.54937744, 16.61552048], [74.55024719, 16.60902023], [74.54985046, 16.59218025], [74.55459595, 16.59242058], [74.56555939, 16.59037971], [74.56981659, 16.58122063], [74.56510162, 16.57463074], [74.55970001, 16.57137108], [74.55908966, 16.56710815], [74.55966949, 16.5597496], [74.56220245, 16.55803108], [74.56552887, 16.55779076], [74.56907654, 16.55639839], [74.5740509, 16.55196953], [74.58152008, 16.55183983], [74.58152008, 16.55500031], [74.59195709, 16.55554962], [74.59253693, 16.55727005], [74.5916214, 16.55883026], [74.59179688, 16.56072044], [74.59335327, 16.56382942], [74.59588623, 16.56439018], [74.60484314, 16.56214142], [74.61699677, 16.56797028], [74.62264252, 16.57364082], [74.62438965, 16.57755089], [74.62393951, 16.58192062], [74.62695313, 16.58093071], [74.63066101, 16.57765007], [74.6363678, 16.57574081], [74.64051819, 16.5819397], [74.63938141, 16.59435272], [74.63974762, 16.59953117], [74.64113617, 16.60469055], [74.64280701, 16.60677147], [74.64771271, 16.60807037], [74.65174866, 16.60697937], [74.66387177, 16.60107994], [74.66882324, 16.60268021], [74.67529297, 16.60598946], [74.67855072, 16.60655975], [74.69037628, 16.60445976], [74.69338226, 16.60727119], [74.69462585, 16.61082077], [74.69431305, 16.61519051], [74.69122314, 16.61814117], [74.68531036, 16.61988068], [74.67386627, 16.62845993], [74.66600037, 16.62872124], [74.66304779, 16.63216972], [74.6605072, 16.63758087], [74.66880035, 16.65555191], [74.67173767, 16.66353035], [74.69610596, 16.67498016], [74.69458008, 16.67864037], [74.68727875, 16.67901039], [74.68752289, 16.68166161], [74.68895721, 16.68412018], [74.69561005, 16.68583107], [74.69503784, 16.69244194], [74.69593811, 16.71054077], [74.69819641, 16.71520042], [74.70783234, 16.7130909], [74.72244263, 16.71329117], [74.73661804, 16.71583939], [74.74820709, 16.72212029], [74.75409698, 16.72619057], [74.75614166, 16.72962952], [74.76381683, 16.73680115], [74.76940918, 16.73946953], [74.7750473, 16.74077988], [74.77555847, 16.74399948], [74.77900696, 16.74859047], [74.79110718, 16.74814987], [74.80040741, 16.74565125], [74.80410767, 16.75076294], [74.8503418, 16.76032066], [74.85497284, 16.77076912], [74.86836243, 16.77108002], [74.89263916, 16.76869011], [74.90701294, 16.76979065], [74.9238205, 16.76995087], [74.91586304, 16.78568077], [74.91581726, 16.81022072], [74.91306305, 16.83074951], [74.91330719, 16.84144974], [74.91195679, 16.85593987], [74.92778778, 16.86334991], [74.9315033, 16.86954117], [74.93708038, 16.86916161], [74.93984985, 16.87232018], [74.93966675, 16.87652016], [74.94513702, 16.87712288], [74.94861603, 16.88009071], [74.95606995, 16.87729073], [74.96409607, 16.8778801], [74.96726227, 16.90538025], [74.95284271, 16.90648079], [74.94803619, 16.90917015], [74.94407654, 16.91327095], [74.9382019, 16.91646957], [74.93694305, 16.92073059], [74.92703247, 16.92562294], [74.9285202, 16.93520164], [74.93839264, 16.94099045], [74.94834137, 16.93581963], [74.95243073, 16.93622017], [74.95453644, 16.93000031], [74.95802307, 16.92914009], [74.95999908, 16.9329319], [74.96671295, 16.93564987], [74.96949768, 16.93591118], [74.97528839, 16.93460083], [74.98142242, 16.93061066], [74.98581696, 16.92901993], [74.99449158, 16.93503952], [74.99954224, 16.94189835], [75.00370026, 16.94582748], [75.01140594, 16.94258118], [75.03029633, 16.94153023], [75.03011322, 16.93114281], [75.03190613, 16.92567062], [75.03449249, 16.92873955], [75.04535675, 16.93425941], [75.04814911, 16.93871117], [75.05078888, 16.93966103], [75.05523682, 16.93885994], [75.0654068, 16.93926048], [75.08294678, 16.94659805], [75.09041595, 16.94865036], [75.09414673, 16.94722939], [75.0947113, 16.92115021], [75.09796906, 16.91386986], [75.10692596, 16.9095211], [75.11875916, 16.90997124], [75.12200165, 16.90723038], [75.1235733, 16.90043831], [75.12763214, 16.89718056], [75.13839722, 16.89292145], [75.13710785, 16.88459969], [75.13838959, 16.8782692], [75.14112854, 16.87354088], [75.15052795, 16.86940956], [75.16438293, 16.86557961], [75.17175293, 16.86479759], [75.18084717, 16.86751175], [75.18965912, 16.87350082], [75.19252014, 16.86955833], [75.18900299, 16.86189842], [75.18319702, 16.84204102], [75.18828583, 16.84089088], [75.21585846, 16.84033966], [75.23001099, 16.84091949], [75.23291016, 16.84554291], [75.23565674, 16.85419083], [75.24099731, 16.86296082], [75.24344635, 16.86449051], [75.24867249, 16.86452866], [75.25797272, 16.86213112], [75.26830292, 16.86086082], [75.28277588, 16.87424088], [75.28565216, 16.87879944], [75.28749847, 16.88321114], [75.29177856, 16.90113831], [75.28557587, 16.90943146], [75.28359985, 16.94294167], [75.28462219, 16.95355034], [75.28843689, 16.95477295], [75.2947464, 16.95412827], [75.30612946, 16.95466995], [75.33796692, 16.9535408], [75.34532928, 16.95252037], [75.35957336, 16.9568882], [75.36435699, 16.9636097], [75.37168884, 16.96869087], [75.39476013, 16.97639275], [75.41683197, 16.96949959], [75.43102264, 16.96346092], [75.4388504, 16.97088051], [75.44380188, 16.97949028], [75.45353699, 16.98265076], [75.46791077, 16.98533058], [75.46858978, 16.97957039], [75.48249817, 16.97595024], [75.48969269, 16.96538925], [75.49178314, 16.95783043], [75.49263, 16.95150948], [75.49301147, 16.94518089], [75.49249268, 16.9428997], [75.50187683, 16.94540977], [75.5092926, 16.94859123], [75.51065063, 16.94730949], [75.51700592, 16.95193291], [75.52406311, 16.95874023], [75.53000641, 16.96582985], [75.53286743, 16.96665192], [75.54281616, 16.96314049], [75.55847168, 16.96434975], [75.57034302, 16.96362114], [75.56929779, 16.99885941], [75.56991577, 17.00617027], [75.57579803, 17.00779915], [75.59944153, 17.00522041], [75.60951996, 17.00311089], [75.60965729, 16.99893951], [75.61065674, 16.96961975], [75.62101746, 16.96775055], [75.6309433, 16.96714973], [75.63633728, 16.96581078], [75.63938904, 16.95915985], [75.64502716, 16.95103264], [75.64962769, 16.95199966], [75.65561676, 16.95611], [75.66374969, 16.95788193], [75.67137909, 16.95853806], [75.67460632, 16.96026993], [75.67842102, 16.96394157], [75.67459106, 16.96935081], [75.67263031, 16.97408104], [75.66938019, 16.97562981], [75.66883087, 16.97776031], [75.66867828, 16.98321915], [75.67053986, 16.9988308], [75.67310333, 17.02617073], [75.67224121, 17.03573036], [75.66216278, 17.03244972], [75.65399933, 17.03063965], [75.64819336, 17.03269005], [75.64375305, 17.03639984], [75.64787292, 17.04657173], [75.65439606, 17.05508995], [75.66268921, 17.06178284], [75.6709671, 17.06157112], [75.67840576, 17.06286049], [75.68107605, 17.07114029], [75.68013763, 17.07826805], [75.67739105, 17.08774948], [75.67848969, 17.09417152], [75.67550659, 17.10112953], [75.67410278, 17.11355019], [75.65363312, 17.11313057], [75.65273285, 17.13273048], [75.64968872, 17.13318062], [75.64871216, 17.13880157], [75.64273071, 17.14763832], [75.6313858, 17.16007042], [75.62802124, 17.17012024], [75.62851715, 17.18074989], [75.63018799, 17.18144989], [75.63069916, 17.18616104], [75.64264679, 17.18815994], [75.64359283, 17.19408035], [75.65743256, 17.20378113], [75.662117, 17.20833015], [75.66387939, 17.21375084], [75.66281891, 17.22793961], [75.66091919, 17.23999977], [75.65988922, 17.26144028], [75.65747833, 17.27057076], [75.63231659, 17.27222061], [75.63336945, 17.27738953], [75.63109589, 17.2798481], [75.62786865, 17.28812027], [75.62468719, 17.29380035], [75.60595703, 17.3032608], [75.61374664, 17.31944084], [75.61604309, 17.32876015], [75.61310577, 17.34229088], [75.59810638, 17.34511948], [75.58994293, 17.34968948], [75.58483124, 17.34977913], [75.58405304, 17.35134125], [75.57853699, 17.38293076], [75.58371735, 17.38220024], [75.58817291, 17.3830204], [75.59815979, 17.38610077], [75.60331726, 17.38986015], [75.61057281, 17.39200974], [75.61580658, 17.39185905], [75.61672211, 17.39863968], [75.61495209, 17.40956116], [75.61055756, 17.41711998], [75.61013794, 17.41954041], [75.61543274, 17.4220295], [75.61873627, 17.43911171], [75.62532806, 17.45811081], [75.63127136, 17.46117973], [75.63288879, 17.46964073], [75.6355896, 17.47751045], [75.64955902, 17.47340965], [75.65618134, 17.46751022], [75.66230011, 17.45968056], [75.6704483, 17.45932007], [75.6775589, 17.45797157], [75.68081665, 17.45397186], [75.68080902, 17.43616295], [75.68711853, 17.41730118], [75.69119263, 17.41261101], [75.69721222, 17.41056824], [75.70806122, 17.40831947], [75.71517944, 17.40893173], [75.72236633, 17.4117794], [75.72901154, 17.41950989], [75.7339859, 17.42165947], [75.73703766, 17.4218998], [75.75052643, 17.41290092], [75.75875854, 17.40841103], [75.76412201, 17.40842056], [75.76976776, 17.40684128], [75.77661896, 17.38820267], [75.78231812, 17.37881279], [75.79102325, 17.37298012], [75.80233765, 17.37010193], [75.8113327, 17.3699398], [75.81505585, 17.37384987], [75.81759644, 17.38072968], [75.81768799, 17.38804054], [75.81627655, 17.39781189], [75.81729126, 17.40121078], [75.82025146, 17.4065609], [75.82199097, 17.41967964], [75.82472229, 17.42284966], [75.82779694, 17.42371941], [75.83889008, 17.42054176], [75.8478775, 17.41534042], [75.85600281, 17.40768242], [75.85910797, 17.38896942], [75.86196899, 17.38585091], [75.86487579, 17.38644028], [75.87666321, 17.39697075], [75.87890625, 17.40032959], [75.87909698, 17.40493965], [75.8771286, 17.41135025], [75.87844849, 17.41654015], [75.88243103, 17.41900063], [75.88723755, 17.41732979], [75.89025879, 17.41360092], [75.89435577, 17.40590286], [75.89643097, 17.39497948], [75.89697266, 17.37700081], [75.89639282, 17.3699894], [75.89198303, 17.36079979], [75.8936615, 17.35362053], [75.89808655, 17.35075951], [75.9107132, 17.34581947], [75.91622162, 17.33897018], [75.93115234, 17.32411003], [75.94174957, 17.32485962], [75.95981598, 17.33383179], [75.9715271, 17.33646011], [75.98071289, 17.33620071], [76.00026703, 17.33774948], [76.00417328, 17.3427906], [76.00914001, 17.34752274], [76.01545715, 17.35061073], [76.02127838, 17.34931183], [76.03666687, 17.34896278], [76.05452728, 17.35429955], [76.06046295, 17.35393143], [76.0632019, 17.3519001], [76.0734787, 17.33232117], [76.07874298, 17.3300705], [76.08499146, 17.3321209], [76.08685303, 17.3337307], [76.08696747, 17.33844757], [76.09252167, 17.34367943], [76.09407806, 17.34709167], [76.09046936, 17.35056114], [76.09276581, 17.35444069], [76.09596252, 17.35781288], [76.10199738, 17.36226082], [76.11667633, 17.36622047], [76.12120819, 17.36634064], [76.1375885, 17.35256958], [76.14566803, 17.34793282], [76.16314697, 17.34090996], [76.16422272, 17.31925964], [76.1638031, 17.30033112], [76.17188263, 17.29758072], [76.17575836, 17.29721069], [76.18383026, 17.31104279], [76.18260193, 17.31430054], [76.17891693, 17.31391907], [76.1763382, 17.32146072], [76.17350769, 17.33223915], [76.17233276, 17.34873009], [76.17603302, 17.35238075], [76.1829071, 17.35650063], [76.19320679, 17.35859108], [76.20352173, 17.35878944], [76.22899628, 17.36322975], [76.2303772, 17.37026024], [76.24436188, 17.37467957], [76.24671173, 17.3678894], [76.2504425, 17.36667061], [76.248909, 17.36213112], [76.25, 17.35790062], [76.25627899, 17.35738945], [76.26494598, 17.35816193], [76.27017975, 17.35653114], [76.27263641, 17.34794998], [76.27587891, 17.33053017], [76.2857666, 17.33035088], [76.29589844, 17.32863808], [76.30502319, 17.32845116], [76.31720734, 17.32944107], [76.318367, 17.33184052], [76.31301117, 17.34327126], [76.31704712, 17.34540939], [76.33473969, 17.3498497], [76.34361267, 17.34993172], [76.3506012, 17.32772064], [76.35227203, 17.31059074], [76.35936737, 17.31028938], [76.38170624, 17.31180954], [76.38389587, 17.31954193], [76.39299011, 17.33628082], [76.4020462, 17.34399033], [76.4106369, 17.34769058], [76.4105072, 17.35413933], [76.4080658, 17.3692894], [76.36199951, 17.37508011], [76.37004852, 17.40789986], [76.36988068, 17.42304039], [76.37317657, 17.43441963], [76.3638916, 17.43555069], [76.34195709, 17.43383026], [76.33365631, 17.43229294], [76.33084106, 17.46162033], [76.33080292, 17.46881866], [76.33776855, 17.47040939], [76.3427887, 17.47037125], [76.3500061, 17.47212982], [76.37229919, 17.48578072], [76.37503815, 17.49352074], [76.36659241, 17.49529266], [76.35518646, 17.49416924], [76.34594727, 17.49159813], [76.34348297, 17.49435043], [76.34372711, 17.50811958], [76.34633636, 17.51148033], [76.35601807, 17.51337051], [76.3664093, 17.51671028], [76.36612701, 17.52217293], [76.36460876, 17.52852058], [76.36090088, 17.5362606], [76.35481262, 17.53873062], [76.34583282, 17.54021072], [76.34002686, 17.54257011], [76.33724213, 17.5551796], [76.33423615, 17.56348991], [76.33290863, 17.57383156], [76.33167267, 17.59486961], [76.33641052, 17.59604073], [76.34870148, 17.59539986], [76.35948181, 17.5962925], [76.37301636, 17.59793854], [76.38207245, 17.60078049], [76.4156723, 17.60420036], [76.41818237, 17.60583115], [76.42074585, 17.61424065], [76.42410278, 17.62154007], [76.42579651, 17.62832069], [76.42723083, 17.63978004], [76.4287262, 17.64441109], [76.43477631, 17.64453125], [76.44275665, 17.6418705], [76.4408493, 17.64937019], [76.45153809, 17.65151024], [76.45230103, 17.6555481], [76.48929596, 17.66066933], [76.48464966, 17.66963005], [76.48442841, 17.68442917], [76.48562622, 17.69269943], [76.48636627, 17.71352005], [76.49225616, 17.71494102], [76.51095581, 17.71591949], [76.52363586, 17.71523094], [76.52482605, 17.72290993], [76.52503967, 17.73467255], [76.5236969, 17.75889015], [76.52632141, 17.75936127], [76.53159332, 17.75852966], [76.53820801, 17.75893974], [76.55977631, 17.76313972], [76.56754303, 17.76288986], [76.57330322, 17.76000023], [76.56936646, 17.75638008], [76.56459045, 17.7536602], [76.5681076, 17.7397995], [76.56942749, 17.70374107], [76.57322693, 17.70216942], [76.57720947, 17.70314026], [76.5870285, 17.70788956], [76.59324646, 17.71755981], [76.59880066, 17.72797012], [76.60405731, 17.75583076], [76.60690308, 17.75958061], [76.60951233, 17.76597977], [76.61444855, 17.76831245], [76.62336731, 17.7578907], [76.62695313, 17.75596046], [76.62979889, 17.74187088], [76.63065338, 17.72900009], [76.63743591, 17.72410965], [76.65083313, 17.72083092], [76.6552124, 17.71640015], [76.65812683, 17.70853043], [76.65983582, 17.69919014], [76.66313934, 17.68786049], [76.67164612, 17.68914032], [76.67814636, 17.68734169], [76.68826294, 17.67851067], [76.69055176, 17.67995262], [76.69313049, 17.69376183], [76.69122314, 17.6981411], [76.69087219, 17.70194054], [76.69235992, 17.70526123], [76.70079803, 17.70726967], [76.70345306, 17.7186203], [76.70210266, 17.72371101], [76.69815063, 17.72603989], [76.70347595, 17.72912025], [76.72760773, 17.73699951], [76.72650146, 17.7403698], [76.72193146, 17.74802971], [76.7179718, 17.74786949], [76.71909332, 17.76133156], [76.72096252, 17.76758957], [76.71720123, 17.76984978], [76.7128067, 17.7713604], [76.71244812, 17.77509117], [76.71570587, 17.78191948], [76.71938324, 17.7852993], [76.72463226, 17.78507805], [76.73943329, 17.77913094], [76.74355316, 17.78079033], [76.74401093, 17.78346062], [76.74777222, 17.78360939], [76.74887848, 17.78635025], [76.76275635, 17.78710938], [76.7663269, 17.79664993], [76.77002716, 17.79701996], [76.77628326, 17.79938126], [76.77979279, 17.80591965], [76.77947998, 17.81028938], [76.78141785, 17.8151207], [76.78481293, 17.81963921], [76.78816986, 17.82647133], [76.78546906, 17.83146286], [76.77974701, 17.83633041], [76.76573944, 17.85079956], [76.76434326, 17.84950066], [76.75972748, 17.85206032], [76.75456238, 17.85658836], [76.74578857, 17.8583107], [76.73745728, 17.85705948], [76.73964691, 17.88362122], [76.73958588, 17.89204979], [76.74067688, 17.89801025], [76.74297333, 17.89902115], [76.76595306, 17.89842987], [76.7701416, 17.89236069], [76.77310944, 17.88515091], [76.77379608, 17.8822403], [76.77326202, 17.8786602], [76.77456665, 17.87696075], [76.7974472, 17.8693409], [76.80280304, 17.86832047], [76.80625153, 17.87049294], [76.80535126, 17.87420845], [76.80822754, 17.88309097], [76.81108093, 17.88408852], [76.81713104, 17.88309097], [76.82036591, 17.88445282], [76.83307648, 17.88274956], [76.83175659, 17.89067268], [76.8469162, 17.89640045], [76.85383606, 17.89783859], [76.87185669, 17.89474106], [76.87526703, 17.89273071], [76.88117981, 17.89305115], [76.88320923, 17.89707947], [76.88938141, 17.89718056], [76.89240265, 17.9028511], [76.89366913, 17.90737152], [76.89659882, 17.90802002], [76.90020752, 17.91468811], [76.91320038, 17.91379929], [76.91644287, 17.91509056], [76.91834259, 17.92310905], [76.91918945, 17.93666077], [76.91322327, 17.93720818], [76.91726685, 17.96047974], [76.91823578, 17.9728508], [76.91958618, 17.98538017], [76.9196701, 17.99064064], [76.91763306, 17.99625969], [76.91848755, 17.99868965], [76.91816711, 18.00187111], [76.9176712, 18.01234055], [76.92024994, 18.01375961], [76.91940308, 18.0220108], [76.91771698, 18.03322983], [76.93863678, 18.03722954], [76.95205688, 18.03771019], [76.95464325, 18.03968048], [76.95430756, 18.04273033], [76.94863129, 18.04572105], [76.94844818, 18.04866028], [76.9506073, 18.0582695], [76.95266724, 18.06340981], [76.94948578, 18.06826973], [76.94702911, 18.07376099], [76.94973755, 18.0823307], [76.95482635, 18.08535957], [76.96431732, 18.08821106], [76.96734619, 18.09263992], [76.96827698, 18.09711075], [76.95857239, 18.10643005], [76.95339203, 18.11011124], [76.94252777, 18.11141014], [76.93215179, 18.11098289], [76.92256165, 18.11610985], [76.92228699, 18.12018967], [76.92417908, 18.12446022], [76.92999268, 18.13225174], [76.9317627, 18.13657951], [76.92765808, 18.13986015], [76.92536926, 18.14481926], [76.93335724, 18.15790939], [76.9437561, 18.15473938], [76.95095825, 18.17247963], [76.95410919, 18.18489075], [76.95881653, 18.18614006], [76.97090149, 18.18686104], [76.97985077, 18.18740082], [76.98055267, 18.18939972], [76.98789215, 18.18847847], [76.99146271, 18.18665123], [76.99295044, 18.1820507], [76.99547577, 18.1783905], [76.99529266, 18.17333031], [76.99775696, 18.16684914], [77.02398682, 18.16267967], [77.02274323, 18.17124939], [77.02171326, 18.17822075], [77.03032684, 18.17934036], [77.03238678, 18.18300056], [77.03283691, 18.18378067], [77.0381012, 18.18131065], [77.04944611, 18.17320824], [77.05031586, 18.16127968], [77.05767059, 18.15592957], [77.05767059, 18.15236282], [77.06910706, 18.14944077], [77.08618164, 18.15027046], [77.08925629, 18.15596008], [77.09268188, 18.15697861], [77.09661865, 18.15813065], [77.10888672, 18.15269089], [77.11633301, 18.16760826], [77.10292816, 18.18630981], [77.09886169, 18.19114113], [77.09554291, 18.19510078], [77.10659027, 18.20181084], [77.11662292, 18.20240974], [77.12098694, 18.20670128], [77.13114929, 18.20618057], [77.13949585, 18.20724106], [77.14221954, 18.21604919], [77.14998627, 18.21656036], [77.1506424, 18.22153091], [77.14879608, 18.22145271], [77.14768982, 18.22140121], [77.14776611, 18.23764992], [77.15141296, 18.23793983], [77.15719604, 18.25309181], [77.16567993, 18.25592041], [77.16738129, 18.27345085], [77.17053223, 18.28087044], [77.17784119, 18.28185081], [77.19165039, 18.27429008], [77.19882965, 18.27923012], [77.20617676, 18.27795982], [77.20446014, 18.29047966], [77.19764709, 18.29552078], [77.19541168, 18.31270981], [77.20014954, 18.31917], [77.2099762, 18.31374168], [77.21691132, 18.32489014], [77.22297668, 18.33780098], [77.22727203, 18.34490013], [77.22136688, 18.34720993], [77.23081207, 18.36557961], [77.24163055, 18.3663826], [77.24503326, 18.3705883], [77.23287201, 18.38612747], [77.23639679, 18.39981079], [77.24022675, 18.40864754], [77.24912262, 18.40825272], [77.25836182, 18.41041946], [77.26455688, 18.41838074], [77.29476929, 18.43268013], [77.30226135, 18.43847084], [77.31327057, 18.43938065], [77.31741333, 18.45379066], [77.32557678, 18.45512009], [77.32601929, 18.44885063], [77.33271027, 18.44845963], [77.33338165, 18.44189072], [77.33731079, 18.43544006], [77.34207916, 18.43029022], [77.34529114, 18.43437195], [77.35407257, 18.44874191], [77.36962891, 18.44765091], [77.36535645, 18.43808937], [77.3644104, 18.42984962], [77.36975098, 18.40070915], [77.39263916, 18.39702988], [77.40049744, 18.39780045], [77.41011047, 18.38853073], [77.40788269, 18.37849045], [77.40067291, 18.37017059], [77.39182281, 18.36593056], [77.39824677, 18.35353088], [77.39833069, 18.34749985], [77.39594269, 18.34464073], [77.39277649, 18.3456707], [77.3928299, 18.34054947], [77.38922882, 18.34078979], [77.38617706, 18.33819008], [77.37930298, 18.33910179], [77.38089752, 18.33193016], [77.37800598, 18.32868958], [77.37394714, 18.32950974], [77.36701965, 18.32232285], [77.35542297, 18.31851959], [77.35881042, 18.31064987], [77.36252594, 18.30829048], [77.38128662, 18.30595016], [77.3925705, 18.30093002], [77.39628601, 18.30298042], [77.4078064, 18.29956055], [77.42500305, 18.30467033], [77.42780304, 18.30917931], [77.43637085, 18.30649185], [77.43461609, 18.29298019], [77.4369278, 18.28203964], [77.44489288, 18.27724075], [77.44522095, 18.27012062], [77.45079041, 18.26596069], [77.46539307, 18.25996017], [77.46923065, 18.26316071], [77.47480774, 18.26229095], [77.48034668, 18.26865959], [77.49223328, 18.26588058], [77.4977417, 18.27334976], [77.51020813, 18.27844048], [77.51264191, 18.28198051], [77.50843048, 18.3021698], [77.50950623, 18.30673027], [77.51978302, 18.30736923], [77.52388763, 18.30303192], [77.5395813, 18.29383087], [77.54995728, 18.29134941], [77.56098175, 18.28310966], [77.57065582, 18.29047012], [77.57463837, 18.28931046], [77.57433319, 18.28684807], [77.58381653, 18.28308105], [77.59784698, 18.28121948], [77.60301971, 18.27799988], [77.59902954, 18.27291107], [77.59194183, 18.26177025], [77.58149719, 18.25632095], [77.57253265, 18.24056053], [77.57676697, 18.23310089], [77.58106995, 18.22273827], [77.58496094, 18.21674156], [77.5743866, 18.19992065], [77.56430817, 18.20055008], [77.5643158, 18.18997955], [77.57002258, 18.18915939], [77.57247162, 18.17894936], [77.57753754, 18.16827011], [77.57936096, 18.16212082], [77.5891571, 18.15345955], [77.59777069, 18.15184021], [77.59350586, 18.12786102], [77.59661102, 18.12103081], [77.60056305, 18.09939957], [77.59745789, 18.08428955], [77.58979797, 18.08028984], [77.57744598, 18.07686996], [77.56733704, 18.07629013], [77.56048584, 18.07113075], [77.55670929, 18.06217003], [77.54743195, 18.06363106], [77.54574585, 18.05376053], [77.54807281, 18.0479908], [77.55206299, 18.04693985], [77.55311584, 18.03466988], [77.55782318, 18.03520012], [77.57448578, 18.03074074], [77.58496857, 18.02478981], [77.58724976, 18.01333046], [77.59224701, 18.01016808], [77.5994873, 18.01573944], [77.60666656, 18.01801109], [77.61006165, 18.01048088], [77.61585236, 18.00608826], [77.62229156, 18.00465965], [77.62390137, 18.00115967], [77.62145233, 17.99834061], [77.62879944, 17.99251938], [77.63272858, 17.99514008], [77.63822174, 17.99654007], [77.64228821, 17.99590111], [77.6461792, 17.9932003], [77.64775085, 17.98732185], [77.64978027, 17.98586273], [77.64888763, 17.97841072], [77.64360809, 17.97344971], [77.64742279, 17.97043991], [77.65339661, 17.96935272], [77.6520462, 17.96430016], [77.64425659, 17.96269035], [77.6428299, 17.95729065], [77.64742279, 17.95318985], [77.64398956, 17.94637108], [77.64061737, 17.9496212], [77.63561249, 17.95051956], [77.63182068, 17.95353127], [77.6297226, 17.96297073], [77.62374115, 17.95775032], [77.62899017, 17.95384026], [77.62886047, 17.94851112], [77.62428284, 17.94369125], [77.62001038, 17.94445992], [77.6167984, 17.93810081], [77.61952972, 17.93007088], [77.6186676, 17.92180824], [77.61894989, 17.91348076], [77.61657715, 17.90286827], [77.60444641, 17.90549088], [77.59979248, 17.90367126], [77.58516693, 17.90822983], [77.58307648, 17.89838028], [77.58521271, 17.8925209], [77.59249115, 17.87949944], [77.59777832, 17.87706947], [77.59668732, 17.87045097], [77.59275818, 17.86977959], [77.58127594, 17.87574959], [77.57772827, 17.87122917], [77.57274628, 17.87281036], [77.56743622, 17.86614037], [77.56604004, 17.84955978], [77.56215668, 17.84913063], [77.56346893, 17.84200096], [77.55918884, 17.83864021], [77.55432129, 17.83049011], [77.54973602, 17.8180294], [77.54479218, 17.81701088], [77.54371643, 17.82626915], [77.52600098, 17.82681847], [77.52607727, 17.81168938], [77.51805115, 17.80772018], [77.51087952, 17.80144119], [77.50701904, 17.79295921], [77.50448608, 17.78259087], [77.50934601, 17.7800808], [77.52304077, 17.77962112], [77.52760315, 17.77666092], [77.53449249, 17.77469063], [77.53697205, 17.7704525], [77.55445099, 17.76125908], [77.56595612, 17.76411057], [77.56202698, 17.74711037], [77.55464172, 17.74113083], [77.55187988, 17.73438072], [77.54412079, 17.73339081], [77.53936005, 17.72542191], [77.53398895, 17.72520256], [77.52755737, 17.72711754], [77.52258301, 17.72402954], [77.50946808, 17.71996117], [77.50544739, 17.7145195], [77.49427795, 17.71603966], [77.49173737, 17.71286011], [77.48932648, 17.70680046], [77.48446655, 17.70364952], [77.48108673, 17.70685005], [77.47867584, 17.70302963], [77.47415161, 17.70139122], [77.47155762, 17.70401001], [77.45786285, 17.69896126], [77.45462036, 17.69409752], [77.4503479, 17.69129944], [77.45140839, 17.68774033], [77.4509964, 17.68086052], [77.44909668, 17.66611099], [77.44564819, 17.65746117], [77.44500732, 17.64842033], [77.44753265, 17.64711952], [77.45081329, 17.63236046], [77.45321655, 17.63076973], [77.44882202, 17.62278938], [77.44580078, 17.61230087], [77.44650269, 17.60724068], [77.44130707, 17.60663033], [77.44050598, 17.60409164], [77.44207001, 17.59581184], [77.43992615, 17.58147049], [77.46121979, 17.57703018], [77.46515656, 17.57465935], [77.46911621, 17.56818008], [77.47207642, 17.56913185], [77.47408295, 17.56511116], [77.48999786, 17.56627083], [77.49563599, 17.55002975], [77.49555206, 17.54652977], [77.49681854, 17.5433712], [77.50161743, 17.5408802], [77.50965881, 17.54916954], [77.51390076, 17.55724907], [77.52742004, 17.57322121], [77.5320816, 17.5730896], [77.53669739, 17.57132912], [77.54395294, 17.55459976], [77.54839325, 17.54945946], [77.55281067, 17.55000114], [77.55612946, 17.55215073], [77.56083679, 17.5535202], [77.58538818, 17.55836105], [77.5854187, 17.56204033], [77.58982849, 17.5627594], [77.59185791, 17.55505943], [77.592453, 17.5490799], [77.59172821, 17.53268051], [77.59925079, 17.5340004], [77.60325623, 17.53069115], [77.60797119, 17.53107262], [77.61657715, 17.52935028], [77.62121582, 17.52225113], [77.63315582, 17.52308083], [77.64531708, 17.5187912], [77.64987946, 17.52107048], [77.65661621, 17.52133942], [77.66120911, 17.51481056], [77.66606903, 17.50995064], [77.67893982, 17.50510025], [77.68202972, 17.50666809], [77.68325043, 17.50402069], [77.68562317, 17.50564957], [77.68799591, 17.49854279], [77.68696594, 17.49156952], [77.68467712, 17.48522949], [77.68401337, 17.4728508], [77.66488647, 17.47628975], [77.64808655, 17.48117828], [77.64897156, 17.49155235], [77.65276337, 17.50325012], [77.64794922, 17.49936295], [77.64422607, 17.49489975], [77.64259338, 17.48344994], [77.64042664, 17.47601128], [77.6340332, 17.47223091], [77.62657166, 17.47120094], [77.61564636, 17.47140121], [77.61094666, 17.46994019], [77.61010742, 17.46463966], [77.61144257, 17.45290947], [77.61061096, 17.44423294], [77.60447693, 17.44309044], [77.59590149, 17.44268036], [77.59041595, 17.44810295], [77.57319641, 17.45420074], [77.57195282, 17.43855095], [77.57256317, 17.42951965], [77.5577774, 17.43527031], [77.54884338, 17.43492126], [77.53347015, 17.44095039], [77.52337646, 17.43668938], [77.51014709, 17.42725945], [77.51068878, 17.41254044], [77.52671814, 17.4059906], [77.53357697, 17.40610123], [77.5355072, 17.40410042], [77.53357697, 17.39884949], [77.52133179, 17.38633156], [77.52658844, 17.37882996], [77.53018188, 17.3778801], [77.52802277, 17.37211037], [77.52081299, 17.36205101], [77.509758, 17.3592701], [77.49912262, 17.35407066], [77.49237823, 17.35551071], [77.48261261, 17.35445976], [77.47447205, 17.35917091], [77.47241211, 17.36317825], [77.4753418, 17.36815071], [77.47931671, 17.36961174], [77.45159912, 17.37049103], [77.44988251, 17.3630619], [77.44976807, 17.35004807], [77.45298004, 17.34880829], [77.45635223, 17.34498978], [77.45510101, 17.3379097], [77.45250702, 17.32793045], [77.45137024, 17.32723045], [77.44963837, 17.31489944], [77.44798279, 17.31345177], [77.44043732, 17.2978096], [77.43776703, 17.29668999], [77.434021, 17.28825951], [77.4469986, 17.2888298], [77.45279694, 17.28663063], [77.45450592, 17.27589035], [77.44967651, 17.26986122], [77.44248199, 17.26859093], [77.43736267, 17.26136971], [77.4225769, 17.25325012], [77.42047882, 17.24933052], [77.42002106, 17.24160957], [77.41776276, 17.23278999], [77.41493988, 17.22987938], [77.40545654, 17.23740959], [77.3988266, 17.23188972], [77.39585114, 17.23285103], [77.39225006, 17.22855949], [77.38401794, 17.22331047], [77.38035583, 17.21977043], [77.38128662, 17.21632195], [77.38458252, 17.2129612], [77.39318848, 17.21147919], [77.39901733, 17.21153069], [77.39881134, 17.20877838], [77.39344788, 17.2069397], [77.39148712, 17.19236946], [77.38173676, 17.1937294], [77.37671661, 17.19300079], [77.37075043, 17.19007111], [77.36753082, 17.18320084], [77.36837006, 17.17648125], [77.36354828, 17.16948128], [77.36490631, 17.16494942], [77.35999298, 17.16162109], [77.36686707, 17.15133095], [77.37541962, 17.14870071], [77.37632751, 17.13788986], [77.39890289, 17.13191986], [77.4037323, 17.12321091], [77.41178894, 17.12051964], [77.42352295, 17.11405754], [77.43376923, 17.11115074], [77.43862915, 17.11458015], [77.44841766, 17.11149979], [77.45237732, 17.1076107], [77.46263885, 17.10407066], [77.46031189, 17.09284019], [77.46386719, 17.08671188], [77.46842957, 17.08111191], [77.47692108, 17.07623291], [77.47783661, 17.07226944], [77.47543335, 17.06989098], [77.47805786, 17.06098938], [77.48306274, 17.05344009], [77.486763, 17.04467964], [77.49186707, 17.03884125], [77.49323273, 17.0329895], [77.49199677, 17.02165031], [77.49819946, 17.01519966], [77.49938965, 17.0073204], [77.49357605, 17.0058403], [77.48323059, 16.99867821], [77.481987, 16.99719048], [77.47837067, 16.99024963], [77.47998047, 16.97517014], [77.47918701, 16.96803284], [77.47374725, 16.95947075], [77.46917725, 16.95384026], [77.46407318, 16.95269012], [77.46465302, 16.94637108], [77.46430206, 16.93980026], [77.4659729, 16.93457031], [77.46354675, 16.92904091], [77.46459961, 16.92489815], [77.46787262, 16.92419815], [77.46774292, 16.91711044], [77.46537018, 16.91407967], [77.4601059, 16.91292953], [77.45339966, 16.90903282], [77.45391846, 16.90627289], [77.45581818, 16.90465927], [77.45426178, 16.88612938], [77.45223999, 16.88159943], [77.45759583, 16.87928009], [77.46031189, 16.85453033], [77.46039581, 16.84411049], [77.45662689, 16.82374954], [77.45941162, 16.81776237], [77.46272278, 16.80451965], [77.46575928, 16.80083084], [77.47175598, 16.79628944], [77.47162628, 16.78518105], [77.471138, 16.77913094], [77.46733856, 16.77659988], [77.44454193, 16.78004265], [77.43753815, 16.78321075], [77.43527985, 16.77762032], [77.43721008, 16.76313019], [77.43534088, 16.74954987], [77.43128967, 16.73644066], [77.42784119, 16.72948265], [77.42569733, 16.72706032], [77.42633057, 16.72274971], [77.42755127, 16.72113991], [77.42672729, 16.71837997], [77.4241333, 16.71780014], [77.42341614, 16.71453094], [77.4254303, 16.71175957], [77.43000793, 16.71170044], [77.43325806, 16.70911026], [77.4373703, 16.70754814], [77.44541168, 16.71380043], [77.44845581, 16.71357918], [77.45627594, 16.71068954], [77.46103668, 16.71316147], [77.46679688, 16.71194077], [77.46877289, 16.70870972], [77.46746063, 16.70237923], [77.46750641, 16.69680023], [77.46504211, 16.67828178], [77.46170044, 16.67235947], [77.44642639, 16.67416], [77.43715668, 16.6665802], [77.41657257, 16.66281128], [77.41684723, 16.65475082], [77.42119598, 16.65199089], [77.42809296, 16.65007973], [77.43026733, 16.64472961], [77.43247223, 16.64306068], [77.43622589, 16.64253044], [77.43293762, 16.63763809], [77.43836975, 16.63620186], [77.44406128, 16.63579178], [77.44851685, 16.63883018], [77.45478058, 16.64487076], [77.46141815, 16.64883041], [77.46939087, 16.64691162], [77.47133636, 16.6435318], [77.46586609, 16.63594055], [77.46247101, 16.62920952], [77.4613266, 16.62478065], [77.45556641, 16.62001038], [77.4538269, 16.61379814], [77.45388031, 16.60741997], [77.46363068, 16.60481071], [77.4646759, 16.59744072], [77.46420288, 16.59514046], [77.46034241, 16.59555054], [77.45877838, 16.59205055], [77.46134186, 16.59065819], [77.46418762, 16.58719063], [77.46417236, 16.58420944], [77.46038055, 16.58346939], [77.45639038, 16.58099937], [77.44326019, 16.58205986], [77.43672943, 16.58120918], [77.42095947, 16.56517029], [77.41728973, 16.56390953], [77.40213013, 16.56629181], [77.39753723, 16.56335068], [77.39144135, 16.56520081], [77.39029694, 16.5597496], [77.39261627, 16.55945015], [77.39480591, 16.55824089], [77.39653778, 16.55554008], [77.39705658, 16.55289268], [77.4004364, 16.55023003], [77.40157318, 16.54677963], [77.41565704, 16.54400063], [77.41532135, 16.5178299], [77.41197968, 16.51381111], [77.40061188, 16.51595116], [77.39351654, 16.51486015], [77.38871002, 16.51210976], [77.38115692, 16.51153946], [77.37908173, 16.51072121], [77.37290192, 16.50601959], [77.36908722, 16.50210953], [77.36730957, 16.4937706], [77.36717224, 16.48693085], [77.36628723, 16.48410988], [77.35816956, 16.48315048], [77.35163116, 16.48332024], [77.34790039, 16.4855175], [77.3436203, 16.48488045], [77.34365845, 16.48205948], [77.32995605, 16.48069191], [77.32440948, 16.48093033], [77.31362152, 16.48755074], [77.30909729, 16.48933983], [77.29664612, 16.49147034], [77.29688263, 16.48588943], [77.29580688, 16.48134041], [77.29199982, 16.47363853], [77.28536224, 16.47151184], [77.25151062, 16.46790123], [77.24452209, 16.47221947], [77.23886108, 16.47290993], [77.23517609, 16.46808052], [77.25245667, 16.45329094], [77.25820923, 16.44730949], [77.26438904, 16.4300518], [77.26925659, 16.42308044], [77.27475739, 16.41773987], [77.27820587, 16.41070938], [77.28466034, 16.40299988], [77.29457855, 16.39960289], [77.30696869, 16.39402008], [77.33273315, 16.38829994], [77.34294891, 16.37972069], [77.35253906, 16.3766098], [77.37319946, 16.37992096], [77.38813782, 16.37179947], [77.40112305, 16.36602974], [77.41174316, 16.36268044], [77.42220306, 16.36284256], [77.42778015, 16.36507988], [77.43519592, 16.37267113], [77.43811035, 16.3744297], [77.44896698, 16.37580109], [77.46131134, 16.3754406], [77.48137665, 16.37776947], [77.49449158, 16.37578964], [77.51014709, 16.37018013], [77.51885986, 16.37010956], [77.52863312, 16.35836029], [77.53515625, 16.35293961], [77.54432678, 16.34975815], [77.54949188, 16.34468079], [77.55452728, 16.34156036], [77.57184601, 16.33595085], [77.58644104, 16.33793068], [77.59160614, 16.33751106], [77.58438873, 16.32804108], [77.5866394, 16.32044983], [77.5908432, 16.31197929], [77.59099579, 16.30461121], [77.58835602, 16.29565048], [77.59227753, 16.29010963], [77.59030151, 16.28685188], [77.58068085, 16.28606033], [77.57434082, 16.28894043], [77.56925964, 16.29477119], [77.56498718, 16.29771042], [77.54950714, 16.29067039], [77.54321289, 16.28705978], [77.53975677, 16.28263283], [77.53378296, 16.26263046], [77.52581787, 16.26702118], [77.52442169, 16.26978111], [77.51933289, 16.27088165], [77.51309204, 16.27071953], [77.50122833, 16.26781082], [77.50020599, 16.26068115], [77.49897003, 16.25786018], [77.48755646, 16.24982071], [77.48890686, 16.24183083], [77.4887619, 16.22434998], [77.49362183, 16.22302055], [77.50222778, 16.22478104], [77.51075745, 16.22333908], [77.51116943, 16.21718979], [77.50878143, 16.21494293], [77.50232697, 16.21570015], [77.49532318, 16.21300125], [77.49369812, 16.20617104], [77.49494171, 16.19535065], [77.49491882, 16.18712044], [77.4883728, 16.17868042], [77.48362732, 16.15855026], [77.48680878, 16.15307808], [77.48809814, 16.14739037], [77.48858643, 16.12646103], [77.48667145, 16.1157608], [77.49022675, 16.11615944], [77.49543762, 16.11465073], [77.50271606, 16.10947037], [77.50939941, 16.10353088], [77.50347137, 16.10152054], [77.49788666, 16.09721947], [77.4928894, 16.08377075], [77.4930191, 16.0796299], [77.50293732, 16.07323265], [77.49952698, 16.05426025], [77.49621582, 16.05477905], [77.49447632, 16.04977989], [77.4956665, 16.04771042], [77.49072266, 16.03063011], [77.49207306, 16.02556992], [77.49881744, 16.01716042], [77.4985733, 16.01389122], [77.50028229, 16.01135063], [77.5016861, 16.00554085], [77.51010895, 16.00225067], [77.50839996, 15.99582958], [77.50549316, 15.97876167], [77.50551605, 15.97266865], [77.50901031, 15.96744061], [77.51487732, 15.96315193], [77.51589966, 15.95746136], [77.51457977, 15.94342995], [77.50945282, 15.92086029], [77.49732208, 15.92630005], [77.48332214, 15.92805958], [77.46697998, 15.92758083], [77.45250702, 15.93152046], [77.43647766, 15.9390316], [77.42642212, 15.94227886], [77.42193604, 15.94129944], [77.41644287, 15.93796062], [77.40763092, 15.93565178], [77.40003204, 15.93546009], [77.3927002, 15.93676186], [77.38559723, 15.9344511], [77.3762207, 15.93325043], [77.36814117, 15.93604088], [77.35987091, 15.94155025], [77.35360718, 15.94370174], [77.33516693, 15.94327068], [77.31478882, 15.94519043], [77.30021667, 15.95049953], [77.29178619, 15.94996929], [77.28244781, 15.94736195], [77.26317596, 15.95138931], [77.25813293, 15.95397091], [77.24891663, 15.95774078], [77.2440567, 15.95676136], [77.23609161, 15.95271111], [77.22711945, 15.95160961], [77.21866608, 15.95164204], [77.20295715, 15.94987965], [77.18782806, 15.9507103], [77.18062592, 15.95006275], [77.17070007, 15.94554996], [77.15712738, 15.9444809], [77.14343262, 15.9406004], [77.13677216, 15.93621922], [77.12993622, 15.93039131], [77.12065887, 15.92882061], [77.10460663, 15.92453194], [77.09005737, 15.91786957], [77.07679749, 15.90974045], [77.06595612, 15.89931107], [77.05821228, 15.88716125], [77.05245209, 15.87628269], [77.04104614, 15.86395931], [77.03318787, 15.85308075], [77.02902985, 15.84490108], [77.0222702, 15.83178043], [77.02442169, 15.82948971], [77.02815247, 15.82559013], [77.03388214, 15.82439995], [77.03836823, 15.82551003], [77.04154205, 15.821661], [77.04991913, 15.82014275], [77.05226135, 15.82433891], [77.06388855, 15.82316971], [77.06151581, 15.79792118], [77.06723785, 15.79605007], [77.06247711, 15.77839088], [77.05976868, 15.77884007], [77.05660248, 15.77228069], [77.0537262, 15.76364994], [77.04972076, 15.76410103], [77.04850769, 15.76076031], [77.05316925, 15.75887966], [77.05171967, 15.7501297], [77.04669189, 15.75133133], [77.04322815, 15.73448181], [77.04724884, 15.73317146], [77.04708862, 15.72501183], [77.06299591, 15.72367191], [77.07627106, 15.72141075], [77.0762558, 15.71037102], [77.08436584, 15.70895958], [77.08164978, 15.69533062], [77.07792664, 15.69336128], [77.07592773, 15.69087887], [77.10083771, 15.67887974], [77.110466, 15.67126274], [77.1190567, 15.66208935], [77.12497711, 15.65905094], [77.1209259, 15.63720131], [77.11620331, 15.62510967], [77.10389709, 15.63393116], [77.10056305, 15.63916111], [77.09593201, 15.64414978], [77.08889771, 15.64752102], [77.08143616, 15.65284061], [77.06887054, 15.64090919], [77.03601074, 15.6323719], [77.03266144, 15.63200855], [77.02928162, 15.63383865], [77.02710724, 15.62934971], [77.02839661, 15.60684967], [77.02889252, 15.59825993], [77.02443695, 15.58436203], [77.02371216, 15.57638168], [77.028862, 15.52512169], [77.02874756, 15.50856018], [77.02659607, 15.49999046], [77.00543213, 15.50277138], [76.99603271, 15.49973106], [76.99085236, 15.50107098], [76.98165131, 15.50477028], [76.97189331, 15.50633144], [76.97013855, 15.49495125], [76.97039032, 15.49092197], [76.97608185, 15.48201275], [76.98898315, 15.47315121], [76.9960022, 15.46745968], [77.00074005, 15.46170139], [77.00203705, 15.45538139], [77.00609589, 15.44823074], [77.01528168, 15.4410696], [77.02384186, 15.43856144], [77.02739716, 15.43518066], [77.03048706, 15.42633057], [77.03100586, 15.41833973], [77.0268631, 15.40775204], [77.02854156, 15.40130234], [77.03325653, 15.39626026], [77.041008, 15.39151001], [77.04382324, 15.38374138], [77.04228973, 15.37479973], [77.03803253, 15.35878181], [77.04260254, 15.35224056], [77.05784607, 15.34319019], [77.06289673, 15.3379097], [77.0631485, 15.32808018], [77.06157684, 15.32186031], [77.0690918, 15.31947136], [77.09929657, 15.32662106], [77.10968781, 15.32728195], [77.11023712, 15.32073021], [77.11342621, 15.31912041], [77.11541748, 15.28985023], [77.12374878, 15.28757], [77.13883972, 15.28547955], [77.14791107, 15.28567028], [77.14872742, 15.27785015], [77.14803314, 15.27095127], [77.14491272, 15.26928043], [77.14517212, 15.26605129], [77.14985657, 15.26693058], [77.15766907, 15.26037979], [77.16414642, 15.2590704], [77.16525269, 15.25097179], [77.1579361, 15.2513504], [77.14668274, 15.25029087], [77.14025116, 15.25155067], [77.13265991, 15.2346096], [77.12345886, 15.23332024], [77.12090302, 15.221241], [77.14138031, 15.21813202], [77.14707947, 15.20880985], [77.14996338, 15.207901], [77.15577698, 15.19433975], [77.15815735, 15.19382], [77.16153717, 15.18221092], [77.16448212, 15.16847038], [77.16320038, 15.16133118], [77.15879059, 15.15786934], [77.1592865, 15.15212059], [77.15770721, 15.14895058], [77.15305328, 15.14882088], [77.14549255, 15.15070057], [77.13697052, 15.14925194], [77.13208008, 15.14268112], [77.13536072, 15.13601017], [77.15276337, 15.13162136], [77.15403748, 15.12052059], [77.14771271, 15.10733032], [77.13938904, 15.09988117], [77.12760925, 15.09364128], [77.12552643, 15.06820965], [77.12091064, 15.05507088], [77.11839294, 15.05063057], [77.11606598, 15.04010201], [77.11161041, 15.03812981], [77.10957336, 15.02856922], [77.10167694, 15.02734089], [77.09078217, 15.02772236], [77.08825684, 15.02303791], [77.0820694, 15.02229023], [77.08049774, 15.00791073], [77.07881927, 15.00000954], [77.06858826, 15.00111008], [77.06147003, 15.00154972], [77.05092621, 15.00428963], [77.041008, 15.00548172], [77.04638672, 15.01601791], [77.04878998, 15.02386093], [77.04688263, 15.029212], [77.0374527, 15.02757072], [77.02295685, 15.02765083], [77.0092926, 15.02958107], [77.00067902, 15.02958965], [76.99862671, 15.02706146], [76.99565125, 15.02368069], [76.98351288, 15.02042198], [76.98178101, 15.01036072], [76.96679688, 15.01316929], [76.95066833, 15.02443123], [76.94274902, 15.02703094], [76.93167114, 15.02631092], [76.9193573, 15.02852154], [76.91352081, 15.03095055], [76.90544128, 15.0292902], [76.89620972, 15.03188133], [76.88868713, 15.03175068], [76.87670135, 15.02867889], [76.86975098, 15.0440197], [76.86406708, 15.05000019], [76.86057281, 15.05671024], [76.84320831, 15.06615925], [76.83740997, 15.07246971], [76.82943726, 15.07429123], [76.82126617, 15.07485199], [76.81188202, 15.08023071], [76.79693604, 15.09076023], [76.78756714, 15.08043957], [76.78423309, 15.08078003], [76.78224945, 15.07882023], [76.78391266, 15.07567024], [76.7786026, 15.0715704], [76.77636719, 15.07329273], [76.77422333, 15.07138062], [76.77574158, 15.06916142], [76.77256012, 15.06511974], [76.77082062, 15.05828857], [76.77112579, 15.05409145], [76.77501678, 15.04395962], [76.78079224, 15.03423977], [76.78179169, 15.02332973], [76.78457642, 15.01667023], [76.77974701, 15.00588989], [76.76953125, 15.00058174], [76.76805878, 14.9956398], [76.76622009, 14.99081135], [76.7651825, 14.98906136], [76.76235962, 14.9894619], [76.7592392, 14.98507023], [76.75698853, 14.98297119], [76.75863647, 14.97946072], [76.76185608, 14.97528076], [76.76377106, 14.96986961], [76.7720871, 14.96864033], [76.79688263, 14.96292114], [76.81545258, 14.96380997], [76.82028198, 14.95917034], [76.82364655, 14.95361137], [76.82789612, 14.95100975], [76.83255005, 14.95348072], [76.83587646, 14.9590807], [76.84115601, 14.96117115], [76.86445618, 14.96401978], [76.86367035, 14.95521069], [76.86547852, 14.93760014], [76.86348724, 14.91564274], [76.86389923, 14.91174126], [76.86271667, 14.90176964], [76.86030579, 14.89118958], [76.846138, 14.89033127], [76.84377289, 14.88642025], [76.84326172, 14.88147163], [76.84905243, 14.87993145], [76.85087585, 14.87285042], [76.85167694, 14.86252117], [76.85411835, 14.86137199], [76.84938812, 14.83869934], [76.84436035, 14.83325195], [76.84008789, 14.83004093], [76.84026337, 14.82807159], [76.84298706, 14.82430172], [76.8444519, 14.81559086], [76.84854126, 14.81425095], [76.84960175, 14.81180954], [76.84873962, 14.80403137], [76.8469162, 14.80231094], [76.83721161, 14.80414104], [76.83496857, 14.8001318], [76.83377075, 14.78490925], [76.83136749, 14.78411198], [76.82641602, 14.78698063], [76.82073212, 14.78660965], [76.81735229, 14.78544044], [76.81671143, 14.78249073], [76.81096649, 14.7814312], [76.78034973, 14.77926159], [76.78128815, 14.77433014], [76.78642273, 14.76191139], [76.78813934, 14.75184059], [76.79502869, 14.74113178], [76.79807281, 14.73459053], [76.78553772, 14.70709133], [76.78108215, 14.6904707], [76.77127838, 14.67383957], [76.76950836, 14.65631104], [76.7629776, 14.61192131], [76.76017761, 14.60201073], [76.76091003, 14.59628105], [76.77275085, 14.58720112], [76.77435303, 14.59057045], [76.77628326, 14.59033012], [76.77815247, 14.5793314], [76.78405762, 14.56198025], [76.78617096, 14.55305958], [76.79469299, 14.54073048], [76.79972839, 14.5277319], [76.80509186, 14.52487087], [76.81089783, 14.5237999], [76.81973267, 14.52033997], [76.82758331, 14.52305889], [76.82842255, 14.52224064], [76.83207703, 14.51507092], [76.84393311, 14.50914955], [76.85421753, 14.49888039], [76.86044312, 14.48713112], [76.86380768, 14.47467136], [76.87020111, 14.46844006], [76.88030243, 14.47052956], [76.88549042, 14.4759407], [76.89427185, 14.48075199], [76.90651703, 14.48416138], [76.94541168, 14.48215103], [76.95580292, 14.47958946], [76.96909332, 14.47908974], [76.9733963, 14.47828102], [76.97419739, 14.47036076], [76.96437073, 14.45174122], [76.95858765, 14.4453907], [76.94378662, 14.44510174], [76.94271088, 14.43984127], [76.94432068, 14.42523193], [76.94467926, 14.40892029], [76.94359589, 14.40326118], [76.94156647, 14.39954185], [76.93678284, 14.40130997], [76.9189682, 14.41145039], [76.9131012, 14.41355228], [76.90116119, 14.3983202], [76.89663696, 14.39447975], [76.89232635, 14.3928709], [76.88677979, 14.39245129], [76.88314056, 14.39029121], [76.87861633, 14.35139275], [76.87909698, 14.34638977], [76.88536072, 14.33959103], [76.89897156, 14.31924057], [76.90615845, 14.315341], [76.91680908, 14.31225967], [76.92314911, 14.30965042], [76.93656158, 14.30840969], [76.94293976, 14.30537891], [76.94670105, 14.30044937], [76.95011139, 14.29402924], [76.9487381, 14.28676128], [76.9437561, 14.28168106], [76.93548584, 14.27664185], [76.92485809, 14.27218056], [76.92582703, 14.26439953], [76.9336319, 14.25350094], [76.93598938, 14.24877167], [76.93784332, 14.24012089], [76.94346619, 14.23631001], [76.95139313, 14.23415184], [76.96157074, 14.23590183], [76.96971893, 14.23521137], [76.97560883, 14.23742008], [76.98248291, 14.23815155], [76.98937988, 14.2364006], [76.99279022, 14.23298931], [76.99456024, 14.23556042], [77.00411987, 14.23156929], [77.01251221, 14.23509121], [77.02458954, 14.23668098], [77.03304291, 14.24048996], [77.04064941, 14.2407589], [77.04962921, 14.23954201], [77.05532074, 14.23230076], [77.06022644, 14.22416019], [77.06761932, 14.21786022], [77.07534027, 14.20934963], [77.08486938, 14.20845032], [77.09522247, 14.20948029], [77.10507965, 14.21328163], [77.1099472, 14.22148037], [77.110466, 14.23198032], [77.11299896, 14.23991966], [77.1115799, 14.24846172], [77.11551666, 14.25681973], [77.10692596, 14.26176071], [77.1105423, 14.27493], [77.11192322, 14.2875309], [77.11730957, 14.29141045], [77.12577057, 14.30153179], [77.13092804, 14.31381035], [77.13262939, 14.32404995], [77.13191986, 14.3305912], [77.13553619, 14.33401203], [77.14054108, 14.33611107], [77.14644623, 14.33219147], [77.15215302, 14.3377409], [77.15975952, 14.33623886], [77.16422272, 14.33046055], [77.17188263, 14.33023071], [77.17674255, 14.32629013], [77.17951202, 14.32637024], [77.19635773, 14.31429958], [77.20979309, 14.31301022], [77.22292328, 14.31498146], [77.23195648, 14.31107044], [77.24508667, 14.31453037], [77.251297, 14.32060242], [77.25785065, 14.32570171], [77.26732635, 14.32701015], [77.2733078, 14.33175087], [77.28114319, 14.33111095], [77.2826767, 14.30228043], [77.28189087, 14.29045963], [77.27958679, 14.27608967], [77.28549957, 14.27474976], [77.29545593, 14.27647114], [77.30748749, 14.27383995], [77.32058716, 14.27345085], [77.34336853, 14.27052021], [77.35340881, 14.27067947], [77.35926056, 14.26933002], [77.35826874, 14.26032066], [77.35923767, 14.24360085], [77.35540771, 14.2300396], [77.36431122, 14.22331047], [77.37661743, 14.216712], [77.38162231, 14.21018028], [77.38011169, 14.20255089], [77.38378906, 14.1918211], [77.39122009, 14.19088173], [77.41487885, 14.20322132], [77.41570282, 14.21196175], [77.41470337, 14.21706009], [77.40905762, 14.22358131], [77.40618134, 14.23671055], [77.40479279, 14.24860096], [77.40101624, 14.26041031], [77.38986969, 14.26138973], [77.38433838, 14.26561069], [77.38504791, 14.27245045], [77.3812027, 14.28299141], [77.37500763, 14.2951889], [77.37386322, 14.30510998], [77.37882233, 14.31707954], [77.38565826, 14.32487011], [77.39488983, 14.32915974], [77.4092865, 14.32710171], [77.42072296, 14.32199192], [77.4258728, 14.32081127], [77.42752838, 14.30484962], [77.44233704, 14.30975056], [77.44243622, 14.29091072], [77.4436264, 14.2775507], [77.45469666, 14.27219009], [77.46842957, 14.27943993], [77.47912598, 14.283741], [77.47934723, 14.28477097], [77.48439026, 14.27525997], [77.49214172, 14.27128124], [77.4962616, 14.2717514], [77.49936676, 14.26051044], [77.49878693, 14.24954033], [77.49627686, 14.24040985], [77.49008179, 14.22763062], [77.49285126, 14.22006035], [77.49308777, 14.21397018], [77.49971008, 14.20446968], [77.50108337, 14.19322109], [77.50414276, 14.18066025], [77.5094223, 14.17695045], [77.51035309, 14.17201996], [77.50679016, 14.16424084], [77.50267029, 14.1571207], [77.5004425, 14.15096092], [77.48854065, 14.15307999], [77.46333313, 14.16423035], [77.45392609, 14.16298103], [77.42347717, 14.16508007], [77.41631317, 14.16930103], [77.40972137, 14.1697197], [77.39745331, 14.16650009], [77.3897171, 14.16526031], [77.38955688, 14.15354061], [77.38262177, 14.14772034], [77.37873077, 14.13827991], [77.3766861, 14.12960052], [77.36501312, 14.12710953], [77.3548584, 14.12374973], [77.34773254, 14.12434101], [77.34651184, 14.1178503], [77.34651184, 14.11044025], [77.34453583, 14.09601116], [77.34851074, 14.09926128], [77.35246277, 14.10535145], [77.3589325, 14.10872173], [77.37325287, 14.1125803], [77.38035583, 14.1166296], [77.38973999, 14.11857033], [77.39444733, 14.11464119], [77.39643097, 14.11056995], [77.39544678, 14.10344124], [77.38568115, 14.09346104], [77.37966156, 14.09039116], [77.37238312, 14.07185173], [77.36136627, 14.06595135], [77.35855865, 14.05892944], [77.35012054, 14.05338192], [77.33796692, 14.0538311], [77.33454895, 14.04779053], [77.33126068, 14.03984165], [77.32618713, 14.02293968], [77.34406281, 14.01906013], [77.35009766, 14.01645088], [77.36232758, 14.01599026], [77.37507629, 14.01210022], [77.38336182, 14.00735855], [77.37988281, 13.99328136], [77.37320709, 13.98171043], [77.37269592, 13.9755106], [77.37565613, 13.96911144], [77.38651276, 13.97400188], [77.41018677, 13.97692204], [77.42050171, 13.97687054], [77.42661285, 13.97328186], [77.43064117, 13.96877956], [77.43090057, 13.96199131], [77.42904663, 13.9563818], [77.42870331, 13.94334126], [77.4225769, 13.93900108], [77.40770721, 13.93610001], [77.40843964, 13.92161083], [77.41015625, 13.91460133], [77.42250061, 13.91195011], [77.42740631, 13.90921974], [77.42562866, 13.90205193], [77.4189682, 13.89490891], [77.4085083, 13.88881016], [77.39705658, 13.88054085], [77.39626312, 13.88044071], [77.39186096, 13.87989044], [77.39041901, 13.89768982], [77.35884857, 13.89556122], [77.3483429, 13.89654064], [77.34590149, 13.9033308], [77.34350586, 13.90598106], [77.34261322, 13.91224194], [77.35263824, 13.92845058], [77.36260986, 13.9423008], [77.36200714, 13.9454689], [77.34374237, 13.95089245], [77.34720612, 13.95535183], [77.34693909, 13.96058941], [77.35338593, 13.97628975], [77.35378265, 13.98232079], [77.34567261, 13.98558044], [77.33347321, 13.98805141], [77.3303299, 13.99035931], [77.32977295, 13.99335194], [77.32966614, 13.99335194], [77.33011627, 13.99488068], [77.32409668, 14.00531006], [77.32022095, 14.00925064], [77.31700897, 14.01532269], [77.31648254, 14.02145958], [77.31349182, 14.02482033], [77.30355835, 14.02672958], [77.29802704, 14.02303123], [77.2922821, 14.01449966], [77.28518677, 14.01152992], [77.27851105, 14.00690079], [77.2726059, 14.0080204], [77.27420807, 14.01618195], [77.27150726, 14.02810192], [77.26451874, 14.02652931], [77.25575256, 14.0209589], [77.24256897, 14.00631142], [77.22727203, 14.00795174], [77.21884918, 14.00791073], [77.20767975, 14.00487137], [77.19455719, 14.00286007], [77.17138672, 14.00859928], [77.16168976, 14.00624943], [77.16278076, 13.99775982], [77.15815735, 13.99351978], [77.15836334, 13.99351978], [77.15444183, 13.99061012], [77.14733887, 13.99162197], [77.14459991, 13.99351978], [77.14437103, 13.99351978], [77.13949585, 13.99719048], [77.13434601, 13.9981308], [77.13288116, 14.00421047], [77.1340332, 14.00967026], [77.12783051, 14.01865005], [77.12468719, 14.0347414], [77.12110138, 14.04218006], [77.1101532, 14.04204082], [77.10396576, 14.04057121], [77.0966568, 14.04070091], [77.09075928, 14.03826046], [77.07649231, 14.0380497], [77.06952667, 14.03944111], [77.06903076, 14.04718971], [77.05120087, 14.04959202], [77.04322052, 14.05167007], [77.0348587, 14.05144024], [77.02848053, 14.05198002], [77.0236969, 14.0532589], [77.02024078, 14.06144142], [77.02453613, 14.07716942], [77.02398682, 14.08337116], [77.01470947, 14.08869934], [77.01043701, 14.0920496], [77.00831604, 14.09813118], [77.0165863, 14.10609245], [77.01703644, 14.11195087], [77.01635742, 14.11752129], [77.0202713, 14.12232113], [77.01920319, 14.12529087], [77.01380157, 14.12740135], [77.01493835, 14.13218117], [77.01600647, 14.15269089], [77.02105713, 14.16432953], [77.02133942, 14.16839886], [77.0198288, 14.17270184], [77.01403809, 14.17304134], [77.00605011, 14.17485142], [76.9943924, 14.17374992], [76.98626709, 14.17253113], [76.97818756, 14.17292023], [76.97276306, 14.1742897], [76.96568298, 14.17432022], [76.95849609, 14.17550945], [76.95378113, 14.18103027], [76.94908142, 14.18381023], [76.94404602, 14.18832016], [76.94164276, 14.18931198], [76.9392395, 14.18680859], [76.94153595, 14.17803001], [76.93924713, 14.1677103], [76.9369812, 14.16589165], [76.922966, 14.1633997], [76.91718292, 14.15767097], [76.89675903, 14.16190147], [76.89142609, 14.15899944], [76.88919067, 14.15087891], [76.88691711, 14.13624001], [76.88368225, 14.13103199], [76.89090729, 14.127841], [76.89846802, 14.12687969], [76.9125061, 14.12210941], [76.91712952, 14.12448025], [76.92241669, 14.12903976], [76.92697906, 14.12720966], [76.93739319, 14.11515141], [76.94291687, 14.11190128], [76.94658661, 14.10297108], [76.94822693, 14.09658146], [76.94854736, 14.09141159], [76.94629669, 14.08526039], [76.95143127, 14.08537197], [76.96012115, 14.08296967], [76.96808624, 14.07973957], [76.97184753, 14.07571125], [76.97225189, 14.06840134], [76.9750061, 14.06527042], [76.97421265, 14.05770969], [76.9715271, 14.05239105], [76.94972992, 14.04784107], [76.94328308, 14.04721928], [76.93797302, 14.04759979], [76.93371582, 14.04067135], [76.93109894, 14.02273178], [76.94078064, 14.02060127], [76.94232941, 14.01548004], [76.9447403, 14.0106802], [76.94857025, 14.00677967], [76.96420288, 14.00224018], [76.97518158, 13.99658966], [76.97764587, 13.99386024], [76.97734833, 13.99387074], [76.98501587, 13.98752022], [76.99437714, 13.98149109], [76.99133301, 13.97581196], [76.99019623, 13.97027969], [76.98899841, 13.95669174], [76.99433136, 13.95337963], [76.99505615, 13.9527216], [76.99942017, 13.95044041], [77.00810242, 13.94736958], [77.01397705, 13.93948174], [77.01860046, 13.93479156], [77.0358429, 13.92559147], [77.04128265, 13.8973999], [77.02780914, 13.89717007], [77.01728058, 13.89337063], [77.01661682, 13.88772964], [77.01169586, 13.87144089], [77.01259613, 13.86723995], [77.01230621, 13.86409092], [77.00802612, 13.86290073], [77.00711823, 13.85417175], [77.00598907, 13.85009003], [76.994133, 13.83897018], [76.9899292, 13.83950996], [76.98625946, 13.83922958], [76.9839859, 13.82774067], [76.97653961, 13.82136059], [76.97155762, 13.81886101], [76.96839142, 13.81439018], [76.96882629, 13.8102417], [76.98002625, 13.80719185], [76.98371887, 13.80418968], [76.98577881, 13.79300022], [76.98484802, 13.78870106], [76.98123169, 13.78579998], [76.98435974, 13.77657032], [76.98634338, 13.76652145], [76.98898315, 13.76018047], [76.99012756, 13.7530899], [76.99212646, 13.74950886], [76.99167633, 13.7453413], [76.99259186, 13.74255085], [76.993927, 13.74151039], [77.00193787, 13.73666191], [77.0114212, 13.73272133], [77.01384735, 13.74747181], [77.01844025, 13.76169968], [77.01986694, 13.76986027], [77.02636719, 13.77144146], [77.03518677, 13.76928139], [77.04734802, 13.75607967], [77.05474854, 13.74450016], [77.06004333, 13.73886108], [77.07148743, 13.73875046], [77.08058929, 13.73739147], [77.07927704, 13.74602032], [77.08036041, 13.75342274], [77.08521271, 13.75455093], [77.08577728, 13.758111], [77.09526825, 13.76088047], [77.11094666, 13.75462055], [77.1235199, 13.75089073], [77.1341095, 13.75303078], [77.13751984, 13.75565243], [77.14673615, 13.75475121], [77.15815735, 13.75493145], [77.1665802, 13.75466919], [77.16964722, 13.76136971], [77.17134094, 13.7720499], [77.16918945, 13.77556038], [77.16407013, 13.78035069], [77.15849304, 13.78710079], [77.15599823, 13.79331017], [77.15573883, 13.79814243], [77.15409851, 13.8005619], [77.15632629, 13.80375957], [77.15537262, 13.80739021], [77.15619659, 13.81134033], [77.16194153, 13.81546116], [77.1622467, 13.8207407], [77.15791321, 13.82547092], [77.14789581, 13.82885075], [77.14576721, 13.83493996], [77.14045715, 13.83788967], [77.12526703, 13.8430109], [77.12388611, 13.84939003], [77.13015747, 13.84993935], [77.13938904, 13.85904026], [77.14821625, 13.85980129], [77.16249084, 13.85698032], [77.16491699, 13.86621857], [77.1623764, 13.87629128], [77.16171265, 13.88243103], [77.15702057, 13.89130116], [77.15593719, 13.89981174], [77.15956116, 13.90846062], [77.17006683, 13.91634178], [77.17703247, 13.91740036], [77.18161774, 13.91077042], [77.18221283, 13.90130043], [77.18134308, 13.89118958], [77.17920685, 13.88328075], [77.17959595, 13.87833118], [77.17822266, 13.8713913], [77.17513275, 13.8614006], [77.17880249, 13.85984039], [77.19271088, 13.8562212], [77.19689178, 13.85953045], [77.20095825, 13.86651993], [77.20256805, 13.87484074], [77.2049408, 13.88116074], [77.20884705, 13.87843132], [77.20812225, 13.86040115], [77.2115097, 13.86141872], [77.21700287, 13.86926174], [77.22093201, 13.8817606], [77.22189331, 13.88883114], [77.22547913, 13.89546967], [77.23384094, 13.89493179], [77.24009705, 13.89408016], [77.24156189, 13.88885117], [77.23882294, 13.88150978], [77.23925018, 13.87359047], [77.24073792, 13.86588192], [77.24373627, 13.86029053], [77.2530365, 13.85612106], [77.2504425, 13.83947086], [77.25595093, 13.83945084], [77.27514648, 13.84280109], [77.28292847, 13.84097958], [77.28552246, 13.84603119], [77.28970337, 13.85002232], [77.29602814, 13.8535614], [77.30693054, 13.85723972], [77.31088257, 13.85113144], [77.31616211, 13.83973122], [77.32000732, 13.8257513], [77.32724762, 13.82479191], [77.33468628, 13.82942009], [77.3398819, 13.83484936], [77.34697723, 13.83958054], [77.35220337, 13.84438133], [77.35946655, 13.8456707], [77.36753845, 13.84320927], [77.3731308, 13.83819103], [77.37285614, 13.83128929], [77.38111115, 13.83125114], [77.38983917, 13.83292961], [77.39920044, 13.83242035], [77.40393066, 13.83142185], [77.41873932, 13.83353043], [77.42453003, 13.83512974], [77.42624664, 13.82973003], [77.42472076, 13.82668972], [77.41506195, 13.81536007], [77.41275787, 13.81175041], [77.41368103, 13.80738068], [77.40820313, 13.80247021], [77.40866089, 13.79925156], [77.41158295, 13.79889107], [77.41470337, 13.80019093], [77.41925812, 13.79971027], [77.41954041, 13.79580116], [77.41689301, 13.79094028], [77.4200592, 13.78896141], [77.42865753, 13.78798962], [77.43546295, 13.79923058], [77.44056702, 13.80229187], [77.44676971, 13.80202961], [77.45559692, 13.79981041], [77.45745087, 13.79705048], [77.4527359, 13.79131985], [77.45079041, 13.78553104], [77.45240021, 13.78040123], [77.4539566, 13.77804184], [77.4587326, 13.74981022], [77.46212006, 13.74905109], [77.46261597, 13.74357891], [77.46006012, 13.73388958], [77.45809937, 13.73033047], [77.45806885, 13.72303867], [77.45684814, 13.71263981], [77.45340729, 13.70409966], [77.44600677, 13.70063972], [77.44481659, 13.69576073], [77.44975281, 13.67579079], [77.47648621, 13.67759991], [77.48294067, 13.67970181], [77.48513794, 13.68669033], [77.48352051, 13.69170094], [77.48239899, 13.6988306], [77.47972107, 13.70321083], [77.48734283, 13.70679188], [77.50276947, 13.7044096], [77.50679016, 13.70047092], [77.50691986, 13.69266129], [77.50797272, 13.68879986], [77.5123291, 13.68568039], [77.52152252, 13.68787003], [77.5255661, 13.69721031], [77.52783966, 13.70703125], [77.52754211, 13.71903038], [77.52659607, 13.72525024], [77.52268982, 13.73107147], [77.51512146, 13.73703957], [77.51966858, 13.74384975], [77.52950287, 13.74585056], [77.53951263, 13.74372005], [77.54155731, 13.73493195], [77.54514313, 13.72818089], [77.54814148, 13.72040939], [77.55607605, 13.71646023], [77.56661987, 13.72938919], [77.57363129, 13.72665024], [77.58154297, 13.73057175], [77.5868988, 13.7367897], [77.59559631, 13.74357891], [77.60427094, 13.74255085], [77.61564636, 13.72836113], [77.62124634, 13.72740173], [77.62851715, 13.72994137], [77.63356018, 13.73283958], [77.63674927, 13.73524189], [77.63375092, 13.74129105], [77.61264801, 13.74687004], [77.610466, 13.75543976], [77.61434937, 13.76031017], [77.649086, 13.77583981], [77.65659332, 13.77666092], [77.66401672, 13.77587032], [77.67022705, 13.7774992], [77.67176819, 13.77013111], [77.66979218, 13.76255989], [77.66371155, 13.75226021], [77.66850281, 13.75228119], [77.67881775, 13.75568104], [77.68467712, 13.75862122], [77.69552612, 13.76143169], [77.70218658, 13.73099136], [77.70736694, 13.73418045], [77.70874786, 13.73273945], [77.71100616, 13.73771], [77.71346283, 13.74615002], [77.7131424, 13.75074005], [77.71420288, 13.76079082], [77.7127533, 13.7747097], [77.71512604, 13.78327179], [77.71286011, 13.79051971], [77.71849823, 13.79272175], [77.72841644, 13.80173969], [77.7335968, 13.80344105], [77.74102783, 13.803792], [77.74817657, 13.80620956], [77.75533295, 13.80754089], [77.76921082, 13.8085413], [77.77848816, 13.81289196], [77.78044128, 13.8166914], [77.78026581, 13.82002068], [77.77742767, 13.82406044], [77.77410126, 13.83173084], [77.77603912, 13.8359108], [77.78637695, 13.83992004], [77.79453278, 13.84095955], [77.80278015, 13.84066963], [77.80784607, 13.8466711], [77.81080627, 13.85211182], [77.82772064, 13.86061954], [77.81920624, 13.86602116], [77.82724762, 13.87160015], [77.82504272, 13.87990093], [77.82099152, 13.88923168], [77.81468964, 13.89111042], [77.81108093, 13.89470196], [77.80737305, 13.90322971], [77.80635834, 13.90864086], [77.80635071, 13.91755009], [77.80848694, 13.9225893], [77.81423187, 13.93100166], [77.81829071, 13.93488121], [77.82158661, 13.93054104], [77.83011627, 13.92715168], [77.84600067, 13.92832088], [77.85407257, 13.9270792], [77.86242676, 13.92680073], [77.88698578, 13.93118191], [77.88786316, 13.92772198], [77.88732147, 13.91774082], [77.88968658, 13.9113512], [77.89570618, 13.90771961], [77.90045166, 13.90234089], [77.90593719, 13.89945126], [77.91160583, 13.89724064], [77.91980743, 13.89870167], [77.92973328, 13.90880966], [77.93564606, 13.91790962], [77.93885803, 13.92461967], [77.94602203, 13.92843056], [77.9490509, 13.92673969], [77.95075989, 13.92792034], [77.95426941, 13.93704987], [77.95532227, 13.94190025], [77.96127319, 13.9499712], [77.96643066, 13.95055199], [77.97857666, 13.94765091], [77.97795105, 13.93762016], [77.97351074, 13.92422962], [77.97336578, 13.91988182], [77.97460175, 13.91225147], [77.97466278, 13.90533161], [77.97802734, 13.89334965], [77.97161865, 13.88858891], [77.9495163, 13.88447094], [77.94246674, 13.8802309], [77.94184113, 13.87105083], [77.94571686, 13.83980179], [77.94805145, 13.82936096], [77.94814301, 13.82480145], [77.94458008, 13.81997108], [77.96578217, 13.82015991], [77.97038269, 13.82664204], [77.98123932, 13.84879971], [77.98226929, 13.85680199], [77.98516083, 13.86166954], [77.99149323, 13.86241055], [78.004776, 13.86171055], [78.01033783, 13.85649014], [78.01558685, 13.85438156], [78.03782654, 13.85284996], [78.04133606, 13.8580513], [78.04292297, 13.86378098], [78.04270172, 13.87337971], [78.04115295, 13.88672924], [78.04831696, 13.88453007], [78.05471039, 13.87935162], [78.06034851, 13.87678146], [78.06796265, 13.8745203], [78.07092285, 13.87195969], [78.07491302, 13.85491943], [78.08837891, 13.85491943], [78.09736633, 13.85276127], [78.10604095, 13.85354137], [78.11353302, 13.84089088], [78.11725616, 13.82177162], [78.10765839, 13.80360031], [78.10900116, 13.79836273], [78.11517334, 13.78767967], [78.11823273, 13.77690029], [78.11100769, 13.76175117], [78.10649872, 13.75679111], [78.10119629, 13.75298977], [78.09532166, 13.75028038], [78.08927155, 13.74304962], [78.08492279, 13.7334919], [78.09327698, 13.72762108], [78.09738922, 13.72315121], [78.10044098, 13.71801186], [78.1055069, 13.71463203], [78.10938263, 13.71023083], [78.10988617, 13.70395184], [78.10721588, 13.69835186], [78.1053772, 13.68440056], [78.09986877, 13.68256187], [78.08515167, 13.68063164], [78.0640564, 13.68817997], [78.06260681, 13.68560028], [78.06537628, 13.68006039], [78.06408691, 13.67455959], [78.06092072, 13.6717701], [78.05834198, 13.66697025], [78.06585693, 13.6644907], [78.07280731, 13.65517139], [78.07998657, 13.65038967], [78.07965851, 13.64454174], [78.08072662, 13.63534069], [78.08634949, 13.63350105], [78.09060669, 13.63300037], [78.09390259, 13.6402607], [78.10736084, 13.64709187], [78.1158905, 13.64563084], [78.12322998, 13.64890099], [78.12908936, 13.64826965], [78.14617157, 13.64966011], [78.15576172, 13.64871025], [78.15899658, 13.64517117], [78.16053772, 13.62343025], [78.16555786, 13.62097073], [78.18583679, 13.62117958], [78.19393921, 13.61615944], [78.19536591, 13.6015501], [78.19374084, 13.59490204], [78.18856812, 13.58840179], [78.17946625, 13.57894135], [78.18105316, 13.5737009], [78.18012238, 13.56417179], [78.18161011, 13.5591507], [78.18327332, 13.55638027], [78.18900299, 13.55638027], [78.19583893, 13.56068134], [78.20240021, 13.56796932], [78.20849609, 13.58188057], [78.21479034, 13.58010101], [78.21840668, 13.57800198], [78.22261047, 13.57709026], [78.22769165, 13.58722115], [78.23655701, 13.58449078], [78.24967957, 13.57430077], [78.25827026, 13.57530975], [78.26539612, 13.57822132], [78.28058624, 13.577672], [78.2918396, 13.57882023], [78.31247711, 13.58350182], [78.3228302, 13.58299065], [78.34366608, 13.57778072], [78.36139679, 13.57887268], [78.36709595, 13.58030033], [78.38031769, 13.58130932], [78.39076233, 13.5781002], [78.39389801, 13.57065201], [78.39775848, 13.56619167], [78.38600922, 13.54395199], [78.38546753, 13.53166962], [78.37309265, 13.5122509], [78.37419128, 13.50551033], [78.36958313, 13.49993038], [78.36728668, 13.49517155], [78.36828613, 13.48976994], [78.3674469, 13.48197079], [78.36728668, 13.46685123], [78.3635788, 13.45924091], [78.36255646, 13.45207119], [78.36419678, 13.44561195], [78.36416626, 13.43791103], [78.36463165, 13.43685055], [78.36702728, 13.4312706], [78.36531067, 13.42439079], [78.3673172, 13.41500092], [78.36946106, 13.40894985], [78.37127686, 13.3971796], [78.37127686, 13.39100075], [78.36871338, 13.37981129], [78.36444855, 13.37049103], [78.3598175, 13.36432171], [78.35515594, 13.35507107], [78.35640717, 13.34671974], [78.35839844, 13.34684086], [78.36051178, 13.34696198], [78.3640213, 13.34830189], [78.36818695, 13.34831142], [78.37477112, 13.3464098], [78.38366699, 13.34235096], [78.38491058, 13.33820057], [78.39253235, 13.33554077], [78.39737701, 13.33233166], [78.39523315, 13.32256985], [78.39125061, 13.32371044], [78.38838959, 13.31845188], [78.38456726, 13.32354069], [78.37899017, 13.32452106], [78.3753891, 13.32640171], [78.37754059, 13.33131981], [78.37129211, 13.33240891], [78.36791229, 13.3284893], [78.36699677, 13.32003975], [78.37512207, 13.31859112], [78.37914276, 13.31687927], [78.38291168, 13.3140707], [78.39125061, 13.30370998], [78.40206146, 13.30737972], [78.40706635, 13.31009197], [78.41526031, 13.31713009], [78.42077637, 13.3190918], [78.42446899, 13.31910133], [78.42682648, 13.31807995], [78.42906952, 13.31711197], [78.43031311, 13.3078289], [78.43598175, 13.29835033], [78.43785858, 13.29876041], [78.44130707, 13.29950142], [78.44507599, 13.30139923], [78.44790649, 13.30281925], [78.45417786, 13.30414963], [78.46053314, 13.30792046], [78.46640015, 13.31012154], [78.47174835, 13.30792046], [78.4701767, 13.29390144], [78.47255707, 13.29113197], [78.48352814, 13.28808022], [78.49521637, 13.279212], [78.50115967, 13.27721119], [78.50392914, 13.27245045], [78.5083313, 13.26947117], [78.51197052, 13.25995064], [78.51550293, 13.2571497], [78.52079773, 13.25559139], [78.52229309, 13.25811195], [78.52377319, 13.26062107], [78.52561951, 13.26929092], [78.52876282, 13.27586174], [78.53327179, 13.27600098], [78.53557587, 13.27608013], [78.54361725, 13.27323246], [78.54717255, 13.27267075], [78.55060577, 13.27602959], [78.55323029, 13.28462029], [78.55413818, 13.2983017], [78.55565643, 13.29942989], [78.56009674, 13.29334927], [78.56156158, 13.28803921], [78.56443787, 13.28341007], [78.56716919, 13.27177143], [78.57611084, 13.2671299], [78.57746887, 13.26204967], [78.57215118, 13.24860096], [78.56854248, 13.24353027], [78.56321716, 13.23841095], [78.55989075, 13.23337173], [78.5594101, 13.23038197], [78.55887604, 13.22713089], [78.55719757, 13.21202087], [78.56433105, 13.20805073], [78.56867981, 13.20426273], [78.56588745, 13.20088959], [78.56012726, 13.19820023], [78.5583725, 13.19218063], [78.5532608, 13.18924141], [78.54094696, 13.18725109], [78.54247284, 13.18017006], [78.54688263, 13.17862034], [78.55349731, 13.17987061], [78.55647278, 13.179842], [78.55940247, 13.17980099], [78.56333923, 13.17740059], [78.56472778, 13.17404079], [78.56568146, 13.17175102], [78.56907654, 13.1564827], [78.56536865, 13.15681076], [78.56125641, 13.15570068], [78.55805969, 13.15234184], [78.54685974, 13.15343094], [78.53878021, 13.15157127], [78.53369904, 13.14610958], [78.53269958, 13.14209175], [78.53669739, 13.13693047], [78.53544617, 13.13074017], [78.52143097, 13.12905121], [78.51291656, 13.12023067], [78.50875092, 13.11958981], [78.50869751, 13.11326981], [78.51113892, 13.10632992], [78.5161972, 13.10081959], [78.52237701, 13.09966183], [78.52796173, 13.09735966], [78.51480865, 13.09111023], [78.5138092, 13.08468056], [78.50681305, 13.08419132], [78.50192261, 13.08166122], [78.49958038, 13.07582188], [78.4985733, 13.06979084], [78.50479889, 13.05937958], [78.50457764, 13.05276203], [78.48792267, 13.04972076], [78.48750305, 13.04939079], [78.48108673, 13.04438972], [78.47738647, 13.04322147], [78.47107697, 13.04385853], [78.46704865, 13.04137135], [78.46472168, 13.03489971], [78.46105194, 13.03201008], [78.45500946, 13.03259087], [78.45157623, 13.03153229], [78.4506073, 13.0282402], [78.44991302, 13.0258112], [78.45036316, 13.01487064], [78.45263672, 13.00858116], [78.45231628, 13.00376034], [78.45542145, 12.99009037], [78.46142578, 12.97912025], [78.45939636, 12.97575188], [78.45759583, 12.97066021], [78.457901, 12.96324158], [78.43358612, 12.96877956], [78.42565155, 12.96977139], [78.4226532, 12.96860027], [78.42191315, 12.96274853], [78.42282104, 12.95773125], [78.42384338, 12.95440102], [78.42735291, 12.95053101], [78.420578, 12.94764996], [78.41977692, 12.94668198], [78.42459106, 12.93820953], [78.42328644, 12.93379974], [78.42035675, 12.92895889], [78.4213562, 12.92352962], [78.4259491, 12.91713047], [78.43447113, 12.90827084], [78.4412384, 12.90563202], [78.44290161, 12.90411186], [78.4490509, 12.8966589], [78.45613098, 12.89275265], [78.45833588, 12.87972069], [78.45694733, 12.8660593], [78.45423889, 12.85316181], [78.45211792, 12.85572147], [78.45266724, 12.86549187], [78.44644165, 12.87473202], [78.43849182, 12.87974072], [78.43830109, 12.88624096], [78.43570709, 12.88885975], [78.43582916, 12.90067005], [78.42640686, 12.90206146], [78.42489624, 12.89817047], [78.42465973, 12.89341068], [78.41734314, 12.88903141], [78.41152954, 12.89089966], [78.40291595, 12.89132118], [78.39953613, 12.89620113], [78.38839722, 12.90552044], [78.38508606, 12.89625072], [78.38337708, 12.89540958], [78.37834167, 12.89519119], [78.36868286, 12.90178013], [78.36097717, 12.91161919], [78.34542847, 12.92806053], [78.34076691, 12.92492008], [78.34041595, 12.92198944], [78.34398651, 12.91809177], [78.33827209, 12.91575146], [78.33773041, 12.91312122], [78.33833313, 12.90649986], [78.32718658, 12.88923073], [78.32216644, 12.88960075], [78.31645966, 12.89261055], [78.31347656, 12.88862133], [78.31240845, 12.88330078], [78.31328583, 12.87977123], [78.30996704, 12.87648201], [78.31093597, 12.8738308], [78.31617737, 12.87220192], [78.32141876, 12.87165928], [78.32271576, 12.87619019], [78.32749176, 12.8740406], [78.32271576, 12.86785126], [78.32158661, 12.86285019], [78.31105042, 12.86537075], [78.30409241, 12.8657608], [78.30622101, 12.85647106], [78.30310059, 12.84720039], [78.27568817, 12.84916019], [78.27056885, 12.8505497], [78.26262665, 12.85659027], [78.25814819, 12.85562992], [78.25382233, 12.8495903], [78.24874878, 12.8498497], [78.24465942, 12.85110092], [78.2410965, 12.84742069], [78.24186707, 12.8123312], [78.24021912, 12.80314159], [78.23542786, 12.78757954], [78.22949982, 12.76200962], [78.22512054, 12.75493145], [78.22064972, 12.75259018], [78.21248627, 12.75506973], [78.20233917, 12.75507927], [78.1989212, 12.75509071], [78.19538116, 12.7575407], [78.19024658, 12.76107979], [78.18395996, 12.76260853], [78.17871857, 12.75992012], [78.17530823, 12.76331139], [78.16615295, 12.76500034], [78.16156006, 12.76226139], [78.15814209, 12.76022053], [78.14771271, 12.76329994], [78.14302826, 12.76664066], [78.1364975, 12.76916027], [78.13163757, 12.76966953], [78.12711334, 12.77015972], [78.1206665, 12.7700119], [78.117836, 12.77989197], [78.11448669, 12.78707123], [78.10946655, 12.79140186], [78.10205078, 12.7933979], [78.09765625, 12.79592991], [78.09514618, 12.80023098], [78.08647919, 12.80333996], [78.08246613, 12.80915165], [78.0761261, 12.82051086], [78.07367706, 12.821311], [78.06594849, 12.81893063], [78.06639862, 12.82668114], [78.06456757, 12.83016968], [78.05139923, 12.83230972], [78.05060577, 12.83858204], [78.04673004, 12.84237003], [78.04202271, 12.8421011], [78.04000854, 12.83821106], [78.02215576, 12.84122086], [78.01957703, 12.84620953], [78.0149231, 12.84592056], [78.01435852, 12.84298992], [78.01685333, 12.83836079], [78.01677704, 12.83352947], [78.00907898, 12.83370018], [78.00711823, 12.82820129], [78.00804901, 12.82296085], [78.00712585, 12.8200407], [78.00382233, 12.8179493], [77.9998703, 12.81904125], [77.99330139, 12.81367111], [78.0032959, 12.80583096], [78.00559998, 12.80326939], [78.0014801, 12.79543972], [77.98972321, 12.79719067], [77.98602295, 12.79530144], [77.98139954, 12.79564095], [77.98134613, 12.81042099], [77.97457886, 12.81444168], [77.97360229, 12.81816959], [77.97129822, 12.82264042], [77.95746613, 12.82153034], [77.95501709, 12.82516003], [77.95800018, 12.83634186], [77.95522308, 12.83870983], [77.95134735, 12.83786201], [77.94684601, 12.83808136], [77.94856262, 12.84811974], [77.94555664, 12.8493309], [77.93860626, 12.84969139], [77.93345642, 12.84478092], [77.93255615, 12.83963108], [77.93612671, 12.83380985], [77.93990326, 12.82934856], [77.93297577, 12.81292057], [77.92479706, 12.8137207], [77.92076111, 12.81621933], [77.91825104, 12.81921196], [77.91047668, 12.81971073], [77.90923309, 12.82201958], [77.91182709, 12.83243084], [77.91487885, 12.83899021], [77.91533661, 12.84427071], [77.91844177, 12.84736061], [77.92780304, 12.85046959], [77.92878723, 12.85425091], [77.93105316, 12.85621071], [77.93444824, 12.85604], [77.93356323, 12.86168957], [77.91967773, 12.86349964], [77.91838074, 12.86887169], [77.92871857, 12.87143135], [77.92900848, 12.87477016], [77.92428589, 12.87784004], [77.9177475, 12.87837124], [77.91436768, 12.87354183], [77.90933228, 12.87295246], [77.90219879, 12.87337112], [77.90052032, 12.86788273], [77.89427948, 12.86822891], [77.8874588, 12.86692142], [77.88226318, 12.85839939], [77.87800598, 12.85928059], [77.86689758, 12.85861969], [77.86219025, 12.85692024], [77.85884857, 12.85762024], [77.85449982, 12.85673141], [77.84944153, 12.85786057], [77.84407043, 12.85589027], [77.83963013, 12.85585117], [77.83644867, 12.85763073], [77.83094025, 12.85786057], [77.82559967, 12.85898972], [77.82224274, 12.85461998], [77.82209015, 12.8498497], [77.81704712, 12.84898186], [77.81362915, 12.84401131], [77.80902863, 12.84272957], [77.80493927, 12.84275055], [77.79981995, 12.83784103], [77.79196167, 12.83983135], [77.78948975, 12.83877087], [77.78859711, 12.83535004], [77.78488159, 12.83380985], [77.78356171, 12.82825089], [77.78803253, 12.82364178], [77.79232025, 12.82137012], [77.80101776, 12.82080936], [77.79868317, 12.8117609], [77.80066681, 12.80562973], [77.79876709, 12.80491924], [77.79441071, 12.80580997], [77.79136658, 12.79631996], [77.79650116, 12.78961945], [77.79949188, 12.78685856], [77.7979126, 12.78292084], [77.79353333, 12.78387165], [77.78793335, 12.78132057], [77.78304291, 12.77612019], [77.7815094, 12.77103138], [77.77162933, 12.75983143], [77.77163696, 12.75477791], [77.77384949, 12.75113201], [77.77829742, 12.74787045], [77.78497314, 12.74505138], [77.78292084, 12.73882198], [77.77807617, 12.73367119], [77.76695251, 12.72963047], [77.75836945, 12.72931957], [77.75306702, 12.72509861], [77.75166321, 12.71840096], [77.75557709, 12.71557045], [77.76303864, 12.71446037], [77.76152802, 12.70771027], [77.75733948, 12.70398998], [77.75598145, 12.69705009], [77.75023651, 12.68716145], [77.7470932, 12.68664074], [77.74001312, 12.68855095], [77.73355865, 12.69147968], [77.72725677, 12.68287182], [77.730896, 12.67797089], [77.73320007, 12.67189121], [77.73140717, 12.66397953], [77.7232132, 12.66321182], [77.71839905, 12.66198063], [77.71531677, 12.6630106], [77.71412659, 12.66539097], [77.71411133, 12.67027855], [77.70381927, 12.67374134], [77.70178986, 12.65824986], [77.69547272, 12.6512394], [77.68753052, 12.65190029], [77.67835999, 12.6490202], [77.6733017, 12.65042973], [77.66780853, 12.65063953], [77.66738129, 12.65283012], [77.66929626, 12.66193962], [77.66590881, 12.66436005], [77.67030334, 12.6712389], [77.65428925, 12.67416954], [77.63878632, 12.67014027], [77.6329422, 12.67013073], [77.60943604, 12.66335106], [77.59783936, 12.65902042], [77.59033966, 12.65754128], [77.58927917, 12.64825153], [77.58796692, 12.6426897], [77.58937073, 12.63664246], [77.59169006, 12.63275146], [77.59552002, 12.63043118], [77.594841, 12.62710953], [77.59781647, 12.62102032], [77.59352875, 12.6165514], [77.58539581, 12.61193085], [77.5821228, 12.60508919], [77.58145905, 12.58423138], [77.57422638, 12.56723118], [77.57119751, 12.56354141], [77.5700531, 12.5579319], [77.57235718, 12.54042053], [77.57644653, 12.5368309], [77.57763672, 12.52347088], [77.57982635, 12.51148129], [77.57850647, 12.50701141], [77.59516144, 12.50366974], [77.60520172, 12.50333023], [77.60636902, 12.49979115], [77.60473633, 12.49488163], [77.60177612, 12.49166107], [77.58249664, 12.47631073], [77.57536316, 12.46837997], [77.59664917, 12.4646101], [77.6108017, 12.4780407], [77.61728668, 12.48550987], [77.62520599, 12.47726154], [77.62169647, 12.45444965], [77.61815643, 12.4431324], [77.62010193, 12.43809032], [77.61694336, 12.42464066], [77.61712646, 12.41866112], [77.62065125, 12.41376019], [77.62008667, 12.40847969], [77.61582947, 12.40488052], [77.61329651, 12.39780045], [77.61094666, 12.38564968], [77.60987854, 12.3736496], [77.60753632, 12.36765957], [77.6063385, 12.36026001], [77.60382843, 12.35375118], [77.60024261, 12.35122108], [77.59120178, 12.3491993], [77.58616638, 12.3363018], [77.57530975, 12.32625103], [77.56859589, 12.32419014], [77.56603241, 12.31670094], [77.55609894, 12.29716015], [77.54515076, 12.29269028], [77.54270935, 12.28371143], [77.53954315, 12.28239059], [77.52352142, 12.28100109], [77.51834106, 12.2695303], [77.50208282, 12.2663002], [77.49796295, 12.2683897], [77.49318695, 12.27279091], [77.4906311, 12.27305984], [77.48423004, 12.2697897], [77.47844696, 12.26965141], [77.4752121, 12.26597023], [77.4701767, 12.26187038], [77.46723175, 12.25318241], [77.46666718, 12.24847126], [77.46350098, 12.24403954], [77.46295166, 12.23577118], [77.46676636, 12.23398018], [77.47366333, 12.22494125], [77.47229004, 12.21726036], [77.4683609, 12.21019936], [77.46566772, 12.20226097], [77.46923828, 12.19651127], [77.47493744, 12.19582939], [77.47875214, 12.19398117], [77.48248291, 12.19011974], [77.49246216, 12.18719196], [77.51130676, 12.18397141], [77.51979828, 12.18866158], [77.52445221, 12.18824005], [77.52805328, 12.19001102], [77.53102112, 12.19014072], [77.53341675, 12.19383144], [77.53852081, 12.19448853], [77.54667664, 12.19037056], [77.55583191, 12.18711185], [77.56533813, 12.19045067], [77.56955719, 12.18807125], [77.58421326, 12.18884182], [77.59113312, 12.19056034], [77.59659576, 12.19530106], [77.60411835, 12.19516182], [77.61051941, 12.19159031], [77.61582184, 12.18978119], [77.62136841, 12.19170189], [77.62561035, 12.1897192], [77.62890625, 12.18632126], [77.63301086, 12.18642139], [77.64466858, 12.18857002], [77.65544891, 12.18774986], [77.6681366, 12.18371964], [77.67282104, 12.18138885], [77.7012558, 12.17259979], [77.71077728, 12.1733408], [77.71951294, 12.17152023], [77.72635651, 12.16732025], [77.7290802, 12.15995979], [77.73195648, 12.15461063], [77.73906708, 12.14785957], [77.74046326, 12.14258194], [77.74024963, 12.12928963], [77.74421692, 12.12669182], [77.74729156, 12.12232018], [77.75282288, 12.11797047], [77.76700592, 12.1091404], [77.76844788, 12.10559177], [77.76638794, 12.1009903], [77.76280975, 12.09748173], [77.75826263, 12.09440136], [77.75634003, 12.09195995], [77.75052643, 12.08051014], [77.74610138, 12.06932068], [77.73396301, 12.06022072], [77.72036743, 12.05335236], [77.71562195, 12.04850197], [77.71264648, 12.04138184], [77.70722961, 12.03328133], [77.70155334, 12.02714062], [77.69410706, 12.01519203], [77.68945313, 12.00994968], [77.68115234, 11.99123096], [77.6810379, 11.99123096], [77.67719269, 11.98427105], [77.66705322, 11.95893192], [77.66371155, 11.95296001], [77.664711, 11.93970013], [77.66044617, 11.93814087], [77.6548233, 11.93735886], [77.64675903, 11.93871117], [77.64341736, 11.94417191], [77.63949585, 11.94283199], [77.63672638, 11.94026089], [77.63021851, 11.93797016], [77.61517334, 11.93414974], [77.60372162, 11.93026924], [77.59596252, 11.92928028], [77.591362, 11.92633057], [77.58573151, 11.92945957], [77.5789566, 11.9282999], [77.57328796, 11.92401123], [77.54799652, 11.93074989], [77.53132629, 11.92649937], [77.52365112, 11.92148113], [77.51402283, 11.92568111], [77.51095581, 11.92534161], [77.50063324, 11.92723083], [77.49043274, 11.92973995], [77.48439789, 11.93239975], [77.48282623, 11.92869186], [77.48394012, 11.9214716], [77.48219299, 11.91214085], [77.47949982, 11.9003706], [77.47733307, 11.8952713], [77.47596741, 11.88955021], [77.47721863, 11.88177967], [77.47690582, 11.87601185], [77.47367096, 11.87780094], [77.4704361, 11.88361073], [77.46743011, 11.88321018], [77.46333313, 11.88727093], [77.45392609, 11.89055061], [77.45279694, 11.88853073], [77.45385742, 11.8819418], [77.45302582, 11.87589073], [77.45329285, 11.87089062], [77.45516205, 11.8672514], [77.45387268, 11.85733891], [77.45210266, 11.85323048], [77.45252991, 11.84910011], [77.45096588, 11.84431171], [77.45536041, 11.84268188], [77.45629883, 11.83912182], [77.45159149, 11.82341194], [77.44658661, 11.81626034], [77.44650269, 11.81149197], [77.44246674, 11.80647087], [77.44087219, 11.79134178], [77.43622589, 11.78176975], [77.43209076, 11.77894115], [77.43028259, 11.77667141], [77.43105316, 11.77168179], [77.42384338, 11.76608944], [77.4207077, 11.7602911], [77.41925049, 11.75067139], [77.4134903, 11.75115204], [77.4125061, 11.75612926], [77.41246796, 11.76228142], [77.40654755, 11.76233959], [77.40145111, 11.76403141], [77.38189697, 11.77616119], [77.36223602, 11.7758007], [77.35948944, 11.77879143], [77.35515594, 11.77837181], [77.35092926, 11.76858044], [77.34565735, 11.76406956], [77.32611847, 11.75893974], [77.31356049, 11.76998043], [77.30623627, 11.77870178], [77.29045105, 11.79416084], [77.28481293, 11.79836178], [77.28235626, 11.79286003], [77.27829742, 11.78973961], [77.27227783, 11.79117966], [77.24848175, 11.8008604], [77.24173737, 11.80245972], [77.24125671, 11.79399967], [77.23707581, 11.7881918], [77.22705078, 11.78374958], [77.21642303, 11.78476048], [77.20392609, 11.78447056], [77.18966675, 11.78281975], [77.17842102, 11.77952003], [77.17230225, 11.77573013], [77.16591644, 11.77423], [77.15541077, 11.77427101], [77.14379883, 11.77129936], [77.13723755, 11.7719717], [77.13459015, 11.76641083], [77.13102722, 11.7623806], [77.12738037, 11.76093197], [77.11972046, 11.76338196], [77.1138916, 11.76183033], [77.11096954, 11.76314926], [77.10282898, 11.7631197], [77.1053009, 11.75948048], [77.10610962, 11.75622082], [77.10573578, 11.75064087], [77.10323334, 11.74588013], [77.10540009, 11.73158073], [77.10830688, 11.72243023], [77.10929871, 11.71280098], [77.10367584, 11.71554947], [77.0962677, 11.72312069], [77.07588959, 11.72389126], [77.07163239, 11.72500992], [77.07385254, 11.72954082], [77.05010986, 11.75774956], [77.05438995, 11.76496124], [77.0618515, 11.77206135], [77.05654144, 11.77711964], [77.05253601, 11.77923107], [77.04569244, 11.77915955], [77.04125977, 11.7775898], [77.02757263, 11.76169968], [77.02233887, 11.76470089], [77.03026581, 11.77830124], [77.03167725, 11.78395081], [77.02767944, 11.78668976], [77.02855682, 11.78911972], [77.02275848, 11.79498196], [77.01857758, 11.79732037], [77.01344299, 11.79917145], [77.00884247, 11.79696178], [77.00443268, 11.80301952], [76.99035645, 11.79931927], [76.9821167, 11.79953957], [76.97277069, 11.80106926], [76.97341156, 11.79511166], [76.97483826, 11.79102135], [76.96539307, 11.77647972], [76.96330261, 11.77079964], [76.95960236, 11.76519966], [76.95316315, 11.7712698], [76.95025635, 11.77543068], [76.94444275, 11.7813406], [76.94032288, 11.78102016], [76.93580627, 11.77674198], [76.93239594, 11.77737141], [76.92666626, 11.78089046], [76.91348267, 11.78036976], [76.90679169, 11.78123188], [76.89968872, 11.78327179], [76.89335632, 11.77730274], [76.89150238, 11.77011204], [76.88796997, 11.76589966], [76.88934326, 11.76060104], [76.88851166, 11.75043201], [76.88600922, 11.74448109], [76.88172913, 11.73009014], [76.880867, 11.72459126], [76.87558746, 11.71789932], [76.86457062, 11.71053123], [76.8535614, 11.69878197], [76.85572815, 11.69433975], [76.84910583, 11.68721962], [76.84617615, 11.6824789], [76.84472656, 11.67737198], [76.84137726, 11.66977119], [76.83838654, 11.66466999], [76.83566284, 11.65607071], [76.83230591, 11.65266132], [76.83003235, 11.64904022], [76.82847595, 11.64410973], [76.82775116, 11.63842964], [76.829216, 11.63497066], [76.82969666, 11.62934113], [76.83309174, 11.62529087], [76.83882141, 11.62341976], [76.83798218, 11.6187706], [76.83825684, 11.61584187], [76.84155273, 11.61322117], [76.84581757, 11.61164093], [76.84588623, 11.60605145], [76.85090637, 11.60182953], [76.84733582, 11.58864021], [76.84375763, 11.58603096], [76.83728027, 11.57448006], [76.83596802, 11.58403015], [76.83349609, 11.58703136], [76.82993317, 11.58982086], [76.8236084, 11.59130001], [76.81651306, 11.59720993], [76.80832672, 11.59618187], [76.79075623, 11.59970093], [76.78082275, 11.60357094], [76.77377319, 11.60342979], [76.75139618, 11.60670853], [76.74626923, 11.61054134], [76.74104309, 11.60580921], [76.73542786, 11.60523033], [76.72020721, 11.60505009], [76.70749664, 11.60593891], [76.69309998, 11.6044302], [76.67904663, 11.60414124], [76.66443634, 11.60509968], [76.63372803, 11.60352993], [76.62565613, 11.60381889], [76.60787201, 11.60044193]]], [[[74.36514282, 14.55263996], [74.36514282, 14.55235958], [74.36597443, 14.55236244], [74.36597443, 14.55208206], [74.3677063, 14.55208206], [74.37208557, 14.55208206], [74.37208557, 14.55236244], [74.37291718, 14.55236244], [74.37291718, 14.55208206], [74.37319183, 14.55208206], [74.37319183, 14.55180645], [74.37346649, 14.55181122], [74.37346649, 14.55153275], [74.37374878, 14.55153275], [74.37374878, 14.55125046], [74.37403107, 14.55125046], [74.37403107, 14.55097198], [74.37430573, 14.55097198], [74.37430573, 14.55041599], [74.37458038, 14.55041981], [74.37458038, 14.55014038], [74.37486267, 14.55014038], [74.37486267, 14.54986191], [74.37513733, 14.54986191], [74.37513733, 14.54957867], [74.37541962, 14.54958439], [74.37541962, 14.54930592], [74.37568665, 14.54930973], [74.37568665, 14.5490303], [74.37596893, 14.5490303], [74.37596893, 14.54874992], [74.37625122, 14.54874992], [74.37625122, 14.54681015], [74.3779068, 14.54681015], [74.3779068, 14.54597187], [74.37819672, 14.54597187], [74.37819672, 14.54541779], [74.37708282, 14.54541969], [74.37708282, 14.54514027], [74.37596893, 14.54514027], [74.37596893, 14.54486179], [74.37568665, 14.54486179], [74.37568665, 14.54456997], [74.37513733, 14.54458427], [74.37513733, 14.5443058], [74.37486267, 14.54430962], [74.37486267, 14.54403019], [74.37431335, 14.54403019], [74.37431335, 14.54347134], [74.37403107, 14.54347134], [74.37403107, 14.54291534], [74.37431335, 14.54292202], [74.37431335, 14.54264164], [74.37458038, 14.54264164], [74.37458038, 14.54236126], [74.37486267, 14.54236126], [74.37486267, 14.54208279], [74.37513733, 14.54208279], [74.37513733, 14.54180527], [74.37404633, 14.54181385], [74.37346649, 14.54182053], [74.37346649, 14.54152966], [74.37124634, 14.54152966], [74.37124634, 14.54182053], [74.37041473, 14.54180527], [74.37041473, 14.54208279], [74.36791992, 14.54208279], [74.36791992, 14.54180527], [74.36763763, 14.54182053], [74.36763763, 14.54152966], [74.36736298, 14.54152966], [74.36736298, 14.54124928], [74.36680603, 14.54124928], [74.36680603, 14.54152966], [74.36653137, 14.54152966], [74.36653137, 14.54182053], [74.36597443, 14.54180527], [74.36597443, 14.54208279], [74.36541748, 14.54208279], [74.36541748, 14.54236126], [74.36514282, 14.54236126], [74.36514282, 14.54264164], [74.36458588, 14.54264164], [74.36458588, 14.54292202], [74.36430359, 14.54291534], [74.36430359, 14.54319572], [74.36398315, 14.54319286], [74.36374664, 14.54319096], [74.36374664, 14.54375172], [74.36347198, 14.54374886], [74.36347198, 14.54458427], [74.36319733, 14.54456997], [74.36319733, 14.54486179], [74.36347198, 14.54486179], [74.36347198, 14.54569435], [74.36374664, 14.54569054], [74.36374664, 14.54652977], [74.36402893, 14.54652977], [74.36402893, 14.54930973], [74.36374664, 14.54930592], [74.36374664, 14.55208206], [74.36402893, 14.55208015], [74.36402893, 14.55263996], [74.36514282, 14.55263996]]]]}}, {\\\"id\\\": \\\"15\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.17_1\\\", \\\"HASC_1\\\": \\\"IN.KL\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Kerala\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 49.0, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1369.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1149.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2518.0, \\\"geo-id\\\": 15, \\\"hpm25_child_popweighted\\\": 110.2, \\\"hpm25_female_popweighted\\\": 126.7, \\\"hpm25_male_popweighted\\\": 91.2, \\\"location\\\": \\\"Kerala\\\", \\\"mort_apm25_6cod_mean_total\\\": 13654.0, \\\"mort_hpm25_6cod_mean_total\\\": 11123.0, \\\"mort_tpm25_6cod_mean_total\\\": 24777.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[76.40429688, 9.54152966], [76.40429688, 9.53986073], [76.40458679, 9.53986073], [76.40458679, 9.53708267], [76.40486145, 9.53708267], [76.40486145, 9.52763844], [76.40207672, 9.5276413], [76.40207672, 9.52735996], [76.38318634, 9.52735996], [76.38318634, 9.5276413], [76.38291931, 9.52763844], [76.38291931, 9.52875137], [76.38263702, 9.52875137], [76.38263702, 9.52902889], [76.38291931, 9.52902889], [76.38291931, 9.53042126], [76.38263702, 9.53041744], [76.38263702, 9.53069496], [76.38291931, 9.53069496], [76.38291931, 9.53208256], [76.38263702, 9.53208065], [76.38263702, 9.53292179], [76.38207245, 9.53292179], [76.38207245, 9.53375053], [76.38236237, 9.53375053], [76.38236237, 9.53403091], [76.38291931, 9.53403091], [76.38291931, 9.53431034], [76.38375092, 9.53430462], [76.38375092, 9.53458309], [76.38458252, 9.53458309], [76.38458252, 9.53486061], [76.38513947, 9.53486061], [76.38513947, 9.53514099], [76.38597107, 9.53514099], [76.38597107, 9.53541946], [76.38680267, 9.5354166], [76.38680267, 9.53569508], [76.38764191, 9.53569508], [76.38764191, 9.5359726], [76.38846588, 9.53597069], [76.38846588, 9.53625107], [76.38903046, 9.53624916], [76.38903046, 9.53652668], [76.38986206, 9.53652], [76.38986206, 9.53681183], [76.39069366, 9.53680515], [76.39069366, 9.53708267], [76.39152527, 9.53708267], [76.39152527, 9.53736115], [76.39235687, 9.53736115], [76.39235687, 9.53764153], [76.39319611, 9.53764153], [76.39319611, 9.53792191], [76.39375305, 9.53791714], [76.39375305, 9.53819466], [76.39458466, 9.53819466], [76.39458466, 9.53847122], [76.39541626, 9.53847122], [76.39541626, 9.5387516], [76.39624786, 9.5387516], [76.39624786, 9.53903198], [76.3970871, 9.53903198], [76.3970871, 9.53931046], [76.39763641, 9.53930473], [76.39763641, 9.53958321], [76.39847565, 9.53958321], [76.39847565, 9.53986073], [76.39930725, 9.53986073], [76.39930725, 9.54014015], [76.40013885, 9.54014015], [76.40013885, 9.54041958], [76.40097046, 9.54041767], [76.40097046, 9.54069328], [76.4015274, 9.54069328], [76.4015274, 9.5409708], [76.40235901, 9.54097366], [76.40235901, 9.54124928], [76.40318298, 9.54124928], [76.40319824, 9.54152966], [76.40429688, 9.54152966]]], [[[76.46736145, 9.5409708], [76.46736145, 9.54069328], [76.46847534, 9.54069328], [76.46847534, 9.54041767], [76.46901703, 9.54041958], [76.46901703, 9.54014015], [76.4695816, 9.54014015], [76.4695816, 9.53986073], [76.4706955, 9.53986073], [76.4706955, 9.53958321], [76.4715271, 9.53958321], [76.4715271, 9.53930473], [76.4723587, 9.53931046], [76.4723587, 9.53903198], [76.4734726, 9.53903198], [76.4734726, 9.5387516], [76.47429657, 9.5387516], [76.47429657, 9.53847122], [76.47458649, 9.53847122], [76.47458649, 9.53819466], [76.47624969, 9.53819466], [76.47624969, 9.53791714], [76.47680664, 9.53792191], [76.47680664, 9.53764153], [76.47763824, 9.53764153], [76.47763824, 9.53736115], [76.47846985, 9.53736115], [76.47846985, 9.53708267], [76.47902679, 9.53708267], [76.47902679, 9.53652668], [76.47930908, 9.53652668], [76.47930908, 9.53013897], [76.47902679, 9.53014088], [76.47902679, 9.52986145], [76.47125244, 9.52986145], [76.47125244, 9.52958298], [76.46763611, 9.52958298], [76.46763611, 9.52930546], [76.46736145, 9.52930546], [76.46736145, 9.52958298], [76.46652985, 9.52958298], [76.46652985, 9.52986145], [76.4659729, 9.52986145], [76.4659729, 9.53514099], [76.46624756, 9.53514099], [76.46624756, 9.53625107], [76.4659729, 9.53625107], [76.4659729, 9.53931046], [76.46624756, 9.53930473], [76.46624756, 9.5409708], [76.46736145, 9.5409708]]], [[[76.45207977, 9.54569435], [76.45291901, 9.54569435], [76.45291901, 9.54541588], [76.4540329, 9.54541969], [76.4540329, 9.54514027], [76.45513916, 9.54514027], [76.45513916, 9.54486179], [76.45569611, 9.54486179], [76.45569611, 9.54458237], [76.45652771, 9.54458427], [76.45652771, 9.5443058], [76.45735931, 9.54430962], [76.45735931, 9.54403019], [76.45819092, 9.54403019], [76.45819092, 9.54374981], [76.45847321, 9.54374981], [76.45847321, 9.54347229], [76.45930481, 9.54347229], [76.45930481, 9.54319572], [76.46013641, 9.54319572], [76.46013641, 9.5429163], [76.46098328, 9.54292011], [76.46098328, 9.54265118], [76.46180725, 9.54265118], [76.46180725, 9.54235935], [76.46263885, 9.54236221], [76.46263885, 9.54208374], [76.4631958, 9.54208374], [76.4631958, 9.54180622], [76.4640274, 9.54181004], [76.4640274, 9.54152966], [76.46457672, 9.54152966], [76.46457672, 9.54041958], [76.46485901, 9.54041958], [76.46485901, 9.53764153], [76.46457672, 9.53764153], [76.46457672, 9.53681183], [76.46430206, 9.53681183], [76.46430206, 9.53625107], [76.46457672, 9.53625107], [76.46457672, 9.53458118], [76.46430206, 9.53458309], [76.46430206, 9.53430462], [76.46457672, 9.53431034], [76.46457672, 9.53042126], [76.46430206, 9.53042126], [76.46430206, 9.52986145], [76.46263885, 9.52986145], [76.46263885, 9.52958298], [76.46180725, 9.52958298], [76.46180725, 9.52986145], [76.4604187, 9.52986145], [76.4604187, 9.52958298], [76.45791626, 9.52958298], [76.45791626, 9.52930546], [76.45375061, 9.52930546], [76.45375061, 9.52958298], [76.45319366, 9.52958298], [76.45319366, 9.52930546], [76.4465332, 9.52930927], [76.4465332, 9.52902889], [76.44513702, 9.52902889], [76.44513702, 9.52930927], [76.44431305, 9.52930927], [76.44431305, 9.52902889], [76.44235229, 9.52902889], [76.44235229, 9.52875137], [76.44013977, 9.52875137], [76.44013977, 9.5284729], [76.43958282, 9.5284729], [76.43958282, 9.52819538], [76.43930817, 9.52819538], [76.43930817, 9.52791691], [76.43846893, 9.52791691], [76.43846893, 9.52819538], [76.43708038, 9.52819538], [76.43708038, 9.5284729], [76.43680573, 9.5284729], [76.43680573, 9.52819538], [76.43597412, 9.52819538], [76.43597412, 9.5284729], [76.43541718, 9.5284729], [76.43541718, 9.53819466], [76.43569183, 9.53819466], [76.43569183, 9.54597187], [76.43597412, 9.54597187], [76.43597412, 9.54758072], [76.43597412, 9.55152798], [76.43680573, 9.55152798], [76.43680573, 9.55125046], [76.43736267, 9.55125046], [76.43736267, 9.55097198], [76.43763733, 9.55097198], [76.43763733, 9.55069447], [76.43846893, 9.55069447], [76.43846893, 9.55041599], [76.43875122, 9.55042076], [76.43875122, 9.55014038], [76.43985748, 9.55014038], [76.43985748, 9.54986], [76.44069672, 9.54986], [76.44069672, 9.54958439], [76.44125366, 9.54958439], [76.44125366, 9.54930592], [76.4420929, 9.54931068], [76.44208527, 9.54912186], [76.44208527, 9.5490284], [76.44291687, 9.5490303], [76.44291687, 9.54874992], [76.44374847, 9.54874992], [76.44374847, 9.54846096], [76.44458008, 9.5484724], [76.44458008, 9.54819393], [76.44486237, 9.54819393], [76.44486237, 9.54791641], [76.44541931, 9.54792118], [76.44541931, 9.54763985], [76.44735718, 9.54763985], [76.44735718, 9.54736042], [76.44819641, 9.54736233], [76.44819641, 9.54708195], [76.44902802, 9.54708195], [76.44902802, 9.54680634], [76.44957733, 9.5468111], [76.44957733, 9.54653263], [76.44985962, 9.54653263], [76.44985962, 9.54625034], [76.45069122, 9.54625034], [76.45069122, 9.54597187], [76.45207977, 9.54597187], [76.45207977, 9.54569435]]], [[[76.43458557, 9.55152798], [76.43458557, 9.55125046], [76.43486023, 9.55125046], [76.43486023, 9.54819393], [76.43458557, 9.54819393], [76.43458557, 9.54722977], [76.43458557, 9.54014015], [76.43430328, 9.54014015], [76.43430328, 9.53236103], [76.43402863, 9.53236103], [76.43402863, 9.5284729], [76.42791748, 9.5284729], [76.42791748, 9.52819538], [76.42124939, 9.52819538], [76.42124939, 9.52791691], [76.4145813, 9.52792072], [76.4145813, 9.5276413], [76.40625, 9.52763844], [76.40625, 9.52986145], [76.40598297, 9.52986145], [76.40598297, 9.53541946], [76.40569305, 9.53541946], [76.40569305, 9.54014015], [76.4054184, 9.54014015], [76.4054184, 9.54208374], [76.40569305, 9.54208374], [76.40569305, 9.54236221], [76.40651703, 9.54235935], [76.40651703, 9.54265118], [76.40735626, 9.54265118], [76.40735626, 9.54292011], [76.4081955, 9.5429163], [76.4081955, 9.54319572], [76.4090271, 9.54319572], [76.4090271, 9.54347229], [76.41014099, 9.54347229], [76.41014099, 9.54374981], [76.4109726, 9.54374981], [76.4109726, 9.54403019], [76.41159058, 9.54403019], [76.41179657, 9.54403019], [76.41179657, 9.54430962], [76.4126358, 9.5443058], [76.4126358, 9.54458427], [76.41348267, 9.54458237], [76.41348267, 9.54486179], [76.41430664, 9.54486179], [76.41430664, 9.54514027], [76.41513824, 9.54514027], [76.41513824, 9.54541969], [76.41596985, 9.54541588], [76.41596985, 9.54569435], [76.41680908, 9.54569435], [76.41680908, 9.54597187], [76.41764069, 9.54597187], [76.41764069, 9.54625034], [76.41847229, 9.54625034], [76.41847229, 9.54653263], [76.41902924, 9.54653263], [76.41902924, 9.5468111], [76.41986084, 9.54680634], [76.41986084, 9.54708195], [76.42069244, 9.54708195], [76.42069244, 9.54736233], [76.42151642, 9.54736042], [76.42151642, 9.54763985], [76.42236328, 9.54763985], [76.42236328, 9.54792118], [76.42319489, 9.54791641], [76.42319489, 9.54819393], [76.42402649, 9.54819393], [76.42402649, 9.5484724], [76.42485809, 9.54846096], [76.42485809, 9.54874992], [76.42542267, 9.54874992], [76.42542267, 9.5490303], [76.42624664, 9.5490303], [76.42624664, 9.54931068], [76.42708588, 9.54930592], [76.42708588, 9.54958439], [76.42819214, 9.54958439], [76.42819214, 9.54986], [76.42874908, 9.54986], [76.42874908, 9.55014038], [76.43013763, 9.55014038], [76.43013763, 9.55042076], [76.43125153, 9.55041599], [76.43125153, 9.55069447], [76.43208313, 9.55069447], [76.43208313, 9.55097198], [76.43347168, 9.55097198], [76.43347168, 9.55125046], [76.43430328, 9.55125046], [76.43430328, 9.55152798], [76.43458557, 9.55152798]]], [[[76.41430664, 9.56319523], [76.41430664, 9.56291676], [76.4145813, 9.56291962], [76.4145813, 9.56236076], [76.41485596, 9.56236076], [76.41485596, 9.56069088], [76.41513824, 9.56069469], [76.41513824, 9.5601387], [76.4154129, 9.56014061], [76.4154129, 9.55986118], [76.41513824, 9.55986118], [76.41513824, 9.55958271], [76.4154129, 9.55958271], [76.4154129, 9.55902672], [76.41570282, 9.55903053], [76.41570282, 9.55819035], [76.41625214, 9.55819511], [76.41625214, 9.55763912], [76.41707611, 9.55764961], [76.41707611, 9.55736065], [76.41819763, 9.55736065], [76.41819763, 9.55708313], [76.41902924, 9.55708313], [76.41902924, 9.55680466], [76.41958618, 9.55680466], [76.41958618, 9.55708313], [76.4201355, 9.55708313], [76.4201355, 9.55680466], [76.42124939, 9.55681133], [76.42124939, 9.55653095], [76.42151642, 9.55653095], [76.42151642, 9.55625057], [76.42208099, 9.55625057], [76.42208099, 9.55597019], [76.42292023, 9.55597305], [76.42292023, 9.55569458], [76.42319489, 9.55569458], [76.42319489, 9.55486012], [76.42375183, 9.55486012], [76.42375183, 9.55402946], [76.42402649, 9.55403137], [76.42402649, 9.55346966], [76.42430878, 9.55347157], [76.42430878, 9.55263805], [76.42457581, 9.55264091], [76.42457581, 9.55208015], [76.42485809, 9.55208206], [76.42485809, 9.55152798], [76.42514038, 9.55152798], [76.42514038, 9.55097198], [76.42569733, 9.55097198], [76.42569733, 9.54986], [76.42485809, 9.54986], [76.42485809, 9.54958439], [76.42402649, 9.54958439], [76.42402649, 9.54930592], [76.42318726, 9.54931068], [76.42318726, 9.5490303], [76.42236328, 9.5490303], [76.42236328, 9.54874992], [76.42151642, 9.54874992], [76.42151642, 9.54846096], [76.42069244, 9.5484724], [76.42069244, 9.54819393], [76.41986084, 9.54819393], [76.41986084, 9.54791641], [76.41902924, 9.54792118], [76.41902924, 9.54763985], [76.41819763, 9.54763985], [76.41819763, 9.54736042], [76.4173584, 9.54736233], [76.4173584, 9.54708195], [76.41652679, 9.54708195], [76.41652679, 9.54680634], [76.41570282, 9.5468111], [76.41570282, 9.54653263], [76.41513824, 9.54653263], [76.41513824, 9.54625034], [76.41430664, 9.54625034], [76.41430664, 9.54597187], [76.41347504, 9.54597187], [76.41347504, 9.54569435], [76.41291809, 9.54569435], [76.41291809, 9.54541588], [76.41208649, 9.54541969], [76.41208649, 9.54514027], [76.41152954, 9.54514027], [76.41152954, 9.54486179], [76.41088104, 9.54486179], [76.41069794, 9.54486179], [76.41069794, 9.54458237], [76.4098587, 9.54458427], [76.4098587, 9.5443058], [76.40930939, 9.54430962], [76.40930939, 9.54403019], [76.40847015, 9.54403019], [76.40847015, 9.54374981], [76.40763855, 9.54374981], [76.40763855, 9.54347229], [76.40680695, 9.54347229], [76.40680695, 9.54319572], [76.40569305, 9.54319572], [76.40569305, 9.5429163], [76.40486145, 9.54292011], [76.40486145, 9.54265118], [76.40374756, 9.54265118], [76.40374756, 9.54235935], [76.40319824, 9.54236221], [76.40319824, 9.54208374], [76.40208435, 9.54208374], [76.40208435, 9.54180622], [76.40125275, 9.54181004], [76.40125275, 9.54152966], [76.40040588, 9.54152966], [76.40040588, 9.54124928], [76.39958191, 9.54124928], [76.39958191, 9.5409708], [76.39902496, 9.5409708], [76.39902496, 9.54069328], [76.39819336, 9.54069328], [76.39819336, 9.54041767], [76.39763641, 9.54041958], [76.39763641, 9.54014015], [76.39679718, 9.54014015], [76.39679718, 9.53986073], [76.39597321, 9.53986073], [76.39597321, 9.53958321], [76.39541626, 9.53958321], [76.39541626, 9.53930473], [76.39457703, 9.53931046], [76.39457703, 9.53903198], [76.39402771, 9.53903198], [76.39402771, 9.5387516], [76.39319611, 9.5387516], [76.39319611, 9.53847122], [76.3923645, 9.53847122], [76.3923645, 9.53819466], [76.39180756, 9.53819466], [76.39180756, 9.53791714], [76.39097595, 9.53792191], [76.39097595, 9.53764153], [76.39041901, 9.53764153], [76.39041901, 9.53736115], [76.38957977, 9.53736115], [76.38957977, 9.53708267], [76.38874817, 9.53708267], [76.38874817, 9.53680515], [76.38819885, 9.53681183], [76.38819885, 9.53652], [76.38735962, 9.53652668], [76.38735962, 9.53624916], [76.38680267, 9.53625107], [76.38680267, 9.53597069], [76.38597107, 9.5359726], [76.38597107, 9.53569508], [76.38541412, 9.53569508], [76.38541412, 9.5354166], [76.38458252, 9.53541946], [76.38458252, 9.53514099], [76.3840332, 9.53514099], [76.3840332, 9.53486061], [76.38291931, 9.53486061], [76.38291931, 9.53703976], [76.38291931, 9.53736115], [76.38263702, 9.53736115], [76.38263702, 9.54069328], [76.38236237, 9.54069138], [76.38236237, 9.54181004], [76.38208008, 9.54180622], [76.38208008, 9.54319572], [76.38263702, 9.54319572], [76.38263702, 9.54347229], [76.38346863, 9.54347229], [76.38346863, 9.54374981], [76.3840332, 9.54374981], [76.3840332, 9.54403019], [76.38458252, 9.54403019], [76.38458252, 9.54430962], [76.38513947, 9.5443058], [76.38513947, 9.54458427], [76.38597107, 9.54458237], [76.38597107, 9.54486179], [76.38652802, 9.54486179], [76.38652802, 9.54514027], [76.38707733, 9.54514027], [76.38707733, 9.54541969], [76.38764191, 9.54541588], [76.38764191, 9.54569435], [76.38847351, 9.54569435], [76.38847351, 9.54597187], [76.38903046, 9.54597187], [76.38903046, 9.54625034], [76.38957977, 9.54625034], [76.38957977, 9.54653263], [76.39013672, 9.54653263], [76.39013672, 9.5468111], [76.39069366, 9.54680634], [76.39069366, 9.54708195], [76.39125061, 9.54708195], [76.39125061, 9.54736233], [76.39180756, 9.54736042], [76.39180756, 9.54763985], [76.39235687, 9.54763985], [76.39235687, 9.54792118], [76.39291382, 9.54791641], [76.39291382, 9.54819393], [76.39347076, 9.54819393], [76.39347076, 9.5484724], [76.39402771, 9.54846096], [76.39402771, 9.54874992], [76.39457703, 9.54874992], [76.39457703, 9.5490303], [76.3951416, 9.5490303], [76.3951416, 9.54931068], [76.39569092, 9.54930592], [76.39569092, 9.54958439], [76.39624786, 9.54958439], [76.39624786, 9.54986], [76.39679718, 9.54986], [76.39679718, 9.55014038], [76.39736938, 9.55014038], [76.39736938, 9.55042076], [76.3979187, 9.55041599], [76.3979187, 9.55069447], [76.39847565, 9.55069447], [76.39847565, 9.55097198], [76.39901733, 9.55097008], [76.39901733, 9.55125046], [76.39958191, 9.55125046], [76.39958191, 9.55152798], [76.40013885, 9.55151939], [76.40013885, 9.55181122], [76.40041351, 9.55180645], [76.40041351, 9.55208206], [76.40097046, 9.55208206], [76.40097046, 9.5523634], [76.4015274, 9.55235958], [76.4015274, 9.55264091], [76.4019928, 9.55263805], [76.40208435, 9.55263805], [76.40207672, 9.5529213], [76.4026413, 9.55291557], [76.4026413, 9.55319405], [76.4034729, 9.55319405], [76.4034729, 9.55347157], [76.40429688, 9.55346966], [76.40429688, 9.55375099], [76.40458679, 9.55375099], [76.40458679, 9.55653095], [76.4043045, 9.55652905], [76.4043045, 9.55847263], [76.40458679, 9.55847073], [76.40458679, 9.55903053], [76.40374756, 9.55903053], [76.40374756, 9.55931187], [76.4043045, 9.55930519], [76.4043045, 9.55958271], [76.40458679, 9.55958271], [76.40458679, 9.55986118], [76.40486145, 9.55986118], [76.40486145, 9.56014061], [76.4054184, 9.56014061], [76.4054184, 9.56042194], [76.40625, 9.56041718], [76.40625, 9.56069469], [76.40680695, 9.56069469], [76.40680695, 9.56097317], [76.40735626, 9.56097126], [76.40735626, 9.56125069], [76.40770721, 9.56125069], [76.40791321, 9.56125069], [76.40791321, 9.56153202], [76.4090271, 9.56153202], [76.4090271, 9.56180954], [76.4098587, 9.56180477], [76.4098587, 9.56208324], [76.4109726, 9.56208134], [76.4109726, 9.56236076], [76.41179657, 9.56236076], [76.41179657, 9.56263924], [76.4126358, 9.56263924], [76.4126358, 9.56291962], [76.41319275, 9.56291676], [76.41319275, 9.56319523], [76.41430664, 9.56319523]]], [[[76.37152863, 9.75847244], [76.37152863, 9.75791645], [76.37180328, 9.75792027], [76.37180328, 9.75626087], [76.3720932, 9.75626087], [76.3720932, 9.7551403], [76.37236023, 9.7551403], [76.37236023, 9.75486088], [76.37208557, 9.75486088], [76.37208557, 9.7546196], [76.37208557, 9.75430489], [76.37236023, 9.75430965], [76.37236023, 9.75403023], [76.37264252, 9.75403023], [76.37264252, 9.75319958], [76.37291718, 9.75319958], [76.37291718, 9.7523613], [76.37319183, 9.7523613], [76.37319183, 9.75180531], [76.37291718, 9.75181198], [76.37291718, 9.75125122], [76.3720932, 9.75125122], [76.3720932, 9.7515316], [76.37180328, 9.75152683], [76.37180328, 9.75208282], [76.37152863, 9.75208092], [76.37152863, 9.75264168], [76.37124634, 9.75263882], [76.37124634, 9.75347137], [76.37097168, 9.75347137], [76.37097168, 9.75458336], [76.37069702, 9.75458145], [76.37069702, 9.75541973], [76.37041473, 9.75541782], [76.3704071, 9.75598145], [76.3704071, 9.75652981], [76.37013245, 9.75652981], [76.37013245, 9.75792027], [76.37041473, 9.75791645], [76.37041473, 9.75819397], [76.37124634, 9.75819588], [76.37124634, 9.75847244], [76.37152863, 9.75847244]]], [[[76.32402802, 9.82569504], [76.32402802, 9.82541656], [76.32457733, 9.82542133], [76.32457733, 9.82486057], [76.32485962, 9.82486057], [76.32485962, 9.82430363], [76.32514954, 9.82431126], [76.32514954, 9.82375145], [76.32541656, 9.82375145], [76.32541656, 9.82319546], [76.32569122, 9.82319546], [76.32569122, 9.82291603], [76.32596588, 9.82291889], [76.32596588, 9.82235146], [76.32653046, 9.82235146], [76.32653046, 9.82264137], [76.32681274, 9.82264137], [76.32681274, 9.82291889], [76.32707977, 9.82291603], [76.32707977, 9.82347298], [76.32763672, 9.82347298], [76.32763672, 9.82319546], [76.32847595, 9.82319546], [76.32847595, 9.82180691], [76.32763672, 9.82181072], [76.32763672, 9.82096958], [76.32736206, 9.82097244], [76.32736206, 9.81958199], [76.32763672, 9.81958199], [76.32763672, 9.81847191], [76.32791901, 9.81847191], [76.32791901, 9.81791592], [76.32847595, 9.81792068], [76.32847595, 9.8176403], [76.3290329, 9.8176403], [76.3290329, 9.81735992], [76.32875061, 9.81735992], [76.32875061, 9.81680584], [76.32847595, 9.81681061], [76.32847595, 9.81624985], [76.32875061, 9.81624985], [76.32875061, 9.81597233], [76.32847595, 9.81597233], [76.32847595, 9.81569386], [76.32819366, 9.81569386], [76.32819366, 9.81541634], [76.32791901, 9.81542015], [76.32791901, 9.81431007], [76.32763672, 9.81431007], [76.32763672, 9.81208134], [76.32736206, 9.8120842], [76.32736206, 9.81041527], [76.32707977, 9.81041527], [76.32707977, 9.80958366], [76.32680511, 9.80958366], [76.32680511, 9.8087492], [76.32653046, 9.8087492], [76.32653046, 9.80819321], [76.32680511, 9.80819321], [76.32680511, 9.80791664], [76.32653046, 9.80792046], [76.32653046, 9.80764198], [76.32541656, 9.80764198], [76.32541656, 9.80735016], [76.32430267, 9.80735016], [76.32430267, 9.80764198], [76.32375336, 9.80764198], [76.32375336, 9.80792046], [76.32319641, 9.80792046], [76.32319641, 9.80902958], [76.32291412, 9.80902672], [76.32291412, 9.81097221], [76.32319641, 9.81097221], [76.32319641, 9.81236172], [76.32347107, 9.81235981], [76.32347107, 9.81348133], [76.32319641, 9.81347179], [76.32319641, 9.81486225], [76.32291412, 9.81486225], [76.32291412, 9.81708431], [76.32319641, 9.81707954], [76.32319641, 9.8215313], [76.32290649, 9.8215313], [76.32290649, 9.82264137], [76.32263947, 9.82264137], [76.32263947, 9.82375145], [76.32291412, 9.82375145], [76.32291412, 9.82486057], [76.32319641, 9.82486057], [76.32319641, 9.82542133], [76.32347107, 9.82541656], [76.32347107, 9.82569504], [76.32402802, 9.82569504]]], [[[76.37236023, 9.82569504], [76.37236023, 9.82541656], [76.37291718, 9.82542133], [76.37291718, 9.82514095], [76.37319946, 9.82514095], [76.37319946, 9.82486057], [76.37347412, 9.82486057], [76.37347412, 9.82458305], [76.37319183, 9.82458305], [76.37319183, 9.82152843], [76.37236023, 9.82152843], [76.37236023, 9.82208538], [76.37208557, 9.82208538], [76.37208557, 9.82319546], [76.37180328, 9.82318974], [76.37180328, 9.82542133], [76.37152863, 9.82541656], [76.37152863, 9.82569504], [76.37236023, 9.82569504]]], [[[76.36846924, 9.82681179], [76.36846924, 9.82653141], [76.36958313, 9.82653141], [76.36958313, 9.82625103], [76.36985779, 9.82625103], [76.36985779, 9.82569027], [76.37014008, 9.82569504], [76.37014008, 9.82513905], [76.3704071, 9.82514095], [76.3704071, 9.82431126], [76.37013245, 9.82431126], [76.37013245, 9.82403088], [76.36985779, 9.82403088], [76.36985779, 9.82431126], [76.36958313, 9.82430363], [76.36958313, 9.82458305], [76.36930847, 9.82458305], [76.36930847, 9.82486057], [76.36846924, 9.82486057], [76.36846924, 9.82514095], [76.36736298, 9.82514095], [76.36736298, 9.82542133], [76.36708069, 9.82541656], [76.36708069, 9.82569504], [76.36680603, 9.82569027], [76.36680603, 9.82681179], [76.36846924, 9.82681179]]], [[[76.28930664, 9.84736156], [76.28930664, 9.84708214], [76.28986359, 9.84708214], [76.28986359, 9.84680557], [76.2904129, 9.84681129], [76.2904129, 9.84624958], [76.29013824, 9.84624958], [76.29013824, 9.84569168], [76.28986359, 9.84569359], [76.28986359, 9.8451376], [76.2895813, 9.84514046], [76.2895813, 9.8445797], [76.28930664, 9.84458447], [76.28930664, 9.84430599], [76.28874969, 9.84431076], [76.28874969, 9.84403038], [76.28819275, 9.84403038], [76.28819275, 9.84431076], [76.28791809, 9.84430599], [76.28791809, 9.84458447], [76.2876358, 9.84458447], [76.2876358, 9.84569359], [76.28791809, 9.84569168], [76.28791809, 9.84681129], [76.28819275, 9.84680557], [76.28819275, 9.84708214], [76.28847504, 9.84708214], [76.28847504, 9.84736156], [76.28930664, 9.84736156]]], [[[76.37791443, 9.83930588], [76.37791443, 9.83958435], [76.37847137, 9.83958435], [76.37847137, 9.83902836], [76.37874603, 9.83903027], [76.37874603, 9.83847237], [76.37902832, 9.83847237], [76.37902832, 9.83791542], [76.37930298, 9.83792019], [76.37930298, 9.83708096], [76.37875366, 9.83708382], [76.37875366, 9.8368063], [76.37819672, 9.83681011], [76.37819672, 9.83652973], [76.37708282, 9.83652973], [76.37708282, 9.83681011], [76.37625122, 9.8368063], [76.37625122, 9.83736229], [76.37652588, 9.83735943], [76.37652588, 9.83792019], [76.37680817, 9.83791542], [76.37680817, 9.83847237], [76.37708282, 9.83847237], [76.37708282, 9.83903027], [76.37735748, 9.83903027], [76.37735748, 9.83930969], [76.37791443, 9.83930588]]], [[[76.37625885, 9.84125042], [76.37625885, 9.84152985], [76.37763977, 9.84152985], [76.37763977, 9.84069061], [76.37735748, 9.84069443], [76.37735748, 9.84041786], [76.37708282, 9.84041977], [76.37708282, 9.84014034], [76.37680817, 9.84014034], [76.37680817, 9.83986187], [76.37652588, 9.83986187], [76.37652588, 9.83930588], [76.37625885, 9.83930969], [76.37625885, 9.83903027], [76.37596893, 9.83903027], [76.37596893, 9.83875179], [76.37568665, 9.83875179], [76.37568665, 9.83819103], [76.37541962, 9.8381958], [76.37541962, 9.83791542], [76.37513733, 9.83792019], [76.37513733, 9.83763981], [76.37486267, 9.83763981], [76.37486267, 9.83792019], [76.37403107, 9.83791542], [76.37403107, 9.83847237], [76.37374878, 9.83847237], [76.37374878, 9.83903027], [76.37346649, 9.83903027], [76.37346649, 9.83930969], [76.37319183, 9.83930588], [76.37319183, 9.83986187], [76.37291718, 9.83986187], [76.37291718, 9.84041977], [76.37264252, 9.84041786], [76.37264252, 9.84069443], [76.37319183, 9.84069443], [76.37319183, 9.84097195], [76.37346649, 9.84097195], [76.37346649, 9.84125042], [76.37625885, 9.84125042]]], [[[76.34958649, 9.87458229], [76.34958649, 9.87402821], [76.34986115, 9.87403107], [76.34986115, 9.87319183], [76.3501358, 9.87319374], [76.3501358, 9.87208366], [76.34986115, 9.87208366], [76.34986115, 9.87097168], [76.3501358, 9.87097168], [76.3501358, 9.87041569], [76.35041809, 9.87042046], [76.35041809, 9.8698597], [76.35069275, 9.8698597], [76.35069275, 9.86930561], [76.35098267, 9.86931133], [76.35098267, 9.86847019], [76.35124969, 9.8684721], [76.35124969, 9.86763763], [76.35151672, 9.86765099], [76.35151672, 9.86708164], [76.35180664, 9.86708355], [76.35180664, 9.86625004], [76.35206604, 9.86625195], [76.35206604, 9.86569118], [76.35236359, 9.86569405], [76.35236359, 9.86513996], [76.35263824, 9.86514187], [76.35263824, 9.86486244], [76.3529129, 9.86486244], [76.3529129, 9.86458397], [76.35346985, 9.86458969], [76.35346985, 9.86431026], [76.35375214, 9.86431026], [76.35375214, 9.86403179], [76.35430908, 9.86403179], [76.35430908, 9.86374855], [76.3548584, 9.86374855], [76.3548584, 9.86347103], [76.35541534, 9.86347103], [76.35541534, 9.8629179], [76.35569763, 9.86291981], [76.35569763, 9.86236095], [76.35597229, 9.86236095], [76.35597229, 9.86180496], [76.35624695, 9.86180973], [76.35624695, 9.86069107], [76.35652924, 9.86069489], [76.35652924, 9.85986137], [76.35736084, 9.85986137], [76.35736084, 9.8595829], [76.35847473, 9.8595829], [76.35847473, 9.85930538], [76.35930634, 9.85931015], [76.35930634, 9.85903168], [76.36042023, 9.85903168], [76.36042023, 9.8587513], [76.36069489, 9.8587513], [76.36068726, 9.85819054], [76.36096954, 9.8581953], [76.36096954, 9.85791683], [76.36125946, 9.8579216], [76.36125946, 9.85764122], [76.36152649, 9.85764122], [76.36152649, 9.85736084], [76.36180878, 9.85736084], [76.36180878, 9.85708141], [76.36208344, 9.85708332], [76.36208344, 9.85680485], [76.36235809, 9.85680866], [76.36235809, 9.85652924], [76.36264038, 9.85652924], [76.36264038, 9.85624886], [76.36291504, 9.85624886], [76.36291504, 9.85597324], [76.36430359, 9.85597324], [76.36430359, 9.85569477], [76.3655014, 9.85569477], [76.36597443, 9.85569477], [76.36597443, 9.85541725], [76.36624908, 9.85542107], [76.36624908, 9.85457993], [76.36597443, 9.85458279], [76.36597443, 9.85319519], [76.36624908, 9.85319519], [76.36624908, 9.8526392], [76.36653137, 9.85264969], [76.36653137, 9.85208035], [76.36680603, 9.85208321], [76.36680603, 9.85180664], [76.36705017, 9.85181141], [76.3670578, 9.85168839], [76.36708069, 9.85125065], [76.36725616, 9.85125065], [76.36736298, 9.85125065], [76.36736298, 9.85098171], [76.36763763, 9.85097027], [76.36763763, 9.85069466], [76.36791992, 9.85069466], [76.36791992, 9.8493042], [76.36763763, 9.84931087], [76.36763763, 9.84764099], [76.36736298, 9.84764099], [76.36736298, 9.84735966], [76.36763763, 9.84736156], [76.36763763, 9.84624958], [76.36791992, 9.84624958], [76.36791992, 9.84431076], [76.36763763, 9.84431076], [76.36763763, 9.84403038], [76.36791992, 9.84403038], [76.36791992, 9.84375], [76.36818695, 9.84375], [76.36818695, 9.8429203], [76.36846924, 9.8429203], [76.36846924, 9.84235954], [76.36875153, 9.8423624], [76.36875153, 9.84180641], [76.36902618, 9.84181023], [76.36902618, 9.84125042], [76.36930847, 9.84125042], [76.36930847, 9.84097195], [76.36958313, 9.84097195], [76.36958313, 9.83986187], [76.36985779, 9.83986187], [76.36985779, 9.83958435], [76.36958313, 9.83958435], [76.36958313, 9.83902836], [76.36985779, 9.83903027], [76.36985779, 9.83819103], [76.37014008, 9.8381958], [76.37014008, 9.83736229], [76.37041473, 9.83736229], [76.37041473, 9.83652687], [76.37097168, 9.83652973], [76.37097168, 9.83541965], [76.37124634, 9.83541965], [76.37124634, 9.83485889], [76.37152863, 9.8348608], [76.37152863, 9.83430481], [76.37180328, 9.83430958], [76.37180328, 9.83292198], [76.3720932, 9.83292198], [76.3720932, 9.83125114], [76.37180328, 9.83125114], [76.37180328, 9.83097267], [76.37097168, 9.83097076], [76.37097168, 9.83069515], [76.37014008, 9.83069515], [76.37014008, 9.83041668], [76.36930847, 9.83041859], [76.36930847, 9.83014107], [76.36292267, 9.83014107], [76.36292267, 9.83041859], [76.36152649, 9.83041668], [76.36152649, 9.83069515], [76.36042023, 9.83069515], [76.36042023, 9.83097076], [76.35986328, 9.83097267], [76.35986328, 9.83125114], [76.35941315, 9.83125114], [76.35930634, 9.83125114], [76.35930634, 9.83148098], [76.35930634, 9.8318119], [76.35916138, 9.83180714], [76.35902405, 9.83180523], [76.35902405, 9.83208275], [76.35791779, 9.83208275], [76.35791779, 9.83236122], [76.35736084, 9.83236122], [76.35736084, 9.8326416], [76.35708618, 9.8326416], [76.35708618, 9.83292198], [76.35680389, 9.83291721], [76.35680389, 9.83319473], [76.35652924, 9.83319473], [76.35652924, 9.8334713], [76.35597229, 9.8334713], [76.35597229, 9.83375072], [76.35569763, 9.83375072], [76.35569763, 9.83403015], [76.35542297, 9.83403015], [76.35542297, 9.83375072], [76.35513306, 9.83375072], [76.35513306, 9.83403015], [76.35457611, 9.83403015], [76.35457611, 9.83430958], [76.35402679, 9.83430481], [76.35402679, 9.83458328], [76.35375214, 9.83458138], [76.35375214, 9.83513927], [76.35320282, 9.83513927], [76.35320282, 9.83541965], [76.3529129, 9.83541775], [76.3529129, 9.83569336], [76.35263824, 9.83569336], [76.35263824, 9.83597088], [76.35235596, 9.83597088], [76.35236359, 9.83624935], [76.35180664, 9.83624935], [76.35180664, 9.83652973], [76.35151672, 9.83652973], [76.35151672, 9.83681011], [76.35097504, 9.8368063], [76.35097504, 9.83736229], [76.35041809, 9.83736229], [76.35041809, 9.83763981], [76.34986115, 9.83763981], [76.34986115, 9.83792019], [76.34958649, 9.83791542], [76.34958649, 9.83847237], [76.34902954, 9.83847237], [76.34902954, 9.83930969], [76.34874725, 9.83930969], [76.34874725, 9.84014034], [76.34902954, 9.84014034], [76.34902954, 9.84041977], [76.34986115, 9.84041786], [76.34986115, 9.84097195], [76.3501358, 9.84097195], [76.3501358, 9.84125042], [76.35069275, 9.84125042], [76.35069275, 9.84152985], [76.35098267, 9.84152985], [76.35098267, 9.84181023], [76.35124969, 9.84180641], [76.35124969, 9.84208393], [76.35151672, 9.84208202], [76.35151672, 9.84263992], [76.35180664, 9.84263992], [76.35180664, 9.84403038], [76.35151672, 9.84403038], [76.35152435, 9.84486008], [76.35124969, 9.84486008], [76.35124969, 9.84597206], [76.35140991, 9.84597206], [76.35152435, 9.84597206], [76.35152435, 9.84652805], [76.35180664, 9.84652138], [76.35180664, 9.84764099], [76.35152435, 9.84763813], [76.35152435, 9.84819412], [76.35180664, 9.84819412], [76.35180664, 9.84958458], [76.3520813, 9.84958458], [76.3520813, 9.84986019], [76.35180664, 9.84986019], [76.35180664, 9.85014057], [76.35206604, 9.85014057], [76.35206604, 9.85236073], [76.35235596, 9.85236073], [76.35235596, 9.85292053], [76.35263824, 9.85291672], [76.35263824, 9.85375118], [76.3529129, 9.85375118], [76.3529129, 9.85458279], [76.35263824, 9.85458279], [76.35263824, 9.85569477], [76.35235596, 9.85569], [76.35235596, 9.85764122], [76.3520813, 9.85763931], [76.3520813, 9.8581953], [76.35180664, 9.8581953], [76.35180664, 9.8587513], [76.35151672, 9.8587513], [76.35151672, 9.85931015], [76.35124969, 9.85930538], [76.35124969, 9.8595829], [76.35069275, 9.8595829], [76.35069275, 9.85986137], [76.35041809, 9.85986137], [76.35041809, 9.86013889], [76.3501358, 9.86013889], [76.3501358, 9.86042023], [76.34986115, 9.86041737], [76.34986115, 9.86069489], [76.34874725, 9.86069489], [76.34874725, 9.86097336], [76.34819794, 9.86097145], [76.34819794, 9.86180973], [76.3484726, 9.86180496], [76.3484726, 9.86208344], [76.34874725, 9.86208057], [76.34874725, 9.86264038], [76.34902954, 9.86264038], [76.34902954, 9.86319256], [76.34929657, 9.86319065], [76.34929657, 9.86403179], [76.34902954, 9.86402798], [76.34902954, 9.86569405], [76.34929657, 9.86569118], [76.34929657, 9.86680984], [76.34902954, 9.86680603], [76.34902954, 9.86708355], [76.3484726, 9.86708355], [76.3484726, 9.86736202], [76.34792328, 9.86736202], [76.34792328, 9.86791992], [76.34764099, 9.86791801], [76.34764099, 9.86819363], [76.3473587, 9.86818886], [76.3473587, 9.86931133], [76.34708405, 9.86930561], [76.34708405, 9.86958408], [76.3473587, 9.86957932], [76.3473587, 9.87014008], [76.34764099, 9.87014008], [76.34764099, 9.87069416], [76.34792328, 9.87068939], [76.34792328, 9.87152958], [76.34819794, 9.87152958], [76.34819794, 9.87263966], [76.3484726, 9.87263775], [76.3484726, 9.87347221], [76.34874725, 9.87345886], [76.34874725, 9.87431145], [76.3493042, 9.87430573], [76.3493042, 9.87458229], [76.34958649, 9.87458229]]], [[[76.38541412, 9.62069321], [76.38541412, 9.62041759], [76.38597107, 9.62042046], [76.38597107, 9.62014198], [76.38625336, 9.62014198], [76.38625336, 9.62042046], [76.38652802, 9.62042046], [76.38652802, 9.61986065], [76.38680267, 9.61986065], [76.38680267, 9.62014198], [76.38707733, 9.62014198], [76.38707733, 9.61986065], [76.38764191, 9.61986065], [76.38764191, 9.61930466], [76.38791656, 9.61931038], [76.38791656, 9.61903191], [76.38764191, 9.61903191], [76.38764191, 9.6176424], [76.38735962, 9.6176424], [76.38735962, 9.61736107], [76.38707733, 9.61736107], [76.38707733, 9.61680984], [76.38680267, 9.61680984], [76.38680267, 9.61569118], [76.38652802, 9.615695], [76.38652802, 9.61541653], [76.38625336, 9.61541653], [76.38625336, 9.615695], [76.38597107, 9.615695], [76.38597107, 9.61458302], [76.38541412, 9.61458302], [76.38541412, 9.61430454], [76.38513947, 9.61430931], [76.38513947, 9.61375141], [76.38485718, 9.61375141], [76.38485718, 9.61347103], [76.38458252, 9.61347294], [76.38458252, 9.61374855], [76.38402557, 9.61375141], [76.38402557, 9.61458302], [76.38430786, 9.61458302], [76.38430786, 9.61486053], [76.38318634, 9.61486053], [76.38318634, 9.61541939], [76.38291931, 9.61541653], [76.38291931, 9.615695], [76.38236237, 9.615695], [76.38236237, 9.61597347], [76.38207245, 9.61597061], [76.38207245, 9.61625099], [76.38181305, 9.61625099], [76.38181305, 9.61793137], [76.38208008, 9.61791706], [76.38208008, 9.61847115], [76.38236237, 9.61847115], [76.38236237, 9.61903191], [76.38263702, 9.61903191], [76.38263702, 9.61931038], [76.38402557, 9.61930466], [76.38402557, 9.61986065], [76.38430786, 9.61986065], [76.38430786, 9.62014198], [76.38458252, 9.62014198], [76.38458252, 9.62042046], [76.38513947, 9.62041759], [76.38513947, 9.62069321], [76.38541412, 9.62069321]]], [[[76.38124847, 9.71458244], [76.38069153, 9.71457958], [76.38069153, 9.7151413], [76.38096619, 9.7151413], [76.38096619, 9.71681118], [76.38124847, 9.71681118], [76.38124847, 9.71709156], [76.38181305, 9.71709156], [76.38181305, 9.7165308], [76.38153076, 9.7165308], [76.38153076, 9.71485996], [76.38124847, 9.71485996], [76.38124847, 9.71458244]]], [[[76.23986053, 10.10237026], [76.23986053, 10.1020813], [76.24013519, 10.10208321], [76.24013519, 10.10180473], [76.24067688, 10.10181046], [76.24067688, 10.10153198], [76.24124908, 10.10153198], [76.24124908, 10.10125065], [76.24153137, 10.10125065], [76.24153137, 10.10097122], [76.24208069, 10.10097313], [76.24208069, 10.10069466], [76.24263763, 10.10069466], [76.24263763, 10.09958267], [76.24291992, 10.09958267], [76.24291992, 10.09930515], [76.24318695, 10.09931183], [76.24318695, 10.09903145], [76.24346924, 10.09903145], [76.24346924, 10.09875107], [76.24373627, 10.09875107], [76.24373627, 10.09847069], [76.24458313, 10.0984726], [76.24458313, 10.09819508], [76.24485779, 10.09819508], [76.24485779, 10.0979166], [76.24514008, 10.09792233], [76.24514008, 10.09764099], [76.2454071, 10.09764099], [76.2454071, 10.09736061], [76.24597168, 10.09736061], [76.24597168, 10.09708309], [76.24624634, 10.09708309], [76.24624634, 10.09680462], [76.24652863, 10.09680939], [76.24652863, 10.09597111], [76.24680328, 10.09597301], [76.24680328, 10.09513855], [76.2470932, 10.09514141], [76.2470932, 10.0945797], [76.24736023, 10.09458256], [76.24736023, 10.09402561], [76.24764252, 10.09403133], [76.24764252, 10.09346962], [76.24791718, 10.09347343], [76.24791718, 10.09291744], [76.24819183, 10.09292126], [76.24819183, 10.09068966], [76.24764252, 10.09069443], [76.24764252, 10.09125042], [76.24736023, 10.09125042], [76.24736023, 10.09181118], [76.24708557, 10.09180355], [76.24708557, 10.09235954], [76.24680328, 10.09235954], [76.24680328, 10.09292126], [76.24652863, 10.09291744], [76.24652863, 10.09319496], [76.24624634, 10.09318066], [76.24624634, 10.09375095], [76.24597168, 10.09375095], [76.24597168, 10.09486103], [76.24541473, 10.09486103], [76.24541473, 10.09569454], [76.24514008, 10.09568977], [76.24514008, 10.09653091], [76.24373627, 10.09653091], [76.24373627, 10.09680939], [76.24346924, 10.09680462], [76.24346924, 10.09736061], [76.24263763, 10.09736061], [76.24263763, 10.09708309], [76.24236298, 10.09708309], [76.24236298, 10.09680462], [76.24180603, 10.09680939], [76.24180603, 10.09181118], [76.24041748, 10.09181118], [76.24041748, 10.09292126], [76.24067688, 10.09292126], [76.24069214, 10.09486103], [76.24041748, 10.09486103], [76.24041748, 10.09569454], [76.24013519, 10.09569454], [76.24013519, 10.09624863], [76.24041748, 10.09624195], [76.24041748, 10.09680939], [76.24069214, 10.09680462], [76.24069214, 10.09736061], [76.24208069, 10.09736061], [76.24208069, 10.09764099], [76.24318695, 10.09764099], [76.24318695, 10.09792233], [76.24263763, 10.0979166], [76.24263763, 10.09819508], [76.24208069, 10.09819508], [76.24208069, 10.0984726], [76.23929596, 10.09847069], [76.23929596, 10.09875107], [76.23902893, 10.09875107], [76.23902893, 10.09931183], [76.23874664, 10.09930515], [76.23874664, 10.09958267], [76.23902893, 10.09958267], [76.23902893, 10.09986115], [76.23874664, 10.09986115], [76.23874664, 10.10042191], [76.23847198, 10.10041714], [76.23847198, 10.10097313], [76.23819733, 10.10097122], [76.23819733, 10.10125065], [76.2379303, 10.10125065], [76.2379303, 10.10181046], [76.23847198, 10.10180473], [76.23847198, 10.10208321], [76.23902893, 10.1020813], [76.23902893, 10.10237026], [76.23986053, 10.10237026]]], [[[75.81124878, 11.16180611], [75.81124878, 11.16152763], [75.81153107, 11.16152954], [75.81153107, 11.16068935], [75.81124878, 11.16069412], [75.81124878, 11.15958405], [75.81097412, 11.15958405], [75.81097412, 11.15930557], [75.81014252, 11.15931034], [75.81014252, 11.16042042], [75.81040955, 11.16042042], [75.81040955, 11.16152954], [75.81097412, 11.16152763], [75.81097412, 11.16180611], [75.81124878, 11.16180611]]], [[[75.8381958, 11.13431072], [75.8381958, 11.13403034], [75.83847046, 11.13403034], [75.83847046, 11.13374996], [75.8381958, 11.13374996], [75.8381958, 11.13309956], [75.8381958, 11.13263988], [75.83790588, 11.13264179], [75.83790588, 11.13182163], [75.83763885, 11.13182163], [75.83763885, 11.13125038], [75.83735657, 11.13125038], [75.83735657, 11.13069057], [75.83708191, 11.13069439], [75.83708191, 11.12986183], [75.83680725, 11.12986183], [75.83680725, 11.12930584], [75.83651733, 11.12930965], [75.83651733, 11.12876129], [75.83625031, 11.12876129], [75.83625031, 11.12819099], [75.83597565, 11.12819576], [75.83597565, 11.12791538], [75.8354187, 11.12792015], [75.8354187, 11.12764168], [75.83457947, 11.12764168], [75.83457947, 11.12735939], [75.83403015, 11.12736225], [75.83403015, 11.12708282], [75.83319092, 11.12708282], [75.83319092, 11.12680531], [75.83235931, 11.12681007], [75.83235931, 11.12652969], [75.83152771, 11.12652683], [75.83152771, 11.12708282], [75.83125305, 11.12708282], [75.83125305, 11.12763023], [75.83097076, 11.12764168], [75.83097076, 11.12903023], [75.83040619, 11.12903023], [75.83040619, 11.12930965], [75.83013916, 11.12930584], [75.83013916, 11.12986183], [75.83154297, 11.12986183], [75.83154297, 11.13041973], [75.83235931, 11.13041782], [75.83235931, 11.13069439], [75.8326416, 11.13069439], [75.8326416, 11.13125038], [75.83291626, 11.13125038], [75.83291626, 11.1315279], [75.83319092, 11.1315279], [75.83319092, 11.13182163], [75.83347321, 11.13180637], [75.83347321, 11.13208389], [75.83374786, 11.13208389], [75.83374786, 11.13236237], [75.83428955, 11.13236046], [75.83428955, 11.13292027], [75.83486176, 11.13291645], [75.83486176, 11.13319397], [75.83513641, 11.13319397], [75.83513641, 11.13347244], [75.83569336, 11.13346958], [75.83569336, 11.13374996], [75.83625031, 11.13374996], [75.83625031, 11.13403034], [75.83735657, 11.13403034], [75.83735657, 11.13431072], [75.8381958, 11.13431072]]], [[[75.15763855, 12.1093111], [75.15763855, 12.10902882], [75.15791321, 12.10903072], [75.15791321, 12.10875034], [75.15820313, 12.10875034], [75.15820313, 12.10848236], [75.1581955, 12.10819435], [75.15847015, 12.10819435], [75.15847015, 12.10763836], [75.15875244, 12.10764122], [75.15875244, 12.10736275], [75.15892029, 12.10735989], [75.1590271, 12.10736275], [75.1590271, 12.10696125], [75.1590271, 12.1068058], [75.15957642, 12.10681057], [75.15957642, 12.10625267], [75.1598587, 12.10625267], [75.1598587, 12.10597038], [75.16041565, 12.10597229], [75.16041565, 12.10569382], [75.16069794, 12.10569382], [75.16069794, 12.1054163], [75.1609726, 12.10542107], [75.1609726, 12.10486031], [75.16124725, 12.10486221], [75.16124725, 12.10458374], [75.16152954, 12.10458374], [75.16152954, 12.10402775], [75.16179657, 12.10402966], [75.16179657, 12.10374069], [75.16208649, 12.10375023], [75.16208649, 12.10319424], [75.16236115, 12.10319424], [75.16236115, 12.10264015], [75.16291809, 12.10264015], [75.16291809, 12.10236168], [75.16346741, 12.10236168], [75.16346741, 12.10207939], [75.16402435, 12.10208416], [75.16402435, 12.10180569], [75.16430664, 12.10181141], [75.16430664, 12.10153008], [75.16485596, 12.10153008], [75.16485596, 12.10068035], [75.16513824, 12.1006937], [75.16513824, 12.10013771], [75.1654129, 12.10013962], [75.1654129, 12.09902954], [75.16570282, 12.09902954], [75.16570282, 12.09875202], [75.1654129, 12.09875202], [75.1654129, 12.09793091], [75.16513824, 12.09793091], [75.16513824, 12.09764194], [75.1654129, 12.09764194], [75.1654129, 12.09681034], [75.16570282, 12.09681034], [75.16570282, 12.09487057], [75.16596985, 12.09487057], [75.16596985, 12.09264183], [75.16623688, 12.09264183], [75.16624451, 12.09175968], [75.16625214, 12.09125137], [75.16641998, 12.09125137], [75.16652679, 12.09125137], [75.16652679, 12.09087086], [75.16652679, 12.09041691], [75.16623688, 12.09042168], [75.16623688, 12.0893116], [75.16652679, 12.0893116], [75.16652679, 12.08819008], [75.16680908, 12.08819485], [75.16680908, 12.08791733], [75.16707611, 12.08791924], [75.16707611, 12.08763885], [75.16764069, 12.08763885], [75.16764069, 12.08681202], [75.1673584, 12.08681202], [75.1673584, 12.08653069], [75.16764069, 12.08653069], [75.16764069, 12.08570194], [75.16792297, 12.08570194], [75.16792297, 12.08514118], [75.16819763, 12.08514118], [75.16819763, 12.0848608], [75.16847229, 12.0848608], [75.16847229, 12.08458328], [75.16874695, 12.08458328], [75.16874695, 12.0840292], [75.16902924, 12.08403111], [75.16902924, 12.08375072], [75.16931152, 12.08375072], [75.16931152, 12.08318996], [75.16958618, 12.08319473], [75.16958618, 12.08291626], [75.16986084, 12.08292103], [75.16986084, 12.08208179], [75.17041779, 12.08208466], [75.17041779, 12.08152866], [75.17095947, 12.08150959], [75.17097473, 12.08097172], [75.17124939, 12.08097172], [75.17124939, 12.0806942], [75.17180634, 12.0806942], [75.17180634, 12.07985973], [75.17208099, 12.07985973], [75.17208099, 12.07956791], [75.17236328, 12.07958221], [75.17236328, 12.07874966], [75.17263794, 12.07874966], [75.17263794, 12.07847023], [75.17292023, 12.07847214], [75.17292023, 12.07791615], [75.17318726, 12.07792091], [75.17318726, 12.07736015], [75.17375183, 12.07736206], [75.17375183, 12.07680607], [75.17402649, 12.07680607], [75.17402649, 12.0765276], [75.17430878, 12.07653046], [75.17430878, 12.07625008], [75.17456818, 12.07621956], [75.17458344, 12.07458401], [75.17485809, 12.07458401], [75.17485809, 12.07374954], [75.17457581, 12.07376099], [75.17458344, 12.07332134], [75.17458344, 12.07291794], [75.17430878, 12.07291985], [75.17430878, 12.07264042], [75.17457581, 12.07264042], [75.17457581, 12.07236195], [75.17430878, 12.07236195], [75.17430878, 12.07208061], [75.17458344, 12.07208443], [75.17458344, 12.07180595], [75.17430878, 12.07180977], [75.17430878, 12.07042027], [75.17457581, 12.07042027], [75.17457581, 12.06985855], [75.17485809, 12.06986237], [75.17485809, 12.06958389], [75.17458344, 12.06958389], [75.17458344, 12.06930542], [75.17485809, 12.06931019], [75.17485809, 12.06847095], [75.17514038, 12.06847095], [75.17514038, 12.06680489], [75.17569733, 12.06680965], [75.17569733, 12.06597137], [75.17597198, 12.06597328], [75.17597198, 12.06569481], [75.17652893, 12.06569481], [75.17652893, 12.06513882], [75.17679596, 12.06514168], [75.17679596, 12.06456947], [75.17708588, 12.06458282], [75.17708588, 12.06402683], [75.17736053, 12.0640316], [75.17736053, 12.06319141], [75.17763519, 12.06319523], [75.17763519, 12.06263924], [75.17791748, 12.06264114], [75.17791748, 12.06208134], [75.17819214, 12.06208324], [75.17819214, 12.06180477], [75.1784668, 12.06182098], [75.1784668, 12.06125069], [75.17874908, 12.06125069], [75.17874908, 12.06068993], [75.17930603, 12.06069469], [75.17930603, 12.05986118], [75.17958069, 12.05986118], [75.17958069, 12.05902672], [75.17986298, 12.05903053], [75.17986298, 12.05846977], [75.18013763, 12.05847263], [75.18013763, 12.05708218], [75.18041992, 12.05708218], [75.18041992, 12.05597305], [75.18069458, 12.05597305], [75.18069458, 12.05513763], [75.18096924, 12.05514145], [75.18096924, 12.05457973], [75.18125153, 12.05458546], [75.18125153, 12.05375004], [75.18152618, 12.05375004], [75.18152618, 12.05153275], [75.18180847, 12.05153275], [75.18180847, 12.04986], [75.18125153, 12.04986], [75.18125153, 12.05042076], [75.18096924, 12.05042076], [75.18096924, 12.05125046], [75.18068695, 12.05125046], [75.18068695, 12.05153275], [75.18041992, 12.05152798], [75.18041992, 12.05208206], [75.18013763, 12.05208206], [75.18013763, 12.05263805], [75.17986298, 12.05263805], [75.17986298, 12.05319405], [75.17958069, 12.05319405], [75.17958069, 12.05347157], [75.17930603, 12.05346966], [75.17930603, 12.05403137], [75.17903137, 12.05403137], [75.17903137, 12.05542088], [75.17874908, 12.05541611], [75.17874908, 12.05569363], [75.1784668, 12.05569172], [75.1784668, 12.05625057], [75.17817688, 12.05625057], [75.17817688, 12.05681133], [75.17791748, 12.05681133], [75.17791748, 12.05736065], [75.17763519, 12.05736065], [75.17763519, 12.05847263], [75.17736053, 12.05846977], [75.17736053, 12.05903053], [75.17708588, 12.05902672], [75.17708588, 12.05958271], [75.17679596, 12.05957985], [75.17679596, 12.06042099], [75.17652893, 12.06042099], [75.17652893, 12.06125069], [75.17624664, 12.06125069], [75.17624664, 12.06182098], [75.17597198, 12.06180477], [75.17597198, 12.06208324], [75.17569733, 12.06208134], [75.17569733, 12.06264114], [75.17540741, 12.06264114], [75.17540741, 12.06347084], [75.17514038, 12.06347084], [75.17514038, 12.06458282], [75.17485809, 12.06456947], [75.17485809, 12.06514168], [75.17458344, 12.06513882], [75.17458344, 12.06569481], [75.17430878, 12.06569099], [75.17430878, 12.06653023], [75.17402649, 12.06652737], [75.17402649, 12.06708336], [75.17375183, 12.06708336], [75.17375183, 12.06763935], [75.17346954, 12.06763935], [75.17346954, 12.06819344], [75.17319489, 12.06819344], [75.17319489, 12.06847095], [75.17292023, 12.06847095], [75.17292023, 12.06902981], [75.17263794, 12.06902981], [75.17263794, 12.07042027], [75.17237091, 12.07042027], [75.17237091, 12.07069969], [75.17208099, 12.07069969], [75.17208099, 12.07180977], [75.17180634, 12.07180977], [75.17180634, 12.07291985], [75.17152405, 12.07291794], [75.17152405, 12.07319355], [75.17124939, 12.07319069], [75.17124939, 12.07376099], [75.1709671, 12.07376099], [75.1709671, 12.0743103], [75.17069244, 12.0743103], [75.17069244, 12.07514], [75.17041779, 12.07514], [75.17041779, 12.0759716], [75.17014313, 12.0759697], [75.17014313, 12.07653046], [75.16986084, 12.0765276], [75.16986084, 12.07708359], [75.16958618, 12.07708359], [75.16958618, 12.07819366], [75.16931152, 12.07818985], [75.16931152, 12.07903099], [75.16902924, 12.07902813], [75.16902924, 12.07958221], [75.16874695, 12.07956791], [75.16874695, 12.08014107], [75.16847229, 12.08013821], [75.16847229, 12.0806942], [75.16819763, 12.0806942], [75.16819763, 12.08208466], [75.16792297, 12.08208179], [75.16792297, 12.08264065], [75.16764069, 12.08263779], [75.16764069, 12.08319473], [75.1673584, 12.08318996], [75.1673584, 12.08375072], [75.16707611, 12.08375072], [75.16707611, 12.08431053], [75.16680908, 12.08430672], [75.16680908, 12.0848608], [75.16652679, 12.0848608], [75.16652679, 12.08514118], [75.16625214, 12.08513927], [75.16625214, 12.08597279], [75.16596985, 12.08597088], [75.16596985, 12.08653069], [75.16569519, 12.08652878], [75.16569519, 12.08736134], [75.1654129, 12.08736134], [75.1654129, 12.08791924], [75.16513824, 12.08791733], [75.16513824, 12.08847332], [75.16486359, 12.08847332], [75.16486359, 12.08874893], [75.1645813, 12.08874035], [75.1645813, 12.0893116], [75.16430664, 12.0893116], [75.16430664, 12.0901413], [75.16401672, 12.0901413], [75.16401672, 12.09152889], [75.16374969, 12.09152699], [75.16374969, 12.09180546], [75.16346741, 12.09180069], [75.16346741, 12.09264183], [75.16319275, 12.09263897], [75.16319275, 12.09347343], [75.16291809, 12.09347343], [75.16291809, 12.09458256], [75.1626358, 12.09458065], [75.1626358, 12.09542179], [75.16236115, 12.09541798], [75.16236115, 12.09597111], [75.16208649, 12.0959692], [75.16208649, 12.09624863], [75.16179657, 12.09624863], [75.16179657, 12.09653187], [75.16152954, 12.09653187], [75.16152954, 12.09793091], [75.16124725, 12.0979147], [75.16124725, 12.09847164], [75.1609726, 12.09847164], [75.1609726, 12.09902954], [75.16069794, 12.09902763], [75.16069794, 12.09958363], [75.16043091, 12.09957886], [75.16043091, 12.10042], [75.16014099, 12.10041809], [75.16014099, 12.10097218], [75.1598587, 12.10097027], [75.1598587, 12.10264015], [75.15957642, 12.10264015], [75.15957642, 12.10291958], [75.15930176, 12.10291958], [75.15930176, 12.10402966], [75.1590271, 12.10402966], [75.1590271, 12.10431099], [75.15875244, 12.10430622], [75.15875244, 12.10458374], [75.15847015, 12.10458183], [75.15847015, 12.10542107], [75.1581955, 12.1054163], [75.1581955, 12.10597229], [75.15791321, 12.10597038], [75.15791321, 12.10653114], [75.15763855, 12.10652828], [75.15763855, 12.10819435], [75.15737152, 12.10818958], [75.15737152, 12.10903072], [75.1570816, 12.10902882], [75.1570816, 12.10958195], [75.15763855, 12.10958195], [75.15763855, 12.1093111]]], [[[75.19403076, 12.11625099], [75.19403076, 12.11597061], [75.19430542, 12.11597347], [75.19430542, 12.11541653], [75.19458008, 12.11541939], [75.19458008, 12.11403084], [75.19431305, 12.11403084], [75.19431305, 12.11375141], [75.19403076, 12.11375141], [75.19403076, 12.11347103], [75.19291687, 12.11347103], [75.19291687, 12.11375141], [75.19180298, 12.11375141], [75.19180298, 12.11403084], [75.1920929, 12.11403084], [75.1920929, 12.11541939], [75.19235992, 12.11541653], [75.19235992, 12.115695], [75.19264221, 12.115695], [75.19264221, 12.11597347], [75.19319153, 12.11597061], [75.19319153, 12.11625099], [75.19403076, 12.11625099]]], [[[75.13541412, 12.18597221], [75.13541412, 12.18569374], [75.13597107, 12.18569374], [75.13597107, 12.18513775], [75.13626099, 12.18514919], [75.13626099, 12.18457985], [75.13652802, 12.18458366], [75.13652802, 12.18375015], [75.13680267, 12.18375015], [75.13680267, 12.18318939], [75.13708496, 12.18319416], [75.13708496, 12.18264008], [75.13764191, 12.18264008], [75.13764191, 12.1823597], [75.13791656, 12.1823597], [75.13791656, 12.18209076], [75.13846588, 12.18209076], [75.13846588, 12.18181038], [75.13874817, 12.18181038], [75.13874817, 12.18153], [75.13903046, 12.18153], [75.13903046, 12.18124962], [75.13957977, 12.18124962], [75.13957977, 12.18096924], [75.13986206, 12.1809721], [75.13986206, 12.18069363], [75.14041901, 12.18069363], [75.14041901, 12.18041801], [75.14068604, 12.18041992], [75.14068604, 12.17930984], [75.14097595, 12.17930984], [75.14097595, 12.17819118], [75.14069366, 12.17819309], [75.14069366, 12.17541695], [75.14125061, 12.17541981], [75.14125061, 12.17458057], [75.14097595, 12.17458344], [75.14097595, 12.17402744], [75.14125061, 12.1740303], [75.14125061, 12.17319107], [75.14152527, 12.17319489], [75.14152527, 12.17263889], [75.14180756, 12.17263889], [75.14180756, 12.17181015], [75.14206696, 12.17181015], [75.14206696, 12.1712513], [75.14235687, 12.1712513], [75.14235687, 12.17069054], [75.14263916, 12.1706953], [75.14263916, 12.17041683], [75.14290619, 12.1704216], [75.14290619, 12.17015266], [75.14319611, 12.17015266], [75.14319611, 12.16986084], [75.14347076, 12.16986084], [75.14347076, 12.16958141], [75.14375305, 12.16958332], [75.14375305, 12.16902924], [75.14402771, 12.16902924], [75.14402771, 12.16874886], [75.14430237, 12.16874886], [75.14430237, 12.16847324], [75.14458466, 12.16847324], [75.14458466, 12.16819477], [75.14485931, 12.16819477], [75.14485931, 12.16791725], [75.1451416, 12.16792107], [75.1451416, 12.16764069], [75.14543152, 12.16764069], [75.14543152, 12.16736126], [75.14569092, 12.16736126], [75.14569092, 12.16708279], [75.14597321, 12.16708279], [75.14597321, 12.16680527], [75.14624786, 12.16681099], [75.14624786, 12.16653061], [75.14653015, 12.16653061], [75.14653015, 12.16625118], [75.14679718, 12.16625118], [75.14679718, 12.16596985], [75.1470871, 12.16597271], [75.1470871, 12.16569519], [75.14736176, 12.16569519], [75.14736176, 12.16541672], [75.14763641, 12.16542053], [75.14763641, 12.16514111], [75.1479187, 12.16514111], [75.1479187, 12.16486073], [75.14820099, 12.16486073], [75.14819336, 12.16430664], [75.14849091, 12.16431141], [75.14849091, 12.16401958], [75.14875031, 12.16402912], [75.14875031, 12.16375065], [75.14901733, 12.16375065], [75.14901733, 12.1631918], [75.14930725, 12.1631937], [75.14930725, 12.16236019], [75.14958191, 12.16236019], [75.14958191, 12.16152763], [75.14985657, 12.16153145], [75.14985657, 12.16125011], [75.15013885, 12.16125011], [75.15013885, 12.16097927], [75.15040588, 12.16097927], [75.15040588, 12.16069031], [75.1506958, 12.16069412], [75.1506958, 12.16041565], [75.15097046, 12.16042137], [75.15097046, 12.16014004], [75.15123749, 12.16014004], [75.15123749, 12.15985966], [75.1515274, 12.15986156], [75.1515274, 12.15958214], [75.15180206, 12.15958214], [75.15180206, 12.15874958], [75.15207672, 12.15874958], [75.15207672, 12.15819168], [75.15180206, 12.15819359], [75.15180206, 12.15597153], [75.1515274, 12.15597153], [75.1515274, 12.15569401], [75.15180206, 12.15569401], [75.15180206, 12.15430641], [75.1515274, 12.15431023], [75.1515274, 12.15402985], [75.15123749, 12.15402985], [75.15123749, 12.15375042], [75.1506958, 12.15375042], [75.1506958, 12.15319061], [75.15041351, 12.15319443], [75.15041351, 12.15291786], [75.15013885, 12.15291977], [75.15013885, 12.15208054], [75.15041351, 12.15208435], [75.15041351, 12.15180588], [75.15013885, 12.15180969], [75.15013885, 12.15042019], [75.15040588, 12.15042019], [75.15040588, 12.14931011], [75.1506958, 12.14931011], [75.1506958, 12.14763927], [75.15040588, 12.14763927], [75.15040588, 12.14735889], [75.1506958, 12.1473608], [75.1506958, 12.14708328], [75.15013885, 12.14708328], [75.15013885, 12.14680481], [75.1498642, 12.14680481], [75.1498642, 12.1473608], [75.14958191, 12.14735889], [75.14958191, 12.14791965], [75.14930725, 12.14791965], [75.14930725, 12.14874935], [75.14901733, 12.14874935], [75.14901733, 12.14931011], [75.14875031, 12.14931011], [75.14875031, 12.15042019], [75.14849091, 12.15042019], [75.14849091, 12.15125179], [75.14820099, 12.15125179], [75.14820099, 12.15153027], [75.1479187, 12.15153027], [75.1479187, 12.15180969], [75.14763641, 12.15180969], [75.14763641, 12.15236187], [75.14736176, 12.15236187], [75.14736176, 12.15264034], [75.1470871, 12.15263844], [75.1470871, 12.15347195], [75.14680481, 12.15347195], [75.14680481, 12.15458393], [75.14653015, 12.15458393], [75.14653015, 12.15597153], [75.14624786, 12.15597153], [75.14624786, 12.15708447], [75.14597321, 12.1570797], [75.14597321, 12.15764046], [75.14569092, 12.1576376], [75.14569092, 12.15819359], [75.14543152, 12.15819168], [75.14543152, 12.15874958], [75.1451416, 12.15874958], [75.1451416, 12.16014004], [75.14485931, 12.16013813], [75.14485931, 12.16236019], [75.14458466, 12.16236019], [75.14458466, 12.16402912], [75.14430237, 12.16401958], [75.14430237, 12.16514111], [75.14402771, 12.16514111], [75.14402771, 12.16625118], [75.14375305, 12.16625118], [75.14375305, 12.16736126], [75.14347076, 12.16736126], [75.14347076, 12.16792107], [75.14319611, 12.16791725], [75.14319611, 12.16847324], [75.14290619, 12.16847134], [75.14290619, 12.16902924], [75.14263916, 12.16902733], [75.14263916, 12.16958332], [75.14235687, 12.16958141], [75.14235687, 12.17015266], [75.14206696, 12.17015266], [75.14206696, 12.1704216], [75.14180756, 12.17041683], [75.14180756, 12.17097092], [75.14152527, 12.17097092], [75.1415329, 12.1712513], [75.14125061, 12.1712513], [75.14125061, 12.17153168], [75.14097595, 12.17152691], [75.14097595, 12.1720829], [75.14069366, 12.1720829], [75.14069366, 12.17236137], [75.14041901, 12.17236137], [75.14041901, 12.17292023], [75.14013672, 12.17291737], [75.14013672, 12.17319489], [75.13986206, 12.17319107], [75.13986206, 12.17375088], [75.13957977, 12.17375088], [75.13957977, 12.1740303], [75.13929749, 12.1740303], [75.13929749, 12.17430973], [75.13957977, 12.17430973], [75.13957977, 12.17486095], [75.13929749, 12.17486095], [75.13929749, 12.17513943], [75.13903046, 12.17513943], [75.13903046, 12.17569637], [75.13874817, 12.17569637], [75.13874817, 12.17708397], [75.13846588, 12.17708111], [75.13846588, 12.17792034], [75.13819122, 12.17791462], [75.13819122, 12.17847157], [75.13764191, 12.17847157], [75.13764191, 12.17930984], [75.13735962, 12.17930984], [75.13735962, 12.18041992], [75.13707733, 12.18041992], [75.13707733, 12.1823597], [75.13680267, 12.1823597], [75.13680267, 12.18292046], [75.13652802, 12.18291569], [75.13652802, 12.18347168], [75.13625336, 12.18347168], [75.13626099, 12.18375015], [75.13569641, 12.18375015], [75.13569641, 12.18264008], [75.13540649, 12.18264008], [75.13540649, 12.18181038], [75.13513947, 12.18181038], [75.13513947, 12.18153], [75.13485718, 12.18153], [75.13485718, 12.18181038], [75.13458252, 12.18181038], [75.13458252, 12.1823597], [75.13430786, 12.1823597], [75.13430786, 12.18375015], [75.1340332, 12.18375015], [75.1340332, 12.18431091], [75.13430786, 12.18430614], [75.13430786, 12.18458366], [75.13458252, 12.18457985], [75.13458252, 12.18514919], [75.13486481, 12.18513775], [75.13486481, 12.18569374], [75.13513947, 12.18569374], [75.13513947, 12.18597221], [75.13541412, 12.18597221]]], [[[75.13181305, 12.19153118], [75.13181305, 12.1912508], [75.13208008, 12.1912508], [75.13208008, 12.19096088], [75.13263702, 12.19097328], [75.13263702, 12.19069481], [75.13319397, 12.19069481], [75.13319397, 12.19013786], [75.13346863, 12.19014072], [75.13346863, 12.18986034], [75.13375092, 12.18986034], [75.13375092, 12.18958473], [75.13402557, 12.18958473], [75.13402557, 12.18930435], [75.13430786, 12.18931103], [75.13430786, 12.18819046], [75.13402557, 12.18819427], [75.13402557, 12.18735981], [75.1332016, 12.18736172], [75.1332016, 12.18792057], [75.13291931, 12.1879158], [75.13291931, 12.18819427], [75.13263702, 12.18819046], [75.13263702, 12.18847179], [75.13236237, 12.18847179], [75.13236237, 12.18875027], [75.13208008, 12.18875027], [75.13208008, 12.18931103], [75.13181305, 12.18931103], [75.13181305, 12.1904211], [75.13153076, 12.1904211], [75.13153076, 12.1912508], [75.13124847, 12.1912508], [75.13124847, 12.19153118], [75.13181305, 12.19153118]]], [[[75.16346741, 12.11541939], [75.16346741, 12.11514091], [75.16374969, 12.11514091], [75.16374969, 12.11486053], [75.16430664, 12.11486053], [75.16430664, 12.11458302], [75.1645813, 12.11458302], [75.1645813, 12.11430454], [75.1654129, 12.11430931], [75.1654129, 12.11375141], [75.16570282, 12.11375141], [75.16569519, 12.11347294], [75.16652679, 12.11347294], [75.16652679, 12.11319542], [75.16708374, 12.11319542], [75.16708374, 12.11263943], [75.16819763, 12.11264133], [75.16819763, 12.11236095], [75.16874695, 12.11236095], [75.16874695, 12.11207962], [75.16902924, 12.11208344], [75.16902924, 12.11180687], [75.16931152, 12.11181068], [75.16931152, 12.11153126], [75.16986084, 12.11153126], [75.16986084, 12.11096954], [75.1701355, 12.11097336], [75.1701355, 12.11069489], [75.17041779, 12.11069489], [75.17041779, 12.11013794], [75.17069244, 12.1101408], [75.17069244, 12.10903072], [75.1709671, 12.10903072], [75.1709671, 12.10875034], [75.17069244, 12.10875034], [75.17069244, 12.10764122], [75.17041779, 12.10764122], [75.17041779, 12.10736275], [75.17014313, 12.10736275], [75.17014313, 12.10653114], [75.16986084, 12.10653114], [75.16986084, 12.10625267], [75.16958618, 12.10625267], [75.16958618, 12.10569191], [75.16930389, 12.10569382], [75.16930389, 12.10458374], [75.16902924, 12.10458374], [75.16902924, 12.10430622], [75.16931152, 12.10431099], [75.16931152, 12.10402966], [75.16902924, 12.10402966], [75.16902924, 12.10374069], [75.16930389, 12.10375023], [75.16930389, 12.10319424], [75.16958618, 12.10319424], [75.16958618, 12.10291576], [75.16986084, 12.10291958], [75.16986084, 12.10181141], [75.17014313, 12.10181141], [75.17014313, 12.10124969], [75.17041779, 12.10124969], [75.17041779, 12.10097027], [75.17097473, 12.10097218], [75.17097473, 12.1006937], [75.17152405, 12.1006937], [75.17152405, 12.09930611], [75.17124939, 12.09930992], [75.17124939, 12.09847164], [75.17097473, 12.09847164], [75.17097473, 12.09819412], [75.17069244, 12.09819412], [75.17069244, 12.0979147], [75.17041779, 12.09793091], [75.17041779, 12.09764194], [75.17014313, 12.09764194], [75.17014313, 12.09708118], [75.16986084, 12.09708405], [75.16986084, 12.0965271], [75.16958618, 12.09653187], [75.16958618, 12.09624863], [75.16874695, 12.09624863], [75.16874695, 12.0959692], [75.16847229, 12.0959692], [75.16847229, 12.09653187], [75.16819763, 12.0965271], [75.16819763, 12.09708405], [75.16791534, 12.09708405], [75.16791534, 12.09736156], [75.16764069, 12.09736156], [75.16764069, 12.09793091], [75.1673584, 12.0979147], [75.1673584, 12.09847164], [75.16708374, 12.09847164], [75.16708374, 12.09958363], [75.16652679, 12.09958363], [75.16652679, 12.10208416], [75.16623688, 12.10207939], [75.16623688, 12.10236168], [75.16596985, 12.10236168], [75.16596985, 12.10291958], [75.16569519, 12.10291576], [75.16569519, 12.10319424], [75.16596985, 12.10319424], [75.16596985, 12.10347176], [75.1654129, 12.10346985], [75.1654129, 12.10402966], [75.16486359, 12.10402775], [75.16486359, 12.10458374], [75.1645813, 12.10458374], [75.1645813, 12.10486221], [75.16401672, 12.10486031], [75.16401672, 12.10513973], [75.16374969, 12.10513973], [75.16374969, 12.10542107], [75.16291809, 12.1054163], [75.16291809, 12.10597229], [75.1626358, 12.10597038], [75.1626358, 12.10681057], [75.16291809, 12.10681057], [75.16291809, 12.10764122], [75.1626358, 12.10763836], [75.1626358, 12.10819435], [75.16236115, 12.10819435], [75.16236115, 12.10847187], [75.16208649, 12.10846996], [75.16208649, 12.10903072], [75.1618042, 12.10902882], [75.1618042, 12.10958195], [75.16152954, 12.10958004], [75.16152954, 12.10987186], [75.16179657, 12.10987186], [75.16179657, 12.11042118], [75.16152954, 12.11041737], [75.16152954, 12.11069489], [75.16179657, 12.11069012], [75.16179657, 12.11125088], [75.1609726, 12.11125088], [75.1609726, 12.11096954], [75.16069794, 12.11096954], [75.16069794, 12.11181068], [75.16043091, 12.11181068], [75.16043091, 12.11430931], [75.16069794, 12.11430454], [75.16069794, 12.11458302], [75.16124725, 12.11458302], [75.16124725, 12.11486053], [75.16152954, 12.11486053], [75.16152954, 12.11514091], [75.1626358, 12.11514091], [75.1626358, 12.11541939], [75.16346741, 12.11541939]]], [[[75.15402985, 12.14264107], [75.15402985, 12.14208126], [75.1543045, 12.14208317], [75.1543045, 12.14152908], [75.15458679, 12.14153099], [75.15458679, 12.14097118], [75.15486145, 12.14097309], [75.15486145, 12.14069462], [75.15513611, 12.14069462], [75.15513611, 12.1404171], [75.1554184, 12.14042091], [75.1554184, 12.14014053], [75.15569305, 12.14014053], [75.15569305, 12.14042091], [75.15598297, 12.14042091], [75.15598297, 12.14014053], [75.15651703, 12.14014053], [75.15651703, 12.13985157], [75.1570816, 12.13986111], [75.1570816, 12.13958263], [75.15763855, 12.13958263], [75.15763855, 12.13902664], [75.15791321, 12.13903141], [75.15791321, 12.13875103], [75.15875244, 12.13875103], [75.15875244, 12.1384697], [75.1590271, 12.13847256], [75.1590271, 12.13819504], [75.15930176, 12.13819504], [75.15930939, 12.13735962], [75.1598587, 12.13735962], [75.1598587, 12.13680744], [75.16043091, 12.13681126], [75.16043091, 12.13625145], [75.16069794, 12.13625145], [75.16069794, 12.13597012], [75.1609726, 12.13597202], [75.1609726, 12.13569355], [75.16124725, 12.13569355], [75.16124725, 12.13541603], [75.16152954, 12.1354208], [75.16152954, 12.13486004], [75.16179657, 12.13486004], [75.16179657, 12.13404179], [75.16208649, 12.13404179], [75.16208649, 12.13319016], [75.1618042, 12.13319397], [75.1618042, 12.13263798], [75.16152954, 12.13264275], [75.16152954, 12.13153267], [75.16124725, 12.13153267], [75.16124725, 12.13125038], [75.1609726, 12.13125038], [75.1609726, 12.13097191], [75.16014099, 12.13097191], [75.16014099, 12.13069439], [75.1598587, 12.13069439], [75.1598587, 12.1301403], [75.15957642, 12.1301403], [75.15957642, 12.12763977], [75.1598587, 12.12763977], [75.1598587, 12.12708187], [75.15958405, 12.12708378], [75.15958405, 12.12625027], [75.15930939, 12.12625027], [75.15930939, 12.12541962], [75.15957642, 12.12541962], [75.15957642, 12.12514019], [75.15930939, 12.12514019], [75.15930939, 12.1245842], [75.15930176, 12.12347126], [75.1590271, 12.12347126], [75.1590271, 12.12263966], [75.15875244, 12.12263966], [75.15875244, 12.12235928], [75.1590271, 12.12236118], [75.1590271, 12.12152672], [75.15875244, 12.12152958], [75.15875244, 12.1212492], [75.15847015, 12.1212492], [75.15847015, 12.12097073], [75.1581955, 12.12097359], [75.15820313, 12.1212492], [75.15791321, 12.1212492], [75.15791321, 12.12292004], [75.15763855, 12.12292004], [75.15763855, 12.12430954], [75.1570816, 12.12430954], [75.1570816, 12.12487125], [75.15680695, 12.12487125], [75.15680695, 12.12514019], [75.15651703, 12.12514019], [75.15651703, 12.12541962], [75.15625, 12.12541962], [75.15625, 12.12597179], [75.15597534, 12.12597179], [75.15598297, 12.12625027], [75.15569305, 12.12625027], [75.15569305, 12.12708378], [75.1554184, 12.12708378], [75.1554184, 12.12736225], [75.15486145, 12.12736225], [75.15486145, 12.12819386], [75.15458679, 12.12819195], [75.15458679, 12.12874985], [75.15429688, 12.12874985], [75.15429688, 12.12985992], [75.15374756, 12.12985992], [75.15374756, 12.13097191], [75.1534729, 12.13097191], [75.1534729, 12.13153267], [75.15319824, 12.1315279], [75.15319061, 12.13236237], [75.15291595, 12.13236237], [75.15291595, 12.13319397], [75.15235901, 12.13319397], [75.15235901, 12.13347244], [75.15207672, 12.13346958], [75.15207672, 12.13374996], [75.15180206, 12.13374996], [75.15180206, 12.13404179], [75.1515274, 12.13404179], [75.1515274, 12.13486004], [75.15125275, 12.13486004], [75.15125275, 12.13597202], [75.15097046, 12.13597012], [75.15097046, 12.13625145], [75.15123749, 12.13625145], [75.15123749, 12.13653088], [75.15097046, 12.13653088], [75.15097046, 12.13764095], [75.1506958, 12.13763905], [75.1506958, 12.13847256], [75.15013885, 12.1384697], [75.15013885, 12.13903141], [75.1498642, 12.13902664], [75.1498642, 12.13958263], [75.14958191, 12.13958263], [75.14958191, 12.14097309], [75.15013885, 12.14097118], [75.15013885, 12.14153099], [75.15097046, 12.14153099], [75.15097046, 12.14180946], [75.15125275, 12.1418047], [75.15125275, 12.14208317], [75.15180206, 12.14208126], [75.15180206, 12.14236069], [75.15207672, 12.14236069], [75.15207672, 12.14264107], [75.1526413, 12.14264107], [75.1526413, 12.14236069], [75.15291595, 12.14236069], [75.15291595, 12.14264107], [75.15402985, 12.14264107]]], [[[75.12652588, 12.20514202], [75.12652588, 12.20486164], [75.12680817, 12.20486164], [75.12680817, 12.20403194], [75.12652588, 12.20403194], [75.12652588, 12.20263863], [75.12680817, 12.20263863], [75.12680817, 12.20097065], [75.12708282, 12.20097256], [75.12708282, 12.19986057], [75.12735748, 12.19986057], [75.12735748, 12.19763947], [75.12706757, 12.19764137], [75.12706757, 12.19597054], [75.12735748, 12.1959734], [75.12735748, 12.19486141], [75.12763977, 12.19486141], [75.12763977, 12.19430542], [75.1279068, 12.19430923], [75.1279068, 12.19403076], [75.12819672, 12.19403076], [75.12819672, 12.19375134], [75.12847137, 12.19375134], [75.12847137, 12.19292068], [75.12874603, 12.19292068], [75.12874603, 12.19236088], [75.12930298, 12.19236088], [75.12930298, 12.19207954], [75.12958527, 12.19208336], [75.12958527, 12.19152641], [75.12985992, 12.19153118], [75.12985992, 12.19096088], [75.13014221, 12.19097328], [75.13014221, 12.19041634], [75.13041687, 12.1904211], [75.13041687, 12.19014072], [75.13069153, 12.19014072], [75.13069153, 12.18903065], [75.13096619, 12.18903065], [75.13096619, 12.18847179], [75.13069153, 12.18847179], [75.13069153, 12.18819046], [75.13097382, 12.18819427], [75.13097382, 12.18652821], [75.13124847, 12.18653107], [75.13124847, 12.18569183], [75.13097382, 12.18569374], [75.13097382, 12.18541622], [75.13124847, 12.18542099], [75.13124847, 12.18457985], [75.13153076, 12.18458366], [75.13153076, 12.18375015], [75.13181305, 12.18375015], [75.13180542, 12.18319416], [75.13208008, 12.18319416], [75.13208008, 12.18264008], [75.13236237, 12.18264008], [75.13236237, 12.18209076], [75.13263702, 12.18209076], [75.13263702, 12.18153], [75.13291931, 12.18153], [75.13291931, 12.18096924], [75.13319397, 12.1809721], [75.13319397, 12.18041801], [75.13346863, 12.18041992], [75.13346863, 12.17986202], [75.13375092, 12.17986202], [75.13375092, 12.17930984], [75.1340332, 12.17930984], [75.1340332, 12.17875195], [75.13430786, 12.17875195], [75.13430786, 12.17819118], [75.13458252, 12.17819309], [75.13458252, 12.17763996], [75.13485718, 12.17764187], [75.13485718, 12.17708111], [75.13513947, 12.17708397], [75.13513947, 12.17652702], [75.13540649, 12.17653179], [75.13540649, 12.17595959], [75.13569641, 12.17597103], [75.13569641, 12.17541695], [75.13597107, 12.17541981], [75.13597107, 12.17486095], [75.13569641, 12.17486095], [75.13569641, 12.1740303], [75.13540649, 12.1740303], [75.13540649, 12.17208099], [75.13569641, 12.1720829], [75.13569641, 12.17152691], [75.13597107, 12.17153168], [75.13597107, 12.17097092], [75.13625336, 12.17097092], [75.13625336, 12.1706953], [75.13652802, 12.1706953], [75.13652802, 12.17041683], [75.13680267, 12.1704216], [75.13680267, 12.17015266], [75.13707733, 12.17015266], [75.13707733, 12.16986084], [75.13735962, 12.16986084], [75.13735962, 12.16958141], [75.13764191, 12.16958332], [75.13764191, 12.16930485], [75.13791656, 12.16931152], [75.13791656, 12.16902924], [75.13819122, 12.16902924], [75.13819122, 12.16874886], [75.13847351, 12.16874886], [75.13847351, 12.16847324], [75.13874817, 12.16847324], [75.13874817, 12.16819477], [75.13903046, 12.16819477], [75.13903046, 12.16791725], [75.13929749, 12.16792107], [75.13929749, 12.16764069], [75.13957977, 12.16764069], [75.13957977, 12.16736126], [75.13986206, 12.16736126], [75.13986206, 12.16708279], [75.14013672, 12.16708279], [75.14013672, 12.1665287], [75.14041901, 12.16653061], [75.14041901, 12.16625118], [75.14068604, 12.16625118], [75.14068604, 12.16569042], [75.14097595, 12.16569519], [75.14097595, 12.1651392], [75.14125061, 12.16514111], [75.14125061, 12.16486073], [75.1415329, 12.16486073], [75.14152527, 12.16430664], [75.14180756, 12.16431141], [75.14180756, 12.16264057], [75.1415329, 12.16264057], [75.1415329, 12.15903091], [75.14180756, 12.15903091], [75.14180756, 12.15596962], [75.14208221, 12.15597153], [75.14208221, 12.15513992], [75.14235687, 12.15513992], [75.14235687, 12.15402985], [75.14263916, 12.15402985], [75.14263916, 12.15319061], [75.14291382, 12.15319443], [75.14291382, 12.15236187], [75.14319611, 12.15236187], [75.14319611, 12.15180969], [75.14347076, 12.15180969], [75.14347076, 12.15125179], [75.14375305, 12.15125179], [75.14375305, 12.15069103], [75.14402771, 12.1506958], [75.14402771, 12.15041542], [75.14430237, 12.15042019], [75.14430237, 12.14985943], [75.14458466, 12.14986229], [75.14458466, 12.14930534], [75.14485931, 12.14931011], [75.14485931, 12.14874935], [75.1451416, 12.14874935], [75.1451416, 12.14847088], [75.14569092, 12.14847088], [75.14569092, 12.14819336], [75.14624786, 12.14819336], [75.14624786, 12.14763927], [75.14653015, 12.14763927], [75.14653015, 12.14708138], [75.14680481, 12.14708328], [75.14680481, 12.14652729], [75.1470871, 12.1465292], [75.1470871, 12.14598179], [75.14736176, 12.14598179], [75.14736176, 12.14542198], [75.14763641, 12.14542198], [75.14763641, 12.14486122], [75.1479187, 12.14486122], [75.1479187, 12.14319515], [75.14763641, 12.14319515], [75.14763641, 12.14152908], [75.14736176, 12.14153099], [75.14736176, 12.13985157], [75.1470871, 12.13986111], [75.1470871, 12.13735962], [75.14736176, 12.13735962], [75.14736176, 12.13647175], [75.14736176, 12.13541603], [75.14763641, 12.1354208], [75.14763641, 12.13457966], [75.1479187, 12.13458538], [75.1479187, 12.13374996], [75.14820099, 12.13374996], [75.14820099, 12.13320065], [75.14849091, 12.13319016], [75.14847565, 12.13236237], [75.14875031, 12.13236237], [75.14875031, 12.1315279], [75.14901733, 12.13153267], [75.14901733, 12.13097191], [75.14930725, 12.13097191], [75.14930725, 12.13041592], [75.14958191, 12.13042068], [75.14958191, 12.12985992], [75.14985657, 12.12985992], [75.14985657, 12.12903023], [75.15013885, 12.12903023], [75.15013885, 12.12847042], [75.15041351, 12.12847233], [75.15041351, 12.12791634], [75.1506958, 12.12791634], [75.1506958, 12.12736225], [75.15097046, 12.12736225], [75.15097046, 12.12680626], [75.15123749, 12.12681007], [75.15123749, 12.12597179], [75.1515274, 12.12597179], [75.1515274, 12.12541962], [75.15180206, 12.12541962], [75.15180206, 12.12487125], [75.15207672, 12.12487125], [75.15207672, 12.12430954], [75.15235901, 12.12430954], [75.15235901, 12.12347126], [75.1526413, 12.12347126], [75.1526413, 12.12291527], [75.15291595, 12.12292004], [75.15291595, 12.12235928], [75.15319824, 12.12236118], [75.15319824, 12.12180519], [75.1534729, 12.12180996], [75.1534729, 12.1212492], [75.15374756, 12.1212492], [75.15374756, 12.12097073], [75.15402985, 12.12097359], [75.15402985, 12.12069321], [75.1543045, 12.12069321], [75.1543045, 12.12041664], [75.15450287, 12.12042046], [75.15458679, 12.12041664], [75.15458679, 12.11998653], [75.15458679, 12.11986065], [75.15486145, 12.11986065], [75.15486145, 12.11958122], [75.15513611, 12.11958313], [75.15513611, 12.11930466], [75.1554184, 12.11931038], [75.1554184, 12.11875057], [75.15569305, 12.11875057], [75.15569305, 12.11819077], [75.15597534, 12.11819458], [75.15597534, 12.11736107], [75.15625, 12.11736107], [75.15625, 12.11681175], [75.15651703, 12.11681175], [75.15651703, 12.11625099], [75.15680695, 12.11625099], [75.15680695, 12.11191177], [75.15680695, 12.11097336], [75.1570816, 12.11097336], [75.1570816, 12.11041737], [75.15729523, 12.11039352], [75.15737152, 12.11016083], [75.15652466, 12.11013794], [75.15652466, 12.11069489], [75.15625, 12.11069489], [75.15625, 12.11097336], [75.15598297, 12.11096954], [75.15598297, 12.11153126], [75.15569305, 12.11153126], [75.15569305, 12.11236095], [75.1554184, 12.11236095], [75.1554184, 12.1129303], [75.15513611, 12.11291695], [75.15513611, 12.11347294], [75.15486145, 12.11347103], [75.15486145, 12.11430931], [75.15458679, 12.11430931], [75.15458679, 12.11541939], [75.1543045, 12.11541653], [75.1543045, 12.11597347], [75.15402985, 12.11597061], [75.15402985, 12.11625099], [75.15374756, 12.11625099], [75.15374756, 12.1170826], [75.1534729, 12.11708069], [75.1534729, 12.11736107], [75.15319824, 12.11736107], [75.15319061, 12.11792183], [75.15291595, 12.11792183], [75.15291595, 12.11931038], [75.1526413, 12.11931038], [75.1526413, 12.11986065], [75.15235901, 12.11986065], [75.15235901, 12.12042046], [75.15207672, 12.12042046], [75.15207672, 12.12152958], [75.15180206, 12.12152672], [75.15180206, 12.12208271], [75.1515274, 12.1220789], [75.1515274, 12.12292004], [75.15125275, 12.12291527], [75.15125275, 12.12347126], [75.15097046, 12.12347126], [75.15097046, 12.12403202], [75.1506958, 12.12402821], [75.1506958, 12.1245842], [75.15040588, 12.12458134], [75.15040588, 12.12597179], [75.15013885, 12.12597179], [75.15013885, 12.12625027], [75.14985657, 12.12625027], [75.14985657, 12.12681007], [75.14958191, 12.12680626], [75.14958191, 12.12736225], [75.14930725, 12.12736225], [75.14930725, 12.12847233], [75.14901733, 12.12847042], [75.14901733, 12.12931061], [75.14875031, 12.12931061], [75.14875031, 12.12985992], [75.14849091, 12.12985992], [75.14849091, 12.13042068], [75.14819336, 12.13041592], [75.14819336, 12.13069439], [75.1479187, 12.13069439], [75.1479187, 12.13097191], [75.14763641, 12.13097191], [75.14763641, 12.13153267], [75.14736176, 12.13153267], [75.14736176, 12.13264275], [75.1470871, 12.13264275], [75.1470871, 12.13292122], [75.14679718, 12.13292122], [75.14679718, 12.13431072], [75.14653015, 12.13431072], [75.14653015, 12.13514137], [75.14624786, 12.13513756], [75.14624786, 12.13597202], [75.14597321, 12.13597012], [75.14597321, 12.13681126], [75.14569092, 12.13680744], [75.14569092, 12.13735962], [75.14543152, 12.13735962], [75.14543152, 12.13764095], [75.1451416, 12.13763905], [75.1451416, 12.13819504], [75.14485931, 12.13819027], [75.14485931, 12.13931084], [75.14457703, 12.13931084], [75.14457703, 12.14014053], [75.14430237, 12.14013863], [75.14430237, 12.14069462], [75.14402771, 12.14068985], [75.14402771, 12.14125061], [75.14375305, 12.14125061], [75.14375305, 12.14180946], [75.14347076, 12.14180946], [75.14347076, 12.14236069], [75.14319611, 12.14236069], [75.14319611, 12.14291668], [75.14291382, 12.14291668], [75.14291382, 12.14347076], [75.14263916, 12.14346886], [75.14263916, 12.14375114], [75.14235687, 12.14375114], [75.14235687, 12.14403152], [75.14208221, 12.14402676], [75.14208221, 12.14486122], [75.14180756, 12.14486122], [75.14180756, 12.14542198], [75.14206696, 12.14542198], [75.14206696, 12.14598179], [75.14180756, 12.14598179], [75.14180756, 12.1465292], [75.14152527, 12.14652729], [75.14152527, 12.14708328], [75.14125061, 12.14708138], [75.14125061, 12.14763927], [75.14097595, 12.14763927], [75.14097595, 12.14847088], [75.14068604, 12.14847088], [75.14068604, 12.14904118], [75.14041901, 12.14904118], [75.14041901, 12.14931011], [75.14013672, 12.14931011], [75.14013672, 12.15042019], [75.13986206, 12.15042019], [75.13986206, 12.15125179], [75.13957977, 12.15125179], [75.13957977, 12.15180969], [75.13929749, 12.15180969], [75.13929749, 12.15264034], [75.13903046, 12.15263844], [75.13903046, 12.15319443], [75.13874817, 12.15319061], [75.13874817, 12.15375042], [75.13846588, 12.15375042], [75.13846588, 12.15431023], [75.13819122, 12.15430641], [75.13819122, 12.1548624], [75.13791656, 12.15485096], [75.13791656, 12.15625], [75.13764191, 12.15625], [75.13764191, 12.15681076], [75.13735962, 12.15680599], [75.13735962, 12.15708447], [75.13707733, 12.1570797], [75.13707733, 12.15931129], [75.13680267, 12.15930557], [75.13680267, 12.15958214], [75.13652802, 12.15958214], [75.13652802, 12.16069412], [75.13626099, 12.16069031], [75.13626099, 12.16125011], [75.13597107, 12.16125011], [75.13597107, 12.16181087], [75.13569641, 12.1618042], [75.13569641, 12.16236019], [75.13541412, 12.16236019], [75.13541412, 12.16347313], [75.13513947, 12.16347313], [75.13513947, 12.16402912], [75.13485718, 12.16401958], [75.13485718, 12.16486073], [75.13458252, 12.16486073], [75.13458252, 12.16569519], [75.13430786, 12.16569042], [75.13430786, 12.16625118], [75.1340332, 12.16625118], [75.1340332, 12.16681099], [75.13375092, 12.16680527], [75.13375092, 12.16736126], [75.13346863, 12.16736126], [75.13346863, 12.16792107], [75.13319397, 12.16791725], [75.13319397, 12.16874886], [75.13263702, 12.16874886], [75.13263702, 12.17015266], [75.13236237, 12.17015266], [75.13236237, 12.1712513], [75.13208008, 12.1712513], [75.13208008, 12.17181015], [75.13180542, 12.17180538], [75.13180542, 12.17236137], [75.13153076, 12.17236137], [75.13153076, 12.17292023], [75.13124847, 12.17292023], [75.13124847, 12.17375088], [75.13097382, 12.17374897], [75.13097382, 12.17458344], [75.13069153, 12.17458057], [75.13069153, 12.17541981], [75.13041687, 12.17541981], [75.13041687, 12.17624855], [75.13014221, 12.17624855], [75.13014221, 12.17708397], [75.12985992, 12.17708111], [75.12985992, 12.17764187], [75.12958527, 12.17763996], [75.12958527, 12.17847157], [75.12930298, 12.17847157], [75.12930298, 12.17902756], [75.12902832, 12.17902756], [75.12902832, 12.17958355], [75.12874603, 12.17958069], [75.12874603, 12.18124962], [75.12847137, 12.18124962], [75.12847137, 12.18153], [75.12819672, 12.18153], [75.12819672, 12.18209076], [75.1279068, 12.18209076], [75.1279068, 12.1823597], [75.12763977, 12.1823597], [75.12763977, 12.18292046], [75.12735748, 12.18292046], [75.12735748, 12.18375015], [75.12708282, 12.18375015], [75.12708282, 12.18458366], [75.12680817, 12.18457985], [75.12680817, 12.18542099], [75.12652588, 12.18542099], [75.12652588, 12.18624973], [75.12625122, 12.18624973], [75.12625122, 12.18681145], [75.12596893, 12.18681145], [75.12596893, 12.18736172], [75.12568665, 12.18736172], [75.12568665, 12.18764114], [75.12541962, 12.18764114], [75.12541962, 12.18847179], [75.12513733, 12.18847179], [75.12513733, 12.18958473], [75.12486267, 12.18957996], [75.12486267, 12.19014072], [75.12458038, 12.19013786], [75.12458038, 12.19069481], [75.12430573, 12.19069481], [75.12432098, 12.1912508], [75.12403107, 12.1912508], [75.12403107, 12.19153118], [75.12374878, 12.19153118], [75.12374878, 12.19181061], [75.12346649, 12.19181061], [75.12346649, 12.19236088], [75.12374878, 12.19236088], [75.12374878, 12.19264126], [75.12403107, 12.19264126], [75.12403107, 12.19292068], [75.12430573, 12.19291687], [75.12430573, 12.19334126], [75.12430573, 12.19347286], [75.12374878, 12.19347095], [75.12374878, 12.19403076], [75.12346649, 12.19403076], [75.12346649, 12.19430923], [75.12319183, 12.19430542], [75.12319183, 12.19486141], [75.12291718, 12.19486141], [75.12291718, 12.19721985], [75.12291718, 12.19736099], [75.12264252, 12.19736099], [75.12264252, 12.19798088], [75.12264252, 12.19847107], [75.12246704, 12.19847107], [75.12236023, 12.19847107], [75.12236786, 12.19875145], [75.12264252, 12.19875145], [75.12264252, 12.19958305], [75.12291718, 12.19958305], [75.12291718, 12.20013905], [75.12319183, 12.20013046], [75.12319183, 12.20125103], [75.12346649, 12.20125103], [75.12346649, 12.20153046], [75.12374878, 12.20152664], [75.12374878, 12.20208263], [75.12403107, 12.20208073], [75.12403107, 12.20291996], [75.12430573, 12.20291805], [75.12430573, 12.20319557], [75.12458038, 12.20319557], [75.12458038, 12.20347118], [75.12486267, 12.20346928], [75.12486267, 12.20431042], [75.12513733, 12.20431042], [75.12513733, 12.20486164], [75.12541962, 12.20486164], [75.12541962, 12.20514202], [75.12652588, 12.20514202]]], [[[75.13014221, 12.19819546], [75.13014221, 12.19791698], [75.13069153, 12.19792175], [75.13069153, 12.19764137], [75.13124847, 12.19764137], [75.13124847, 12.19681168], [75.13153076, 12.19681168], [75.13153076, 12.19569016], [75.13124847, 12.19569492], [75.13124847, 12.1954174], [75.13096619, 12.19541931], [75.13096619, 12.19514084], [75.13041687, 12.19514084], [75.13041687, 12.19486141], [75.13014221, 12.19486141], [75.13014221, 12.19458294], [75.12930298, 12.19458008], [75.12930298, 12.1965313], [75.1295929, 12.1965313], [75.1295929, 12.19764137], [75.12985992, 12.19763947], [75.12985992, 12.19819546], [75.13014221, 12.19819546]]], [[[75.36791992, 11.94347191], [75.36791992, 11.94235992], [75.36818695, 11.94235992], [75.36818695, 11.94181061], [75.36846924, 11.94181061], [75.36846924, 11.94124126], [75.36819458, 11.94124985], [75.36819458, 11.94041634], [75.36791992, 11.94042015], [75.36791992, 11.93958187], [75.36736298, 11.93958378], [75.36736298, 11.93902779], [75.36708069, 11.93902969], [75.36708069, 11.9382], [75.36653137, 11.9382], [75.36653137, 11.93791962], [75.36624908, 11.93791962], [75.36624908, 11.93735886], [75.36597443, 11.93736172], [75.36597443, 11.9370842], [75.36569214, 11.9370842], [75.36569214, 11.93680573], [75.36514282, 11.93680954], [75.36514282, 11.93624973], [75.36485291, 11.93624973], [75.36485291, 11.93596935], [75.36430359, 11.93597221], [75.36430359, 11.9370842], [75.36458588, 11.93708134], [75.36458588, 11.93791962], [75.36485291, 11.93791962], [75.36485291, 11.93875027], [75.36541748, 11.93875027], [75.36541748, 11.93931007], [75.36569214, 11.93930626], [75.36569214, 11.93986225], [75.3659668, 11.93986034], [75.3659668, 11.94013977], [75.36624908, 11.94013977], [75.36624908, 11.94042015], [75.36653137, 11.94042015], [75.36653137, 11.94153023], [75.36680603, 11.94153023], [75.36680603, 11.94181061], [75.36708069, 11.94181061], [75.36708069, 11.94292068], [75.36736298, 11.94291592], [75.36736298, 11.94347191], [75.36791992, 11.94347191]]], [[[75.36624908, 11.94208431], [75.36624908, 11.94180584], [75.3659668, 11.94181061], [75.3659668, 11.94069195], [75.36569214, 11.94069386], [75.36569214, 11.94041634], [75.36541748, 11.94042015], [75.36541748, 11.94013977], [75.36514282, 11.94013977], [75.36514282, 11.93986034], [75.36486053, 11.93986225], [75.36486053, 11.93930626], [75.36458588, 11.93931007], [75.36458588, 11.93902969], [75.36429596, 11.93902969], [75.36429596, 11.93847179], [75.36402893, 11.93847179], [75.36402893, 11.93791962], [75.36374664, 11.93791962], [75.36374664, 11.93902969], [75.36402893, 11.93902969], [75.36402893, 11.93931007], [75.36429596, 11.93931007], [75.36429596, 11.94013977], [75.36458588, 11.94013786], [75.36458588, 11.94069386], [75.36514282, 11.94069195], [75.36514282, 11.94181061], [75.36541748, 11.94181061], [75.36541748, 11.94235992], [75.36569214, 11.94235992], [75.36569214, 11.94207954], [75.3659668, 11.94207954], [75.3659668, 11.94235992], [75.36624908, 11.94235992], [75.36624908, 11.94319439], [75.36653137, 11.94319439], [75.36653137, 11.94347191], [75.36680603, 11.94347191], [75.36680603, 11.94208431], [75.36624908, 11.94208431]]], [[[75.30069733, 11.96347237], [75.30069733, 11.9631958], [75.30124664, 11.9631958], [75.30124664, 11.96291542], [75.30152893, 11.96292019], [75.30152893, 11.96208096], [75.30180359, 11.96208382], [75.30180359, 11.96152687], [75.30208588, 11.96152973], [75.30208588, 11.96124935], [75.30236053, 11.96124935], [75.30236053, 11.95958138], [75.30179596, 11.95958138], [75.30179596, 11.96013927], [75.30152893, 11.96013927], [75.30152893, 11.96041965], [75.30097198, 11.96041775], [75.30097198, 11.96097088], [75.30069733, 11.96097088], [75.30069733, 11.96152973], [75.30042267, 11.96152973], [75.30042267, 11.96237087], [75.30014038, 11.96237087], [75.30014038, 11.96292019], [75.29985809, 11.96291542], [75.29985809, 11.96347237], [75.30069733, 11.96347237]]], [[[75.29652405, 11.96847153], [75.29652405, 11.96819401], [75.29680634, 11.96819401], [75.29680634, 11.96791553], [75.29708099, 11.9679203], [75.29708099, 11.96763992], [75.29736328, 11.96763992], [75.29736328, 11.96735954], [75.29763794, 11.9673624], [75.29763794, 11.96708393], [75.29792023, 11.96708393], [75.29792023, 11.96680641], [75.29818726, 11.96681023], [75.29818726, 11.96625042], [75.29846954, 11.96625042], [75.29846954, 11.96569061], [75.29875183, 11.96569443], [75.29875183, 11.96541786], [75.29846954, 11.96541786], [75.29846954, 11.96513844], [75.29792023, 11.96513844], [75.29792023, 11.96541786], [75.29763794, 11.96541786], [75.29763794, 11.96569443], [75.29708099, 11.96569443], [75.29708099, 11.96597195], [75.29680634, 11.96597195], [75.29680634, 11.96625042], [75.29651642, 11.96625042], [75.29651642, 11.96652985], [75.29624939, 11.96652794], [75.29624939, 11.96708393], [75.29570007, 11.96708202], [75.29570007, 11.96763992], [75.29514313, 11.96763992], [75.29514313, 11.9679203], [75.29541779, 11.96791553], [75.29541779, 11.96819401], [75.29569244, 11.96819401], [75.29569244, 11.96847153], [75.29652405, 11.96847153]]], [[[75.28541565, 11.98708344], [75.28541565, 11.98680496], [75.2859726, 11.98680973], [75.2859726, 11.98654079], [75.28679657, 11.98654079], [75.28679657, 11.98625183], [75.28736115, 11.98625183], [75.28736115, 11.98597145], [75.2876358, 11.98597336], [75.2876358, 11.98556995], [75.2876358, 11.98541737], [75.28819275, 11.98542023], [75.28819275, 11.98348045], [75.28848267, 11.98348045], [75.28848267, 11.98264122], [75.28874969, 11.98264122], [75.28874969, 11.98236084], [75.28901672, 11.98236084], [75.28901672, 11.98208141], [75.28930664, 11.98208332], [75.28930664, 11.98180485], [75.28956604, 11.98180866], [75.28956604, 11.98152924], [75.28985596, 11.98152924], [75.28985596, 11.98097134], [75.29013824, 11.98097324], [75.29013824, 11.98069477], [75.2904129, 11.98069477], [75.2904129, 11.98013878], [75.29070282, 11.98014069], [75.29070282, 11.97931194], [75.29096985, 11.97931194], [75.29096985, 11.97875118], [75.29125214, 11.97875118], [75.29125214, 11.9784708], [75.29152679, 11.97847271], [75.29152679, 11.97819519], [75.29180908, 11.97819519], [75.29180908, 11.9776392], [75.29207611, 11.97764111], [75.29207611, 11.97734928], [75.2923584, 11.97736073], [75.2923584, 11.97708321], [75.29264069, 11.97708321], [75.29264069, 11.97680664], [75.29292297, 11.97681141], [75.29292297, 11.97625065], [75.29319763, 11.97625065], [75.29319763, 11.97597027], [75.29347229, 11.97597313], [75.29347229, 11.97486019], [75.29374695, 11.97486019], [75.29374695, 11.97458458], [75.29402924, 11.97458458], [75.29402924, 11.97402859], [75.29429626, 11.97403145], [75.29429626, 11.97375011], [75.29458618, 11.97375011], [75.29458618, 11.97319031], [75.29486084, 11.97319412], [75.29486084, 11.97236156], [75.2951355, 11.97236156], [75.2951355, 11.97152805], [75.29541779, 11.97154045], [75.29541779, 11.97097015], [75.29569244, 11.97097206], [75.29569244, 11.96986008], [75.29624939, 11.96986008], [75.29624939, 11.96931076], [75.29541779, 11.96930599], [75.29541779, 11.96958447], [75.2951355, 11.96958447], [75.29514313, 11.96986008], [75.29458618, 11.96986008], [75.29458618, 11.96931076], [75.29402924, 11.96930599], [75.29402924, 11.96958447], [75.29374695, 11.9695797], [75.29374695, 11.96986008], [75.29319763, 11.96986008], [75.29319763, 11.97014046], [75.29292297, 11.97014046], [75.29292297, 11.97042274], [75.2923584, 11.97041607], [75.2923584, 11.97069359], [75.29207611, 11.97069168], [75.29207611, 11.97124958], [75.29180908, 11.97124958], [75.29180908, 11.97154045], [75.29152679, 11.97154045], [75.29152679, 11.97181129], [75.29125214, 11.97181129], [75.29125214, 11.97235966], [75.29096985, 11.97235966], [75.29096985, 11.97264099], [75.29069519, 11.97263813], [75.29069519, 11.97347164], [75.29013824, 11.97346973], [75.29013824, 11.97403145], [75.28985596, 11.97403145], [75.28985596, 11.97431087], [75.2895813, 11.9743042], [75.2895813, 11.97458458], [75.28930664, 11.97458458], [75.28930664, 11.97486019], [75.28901672, 11.97486019], [75.28901672, 11.97681141], [75.28874969, 11.97681141], [75.28874969, 11.97764111], [75.28848267, 11.97764111], [75.28848267, 11.97792053], [75.28819275, 11.97791672], [75.28819275, 11.97847271], [75.28791809, 11.9784708], [75.28791809, 11.97931194], [75.2876358, 11.97930527], [75.2876358, 11.97958279], [75.28736115, 11.97957993], [75.28736115, 11.98014069], [75.28708649, 11.98013878], [75.28708649, 11.98069477], [75.2868042, 11.98069477], [75.2868042, 11.98124886], [75.28652954, 11.98124886], [75.28652954, 11.98208332], [75.2859726, 11.98208141], [75.2859726, 11.98264122], [75.2857132, 11.98264122], [75.28569794, 11.9837513], [75.28542328, 11.9837513], [75.28542328, 11.98513889], [75.28514099, 11.98513889], [75.28514099, 11.98569489], [75.2848587, 11.98569107], [75.2848587, 11.98680973], [75.28514099, 11.98680496], [75.28514099, 11.98708344], [75.28541565, 11.98708344]]], [[[75.29792023, 12.01736164], [75.29792023, 12.0162487], [75.29763794, 12.0162487], [75.29763794, 12.01596928], [75.29792023, 12.01597118], [75.29792023, 12.01569557], [75.29736328, 12.01569557], [75.29736328, 12.01513958], [75.29708099, 12.01513958], [75.29708099, 12.01458073], [75.29652405, 12.01458263], [75.29652405, 12.01430511], [75.29624939, 12.01431179], [75.29624939, 12.01375198], [75.2959671, 12.01375198], [75.2959671, 12.01346016], [75.29569244, 12.01347446], [75.29569244, 12.01319313], [75.2951355, 12.01319313], [75.2951355, 12.01291656], [75.29402924, 12.01292038], [75.29402924, 12.01264191], [75.29125214, 12.01264191], [75.29125214, 12.01292038], [75.29013824, 12.01291656], [75.29013824, 12.01319313], [75.2895813, 12.01319313], [75.2895813, 12.01347446], [75.28930664, 12.01346016], [75.28930664, 12.01375198], [75.28874969, 12.01375198], [75.28874969, 12.01403046], [75.28848267, 12.01403046], [75.28848267, 12.01431179], [75.28791809, 12.01431179], [75.28791809, 12.01541996], [75.28901672, 12.01541996], [75.28901672, 12.01513958], [75.28930664, 12.01513958], [75.28930664, 12.0148592], [75.28986359, 12.01486206], [75.28986359, 12.01458263], [75.29096985, 12.01458263], [75.29096985, 12.01430511], [75.29125214, 12.01431179], [75.29125214, 12.01403046], [75.29152679, 12.01403046], [75.29152679, 12.01375198], [75.2923584, 12.01375198], [75.2923584, 12.01403046], [75.29264069, 12.01402664], [75.29264069, 12.01569557], [75.29319763, 12.01569557], [75.29319763, 12.01541805], [75.29430389, 12.01541805], [75.29430389, 12.01569557], [75.29486084, 12.01569557], [75.29486084, 12.01597118], [75.29514313, 12.01596928], [75.29514313, 12.0162487], [75.29569244, 12.0162487], [75.29569244, 12.01652813], [75.29597473, 12.01652813], [75.29597473, 12.01708412], [75.29624939, 12.01708126], [75.29624939, 12.01736164], [75.29792023, 12.01736164]]], [[[75.29763794, 12.02375031], [75.29763794, 12.02346992], [75.29819489, 12.02347183], [75.29819489, 12.02319431], [75.29985809, 12.02319431], [75.29985809, 12.02235985], [75.29958344, 12.02235985], [75.29958344, 12.02208424], [75.29763794, 12.02208424], [75.29763794, 12.02152824], [75.29736328, 12.02153015], [75.29736328, 12.02125168], [75.29651642, 12.02125168], [75.29651642, 12.02153015], [75.2959671, 12.02153015], [75.2959671, 12.02181053], [75.29569244, 12.02180576], [75.29569244, 12.02208424], [75.29541779, 12.02208424], [75.29541779, 12.02347183], [75.29569244, 12.02347183], [75.29569244, 12.02375031], [75.29763794, 12.02375031]]], [[[76.05208588, 10.53542042], [76.05208588, 10.53458118], [76.05180359, 10.53458309], [76.05180359, 10.5340271], [76.05152893, 10.53403187], [76.05152893, 10.53375244], [76.05069733, 10.53375244], [76.05069733, 10.53347111], [76.05042267, 10.53347111], [76.05042267, 10.53375244], [76.04930878, 10.53375244], [76.04930878, 10.53431034], [76.04958344, 10.53430462], [76.04958344, 10.53458309], [76.04985809, 10.53458309], [76.04985809, 10.53486061], [76.05014038, 10.53486061], [76.05014038, 10.53514194], [76.05069733, 10.53514194], [76.05069733, 10.53542042], [76.05208588, 10.53542042]]], [[[76.05097198, 10.53903008], [76.05097198, 10.53874111], [76.05124664, 10.53874969], [76.05124664, 10.53791809], [76.05152893, 10.53792], [76.05152893, 10.53735924], [76.05124664, 10.5373621], [76.05124664, 10.53652763], [76.05069733, 10.53652954], [76.05069733, 10.53625202], [76.04985809, 10.53625202], [76.04985809, 10.53597069], [76.04930878, 10.53597355], [76.04930878, 10.53708363], [76.04902649, 10.53707886], [76.04902649, 10.53792], [76.04957581, 10.53792], [76.04957581, 10.53903008], [76.05097198, 10.53903008]]], [[[76.25875092, 9.97041798], [76.25875092, 9.97069645], [76.26069641, 9.97069645], [76.26069641, 9.97041798], [76.26207733, 9.97042179], [76.26207733, 9.97014046], [76.26291656, 9.97014046], [76.26291656, 9.96984959], [76.26457977, 9.96986103], [76.26457977, 9.96958256], [76.26486206, 9.96958256], [76.26486206, 9.96930504], [76.26597595, 9.96930981], [76.26597595, 9.96903038], [76.26625061, 9.96903038], [76.26625061, 9.96930981], [76.26708221, 9.96930981], [76.26708221, 9.96903038], [76.26763916, 9.96903038], [76.26763916, 9.96875191], [76.26783752, 9.96875191], [76.26875305, 9.96875191], [76.26875305, 9.96847057], [76.26930237, 9.96847343], [76.26930237, 9.96819305], [76.2701416, 9.96819305], [76.2701416, 9.96791744], [76.27153015, 9.9679203], [76.27153015, 9.96764183], [76.27179718, 9.96764183], [76.27179718, 9.96736145], [76.27236176, 9.96736145], [76.27236176, 9.96680546], [76.27263641, 9.96681023], [76.27263641, 9.96652889], [76.2729187, 9.96652889], [76.2729187, 9.96625137], [76.2748642, 9.96625137], [76.27485657, 9.96542168], [76.27513885, 9.96542168], [76.27513885, 9.96458054], [76.27541351, 9.9645834], [76.27541351, 9.96347332], [76.2756958, 9.96347332], [76.2756958, 9.96319485], [76.27625275, 9.96319485], [76.27625275, 9.96236134], [76.27680206, 9.96236134], [76.27680206, 9.96208286], [76.27708435, 9.96208286], [76.27708435, 9.96125126], [76.27735901, 9.96125126], [76.27735901, 9.96069527], [76.2776413, 9.96069527], [76.2776413, 9.96041679], [76.27791595, 9.96042061], [76.27791595, 9.9598608], [76.27819824, 9.9598608], [76.27819824, 9.95930672], [76.2784729, 9.95931053], [76.2784729, 9.95875072], [76.27874756, 9.95875072], [76.27874756, 9.95818996], [76.27902985, 9.95819473], [76.27902985, 9.95791721], [76.2793045, 9.95791721], [76.2793045, 9.95736027], [76.27958679, 9.95736027], [76.27958679, 9.95708466], [76.27986145, 9.95708466], [76.27986145, 9.95680428], [76.2804184, 9.95681095], [76.2804184, 9.95625019], [76.28069305, 9.95625019], [76.28069305, 9.95458221], [76.28013611, 9.95458221], [76.28013611, 9.95430565], [76.2804184, 9.95431137], [76.2804184, 9.95374966], [76.28151703, 9.95374966], [76.28151703, 9.95318985], [76.28180695, 9.95319366], [76.28180695, 9.95263767], [76.2820816, 9.95263958], [76.2820816, 9.95208168], [76.28236389, 9.95208359], [76.28236389, 9.95180607], [76.28263855, 9.95181084], [76.28263855, 9.95125008], [76.28291321, 9.95125008], [76.28291321, 9.95068932], [76.2831955, 9.95069408], [76.2831955, 9.95014], [76.28347015, 9.95014], [76.28347015, 9.94957924], [76.28375244, 9.94958401], [76.28375244, 9.94902802], [76.2840271, 9.94902992], [76.2840271, 9.94819069], [76.28430176, 9.94819355], [76.28430939, 9.94763756], [76.28457642, 9.94764042], [76.28457642, 9.94680977], [76.2848587, 9.94680977], [76.2848587, 9.94625187], [76.28514099, 9.94625187], [76.28514099, 9.94569969], [76.28542328, 9.94567966], [76.28541565, 9.94486237], [76.28569794, 9.94486237], [76.28569794, 9.94430637], [76.28598022, 9.94431019], [76.28598022, 9.94347095], [76.28624725, 9.94347095], [76.28624725, 9.94291782], [76.28652954, 9.94293118], [76.28652954, 9.94236088], [76.2868042, 9.94236088], [76.28679657, 9.94180965], [76.28708649, 9.94180965], [76.28708649, 9.94124889], [76.28736115, 9.94124889], [76.28736115, 9.94069481], [76.2876358, 9.94069481], [76.2876358, 9.94013882], [76.28791809, 9.94014168], [76.28791809, 9.93958092], [76.28819275, 9.93958282], [76.28819275, 9.93902683], [76.28848267, 9.9390316], [76.28848267, 9.93847084], [76.28874969, 9.93847084], [76.28874969, 9.93791676], [76.28901672, 9.93792152], [76.28901672, 9.93764114], [76.28930664, 9.93764114], [76.28930664, 9.93735886], [76.2895813, 9.93736076], [76.2895813, 9.93680477], [76.28985596, 9.93680859], [76.28985596, 9.93625069], [76.29013824, 9.93625069], [76.29013824, 9.93568993], [76.2904129, 9.93569469], [76.2904129, 9.9351387], [76.29070282, 9.93514061], [76.29070282, 9.93457985], [76.29096985, 9.93458271], [76.29096985, 9.93402672], [76.29125214, 9.93403053], [76.29125214, 9.93346977], [76.29152679, 9.93347263], [76.29152679, 9.93291664], [76.29180908, 9.93292141], [76.29180908, 9.93208027], [76.29208374, 9.93208218], [76.29208374, 9.93152905], [76.29226685, 9.93152905], [76.2923584, 9.93152905], [76.2923584, 9.93097019], [76.29264069, 9.93097305], [76.29264069, 9.93013763], [76.29292297, 9.93014145], [76.29292297, 9.92957973], [76.29319763, 9.92958546], [76.29319763, 9.92875004], [76.29347229, 9.92875004], [76.29347229, 9.92819023], [76.29374695, 9.92819405], [76.29374695, 9.92763805], [76.29402924, 9.92763996], [76.29402924, 9.9256897], [76.29319763, 9.92569447], [76.29319763, 9.92541599], [76.29291534, 9.92541599], [76.29291534, 9.92569447], [76.29208374, 9.92569447], [76.29208374, 9.92597198], [76.29174805, 9.92597198], [76.29096985, 9.92597198], [76.29096985, 9.92625046], [76.29013824, 9.92625046], [76.29013824, 9.92653275], [76.28930664, 9.92653275], [76.28930664, 9.92681122], [76.28847504, 9.92680645], [76.28847504, 9.92708206], [76.28791809, 9.92708206], [76.28791809, 9.92736244], [76.28708649, 9.92735958], [76.28708649, 9.92763996], [76.28652954, 9.92763996], [76.28652954, 9.92793179], [76.28569794, 9.92791557], [76.28569794, 9.92819405], [76.28531647, 9.92819405], [76.28514099, 9.92819405], [76.28514099, 9.92847157], [76.28430176, 9.92846966], [76.28430176, 9.92875004], [76.28375244, 9.92875004], [76.28375244, 9.92903137], [76.28291321, 9.92903137], [76.28291321, 9.92930889], [76.28236389, 9.92930698], [76.28236389, 9.92958546], [76.28152466, 9.92958546], [76.28152466, 9.92986012], [76.28098297, 9.92986012], [76.28098297, 9.93014145], [76.28013611, 9.93014145], [76.28013611, 9.93042088], [76.27958679, 9.93041611], [76.27958679, 9.93069458], [76.27874756, 9.93069458], [76.27874756, 9.93097305], [76.27819824, 9.93097019], [76.27819061, 9.93125057], [76.2776413, 9.93125057], [76.2776413, 9.93153095], [76.27707672, 9.93153095], [76.27707672, 9.93181133], [76.27680206, 9.93180656], [76.27680206, 9.93208218], [76.27625275, 9.93208218], [76.27625275, 9.93236065], [76.27597046, 9.93236065], [76.27597046, 9.93264103], [76.27513885, 9.93264103], [76.27513885, 9.93292141], [76.27498627, 9.93291664], [76.27458191, 9.93291664], [76.27458191, 9.93319511], [76.27402496, 9.93319511], [76.27402496, 9.93347263], [76.27347565, 9.93347263], [76.27347565, 9.93375111], [76.27319336, 9.93374157], [76.27319336, 9.93403053], [76.27236176, 9.93403053], [76.27236176, 9.93431091], [76.27180481, 9.93430519], [76.27180481, 9.93458271], [76.27153015, 9.93458271], [76.27153015, 9.93486118], [76.27124786, 9.93486118], [76.27124786, 9.93514061], [76.27097321, 9.93514061], [76.27097321, 9.93542099], [76.27069092, 9.93541718], [76.27069092, 9.93569469], [76.27041626, 9.93568993], [76.27041626, 9.93625069], [76.2701416, 9.93625069], [76.2701416, 9.93653107], [76.26985931, 9.93653107], [76.26985931, 9.93680859], [76.26958466, 9.93680477], [76.26958466, 9.93708324], [76.26930237, 9.93708324], [76.26930237, 9.93736076], [76.26902771, 9.93735886], [76.26902771, 9.93792152], [76.26875305, 9.93791676], [76.26875305, 9.93819523], [76.26847076, 9.93819523], [76.26847076, 9.93847084], [76.26819611, 9.93847084], [76.26819611, 9.93875122], [76.26790619, 9.93875122], [76.26790619, 9.9390316], [76.26763916, 9.9390316], [76.26763916, 9.93931198], [76.26735687, 9.93931198], [76.26735687, 9.93987274], [76.26708221, 9.9398613], [76.26708221, 9.94097328], [76.26680756, 9.94097137], [76.26680756, 9.94293118], [76.26708221, 9.94291782], [76.26708221, 9.94374943], [76.26735687, 9.94374943], [76.26735687, 9.94431019], [76.26708221, 9.94430637], [76.26708221, 9.94458389], [76.26680756, 9.94458389], [76.26680756, 9.94486237], [76.2665329, 9.94485855], [76.2665329, 9.94542027], [76.26625061, 9.94541454], [76.26625061, 9.94597244], [76.26597595, 9.94597244], [76.26597595, 9.94680977], [76.26569366, 9.94680595], [76.26569366, 9.94819355], [76.26597595, 9.94819069], [76.26597595, 9.94902992], [76.26625061, 9.94902802], [76.26625061, 9.94919014], [76.26625061, 9.95014], [76.26652527, 9.95014], [76.26652527, 9.95208359], [76.26625061, 9.95208359], [76.26625061, 9.95347214], [76.26597595, 9.95347023], [76.26597595, 9.95514107], [76.26569366, 9.95513821], [76.26569366, 9.9556942], [76.26597595, 9.9556942], [76.26597595, 9.95736027], [76.26568604, 9.95736027], [76.26568604, 9.95764065], [76.26597595, 9.95763779], [76.26597595, 9.95791721], [76.26569366, 9.95791721], [76.26569366, 9.95847321], [76.26541901, 9.95847321], [76.26541901, 9.9598608], [76.26513672, 9.9598608], [76.26513672, 9.96153069], [76.26486206, 9.96152878], [76.26486206, 9.96208286], [76.26457977, 9.96208286], [76.26457977, 9.96236134], [76.26431274, 9.96236134], [76.26431274, 9.96291924], [76.26374817, 9.96291733], [76.26374817, 9.96347332], [76.26346588, 9.96347141], [76.26346588, 9.96375084], [76.26291656, 9.96375084], [76.26291656, 9.9643116], [76.26235962, 9.96430492], [76.26235962, 9.9645834], [76.26152802, 9.9645834], [76.26152802, 9.96486092], [76.26125336, 9.96486092], [76.26125336, 9.9651413], [76.26097107, 9.9651413], [76.26097107, 9.96542168], [76.26041412, 9.96541691], [76.26041412, 9.96569538], [76.26013947, 9.96569538], [76.26013947, 9.96597099], [76.25958252, 9.96597099], [76.25958252, 9.96625137], [76.25930786, 9.96625137], [76.25930786, 9.96652889], [76.25902557, 9.96652699], [76.25902557, 9.96708298], [76.25875092, 9.96708298], [76.25875092, 9.96736145], [76.25846863, 9.96736145], [76.25846863, 9.96764183], [76.25818634, 9.96764183], [76.25818634, 9.9679203], [76.25791931, 9.96791744], [76.25791931, 9.96819305], [76.25763702, 9.96819115], [76.25763702, 9.96903038], [76.25791931, 9.96902657], [76.25791931, 9.96958256], [76.25818634, 9.96958065], [76.25818634, 9.97042179], [76.25875092, 9.97041798]]], [[[76.24430847, 9.98097229], [76.24430847, 9.97847176], [76.24402618, 9.97847176], [76.24402618, 9.97819424], [76.24319458, 9.97819424], [76.24319458, 9.97847176], [76.24291992, 9.97847176], [76.24291992, 9.97958374], [76.24318695, 9.97958183], [76.24318695, 9.98042107], [76.24346924, 9.9804163], [76.24346924, 9.98069382], [76.24375153, 9.98069382], [76.24375153, 9.98097229], [76.24430847, 9.98097229]]], [[[76.27153015, 9.97264004], [76.27153015, 9.9729147], [76.27236176, 9.9729147], [76.27236176, 9.97208405], [76.27263641, 9.97208405], [76.27263641, 9.97180557], [76.27236176, 9.97181034], [76.27236176, 9.97152996], [76.27179718, 9.97152996], [76.27179718, 9.97124863], [76.27097321, 9.97124863], [76.27097321, 9.9709692], [76.26957703, 9.9709692], [76.26957703, 9.97124863], [76.26930237, 9.97124863], [76.26930237, 9.97181034], [76.26902771, 9.97180557], [76.26902771, 9.97208405], [76.26875305, 9.97208118], [76.26875305, 9.97264194], [76.2701416, 9.97264194], [76.2701416, 9.97236156], [76.27097321, 9.97236156], [76.27097321, 9.97264194], [76.27153015, 9.97264004]]], [[[76.26735687, 10.00263977], [76.26735687, 10.00292015], [76.26819611, 10.00292015], [76.26819611, 10.00263977], [76.26847076, 10.00263977], [76.26847076, 10.00208187], [76.26875305, 10.00208378], [76.26875305, 10.00152779], [76.26902771, 10.00152969], [76.26902771, 10.00125027], [76.26930237, 10.00125027], [76.26930237, 10.00097179], [76.26958466, 10.00097179], [76.26957703, 10.00041962], [76.26985931, 10.00041962], [76.26985931, 9.99994087], [76.26985931, 9.99874878], [76.26957703, 9.99875164], [76.26957703, 9.99792004], [76.26930237, 9.99792004], [76.26930237, 9.9970789], [76.26902771, 9.99708271], [76.26902771, 9.99680519], [76.26819611, 9.99680519], [76.26819611, 9.99708271], [76.26791382, 9.99708271], [76.26791382, 9.99986172], [76.26763916, 9.99985886], [76.26763916, 10.00015068], [76.26735687, 10.00015068], [76.2673645, 10.00125027], [76.26708221, 10.00125027], [76.26708221, 10.00152969], [76.26680756, 10.00152969], [76.26680756, 10.00263977], [76.26735687, 10.00263977]]], [[[76.24124908, 10.01403141], [76.24124908, 10.01431084], [76.24180603, 10.01431084], [76.24180603, 10.01403141], [76.24208069, 10.01403141], [76.24208069, 10.01375103], [76.24263763, 10.01375103], [76.24263763, 10.0134697], [76.24319458, 10.01347256], [76.24319458, 10.01319504], [76.24375153, 10.01319504], [76.24375153, 10.01235962], [76.24402618, 10.01235962], [76.24402618, 10.0120821], [76.24430847, 10.01209164], [76.24430847, 10.01181126], [76.24458313, 10.01181126], [76.24458313, 10.01068974], [76.24485779, 10.01069355], [76.24485779, 10.01041603], [76.24514008, 10.0104208], [76.24514008, 10.01014137], [76.24569702, 10.01014137], [76.24569702, 10.00986004], [76.24624634, 10.00986004], [76.24624634, 10.00958538], [76.24680328, 10.00958538], [76.24680328, 10.00930595], [76.24791718, 10.00931072], [76.24791718, 10.0090189], [76.24819183, 10.00902843], [76.24819183, 10.00874996], [76.24874878, 10.00874996], [76.24874878, 10.00846958], [76.24903107, 10.00847244], [76.24903107, 10.00819397], [76.24986267, 10.00819397], [76.24986267, 10.00791645], [76.25068665, 10.00792122], [76.25068665, 10.00736046], [76.25096893, 10.00736237], [76.25096893, 10.00708199], [76.25152588, 10.00708199], [76.25152588, 10.00680637], [76.25180817, 10.00681114], [76.25180817, 10.00653267], [76.25235748, 10.00653267], [76.25235748, 10.00625038], [76.25263977, 10.00625038], [76.25263977, 10.00597191], [76.25319672, 10.00597191], [76.25319672, 10.00485992], [76.25347137, 10.00485992], [76.25347137, 10.00263786], [76.25374603, 10.00263977], [76.25374603, 10.00125027], [76.25402832, 10.00125027], [76.25402832, 10.00069427], [76.25430298, 10.00069427], [76.25430298, 10.00041771], [76.2545929, 10.00041962], [76.2545929, 9.99985886], [76.25458527, 9.9995842], [76.25485992, 9.9995842], [76.25485992, 9.99902821], [76.25514221, 9.99903202], [76.25514221, 9.99847126], [76.25541687, 9.99847126], [76.25541687, 9.99791527], [76.25567627, 9.99792004], [76.25567627, 9.99735928], [76.25597382, 9.99736214], [76.25597382, 9.99652672], [76.25624847, 9.99652958], [76.25624847, 9.99597073], [76.25653076, 9.99597359], [76.25653076, 9.99541664], [76.25681305, 9.99542046], [76.25681305, 9.99458122], [76.25708008, 9.99458313], [76.25708008, 9.99430466], [76.25681305, 9.99431038], [76.25681305, 9.99402046], [76.25708008, 9.99402714], [76.25708008, 9.99374866], [76.25736237, 9.99375057], [76.25736237, 9.99236107], [76.25763702, 9.99236107], [76.25763702, 9.9920826], [76.25791931, 9.9920826], [76.25791931, 9.99125099], [76.25818634, 9.99125099], [76.25818634, 9.99098015], [76.25846863, 9.99098015], [76.25846863, 9.99014091], [76.25875092, 9.99014091], [76.25875092, 9.98958111], [76.25846863, 9.98958302], [76.25846863, 9.98708344], [76.25875092, 9.98708344], [76.25875092, 9.98541737], [76.2590332, 9.98542118], [76.2590332, 9.98403072], [76.25930786, 9.98403072], [76.25930786, 9.98318958], [76.25958252, 9.98319435], [76.25958252, 9.98263836], [76.25985718, 9.98264122], [76.25985718, 9.98236275], [76.26013947, 9.98236275], [76.26013947, 9.98153114], [76.25985718, 9.98153114], [76.25985718, 9.98097038], [76.25958252, 9.98097229], [76.25958252, 9.98069382], [76.25902557, 9.98069382], [76.25902557, 9.9804163], [76.25846863, 9.98042107], [76.25846863, 9.98013973], [76.25818634, 9.98013973], [76.25818634, 9.97986031], [76.25763702, 9.97986221], [76.25763702, 9.97958374], [76.25708008, 9.97958374], [76.25708008, 9.97930622], [76.25653076, 9.97931099], [76.25653076, 9.97904015], [76.25596619, 9.97904015], [76.25596619, 9.97875023], [76.25514221, 9.97875023], [76.25514221, 9.97847176], [76.25458527, 9.97847176], [76.25458527, 9.97819424], [76.25375366, 9.97819424], [76.25375366, 9.97764015], [76.25319672, 9.97764015], [76.25319672, 9.97736168], [76.25263977, 9.97736168], [76.25263977, 9.97707939], [76.25208282, 9.97708416], [76.25208282, 9.97680569], [76.25152588, 9.97681141], [76.25152588, 9.97653008], [76.25068665, 9.97653008], [76.25068665, 9.97624969], [76.24958038, 9.97624969], [76.24958038, 9.97598076], [76.24819183, 9.97598076], [76.24819183, 9.97624969], [76.24736023, 9.97624969], [76.24736023, 9.97653008], [76.24652863, 9.97652817], [76.24652863, 9.97713184], [76.24652863, 9.9843111], [76.24624634, 9.98430443], [76.24624634, 9.98449993], [76.24624634, 9.98708344], [76.24597168, 9.98708344], [76.24597168, 9.98819542], [76.24569702, 9.9881897], [76.24569702, 9.98930931], [76.2454071, 9.98930931], [76.2454071, 9.99041939], [76.24514008, 9.99041939], [76.24514008, 9.99125099], [76.24485779, 9.99125099], [76.24485779, 9.99180984], [76.24458313, 9.99180984], [76.24458313, 9.99264145], [76.24430847, 9.99263859], [76.24430847, 9.99357128], [76.24430847, 9.99458313], [76.24402618, 9.99458313], [76.24402618, 9.99569321], [76.24373627, 9.9956913], [76.24373627, 9.99680996], [76.24346924, 9.99680996], [76.24346924, 9.99763966], [76.24319458, 9.99763966], [76.24319458, 9.99847126], [76.24346924, 9.99847126], [76.24346924, 9.99985886], [76.24346924, 10.00015068], [76.24373627, 10.00015068], [76.24373627, 10.00041962], [76.24402618, 10.00041771], [76.24402618, 10.00097179], [76.24373627, 10.00097179], [76.24373627, 10.00152969], [76.24346924, 10.00152779], [76.24346924, 10.00374985], [76.24373627, 10.00374985], [76.24373627, 10.00403023], [76.24346924, 10.00403023], [76.24346924, 10.00431061], [76.24319458, 10.00430584], [76.24319458, 10.00458431], [76.24291992, 10.00458431], [76.24291992, 10.00485992], [76.24263763, 10.00485992], [76.24263763, 10.0051403], [76.24236298, 10.0051403], [76.24236298, 10.00542068], [76.24208069, 10.00541592], [76.24208069, 10.00597191], [76.24180603, 10.00597191], [76.24180603, 10.00625038], [76.24153137, 10.00625038], [76.24153137, 10.00681114], [76.24124908, 10.00681114], [76.24124908, 10.00792122], [76.2409668, 10.00792122], [76.2409668, 10.00986004], [76.24067688, 10.00986004], [76.24069214, 10.01125145], [76.24041748, 10.01125145], [76.24041748, 10.01181126], [76.24014282, 10.01181126], [76.24014282, 10.01292133], [76.23986053, 10.01292133], [76.23986053, 10.01403141], [76.24014282, 10.01403141], [76.24014282, 10.01431084], [76.24067688, 10.01431084], [76.24067688, 10.01403141], [76.24124908, 10.01403141]]], [[[76.30764008, 9.92125034], [76.30764008, 9.92152977], [76.30847168, 9.92152977], [76.30847168, 9.92125034], [76.30874634, 9.92125034], [76.30874634, 9.92069435], [76.30902863, 9.92069435], [76.30902863, 9.92041779], [76.30930328, 9.92041969], [76.30930328, 9.91986179], [76.3095932, 9.91986179], [76.3095932, 9.91930962], [76.30986023, 9.91930962], [76.30986023, 9.91874027], [76.31014252, 9.91874981], [76.31014252, 9.91763973], [76.31041718, 9.91763973], [76.31041718, 9.91708088], [76.31069183, 9.91708374], [76.31069183, 9.91680527], [76.31096649, 9.91681004], [76.31096649, 9.91652966], [76.31124878, 9.91652966], [76.31124878, 9.91624928], [76.31153107, 9.91624928], [76.31153107, 9.91597366], [76.31180573, 9.9159708], [76.31180573, 9.91569328], [76.31236267, 9.91569996], [76.31236267, 9.91541958], [76.31263733, 9.91541958], [76.31263733, 9.91264057], [76.31236267, 9.91264057], [76.31236267, 9.91208076], [76.31208038, 9.91208267], [76.31208038, 9.91152668], [76.31181335, 9.9115324], [76.31181335, 9.91097069], [76.31153107, 9.9109726], [76.31153107, 9.9104166], [76.31124878, 9.91041946], [76.31124878, 9.90986061], [76.31097412, 9.90986061], [76.31097412, 9.90902901], [76.31124878, 9.90903091], [76.31124878, 9.90818977], [76.31153107, 9.90819454], [76.31153107, 9.90791702], [76.31181335, 9.90792084], [76.31181335, 9.90764141], [76.31208038, 9.90764141], [76.31208038, 9.90736103], [76.31236267, 9.90736103], [76.31236267, 9.90708256], [76.31263733, 9.90708256], [76.31263733, 9.90680695], [76.31291962, 9.90680695], [76.31291962, 9.90652657], [76.31318665, 9.90653133], [76.31318665, 9.90625095], [76.31375122, 9.90625095], [76.31375122, 9.90596962], [76.31402588, 9.90597343], [76.31402588, 9.90569496], [76.31430817, 9.90569496], [76.31430817, 9.90541744], [76.31458282, 9.90542126], [76.31458282, 9.90514088], [76.31513977, 9.90514088], [76.31513977, 9.90486145], [76.31541443, 9.90486145], [76.31541443, 9.90458202], [76.31569672, 9.90458202], [76.31569672, 9.90430355], [76.31595612, 9.90431118], [76.31595612, 9.9040308], [76.31624603, 9.9040308], [76.31624603, 9.90347004], [76.31652832, 9.9034729], [76.31652832, 9.90319443], [76.31680298, 9.90319443], [76.31680298, 9.90291595], [76.3170929, 9.90292072], [76.3170929, 9.90207958], [76.31680298, 9.9020853], [76.31680298, 9.90069389], [76.31652832, 9.90070057], [76.31652832, 9.90014267], [76.31624603, 9.90014267], [76.31624603, 9.89958191], [76.31597137, 9.89958191], [76.31597137, 9.89902782], [76.31569672, 9.89902973], [76.31569672, 9.89818859], [76.31541443, 9.89819431], [76.31541443, 9.89652824], [76.31569672, 9.89653015], [76.31569672, 9.89513969], [76.31595612, 9.89513969], [76.31595612, 9.89457035], [76.31625366, 9.8945837], [76.31625366, 9.89402771], [76.31652832, 9.89402962], [76.31652832, 9.89346886], [76.31680298, 9.89347172], [76.31680298, 9.89264011], [76.3170929, 9.89264202], [76.3170929, 9.89153194], [76.31735992, 9.89153194], [76.31735992, 9.89041996], [76.31764221, 9.89041996], [76.31764221, 9.8868103], [76.31735992, 9.8868103], [76.31735992, 9.88653183], [76.31595612, 9.88653183], [76.31595612, 9.8868103], [76.31458282, 9.88680458], [76.31458282, 9.88708305], [76.31346893, 9.88708305], [76.31346893, 9.88736057], [76.31227875, 9.88736057], [76.31041718, 9.88736057], [76.31041718, 9.88764191], [76.31014252, 9.88763905], [76.31014252, 9.88819313], [76.30986023, 9.88819313], [76.30986023, 9.88847446], [76.3095932, 9.88847065], [76.3095932, 9.88876057], [76.30930328, 9.88874912], [76.30930328, 9.88986206], [76.30902863, 9.88986206], [76.30902863, 9.89069557], [76.30874634, 9.8906889], [76.30874634, 9.89153194], [76.30847168, 9.89152813], [76.30847168, 9.89208412], [76.30819702, 9.89208126], [76.30819702, 9.89291954], [76.3079071, 9.89291954], [76.30791473, 9.89375019], [76.30764008, 9.89375019], [76.30764008, 9.89482117], [76.30764008, 9.89542007], [76.30735779, 9.89541626], [76.30735779, 9.89708424], [76.30708313, 9.89708424], [76.30708313, 9.89764023], [76.30680847, 9.89764023], [76.30680847, 9.89819431], [76.30652618, 9.89818859], [76.30652618, 9.89902973], [76.30625153, 9.89902782], [76.30625153, 9.89958191], [76.30596924, 9.89958191], [76.30596924, 9.90014267], [76.30569458, 9.9001379], [76.30569458, 9.90097237], [76.30541992, 9.90097046], [76.30541992, 9.90125275], [76.30513763, 9.90125275], [76.30513763, 9.90181065], [76.30486298, 9.90180588], [76.30486298, 9.90235996], [76.30458069, 9.90235996], [76.30458069, 9.90292072], [76.30430603, 9.90292072], [76.30430603, 9.9040308], [76.30458069, 9.9040308], [76.30458069, 9.90514088], [76.30486298, 9.90514088], [76.30486298, 9.90625095], [76.30458069, 9.90625095], [76.30458069, 9.90680695], [76.30430603, 9.90680027], [76.30430603, 9.90875053], [76.30458069, 9.90874863], [76.30458069, 9.90986061], [76.30486298, 9.90986061], [76.30486298, 9.9109726], [76.30513763, 9.9109726], [76.30513763, 9.91208267], [76.30541992, 9.91208267], [76.30541992, 9.91347122], [76.30569458, 9.91347122], [76.30569458, 9.91458321], [76.30541992, 9.9145813], [76.30541992, 9.9151392], [76.30513763, 9.9151392], [76.30513763, 9.9159708], [76.30486298, 9.91596889], [76.30486298, 9.91792011], [76.30458069, 9.91791534], [76.30458069, 9.91958427], [76.30486298, 9.91958141], [76.30486298, 9.91986179], [76.30513763, 9.91986179], [76.30513763, 9.92014027], [76.30541992, 9.92014027], [76.30541992, 9.92041969], [76.30569458, 9.92041779], [76.30569458, 9.92069435], [76.30596924, 9.92069435], [76.30596924, 9.92097187], [76.30680847, 9.92097187], [76.30680847, 9.92125034], [76.30764008, 9.92125034]]], [[[76.36763763, 9.58331108], [76.36763763, 9.58319473], [76.36735535, 9.58322716], [76.36736298, 9.58292103], [76.36707306, 9.58292103], [76.36707306, 9.58264065], [76.36680603, 9.58264065], [76.36680603, 9.58207989], [76.36653137, 9.58208466], [76.36653137, 9.58180428], [76.36624908, 9.58181953], [76.36624908, 9.58125114], [76.3659668, 9.58125114], [76.3659668, 9.58069038], [76.36569214, 9.5806942], [76.36569214, 9.57958221], [76.36541748, 9.57958221], [76.36541748, 9.57902813], [76.36514282, 9.57903099], [76.36514282, 9.57875919], [76.36541748, 9.57875919], [76.36541748, 9.57847023], [76.36486053, 9.57847214], [76.36486053, 9.57791615], [76.36429596, 9.57792091], [76.36429596, 9.57763958], [76.36374664, 9.57763958], [76.36374664, 9.57792091], [76.36319733, 9.57792091], [76.36319733, 9.57763958], [76.36235809, 9.57763958], [76.36235809, 9.57736015], [76.36180878, 9.57736015], [76.36180878, 9.57708359], [76.36125183, 9.57708359], [76.36125183, 9.57680416], [76.36068726, 9.57681084], [76.36068726, 9.57653046], [76.36013794, 9.57653046], [76.36013794, 9.5759697], [76.35986328, 9.5759716], [76.35986328, 9.57569408], [76.35958099, 9.57569408], [76.35958099, 9.57486153], [76.35930634, 9.57486153], [76.35930634, 9.57458401], [76.35958099, 9.57458401], [76.35958099, 9.57430553], [76.35930634, 9.57431126], [76.35930634, 9.56931019], [76.35958099, 9.56931019], [76.35958099, 9.5676403], [76.35930634, 9.5676403], [76.35930634, 9.56736183], [76.35958099, 9.56736183], [76.35958099, 9.56597137], [76.35930634, 9.56597137], [76.35930634, 9.56513882], [76.35901642, 9.56514168], [76.35901642, 9.5648613], [76.35847473, 9.5648613], [76.35847473, 9.56458282], [76.35819244, 9.56458282], [76.35819244, 9.56402683], [76.35764313, 9.5640316], [76.35764313, 9.56375122], [76.35736084, 9.56375122], [76.35736084, 9.56152916], [76.35764313, 9.56153202], [76.35764313, 9.56125069], [76.35736084, 9.56125069], [76.35736084, 9.56097126], [76.3576355, 9.56097317], [76.3576355, 9.56069469], [76.35736084, 9.56069469], [76.35736084, 9.56041718], [76.35764313, 9.56042194], [76.35764313, 9.55931187], [76.35791779, 9.55931187], [76.35791779, 9.55903053], [76.35764313, 9.55903053], [76.35764313, 9.55792141], [76.35736084, 9.55792141], [76.35736084, 9.55486012], [76.35708618, 9.55486012], [76.35708618, 9.55430698], [76.35679626, 9.55430889], [76.35679626, 9.55264091], [76.35652924, 9.55264091], [76.35652924, 9.55151939], [76.35624695, 9.55152798], [76.35624695, 9.55125046], [76.35597229, 9.55125046], [76.35597229, 9.55041599], [76.35569763, 9.55042076], [76.35569763, 9.54792118], [76.35542297, 9.54792118], [76.35542297, 9.54736042], [76.35514069, 9.54736233], [76.35514069, 9.54652786], [76.3548584, 9.54653263], [76.3548584, 9.54265118], [76.35457611, 9.54265118], [76.35457611, 9.54181004], [76.35430908, 9.54181004], [76.35430908, 9.54124928], [76.35402679, 9.54124928], [76.35402679, 9.54097366], [76.35375214, 9.5409708], [76.35375214, 9.54041767], [76.35346985, 9.54041958], [76.35346985, 9.53986073], [76.35319519, 9.53986073], [76.35319519, 9.53958321], [76.35346985, 9.53958321], [76.35346985, 9.53930473], [76.35320282, 9.53931046], [76.35320282, 9.53792191], [76.35346985, 9.53792191], [76.35346985, 9.53764153], [76.35320282, 9.53764153], [76.35320282, 9.53736115], [76.35346985, 9.53736115], [76.35346985, 9.53680515], [76.35320282, 9.53681183], [76.35320282, 9.53652], [76.35346985, 9.53652668], [76.35346985, 9.5354166], [76.35320282, 9.53541946], [76.35320282, 9.53486061], [76.35346985, 9.53486061], [76.35346985, 9.53319454], [76.35402679, 9.53319454], [76.35402679, 9.53263855], [76.35430908, 9.53264141], [76.35430908, 9.53097057], [76.35458374, 9.53097343], [76.35458374, 9.53069496], [76.3548584, 9.53069496], [76.3548584, 9.52986145], [76.35514069, 9.52986145], [76.35514069, 9.52930546], [76.35542297, 9.52930927], [76.35542297, 9.52902889], [76.35569763, 9.52902889], [76.35569763, 9.52875137], [76.35597229, 9.52875137], [76.35597229, 9.5284729], [76.35624695, 9.5284729], [76.35624695, 9.52791691], [76.35652924, 9.52792072], [76.35652924, 9.52707958], [76.35680389, 9.52708244], [76.35680389, 9.52597237], [76.35708618, 9.52597237], [76.35708618, 9.52541637], [76.35736084, 9.52542114], [76.35736084, 9.5251379], [76.3576355, 9.5251379], [76.3576355, 9.52458191], [76.35819244, 9.52458191], [76.35819244, 9.52486038], [76.35902405, 9.52486038], [76.35902405, 9.52458191], [76.36013794, 9.52458191], [76.36013794, 9.52402782], [76.36042023, 9.52403069], [76.36042023, 9.52375031], [76.36319733, 9.52375031], [76.36319733, 9.52347183], [76.36374664, 9.52347183], [76.36374664, 9.52319431], [76.36430359, 9.52319431], [76.36430359, 9.52291584], [76.36541748, 9.52292061], [76.36541748, 9.52264023], [76.36653137, 9.52264023], [76.36653137, 9.52235985], [76.36736298, 9.52235985], [76.36736298, 9.52208424], [76.36846924, 9.52208424], [76.36846924, 9.52180576], [76.37124634, 9.52180576], [76.37124634, 9.52208424], [76.37213135, 9.52208424], [76.37264252, 9.52208424], [76.37264252, 9.52235985], [76.37403107, 9.52235985], [76.37403107, 9.52264023], [76.37458038, 9.52264023], [76.37458038, 9.52235985], [76.37486267, 9.52235985], [76.37486267, 9.52208424], [76.37513733, 9.52208424], [76.37513733, 9.52180576], [76.37541962, 9.52181053], [76.37541962, 9.52153969], [76.37568665, 9.52153969], [76.37568665, 9.52124977], [76.37625885, 9.52124977], [76.37625885, 9.52097034], [76.37652588, 9.52097225], [76.37652588, 9.52069378], [76.37680817, 9.52069378], [76.37680817, 9.52041626], [76.37708282, 9.52042007], [76.37708282, 9.52013969], [76.37735748, 9.52013969], [76.37735748, 9.51986027], [76.37763977, 9.51986217], [76.37763977, 9.5195837], [76.37819672, 9.5195837], [76.37819672, 9.51930618], [76.37847137, 9.51931095], [76.37847137, 9.51902962], [76.37874603, 9.51902962], [76.37874603, 9.51791954], [76.37847137, 9.51791954], [76.37847137, 9.51707935], [76.38097382, 9.51708412], [76.38097382, 9.51680565], [76.38124847, 9.51681042], [76.38124847, 9.51653004], [76.38181305, 9.51653004], [76.38181305, 9.51624966], [76.38207245, 9.51624966], [76.38207245, 9.51596928], [76.38263702, 9.51597214], [76.38263702, 9.51430607], [76.38291931, 9.51431179], [76.38291931, 9.51153183], [76.38263702, 9.51153183], [76.38263702, 9.50847054], [76.38236237, 9.5084734], [76.38236237, 9.50652695], [76.38319397, 9.50652695], [76.38319397, 9.50708294], [76.38346863, 9.50708103], [76.38346863, 9.50764084], [76.38375092, 9.50764084], [76.38375092, 9.51041985], [76.3840332, 9.51041985], [76.3840332, 9.51431179], [76.38375092, 9.51431179], [76.38375092, 9.51653004], [76.38346863, 9.51652813], [76.38346863, 9.51986217], [76.38319397, 9.51986217], [76.38319397, 9.52097225], [76.38346863, 9.52097034], [76.38346863, 9.52124977], [76.38318634, 9.52124977], [76.38318634, 9.52153969], [76.38346863, 9.52152824], [76.38346863, 9.52347183], [76.38319397, 9.52347183], [76.38319397, 9.52597237], [76.38846588, 9.52597046], [76.38846588, 9.52625275], [76.39624786, 9.52625275], [76.39624786, 9.52653122], [76.40402985, 9.52653122], [76.40402985, 9.52681065], [76.41402435, 9.52680683], [76.41402435, 9.52708244], [76.42375183, 9.52708244], [76.42375183, 9.52735996], [76.43402863, 9.52735996], [76.43402863, 9.52680683], [76.43430328, 9.52681065], [76.43430328, 9.52653122], [76.43402863, 9.52653122], [76.43402863, 9.52625275], [76.43430328, 9.52625275], [76.43430328, 9.52486038], [76.43458557, 9.52486038], [76.43458557, 9.5243063], [76.43514252, 9.52431107], [76.43514252, 9.52403069], [76.43541718, 9.52403069], [76.43541718, 9.52375031], [76.43569183, 9.52375031], [76.43569183, 9.52403069], [76.43596649, 9.52403069], [76.43596649, 9.52346992], [76.43624878, 9.52347183], [76.43624878, 9.52319431], [76.43597412, 9.52319431], [76.43597412, 9.52291584], [76.43624878, 9.52292061], [76.43624878, 9.52264023], [76.43596649, 9.52264023], [76.43596649, 9.52235985], [76.43624878, 9.52235985], [76.43624878, 9.52097225], [76.43541718, 9.52097225], [76.43541718, 9.52069378], [76.43514252, 9.52069378], [76.43514252, 9.52041626], [76.4345932, 9.52042007], [76.4345932, 9.51931095], [76.43486023, 9.51931095], [76.43486023, 9.51902962], [76.43514252, 9.51902962], [76.43514252, 9.51848125], [76.43596649, 9.51848125], [76.43596649, 9.51902962], [76.43624878, 9.51902962], [76.43624878, 9.51931095], [76.4365387, 9.51931095], [76.4365387, 9.52013969], [76.43708038, 9.52013779], [76.43708038, 9.52069378], [76.43763733, 9.52069378], [76.43763733, 9.52041626], [76.43791962, 9.52042007], [76.43791962, 9.51986027], [76.43819427, 9.51986217], [76.43819427, 9.5195837], [76.43846893, 9.5195837], [76.43846893, 9.51875019], [76.43875122, 9.51875019], [76.43875122, 9.51791573], [76.43902588, 9.51791954], [76.43902588, 9.51653004], [76.43875122, 9.51653004], [76.43875122, 9.51624966], [76.43846893, 9.51624966], [76.43846893, 9.51541996], [76.43818665, 9.51541996], [76.43818665, 9.51431179], [76.43846893, 9.51431179], [76.43846893, 9.51403046], [76.43875122, 9.51403046], [76.43875122, 9.51375198], [76.43902588, 9.51375198], [76.43902588, 9.51347065], [76.43958282, 9.51347446], [76.43958282, 9.51319313], [76.43985748, 9.51319313], [76.43985748, 9.51291847], [76.4404068, 9.51292038], [76.4404068, 9.51235008], [76.44069672, 9.51236057], [76.44069672, 9.51208305], [76.44097137, 9.51208305], [76.44097137, 9.51152706], [76.44152832, 9.51153183], [76.44152832, 9.51125145], [76.44235229, 9.51125145], [76.44235229, 9.51153183], [76.44264221, 9.51152706], [76.44264221, 9.51236057], [76.44291687, 9.51235008], [76.44291687, 9.51375198], [76.44264221, 9.51375198], [76.44264221, 9.51403046], [76.44291687, 9.51402664], [76.44291687, 9.51735973], [76.44264221, 9.51735973], [76.44264221, 9.52403069], [76.44235229, 9.52403069], [76.44235229, 9.5251379], [76.44264221, 9.5251379], [76.44264221, 9.52542114], [76.44235229, 9.52542114], [76.44235229, 9.52625275], [76.44264221, 9.52624989], [76.44264221, 9.52708244], [76.44291687, 9.52707958], [76.44291687, 9.5276413], [76.4484787, 9.5276413], [76.4484787, 9.52792072], [76.45319366, 9.52791691], [76.45319366, 9.52819538], [76.45930481, 9.52819538], [76.45930481, 9.52791691], [76.4595871, 9.52791691], [76.4595871, 9.52819538], [76.46152496, 9.52819538], [76.46152496, 9.52791691], [76.46263885, 9.52791691], [76.46263885, 9.52819538], [76.46389771, 9.52819538], [76.46430206, 9.52819538], [76.46430206, 9.5284729], [76.46679688, 9.52847004], [76.46679688, 9.52875137], [76.46708679, 9.52875137], [76.46708679, 9.52902889], [76.46763611, 9.52902889], [76.46763611, 9.52875137], [76.46847534, 9.52875137], [76.46847534, 9.5284729], [76.47041321, 9.5284729], [76.47041321, 9.52875137], [76.4715271, 9.52875137], [76.4715271, 9.5284729], [76.47264099, 9.5284729], [76.47264099, 9.52875137], [76.47486115, 9.52875137], [76.47486115, 9.5284729], [76.47569275, 9.5284729], [76.47569275, 9.52875137], [76.47902679, 9.52875137], [76.47902679, 9.52819538], [76.47930908, 9.52819538], [76.47930908, 9.52735996], [76.47902679, 9.52735996], [76.47902679, 9.52708244], [76.47930908, 9.52708244], [76.47930908, 9.52680683], [76.47902679, 9.52681065], [76.47902679, 9.52458], [76.47930908, 9.52458191], [76.47930908, 9.52375031], [76.47958374, 9.52375031], [76.47957611, 9.52318954], [76.47930908, 9.52319431], [76.47930908, 9.51847172], [76.47957611, 9.51848125], [76.47957611, 9.51791954], [76.47930908, 9.51791954], [76.47930908, 9.51653004], [76.47957611, 9.51653004], [76.47957611, 9.51403046], [76.4798584, 9.51403046], [76.4798584, 9.5118103], [76.48014069, 9.5118103], [76.48014069, 9.51125145], [76.48042297, 9.51125145], [76.48042297, 9.5118103], [76.48069763, 9.51180458], [76.48069763, 9.51347446], [76.48097229, 9.51347446], [76.48097229, 9.51708412], [76.48069763, 9.51707935], [76.48069763, 9.51764202], [76.48097229, 9.51764202], [76.48097229, 9.51902962], [76.48069763, 9.51902962], [76.48069763, 9.52292061], [76.48042297, 9.52292061], [76.48042297, 9.52431107], [76.48069763, 9.5243063], [76.48069763, 9.52569389], [76.48041534, 9.52569389], [76.48041534, 9.52735996], [76.48069763, 9.52735996], [76.48069763, 9.52902889], [76.48264313, 9.52902889], [76.48264313, 9.52930927], [76.48319244, 9.52930927], [76.48319244, 9.52902889], [76.48486328, 9.52902889], [76.48486328, 9.52930927], [76.48542023, 9.52930927], [76.48542023, 9.52902889], [76.48596954, 9.52902889], [76.48596954, 9.52930927], [76.48902893, 9.52930546], [76.48902893, 9.52958298], [76.48930359, 9.52958298], [76.48930359, 9.52930546], [76.48958588, 9.52930546], [76.48958588, 9.52958298], [76.49153137, 9.52958298], [76.49153137, 9.52930546], [76.49291992, 9.52930546], [76.49291992, 9.52958298], [76.49319458, 9.52958298], [76.49319458, 9.52930546], [76.49375153, 9.52930546], [76.49375153, 9.52958298], [76.49458313, 9.52958298], [76.49458313, 9.52930546], [76.49597168, 9.52930927], [76.49597168, 9.52902889], [76.49652863, 9.52902889], [76.49652863, 9.52875137], [76.49846649, 9.52875137], [76.49846649, 9.52902889], [76.50013733, 9.52902889], [76.50013733, 9.52930927], [76.50096893, 9.52930546], [76.50096893, 9.52958298], [76.50125122, 9.52958298], [76.50125122, 9.52986145], [76.50152588, 9.52986145], [76.50152588, 9.53014088], [76.50180817, 9.53013897], [76.50180817, 9.53069496], [76.50208282, 9.53069496], [76.50208282, 9.53097343], [76.50180817, 9.53097057], [76.50180817, 9.53125095], [76.49958801, 9.53125095], [76.49958801, 9.53153133], [76.49931335, 9.53153133], [76.49931335, 9.53180885], [76.49874878, 9.53180695], [76.49874878, 9.53208256], [76.49791718, 9.53208256], [76.49791718, 9.53236103], [76.49764252, 9.53236103], [76.49764252, 9.53292179], [76.49736023, 9.53292179], [76.49736023, 9.53347969], [76.4970932, 9.53347969], [76.4970932, 9.53375053], [76.49680328, 9.53375053], [76.49680328, 9.53403091], [76.49597168, 9.53403091], [76.49597168, 9.53431034], [76.49569702, 9.53430462], [76.49569702, 9.53458309], [76.49458313, 9.53458309], [76.49458313, 9.53486061], [76.49430847, 9.53486061], [76.49430847, 9.53514099], [76.49318695, 9.53514099], [76.49318695, 9.53541946], [76.49236298, 9.5354166], [76.49236298, 9.53569508], [76.49208069, 9.53569508], [76.49208069, 9.5359726], [76.49153137, 9.5359726], [76.49153137, 9.53652668], [76.49124908, 9.53652668], [76.49124908, 9.53736115], [76.4909668, 9.53736115], [76.4909668, 9.53931046], [76.49069214, 9.53931046], [76.49069214, 9.54041958], [76.49041748, 9.54041767], [76.49041748, 9.54069328], [76.49013519, 9.54069328], [76.49013519, 9.5409708], [76.48958588, 9.54097366], [76.48958588, 9.54124928], [76.48902893, 9.54124928], [76.48902893, 9.54152966], [76.48792267, 9.54152966], [76.48792267, 9.54181004], [76.48764038, 9.54180622], [76.48764038, 9.54208374], [76.48708344, 9.54208374], [76.48708344, 9.54236221], [76.48569489, 9.54236221], [76.48569489, 9.54208374], [76.48513794, 9.54208374], [76.48513794, 9.54180622], [76.48458862, 9.54181004], [76.48458862, 9.54152966], [76.48430634, 9.54152966], [76.48430634, 9.54124928], [76.48401642, 9.54124928], [76.48401642, 9.54096889], [76.48374939, 9.5409708], [76.48374939, 9.54069328], [76.48319244, 9.54069328], [76.48319244, 9.54041767], [76.48291779, 9.54041958], [76.48291779, 9.54014015], [76.48236084, 9.54014015], [76.48236084, 9.5395813], [76.48180389, 9.53958321], [76.48180389, 9.53930473], [76.48124695, 9.53931046], [76.48124695, 9.53903198], [76.48097229, 9.53903198], [76.48097229, 9.5387516], [76.48042297, 9.5387516], [76.48042297, 9.53819084], [76.47846985, 9.53819466], [76.47846985, 9.53847122], [76.4779129, 9.53847122], [76.4779129, 9.5387516], [76.4770813, 9.5387516], [76.4770813, 9.53903198], [76.47624969, 9.53903198], [76.47624969, 9.53931046], [76.47569275, 9.53930473], [76.47569275, 9.53958321], [76.47402954, 9.53958321], [76.47402954, 9.53986073], [76.4734726, 9.53986073], [76.4734726, 9.54014015], [76.47292328, 9.54014015], [76.47292328, 9.54041958], [76.47264099, 9.54041767], [76.47264099, 9.54069328], [76.47097015, 9.54069328], [76.47097015, 9.5409708], [76.47013855, 9.54097366], [76.47013855, 9.54124928], [76.46930695, 9.54124928], [76.46930695, 9.54152966], [76.46848297, 9.54152966], [76.46848297, 9.54181004], [76.4679184, 9.54180622], [76.4679184, 9.54208374], [76.46708679, 9.54208374], [76.46708679, 9.54236221], [76.46652222, 9.54235935], [76.46652222, 9.54265118], [76.46624756, 9.54265118], [76.46624756, 9.54292011], [76.4659729, 9.54292011], [76.4659729, 9.54514027], [76.46624756, 9.54514027], [76.46624756, 9.54986], [76.46652222, 9.54986], [76.46652222, 9.55042076], [76.46624756, 9.55041599], [76.46624756, 9.55125046], [76.4659729, 9.55125046], [76.4659729, 9.55152798], [76.46624756, 9.55152798], [76.46624756, 9.55347157], [76.46652222, 9.55346966], [76.46652222, 9.55403137], [76.46624756, 9.55403137], [76.46624756, 9.55458927], [76.46652222, 9.55458927], [76.46652222, 9.55792141], [76.4668045, 9.55791664], [76.4668045, 9.55847263], [76.46652222, 9.55847073], [76.46652222, 9.55931187], [76.46541595, 9.55931187], [76.46541595, 9.55653095], [76.4651413, 9.55653095], [76.4651413, 9.55597019], [76.46541595, 9.55597305], [76.46541595, 9.55569458], [76.4651413, 9.55569458], [76.4651413, 9.55430698], [76.46541595, 9.55430889], [76.46541595, 9.55346966], [76.4651413, 9.55347157], [76.4651413, 9.55291557], [76.46541595, 9.5529213], [76.46541595, 9.55125046], [76.4651413, 9.55125046], [76.4651413, 9.54986], [76.46541595, 9.54986], [76.46541595, 9.5490284], [76.4651413, 9.5490303], [76.4651413, 9.54736042], [76.46485901, 9.54736233], [76.46485901, 9.54374981], [76.46458435, 9.54374981], [76.46458435, 9.54347229], [76.46347046, 9.54347229], [76.46347046, 9.54374981], [76.46263885, 9.54374981], [76.46263885, 9.54403019], [76.46208191, 9.54403019], [76.46208191, 9.54430962], [76.46125031, 9.5443058], [76.46125031, 9.54458427], [76.4604187, 9.54458237], [76.4604187, 9.54486179], [76.45874786, 9.54486179], [76.45874786, 9.54514027], [76.45819092, 9.54514027], [76.45819092, 9.54541969], [76.4576416, 9.54541588], [76.4576416, 9.54569435], [76.45625305, 9.54569435], [76.45625305, 9.54597187], [76.45597076, 9.54597187], [76.45597076, 9.54625034], [76.45513916, 9.54625034], [76.45513916, 9.54653263], [76.45430756, 9.54653263], [76.45430756, 9.5468111], [76.45236206, 9.54680634], [76.45236206, 9.54708195], [76.45218658, 9.54708195], [76.45180511, 9.54708195], [76.45180511, 9.54736233], [76.45124817, 9.54736042], [76.45124817, 9.54763985], [76.45014191, 9.54763985], [76.45014191, 9.54792118], [76.44930267, 9.54791641], [76.44930267, 9.54819393], [76.44875336, 9.54819393], [76.44875336, 9.5484724], [76.44735718, 9.54846096], [76.44735718, 9.54874992], [76.44680786, 9.54874992], [76.44680786, 9.5490303], [76.4465332, 9.5490303], [76.4465332, 9.54931068], [76.44486237, 9.54930592], [76.44486237, 9.54957962], [76.44403076, 9.54958439], [76.44403076, 9.54986], [76.44374847, 9.54986], [76.44374847, 9.55014038], [76.44291687, 9.55014038], [76.44291687, 9.55042076], [76.44180298, 9.55041599], [76.44180298, 9.55069447], [76.44125366, 9.55069447], [76.44125366, 9.55097198], [76.4404068, 9.55097008], [76.44041443, 9.55125046], [76.43985748, 9.55125046], [76.43985748, 9.55152798], [76.43930817, 9.55152798], [76.43930817, 9.55319405], [76.43902588, 9.55319023], [76.43902588, 9.55375099], [76.43846893, 9.55375099], [76.43846893, 9.55403137], [76.43569183, 9.55403137], [76.43569183, 9.55430889], [76.4345932, 9.55430889], [76.4345932, 9.55458927], [76.43430328, 9.55458164], [76.43430328, 9.55486012], [76.43347931, 9.55486012], [76.43347931, 9.55514145], [76.43180847, 9.55514145], [76.43180847, 9.55486012], [76.43125153, 9.55486012], [76.43125153, 9.55514145], [76.43096924, 9.55514145], [76.43096924, 9.55486012], [76.42819214, 9.55486012], [76.42819214, 9.55514145], [76.42652893, 9.55514145], [76.42652893, 9.55542088], [76.42597198, 9.55541706], [76.42597198, 9.55569458], [76.42541504, 9.55569458], [76.42541504, 9.55597305], [76.42485809, 9.55597019], [76.42485809, 9.55625057], [76.42457581, 9.55625057], [76.42457581, 9.55653095], [76.42430878, 9.55653095], [76.42430878, 9.55681133], [76.42402649, 9.55680466], [76.42402649, 9.55708313], [76.42375183, 9.55708313], [76.42375183, 9.55736065], [76.42318726, 9.55736065], [76.42318726, 9.55764961], [76.42263794, 9.55764961], [76.42263794, 9.55792141], [76.42208099, 9.55791664], [76.42208099, 9.55819511], [76.42097473, 9.55819511], [76.42097473, 9.55847263], [76.4201355, 9.55847263], [76.42014313, 9.55875111], [76.41929626, 9.55875111], [76.41929626, 9.55903053], [76.41874695, 9.55903053], [76.41874695, 9.55931187], [76.41819763, 9.55930519], [76.41819763, 9.55958271], [76.41792297, 9.5595808], [76.41792297, 9.56042194], [76.41764069, 9.56042194], [76.41764069, 9.56125069], [76.41792297, 9.56125069], [76.41792297, 9.56236076], [76.41819763, 9.56236076], [76.41819763, 9.56319523], [76.41847229, 9.56319523], [76.41847229, 9.56347084], [76.41819763, 9.56346035], [76.41819763, 9.56431198], [76.41791534, 9.56430531], [76.41791534, 9.56458282], [76.41764069, 9.56458282], [76.41764069, 9.5648613], [76.4173584, 9.5648613], [76.4173584, 9.56514168], [76.41680908, 9.56514168], [76.41680908, 9.56542015], [76.41625214, 9.56541729], [76.41625214, 9.56597137], [76.41596985, 9.56597137], [76.41596985, 9.56959057], [76.41625214, 9.56958389], [76.41625214, 9.56986237], [76.41652679, 9.56985855], [76.41652679, 9.57014179], [76.41680908, 9.57013988], [76.41680908, 9.5706892], [76.41652679, 9.57069969], [76.41652679, 9.57181263], [76.41680908, 9.57180595], [76.41680908, 9.57208443], [76.4173584, 9.57208443], [76.4173584, 9.57236195], [76.41791534, 9.57236195], [76.41791534, 9.57319355], [76.41819763, 9.57319164], [76.41819763, 9.57402992], [76.41847229, 9.57402802], [76.41847229, 9.57458401], [76.41874695, 9.57458401], [76.41874695, 9.57569408], [76.41930389, 9.57569408], [76.41930389, 9.5759716], [76.41958618, 9.5759716], [76.41958618, 9.57736015], [76.41986084, 9.57736015], [76.41986084, 9.57792091], [76.4201355, 9.57791615], [76.4201355, 9.57819366], [76.42041779, 9.57818985], [76.42041779, 9.57931137], [76.42069244, 9.57930565], [76.42069244, 9.58097267], [76.4209671, 9.5809679], [76.4209671, 9.58181953], [76.42124939, 9.58181953], [76.42124939, 9.58264065], [76.42152405, 9.58263874], [76.42152405, 9.58319473], [76.42124939, 9.58318996], [76.42124939, 9.58375072], [76.42152405, 9.58375072], [76.42152405, 9.58458328], [76.42180634, 9.58457088], [76.42180634, 9.58514118], [76.42208099, 9.58513927], [76.42208099, 9.58625126], [76.42236328, 9.58625126], [76.42236328, 9.58736134], [76.42263794, 9.58736134], [76.42263794, 9.58763885], [76.42292023, 9.58763027], [76.42292023, 9.58791924], [76.42263794, 9.58791733], [76.42263794, 9.58819485], [76.42292023, 9.58819103], [76.42292023, 9.58930969], [76.42318726, 9.58930969], [76.42318726, 9.59042168], [76.42292023, 9.59042168], [76.42292023, 9.59152889], [76.42319489, 9.59152699], [76.42319489, 9.59319305], [76.42346954, 9.59319115], [76.42346954, 9.59403038], [76.42375183, 9.59402657], [76.42375183, 9.59458447], [76.42402649, 9.59458065], [76.42402649, 9.59514046], [76.42430878, 9.59514046], [76.42430878, 9.59597206], [76.42457581, 9.5959692], [76.42457581, 9.59652996], [76.42485809, 9.59652805], [76.42485809, 9.59708405], [76.42514038, 9.59707928], [76.42514038, 9.59792042], [76.42542267, 9.59792042], [76.42542267, 9.59875202], [76.42569733, 9.59875011], [76.42569733, 9.59958363], [76.42597198, 9.59958363], [76.42597198, 9.6006937], [76.42624664, 9.6006937], [76.42624664, 9.60235977], [76.42652893, 9.60235977], [76.42652893, 9.60347176], [76.42679596, 9.60346985], [76.42679596, 9.60403061], [76.42764282, 9.60403061], [76.42764282, 9.60431099], [76.42791748, 9.60430622], [76.42791748, 9.60458374], [76.42819214, 9.60458374], [76.42819214, 9.60486031], [76.4284668, 9.60486031], [76.4284668, 9.60513973], [76.42874908, 9.60513973], [76.42874908, 9.60570145], [76.42903137, 9.60570145], [76.42903137, 9.60681057], [76.42930603, 9.60680676], [76.42930603, 9.6081953], [76.42958069, 9.60818958], [76.42958069, 9.6093092], [76.42986298, 9.6093092], [76.42986298, 9.61042118], [76.43013763, 9.61042118], [76.43013763, 9.61125088], [76.42986298, 9.61125088], [76.42986298, 9.61208344], [76.42958069, 9.61207962], [76.42958069, 9.61291885], [76.42930603, 9.61291695], [76.42930603, 9.61347294], [76.4284668, 9.61347103], [76.4284668, 9.61652946], [76.42819214, 9.61652946], [76.42819214, 9.61680984], [76.42791748, 9.61680508], [76.42791748, 9.61736107], [76.42735291, 9.61736107], [76.42735291, 9.61793137], [76.42680359, 9.61791706], [76.42680359, 9.61819458], [76.42652893, 9.61819077], [76.42652893, 9.61903191], [76.42624664, 9.61903191], [76.42624664, 9.61931038], [76.42597198, 9.61930466], [76.42597198, 9.61958313], [76.42569733, 9.61958122], [76.42569733, 9.62042046], [76.42542267, 9.62042046], [76.42542267, 9.62152958], [76.42514038, 9.62152958], [76.42514038, 9.62263966], [76.42485809, 9.62263966], [76.42485809, 9.62292004], [76.42458344, 9.62291527], [76.42458344, 9.62347221], [76.42430878, 9.62347221], [76.42430878, 9.62486172], [76.42402649, 9.62485981], [76.42402649, 9.62541962], [76.42375183, 9.6254158], [76.42375183, 9.62625027], [76.42346954, 9.62625027], [76.42346954, 9.62681103], [76.42319489, 9.62680626], [76.42319489, 9.62708378], [76.42346954, 9.62708378], [76.42346954, 9.62736225], [76.42318726, 9.62736034], [76.42318726, 9.62764168], [76.42292023, 9.62763786], [76.42292023, 9.62819386], [76.42263794, 9.62819386], [76.42263794, 9.62847233], [76.42236328, 9.62847233], [76.42236328, 9.62874985], [76.42208099, 9.62874985], [76.42208099, 9.62903023], [76.42180634, 9.62903023], [76.42180634, 9.62931061], [76.42124939, 9.62930584], [76.42124939, 9.62958431], [76.42069244, 9.62957954], [76.42069244, 9.62987137], [76.42041779, 9.62987137], [76.42041779, 9.6301403], [76.42014313, 9.6301403], [76.42014313, 9.63042068], [76.41930389, 9.63041592], [76.41930389, 9.63069439], [76.41874695, 9.63069439], [76.41874695, 9.63097191], [76.41847229, 9.63097], [76.41847229, 9.63153076], [76.41819763, 9.6315279], [76.41819763, 9.63208199], [76.41792297, 9.63208199], [76.41792297, 9.63264275], [76.41764069, 9.63263798], [76.41764069, 9.63319016], [76.4173584, 9.63320065], [76.4173584, 9.63514137], [76.41707611, 9.63514137], [76.41707611, 9.63625145], [76.4173584, 9.63625145], [76.4173584, 9.63681126], [76.41764069, 9.63681126], [76.41764069, 9.63792133], [76.41792297, 9.63792133], [76.41792297, 9.63903141], [76.41819763, 9.63903141], [76.41819763, 9.63931179], [76.41847229, 9.63930511], [76.41847229, 9.63958263], [76.41874695, 9.63958073], [76.41874695, 9.64014053], [76.41902924, 9.64014053], [76.41902924, 9.64042187], [76.41930389, 9.6404171], [76.41930389, 9.64069462], [76.41958618, 9.64068985], [76.41958618, 9.64125061], [76.41986084, 9.64125061], [76.41986084, 9.64153099], [76.42069244, 9.64153099], [76.42069244, 9.64125061], [76.4209671, 9.64125061], [76.4209671, 9.64097118], [76.42263794, 9.64097118], [76.42263794, 9.64125061], [76.42542267, 9.64125061], [76.42542267, 9.64181042], [76.42514038, 9.6418047], [76.42514038, 9.64208317], [76.42485809, 9.64208317], [76.42485809, 9.64236069], [76.42457581, 9.64236069], [76.42457581, 9.64291859], [76.42430878, 9.64291668], [76.42430878, 9.64319515], [76.42402649, 9.64319515], [76.42402649, 9.64347267], [76.42375183, 9.64347267], [76.42375183, 9.64375114], [76.42318726, 9.64375114], [76.42318726, 9.64403152], [76.42263794, 9.64403152], [76.42263794, 9.6443119], [76.42208099, 9.6443119], [76.42208099, 9.64375114], [76.42180634, 9.64375114], [76.42180634, 9.64347267], [76.42151642, 9.64347076], [76.42152405, 9.64375114], [76.42124939, 9.64375114], [76.42124939, 9.64439201], [76.42124939, 9.64458275], [76.4209671, 9.64458084], [76.4209671, 9.6451416], [76.42041779, 9.6451416], [76.42041779, 9.64458084], [76.4201355, 9.64458275], [76.4201355, 9.64347267], [76.41986084, 9.64347267], [76.41986084, 9.64319992], [76.41986084, 9.64236069], [76.41958618, 9.64236069], [76.41958618, 9.6418047], [76.41930389, 9.6418047], [76.41930389, 9.64272118], [76.41929626, 9.64403152], [76.41958618, 9.64402676], [76.41958618, 9.64569473], [76.41986084, 9.64569092], [76.41986084, 9.64625168], [76.42014313, 9.64625168], [76.42014313, 9.64680958], [76.42041779, 9.64680958], [76.42041779, 9.64764023], [76.42069244, 9.64764023], [76.42069244, 9.64819336], [76.4209671, 9.64819145], [76.4209671, 9.64931011], [76.42124939, 9.64931011], [76.42124939, 9.65042019], [76.42041779, 9.65042019], [76.42041779, 9.65013981], [76.4201355, 9.65013981], [76.4201355, 9.64986229], [76.41986084, 9.64986229], [76.41986084, 9.64902782], [76.41958618, 9.64902973], [76.41958618, 9.64791107], [76.41930389, 9.64791775], [76.41930389, 9.6473608], [76.41902924, 9.6473608], [76.41902924, 9.64680481], [76.41874695, 9.64680958], [76.41874695, 9.64625168], [76.41847229, 9.64625168], [76.41847229, 9.64458084], [76.41819763, 9.64458275], [76.41819763, 9.64291668], [76.41792297, 9.64291859], [76.41792297, 9.64236069], [76.4173584, 9.64236069], [76.4173584, 9.64264107], [76.41680908, 9.64264107], [76.41680908, 9.64291859], [76.41513824, 9.64291668], [76.41513824, 9.64319515], [76.41402435, 9.64319515], [76.41402435, 9.64347267], [76.41291809, 9.64347267], [76.41291809, 9.64375114], [76.41208649, 9.64375114], [76.41208649, 9.64403152], [76.41124725, 9.64403152], [76.41124725, 9.6443119], [76.41069794, 9.64430523], [76.41069794, 9.64458275], [76.40820313, 9.64458084], [76.40820313, 9.6448698], [76.40763855, 9.6448698], [76.40763855, 9.6451416], [76.40735626, 9.6451416], [76.40735626, 9.64542198], [76.4067688, 9.64541721], [76.40625, 9.64541721], [76.40625, 9.64569473], [76.40569305, 9.64569473], [76.40569305, 9.6459713], [76.40458679, 9.6459713], [76.40458679, 9.64625168], [76.40374756, 9.64625168], [76.40374756, 9.64653015], [76.4034729, 9.64653015], [76.4034729, 9.64680958], [76.40319824, 9.64680481], [76.40319824, 9.64708328], [76.40291595, 9.64708328], [76.40291595, 9.6473608], [76.4026413, 9.64735889], [76.4026413, 9.64931011], [76.40291595, 9.6493063], [76.40291595, 9.6506958], [76.40319824, 9.6506958], [76.40319824, 9.6514616], [76.40319824, 9.65236187], [76.4034729, 9.65236187], [76.4034729, 9.65458393], [76.40374756, 9.65458202], [76.40374756, 9.65513992], [76.40402985, 9.65513802], [76.40402985, 9.65597153], [76.40429688, 9.65596962], [76.40429688, 9.65625], [76.40402985, 9.65625], [76.40402985, 9.65653038], [76.40429688, 9.65653038], [76.40429688, 9.65681076], [76.40402985, 9.65680599], [76.40402985, 9.65708447], [76.4043045, 9.65708447], [76.4043045, 9.65847206], [76.40458679, 9.65847015], [76.40458679, 9.66181087], [76.40486145, 9.6618042], [76.40486145, 9.66236019], [76.40513611, 9.66236019], [76.40513611, 9.66264057], [76.40486145, 9.66264057], [76.40486145, 9.66375065], [76.40458679, 9.66375065], [76.40458679, 9.66458321], [76.4054184, 9.66458321], [76.4054184, 9.66486073], [76.40651703, 9.66486073], [76.40651703, 9.66514111], [76.40735626, 9.66514111], [76.40735626, 9.66486073], [76.40763855, 9.66486073], [76.40763855, 9.66458321], [76.4081955, 9.66458321], [76.4081955, 9.66430473], [76.40847015, 9.66431141], [76.40847015, 9.66403103], [76.40875244, 9.66403103], [76.40875244, 9.66375065], [76.40930939, 9.66375065], [76.40930939, 9.66347027], [76.40958405, 9.66347313], [76.40958405, 9.66319466], [76.41014099, 9.66319466], [76.41014099, 9.66291714], [76.41041565, 9.66291714], [76.41041565, 9.66263866], [76.4109726, 9.66264057], [76.4109726, 9.66236019], [76.41124725, 9.66236019], [76.41124725, 9.66208458], [76.4118042, 9.66208458], [76.4118042, 9.6618042], [76.41208649, 9.66181087], [76.41208649, 9.66153145], [76.4126358, 9.66153145], [76.4126358, 9.66125107], [76.41291809, 9.66125107], [76.41291809, 9.66096973], [76.41347504, 9.66097164], [76.41347504, 9.66069412], [76.41374969, 9.66069412], [76.41374969, 9.66041565], [76.41430664, 9.66042137], [76.41430664, 9.66014099], [76.4145813, 9.66014099], [76.4145813, 9.65985107], [76.41513824, 9.65985966], [76.41513824, 9.65958214], [76.4154129, 9.65958214], [76.4154129, 9.65930557], [76.41570282, 9.65931129], [76.41570282, 9.65874958], [76.41596985, 9.65874958], [76.41596985, 9.65847015], [76.41652679, 9.65847206], [76.41652679, 9.65819359], [76.41708374, 9.65819359], [76.41708374, 9.65847206], [76.41764069, 9.65847206], [76.41764069, 9.65819359], [76.41902924, 9.65819359], [76.41902924, 9.65847206], [76.41874695, 9.65847015], [76.41874695, 9.65874958], [76.41819763, 9.65874958], [76.41819763, 9.65903091], [76.41792297, 9.65903091], [76.41792297, 9.65931129], [76.4173584, 9.65930557], [76.4173584, 9.65958214], [76.41708374, 9.65958214], [76.41708374, 9.65986347], [76.41625214, 9.65985107], [76.41625214, 9.66014099], [76.41570282, 9.66014099], [76.41570282, 9.66042137], [76.41513824, 9.66041565], [76.41513824, 9.66069412], [76.41486359, 9.66069412], [76.41486359, 9.66097164], [76.4145813, 9.66096973], [76.4145813, 9.66125107], [76.41430664, 9.66125107], [76.41430664, 9.66153145], [76.41401672, 9.66153145], [76.41401672, 9.66181087], [76.41374969, 9.6618042], [76.41374969, 9.66208458], [76.41347504, 9.66208458], [76.41347504, 9.66236019], [76.41319275, 9.66236019], [76.41319275, 9.66291714], [76.41291809, 9.66291714], [76.41291809, 9.66319466], [76.41236115, 9.66319466], [76.41236115, 9.66347313], [76.41208649, 9.66347027], [76.41208649, 9.66375065], [76.41152954, 9.66375065], [76.41152954, 9.66403103], [76.4109726, 9.66403103], [76.4109726, 9.66431141], [76.41069794, 9.66430473], [76.41069794, 9.66458321], [76.41014099, 9.66458321], [76.41014099, 9.66486073], [76.4098587, 9.66486073], [76.4098587, 9.66514111], [76.40930939, 9.66514111], [76.40930939, 9.66542053], [76.4090271, 9.66541672], [76.4090271, 9.66569519], [76.40847015, 9.66569042], [76.40847015, 9.66598034], [76.4081955, 9.66597271], [76.4081955, 9.66625118], [76.40791321, 9.66625118], [76.40791321, 9.66653061], [76.40402985, 9.66653061], [76.40402985, 9.66681194], [76.4043045, 9.66680527], [76.4043045, 9.66736126], [76.40458679, 9.66736126], [76.40458679, 9.66819477], [76.40486145, 9.66819477], [76.40486145, 9.66958332], [76.40513611, 9.66958141], [76.40513611, 9.67153168], [76.40486145, 9.67153168], [76.40486145, 9.67263889], [76.40513611, 9.67263889], [76.40513611, 9.67292023], [76.40597534, 9.67291737], [76.40597534, 9.67319489], [76.40652466, 9.67319489], [76.40652466, 9.67347431], [76.40680695, 9.67347145], [76.40680695, 9.67375183], [76.4070816, 9.67375183], [76.4070816, 9.67430973], [76.40735626, 9.67430973], [76.40735626, 9.67514038], [76.40791321, 9.67514038], [76.40791321, 9.67597103], [76.40820313, 9.67597103], [76.40820313, 9.67625046], [76.40847015, 9.67625046], [76.40847015, 9.67653179], [76.40875244, 9.67652798], [76.40875244, 9.67736244], [76.4090271, 9.67735863], [76.4090271, 9.67763996], [76.40930176, 9.67763996], [76.40930939, 9.67847157], [76.40957642, 9.67847157], [76.40957642, 9.67875195], [76.4098587, 9.67875195], [76.4098587, 9.67903042], [76.41014099, 9.67903042], [76.41014099, 9.67930984], [76.41042328, 9.67930984], [76.41042328, 9.68013954], [76.41069794, 9.68013954], [76.41069794, 9.68041992], [76.4109726, 9.68041992], [76.4109726, 9.68098068], [76.41152954, 9.68098068], [76.41152954, 9.68153], [76.41179657, 9.68153], [76.41179657, 9.68181133], [76.41208649, 9.68180561], [76.41208649, 9.68208408], [76.41236115, 9.68208408], [76.41236115, 9.6823597], [76.4126358, 9.6823597], [76.4126358, 9.68292141], [76.41291809, 9.68291569], [76.41291809, 9.68375015], [76.41319275, 9.68375015], [76.41319275, 9.68486023], [76.41347504, 9.68486023], [76.41347504, 9.68569374], [76.41374969, 9.68569183], [76.41374969, 9.68681145], [76.41401672, 9.68681145], [76.41401672, 9.68792057], [76.41430664, 9.68792057], [76.41430664, 9.68903065], [76.4145813, 9.68903065], [76.4145813, 9.69015026], [76.41486359, 9.69013882], [76.41486359, 9.69208336], [76.4145813, 9.69207954], [76.4145813, 9.69430923], [76.41430664, 9.69430923], [76.41430664, 9.69541931], [76.41401672, 9.69541931], [76.41401672, 9.69625092], [76.41374969, 9.69625092], [76.41374969, 9.69680977], [76.41319275, 9.696805], [76.41319275, 9.69736099], [76.4126358, 9.69736099], [76.4126358, 9.69764137], [76.41179657, 9.69764137], [76.41179657, 9.69791985], [76.41069794, 9.69791698], [76.41069794, 9.69819546], [76.4098587, 9.69819546], [76.4098587, 9.69847107], [76.40957642, 9.69847107], [76.40958405, 9.69874859], [76.40930939, 9.69875145], [76.40930176, 9.69902706], [76.40875244, 9.69902039], [76.40875244, 9.6993103], [76.40847015, 9.69930458], [76.40847015, 9.69958305], [76.40791321, 9.69958305], [76.40791321, 9.69986057], [76.40652466, 9.69986057], [76.40652466, 9.69958305], [76.40597534, 9.69958305], [76.40597534, 9.69902706], [76.40569305, 9.69902706], [76.40569305, 9.69875145], [76.4054184, 9.69875145], [76.4054184, 9.69847107], [76.40513611, 9.69847107], [76.40513611, 9.69819546], [76.4043045, 9.69819546], [76.4043045, 9.69791698], [76.40402985, 9.69791985], [76.40402985, 9.69764137], [76.40374756, 9.69764137], [76.40374756, 9.69708061], [76.40319824, 9.69708347], [76.40319061, 9.69652653], [76.4026413, 9.69652939], [76.4026413, 9.69625092], [76.4006958, 9.69625092], [76.4006958, 9.69652939], [76.40040588, 9.69652939], [76.40040588, 9.69680977], [76.40013885, 9.696805], [76.40013885, 9.69708347], [76.39958191, 9.69708347], [76.39958191, 9.69736099], [76.39930725, 9.69736099], [76.39930725, 9.69764137], [76.39875031, 9.69763947], [76.39875031, 9.69874859], [76.39847565, 9.69875145], [76.39847565, 9.69986057], [76.39819336, 9.69986057], [76.39819336, 9.70042038], [76.3970871, 9.70041656], [76.3970871, 9.70069313], [76.39680481, 9.70069313], [76.39680481, 9.70097446], [76.39653015, 9.70097065], [76.39653015, 9.70125198], [76.39624786, 9.70125198], [76.39624786, 9.70181179], [76.39485931, 9.70181179], [76.39485931, 9.70153046], [76.39375305, 9.70153046], [76.39375305, 9.70125198], [76.39290619, 9.70125198], [76.39290619, 9.70097065], [76.3923645, 9.70097446], [76.3923645, 9.70069313], [76.38735962, 9.70069313], [76.38735962, 9.70097446], [76.38540649, 9.70097065], [76.38540649, 9.70125198], [76.38458252, 9.70125198], [76.38458252, 9.70153046], [76.3840332, 9.70153046], [76.3840332, 9.70209026], [76.38346863, 9.70208359], [76.38346863, 9.70236206], [76.38318634, 9.7023592], [76.38318634, 9.70263958], [76.38291931, 9.70263958], [76.38291931, 9.70347214], [76.38263702, 9.70346928], [76.38263702, 9.70374966], [76.38291931, 9.70374966], [76.38291931, 9.70403004], [76.38263702, 9.70402813], [76.38263702, 9.70458412], [76.38291931, 9.70458412], [76.38291931, 9.70486164], [76.38318634, 9.70486164], [76.38318634, 9.70541954], [76.38346863, 9.70541573], [76.38346863, 9.70597172], [76.38375092, 9.70596886], [76.38375092, 9.70681], [76.3840332, 9.70681], [76.3840332, 9.70792007], [76.38430786, 9.70792007], [76.38430786, 9.70903015], [76.38458252, 9.70902824], [76.38458252, 9.70985985], [76.38486481, 9.70985985], [76.38486481, 9.71097183], [76.38513947, 9.71096134], [76.38513947, 9.71181107], [76.38541412, 9.7118063], [76.38541412, 9.71236229], [76.38569641, 9.71236229], [76.38569641, 9.71319389], [76.38597107, 9.71319199], [76.38597107, 9.71375275], [76.38625336, 9.71375275], [76.38625336, 9.71431065], [76.38652802, 9.71430683], [76.38652802, 9.71458244], [76.38707733, 9.71457958], [76.38707733, 9.71485996], [76.38735962, 9.71485996], [76.38735962, 9.71569538], [76.38764191, 9.71568966], [76.38764191, 9.71681118], [76.38791656, 9.71681118], [76.38791656, 9.71792126], [76.38819885, 9.71792126], [76.38819885, 9.71903133], [76.38846588, 9.71903133], [76.38846588, 9.72042084], [76.38874817, 9.72041702], [76.38874817, 9.72236061], [76.38903046, 9.72236061], [76.38903046, 9.7240324], [76.38874817, 9.72402668], [76.38874817, 9.72569466], [76.38847351, 9.72569466], [76.38847351, 9.72708321], [76.38874817, 9.7270813], [76.38874817, 9.72791958], [76.38903046, 9.72791767], [76.38903046, 9.72874928], [76.38930511, 9.72874928], [76.38930511, 9.72986221], [76.38957977, 9.72986221], [76.38957977, 9.73486233], [76.38986206, 9.73486042], [76.38986206, 9.73624992], [76.39013672, 9.73624992], [76.39013672, 9.73764038], [76.39041901, 9.73764038], [76.39041901, 9.73931122], [76.39069366, 9.73930645], [76.39069366, 9.74097157], [76.39097595, 9.74097157], [76.39097595, 9.74208546], [76.39068604, 9.74207973], [76.39068604, 9.74264145], [76.39041901, 9.74263763], [76.39041901, 9.74319458], [76.38986206, 9.74319458], [76.38986206, 9.74569511], [76.39013672, 9.74569511], [76.39013672, 9.74597263], [76.38986206, 9.74597263], [76.38986206, 9.74625111], [76.39013672, 9.74625111], [76.39013672, 9.74681187], [76.38986206, 9.74681187], [76.38986206, 9.74764061], [76.38957977, 9.74764061], [76.38957977, 9.74792194], [76.38930511, 9.74791718], [76.38930511, 9.74819469], [76.38903046, 9.74819469], [76.38903046, 9.75097084], [76.38874817, 9.75097084], [76.38874817, 9.75181198], [76.38846588, 9.75181198], [76.38846588, 9.75292015], [76.38819885, 9.75292015], [76.38819885, 9.75319958], [76.38847351, 9.75319481], [76.38847351, 9.75374889], [76.38819885, 9.75374889], [76.38819885, 9.75541973], [76.38791656, 9.75541782], [76.38791656, 9.75597095], [76.38764191, 9.75597095], [76.38764191, 9.75652981], [76.38735962, 9.75652981], [76.38735962, 9.75681019], [76.38708496, 9.75680637], [76.38708496, 9.75736237], [76.38680267, 9.75736237], [76.38680267, 9.75847244], [76.38652802, 9.75847244], [76.38652802, 9.75875187], [76.38625336, 9.75874996], [76.38625336, 9.75930595], [76.38569641, 9.75930595], [76.38569641, 9.75986195], [76.38540649, 9.75986195], [76.38540649, 9.76014042], [76.38485718, 9.76014042], [76.38485718, 9.76041985], [76.38458252, 9.76041794], [76.38458252, 9.76069355], [76.38430786, 9.76069355], [76.38430786, 9.76097202], [76.38375092, 9.76097202], [76.38375092, 9.76124954], [76.38346863, 9.76124954], [76.38346863, 9.76152992], [76.38291931, 9.76152992], [76.38291931, 9.76181126], [76.38236237, 9.76180553], [76.38236237, 9.76208401], [76.38180542, 9.76208401], [76.38180542, 9.76236153], [76.38153076, 9.76235962], [76.38153076, 9.76264], [76.38124847, 9.76264], [76.38124847, 9.76319408], [76.38097382, 9.76319408], [76.38097382, 9.7634716], [76.38069153, 9.7634697], [76.38069153, 9.76375008], [76.38041687, 9.76375008], [76.38041687, 9.76403046], [76.38014221, 9.7640276], [76.38014221, 9.76458359], [76.37958527, 9.76458359], [76.37958527, 9.76486015], [76.37930298, 9.76486015], [76.37930298, 9.76513958], [76.37902832, 9.76513958], [76.37902832, 9.76543045], [76.37819672, 9.76541615], [76.37819672, 9.76569366], [76.3779068, 9.76568985], [76.3779068, 9.76820087], [76.37763977, 9.7681942], [76.37763977, 9.76875114], [76.37708282, 9.76875114], [76.37708282, 9.76903057], [76.37735748, 9.76903057], [76.37735748, 9.76931095], [76.37708282, 9.76930428], [76.37708282, 9.76958466], [76.37652588, 9.76958466], [76.37652588, 9.76986027], [76.37625885, 9.76986027], [76.37625885, 9.77014065], [76.37596893, 9.77014065], [76.37596893, 9.77042103], [76.37541962, 9.77041721], [76.37541962, 9.77069473], [76.37513733, 9.77069473], [76.37513733, 9.77097321], [76.37458038, 9.77097321], [76.37458038, 9.77125072], [76.37403107, 9.77123928], [76.37403107, 9.77181053], [76.37374878, 9.77180672], [76.37374878, 9.7723608], [76.37346649, 9.7723608], [76.37346649, 9.77264118], [76.37319183, 9.77263927], [76.37319183, 9.77375126], [76.37347412, 9.77375126], [76.37347412, 9.77430534], [76.37374878, 9.77430534], [76.37374878, 9.77513885], [76.37403107, 9.77513885], [76.37403107, 9.77569485], [76.37374878, 9.77569485], [76.37374878, 9.77597332], [76.37403107, 9.77597141], [76.37403107, 9.77652931], [76.37431335, 9.77652931], [76.37431335, 9.7776413], [76.37403107, 9.77763939], [76.37403107, 9.77847099], [76.37346649, 9.77847099], [76.37347412, 9.77875137], [76.37291718, 9.77875137], [76.37291718, 9.77902889], [76.3720932, 9.77902889], [76.3720932, 9.77931023], [76.37152863, 9.77930546], [76.37152863, 9.77958298], [76.37124634, 9.77958107], [76.37124634, 9.78014183], [76.37097168, 9.78013897], [76.37097168, 9.78097439], [76.37124634, 9.78097057], [76.37124634, 9.78180981], [76.37180328, 9.78180981], [76.37180328, 9.78374958], [76.37152863, 9.78374958], [76.37152863, 9.78402996], [76.37124634, 9.78402805], [76.37124634, 9.78458405], [76.37097168, 9.78458405], [76.37097168, 9.78486156], [76.37069702, 9.78486156], [76.37069702, 9.78514194], [76.36985779, 9.78514004], [76.36985779, 9.78569412], [76.36958313, 9.78569412], [76.36958313, 9.78597164], [76.36930847, 9.78597164], [76.36930847, 9.78652954], [76.36902618, 9.78652763], [76.36902618, 9.7873621], [76.36875153, 9.7873621], [76.36875153, 9.7881937], [76.36846924, 9.7881918], [76.36846924, 9.78903008], [76.36818695, 9.78903008], [76.36818695, 9.79014015], [76.36791992, 9.79014015], [76.36791992, 9.79097176], [76.36846924, 9.79097176], [76.36846924, 9.79125023], [76.36875153, 9.79125023], [76.36875153, 9.79181099], [76.36902618, 9.79181099], [76.36902618, 9.79263973], [76.36930847, 9.79263783], [76.36930847, 9.79319382], [76.36902618, 9.79319191], [76.36902618, 9.79431057], [76.36930847, 9.7943058], [76.36930847, 9.79458237], [76.36958313, 9.79458046], [76.36958313, 9.79486275], [76.37013245, 9.79486275], [76.37013245, 9.79514122], [76.37069702, 9.79513836], [76.37069702, 9.79541588], [76.37097168, 9.79541588], [76.37097168, 9.79569435], [76.37152863, 9.79569435], [76.37152863, 9.7962513], [76.37180328, 9.7962513], [76.37180328, 9.7968111], [76.37208557, 9.79680443], [76.37208557, 9.79708195], [76.37264252, 9.79708195], [76.37264252, 9.79736137], [76.37291718, 9.79736137], [76.37291718, 9.7976408], [76.37346649, 9.7976408], [76.37346649, 9.79792118], [76.37374878, 9.79791737], [76.37374878, 9.79819489], [76.37403107, 9.79819489], [76.37403107, 9.79847336], [76.37458038, 9.79847336], [76.37458038, 9.79819489], [76.37486267, 9.79819489], [76.37486267, 9.79736137], [76.37513733, 9.79736137], [76.37513733, 9.79652882], [76.37486267, 9.79653072], [76.37486267, 9.7962513], [76.37458038, 9.7962513], [76.37458038, 9.79597282], [76.37430573, 9.79597282], [76.37430573, 9.79569435], [76.37403107, 9.79569435], [76.37403107, 9.79541588], [76.37430573, 9.79541588], [76.37430573, 9.79485989], [76.37403107, 9.79486275], [76.37403107, 9.79403114], [76.37431335, 9.79403114], [76.37431335, 9.79375267], [76.37541962, 9.79375267], [76.37541962, 9.79403114], [76.37568665, 9.79403114], [76.37568665, 9.79431057], [76.37680817, 9.7943058], [76.37680817, 9.79458237], [76.37652588, 9.79458046], [76.37652588, 9.79514122], [76.37625122, 9.79513836], [76.37625122, 9.79569435], [76.37596893, 9.79569435], [76.37596893, 9.79597282], [76.37625122, 9.79597282], [76.37625122, 9.7962513], [76.37652588, 9.7962513], [76.37652588, 9.79653072], [76.37680817, 9.79653072], [76.37680817, 9.7968111], [76.37708282, 9.79680443], [76.37708282, 9.79708195], [76.37735748, 9.79708195], [76.37735748, 9.79736137], [76.37763977, 9.79736137], [76.37763977, 9.79819489], [76.3779068, 9.79818058], [76.3779068, 9.79903126], [76.37819672, 9.79903126], [76.37819672, 9.79931068], [76.37847137, 9.79930687], [76.37847137, 9.79986095], [76.37875366, 9.79986095], [76.37875366, 9.80069542], [76.37902832, 9.8006897], [76.37902832, 9.80180931], [76.37930298, 9.80180454], [76.37930298, 9.80208302], [76.3795929, 9.80208111], [76.3795929, 9.80264091], [76.37985992, 9.80263901], [76.37985992, 9.80347347], [76.38014221, 9.80347347], [76.38014221, 9.8045826], [76.38041687, 9.8045826], [76.38041687, 9.80486107], [76.38124847, 9.80486107], [76.38124847, 9.80514145], [76.38153076, 9.80514145], [76.38153076, 9.80542183], [76.38236237, 9.80541706], [76.38236237, 9.80569458], [76.38263702, 9.80569458], [76.38263702, 9.80597115], [76.38291931, 9.80597115], [76.38291931, 9.80625057], [76.38318634, 9.80625057], [76.38318634, 9.80653191], [76.38346863, 9.80652714], [76.38346863, 9.80708313], [76.38375092, 9.80708313], [76.38375092, 9.80736065], [76.3840332, 9.80735016], [76.3840332, 9.80792046], [76.38458252, 9.80791664], [76.38458252, 9.80819321], [76.38485718, 9.8081913], [76.38485718, 9.8087492], [76.38513947, 9.8087492], [76.38513947, 9.80930996], [76.38541412, 9.80930519], [76.38541412, 9.80958366], [76.38569641, 9.8095789], [76.38569641, 9.81013966], [76.38625336, 9.81013966], [76.38625336, 9.81069565], [76.38652802, 9.81069565], [76.38652802, 9.81097221], [76.38680267, 9.81096935], [76.38680267, 9.81153202], [76.38708496, 9.81152821], [76.38708496, 9.8120842], [76.38735962, 9.8120842], [76.38735962, 9.81236172], [76.38764191, 9.81235981], [76.38764191, 9.81291962], [76.38791656, 9.81291771], [76.38791656, 9.81375027], [76.38819885, 9.81375027], [76.38819885, 9.81402969], [76.38846588, 9.81402969], [76.38846588, 9.81431007], [76.38874817, 9.81430626], [76.38874817, 9.81458378], [76.38903046, 9.81458378], [76.38903046, 9.81486225], [76.38931274, 9.81486034], [76.38931274, 9.81542015], [76.38957977, 9.81541634], [76.38957977, 9.81569386], [76.38986206, 9.81569386], [76.38986206, 9.81624985], [76.39013672, 9.81624985], [76.39013672, 9.81681061], [76.39041901, 9.81680584], [76.39041901, 9.81986237], [76.39013672, 9.81986046], [76.39013672, 9.82014275], [76.38986206, 9.82014275], [76.38986206, 9.82042122], [76.38903046, 9.82042122], [76.38903046, 9.82014275], [76.38764191, 9.82014275], [76.38764191, 9.81986046], [76.38680267, 9.81986237], [76.38680267, 9.81958199], [76.38569641, 9.81958199], [76.38569641, 9.81930637], [76.38346863, 9.81930637], [76.38346863, 9.81958199], [76.38318634, 9.81958199], [76.38318634, 9.82014275], [76.38291931, 9.82013798], [76.38291931, 9.82097244], [76.38263702, 9.82097244], [76.38263702, 9.82208538], [76.38236237, 9.82207966], [76.38239288, 9.82431126], [76.38263702, 9.82430363], [76.38263702, 9.82597256], [76.38236237, 9.82597065], [76.38236237, 9.82653141], [76.38124847, 9.82653141], [76.38124847, 9.82681179], [76.38153076, 9.82680511], [76.38153076, 9.82708263], [76.38180542, 9.82708263], [76.38180542, 9.82736111], [76.38291931, 9.82736111], [76.38291931, 9.82708263], [76.38402557, 9.82708263], [76.38402557, 9.82680511], [76.38430786, 9.82681179], [76.38430786, 9.82653141], [76.38485718, 9.82653141], [76.38485718, 9.82625103], [76.38513947, 9.82625103], [76.38513947, 9.82597065], [76.38569641, 9.82597256], [76.38569641, 9.82569504], [76.38597107, 9.82569504], [76.38597107, 9.82541656], [76.38652802, 9.82542133], [76.38652802, 9.82514095], [76.38680267, 9.82514095], [76.38680267, 9.82486057], [76.38708496, 9.82486057], [76.38708496, 9.82458305], [76.38764191, 9.82458305], [76.38764191, 9.82430363], [76.38791656, 9.82431126], [76.38791656, 9.82403088], [76.38846588, 9.82403088], [76.38846588, 9.82375145], [76.38874817, 9.82375145], [76.38874817, 9.82347012], [76.38903046, 9.82347298], [76.38903046, 9.82319546], [76.38957977, 9.82319546], [76.38957977, 9.82291603], [76.38986206, 9.82291889], [76.38986206, 9.82264137], [76.39041901, 9.82264137], [76.39041901, 9.82235146], [76.39069366, 9.82236004], [76.39069366, 9.82208538], [76.39125061, 9.82208538], [76.39125061, 9.82180691], [76.3915329, 9.82181072], [76.3915329, 9.82118225], [76.39180756, 9.82124996], [76.39180756, 9.82097244], [76.39208221, 9.82097244], [76.39208221, 9.82041645], [76.39235687, 9.82042122], [76.39235687, 9.82014275], [76.39263916, 9.82014275], [76.39263916, 9.81958199], [76.39291382, 9.81958199], [76.39291382, 9.81930637], [76.39319611, 9.81931114], [76.39319611, 9.81903267], [76.39347076, 9.81903267], [76.39347076, 9.81875038], [76.39375305, 9.81875038], [76.39375305, 9.81847191], [76.39402771, 9.81847191], [76.39402771, 9.81819439], [76.39430237, 9.81819439], [76.39430237, 9.81791592], [76.3951416, 9.81791592], [76.3951416, 9.81819439], [76.39485931, 9.81819439], [76.39485931, 9.81875038], [76.39457703, 9.81875038], [76.39457703, 9.81903267], [76.39430237, 9.8190279], [76.39430237, 9.81958199], [76.39402771, 9.81958199], [76.39402771, 9.81986237], [76.39375305, 9.81986046], [76.39375305, 9.82042122], [76.39347076, 9.82041645], [76.39347076, 9.82069397], [76.39319611, 9.82069397], [76.39319611, 9.82111073], [76.39319611, 9.82124996], [76.39290619, 9.82124996], [76.39290619, 9.8215313], [76.39263916, 9.82152843], [76.39263916, 9.82208538], [76.3923645, 9.82208538], [76.3923645, 9.82236004], [76.39208221, 9.82235146], [76.39208221, 9.82291889], [76.39180756, 9.82291603], [76.39180756, 9.82319546], [76.3915329, 9.82318974], [76.3915329, 9.82375145], [76.39124298, 9.82375145], [76.39124298, 9.82403088], [76.39097595, 9.82403088], [76.39097595, 9.82431126], [76.39041901, 9.82430363], [76.39041901, 9.82458305], [76.39013672, 9.82458305], [76.39013672, 9.82486057], [76.38986206, 9.82486057], [76.38986206, 9.82514095], [76.38957977, 9.82514095], [76.38957977, 9.82542133], [76.38903046, 9.82541656], [76.38903046, 9.82569504], [76.38819122, 9.82569504], [76.38819122, 9.82597256], [76.38764191, 9.82597065], [76.38764191, 9.82625103], [76.38707733, 9.82625103], [76.38707733, 9.82653141], [76.38625336, 9.82653141], [76.38625336, 9.82681179], [76.38569641, 9.82680511], [76.38569641, 9.82708263], [76.38486481, 9.82708263], [76.38486481, 9.82736111], [76.38458252, 9.82736111], [76.38458252, 9.82764053], [76.38430786, 9.82764053], [76.38430786, 9.82792091], [76.38375092, 9.8279171], [76.38375092, 9.82819462], [76.38346863, 9.82818985], [76.38346863, 9.82847977], [76.38318634, 9.82847977], [76.38318634, 9.82903099], [76.38291931, 9.82902908], [76.38291931, 9.82958317], [76.38318634, 9.82958126], [76.38318634, 9.82986069], [76.38346863, 9.82986069], [76.38346863, 9.8318119], [76.38291931, 9.83180523], [76.38291931, 9.83236122], [76.38263702, 9.83236122], [76.38263702, 9.83375072], [76.38236237, 9.83375072], [76.38236237, 9.83403015], [76.38318634, 9.83403015], [76.38318634, 9.83375072], [76.38707733, 9.83375072], [76.38707733, 9.83513927], [76.38735962, 9.83513927], [76.38735962, 9.83597088], [76.38708496, 9.83597088], [76.38708496, 9.83708382], [76.38680267, 9.83708382], [76.38680267, 9.8381958], [76.38652802, 9.83819103], [76.38652802, 9.83875179], [76.38625336, 9.83874989], [76.38625336, 9.84069443], [76.38569641, 9.84069443], [76.38569641, 9.84097195], [76.38540649, 9.84097195], [76.38540649, 9.84125042], [76.38485718, 9.84125042], [76.38485718, 9.84152985], [76.38458252, 9.84152985], [76.38458252, 9.84181023], [76.38318634, 9.84181023], [76.38318634, 9.84152985], [76.38263702, 9.84152985], [76.38263702, 9.84125042], [76.38180542, 9.84125042], [76.38180542, 9.84097195], [76.38124847, 9.84097195], [76.38124847, 9.84069443], [76.38041687, 9.84069443], [76.38041687, 9.84041786], [76.37985992, 9.84041786], [76.37985992, 9.84125042], [76.38014221, 9.84125042], [76.38014221, 9.84181023], [76.38097382, 9.84180641], [76.38097382, 9.84208393], [76.38153076, 9.84208393], [76.38153076, 9.8423624], [76.38181305, 9.84235954], [76.38181305, 9.84263992], [76.38236237, 9.84263992], [76.38236237, 9.8429203], [76.38319397, 9.84291553], [76.38319397, 9.84319401], [76.38375092, 9.84318924], [76.38375092, 9.84348106], [76.3840332, 9.84348106], [76.3840332, 9.84375], [76.38458252, 9.84375], [76.38458252, 9.84431076], [76.38181305, 9.84431076], [76.38181305, 9.84403038], [76.38096619, 9.84403038], [76.38096619, 9.84375], [76.37985992, 9.84375], [76.37985992, 9.84403038], [76.3795929, 9.84403038], [76.3795929, 9.84431076], [76.37930298, 9.84430599], [76.37930298, 9.84458447], [76.37902832, 9.84458447], [76.37902832, 9.84486008], [76.37847137, 9.84486008], [76.37847137, 9.84514046], [76.37819672, 9.84514046], [76.37819672, 9.84542274], [76.37791443, 9.84541607], [76.37791443, 9.84569359], [76.37763977, 9.84569359], [76.37763977, 9.84597206], [76.37680817, 9.84597206], [76.37680817, 9.84569359], [76.37708282, 9.84569359], [76.37708282, 9.8451376], [76.37735748, 9.84514046], [76.37735748, 9.8445797], [76.37763977, 9.84458447], [76.37763977, 9.84402847], [76.3779068, 9.84403038], [76.3779068, 9.84348106], [76.37763977, 9.84348106], [76.37763977, 9.84318924], [76.37708282, 9.84319401], [76.37708282, 9.84291553], [76.37652588, 9.8429203], [76.37652588, 9.84263992], [76.37374878, 9.84263992], [76.37374878, 9.84235954], [76.37291718, 9.8423624], [76.37291718, 9.84208393], [76.37208557, 9.84208393], [76.37208557, 9.8423624], [76.37152863, 9.84235954], [76.37152863, 9.84431076], [76.37180328, 9.84430599], [76.37180328, 9.84486008], [76.37152863, 9.84486008], [76.37152863, 9.84764099], [76.37124634, 9.84764099], [76.37124634, 9.84792137], [76.37152863, 9.84791565], [76.37152863, 9.84819412], [76.37124634, 9.84819412], [76.37124634, 9.84847164], [76.37152863, 9.84846973], [76.37152863, 9.84903145], [76.37180328, 9.84903145], [76.37180328, 9.84931087], [76.37236023, 9.8493042], [76.37236023, 9.84958458], [76.37430573, 9.84958458], [76.37430573, 9.8493042], [76.37458038, 9.8493042], [76.37458038, 9.84958458], [76.37513733, 9.84958458], [76.37513733, 9.84986019], [76.37568665, 9.84986019], [76.37568665, 9.85014057], [76.37596893, 9.85014057], [76.37596893, 9.85042095], [76.37625122, 9.85041714], [76.37625122, 9.85069466], [76.37680817, 9.85069466], [76.37680817, 9.85097313], [76.37708282, 9.85097027], [76.37708282, 9.85125065], [76.37735748, 9.85125065], [76.37735748, 9.85153103], [76.37763977, 9.85153103], [76.37763977, 9.85181141], [76.37819672, 9.85180664], [76.37819672, 9.85208321], [76.37847137, 9.85208321], [76.37847137, 9.85236073], [76.37874603, 9.85236073], [76.37874603, 9.85264969], [76.37902832, 9.8526392], [76.37902832, 9.85319519], [76.37930298, 9.85319519], [76.37930298, 9.85347271], [76.37958527, 9.85347271], [76.37958527, 9.85486126], [76.37930298, 9.85486126], [76.37930298, 9.85652924], [76.37902832, 9.85652924], [76.37902832, 9.85931015], [76.37874603, 9.85931015], [76.37874603, 9.86042023], [76.37847137, 9.86042023], [76.37847137, 9.86125183], [76.37819672, 9.86124897], [76.37819672, 9.86236095], [76.3779068, 9.86236095], [76.3779068, 9.86291981], [76.37763977, 9.8629179], [76.37763977, 9.86374855], [76.37735748, 9.86374855], [76.37735748, 9.86486244], [76.37708282, 9.86486244], [76.37708282, 9.86514187], [76.37652588, 9.86514187], [76.37652588, 9.86542034], [76.37625122, 9.86541557], [76.37625122, 9.86569405], [76.37596893, 9.86569118], [76.37596893, 9.86625195], [76.37568665, 9.86625195], [76.37568665, 9.86653042], [76.37541962, 9.86652756], [76.37541962, 9.86708355], [76.37513733, 9.86708355], [76.37513733, 9.86736202], [76.37486267, 9.86736202], [76.37486267, 9.86765099], [76.37458038, 9.86765099], [76.37458038, 9.86791992], [76.37430573, 9.86791801], [76.37430573, 9.8684721], [76.37374878, 9.8684721], [76.37374878, 9.86958408], [76.37347412, 9.86958408], [76.37347412, 9.8698597], [76.37319946, 9.8698597], [76.37319946, 9.87014008], [76.37291718, 9.87014008], [76.37291718, 9.87069416], [76.37264252, 9.87068939], [76.37264252, 9.87181091], [76.37291718, 9.87180614], [76.37291718, 9.87208366], [76.37264252, 9.87207985], [76.37264252, 9.87263966], [76.37236023, 9.87263966], [76.37236023, 9.87514114], [76.37208557, 9.87513828], [76.37208557, 9.87625122], [76.37180328, 9.87625122], [76.37180328, 9.87681961], [76.37152863, 9.87680435], [76.37152863, 9.87736034], [76.37124634, 9.87736034], [76.37124634, 9.8779211], [76.37097168, 9.87791729], [76.37097168, 9.87819481], [76.37069702, 9.87819481], [76.37069702, 9.87847328], [76.3704071, 9.87847042], [76.3704071, 9.87903118], [76.37013245, 9.87903118], [76.37014008, 9.87986088], [76.36985779, 9.87986088], [76.36985779, 9.88014126], [76.36930847, 9.88013935], [76.36930847, 9.88069534], [76.36902618, 9.88069534], [76.36902618, 9.88097286], [76.36875153, 9.88097095], [76.36875153, 9.88152885], [76.36846924, 9.88152885], [76.36846924, 9.88236141], [76.36791992, 9.88236141], [76.36791992, 9.88291931], [76.36763763, 9.8829174], [76.36763763, 9.88319016], [76.36736298, 9.88319969], [76.36736298, 9.88375092], [76.36708069, 9.88374901], [76.36708069, 9.88458347], [76.36680603, 9.88458061], [76.36680603, 9.88541889], [76.36653137, 9.88541889], [76.36653137, 9.88624859], [76.36624908, 9.88625145], [76.36624908, 9.88708305], [76.3659668, 9.88708115], [76.3659668, 9.88792038], [76.36569214, 9.88792038], [76.36569214, 9.88876057], [76.36541748, 9.88874912], [76.36541748, 9.88986206], [76.36514282, 9.8898592], [76.36514282, 9.89153194], [76.36486053, 9.89152813], [76.36486053, 9.89208412], [76.36458588, 9.89208126], [76.36458588, 9.89264202], [76.36430359, 9.89264011], [76.36430359, 9.8931942], [76.36402893, 9.8931942], [76.36402893, 9.89347172], [76.36374664, 9.89347172], [76.36374664, 9.89375019], [76.36347198, 9.89375019], [76.36347198, 9.89402962], [76.36319733, 9.89402962], [76.36319733, 9.89431], [76.36291504, 9.89430618], [76.36291504, 9.89486217], [76.36264038, 9.89486027], [76.36264038, 9.89542007], [76.36235809, 9.89541626], [76.36235809, 9.89569378], [76.36207581, 9.89569187], [76.36207581, 9.89625168], [76.36180878, 9.89625168], [76.36180878, 9.89681053], [76.36152649, 9.89680576], [76.36152649, 9.89735985], [76.36125946, 9.89735985], [76.36125946, 9.89792061], [76.36096954, 9.89791584], [76.36096954, 9.89875031], [76.36069489, 9.89875031], [76.36069489, 9.89958191], [76.36042023, 9.89958191], [76.36042023, 9.90014267], [76.36013794, 9.9001379], [76.36013794, 9.90097237], [76.35986328, 9.90097046], [76.35986328, 9.90181065], [76.35958099, 9.90180588], [76.35958099, 9.90235996], [76.35930634, 9.90235996], [76.35930634, 9.9026413], [76.35901642, 9.9026413], [76.35901642, 9.90292072], [76.35874939, 9.90291595], [76.35874939, 9.9034729], [76.3584671, 9.90347004], [76.3584671, 9.90376186], [76.35819244, 9.90376186], [76.35819244, 9.90431118], [76.35791779, 9.90430355], [76.35791779, 9.90486145], [76.35764313, 9.90486145], [76.35764313, 9.90542126], [76.35736084, 9.90541744], [76.35736084, 9.90597343], [76.35708618, 9.90596962], [76.35708618, 9.90653133], [76.35680389, 9.90652657], [76.35680389, 9.90708256], [76.35652924, 9.90708256], [76.35652924, 9.90736103], [76.35624695, 9.90736103], [76.35624695, 9.90792084], [76.35597229, 9.90791702], [76.35597229, 9.90819454], [76.35569763, 9.90819454], [76.35569763, 9.90847301], [76.35542297, 9.90847111], [76.35542297, 9.90903091], [76.35513306, 9.90903091], [76.35513306, 9.90930939], [76.3548584, 9.90930462], [76.3548584, 9.90958309], [76.35457611, 9.90957069], [76.35457611, 9.91014099], [76.35430908, 9.91014099], [76.35430908, 9.91041946], [76.35402679, 9.9104166], [76.35402679, 9.91069508], [76.35346985, 9.91069508], [76.35346985, 9.9109726], [76.35320282, 9.91097069], [76.35320282, 9.91125107], [76.35263824, 9.91125107], [76.35263824, 9.9115324], [76.35235596, 9.9115324], [76.35235596, 9.91181183], [76.35180664, 9.91180515], [76.35180664, 9.91208267], [76.35152435, 9.91208267], [76.35152435, 9.91236115], [76.34625244, 9.91236115], [76.34625244, 9.91180515], [76.34597015, 9.91181183], [76.34597015, 9.91125107], [76.34570312, 9.91125107], [76.34570312, 9.91069126], [76.34541321, 9.91069508], [76.34541321, 9.91013908], [76.34485626, 9.91014099], [76.34485626, 9.91041946], [76.34402466, 9.9104166], [76.34402466, 9.91069508], [76.34430695, 9.91069126], [76.34430695, 9.91181183], [76.3445816, 9.91180515], [76.3445816, 9.91236115], [76.34430695, 9.91236115], [76.34430695, 9.91375065], [76.34401703, 9.91375065], [76.34401703, 9.91403198], [76.34375, 9.91402721], [76.34375, 9.91486073], [76.34401703, 9.91486073], [76.34402466, 9.91624928], [76.34375, 9.91624928], [76.34375, 9.91652966], [76.34319305, 9.91652679], [76.34319305, 9.91708374], [76.3429184, 9.91708374], [76.3429184, 9.91736221], [76.34263611, 9.91735935], [76.34263611, 9.91763973], [76.3418045, 9.91763973], [76.3418045, 9.91819572], [76.34124756, 9.91819572], [76.34124756, 9.91847229], [76.3409729, 9.91847229], [76.3409729, 9.91874981], [76.34041595, 9.91874027], [76.34041595, 9.91903019], [76.3401413, 9.91902828], [76.3401413, 9.91958427], [76.33680725, 9.91958427], [76.33680725, 9.91624928], [76.33651733, 9.91624928], [76.33651733, 9.91596889], [76.33625031, 9.9159708], [76.33625031, 9.91569328], [76.33598328, 9.91569996], [76.33598328, 9.91541958], [76.33569336, 9.91541958], [76.33569336, 9.91569996], [76.3354187, 9.91569328], [76.3354187, 9.9159708], [76.33403015, 9.91597366], [76.33403015, 9.91624928], [76.3326416, 9.91624928], [76.3326416, 9.91597366], [76.33235931, 9.9159708], [76.33235931, 9.91569328], [76.33207703, 9.91569996], [76.33207703, 9.91541958], [76.33152771, 9.91541958], [76.33152771, 9.9151392], [76.33096313, 9.9151392], [76.33096313, 9.91486073], [76.33040619, 9.91486073], [76.33040619, 9.9145813], [76.33013153, 9.9145813], [76.32930756, 9.91458321], [76.32930756, 9.91486073], [76.32875061, 9.91486073], [76.32875061, 9.9151392], [76.32818604, 9.9151392], [76.32818604, 9.91541958], [76.32763672, 9.91541958], [76.32763672, 9.91569996], [76.32457733, 9.91569996], [76.32457733, 9.91541958], [76.32402802, 9.91541958], [76.32402802, 9.91486073], [76.32375336, 9.91486073], [76.32375336, 9.91430473], [76.32402802, 9.91431046], [76.32402802, 9.91375065], [76.32430267, 9.91375065], [76.32430267, 9.91347122], [76.32485962, 9.91347122], [76.32485962, 9.91375065], [76.32514954, 9.91375065], [76.32514954, 9.91403198], [76.32541656, 9.91402721], [76.32541656, 9.91458321], [76.32569122, 9.91458321], [76.32569122, 9.91486073], [76.32681274, 9.91486073], [76.32681274, 9.9151392], [76.32707977, 9.9151392], [76.32707977, 9.91486073], [76.32736206, 9.91486073], [76.32736206, 9.91458321], [76.32791901, 9.91458321], [76.32791901, 9.91430473], [76.32818604, 9.91431046], [76.32818604, 9.91375065], [76.32847595, 9.91375065], [76.32847595, 9.91347122], [76.32902527, 9.91347122], [76.32902527, 9.91319466], [76.33069611, 9.91319466], [76.33069611, 9.91347122], [76.33125305, 9.91347122], [76.33125305, 9.91375065], [76.33180237, 9.91375065], [76.33180237, 9.91403198], [76.3326416, 9.91403198], [76.3326416, 9.91347122], [76.33291626, 9.91347122], [76.33291626, 9.91319466], [76.33319092, 9.91319466], [76.33319092, 9.91291714], [76.33347321, 9.91292191], [76.33347321, 9.91236115], [76.33374786, 9.91236115], [76.33374786, 9.91069508], [76.33403015, 9.91069508], [76.33403015, 9.90930462], [76.33429718, 9.90930939], [76.33429718, 9.90818977], [76.3345871, 9.90819454], [76.3345871, 9.90680695], [76.33486176, 9.90680695], [76.33486176, 9.90625095], [76.33513641, 9.90625095], [76.33513641, 9.90542126], [76.3354187, 9.90542126], [76.3354187, 9.9049902], [76.3354187, 9.90458202], [76.33569336, 9.90458202], [76.33569336, 9.90402889], [76.33598328, 9.9040308], [76.33598328, 9.90347004], [76.33702087, 9.90347004], [76.34069061, 9.9034729], [76.34069824, 9.90319443], [76.3409729, 9.90319443], [76.3409729, 9.90291595], [76.34124756, 9.90292072], [76.34124756, 9.90224171], [76.34124756, 9.90180588], [76.34069824, 9.90181065], [76.34069061, 9.90153122], [76.34012604, 9.90153122], [76.34012604, 9.90125275], [76.33985901, 9.90125275], [76.33985901, 9.90070057], [76.33957672, 9.90070057], [76.33957672, 9.90042114], [76.33930206, 9.90042114], [76.33930206, 9.89958191], [76.33958435, 9.89958191], [76.33958435, 9.8993063], [76.34069061, 9.89931107], [76.34069824, 9.89902973], [76.3409729, 9.89902973], [76.3409729, 9.89846992], [76.34124756, 9.89847183], [76.34124756, 9.89791584], [76.3409729, 9.89792061], [76.3409729, 9.89625168], [76.34069824, 9.89625168], [76.34069061, 9.89513969], [76.34041595, 9.89513969], [76.34041595, 9.89375019], [76.34012604, 9.89375019], [76.34012604, 9.89208126], [76.34041595, 9.89208412], [76.34041595, 9.89041805], [76.34069061, 9.89041996], [76.34069824, 9.8898592], [76.34124756, 9.88986206], [76.34124756, 9.88958263], [76.34152985, 9.88958263], [76.34152985, 9.88930511], [76.34208679, 9.88931179], [76.34208679, 9.88903046], [76.34236145, 9.88903046], [76.34236145, 9.88876057], [76.34263611, 9.88876057], [76.34263611, 9.88819122], [76.3429184, 9.88819313], [76.3429184, 9.88763905], [76.34319305, 9.88764191], [76.34319305, 9.88514137], [76.34263611, 9.88514137], [76.34263611, 9.88486099], [76.34179688, 9.88486099], [76.34179688, 9.88458061], [76.3409729, 9.88458347], [76.3409729, 9.884305], [76.33985901, 9.884305], [76.33985901, 9.88458347], [76.33930206, 9.88458347], [76.33930206, 9.88486099], [76.33875275, 9.88486099], [76.33875275, 9.88514137], [76.33847046, 9.88514137], [76.33847046, 9.88541889], [76.3381958, 9.88541698], [76.3381958, 9.88597107], [76.33790588, 9.88597107], [76.33791351, 9.88624859], [76.33763885, 9.88625145], [76.33763885, 9.88653183], [76.3373642, 9.88652706], [76.3373642, 9.88708305], [76.33708191, 9.88708305], [76.33708191, 9.88736057], [76.33680725, 9.88736057], [76.33680725, 9.88792038], [76.33652496, 9.88791656], [76.33652496, 9.88847446], [76.33569336, 9.88847065], [76.33569336, 9.88876057], [76.33513641, 9.88876057], [76.33513641, 9.88903046], [76.33486176, 9.88903046], [76.33486176, 9.88931179], [76.3345871, 9.88930511], [76.3345871, 9.88986206], [76.33486176, 9.88986206], [76.33486176, 9.89002991], [76.33486938, 9.89013958], [76.33513641, 9.89013958], [76.33513641, 9.89041996], [76.33569336, 9.89041805], [76.33569336, 9.89069557], [76.33597565, 9.89069557], [76.33597565, 9.89097118], [76.33625031, 9.89096928], [76.33625031, 9.89264202], [76.33651733, 9.89264202], [76.33652496, 9.89375019], [76.33625031, 9.89375019], [76.33625031, 9.8945837], [76.33598328, 9.89457035], [76.33598328, 9.89542007], [76.33569336, 9.89541626], [76.33569336, 9.89597225], [76.3345871, 9.89597225], [76.3345871, 9.89569378], [76.33291626, 9.89569187], [76.33291626, 9.89625168], [76.3326416, 9.89625168], [76.3326416, 9.89681053], [76.33235931, 9.89680576], [76.33235931, 9.89735985], [76.33207703, 9.89735985], [76.33207703, 9.89792061], [76.33180237, 9.89791584], [76.33180237, 9.89847183], [76.33152771, 9.89846992], [76.33152771, 9.89902973], [76.33125305, 9.89902973], [76.33125305, 9.89931107], [76.33097076, 9.8993063], [76.33097076, 9.89986229], [76.33069611, 9.89986038], [76.33069611, 9.90070057], [76.33040619, 9.90070057], [76.33040619, 9.90153122], [76.33013916, 9.90153122], [76.33013916, 9.90181065], [76.3298645, 9.90180588], [76.3298645, 9.9020853], [76.32958221, 9.90207958], [76.32958221, 9.9026413], [76.32930756, 9.9026413], [76.32930756, 9.90292072], [76.32875061, 9.90292072], [76.32875061, 9.90207958], [76.32902527, 9.9020853], [76.32902527, 9.90124989], [76.32930756, 9.90125275], [76.32930756, 9.90070057], [76.32958221, 9.90070057], [76.32958221, 9.89986038], [76.3298645, 9.89986229], [76.3298645, 9.8993063], [76.33013916, 9.89931107], [76.33013916, 9.89875031], [76.33041382, 9.89875031], [76.33040619, 9.89818859], [76.33069611, 9.89819431], [76.33069611, 9.89764023], [76.33097076, 9.89764023], [76.33097076, 9.89708424], [76.33125305, 9.89708424], [76.33125305, 9.89652824], [76.33152771, 9.89653015], [76.33152771, 9.89597034], [76.33180237, 9.89597225], [76.33180237, 9.89569378], [76.33208466, 9.89569378], [76.33208466, 9.89541626], [76.3326416, 9.89542007], [76.3326416, 9.89486027], [76.33291626, 9.89486217], [76.33291626, 9.89464092], [76.33291626, 9.89430618], [76.33319092, 9.89431], [76.33319092, 9.89375019], [76.33347321, 9.89375019], [76.33347321, 9.89347172], [76.33319092, 9.89347172], [76.33319092, 9.89291573], [76.33291626, 9.89291954], [76.33291626, 9.89236164], [76.3326416, 9.89236164], [76.3326416, 9.89069557], [76.33291626, 9.89069557], [76.33291626, 9.88902664], [76.33319092, 9.88903046], [76.33319092, 9.88847065], [76.33347321, 9.88847446], [76.33347321, 9.88830853], [76.33347321, 9.88791656], [76.33374786, 9.88792038], [76.33374786, 9.88736057], [76.33403015, 9.88736057], [76.33403015, 9.88708305], [76.33430481, 9.88708305], [76.33430481, 9.88652706], [76.3345871, 9.88653183], [76.3345871, 9.88597107], [76.3354187, 9.88597107], [76.3354187, 9.88541698], [76.33569336, 9.88541889], [76.33569336, 9.88458061], [76.3354187, 9.88458347], [76.3354187, 9.88402653], [76.33513641, 9.88402939], [76.33513641, 9.88375092], [76.33429718, 9.88375092], [76.33429718, 9.88347054], [76.33403015, 9.8834734], [76.33403015, 9.88319492], [76.33347321, 9.88319492], [76.33347321, 9.8829174], [76.33328247, 9.8829174], [76.33291626, 9.88291931], [76.33291626, 9.88263035], [76.3326416, 9.88263035], [76.3326416, 9.88291931], [76.33235931, 9.88291931], [76.33235931, 9.88263035], [76.33180237, 9.88263893], [76.33180237, 9.88236141], [76.33152771, 9.88236141], [76.33152771, 9.88208294], [76.33069611, 9.88208294], [76.33069611, 9.88236141], [76.33013916, 9.88236141], [76.33013916, 9.88263893], [76.32958221, 9.88263035], [76.32958221, 9.88291931], [76.32930756, 9.8829174], [76.32930756, 9.88319016], [76.3290329, 9.88319969], [76.3290329, 9.88375092], [76.32847595, 9.88375092], [76.32847595, 9.88402939], [76.32818604, 9.88402939], [76.32818604, 9.88431168], [76.32791901, 9.884305], [76.32791901, 9.88486099], [76.32763672, 9.88486099], [76.32763672, 9.88541889], [76.32736206, 9.88541698], [76.32736206, 9.88597107], [76.32707977, 9.88597107], [76.32707977, 9.88624859], [76.32624817, 9.88625145], [76.32624817, 9.88653183], [76.32569122, 9.88653183], [76.32569122, 9.8868103], [76.32514191, 9.88680458], [76.32514191, 9.88708305], [76.32485962, 9.88708305], [76.32485962, 9.88736057], [76.32457733, 9.88736057], [76.32457733, 9.88764191], [76.32430267, 9.88764191], [76.32430267, 9.88792038], [76.32402802, 9.88791656], [76.32402802, 9.88819313], [76.32375336, 9.88819313], [76.32375336, 9.88847446], [76.32209015, 9.88847065], [76.32209015, 9.88876057], [76.3215332, 9.88876057], [76.3215332, 9.88903046], [76.31931305, 9.88903046], [76.31931305, 9.88876057], [76.31874847, 9.88876057], [76.31874847, 9.88931179], [76.31846619, 9.88931179], [76.31846619, 9.89013958], [76.31874847, 9.89013958], [76.31874847, 9.89069557], [76.31930542, 9.89069557], [76.31930542, 9.89097118], [76.31958008, 9.89096928], [76.31958008, 9.89124966], [76.32125092, 9.89124966], [76.32125092, 9.89182186], [76.32152557, 9.89180565], [76.32152557, 9.89236164], [76.32096863, 9.89236164], [76.32096863, 9.89264202], [76.32041931, 9.89264202], [76.32041931, 9.89291954], [76.31958008, 9.89291573], [76.31958008, 9.8931942], [76.31791687, 9.8931942], [76.31791687, 9.89347172], [76.31764221, 9.89346886], [76.31764221, 9.89402962], [76.31735992, 9.89402962], [76.31735992, 9.89431], [76.31708527, 9.89430618], [76.31708527, 9.89569378], [76.31680298, 9.89569378], [76.31680298, 9.89708424], [76.31735992, 9.89708424], [76.31735992, 9.89735985], [76.31764221, 9.89735985], [76.31764221, 9.89764023], [76.31791687, 9.89764023], [76.31791687, 9.89819431], [76.31819153, 9.89819431], [76.31819153, 9.89847183], [76.31846619, 9.89846992], [76.31846619, 9.89875031], [76.31874847, 9.89875031], [76.31874847, 9.89986229], [76.31846619, 9.89986038], [76.31846619, 9.90042114], [76.31819153, 9.90041637], [76.31819153, 9.9020853], [76.31791687, 9.90207958], [76.31791687, 9.90292072], [76.31764221, 9.90291595], [76.31764221, 9.9034729], [76.31735992, 9.90347004], [76.31735992, 9.90376186], [76.3170929, 9.90376186], [76.3170929, 9.90431118], [76.31680298, 9.90430355], [76.31680298, 9.90458202], [76.31652832, 9.90458202], [76.31652832, 9.90486145], [76.31624603, 9.90486145], [76.31624603, 9.90514088], [76.31569672, 9.90514088], [76.31569672, 9.90542126], [76.31541443, 9.90541744], [76.31541443, 9.90569496], [76.31513977, 9.90569496], [76.31513977, 9.90597343], [76.31485748, 9.90596962], [76.31485748, 9.90653133], [76.31458282, 9.90652657], [76.31458282, 9.90680695], [76.31430817, 9.90680695], [76.31430817, 9.90708256], [76.31402588, 9.9070797], [76.31402588, 9.90764141], [76.31375122, 9.90763855], [76.31375122, 9.90819454], [76.31346893, 9.90818977], [76.31346893, 9.90875053], [76.31318665, 9.90875053], [76.31318665, 9.91041946], [76.31346893, 9.9104166], [76.31346893, 9.91069508], [76.31375122, 9.91069508], [76.31375122, 9.9109726], [76.31458282, 9.9109726], [76.31458282, 9.91208267], [76.31430817, 9.91208267], [76.31430817, 9.91319466], [76.31402588, 9.91319084], [76.31402588, 9.91375065], [76.31375122, 9.91374874], [76.31375122, 9.91458321], [76.31346893, 9.9145813], [76.31346893, 9.91541958], [76.31319427, 9.91541672], [76.31319427, 9.9159708], [76.31291962, 9.91596889], [76.31291962, 9.91652966], [76.31263733, 9.91652679], [76.31263733, 9.91708374], [76.31208038, 9.91708374], [76.31208038, 9.91736221], [76.31181335, 9.91735935], [76.31181335, 9.91763973], [76.31124878, 9.91763973], [76.31124878, 9.91792011], [76.31097412, 9.91791534], [76.31097412, 9.91874981], [76.31069183, 9.91874981], [76.31069183, 9.92069435], [76.31041718, 9.92069435], [76.31041718, 9.92208385], [76.31014252, 9.92208385], [76.31014252, 9.92236233], [76.30986023, 9.92236042], [76.30986023, 9.92263985], [76.3095932, 9.92263985], [76.3095932, 9.92292023], [76.30930328, 9.92291641], [76.30930328, 9.9234724], [76.30902863, 9.92346954], [76.30902863, 9.9240303], [76.30874634, 9.9240284], [76.30874634, 9.92486], [76.30847168, 9.92486], [76.30847168, 9.92542076], [76.30819702, 9.92541599], [76.30819702, 9.92625046], [76.30791473, 9.92625046], [76.30791473, 9.92708206], [76.30764008, 9.92708015], [76.30764008, 9.92763996], [76.30735779, 9.92763805], [76.30735779, 9.92819405], [76.30708313, 9.92819405], [76.30708313, 9.92847157], [76.30680847, 9.92846966], [76.30680847, 9.92903137], [76.30652618, 9.92902756], [76.30652618, 9.92958546], [76.30625153, 9.92958546], [76.30625153, 9.92986012], [76.30596924, 9.92986012], [76.30596924, 9.93042088], [76.30569458, 9.93041611], [76.30569458, 9.93069458], [76.30541992, 9.93068123], [76.30541992, 9.93125057], [76.30513763, 9.93125057], [76.30513763, 9.93181133], [76.30486298, 9.93180656], [76.30486298, 9.93236065], [76.30458069, 9.93236065], [76.30458069, 9.93319511], [76.30430603, 9.93319035], [76.30430603, 9.93431091], [76.30403137, 9.93430519], [76.30403137, 9.93486118], [76.30430603, 9.93486118], [76.30430603, 9.93514061], [76.30458069, 9.93514061], [76.30458069, 9.93542099], [76.30486298, 9.93541718], [76.30486298, 9.93569469], [76.30513763, 9.93569469], [76.30513763, 9.93597317], [76.30541992, 9.93597126], [76.30541992, 9.93653107], [76.30569458, 9.93652916], [76.30569458, 9.93736076], [76.30541992, 9.93736076], [76.30541992, 9.93762112], [76.30541992, 9.93847084], [76.30513763, 9.93847084], [76.30513763, 9.93958282], [76.30486298, 9.93958282], [76.30486298, 9.94069481], [76.30541992, 9.94069481], [76.30541992, 9.94347095], [76.30568695, 9.94347095], [76.30568695, 9.94374943], [76.30596924, 9.94374943], [76.30596924, 9.94402981], [76.30652618, 9.94402981], [76.30652618, 9.94431019], [76.30680847, 9.94430637], [76.30680847, 9.94486237], [76.30725861, 9.94485855], [76.30764008, 9.94485855], [76.30764008, 9.94514179], [76.3079071, 9.94514179], [76.3079071, 9.94485855], [76.30819702, 9.94485855], [76.30819702, 9.94514179], [76.30902863, 9.94514179], [76.30902863, 9.94542027], [76.31041718, 9.94541454], [76.31041718, 9.94569302], [76.31096649, 9.94567966], [76.31096649, 9.94625187], [76.31124878, 9.94625187], [76.31124878, 9.94764042], [76.31153107, 9.94763756], [76.31153107, 9.94847202], [76.31096649, 9.94847202], [76.31096649, 9.9493103], [76.31069183, 9.94930553], [76.31069183, 9.94958401], [76.30986023, 9.94958401], [76.30986023, 9.94930553], [76.30874634, 9.9493103], [76.30874634, 9.94902992], [76.30819702, 9.94902992], [76.30819702, 9.94847202], [76.30791473, 9.94847202], [76.30791473, 9.94791794], [76.30764008, 9.94791985], [76.30764008, 9.94708061], [76.30735779, 9.94708443], [76.30735779, 9.94624996], [76.30684662, 9.94624996], [76.30541992, 9.94625187], [76.30541992, 9.94597244], [76.30513763, 9.94597244], [76.30513763, 9.94513988], [76.30486298, 9.94514179], [76.30486298, 9.94374943], [76.30458069, 9.94374943], [76.30458069, 9.94263935], [76.30430603, 9.94263935], [76.30430603, 9.94153023], [76.30401611, 9.94153023], [76.30401611, 9.93875122], [76.30430603, 9.93875122], [76.30430603, 9.93763924], [76.30458069, 9.93764114], [76.30458069, 9.93714046], [76.30458069, 9.93680477], [76.30430603, 9.93680859], [76.30430603, 9.93625069], [76.30401611, 9.93625069], [76.30401611, 9.93597126], [76.3034668, 9.93597126], [76.3034668, 9.93625069], [76.30319214, 9.93625069], [76.30319214, 9.93653107], [76.30264282, 9.93653107], [76.30264282, 9.93680859], [76.30236053, 9.93680477], [76.30236053, 9.93708324], [76.30208588, 9.93708324], [76.30208588, 9.93736076], [76.30041504, 9.93736076], [76.30041504, 9.93680477], [76.30014038, 9.93680859], [76.30014038, 9.93597126], [76.30041504, 9.93597317], [76.30041504, 9.93541718], [76.30069733, 9.93542099], [76.30069733, 9.93494129], [76.30069733, 9.93486118], [76.30097961, 9.93486118], [76.30097198, 9.93402672], [76.30124664, 9.93403053], [76.30124664, 9.93292141], [76.30152893, 9.93292141], [76.30152893, 9.93208027], [76.30180359, 9.93208218], [76.30180359, 9.93152905], [76.30208588, 9.93153095], [76.30208588, 9.93125057], [76.30236053, 9.93125057], [76.30236053, 9.93097019], [76.30263519, 9.93097305], [76.30263519, 9.93041611], [76.30291748, 9.93042088], [76.30291748, 9.93014145], [76.30319214, 9.93014145], [76.30319214, 9.92986012], [76.30347443, 9.92986012], [76.3034668, 9.92957973], [76.30374908, 9.92958546], [76.30374908, 9.92930698], [76.30430603, 9.92930889], [76.30430603, 9.92903137], [76.30458069, 9.92903137], [76.30458069, 9.92597198], [76.30430603, 9.92597198], [76.30430603, 9.92569447], [76.30347443, 9.92569447], [76.30347443, 9.92597198], [76.30319214, 9.92597198], [76.30319214, 9.92625046], [76.30264282, 9.92625046], [76.30264282, 9.92653275], [76.30236053, 9.92653275], [76.30236053, 9.92681122], [76.30180359, 9.92680645], [76.30180359, 9.92708206], [76.30124664, 9.92708015], [76.30124664, 9.92793179], [76.30097198, 9.92791557], [76.30097198, 9.92819405], [76.30069733, 9.92819405], [76.30069733, 9.92847157], [76.30042267, 9.92846966], [76.30042267, 9.92903137], [76.30014038, 9.92903137], [76.30014038, 9.92930889], [76.29985809, 9.92930698], [76.29985809, 9.92986012], [76.29957581, 9.92986012], [76.29957581, 9.93014145], [76.29930878, 9.93013763], [76.29930878, 9.93069458], [76.29902649, 9.93068123], [76.29902649, 9.93125057], [76.29875183, 9.93125057], [76.29872131, 9.93153095], [76.29846954, 9.93152905], [76.29846954, 9.93208218], [76.29818726, 9.93208027], [76.29818726, 9.93264103], [76.29792023, 9.93263912], [76.29792023, 9.93319511], [76.29763794, 9.93319511], [76.29763794, 9.93375111], [76.29736328, 9.93374157], [76.29736328, 9.93403053], [76.29708099, 9.93402672], [76.29708099, 9.93458271], [76.29680634, 9.93458271], [76.29680634, 9.93486118], [76.29651642, 9.93486118], [76.29651642, 9.93542099], [76.29624939, 9.93541718], [76.29624939, 9.93597317], [76.2959671, 9.93597126], [76.2959671, 9.93625069], [76.29569244, 9.93625069], [76.29569244, 9.93680859], [76.29541779, 9.93680477], [76.29541779, 9.93708324], [76.29514313, 9.93708134], [76.29514313, 9.93764114], [76.29485321, 9.93764114], [76.29485321, 9.93792152], [76.29458618, 9.93791676], [76.29458618, 9.93847084], [76.29430389, 9.93847084], [76.29429626, 9.93904972], [76.29429626, 9.93931198], [76.29402924, 9.93931198], [76.29402924, 9.93987274], [76.29374695, 9.93987274], [76.29374695, 9.94042015], [76.29347229, 9.94041729], [76.29347229, 9.94097328], [76.29319763, 9.94097137], [76.29319763, 9.94153023], [76.29291534, 9.94152737], [76.29291534, 9.94208336], [76.29264069, 9.94208145], [76.29264069, 9.94293118], [76.2923584, 9.94291782], [76.2923584, 9.94374943], [76.29207611, 9.94374943], [76.29207611, 9.94431019], [76.29180908, 9.94431019], [76.29180908, 9.94514179], [76.29152679, 9.94513988], [76.29152679, 9.94567966], [76.29125214, 9.94569969], [76.29125214, 9.94625187], [76.29096985, 9.94625187], [76.29096985, 9.94680977], [76.29069519, 9.94680595], [76.29069519, 9.94736195], [76.2904129, 9.94736195], [76.2904129, 9.94791985], [76.29013824, 9.94791794], [76.29013824, 9.94847202], [76.28985596, 9.94847202], [76.28985596, 9.94902992], [76.2895813, 9.94902802], [76.2895813, 9.94958401], [76.28930664, 9.94958401], [76.28930664, 9.94986153], [76.28901672, 9.94985962], [76.28901672, 9.95042038], [76.28874969, 9.95041561], [76.28874969, 9.95069408], [76.28848267, 9.95068932], [76.28848267, 9.95125008], [76.28819275, 9.95125008], [76.28819275, 9.95181084], [76.28791809, 9.95180607], [76.28791809, 9.95208359], [76.2876358, 9.95208168], [76.2876358, 9.95263958], [76.28736115, 9.95263767], [76.28736115, 9.95319366], [76.28708649, 9.95319366], [76.28708649, 9.95347214], [76.28679657, 9.95347023], [76.28679657, 9.95403099], [76.28652954, 9.95402813], [76.28652954, 9.95458221], [76.28624725, 9.95458031], [76.28624725, 9.95514107], [76.2859726, 9.95513821], [76.2859726, 9.9556942], [76.28569794, 9.9556942], [76.28569794, 9.95625019], [76.28542328, 9.95625019], [76.28542328, 9.95681095], [76.28458405, 9.95680428], [76.28458405, 9.95708466], [76.28430939, 9.95707989], [76.28430176, 9.95764065], [76.2840271, 9.95763779], [76.2840271, 9.9598608], [76.28375244, 9.9598608], [76.28375244, 9.96069527], [76.28347015, 9.96069527], [76.28347015, 9.96125126], [76.2831955, 9.96125126], [76.2831955, 9.96208286], [76.28291321, 9.96208], [76.28291321, 9.96291924], [76.28263855, 9.96291733], [76.28263855, 9.96347332], [76.28235626, 9.96347141], [76.28235626, 9.9643116], [76.2820816, 9.96430492], [76.2820816, 9.96486092], [76.28180695, 9.96486092], [76.28180695, 9.96569538], [76.28151703, 9.96569061], [76.28152466, 9.96625137], [76.28125, 9.96625137], [76.28125, 9.96681023], [76.28097534, 9.96680546], [76.28097534, 9.96736145], [76.28069305, 9.96736145], [76.28069305, 9.9679203], [76.2804184, 9.96791744], [76.2804184, 9.96847343], [76.28013611, 9.96847057], [76.28013611, 9.96903038], [76.27986145, 9.96902657], [76.27986145, 9.96958256], [76.27958679, 9.96958065], [76.27958679, 9.97014046], [76.2793045, 9.97014046], [76.2793045, 9.97069645], [76.27902985, 9.97069073], [76.27902985, 9.97124863], [76.27874756, 9.97124863], [76.27874756, 9.97208405], [76.2784729, 9.97208118], [76.2784729, 9.97264194], [76.27819824, 9.97264004], [76.27819824, 9.97347164], [76.27791595, 9.97347164], [76.27791595, 9.97402954], [76.2776413, 9.97402763], [76.2776413, 9.97458363], [76.27735901, 9.97457886], [76.27735901, 9.97542], [76.27707672, 9.97542], [76.27707672, 9.97598076], [76.27680969, 9.97598076], [76.27680969, 9.97653008], [76.2765274, 9.97652817], [76.2765274, 9.97708416], [76.27625275, 9.97707939], [76.27625275, 9.97764015], [76.27597046, 9.97764015], [76.27597046, 9.97819424], [76.2756958, 9.97819424], [76.2756958, 9.97875023], [76.27540588, 9.97875023], [76.27540588, 9.97931099], [76.27513885, 9.97930622], [76.27513885, 9.97986221], [76.27485657, 9.97986031], [76.27485657, 9.98042107], [76.27458191, 9.9804163], [76.27458191, 9.98097229], [76.27430725, 9.98097038], [76.27430725, 9.98153114], [76.27402496, 9.98152828], [76.27402496, 9.98208427], [76.27348328, 9.98208046], [76.27348328, 9.98236275], [76.27319336, 9.98236275], [76.27319336, 9.98292065], [76.2729187, 9.98291588], [76.2729187, 9.98319435], [76.27263641, 9.98318958], [76.27263641, 9.98403072], [76.27236176, 9.98402882], [76.27236176, 9.98458195], [76.2720871, 9.98458004], [76.2720871, 9.98542118], [76.27180481, 9.98541737], [76.27180481, 9.98569489], [76.27153015, 9.98569489], [76.27153015, 9.98708344], [76.27124786, 9.98707962], [76.27124786, 9.98764133], [76.27097321, 9.98764133], [76.27097321, 9.98791885], [76.27069092, 9.98791695], [76.27069092, 9.98847294], [76.27041626, 9.98847103], [76.27041626, 9.98903084], [76.2701416, 9.98903084], [76.2701416, 9.98930931], [76.26985931, 9.98930454], [76.26985931, 9.98958302], [76.2701416, 9.98958302], [76.2701416, 9.990695], [76.27041626, 9.99069023], [76.27041626, 9.99180984], [76.27097321, 9.99180508], [76.27097321, 9.9920826], [76.27153015, 9.9920826], [76.27153015, 9.99236107], [76.2720871, 9.99236107], [76.2720871, 9.99292183], [76.27236176, 9.99291706], [76.27236176, 9.99347115], [76.27263641, 9.99347115], [76.27263641, 9.99375057], [76.27236176, 9.99374866], [76.27236176, 9.99402714], [76.27263641, 9.99402046], [76.27263641, 9.99542046], [76.2729187, 9.99541664], [76.2729187, 9.99597359], [76.27319336, 9.99597073], [76.27319336, 9.99652958], [76.27348328, 9.99652958], [76.27348328, 9.99680996], [76.27375031, 9.99680519], [76.27375031, 9.99708271], [76.27430725, 9.99708271], [76.27430725, 9.99680519], [76.2756958, 9.99680519], [76.2756958, 9.99708271], [76.27625275, 9.99708271], [76.27625275, 9.99736214], [76.2765274, 9.99735928], [76.2765274, 9.99875164], [76.27625275, 9.99875164], [76.27625275, 9.99903202], [76.27597046, 9.99903202], [76.27597046, 9.99930954], [76.2756958, 9.99930573], [76.2756958, 10.00000095], [76.2756958, 10.00069427], [76.27597046, 10.00069141], [76.27597046, 10.00181007], [76.27625275, 10.00181007], [76.27625275, 10.00292015], [76.27597046, 10.00291634], [76.27597046, 10.00319386], [76.2756958, 10.00319386], [76.2756958, 10.00347233], [76.27540588, 10.00347042], [76.27540588, 10.00431061], [76.27513885, 10.00431061], [76.27513885, 10.00542068], [76.2748642, 10.00541592], [76.2748642, 10.00569439], [76.27458191, 10.00569439], [76.27458191, 10.00625038], [76.27430725, 10.00625038], [76.27430725, 10.00681114], [76.27401733, 10.00681114], [76.27401733, 10.00792122], [76.27375031, 10.00791645], [76.27375031, 10.00902843], [76.27348328, 10.0090189], [76.27348328, 10.00931072], [76.27319336, 10.00930595], [76.27319336, 10.00986004], [76.2729187, 10.00986004], [76.2729187, 10.01014137], [76.27263641, 10.01014137], [76.27263641, 10.01125145], [76.27236176, 10.01125145], [76.27236176, 10.01235962], [76.27263641, 10.01235962], [76.27263641, 10.01542091], [76.27236176, 10.01542091], [76.27236176, 10.01625061], [76.27153015, 10.01625061], [76.27153015, 10.01680946], [76.27124786, 10.01680946], [76.27124786, 10.01764107], [76.27097321, 10.01764107], [76.27097321, 10.0179224], [76.27069092, 10.0179224], [76.27069092, 10.01903152], [76.27041626, 10.01903152], [76.27041626, 10.02014065], [76.2701416, 10.02013874], [76.2701416, 10.02069473], [76.26958466, 10.02069473], [76.26958466, 10.02097321], [76.26902771, 10.02095985], [76.26902771, 10.02125072], [76.26847076, 10.02125072], [76.26847076, 10.02180958], [76.26819611, 10.02180958], [76.26819611, 10.02263927], [76.26790619, 10.02263927], [76.26790619, 10.02402973], [76.26763916, 10.02402687], [76.26763916, 10.02486229], [76.2673645, 10.02486229], [76.2673645, 10.02597141], [76.26708221, 10.02597141], [76.26708221, 10.02709103], [76.26680756, 10.02709103], [76.26680756, 10.02764034], [76.26652527, 10.02764034], [76.26652527, 10.02958393], [76.26680756, 10.02958393], [76.26680756, 10.03069401], [76.2673645, 10.03069401], [76.2673645, 10.03097153], [76.26763916, 10.03096962], [76.26763916, 10.03153038], [76.2673645, 10.03152847], [76.2673645, 10.03208447], [76.26652527, 10.03208447], [76.26652527, 10.03180599], [76.26625061, 10.03181076], [76.26625061, 10.03153038], [76.26568604, 10.03153038], [76.26568604, 10.03125], [76.26513672, 10.03125], [76.26513672, 10.03096962], [76.26346588, 10.03096962], [76.26346588, 10.03153038], [76.26319122, 10.03152847], [76.26319122, 10.03236008], [76.26291656, 10.03236008], [76.26291656, 10.03264046], [76.26264191, 10.03264046], [76.26264191, 10.03292274], [76.26208496, 10.03291607], [76.26208496, 10.03319359], [76.26180267, 10.03319359], [76.26180267, 10.03347206], [76.26152802, 10.03347015], [76.26152802, 10.03374958], [76.26097107, 10.03374958], [76.26097107, 10.03403091], [76.26040649, 10.03403091], [76.26040649, 10.03431129], [76.26013947, 10.03431129], [76.26013947, 10.03403091], [76.25985718, 10.03403091], [76.25985718, 10.03347015], [76.25958252, 10.03347206], [76.25958252, 10.03152847], [76.25985718, 10.03153038], [76.25985718, 10.0304203], [76.25958252, 10.0304203], [76.25958252, 10.03013134], [76.25930786, 10.03013992], [76.25930786, 10.02958393], [76.25902557, 10.02958393], [76.25902557, 10.02902794], [76.25875092, 10.02902985], [76.25875092, 10.02875042], [76.25846863, 10.02875042], [76.25846863, 10.02819443], [76.25819397, 10.02819443], [76.25819397, 10.02791786], [76.25791931, 10.02791977], [76.25791931, 10.02709103], [76.25763702, 10.02709103], [76.25763702, 10.02597141], [76.25736237, 10.02597141], [76.25736237, 10.02319336], [76.25763702, 10.02319336], [76.25763702, 10.0223608], [76.25791931, 10.0223608], [76.25791931, 10.02208328], [76.25819397, 10.02208328], [76.25819397, 10.02152729], [76.25846863, 10.0215292], [76.25846863, 10.02095985], [76.25875092, 10.02097321], [76.25875092, 10.02069473], [76.25902557, 10.02069473], [76.25902557, 10.01986122], [76.25958252, 10.01986122], [76.25958252, 10.01958275], [76.26013947, 10.01958275], [76.26013947, 10.01930523], [76.26040649, 10.0193119], [76.26040649, 10.01847076], [76.26069641, 10.01847076], [76.26069641, 10.01791668], [76.26097107, 10.0179224], [76.26097107, 10.01708126], [76.26125336, 10.01708317], [76.26125336, 10.01652908], [76.26097107, 10.01653099], [76.26097107, 10.01625061], [76.26125336, 10.01625061], [76.26125336, 10.01515007], [76.26152802, 10.01515007], [76.26152802, 10.01486111], [76.26125336, 10.01486111], [76.26125336, 10.01458263], [76.26152802, 10.01458263], [76.26152802, 10.01319504], [76.26180267, 10.01319504], [76.26180267, 10.0120821], [76.26207733, 10.01209164], [76.26207733, 10.0104208], [76.26235962, 10.0104208], [76.26235962, 10.00957966], [76.26264191, 10.00958538], [76.26264191, 10.00763798], [76.26291656, 10.00764275], [76.26291656, 10.00542068], [76.26319122, 10.00542068], [76.26319122, 10.00374985], [76.26347351, 10.00374985], [76.26346588, 10.00319195], [76.26374817, 10.00319386], [76.26374817, 10.00263786], [76.26403046, 10.00263977], [76.26403046, 10.00236034], [76.26430511, 10.00236225], [76.26430511, 10.00152779], [76.26457977, 10.00152969], [76.26457977, 10.00041962], [76.26486969, 10.00041962], [76.26486969, 9.99994087], [76.26486206, 9.99874878], [76.26457977, 9.99875164], [76.26457977, 9.99847126], [76.26486206, 9.99847126], [76.26486206, 9.99708271], [76.26513672, 9.99708271], [76.26513672, 9.99652672], [76.26541901, 9.99652958], [76.26541901, 9.99542046], [76.26568604, 9.99542046], [76.26568604, 9.99514198], [76.26597595, 9.99514198], [76.26597595, 9.99459934], [76.26597595, 9.99341202], [76.26597595, 9.99291706], [76.26625061, 9.99292183], [76.26625061, 9.99180984], [76.2665329, 9.99180984], [76.2665329, 9.99153137], [76.26680756, 9.99153137], [76.26680756, 9.99069023], [76.26708221, 9.990695], [76.26708221, 9.98958302], [76.2673645, 9.98958302], [76.2673645, 9.98847294], [76.26763916, 9.98847294], [76.26763916, 9.98708344], [76.26791382, 9.98708344], [76.26791382, 9.98652554], [76.26819611, 9.98653126], [76.26819611, 9.9843111], [76.26847076, 9.9843111], [76.26847076, 9.9837513], [76.26875305, 9.9837513], [76.26875305, 9.98319435], [76.26847076, 9.98319435], [76.26847076, 9.98291588], [76.26819611, 9.98292065], [76.26819611, 9.98264122], [76.26735687, 9.98264122], [76.26735687, 9.98292065], [76.26680756, 9.98291588], [76.26680756, 9.98319435], [76.26625061, 9.98319435], [76.26625061, 9.98347187], [76.26597595, 9.98346996], [76.26597595, 9.98403072], [76.26569366, 9.98402882], [76.26569366, 9.98486042], [76.26597595, 9.98485088], [76.26597595, 9.9851408], [76.26568604, 9.9851408], [76.26568604, 9.98542118], [76.26541901, 9.98541737], [76.26541901, 9.98736095], [76.26557922, 9.98736095], [76.26568604, 9.98736095], [76.26568604, 9.98791885], [76.26541901, 9.98791695], [76.26541901, 9.98819542], [76.26569366, 9.98819542], [76.26569366, 9.98898125], [76.26569366, 9.98958302], [76.26541901, 9.98958111], [76.26541901, 9.99041939], [76.26513672, 9.99041939], [76.26513672, 9.99098015], [76.26486969, 9.99098015], [76.26486969, 9.99153137], [76.26457977, 9.9915266], [76.26457977, 9.9920826], [76.26431274, 9.99208069], [76.26431274, 9.99292183], [76.26403046, 9.99291706], [76.26403046, 9.99347115], [76.26374817, 9.99347115], [76.26374817, 9.99402714], [76.26346588, 9.99402046], [76.26346588, 9.99431038], [76.26319122, 9.99430466], [76.26319122, 9.99486065], [76.26291656, 9.99486065], [76.26291656, 9.99542046], [76.26264191, 9.99541664], [76.26264191, 9.99597359], [76.26235962, 9.99597073], [76.26235962, 9.99680996], [76.26264191, 9.99680519], [76.26264191, 9.99708271], [76.26235962, 9.99708271], [76.26235962, 9.99736214], [76.26264191, 9.99735928], [76.26264191, 9.99763966], [76.26235962, 9.99763966], [76.26235962, 9.99847126], [76.26207733, 9.99847126], [76.26207733, 9.99903202], [76.26180267, 9.99902821], [76.26180267, 9.9995842], [76.26152802, 9.9995842], [76.26152802, 9.99986172], [76.26125336, 9.99985886], [76.26125336, 10.00015068], [76.26125336, 10.00041962], [76.26097107, 10.00041962], [76.26097107, 10.00152969], [76.26069641, 10.00152969], [76.26069641, 10.00263977], [76.26040649, 10.00263977], [76.26040649, 10.00403023], [76.26013947, 10.00402832], [76.26013947, 10.00500965], [76.26013947, 10.00569439], [76.25985718, 10.00568867], [76.25985718, 10.00653267], [76.25958252, 10.00653267], [76.25958252, 10.00681114], [76.25930786, 10.00681114], [76.25930786, 10.00792122], [76.2590332, 10.00792122], [76.2590332, 10.00874996], [76.25875092, 10.00874996], [76.25875092, 10.00902843], [76.25846863, 10.0090189], [76.25846863, 10.00931072], [76.25875092, 10.00930595], [76.25875092, 10.00986004], [76.25846863, 10.00986004], [76.25846863, 10.0104208], [76.25819397, 10.01041603], [76.25819397, 10.01069355], [76.25791931, 10.01068974], [76.25791931, 10.01125145], [76.25763702, 10.01125145], [76.25763702, 10.01153088], [76.25736237, 10.01153088], [76.25736237, 10.01209164], [76.25708008, 10.01209164], [76.25708008, 10.01264095], [76.25680542, 10.01263905], [76.25680542, 10.01319504], [76.25653076, 10.01319504], [76.25653076, 10.01347256], [76.25624847, 10.0134697], [76.25624847, 10.01403141], [76.25597382, 10.01402664], [76.25597382, 10.01458263], [76.25569153, 10.01458263], [76.25569153, 10.01597309], [76.25541687, 10.01597118], [76.25541687, 10.01653099], [76.25514221, 10.01653099], [76.25514221, 10.01680946], [76.25485992, 10.0168047], [76.25485992, 10.01708317], [76.2545929, 10.01708126], [76.2545929, 10.0179224], [76.25430298, 10.01791668], [76.25430298, 10.01958275], [76.25402832, 10.01958084], [76.25402832, 10.02042198], [76.25375366, 10.02041721], [76.25375366, 10.02097321], [76.25347137, 10.02095985], [76.25347137, 10.0215292], [76.25319672, 10.0215292], [76.25319672, 10.02180958], [76.25291443, 10.02180481], [76.25291443, 10.0223608], [76.25263977, 10.02235889], [76.25263977, 10.02291965], [76.25235748, 10.02291679], [76.25235748, 10.02347088], [76.25208282, 10.02347088], [76.25208282, 10.02431011], [76.25235748, 10.02430534], [76.25235748, 10.0256958], [76.25208282, 10.02569103], [76.25208282, 10.02680969], [76.25180817, 10.02680588], [76.25180817, 10.02736187], [76.25152588, 10.02736187], [76.25152588, 10.02847195], [76.25125122, 10.02847195], [76.25125122, 10.02931023], [76.24986267, 10.02930641], [76.24986267, 10.0298624], [76.24958038, 10.0298624], [76.24958038, 10.03013992], [76.2498703, 10.03013134], [76.2498703, 10.0304203], [76.25041962, 10.03041553], [76.25041962, 10.03069401], [76.25069427, 10.03069401], [76.25069427, 10.03097153], [76.25096893, 10.03096962], [76.25096893, 10.03125], [76.25125122, 10.03125], [76.25125122, 10.03181076], [76.25152588, 10.03180599], [76.25152588, 10.03236008], [76.25208282, 10.03236008], [76.25208282, 10.03292274], [76.25235748, 10.03292274], [76.25235748, 10.03374958], [76.25263977, 10.03374958], [76.25263977, 10.03458214], [76.25291443, 10.03458214], [76.25291443, 10.03485966], [76.25319672, 10.03485966], [76.25319672, 10.03514004], [76.25374603, 10.03514004], [76.25374603, 10.03542137], [76.25402832, 10.03541565], [76.25402832, 10.03569412], [76.25430298, 10.03569412], [76.25430298, 10.03597164], [76.2545929, 10.03596973], [76.2545929, 10.03625011], [76.25485992, 10.03625011], [76.25485992, 10.03653145], [76.25514221, 10.03653145], [76.25514221, 10.03681087], [76.25541687, 10.0368042], [76.25541687, 10.03708458], [76.25569153, 10.03708458], [76.25569153, 10.03736019], [76.25596619, 10.03736019], [76.25596619, 10.03764057], [76.25624847, 10.03764057], [76.25624847, 10.03792095], [76.25653076, 10.03791618], [76.25653076, 10.0381937], [76.25680542, 10.0381937], [76.25680542, 10.03847313], [76.25708008, 10.03847027], [76.25708008, 10.03903103], [76.25818634, 10.03903103], [76.25818634, 10.03931999], [76.25902557, 10.03930664], [76.25902557, 10.03958225], [76.26013947, 10.03958225], [76.26013947, 10.03875065], [76.26125336, 10.03875065], [76.26125336, 10.03903103], [76.2618103, 10.03903103], [76.2618103, 10.03847027], [76.26208496, 10.03847313], [76.26208496, 10.0381937], [76.26235962, 10.0381937], [76.26235962, 10.03791618], [76.26264191, 10.03792095], [76.26264191, 10.03708172], [76.26180267, 10.03708458], [76.26180267, 10.0368042], [76.26152802, 10.03681087], [76.26152802, 10.03625011], [76.26125336, 10.03625011], [76.26125336, 10.03569031], [76.26152802, 10.03569412], [76.26152802, 10.03513813], [76.2618103, 10.03514004], [76.2618103, 10.03485966], [76.26264191, 10.03486156], [76.26264191, 10.03569412], [76.26347351, 10.03569412], [76.26347351, 10.03486156], [76.26374817, 10.03485966], [76.26374817, 10.03374958], [76.26403046, 10.03374958], [76.26403046, 10.03347015], [76.26431274, 10.03347015], [76.26431274, 10.03514004], [76.26457977, 10.03513813], [76.26457977, 10.03569412], [76.26486206, 10.03569412], [76.26486206, 10.03597164], [76.26513672, 10.03596973], [76.26513672, 10.03625011], [76.26541901, 10.03625011], [76.26541901, 10.03653145], [76.26568604, 10.03653145], [76.26568604, 10.03681087], [76.26597595, 10.0368042], [76.26597595, 10.03708458], [76.26625061, 10.03708458], [76.26625061, 10.03736019], [76.26597595, 10.03736019], [76.26597595, 10.03792095], [76.26569366, 10.03791618], [76.26569366, 10.0381937], [76.26541901, 10.03818989], [76.26541901, 10.03875065], [76.26513672, 10.03875065], [76.26513672, 10.03931999], [76.26486206, 10.03930664], [76.26486206, 10.03958225], [76.26430511, 10.03958225], [76.26430511, 10.03875065], [76.26403046, 10.03875065], [76.26403046, 10.03847027], [76.26374817, 10.03847313], [76.26374817, 10.0381937], [76.26347351, 10.0381937], [76.26347351, 10.03847313], [76.26319122, 10.03847027], [76.26319122, 10.03875065], [76.26291656, 10.03875065], [76.26291656, 10.03958225], [76.26264191, 10.03958225], [76.26264191, 10.03986073], [76.26291656, 10.03986073], [76.26291656, 10.04014111], [76.26319122, 10.04014111], [76.26319122, 10.04042053], [76.26347351, 10.04041672], [76.26347351, 10.04069519], [76.26291656, 10.04069519], [76.26291656, 10.04097271], [76.26125336, 10.04097271], [76.26125336, 10.04125118], [76.25985718, 10.04125118], [76.25985718, 10.04181099], [76.26013947, 10.04180527], [76.26013947, 10.04236126], [76.26041412, 10.04236126], [76.26041412, 10.04347324], [76.26013947, 10.04347324], [76.26013947, 10.04319477], [76.25986481, 10.04319477], [76.25986481, 10.04263878], [76.25930786, 10.04264069], [76.25930786, 10.04292107], [76.25902557, 10.04291725], [76.25902557, 10.04319477], [76.25875092, 10.04319477], [76.25875092, 10.04347324], [76.25819397, 10.04347324], [76.25819397, 10.04319477], [76.25736237, 10.04319477], [76.25736237, 10.04291725], [76.25681305, 10.04292107], [76.25681305, 10.04264069], [76.25569153, 10.04263878], [76.25569153, 10.04347324], [76.25541687, 10.04347134], [76.25541687, 10.04431152], [76.25514221, 10.04430485], [76.25514221, 10.04513931], [76.25485992, 10.04513931], [76.25485992, 10.0456953], [76.25514221, 10.04569054], [76.25514221, 10.04763889], [76.25430298, 10.04763889], [76.25430298, 10.04708099], [76.25458527, 10.0470829], [76.25458527, 10.04652691], [76.25347137, 10.04653168], [76.25347137, 10.0462513], [76.25375366, 10.0462513], [76.25374603, 10.04512978], [76.25402832, 10.04513931], [76.25402832, 10.04430485], [76.25430298, 10.04431152], [76.25430298, 10.04374886], [76.25458527, 10.04374886], [76.25458527, 10.04319477], [76.25485992, 10.04319477], [76.25485992, 10.04236126], [76.25514221, 10.04236126], [76.25514221, 10.03958225], [76.25541687, 10.03958225], [76.25541687, 10.03930664], [76.25485992, 10.03931999], [76.25485992, 10.03903103], [76.25430298, 10.03903103], [76.25430298, 10.03931999], [76.25402832, 10.03931999], [76.25402832, 10.04042053], [76.25374603, 10.04042053], [76.25374603, 10.04153061], [76.25347137, 10.0415287], [76.25347137, 10.04208279], [76.25319672, 10.04207134], [76.25319672, 10.04264069], [76.25291443, 10.04263878], [76.25291443, 10.04319477], [76.25263977, 10.04319477], [76.25263977, 10.04374886], [76.25235748, 10.04374886], [76.25235748, 10.04402924], [76.25208282, 10.04402924], [76.25208282, 10.04486084], [76.25180817, 10.04486084], [76.25180817, 10.04513931], [76.25152588, 10.04513931], [76.25152588, 10.0456953], [76.25125122, 10.0456953], [76.25125122, 10.0470829], [76.25041962, 10.0470829], [76.25041962, 10.04736137], [76.25096893, 10.04736137], [76.25096893, 10.04763889], [76.25235748, 10.04763889], [76.25235748, 10.04736137], [76.25263977, 10.04736137], [76.25263977, 10.04792023], [76.25291443, 10.04791737], [76.25291443, 10.04819489], [76.25263977, 10.04819489], [76.25263977, 10.04847336], [76.25208282, 10.04847145], [76.25208282, 10.04875088], [76.25180817, 10.04875088], [76.25180817, 10.04930973], [76.25125122, 10.04930496], [76.25125122, 10.04986095], [76.25096893, 10.04986095], [76.25096893, 10.05013943], [76.25041962, 10.05013943], [76.25041962, 10.05069637], [76.25013733, 10.05069065], [76.25013733, 10.05153179], [76.24986267, 10.05152702], [76.24986267, 10.05208397], [76.24958038, 10.05208111], [76.24958038, 10.05292034], [76.24903107, 10.05291462], [76.24903107, 10.05347157], [76.24874878, 10.05347157], [76.24874878, 10.05458355], [76.24846649, 10.05458069], [76.24846649, 10.05513954], [76.24791718, 10.05513954], [76.24791718, 10.05541992], [76.24764252, 10.05541992], [76.24764252, 10.05624962], [76.24791718, 10.05624962], [76.24791718, 10.05708408], [76.24764252, 10.05708408], [76.24764252, 10.0573597], [76.24624634, 10.0573616], [76.24624634, 10.05819416], [76.24652863, 10.05819416], [76.24652863, 10.05875015], [76.24624634, 10.05875015], [76.24624634, 10.05931091], [76.24569702, 10.05930614], [76.24569702, 10.05958366], [76.24541473, 10.05958366], [76.24541473, 10.06013775], [76.24514008, 10.06013775], [76.24514008, 10.06069374], [76.24485779, 10.06069183], [76.24485779, 10.06124973], [76.24514008, 10.06124973], [76.24514008, 10.06181145], [76.2454071, 10.06181145], [76.24545288, 10.06270695], [76.24514008, 10.06263828], [76.24514008, 10.06291199], [76.24514008, 10.06320095], [76.24485779, 10.06319427], [76.24485779, 10.06347179], [76.24458313, 10.06347179], [76.24458313, 10.06375027], [76.24430847, 10.06375027], [76.24430847, 10.06403065], [76.24402618, 10.06403065], [76.24402618, 10.06431103], [76.24375153, 10.06430435], [76.24375153, 10.06458473], [76.24346924, 10.06458473], [76.24346924, 10.06486034], [76.24318695, 10.06486034], [76.24318695, 10.06514072], [76.24236298, 10.06513786], [76.24236298, 10.06569481], [76.24263763, 10.06569004], [76.24263763, 10.06626034], [76.24291992, 10.06626034], [76.24291992, 10.06653118], [76.24318695, 10.06653118], [76.24318695, 10.06681061], [76.24291992, 10.06680679], [76.24291992, 10.06736088], [76.24263763, 10.06736088], [76.24263763, 10.06792068], [76.24236298, 10.06791687], [76.24236298, 10.06847286], [76.24208069, 10.06847095], [76.24208069, 10.06902885], [76.24153137, 10.06902885], [76.24153137, 10.06930542], [76.24124908, 10.06930542], [76.24124908, 10.06958294], [76.24097443, 10.06958294], [76.24097443, 10.06986141], [76.24067688, 10.06986141], [76.24067688, 10.07041931], [76.24041748, 10.0704174], [76.24041748, 10.0709734], [76.24067688, 10.07097054], [76.24067688, 10.0715313], [76.24097443, 10.07152653], [76.24097443, 10.07208347], [76.24124908, 10.07208347], [76.24124908, 10.07236099], [76.24180603, 10.07236099], [76.24180603, 10.07264137], [76.24346924, 10.07264137], [76.24346924, 10.07236099], [76.24375153, 10.07236099], [76.24373627, 10.07181168], [76.24402618, 10.07181168], [76.24402618, 10.0715313], [76.24430847, 10.0715313], [76.24430847, 10.07097054], [76.24458313, 10.0709734], [76.24458313, 10.07069492], [76.24485779, 10.07069492], [76.24485779, 10.06986141], [76.24514008, 10.06986141], [76.24514008, 10.06930542], [76.24541473, 10.06930542], [76.24541473, 10.06902885], [76.24514008, 10.06902885], [76.24514008, 10.06847095], [76.24485779, 10.06847286], [76.24485779, 10.06819534], [76.24514008, 10.06819534], [76.24514008, 10.06736088], [76.24541473, 10.06736088], [76.2454071, 10.06653118], [76.24569702, 10.06653118], [76.24569702, 10.06569004], [76.24597168, 10.06569481], [76.24597168, 10.06513786], [76.24624634, 10.06514072], [76.24624634, 10.06457996], [76.24652863, 10.06458473], [76.24652863, 10.06430435], [76.24680328, 10.06431103], [76.24680328, 10.06403065], [76.2470932, 10.06403065], [76.2470932, 10.06347179], [76.24736023, 10.06347179], [76.24736023, 10.0629158], [76.2470932, 10.06292057], [76.2470932, 10.06264114], [76.24736023, 10.06264114], [76.24736023, 10.06236172], [76.24764252, 10.06236172], [76.24764252, 10.06181145], [76.24791718, 10.06181145], [76.24791718, 10.06153107], [76.24819183, 10.06153107], [76.24819183, 10.06091118], [76.24819183, 10.06041622], [76.24791718, 10.06042099], [76.24791718, 10.06013107], [76.24819183, 10.06013775], [76.24819183, 10.05958366], [76.24847412, 10.05958366], [76.24847412, 10.05902767], [76.24874878, 10.05902958], [76.24874878, 10.05875015], [76.24903107, 10.05875015], [76.24903107, 10.05847168], [76.24930573, 10.05847168], [76.24930573, 10.05819416], [76.24903107, 10.05819416], [76.24903107, 10.05791569], [76.24874878, 10.05792046], [76.24874878, 10.05764008], [76.24903107, 10.05764008], [76.24903107, 10.05706978], [76.24930573, 10.05708408], [76.24930573, 10.05680561], [76.24958038, 10.05681038], [76.24958038, 10.05624962], [76.2498703, 10.05624962], [76.2498703, 10.05568886], [76.25013733, 10.05569363], [76.25013733, 10.05541801], [76.25041962, 10.05541992], [76.25041962, 10.05486202], [76.25069427, 10.05486202], [76.25068665, 10.05458069], [76.25096893, 10.05458355], [76.25096893, 10.05430603], [76.25125122, 10.05431938], [76.25125122, 10.05375195], [76.25096893, 10.05375195], [76.25096893, 10.05319118], [76.25069427, 10.05319309], [76.25069427, 10.05263996], [76.25096893, 10.05264187], [76.25096893, 10.05208111], [76.25125122, 10.05208397], [76.25125122, 10.05180454], [76.25152588, 10.05181026], [76.25152588, 10.05264187], [76.25180817, 10.05263996], [76.25180817, 10.05319309], [76.25208282, 10.05319118], [76.25208282, 10.05375195], [76.25235748, 10.05375195], [76.25235748, 10.05403042], [76.25208282, 10.05403042], [76.25208282, 10.05513954], [76.25235748, 10.05513763], [76.25235748, 10.05569363], [76.25263977, 10.05569363], [76.25263977, 10.0559721], [76.25514221, 10.0559721], [76.25514221, 10.05569363], [76.25569153, 10.05569363], [76.25569153, 10.05541801], [76.25624847, 10.05541992], [76.25624847, 10.05513954], [76.25708008, 10.05513954], [76.25708008, 10.05486202], [76.25736237, 10.05486202], [76.25736237, 10.05375004], [76.25763702, 10.05375195], [76.25763702, 10.05319118], [76.25791931, 10.05319309], [76.25791931, 10.05263996], [76.25818634, 10.05264187], [76.25818634, 10.05208111], [76.25846863, 10.05208397], [76.25846863, 10.05097103], [76.25763702, 10.05097103], [76.25763702, 10.05153179], [76.25736237, 10.05152702], [76.25736237, 10.05208397], [76.25708008, 10.05208111], [76.25708008, 10.05264187], [76.25680542, 10.05263996], [76.25680542, 10.05347157], [76.25653076, 10.05347157], [76.25653076, 10.05403042], [76.25624847, 10.05403042], [76.25624847, 10.05347157], [76.25597382, 10.05347157], [76.25597382, 10.05319309], [76.25569153, 10.05319309], [76.25569153, 10.05291462], [76.25541687, 10.05292034], [76.25541687, 10.05208111], [76.25514221, 10.05208397], [76.25514221, 10.05180454], [76.25485992, 10.05181026], [76.25485992, 10.05153179], [76.25347137, 10.05152702], [76.25347137, 10.05208397], [76.25319672, 10.05208397], [76.25319672, 10.05180454], [76.25208282, 10.05181026], [76.25208282, 10.05126095], [76.25180817, 10.05126095], [76.25180817, 10.05097103], [76.25208282, 10.05097103], [76.25208282, 10.04986095], [76.25347137, 10.04986095], [76.25347137, 10.04958344], [76.25458527, 10.04958344], [76.25458527, 10.04930496], [76.25514221, 10.04930973], [76.25514221, 10.0490303], [76.25596619, 10.0490303], [76.25596619, 10.04930973], [76.25681305, 10.04930973], [76.25681305, 10.04763889], [76.25653076, 10.04763889], [76.25653076, 10.04708099], [76.25597382, 10.0470829], [76.25597382, 10.04736137], [76.25569153, 10.04736137], [76.25569153, 10.04680538], [76.25596619, 10.04681015], [76.25596619, 10.04653168], [76.25624847, 10.04653168], [76.25624847, 10.04597092], [76.25708008, 10.04597092], [76.25708008, 10.0462513], [76.25763702, 10.0462513], [76.25763702, 10.04653168], [76.25818634, 10.04653168], [76.25818634, 10.04681015], [76.25902557, 10.04680538], [76.25902557, 10.0470829], [76.25958252, 10.0470829], [76.25958252, 10.04736137], [76.25985718, 10.04736137], [76.25985718, 10.04763889], [76.26041412, 10.04763889], [76.26041412, 10.04819489], [76.26013947, 10.04819107], [76.26013947, 10.04930973], [76.25985718, 10.04930973], [76.25985718, 10.05013943], [76.25930786, 10.05013943], [76.25930786, 10.05153179], [76.25986481, 10.05152702], [76.25986481, 10.05208397], [76.25958252, 10.05208111], [76.25958252, 10.05264187], [76.25930786, 10.05264187], [76.25930786, 10.05292034], [76.25902557, 10.05291462], [76.25902557, 10.05319309], [76.25846863, 10.05319118], [76.25846863, 10.05431938], [76.25875092, 10.05430603], [76.25875092, 10.05458355], [76.25818634, 10.05458069], [76.25818634, 10.05541992], [76.25902557, 10.05541801], [76.25902557, 10.05569363], [76.25958252, 10.05569363], [76.25958252, 10.0559721], [76.25985718, 10.05596924], [76.25985718, 10.05624962], [76.26013947, 10.05624962], [76.26013947, 10.05653], [76.26040649, 10.05653], [76.26040649, 10.05681038], [76.26097107, 10.05680561], [76.26097107, 10.05694008], [76.26097107, 10.05708408], [76.26125336, 10.05708408], [76.26125336, 10.0573597], [76.2618103, 10.0573597], [76.2618103, 10.05792046], [76.26152802, 10.05791569], [76.26152802, 10.05875015], [76.26125336, 10.05875015], [76.26125336, 10.05902958], [76.26097107, 10.05902958], [76.26097107, 10.05931091], [76.26041412, 10.05930614], [76.26041412, 10.05958366], [76.26013947, 10.05958366], [76.26013947, 10.06013775], [76.25986481, 10.06013775], [76.25986481, 10.06069374], [76.25930786, 10.06069183], [76.25930786, 10.06124973], [76.2590332, 10.06124973], [76.2590332, 10.06153107], [76.25875092, 10.06153107], [76.25875092, 10.06181145], [76.25846863, 10.06180573], [76.25846863, 10.06208229], [76.25763702, 10.06208229], [76.25763702, 10.06152821], [76.25736237, 10.06153107], [76.25736237, 10.06124973], [76.25681305, 10.06124973], [76.25681305, 10.06320095], [76.25708008, 10.06319427], [76.25708008, 10.06347179], [76.25763702, 10.06347179], [76.25763702, 10.06431103], [76.25791931, 10.06430435], [76.25791931, 10.06458473], [76.25763702, 10.06458473], [76.25763702, 10.06486034], [76.25736237, 10.06486034], [76.25736237, 10.06514072], [76.25708008, 10.06514072], [76.25708008, 10.0654211], [76.25736237, 10.06541634], [76.25736237, 10.06597328], [76.25763702, 10.06597042], [76.25763702, 10.06653118], [76.25736237, 10.06652641], [76.25736237, 10.06708336], [76.25708008, 10.06707954], [76.25708008, 10.06792068], [76.25736237, 10.06791687], [76.25736237, 10.06847286], [76.25875092, 10.06847286], [76.25875092, 10.06791687], [76.2590332, 10.06792068], [76.2590332, 10.06736088], [76.25930786, 10.06736088], [76.25930786, 10.06680679], [76.25958252, 10.06681061], [76.25958252, 10.06653118], [76.26013947, 10.06653118], [76.26013947, 10.06626034], [76.26040649, 10.06626034], [76.26040649, 10.06514072], [76.26013947, 10.06514072], [76.26013947, 10.06431103], [76.26069641, 10.06430435], [76.26069641, 10.06458473], [76.26125336, 10.06457996], [76.26125336, 10.06514072], [76.2618103, 10.06514072], [76.2618103, 10.0654211], [76.26207733, 10.0654211], [76.26207733, 10.06653118], [76.26291656, 10.06652641], [76.26291656, 10.06708336], [76.26403046, 10.06707954], [76.26403046, 10.06764126], [76.26431274, 10.06764126], [76.26431274, 10.06792068], [76.26541901, 10.06792068], [76.26541901, 10.06764126], [76.26568604, 10.06764126], [76.26568604, 10.06707954], [76.26597595, 10.06708336], [76.26597595, 10.06680679], [76.26680756, 10.06680679], [76.26680756, 10.06708336], [76.26708221, 10.06707954], [76.26708221, 10.06764126], [76.26680756, 10.06763935], [76.26680756, 10.06819534], [76.26652527, 10.06819534], [76.26652527, 10.06875134], [76.26625061, 10.06875134], [76.26625061, 10.06930542], [76.26652527, 10.06930542], [76.26652527, 10.06986141], [76.26680756, 10.06986141], [76.26680756, 10.07014084], [76.26708221, 10.07013893], [76.26708221, 10.0709734], [76.26680756, 10.07097054], [76.26680756, 10.07181168], [76.26457977, 10.07181168], [76.26457977, 10.0715313], [76.26403046, 10.0715313], [76.26403046, 10.07125092], [76.26374817, 10.07125092], [76.26374817, 10.07097054], [76.26347351, 10.0709734], [76.26347351, 10.07069492], [76.26319122, 10.07069492], [76.26319122, 10.0709734], [76.26291656, 10.0709734], [76.26291656, 10.07069492], [76.26180267, 10.07069492], [76.26180267, 10.0704174], [76.26152802, 10.07041931], [76.26152802, 10.07014084], [76.26097107, 10.07013893], [76.26097107, 10.0709734], [76.26125336, 10.07097054], [76.26125336, 10.0715313], [76.26235962, 10.0715313], [76.26235962, 10.07181168], [76.26207733, 10.07181168], [76.26207733, 10.07264137], [76.2618103, 10.07264137], [76.26180267, 10.07374859], [76.26152802, 10.07375145], [76.26152802, 10.0743103], [76.26125336, 10.07430458], [76.26125336, 10.07486057], [76.26097107, 10.07486057], [76.26097107, 10.07543087], [76.26069641, 10.07541656], [76.26069641, 10.07597256], [76.26040649, 10.07597065], [76.26040649, 10.07681179], [76.26013947, 10.07680511], [76.26013947, 10.07708263], [76.25985718, 10.07708073], [76.25985718, 10.07791996], [76.25958252, 10.07791996], [76.25958252, 10.07903194], [76.25930786, 10.07903194], [76.25930786, 10.07931042], [76.25902557, 10.07930565], [76.25902557, 10.07986164], [76.25875092, 10.07986164], [76.25875092, 10.0806942], [76.25846863, 10.0806942], [76.25846863, 10.08125019], [76.25818634, 10.08124065], [76.25818634, 10.08181], [76.25791931, 10.08180618], [76.25791931, 10.0820837], [76.25763702, 10.0820837], [76.25763702, 10.08319378], [76.25736237, 10.08319378], [76.25736237, 10.08458424], [76.25791931, 10.08458424], [76.25791931, 10.08485985], [76.25818634, 10.08485985], [76.25818634, 10.08514023], [76.25875092, 10.08514023], [76.25875092, 10.08485985], [76.25902557, 10.08485985], [76.25902557, 10.08458424], [76.25930786, 10.08458424], [76.25930786, 10.08430576], [76.25958252, 10.08430576], [76.25958252, 10.08402824], [76.25985718, 10.08403015], [76.25985718, 10.08319092], [76.26013947, 10.08319378], [76.26013947, 10.08236217], [76.26041412, 10.08236217], [76.26041412, 10.08152771], [76.26069641, 10.08152962], [76.26069641, 10.08124065], [76.26097107, 10.08125019], [76.26097107, 10.08097172], [76.26125336, 10.08097172], [76.26125336, 10.07902718], [76.26152802, 10.07903194], [76.26152802, 10.07875156], [76.26207733, 10.07875156], [76.26207733, 10.07846928], [76.26235962, 10.07847118], [76.26235962, 10.07819557], [76.26291656, 10.07820034], [76.26291656, 10.07791996], [76.26264191, 10.07791996], [76.26264191, 10.07653046], [76.26403046, 10.07653046], [76.26403046, 10.07597065], [76.26430511, 10.07597256], [76.26430511, 10.07541656], [76.26457977, 10.07543087], [76.26457977, 10.07486057], [76.26486206, 10.07486057], [76.26486206, 10.07430458], [76.26513672, 10.0743103], [76.26513672, 10.07347107], [76.26486206, 10.07347107], [76.26486206, 10.07263947], [76.26513672, 10.07264137], [76.26513672, 10.07291889], [76.26569366, 10.07291698], [76.26569366, 10.07319546], [76.26625061, 10.07319546], [76.26625061, 10.07458305], [76.26597595, 10.07458115], [76.26597595, 10.07514191], [76.26569366, 10.07513905], [76.26569366, 10.07569313], [76.26597595, 10.07569313], [76.26597595, 10.07597256], [76.26568604, 10.07597065], [76.26568604, 10.07625198], [76.26541901, 10.07625198], [76.26541901, 10.07681179], [76.26513672, 10.07680511], [76.26513672, 10.07708263], [76.26486206, 10.07708263], [76.26486206, 10.07736111], [76.26457977, 10.0773592], [76.26457977, 10.07931042], [76.26430511, 10.07930565], [76.26430511, 10.07986164], [76.26403046, 10.07986164], [76.26403046, 10.08014202], [76.26374817, 10.08014202], [76.26374817, 10.08041954], [76.26347351, 10.08041763], [76.26347351, 10.0806942], [76.26319122, 10.08069134], [76.26319122, 10.08152962], [76.26291656, 10.08152962], [76.26291656, 10.08181], [76.26264191, 10.08180618], [76.26264191, 10.0820837], [76.26235962, 10.0820837], [76.26235962, 10.08236217], [76.26208496, 10.08236217], [76.26208496, 10.08319378], [76.26180267, 10.08319378], [76.26180267, 10.08347225], [76.26152802, 10.08347034], [76.26152802, 10.08374977], [76.26125336, 10.08374977], [76.26125336, 10.08430576], [76.26097107, 10.08430576], [76.26097107, 10.08569431], [76.26069641, 10.08569431], [76.26069641, 10.08625031], [76.26013947, 10.08625031], [76.26013947, 10.08652973], [76.25930786, 10.08652973], [76.25930786, 10.08681107], [76.2590332, 10.08681107], [76.2590332, 10.08764267], [76.25930786, 10.08764267], [76.25930786, 10.08792114], [76.25958252, 10.08791637], [76.25958252, 10.08819389], [76.25985718, 10.08819199], [76.25985718, 10.08931065], [76.25958252, 10.08931065], [76.25958252, 10.0901413], [76.25930786, 10.09013844], [76.25930786, 10.09069443], [76.25902557, 10.09069443], [76.2590332, 10.09125042], [76.25818634, 10.09125042], [76.25818634, 10.09068966], [76.25791931, 10.09069443], [76.25791931, 10.08958435], [76.25763702, 10.08958435], [76.25763702, 10.08819389], [76.25791931, 10.08819389], [76.25791931, 10.08791637], [76.25818634, 10.08792114], [76.25818634, 10.08764267], [76.25846863, 10.08764267], [76.25846863, 10.08708191], [76.25819397, 10.08708191], [76.25819397, 10.08625031], [76.25791931, 10.08625031], [76.25791931, 10.08569431], [76.25763702, 10.08569431], [76.25763702, 10.08541584], [76.25736237, 10.08541965], [76.25736237, 10.08514023], [76.25708008, 10.08514023], [76.25708008, 10.08541965], [76.25624847, 10.08541584], [76.25624847, 10.08708191], [76.25597382, 10.08708191], [76.25597382, 10.08652782], [76.25567627, 10.08652973], [76.25567627, 10.08568859], [76.25541687, 10.08569431], [76.25541687, 10.08485985], [76.25514221, 10.08485985], [76.25514221, 10.08430576], [76.25485992, 10.08430576], [76.25485992, 10.08374977], [76.25430298, 10.08374977], [76.25430298, 10.08347034], [76.2529068, 10.08347034], [76.2529068, 10.08374977], [76.25263977, 10.08374977], [76.25263977, 10.08458424], [76.25235748, 10.08457947], [76.25235748, 10.08514023], [76.25208282, 10.08514023], [76.25208282, 10.08541965], [76.25235748, 10.08541965], [76.25235748, 10.08737087], [76.25347137, 10.08737087], [76.25347137, 10.08875275], [76.25319672, 10.08875275], [76.25319672, 10.08931065], [76.2529068, 10.08931065], [76.2529068, 10.08819199], [76.25263977, 10.08819389], [76.25263977, 10.0876379], [76.25152588, 10.08764267], [76.25152588, 10.08792114], [76.25096893, 10.08791637], [76.25096893, 10.08819389], [76.25068665, 10.08819199], [76.25068665, 10.08903122], [76.25096893, 10.08903122], [76.25096893, 10.0901413], [76.25125122, 10.09013844], [76.25125122, 10.09069443], [76.25152588, 10.09069443], [76.25152588, 10.09125042], [76.25235748, 10.09125042], [76.25235748, 10.0915308], [76.25263977, 10.09152889], [76.25263977, 10.09208202], [76.25235748, 10.09208012], [76.25235748, 10.09264088], [76.25208282, 10.09263802], [76.25208282, 10.09319496], [76.25180817, 10.09319496], [76.25180817, 10.09347343], [76.25125122, 10.09346962], [76.25125122, 10.09375095], [76.25096893, 10.09375095], [76.25096893, 10.09403133], [76.25041962, 10.09402561], [76.25041962, 10.09458256], [76.25013733, 10.0945797], [76.25013733, 10.09514141], [76.24986267, 10.09513855], [76.24986267, 10.09597301], [76.24958038, 10.09597301], [76.24958038, 10.09541702], [76.24931335, 10.09542084], [76.24931335, 10.09514141], [76.24764252, 10.09513855], [76.24764252, 10.09597301], [76.24791718, 10.09597301], [76.24791718, 10.09708309], [76.24847412, 10.09708309], [76.24847412, 10.09736061], [76.24874878, 10.09736061], [76.24874878, 10.09819508], [76.24846649, 10.09819031], [76.24846649, 10.09875107], [76.24819183, 10.09875107], [76.24819183, 10.09903145], [76.24791718, 10.09903145], [76.24791718, 10.09931183], [76.24764252, 10.09930515], [76.24764252, 10.09958267], [76.24736023, 10.09958267], [76.24736023, 10.09986115], [76.2470932, 10.09986115], [76.2470932, 10.10014057], [76.24597168, 10.10014057], [76.24597168, 10.10042191], [76.24624634, 10.10041714], [76.24624634, 10.10097313], [76.24652863, 10.10097122], [76.24652863, 10.10125065], [76.24569702, 10.10125065], [76.24569702, 10.10181046], [76.24541473, 10.10180473], [76.24541473, 10.10208321], [76.24514008, 10.1020813], [76.24514008, 10.1026392], [76.24208069, 10.1026392], [76.24208069, 10.10402966], [76.24318695, 10.10402966], [76.24318695, 10.10431004], [76.24346924, 10.10430527], [76.24346924, 10.10486126], [76.24236298, 10.10485935], [76.24236298, 10.10513973], [76.24180603, 10.10513973], [76.24180603, 10.10541534], [76.24208069, 10.10541534], [76.24208069, 10.10597134], [76.24236298, 10.10597134], [76.24236298, 10.10653019], [76.24124908, 10.10652828], [76.24124908, 10.10708427], [76.2409668, 10.10708141], [76.2409668, 10.10764027], [76.24124908, 10.10764027], [76.24124908, 10.10875034], [76.24067688, 10.10875034], [76.24067688, 10.10847187], [76.24041748, 10.10847187], [76.24041748, 10.10819435], [76.23930359, 10.10819435], [76.23930359, 10.10847187], [76.23902893, 10.10847187], [76.23902893, 10.10902977], [76.23930359, 10.10902786], [76.23930359, 10.10958385], [76.23958588, 10.10958195], [76.23958588, 10.11013985], [76.23986053, 10.11013985], [76.23986053, 10.11042023], [76.23847198, 10.11041641], [76.23847198, 10.11069393], [76.23819733, 10.11069393], [76.23819733, 10.1109724], [76.2379303, 10.11096954], [76.2379303, 10.11124992], [76.23902893, 10.11124992], [76.23902893, 10.11154175], [76.23874664, 10.1115284], [76.23874664, 10.11208439], [76.23847198, 10.11208439], [76.23847198, 10.11236], [76.23819733, 10.11236], [76.23819733, 10.11180592], [76.23680878, 10.11181068], [76.23680878, 10.11264038], [76.23707581, 10.11264038], [76.23708344, 10.11375046], [76.23680878, 10.11375046], [76.23680878, 10.11403275], [76.23486328, 10.11403275], [76.23486328, 10.11292267], [76.23374939, 10.11291599], [76.23374939, 10.11347198], [76.2334671, 10.11347198], [76.2334671, 10.11403275], [76.23179626, 10.11403275], [76.23179626, 10.11347198], [76.23124695, 10.11347198], [76.23124695, 10.11375046], [76.23097229, 10.11375046], [76.23097229, 10.11403275], [76.23041534, 10.11402798], [76.23041534, 10.11458206], [76.23014069, 10.11458015], [76.23014069, 10.1154213], [76.23041534, 10.11541557], [76.23041534, 10.11597157], [76.23014069, 10.11596966], [76.23014069, 10.11625004], [76.22902679, 10.11625004], [76.22902679, 10.11680889], [76.22875214, 10.11680603], [76.22875214, 10.11736012], [76.22846985, 10.11735058], [76.22846985, 10.11792088], [76.22875214, 10.11791611], [76.22875214, 10.1184721], [76.22846985, 10.11847019], [76.22846985, 10.11903095], [76.22820282, 10.11903095], [76.22820282, 10.11931133], [76.2279129, 10.11931133], [76.2279129, 10.12014103], [76.22819519, 10.12013912], [76.22819519, 10.12069511], [76.22875214, 10.12069511], [76.22875214, 10.12097263], [76.23124695, 10.12096977], [76.23124695, 10.12153053], [76.23097229, 10.12153053], [76.23097229, 10.12181091], [76.23069763, 10.12180519], [76.23069763, 10.12208271], [76.22819519, 10.12208271], [76.22819519, 10.12236118], [76.2279129, 10.12236118], [76.2279129, 10.12264061], [76.22735596, 10.12264061], [76.22735596, 10.12375069], [76.22846985, 10.12374878], [76.22846985, 10.12486076], [76.22820282, 10.12485886], [76.22820282, 10.12514114], [76.2279129, 10.12514114], [76.2279129, 10.12542152], [76.22763824, 10.12541676], [76.22763824, 10.12625122], [76.22735596, 10.12625122], [76.22735596, 10.12654114], [76.2270813, 10.12654114], [76.2270813, 10.12681198], [76.22680664, 10.12680531], [76.22680664, 10.12708282], [76.22569275, 10.12708282], [76.22569275, 10.12680531], [76.2259903, 10.12681198], [76.2259903, 10.12625122], [76.22624969, 10.12625122], [76.22624969, 10.12569523], [76.2270813, 10.12569523], [76.2270813, 10.12541676], [76.22735596, 10.12542152], [76.22735596, 10.12514114], [76.22763824, 10.12514114], [76.22763824, 10.12485886], [76.22736359, 10.12486076], [76.22736359, 10.12458324], [76.22680664, 10.12458324], [76.22680664, 10.12486076], [76.22651672, 10.12485886], [76.22651672, 10.12514114], [76.22570038, 10.12514114], [76.22570038, 10.12485886], [76.22541809, 10.12486076], [76.22541809, 10.12402916], [76.22570038, 10.12403107], [76.22570038, 10.12347984], [76.2259903, 10.12347984], [76.2259903, 10.12264061], [76.22624969, 10.12264061], [76.22624969, 10.12236118], [76.22652435, 10.12236118], [76.22652435, 10.12208271], [76.22680664, 10.12208271], [76.22680664, 10.12180519], [76.2270813, 10.12181091], [76.2270813, 10.12153053], [76.22763824, 10.12153053], [76.22763824, 10.12125111], [76.2279129, 10.12125111], [76.2279129, 10.12041664], [76.2270813, 10.12041664], [76.2270813, 10.12013912], [76.22735596, 10.12014103], [76.22735596, 10.11958027], [76.22763824, 10.11958218], [76.22763824, 10.11902905], [76.2279129, 10.11903095], [76.2279129, 10.11764145], [76.22820282, 10.11764145], [76.22820282, 10.11707973], [76.22846985, 10.11708355], [76.22846985, 10.11652756], [76.22873688, 10.11653137], [76.22873688, 10.11569023], [76.22902679, 10.11569405], [76.22902679, 10.11541557], [76.22930908, 10.1154213], [76.22930908, 10.11458015], [76.22902679, 10.11458206], [76.22902679, 10.11375046], [76.22930908, 10.11375046], [76.22930908, 10.11347198], [76.2298584, 10.11347198], [76.2298584, 10.11375046], [76.23014069, 10.11375046], [76.23014069, 10.11347198], [76.23069763, 10.11347198], [76.23069763, 10.11263847], [76.23124695, 10.11264038], [76.23124695, 10.11207962], [76.23152924, 10.11208439], [76.23152924, 10.1115284], [76.23458099, 10.11154175], [76.23458099, 10.11124992], [76.23486328, 10.11124992], [76.23486328, 10.11096954], [76.23513794, 10.1109724], [76.23513794, 10.10958385], [76.23542023, 10.10958385], [76.23542023, 10.10819435], [76.23430634, 10.10818005], [76.23430634, 10.10902977], [76.23402405, 10.10902786], [76.23402405, 10.10986233], [76.23374939, 10.10986233], [76.23374939, 10.10958385], [76.23264313, 10.10958195], [76.23264313, 10.11013985], [76.23236084, 10.11013985], [76.23236084, 10.1109724], [76.23124695, 10.1109724], [76.23124695, 10.11069393], [76.23097229, 10.11069393], [76.23097229, 10.10958385], [76.23124695, 10.10958385], [76.23124695, 10.10902786], [76.23152924, 10.10902977], [76.23152924, 10.10847187], [76.23180389, 10.10847187], [76.23180389, 10.10791779], [76.23208618, 10.10791969], [76.23208618, 10.10736179], [76.23236084, 10.10736179], [76.23236084, 10.10653019], [76.23264313, 10.10653019], [76.23264313, 10.10541058], [76.23291779, 10.10541534], [76.23291779, 10.10486126], [76.23319244, 10.10486126], [76.23319244, 10.10402679], [76.2334671, 10.10402966], [76.2334671, 10.1026392], [76.23374939, 10.1026392], [76.23374939, 10.1020813], [76.23402405, 10.10208321], [76.23402405, 10.10069466], [76.23430634, 10.10069466], [76.23430634, 10.09986115], [76.23458099, 10.09986115], [76.23458099, 10.09875107], [76.23486328, 10.09875107], [76.23486328, 10.09847069], [76.23513794, 10.0984726], [76.23513794, 10.09763908], [76.23542023, 10.09764099], [76.23542023, 10.09708118], [76.23569489, 10.09708309], [76.23569489, 10.09624863], [76.23596954, 10.09624863], [76.23596954, 10.09569454], [76.23625183, 10.09569454], [76.23625183, 10.09541702], [76.23652649, 10.09542084], [76.23652649, 10.09486103], [76.23680878, 10.09486103], [76.23680878, 10.09319496], [76.23708344, 10.09319496], [76.23708344, 10.09208202], [76.23680878, 10.09208202], [76.23680878, 10.09152889], [76.23652649, 10.0915308], [76.23652649, 10.09125042], [76.23680878, 10.09125042], [76.23680878, 10.09097195], [76.23735809, 10.09097195], [76.23735809, 10.09069443], [76.23764038, 10.09069443], [76.23764038, 10.09041595], [76.2379303, 10.09043026], [76.2379303, 10.08931065], [76.23819733, 10.08931065], [76.23819733, 10.08875275], [76.23847198, 10.08875275], [76.23847198, 10.08819199], [76.23874664, 10.08819389], [76.23874664, 10.08791637], [76.23902893, 10.08792114], [76.23902893, 10.08708191], [76.23930359, 10.08708191], [76.23930359, 10.08652782], [76.23958588, 10.08652973], [76.23958588, 10.08514023], [76.23986053, 10.08514023], [76.23986053, 10.08403015], [76.24014282, 10.08403015], [76.24014282, 10.08263969], [76.24041748, 10.08263969], [76.24041748, 10.08181], [76.24067688, 10.08181], [76.24067688, 10.08069134], [76.24097443, 10.0806942], [76.24097443, 10.08014011], [76.24124908, 10.08014202], [76.24124908, 10.07958126], [76.24153137, 10.07958412], [76.24153137, 10.07930565], [76.24180603, 10.07931042], [76.24180603, 10.07763863], [76.24208069, 10.07763863], [76.24208069, 10.07708073], [76.24236298, 10.07708263], [76.24236298, 10.07624912], [76.24263763, 10.07625198], [76.24263763, 10.07543087], [76.24236298, 10.07543087], [76.24236298, 10.07486057], [76.24208069, 10.07486057], [76.24208069, 10.07458305], [76.23986053, 10.07458305], [76.23986053, 10.07486057], [76.23958588, 10.07486057], [76.23958588, 10.07514191], [76.23930359, 10.07513905], [76.23930359, 10.07569313], [76.23902893, 10.07569313], [76.23902893, 10.07597256], [76.23874664, 10.07597065], [76.23874664, 10.07653046], [76.23847198, 10.07652664], [76.23847198, 10.07708263], [76.23819733, 10.07708263], [76.23819733, 10.07736111], [76.23791504, 10.07736111], [76.23791504, 10.07847118], [76.23764038, 10.07846928], [76.23764038, 10.07903194], [76.23735809, 10.07902718], [76.23735809, 10.07958412], [76.23680878, 10.07958412], [76.23680878, 10.07986164], [76.23652649, 10.07986164], [76.23652649, 10.08041954], [76.23625183, 10.08041763], [76.23625183, 10.0806942], [76.23652649, 10.0806942], [76.23652649, 10.08097172], [76.23625183, 10.08096886], [76.23625183, 10.08152962], [76.23596954, 10.08152962], [76.23596954, 10.08181], [76.23568726, 10.08181], [76.23568726, 10.08292007], [76.23542023, 10.08292007], [76.23542023, 10.08374977], [76.23486328, 10.08374977], [76.23486328, 10.08403015], [76.23458099, 10.08402824], [76.23458099, 10.08430576], [76.23430634, 10.08430576], [76.23430634, 10.08485985], [76.23402405, 10.08485985], [76.23402405, 10.08569431], [76.23374939, 10.08569431], [76.23374939, 10.08625031], [76.23401642, 10.08625031], [76.23401642, 10.08764267], [76.23374939, 10.08764267], [76.23374939, 10.08792114], [76.23319244, 10.08791637], [76.23319244, 10.08819389], [76.23291779, 10.08819199], [76.23291779, 10.08875275], [76.23264313, 10.08875275], [76.23264313, 10.08903122], [76.23236084, 10.08903122], [76.23236084, 10.08931065], [76.23208618, 10.08930588], [76.23208618, 10.08958435], [76.23152924, 10.08957958], [76.23152924, 10.0901413], [76.23124695, 10.09013844], [76.23124695, 10.09097195], [76.23097229, 10.09097004], [76.23097229, 10.0915308], [76.23069763, 10.0915308], [76.23069763, 10.09181118], [76.23041534, 10.09180355], [76.23041534, 10.09208202], [76.23014069, 10.09208012], [76.23014069, 10.09264088], [76.2298584, 10.09264088], [76.2298584, 10.09403133], [76.23014069, 10.09403133], [76.23014069, 10.09514141], [76.2298584, 10.09514141], [76.2298584, 10.09542084], [76.22958374, 10.09541702], [76.22958374, 10.09597301], [76.22930908, 10.09597301], [76.22930908, 10.09624863], [76.23041534, 10.09624863], [76.23041534, 10.09597301], [76.23069763, 10.09597301], [76.23069763, 10.09569454], [76.23097229, 10.09569454], [76.23097229, 10.09541702], [76.23124695, 10.09542084], [76.23124695, 10.09514141], [76.23152924, 10.09514141], [76.23152924, 10.0945797], [76.23180389, 10.09458256], [76.23180389, 10.09402561], [76.23097229, 10.09403133], [76.23097229, 10.09292126], [76.23180389, 10.09291744], [76.23180389, 10.09347343], [76.23208618, 10.09346962], [76.23208618, 10.09430885], [76.23347473, 10.09430695], [76.23347473, 10.09458256], [76.23319244, 10.0945797], [76.23319244, 10.09514141], [76.23264313, 10.09514141], [76.23264313, 10.09542084], [76.23236084, 10.09541702], [76.23236084, 10.09569454], [76.23180389, 10.09569454], [76.23180389, 10.09597301], [76.23152924, 10.09597301], [76.23152924, 10.09624863], [76.23124695, 10.09624195], [76.23124695, 10.09680939], [76.23097229, 10.09680462], [76.23097229, 10.09736061], [76.23069763, 10.09736061], [76.23069763, 10.09792233], [76.22846985, 10.0979166], [76.22846985, 10.0984726], [76.22820282, 10.09847069], [76.22820282, 10.09903145], [76.22846985, 10.09902668], [76.22846985, 10.10097313], [76.22820282, 10.10097122], [76.22820282, 10.10181046], [76.2279129, 10.10181046], [76.2279129, 10.10237026], [76.2270813, 10.10237026], [76.2270813, 10.10181046], [76.22680664, 10.10181046], [76.22680664, 10.10153198], [76.2259903, 10.10153198], [76.2259903, 10.10125065], [76.22541809, 10.10125065], [76.22541809, 10.10097122], [76.22569275, 10.10097313], [76.22569275, 10.10041714], [76.2259903, 10.10042191], [76.2259903, 10.09986115], [76.22624969, 10.09986115], [76.22624969, 10.09958267], [76.22652435, 10.09958267], [76.22652435, 10.09902668], [76.22680664, 10.09903145], [76.22680664, 10.09847069], [76.22736359, 10.0984726], [76.22736359, 10.09819508], [76.2270813, 10.09819508], [76.2270813, 10.0979166], [76.22735596, 10.09792233], [76.22735596, 10.09764099], [76.22763824, 10.09764099], [76.22763824, 10.09680939], [76.2279129, 10.09680939], [76.2279129, 10.09653091], [76.22873688, 10.09653091], [76.22873688, 10.09624195], [76.22846985, 10.09624863], [76.22846985, 10.09597301], [76.22875214, 10.09597301], [76.22875214, 10.09569454], [76.22902679, 10.09569454], [76.22902679, 10.09458256], [76.22819519, 10.09458256], [76.22819519, 10.09430695], [76.22763824, 10.09430695], [76.22763824, 10.09458256], [76.2270813, 10.0945797], [76.2270813, 10.09514141], [76.22680664, 10.09514141], [76.22680664, 10.09542084], [76.22652435, 10.09541702], [76.22652435, 10.09624863], [76.22624969, 10.09624195], [76.22624969, 10.09653091], [76.22597504, 10.09652901], [76.22597504, 10.09708309], [76.22569275, 10.09708309], [76.22569275, 10.09736061], [76.22541809, 10.09736061], [76.22541809, 10.09792233], [76.22486115, 10.0979166], [76.22486115, 10.0984726], [76.22429657, 10.09847069], [76.22429657, 10.09875107], [76.22402954, 10.09875107], [76.22402954, 10.09986115], [76.22374725, 10.09986115], [76.22374725, 10.10014057], [76.2234726, 10.10013866], [76.2234726, 10.10069466], [76.22319794, 10.10069084], [76.22319794, 10.10181046], [76.22291565, 10.10180473], [76.22291565, 10.10208321], [76.2223587, 10.1020813], [76.2223587, 10.10291958], [76.22208405, 10.10291672], [76.22208405, 10.1034708], [76.22180939, 10.10347366], [76.22180176, 10.10374928], [76.2215271, 10.10374928], [76.2215271, 10.10431004], [76.22125244, 10.10430527], [76.22125244, 10.10486126], [76.22097015, 10.10485935], [76.22097015, 10.10513973], [76.2206955, 10.10513973], [76.2206955, 10.10569572], [76.22041321, 10.10569572], [76.22041321, 10.10597134], [76.22013855, 10.10597134], [76.22013855, 10.10653019], [76.21985626, 10.10653019], [76.21985626, 10.10680962], [76.2195816, 10.1068058], [76.2195816, 10.10708427], [76.21930695, 10.10708141], [76.21930695, 10.10736179], [76.21901703, 10.10736179], [76.21901703, 10.10791969], [76.21875, 10.10791779], [76.21875, 10.10847187], [76.21848297, 10.10847187], [76.21848297, 10.10902977], [76.21819305, 10.10902786], [76.21819305, 10.10958385], [76.2179184, 10.10958385], [76.2179184, 10.10986233], [76.21763611, 10.10986042], [76.21763611, 10.11013985], [76.21736145, 10.11013985], [76.21736145, 10.11069393], [76.21708679, 10.11069202], [76.21708679, 10.11124992], [76.21679688, 10.11124992], [76.21679688, 10.11181068], [76.21624756, 10.11180592], [76.21624756, 10.11236], [76.2159729, 10.11236], [76.2159729, 10.11264038], [76.21569824, 10.11264038], [76.21569824, 10.11292267], [76.2159729, 10.11291599], [76.2159729, 10.11319447], [76.21624756, 10.11319447], [76.21624756, 10.11569405], [76.21847534, 10.11569405], [76.21847534, 10.11541557], [76.21875, 10.1154213], [76.21875, 10.11485958], [76.21902466, 10.11486244], [76.21902466, 10.11430645], [76.21930695, 10.11431122], [76.21930695, 10.11403275], [76.21901703, 10.11403275], [76.21901703, 10.11375046], [76.21847534, 10.11375046], [76.21847534, 10.11347198], [76.2179184, 10.11347198], [76.2179184, 10.11319447], [76.21819305, 10.11319447], [76.21819305, 10.11263847], [76.21875, 10.11264038], [76.21875, 10.11236], [76.21902466, 10.11236], [76.21901703, 10.11181068], [76.21930695, 10.11181068], [76.21930695, 10.11124992], [76.21956635, 10.11124992], [76.21956635, 10.11069202], [76.21986389, 10.11069393], [76.21986389, 10.11041641], [76.22013855, 10.11042023], [76.22013855, 10.10986042], [76.22041321, 10.10986233], [76.22041321, 10.10930634], [76.22070313, 10.10931015], [76.22070313, 10.10902977], [76.22097015, 10.10902977], [76.22097015, 10.10847187], [76.22125244, 10.10847187], [76.22125244, 10.10791779], [76.2215271, 10.10791969], [76.2215271, 10.10736179], [76.22180176, 10.10736179], [76.22180176, 10.10680962], [76.22207642, 10.10680962], [76.22207642, 10.10624886], [76.2223587, 10.10624886], [76.2223587, 10.10597134], [76.22264099, 10.10597134], [76.22264099, 10.10541534], [76.22291565, 10.10541534], [76.22291565, 10.10458279], [76.22319794, 10.10458279], [76.22319794, 10.10430527], [76.2234726, 10.10431004], [76.2234726, 10.10402966], [76.22374725, 10.10402966], [76.22374725, 10.10346889], [76.22429657, 10.10346889], [76.22429657, 10.10374928], [76.22458649, 10.10374928], [76.22458649, 10.10402966], [76.22429657, 10.10402966], [76.22429657, 10.10431004], [76.22402954, 10.10430527], [76.22402954, 10.10458279], [76.22374725, 10.10458279], [76.22374725, 10.10486126], [76.2234726, 10.10485935], [76.2234726, 10.10513973], [76.22374725, 10.10513973], [76.22374725, 10.10541534], [76.22402954, 10.10541534], [76.22402954, 10.10569572], [76.2243042, 10.10569572], [76.2243042, 10.10597134], [76.22402954, 10.10597134], [76.22402954, 10.10764027], [76.22319794, 10.10764027], [76.22319794, 10.10875034], [76.2234726, 10.10875034], [76.2234726, 10.10902977], [76.22374725, 10.10902977], [76.22374725, 10.10931015], [76.22486115, 10.10931015], [76.22486115, 10.10902977], [76.22541809, 10.10902977], [76.22541809, 10.10931015], [76.22624969, 10.10931015], [76.22624969, 10.11013985], [76.2259903, 10.11013985], [76.2259903, 10.11042023], [76.22570038, 10.11042023], [76.22570038, 10.11124992], [76.22541809, 10.11124992], [76.22541809, 10.11154175], [76.2251358, 10.11154175], [76.2251358, 10.11181068], [76.22458649, 10.11180592], [76.22458649, 10.11208439], [76.2243042, 10.11208439], [76.2243042, 10.11319447], [76.22402954, 10.11319447], [76.22402954, 10.11347198], [76.22374725, 10.11347198], [76.22374725, 10.11375046], [76.2234726, 10.11375046], [76.2234726, 10.11403275], [76.22319794, 10.11403275], [76.22319794, 10.11431122], [76.22291565, 10.11430645], [76.22291565, 10.11458206], [76.22264099, 10.11458206], [76.22264099, 10.11486244], [76.2223587, 10.11485958], [76.2223587, 10.1154213], [76.22208405, 10.11541557], [76.22208405, 10.11569405], [76.22180939, 10.11569405], [76.22180176, 10.11597157], [76.2215271, 10.11596966], [76.2215271, 10.11625004], [76.2223587, 10.11625004], [76.2223587, 10.11653137], [76.22319794, 10.11653137], [76.22319794, 10.11680889], [76.2234726, 10.11680603], [76.2234726, 10.11736012], [76.22319794, 10.11735058], [76.22319794, 10.11875057], [76.22291565, 10.11875057], [76.22291565, 10.11958218], [76.22264099, 10.11958218], [76.22264099, 10.12041664], [76.2223587, 10.12041664], [76.2223587, 10.12125111], [76.22207642, 10.12125111], [76.22207642, 10.12264061], [76.22180939, 10.1226387], [76.22180176, 10.12319469], [76.2215271, 10.12318993], [76.2215271, 10.12375069], [76.22125244, 10.12375069], [76.22125244, 10.12403107], [76.2215271, 10.12402916], [76.2215271, 10.12486076], [76.22125244, 10.12486076], [76.22125244, 10.12569523], [76.22097015, 10.12569523], [76.22097015, 10.12625122], [76.22070313, 10.12625122], [76.22070313, 10.12654114], [76.22041321, 10.12652683], [76.22041321, 10.12708282], [76.22013855, 10.12708282], [76.22013855, 10.1273613], [76.21985626, 10.1273613], [76.21985626, 10.12764072], [76.21956635, 10.12764072], [76.21956635, 10.12792015], [76.21930695, 10.12791729], [76.21930695, 10.12819481], [76.21901703, 10.12819099], [76.21902466, 10.12874889], [76.21875, 10.12874889], [76.21875, 10.12902927], [76.21848297, 10.12902927], [76.21848297, 10.12930965], [76.21819305, 10.12930965], [76.21819305, 10.13013935], [76.21763611, 10.13013935], [76.21763611, 10.13041973], [76.21736145, 10.13041687], [76.21736145, 10.13069534], [76.21708679, 10.13069534], [76.21708679, 10.13097095], [76.21652985, 10.13097095], [76.21652985, 10.13124943], [76.2159729, 10.13124943], [76.2159729, 10.13097095], [76.21347046, 10.13097095], [76.21347046, 10.13069534], [76.2131958, 10.13069534], [76.2131958, 10.13097095], [76.21290588, 10.13097095], [76.21291351, 10.13124943], [76.21263885, 10.13124943], [76.21263885, 10.13181019], [76.21235657, 10.13181019], [76.21235657, 10.13264179], [76.21208191, 10.13263988], [76.21208191, 10.13319302], [76.21180725, 10.13319588], [76.21180725, 10.13347054], [76.21151733, 10.13347054], [76.21151733, 10.13375187], [76.21125031, 10.13375187], [76.21125031, 10.13347054], [76.21098328, 10.13347054], [76.21098328, 10.13375187], [76.21069336, 10.13374996], [76.21069336, 10.13458443], [76.21125031, 10.13458443], [76.21125031, 10.13569355], [76.21069336, 10.13569355], [76.21069336, 10.13513756], [76.2104187, 10.13514042], [76.2104187, 10.13486195], [76.20762634, 10.13486195], [76.20762634, 10.13514042], [76.20735931, 10.13513756], [76.20735931, 10.13569355], [76.2076416, 10.13569355], [76.2076416, 10.13597202], [76.20791626, 10.13597202], [76.20791626, 10.13624954], [76.20874786, 10.13624954], [76.20874786, 10.13652992], [76.20929718, 10.13652992], [76.20929718, 10.1368103], [76.2095871, 10.13680553], [76.2095871, 10.13708401], [76.21069336, 10.13708401], [76.21069336, 10.13736153], [76.21098328, 10.13735962], [76.21098328, 10.13764], [76.21125031, 10.13764], [76.21125031, 10.13792038], [76.21208191, 10.13791561], [76.21208191, 10.13819408], [76.21235657, 10.13818932], [76.21235657, 10.13848114], [76.21263885, 10.13848114], [76.21263885, 10.13931274], [76.21208191, 10.13930607], [76.21208191, 10.13958359], [76.21180725, 10.13958168], [76.21180725, 10.14042091], [76.21208191, 10.14042091], [76.21208191, 10.14264011], [76.21180725, 10.14263821], [76.21180725, 10.1431942], [76.21152496, 10.1431942], [76.21152496, 10.14347172], [76.21125031, 10.14347172], [76.21125031, 10.14375019], [76.21070099, 10.14375019], [76.21070099, 10.14403057], [76.20986176, 10.14403057], [76.20986176, 10.14431095], [76.20930481, 10.14430428], [76.20930481, 10.14458466], [76.20791626, 10.14458466], [76.20791626, 10.14486027], [76.20762634, 10.14486027], [76.20762634, 10.14514065], [76.20735931, 10.14514065], [76.20735931, 10.14542103], [76.20680237, 10.14542103], [76.20680237, 10.14625072], [76.20652771, 10.14625072], [76.20652771, 10.14708233], [76.20569611, 10.14708233], [76.20569611, 10.14680672], [76.20540619, 10.14681053], [76.20540619, 10.14625072], [76.20569611, 10.14625072], [76.20569611, 10.14542103], [76.20540619, 10.14542103], [76.20540619, 10.14486027], [76.20513916, 10.14486027], [76.20513916, 10.14458466], [76.2048645, 10.14458466], [76.2048645, 10.14430428], [76.20541382, 10.14430428], [76.20541382, 10.14458466], [76.20569611, 10.14458466], [76.20569611, 10.14486027], [76.20625305, 10.14486027], [76.20625305, 10.14430428], [76.20652771, 10.14431095], [76.20652771, 10.14375019], [76.20625305, 10.14375019], [76.20625305, 10.14347172], [76.20597076, 10.14347172], [76.20597076, 10.14235973], [76.20569611, 10.14235973], [76.20569611, 10.14097214], [76.20402527, 10.14097214], [76.20402527, 10.14069366], [76.20347595, 10.14069366], [76.20347595, 10.13986206], [76.20375061, 10.13986206], [76.20375061, 10.13930607], [76.2040329, 10.13931274], [76.2040329, 10.13875008], [76.20430756, 10.13875008], [76.20430756, 10.13792038], [76.20347595, 10.13791561], [76.20347595, 10.13819408], [76.20319366, 10.13819408], [76.20319366, 10.13764], [76.20347595, 10.13764], [76.20347595, 10.13707924], [76.20375061, 10.13708401], [76.20375061, 10.13680553], [76.2040329, 10.1368103], [76.2040329, 10.13652992], [76.20430756, 10.13652992], [76.20430756, 10.13624954], [76.20456696, 10.13624954], [76.20456696, 10.13597202], [76.2048645, 10.13597202], [76.2048645, 10.13541794], [76.20513916, 10.13541985], [76.20513916, 10.13514042], [76.20540619, 10.13514042], [76.20540619, 10.13486195], [76.20569611, 10.13486195], [76.20569611, 10.13458443], [76.20597076, 10.13458443], [76.20597076, 10.13402843], [76.20625305, 10.13403034], [76.20625305, 10.13347054], [76.20652771, 10.13347054], [76.20652771, 10.13097095], [76.20708466, 10.13097095], [76.20708466, 10.13069534], [76.20680237, 10.13069534], [76.20680237, 10.13013935], [76.20569611, 10.13013935], [76.20569611, 10.13097095], [76.20541382, 10.13097095], [76.20541382, 10.13236237], [76.20513916, 10.13234997], [76.20513916, 10.13292027], [76.2048645, 10.13291454], [76.2048645, 10.13319302], [76.20458221, 10.13319588], [76.20458221, 10.13347054], [76.20375061, 10.13347054], [76.20375061, 10.13375187], [76.20347595, 10.13375187], [76.20347595, 10.13347054], [76.20291901, 10.13347054], [76.20291901, 10.13291454], [76.20263672, 10.13292027], [76.20263672, 10.13264179], [76.20236206, 10.13264179], [76.20236206, 10.13208103], [76.20263672, 10.13208294], [76.20263672, 10.13180542], [76.20318604, 10.13181019], [76.20318604, 10.13152981], [76.20456696, 10.13152981], [76.20456696, 10.13041973], [76.20485687, 10.13041973], [76.20485687, 10.12986088], [76.20625305, 10.12986088], [76.20625305, 10.12958336], [76.20652771, 10.12958336], [76.20652771, 10.12902737], [76.20680237, 10.12902927], [76.20680237, 10.12847137], [76.20708466, 10.12847328], [76.20708466, 10.12791729], [76.20735931, 10.12792015], [76.20735931, 10.12764072], [76.20707703, 10.12764072], [76.20707703, 10.1273613], [76.20735931, 10.1273613], [76.20735931, 10.12708282], [76.20708466, 10.12708282], [76.20708466, 10.12652683], [76.20735931, 10.12654114], [76.20735931, 10.12625122], [76.20707703, 10.12625122], [76.20707703, 10.12430859], [76.20735931, 10.12430859], [76.20735931, 10.12318993], [76.2076416, 10.12319469], [76.2076416, 10.12236118], [76.20791626, 10.12236118], [76.20791626, 10.12152672], [76.20819092, 10.12153053], [76.20819092, 10.12125111], [76.20847321, 10.12125111], [76.20847321, 10.12097263], [76.20791626, 10.12097263], [76.20791626, 10.12069511], [76.20819092, 10.12069511], [76.20819092, 10.12041664], [76.20847321, 10.12041664], [76.20847321, 10.1198597], [76.20874786, 10.1198597], [76.20874786, 10.11930656], [76.20903015, 10.11931133], [76.20903015, 10.11875057], [76.20929718, 10.11875057], [76.20929718, 10.11819172], [76.2095871, 10.11819363], [76.2095871, 10.11708355], [76.20986176, 10.11708355], [76.20986176, 10.11625004], [76.21013641, 10.11625004], [76.21013641, 10.11569023], [76.2104187, 10.11569405], [76.2104187, 10.11541557], [76.21013641, 10.1154213], [76.21013641, 10.11458015], [76.2104187, 10.11458206], [76.2104187, 10.11375046], [76.21069336, 10.11375046], [76.21070099, 10.1131916], [76.21097565, 10.11319447], [76.21097565, 10.11263847], [76.21125031, 10.11264038], [76.21125031, 10.11207962], [76.21152496, 10.11208439], [76.21152496, 10.1109724], [76.21180725, 10.1109724], [76.21180725, 10.11013985], [76.21208191, 10.11013985], [76.21208191, 10.10958195], [76.2123642, 10.10958385], [76.2123642, 10.10930634], [76.21290588, 10.10931015], [76.21290588, 10.10791969], [76.2131958, 10.10791969], [76.2131958, 10.10653019], [76.21347046, 10.10653019], [76.21347046, 10.10597134], [76.21375275, 10.10597134], [76.21375275, 10.10569572], [76.2140274, 10.10569572], [76.2140274, 10.10513973], [76.21376038, 10.10513973], [76.21376038, 10.10458088], [76.2131958, 10.10458279], [76.2131958, 10.10430527], [76.21290588, 10.10431004], [76.21290588, 10.10346889], [76.2131958, 10.1034708], [76.2131958, 10.10319328], [76.2140274, 10.10319328], [76.2140274, 10.10152721], [76.21376038, 10.10153198], [76.21376038, 10.10097122], [76.2140274, 10.10097313], [76.2140274, 10.10041714], [76.21430206, 10.10042191], [76.21430206, 10.09958076], [76.21458435, 10.09958267], [76.21458435, 10.09930515], [76.21430206, 10.09931183], [76.21430206, 10.09792233], [76.21457672, 10.09792233], [76.21457672, 10.09736061], [76.21485901, 10.09736061], [76.21485901, 10.09680462], [76.2151413, 10.09680939], [76.2151413, 10.09624195], [76.21541595, 10.09624863], [76.21541595, 10.09541702], [76.21569061, 10.09542084], [76.21569824, 10.09514141], [76.2159729, 10.09514141], [76.2159729, 10.09486103], [76.21624756, 10.09486103], [76.21624756, 10.09291744], [76.21652985, 10.09292126], [76.21652985, 10.09208012], [76.2168045, 10.09208202], [76.2168045, 10.09152889], [76.21708679, 10.0915308], [76.21708679, 10.09125042], [76.21736145, 10.09125042], [76.21736145, 10.09069443], [76.21763611, 10.09069443], [76.21763611, 10.08985996], [76.21736145, 10.08985996], [76.21736145, 10.08902836], [76.2168045, 10.08902836], [76.2168045, 10.08958435], [76.21652985, 10.08957958], [76.21652985, 10.0901413], [76.21624756, 10.09013844], [76.21624756, 10.09097195], [76.2159729, 10.09097004], [76.2159729, 10.0915308], [76.21569824, 10.0915308], [76.21569824, 10.09292126], [76.21541595, 10.09291744], [76.21541595, 10.09319496], [76.2151413, 10.09318066], [76.2151413, 10.09403133], [76.21485901, 10.09402561], [76.21485901, 10.09597301], [76.21457672, 10.09597111], [76.21457672, 10.09653091], [76.21430206, 10.09653091], [76.21430206, 10.09680939], [76.21375275, 10.09680462], [76.21375275, 10.09708309], [76.21347046, 10.09708118], [76.21347046, 10.09875107], [76.2131958, 10.09875107], [76.2131958, 10.09986115], [76.21290588, 10.09986115], [76.21290588, 10.10042191], [76.21263885, 10.10042191], [76.21263885, 10.10125065], [76.21235657, 10.10125065], [76.21235657, 10.10153198], [76.21180725, 10.10153198], [76.21180725, 10.10181046], [76.21153259, 10.10181046], [76.21153259, 10.10237026], [76.21125031, 10.10236073], [76.21125031, 10.1034708], [76.21180725, 10.10346889], [76.21180725, 10.10402966], [76.21153259, 10.10402966], [76.21153259, 10.10431004], [76.21098328, 10.10431004], [76.21098328, 10.10402966], [76.21070099, 10.10402966], [76.21070099, 10.10374928], [76.20929718, 10.10374928], [76.20929718, 10.10346889], [76.20903015, 10.1034708], [76.20903015, 10.10319328], [76.20847321, 10.10319328], [76.20847321, 10.10152721], [76.20874786, 10.10153198], [76.20874786, 10.10097122], [76.20903015, 10.10097313], [76.20903015, 10.10069466], [76.20930481, 10.10069466], [76.20930481, 10.10013866], [76.2095871, 10.10014057], [76.2095871, 10.09986115], [76.20930481, 10.09986115], [76.20930481, 10.09930515], [76.20903015, 10.09931183], [76.20903015, 10.09903145], [76.20874786, 10.09903145], [76.20874786, 10.09875107], [76.20929718, 10.09875107], [76.20929718, 10.09847069], [76.2095871, 10.0984726], [76.2095871, 10.09819508], [76.20986176, 10.09819508], [76.20986176, 10.0979166], [76.21013641, 10.09792233], [76.21013641, 10.09653091], [76.2104187, 10.09653091], [76.2104187, 10.09568977], [76.21069336, 10.09569454], [76.21069336, 10.09347343], [76.21097565, 10.09347343], [76.21097565, 10.09263802], [76.21125031, 10.09264088], [76.21125031, 10.09235954], [76.21097565, 10.09235954], [76.21097565, 10.09208202], [76.21069336, 10.09208202], [76.21069336, 10.09180355], [76.2104187, 10.09181118], [76.2104187, 10.09125042], [76.21069336, 10.09125042], [76.21069336, 10.09097195], [76.21125031, 10.09097195], [76.21125031, 10.09069443], [76.21180725, 10.09069443], [76.21180725, 10.09041595], [76.21235657, 10.09043026], [76.21235657, 10.0901413], [76.2131958, 10.0901413], [76.2131958, 10.09043026], [76.21375275, 10.09041595], [76.21375275, 10.09069443], [76.2140274, 10.09068966], [76.2140274, 10.0915308], [76.21376038, 10.0915308], [76.21376038, 10.09264088], [76.2140274, 10.09264088], [76.2140274, 10.09292126], [76.21457672, 10.09292126], [76.21457672, 10.09264088], [76.2151413, 10.09264088], [76.2151413, 10.0915308], [76.21541595, 10.0915308], [76.21541595, 10.09043026], [76.21569061, 10.09043026], [76.21569824, 10.08903122], [76.2159729, 10.08903122], [76.2159729, 10.08847046], [76.21624756, 10.08847237], [76.21624756, 10.08736229], [76.21569824, 10.08737087], [76.21569061, 10.08541965], [76.21541595, 10.08541965], [76.21541595, 10.08514023], [76.21430206, 10.08514023], [76.21430206, 10.08569431], [76.2140274, 10.08569431], [76.2140274, 10.08708191], [76.21430206, 10.08708191], [76.21430206, 10.08737087], [76.21457672, 10.08737087], [76.21457672, 10.08764267], [76.21485901, 10.08764267], [76.21485901, 10.08875275], [76.21457672, 10.08875275], [76.21457672, 10.08931065], [76.2140274, 10.08931065], [76.2140274, 10.08903122], [76.21376038, 10.08903122], [76.21376038, 10.08792114], [76.21347046, 10.08792114], [76.21347046, 10.08764267], [76.21263885, 10.08764267], [76.21263885, 10.08737087], [76.21235657, 10.08737087], [76.21235657, 10.08708191], [76.21263885, 10.08708191], [76.21263885, 10.08652782], [76.21290588, 10.08652973], [76.21290588, 10.08597183], [76.2131958, 10.08597183], [76.2131958, 10.08541584], [76.21290588, 10.08541965], [76.21291351, 10.08508968], [76.21291351, 10.08485985], [76.21263885, 10.08485985], [76.21263885, 10.08402824], [76.21290588, 10.08403015], [76.21290588, 10.08347034], [76.2131958, 10.08347225], [76.2131958, 10.08319378], [76.21370697, 10.08319378], [76.21541595, 10.08319378], [76.21541595, 10.08263779], [76.21569061, 10.08263969], [76.21569824, 10.08236027], [76.2159729, 10.08236217], [76.2159729, 10.0820837], [76.21624756, 10.0820837], [76.21624756, 10.0806942], [76.2159729, 10.0806942], [76.2159729, 10.08014011], [76.21624756, 10.08014202], [76.21624756, 10.07958126], [76.21652985, 10.07958412], [76.21652985, 10.07902718], [76.21679688, 10.07903194], [76.21679688, 10.0773592], [76.21708679, 10.07736111], [76.21708679, 10.07680511], [76.21736145, 10.07681179], [76.21736145, 10.07597065], [76.21763611, 10.07597065], [76.21763611, 10.07625198], [76.2179184, 10.07625198], [76.2179184, 10.07597065], [76.21819305, 10.07597256], [76.21819305, 10.07569313], [76.21847534, 10.07569313], [76.21847534, 10.07486057], [76.21875, 10.07486057], [76.21875, 10.07458305], [76.21902466, 10.07458305], [76.21902466, 10.07402706], [76.21930695, 10.07403183], [76.21930695, 10.07291889], [76.21956635, 10.07291889], [76.21956635, 10.07375145], [76.22097015, 10.07375145], [76.22097015, 10.07543087], [76.2206955, 10.07541656], [76.2206955, 10.07569313], [76.22041321, 10.07569313], [76.22041321, 10.07597256], [76.22013855, 10.07597065], [76.22013855, 10.07625198], [76.22041321, 10.07625198], [76.22041321, 10.07681179], [76.2206955, 10.07680511], [76.2206955, 10.07736111], [76.22041321, 10.0773592], [76.22041321, 10.07791996], [76.22013855, 10.07791805], [76.22013855, 10.07847118], [76.21985626, 10.07846928], [76.21985626, 10.07875156], [76.2195816, 10.0787487], [76.2195816, 10.07958412], [76.21930695, 10.07958126], [76.21930695, 10.08041954], [76.21902466, 10.08041763], [76.21902466, 10.08125019], [76.21875, 10.08124065], [76.21875, 10.08152962], [76.2179184, 10.08152771], [76.2179184, 10.0820837], [76.21819305, 10.08208179], [76.21819305, 10.08263969], [76.21847534, 10.08263779], [76.21847534, 10.08347225], [76.21819305, 10.08347225], [76.21819305, 10.08430576], [76.21847534, 10.08430576], [76.21847534, 10.08458424], [76.21930695, 10.08458424], [76.21930695, 10.08430576], [76.2195816, 10.08430576], [76.2195816, 10.08374977], [76.22013855, 10.08374977], [76.22013855, 10.08403015], [76.22041321, 10.08402824], [76.22041321, 10.08430576], [76.22125244, 10.08430576], [76.22125244, 10.08374977], [76.22097015, 10.08374977], [76.22097015, 10.08319092], [76.22125244, 10.08319378], [76.22125244, 10.08291626], [76.2215271, 10.08292007], [76.2215271, 10.08181], [76.22180176, 10.08181], [76.22180176, 10.08096886], [76.22264099, 10.08097172], [76.22264099, 10.08014011], [76.22180176, 10.08014202], [76.22180176, 10.07986164], [76.2215271, 10.07986164], [76.2215271, 10.07930565], [76.22180176, 10.07931042], [76.22180176, 10.07875156], [76.22207642, 10.07875156], [76.22207642, 10.07820034], [76.2223587, 10.07820034], [76.2223587, 10.07763863], [76.22264099, 10.07763863], [76.22264099, 10.0773592], [76.22291565, 10.07736111], [76.22291565, 10.07680511], [76.22319794, 10.07680511], [76.22319794, 10.07708263], [76.2234726, 10.07708263], [76.2234726, 10.07736111], [76.22402954, 10.07736111], [76.22402954, 10.07680511], [76.22429657, 10.07681179], [76.22429657, 10.07597065], [76.22319794, 10.07597256], [76.22319794, 10.07541656], [76.2234726, 10.07543087], [76.2234726, 10.0743103], [76.22374725, 10.0743103], [76.22374725, 10.07375145], [76.22402954, 10.07375145], [76.22402954, 10.07319069], [76.2243042, 10.07319546], [76.2243042, 10.07291698], [76.22486115, 10.07291889], [76.22486115, 10.07264137], [76.22541809, 10.07264137], [76.22541809, 10.07236099], [76.2251358, 10.07236099], [76.2251358, 10.07208347], [76.22486115, 10.07208347], [76.22486115, 10.071805], [76.22458649, 10.07181168], [76.22458649, 10.07125092], [76.22486115, 10.07125092], [76.22486115, 10.07097054], [76.22569275, 10.0709734], [76.22569275, 10.06902885], [76.22624969, 10.06902885], [76.22624969, 10.06847095], [76.22541809, 10.06847286], [76.22541809, 10.06736088], [76.22569275, 10.06736088], [76.22569275, 10.06680679], [76.2259903, 10.06681061], [76.2259903, 10.06597042], [76.22624969, 10.06597328], [76.22624969, 10.06541634], [76.22735596, 10.0654211], [76.22735596, 10.06514072], [76.22763824, 10.06514072], [76.22763824, 10.06486034], [76.2279129, 10.06486034], [76.2279129, 10.06430435], [76.22820282, 10.06431103], [76.22820282, 10.06403065], [76.22846985, 10.06400967], [76.22846985, 10.06319427], [76.22873688, 10.06320095], [76.22873688, 10.06236172], [76.22820282, 10.06236172], [76.22820282, 10.06208038], [76.22763824, 10.06208229], [76.22763824, 10.06124973], [76.2279129, 10.06124973], [76.2279129, 10.06069183], [76.22846985, 10.06069183], [76.22846985, 10.06124973], [76.22930908, 10.06124973], [76.22930908, 10.06097031], [76.22958374, 10.06097221], [76.22958374, 10.06041622], [76.2298584, 10.06042099], [76.2298584, 10.05986023], [76.23014069, 10.05986214], [76.23014069, 10.05847168], [76.2298584, 10.05847168], [76.2298584, 10.05819416], [76.22930908, 10.05819416], [76.22930908, 10.05791569], [76.22902679, 10.05792046], [76.22902679, 10.05596924], [76.22846985, 10.0559721], [76.22846985, 10.05569363], [76.2279129, 10.05569363], [76.2279129, 10.05541801], [76.22736359, 10.05541801], [76.22736359, 10.05513763], [76.22680664, 10.05513954], [76.22680664, 10.05486202], [76.22651672, 10.05486202], [76.22651672, 10.05458069], [76.22624969, 10.05458355], [76.22624969, 10.05486202], [76.22597504, 10.05486202], [76.22597504, 10.05402756], [76.22541809, 10.05403042], [76.22541809, 10.05513954], [76.2251358, 10.05513763], [76.2251358, 10.05708408], [76.22486115, 10.05708408], [76.22486115, 10.05766964], [76.22486115, 10.05958366], [76.22458649, 10.05957985], [76.22458649, 10.06236172], [76.2243042, 10.06235981], [76.2243042, 10.06263065], [76.22429657, 10.06292057], [76.22402954, 10.0629158], [76.22402954, 10.06375027], [76.22374725, 10.06375027], [76.22374725, 10.06514072], [76.2234726, 10.06513786], [76.2234726, 10.06597328], [76.22319794, 10.06597328], [76.22319794, 10.06708336], [76.22292328, 10.06707954], [76.22292328, 10.06764126], [76.22264099, 10.06764126], [76.22264099, 10.06792068], [76.22180176, 10.06792068], [76.22180176, 10.06777096], [76.22180176, 10.06763935], [76.2215271, 10.06764126], [76.2215271, 10.06754112], [76.2215271, 10.06736088], [76.22125244, 10.06736088], [76.22125244, 10.06764126], [76.22097015, 10.06763935], [76.22093964, 10.06785965], [76.22083282, 10.06791687], [76.2206955, 10.06791687], [76.2206955, 10.06819534], [76.22041321, 10.06819534], [76.22041321, 10.06847286], [76.22013855, 10.06847286], [76.22013855, 10.06875134], [76.21985626, 10.06875134], [76.21985626, 10.06847095], [76.2195816, 10.06847286], [76.2195816, 10.06819534], [76.21986389, 10.06819534], [76.21986389, 10.06763935], [76.22013855, 10.06764126], [76.22013855, 10.06736088], [76.2206955, 10.06736088], [76.2206955, 10.06708336], [76.22125244, 10.06708336], [76.22125244, 10.06680679], [76.22097015, 10.06681061], [76.22097015, 10.06569004], [76.2206955, 10.06569481], [76.2206955, 10.06430435], [76.22097015, 10.06431103], [76.22097015, 10.06375027], [76.22125244, 10.06375027], [76.22125244, 10.06319427], [76.2215271, 10.06320095], [76.2215271, 10.06208038], [76.22168732, 10.06208229], [76.22180176, 10.06208229], [76.22180176, 10.06124973], [76.22207642, 10.06124973], [76.22207642, 10.06097031], [76.2223587, 10.06097221], [76.2223587, 10.06069374], [76.22264099, 10.06069374], [76.22264099, 10.05969143], [76.22264099, 10.05958366], [76.2215271, 10.05958366], [76.2215271, 10.05986214], [76.22097015, 10.05986214], [76.22097015, 10.06013775], [76.22013855, 10.06013775], [76.22013855, 10.05986214], [76.21986389, 10.05986214], [76.21986389, 10.05624962], [76.22013855, 10.05624962], [76.22013855, 10.05596924], [76.2206955, 10.0559721], [76.2206955, 10.05569363], [76.22097015, 10.05569363], [76.22097015, 10.05430603], [76.22125244, 10.05431938], [76.22125244, 10.05347157], [76.2215271, 10.05347157], [76.2215271, 10.05319309], [76.22207642, 10.05319118], [76.22207642, 10.05375195], [76.2223587, 10.05375195], [76.2223587, 10.05403042], [76.22264099, 10.05403042], [76.22264099, 10.05431938], [76.22319794, 10.05431938], [76.22319794, 10.05403042], [76.22402954, 10.05403042], [76.22402954, 10.05375195], [76.22458649, 10.05375195], [76.22458649, 10.05264187], [76.22429657, 10.05264187], [76.22429657, 10.05236244], [76.22374725, 10.05236244], [76.22374725, 10.05208397], [76.2234726, 10.05208397], [76.2234726, 10.05124855], [76.22374725, 10.05126095], [76.22374725, 10.05097103], [76.22402954, 10.05097103], [76.22402954, 10.05069637], [76.2243042, 10.05069637], [76.2243042, 10.0504179], [76.22458649, 10.05041981], [76.22458649, 10.05013943], [76.2251358, 10.05013943], [76.2251358, 10.04986095], [76.22541809, 10.04986095], [76.22541809, 10.04958344], [76.22597504, 10.04958344], [76.22597504, 10.04930496], [76.22624969, 10.04930973], [76.22624969, 10.04875088], [76.22651672, 10.04875088], [76.22651672, 10.04847145], [76.22680664, 10.04847336], [76.22680664, 10.04819489], [76.22763824, 10.04819489], [76.22763824, 10.04847336], [76.22820282, 10.04847145], [76.22820282, 10.04875088], [76.22873688, 10.04875088], [76.22873688, 10.0490303], [76.22957611, 10.0490303], [76.22957611, 10.04875088], [76.2298584, 10.04875088], [76.2298584, 10.04792023], [76.23042297, 10.04792023], [76.23042297, 10.04763889], [76.23179626, 10.04763889], [76.23179626, 10.04736137], [76.23208618, 10.04736137], [76.23208618, 10.04430485], [76.23236084, 10.04431152], [76.23236084, 10.04347134], [76.2326355, 10.04347324], [76.2326355, 10.04259968], [76.2326355, 10.0415287], [76.23069763, 10.04153061], [76.23069763, 10.04125118], [76.23041534, 10.04125118], [76.23041534, 10.04069519], [76.23069763, 10.04069519], [76.23069763, 10.04041672], [76.23208618, 10.04041672], [76.23208618, 10.04069519], [76.23280334, 10.04069519], [76.23291779, 10.04069519], [76.23291779, 10.0401392], [76.23319244, 10.04014111], [76.23319244, 10.03958035], [76.23291779, 10.03958225], [76.23291779, 10.03930664], [76.23264313, 10.03931999], [76.23264313, 10.03903103], [76.23236084, 10.03903103], [76.23236084, 10.03764057], [76.23208618, 10.03764057], [76.23208618, 10.03681087], [76.23179626, 10.03681087], [76.23179626, 10.03625011], [76.23152924, 10.03625011], [76.23152924, 10.03514004], [76.23179626, 10.03514004], [76.23179626, 10.03485966], [76.23208618, 10.03485966], [76.23208618, 10.03458214], [76.23236084, 10.03458214], [76.23236084, 10.03430557], [76.23264313, 10.03431129], [76.23264313, 10.03347015], [76.23291779, 10.03347206], [76.23291779, 10.03319359], [76.23319244, 10.03319359], [76.23319244, 10.03291607], [76.23291779, 10.03292274], [76.23291779, 10.03264046], [76.23319244, 10.03264046], [76.23319244, 10.03125], [76.23339081, 10.03125], [76.23347473, 10.03125], [76.2334671, 10.0304203], [76.23374939, 10.03041553], [76.23374939, 10.03097153], [76.23401642, 10.03096962], [76.23401642, 10.03125], [76.23430634, 10.03125], [76.23430634, 10.03153038], [76.23486328, 10.03152847], [76.23486328, 10.03236008], [76.23458099, 10.03236008], [76.23458099, 10.03319359], [76.23486328, 10.03319359], [76.23486328, 10.03347206], [76.23458099, 10.03347015], [76.23458099, 10.03374958], [76.23430634, 10.03374958], [76.23430634, 10.03431129], [76.23402405, 10.03430557], [76.23402405, 10.03486156], [76.23374939, 10.03485966], [76.23374939, 10.03514004], [76.2334671, 10.03514004], [76.2334671, 10.03625011], [76.23401642, 10.03625011], [76.23401642, 10.03653145], [76.23486328, 10.03653145], [76.23486328, 10.03374958], [76.23513794, 10.03374958], [76.23513794, 10.03347015], [76.23542023, 10.03347206], [76.23542023, 10.03319359], [76.23569489, 10.03319359], [76.23569489, 10.03291607], [76.23680878, 10.03292274], [76.23680878, 10.03236008], [76.23708344, 10.03236008], [76.23707581, 10.0320797], [76.23735809, 10.03208447], [76.23735809, 10.03152847], [76.23764038, 10.03153038], [76.23764038, 10.03125], [76.2379303, 10.03125], [76.2379303, 10.03096962], [76.23819733, 10.03097153], [76.23819733, 10.03069401], [76.23847198, 10.03069401], [76.23847198, 10.03041553], [76.23874664, 10.0304203], [76.23874664, 10.02958202], [76.23847198, 10.02958393], [76.23847198, 10.02902794], [76.23874664, 10.02902985], [76.23874664, 10.02791977], [76.23902893, 10.02791977], [76.23902893, 10.02653027], [76.23929596, 10.02653027], [76.23929596, 10.02625179], [76.23902893, 10.02625179], [76.23902893, 10.02597141], [76.23930359, 10.02597141], [76.23930359, 10.02541542], [76.23819733, 10.02541542], [76.23819733, 10.0256958], [76.2379303, 10.02569103], [76.2379303, 10.02625179], [76.23764038, 10.02625179], [76.23764038, 10.02653027], [76.23735809, 10.02653027], [76.23735809, 10.02680969], [76.23680878, 10.02680588], [76.23680878, 10.02736187], [76.23625183, 10.02736187], [76.23625183, 10.02764034], [76.23596954, 10.02764034], [76.23596954, 10.02819443], [76.23568726, 10.02819061], [76.23569489, 10.02875042], [76.23542023, 10.02875042], [76.23542023, 10.02931023], [76.23513794, 10.02930641], [76.23513794, 10.0298624], [76.23347473, 10.0298624], [76.23347473, 10.02958393], [76.23319244, 10.02958393], [76.23319244, 10.02847195], [76.23347473, 10.02847195], [76.23347473, 10.02819443], [76.23374939, 10.02819443], [76.23374939, 10.02791786], [76.23401642, 10.02791977], [76.23401642, 10.02764034], [76.23458099, 10.02764034], [76.23458099, 10.02736187], [76.23486328, 10.02736187], [76.23486328, 10.02708435], [76.23513794, 10.02709103], [76.23513794, 10.02653027], [76.23542023, 10.02653027], [76.23542023, 10.02625179], [76.23596954, 10.02625179], [76.23596954, 10.02597141], [76.23625183, 10.02597141], [76.23625183, 10.02513981], [76.23652649, 10.02513981], [76.23652649, 10.02458286], [76.23680878, 10.02458286], [76.23680878, 10.02430534], [76.23735809, 10.02431011], [76.23735809, 10.02402973], [76.23764038, 10.02402973], [76.23764038, 10.02374935], [76.23874664, 10.02374935], [76.23874664, 10.02291679], [76.23819733, 10.02291965], [76.23819733, 10.02263927], [76.2379303, 10.02263927], [76.2379303, 10.02235889], [76.23764038, 10.0223608], [76.23764038, 10.02208328], [76.23735809, 10.02208328], [76.23735809, 10.02180481], [76.23707581, 10.02180958], [76.23707581, 10.0215292], [76.23680878, 10.0215292], [76.23680878, 10.0212698], [76.23652649, 10.02125072], [76.23652649, 10.02115059], [76.23652649, 10.02097321], [76.23625183, 10.02097321], [76.23625183, 10.02069473], [76.23596954, 10.02069473], [76.23596954, 10.02041721], [76.23542023, 10.02042198], [76.23542023, 10.02014065], [76.23486328, 10.02014065], [76.23486328, 10.01986122], [76.23458099, 10.01986122], [76.23458099, 10.01930523], [76.23430634, 10.0193119], [76.23430634, 10.01875114], [76.23401642, 10.01875114], [76.23401642, 10.01847076], [76.23347473, 10.01847267], [76.23347473, 10.01819515], [76.23208618, 10.01819515], [76.23208618, 10.01847267], [76.23124695, 10.01847267], [76.23124695, 10.01819515], [76.23041534, 10.01819515], [76.23041534, 10.0168047], [76.23152924, 10.01680946], [76.23152924, 10.01653099], [76.23204803, 10.01653099], [76.23236084, 10.01653099], [76.23236084, 10.01680946], [76.23347473, 10.0168047], [76.23347473, 10.01708317], [76.23430634, 10.01708317], [76.23430634, 10.01736069], [76.23596954, 10.01736069], [76.23596954, 10.01708317], [76.23625183, 10.01708317], [76.23625183, 10.0168047], [76.23652649, 10.01680946], [76.23652649, 10.01653099], [76.23680878, 10.01653099], [76.23680878, 10.01597118], [76.23708344, 10.01597309], [76.23708344, 10.01235962], [76.23680878, 10.01235962], [76.23680878, 10.01125145], [76.23652649, 10.01125145], [76.23652649, 10.01097012], [76.23680878, 10.01097298], [76.23680878, 10.01041603], [76.23707581, 10.0104208], [76.23707581, 10.01014137], [76.23652649, 10.01014137], [76.23652649, 10.0104208], [76.23542023, 10.0104208], [76.23542023, 10.01014137], [76.23513794, 10.01014137], [76.23513794, 10.00986004], [76.23569489, 10.00986004], [76.23568726, 10.00957966], [76.23625183, 10.00958538], [76.23625183, 10.00902843], [76.23652649, 10.00902843], [76.23652649, 10.00874996], [76.23708344, 10.00874996], [76.23708344, 10.00902843], [76.23735809, 10.00902843], [76.23735809, 10.00958538], [76.23764038, 10.00958538], [76.23764038, 10.00902843], [76.23791504, 10.00902843], [76.23791504, 10.00874996], [76.23819733, 10.00874996], [76.23819733, 10.00792122], [76.2379303, 10.00792122], [76.2379303, 10.00708199], [76.23819733, 10.00708199], [76.23819733, 10.00625038], [76.23847198, 10.00625038], [76.23847198, 10.00569439], [76.23874664, 10.00569439], [76.23874664, 10.0051403], [76.23902893, 10.0051403], [76.23902893, 10.00457954], [76.23930359, 10.00458431], [76.23930359, 10.00402832], [76.23958588, 10.00403023], [76.23958588, 10.00374985], [76.23986053, 10.00374985], [76.23986053, 10.00319386], [76.24013519, 10.00319386], [76.24013519, 10.00291634], [76.24041748, 10.00292015], [76.24041748, 10.00236034], [76.24069214, 10.00236225], [76.24069214, 10.00069427], [76.24041748, 10.00069427], [76.24041748, 10.00041771], [76.24014282, 10.00041962], [76.24014282, 10.00015068], [76.23986053, 10.00015068], [76.23986053, 9.99875164], [76.23958588, 9.99875164], [76.23958588, 9.99847126], [76.23902893, 9.99847126], [76.23902893, 9.99819565], [76.23874664, 9.99819565], [76.23874664, 9.99783993], [76.23874664, 9.99763966], [76.2379303, 9.99763966], [76.2379303, 9.99735928], [76.23735809, 9.99736214], [76.23735809, 9.99680519], [76.23764038, 9.99680996], [76.23764038, 9.9962492], [76.23847198, 9.9962492], [76.23847198, 9.99597359], [76.23874664, 9.99597359], [76.23874664, 9.99569321], [76.23930359, 9.99569321], [76.23930359, 9.99513912], [76.23958588, 9.99514198], [76.23958588, 9.99431038], [76.23929596, 9.99431038], [76.23929596, 9.99319077], [76.23902893, 9.99319458], [76.23902893, 9.99236107], [76.23930359, 9.99236107], [76.23929596, 9.99180984], [76.23958588, 9.99180984], [76.23958588, 9.99069023], [76.23986053, 9.990695], [76.23986053, 9.98902893], [76.24014282, 9.98903084], [76.24014282, 9.9881897], [76.24041748, 9.98819542], [76.24041748, 9.98763943], [76.24067688, 9.98764133], [76.24067688, 9.98736095], [76.2409668, 9.98736095], [76.2409668, 9.98681068], [76.24124908, 9.98681068], [76.24124908, 9.98653126], [76.24153137, 9.98653126], [76.24153137, 9.98596954], [76.24180603, 9.98597336], [76.24180603, 9.98569489], [76.24208069, 9.98569489], [76.24208069, 9.98513794], [76.24236298, 9.9851408], [76.24236298, 9.98485088], [76.24263763, 9.98486042], [76.24263763, 9.98430443], [76.24291992, 9.9843111], [76.24291992, 9.98318958], [76.24319458, 9.98319435], [76.24319458, 9.98302078], [76.24319458, 9.98263836], [76.24291992, 9.98264122], [76.24291992, 9.98208046], [76.24263763, 9.98208427], [76.24263763, 9.9818058], [76.24208069, 9.98181057], [76.24208069, 9.98153114], [76.24180603, 9.98153114], [76.24180603, 9.97986031], [76.24208069, 9.97986221], [76.24208069, 9.97819424], [76.24263763, 9.97819424], [76.24263763, 9.97764015], [76.24291992, 9.97764015], [76.24291992, 9.97736168], [76.24318695, 9.97736168], [76.24318695, 9.97707939], [76.24375153, 9.97708416], [76.24375153, 9.97680569], [76.24402618, 9.97681141], [76.24402618, 9.97653008], [76.24430847, 9.97653008], [76.24430847, 9.97569084], [76.24458313, 9.9756937], [76.24458313, 9.97458363], [76.24485779, 9.97458363], [76.24485779, 9.97347164], [76.24514008, 9.97347164], [76.24514008, 9.9729147], [76.24541473, 9.9729147], [76.24541473, 9.97236156], [76.24319458, 9.97236156], [76.24319458, 9.97208405], [76.24097443, 9.97208405], [76.24097443, 9.97236156], [76.24067688, 9.97236156], [76.24067688, 9.97264194], [76.24041748, 9.97264004], [76.24041748, 9.9729147], [76.24013519, 9.9729147], [76.24013519, 9.97319412], [76.23986053, 9.97319412], [76.23986053, 9.97347164], [76.23958588, 9.97347164], [76.23958588, 9.97402954], [76.23929596, 9.97402954], [76.23929596, 9.97430992], [76.23847198, 9.97430992], [76.23847198, 9.97402954], [76.2379303, 9.97402954], [76.2379303, 9.97375202], [76.23735809, 9.97375202], [76.23735809, 9.97347164], [76.23680878, 9.97347164], [76.23680878, 9.97319412], [76.23625183, 9.97319412], [76.23625183, 9.9729147], [76.23569489, 9.9729147], [76.23569489, 9.97264004], [76.23458099, 9.97264194], [76.23458099, 9.97236156], [76.23236084, 9.97236156], [76.23236084, 9.97264194], [76.23124695, 9.97264004], [76.23124695, 9.9729147], [76.23014069, 9.9729147], [76.23014069, 9.97319412], [76.22958374, 9.97319412], [76.22958374, 9.97347164], [76.22902679, 9.97347164], [76.22902679, 9.97375202], [76.22846985, 9.97375202], [76.22846985, 9.97402954], [76.2279129, 9.97402954], [76.2279129, 9.97430992], [76.22763824, 9.97430611], [76.22763824, 9.97458363], [76.2270813, 9.97457886], [76.2270813, 9.97513962], [76.22680664, 9.97513771], [76.22680664, 9.9756937], [76.22651672, 9.97569084], [76.22651672, 9.97624969], [76.2251358, 9.97624969], [76.2251358, 9.97653008], [76.22458649, 9.97653008], [76.22458649, 9.97681141], [76.2243042, 9.97680569], [76.2243042, 9.97708416], [76.22402954, 9.97707939], [76.22402954, 9.97791958], [76.22374725, 9.97791576], [76.22374725, 9.97875023], [76.2234726, 9.97875023], [76.2234726, 9.97986221], [76.22319794, 9.97986221], [76.22319794, 9.98069382], [76.22292328, 9.98069191], [76.22290039, 9.98181057], [76.22264099, 9.98181057], [76.22264099, 9.98292065], [76.2223587, 9.98292065], [76.2223587, 9.98403072], [76.22207642, 9.98403072], [76.22207642, 9.9851408], [76.22180939, 9.9851408], [76.22180176, 9.98625088], [76.2215271, 9.98625088], [76.2215271, 9.98736095], [76.22125244, 9.98736095], [76.22125244, 9.98847294], [76.22097015, 9.98847294], [76.22097015, 9.98958302], [76.2206955, 9.98958302], [76.22070313, 9.99061966], [76.22070313, 9.99098015], [76.22054291, 9.99097538], [76.22041321, 9.99097347], [76.22041321, 9.99127197], [76.22041321, 9.9920826], [76.22013855, 9.99208069], [76.22013855, 9.99264145], [76.21986389, 9.99263859], [76.21986389, 9.99324131], [76.21986389, 9.99347115], [76.2195816, 9.99347115], [76.2195816, 9.99402714], [76.21930695, 9.99402714], [76.21930695, 9.99486065], [76.21901703, 9.99486065], [76.21901703, 9.99542046], [76.21875, 9.99541664], [76.21875, 9.99847126], [76.21848297, 9.99847126], [76.21848297, 9.99903202], [76.21819305, 9.99902821], [76.21819305, 10.00014019], [76.21819305, 10.00208378], [76.2179184, 10.00208378], [76.2179184, 10.00319386], [76.21763611, 10.00319195], [76.21763611, 10.00542068], [76.2179184, 10.00541592], [76.2179184, 10.00569439], [76.21763611, 10.00569439], [76.21763611, 10.00597191], [76.21708679, 10.00597191], [76.21708679, 10.00819016], [76.21679688, 10.00820065], [76.21679688, 10.00874996], [76.21624756, 10.00874996], [76.21624756, 10.01069355], [76.2159729, 10.01068974], [76.2159729, 10.01125145], [76.21569824, 10.01125145], [76.21569824, 10.01153088], [76.2159729, 10.01152897], [76.2159729, 10.01235962], [76.21569824, 10.01235962], [76.21569824, 10.01458263], [76.2151413, 10.01457977], [76.2151413, 10.01515007], [76.21485901, 10.01515007], [76.21485901, 10.01625061], [76.21457672, 10.01625061], [76.21458435, 10.01736069], [76.21430206, 10.01736069], [76.21430206, 10.01875114], [76.2140274, 10.01875114], [76.2140274, 10.02014065], [76.21376038, 10.02014065], [76.21376038, 10.02125072], [76.21347046, 10.02124882], [76.21347046, 10.02208328], [76.2131958, 10.02208328], [76.2131958, 10.0223608], [76.21291351, 10.0223608], [76.21291351, 10.02319336], [76.21263885, 10.02319336], [76.21263885, 10.02374935], [76.21235657, 10.02374935], [76.21235657, 10.02431011], [76.21208191, 10.02430534], [76.21208191, 10.02486229], [76.2123642, 10.02486229], [76.2123642, 10.0256958], [76.21152496, 10.0256958], [76.21152496, 10.02597141], [76.21098328, 10.02597141], [76.21098328, 10.02625179], [76.21070099, 10.02625179], [76.21070099, 10.02680969], [76.2104187, 10.02680969], [76.2104187, 10.02791977], [76.21013641, 10.02791786], [76.21013641, 10.02819443], [76.20986176, 10.02819443], [76.20986176, 10.0298624], [76.2095871, 10.02985954], [76.2095871, 10.0304203], [76.20930481, 10.03041553], [76.20930481, 10.03069401], [76.20903015, 10.03068924], [76.20903015, 10.03125], [76.20929718, 10.03125], [76.20929718, 10.03153038], [76.20903015, 10.03152847], [76.20903015, 10.03236008], [76.20874786, 10.03236008], [76.20874786, 10.03292274], [76.20847321, 10.03292274], [76.20847321, 10.03403091], [76.20819092, 10.03403091], [76.20819092, 10.03431129], [76.20847321, 10.03430557], [76.20847321, 10.03486156], [76.20819092, 10.03486156], [76.20819092, 10.03597164], [76.20791626, 10.03596973], [76.20791626, 10.03681087], [76.20762634, 10.03681087], [76.20762634, 10.03764057], [76.20735931, 10.03763771], [76.20735931, 10.03847313], [76.20707703, 10.03847027], [76.20707703, 10.03903103], [76.20680237, 10.03902912], [76.20680237, 10.03986073], [76.20652771, 10.03986073], [76.20652771, 10.04208279], [76.20625305, 10.04208279], [76.20625305, 10.04347324], [76.20597076, 10.04347134], [76.20597076, 10.04431152], [76.20569611, 10.04431152], [76.20569611, 10.0454216], [76.20540619, 10.0454216], [76.20541382, 10.0462513], [76.20513916, 10.0462513], [76.20513916, 10.04736137], [76.2048645, 10.04736137], [76.2048645, 10.04819489], [76.20456696, 10.04819107], [76.20456696, 10.04875088], [76.20430756, 10.04874897], [76.20430756, 10.04986095], [76.2040329, 10.04986095], [76.2040329, 10.05041981], [76.20375061, 10.0504179], [76.20375061, 10.05097103], [76.20318604, 10.05097103], [76.20318604, 10.05126095], [76.20291901, 10.05126095], [76.20291901, 10.05153179], [76.20236206, 10.05153179], [76.20236206, 10.05181026], [76.20207977, 10.05180454], [76.20207977, 10.05208397], [76.20182037, 10.05208111], [76.20182037, 10.05264187], [76.20153046, 10.05263996], [76.20153046, 10.05458355], [76.20124817, 10.05458069], [76.20124817, 10.05513954], [76.20096588, 10.05513954], [76.20096588, 10.05624962], [76.20069122, 10.05624962], [76.20069122, 10.05708408], [76.20041656, 10.05708408], [76.20041656, 10.0573597], [76.20069122, 10.0573597], [76.20069122, 10.05792046], [76.20041656, 10.05791569], [76.20041656, 10.05875015], [76.20014191, 10.05875015], [76.20014191, 10.05902958], [76.19985962, 10.05902958], [76.19985962, 10.06042099], [76.19959259, 10.06042099], [76.19959259, 10.06124973], [76.19985962, 10.06124973], [76.19985962, 10.06153107], [76.19958496, 10.06152821], [76.19958496, 10.06208229], [76.19930267, 10.06208038], [76.19930267, 10.06292057], [76.19902802, 10.0629158], [76.19902802, 10.06486034], [76.19876099, 10.06486034], [76.19876099, 10.06514072], [76.19847107, 10.06513786], [76.19847107, 10.06597328], [76.19819641, 10.06597042], [76.19819641, 10.06681061], [76.19790649, 10.06681061], [76.19790649, 10.06792068], [76.19763947, 10.06792068], [76.19763947, 10.06902885], [76.19736481, 10.06902885], [76.19736481, 10.06958294], [76.19763947, 10.06958294], [76.19763947, 10.06986141], [76.19735718, 10.06986141], [76.19735718, 10.07181168], [76.19708252, 10.071805], [76.19708252, 10.07236099], [76.19680786, 10.07236099], [76.19680786, 10.07347107], [76.1965332, 10.07347107], [76.1965332, 10.0743103], [76.19625092, 10.07430458], [76.19625092, 10.07458305], [76.19596863, 10.07458115], [76.19596863, 10.07681179], [76.19569397, 10.07680511], [76.19569397, 10.07736111], [76.19541931, 10.0773592], [76.19541931, 10.07791996], [76.19513702, 10.07791805], [76.19513702, 10.07847118], [76.19486237, 10.07847118], [76.19486237, 10.07986164], [76.19458008, 10.07986164], [76.19458008, 10.08181], [76.19430542, 10.08180618], [76.19430542, 10.08319378], [76.19403076, 10.08319092], [76.19403076, 10.08403015], [76.19374847, 10.08403015], [76.19374847, 10.08514023], [76.19346619, 10.08514023], [76.19346619, 10.08541965], [76.19319153, 10.08541584], [76.19319153, 10.08597183], [76.19291687, 10.08597183], [76.19291687, 10.08652973], [76.19264221, 10.08652782], [76.19264221, 10.08708191], [76.19235992, 10.08708191], [76.19235992, 10.08764267], [76.1920929, 10.08764267], [76.1920929, 10.08792114], [76.19180298, 10.08791637], [76.19180298, 10.09097195], [76.19152832, 10.09097004], [76.19152832, 10.0915308], [76.19097137, 10.0915308], [76.19097137, 10.09264088], [76.19069672, 10.09263802], [76.19069672, 10.09347343], [76.1904068, 10.09346962], [76.1904068, 10.09403133], [76.19013977, 10.09402561], [76.19013977, 10.09486103], [76.18985748, 10.09486103], [76.18985748, 10.09569454], [76.18959045, 10.09568977], [76.18959045, 10.09764099], [76.18930817, 10.09763908], [76.18930817, 10.09986115], [76.18902588, 10.09986115], [76.18902588, 10.10208321], [76.18875122, 10.1020813], [76.18875122, 10.10431004], [76.18846893, 10.10430527], [76.18846893, 10.10541534], [76.18819427, 10.10541534], [76.18819427, 10.10708427], [76.18791962, 10.10708141], [76.18791962, 10.10791969], [76.18763733, 10.10791779], [76.18763733, 10.10986233], [76.18736267, 10.10986233], [76.18736267, 10.1109724], [76.18708038, 10.1109724], [76.18708038, 10.11236], [76.18680573, 10.11236], [76.18680573, 10.11319447], [76.18653107, 10.11319447], [76.18653107, 10.11375046], [76.18624878, 10.11375046], [76.18624878, 10.11597157], [76.18596649, 10.11596966], [76.18596649, 10.11653137], [76.18569183, 10.11653137], [76.18569183, 10.11792088], [76.18541718, 10.11791611], [76.18541718, 10.1184721], [76.18514252, 10.1184721], [76.18514252, 10.1198597], [76.18486023, 10.1198597], [76.18486023, 10.12069511], [76.1845932, 10.12069035], [76.1845932, 10.12153053], [76.18430328, 10.12153053], [76.18430328, 10.12292099], [76.18402863, 10.12292099], [76.18402863, 10.12403107], [76.18374634, 10.12402916], [76.18374634, 10.12458324], [76.18345642, 10.12458134], [76.18347168, 10.12597084], [76.18319702, 10.12597084], [76.18319702, 10.12681198], [76.1829071, 10.12681198], [76.1829071, 10.12792015], [76.18264008, 10.12792015], [76.18264008, 10.12902927], [76.18235779, 10.12902737], [76.18235779, 10.12958336], [76.18208313, 10.12958336], [76.18208313, 10.13069534], [76.18180847, 10.13069534], [76.18180847, 10.13124943], [76.18152618, 10.13124943], [76.18152618, 10.13181019], [76.18125153, 10.13181019], [76.18125153, 10.13264179], [76.18096924, 10.13263988], [76.18096924, 10.13319111], [76.18068695, 10.13319969], [76.18069458, 10.13486195], [76.18041992, 10.13486195], [76.18041992, 10.13541985], [76.18013763, 10.13541794], [76.18013763, 10.13569355], [76.17986298, 10.13569069], [76.17986298, 10.13652992], [76.17958069, 10.13652992], [76.17958069, 10.13764], [76.17930603, 10.13764], [76.17930603, 10.13792038], [76.17903137, 10.13792038], [76.17903137, 10.13875008], [76.17874908, 10.13875008], [76.17874908, 10.13931274], [76.1784668, 10.13931274], [76.1784668, 10.14042091], [76.17819214, 10.14042091], [76.17819214, 10.14264011], [76.17791748, 10.14263821], [76.17791748, 10.14347172], [76.17763519, 10.14347172], [76.17763519, 10.14375019], [76.17736053, 10.14375019], [76.17736053, 10.14458466], [76.17708588, 10.14457989], [76.17708588, 10.14625072], [76.17679596, 10.14625072], [76.17679596, 10.14681053], [76.17652893, 10.14680672], [76.17652893, 10.14708233], [76.17624664, 10.14708233], [76.17624664, 10.1473608], [76.17597198, 10.1473608], [76.17597198, 10.14792061], [76.17624664, 10.14792061], [76.17624664, 10.14931107], [76.17597198, 10.14930534], [76.17597198, 10.15013885], [76.17569733, 10.15013885], [76.17569733, 10.15041924], [76.17541504, 10.15041733], [76.17541504, 10.15069485], [76.17514038, 10.15069008], [76.17514038, 10.15125084], [76.17485809, 10.15125084], [76.17485809, 10.15153122], [76.17458344, 10.1515274], [76.17458344, 10.15319538], [76.17430878, 10.15319061], [76.17430878, 10.15402889], [76.17402649, 10.15402699], [76.17402649, 10.15458298], [76.17375183, 10.15458107], [76.17375183, 10.15514183], [76.17346954, 10.15513897], [76.17346954, 10.15597343], [76.17318726, 10.15597057], [76.17318726, 10.15680981], [76.17292023, 10.15680504], [76.17292023, 10.15736103], [76.17263794, 10.15736103], [76.17263794, 10.15763855], [76.17236328, 10.15763855], [76.17236328, 10.15875244], [76.17208099, 10.15875244], [76.17208099, 10.15931034], [76.17180634, 10.15930462], [76.17180634, 10.15984058], [76.17180634, 10.16014194], [76.17152405, 10.16014004], [76.17152405, 10.16069317], [76.17124939, 10.16069126], [76.17124939, 10.16125202], [76.17097473, 10.16125011], [76.17097473, 10.16208363], [76.17069244, 10.16207886], [76.17069244, 10.16292], [76.17041779, 10.16292], [76.17041779, 10.16374969], [76.1701355, 10.16374969], [76.1701355, 10.16458416], [76.16986084, 10.16457939], [76.16986084, 10.16514015], [76.16958618, 10.16514015], [76.16958618, 10.16597176], [76.16929626, 10.16596985], [76.16929626, 10.16681099], [76.16902924, 10.16680622], [76.16902924, 10.16708374], [76.16874695, 10.16708183], [76.16874695, 10.16763973], [76.16847229, 10.16763783], [76.16847229, 10.16847229], [76.16819763, 10.16846085], [76.16819763, 10.16903114], [76.16792297, 10.16903114], [76.16792297, 10.16931057], [76.16764069, 10.16931057], [76.16764069, 10.16986179], [76.1673584, 10.16986179], [76.1673584, 10.17042065], [76.16708374, 10.17041588], [76.16708374, 10.17097187], [76.16680908, 10.17097187], [76.16680908, 10.17152786], [76.16652679, 10.17152786], [76.16652679, 10.17208195], [76.16680908, 10.17208195], [76.16680908, 10.17236042], [76.16652679, 10.17236042], [76.16652679, 10.17347336], [76.16625214, 10.17346954], [76.16625214, 10.17375088], [76.16652679, 10.17375088], [76.16652679, 10.17403126], [76.16625214, 10.17402554], [76.16625214, 10.17486095], [76.16596985, 10.17486095], [76.16596985, 10.17569542], [76.16625214, 10.17569542], [76.16625214, 10.17847347], [76.16680908, 10.17847061], [76.16680908, 10.17903137], [76.16707611, 10.17903137], [76.16707611, 10.18014145], [76.1673584, 10.18013859], [76.1673584, 10.18069458], [76.16764069, 10.18069458], [76.16764069, 10.18097305], [76.16792297, 10.18097115], [76.16792297, 10.18125057], [76.16819763, 10.18125057], [76.16819763, 10.18153191], [76.16847229, 10.18152714], [76.16847229, 10.18208313], [76.16863251, 10.18208313], [76.16902924, 10.18208313], [76.16902924, 10.18236065], [76.1692276, 10.18236065], [76.16930389, 10.18236065], [76.16929626, 10.18264198], [76.16958618, 10.18264198], [76.16958618, 10.18292046], [76.16986084, 10.18291664], [76.16986084, 10.18319321], [76.17097473, 10.18319321], [76.17097473, 10.18347263], [76.17208099, 10.18347263], [76.17208099, 10.1837492], [76.17318726, 10.1837492], [76.17318726, 10.18402958], [76.17402649, 10.18402958], [76.17402649, 10.1837492], [76.17424774, 10.1837492], [76.17458344, 10.1837492], [76.17458344, 10.18347263], [76.17514038, 10.18347263], [76.17514038, 10.18319321], [76.17597198, 10.18319321], [76.17597198, 10.18236065], [76.17624664, 10.18236065], [76.17624664, 10.18069458], [76.17652893, 10.18069458], [76.17652893, 10.1795826], [76.17680359, 10.1795826], [76.17680359, 10.17930508], [76.17708588, 10.17930889], [76.17708588, 10.17847061], [76.17736053, 10.17847347], [76.17736053, 10.17525005], [76.17736053, 10.17513943], [76.17765045, 10.17514133], [76.17765045, 10.17403126], [76.17791748, 10.17403126], [76.17791748, 10.17375088], [76.17819214, 10.17375088], [76.17819214, 10.17346954], [76.17847443, 10.17347336], [76.17847443, 10.17319489], [76.17874908, 10.17319489], [76.17874908, 10.17291641], [76.17930603, 10.17292118], [76.17930603, 10.17236042], [76.17958069, 10.17236042], [76.17958069, 10.17208195], [76.17986298, 10.17208195], [76.17986298, 10.17180443], [76.18013763, 10.1718111], [76.18013763, 10.17125034], [76.18069458, 10.17125034], [76.18068695, 10.17096996], [76.18152618, 10.17097187], [76.18152618, 10.17041588], [76.18180847, 10.17042065], [76.18180847, 10.16986179], [76.18208313, 10.16986179], [76.18208313, 10.16958046], [76.18235779, 10.16958427], [76.18235779, 10.1693058], [76.18264008, 10.16931057], [76.18264008, 10.16903114], [76.1829071, 10.16903114], [76.1829071, 10.16875267], [76.18319702, 10.16875267], [76.18319702, 10.16819191], [76.18347168, 10.16819382], [76.18347168, 10.16763783], [76.18374634, 10.16763973], [76.18374634, 10.16736031], [76.18402863, 10.16736221], [76.18402863, 10.16680622], [76.18430328, 10.16681099], [76.18430328, 10.16652966], [76.18486023, 10.16652966], [76.18486023, 10.16625023], [76.18514252, 10.16625023], [76.18514252, 10.16569424], [76.18541718, 10.16569424], [76.18541718, 10.16514015], [76.18624878, 10.16514015], [76.18624878, 10.16485977], [76.18680573, 10.16485977], [76.18680573, 10.16458416], [76.18736267, 10.16458416], [76.18736267, 10.16430569], [76.18791962, 10.16431046], [76.18791962, 10.16403008], [76.18846893, 10.16403008], [76.18846893, 10.16374969], [76.1904068, 10.16374969], [76.1904068, 10.16346931], [76.19069672, 10.16347218], [76.19069672, 10.1631937], [76.19125366, 10.1631937], [76.19125366, 10.16291809], [76.19152832, 10.16292], [76.19152832, 10.16265106], [76.1920929, 10.16265106], [76.1920929, 10.16236019], [76.19319153, 10.1623621], [76.19319153, 10.16180611], [76.19346619, 10.16180992], [76.19346619, 10.16097164], [76.19319153, 10.16097164], [76.19319153, 10.15958405], [76.19347382, 10.15958405], [76.19347382, 10.15930462], [76.19319153, 10.15931034], [76.19319153, 10.15819073], [76.19347382, 10.15819645], [76.19347382, 10.15763855], [76.19374847, 10.15763855], [76.19374847, 10.15708065], [76.19403076, 10.15708256], [76.19403076, 10.15569305], [76.19430542, 10.15569305], [76.19430542, 10.15541744], [76.19458008, 10.1554203], [76.19458008, 10.15486145], [76.19486237, 10.15486145], [76.19486237, 10.15458298], [76.19513702, 10.15458298], [76.19513702, 10.15402699], [76.19541931, 10.15402889], [76.19541931, 10.15347958], [76.19568634, 10.15347958], [76.19568634, 10.1526413], [76.19625092, 10.1526413], [76.19625092, 10.15236092], [76.19652557, 10.15236092], [76.19652557, 10.15180492], [76.19680786, 10.1518116], [76.19680786, 10.15097141], [76.19708252, 10.15097332], [76.19708252, 10.15041733], [76.19763947, 10.15041924], [76.19763947, 10.15013885], [76.19791412, 10.15013885], [76.19790649, 10.14986134], [76.19819641, 10.14986134], [76.19819641, 10.14958286], [76.19791412, 10.14958286], [76.19791412, 10.14847279], [76.19819641, 10.14847279], [76.19819641, 10.14819527], [76.19875336, 10.14819527], [76.19875336, 10.14791679], [76.19902802, 10.14792061], [76.19902802, 10.14625072], [76.19876099, 10.14625072], [76.19876099, 10.14514065], [76.19902802, 10.14514065], [76.19902802, 10.14347172], [76.19930267, 10.14347172], [76.19930267, 10.1431942], [76.19958496, 10.1431942], [76.19958496, 10.14291573], [76.19985962, 10.14292145], [76.19985962, 10.14235973], [76.20014191, 10.14235973], [76.20014191, 10.14208221], [76.20041656, 10.14208221], [76.20041656, 10.14180565], [76.20069122, 10.14181137], [76.20069122, 10.14153957], [76.20096588, 10.14153957], [76.20096588, 10.14097023], [76.20124817, 10.14097214], [76.20124817, 10.14069366], [76.20153046, 10.14069366], [76.20153046, 10.14041615], [76.20182037, 10.14042091], [76.20182037, 10.13958168], [76.20207977, 10.13958359], [76.20207977, 10.1390276], [76.20263672, 10.1390276], [76.20263672, 10.13958359], [76.20236206, 10.13958168], [76.20236206, 10.14013958], [76.20207977, 10.14013767], [76.20207977, 10.14097214], [76.20182037, 10.14097023], [76.20182037, 10.14153957], [76.20153046, 10.14153957], [76.20153046, 10.14181137], [76.20124817, 10.14180565], [76.20124817, 10.14208221], [76.20153046, 10.14208221], [76.20153046, 10.14235973], [76.20124817, 10.14235973], [76.20124817, 10.14292145], [76.20097351, 10.14291573], [76.20097351, 10.14347172], [76.20069122, 10.14347172], [76.20069122, 10.14403057], [76.20041656, 10.14402771], [76.20041656, 10.14458466], [76.20014191, 10.14457989], [76.20014191, 10.14681053], [76.20041656, 10.14680672], [76.20041656, 10.1473608], [76.20069122, 10.1473608], [76.20069122, 10.14764118], [76.20041656, 10.14763927], [76.20041656, 10.14819527], [76.20069122, 10.14819527], [76.20069122, 10.14847279], [76.20096588, 10.14846992], [76.20096588, 10.14875126], [76.20124817, 10.14875126], [76.20124817, 10.14903069], [76.20153046, 10.14903069], [76.20153046, 10.14931107], [76.20180511, 10.14930534], [76.20180511, 10.14958286], [76.20263672, 10.14958286], [76.20263672, 10.14902878], [76.20291901, 10.14903069], [76.20291901, 10.14875126], [76.20263672, 10.14875126], [76.20263672, 10.14819527], [76.20236206, 10.14819527], [76.20236206, 10.14791679], [76.20207977, 10.14792061], [76.20207977, 10.14764118], [76.20291901, 10.14764118], [76.20291901, 10.14792061], [76.20375061, 10.14791679], [76.20375061, 10.14875126], [76.20347595, 10.14875126], [76.20347595, 10.14958286], [76.20291901, 10.14958286], [76.20291901, 10.14986134], [76.20263672, 10.14986134], [76.20263672, 10.15041924], [76.20319366, 10.15041733], [76.20319366, 10.15069485], [76.20375061, 10.15069008], [76.20375061, 10.15125084], [76.2040329, 10.15125084], [76.2040329, 10.1518116], [76.20375061, 10.15180492], [76.20375061, 10.1520834], [76.20153046, 10.1520834], [76.20153046, 10.15180492], [76.20182037, 10.1518116], [76.20182037, 10.15153122], [76.20153046, 10.15153122], [76.20153046, 10.15097141], [76.20124817, 10.15097332], [76.20124817, 10.15069485], [76.20097351, 10.15069485], [76.20097351, 10.14902878], [76.19957733, 10.14903069], [76.19957733, 10.15153122], [76.19902802, 10.15153122], [76.19902802, 10.1518116], [76.19875336, 10.15180492], [76.19875336, 10.1520834], [76.19819641, 10.1520834], [76.19819641, 10.15236092], [76.19790649, 10.15236092], [76.19790649, 10.1526413], [76.19763947, 10.15263939], [76.19763947, 10.15319538], [76.19735718, 10.15319061], [76.19736481, 10.15375137], [76.19708252, 10.15375137], [76.19708252, 10.15431023], [76.19680786, 10.15430546], [76.19680786, 10.15458298], [76.19652557, 10.15458298], [76.19652557, 10.15569305], [76.19596863, 10.15569305], [76.19596863, 10.15597343], [76.19569397, 10.15597343], [76.19569397, 10.15708256], [76.19541931, 10.15708256], [76.19541931, 10.15819645], [76.19513702, 10.15819073], [76.19513702, 10.15903187], [76.19486237, 10.15903187], [76.19486237, 10.16042042], [76.19458008, 10.16042042], [76.19458008, 10.16152954], [76.19430542, 10.16152763], [76.19430542, 10.16208363], [76.19403076, 10.16208363], [76.19403076, 10.1623621], [76.19374847, 10.1623621], [76.19374847, 10.1631937], [76.19346619, 10.16319084], [76.19346619, 10.16374969], [76.19319153, 10.16374969], [76.19319153, 10.16403008], [76.19291687, 10.16403008], [76.19291687, 10.16431046], [76.19125366, 10.16430569], [76.19125366, 10.16458416], [76.19069672, 10.16458416], [76.19069672, 10.16485977], [76.18985748, 10.16485977], [76.18985748, 10.16514015], [76.18818665, 10.16514015], [76.18818665, 10.16541958], [76.18763733, 10.16541576], [76.18763733, 10.16569424], [76.18708038, 10.16569424], [76.18708038, 10.16597176], [76.18680573, 10.16597176], [76.18680573, 10.16625023], [76.18653107, 10.16625023], [76.18653107, 10.16652966], [76.18624878, 10.16652775], [76.18624878, 10.16708374], [76.18596649, 10.16708183], [76.18596649, 10.16763973], [76.18569183, 10.16763783], [76.18569183, 10.16819382], [76.18541718, 10.16819191], [76.18541718, 10.16903114], [76.18514252, 10.16903114], [76.18514252, 10.16986179], [76.1845932, 10.16986179], [76.1845932, 10.17042065], [76.18430328, 10.17041588], [76.18430328, 10.17097187], [76.18402863, 10.17097187], [76.18402863, 10.17125034], [76.18347168, 10.17125034], [76.18347168, 10.17152786], [76.18319702, 10.17151928], [76.18319702, 10.1718111], [76.18291473, 10.17180443], [76.18291473, 10.17208195], [76.18180847, 10.17208195], [76.18180847, 10.17180443], [76.18125153, 10.17180443], [76.18125153, 10.17208195], [76.18096924, 10.17208195], [76.18096924, 10.17236042], [76.18068695, 10.17236042], [76.18068695, 10.1726408], [76.18041992, 10.1726408], [76.18041992, 10.17292118], [76.18013763, 10.17291641], [76.18013763, 10.17347336], [76.17986298, 10.17346954], [76.17986298, 10.17375088], [76.17958069, 10.17375088], [76.17958069, 10.17431068], [76.17930603, 10.17431068], [76.17930603, 10.17541885], [76.17903137, 10.17541695], [76.17903137, 10.17597294], [76.17874908, 10.17597294], [76.17874908, 10.17708302], [76.1784668, 10.17708015], [76.1784668, 10.17903137], [76.17819214, 10.17903137], [76.17819214, 10.18014145], [76.17791748, 10.18014145], [76.17791748, 10.18042183], [76.17819214, 10.18041706], [76.17819214, 10.18069458], [76.17791748, 10.18069458], [76.17791748, 10.18097305], [76.17763519, 10.18097305], [76.17763519, 10.18208313], [76.17736053, 10.18208122], [76.17736053, 10.18264198], [76.17708588, 10.18263912], [76.17709351, 10.18345261], [76.17736053, 10.18347263], [76.17736053, 10.18355083], [76.17736053, 10.1837492], [76.17767334, 10.18375397], [76.17765045, 10.18402958], [76.17819214, 10.18402958], [76.17819214, 10.18430996], [76.17847443, 10.18430519], [76.17847443, 10.18458271], [76.17930603, 10.18458271], [76.17930603, 10.1847496], [76.17930603, 10.18542194], [76.17958069, 10.18542194], [76.17958069, 10.18625164], [76.18068695, 10.18625164], [76.18068695, 10.18682098], [76.18041992, 10.18680573], [76.18041992, 10.18736172], [76.18096924, 10.18735886], [76.18096924, 10.18764019], [76.18180847, 10.18764019], [76.18180847, 10.18791962], [76.18235779, 10.18791771], [76.18235779, 10.18819427], [76.1829071, 10.18819141], [76.1829071, 10.18847179], [76.18319702, 10.18847179], [76.18319702, 10.18902969], [76.18345642, 10.18902969], [76.18345642, 10.18931007], [76.18430328, 10.18931007], [76.18430328, 10.18959141], [76.18597412, 10.18958378], [76.18597412, 10.18986225], [76.18653107, 10.18986034], [76.18653107, 10.19013977], [76.18708038, 10.19013977], [76.18708038, 10.19042015], [76.18902588, 10.19041634], [76.18902588, 10.19069386], [76.19041443, 10.19069386], [76.19041443, 10.19097233], [76.19152832, 10.19097233], [76.19152832, 10.19124985], [76.19208527, 10.19124985], [76.19208527, 10.19097233], [76.19235992, 10.19097042], [76.19235992, 10.19153023], [76.19208527, 10.19152832], [76.19208527, 10.19235992], [76.19180298, 10.19235992], [76.19180298, 10.19347191], [76.19152832, 10.19347191], [76.19152832, 10.19431114], [76.19125366, 10.19430637], [76.19125366, 10.19486237], [76.18875122, 10.19486237], [76.18875122, 10.19458199], [76.18708038, 10.19458199], [76.18708038, 10.19430637], [76.18653107, 10.19431114], [76.18653107, 10.19403267], [76.18596649, 10.19403267], [76.18596649, 10.19375038], [76.18514252, 10.19375038], [76.18514252, 10.19347191], [76.18458557, 10.19347191], [76.18458557, 10.19319439], [76.18430328, 10.19319439], [76.18430328, 10.19291592], [76.18374634, 10.19291973], [76.18374634, 10.19262886], [76.18319702, 10.1926403], [76.18319702, 10.19235992], [76.18264008, 10.19235992], [76.18264008, 10.19208431], [76.18208313, 10.19208431], [76.18208313, 10.19180584], [76.18125153, 10.19181061], [76.18125153, 10.19153023], [76.18068695, 10.19153023], [76.18068695, 10.19124985], [76.17986298, 10.19124985], [76.17986298, 10.19097233], [76.17874908, 10.19097233], [76.17874908, 10.19069386], [76.17847443, 10.19069386], [76.17847443, 10.19041634], [76.17819214, 10.19042015], [76.17819214, 10.19013977], [76.17765045, 10.19013977], [76.17765045, 10.18986034], [76.17597198, 10.18986225], [76.17597198, 10.18930626], [76.17569733, 10.18931007], [76.17569733, 10.18902969], [76.17459106, 10.18902969], [76.17459106, 10.18875027], [76.17318726, 10.18875027], [76.17318726, 10.18847179], [76.17208099, 10.18847179], [76.17208099, 10.18819427], [76.17069244, 10.18819427], [76.17069244, 10.18791771], [76.16845703, 10.18791962], [76.16845703, 10.18764019], [76.16819763, 10.18764019], [76.16819763, 10.18791962], [76.16792297, 10.18791962], [76.16792297, 10.18764019], [76.1673584, 10.18764019], [76.1673584, 10.18791962], [76.16513824, 10.18791962], [76.16513824, 10.18735886], [76.1645813, 10.18736172], [76.1645813, 10.18652725], [76.16485596, 10.18653202], [76.16485596, 10.18597126], [76.16513824, 10.18597126], [76.16513824, 10.18541527], [76.16542053, 10.18542194], [76.16542053, 10.1845789], [76.16596985, 10.18458271], [76.16596985, 10.18402672], [76.16625214, 10.18402958], [76.16625214, 10.1837492], [76.16569519, 10.1837492], [76.16569519, 10.18291664], [76.16542053, 10.18292046], [76.16542053, 10.18264198], [76.16513824, 10.18264198], [76.16513824, 10.18237019], [76.16513824, 10.18208313], [76.1645813, 10.18208313], [76.1645813, 10.18180466], [76.16347504, 10.18180466], [76.16347504, 10.18236065], [76.16319275, 10.18236065], [76.16319275, 10.18264198], [76.16291809, 10.18263912], [76.16291809, 10.18319321], [76.1626358, 10.18319321], [76.1626358, 10.18347263], [76.16236115, 10.18346024], [76.16236115, 10.18402958], [76.16208649, 10.18402672], [76.16208649, 10.18458271], [76.16179657, 10.1845789], [76.16179657, 10.18542194], [76.16152954, 10.18541527], [76.16152954, 10.18597126], [76.16124725, 10.18597126], [76.16124725, 10.18653202], [76.1609726, 10.18653202], [76.1609726, 10.18682098], [76.16069794, 10.18682098], [76.16069794, 10.18791962], [76.16041565, 10.18791771], [76.16041565, 10.18847179], [76.1598587, 10.18847179], [76.1598587, 10.18959141], [76.15957642, 10.18959141], [76.15958405, 10.19124985], [76.15930939, 10.19124985], [76.15930939, 10.19153023], [76.15957642, 10.19153023], [76.15957642, 10.19181061], [76.15930939, 10.19180584], [76.15930176, 10.19235992], [76.1590271, 10.19235992], [76.1590271, 10.19291973], [76.15875244, 10.19291592], [76.15875244, 10.19347191], [76.15847015, 10.19347191], [76.15847015, 10.19375038], [76.15820313, 10.19375038], [76.15820313, 10.19431114], [76.15791321, 10.19430637], [76.15791321, 10.19486237], [76.15763855, 10.19486046], [76.15763855, 10.19542122], [76.15735626, 10.19542122], [76.15735626, 10.1965313], [76.1570816, 10.19652843], [76.1570816, 10.19708443], [76.15680695, 10.19708443], [76.15680695, 10.19847202], [76.15652466, 10.19847202], [76.15652466, 10.1995821], [76.15625, 10.1995821], [76.15625, 10.20069504], [76.15598297, 10.20069027], [76.15598297, 10.20153141], [76.15569305, 10.20152569], [76.15569305, 10.20208263], [76.1554184, 10.20208263], [76.1554184, 10.20236111], [76.15513611, 10.20236111], [76.15513611, 10.20292091], [76.15486145, 10.2029171], [76.15486145, 10.20319462], [76.15458679, 10.20319462], [76.15458679, 10.20347309], [76.1543045, 10.20347309], [76.1543045, 10.20569515], [76.15402985, 10.20569038], [76.15402985, 10.2068119], [76.15374756, 10.20680523], [76.15374756, 10.20763874], [76.1534729, 10.20763874], [76.1534729, 10.20819473], [76.15319824, 10.20819092], [76.15319824, 10.20875072], [76.15291595, 10.20875072], [76.15291595, 10.2090292], [76.1526413, 10.20902729], [76.1526413, 10.20958328], [76.15235901, 10.20958138], [76.15235901, 10.21070004], [76.1526413, 10.21069527], [76.1526413, 10.21097088], [76.15235901, 10.21097088], [76.15235901, 10.21124935], [76.15208435, 10.21124935], [76.15208435, 10.21236134], [76.15180206, 10.21236134], [76.15180206, 10.2131958], [76.1515274, 10.21319103], [76.1515274, 10.21376133], [76.15125275, 10.21374893], [76.15125275, 10.21486187], [76.15097046, 10.21486187], [76.15097046, 10.21569443], [76.1506958, 10.21569443], [76.1506958, 10.21625042], [76.15041351, 10.21625042], [76.15041351, 10.2173624], [76.15013885, 10.21735954], [76.15013885, 10.21875], [76.14985657, 10.21875], [76.14985657, 10.21931267], [76.14958191, 10.21930599], [76.14958191, 10.21986198], [76.14930725, 10.21986198], [76.14930725, 10.22014046], [76.14902496, 10.2201376], [76.14902496, 10.22097206], [76.14875031, 10.22097206], [76.14875031, 10.22236156], [76.14847565, 10.22236156], [76.14847565, 10.22347164], [76.14819336, 10.22347164], [76.14819336, 10.22486019], [76.1479187, 10.22486019], [76.1479187, 10.22542095], [76.14763641, 10.22542095], [76.14763641, 10.22653103], [76.14736176, 10.22653103], [76.14736176, 10.22681141], [76.1470871, 10.22680664], [76.1470871, 10.22735977], [76.14653015, 10.22735977], [76.14653015, 10.22875118], [76.14624786, 10.22875118], [76.14624786, 10.22958279], [76.14597321, 10.22958279], [76.14597321, 10.23124886], [76.14569092, 10.23124886], [76.14569092, 10.23208332], [76.14541626, 10.23208141], [76.14541626, 10.23264122], [76.1451416, 10.23264122], [76.1451416, 10.2329216], [76.14485931, 10.23291683], [76.14485931, 10.23347092], [76.14457703, 10.23347092], [76.14457703, 10.23403168], [76.14428711, 10.23403168], [76.14428711, 10.23431015], [76.14402771, 10.23431015], [76.14402771, 10.23542023], [76.14428711, 10.23542023], [76.14428711, 10.23652935], [76.14402771, 10.23652935], [76.14402771, 10.23680973], [76.14430237, 10.23680496], [76.14430237, 10.23708344], [76.14402771, 10.23708057], [76.14402771, 10.23763943], [76.14375305, 10.23763943], [76.14375305, 10.23819542], [76.14347076, 10.23819065], [76.14347076, 10.23903179], [76.14319611, 10.23902702], [76.14319611, 10.23958302], [76.14290619, 10.23958111], [76.14290619, 10.24014187], [76.14263916, 10.24014187], [76.14263916, 10.24042034], [76.1423645, 10.24041843], [76.1423645, 10.24208355], [76.14208221, 10.24208069], [76.14208221, 10.24291992], [76.1423645, 10.24291801], [76.1423645, 10.24319363], [76.14208221, 10.24318886], [76.14208221, 10.24431038], [76.14180756, 10.24430561], [76.14180756, 10.24458408], [76.14208221, 10.24458408], [76.14208221, 10.2448597], [76.14180756, 10.2448597], [76.14180756, 10.24514008], [76.14152527, 10.24514008], [76.14152527, 10.24569416], [76.14125061, 10.24569416], [76.14125061, 10.24625015], [76.14097595, 10.24625015], [76.14097595, 10.24681091], [76.14069366, 10.24680614], [76.14069366, 10.24708366], [76.14041901, 10.24708366], [76.14041901, 10.24847221], [76.14013672, 10.24847221], [76.14013672, 10.2495842], [76.13986206, 10.24958038], [76.13986206, 10.25042057], [76.13957977, 10.2504158], [76.13957977, 10.25097179], [76.13930511, 10.25097179], [76.13930511, 10.25125027], [76.13903046, 10.25125027], [76.13903046, 10.25181103], [76.13874817, 10.25180435], [76.13874817, 10.25208473], [76.13847351, 10.25208473], [76.13847351, 10.25236034], [76.13874817, 10.25236034], [76.13874817, 10.25431061], [76.13819122, 10.25431061], [76.13819122, 10.25514126], [76.13791656, 10.25514126], [76.13791656, 10.25652885], [76.13764191, 10.25652885], [76.13764191, 10.25736141], [76.13735962, 10.25736141], [76.13735962, 10.25791931], [76.13708496, 10.2579174], [76.13708496, 10.2584734], [76.13680267, 10.25847054], [76.13680267, 10.2590313], [76.13652802, 10.25902653], [76.13652802, 10.26097107], [76.13625336, 10.26097107], [76.13625336, 10.26153183], [76.13597107, 10.26152706], [76.13597107, 10.26236057], [76.13625336, 10.26236057], [76.13625336, 10.26347256], [76.13597107, 10.26347256], [76.13597107, 10.26458263], [76.13569641, 10.26458073], [76.13569641, 10.26513863], [76.13541412, 10.26513863], [76.13541412, 10.26597118], [76.13513947, 10.26597118], [76.13513947, 10.26653194], [76.13485718, 10.26653194], [76.13485718, 10.26681042], [76.13458252, 10.2668047], [76.13458252, 10.26736164], [76.13430786, 10.26736164], [76.13430786, 10.26764202], [76.13458252, 10.26764011], [76.13458252, 10.26791763], [76.13430786, 10.26791763], [76.13430786, 10.2695837], [76.1340332, 10.26958084], [76.1340332, 10.27013969], [76.13375092, 10.27013969], [76.13375092, 10.27124977], [76.13346863, 10.27124977], [76.13346863, 10.27319431], [76.13318634, 10.27319241], [76.13318634, 10.27431107], [76.13291931, 10.2743063], [76.13291931, 10.27486229], [76.13263702, 10.27486038], [76.13263702, 10.27514267], [76.13291931, 10.27514267], [76.13291931, 10.27542114], [76.13263702, 10.27542114], [76.13263702, 10.27653122], [76.13234711, 10.27653122], [76.13236237, 10.27735996], [76.13208008, 10.27735996], [76.13208008, 10.27792072], [76.13180542, 10.27791595], [76.13180542, 10.27847195], [76.13153076, 10.27847195], [76.13153076, 10.27875042], [76.13124847, 10.27875042], [76.13124847, 10.27931118], [76.13096619, 10.27931118], [76.13096619, 10.28042126], [76.13069153, 10.28042126], [76.13069153, 10.28125095], [76.13096619, 10.28125095], [76.13096619, 10.28264141], [76.13069153, 10.28263855], [76.13069153, 10.28291702], [76.13041687, 10.28291035], [76.13041687, 10.28430939], [76.13014221, 10.28430939], [76.13014221, 10.28514099], [76.12985992, 10.28514099], [76.12985992, 10.28653145], [76.12958527, 10.28652668], [76.12958527, 10.28708267], [76.12985992, 10.2870779], [76.12985992, 10.28764057], [76.12960052, 10.28764057], [76.12960052, 10.28931046], [76.12928772, 10.28931046], [76.12928772, 10.2901392], [76.12902832, 10.2901392], [76.12902832, 10.29069328], [76.12874603, 10.29069138], [76.12874603, 10.29152966], [76.12847137, 10.29152966], [76.12847137, 10.29264164], [76.12819672, 10.29263878], [76.12819672, 10.29319572], [76.12791443, 10.29319572], [76.12791443, 10.29458427], [76.12763977, 10.29458427], [76.12763977, 10.29597187], [76.12735748, 10.29597187], [76.12735748, 10.29652977], [76.12708282, 10.29652977], [76.12708282, 10.29681015], [76.12680817, 10.29681015], [76.12680817, 10.29792023], [76.12654114, 10.29792023], [76.12654114, 10.2990303], [76.12625122, 10.2990303], [76.12625122, 10.29931068], [76.12652588, 10.29930592], [76.12652588, 10.29958439], [76.12625122, 10.29958439], [76.12625122, 10.29986191], [76.12596893, 10.29986191], [76.12596893, 10.30098057], [76.12541962, 10.30098057], [76.12541962, 10.30153275], [76.12513733, 10.30153275], [76.12513733, 10.30263996], [76.12486267, 10.30263996], [76.12486267, 10.3029213], [76.12431335, 10.3029213], [76.12431335, 10.30375004], [76.12458038, 10.30375004], [76.12458038, 10.30486012], [76.12430573, 10.30486012], [76.12430573, 10.30569363], [76.12403107, 10.30569363], [76.12403107, 10.3059721], [76.12431335, 10.30597019], [76.12431335, 10.30764103], [76.12403107, 10.30763817], [76.12403107, 10.30819511], [76.12374878, 10.30819511], [76.12374878, 10.30875111], [76.12348175, 10.30875111], [76.12348175, 10.30903053], [76.12319183, 10.30902863], [76.12319183, 10.30958271], [76.12291718, 10.30957985], [76.12291718, 10.31153107], [76.12264252, 10.31153107], [76.12264252, 10.31264114], [76.12236023, 10.31264114], [76.12236023, 10.31292152], [76.12208557, 10.31291676], [76.12208557, 10.31375122], [76.12180328, 10.31375122], [76.12180328, 10.31458282], [76.12208557, 10.31458282], [76.12208557, 10.3148613], [76.12180328, 10.3148613], [76.12180328, 10.31514072], [76.12152863, 10.31513882], [76.12152863, 10.31624889], [76.12124634, 10.31624889], [76.12124634, 10.31680965], [76.12097168, 10.31680965], [76.12097168, 10.31791973], [76.12069702, 10.31791687], [76.12069702, 10.31874943], [76.1204071, 10.31874943], [76.1204071, 10.31931019], [76.12014008, 10.31931019], [76.12014008, 10.32014179], [76.11985779, 10.32014179], [76.11985779, 10.32153034], [76.11958313, 10.32152843], [76.11958313, 10.32236195], [76.11930847, 10.32236195], [76.11930847, 10.32291985], [76.11902618, 10.32291794], [76.11902618, 10.32319355], [76.11846924, 10.32319069], [76.11846924, 10.32374954], [76.11875153, 10.32374954], [76.11875153, 10.3243103], [76.11846924, 10.3243103], [76.11846924, 10.32542038], [76.11818695, 10.32542038], [76.11818695, 10.32625008], [76.11791992, 10.32625008], [76.11791992, 10.32763958], [76.11818695, 10.32763958], [76.11818695, 10.32792091], [76.11791992, 10.32791805], [76.11791992, 10.32819366], [76.11763763, 10.3281889], [76.11763763, 10.32874966], [76.11734772, 10.32874966], [76.11736298, 10.32985973], [76.11708069, 10.32985973], [76.11708069, 10.33042145], [76.11680603, 10.33041573], [76.11680603, 10.3306942], [76.11653137, 10.33069038], [76.11653137, 10.33181095], [76.11624908, 10.33180428], [76.11624908, 10.33319378], [76.1159668, 10.33318996], [76.1159668, 10.33375072], [76.11569214, 10.33375072], [76.11569214, 10.33403111], [76.11541748, 10.33403111], [76.11541748, 10.33514118], [76.11514282, 10.33514118], [76.11514282, 10.33681107], [76.11486053, 10.33680534], [76.11486053, 10.33736134], [76.11460114, 10.33736134], [76.11460114, 10.33791924], [76.11431122, 10.33791924], [76.11431122, 10.33875084], [76.11402893, 10.33875084], [76.11402893, 10.33986092], [76.11374664, 10.33986092], [76.11374664, 10.34069538], [76.11347198, 10.34069538], [76.11347198, 10.34097099], [76.11319733, 10.34097099], [76.11319733, 10.34264088], [76.11292267, 10.34264088], [76.11292267, 10.34291935], [76.11235809, 10.34291935], [76.11235809, 10.34375095], [76.11207581, 10.34375095], [76.11207581, 10.34430981], [76.11180878, 10.34430504], [76.11180878, 10.34458256], [76.11152649, 10.34458256], [76.11152649, 10.34597111], [76.11125183, 10.34597111], [76.11120605, 10.34653187], [76.11096954, 10.34653187], [76.11096954, 10.34764194], [76.11068726, 10.34764194], [76.11068726, 10.34875202], [76.11042023, 10.34875202], [76.11042023, 10.34931946], [76.11013794, 10.34931946], [76.11013794, 10.35013962], [76.10986328, 10.35013962], [76.10986328, 10.3506937], [76.10958099, 10.3506937], [76.10958099, 10.35097218], [76.10930634, 10.35097218], [76.10930634, 10.35208416], [76.10901642, 10.35206985], [76.10901642, 10.35291958], [76.10874939, 10.35291576], [76.10874939, 10.35375023], [76.10847473, 10.35375023], [76.10847473, 10.35458374], [76.10819244, 10.35458374], [76.10819244, 10.35513783], [76.10791779, 10.35513783], [76.10791779, 10.35569382], [76.10764313, 10.35569191], [76.10764313, 10.35625172], [76.10736084, 10.35625172], [76.10736084, 10.35681057], [76.10708618, 10.35681057], [76.10708618, 10.35736179], [76.10680389, 10.35735989], [76.10680389, 10.35819435], [76.10652924, 10.35819435], [76.10652924, 10.35875034], [76.10624695, 10.35875034], [76.10624695, 10.35958195], [76.10597229, 10.35958004], [76.10597229, 10.3601408], [76.10569763, 10.3601408], [76.10569763, 10.36126041], [76.10540771, 10.36126041], [76.10540771, 10.36181068], [76.10514069, 10.36180687], [76.10514069, 10.36236095], [76.1048584, 10.36236095], [76.1048584, 10.36319542], [76.10457611, 10.3631897], [76.10458374, 10.36375141], [76.10430908, 10.36375141], [76.10430908, 10.36458302], [76.10402679, 10.36458302], [76.10402679, 10.365695], [76.10375214, 10.36569023], [76.10375214, 10.36625099], [76.10346985, 10.36625099], [76.10346985, 10.36680889], [76.10319519, 10.36680698], [76.10319519, 10.36819458], [76.1029129, 10.36819458], [76.1029129, 10.36847305], [76.10263824, 10.36847115], [76.10263824, 10.36903191], [76.10236359, 10.36902714], [76.10236359, 10.36958313], [76.1020813, 10.36958313], [76.1020813, 10.36986065], [76.10236359, 10.36986065], [76.10236359, 10.37013912], [76.1020813, 10.37013912], [76.1020813, 10.3712492], [76.10180664, 10.3712492], [76.10180664, 10.37180996], [76.10152435, 10.37180519], [76.10152435, 10.37236118], [76.10124969, 10.37236118], [76.10124969, 10.37320042], [76.10098267, 10.37320042], [76.10098267, 10.37375164], [76.10069275, 10.37374878], [76.10069275, 10.3745842], [76.10041809, 10.37458134], [76.10041809, 10.37514019], [76.1001358, 10.37514019], [76.1001358, 10.37541962], [76.09986115, 10.37541771], [76.09986115, 10.37708378], [76.09958649, 10.37708092], [76.09958649, 10.37792015], [76.0993042, 10.37791634], [76.0993042, 10.38069439], [76.09874725, 10.38069439], [76.09874725, 10.38097191], [76.0984726, 10.38097191], [76.0984726, 10.38125038], [76.09791565, 10.38125038], [76.09791565, 10.38208199], [76.09764099, 10.38208199], [76.09764099, 10.38292122], [76.0973587, 10.38291645], [76.0973587, 10.38319016], [76.09707642, 10.38320065], [76.09707642, 10.38374996], [76.09680939, 10.38374996], [76.09680176, 10.38458443], [76.0965271, 10.38458443], [76.0965271, 10.38569355], [76.09623718, 10.38568974], [76.09623718, 10.38653088], [76.09597015, 10.38653088], [76.09597015, 10.38681126], [76.09570313, 10.38681126], [76.09570313, 10.38764095], [76.09541321, 10.38764095], [76.09541321, 10.38820076], [76.09513855, 10.38820076], [76.09513855, 10.38931084], [76.09485626, 10.38931084], [76.09485626, 10.39014053], [76.0945816, 10.39014053], [76.0945816, 10.39042091], [76.09430695, 10.3904171], [76.09430695, 10.3912487], [76.09402466, 10.3912487], [76.09402466, 10.39208317], [76.09375, 10.39208031], [76.09375, 10.39292145], [76.09347534, 10.39291668], [76.09347534, 10.39347267], [76.0931778, 10.3934679], [76.0931778, 10.39403057], [76.0929184, 10.39402676], [76.0929184, 10.39486122], [76.09263611, 10.39486122], [76.09263611, 10.39597321], [76.09236145, 10.3959713], [76.09236145, 10.39680958], [76.09208679, 10.39680481], [76.09208679, 10.39708328], [76.09179688, 10.39708138], [76.09179688, 10.39763927], [76.09124756, 10.39763927], [76.09124756, 10.39903164], [76.0909729, 10.39902687], [76.0909729, 10.39958286], [76.09069824, 10.39958096], [76.09069824, 10.40043068], [76.09041595, 10.40041542], [76.09041595, 10.40097141], [76.0901413, 10.40097141], [76.0901413, 10.40180969], [76.08985901, 10.40180969], [76.08985901, 10.40264034], [76.08957672, 10.40264034], [76.08958435, 10.40375042], [76.08930206, 10.40375042], [76.08930206, 10.40402985], [76.0890274, 10.40402985], [76.0890274, 10.40431023], [76.08875275, 10.40431023], [76.08875275, 10.40513992], [76.08847046, 10.40513992], [76.08847046, 10.40625], [76.0881958, 10.40624142], [76.0881958, 10.40681267], [76.08790588, 10.40681267], [76.08790588, 10.40764046], [76.08763885, 10.4076376], [76.08763885, 10.40819359], [76.08737183, 10.40819168], [76.08737183, 10.40874958], [76.08708191, 10.40874958], [76.08708191, 10.40931129], [76.08680725, 10.40930557], [76.08680725, 10.40986156], [76.08651733, 10.40985966], [76.08651733, 10.41042137], [76.08625031, 10.41041565], [76.08625031, 10.41069412], [76.08598328, 10.41069031], [76.08598328, 10.41125011], [76.08569336, 10.41125011], [76.08569336, 10.41181087], [76.0854187, 10.41181087], [76.0854187, 10.41264057], [76.08513641, 10.41264057], [76.08513641, 10.41292095], [76.08486176, 10.41292095], [76.08486176, 10.41431141], [76.0845871, 10.41430664], [76.0845871, 10.41485977], [76.08429718, 10.41485977], [76.08429718, 10.41514111], [76.08403015, 10.41513824], [76.08403015, 10.41541672], [76.08374786, 10.41541195], [76.08374786, 10.41681099], [76.08347321, 10.41680527], [76.08347321, 10.41736126], [76.08319092, 10.41736126], [76.08319092, 10.41792107], [76.08291626, 10.41791725], [76.08291626, 10.41847324], [76.0826416, 10.41847134], [76.0826416, 10.41931152], [76.08291626, 10.41931152], [76.08291626, 10.41986084], [76.0826416, 10.41986084], [76.0826416, 10.4204216], [76.08235931, 10.42041683], [76.08235931, 10.4206953], [76.08180237, 10.4206953], [76.08180237, 10.4212513], [76.08152771, 10.4212513], [76.08152771, 10.42236137], [76.08125305, 10.42236137], [76.08125305, 10.42319489], [76.08097076, 10.42319489], [76.08097076, 10.42347336], [76.08069611, 10.42347145], [76.08069611, 10.42402935], [76.08040619, 10.42402935], [76.08040619, 10.42430973], [76.08013916, 10.42430496], [76.08013916, 10.42486095], [76.07985687, 10.42486095], [76.07985687, 10.42513943], [76.07958221, 10.42513943], [76.07958221, 10.42764187], [76.07930756, 10.42764187], [76.07930756, 10.42792034], [76.07902527, 10.42791843], [76.07902527, 10.42847061], [76.07875061, 10.42847061], [76.07875061, 10.42875195], [76.07820129, 10.42875195], [76.07820129, 10.42930984], [76.07791901, 10.42930603], [76.07791901, 10.43041801], [76.07763672, 10.43041134], [76.07763672, 10.43124962], [76.07736206, 10.43124962], [76.07736206, 10.43208408], [76.07707977, 10.43207932], [76.07707977, 10.43264008], [76.07681274, 10.43264008], [76.07681274, 10.43292046], [76.07624817, 10.43292046], [76.07624817, 10.43348122], [76.07596588, 10.43348122], [76.07596588, 10.43431091], [76.07569122, 10.43430614], [76.07569122, 10.43486214], [76.07543182, 10.43486023], [76.07543182, 10.43513966], [76.07514191, 10.43513966], [76.07514191, 10.43681145], [76.07485962, 10.43681145], [76.07485962, 10.43764019], [76.07458496, 10.43764019], [76.07458496, 10.43819427], [76.07430267, 10.43819427], [76.07430267, 10.43847179], [76.07402802, 10.43847179], [76.07402802, 10.43903065], [76.07375336, 10.43902779], [76.07375336, 10.43958378], [76.07347107, 10.43957996], [76.07347107, 10.44014072], [76.07319641, 10.44013786], [76.07319641, 10.4412508], [76.07291412, 10.4412508], [76.07291412, 10.44235992], [76.07263947, 10.44235134], [76.07263947, 10.44264126], [76.07208252, 10.44263935], [76.07208252, 10.44347286], [76.07180786, 10.44347], [76.07180786, 10.44430923], [76.07152557, 10.44430542], [76.07152557, 10.44458294], [76.07125092, 10.44458294], [76.07125092, 10.44486141], [76.07096863, 10.44486141], [76.07096863, 10.44514084], [76.07069397, 10.44513893], [76.07069397, 10.44569492], [76.07041931, 10.44569492], [76.07041931, 10.44708347], [76.07013702, 10.44708061], [76.07013702, 10.44791889], [76.06986237, 10.44791698], [76.06986237, 10.44819546], [76.06958008, 10.44818974], [76.06958008, 10.44847965], [76.06929779, 10.44847965], [76.06929779, 10.44903088], [76.06903076, 10.44903088], [76.06903076, 10.4493103], [76.06874847, 10.4493103], [76.06874847, 10.45014095], [76.06846619, 10.45014095], [76.06846619, 10.45125103], [76.06819153, 10.45125103], [76.06819153, 10.45181179], [76.06764221, 10.45180511], [76.06764221, 10.45208263], [76.06735992, 10.45208073], [76.06735992, 10.45292187], [76.0670929, 10.45292187], [76.0670929, 10.45431042], [76.06652832, 10.4543047], [76.06652832, 10.45597363], [76.06625366, 10.45597363], [76.06625366, 10.45625019], [76.06597137, 10.45625019], [76.06597137, 10.45681], [76.06541443, 10.45680618], [76.06541443, 10.4570837], [76.06513977, 10.4570837], [76.06513977, 10.45736217], [76.06485748, 10.45735931], [76.06485748, 10.45763969], [76.06513977, 10.45763969], [76.06513977, 10.45792007], [76.06485748, 10.45791626], [76.06485748, 10.45847225], [76.06458282, 10.45846939], [76.06458282, 10.45874977], [76.06430817, 10.45874977], [76.06430817, 10.45930958], [76.06402588, 10.45930576], [76.06402588, 10.45985985], [76.06375122, 10.45985985], [76.06375122, 10.46041965], [76.06346893, 10.46041584], [76.06346893, 10.46125031], [76.06319427, 10.46125031], [76.06319427, 10.46208191], [76.06291962, 10.46208382], [76.06291962, 10.46236229], [76.06263733, 10.46236038], [76.06263733, 10.46264172], [76.06236267, 10.4626379], [76.06236267, 10.46319389], [76.06208038, 10.46319199], [76.06208038, 10.46431065], [76.06180573, 10.46430588], [76.06180573, 10.46458435], [76.06153107, 10.46458435], [76.06153107, 10.46569443], [76.06124878, 10.46569443], [76.06124878, 10.46625042], [76.06097412, 10.46625042], [76.06097412, 10.46652794], [76.06041718, 10.46652794], [76.06041718, 10.46708202], [76.06014252, 10.46708202], [76.06014252, 10.46736336], [76.05986023, 10.46736336], [76.05986023, 10.46847343], [76.0595932, 10.46846962], [76.0595932, 10.46903133], [76.05930328, 10.46903133], [76.05930328, 10.46931076], [76.05902863, 10.46930695], [76.05902863, 10.4695816], [76.05874634, 10.4695816], [76.05874634, 10.46986103], [76.05902863, 10.46986103], [76.05902863, 10.47014141], [76.05874634, 10.47014141], [76.05874634, 10.47042084], [76.05847168, 10.47042084], [76.05847168, 10.47125053], [76.05819702, 10.47125053], [76.05819702, 10.47153091], [76.0579071, 10.47153091], [76.0579071, 10.47181129], [76.05764008, 10.47181129], [76.05764008, 10.47264957], [76.05735779, 10.47263908], [76.05735779, 10.4734726], [76.05706787, 10.47347069], [76.05706787, 10.47375107], [76.05680847, 10.47375107], [76.05680847, 10.47403145], [76.05652618, 10.47402668], [76.05652618, 10.47486115], [76.05625153, 10.47486115], [76.05625153, 10.47542191], [76.05596924, 10.47541714], [76.05596924, 10.47597313], [76.05568695, 10.47597122], [76.05568695, 10.47625065], [76.05541992, 10.47624874], [76.05541992, 10.47736073], [76.05513763, 10.47736073], [76.05513763, 10.47791958], [76.05486298, 10.47791672], [76.05486298, 10.47819519], [76.05458069, 10.47819519], [76.05458069, 10.47874928], [76.05432129, 10.47874928], [76.05432129, 10.47931194], [76.05403137, 10.47930527], [76.05403137, 10.47986126], [76.05374908, 10.47986126], [76.05374908, 10.48069572], [76.05347443, 10.48069572], [76.05347443, 10.48124886], [76.05319214, 10.48124886], [76.05319214, 10.48236179], [76.05264282, 10.48236179], [76.05264282, 10.48264027], [76.05236053, 10.48264027], [76.05236053, 10.4831934], [76.05208588, 10.48319054], [76.05208588, 10.48431015], [76.05180359, 10.48430634], [76.05180359, 10.48486233], [76.05152893, 10.48486042], [76.05152893, 10.48542023], [76.05124664, 10.48541641], [76.05124664, 10.4859724], [76.05097198, 10.48596859], [76.05097198, 10.48680973], [76.05041504, 10.48680592], [76.05041504, 10.48708439], [76.05014038, 10.48708153], [76.05014038, 10.48765087], [76.04985809, 10.48765087], [76.04985809, 10.48792267], [76.04958344, 10.48791599], [76.04958344, 10.48847198], [76.04930878, 10.48847198], [76.04930878, 10.48903275], [76.04902649, 10.48902798], [76.04902649, 10.48958397], [76.04875183, 10.48958397], [76.04875183, 10.48986244], [76.04846954, 10.48985958], [76.04846954, 10.4904213], [76.04818726, 10.4904213], [76.04818726, 10.49125004], [76.04792023, 10.49125004], [76.04792023, 10.49153137], [76.04763794, 10.49153137], [76.04763794, 10.4918108], [76.04736328, 10.49180603], [76.04736328, 10.49236012], [76.04708099, 10.49236012], [76.04708099, 10.4934721], [76.04680634, 10.49346066], [76.04680634, 10.49374962], [76.04651642, 10.49374962], [76.04651642, 10.49431133], [76.0459671, 10.49431133], [76.0459671, 10.49542141], [76.04569244, 10.49541569], [76.04569244, 10.49625111], [76.04541779, 10.49625111], [76.04541779, 10.49653053], [76.04512787, 10.49653053], [76.04512787, 10.49682045], [76.04486084, 10.49680424], [76.04486084, 10.49708462], [76.04458618, 10.49707985], [76.04458618, 10.49792099], [76.04430389, 10.49791718], [76.04430389, 10.49819469], [76.04402924, 10.49818993], [76.04402924, 10.49903107], [76.04374695, 10.49903107], [76.04374695, 10.4993124], [76.04347229, 10.49930477], [76.04347229, 10.49986076], [76.04319763, 10.4998579], [76.04319763, 10.50042057], [76.04292297, 10.50042057], [76.04292297, 10.50153065], [76.04264069, 10.50153065], [76.04264069, 10.50181198], [76.0423584, 10.50180531], [76.0423584, 10.50208282], [76.04208374, 10.50208282], [76.04208374, 10.5023613], [76.04180908, 10.5023613], [76.04180908, 10.5029192], [76.04125214, 10.50291729], [76.04125214, 10.50347328], [76.04096985, 10.50347137], [76.04096985, 10.50402927], [76.04070282, 10.50402927], [76.04070282, 10.50430965], [76.0404129, 10.50430489], [76.0404129, 10.50486088], [76.04013824, 10.50486088], [76.04013824, 10.50541973], [76.03986359, 10.50541687], [76.03986359, 10.50708294], [76.0404129, 10.50708294], [76.0404129, 10.50736141], [76.04069519, 10.50736141], [76.04069519, 10.50708294], [76.04208374, 10.50708294], [76.04208374, 10.50736141], [76.0423584, 10.50736141], [76.0423584, 10.50764179], [76.04264069, 10.50764179], [76.04264069, 10.50876141], [76.0423584, 10.50876141], [76.0423584, 10.50903034], [76.04208374, 10.50902653], [76.04208374, 10.51069355], [76.04180908, 10.51069069], [76.04180908, 10.51124954], [76.04152679, 10.51124954], [76.04152679, 10.51182175], [76.04125214, 10.51182175], [76.04125214, 10.51264], [76.04152679, 10.51264], [76.04152679, 10.51375198], [76.04125214, 10.51375008], [76.04125214, 10.51458359], [76.04096985, 10.51458359], [76.04096985, 10.51763821], [76.04070282, 10.51763058], [76.04070282, 10.51792145], [76.0404129, 10.51791573], [76.0404129, 10.51847172], [76.04013824, 10.51847172], [76.04013824, 10.51903057], [76.03986359, 10.51902771], [76.03986359, 10.5195837], [76.0395813, 10.5195837], [76.0395813, 10.51969242], [76.0395813, 10.51986027], [76.0393219, 10.51986027], [76.0393219, 10.52014065], [76.03903198, 10.52014065], [76.03903198, 10.52042103], [76.03874969, 10.52041626], [76.03874969, 10.52097225], [76.03848267, 10.52097034], [76.03848267, 10.52153111], [76.03819275, 10.52153111], [76.03819275, 10.52181053], [76.0376358, 10.52180672], [76.0376358, 10.52208233], [76.03708649, 10.52208042], [76.03708649, 10.52264118], [76.0368042, 10.52263832], [76.0368042, 10.52319527], [76.03624725, 10.52319527], [76.03624725, 10.52347279], [76.0359726, 10.52346992], [76.0359726, 10.52375984], [76.03569794, 10.52375984], [76.03569794, 10.52403069], [76.03514099, 10.52402878], [76.03514099, 10.52458286], [76.0348587, 10.52458477], [76.0348587, 10.52486134], [76.03458405, 10.52486134], [76.03458405, 10.52507019], [76.03457642, 10.52542114], [76.03430939, 10.52541733], [76.03430176, 10.52569485], [76.0340271, 10.52569485], [76.0340271, 10.52819538], [76.03430176, 10.52819538], [76.03430939, 10.52986145], [76.03457642, 10.52986145], [76.03457642, 10.53014088], [76.0348587, 10.53014088], [76.0348587, 10.53041935], [76.03541565, 10.53041744], [76.03541565, 10.53069305], [76.0359726, 10.53069305], [76.0359726, 10.53097343], [76.03624725, 10.53097057], [76.03624725, 10.53152943], [76.03652954, 10.53152943], [76.03652954, 10.53181171], [76.03708649, 10.53180504], [76.03708649, 10.53208256], [76.03736115, 10.53208256], [76.03736115, 10.53236103], [76.03794861, 10.53236103], [76.03874969, 10.53236103], [76.03874969, 10.53264236], [76.03985596, 10.53264236], [76.03985596, 10.53236103], [76.04096985, 10.53236103], [76.04096985, 10.53208256], [76.04319763, 10.53208256], [76.04319763, 10.53180504], [76.04374695, 10.53180504], [76.04374695, 10.53208256], [76.04541779, 10.53208256], [76.04541779, 10.53180504], [76.04569244, 10.53181171], [76.04569244, 10.53152943], [76.04792023, 10.53152943], [76.04792023, 10.53125095], [76.04846954, 10.53125095], [76.04846954, 10.53097057], [76.04985809, 10.53097057], [76.04985809, 10.53125095], [76.05042267, 10.53125095], [76.05042267, 10.53152943], [76.05097198, 10.53152943], [76.05097198, 10.53181171], [76.05208588, 10.53180504], [76.05208588, 10.53208256], [76.05263519, 10.53208256], [76.05263519, 10.53236103], [76.05291748, 10.53236103], [76.05291748, 10.53292179], [76.05319214, 10.53291702], [76.05319214, 10.53347111], [76.0534668, 10.53347111], [76.0534668, 10.53403187], [76.05374908, 10.53403187], [76.05374908, 10.53431034], [76.05430603, 10.53430462], [76.05430603, 10.53458309], [76.05403137, 10.53458309], [76.05403137, 10.53597355], [76.05374908, 10.53597069], [76.05374908, 10.53680992], [76.05319214, 10.53680611], [76.05319214, 10.53708363], [76.05374908, 10.53707886], [76.05374908, 10.53763962], [76.05347443, 10.53763962], [76.05347443, 10.53847218], [76.05319214, 10.53847218], [76.05319214, 10.53874969], [76.0534668, 10.53874111], [76.0534668, 10.53931046], [76.05319214, 10.53930569], [76.05319214, 10.54097176], [76.0534668, 10.54096985], [76.0534668, 10.54152966], [76.05319214, 10.54152775], [76.05319214, 10.54236221], [76.05291748, 10.54236031], [76.05291748, 10.54263973], [76.05236053, 10.54263783], [76.05236053, 10.54347229], [76.05347443, 10.54347229], [76.05347443, 10.54319382], [76.05374908, 10.54319382], [76.05374908, 10.54208374], [76.05403137, 10.54208374], [76.05403137, 10.54180622], [76.05458069, 10.54180622], [76.05458069, 10.54208374], [76.05486298, 10.54208374], [76.05486298, 10.54180622], [76.05541992, 10.54180622], [76.05541992, 10.54152775], [76.05568695, 10.54152966], [76.05568695, 10.54096985], [76.05596924, 10.54097176], [76.05596924, 10.54069424], [76.05625153, 10.54069424], [76.05625153, 10.54041576], [76.05680847, 10.54041958], [76.05680847, 10.54014015], [76.05706787, 10.54014015], [76.05706787, 10.53957939], [76.05735779, 10.53958416], [76.05735779, 10.53874969], [76.05764008, 10.53874969], [76.05764008, 10.5381937], [76.05847168, 10.5381937], [76.05847168, 10.53847218], [76.05874634, 10.53846931], [76.05874634, 10.53931046], [76.05986023, 10.53931046], [76.05986023, 10.53903008], [76.06012726, 10.53903008], [76.06012726, 10.53846931], [76.06069183, 10.53847218], [76.06069183, 10.5381937], [76.06097412, 10.5381937], [76.06097412, 10.53791809], [76.06124878, 10.53792], [76.06124878, 10.53763962], [76.06153107, 10.53763962], [76.06153107, 10.53735924], [76.06180573, 10.5373621], [76.06180573, 10.53708363], [76.06208038, 10.53708363], [76.06208038, 10.53652763], [76.06236267, 10.53652954], [76.06236267, 10.53625202], [76.06263733, 10.53625202], [76.06263733, 10.53597069], [76.06291962, 10.53597355], [76.06291962, 10.53569317], [76.06346893, 10.53569317], [76.06346893, 10.53597355], [76.06375122, 10.53597355], [76.06375122, 10.53708363], [76.06402588, 10.53708363], [76.06402588, 10.5373621], [76.06458282, 10.5373621], [76.06458282, 10.5381937], [76.06513977, 10.5381937], [76.06513977, 10.53847218], [76.06541443, 10.53847218], [76.06541443, 10.53874969], [76.06597137, 10.53874111], [76.06597137, 10.53931046], [76.06626129, 10.53931046], [76.06626129, 10.54041958], [76.06652832, 10.54041958], [76.06652832, 10.54263973], [76.06680298, 10.54263783], [76.06680298, 10.54319382], [76.06764221, 10.54319382], [76.06764221, 10.54458427], [76.06735992, 10.54458046], [76.06735992, 10.54514027], [76.0670929, 10.54514027], [76.0670929, 10.54542065], [76.06680298, 10.54541588], [76.06680298, 10.54625034], [76.06652832, 10.54625034], [76.06652832, 10.54653072], [76.06626129, 10.54653072], [76.06626129, 10.54625034], [76.06597137, 10.54625034], [76.06597137, 10.54597187], [76.06569672, 10.54597187], [76.06569672, 10.54569435], [76.06485748, 10.54569435], [76.06485748, 10.54597187], [76.06458282, 10.54597187], [76.06458282, 10.54625034], [76.06402588, 10.54625034], [76.06402588, 10.54653072], [76.06236267, 10.54653072], [76.06236267, 10.54596996], [76.06208038, 10.54597187], [76.06208038, 10.54541588], [76.06181335, 10.54542065], [76.06181335, 10.54487133], [76.06153107, 10.54487133], [76.06153107, 10.54431057], [76.06124878, 10.54431057], [76.06124878, 10.54403019], [76.06096649, 10.54403019], [76.06096649, 10.54375172], [76.06069183, 10.54375172], [76.06069183, 10.54319191], [76.06014252, 10.54319382], [76.06014252, 10.5429163], [76.05986023, 10.5429163], [76.05986023, 10.54347229], [76.0595932, 10.54347038], [76.0595932, 10.54375172], [76.05930328, 10.54375172], [76.05930328, 10.54487133], [76.05902863, 10.54487133], [76.05902863, 10.54514027], [76.05847168, 10.54514027], [76.05847168, 10.54569435], [76.05791473, 10.54569435], [76.05791473, 10.54597187], [76.05706787, 10.54596996], [76.05706787, 10.54625034], [76.05568695, 10.54625034], [76.05568695, 10.54653072], [76.05541992, 10.54653072], [76.05541992, 10.54625034], [76.05458069, 10.54625034], [76.05458069, 10.54597187], [76.05347443, 10.54597187], [76.05347443, 10.54569435], [76.05319214, 10.54569435], [76.05319214, 10.54541588], [76.05152893, 10.54541588], [76.05152893, 10.54569435], [76.05124664, 10.54569435], [76.05124664, 10.54597187], [76.05097198, 10.54597187], [76.05097198, 10.54625034], [76.05042267, 10.54625034], [76.05042267, 10.54653072], [76.05014038, 10.54653072], [76.05014038, 10.5468111], [76.04958344, 10.54680634], [76.04958344, 10.54708195], [76.04985809, 10.54708195], [76.04985809, 10.54736042], [76.04957581, 10.54736042], [76.04957581, 10.5476408], [76.04985809, 10.54763794], [76.04985809, 10.5484724], [76.04958344, 10.5484724], [76.04958344, 10.54958153], [76.04930878, 10.54958153], [76.04930878, 10.55125141], [76.04902649, 10.55125141], [76.04902649, 10.55153084], [76.04930878, 10.55153084], [76.04930878, 10.55181122], [76.04875183, 10.55180454], [76.04875183, 10.55236053], [76.04846954, 10.55236053], [76.04846954, 10.55264091], [76.04818726, 10.55264091], [76.04818726, 10.5529213], [76.04736328, 10.55291653], [76.04736328, 10.553195], [76.04708099, 10.553195], [76.04708099, 10.55375099], [76.04680634, 10.55373955], [76.04680634, 10.55430889], [76.04652405, 10.55430698], [76.04652405, 10.5545826], [76.04624939, 10.5545826], [76.04624939, 10.55486107], [76.04569244, 10.55486107], [76.04569244, 10.55542183], [76.04541779, 10.55541706], [76.04541779, 10.55569458], [76.04512787, 10.5556879], [76.04512787, 10.55625057], [76.04486084, 10.55625057], [76.04486084, 10.55653095], [76.04458618, 10.55652905], [76.04458618, 10.55819511], [76.04430389, 10.55819511], [76.04430389, 10.55847263], [76.04458618, 10.55847263], [76.04458618, 10.5587492], [76.04429626, 10.5587492], [76.04429626, 10.55986977], [76.04402924, 10.55986977], [76.04402924, 10.56014156], [76.04347229, 10.5601387], [76.04347229, 10.56069469], [76.04319763, 10.56069088], [76.04319763, 10.56125164], [76.04291534, 10.56124878], [76.04291534, 10.56208324], [76.04264069, 10.56208324], [76.04264069, 10.56236172], [76.0423584, 10.56235886], [76.0423584, 10.56264019], [76.04180908, 10.56264019], [76.04180908, 10.56293106], [76.04152679, 10.56291771], [76.04152679, 10.56347084], [76.04125214, 10.56347084], [76.04125214, 10.56431007], [76.04096985, 10.56430626], [76.04096985, 10.56597233], [76.04125214, 10.56597233], [76.04125214, 10.56624985], [76.04152679, 10.56624985], [76.04152679, 10.56653023], [76.04180908, 10.56653023], [76.04180908, 10.56680965], [76.04208374, 10.56680584], [76.04208374, 10.56708431], [76.04264069, 10.56708431], [76.04264069, 10.56736183], [76.04402924, 10.56736183], [76.04402924, 10.56708431], [76.04597473, 10.56708431], [76.04597473, 10.56680584], [76.04624939, 10.56680965], [76.04624939, 10.56653023], [76.04708099, 10.56652832], [76.04708099, 10.56708431], [76.04736328, 10.56708241], [76.04736328, 10.56791973], [76.04680634, 10.56791592], [76.04680634, 10.56819439], [76.04652405, 10.56819439], [76.04652405, 10.56847191], [76.04624939, 10.56847191], [76.04624939, 10.56958199], [76.04597473, 10.56958199], [76.04597473, 10.56986237], [76.04569244, 10.56986046], [76.04569244, 10.57042122], [76.04541779, 10.57042122], [76.04541779, 10.57124996], [76.04512787, 10.57124996], [76.04512787, 10.57153034], [76.04486084, 10.57153034], [76.04486084, 10.57181072], [76.04458618, 10.57180595], [76.04458618, 10.57236004], [76.04429626, 10.57236004], [76.04429626, 10.57264042], [76.04319763, 10.57263756], [76.04319763, 10.57319355], [76.04291534, 10.57319355], [76.04291534, 10.57347202], [76.04264069, 10.57347012], [76.04264069, 10.57431126], [76.04291534, 10.57430553], [76.04291534, 10.5745821], [76.04264069, 10.57458019], [76.04264069, 10.57487202], [76.0423584, 10.57487202], [76.0423584, 10.57514095], [76.04206848, 10.57514095], [76.04206848, 10.57542133], [76.04152679, 10.57542133], [76.04152679, 10.57514095], [76.04180908, 10.57514095], [76.04180908, 10.57153034], [76.04125214, 10.57153034], [76.04125214, 10.57124996], [76.04070282, 10.57124996], [76.04070282, 10.57096958], [76.0404129, 10.57096958], [76.0404129, 10.57124996], [76.03985596, 10.57124996], [76.03985596, 10.57096958], [76.03902435, 10.57097244], [76.03902435, 10.57069397], [76.03847504, 10.57069397], [76.03847504, 10.57041645], [76.0376358, 10.57042122], [76.0376358, 10.57014179], [76.03736115, 10.57014179], [76.03736115, 10.56958199], [76.03708649, 10.56958199], [76.03708649, 10.5690279], [76.03679657, 10.56903267], [76.03679657, 10.56847191], [76.03652954, 10.56847191], [76.03652954, 10.56819439], [76.03624725, 10.56819439], [76.03624725, 10.56791592], [76.03652954, 10.56791973], [76.03652954, 10.56680965], [76.03679657, 10.56680965], [76.03679657, 10.56624985], [76.03708649, 10.56624985], [76.03708649, 10.56569576], [76.03736115, 10.56569576], [76.03736115, 10.56486225], [76.0376358, 10.56486225], [76.0376358, 10.56430626], [76.03819275, 10.56431007], [76.03819275, 10.56402969], [76.03874969, 10.56402969], [76.03874969, 10.56375027], [76.03902435, 10.56375027], [76.03902435, 10.56347084], [76.03930664, 10.56347084], [76.03930664, 10.56319332], [76.0395813, 10.56319332], [76.0395813, 10.56291771], [76.03985596, 10.56293106], [76.03985596, 10.56264019], [76.04013824, 10.56264019], [76.04013824, 10.56069088], [76.0404129, 10.56069469], [76.0404129, 10.56041527], [76.04013824, 10.56042194], [76.04013824, 10.56014156], [76.0404129, 10.56014156], [76.0404129, 10.55986977], [76.04070282, 10.55986977], [76.04070282, 10.5595808], [76.0404129, 10.55958271], [76.0404129, 10.55930519], [76.04070282, 10.55931187], [76.04070282, 10.55902863], [76.04096985, 10.55902863], [76.04096985, 10.55791855], [76.04125214, 10.55791855], [76.04125214, 10.55764103], [76.04152679, 10.55764103], [76.04152679, 10.55736065], [76.04180908, 10.55736065], [76.04180908, 10.55708313], [76.04208374, 10.55708313], [76.04208374, 10.55680466], [76.0423584, 10.55681038], [76.0423584, 10.55653095], [76.04264069, 10.55653095], [76.04264069, 10.55625057], [76.04292297, 10.55625057], [76.04292297, 10.55597115], [76.04319763, 10.55597305], [76.04319763, 10.55569458], [76.04347229, 10.55569458], [76.04347229, 10.55347347], [76.04374695, 10.55347347], [76.04374695, 10.553195], [76.04402924, 10.553195], [76.04402924, 10.55152893], [76.04429626, 10.55153084], [76.04429626, 10.55097008], [76.04458618, 10.55097294], [76.04458618, 10.55041695], [76.04486084, 10.55041885], [76.04486084, 10.54986], [76.0451355, 10.54986], [76.04512787, 10.54957962], [76.04541779, 10.54958153], [76.04541779, 10.54930687], [76.04569244, 10.54931068], [76.04569244, 10.54903126], [76.0459671, 10.54903126], [76.0459671, 10.54846954], [76.04652405, 10.5484724], [76.04652405, 10.54763794], [76.04680634, 10.5476408], [76.04680634, 10.54736042], [76.04736328, 10.54736042], [76.04736328, 10.54652786], [76.04763794, 10.54653072], [76.04763794, 10.54596996], [76.04736328, 10.54597187], [76.04736328, 10.54485989], [76.04763794, 10.54487133], [76.04763794, 10.54292011], [76.04736328, 10.54292011], [76.04736328, 10.54152966], [76.04763794, 10.54152966], [76.04763794, 10.54096985], [76.04792023, 10.54097176], [76.04792023, 10.54041576], [76.04818726, 10.54041958], [76.04818726, 10.53903008], [76.04792023, 10.53903008], [76.04792023, 10.53625202], [76.04818726, 10.53625202], [76.04818726, 10.53514194], [76.04792023, 10.53514194], [76.04792023, 10.53431034], [76.04763794, 10.53431034], [76.04763794, 10.53403187], [76.04736328, 10.53403187], [76.04736328, 10.53347111], [76.04708099, 10.53347111], [76.04708099, 10.53375244], [76.04680634, 10.53375244], [76.04680634, 10.53347111], [76.04651642, 10.53347111], [76.04651642, 10.53375244], [76.0459671, 10.53375244], [76.0459671, 10.53403187], [76.04512787, 10.53403187], [76.04512787, 10.53431034], [76.04464722, 10.53430462], [76.04430389, 10.53430462], [76.04430389, 10.53458118], [76.04430389, 10.53486061], [76.04408264, 10.53486061], [76.04374695, 10.53486061], [76.04374695, 10.53514194], [76.04319763, 10.53514194], [76.04319763, 10.53542042], [76.04264069, 10.53542042], [76.04264069, 10.53569984], [76.04208374, 10.53569317], [76.04208374, 10.53597355], [76.04180908, 10.53597355], [76.04180908, 10.53569317], [76.04069519, 10.53569317], [76.04069519, 10.53597355], [76.03847504, 10.53597355], [76.03847504, 10.53569317], [76.0376358, 10.53569984], [76.0376358, 10.53542042], [76.03650665, 10.53541756], [76.0359726, 10.53542042], [76.0359726, 10.53514194], [76.03569794, 10.53514194], [76.03569794, 10.53542042], [76.03542328, 10.53542042], [76.03542328, 10.53514194], [76.0348587, 10.53514194], [76.0348587, 10.53486061], [76.03457642, 10.53486061], [76.03457642, 10.53514194], [76.03430176, 10.53514194], [76.03430176, 10.53486061], [76.03347015, 10.53486061], [76.03347015, 10.53680992], [76.0331955, 10.53680611], [76.0331955, 10.53708363], [76.03291321, 10.53708363], [76.03291321, 10.5373621], [76.0320816, 10.5373621], [76.0320816, 10.53708363], [76.03180695, 10.53708363], [76.03180695, 10.53680611], [76.0320816, 10.53680992], [76.0320816, 10.53625202], [76.03235626, 10.53625202], [76.03235626, 10.53569984], [76.03263855, 10.53569984], [76.03263855, 10.53514194], [76.03318787, 10.53514194], [76.03318787, 10.53319073], [76.03347015, 10.53319454], [76.03347015, 10.53236103], [76.03318787, 10.53236103], [76.03318787, 10.53181171], [76.03289795, 10.53181171], [76.03289795, 10.53125095], [76.03263855, 10.53125095], [76.03263855, 10.53069115], [76.03236389, 10.53069305], [76.03236389, 10.53013897], [76.03180695, 10.53014088], [76.03180695, 10.52902889], [76.03151703, 10.52902889], [76.03151703, 10.52818966], [76.03097534, 10.52819538], [76.03097534, 10.5265274], [76.03125, 10.52653122], [76.03125, 10.52569008], [76.03152466, 10.52569485], [76.03152466, 10.52513885], [76.03180695, 10.52513885], [76.03180695, 10.52486134], [76.0320816, 10.52486134], [76.0320816, 10.52447128], [76.0320816, 10.52430534], [76.03235626, 10.52431107], [76.03235626, 10.52375984], [76.03263855, 10.52375984], [76.03263855, 10.52318954], [76.03291321, 10.52319527], [76.03291321, 10.52291679], [76.03347015, 10.52292061], [76.03347015, 10.52235985], [76.03375244, 10.52235985], [76.03375244, 10.52208233], [76.0340271, 10.52208233], [76.0340271, 10.52180672], [76.03430176, 10.52181053], [76.03430176, 10.52153111], [76.03457642, 10.52153111], [76.03457642, 10.52097034], [76.03541565, 10.52097225], [76.03541565, 10.52069378], [76.03514099, 10.52070141], [76.03514099, 10.52014065], [76.03542328, 10.52014065], [76.03542328, 10.51958179], [76.03569794, 10.5195837], [76.03569794, 10.51930618], [76.0359726, 10.51931095], [76.03598785, 10.51909447], [76.03624725, 10.51903057], [76.03624725, 10.51792145], [76.03652954, 10.51792145], [76.03652954, 10.51763058], [76.0368042, 10.51763821], [76.0368042, 10.51708412], [76.03708649, 10.51708412], [76.03708649, 10.51680565], [76.03736115, 10.51681137], [76.03736115, 10.51624966], [76.0376358, 10.51624966], [76.0376358, 10.5156889], [76.03791809, 10.51569366], [76.03791809, 10.51513767], [76.03819275, 10.51513958], [76.03819275, 10.51457024], [76.03847504, 10.51458359], [76.03847504, 10.51375008], [76.03874969, 10.51375198], [76.03874969, 10.5134716], [76.03902435, 10.5134716], [76.03902435, 10.51291561], [76.0393219, 10.51292038], [76.0393219, 10.51264], [76.0395813, 10.51264], [76.0395813, 10.51207924], [76.03986359, 10.51208401], [76.03986359, 10.51124954], [76.04013824, 10.51124954], [76.04013824, 10.51069069], [76.03986359, 10.51069355], [76.03986359, 10.5101366], [76.0395813, 10.51014042], [76.0395813, 10.50986195], [76.03819275, 10.50986195], [76.03819275, 10.51014042], [76.03624725, 10.51014042], [76.03624725, 10.51041985], [76.0359726, 10.51041794], [76.0359726, 10.51097202], [76.03569794, 10.51097202], [76.03569794, 10.51124954], [76.03542328, 10.51124954], [76.03542328, 10.51182175], [76.03514099, 10.51180553], [76.03514099, 10.51236153], [76.0348587, 10.51235962], [76.0348587, 10.51292038], [76.03458405, 10.51291561], [76.03458405, 10.5134716], [76.0340271, 10.5134716], [76.0340271, 10.51403046], [76.03375244, 10.51403046], [76.03375244, 10.51431274], [76.03347015, 10.51430607], [76.03347015, 10.51486206], [76.0331955, 10.51486206], [76.0331955, 10.51569366], [76.03289795, 10.5156889], [76.03289795, 10.51624966], [76.03263855, 10.51624966], [76.03263855, 10.51735973], [76.03235626, 10.51735973], [76.03235626, 10.51792145], [76.0320816, 10.51791573], [76.0320816, 10.5181942], [76.03180695, 10.51819038], [76.03180695, 10.51903057], [76.03152466, 10.51902771], [76.03152466, 10.5195837], [76.03125, 10.5195837], [76.03125, 10.51986027], [76.03097534, 10.51986027], [76.03097534, 10.52097225], [76.03069305, 10.52097034], [76.03069305, 10.52153111], [76.0304184, 10.52153111], [76.0304184, 10.52181053], [76.03013611, 10.52180672], [76.03013611, 10.52235985], [76.02986145, 10.52235985], [76.02986145, 10.52292061], [76.02958679, 10.52291679], [76.02958679, 10.52347279], [76.02929688, 10.52346992], [76.02925873, 10.52375984], [76.02902985, 10.52375126], [76.02902985, 10.52458286], [76.02874756, 10.52458477], [76.02874756, 10.52513885], [76.0284729, 10.52513885], [76.0284729, 10.52625084], [76.02819824, 10.52625084], [76.02819824, 10.52653122], [76.02791595, 10.5265274], [76.02791595, 10.5270834], [76.0276413, 10.52707958], [76.0276413, 10.5276413], [76.02735901, 10.52763939], [76.02735901, 10.5284729], [76.02680206, 10.52847099], [76.02680206, 10.52902889], [76.0265274, 10.52902889], [76.0265274, 10.52930927], [76.02625275, 10.52930927], [76.02625275, 10.53041935], [76.02597046, 10.53041935], [76.02597046, 10.53181171], [76.0256958, 10.53180504], [76.0256958, 10.53208256], [76.02513885, 10.53208256], [76.02513885, 10.53347111], [76.02485657, 10.53347111], [76.02485657, 10.53403187], [76.02458191, 10.5340271], [76.02458191, 10.53458309], [76.02430725, 10.53458118], [76.02430725, 10.53514194], [76.02403259, 10.53514194], [76.02403259, 10.53569984], [76.02375031, 10.53569317], [76.02375031, 10.53597355], [76.02319336, 10.53597069], [76.02319336, 10.53680992], [76.0229187, 10.53680611], [76.0229187, 10.5381937], [76.02263641, 10.5381937], [76.02263641, 10.53874969], [76.02236176, 10.53874111], [76.02236176, 10.53931046], [76.02179718, 10.53931046], [76.02180481, 10.53985977], [76.02153015, 10.53985977], [76.02153015, 10.54097176], [76.02124786, 10.54096985], [76.02124786, 10.54152966], [76.02097321, 10.54152775], [76.02097321, 10.54180622], [76.02069092, 10.54180145], [76.02069092, 10.54263973], [76.02041626, 10.54263973], [76.02041626, 10.54292011], [76.0201416, 10.54292011], [76.0201416, 10.54403019], [76.01985931, 10.54403019], [76.01985931, 10.54487133], [76.01958466, 10.54485989], [76.01958466, 10.54597187], [76.01930237, 10.54596996], [76.01930237, 10.5468111], [76.01902771, 10.54680634], [76.01902771, 10.54736042], [76.01875305, 10.54736042], [76.01875305, 10.5476408], [76.01847076, 10.54763794], [76.01847076, 10.5484724], [76.01821136, 10.54846954], [76.01821136, 10.54931068], [76.01789856, 10.54931068], [76.01791382, 10.54986], [76.01763916, 10.54986], [76.01763916, 10.55014133], [76.01735687, 10.55014133], [76.01735687, 10.55153084], [76.01708221, 10.55152893], [76.01708221, 10.55208302], [76.01735687, 10.55208015], [76.01735687, 10.55264091], [76.01708221, 10.55263901], [76.01708221, 10.55347347], [76.01680756, 10.55347347], [76.01680756, 10.55375099], [76.0165329, 10.55373955], [76.0165329, 10.55403137], [76.01597595, 10.5540266], [76.01597595, 10.5545826], [76.01568604, 10.55458069], [76.01568604, 10.55542183], [76.01597595, 10.55542183], [76.01597595, 10.55625057], [76.01568604, 10.55625057], [76.01568604, 10.55681038], [76.01541901, 10.55680466], [76.01541901, 10.55736065], [76.01515198, 10.55736065], [76.01515198, 10.55764103], [76.01486206, 10.55763912], [76.01486206, 10.5587492], [76.01457977, 10.5587492], [76.01457977, 10.55958271], [76.01431274, 10.5595808], [76.01431274, 10.55986977], [76.01403046, 10.55986977], [76.01403046, 10.56042194], [76.01374817, 10.56041527], [76.01374817, 10.56097126], [76.01346588, 10.56097126], [76.01346588, 10.56153202], [76.01319122, 10.56153202], [76.01319122, 10.56180954], [76.01291656, 10.56180477], [76.01291656, 10.56208324], [76.01264191, 10.56208134], [76.01264191, 10.56264019], [76.01235962, 10.56264019], [76.01235962, 10.56375027], [76.01209259, 10.56375027], [76.01209259, 10.56431007], [76.01180267, 10.56430626], [76.01180267, 10.56458378], [76.01152802, 10.56458378], [76.01152802, 10.56486225], [76.01125336, 10.56486225], [76.01125336, 10.56569576], [76.01097107, 10.56569576], [76.01097107, 10.56624985], [76.01069641, 10.56624985], [76.01069641, 10.56653023], [76.01040649, 10.56653023], [76.01040649, 10.5676403], [76.01013947, 10.5676403], [76.01013947, 10.56791973], [76.00985718, 10.56791973], [76.00985718, 10.56903267], [76.00930786, 10.5690279], [76.00930786, 10.56958199], [76.00902557, 10.56958199], [76.00901794, 10.5706892], [76.00875092, 10.57070065], [76.00875092, 10.57153034], [76.00846863, 10.57153034], [76.00846863, 10.57181072], [76.00819397, 10.57180595], [76.00819397, 10.57208443], [76.00791931, 10.57207966], [76.00791931, 10.5729208], [76.00763702, 10.5729208], [76.00763702, 10.57403088], [76.00736237, 10.57402802], [76.00736237, 10.5745821], [76.00681305, 10.57458019], [76.00681305, 10.57514095], [76.00653076, 10.57514095], [76.00653076, 10.57542133], [76.00624847, 10.57542133], [76.00624847, 10.57681084], [76.00597382, 10.57680416], [76.00597382, 10.57736111], [76.00569153, 10.57736111], [76.00569153, 10.57819462], [76.00541687, 10.57818985], [76.00541687, 10.57875061], [76.00514221, 10.57875061], [76.00514221, 10.57903099], [76.00485992, 10.57902908], [76.00485992, 10.57958317], [76.00458527, 10.57958317], [76.00458527, 10.57986069], [76.00430298, 10.57986069], [76.00430298, 10.58069515], [76.00402832, 10.58069515], [76.00402832, 10.58208275], [76.00374603, 10.58208275], [76.00374603, 10.58264065], [76.00347137, 10.58264065], [76.00347137, 10.58292198], [76.00319672, 10.58291721], [76.00319672, 10.58347321], [76.00292206, 10.5834713], [76.00292206, 10.58375072], [76.00263977, 10.58374882], [76.00263977, 10.58569527], [76.00235748, 10.58569527], [76.00235748, 10.58625126], [76.00208282, 10.58625126], [76.00208282, 10.58681202], [76.00180817, 10.58680534], [76.00180817, 10.58708286], [76.00152588, 10.58708286], [76.00152588, 10.58763885], [76.00125122, 10.58763885], [76.00125122, 10.58847141], [76.00096893, 10.58847141], [76.00096893, 10.58875179], [76.00068665, 10.58875179], [76.00068665, 10.58903027], [76.00015259, 10.58903027], [75.99958038, 10.58903027], [75.99958038, 10.59014034], [75.99931335, 10.59014034], [75.99931335, 10.59041977], [75.99903107, 10.59041786], [75.99903107, 10.59097195], [75.99874878, 10.59097195], [75.99874878, 10.59152985], [75.99847412, 10.59152794], [75.99847412, 10.5923624], [75.99819183, 10.59235859], [75.99819183, 10.59375191], [75.99791718, 10.59375], [75.99791718, 10.59486198], [75.99764252, 10.59486198], [75.99764252, 10.59569359], [75.99736023, 10.59569168], [75.99736023, 10.59652996], [75.99708557, 10.59652805], [75.99708557, 10.59736156], [75.99680328, 10.59736156], [75.99680328, 10.59819412], [75.99652863, 10.59819031], [75.99652863, 10.59904194], [75.99624634, 10.59902763], [75.99624634, 10.59986019], [75.99597168, 10.59986019], [75.99597168, 10.60042095], [75.99569702, 10.60042095], [75.99569702, 10.60124969], [75.99541473, 10.60124969], [75.99541473, 10.60208225], [75.99514008, 10.60208035], [75.99514008, 10.60264111], [75.99485779, 10.60263824], [75.99485779, 10.60347271], [75.99458313, 10.60346985], [75.99458313, 10.60403061], [75.99430847, 10.6040287], [75.99430847, 10.60458469], [75.99401855, 10.60457993], [75.99401855, 10.60514069], [75.99375153, 10.60513878], [75.99375153, 10.60569477], [75.99346924, 10.60569477], [75.99346924, 10.60625076], [75.99319458, 10.60625076], [75.99319458, 10.60708332], [75.99291992, 10.60708046], [75.99291992, 10.60764122], [75.99263763, 10.60763931], [75.99263763, 10.6081953], [75.99236298, 10.6081953], [75.99236298, 10.6087513], [75.99208069, 10.6087513], [75.99208069, 10.6093092], [75.99180603, 10.6093092], [75.99180603, 10.61013889], [75.99153137, 10.61013889], [75.99153137, 10.61069489], [75.99124908, 10.61069107], [75.99124908, 10.61125088], [75.99097443, 10.61124897], [75.99097443, 10.61208344], [75.99069214, 10.61208057], [75.99069214, 10.61263943], [75.99041748, 10.61263943], [75.99041748, 10.61319542], [75.99013519, 10.61319542], [75.99013519, 10.61402702], [75.98986053, 10.61402702], [75.98986053, 10.61458302], [75.98958588, 10.61458111], [75.98958588, 10.61514187], [75.98930359, 10.61513901], [75.98930359, 10.61597443], [75.98902893, 10.61597061], [75.98902893, 10.61653042], [75.98874664, 10.6165266], [75.98874664, 10.61736202], [75.98847198, 10.61736202], [75.98847198, 10.61791992], [75.98819733, 10.61791801], [75.98819733, 10.6184721], [75.98792267, 10.61846924], [75.98792267, 10.61931038], [75.98764038, 10.61930561], [75.98764038, 10.6198597], [75.98735809, 10.6198597], [75.98735809, 10.62042046], [75.98708344, 10.62041569], [75.98708344, 10.62097168], [75.98680878, 10.62097168], [75.98680878, 10.62152958], [75.98652649, 10.62152767], [75.98652649, 10.62208366], [75.98625183, 10.6220789], [75.98625183, 10.62263966], [75.98596954, 10.62263775], [75.98596954, 10.62319374], [75.98568726, 10.62319183], [75.98568726, 10.62374973], [75.98542023, 10.62374973], [75.98542023, 10.62431145], [75.98513794, 10.62431145], [75.98513794, 10.62486172], [75.98484802, 10.62486172], [75.98484802, 10.62542057], [75.98458099, 10.6254158], [75.98458099, 10.62597179], [75.98430634, 10.6259613], [75.98430634, 10.62681103], [75.98402405, 10.62680626], [75.98402405, 10.62736034], [75.98374939, 10.62736034], [75.98374939, 10.6279211], [75.98347473, 10.62791634], [75.98347473, 10.62847233], [75.98319244, 10.62847233], [75.98319244, 10.62902641], [75.98291779, 10.62902641], [75.98291779, 10.62958241], [75.98264313, 10.62957954], [75.98264313, 10.63014126], [75.98236084, 10.6301384], [75.98236084, 10.63069534], [75.98207855, 10.63068962], [75.98207855, 10.63125134], [75.98178864, 10.63125134], [75.98178864, 10.63180923], [75.98152924, 10.63180447], [75.98152924, 10.63236141], [75.98124695, 10.63236141], [75.98124695, 10.63292122], [75.98097229, 10.63292122], [75.98097229, 10.6340313], [75.98069763, 10.6340313], [75.98069763, 10.63514996], [75.98041534, 10.63513947], [75.98041534, 10.63569546], [75.98014069, 10.63568974], [75.98014069, 10.63624859], [75.9798584, 10.63625145], [75.9798584, 10.63653088], [75.97957611, 10.63653088], [75.97957611, 10.63680935], [75.97930908, 10.63680458], [75.97930908, 10.63708305], [75.97902679, 10.63708305], [75.97902679, 10.63736057], [75.97875214, 10.63736057], [75.97875214, 10.63958263], [75.97846985, 10.63958073], [75.97846985, 10.64014244], [75.97820282, 10.64014244], [75.97820282, 10.64042187], [75.9779129, 10.6404171], [75.9779129, 10.64069462], [75.97763824, 10.6406908], [75.97763824, 10.64125156], [75.97735596, 10.64125156], [75.97735596, 10.64181042], [75.9770813, 10.6418047], [75.9770813, 10.64236069], [75.97680664, 10.64236069], [75.97680664, 10.64291954], [75.97652435, 10.64291763], [75.97652435, 10.64347363], [75.97624969, 10.64346886], [75.97624969, 10.64431], [75.97597504, 10.64430618], [75.97597504, 10.64486217], [75.97569275, 10.64485931], [75.97569275, 10.64542007], [75.97541809, 10.64541531], [75.97541809, 10.64597225], [75.9751358, 10.64596939], [75.9751358, 10.64653015], [75.97486115, 10.64653015], [75.97486115, 10.64709091], [75.97458649, 10.64709091], [75.97458649, 10.64764023], [75.9743042, 10.64764023], [75.9743042, 10.64819431], [75.97402954, 10.64819145], [75.97402954, 10.64902973], [75.97374725, 10.64902782], [75.97374725, 10.64958191], [75.9734726, 10.64958382], [75.9734726, 10.6501379], [75.97319794, 10.6501379], [75.97319794, 10.65069389], [75.97290802, 10.65069199], [75.97290802, 10.65125179], [75.97264099, 10.65125179], [75.97264099, 10.65181065], [75.9723587, 10.65180588], [75.9723587, 10.65235996], [75.97208405, 10.65235996], [75.97208405, 10.65319443], [75.97180939, 10.65319443], [75.97180176, 10.65375042], [75.9715271, 10.65375042], [75.9715271, 10.65458202], [75.97125244, 10.65458202], [75.97125244, 10.65542126], [75.97097015, 10.65541553], [75.97097015, 10.65597153], [75.97070313, 10.65596962], [75.97070313, 10.65681076], [75.97041321, 10.65680695], [75.97041321, 10.65736008], [75.97013855, 10.65736008], [75.97013855, 10.65819454], [75.96984863, 10.65818977], [75.96984863, 10.65903091], [75.9695816, 10.65902901], [75.9695816, 10.65958309], [75.96930695, 10.65958023], [75.96930695, 10.66014099], [75.96902466, 10.66013908], [75.96902466, 10.66069508], [75.96875, 10.66069508], [75.96875, 10.6609726], [75.96848297, 10.66097069], [75.96848297, 10.66153145], [75.96819305, 10.66153145], [75.96819305, 10.66181183], [75.9679184, 10.66180515], [75.9679184, 10.66236115], [75.96763611, 10.66236115], [75.96763611, 10.66264057], [75.96736145, 10.66263866], [75.96736145, 10.66319466], [75.96708679, 10.66319466], [75.96708679, 10.66347313], [75.96681213, 10.66347122], [75.96681213, 10.66403103], [75.96652985, 10.66403103], [75.96652985, 10.66431046], [75.96624756, 10.66431046], [75.96624756, 10.66486073], [75.9659729, 10.66486073], [75.9659729, 10.66541862], [75.96569824, 10.66541672], [75.96569824, 10.6659708], [75.96541595, 10.66596889], [75.96541595, 10.66653156], [75.9651413, 10.66652679], [75.9651413, 10.66708279], [75.96485901, 10.66708088], [75.96485901, 10.66792202], [75.96458435, 10.66791725], [75.96458435, 10.66847134], [75.96430206, 10.66847134], [75.96430206, 10.66903019], [75.9640274, 10.66902733], [75.9640274, 10.66958332], [75.96375275, 10.66958141], [75.96375275, 10.67014027], [75.96347046, 10.67014027], [75.96347046, 10.6706934], [75.9631958, 10.67069054], [75.9631958, 10.67126083], [75.96290588, 10.67126083], [75.96290588, 10.67181015], [75.96263885, 10.67180634], [75.96263885, 10.67236233], [75.96235657, 10.67235947], [75.96235657, 10.67292023], [75.96208191, 10.67291641], [75.96208191, 10.6734724], [75.96180725, 10.67346859], [75.96180725, 10.6740303], [75.96152496, 10.6740284], [75.96152496, 10.67458439], [75.96125031, 10.67458153], [75.96125031, 10.67514038], [75.96097565, 10.67513847], [75.96097565, 10.67597198], [75.96069336, 10.67597198], [75.96069336, 10.67653275], [75.9604187, 10.67652798], [75.9604187, 10.67708397], [75.96013641, 10.67706966], [75.96013641, 10.67763996], [75.95986176, 10.67763805], [75.95986176, 10.67819405], [75.9595871, 10.67818928], [75.9595871, 10.67875004], [75.95929718, 10.67875004], [75.95929718, 10.6793108], [75.95903015, 10.67930603], [75.95903015, 10.67986012], [75.95874786, 10.67986012], [75.95874786, 10.68042088], [75.95847321, 10.68041611], [75.95847321, 10.6809721], [75.95819092, 10.68097019], [75.95819092, 10.68153095], [75.95791626, 10.68152809], [75.95791626, 10.6823597], [75.9576416, 10.6823597], [75.9576416, 10.68292141], [75.95735931, 10.68291569], [75.95735931, 10.68347263], [75.95708466, 10.68347263], [75.95707703, 10.68389034], [75.95707703, 10.68403053], [75.95680237, 10.68402863], [75.95680237, 10.68458462], [75.95652771, 10.68457985], [75.95652771, 10.68514061], [75.95625305, 10.6851387], [75.95625305, 10.68597317], [75.95597076, 10.68597031], [75.95597076, 10.68653107], [75.95569611, 10.68652916], [75.95569611, 10.68708324], [75.95540619, 10.68708038], [75.95540619, 10.68764114], [75.95513916, 10.68763924], [75.95513916, 10.68819523], [75.9548645, 10.68819523], [75.9548645, 10.68875122], [75.95458221, 10.68875122], [75.95458221, 10.68958282], [75.95430756, 10.68958092], [75.95430756, 10.69014072], [75.95402527, 10.69013882], [75.95402527, 10.69069481], [75.95375061, 10.69069099], [75.95375061, 10.69152927], [75.95347595, 10.69152737], [75.95347595, 10.69208336], [75.95318604, 10.69208145], [75.95318604, 10.69292164], [75.95291901, 10.69291687], [75.95291901, 10.69347095], [75.95263672, 10.69347095], [75.95263672, 10.69403172], [75.95236206, 10.69402695], [75.95236206, 10.69486141], [75.95207977, 10.69486141], [75.95207977, 10.69543076], [75.95181274, 10.69543076], [75.95181274, 10.69653034], [75.95153046, 10.69653034], [75.95153046, 10.69764042], [75.95124817, 10.69764042], [75.95124817, 10.69902992], [75.95097351, 10.69902802], [75.95097351, 10.69986153], [75.95069122, 10.69985867], [75.95069122, 10.70014], [75.95041656, 10.70014], [75.95041656, 10.70069408], [75.95014191, 10.70069122], [75.95014191, 10.70153046], [75.94985962, 10.7015276], [75.94985962, 10.70347214], [75.94957733, 10.70347023], [75.94957733, 10.70374966], [75.94930267, 10.70374966], [75.94930267, 10.70403004], [75.94902802, 10.70402813], [75.94902802, 10.70430565], [75.94875336, 10.70430565], [75.94875336, 10.70485973], [75.94847107, 10.70485973], [75.94847107, 10.70542145], [75.94819641, 10.70541573], [75.94819641, 10.70597172], [75.94790649, 10.70597172], [75.94790649, 10.70653057], [75.94763947, 10.70652771], [75.94763947, 10.7070837], [75.94735718, 10.70708179], [75.94735718, 10.70763969], [75.94708252, 10.70763779], [75.94708252, 10.70819378], [75.94680786, 10.70819187], [75.94680786, 10.70874977], [75.9465332, 10.70874977], [75.9465332, 10.70931053], [75.94625092, 10.70930672], [75.94625092, 10.70985985], [75.94596863, 10.70985985], [75.94596863, 10.71043015], [75.94569397, 10.71041584], [75.94569397, 10.71097279], [75.94541931, 10.71096992], [75.94541931, 10.71153069], [75.94513702, 10.71152878], [75.94513702, 10.71208191], [75.94486237, 10.71208], [75.94486237, 10.71292114], [75.94458008, 10.71291733], [75.94458008, 10.71347332], [75.94431305, 10.71347046], [75.94431305, 10.71403122], [75.94403076, 10.7140274], [75.94403076, 10.7145834], [75.94374847, 10.71457958], [75.94374847, 10.7151413], [75.94347382, 10.71513939], [75.94347382, 10.71569538], [75.94319153, 10.71569538], [75.94319153, 10.71625137], [75.94291687, 10.71625137], [75.94291687, 10.71708298], [75.94264221, 10.71708107], [75.94264221, 10.71764088], [75.94235992, 10.71763897], [75.94235992, 10.71819496], [75.9420929, 10.71819115], [75.9420929, 10.71875095], [75.94180298, 10.71875095], [75.94180298, 10.71931171], [75.94152832, 10.71930504], [75.94152832, 10.71986103], [75.94125366, 10.71986103], [75.94125366, 10.72069454], [75.94097137, 10.72069073], [75.94097137, 10.72125053], [75.94069672, 10.72125053], [75.94069672, 10.72181034], [75.9404068, 10.72181034], [75.9404068, 10.7223711], [75.94013977, 10.7223711], [75.94013977, 10.72292042], [75.93985748, 10.72291756], [75.93985748, 10.72347355], [75.93958282, 10.72347069], [75.93958282, 10.72402954], [75.93930817, 10.72402668], [75.93930817, 10.72458363], [75.93902588, 10.72457886], [75.93902588, 10.72513962], [75.93875122, 10.72513962], [75.93875122, 10.72569561], [75.93846893, 10.72569084], [75.93846893, 10.72624969], [75.93818665, 10.72624969], [75.93818665, 10.72681046], [75.93791962, 10.72680569], [75.93791962, 10.72736168], [75.93763733, 10.72736168], [75.93763733, 10.72791958], [75.93736267, 10.72791576], [75.93736267, 10.72819424], [75.93708038, 10.72819424], [75.93708038, 10.72875023], [75.9367981, 10.72875023], [75.9367981, 10.72931004], [75.93653107, 10.72930622], [75.93653107, 10.72958374], [75.93624878, 10.72958183], [75.93624878, 10.73013973], [75.93597412, 10.73013783], [75.93597412, 10.73069382], [75.93569183, 10.73069191], [75.93569183, 10.73181057], [75.93541718, 10.73181057], [75.93541718, 10.73292065], [75.93514252, 10.73291588], [75.93514252, 10.73375034], [75.93486023, 10.73375034], [75.93486023, 10.73403072], [75.93458557, 10.73402786], [75.93458557, 10.73458195], [75.93430328, 10.73458195], [75.93430328, 10.7351408], [75.93402863, 10.7351408], [75.93402863, 10.73624992], [75.93374634, 10.73624992], [75.93374634, 10.73708153], [75.93347168, 10.73707962], [75.93347168, 10.73764133], [75.93319702, 10.73763847], [75.93319702, 10.73819542], [75.9329071, 10.7381897], [75.93291473, 10.73875141], [75.93264008, 10.73875141], [75.93264008, 10.73958302], [75.93235779, 10.73958015], [75.93235779, 10.74014091], [75.93208313, 10.74013901], [75.93208313, 10.74097347], [75.93180847, 10.74097061], [75.93180847, 10.74153137], [75.93152618, 10.7415266], [75.93152618, 10.74236107], [75.93125153, 10.74236107], [75.93125153, 10.74292088], [75.93096924, 10.74292088], [75.93096924, 10.74375057], [75.93069458, 10.74374866], [75.93069458, 10.74458313], [75.93041992, 10.74458122], [75.93041992, 10.74514103], [75.93013763, 10.74513912], [75.93013763, 10.74597263], [75.92986298, 10.74597073], [75.92986298, 10.74654102], [75.92958069, 10.74652672], [75.92958069, 10.74736118], [75.92930603, 10.74736118], [75.92930603, 10.74792194], [75.92903137, 10.74792194], [75.92903137, 10.74875164], [75.92874908, 10.74875164], [75.92874908, 10.74930954], [75.9284668, 10.74930954], [75.9284668, 10.75013924], [75.92819214, 10.75013924], [75.92819214, 10.75069332], [75.92791748, 10.75069332], [75.92791748, 10.75124931], [75.92763519, 10.75124931], [75.92763519, 10.75208378], [75.92736053, 10.75208092], [75.92736053, 10.75263977], [75.92708588, 10.75263977], [75.92708588, 10.75319576], [75.92679596, 10.75319099], [75.92679596, 10.75403023], [75.92652893, 10.75402832], [75.92652893, 10.75458431], [75.92624664, 10.75458241], [75.92624664, 10.75541973], [75.92597198, 10.75541782], [75.92597198, 10.75597191], [75.92569733, 10.75597191], [75.92569733, 10.7565279], [75.92541504, 10.7565279], [75.92541504, 10.75736237], [75.92514038, 10.75736046], [75.92514038, 10.75792027], [75.92485809, 10.75792027], [75.92485809, 10.75848103], [75.92457581, 10.75848103], [75.92457581, 10.75931072], [75.92430878, 10.75930595], [75.92430878, 10.75986004], [75.92402649, 10.75986004], [75.92402649, 10.7604208], [75.92375183, 10.7604208], [75.92375183, 10.76124954], [75.92346954, 10.76124954], [75.92346954, 10.76181126], [75.92318726, 10.76181126], [75.92318726, 10.76264095], [75.92292023, 10.76263809], [75.92292023, 10.76319408], [75.92263794, 10.76319027], [75.92263794, 10.76375008], [75.92236328, 10.76375008], [75.92236328, 10.76431084], [75.92208099, 10.76430416], [75.92208099, 10.76486015], [75.92179871, 10.76486015], [75.92179871, 10.76542091], [75.92152405, 10.7654171], [75.92152405, 10.76597309], [75.92124939, 10.76597023], [75.92124939, 10.76653099], [75.9209671, 10.76653099], [75.9209671, 10.76792145], [75.92069244, 10.76791668], [75.92069244, 10.76958275], [75.92041779, 10.76958275], [75.92041779, 10.77014065], [75.9201355, 10.77013874], [75.9201355, 10.77069473], [75.91986084, 10.77068996], [75.91986084, 10.77125072], [75.91958618, 10.77124882], [75.91958618, 10.77208328], [75.91929626, 10.77208138], [75.91929626, 10.77263927], [75.91902924, 10.77263927], [75.91902924, 10.77347088], [75.91873932, 10.77346039], [75.91873932, 10.77431202], [75.91847229, 10.77430534], [75.91847229, 10.77486134], [75.91819763, 10.77486134], [75.91819763, 10.77538109], [75.91819763, 10.77569485], [75.91792297, 10.77569103], [75.91792297, 10.77625179], [75.91764069, 10.77625179], [75.91764069, 10.77680969], [75.9173584, 10.77680492], [75.9173584, 10.7770834], [75.91707611, 10.77708054], [75.91707611, 10.77764034], [75.91680908, 10.77764034], [75.91680908, 10.77819347], [75.91652679, 10.77819347], [75.91652679, 10.77874947], [75.91625214, 10.77874947], [75.91625214, 10.77931023], [75.91596985, 10.77930641], [75.91596985, 10.7798624], [75.91570282, 10.77985859], [75.91570282, 10.7804203], [75.9154129, 10.7804203], [75.9154129, 10.78125191], [75.91513824, 10.78125191], [75.91513824, 10.78180981], [75.91485596, 10.78180981], [75.91486359, 10.78236198], [75.9145813, 10.78236198], [75.9145813, 10.78292274], [75.91430664, 10.78292274], [75.91430664, 10.78374958], [75.91401672, 10.78374958], [75.91401672, 10.78431129], [75.91374969, 10.78430557], [75.91374969, 10.78486156], [75.91348267, 10.78485966], [75.91348267, 10.78542137], [75.91319275, 10.78541565], [75.91319275, 10.78551197], [75.91319275, 10.78625011], [75.91291809, 10.78625011], [75.91291809, 10.78681087], [75.9126358, 10.78680611], [75.9126358, 10.78736019], [75.91236115, 10.78736019], [75.91236115, 10.7881937], [75.91208649, 10.7881918], [75.91208649, 10.78874969], [75.91179657, 10.78874969], [75.91179657, 10.78931141], [75.91152954, 10.78930569], [75.91152954, 10.78985977], [75.91124725, 10.78985977], [75.91124725, 10.79042053], [75.9109726, 10.79041576], [75.9109726, 10.79097176], [75.91069794, 10.79097176], [75.91069794, 10.7915287], [75.91041565, 10.7915287], [75.91041565, 10.79236031], [75.91014099, 10.79236031], [75.91014099, 10.79347324], [75.9098587, 10.79347038], [75.9098587, 10.7945919], [75.90958405, 10.79458332], [75.90958405, 10.7956953], [75.90930939, 10.7956953], [75.90930176, 10.7970829], [75.9090271, 10.7970829], [75.9090271, 10.79819489], [75.90875244, 10.79819107], [75.90875244, 10.79930973], [75.90847015, 10.79930973], [75.90847015, 10.80042171], [75.90820313, 10.80042171], [75.90820313, 10.80181026], [75.90791321, 10.80181026], [75.90791321, 10.80292034], [75.90763855, 10.80292034], [75.90763855, 10.80403042], [75.90735626, 10.80403042], [75.90735626, 10.80513954], [75.9070816, 10.80513954], [75.9070816, 10.80624962], [75.90680695, 10.80624962], [75.90680695, 10.8073616], [75.90652466, 10.8073616], [75.90652466, 10.80847168], [75.90625, 10.80847168], [75.90625, 10.80959129], [75.90597534, 10.80958366], [75.90597534, 10.81069374], [75.90569305, 10.81069183], [75.90569305, 10.81181145], [75.9054184, 10.81181145], [75.9054184, 10.81292057], [75.90513611, 10.81292057], [75.90513611, 10.81403065], [75.90486145, 10.81403065], [75.90486145, 10.81513977], [75.90458679, 10.81513786], [75.90458679, 10.81624985], [75.90429688, 10.81624985], [75.90429688, 10.81764126], [75.90402985, 10.81764126], [75.90402985, 10.81902885], [75.90376282, 10.81902885], [75.90376282, 10.82042122], [75.9034729, 10.8204174], [75.9034729, 10.82208347], [75.90319824, 10.82208347], [75.90319824, 10.82347298], [75.90291595, 10.82347298], [75.90291595, 10.82486057], [75.9026413, 10.82486057], [75.9026413, 10.82625103], [75.90235901, 10.82624912], [75.90235901, 10.82763863], [75.90207672, 10.82763004], [75.90207672, 10.82931042], [75.90180206, 10.82931042], [75.90180206, 10.83069992], [75.9015274, 10.83069324], [75.9015274, 10.8320837], [75.90125275, 10.8320837], [75.90125275, 10.83347225], [75.90097046, 10.83347225], [75.90097046, 10.83458424], [75.9006958, 10.83458424], [75.9006958, 10.83569431], [75.90041351, 10.83569431], [75.90041351, 10.83708382], [75.90013885, 10.83708382], [75.90013885, 10.83819389], [75.89985657, 10.83819199], [75.89985657, 10.83931065], [75.89958191, 10.83931065], [75.89958191, 10.84042072], [75.89930725, 10.84042072], [75.89930725, 10.84181118], [75.89901733, 10.84181118], [75.89901733, 10.84292126], [75.89875031, 10.84292126], [75.89875031, 10.84403133], [75.89848328, 10.84403133], [75.89848328, 10.84542084], [75.89819336, 10.84542084], [75.89819336, 10.84653091], [75.8979187, 10.84653091], [75.8979187, 10.84764099], [75.89762878, 10.84764099], [75.89762878, 10.84903145], [75.89736176, 10.84903145], [75.89736176, 10.85042095], [75.8970871, 10.85041714], [75.8970871, 10.85180473], [75.89680481, 10.85180473], [75.89680481, 10.85319519], [75.89653015, 10.85319519], [75.89653015, 10.85458279], [75.89624786, 10.85458279], [75.89624786, 10.85597134], [75.89597321, 10.85597134], [75.89597321, 10.85736084], [75.89569092, 10.85736084], [75.89569092, 10.85874939], [75.89541626, 10.85874939], [75.89541626, 10.86013985], [75.8951416, 10.86013985], [75.8951416, 10.8615303], [75.89485931, 10.8615303], [75.89485931, 10.8629179], [75.8945694, 10.8629179], [75.8945694, 10.86403179], [75.89430237, 10.86403179], [75.89430237, 10.86513996], [75.89402771, 10.86513996], [75.89402771, 10.86597157], [75.89375305, 10.86597157], [75.89375305, 10.86708355], [75.89347076, 10.86708355], [75.89347076, 10.8684721], [75.89319611, 10.86847019], [75.89319611, 10.87014103], [75.89290619, 10.87014103], [75.89290619, 10.87181091], [75.89263916, 10.87180424], [75.89263916, 10.87319469], [75.89235687, 10.87318993], [75.89235687, 10.87403107], [75.89208221, 10.87402916], [75.89208221, 10.87458324], [75.89180756, 10.87458324], [75.89180756, 10.87569523], [75.8915329, 10.87568092], [75.8915329, 10.87653065], [75.89125061, 10.87653065], [75.89125061, 10.87764072], [75.89097595, 10.87763882], [75.89097595, 10.88097095], [75.89041901, 10.88097095], [75.89041901, 10.88181019], [75.89013672, 10.88180542], [75.89013672, 10.8834734], [75.88986206, 10.88347054], [75.88986206, 10.88487053], [75.88957977, 10.88487053], [75.88957977, 10.88652992], [75.88930511, 10.88652802], [75.88930511, 10.88819408], [75.88903046, 10.88819408], [75.88903046, 10.88958359], [75.8887558, 10.88958168], [75.8887558, 10.89124966], [75.88846588, 10.89124966], [75.88846588, 10.89264011], [75.88819122, 10.89264011], [75.88819122, 10.89375019], [75.88791656, 10.89375019], [75.88791656, 10.89513969], [75.88764191, 10.89513969], [75.88764191, 10.89624977], [75.88735962, 10.89624977], [75.88735962, 10.89764118], [75.88707733, 10.89764118], [75.88708496, 10.89875126], [75.88680267, 10.89875126], [75.88680267, 10.90013885], [75.88652802, 10.90013885], [75.88652802, 10.90153122], [75.88625336, 10.90153122], [75.88625336, 10.9026413], [75.88597107, 10.9026413], [75.88597107, 10.90402889], [75.88568878, 10.90402889], [75.88568878, 10.90514088], [75.88539886, 10.90514088], [75.88539886, 10.90625095], [75.88513947, 10.90624905], [75.88513947, 10.90736103], [75.88486481, 10.90736103], [75.88486481, 10.90847111], [75.88458252, 10.90847111], [75.88458252, 10.90986061], [75.88430786, 10.90986061], [75.88430786, 10.91097355], [75.88402557, 10.91097355], [75.88402557, 10.9123621], [75.88375092, 10.9123621], [75.88375092, 10.91347122], [75.88346863, 10.91347122], [75.88346863, 10.91458416], [75.88319397, 10.91458416], [75.88319397, 10.91597176], [75.88291931, 10.91597176], [75.88291931, 10.91708374], [75.88263702, 10.91708374], [75.88263702, 10.91847229], [75.88236237, 10.91847229], [75.88236237, 10.91958427], [75.88208008, 10.91958046], [75.88208008, 10.92098141], [75.88180542, 10.92097187], [75.88180542, 10.92236233], [75.88153076, 10.92236233], [75.88153076, 10.9234724], [75.88124847, 10.9234724], [75.88124847, 10.92486], [75.88096619, 10.92486], [75.88097382, 10.92625141], [75.88069153, 10.92625141], [75.88069153, 10.92764091], [75.88041687, 10.92764091], [75.88041687, 10.92903137], [75.88014221, 10.92903137], [75.88014221, 10.93015003], [75.87985992, 10.93015003], [75.87985992, 10.93153095], [75.8795929, 10.93153095], [75.8795929, 10.93264103], [75.87930298, 10.93263912], [75.87930298, 10.93375111], [75.87902832, 10.93375111], [75.87902832, 10.93486118], [75.87875366, 10.93486118], [75.87875366, 10.93597126], [75.87847137, 10.93597126], [75.87847137, 10.93708324], [75.87819672, 10.93708324], [75.87819672, 10.93819332], [75.8779068, 10.93819141], [75.8779068, 10.93931007], [75.87763977, 10.93931007], [75.87763977, 10.94042015], [75.87735748, 10.94042015], [75.87735748, 10.94153023], [75.87708282, 10.94153023], [75.87708282, 10.9426403], [75.8768158, 10.9426403], [75.8768158, 10.9440279], [75.87652588, 10.9440279], [75.87652588, 10.94515133], [75.87625122, 10.94515133], [75.87625122, 10.94624996], [75.87596893, 10.94624996], [75.87596893, 10.94736004], [75.87569427, 10.94736004], [75.87569427, 10.94847202], [75.87541962, 10.94847202], [75.87541962, 10.9495821], [75.87513733, 10.9495821], [75.87513733, 10.95069408], [75.87486267, 10.95069027], [75.87486267, 10.95181084], [75.87458038, 10.95181084], [75.87458038, 10.95292091], [75.87431335, 10.95292091], [75.87431335, 10.95403099], [75.87403107, 10.95403099], [75.87403107, 10.95514107], [75.87374878, 10.95513916], [75.87374878, 10.95625114], [75.87347412, 10.95625114], [75.87347412, 10.95736122], [75.87319183, 10.95736122], [75.87319183, 10.95847321], [75.87291718, 10.95847321], [75.87291718, 10.95958328], [75.87264252, 10.95958138], [75.87264252, 10.96042156], [75.87236023, 10.96042156], [75.87236023, 10.96153164], [75.8720932, 10.96153164], [75.8720932, 10.96264172], [75.87180328, 10.96264172], [75.87180328, 10.96375084], [75.87152863, 10.96374893], [75.87152863, 10.96486092], [75.87124634, 10.96486092], [75.87124634, 10.96597099], [75.87097168, 10.96597099], [75.87097168, 10.96681023], [75.87068939, 10.96681023], [75.87068939, 10.9679203], [75.87039948, 10.9679203], [75.87039948, 10.96903038], [75.87014008, 10.96903038], [75.87014008, 10.97014046], [75.86985779, 10.97014046], [75.86985779, 10.97124958], [75.86958313, 10.97124958], [75.86958313, 10.97236156], [75.86930847, 10.97236156], [75.86930847, 10.97347164], [75.86902618, 10.97347164], [75.86902618, 10.97458363], [75.86875153, 10.97458363], [75.86875153, 10.9756937], [75.86846924, 10.9756918], [75.86846924, 10.97681141], [75.86818695, 10.97681141], [75.86818695, 10.97792053], [75.86791992, 10.97792053], [75.86791992, 10.97903061], [75.86765289, 10.97903061], [75.86765289, 10.98014069], [75.86736298, 10.98014069], [75.86736298, 10.9812603], [75.86708069, 10.9812603], [75.86708069, 10.98236275], [75.86680603, 10.98236084], [75.86680603, 10.98347282], [75.86653137, 10.98347282], [75.86653137, 10.9845829], [75.86624908, 10.9845829], [75.86624908, 10.98569489], [75.8659668, 10.98569012], [75.8659668, 10.98681164], [75.86569214, 10.98681164], [75.86569214, 10.98792171], [75.86541748, 10.98791695], [75.86541748, 10.98875141], [75.86513519, 10.98875141], [75.86513519, 10.98986053], [75.86486053, 10.98986053], [75.86486053, 10.99097347], [75.86458588, 10.99097347], [75.86458588, 10.9920826], [75.86429596, 10.99208069], [75.86429596, 10.9932003], [75.86402893, 10.9932003], [75.86402893, 10.99403191], [75.86374664, 10.99403191], [75.86374664, 10.99514198], [75.86347198, 10.99514198], [75.86347198, 10.99626064], [75.86319733, 10.99625015], [75.86319733, 10.99736214], [75.86291504, 10.99736214], [75.86291504, 10.99847221], [75.86235809, 10.99847031], [75.86235809, 10.99903011], [75.86208344, 10.99902821], [75.86208344, 10.99985981], [75.86180878, 10.99985981], [75.86180878, 11.00014019], [75.86180878, 11.00069427], [75.86151886, 11.00068855], [75.86152649, 11.00097179], [75.86125183, 11.00097179], [75.86125183, 11.00208378], [75.86096954, 11.00208187], [75.86096954, 11.0029211], [75.86069489, 11.00291634], [75.86069489, 11.00319386], [75.86096954, 11.00319386], [75.86096954, 11.00374985], [75.86068726, 11.00374985], [75.86069489, 11.00485992], [75.86042023, 11.00485992], [75.86042023, 11.00569439], [75.86013794, 11.00568962], [75.86013794, 11.00681114], [75.85986328, 11.00681114], [75.85986328, 11.00792122], [75.85958099, 11.00792122], [75.85958099, 11.0090313], [75.85930634, 11.00902653], [75.85930634, 11.00986099], [75.85902405, 11.00986099], [75.85902405, 11.01097298], [75.85874939, 11.01097298], [75.85874939, 11.01124859], [75.85901642, 11.01124191], [75.85901642, 11.01153088], [75.85874939, 11.01153088], [75.85874939, 11.01264095], [75.85847473, 11.01263905], [75.85847473, 11.01347256], [75.85819244, 11.01347065], [75.85819244, 11.01375103], [75.85791779, 11.01375103], [75.85791779, 11.01430511], [75.85764313, 11.01430035], [75.85764313, 11.01653194], [75.85736084, 11.01653194], [75.85736084, 11.01791954], [75.8576355, 11.01791668], [75.8576355, 11.01847076], [75.85791779, 11.01847363], [75.85791779, 11.01874924], [75.85902405, 11.01874924], [75.85901642, 11.01847076], [75.85958099, 11.01847076], [75.85958099, 11.01819324], [75.86013794, 11.01819324], [75.86013794, 11.01791668], [75.86042023, 11.01791954], [75.86042023, 11.01764202], [75.86096954, 11.01764202], [75.86096954, 11.01653194], [75.86125183, 11.01653194], [75.86125183, 11.01347065], [75.86152649, 11.01347256], [75.86152649, 11.01319504], [75.86180878, 11.01319504], [75.86180878, 11.01291656], [75.86207581, 11.01291943], [75.86207581, 11.01236057], [75.86235809, 11.01236057], [75.86235809, 11.01180458], [75.86264038, 11.01180935], [75.86264038, 11.00986099], [75.86235809, 11.00986099], [75.86235809, 11.00958347], [75.86208344, 11.00958347], [75.86208344, 11.00930691], [75.86180878, 11.00931072], [75.86180878, 11.00875092], [75.86207581, 11.00875092], [75.86207581, 11.00792122], [75.86180878, 11.00792122], [75.86180878, 11.00736046], [75.86208344, 11.00736046], [75.86208344, 11.00680447], [75.86235809, 11.00681114], [75.86235809, 11.00597], [75.86291504, 11.00597191], [75.86291504, 11.00541592], [75.86347198, 11.00543022], [75.86347198, 11.00514126], [75.86374664, 11.00514126], [75.86374664, 11.00485992], [75.86430359, 11.00485992], [75.86429596, 11.00457954], [75.86541748, 11.00458431], [75.86541748, 11.00485992], [75.86569214, 11.00485992], [75.86569214, 11.00514126], [75.8659668, 11.00514126], [75.8659668, 11.00543022], [75.86653137, 11.00541592], [75.86653137, 11.00569439], [75.86680603, 11.00569439], [75.86680603, 11.00597191], [75.86708069, 11.00597191], [75.86708069, 11.00625134], [75.86736298, 11.00625134], [75.86736298, 11.00652885], [75.86765289, 11.00652885], [75.86765289, 11.00931072], [75.86736298, 11.00930691], [75.86736298, 11.00986099], [75.86708069, 11.00986099], [75.86708069, 11.01124859], [75.86680603, 11.01125145], [75.86680603, 11.01236057], [75.86653137, 11.01236057], [75.86653137, 11.01291943], [75.86624908, 11.01291656], [75.86624908, 11.01319504], [75.86597443, 11.01319504], [75.86597443, 11.01347256], [75.86541748, 11.01347256], [75.86541748, 11.01291656], [75.86569214, 11.01291943], [75.86569214, 11.01097107], [75.86597443, 11.01097298], [75.86597443, 11.00986099], [75.86624908, 11.00986099], [75.86624908, 11.00875092], [75.86653137, 11.00875092], [75.86653137, 11.00846958], [75.86624908, 11.0084734], [75.86624908, 11.00708199], [75.86597443, 11.00708199], [75.86597443, 11.00680447], [75.86569214, 11.00681114], [75.86569214, 11.00652885], [75.86429596, 11.00652885], [75.86429596, 11.00681114], [75.86402893, 11.00680447], [75.86402893, 11.00736046], [75.86374664, 11.00736046], [75.86374664, 11.00764084], [75.86347198, 11.00764084], [75.86347198, 11.00792122], [75.86319733, 11.00792122], [75.86319733, 11.00820065], [75.86347198, 11.00819492], [75.86347198, 11.00958347], [75.86374664, 11.00957966], [75.86374664, 11.01014137], [75.86347198, 11.01014137], [75.86347198, 11.01153088], [75.86319733, 11.01153088], [75.86319733, 11.01291943], [75.86291504, 11.01291656], [75.86291504, 11.01347256], [75.86264038, 11.01347065], [75.86264038, 11.01403236], [75.86235809, 11.01402664], [75.86235809, 11.01458263], [75.86208344, 11.01458263], [75.86208344, 11.01569462], [75.86180878, 11.0156908], [75.86180878, 11.01681042], [75.86151886, 11.01681042], [75.86151886, 11.01791954], [75.86125183, 11.01791668], [75.86125183, 11.01874924], [75.86096954, 11.01874924], [75.86096954, 11.01902962], [75.86068726, 11.01902962], [75.86068726, 11.01931], [75.86042023, 11.01930523], [75.86042023, 11.01958275], [75.85930634, 11.01958275], [75.85930634, 11.01986217], [75.85901642, 11.01985931], [75.85901642, 11.02013969], [75.85874939, 11.02013969], [75.85874939, 11.02043056], [75.85845947, 11.02043056], [75.85845947, 11.02153015], [75.85791779, 11.02153015], [75.85791779, 11.02069092], [75.8576355, 11.02069569], [75.8576355, 11.02041531], [75.85708618, 11.02043056], [75.85708618, 11.02013969], [75.85652924, 11.02013969], [75.85652924, 11.02043056], [75.85624695, 11.02041531], [75.85624695, 11.02069569], [75.85597229, 11.02069569], [75.85597229, 11.0209713], [75.85624695, 11.0209713], [75.85624695, 11.02125168], [75.85597229, 11.02124977], [75.85597229, 11.02208424], [75.85569763, 11.02208424], [75.85569763, 11.02319431], [75.85542297, 11.02318001], [75.85542297, 11.02431011], [75.8548584, 11.0243063], [75.8548584, 11.02569389], [75.85457611, 11.02569199], [75.85457611, 11.02653027], [75.85430908, 11.02653027], [75.85430908, 11.02681065], [75.85402679, 11.02681065], [75.85402679, 11.02902985], [75.85375214, 11.02902794], [75.85375214, 11.0298624], [75.85346985, 11.02985954], [75.85346985, 11.03153133], [75.85320282, 11.03153133], [75.85320282, 11.03237247], [75.8529129, 11.03237247], [75.8529129, 11.03403091], [75.85263824, 11.03402901], [75.85263824, 11.03486061], [75.85235596, 11.03486061], [75.85235596, 11.03514099], [75.85263824, 11.03513908], [75.85263824, 11.03569508], [75.85235596, 11.03569031], [75.85235596, 11.03653145], [75.8520813, 11.03653145], [75.8520813, 11.03764057], [75.85180664, 11.03763866], [75.85180664, 11.03819466], [75.85151672, 11.0381813], [75.85151672, 11.03986073], [75.85124969, 11.03986073], [75.85124969, 11.04069519], [75.85098267, 11.04069138], [75.85098267, 11.04181194], [75.85069275, 11.04180527], [75.85069275, 11.04208279], [75.85098267, 11.04208088], [75.85098267, 11.04264069], [75.85069275, 11.04263878], [75.85069275, 11.04347324], [75.85041809, 11.04347324], [75.85041809, 11.04458332], [75.8501358, 11.04458141], [75.8501358, 11.04541969], [75.84986115, 11.04541683], [75.84986115, 11.0456934], [75.8501358, 11.0456934], [75.8501358, 11.04597092], [75.84986115, 11.04597092], [75.84986115, 11.04624939], [75.8501358, 11.04624939], [75.8501358, 11.04652977], [75.84986115, 11.04652691], [75.84986115, 11.04736233], [75.84958649, 11.04736233], [75.84958649, 11.0484724], [75.84929657, 11.0484724], [75.84929657, 11.0490303], [75.84902954, 11.0490284], [75.84902954, 11.04958439], [75.84874725, 11.04958439], [75.84874725, 11.0504179], [75.8484726, 11.05041122], [75.8484726, 11.05153179], [75.84874725, 11.05153179], [75.84874725, 11.05181026], [75.8484726, 11.05180645], [75.8484726, 11.05236244], [75.84819794, 11.05235958], [75.84819794, 11.05375004], [75.84792328, 11.05375004], [75.84792328, 11.05403042], [75.84819794, 11.05402756], [75.84819794, 11.05486012], [75.84791565, 11.05486012], [75.84791565, 11.0559721], [75.84764099, 11.05597019], [75.84764099, 11.05681133], [75.8473587, 11.05681133], [75.8473587, 11.05792141], [75.84708405, 11.05791569], [75.84708405, 11.05958462], [75.84680939, 11.05958462], [75.84680176, 11.06069469], [75.8465271, 11.06069469], [75.8465271, 11.06236076], [75.84625244, 11.06236076], [75.84625244, 11.06375122], [75.84597015, 11.06375122], [75.84597015, 11.06458282], [75.84570313, 11.06457996], [75.84570313, 11.0654192], [75.84541321, 11.06541729], [75.84541321, 11.06569481], [75.84513855, 11.06569004], [75.84513855, 11.06652927], [75.84485626, 11.06652927], [75.84485626, 11.06792164], [75.8445816, 11.06791687], [75.8445816, 11.06875134], [75.84430695, 11.06875134], [75.84430695, 11.06903172], [75.84402466, 11.06902695], [75.84402466, 11.06958294], [75.84375, 11.06958103], [75.84375, 11.07042027], [75.84348297, 11.07042027], [75.84348297, 11.07263947], [75.84319305, 11.07263947], [75.84319305, 11.07402992], [75.8429184, 11.07402706], [75.8429184, 11.07458401], [75.84263611, 11.07458401], [75.84263611, 11.07569408], [75.84236145, 11.07569408], [75.84236145, 11.07708359], [75.84208679, 11.07708359], [75.84208679, 11.07736206], [75.84179688, 11.07736015], [75.84179688, 11.07791996], [75.84152985, 11.07791805], [75.84152985, 11.07847214], [75.84124756, 11.07847023], [75.84124756, 11.07931137], [75.8409729, 11.07931137], [75.8409729, 11.08041954], [75.84070587, 11.08041954], [75.84070587, 11.08152962], [75.84041595, 11.08152771], [75.84041595, 11.08236217], [75.8401413, 11.08236217], [75.8401413, 11.08347225], [75.83985901, 11.08346081], [75.83985901, 11.08431053], [75.83957672, 11.08431053], [75.83957672, 11.08542061], [75.83930206, 11.08542061], [75.83930206, 11.08681107], [75.8390274, 11.08680439], [75.8390274, 11.0876379], [75.83875275, 11.0876379], [75.83875275, 11.08847332], [75.83847046, 11.08847046], [75.83847046, 11.08875084], [75.8381958, 11.08875084], [75.8381958, 11.08986092], [75.83790588, 11.08986092], [75.83790588, 11.09042072], [75.83763885, 11.09041691], [75.83763885, 11.09069538], [75.83791351, 11.09069538], [75.83791351, 11.0909729], [75.83763885, 11.0909729], [75.83763885, 11.09125137], [75.83790588, 11.09125137], [75.83790588, 11.09152889], [75.83763885, 11.09152889], [75.83763885, 11.09265041], [75.8373642, 11.09263897], [75.8373642, 11.09347343], [75.83708191, 11.09347057], [75.83708191, 11.09403133], [75.83680725, 11.09403133], [75.83680725, 11.09514141], [75.83652496, 11.09513855], [75.83652496, 11.09569454], [75.83625031, 11.09569073], [75.83625031, 11.09681034], [75.83598328, 11.09681034], [75.83598328, 11.09792042], [75.83569336, 11.09792042], [75.83569336, 11.09902954], [75.8354187, 11.09902668], [75.8354187, 11.09958267], [75.83513641, 11.09958076], [75.83513641, 11.10042], [75.83486176, 11.10042], [75.83486176, 11.1012516], [75.8345871, 11.10124874], [75.8345871, 11.10208416], [75.83428955, 11.1020813], [75.83428955, 11.10264015], [75.83403015, 11.10264015], [75.83403015, 11.10347176], [75.83374786, 11.10346889], [75.83374786, 11.10431004], [75.83347321, 11.10430622], [75.83347321, 11.10486221], [75.83319092, 11.10486221], [75.83319092, 11.10597229], [75.83291626, 11.10597229], [75.83291626, 11.10708427], [75.8326416, 11.10708427], [75.8326416, 11.10819435], [75.83235931, 11.10818863], [75.83235931, 11.10902977], [75.8326416, 11.10902786], [75.8326416, 11.10958195], [75.83235931, 11.10958195], [75.83235931, 11.10986233], [75.83207703, 11.10986042], [75.83207703, 11.11042118], [75.83180237, 11.11042118], [75.83180237, 11.11153126], [75.83152771, 11.1115284], [75.83152771, 11.11208439], [75.83125305, 11.11207962], [75.83125305, 11.11264133], [75.83097076, 11.11263847], [75.83097076, 11.11347198], [75.83069611, 11.11347198], [75.83069611, 11.11375141], [75.83040619, 11.11375141], [75.83040619, 11.1154213], [75.83013916, 11.11541653], [75.83013916, 11.115695], [75.82985687, 11.11569023], [75.82985687, 11.11653137], [75.82958221, 11.1165266], [75.82958221, 11.1170826], [75.82930756, 11.1170826], [75.82930756, 11.11736107], [75.8290329, 11.11736107], [75.8290329, 11.11792088], [75.82875061, 11.11791706], [75.82875061, 11.11819458], [75.82847595, 11.11819458], [75.82847595, 11.11847305], [75.82791901, 11.11847115], [75.82791901, 11.11930943], [75.82763672, 11.11930943], [75.82763672, 11.12042236], [75.82736206, 11.12041664], [75.82736206, 11.12069511], [75.82707977, 11.12069511], [75.82707977, 11.12125111], [75.82681274, 11.12125111], [75.82681274, 11.12153053], [75.82624817, 11.12153053], [75.82624817, 11.12181187], [75.82597351, 11.12180519], [75.82597351, 11.1226387], [75.82579041, 11.1226387], [75.82569122, 11.1226387], [75.82569122, 11.12292194], [75.82514191, 11.12291718], [75.82514191, 11.12319469], [75.82569122, 11.12319469], [75.82569122, 11.12347317], [75.82624817, 11.12347317], [75.82624817, 11.12319469], [75.82680511, 11.12319469], [75.82680511, 11.12291718], [75.82736206, 11.12292194], [75.82736206, 11.12263012], [75.82847595, 11.1226387], [75.82847595, 11.12236118], [75.82930756, 11.12236118], [75.82930756, 11.1226387], [75.82985687, 11.12263012], [75.82985687, 11.12292194], [75.83013916, 11.12291718], [75.83013916, 11.12319469], [75.83069611, 11.12319469], [75.83069611, 11.12347317], [75.83125305, 11.12347126], [75.83125305, 11.12375069], [75.83154297, 11.12375069], [75.83154297, 11.12403202], [75.83180237, 11.12402725], [75.83180237, 11.12458324], [75.83207703, 11.12458134], [75.83207703, 11.12541962], [75.83235931, 11.12541676], [75.83235931, 11.12569332], [75.8326416, 11.12569332], [75.8326416, 11.12597084], [75.83374786, 11.12597084], [75.83374786, 11.12624931], [75.83513641, 11.12624931], [75.83513641, 11.12652969], [75.83569336, 11.12652969], [75.83569336, 11.12681007], [75.83597565, 11.12680531], [75.83597565, 11.12708282], [75.83625031, 11.12708282], [75.83625031, 11.12736225], [75.83651733, 11.12735939], [75.83651733, 11.12764168], [75.83680725, 11.12764168], [75.83680725, 11.12792015], [75.83708191, 11.12791538], [75.83708191, 11.12819576], [75.83735657, 11.12819099], [75.83735657, 11.12876129], [75.83763885, 11.12876129], [75.83763885, 11.12930965], [75.83790588, 11.12930965], [75.83790588, 11.12986183], [75.8381958, 11.12986183], [75.8381958, 11.13041973], [75.83847046, 11.13041782], [75.83847046, 11.13097191], [75.83875275, 11.13097191], [75.83875275, 11.1315279], [75.8390274, 11.1315279], [75.8390274, 11.13208389], [75.83930206, 11.13208199], [75.83930206, 11.13264179], [75.83958435, 11.13263988], [75.83957672, 11.13409042], [75.83957672, 11.1354208], [75.83985901, 11.1354208], [75.83985901, 11.13624954], [75.8401413, 11.13624954], [75.8401413, 11.13681126], [75.84041595, 11.13680553], [75.84041595, 11.13736153], [75.84069824, 11.13736153], [75.84069824, 11.13763809], [75.8409729, 11.13763142], [75.8409729, 11.13792133], [75.84124756, 11.13791561], [75.84124756, 11.1384716], [75.84152985, 11.1384697], [75.84152985, 11.13875008], [75.84179688, 11.13875008], [75.84179688, 11.13903141], [75.84208679, 11.13903141], [75.84208679, 11.13931084], [75.84236145, 11.13930416], [75.84236145, 11.13986015], [75.84263611, 11.13986015], [75.84263611, 11.14014053], [75.8429184, 11.14014053], [75.8429184, 11.14042091], [75.84348297, 11.14042091], [75.84348297, 11.14070129], [75.84402466, 11.14069366], [75.84402466, 11.14097309], [75.84430695, 11.14097023], [75.84430695, 11.14125061], [75.84485626, 11.14125061], [75.84485626, 11.14153099], [75.84570313, 11.14153099], [75.84570313, 11.14181137], [75.84680176, 11.1418066], [75.84680939, 11.14236069], [75.84792328, 11.14236069], [75.84792328, 11.14264107], [75.8484726, 11.14264107], [75.8484726, 11.14236069], [75.84929657, 11.14236069], [75.84929657, 11.14264107], [75.84957886, 11.14264107], [75.84957886, 11.14236069], [75.84986115, 11.14236069], [75.84986115, 11.14208221], [75.8501358, 11.14208221], [75.8501358, 11.1418066], [75.85041809, 11.1418066], [75.85041809, 11.14152908], [75.85054016, 11.14152908], [75.85098267, 11.14153099], [75.85098267, 11.14181137], [75.85151672, 11.14181137], [75.85151672, 11.14153099], [75.8520813, 11.14153099], [75.8520813, 11.14125061], [75.85264587, 11.14125061], [75.85264587, 11.14097023], [75.8529129, 11.14097309], [75.8529129, 11.14069366], [75.85346985, 11.14070129], [75.85346985, 11.14042091], [75.85375214, 11.14042091], [75.85375214, 11.13986015], [75.85402679, 11.13986015], [75.85402679, 11.13930416], [75.85430908, 11.13931084], [75.85430908, 11.13903141], [75.8548584, 11.13903141], [75.8548584, 11.13875008], [75.85542297, 11.13875008], [75.85542297, 11.1384697], [75.85569763, 11.1384716], [75.85569763, 11.13819408], [75.85624695, 11.13819408], [75.85624695, 11.13763809], [75.85680389, 11.13763809], [75.85680389, 11.13736153], [75.85708618, 11.13736153], [75.85708618, 11.13680553], [75.85791779, 11.13681126], [75.85791779, 11.13569164], [75.85819244, 11.13569355], [75.85819244, 11.13374996], [75.85845947, 11.13374996], [75.85845947, 11.13264179], [75.85819244, 11.13264179], [75.85819244, 11.13236046], [75.8576355, 11.13236237], [75.8576355, 11.13180637], [75.85791779, 11.13182163], [75.85791779, 11.13125038], [75.85874939, 11.13125038], [75.85874939, 11.13069439], [75.85902405, 11.13069439], [75.85902405, 11.1301403], [75.85930634, 11.1301403], [75.85930634, 11.12986183], [75.85986328, 11.12986183], [75.85986328, 11.12958431], [75.86125183, 11.12958431], [75.86125183, 11.12986183], [75.86096954, 11.12986183], [75.86096954, 11.1301403], [75.86068726, 11.1301403], [75.86068726, 11.13041973], [75.86042023, 11.13041782], [75.86042023, 11.13069439], [75.86013794, 11.13069439], [75.86013794, 11.13097191], [75.85986328, 11.13097191], [75.85986328, 11.13125038], [75.85958099, 11.13125038], [75.85958099, 11.1315279], [75.85930634, 11.1315279], [75.85930634, 11.13182163], [75.85901642, 11.13182163], [75.85902405, 11.13624954], [75.85874939, 11.13624954], [75.85874939, 11.13763809], [75.85847473, 11.13763809], [75.85847473, 11.1384716], [75.85819244, 11.1384697], [75.85819244, 11.13875008], [75.85764313, 11.13875008], [75.85764313, 11.13903141], [75.85652924, 11.13903141], [75.85652924, 11.13931084], [75.85597229, 11.13930416], [75.85597229, 11.13958454], [75.85569763, 11.13958454], [75.85569763, 11.13986015], [75.85514069, 11.13986015], [75.85514069, 11.14014053], [75.8548584, 11.14014053], [75.8548584, 11.14042091], [75.85457611, 11.14042091], [75.85457611, 11.14070129], [75.85430908, 11.14069366], [75.85430908, 11.14097309], [75.85402679, 11.14097023], [75.85402679, 11.14125061], [75.85375214, 11.14125061], [75.85375214, 11.14153099], [75.85320282, 11.14153099], [75.85320282, 11.14181137], [75.8529129, 11.14181137], [75.8529129, 11.14264107], [75.85263824, 11.14263916], [75.85263824, 11.14319515], [75.8520813, 11.14319515], [75.8520813, 11.14347267], [75.85151672, 11.1434679], [75.85151672, 11.14375973], [75.85124969, 11.14375973], [75.85124969, 11.14403057], [75.85041809, 11.14403057], [75.85041809, 11.14319038], [75.84964752, 11.14319229], [75.8473587, 11.14319515], [75.8473587, 11.14347267], [75.84651947, 11.1434679], [75.84651947, 11.14375973], [75.84513855, 11.14375973], [75.84513855, 11.1434679], [75.84486389, 11.14347267], [75.84486389, 11.14319515], [75.8445816, 11.14319515], [75.8445816, 11.14263916], [75.84401703, 11.14264107], [75.84401703, 11.14236069], [75.84347534, 11.14236069], [75.84347534, 11.1418066], [75.84319305, 11.14181137], [75.84319305, 11.14153099], [75.8429184, 11.14153099], [75.8429184, 11.14125061], [75.84263611, 11.14125061], [75.84263611, 11.14097023], [75.84208679, 11.14097309], [75.84208679, 11.14069366], [75.84179688, 11.14070129], [75.84179688, 11.14042091], [75.84152985, 11.14042091], [75.84152985, 11.14014053], [75.84124756, 11.14014053], [75.84124756, 11.13957977], [75.8409729, 11.13958454], [75.8409729, 11.1390276], [75.84070587, 11.13903141], [75.84069061, 11.13875008], [75.84041595, 11.13875008], [75.84041595, 11.1384697], [75.8401413, 11.1384716], [75.8401413, 11.13791561], [75.83985901, 11.13792133], [75.83985901, 11.13763142], [75.83958435, 11.13763809], [75.83958435, 11.13736153], [75.83930206, 11.13736153], [75.83930206, 11.1370821], [75.8390274, 11.1370821], [75.8390274, 11.13652802], [75.83847046, 11.13652992], [75.83847046, 11.13624954], [75.8381958, 11.13624954], [75.8381958, 11.13597202], [75.83791351, 11.13597202], [75.83791351, 11.13569355], [75.83763885, 11.13569355], [75.83763885, 11.13541603], [75.83598328, 11.1354208], [75.83598328, 11.13514042], [75.83513641, 11.13514042], [75.83513641, 11.13486004], [75.83428955, 11.13486004], [75.83428955, 11.13457012], [75.83403015, 11.13458443], [75.83403015, 11.13319397], [75.83374786, 11.13319397], [75.83374786, 11.13291645], [75.83347321, 11.13292027], [75.83347321, 11.13264179], [75.83319092, 11.13264179], [75.83319092, 11.13208199], [75.83291626, 11.13208389], [75.83291626, 11.13180637], [75.8326416, 11.13182163], [75.8326416, 11.1315279], [75.83235931, 11.1315279], [75.83235931, 11.13125038], [75.83207703, 11.13125038], [75.83207703, 11.13097191], [75.83125305, 11.13097191], [75.83125305, 11.13125038], [75.82958221, 11.13125038], [75.82958221, 11.13069439], [75.82847595, 11.13069439], [75.82847595, 11.1301403], [75.82818604, 11.1301403], [75.82818604, 11.12958145], [75.82791901, 11.12958431], [75.82791901, 11.12930584], [75.82736206, 11.12930965], [75.82736206, 11.12876129], [75.82707977, 11.12876129], [75.82707977, 11.12847137], [75.82680511, 11.12847137], [75.82680511, 11.12819576], [75.82653046, 11.12819576], [75.82653046, 11.12763977], [75.82624817, 11.12764168], [75.82624817, 11.12569141], [75.82597351, 11.12569332], [75.82597351, 11.12541676], [75.82485962, 11.12541676], [75.82485962, 11.12597084], [75.82430267, 11.12597084], [75.82430267, 11.12624931], [75.82402802, 11.12624931], [75.82402802, 11.12681007], [75.82375336, 11.12680531], [75.82375336, 11.12708282], [75.82347107, 11.12708092], [75.82347107, 11.12764168], [75.82319641, 11.12763977], [75.82319641, 11.12819576], [75.82290649, 11.12819099], [75.82290649, 11.12930965], [75.82263947, 11.12930584], [75.82263947, 11.12986183], [75.82234955, 11.12986183], [75.82234955, 11.1301403], [75.82208252, 11.1301403], [75.82208252, 11.13097191], [75.82180786, 11.13097191], [75.82180786, 11.13182163], [75.82152557, 11.13180637], [75.82152557, 11.13208389], [75.82125092, 11.13208389], [75.82125092, 11.1331892], [75.82096863, 11.13320065], [75.82096863, 11.13403034], [75.82069397, 11.13402843], [75.82069397, 11.13458443], [75.82041931, 11.13457012], [75.82041931, 11.1354208], [75.82013702, 11.13541603], [75.82013702, 11.13569355], [75.81986237, 11.13569164], [75.81986237, 11.13624954], [75.81958008, 11.13624954], [75.81958008, 11.1370821], [75.81930542, 11.1370821], [75.81930542, 11.13763809], [75.81903076, 11.13763142], [75.81903076, 11.13792133], [75.81930542, 11.13791561], [75.81930542, 11.13819408], [75.81903076, 11.13819027], [75.81903076, 11.13875008], [75.81874847, 11.13875008], [75.81874847, 11.13903141], [75.81846619, 11.13903141], [75.81846619, 11.13931084], [75.81819153, 11.13931084], [75.81819153, 11.14042091], [75.81791687, 11.14041615], [75.81791687, 11.14097309], [75.81764221, 11.14097023], [75.81764221, 11.14125061], [75.81735992, 11.14125061], [75.81735992, 11.14208221], [75.8170929, 11.14208031], [75.8170929, 11.14375973], [75.81680298, 11.14375973], [75.81680298, 11.14403057], [75.81653595, 11.14403057], [75.81653595, 11.14514065], [75.81625366, 11.14513874], [75.81625366, 11.14569473], [75.81597137, 11.14568996], [75.81597137, 11.14625072], [75.81569672, 11.14625072], [75.81569672, 11.1465292], [75.81541443, 11.1465292], [75.81541443, 11.14708328], [75.81513977, 11.14708328], [75.81513977, 11.1473608], [75.81485748, 11.1473608], [75.81485748, 11.14792156], [75.81430817, 11.14791679], [75.81430817, 11.14847088], [75.81402588, 11.14847088], [75.81402588, 11.14903164], [75.81375122, 11.14903164], [75.81375122, 11.14931202], [75.81319427, 11.14930534], [75.81319427, 11.14958286], [75.81263733, 11.14958286], [75.81263733, 11.14986134], [75.81181335, 11.14986134], [75.81181335, 11.15014076], [75.81153107, 11.15014076], [75.81153107, 11.15042019], [75.81069183, 11.15041733], [75.81069183, 11.15069485], [75.81014252, 11.15069485], [75.81014252, 11.15097332], [75.80986023, 11.15097141], [75.80986023, 11.15125084], [75.8095932, 11.15125084], [75.8095932, 11.15152931], [75.80902863, 11.1515274], [75.80902863, 11.1520834], [75.80874634, 11.1520834], [75.80874634, 11.15236092], [75.80819702, 11.15236092], [75.80819702, 11.15291977], [75.80791473, 11.15291691], [75.80791473, 11.15319633], [75.80764008, 11.15319633], [75.80764008, 11.15347099], [75.80708313, 11.15347099], [75.80708313, 11.15361023], [75.80708313, 11.15402985], [75.80680847, 11.15402985], [75.80680847, 11.15431023], [75.80625153, 11.15430546], [75.80625153, 11.1548624], [75.80568695, 11.1548624], [75.80568695, 11.15514183], [75.80541992, 11.15514183], [75.80541992, 11.1554203], [75.80513763, 11.1554203], [75.80513763, 11.15569973], [75.80347443, 11.15569305], [75.80347443, 11.15597153], [75.80319214, 11.15597153], [75.80319214, 11.15625191], [75.80291748, 11.15625191], [75.80291748, 11.15653038], [75.80319214, 11.15653038], [75.80319214, 11.15680981], [75.8034668, 11.15680981], [75.8034668, 11.15736198], [75.80374908, 11.15736198], [75.80374908, 11.15764046], [75.80264282, 11.15764046], [75.80264282, 11.15792179], [75.80208588, 11.15791798], [75.80208588, 11.15819359], [75.80180359, 11.15819359], [75.80180359, 11.15874958], [75.80153656, 11.158741], [75.80153656, 11.15931034], [75.80180359, 11.15930557], [75.80180359, 11.15985966], [75.80236053, 11.15985966], [75.80236053, 11.16014004], [75.80291748, 11.16014004], [75.80291748, 11.16042042], [75.80319214, 11.16041565], [75.80319214, 11.16069412], [75.80347443, 11.16069412], [75.80347443, 11.16097164], [75.80374908, 11.16096973], [75.80374908, 11.16125011], [75.80430603, 11.16125011], [75.80430603, 11.16152954], [75.80458069, 11.16152763], [75.80458069, 11.16180611], [75.80513763, 11.16180611], [75.80513763, 11.16208363], [75.80596924, 11.16208363], [75.80596924, 11.1623621], [75.80652618, 11.16236019], [75.80652618, 11.16263962], [75.80902863, 11.16263962], [75.80902863, 11.15931034], [75.80930328, 11.15931034], [75.80930328, 11.158741], [75.80958557, 11.15874958], [75.80958557, 11.15791798], [75.80986023, 11.15792179], [75.80986023, 11.15764046], [75.81014252, 11.15764046], [75.81014252, 11.15736198], [75.81069183, 11.15736198], [75.81069183, 11.15708447], [75.81096649, 11.15708065], [75.81096649, 11.15736198], [75.81153107, 11.15736198], [75.81153107, 11.15764046], [75.81236267, 11.15764046], [75.81236267, 11.15792179], [75.81319427, 11.15791798], [75.81319427, 11.15819359], [75.81346893, 11.15819359], [75.81346893, 11.15847206], [75.81375122, 11.15847206], [75.81375122, 11.15874958], [75.81430817, 11.158741], [75.81430817, 11.15902996], [75.81458282, 11.15902996], [75.81458282, 11.15931034], [75.81513977, 11.15930557], [75.81513977, 11.15958405], [75.81597137, 11.15958405], [75.81597137, 11.15985966], [75.81719208, 11.15985966], [75.81735992, 11.15985966], [75.81735992, 11.15958405], [75.81764221, 11.15958405], [75.81764221, 11.15902805], [75.81819153, 11.15902996], [75.81819153, 11.158741], [75.81847382, 11.15874958], [75.81847382, 11.15847206], [75.81874847, 11.15847206], [75.81874847, 11.15791798], [75.81903076, 11.15792179], [75.81903076, 11.15764046], [75.81931305, 11.15764046], [75.81931305, 11.15736198], [75.81958008, 11.15736198], [75.81958008, 11.15708447], [75.82013702, 11.15708447], [75.82013702, 11.15680599], [75.82096863, 11.15680981], [75.82096863, 11.15653038], [75.82180786, 11.15653038], [75.82180786, 11.15625191], [75.82234955, 11.15625191], [75.82234955, 11.15597153], [75.82319641, 11.15597153], [75.82319641, 11.15625191], [75.82347107, 11.15625191], [75.82347107, 11.15653038], [75.82375336, 11.15653038], [75.82375336, 11.15680981], [75.82430267, 11.15680599], [75.82430267, 11.15708447], [75.82457733, 11.15708065], [75.82457733, 11.15736198], [75.82485962, 11.15736198], [75.82485962, 11.15764046], [75.82514191, 11.1576376], [75.82514191, 11.15819359], [75.82569122, 11.15819359], [75.82569122, 11.15874958], [75.82624817, 11.15874958], [75.82624817, 11.15847206], [75.82680511, 11.15847206], [75.82680511, 11.15819359], [75.82875061, 11.15819359], [75.82875061, 11.15847206], [75.82819366, 11.15847206], [75.82819366, 11.15874958], [75.82791901, 11.158741], [75.82791901, 11.15902996], [75.82763672, 11.15902996], [75.82763672, 11.15931034], [75.82736206, 11.15930557], [75.82736206, 11.15986156], [75.82707977, 11.15985966], [75.82707977, 11.16042042], [75.82680511, 11.16041565], [75.82680511, 11.16069412], [75.82707977, 11.16069412], [75.82707977, 11.16097164], [75.82736206, 11.16096973], [75.82736206, 11.16152954], [75.82763672, 11.16152763], [75.82763672, 11.16180611], [75.82736206, 11.16180611], [75.82736206, 11.16208363], [75.82514191, 11.16208363], [75.82514191, 11.16152763], [75.82457733, 11.16152954], [75.82457733, 11.16125011], [75.82430267, 11.16125011], [75.82430267, 11.16068935], [75.82402802, 11.16069412], [75.82402802, 11.16014004], [75.82375336, 11.16014004], [75.82375336, 11.15902996], [75.82347107, 11.15902996], [75.82347107, 11.158741], [75.82375336, 11.15874958], [75.82375336, 11.15819359], [75.82347107, 11.15819359], [75.82347107, 11.15791798], [75.82319641, 11.15792179], [75.82319641, 11.15736198], [75.82290649, 11.15736198], [75.82290649, 11.15708065], [75.82263947, 11.15708447], [75.82263947, 11.15680599], [75.82208252, 11.15680599], [75.82208252, 11.15708447], [75.82180786, 11.15708447], [75.82180786, 11.15736198], [75.82125092, 11.15736198], [75.82125092, 11.15764046], [75.82096863, 11.15764046], [75.82096863, 11.15792179], [75.82069397, 11.15791798], [75.82069397, 11.15819359], [75.82041931, 11.15819359], [75.82041931, 11.15847206], [75.82013702, 11.15847206], [75.82013702, 11.15874958], [75.81986237, 11.158741], [75.81986237, 11.15902996], [75.81958008, 11.15902996], [75.81958008, 11.15931034], [75.81930542, 11.15930557], [75.81930542, 11.15958405], [75.81903076, 11.15957928], [75.81903076, 11.16014004], [75.81874847, 11.16014004], [75.81874847, 11.16125011], [75.81847382, 11.16125011], [75.81847382, 11.16180611], [75.81735992, 11.16180611], [75.81735992, 11.16152763], [75.8170929, 11.16152954], [75.8170929, 11.16125011], [75.8167572, 11.16125011], [75.81569672, 11.16125011], [75.81569672, 11.16096973], [75.81485748, 11.16097164], [75.81485748, 11.16069412], [75.81402588, 11.16069412], [75.81402588, 11.16041565], [75.81375122, 11.16042042], [75.81375122, 11.16014004], [75.81347656, 11.16014004], [75.81347656, 11.15985966], [75.81319427, 11.15986156], [75.81319427, 11.15958405], [75.81291962, 11.15958405], [75.81291962, 11.15930557], [75.81236267, 11.15930557], [75.81236267, 11.1623621], [75.81263733, 11.16236019], [75.81263733, 11.16263962], [75.81291962, 11.16263771], [75.81291962, 11.1631937], [75.81319427, 11.1631937], [75.81318665, 11.16486931], [75.81318665, 11.16514015], [75.81346893, 11.16513824], [75.81346893, 11.16569424], [75.81375122, 11.16569424], [75.81375122, 11.16597176], [75.81402588, 11.16597176], [75.81402588, 11.16625023], [75.81430817, 11.16625023], [75.81430817, 11.16653061], [75.81458282, 11.16653061], [75.81458282, 11.16681099], [75.81513977, 11.16681099], [75.81513977, 11.16792965], [75.81541443, 11.1679163], [75.81541443, 11.16875076], [75.81569672, 11.1687479], [75.81569672, 11.16986275], [75.81597137, 11.16986084], [75.81597137, 11.1706953], [75.81624603, 11.170681], [75.81624603, 11.17153072], [75.81653595, 11.17153072], [75.81653595, 11.1718092], [75.81680298, 11.17180538], [75.81680298, 11.17236137], [75.8170929, 11.17236137], [75.8170929, 11.17263889], [75.81764221, 11.17263889], [75.81764221, 11.17291927], [75.81819153, 11.17291737], [75.81819153, 11.17319489], [75.81847382, 11.17319489], [75.81847382, 11.17347336], [75.81903076, 11.17347336], [75.81903076, 11.17375088], [75.81958008, 11.17374039], [75.81958008, 11.17403126], [75.82013702, 11.17402744], [75.82013702, 11.17458344], [75.82041931, 11.17458057], [75.82041931, 11.17514133], [75.82068634, 11.17514133], [75.82068634, 11.17542171], [75.82096863, 11.17541695], [75.82096863, 11.17597103], [75.82125092, 11.17597103], [75.82125092, 11.17681026], [75.8215332, 11.17681026], [75.8215332, 11.17764187], [75.82208252, 11.17763901], [75.82208252, 11.17819309], [75.82236481, 11.17819309], [75.82236481, 11.17847347], [75.82290649, 11.17847061], [75.82290649, 11.17875099], [75.82347107, 11.17875099], [75.82347107, 11.17903042], [75.82875061, 11.17903042], [75.82875061, 11.17930984], [75.82902527, 11.17930508], [75.82902527, 11.18069553], [75.82514191, 11.18069553], [75.82514191, 11.18097115], [75.82347107, 11.18096924], [75.82347107, 11.18125153], [75.82234955, 11.18125153], [75.82234955, 11.18153191], [75.8215332, 11.18153191], [75.8215332, 11.18181038], [75.82096863, 11.18180561], [75.82096863, 11.18208408], [75.82013702, 11.18208408], [75.82013702, 11.18180561], [75.81931305, 11.18181038], [75.81931305, 11.18153191], [75.81874847, 11.18153191], [75.81874847, 11.18125153], [75.81846619, 11.18125153], [75.81846619, 11.18096924], [75.81764221, 11.18097115], [75.81764221, 11.18069553], [75.81708527, 11.18069553], [75.81708527, 11.18041801], [75.81624603, 11.18041992], [75.81624603, 11.18013859], [75.81569672, 11.18013859], [75.81569672, 11.17987061], [75.81513977, 11.17987061], [75.81513977, 11.17958069], [75.81458282, 11.1795826], [75.81458282, 11.17930508], [75.81402588, 11.17930984], [75.81402588, 11.17875099], [75.81375122, 11.17875099], [75.81375122, 11.17819118], [75.81346893, 11.17819309], [75.81346893, 11.17708302], [75.81319427, 11.17708302], [75.81319427, 11.17680454], [75.81291962, 11.17681026], [75.81291962, 11.17653179], [75.81263733, 11.17653179], [75.81263733, 11.17597103], [75.81236267, 11.17597103], [75.81236267, 11.17569542], [75.81208038, 11.17569542], [75.81208038, 11.17513943], [75.81153107, 11.17514133], [75.81153107, 11.17458057], [75.81124878, 11.17458344], [75.81124878, 11.1712513], [75.81096649, 11.1712513], [75.81096649, 11.17097092], [75.81069183, 11.17097282], [75.81069183, 11.1706953], [75.81014252, 11.1706953], [75.81014252, 11.17041683], [75.80986023, 11.17042065], [75.80986023, 11.16986275], [75.8095932, 11.16986275], [75.8095932, 11.16958046], [75.80930328, 11.16958332], [75.80930328, 11.16847324], [75.80902863, 11.16847324], [75.80902863, 11.16625023], [75.80874634, 11.16625023], [75.80874634, 11.16597176], [75.80819702, 11.16597176], [75.80819702, 11.16541576], [75.80764008, 11.16542053], [75.80764008, 11.16514015], [75.80697632, 11.16514015], [75.80680847, 11.16514015], [75.80680847, 11.16499043], [75.80680847, 11.16485977], [75.80664825, 11.16486454], [75.80625153, 11.16486931], [75.80625153, 11.16458035], [75.80569458, 11.16458225], [75.80569458, 11.16430569], [75.80458069, 11.16431141], [75.80458069, 11.16374969], [75.80430603, 11.16374969], [75.80430603, 11.16347027], [75.80374908, 11.16347218], [75.80374908, 11.1631937], [75.80347443, 11.1631937], [75.80347443, 11.16291618], [75.80291748, 11.16292095], [75.80291748, 11.16263962], [75.80208588, 11.16263771], [75.80208588, 11.1631937], [75.80236053, 11.1631918], [75.80236053, 11.16431141], [75.80208588, 11.16431141], [75.80208588, 11.16514015], [75.80179596, 11.16514015], [75.80179596, 11.16542053], [75.80152893, 11.16541576], [75.80152893, 11.16597176], [75.80124664, 11.16596985], [75.80124664, 11.16681099], [75.80097198, 11.16681099], [75.80097198, 11.16764069], [75.80069733, 11.16764069], [75.80069733, 11.16903114], [75.80042267, 11.16903114], [75.80042267, 11.17014122], [75.80014038, 11.17013931], [75.80014038, 11.1706953], [75.79985809, 11.170681], [75.79985809, 11.17153072], [75.79957581, 11.17153072], [75.79957581, 11.1718092], [75.79985809, 11.17180538], [75.79985809, 11.17236137], [75.79958344, 11.17236137], [75.79958344, 11.17319489], [75.79930878, 11.17319489], [75.79930878, 11.17347336], [75.79902649, 11.17347336], [75.79902649, 11.17375088], [75.79875183, 11.17374039], [75.79875183, 11.17403126], [75.79846954, 11.17402744], [75.79846954, 11.17458344], [75.79817963, 11.17458057], [75.79819489, 11.17486095], [75.79763794, 11.17486095], [75.79763794, 11.17569542], [75.79792023, 11.17569065], [75.79792023, 11.17764187], [75.79736328, 11.17763901], [75.79736328, 11.17847347], [75.79708099, 11.17847061], [75.79708099, 11.17903042], [75.79680634, 11.17903042], [75.79680634, 11.18013859], [75.79651642, 11.18013859], [75.79651642, 11.18041992], [75.79680634, 11.18041801], [75.79680634, 11.18069553], [75.79651642, 11.18069077], [75.79651642, 11.18125153], [75.79624939, 11.18125153], [75.79624939, 11.18153191], [75.7959671, 11.18153191], [75.7959671, 11.18264198], [75.79569244, 11.18264008], [75.79569244, 11.18375015], [75.79541779, 11.18375015], [75.79541779, 11.18486214], [75.79514313, 11.18486023], [75.79514313, 11.18513966], [75.79486084, 11.18513775], [75.79486084, 11.18569374], [75.79458618, 11.18568039], [75.79458618, 11.18624973], [75.79429626, 11.18624973], [75.79429626, 11.18653011], [75.79402924, 11.18653011], [75.79402924, 11.18764019], [75.79374695, 11.18764019], [75.79374695, 11.18847179], [75.79347229, 11.18847179], [75.79347229, 11.18902969], [75.79319763, 11.18902779], [75.79319763, 11.18958378], [75.79291534, 11.18958378], [75.79291534, 11.19069386], [75.79264069, 11.19069386], [75.79264069, 11.19124985], [75.79236603, 11.19124985], [75.79236603, 11.19153118], [75.79208374, 11.19152832], [75.79208374, 11.19208431], [75.79180908, 11.19207954], [75.79180908, 11.19264126], [75.79152679, 11.1926384], [75.79152679, 11.19319439], [75.79125214, 11.19318962], [75.79125214, 11.19402885], [75.79096985, 11.19402885], [75.79096985, 11.19458199], [75.79070282, 11.19458008], [75.79070282, 11.19514084], [75.7904129, 11.19514084], [75.7904129, 11.19542122], [75.79070282, 11.19542122], [75.79070282, 11.1965313], [75.7904129, 11.1965313], [75.7904129, 11.19681072], [75.79013824, 11.19680691], [75.79013824, 11.19708347], [75.78985596, 11.19707966], [75.78985596, 11.19764137], [75.7895813, 11.19763947], [75.7895813, 11.19791698], [75.78986359, 11.19791698], [75.78986359, 11.19819546], [75.7895813, 11.19819546], [75.7895813, 11.19847298], [75.78930664, 11.19847107], [75.78930664, 11.19903088], [75.78902435, 11.19902897], [75.78902435, 11.19958305], [75.78874969, 11.19958019], [75.78874969, 11.20014095], [75.78847504, 11.20013905], [75.78847504, 11.20097256], [75.78819275, 11.20097065], [75.78819275, 11.20153141], [75.78791809, 11.20152664], [75.78791809, 11.20208263], [75.7876358, 11.20208073], [75.7876358, 11.20292187], [75.78736115, 11.2029171], [75.78736115, 11.20347309], [75.78708649, 11.20347118], [75.78708649, 11.20404053], [75.7868042, 11.20402718], [75.7868042, 11.20458317], [75.78708649, 11.20458126], [75.78708649, 11.20514202], [75.78679657, 11.20514202], [75.78679657, 11.20541954], [75.78652954, 11.20541668], [75.78652954, 11.20569324], [75.78623962, 11.20569134], [75.78623962, 11.20624924], [75.78652954, 11.20624924], [75.78652954, 11.20652962], [75.78623962, 11.20652962], [75.78623962, 11.20763969], [75.7859726, 11.20763969], [75.7859726, 11.20792198], [75.78569794, 11.20792198], [75.78569794, 11.20875168], [75.78541565, 11.20874882], [75.78541565, 11.20958424], [75.78514099, 11.20958138], [75.78514099, 11.21041965], [75.7848587, 11.21041775], [75.7848587, 11.21125031], [75.78457642, 11.21125031], [75.78457642, 11.21152973], [75.78430939, 11.21152782], [75.78430176, 11.21291637], [75.7840271, 11.21291637], [75.7840271, 11.21319389], [75.78375244, 11.21319103], [75.78375244, 11.21375179], [75.78347015, 11.21374989], [75.78347015, 11.21458435], [75.78320313, 11.21457863], [75.78320313, 11.21514034], [75.78291321, 11.21514034], [75.78291321, 11.21625042], [75.78263855, 11.21625042], [75.78263855, 11.21708202], [75.78235626, 11.21708202], [75.78235626, 11.21763992], [75.7820816, 11.21763992], [75.7820816, 11.21792126], [75.78180695, 11.21791553], [75.78180695, 11.21819401], [75.78151703, 11.21819019], [75.78151703, 11.21931076], [75.78125, 11.21930599], [75.78125, 11.22097206], [75.78098297, 11.22097015], [75.78098297, 11.22181129], [75.78069305, 11.22181129], [75.78069305, 11.22264099], [75.7804184, 11.22263908], [75.7804184, 11.2234726], [75.78013611, 11.22346973], [75.78013611, 11.22431087], [75.77986145, 11.22430515], [75.77986145, 11.22486115], [75.77958679, 11.22485161], [75.77958679, 11.22542095], [75.7793045, 11.22541714], [75.7793045, 11.22597313], [75.77902985, 11.22597122], [75.77902985, 11.22653103], [75.77874756, 11.22652912], [75.77874756, 11.22708321], [75.7784729, 11.2270813], [75.7784729, 11.23014069], [75.77819824, 11.23013878], [75.77819824, 11.23069477], [75.77791595, 11.23069096], [75.77791595, 11.23125076], [75.7776413, 11.23125076], [75.7776413, 11.23152924], [75.77735901, 11.23152924], [75.77735901, 11.23208332], [75.77707672, 11.23208141], [75.77707672, 11.23236084], [75.77680206, 11.23236084], [75.77680206, 11.23291969], [75.7765274, 11.23291683], [75.7765274, 11.23402691], [75.77625275, 11.23402691], [75.77625275, 11.2345829], [75.77597046, 11.23458099], [75.77597046, 11.23542023], [75.77541351, 11.23541546], [75.77541351, 11.23597145], [75.77513885, 11.23597145], [75.77513885, 11.23680973], [75.77485657, 11.23680973], [75.77485657, 11.23791981], [75.77458191, 11.2379179], [75.77458191, 11.23847198], [75.77429962, 11.23847198], [75.77429962, 11.23931026], [75.77402496, 11.23930645], [75.77402496, 11.23986244], [75.77375031, 11.23985958], [75.77375031, 11.24042034], [75.77348328, 11.24042034], [75.77348328, 11.24153042], [75.77319336, 11.24152756], [75.77319336, 11.24208355], [75.7729187, 11.24208164], [75.7729187, 11.24374962], [75.77263641, 11.24374962], [75.77263641, 11.24514008], [75.77236176, 11.24514008], [75.77236176, 11.24653053], [75.7720871, 11.24653053], [75.7720871, 11.24792099], [75.77179718, 11.24792099], [75.77179718, 11.24875069], [75.77153015, 11.24875069], [75.77153015, 11.24931145], [75.77124023, 11.24931145], [75.77124023, 11.25014114], [75.77097321, 11.25013924], [75.77097321, 11.25097275], [75.77069092, 11.25097275], [75.77069092, 11.25181103], [75.77041626, 11.25181103], [75.77041626, 11.25264072], [75.7701416, 11.25263882], [75.7701416, 11.25347328], [75.76985931, 11.25347137], [75.76985931, 11.25431156], [75.76957703, 11.25431156], [75.76957703, 11.2551527], [75.76930237, 11.25513935], [75.76930237, 11.25625134], [75.76902771, 11.25625134], [75.76902771, 11.25819302], [75.76875305, 11.25819492], [75.76875305, 11.2584734], [75.76847076, 11.25847054], [75.76847076, 11.25875092], [75.76819611, 11.25875092], [75.76819611, 11.25902939], [75.76847076, 11.25902653], [75.76847076, 11.25986099], [75.76819611, 11.25986099], [75.76819611, 11.26069641], [75.76790619, 11.26069069], [75.76790619, 11.26153183], [75.76763916, 11.26152706], [75.76763916, 11.26319313], [75.7673645, 11.26319313], [75.7673645, 11.2634716], [75.76708221, 11.2634716], [75.76708221, 11.26375198], [75.76680756, 11.26375198], [75.76680756, 11.26403046], [75.7665329, 11.26403046], [75.7665329, 11.26431274], [75.76625061, 11.26430607], [75.76625061, 11.26486206], [75.76597595, 11.26486206], [75.76597595, 11.26597214], [75.76568604, 11.26596928], [75.76568604, 11.26653004], [75.76542664, 11.26653004], [75.76542664, 11.2670908], [75.76513672, 11.2670908], [75.76513672, 11.26764011], [75.76486206, 11.26764011], [75.76486206, 11.26931095], [75.76513672, 11.26930618], [75.76513672, 11.2695837], [75.76541901, 11.2695837], [75.76541901, 11.26986217], [75.76513672, 11.26986027], [75.76513672, 11.27042103], [75.76457977, 11.27041626], [75.76457977, 11.27069378], [75.76430511, 11.27069378], [75.76430511, 11.27097225], [75.76403046, 11.27097034], [75.76403046, 11.27124977], [75.76374817, 11.27124977], [75.76374817, 11.27235985], [75.76347351, 11.27235985], [75.76347351, 11.27347183], [75.76374817, 11.27346992], [75.76374817, 11.27403069], [75.76403046, 11.27402782], [75.76403046, 11.27486038], [75.76374817, 11.27486038], [75.76374817, 11.27597332], [75.76346588, 11.27597046], [75.76346588, 11.27681065], [75.76319122, 11.27680683], [75.76319122, 11.27736092], [75.76291656, 11.27736092], [75.76291656, 11.27792072], [75.76264191, 11.27791691], [75.76264191, 11.2784729], [75.76235962, 11.2784729], [75.76235962, 11.27875137], [75.7620697, 11.27875137], [75.7620697, 11.27932072], [75.76180267, 11.27930546], [75.76180267, 11.27986145], [75.76125336, 11.27986145], [75.76125336, 11.28014088], [75.76069641, 11.28014088], [75.76069641, 11.28042126], [75.76040649, 11.28042126], [75.76040649, 11.28125095], [75.76013947, 11.28125095], [75.76013947, 11.28236103], [75.75985718, 11.28236103], [75.75985718, 11.28292179], [75.75958252, 11.28292179], [75.75958252, 11.28375053], [75.75930023, 11.28375053], [75.75930023, 11.28431034], [75.75902557, 11.28430462], [75.75902557, 11.28486061], [75.75875092, 11.28486061], [75.75875092, 11.28569317], [75.75846863, 11.28569126], [75.75846863, 11.28652954], [75.75819397, 11.28652668], [75.75819397, 11.28708267], [75.75875092, 11.28708267], [75.75875092, 11.28736115], [75.7590332, 11.28735924], [75.7590332, 11.28792191], [75.75875092, 11.28791809], [75.75875092, 11.28819561], [75.75818634, 11.28819084], [75.75818634, 11.2887516], [75.75791931, 11.2887516], [75.75791931, 11.28931046], [75.75763702, 11.28930569], [75.75763702, 11.28958416], [75.75736237, 11.2895813], [75.75736237, 11.29014015], [75.75708008, 11.29014015], [75.75708008, 11.29097176], [75.75681305, 11.29096889], [75.75681305, 11.29152966], [75.75653076, 11.29152966], [75.75653076, 11.29181004], [75.75624847, 11.29180622], [75.75624847, 11.29236221], [75.75597382, 11.29236221], [75.75597382, 11.29319382], [75.75569153, 11.29319096], [75.75569153, 11.29432201], [75.75541687, 11.2943058], [75.75541687, 11.29458427], [75.75514221, 11.29457855], [75.75514221, 11.29541969], [75.75485992, 11.29541588], [75.75485992, 11.29625034], [75.75458527, 11.29625034], [75.75458527, 11.29708195], [75.75430298, 11.29707146], [75.75430298, 11.29792118], [75.75402832, 11.29792118], [75.75402832, 11.29903126], [75.75375366, 11.2990284], [75.75375366, 11.29958439], [75.75347137, 11.29958439], [75.75347137, 11.30013847], [75.75319672, 11.30013847], [75.75319672, 11.30097198], [75.75291443, 11.30097198], [75.75291443, 11.30235958], [75.75263977, 11.30235958], [75.75263977, 11.3029213], [75.75235748, 11.3029213], [75.75235748, 11.30403137], [75.75208282, 11.30403137], [75.75208282, 11.30430889], [75.75235748, 11.30430698], [75.75235748, 11.3045826], [75.75208282, 11.3045826], [75.75208282, 11.30569458], [75.75180817, 11.30569458], [75.75180817, 11.30597305], [75.75152588, 11.30597115], [75.75152588, 11.30626011], [75.75096893, 11.30626011], [75.75096893, 11.30680943], [75.75068665, 11.30680943], [75.75068665, 11.30792141], [75.75041962, 11.30791664], [75.75041962, 11.30847263], [75.75068665, 11.30847073], [75.75069427, 11.30875111], [75.75041962, 11.30875111], [75.75041962, 11.31014061], [75.7501297, 11.31014061], [75.7501297, 11.31042194], [75.74986267, 11.31042194], [75.74986267, 11.31153202], [75.74958038, 11.31153202], [75.74958038, 11.31180954], [75.74930573, 11.31180477], [75.74930573, 11.31208324], [75.74903107, 11.31208134], [75.74903107, 11.31263924], [75.74874878, 11.31263924], [75.74874878, 11.31347084], [75.74846649, 11.31347084], [75.74846649, 11.31514168], [75.74819183, 11.31514168], [75.74819183, 11.31543064], [75.74791718, 11.31543064], [75.74791718, 11.31736183], [75.74764252, 11.31736183], [75.74764252, 11.31847191], [75.74736023, 11.31847191], [75.74736023, 11.31902981], [75.7470932, 11.31902981], [75.7470932, 11.31931019], [75.74680328, 11.31930637], [75.74680328, 11.31986237], [75.74624634, 11.31986046], [75.74624634, 11.32042027], [75.74597168, 11.32041645], [75.74597168, 11.32069397], [75.74375153, 11.32069397], [75.74375153, 11.32041645], [75.74319458, 11.32041645], [75.74318695, 11.3206892], [75.74180603, 11.32069588], [75.74180603, 11.32097244], [75.74124908, 11.32097244], [75.74124908, 11.32124996], [75.74041748, 11.32124138], [75.74041748, 11.32153034], [75.74014282, 11.32153034], [75.74014282, 11.32181072], [75.73986053, 11.32181072], [75.73986053, 11.32291985], [75.73958588, 11.32291603], [75.73958588, 11.32319355], [75.73930359, 11.32319355], [75.73930359, 11.32347202], [75.7381897, 11.32347202], [75.73819733, 11.32374954], [75.73792267, 11.32374954], [75.73792267, 11.32402992], [75.73735809, 11.32402802], [75.73735809, 11.3245821], [75.73707581, 11.32458019], [75.73707581, 11.3273716], [75.73680878, 11.32736015], [75.73680878, 11.32847214], [75.73652649, 11.32847023], [75.73652649, 11.32903099], [75.73625183, 11.32903099], [75.73625183, 11.32931137], [75.73596954, 11.3293066], [75.73596954, 11.33097267], [75.73568726, 11.3309679], [75.73568726, 11.33153057], [75.73542023, 11.33152866], [75.73542023, 11.33236122], [75.73513031, 11.33236122], [75.73513031, 11.33264065], [75.73486328, 11.33263874], [75.73486328, 11.33319473], [75.73458099, 11.33319473], [75.73458099, 11.33347321], [75.73430634, 11.3334713], [75.73430634, 11.33375072], [75.73401642, 11.33375072], [75.73400116, 11.33403111], [75.73374939, 11.3340292], [75.73374939, 11.3348608], [75.73401642, 11.3348608], [75.73401642, 11.33514118], [75.73430634, 11.33514118], [75.73430634, 11.33681202], [75.73458099, 11.33680534], [75.73458099, 11.33708286], [75.73486328, 11.33708286], [75.73486328, 11.33736134], [75.73513031, 11.33736134], [75.73513031, 11.33791924], [75.73542023, 11.33791924], [75.73542023, 11.33875084], [75.73568726, 11.33875084], [75.73568726, 11.33902931], [75.73542023, 11.33902931], [75.73542023, 11.33930969], [75.73568726, 11.33930969], [75.73568726, 11.33986092], [75.73596954, 11.33986092], [75.73596954, 11.34069538], [75.73625183, 11.34069538], [75.73625183, 11.34097099], [75.73596954, 11.34097099], [75.73596954, 11.34152985], [75.73625183, 11.34152985], [75.73625183, 11.34181023], [75.73596954, 11.34181023], [75.73596954, 11.34237099], [75.73568726, 11.34237099], [75.73568726, 11.34264183], [75.73542023, 11.34264183], [75.73542023, 11.34375191], [75.73513031, 11.34375191], [75.73513031, 11.34403038], [75.73542023, 11.34403038], [75.73542023, 11.34430981], [75.73569489, 11.34430599], [75.73569489, 11.34569359], [75.73596954, 11.34569359], [75.73596954, 11.34597206], [75.73625183, 11.3459692], [75.73625183, 11.34624958], [75.73652649, 11.34624958], [75.73652649, 11.34652996], [75.73680878, 11.34652805], [75.73680878, 11.34708405], [75.73707581, 11.34707928], [75.73707581, 11.34764004], [75.73735809, 11.34764004], [75.73735809, 11.34847164], [75.73707581, 11.34846973], [75.73707581, 11.34902954], [75.73680878, 11.34902763], [75.73687744, 11.34951305], [75.73652649, 11.34957981], [75.73652649, 11.35013962], [75.73625183, 11.35013771], [75.73625183, 11.3506937], [75.73596954, 11.3506937], [75.73596954, 11.35097218], [75.73625183, 11.35097027], [75.73625183, 11.35124969], [75.73596954, 11.35124969], [75.73596954, 11.35235977], [75.73569489, 11.35235977], [75.73569489, 11.35319424], [75.73542023, 11.35319042], [75.73542023, 11.35375023], [75.73513031, 11.35375023], [75.73513031, 11.35403061], [75.73486328, 11.35403061], [75.73486328, 11.35431099], [75.73458099, 11.35430431], [75.73458099, 11.35458469], [75.73430634, 11.35458469], [75.73430634, 11.35486031], [75.73347473, 11.35486031], [75.73347473, 11.35458469], [75.73374939, 11.35458469], [75.73374939, 11.35319424], [75.73347473, 11.35319424], [75.73347473, 11.35291576], [75.73319244, 11.35291576], [75.73319244, 11.35319424], [75.73291779, 11.35319424], [75.73291779, 11.35347176], [75.73236084, 11.35346985], [75.73236084, 11.35403061], [75.73208618, 11.35402775], [75.73208618, 11.35569382], [75.73180389, 11.35569382], [75.73180389, 11.35625076], [75.73152924, 11.35625076], [75.73152924, 11.35708237], [75.73124695, 11.35708046], [75.73124695, 11.35764122], [75.73097229, 11.35763931], [75.73097229, 11.3581953], [75.73069763, 11.3581953], [75.73069763, 11.35847282], [75.73042297, 11.35846996], [75.73042297, 11.35903072], [75.73014069, 11.35902882], [75.73014069, 11.3595829], [75.7298584, 11.35958004], [75.7298584, 11.36013889], [75.72958374, 11.36013889], [75.72958374, 11.36097336], [75.72931671, 11.36097145], [75.72931671, 11.36181164], [75.72902679, 11.36180496], [75.72902679, 11.36208344], [75.72875214, 11.36208057], [75.72875214, 11.36264133], [75.72846985, 11.36263943], [75.72846985, 11.36319542], [75.72819519, 11.36319542], [75.72819519, 11.36458302], [75.72763824, 11.36458111], [75.72763824, 11.36542034], [75.72735596, 11.36542034], [75.72735596, 11.36625099], [75.7270813, 11.36625099], [75.7270813, 11.36654091], [75.72680664, 11.3665266], [75.72680664, 11.3670826], [75.72651672, 11.36708069], [75.72651672, 11.36792183], [75.72624969, 11.36792183], [75.72624969, 11.36875153], [75.72598267, 11.36875153], [75.72598267, 11.36931038], [75.72569275, 11.36931038], [75.72569275, 11.3698616], [75.72541809, 11.3698616], [75.72541809, 11.37042046], [75.7251358, 11.37041759], [75.7251358, 11.37097073], [75.72486115, 11.37097073], [75.72486115, 11.37152958], [75.72458649, 11.37152767], [75.72458649, 11.37208366], [75.72429657, 11.3720789], [75.72429657, 11.37292004], [75.72374725, 11.37292004], [75.72374725, 11.37403011], [75.7234726, 11.37403011], [75.7234726, 11.37430954], [75.72319031, 11.37430954], [75.72319031, 11.37514019], [75.72291565, 11.37514019], [75.72292328, 11.37625027], [75.72264099, 11.37625027], [75.72264099, 11.37681103], [75.7223587, 11.37680626], [75.7223587, 11.37736225], [75.72207642, 11.37736034], [75.72207642, 11.37763977], [75.72180939, 11.37763977], [75.72180176, 11.37874985], [75.7215271, 11.37874985], [75.7215271, 11.37985992], [75.72125244, 11.37985992], [75.72125244, 11.38042068], [75.72097015, 11.38041592], [75.72097015, 11.38069439], [75.72070313, 11.38068962], [75.72070313, 11.38181114], [75.72041321, 11.38180733], [75.72041321, 11.38236046], [75.71986389, 11.38236046], [75.71985626, 11.38319016], [75.7195816, 11.38320065], [75.7195816, 11.38375092], [75.71930695, 11.38375092], [75.71930695, 11.3840313], [75.71901703, 11.3840313], [75.71901703, 11.38431072], [75.71875, 11.38431072], [75.71875, 11.38486099], [75.71819305, 11.38486099], [75.71819305, 11.38541889], [75.7179184, 11.38541698], [75.7179184, 11.38569546], [75.71763611, 11.38568974], [75.71763611, 11.38764095], [75.71736145, 11.38763905], [75.71736145, 11.38819504], [75.71708679, 11.38819027], [75.71708679, 11.38875103], [75.71679688, 11.38875103], [75.71679688, 11.38931179], [75.71652985, 11.38930511], [75.71652985, 11.38986111], [75.71624756, 11.38986111], [75.71624756, 11.39042187], [75.7159729, 11.3904171], [75.7159729, 11.39097309], [75.71569824, 11.39097118], [75.71569824, 11.39153194], [75.71541595, 11.39153194], [75.71541595, 11.39236069], [75.7151413, 11.39236069], [75.7151413, 11.39291954], [75.71430206, 11.39291668], [75.71430206, 11.39319324], [75.7140274, 11.39319324], [75.7140274, 11.39347267], [75.71291351, 11.39347267], [75.71291351, 11.39486122], [75.71263885, 11.39486122], [75.71263885, 11.39542198], [75.7123642, 11.39541531], [75.7123642, 11.3959713], [75.71208191, 11.3959713], [75.71208191, 11.39652729], [75.71180725, 11.39652729], [75.71180725, 11.39708424], [75.71151733, 11.39708138], [75.71151733, 11.39764023], [75.71125031, 11.39764023], [75.71125031, 11.39847183], [75.71097565, 11.39847183], [75.71098328, 11.39875031], [75.71069336, 11.39875031], [75.71069336, 11.40013981], [75.7104187, 11.40013981], [75.7104187, 11.40042019], [75.71013641, 11.40041637], [75.71013641, 11.4006958], [75.7104187, 11.4006958], [75.7104187, 11.40097237], [75.71013641, 11.40096855], [75.71013641, 11.40125179], [75.7095871, 11.40125179], [75.7095871, 11.40153027], [75.70929718, 11.40153027], [75.70929718, 11.40236187], [75.70903015, 11.40236187], [75.70903015, 11.40292263], [75.70874786, 11.40291595], [75.70874786, 11.40347195], [75.70847321, 11.40347195], [75.70847321, 11.40375042], [75.70819092, 11.40375042], [75.70819092, 11.40431118], [75.70791626, 11.40430641], [75.70791626, 11.4048624], [75.7076416, 11.40485954], [75.7076416, 11.40513992], [75.70735931, 11.40513802], [75.70735931, 11.40597153], [75.70707703, 11.40596962], [75.70707703, 11.40625], [75.70680237, 11.40625], [75.70680237, 11.40681076], [75.70625305, 11.40681076], [75.70625305, 11.40736008], [75.70597076, 11.40736008], [75.70597076, 11.40764141], [75.70541382, 11.4076376], [75.70541382, 11.40819359], [75.70514679, 11.40818977], [75.70514679, 11.40874958], [75.70485687, 11.40874958], [75.70485687, 11.40903091], [75.70458221, 11.40903091], [75.70458221, 11.40931129], [75.7048645, 11.40930653], [75.7048645, 11.40958214], [75.70458221, 11.40958023], [75.70458221, 11.40985966], [75.70485687, 11.40985966], [75.70485687, 11.41014099], [75.70458221, 11.41014099], [75.70458221, 11.41042137], [75.7048645, 11.41041565], [75.7048645, 11.41069508], [75.70458221, 11.41069508], [75.70458221, 11.41152859], [75.70430756, 11.41152859], [75.70430756, 11.41208267], [75.70402527, 11.41208267], [75.70402527, 11.41319466], [75.70375061, 11.41319466], [75.70375061, 11.41347313], [75.70347595, 11.41347122], [75.70347595, 11.41431236], [75.70318604, 11.41431236], [75.70318604, 11.41514111], [75.70291901, 11.4151392], [75.70291901, 11.41569519], [75.70263672, 11.41569519], [75.70263672, 11.4159708], [75.70236206, 11.4159708], [75.70236206, 11.41681194], [75.70207977, 11.41680527], [75.70207977, 11.41736126], [75.70181274, 11.41736126], [75.70181274, 11.41792202], [75.70153046, 11.41791725], [75.70153046, 11.41819477], [75.70124817, 11.41819096], [75.70124817, 11.41930962], [75.70041656, 11.41930962], [75.70041656, 11.41986084], [75.70014191, 11.41986084], [75.70014191, 11.42041969], [75.69985962, 11.42041969], [75.69985962, 11.42124939], [75.69957733, 11.42124939], [75.69957733, 11.42153168], [75.69930267, 11.42153168], [75.69930267, 11.42181015], [75.69902802, 11.42180538], [75.69902802, 11.42236137], [75.69875336, 11.42236137], [75.69875336, 11.42292023], [75.69847107, 11.42291546], [75.69847107, 11.42319584], [75.69819641, 11.42319107], [75.69819641, 11.42430973], [75.69791412, 11.42430592], [75.69791412, 11.42458439], [75.69763947, 11.42458057], [75.69763947, 11.42514038], [75.69708252, 11.42513657], [75.69708252, 11.42569447], [75.69680786, 11.42569065], [75.69680786, 11.42625046], [75.6965332, 11.42625046], [75.6965332, 11.42653179], [75.69625092, 11.42652798], [75.69625092, 11.42708397], [75.69596863, 11.42708397], [75.69596863, 11.42736244], [75.69568634, 11.42735958], [75.69568634, 11.42763996], [75.69541931, 11.42763996], [75.69541931, 11.42792034], [75.69513702, 11.42791557], [75.69513702, 11.42847157], [75.69486237, 11.42846966], [75.69486237, 11.42903042], [75.69458008, 11.42903042], [75.69458008, 11.42959118], [75.69403076, 11.42959118], [75.69403076, 11.42986202], [75.69374847, 11.42986202], [75.69374847, 11.43013954], [75.69346619, 11.43013954], [75.69346619, 11.43041992], [75.69319153, 11.43041992], [75.69319153, 11.43153], [75.69291687, 11.43152809], [75.69291687, 11.43208408], [75.69264221, 11.43208408], [75.69264221, 11.43263817], [75.69235992, 11.43263054], [75.69235992, 11.43292141], [75.69208527, 11.43291569], [75.69208527, 11.43347168], [75.69180298, 11.43346977], [75.69180298, 11.43375015], [75.69152832, 11.43375015], [75.69152832, 11.43431091], [75.69125366, 11.43430424], [75.69125366, 11.43458366], [75.69097137, 11.43457985], [75.69097137, 11.43514061], [75.69069672, 11.43514061], [75.69069672, 11.43542099], [75.69041443, 11.43541622], [75.69041443, 11.43597221], [75.6901474, 11.43597031], [75.6901474, 11.43624973], [75.68985748, 11.43624973], [75.68985748, 11.43708229], [75.68958282, 11.43708038], [75.68958282, 11.43764114], [75.68930817, 11.43764114], [75.68930817, 11.43792057], [75.68902588, 11.43792057], [75.68902588, 11.4387598], [75.68875122, 11.4387598], [75.68875122, 11.43903065], [75.68846893, 11.43902874], [75.68846893, 11.43958473], [75.68791962, 11.43957996], [75.68791962, 11.44014072], [75.68736267, 11.44014072], [75.68736267, 11.4404192], [75.68708038, 11.44041729], [75.68708038, 11.44097328], [75.68681335, 11.44097137], [75.68681335, 11.44153118], [75.68653107, 11.44153118], [75.68653107, 11.44236088], [75.68624878, 11.44236088], [75.68624878, 11.44292164], [75.68597412, 11.44291687], [75.68597412, 11.44347095], [75.68569183, 11.44347095], [75.68569183, 11.44375134], [75.68541718, 11.44375134], [75.68541718, 11.44403076], [75.68514252, 11.44403076], [75.68514252, 11.44431019], [75.68486023, 11.44430542], [75.68486023, 11.44458294], [75.68458557, 11.44458294], [75.68458557, 11.44486141], [75.68430328, 11.44486141], [75.68430328, 11.44514084], [75.684021, 11.44514084], [75.684021, 11.44541931], [75.68374634, 11.4454174], [75.68374634, 11.4459734], [75.68347168, 11.44597054], [75.68347168, 11.44680977], [75.68319702, 11.44680977], [75.68319702, 11.44736099], [75.68291473, 11.44736099], [75.68291473, 11.44763947], [75.68264008, 11.44763947], [75.68264008, 11.44819546], [75.68235779, 11.44819546], [75.68235779, 11.44847107], [75.68208313, 11.44847107], [75.68208313, 11.4487524], [75.68180847, 11.4487524], [75.68180847, 11.4493103], [75.68152618, 11.44930458], [75.68152618, 11.44958305], [75.68125153, 11.44958305], [75.68125153, 11.44986057], [75.68013763, 11.44986057], [75.68013763, 11.45014191], [75.67903137, 11.45014191], [75.67903137, 11.44986057], [75.67847443, 11.44986057], [75.67847443, 11.44958305], [75.67819214, 11.44958305], [75.67819214, 11.44930458], [75.67736053, 11.44930458], [75.67736053, 11.44958305], [75.67680359, 11.44958305], [75.67680359, 11.44986057], [75.67624664, 11.44986057], [75.67624664, 11.45014191], [75.67542267, 11.45014191], [75.67542267, 11.45069981], [75.67514038, 11.45069313], [75.67514038, 11.45097065], [75.67485046, 11.45097065], [75.67485046, 11.45153046], [75.67457581, 11.45153046], [75.67457581, 11.45181179], [75.67430878, 11.45180607], [75.67430878, 11.45208359], [75.67402649, 11.45208073], [75.67402649, 11.45263958], [75.67346954, 11.45263958], [75.67346954, 11.45291996], [75.67319489, 11.45291805], [75.67319489, 11.45319366], [75.67292023, 11.45319366], [75.67292023, 11.45347214], [75.67263794, 11.45346928], [75.67263794, 11.4537611], [75.67236328, 11.4537611], [75.67236328, 11.45431042], [75.67180634, 11.45430565], [75.67180634, 11.45458412], [75.67124939, 11.45457935], [75.67124939, 11.45514011], [75.6709671, 11.45514011], [75.6709671, 11.45541954], [75.67041779, 11.45541573], [75.67041779, 11.4556942], [75.6701355, 11.4556942], [75.67014313, 11.45625019], [75.66986084, 11.45625019], [75.66986084, 11.45652962], [75.66958618, 11.45652771], [75.66958618, 11.4570837], [75.66930389, 11.4570837], [75.66930389, 11.45736217], [75.66903687, 11.45736027], [75.66903687, 11.45763969], [75.66874695, 11.45763969], [75.66874695, 11.45792103], [75.66847229, 11.45791626], [75.66847229, 11.45819378], [75.66819763, 11.45819378], [75.66819763, 11.45847225], [75.66792297, 11.45847034], [75.66792297, 11.45874977], [75.6673584, 11.45874977], [75.6673584, 11.45903015], [75.66680908, 11.45903015], [75.66680908, 11.45931053], [75.66652679, 11.45930576], [75.66652679, 11.45985985], [75.66597748, 11.45985985], [75.66597748, 11.46014023], [75.66569519, 11.46014023], [75.66569519, 11.46069431], [75.66513824, 11.46068954], [75.66513824, 11.46125031], [75.6645813, 11.46125031], [75.6645813, 11.46153069], [75.66179657, 11.46153069], [75.66179657, 11.46181107], [75.66124725, 11.4618063], [75.66124725, 11.46208191], [75.66041565, 11.46208477], [75.66041565, 11.46236038], [75.66014099, 11.46236038], [75.66014099, 11.4626379], [75.65957642, 11.4626379], [75.65957642, 11.46292114], [75.6590271, 11.46291637], [75.6590271, 11.46319389], [75.65875244, 11.46319389], [75.65875244, 11.46347237], [75.65820313, 11.46347046], [75.65820313, 11.46403122], [75.65763855, 11.46403122], [75.65763855, 11.46431065], [75.65736389, 11.46430683], [75.65736389, 11.46458244], [75.6570816, 11.46457958], [75.6570816, 11.46485996], [75.65651703, 11.46485996], [75.65651703, 11.4651413], [75.65569305, 11.4651413], [75.65569305, 11.46542072], [75.6554184, 11.46542072], [75.6554184, 11.4656992], [75.65513611, 11.46569538], [75.65513611, 11.4659729], [75.65402985, 11.4659729], [75.65403748, 11.46625137], [75.65207672, 11.46625137], [75.65207672, 11.46652889], [75.65125275, 11.46652889], [75.65125275, 11.46680927], [75.65013885, 11.46680546], [75.65013885, 11.46708298], [75.64930725, 11.46708298], [75.64930725, 11.46736145], [75.64819336, 11.46736145], [75.64819336, 11.46764088], [75.6470871, 11.46764088], [75.6470871, 11.46792126], [75.64569092, 11.46792126], [75.64569092, 11.46764088], [75.6451416, 11.46764088], [75.6451416, 11.46708012], [75.64485931, 11.46708298], [75.64485931, 11.46680546], [75.64402771, 11.46680927], [75.64402771, 11.46652889], [75.64347076, 11.46652889], [75.64347076, 11.46625137], [75.64263916, 11.46625137], [75.64263916, 11.46597004], [75.64208221, 11.4659729], [75.64208221, 11.46569538], [75.64125061, 11.4656992], [75.64125061, 11.46542072], [75.63903046, 11.46542072], [75.63903046, 11.4651413], [75.63819122, 11.4651413], [75.63819122, 11.46485996], [75.63707733, 11.46485996], [75.63707733, 11.46457958], [75.63735962, 11.46458244], [75.63735962, 11.46402645], [75.63764191, 11.46403122], [75.63764191, 11.46347046], [75.63791656, 11.46347237], [75.63791656, 11.46208477], [75.63764191, 11.46208191], [75.63764191, 11.4618063], [75.63735962, 11.46181107], [75.63735962, 11.46153069], [75.63707733, 11.46153069], [75.63707733, 11.46125031], [75.63625336, 11.46125031], [75.63625336, 11.46153069], [75.63430786, 11.46153069], [75.63430786, 11.46181107], [75.63375092, 11.4618063], [75.63375092, 11.46208191], [75.63346863, 11.46208477], [75.63346863, 11.46236038], [75.63318634, 11.46236038], [75.63318634, 11.4626379], [75.63263702, 11.4626379], [75.63263702, 11.46319389], [75.63236237, 11.46319199], [75.63236237, 11.46485996], [75.63208008, 11.46485996], [75.63208008, 11.4651413], [75.63236237, 11.4651413], [75.63236237, 11.46542072], [75.63208008, 11.46542072], [75.63208008, 11.4656992], [75.63180542, 11.46569538], [75.63181305, 11.46625137], [75.63153076, 11.46625137], [75.63153076, 11.46680927], [75.63124847, 11.46680546], [75.63124847, 11.46708298], [75.63096619, 11.46708012], [75.63096619, 11.46764088], [75.63069153, 11.46763897], [75.63069153, 11.46819496], [75.63041687, 11.46819496], [75.63041687, 11.46875095], [75.63014221, 11.46874046], [75.63014221, 11.46903133], [75.62985992, 11.46902657], [75.62985992, 11.46958256], [75.6295929, 11.46958065], [75.6295929, 11.47014141], [75.62930298, 11.47014141], [75.62930298, 11.47042179], [75.62902832, 11.47041702], [75.62902832, 11.47069454], [75.62875366, 11.47069454], [75.62875366, 11.47097301], [75.62847137, 11.47097111], [75.62847137, 11.47125053], [75.62819672, 11.47125053], [75.62819672, 11.47153187], [75.62763977, 11.4715271], [75.62763977, 11.47208309], [75.62735748, 11.47208309], [75.62735748, 11.47236061], [75.62680054, 11.47236061], [75.62680054, 11.47292042], [75.62652588, 11.4729166], [75.62652588, 11.47319317], [75.62596893, 11.47319317], [75.62596893, 11.4734726], [75.62541962, 11.47347069], [75.62541962, 11.47375107], [75.62486267, 11.47375107], [75.62486267, 11.47402859], [75.62458038, 11.47402859], [75.62458038, 11.47430992], [75.62431335, 11.47430992], [75.62431335, 11.47402859], [75.62374115, 11.47402859], [75.62374115, 11.47430992], [75.62208557, 11.47430515], [75.62208557, 11.47458267], [75.62014008, 11.47458076], [75.62014008, 11.47486973], [75.6204071, 11.47486973], [75.6204071, 11.47514153], [75.62014008, 11.47514153], [75.62014008, 11.47542191], [75.61985779, 11.47541714], [75.61985779, 11.47569466], [75.61958313, 11.47569466], [75.61958313, 11.47597122], [75.61930847, 11.47597122], [75.61930847, 11.4762516], [75.61846924, 11.4762516], [75.61846924, 11.47653198], [75.61792755, 11.47653198], [75.61792755, 11.47681046], [75.61763763, 11.47680473], [75.61763763, 11.47708321], [75.61736298, 11.47708321], [75.61736298, 11.47819328], [75.61763763, 11.47819138], [75.61763763, 11.47902966], [75.61792755, 11.47902966], [75.61792755, 11.47931004], [75.61819458, 11.47930622], [75.61819458, 11.47958374], [75.61846924, 11.47958374], [75.61846924, 11.47986221], [75.61875153, 11.47986221], [75.61875153, 11.48069382], [75.61902618, 11.48069382], [75.61902618, 11.48375034], [75.61875153, 11.48374081], [75.61875153, 11.4843111], [75.61846924, 11.4843111], [75.61846924, 11.48681068], [75.61818695, 11.48681068], [75.61818695, 11.48764038], [75.61791992, 11.48763847], [75.61792755, 11.48875046], [75.61763763, 11.48875046], [75.61763763, 11.48931122], [75.61736298, 11.48931122], [75.61736298, 11.48987198], [75.61708069, 11.48987198], [75.61708069, 11.4904213], [75.61680603, 11.49041557], [75.61680603, 11.49097347], [75.61653137, 11.49096966], [75.61653137, 11.49180889], [75.61624908, 11.49180698], [75.61624908, 11.49208164], [75.6159668, 11.49207973], [75.6159668, 11.49264145], [75.61569214, 11.49263859], [75.61569214, 11.49347305], [75.61541748, 11.49347019], [75.61541748, 11.49431133], [75.61569214, 11.49430466], [75.61569214, 11.49569511], [75.61541748, 11.49569511], [75.61541748, 11.49597263], [75.61513519, 11.49597263], [75.61514282, 11.49625111], [75.61486053, 11.49625111], [75.61486053, 11.49653053], [75.61458588, 11.49652672], [75.61458588, 11.49708271], [75.61402893, 11.4970808], [75.61402893, 11.49792194], [75.61374664, 11.49791718], [75.61374664, 11.49819469], [75.61347198, 11.49819088], [75.61347198, 11.50013924], [75.61319733, 11.50013924], [75.61319733, 11.50041962], [75.61292267, 11.50041962], [75.61292267, 11.5015316], [75.61264038, 11.50152683], [75.61264038, 11.50208282], [75.61235809, 11.50208092], [75.61235809, 11.50403023], [75.61207581, 11.50403023], [75.61207581, 11.50430965], [75.61180115, 11.50430965], [75.61180115, 11.50487137], [75.61152649, 11.50486183], [75.61152649, 11.50597191], [75.61125183, 11.50597191], [75.61125183, 11.50681019], [75.61096954, 11.50680637], [75.61096954, 11.50736237], [75.61068726, 11.50736046], [75.61068726, 11.50764179], [75.61042023, 11.50764179], [75.61042023, 11.50874996], [75.61013794, 11.50874996], [75.61013794, 11.50903034], [75.60986328, 11.50903034], [75.60986328, 11.50986195], [75.60958099, 11.50986195], [75.60958099, 11.51041985], [75.60930634, 11.51041603], [75.60930634, 11.51069355], [75.60958099, 11.51069355], [75.60958099, 11.51097202], [75.60930634, 11.51097202], [75.60930634, 11.51152992], [75.60902405, 11.51152802], [75.60902405, 11.51208401], [75.60874939, 11.51208401], [75.60874939, 11.51236153], [75.6084671, 11.51235962], [75.6084671, 11.51264], [75.60819244, 11.51263809], [75.60819244, 11.51319408], [75.60847473, 11.51319408], [75.60847473, 11.5134716], [75.60819244, 11.5134716], [75.60819244, 11.51486015], [75.60791779, 11.51486015], [75.60791779, 11.51513958], [75.6076355, 11.51513767], [75.6076355, 11.51569366], [75.60736084, 11.51569366], [75.60736084, 11.51597214], [75.60708618, 11.51597023], [75.60708618, 11.51735973], [75.60680389, 11.51735973], [75.60680389, 11.51847267], [75.60652924, 11.5184679], [75.60652924, 11.51903057], [75.60624695, 11.51902866], [75.60624695, 11.51958466], [75.60597229, 11.51958275], [75.60597229, 11.52014065], [75.60569763, 11.52014065], [75.60569763, 11.52042103], [75.60541534, 11.52041721], [75.60541534, 11.52069473], [75.60514069, 11.52068996], [75.60514069, 11.52181244], [75.6048584, 11.52180481], [75.6048584, 11.5223608], [75.60514069, 11.5223608], [75.60514069, 11.52264118], [75.6048584, 11.52263927], [75.6048584, 11.52347088], [75.60457611, 11.52347088], [75.60457611, 11.52403069], [75.60430908, 11.52403069], [75.60430908, 11.52431202], [75.60402679, 11.52431202], [75.60402679, 11.52541924], [75.60375214, 11.52541733], [75.60375214, 11.52569485], [75.60402679, 11.52569103], [75.60402679, 11.52598], [75.60375214, 11.52598], [75.60375214, 11.52625084], [75.60346985, 11.52625084], [75.60346985, 11.52680969], [75.60319519, 11.52680492], [75.60320282, 11.52736092], [75.6029129, 11.52736092], [75.6029129, 11.52763939], [75.60263824, 11.52763939], [75.60263824, 11.52819538], [75.6029129, 11.52819538], [75.6029129, 11.52847099], [75.60263824, 11.52847099], [75.60263824, 11.52875137], [75.60235596, 11.52875137], [75.60235596, 11.52931023], [75.6020813, 11.52931023], [75.6020813, 11.5304203], [75.60180664, 11.5304184], [75.60180664, 11.53069305], [75.60151672, 11.53069115], [75.60151672, 11.53125191], [75.60124969, 11.53125191], [75.60124969, 11.53236198], [75.60097504, 11.53236198], [75.60097504, 11.53319359], [75.60069275, 11.53319073], [75.60069275, 11.53374958], [75.60041809, 11.53374958], [75.60041809, 11.53431034], [75.6001358, 11.53431034], [75.6001358, 11.53542042], [75.59986115, 11.53542042], [75.59986115, 11.53625202], [75.59958649, 11.53625202], [75.59958649, 11.53681087], [75.5993042, 11.53680611], [75.5993042, 11.5373621], [75.59902954, 11.5373621], [75.59902954, 11.5381937], [75.59874725, 11.5381918], [75.59874725, 11.53874969], [75.5984726, 11.53874969], [75.5984726, 11.53985977], [75.59819794, 11.53985977], [75.59819794, 11.54014015], [75.59792328, 11.54014015], [75.59792328, 11.54042053], [75.59764099, 11.54042053], [75.59764099, 11.54181099], [75.5973587, 11.54181099], [75.5973587, 11.54292107], [75.59708405, 11.5429163], [75.59708405, 11.54347229], [75.59680176, 11.54347038], [75.59680176, 11.54431057], [75.5965271, 11.54431057], [75.5965271, 11.54514122], [75.59625244, 11.54514122], [75.59625244, 11.5462513], [75.59597015, 11.5462513], [75.59597015, 11.54653072], [75.59570313, 11.54653072], [75.59570313, 11.5476408], [75.59541321, 11.54763889], [75.59541321, 11.54847336], [75.59486389, 11.54847336], [75.59486389, 11.55069542], [75.5945816, 11.5506897], [75.5945816, 11.55125141], [75.59430695, 11.55125141], [75.59430695, 11.55153084], [75.59402466, 11.55152702], [75.59402466, 11.55236053], [75.59375, 11.55236053], [75.59375, 11.55268002], [75.59375, 11.55319309], [75.59319305, 11.55319118], [75.59319305, 11.55375099], [75.5929184, 11.55374908], [75.5929184, 11.55569458], [75.59263611, 11.55569077], [75.59263611, 11.55625153], [75.59236145, 11.55625153], [75.59236145, 11.55681038], [75.59208679, 11.55681038], [75.59208679, 11.55792046], [75.5918045, 11.55791759], [75.5918045, 11.55819321], [75.59124756, 11.55819321], [75.59124756, 11.55902767], [75.5909729, 11.55902767], [75.5909729, 11.55986214], [75.59069824, 11.55986214], [75.59069824, 11.56097221], [75.59041595, 11.56096935], [75.59041595, 11.56347179], [75.58985901, 11.56347179], [75.58985901, 11.5654211], [75.5901413, 11.56541634], [75.5901413, 11.56597233], [75.59041595, 11.56597042], [75.59041595, 11.56735992], [75.5901413, 11.56735992], [75.5901413, 11.56875038], [75.59069824, 11.56875038], [75.59069824, 11.56819439], [75.5909729, 11.56819439], [75.5909729, 11.56735992], [75.59124756, 11.56735992], [75.59124756, 11.56624985], [75.59152985, 11.56624985], [75.59152985, 11.56569195], [75.59124756, 11.56569386], [75.59124756, 11.56541634], [75.5909729, 11.5654211], [75.5909729, 11.56514931], [75.59069824, 11.56514931], [75.59069824, 11.56458187], [75.59124756, 11.56458378], [75.59124756, 11.56430626], [75.59179688, 11.56431103], [75.59179688, 11.56375027], [75.59236145, 11.56375027], [75.59236145, 11.56153011], [75.59263611, 11.56153011], [75.59263611, 11.56124973], [75.5929184, 11.56124973], [75.5929184, 11.56096935], [75.59319305, 11.56097221], [75.59319305, 11.56069374], [75.59347534, 11.56069374], [75.59347534, 11.56013966], [75.59375763, 11.56013966], [75.59375763, 11.55930996], [75.59401703, 11.55930996], [75.59401703, 11.5587492], [75.59430695, 11.5587492], [75.59430695, 11.55847073], [75.5945816, 11.55847359], [75.5945816, 11.55764008], [75.59485626, 11.55764198], [75.59485626, 11.55653191], [75.59513855, 11.55653191], [75.59513855, 11.55625153], [75.59541321, 11.55625153], [75.59541321, 11.55569077], [75.59513855, 11.55569458], [75.59513855, 11.55486107], [75.59541321, 11.55486107], [75.59541321, 11.55431175], [75.59570313, 11.55431175], [75.59570313, 11.55264091], [75.59597015, 11.55264091], [75.59597015, 11.55125141], [75.5956955, 11.55125141], [75.5956955, 11.55069542], [75.59597015, 11.55069542], [75.59597015, 11.55041695], [75.59680176, 11.55042171], [75.59680176, 11.55014992], [75.59764099, 11.55014992], [75.59764099, 11.54903126], [75.5973587, 11.54903126], [75.5973587, 11.54875088], [75.59764099, 11.54875088], [75.59764099, 11.54847145], [75.59791565, 11.54847336], [75.59791565, 11.54791737], [75.59819794, 11.54792118], [75.59819794, 11.54736137], [75.5984726, 11.54736137], [75.5984726, 11.54680538], [75.59874725, 11.5468092], [75.59874725, 11.54596996], [75.5984726, 11.54597282], [75.5984726, 11.54541683], [75.59874725, 11.54542065], [75.59874725, 11.54514122], [75.59902954, 11.54514122], [75.59902954, 11.54431057], [75.59986115, 11.54430676], [75.59986115, 11.54458237], [75.6001358, 11.54458237], [75.6001358, 11.5470829], [75.59986115, 11.54708004], [75.59986115, 11.5476408], [75.59958649, 11.54763889], [75.59958649, 11.54819489], [75.5984726, 11.54819489], [75.5984726, 11.54847336], [75.59819794, 11.54847336], [75.59819794, 11.54958344], [75.5984726, 11.54958057], [75.5984726, 11.55014992], [75.59874725, 11.55013943], [75.59874725, 11.55069542], [75.5984726, 11.5506897], [75.5984726, 11.55181026], [75.59819794, 11.55180454], [75.59819794, 11.55225182], [75.59819794, 11.55264091], [75.59792328, 11.55264091], [75.59792328, 11.55375099], [75.59764099, 11.55375099], [75.59764099, 11.55431175], [75.5973587, 11.55430508], [75.5973587, 11.5545826], [75.59764099, 11.55458069], [75.59764099, 11.55486107], [75.5973587, 11.55486107], [75.5973587, 11.55597115], [75.59708405, 11.55597115], [75.59708405, 11.55708313], [75.59680939, 11.55708313], [75.59680176, 11.55958366], [75.5965271, 11.55958366], [75.5965271, 11.55991173], [75.5965271, 11.56042004], [75.59625244, 11.56041622], [75.59625244, 11.56097221], [75.59597015, 11.56096935], [75.59597015, 11.56124973], [75.59625244, 11.56124973], [75.59625244, 11.56153011], [75.59597015, 11.56153011], [75.59597015, 11.56209087], [75.5956955, 11.5620842], [75.5956955, 11.56235981], [75.59513855, 11.56235981], [75.59513855, 11.56264019], [75.59485626, 11.56264019], [75.59485626, 11.56291962], [75.59430695, 11.5629158], [75.59430695, 11.56319427], [75.59375, 11.56319427], [75.59375, 11.56375027], [75.59348297, 11.56375027], [75.59348297, 11.56431103], [75.59319305, 11.56430626], [75.59319305, 11.56458378], [75.59347534, 11.56458378], [75.59347534, 11.56486225], [75.59319305, 11.56486034], [75.59319305, 11.5654211], [75.5929184, 11.5654211], [75.5929184, 11.56653023], [75.59263611, 11.56652832], [75.59263611, 11.56708431], [75.59236145, 11.56708431], [75.59236145, 11.56847191], [75.5929184, 11.56847], [75.5929184, 11.56875038], [75.59375763, 11.56875038], [75.59375763, 11.56903076], [75.59430695, 11.5690279], [75.59430695, 11.56958199], [75.5945816, 11.56958199], [75.5945816, 11.57097244], [75.59430695, 11.570961], [75.59430695, 11.5715313], [75.59401703, 11.5715313], [75.59401703, 11.57181072], [75.59347534, 11.57180691], [75.59347534, 11.57208157], [75.5929184, 11.57207966], [75.5929184, 11.57236004], [75.59236145, 11.57236004], [75.59236145, 11.57264137], [75.59179688, 11.57264137], [75.59179688, 11.57291889], [75.5909729, 11.57291698], [75.5909729, 11.57319546], [75.59069824, 11.57319546], [75.59069824, 11.57347298], [75.5901413, 11.57347012], [75.5901413, 11.57375145], [75.58985901, 11.57375145], [75.58985901, 11.57458305], [75.58957672, 11.57458019], [75.58957672, 11.57514095], [75.58985901, 11.57513905], [75.58985901, 11.57567024], [75.58985901, 11.57597256], [75.5901413, 11.57597256], [75.5901413, 11.57736111], [75.58985901, 11.57736111], [75.58985901, 11.57847309], [75.58958435, 11.57847309], [75.58958435, 11.58013916], [75.58930206, 11.58013916], [75.58930206, 11.58069515], [75.5890274, 11.58069515], [75.5890274, 11.58208275], [75.58847046, 11.58208084], [75.58847046, 11.58292198], [75.5881958, 11.58291531], [75.5881958, 11.58319473], [75.58791351, 11.58319473], [75.58791351, 11.5834713], [75.58763123, 11.5834713], [75.58763123, 11.58403015], [75.58708191, 11.58402729], [75.58708191, 11.58458328], [75.58680725, 11.58458138], [75.58680725, 11.58514023], [75.58652496, 11.58514023], [75.58652496, 11.58569336], [75.58625031, 11.58569145], [75.58625031, 11.58625031], [75.58569336, 11.58625031], [75.58569336, 11.58569145], [75.58597565, 11.58569336], [75.58597565, 11.58458328], [75.58625031, 11.58458328], [75.58625031, 11.58374882], [75.58598328, 11.58375168], [75.58598328, 11.58292198], [75.58651733, 11.58292198], [75.58651733, 11.58236122], [75.58680725, 11.58236122], [75.58680725, 11.58208275], [75.58708191, 11.58208275], [75.58708191, 11.58124924], [75.58735657, 11.58124924], [75.58735657, 11.57958126], [75.58763885, 11.57958317], [75.58763885, 11.5793047], [75.58735657, 11.57931042], [75.58735657, 11.57875061], [75.58763123, 11.57875061], [75.58763123, 11.57681179], [75.58790588, 11.57681179], [75.58790588, 11.57653141], [75.5881958, 11.57653141], [75.5881958, 11.57597065], [75.58847046, 11.57597256], [75.58847046, 11.57541656], [75.58875275, 11.57542133], [75.58875275, 11.57403088], [75.58885956, 11.57402897], [75.5890274, 11.57403088], [75.5890274, 11.57291889], [75.58930206, 11.57291889], [75.58930206, 11.57069016], [75.58958435, 11.57069397], [75.58958435, 11.57013798], [75.58985901, 11.57014275], [75.58985901, 11.56986046], [75.58958435, 11.56986332], [75.58958435, 11.56930637], [75.58930206, 11.56931114], [75.58930206, 11.56903076], [75.5890274, 11.56903076], [75.5890274, 11.56875038], [75.58847046, 11.56875038], [75.58847046, 11.56903076], [75.5881958, 11.5690279], [75.5881958, 11.56986332], [75.58790588, 11.56986046], [75.58790588, 11.57042122], [75.58763885, 11.57041645], [75.58763885, 11.57097244], [75.58750153, 11.57096577], [75.58735657, 11.570961], [75.58735657, 11.57181072], [75.58708191, 11.57181072], [75.58708191, 11.57236004], [75.58680725, 11.57236004], [75.58680725, 11.57291889], [75.58652496, 11.57291698], [75.58652496, 11.57319546], [75.58680725, 11.57319546], [75.58680725, 11.57347298], [75.58651733, 11.57347012], [75.58651733, 11.57375145], [75.58625031, 11.57375145], [75.58625031, 11.57458305], [75.58598328, 11.57458019], [75.58598328, 11.57542133], [75.58569336, 11.57542133], [75.58569336, 11.57625103], [75.5854187, 11.57625103], [75.5854187, 11.57681179], [75.58513641, 11.57681179], [75.58513641, 11.57792187], [75.58486176, 11.5779171], [75.58486176, 11.57847309], [75.5845871, 11.57847118], [75.5845871, 11.57903194], [75.58429718, 11.57903194], [75.58429718, 11.57986069], [75.58403015, 11.57986069], [75.58403015, 11.58097267], [75.58374786, 11.58097076], [75.58374786, 11.58124924], [75.58347321, 11.58124924], [75.58347321, 11.5818119], [75.58319092, 11.58180523], [75.58319092, 11.58236122], [75.58347321, 11.58236122], [75.58347321, 11.58292198], [75.58319092, 11.58292198], [75.58319092, 11.58403015], [75.58291626, 11.58403015], [75.58291626, 11.58430958], [75.5826416, 11.58430958], [75.5826416, 11.58541965], [75.58235931, 11.58541775], [75.58235931, 11.58597088], [75.58207703, 11.58597088], [75.58207703, 11.58681011], [75.58180237, 11.5868063], [75.58180237, 11.58736229], [75.58152771, 11.58735943], [75.58152771, 11.58763981], [75.58125305, 11.58763981], [75.58125305, 11.58847237], [75.58097076, 11.58846855], [75.58097076, 11.58875179], [75.58069611, 11.58875179], [75.58069611, 11.59042263], [75.58041382, 11.59041595], [75.58041382, 11.59097195], [75.58013916, 11.59097195], [75.58013916, 11.59263992], [75.5798645, 11.59263802], [75.5798645, 11.59347153], [75.57958221, 11.59346962], [75.57958221, 11.59403133], [75.57930756, 11.59403133], [75.57930756, 11.59431076], [75.57902527, 11.59430599], [75.57902527, 11.59458447], [75.57875061, 11.59458447], [75.57875061, 11.59597206], [75.57847595, 11.59597015], [75.57847595, 11.59624958], [75.57818604, 11.59624958], [75.57818604, 11.59653091], [75.57791901, 11.59653091], [75.57791901, 11.59792137], [75.57763672, 11.59791565], [75.57763672, 11.5984726], [75.57736206, 11.59846973], [75.57736206, 11.59875107], [75.57707977, 11.59875107], [75.57707977, 11.59903145], [75.57736206, 11.59902859], [75.57736206, 11.59958458], [75.57707977, 11.59958458], [75.57707977, 11.59986115], [75.57736206, 11.59986115], [75.57736206, 11.60097313], [75.57707977, 11.60097027], [75.57707977, 11.60126019], [75.57681274, 11.60126019], [75.57681274, 11.60153103], [75.57653046, 11.60153103], [75.57653046, 11.60181141], [75.57624817, 11.60180473], [75.57624817, 11.60208321], [75.57597351, 11.60208321], [75.57597351, 11.6034708], [75.57569122, 11.6034708], [75.57569122, 11.60375118], [75.57541656, 11.60375118], [75.57541656, 11.60458279], [75.57514191, 11.60458279], [75.57514191, 11.60486126], [75.57485962, 11.60486126], [75.57485962, 11.60569477], [75.57457733, 11.60569096], [75.57457733, 11.60652924], [75.57430267, 11.60652924], [75.57430267, 11.60708332], [75.57402802, 11.60708332], [75.57402802, 11.60847092], [75.57375336, 11.60847092], [75.57375336, 11.60931015], [75.57347107, 11.60930538], [75.57347107, 11.60986137], [75.57319641, 11.60986137], [75.57319641, 11.61042023], [75.57290649, 11.61042023], [75.57290649, 11.61125183], [75.57263184, 11.61125183], [75.57263184, 11.61236191], [75.57235718, 11.61236191], [75.57235718, 11.61291981], [75.57208252, 11.61291981], [75.57208252, 11.61431026], [75.57180786, 11.61430645], [75.57180786, 11.61458397], [75.57152557, 11.61458397], [75.57152557, 11.61597157], [75.57125092, 11.61597157], [75.57125092, 11.61680984], [75.57068634, 11.61680984], [75.57068634, 11.61736202], [75.57041931, 11.61736202], [75.57041931, 11.61791992], [75.57013702, 11.61791801], [75.57013702, 11.6184721], [75.56986237, 11.6184721], [75.56986237, 11.61930561], [75.56958008, 11.61930561], [75.56958008, 11.6198597], [75.56930542, 11.6198616], [75.56930542, 11.62069416], [75.56903076, 11.62069035], [75.56903076, 11.62153053], [75.56874847, 11.62152767], [75.56874847, 11.62236023], [75.56847382, 11.62236023], [75.56847382, 11.62319374], [75.56819153, 11.62318993], [75.56819153, 11.62374973], [75.56791687, 11.62374973], [75.56791687, 11.62403107], [75.56764221, 11.62403107], [75.56764221, 11.62543011], [75.56735992, 11.6254158], [75.56735992, 11.62569523], [75.56764221, 11.62569046], [75.56764221, 11.62597275], [75.56735992, 11.62597275], [75.56735992, 11.62625122], [75.5670929, 11.62625122], [75.5670929, 11.62681103], [75.56680298, 11.62680435], [75.56680298, 11.6273613], [75.56652832, 11.6273613], [75.56652832, 11.62820244], [75.56624603, 11.62820244], [75.56624603, 11.6287508], [75.56597137, 11.6287508], [75.56597137, 11.62958336], [75.5654068, 11.62957954], [75.5654068, 11.63014126], [75.56513977, 11.63013935], [75.56513977, 11.63125134], [75.56485748, 11.6312418], [75.56485748, 11.63180923], [75.56458282, 11.63180542], [75.56458282, 11.63208294], [75.56430817, 11.63208103], [75.56430817, 11.63375092], [75.56402588, 11.63374901], [75.56402588, 11.63458347], [75.56375122, 11.63458061], [75.56375122, 11.63486099], [75.5634613, 11.63486099], [75.5634613, 11.63514233], [75.56319427, 11.63513947], [75.56319427, 11.63569546], [75.56291962, 11.63569069], [75.56291962, 11.63653183], [75.56263733, 11.63652706], [75.56263733, 11.63708305], [75.56236267, 11.63708305], [75.56236267, 11.63819313], [75.56208038, 11.63819122], [75.56208038, 11.63875198], [75.56181335, 11.63875198], [75.56181335, 11.63903046], [75.56153107, 11.63903046], [75.56153107, 11.64013958], [75.56124878, 11.64013958], [75.56124878, 11.64069366], [75.56097412, 11.64069366], [75.56097412, 11.64097214], [75.56069183, 11.64097214], [75.56069183, 11.64208412], [75.56041718, 11.64207935], [75.56041718, 11.64264202], [75.56014252, 11.64264202], [75.56014252, 11.64291954], [75.55986023, 11.64291573], [75.55986023, 11.6431942], [75.5595932, 11.64317989], [75.5595932, 11.64402962], [75.55930328, 11.64402771], [75.55930328, 11.6445837], [75.55902863, 11.64458179], [75.55902863, 11.64542007], [75.55874634, 11.64541626], [75.55874634, 11.64569378], [75.55847168, 11.64569187], [75.55847168, 11.64653015], [75.55819702, 11.64652824], [75.55819702, 11.64708424], [75.55791473, 11.64708424], [75.55791473, 11.64735985], [75.55764771, 11.64735985], [75.55764771, 11.64764023], [75.55735779, 11.64764023], [75.55735779, 11.64819431], [75.55708313, 11.64818954], [75.55708313, 11.64903069], [75.55680847, 11.64903069], [75.55680847, 11.64931107], [75.55708313, 11.6493063], [75.55708313, 11.64958191], [75.55680847, 11.64958], [75.55680847, 11.65014267], [75.55652618, 11.6501379], [75.55652618, 11.65069389], [75.55625153, 11.65069199], [75.55625153, 11.65153122], [75.55596924, 11.65153122], [75.55596924, 11.65237045], [75.55569458, 11.65235996], [75.55569458, 11.65319538], [75.55541992, 11.65318966], [75.55541992, 11.65375137], [75.55486298, 11.65375137], [75.55486298, 11.65458298], [75.55458832, 11.65458012], [75.55458832, 11.65514088], [75.55430603, 11.65513897], [75.55430603, 11.65541744], [75.55403137, 11.65540981], [75.55403137, 11.65653133], [75.55374908, 11.65653133], [75.55374908, 11.65681171], [75.5534668, 11.65681171], [75.5534668, 11.65736103], [75.55319214, 11.65736103], [75.55319214, 11.65875053], [75.55291748, 11.65874863], [75.55291748, 11.65986061], [75.55264282, 11.65986061], [75.55264282, 11.66014099], [75.55236053, 11.66014099], [75.55236053, 11.66041946], [75.55208588, 11.6604166], [75.55208588, 11.6609726], [75.55179596, 11.66097069], [75.55179596, 11.66125107], [75.5515213, 11.66125107], [75.5515213, 11.66154099], [75.55124664, 11.66152668], [75.55124664, 11.66208267], [75.55097198, 11.66208076], [75.55097198, 11.66264153], [75.55042267, 11.66264153], [75.55042267, 11.66292191], [75.55069733, 11.66291714], [75.55069733, 11.66347122], [75.55042267, 11.66347122], [75.55042267, 11.66403198], [75.55014038, 11.66403198], [75.55014038, 11.66431046], [75.54985809, 11.66430473], [75.54985809, 11.66458321], [75.54958344, 11.66458321], [75.54958344, 11.66569328], [75.54930878, 11.66569328], [75.54930878, 11.6659708], [75.54875183, 11.66596889], [75.54875183, 11.66624928], [75.54846191, 11.66624928], [75.54846191, 11.66681004], [75.54818726, 11.66681004], [75.54818726, 11.66792011], [75.54792023, 11.66792011], [75.54792023, 11.66903019], [75.54763794, 11.66902828], [75.54763794, 11.66958427], [75.54736328, 11.66958237], [75.54736328, 11.67014027], [75.54708099, 11.67014027], [75.54708099, 11.67097187], [75.54680634, 11.67097187], [75.54680634, 11.67153263], [75.54652405, 11.67152786], [75.54652405, 11.67319393], [75.54624939, 11.67319202], [75.54624939, 11.67374992], [75.5459671, 11.67374992], [75.5459671, 11.6740303], [75.54569244, 11.6740284], [75.54569244, 11.67458439], [75.54541779, 11.67457962], [75.54541779, 11.67514038], [75.54514313, 11.67514038], [75.54514313, 11.67542076], [75.54486084, 11.67541599], [75.54486084, 11.67597198], [75.54458618, 11.67597008], [75.54458618, 11.67681122], [75.54430389, 11.67680645], [75.54430389, 11.6773634], [75.54402924, 11.6773634], [75.54402924, 11.67819405], [75.54374695, 11.67819023], [75.54374695, 11.67875099], [75.54347229, 11.67875099], [75.54347229, 11.6793108], [75.54319763, 11.6793108], [75.54319763, 11.67986012], [75.54292297, 11.67986012], [75.54292297, 11.68014145], [75.54264069, 11.68013859], [75.54264069, 11.68069458], [75.5423584, 11.6806879], [75.5423584, 11.68181133], [75.54208374, 11.68180466], [75.54208374, 11.68208313], [75.54180908, 11.68208027], [75.54180908, 11.68264103], [75.54152679, 11.68263912], [75.54152679, 11.68319511], [75.54125214, 11.68319511], [75.54125214, 11.68347263], [75.54096985, 11.68347073], [75.54096985, 11.68403053], [75.54070282, 11.68403053], [75.54070282, 11.68431187], [75.5404129, 11.68430519], [75.5404129, 11.68486118], [75.54013824, 11.68486118], [75.54013824, 11.68569469], [75.53985596, 11.68568993], [75.53985596, 11.68625069], [75.5395813, 11.68625069], [75.5395813, 11.68653202], [75.53930664, 11.68653202], [75.53930664, 11.68680954], [75.53901672, 11.68680954], [75.53901672, 11.68763924], [75.53874969, 11.68763924], [75.53874969, 11.68848038], [75.53847504, 11.68847084], [75.53848267, 11.68875122], [75.53819275, 11.68875122], [75.53819275, 11.68931198], [75.53791809, 11.68930531], [75.53791809, 11.6898613], [75.5376358, 11.6898613], [75.5376358, 11.69014168], [75.53736115, 11.69013882], [75.53736115, 11.69069481], [75.53708649, 11.69069099], [75.53708649, 11.69124889], [75.53679657, 11.69124889], [75.53679657, 11.69180965], [75.53652954, 11.69180489], [75.53652954, 11.69208336], [75.53624725, 11.69208145], [75.53624725, 11.6926403], [75.5359726, 11.6926403], [75.5359726, 11.69319344], [75.53569794, 11.69319057], [75.53569794, 11.69375038], [75.53542328, 11.69375038], [75.53542328, 11.69402981], [75.53514099, 11.69402981], [75.53514099, 11.69514179], [75.5348587, 11.69513988], [75.5348587, 11.6956892], [75.53458405, 11.69569588], [75.53458405, 11.69597244], [75.53430939, 11.69596863], [75.53430176, 11.69653034], [75.5340271, 11.69652843], [75.5340271, 11.69708443], [75.53375244, 11.69708157], [75.53375244, 11.69736195], [75.53347778, 11.69736195], [75.53347778, 11.69791985], [75.5331955, 11.69791794], [75.5331955, 11.69819355], [75.53291321, 11.69819355], [75.53291321, 11.69847202], [75.53263855, 11.69847202], [75.53263855, 11.69902992], [75.53235626, 11.69902992], [75.53235626, 11.69931126], [75.5320816, 11.69930553], [75.5320816, 11.69986153], [75.53180695, 11.69985962], [75.53180695, 11.70014], [75.53151703, 11.70014], [75.53151703, 11.70042133], [75.53097534, 11.70041561], [75.53097534, 11.70069408], [75.5304184, 11.70069408], [75.5304184, 11.7009716], [75.53013611, 11.7009697], [75.53013611, 11.70153046], [75.52986145, 11.70153046], [75.52986145, 11.70263958], [75.5304184, 11.70263958], [75.5304184, 11.70292091], [75.53013611, 11.70294094], [75.53013611, 11.70374966], [75.52986145, 11.70374966], [75.52986145, 11.70403099], [75.53013611, 11.70403099], [75.53013611, 11.70431137], [75.52986145, 11.70430565], [75.52986145, 11.70458221], [75.52929688, 11.70458031], [75.52929688, 11.70514107], [75.52874756, 11.70513821], [75.52874756, 11.7056942], [75.5284729, 11.7056942], [75.5284729, 11.70597267], [75.52819824, 11.7059679], [75.52819824, 11.70625114], [75.52791595, 11.70625114], [75.52791595, 11.70652866], [75.52735901, 11.70652199], [75.52735901, 11.70681095], [75.52708435, 11.70680428], [75.52708435, 11.70708466], [75.5256958, 11.70708466], [75.5256958, 11.70680428], [75.52458191, 11.70680428], [75.52458191, 11.70708466], [75.52402496, 11.70708466], [75.52402496, 11.70819473], [75.52375031, 11.70818996], [75.52375031, 11.70875072], [75.52347565, 11.70875072], [75.52347565, 11.70958328], [75.52319336, 11.70958042], [75.52319336, 11.71042061], [75.5229187, 11.71041679], [75.5229187, 11.71069527], [75.52263641, 11.71068954], [75.52263641, 11.71125126], [75.52236176, 11.71125126], [75.52236176, 11.71153069], [75.5220871, 11.71152687], [75.5220871, 11.71208286], [75.52179718, 11.71208096], [75.52179718, 11.7126503], [75.52153015, 11.71263885], [75.52153015, 11.71347332], [75.52124786, 11.71347141], [75.52124786, 11.71402931], [75.52069092, 11.7140274], [75.52069092, 11.7145834], [75.52041626, 11.71458054], [75.52041626, 11.71486092], [75.51957703, 11.71486092], [75.51957703, 11.71513939], [75.51847839, 11.71513939], [75.51847839, 11.71542168], [75.51735687, 11.71542168], [75.51735687, 11.71513939], [75.51680756, 11.71513939], [75.51680756, 11.71819305], [75.51652527, 11.71819305], [75.51652527, 11.71847439], [75.51625061, 11.71846008], [75.51625061, 11.71875191], [75.51597595, 11.71874905], [75.51597595, 11.71958447], [75.51568604, 11.71958065], [75.51568604, 11.71986198], [75.51541901, 11.71986198], [75.51541901, 11.72014046], [75.51513672, 11.72014046], [75.51513672, 11.72069263], [75.51486206, 11.72069073], [75.51486206, 11.72124958], [75.51457977, 11.72124958], [75.51457977, 11.72152805], [75.51431274, 11.72152138], [75.51431274, 11.72181034], [75.51403046, 11.72180557], [75.51403046, 11.72236156], [75.51374817, 11.72235966], [75.51374817, 11.72264194], [75.51347351, 11.72264004], [75.51347351, 11.72319412], [75.51319122, 11.72319412], [75.51319122, 11.72347164], [75.51291656, 11.72347164], [75.51291656, 11.72375202], [75.51264191, 11.72375202], [75.51264191, 11.72459126], [75.51235962, 11.72458363], [75.51235962, 11.7248621], [75.51208496, 11.7248621], [75.51208496, 11.7256937], [75.51152802, 11.7256918], [75.51152802, 11.72653008], [75.51125336, 11.72653008], [75.51125336, 11.72681141], [75.51097107, 11.72681141], [75.51097107, 11.72792053], [75.51069641, 11.72791576], [75.51069641, 11.72819424], [75.51041412, 11.72819424], [75.51041412, 11.72847176], [75.51013947, 11.72846985], [75.51013947, 11.72875023], [75.50985718, 11.72875023], [75.50985718, 11.72931099], [75.50958252, 11.72930622], [75.50958252, 11.72958374], [75.50930786, 11.72957993], [75.50930786, 11.73013973], [75.50902557, 11.73013783], [75.50902557, 11.73069382], [75.50875092, 11.73069382], [75.50875092, 11.73097229], [75.50846863, 11.73097038], [75.50846863, 11.73153114], [75.50791931, 11.73152828], [75.50791931, 11.73208237], [75.50736237, 11.73208046], [75.50736237, 11.73236275], [75.50708008, 11.73236275], [75.50708008, 11.73264122], [75.50681305, 11.73264122], [75.50681305, 11.73292065], [75.50597382, 11.73291588], [75.50597382, 11.7331953], [75.50514221, 11.7331953], [75.50514221, 11.73347282], [75.50485992, 11.73346138], [75.50485992, 11.73403072], [75.5045929, 11.73403072], [75.5045929, 11.7343092], [75.50319672, 11.73430443], [75.50319672, 11.7345829], [75.50096893, 11.7345829], [75.50096893, 11.73430443], [75.50013733, 11.7343092], [75.50013733, 11.73318958], [75.49874878, 11.7331953], [75.49874878, 11.73180676], [75.49847412, 11.73180676], [75.49847412, 11.73208237], [75.49819183, 11.73208046], [75.49819183, 11.73236275], [75.49764252, 11.73236275], [75.49764252, 11.73264122], [75.4973526, 11.73264122], [75.4973526, 11.73292065], [75.49708557, 11.73291588], [75.49708557, 11.73347282], [75.4973526, 11.73346138], [75.4973526, 11.73403072], [75.49764252, 11.73403072], [75.49764252, 11.7343092], [75.49736023, 11.73430443], [75.49736023, 11.73597336], [75.4970932, 11.73597145], [75.4970932, 11.73625088], [75.49680328, 11.73625088], [75.49680328, 11.73653126], [75.49652863, 11.73653126], [75.49652863, 11.73682117], [75.49624634, 11.73682117], [75.49624634, 11.73736095], [75.49597168, 11.73736095], [75.49597168, 11.73764133], [75.49569702, 11.73763943], [75.49569702, 11.73819542], [75.49541473, 11.73819542], [75.49541473, 11.73847294], [75.49514008, 11.73847103], [75.49514008, 11.73875141], [75.49485779, 11.73875141], [75.49485779, 11.73903084], [75.49402618, 11.73902893], [75.49402618, 11.73986053], [75.49375153, 11.73986053], [75.49375153, 11.74041939], [75.49346924, 11.74041653], [75.49346924, 11.740695], [75.49318695, 11.74069118], [75.49318695, 11.74152946], [75.49291992, 11.7415266], [75.49291992, 11.7420826], [75.49263763, 11.7420826], [75.49263763, 11.74263859], [75.49208069, 11.74263], [75.49208069, 11.74292183], [75.49180603, 11.74291706], [75.49180603, 11.74319458], [75.49124908, 11.74319077], [75.49124908, 11.74375057], [75.4909668, 11.74375057], [75.4909668, 11.74431038], [75.49069214, 11.74430466], [75.49069214, 11.74458313], [75.49041748, 11.74458122], [75.49041748, 11.74486065], [75.48986053, 11.74486065], [75.48986053, 11.74514198], [75.48958588, 11.74514198], [75.48958588, 11.74542046], [75.48902893, 11.74541759], [75.48902893, 11.74569321], [75.48847198, 11.74569321], [75.48847198, 11.74597359], [75.48791504, 11.74597359], [75.48792267, 11.7462492], [75.48596954, 11.7462492], [75.48596954, 11.74652958], [75.48542023, 11.74652672], [75.48542023, 11.74708366], [75.48513794, 11.74708366], [75.48513794, 11.74736214], [75.48486328, 11.74736214], [75.48486328, 11.74819565], [75.48458099, 11.74819565], [75.48458099, 11.74847221], [75.48486328, 11.74846935], [75.48486328, 11.74903011], [75.48458099, 11.74902821], [75.48458099, 11.74986172], [75.48430634, 11.74985981], [75.48430634, 11.75125027], [75.48401642, 11.75125027], [75.48401642, 11.75152969], [75.48374939, 11.75152779], [75.48374939, 11.75208378], [75.48347473, 11.75208378], [75.48347473, 11.75236225], [75.48319244, 11.75236034], [75.48319244, 11.75292015], [75.48291779, 11.75291634], [75.48291779, 11.75347233], [75.4826355, 11.75347233], [75.4826355, 11.75374985], [75.48236847, 11.75374985], [75.48236847, 11.75403023], [75.48179626, 11.75403023], [75.48179626, 11.75431061], [75.48152924, 11.75431061], [75.48152924, 11.75485992], [75.48097229, 11.75485992], [75.48097229, 11.75542068], [75.48041534, 11.75541592], [75.48041534, 11.75569439], [75.4798584, 11.75569439], [75.4798584, 11.75597191], [75.47957611, 11.75597], [75.47957611, 11.75625038], [75.47930908, 11.75625038], [75.47930908, 11.75653076], [75.47875214, 11.75653076], [75.47875214, 11.75681114], [75.47819519, 11.75680637], [75.47819519, 11.75736237], [75.47763824, 11.75736237], [75.47763824, 11.75763798], [75.47736359, 11.75763798], [75.47735596, 11.75819016], [75.47680664, 11.75820065], [75.47680664, 11.75874996], [75.47651672, 11.75874996], [75.47651672, 11.7590313], [75.47624207, 11.7590313], [75.47624207, 11.75931072], [75.47597504, 11.75930691], [75.47597504, 11.75958157], [75.47569275, 11.75957966], [75.47569275, 11.75986004], [75.47541809, 11.75986004], [75.47541809, 11.76014137], [75.4751358, 11.76014137], [75.4751358, 11.76069927], [75.47486115, 11.76069546], [75.47486115, 11.76097298], [75.47458649, 11.76097012], [75.47458649, 11.76125145], [75.47429657, 11.76125145], [75.47429657, 11.76181126], [75.47402954, 11.76180458], [75.47402954, 11.76208305], [75.47374725, 11.76208305], [75.47374725, 11.76236057], [75.4734726, 11.76236057], [75.4734726, 11.76292133], [75.47291565, 11.76291656], [75.47291565, 11.76319504], [75.4723587, 11.76319027], [75.4723587, 11.76375961], [75.47207642, 11.76375961], [75.47207642, 11.76403141], [75.4723587, 11.76402664], [75.4723587, 11.76458263], [75.47291565, 11.76458263], [75.47291565, 11.76486111], [75.47319794, 11.76486111], [75.47319794, 11.76514053], [75.4734726, 11.76514053], [75.4734726, 11.76542187], [75.47402954, 11.7654171], [75.47402954, 11.76569462], [75.47486115, 11.76569462], [75.47486115, 11.7654171], [75.47598267, 11.76542187], [75.47598267, 11.76486111], [75.47652435, 11.76486111], [75.47652435, 11.76458263], [75.4770813, 11.76458263], [75.4770813, 11.76430511], [75.47763824, 11.76431179], [75.47763824, 11.76403141], [75.47875214, 11.76402664], [75.47875214, 11.76458263], [75.48097229, 11.76458263], [75.48097229, 11.76569462], [75.48347473, 11.76569462], [75.48347473, 11.7654171], [75.48513794, 11.76542187], [75.48513794, 11.76514053], [75.48596954, 11.76514053], [75.48596954, 11.76486111], [75.48625183, 11.76486111], [75.48625183, 11.76458263], [75.48680878, 11.76458263], [75.48680878, 11.76430511], [75.48707581, 11.76431179], [75.48707581, 11.76403141], [75.48735809, 11.76403141], [75.48735809, 11.76347065], [75.48764038, 11.76347256], [75.48764038, 11.76319504], [75.48791504, 11.76319504], [75.48791504, 11.76291656], [75.48819733, 11.76292133], [75.48819733, 11.76264095], [75.48847198, 11.76264095], [75.48847198, 11.76208019], [75.48874664, 11.76208305], [75.48874664, 11.76124763], [75.48902893, 11.76125145], [75.48902893, 11.76069927], [75.48929596, 11.76069927], [75.48929596, 11.75986004], [75.48958588, 11.75986004], [75.48958588, 11.7576313], [75.48986053, 11.75763798], [75.48986053, 11.75736237], [75.49013519, 11.75736237], [75.49013519, 11.75708199], [75.49041748, 11.75708199], [75.49041748, 11.75680637], [75.4909668, 11.75681114], [75.4909668, 11.75653076], [75.49180603, 11.75653076], [75.49180603, 11.75681114], [75.49318695, 11.75681114], [75.49318695, 11.75653076], [75.49346924, 11.75653076], [75.49346924, 11.75625038], [75.49375153, 11.75625038], [75.49375153, 11.75653076], [75.4954071, 11.75653076], [75.4954071, 11.75681114], [75.49597168, 11.75680637], [75.49597168, 11.75708199], [75.49624634, 11.75708199], [75.49624634, 11.75763798], [75.49680328, 11.7576313], [75.49680328, 11.75792122], [75.49736023, 11.75791645], [75.49736023, 11.75819397], [75.49764252, 11.75819397], [75.49764252, 11.75847244], [75.49819183, 11.75846958], [75.49819183, 11.75874996], [75.49874878, 11.75874996], [75.49874878, 11.75931072], [75.49930573, 11.75930691], [75.49930573, 11.75958157], [75.49986267, 11.75957966], [75.49986267, 11.75986004], [75.50013733, 11.75986004], [75.50013733, 11.76014137], [75.50041199, 11.76014137], [75.50041199, 11.76069927], [75.50068665, 11.76069927], [75.50068665, 11.76125145], [75.50096893, 11.76125145], [75.50096893, 11.76181126], [75.50152588, 11.76180458], [75.50152588, 11.76208305], [75.50180817, 11.76208305], [75.50180817, 11.76236057], [75.503479, 11.76236057], [75.503479, 11.76264095], [75.50430298, 11.76264095], [75.50430298, 11.76292133], [75.50458527, 11.76291656], [75.50458527, 11.76319504], [75.50541687, 11.76319504], [75.50541687, 11.76291656], [75.50569153, 11.76292133], [75.50569153, 11.76264095], [75.50596619, 11.76264095], [75.50596619, 11.76181126], [75.50624847, 11.76181126], [75.50624847, 11.76125145], [75.50763702, 11.76124763], [75.50763702, 11.76236057], [75.50791931, 11.76236057], [75.50791931, 11.76347256], [75.50818634, 11.76347065], [75.50818634, 11.76431179], [75.50791931, 11.76430511], [75.50791931, 11.76458263], [75.50708008, 11.76458263], [75.50708008, 11.76430511], [75.50653839, 11.76431179], [75.50653839, 11.76403141], [75.50596619, 11.76403141], [75.50596619, 11.76375961], [75.5045929, 11.76375961], [75.5045929, 11.76347065], [75.50375366, 11.76347256], [75.50375366, 11.76319504], [75.50347137, 11.76319504], [75.50347137, 11.76291656], [75.50152588, 11.76292133], [75.50152588, 11.76264095], [75.50125122, 11.76264095], [75.50125122, 11.76236057], [75.50069427, 11.76236057], [75.50069427, 11.76208305], [75.50041962, 11.76208305], [75.50041962, 11.76180458], [75.49986267, 11.76181126], [75.49986267, 11.76153088], [75.49958038, 11.76153088], [75.49958038, 11.76125145], [75.49931335, 11.76125145], [75.49931335, 11.76097012], [75.49903107, 11.76097298], [75.49903107, 11.76069546], [75.49874878, 11.76069927], [75.49874878, 11.76041889], [75.49764252, 11.76041889], [75.49764252, 11.76069927], [75.49736023, 11.76069546], [75.49736023, 11.76097298], [75.4970932, 11.76097012], [75.4970932, 11.76125145], [75.49624634, 11.76125145], [75.49624634, 11.76069927], [75.49597168, 11.76069927], [75.49597168, 11.76041889], [75.4954071, 11.76041889], [75.4954071, 11.76014137], [75.49485779, 11.76014137], [75.49485779, 11.75874996], [75.49458313, 11.75874996], [75.49458313, 11.75846958], [75.49375153, 11.75847244], [75.49375153, 11.75819397], [75.49236298, 11.75820065], [75.49236298, 11.75874996], [75.49208069, 11.75874996], [75.49208069, 11.75986004], [75.4909668, 11.75986004], [75.4909668, 11.76014137], [75.49124908, 11.76014137], [75.49124908, 11.76069927], [75.49153137, 11.76069927], [75.49153137, 11.76124763], [75.49014282, 11.76125145], [75.49014282, 11.76153088], [75.49041748, 11.76152897], [75.49041748, 11.76208305], [75.49069214, 11.76208305], [75.49069214, 11.76236057], [75.4909668, 11.76236057], [75.4909668, 11.76264095], [75.49124908, 11.76263905], [75.49124908, 11.76319504], [75.49069214, 11.76319504], [75.49069214, 11.76347256], [75.49041748, 11.76347065], [75.49041748, 11.76375961], [75.48958588, 11.76375961], [75.48958588, 11.76403141], [75.48930359, 11.76402664], [75.48930359, 11.76458263], [75.48902893, 11.76458073], [75.48902893, 11.76514053], [75.48874664, 11.76514053], [75.48874664, 11.76542187], [75.48847198, 11.7654171], [75.48847198, 11.76597309], [75.48819733, 11.76597118], [75.48819733, 11.76625061], [75.48792267, 11.76625061], [75.48792267, 11.76653099], [75.48735809, 11.76653099], [75.48735809, 11.76625061], [75.48596954, 11.76625061], [75.48596954, 11.76653099], [75.48569489, 11.76652908], [75.48569489, 11.7668047], [75.48542023, 11.7668047], [75.48542023, 11.76708317], [75.48458099, 11.76708126], [75.48458099, 11.76736069], [75.48430634, 11.76736069], [75.48430634, 11.76764107], [75.48208618, 11.76764107], [75.48208618, 11.76736069], [75.48179626, 11.76736069], [75.48179626, 11.76708126], [75.48152924, 11.76708317], [75.48152924, 11.7668047], [75.48069763, 11.7668047], [75.48069763, 11.76597309], [75.47875214, 11.76597309], [75.47875214, 11.76513863], [75.4770813, 11.76514053], [75.4770813, 11.76542187], [75.47652435, 11.7654171], [75.47652435, 11.76569462], [75.4751358, 11.76568985], [75.4751358, 11.76653099], [75.47486115, 11.76652908], [75.47486115, 11.76819515], [75.4751358, 11.76819515], [75.4751358, 11.76958275], [75.47541809, 11.76958275], [75.47541809, 11.76986122], [75.47569275, 11.76986122], [75.47569275, 11.77042198], [75.47597504, 11.77041721], [75.47597504, 11.77069473], [75.47652435, 11.77069473], [75.47652435, 11.7709713], [75.47680664, 11.7709713], [75.47680664, 11.77125168], [75.47735596, 11.77125168], [75.47735596, 11.77153015], [75.47763824, 11.77153015], [75.47763824, 11.77180958], [75.4779129, 11.77180481], [75.4779129, 11.77208328], [75.47820282, 11.77208138], [75.47820282, 11.77264023], [75.47846985, 11.77264023], [75.47846985, 11.77319336], [75.47902679, 11.77319336], [75.47902679, 11.77347088], [75.47930908, 11.77347088], [75.47930908, 11.77374935], [75.47957611, 11.77374935], [75.47957611, 11.77402973], [75.4798584, 11.77402973], [75.4798584, 11.77431011], [75.48069763, 11.7743063], [75.48069763, 11.77458382], [75.48152924, 11.77458382], [75.48152924, 11.7743063], [75.48208618, 11.77431011], [75.48208618, 11.77402973], [75.48236847, 11.77402973], [75.48236847, 11.77374935], [75.4826355, 11.77374935], [75.4826355, 11.77347088], [75.48291779, 11.77347088], [75.48291779, 11.77319336], [75.48319244, 11.77319336], [75.48319244, 11.77291775], [75.48374939, 11.77291775], [75.48374939, 11.77319336], [75.48430634, 11.77319145], [75.48430634, 11.77374935], [75.48458099, 11.77374935], [75.48458099, 11.77431011], [75.48430634, 11.7743063], [75.48430634, 11.77486229], [75.48401642, 11.77485943], [75.48401642, 11.77513981], [75.48374939, 11.77513981], [75.48374939, 11.77569962], [75.48430634, 11.7756958], [75.48430634, 11.77597237], [75.48652649, 11.77596855], [75.48652649, 11.77625179], [75.48680878, 11.77624989], [75.48680878, 11.77708435], [75.48652649, 11.77708244], [75.48652649, 11.77736187], [75.48625183, 11.77736187], [75.48625183, 11.77764034], [75.4854126, 11.77764034], [75.4854126, 11.77791977], [75.48513794, 11.77791786], [75.48513794, 11.77819443], [75.48486328, 11.77819443], [75.48486328, 11.77875042], [75.48513794, 11.77874088], [75.48513794, 11.77902985], [75.48568726, 11.77902985], [75.48568726, 11.77931118], [75.48625183, 11.77930641], [75.48625183, 11.7798624], [75.48652649, 11.7798624], [75.48652649, 11.78208447], [75.48680878, 11.7820797], [75.48680878, 11.78236008], [75.48735809, 11.78236008], [75.48735809, 11.78264046], [75.48764038, 11.78264046], [75.48764038, 11.78292084], [75.48792267, 11.78292084], [75.48792267, 11.78431129], [75.48764038, 11.78430557], [75.48764038, 11.78458214], [75.48708344, 11.78458214], [75.48708344, 11.78374958], [75.48596954, 11.78374958], [75.48596954, 11.78403091], [75.48513794, 11.78403091], [75.48513794, 11.78431129], [75.48402405, 11.78430557], [75.48402405, 11.78458214], [75.48374939, 11.78458023], [75.48374939, 11.78542137], [75.48402405, 11.78541565], [75.48402405, 11.78569412], [75.48430634, 11.78569412], [75.48430634, 11.78597164], [75.48401642, 11.78596973], [75.48401642, 11.78681087], [75.48430634, 11.7868042], [75.48430634, 11.78736019], [75.48458099, 11.78736019], [75.48458099, 11.78764057], [75.48486328, 11.78763866], [75.48486328, 11.78819466], [75.48458099, 11.78819466], [75.48458099, 11.78847313], [75.48569489, 11.78847313], [75.48569489, 11.78819466], [75.48596954, 11.78819466], [75.48596954, 11.78847313], [75.48625183, 11.78847027], [75.48625183, 11.78903103], [75.48652649, 11.78903103], [75.48652649, 11.78931141], [75.48680878, 11.78931141], [75.48680878, 11.78986073], [75.48764038, 11.78986073], [75.48764038, 11.79014111], [75.48792267, 11.79014111], [75.48792267, 11.79042053], [75.48819733, 11.79041672], [75.48819733, 11.79069519], [75.48874664, 11.79069519], [75.48874664, 11.79097271], [75.48958588, 11.7909708], [75.48958588, 11.79153061], [75.48986053, 11.79152679], [75.48986053, 11.79208279], [75.49069214, 11.79208279], [75.49069214, 11.79180527], [75.4909668, 11.79181194], [75.4909668, 11.79153061], [75.49124908, 11.79153061], [75.49124908, 11.79125118], [75.49153137, 11.79125118], [75.49153137, 11.7909708], [75.49263763, 11.79097271], [75.49263763, 11.79069519], [75.49291992, 11.79069519], [75.49291992, 11.79041672], [75.49375153, 11.79041672], [75.49375153, 11.79069519], [75.49402618, 11.79068089], [75.49402618, 11.79181194], [75.49375153, 11.79180527], [75.49375153, 11.79319477], [75.49402618, 11.79319477], [75.49402618, 11.79374886], [75.49430847, 11.79374027], [75.49430847, 11.79402924], [75.49458313, 11.79402924], [75.49458313, 11.79430962], [75.49514008, 11.79430485], [75.49514008, 11.79458332], [75.49597168, 11.79458141], [75.49597168, 11.79486084], [75.49624634, 11.79486084], [75.49624634, 11.79513931], [75.49652863, 11.79513931], [75.49652863, 11.7954216], [75.49680328, 11.7954216], [75.49680328, 11.79513931], [75.49764252, 11.79513931], [75.49764252, 11.79486084], [75.49791718, 11.79486084], [75.49791718, 11.79430962], [75.49819183, 11.79430962], [75.49819183, 11.79374027], [75.49874878, 11.79374886], [75.49874878, 11.79347324], [75.49930573, 11.79347324], [75.49930573, 11.79319477], [75.50013733, 11.79319477], [75.50013733, 11.79347324], [75.50041962, 11.79347324], [75.50041962, 11.79736137], [75.50013733, 11.79736137], [75.50013733, 11.79819489], [75.49986267, 11.79819489], [75.49986267, 11.79847431], [75.49903107, 11.79847431], [75.49903107, 11.79819489], [75.49874878, 11.79819489], [75.49874878, 11.79791737], [75.49847412, 11.79791737], [75.49847412, 11.79847431], [75.49819183, 11.79847145], [75.49819183, 11.7990303], [75.49791718, 11.7990303], [75.49791718, 11.79930973], [75.49764252, 11.79930496], [75.49764252, 11.79958344], [75.49652863, 11.79958344], [75.49652863, 11.79930496], [75.49624634, 11.79930973], [75.49624634, 11.7990303], [75.49569702, 11.7990303], [75.49569702, 11.79875183], [75.49514008, 11.79875183], [75.49514008, 11.79847145], [75.49458313, 11.79847431], [75.49458313, 11.79819489], [75.49319458, 11.79819489], [75.49319458, 11.79791737], [75.49263763, 11.79792023], [75.49263763, 11.79763889], [75.49124908, 11.79763889], [75.49124908, 11.79736137], [75.49069214, 11.79736137], [75.49069214, 11.7970829], [75.49041748, 11.7970829], [75.49041748, 11.79680538], [75.49014282, 11.79681015], [75.49014282, 11.79653168], [75.48902893, 11.79653168], [75.48902893, 11.7962513], [75.48764038, 11.7962513], [75.48764038, 11.79653168], [75.48707581, 11.79653168], [75.48707581, 11.79681015], [75.48680878, 11.79681015], [75.48680878, 11.79763889], [75.48652649, 11.79763889], [75.48652649, 11.79819489], [75.48625183, 11.79819489], [75.48625183, 11.79847431], [75.48596954, 11.79847145], [75.48596954, 11.79875183], [75.48625183, 11.79875183], [75.48625183, 11.7990303], [75.48596954, 11.7990303], [75.48596954, 11.79930973], [75.48568726, 11.79930973], [75.48568726, 11.7990303], [75.4854126, 11.7990303], [75.4854126, 11.79875183], [75.48319244, 11.79875183], [75.48319244, 11.79847145], [75.48264313, 11.79847145], [75.48264313, 11.79875183], [75.48236847, 11.79875183], [75.48236847, 11.79930973], [75.48097229, 11.79930973], [75.48097229, 11.80014038], [75.47957611, 11.80014038], [75.47957611, 11.80041981], [75.4779129, 11.80041981], [75.4779129, 11.80014038], [75.47735596, 11.80014038], [75.47735596, 11.80041981], [75.4770813, 11.8004179], [75.4770813, 11.80097103], [75.47680664, 11.80097103], [75.47680664, 11.80208397], [75.47652435, 11.80208397], [75.47652435, 11.80236244], [75.47569275, 11.80235863], [75.47569275, 11.80293179], [75.47541809, 11.80291557], [75.47541809, 11.80347157], [75.4743042, 11.80347157], [75.4743042, 11.80097103], [75.47458649, 11.80097103], [75.47458649, 11.79986191], [75.47486115, 11.79987144], [75.47486115, 11.79958057], [75.47541809, 11.79958344], [75.47541809, 11.79930496], [75.47569275, 11.79930973], [75.47569275, 11.7990303], [75.4770813, 11.7990303], [75.4770813, 11.79930973], [75.47930908, 11.79930973], [75.47930908, 11.7990303], [75.47957611, 11.7990303], [75.47957611, 11.79847145], [75.4798584, 11.79847431], [75.4798584, 11.79763889], [75.48042297, 11.79763889], [75.48042297, 11.79681015], [75.48069763, 11.79681015], [75.48069763, 11.79653168], [75.48124695, 11.79653168], [75.48124695, 11.79681015], [75.48180389, 11.79680538], [75.48180389, 11.7970829], [75.48236084, 11.7970829], [75.48236084, 11.79680538], [75.48264313, 11.79681015], [75.48264313, 11.79653168], [75.48374939, 11.79653168], [75.48374939, 11.7962513], [75.48430634, 11.7962513], [75.48430634, 11.79597092], [75.48458099, 11.79597092], [75.48458099, 11.7956953], [75.48486328, 11.7956953], [75.48486328, 11.79541683], [75.48513794, 11.7954216], [75.48513794, 11.79486084], [75.4854126, 11.79486084], [75.4854126, 11.79458141], [75.48569489, 11.79458332], [75.48569489, 11.79430485], [75.48596954, 11.79430962], [75.48596954, 11.79402924], [75.48625183, 11.79402924], [75.48625183, 11.79374027], [75.48596954, 11.79374886], [75.48596954, 11.79347324], [75.48625183, 11.79347324], [75.48625183, 11.79236126], [75.48680878, 11.79236126], [75.48680878, 11.79180527], [75.48652649, 11.79180527], [75.48652649, 11.79208279], [75.48569489, 11.79208279], [75.48569489, 11.79180527], [75.4854126, 11.79181194], [75.4854126, 11.79153061], [75.48486328, 11.79153061], [75.48486328, 11.7909708], [75.48430634, 11.7909708], [75.48430634, 11.79125118], [75.48458099, 11.79125118], [75.48458099, 11.79181194], [75.48486328, 11.79180527], [75.48486328, 11.79236126], [75.48401642, 11.79236126], [75.48401642, 11.79264069], [75.48236847, 11.79264069], [75.48236847, 11.79236126], [75.48180389, 11.79236126], [75.48180389, 11.79125118], [75.48124695, 11.79125118], [75.48124695, 11.79068089], [75.48069763, 11.79069519], [75.48069763, 11.79041672], [75.48042297, 11.79042053], [75.48042297, 11.79014111], [75.4798584, 11.79014111], [75.4798584, 11.78958035], [75.47958374, 11.78958321], [75.47958374, 11.78930473], [75.47902679, 11.78931141], [75.47902679, 11.78875065], [75.47875214, 11.78875065], [75.47875214, 11.78764057], [75.47902679, 11.78764057], [75.47902679, 11.78681087], [75.47875214, 11.78681087], [75.47875214, 11.78653145], [75.47820282, 11.78653145], [75.47820282, 11.78569031], [75.4779129, 11.78569412], [75.4779129, 11.78430557], [75.47820282, 11.78431129], [75.47820282, 11.78264046], [75.47846985, 11.78264046], [75.47846985, 11.78236008], [75.47875214, 11.78236008], [75.47875214, 11.7820797], [75.47958374, 11.78208447], [75.47958374, 11.78180599], [75.4798584, 11.78180599], [75.4798584, 11.78041553], [75.48014069, 11.7804203], [75.48014069, 11.78013992], [75.48042297, 11.78013992], [75.48042297, 11.77958202], [75.48069763, 11.77958393], [75.48069763, 11.77930641], [75.48042297, 11.77931118], [75.48042297, 11.77902985], [75.48014069, 11.77902985], [75.48014069, 11.77847195], [75.47958374, 11.77847195], [75.47958374, 11.77819443], [75.47930908, 11.77819443], [75.47930908, 11.77791786], [75.47902679, 11.77791977], [75.47902679, 11.77764034], [75.47875214, 11.77764034], [75.47875214, 11.77736187], [75.47846985, 11.77736187], [75.47846985, 11.77708244], [75.47819519, 11.77708435], [75.47819519, 11.77680588], [75.4779129, 11.77680969], [75.4779129, 11.77653027], [75.47763824, 11.77653027], [75.47763824, 11.77625179], [75.47735596, 11.77625179], [75.47735596, 11.77596855], [75.47680664, 11.77597237], [75.47680664, 11.7756958], [75.47651672, 11.77569962], [75.47651672, 11.77542019], [75.47569275, 11.77542019], [75.47569275, 11.77513981], [75.47486115, 11.77513981], [75.47486115, 11.77485943], [75.47374725, 11.77486229], [75.47374725, 11.77458382], [75.47319794, 11.77458382], [75.47319794, 11.7743063], [75.47292328, 11.77431011], [75.47292328, 11.77347088], [75.47264099, 11.77347088], [75.47264099, 11.7723608], [75.4723587, 11.7723608], [75.4723587, 11.77152729], [75.47207642, 11.77153015], [75.47207642, 11.7709713], [75.47180176, 11.7709713], [75.47180176, 11.77069473], [75.4715271, 11.77069473], [75.4715271, 11.77013874], [75.47125244, 11.7701416], [75.47125244, 11.76957035], [75.47097015, 11.76958275], [75.47097015, 11.76819515], [75.4706955, 11.76819515], [75.4706955, 11.76708317], [75.47041321, 11.76708317], [75.47041321, 11.76652908], [75.47013855, 11.76653099], [75.47013855, 11.76568985], [75.4695816, 11.76569462], [75.4695816, 11.7654171], [75.46930695, 11.76542187], [75.46930695, 11.76514053], [75.46901703, 11.76514053], [75.46901703, 11.76486111], [75.46875, 11.76486111], [75.46875, 11.76458263], [75.46819305, 11.76458263], [75.46819305, 11.76430511], [75.4679184, 11.76430511], [75.4679184, 11.76458263], [75.46736145, 11.76458263], [75.46736145, 11.76486111], [75.46708679, 11.76486111], [75.46708679, 11.76514053], [75.46679687, 11.76514053], [75.46679687, 11.76542187], [75.46652985, 11.7654171], [75.46652985, 11.76569462], [75.46624756, 11.76569462], [75.46624756, 11.76597309], [75.4659729, 11.76597118], [75.4659729, 11.76625061], [75.46485901, 11.76625061], [75.46485901, 11.76597118], [75.46430206, 11.76597309], [75.46430206, 11.76569462], [75.46347046, 11.76569462], [75.46347046, 11.7654171], [75.4631958, 11.7654171], [75.4631958, 11.76569462], [75.46263885, 11.76569462], [75.46263885, 11.76597309], [75.46152496, 11.76597309], [75.46152496, 11.76569462], [75.46097565, 11.76569462], [75.46097565, 11.7654171], [75.45986176, 11.7654171], [75.45986176, 11.76569462], [75.4595871, 11.76569462], [75.4595871, 11.7668047], [75.45903015, 11.76679993], [75.45903015, 11.76736069], [75.45874786, 11.76736069], [75.45874786, 11.76764107], [75.45819092, 11.76763916], [75.45819092, 11.76819515], [75.45789337, 11.76819515], [75.45777893, 11.76819515], [75.4576416, 11.76819515], [75.4576416, 11.76847267], [75.45735931, 11.76847076], [75.45735931, 11.76875114], [75.45680237, 11.76875114], [75.45680237, 11.76903152], [75.45625305, 11.76903152], [75.45625305, 11.7693119], [75.45569611, 11.76930523], [75.45569611, 11.76958275], [75.45541382, 11.76958275], [75.45541382, 11.76986122], [75.45485687, 11.76986122], [75.45485687, 11.7701416], [75.45458221, 11.7701416], [75.45458221, 11.76986122], [75.45430756, 11.76986122], [75.45430756, 11.7701416], [75.45375061, 11.77013874], [75.45375061, 11.77069473], [75.45347595, 11.77069092], [75.45347595, 11.77125168], [75.45375061, 11.77125168], [75.45375061, 11.77153015], [75.4540329, 11.77153015], [75.4540329, 11.77180958], [75.45430756, 11.77180481], [75.45430756, 11.77319336], [75.45458221, 11.77319336], [75.45458221, 11.77347088], [75.45458221, 11.77431011], [75.45430756, 11.77431011], [75.45430756, 11.77542019], [75.45458221, 11.77542019], [75.45458221, 11.77569962], [75.45485687, 11.77569962], [75.45485687, 11.77625179], [75.45513916, 11.77625179], [75.45513916, 11.77653027], [75.45540619, 11.77653027], [75.45540619, 11.77680969], [75.45597076, 11.77680588], [75.45597076, 11.77708435], [75.45652771, 11.77708435], [75.45652771, 11.77652836], [75.45680237, 11.77653027], [75.45680237, 11.77625179], [75.4576416, 11.77625179], [75.4576416, 11.77596855], [75.45819855, 11.77596855], [75.45819855, 11.77625179], [75.45903015, 11.77625179], [75.45903015, 11.77653027], [75.46013641, 11.77653027], [75.46013641, 11.77680969], [75.4604187, 11.77680969], [75.4604187, 11.77764034], [75.46069336, 11.77764034], [75.46069336, 11.77791977], [75.4604187, 11.77791786], [75.4604187, 11.77819443], [75.46069336, 11.77819443], [75.46069336, 11.77875042], [75.46098328, 11.77874088], [75.46098328, 11.77931118], [75.46125031, 11.77930641], [75.46125031, 11.7798624], [75.46151733, 11.77985954], [75.46151733, 11.78013992], [75.46180725, 11.78013802], [75.46180725, 11.78069401], [75.46208191, 11.78068924], [75.46208191, 11.78153038], [75.4623642, 11.78152847], [75.4623642, 11.78208447], [75.46263885, 11.78208447], [75.46263885, 11.78319359], [75.46290588, 11.78318977], [75.46290588, 11.78374958], [75.4631958, 11.78374958], [75.4631958, 11.78514099], [75.46347046, 11.78514099], [75.46347046, 11.78625107], [75.4631958, 11.78625107], [75.4631958, 11.78681087], [75.46347046, 11.78681087], [75.46347046, 11.79125118], [75.4631958, 11.79125118], [75.4631958, 11.79319477], [75.46291351, 11.79319477], [75.46291351, 11.79347324], [75.4631958, 11.79347134], [75.4631958, 11.79430962], [75.46291351, 11.79430485], [75.46291351, 11.7956953], [75.4631958, 11.79569054], [75.4631958, 11.7962513], [75.46347046, 11.7962513], [75.46347046, 11.79681015], [75.46375275, 11.79680538], [75.46375275, 11.7970829], [75.46347046, 11.79708099], [75.46347046, 11.7990303], [75.4631958, 11.7990303], [75.4631958, 11.80014038], [75.46290588, 11.80014038], [75.46290588, 11.80041981], [75.46263885, 11.8004179], [75.46263885, 11.80069256], [75.4623642, 11.80069256], [75.4623642, 11.80097103], [75.46208191, 11.80097103], [75.46208191, 11.80153179], [75.46180725, 11.80152798], [75.46180725, 11.80208397], [75.46151733, 11.8020792], [75.46151733, 11.80263996], [75.46125031, 11.80263996], [75.46125031, 11.80347157], [75.46098328, 11.80347157], [75.46098328, 11.80403042], [75.4604187, 11.80402756], [75.4604187, 11.80569363], [75.46013641, 11.80569363], [75.46013641, 11.80579185], [75.46013641, 11.8073597], [75.45874786, 11.8073597], [75.45874786, 11.80597019], [75.45847321, 11.8059721], [75.45847321, 11.80458355], [75.45874786, 11.80458355], [75.45874786, 11.80375004], [75.45903015, 11.80375195], [75.45903015, 11.80293179], [75.45923615, 11.80293179], [75.45929718, 11.80263996], [75.46013641, 11.80263996], [75.46013641, 11.80235863], [75.4604187, 11.80236244], [75.4604187, 11.80180645], [75.46069336, 11.80181026], [75.46069336, 11.80097103], [75.46097565, 11.80097103], [75.46097565, 11.8004179], [75.46124268, 11.80041981], [75.46124268, 11.79930973], [75.46098328, 11.79930973], [75.46098328, 11.79875183], [75.46124268, 11.79875183], [75.46124268, 11.79847145], [75.46208191, 11.79847431], [75.46208191, 11.79819489], [75.46180725, 11.79819489], [75.46180725, 11.79791737], [75.46208191, 11.79792023], [75.46208191, 11.79653168], [75.46180725, 11.79653168], [75.46180725, 11.79588032], [75.46180725, 11.79541683], [75.46153259, 11.7954216], [75.46153259, 11.79374027], [75.46180725, 11.79374886], [75.46180725, 11.79347324], [75.46152496, 11.79347324], [75.46152496, 11.79263878], [75.46124268, 11.79264069], [75.46124268, 11.79236126], [75.46152496, 11.79236126], [75.46152496, 11.79208279], [75.46125031, 11.79208279], [75.46125031, 11.79125118], [75.46097565, 11.79125118], [75.46097565, 11.78763866], [75.46124268, 11.78764057], [75.46124268, 11.78458023], [75.46097565, 11.78458214], [75.46097565, 11.78402805], [75.46069336, 11.78403091], [75.46069336, 11.78347015], [75.4604187, 11.78347206], [75.4604187, 11.78291607], [75.46069336, 11.78292084], [75.46069336, 11.78264046], [75.4604187, 11.78264046], [75.4604187, 11.7820797], [75.46013641, 11.78208447], [75.46013641, 11.77958393], [75.45986176, 11.77958393], [75.45986176, 11.77902794], [75.4595871, 11.77902985], [75.4595871, 11.77847195], [75.45930481, 11.77847195], [75.45930481, 11.77819443], [75.45735931, 11.77819443], [75.45735931, 11.77847195], [75.45652771, 11.77847195], [75.45652771, 11.77875042], [75.45625305, 11.77874088], [75.45625305, 11.77902985], [75.45540619, 11.77902985], [75.45540619, 11.77874088], [75.45513916, 11.77875042], [75.45513916, 11.77847195], [75.4548645, 11.77847195], [75.4548645, 11.77875042], [75.45458221, 11.77875042], [75.45458221, 11.77847195], [75.45402527, 11.77847195], [75.45402527, 11.77875042], [75.45347595, 11.77874088], [75.45347595, 11.77902985], [75.45318604, 11.77902985], [75.45318604, 11.77931118], [75.45263672, 11.77930641], [75.45263672, 11.77958393], [75.45207977, 11.77958393], [75.45207977, 11.7798624], [75.45153046, 11.77985954], [75.45153046, 11.78013992], [75.45069122, 11.78013992], [75.45069122, 11.7804203], [75.45014191, 11.78041553], [75.45014191, 11.78069401], [75.44958496, 11.78069401], [75.44958496, 11.78097153], [75.44847107, 11.78096962], [75.44847107, 11.78125], [75.44819641, 11.78125], [75.44819641, 11.78153038], [75.44763947, 11.78152847], [75.44763947, 11.78180599], [75.44736481, 11.78180599], [75.44736481, 11.78347206], [75.44763947, 11.78347015], [75.44763947, 11.78542137], [75.44790649, 11.78542137], [75.44790649, 11.78653145], [75.44763947, 11.78653145], [75.44763947, 11.78764057], [75.44736481, 11.78763866], [75.44736481, 11.78819466], [75.44708252, 11.7881918], [75.44708252, 11.78875065], [75.44680786, 11.78875065], [75.44680786, 11.78903103], [75.4465332, 11.78903103], [75.4465332, 11.79014111], [75.44625092, 11.7901392], [75.44625092, 11.79069519], [75.44596863, 11.79068089], [75.44596863, 11.79125118], [75.44541931, 11.79125118], [75.44541931, 11.79153061], [75.44513702, 11.79153061], [75.44513702, 11.79181194], [75.44486237, 11.79180527], [75.44486237, 11.79236126], [75.44458008, 11.79236126], [75.44458008, 11.79292202], [75.44430542, 11.79291725], [75.44430542, 11.79319477], [75.44374847, 11.79319477], [75.44374847, 11.79374886], [75.44347382, 11.79374886], [75.44347382, 11.79458332], [75.44319916, 11.79458141], [75.44319916, 11.79513931], [75.44291687, 11.79513931], [75.44291687, 11.79597092], [75.44264221, 11.79597092], [75.44264221, 11.79653168], [75.44235992, 11.79652691], [75.44235992, 11.79736137], [75.44152832, 11.79736137], [75.44152832, 11.79763889], [75.44069672, 11.79763889], [75.44069672, 11.79819489], [75.4404068, 11.79819107], [75.4404068, 11.79875183], [75.44013214, 11.79875183], [75.44013214, 11.7990303], [75.43985748, 11.79902744], [75.43985748, 11.79958344], [75.43958282, 11.79958344], [75.43958282, 11.80069256], [75.43902588, 11.80069256], [75.43902588, 11.80097103], [75.43875122, 11.80097103], [75.43875122, 11.80153179], [75.43846893, 11.80153179], [75.43846893, 11.80181026], [75.43791962, 11.80180645], [75.43791962, 11.80236244], [75.43763733, 11.80235863], [75.43763733, 11.80293179], [75.43707275, 11.80293179], [75.43707275, 11.80375195], [75.43681335, 11.80375195], [75.43681335, 11.80403042], [75.43653107, 11.80402756], [75.43653107, 11.80458355], [75.43596649, 11.80458164], [75.43596649, 11.80513954], [75.43569183, 11.80513954], [75.43569183, 11.80541992], [75.43541718, 11.80541801], [75.43541718, 11.8059721], [75.43514252, 11.80597019], [75.43514252, 11.80624962], [75.43486023, 11.80624962], [75.43486023, 11.80653], [75.4345932, 11.80653], [75.4345932, 11.80681133], [75.43402863, 11.80680561], [75.43402863, 11.80708408], [75.43374634, 11.80708027], [75.43374634, 11.8073597], [75.4329071, 11.8073597], [75.4329071, 11.80764008], [75.43264008, 11.80764008], [75.43264008, 11.80792141], [75.43208313, 11.80792141], [75.43208313, 11.80764008], [75.43180847, 11.80764008], [75.43180847, 11.8073597], [75.43152618, 11.8073597], [75.43152618, 11.80681133], [75.42958069, 11.80680561], [75.42958069, 11.80708408], [75.42930603, 11.80708027], [75.42930603, 11.8073597], [75.42903137, 11.8073597], [75.42903137, 11.80764008], [75.42874908, 11.80764008], [75.42874908, 11.80819416], [75.4284668, 11.80818939], [75.4284668, 11.80875015], [75.42819214, 11.80875015], [75.42819214, 11.80902958], [75.42764282, 11.80902958], [75.42764282, 11.80931091], [75.42736053, 11.80930614], [75.42736053, 11.80958366], [75.42708588, 11.80957985], [75.42708588, 11.81013966], [75.42652893, 11.81013966], [75.42652893, 11.81042099], [75.42569733, 11.81042099], [75.42569733, 11.81124973], [75.42542267, 11.81124973], [75.42542267, 11.81181145], [75.42485809, 11.81180573], [75.42485809, 11.81208229], [75.42402649, 11.81208038], [75.42402649, 11.81236267], [75.42375183, 11.81236267], [75.42375183, 11.81264114], [75.42346954, 11.81264114], [75.42346954, 11.81292057], [75.42375183, 11.81292057], [75.42375183, 11.81431103], [75.42346954, 11.81430435], [75.42346954, 11.81458473], [75.42318726, 11.81457996], [75.42318726, 11.81487179], [75.42292023, 11.81487179], [75.42292023, 11.81514072], [75.42263794, 11.81514072], [75.42263794, 11.8162508], [75.42236328, 11.8162508], [75.42236328, 11.81653118], [75.42180634, 11.81653118], [75.42180634, 11.81681061], [75.42151642, 11.81681061], [75.42151642, 11.81736088], [75.42124939, 11.81736088], [75.42124939, 11.81764126], [75.42097473, 11.81763935], [75.42097473, 11.81791687], [75.42069244, 11.81791687], [75.42069244, 11.81819534], [75.42041779, 11.81819534], [75.42041779, 11.81847286], [75.42014313, 11.81847095], [75.42014313, 11.81903076], [75.41958618, 11.81903076], [75.41958618, 11.81930923], [75.41902924, 11.81930542], [75.41902924, 11.81958294], [75.41847229, 11.81958103], [75.41847229, 11.82014084], [75.41819763, 11.82013893], [75.41819763, 11.82069111], [75.41792297, 11.82069969], [75.41792297, 11.82180977], [75.41764069, 11.82180977], [75.41764069, 11.82236099], [75.4173584, 11.82236099], [75.4173584, 11.82291985], [75.41708374, 11.82291698], [75.41708374, 11.82319546], [75.41652679, 11.82319069], [75.41652679, 11.82375145], [75.41625214, 11.82375145], [75.41625214, 11.8243103], [75.41596985, 11.82430458], [75.41596985, 11.82458305], [75.41570282, 11.82458115], [75.41570282, 11.82514191], [75.41513824, 11.82514191], [75.41513824, 11.82542038], [75.41486359, 11.82541656], [75.41486359, 11.82597446], [75.4145813, 11.82597065], [75.4145813, 11.82653046], [75.41401672, 11.82653046], [75.41401672, 11.82681179], [75.41374969, 11.82680511], [75.41374969, 11.82736206], [75.41319275, 11.8273592], [75.41319275, 11.82763958], [75.41291809, 11.82763958], [75.41291809, 11.82819557], [75.4126358, 11.8281889], [75.4126358, 11.82874966], [75.41236115, 11.82874966], [75.41236115, 11.82903004], [75.41208649, 11.82903004], [75.41208649, 11.82931042], [75.4118042, 11.82930565], [75.4118042, 11.82958412], [75.41152954, 11.82958412], [75.41152954, 11.82986164], [75.41124725, 11.8298502], [75.41124725, 11.83014202], [75.4109726, 11.83014202], [75.4109726, 11.83041954], [75.41069794, 11.83041573], [75.41069794, 11.8306942], [75.41041565, 11.8306942], [75.41041565, 11.83097172], [75.41014099, 11.83097172], [75.41014862, 11.83125019], [75.4098587, 11.83125019], [75.4098587, 11.83152962], [75.40957642, 11.83152962], [75.40957642, 11.83181], [75.4090271, 11.83180618], [75.4090271, 11.8320837], [75.40875244, 11.8320837], [75.40875244, 11.83236217], [75.40847015, 11.83236027], [75.40847015, 11.83263969], [75.40791321, 11.83263779], [75.40791321, 11.83347225], [75.40763855, 11.83347034], [75.40763855, 11.83403015], [75.40736389, 11.83402824], [75.40736389, 11.83485985], [75.40680695, 11.83485985], [75.40680695, 11.83542061], [75.40651703, 11.83542061], [75.40651703, 11.83598137], [75.40625, 11.83598137], [75.40625, 11.83625031], [75.40569305, 11.83625031], [75.40569305, 11.83653069], [75.4054184, 11.83653069], [75.4054184, 11.83681107], [75.40513611, 11.8368063], [75.40513611, 11.83819389], [75.4034729, 11.83819389], [75.4034729, 11.83791637], [75.40319824, 11.83791637], [75.40319824, 11.83819389], [75.40291595, 11.83819389], [75.40291595, 11.83847237], [75.4026413, 11.83847046], [75.4026413, 11.83875275], [75.40235901, 11.83875275], [75.40235901, 11.8390398], [75.40207672, 11.8390398], [75.40207672, 11.83931065], [75.4015274, 11.83930683], [75.4015274, 11.83958244], [75.40125275, 11.83957958], [75.40125275, 11.83985996], [75.40096283, 11.83985996], [75.40096283, 11.8401413], [75.4006958, 11.8401413], [75.4006958, 11.84042072], [75.40041351, 11.84041595], [75.40041351, 11.84069538], [75.39875031, 11.84069538], [75.39875031, 11.8409729], [75.39847565, 11.8409729], [75.39848328, 11.84125137], [75.39819336, 11.84125137], [75.39819336, 11.8415308], [75.39763641, 11.8415308], [75.39763641, 11.84181118], [75.39736176, 11.84180355], [75.39736176, 11.84236145], [75.3970871, 11.84236145], [75.3970871, 11.84264088], [75.39653015, 11.84264088], [75.39653015, 11.84375095], [75.39624786, 11.84375095], [75.39624786, 11.84431171], [75.39597321, 11.84430695], [75.39597321, 11.84486103], [75.39569092, 11.84485245], [75.39569092, 11.84514141], [75.39541626, 11.84513855], [75.39541626, 11.84569454], [75.3951416, 11.84569454], [75.3951416, 11.84597301], [75.39457703, 11.84597111], [75.39457703, 11.84653091], [75.39430237, 11.84653091], [75.39430237, 11.84680939], [75.39402771, 11.84680462], [75.39402771, 11.84736061], [75.39375305, 11.84736061], [75.39375305, 11.84791946], [75.39347076, 11.8479166], [75.39347076, 11.8484726], [75.39319611, 11.84847069], [75.39319611, 11.84875107], [75.39290619, 11.84875107], [75.39290619, 11.8490324], [75.39263916, 11.8490324], [75.39263916, 11.84931183], [75.39152527, 11.84930515], [75.39152527, 11.84958267], [75.39125061, 11.84958267], [75.39125061, 11.84986115], [75.39097595, 11.84986115], [75.39097595, 11.85014153], [75.39069366, 11.85013866], [75.39069366, 11.85069466], [75.39041901, 11.85069084], [75.39041901, 11.8509798], [75.39013672, 11.8509798], [75.39013672, 11.85125065], [75.38986206, 11.85125065], [75.38986206, 11.85153198], [75.38957977, 11.85153198], [75.38957977, 11.85181046], [75.38930511, 11.85180473], [75.38930511, 11.85208321], [75.38902283, 11.8520813], [75.38902283, 11.85236073], [75.38846588, 11.85236073], [75.38846588, 11.8526392], [75.38819122, 11.8526392], [75.38819122, 11.85291958], [75.38791656, 11.85291767], [75.38791656, 11.85319328], [75.38764191, 11.85319328], [75.38764191, 11.8534708], [75.38708496, 11.85347366], [75.38709259, 11.85374928], [75.38680267, 11.85374928], [75.38680267, 11.85402679], [75.38652802, 11.85402107], [75.38652802, 11.85431004], [75.38625336, 11.85430622], [75.38625336, 11.85458374], [75.38569641, 11.85458374], [75.38569641, 11.85486221], [75.38540649, 11.85485935], [75.38540649, 11.85513973], [75.38513947, 11.85513973], [75.38513947, 11.85542011], [75.38486481, 11.85541534], [75.38486481, 11.85569572], [75.38458252, 11.85569572], [75.38458252, 11.85597229], [75.38430786, 11.85597229], [75.38430786, 11.85624981], [75.3840332, 11.85624981], [75.3840332, 11.85653019], [75.38375092, 11.85653019], [75.38375092, 11.85680962], [75.38319397, 11.8568058], [75.38319397, 11.85708427], [75.38263702, 11.85708237], [75.38263702, 11.85736179], [75.38236237, 11.85736179], [75.38236237, 11.85764027], [75.38181305, 11.85764027], [75.38181305, 11.85791969], [75.38097382, 11.85791779], [75.38097382, 11.85819435], [75.38041687, 11.85819435], [75.38041687, 11.85847187], [75.37985992, 11.85847187], [75.37985992, 11.85875034], [75.37930298, 11.85875034], [75.37930298, 11.85902977], [75.37902832, 11.85902977], [75.37902832, 11.85875034], [75.37763977, 11.85875034], [75.37763977, 11.85847187], [75.37652588, 11.85847187], [75.37652588, 11.85819435], [75.37625122, 11.85819435], [75.37625122, 11.85791779], [75.37458038, 11.85791969], [75.37458038, 11.85736179], [75.37431335, 11.85736179], [75.37431335, 11.85680962], [75.37346649, 11.85680962], [75.37346649, 11.85653019], [75.37319183, 11.85653019], [75.37319183, 11.85624981], [75.37291718, 11.85624981], [75.37291718, 11.85597229], [75.37264252, 11.85597229], [75.37264252, 11.85513973], [75.37291718, 11.85513973], [75.37291718, 11.85431004], [75.37319183, 11.85431004], [75.37319183, 11.85402107], [75.37347412, 11.85402679], [75.37347412, 11.85374928], [75.37401581, 11.85374928], [75.37401581, 11.85346889], [75.37430573, 11.8534708], [75.37430573, 11.85319328], [75.37458038, 11.85319328], [75.37458038, 11.85291767], [75.37431335, 11.85291958], [75.37431335, 11.8526392], [75.37401581, 11.8526392], [75.37401581, 11.85236073], [75.37319183, 11.85236073], [75.37319183, 11.8526392], [75.37264252, 11.8526392], [75.37264252, 11.85291958], [75.37208557, 11.85291767], [75.37208557, 11.85319328], [75.37180328, 11.85319328], [75.37180328, 11.85291767], [75.37097168, 11.85291767], [75.37097168, 11.85319328], [75.37069702, 11.85319328], [75.37069702, 11.85291767], [75.37014008, 11.85291958], [75.37014008, 11.8526392], [75.36971283, 11.8526392], [75.36930847, 11.8526392], [75.36930847, 11.85236073], [75.36875153, 11.85236073], [75.36875153, 11.8520813], [75.36819458, 11.85208321], [75.36819458, 11.85180473], [75.36763763, 11.85181046], [75.36763763, 11.85125065], [75.36680603, 11.85125065], [75.36680603, 11.85181046], [75.36653137, 11.85180473], [75.36653137, 11.85208321], [75.36624908, 11.8520813], [75.36624908, 11.85236073], [75.3659668, 11.85236073], [75.3659668, 11.8526392], [75.36569214, 11.8526392], [75.36569214, 11.85236073], [75.36485291, 11.85236073], [75.36485291, 11.85291958], [75.36458588, 11.85291767], [75.36458588, 11.85319328], [75.36430359, 11.85319328], [75.36430359, 11.8534708], [75.36402893, 11.85346889], [75.36402893, 11.85374928], [75.36374664, 11.85374928], [75.36374664, 11.85486221], [75.36347198, 11.85485935], [75.36347198, 11.85542011], [75.36319733, 11.85541534], [75.36319733, 11.85569572], [75.36347198, 11.85569572], [75.36347198, 11.85624981], [75.36319733, 11.85624981], [75.36319733, 11.85653019], [75.36292267, 11.85653019], [75.36292267, 11.85680962], [75.36235809, 11.85680962], [75.36235809, 11.85653019], [75.36152649, 11.85653019], [75.36152649, 11.85680962], [75.36096954, 11.85680962], [75.36096954, 11.85736179], [75.36068726, 11.85736179], [75.36068726, 11.85791969], [75.36042023, 11.85791779], [75.36042023, 11.85819435], [75.36013794, 11.85819435], [75.36013794, 11.85847187], [75.35986328, 11.85847187], [75.35986328, 11.85875034], [75.35958099, 11.85875034], [75.35958099, 11.85902977], [75.35874939, 11.85902977], [75.35874939, 11.85931015], [75.35819244, 11.85930634], [75.35819244, 11.85958385], [75.35541534, 11.85958385], [75.35541534, 11.85986233], [75.35514069, 11.85986042], [75.35514069, 11.86236], [75.3548584, 11.86236], [75.3548584, 11.86347198], [75.35457611, 11.86347008], [75.35457611, 11.86431122], [75.35430908, 11.86430645], [75.35430908, 11.86486244], [75.35402679, 11.86485958], [75.35402679, 11.8654213], [75.35375214, 11.86541557], [75.35375214, 11.86597157], [75.35346985, 11.86596107], [75.35346985, 11.86625004], [75.3529129, 11.86625004], [75.3529129, 11.8668108], [75.35263824, 11.86680698], [75.35263824, 11.86708546], [75.35235596, 11.86707973], [75.35235596, 11.86792088], [75.35263824, 11.86791706], [75.35263824, 11.86819458], [75.3529129, 11.86819458], [75.3529129, 11.86958313], [75.35263824, 11.86958027], [75.35263824, 11.86986065], [75.35235596, 11.86986065], [75.35235596, 11.87014103], [75.3520813, 11.87014103], [75.3520813, 11.87125111], [75.35151672, 11.87125111], [75.35151672, 11.87153053], [75.35124969, 11.87153053], [75.35124969, 11.87181187], [75.35097504, 11.87180519], [75.35097504, 11.87236118], [75.35069275, 11.87236118], [75.35069275, 11.87264061], [75.35041809, 11.8726387], [75.35041809, 11.87319469], [75.3501358, 11.87318993], [75.3501358, 11.87375069], [75.34958649, 11.87375069], [75.34958649, 11.87403107], [75.3493042, 11.87402916], [75.3493042, 11.87458324], [75.34902954, 11.87458134], [75.34902954, 11.87514973], [75.34874725, 11.87514973], [75.34874725, 11.87542152], [75.3484726, 11.87542152], [75.3484726, 11.87597084], [75.34819794, 11.87597084], [75.34819794, 11.87625122], [75.34764099, 11.87625122], [75.34764099, 11.8765316], [75.3473587, 11.8765316], [75.3473587, 11.87681198], [75.34708405, 11.87680531], [75.34708405, 11.8773613], [75.34680939, 11.8773613], [75.34680939, 11.87764168], [75.34625244, 11.87763882], [75.34625244, 11.87819481], [75.34597015, 11.87819099], [75.34597015, 11.87874889], [75.34570313, 11.87874889], [75.34570313, 11.87930965], [75.34541321, 11.87930489], [75.34541321, 11.87958336], [75.34513855, 11.87958145], [75.34513855, 11.8801403], [75.3445816, 11.8801403], [75.3445816, 11.88041973], [75.34430695, 11.88041782], [75.34430695, 11.88097095], [75.34401703, 11.88096046], [75.34401703, 11.88152981], [75.34375, 11.88152981], [75.34375, 11.88181019], [75.34347534, 11.88180637], [75.34347534, 11.88208389], [75.34319305, 11.88208389], [75.34319305, 11.88236237], [75.3429184, 11.88235855], [75.3429184, 11.88292027], [75.34263611, 11.88291645], [75.34263611, 11.88319111], [75.34236145, 11.88319588], [75.34236145, 11.88347244], [75.34208679, 11.88347244], [75.34208679, 11.88375187], [75.34152985, 11.88375187], [75.34152985, 11.88403034], [75.34124756, 11.88402843], [75.34124756, 11.88458443], [75.3409729, 11.88458157], [75.3409729, 11.88514042], [75.34069824, 11.88514042], [75.34069824, 11.88541985], [75.34041595, 11.88541794], [75.34041595, 11.88569355], [75.34069824, 11.88569355], [75.34069824, 11.88597202], [75.3401413, 11.88597202], [75.3401413, 11.88652992], [75.33957672, 11.88652992], [75.33957672, 11.88681126], [75.33930206, 11.88680553], [75.33930206, 11.88736153], [75.3390274, 11.88735962], [75.3390274, 11.88764], [75.33875275, 11.88764], [75.33875275, 11.88819408], [75.3381958, 11.88819408], [75.3381958, 11.8884716], [75.33790588, 11.8884697], [75.33790588, 11.88903046], [75.33763885, 11.88903046], [75.33763885, 11.88931084], [75.3373642, 11.88930607], [75.3373642, 11.88958359], [75.33708191, 11.88958359], [75.33708191, 11.89013767], [75.33680725, 11.890131], [75.33680725, 11.89042091], [75.33652496, 11.89041615], [75.33652496, 11.89069366], [75.33625031, 11.89069366], [75.33625031, 11.89097214], [75.33598328, 11.89097023], [75.33598328, 11.89124966], [75.33569336, 11.89124966], [75.33569336, 11.89208221], [75.3354187, 11.89208031], [75.3354187, 11.89235973], [75.33513641, 11.89235973], [75.33513641, 11.89264107], [75.33486176, 11.89263821], [75.33486176, 11.8931942], [75.33429718, 11.89319038], [75.33429718, 11.89375114], [75.33403015, 11.89375114], [75.33403015, 11.89403057], [75.33347321, 11.89402866], [75.33347321, 11.89458466], [75.33319092, 11.89458179], [75.33319092, 11.89514065], [75.33291626, 11.89514065], [75.33291626, 11.89542103], [75.33235931, 11.89542103], [75.33235931, 11.89625072], [75.33207703, 11.89625072], [75.33207703, 11.89653111], [75.33181, 11.89653111], [75.33181, 11.89681053], [75.33152771, 11.89680672], [75.33152771, 11.8973608], [75.33125305, 11.8973608], [75.33125305, 11.89764118], [75.33097076, 11.89764118], [75.33097076, 11.89792061], [75.33069611, 11.89791679], [75.33069611, 11.89819527], [75.33041382, 11.89819527], [75.33041382, 11.89847279], [75.33013916, 11.89847088], [75.33013916, 11.89875126], [75.32930756, 11.89875126], [75.32930756, 11.89903069], [75.3290329, 11.89903069], [75.3290329, 11.8993206], [75.32875061, 11.89930534], [75.32875061, 11.89986134], [75.32818604, 11.89986134], [75.32818604, 11.90013885], [75.32763672, 11.90013885], [75.32763672, 11.90069485], [75.32707977, 11.90069008], [75.32707977, 11.90125084], [75.32681274, 11.90125084], [75.32681274, 11.90152931], [75.32624817, 11.9015274], [75.32624817, 11.9020834], [75.32596588, 11.90207195], [75.32596588, 11.90236092], [75.32567596, 11.90236092], [75.32567596, 11.90292168], [75.32541656, 11.90291691], [75.32541656, 11.90319538], [75.32514191, 11.90319538], [75.32514191, 11.90347099], [75.32485962, 11.90347099], [75.32485962, 11.90375137], [75.32290649, 11.90375137], [75.32290649, 11.90402889], [75.32235718, 11.90402889], [75.32235718, 11.90431023], [75.32180786, 11.90430546], [75.32180786, 11.90458298], [75.32069397, 11.90458298], [75.32069397, 11.90486145], [75.32041931, 11.90486145], [75.32041931, 11.90513897], [75.31986237, 11.90513897], [75.31986237, 11.90486145], [75.31960297, 11.90486145], [75.31903076, 11.90486145], [75.31903076, 11.90513897], [75.31846619, 11.90513039], [75.31846619, 11.9054203], [75.31819153, 11.90541744], [75.31819153, 11.90597439], [75.31847382, 11.90597439], [75.31846619, 11.9064703], [75.31846619, 11.90680981], [75.31835938, 11.90680504], [75.31819153, 11.90680504], [75.31819153, 11.9073], [75.31819153, 11.90764046], [75.31807709, 11.90764046], [75.31791687, 11.90764046], [75.31791687, 11.90812016], [75.31791687, 11.90847111], [75.31846619, 11.9084692], [75.31846619, 11.90874958], [75.31874847, 11.90874958], [75.31874847, 11.90931034], [75.31903076, 11.90931034], [75.31903076, 11.90986156], [75.31931305, 11.90986156], [75.31931305, 11.91014194], [75.31958008, 11.91014004], [75.31958008, 11.91069412], [75.31987, 11.91069126], [75.31987, 11.9112606], [75.32013702, 11.9112606], [75.32013702, 11.91152954], [75.31986237, 11.91152763], [75.31986237, 11.9131937], [75.31958008, 11.9131918], [75.31958008, 11.91403008], [75.31930542, 11.91402817], [75.31930542, 11.91458416], [75.31903076, 11.91458035], [75.31903076, 11.91514015], [75.31874847, 11.91514015], [75.31874847, 11.91597176], [75.31846619, 11.91596985], [75.31846619, 11.91625023], [75.31819153, 11.91625023], [75.31819153, 11.91681099], [75.31791687, 11.91680622], [75.31791687, 11.91736221], [75.31764221, 11.91736031], [75.31764221, 11.91763973], [75.31735992, 11.91763783], [75.31735992, 11.91819382], [75.3170929, 11.91819191], [75.3170929, 11.91875267], [75.31680298, 11.91875267], [75.31680298, 11.91903114], [75.31652832, 11.91903114], [75.31652832, 11.91931057], [75.31625366, 11.9193058], [75.31625366, 11.91958237], [75.31597137, 11.91958046], [75.31597137, 11.91986275], [75.31569672, 11.91986275], [75.31569672, 11.92042065], [75.31541443, 11.92041588], [75.31541443, 11.92069435], [75.31513977, 11.92069435], [75.31513977, 11.92097282], [75.31485748, 11.92096996], [75.31485748, 11.92153072], [75.31458282, 11.92153072], [75.31458282, 11.9218111], [75.31430817, 11.92180443], [75.31430817, 11.92208195], [75.31402588, 11.92208195], [75.31402588, 11.92236137], [75.31373596, 11.92236137], [75.31373596, 11.92320156], [75.31346893, 11.92319489], [75.31346893, 11.92347336], [75.31318665, 11.92346954], [75.31318665, 11.92375088], [75.31291962, 11.92375088], [75.31291962, 11.92431068], [75.31263733, 11.92430687], [75.31263733, 11.92458344], [75.31236267, 11.92457962], [75.31236267, 11.92486095], [75.31208038, 11.92486095], [75.31208038, 11.92514133], [75.31181335, 11.92514133], [75.31181335, 11.92542076], [75.31153107, 11.92541695], [75.31153107, 11.92597294], [75.31124878, 11.92597103], [75.31124878, 11.92625999], [75.31096649, 11.92625999], [75.31096649, 11.92680931], [75.31069183, 11.92680454], [75.31069183, 11.92736053], [75.31041718, 11.92736053], [75.31041718, 11.92764091], [75.31014252, 11.92764091], [75.31014252, 11.92791939], [75.30986023, 11.92791653], [75.30986023, 11.92847347], [75.3095932, 11.92847061], [75.3095932, 11.92875099], [75.30930328, 11.92875099], [75.30930328, 11.92903233], [75.30902863, 11.9290266], [75.30902863, 11.9295826], [75.30874634, 11.92958069], [75.30874634, 11.93014145], [75.30847168, 11.93014145], [75.30847168, 11.93042183], [75.30819702, 11.93041706], [75.30819702, 11.93069458], [75.30791473, 11.93069458], [75.30791473, 11.93097115], [75.30764008, 11.93097115], [75.30764008, 11.93153191], [75.30735779, 11.93152714], [75.30735779, 11.93208313], [75.30719757, 11.93208313], [75.30708313, 11.93208313], [75.30706787, 11.93247986], [75.30706024, 11.93264198], [75.30680847, 11.93263912], [75.30680847, 11.9327898], [75.30680847, 11.93319321], [75.30652618, 11.9331913], [75.30652618, 11.9337492], [75.30636597, 11.9337492], [75.30625153, 11.9337492], [75.30625153, 11.9342804], [75.30596924, 11.93430519], [75.30596924, 11.93486214], [75.30568695, 11.93485928], [75.30568695, 11.93513966], [75.30541992, 11.93513966], [75.30541992, 11.93543053], [75.30513763, 11.93541527], [75.30513763, 11.93569565], [75.30486298, 11.93569565], [75.30486298, 11.93597221], [75.30458069, 11.93596935], [75.30458069, 11.93653202], [75.30430603, 11.93653202], [75.30430603, 11.93680954], [75.30403137, 11.93680573], [75.30403137, 11.9370842], [75.30347443, 11.9370842], [75.30347443, 11.93736172], [75.30319214, 11.93735886], [75.30319214, 11.93764019], [75.30291748, 11.93764019], [75.30291748, 11.93791962], [75.30263519, 11.93791771], [75.30264282, 11.93875027], [75.30236053, 11.93875027], [75.30236053, 11.93902969], [75.30179596, 11.93902969], [75.30179596, 11.93931007], [75.30152893, 11.93930626], [75.30152893, 11.93958378], [75.30097198, 11.93958378], [75.30097198, 11.93986225], [75.30069733, 11.93986225], [75.30069733, 11.94069386], [75.30041504, 11.94069386], [75.30041504, 11.94124985], [75.30014038, 11.94124126], [75.30014038, 11.94153023], [75.29985809, 11.94153023], [75.29985809, 11.9426403], [75.29930878, 11.9426403], [75.29930878, 11.94292068], [75.29902649, 11.94291592], [75.29902649, 11.94347191], [75.29873657, 11.94347], [75.29873657, 11.94375038], [75.29930878, 11.94375038], [75.29930878, 11.94403267], [75.29985809, 11.9440279], [75.29985809, 11.94430637], [75.30069733, 11.94430637], [75.30069733, 11.94458199], [75.30124664, 11.94458199], [75.30124664, 11.94514275], [75.30179596, 11.94514275], [75.30179596, 11.94542122], [75.30208588, 11.94541645], [75.30208588, 11.94597244], [75.30236053, 11.94596958], [75.30236053, 11.94624996], [75.30291748, 11.94624996], [75.30291748, 11.94681072], [75.30319214, 11.94680691], [75.30319214, 11.94708538], [75.30541992, 11.94708538], [75.30541992, 11.94680691], [75.30596924, 11.94681072], [75.30596924, 11.9465313], [75.30652618, 11.9465313], [75.30652618, 11.94624996], [75.30735779, 11.94624996], [75.30735779, 11.94596958], [75.30902863, 11.94597244], [75.30902863, 11.94569397], [75.30958557, 11.94569397], [75.30958557, 11.94541645], [75.31041718, 11.94542122], [75.31041718, 11.94514275], [75.31096649, 11.94514275], [75.31096649, 11.94486046], [75.31153107, 11.94486237], [75.31153107, 11.94458199], [75.31208038, 11.94458199], [75.31208038, 11.94430637], [75.31291962, 11.94430637], [75.31291962, 11.9440279], [75.31346893, 11.94403267], [75.31346893, 11.94375038], [75.31402588, 11.94375038], [75.31402588, 11.94347], [75.31458282, 11.94347191], [75.31458282, 11.94319439], [75.31485748, 11.94319439], [75.31485748, 11.94291592], [75.3154068, 11.94292068], [75.3154068, 11.9426403], [75.31597137, 11.9426403], [75.31597137, 11.94235992], [75.31652832, 11.94235992], [75.31652832, 11.94207954], [75.31708527, 11.94208431], [75.31708527, 11.94180584], [75.31764221, 11.94181061], [75.31764221, 11.94153023], [75.31819153, 11.94153023], [75.31819153, 11.94124126], [75.31903076, 11.94124985], [75.31903076, 11.94097233], [75.31958008, 11.94097233], [75.31958008, 11.94069386], [75.32041931, 11.94069386], [75.32041931, 11.94041634], [75.32096863, 11.94042015], [75.32096863, 11.94013977], [75.32180786, 11.94013977], [75.32180786, 11.93986034], [75.32236481, 11.93986225], [75.32236481, 11.93958378], [75.32291412, 11.93958378], [75.32291412, 11.93930626], [75.32347107, 11.93931007], [75.32347107, 11.93902969], [75.32402802, 11.93902969], [75.32402802, 11.93875027], [75.32459259, 11.93875027], [75.32458496, 11.93847179], [75.32514191, 11.93847179], [75.32514191, 11.9382], [75.32596588, 11.9382], [75.32596588, 11.93791962], [75.32653046, 11.93791962], [75.32653046, 11.93764019], [75.32707977, 11.93764019], [75.32707977, 11.93735886], [75.32763672, 11.93736172], [75.32763672, 11.9370842], [75.32819366, 11.9370842], [75.32819366, 11.93680573], [75.32875061, 11.93680954], [75.32875061, 11.93653202], [75.32930756, 11.93653202], [75.32930756, 11.93624973], [75.33013916, 11.93624973], [75.33013916, 11.93596935], [75.33152771, 11.93597221], [75.33152771, 11.93569565], [75.33235931, 11.93569565], [75.33235931, 11.93541527], [75.33291626, 11.93543053], [75.33291626, 11.93513966], [75.33347321, 11.93513966], [75.33347321, 11.93485928], [75.33403015, 11.93486214], [75.33403015, 11.93458366], [75.33430481, 11.93458366], [75.33430481, 11.93430519], [75.33486938, 11.93430996], [75.33486938, 11.93402958], [75.3354187, 11.93402958], [75.3354187, 11.9337492], [75.33625031, 11.9337492], [75.33625031, 11.93347073], [75.33680725, 11.93347359], [75.33680725, 11.93291664], [75.33735657, 11.93292046], [75.33735657, 11.93264198], [75.33763885, 11.93264198], [75.33763885, 11.93236065], [75.33875275, 11.93236065], [75.33875275, 11.93208122], [75.33985901, 11.93208313], [75.33985901, 11.93180466], [75.34152985, 11.93181038], [75.34152985, 11.93153191], [75.34358978, 11.93153191], [75.34513855, 11.93153191], [75.34513855, 11.93181038], [75.3456955, 11.93180466], [75.3456955, 11.93208313], [75.34597015, 11.93208313], [75.34597015, 11.93180466], [75.34625244, 11.93181038], [75.34625244, 11.93153191], [75.34680939, 11.93153191], [75.34680939, 11.93125057], [75.34707642, 11.93125057], [75.34707642, 11.93069077], [75.3473587, 11.93069458], [75.3473587, 11.93013859], [75.34792328, 11.93014145], [75.34792328, 11.93042183], [75.3501358, 11.93041706], [75.3501358, 11.93069458], [75.35124969, 11.93069458], [75.35124969, 11.93097115], [75.3520813, 11.93097115], [75.3520813, 11.93125057], [75.35263824, 11.93125057], [75.35263824, 11.93153191], [75.3529129, 11.93153191], [75.3529129, 11.93125057], [75.35346985, 11.93125057], [75.35346985, 11.93097115], [75.35375214, 11.93097115], [75.35375214, 11.93069458], [75.35430908, 11.93069458], [75.35430908, 11.93013859], [75.3548584, 11.93014145], [75.3548584, 11.92986107], [75.35514069, 11.92986107], [75.35514069, 11.92930031], [75.35569763, 11.92930508], [75.35569763, 11.9290266], [75.35624695, 11.92903233], [75.35624695, 11.92875099], [75.35652924, 11.92875099], [75.35652924, 11.92847061], [75.35874939, 11.92847061], [75.35874939, 11.92875099], [75.35930634, 11.92875099], [75.35930634, 11.92903233], [75.35958099, 11.92903233], [75.35958099, 11.92875099], [75.35986328, 11.92875099], [75.35986328, 11.92903233], [75.36042023, 11.9290266], [75.36042023, 11.92930508], [75.36152649, 11.92930508], [75.36152649, 11.9295826], [75.36235809, 11.92958069], [75.36235809, 11.92986107], [75.36264038, 11.92986107], [75.36264038, 11.93014145], [75.36347198, 11.93014145], [75.36347198, 11.93042183], [75.36402893, 11.93041706], [75.36402893, 11.93097115], [75.36429596, 11.93097115], [75.36429596, 11.93153191], [75.36486053, 11.93152714], [75.36486053, 11.93208313], [75.36513519, 11.93208313], [75.36513519, 11.93236065], [75.36541748, 11.93236065], [75.36541748, 11.93347359], [75.36569214, 11.93347073], [75.36569214, 11.9337492], [75.3659668, 11.9337492], [75.3659668, 11.93430996], [75.36624908, 11.93430996], [75.36624908, 11.93513966], [75.36653137, 11.93513966], [75.36653137, 11.93569565], [75.36708069, 11.93569565], [75.36708069, 11.93597221], [75.36763763, 11.93596935], [75.36763763, 11.93624973], [75.36791992, 11.93624973], [75.36791992, 11.93653202], [75.36818695, 11.93653202], [75.36818695, 11.93680954], [75.36846924, 11.93680954], [75.36846924, 11.93791962], [75.36875153, 11.93791962], [75.36875153, 11.9382], [75.36930847, 11.9382], [75.36930847, 11.93847179], [75.36985779, 11.93847179], [75.36985779, 11.93875027], [75.37014008, 11.93875027], [75.37014008, 11.93902969], [75.3704071, 11.93902969], [75.3704071, 11.93931007], [75.37152863, 11.93930626], [75.37152863, 11.93958378], [75.37208557, 11.93958378], [75.37208557, 11.93930626], [75.37264252, 11.93931007], [75.37264252, 11.93902969], [75.37374878, 11.93902969], [75.37374878, 11.93875027], [75.37401581, 11.93875027], [75.37401581, 11.93847179], [75.37458038, 11.93847179], [75.37458038, 11.9382], [75.37486267, 11.9382], [75.37486267, 11.93791962], [75.37513733, 11.93791962], [75.37513733, 11.93735886], [75.37541962, 11.93736172], [75.37541962, 11.93624973], [75.37513733, 11.93624973], [75.37513733, 11.93569088], [75.37569427, 11.93569565], [75.37569427, 11.93458366], [75.37596893, 11.93458366], [75.37596893, 11.93291664], [75.37625122, 11.93292046], [75.37625122, 11.93125057], [75.37652588, 11.93125057], [75.37652588, 11.93069077], [75.37680817, 11.93069458], [75.37680817, 11.92986107], [75.37708282, 11.92986107], [75.37708282, 11.92903233], [75.37735748, 11.92903233], [75.37735748, 11.92819118], [75.37763977, 11.928195], [75.37763977, 11.92736053], [75.37819672, 11.92736053], [75.37819672, 11.92680454], [75.37847137, 11.92680931], [75.37847137, 11.92653084], [75.3795929, 11.92653084], [75.3795929, 11.92625999], [75.38153076, 11.92625999], [75.38153076, 11.92653084], [75.38263702, 11.92653084], [75.38263702, 11.92680931], [75.38318634, 11.92680931], [75.38318634, 11.92653084], [75.3840332, 11.92653084], [75.3840332, 11.92625999], [75.38430786, 11.92625999], [75.38430786, 11.92597103], [75.38486481, 11.92597294], [75.38486481, 11.92569542], [75.38541412, 11.92569542], [75.38541412, 11.92486095], [75.38513947, 11.92486095], [75.38513947, 11.92375088], [75.38485718, 11.92375088], [75.38485718, 11.9226408], [75.38458252, 11.9226408], [75.38458252, 11.9218111], [75.38430786, 11.9218111], [75.38430786, 11.9212513], [75.38458252, 11.9212513], [75.38458252, 11.92096996], [75.38430786, 11.92097282], [75.38430786, 11.92069435], [75.38458252, 11.92069435], [75.38458252, 11.91819382], [75.38486481, 11.91819382], [75.38486481, 11.91763783], [75.38513947, 11.91763973], [75.38513947, 11.91652966], [75.38625336, 11.91652966], [75.38625336, 11.91625023], [75.38652802, 11.91625023], [75.38652802, 11.91596985], [75.38708496, 11.91597176], [75.38708496, 11.91569424], [75.38764191, 11.91569424], [75.38764191, 11.91541576], [75.38791656, 11.91542053], [75.38791656, 11.91486168], [75.38846588, 11.91486168], [75.38846588, 11.91458035], [75.38931274, 11.91458035], [75.38931274, 11.91486168], [75.38957977, 11.91486168], [75.38957977, 11.91458035], [75.39013672, 11.91458035], [75.39013672, 11.91486168], [75.39125061, 11.91486168], [75.39125061, 11.91514015], [75.39208984, 11.91514015], [75.39208984, 11.91542053], [75.39319611, 11.91541576], [75.39319611, 11.91569424], [75.39375305, 11.91568947], [75.39375305, 11.91625023], [75.39430237, 11.91625023], [75.39430237, 11.91652966], [75.39514923, 11.91652966], [75.39514923, 11.91681099], [75.39569092, 11.91681099], [75.39569092, 11.91652966], [75.39624786, 11.91652966], [75.39624786, 11.91625023], [75.39679718, 11.91625023], [75.39679718, 11.91596985], [75.39763641, 11.91597176], [75.39763641, 11.91569424], [75.39819336, 11.91569424], [75.39819336, 11.91541576], [75.39930725, 11.91541576], [75.39930725, 11.91597176], [75.39958191, 11.91596985], [75.39958191, 11.91652966], [75.3998642, 11.91652775], [75.3998642, 11.91708374], [75.40013885, 11.91707134], [75.40013885, 11.91763973], [75.3998642, 11.91763783], [75.3998642, 11.91819382], [75.39958191, 11.91819191], [75.39958191, 11.91875267], [75.39930725, 11.91875267], [75.39930725, 11.91931057], [75.39902496, 11.9193058], [75.39902496, 11.91958237], [75.39847565, 11.91958237], [75.39847565, 11.9193058], [75.39763641, 11.91931057], [75.39763641, 11.91903114], [75.3970871, 11.91903114], [75.3970871, 11.91875267], [75.39653015, 11.91875267], [75.39653015, 11.91903114], [75.39485931, 11.91903114], [75.39485931, 11.91931057], [75.39458466, 11.9193058], [75.39458466, 11.91958237], [75.39263916, 11.91958237], [75.39263916, 11.9193058], [75.39208984, 11.91931057], [75.39208984, 11.91875267], [75.3915329, 11.91875267], [75.3915329, 11.91847038], [75.39097595, 11.91847229], [75.39097595, 11.91819382], [75.39013672, 11.91819382], [75.39013672, 11.9179163], [75.38986206, 11.91792107], [75.38986206, 11.91763973], [75.38957977, 11.91763973], [75.38957977, 11.91792107], [75.38931274, 11.91792107], [75.38931274, 11.91903114], [75.38957977, 11.91903114], [75.38957977, 11.91986275], [75.38986206, 11.91985989], [75.38986206, 11.92097282], [75.39013672, 11.92096996], [75.39013672, 11.92292118], [75.39041901, 11.92291737], [75.39041901, 11.92347336], [75.39068604, 11.92346954], [75.39068604, 11.92375088], [75.39097595, 11.92375088], [75.39097595, 11.92431068], [75.39125061, 11.92430687], [75.39125061, 11.92458344], [75.39097595, 11.92457962], [75.39097595, 11.92486095], [75.39125061, 11.92486095], [75.39125061, 11.92542076], [75.39097595, 11.92541695], [75.39097595, 11.92597294], [75.39068604, 11.92597103], [75.39068604, 11.92680931], [75.39041901, 11.92680454], [75.39041901, 11.92736053], [75.39013672, 11.92736053], [75.39013672, 11.92791939], [75.38986206, 11.92791939], [75.38986206, 11.92875099], [75.38957977, 11.92875099], [75.38957977, 11.92903233], [75.38903046, 11.9290266], [75.38903046, 11.9295826], [75.38874817, 11.92958069], [75.38874817, 11.92986107], [75.38819122, 11.92986107], [75.38819122, 11.93014145], [75.38764191, 11.93014145], [75.38764191, 11.93042183], [75.38652802, 11.93041706], [75.38652802, 11.93069458], [75.38625336, 11.93069458], [75.38625336, 11.93097115], [75.38595581, 11.93097115], [75.38595581, 11.93125057], [75.38485718, 11.93125057], [75.38485718, 11.93153191], [75.38458252, 11.93153191], [75.38458252, 11.93125057], [75.38375092, 11.93125057], [75.38375092, 11.93097115], [75.38319397, 11.93097115], [75.38319397, 11.93069458], [75.38263702, 11.93069458], [75.38263702, 11.93041706], [75.38181305, 11.93042183], [75.38181305, 11.93014145], [75.38124847, 11.93014145], [75.38124847, 11.92986107], [75.38014984, 11.92986107], [75.38014984, 11.93014145], [75.37875366, 11.93013859], [75.37875366, 11.93069458], [75.37847137, 11.93069077], [75.37847137, 11.93236065], [75.37875366, 11.93236065], [75.37875366, 11.93486214], [75.37847137, 11.93485928], [75.37847137, 11.93543053], [75.37819672, 11.93543053], [75.37819672, 11.93931007], [75.37791443, 11.93930626], [75.37791443, 11.93958378], [75.37763977, 11.93958378], [75.37763977, 11.93986225], [75.37708282, 11.93986034], [75.37708282, 11.94013977], [75.37680817, 11.94013977], [75.37680817, 11.94042015], [75.37625122, 11.94041634], [75.37625122, 11.94069386], [75.37569427, 11.94069386], [75.37569427, 11.94097233], [75.37541962, 11.94097233], [75.37541962, 11.94124985], [75.37486267, 11.94124126], [75.37486267, 11.94181061], [75.37319183, 11.94180584], [75.37319183, 11.94208431], [75.37291718, 11.94207954], [75.37291718, 11.94403267], [75.37264252, 11.94403267], [75.37264252, 11.94681072], [75.37291718, 11.94681072], [75.37291718, 11.94764137], [75.37319183, 11.94763756], [75.37319183, 11.94847298], [75.37346649, 11.94847012], [75.37346649, 11.94903088], [75.37374878, 11.94903088], [75.37374878, 11.95014095], [75.37401581, 11.95014095], [75.37401581, 11.95042992], [75.37374878, 11.95041656], [75.37374878, 11.95069504], [75.37401581, 11.95069027], [75.37401581, 11.95181084], [75.37431335, 11.95181084], [75.37431335, 11.95375061], [75.37458038, 11.9537487], [75.37458038, 11.95569515], [75.37486267, 11.95569134], [75.37486267, 11.95653152], [75.37458038, 11.95653152], [75.37458038, 11.9568119], [75.37430573, 11.95680523], [75.37430573, 11.95708275], [75.37374878, 11.95708275], [75.37374878, 11.95736122], [75.37347412, 11.95736122], [75.37347412, 11.95680523], [75.37319183, 11.9568119], [75.37319183, 11.95597076], [75.37291718, 11.95597267], [75.37291718, 11.95569515], [75.37264252, 11.95569515], [75.37264252, 11.95541668], [75.37236023, 11.95541859], [75.37236023, 11.95458126], [75.37208557, 11.95458317], [75.37208557, 11.95402908], [75.37180328, 11.95403099], [75.37180328, 11.95347118], [75.37152863, 11.95347309], [75.37152863, 11.95319462], [75.37124634, 11.95319462], [75.37124634, 11.9529171], [75.37097931, 11.95292091], [75.37097931, 11.95264053], [75.37069702, 11.95264053], [75.37069702, 11.95207977], [75.37041473, 11.95208263], [75.37041473, 11.95180511], [75.37014008, 11.95181084], [75.37014008, 11.95125103], [75.36958313, 11.95125103], [75.36958313, 11.95069027], [75.36930847, 11.95069504], [75.36930847, 11.95041656], [75.36902618, 11.95042992], [75.36902618, 11.95014095], [75.36846924, 11.95014095], [75.36846924, 11.94986057], [75.36791992, 11.94986057], [75.36791992, 11.94958305], [75.36763763, 11.94958305], [75.36763763, 11.94930363], [75.36708069, 11.94931126], [75.36708069, 11.94903088], [75.36680603, 11.94903088], [75.36680603, 11.94875145], [75.36653137, 11.94875145], [75.36653137, 11.94847012], [75.36597443, 11.94847298], [75.36597443, 11.94819546], [75.36569214, 11.94819546], [75.36569214, 11.94791603], [75.36514282, 11.94791889], [75.36514282, 11.94736862], [75.36458588, 11.94736862], [75.36458588, 11.94681072], [75.36429596, 11.94681072], [75.36429596, 11.9465313], [75.36402893, 11.9465313], [75.36402893, 11.94624996], [75.36374664, 11.94624996], [75.36374664, 11.94596958], [75.36347198, 11.94597244], [75.36347198, 11.94541645], [75.36319733, 11.94542122], [75.36319733, 11.94486046], [75.36291504, 11.94486237], [75.36291504, 11.94430637], [75.36264038, 11.94430637], [75.36264038, 11.94347191], [75.36235809, 11.94347191], [75.36235809, 11.94235992], [75.36207581, 11.94235992], [75.36207581, 11.94153023], [75.36180878, 11.94153023], [75.36180878, 11.94097042], [75.36152649, 11.94097233], [75.36152649, 11.94069386], [75.36180878, 11.94069386], [75.36180878, 11.93819427], [75.36207581, 11.9382], [75.36207581, 11.93543053], [75.36180878, 11.93543053], [75.36180878, 11.93430996], [75.36152649, 11.93430996], [75.36152649, 11.9337492], [75.36125183, 11.9337492], [75.36125183, 11.93347073], [75.36096954, 11.93347359], [75.36096954, 11.93319321], [75.36042023, 11.93319321], [75.36042023, 11.93263912], [75.36013794, 11.93264198], [75.36013794, 11.93236065], [75.35958099, 11.93236065], [75.35958099, 11.93208122], [75.35930634, 11.93208313], [75.35930634, 11.93180466], [75.35874939, 11.93181038], [75.35874939, 11.93153191], [75.35708618, 11.93153191], [75.35708618, 11.93125057], [75.35679626, 11.93125057], [75.35679626, 11.93153191], [75.35569763, 11.93153191], [75.35569763, 11.93181038], [75.35541534, 11.93180466], [75.35541534, 11.93208313], [75.3548584, 11.93208122], [75.3548584, 11.93236065], [75.35430908, 11.93236065], [75.35430908, 11.93264198], [75.35346985, 11.93264198], [75.35346985, 11.93292046], [75.3529129, 11.93291664], [75.3529129, 11.93319321], [75.3520813, 11.93319321], [75.3520813, 11.93347359], [75.35069275, 11.93347073], [75.35069275, 11.9337492], [75.35041809, 11.9337492], [75.35041809, 11.93402958], [75.34958649, 11.93402958], [75.34958649, 11.93430996], [75.3484726, 11.93430519], [75.3484726, 11.93458366], [75.34708405, 11.93458366], [75.34708405, 11.93486214], [75.3465271, 11.93485928], [75.3465271, 11.93513966], [75.34570313, 11.93513966], [75.34570313, 11.93543053], [75.34513855, 11.93541527], [75.34513855, 11.93569565], [75.34430695, 11.93569565], [75.34430695, 11.93597221], [75.34375, 11.93596935], [75.34375, 11.93624973], [75.34319305, 11.93624973], [75.34319305, 11.93653202], [75.3429184, 11.93653202], [75.3429184, 11.93680954], [75.34263611, 11.93680573], [75.34263611, 11.9370842], [75.34208679, 11.93708134], [75.34208679, 11.93764019], [75.34179688, 11.93764019], [75.34179688, 11.9382], [75.34124756, 11.9382], [75.34124756, 11.93847179], [75.3409729, 11.93847179], [75.3409729, 11.93875027], [75.34069824, 11.93875027], [75.34069824, 11.93902969], [75.34041595, 11.93902969], [75.34041595, 11.93931007], [75.3401413, 11.93930626], [75.3401413, 11.93958378], [75.33958435, 11.93958378], [75.33958435, 11.93986225], [75.33930206, 11.93986034], [75.33930206, 11.94013977], [75.3390274, 11.94013977], [75.3390274, 11.94042015], [75.33847046, 11.94041634], [75.33847046, 11.94069386], [75.33791351, 11.94069386], [75.33791351, 11.94124985], [75.33763885, 11.94124126], [75.33763885, 11.94153023], [75.33735657, 11.94153023], [75.33735657, 11.94181061], [75.33708191, 11.94180584], [75.33708191, 11.94208431], [75.33680725, 11.94207954], [75.33680725, 11.94235992], [75.33653259, 11.94235992], [75.33653259, 11.9426403], [75.33598328, 11.9426403], [75.33598328, 11.94292068], [75.33569336, 11.94291592], [75.33569336, 11.94319439], [75.3354187, 11.94319439], [75.3354187, 11.94347191], [75.3345871, 11.94347], [75.3345871, 11.94375038], [75.33347321, 11.94375038], [75.33347321, 11.94403267], [75.33235931, 11.9440279], [75.33235931, 11.94430637], [75.32875061, 11.94430637], [75.32875061, 11.9440279], [75.32847595, 11.9440279], [75.32847595, 11.94430637], [75.32736206, 11.94430637], [75.32736206, 11.94458199], [75.32707977, 11.94458199], [75.32707977, 11.94430637], [75.32680511, 11.94430637], [75.32680511, 11.94458199], [75.32653046, 11.94458199], [75.32653046, 11.94430637], [75.32597351, 11.94430637], [75.32597351, 11.94458199], [75.32569122, 11.94458199], [75.32569122, 11.94486237], [75.32514191, 11.94486046], [75.32514191, 11.94514275], [75.32430267, 11.94514275], [75.32430267, 11.94542122], [75.32402802, 11.94542122], [75.32402802, 11.94514275], [75.32375336, 11.94514275], [75.32375336, 11.94542122], [75.32096863, 11.94541645], [75.32096863, 11.94569016], [75.31930542, 11.94569397], [75.31930542, 11.94597244], [75.31874847, 11.94596958], [75.31874847, 11.94624996], [75.31791687, 11.94624996], [75.31791687, 11.9465313], [75.31735992, 11.9465313], [75.31735992, 11.94681072], [75.31680298, 11.94680691], [75.31680298, 11.94708538], [75.31652832, 11.94707966], [75.31652832, 11.94764137], [75.3170929, 11.94764137], [75.3170929, 11.94791889], [75.31735992, 11.94791603], [75.31735992, 11.94847298], [75.31764221, 11.94847012], [75.31764221, 11.94903088], [75.31791687, 11.94903088], [75.31791687, 11.95125103], [75.31764221, 11.95125103], [75.31764221, 11.95208263], [75.31735992, 11.95208263], [75.31735992, 11.95236111], [75.3170929, 11.95236111], [75.3170929, 11.95264053], [75.31680298, 11.95264053], [75.31680298, 11.95292091], [75.31652832, 11.95292091], [75.31652832, 11.95375061], [75.31624603, 11.95375061], [75.31624603, 11.95403099], [75.31597137, 11.95402908], [75.31597137, 11.95569515], [75.31569672, 11.95569515], [75.31569672, 11.95597267], [75.3154068, 11.95597076], [75.3154068, 11.95653152], [75.31513977, 11.95653152], [75.31513977, 11.9568119], [75.31485748, 11.95680523], [75.31485748, 11.95708275], [75.31458282, 11.95708084], [75.31458282, 11.95792198], [75.31430817, 11.95791721], [75.31430817, 11.95819473], [75.31402588, 11.95819473], [75.31402588, 11.9584713], [75.31373596, 11.9584713], [75.31373596, 11.95903015], [75.31346893, 11.95903015], [75.31346893, 11.95930958], [75.31319427, 11.95930481], [75.31319427, 11.95958328], [75.31291962, 11.95958138], [75.31291962, 11.96013927], [75.31263733, 11.96013927], [75.31263733, 11.96069336], [75.31236267, 11.96069145], [75.31236267, 11.96124935], [75.31208038, 11.96124935], [75.31208038, 11.96237087], [75.31180573, 11.96236229], [75.31180573, 11.96347237], [75.31153107, 11.96347237], [75.31153107, 11.96375179], [75.31067657, 11.96375179], [75.31067657, 11.96403027], [75.31041718, 11.96403027], [75.31041718, 11.96430969], [75.31014252, 11.96430588], [75.31014252, 11.96569443], [75.31041718, 11.96569443], [75.31041718, 11.9673624], [75.31014252, 11.96735954], [75.31014252, 11.96763992], [75.30986023, 11.96763992], [75.30986023, 11.96903038], [75.30958557, 11.96902847], [75.3095932, 11.96986008], [75.30930328, 11.96986008], [75.30930328, 11.97007179], [75.30902863, 11.97014046], [75.30902863, 11.97042274], [75.3079071, 11.97042274], [75.3079071, 11.96986008], [75.30764008, 11.96986008], [75.30764008, 11.9695797], [75.30680847, 11.9695797], [75.30680847, 11.97014046], [75.30652618, 11.97014046], [75.30652618, 11.97042274], [75.30625153, 11.97041607], [75.30625153, 11.97069359], [75.30596924, 11.97069168], [75.30596924, 11.97124958], [75.30430603, 11.97124958], [75.30430603, 11.97097015], [75.30403137, 11.97097206], [75.30403137, 11.97069359], [75.30374908, 11.97069359], [75.30374908, 11.96875], [75.30486298, 11.96875], [75.30486298, 11.96903038], [75.30541992, 11.96903038], [75.30541992, 11.96846962], [75.30569458, 11.96847153], [75.30569458, 11.96791553], [75.30596924, 11.9679203], [75.30596924, 11.96763992], [75.30625153, 11.96763992], [75.30625153, 11.96735954], [75.30652618, 11.9673624], [75.30652618, 11.96708393], [75.30708313, 11.96708393], [75.30708313, 11.96680641], [75.30735779, 11.96681023], [75.30735779, 11.96652985], [75.30764008, 11.96652985], [75.30764008, 11.96625042], [75.3079071, 11.96625042], [75.3079071, 11.96541119], [75.30764008, 11.96541786], [75.30764008, 11.96514034], [75.30735779, 11.96514034], [75.30735779, 11.96486187], [75.30708313, 11.96486187], [75.30708313, 11.96458054], [75.30652618, 11.96458435], [75.30652618, 11.96430588], [75.30625153, 11.96430969], [75.30625153, 11.96375179], [75.30652618, 11.96375179], [75.30652618, 11.96319103], [75.30680847, 11.9631958], [75.30680847, 11.96291542], [75.30735779, 11.96292019], [75.30735779, 11.96263981], [75.30760956, 11.96263981], [75.30764008, 11.96237087], [75.30819702, 11.96237087], [75.30819702, 11.96208096], [75.30874634, 11.96208382], [75.30874634, 11.9618063], [75.31014252, 11.96181011], [75.31014252, 11.96152973], [75.31041718, 11.96152973], [75.31041718, 11.96041965], [75.31067657, 11.96041965], [75.31067657, 11.95985889], [75.31097412, 11.9598608], [75.31097412, 11.95930481], [75.31124878, 11.95930958], [75.31124878, 11.95903015], [75.31153107, 11.95903015], [75.31153107, 11.95875072], [75.31181335, 11.95875072], [75.31181335, 11.9584713], [75.31236267, 11.9584713], [75.31236267, 11.95819473], [75.31291962, 11.95819473], [75.31291962, 11.95763874], [75.31318665, 11.9576416], [75.31318665, 11.95736122], [75.31346893, 11.95736122], [75.31346893, 11.95708275], [75.31402588, 11.95708275], [75.31402588, 11.95680523], [75.31430817, 11.9568119], [75.31430817, 11.95541859], [75.31458282, 11.95541859], [75.31458282, 11.95430946], [75.31485748, 11.95430946], [75.31485748, 11.95375061], [75.31513977, 11.95375061], [75.31513977, 11.95207977], [75.31541443, 11.95208263], [75.31541443, 11.95180511], [75.31513977, 11.95181084], [75.31513977, 11.95125103], [75.31485748, 11.95125103], [75.31485748, 11.9509697], [75.31458282, 11.95097256], [75.31458282, 11.95069504], [75.31430817, 11.95069504], [75.31430817, 11.95013905], [75.31458282, 11.95014095], [75.31458282, 11.94986057], [75.31430817, 11.94986057], [75.31430817, 11.94958305], [75.31346893, 11.94958305], [75.31346893, 11.94986057], [75.31318665, 11.94986057], [75.31318665, 11.95042992], [75.31291962, 11.95041656], [75.31291962, 11.95097256], [75.31263733, 11.9509697], [75.31263733, 11.95125103], [75.31236267, 11.95125103], [75.31236267, 11.95153141], [75.31208038, 11.95153141], [75.31208038, 11.95181084], [75.31180573, 11.95180511], [75.31180573, 11.95208263], [75.31124878, 11.95208263], [75.31124878, 11.95236111], [75.30986023, 11.95236111], [75.30986023, 11.95264053], [75.30930328, 11.95264053], [75.30930328, 11.95236111], [75.3079071, 11.95236111], [75.3079071, 11.95264053], [75.30764008, 11.95264053], [75.30764008, 11.95292091], [75.30708313, 11.9529171], [75.30708313, 11.95319462], [75.30680847, 11.95318127], [75.30680847, 11.95375061], [75.30652618, 11.95375061], [75.30652618, 11.95430946], [75.30625153, 11.9543047], [75.30625153, 11.95458317], [75.30652618, 11.95458126], [75.30652618, 11.95486069], [75.30680847, 11.95486069], [75.30680847, 11.95708275], [75.30652618, 11.95708275], [75.30652618, 11.95736122], [75.30625153, 11.95736122], [75.30625153, 11.95792198], [75.30596924, 11.95791721], [75.30596924, 11.95819473], [75.30569458, 11.95819473], [75.30569458, 11.9584713], [75.30513763, 11.9584713], [75.30513763, 11.95903015], [75.30486298, 11.95903015], [75.30486298, 11.95930958], [75.30458069, 11.95930481], [75.30458069, 11.95958328], [75.30403137, 11.95958138], [75.30403137, 11.96013927], [75.30374908, 11.96013927], [75.30374908, 11.96069336], [75.30347443, 11.96069336], [75.30347443, 11.96097088], [75.30319214, 11.96097088], [75.30319214, 11.96152973], [75.30291748, 11.96152973], [75.30291748, 11.96263981], [75.30263519, 11.96263981], [75.30263519, 11.9631958], [75.30208588, 11.96319103], [75.30208588, 11.96375179], [75.30179596, 11.96375179], [75.30179596, 11.96403027], [75.30152893, 11.96403027], [75.30152893, 11.96430969], [75.30124664, 11.96430588], [75.30124664, 11.96458435], [75.30097198, 11.96458054], [75.30097198, 11.96486187], [75.30069733, 11.96486187], [75.30069733, 11.96541786], [75.30041504, 11.96541786], [75.30041504, 11.96569443], [75.30014038, 11.96569061], [75.30014038, 11.96625042], [75.29985809, 11.96625042], [75.29985809, 11.96681023], [75.29958344, 11.96680641], [75.29958344, 11.96708393], [75.29930878, 11.96708202], [75.29930878, 11.9679203], [75.29902649, 11.96791553], [75.29902649, 11.96819401], [75.29875183, 11.96819401], [75.29875183, 11.96847153], [75.29846954, 11.96846962], [75.29846954, 11.96875], [75.29819489, 11.96875], [75.29819489, 11.96958447], [75.29792023, 11.9695797], [75.29792023, 11.97014046], [75.29763794, 11.9701376], [75.29763794, 11.97097206], [75.29736328, 11.97097015], [75.29736328, 11.97124958], [75.29708099, 11.97124958], [75.29708099, 11.97154045], [75.29680634, 11.97154045], [75.29680634, 11.97181129], [75.29652405, 11.97180557], [75.29652405, 11.97236156], [75.29624939, 11.97235966], [75.29624939, 11.97292137], [75.29651642, 11.97292137], [75.29651642, 11.97375011], [75.29624939, 11.97375011], [75.29624939, 11.97403145], [75.29569244, 11.97402859], [75.29569244, 11.97458458], [75.29541779, 11.97458172], [75.29541779, 11.97514057], [75.2951355, 11.97513771], [75.2951355, 11.97569466], [75.29486084, 11.9756918], [75.29486084, 11.97625065], [75.29458618, 11.97625065], [75.29458618, 11.97653103], [75.29430389, 11.97652912], [75.29430389, 11.97708321], [75.29402924, 11.97708321], [75.29402924, 11.97736073], [75.29374695, 11.97736073], [75.29374695, 11.97819519], [75.29347229, 11.97819519], [75.29347229, 11.97847271], [75.29319763, 11.9784708], [75.29319763, 11.97875118], [75.29292297, 11.97875118], [75.29292297, 11.97931194], [75.29264069, 11.97931194], [75.29264069, 11.98014069], [75.2923584, 11.98013878], [75.2923584, 11.98069477], [75.29208374, 11.98069477], [75.29208374, 11.98097324], [75.29180908, 11.98097134], [75.29180908, 11.98236084], [75.29152679, 11.98236084], [75.29152679, 11.98264122], [75.29125214, 11.98264122], [75.29125214, 11.9829216], [75.28930664, 11.9829216], [75.28930664, 11.98348045], [75.28956604, 11.98348045], [75.28956604, 11.98431015], [75.28986359, 11.98430538], [75.28986359, 11.98486137], [75.29013824, 11.98486137], [75.29013824, 11.98513889], [75.29070282, 11.98513889], [75.29070282, 11.98542023], [75.29096985, 11.98541737], [75.29096985, 11.98569489], [75.29070282, 11.98569107], [75.29070282, 11.98625183], [75.2904129, 11.98625183], [75.2904129, 11.98680973], [75.29013824, 11.98680496], [75.29013824, 11.98708344], [75.28985596, 11.98708057], [75.28985596, 11.98736095], [75.28956604, 11.98736095], [75.28956604, 11.98791981], [75.28930664, 11.9879179], [75.28930664, 11.98819256], [75.28819275, 11.98819065], [75.28819275, 11.98874855], [75.28791809, 11.98874855], [75.28791809, 11.98903179], [75.2876358, 11.98902798], [75.2876358, 11.98958397], [75.28708649, 11.98958397], [75.28708649, 11.98986244], [75.28679657, 11.98986244], [75.28679657, 11.99014187], [75.28624725, 11.99014187], [75.28624725, 11.99042034], [75.2859726, 11.99042034], [75.2859726, 11.99014187], [75.28569794, 11.99014187], [75.28569794, 11.99042034], [75.28514099, 11.99041462], [75.28514099, 11.99069405], [75.28458405, 11.99069405], [75.28458405, 11.99097157], [75.28430939, 11.99097157], [75.28430176, 11.99125195], [75.28376007, 11.99125195], [75.28376007, 11.99153042], [75.28347015, 11.99153042], [75.28347015, 11.99180984], [75.2831955, 11.99180603], [75.2831955, 11.99236202], [75.28291321, 11.99234962], [75.28291321, 11.99291992], [75.28236389, 11.99291801], [75.28236389, 11.99319363], [75.2820816, 11.99318886], [75.2820816, 11.99374962], [75.28180695, 11.99374962], [75.28180695, 11.99431133], [75.28151703, 11.99431133], [75.28152466, 11.9948597], [75.28125, 11.9948597], [75.28125, 11.99542046], [75.28097534, 11.99541569], [75.28097534, 11.99597168], [75.28070068, 11.99597168], [75.28070068, 11.99652958], [75.2804184, 11.99652767], [75.2804184, 11.99708366], [75.28070068, 11.99707985], [75.28070068, 11.9984808], [75.2804184, 11.9984808], [75.2804184, 11.99931145], [75.28013611, 11.99931145], [75.28013611, 11.99986267], [75.27986145, 11.99986267], [75.27986145, 12.00014114], [75.27986145, 12.00042057], [75.27958679, 12.00042057], [75.27958679, 12.00097179], [75.2793045, 12.00097179], [75.2793045, 12.00152874], [75.27902985, 12.00152874], [75.27902985, 12.00208473], [75.2784729, 12.00208473], [75.2784729, 12.00236034], [75.27791595, 12.00236034], [75.27791595, 12.00264072], [75.27735901, 12.00264072], [75.27735901, 12.0029211], [75.27680206, 12.00291729], [75.27680206, 12.00347328], [75.2765274, 12.00347042], [75.2765274, 12.0037508], [75.27625275, 12.0037508], [75.27625275, 12.00403118], [75.27597046, 12.00403118], [75.27597046, 12.00431061], [75.27513885, 12.00431061], [75.27513885, 12.00486088], [75.27485657, 12.00486088], [75.27485657, 12.00542068], [75.27458191, 12.00541687], [75.27458191, 12.00569534], [75.27430725, 12.00569534], [75.27430725, 12.00597286], [75.27403259, 12.00597095], [75.27403259, 12.00653076], [75.27348328, 12.00653076], [75.27348328, 12.00680923], [75.27319336, 12.00680923], [75.27319336, 12.00653076], [75.2729187, 12.00653076], [75.2729187, 12.00542068], [75.27263641, 12.00542068], [75.27263641, 12.00403118], [75.2729187, 12.00403118], [75.2729187, 12.00347042], [75.27375031, 12.00347328], [75.27375031, 12.00319481], [75.27430725, 12.00319481], [75.27430725, 12.00291729], [75.27456665, 12.0029211], [75.27456665, 12.00236034], [75.2748642, 12.00236034], [75.2748642, 12.00208473], [75.27541351, 12.00208473], [75.27541351, 12.00180435], [75.2756958, 12.00181103], [75.2756958, 12.0015192], [75.27597046, 12.00152874], [75.27597046, 12.00125122], [75.27625275, 12.00125122], [75.27625275, 12.00097179], [75.2765274, 12.00097179], [75.2765274, 12.00042057], [75.27707672, 12.00042057], [75.27707672, 12.00014114], [75.27735901, 12.00014114], [75.27735901, 11.99986267], [75.27762604, 11.99986267], [75.27762604, 11.99958038], [75.27791595, 11.99958229], [75.27791595, 11.99930573], [75.27819061, 11.99931145], [75.27819824, 11.99874973], [75.2784729, 11.99874973], [75.2784729, 11.99763966], [75.27874756, 11.99763966], [75.27874756, 11.99736023], [75.27902985, 11.99736214], [75.27902985, 11.99680614], [75.27929688, 11.99681091], [75.27929688, 11.99625015], [75.27958679, 11.99625015], [75.27958679, 11.99568939], [75.27986145, 11.99569416], [75.27986145, 11.9948616], [75.27958679, 11.9948597], [75.27958679, 11.99457932], [75.2784729, 11.99457932], [75.2784729, 11.9948597], [75.27762604, 11.9948597], [75.27762604, 11.99542046], [75.27735901, 11.99541569], [75.27735901, 11.99597168], [75.27707672, 11.99597168], [75.27707672, 11.99652958], [75.27680206, 11.99652958], [75.27680206, 11.99681091], [75.2765274, 11.99680614], [75.2765274, 11.99736214], [75.27625275, 11.99736023], [75.27625275, 11.99763966], [75.2756958, 11.99763775], [75.2756958, 11.99819374], [75.27540588, 11.99819183], [75.27540588, 11.99874973], [75.27485657, 11.99874973], [75.27485657, 11.99903107], [75.27458191, 11.99902821], [75.27458191, 11.99958229], [75.27403259, 11.99958038], [75.27403259, 11.99986267], [75.27348328, 11.99986267], [75.27348328, 12.00014114], [75.27319336, 12.00014114], [75.27319336, 12.00042057], [75.2729187, 12.0004158], [75.2729187, 12.00069427], [75.27236176, 12.00069046], [75.27236176, 12.00097179], [75.2720871, 12.00097179], [75.2720871, 12.00125122], [75.27180481, 12.00125122], [75.27180481, 12.00152874], [75.27124786, 12.0015192], [75.27124786, 12.00181103], [75.27097321, 12.00180435], [75.27097321, 12.00208473], [75.27069092, 12.00208473], [75.27069092, 12.00236034], [75.27041626, 12.00236034], [75.27041626, 12.00264072], [75.2701416, 12.00264072], [75.2701416, 12.0029211], [75.26985931, 12.00291729], [75.26985931, 12.00319481], [75.26958466, 12.00319481], [75.26958466, 12.00347328], [75.26930237, 12.00347042], [75.26930237, 12.00403118], [75.26902771, 12.00403118], [75.26902771, 12.00431061], [75.26875305, 12.00430679], [75.26875305, 12.00458336], [75.26847076, 12.00457954], [75.26847076, 12.00486088], [75.26819611, 12.00486088], [75.26819611, 12.00514126], [75.26763916, 12.00514126], [75.26763916, 12.00542068], [75.26680756, 12.00541687], [75.26680756, 12.00569534], [75.26625061, 12.00569534], [75.26625061, 12.00597286], [75.26597595, 12.00597095], [75.26597595, 12.00653076], [75.26569366, 12.00652885], [75.26569366, 12.00708294], [75.26541901, 12.00708103], [75.26541901, 12.01153183], [75.26568604, 12.01153183], [75.26568604, 12.01375198], [75.26597595, 12.01375198], [75.26597595, 12.01541996], [75.26625061, 12.01541805], [75.26625061, 12.0181942], [75.26652527, 12.0181942], [75.26652527, 12.01847172], [75.26680756, 12.01847172], [75.26680756, 12.0195837], [75.26708221, 12.01958179], [75.26708221, 12.02013969], [75.26735687, 12.02013969], [75.26735687, 12.02125168], [75.26763916, 12.02124977], [75.26763916, 12.02235985], [75.26790619, 12.02235985], [75.26790619, 12.02292061], [75.26819611, 12.02291584], [75.26819611, 12.02347183], [75.27097321, 12.02347183], [75.27097321, 12.02319431], [75.27375031, 12.02319431], [75.27375031, 12.02291584], [75.27485657, 12.02292061], [75.27485657, 12.02265167], [75.27625275, 12.02265167], [75.27625275, 12.02235985], [75.27735901, 12.02235985], [75.27735901, 12.02208424], [75.27819061, 12.02208424], [75.27819824, 12.02180576], [75.27929688, 12.02181053], [75.27929688, 12.02153015], [75.27958679, 12.02153015], [75.27958679, 12.02097034], [75.27986145, 12.02097225], [75.27986145, 12.02069378], [75.28013611, 12.02069378], [75.28013611, 12.02041626], [75.28098297, 12.02042007], [75.28098297, 12.02013969], [75.28151703, 12.02013969], [75.28151703, 12.01986027], [75.28236389, 12.01986217], [75.28236389, 12.0195837], [75.28291321, 12.0195837], [75.28291321, 12.01930618], [75.28376007, 12.01931], [75.28376007, 12.01902962], [75.28430176, 12.01902962], [75.28430176, 12.01875019], [75.28514099, 12.01875019], [75.28514099, 12.01819134], [75.28541565, 12.0181942], [75.28541565, 12.0162487], [75.28514099, 12.0162487], [75.28514099, 12.0156889], [75.2848587, 12.01569557], [75.2848587, 12.01541805], [75.28514099, 12.01541996], [75.28514099, 12.0148592], [75.28541565, 12.01486206], [75.28541565, 12.01458263], [75.28569794, 12.01458263], [75.28569794, 12.01402664], [75.2859726, 12.01403046], [75.2859726, 12.01375198], [75.28624725, 12.01375198], [75.28624725, 12.01319122], [75.28652954, 12.01319313], [75.28652954, 12.01291656], [75.28679657, 12.01292038], [75.28679657, 12.01236057], [75.28708649, 12.01236057], [75.28708649, 12.01208305], [75.28736115, 12.01208305], [75.28736115, 12.01152706], [75.2876358, 12.01153183], [75.2876358, 12.01097107], [75.28791809, 12.01097107], [75.28791809, 12.01041698], [75.28819275, 12.01041889], [75.28819275, 12.00986099], [75.28848267, 12.00986099], [75.28847504, 12.009305], [75.28874969, 12.00931168], [75.28874969, 12.0090313], [75.28901672, 12.0090313], [75.28901672, 12.00875092], [75.28930664, 12.00875092], [75.28930664, 12.00847054], [75.2895813, 12.0084734], [75.2895813, 12.00819492], [75.29013824, 12.00819492], [75.29013824, 12.0079174], [75.2904129, 12.00791931], [75.2904129, 12.00764084], [75.29070282, 12.00764084], [75.29070282, 12.00736141], [75.29096985, 12.00736141], [75.29096985, 12.00708294], [75.29125214, 12.00708294], [75.29125214, 12.00680542], [75.29180908, 12.00680923], [75.29180908, 12.00653076], [75.29207611, 12.00653076], [75.29207611, 12.00542068], [75.29180908, 12.00542068], [75.29180908, 12.00514126], [75.29207611, 12.00514126], [75.29207611, 12.00486088], [75.29319763, 12.00486088], [75.29319763, 12.00514126], [75.29347229, 12.00514126], [75.29347229, 12.00542068], [75.29374695, 12.00541687], [75.29374695, 12.00569534], [75.29402924, 12.00569534], [75.29402924, 12.00597286], [75.29429626, 12.00597095], [75.29429626, 12.00625134], [75.29458618, 12.00625134], [75.29458618, 12.00736141], [75.29430389, 12.00736141], [75.29430389, 12.00958347], [75.29486084, 12.00958061], [75.29486084, 12.00986099], [75.29514313, 12.00986099], [75.29514313, 12.01014137], [75.29541779, 12.01014137], [75.29541779, 12.00986099], [75.29570007, 12.00986099], [75.29569244, 12.009305], [75.2959671, 12.00931168], [75.2959671, 12.0090313], [75.29624939, 12.0090313], [75.29624939, 12.00875092], [75.29651642, 12.00875092], [75.29651642, 12.00819016], [75.29680634, 12.00819492], [75.29680634, 12.0079174], [75.29708099, 12.00791931], [75.29708099, 12.00736141], [75.29736328, 12.00736141], [75.29736328, 12.00708294], [75.29763794, 12.00708294], [75.29763794, 12.00652885], [75.29792023, 12.00653076], [75.29792023, 12.00457954], [75.29819489, 12.00458336], [75.29819489, 12.00402641], [75.29846954, 12.00403118], [75.29846954, 12.0037508], [75.29873657, 12.0037508], [75.29873657, 12.00347042], [75.29957581, 12.00347042], [75.29957581, 12.00431061], [75.29930878, 12.00430679], [75.29930878, 12.00569534], [75.29958344, 12.00569534], [75.29958344, 12.00597286], [75.30014038, 12.00597095], [75.30014038, 12.00625134], [75.30097198, 12.00625134], [75.30097198, 12.00653076], [75.30152893, 12.00653076], [75.30152893, 12.00680923], [75.30236053, 12.00680542], [75.30236053, 12.00708294], [75.30347443, 12.00708294], [75.30347443, 12.00680542], [75.30374908, 12.00680923], [75.30374908, 12.00653076], [75.30403137, 12.00653076], [75.30403137, 12.00625134], [75.30568695, 12.00625134], [75.30568695, 12.00653076], [75.30596924, 12.00653076], [75.30596924, 12.00680923], [75.30652618, 12.00680923], [75.30652618, 12.00653076], [75.30680847, 12.00653076], [75.30680847, 12.00625134], [75.30735779, 12.00625134], [75.30735779, 12.00597095], [75.30791473, 12.00597286], [75.30791473, 12.00569534], [75.30819702, 12.00569534], [75.30819702, 12.00486088], [75.30847168, 12.00486088], [75.30847168, 12.00431061], [75.30819702, 12.00431061], [75.30819702, 12.0037508], [75.3079071, 12.0037508], [75.3079071, 12.00347042], [75.30764008, 12.00347328], [75.30764008, 12.00319481], [75.30791473, 12.00319481], [75.30791473, 12.00291729], [75.30819702, 12.0029211], [75.30819702, 12.00264072], [75.30847168, 12.00264072], [75.30847168, 12.00236034], [75.30902863, 12.00236034], [75.30902863, 12.0029211], [75.30930328, 12.00291729], [75.30930328, 12.00319481], [75.31124878, 12.00319481], [75.31124878, 12.00347328], [75.31208038, 12.00347042], [75.31208038, 12.0037508], [75.31291962, 12.0037508], [75.31291962, 12.00403118], [75.31597137, 12.00403118], [75.31597137, 12.00431061], [75.31652832, 12.00430679], [75.31652832, 12.00458336], [75.31680298, 12.00457954], [75.31680298, 12.00542068], [75.31652832, 12.00541687], [75.31652832, 12.00599957], [75.31652832, 12.00625134], [75.31597137, 12.00625134], [75.31597137, 12.00653076], [75.3154068, 12.00653076], [75.3154068, 12.00680923], [75.31513977, 12.00680542], [75.31513977, 12.00708294], [75.31458282, 12.00708294], [75.31458282, 12.00736141], [75.31402588, 12.00736141], [75.31402588, 12.00764084], [75.31375122, 12.00763893], [75.31375122, 12.0084734], [75.31402588, 12.0084734], [75.31402588, 12.00958347], [75.31430817, 12.00958061], [75.31430817, 12.01041889], [75.31485748, 12.01041698], [75.31485748, 12.01069546], [75.31541443, 12.01069546], [75.31541443, 12.01097107], [75.31791687, 12.01097107], [75.31791687, 12.01125145], [75.31903076, 12.01125145], [75.31903076, 12.01153183], [75.32013702, 12.01153183], [75.32013702, 12.01125145], [75.32041931, 12.01125145], [75.32041931, 12.01097107], [75.32096863, 12.01097107], [75.32096863, 12.01069546], [75.32125092, 12.01069546], [75.32125092, 12.01041698], [75.3215332, 12.01041889], [75.3215332, 12.01014137], [75.32402802, 12.01014137], [75.32402802, 12.00986099], [75.32514191, 12.00986099], [75.32514191, 12.00958061], [75.32596588, 12.00958061], [75.32596588, 12.00986099], [75.32653046, 12.00986099], [75.32653046, 12.01014137], [75.32707977, 12.01014137], [75.32707977, 12.01041889], [75.32736206, 12.01041889], [75.32736206, 12.01125145], [75.32763672, 12.01125145], [75.32763672, 12.0118103], [75.32791901, 12.01180458], [75.32791901, 12.01208305], [75.32847595, 12.01208305], [75.32847595, 12.01236057], [75.32875061, 12.01236057], [75.32875061, 12.01125145], [75.32847595, 12.01125145], [75.32847595, 12.01014137], [75.32875061, 12.01014137], [75.32875061, 12.00931168], [75.32930756, 12.00931168], [75.32930756, 12.0090313], [75.32958221, 12.00902653], [75.32958221, 12.00958347], [75.32985687, 12.00958061], [75.32985687, 12.01014137], [75.33013916, 12.01013947], [75.33013916, 12.01069546], [75.33041382, 12.01069546], [75.33041382, 12.01097107], [75.33152771, 12.01097107], [75.33152771, 12.01069546], [75.33180237, 12.01069546], [75.33180237, 12.01041698], [75.33207703, 12.01041889], [75.33207703, 12.01014137], [75.33319092, 12.01014137], [75.33319092, 12.01125145], [75.33291626, 12.01125145], [75.33291626, 12.0118103], [75.33208466, 12.01180458], [75.33208466, 12.01208305], [75.33181, 12.01208115], [75.33181, 12.01292038], [75.33208466, 12.01291656], [75.33208466, 12.01347446], [75.33180237, 12.01347446], [75.33180237, 12.01319313], [75.33125305, 12.01319313], [75.33125305, 12.01347446], [75.32791901, 12.01347446], [75.32791901, 12.01319313], [75.32736206, 12.01319313], [75.32736206, 12.01291656], [75.32707977, 12.01292038], [75.32707977, 12.01264191], [75.32681274, 12.01264191], [75.32681274, 12.01236057], [75.32653046, 12.01236057], [75.32653046, 12.01208305], [75.32624817, 12.01208305], [75.32624817, 12.01180458], [75.32541656, 12.0118103], [75.32541656, 12.01153183], [75.32319641, 12.01153183], [75.32319641, 12.0118103], [75.32180786, 12.01180458], [75.32180786, 12.01236057], [75.3215332, 12.01236057], [75.3215332, 12.01264191], [75.32125092, 12.01264191], [75.32125092, 12.01292038], [75.32069397, 12.01291656], [75.32069397, 12.01319313], [75.32041931, 12.01319313], [75.32041931, 12.01347446], [75.32013702, 12.01346016], [75.32013702, 12.01375198], [75.31987, 12.01375198], [75.31987, 12.01403046], [75.31846619, 12.01403046], [75.31846619, 12.01431179], [75.31652832, 12.01431179], [75.31652832, 12.01403046], [75.31569672, 12.01403046], [75.31569672, 12.01375198], [75.31513977, 12.01375198], [75.31513977, 12.01403046], [75.31430817, 12.01403046], [75.31430817, 12.01431179], [75.31375122, 12.01430511], [75.31375122, 12.01458263], [75.31346893, 12.01458263], [75.31346893, 12.01486206], [75.31318665, 12.0148592], [75.31318665, 12.01513958], [75.31208038, 12.01513958], [75.31208038, 12.0148592], [75.31014252, 12.01486206], [75.31014252, 12.01430511], [75.30986023, 12.01431179], [75.30986023, 12.01375198], [75.3095932, 12.01375198], [75.3095932, 12.01319122], [75.30847168, 12.01319313], [75.30847168, 12.01347446], [75.3079071, 12.01346016], [75.3079071, 12.01403046], [75.30819702, 12.01402664], [75.30819702, 12.01486206], [75.3079071, 12.0148592], [75.3079071, 12.01513958], [75.30735779, 12.01513958], [75.30735779, 12.01541996], [75.30708313, 12.01541805], [75.30708313, 12.01569557], [75.30652618, 12.01569557], [75.30652618, 12.01597118], [75.30403137, 12.01597118], [75.30403137, 12.01569557], [75.30374908, 12.01569557], [75.30374908, 12.01541805], [75.30264282, 12.01541996], [75.30264282, 12.01513958], [75.30208588, 12.01513958], [75.30208588, 12.01541996], [75.30041504, 12.01541805], [75.30041504, 12.01569557], [75.29969025, 12.0156908], [75.29930878, 12.0156889], [75.29930878, 12.01681042], [75.29958344, 12.01680565], [75.29958344, 12.01708412], [75.29971313, 12.01708126], [75.29985809, 12.01708126], [75.29985809, 12.01764202], [75.30041504, 12.01764011], [75.30041504, 12.0181942], [75.30097198, 12.0181942], [75.30097198, 12.01847172], [75.30179596, 12.01846886], [75.30179596, 12.01875019], [75.30291748, 12.01875019], [75.30291748, 12.01791954], [75.30319214, 12.01791954], [75.30319214, 12.01764202], [75.30430603, 12.01764202], [75.30430603, 12.01791954], [75.30458069, 12.01791573], [75.30458069, 12.01847172], [75.30486298, 12.01846886], [75.30486298, 12.01875019], [75.30513763, 12.01875019], [75.30513763, 12.01902962], [75.30541992, 12.01902962], [75.30541992, 12.01931], [75.30568695, 12.01931], [75.30568695, 12.02013969], [75.30541992, 12.02013969], [75.30541992, 12.02042007], [75.30513763, 12.02041626], [75.30513763, 12.02069378], [75.30486298, 12.02069378], [75.30486298, 12.02097225], [75.30458069, 12.02097034], [75.30458069, 12.02153015], [75.30403137, 12.02153015], [75.30403137, 12.02181053], [75.30347443, 12.02180576], [75.30347443, 12.02208424], [75.30319214, 12.02208042], [75.30319214, 12.02265167], [75.30347443, 12.02264023], [75.30347443, 12.02319431], [75.30374908, 12.02318859], [75.30374908, 12.02375031], [75.30403137, 12.02375031], [75.30403137, 12.02486229], [75.30374908, 12.02486038], [75.30374908, 12.02542114], [75.30347443, 12.02541637], [75.30347443, 12.02569389], [75.30319214, 12.02569199], [75.30319214, 12.02625275], [75.30291748, 12.02625275], [75.30291748, 12.02653122], [75.30264282, 12.02653122], [75.30264282, 12.02681065], [75.30236053, 12.02680588], [75.30236053, 12.0270853], [75.30208588, 12.02707958], [75.30208588, 12.02735996], [75.30179596, 12.02735996], [75.30179596, 12.0276413], [75.30152893, 12.0276413], [75.30152893, 12.02792072], [75.30124664, 12.02791595], [75.30124664, 12.0284729], [75.30152893, 12.02846146], [75.30152893, 12.02875137], [75.30180359, 12.02875137], [75.30180359, 12.02958202], [75.30208588, 12.02958202], [75.30208588, 12.02985954], [75.30236053, 12.02985954], [75.30236053, 12.03014088], [75.30291748, 12.03014088], [75.30291748, 12.03042126], [75.30319214, 12.03041744], [75.30319214, 12.03069496], [75.30347443, 12.03069496], [75.30347443, 12.03097343], [75.30403137, 12.03096962], [75.30403137, 12.03125095], [75.30430603, 12.03125095], [75.30430603, 12.03152657], [75.30486298, 12.03151989], [75.30486298, 12.03181076], [75.30513763, 12.03180695], [75.30513763, 12.03208256], [75.30568695, 12.0320797], [75.30568695, 12.03236103], [75.30680847, 12.03236103], [75.30680847, 12.03264141], [75.30764008, 12.03264141], [75.30764008, 12.03292084], [75.30986023, 12.03291702], [75.30986023, 12.03319454], [75.31014252, 12.03319454], [75.31014252, 12.03347301], [75.31069183, 12.03347301], [75.31069183, 12.03263855], [75.31180573, 12.03263855], [75.31180573, 12.03319454], [75.31208038, 12.03319454], [75.31208038, 12.03486061], [75.31181335, 12.03486061], [75.31181335, 12.0365324], [75.31208038, 12.03652668], [75.31208038, 12.03708267], [75.31319427, 12.03708267], [75.31319427, 12.03736115], [75.31346893, 12.03736115], [75.31346893, 12.03819466], [75.31318665, 12.03819084], [75.31318665, 12.03875065], [75.31291962, 12.03875065], [75.31291962, 12.03903198], [75.31236267, 12.03902721], [75.31236267, 12.03958321], [75.31208038, 12.0395813], [75.31208038, 12.04124928], [75.31236267, 12.04124928], [75.31236267, 12.04181004], [75.31263733, 12.04180527], [75.31263733, 12.04236221], [75.31291962, 12.04235935], [75.31291962, 12.04292011], [75.31319427, 12.04291534], [75.31319427, 12.04319572], [75.31375122, 12.04319572], [75.31375122, 12.04347134], [75.31402588, 12.04347134], [75.31402588, 12.04374981], [75.31430817, 12.04374981], [75.31430817, 12.04430962], [75.31458282, 12.0443058], [75.31458282, 12.04458427], [75.31485748, 12.04458141], [75.31485748, 12.04486179], [75.31513977, 12.04486179], [75.31513977, 12.04514027], [75.31569672, 12.04514027], [75.31569672, 12.04569435], [75.31597137, 12.04569435], [75.31597137, 12.04597187], [75.31624603, 12.04597187], [75.31624603, 12.04625034], [75.31680298, 12.04625034], [75.31680298, 12.04652977], [75.31931305, 12.04652977], [75.31931305, 12.04625034], [75.31958008, 12.04625034], [75.31958008, 12.04597187], [75.32069397, 12.04597187], [75.32069397, 12.04569435], [75.32125092, 12.04569435], [75.32125092, 12.04541779], [75.3215332, 12.04541969], [75.3215332, 12.04514027], [75.32180786, 12.04514027], [75.32180786, 12.04486179], [75.32208252, 12.04486179], [75.32208252, 12.04430962], [75.32235718, 12.04430962], [75.32235718, 12.04374981], [75.32263947, 12.04374981], [75.32263947, 12.04319572], [75.32291412, 12.04319572], [75.32291412, 12.04263973], [75.32319641, 12.04263973], [75.32319641, 12.04152966], [75.32347107, 12.04152966], [75.32347107, 12.04124928], [75.32375336, 12.04124928], [75.32375336, 12.04096889], [75.32402802, 12.0409708], [75.32402802, 12.04041672], [75.32430267, 12.04041958], [75.32430267, 12.0401392], [75.32457733, 12.0401392], [75.32457733, 12.0395813], [75.32485962, 12.03958321], [75.32485962, 12.03899097], [75.32485962, 12.03874874], [75.32514191, 12.03875065], [75.32514191, 12.03819084], [75.32569122, 12.03819466], [75.32569122, 12.03791714], [75.32595062, 12.03792191], [75.32596588, 12.03736115], [75.32624817, 12.03736115], [75.32624817, 12.03708267], [75.32653046, 12.03708267], [75.32653046, 12.03652668], [75.32707977, 12.0365324], [75.32707977, 12.03625107], [75.32736206, 12.03625107], [75.32736206, 12.03597069], [75.32818604, 12.03597069], [75.32818604, 12.03625107], [75.32875061, 12.03625107], [75.32875061, 12.0365324], [75.3290329, 12.0365324], [75.3290329, 12.03625107], [75.32930756, 12.03625107], [75.32930756, 12.0365324], [75.32985687, 12.0365324], [75.32985687, 12.03681183], [75.33013916, 12.03680515], [75.33013916, 12.03708267], [75.33069611, 12.03708267], [75.33069611, 12.03736115], [75.33125305, 12.03736115], [75.33125305, 12.03765106], [75.33152771, 12.03765106], [75.33152771, 12.03792191], [75.33180237, 12.03791714], [75.33181763, 12.03816128], [75.33152771, 12.03819466], [75.33152771, 12.03847122], [75.33208466, 12.03847122], [75.33208466, 12.03862095], [75.33207703, 12.03875065], [75.33235931, 12.03874874], [75.33235931, 12.0391407], [75.33235931, 12.03931046], [75.3326416, 12.03930473], [75.3326416, 12.03969002], [75.3326416, 12.03986073], [75.33281708, 12.03986073], [75.33287811, 12.03990936], [75.33291626, 12.04041958], [75.33347321, 12.04041672], [75.33347321, 12.04069328], [75.33374786, 12.04069138], [75.33374786, 12.04124928], [75.33403015, 12.04124928], [75.33403015, 12.04208374], [75.33429718, 12.04208088], [75.33429718, 12.04263973], [75.3345871, 12.04263973], [75.3345871, 12.04319572], [75.33486176, 12.04319572], [75.33486176, 12.04347134], [75.33513641, 12.04347134], [75.33513641, 12.04374981], [75.33486938, 12.04374981], [75.33486938, 12.04430962], [75.3345871, 12.0443058], [75.3345871, 12.04458427], [75.33429718, 12.04458141], [75.33429718, 12.04514027], [75.3345871, 12.04514027], [75.3345871, 12.04652977], [75.33513641, 12.04652977], [75.33513641, 12.04681969], [75.3354187, 12.04680634], [75.3354187, 12.04708385], [75.33597565, 12.04708385], [75.33597565, 12.04736233], [75.33901215, 12.04736042], [75.3390274, 12.04763985], [75.33930206, 12.04763794], [75.33930206, 12.04819393], [75.3390274, 12.04819393], [75.3390274, 12.0484724], [75.33875275, 12.0484724], [75.33875275, 12.04819393], [75.3381958, 12.04819393], [75.3381958, 12.0484724], [75.33680725, 12.04846954], [75.33680725, 12.04874992], [75.33651733, 12.04874992], [75.33651733, 12.04846954], [75.33569336, 12.04843998], [75.33569336, 12.04819393], [75.33513641, 12.04819393], [75.33513641, 12.04791641], [75.3345871, 12.04792023], [75.3345871, 12.04763985], [75.33429718, 12.04763985], [75.33429718, 12.04708195], [75.33403015, 12.04708385], [75.33403015, 12.04625034], [75.33374786, 12.04625034], [75.33374786, 12.04597187], [75.33347321, 12.04597187], [75.33347321, 12.04541779], [75.33319092, 12.04541969], [75.33319092, 12.04403019], [75.33347321, 12.04403019], [75.33347321, 12.04345989], [75.33319092, 12.04347134], [75.33319092, 12.04263973], [75.33291626, 12.04263973], [75.33291626, 12.04181004], [75.33235931, 12.04181004], [75.33235931, 12.04152966], [75.3326416, 12.04152966], [75.3326416, 12.04124928], [75.33207703, 12.04124928], [75.33207703, 12.04096889], [75.33180237, 12.0409708], [75.33180237, 12.04069328], [75.33152771, 12.04069328], [75.33152771, 12.04041672], [75.33125305, 12.04041958], [75.33125305, 12.0401392], [75.33097076, 12.0401392], [75.33097076, 12.0395813], [75.33069611, 12.03958321], [75.33069611, 12.03930473], [75.33040619, 12.03931046], [75.33040619, 12.03903198], [75.33013916, 12.03903198], [75.33013916, 12.03875065], [75.32985687, 12.03875065], [75.32985687, 12.03847122], [75.32930756, 12.03847122], [75.32930756, 12.03819466], [75.32902527, 12.03819466], [75.32902527, 12.03791714], [75.32680511, 12.03791714], [75.32680511, 12.03819466], [75.32653046, 12.03819466], [75.32653046, 12.03847122], [75.32624817, 12.03847122], [75.32624817, 12.03875065], [75.32596588, 12.03875065], [75.32596588, 12.03903198], [75.32569122, 12.03902721], [75.32569122, 12.03958321], [75.32541656, 12.0395813], [75.32541656, 12.03986073], [75.32514191, 12.03986073], [75.32514191, 12.0409708], [75.32485962, 12.04096889], [75.32485962, 12.04152966], [75.32458496, 12.04152679], [75.32458496, 12.04236221], [75.32430267, 12.04235935], [75.32430267, 12.04292011], [75.32402802, 12.04291534], [75.32402802, 12.04374981], [75.32375336, 12.04374981], [75.32375336, 12.04486179], [75.32347107, 12.04486179], [75.32347107, 12.04541969], [75.32319641, 12.04541779], [75.32319641, 12.04569435], [75.32291412, 12.04569435], [75.32291412, 12.04597187], [75.32263947, 12.04597187], [75.32263947, 12.04625034], [75.32235718, 12.04625034], [75.32235718, 12.04652977], [75.32208252, 12.04652977], [75.32208252, 12.04681969], [75.32180786, 12.04680634], [75.32180786, 12.04708385], [75.32152557, 12.04708385], [75.32152557, 12.04736233], [75.32096863, 12.04736042], [75.32096863, 12.04763985], [75.32041931, 12.04763985], [75.32041931, 12.04736042], [75.31958008, 12.04736042], [75.31958008, 12.04763985], [75.31874847, 12.04763985], [75.31874847, 12.04792023], [75.31652832, 12.04792023], [75.31652832, 12.04763985], [75.31569672, 12.04763985], [75.31569672, 12.04736042], [75.31513977, 12.04736233], [75.31513977, 12.04708385], [75.31485748, 12.04708385], [75.31485748, 12.04680634], [75.31430817, 12.04681969], [75.31430817, 12.04652977], [75.31402588, 12.04652977], [75.31402588, 12.04597187], [75.31375122, 12.04597187], [75.31375122, 12.04569435], [75.31346893, 12.04569435], [75.31346893, 12.04541779], [75.31318665, 12.04541969], [75.31318665, 12.04514027], [75.31291962, 12.04514027], [75.31291962, 12.04486179], [75.31263733, 12.04486179], [75.31263733, 12.04458141], [75.31208038, 12.04458427], [75.31208038, 12.0443058], [75.31181335, 12.04430962], [75.31181335, 12.04403019], [75.31124878, 12.04403019], [75.31124878, 12.04345989], [75.31097412, 12.04347134], [75.31097412, 12.04291534], [75.31067657, 12.04292011], [75.31067657, 12.04235935], [75.31041718, 12.04236221], [75.31041718, 12.04069328], [75.31014252, 12.04069328], [75.31014252, 12.03902721], [75.31041718, 12.03903198], [75.31041718, 12.03819084], [75.31014252, 12.03819466], [75.31014252, 12.03791714], [75.31041718, 12.03792191], [75.31041718, 12.03708076], [75.31069183, 12.03708267], [75.31069183, 12.03680515], [75.31014252, 12.03681183], [75.31014252, 12.0365324], [75.30986023, 12.0365324], [75.30986023, 12.03597069], [75.30958557, 12.0359726], [75.30958557, 12.03569508], [75.30930328, 12.03569508], [75.30930328, 12.0354166], [75.30902863, 12.03541946], [75.30902863, 12.03486061], [75.30874634, 12.03486061], [75.30874634, 12.03458309], [75.30819702, 12.03458977], [75.30819702, 12.03430939], [75.30708313, 12.03430939], [75.30708313, 12.03458977], [75.30735779, 12.03458977], [75.30735779, 12.03486061], [75.30764008, 12.03486061], [75.30764008, 12.03514099], [75.30791473, 12.03513908], [75.30791473, 12.03569508], [75.30819702, 12.03569508], [75.30819702, 12.03708267], [75.3079071, 12.03708076], [75.3079071, 12.03765106], [75.30764008, 12.03763866], [75.30764008, 12.03819466], [75.30735779, 12.03819466], [75.30735779, 12.03847122], [75.30708313, 12.03847122], [75.30708313, 12.03875065], [75.30680847, 12.03874874], [75.30680847, 12.03958321], [75.30708313, 12.03958321], [75.30708313, 12.04069328], [75.30680847, 12.04069138], [75.30680847, 12.04152966], [75.30708313, 12.04152679], [75.30708313, 12.04208374], [75.30735779, 12.04208374], [75.30735779, 12.04236221], [75.30764008, 12.04235935], [75.30764008, 12.04263973], [75.3079071, 12.04263973], [75.3079071, 12.04292011], [75.30819702, 12.04291534], [75.30819702, 12.04374981], [75.3079071, 12.04374981], [75.3079071, 12.04514027], [75.30819702, 12.04514027], [75.30819702, 12.04625034], [75.30847168, 12.04625034], [75.30847168, 12.04681969], [75.30874634, 12.04680634], [75.30874634, 12.04736233], [75.30902863, 12.04736042], [75.30902863, 12.04763985], [75.30930328, 12.04763985], [75.30930328, 12.04792023], [75.30958557, 12.04791641], [75.30958557, 12.04819393], [75.30986023, 12.04819202], [75.30986023, 12.04874992], [75.31014252, 12.04874992], [75.31014252, 12.04846954], [75.31041718, 12.0484724], [75.31041718, 12.04819393], [75.31069183, 12.04819393], [75.31069183, 12.04791641], [75.31096649, 12.04792023], [75.31096649, 12.04763985], [75.31124878, 12.04763985], [75.31124878, 12.04736042], [75.31181335, 12.04736042], [75.31181335, 12.04792023], [75.31208038, 12.04791641], [75.31208038, 12.04867172], [75.31208038, 12.0490303], [75.31184387, 12.04904175], [75.31181335, 12.04931068], [75.3116684, 12.04930592], [75.30879211, 12.05379105], [75.30480957, 12.0529213], [75.30066681, 12.05802059], [75.2961731, 12.05924129], [75.29737091, 12.06365108], [75.29917145, 12.06679153], [75.30916595, 12.07843971], [75.3147583, 12.08760929], [75.30964661, 12.09063053], [75.30906677, 12.10266113], [75.31288147, 12.10531139], [75.31962585, 12.10665131], [75.32817841, 12.10727978], [75.32998657, 12.10258961], [75.33598328, 12.09864044], [75.3398819, 12.09825134], [75.35193634, 12.10885143], [75.3553009, 12.10936069], [75.35790253, 12.11290073], [75.36267853, 12.11610985], [75.36592102, 12.11693001], [75.3685379, 12.12126064], [75.37548065, 12.12341022], [75.37930298, 12.12213993], [75.37993622, 12.12639141], [75.38228607, 12.12912083], [75.38308716, 12.12397957], [75.39215088, 12.12634087], [75.39823914, 12.12987137], [75.4021759, 12.13414001], [75.40251923, 12.13684082], [75.39982605, 12.14050102], [75.39392853, 12.14548111], [75.38852692, 12.14629173], [75.37838745, 12.14603043], [75.37460327, 12.14908028], [75.37201691, 12.14647007], [75.37149048, 12.14262962], [75.36826324, 12.14007854], [75.36669159, 12.13537979], [75.36360931, 12.13496971], [75.34784698, 12.13530922], [75.34616089, 12.13861179], [75.34194946, 12.13718033], [75.33522797, 12.14400196], [75.33112335, 12.14515114], [75.32515717, 12.14489079], [75.32064056, 12.14352131], [75.31429291, 12.14009953], [75.31115723, 12.1364603], [75.3098526, 12.13204956], [75.31067657, 12.12473202], [75.29277039, 12.11613274], [75.28392792, 12.11498165], [75.28198242, 12.1091404], [75.27781677, 12.1017704], [75.2745285, 12.10026073], [75.26602173, 12.10366058], [75.25985718, 12.10893059], [75.25588989, 12.10857964], [75.24739075, 12.1036911], [75.24344635, 12.10467052], [75.24053192, 12.10926056], [75.23660278, 12.11023045], [75.22306061, 12.10484028], [75.22113037, 12.10095119], [75.22245789, 12.08556938], [75.22225952, 12.07815075], [75.22424316, 12.07438087], [75.2231369, 12.06444168], [75.22367096, 12.05447102], [75.22735596, 12.04430103], [75.22492218, 12.03195], [75.23105621, 12.02456188], [75.23069763, 12.02414036], [75.23069763, 12.02431107], [75.23014069, 12.02431107], [75.23014069, 12.02402973], [75.22930908, 12.02402973], [75.22930908, 12.02375031], [75.22846985, 12.02375031], [75.22846985, 12.02346992], [75.22819519, 12.02347183], [75.22819519, 12.02319431], [75.22763824, 12.02319431], [75.22763824, 12.02291584], [75.22680664, 12.02292061], [75.22680664, 12.02265167], [75.22651672, 12.02265167], [75.22651672, 12.02208042], [75.22624969, 12.02208424], [75.22624969, 12.02180576], [75.22651672, 12.02181053], [75.22651672, 12.02153015], [75.22598267, 12.02153015], [75.22598267, 12.02097034], [75.22569275, 12.02097225], [75.22569275, 12.02069378], [75.22541809, 12.02069378], [75.22541809, 12.02013779], [75.22486115, 12.02013969], [75.22486115, 12.01986027], [75.2243042, 12.01986217], [75.2243042, 12.01930618], [75.22374725, 12.01931], [75.22374725, 12.01902962], [75.22348022, 12.01902962], [75.22348022, 12.01846886], [75.22319794, 12.01847172], [75.22319794, 12.01764011], [75.22292328, 12.01764202], [75.22292328, 12.01736164], [75.22264099, 12.01736164], [75.22264099, 12.01681042], [75.2223587, 12.01681042], [75.2223587, 12.01596928], [75.22208405, 12.01597118], [75.22208405, 12.01486206], [75.22180176, 12.01486206], [75.22180176, 12.01402664], [75.2215271, 12.01403046], [75.2215271, 12.01375198], [75.22125244, 12.01375198], [75.22125244, 12.01346016], [75.2206955, 12.01347446], [75.2206955, 12.01263905], [75.21985626, 12.01264191], [75.21985626, 12.01236057], [75.21930695, 12.01236057], [75.21930695, 12.01208305], [75.21902466, 12.01208305], [75.21902466, 12.01180458], [75.21875, 12.0118103], [75.21875, 12.01153183], [75.21819305, 12.01153183], [75.21819305, 12.01125145], [75.21763611, 12.01125145], [75.21763611, 12.01069069], [75.21736145, 12.01069546], [75.21736145, 12.01041698], [75.21708679, 12.01041889], [75.21708679, 12.01014137], [75.21624756, 12.01014137], [75.21624756, 12.01041889], [75.21457672, 12.01041889], [75.21457672, 12.01014137], [75.21375275, 12.01014137], [75.21375275, 12.01041889], [75.21263885, 12.01041698], [75.21263885, 12.01069546], [75.2123642, 12.01069546], [75.2123642, 12.01041698], [75.21208191, 12.01041698], [75.21208191, 12.01069546], [75.21097565, 12.01069546], [75.21097565, 12.01097107], [75.2104187, 12.01097107], [75.2104187, 12.01125145], [75.2095871, 12.01125145], [75.2095871, 12.01097107], [75.20930481, 12.01097107], [75.20930481, 12.01069546], [75.20791626, 12.01069546], [75.20791626, 12.01041698], [75.2076416, 12.01041889], [75.2076416, 12.01014137], [75.20735931, 12.01014137], [75.20735931, 12.00986099], [75.20707703, 12.00986099], [75.20707703, 12.0090313], [75.20735931, 12.0090313], [75.20735931, 12.00875092], [75.2076416, 12.00875092], [75.2076416, 12.00791931], [75.20707703, 12.00791931], [75.20707703, 12.00708103], [75.20680237, 12.00708294], [75.20680237, 12.00680542], [75.20652771, 12.00680923], [75.20652771, 12.00653076], [75.20625305, 12.00653076], [75.20625305, 12.00625134], [75.20597076, 12.00625134], [75.20597076, 12.00597095], [75.20541382, 12.00597286], [75.20541382, 12.00569534], [75.2048645, 12.00569534], [75.2048645, 12.00513935], [75.20458221, 12.00514126], [75.20458221, 12.00486088], [75.20291901, 12.00486088], [75.20291901, 12.00514126], [75.20181274, 12.00514126], [75.20181274, 12.00542068], [75.20153046, 12.00541687], [75.20153046, 12.00597286], [75.20124817, 12.00597095], [75.20124817, 12.00653076], [75.20096588, 12.00653076], [75.20096588, 12.00680923], [75.20085144, 12.00680542], [75.20069122, 12.00680542], [75.20069122, 12.00736141], [75.20041656, 12.00736141], [75.20041656, 12.00819492], [75.20063019, 12.00819492], [75.20097351, 12.00819492], [75.20097351, 12.0084734], [75.20124817, 12.00847054], [75.20124817, 12.00875092], [75.20153046, 12.00875092], [75.20153046, 12.00986099], [75.20124817, 12.00986099], [75.20124817, 12.01041889], [75.20097351, 12.01041698], [75.20097351, 12.01097107], [75.20069122, 12.01097107], [75.20069122, 12.01153183], [75.20041656, 12.01152706], [75.20041656, 12.01208305], [75.20014191, 12.01208305], [75.20014191, 12.01236057], [75.19996643, 12.01236057], [75.19985962, 12.01236057], [75.19985962, 12.01299], [75.19985962, 12.01319313], [75.19958496, 12.01319313], [75.19958496, 12.01347446], [75.19928741, 12.01346016], [75.19928741, 12.01375198], [75.19902802, 12.01375198], [75.19902802, 12.01403046], [75.19875336, 12.01402664], [75.19875336, 12.01458263], [75.19847107, 12.01458073], [75.19847107, 12.01541996], [75.19819641, 12.01541805], [75.19819641, 12.01597118], [75.19791412, 12.01597118], [75.19791412, 12.01708412], [75.19763947, 12.01708126], [75.19763947, 12.01764202], [75.19736481, 12.01764011], [75.19736481, 12.0181942], [75.19708252, 12.01819134], [75.19708252, 12.01875019], [75.19680786, 12.01875019], [75.19680786, 12.01902962], [75.19652557, 12.01902771], [75.19652557, 12.0195837], [75.19625092, 12.0195837], [75.19625092, 12.01986217], [75.19596863, 12.01986027], [75.19596863, 12.02013969], [75.19569397, 12.02013779], [75.19569397, 12.02097225], [75.19541931, 12.02097034], [75.19541931, 12.02181053], [75.19513702, 12.02180576], [75.19513702, 12.02208424], [75.19486237, 12.02208424], [75.19486237, 12.02235985], [75.19458008, 12.02235985], [75.19458008, 12.02319431], [75.19430542, 12.02319431], [75.19431305, 12.02375031], [75.19403076, 12.02375031], [75.19403076, 12.02402973], [75.19374847, 12.02402782], [75.19374847, 12.02458191], [75.19347382, 12.02458382], [75.19347382, 12.02569389], [75.19319153, 12.02569199], [75.19319153, 12.02653122], [75.19291687, 12.02653122], [75.19291687, 12.02681065], [75.19264221, 12.02681065], [75.19264221, 12.02735996], [75.19235992, 12.02735996], [75.19235992, 12.0276413], [75.1920929, 12.0276413], [75.1920929, 12.02792072], [75.19180298, 12.02792072], [75.19180298, 12.02875137], [75.19152832, 12.02875137], [75.19152832, 12.0290308], [75.19124603, 12.0290308], [75.19124603, 12.02931118], [75.19097137, 12.02930355], [75.19097137, 12.02985954], [75.19069672, 12.02985954], [75.19069672, 12.03042126], [75.1904068, 12.03042126], [75.1904068, 12.03125095], [75.19013977, 12.03125095], [75.19013977, 12.03208256], [75.18985748, 12.0320797], [75.18985748, 12.03264141], [75.18958282, 12.03264141], [75.18958282, 12.03292084], [75.18930817, 12.03291702], [75.18930817, 12.03347301], [75.18902588, 12.03347111], [75.18902588, 12.03430939], [75.18875122, 12.03430939], [75.18875122, 12.03458977], [75.18846893, 12.03458309], [75.18846893, 12.03486061], [75.18818665, 12.03486061], [75.18818665, 12.03541946], [75.18791962, 12.0354166], [75.18791962, 12.0359726], [75.18763733, 12.03597069], [75.18763733, 12.0365324], [75.18734741, 12.0365324], [75.18734741, 12.03681183], [75.18708038, 12.03680515], [75.18708038, 12.03708267], [75.18680573, 12.03708267], [75.18680573, 12.03847122], [75.18653107, 12.03847122], [75.18653107, 12.03875065], [75.18624878, 12.03875065], [75.18624878, 12.03986073], [75.18596649, 12.03986073], [75.18596649, 12.04041958], [75.18541718, 12.04041672], [75.18541718, 12.0409708], [75.18514252, 12.04096889], [75.18514252, 12.04152966], [75.18486023, 12.04152679], [75.18486023, 12.04208374], [75.18460083, 12.04208088], [75.18460083, 12.04292011], [75.18430328, 12.04291534], [75.18430328, 12.04374981], [75.18402863, 12.04374981], [75.18402863, 12.04430962], [75.18347168, 12.0443058], [75.18347168, 12.04458427], [75.18319702, 12.04458141], [75.18319702, 12.04541969], [75.1829071, 12.04541969], [75.1829071, 12.04625034], [75.18264008, 12.04625034], [75.18264008, 12.04681969], [75.18235779, 12.04680634], [75.18235779, 12.04736233], [75.18208313, 12.04736042], [75.18208313, 12.04763985], [75.18180847, 12.04763794], [75.18180847, 12.04819393], [75.18152618, 12.04819202], [75.18152618, 12.04874992], [75.18208313, 12.04874992], [75.18208313, 12.04846954], [75.18264008, 12.0484724], [75.18264008, 12.04819393], [75.18291473, 12.04819393], [75.18291473, 12.04791641], [75.18319702, 12.04792023], [75.18319702, 12.04763985], [75.18347168, 12.04763985], [75.18347168, 12.04708195], [75.18374634, 12.04708385], [75.18374634, 12.04652786], [75.18402863, 12.04652977], [75.18402863, 12.04541969], [75.18431091, 12.04541969], [75.18431091, 12.04430962], [75.18460083, 12.04430962], [75.18460083, 12.04403019], [75.18486023, 12.04403019], [75.18486023, 12.04374981], [75.18569183, 12.04374981], [75.18569183, 12.04403019], [75.18596649, 12.04403019], [75.18596649, 12.04430962], [75.18624878, 12.0443058], [75.18624878, 12.04458427], [75.18681335, 12.04458141], [75.18681335, 12.04486179], [75.18708038, 12.04486179], [75.18708038, 12.04514027], [75.18734741, 12.04514027], [75.18734741, 12.04541969], [75.18763733, 12.04541779], [75.18763733, 12.04597187], [75.18734741, 12.04597187], [75.18734741, 12.04681969], [75.18708038, 12.04680634], [75.18708038, 12.04736233], [75.18681335, 12.04736042], [75.18681335, 12.04792023], [75.18653107, 12.04791641], [75.18653107, 12.0484724], [75.18624878, 12.04846954], [75.18624878, 12.04931068], [75.18596649, 12.04931068], [75.18596649, 12.04986], [75.18569183, 12.04986], [75.18569183, 12.05042076], [75.18541718, 12.05042076], [75.18541718, 12.05125046], [75.18514252, 12.05125046], [75.18514252, 12.05181122], [75.18486023, 12.05181122], [75.18486023, 12.0529213], [75.18514252, 12.05291557], [75.18514252, 12.05347157], [75.18541718, 12.05346966], [75.18541718, 12.05375004], [75.18569183, 12.05375004], [75.18569183, 12.0543108], [75.18597412, 12.05430698], [75.18597412, 12.05458546], [75.18624878, 12.05457973], [75.18624878, 12.05486012], [75.18653107, 12.05486012], [75.18653107, 12.05514145], [75.18680573, 12.05513763], [75.18680573, 12.05569363], [75.18653107, 12.05569172], [75.18653107, 12.05653095], [75.18596649, 12.05653095], [75.18596649, 12.05681133], [75.18569183, 12.05680656], [75.18569183, 12.05708218], [75.18514252, 12.05708027], [75.18514252, 12.05736065], [75.18486023, 12.05736065], [75.18486023, 12.05764103], [75.18460083, 12.05764103], [75.18460083, 12.05792141], [75.18430328, 12.05791664], [75.18430328, 12.05847263], [75.18402863, 12.05846977], [75.18402863, 12.05903053], [75.18374634, 12.05902672], [75.18374634, 12.05958271], [75.18347168, 12.05957985], [75.18347168, 12.06014061], [75.18319702, 12.06014061], [75.18319702, 12.06125069], [75.1829071, 12.06125069], [75.1829071, 12.06375122], [75.18264008, 12.06375122], [75.18264008, 12.06458282], [75.18235779, 12.06456947], [75.18235779, 12.06542015], [75.18208313, 12.06541729], [75.18208313, 12.06597328], [75.18180847, 12.06597137], [75.18180847, 12.06653023], [75.18152618, 12.06652737], [75.18152618, 12.06708336], [75.18125153, 12.06708145], [75.18125153, 12.06736088], [75.18096924, 12.06736088], [75.18096924, 12.06763935], [75.18068695, 12.06763268], [75.18068695, 12.06791973], [75.18041992, 12.06791782], [75.18041992, 12.06847095], [75.18013763, 12.06847095], [75.18013763, 12.06902981], [75.17986298, 12.06902695], [75.17986298, 12.06986237], [75.17958069, 12.06985855], [75.17958069, 12.07042027], [75.17930603, 12.07042027], [75.17930603, 12.07153034], [75.17903137, 12.07153034], [75.17903137, 12.07236195], [75.17874908, 12.07236195], [75.17874908, 12.07291985], [75.17847443, 12.07291794], [75.17847443, 12.07347202], [75.17817688, 12.07347202], [75.17817688, 12.07376099], [75.17791748, 12.07376099], [75.17791748, 12.07402992], [75.17764282, 12.07402992], [75.17764282, 12.07542038], [75.17791748, 12.07542038], [75.17791748, 12.07763958], [75.17817688, 12.07763958], [75.17817688, 12.07874966], [75.17847443, 12.07874966], [75.17847443, 12.07958221], [75.17874908, 12.07958221], [75.17874908, 12.0806942], [75.17903137, 12.08069038], [75.17903137, 12.08125019], [75.17930603, 12.08125019], [75.17930603, 12.08153057], [75.17958069, 12.08153057], [75.17958069, 12.08181095], [75.17986298, 12.08180428], [75.17986298, 12.08208466], [75.18013763, 12.08208466], [75.18013763, 12.08236027], [75.18068695, 12.08236027], [75.18068695, 12.08264065], [75.18096924, 12.08264065], [75.18096924, 12.08292103], [75.18125153, 12.08291626], [75.18125153, 12.08319473], [75.18180847, 12.08319473], [75.18180847, 12.08347321], [75.18235779, 12.08347034], [75.18235779, 12.08375072], [75.18319702, 12.08375072], [75.18319702, 12.08403111], [75.18374634, 12.0840292], [75.18374634, 12.08458328], [75.18402863, 12.08458042], [75.18402863, 12.08514118], [75.18431091, 12.08514118], [75.18431091, 12.08570194], [75.18458557, 12.08569527], [75.18458557, 12.08597279], [75.18514252, 12.08597088], [75.18514252, 12.08681202], [75.18541718, 12.08680534], [75.18541718, 12.08736134], [75.18569183, 12.08736134], [75.18569183, 12.08763885], [75.18597412, 12.08763885], [75.18597412, 12.08819485], [75.18653107, 12.08819485], [75.18653107, 12.08874893], [75.18681335, 12.08874035], [75.18681335, 12.08902931], [75.18734741, 12.08902931], [75.18734741, 12.0893116], [75.18875122, 12.08930492], [75.18875122, 12.0895834], [75.18930817, 12.0895834], [75.18930817, 12.08930492], [75.18985748, 12.0893116], [75.18985748, 12.08902931], [75.19013977, 12.08902931], [75.19013977, 12.08874035], [75.19041443, 12.08874893], [75.19041443, 12.08847332], [75.19069672, 12.08847332], [75.19069672, 12.08791733], [75.19097137, 12.08791924], [75.19097137, 12.08736134], [75.19125366, 12.08736134], [75.19125366, 12.08652878], [75.19152832, 12.08653069], [75.19152832, 12.08542061], [75.19180298, 12.08542061], [75.19180298, 12.08458042], [75.19152832, 12.08458328], [75.19152832, 12.08430672], [75.19180298, 12.08431053], [75.19180298, 12.08403111], [75.19152832, 12.08403111], [75.19152832, 12.08375072], [75.19124603, 12.08375072], [75.19124603, 12.08347034], [75.19097137, 12.08347321], [75.19097137, 12.08180428], [75.19124603, 12.08181095], [75.19124603, 12.08097172], [75.19152832, 12.08097172], [75.19152832, 12.08069038], [75.19125366, 12.0806942], [75.19125366, 12.08013821], [75.19152832, 12.08014107], [75.19152832, 12.07985973], [75.19124603, 12.07985973], [75.19124603, 12.07931137], [75.19152832, 12.07931137], [75.19152832, 12.07847023], [75.19180298, 12.07847214], [75.19180298, 12.07708359], [75.19208527, 12.07708359], [75.19208527, 12.0765276], [75.19235992, 12.07653046], [75.19235992, 12.07542038], [75.19264221, 12.07542038], [75.19264221, 12.07457924], [75.19291687, 12.07458401], [75.19291687, 12.07402802], [75.19319153, 12.07402992], [75.19319153, 12.07319069], [75.19347382, 12.07319355], [75.19347382, 12.07263756], [75.19374847, 12.07264042], [75.19374847, 12.07236195], [75.19403076, 12.07236195], [75.19403076, 12.07180977], [75.19431305, 12.07180977], [75.19431305, 12.07097244], [75.19458008, 12.07097244], [75.19458008, 12.07069302], [75.19486237, 12.07069969], [75.19486237, 12.07042027], [75.19513702, 12.07042027], [75.19513702, 12.07014179], [75.19654083, 12.07014179], [75.19654083, 12.06985855], [75.19763947, 12.06985855], [75.19763947, 12.07014179], [75.20014191, 12.07014179], [75.20014191, 12.07042027], [75.20153046, 12.07042027], [75.20153046, 12.07069969], [75.20207977, 12.07069302], [75.20207977, 12.07097244], [75.20263672, 12.07097244], [75.20263672, 12.07125187], [75.20318604, 12.07125187], [75.20318604, 12.07153034], [75.20375061, 12.07153034], [75.20375061, 12.07180977], [75.20430756, 12.07180977], [75.20430756, 12.07236195], [75.20458221, 12.07236195], [75.20458221, 12.07291985], [75.20513916, 12.07291985], [75.20513916, 12.07264042], [75.20541382, 12.07263756], [75.20541382, 12.07319355], [75.20597076, 12.07319355], [75.20597076, 12.07291794], [75.20652771, 12.07291794], [75.20652771, 12.07319355], [75.20735931, 12.07319355], [75.20735931, 12.07347202], [75.2076416, 12.07347202], [75.2076416, 12.07319355], [75.20819092, 12.07319355], [75.20819092, 12.07291794], [75.20874786, 12.07291985], [75.20874786, 12.07264042], [75.20929718, 12.07264042], [75.20929718, 12.07208061], [75.2095871, 12.07208443], [75.2095871, 12.07180595], [75.20986176, 12.07180977], [75.20986176, 12.07097244], [75.21013641, 12.07097244], [75.21013641, 12.07041454], [75.21069336, 12.07042027], [75.21069336, 12.07014179], [75.21098328, 12.07014179], [75.21098328, 12.06985855], [75.21152496, 12.06986237], [75.21152496, 12.06958389], [75.21180725, 12.06958389], [75.21180725, 12.06930542], [75.21208191, 12.06931019], [75.21208191, 12.06902981], [75.21235657, 12.06902981], [75.21235657, 12.06874943], [75.2131958, 12.06874943], [75.2131958, 12.06847095], [75.21347046, 12.06847095], [75.21347046, 12.06819344], [75.21375275, 12.06819344], [75.21375275, 12.06791782], [75.2140274, 12.06791973], [75.2140274, 12.06736088], [75.2142868, 12.06736088], [75.2142868, 12.06680965], [75.2151413, 12.06680489], [75.2151413, 12.06708336], [75.21569824, 12.06708145], [75.21569824, 12.06736088], [75.2168045, 12.06736088], [75.2168045, 12.06763935], [75.21736145, 12.06763268], [75.21736145, 12.06791973], [75.21819305, 12.06791973], [75.21819305, 12.06763268], [75.2195816, 12.06763268], [75.2195816, 12.06791973], [75.22013855, 12.06791782], [75.22013855, 12.06847095], [75.22042084, 12.06847095], [75.22042084, 12.06931019], [75.22013855, 12.06931019], [75.22013855, 12.07014179], [75.21985626, 12.07014179], [75.21985626, 12.07042027], [75.2195816, 12.07042027], [75.2195816, 12.07125187], [75.21901703, 12.07125187], [75.21901703, 12.07153034], [75.21875, 12.07153034], [75.21875, 12.07125187], [75.21848297, 12.07125187], [75.21848297, 12.07042027], [75.21819305, 12.07042027], [75.21819305, 12.06985855], [75.2179184, 12.06986237], [75.2179184, 12.06958389], [75.21763611, 12.06958389], [75.21763611, 12.06902695], [75.2159729, 12.06902981], [75.2159729, 12.06874943], [75.2151413, 12.06874943], [75.2151413, 12.06902981], [75.2142868, 12.06902981], [75.2142868, 12.06874943], [75.2140274, 12.06874943], [75.2140274, 12.06902981], [75.21347046, 12.06902981], [75.21347046, 12.06931019], [75.2131958, 12.06930542], [75.2131958, 12.06958389], [75.21291351, 12.06958389], [75.21291351, 12.06986237], [75.21235657, 12.06985855], [75.21235657, 12.07014179], [75.21208191, 12.07014179], [75.21208191, 12.07042027], [75.21180725, 12.07041454], [75.21180725, 12.07097244], [75.21151733, 12.07097244], [75.21151733, 12.07125187], [75.21125031, 12.07125187], [75.21125031, 12.07180977], [75.21097565, 12.07180595], [75.21098328, 12.07236195], [75.21069336, 12.07236195], [75.21069336, 12.07264042], [75.2104187, 12.07264042], [75.2104187, 12.07291985], [75.20986176, 12.07291794], [75.20986176, 12.07319355], [75.20903015, 12.07319355], [75.20903015, 12.07347202], [75.20874786, 12.07347202], [75.20874786, 12.07376099], [75.20848083, 12.07376099], [75.20848083, 12.07402992], [75.20791626, 12.07402992], [75.20791626, 12.0743103], [75.20680237, 12.07430553], [75.20680237, 12.07458401], [75.20652771, 12.07458401], [75.20652771, 12.07430553], [75.2040329, 12.0743103], [75.2040329, 12.07402992], [75.20375061, 12.07402992], [75.20375061, 12.07376099], [75.20347595, 12.07376099], [75.20347595, 12.07347202], [75.20319366, 12.07347202], [75.20319366, 12.07319355], [75.20291901, 12.07319355], [75.20291901, 12.07291794], [75.20263672, 12.07291985], [75.20263672, 12.07264042], [75.20207977, 12.07264042], [75.20207977, 12.07236195], [75.20180511, 12.07236195], [75.20180511, 12.07208443], [75.20153046, 12.07208443], [75.20153046, 12.07180595], [75.20096588, 12.07180977], [75.20096588, 12.07153034], [75.19875336, 12.07153034], [75.19875336, 12.07180977], [75.19763947, 12.07180977], [75.19763947, 12.07153034], [75.19568634, 12.07153034], [75.19568634, 12.07180977], [75.19541931, 12.07180595], [75.19541931, 12.07208443], [75.19513702, 12.07208061], [75.19513702, 12.07236195], [75.19486237, 12.07236195], [75.19486237, 12.07264042], [75.19458008, 12.07263756], [75.19458008, 12.07347202], [75.19431305, 12.07347202], [75.19431305, 12.07402992], [75.19403076, 12.07402802], [75.19403076, 12.0759716], [75.19374847, 12.0759716], [75.19374847, 12.07680607], [75.19347382, 12.07680607], [75.19347382, 12.07708359], [75.19319153, 12.07708168], [75.19319153, 12.07792091], [75.19291687, 12.07792091], [75.19291687, 12.07874966], [75.19264221, 12.07874966], [75.19264221, 12.07931137], [75.19291687, 12.07930565], [75.19291687, 12.07958221], [75.19264221, 12.07956791], [75.19264221, 12.08014107], [75.19235992, 12.08014107], [75.19235992, 12.08125019], [75.1920929, 12.08125019], [75.1920929, 12.08153057], [75.19235992, 12.08153057], [75.19235992, 12.08292103], [75.19208527, 12.08291626], [75.19208527, 12.08319473], [75.19235992, 12.08318996], [75.19235992, 12.08403111], [75.19264221, 12.0840292], [75.19264221, 12.08458328], [75.19291687, 12.08458328], [75.19291687, 12.08597279], [75.19264221, 12.08597279], [75.19264221, 12.08708286], [75.19235992, 12.08708286], [75.19235992, 12.08819485], [75.19208527, 12.08819485], [75.19208527, 12.08847332], [75.19180298, 12.08847141], [75.19180298, 12.08902931], [75.19152832, 12.08902931], [75.19152832, 12.0893116], [75.19124603, 12.0893116], [75.19124603, 12.08986092], [75.19097137, 12.08986092], [75.19097137, 12.0901413], [75.1904068, 12.0901413], [75.1904068, 12.09042168], [75.18958282, 12.09041691], [75.18958282, 12.09069538], [75.18930817, 12.09069538], [75.18930817, 12.09097099], [75.18902588, 12.09097099], [75.18902588, 12.09125137], [75.18791962, 12.09125137], [75.18791962, 12.09097099], [75.18736267, 12.09097099], [75.18736267, 12.09069538], [75.18680573, 12.09069538], [75.18680573, 12.09097099], [75.18597412, 12.09097099], [75.18597412, 12.08986092], [75.18569183, 12.08986092], [75.18569183, 12.0893116], [75.18514252, 12.0893116], [75.18514252, 12.08902931], [75.18486023, 12.08902931], [75.18486023, 12.08874035], [75.18430328, 12.08874893], [75.18430328, 12.08819485], [75.18374634, 12.08819485], [75.18374634, 12.08763885], [75.18319702, 12.08763885], [75.18319702, 12.08736134], [75.18291473, 12.08736134], [75.18291473, 12.08680534], [75.18264008, 12.08681202], [75.18264008, 12.08653069], [75.18235779, 12.08653069], [75.18235779, 12.08597088], [75.18208313, 12.08597279], [75.18208313, 12.08569527], [75.18180847, 12.08570194], [75.18180847, 12.08514118], [75.18125153, 12.08514118], [75.18125153, 12.08431053], [75.18096924, 12.08431053], [75.18096924, 12.08403111], [75.18041992, 12.08403111], [75.18041992, 12.08375072], [75.17986298, 12.08375072], [75.17986298, 12.08347034], [75.17958069, 12.08347321], [75.17958069, 12.08319473], [75.17903137, 12.08319473], [75.17903137, 12.08291626], [75.17874908, 12.08291626], [75.17874908, 12.08319473], [75.17847443, 12.08319473], [75.17847443, 12.08347321], [75.17791748, 12.08347034], [75.17791748, 12.08375072], [75.17736053, 12.08375072], [75.17736053, 12.08403111], [75.17624664, 12.08403111], [75.17624664, 12.08375072], [75.17485809, 12.08375072], [75.17485809, 12.08403111], [75.17458344, 12.0840292], [75.17458344, 12.0848608], [75.17485809, 12.0848608], [75.17485809, 12.08542061], [75.17514038, 12.08541679], [75.17514038, 12.08597279], [75.17485809, 12.08597088], [75.17485809, 12.08681202], [75.17430878, 12.08680534], [75.17430878, 12.08708286], [75.17346954, 12.08708286], [75.17346954, 12.08597279], [75.17292023, 12.08597279], [75.17292023, 12.08569527], [75.17263794, 12.08570194], [75.17263794, 12.08653069], [75.17236328, 12.08652878], [75.17236328, 12.08874893], [75.17263794, 12.08874035], [75.17263794, 12.0893116], [75.17292023, 12.08930492], [75.17292023, 12.0895834], [75.17346954, 12.08958054], [75.17346954, 12.08986092], [75.17375183, 12.08986092], [75.17375183, 12.0901413], [75.17457581, 12.0901413], [75.17457581, 12.09042168], [75.17514038, 12.09042168], [75.17514038, 12.0901413], [75.17597198, 12.0901413], [75.17597198, 12.09042168], [75.17708588, 12.09042168], [75.17708588, 12.09125137], [75.17680359, 12.09125137], [75.17680359, 12.09180546], [75.17652893, 12.09180546], [75.17652893, 12.09208298], [75.17597198, 12.09208107], [75.17597198, 12.09264183], [75.17569733, 12.09264183], [75.17569733, 12.0929203], [75.17541504, 12.09291744], [75.17541504, 12.09347343], [75.17514038, 12.09347057], [75.17510986, 12.09403038], [75.17485809, 12.09402657], [75.17485809, 12.09458256], [75.17458344, 12.09458256], [75.17458344, 12.09597111], [75.17485809, 12.0959692], [75.17485809, 12.09653187], [75.17514038, 12.09653187], [75.17514038, 12.09681034], [75.17540741, 12.09681034], [75.17541504, 12.09736156], [75.17569733, 12.09736156], [75.17569733, 12.09764194], [75.17597198, 12.09764194], [75.17597198, 12.09793091], [75.17624664, 12.0979147], [75.17624664, 12.09819412], [75.17652893, 12.09819412], [75.17652893, 12.09847164], [75.17679596, 12.09847164], [75.17679596, 12.09875202], [75.17708588, 12.09875202], [75.17708588, 12.09902954], [75.17736053, 12.09902954], [75.17736053, 12.09875202], [75.17791748, 12.09875202], [75.17791748, 12.09847164], [75.17819214, 12.09847164], [75.17819214, 12.09819412], [75.17847443, 12.09819412], [75.17847443, 12.0979147], [75.17874908, 12.09793091], [75.17874908, 12.09708118], [75.17903137, 12.09708405], [75.17903137, 12.09691048], [75.17903137, 12.09680557], [75.17930603, 12.09681034], [75.17930603, 12.09624863], [75.17958069, 12.09624863], [75.17958069, 12.09569073], [75.17986298, 12.09569645], [75.17986298, 12.09514046], [75.18013763, 12.09514046], [75.18013763, 12.09487057], [75.18068695, 12.09487057], [75.18068695, 12.09458065], [75.18125153, 12.09458256], [75.18125153, 12.09430504], [75.18152618, 12.09430981], [75.18152618, 12.09403038], [75.18264008, 12.09403038], [75.18264008, 12.09375191], [75.18461609, 12.09374905], [75.18489075, 12.09374905], [75.18541718, 12.09375191], [75.18541718, 12.09347057], [75.18596649, 12.09347057], [75.18596649, 12.09375191], [75.18763733, 12.09375191], [75.18763733, 12.09403038], [75.18818665, 12.09403038], [75.18818665, 12.09430981], [75.18846893, 12.09430504], [75.18846893, 12.09458256], [75.18875122, 12.09458256], [75.18875122, 12.09500027], [75.18875122, 12.09514046], [75.18902588, 12.09514046], [75.18902588, 12.09569645], [75.18958282, 12.09569645], [75.18958282, 12.09597111], [75.18985748, 12.0959692], [75.18985748, 12.09624863], [75.19029999, 12.09624863], [75.1904068, 12.09624863], [75.1904068, 12.09653187], [75.19069672, 12.09653187], [75.19069672, 12.09681034], [75.19097137, 12.09680557], [75.19097137, 12.09708405], [75.19124603, 12.09708118], [75.19124603, 12.09764194], [75.19097137, 12.09764004], [75.19097137, 12.09819412], [75.19069672, 12.09819126], [75.19069672, 12.09902954], [75.19097137, 12.09902763], [75.19097137, 12.09958363], [75.19124603, 12.09957886], [75.19124603, 12.10013962], [75.19152832, 12.10013962], [75.19152832, 12.10042], [75.19264221, 12.10041809], [75.19264221, 12.1006937], [75.19291687, 12.10068035], [75.19291687, 12.10181141], [75.19264221, 12.10180569], [75.19264221, 12.10208416], [75.19291687, 12.10207939], [75.19291687, 12.10236168], [75.19319153, 12.10236168], [75.19319153, 12.10264015], [75.19291687, 12.10264015], [75.19291687, 12.10291958], [75.19319153, 12.10291576], [75.19319153, 12.10319424], [75.19347382, 12.10319424], [75.19347382, 12.10375023], [75.19319153, 12.10374069], [75.19319153, 12.10431099], [75.19347382, 12.10430622], [75.19347382, 12.10486221], [75.19319153, 12.10486031], [75.19319153, 12.10542107], [75.19291687, 12.1054163], [75.19291687, 12.10597229], [75.19264221, 12.10597038], [75.19264221, 12.10625267], [75.19235992, 12.10625267], [75.19235992, 12.10681057], [75.19208527, 12.1068058], [75.19208527, 12.10708427], [75.19152832, 12.10708046], [75.19152832, 12.10736275], [75.19180298, 12.10735989], [75.19180298, 12.10847187], [75.1920929, 12.10846996], [75.1920929, 12.11181068], [75.19374847, 12.11180687], [75.19374847, 12.11208344], [75.19403076, 12.11207962], [75.19403076, 12.11236095], [75.19431305, 12.11236095], [75.19431305, 12.11264133], [75.19541931, 12.11264133], [75.19541931, 12.11236095], [75.19596863, 12.11236095], [75.19596863, 12.11264133], [75.19625092, 12.11264133], [75.19625092, 12.1129303], [75.19652557, 12.11291695], [75.19654083, 12.11375141], [75.19625092, 12.11375141], [75.19625092, 12.11430931], [75.19596863, 12.11430931], [75.19596863, 12.11514091], [75.19568634, 12.11514091], [75.19568634, 12.11541939], [75.19596863, 12.11541653], [75.19596863, 12.115695], [75.19625092, 12.11568069], [75.19625092, 12.11625099], [75.19654083, 12.11625099], [75.19654083, 12.11653137], [75.19708252, 12.11653137], [75.19708252, 12.11681175], [75.19735718, 12.11681175], [75.19735718, 12.11736107], [75.19708252, 12.11736107], [75.19708252, 12.11764145], [75.19680786, 12.11764145], [75.19680786, 12.11792183], [75.19596863, 12.11791706], [75.19596863, 12.11819458], [75.19569397, 12.11819458], [75.19569397, 12.11847115], [75.19541931, 12.11847115], [75.19541931, 12.11875057], [75.19513702, 12.11875057], [75.19513702, 12.11903191], [75.19486237, 12.11903191], [75.19486237, 12.11931038], [75.19458008, 12.11930466], [75.19458008, 12.11958313], [75.19403076, 12.11958122], [75.19403076, 12.12042046], [75.19347382, 12.12041664], [75.19347382, 12.12069321], [75.19319153, 12.12069321], [75.19319153, 12.12097359], [75.19291687, 12.12097073], [75.19291687, 12.12152958], [75.19264221, 12.12152672], [75.19264221, 12.12236118], [75.19291687, 12.12235928], [75.19291687, 12.12292004], [75.19264221, 12.12291527], [75.19264221, 12.12347126], [75.19235992, 12.12347126], [75.19235992, 12.12375164], [75.1920929, 12.12375164], [75.1920929, 12.12403202], [75.19180298, 12.12403202], [75.19180298, 12.12430954], [75.19097137, 12.12430573], [75.19097137, 12.1245842], [75.19069672, 12.12458134], [75.19069672, 12.12487125], [75.1904068, 12.12487125], [75.1904068, 12.12514019], [75.19013977, 12.12514019], [75.19013977, 12.12541962], [75.18985748, 12.12541771], [75.18985748, 12.12569427], [75.19013977, 12.12569141], [75.19013977, 12.12625027], [75.18985748, 12.12625027], [75.18985748, 12.12681007], [75.18958282, 12.12680626], [75.18958282, 12.12736225], [75.18930817, 12.12736225], [75.18930817, 12.12791634], [75.18902588, 12.12791634], [75.18902588, 12.12819386], [75.18875122, 12.12819386], [75.18875122, 12.12958431], [75.18902588, 12.12957954], [75.18902588, 12.12985992], [75.18930817, 12.12985992], [75.18930817, 12.1301403], [75.18985748, 12.1301403], [75.18985748, 12.13042068], [75.19069672, 12.13042068], [75.19069672, 12.1301403], [75.19124603, 12.1301403], [75.19124603, 12.12985992], [75.19152832, 12.12985992], [75.19152832, 12.12957954], [75.19208527, 12.12958431], [75.19208527, 12.12985992], [75.19235992, 12.12985992], [75.19235992, 12.13125038], [75.1920929, 12.13125038], [75.1920929, 12.13153267], [75.19180298, 12.13153267], [75.19180298, 12.13181114], [75.1920929, 12.13181114], [75.1920929, 12.13264275], [75.19069672, 12.13264275], [75.19069672, 12.13236046], [75.18930817, 12.13236237], [75.18930817, 12.13208199], [75.18902588, 12.13208199], [75.18902588, 12.1315279], [75.18875122, 12.13153267], [75.18875122, 12.13125038], [75.18846893, 12.13125038], [75.18846893, 12.13097191], [75.18815613, 12.13097191], [75.18791962, 12.13097191], [75.18791962, 12.13041592], [75.18763733, 12.13042068], [75.18763733, 12.12985992], [75.18734741, 12.12985992], [75.18734741, 12.12957954], [75.18708038, 12.12958431], [75.18708038, 12.12819386], [75.18736267, 12.12819386], [75.18736267, 12.12791634], [75.18791962, 12.12791634], [75.18791962, 12.12736225], [75.18819427, 12.12736225], [75.18819427, 12.12708378], [75.18846893, 12.12708378], [75.18846893, 12.12680626], [75.18875122, 12.12681007], [75.18875122, 12.12625027], [75.18902588, 12.12625027], [75.18902588, 12.12569141], [75.18930817, 12.12569427], [75.18930817, 12.12541771], [75.18958282, 12.12541962], [75.18958282, 12.12514019], [75.18985748, 12.12514019], [75.18985748, 12.12458134], [75.18958282, 12.1245842], [75.18958282, 12.12374878], [75.18985748, 12.12375164], [75.18985748, 12.12347126], [75.19013977, 12.12347126], [75.19013977, 12.12319565], [75.19041443, 12.12319565], [75.19041443, 12.12180519], [75.19069672, 12.12180996], [75.19069672, 12.1212492], [75.19097137, 12.1212492], [75.19097137, 12.12042046], [75.19124603, 12.12042046], [75.19124603, 12.11986065], [75.19152832, 12.11986065], [75.19152832, 12.11903191], [75.19180298, 12.11903191], [75.19180298, 12.11847115], [75.19208527, 12.11847115], [75.19208527, 12.11763859], [75.19235992, 12.11764145], [75.19235992, 12.11681175], [75.1920929, 12.11681175], [75.1920929, 12.11653137], [75.19180298, 12.11653137], [75.19180298, 12.11625099], [75.19124603, 12.11625099], [75.19124603, 12.11597061], [75.19097137, 12.11597347], [75.19097137, 12.115695], [75.19081116, 12.115695], [75.19013977, 12.115695], [75.19013977, 12.11513901], [75.18985748, 12.11514091], [75.18985748, 12.11486053], [75.18958282, 12.11486053], [75.18958282, 12.11430454], [75.18930817, 12.11430931], [75.18930817, 12.11375141], [75.18902588, 12.11375141], [75.18902588, 12.11334991], [75.18902588, 12.11263943], [75.18930817, 12.11264133], [75.18930817, 12.11207962], [75.18985748, 12.11208344], [75.18985748, 12.11180687], [75.19013977, 12.11181068], [75.19013977, 12.11153126], [75.1904068, 12.11153126], [75.1904068, 12.11096954], [75.19069672, 12.11097336], [75.19069672, 12.11041737], [75.19097137, 12.11042118], [75.19097137, 12.10818958], [75.19069672, 12.10819435], [75.19069672, 12.1068058], [75.1904068, 12.10681057], [75.1904068, 12.10597038], [75.19013977, 12.10597229], [75.19013977, 12.10569382], [75.19041443, 12.10569382], [75.19041443, 12.10486221], [75.19069672, 12.10486221], [75.19069672, 12.10430622], [75.19124603, 12.10431099], [75.19124603, 12.10374069], [75.19152832, 12.10375023], [75.19152832, 12.10291576], [75.19180298, 12.10291958], [75.19180298, 12.10264015], [75.19152832, 12.10264015], [75.19152832, 12.10124969], [75.19069672, 12.10124969], [75.19069672, 12.10068035], [75.19041443, 12.1006937], [75.19041443, 12.0998621], [75.1902771, 12.0998621], [75.19013977, 12.0998621], [75.19013977, 12.09930611], [75.18985748, 12.09930992], [75.18985748, 12.09875202], [75.18958282, 12.09875202], [75.18958282, 12.09819126], [75.18930817, 12.09819412], [75.18930817, 12.09680557], [75.18902588, 12.09681034], [75.18902588, 12.09653187], [75.18875122, 12.09653187], [75.18875122, 12.09624863], [75.18763733, 12.09624863], [75.18763733, 12.09653187], [75.18653107, 12.09653187], [75.18653107, 12.09624863], [75.18486023, 12.09624863], [75.18486023, 12.0959692], [75.18458557, 12.09597111], [75.18458557, 12.09569645], [75.18374634, 12.09569645], [75.18374634, 12.09541798], [75.18319702, 12.09542179], [75.18318176, 12.09514046], [75.18180847, 12.09514046], [75.18180847, 12.09542179], [75.18125153, 12.09541798], [75.18125153, 12.09597111], [75.18096924, 12.09597111], [75.18096924, 12.09623146], [75.18096924, 12.09736156], [75.18068695, 12.09736156], [75.18068695, 12.09764194], [75.18041992, 12.09764194], [75.18041992, 12.09793091], [75.18013763, 12.0979147], [75.18013763, 12.09819412], [75.17986298, 12.09819412], [75.17986298, 12.09847164], [75.17958069, 12.09847164], [75.17958069, 12.09875202], [75.17903137, 12.09875202], [75.17903137, 12.09902954], [75.17874908, 12.09902763], [75.17874908, 12.09958363], [75.17847443, 12.09958363], [75.17847443, 12.0998621], [75.17817688, 12.09986019], [75.17817688, 12.10013962], [75.17791748, 12.10013962], [75.17791748, 12.10042], [75.17708588, 12.10041809], [75.17708588, 12.1006937], [75.17624664, 12.1006937], [75.17624664, 12.10097218], [75.17430878, 12.10097218], [75.17430878, 12.1006937], [75.17318726, 12.10068035], [75.17318726, 12.10264015], [75.17346954, 12.10264015], [75.17346954, 12.10347176], [75.17318726, 12.10346985], [75.17318726, 12.10681057], [75.17292023, 12.1068058], [75.17292023, 12.10819435], [75.17263794, 12.10818958], [75.17263794, 12.10875034], [75.17236328, 12.10875034], [75.17236328, 12.11208344], [75.17263794, 12.11207962], [75.17263794, 12.11264133], [75.17236328, 12.11263943], [75.17236328, 12.11319542], [75.17208099, 12.1131897], [75.17208099, 12.11375141], [75.17152405, 12.11375141], [75.17152405, 12.11458302], [75.17124939, 12.11458111], [75.17124939, 12.11514091], [75.17069244, 12.11514091], [75.17069244, 12.11541939], [75.16986084, 12.11541653], [75.16986084, 12.115695], [75.16874695, 12.11568069], [75.16874695, 12.11625099], [75.16819763, 12.11625099], [75.16819763, 12.11681175], [75.16791534, 12.11680508], [75.16792297, 12.11736107], [75.16764069, 12.11736107], [75.16764069, 12.11764145], [75.1673584, 12.11764145], [75.1673584, 12.11792183], [75.16623688, 12.11792183], [75.16623688, 12.11736107], [75.1654129, 12.11736107], [75.1654129, 12.11708069], [75.16513824, 12.1170826], [75.16513824, 12.11680508], [75.16486359, 12.11680508], [75.16486359, 12.1170826], [75.16374969, 12.11708069], [75.16374969, 12.11736107], [75.16291809, 12.11736107], [75.16291809, 12.11792183], [75.16236115, 12.11791706], [75.16236115, 12.11819458], [75.16208649, 12.11819458], [75.16208649, 12.11847115], [75.16179657, 12.11847115], [75.16179657, 12.11903191], [75.16152954, 12.11903191], [75.16152954, 12.11931038], [75.16124725, 12.11931038], [75.16124725, 12.12042046], [75.16152954, 12.12042046], [75.16152954, 12.12152958], [75.1618042, 12.12152672], [75.1618042, 12.12236118], [75.16208649, 12.12236118], [75.16208649, 12.12347126], [75.16236115, 12.12347126], [75.16236115, 12.12375164], [75.1626358, 12.12375164], [75.1626358, 12.12430954], [75.16291809, 12.12430954], [75.16291809, 12.12541962], [75.16317749, 12.12541962], [75.16317749, 12.12625027], [75.16347504, 12.12625027], [75.16347504, 12.12736225], [75.16374969, 12.12736225], [75.16374969, 12.13069439], [75.16401672, 12.13068867], [75.16401672, 12.13181114], [75.16430664, 12.13180637], [75.16430664, 12.13319016], [75.16401672, 12.13320065], [75.16401672, 12.13374996], [75.16374969, 12.13374996], [75.16374969, 12.13431072], [75.16346741, 12.13431072], [75.16346741, 12.13625145], [75.16317749, 12.13625145], [75.16317749, 12.13653088], [75.16291809, 12.13652897], [75.16291809, 12.1370821], [75.1626358, 12.13708019], [75.1626358, 12.13764095], [75.16208649, 12.13764095], [75.16208649, 12.13875103], [75.16179657, 12.13875103], [75.16179657, 12.13931084], [75.16152954, 12.13930511], [75.16152954, 12.13986111], [75.1609726, 12.13985157], [75.1609726, 12.14014053], [75.16069794, 12.14014053], [75.16069794, 12.14042091], [75.16041565, 12.1404171], [75.16041565, 12.14069462], [75.1598587, 12.14069462], [75.1598587, 12.14097309], [75.15957642, 12.14097118], [75.15957642, 12.14153099], [75.15930939, 12.14153099], [75.15930176, 12.14264107], [75.1590271, 12.14263916], [75.1590271, 12.14347267], [75.15847015, 12.14346886], [75.15847015, 12.14375114], [75.15791321, 12.14375114], [75.15791321, 12.14403152], [75.15763855, 12.14403152], [75.15763855, 12.1443119], [75.1570816, 12.14430523], [75.1570816, 12.14458275], [75.15680695, 12.14458275], [75.15680695, 12.14486122], [75.15651703, 12.14486122], [75.15651703, 12.14542198], [75.15625, 12.14541721], [75.15625, 12.14569473], [75.15598297, 12.14569092], [75.15598297, 12.14598179], [75.15569305, 12.14598179], [75.15569305, 12.14625072], [75.1554184, 12.14625072], [75.1554184, 12.14680958], [75.15486145, 12.14680958], [75.15486145, 12.14763927], [75.15458679, 12.14763927], [75.15458679, 12.14847088], [75.15429688, 12.14847088], [75.15429688, 12.14904118], [75.15402985, 12.14904118], [75.15402985, 12.14931011], [75.15374756, 12.14930534], [75.15374756, 12.15208435], [75.1534729, 12.15208054], [75.1534729, 12.15375042], [75.15319824, 12.15375042], [75.15319824, 12.15458393], [75.1534729, 12.15458202], [75.1534729, 12.15513992], [75.15374756, 12.15513992], [75.15374756, 12.15764046], [75.1534729, 12.15764046], [75.1534729, 12.15903091], [75.15319824, 12.15902805], [75.15319824, 12.15958214], [75.15291595, 12.15958214], [75.15291595, 12.16069412], [75.1526413, 12.16069031], [75.1526413, 12.16125011], [75.15235901, 12.16125011], [75.15235901, 12.16181087], [75.15207672, 12.16181087], [75.15207672, 12.16264057], [75.15180206, 12.16263771], [75.15180206, 12.1631937], [75.1515274, 12.1631937], [75.1515274, 12.16402912], [75.15123749, 12.16401958], [75.15123749, 12.16431141], [75.15097046, 12.16431141], [75.15097046, 12.16514111], [75.1506958, 12.1651392], [75.1506958, 12.16569519], [75.15040588, 12.16569042], [75.15040588, 12.16625118], [75.15013885, 12.16625118], [75.15013885, 12.16708279], [75.14985657, 12.16707993], [75.14985657, 12.16764069], [75.14958191, 12.16763878], [75.14958191, 12.16847324], [75.14930725, 12.16847134], [75.14930725, 12.16902924], [75.14902496, 12.16902924], [75.14902496, 12.16958332], [75.14820099, 12.16958141], [75.14820099, 12.16986084], [75.14763641, 12.16986084], [75.14763641, 12.17015266], [75.14736176, 12.17015266], [75.14736176, 12.1704216], [75.14680481, 12.17041683], [75.14680481, 12.1706953], [75.14653015, 12.1706953], [75.14653015, 12.17097092], [75.14624786, 12.17097092], [75.14624786, 12.1712513], [75.14597321, 12.1712513], [75.14597321, 12.17181015], [75.14569092, 12.17180538], [75.14569092, 12.1720829], [75.14541626, 12.1720829], [75.14541626, 12.17236137], [75.1451416, 12.17236137], [75.1451416, 12.17292023], [75.14485931, 12.17291737], [75.14485931, 12.17347336], [75.14457703, 12.17347145], [75.14457703, 12.1740303], [75.14430237, 12.17402744], [75.14430237, 12.17458344], [75.14402771, 12.17458057], [75.14402771, 12.17486095], [75.14375305, 12.17486095], [75.14375305, 12.17541981], [75.14347076, 12.17541695], [75.14347076, 12.17597103], [75.14319611, 12.17595959], [75.14319611, 12.17653179], [75.14291382, 12.17652702], [75.14291382, 12.17708397], [75.14263916, 12.17708397], [75.14263916, 12.17819309], [75.14235687, 12.17819118], [75.14235687, 12.18013954], [75.14263916, 12.18013954], [75.14263916, 12.18153], [75.14235687, 12.18153], [75.1423645, 12.1823597], [75.14206696, 12.1823597], [75.14206696, 12.18292046], [75.14180756, 12.18291569], [75.14180756, 12.18347168], [75.1415329, 12.18347168], [75.1415329, 12.18402958], [75.14068604, 12.18402958], [75.14068604, 12.18431091], [75.14013672, 12.18430614], [75.14013672, 12.18458366], [75.13930511, 12.18458366], [75.13930511, 12.18486214], [75.13903046, 12.18486023], [75.13903046, 12.18514919], [75.13819122, 12.18514919], [75.13819122, 12.18542099], [75.13735962, 12.18541622], [75.13735962, 12.18569374], [75.13709259, 12.18569183], [75.13709259, 12.18624973], [75.13680267, 12.18624973], [75.13680267, 12.18653107], [75.13652802, 12.18653107], [75.13652802, 12.18681145], [75.13626099, 12.18681145], [75.13626099, 12.18792057], [75.13597107, 12.1879158], [75.13597107, 12.18819427], [75.13625336, 12.18819427], [75.13626099, 12.18847179], [75.13597107, 12.18847179], [75.13597107, 12.18931103], [75.13569641, 12.18931103], [75.13569641, 12.1904211], [75.13540649, 12.1904211], [75.13540649, 12.19153118], [75.13513947, 12.19153118], [75.13513947, 12.19181061], [75.13485718, 12.19181061], [75.13485718, 12.19236088], [75.13458252, 12.19236088], [75.13458252, 12.19292068], [75.13402557, 12.19291687], [75.13402557, 12.19319534], [75.13375092, 12.19318962], [75.13375092, 12.19375134], [75.13346863, 12.19375134], [75.13346863, 12.19430923], [75.1332016, 12.19430923], [75.1332016, 12.19541931], [75.13291931, 12.1954174], [75.13291931, 12.1959734], [75.13263702, 12.19597054], [75.13263702, 12.19681168], [75.13236237, 12.196805], [75.13236237, 12.19819546], [75.13208008, 12.19819069], [75.13208008, 12.1993103], [75.13236237, 12.19930458], [75.13236237, 12.19958305], [75.13263702, 12.19958305], [75.13263702, 12.19986057], [75.13291931, 12.19986057], [75.13291931, 12.20069313], [75.13263702, 12.20069122], [75.13263702, 12.20263863], [75.13236237, 12.20263863], [75.13236237, 12.20291996], [75.13208008, 12.20291805], [75.13208008, 12.20347118], [75.13181305, 12.20346928], [75.13181305, 12.20375156], [75.13153076, 12.20375156], [75.13153076, 12.20403194], [75.13124847, 12.20403194], [75.13124847, 12.20431042], [75.13096619, 12.20431042], [75.13096619, 12.20514202], [75.13069153, 12.20514011], [75.13069153, 12.2070837], [75.13041687, 12.20708179], [75.13041687, 12.20792007], [75.13014221, 12.20791626], [75.13014221, 12.20819378], [75.12985992, 12.20819092], [75.12985992, 12.20932198], [75.12958527, 12.20930576], [75.12958527, 12.21097183], [75.12930298, 12.21097183], [75.12930298, 12.21152973], [75.12902832, 12.21152782], [75.12902832, 12.21208191], [75.12847137, 12.21208382], [75.12847137, 12.21236229], [75.12763977, 12.21236038], [75.12763977, 12.21264267], [75.12680817, 12.21264267], [75.12680817, 12.21292114], [75.12596893, 12.21292114], [75.12596893, 12.21264267], [75.12513733, 12.21264267], [75.12513733, 12.21292114], [75.12486267, 12.21291637], [75.12486267, 12.21319389], [75.12430573, 12.21319389], [75.12430573, 12.21347237], [75.12403107, 12.21347046], [75.12403107, 12.21375275], [75.12346649, 12.21375275], [75.12346649, 12.21403122], [75.1220932, 12.21403122], [75.1220932, 12.21375275], [75.12152863, 12.21375275], [75.12152863, 12.21319199], [75.12124634, 12.21319389], [75.12124634, 12.2126379], [75.12097168, 12.21264267], [75.12097168, 12.21207142], [75.12069702, 12.21208191], [75.12069702, 12.21152782], [75.1204071, 12.21152973], [75.1204071, 12.21097183], [75.12014008, 12.21097183], [75.12014008, 12.21069431], [75.12041473, 12.21069431], [75.12041473, 12.21041584], [75.12014008, 12.21041965], [75.12014008, 12.20985985], [75.12041473, 12.20985985], [75.12041473, 12.20930576], [75.12069702, 12.20932198], [75.12069702, 12.20874977], [75.12097168, 12.20874977], [75.12097168, 12.20819092], [75.12124634, 12.20819378], [75.12124634, 12.20763779], [75.12152863, 12.20763969], [75.12152863, 12.20681], [75.12180328, 12.20681], [75.12180328, 12.20596886], [75.12208557, 12.20597172], [75.12208557, 12.20514011], [75.12236023, 12.20514202], [75.12236023, 12.20486164], [75.12208557, 12.20486164], [75.12208557, 12.20430565], [75.12180328, 12.20431042], [75.12180328, 12.20403194], [75.12152863, 12.20403194], [75.12152863, 12.20375156], [75.1212616, 12.20375156], [75.1212616, 12.20346928], [75.12068176, 12.20346928], [75.11985779, 12.20346928], [75.11985779, 12.20375156], [75.11958313, 12.20375156], [75.11958313, 12.20431042], [75.11930847, 12.20431042], [75.11930847, 12.20486164], [75.11902618, 12.20486164], [75.11902618, 12.20514202], [75.11875153, 12.20514202], [75.11875153, 12.20541954], [75.11846924, 12.20541763], [75.11846924, 12.2056942], [75.11791992, 12.20569134], [75.11791992, 12.20625019], [75.11763763, 12.20625019], [75.11763763, 12.2070837], [75.11736298, 12.20708179], [75.11736298, 12.20763969], [75.11708069, 12.20763969], [75.11708069, 12.20874977], [75.11680603, 12.20874977], [75.11680603, 12.20958424], [75.11653137, 12.20957947], [75.11653137, 12.21014023], [75.11624908, 12.21014023], [75.11624908, 12.21069431], [75.1159668, 12.21068859], [75.1159668, 12.21125031], [75.11569214, 12.21125031], [75.11569214, 12.21208191], [75.11541748, 12.21207142], [75.11541748, 12.21264267], [75.11513519, 12.2126379], [75.11513519, 12.21319389], [75.11486053, 12.21319199], [75.11486053, 12.21403122], [75.11458588, 12.21402836], [75.11458588, 12.21513844], [75.11429596, 12.2151289], [75.11429596, 12.21542072], [75.11402893, 12.21542072], [75.11402893, 12.2165308], [75.11374664, 12.2165308], [75.11374664, 12.21764088], [75.11347198, 12.21763802], [75.11347198, 12.21847343], [75.11319733, 12.21846962], [75.11319733, 12.21903133], [75.11292267, 12.21903133], [75.11292267, 12.21931076], [75.11264038, 12.21931076], [75.11264038, 12.21986103], [75.11235809, 12.21986103], [75.11235809, 12.22069454], [75.11206818, 12.22068977], [75.11206818, 12.22153091], [75.11180878, 12.22152901], [75.11180878, 12.22236061], [75.11152649, 12.22236061], [75.11152649, 12.22292233], [75.11125183, 12.22292233], [75.11125183, 12.22375107], [75.11096954, 12.22375107], [75.11096954, 12.22458267], [75.11068726, 12.2245779], [75.11068726, 12.22514057], [75.11042023, 12.22513866], [75.11042023, 12.22597313], [75.11013794, 12.22597122], [75.11013794, 12.22681046], [75.10986328, 12.22681046], [75.10986328, 12.22736073], [75.10958099, 12.22736073], [75.10958099, 12.22819328], [75.10932159, 12.22819138], [75.10932159, 12.22902966], [75.10902405, 12.22902679], [75.10902405, 12.22986126], [75.10874939, 12.22986126], [75.10874939, 12.23069572], [75.10847473, 12.23069572], [75.10847473, 12.23124886], [75.10819244, 12.23124886], [75.10819244, 12.23208427], [75.10791779, 12.23208141], [75.10791779, 12.23291969], [75.1076355, 12.23291779], [75.10764313, 12.23375034], [75.10736084, 12.23375034], [75.10736084, 12.23431015], [75.10708618, 12.23431015], [75.10707092, 12.23513985], [75.10680389, 12.23513985], [75.10680389, 12.23550034], [75.10680389, 12.2359724], [75.10652924, 12.2359724], [75.10652924, 12.23617935], [75.10652924, 12.23681068], [75.10626984, 12.23681068], [75.10624695, 12.23764038], [75.10597229, 12.23763847], [75.10597229, 12.2381916], [75.10569763, 12.23820972], [75.10569763, 12.23903275], [75.10541534, 12.23902798], [75.10541534, 12.23986244], [75.10514069, 12.23985958], [75.10514069, 12.2404213], [75.10498047, 12.24041843], [75.1048584, 12.24041557], [75.1048584, 12.24082184], [75.1048584, 12.24125004], [75.10457611, 12.24125004], [75.10457611, 12.2418108], [75.10430908, 12.2418108], [75.10430908, 12.24264145], [75.10402679, 12.24263763], [75.10402679, 12.24319363], [75.10375214, 12.24319172], [75.10375214, 12.24375057], [75.10346985, 12.24375057], [75.10346985, 12.24458218], [75.10318756, 12.24458027], [75.10318756, 12.24514103], [75.1029129, 12.24513912], [75.1029129, 12.2453804], [75.1029129, 12.24597263], [75.10276794, 12.24597263], [75.10263824, 12.24597263], [75.10263824, 12.24652195], [75.10236359, 12.24652863], [75.10236359, 12.24736118], [75.1020813, 12.24736118], [75.1020813, 12.24792099], [75.10180664, 12.24792099], [75.10180664, 12.24875069], [75.10151672, 12.24875069], [75.10151672, 12.2493124], [75.10124969, 12.2493124], [75.10124969, 12.25014114], [75.10097504, 12.25013924], [75.10097504, 12.25069523], [75.10069275, 12.25069523], [75.10069275, 12.25125122], [75.10041809, 12.25125122], [75.10041809, 12.25208282], [75.10015106, 12.25208092], [75.10015106, 12.25264072], [75.09986115, 12.25263882], [75.09986115, 12.25347328], [75.09958649, 12.25347137], [75.09958649, 12.25402927], [75.09929657, 12.25402927], [75.09929657, 12.25486088], [75.09902954, 12.25486088], [75.09902954, 12.25569534], [75.09874725, 12.25569057], [75.09874725, 12.25652981], [75.0984726, 12.25652695], [75.0984726, 12.25708294], [75.09819794, 12.25708103], [75.09819794, 12.25792027], [75.09792328, 12.25792027], [75.09792328, 12.25875187], [75.09764099, 12.25874996], [75.09764099, 12.25958443], [75.0973587, 12.25958061], [75.0973587, 12.26014042], [75.09708405, 12.26013756], [75.09708405, 12.26097202], [75.09680939, 12.26097202], [75.09680176, 12.26152992], [75.0965271, 12.26152802], [75.0965271, 12.2634716], [75.09625244, 12.2634697], [75.09625244, 12.26375008], [75.09597015, 12.26375008], [75.09597015, 12.26403046], [75.09570313, 12.26403046], [75.09570313, 12.26431274], [75.09541321, 12.26430607], [75.09541321, 12.26486206], [75.09513855, 12.26486015], [75.09513855, 12.26542091], [75.09486389, 12.26541615], [75.09486389, 12.26624966], [75.0945816, 12.26624107], [75.0945816, 12.26681137], [75.09430695, 12.26681137], [75.09430695, 12.26735973], [75.09402466, 12.26735973], [75.09402466, 12.2681942], [75.09375, 12.26819038], [75.09375, 12.26875019], [75.09348297, 12.26875019], [75.09348297, 12.26931095], [75.09319305, 12.26931095], [75.09319305, 12.27014065], [75.0929184, 12.27013779], [75.0929184, 12.27069378], [75.09263611, 12.27068996], [75.09263611, 12.27125072], [75.09236145, 12.27125072], [75.09236145, 12.27208233], [75.09208679, 12.27208042], [75.09208679, 12.27264118], [75.0918045, 12.27263927], [75.0918045, 12.27319527], [75.09152985, 12.27318954], [75.09152985, 12.27403069], [75.09124756, 12.27402878], [75.09124756, 12.27458286], [75.09095764, 12.27458], [75.09095764, 12.27514076], [75.09069824, 12.27513885], [75.09069824, 12.27597332], [75.09041595, 12.27597141], [75.09041595, 12.27653122], [75.0901413, 12.2765274], [75.0901413, 12.2770834], [75.08985901, 12.27708054], [75.08985901, 12.27792168], [75.08958435, 12.27791691], [75.08958435, 12.27847099], [75.08930206, 12.27847099], [75.08930206, 12.27902889], [75.0890274, 12.27902699], [75.0890274, 12.27986145], [75.08875275, 12.27986145], [75.08875275, 12.2804203], [75.08847046, 12.28041744], [75.08847046, 12.28097343], [75.08821106, 12.28097057], [75.08821106, 12.28180981], [75.08789825, 12.28180981], [75.08789825, 12.28236103], [75.08763885, 12.28236103], [75.08763885, 12.28292179], [75.08735657, 12.28292179], [75.08735657, 12.28375244], [75.08708191, 12.28375244], [75.08708191, 12.28431034], [75.08680725, 12.28431034], [75.08680725, 12.28514194], [75.08652496, 12.28514004], [75.08652496, 12.28569317], [75.08625031, 12.28569126], [75.08625031, 12.28625202], [75.08597565, 12.28625011], [75.08597565, 12.28708363], [75.08569336, 12.28707886], [75.08569336, 12.28763962], [75.0854187, 12.28763771], [75.0854187, 12.2881937], [75.08515167, 12.28819084], [75.08515167, 12.28903008], [75.08486176, 12.28902817], [75.08486176, 12.28958416], [75.0845871, 12.28957939], [75.0845871, 12.29014015], [75.08430481, 12.29014015], [75.08430481, 12.29097176], [75.08403015, 12.29096985], [75.08403015, 12.29152966], [75.08374786, 12.29152775], [75.08374786, 12.29208374], [75.08347321, 12.29208183], [75.08347321, 12.29292107], [75.08319092, 12.29292107], [75.08319092, 12.29348087], [75.08291626, 12.29348087], [75.08291626, 12.29403114], [75.0826416, 12.29403114], [75.0826416, 12.29486179], [75.08235931, 12.29486179], [75.08235931, 12.29542065], [75.08208466, 12.29541588], [75.08208466, 12.29597187], [75.08180237, 12.29596996], [75.08180237, 12.2968111], [75.08152771, 12.29680443], [75.08152771, 12.29736042], [75.08125305, 12.29736042], [75.08125305, 12.29792118], [75.08097076, 12.29792118], [75.08097076, 12.29875088], [75.08069611, 12.29875088], [75.08069611, 12.29931068], [75.08040619, 12.29931068], [75.08040619, 12.29986095], [75.08013916, 12.29986095], [75.08013916, 12.30069542], [75.07985687, 12.3006897], [75.07985687, 12.30125141], [75.07958221, 12.30125141], [75.07958221, 12.30208302], [75.07930756, 12.30208015], [75.07930756, 12.30264091], [75.07902527, 12.30263901], [75.07902527, 12.303195], [75.07875061, 12.30319023], [75.07875061, 12.30403137], [75.07847595, 12.3040266], [75.07847595, 12.3045826], [75.07818604, 12.30458069], [75.07818604, 12.30514145], [75.07791901, 12.30513859], [75.07791901, 12.30597305], [75.07763672, 12.30597115], [75.07763672, 12.30653191], [75.07736206, 12.30652714], [75.07736206, 12.30708313], [75.07707977, 12.30708122], [75.07707977, 12.30792046], [75.07681274, 12.30792046], [75.07681274, 12.30848026], [75.07653046, 12.30848026], [75.07653046, 12.30902958], [75.07624817, 12.30902672], [75.07624817, 12.30986118], [75.07595825, 12.30985928], [75.07595825, 12.31042194], [75.07569122, 12.31042194], [75.07569122, 12.31125164], [75.07541656, 12.31125164], [75.07541656, 12.31180954], [75.07514191, 12.31180573], [75.07514191, 12.31236172], [75.07485962, 12.31236172], [75.07485962, 12.31319427], [75.07458496, 12.31319427], [75.07459259, 12.31375027], [75.07430267, 12.31375027], [75.07430267, 12.31431007], [75.07402802, 12.31430626], [75.07402802, 12.31486225], [75.07375336, 12.31486225], [75.07375336, 12.31569386], [75.07347107, 12.31569099], [75.07347107, 12.31653023], [75.07319641, 12.31652832], [75.07319641, 12.31708431], [75.07292175, 12.31707859], [75.07292175, 12.31791973], [75.07263947, 12.31791592], [75.07263947, 12.31819439], [75.07235718, 12.31819153], [75.07235718, 12.31903267], [75.07208252, 12.3190279], [75.07208252, 12.31986237], [75.07180786, 12.31986046], [75.07180786, 12.32014275], [75.0715332, 12.32014275], [75.0715332, 12.32042122], [75.07125092, 12.32042122], [75.07125092, 12.32124996], [75.07096863, 12.32124996], [75.07096863, 12.3215313], [75.07068634, 12.3215313], [75.07068634, 12.32236004], [75.07041931, 12.32236004], [75.07041931, 12.3229208], [75.07013702, 12.32291603], [75.07013702, 12.32347202], [75.06986237, 12.32346058], [75.06986237, 12.32403088], [75.06958008, 12.32402897], [75.06958008, 12.32485962], [75.06930542, 12.32485962], [75.06931305, 12.32530022], [75.06931305, 12.32542133], [75.06919098, 12.32541943], [75.06903076, 12.32541656], [75.06903076, 12.32559013], [75.06903076, 12.32597256], [75.06886292, 12.32597256], [75.06874847, 12.32597256], [75.06874847, 12.32629204], [75.06874847, 12.32652569], [75.06847382, 12.32652569], [75.06847382, 12.32707977], [75.06847382, 12.32736111], [75.06819153, 12.32736111], [75.06819153, 12.32792091], [75.06791687, 12.3279171], [75.06791687, 12.32847309], [75.06764221, 12.32847309], [75.06764221, 12.3293047], [75.06735992, 12.3293047], [75.06735992, 12.32947063], [75.06735992, 12.32986069], [75.06707764, 12.32987022], [75.06707764, 12.3304224], [75.06694794, 12.33041668], [75.06680298, 12.33041668], [75.06679535, 12.33095932], [75.06678772, 12.33125114], [75.06652832, 12.33125114], [75.06652832, 12.33153057], [75.06625366, 12.33152676], [75.06624603, 12.33236122], [75.06624603, 12.33265114], [75.06613159, 12.33263874], [75.06597137, 12.33263874], [75.06597137, 12.33302021], [75.06597137, 12.33319473], [75.06569672, 12.33319473], [75.06569672, 12.33347321], [75.0654068, 12.3334713], [75.0654068, 12.33430958], [75.06513977, 12.33430481], [75.06513977, 12.33458328], [75.06485748, 12.33458328], [75.06485748, 12.33491135], [75.06485748, 12.33513927], [75.06458282, 12.33513927], [75.06458282, 12.33624935], [75.06430817, 12.33624935], [75.06430817, 12.33652973], [75.06401825, 12.33652973], [75.06401825, 12.33681011], [75.06375122, 12.33680534], [75.06375122, 12.33736134], [75.06346893, 12.33736134], [75.06346893, 12.33792019], [75.06319427, 12.33791542], [75.06319427, 12.33802032], [75.06319427, 12.3381958], [75.06346893, 12.3381958], [75.06346893, 12.33847141], [75.06318665, 12.33845997], [75.06318665, 12.33930969], [75.06291962, 12.33930969], [75.06291962, 12.33986187], [75.06263733, 12.33986187], [75.06263733, 12.34014034], [75.06236267, 12.34014034], [75.06236267, 12.34029007], [75.06236267, 12.34041977], [75.06263733, 12.34041786], [75.06263733, 12.34069443], [75.06319427, 12.34069443], [75.06319427, 12.34013653], [75.06346893, 12.34014034], [75.06346893, 12.33986187], [75.06318665, 12.33986187], [75.06318665, 12.33958054], [75.06346893, 12.33958435], [75.06346893, 12.33902836], [75.06375122, 12.33903027], [75.06375122, 12.33875179], [75.06401825, 12.33875179], [75.06401825, 12.33819103], [75.06430817, 12.3381958], [75.06430817, 12.33791542], [75.06401825, 12.33792019], [75.06401825, 12.33736134], [75.06430817, 12.33736134], [75.06430817, 12.33708286], [75.06458282, 12.33708286], [75.06458282, 12.33680534], [75.06485748, 12.33681011], [75.06485748, 12.33624935], [75.06513977, 12.33624935], [75.06513977, 12.33569145], [75.06541443, 12.33569527], [75.06541443, 12.33597088], [75.06569672, 12.33597088], [75.06569672, 12.33624935], [75.0654068, 12.33624935], [75.0654068, 12.33764172], [75.06513977, 12.33763981], [75.06513977, 12.33958435], [75.06485748, 12.33958054], [75.06485748, 12.34181023], [75.06458282, 12.34181023], [75.06458282, 12.3429203], [75.06430817, 12.34291553], [75.06430817, 12.34347153], [75.06401825, 12.34346962], [75.06401825, 12.34403038], [75.06375122, 12.34403038], [75.06375122, 12.34459114], [75.06346893, 12.34459114], [75.06346893, 12.34514046], [75.06319427, 12.3451376], [75.06319427, 12.34569359], [75.06291962, 12.34569359], [75.06291962, 12.34597206], [75.06263733, 12.34597015], [75.06263733, 12.34652996], [75.06236267, 12.34652805], [75.06236267, 12.34708214], [75.06208038, 12.34708023], [75.06208038, 12.34903145], [75.06180573, 12.34902763], [75.06180573, 12.34958363], [75.06153107, 12.34958172], [75.06153107, 12.35014057], [75.06124878, 12.35013771], [75.06124878, 12.3506937], [75.06098175, 12.3506918], [75.06098175, 12.35125065], [75.06069183, 12.35125065], [75.06069183, 12.35235977], [75.06041718, 12.35235977], [75.06041718, 12.35264111], [75.06014252, 12.3526392], [75.06014252, 12.35319519], [75.05986023, 12.35319042], [75.05986023, 12.35403061], [75.0595932, 12.35403061], [75.0595932, 12.35514069], [75.05930328, 12.35513878], [75.05930328, 12.35569477], [75.05902863, 12.35569477], [75.05902863, 12.35597324], [75.05874634, 12.35597134], [75.05874634, 12.35682106], [75.05847168, 12.35680485], [75.05847168, 12.35708332], [75.05821228, 12.35708141], [75.05821228, 12.35764122], [75.05791473, 12.35763931], [75.05791473, 12.35847092], [75.05764008, 12.35847092], [75.05764008, 12.35958958], [75.05735779, 12.35958958], [75.05735779, 12.36013889], [75.05708313, 12.36013889], [75.05708313, 12.36152935], [75.05680847, 12.36152935], [75.05680847, 12.36236095], [75.05652618, 12.36236095], [75.05652618, 12.36263943], [75.05569458, 12.36263943], [75.05569458, 12.36236095], [75.05541992, 12.36236095], [75.05541992, 12.36097145], [75.05569458, 12.36097336], [75.05569458, 12.36041737], [75.05596924, 12.36041927], [75.05596924, 12.35931015], [75.05625153, 12.35931015], [75.05625153, 12.3587513], [75.05652618, 12.3587513], [75.05652618, 12.35819054], [75.05680847, 12.3581953], [75.05680847, 12.35708332], [75.05708313, 12.35708332], [75.05708313, 12.35541725], [75.05735779, 12.35542107], [75.05735779, 12.35486126], [75.05764008, 12.35486126], [75.05764008, 12.35458279], [75.05819702, 12.35458279], [75.05819702, 12.3540287], [75.05847168, 12.35403061], [75.05847168, 12.35346127], [75.05874634, 12.35347271], [75.05874634, 12.35319519], [75.05902863, 12.35319519], [75.05902863, 12.35152912], [75.05930328, 12.35153103], [75.05930328, 12.3506918], [75.05958557, 12.3506937], [75.05958557, 12.35013771], [75.05986023, 12.35014057], [75.05986023, 12.34958172], [75.06014252, 12.34958363], [75.06014252, 12.34902763], [75.06041718, 12.34903145], [75.06041718, 12.34846973], [75.06069183, 12.34847164], [75.06069183, 12.34791565], [75.06098175, 12.34792137], [75.06098175, 12.34624958], [75.06124878, 12.34624958], [75.06124878, 12.34597015], [75.06097412, 12.34597206], [75.06097412, 12.34541607], [75.06124878, 12.34542274], [75.06124878, 12.34459114], [75.06153107, 12.34459114], [75.06153107, 12.34375], [75.06181335, 12.34375], [75.06181335, 12.34346962], [75.06208038, 12.34347153], [75.06208038, 12.34319401], [75.06236267, 12.34319401], [75.06236267, 12.34208393], [75.06263733, 12.34208393], [75.06263733, 12.34097195], [75.06208801, 12.34097195], [75.06208038, 12.34125042], [75.06180573, 12.34125042], [75.06180573, 12.34181023], [75.06180573, 12.34208393], [75.06153107, 12.34208393], [75.06153107, 12.34256172], [75.06153107, 12.34263992], [75.06124878, 12.34263992], [75.06124878, 12.34319401], [75.06097412, 12.34319401], [75.06098175, 12.34363079], [75.06098175, 12.34403038], [75.06069183, 12.34403038], [75.06069183, 12.34459114], [75.06041718, 12.34459114], [75.06041718, 12.34542274], [75.06014252, 12.34541607], [75.06014252, 12.34597206], [75.05986023, 12.34597015], [75.05986023, 12.34652996], [75.05958557, 12.34652805], [75.05958557, 12.34708214], [75.05930328, 12.34708023], [75.05930328, 12.34764862], [75.05902863, 12.34763813], [75.05902863, 12.34819412], [75.05874634, 12.34819031], [75.05874634, 12.34903145], [75.05847168, 12.34902763], [75.05847168, 12.34958363], [75.05821228, 12.34958172], [75.05821228, 12.35014057], [75.05791473, 12.35013771], [75.05791473, 12.3506937], [75.05764008, 12.3506918], [75.05764008, 12.35125065], [75.05735779, 12.35125065], [75.05735779, 12.35208225], [75.05708313, 12.35208035], [75.05708313, 12.35264111], [75.05680847, 12.3526392], [75.05680847, 12.35319519], [75.05652618, 12.35319519], [75.05652618, 12.35327435], [75.05652618, 12.35375118], [75.05625153, 12.35375118], [75.05625153, 12.35431099], [75.05596924, 12.35430527], [75.05596924, 12.35486126], [75.05569458, 12.35486126], [75.05569458, 12.35569477], [75.05541992, 12.35569477], [75.05541992, 12.35624886], [75.05513763, 12.35624886], [75.05513763, 12.35708332], [75.05484772, 12.35708141], [75.05484772, 12.35764122], [75.05458069, 12.35763931], [75.05458069, 12.3581953], [75.05430603, 12.35819054], [75.05430603, 12.35903168], [75.05403137, 12.35903168], [75.05403137, 12.35958958], [75.05374908, 12.35958958], [75.05374908, 12.36041927], [75.05347443, 12.36041737], [75.05347443, 12.36097336], [75.05319214, 12.36097145], [75.05319214, 12.36152935], [75.05291748, 12.36152935], [75.05291748, 12.36236095], [75.05264282, 12.36236095], [75.05264282, 12.36291981], [75.05236053, 12.36291981], [75.05236053, 12.36375237], [75.05207825, 12.36375237], [75.05207825, 12.36431026], [75.05180359, 12.36430454], [75.05180359, 12.36486244], [75.05152893, 12.36486244], [75.05152893, 12.36542034], [75.05124664, 12.36541843], [75.05124664, 12.36597061], [75.05097198, 12.36597061], [75.05097198, 12.36653042], [75.05069733, 12.36653042], [75.05069733, 12.36736202], [75.05042267, 12.36736202], [75.05042267, 12.36791992], [75.05014038, 12.36791801], [75.05014038, 12.3684721], [75.04985809, 12.36846924], [75.04985809, 12.36903], [75.04958344, 12.36902809], [75.04958344, 12.36958408], [75.04930878, 12.36957932], [75.04930878, 12.37014008], [75.04902649, 12.37014008], [75.04902649, 12.37097168], [75.04875183, 12.37096977], [75.04875183, 12.37152958], [75.04846954, 12.37152767], [75.04846954, 12.37208366], [75.04818726, 12.37207985], [75.04818726, 12.37263966], [75.04792023, 12.37263775], [75.04792023, 12.37319374], [75.04763794, 12.37319183], [75.04763794, 12.37374973], [75.04736328, 12.37374973], [75.04736328, 12.3745842], [75.04708099, 12.37457085], [75.04708099, 12.37514019], [75.04680634, 12.37513828], [75.04680634, 12.37569427], [75.04651642, 12.37569046], [75.04651642, 12.37625027], [75.04624939, 12.37625027], [75.04624939, 12.37681103], [75.04597473, 12.37680435], [75.04597473, 12.37736034], [75.04569244, 12.37736034], [75.04569244, 12.3779211], [75.04541779, 12.37791634], [75.04541779, 12.37847328], [75.04514313, 12.37847042], [75.04514313, 12.37903118], [75.04486084, 12.37902641], [75.04486084, 12.37958241], [75.04473114, 12.37958241], [75.04458618, 12.37958241], [75.04458618, 12.37983131], [75.04458618, 12.38014126], [75.04429626, 12.38014126], [75.04429626, 12.38070202], [75.04402924, 12.38070202], [75.04402924, 12.38125134], [75.04374695, 12.38125134], [75.04374695, 12.38153076], [75.04347229, 12.38152885], [75.04347229, 12.38208294], [75.04319763, 12.38208008], [75.04319763, 12.38264084], [75.04291534, 12.38263893], [75.04290771, 12.38319016], [75.04264069, 12.3832016], [75.04264069, 12.38376045], [75.0423584, 12.38376045], [75.0423584, 12.38431168], [75.04208374, 12.384305], [75.04208374, 12.38458347], [75.04180908, 12.38458061], [75.04180908, 12.38514137], [75.04152679, 12.38513947], [75.04152679, 12.38569546], [75.04125214, 12.38569069], [75.04125214, 12.38625145], [75.04096985, 12.38625145], [75.04096985, 12.38680458], [75.04069519, 12.38680458], [75.04069519, 12.38736057], [75.0404129, 12.38736057], [75.0404129, 12.38792038], [75.04013824, 12.38791656], [75.04013824, 12.38819313], [75.03986359, 12.38819313], [75.03986359, 12.38847256], [75.0395813, 12.38847065], [75.0395813, 12.38902855], [75.03930664, 12.38902855], [75.03930664, 12.38931179], [75.03902435, 12.38930511], [75.03902435, 12.38986111], [75.03874969, 12.3898592], [75.03874969, 12.39013863], [75.03847504, 12.39013863], [75.03847504, 12.39069557], [75.03819275, 12.3906908], [75.03819275, 12.39125156], [75.0376358, 12.39125156], [75.0376358, 12.39153194], [75.03710175, 12.39153194], [75.03710175, 12.39181042], [75.03652954, 12.3918047], [75.03652954, 12.39208412], [75.03569794, 12.39208412], [75.03569794, 12.3918047], [75.03542328, 12.39181042], [75.03542328, 12.39153194], [75.03514099, 12.39153194], [75.03514099, 12.3906908], [75.0349884, 12.3906908], [75.03458405, 12.39069557], [75.03458405, 12.3904171], [75.03404236, 12.39042187], [75.03404236, 12.39013863], [75.03320313, 12.39013863], [75.03320313, 12.39042187], [75.03236389, 12.3904171], [75.03236389, 12.39069557], [75.03180695, 12.39069557], [75.03180695, 12.39097118], [75.03151703, 12.39097118], [75.03151703, 12.39125156], [75.03096771, 12.39125156], [75.03096771, 12.39153194], [75.03069305, 12.39153194], [75.03069305, 12.39181042], [75.0304184, 12.39181042], [75.0304184, 12.39293098], [75.03013611, 12.39293098], [75.03013611, 12.39431], [75.02986145, 12.39430618], [75.02986145, 12.39486217], [75.02958679, 12.39486027], [75.02958679, 12.39542007], [75.02929688, 12.39542007], [75.02929688, 12.39624977], [75.02902985, 12.39624977], [75.02902985, 12.39680958], [75.02874756, 12.39680958], [75.02874756, 12.39764023], [75.0284729, 12.39764023], [75.0284729, 12.39819431], [75.02819824, 12.39819431], [75.02819824, 12.39875031], [75.02791595, 12.39875031], [75.02791595, 12.39958191], [75.0276413, 12.39958191], [75.0276413, 12.40014267], [75.02735901, 12.4001379], [75.02735901, 12.40069389], [75.02708435, 12.40069389], [75.02707672, 12.40113163], [75.02707672, 12.40125179], [75.02694702, 12.40124989], [75.02680206, 12.40124989], [75.02680206, 12.40139198], [75.02680206, 12.40180588], [75.0265274, 12.4017992], [75.0265274, 12.40235996], [75.02625275, 12.40235996], [75.02625275, 12.40292072], [75.02609253, 12.40291595], [75.02597046, 12.40291595], [75.02597046, 12.40347195], [75.02585602, 12.40347195], [75.0256958, 12.40347195], [75.0256958, 12.40360928], [75.0256958, 12.4040308], [75.02541351, 12.40402794], [75.02541351, 12.40458202], [75.02513885, 12.40458012], [75.02513885, 12.40514088], [75.0248642, 12.40513802], [75.0248642, 12.40569496], [75.02458191, 12.40569019], [75.02458191, 12.40625095], [75.02430725, 12.40625095], [75.02430725, 12.40681076], [75.02402496, 12.40680695], [75.02403259, 12.40736103], [75.02375031, 12.40736103], [75.02375031, 12.40764141], [75.02347565, 12.40763855], [75.02347565, 12.40819454], [75.02319336, 12.40818977], [75.02319336, 12.40930939], [75.0229187, 12.40930462], [75.0229187, 12.40986061], [75.02263641, 12.40986061], [75.02263641, 12.41014099], [75.02236176, 12.41013908], [75.02236176, 12.41069508], [75.02210236, 12.41067886], [75.02210236, 12.41153145], [75.02180481, 12.41152668], [75.02180481, 12.41208267], [75.02124786, 12.41208267], [75.02124786, 12.41236115], [75.02069092, 12.41236115], [75.02069092, 12.41292191], [75.02041626, 12.41291714], [75.02041626, 12.41347313], [75.0201416, 12.41347122], [75.0201416, 12.41403198], [75.01985931, 12.41402721], [75.01985931, 12.41458321], [75.01957703, 12.4145813], [75.01957703, 12.41486073], [75.01930237, 12.41486073], [75.01930237, 12.4151392], [75.01902771, 12.4151392], [75.01902771, 12.41541958], [75.01875305, 12.41541672], [75.01875305, 12.41569519], [75.01847076, 12.41569519], [75.01847076, 12.4159708], [75.01819611, 12.41596889], [75.01819611, 12.41624928], [75.01790619, 12.41624928], [75.01790619, 12.41652966], [75.01763916, 12.41652966], [75.01763916, 12.41681004], [75.01670074, 12.41681004], [75.01457977, 12.41681004], [75.01457977, 12.41764164], [75.01486206, 12.41763878], [75.01486206, 12.41819572], [75.01513672, 12.41819572], [75.01513672, 12.41847134], [75.01486206, 12.41847134], [75.01486206, 12.41958427], [75.01457977, 12.41958141], [75.01457977, 12.41987133], [75.01374817, 12.41987133], [75.01374817, 12.42041969], [75.01347351, 12.42041779], [75.01347351, 12.42069435], [75.01319122, 12.42069054], [75.01319122, 12.42181015], [75.01291656, 12.42180634], [75.01291656, 12.42236233], [75.01264191, 12.42236233], [75.01264191, 12.42319584], [75.01235962, 12.42319107], [75.01235962, 12.42374992], [75.01209259, 12.42374992], [75.01209259, 12.4240303], [75.01180267, 12.4240303], [75.01180267, 12.42431068], [75.01152802, 12.42430592], [75.01152802, 12.42458439], [75.01125336, 12.42457867], [75.01125336, 12.42514038], [75.01097107, 12.42514038], [75.01097107, 12.42542267], [75.01069641, 12.42542267], [75.01069641, 12.42625046], [75.01040649, 12.42625046], [75.01040649, 12.42681122], [75.01013947, 12.42680645], [75.01013184, 12.42761135], [75.00986481, 12.42763805], [75.00986481, 12.42805099], [75.00986481, 12.42819405], [75.00958252, 12.42819405], [75.00958252, 12.4285202], [75.00958252, 12.42875004], [75.00945282, 12.42875004], [75.00930786, 12.42875004], [75.00930023, 12.42900085], [75.00902557, 12.42902756], [75.00902557, 12.4294796], [75.00902557, 12.42958355], [75.00875092, 12.42958355], [75.00875092, 12.4300108], [75.00875092, 12.43124962], [75.00846863, 12.43124962], [75.00846863, 12.43181133], [75.00818634, 12.43181133], [75.00819397, 12.4323597], [75.00791931, 12.4323597], [75.00791931, 12.43292141], [75.00763702, 12.43291664], [75.00763702, 12.43347263], [75.00736237, 12.43346977], [75.00736237, 12.43403053], [75.00708008, 12.43402863], [75.00708008, 12.43458271], [75.00679779, 12.43457985], [75.00679779, 12.43514061], [75.00653076, 12.4351387], [75.00653076, 12.43569469], [75.00624847, 12.43568993], [75.00624847, 12.43625069], [75.006073, 12.43624878], [75.00597382, 12.43624878], [75.00595856, 12.43669128], [75.00595856, 12.4368124], [75.00569153, 12.43680477], [75.00569153, 12.43736076], [75.00541687, 12.43736076], [75.00541687, 12.43754101], [75.00541687, 12.43791676], [75.00514221, 12.43791676], [75.00514221, 12.43809891], [75.00514221, 12.43847084], [75.00485992, 12.43847084], [75.00485992, 12.43903065], [75.00458527, 12.43902683], [75.00458527, 12.44069481], [75.00485992, 12.44069099], [75.00485992, 12.44124889], [75.00514221, 12.44124889], [75.00514221, 12.44208336], [75.00485992, 12.44208145], [75.00485992, 12.44291973], [75.00458527, 12.44291687], [75.0045929, 12.44374943], [75.00430298, 12.44374943], [75.00430298, 12.44431019], [75.00458527, 12.44430542], [75.00458527, 12.44458294], [75.00485992, 12.44458103], [75.00485992, 12.44514179], [75.00430298, 12.44514179], [75.00430298, 12.44486141], [75.00402832, 12.44486141], [75.00402832, 12.44458294], [75.00375366, 12.44458294], [75.00375366, 12.44402695], [75.00347137, 12.44404125], [75.00347137, 12.44374943], [75.0029068, 12.44374943], [75.0029068, 12.44347095], [75.00263977, 12.44347095], [75.00263977, 12.44374943], [75.00235748, 12.44374943], [75.00235748, 12.44404125], [75.00208282, 12.44402695], [75.00208282, 12.44458294], [75.00180817, 12.44458103], [75.00180817, 12.44514179], [75.00152588, 12.44513988], [75.00152588, 12.44569111], [75.00125122, 12.44569969], [75.00125122, 12.44653034], [75.00096893, 12.44652843], [75.00096893, 12.44708443], [75.00067902, 12.44708061], [75.00067902, 12.44764042], [75.00036621, 12.44764042], [75.00028992, 12.44764042], [75.00013733, 12.44764042], [74.99986267, 12.4476366], [74.99986267, 12.44847202], [74.99931335, 12.44847202], [74.99931335, 12.44902992], [74.99903107, 12.44902992], [74.99903107, 12.4493103], [74.99874878, 12.44930553], [74.99874878, 12.44958401], [74.99819183, 12.44958401], [74.99819183, 12.44986153], [74.99791718, 12.44986153], [74.99791718, 12.45069408], [74.99764252, 12.45068932], [74.99764252, 12.45153046], [74.99793243, 12.45153046], [74.99793243, 12.45181274], [74.99764252, 12.45180607], [74.99764252, 12.45208359], [74.99736023, 12.45208359], [74.99736023, 12.45291805], [74.99708557, 12.45291805], [74.99708557, 12.45347214], [74.99736023, 12.45347023], [74.99736023, 12.45431137], [74.99708557, 12.45430565], [74.99708557, 12.45458412], [74.99680328, 12.45458031], [74.99680328, 12.45485973], [74.99652863, 12.45485973], [74.99652863, 12.45514011], [74.99624634, 12.45514011], [74.99624634, 12.45542145], [74.99597168, 12.45542145], [74.99597168, 12.45625019], [74.99624634, 12.45625019], [74.99624634, 12.45653057], [74.99597168, 12.45652771], [74.99597168, 12.4570837], [74.99569702, 12.4570837], [74.99569702, 12.45737171], [74.99569702, 12.45764065], [74.99541473, 12.45763779], [74.99541473, 12.45775032], [74.99541473, 12.45847225], [74.99524689, 12.45847034], [74.99485779, 12.45847034], [74.99485779, 12.45903969], [74.99458313, 12.4590292], [74.99458313, 12.45958233], [74.99430847, 12.45958042], [74.99430847, 12.46014118], [74.99402618, 12.46014118], [74.99402618, 12.46042061], [74.99375153, 12.46042061], [74.99375153, 12.46125126], [74.99346924, 12.46125126], [74.99346924, 12.46153069], [74.99375153, 12.46153069], [74.99375153, 12.46181107], [74.99346924, 12.46181107], [74.99346924, 12.46264076], [74.99263763, 12.46263885], [74.99263763, 12.46319485], [74.99291992, 12.46319485], [74.99291992, 12.46347332], [74.99263763, 12.46347332], [74.99263763, 12.4645834], [74.99236298, 12.4645834], [74.99236298, 12.46486092], [74.99208069, 12.46484947], [74.99208069, 12.4651413], [74.99236298, 12.4651413], [74.99236298, 12.46542168], [74.99208069, 12.46541691], [74.99208069, 12.46597099], [74.9917984, 12.46597099], [74.9917984, 12.46652889], [74.99153137, 12.46652889], [74.99153137, 12.46681023], [74.99180603, 12.46680546], [74.99180603, 12.46708298], [74.99153137, 12.46708298], [74.99153137, 12.46736145], [74.99124908, 12.46736145], [74.99124908, 12.46791935], [74.99097443, 12.46791744], [74.99097443, 12.46847343], [74.99069214, 12.46847057], [74.99069214, 12.46875095], [74.99041748, 12.46875095], [74.99041748, 12.46902943], [74.99013519, 12.46902657], [74.99014282, 12.46986103], [74.98986053, 12.46986103], [74.98986053, 12.47013855], [74.98930359, 12.47013855], [74.98930359, 12.47069454], [74.98902893, 12.47069073], [74.98902893, 12.47125244], [74.98873901, 12.47125244], [74.98873901, 12.47181034], [74.98847198, 12.47180462], [74.98847198, 12.47208309], [74.98819733, 12.47208118], [74.98819733, 12.47292042], [74.98791504, 12.47291756], [74.98791504, 12.47319317], [74.98764038, 12.47319126], [74.98764038, 12.47375202], [74.98735809, 12.47375202], [74.98735809, 12.47430992], [74.98708344, 12.47430611], [74.98708344, 12.47458363], [74.98680878, 12.47458363], [74.98680878, 12.4748621], [74.98707581, 12.47485924], [74.98707581, 12.47513962], [74.98680878, 12.47513962], [74.98680878, 12.4756937], [74.98652649, 12.4756937], [74.98652649, 12.47597218], [74.98625183, 12.47596931], [74.98625183, 12.47653008], [74.98596954, 12.47652817], [74.98596954, 12.47708416], [74.98625183, 12.47707939], [74.98625183, 12.47735977], [74.98596954, 12.47735977], [74.98596954, 12.47791958], [74.98569489, 12.47791576], [74.98569489, 12.47819424], [74.98542023, 12.47819233], [74.98542023, 12.47875023], [74.98513794, 12.47875023], [74.98513794, 12.47958374], [74.98486328, 12.47958183], [74.98486328, 12.48042107], [74.98458099, 12.4804163], [74.98458099, 12.48097229], [74.98430634, 12.48097038], [74.98430634, 12.48125172], [74.98401642, 12.48125172], [74.98400116, 12.48153019], [74.98374939, 12.48153019], [74.98374939, 12.48236179], [74.9834671, 12.48236179], [74.9834671, 12.48264027], [74.98319244, 12.48264027], [74.98319244, 12.48236179], [74.98291779, 12.48236179], [74.98291779, 12.48264027], [74.98236084, 12.48264027], [74.98236084, 12.48292065], [74.98208618, 12.48291588], [74.98208618, 12.48347187], [74.98179626, 12.48346996], [74.98179626, 12.48403072], [74.98152924, 12.48402786], [74.98152924, 12.48458195], [74.98124695, 12.48458004], [74.98124695, 12.4851408], [74.98097229, 12.48513794], [74.98097229, 12.48569393], [74.98042297, 12.48569202], [74.98042297, 12.48625088], [74.98014069, 12.48625088], [74.98014069, 12.48681068], [74.9798584, 12.48681068], [74.9798584, 12.48736095], [74.97958374, 12.48736095], [74.97957611, 12.48746967], [74.97956085, 12.48792076], [74.97930908, 12.48792076], [74.97930908, 12.48875141], [74.97902679, 12.48875141], [74.97902679, 12.48930931], [74.97875214, 12.48930454], [74.97875214, 12.48986053], [74.97846985, 12.48986053], [74.97846985, 12.490695], [74.97820282, 12.49069023], [74.97820282, 12.49125099], [74.9779129, 12.49125099], [74.9779129, 12.49180889], [74.97763824, 12.49180889], [74.97763824, 12.49264145], [74.97736359, 12.49263859], [74.97736359, 12.49319458], [74.9770813, 12.4931879], [74.9770813, 12.49375057], [74.97679901, 12.49375057], [74.97679901, 12.49403191], [74.97652435, 12.49402714], [74.97652435, 12.49458313], [74.97624969, 12.49458122], [74.97624969, 12.49515057], [74.97597504, 12.49513912], [74.97597504, 12.49597263], [74.97569275, 12.49597073], [74.97569275, 12.49680996], [74.97541809, 12.49680519], [74.97541809, 12.49736118], [74.9751358, 12.49736118], [74.9751358, 12.49764156], [74.97486115, 12.49764156], [74.97486115, 12.49792194], [74.97458649, 12.49791527], [74.97458649, 12.49847126], [74.97402954, 12.49847126], [74.97402954, 12.49875164], [74.9734726, 12.49874878], [74.9734726, 12.4995842], [74.97376251, 12.49958134], [74.97376251, 12.50041962], [74.9734726, 12.50041771], [74.9734726, 12.50097179], [74.97292328, 12.50096035], [74.97292328, 12.50181007], [74.97264099, 12.50180626], [74.97264099, 12.50208378], [74.97292328, 12.50208092], [74.97292328, 12.50263977], [74.97264099, 12.50263977], [74.97264099, 12.50374985], [74.9723587, 12.50374985], [74.9723587, 12.50430965], [74.97207642, 12.50430965], [74.97207642, 12.50541973], [74.97180939, 12.50541592], [74.97180176, 12.50597191], [74.9715271, 12.50597191], [74.9715271, 12.50625038], [74.97125244, 12.50625038], [74.97125244, 12.50653267], [74.97097015, 12.50653267], [74.97097015, 12.50709057], [74.9706955, 12.50708199], [74.9706955, 12.50847244], [74.97013855, 12.50846958], [74.97013855, 12.50874996], [74.97041321, 12.50874996], [74.97041321, 12.50931072], [74.97013855, 12.50931072], [74.97013855, 12.5104208], [74.96986389, 12.51041603], [74.96986389, 12.51069355], [74.9695816, 12.51068974], [74.9695816, 12.51292133], [74.96902466, 12.51291561], [74.96902466, 12.51319504], [74.96875, 12.51319027], [74.96875, 12.51403141], [74.96848297, 12.51403141], [74.96848297, 12.51514053], [74.96819305, 12.51513863], [74.96819305, 12.51597309], [74.9679184, 12.51597118], [74.9679184, 12.51625061], [74.96762848, 12.51625061], [74.96762848, 12.51681232], [74.96736145, 12.5168047], [74.96736145, 12.51708317], [74.96708679, 12.51708317], [74.96708679, 12.51819515], [74.96679688, 12.51819038], [74.96679688, 12.51875114], [74.96652985, 12.51875114], [74.96652985, 12.51986122], [74.96624756, 12.51986122], [74.96624756, 12.52125072], [74.9659729, 12.52125072], [74.9659729, 12.52180958], [74.96569824, 12.52180481], [74.96569824, 12.52208328], [74.96541595, 12.52208328], [74.96541595, 12.5223608], [74.9651413, 12.52235889], [74.9651413, 12.52291965], [74.96485901, 12.52291679], [74.96485901, 12.52319527], [74.96458435, 12.52319527], [74.96458435, 12.52458286], [74.96430206, 12.52458286], [74.96430206, 12.52513885], [74.9640274, 12.52513885], [74.9640274, 12.5256958], [74.96375275, 12.52569103], [74.96375275, 12.52625179], [74.96347046, 12.52625179], [74.96347046, 12.52680969], [74.9631958, 12.52680588], [74.9631958, 12.52708435], [74.96290588, 12.52708054], [74.96290588, 12.52875042], [74.96263885, 12.52875042], [74.96263885, 12.5298624], [74.9623642, 12.5298624], [74.9623642, 12.53040886], [74.9623642, 12.53069401], [74.96222687, 12.53069401], [74.96208191, 12.53069401], [74.96208191, 12.53099918], [74.96208191, 12.53126144], [74.96196747, 12.53125], [74.96180725, 12.53125], [74.96181488, 12.53152084], [74.96182251, 12.53180981], [74.96153259, 12.53180981], [74.96153259, 12.53264046], [74.96125031, 12.5326376], [74.96125031, 12.53319359], [74.96098328, 12.53319168], [74.96098328, 12.53374958], [74.96069336, 12.53374958], [74.96069336, 12.53681087], [74.9604187, 12.5368042], [74.9604187, 12.5381937], [74.96013641, 12.5381918], [74.96013641, 12.53985977], [74.95986176, 12.53985977], [74.95986176, 12.54125118], [74.9595871, 12.54125118], [74.9595871, 12.54236126], [74.95929718, 12.54236126], [74.95929718, 12.5432024], [74.95903015, 12.54319477], [74.95903015, 12.54375076], [74.95874786, 12.54375076], [74.95874786, 12.54458332], [74.95847321, 12.54458046], [74.95847321, 12.54514122], [74.95819092, 12.54513931], [74.95819092, 12.5456953], [74.95791626, 12.54568958], [74.95791626, 12.54626179], [74.9576416, 12.54626179], [74.9576416, 12.54653072], [74.95735931, 12.54652691], [74.95735931, 12.5470829], [74.95707703, 12.54708099], [74.95707703, 12.54763889], [74.95680237, 12.54763889], [74.95680237, 12.54819489], [74.95652771, 12.54819489], [74.95652771, 12.54847336], [74.95625305, 12.54847145], [74.95625305, 12.54902935], [74.95652771, 12.54902744], [74.95652771, 12.54958344], [74.95680237, 12.54958057], [74.95680237, 12.54986095], [74.95707703, 12.54986095], [74.95707703, 12.55013943], [74.95735931, 12.55013943], [74.95735931, 12.55042171], [74.9576416, 12.55041695], [74.9576416, 12.55069542], [74.95791626, 12.55069065], [74.95791626, 12.55125237], [74.9576416, 12.55125237], [74.9576416, 12.55181026], [74.95735931, 12.55180454], [74.95735931, 12.55208302], [74.95708466, 12.55208302], [74.95708466, 12.55236053], [74.95680237, 12.55236053], [74.95680237, 12.55264187], [74.95652771, 12.55263996], [74.95652771, 12.55319309], [74.95625305, 12.55319309], [74.95625305, 12.55347061], [74.95597076, 12.55347061], [74.95597076, 12.55375195], [74.95568848, 12.55375195], [74.95568848, 12.55403042], [74.95539856, 12.55403042], [74.95539856, 12.55431175], [74.95513916, 12.55431175], [74.95513916, 12.55403042], [74.95485687, 12.55403042], [74.95485687, 12.55375195], [74.95513916, 12.55375195], [74.95513916, 12.55347061], [74.95541382, 12.55347061], [74.95541382, 12.55291843], [74.95568848, 12.55292034], [74.95568848, 12.55264187], [74.95597076, 12.55264187], [74.95597076, 12.55236053], [74.95625305, 12.55236053], [74.95625305, 12.55208302], [74.95652771, 12.55208302], [74.95652771, 12.55013943], [74.95625305, 12.55013943], [74.95625305, 12.54986095], [74.95597076, 12.54986095], [74.95597076, 12.54958057], [74.95569611, 12.54958344], [74.95569611, 12.54930496], [74.95541382, 12.54930496], [74.95541382, 12.54902744], [74.95513916, 12.54902935], [74.95511627, 12.54875088], [74.95458221, 12.54874897], [74.95458221, 12.54930496], [74.95430756, 12.54930115], [74.95430756, 12.55013943], [74.95402527, 12.55013943], [74.95402527, 12.55069542], [74.95375061, 12.55069065], [74.95375061, 12.55153179], [74.95347595, 12.55152702], [74.95347595, 12.55236053], [74.95318604, 12.55236053], [74.95318604, 12.55292034], [74.95291901, 12.55291843], [74.95291901, 12.55347061], [74.95262909, 12.55347061], [74.95262909, 12.55403042], [74.95236206, 12.55402756], [74.95236206, 12.55458355], [74.95207977, 12.55458355], [74.95207977, 12.55569363], [74.95181274, 12.55568886], [74.95181274, 12.55624962], [74.95153046, 12.55624962], [74.95153046, 12.55653], [74.95124817, 12.55653], [74.95124817, 12.55764008], [74.95096588, 12.55764008], [74.95096588, 12.55931091], [74.95069122, 12.55930614], [74.95069122, 12.55986214], [74.95041656, 12.55986023], [74.95041656, 12.56042004], [74.95014191, 12.56041622], [74.95014191, 12.56097221], [74.94985962, 12.56097031], [74.94985962, 12.56153011], [74.94958496, 12.56152821], [74.94958496, 12.5620842], [74.94930267, 12.56208038], [74.94930267, 12.56264019], [74.94902802, 12.56264019], [74.94902802, 12.56319427], [74.94875336, 12.56319046], [74.94875336, 12.56375027], [74.94847107, 12.56375027], [74.94847107, 12.56430626], [74.94819641, 12.56430626], [74.94819641, 12.56486034], [74.94790649, 12.56486034], [74.94790649, 12.5654211], [74.94763947, 12.5654211], [74.94763947, 12.56653118], [74.94736481, 12.56652641], [74.94736481, 12.56708241], [74.94708252, 12.56707954], [74.94708252, 12.56792068], [74.94680786, 12.56791687], [74.94680786, 12.56819534], [74.9465332, 12.56818962], [74.9465332, 12.56930923], [74.94625092, 12.56930542], [74.94625092, 12.56986141], [74.94596863, 12.56986141], [74.94595337, 12.57138062], [74.94595337, 12.5715313], [74.94569397, 12.57152653], [74.94569397, 12.57208347], [74.94541931, 12.57208347], [74.94541931, 12.5725317], [74.94541931, 12.57264137], [74.94513702, 12.57263947], [74.94513702, 12.57347298], [74.94486237, 12.57347107], [74.94486237, 12.57375145], [74.94458008, 12.57375145], [74.94458008, 12.57458305], [74.94431305, 12.57458115], [74.94431305, 12.57541943], [74.94403076, 12.57541656], [74.94403076, 12.57569313], [74.9438858, 12.57569313], [74.94374847, 12.57569313], [74.94374847, 12.57624912], [74.94347382, 12.57624912], [74.94347382, 12.57708263], [74.94319153, 12.57708263], [74.94319153, 12.57796097], [74.94319153, 12.57819462], [74.94291687, 12.57819462], [74.94291687, 12.57862186], [74.94291687, 12.57903194], [74.94274902, 12.57903004], [74.94264221, 12.57902718], [74.94264221, 12.5792799], [74.94264221, 12.57958317], [74.94251251, 12.57958317], [74.94235992, 12.57958317], [74.94235992, 12.57995033], [74.94235992, 12.58014202], [74.94208527, 12.58014011], [74.94208527, 12.58069324], [74.94180298, 12.58069134], [74.94180298, 12.58125019], [74.94152832, 12.58125019], [74.94152832, 12.5819397], [74.94152832, 12.5820837], [74.94125366, 12.5820837], [74.94124603, 12.58260059], [74.94124603, 12.58292007], [74.94097137, 12.58292007], [74.94097137, 12.58403015], [74.94069672, 12.58402824], [74.94069672, 12.58458424], [74.94041443, 12.58458424], [74.94041443, 12.58486176], [74.94010925, 12.58486176], [74.93985748, 12.58486176], [74.93985748, 12.58569431], [74.93958282, 12.58569241], [74.93958282, 12.58625031], [74.93930817, 12.58625031], [74.93930817, 12.58708191], [74.93902588, 12.58708382], [74.93902588, 12.58819389], [74.93875122, 12.58819389], [74.93875122, 12.58847237], [74.93846893, 12.58847046], [74.93846893, 12.58875179], [74.93818665, 12.58875179], [74.93818665, 12.59014034], [74.93791962, 12.59014034], [74.93791962, 12.59042072], [74.93819427, 12.59041595], [74.93819427, 12.59069443], [74.93791962, 12.59068966], [74.93791962, 12.59125042], [74.93765259, 12.59125042], [74.93765259, 12.59154034], [74.93736267, 12.59152794], [74.93736267, 12.59208202], [74.93708038, 12.59208012], [74.93708038, 12.59264088], [74.93681335, 12.59264088], [74.93681335, 12.59292126], [74.93653107, 12.59291553], [74.93653107, 12.59347343], [74.93624878, 12.59346962], [74.93624878, 12.59403133], [74.93597412, 12.59402943], [74.93597412, 12.5945816], [74.93569183, 12.5945797], [74.93569183, 12.59486103], [74.93541718, 12.59486103], [74.93541718, 12.59542084], [74.93514252, 12.59541702], [74.93514252, 12.59597301], [74.93486023, 12.59597015], [74.93486023, 12.59625053], [74.93514252, 12.59625053], [74.93514252, 12.59653091], [74.93486023, 12.59653091], [74.93486023, 12.59681129], [74.93458557, 12.59680462], [74.93458557, 12.59736061], [74.93430328, 12.59735203], [74.93430328, 12.59792137], [74.93402863, 12.59792137], [74.93402863, 12.59875107], [74.93430328, 12.59875107], [74.93430328, 12.59903145], [74.93402863, 12.59903145], [74.93402863, 12.59931183], [74.93374634, 12.59930515], [74.93374634, 12.59958267], [74.93347168, 12.59958267], [74.93347168, 12.59986115], [74.93374634, 12.59986115], [74.93374634, 12.60014057], [74.93347168, 12.60013866], [74.93347168, 12.60069466], [74.93319702, 12.60069466], [74.93319702, 12.60097313], [74.9329071, 12.60097122], [74.9329071, 12.60125065], [74.93264008, 12.60125065], [74.93264008, 12.60291958], [74.93235779, 12.60291672], [74.93235779, 12.60319519], [74.93208313, 12.60319138], [74.93208313, 12.60374928], [74.93235779, 12.60374928], [74.93235779, 12.60403156], [74.93264008, 12.60403156], [74.93264008, 12.60348034], [74.9329071, 12.60348034], [74.9329071, 12.6026392], [74.93319702, 12.6026392], [74.93319702, 12.60236073], [74.93347168, 12.60236073], [74.93347168, 12.6020813], [74.93374634, 12.60208321], [74.93374634, 12.60069466], [74.93402863, 12.60069466], [74.93402863, 12.60041714], [74.93430328, 12.60041714], [74.93430328, 12.60013866], [74.9345932, 12.60014057], [74.9345932, 12.59903145], [74.93486023, 12.59903145], [74.93486023, 12.59875107], [74.93541718, 12.59875107], [74.93541718, 12.59819031], [74.93569183, 12.59819508], [74.93569183, 12.5979166], [74.93596649, 12.59792137], [74.93596649, 12.59735203], [74.93624878, 12.59736061], [74.93624878, 12.59708309], [74.93653107, 12.59708309], [74.93653107, 12.59652901], [74.93681335, 12.59653091], [74.93681335, 12.59597015], [74.93708038, 12.59597301], [74.93708038, 12.59569454], [74.93736267, 12.59569454], [74.93736267, 12.59513855], [74.93765259, 12.59514141], [74.93765259, 12.59486103], [74.93736267, 12.59486103], [74.93736267, 12.5945797], [74.93763733, 12.5945816], [74.93763733, 12.59430695], [74.93791962, 12.59431076], [74.93791962, 12.59403133], [74.93818665, 12.59403133], [74.93818665, 12.59375095], [74.93846893, 12.59375095], [74.93846893, 12.59346962], [74.93875122, 12.59347343], [74.93875122, 12.59319401], [74.93902588, 12.59319401], [74.93902588, 12.59263802], [74.93930817, 12.59264088], [74.93930817, 12.59208012], [74.93958282, 12.59208202], [74.93958282, 12.59125042], [74.93985748, 12.59125042], [74.93985748, 12.59068966], [74.94013977, 12.59069443], [74.94013977, 12.58985996], [74.94039917, 12.58985996], [74.94039917, 12.58931065], [74.94097137, 12.58930588], [74.94097137, 12.58958435], [74.94125366, 12.58958435], [74.94125366, 12.59069443], [74.94097137, 12.59068966], [74.94097137, 12.59125042], [74.94069672, 12.59125042], [74.94069672, 12.59236336], [74.94039917, 12.59235954], [74.94039917, 12.59264088], [74.94013977, 12.59263802], [74.94013977, 12.59347343], [74.93985748, 12.59346962], [74.93985748, 12.59486103], [74.93930817, 12.59486103], [74.93930817, 12.59597301], [74.93902588, 12.59597015], [74.93902588, 12.59625053], [74.93875122, 12.59625053], [74.93875122, 12.59681129], [74.93818665, 12.59681129], [74.93818665, 12.59792137], [74.93791962, 12.59792137], [74.93791962, 12.59875107], [74.93708038, 12.59875107], [74.93708038, 12.59931183], [74.93680573, 12.59930515], [74.93680573, 12.60097313], [74.93653107, 12.60097122], [74.93653107, 12.60125065], [74.93596649, 12.60125065], [74.93596649, 12.60181046], [74.93569183, 12.60180473], [74.93569183, 12.60208321], [74.93541718, 12.6020813], [74.93541718, 12.60291958], [74.93514252, 12.60291958], [74.93514252, 12.60403156], [74.93486023, 12.60402679], [74.93486023, 12.60458279], [74.9345932, 12.60458088], [74.9345932, 12.60514164], [74.93430328, 12.60513878], [74.93430328, 12.60569572], [74.93402863, 12.60569572], [74.93402863, 12.60597134], [74.93374634, 12.60597134], [74.93374634, 12.60764027], [74.93347168, 12.60764027], [74.93347168, 12.60791969], [74.93319702, 12.60791779], [74.93319702, 12.6081934], [74.93347168, 12.6081934], [74.93347168, 12.60847187], [74.93319702, 12.60847187], [74.93319702, 12.60875034], [74.9329071, 12.60875034], [74.9329071, 12.60931015], [74.93264008, 12.60930634], [74.93264008, 12.60958385], [74.93235779, 12.60958099], [74.93235779, 12.61013985], [74.93208313, 12.61013985], [74.93208313, 12.61069584], [74.93180847, 12.61069107], [74.93180847, 12.61180973], [74.93208313, 12.61180592], [74.93208313, 12.61319447], [74.93152618, 12.61319447], [74.93152618, 12.61347198], [74.93096924, 12.61347198], [74.93096924, 12.61375046], [74.93068695, 12.61375046], [74.93068695, 12.61403275], [74.93013763, 12.61403275], [74.93013763, 12.61375046], [74.92986298, 12.61375046], [74.92986298, 12.61347198], [74.92958069, 12.61347198], [74.92958069, 12.61263847], [74.92930603, 12.61264038], [74.92930603, 12.61235142], [74.92958069, 12.61236191], [74.92958069, 12.61180592], [74.92930603, 12.61180973], [74.92930603, 12.61096859], [74.92958069, 12.6109724], [74.92958069, 12.61041641], [74.92930603, 12.61042023], [74.92930603, 12.61013985], [74.92903137, 12.61013985], [74.92903137, 12.61042023], [74.92874908, 12.61041641], [74.92874908, 12.6109724], [74.92819214, 12.6109724], [74.92819214, 12.61208439], [74.92791748, 12.61208439], [74.92791748, 12.61236191], [74.92764282, 12.61235142], [74.92764282, 12.61264038], [74.92736053, 12.61264038], [74.92736053, 12.61403275], [74.92708588, 12.61402798], [74.92708588, 12.61486244], [74.92679596, 12.61485958], [74.92679596, 12.6154213], [74.92652893, 12.6154213], [74.92652893, 12.61653137], [74.92597198, 12.61653137], [74.92597198, 12.61763954], [74.92571259, 12.61763954], [74.92571259, 12.61931133], [74.92485809, 12.61930656], [74.92485809, 12.62097263], [74.92458344, 12.62097263], [74.92458344, 12.62152863], [74.92430878, 12.62152863], [74.92430878, 12.62236118], [74.92402649, 12.62236118], [74.92402649, 12.62292099], [74.92375183, 12.62292099], [74.92375183, 12.62375069], [74.92346954, 12.62375069], [74.92346954, 12.62431145], [74.92319489, 12.62430477], [74.92319489, 12.62486076], [74.92292023, 12.6248579], [74.92292023, 12.62542057], [74.92263794, 12.62541676], [74.9226532, 12.62625122], [74.92236328, 12.62625122], [74.92236328, 12.62653065], [74.92208099, 12.62652683], [74.92208099, 12.62708282], [74.92180634, 12.62708092], [74.92180634, 12.62764072], [74.92152405, 12.62763882], [74.92152405, 12.62819481], [74.92124939, 12.62819099], [74.92124939, 12.62874889], [74.9209671, 12.62874889], [74.9209671, 12.62902927], [74.92124939, 12.62902927], [74.92124939, 12.62930965], [74.92097473, 12.62930489], [74.92097473, 12.62958336], [74.92069244, 12.62958145], [74.92069244, 12.62986088], [74.92097473, 12.62986088], [74.92097473, 12.63050175], [74.92097473, 12.63069534], [74.92069244, 12.63069534], [74.92069244, 12.63111019], [74.92069244, 12.63125134], [74.92041779, 12.63125134], [74.92041779, 12.63181019], [74.9201355, 12.63180542], [74.9201355, 12.63208294], [74.91957855, 12.63208103], [74.91957855, 12.63375187], [74.91929626, 12.63375187], [74.91929626, 12.63403034], [74.91902924, 12.63403034], [74.91902924, 12.63486195], [74.91874695, 12.63486195], [74.91874695, 12.63542175], [74.91847229, 12.63542175], [74.91847229, 12.63624954], [74.91819763, 12.63624954], [74.91819763, 12.63652802], [74.91791534, 12.63652802], [74.91791534, 12.63736153], [74.91764069, 12.63735962], [74.91764069, 12.63903046], [74.91707611, 12.63903046], [74.91707611, 12.64013958], [74.91680908, 12.64013958], [74.91680908, 12.64041996], [74.91651917, 12.64041996], [74.91651917, 12.64124966], [74.91625214, 12.64124966], [74.91625214, 12.64208412], [74.91596985, 12.64208031], [74.91596985, 12.64292145], [74.91569519, 12.64291573], [74.91570282, 12.64375019], [74.9154129, 12.64375019], [74.9154129, 12.6445837], [74.91513824, 12.64458179], [74.91513824, 12.64514065], [74.91486359, 12.64513779], [74.91486359, 12.64569378], [74.9145813, 12.64568996], [74.9145813, 12.64624977], [74.91430664, 12.64624977], [74.91430664, 12.64708233], [74.91401672, 12.64708042], [74.91401672, 12.64764118], [74.91374969, 12.64763832], [74.91374969, 12.64819527], [74.91348267, 12.64818954], [74.91348267, 12.64903069], [74.91319275, 12.64902878], [74.91319275, 12.64958286], [74.91291809, 12.64958], [74.91291809, 12.65014076], [74.9126358, 12.65013885], [74.9126358, 12.65069485], [74.91236115, 12.65069485], [74.91236115, 12.6515274], [74.91208649, 12.6515274], [74.91208649, 12.6520834], [74.91179657, 12.65207958], [74.91179657, 12.6526413], [74.91152954, 12.65263939], [74.91152954, 12.6534729], [74.91124725, 12.65347099], [74.91124725, 12.65402889], [74.9109726, 12.65402889], [74.9109726, 12.65458965], [74.9107132, 12.65458965], [74.9107132, 12.65514088], [74.91041565, 12.65513897], [74.91041565, 12.65597343], [74.91014099, 12.65597057], [74.91014099, 12.65652943], [74.9098587, 12.65652657], [74.9098587, 12.65708256], [74.90957642, 12.65708065], [74.90957642, 12.65792179], [74.90930939, 12.65791702], [74.90930176, 12.65847111], [74.9090271, 12.65847111], [74.9090271, 12.65903187], [74.90875244, 12.6590271], [74.90875244, 12.65958309], [74.90847015, 12.65958118], [74.90847015, 12.66042042], [74.9081955, 12.66041756], [74.9081955, 12.66097355], [74.90791321, 12.66097069], [74.90791321, 12.66152954], [74.90763855, 12.66152763], [74.90763855, 12.66208363], [74.90735626, 12.66207886], [74.90735626, 12.66263962], [74.9070816, 12.66263962], [74.9070816, 12.6631937], [74.90680695, 12.66319084], [74.90680695, 12.66374969], [74.90651703, 12.66374969], [74.90651703, 12.66431046], [74.90625, 12.66431046], [74.90625, 12.66485977], [74.90598297, 12.66485977], [74.90598297, 12.66541958], [74.90569305, 12.66541576], [74.90569305, 12.66597176], [74.9054184, 12.66596985], [74.9054184, 12.66652966], [74.90513611, 12.66652775], [74.90513611, 12.66708374], [74.90486145, 12.66708183], [74.90486145, 12.66763973], [74.9043045, 12.66763783], [74.9043045, 12.66819382], [74.90402985, 12.66819191], [74.90402985, 12.66875172], [74.90374756, 12.66875172], [74.90374756, 12.66931057], [74.9034729, 12.66931057], [74.9034729, 12.67014027], [74.90319824, 12.67014027], [74.90319824, 12.67125034], [74.90291595, 12.67125034], [74.90291595, 12.6718111], [74.9026413, 12.67180634], [74.9026413, 12.67263794], [74.90235901, 12.67263794], [74.90235901, 12.67319393], [74.90207672, 12.67319202], [74.90207672, 12.67431068], [74.90180206, 12.67431068], [74.90180206, 12.67486], [74.9015274, 12.67486], [74.9015274, 12.67569542], [74.90125275, 12.6756897], [74.90125275, 12.67681122], [74.9015274, 12.67680454], [74.9015274, 12.67708302], [74.90097046, 12.67708302], [74.90097046, 12.67736053], [74.9006958, 12.67736053], [74.9006958, 12.678195], [74.90040588, 12.67819023], [74.90040588, 12.67930889], [74.90013885, 12.67930889], [74.90013885, 12.67986107], [74.89985657, 12.67986107], [74.89985657, 12.68014145], [74.89958191, 12.68013859], [74.89958191, 12.68069458], [74.89930725, 12.6806879], [74.89930725, 12.68125057], [74.89901733, 12.68125057], [74.89901733, 12.68182087], [74.89875031, 12.68180466], [74.89875031, 12.68208313], [74.89848328, 12.68208122], [74.89848328, 12.68264103], [74.89819336, 12.68264103], [74.89819336, 12.68291855], [74.8979187, 12.68291664], [74.8979187, 12.68347263], [74.89763641, 12.68347073], [74.89763641, 12.68402863], [74.89736176, 12.68402672], [74.89736176, 12.68458271], [74.8970871, 12.68457031], [74.8970871, 12.68514156], [74.89680481, 12.6851387], [74.89680481, 12.68569469], [74.89653015, 12.68569088], [74.89653015, 12.68625164], [74.89624786, 12.68625164], [74.89624786, 12.68680954], [74.89597321, 12.68680477], [74.89597321, 12.68736172], [74.89569092, 12.68735886], [74.89569092, 12.68791962], [74.89541626, 12.68791962], [74.89541626, 12.68847084], [74.8951416, 12.68847084], [74.8951416, 12.68902969], [74.89485931, 12.68902779], [74.89485931, 12.68958378], [74.89457703, 12.68958092], [74.89457703, 12.69013977], [74.89430237, 12.69013977], [74.89430237, 12.69069958], [74.89402771, 12.69069576], [74.89402771, 12.69208431], [74.89375305, 12.69208241], [74.89375305, 12.6926403], [74.89347076, 12.6926403], [74.89347076, 12.69347191], [74.89319611, 12.69347191], [74.89319611, 12.69376087], [74.89291382, 12.69375038], [74.89291382, 12.69458199], [74.89263916, 12.69458199], [74.89263916, 12.69514179], [74.8923645, 12.69513798], [74.8923645, 12.69597244], [74.89208221, 12.69597244], [74.89208221, 12.69680595], [74.89180756, 12.69679928], [74.89180756, 12.69764042], [74.89152527, 12.69763756], [74.89152527, 12.69819355], [74.89125061, 12.69818974], [74.89125061, 12.69903088], [74.89097595, 12.69902802], [74.89097595, 12.69986343], [74.89068604, 12.69985962], [74.89068604, 12.70042133], [74.89041901, 12.70042133], [74.89041901, 12.70125103], [74.89013672, 12.70125103], [74.89013672, 12.70208454], [74.88986206, 12.70207977], [74.88986206, 12.70264053], [74.88957977, 12.70263863], [74.88957977, 12.70347309], [74.88931274, 12.70347023], [74.88931274, 12.70375061], [74.88874817, 12.70375061], [74.88874817, 12.70403099], [74.88847351, 12.70402908], [74.88847351, 12.70458317], [74.88819122, 12.70458317], [74.88819122, 12.70497036], [74.88819122, 12.70514107], [74.88802338, 12.70514107], [74.88791656, 12.70514107], [74.88791656, 12.70570183], [74.88748169, 12.70569515], [74.88735962, 12.70569515], [74.88735962, 12.70582008], [74.88735962, 12.7068119], [74.88764191, 12.70680523], [74.88764191, 12.70708275], [74.88791656, 12.70708275], [74.88791656, 12.70736122], [74.88847351, 12.70736122], [74.88847351, 12.70708275], [74.88874817, 12.70708275], [74.88874817, 12.70680523], [74.88931274, 12.7068119], [74.88931274, 12.70653057], [74.88957977, 12.70653057], [74.88957977, 12.70625114], [74.89013672, 12.70625114], [74.89013672, 12.7059679], [74.89041901, 12.70597076], [74.89041901, 12.70569515], [74.89097595, 12.70570183], [74.89097595, 12.70542145], [74.89125061, 12.70542145], [74.89125061, 12.70514107], [74.8915329, 12.70514107], [74.8915329, 12.70458031], [74.89180756, 12.70458317], [74.89180756, 12.70402908], [74.89208221, 12.70403099], [74.89208221, 12.70347023], [74.89263916, 12.70347023], [74.89263916, 12.70431137], [74.8923645, 12.7043047], [74.8923645, 12.70597267], [74.89208221, 12.7059679], [74.89208221, 12.7068119], [74.89234924, 12.7068119], [74.89234924, 12.70792198], [74.89263916, 12.70791721], [74.89263916, 12.70847321], [74.8923645, 12.70847321], [74.8923645, 12.70874882], [74.89208221, 12.70874023], [74.89208221, 12.7090292], [74.89180756, 12.7090292], [74.89180756, 12.70930958], [74.89152527, 12.70930481], [74.89152527, 12.70958328], [74.89125061, 12.70958138], [74.89125061, 12.71041965], [74.89097595, 12.71041679], [74.89097595, 12.71069527], [74.89041901, 12.71069527], [74.89041901, 12.71097088], [74.88986206, 12.71097088], [74.88986206, 12.71125126], [74.88903046, 12.71125126], [74.88903046, 12.71097088], [74.88791656, 12.71097088], [74.88791656, 12.71125126], [74.88652802, 12.71125126], [74.88652802, 12.71097088], [74.88625336, 12.71097088], [74.88625336, 12.71013927], [74.88654327, 12.71013927], [74.88654327, 12.7090292], [74.88680267, 12.7090292], [74.88680267, 12.7084713], [74.88708496, 12.70847321], [74.88708496, 12.70819473], [74.88625336, 12.70819473], [74.88625336, 12.70791721], [74.88552094, 12.70791721], [74.88541412, 12.70791721], [74.88541412, 12.70819473], [74.88513947, 12.70819473], [74.88513947, 12.70847321], [74.88485718, 12.7084713], [74.88485718, 12.7090292], [74.88458252, 12.7090292], [74.88458252, 12.70930958], [74.88430786, 12.70930481], [74.88430786, 12.70958328], [74.88375092, 12.70958138], [74.88375092, 12.71041965], [74.88346863, 12.71041679], [74.88347626, 12.71125126], [74.88319397, 12.71125126], [74.88319397, 12.71180534], [74.88291931, 12.71180058], [74.88291931, 12.71264172], [74.88263702, 12.71263885], [74.88263702, 12.71347141], [74.88236237, 12.71347141], [74.88236237, 12.71430969], [74.88208008, 12.71430969], [74.88208008, 12.71487141], [74.88181305, 12.71487141], [74.88181305, 12.71541977], [74.88153076, 12.71541977], [74.88153076, 12.71625042], [74.88124847, 12.71625042], [74.88124847, 12.71681023], [74.88096619, 12.71681023], [74.88096619, 12.71763992], [74.88069153, 12.71763992], [74.88069153, 12.71847153], [74.88040924, 12.71847153], [74.88040924, 12.72014046], [74.87985992, 12.7201376], [74.87985992, 12.72069359], [74.87958527, 12.72069359], [74.87958527, 12.72097206], [74.87930298, 12.72097015], [74.87930298, 12.72124958], [74.8795929, 12.72124958], [74.8795929, 12.72181129], [74.87930298, 12.72181129], [74.87930298, 12.72292137], [74.87902832, 12.72291565], [74.87902832, 12.72375011], [74.87874603, 12.72374058], [74.87874603, 12.72431087], [74.87847137, 12.7243042], [74.87847137, 12.72458363], [74.87819672, 12.72458363], [74.87819672, 12.72597218], [74.8779068, 12.72597027], [74.8779068, 12.72653103], [74.87763977, 12.72652817], [74.87763977, 12.72708225], [74.87708282, 12.72708225], [74.87708282, 12.72819519], [74.87680817, 12.72819042], [74.87680817, 12.72931099], [74.87652588, 12.72930431], [74.87652588, 12.73012924], [74.87652588, 12.73042107], [74.87637329, 12.73041725], [74.87625122, 12.73041725], [74.87625122, 12.73064041], [74.87625122, 12.73153114], [74.87596893, 12.73152924], [74.87596893, 12.73208332], [74.87568665, 12.73208046], [74.87568665, 12.73264122], [74.87541962, 12.73263931], [74.87541962, 12.7331953], [74.87513733, 12.73318958], [74.87513733, 12.7337513], [74.87486267, 12.7337513], [74.87486267, 12.7343092], [74.87458038, 12.73430538], [74.87458038, 12.73486137], [74.87431335, 12.73486137], [74.87431335, 12.73541927], [74.87403107, 12.73541737], [74.87403107, 12.73597336], [74.87374878, 12.73597145], [74.87374878, 12.73652935], [74.87346649, 12.73652935], [74.87346649, 12.73736095], [74.87319183, 12.73736095], [74.87319183, 12.73792171], [74.87291718, 12.73791695], [74.87291718, 12.73847103], [74.87264252, 12.73847103], [74.87264252, 12.73903179], [74.87236023, 12.73902702], [74.87236023, 12.73958302], [74.8720932, 12.73958111], [74.8720932, 12.74014187], [74.87180328, 12.74013901], [74.87180328, 12.74069309], [74.87152863, 12.74069118], [74.87152863, 12.74125195], [74.87124634, 12.74125195], [74.87124634, 12.74181175], [74.87097168, 12.74181175], [74.87097168, 12.74236202], [74.87069702, 12.74236202], [74.87069702, 12.74291992], [74.8704071, 12.74291992], [74.8704071, 12.74374962], [74.87014008, 12.74374962], [74.87014008, 12.74431038], [74.86985779, 12.74431038], [74.86985779, 12.74514198], [74.86958313, 12.74514008], [74.86958313, 12.74569416], [74.86930847, 12.7456913], [74.86930847, 12.74652958], [74.86902618, 12.74652767], [74.86902618, 12.74736214], [74.86875153, 12.74736214], [74.86875153, 12.74791622], [74.86846924, 12.74791622], [74.86846924, 12.74847221], [74.86875153, 12.74847031], [74.86875153, 12.74874973], [74.86846924, 12.74874973], [74.86846924, 12.7495842], [74.86763763, 12.74958038], [74.86763763, 12.75042057], [74.86736298, 12.7504158], [74.86736298, 12.75069427], [74.86763763, 12.75069046], [74.86763763, 12.75097179], [74.86736298, 12.75097179], [74.86736298, 12.75153065], [74.86708069, 12.75152779], [74.86708069, 12.75208378], [74.86680603, 12.75207996], [74.86680603, 12.75264072], [74.86653137, 12.75264072], [74.86653137, 12.7529211], [74.86680603, 12.75291634], [74.86680603, 12.75319386], [74.86653137, 12.75319195], [74.86653137, 12.75374985], [74.86680603, 12.75374985], [74.86680603, 12.75403976], [74.86708069, 12.75402927], [74.86708069, 12.75445175], [74.87589264, 12.75529099], [74.87766266, 12.7523489], [74.87802887, 12.75024128], [74.87991333, 12.74927044], [74.88559723, 12.74877071], [74.8886795, 12.75237179], [74.89176178, 12.75452995], [74.89453125, 12.7560997], [74.89776611, 12.75540066], [74.90141296, 12.75953007], [74.90509796, 12.75993061], [74.90804291, 12.76257133], [74.90911102, 12.76303101], [74.92935181, 12.77133179], [74.93733215, 12.77219105], [74.95420074, 12.77928066], [74.96025848, 12.77904034], [74.96337128, 12.77482986], [74.96536255, 12.77480125], [74.96726227, 12.77685165], [74.96862793, 12.77626133], [74.96900177, 12.77292919], [74.97067261, 12.77256012], [74.98192596, 12.77523994], [74.98729706, 12.77792072], [74.9925766, 12.78362083], [74.98883057, 12.78923035], [74.98945618, 12.79081059], [74.99228668, 12.79045963], [74.9960022, 12.78798103], [75.00029755, 12.7834816], [75.00393677, 12.78561974], [75.00527954, 12.78549194], [75.0041275, 12.77355194], [75.00522614, 12.76933098], [75.00779724, 12.76509094], [75.00860596, 12.76043129], [75.0071106, 12.75706196], [75.00427246, 12.75399017], [75.0002594, 12.75155067], [74.99529266, 12.74484062], [74.99175262, 12.73816967], [74.98986053, 12.73728085], [74.9860611, 12.73847961], [74.98442841, 12.73594093], [74.98477936, 12.72988129], [74.98693848, 12.72879791], [74.98838043, 12.73192978], [74.99015045, 12.73110008], [74.99304962, 12.73313999], [75.00023651, 12.72740078], [75.01216888, 12.72284126], [75.01085663, 12.71928978], [75.00306702, 12.71369171], [75.00402832, 12.71172142], [75.00708008, 12.70920944], [75.01429749, 12.70780087], [75.01905823, 12.71475029], [75.02295685, 12.71562099], [75.0256958, 12.71431923], [75.0313797, 12.71695232], [75.03811646, 12.71858978], [75.04308319, 12.71552944], [75.04624176, 12.7163496], [75.04966736, 12.71469975], [75.05285645, 12.7098217], [75.05574799, 12.7034111], [75.0521698, 12.69817066], [75.05679321, 12.68672085], [75.05455017, 12.6835804], [75.05213165, 12.6870079], [75.04859924, 12.68832111], [75.04467773, 12.68744087], [75.04309082, 12.67057133], [75.04476166, 12.66330147], [75.04780579, 12.66008854], [75.05531311, 12.66006184], [75.05827332, 12.65863132], [75.0608902, 12.66148186], [75.06600952, 12.65795231], [75.07026672, 12.65802002], [75.07520294, 12.66543198], [75.079422, 12.6665802], [75.08309174, 12.66640854], [75.08490753, 12.67047977], [75.08670044, 12.67085075], [75.08743286, 12.67596054], [75.0849762, 12.68968201], [75.08242798, 12.69322968], [75.08609772, 12.69778156], [75.09163666, 12.69471169], [75.09925842, 12.69335079], [75.10441589, 12.69155121], [75.10865784, 12.68494129], [75.1126709, 12.67591095], [75.12078857, 12.67356968], [75.12689972, 12.67331123], [75.13188934, 12.67084026], [75.13667297, 12.67117119], [75.1391983, 12.67275047], [75.14450836, 12.6729002], [75.1506424, 12.67634201], [75.1506958, 12.66885853], [75.15571594, 12.66603088], [75.16113281, 12.66567993], [75.16129303, 12.66407108], [75.1550827, 12.65367985], [75.15164948, 12.64936066], [75.15123749, 12.64344025], [75.15032959, 12.64188957], [75.14122009, 12.63782024], [75.14296722, 12.63331032], [75.14766693, 12.62865067], [75.15487671, 12.61958027], [75.15917206, 12.61705017], [75.16279602, 12.61763954], [75.1700058, 12.61655998], [75.1774826, 12.62220955], [75.18257904, 12.62744141], [75.18985748, 12.62705135], [75.19438171, 12.62543106], [75.20143127, 12.62511063], [75.20279694, 12.62307167], [75.19946289, 12.61312103], [75.19870758, 12.60616016], [75.20244598, 12.60272121], [75.20729828, 12.59994984], [75.20954132, 12.59727192], [75.20897675, 12.59154034], [75.20749664, 12.58850193], [75.2045517, 12.58665085], [75.20340729, 12.58057022], [75.20752716, 12.58299065], [75.21084595, 12.58397961], [75.21404266, 12.57341194], [75.21691132, 12.57107067], [75.22290039, 12.56264019], [75.23129272, 12.56082153], [75.23629761, 12.56184006], [75.2381897, 12.56411266], [75.23867798, 12.57250023], [75.24003601, 12.57396984], [75.24948883, 12.57488155], [75.25019836, 12.5791893], [75.25617981, 12.58572102], [75.25881958, 12.59097004], [75.262146, 12.59300137], [75.26785278, 12.60568047], [75.27031708, 12.60898018], [75.27672577, 12.61166], [75.28103638, 12.60802937], [75.28885651, 12.60458088], [75.2911377, 12.59661961], [75.29390717, 12.59554195], [75.29833984, 12.59841061], [75.30149078, 12.59906101], [75.30561829, 12.59492016], [75.30825043, 12.58786964], [75.31852722, 12.58514023], [75.32785797, 12.58518124], [75.32846069, 12.57711124], [75.3263092, 12.57444191], [75.31936646, 12.57374191], [75.31619263, 12.56866169], [75.30977631, 12.57163239], [75.30314636, 12.57349968], [75.29496765, 12.57492924], [75.29139709, 12.57488155], [75.28676605, 12.56499004], [75.28349304, 12.56417179], [75.27683258, 12.56408978], [75.27258301, 12.55886173], [75.2709198, 12.55354023], [75.27240753, 12.53988075], [75.27961731, 12.52338028], [75.28114319, 12.51813984], [75.28581238, 12.51986122], [75.29177094, 12.52069092], [75.29611969, 12.51966], [75.30004883, 12.51689053], [75.30465698, 12.51729012], [75.30430603, 12.49751186], [75.3049469, 12.49675274], [75.30735016, 12.49741173], [75.31009674, 12.495821], [75.3141861, 12.49202061], [75.32064056, 12.49125099], [75.32805634, 12.49177074], [75.3348465, 12.49024105], [75.33557892, 12.48504925], [75.33898926, 12.48294067], [75.3393631, 12.47964954], [75.33833313, 12.47334194], [75.3405304, 12.46463108], [75.33676147, 12.45778179], [75.34086609, 12.45604992], [75.3556366, 12.45802116], [75.35941315, 12.45998096], [75.36273956, 12.46489143], [75.37206268, 12.46878147], [75.3730011, 12.47716141], [75.37055206, 12.48099041], [75.37000275, 12.48346996], [75.37223816, 12.48550987], [75.37721252, 12.48643112], [75.37950897, 12.48787975], [75.381073, 12.49149036], [75.3830719, 12.49265957], [75.38656616, 12.49192142], [75.39187622, 12.49254131], [75.39492798, 12.49755955], [75.39731598, 12.49781036], [75.40099335, 12.49057198], [75.40423584, 12.48960114], [75.40892029, 12.49419117], [75.41448975, 12.49671173], [75.42018127, 12.47966194], [75.42053986, 12.4715414], [75.42428589, 12.46625137], [75.42250824, 12.46006107], [75.41677094, 12.45888042], [75.41467285, 12.45409203], [75.40908051, 12.44985008], [75.40349579, 12.44756889], [75.39192963, 12.44508934], [75.38582611, 12.45070076], [75.36662292, 12.45166016], [75.3658905, 12.44908047], [75.36943817, 12.44563198], [75.3705368, 12.42894173], [75.36560059, 12.4070406], [75.36972046, 12.4017992], [75.37219238, 12.39573002], [75.3761673, 12.39246178], [75.37858582, 12.38667107], [75.38117218, 12.38479042], [75.38578796, 12.3855896], [75.39071655, 12.38344097], [75.39433289, 12.37983131], [75.39711761, 12.37524128], [75.40113831, 12.37570095], [75.40336609, 12.37255955], [75.41146088, 12.37457085], [75.41886902, 12.36952019], [75.42138672, 12.36672974], [75.4214325, 12.36190128], [75.4193573, 12.35254955], [75.4177475, 12.34843063], [75.41427612, 12.34393024], [75.41005707, 12.34134102], [75.41117859, 12.33782196], [75.41436768, 12.33375072], [75.41633606, 12.32147121], [75.41985321, 12.31946087], [75.41996002, 12.31446075], [75.42308044, 12.30814075], [75.42990875, 12.30223083], [75.43039703, 12.29952145], [75.42164612, 12.29096127], [75.41912842, 12.28639984], [75.42366791, 12.28703976], [75.42737579, 12.29067135], [75.43073273, 12.29200172], [75.43608093, 12.29181099], [75.44140625, 12.29001045], [75.45836639, 12.28855228], [75.46720886, 12.29537964], [75.48272705, 12.28618145], [75.48670197, 12.28146076], [75.49252319, 12.26681995], [75.4940033, 12.265131], [75.50200653, 12.2640419], [75.50392914, 12.26315975], [75.5038681, 12.25970173], [75.5111084, 12.25332069], [75.51140594, 12.25043964], [75.51307678, 12.24932098], [75.51667023, 12.24375057], [75.51928711, 12.23593998], [75.51994324, 12.23317146], [75.51850128, 12.23060036], [75.52336121, 12.22887039], [75.52482605, 12.22503185], [75.52532959, 12.21963024], [75.53793335, 12.21105194], [75.53804779, 12.20678139], [75.53688049, 12.20352173], [75.5329895, 12.19909096], [75.53373718, 12.19609165], [75.53791809, 12.19539165], [75.54036713, 12.19237041], [75.54386139, 12.19197083], [75.54875183, 12.18838978], [75.5511322, 12.18444061], [75.55240631, 12.17614174], [75.55525208, 12.17633057], [75.55961609, 12.16867065], [75.56384277, 12.16683197], [75.57038879, 12.16545963], [75.57684326, 12.15075016], [75.58271027, 12.15043068], [75.58715057, 12.14829063], [75.59144592, 12.14304924], [75.5931778, 12.14295959], [75.59471893, 12.14535999], [75.59760284, 12.1465292], [75.6020813, 12.1467514], [75.60814667, 12.1486702], [75.61131287, 12.14586163], [75.61708832, 12.14893246], [75.6268692, 12.14505005], [75.62937164, 12.14161968], [75.63508606, 12.1423912], [75.63678741, 12.14042091], [75.63761902, 12.13377953], [75.64068604, 12.13315105], [75.64250946, 12.13077164], [75.64385223, 12.12707043], [75.64433289, 12.12371063], [75.64298248, 12.11993027], [75.64745331, 12.11475086], [75.64807892, 12.10558033], [75.65155029, 12.10396194], [75.65278625, 12.10130024], [75.65822601, 12.09430122], [75.66242981, 12.0911808], [75.66760254, 12.09000015], [75.67273712, 12.09066963], [75.67830658, 12.09306145], [75.681633, 12.09657955], [75.68419647, 12.10224056], [75.6919632, 12.10258961], [75.70159912, 12.10033131], [75.70033264, 12.08803082], [75.70066071, 12.08353043], [75.70652771, 12.08280945], [75.71714783, 12.07843113], [75.71753693, 12.07745075], [75.71420288, 12.06921196], [75.71465302, 12.06534195], [75.71705627, 12.06208992], [75.72805023, 12.06410027], [75.73435974, 12.06770134], [75.73890686, 12.0721817], [75.74294281, 12.07178116], [75.74758911, 12.0734396], [75.75190735, 12.07740974], [75.75813293, 12.07721043], [75.76296234, 12.07858181], [75.7678833, 12.07752037], [75.78370667, 12.07643032], [75.7895813, 12.07461071], [75.79534912, 12.07423115], [75.79968262, 12.0711813], [75.80169678, 12.06797886], [75.79618073, 12.04949093], [75.79325867, 12.04751015], [75.79785919, 12.04164124], [75.79857635, 12.03966999], [75.79815674, 12.03267097], [75.79995728, 12.0302906], [75.81019592, 12.02406025], [75.81199646, 12.02196121], [75.81191254, 12.01611042], [75.8235321, 12.00933933], [75.82662964, 12.00579071], [75.82752228, 12.00284958], [75.82375336, 11.99456978], [75.82359314, 11.99456978], [75.8243866, 11.98427963], [75.82697296, 11.97797108], [75.83058929, 11.97463036], [75.83969116, 11.97281075], [75.84443665, 11.97027016], [75.84657288, 11.96465015], [75.85108948, 11.95704174], [75.86589813, 11.94563007], [75.87674713, 11.94071198], [75.88330078, 11.93891239], [75.88968658, 11.93814087], [75.89444733, 11.9365406], [75.90379333, 11.93476963], [75.91543579, 11.93402958], [75.91963196, 11.93562126], [75.92518616, 11.93287182], [75.93112183, 11.93111038], [75.93718719, 11.93283081], [75.94838715, 11.93391132], [75.95490265, 11.93151093], [75.95887756, 11.92860985], [75.9679184, 11.92697144], [75.97264862, 11.92755032], [75.97627258, 11.92496967], [75.9798584, 11.92466927], [75.98336792, 11.92544174], [75.9944458, 11.9233017], [75.99819183, 11.92362118], [76.00396729, 11.93192101], [76.01390076, 11.93326187], [76.01843262, 11.9350214], [76.02301788, 11.93465042], [76.02958679, 11.93278122], [76.03851318, 11.93900013], [76.04194641, 11.9433012], [76.04775238, 11.94447041], [76.06674957, 11.95827103], [76.07280731, 11.96128082], [76.08100128, 11.96067047], [76.09127045, 11.96158886], [76.10791016, 11.97063923], [76.10865021, 11.9280901], [76.10743713, 11.87633991], [76.10874939, 11.87059021], [76.10932159, 11.85859013], [76.10806274, 11.85118103], [76.11653137, 11.84304047], [76.12043762, 11.84429073], [76.1256485, 11.84477043], [76.13902283, 11.85711098], [76.14942169, 11.86101055], [76.16259003, 11.86003113], [76.1736908, 11.86244202], [76.18403625, 11.8637619], [76.19608307, 11.85554123], [76.20088959, 11.85412979], [76.20342255, 11.84906101], [76.20510864, 11.83865929], [76.20720673, 11.83176041], [76.205513, 11.81958103], [76.21199036, 11.81427002], [76.21431732, 11.80420971], [76.21852875, 11.80003929], [76.23210907, 11.79646969], [76.2443924, 11.79531002], [76.25312805, 11.79979992], [76.26544952, 11.80041122], [76.2720108, 11.80354023], [76.27509308, 11.80076027], [76.28365326, 11.78486919], [76.29469299, 11.7780714], [76.29995728, 11.77615166], [76.30311584, 11.76957035], [76.3105011, 11.7438612], [76.31758118, 11.7403717], [76.32434845, 11.73873138], [76.3349762, 11.73062992], [76.34091949, 11.73110008], [76.34625244, 11.73050117], [76.35114288, 11.73443031], [76.35604858, 11.73991108], [76.37233734, 11.73620129], [76.38376617, 11.74504089], [76.39071655, 11.74286938], [76.40441895, 11.74985027], [76.4076767, 11.75333118], [76.4108429, 11.7464819], [76.40661621, 11.74063969], [76.40558624, 11.73336124], [76.41197968, 11.73429108], [76.41726685, 11.72593117], [76.41899109, 11.7215004], [76.41889191, 11.71708107], [76.41793823, 11.71358013], [76.41108704, 11.70995045], [76.40867615, 11.70414925], [76.40628815, 11.70359993], [76.40310669, 11.70677853], [76.39640808, 11.70107937], [76.40293884, 11.69948196], [76.40219879, 11.68311977], [76.40740204, 11.66953087], [76.41020966, 11.66456985], [76.41757965, 11.66342068], [76.42346191, 11.65932083], [76.42767334, 11.64752197], [76.4298172, 11.6450901], [76.43461609, 11.64161015], [76.43557739, 11.63770103], [76.43421936, 11.63352108], [76.43070221, 11.62963104], [76.42588806, 11.62903118], [76.42479706, 11.62329006], [76.42128754, 11.62510014], [76.39618683, 11.62531185], [76.38006592, 11.62241936], [76.37674713, 11.61474133], [76.37683868, 11.60464001], [76.37106323, 11.60069942], [76.37069702, 11.59346962], [76.3653717, 11.59171867], [76.35011292, 11.58274174], [76.34034729, 11.58056068], [76.33558655, 11.57834053], [76.33349609, 11.58065033], [76.3334198, 11.58512974], [76.32858276, 11.58855057], [76.31109619, 11.57751083], [76.30919647, 11.56960011], [76.30517578, 11.57042122], [76.29789734, 11.56433105], [76.29377747, 11.56503105], [76.29316711, 11.57176113], [76.29064178, 11.58056068], [76.28588867, 11.58295155], [76.27793884, 11.5835104], [76.27600098, 11.58995056], [76.27097321, 11.59290886], [76.266716, 11.58932018], [76.25969696, 11.5869379], [76.22574615, 11.56443977], [76.22693634, 11.55968189], [76.23445892, 11.54648113], [76.2383194, 11.53335953], [76.24246979, 11.52879047], [76.24295807, 11.5241909], [76.23964691, 11.52094078], [76.23320007, 11.51867962], [76.24151611, 11.50479126], [76.24288177, 11.49868965], [76.24475861, 11.49432087], [76.24089813, 11.47521019], [76.24009705, 11.45964146], [76.24726868, 11.46414948], [76.25792694, 11.47322273], [76.26608276, 11.46869183], [76.27806091, 11.47453117], [76.28578949, 11.46857071], [76.28769684, 11.46599102], [76.28407288, 11.46243954], [76.28903961, 11.4563179], [76.297966, 11.4588604], [76.30593872, 11.45335102], [76.32090759, 11.44469929], [76.33368683, 11.45871067], [76.33905792, 11.45417976], [76.35308075, 11.45083046], [76.36148071, 11.44796085], [76.37058258, 11.44089985], [76.39057922, 11.42796135], [76.41039276, 11.43359089], [76.41004944, 11.42520142], [76.40817261, 11.41481972], [76.41838837, 11.40526962], [76.43934631, 11.39066982], [76.44838715, 11.38141918], [76.47286987, 11.37534142], [76.51007843, 11.36115074], [76.50945282, 11.3537302], [76.50673676, 11.34766006], [76.50949097, 11.34661198], [76.51637268, 11.34897137], [76.52986145, 11.34768105], [76.53820038, 11.35159016], [76.54075623, 11.32704067], [76.53978729, 11.32095146], [76.53524017, 11.3163414], [76.53048706, 11.30963993], [76.52854156, 11.30344963], [76.5304718, 11.29574203], [76.54016876, 11.29234791], [76.53405762, 11.28796101], [76.52194977, 11.28120136], [76.51593018, 11.2724514], [76.51309204, 11.26466084], [76.51352692, 11.26196003], [76.48812866, 11.25196171], [76.44638824, 11.23046112], [76.44287872, 11.20009136], [76.43802643, 11.19454956], [76.44030762, 11.19125938], [76.443573, 11.1908989], [76.45272064, 11.18021011], [76.45883179, 11.18412971], [76.46653748, 11.18609047], [76.46586609, 11.19874191], [76.474823, 11.20125961], [76.48764801, 11.20279026], [76.50231171, 11.20286179], [76.50601196, 11.20197964], [76.51024628, 11.19528198], [76.5212326, 11.19027042], [76.53611755, 11.18931103], [76.54801178, 11.19314194], [76.57778168, 11.19684124], [76.59333801, 11.19749069], [76.60205841, 11.1954689], [76.62303925, 11.18567085], [76.62966919, 11.19080067], [76.64164734, 11.19651031], [76.65344238, 11.20429134], [76.66819, 11.21068001], [76.67816925, 11.21883011], [76.67784119, 11.22280025], [76.67938995, 11.2270298], [76.69696808, 11.23133087], [76.71038818, 11.21831036], [76.72054291, 11.21163273], [76.72261047, 11.20810032], [76.72557831, 11.20889091], [76.72654724, 11.20646954], [76.71795654, 11.19831085], [76.71791077, 11.19240093], [76.72115326, 11.18451118], [76.71375275, 11.17801094], [76.70643616, 11.1796217], [76.70133209, 11.17453957], [76.69676971, 11.17187977], [76.6934967, 11.16672039], [76.68902588, 11.16508961], [76.68601227, 11.15770054], [76.69117737, 11.14451027], [76.6950531, 11.14023018], [76.69667816, 11.13268089], [76.70014954, 11.1314497], [76.70361328, 11.13201141], [76.70555878, 11.13612938], [76.70269012, 11.13862038], [76.70298767, 11.14178181], [76.70983124, 11.1402998], [76.71266174, 11.13286972], [76.71536255, 11.12842083], [76.72220612, 11.12251186], [76.72930908, 11.12539005], [76.73493195, 11.12512112], [76.73871613, 11.12129021], [76.7388916, 11.11485958], [76.74060822, 11.10991001], [76.73937225, 11.10361099], [76.73500061, 11.09910011], [76.73413849, 11.0933609], [76.73858643, 11.08395958], [76.74272919, 11.08600044], [76.74572754, 11.08392143], [76.7462616, 11.07885933], [76.74803925, 11.0751009], [76.74643707, 11.07087135], [76.73449707, 11.06389046], [76.73443604, 11.05832195], [76.73600006, 11.05445194], [76.73709869, 11.04751015], [76.74022675, 11.04562855], [76.74649048, 11.04697037], [76.75112915, 11.04675961], [76.754776, 11.03919983], [76.76232147, 11.03426075], [76.7671814, 11.03221035], [76.7754364, 11.03428173], [76.7899704, 11.04968166], [76.79342651, 11.04701138], [76.79247284, 11.0423727], [76.78678131, 11.03225136], [76.78183746, 11.02895069], [76.75697327, 11.02459145], [76.74401855, 11.02590084], [76.73239899, 11.02897072], [76.71205139, 11.03245068], [76.70652008, 11.03135109], [76.69883728, 11.0226717], [76.6904068, 11.01749992], [76.67978668, 10.99943066], [76.68081665, 10.99265957], [76.67868805, 10.98605061], [76.67777252, 10.97970104], [76.66044617, 10.96045971], [76.65931702, 10.95048046], [76.654953, 10.94219112], [76.65727997, 10.93868065], [76.65558624, 10.93427086], [76.64739227, 10.92897034], [76.64916229, 10.92415237], [76.65278625, 10.91996002], [76.67487335, 10.90640163], [76.68460083, 10.90243053], [76.69300079, 10.90227032], [76.70040131, 10.90079021], [76.71142578, 10.89556026], [76.71846008, 10.88984108], [76.72283936, 10.88762188], [76.7278595, 10.88679886], [76.73079681, 10.88408184], [76.7326889, 10.88097954], [76.73943329, 10.88443089], [76.74395752, 10.88492107], [76.74910736, 10.88478184], [76.76191711, 10.87977028], [76.76669312, 10.88174057], [76.77298737, 10.88164139], [76.77773285, 10.87897015], [76.78128052, 10.87390137], [76.78527069, 10.87147236], [76.79094696, 10.87096977], [76.81755829, 10.86180115], [76.82089233, 10.85891056], [76.82459259, 10.85044193], [76.82762909, 10.84714031], [76.83407593, 10.84270191], [76.83872986, 10.83762169], [76.84266663, 10.83185101], [76.84519196, 10.82650185], [76.84342957, 10.82250023], [76.83712769, 10.81553936], [76.84041595, 10.8076601], [76.85259247, 10.80850124], [76.85999298, 10.79980183], [76.88194275, 10.80107117], [76.88829803, 10.79988194], [76.89148712, 10.79216003], [76.89750671, 10.77079964], [76.89668274, 10.76607132], [76.89385986, 10.76055145], [76.89427948, 10.75535202], [76.8931427, 10.75040245], [76.89035034, 10.74749088], [76.88765717, 10.74300957], [76.88680267, 10.73674965], [76.88040161, 10.72614002], [76.87931824, 10.72023964], [76.88128662, 10.71292973], [76.88374329, 10.70735073], [76.88101196, 10.70606136], [76.87504578, 10.70672035], [76.8651123, 10.69293976], [76.86160278, 10.68626022], [76.86190033, 10.68056202], [76.85980225, 10.67714119], [76.8555069, 10.67527199], [76.85507202, 10.67240047], [76.86326599, 10.66695976], [76.86769867, 10.66623974], [76.87016296, 10.66409969], [76.87036896, 10.66076088], [76.86947632, 10.65635967], [76.87216949, 10.65353107], [76.87460327, 10.63922977], [76.87261963, 10.62943172], [76.85952759, 10.62520027], [76.85246277, 10.62394142], [76.84471893, 10.62627125], [76.83822632, 10.62671089], [76.83129883, 10.62588978], [76.82685089, 10.627141], [76.8224411, 10.62738132], [76.81468964, 10.6260004], [76.80499268, 10.62634087], [76.80568695, 10.62082958], [76.80326843, 10.61408043], [76.80497742, 10.60913181], [76.80847931, 10.60727024], [76.80961609, 10.60427856], [76.80861664, 10.59448147], [76.81539917, 10.58829975], [76.82450104, 10.58956146], [76.82834625, 10.58827972], [76.82972717, 10.58506203], [76.82932281, 10.5764513], [76.82601166, 10.56751919], [76.82546234, 10.56156158], [76.82907104, 10.55706024], [76.83017731, 10.55298138], [76.82572937, 10.54298019], [76.8245163, 10.53763962], [76.83196259, 10.52916145], [76.83143616, 10.52457142], [76.82525635, 10.50298119], [76.82028961, 10.49067974], [76.82097626, 10.48023129], [76.81745148, 10.43848991], [76.80732727, 10.41491985], [76.81196594, 10.41138935], [76.81503296, 10.40178967], [76.82145691, 10.40340996], [76.82264709, 10.39893246], [76.82264709, 10.39406109], [76.8156662, 10.38653088], [76.82048798, 10.38179016], [76.82460785, 10.37524033], [76.83069611, 10.37210178], [76.83815765, 10.36264133], [76.83934784, 10.35970974], [76.83624268, 10.35296059], [76.83577728, 10.34636974], [76.82756042, 10.33758163], [76.82569122, 10.33421135], [76.82676697, 10.33026123], [76.82585907, 10.32004166], [76.82419586, 10.31231117], [76.81961823, 10.30263996], [76.81967163, 10.2952404], [76.82492065, 10.29383087], [76.83000183, 10.29111004], [76.83194733, 10.28377056], [76.83525085, 10.2816906], [76.83854675, 10.27759933], [76.83988953, 10.27754021], [76.83985901, 10.28143978], [76.84056854, 10.28361034], [76.85073853, 10.2828207], [76.85788727, 10.28926182], [76.86057281, 10.29074097], [76.86427307, 10.29004097], [76.86206818, 10.28254986], [76.86157227, 10.26962852], [76.86229706, 10.26706123], [76.87081909, 10.26408195], [76.87705994, 10.25631046], [76.8846283, 10.25507927], [76.89182281, 10.24308014], [76.89356232, 10.23744106], [76.89231873, 10.23267078], [76.89872742, 10.2325592], [76.90123749, 10.22781181], [76.90547943, 10.22475147], [76.90934753, 10.22319889], [76.92030334, 10.22544098], [76.92500305, 10.22978115], [76.92777252, 10.22958946], [76.93920898, 10.2211113], [76.94587708, 10.22279072], [76.95226288, 10.2197504], [76.95878601, 10.21873188], [76.96176147, 10.21581173], [76.96734619, 10.21257973], [76.97078705, 10.20865059], [76.97458649, 10.21393204], [76.98145294, 10.21990967], [76.98726654, 10.21994019], [76.99141693, 10.22299957], [76.99372101, 10.22772121], [76.99577332, 10.22935009], [76.99939728, 10.22979927], [77.00666809, 10.23637009], [77.01522064, 10.23759174], [77.01603699, 10.24096012], [77.01859283, 10.24183083], [77.03025818, 10.24293232], [77.03855133, 10.24816036], [77.04250336, 10.26197147], [77.03383636, 10.27217102], [77.0460968, 10.27429008], [77.05332184, 10.27989006], [77.05111694, 10.2828598], [77.05187988, 10.28548145], [77.06078339, 10.28646088], [77.06755066, 10.29022121], [77.07344055, 10.29579163], [77.08170319, 10.29965019], [77.08795929, 10.30176067], [77.09224701, 10.30426979], [77.10072327, 10.30445004], [77.10832214, 10.30717087], [77.11425781, 10.31056023], [77.11933136, 10.31551075], [77.12673187, 10.32024193], [77.13405609, 10.32371998], [77.14823151, 10.33405972], [77.16295624, 10.34628105], [77.16883087, 10.34598923], [77.17312622, 10.34401131], [77.18136597, 10.34317017], [77.1889801, 10.34617043], [77.19274139, 10.3434], [77.19946289, 10.34195137], [77.21444702, 10.34136963], [77.22216034, 10.34030056], [77.22251129, 10.32853127], [77.21833038, 10.32201958], [77.2144928, 10.30580139], [77.21720886, 10.29800034], [77.22093201, 10.29603958], [77.23191833, 10.27723026], [77.24652863, 10.25755024], [77.25054932, 10.2537508], [77.24755859, 10.25157166], [77.24530029, 10.24857044], [77.24482727, 10.24518967], [77.24577332, 10.23215103], [77.2455368, 10.22625065], [77.24652863, 10.22060966], [77.24915314, 10.22205925], [77.2512207, 10.22436142], [77.25418854, 10.22332191], [77.25556946, 10.22552967], [77.25875092, 10.22385979], [77.26622772, 10.22509003], [77.26996613, 10.22433186], [77.27482605, 10.22054958], [77.28044891, 10.20725155], [77.27905273, 10.20401096], [77.27620697, 10.20366192], [77.27385712, 10.20146942], [77.27297974, 10.19776058], [77.26966858, 10.19678974], [77.2713623, 10.19406033], [77.26941681, 10.18710041], [77.26441193, 10.17973995], [77.25914764, 10.15535069], [77.25961304, 10.14122963], [77.25743103, 10.13588142], [77.25756073, 10.13222027], [77.26013947, 10.13066101], [77.26101685, 10.12869167], [77.25978088, 10.11908054], [77.25498962, 10.11631203], [77.25327301, 10.11140919], [77.24608612, 10.11235142], [77.23990631, 10.11413956], [77.23483276, 10.11665058], [77.2305069, 10.12012005], [77.22511292, 10.11845016], [77.22126007, 10.11537075], [77.21872711, 10.11129093], [77.2154007, 10.10929203], [77.21234894, 10.10876083], [77.20600128, 10.10603142], [77.20330048, 10.10362244], [77.19787598, 10.10647964], [77.19460297, 10.10624886], [77.18814087, 10.09565163], [77.18779755, 10.09250164], [77.18990326, 10.09097004], [77.18979645, 10.08655071], [77.19072723, 10.08115196], [77.19519806, 10.07354164], [77.19906616, 10.07066059], [77.20443726, 10.06849098], [77.2129364, 10.0584507], [77.21817017, 10.05686092], [77.22068024, 10.05061054], [77.2244873, 10.04554939], [77.23065948, 10.03952122], [77.23707581, 10.03520203], [77.2423172, 10.02615166], [77.24556732, 10.02362156], [77.24809265, 10.02023029], [77.24893188, 10.01581097], [77.24443054, 10.00774956], [77.2407074, 10.00289059], [77.24088287, 10.00013065], [77.24768066, 9.99484062], [77.24772644, 9.99116039], [77.2478714, 9.99116039], [77.24514771, 9.98622131], [77.24672699, 9.98149014], [77.25076294, 9.98140144], [77.2487793, 9.97740078], [77.24983978, 9.97278118], [77.25952148, 9.96620083], [77.2614212, 9.96372128], [77.25898743, 9.953372], [77.25527954, 9.95018959], [77.24991608, 9.94253922], [77.24021149, 9.94306087], [77.23661041, 9.94138145], [77.23594666, 9.94338036], [77.23471069, 9.94283104], [77.23448181, 9.93811131], [77.2219162, 9.92282009], [77.22094727, 9.91775131], [77.21689606, 9.90576077], [77.20443726, 9.89431953], [77.20654297, 9.87776184], [77.2027359, 9.87474155], [77.20144653, 9.869771], [77.19911194, 9.8659811], [77.20919037, 9.85379028], [77.21325684, 9.85198021], [77.2183075, 9.8534708], [77.22366333, 9.84901047], [77.22373962, 9.84296131], [77.21383667, 9.83854008], [77.21335602, 9.832901], [77.21502686, 9.83087063], [77.20892334, 9.81452179], [77.21235657, 9.81293201], [77.21898651, 9.81325054], [77.21945953, 9.80884075], [77.22708893, 9.80631065], [77.23282623, 9.79728985], [77.23203278, 9.79441071], [77.2339859, 9.78851986], [77.2266922, 9.78675079], [77.22254944, 9.78177071], [77.20981598, 9.77994061], [77.21069336, 9.76638889], [77.21859741, 9.76000977], [77.2124176, 9.75539017], [77.21135712, 9.74524975], [77.20603943, 9.7374897], [77.20822906, 9.72167015], [77.19991302, 9.71728992], [77.18992615, 9.71551037], [77.19021606, 9.70615196], [77.18900299, 9.69750023], [77.19168854, 9.68618202], [77.18589783, 9.67817116], [77.18477631, 9.67147923], [77.18219757, 9.66871929], [77.17959595, 9.66038036], [77.17251587, 9.65620041], [77.17308807, 9.65184021], [77.16887665, 9.65157986], [77.16565704, 9.6482296], [77.16588593, 9.6379509], [77.16062927, 9.63024139], [77.16065216, 9.6273098], [77.1622467, 9.61981106], [77.15457916, 9.61395168], [77.15487671, 9.60838127], [77.15187073, 9.60601997], [77.15550232, 9.60150146], [77.1672821, 9.60066891], [77.17456818, 9.59716129], [77.17914581, 9.60146046], [77.18398285, 9.6024313], [77.18596649, 9.60592175], [77.19593811, 9.60419178], [77.19657898, 9.59570026], [77.20081329, 9.5923996], [77.2053833, 9.59227943], [77.20861053, 9.58883953], [77.20910645, 9.58443928], [77.21466827, 9.57880116], [77.22280884, 9.57279015], [77.22989655, 9.57592201], [77.2388916, 9.57336044], [77.24198914, 9.57154083], [77.24475861, 9.56861115], [77.24672699, 9.56866074], [77.25054932, 9.56541061], [77.25501251, 9.564991], [77.25785828, 9.56816196], [77.26113892, 9.56667995], [77.27529144, 9.57658958], [77.27497101, 9.58095169], [77.27954102, 9.58006954], [77.28649139, 9.58729935], [77.30430603, 9.59304142], [77.30901337, 9.58883095], [77.31371307, 9.59013939], [77.31484985, 9.58862114], [77.31078339, 9.58450127], [77.31201172, 9.57815075], [77.30976105, 9.5759697], [77.31067657, 9.57036114], [77.32100677, 9.56737137], [77.32478333, 9.5632], [77.32850647, 9.57322979], [77.34089661, 9.59505081], [77.35106659, 9.58930016], [77.35132599, 9.58804035], [77.34922028, 9.58649921], [77.34623718, 9.58780956], [77.34481812, 9.58760929], [77.34320068, 9.58481121], [77.34091949, 9.57763958], [77.34525299, 9.56727028], [77.34371185, 9.56384945], [77.3405304, 9.56406116], [77.33587646, 9.55683041], [77.33743286, 9.55486012], [77.33805084, 9.55027008], [77.33996582, 9.54911041], [77.34655762, 9.5485611], [77.34880829, 9.5461998], [77.35057068, 9.54026031], [77.35054779, 9.52629185], [77.35470581, 9.52390957], [77.36097717, 9.51616955], [77.36625671, 9.51479053], [77.37071991, 9.50869179], [77.3867569, 9.51673985], [77.38639832, 9.50679111], [77.39008331, 9.50463104], [77.39486694, 9.50439072], [77.3962326, 9.49654198], [77.38788605, 9.49096012], [77.38551331, 9.48619175], [77.38391876, 9.47909069], [77.38405609, 9.46977997], [77.38683319, 9.46737099], [77.38220978, 9.46118069], [77.37737274, 9.45866013], [77.37858582, 9.45075035], [77.37223816, 9.44527054], [77.36765289, 9.44390106], [77.3636322, 9.4433012], [77.3602066, 9.44367981], [77.35655212, 9.44791031], [77.35160828, 9.44970131], [77.34542847, 9.445261], [77.34292603, 9.4404211], [77.3342514, 9.43105125], [77.33461761, 9.42393112], [77.33185577, 9.42138958], [77.33007813, 9.41521072], [77.3241272, 9.40818024], [77.32167816, 9.40565014], [77.32137299, 9.40180111], [77.3274231, 9.39406109], [77.32762909, 9.38980961], [77.32488251, 9.38354015], [77.32608795, 9.38046074], [77.32579041, 9.37868118], [77.31980133, 9.37613106], [77.31954193, 9.36326027], [77.32303619, 9.35856056], [77.32000732, 9.35480022], [77.32061005, 9.35109043], [77.30966187, 9.33464146], [77.31134033, 9.32790184], [77.30702972, 9.327631], [77.30010986, 9.32495022], [77.29055023, 9.327672], [77.28687286, 9.32690144], [77.28414154, 9.32747078], [77.28515625, 9.32123089], [77.28230286, 9.31961918], [77.2853775, 9.31560135], [77.28681946, 9.31006145], [77.28675842, 9.30811024], [77.28423309, 9.30506039], [77.28350067, 9.30091], [77.27768707, 9.29526043], [77.27345276, 9.29419136], [77.27011108, 9.29177094], [77.26682281, 9.2908802], [77.26714325, 9.28168964], [77.27411652, 9.26317024], [77.26760864, 9.26239967], [77.2678299, 9.25787067], [77.26590729, 9.25529099], [77.26566315, 9.24368095], [77.26248169, 9.24090958], [77.26364899, 9.23185921], [77.2594986, 9.22441101], [77.26139069, 9.21698093], [77.26680756, 9.20881939], [77.25817871, 9.20007038], [77.2532959, 9.19336033], [77.25026703, 9.19023991], [77.24704742, 9.18925953], [77.23973083, 9.18994999], [77.23957062, 9.18656063], [77.23661804, 9.17919064], [77.24328613, 9.17612076], [77.24550629, 9.17597008], [77.2483902, 9.17578125], [77.25229645, 9.16495132], [77.24960327, 9.15603924], [77.25177765, 9.14304066], [77.24606323, 9.13924026], [77.24537659, 9.13554955], [77.23766327, 9.1299696], [77.23258209, 9.11791134], [77.23015594, 9.1148119], [77.22572327, 9.1141386], [77.21704865, 9.10809135], [77.21173096, 9.10636139], [77.20935059, 9.09757042], [77.20482635, 9.09581089], [77.2022171, 9.09138012], [77.19586182, 9.08842182], [77.18974304, 9.07518005], [77.19062042, 9.06997013], [77.19284821, 9.06503105], [77.19148254, 9.06195164], [77.1886673, 9.05648041], [77.18434906, 9.05064011], [77.18286896, 9.04710102], [77.18019104, 9.04480076], [77.18208313, 9.03650093], [77.17014313, 9.03388023], [77.16742706, 9.0385313], [77.15376282, 9.03656006], [77.14824677, 9.03298187], [77.14533234, 9.02721977], [77.14689636, 9.02156067], [77.14055634, 9.01543045], [77.13648987, 9.01310062], [77.13217926, 9.01185036], [77.13326263, 9.00825119], [77.13510895, 9.00547028], [77.13424683, 8.99997997], [77.13725281, 8.99822044], [77.14319611, 8.99788094], [77.14392853, 8.99184132], [77.1440506, 8.99184132], [77.14689636, 8.98694992], [77.15844727, 8.97819138], [77.1632309, 8.96234035], [77.17473602, 8.95685196], [77.17529297, 8.95083046], [77.18016815, 8.94701958], [77.18123627, 8.94197083], [77.17967224, 8.93749046], [77.18164825, 8.93256092], [77.18187714, 8.92883015], [77.17919159, 8.92098045], [77.18061829, 8.91845131], [77.18044281, 8.91574955], [77.18476868, 8.9101696], [77.18966675, 8.91257], [77.18675232, 8.91567039], [77.18976593, 8.91957188], [77.19386292, 8.92191029], [77.1980896, 8.91930962], [77.20474243, 8.91741085], [77.20736694, 8.91389179], [77.20204163, 8.90668106], [77.20625305, 8.8931818], [77.2116394, 8.89305019], [77.21473694, 8.89212036], [77.22145081, 8.88813972], [77.22389984, 8.88514996], [77.22318268, 8.87781143], [77.22712708, 8.87181854], [77.23203278, 8.86905003], [77.23986816, 8.86806107], [77.24150085, 8.86478233], [77.24298859, 8.85927105], [77.24318695, 8.85509109], [77.24040985, 8.85147095], [77.24562073, 8.84508133], [77.24595642, 8.84307957], [77.2428894, 8.84123993], [77.24704742, 8.83187962], [77.23616791, 8.81762791], [77.23195648, 8.81346035], [77.23085785, 8.81157112], [77.23159027, 8.80709171], [77.22735596, 8.80056], [77.22396851, 8.79833126], [77.21736145, 8.79703045], [77.21536255, 8.78666019], [77.2146759, 8.77576065], [77.20960999, 8.77371025], [77.20529175, 8.77039146], [77.19837952, 8.76949978], [77.19933319, 8.76559067], [77.20224762, 8.76088047], [77.19780731, 8.75774193], [77.19143677, 8.75839138], [77.18300629, 8.76111031], [77.18076324, 8.75756168], [77.18344116, 8.75336075], [77.18370819, 8.74814034], [77.18107605, 8.74081039], [77.1765213, 8.73502064], [77.17093658, 8.73338032], [77.16274261, 8.73518085], [77.15724182, 8.74075985], [77.15531921, 8.73756027], [77.15737915, 8.73118114], [77.16294098, 8.720891], [77.16172791, 8.71516132], [77.16703033, 8.70763111], [77.17234802, 8.70324993], [77.17929077, 8.69961929], [77.18296814, 8.69003105], [77.18772125, 8.68376064], [77.18975067, 8.67737961], [77.19046783, 8.67118931], [77.18710327, 8.66229153], [77.19033813, 8.65489101], [77.19523621, 8.64868069], [77.1984787, 8.64109993], [77.20523071, 8.63528156], [77.20825195, 8.63115025], [77.21237946, 8.62877941], [77.21869659, 8.61837959], [77.22827911, 8.61290073], [77.22786713, 8.60309124], [77.22840881, 8.59781265], [77.2321167, 8.59211922], [77.23761749, 8.58842945], [77.24285889, 8.58055019], [77.25152588, 8.57098961], [77.25969696, 8.54906178], [77.26508331, 8.54255962], [77.26515961, 8.53744984], [77.25817108, 8.52812958], [77.25248718, 8.51708126], [77.24754333, 8.50137997], [77.24125671, 8.49812984], [77.23240662, 8.49591923], [77.22754669, 8.49059963], [77.22255707, 8.4883213], [77.21726227, 8.49613953], [77.20639038, 8.50443172], [77.19857788, 8.50393963], [77.1920166, 8.49938107], [77.18649292, 8.49337101], [77.19091797, 8.48819065], [77.19462585, 8.4693718], [77.19877625, 8.46023941], [77.20513153, 8.45551014], [77.2090683, 8.45068073], [77.21022797, 8.44305038], [77.20951843, 8.43771935], [77.19877625, 8.43677998], [77.18868256, 8.43474102], [77.18267059, 8.4274807], [77.18039703, 8.41860199], [77.17977905, 8.409091], [77.17222595, 8.40170002], [77.16709137, 8.39546013], [77.16448212, 8.38784027], [77.15368652, 8.37744141], [77.14939117, 8.37543964], [77.14579773, 8.38169956], [77.14074707, 8.38280964], [77.13481903, 8.37852955], [77.13584137, 8.37251091], [77.14121246, 8.36899185], [77.14322662, 8.36227131], [77.13537598, 8.35174084], [77.13577271, 8.34566975], [77.1415329, 8.3491497], [77.14749908, 8.35458088], [77.15203857, 8.35473061], [77.15460968, 8.35139942], [77.15680695, 8.34519958], [77.15093231, 8.3354702], [77.15106201, 8.33094025], [77.15318298, 8.32566071], [77.15966797, 8.31738091], [77.15965271, 8.31250095], [77.15483093, 8.31361103], [77.15210724, 8.31946182], [77.14977264, 8.32194233], [77.14470673, 8.32022953], [77.13703156, 8.32009125], [77.13062286, 8.32423019], [77.12194824, 8.32294178], [77.11152649, 8.31649017], [77.10883331, 8.31287956], [77.10085297, 8.31165123], [77.1046524, 8.30160046], [77.09822083, 8.30150032], [77.09648895, 8.29806995], [77.09069824, 8.29747009], [77.09069824, 8.29763889], [77.09041595, 8.29763889], [77.09041595, 8.29791927], [77.08985901, 8.29791737], [77.08985901, 8.29819489], [77.08930206, 8.29819489], [77.08930206, 8.29847336], [77.08847046, 8.29847145], [77.08847046, 8.29875088], [77.0881958, 8.29875088], [77.0881958, 8.29930973], [77.08763885, 8.29930496], [77.08763885, 8.29958344], [77.08708191, 8.29958344], [77.08708191, 8.29986095], [77.08680725, 8.29986095], [77.08680725, 8.30013943], [77.08651733, 8.30013943], [77.08651733, 8.30041981], [77.08569336, 8.30041695], [77.08569336, 8.30069542], [77.0854187, 8.30069542], [77.0854187, 8.30125237], [77.08513641, 8.30125237], [77.08513641, 8.30153179], [77.0854187, 8.30152702], [77.0854187, 8.30236053], [77.08513641, 8.30236053], [77.08513641, 8.30319309], [77.08569336, 8.30319309], [77.08569336, 8.30291843], [77.08652496, 8.30291843], [77.08652496, 8.30319309], [77.08625031, 8.30319309], [77.08625031, 8.30347061], [77.08598328, 8.30347061], [77.08598328, 8.30403042], [77.08569336, 8.30403042], [77.08569336, 8.30430984], [77.08513641, 8.30430603], [77.08513641, 8.30458355], [77.0845871, 8.30458355], [77.0845871, 8.30486202], [77.08403015, 8.30486202], [77.08403015, 8.30513954], [77.08348083, 8.30513954], [77.08348083, 8.30541992], [77.08319092, 8.30541801], [77.08319092, 8.30569363], [77.0826416, 8.30569363], [77.0826416, 8.3059721], [77.08235931, 8.30596924], [77.08235931, 8.30624962], [77.08180237, 8.30624962], [77.08180237, 8.30681038], [77.08152771, 8.30680561], [77.08152771, 8.3073597], [77.08125305, 8.3073597], [77.08125305, 8.30764008], [77.08071136, 8.30764008], [77.08071136, 8.30792046], [77.08041382, 8.30791569], [77.08041382, 8.30819416], [77.08013916, 8.30819416], [77.08013916, 8.30847168], [77.07958221, 8.30847168], [77.07958221, 8.30875015], [77.07930756, 8.30875015], [77.07930756, 8.30902958], [77.07847595, 8.30902958], [77.07847595, 8.30846024], [77.07791901, 8.30847168], [77.07791901, 8.30875015], [77.07707977, 8.30875015], [77.07707977, 8.30847168], [77.07680511, 8.30847168], [77.07680511, 8.30875015], [77.07653046, 8.30875015], [77.07653046, 8.30902958], [77.07624817, 8.30902958], [77.07624817, 8.30931091], [77.07597351, 8.30930614], [77.07597351, 8.30958366], [77.07569122, 8.30958366], [77.07569122, 8.30986214], [77.07541656, 8.30986023], [77.07541656, 8.31013966], [77.07514191, 8.31013966], [77.07514191, 8.31042004], [77.07458496, 8.31041622], [77.07458496, 8.31069374], [77.07402802, 8.31069374], [77.07402802, 8.31097221], [77.07375336, 8.31097031], [77.07375336, 8.31124973], [77.07319641, 8.31124973], [77.07319641, 8.31152821], [77.07290649, 8.31152058], [77.07290649, 8.31181145], [77.07236481, 8.31180573], [77.07236481, 8.3120842], [77.07208252, 8.31208038], [77.07208252, 8.31236172], [77.07154083, 8.31236172], [77.07154083, 8.31264019], [77.07125092, 8.31264019], [77.07125092, 8.31292057], [77.07069397, 8.3129158], [77.07069397, 8.31319427], [77.07041931, 8.31319427], [77.07041931, 8.31347179], [77.06986237, 8.31347179], [77.06986237, 8.31375027], [77.06958008, 8.31375027], [77.06958008, 8.31403065], [77.06903076, 8.31403065], [77.06903076, 8.31431103], [77.06874847, 8.31431103], [77.06874847, 8.31459141], [77.06819153, 8.31458378], [77.06819153, 8.31486034], [77.06791687, 8.31486034], [77.06791687, 8.31514072], [77.06764221, 8.31514072], [77.06764221, 8.3154211], [77.06735992, 8.31541634], [77.06735992, 8.31569386], [77.06708527, 8.31569386], [77.06708527, 8.31597233], [77.06680298, 8.31597042], [77.06680298, 8.31653118], [77.06652832, 8.31653118], [77.06652832, 8.31681061], [77.06625366, 8.31680679], [77.06625366, 8.31708241], [77.06597137, 8.31708241], [77.06597137, 8.31735992], [77.06542206, 8.31735992], [77.06542206, 8.31764984], [77.06513977, 8.31764984], [77.06513977, 8.31792068], [77.06485748, 8.31791687], [77.06485748, 8.31819534], [77.06458282, 8.31819534], [77.06458282, 8.31847286], [77.06402588, 8.31847286], [77.06402588, 8.31875134], [77.06318665, 8.31875134], [77.06318665, 8.31902885], [77.06181335, 8.31902885], [77.06181335, 8.31930923], [77.06153107, 8.31930542], [77.06153107, 8.31986141], [77.06124878, 8.31986141], [77.06124878, 8.32042122], [77.06069183, 8.3204174], [77.06069183, 8.3209734], [77.06041718, 8.32097054], [77.06041718, 8.32125092], [77.05960083, 8.32125092], [77.05960083, 8.3215313], [77.05902863, 8.3215313], [77.05902863, 8.32181168], [77.05874634, 8.32180691], [77.05874634, 8.32208347], [77.05847168, 8.32208347], [77.05847168, 8.32236099], [77.0579071, 8.32236099], [77.0579071, 8.32291889], [77.05735779, 8.32291698], [77.05735779, 8.32347298], [77.05708313, 8.32346153], [77.05708313, 8.32374859], [77.05680847, 8.32375145], [77.05680847, 8.32403088], [77.05654144, 8.32403088], [77.05654144, 8.3243103], [77.05625153, 8.32430458], [77.05625153, 8.32458305], [77.05569458, 8.32458305], [77.05569458, 8.32486057], [77.05541992, 8.32486057], [77.05541992, 8.32514095], [77.05513763, 8.32513905], [77.05513763, 8.32569313], [77.05458069, 8.32569313], [77.05458069, 8.32597256], [77.05403137, 8.32597065], [77.05403137, 8.32652855], [77.05348206, 8.32652855], [77.05348206, 8.32682133], [77.05291748, 8.32680511], [77.05291748, 8.32708263], [77.05263519, 8.32708263], [77.05263519, 8.32736111], [77.05208588, 8.3273592], [77.05208588, 8.32764244], [77.05152893, 8.32763863], [77.05152893, 8.32819462], [77.05124664, 8.32819462], [77.05124664, 8.32847118], [77.05097198, 8.32847118], [77.05097198, 8.32903194], [77.05040741, 8.32903194], [77.05040741, 8.32931042], [77.05014038, 8.32931042], [77.05014038, 8.32958984], [77.04957581, 8.32958984], [77.04957581, 8.33014202], [77.04930878, 8.33014202], [77.04930878, 8.33041954], [77.04902649, 8.33041763], [77.04902649, 8.33069324], [77.04875183, 8.33069324], [77.04875183, 8.33097363], [77.04846954, 8.33097363], [77.04846954, 8.33125019], [77.04818726, 8.33125019], [77.04818726, 8.33181], [77.04792023, 8.33180618], [77.04792023, 8.3320837], [77.04763794, 8.3320837], [77.04763794, 8.33263969], [77.04736328, 8.33263969], [77.04736328, 8.33319378], [77.04708099, 8.33319092], [77.04708099, 8.33374977], [77.0459671, 8.33374977], [77.0459671, 8.33403015], [77.04541779, 8.33403015], [77.04541779, 8.33430958], [77.0451355, 8.33430576], [77.0451355, 8.33458424], [77.04486084, 8.33458424], [77.04486084, 8.33485985], [77.04431152, 8.33485985], [77.04431152, 8.33514023], [77.04402924, 8.33514023], [77.04402924, 8.33541965], [77.04374695, 8.33541584], [77.04374695, 8.33569431], [77.04347229, 8.33569431], [77.04347229, 8.33597183], [77.04291534, 8.33597183], [77.04291534, 8.33625031], [77.0423584, 8.33625031], [77.0423584, 8.33652973], [77.04207611, 8.33652973], [77.04207611, 8.33681107], [77.04152679, 8.3368063], [77.04152679, 8.33736229], [77.04125214, 8.33736038], [77.04125214, 8.33764172], [77.04070282, 8.33764172], [77.04070282, 8.33792114], [77.0395813, 8.33791637], [77.0395813, 8.33819389], [77.03930664, 8.33819199], [77.03930664, 8.33875942], [77.03901672, 8.33875942], [77.03901672, 8.33903027], [77.03874969, 8.33903027], [77.03874969, 8.33931065], [77.03847504, 8.33930588], [77.03847504, 8.33958435], [77.03817749, 8.33957958], [77.03819275, 8.33985996], [77.03791809, 8.33985996], [77.03791809, 8.34042072], [77.0376358, 8.34041595], [77.0376358, 8.34069443], [77.03708649, 8.34069443], [77.03708649, 8.34097195], [77.03679657, 8.34097004], [77.0368042, 8.34125042], [77.03624725, 8.34125042], [77.03624725, 8.3415308], [77.0359726, 8.3415308], [77.0359726, 8.34181976], [77.03569794, 8.34180641], [77.03569794, 8.34208202], [77.03514099, 8.34208202], [77.03514099, 8.34236336], [77.0348587, 8.34235954], [77.0348587, 8.34264088], [77.03457642, 8.34264088], [77.03457642, 8.34292126], [77.0340271, 8.34291553], [77.0340271, 8.34319401], [77.03375244, 8.34319019], [77.03375244, 8.34375095], [77.03347015, 8.34375095], [77.03347015, 8.34403133], [77.03291321, 8.34403133], [77.03291321, 8.34430885], [77.03263855, 8.34430695], [77.03263855, 8.3445816], [77.0320816, 8.3445816], [77.0320816, 8.34486103], [77.03180695, 8.34486103], [77.03180695, 8.34514141], [77.03151703, 8.34514141], [77.03151703, 8.34542084], [77.03125, 8.34541702], [77.03125, 8.34569454], [77.03097534, 8.34569454], [77.03097534, 8.34597301], [77.03069305, 8.34597015], [77.03069305, 8.34625053], [77.0304184, 8.34625053], [77.0304184, 8.34653091], [77.02986145, 8.34653091], [77.02986145, 8.34681129], [77.02958679, 8.34680462], [77.02958679, 8.34708309], [77.0293045, 8.34708309], [77.0293045, 8.34763908], [77.02902985, 8.34762955], [77.02902985, 8.34792137], [77.02874756, 8.3479166], [77.02874756, 8.34819508], [77.02819824, 8.34819508], [77.02819824, 8.3484726], [77.02791595, 8.34847069], [77.02791595, 8.34875107], [77.0276413, 8.34875107], [77.0276413, 8.34903145], [77.02680206, 8.34903145], [77.02680206, 8.34931183], [77.02625275, 8.34930515], [77.02625275, 8.34958267], [77.02597046, 8.34958267], [77.02597046, 8.34986115], [77.0256958, 8.34986115], [77.0256958, 8.35014057], [77.02513885, 8.35014057], [77.02513885, 8.35042191], [77.02458191, 8.35042191], [77.02458191, 8.35070038], [77.02430725, 8.35069466], [77.02430725, 8.35097313], [77.02375031, 8.35097122], [77.02375031, 8.35125065], [77.02346802, 8.35125065], [77.02346802, 8.35153198], [77.0229187, 8.35153198], [77.0229187, 8.35181046], [77.02263641, 8.35180473], [77.02263641, 8.35208321], [77.0220871, 8.35208321], [77.0220871, 8.35236073], [77.02179718, 8.35236073], [77.02179718, 8.3526392], [77.02124786, 8.3526392], [77.02124786, 8.35291958], [77.02097321, 8.35291672], [77.02097321, 8.35319519], [77.02041626, 8.35319519], [77.02041626, 8.3534708], [77.0201416, 8.35346889], [77.0201416, 8.35376072], [77.01930237, 8.35376072], [77.01930237, 8.3540287], [77.01902771, 8.3540287], [77.01902771, 8.35431194], [77.01875305, 8.35430527], [77.01875305, 8.35486126], [77.01847076, 8.35486126], [77.01847076, 8.35514164], [77.01819611, 8.35514164], [77.01819611, 8.35542202], [77.01791382, 8.35541534], [77.01791382, 8.35597134], [77.01708221, 8.35597134], [77.01708221, 8.35624886], [77.01625061, 8.35624886], [77.01625061, 8.35653019], [77.01513672, 8.35653019], [77.01513672, 8.35624886], [77.01430511, 8.35624886], [77.01430511, 8.35569572], [77.01319122, 8.35569572], [77.01319122, 8.35597134], [77.01235962, 8.35597134], [77.01235962, 8.35624886], [77.00985718, 8.35624886], [77.00985718, 8.35653019], [77.00958252, 8.35652733], [77.00958252, 8.35680485], [77.00930786, 8.35680485], [77.00930786, 8.35708427], [77.00875092, 8.35708427], [77.00875092, 8.35736179], [77.00846863, 8.35736179], [77.00846863, 8.35931015], [77.0082016, 8.35931015], [77.0082016, 8.36013985], [77.00791931, 8.36013985], [77.00791931, 8.3615303], [77.00763702, 8.3615284], [77.00763702, 8.36208439], [77.00736237, 8.36208153], [77.00736237, 8.36264038], [77.00708008, 8.36263847], [77.00708008, 8.36319447], [77.00680542, 8.36319447], [77.00680542, 8.36347198], [77.00624847, 8.36347198], [77.00624847, 8.36375046], [77.00596619, 8.36375046], [77.00596619, 8.36403275], [77.00543213, 8.36403275], [77.00543213, 8.36431122], [77.00514221, 8.36430645], [77.00514221, 8.36458206], [77.00458527, 8.36458206], [77.00458527, 8.36486244], [77.00430298, 8.36485958], [77.00430298, 8.36513996], [77.00347137, 8.36513996], [77.00347137, 8.36570072], [77.00319672, 8.36569405], [77.00319672, 8.36874962], [77.0029068, 8.36874104], [77.0029068, 8.36931133], [77.00263977, 8.36930656], [77.00263977, 8.3698597], [77.00235748, 8.3698597], [77.00235748, 8.37042141], [77.00208282, 8.37041569], [77.00208282, 8.37097263], [77.00180817, 8.37097263], [77.00180817, 8.37125111], [77.00125122, 8.37125111], [77.00125122, 8.37153053], [77.00013733, 8.37153053], [76.99986267, 8.37152863], [76.99986267, 8.37180424], [76.99930573, 8.37180424], [76.99930573, 8.37236118], [76.99903107, 8.37236118], [76.99903107, 8.37292099], [76.99874878, 8.37291718], [76.99874878, 8.37347317], [76.99846649, 8.37347126], [76.99846649, 8.37375069], [76.99819183, 8.37375069], [76.99819183, 8.37403107], [76.99764252, 8.37403107], [76.99764252, 8.3743124], [76.99736023, 8.37430477], [76.99736023, 8.37458324], [76.99708557, 8.37458324], [76.99708557, 8.37486076], [76.99652863, 8.37485886], [76.99652863, 8.37514114], [76.9962616, 8.37514114], [76.9962616, 8.37542057], [76.99569702, 8.37541676], [76.99569702, 8.37597084], [76.9954071, 8.37597084], [76.99541473, 8.37625122], [76.99375153, 8.37625122], [76.99375153, 8.37653065], [76.99320221, 8.37653065], [76.99320221, 8.37625122], [76.99263763, 8.37625122], [76.99263763, 8.37569523], [76.99208069, 8.37569523], [76.99208069, 8.37513924], [76.99153137, 8.37513924], [76.99153137, 8.37569523], [76.99097443, 8.37569523], [76.99097443, 8.37597084], [76.99069214, 8.37597084], [76.99069214, 8.37681198], [76.99041748, 8.37680531], [76.99041748, 8.37708282], [76.99013519, 8.37708282], [76.99013519, 8.3773613], [76.98874664, 8.3773613], [76.98874664, 8.37708282], [76.98847198, 8.37708282], [76.98847198, 8.37597084], [76.98874664, 8.37597084], [76.98874664, 8.37541676], [76.98902893, 8.37542057], [76.98902893, 8.37485886], [76.98930359, 8.37486076], [76.98930359, 8.37458324], [76.98958588, 8.37458324], [76.98958588, 8.37430477], [76.98986053, 8.3743124], [76.98986053, 8.37403107], [76.99012756, 8.37403107], [76.99012756, 8.37292099], [76.98958588, 8.37291718], [76.98958588, 8.37319469], [76.98929596, 8.37318993], [76.98929596, 8.37375069], [76.98902893, 8.37375069], [76.98902893, 8.37403107], [76.98874664, 8.37403107], [76.98874664, 8.3743124], [76.98819733, 8.37430477], [76.98819733, 8.37458324], [76.98791504, 8.37458324], [76.98791504, 8.37486076], [76.98764038, 8.37485886], [76.98764038, 8.37514114], [76.98680878, 8.37514114], [76.98680878, 8.37542057], [76.98625183, 8.37541676], [76.98625183, 8.37569523], [76.98596954, 8.37569523], [76.98596954, 8.37597084], [76.98542023, 8.37597084], [76.98542023, 8.37625122], [76.98486328, 8.37625122], [76.98486328, 8.37708282], [76.98458099, 8.37708092], [76.98458099, 8.37793064], [76.98430634, 8.37791729], [76.98432159, 8.37874889], [76.98400879, 8.37874889], [76.98400879, 8.37930965], [76.98347473, 8.37930489], [76.98347473, 8.37958336], [76.98291779, 8.37958336], [76.98291779, 8.37986088], [76.98264313, 8.37986088], [76.98264313, 8.38013935], [76.98236084, 8.38013935], [76.98236084, 8.37986088], [76.98208618, 8.37986088], [76.98208618, 8.38041973], [76.98152924, 8.38041687], [76.98152924, 8.38069534], [76.98124695, 8.38069534], [76.98124695, 8.38097095], [76.98041534, 8.38097095], [76.98041534, 8.38125134], [76.98014069, 8.38125134], [76.98014069, 8.38152981], [76.97875214, 8.38152695], [76.97875214, 8.38236141], [76.97846985, 8.38236141], [76.97846985, 8.38403034], [76.97818756, 8.38403034], [76.97819519, 8.38486195], [76.97763824, 8.38486195], [76.97763824, 8.38513088], [76.97680664, 8.38514042], [76.97680664, 8.38486195], [76.97569275, 8.38486195], [76.97569275, 8.38458443], [76.97541809, 8.38458061], [76.97541809, 8.38514042], [76.97486115, 8.38514042], [76.97486115, 8.38624954], [76.9751358, 8.38624954], [76.9751358, 8.38708401], [76.97541809, 8.38707924], [76.97541809, 8.38764], [76.97569275, 8.38764], [76.97569275, 8.38792038], [76.97541809, 8.38792038], [76.97541809, 8.38875198], [76.97512817, 8.38875198], [76.97512817, 8.38903046], [76.97429657, 8.38903046], [76.97429657, 8.38931274], [76.97402954, 8.38930607], [76.97402954, 8.38958359], [76.97264099, 8.38958168], [76.97264099, 8.38987064], [76.97206879, 8.38987064], [76.97206879, 8.39041996], [76.97180939, 8.39041996], [76.97180176, 8.39124966], [76.9715271, 8.39124966], [76.9715271, 8.39208412], [76.97097015, 8.39208031], [76.97097015, 8.39264011], [76.97041321, 8.39263821], [76.97041321, 8.3931942], [76.97013855, 8.3931942], [76.97013855, 8.39347172], [76.96985626, 8.39347172], [76.96985626, 8.39403057], [76.9695816, 8.39403057], [76.9695816, 8.39431095], [76.96986389, 8.39430618], [76.96986389, 8.3945837], [76.97041321, 8.3945837], [76.97041321, 8.39486027], [76.97070313, 8.39486027], [76.97070313, 8.39514065], [76.9715271, 8.39513779], [76.9715271, 8.39569378], [76.97180176, 8.39569378], [76.97180939, 8.39597225], [76.97292328, 8.39597034], [76.97292328, 8.39624977], [76.97319794, 8.39624977], [76.97319794, 8.39708233], [76.97292328, 8.39708042], [76.97292328, 8.39764118], [76.97264099, 8.39764118], [76.97264099, 8.39792061], [76.9723587, 8.39791679], [76.9723587, 8.39819527], [76.97206879, 8.39818954], [76.97206879, 8.39903069], [76.97180939, 8.39903069], [76.97180939, 8.39931107], [76.97208405, 8.39930534], [76.97208405, 8.39958286], [76.9715271, 8.39958], [76.9715271, 8.40042114], [76.97125244, 8.40042114], [76.97125244, 8.4018116], [76.97097015, 8.4018116], [76.97097015, 8.4026413], [76.9706955, 8.40263939], [76.9706955, 8.4034729], [76.97041321, 8.4034729], [76.97041321, 8.40375137], [76.97013855, 8.40375137], [76.97013855, 8.40430927], [76.96985626, 8.40430927], [76.96985626, 8.40487003], [76.9695816, 8.40486145], [76.9695816, 8.40597343], [76.9693222, 8.40597057], [76.9693222, 8.40652943], [76.96903229, 8.40652943], [76.96903229, 8.40681171], [76.96875, 8.40681171], [76.96875, 8.40764236], [76.96847534, 8.40763855], [76.96847534, 8.40819454], [76.96819305, 8.40819454], [76.96819305, 8.40847111], [76.9679184, 8.40847111], [76.9679184, 8.40931034], [76.96763611, 8.40930462], [76.96763611, 8.40958309], [76.96736145, 8.40958309], [76.96736145, 8.40986061], [76.96708679, 8.40986061], [76.96708679, 8.41014194], [76.9668045, 8.41014004], [76.9668045, 8.41069317], [76.96624756, 8.41069126], [76.96624756, 8.41125202], [76.96569824, 8.41125202], [76.96569824, 8.41180992], [76.96541595, 8.41180611], [76.96541595, 8.4123621], [76.9651413, 8.4123621], [76.9651413, 8.4131937], [76.96485901, 8.41319084], [76.96485901, 8.41431046], [76.96430206, 8.41430569], [76.96430206, 8.41485977], [76.96375275, 8.41485977], [76.96375275, 8.41569424], [76.96347046, 8.41569138], [76.96347046, 8.41652966], [76.9631958, 8.41652775], [76.9631958, 8.41736221], [76.96263885, 8.41736031], [76.96263885, 8.41763973], [76.9623642, 8.41763783], [76.9623642, 8.41847229], [76.96180725, 8.41847038], [76.96180725, 8.41903019], [76.96152496, 8.41902828], [76.96152496, 8.41958427], [76.96097565, 8.41958427], [76.96097565, 8.41985989], [76.96069336, 8.4198513], [76.96069336, 8.42042065], [76.9604187, 8.42041588], [76.9604187, 8.42069435], [76.96012878, 8.42068958], [76.96013641, 8.42125034], [76.95986176, 8.42125034], [76.95986176, 8.4218111], [76.95930481, 8.42180634], [76.95930481, 8.42208195], [76.95903015, 8.42208004], [76.95903015, 8.4226408], [76.95874786, 8.42263794], [76.95874786, 8.42291641], [76.95847321, 8.42291641], [76.95847321, 8.42319393], [76.95791626, 8.42319393], [76.95791626, 8.4234724], [76.95735931, 8.42346954], [76.95735931, 8.42375088], [76.95709229, 8.42375088], [76.95709229, 8.42403126], [76.95680237, 8.42403126], [76.95680237, 8.42431068], [76.95652771, 8.42430687], [76.95652771, 8.42458153], [76.95625305, 8.42457962], [76.95625305, 8.42514133], [76.95597076, 8.42514133], [76.95597076, 8.42541885], [76.95569611, 8.42541885], [76.95569611, 8.42597961], [76.95540619, 8.42597961], [76.95541382, 8.42625141], [76.95513916, 8.42625141], [76.95513916, 8.42653084], [76.9548645, 8.42652893], [76.9548645, 8.42708302], [76.95458221, 8.42708302], [76.95458221, 8.42736053], [76.95430756, 8.42736053], [76.95430756, 8.4279213], [76.95402527, 8.42791653], [76.95402527, 8.428195], [76.95375061, 8.42819023], [76.95375061, 8.42875099], [76.95347595, 8.42875099], [76.95347595, 8.42903996], [76.95318604, 8.42903996], [76.95318604, 8.42930889], [76.95291901, 8.42930698], [76.95291901, 8.4295826], [76.95263672, 8.42958069], [76.95263672, 8.43014145], [76.95236206, 8.43014145], [76.95236206, 8.43042183], [76.95207977, 8.43042183], [76.95207977, 8.43181038], [76.95153046, 8.43180466], [76.95153046, 8.43208313], [76.95124817, 8.43208122], [76.95124817, 8.43264103], [76.95095825, 8.43264103], [76.95095825, 8.43291855], [76.95041656, 8.43291664], [76.95041656, 8.43347263], [76.94957733, 8.43347073], [76.94958496, 8.4337492], [76.94930267, 8.4337492], [76.94930267, 8.43431187], [76.94902802, 8.43430519], [76.94902802, 8.43458271], [76.94875336, 8.43458271], [76.94875336, 8.43486118], [76.94847107, 8.43484974], [76.94847107, 8.43514156], [76.94819641, 8.4351387], [76.94819641, 8.43569469], [76.94791412, 8.43569469], [76.94791412, 8.43597126], [76.94763947, 8.43597126], [76.94763947, 8.43625164], [76.94708252, 8.43625164], [76.94708252, 8.43680954], [76.94680786, 8.43680477], [76.94680786, 8.43736172], [76.94625092, 8.43735886], [76.94625092, 8.43764019], [76.94596863, 8.43764019], [76.94596863, 8.43791962], [76.94568634, 8.43791962], [76.94568634, 8.43902969], [76.94541931, 8.43902779], [76.94541931, 8.43958378], [76.94513702, 8.43958378], [76.94513702, 8.43986225], [76.94458008, 8.43985939], [76.94458008, 8.44013977], [76.94431305, 8.44013977], [76.94431305, 8.44042015], [76.94403076, 8.44041634], [76.94403076, 8.44124985], [76.94374847, 8.44124985], [76.94374847, 8.44153023], [76.94347382, 8.44152832], [76.94347382, 8.44208431], [76.94319153, 8.44208431], [76.94319153, 8.44236183], [76.94291687, 8.44236183], [76.94291687, 8.4426403], [76.94264221, 8.4426403], [76.94264221, 8.44291973], [76.94235992, 8.44291592], [76.94235992, 8.44319439], [76.94208527, 8.44319439], [76.94208527, 8.44347191], [76.94180298, 8.44347191], [76.94180298, 8.44375038], [76.94152832, 8.44375038], [76.94152832, 8.44431114], [76.94097137, 8.44430637], [76.94097137, 8.44458199], [76.94069672, 8.44458199], [76.94069672, 8.44486237], [76.9404068, 8.44486046], [76.9404068, 8.44514179], [76.94013977, 8.44513798], [76.94013977, 8.4456892], [76.93985748, 8.44570065], [76.93985748, 8.44624996], [76.93930817, 8.44624996], [76.93930817, 8.44653034], [76.93902588, 8.44652843], [76.93902588, 8.44708443], [76.93875122, 8.44708443], [76.93875122, 8.44736004], [76.93846893, 8.44736004], [76.93846893, 8.44764042], [76.93819427, 8.44763756], [76.93819427, 8.44847202], [76.93791962, 8.44847012], [76.93791962, 8.44903088], [76.93763733, 8.44903088], [76.93763733, 8.44931126], [76.93736267, 8.44930553], [76.93736267, 8.4495821], [76.93708038, 8.4495821], [76.93708038, 8.44986343], [76.93681335, 8.44985962], [76.93681335, 8.45014954], [76.93653107, 8.45014954], [76.93653107, 8.45042133], [76.93624878, 8.45041561], [76.93624878, 8.45069408], [76.93595886, 8.45069027], [76.93595886, 8.45125103], [76.93569183, 8.45125103], [76.93569183, 8.45153141], [76.93514252, 8.45153141], [76.93514252, 8.45181084], [76.93486023, 8.45180416], [76.93486023, 8.45208168], [76.9345932, 8.45207977], [76.9345932, 8.45264053], [76.93430328, 8.45264053], [76.93430328, 8.45292091], [76.93402863, 8.4529171], [76.93402863, 8.45319462], [76.93374634, 8.45318985], [76.93374634, 8.45375061], [76.93321228, 8.45375061], [76.93321228, 8.45403099], [76.93291473, 8.45402908], [76.93291473, 8.45458317], [76.93264008, 8.45458317], [76.93264008, 8.45486069], [76.93235779, 8.45486069], [76.93235779, 8.45514107], [76.93180847, 8.45514107], [76.93180847, 8.45542145], [76.93152618, 8.45541668], [76.93152618, 8.45597267], [76.93125153, 8.45597267], [76.93125153, 8.45625114], [76.93096924, 8.45625114], [76.93096924, 8.4568119], [76.93041992, 8.45680523], [76.93041992, 8.45736122], [76.93015289, 8.45736122], [76.93015289, 8.45792198], [76.92986298, 8.45791721], [76.92986298, 8.45819473], [76.92930603, 8.45819092], [76.92930603, 8.45875072], [76.92874908, 8.45875072], [76.92874908, 8.45930958], [76.92847443, 8.45930481], [76.92847443, 8.45958328], [76.92819214, 8.45958328], [76.92819214, 8.4598608], [76.92791748, 8.45985889], [76.92791748, 8.46041965], [76.92763519, 8.46041679], [76.92763519, 8.46069527], [76.92736053, 8.46069527], [76.92736053, 8.46125126], [76.92707825, 8.46125126], [76.92707825, 8.46153164], [76.92652893, 8.46153164], [76.92652893, 8.46181202], [76.92624664, 8.46180534], [76.92624664, 8.46236134], [76.92569733, 8.46236134], [76.92569733, 8.46263885], [76.92541504, 8.46263885], [76.92541504, 8.4631958], [76.92514038, 8.46319103], [76.92514038, 8.46430969], [76.92458344, 8.46430492], [76.92458344, 8.46458435], [76.92318726, 8.46458054], [76.92318726, 8.46515083], [76.92292023, 8.46514034], [76.92292023, 8.46569347], [76.92263794, 8.46569347], [76.92263794, 8.46597195], [76.92236328, 8.46597195], [76.92236328, 8.46652985], [76.92208099, 8.46652985], [76.92208099, 8.46681023], [76.92180634, 8.46680641], [76.92180634, 8.4673624], [76.92151642, 8.46735954], [76.92151642, 8.46763992], [76.92124939, 8.46763992], [76.92124939, 8.4679203], [76.92069244, 8.46791553], [76.92069244, 8.46819401], [76.92041779, 8.46818924], [76.92041779, 8.46875191], [76.92014313, 8.46875191], [76.92014313, 8.46931267], [76.91986084, 8.46930599], [76.91986084, 8.46958447], [76.91929626, 8.4695816], [76.91929626, 8.47014046], [76.91902924, 8.47014046], [76.91902924, 8.47042274], [76.91874695, 8.47041798], [76.91874695, 8.47069359], [76.91847229, 8.47069168], [76.91847229, 8.47124958], [76.91821289, 8.47124958], [76.91821289, 8.47152996], [76.91792297, 8.47152996], [76.91792297, 8.47181129], [76.9173584, 8.47180557], [76.9173584, 8.47208405], [76.91708374, 8.47208405], [76.91708374, 8.47236156], [76.91680908, 8.47235966], [76.91680908, 8.47264004], [76.91652679, 8.47263813], [76.91652679, 8.47319412], [76.91625214, 8.47319412], [76.91625214, 8.47347164], [76.91570282, 8.47346973], [76.91570282, 8.47403145], [76.9154129, 8.47402763], [76.9154129, 8.47458363], [76.91513824, 8.47458172], [76.91513824, 8.47513962], [76.91486359, 8.47513771], [76.91486359, 8.4756937], [76.91430664, 8.4756937], [76.91430664, 8.47597218], [76.91401672, 8.47597027], [76.91401672, 8.47624969], [76.91348267, 8.47624969], [76.91348267, 8.47653103], [76.91319275, 8.47653103], [76.91319275, 8.47681141], [76.91291809, 8.47681141], [76.91291809, 8.47709084], [76.9126358, 8.47709084], [76.9126358, 8.47764111], [76.91236115, 8.47764111], [76.91236115, 8.47792053], [76.91207886, 8.47792053], [76.91207886, 8.47875118], [76.91178894, 8.47875118], [76.91178894, 8.47931099], [76.91152954, 8.47930431], [76.91152954, 8.47958469], [76.91124725, 8.47958469], [76.91124725, 8.48013878], [76.91069794, 8.48012924], [76.91069794, 8.48042107], [76.91041565, 8.48041725], [76.91041565, 8.48069477], [76.91014099, 8.48069477], [76.91014099, 8.48097324], [76.90957642, 8.48097038], [76.90957642, 8.48153114], [76.90930939, 8.48153114], [76.90930176, 8.48181152], [76.90875244, 8.48180485], [76.90875244, 8.48208332], [76.90847015, 8.48208046], [76.90847015, 8.48264122], [76.90820313, 8.48264122], [76.90820313, 8.48292065], [76.90791321, 8.48291683], [76.90791321, 8.4831953], [76.90763855, 8.4831953], [76.90763855, 8.48347282], [76.90735626, 8.48347092], [76.90736389, 8.4837513], [76.9070816, 8.4837513], [76.9070816, 8.48403072], [76.90680695, 8.48403072], [76.90680695, 8.4843092], [76.90652466, 8.48430538], [76.90652466, 8.48486137], [76.90625, 8.48486137], [76.90625, 8.48513889], [76.90598297, 8.48513889], [76.90598297, 8.48541927], [76.9054184, 8.48541737], [76.9054184, 8.48597336], [76.90513611, 8.48597145], [76.90513611, 8.48625088], [76.90458679, 8.48625088], [76.90458679, 8.48680973], [76.9043045, 8.48680496], [76.9043045, 8.48708344], [76.90402985, 8.48708057], [76.90402985, 8.48763943], [76.90374756, 8.48763943], [76.90374756, 8.48792171], [76.90319824, 8.48791695], [76.90319824, 8.48847103], [76.90290833, 8.48847103], [76.90290833, 8.48903179], [76.90235901, 8.48902702], [76.90235901, 8.48958302], [76.90180206, 8.48958111], [76.90180206, 8.49014187], [76.9015274, 8.49013901], [76.9015274, 8.49069309], [76.90125275, 8.49069309], [76.90125275, 8.49097443], [76.9006958, 8.49097061], [76.9006958, 8.49153042], [76.90040588, 8.49153042], [76.90040588, 8.49180984], [76.8998642, 8.49180603], [76.8998642, 8.49208355], [76.89958191, 8.4920702], [76.89958191, 8.49291992], [76.89930725, 8.49291801], [76.89930725, 8.49319363], [76.89902496, 8.49319363], [76.89902496, 8.4934721], [76.89848328, 8.49346924], [76.89848328, 8.49374962], [76.89819336, 8.49374962], [76.89819336, 8.49403], [76.8979187, 8.49402809], [76.8979187, 8.49458408], [76.89763641, 8.49458408], [76.89763641, 8.49514008], [76.89736176, 8.49513054], [76.89736176, 8.49542046], [76.8970871, 8.49541569], [76.8970871, 8.49569416], [76.89680481, 8.49569416], [76.89680481, 8.49597168], [76.89653015, 8.49597168], [76.89653015, 8.49625015], [76.89624786, 8.49625015], [76.89624786, 8.49680996], [76.89569092, 8.49680614], [76.89569092, 8.49708366], [76.89541626, 8.49708366], [76.89541626, 8.49736214], [76.8951416, 8.49736023], [76.8951416, 8.49763966], [76.89485931, 8.49763775], [76.89485931, 8.49819374], [76.89458466, 8.49819374], [76.89458466, 8.49847221], [76.89430237, 8.49847031], [76.89430237, 8.49903011], [76.89404297, 8.49903011], [76.89404297, 8.49931145], [76.89375305, 8.49930573], [76.89375305, 8.4995842], [76.89319611, 8.49958038], [76.89319611, 8.49986172], [76.89290619, 8.49986172], [76.89290619, 8.50042057], [76.89263916, 8.5004158], [76.89263916, 8.50069427], [76.89235687, 8.50069046], [76.89235687, 8.50126171], [76.89208221, 8.50126171], [76.89208221, 8.50153065], [76.89180756, 8.50153065], [76.89180756, 8.50181103], [76.89152527, 8.50180626], [76.89152527, 8.50208378], [76.89125061, 8.50208378], [76.89125061, 8.50236034], [76.89096832, 8.50236034], [76.89096832, 8.50264072], [76.89041901, 8.50263786], [76.89041901, 8.50319386], [76.89013672, 8.50319386], [76.89013672, 8.50374985], [76.88986206, 8.50374985], [76.88986206, 8.50403118], [76.88957977, 8.50403118], [76.88957977, 8.50432014], [76.88930511, 8.50430679], [76.88930511, 8.50458241], [76.88903046, 8.50457954], [76.88903046, 8.50542068], [76.88874817, 8.50541687], [76.88874817, 8.50569534], [76.88847351, 8.50569534], [76.88847351, 8.50597286], [76.88819122, 8.50597286], [76.88819122, 8.50625134], [76.88790894, 8.50625134], [76.88790894, 8.50680923], [76.88735962, 8.50680542], [76.88735962, 8.50708294], [76.88708496, 8.50708294], [76.88708496, 8.50736141], [76.88680267, 8.50736141], [76.88680267, 8.50792122], [76.88652802, 8.5079174], [76.88652802, 8.50819492], [76.88625336, 8.50819492], [76.88625336, 8.5084734], [76.88597107, 8.50847054], [76.88597107, 8.50875092], [76.88569641, 8.50875092], [76.88569641, 8.5090313], [76.88541412, 8.50902653], [76.88541412, 8.50958347], [76.88513947, 8.50958347], [76.88513947, 8.50986099], [76.88487244, 8.50986099], [76.88487244, 8.51041889], [76.88458252, 8.51041698], [76.88458252, 8.51097298], [76.88430786, 8.51097298], [76.88430786, 8.51124859], [76.8840332, 8.51125145], [76.8840332, 8.51153088], [76.88375092, 8.51153088], [76.88375092, 8.51180935], [76.88346863, 8.51180458], [76.88346863, 8.51208305], [76.88318634, 8.51208115], [76.88318634, 8.51264095], [76.88291931, 8.51264095], [76.88291931, 8.51291943], [76.88263702, 8.51291943], [76.88263702, 8.51320171], [76.88236237, 8.51319504], [76.88236237, 8.51347256], [76.88208008, 8.51347065], [76.88208008, 8.51402855], [76.88181305, 8.51402855], [76.88181305, 8.51431179], [76.88153076, 8.51430511], [76.88153076, 8.51458263], [76.88124847, 8.51458263], [76.88124847, 8.51486111], [76.88096619, 8.51486111], [76.88096619, 8.51514244], [76.88041687, 8.51513863], [76.88041687, 8.51569462], [76.88014221, 8.5156908], [76.88014221, 8.5162611], [76.87985992, 8.5162611], [76.87985992, 8.51653194], [76.8795929, 8.51653194], [76.8795929, 8.51681042], [76.87930298, 8.5168047], [76.87930298, 8.51736069], [76.87847137, 8.51736069], [76.87847137, 8.51791954], [76.87819672, 8.51791763], [76.87819672, 8.51847363], [76.8779068, 8.51846886], [76.8779068, 8.51902962], [76.87763977, 8.51902771], [76.87763977, 8.51930618], [76.87735748, 8.51930618], [76.87735748, 8.51986217], [76.87708282, 8.51985931], [76.87708282, 8.52042007], [76.87680817, 8.52041626], [76.87680817, 8.52069569], [76.87652588, 8.52069092], [76.87652588, 8.52124977], [76.87625122, 8.52124977], [76.87625122, 8.52180958], [76.87596893, 8.52180576], [76.87596893, 8.52208424], [76.87569427, 8.52208424], [76.87569427, 8.52236176], [76.87541962, 8.52235985], [76.87541962, 8.52264023], [76.87513733, 8.52264023], [76.87513733, 8.52291965], [76.87486267, 8.52291584], [76.87486267, 8.52319431], [76.87458038, 8.52319431], [76.87458038, 8.52375031], [76.87431335, 8.52375031], [76.87431335, 8.52402973], [76.87403107, 8.52402782], [76.87403107, 8.52458191], [76.87374878, 8.52458382], [76.87374878, 8.52486229], [76.87346649, 8.52486038], [76.87346649, 8.52514172], [76.87319183, 8.52514172], [76.87319183, 8.52542973], [76.87291718, 8.52541637], [76.87291718, 8.52569389], [76.87264252, 8.52569389], [76.87264252, 8.52597237], [76.87236023, 8.52597046], [76.87236023, 8.52625179], [76.87180328, 8.52625179], [76.87180328, 8.52653027], [76.87152863, 8.52653027], [76.87152863, 8.52681065], [76.87124634, 8.52680588], [76.87124634, 8.52735996], [76.87097168, 8.52735996], [76.87097168, 8.52764034], [76.87069702, 8.52764034], [76.87069702, 8.5282011], [76.87041473, 8.52819443], [76.87041473, 8.52847195], [76.87014008, 8.52847195], [76.87014008, 8.52875042], [76.86987305, 8.52875042], [76.86987305, 8.5290308], [76.86930847, 8.52902794], [76.86930847, 8.52958202], [76.86902618, 8.52958202], [76.86902618, 8.53014088], [76.86875153, 8.53014088], [76.86875153, 8.53042126], [76.86846924, 8.53041553], [76.86846924, 8.53097153], [76.86818695, 8.53096962], [76.86818695, 8.53180885], [76.86736298, 8.53180695], [76.86736298, 8.53236008], [76.86708069, 8.53236008], [76.86708069, 8.53292084], [76.86680603, 8.53291702], [76.86680603, 8.53319454], [76.86653137, 8.53318977], [76.86653137, 8.53375053], [76.86624908, 8.53375053], [76.86624908, 8.53403091], [76.86597443, 8.53402901], [76.86597443, 8.53458309], [76.86569214, 8.53458309], [76.86569214, 8.53486061], [76.86541748, 8.53486061], [76.86541748, 8.53514099], [76.86513519, 8.53513908], [76.86513519, 8.5359726], [76.86486053, 8.53597069], [76.86486053, 8.53625107], [76.86458588, 8.53625107], [76.86458588, 8.53681183], [76.86402893, 8.53680515], [76.86402893, 8.53708267], [76.86373901, 8.5370779], [76.86373901, 8.53736973], [76.86347198, 8.53736973], [76.86347198, 8.53764057], [76.86292267, 8.53764057], [76.86292267, 8.53792191], [76.86264038, 8.53791714], [76.86264038, 8.53847313], [76.86207581, 8.53847122], [76.86207581, 8.53875065], [76.86235809, 8.53875065], [76.86235809, 8.53903103], [76.86180878, 8.53902912], [76.86180878, 8.53958321], [76.86125183, 8.53958321], [76.86125183, 8.53986073], [76.86096954, 8.53986073], [76.86096954, 8.5401392], [76.86069489, 8.5401392], [76.86069489, 8.54069519], [76.86042023, 8.54069519], [76.86042023, 8.5409708], [76.86013794, 8.54097271], [76.86013794, 8.54125118], [76.85986328, 8.54125118], [76.85986328, 8.54153156], [76.85958099, 8.54152679], [76.85958099, 8.54208279], [76.85930634, 8.54208279], [76.85930634, 8.54236126], [76.85901642, 8.54236126], [76.85901642, 8.54264164], [76.85874939, 8.54264164], [76.85874939, 8.54292202], [76.85819244, 8.54291725], [76.85819244, 8.54347134], [76.85793304, 8.54347134], [76.85793304, 8.54403019], [76.8576355, 8.54402733], [76.8576355, 8.54458332], [76.85736084, 8.54458332], [76.85736084, 8.54486179], [76.85708618, 8.54486179], [76.85708618, 8.54541969], [76.85652924, 8.54541779], [76.85652924, 8.5456934], [76.85624695, 8.5456934], [76.85624695, 8.54597092], [76.85597229, 8.54597092], [76.85597229, 8.54625034], [76.85569763, 8.54623985], [76.85569763, 8.54681015], [76.85541534, 8.54680634], [76.85541534, 8.54708385], [76.85514069, 8.54708099], [76.85514069, 8.54763985], [76.8548584, 8.54763985], [76.8548584, 8.54819584], [76.85430908, 8.54819584], [76.85430908, 8.5484724], [76.85402679, 8.54846859], [76.85402679, 8.5490303], [76.85375214, 8.5490303], [76.85375214, 8.54930973], [76.85346985, 8.54930592], [76.85346985, 8.54986191], [76.8529129, 8.54986191], [76.8529129, 8.55042267], [76.85236359, 8.5504179], [76.85236359, 8.55069447], [76.8520813, 8.55069447], [76.8520813, 8.55125046], [76.85179901, 8.55125046], [76.85179901, 8.55181122], [76.85150909, 8.55181122], [76.85150909, 8.55237103], [76.85124969, 8.55237103], [76.85124969, 8.5529213], [76.85097504, 8.55291557], [76.85097504, 8.55319405], [76.85041809, 8.55318928], [76.85041809, 8.55375004], [76.8501358, 8.55375004], [76.8501358, 8.55403042], [76.84958649, 8.55402756], [76.84958649, 8.55458355], [76.84929657, 8.55457973], [76.8493042, 8.55486012], [76.84902954, 8.55486012], [76.84902954, 8.55513954], [76.84874725, 8.55513763], [76.84874725, 8.55569363], [76.8484726, 8.55569363], [76.8484726, 8.5559721], [76.84819794, 8.55597019], [76.84819794, 8.55653095], [76.84791565, 8.55652809], [76.84791565, 8.55708218], [76.8473587, 8.55708218], [76.8473587, 8.5573597], [76.84707642, 8.5573597], [76.84707642, 8.55792141], [76.84680939, 8.55791569], [76.84680176, 8.55819416], [76.8465271, 8.55819416], [76.8465271, 8.55875111], [76.84597015, 8.55875111], [76.84597015, 8.55931091], [76.84541321, 8.55930424], [76.84541321, 8.55986118], [76.84513855, 8.55986118], [76.84513855, 8.56014061], [76.8445816, 8.5601387], [76.8445816, 8.56069469], [76.84430695, 8.56068993], [76.84430695, 8.56125069], [76.84375, 8.56125069], [76.84375, 8.56153965], [76.84347534, 8.56152916], [76.84347534, 8.56208324], [76.84319305, 8.56208038], [76.84319305, 8.56264114], [76.84263611, 8.56264114], [76.84263611, 8.56292057], [76.84236145, 8.56291676], [76.84236145, 8.56347275], [76.84208679, 8.56347084], [76.84208679, 8.56403065], [76.84179688, 8.56403065], [76.84179688, 8.56431198], [76.84152985, 8.56430531], [76.84152985, 8.56458282], [76.84124756, 8.56458282], [76.84124756, 8.5648613], [76.84069824, 8.5648613], [76.84069824, 8.5654192], [76.84041595, 8.56541729], [76.84041595, 8.56569481], [76.83985901, 8.56569481], [76.83985901, 8.56597328], [76.83930206, 8.56597137], [76.83930206, 8.56652927], [76.8390274, 8.56652737], [76.8390274, 8.56708336], [76.83875275, 8.56708145], [76.83875275, 8.56792164], [76.8381958, 8.56791687], [76.8381958, 8.56875134], [76.83790588, 8.56875134], [76.83790588, 8.56903172], [76.83763885, 8.56902695], [76.83763885, 8.56958294], [76.83708191, 8.56958294], [76.83708191, 8.56986141], [76.83680725, 8.56986141], [76.83680725, 8.5704174], [76.83652496, 8.5704174], [76.83652496, 8.57097435], [76.83598328, 8.57097054], [76.83598328, 8.57153034], [76.83569336, 8.57153034], [76.83569336, 8.57180977], [76.8354187, 8.571805], [76.8354187, 8.57236195], [76.83513641, 8.57236195], [76.83513641, 8.57264042], [76.83486176, 8.57264042], [76.83486176, 8.5731926], [76.83429718, 8.57319069], [76.83429718, 8.57348061], [76.83376312, 8.57348061], [76.83374786, 8.57374954], [76.83347321, 8.57374954], [76.83347321, 8.57402992], [76.83319092, 8.57402802], [76.83319092, 8.57458401], [76.83291626, 8.57458401], [76.83291626, 8.57486153], [76.83235931, 8.57486153], [76.83235931, 8.57569408], [76.83180237, 8.57569122], [76.83180237, 8.57625198], [76.83152771, 8.57625198], [76.83152771, 8.57681274], [76.83125305, 8.57680607], [76.83125305, 8.57736206], [76.83097076, 8.57736015], [76.83097076, 8.57791996], [76.83041382, 8.57791805], [76.83041382, 8.57819366], [76.83013916, 8.57819366], [76.83013916, 8.57847214], [76.82958221, 8.57847023], [76.82958221, 8.57903004], [76.82930756, 8.57903004], [76.82930756, 8.57931137], [76.82902527, 8.57930565], [76.82902527, 8.57958412], [76.82875061, 8.57958412], [76.82875061, 8.57985973], [76.82818604, 8.57985973], [76.82818604, 8.58042145], [76.82791901, 8.58041573], [76.82791901, 8.5806942], [76.82736206, 8.58069038], [76.82736206, 8.58181095], [76.82707977, 8.58180618], [76.82707977, 8.5820837], [76.82681274, 8.58207989], [76.82681274, 8.58263969], [76.82653046, 8.58263969], [76.82653046, 8.58292103], [76.82597351, 8.58291626], [76.82597351, 8.58319378], [76.82569122, 8.58319187], [76.82569122, 8.58374977], [76.82514191, 8.58374977], [76.82514191, 8.58403111], [76.82485962, 8.58402824], [76.82485962, 8.58485985], [76.8245697, 8.58485985], [76.8245697, 8.58514118], [76.82430267, 8.58513832], [76.82430267, 8.58569527], [76.82402802, 8.58569527], [76.82402802, 8.58597279], [76.82375336, 8.58597279], [76.82375336, 8.58625126], [76.82347107, 8.58625126], [76.82347107, 8.58653069], [76.82319641, 8.58652878], [76.82319641, 8.58708191], [76.82291412, 8.58708477], [76.82291412, 8.58736134], [76.82263947, 8.58736134], [76.82263947, 8.58792114], [76.82208252, 8.58792114], [76.82208252, 8.5884819], [76.82182312, 8.5884819], [76.82182312, 8.58875084], [76.8215332, 8.58875084], [76.8215332, 8.58903122], [76.82125092, 8.58903122], [76.82125092, 8.58931065], [76.82096863, 8.58930683], [76.82096863, 8.58986092], [76.82068634, 8.58986092], [76.82068634, 8.5901413], [76.82041931, 8.59013939], [76.82041931, 8.59069538], [76.81958008, 8.59068966], [76.81958008, 8.59154034], [76.81930542, 8.59152699], [76.81930542, 8.59208298], [76.81874847, 8.59208298], [76.81874847, 8.59236145], [76.81819153, 8.59236145], [76.81819153, 8.59291935], [76.81791687, 8.59291744], [76.81791687, 8.59347343], [76.81764221, 8.59347057], [76.81764221, 8.59402943], [76.81735992, 8.59402943], [76.81735992, 8.59431171], [76.81708527, 8.59430504], [76.81708527, 8.59458256], [76.81680298, 8.59458065], [76.81680298, 8.59514236], [76.81652832, 8.59514236], [76.81652832, 8.59542179], [76.81597137, 8.59541702], [76.81597137, 8.59597111], [76.81568909, 8.59597111], [76.81568909, 8.59653187], [76.81539917, 8.59653187], [76.81539917, 8.59681034], [76.81513977, 8.59680462], [76.81513977, 8.59708309], [76.81485748, 8.59708118], [76.81485748, 8.59764194], [76.81458282, 8.59763908], [76.81458282, 8.59819317], [76.81402588, 8.59819317], [76.81402588, 8.59847355], [76.81375122, 8.59847069], [76.81375122, 8.59902954], [76.81319427, 8.59902668], [76.81319427, 8.59958363], [76.81291962, 8.59958363], [76.81291962, 8.5998621], [76.8126297, 8.59985924], [76.8126297, 8.60042], [76.81236267, 8.60041809], [76.81236267, 8.60069561], [76.81208038, 8.60069561], [76.81208038, 8.60097218], [76.81181335, 8.60096931], [76.81181335, 8.60124969], [76.81124878, 8.60124969], [76.81124878, 8.60181046], [76.81096649, 8.60181046], [76.81097412, 8.60236168], [76.81069183, 8.60236168], [76.81069183, 8.60264015], [76.81041718, 8.60264015], [76.81041718, 8.60319424], [76.80986023, 8.60319424], [76.80986023, 8.60375023], [76.8095932, 8.60375023], [76.8095932, 8.60402966], [76.80930328, 8.60402775], [76.80930328, 8.60458374], [76.80902863, 8.60458183], [76.80902863, 8.60513973], [76.80847168, 8.60513973], [76.80847168, 8.60542011], [76.80819702, 8.6054163], [76.80819702, 8.60597229], [76.80764008, 8.60597229], [76.80764008, 8.60652828], [76.80735779, 8.60652828], [76.80735779, 8.60708427], [76.80708313, 8.60708427], [76.80708313, 8.60735989], [76.8068161, 8.60735989], [76.8068161, 8.60792065], [76.80652618, 8.60791588], [76.80652618, 8.60819435], [76.80596924, 8.60819435], [76.80596924, 8.60875034], [76.80568695, 8.60875034], [76.80568695, 8.60903072], [76.80541992, 8.60903072], [76.80541992, 8.6093111], [76.80513763, 8.60930634], [76.80513763, 8.60986233], [76.80486298, 8.60986042], [76.80486298, 8.6101408], [76.80458069, 8.6101408], [76.80458069, 8.61042118], [76.80430603, 8.61041641], [76.80430603, 8.6109724], [76.80403137, 8.61096954], [76.80403137, 8.61124992], [76.80374908, 8.61124992], [76.80374908, 8.61153126], [76.80345917, 8.61153126], [76.80345917, 8.61181068], [76.80319214, 8.61180687], [76.80319214, 8.61236], [76.80291748, 8.61236], [76.80291748, 8.61252022], [76.80291748, 8.61264992], [76.80264282, 8.61264992], [76.80264282, 8.61291885], [76.80236053, 8.61291695], [76.80236053, 8.61347294], [76.80179596, 8.61347008], [76.80180359, 8.61375141], [76.80152893, 8.61375141], [76.80152893, 8.61431122], [76.80124664, 8.61430359], [76.80124664, 8.61458302], [76.80097198, 8.61458015], [76.80097198, 8.61514091], [76.80069733, 8.61513901], [76.80069733, 8.615695], [76.80014038, 8.61569023], [76.80014038, 8.61625099], [76.79985809, 8.61625099], [76.79985809, 8.61653137], [76.79957581, 8.61653137], [76.79957581, 8.61680889], [76.79930878, 8.61680698], [76.79930878, 8.6170826], [76.79902649, 8.61707973], [76.79902649, 8.61764145], [76.79846954, 8.61764145], [76.79846954, 8.61792088], [76.79819489, 8.61791706], [76.79819489, 8.61847305], [76.79792023, 8.61846161], [76.79792023, 8.61903095], [76.79736328, 8.61903095], [76.79736328, 8.61930943], [76.79680634, 8.61930466], [76.79680634, 8.61986065], [76.79651642, 8.61986065], [76.79651642, 8.62041855], [76.79624939, 8.62041664], [76.79624939, 8.62097263], [76.79569244, 8.62097263], [76.79569244, 8.6212492], [76.79541779, 8.6212492], [76.79541779, 8.62181187], [76.7951355, 8.62180519], [76.7951355, 8.62236118], [76.79458618, 8.62236118], [76.79458618, 8.62264156], [76.79430389, 8.6226387], [76.79430389, 8.62319469], [76.79402924, 8.62319088], [76.79402924, 8.62375164], [76.79374695, 8.62375164], [76.79374695, 8.62403202], [76.79347229, 8.62403202], [76.79347229, 8.62430954], [76.79319763, 8.62430954], [76.79319763, 8.62458992], [76.79291534, 8.62458324], [76.79291534, 8.62486076], [76.79264069, 8.62485886], [76.79264069, 8.62514019], [76.79207611, 8.62514019], [76.79207611, 8.62541962], [76.79180908, 8.62541771], [76.79180908, 8.62569332], [76.79152679, 8.62569332], [76.79152679, 8.62597084], [76.79125214, 8.62597084], [76.79125214, 8.62652969], [76.79096985, 8.62652969], [76.79096985, 8.62681007], [76.79069519, 8.62680626], [76.79069519, 8.62708378], [76.7904129, 8.62708092], [76.7904129, 8.62765121], [76.79013824, 8.62765121], [76.79013824, 8.62792015], [76.78986359, 8.62791538], [76.78986359, 8.62847233], [76.78930664, 8.62847233], [76.78930664, 8.62874985], [76.78901672, 8.62874985], [76.78901672, 8.62903023], [76.78874969, 8.62903023], [76.78874969, 8.62930965], [76.78847504, 8.62930584], [76.78847504, 8.62958431], [76.78819275, 8.62958431], [76.78819275, 8.63069439], [76.78791809, 8.63069439], [76.78791809, 8.63125038], [76.78679657, 8.63125038], [76.78679657, 8.63153172], [76.78652954, 8.63153172], [76.78652954, 8.63181114], [76.78624725, 8.63180637], [76.78624725, 8.63208389], [76.7859726, 8.63208389], [76.7859726, 8.63236237], [76.7857132, 8.63236046], [76.7857132, 8.63292027], [76.78541565, 8.63291645], [76.78541565, 8.63347244], [76.78514099, 8.633461], [76.78514099, 8.63403034], [76.7848587, 8.63402843], [76.7848587, 8.63486004], [76.78457642, 8.63486004], [76.78457642, 8.6354208], [76.78430939, 8.63541603], [76.78430176, 8.63597202], [76.78375244, 8.63597012], [76.78375244, 8.63653088], [76.78347015, 8.63653088], [76.78347015, 8.63681984], [76.78291321, 8.63680553], [76.78291321, 8.6370821], [76.78263855, 8.6370821], [76.78263855, 8.63736343], [76.78235626, 8.63735962], [76.78235626, 8.63792133], [76.7820816, 8.63791561], [76.7820816, 8.63819408], [76.78152466, 8.63819408], [76.78152466, 8.6384716], [76.78125, 8.6384697], [76.78125, 8.63931084], [76.78097534, 8.63930416], [76.78097534, 8.63986015], [76.78069305, 8.63986015], [76.78069305, 8.64014053], [76.7804184, 8.64014053], [76.7804184, 8.64042091], [76.78013611, 8.6404171], [76.78013611, 8.64097309], [76.77986145, 8.64097023], [76.77986145, 8.64125061], [76.77957916, 8.64125061], [76.77957916, 8.64181137], [76.7793045, 8.6418047], [76.7793045, 8.64208317], [76.77902985, 8.64208317], [76.77902985, 8.64236069], [76.77874756, 8.64236069], [76.77874756, 8.64292145], [76.7784729, 8.64291668], [76.7784729, 8.64319515], [76.77819824, 8.64319515], [76.77819824, 8.64347267], [76.77791595, 8.6434679], [76.77791595, 8.64403057], [76.77735901, 8.64403057], [76.77735901, 8.6443119], [76.77708435, 8.64430523], [76.77708435, 8.64486122], [76.77680206, 8.64486122], [76.77680206, 8.64542198], [76.7765274, 8.64541721], [76.7765274, 8.64597321], [76.77625275, 8.6459713], [76.77625275, 8.64625072], [76.77597046, 8.64625072], [76.77597046, 8.6465292], [76.7756958, 8.6465292], [76.7756958, 8.64708328], [76.77541351, 8.64708328], [76.77541351, 8.6473608], [76.77513885, 8.64735889], [76.77513885, 8.64763927], [76.77485657, 8.64763927], [76.77485657, 8.64792156], [76.77458191, 8.64791679], [76.77458191, 8.64819527], [76.77401733, 8.64819145], [76.77401733, 8.6487627], [76.77375031, 8.6487627], [76.77375031, 8.64903164], [76.77348328, 8.64903164], [76.77348328, 8.64931202], [76.7729187, 8.64930534], [76.7729187, 8.64986134], [76.77263641, 8.64986134], [76.77263641, 8.65042019], [76.77236176, 8.65041733], [76.77236176, 8.65097141], [76.7720871, 8.65097141], [76.7720871, 8.65125179], [76.77179718, 8.65125179], [76.77179718, 8.65153027], [76.77153015, 8.65153027], [76.77153015, 8.65181923], [76.77124786, 8.65180492], [76.77124786, 8.6520834], [76.77097321, 8.65208054], [76.77097321, 8.65264034], [76.77069092, 8.65264034], [76.77069092, 8.65291977], [76.77041626, 8.65291786], [76.77041626, 8.65319347], [76.7701416, 8.65319347], [76.7701416, 8.65374947], [76.76985931, 8.65374947], [76.76985931, 8.65431023], [76.76930237, 8.65430641], [76.76930237, 8.6548624], [76.76902771, 8.65485859], [76.76902771, 8.65513992], [76.76875305, 8.65513992], [76.76875305, 8.65569401], [76.76847076, 8.65569115], [76.76847076, 8.65625191], [76.76790619, 8.65625191], [76.76790619, 8.65653038], [76.76763916, 8.65652847], [76.76763916, 8.65708447], [76.76735687, 8.6570816], [76.7673645, 8.65736198], [76.76708221, 8.65736198], [76.76708221, 8.6576376], [76.76680756, 8.65763092], [76.76680756, 8.65792274], [76.76652527, 8.65791798], [76.76652527, 8.65819359], [76.76625061, 8.65819359], [76.76625061, 8.65847206], [76.76597595, 8.65847015], [76.76597595, 8.65874958], [76.76568604, 8.65874958], [76.76568604, 8.65931129], [76.76541901, 8.65930557], [76.76541901, 8.65958405], [76.76513672, 8.65958023], [76.76513672, 8.66014004], [76.76486206, 8.66014004], [76.76486206, 8.66042137], [76.76457977, 8.66042137], [76.76457977, 8.6607008], [76.76431274, 8.6607008], [76.76431274, 8.66125011], [76.76403046, 8.66125011], [76.76403046, 8.66152954], [76.76374817, 8.66152954], [76.76374817, 8.66181087], [76.76347351, 8.66180611], [76.76347351, 8.66208363], [76.76291656, 8.66208172], [76.76291656, 8.66263962], [76.76264191, 8.66263962], [76.76264191, 8.66292095], [76.76235962, 8.66291618], [76.76235962, 8.66347218], [76.76180267, 8.66347027], [76.76180267, 8.66375923], [76.76154327, 8.66375923], [76.76154327, 8.66403103], [76.76125336, 8.66403103], [76.76125336, 8.66431141], [76.76097107, 8.66430569], [76.76097107, 8.66485977], [76.76069641, 8.66485977], [76.76069641, 8.66542053], [76.76041412, 8.66541576], [76.76041412, 8.66569424], [76.76013947, 8.66569424], [76.76013947, 8.66625118], [76.75986481, 8.66625118], [76.75986481, 8.66680431], [76.75958252, 8.66680431], [76.75958252, 8.66736031], [76.75930786, 8.66736031], [76.75930786, 8.66764069], [76.75875092, 8.66764069], [76.75875092, 8.66792107], [76.75846863, 8.66791725], [76.75846863, 8.66819477], [76.75819397, 8.66819477], [76.75819397, 8.66847324], [76.75791931, 8.66847324], [76.75791931, 8.66875076], [76.75763702, 8.6687479], [76.75763702, 8.66903114], [76.75736237, 8.66902924], [76.75736237, 8.66958332], [76.75708008, 8.66958332], [76.75708008, 8.66986084], [76.75653076, 8.66986084], [76.75653076, 8.67014122], [76.75569153, 8.67014122], [76.75569153, 8.67153072], [76.75541687, 8.67152691], [76.75541687, 8.6720829], [76.75514221, 8.6720829], [76.75514221, 8.67236137], [76.7545929, 8.67236137], [76.7545929, 8.67263889], [76.75430298, 8.67263889], [76.75430298, 8.67291927], [76.75402832, 8.67291737], [76.75402832, 8.67319489], [76.75375366, 8.67319489], [76.75375366, 8.67347336], [76.75347137, 8.67347145], [76.75347137, 8.67402935], [76.75319672, 8.67402935], [76.75319672, 8.67430973], [76.7529068, 8.67430973], [76.75291443, 8.67486095], [76.75263977, 8.67486095], [76.75263977, 8.67542171], [76.75208282, 8.67541695], [76.75208282, 8.67597103], [76.75180817, 8.67597103], [76.75180817, 8.67625141], [76.75152588, 8.67625141], [76.75152588, 8.67681026], [76.75096893, 8.67680454], [76.75096893, 8.67708302], [76.75069427, 8.67708302], [76.75069427, 8.67736053], [76.75041962, 8.67736053], [76.75041962, 8.67764187], [76.74986267, 8.67763901], [76.74986267, 8.67847443], [76.74958038, 8.67847443], [76.74958038, 8.67874908], [76.74903107, 8.67873955], [76.74903107, 8.67930984], [76.74874878, 8.67930984], [76.74874878, 8.68013954], [76.74819183, 8.68013954], [76.74819183, 8.68041992], [76.74791718, 8.68041801], [76.74791718, 8.68069553], [76.74764252, 8.68068886], [76.74764252, 8.68124962], [76.74736023, 8.68124962], [76.74736023, 8.68180561], [76.74680328, 8.68180561], [76.74680328, 8.6823616], [76.74653625, 8.6823616], [76.74653625, 8.68292046], [76.74624634, 8.68291569], [76.74624634, 8.68319416], [76.74597168, 8.68319416], [76.74597168, 8.68347168], [76.7454071, 8.68347168], [76.74541473, 8.68375015], [76.74514008, 8.68375015], [76.74514008, 8.68430996], [76.74485779, 8.68430614], [76.74485779, 8.68486214], [76.74458313, 8.68486023], [76.74458313, 8.68513966], [76.74430847, 8.68513966], [76.74430847, 8.68542004], [76.74402618, 8.68541622], [76.74402618, 8.68569374], [76.74375153, 8.68569183], [76.74375153, 8.68624973], [76.74318695, 8.68624973], [76.74318695, 8.68681145], [76.74291992, 8.68681145], [76.74291992, 8.68736172], [76.74236298, 8.68736172], [76.74236298, 8.68793201], [76.74208069, 8.6879158], [76.74208069, 8.68819427], [76.74180603, 8.68819427], [76.74180603, 8.68847179], [76.74153137, 8.68847179], [76.74153137, 8.68875027], [76.74124908, 8.68875027], [76.74124908, 8.68931103], [76.74097443, 8.68930626], [76.74097443, 8.68958378], [76.74040985, 8.68957996], [76.74040985, 8.69013977], [76.74013519, 8.69013786], [76.74013519, 8.69069386], [76.73986053, 8.69069386], [76.73986053, 8.69097233], [76.73958588, 8.69097233], [76.73958588, 8.69124985], [76.73929596, 8.69124985], [76.73929596, 8.69153118], [76.73902893, 8.69153118], [76.73902893, 8.69181061], [76.73874664, 8.69180679], [76.73874664, 8.69208241], [76.73847198, 8.69207954], [76.73847198, 8.69264126], [76.73819733, 8.69264126], [76.73819733, 8.69292068], [76.73791504, 8.69291592], [76.73791504, 8.69347286], [76.73764038, 8.69347], [76.73764038, 8.69402885], [76.73735046, 8.69402885], [76.73735046, 8.69431114], [76.73680878, 8.69430447], [76.73680878, 8.69486141], [76.73652649, 8.69486141], [76.73652649, 8.69542122], [76.73625183, 8.6954174], [76.73625183, 8.69569492], [76.73596954, 8.69569492], [76.73596954, 8.6959734], [76.73568726, 8.69596958], [76.73568726, 8.6965313], [76.73542023, 8.69652653], [76.73542023, 8.69680691], [76.73513794, 8.69680691], [76.73513794, 8.69736099], [76.73486328, 8.69736099], [76.73486328, 8.69791889], [76.73458099, 8.69791698], [76.73458099, 8.69819546], [76.73430634, 8.69819546], [76.73430634, 8.69847298], [76.73374939, 8.69847107], [76.73374939, 8.69875145], [76.7334671, 8.69875145], [76.7334671, 8.69903088], [76.73319244, 8.69903088], [76.73319244, 8.69930935], [76.73291779, 8.69930935], [76.73291779, 8.70014095], [76.73264313, 8.70014095], [76.73264313, 8.70041943], [76.73236084, 8.70041656], [76.73236084, 8.70069504], [76.73208618, 8.70069504], [76.73208618, 8.70097256], [76.73179626, 8.70097065], [76.73179626, 8.70125103], [76.73153687, 8.70125103], [76.73153687, 8.70153236], [76.73124695, 8.70153236], [76.73124695, 8.70181179], [76.73097229, 8.70180511], [76.73097229, 8.70208263], [76.73069763, 8.70208263], [76.73069763, 8.70236111], [76.73042297, 8.70236111], [76.73042297, 8.70264244], [76.73014069, 8.70264244], [76.73014069, 8.7029314], [76.7298584, 8.7029171], [76.7298584, 8.70319462], [76.72958374, 8.70319462], [76.72958374, 8.70347118], [76.72902679, 8.70347118], [76.72902679, 8.70375061], [76.72875214, 8.70375061], [76.72875214, 8.70431042], [76.72820282, 8.70431042], [76.72820282, 8.70514202], [76.7279129, 8.70513916], [76.7279129, 8.70569324], [76.72763824, 8.70569324], [76.72763824, 8.70597363], [76.72735596, 8.70596886], [76.72736359, 8.70624924], [76.7270813, 8.70624924], [76.7270813, 8.70681], [76.72680664, 8.70680523], [76.72680664, 8.7070837], [76.72651672, 8.70708084], [76.72651672, 8.70763969], [76.72597504, 8.70763969], [76.72597504, 8.70819569], [76.72569275, 8.70819569], [76.72569275, 8.70847225], [76.72541046, 8.70846939], [76.72541046, 8.70903015], [76.7251358, 8.70903015], [76.7251358, 8.70930958], [76.72486115, 8.70930576], [76.72486115, 8.70958424], [76.72458649, 8.70958424], [76.72458649, 8.70986176], [76.72429657, 8.70985985], [76.72429657, 8.71014023], [76.72402954, 8.71014023], [76.72402954, 8.71069431], [76.7234726, 8.71069431], [76.7234726, 8.71097183], [76.72319794, 8.71097183], [76.72319794, 8.71152973], [76.72291565, 8.71152782], [76.72291565, 8.71208382], [76.72264099, 8.71208382], [76.72264099, 8.71236229], [76.72236633, 8.71236038], [76.72236633, 8.71264172], [76.72207642, 8.71264172], [76.72207642, 8.71292019], [76.72180939, 8.71291637], [76.72180176, 8.71347237], [76.7215271, 8.71347046], [76.7215271, 8.71375179], [76.72125244, 8.71375179], [76.72125244, 8.71403027], [76.72097015, 8.71402836], [76.72097015, 8.71458435], [76.72070313, 8.71457958], [76.72070313, 8.71514034], [76.72041321, 8.71514034], [76.72041321, 8.71542072], [76.72013855, 8.71541595], [76.72013855, 8.71569443], [76.7195816, 8.71569443], [76.7195816, 8.71597195], [76.71930695, 8.71597195], [76.71930695, 8.71625042], [76.71901703, 8.71625042], [76.71901703, 8.7165308], [76.71875, 8.71652794], [76.71875, 8.71708202], [76.71848297, 8.71708202], [76.71848297, 8.71764088], [76.71819305, 8.71763802], [76.71819305, 8.71791553], [76.71763611, 8.71791553], [76.71763611, 8.71847153], [76.71736145, 8.71846962], [76.71736145, 8.71875], [76.71708679, 8.71875], [76.71708679, 8.71903133], [76.71679688, 8.71903133], [76.71679688, 8.71930885], [76.71652985, 8.71930695], [76.71652985, 8.71958542], [76.7159729, 8.71958542], [76.7159729, 8.71986008], [76.71569824, 8.71986008], [76.71569824, 8.72014141], [76.71541595, 8.72014141], [76.71541595, 8.72042084], [76.71485901, 8.72042084], [76.71485901, 8.72125053], [76.71457672, 8.72125053], [76.71457672, 8.72153091], [76.71430206, 8.72152901], [76.71430206, 8.72208309], [76.7140274, 8.72208309], [76.7140274, 8.72236061], [76.71375275, 8.72236061], [76.71375275, 8.72264099], [76.7131958, 8.72263908], [76.7131958, 8.72319508], [76.71291351, 8.72319508], [76.71291351, 8.7234726], [76.71263885, 8.72347069], [76.71263885, 8.72375107], [76.71235657, 8.72375107], [76.71235657, 8.72404003], [76.71208191, 8.72404003], [76.71208191, 8.72431183], [76.71152496, 8.72430515], [76.71152496, 8.72458267], [76.71097565, 8.72458267], [76.71097565, 8.72486115], [76.71069336, 8.72486115], [76.71069336, 8.72569466], [76.71042633, 8.72568989], [76.71042633, 8.72653103], [76.71013641, 8.72653103], [76.71013641, 8.72680855], [76.70986176, 8.72680473], [76.70986176, 8.72708321], [76.7095871, 8.7270813], [76.7095871, 8.72736073], [76.70847321, 8.72736073], [76.70847321, 8.72819519], [76.70791626, 8.72819519], [76.70791626, 8.72875118], [76.7076416, 8.72875118], [76.7076416, 8.72931194], [76.70708466, 8.72930527], [76.70708466, 8.72958279], [76.70680237, 8.72958279], [76.70680237, 8.72986126], [76.70625305, 8.72986126], [76.70625305, 8.73069477], [76.70569611, 8.73069096], [76.70569611, 8.73125172], [76.70541382, 8.73124886], [76.70541382, 8.73208332], [76.70513916, 8.73208332], [76.70513916, 8.73291779], [76.70485687, 8.73291111], [76.7048645, 8.73374939], [76.70458221, 8.73374939], [76.70458221, 8.73431015], [76.70430756, 8.73430634], [76.70430756, 8.73458385], [76.70402527, 8.73458385], [76.70402527, 8.73486233], [76.70375061, 8.73485947], [76.70375061, 8.73513985], [76.70318604, 8.73513985], [76.70318604, 8.73542023], [76.70291901, 8.73541546], [76.70291901, 8.73569584], [76.70263672, 8.73569107], [76.70263672, 8.73598099], [76.70236206, 8.73598099], [76.70236206, 8.7365303], [76.70124054, 8.7365303], [76.70124054, 8.73680973], [76.70069122, 8.73680592], [76.70069122, 8.73708439], [76.70014191, 8.73708439], [76.70014191, 8.73736191], [76.69985962, 8.73736191], [76.69985962, 8.73764038], [76.69958496, 8.73763847], [76.69958496, 8.73819447], [76.69930267, 8.73819447], [76.69930267, 8.73875046], [76.69902802, 8.73875046], [76.69902802, 8.73931122], [76.69875336, 8.73930645], [76.69875336, 8.73958397], [76.69902802, 8.7395792], [76.69902802, 8.74013996], [76.69875336, 8.74013996], [76.69875336, 8.74125004], [76.69847107, 8.74125004], [76.69847107, 8.74236012], [76.69819641, 8.74236012], [76.69819641, 8.74292088], [76.69790649, 8.74292088], [76.69790649, 8.74374962], [76.69763947, 8.74374962], [76.69763947, 8.74403095], [76.69735718, 8.74403095], [76.69735718, 8.74431133], [76.69680786, 8.74431133], [76.69680786, 8.74514103], [76.69652557, 8.74513817], [76.69652557, 8.74569416], [76.69625092, 8.74569416], [76.69625092, 8.74625015], [76.69596863, 8.74625015], [76.69596863, 8.74681091], [76.69569397, 8.74680424], [76.69569397, 8.74736023], [76.69542694, 8.74736023], [76.69542694, 8.74792099], [76.69486237, 8.74791718], [76.69486237, 8.74819469], [76.69458008, 8.74819469], [76.69458008, 8.74847317], [76.69431305, 8.74847031], [76.69431305, 8.74931145], [76.69403076, 8.74930668], [76.69403076, 8.74986076], [76.69374847, 8.74986076], [76.69374847, 8.75069523], [76.69346619, 8.75069046], [76.69346619, 8.75098038], [76.69319153, 8.75097275], [76.69319153, 8.75125122], [76.69291687, 8.75125122], [76.69291687, 8.75153065], [76.69264221, 8.75153065], [76.69264221, 8.75181198], [76.69235992, 8.75180531], [76.69235992, 8.75208282], [76.69180298, 8.75208092], [76.69180298, 8.75264072], [76.69124603, 8.75264072], [76.69124603, 8.7529192], [76.69097137, 8.75291729], [76.69097137, 8.75319481], [76.69069672, 8.75319481], [76.69069672, 8.75374889], [76.69041443, 8.75374889], [76.69041443, 8.75402737], [76.69013977, 8.75402737], [76.69013977, 8.75458336], [76.68985748, 8.75458336], [76.68985748, 8.75486088], [76.68958282, 8.75486088], [76.68958282, 8.75514126], [76.68930817, 8.75513935], [76.68930817, 8.75569534], [76.68902588, 8.75569534], [76.68902588, 8.75597095], [76.68875122, 8.75597095], [76.68875122, 8.75653172], [76.68846893, 8.75652695], [76.68846893, 8.75708294], [76.68818665, 8.75708103], [76.68818665, 8.75792027], [76.68791962, 8.75792027], [76.68791962, 8.75875187], [76.68763733, 8.75875187], [76.68763733, 8.75903034], [76.68736267, 8.75902653], [76.68736267, 8.75958347], [76.68708038, 8.75958061], [76.68708038, 8.76015091], [76.68681335, 8.76015091], [76.68681335, 8.76041985], [76.68653107, 8.76041794], [76.68653107, 8.7606926], [76.68624878, 8.7606926], [76.68624878, 8.76097107], [76.68596649, 8.76097107], [76.68597412, 8.76124859], [76.68569183, 8.76124859], [76.68569183, 8.7618103], [76.68541718, 8.76180553], [76.68541718, 8.76208401], [76.68514252, 8.76207924], [76.68514252, 8.76264191], [76.68486023, 8.76264191], [76.68486023, 8.76292038], [76.6845932, 8.76292038], [76.6845932, 8.76375198], [76.68430328, 8.76375198], [76.68430328, 8.76403046], [76.68374634, 8.76403046], [76.68374634, 8.76431274], [76.68347168, 8.76430607], [76.68347168, 8.76486206], [76.68319702, 8.76486206], [76.68319702, 8.76569366], [76.6829071, 8.7656889], [76.6829071, 8.76653004], [76.68319702, 8.76653004], [76.68319702, 8.76681137], [76.6829071, 8.76681137], [76.68291473, 8.76735973], [76.68264008, 8.76735973], [76.68264008, 8.76764011], [76.68235779, 8.76764011], [76.68235779, 8.76792145], [76.68208313, 8.76791573], [76.68208313, 8.76847172], [76.68180847, 8.76847172], [76.68180847, 8.76931095], [76.68152618, 8.76930618], [76.68152618, 8.7695837], [76.68125153, 8.7695837], [76.68125153, 8.76986217], [76.68096924, 8.76986027], [76.68096924, 8.77013969], [76.68068695, 8.77013969], [76.68068695, 8.77042103], [76.68041992, 8.77041626], [76.68041992, 8.77069378], [76.68013, 8.77069187], [76.68013, 8.77124977], [76.67986298, 8.77124977], [76.67986298, 8.77153111], [76.67958069, 8.77153111], [76.67958069, 8.77264118], [76.67930603, 8.77263832], [76.67930603, 8.77319431], [76.67903137, 8.77319431], [76.67903137, 8.77347183], [76.67874908, 8.77347183], [76.67874908, 8.77375126], [76.67819214, 8.77375126], [76.67819214, 8.77403069], [76.67791748, 8.77403069], [76.67791748, 8.77431107], [76.67763519, 8.77430439], [76.67763519, 8.77474022], [76.67763519, 8.77486038], [76.67736053, 8.77486038], [76.67736053, 8.7751503], [76.67708588, 8.7751503], [76.67708588, 8.77542114], [76.67680359, 8.77541733], [76.67680359, 8.77569485], [76.67662811, 8.77569485], [76.67652893, 8.77569485], [76.67652893, 8.77653122], [76.67624664, 8.7765274], [76.67624664, 8.7770834], [76.67597198, 8.77707958], [76.67597198, 8.7776413], [76.67569733, 8.7776413], [76.67569733, 8.77792072], [76.67541504, 8.77791691], [76.67541504, 8.77819538], [76.67514038, 8.77819538], [76.67514038, 8.7784729], [76.67457581, 8.77847099], [76.67457581, 8.77875137], [76.67514038, 8.77875137], [76.67514038, 8.77930927], [76.67485809, 8.77930927], [76.67485809, 8.77902889], [76.67457581, 8.77902889], [76.67457581, 8.77930927], [76.67431641, 8.77930927], [76.67431641, 8.78041935], [76.67402649, 8.78041744], [76.67402649, 8.78069496], [76.67318726, 8.78069115], [76.67318726, 8.78153229], [76.67292023, 8.78152657], [76.67292023, 8.78208256], [76.67236328, 8.78208256], [76.67236328, 8.78236103], [76.67208099, 8.78236103], [76.67208099, 8.78281021], [76.67208099, 8.78292179], [76.67180634, 8.78291702], [76.67180634, 8.7834301], [76.67180634, 8.78375053], [76.67151642, 8.78375053], [76.67151642, 8.78347111], [76.67124939, 8.78347111], [76.67125702, 8.78391075], [76.67125702, 8.78431034], [76.67069244, 8.78430462], [76.67069244, 8.78458309], [76.67041779, 8.78458309], [76.67041779, 8.78486061], [76.67069244, 8.78486061], [76.67069244, 8.78514194], [76.67041779, 8.78514194], [76.67041779, 8.78542042], [76.6701355, 8.7854166], [76.6701355, 8.78597355], [76.66958618, 8.78597069], [76.66958618, 8.78625202], [76.66929626, 8.78625202], [76.66929626, 8.78652954], [76.66902924, 8.78652954], [76.66902924, 8.78680992], [76.66819763, 8.78680515], [76.66819763, 8.7873621], [76.66792297, 8.78735924], [76.66792297, 8.78792], [76.66764069, 8.78791809], [76.66764069, 8.78847122], [76.6673584, 8.78846931], [76.6673584, 8.78874969], [76.66680908, 8.78874969], [76.66680908, 8.78931046], [76.66652679, 8.78930569], [76.66652679, 8.78958416], [76.66625214, 8.78958416], [76.66625214, 8.79014015], [76.66596985, 8.79013062], [76.66596985, 8.79041958], [76.66569519, 8.79041576], [76.66569519, 8.79069424], [76.6645813, 8.79069424], [76.6645813, 8.79097176], [76.66430664, 8.79096889], [76.66430664, 8.79152966], [76.66401672, 8.79152966], [76.66401672, 8.79181004], [76.66374969, 8.79181004], [76.66374969, 8.79263973], [76.66348267, 8.79263973], [76.66348267, 8.79292011], [76.66319275, 8.7929163], [76.66319275, 8.79319382], [76.66291809, 8.79319382], [76.66291809, 8.79347229], [76.6626358, 8.79347038], [76.6626358, 8.79403019], [76.66236115, 8.79403019], [76.66236115, 8.79431057], [76.6618042, 8.7943058], [76.6618042, 8.79458427], [76.66124725, 8.79458427], [76.66124725, 8.79485989], [76.6609726, 8.79485989], [76.6609726, 8.79514027], [76.66042328, 8.79514027], [76.66042328, 8.79542065], [76.66014099, 8.79541588], [76.66014099, 8.79597187], [76.6598587, 8.79597187], [76.6598587, 8.79625034], [76.65957642, 8.79625034], [76.65957642, 8.79763985], [76.65931702, 8.79763985], [76.65930176, 8.79792118], [76.6590271, 8.79791641], [76.6590271, 8.79819393], [76.65875244, 8.79819393], [76.65875244, 8.7984724], [76.65847015, 8.79846954], [76.65847015, 8.79903126], [76.6581955, 8.7990284], [76.6581955, 8.79958534], [76.65791321, 8.79958534], [76.65791321, 8.79986], [76.65763855, 8.79986], [76.65763855, 8.80014133], [76.6570816, 8.80014133], [76.6570816, 8.80041885], [76.65680695, 8.80041599], [76.65680695, 8.80069447], [76.65625, 8.80069447], [76.65625, 8.80125141], [76.65598297, 8.80125141], [76.65598297, 8.80153084], [76.65569305, 8.80152893], [76.65569305, 8.80208206], [76.6554184, 8.80207062], [76.6554184, 8.80264091], [76.65513611, 8.80263901], [76.65513611, 8.803195], [76.65486145, 8.803195], [76.65486145, 8.80347347], [76.65458679, 8.80346966], [76.65458679, 8.80375099], [76.65429688, 8.80375099], [76.65429688, 8.80403137], [76.65402985, 8.80403137], [76.65402985, 8.80430889], [76.65374756, 8.80430698], [76.65374756, 8.80486107], [76.6534729, 8.80486107], [76.6534729, 8.80513859], [76.65319061, 8.80513191], [76.65319061, 8.80542088], [76.65291595, 8.80541706], [76.65291595, 8.80597305], [76.65235901, 8.80597115], [76.65235901, 8.80653095], [76.65207672, 8.80653095], [76.65207672, 8.80680943], [76.65180206, 8.80680466], [76.65180206, 8.80708313], [76.6515274, 8.80708313], [76.6515274, 8.80736065], [76.65097046, 8.80736065], [76.65097046, 8.80764103], [76.6506958, 8.80764103], [76.6506958, 8.80791855], [76.65040588, 8.80791855], [76.65040588, 8.80875111], [76.65013123, 8.80875111], [76.65013123, 8.80903244], [76.6498642, 8.80902672], [76.6498642, 8.80958271], [76.64930725, 8.80958271], [76.64930725, 8.80986118], [76.64901733, 8.80986118], [76.64901733, 8.81014156], [76.64875031, 8.8101387], [76.64875031, 8.81069469], [76.64847565, 8.81069469], [76.64847565, 8.81097126], [76.64819336, 8.81097126], [76.64819336, 8.81208324], [76.6479187, 8.81208324], [76.6479187, 8.81347084], [76.64763641, 8.81347084], [76.64763641, 8.81402969], [76.64736176, 8.81402683], [76.64736176, 8.81458378], [76.6470871, 8.81458092], [76.6470871, 8.81513977], [76.64679718, 8.81513977], [76.64679718, 8.81542015], [76.64653015, 8.81541538], [76.64653015, 8.81624985], [76.64624786, 8.81624985], [76.64624786, 8.81653023], [76.64597321, 8.81653023], [76.64597321, 8.8176403], [76.64569092, 8.8176403], [76.64569092, 8.81791973], [76.6451416, 8.81791782], [76.6451416, 8.81847191], [76.64485931, 8.81847191], [76.64485931, 8.81875038], [76.64457703, 8.81875038], [76.64457703, 8.81931019], [76.64430237, 8.81930637], [76.64430237, 8.81958389], [76.64402771, 8.81958389], [76.64402771, 8.81986237], [76.64375305, 8.81986046], [76.64375305, 8.82042027], [76.64347076, 8.82041645], [76.64347076, 8.82097244], [76.64319611, 8.82096958], [76.64319611, 8.82124996], [76.64290619, 8.82124996], [76.64291382, 8.82236004], [76.64263916, 8.82236004], [76.64263916, 8.82264042], [76.64235687, 8.82264042], [76.64235687, 8.82320118], [76.64180756, 8.82319355], [76.64180756, 8.82374954], [76.6415329, 8.82374954], [76.6415329, 8.82431126], [76.64125061, 8.82430553], [76.64125061, 8.8245821], [76.64097595, 8.8245821], [76.64097595, 8.82486153], [76.64068604, 8.82485962], [76.64068604, 8.82514], [76.64041901, 8.82513809], [76.64041901, 8.82569408], [76.64013672, 8.82569408], [76.64013672, 8.8259716], [76.63957977, 8.8259697], [76.63957977, 8.82625961], [76.63931274, 8.82625961], [76.63931274, 8.82653141], [76.63903046, 8.8265276], [76.63903046, 8.82708454], [76.63874817, 8.82708454], [76.63874817, 8.82736015], [76.63846588, 8.82736015], [76.63846588, 8.82792091], [76.63819122, 8.82791615], [76.63819122, 8.82819462], [76.63764191, 8.82818985], [76.63764191, 8.82903099], [76.63735962, 8.82902908], [76.63735962, 8.8293066], [76.63708496, 8.8293066], [76.63708496, 8.82958317], [76.63652802, 8.82958317], [76.63652802, 8.82986069], [76.63625336, 8.82986069], [76.63625336, 8.83069515], [76.63597107, 8.83069515], [76.63597107, 8.83097267], [76.63569641, 8.83097267], [76.63569641, 8.83125114], [76.63514709, 8.83125114], [76.63514709, 8.8318119], [76.63486481, 8.83180523], [76.63486481, 8.83208275], [76.63458252, 8.83208275], [76.63458252, 8.83236122], [76.63430786, 8.83236122], [76.63430786, 8.83319473], [76.63402557, 8.83319473], [76.63402557, 8.83347321], [76.63375092, 8.8334713], [76.63375092, 8.83375072], [76.63346863, 8.83375072], [76.63346863, 8.8340292], [76.63318634, 8.8340292], [76.63318634, 8.83430862], [76.63291931, 8.83430481], [76.63291931, 8.83458328], [76.63263702, 8.83458138], [76.63263702, 8.83514118], [76.63208008, 8.83513927], [76.63208008, 8.83569527], [76.63180542, 8.83569527], [76.63180542, 8.83625126], [76.63153076, 8.83625126], [76.63153076, 8.83653164], [76.63097382, 8.83652687], [76.63097382, 8.83708286], [76.63069153, 8.83708286], [76.63069153, 8.83736134], [76.63041687, 8.83736134], [76.63041687, 8.83764172], [76.63014221, 8.83764172], [76.63014221, 8.83792019], [76.6295929, 8.83792019], [76.6295929, 8.83819962], [76.62930298, 8.83819962], [76.62930298, 8.83875084], [76.62902069, 8.83875084], [76.62902069, 8.83903027], [76.62874603, 8.83903027], [76.62874603, 8.83930969], [76.62847137, 8.83930492], [76.62847137, 8.83986092], [76.62819672, 8.83986092], [76.62819672, 8.84013939], [76.62791443, 8.84013939], [76.62791443, 8.84069347], [76.62735748, 8.84069347], [76.62735748, 8.84097099], [76.62708282, 8.84097099], [76.62708282, 8.84124947], [76.62680817, 8.84123993], [76.62680817, 8.84152985], [76.62652588, 8.84152699], [76.62652588, 8.84208393], [76.62625122, 8.84208393], [76.62625122, 8.8423624], [76.6259613, 8.84235859], [76.6259613, 8.84264183], [76.62568665, 8.84264183], [76.62568665, 8.8429203], [76.62513733, 8.84291458], [76.62513733, 8.84319401], [76.62486267, 8.84319115], [76.62486267, 8.84375191], [76.62458038, 8.84375191], [76.62458038, 8.84403038], [76.62430573, 8.84402847], [76.62430573, 8.84430599], [76.62374878, 8.84430599], [76.62374878, 8.84486198], [76.62319183, 8.84486198], [76.62319183, 8.84542274], [76.62264252, 8.84541798], [76.62264252, 8.84597206], [76.62236023, 8.84597015], [76.62236023, 8.84652996], [76.6220932, 8.84652996], [76.6220932, 8.84681129], [76.62152863, 8.84680557], [76.62152863, 8.84708405], [76.62124634, 8.84707928], [76.62124634, 8.84764004], [76.62097168, 8.84764004], [76.62097168, 8.84792042], [76.62069702, 8.84791565], [76.62069702, 8.84819412], [76.62041473, 8.84819412], [76.62041473, 8.84847164], [76.62014771, 8.84846973], [76.62014771, 8.84902954], [76.61985779, 8.84902954], [76.61985779, 8.84931087], [76.61958313, 8.84930611], [76.61958313, 8.8498621], [76.61930847, 8.84986019], [76.61930847, 8.85042953], [76.61902618, 8.85041618], [76.61902618, 8.8506937], [76.61875153, 8.8506937], [76.61875153, 8.85097218], [76.61818695, 8.85097027], [76.61818695, 8.85124969], [76.61791992, 8.85124969], [76.61791992, 8.85153103], [76.61736298, 8.85152817], [76.61736298, 8.85208225], [76.61708069, 8.85208225], [76.61708069, 8.85235977], [76.61680603, 8.85235977], [76.61680603, 8.85264111], [76.61653137, 8.85264111], [76.61653137, 8.85292053], [76.61624908, 8.85291576], [76.61624908, 8.85319424], [76.61597443, 8.85319424], [76.61597443, 8.85347176], [76.61541748, 8.85347176], [76.61541748, 8.85375023], [76.61514282, 8.85375023], [76.61514282, 8.85431099], [76.61458588, 8.85430431], [76.61458588, 8.85486031], [76.61429596, 8.85486031], [76.61429596, 8.85514069], [76.61402893, 8.85513783], [76.61402893, 8.85569477], [76.61347198, 8.85569477], [76.61347198, 8.85597324], [76.61319733, 8.85597324], [76.61319733, 8.85625076], [76.61292267, 8.85623932], [76.61292267, 8.85653114], [76.61264038, 8.85653114], [76.61264038, 8.85681057], [76.61235809, 8.85680676], [76.61235809, 8.85708332], [76.61207581, 8.85708046], [76.61208344, 8.85736084], [76.61180878, 8.85736084], [76.61180878, 8.85764122], [76.61152649, 8.85764122], [76.61152649, 8.85792065], [76.61125183, 8.85791683], [76.61125183, 8.8581953], [76.61069489, 8.8581953], [76.61069489, 8.85847282], [76.61042023, 8.85847282], [76.61042023, 8.8587513], [76.61013794, 8.8587513], [76.61013794, 8.85903072], [76.60986328, 8.85903072], [76.60986328, 8.8593092], [76.60958099, 8.85930538], [76.60958099, 8.8595829], [76.60930634, 8.8595829], [76.60930634, 8.85986137], [76.60901642, 8.85986137], [76.60901642, 8.86041927], [76.60874939, 8.86041737], [76.60874939, 8.86069489], [76.60819244, 8.86069012], [76.60819244, 8.86125088], [76.60764313, 8.86125088], [76.60764313, 8.86181164], [76.60736084, 8.86180496], [76.60736084, 8.86208344], [76.60708618, 8.86208057], [76.60708618, 8.86236954], [76.60679626, 8.86236954], [76.60679626, 8.86264133], [76.60624695, 8.86264133], [76.60624695, 8.86292171], [76.60597229, 8.86292171], [76.60597229, 8.86264133], [76.60569763, 8.86264133], [76.60569763, 8.86292171], [76.60514069, 8.86291695], [76.60514069, 8.86319542], [76.60485077, 8.86319065], [76.6048584, 8.86375141], [76.60430908, 8.86375141], [76.60430908, 8.86403179], [76.60402679, 8.86403179], [76.60402679, 8.86431026], [76.60375214, 8.86430454], [76.60375214, 8.86486053], [76.60320282, 8.86486053], [76.60320282, 8.86514187], [76.6029129, 8.86513901], [76.6029129, 8.86541653], [76.60263824, 8.86541653], [76.60263824, 8.86569309], [76.60236359, 8.86569309], [76.60236359, 8.86597347], [76.6020813, 8.86597061], [76.6020813, 8.86625195], [76.60180664, 8.86625195], [76.60180664, 8.86653042], [76.60124969, 8.86653042], [76.60124969, 8.86680984], [76.60097504, 8.86680508], [76.60097504, 8.8670826], [76.60069275, 8.8670826], [76.60069275, 8.86736107], [76.6001358, 8.86736107], [76.6001358, 8.86763954], [76.59986115, 8.86763954], [76.59986115, 8.86791992], [76.5993042, 8.86791801], [76.5993042, 8.86819553], [76.59874725, 8.86818027], [76.59874725, 8.86874866], [76.5984726, 8.86874866], [76.5984726, 8.86903191], [76.59819794, 8.86902809], [76.59819794, 8.86958408], [76.59791565, 8.86958408], [76.59791565, 8.8698616], [76.59707642, 8.8698616], [76.59707642, 8.87014198], [76.5965271, 8.87014198], [76.5965271, 8.87042046], [76.59625244, 8.87041569], [76.59625244, 8.87097168], [76.5956955, 8.87097168], [76.5956955, 8.87125015], [76.59513855, 8.87125015], [76.59513855, 8.87154102], [76.59485626, 8.87154102], [76.59485626, 8.87180996], [76.5945816, 8.87180614], [76.5945816, 8.87236214], [76.59430695, 8.87236023], [76.59430695, 8.87263966], [76.59402466, 8.87263775], [76.59402466, 8.87319374], [76.59375, 8.87319374], [76.59375, 8.87347221], [76.59348297, 8.87347031], [76.59348297, 8.87374973], [76.59263611, 8.87374973], [76.59263611, 8.87403011], [76.59236145, 8.87403011], [76.59236145, 8.87431145], [76.5918045, 8.87430573], [76.5918045, 8.8745842], [76.5909729, 8.87458038], [76.5909729, 8.87486172], [76.59041595, 8.87486172], [76.59041595, 8.87514019], [76.58985138, 8.87514019], [76.58985138, 8.87542057], [76.58930206, 8.8754158], [76.58930206, 8.87569427], [76.5890274, 8.87569427], [76.5890274, 8.87597179], [76.58875275, 8.87597179], [76.58875275, 8.87625027], [76.58847046, 8.87625027], [76.58847046, 8.87652969], [76.58763885, 8.87652969], [76.58763885, 8.87681103], [76.58708191, 8.87680626], [76.58708191, 8.87708378], [76.58652496, 8.87708378], [76.58652496, 8.87736225], [76.58625031, 8.87735081], [76.58625031, 8.87763977], [76.58569336, 8.87763977], [76.58569336, 8.8779211], [76.5854187, 8.87791634], [76.5854187, 8.87819386], [76.58486176, 8.87819386], [76.58486176, 8.87847233], [76.5845871, 8.87847233], [76.5845871, 8.87874985], [76.58403778, 8.87874985], [76.58403778, 8.87903118], [76.58347321, 8.87903118], [76.58347321, 8.87931061], [76.58319092, 8.87930584], [76.58319092, 8.87958431], [76.5826416, 8.87958431], [76.5826416, 8.87985992], [76.58207703, 8.87985992], [76.58207703, 8.88014126], [76.58152771, 8.8801384], [76.58152771, 8.88041592], [76.58097076, 8.88041592], [76.58097076, 8.88069439], [76.5798645, 8.88069439], [76.5798645, 8.88097191], [76.57930756, 8.88097191], [76.57930756, 8.88125134], [76.57818604, 8.88125134], [76.57818604, 8.88152885], [76.57707977, 8.88152885], [76.57707977, 8.88181114], [76.57597351, 8.88180447], [76.57597351, 8.88208199], [76.57402802, 8.88208199], [76.57402802, 8.88236046], [76.57152557, 8.88236046], [76.57152557, 8.88208199], [76.57096863, 8.88208199], [76.57096863, 8.88180447], [76.57041931, 8.88181114], [76.57041931, 8.88152885], [76.56958008, 8.88152885], [76.56958008, 8.88125134], [76.56930542, 8.88125134], [76.56930542, 8.88097191], [76.56903076, 8.88097191], [76.56903076, 8.88069439], [76.56847382, 8.88069439], [76.56847382, 8.88041592], [76.56791687, 8.88041592], [76.56791687, 8.87985992], [76.56819153, 8.87985992], [76.56819153, 8.87930584], [76.56846619, 8.87931061], [76.56846619, 8.87903118], [76.56903076, 8.87903118], [76.56903076, 8.87874985], [76.56930542, 8.87874985], [76.56930542, 8.87847233], [76.56958008, 8.87847233], [76.56958008, 8.87819386], [76.56986237, 8.87819386], [76.56986237, 8.87791634], [76.57013702, 8.8779211], [76.57013702, 8.87763977], [76.57068634, 8.87763977], [76.57068634, 8.87735081], [76.57096863, 8.87736225], [76.57096863, 8.87708378], [76.57236481, 8.87708378], [76.57236481, 8.87680626], [76.57290649, 8.87681103], [76.57290649, 8.87652969], [76.57319641, 8.87652969], [76.57319641, 8.87625027], [76.57375336, 8.87625027], [76.57375336, 8.87597179], [76.57430267, 8.87597179], [76.57430267, 8.87569427], [76.57541656, 8.87569427], [76.57541656, 8.8754158], [76.57624817, 8.87542057], [76.57624817, 8.87514019], [76.57707977, 8.87514019], [76.57707977, 8.87486172], [76.57763672, 8.87486172], [76.57763672, 8.87458038], [76.57791901, 8.8745842], [76.57791901, 8.87430573], [76.57818604, 8.87431145], [76.57818604, 8.87403011], [76.5790329, 8.87403011], [76.5790329, 8.87374973], [76.57985687, 8.87374973], [76.57985687, 8.87347031], [76.58041382, 8.87347221], [76.58041382, 8.87319374], [76.58069611, 8.87319374], [76.58069611, 8.87291622], [76.58097076, 8.87292004], [76.58097076, 8.87263966], [76.58235931, 8.87263966], [76.58235931, 8.87236023], [76.5826416, 8.87236214], [76.5826416, 8.87208366], [76.58291626, 8.87208366], [76.58291626, 8.87180614], [76.58319092, 8.87180996], [76.58319092, 8.87154102], [76.58347321, 8.87154102], [76.58347321, 8.87014198], [76.5826416, 8.87014198], [76.5826416, 8.87042046], [76.58208466, 8.87041569], [76.58208466, 8.87069416], [76.58180237, 8.87069416], [76.58180237, 8.87097168], [76.58152771, 8.87097168], [76.58152771, 8.87125015], [76.58125305, 8.87125015], [76.58125305, 8.87154102], [76.58097076, 8.87154102], [76.58097076, 8.87180996], [76.58041382, 8.87180614], [76.58041382, 8.87208366], [76.58013916, 8.87208366], [76.58013916, 8.87236214], [76.57985687, 8.87236023], [76.57985687, 8.87263966], [76.57930756, 8.87263966], [76.57930756, 8.87292004], [76.57875061, 8.87291622], [76.57875061, 8.87319374], [76.57736206, 8.87319374], [76.57736206, 8.87347221], [76.57681274, 8.87347031], [76.57681274, 8.87374973], [76.57624817, 8.87374973], [76.57624817, 8.87403011], [76.57569122, 8.87402821], [76.57569122, 8.8745842], [76.57514191, 8.87458038], [76.57514191, 8.87486172], [76.57402802, 8.87486172], [76.57402802, 8.87514019], [76.57347107, 8.87514019], [76.57347107, 8.87542057], [76.57291412, 8.8754158], [76.57291412, 8.87569427], [76.57236481, 8.87569427], [76.57236481, 8.87597179], [76.57125092, 8.87596989], [76.57125092, 8.87652969], [76.57096863, 8.87652969], [76.57096863, 8.87681103], [76.56986237, 8.87680626], [76.56986237, 8.87708378], [76.56930542, 8.87708378], [76.56930542, 8.87736225], [76.56903076, 8.87735081], [76.56903076, 8.87763977], [76.56874847, 8.87763977], [76.56874847, 8.8779211], [76.56847382, 8.87791634], [76.56847382, 8.87819386], [76.56819153, 8.87819386], [76.56819153, 8.87847233], [76.56791687, 8.87847233], [76.56791687, 8.87874985], [76.56764221, 8.87874985], [76.56764221, 8.87903118], [76.56735992, 8.87903118], [76.56735992, 8.87931061], [76.56597137, 8.87930584], [76.56597137, 8.87958431], [76.5654068, 8.87957954], [76.5654068, 8.88014126], [76.56513977, 8.8801384], [76.56513977, 8.88069439], [76.56485748, 8.88068962], [76.56485748, 8.88152885], [76.56458282, 8.88152885], [76.56458282, 8.88208199], [76.56430817, 8.88208199], [76.56430817, 8.88236046], [76.56402588, 8.88236046], [76.56402588, 8.88264084], [76.56375122, 8.88264084], [76.56375122, 8.88292122], [76.56346893, 8.8829174], [76.56346893, 8.88319016], [76.56292725, 8.88320065], [76.56292725, 8.88348198], [76.56263733, 8.88348198], [76.56263733, 8.88375092], [76.56236267, 8.88375092], [76.56236267, 8.88431072], [76.56208038, 8.88431072], [76.56208038, 8.88541889], [76.56181335, 8.88541889], [76.56180573, 8.88624859], [76.56153107, 8.88625145], [76.56153107, 8.88654041], [76.56124878, 8.88652897], [76.56124878, 8.88708305], [76.56097412, 8.88708305], [76.56097412, 8.88736057], [76.56069183, 8.88736057], [76.56069183, 8.88764095], [76.56041718, 8.88764095], [76.56041718, 8.88791943], [76.56014252, 8.88791656], [76.56014252, 8.88819504], [76.55986786, 8.88819122], [76.55986786, 8.88875103], [76.55930328, 8.88875103], [76.55930328, 8.88903236], [76.5579071, 8.88903236], [76.5579071, 8.88931179], [76.55764008, 8.88930511], [76.55764008, 8.88986111], [76.55735779, 8.88986111], [76.55735779, 8.89014053], [76.55708313, 8.89014053], [76.55708313, 8.89042187], [76.55652618, 8.8904171], [76.55652618, 8.89069462], [76.55596924, 8.8906908], [76.55596924, 8.89153194], [76.55568695, 8.89153194], [76.55568695, 8.89181042], [76.55513763, 8.89181042], [76.55513763, 8.89153194], [76.55486298, 8.89152718], [76.55486298, 8.89208317], [76.55458069, 8.89208317], [76.55458069, 8.89236069], [76.55403137, 8.89236069], [76.55403137, 8.89319324], [76.55374146, 8.89319134], [76.55374146, 8.89402962], [76.5534668, 8.89402962], [76.5534668, 8.89431], [76.55319214, 8.89430523], [76.55319214, 8.89458275], [76.55291748, 8.89458084], [76.55291748, 8.89513969], [76.55264282, 8.89513969], [76.55264282, 8.89542007], [76.55236053, 8.89541531], [76.55236053, 8.89569569], [76.55180359, 8.89569569], [76.55180359, 8.8959713], [76.55152893, 8.8959713], [76.55152893, 8.89653015], [76.55124664, 8.89652824], [76.55124664, 8.89708424], [76.55097198, 8.89708138], [76.55097198, 8.89764023], [76.55069733, 8.89764023], [76.55069733, 8.89819431], [76.55042267, 8.89819145], [76.55042267, 8.89848137], [76.55014038, 8.89847183], [76.55014038, 8.89875031], [76.54985809, 8.89875031], [76.54985809, 8.9001379], [76.54958344, 8.9001379], [76.54958344, 8.90069389], [76.54902649, 8.90069389], [76.54902649, 8.90097237], [76.54846954, 8.90097046], [76.54846954, 8.90125179], [76.54792786, 8.90125179], [76.54792786, 8.90154171], [76.54736328, 8.90154171], [76.54736328, 8.90181065], [76.54680634, 8.90180588], [76.54680634, 8.90208435], [76.54651642, 8.90207958], [76.54652405, 8.90235996], [76.54624939, 8.90235996], [76.54624939, 8.9048624], [76.54597473, 8.9048624], [76.54597473, 8.90569401], [76.54569244, 8.90569019], [76.54569244, 8.90625], [76.54541779, 8.90625], [76.54541779, 8.90680885], [76.5451355, 8.90680599], [76.5451355, 8.90736008], [76.54486084, 8.90736008], [76.54486084, 8.90764141], [76.54458618, 8.90764141], [76.54458618, 8.90792084], [76.54430389, 8.90791607], [76.54430389, 8.90847301], [76.54402924, 8.90847015], [76.54402924, 8.90903091], [76.54374695, 8.90902901], [76.54374695, 8.90958214], [76.54347229, 8.90958214], [76.54347229, 8.90986061], [76.54319763, 8.90986061], [76.54319763, 8.91042137], [76.54292297, 8.91042137], [76.54292297, 8.91153145], [76.54264069, 8.91152668], [76.54264069, 8.91236115], [76.5423584, 8.91236115], [76.5423584, 8.91319466], [76.54207611, 8.91318989], [76.54207611, 8.91348171], [76.54180145, 8.91348171], [76.54180145, 8.91486073], [76.54152679, 8.91486073], [76.54152679, 8.91542244], [76.54125214, 8.91542244], [76.54125214, 8.91875076], [76.54096985, 8.91874886], [76.54096985, 8.9206934], [76.54070282, 8.92069054], [76.54070282, 8.92152977], [76.5404129, 8.92152977], [76.5404129, 8.92265129], [76.54070282, 8.92265129], [76.54070282, 8.92292023], [76.5404129, 8.92291546], [76.5404129, 8.92319584], [76.54070282, 8.92319107], [76.54070282, 8.92375183], [76.5404129, 8.92375183], [76.5404129, 8.9240303], [76.54013824, 8.9240303], [76.54013824, 8.92430973], [76.5404129, 8.92430592], [76.5404129, 8.92708397], [76.54013824, 8.9270792], [76.54013824, 8.92763996], [76.53985596, 8.92763996], [76.53985596, 8.92875004], [76.5395813, 8.92875004], [76.5395813, 8.92903042], [76.53930664, 8.92902756], [76.53930664, 8.92957973], [76.53930664, 8.9309721], [76.53902435, 8.9309721], [76.53902435, 8.93152809], [76.53874207, 8.93152142], [76.53874207, 8.93181133], [76.53847504, 8.93180561], [76.53847504, 8.93208218], [76.53819275, 8.93208218], [76.53819275, 8.9323597], [76.5359726, 8.9323597], [76.5359726, 8.93264008], [76.53542328, 8.93264008], [76.53542328, 8.93292141], [76.53514099, 8.93291569], [76.53514099, 8.93347168], [76.53569794, 8.93347168], [76.53569794, 8.93375015], [76.53736115, 8.93375015], [76.53736115, 8.93514061], [76.53679657, 8.93514061], [76.53679657, 8.93542099], [76.53541565, 8.93541622], [76.53541565, 8.93597317], [76.53569794, 8.93597031], [76.53569794, 8.93625069], [76.5359726, 8.93625069], [76.5359726, 8.93653107], [76.53624725, 8.93653107], [76.53624725, 8.93681145], [76.53652954, 8.93680668], [76.53652954, 8.93708324], [76.53679657, 8.93708038], [76.5368042, 8.93875122], [76.53652954, 8.93875122], [76.53652954, 8.93903065], [76.53624725, 8.93902874], [76.53624725, 8.93958282], [76.5359726, 8.93958282], [76.5359726, 8.9398613], [76.53569794, 8.9398613], [76.53569794, 8.94124889], [76.53541565, 8.94124889], [76.53541565, 8.94347095], [76.53514099, 8.94346046], [76.53514099, 8.94431019], [76.5348587, 8.94431019], [76.5348587, 8.94542027], [76.53514099, 8.9454174], [76.53514099, 8.94736099], [76.5348587, 8.94736099], [76.5348587, 8.94791985], [76.53458405, 8.94791794], [76.53458405, 8.94819641], [76.53430939, 8.94819069], [76.53430176, 8.94902992], [76.5340271, 8.94902992], [76.5340271, 8.95014191], [76.53375244, 8.95014191], [76.53375244, 8.95125198], [76.53347015, 8.95125198], [76.53347015, 8.95181274], [76.5331955, 8.95180607], [76.5331955, 8.95263767], [76.53291321, 8.952631], [76.53291321, 8.95403004], [76.53263855, 8.95402813], [76.53263855, 8.95458412], [76.53235626, 8.95457935], [76.53235626, 8.95541954], [76.5320816, 8.95541573], [76.5320816, 8.95597172], [76.53180695, 8.95597172], [76.53180695, 8.95652962], [76.53151703, 8.95652962], [76.53151703, 8.95681095], [76.53180695, 8.95680618], [76.53180695, 8.95736217], [76.53151703, 8.95736027], [76.53151703, 8.95763969], [76.53125, 8.95763779], [76.53125, 8.95819378], [76.53098297, 8.95819187], [76.53098297, 8.95875931], [76.53069305, 8.95874977], [76.53069305, 8.95958233], [76.5304184, 8.95958233], [76.5304184, 8.96125031], [76.53013611, 8.96125031], [76.53013611, 8.96181965], [76.52986145, 8.96180439], [76.52986145, 8.9626379], [76.52958679, 8.9626379], [76.52958679, 8.96347332], [76.52929688, 8.96347046], [76.52929688, 8.96403122], [76.52902985, 8.96403122], [76.52902985, 8.9651413], [76.52874756, 8.96513939], [76.52874756, 8.96625137], [76.5284729, 8.96625137], [76.5284729, 8.96652889], [76.52819824, 8.96652889], [76.52819824, 8.96680927], [76.52791595, 8.96680546], [76.52791595, 8.96819496], [76.5276413, 8.96819496], [76.5276413, 8.96847343], [76.52791595, 8.96847057], [76.52791595, 8.96875095], [76.52819824, 8.96875095], [76.52819824, 8.96958256], [76.5284729, 8.96958256], [76.5284729, 8.96986103], [76.52819824, 8.96986103], [76.52819824, 8.97042179], [76.52791595, 8.97041702], [76.52791595, 8.97097111], [76.5276413, 8.97097111], [76.5276413, 8.97153187], [76.52735901, 8.9715271], [76.52735901, 8.97208309], [76.52707672, 8.97208118], [76.52707672, 8.97264194], [76.52680206, 8.97263908], [76.52680206, 8.9734726], [76.5265274, 8.97347069], [76.5265274, 8.97402954], [76.52625275, 8.97402668], [76.52625275, 8.97569561], [76.52597046, 8.97569561], [76.52597046, 8.97597122], [76.5256958, 8.97596931], [76.5256958, 8.9762516], [76.52597046, 8.9762516], [76.52597046, 8.97653198], [76.5256958, 8.97652817], [76.5256958, 8.97819424], [76.52540588, 8.97819138], [76.52541351, 8.97875023], [76.52513885, 8.97875023], [76.52513885, 8.98013973], [76.52485657, 8.98013973], [76.52485657, 8.98181057], [76.52458191, 8.9818058], [76.52458191, 8.98235989], [76.52430725, 8.98235989], [76.52430725, 8.98292065], [76.52402496, 8.98291588], [76.52402496, 8.98375034], [76.52375793, 8.98375034], [76.52375793, 8.98402977], [76.52402496, 8.98402786], [76.52402496, 8.98458195], [76.52375793, 8.98458195], [76.52375793, 8.98570061], [76.52401733, 8.98570061], [76.52401733, 8.98624992], [76.52375793, 8.98624992], [76.52375793, 8.98681068], [76.52348328, 8.98681068], [76.52348328, 8.98764133], [76.52319336, 8.98764133], [76.52319336, 8.98931122], [76.52347565, 8.98930359], [76.52347565, 8.98958206], [76.52375793, 8.98958015], [76.52375793, 8.99014091], [76.52348328, 8.99014091], [76.52348328, 8.9904213], [76.52319336, 8.99041653], [76.52319336, 8.99097347], [76.52263641, 8.99097347], [76.52263641, 8.99236107], [76.52236176, 8.99236107], [76.52236176, 8.99292088], [76.5220871, 8.99292088], [76.5220871, 8.99403095], [76.52179718, 8.99403095], [76.52179718, 8.99430943], [76.52153015, 8.99430466], [76.52153015, 8.99625111], [76.52124786, 8.99625111], [76.52124786, 9.00013924], [76.52124786, 9.00069332], [76.52097321, 9.00069332], [76.52097321, 9.00097084], [76.52124786, 9.00097084], [76.52124786, 9.00124931], [76.52153015, 9.00124931], [76.52153015, 9.00152969], [76.52179718, 9.00152969], [76.52179718, 9.00181007], [76.5220871, 9.00180531], [76.5220871, 9.00208282], [76.52179718, 9.00208092], [76.52179718, 9.00264168], [76.52153015, 9.00264168], [76.52153015, 9.00292015], [76.52124786, 9.00291538], [76.52124786, 9.00319576], [76.52153015, 9.00319099], [76.52153015, 9.0051403], [76.5220871, 9.0051403], [76.5220871, 9.00541973], [76.52236176, 9.00541782], [76.52236176, 9.00569439], [76.52263641, 9.00569057], [76.52263641, 9.0065279], [76.52236176, 9.0065279], [76.52236176, 9.00597191], [76.5220871, 9.00597191], [76.5220871, 9.00569439], [76.52180481, 9.00569439], [76.52180481, 9.00541782], [76.52069092, 9.00541782], [76.52069092, 9.00597191], [76.52041626, 9.00597191], [76.52041626, 9.0065279], [76.5201416, 9.0065279], [76.5201416, 9.00764179], [76.51985931, 9.00763988], [76.51985931, 9.00847244], [76.51957703, 9.00846958], [76.51957703, 9.00987053], [76.51930237, 9.00987053], [76.51930237, 9.0104208], [76.51902771, 9.01041603], [76.51902771, 9.01069355], [76.51875305, 9.01069164], [76.51875305, 9.01181126], [76.51902771, 9.01180553], [76.51902771, 9.0134716], [76.51875305, 9.0134716], [76.51875305, 9.01486015], [76.51847076, 9.01486015], [76.51847076, 9.01514053], [76.51875305, 9.01514053], [76.51875305, 9.01542091], [76.51847076, 9.01541615], [76.51847076, 9.01569366], [76.51875305, 9.01569366], [76.51875305, 9.01597309], [76.51847076, 9.01597023], [76.51847076, 9.01792145], [76.51875305, 9.01791668], [76.51875305, 9.01847267], [76.51819611, 9.01847267], [76.51819611, 9.01875114], [76.51790619, 9.01875114], [76.51790619, 9.01931095], [76.5173645, 9.01930523], [76.5173645, 9.01958275], [76.51708221, 9.01957989], [76.51708221, 9.02014065], [76.51680756, 9.02014065], [76.51680756, 9.02042103], [76.5165329, 9.02042103], [76.5165329, 9.0215292], [76.51625061, 9.0215292], [76.51625061, 9.02208328], [76.51597595, 9.02208328], [76.51597595, 9.0223608], [76.51541901, 9.0223608], [76.51541901, 9.02292156], [76.51513672, 9.02291679], [76.51513672, 9.02347088], [76.51486206, 9.02347088], [76.51486206, 9.02403164], [76.51457977, 9.02402687], [76.51457977, 9.02458286], [76.51431274, 9.02458096], [76.51431274, 9.02486992], [76.51403046, 9.02486992], [76.51403046, 9.02542019], [76.51374817, 9.02541733], [76.51374817, 9.02569485], [76.51347351, 9.02569485], [76.51347351, 9.02597332], [76.51319122, 9.02597141], [76.51319122, 9.02652931], [76.51291656, 9.0265274], [76.51291656, 9.0270834], [76.51264191, 9.0270834], [76.51264191, 9.02791691], [76.51235962, 9.02791691], [76.51235962, 9.02847099], [76.51207733, 9.02847099], [76.51207733, 9.02902985], [76.51152802, 9.02902985], [76.51152802, 9.02931023], [76.51125336, 9.02930546], [76.51125336, 9.02958393], [76.51097107, 9.02958107], [76.51097107, 9.0304203], [76.51069641, 9.03041458], [76.51069641, 9.03097153], [76.51040649, 9.03097153], [76.51040649, 9.03153038], [76.51013947, 9.03152847], [76.51013947, 9.03236198], [76.50985718, 9.03236198], [76.50985718, 9.03292179], [76.50958252, 9.03291798], [76.50958252, 9.03347206], [76.50930786, 9.0334692], [76.50930786, 9.03404236], [76.5090332, 9.03404236], [76.5090332, 9.03431034], [76.50875854, 9.03431034], [76.50875854, 9.03542042], [76.50846863, 9.03541565], [76.50846863, 9.03708363], [76.50819397, 9.03708363], [76.50819397, 9.0373621], [76.50791931, 9.03736019], [76.50791931, 9.03763962], [76.50763702, 9.03763962], [76.50763702, 9.03792095], [76.50736237, 9.03791618], [76.50736237, 9.03847218], [76.50708008, 9.03847027], [76.50708008, 9.03874969], [76.50681305, 9.03874969], [76.50681305, 9.03903103], [76.50708008, 9.03902817], [76.50708008, 9.03985977], [76.50681305, 9.03985119], [76.50681305, 9.04042053], [76.50653076, 9.04041576], [76.50653076, 9.04097176], [76.50624847, 9.04096985], [76.50624847, 9.04153061], [76.50596619, 9.04153061], [76.50596619, 9.04181099], [76.50569153, 9.04180431], [76.50569153, 9.04236031], [76.50541687, 9.04236031], [76.50541687, 9.04347324], [76.50514221, 9.04347324], [76.50514221, 9.04375076], [76.50541687, 9.0437479], [76.50541687, 9.04403114], [76.50514221, 9.04403114], [76.50514221, 9.04431057], [76.50485992, 9.04431057], [76.50485992, 9.04486275], [76.5045929, 9.04486275], [76.5045929, 9.04542065], [76.50430298, 9.04542065], [76.50430298, 9.04598045], [76.50402832, 9.04597282], [76.50402832, 9.0462513], [76.50374603, 9.0462513], [76.50374603, 9.04653072], [76.50347137, 9.04653072], [76.50347137, 9.04763889], [76.50319672, 9.04763889], [76.50319672, 9.04791927], [76.50291443, 9.04791737], [76.50291443, 9.04847336], [76.50263214, 9.04847145], [76.50263214, 9.04931164], [76.50235748, 9.04931164], [76.50235748, 9.05042171], [76.50208282, 9.05041695], [76.50208282, 9.05097103], [76.50180817, 9.05097103], [76.50180817, 9.05125141], [76.50208282, 9.05125141], [76.50208282, 9.05153179], [76.50180817, 9.05153179], [76.50180817, 9.05181026], [76.50152588, 9.05180454], [76.50152588, 9.05236053], [76.50125122, 9.05236053], [76.50125122, 9.05292034], [76.50096893, 9.05291653], [76.50096893, 9.05319309], [76.50068665, 9.05319118], [76.50068665, 9.05430984], [76.50041962, 9.05430508], [76.50041962, 9.05486107], [76.50013733, 9.05486107], [76.50013733, 9.05569553], [76.49958801, 9.05569077], [76.49958801, 9.05625153], [76.49930573, 9.05624866], [76.49930573, 9.0573616], [76.49903107, 9.0573616], [76.49903107, 9.05792046], [76.49874878, 9.05791759], [76.49874878, 9.05819416], [76.49847412, 9.05819416], [76.49847412, 9.05847168], [76.49819183, 9.05847168], [76.49819183, 9.05958366], [76.49791718, 9.0595789], [76.49791718, 9.06013966], [76.49764252, 9.06013966], [76.49764252, 9.06124973], [76.49736023, 9.06124973], [76.49736023, 9.06181145], [76.4970932, 9.06181145], [76.4970932, 9.06291962], [76.49680328, 9.0629158], [76.49680328, 9.06347179], [76.49652863, 9.06347179], [76.49652863, 9.06375027], [76.49624634, 9.06375027], [76.49624634, 9.06431103], [76.49597168, 9.06430626], [76.49597168, 9.06486225], [76.49569702, 9.06486225], [76.49569702, 9.06569386], [76.4954071, 9.06569195], [76.4954071, 9.06653118], [76.49514008, 9.06653118], [76.49514008, 9.06681061], [76.49485779, 9.06680584], [76.49485779, 9.06735992], [76.49458313, 9.06735992], [76.49458313, 9.06819439], [76.49430847, 9.06819439], [76.49430847, 9.06847191], [76.49402618, 9.06847], [76.49402618, 9.06902885], [76.49375153, 9.06902885], [76.49375153, 9.06931114], [76.49346924, 9.06930447], [76.49346924, 9.06986046], [76.49318695, 9.06986046], [76.49318695, 9.07125092], [76.49291992, 9.07125092], [76.49291992, 9.07181072], [76.49263763, 9.07181072], [76.49263763, 9.07264137], [76.49208069, 9.07264137], [76.49208069, 9.07374859], [76.49180603, 9.07375145], [76.49180603, 9.07458305], [76.49153137, 9.07458019], [76.49153137, 9.07514095], [76.49124908, 9.07513905], [76.49124908, 9.07569504], [76.4909668, 9.07569027], [76.4909668, 9.07625103], [76.49069214, 9.07625103], [76.49069214, 9.07653141], [76.49041748, 9.07653141], [76.49041748, 9.07681179], [76.49014282, 9.07681179], [76.49014282, 9.07764053], [76.48986053, 9.07763863], [76.48986053, 9.07847309], [76.48958588, 9.07847309], [76.48958588, 9.07902718], [76.48930359, 9.07902718], [76.48930359, 9.08069324], [76.48902893, 9.08069324], [76.48902893, 9.08124924], [76.48874664, 9.08124924], [76.48874664, 9.08152962], [76.48847198, 9.08152962], [76.48847198, 9.08209038], [76.48819733, 9.08209038], [76.48819733, 9.08263969], [76.48791504, 9.08263969], [76.48791504, 9.08319569], [76.48764038, 9.08319569], [76.48764038, 9.0834713], [76.48735809, 9.0834713], [76.48735809, 9.08458424], [76.48707581, 9.08458138], [76.48707581, 9.08515072], [76.48680878, 9.08514023], [76.48680878, 9.08569431], [76.48652649, 9.08569145], [76.48652649, 9.08652973], [76.48625183, 9.08652973], [76.48625183, 9.08681011], [76.48596954, 9.0868063], [76.48596954, 9.08736229], [76.48568726, 9.08736038], [76.48568726, 9.08792019], [76.48542023, 9.08792019], [76.48542023, 9.08903027], [76.48513794, 9.08902836], [76.48513794, 9.08958435], [76.48486328, 9.08957863], [76.48486328, 9.09041977], [76.48430634, 9.09041977], [76.48430634, 9.09152985], [76.48402405, 9.09152794], [76.48402405, 9.09208202], [76.48374939, 9.09208202], [76.48374939, 9.09319401], [76.48319244, 9.09319401], [76.48319244, 9.09347153], [76.48291779, 9.09346962], [76.48291779, 9.09403133], [76.4826355, 9.09402847], [76.4826355, 9.09486008], [76.48291779, 9.09486008], [76.48291779, 9.09542084], [76.48264313, 9.09542084], [76.48264313, 9.09514141], [76.48208618, 9.0951376], [76.48208618, 9.09569359], [76.48180389, 9.09569359], [76.48180389, 9.09597206], [76.48152161, 9.09597015], [76.48152161, 9.09653091], [76.48124695, 9.09652901], [76.48124695, 9.09735966], [76.48097229, 9.09735966], [76.48097229, 9.09764099], [76.48069763, 9.09764099], [76.48069763, 9.09792137], [76.48042297, 9.09792137], [76.48042297, 9.09903145], [76.48014069, 9.09902668], [76.48014069, 9.09958267], [76.4798584, 9.09958267], [76.4798584, 9.10013866], [76.47958374, 9.10013866], [76.47958374, 9.10069466], [76.47930908, 9.10068989], [76.47930908, 9.10180855], [76.47902679, 9.10180855], [76.47902679, 9.10236073], [76.47875214, 9.10236073], [76.47875214, 9.1034708], [76.47846985, 9.10347271], [76.47846985, 9.10375118], [76.47820282, 9.10375118], [76.47820282, 9.10431194], [76.4779129, 9.10430527], [76.4779129, 9.10486126], [76.47763824, 9.10486126], [76.47763824, 9.10542202], [76.47736359, 9.10541725], [76.47736359, 9.10569477], [76.4770813, 9.10569096], [76.4770813, 9.10625076], [76.47680664, 9.10625076], [76.47680664, 9.10680962], [76.47651672, 9.10680962], [76.47651672, 9.10736084], [76.47624969, 9.10736084], [76.47624969, 9.10763931], [76.47597504, 9.10763931], [76.47597504, 9.1081953], [76.47569275, 9.1081953], [76.47569275, 9.10847092], [76.47541809, 9.10847092], [76.47541809, 9.10902977], [76.4751358, 9.10902977], [76.4751358, 9.11013985], [76.47458649, 9.11013985], [76.47458649, 9.11125183], [76.47429657, 9.11125183], [76.47429657, 9.1115303], [76.47402954, 9.1115303], [76.47402954, 9.11180973], [76.47374725, 9.11180592], [76.47374725, 9.11208439], [76.4734726, 9.11208439], [76.4734726, 9.11319447], [76.47319794, 9.11319447], [76.47319794, 9.11347198], [76.47292328, 9.11347198], [76.47292328, 9.11403179], [76.47264099, 9.11402798], [76.47264099, 9.11458397], [76.4723587, 9.11458397], [76.4723587, 9.1147089], [76.4723587, 9.11569405], [76.47208405, 9.11569405], [76.47208405, 9.11597157], [76.47180939, 9.11596966], [76.47180176, 9.1168108], [76.4715271, 9.11680603], [76.4715271, 9.11736202], [76.47125244, 9.11736202], [76.47125244, 9.11819363], [76.47097015, 9.11819363], [76.47097015, 9.1184721], [76.47070313, 9.11847019], [76.47070313, 9.11903], [76.47041321, 9.11902809], [76.47041321, 9.11999035], [76.47041321, 9.12014008], [76.47013855, 9.12013817], [76.47013855, 9.12068081], [76.47013855, 9.12097168], [76.47003174, 9.12097168], [76.46986389, 9.12097168], [76.46985626, 9.12137985], [76.46985626, 9.12153053], [76.4695816, 9.12152767], [76.4695816, 9.12208462], [76.46930695, 9.12207985], [76.46930695, 9.12264061], [76.46901703, 9.12264061], [76.46901703, 9.12292099], [76.46875, 9.12291622], [76.46875, 9.12347317], [76.46848297, 9.12347031], [76.46848297, 9.12403107], [76.46819305, 9.12402916], [76.46819305, 9.12458229], [76.4679184, 9.12458229], [76.4679184, 9.12486076], [76.46763611, 9.12486076], [76.46763611, 9.12597275], [76.46736145, 9.12596989], [76.46736145, 9.12653065], [76.46708679, 9.12652874], [76.46708679, 9.1273613], [76.4668045, 9.1273613], [76.4668045, 9.12819481], [76.46652985, 9.12819481], [76.46652985, 9.12847328], [76.46624756, 9.12847137], [76.46624756, 9.12903118], [76.4659729, 9.12902737], [76.4659729, 9.12958336], [76.46569824, 9.12958336], [76.46569824, 9.13013935], [76.46541595, 9.13013935], [76.46541595, 9.13069534], [76.4651413, 9.13069534], [76.4651413, 9.13125134], [76.46485901, 9.13125134], [76.46485901, 9.13181019], [76.46458435, 9.13180542], [76.46458435, 9.13236141], [76.46430206, 9.13236141], [76.46430206, 9.13292027], [76.4640274, 9.13292027], [76.4640274, 9.13319969], [76.46375275, 9.13319969], [76.46375275, 9.13402939], [76.46347809, 9.13402939], [76.46347809, 9.13513947], [76.46736145, 9.13513947], [76.46736145, 9.13541985], [76.4679184, 9.13541698], [76.4679184, 9.13569641], [76.46819305, 9.13569641], [76.46819305, 9.13597107], [76.46848297, 9.13597107], [76.46848297, 9.13653183], [76.4690094, 9.13652992], [76.46930695, 9.13653183], [76.46930695, 9.13626099], [76.46930695, 9.13513947], [76.46901703, 9.13513947], [76.46901703, 9.13486099], [76.46875, 9.13486099], [76.46875, 9.134305], [76.46848297, 9.13430977], [76.46848297, 9.13402939], [76.46819305, 9.13402939], [76.46819305, 9.13375092], [76.4679184, 9.13375092], [76.4679184, 9.13347054], [76.46763611, 9.1334734], [76.46763611, 9.13319492], [76.46708679, 9.13319969], [76.46708679, 9.13292027], [76.46679688, 9.13292027], [76.46679688, 9.13097095], [76.4679184, 9.13097095], [76.4679184, 9.13069534], [76.46930695, 9.13069534], [76.46930695, 9.13041687], [76.47070313, 9.13042164], [76.47070313, 9.13012981], [76.47097015, 9.13013935], [76.47097015, 9.12958336], [76.47125244, 9.12958336], [76.47125244, 9.12902737], [76.4715271, 9.12903118], [76.47154999, 9.12819004], [76.47180176, 9.12819481], [76.47180176, 9.12708282], [76.47208405, 9.12708282], [76.47208405, 9.12652874], [76.47125244, 9.12653065], [76.47125244, 9.12596989], [76.4715271, 9.12597275], [76.4715271, 9.12569523], [76.47264099, 9.12569523], [76.47264099, 9.12430668], [76.4723587, 9.12432003], [76.4723587, 9.12375069], [76.47207642, 9.12375069], [76.47207642, 9.12292099], [76.47264099, 9.12291622], [76.47264099, 9.12347317], [76.47292328, 9.12347031], [76.47292328, 9.12403107], [76.47319794, 9.12402916], [76.47319794, 9.12458229], [76.47651672, 9.12458038], [76.47651672, 9.12542057], [76.47624969, 9.12542057], [76.47624969, 9.12653065], [76.47598267, 9.12653065], [76.47598267, 9.12681103], [76.4734726, 9.12681103], [76.4734726, 9.12764072], [76.47374725, 9.12763882], [76.47374725, 9.12819481], [76.47402954, 9.12819481], [76.47402954, 9.12874889], [76.47429657, 9.12874889], [76.47429657, 9.12931156], [76.47458649, 9.12931156], [76.47458649, 9.13042164], [76.47429657, 9.13042164], [76.47429657, 9.13153172], [76.47486115, 9.13153172], [76.47486115, 9.13125134], [76.47624969, 9.13125134], [76.47624969, 9.13153172], [76.47651672, 9.13153172], [76.47651672, 9.13181019], [76.47680664, 9.13180542], [76.47680664, 9.13208294], [76.4770813, 9.13208294], [76.4770813, 9.1334734], [76.47736359, 9.1334734], [76.47736359, 9.13319302], [76.47763824, 9.13319969], [76.47763824, 9.13264084], [76.4779129, 9.13264084], [76.4779129, 9.13208103], [76.47819519, 9.13208294], [76.47819519, 9.13152695], [76.47846222, 9.13153172], [76.47846222, 9.13097095], [76.47875214, 9.13097095], [76.47875214, 9.12902737], [76.47902679, 9.12903118], [76.47902679, 9.12819004], [76.47930908, 9.12819481], [76.47930908, 9.12763882], [76.47957611, 9.12764072], [76.47957611, 9.12707138], [76.4798584, 9.12708282], [76.4798584, 9.12680531], [76.48042297, 9.12681103], [76.48042297, 9.12625122], [76.48124695, 9.12625122], [76.48124695, 9.12597275], [76.48180389, 9.12597275], [76.48180389, 9.12569523], [76.4826355, 9.12569523], [76.4826355, 9.12597275], [76.48291779, 9.12597275], [76.48291779, 9.12625122], [76.48319244, 9.12625122], [76.48319244, 9.12653065], [76.4834671, 9.12653065], [76.4834671, 9.12681103], [76.48374939, 9.12680531], [76.48374939, 9.1273613], [76.4834671, 9.1273613], [76.4834671, 9.12903118], [76.48319244, 9.12902737], [76.48319244, 9.12958336], [76.4834671, 9.12958145], [76.48347473, 9.12986088], [76.48319244, 9.12986088], [76.48319244, 9.13013935], [76.4834671, 9.13012981], [76.4834671, 9.13181019], [76.48374939, 9.13181019], [76.48374939, 9.13402939], [76.4834671, 9.13402939], [76.4834671, 9.13513947], [76.48319244, 9.13513947], [76.48319244, 9.13708401], [76.48374939, 9.13708401], [76.48374939, 9.13736153], [76.48401642, 9.13736153], [76.48401642, 9.13764191], [76.48430634, 9.13764191], [76.48430634, 9.13792038], [76.48458099, 9.13791847], [76.48458099, 9.13819313], [76.48486328, 9.13819313], [76.48486328, 9.13930607], [76.48458862, 9.1393013], [76.48458862, 9.14013958], [76.48430634, 9.14013958], [76.48430634, 9.14153004], [76.48401642, 9.14153004], [76.48402405, 9.14235973], [76.48374939, 9.14235973], [76.48374939, 9.14291954], [76.48347473, 9.14291573], [76.48347473, 9.1445837], [76.48319244, 9.14458179], [76.48319244, 9.14542961], [76.48347473, 9.14541626], [76.48347473, 9.14597225], [76.48319244, 9.14597225], [76.48319244, 9.14708424], [76.48291779, 9.14708042], [76.48291779, 9.14764023], [76.48264313, 9.14764023], [76.48264313, 9.14792061], [76.48236084, 9.14792061], [76.48236084, 9.14820099], [76.48208618, 9.14819431], [76.48208618, 9.14875031], [76.48236084, 9.14875031], [76.48236084, 9.14903069], [76.48180389, 9.14902782], [76.48180389, 9.14986038], [76.48152924, 9.14986038], [76.48152924, 9.15069485], [76.48124695, 9.15069485], [76.48124695, 9.15125084], [76.48097229, 9.1512394], [76.48097229, 9.15153122], [76.48069763, 9.15152645], [76.48069763, 9.1520834], [76.48041534, 9.1520834], [76.48041534, 9.15375137], [76.48069763, 9.15375137], [76.48069763, 9.15569496], [76.48042297, 9.15569019], [76.48042297, 9.15653133], [76.48014069, 9.15652657], [76.48014069, 9.15708256], [76.4798584, 9.15708256], [76.4798584, 9.15819454], [76.47958374, 9.15819454], [76.47958374, 9.15986061], [76.4798584, 9.15986061], [76.4798584, 9.16014194], [76.48014069, 9.16013908], [76.48014069, 9.16069317], [76.48042297, 9.16069126], [76.48042297, 9.16263866], [76.48014069, 9.16263866], [76.48014069, 9.1637516], [76.4798584, 9.1637516], [76.4798584, 9.16403198], [76.48014069, 9.16403198], [76.48014069, 9.16431046], [76.4798584, 9.16430569], [76.4798584, 9.16458416], [76.48014069, 9.16458416], [76.48014069, 9.16486168], [76.4798584, 9.16486168], [76.4798584, 9.16514015], [76.48014069, 9.16514015], [76.48014069, 9.16569424], [76.48042297, 9.16569138], [76.48042297, 9.16681004], [76.48097229, 9.16680622], [76.48097229, 9.16708374], [76.48180389, 9.16708374], [76.48180389, 9.16736221], [76.48236084, 9.16736031], [76.48236084, 9.16763973], [76.48430634, 9.16763973], [76.48430634, 9.16736031], [76.48486328, 9.16736221], [76.48486328, 9.16708374], [76.48542023, 9.16708374], [76.48542023, 9.16680622], [76.48819733, 9.16680622], [76.48819733, 9.16708374], [76.48847198, 9.16708374], [76.48847198, 9.16736221], [76.48874664, 9.16736031], [76.48874664, 9.16763973], [76.48902893, 9.16763973], [76.48902893, 9.16819382], [76.48930359, 9.16819382], [76.48930359, 9.16847229], [76.48958588, 9.16847229], [76.48958588, 9.16874981], [76.48986053, 9.16874981], [76.48986053, 9.16903019], [76.49013519, 9.16902828], [76.49013519, 9.16958427], [76.49041748, 9.16957855], [76.49041748, 9.17014027], [76.49013519, 9.17014027], [76.49013519, 9.17069435], [76.48847198, 9.17069435], [76.48847198, 9.17041588], [76.48792267, 9.17041969], [76.48792267, 9.17014027], [76.48735809, 9.17014027], [76.48735809, 9.16986179], [76.48680878, 9.16986179], [76.48680878, 9.16957855], [76.48625183, 9.16958427], [76.48625183, 9.1693058], [76.48568726, 9.16930962], [76.48568726, 9.16903019], [76.48513794, 9.16903019], [76.48513794, 9.16874981], [76.48236084, 9.16874981], [76.48236084, 9.16903019], [76.48179626, 9.16903019], [76.48179626, 9.16930962], [76.48152924, 9.1693058], [76.48152924, 9.16958427], [76.48124695, 9.16957855], [76.48124695, 9.16986179], [76.48097229, 9.16986179], [76.48097229, 9.17014027], [76.48069763, 9.17014027], [76.48069763, 9.17069435], [76.48041534, 9.17069435], [76.48041534, 9.17097187], [76.4798584, 9.17097187], [76.4798584, 9.17014027], [76.47957611, 9.17014027], [76.47957611, 9.16930962], [76.47930908, 9.16930962], [76.47930908, 9.16903019], [76.47902679, 9.16903019], [76.47902679, 9.16874981], [76.47846985, 9.16874981], [76.47846985, 9.16847229], [76.47819519, 9.16847229], [76.47819519, 9.1679163], [76.4779129, 9.16792011], [76.4779129, 9.16736031], [76.47680664, 9.16736221], [76.47680664, 9.16708374], [76.47624969, 9.16708374], [76.47624969, 9.16652775], [76.47569275, 9.16652966], [76.47569275, 9.1645813], [76.47541809, 9.16458416], [76.47541809, 9.16402721], [76.47569275, 9.16403198], [76.47569275, 9.16292191], [76.47598267, 9.16292191], [76.47598267, 9.15986061], [76.47624969, 9.15986061], [76.47624969, 9.15874863], [76.47651672, 9.15875053], [76.47651672, 9.15764141], [76.4770813, 9.15764141], [76.4770813, 9.15681171], [76.47735596, 9.15681171], [76.47735596, 9.15653133], [76.47763824, 9.15653133], [76.47763824, 9.15625095], [76.4779129, 9.15625095], [76.4779129, 9.15569019], [76.47819519, 9.15569496], [76.47819519, 9.15513897], [76.47846222, 9.15514088], [76.47846222, 9.15486145], [76.47875214, 9.15486145], [76.47875214, 9.15402889], [76.47846222, 9.15402889], [76.47846222, 9.15318966], [76.47819519, 9.15319538], [76.47819519, 9.15291691], [76.4779129, 9.15292072], [76.4779129, 9.15236092], [76.47763824, 9.15236092], [76.47763824, 9.1520834], [76.47736359, 9.1520834], [76.47736359, 9.14930439], [76.47763824, 9.14931107], [76.47763824, 9.14903069], [76.47735596, 9.14903069], [76.47735596, 9.14875031], [76.47763824, 9.14875031], [76.47763824, 9.14847183], [76.47736359, 9.14847183], [76.47736359, 9.14791584], [76.47680664, 9.14792061], [76.47680664, 9.14735985], [76.47569275, 9.14735985], [76.47569275, 9.14708424], [76.4751358, 9.14708424], [76.4751358, 9.14680576], [76.47486115, 9.14681053], [76.47486115, 9.14624977], [76.47429657, 9.14624977], [76.47429657, 9.14513969], [76.47402954, 9.14513969], [76.47402954, 9.14486027], [76.4743042, 9.14486217], [76.4743042, 9.1445837], [76.47402954, 9.1445837], [76.47402954, 9.14402771], [76.47429657, 9.14402962], [76.47429657, 9.14375019], [76.47402954, 9.14375019], [76.47402954, 9.14347172], [76.4743042, 9.14347172], [76.4743042, 9.1431942], [76.47402954, 9.1431942], [76.47402954, 9.14264011], [76.47374725, 9.14264011], [76.47374725, 9.14235973], [76.4734726, 9.14235973], [76.4734726, 9.14208412], [76.47319794, 9.14208412], [76.47319794, 9.14235973], [76.47291565, 9.14235973], [76.47291565, 9.14208412], [76.4715271, 9.14208412], [76.4715271, 9.14235973], [76.47070313, 9.14235973], [76.47070313, 9.14291954], [76.47041321, 9.14291573], [76.47041321, 9.14375019], [76.47013855, 9.14375019], [76.47013855, 9.1445837], [76.46985626, 9.14458179], [76.46985626, 9.14542961], [76.47041321, 9.14541626], [76.47041321, 9.14569378], [76.47097015, 9.14569378], [76.47097015, 9.14597225], [76.47070313, 9.14597034], [76.47070313, 9.14653111], [76.47041321, 9.14653111], [76.47041321, 9.14681053], [76.46875, 9.14680576], [76.46875, 9.14708424], [76.46858215, 9.14708233], [76.46819305, 9.14708042], [76.46819305, 9.14764023], [76.46848297, 9.14764023], [76.46848297, 9.14792061], [76.46819305, 9.14791584], [76.46819305, 9.14847183], [76.4679184, 9.14847183], [76.4679184, 9.14958191], [76.46763611, 9.14958477], [76.46763611, 9.15069485], [76.46736145, 9.15069485], [76.46736145, 9.15097332], [76.46708679, 9.15097332], [76.46708679, 9.1520834], [76.46736145, 9.15207958], [76.46736145, 9.15625095], [76.46763611, 9.15625095], [76.46763611, 9.15708256], [76.46736145, 9.15708256], [76.46736145, 9.15819454], [76.46708679, 9.15819454], [76.46708679, 9.15847111], [76.46652222, 9.15847111], [76.46652222, 9.15875053], [76.46624756, 9.15875053], [76.46624756, 9.15903187], [76.4659729, 9.1590271], [76.4659729, 9.16069317], [76.46569824, 9.16069317], [76.46569824, 9.1609726], [76.46541595, 9.16097069], [76.46541595, 9.16152954], [76.4651413, 9.16152668], [76.4651413, 9.16208267], [76.46485901, 9.16208267], [76.46485901, 9.16236115], [76.46457672, 9.16235924], [76.46457672, 9.16292191], [76.46430206, 9.16291809], [76.46430206, 9.16319561], [76.4640274, 9.16319561], [76.4640274, 9.16347122], [76.46375275, 9.16347122], [76.46375275, 9.1637516], [76.4631958, 9.1637516], [76.4631958, 9.16403198], [76.46263885, 9.16402721], [76.46263885, 9.16486168], [76.46180725, 9.16486168], [76.46180725, 9.16458416], [76.4604187, 9.16458416], [76.4604187, 9.16486168], [76.45986176, 9.16486168], [76.45986176, 9.16514015], [76.4595871, 9.16514015], [76.4595871, 9.16569424], [76.45930481, 9.16569424], [76.45930481, 9.16597176], [76.45903015, 9.16597366], [76.45903015, 9.16625023], [76.45874786, 9.16623974], [76.45874786, 9.16681004], [76.45847321, 9.16680622], [76.45847321, 9.16708374], [76.45791626, 9.16708088], [76.45791626, 9.16763973], [76.4576416, 9.16763973], [76.4576416, 9.16819382], [76.45791626, 9.16819382], [76.45791626, 9.16874981], [76.4576416, 9.16874981], [76.4576416, 9.16930962], [76.45735931, 9.16930962], [76.45735931, 9.16986179], [76.45707703, 9.16986179], [76.45707703, 9.17041969], [76.45680237, 9.17041588], [76.45680237, 9.17097187], [76.45652771, 9.17097187], [76.45652771, 9.17152977], [76.45625305, 9.17152786], [76.45625305, 9.17208195], [76.45597076, 9.17208195], [76.45597076, 9.17237091], [76.45569611, 9.17237091], [76.45569611, 9.17292118], [76.45540619, 9.17292118], [76.45540619, 9.17374992], [76.45513916, 9.17374992], [76.45513916, 9.17431068], [76.4548645, 9.17430592], [76.4548645, 9.17458439], [76.45458221, 9.17458439], [76.45458221, 9.17541599], [76.45430756, 9.17540932], [76.45430756, 9.17653084], [76.45402527, 9.17652893], [76.45402527, 9.17735958], [76.45375061, 9.17735958], [76.45375061, 9.17847347], [76.45347595, 9.17846966], [76.45347595, 9.17903137], [76.45318604, 9.17903137], [76.45318604, 9.18014145], [76.45291901, 9.18013859], [76.45291901, 9.18069458], [76.45263672, 9.1806879], [76.45263672, 9.18125057], [76.45236206, 9.18125057], [76.45236206, 9.18153954], [76.45207977, 9.18153954], [76.45207977, 9.18180943], [76.45153046, 9.18180466], [76.45153046, 9.18236065], [76.45124817, 9.18236065], [76.45124817, 9.18347263], [76.45069122, 9.18347073], [76.45069122, 9.18403053], [76.45041656, 9.18402672], [76.45041656, 9.18458271], [76.45014191, 9.18458271], [76.45014191, 9.18486118], [76.44985962, 9.18486118], [76.44985962, 9.18542194], [76.44930267, 9.18541718], [76.44930267, 9.18597317], [76.44902802, 9.18597126], [76.44902802, 9.18653202], [76.44875336, 9.18653202], [76.44875336, 9.18680954], [76.4484787, 9.18680954], [76.4484787, 9.18763924], [76.44819641, 9.18763924], [76.44819641, 9.18847084], [76.44790649, 9.18847084], [76.44790649, 9.18902969], [76.44763947, 9.18902683], [76.44763947, 9.18958282], [76.44735718, 9.18958092], [76.44735718, 9.19014168], [76.44708252, 9.19013977], [76.44708252, 9.19069576], [76.44680786, 9.19069576], [76.44680786, 9.19097137], [76.44652557, 9.19097137], [76.44652557, 9.19124889], [76.44625092, 9.19124889], [76.44625092, 9.19208431], [76.44596863, 9.19208145], [76.44596863, 9.1926403], [76.44568634, 9.1926403], [76.44568634, 9.19348145], [76.44541931, 9.19347191], [76.44541931, 9.19375038], [76.44513702, 9.19375038], [76.44513702, 9.19458389], [76.44486237, 9.19458199], [76.44486237, 9.19514179], [76.44458008, 9.19513988], [76.44458008, 9.19569397], [76.44430542, 9.19569588], [76.44430542, 9.19597244], [76.44403076, 9.19596958], [76.44403076, 9.19681072], [76.44374847, 9.19680595], [76.44374847, 9.19736195], [76.44347382, 9.19736195], [76.44347382, 9.19819355], [76.44319153, 9.19819164], [76.44319153, 9.19931126], [76.44291687, 9.19930553], [76.44291687, 9.19986153], [76.44264221, 9.19985962], [76.44264221, 9.20042133], [76.44235229, 9.20042133], [76.44235229, 9.20153141], [76.44208527, 9.2015276], [76.44208527, 9.20236015], [76.44180298, 9.20235062], [76.44180298, 9.20264053], [76.44208527, 9.20263767], [76.44208527, 9.20319366], [76.44180298, 9.20319366], [76.44180298, 9.20458221], [76.44152832, 9.20458031], [76.44152832, 9.20681095], [76.44125366, 9.20680523], [76.44125366, 9.20708275], [76.44152832, 9.20708275], [76.44152832, 9.20736122], [76.44124603, 9.20736122], [76.44124603, 9.20848179], [76.44097137, 9.20847321], [76.44097137, 9.2098608], [76.44069672, 9.2098608], [76.44069672, 9.21069527], [76.4404068, 9.21068954], [76.4404068, 9.21154118], [76.44013977, 9.21152687], [76.44013977, 9.21208286], [76.43985748, 9.21208286], [76.43985748, 9.21319485], [76.44013977, 9.21319485], [76.44013977, 9.21347332], [76.44069672, 9.21347141], [76.44069672, 9.21430969], [76.4404068, 9.21430969], [76.4404068, 9.21541977], [76.44013977, 9.21541977], [76.44013977, 9.21652985], [76.43985748, 9.21652699], [76.43985748, 9.2173624], [76.43958282, 9.2173624], [76.43958282, 9.21819305], [76.43930817, 9.21819305], [76.43930817, 9.21958447], [76.43958282, 9.21958065], [76.43958282, 9.22375202], [76.43985748, 9.22375202], [76.43985748, 9.22513962], [76.44013977, 9.22513962], [76.44013977, 9.22624969], [76.4404068, 9.22624969], [76.4404068, 9.23042107], [76.44013977, 9.2304163], [76.44013977, 9.23069382], [76.43958282, 9.23069382], [76.43958282, 9.23097324], [76.43819427, 9.23097324], [76.43819427, 9.23069382], [76.43708038, 9.23069382], [76.43708038, 9.23097324], [76.43624878, 9.23097324], [76.43624878, 9.23069382], [76.43541718, 9.23069382], [76.43541718, 9.2304163], [76.43152618, 9.2304163], [76.43152618, 9.23069382], [76.43125153, 9.23069382], [76.43125153, 9.23125076], [76.43096924, 9.2312479], [76.43096924, 9.23181057], [76.43069458, 9.23180676], [76.43069458, 9.23208237], [76.43041229, 9.23208046], [76.43041229, 9.2326498], [76.43013763, 9.2326498], [76.43013763, 9.23292065], [76.42986298, 9.23291683], [76.42986298, 9.2331953], [76.42903137, 9.2331953], [76.42903137, 9.23347282], [76.42874908, 9.23347282], [76.42874908, 9.23486137], [76.42847443, 9.23486137], [76.42847443, 9.23597336], [76.42819214, 9.23597145], [76.42819214, 9.23653126], [76.42791748, 9.23653126], [76.42791748, 9.23681164], [76.42763519, 9.23680496], [76.42764282, 9.23736095], [76.42735291, 9.23736095], [76.42735291, 9.23792171], [76.42708588, 9.23791695], [76.42708588, 9.23847103], [76.42680359, 9.23847103], [76.42680359, 9.23958302], [76.42652893, 9.23958111], [76.42652893, 9.24014091], [76.42624664, 9.24013901], [76.42624664, 9.24069309], [76.42597198, 9.24069118], [76.42597198, 9.24125099], [76.42569733, 9.24125099], [76.42569733, 9.24180984], [76.42541504, 9.24180508], [76.42541504, 9.24236107], [76.42514038, 9.24236107], [76.42514038, 9.24291992], [76.42485809, 9.24291706], [76.42485809, 9.24319553], [76.42457581, 9.24319077], [76.42457581, 9.24375153], [76.42430878, 9.24375153], [76.42430878, 9.24431038], [76.42402649, 9.24430466], [76.42402649, 9.2448616], [76.42375183, 9.2448616], [76.42375183, 9.24514198], [76.42346954, 9.24514198], [76.42346954, 9.24542046], [76.42319489, 9.24541759], [76.42319489, 9.24569321], [76.42263794, 9.24569321], [76.42263794, 9.24514008], [76.42236328, 9.24514198], [76.42236328, 9.2448616], [76.42208099, 9.2448616], [76.42208099, 9.24430466], [76.42180634, 9.24431038], [76.42180634, 9.24375153], [76.42124939, 9.24375153], [76.42124939, 9.24319077], [76.42097473, 9.24319553], [76.42097473, 9.24236107], [76.42069244, 9.24236107], [76.42069244, 9.2415266], [76.42097473, 9.2415266], [76.42097473, 9.24097347], [76.42124939, 9.24097347], [76.42124939, 9.24041653], [76.42151642, 9.24042034], [76.42151642, 9.24014091], [76.42180634, 9.24014091], [76.42180634, 9.23958111], [76.42208099, 9.23958302], [76.42208099, 9.23930454], [76.42236328, 9.23931026], [76.42236328, 9.23875141], [76.42263794, 9.23874855], [76.42263794, 9.23845863], [76.42292023, 9.23847103], [76.42292023, 9.23791695], [76.42318726, 9.23792171], [76.42318726, 9.23743153], [76.42346954, 9.23736095], [76.42346954, 9.23715115], [76.42346954, 9.23680496], [76.42375183, 9.23681164], [76.42375183, 9.23625088], [76.42402649, 9.23625088], [76.42402649, 9.23569012], [76.42430878, 9.23569489], [76.42430878, 9.23513889], [76.42457581, 9.23513889], [76.42457581, 9.23458004], [76.42485809, 9.2345829], [76.42485809, 9.23402882], [76.42514038, 9.23403072], [76.42514038, 9.23346996], [76.42541504, 9.23347282], [76.42541504, 9.23291683], [76.42569733, 9.23292065], [76.42569733, 9.23236275], [76.42597198, 9.23236275], [76.42597198, 9.23208046], [76.42624664, 9.23208237], [76.42624664, 9.23152637], [76.42652893, 9.23153114], [76.42652893, 9.2312479], [76.42680359, 9.23125076], [76.42680359, 9.23097324], [76.42708588, 9.23097324], [76.42708588, 9.2304163], [76.42735291, 9.23042107], [76.42735291, 9.23014069], [76.42764282, 9.23014069], [76.42764282, 9.22986031], [76.42791748, 9.22986031], [76.42791748, 9.22930431], [76.42819214, 9.22931099], [76.42819214, 9.22875023], [76.42847443, 9.22875023], [76.4284668, 9.22819042], [76.42874908, 9.22819424], [76.42874908, 9.22800064], [76.42874908, 9.22763824], [76.42903137, 9.22764015], [76.42903137, 9.22708035], [76.42930603, 9.22708416], [76.42930603, 9.22652817], [76.42958069, 9.22652817], [76.42958069, 9.22597218], [76.42986298, 9.22597218], [76.42986298, 9.2256937], [76.43013763, 9.2256937], [76.43013763, 9.22541809], [76.43041229, 9.22542095], [76.43041229, 9.22513962], [76.43068695, 9.22513962], [76.43068695, 9.22457981], [76.43096924, 9.22458363], [76.43096924, 9.22430611], [76.43068695, 9.22431087], [76.43068695, 9.22402954], [76.43096924, 9.22402954], [76.43096924, 9.22292042], [76.43125153, 9.22292042], [76.43125153, 9.22207928], [76.43152618, 9.22208405], [76.43152618, 9.22180557], [76.43180847, 9.22181034], [76.43180847, 9.22124958], [76.43208313, 9.22124958], [76.43208313, 9.22042179], [76.43180847, 9.22042179], [76.43180847, 9.22014046], [76.43152618, 9.22014046], [76.43152618, 9.2193079], [76.43180847, 9.2193079], [76.43180847, 9.21903038], [76.43208313, 9.21903038], [76.43208313, 9.21875191], [76.43235779, 9.21875191], [76.43235779, 9.21819115], [76.43264008, 9.21819305], [76.43264008, 9.21763992], [76.4329071, 9.21764183], [76.4329071, 9.2173624], [76.43319702, 9.2173624], [76.43319702, 9.21680546], [76.43347931, 9.21681023], [76.43347931, 9.21624947], [76.43374634, 9.21624947], [76.43374634, 9.21569538], [76.43402863, 9.21569538], [76.43402863, 9.21513939], [76.43430328, 9.21513939], [76.43430328, 9.21458054], [76.43458557, 9.2145834], [76.43458557, 9.2140274], [76.43486023, 9.21402931], [76.43486023, 9.21319103], [76.43514252, 9.21319485], [76.43514252, 9.21236134], [76.43541718, 9.21236134], [76.43541718, 9.21180534], [76.43569183, 9.21181202], [76.43569183, 9.21125126], [76.43597412, 9.21125126], [76.43596649, 9.21042156], [76.43624878, 9.21042156], [76.43624878, 9.20958138], [76.43597412, 9.20958328], [76.43597412, 9.20874882], [76.43624878, 9.20875072], [76.43624878, 9.20848179], [76.43596649, 9.20848179], [76.43596649, 9.20818996], [76.43624878, 9.20819473], [76.43624878, 9.20680523], [76.4365387, 9.20681095], [76.4365387, 9.20625114], [76.43680573, 9.20625114], [76.43680573, 9.20597267], [76.43708038, 9.20597267], [76.43708038, 9.20541668], [76.43736267, 9.20542145], [76.43736267, 9.20485973], [76.43763733, 9.20485973], [76.43763733, 9.20458221], [76.43791962, 9.20458221], [76.43791962, 9.20402908], [76.43846893, 9.20403099], [76.43846893, 9.20181084], [76.43875122, 9.20181084], [76.43875122, 9.20069027], [76.43902588, 9.20069408], [76.43902588, 9.19902802], [76.43930817, 9.19902992], [76.43930817, 9.19654179], [76.43958282, 9.19654179], [76.43958282, 9.19624996], [76.43930817, 9.19624996], [76.43930817, 9.1956892], [76.43958282, 9.19569397], [76.43958282, 9.19541645], [76.43985748, 9.19542027], [76.43985748, 9.19458199], [76.44013977, 9.19458389], [76.44013977, 9.19319439], [76.44069672, 9.19319439], [76.44069672, 9.1926403], [76.4404068, 9.1926403], [76.4404068, 9.19208145], [76.44013977, 9.19208431], [76.44013977, 9.19152832], [76.43985748, 9.19153023], [76.43985748, 9.19097137], [76.43958282, 9.19097137], [76.43958282, 9.19013977], [76.43985748, 9.19014168], [76.43985748, 9.18958092], [76.44013977, 9.18958282], [76.44013977, 9.18930531], [76.4404068, 9.18931007], [76.4404068, 9.18902969], [76.44097137, 9.18902969], [76.44097137, 9.18874931], [76.44125366, 9.18874931], [76.44124603, 9.18847084], [76.44152832, 9.18847084], [76.44152832, 9.18819523], [76.44180298, 9.18819523], [76.44180298, 9.18791676], [76.44235229, 9.18791962], [76.44235229, 9.18708134], [76.44264221, 9.18708324], [76.44264221, 9.18680477], [76.44291687, 9.18680954], [76.44291687, 9.18653202], [76.44319153, 9.18653202], [76.44319153, 9.18625069], [76.44346619, 9.18625069], [76.44346619, 9.18597126], [76.44403076, 9.18597317], [76.44403076, 9.18569469], [76.44430542, 9.18569469], [76.44430542, 9.18541718], [76.44458008, 9.18542194], [76.44458008, 9.18514061], [76.44486237, 9.18514061], [76.44486237, 9.18486118], [76.44541931, 9.18486118], [76.44541931, 9.18458271], [76.44569397, 9.18458271], [76.44569397, 9.18430519], [76.44596863, 9.18431187], [76.44596863, 9.18403053], [76.44625092, 9.18403053], [76.44625092, 9.18319035], [76.44652557, 9.18319511], [76.44652557, 9.18236065], [76.44680786, 9.18236065], [76.44680786, 9.18180466], [76.44708252, 9.18180943], [76.44708252, 9.18153954], [76.44735718, 9.18153954], [76.44735718, 9.18125057], [76.44763947, 9.18125057], [76.44763947, 9.18097115], [76.44791412, 9.18097305], [76.44791412, 9.18069458], [76.44819641, 9.18069458], [76.44819641, 9.18041706], [76.4484787, 9.18042088], [76.4484787, 9.18014145], [76.44875336, 9.18014145], [76.44875336, 9.17986107], [76.44902802, 9.17986107], [76.44902802, 9.1795826], [76.44930267, 9.1795826], [76.44930267, 9.17930698], [76.44957733, 9.17930889], [76.44957733, 9.17903137], [76.44985962, 9.17903137], [76.44985962, 9.17875099], [76.45014191, 9.17875099], [76.45014191, 9.17846966], [76.45153046, 9.17847347], [76.45153046, 9.17791653], [76.45181274, 9.1779213], [76.45181274, 9.17708015], [76.45207977, 9.17708206], [76.45207977, 9.17513847], [76.45236206, 9.17514133], [76.45236206, 9.17457962], [76.45263672, 9.17458439], [76.45263672, 9.1740284], [76.45291901, 9.17403126], [76.45291901, 9.17374992], [76.45318604, 9.17374992], [76.45318604, 9.17319202], [76.45347595, 9.17319393], [76.45347595, 9.17291641], [76.45375061, 9.17292118], [76.45375061, 9.17237091], [76.45430756, 9.17237091], [76.45430756, 9.17208195], [76.45458221, 9.17208195], [76.45458221, 9.17097187], [76.4548645, 9.17097187], [76.4548645, 9.16985989], [76.45513916, 9.16986179], [76.45513916, 9.16930962], [76.45540619, 9.16930962], [76.45540619, 9.16874981], [76.45569611, 9.16874981], [76.45569611, 9.16819382], [76.45597076, 9.16819382], [76.45597076, 9.16763973], [76.45625305, 9.16763973], [76.45625305, 9.16652966], [76.45597076, 9.16652966], [76.45597076, 9.16623974], [76.45625305, 9.16625023], [76.45625305, 9.16597176], [76.45652771, 9.16597176], [76.45652771, 9.16569424], [76.45680237, 9.16569424], [76.45680237, 9.16541767], [76.45707703, 9.16541958], [76.45707703, 9.16514015], [76.45735931, 9.16514015], [76.45735931, 9.16486168], [76.4576416, 9.16486168], [76.4576416, 9.16458416], [76.45791626, 9.16458416], [76.45791626, 9.16347122], [76.45819092, 9.16347122], [76.45819092, 9.16263866], [76.45791626, 9.16263866], [76.45791626, 9.16208076], [76.4576416, 9.16208267], [76.4576416, 9.16180515], [76.45735931, 9.16180992], [76.45735931, 9.16125107], [76.45680237, 9.16125107], [76.45680237, 9.16097069], [76.45652771, 9.16097069], [76.45652771, 9.16125107], [76.45625305, 9.16125107], [76.45625305, 9.16152954], [76.45540619, 9.16152954], [76.45540619, 9.16125107], [76.45485687, 9.16125107], [76.45485687, 9.16097069], [76.45458221, 9.1609726], [76.45458221, 9.16069317], [76.45430756, 9.16069317], [76.45430756, 9.15847111], [76.4548645, 9.15847111], [76.4548645, 9.15819454], [76.45513916, 9.15819454], [76.45513916, 9.15791702], [76.45540619, 9.15792179], [76.45540619, 9.15764141], [76.45569611, 9.15764141], [76.45569611, 9.15708065], [76.45597076, 9.15708256], [76.45597076, 9.15625095], [76.45652771, 9.15625095], [76.45652771, 9.15597057], [76.4576416, 9.15597057], [76.4576416, 9.15625095], [76.45791626, 9.15625095], [76.45791626, 9.15681171], [76.45847321, 9.15680504], [76.45847321, 9.15847111], [76.45874786, 9.15847111], [76.45874786, 9.15931034], [76.45903015, 9.15930462], [76.45903015, 9.15986061], [76.4595871, 9.15986061], [76.4595871, 9.16014194], [76.45986176, 9.16014194], [76.45986176, 9.15986061], [76.46013641, 9.15986061], [76.46013641, 9.15958309], [76.4604187, 9.15958309], [76.4604187, 9.1590271], [76.46098328, 9.15903187], [76.46098328, 9.15850067], [76.46097565, 9.15763855], [76.46125031, 9.15764141], [76.46125031, 9.15681171], [76.46151733, 9.15681171], [76.46151733, 9.15625095], [76.46180725, 9.15625095], [76.46180725, 9.15597057], [76.46208191, 9.15597343], [76.46208191, 9.15513897], [76.46235657, 9.15514088], [76.46235657, 9.15486145], [76.46263885, 9.15486145], [76.46263885, 9.15430546], [76.46291351, 9.15430546], [76.46291351, 9.15402889], [76.4631958, 9.15402889], [76.4631958, 9.15375137], [76.46347046, 9.15375137], [76.46347046, 9.1520834], [76.4631958, 9.1520834], [76.4631958, 9.15152645], [76.4640274, 9.15153122], [76.4640274, 9.15097046], [76.46430206, 9.15097332], [76.46430206, 9.15041637], [76.46457672, 9.15042114], [76.46457672, 9.14986038], [76.46485901, 9.14986038], [76.46485901, 9.14930439], [76.4651413, 9.14931107], [76.4651413, 9.14820099], [76.46569061, 9.14820099], [76.46569061, 9.14792061], [76.46541595, 9.14792061], [76.46541595, 9.14735985], [76.46569061, 9.14735985], [76.46569824, 9.14680576], [76.4659729, 9.14681053], [76.4659729, 9.14597034], [76.46624756, 9.14597225], [76.46624756, 9.14513779], [76.46652222, 9.14513969], [76.46652222, 9.14458179], [76.4668045, 9.1445837], [76.4668045, 9.14375019], [76.46708679, 9.14375019], [76.46708679, 9.1431942], [76.46736145, 9.1431942], [76.46736145, 9.14291573], [76.4679184, 9.14291954], [76.4679184, 9.14235973], [76.46763611, 9.14235973], [76.46763611, 9.14180565], [76.4679184, 9.14181042], [76.4679184, 9.14124966], [76.46736145, 9.14124966], [76.46736145, 9.14096928], [76.4668045, 9.14097214], [76.4668045, 9.14069366], [76.46624756, 9.14069366], [76.46624756, 9.14041805], [76.4659729, 9.14041805], [76.4659729, 9.14069366], [76.46541595, 9.14069366], [76.46541595, 9.14097214], [76.46485901, 9.14096928], [76.46485901, 9.14124966], [76.46347809, 9.14124966], [76.46347809, 9.14096928], [76.46291351, 9.14097214], [76.46291351, 9.14069366], [76.46208191, 9.14069366], [76.46208191, 9.14013767], [76.46180725, 9.14013958], [76.46180725, 9.13958073], [76.46125031, 9.13958359], [76.46125031, 9.13986206], [76.46151733, 9.13986015], [76.46151733, 9.14041996], [76.46097565, 9.14041805], [76.46097565, 9.14069366], [76.4604187, 9.1406889], [76.4604187, 9.14181042], [76.46013641, 9.14180565], [76.46013641, 9.14235973], [76.46002197, 9.14235973], [76.45986176, 9.14235973], [76.45986176, 9.14291954], [76.4595871, 9.14291573], [76.4595871, 9.14347172], [76.45929718, 9.14346981], [76.45929718, 9.14402962], [76.45903015, 9.14402771], [76.45903015, 9.1445837], [76.45874786, 9.1445837], [76.45874786, 9.14569378], [76.45847321, 9.14569187], [76.45847321, 9.14653111], [76.45819092, 9.14652824], [76.45819092, 9.14708424], [76.45791626, 9.14708042], [76.45791626, 9.14792061], [76.4576416, 9.14792061], [76.4576416, 9.14820099], [76.45735931, 9.14819431], [76.45735931, 9.14875031], [76.45708466, 9.14875031], [76.45708466, 9.14986038], [76.45680237, 9.14986038], [76.45680237, 9.1501379], [76.45652771, 9.1501379], [76.45652771, 9.15069485], [76.45625305, 9.15069485], [76.45625305, 9.15125084], [76.45597076, 9.1512394], [76.45597076, 9.15153122], [76.45625305, 9.15153122], [76.45625305, 9.15181065], [76.45597076, 9.15181065], [76.45597076, 9.1526413], [76.45569611, 9.1526413], [76.45569611, 9.15292072], [76.45541382, 9.15291691], [76.45541382, 9.15319538], [76.45513916, 9.15319538], [76.45513916, 9.15375137], [76.4548645, 9.15375137], [76.4548645, 9.15430546], [76.45458221, 9.15430546], [76.45458221, 9.15458298], [76.45430756, 9.15458012], [76.45430756, 9.15514088], [76.4540329, 9.15514088], [76.4540329, 9.15625095], [76.45375061, 9.15625095], [76.45375061, 9.15681171], [76.45347595, 9.15680504], [76.45347595, 9.15708256], [76.45318604, 9.15708065], [76.45318604, 9.15764141], [76.45291901, 9.15764141], [76.45291901, 9.15792179], [76.45263672, 9.15791702], [76.45263672, 9.15847111], [76.45236206, 9.15847111], [76.45236206, 9.15931034], [76.45207977, 9.15930462], [76.45207977, 9.15958309], [76.45180511, 9.15958309], [76.45180511, 9.16069317], [76.45153809, 9.16069126], [76.45153809, 9.16125107], [76.45124817, 9.16124916], [76.45124817, 9.16208267], [76.45096588, 9.16208076], [76.45096588, 9.16263866], [76.45069122, 9.16263866], [76.45069122, 9.16319561], [76.45041656, 9.16319561], [76.45041656, 9.16347122], [76.45014191, 9.16347122], [76.45014191, 9.16403198], [76.44985962, 9.16402721], [76.44985962, 9.16458416], [76.44957733, 9.1645813], [76.44958496, 9.16486168], [76.44930267, 9.16486168], [76.44930267, 9.16541958], [76.44902802, 9.16541958], [76.44902802, 9.16652966], [76.44875336, 9.16652775], [76.44875336, 9.16708374], [76.4484787, 9.16708088], [76.4484787, 9.16763973], [76.44819641, 9.16763973], [76.44819641, 9.16792011], [76.44763947, 9.1679163], [76.44763947, 9.16819382], [76.44791412, 9.16819382], [76.44791412, 9.16847229], [76.44763947, 9.16847229], [76.44763947, 9.16874981], [76.44736481, 9.16874981], [76.44736481, 9.16958427], [76.44708252, 9.16957855], [76.44708252, 9.17041969], [76.44652557, 9.17041588], [76.44652557, 9.17097187], [76.44625092, 9.17097187], [76.44625092, 9.1718111], [76.44596863, 9.1718111], [76.44596863, 9.17237091], [76.44568634, 9.17237091], [76.44568634, 9.17292118], [76.44541931, 9.17291641], [76.44541931, 9.17319393], [76.44569397, 9.17319393], [76.44569397, 9.1734724], [76.44541931, 9.17346954], [76.44541931, 9.17374992], [76.44513702, 9.17374992], [76.44513702, 9.17431068], [76.44486237, 9.17430592], [76.44486237, 9.17486], [76.44458008, 9.17486], [76.44458008, 9.17541599], [76.44430542, 9.17541599], [76.44430542, 9.17625046], [76.44403076, 9.17625046], [76.44403076, 9.17681122], [76.44374847, 9.1768074], [76.44374847, 9.17735958], [76.44346619, 9.17735958], [76.44346619, 9.1779213], [76.44319153, 9.17791653], [76.44319153, 9.178195], [76.44291687, 9.17818069], [76.44291687, 9.17903137], [76.44264221, 9.17902565], [76.44264221, 9.17986107], [76.44235229, 9.17986107], [76.44235229, 9.18042088], [76.4420929, 9.18042088], [76.4420929, 9.18125057], [76.44180298, 9.18125057], [76.44180298, 9.18264103], [76.44152832, 9.18263912], [76.44152832, 9.18375111], [76.44124603, 9.18375111], [76.44124603, 9.18431187], [76.44097137, 9.18430519], [76.44097137, 9.18458271], [76.44069672, 9.18458271], [76.44069672, 9.18486118], [76.44041443, 9.18486118], [76.44041443, 9.18597317], [76.43985748, 9.18597126], [76.43985748, 9.18653202], [76.43958282, 9.18652725], [76.43958282, 9.18708324], [76.43930817, 9.18708134], [76.43930817, 9.18763924], [76.43875122, 9.18763924], [76.43875122, 9.18819523], [76.43846893, 9.18819523], [76.43846893, 9.18874931], [76.43819427, 9.18874931], [76.43819427, 9.18958282], [76.43791962, 9.18958092], [76.43791962, 9.19014168], [76.43763733, 9.19013977], [76.43763733, 9.19124889], [76.43736267, 9.19124889], [76.43736267, 9.19180965], [76.43708038, 9.19180965], [76.43708038, 9.1926403], [76.43680573, 9.1926403], [76.43680573, 9.19319439], [76.4365387, 9.19319057], [76.4365387, 9.19348145], [76.43624878, 9.19347191], [76.43624878, 9.19375038], [76.43597412, 9.19375038], [76.43597412, 9.19458389], [76.43569183, 9.19458199], [76.43569183, 9.19514179], [76.43541718, 9.19514179], [76.43541718, 9.19624996], [76.43514252, 9.19624996], [76.43514252, 9.19654179], [76.43486023, 9.19654179], [76.43486023, 9.19764042], [76.43458557, 9.19763756], [76.43458557, 9.19819355], [76.43430328, 9.19819164], [76.43430328, 9.19874954], [76.43402863, 9.19874954], [76.43402863, 9.1995821], [76.43374634, 9.1995821], [76.43374634, 9.20069408], [76.43347931, 9.20069027], [76.43347931, 9.20125008], [76.43319702, 9.20125008], [76.43319702, 9.20153141], [76.4329071, 9.20153141], [76.4329071, 9.20375061], [76.43264008, 9.20375061], [76.43264008, 9.20431137], [76.43235779, 9.2043066], [76.43235779, 9.20458221], [76.43208313, 9.20458031], [76.43208313, 9.20514107], [76.43152618, 9.20513916], [76.43152618, 9.20569515], [76.43125153, 9.20569038], [76.43125153, 9.20653057], [76.43096924, 9.20652866], [76.43096924, 9.20708275], [76.43068695, 9.20707989], [76.43068695, 9.20792103], [76.43041229, 9.20792103], [76.43041229, 9.20848179], [76.43013763, 9.20848179], [76.43013763, 9.20931244], [76.42986298, 9.20930481], [76.42986298, 9.2098608], [76.42958069, 9.2098608], [76.42958069, 9.21042156], [76.42930603, 9.21041679], [76.42930603, 9.21097088], [76.42903137, 9.21097088], [76.42903137, 9.21154118], [76.42891693, 9.21152687], [76.42874908, 9.21152687], [76.42874908, 9.21208286], [76.4284668, 9.21208096], [76.4284668, 9.21264076], [76.42819214, 9.21263885], [76.42819214, 9.21319485], [76.42791748, 9.21319103], [76.42791748, 9.21402931], [76.42735291, 9.21402931], [76.42735291, 9.21513939], [76.42708588, 9.21513939], [76.42708588, 9.21569538], [76.42679596, 9.21569061], [76.42680359, 9.21624947], [76.42652893, 9.21624947], [76.42652893, 9.21652985], [76.42624664, 9.21652699], [76.42624664, 9.21708298], [76.42597198, 9.21708107], [76.42597198, 9.2179203], [76.42569733, 9.2179184], [76.42569733, 9.21819305], [76.42541504, 9.21819305], [76.42541504, 9.21847057], [76.42514038, 9.21847057], [76.42514038, 9.21903038], [76.42485809, 9.21902847], [76.42485809, 9.21986198], [76.42457581, 9.21986198], [76.42457581, 9.22042179], [76.42430878, 9.22041798], [76.42430878, 9.22097206], [76.42402649, 9.2209692], [76.42402649, 9.22152996], [76.42375183, 9.22152805], [76.42375183, 9.22236156], [76.42346954, 9.22235966], [76.42346954, 9.22292042], [76.42318726, 9.22292042], [76.42318726, 9.22348118], [76.42292023, 9.22348118], [76.42292023, 9.22431087], [76.42263794, 9.22430611], [76.42263794, 9.2248621], [76.42236328, 9.22486019], [76.42236328, 9.22542095], [76.42208099, 9.22542095], [76.42208099, 9.22624969], [76.42180634, 9.22624969], [76.42180634, 9.22681141], [76.42151642, 9.22681141], [76.42152405, 9.22735977], [76.42124939, 9.22735977], [76.42124939, 9.22792053], [76.42097473, 9.22791576], [76.42097473, 9.22847176], [76.42069244, 9.22846985], [76.42069244, 9.22903061], [76.42041779, 9.22902775], [76.42041779, 9.22986031], [76.42014313, 9.22986031], [76.42014313, 9.23042107], [76.41986084, 9.2304163], [76.41986084, 9.23097324], [76.41958618, 9.23097038], [76.41958618, 9.23153114], [76.41930389, 9.23152924], [76.41930389, 9.23208237], [76.41902924, 9.23208046], [76.41902924, 9.23292065], [76.41874695, 9.23291683], [76.41874695, 9.23347282], [76.41847229, 9.23346996], [76.41847229, 9.23403072], [76.41819763, 9.23402882], [76.41819763, 9.2345829], [76.41792297, 9.23458004], [76.41792297, 9.23513889], [76.41764069, 9.23513889], [76.41764069, 9.23569489], [76.4173584, 9.23569012], [76.4173584, 9.23653126], [76.41708374, 9.23652744], [76.41708374, 9.23708344], [76.41680908, 9.23708057], [76.41680908, 9.23764133], [76.41652679, 9.23763943], [76.41652679, 9.23819542], [76.41625214, 9.23819542], [76.41625214, 9.23875141], [76.41596985, 9.23875141], [76.41596985, 9.23931026], [76.41569519, 9.23930454], [76.41569519, 9.23986053], [76.4154129, 9.23986053], [76.4154129, 9.24042034], [76.41513824, 9.24041653], [76.41513824, 9.24069309], [76.41486359, 9.24069309], [76.41486359, 9.2415266], [76.4145813, 9.2415266], [76.4145813, 9.24183941], [76.4145813, 9.2420826], [76.41430664, 9.24208069], [76.41430664, 9.24263859], [76.41402435, 9.24263859], [76.41402435, 9.24319553], [76.41374969, 9.24319077], [76.41374969, 9.24375153], [76.41348267, 9.24375153], [76.41348267, 9.24458981], [76.41319275, 9.24458981], [76.41319275, 9.24514198], [76.41291809, 9.24514008], [76.41291809, 9.24569321], [76.4126358, 9.24569321], [76.4126358, 9.24625015], [76.41236877, 9.24625015], [76.41236877, 9.24680996], [76.41208649, 9.24680614], [76.41208649, 9.24708366], [76.4118042, 9.24708366], [76.4118042, 9.24819374], [76.41152954, 9.24819374], [76.41152954, 9.24847221], [76.41124725, 9.24846935], [76.41124725, 9.24874973], [76.4109726, 9.24874973], [76.4109726, 9.24903011], [76.41069794, 9.24902821], [76.41069794, 9.25097179], [76.41041565, 9.25097179], [76.41041565, 9.25125027], [76.41014099, 9.25125027], [76.41014099, 9.25152969], [76.4098587, 9.25152779], [76.4098587, 9.25208378], [76.40958405, 9.25208378], [76.40958405, 9.25236225], [76.40930939, 9.25236034], [76.40930939, 9.2529211], [76.4090271, 9.2529211], [76.4090271, 9.25403118], [76.40875244, 9.25402832], [76.40875244, 9.25458431], [76.40847015, 9.25457954], [76.40847015, 9.2551403], [76.4081955, 9.2551403], [76.4081955, 9.25569439], [76.40791321, 9.25569439], [76.40791321, 9.25625038], [76.40763855, 9.25625038], [76.40763855, 9.25681973], [76.40736389, 9.25680733], [76.40736389, 9.25708199], [76.4070816, 9.25708008], [76.4070816, 9.25764084], [76.40680695, 9.25764084], [76.40680695, 9.2590313], [76.40624237, 9.2590313], [76.40624237, 9.2595892], [76.40598297, 9.2595892], [76.40598297, 9.26014137], [76.40569305, 9.26014137], [76.40569305, 9.26041889], [76.40625, 9.26041698], [76.40625, 9.26069546], [76.40598297, 9.26068974], [76.40597534, 9.26124859], [76.40569305, 9.26125145], [76.40569305, 9.26180935], [76.4054184, 9.26180458], [76.4054184, 9.26236057], [76.40513611, 9.26236057], [76.40513611, 9.26292133], [76.40486145, 9.26291656], [76.40486145, 9.26347256], [76.40458679, 9.26347065], [76.40458679, 9.26403141], [76.4043045, 9.26402664], [76.4043045, 9.26458263], [76.40402985, 9.26458073], [76.40402985, 9.26514053], [76.40374756, 9.26513863], [76.40374756, 9.26569462], [76.4034729, 9.2656908], [76.4034729, 9.26625061], [76.40319824, 9.26625061], [76.40319824, 9.26681042], [76.40291595, 9.2668047], [76.40291595, 9.26736069], [76.4026413, 9.26736069], [76.4026413, 9.26791954], [76.40235901, 9.26791668], [76.40235901, 9.26847267], [76.40207672, 9.26847076], [76.40207672, 9.26902962], [76.40180206, 9.26902676], [76.40180206, 9.26958275], [76.4015274, 9.26958084], [76.4015274, 9.2701416], [76.40125275, 9.27013874], [76.40125275, 9.27069569], [76.40097046, 9.27069092], [76.40097046, 9.27125168], [76.4006958, 9.27124882], [76.4006958, 9.27208424], [76.40040588, 9.27208138], [76.40040588, 9.27264023], [76.40013885, 9.27264023], [76.40013885, 9.27347183], [76.39985657, 9.27347183], [76.39985657, 9.27402973], [76.39958191, 9.27402782], [76.39958191, 9.27486229], [76.39930725, 9.27486038], [76.39930725, 9.27542019], [76.39901733, 9.27542019], [76.39901733, 9.27625179], [76.39875031, 9.27625179], [76.39875031, 9.27680969], [76.39847565, 9.27680588], [76.39847565, 9.27763844], [76.39819336, 9.27764034], [76.39819336, 9.27819443], [76.3979187, 9.27819157], [76.3979187, 9.27902985], [76.39763641, 9.27902794], [76.39763641, 9.27958202], [76.39736938, 9.27958202], [76.39736938, 9.28013992], [76.3970871, 9.28013992], [76.3970871, 9.28070068], [76.39679718, 9.28070068], [76.39679718, 9.28125], [76.39653015, 9.28125], [76.39653015, 9.28180885], [76.39624786, 9.28180599], [76.39624786, 9.28236008], [76.39597321, 9.28236008], [76.39597321, 9.28319359], [76.39569092, 9.28318977], [76.39569092, 9.28376198], [76.39541626, 9.28374958], [76.39541626, 9.28458214], [76.3951416, 9.28458023], [76.3951416, 9.28514099], [76.39485931, 9.28514099], [76.39485931, 9.28542137], [76.39458466, 9.2854166], [76.39458466, 9.28569508], [76.39430237, 9.28569508], [76.39430237, 9.2859726], [76.39402771, 9.28596973], [76.39402771, 9.28653145], [76.39375305, 9.28652859], [76.39375305, 9.28708267], [76.39347076, 9.2870779], [76.39347076, 9.28764057], [76.39319611, 9.28764057], [76.39319611, 9.28792095], [76.39291382, 9.28791714], [76.39291382, 9.28847313], [76.39263916, 9.28847122], [76.39263916, 9.28875065], [76.39290619, 9.28875065], [76.39290619, 9.28931236], [76.39263916, 9.28930473], [76.39263916, 9.28986073], [76.39235687, 9.28986073], [76.39235687, 9.29042053], [76.39208221, 9.29041672], [76.39208221, 9.29125118], [76.39180756, 9.29125118], [76.39180756, 9.29181194], [76.39152527, 9.29180527], [76.39152527, 9.29236126], [76.39125061, 9.29236126], [76.39125061, 9.29319477], [76.39097595, 9.29319096], [76.39097595, 9.29375076], [76.39068604, 9.29375076], [76.39068604, 9.29430962], [76.39041901, 9.29430962], [76.39041901, 9.29513931], [76.39013672, 9.29513931], [76.39013672, 9.29570007], [76.38986206, 9.2956953], [76.38986206, 9.29624939], [76.38957977, 9.29624939], [76.38957977, 9.2970829], [76.38931274, 9.29708099], [76.38931274, 9.29763985], [76.38903046, 9.29763985], [76.38903046, 9.29819584], [76.38874817, 9.29819584], [76.38874817, 9.29874897], [76.38846588, 9.29874039], [76.38846588, 9.29930973], [76.38819122, 9.29930592], [76.38819122, 9.29986191], [76.38791656, 9.29986191], [76.38791656, 9.3004179], [76.38764191, 9.3004179], [76.38764191, 9.30097198], [76.38735962, 9.30097198], [76.38735962, 9.30153179], [76.38708496, 9.30152798], [76.38708496, 9.30208397], [76.38680267, 9.3020792], [76.38680267, 9.30263996], [76.38625336, 9.30263996], [76.38619232, 9.30294514], [76.38597107, 9.30291557], [76.38597107, 9.30318928], [76.38625336, 9.30325794], [76.38625336, 9.30347157], [76.38597107, 9.30346966], [76.38597107, 9.30375004], [76.38569641, 9.30375004], [76.38569641, 9.3043108], [76.38540649, 9.3043108], [76.38541412, 9.30486202], [76.38513947, 9.30486202], [76.38513947, 9.30541992], [76.38486481, 9.30541801], [76.38486481, 9.30569363], [76.38458252, 9.30568886], [76.38458252, 9.30653], [76.38430786, 9.30652809], [76.38430786, 9.3073597], [76.3840332, 9.3073597], [76.3840332, 9.30764008], [76.38375092, 9.30763817], [76.38375092, 9.30819416], [76.38346863, 9.30819416], [76.38346863, 9.30847168], [76.38318634, 9.30846977], [76.38318634, 9.30903053], [76.38291931, 9.30902767], [76.38291931, 9.30986023], [76.38236237, 9.30986023], [76.38236237, 9.31014061], [76.38208008, 9.31013775], [76.38208008, 9.31097221], [76.38181305, 9.31097031], [76.38181305, 9.31125069], [76.38153076, 9.31125069], [76.38153076, 9.31153107], [76.38124847, 9.31152916], [76.38124847, 9.31208229], [76.38096619, 9.31208038], [76.38096619, 9.31264114], [76.38124847, 9.31264114], [76.38124847, 9.31403065], [76.38097382, 9.31402874], [76.38097382, 9.3148613], [76.38069153, 9.3148613], [76.38069153, 9.31569481], [76.38041687, 9.31569004], [76.38041687, 9.31653118], [76.38014221, 9.31652737], [76.38014221, 9.31708336], [76.37985992, 9.31708336], [76.37985992, 9.31736088], [76.37958527, 9.31736088], [76.37958527, 9.31819534], [76.37930298, 9.31819534], [76.37930298, 9.31875134], [76.37902832, 9.31875134], [76.37902832, 9.31958294], [76.37874603, 9.31958103], [76.37874603, 9.32014084], [76.37847137, 9.32013893], [76.37847137, 9.32069111], [76.37819672, 9.32069969], [76.37819672, 9.32152939], [76.37791443, 9.32152653], [76.37791443, 9.32208347], [76.37763977, 9.32208061], [76.37763977, 9.32293129], [76.37735748, 9.32291698], [76.37735748, 9.32347107], [76.37708282, 9.32347107], [76.37708282, 9.3243103], [76.37680817, 9.32430458], [76.37680817, 9.32486153], [76.37652588, 9.32486153], [76.37652588, 9.32542038], [76.37625885, 9.32542038], [76.37625885, 9.32625198], [76.37596893, 9.32625198], [76.37596893, 9.32681179], [76.37568665, 9.32681179], [76.37568665, 9.32763958], [76.37541962, 9.32763672], [76.37541962, 9.32819366], [76.37513733, 9.3281889], [76.37513733, 9.32874966], [76.37486267, 9.32874966], [76.37486267, 9.32958412], [76.37458038, 9.32957935], [76.37458038, 9.33014011], [76.37430573, 9.33014011], [76.37430573, 9.3306942], [76.37403107, 9.3306942], [76.37403107, 9.33125019], [76.37374878, 9.33125019], [76.37374878, 9.3320837], [76.37346649, 9.33208179], [76.37346649, 9.33263969], [76.37319183, 9.33263779], [76.37319183, 9.33319378], [76.37291718, 9.33319378], [76.37291718, 9.33347225], [76.37264252, 9.33347034], [76.37264252, 9.33487129], [76.37236023, 9.33487129], [76.37236023, 9.33542061], [76.3720932, 9.33542061], [76.3720932, 9.33681107], [76.37180328, 9.3368063], [76.37180328, 9.33708191], [76.37152863, 9.33708477], [76.37152863, 9.3376379], [76.37124634, 9.3376379], [76.37124634, 9.33819389], [76.37097168, 9.33819199], [76.37097168, 9.33903122], [76.37069702, 9.33902645], [76.37069702, 9.33958244], [76.3704071, 9.33957958], [76.3704071, 9.34042072], [76.37014008, 9.34041691], [76.37014008, 9.3409729], [76.36985779, 9.34097004], [76.36985779, 9.34180927], [76.36958313, 9.34180546], [76.36958313, 9.34208298], [76.36930847, 9.34208298], [76.36930847, 9.34319496], [76.36902618, 9.34319019], [76.36902618, 9.34375095], [76.36875153, 9.34375095], [76.36875153, 9.34431171], [76.36846924, 9.34430695], [76.36846924, 9.34486103], [76.36818695, 9.34486103], [76.36818695, 9.34514141], [76.36791992, 9.34513855], [76.36791992, 9.34569454], [76.36763763, 9.34569263], [76.36763763, 9.34625053], [76.36736298, 9.34625053], [76.36736298, 9.34653187], [76.36708069, 9.3465271], [76.36708069, 9.34708309], [76.36680603, 9.34708118], [76.36680603, 9.34764099], [76.36653137, 9.34763908], [76.36653137, 9.3484726], [76.36624908, 9.3484726], [76.36624908, 9.34958267], [76.3659668, 9.34958076], [76.3659668, 9.35014153], [76.36569214, 9.35014153], [76.36569214, 9.35042191], [76.36541748, 9.35041714], [76.36541748, 9.35069561], [76.36513519, 9.35069561], [76.36513519, 9.35097122], [76.36486053, 9.35097122], [76.36486053, 9.35153198], [76.36458588, 9.35152721], [76.36458588, 9.35208321], [76.36429596, 9.3520813], [76.36430359, 9.35236168], [76.36402893, 9.35236168], [76.36402893, 9.35264015], [76.36374664, 9.35264015], [76.36374664, 9.35319328], [76.36347198, 9.35319138], [76.36347198, 9.35402966], [76.36319733, 9.35402775], [76.36319733, 9.35486221], [76.36292267, 9.35485935], [76.36292267, 9.35542011], [76.36264038, 9.3554163], [76.36264038, 9.35624981], [76.36235809, 9.35624981], [76.36235809, 9.35708427], [76.36207581, 9.35707855], [76.36207581, 9.35764027], [76.36180878, 9.35764027], [76.36180878, 9.35819435], [76.36152649, 9.35819435], [76.36152649, 9.35847187], [76.36125183, 9.35847187], [76.36125183, 9.35875034], [76.36096954, 9.35875034], [76.36096954, 9.3593111], [76.36069489, 9.35930634], [76.36069489, 9.35986233], [76.36042023, 9.35986042], [76.36042023, 9.36013985], [76.36013794, 9.36013794], [76.36013794, 9.36069393], [76.35986328, 9.36069202], [76.35986328, 9.36153126], [76.35958099, 9.36153126], [76.35958099, 9.36181068], [76.35930634, 9.36180592], [76.35930634, 9.36319447], [76.35901642, 9.3631897], [76.35902405, 9.36375046], [76.35874939, 9.36375046], [76.35874939, 9.36458206], [76.35847473, 9.36458206], [76.35847473, 9.3648634], [76.35819244, 9.364851], [76.35819244, 9.3654213], [76.35791779, 9.3654213], [76.35791779, 9.36625099], [76.35764313, 9.36625099], [76.35764313, 9.36680889], [76.35736084, 9.36680698], [76.35736084, 9.36736107], [76.35708618, 9.36736107], [76.35708618, 9.36819458], [76.35679626, 9.3681879], [76.35679626, 9.36903095], [76.35652924, 9.36903095], [76.35652924, 9.36931133], [76.35624695, 9.36930466], [76.35624695, 9.36958313], [76.35597229, 9.36958313], [76.35597229, 9.36986065], [76.35569763, 9.36986065], [76.35569763, 9.37014103], [76.35541534, 9.37013912], [76.35541534, 9.37069511], [76.35513306, 9.37069035], [76.35514069, 9.37125111], [76.3548584, 9.37125111], [76.3548584, 9.37208271], [76.35457611, 9.3720808], [76.35457611, 9.37264061], [76.35430908, 9.3726387], [76.35430908, 9.37319469], [76.35402679, 9.37319088], [76.35402679, 9.37486076], [76.35375214, 9.37486076], [76.35375214, 9.37541962], [76.35346985, 9.37541676], [76.35346985, 9.37569523], [76.35319519, 9.37569523], [76.35319519, 9.37624931], [76.3529129, 9.37624931], [76.3529129, 9.37681198], [76.35263824, 9.37680531], [76.35263824, 9.37708282], [76.35235596, 9.37708092], [76.35235596, 9.37764168], [76.35206604, 9.37764168], [76.35206604, 9.37792015], [76.35180664, 9.37792015], [76.35180664, 9.38041973], [76.35152435, 9.38041782], [76.35152435, 9.38097191], [76.35098267, 9.38097191], [76.35098267, 9.38181019], [76.35069275, 9.38180637], [76.35069275, 9.38236237], [76.35041809, 9.38236046], [76.35041809, 9.38292027], [76.3501358, 9.38291645], [76.3501358, 9.38347244], [76.34986115, 9.38346863], [76.34986115, 9.38431263], [76.34958649, 9.38430595], [76.34958649, 9.38458443], [76.34929657, 9.38458157], [76.34929657, 9.38514042], [76.34902954, 9.38513756], [76.34902954, 9.38597202], [76.34874725, 9.38597202], [76.34874725, 9.38736153], [76.3484726, 9.38736153], [76.3484726, 9.38819408], [76.34819794, 9.38819408], [76.34819794, 9.3890276], [76.34791565, 9.3890276], [76.34791565, 9.38958359], [76.34764099, 9.38958359], [76.34764099, 9.39069366], [76.3473587, 9.39069366], [76.3473587, 9.39097214], [76.34707642, 9.39097023], [76.34707642, 9.39124966], [76.34680939, 9.39124966], [76.34680176, 9.39153099], [76.3465271, 9.39153099], [76.3465271, 9.39292145], [76.34625244, 9.39291573], [76.34625244, 9.39347267], [76.34597015, 9.3934679], [76.34597015, 9.39403057], [76.3456955, 9.39402866], [76.3456955, 9.39597321], [76.34541321, 9.3959713], [76.34541321, 9.39625072], [76.34513855, 9.39625072], [76.34513855, 9.39681244], [76.3445816, 9.39680481], [76.3445816, 9.39708328], [76.34430695, 9.39708328], [76.34430695, 9.39847088], [76.34402466, 9.39847088], [76.34402466, 9.39986134], [76.34375, 9.39986134], [76.34375, 9.40069485], [76.34348297, 9.40069103], [76.34348297, 9.40125084], [76.34319305, 9.40125084], [76.34319305, 9.40263939], [76.3429184, 9.40263939], [76.3429184, 9.40291977], [76.34263611, 9.40291691], [76.34263611, 9.40347099], [76.34236145, 9.40347099], [76.34236145, 9.40402985], [76.34208679, 9.40402699], [76.34208679, 9.40458298], [76.34179688, 9.40458107], [76.34179688, 9.4054203], [76.34152985, 9.4054184], [76.34152985, 9.40569305], [76.3418045, 9.40569305], [76.3418045, 9.40597057], [76.34152985, 9.40597057], [76.34152985, 9.4068079], [76.34124756, 9.4068079], [76.34124756, 9.40764046], [76.3409729, 9.40764046], [76.3409729, 9.40874958], [76.34069824, 9.40874958], [76.34069824, 9.40902996], [76.34041595, 9.40902805], [76.34041595, 9.40958405], [76.3401413, 9.40958405], [76.3401413, 9.41014004], [76.33985901, 9.41013145], [76.33985901, 9.41125202], [76.33957672, 9.41125202], [76.33957672, 9.41152954], [76.33930206, 9.41152763], [76.33930206, 9.41347218], [76.3390274, 9.41347027], [76.3390274, 9.41403008], [76.33875275, 9.41403008], [76.33875275, 9.41514015], [76.33847046, 9.41514015], [76.33847046, 9.41542053], [76.3381958, 9.41541576], [76.3381958, 9.41597176], [76.33791351, 9.41597176], [76.33791351, 9.41847229], [76.33763885, 9.41847038], [76.33763885, 9.41903114], [76.33735657, 9.41903114], [76.33735657, 9.41986275], [76.33708191, 9.41985989], [76.33708191, 9.4206953], [76.33680725, 9.4206953], [76.33680725, 9.42236137], [76.33652496, 9.42236137], [76.33652496, 9.42319489], [76.33680725, 9.42319012], [76.33680725, 9.42403126], [76.33651733, 9.42403126], [76.33651733, 9.42431164], [76.33625031, 9.42430687], [76.33625031, 9.42486095], [76.33598328, 9.42486095], [76.33598328, 9.42542171], [76.33569336, 9.42541695], [76.33569336, 9.42569542], [76.3354187, 9.4256897], [76.3354187, 9.42653084], [76.33513641, 9.42653084], [76.33513641, 9.42764091], [76.33486176, 9.42764091], [76.33486176, 9.42791939], [76.3345871, 9.42791939], [76.3345871, 9.42875099], [76.33430481, 9.42874908], [76.33430481, 9.43097115], [76.33403015, 9.43097115], [76.33403015, 9.43181038], [76.33374786, 9.43180466], [76.33374786, 9.43236065], [76.33347321, 9.43236065], [76.33347321, 9.43264198], [76.33319092, 9.43264008], [76.33319092, 9.43486214], [76.33347321, 9.43485928], [76.33347321, 9.43542004], [76.33374786, 9.43541622], [76.33374786, 9.43569374], [76.33403015, 9.43569374], [76.33403015, 9.43597221], [76.33374786, 9.43596935], [76.33374786, 9.43624973], [76.33347321, 9.43624973], [76.33347321, 9.43653011], [76.33319092, 9.43653011], [76.33319092, 9.43680954], [76.33291626, 9.43680573], [76.33291626, 9.43735981], [76.3326416, 9.43735981], [76.3326416, 9.43902969], [76.33235931, 9.43902779], [76.33235931, 9.43958378], [76.33180237, 9.43958378], [76.33180237, 9.43986225], [76.33152771, 9.43986034], [76.33152771, 9.4404211], [76.33125305, 9.44041634], [76.33125305, 9.44097233], [76.33152771, 9.44097233], [76.33152771, 9.44208431], [76.33125305, 9.44207954], [76.33125305, 9.44320107], [76.33096313, 9.44320107], [76.33097076, 9.44375038], [76.33069611, 9.44375038], [76.33069611, 9.44458199], [76.33040619, 9.44458008], [76.33040619, 9.44542122], [76.33013916, 9.44541645], [76.33013916, 9.44597244], [76.32985687, 9.44596958], [76.32985687, 9.44626045], [76.32958221, 9.44626045], [76.32958221, 9.44681072], [76.32930756, 9.44681072], [76.32930756, 9.44791889], [76.32902527, 9.44791698], [76.32902527, 9.44847298], [76.32875061, 9.44847298], [76.32875061, 9.45069504], [76.32847595, 9.45069027], [76.32847595, 9.45125103], [76.32819366, 9.45125103], [76.32819366, 9.45236111], [76.32791901, 9.45236111], [76.32791901, 9.45292187], [76.32763672, 9.4529171], [76.32763672, 9.45319462], [76.32736206, 9.45319462], [76.32736206, 9.45458317], [76.32707977, 9.45458126], [76.32707977, 9.4568119], [76.32681274, 9.4568119], [76.32681274, 9.45792198], [76.32653046, 9.45792198], [76.32653046, 9.45875168], [76.32596588, 9.45875168], [76.32596588, 9.46041965], [76.32569122, 9.46041775], [76.32569122, 9.46125031], [76.32541656, 9.46125031], [76.32541656, 9.46208382], [76.32514954, 9.46208096], [76.32514954, 9.46542263], [76.32485962, 9.46541595], [76.32485962, 9.46569443], [76.32457733, 9.46569157], [76.32457733, 9.46652985], [76.32430267, 9.46652794], [76.32430267, 9.46708202], [76.32402802, 9.46708202], [76.32402802, 9.46763992], [76.32375336, 9.46763802], [76.32375336, 9.46986008], [76.32347107, 9.46986008], [76.32347107, 9.47043037], [76.32319641, 9.47041607], [76.32319641, 9.47069359], [76.32291412, 9.47069359], [76.32291412, 9.47236347], [76.32263947, 9.47235966], [76.32263947, 9.47264099], [76.32236481, 9.47263813], [76.32236481, 9.47319412], [76.32263947, 9.47318077], [76.32263947, 9.47403145], [76.32236481, 9.47402859], [76.32236481, 9.47486115], [76.32209015, 9.47486115], [76.32209015, 9.47542095], [76.32180786, 9.47541714], [76.32180786, 9.47569466], [76.3215332, 9.47568989], [76.3215332, 9.47681141], [76.32125092, 9.47680473], [76.32125092, 9.47958279], [76.32096863, 9.47958279], [76.32096863, 9.47986126], [76.32068634, 9.47986126], [76.32068634, 9.48042202], [76.32041931, 9.48041725], [76.32041931, 9.48097324], [76.32013702, 9.48097134], [76.32013702, 9.48152924], [76.31986237, 9.48152924], [76.31986237, 9.48180962], [76.31958008, 9.48180962], [76.31958008, 9.48431015], [76.31931305, 9.48431015], [76.31931305, 9.4865303], [76.31903076, 9.48652744], [76.31903076, 9.48708439], [76.31931305, 9.48708057], [76.31931305, 9.48764038], [76.31958008, 9.48763657], [76.31958008, 9.48875046], [76.31931305, 9.48875046], [76.31931305, 9.49042034], [76.31903076, 9.49041557], [76.31903076, 9.49097157], [76.31874847, 9.49097157], [76.31874847, 9.49125195], [76.31846619, 9.49125195], [76.31846619, 9.49154186], [76.31819153, 9.49152756], [76.31819153, 9.49208355], [76.31791687, 9.49208164], [76.31791687, 9.49263954], [76.31819153, 9.49263763], [76.31819153, 9.49319363], [76.31846619, 9.49318886], [76.31846619, 9.49403], [76.31874847, 9.49403], [76.31874847, 9.49431133], [76.31847382, 9.49430561], [76.31847382, 9.49458408], [76.31819153, 9.49458027], [76.31819153, 9.49542141], [76.31791687, 9.49541569], [76.31791687, 9.49597168], [76.31764221, 9.49597168], [76.31764221, 9.49625015], [76.31735992, 9.49625015], [76.31735992, 9.49708366], [76.31708527, 9.49708366], [76.31708527, 9.49736023], [76.31680298, 9.49735069], [76.31680298, 9.49792099], [76.31652832, 9.49792099], [76.31652832, 9.49874973], [76.31625366, 9.49874973], [76.31625366, 9.49985981], [76.31595612, 9.4998579], [76.31595612, 9.50153065], [76.31569672, 9.50152874], [76.31569672, 9.5023613], [76.3154068, 9.5023613], [76.31541443, 9.5037508], [76.31513977, 9.5037508], [76.31513977, 9.50458336], [76.31485748, 9.50457954], [76.31485748, 9.50514126], [76.31458282, 9.50514126], [76.31458282, 9.50654125], [76.31430817, 9.50654125], [76.31430817, 9.50764084], [76.31402588, 9.50764084], [76.31402588, 9.50875092], [76.31375122, 9.50875092], [76.31375122, 9.51014233], [76.31346893, 9.51014233], [76.31346893, 9.5118103], [76.31319427, 9.51180458], [76.31319427, 9.51319313], [76.31291962, 9.51319122], [76.31291962, 9.51431179], [76.31263733, 9.51431179], [76.31263733, 9.51541996], [76.31236267, 9.51541996], [76.31236267, 9.51764202], [76.31208038, 9.51764011], [76.31208038, 9.5195837], [76.31181335, 9.51958179], [76.31181335, 9.52013969], [76.31153107, 9.52013779], [76.31153107, 9.52069378], [76.31124878, 9.52069187], [76.31124878, 9.52153969], [76.31096649, 9.52153969], [76.31096649, 9.52292061], [76.31069183, 9.52292061], [76.31069183, 9.52403069], [76.31041718, 9.52402782], [76.31041718, 9.5251379], [76.31069183, 9.5251379], [76.31069183, 9.52542114], [76.31041718, 9.52541637], [76.31041718, 9.52569389], [76.31069183, 9.52569199], [76.31069183, 9.52625275], [76.31015015, 9.52625275], [76.31015015, 9.5276413], [76.31041718, 9.5276413], [76.31041718, 9.52902889], [76.31015015, 9.52902889], [76.31015015, 9.53042126], [76.30986023, 9.53041744], [76.30986023, 9.53097343], [76.3095932, 9.53097057], [76.3095932, 9.53153133], [76.30930328, 9.53153133], [76.30930328, 9.53180885], [76.30958557, 9.53180695], [76.30958557, 9.53319454], [76.30930328, 9.53318977], [76.30930328, 9.53347969], [76.30902863, 9.53347969], [76.30902863, 9.53403091], [76.30874634, 9.53403091], [76.30874634, 9.53431034], [76.30902863, 9.53430462], [76.30902863, 9.53458309], [76.30874634, 9.53458309], [76.30874634, 9.53486061], [76.30902863, 9.53486061], [76.30902863, 9.53514099], [76.30874634, 9.53513908], [76.30874634, 9.53652668], [76.30847168, 9.53652668], [76.30847168, 9.53708267], [76.30874634, 9.53708076], [76.30874634, 9.53764153], [76.30847168, 9.53764153], [76.30847168, 9.53931046], [76.30819702, 9.53930473], [76.30819702, 9.5409708], [76.3079071, 9.54096889], [76.30791473, 9.54124928], [76.30764008, 9.54124928], [76.30764008, 9.54265118], [76.30791473, 9.54263973], [76.30791473, 9.54374981], [76.30764008, 9.54374981], [76.30764008, 9.54403019], [76.30735779, 9.54403019], [76.30735779, 9.54430962], [76.30708313, 9.5443058], [76.30708313, 9.54597187], [76.30680847, 9.54597187], [76.30680847, 9.54763985], [76.30652618, 9.54763985], [76.30652618, 9.5490303], [76.30625153, 9.5490284], [76.30625153, 9.55069447], [76.30596924, 9.5506897], [76.30596924, 9.5529213], [76.30569458, 9.55291557], [76.30569458, 9.55347157], [76.30541992, 9.55346966], [76.30541992, 9.55375099], [76.30568695, 9.55375099], [76.30568695, 9.55514145], [76.30541992, 9.55514145], [76.30541992, 9.55764961], [76.30513763, 9.55764961], [76.30513763, 9.55792141], [76.30486298, 9.55791664], [76.30486298, 9.55819511], [76.30458069, 9.55819511], [76.30458069, 9.55847263], [76.30486298, 9.55847263], [76.30486298, 9.55986118], [76.30458069, 9.55986118], [76.30458069, 9.56014061], [76.30486298, 9.56014061], [76.30486298, 9.56042194], [76.30458069, 9.56041718], [76.30458069, 9.56069469], [76.30430603, 9.56069088], [76.30430603, 9.56125069], [76.30458069, 9.56125069], [76.30458069, 9.56236076], [76.30430603, 9.56236076], [76.30430603, 9.56263924], [76.30403137, 9.56263924], [76.30403137, 9.56458282], [76.30374908, 9.56458092], [76.30374908, 9.56542015], [76.30347443, 9.56541729], [76.30347443, 9.56847095], [76.30319214, 9.56847095], [76.30319214, 9.57069397], [76.30291748, 9.57069588], [76.30291748, 9.57097244], [76.30264282, 9.57096863], [76.30264282, 9.57153034], [76.30291748, 9.57153034], [76.30291748, 9.57181263], [76.30319214, 9.57180595], [76.30319214, 9.57236195], [76.30291748, 9.57236195], [76.30291748, 9.57263756], [76.30264282, 9.57263088], [76.30264282, 9.57291985], [76.30236053, 9.57291794], [76.30236053, 9.57319355], [76.30208588, 9.57319164], [76.30208588, 9.57374954], [76.30236053, 9.57374954], [76.30236053, 9.57402992], [76.30208588, 9.57402992], [76.30208588, 9.57431126], [76.30236053, 9.57431126], [76.30236053, 9.57681084], [76.30208588, 9.57680416], [76.30208588, 9.57819366], [76.30179596, 9.57818985], [76.30179596, 9.57875919], [76.30152893, 9.57874966], [76.30152893, 9.57958221], [76.30179596, 9.57958031], [76.30180359, 9.57985973], [76.30152893, 9.57985973], [76.30152893, 9.58014107], [76.30124664, 9.58014107], [76.30124664, 9.58042145], [76.30152893, 9.58041573], [76.30152893, 9.58319473], [76.30180359, 9.58319473], [76.30180359, 9.58347321], [76.30152893, 9.58347034], [76.30152893, 9.58431053], [76.30124664, 9.58430481], [76.30124664, 9.58458328], [76.30097961, 9.58457088], [76.30097961, 9.58542061], [76.30069733, 9.58541679], [76.30069733, 9.58569527], [76.30041504, 9.58569527], [76.30041504, 9.58597279], [76.30014038, 9.58597279], [76.30014038, 9.58625126], [76.30041504, 9.58625126], [76.30041504, 9.58757114], [76.30042267, 9.59013939], [76.30014038, 9.59013939], [76.30014038, 9.59125137], [76.29985809, 9.59125137], [76.29985809, 9.5929203], [76.29957581, 9.5929203], [76.29957581, 9.59403038], [76.29930878, 9.59403038], [76.29930878, 9.5943079], [76.29957581, 9.5943079], [76.29957581, 9.59542179], [76.29985809, 9.59541798], [76.29985809, 9.59569263], [76.29958344, 9.59569263], [76.29958344, 9.59680557], [76.29930878, 9.59680557], [76.29930878, 9.59847164], [76.29902649, 9.59847164], [76.29902649, 9.59875202], [76.29930878, 9.59875202], [76.29930878, 9.59930992], [76.29902649, 9.59930992], [76.29902649, 9.60013962], [76.29875183, 9.60013771], [76.29875183, 9.60097218], [76.29846954, 9.60097218], [76.29846954, 9.60208416], [76.29875183, 9.60208035], [76.29875183, 9.60292053], [76.29846954, 9.60291576], [76.29846954, 9.60375023], [76.29819489, 9.60375023], [76.29819489, 9.60624981], [76.29792023, 9.6062479], [76.29792023, 9.60681057], [76.29763794, 9.60681057], [76.29763794, 9.60764122], [76.29792023, 9.60764122], [76.29792023, 9.6093092], [76.29763794, 9.60930443], [76.29763794, 9.61097336], [76.29736328, 9.61097336], [76.29736328, 9.61236095], [76.29763794, 9.61236095], [76.29763794, 9.61264133], [76.29736328, 9.61263943], [76.29736328, 9.61375141], [76.29708099, 9.61375141], [76.29708099, 9.61458302], [76.29736328, 9.61458302], [76.29736328, 9.61486053], [76.29708099, 9.61486053], [76.29708099, 9.6170826], [76.29680634, 9.61708069], [76.29680634, 9.61875057], [76.29652405, 9.61874866], [76.29652405, 9.61958313], [76.29624939, 9.61958122], [76.29624939, 9.62042046], [76.2959671, 9.62042046], [76.2959671, 9.62180996], [76.29624939, 9.62180614], [76.29624939, 9.62208366], [76.29652405, 9.62208366], [76.29652405, 9.62236214], [76.29680634, 9.62235928], [76.29680634, 9.62263966], [76.29736328, 9.62263966], [76.29736328, 9.62292004], [76.29763794, 9.62291527], [76.29763794, 9.62347221], [76.29680634, 9.62347221], [76.29680634, 9.62374973], [76.29624939, 9.62374115], [76.29624939, 9.62430954], [76.29597473, 9.62430573], [76.29597473, 9.62569427], [76.29569244, 9.62569141], [76.29569244, 9.62652969], [76.29541779, 9.62652969], [76.29541779, 9.62931061], [76.29514313, 9.62931061], [76.29514313, 9.63153076], [76.29486084, 9.6315279], [76.29486084, 9.63236237], [76.2951355, 9.63236237], [76.29514313, 9.63319016], [76.29485321, 9.63320065], [76.29485321, 9.63431072], [76.29458618, 9.63430691], [76.29458618, 9.63458157], [76.29485321, 9.63457966], [76.29485321, 9.63792133], [76.29458618, 9.63791656], [76.29458618, 9.63847256], [76.29430389, 9.63847256], [76.29430389, 9.63986111], [76.29458618, 9.63986111], [76.29458618, 9.64181042], [76.29429626, 9.64181042], [76.29429626, 9.64291859], [76.29458618, 9.64291668], [76.29458618, 9.64347267], [76.29429626, 9.64347076], [76.29429626, 9.64542198], [76.29402924, 9.64541721], [76.29402924, 9.64819336], [76.29374695, 9.64819145], [76.29374695, 9.65042019], [76.29402924, 9.65041637], [76.29402924, 9.6506958], [76.29430389, 9.6506958], [76.29430389, 9.65097237], [76.29458618, 9.65096855], [76.29458618, 9.65153027], [76.29429626, 9.65153027], [76.29429626, 9.65180969], [76.29402924, 9.65180588], [76.29402924, 9.65236187], [76.29374695, 9.65236187], [76.29374695, 9.65264034], [76.29347229, 9.65264034], [76.29347229, 9.65431118], [76.29319763, 9.65430641], [76.29319763, 9.65708447], [76.29291534, 9.65708447], [76.29291534, 9.65986347], [76.29264069, 9.65986347], [76.29264069, 9.66097164], [76.29291534, 9.66097164], [76.29291534, 9.66319466], [76.29264069, 9.66319466], [76.29264069, 9.66347313], [76.2923584, 9.66347027], [76.2923584, 9.66653061], [76.29207611, 9.66653061], [76.29207611, 9.66764069], [76.29180908, 9.66764069], [76.29180908, 9.66986084], [76.29152679, 9.66986084], [76.29152679, 9.67347431], [76.29125214, 9.67347145], [76.29125214, 9.67653179], [76.29096985, 9.67652798], [76.29096985, 9.67958355], [76.29070282, 9.67958164], [76.29070282, 9.68264008], [76.2904129, 9.68264008], [76.2904129, 9.68402767], [76.29013824, 9.68402767], [76.29013824, 9.68847275], [76.28986359, 9.68847275], [76.28986359, 9.68958473], [76.2895813, 9.68958473], [76.2895813, 9.6912508], [76.28930664, 9.6912508], [76.28930664, 9.69430923], [76.28901672, 9.69430923], [76.28902435, 9.69874859], [76.28874969, 9.69875145], [76.28874969, 9.70236206], [76.28847504, 9.70236206], [76.28847504, 9.70458412], [76.28819275, 9.70457935], [76.28819275, 9.70681], [76.28791809, 9.70681], [76.28791809, 9.70903015], [76.2876358, 9.70902824], [76.2876358, 9.71125031], [76.28736115, 9.71125031], [76.28736115, 9.71264267], [76.28708649, 9.71264267], [76.28708649, 9.71431065], [76.28736115, 9.71430683], [76.28736115, 9.71485996], [76.28708649, 9.71485996], [76.28708649, 9.71542072], [76.28679657, 9.71542072], [76.28679657, 9.71709156], [76.28708649, 9.71708298], [76.28708649, 9.71736145], [76.28679657, 9.71736145], [76.28679657, 9.71792126], [76.28652954, 9.71792126], [76.28652954, 9.72042084], [76.28624725, 9.72041702], [76.28624725, 9.72069454], [76.28652954, 9.72069454], [76.28652954, 9.72097301], [76.28624725, 9.72097111], [76.28624725, 9.72264099], [76.28598022, 9.72264099], [76.28598022, 9.72375107], [76.28624725, 9.72374916], [76.28624725, 9.72458267], [76.2859726, 9.72458267], [76.2859726, 9.72819328], [76.28569794, 9.72819138], [76.28569794, 9.72902966], [76.28541565, 9.72902679], [76.28541565, 9.73124981], [76.28514099, 9.73124981], [76.28514099, 9.73347187], [76.28542328, 9.73347187], [76.28542328, 9.73542023], [76.28514099, 9.73542023], [76.28514099, 9.73681068], [76.2848587, 9.73680592], [76.2848587, 9.73708439], [76.28457642, 9.73707962], [76.28457642, 9.73764038], [76.28430939, 9.73763847], [76.28430939, 9.73847198], [76.28457642, 9.73847008], [76.28457642, 9.73931122], [76.28430939, 9.73931122], [76.28430939, 9.7404213], [76.28458405, 9.74041557], [76.28458405, 9.74069405], [76.28430939, 9.74069023], [76.28430176, 9.74153137], [76.2840271, 9.74152946], [76.2840271, 9.74208546], [76.28430176, 9.74207973], [76.28430176, 9.74403095], [76.2840271, 9.74402905], [76.2840271, 9.74458313], [76.28375244, 9.74458027], [76.28375244, 9.74764061], [76.2840271, 9.74764061], [76.2840271, 9.74792194], [76.28514099, 9.74792194], [76.28514099, 9.74764061], [76.28598022, 9.74764061], [76.28598022, 9.74792194], [76.28624725, 9.74791718], [76.28624725, 9.74819469], [76.28652954, 9.74818993], [76.28652954, 9.74986076], [76.28624725, 9.74986076], [76.28624725, 9.75013924], [76.28598022, 9.7501297], [76.28598022, 9.75041866], [76.28542328, 9.75041866], [76.28542328, 9.7501297], [76.28375244, 9.7501297], [76.28375244, 9.75041866], [76.28347015, 9.75041676], [76.28347015, 9.75097084], [76.28320313, 9.75097084], [76.28320313, 9.7515316], [76.28291321, 9.7515316], [76.28291321, 9.75319958], [76.28320313, 9.75319958], [76.28320313, 9.75403023], [76.28291321, 9.75402737], [76.28291321, 9.75458336], [76.28263855, 9.75458145], [76.28263855, 9.75626087], [76.28235626, 9.75626087], [76.28235626, 9.75681019], [76.2820816, 9.75680637], [76.2820816, 9.75736237], [76.28236389, 9.75736237], [76.28236389, 9.75847244], [76.2820816, 9.75847244], [76.2820816, 9.75903034], [76.28180695, 9.75902843], [76.28180695, 9.76097202], [76.28151703, 9.76097202], [76.28151703, 9.76124954], [76.28180695, 9.76124954], [76.28180695, 9.76319408], [76.28151703, 9.76318932], [76.28151703, 9.76431084], [76.28125, 9.76431084], [76.28125, 9.76543045], [76.28097534, 9.76541615], [76.28097534, 9.76708221], [76.28069305, 9.76708221], [76.28069305, 9.76875114], [76.2804184, 9.76875114], [76.2804184, 9.76986027], [76.28013611, 9.76986027], [76.28013611, 9.77097321], [76.27986145, 9.77097321], [76.27986145, 9.77208328], [76.27958679, 9.77208042], [76.27958679, 9.77680969], [76.2793045, 9.77680492], [76.2793045, 9.7770834], [76.27902985, 9.7770834], [76.27902985, 9.77986145], [76.27874756, 9.77986145], [76.27874756, 9.78043079], [76.2784729, 9.78043079], [76.2784729, 9.78153038], [76.27819824, 9.78153038], [76.27819824, 9.78292179], [76.2784729, 9.78291798], [76.2784729, 9.78319263], [76.27819824, 9.78318024], [76.27819824, 9.78374958], [76.27791595, 9.78374958], [76.27791595, 9.78514194], [76.2776413, 9.78514004], [76.2776413, 9.78708363], [76.27735901, 9.78708363], [76.27735901, 9.7881937], [76.27707672, 9.7881918], [76.27707672, 9.78903008], [76.27680969, 9.78903008], [76.27680969, 9.79014015], [76.2765274, 9.79014015], [76.2765274, 9.79152966], [76.27625275, 9.79152966], [76.27625275, 9.79181099], [76.2765274, 9.79180622], [76.2765274, 9.79319382], [76.27625275, 9.79319382], [76.27625275, 9.79458237], [76.27597046, 9.79458046], [76.27597046, 9.79653072], [76.2756958, 9.79652882], [76.2756958, 9.79708195], [76.27540588, 9.79708004], [76.27540588, 9.7976408], [76.27513885, 9.79763889], [76.27513885, 9.79847336], [76.27541351, 9.79847336], [76.27541351, 9.79922009], [76.27541351, 9.79986095], [76.27513885, 9.79986095], [76.27513885, 9.80041885], [76.2748642, 9.80041695], [76.2748642, 9.803195], [76.27458191, 9.80319118], [76.27458191, 9.80403233], [76.27430725, 9.80403233], [76.27430725, 9.80430984], [76.27401733, 9.80430984], [76.27401733, 9.80514145], [76.27375031, 9.80513859], [76.27375031, 9.80597115], [76.27348328, 9.80597115], [76.27348328, 9.80792046], [76.27319336, 9.80792046], [76.27319336, 9.80902958], [76.2729187, 9.80902958], [76.2729187, 9.81013966], [76.27319336, 9.81013966], [76.27319336, 9.810812], [76.27319336, 9.81180954], [76.2729187, 9.81180954], [76.2729187, 9.81264019], [76.27263641, 9.81264019], [76.27263641, 9.81375027], [76.27236176, 9.81375027], [76.27236176, 9.81402969], [76.27263641, 9.81402969], [76.27263641, 9.81431007], [76.27236176, 9.81430626], [76.27236176, 9.81486225], [76.2720871, 9.81486034], [76.2720871, 9.81654167], [76.27179718, 9.81654167], [76.27179718, 9.81931114], [76.27153015, 9.81930637], [76.27153015, 9.81986237], [76.27124786, 9.81986046], [76.27124786, 9.82014275], [76.27097321, 9.82013798], [76.27097321, 9.82208538], [76.27124786, 9.82208538], [76.27124786, 9.82236004], [76.27097321, 9.82236004], [76.27097321, 9.82347298], [76.27086639, 9.82347298], [76.27069092, 9.82347012], [76.27069092, 9.82431126], [76.27041626, 9.82431126], [76.27041626, 9.82653141], [76.2701416, 9.82652664], [76.2701416, 9.82708263], [76.26985931, 9.82708263], [76.26985931, 9.83236122], [76.26957703, 9.83236122], [76.26957703, 9.83375072], [76.26930237, 9.83375072], [76.26930237, 9.83403015], [76.26902771, 9.83402729], [76.26902771, 9.83458328], [76.26875305, 9.83458328], [76.26875305, 9.83624935], [76.26847076, 9.83624935], [76.26847076, 9.83681011], [76.26875305, 9.8368063], [76.26875305, 9.8381958], [76.26847076, 9.83819103], [76.26847076, 9.83875179], [76.26819611, 9.83875179], [76.26819611, 9.84014034], [76.26791382, 9.84014034], [76.26791382, 9.84097195], [76.26763916, 9.84097195], [76.26763916, 9.84152985], [76.26735687, 9.84152985], [76.26735687, 9.84181023], [76.26763916, 9.84180641], [76.26763916, 9.84208393], [76.26790619, 9.84208202], [76.26790619, 9.84263992], [76.26763916, 9.84263992], [76.26763916, 9.84348106], [76.26735687, 9.84348106], [76.26735687, 9.84431076], [76.26708221, 9.84431076], [76.26708221, 9.84542274], [76.26680756, 9.84542274], [76.26680756, 9.84624958], [76.26652527, 9.84624958], [76.26652527, 9.84652805], [76.26625061, 9.84652805], [76.26625061, 9.84847164], [76.26597595, 9.84846973], [76.26597595, 9.84931087], [76.26568604, 9.84931087], [76.26568604, 9.85014057], [76.26597595, 9.85014057], [76.26597595, 9.85181141], [76.26568604, 9.85181141], [76.26569366, 9.85236073], [76.26541901, 9.85236073], [76.26541901, 9.85292053], [76.26513672, 9.85291672], [76.26513672, 9.85347271], [76.26486969, 9.8534708], [76.26486969, 9.85542107], [76.26513672, 9.85541725], [76.26513672, 9.85624886], [76.26486206, 9.85624886], [76.26486206, 9.85708332], [76.26457977, 9.85708141], [76.26457977, 9.85736084], [76.26430511, 9.85736084], [76.26430511, 9.85847092], [76.26403046, 9.85846043], [76.26403046, 9.85931015], [76.26374817, 9.85931015], [76.26374817, 9.86180973], [76.26347351, 9.86180496], [76.26347351, 9.86208344], [76.26319122, 9.86208057], [76.26319122, 9.86514187], [76.26291656, 9.86514187], [76.26291656, 9.86625195], [76.26264191, 9.86625195], [76.26264191, 9.86653042], [76.26235962, 9.86653042], [76.26235962, 9.86791992], [76.26264191, 9.86791801], [76.26264191, 9.86819363], [76.26291656, 9.86819363], [76.26291656, 9.8684721], [76.26319122, 9.8684721], [76.26319122, 9.8698597], [76.26291656, 9.8698597], [76.26291656, 9.87014008], [76.26235962, 9.87014008], [76.26235962, 9.87042046], [76.26180267, 9.87041569], [76.26180267, 9.87097168], [76.26152802, 9.87097168], [76.26152802, 9.87181091], [76.26125336, 9.87180614], [76.26125336, 9.87319374], [76.26097107, 9.87319183], [76.26097107, 9.87486267], [76.26069641, 9.87485981], [76.26069641, 9.87819481], [76.26040649, 9.87819004], [76.26040649, 9.87959194], [76.26013947, 9.87958336], [76.26013947, 9.88097286], [76.26040649, 9.88097095], [76.26040649, 9.88180923], [76.26013947, 9.88180542], [76.26013947, 9.88236141], [76.25986481, 9.88236141], [76.25986481, 9.88263893], [76.25958252, 9.88263893], [76.25958252, 9.8834734], [76.25930786, 9.8834734], [76.25930786, 9.88486099], [76.2590332, 9.88486099], [76.25902557, 9.88624859], [76.25875092, 9.88625145], [76.25875092, 9.88736057], [76.25846863, 9.88736057], [76.25846863, 9.88847446], [76.25818634, 9.88847065], [76.25818634, 9.89041996], [76.25791931, 9.89041805], [76.25791931, 9.89097118], [76.25763702, 9.89096928], [76.25763702, 9.89264202], [76.25736237, 9.89264011], [76.25736237, 9.89375019], [76.25708008, 9.89375019], [76.25708008, 9.89513969], [76.25680542, 9.89513779], [76.25680542, 9.89569378], [76.25653076, 9.89569187], [76.25653076, 9.89625168], [76.25624847, 9.89624977], [76.25624847, 9.89764023], [76.25597382, 9.89764023], [76.25597382, 9.89958191], [76.25567627, 9.89958191], [76.25567627, 9.90070057], [76.25541687, 9.90070057], [76.25541687, 9.90153122], [76.25514221, 9.90153122], [76.25514221, 9.90292072], [76.25485992, 9.90292072], [76.25485992, 9.9040308], [76.25458527, 9.90402889], [76.25458527, 9.90486145], [76.25430298, 9.90486145], [76.25430298, 9.90597343], [76.25402832, 9.90597343], [76.25402832, 9.90708256], [76.25374603, 9.9070797], [76.25374603, 9.90764141], [76.25347137, 9.90763855], [76.25347137, 9.90819454], [76.25319672, 9.90818977], [76.25319672, 9.90930939], [76.2529068, 9.90930939], [76.2529068, 9.91041946], [76.25263977, 9.91041946], [76.25263977, 9.91181183], [76.25235748, 9.91181183], [76.25235748, 9.91292191], [76.25208282, 9.91292191], [76.25208282, 9.91403198], [76.25180817, 9.91403198], [76.25180817, 9.91541958], [76.25152588, 9.91541958], [76.25152588, 9.91652966], [76.25125122, 9.91652966], [76.25125122, 9.91763973], [76.25096893, 9.91763973], [76.25096893, 9.91874981], [76.25069427, 9.91874981], [76.25069427, 9.91958427], [76.25041962, 9.91958141], [76.25041962, 9.92014027], [76.25013733, 9.92014027], [76.25013733, 9.92097187], [76.24986267, 9.92097187], [76.24986267, 9.92180634], [76.24958038, 9.92180634], [76.24958038, 9.92236233], [76.24930573, 9.92236233], [76.24930573, 9.92319393], [76.24903107, 9.92319202], [76.24903107, 9.9240303], [76.24874878, 9.9240284], [76.24874878, 9.92486], [76.24846649, 9.92486], [76.24846649, 9.92542076], [76.24819183, 9.92541599], [76.24819183, 9.92625046], [76.24791718, 9.92625046], [76.24791718, 9.92708206], [76.24764252, 9.92708015], [76.24764252, 9.92793179], [76.24736023, 9.92793179], [76.24736023, 9.92875004], [76.24708557, 9.92875004], [76.24708557, 9.92958546], [76.24680328, 9.92957973], [76.24680328, 9.93042088], [76.24652863, 9.93042088], [76.24652863, 9.93125057], [76.24624634, 9.93125057], [76.24624634, 9.93208218], [76.24597168, 9.93208027], [76.24597168, 9.93292141], [76.24569702, 9.93291664], [76.24569702, 9.93347263], [76.2454071, 9.93346977], [76.2454071, 9.93431091], [76.24514008, 9.93431091], [76.24514008, 9.93514061], [76.24485779, 9.9351387], [76.24485779, 9.93597317], [76.24458313, 9.93597126], [76.24458313, 9.93680859], [76.24430847, 9.93680477], [76.24430847, 9.93708324], [76.24402618, 9.93708324], [76.24402618, 9.93819523], [76.24373627, 9.93819141], [76.24373627, 9.93931198], [76.24346924, 9.93931198], [76.24346924, 9.94014168], [76.24319458, 9.94013882], [76.24319458, 9.94069481], [76.24291992, 9.94069099], [76.24291992, 9.94153023], [76.24263763, 9.94152737], [76.24263763, 9.94208336], [76.24236298, 9.94208145], [76.24236298, 9.94293118], [76.24208069, 9.94291782], [76.24208069, 9.94374943], [76.24180603, 9.94374943], [76.24180603, 9.94431019], [76.24153137, 9.94431019], [76.24153137, 9.94514179], [76.24124908, 9.94513988], [76.24124908, 9.94567966], [76.2409668, 9.94569969], [76.2409668, 9.94653034], [76.24069214, 9.94652843], [76.24069214, 9.94708443], [76.24041748, 9.94708061], [76.24041748, 9.94791985], [76.24013519, 9.94791794], [76.24013519, 9.94847202], [76.23986053, 9.94847202], [76.23986053, 9.9493103], [76.23958588, 9.94930553], [76.23958588, 9.94986153], [76.23930359, 9.94986153], [76.23930359, 9.95069408], [76.23902893, 9.95068932], [76.23902893, 9.95153046], [76.23874664, 9.95153046], [76.23874664, 9.95263958], [76.23847198, 9.95263767], [76.23847198, 9.95347214], [76.23819733, 9.95347023], [76.23819733, 9.95431137], [76.2379303, 9.95431137], [76.2379303, 9.95542145], [76.23764038, 9.95541573], [76.23764038, 9.95625019], [76.23735809, 9.95625019], [76.23735809, 9.95791721], [76.23707581, 9.95790958], [76.23707581, 9.96014118], [76.23680878, 9.96014118], [76.23680878, 9.96291924], [76.23708344, 9.96291733], [76.23708344, 9.96400166], [76.23707581, 9.96486092], [76.23735809, 9.96486092], [76.23735809, 9.96542168], [76.23764038, 9.96541691], [76.23764038, 9.96569538], [76.23791504, 9.96569538], [76.23791504, 9.96597099], [76.23819733, 9.96597099], [76.23819733, 9.96652889], [76.23847198, 9.96652889], [76.23847198, 9.96681023], [76.23902893, 9.96680546], [76.23902893, 9.96708298], [76.23958588, 9.96708298], [76.23958588, 9.96736145], [76.24041748, 9.96736145], [76.24041748, 9.96764183], [76.2409668, 9.96764183], [76.2409668, 9.9679203], [76.24124908, 9.96791744], [76.24124908, 9.96819305], [76.24291992, 9.96819115], [76.24291992, 9.96875191], [76.24318695, 9.96875191], [76.24318695, 9.96903038], [76.24485779, 9.96903038], [76.24485779, 9.96930981], [76.24569702, 9.96930504], [76.24569702, 9.96958256], [76.24764252, 9.96958256], [76.24764252, 9.96986103], [76.24846649, 9.96984959], [76.24846649, 9.97014046], [76.24903107, 9.97014046], [76.24903107, 9.96984959], [76.24986267, 9.96986103], [76.24986267, 9.96958256], [76.25125122, 9.96958256], [76.25125122, 9.96986103], [76.25263977, 9.96986103], [76.25263977, 9.96958256], [76.25319672, 9.96958256], [76.25319672, 9.96847343], [76.25347137, 9.96847343], [76.25347137, 9.96819305], [76.25375366, 9.96819305], [76.25375366, 9.96708298], [76.25430298, 9.96708298], [76.25430298, 9.96652699], [76.2545929, 9.96652889], [76.2545929, 9.96625137], [76.25514221, 9.96625137], [76.25514221, 9.96569538], [76.25541687, 9.96569538], [76.25541687, 9.96541691], [76.25596619, 9.96542168], [76.25596619, 9.9651413], [76.25624847, 9.9651413], [76.25624847, 9.96486092], [76.25653076, 9.96486092], [76.25653076, 9.9645834], [76.25680542, 9.9645834], [76.25680542, 9.96430492], [76.25736237, 9.9643116], [76.25736237, 9.96404266], [76.25791931, 9.96404266], [76.25791931, 9.96375084], [76.25818634, 9.96375084], [76.25818634, 9.96347141], [76.25846863, 9.96347332], [76.25846863, 9.96319485], [76.25875092, 9.96319485], [76.25875092, 9.96291733], [76.2590332, 9.96291924], [76.2590332, 9.96263885], [76.25930786, 9.96263885], [76.25930786, 9.96236134], [76.25986481, 9.96236134], [76.25986481, 9.96152878], [76.25958252, 9.96153069], [76.25958252, 9.96125126], [76.25986481, 9.96125126], [76.25985718, 9.96014118], [76.26013947, 9.96014118], [76.26013947, 9.95931053], [76.26040649, 9.95931053], [76.26040649, 9.95903111], [76.26069641, 9.95903111], [76.26069641, 9.95790958], [76.26097107, 9.95791721], [76.26097107, 9.95680428], [76.26125336, 9.95681095], [76.26125336, 9.95597172], [76.26152802, 9.95597172], [76.26152802, 9.95541573], [76.2618103, 9.95542145], [76.2618103, 9.95514107], [76.26152802, 9.95514107], [76.26152802, 9.95423985], [76.26152802, 9.95236015], [76.26125336, 9.95236015], [76.26125336, 9.95208359], [76.26097107, 9.95208359], [76.26097107, 9.95180607], [76.26125336, 9.95181084], [76.26125336, 9.95153046], [76.26097107, 9.95153046], [76.26097107, 9.95014], [76.26125336, 9.95014], [76.26125336, 9.94957924], [76.26152802, 9.94958401], [76.26152802, 9.94902802], [76.2618103, 9.94902992], [76.2618103, 9.94819069], [76.26208496, 9.94819355], [76.26208496, 9.94458389], [76.26180267, 9.94458389], [76.26180267, 9.94347095], [76.26208496, 9.94347095], [76.26208496, 9.94236088], [76.26235962, 9.94236088], [76.26235962, 9.94124889], [76.26264191, 9.94124889], [76.26264191, 9.94041729], [76.26291656, 9.94042015], [76.26291656, 9.94014168], [76.26319122, 9.94014168], [76.26319122, 9.93958092], [76.26347351, 9.93958282], [76.26347351, 9.93847084], [76.26374817, 9.93847084], [76.26374817, 9.93791676], [76.26403046, 9.93792152], [76.26403046, 9.93764114], [76.26431274, 9.93764114], [76.26431274, 9.93653107], [76.26457977, 9.93653107], [76.26457977, 9.93568993], [76.26486206, 9.93569469], [76.26486206, 9.93541718], [76.26513672, 9.93542099], [76.26513672, 9.93514061], [76.26541901, 9.93514061], [76.26541901, 9.93457985], [76.26569366, 9.93458271], [76.26569366, 9.93430519], [76.26597595, 9.93431091], [76.26597595, 9.93403053], [76.26625061, 9.93403053], [76.26625061, 9.93374157], [76.26680756, 9.93375111], [76.26680756, 9.93291664], [76.26708221, 9.93292141], [76.26708221, 9.93264103], [76.26735687, 9.93264103], [76.26735687, 9.93236065], [76.26763916, 9.93236065], [76.26763916, 9.93208218], [76.26875305, 9.93208218], [76.26875305, 9.93236065], [76.26902771, 9.93236065], [76.26902771, 9.93208218], [76.26930237, 9.93208218], [76.26930237, 9.93125057], [76.26985931, 9.93125057], [76.26985931, 9.93097019], [76.2701416, 9.93097305], [76.2701416, 9.93069458], [76.27041626, 9.93069458], [76.27041626, 9.93041611], [76.27069092, 9.93042088], [76.27069092, 9.93014145], [76.27097321, 9.93014145], [76.27097321, 9.92986012], [76.27124786, 9.92986012], [76.27124786, 9.92958546], [76.27180481, 9.92958546], [76.27180481, 9.92930698], [76.27263641, 9.92930889], [76.27263641, 9.92903137], [76.27319336, 9.92903137], [76.27319336, 9.92875004], [76.27348328, 9.92875004], [76.27348328, 9.92846966], [76.27402496, 9.92847157], [76.27402496, 9.92837048], [76.27402496, 9.92819405], [76.27458191, 9.92819405], [76.27458191, 9.92791557], [76.27513885, 9.92793179], [76.27513885, 9.92763996], [76.2756958, 9.92763996], [76.2756958, 9.92735958], [76.27625275, 9.92736244], [76.27625275, 9.92708206], [76.2765274, 9.92708206], [76.2765274, 9.92680645], [76.27707672, 9.92681122], [76.27707672, 9.92653275], [76.2776413, 9.92653275], [76.2776413, 9.92625046], [76.27819061, 9.92625046], [76.27819824, 9.92597198], [76.2784729, 9.92597198], [76.2784729, 9.92569447], [76.27902985, 9.92569447], [76.27902985, 9.92541599], [76.27958679, 9.92542076], [76.27958679, 9.92514038], [76.28013611, 9.92514038], [76.28013611, 9.92486], [76.28069305, 9.92486], [76.28069305, 9.92458439], [76.28097534, 9.92458439], [76.28097534, 9.92430592], [76.28151703, 9.92431068], [76.28151703, 9.9240303], [76.2820816, 9.9240303], [76.2820816, 9.92374992], [76.28263855, 9.92374992], [76.28263855, 9.92346954], [76.28347015, 9.9234724], [76.28347015, 9.92319393], [76.28430176, 9.92319393], [76.28430176, 9.92291641], [76.28542328, 9.92292023], [76.28542328, 9.92263985], [76.28624725, 9.92263985], [76.28624725, 9.92236042], [76.28708649, 9.92236233], [76.28708649, 9.92208385], [76.28819275, 9.92208385], [76.28819275, 9.92180634], [76.28930664, 9.92180634], [76.28930664, 9.92152786], [76.29264069, 9.92152977], [76.29264069, 9.92125034], [76.29291534, 9.92125034], [76.29291534, 9.92097187], [76.29319763, 9.92097187], [76.29319763, 9.92069435], [76.29347229, 9.92069435], [76.29347229, 9.92041779], [76.29374695, 9.92041969], [76.29374695, 9.92014027], [76.29429626, 9.92014027], [76.29429626, 9.91986179], [76.29458618, 9.91986179], [76.29458618, 9.91930962], [76.29485321, 9.91930962], [76.29485321, 9.91847229], [76.2951355, 9.91847229], [76.2951355, 9.91791534], [76.29541779, 9.91792011], [76.29541779, 9.91681004], [76.29569244, 9.91681004], [76.29569244, 9.91541958], [76.2959671, 9.91541958], [76.2959671, 9.91347122], [76.29624939, 9.91347122], [76.29624939, 9.90909958], [76.29624939, 9.89958191], [76.29652405, 9.89958191], [76.29652405, 9.89735985], [76.29680634, 9.89735985], [76.29680634, 9.89569378], [76.29708099, 9.89569378], [76.29708099, 9.89402771], [76.29680634, 9.89402962], [76.29680634, 9.89319134], [76.29666901, 9.89319134], [76.29652405, 9.8931942], [76.29652405, 9.89291573], [76.29569244, 9.89291573], [76.29569244, 9.89347172], [76.29541779, 9.89346886], [76.29541779, 9.89402962], [76.29514313, 9.89402962], [76.29514313, 9.89431], [76.29486084, 9.89430618], [76.29486084, 9.8945837], [76.29458618, 9.89457035], [76.29458618, 9.89513969], [76.29429626, 9.89513969], [76.29429626, 9.89542007], [76.29402924, 9.89541626], [76.29402924, 9.89569378], [76.29374695, 9.89569378], [76.29374695, 9.89597225], [76.29347229, 9.89597034], [76.29347229, 9.89625168], [76.29264069, 9.89625168], [76.29264069, 9.89653015], [76.2923584, 9.89653015], [76.2923584, 9.89681053], [76.29208374, 9.89680576], [76.29208374, 9.89708424], [76.29152679, 9.89708424], [76.29152679, 9.89735985], [76.29125214, 9.89735985], [76.29125214, 9.89764023], [76.29096985, 9.89763069], [76.29096985, 9.89792061], [76.29069519, 9.89791584], [76.29069519, 9.89819431], [76.2904129, 9.89819431], [76.2904129, 9.89875031], [76.29013824, 9.89875031], [76.29013824, 9.89958191], [76.2904129, 9.89958191], [76.2904129, 9.90181065], [76.29013824, 9.90180588], [76.29013824, 9.9020853], [76.28985596, 9.90207958], [76.28985596, 9.9026413], [76.2895813, 9.9026413], [76.2895813, 9.90376186], [76.28930664, 9.90376186], [76.28930664, 9.90625095], [76.29013824, 9.90625095], [76.29013824, 9.90542126], [76.2904129, 9.90542126], [76.2904129, 9.90347004], [76.29069519, 9.9034729], [76.29069519, 9.9020853], [76.29096985, 9.9020853], [76.29096985, 9.90180588], [76.29347229, 9.90181065], [76.29347229, 9.9026413], [76.29319763, 9.90263844], [76.29319763, 9.90382099], [76.29319763, 9.9040308], [76.29291534, 9.90402889], [76.29291534, 9.90489006], [76.29291534, 9.90569496], [76.29264069, 9.90569496], [76.29264069, 9.90592861], [76.29264069, 9.90708256], [76.2923584, 9.9070797], [76.2923584, 9.90792084], [76.29208374, 9.90791702], [76.29208374, 9.90806961], [76.29208374, 9.90847301], [76.29096985, 9.90847301], [76.29096985, 9.90819454], [76.29069519, 9.90819454], [76.29069519, 9.90791702], [76.2904129, 9.90792084], [76.2904129, 9.90736103], [76.29013824, 9.90736103], [76.29013824, 9.90708256], [76.28874969, 9.9070797], [76.28874969, 9.90764141], [76.28847504, 9.90763855], [76.28847504, 9.90819454], [76.28819275, 9.90818977], [76.28819275, 9.90875053], [76.28791809, 9.90875053], [76.28791809, 9.90930939], [76.28652954, 9.90930939], [76.28652954, 9.90903091], [76.28624725, 9.90903091], [76.28624725, 9.90875053], [76.28598022, 9.90875053], [76.28598022, 9.90764141], [76.28569794, 9.90764141], [76.28569794, 9.90596962], [76.2859726, 9.90597343], [76.2859726, 9.90430355], [76.28624725, 9.90431118], [76.28624725, 9.9026413], [76.28652954, 9.9026413], [76.28652954, 9.90207958], [76.28624725, 9.9020853], [76.28624725, 9.90235996], [76.28369904, 9.90235996], [76.28291321, 9.90235996], [76.28291321, 9.9026413], [76.28180695, 9.9026413], [76.28180695, 9.90207958], [76.28152466, 9.9020853], [76.28152466, 9.90152836], [76.27984619, 9.90153122], [76.27984619, 9.90125275], [76.27874756, 9.90125275], [76.27874756, 9.90097046], [76.2776413, 9.90097237], [76.2776413, 9.90069389], [76.2765274, 9.90070057], [76.2765274, 9.90042114], [76.27540588, 9.90042114], [76.27540588, 9.90014267], [76.27458191, 9.90014267], [76.27458191, 9.89986038], [76.27263641, 9.89986038], [76.27263641, 9.90042114], [76.27236176, 9.90042114], [76.27236176, 9.90125275], [76.2720871, 9.90124989], [76.2720871, 9.9020853], [76.27179718, 9.90207958], [76.27179718, 9.90292072], [76.27153015, 9.90292072], [76.27153015, 9.90376186], [76.27124786, 9.90376186], [76.27124786, 9.90431118], [76.27097321, 9.90430355], [76.27097321, 9.90486145], [76.27069092, 9.90486145], [76.27069092, 9.90542126], [76.27041626, 9.90541744], [76.27041626, 9.90597343], [76.2701416, 9.90596962], [76.2701416, 9.90653133], [76.26985931, 9.90652657], [76.26985931, 9.90708256], [76.26957703, 9.9070797], [76.26957703, 9.90764141], [76.26930237, 9.90764141], [76.26930237, 9.90792084], [76.26902771, 9.90791702], [76.26902771, 9.90819454], [76.26875305, 9.90818977], [76.26875305, 9.90875053], [76.26847076, 9.90875053], [76.26847076, 9.90903091], [76.26819611, 9.90903091], [76.26819611, 9.90930939], [76.26791382, 9.90930462], [76.26791382, 9.90958309], [76.26763916, 9.90957069], [76.26763916, 9.91014099], [76.26735687, 9.91014099], [76.26735687, 9.91181183], [76.26708221, 9.91180515], [76.26708221, 9.91208267], [76.26652527, 9.91208267], [76.26652527, 9.91236115], [76.26597595, 9.91236115], [76.26597595, 9.91208267], [76.26569366, 9.91208267], [76.26569366, 9.91125107], [76.26597595, 9.91125107], [76.26597595, 9.91041946], [76.26625061, 9.91041946], [76.26625061, 9.90957069], [76.26652527, 9.90958309], [76.26652527, 9.90902901], [76.26680756, 9.90903091], [76.26680756, 9.90847111], [76.26708221, 9.90847301], [76.26708221, 9.90791702], [76.26735687, 9.90792084], [76.26735687, 9.90736103], [76.26763916, 9.90736103], [76.26763916, 9.90680695], [76.26791382, 9.90680695], [76.26791382, 9.90625095], [76.26819611, 9.90625095], [76.26819611, 9.90569019], [76.26847076, 9.90569496], [76.26847076, 9.90513897], [76.26875305, 9.90514088], [76.26875305, 9.9040308], [76.26902771, 9.9040308], [76.26902771, 9.90376186], [76.2701416, 9.90376186], [76.2701416, 9.90125275], [76.26985931, 9.90125275], [76.26985931, 9.90097046], [76.26958466, 9.90097237], [76.26958466, 9.90069389], [76.26930237, 9.90070057], [76.26930237, 9.90014267], [76.26902771, 9.90014267], [76.26902771, 9.89986038], [76.26875305, 9.89986229], [76.26875305, 9.89958382], [76.26791382, 9.89958191], [76.26791382, 9.8993063], [76.26763916, 9.89931107], [76.26763916, 9.89902973], [76.26735687, 9.89902973], [76.26735687, 9.89875031], [76.26708221, 9.89875031], [76.26708221, 9.89708424], [76.26680756, 9.89708424], [76.26680756, 9.89680576], [76.2665329, 9.89681053], [76.2665329, 9.89653015], [76.26597595, 9.89653015], [76.26597595, 9.89681053], [76.26541901, 9.89680576], [76.26541901, 9.89708424], [76.26513672, 9.89708424], [76.26513672, 9.89764023], [76.26486969, 9.89763069], [76.26486969, 9.89902973], [76.26403046, 9.89902782], [76.26403046, 9.89958191], [76.26374817, 9.89958191], [76.26374817, 9.90014267], [76.26346588, 9.90014267], [76.26346588, 9.90070057], [76.26374817, 9.90069389], [76.26374817, 9.9020853], [76.26347351, 9.9020853], [76.26347351, 9.90319443], [76.26319122, 9.90318966], [76.26319122, 9.9040308], [76.26291656, 9.9040308], [76.26291656, 9.90514088], [76.26264191, 9.90514088], [76.26264191, 9.90625095], [76.26235962, 9.90625095], [76.26235962, 9.90708256], [76.26210022, 9.9070797], [76.26210022, 9.90792084], [76.26180267, 9.90791702], [76.26180267, 9.90847301], [76.26152802, 9.90847111], [76.26152802, 9.90930939], [76.26125336, 9.90930939], [76.26125336, 9.91014099], [76.26097107, 9.91013908], [76.26097107, 9.91069508], [76.26069641, 9.91069126], [76.26069641, 9.91125107], [76.26040649, 9.91125107], [76.26040649, 9.91181183], [76.26013947, 9.91180515], [76.26013947, 9.91236115], [76.25985718, 9.91236115], [76.25985718, 9.91264057], [76.25930786, 9.91264057], [76.25930786, 9.91431046], [76.25902557, 9.91430473], [76.25902557, 9.91486073], [76.25875092, 9.91486073], [76.25875092, 9.9151392], [76.25846863, 9.9151392], [76.25846863, 9.91541958], [76.25818634, 9.91541958], [76.25818634, 9.91569996], [76.25736237, 9.91569996], [76.25736237, 9.91292191], [76.25763702, 9.91292191], [76.25763702, 9.91236115], [76.25791931, 9.91236115], [76.25791931, 9.91208267], [76.25819397, 9.91208267], [76.25819397, 9.91152668], [76.25791931, 9.9115324], [76.25791931, 9.91097069], [76.25763702, 9.9109726], [76.25763702, 9.9104166], [76.25736237, 9.91041946], [76.25736237, 9.90986061], [76.25708008, 9.90986061], [76.25708008, 9.90930462], [76.25736237, 9.90930939], [76.25736237, 9.90903091], [76.25791931, 9.90903091], [76.25791931, 9.90875053], [76.25846863, 9.90875053], [76.25846863, 9.90818977], [76.25875092, 9.90819454], [76.25875092, 9.90763855], [76.2590332, 9.90764141], [76.2590332, 9.90569019], [76.25736237, 9.90569496], [76.25736237, 9.90541744], [76.25763702, 9.90542126], [76.25763702, 9.90486145], [76.25791931, 9.90486145], [76.25791931, 9.90430355], [76.25818634, 9.90431118], [76.25818634, 9.90097046], [76.25846863, 9.90097237], [76.25846863, 9.8993063], [76.25875092, 9.89931107], [76.25875092, 9.89846992], [76.25902557, 9.89847183], [76.25902557, 9.89764023], [76.25930786, 9.89764023], [76.25930786, 9.89680576], [76.25958252, 9.89681053], [76.25958252, 9.89597034], [76.25986481, 9.89597225], [76.25986481, 9.89541626], [76.26013947, 9.89542007], [76.26013947, 9.89486027], [76.26041412, 9.89486217], [76.26041412, 9.89402771], [76.26069641, 9.89402962], [76.26069641, 9.89346886], [76.26097107, 9.89347172], [76.26097107, 9.89291573], [76.26125336, 9.89291954], [76.26125336, 9.89153194], [76.26097107, 9.89153194], [76.26097107, 9.89124966], [76.26125336, 9.89124966], [76.26125336, 9.8906889], [76.26152802, 9.89069557], [76.26152802, 9.89013958], [76.2618103, 9.89013958], [76.2618103, 9.88903046], [76.26210022, 9.88903046], [76.26210022, 9.88819122], [76.26235962, 9.88819313], [76.26235962, 9.88708305], [76.26264191, 9.88708305], [76.26264191, 9.88541698], [76.26291656, 9.88541889], [76.26291656, 9.88402939], [76.26319122, 9.88402939], [76.26319122, 9.88319016], [76.26347351, 9.88319492], [76.26347351, 9.8829174], [76.26374817, 9.88291931], [76.26374817, 9.88236141], [76.26403046, 9.88236141], [76.26403046, 9.88208294], [76.26430511, 9.88208294], [76.26430511, 9.88180542], [76.26457977, 9.88180923], [76.26457977, 9.88125134], [76.26486206, 9.88125134], [76.26486206, 9.88097286], [76.26513672, 9.88097286], [76.26513672, 9.87958336], [76.26541901, 9.87959194], [76.26541901, 9.87847042], [76.26569366, 9.87847328], [76.26569366, 9.87736034], [76.26597595, 9.87736034], [76.26597595, 9.87625122], [76.26625061, 9.87625122], [76.26625061, 9.87513828], [76.2665329, 9.87514114], [76.2665329, 9.87374973], [76.26680756, 9.87374973], [76.26680756, 9.87263966], [76.26708221, 9.87263966], [76.26708221, 9.87181091], [76.26763916, 9.87181091], [76.26763916, 9.87152958], [76.26819611, 9.87152958], [76.26819611, 9.87097168], [76.26847076, 9.87097168], [76.26847076, 9.87014008], [76.26875305, 9.87014008], [76.26875305, 9.86903], [76.26902771, 9.86903], [76.26902771, 9.86791992], [76.26930237, 9.86791992], [76.26930237, 9.86680984], [76.26957703, 9.86680984], [76.26957703, 9.86625195], [76.27069092, 9.86625195], [76.27069092, 9.86653042], [76.27124786, 9.86653042], [76.27124786, 9.86680984], [76.2720871, 9.86680603], [76.2720871, 9.86708355], [76.27263641, 9.86708355], [76.27263641, 9.86736202], [76.27348328, 9.86736202], [76.27348328, 9.86765099], [76.27404022, 9.86765099], [76.27404022, 9.86791992], [76.27485657, 9.86791992], [76.27485657, 9.86931133], [76.27458191, 9.86931133], [76.27458191, 9.87042046], [76.27430725, 9.87042046], [76.27430725, 9.87152958], [76.27404022, 9.87152958], [76.27404022, 9.87263966], [76.27375031, 9.87263966], [76.27375031, 9.87374973], [76.27404022, 9.87374973], [76.27404022, 9.87431145], [76.27485657, 9.87431145], [76.27485657, 9.87403107], [76.27513885, 9.87403107], [76.27513885, 9.87374973], [76.2756958, 9.87374973], [76.2756958, 9.87345886], [76.27597046, 9.87347221], [76.27597046, 9.87263775], [76.27625275, 9.87263966], [76.27625275, 9.87207985], [76.27597046, 9.87208366], [76.27597046, 9.87152767], [76.27625275, 9.87152958], [76.27625275, 9.87068939], [76.2765274, 9.87069416], [76.2765274, 9.87014008], [76.27680969, 9.87014008], [76.27680969, 9.86957932], [76.27708435, 9.86958408], [76.27708435, 9.86930561], [76.27819824, 9.86930561], [76.27819824, 9.86958408], [76.27874756, 9.86958408], [76.27874756, 9.8698597], [76.27929688, 9.8698597], [76.27929688, 9.87014008], [76.27958679, 9.87014008], [76.27958679, 9.87069416], [76.27986145, 9.87069416], [76.27986145, 9.87097168], [76.28013611, 9.87097168], [76.28013611, 9.87125015], [76.2804184, 9.87125015], [76.2804184, 9.87152958], [76.28069305, 9.87152958], [76.28069305, 9.87181091], [76.28098297, 9.87181091], [76.28098297, 9.87374973], [76.28125, 9.87374973], [76.28125, 9.87403107], [76.28151703, 9.87403107], [76.28152466, 9.87597179], [76.28125, 9.87597179], [76.28125, 9.87708473], [76.28098297, 9.87707996], [76.28098297, 9.87764072], [76.28069305, 9.87763882], [76.28069305, 9.87819481], [76.2804184, 9.87819481], [76.2804184, 9.8787508], [76.28013611, 9.8787508], [76.28013611, 9.87931061], [76.27984619, 9.87931061], [76.27984619, 9.88180923], [76.27958679, 9.88180542], [76.27958679, 9.88319016], [76.27929688, 9.88319969], [76.27929688, 9.88375092], [76.27902985, 9.88374901], [76.27902985, 9.88458347], [76.27874756, 9.88458061], [76.27874756, 9.88514137], [76.2784729, 9.88513947], [76.2784729, 9.88736057], [76.27819824, 9.88736057], [76.27819824, 9.88764191], [76.27791595, 9.88764191], [76.27791595, 9.88792038], [76.2776413, 9.88791656], [76.2776413, 9.88819313], [76.27735901, 9.88819122], [76.27735901, 9.88876057], [76.27707672, 9.88876057], [76.27707672, 9.88931179], [76.27680969, 9.88931179], [76.27680969, 9.89013958], [76.2765274, 9.89013958], [76.2765274, 9.89124966], [76.27625275, 9.89124966], [76.27625275, 9.89208412], [76.27597046, 9.89208412], [76.27597046, 9.8931942], [76.2756958, 9.89319134], [76.2756958, 9.89402962], [76.27597046, 9.89402962], [76.27597046, 9.89431], [76.27625275, 9.89430618], [76.27625275, 9.8945837], [76.27735901, 9.8945837], [76.27735901, 9.89430618], [76.27791595, 9.89431], [76.27791595, 9.89402962], [76.2784729, 9.89402962], [76.2784729, 9.89375019], [76.27874756, 9.89375019], [76.27874756, 9.8931942], [76.27902985, 9.8931942], [76.27902985, 9.88791656], [76.27958679, 9.88791656], [76.27958679, 9.88819313], [76.27986145, 9.88819313], [76.27986145, 9.88847446], [76.28013611, 9.88847065], [76.28013611, 9.88903046], [76.2804184, 9.88903046], [76.2804184, 9.88931179], [76.28069305, 9.88930511], [76.28069305, 9.88958263], [76.28098297, 9.88958073], [76.28098297, 9.89013958], [76.28125, 9.89013958], [76.28125, 9.89041996], [76.28151703, 9.89041996], [76.28151703, 9.89182186], [76.28180695, 9.89180565], [76.28180695, 9.89764023], [76.2820816, 9.89764023], [76.2820816, 9.89875031], [76.28263855, 9.89875031], [76.28263855, 9.89902973], [76.28320313, 9.89902973], [76.28320313, 9.89931107], [76.28375244, 9.8993063], [76.28375244, 9.89958191], [76.28430176, 9.89958191], [76.28430939, 9.89986229], [76.2848587, 9.89986038], [76.2848587, 9.90042114], [76.28569794, 9.90042114], [76.28569794, 9.90070057], [76.28624725, 9.90070057], [76.28624725, 9.90042114], [76.28652954, 9.90042114], [76.28652954, 9.89986038], [76.2868042, 9.89986229], [76.2868042, 9.8993063], [76.28708649, 9.89931107], [76.28708649, 9.89902973], [76.28736115, 9.89902973], [76.28736115, 9.89846992], [76.2876358, 9.89847183], [76.2876358, 9.89819431], [76.28736115, 9.89819431], [76.28736115, 9.89791584], [76.28708649, 9.89792061], [76.28708649, 9.89763069], [76.2868042, 9.89764023], [76.2868042, 9.89735985], [76.28652954, 9.89735985], [76.28652954, 9.89708424], [76.28624725, 9.89708424], [76.28624725, 9.89680576], [76.28598022, 9.89681053], [76.28598022, 9.89625168], [76.28624725, 9.89625168], [76.28624725, 9.89542007], [76.28652954, 9.89542007], [76.28652954, 9.89431], [76.28679657, 9.89431], [76.28679657, 9.89319134], [76.28708649, 9.8931942], [76.28708649, 9.89208412], [76.28736115, 9.89208412], [76.28736115, 9.89124966], [76.28848267, 9.89124966], [76.28848267, 9.89041996], [76.28874969, 9.89041996], [76.28874969, 9.88958073], [76.28902435, 9.88958263], [76.28902435, 9.88847446], [76.28930664, 9.88847446], [76.28930664, 9.88736057], [76.2895813, 9.88736057], [76.2895813, 9.88624859], [76.28985596, 9.88625145], [76.28985596, 9.88486099], [76.29013824, 9.88486099], [76.29013824, 9.88374901], [76.2904129, 9.88375092], [76.2904129, 9.88347054], [76.29013824, 9.8834734], [76.29013824, 9.8829174], [76.2904129, 9.88291931], [76.2904129, 9.88180923], [76.29070282, 9.88180923], [76.29070282, 9.88042068], [76.29096985, 9.88042068], [76.29096985, 9.87931061], [76.29125214, 9.87931061], [76.29125214, 9.8787508], [76.29152679, 9.8787508], [76.29152679, 9.87813091], [76.29152679, 9.87680435], [76.29180908, 9.87681961], [76.29180908, 9.87486267], [76.29207611, 9.87486267], [76.29207611, 9.87319183], [76.2923584, 9.87319374], [76.2923584, 9.87208366], [76.29264069, 9.87208366], [76.29264069, 9.87152767], [76.29292297, 9.87152958], [76.29292297, 9.87068939], [76.29319763, 9.87069416], [76.29319763, 9.87014008], [76.29347229, 9.87014008], [76.29347229, 9.86957932], [76.29374695, 9.86958408], [76.29374695, 9.86874962], [76.29402924, 9.86874962], [76.29402924, 9.86818886], [76.29430389, 9.86819363], [76.29430389, 9.86736202], [76.29458618, 9.86736202], [76.29458618, 9.86652756], [76.29485321, 9.86653042], [76.29485321, 9.86291981], [76.29458618, 9.86291981], [76.29458618, 9.86125183], [76.29429626, 9.86125183], [76.29429626, 9.85986137], [76.29458618, 9.85986137], [76.29458618, 9.8587513], [76.29486084, 9.8587513], [76.29485321, 9.8579216], [76.29514313, 9.8579216], [76.29514313, 9.85736084], [76.29541779, 9.85736084], [76.29541779, 9.85708141], [76.29569244, 9.85708332], [76.29569244, 9.85652733], [76.2959671, 9.85652924], [76.2959671, 9.85624886], [76.29624939, 9.85624886], [76.29624939, 9.85569477], [76.29652405, 9.85569477], [76.29652405, 9.85513878], [76.29680634, 9.85514069], [76.29680634, 9.85457993], [76.29708099, 9.85458279], [76.29708099, 9.85291672], [76.29680634, 9.85292053], [76.29680634, 9.85236073], [76.29651642, 9.85236073], [76.29651642, 9.85181141], [76.29624939, 9.85181141], [76.29624939, 9.85125065], [76.29514313, 9.85125065], [76.29514313, 9.85097027], [76.2923584, 9.85097027], [76.2923584, 9.85125065], [76.29207611, 9.85125065], [76.29207611, 9.85181141], [76.29180908, 9.85180664], [76.29180908, 9.85208321], [76.2895813, 9.85208321], [76.2895813, 9.85180664], [76.28901672, 9.85181141], [76.28901672, 9.85153103], [76.28848267, 9.85153103], [76.28848267, 9.85125065], [76.28819275, 9.85125065], [76.28819275, 9.85097027], [76.2876358, 9.85097313], [76.2876358, 9.85069466], [76.28572083, 9.85069466], [76.2848587, 9.85069466], [76.2848587, 9.85041714], [76.28347015, 9.85042095], [76.28347015, 9.84986019], [76.28375244, 9.84986019], [76.28375244, 9.84875011], [76.2840271, 9.84875011], [76.2840271, 9.84792137], [76.28430176, 9.84792137], [76.28430176, 9.84708023], [76.28458405, 9.84708214], [76.28458405, 9.84624958], [76.2848587, 9.84624958], [76.2848587, 9.84569168], [76.28514099, 9.84569359], [76.28514099, 9.84486008], [76.28541565, 9.84486008], [76.28541565, 9.84460926], [76.28541565, 9.84402847], [76.28569794, 9.84403038], [76.28569794, 9.84348106], [76.28457642, 9.84348106], [76.28457642, 9.84318924], [76.28430176, 9.84319401], [76.28430176, 9.84263992], [76.2840271, 9.84263992], [76.2840271, 9.84208202], [76.28375244, 9.84208393], [76.28375244, 9.84125042], [76.28347015, 9.84125042], [76.28347015, 9.84041786], [76.28320313, 9.84041977], [76.28320313, 9.83958054], [76.28291321, 9.83958435], [76.28291321, 9.83902836], [76.28320313, 9.83903027], [76.28320313, 9.83847237], [76.28347015, 9.83847237], [76.28347015, 9.83791542], [76.28375244, 9.83792019], [76.28375244, 9.83681011], [76.2840271, 9.83681011], [76.2840271, 9.83513927], [76.28430176, 9.83513927], [76.28430176, 9.8334713], [76.28458405, 9.8334713], [76.28458405, 9.83263874], [76.28514099, 9.8326416], [76.28514099, 9.83292198], [76.2859726, 9.83291721], [76.2859726, 9.83319473], [76.28679657, 9.83319092], [76.28679657, 9.83375072], [76.28652954, 9.83375072], [76.28652954, 9.83430958], [76.28902435, 9.83430481], [76.28902435, 9.8348608], [76.28930664, 9.83485889], [76.28930664, 9.83541965], [76.2895813, 9.83541775], [76.2895813, 9.83736229], [76.28985596, 9.83735943], [76.28985596, 9.83763981], [76.29374695, 9.83763981], [76.29374695, 9.83792019], [76.29402924, 9.83792019], [76.29402924, 9.83875179], [76.29374695, 9.83875179], [76.29374695, 9.84041977], [76.29347229, 9.84041786], [76.29347229, 9.84208393], [76.29319763, 9.84208393], [76.29319763, 9.84319401], [76.29292297, 9.84318924], [76.29292297, 9.84348106], [76.29264069, 9.84348106], [76.29264069, 9.84403038], [76.29347229, 9.84402847], [76.29347229, 9.84486008], [76.29319763, 9.84486008], [76.29319763, 9.84597206], [76.29292297, 9.84597015], [76.29292297, 9.84624958], [76.2923584, 9.84624958], [76.2923584, 9.84652805], [76.29180908, 9.84652138], [76.29180908, 9.84681129], [76.29152679, 9.84680557], [76.29152679, 9.84736156], [76.29125214, 9.84735966], [76.29125214, 9.84792137], [76.29096985, 9.84791565], [76.29096985, 9.84819412], [76.29070282, 9.84819031], [76.29070282, 9.84875011], [76.2904129, 9.84875011], [76.2904129, 9.84903145], [76.29070282, 9.84903145], [76.29070282, 9.84931087], [76.29096985, 9.8493042], [76.29096985, 9.84958458], [76.29125214, 9.84958458], [76.29125214, 9.84986019], [76.2923584, 9.84986019], [76.2923584, 9.85014057], [76.29429626, 9.85014057], [76.29429626, 9.85042095], [76.29624939, 9.85041714], [76.29624939, 9.85069466], [76.29708099, 9.85069466], [76.29708099, 9.85041714], [76.29736328, 9.85042095], [76.29736328, 9.85014057], [76.29846954, 9.85014057], [76.29846954, 9.84986019], [76.29875183, 9.84986019], [76.29875183, 9.84958458], [76.29930878, 9.84958458], [76.29930878, 9.84902859], [76.29902649, 9.84903145], [76.29902649, 9.84764099], [76.29930878, 9.84764099], [76.29930878, 9.84514046], [76.29957581, 9.84514046], [76.29957581, 9.84375], [76.30069733, 9.84375], [76.30069733, 9.84403038], [76.30097198, 9.84402847], [76.30097198, 9.84458447], [76.30124664, 9.84458447], [76.30124664, 9.84486008], [76.30152893, 9.84486008], [76.30152893, 9.84542274], [76.30180359, 9.84541607], [76.30180359, 9.84569359], [76.30208588, 9.84569168], [76.30208588, 9.84624958], [76.30236053, 9.84624958], [76.30236053, 9.84681129], [76.30263519, 9.84680557], [76.30263519, 9.84735966], [76.30291748, 9.84735966], [76.30291748, 9.84931087], [76.30263519, 9.8493042], [76.30263519, 9.84986019], [76.30236053, 9.84986019], [76.30236053, 9.85042095], [76.30152893, 9.85042095], [76.30152893, 9.85014057], [76.29985809, 9.85013771], [76.29985809, 9.85069466], [76.29930878, 9.85069466], [76.29930878, 9.85097313], [76.29875183, 9.85097027], [76.29875183, 9.85125065], [76.29902649, 9.85125065], [76.29902649, 9.85153103], [76.29930878, 9.85152912], [76.29930878, 9.85208321], [76.30041504, 9.85208321], [76.30041504, 9.85236073], [76.30124664, 9.85236073], [76.30124664, 9.85264969], [76.30152893, 9.85264969], [76.30152893, 9.85292053], [76.30180359, 9.85291672], [76.30180359, 9.85319519], [76.30208588, 9.85319519], [76.30208588, 9.85347271], [76.30253601, 9.85347271], [76.30291748, 9.85347271], [76.30291748, 9.85375118], [76.30252838, 9.85375118], [76.30236053, 9.85375118], [76.30236053, 9.85403061], [76.30208588, 9.85403061], [76.30208588, 9.85431194], [76.30152893, 9.85430527], [76.30152893, 9.85458279], [76.30124664, 9.85458279], [76.30124664, 9.85486126], [76.30069733, 9.85486126], [76.30069733, 9.85514069], [76.29985809, 9.85514069], [76.29985809, 9.85542107], [76.29902649, 9.85541725], [76.29902649, 9.85569477], [76.29875183, 9.85569477], [76.29875183, 9.85597324], [76.29846954, 9.85597324], [76.29846954, 9.85624886], [76.29818726, 9.85624886], [76.29818726, 9.85652924], [76.29792023, 9.85652924], [76.29792023, 9.85680866], [76.29763794, 9.85680485], [76.29763794, 9.85708332], [76.29736328, 9.85708141], [76.29736328, 9.85764122], [76.29708099, 9.85763931], [76.29708099, 9.8587513], [76.29680634, 9.8587513], [76.29680634, 9.86042023], [76.29651642, 9.86042023], [76.29651642, 9.86264038], [76.29680634, 9.86264038], [76.29680634, 9.86431026], [76.29652405, 9.86430645], [76.29652405, 9.86569405], [76.29624939, 9.86569118], [76.29624939, 9.86625195], [76.2959671, 9.86625195], [76.2959671, 9.86903], [76.29624939, 9.86903], [76.29624939, 9.87014008], [76.29597473, 9.87014008], [76.29597473, 9.87097168], [76.29569244, 9.87097168], [76.29569244, 9.87181091], [76.29541779, 9.87180614], [76.29541779, 9.87319374], [76.29569244, 9.87319374], [76.29569244, 9.87434959], [76.29569244, 9.87542057], [76.29541779, 9.8754158], [76.29541779, 9.87597179], [76.2951355, 9.87597179], [76.2951355, 9.87625122], [76.29541779, 9.87625122], [76.29541779, 9.87681961], [76.29569244, 9.87680435], [76.29569244, 9.88069534], [76.2959671, 9.88068962], [76.29597473, 9.88125134], [76.29569244, 9.88125134], [76.29569244, 9.88263893], [76.29541779, 9.88263035], [76.29541779, 9.88291931], [76.2951355, 9.8829174], [76.2951355, 9.8834734], [76.29458618, 9.88347054], [76.29458618, 9.88431168], [76.29429626, 9.88431168], [76.29429626, 9.88514137], [76.29458618, 9.88514137], [76.29458618, 9.88541889], [76.29486084, 9.88541698], [76.29486084, 9.88569546], [76.29514313, 9.88569069], [76.29514313, 9.88625145], [76.29541779, 9.88624859], [76.29541779, 9.88708305], [76.29569244, 9.88708305], [76.29569244, 9.88986206], [76.29652405, 9.88986206], [76.29652405, 9.88958263], [76.29763794, 9.88958263], [76.29763794, 9.88930511], [76.29818726, 9.88931179], [76.29818726, 9.88903046], [76.29846954, 9.88903046], [76.29846954, 9.88876057], [76.29875183, 9.88876057], [76.29875183, 9.88847065], [76.29902649, 9.88847446], [76.29902649, 9.88819313], [76.29930878, 9.88819313], [76.29930878, 9.88791656], [76.29957581, 9.88792038], [76.29957581, 9.88764191], [76.29985809, 9.88764191], [76.29985809, 9.88736057], [76.30014038, 9.88736057], [76.30014038, 9.88708305], [76.30041504, 9.88708305], [76.30041504, 9.88652706], [76.30069733, 9.88653183], [76.30069733, 9.88625145], [76.30097961, 9.88625145], [76.30097961, 9.88597107], [76.30152893, 9.88597107], [76.30152893, 9.88569546], [76.30180359, 9.88569546], [76.30180359, 9.88541698], [76.30208588, 9.88541889], [76.30208588, 9.88514137], [76.30236053, 9.88514137], [76.30236053, 9.88486099], [76.30263519, 9.88486099], [76.30263519, 9.88458347], [76.30291748, 9.88458347], [76.30291748, 9.884305], [76.30319214, 9.88431168], [76.30319214, 9.88402939], [76.30374908, 9.88402939], [76.30374908, 9.88375092], [76.30401611, 9.88375092], [76.30401611, 9.88347054], [76.30486298, 9.8834734], [76.30486298, 9.88319492], [76.30513763, 9.88319492], [76.30513763, 9.8829174], [76.30568695, 9.88291931], [76.30568695, 9.88263035], [76.30596924, 9.88263893], [76.30596924, 9.88236141], [76.30652618, 9.88236141], [76.30652618, 9.88208294], [76.30680847, 9.88208294], [76.30680847, 9.88180542], [76.30735779, 9.88180923], [76.30735779, 9.88152885], [76.30764008, 9.88152885], [76.30764008, 9.88125134], [76.30819702, 9.88125134], [76.30819702, 9.88097286], [76.30847168, 9.88097286], [76.30847168, 9.88041687], [76.30902863, 9.88042068], [76.30902863, 9.88014126], [76.30930328, 9.88014126], [76.30930328, 9.87986088], [76.30986023, 9.87986088], [76.30986023, 9.87958336], [76.31041718, 9.87959194], [76.31041718, 9.87931061], [76.31096649, 9.87931061], [76.31096649, 9.87903118], [76.31181335, 9.87903118], [76.31181335, 9.8787508], [76.31236267, 9.8787508], [76.31236267, 9.87847328], [76.31291962, 9.87847328], [76.31291962, 9.87819481], [76.31346893, 9.87819481], [76.31346893, 9.87791729], [76.31430817, 9.8779211], [76.31430817, 9.87764072], [76.31485748, 9.87764072], [76.31485748, 9.87736034], [76.31569672, 9.87736034], [76.31569672, 9.87708473], [76.31652832, 9.87708473], [76.31652832, 9.87680435], [76.31735992, 9.87681961], [76.31735992, 9.87653065], [76.31846619, 9.87653065], [76.31846619, 9.87625122], [76.31931305, 9.87625122], [76.31930542, 9.87485981], [76.31902313, 9.87486267], [76.31902313, 9.87403107], [76.31874847, 9.87403107], [76.31874847, 9.87345886], [76.31847382, 9.87347221], [76.31847382, 9.87291622], [76.31819153, 9.87292099], [76.31819153, 9.87181091], [76.31791687, 9.87181091], [76.31791687, 9.87125015], [76.31764221, 9.87125015], [76.31764221, 9.87014008], [76.31735992, 9.87014008], [76.31735992, 9.86903], [76.3170929, 9.86903], [76.3170929, 9.86818886], [76.31680298, 9.86819363], [76.31680298, 9.86652756], [76.3170929, 9.86653042], [76.3170929, 9.86597157], [76.31735992, 9.86597157], [76.31735992, 9.86541557], [76.3170929, 9.86542034], [76.3170929, 9.86514187], [76.31735992, 9.86514187], [76.31735992, 9.86403179], [76.31764221, 9.86403179], [76.31764221, 9.86374855], [76.31735992, 9.86374855], [76.31735992, 9.86264038], [76.3170929, 9.86264038], [76.3170929, 9.86180973], [76.31680298, 9.86180973], [76.31680298, 9.86152267], [76.31708527, 9.86152744], [76.31708527, 9.86124897], [76.31680298, 9.86125183], [76.31680298, 9.86097145], [76.31708527, 9.86097336], [76.31708527, 9.86013889], [76.31680298, 9.86013889], [76.31680298, 9.8587513], [76.31708527, 9.8587513], [76.31708527, 9.85847092], [76.31680298, 9.85847092], [76.31680298, 9.85791683], [76.31708527, 9.85791683], [76.31708527, 9.85708332], [76.31735992, 9.85708332], [76.31735992, 9.85597324], [76.31764221, 9.85597324], [76.31764221, 9.85569477], [76.31735992, 9.85569477], [76.31735992, 9.85375118], [76.31764221, 9.85375118], [76.31764221, 9.85347271], [76.31735992, 9.85347271], [76.31735992, 9.85236073], [76.31764221, 9.85236073], [76.31764221, 9.85125065], [76.31791687, 9.85125065], [76.31791687, 9.85014057], [76.31819153, 9.85014057], [76.31819153, 9.8495779], [76.31791687, 9.84958458], [76.31791687, 9.8493042], [76.31819153, 9.84931087], [76.31819153, 9.84903145], [76.31791687, 9.84903145], [76.31791687, 9.84875011], [76.31819153, 9.84875011], [76.31819153, 9.84846973], [76.31791687, 9.84847164], [76.31791687, 9.84791565], [76.31764221, 9.84792137], [76.31764221, 9.84735966], [76.31708527, 9.84736156], [76.31708527, 9.84680557], [76.31680298, 9.84681129], [76.31680298, 9.84624958], [76.3170929, 9.84624958], [76.3170929, 9.84597015], [76.31680298, 9.84597206], [76.31680298, 9.84486008], [76.31708527, 9.84486008], [76.31708527, 9.84375], [76.31735992, 9.84375], [76.31735992, 9.84318924], [76.31764221, 9.84319401], [76.31764221, 9.8423624], [76.31791687, 9.8423624], [76.31791687, 9.84069443], [76.31819153, 9.84069443], [76.31819153, 9.83958435], [76.31847382, 9.83958435], [76.31847382, 9.83930588], [76.31930542, 9.83930588], [76.31930542, 9.83958435], [76.31958008, 9.83958435], [76.31958008, 9.83902836], [76.31986237, 9.83903027], [76.31986237, 9.83847237], [76.32013702, 9.83847237], [76.32013702, 9.83736229], [76.32041931, 9.83736229], [76.32041931, 9.83652687], [76.32068634, 9.83652973], [76.32068634, 9.83597088], [76.32096863, 9.83597088], [76.32096863, 9.83541775], [76.32125092, 9.83541965], [76.32125092, 9.83485889], [76.32152557, 9.8348608], [76.32152557, 9.83430481], [76.32180786, 9.83430958], [76.32180786, 9.83375072], [76.3215332, 9.83375072], [76.3215332, 9.83319092], [76.32125092, 9.83319473], [76.32125092, 9.83263874], [76.32096863, 9.8326416], [76.32096863, 9.83125114], [76.32068634, 9.83125114], [76.32068634, 9.82736111], [76.32096863, 9.82736111], [76.32096863, 9.82430363], [76.32125092, 9.82431126], [76.32125092, 9.82403088], [76.32096863, 9.82403088], [76.32096863, 9.82347012], [76.32125092, 9.82347298], [76.32125092, 9.82263756], [76.3215332, 9.82264137], [76.3215332, 9.82181072], [76.32180786, 9.82181072], [76.32180786, 9.82069016], [76.32208252, 9.82069397], [76.32208252, 9.81930637], [76.32180786, 9.81931114], [76.32180786, 9.81818962], [76.32152557, 9.81819439], [76.32152557, 9.81708431], [76.32125092, 9.81708431], [76.32125092, 9.81597233], [76.32152557, 9.81597233], [76.32152557, 9.81513786], [76.32180786, 9.81514168], [76.32180786, 9.81458187], [76.32208252, 9.81458378], [76.32208252, 9.81264019], [76.32180786, 9.81264019], [76.32180786, 9.80764198], [76.32209015, 9.80764198], [76.32209015, 9.80681038], [76.32235718, 9.80681038], [76.32235718, 9.80625057], [76.32263947, 9.80625057], [76.32263947, 9.80597115], [76.32291412, 9.80597115], [76.32291412, 9.80569458], [76.32514191, 9.80569458], [76.32514191, 9.80597115], [76.32541656, 9.80597115], [76.32541656, 9.80569458], [76.32569122, 9.80569458], [76.32569122, 9.8040266], [76.32596588, 9.80403233], [76.32596588, 9.80291939], [76.32624817, 9.80291939], [76.32624817, 9.80264091], [76.32596588, 9.80264091], [76.32596588, 9.80180931], [76.32624817, 9.80180931], [76.32624817, 9.80154037], [76.32596588, 9.80154037], [76.32596588, 9.80097103], [76.32624817, 9.80097294], [76.32624817, 9.79986095], [76.32596588, 9.79986095], [76.32596588, 9.79903126], [76.32624817, 9.79903126], [76.32624817, 9.79875088], [76.32596588, 9.79875088], [76.32596588, 9.79818058], [76.32569122, 9.79819489], [76.32569122, 9.79736137], [76.32541656, 9.79736137], [76.32541656, 9.79652882], [76.32569122, 9.79653072], [76.32569122, 9.79514122], [76.32596588, 9.79514122], [76.32596588, 9.79458046], [76.32569122, 9.79458237], [76.32569122, 9.7943058], [76.32596588, 9.79431057], [76.32596588, 9.79403114], [76.32569122, 9.79403114], [76.32569122, 9.79319191], [76.32624817, 9.79319382], [76.32624817, 9.79263783], [76.32681274, 9.79263973], [76.32681274, 9.79207993], [76.32707977, 9.79208374], [76.32707977, 9.79152775], [76.32681274, 9.79152966], [76.32681274, 9.79014015], [76.32707977, 9.79014015], [76.32707977, 9.78903008], [76.32736206, 9.78903008], [76.32736206, 9.7881918], [76.32763672, 9.7881937], [76.32763672, 9.78791809], [76.32791901, 9.78792], [76.32791901, 9.78736019], [76.32819366, 9.7873621], [76.32819366, 9.78680611], [76.32875061, 9.78680992], [76.32875061, 9.78652954], [76.3290329, 9.78652954], [76.3290329, 9.78597164], [76.32958221, 9.78597164], [76.32958221, 9.78569412], [76.33013916, 9.78569412], [76.33013916, 9.78541565], [76.33040619, 9.78542042], [76.33040619, 9.78514194], [76.33096313, 9.78514194], [76.33096313, 9.78486156], [76.33152771, 9.78486156], [76.33152771, 9.78458405], [76.33180237, 9.78458405], [76.33180237, 9.78430557], [76.33207703, 9.78431034], [76.33207703, 9.78402996], [76.33235931, 9.78402996], [76.33235931, 9.7834692], [76.3326416, 9.78347111], [76.3326416, 9.78264046], [76.33291626, 9.78264046], [76.33291626, 9.78236198], [76.33319092, 9.78236198], [76.33319092, 9.78180504], [76.33347321, 9.78180981], [76.33347321, 9.78097057], [76.33374786, 9.78097439], [76.33374786, 9.78069305], [76.33403015, 9.78069305], [76.33403015, 9.78013897], [76.33429718, 9.78014183], [76.33429718, 9.77986145], [76.33486176, 9.77986145], [76.33486176, 9.77902699], [76.3345871, 9.77902889], [76.3345871, 9.77875137], [76.33403015, 9.77875137], [76.33403015, 9.77847099], [76.33374786, 9.77847099], [76.33374786, 9.77819538], [76.33347321, 9.77819538], [76.33347321, 9.7770834], [76.33374786, 9.7770834], [76.33374786, 9.77680492], [76.33347321, 9.77680969], [76.33347321, 9.77569008], [76.33319092, 9.77569485], [76.33319092, 9.77375126], [76.33291626, 9.77375126], [76.33291626, 9.77319527], [76.33347321, 9.77319527], [76.33347321, 9.7723608], [76.33374786, 9.7723608], [76.33374786, 9.77180672], [76.33403015, 9.77181053], [76.33403015, 9.77097034], [76.33430481, 9.77097321], [76.33430481, 9.77069473], [76.3345871, 9.77069473], [76.3345871, 9.76986027], [76.33486176, 9.76986027], [76.33486176, 9.76930428], [76.33513641, 9.76931095], [76.33513641, 9.76875114], [76.3354187, 9.76875114], [76.3354187, 9.76735973], [76.33569336, 9.76735973], [76.33569336, 9.76597214], [76.33597565, 9.76597214], [76.33597565, 9.76569366], [76.33625031, 9.76569366], [76.33625031, 9.76541615], [76.33708954, 9.76543045], [76.33708954, 9.76513958], [76.33790588, 9.76513958], [76.33790588, 9.76486015], [76.3381958, 9.76486015], [76.3381958, 9.76458359], [76.33847046, 9.76458359], [76.33847046, 9.76430607], [76.33875275, 9.76431084], [76.33875275, 9.76403046], [76.3390274, 9.76403046], [76.3390274, 9.76375008], [76.33930206, 9.76375008], [76.33930206, 9.7634697], [76.33958435, 9.7634716], [76.33958435, 9.76319408], [76.33985901, 9.76319408], [76.33985901, 9.76291561], [76.34041595, 9.76292038], [76.34041595, 9.76124954], [76.34012604, 9.76124954], [76.34012604, 9.75819111], [76.34041595, 9.75819397], [76.34041595, 9.75680637], [76.34069061, 9.75681019], [76.34069061, 9.75626087], [76.34041595, 9.75626087], [76.34041595, 9.7551403], [76.34012604, 9.7551403], [76.34012604, 9.75403023], [76.34041595, 9.75403023], [76.34041595, 9.75374889], [76.34012604, 9.75374889], [76.34012604, 9.75347137], [76.34041595, 9.75347137], [76.34041595, 9.75319481], [76.33985901, 9.75319958], [76.33985901, 9.75264168], [76.33957672, 9.75264168], [76.33957672, 9.7523613], [76.33930206, 9.7523613], [76.33930206, 9.75264168], [76.3390274, 9.75264168], [76.3390274, 9.75208092], [76.33875275, 9.75208282], [76.33875275, 9.75180531], [76.3390274, 9.75181198], [76.3390274, 9.75097084], [76.33957672, 9.75097084], [76.33957672, 9.75125122], [76.33985901, 9.75125122], [76.33985901, 9.75097084], [76.34012604, 9.75097084], [76.34012604, 9.75125122], [76.34208679, 9.75125122], [76.34208679, 9.75097084], [76.34236145, 9.75097084], [76.34236145, 9.75041676], [76.34208679, 9.75041866], [76.34208679, 9.74875069], [76.34179688, 9.74875069], [76.34179688, 9.74764061], [76.34208679, 9.74764061], [76.34208679, 9.74736118], [76.3418045, 9.74736118], [76.3418045, 9.74680519], [76.34152985, 9.74681187], [76.34152985, 9.74625111], [76.34124756, 9.74625111], [76.34124756, 9.74513912], [76.3409729, 9.74514103], [76.3409729, 9.74431992], [76.34069824, 9.74431992], [76.34069824, 9.74236012], [76.3409729, 9.74236012], [76.3409729, 9.74125004], [76.34124756, 9.74125957], [76.34124756, 9.73681068], [76.34152985, 9.73681068], [76.34152985, 9.73596954], [76.3418045, 9.7359724], [76.3418045, 9.73541641], [76.34152985, 9.73542023], [76.34152985, 9.73486042], [76.34124756, 9.73486233], [76.34124756, 9.73152828], [76.34152985, 9.73153019], [76.34152985, 9.72985935], [76.3418045, 9.72986221], [76.3418045, 9.72874928], [76.34208679, 9.72874928], [76.34208679, 9.72791767], [76.34236145, 9.72791958], [76.34236145, 9.7276392], [76.34263611, 9.7276392], [76.34263611, 9.72736073], [76.3429184, 9.72736073], [76.3429184, 9.72708321], [76.34319305, 9.72708321], [76.34319305, 9.72680473], [76.34375, 9.72681046], [76.34375, 9.72597122], [76.34430695, 9.72597122], [76.34430695, 9.72541714], [76.3445816, 9.72542191], [76.3445816, 9.72431183], [76.34485626, 9.72431183], [76.34485626, 9.72375107], [76.34513855, 9.72375107], [76.34513855, 9.72153091], [76.34485626, 9.72153091], [76.34485626, 9.71875095], [76.34513855, 9.71875095], [76.34513855, 9.71709156], [76.34485626, 9.71709156], [76.34485626, 9.71597004], [76.34513855, 9.7159729], [76.34513855, 9.71569538], [76.34486389, 9.71569538], [76.34486389, 9.71374989], [76.34513855, 9.71375275], [76.34513855, 9.71319199], [76.3456955, 9.71319389], [76.3456955, 9.71291637], [76.34625244, 9.71292114], [76.34625244, 9.71264267], [76.34707642, 9.71264267], [76.34707642, 9.71208191], [76.34764099, 9.71208191], [76.34764099, 9.7118063], [76.34819794, 9.7118063], [76.34819794, 9.71208191], [76.34902954, 9.71208191], [76.34902954, 9.71319389], [76.34874725, 9.71319199], [76.34874725, 9.71431065], [76.3484726, 9.71430683], [76.3484726, 9.71458244], [76.34874725, 9.71458244], [76.34874725, 9.71736145], [76.34902954, 9.71736145], [76.34902954, 9.71792126], [76.3493042, 9.71791744], [76.3493042, 9.71819496], [76.34958649, 9.71819019], [76.34958649, 9.71903133], [76.34986115, 9.71903133], [76.34986115, 9.72042084], [76.34958649, 9.72041702], [76.34958649, 9.72069454], [76.34986115, 9.72069454], [76.34986115, 9.72097301], [76.34958649, 9.72097111], [76.34958649, 9.72153091], [76.34986115, 9.72153091], [76.34986115, 9.72180939], [76.34958649, 9.72180462], [76.34958649, 9.72208309], [76.34986115, 9.72208309], [76.34986115, 9.72486115], [76.34958649, 9.72486115], [76.34958649, 9.72597122], [76.34929657, 9.72597122], [76.34929657, 9.72681046], [76.34902954, 9.72680473], [76.34902954, 9.72708321], [76.34874725, 9.72708321], [76.34874725, 9.72736073], [76.3484726, 9.72736073], [76.3484726, 9.7284708], [76.34819794, 9.72847366], [76.34819794, 9.72986221], [76.34791565, 9.72986221], [76.34791565, 9.73069572], [76.34764099, 9.73069572], [76.34764099, 9.73124981], [76.3473587, 9.73124981], [76.3473587, 9.73153019], [76.34708405, 9.73152828], [76.34708405, 9.73208427], [76.34680939, 9.73206997], [76.34680176, 9.73291969], [76.3465271, 9.73291779], [76.3465271, 9.73319435], [76.34625244, 9.73319054], [76.34625244, 9.7343111], [76.34597015, 9.7343111], [76.34597015, 9.73624992], [76.34570312, 9.73624992], [76.34570312, 9.73931122], [76.34541321, 9.73931122], [76.34541321, 9.7404213], [76.3456955, 9.74041557], [76.3456955, 9.74097157], [76.34597015, 9.74096966], [76.34597015, 9.74125957], [76.3465271, 9.74125004], [76.3465271, 9.74236012], [76.34680176, 9.74236012], [76.34680176, 9.74292088], [76.3465271, 9.74291706], [76.3465271, 9.74347305], [76.34680176, 9.74347019], [76.34680939, 9.74375057], [76.34707642, 9.74375057], [76.34707642, 9.74542141], [76.34680939, 9.74542141], [76.34680176, 9.74681187], [76.3465271, 9.74680519], [76.3465271, 9.74736118], [76.34680176, 9.74736118], [76.34680176, 9.74792194], [76.3465271, 9.74792194], [76.3465271, 9.75041866], [76.34625244, 9.75041676], [76.34625244, 9.75069523], [76.34597015, 9.75069523], [76.34597015, 9.75125122], [76.3456955, 9.75125122], [76.3456955, 9.75208282], [76.34541321, 9.75208092], [76.34541321, 9.75319958], [76.34513855, 9.75319481], [76.34513855, 9.75374889], [76.34485626, 9.75374889], [76.34485626, 9.75430965], [76.3445816, 9.75430489], [76.3445816, 9.75486088], [76.34430695, 9.75486088], [76.34430695, 9.7551403], [76.34375, 9.7551403], [76.34375, 9.75541973], [76.3429184, 9.75541782], [76.3429184, 9.75569344], [76.34263611, 9.75569344], [76.34263611, 9.75597095], [76.34208679, 9.75597095], [76.34208679, 9.75652981], [76.3418045, 9.7565279], [76.3418045, 9.75708389], [76.34152985, 9.75708389], [76.34152985, 9.75958443], [76.3418045, 9.75958443], [76.3418045, 9.76097202], [76.34152985, 9.76097202], [76.34152985, 9.76208401], [76.34124756, 9.7620697], [76.34124756, 9.76264], [76.3409729, 9.76264], [76.3409729, 9.76292038], [76.34069824, 9.76291561], [76.34069824, 9.7634716], [76.34041595, 9.7634697], [76.34041595, 9.76375008], [76.34012604, 9.76375008], [76.34012604, 9.76403046], [76.33985901, 9.7640276], [76.33985901, 9.76458359], [76.33958435, 9.76458359], [76.33958435, 9.76486015], [76.33930206, 9.76486015], [76.33930206, 9.76513958], [76.3390274, 9.76513767], [76.3390274, 9.76569366], [76.33875275, 9.76569366], [76.33875275, 9.76597214], [76.33847046, 9.76597023], [76.33847046, 9.76624966], [76.33790588, 9.76624966], [76.33790588, 9.76653099], [76.33763885, 9.76652813], [76.33763885, 9.76708221], [76.33735657, 9.76708031], [76.33735657, 9.76764107], [76.33708191, 9.76763821], [76.33708191, 9.76847172], [76.33680725, 9.7684679], [76.33680725, 9.76931095], [76.33651733, 9.76931095], [76.33651733, 9.77042103], [76.33625031, 9.77042103], [76.33625031, 9.77153111], [76.33598328, 9.77153111], [76.33598328, 9.77264118], [76.33569336, 9.77263927], [76.33569336, 9.77319527], [76.3354187, 9.77319527], [76.3354187, 9.77375126], [76.33569336, 9.77375126], [76.33569336, 9.77430534], [76.33597565, 9.77430534], [76.33597565, 9.77486134], [76.33569336, 9.77486134], [76.33569336, 9.77597332], [76.33597565, 9.77597332], [76.33597565, 9.7770834], [76.33625031, 9.77708054], [76.33625031, 9.77737045], [76.33652496, 9.77736092], [76.33652496, 9.77819538], [76.33680725, 9.77819061], [76.33680725, 9.77902889], [76.33651733, 9.77902889], [76.33651733, 9.77931023], [76.33625031, 9.77930546], [76.33625031, 9.77958298], [76.33651733, 9.77958107], [76.33651733, 9.78043079], [76.33680725, 9.78041744], [76.33680725, 9.78069305], [76.33652496, 9.78069305], [76.33652496, 9.78097439], [76.33680725, 9.78097439], [76.33680725, 9.78208256], [76.33708191, 9.78208256], [76.33708191, 9.78236198], [76.3373642, 9.78236198], [76.3373642, 9.78347111], [76.33763885, 9.7834692], [76.33763885, 9.78542042], [76.3373642, 9.78541565], [76.3373642, 9.78569412], [76.33763885, 9.78569412], [76.33763885, 9.78625011], [76.3373642, 9.78625011], [76.3373642, 9.78708363], [76.33708954, 9.78707886], [76.33708954, 9.78763962], [76.33680725, 9.78763962], [76.33680725, 9.78792], [76.33651733, 9.78792], [76.33651733, 9.78874969], [76.33625031, 9.78874969], [76.33625031, 9.78903008], [76.33597565, 9.78902817], [76.33597565, 9.78958416], [76.33569336, 9.78958035], [76.33569336, 9.79014015], [76.33513641, 9.79014015], [76.33513641, 9.79069424], [76.33486176, 9.79069424], [76.33486176, 9.79097176], [76.33513641, 9.79096985], [76.33513641, 9.79152966], [76.33486176, 9.79152775], [76.33486176, 9.79208374], [76.3345871, 9.79208374], [76.3345871, 9.79319382], [76.33429718, 9.79319191], [76.33429718, 9.79375267], [76.33403015, 9.79375267], [76.33403015, 9.79403114], [76.33374786, 9.79403114], [76.33374786, 9.79514122], [76.33347321, 9.79513836], [76.33347321, 9.79569435], [76.33319092, 9.79569435], [76.33319092, 9.79597282], [76.33291626, 9.79596996], [76.33291626, 9.79653072], [76.3326416, 9.79652882], [76.3326416, 9.79708195], [76.33208466, 9.79708195], [76.33208466, 9.79736137], [76.33180237, 9.79736137], [76.33180237, 9.79792118], [76.33152771, 9.79791737], [76.33152771, 9.79819489], [76.33125305, 9.79819489], [76.33125305, 9.79847336], [76.33152771, 9.79846954], [76.33152771, 9.79903126], [76.33125305, 9.79902744], [76.33125305, 9.79958344], [76.33096313, 9.79957962], [76.33096313, 9.80041885], [76.33069611, 9.80041885], [76.33069611, 9.80154037], [76.33040619, 9.80154037], [76.33040619, 9.80180931], [76.33013916, 9.80180931], [76.33013916, 9.80430984], [76.3298645, 9.80430508], [76.3298645, 9.80569458], [76.33041382, 9.80569458], [76.33041382, 9.80597115], [76.33069611, 9.80597115], [76.33069611, 9.80625057], [76.33125305, 9.80625057], [76.33125305, 9.80653191], [76.33207703, 9.80653191], [76.33207703, 9.80681038], [76.3326416, 9.80680466], [76.3326416, 9.80736065], [76.33291626, 9.80735016], [76.33291626, 9.80792046], [76.33347321, 9.80791664], [76.33347321, 9.80819321], [76.33430481, 9.80819321], [76.33430481, 9.80847359], [76.33513641, 9.80847359], [76.33513641, 9.8087492], [76.33569336, 9.8087492], [76.33569336, 9.80902958], [76.33625031, 9.80902958], [76.33625031, 9.80930996], [76.33597565, 9.80930519], [76.33597565, 9.80986214], [76.33569336, 9.80986214], [76.33569336, 9.81041527], [76.3354187, 9.81041527], [76.3354187, 9.81097221], [76.33513641, 9.81096935], [76.33513641, 9.81153202], [76.33486176, 9.81152821], [76.33486176, 9.81236172], [76.3345871, 9.81236172], [76.3345871, 9.81319427], [76.33429718, 9.81319141], [76.33429718, 9.81402969], [76.33403015, 9.81402969], [76.33403015, 9.81514168], [76.33374786, 9.81513786], [76.33374786, 9.81847191], [76.33347321, 9.81847191], [76.33347321, 9.81875038], [76.33319092, 9.81875038], [76.33319092, 9.81931114], [76.33291626, 9.81931114], [76.33291626, 9.82014275], [76.3326416, 9.82014275], [76.3326416, 9.82181072], [76.33235931, 9.82180691], [76.33235931, 9.82319546], [76.33207703, 9.82318974], [76.33207703, 9.82431126], [76.33180237, 9.82431126], [76.33180237, 9.82514095], [76.33152771, 9.82514095], [76.33152771, 9.82625103], [76.33125305, 9.82625103], [76.33125305, 9.82681179], [76.33097076, 9.82680511], [76.33097076, 9.82736111], [76.33069611, 9.82736111], [76.33069611, 9.82792091], [76.33040619, 9.82792091], [76.33040619, 9.82847977], [76.33013916, 9.82847977], [76.33013916, 9.82903099], [76.32958221, 9.82903099], [76.32958221, 9.82875061], [76.32930756, 9.82875061], [76.32930756, 9.82818985], [76.32902527, 9.82819462], [76.32902527, 9.82736111], [76.32875061, 9.82736111], [76.32875061, 9.82569504], [76.32847595, 9.82569504], [76.32847595, 9.82430363], [76.32791901, 9.82430363], [76.32791901, 9.82458305], [76.32763672, 9.82458305], [76.32763672, 9.82486057], [76.32736206, 9.82486057], [76.32736206, 9.82514095], [76.32707977, 9.82514095], [76.32707977, 9.82542133], [76.32680511, 9.82541656], [76.32680511, 9.82569504], [76.32624817, 9.82569504], [76.32624817, 9.82597256], [76.32569122, 9.82597065], [76.32569122, 9.82625103], [76.32514954, 9.82625103], [76.32514954, 9.82653141], [76.32430267, 9.82653141], [76.32430267, 9.82681179], [76.32375336, 9.82680511], [76.32375336, 9.82708263], [76.32347107, 9.82708263], [76.32347107, 9.82736111], [76.32319641, 9.82736111], [76.32319641, 9.82764053], [76.32290649, 9.82764053], [76.32290649, 9.82792091], [76.32263947, 9.82792091], [76.32263947, 9.82847977], [76.32235718, 9.82847977], [76.32235718, 9.82903099], [76.32208252, 9.82902908], [76.32208252, 9.82958317], [76.32180786, 9.82958126], [76.32180786, 9.8318119], [76.32209015, 9.8318119], [76.32209015, 9.8326416], [76.32235718, 9.8326416], [76.32235718, 9.83375072], [76.32263947, 9.83375072], [76.32263947, 9.83513927], [76.32290649, 9.83513927], [76.32291412, 9.83624935], [76.32263947, 9.83624935], [76.32263947, 9.83681011], [76.32236481, 9.8368063], [76.32236481, 9.83736229], [76.32208252, 9.83736229], [76.32208252, 9.83763981], [76.32180786, 9.83763981], [76.32180786, 9.83792019], [76.32152557, 9.83791542], [76.32152557, 9.83847237], [76.32125092, 9.83847237], [76.32125092, 9.83875179], [76.32096863, 9.83875179], [76.32096863, 9.83903027], [76.32069397, 9.83902836], [76.32069397, 9.83958435], [76.32041931, 9.83958435], [76.32041931, 9.83986187], [76.32013702, 9.83986187], [76.32013702, 9.84014034], [76.31986237, 9.84014034], [76.31986237, 9.84069443], [76.31958008, 9.84069443], [76.31958008, 9.84125042], [76.31930542, 9.84125042], [76.31930542, 9.84208393], [76.31902313, 9.84208202], [76.31902313, 9.8429203], [76.31874847, 9.8429203], [76.31874847, 9.84375], [76.31846619, 9.84375], [76.31846619, 9.84403038], [76.31874847, 9.84403038], [76.31874847, 9.84431076], [76.31903076, 9.84430599], [76.31903076, 9.84458447], [76.31874847, 9.84458447], [76.31874847, 9.84486008], [76.31902313, 9.84486008], [76.31902313, 9.84542274], [76.31930542, 9.84541607], [76.31930542, 9.84597206], [76.31958008, 9.84597206], [76.31958008, 9.84652805], [76.31986237, 9.84652805], [76.31986237, 9.84735966], [76.32013702, 9.84735966], [76.32013702, 9.84764099], [76.32041931, 9.84763813], [76.32041931, 9.84819412], [76.32013702, 9.84819412], [76.32013702, 9.84847164], [76.32041931, 9.84846973], [76.32041931, 9.85042095], [76.32069397, 9.85041714], [76.32069397, 9.85069466], [76.32041931, 9.85068989], [76.32041931, 9.85153103], [76.32013702, 9.85152912], [76.32013702, 9.85208321], [76.31986237, 9.85208035], [76.31986237, 9.85264969], [76.32013702, 9.85264969], [76.32013702, 9.85292053], [76.31986237, 9.85291672], [76.31986237, 9.85347271], [76.32013702, 9.85347271], [76.32013702, 9.85375118], [76.31986237, 9.85375118], [76.31986237, 9.85431194], [76.31958008, 9.85430527], [76.31958008, 9.85486126], [76.31986237, 9.85486126], [76.31986237, 9.85542107], [76.32013702, 9.85541725], [76.32013702, 9.85597324], [76.32041931, 9.85597134], [76.32041931, 9.85652924], [76.32069397, 9.85652733], [76.32069397, 9.85708332], [76.32096863, 9.85708332], [76.32096863, 9.85738182], [76.32096863, 9.85764122], [76.32125092, 9.85763931], [76.32125092, 9.8581953], [76.3215332, 9.85819054], [76.3215332, 9.85931015], [76.32125092, 9.85931015], [76.32125092, 9.86042023], [76.32096863, 9.86041737], [76.32096863, 9.86097336], [76.32069397, 9.86097336], [76.32069397, 9.86152744], [76.32041931, 9.86152267], [76.32041931, 9.86180973], [76.32013702, 9.86180496], [76.32013702, 9.86236095], [76.31986237, 9.86236095], [76.31986237, 9.86458969], [76.31958008, 9.86458969], [76.31958008, 9.86765099], [76.31986237, 9.86763763], [76.31986237, 9.8684721], [76.32013702, 9.8684721], [76.32013702, 9.87069416], [76.32041931, 9.87069416], [76.32041931, 9.87097168], [76.32068634, 9.87097168], [76.32068634, 9.87125015], [76.32125092, 9.87125015], [76.32125092, 9.87152958], [76.3215332, 9.87152958], [76.3215332, 9.87181091], [76.32180786, 9.87181091], [76.32180786, 9.87152958], [76.32209015, 9.87152958], [76.32209015, 9.87125015], [76.32430267, 9.87125015], [76.32430267, 9.87152958], [76.32485962, 9.87152958], [76.32485962, 9.87181091], [76.32569122, 9.87180614], [76.32569122, 9.87208366], [76.32624817, 9.87208366], [76.32624817, 9.87236214], [76.32681274, 9.87236023], [76.32681274, 9.87263966], [76.33040619, 9.87263966], [76.33040619, 9.87236023], [76.33125305, 9.87236214], [76.33125305, 9.87208366], [76.33152771, 9.87208366], [76.33152771, 9.87152767], [76.33180237, 9.87152958], [76.33180237, 9.87125015], [76.33208466, 9.87125015], [76.33207703, 9.87097168], [76.33235931, 9.87097168], [76.33235931, 9.87041569], [76.3326416, 9.87042046], [76.3326416, 9.87014008], [76.33291626, 9.87014008], [76.33291626, 9.8698597], [76.33319092, 9.8698597], [76.33319092, 9.86930561], [76.33347321, 9.86931133], [76.33347321, 9.86874962], [76.33374786, 9.86874962], [76.33374786, 9.86818886], [76.33403015, 9.86819363], [76.33403015, 9.86763763], [76.33429718, 9.86765099], [76.33429718, 9.86708164], [76.3345871, 9.86708355], [76.3345871, 9.86652756], [76.33486176, 9.86653042], [76.33486176, 9.86625195], [76.33598328, 9.86625195], [76.33598328, 9.86597157], [76.33625031, 9.86597157], [76.33625031, 9.86569405], [76.33652496, 9.86569405], [76.33652496, 9.86541557], [76.33680725, 9.86542034], [76.33680725, 9.86514187], [76.33708954, 9.86514187], [76.33708954, 9.86486244], [76.3373642, 9.86486244], [76.3373642, 9.86347103], [76.33763885, 9.86347103], [76.33763885, 9.8629179], [76.33790588, 9.86291981], [76.33790588, 9.86208057], [76.3381958, 9.86208344], [76.3381958, 9.86097336], [76.33847046, 9.86097336], [76.33847046, 9.86033058], [76.33847046, 9.86013889], [76.33875275, 9.86013889], [76.33875275, 9.85903168], [76.3390274, 9.85903168], [76.3390274, 9.8579216], [76.33957672, 9.8579216], [76.33957672, 9.85736084], [76.33985901, 9.85736084], [76.33985901, 9.85680866], [76.34012604, 9.85680866], [76.34012604, 9.85652924], [76.33985901, 9.85652924], [76.33985901, 9.85624886], [76.3401413, 9.85624886], [76.3401413, 9.85347271], [76.34041595, 9.85347271], [76.34041595, 9.85291672], [76.34012604, 9.85292053], [76.34012604, 9.85236073], [76.34041595, 9.85236073], [76.34041595, 9.84902859], [76.34012604, 9.84903145], [76.34012604, 9.84846973], [76.34041595, 9.84847164], [76.34041595, 9.84819412], [76.3401413, 9.84819412], [76.3401413, 9.84652805], [76.34041595, 9.84652805], [76.34041595, 9.84597206], [76.3401413, 9.84597206], [76.3401413, 9.84541607], [76.33985901, 9.84542274], [76.33985901, 9.84486008], [76.3401413, 9.84486008], [76.34012604, 9.8445797], [76.33985901, 9.84458447], [76.33985901, 9.84402847], [76.34012604, 9.84403038], [76.34012604, 9.84208202], [76.34041595, 9.84208393], [76.34041595, 9.84180641], [76.34012604, 9.84181023], [76.34012604, 9.84152985], [76.34041595, 9.84152985], [76.34041595, 9.84041977], [76.34069061, 9.84041977], [76.34069824, 9.83986187], [76.3409729, 9.83986187], [76.3409729, 9.83958435], [76.34124756, 9.83958435], [76.34124756, 9.83847237], [76.34152985, 9.83847237], [76.34152985, 9.8368063], [76.34179688, 9.83681011], [76.34179688, 9.83624935], [76.34208679, 9.83624935], [76.34208679, 9.83597088], [76.34236145, 9.83597088], [76.34236145, 9.83541775], [76.34263611, 9.83541965], [76.34263611, 9.83485889], [76.3429184, 9.8348608], [76.3429184, 9.83430481], [76.34319305, 9.83430958], [76.34319305, 9.83403015], [76.34375, 9.83403015], [76.34375, 9.83375072], [76.34401703, 9.83375072], [76.34401703, 9.8334713], [76.34430695, 9.8334713], [76.34430695, 9.83319473], [76.3445816, 9.83319473], [76.3445816, 9.83291721], [76.34485626, 9.83292198], [76.34485626, 9.8326416], [76.34541321, 9.8326416], [76.34541321, 9.8318119], [76.34570312, 9.8318119], [76.34570312, 9.83154106], [76.34625244, 9.83154106], [76.34625244, 9.83125114], [76.34680176, 9.83125114], [76.34680176, 9.83097267], [76.3473587, 9.83097076], [76.3473587, 9.83069515], [76.34764099, 9.83069515], [76.34764099, 9.83041668], [76.34819794, 9.83041859], [76.34819794, 9.83014107], [76.3484726, 9.83014107], [76.3484726, 9.82903099], [76.34874725, 9.82903099], [76.34874725, 9.82875061], [76.34902954, 9.82875061], [76.34902954, 9.82792091], [76.34958649, 9.82792091], [76.34958649, 9.82764053], [76.34986115, 9.82764053], [76.34986115, 9.82736111], [76.35069275, 9.82736111], [76.35069275, 9.82708263], [76.35097504, 9.82708263], [76.35097504, 9.82680511], [76.35124969, 9.82681179], [76.35124969, 9.82653141], [76.35151672, 9.82653141], [76.35151672, 9.82625103], [76.35180664, 9.82625103], [76.35180664, 9.82597065], [76.3520813, 9.82597256], [76.3520813, 9.82541656], [76.35263824, 9.82542133], [76.35263824, 9.82514095], [76.35320282, 9.82514095], [76.35320282, 9.82458019], [76.35346985, 9.82458305], [76.35346985, 9.82430363], [76.35375214, 9.82431126], [76.35375214, 9.82403088], [76.35402679, 9.82403088], [76.35402679, 9.82375145], [76.35430908, 9.82375145], [76.35430908, 9.82347012], [76.35430908, 9.82319546], [76.3548584, 9.82319546], [76.3548584, 9.82291603], [76.35542297, 9.82291889], [76.35542297, 9.82264137], [76.35597229, 9.82264137], [76.35597229, 9.82235146], [76.35624695, 9.82236004], [76.35624695, 9.82208538], [76.35708618, 9.82208538], [76.35708618, 9.82180691], [76.35736084, 9.82181072], [76.35736084, 9.8215313], [76.35930634, 9.8215313], [76.35930634, 9.82124996], [76.35958099, 9.82124996], [76.35958099, 9.82096958], [76.35986328, 9.82097244], [76.35986328, 9.82069397], [76.36069489, 9.82069397], [76.36069489, 9.82041645], [76.36096954, 9.82041645], [76.36096954, 9.82069397], [76.36125183, 9.82069397], [76.36125183, 9.82041645], [76.36152649, 9.82042122], [76.36152649, 9.82014275], [76.36207581, 9.82014275], [76.36207581, 9.82042122], [76.36235809, 9.82042122], [76.36235809, 9.82014275], [76.36429596, 9.82014275], [76.36429596, 9.82042122], [76.36458588, 9.82041645], [76.36458588, 9.82069397], [76.36514282, 9.82069016], [76.36514282, 9.82124996], [76.36486053, 9.82124996], [76.36486053, 9.8215313], [76.36514282, 9.8215313], [76.36514282, 9.82291889], [76.36541748, 9.82291889], [76.36541748, 9.82264137], [76.36569214, 9.82264137], [76.36569214, 9.82235146], [76.3659668, 9.82235146], [76.3659668, 9.82264137], [76.36653137, 9.82264137], [76.36653137, 9.82291889], [76.36736298, 9.82291889], [76.36736298, 9.82264137], [76.36791992, 9.82264137], [76.36791992, 9.82235146], [76.36819458, 9.82236004], [76.36819458, 9.82208538], [76.36875153, 9.82208538], [76.36875153, 9.82180691], [76.36930847, 9.82181072], [76.36930847, 9.8215313], [76.36958313, 9.8215313], [76.36958313, 9.82124996], [76.36985779, 9.82124996], [76.36985779, 9.82096958], [76.37014008, 9.82097244], [76.37014008, 9.82069397], [76.37041473, 9.82069397], [76.37041473, 9.82013798], [76.37069702, 9.82014275], [76.37069702, 9.81735992], [76.3704071, 9.81735992], [76.3704071, 9.81624985], [76.37013245, 9.81624985], [76.37013245, 9.81569195], [76.36985779, 9.81569386], [76.36985779, 9.81513786], [76.36958313, 9.81514168], [76.36958313, 9.81458187], [76.36930847, 9.81458378], [76.36930847, 9.81430626], [76.36846924, 9.81431007], [76.36846924, 9.81402969], [76.36818695, 9.81402969], [76.36818695, 9.81431007], [76.36791992, 9.81430626], [76.36791992, 9.81458378], [76.36763763, 9.81458187], [76.36763763, 9.81514168], [76.36736298, 9.81514168], [76.36736298, 9.81542015], [76.36624908, 9.81542015], [76.36624908, 9.81514168], [76.36486053, 9.81514168], [76.36486053, 9.81458187], [76.36458588, 9.81458378], [76.36458588, 9.81430626], [76.36680603, 9.81431007], [76.36680603, 9.81402969], [76.36707306, 9.81402969], [76.36707306, 9.81348133], [76.36736298, 9.81348133], [76.36736298, 9.81264019], [76.36707306, 9.81264019], [76.36707306, 9.81096935], [76.36680603, 9.81097221], [76.36680603, 9.81069565], [76.36653137, 9.81069565], [76.36653137, 9.81041527], [76.36597443, 9.81041527], [76.36597443, 9.81013966], [76.36569214, 9.81013966], [76.36569214, 9.80985928], [76.36541748, 9.80986214], [76.36541748, 9.80958366], [76.36513519, 9.80958366], [76.36513519, 9.80930519], [76.36486053, 9.80930996], [76.36486053, 9.80902958], [76.36458588, 9.80902958], [76.36458588, 9.8087492], [76.36429596, 9.8087492], [76.36429596, 9.80847073], [76.36402893, 9.80847359], [76.36402893, 9.80819321], [76.36374664, 9.80819321], [76.36374664, 9.80791664], [76.36347198, 9.80792046], [76.36347198, 9.80764198], [76.36319733, 9.80764198], [76.36319733, 9.80735016], [76.36291504, 9.80736065], [76.36291504, 9.80708313], [76.36264038, 9.80708313], [76.36264038, 9.80652714], [76.36235809, 9.80653191], [76.36235809, 9.80625057], [76.36207581, 9.80625057], [76.36207581, 9.80569077], [76.36180878, 9.80569458], [76.36180878, 9.80541706], [76.36152649, 9.80542183], [76.36152649, 9.80486107], [76.36125183, 9.80486107], [76.36125183, 9.80430508], [76.36096954, 9.80430984], [76.36096954, 9.80375099], [76.36068726, 9.80375099], [76.36068726, 9.80291939], [76.36042023, 9.80291939], [76.36042023, 9.80236053], [76.36013794, 9.80236053], [76.36013794, 9.80097294], [76.35986328, 9.80097294], [76.35986328, 9.79875088], [76.35958099, 9.79875088], [76.35958099, 9.7968111], [76.35986328, 9.7968111], [76.35986328, 9.79541016], [76.36013794, 9.79541588], [76.36013794, 9.79458237], [76.36042023, 9.79458237], [76.36042023, 9.79374981], [76.36068726, 9.79375267], [76.36068726, 9.79292107], [76.36096954, 9.79292107], [76.36096954, 9.79207993], [76.36125183, 9.79208374], [76.36125183, 9.79097176], [76.36152649, 9.79097176], [76.36152649, 9.78958416], [76.36180878, 9.78958416], [76.36180878, 9.78902817], [76.36207581, 9.78903008], [76.36207581, 9.78874969], [76.36235809, 9.78874969], [76.36235809, 9.78792], [76.36264038, 9.78792], [76.36264038, 9.78707886], [76.36291504, 9.78708363], [76.36291504, 9.78652763], [76.36319733, 9.78652954], [76.36319733, 9.78597164], [76.36347198, 9.78597164], [76.36347198, 9.78578854], [76.36347198, 9.78541565], [76.36374664, 9.78542042], [76.36374664, 9.78486156], [76.36402893, 9.78486156], [76.36402893, 9.78430557], [76.36429596, 9.78431034], [76.36429596, 9.78374958], [76.36458588, 9.78374958], [76.36458588, 9.78318024], [76.36486053, 9.78319263], [76.36486053, 9.78236198], [76.36513519, 9.78236198], [76.36513519, 9.78180504], [76.36541748, 9.78180981], [76.36541748, 9.78125191], [76.36569214, 9.78125191], [76.36569214, 9.78069115], [76.36597443, 9.78069305], [76.36597443, 9.78013897], [76.36624908, 9.78014183], [76.36624908, 9.77958107], [76.36653137, 9.77958298], [76.36653137, 9.77902699], [76.36680603, 9.77902889], [76.36680603, 9.77847099], [76.36708069, 9.77847099], [76.36708069, 9.77763939], [76.36736298, 9.7776413], [76.36736298, 9.77708054], [76.36763763, 9.7770834], [76.36763763, 9.77680492], [76.36791992, 9.77680969], [76.36791992, 9.77541924], [76.36818695, 9.77541924], [76.36818695, 9.77486134], [76.36846924, 9.77486134], [76.36846924, 9.77430534], [76.36875153, 9.77430534], [76.36875153, 9.77263927], [76.36902618, 9.77264118], [76.36902618, 9.7723608], [76.36875153, 9.7723608], [76.36875153, 9.77125072], [76.36902618, 9.77125072], [76.36902618, 9.76763821], [76.36875153, 9.76764107], [76.36875153, 9.76735973], [76.36846924, 9.76735973], [76.36846924, 9.76652813], [76.36818695, 9.76653099], [76.36818695, 9.76513958], [76.36791992, 9.76513958], [76.36791992, 9.76292038], [76.36763763, 9.76292038], [76.36763763, 9.76264], [76.36791992, 9.76264], [76.36791992, 9.76235962], [76.36763763, 9.76236153], [76.36763763, 9.76180553], [76.36736298, 9.76181126], [76.36736298, 9.76124954], [76.36763763, 9.76124954], [76.36763763, 9.75986195], [76.36791992, 9.75986195], [76.36791992, 9.75874996], [76.36818695, 9.75875187], [76.36818695, 9.75847244], [76.36791992, 9.75847244], [76.36791992, 9.75791645], [76.36818695, 9.75792027], [76.36819458, 9.75704002], [76.36819458, 9.75680637], [76.36846924, 9.75681019], [76.36846924, 9.75597095], [76.36875153, 9.75597095], [76.36875153, 9.75541782], [76.36846924, 9.75541973], [76.36846924, 9.7551403], [76.36875153, 9.7551403], [76.36875153, 9.75430965], [76.36902618, 9.75430965], [76.36902618, 9.75319958], [76.36930847, 9.75319958], [76.36930847, 9.75208092], [76.36958313, 9.75208282], [76.36958313, 9.75125122], [76.36985779, 9.75125122], [76.36985779, 9.74986076], [76.37013245, 9.74986076], [76.37013245, 9.74875069], [76.3704071, 9.74875069], [76.3704071, 9.74653053], [76.37013245, 9.74653053], [76.37013245, 9.74514103], [76.36985779, 9.74514103], [76.36985779, 9.74458027], [76.36958313, 9.74458313], [76.36958313, 9.74375057], [76.36930847, 9.74375057], [76.36930847, 9.74264145], [76.36958313, 9.74264145], [76.36958313, 9.74236012], [76.37014008, 9.74236012], [76.37013245, 9.74207973], [76.37069702, 9.74208546], [76.37069702, 9.74180698], [76.37124634, 9.74180889], [76.37124634, 9.74153137], [76.37180328, 9.74153137], [76.37180328, 9.73847008], [76.37208557, 9.73847198], [76.37208557, 9.73791599], [76.37180328, 9.73792076], [76.37180328, 9.73764038], [76.37152863, 9.73764038], [76.37152863, 9.73707962], [76.37124634, 9.73708439], [76.37124634, 9.73680592], [76.37152863, 9.73681068], [76.37152863, 9.7365303], [76.37124634, 9.7365303], [76.37124634, 9.73596954], [76.37097168, 9.7359724], [76.37097168, 9.73541641], [76.37124634, 9.73542023], [76.37124634, 9.73513126], [76.37097168, 9.73513794], [76.37097168, 9.73458385], [76.37124634, 9.73458385], [76.37124634, 9.73430634], [76.37097168, 9.7343111], [76.37097168, 9.73403168], [76.37069702, 9.73403168], [76.37069702, 9.73347187], [76.37041473, 9.73347187], [76.37041473, 9.7318058], [76.37013245, 9.73180962], [76.37013245, 9.73096943], [76.36985779, 9.73097229], [76.36985779, 9.73069572], [76.36958313, 9.73069572], [76.36958313, 9.73013973], [76.36875153, 9.73013973], [76.36875153, 9.72985935], [76.36846924, 9.72986221], [76.36846924, 9.72958374], [76.36736298, 9.72958374], [76.36736298, 9.72902679], [76.36680603, 9.72902966], [76.36680603, 9.72846889], [76.36653137, 9.7284708], [76.36653137, 9.7276392], [76.36624908, 9.7276392], [76.36624908, 9.72736073], [76.36653137, 9.72736073], [76.36653137, 9.72597122], [76.36624908, 9.72597122], [76.36624908, 9.72263908], [76.3659668, 9.72264099], [76.3659668, 9.72068977], [76.36624908, 9.72069454], [76.36624908, 9.71986103], [76.36680603, 9.71986103], [76.36680603, 9.71902657], [76.36707306, 9.71903133], [76.36707306, 9.71736145], [76.36680603, 9.71736145], [76.36680603, 9.71569538], [76.36653137, 9.71569538], [76.36653137, 9.71374989], [76.36680603, 9.71375275], [76.36680603, 9.71347046], [76.36653137, 9.71347237], [76.36653137, 9.7118063], [76.36624908, 9.71181107], [76.36624908, 9.71068954], [76.36597443, 9.71069431], [76.36597443, 9.71041584], [76.36569214, 9.71042061], [76.36569214, 9.70985985], [76.36541748, 9.70985985], [76.36541748, 9.70930576], [76.36514282, 9.70931053], [76.36514282, 9.70903015], [76.36486053, 9.70903015], [76.36486053, 9.70847034], [76.36458588, 9.70847225], [76.36458588, 9.7056942], [76.36430359, 9.7056942], [76.36430359, 9.70430565], [76.36402893, 9.70431042], [76.36402893, 9.70346928], [76.36374664, 9.70347214], [76.36374664, 9.70291805], [76.36319733, 9.70291996], [76.36319733, 9.70263958], [76.36235809, 9.70263958], [76.36235809, 9.70291996], [76.36125946, 9.70291996], [76.36125946, 9.70263958], [76.36096954, 9.70263958], [76.36096954, 9.7023592], [76.36069489, 9.70236206], [76.36069489, 9.70041656], [76.36096954, 9.70042038], [76.36096954, 9.70014191], [76.36125946, 9.70014191], [76.36125946, 9.69958115], [76.36180878, 9.69958305], [76.36180878, 9.69930458], [76.36235809, 9.69930458], [76.36235809, 9.69958305], [76.36291504, 9.69958305], [76.36291504, 9.69874859], [76.36319733, 9.69875145], [76.36319733, 9.69847107], [76.36347198, 9.69847107], [76.36347198, 9.69791698], [76.36374664, 9.69791985], [76.36374664, 9.69764137], [76.36402893, 9.69764137], [76.36402893, 9.69736099], [76.36458588, 9.69736099], [76.36458588, 9.69708347], [76.36486053, 9.69708347], [76.36486053, 9.696805], [76.36514282, 9.69680977], [76.36514282, 9.69625092], [76.36541748, 9.69625092], [76.36541748, 9.69569111], [76.36569214, 9.69569492], [76.36569214, 9.69513893], [76.36541748, 9.69514084], [76.36541748, 9.69375134], [76.36569214, 9.69375134], [76.36569214, 9.69319534], [76.36597443, 9.69319534], [76.36597443, 9.69263935], [76.36653137, 9.69264126], [76.36653137, 9.69207954], [76.36680603, 9.69208336], [76.36680603, 9.69180679], [76.36736298, 9.69181061], [76.36736298, 9.69153118], [76.36763763, 9.69153118], [76.36763763, 9.6912508], [76.36791992, 9.6912508], [76.36791992, 9.69097328], [76.36875153, 9.69097328], [76.36875153, 9.69041729], [76.36902618, 9.6904211], [76.36902618, 9.6898613], [76.36958313, 9.6898613], [76.36958313, 9.68958473], [76.36985779, 9.68958473], [76.36985779, 9.68875122], [76.37014008, 9.68875122], [76.37013245, 9.68847275], [76.3704071, 9.68847275], [76.3704071, 9.68819046], [76.37069702, 9.68819427], [76.37069702, 9.68708229], [76.37097168, 9.68708229], [76.37097168, 9.68624973], [76.37124634, 9.68624973], [76.37124634, 9.68597031], [76.37152863, 9.68597221], [76.37152863, 9.68541622], [76.37180328, 9.68542099], [76.37180328, 9.68513966], [76.37236023, 9.68513966], [76.37236023, 9.68486023], [76.37291718, 9.68486023], [76.37291718, 9.68458366], [76.37458038, 9.68458366], [76.37458038, 9.68430614], [76.37513733, 9.68430614], [76.37513733, 9.68458366], [76.37708282, 9.68458366], [76.37708282, 9.68430614], [76.37735748, 9.68431091], [76.37735748, 9.684021], [76.37819672, 9.68402767], [76.37819672, 9.68375015], [76.37902832, 9.68375015], [76.37902832, 9.68347168], [76.38097382, 9.68347168], [76.38097382, 9.68319416], [76.38153076, 9.68319416], [76.38153076, 9.68291569], [76.38207245, 9.68292141], [76.38207245, 9.68264008], [76.38263702, 9.68264008], [76.38263702, 9.6823597], [76.38291931, 9.6823597], [76.38291931, 9.68208408], [76.38319397, 9.68208408], [76.38319397, 9.68152809], [76.38346863, 9.68153], [76.38346863, 9.68013954], [76.38318634, 9.68013954], [76.38318634, 9.67986202], [76.38346863, 9.67986202], [76.38346863, 9.67930603], [76.38375092, 9.67930984], [76.38375092, 9.67903042], [76.38430786, 9.67903042], [76.38430786, 9.67875195], [76.38735962, 9.67875195], [76.38735962, 9.67903042], [76.38846588, 9.67903042], [76.38846588, 9.67930984], [76.38930511, 9.67930603], [76.38930511, 9.67958355], [76.39097595, 9.67958355], [76.39097595, 9.67930603], [76.3915329, 9.67930984], [76.3915329, 9.67903042], [76.39235687, 9.67903042], [76.39235687, 9.67875195], [76.39319611, 9.67875195], [76.39319611, 9.67847157], [76.39347076, 9.67847157], [76.39347076, 9.67819405], [76.39375305, 9.67819405], [76.39375305, 9.67763996], [76.39430237, 9.67763996], [76.39430237, 9.6770792], [76.39458466, 9.67708397], [76.39458466, 9.67680645], [76.39541626, 9.67681026], [76.39541626, 9.67653179], [76.39597321, 9.67653179], [76.39597321, 9.67625046], [76.39653015, 9.67625046], [76.39653015, 9.67597103], [76.39679718, 9.67597103], [76.39679718, 9.67625046], [76.39736938, 9.67625046], [76.39736938, 9.67597103], [76.39875031, 9.67597103], [76.39875031, 9.67430496], [76.39819336, 9.67430973], [76.39819336, 9.6740303], [76.39763641, 9.6740303], [76.39763641, 9.67430973], [76.39736176, 9.67430496], [76.39736176, 9.67458344], [76.39680481, 9.67458344], [76.39680481, 9.67486191], [76.39597321, 9.67485046], [76.39597321, 9.67541981], [76.39541626, 9.6754179], [76.39541626, 9.67569256], [76.3951416, 9.67569256], [76.3951416, 9.6754179], [76.39485931, 9.6754179], [76.39485931, 9.67569256], [76.39458466, 9.67569256], [76.39458466, 9.67514038], [76.39430237, 9.67514038], [76.39430237, 9.67541981], [76.39402771, 9.67541981], [76.39402771, 9.67514038], [76.39375305, 9.67514038], [76.39375305, 9.67541981], [76.39347076, 9.67541981], [76.39347076, 9.67514038], [76.39319611, 9.67514038], [76.39319611, 9.67430973], [76.39290619, 9.67430973], [76.39290619, 9.67347145], [76.39263916, 9.67347431], [76.39263916, 9.67291737], [76.39235687, 9.67292023], [76.39235687, 9.67236137], [76.39208221, 9.67236137], [76.39208221, 9.6712513], [76.39180756, 9.6712513], [76.39180756, 9.66902733], [76.39208221, 9.66904068], [76.39208221, 9.66875076], [76.39180756, 9.66875076], [76.39180756, 9.66792202], [76.39208221, 9.66792202], [76.39208221, 9.66736126], [76.39180756, 9.66736126], [76.39180756, 9.66375065], [76.39208221, 9.66375065], [76.39208221, 9.66264057], [76.39180756, 9.66264057], [76.39180756, 9.66236019], [76.39208221, 9.66236019], [76.39208221, 9.66125107], [76.39180756, 9.66125107], [76.39180756, 9.66069031], [76.39152527, 9.66069412], [76.39152527, 9.65986347], [76.39125061, 9.65986347], [76.39125061, 9.65930557], [76.39097595, 9.65931129], [76.39097595, 9.65874958], [76.39068604, 9.65874958], [76.39068604, 9.65818977], [76.39013672, 9.65819359], [76.39013672, 9.6576376], [76.38986206, 9.65764046], [76.38986206, 9.65736008], [76.38930511, 9.65736008], [76.38930511, 9.65708447], [76.38903046, 9.65708447], [76.38903046, 9.65652847], [76.38846588, 9.65653038], [76.38846588, 9.65625], [76.38819885, 9.65625], [76.38819885, 9.65596962], [76.38791656, 9.65597153], [76.38791656, 9.65569401], [76.38735962, 9.65569401], [76.38735962, 9.65541553], [76.38707733, 9.65542126], [76.38707733, 9.65513992], [76.38680267, 9.65513992], [76.38680267, 9.65485954], [76.38625336, 9.6548624], [76.38625336, 9.65458393], [76.38513947, 9.65458393], [76.38513947, 9.65430641], [76.38430786, 9.65431118], [76.38430786, 9.65403938], [76.38375092, 9.65403938], [76.38375092, 9.65375042], [76.38318634, 9.65375042], [76.38318634, 9.65319157], [76.38291931, 9.65319443], [76.38291931, 9.65291786], [76.38263702, 9.65292263], [76.38263702, 9.65264034], [76.38236237, 9.65264034], [76.38236237, 9.65208244], [76.38208008, 9.65208435], [76.38208008, 9.65152836], [76.38236237, 9.65153027], [76.38236237, 9.64874935], [76.38207245, 9.64874935], [76.38207245, 9.64791107], [76.38180542, 9.64791775], [76.38180542, 9.64764023], [76.38153076, 9.64764023], [76.38153076, 9.64569092], [76.38124847, 9.64569473], [76.38124847, 9.64486122], [76.38096619, 9.6448698], [76.38096619, 9.64291859], [76.38069153, 9.64291859], [76.38069153, 9.64181042], [76.38014221, 9.64181042], [76.38014221, 9.64153099], [76.37985992, 9.64153099], [76.37985992, 9.64125061], [76.38014221, 9.64125061], [76.38014221, 9.64097118], [76.37985992, 9.64097309], [76.37985992, 9.63902664], [76.38014221, 9.63903141], [76.38014221, 9.63819027], [76.38041687, 9.63819504], [76.38041687, 9.63763905], [76.38069153, 9.63764095], [76.38069153, 9.63681126], [76.38096619, 9.63681126], [76.38096619, 9.63597012], [76.38124847, 9.63597298], [76.38124847, 9.63347244], [76.38097382, 9.63347244], [76.38097382, 9.63263798], [76.38041687, 9.63264275], [76.38041687, 9.63208199], [76.38014221, 9.63208199], [76.38014221, 9.63125038], [76.37985992, 9.63125038], [76.37985992, 9.63069439], [76.37958527, 9.63069439], [76.37958527, 9.6301403], [76.37930298, 9.6301403], [76.37930298, 9.62931061], [76.37902832, 9.62931061], [76.37902832, 9.62874985], [76.37874603, 9.62874985], [76.37874603, 9.62792015], [76.37847137, 9.62792015], [76.37847137, 9.62708187], [76.37819672, 9.62708378], [76.37819672, 9.62652779], [76.3779068, 9.62652969], [76.3779068, 9.62569141], [76.37763977, 9.62569427], [76.37763977, 9.62514019], [76.37735748, 9.62514019], [76.37735748, 9.62458229], [76.37708282, 9.6245842], [76.37708282, 9.62430573], [76.37680817, 9.62430954], [76.37680817, 9.62319088], [76.37652588, 9.62319565], [76.37652588, 9.62291527], [76.37625885, 9.62292004], [76.37625885, 9.62263966], [76.37596893, 9.62263966], [76.37596893, 9.62180996], [76.37568665, 9.62180996], [76.37568665, 9.62152958], [76.37458038, 9.62152958], [76.37458038, 9.6212492], [76.37403107, 9.6212492], [76.37403107, 9.62097359], [76.37374878, 9.62097359], [76.37374878, 9.62041759], [76.37346649, 9.62042046], [76.37346649, 9.61986065], [76.37291718, 9.61986065], [76.37291718, 9.61874866], [76.37264252, 9.61875057], [76.37264252, 9.61847115], [76.37236023, 9.61847115], [76.37236023, 9.61819458], [76.37208557, 9.61819458], [76.37208557, 9.61791706], [76.37180328, 9.61793137], [76.37180328, 9.6176424], [76.37152863, 9.6176424], [76.37152863, 9.61736107], [76.37124634, 9.61736107], [76.37124634, 9.6170826], [76.37097168, 9.6170826], [76.37097168, 9.61597347], [76.37041473, 9.61597347], [76.37041473, 9.61541653], [76.36985779, 9.61541939], [76.36985779, 9.61458111], [76.36958313, 9.61458302], [76.36958313, 9.61319542], [76.36930847, 9.61319542], [76.36930847, 9.61291695], [76.36902618, 9.61291885], [76.36902618, 9.61264133], [76.36875153, 9.61264133], [76.36875153, 9.61236095], [76.36846924, 9.61236095], [76.36846924, 9.61208344], [76.36819458, 9.61208344], [76.36819458, 9.61180687], [76.36791992, 9.61180687], [76.36791992, 9.61152744], [76.36736298, 9.61153126], [76.36736298, 9.61097145], [76.36708069, 9.61097336], [76.36708069, 9.60847282], [76.36736298, 9.60847282], [76.36736298, 9.60763836], [76.36707306, 9.60764122], [76.36707306, 9.60708046], [76.36680603, 9.60708237], [76.36680603, 9.60652828], [76.36653137, 9.60653114], [76.36653137, 9.60570145], [76.36624908, 9.60570145], [76.36624908, 9.60486031], [76.36597443, 9.60486031], [76.36597443, 9.60347176], [76.36624908, 9.60347176], [76.36624908, 9.60264015], [76.3659668, 9.60264015], [76.3659668, 9.60124969], [76.36569214, 9.60124969], [76.36569214, 9.60042], [76.36541748, 9.60042], [76.36541748, 9.59986019], [76.36486053, 9.5998621], [76.36486053, 9.59958363], [76.36458588, 9.59958363], [76.36458588, 9.59930611], [76.36429596, 9.59930992], [76.36429596, 9.59875202], [76.36402893, 9.59875202], [76.36402893, 9.59847164], [76.36374664, 9.59847164], [76.36374664, 9.59764004], [76.36402893, 9.59764004], [76.36402893, 9.59707928], [76.36374664, 9.59708405], [76.36374664, 9.59680557], [76.36402893, 9.59680557], [76.36402893, 9.59430504], [76.36429596, 9.5943079], [76.36429596, 9.59403038], [76.36458588, 9.59403038], [76.36458588, 9.59347057], [76.36513519, 9.59347439], [76.36513519, 9.59319305], [76.36597443, 9.59319305], [76.36597443, 9.59263897], [76.36624908, 9.59264183], [76.36624908, 9.59181023], [76.3659668, 9.59181023], [76.3659668, 9.59125137], [76.36569214, 9.59125137], [76.36569214, 9.59013939], [76.36541748, 9.59013939], [76.36541748, 9.58930969], [76.36514282, 9.58930969], [76.36514282, 9.58902931], [76.36541748, 9.58902931], [76.36541748, 9.58847141], [76.36569214, 9.58847332], [76.36569214, 9.58763885], [76.36597443, 9.58763885], [76.36597443, 9.58736134], [76.36624908, 9.58736134], [76.36624908, 9.58708286], [76.36708069, 9.58708286], [76.36708069, 9.58652687], [76.36736298, 9.58653069], [76.36736298, 9.58514118], [76.36763763, 9.58514118], [76.36763763, 9.58331108]]], [[[76.25208282, 10.0162487], [76.25208282, 10.01708317], [76.25291443, 10.01708317], [76.25291443, 10.01375103], [76.25347137, 10.01375103], [76.25347137, 10.0134697], [76.25375366, 10.01347256], [76.25375366, 10.01291656], [76.25347137, 10.01292133], [76.25347137, 10.01264095], [76.25374603, 10.01264095], [76.25374603, 10.01235962], [76.25180817, 10.01235962], [76.25180817, 10.01319504], [76.25125122, 10.01319504], [76.25125122, 10.01347256], [76.25096893, 10.0134697], [76.25096893, 10.01375103], [76.25041962, 10.01375103], [76.25041962, 10.01431084], [76.25152588, 10.01431084], [76.25152588, 10.01403141], [76.25208282, 10.01403141], [76.25208282, 10.01515007], [76.25180817, 10.01515007], [76.25180817, 10.01625061], [76.25208282, 10.0162487]]], [[[76.26569366, 10.03041553], [76.26569366, 10.03069401], [76.26597595, 10.03069401], [76.26597595, 10.03013992], [76.26569366, 10.03013992], [76.26569366, 10.02791786], [76.26597595, 10.02791977], [76.26597595, 10.02709103], [76.26625061, 10.02709103], [76.26625061, 10.02653027], [76.2665329, 10.02653027], [76.2665329, 10.02597141], [76.26680756, 10.02597141], [76.26680756, 10.02541542], [76.26708221, 10.02542019], [76.26708221, 10.02291965], [76.26568604, 10.02291965], [76.26568604, 10.02263927], [76.26403046, 10.02263927], [76.26403046, 10.02235889], [76.26264191, 10.0223608], [76.26264191, 10.02180481], [76.26319122, 10.02180958], [76.26319122, 10.0215292], [76.26346588, 10.0215292], [76.26346588, 10.02095985], [76.26374817, 10.02097321], [76.26374817, 10.02069473], [76.26403046, 10.02069473], [76.26403046, 10.02041721], [76.26431274, 10.02042198], [76.26431274, 10.01986122], [76.26457977, 10.01986122], [76.26457977, 10.01958275], [76.26486206, 10.01958275], [76.26486206, 10.01930523], [76.26513672, 10.0193119], [76.26513672, 10.01875114], [76.26486206, 10.01875114], [76.26486206, 10.01847267], [76.26264191, 10.01847267], [76.26264191, 10.01875114], [76.26207733, 10.01875114], [76.26207733, 10.01903152], [76.2618103, 10.01903152], [76.2618103, 10.0193119], [76.26152802, 10.01930523], [76.26152802, 10.01986122], [76.26125336, 10.01986122], [76.26125336, 10.02014065], [76.26069641, 10.02014065], [76.26069641, 10.02042198], [76.26041412, 10.02041721], [76.26041412, 10.02069473], [76.25986481, 10.02069473], [76.25986481, 10.02097321], [76.2590332, 10.02095985], [76.2590332, 10.0215292], [76.25875092, 10.0215292], [76.25875092, 10.02180958], [76.25846863, 10.02180481], [76.25846863, 10.0223608], [76.25818634, 10.02235889], [76.25818634, 10.02291965], [76.25791931, 10.02291679], [76.25791931, 10.02374935], [76.25818634, 10.02374935], [76.25818634, 10.02431011], [76.25902557, 10.02430534], [76.25902557, 10.02458286], [76.25930786, 10.02458286], [76.25930786, 10.02486229], [76.25985718, 10.02485943], [76.25985718, 10.02513981], [76.26013947, 10.02513981], [76.26013947, 10.02542019], [76.26041412, 10.02541542], [76.26041412, 10.0256958], [76.26069641, 10.0256958], [76.26069641, 10.02736187], [76.26125336, 10.02736187], [76.26125336, 10.02764034], [76.26152802, 10.02764034], [76.26152802, 10.02819443], [76.26180267, 10.02819443], [76.26180267, 10.02875042], [76.26235962, 10.02875042], [76.26235962, 10.02902985], [76.26264191, 10.02902985], [76.26264191, 10.02931023], [76.26235962, 10.02930641], [76.26235962, 10.02958393], [76.26208496, 10.02958393], [76.26208496, 10.03013992], [76.2618103, 10.03013134], [76.2618103, 10.0304203], [76.26569366, 10.03041553]]], [[[76.26041412, 10.02958393], [76.26041412, 10.0298624], [76.26180267, 10.0298624], [76.26180267, 10.02930641], [76.26152802, 10.02931023], [76.26152802, 10.02902985], [76.26125336, 10.02902985], [76.26125336, 10.02875042], [76.26097107, 10.02875042], [76.26097107, 10.02847195], [76.26041412, 10.02847195], [76.26041412, 10.02736187], [76.26013947, 10.02736187], [76.26013947, 10.02652836], [76.25958252, 10.02653027], [76.25958252, 10.02569103], [76.25930786, 10.0256958], [76.25930786, 10.02513981], [76.25819397, 10.02513981], [76.25819397, 10.0256958], [76.25846863, 10.02569103], [76.25846863, 10.02709103], [76.25875092, 10.02709103], [76.25875092, 10.02764034], [76.25902557, 10.02764034], [76.25902557, 10.02819443], [76.25930786, 10.02819443], [76.25930786, 10.02875042], [76.25958252, 10.02875042], [76.25958252, 10.02931023], [76.25986481, 10.02930641], [76.25986481, 10.02958393], [76.26041412, 10.02958393]]]]}}, {\\\"id\\\": \\\"16\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.19_1\\\", \\\"HASC_1\\\": \\\"IN.MP\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Madhya Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 95.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1347.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1789.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3136.0, \\\"geo-id\\\": 16, \\\"hpm25_child_popweighted\\\": 206.4, \\\"hpm25_female_popweighted\\\": 237.3, \\\"hpm25_male_popweighted\\\": 170.8, \\\"location\\\": \\\"Madhya Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 33298.0, \\\"mort_hpm25_6cod_mean_total\\\": 43608.0, \\\"mort_tpm25_6cod_mean_total\\\": 76906.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[80.40444183, 21.37581062], [80.40336609, 21.37648964], [80.40196991, 21.37781143], [80.40112305, 21.3782711], [80.39935303, 21.38049126], [80.39792633, 21.3841095], [80.39653778, 21.38784981], [80.39389801, 21.39215088], [80.3915329, 21.39663124], [80.38983154, 21.40087128], [80.38906097, 21.40431976], [80.38907623, 21.40737915], [80.38990021, 21.40888977], [80.39347076, 21.41267014], [80.39678192, 21.41534996], [80.39924622, 21.41790962], [80.39996338, 21.41948128], [80.39803314, 21.42308998], [80.39891815, 21.42494011], [80.40161133, 21.42807961], [80.40426636, 21.4307003], [80.40600586, 21.43245125], [80.40862274, 21.43482971], [80.41024017, 21.43639946], [80.41130829, 21.4382019], [80.41055298, 21.44016075], [80.40947723, 21.4435997], [80.40825653, 21.44721985], [80.40644073, 21.45119286], [80.40535736, 21.45440102], [80.40467834, 21.45635986], [80.40453339, 21.45861053], [80.40367889, 21.46130943], [80.40223694, 21.46337128], [80.40096283, 21.46543121], [80.39904022, 21.46640015], [80.39659119, 21.46723938], [80.39528656, 21.46787071], [80.39209747, 21.46939087], [80.38994598, 21.47092819], [80.38685608, 21.47343254], [80.38445282, 21.47635078], [80.38366699, 21.47900009], [80.38272095, 21.48244095], [80.38170624, 21.48480034], [80.38021088, 21.48727036], [80.37858582, 21.48933029], [80.37767792, 21.49012947], [80.37578583, 21.49094009], [80.37532806, 21.49114037], [80.37494659, 21.49287033], [80.37486267, 21.49483109], [80.37483978, 21.49591064], [80.3745575, 21.49897957], [80.37422943, 21.50110054], [80.37388611, 21.50306129], [80.37386322, 21.50508118], [80.3735733, 21.50945091], [80.3724823, 21.51279068], [80.37117767, 21.51514816], [80.37085724, 21.51709175], [80.3707962, 21.51786995], [80.3706131, 21.52096939], [80.36923218, 21.52291107], [80.36762238, 21.52467918], [80.36582947, 21.52634048], [80.36219025, 21.52849007], [80.35691071, 21.53079987], [80.35189056, 21.53300285], [80.3463974, 21.53572083], [80.34229279, 21.53742027], [80.3396759, 21.53790283], [80.3380127, 21.53874969], [80.33516693, 21.54074097], [80.33294678, 21.54220963], [80.33097839, 21.54370117], [80.32968903, 21.54444122], [80.32740784, 21.54609108], [80.32443237, 21.5487175], [80.32559204, 21.55034065], [80.32728577, 21.55174065], [80.3290863, 21.55365944], [80.33009338, 21.55470085], [80.32977295, 21.55631065], [80.32858276, 21.5582695], [80.32746887, 21.55964088], [80.32628632, 21.56158066], [80.324646, 21.56410027], [80.32283783, 21.5674305], [80.32139587, 21.57059097], [80.3201828, 21.57357979], [80.31884003, 21.57455063], [80.31693268, 21.57568169], [80.31299591, 21.57709122], [80.30988312, 21.57734108], [80.30764008, 21.57674026], [80.30336761, 21.57612991], [80.29908752, 21.57538986], [80.29537201, 21.57547951], [80.29191589, 21.57802963], [80.29026794, 21.58263016], [80.28978729, 21.5859127], [80.28909302, 21.5884304], [80.28864288, 21.58965111], [80.28800964, 21.59229088], [80.28658295, 21.59343147], [80.28282928, 21.59511948], [80.27980042, 21.59613037], [80.2754364, 21.59907913], [80.27374268, 21.60263062], [80.27237701, 21.60712051], [80.27086639, 21.6106205], [80.2649765, 21.61655807], [80.26022339, 21.62014961], [80.25665283, 21.62028122], [80.25527954, 21.62072945], [80.25206757, 21.6222496], [80.24762726, 21.62249947], [80.24269867, 21.62049103], [80.24014282, 21.62051964], [80.23596954, 21.6207695], [80.23207092, 21.62045288], [80.22688293, 21.62010193], [80.22058868, 21.61963081], [80.21630859, 21.62034035], [80.21465302, 21.62124062], [80.21203613, 21.62421989], [80.21039581, 21.62627983], [80.20797729, 21.62965012], [80.20469666, 21.63354111], [80.20040131, 21.63470078], [80.19515228, 21.63493919], [80.19210815, 21.63462067], [80.18942261, 21.63425064], [80.18821716, 21.63420105], [80.18618774, 21.63266945], [80.18519592, 21.63064003], [80.18369293, 21.62849045], [80.18237305, 21.62704086], [80.18031311, 21.62552071], [80.17672729, 21.62392044], [80.1749115, 21.62396049], [80.17339325, 21.62412071], [80.17112732, 21.62374115], [80.16895294, 21.62320137], [80.16499329, 21.6217308], [80.16210175, 21.61948967], [80.15991974, 21.61749077], [80.15673828, 21.61412048], [80.15499115, 21.61179924], [80.1526413, 21.60970116], [80.14998627, 21.60741997], [80.14787292, 21.60630035], [80.1439209, 21.60497284], [80.14068604, 21.60472107], [80.13751984, 21.60519981], [80.13298798, 21.60560989], [80.12622833, 21.60830116], [80.12409973, 21.60861015], [80.12145233, 21.60906029], [80.11857605, 21.60889816], [80.11493683, 21.60700989], [80.11286926, 21.60377121], [80.11242676, 21.6008091], [80.11219025, 21.59955025], [80.11157227, 21.59647942], [80.10990143, 21.59341049], [80.10793304, 21.59211922], [80.10560608, 21.59111023], [80.10209656, 21.5893898], [80.10040283, 21.5887394], [80.09874725, 21.58865929], [80.09632111, 21.58743286], [80.09401703, 21.5862999], [80.09329987, 21.58537102], [80.09081268, 21.58356285], [80.0896759, 21.58228111], [80.08669281, 21.57855988], [80.08483887, 21.5761795], [80.08201599, 21.57176971], [80.07875824, 21.56839943], [80.07704163, 21.56675911], [80.07508087, 21.56513977], [80.07332611, 21.5638504], [80.07115936, 21.56200027], [80.07002258, 21.56038094], [80.06845856, 21.55847168], [80.06658936, 21.5568409], [80.06356812, 21.55458069], [80.06211853, 21.55424118], [80.06118774, 21.55401993], [80.05964661, 21.55373001], [80.05719757, 21.55360031], [80.05419922, 21.55354118], [80.0507431, 21.55411911], [80.05007172, 21.55411911], [80.04815674, 21.55414963], [80.04557037, 21.55475044], [80.04403687, 21.55514908], [80.04155731, 21.55624962], [80.03840637, 21.55685997], [80.03439331, 21.55747032], [80.03199005, 21.55755806], [80.02822876, 21.55734062], [80.02617645, 21.55665016], [80.02265167, 21.55381966], [80.01912689, 21.55079079], [80.01689911, 21.54885101], [80.01465607, 21.54735184], [80.01223755, 21.54598045], [80.01000977, 21.5445919], [80.00746918, 21.54256821], [80.00476074, 21.54087067], [80.00208282, 21.53897095], [79.99819946, 21.53664017], [79.99669647, 21.53531075], [79.99355316, 21.53471184], [79.98558044, 21.5367794], [79.97177887, 21.55512047], [79.96624756, 21.55727005], [79.96144867, 21.55800056], [79.94709778, 21.55525017], [79.93638611, 21.55680084], [79.9310379, 21.55561066], [79.92719269, 21.55373001], [79.92124939, 21.5461998], [79.91831207, 21.54031181], [79.91581726, 21.52448082], [79.90119171, 21.52436066], [79.89228821, 21.52326012], [79.88976288, 21.52388], [79.88582611, 21.5296402], [79.8766861, 21.52847099], [79.87187958, 21.52956009], [79.85707855, 21.53092194], [79.85475922, 21.53252029], [79.85056305, 21.5375309], [79.84153748, 21.54181862], [79.82504272, 21.5467205], [79.81819153, 21.55900955], [79.81165314, 21.56430054], [79.80319214, 21.57262993], [79.79181671, 21.58140945], [79.76879883, 21.59043121], [79.74488831, 21.59786987], [79.73262024, 21.60252953], [79.71382141, 21.59113121], [79.70617676, 21.59090042], [79.69934082, 21.5923214], [79.69380951, 21.59095192], [79.69122314, 21.58789063], [79.68934631, 21.58364105], [79.68483734, 21.58069038], [79.66294098, 21.57971001], [79.65814209, 21.57733154], [79.65394592, 21.56345177], [79.65061951, 21.55880928], [79.6474762, 21.55717278], [79.64074707, 21.55548096], [79.63426971, 21.55495071], [79.62534332, 21.55486107], [79.61682129, 21.55721092], [79.60871124, 21.55593109], [79.59938812, 21.55076981], [79.59490967, 21.54965973], [79.58952332, 21.54955864], [79.57614899, 21.54335976], [79.57135773, 21.54380035], [79.56031036, 21.54801941], [79.54738617, 21.54429817], [79.53662109, 21.54421806], [79.53423309, 21.54816818], [79.5338974, 21.55076027], [79.53605652, 21.55496979], [79.53952026, 21.56520081], [79.53755951, 21.56899071], [79.53214264, 21.57298088], [79.52765656, 21.57480049], [79.52171326, 21.58032036], [79.51066589, 21.5831604], [79.50582123, 21.59028053], [79.50681305, 21.60238075], [79.50308228, 21.60750961], [79.49819183, 21.61236954], [79.50112915, 21.61964989], [79.50324249, 21.62236023], [79.50473022, 21.62326813], [79.50850677, 21.62286186], [79.5124588, 21.6264801], [79.51161957, 21.63113022], [79.50959778, 21.63336182], [79.50263977, 21.63459969], [79.50026703, 21.6405201], [79.50113678, 21.64571762], [79.49929047, 21.64784813], [79.49738312, 21.65193939], [79.49456024, 21.66053963], [79.4908905, 21.66370964], [79.48963928, 21.66580009], [79.4885788, 21.67412186], [79.45851135, 21.68732262], [79.45101166, 21.68433762], [79.44072723, 21.68223953], [79.43224335, 21.68349075], [79.42796326, 21.68526077], [79.42298126, 21.69057274], [79.41577911, 21.69144821], [79.41139984, 21.69096756], [79.40772247, 21.68556023], [79.40045166, 21.67964935], [79.3970871, 21.67564011], [79.39473724, 21.67459106], [79.38307953, 21.67539024], [79.36178589, 21.67951012], [79.34902191, 21.67889023], [79.34832001, 21.68440819], [79.34261322, 21.68451118], [79.32213593, 21.6883812], [79.32025146, 21.68659973], [79.31733704, 21.68581963], [79.28481293, 21.6939106], [79.27680206, 21.70022964], [79.27478027, 21.70523071], [79.27175903, 21.70903969], [79.26486969, 21.71492004], [79.25766754, 21.71754074], [79.2286911, 21.72392845], [79.22808075, 21.72191048], [79.22892761, 21.7204895], [79.23477173, 21.71520805], [79.22187805, 21.70059967], [79.22091675, 21.69659042], [79.21817017, 21.68126106], [79.22016144, 21.67700005], [79.22455597, 21.67588043], [79.22682953, 21.67439079], [79.22840118, 21.67139053], [79.22693634, 21.65764999], [79.22157288, 21.65690994], [79.21990204, 21.65081024], [79.21660614, 21.65019035], [79.18618774, 21.65442848], [79.14782715, 21.66052055], [79.14713287, 21.6565609], [79.14109039, 21.63953018], [79.13707733, 21.63685036], [79.12773895, 21.62805939], [79.11123657, 21.62556267], [79.09916687, 21.6189003], [79.09873199, 21.61631012], [79.09947968, 21.61227036], [79.10411072, 21.60935974], [79.09809875, 21.60284042], [79.09203339, 21.60342979], [79.08808899, 21.59918976], [79.0815506, 21.60715103], [79.07608032, 21.60768127], [79.05075073, 21.60394287], [79.0479126, 21.60569], [79.0429306, 21.60470963], [79.03096008, 21.60560989], [79.009552, 21.60149956], [79.00579834, 21.60402107], [78.99999237, 21.60979843], [78.99738312, 21.61577988], [78.9944458, 21.61874962], [78.98149109, 21.6171608], [78.97476196, 21.61755943], [78.96227264, 21.60588074], [78.94586182, 21.59604073], [78.94034576, 21.59375954], [78.92906189, 21.5946312], [78.92267609, 21.59260941], [78.91323853, 21.59235954], [78.91217804, 21.58518028], [78.91163635, 21.5709095], [78.91433716, 21.56964111], [78.91989899, 21.56895828], [78.9283905, 21.56443024], [78.92782593, 21.56028938], [78.92398071, 21.56015015], [78.91271973, 21.56312943], [78.90909576, 21.56175041], [78.90442657, 21.55484009], [78.92179871, 21.5431881], [78.92457581, 21.53868103], [78.92340088, 21.53308105], [78.92343903, 21.52378845], [78.92623901, 21.52164078], [78.9363327, 21.51939011], [78.93869781, 21.51728821], [78.94064331, 21.51370049], [78.93689728, 21.51044083], [78.93379974, 21.49238968], [78.93183136, 21.48740005], [78.92057037, 21.48763084], [78.90792847, 21.49425125], [78.90273285, 21.49801826], [78.89576721, 21.50056839], [78.89048767, 21.49823952], [78.88537598, 21.48559189], [78.87985229, 21.48497009], [78.87513733, 21.48792839], [78.85154724, 21.49570084], [78.84771729, 21.4914608], [78.84417725, 21.48997116], [78.82794952, 21.48995972], [78.82337952, 21.49111938], [78.81925964, 21.48962975], [78.81313324, 21.48872948], [78.81009674, 21.49086952], [78.79281616, 21.48986053], [78.78968811, 21.4885006], [78.78462219, 21.48913956], [78.78016663, 21.48080826], [78.7770462, 21.47907829], [78.77552032, 21.47351265], [78.77218628, 21.46713066], [78.76438141, 21.4742794], [78.76078796, 21.48471069], [78.76103973, 21.48975945], [78.7505188, 21.4907608], [78.74648285, 21.49386978], [78.74040222, 21.48371124], [78.7388382, 21.47290039], [78.73512268, 21.47141075], [78.7297287, 21.47136116], [78.72418976, 21.46438026], [78.71975708, 21.46462059], [78.71391296, 21.46795082], [78.70388031, 21.47120094], [78.70162201, 21.47470093], [78.69574738, 21.47443008], [78.69618225, 21.47741127], [78.6919632, 21.47868156], [78.68830109, 21.47886086], [78.68444061, 21.47795105], [78.68406677, 21.4819603], [78.66417694, 21.48073006], [78.65908813, 21.47888947], [78.65065765, 21.48282051], [78.64354706, 21.48425102], [78.63745117, 21.48419762], [78.63046265, 21.48133087], [78.62532806, 21.47783089], [78.62097168, 21.47754097], [78.61606598, 21.4815197], [78.6053772, 21.4883709], [78.60102081, 21.48715973], [78.59863281, 21.48480988], [78.59326172, 21.48768997], [78.58486938, 21.48688126], [78.58119202, 21.48964119], [78.57325745, 21.49850082], [78.56529999, 21.50597954], [78.56468964, 21.50932121], [78.56652832, 21.51569748], [78.56004333, 21.51461029], [78.55648804, 21.51581955], [78.55239868, 21.51939011], [78.54647064, 21.51996994], [78.53727722, 21.52456284], [78.52835083, 21.52462006], [78.52474213, 21.52583122], [78.52007294, 21.52537918], [78.50856018, 21.52843285], [78.50434875, 21.52670288], [78.50208282, 21.5266304], [78.49791718, 21.52296066], [78.49600983, 21.51797104], [78.49075317, 21.51797104], [78.48561859, 21.51203918], [78.48339844, 21.50774002], [78.48040009, 21.50612068], [78.47209167, 21.5069294], [78.47090912, 21.50486946], [78.46530151, 21.50353813], [78.46167755, 21.50353813], [78.45922852, 21.50463104], [78.45627594, 21.50445175], [78.45419312, 21.49831009], [78.4516983, 21.49733162], [78.44467926, 21.5019207], [78.43858337, 21.50375938], [78.43009949, 21.50175095], [78.43026733, 21.5091629], [78.43218231, 21.51991081], [78.42782593, 21.52675056], [78.42685699, 21.53019905], [78.42752838, 21.53832054], [78.42550659, 21.54227066], [78.42195129, 21.54584122], [78.42060089, 21.54878044], [78.42073059, 21.55479813], [78.42225647, 21.5637207], [78.41906738, 21.57160187], [78.41594696, 21.57308006], [78.41349792, 21.57773972], [78.41584778, 21.58815002], [78.42256165, 21.60194969], [78.41925812, 21.60429955], [78.41086578, 21.60659981], [78.40448761, 21.61009979], [78.39904785, 21.61108017], [78.39256287, 21.61009979], [78.38932037, 21.61056137], [78.38355255, 21.61663818], [78.3795166, 21.61865044], [78.37571716, 21.61745071], [78.37165833, 21.61503029], [78.37203979, 21.61076927], [78.37763214, 21.59560013], [78.37415314, 21.58996964], [78.36605072, 21.58192062], [78.36096191, 21.57829857], [78.35468292, 21.57690811], [78.34768677, 21.57886124], [78.34203339, 21.58287048], [78.33677673, 21.59052086], [78.32846069, 21.58118057], [78.32293701, 21.57738113], [78.31874084, 21.57558823], [78.30882263, 21.57369041], [78.30410767, 21.57143021], [78.30184937, 21.57287025], [78.3017807, 21.58040047], [78.30000305, 21.58505821], [78.2816391, 21.58675957], [78.27107239, 21.59296036], [78.26612091, 21.59428024], [78.26220703, 21.59375954], [78.25762177, 21.59184074], [78.25517273, 21.58984184], [78.25540924, 21.58523941], [78.25853729, 21.58189964], [78.26902008, 21.57472992], [78.27024841, 21.57237053], [78.26925659, 21.57071114], [78.24655914, 21.56401062], [78.23871613, 21.56549072], [78.22666931, 21.55644035], [78.21547699, 21.55373001], [78.18094635, 21.55868149], [78.17726898, 21.55669975], [78.17273712, 21.55330276], [78.17061615, 21.54219055], [78.17167664, 21.53576279], [78.17106628, 21.52873993], [78.1680069, 21.52604103], [78.17764282, 21.51431847], [78.17134094, 21.50850105], [78.17057037, 21.50205994], [78.16934204, 21.49850082], [78.14280701, 21.48211098], [78.12722778, 21.47340012], [78.10906219, 21.4641819], [78.10074615, 21.46095085], [78.09249115, 21.45601082], [78.0785675, 21.44571114], [78.06371307, 21.43885994], [78.05105591, 21.4370327], [78.04345703, 21.43503189], [78.0291214, 21.42535973], [78.01957703, 21.42058945], [78.00707245, 21.41841125], [78.00443268, 21.4158802], [77.99973297, 21.41616249], [77.99582672, 21.41378021], [77.98027802, 21.40279961], [77.97599792, 21.40209961], [77.97154999, 21.40138054], [77.95995331, 21.40142822], [77.95774841, 21.40114021], [77.94111633, 21.39895058], [77.93878174, 21.38690948], [77.9317627, 21.38581848], [77.92488861, 21.38606071], [77.91825104, 21.38474083], [77.91176605, 21.382761], [77.90550995, 21.37957001], [77.90071869, 21.3787117], [77.89904022, 21.37841988], [77.8923111, 21.3790493], [77.88664246, 21.38042068], [77.88186646, 21.37769127], [77.88337708, 21.38549042], [77.8762207, 21.38643074], [77.86321259, 21.38812065], [77.85473633, 21.39072037], [77.84661102, 21.39410973], [77.83392334, 21.40151978], [77.81801605, 21.40872955], [77.80449677, 21.41200066], [77.79936981, 21.41230011], [77.79847717, 21.41070938], [77.79598999, 21.40625954], [77.79522705, 21.40377808], [77.7939682, 21.39961052], [77.7934494, 21.39073944], [77.7901001, 21.38924026], [77.78552246, 21.38939095], [77.77655029, 21.3880291], [77.76506805, 21.38466263], [77.76140594, 21.38442039], [77.75689697, 21.38640976], [77.74993896, 21.38570976], [77.74649048, 21.38421059], [77.74336243, 21.38006973], [77.73834991, 21.36663055], [77.73387909, 21.36473083], [77.72489929, 21.36415291], [77.70524597, 21.35906982], [77.70519257, 21.36728096], [77.70514679, 21.37345123], [77.70433044, 21.37770081], [77.69554138, 21.37775993], [77.69259644, 21.38064957], [77.69425201, 21.39454269], [77.69352722, 21.3965416], [77.69113159, 21.39706993], [77.68827057, 21.39673042], [77.68109131, 21.38549042], [77.67520142, 21.37881088], [77.6700058, 21.3729229], [77.66877747, 21.3723011], [77.66722107, 21.37149048], [77.66481018, 21.37363052], [77.66307831, 21.37745094], [77.66335297, 21.38562965], [77.66208649, 21.38797188], [77.65158081, 21.39019012], [77.65097046, 21.39339066], [77.64589691, 21.39336014], [77.6425705, 21.39141083], [77.6414566, 21.3886795], [77.63920593, 21.38793945], [77.63617706, 21.38949966], [77.62931061, 21.39097977], [77.61519623, 21.39065933], [77.61145782, 21.39381027], [77.60154724, 21.3935585], [77.60067749, 21.39318085], [77.59919739, 21.39254951], [77.59938812, 21.39208984], [77.60064697, 21.3891201], [77.60066223, 21.3859024], [77.60204315, 21.38420105], [77.60575867, 21.37035179], [77.60481262, 21.36699295], [77.60148621, 21.36527061], [77.58701324, 21.36775017], [77.58444214, 21.36447906], [77.58262634, 21.36680031], [77.58081055, 21.36913109], [77.5759964, 21.37047005], [77.57089233, 21.3732605], [77.56533051, 21.37262917], [77.5625, 21.37338066], [77.54840851, 21.3812294], [77.5398407, 21.38117027], [77.52876282, 21.37907028], [77.52427673, 21.37973022], [77.52072144, 21.37730026], [77.51785278, 21.37784958], [77.516922, 21.37803268], [77.51052856, 21.37676048], [77.50173187, 21.37924957], [77.4870224, 21.3777504], [77.48298645, 21.39038086], [77.48419189, 21.39850998], [77.48175049, 21.41566849], [77.47709656, 21.42086029], [77.47302246, 21.43268967], [77.46920776, 21.43704987], [77.46884155, 21.44292068], [77.46975708, 21.44868088], [77.46858215, 21.45290947], [77.46930695, 21.45689964], [77.45716095, 21.46707153], [77.45378876, 21.46729279], [77.45236206, 21.46799088], [77.4489212, 21.46967125], [77.43875885, 21.47278023], [77.43830872, 21.47291946], [77.43808746, 21.47555923], [77.43785095, 21.47820282], [77.43515015, 21.48163986], [77.43737793, 21.48353195], [77.43921661, 21.48932266], [77.43112946, 21.50222015], [77.42079926, 21.51628113], [77.41880035, 21.52083969], [77.4169693, 21.53306007], [77.41990662, 21.5386982], [77.42350769, 21.54256058], [77.42894745, 21.54566002], [77.43187714, 21.54640007], [77.44207001, 21.54464912], [77.44664001, 21.54561043], [77.45024872, 21.5483799], [77.45030975, 21.55194092], [77.45195007, 21.55561066], [77.4575119, 21.55657005], [77.46472931, 21.55597115], [77.46872711, 21.55449104], [77.48400116, 21.55330276], [77.50435638, 21.55466843], [77.50726318, 21.5508194], [77.51191711, 21.54751015], [77.52919006, 21.54076958], [77.53533936, 21.53904915], [77.54073334, 21.53891945], [77.55339813, 21.53617287], [77.56698608, 21.52975082], [77.57789612, 21.52921104], [77.58924866, 21.53034973], [77.59488678, 21.5331707], [77.6071167, 21.54277039], [77.60575867, 21.55091095], [77.59068298, 21.56161118], [77.58551788, 21.55880928], [77.57972717, 21.55815125], [77.57408905, 21.55750084], [77.57099915, 21.56262016], [77.56999969, 21.56978989], [77.57022858, 21.57566833], [77.57219696, 21.58767128], [77.56993103, 21.6111412], [77.56817627, 21.61623192], [77.56784058, 21.62105942], [77.570961, 21.6235199], [77.57132721, 21.62704086], [77.5655365, 21.63503265], [77.56037903, 21.64518166], [77.55754089, 21.65558815], [77.55856323, 21.66867256], [77.55050659, 21.67628288], [77.54736328, 21.68156052], [77.54566956, 21.6860714], [77.54457092, 21.6924324], [77.54218292, 21.70103073], [77.53592682, 21.70825958], [77.53338623, 21.71269035], [77.52610779, 21.71503258], [77.52345276, 21.71354103], [77.52308655, 21.71362114], [77.52104187, 21.7141304], [77.51882935, 21.72116089], [77.51832581, 21.72437096], [77.51790619, 21.72701073], [77.50836182, 21.7352829], [77.50605011, 21.74121284], [77.49986267, 21.74489021], [77.49687195, 21.74920082], [77.4923172, 21.74979019], [77.48882294, 21.75024986], [77.47586823, 21.75788116], [77.47550964, 21.76185036], [77.47515106, 21.76573944], [77.47701263, 21.76795959], [77.47776794, 21.77022171], [77.4754715, 21.77144051], [77.47138214, 21.77124977], [77.45868683, 21.76818085], [77.45262909, 21.76432037], [77.44988251, 21.76341057], [77.44387817, 21.76351929], [77.43850708, 21.76272011], [77.42665863, 21.76040077], [77.41298676, 21.75773048], [77.40531158, 21.75673103], [77.40113068, 21.75617981], [77.37592316, 21.7571106], [77.35338593, 21.75946045], [77.34229279, 21.76183128], [77.33912659, 21.76165962], [77.33738708, 21.76156044], [77.32598114, 21.75736046], [77.32129669, 21.75703049], [77.3088913, 21.75964928], [77.29367065, 21.75991821], [77.28623962, 21.76275063], [77.27997589, 21.76126289], [77.27707672, 21.75980949], [77.27774811, 21.75375938], [77.27826691, 21.74913979], [77.28227234, 21.7481308], [77.28446198, 21.74644852], [77.28308868, 21.74164963], [77.28328705, 21.73849106], [77.28501892, 21.73750114], [77.28690338, 21.73644257], [77.28581238, 21.7288208], [77.28314972, 21.72422028], [77.26737976, 21.72907066], [77.26277161, 21.72363091], [77.25802612, 21.71582985], [77.25518036, 21.71519089], [77.23993683, 21.71712112], [77.22460175, 21.71788979], [77.22323608, 21.70418167], [77.22223663, 21.70167923], [77.22159576, 21.70010948], [77.21797943, 21.69842911], [77.21021271, 21.69712067], [77.20742035, 21.69400978], [77.20136261, 21.69631958], [77.18432617, 21.70446014], [77.18766022, 21.72072983], [77.18802643, 21.72257042], [77.18383026, 21.72450066], [77.17144775, 21.72726059], [77.16803741, 21.72575951], [77.16506195, 21.71692085], [77.16242218, 21.71410751], [77.16004944, 21.7137394], [77.15777588, 21.71340942], [77.14750671, 21.71465111], [77.13333893, 21.72232056], [77.12110138, 21.72534943], [77.11416626, 21.72486115], [77.10411072, 21.72289085], [77.10330963, 21.7226429], [77.09393311, 21.7196312], [77.08377838, 21.71862984], [77.08024597, 21.71869278], [77.07530975, 21.72237015], [77.07406616, 21.72261047], [77.07232666, 21.72293091], [77.06903839, 21.72180939], [77.0620575, 21.71504974], [77.05948639, 21.70940018], [77.03427124, 21.70051193], [77.02916718, 21.69606018], [77.02333832, 21.6937809], [77.0181427, 21.69079971], [77.01016235, 21.68439102], [77.00158691, 21.68215942], [76.99727631, 21.68161011], [76.97866821, 21.66597939], [76.91155243, 21.61493111], [76.90567017, 21.60449982], [76.90112305, 21.6008091], [76.89174652, 21.60070038], [76.86073303, 21.61230278], [76.85214996, 21.61503029], [76.84776306, 21.61330032], [76.83863068, 21.60050011], [76.8335495, 21.59306908], [76.82318115, 21.59268188], [76.80387115, 21.59683037], [76.79534912, 21.5975399], [76.793396, 21.59517288], [76.79148865, 21.58741951], [76.78359222, 21.5779705], [76.78024292, 21.56246758], [76.78283691, 21.5514698], [76.78457642, 21.54605293], [76.78782654, 21.54013062], [76.78553772, 21.53530121], [76.7753067, 21.53202057], [76.76751709, 21.52754021], [76.76293182, 21.52264977], [76.77023315, 21.51074982], [76.78649139, 21.49922943], [76.79180145, 21.48989105], [76.79017639, 21.48236084], [76.78513336, 21.47672081], [76.78418732, 21.46648979], [76.77578735, 21.46013069], [76.75654602, 21.44992828], [76.74339294, 21.44314003], [76.73842621, 21.42938042], [76.73722839, 21.41529083], [76.73208618, 21.40880966], [76.71909332, 21.40065002], [76.66841125, 21.3694706], [76.62864685, 21.33977127], [76.62452698, 21.33510017], [76.62583923, 21.32974052], [76.63973236, 21.31064987], [76.64862823, 21.3000412], [76.66107178, 21.28242111], [76.66017914, 21.27359962], [76.65944672, 21.26213074], [76.6590271, 21.25324821], [76.65849304, 21.24781036], [76.64987946, 21.24901962], [76.64257813, 21.24772072], [76.63728333, 21.23911285], [76.63169098, 21.22890091], [76.63134003, 21.21564102], [76.63157654, 21.20536995], [76.6268692, 21.19881058], [76.62336731, 21.19265938], [76.62003326, 21.19544029], [76.61678314, 21.19857025], [76.61231995, 21.19591141], [76.60562897, 21.19716263], [76.58674622, 21.19868279], [76.5760498, 21.20366287], [76.57518005, 21.20407295], [76.55938721, 21.20581055], [76.54129791, 21.19629097], [76.52919769, 21.18929291], [76.52078247, 21.18922043], [76.49807739, 21.19614029], [76.49117279, 21.19782066], [76.48737335, 21.19606018], [76.48245239, 21.18823051], [76.47828674, 21.17568016], [76.47673798, 21.16128922], [76.47702026, 21.15530014], [76.47489166, 21.152071], [76.46897125, 21.15056992], [76.46675873, 21.1472683], [76.46700287, 21.14319038], [76.46549988, 21.13924026], [76.4575119, 21.13834], [76.45593262, 21.13191986], [76.45291901, 21.1244297], [76.45269012, 21.11486816], [76.44770813, 21.11285973], [76.44107056, 21.11213112], [76.4375, 21.10758972], [76.43373871, 21.10668945], [76.41182709, 21.10726929], [76.40943909, 21.09408951], [76.39682007, 21.09057045], [76.3901062, 21.08805084], [76.38275909, 21.07956123], [76.38104248, 21.07907104], [76.37961578, 21.07847977], [76.37637329, 21.07731056], [76.37198639, 21.07855988], [76.36862183, 21.07870102], [76.36579132, 21.07907104], [76.3613205, 21.08000183], [76.35697937, 21.07966995], [76.33481598, 21.07718086], [76.29711914, 21.07718086], [76.2857666, 21.07649994], [76.2817688, 21.07530975], [76.27776337, 21.07802963], [76.27324677, 21.08541107], [76.26924896, 21.09295082], [76.26210785, 21.09470177], [76.23510742, 21.09391022], [76.22749329, 21.09144974], [76.20868683, 21.09017944], [76.18907166, 21.09031105], [76.18386078, 21.08995056], [76.1807785, 21.08741951], [76.17727661, 21.08549118], [76.17263794, 21.08460045], [76.16864777, 21.08582115], [76.16702271, 21.089571], [76.1681366, 21.0932312], [76.16927338, 21.09865952], [76.16931152, 21.10141945], [76.16911316, 21.10371971], [76.16845703, 21.10541153], [76.16744232, 21.10629845], [76.16221619, 21.10996056], [76.15146637, 21.11499977], [76.14214325, 21.12107086], [76.13566589, 21.12621117], [76.13417053, 21.1303196], [76.13934326, 21.13363075], [76.14092255, 21.13602257], [76.1399231, 21.14006805], [76.13169098, 21.15267944], [76.12841797, 21.15670967], [76.12409973, 21.15909958], [76.11891174, 21.1601181], [76.11396027, 21.16464043], [76.11431885, 21.17045975], [76.1193924, 21.17468071], [76.12741852, 21.17791939], [76.13070679, 21.17555046], [76.14298248, 21.17313194], [76.15505981, 21.17256165], [76.16088867, 21.17200089], [76.16684723, 21.17072105], [76.16913605, 21.17448044], [76.17063904, 21.18217278], [76.17272186, 21.18828964], [76.16908264, 21.19188118], [76.16590881, 21.19548988], [76.16571808, 21.20004845], [76.16705322, 21.20358086], [76.16770935, 21.20588112], [76.16794586, 21.20812035], [76.16427612, 21.21181107], [76.16152191, 21.21668816], [76.16314697, 21.22195053], [76.16403198, 21.22417259], [76.15933228, 21.22725105], [76.15328979, 21.22981834], [76.14801025, 21.2316494], [76.1455307, 21.23319054], [76.14440155, 21.23809052], [76.14409637, 21.24147987], [76.14412689, 21.24258041], [76.15091705, 21.24561119], [76.15428925, 21.24913979], [76.15809631, 21.25354958], [76.15921783, 21.25914192], [76.15603638, 21.2632103], [76.15386963, 21.26881981], [76.14980316, 21.27420998], [76.1471405, 21.28137016], [76.14499664, 21.28777122], [76.13987732, 21.28899956], [76.13497162, 21.29150009], [76.1292572, 21.29751015], [76.12726593, 21.30734062], [76.12224579, 21.32163811], [76.1159668, 21.33877945], [76.10694885, 21.36020279], [76.09867096, 21.37392807], [76.095047, 21.37267113], [76.08815002, 21.3699894], [76.07724762, 21.36426926], [76.06565857, 21.35919952], [76.05237579, 21.35270119], [76.04704285, 21.35519981], [76.04202271, 21.35889244], [76.0345993, 21.36527061], [76.02749634, 21.36813927], [76.01597595, 21.36988258], [76.00023651, 21.37481117], [75.99160767, 21.3760891], [75.98487854, 21.37717819], [75.96874237, 21.39397049], [75.95939636, 21.39619064], [75.94796753, 21.39298058], [75.93737793, 21.39286995], [75.93234253, 21.39151001], [75.91654205, 21.38982773], [75.91227722, 21.3906498], [75.9050827, 21.39563942], [75.89705658, 21.39726067], [75.89563751, 21.39874077], [75.8881073, 21.39962959], [75.88212585, 21.39842987], [75.87615204, 21.39819145], [75.87226105, 21.39550018], [75.86818695, 21.39048958], [75.86277771, 21.38730049], [75.85932922, 21.38730049], [75.85135651, 21.38935089], [75.84662628, 21.38813972], [75.84342194, 21.38945007], [75.83262634, 21.38330078], [75.8125, 21.38733101], [75.80545807, 21.38903046], [75.80140686, 21.39015007], [75.79220581, 21.38921165], [75.7738266, 21.38664818], [75.76013947, 21.38570023], [75.75894165, 21.38549042], [75.75467682, 21.38838959], [75.74610138, 21.39171028], [75.74408722, 21.39319038], [75.73834991, 21.39343262], [75.73558044, 21.39270973], [75.73294067, 21.39332962], [75.72271729, 21.38915253], [75.72158813, 21.39099121], [75.71385193, 21.3916111], [75.70675659, 21.39132118], [75.69483185, 21.38956261], [75.68972015, 21.38750076], [75.68782043, 21.38433075], [75.68479156, 21.38223076], [75.6784668, 21.38217163], [75.67507935, 21.38145065], [75.67341614, 21.38035011], [75.65882111, 21.38274956], [75.65487671, 21.38202095], [75.64575958, 21.38247108], [75.63986206, 21.38149071], [75.63263702, 21.38177109], [75.6294632, 21.3812294], [75.62679291, 21.38200951], [75.62361145, 21.38428116], [75.62111664, 21.38787079], [75.6194458, 21.39346123], [75.60891724, 21.39500046], [75.60295105, 21.39052963], [75.59126282, 21.3917408], [75.5877533, 21.38890076], [75.58486176, 21.38759995], [75.57655334, 21.38552094], [75.5815506, 21.38084984], [75.58125305, 21.37985992], [75.57209015, 21.37822914], [75.56598663, 21.37915039], [75.56420898, 21.37809944], [75.56027222, 21.37881088], [75.56111145, 21.38117027], [75.55980682, 21.38226128], [75.555336, 21.37745094], [75.55133057, 21.37544823], [75.54814911, 21.37248993], [75.54714966, 21.37265968], [75.54530334, 21.37579918], [75.53994751, 21.37719154], [75.52939606, 21.38472939], [75.52458191, 21.38716125], [75.51628113, 21.38673019], [75.51013184, 21.38799286], [75.50048828, 21.39157295], [75.49643707, 21.39073181], [75.48480225, 21.39126015], [75.46840668, 21.39420128], [75.46559906, 21.39136124], [75.46005249, 21.39302254], [75.45443726, 21.3920517], [75.45007324, 21.39240265], [75.44615173, 21.3904705], [75.44361877, 21.39101982], [75.43628693, 21.39072037], [75.43165588, 21.39394951], [75.41996765, 21.39027023], [75.41337585, 21.3910675], [75.40925598, 21.38992119], [75.40381622, 21.38377953], [75.40091705, 21.3839798], [75.39839172, 21.38298035], [75.39537811, 21.38467979], [75.39308929, 21.38406944], [75.38448334, 21.3855896], [75.3813324, 21.38763046], [75.37866211, 21.39241982], [75.36694336, 21.39891052], [75.36138153, 21.40323067], [75.35800171, 21.3961792], [75.35378265, 21.39348984], [75.33487701, 21.39466858], [75.32681274, 21.39423943], [75.32090759, 21.39240265], [75.31195831, 21.39528084], [75.30866241, 21.39450073], [75.30190277, 21.3892498], [75.30182648, 21.39241982], [75.30316162, 21.39519119], [75.30184937, 21.41483116], [75.29962921, 21.41566086], [75.29162598, 21.41390991], [75.28856659, 21.41181183], [75.27662659, 21.4088707], [75.26702118, 21.4088707], [75.2591095, 21.40521812], [75.2539978, 21.40613937], [75.24768066, 21.41067123], [75.24347687, 21.41493988], [75.23636627, 21.41710091], [75.23226166, 21.41658974], [75.21985626, 21.4108696], [75.21055603, 21.41422081], [75.2074585, 21.41584015], [75.20372009, 21.41731834], [75.19599915, 21.42285919], [75.18802643, 21.42731094], [75.15737152, 21.43827248], [75.14743805, 21.4433403], [75.129776, 21.44927979], [75.12297821, 21.4533329], [75.11509705, 21.45956039], [75.10666656, 21.46962929], [75.10044098, 21.48531151], [75.09487915, 21.49381256], [75.09266663, 21.50090981], [75.08999634, 21.51433182], [75.08355713, 21.52575111], [75.07832336, 21.5321312], [75.07624054, 21.53801918], [75.07221985, 21.54165077], [75.06503296, 21.5508194], [75.06359863, 21.55500031], [75.06018829, 21.55933952], [75.05774689, 21.5649395], [75.05356598, 21.56719017], [75.03183746, 21.56930923], [75.01783752, 21.57261086], [75.01584625, 21.57788086], [75.01341248, 21.5811882], [75.004776, 21.5860424], [75.00356293, 21.58670807], [75.00267792, 21.58716965], [75.00183105, 21.58764267], [75.0009613, 21.58811951], [75.00009918, 21.58859062], [74.99923706, 21.58905029], [74.99835205, 21.58950043], [74.99745941, 21.58992958], [74.99656677, 21.59033012], [74.99565125, 21.59070015], [74.99474335, 21.59109116], [74.9937973, 21.59144974], [74.99289703, 21.59183121], [74.99195862, 21.5921917], [74.99104309, 21.59255028], [74.99011993, 21.59290123], [74.98918152, 21.59325027], [74.9882431, 21.59358978], [74.98731232, 21.59392166], [74.98638916, 21.59424973], [74.98544312, 21.59456062], [74.98449707, 21.59486961], [74.98353577, 21.59517288], [74.98258972, 21.59546089], [74.98162842, 21.59574127], [74.98068237, 21.59601974], [74.9797287, 21.59626961], [74.97875977, 21.59651947], [74.97780609, 21.59674072], [74.97683716, 21.59696007], [74.9758606, 21.59717178], [74.9748764, 21.59737015], [74.97390747, 21.59756088], [74.97293091, 21.59774971], [74.97194672, 21.59793282], [74.97096252, 21.59811974], [74.96997833, 21.59828949], [74.96898651, 21.59847069], [74.96800232, 21.59864998], [74.96702576, 21.59883118], [74.96604919, 21.5990181], [74.96507263, 21.5992012], [74.96408844, 21.59941101], [74.96312714, 21.59959984], [74.96214294, 21.59980965], [74.96116638, 21.60001945], [74.96018982, 21.60026932], [74.95923615, 21.60050964], [74.95826721, 21.60077286], [74.95732117, 21.60103035], [74.95635986, 21.60128975], [74.95539856, 21.60155106], [74.95443726, 21.60181046], [74.95349884, 21.60207939], [74.95252991, 21.60235023], [74.95157623, 21.60263062], [74.9506073, 21.6029129], [74.94966888, 21.60318184], [74.94869995, 21.60346985], [74.94776154, 21.60375023], [74.94682312, 21.60403061], [74.94584656, 21.60432053], [74.94489288, 21.60460091], [74.94394684, 21.60490036], [74.94300079, 21.60518265], [74.94204712, 21.60548973], [74.94108582, 21.60577965], [74.94016266, 21.60608292], [74.93920135, 21.60637093], [74.93824768, 21.60667038], [74.93731689, 21.60697174], [74.93636322, 21.60728073], [74.93541718, 21.60757065], [74.93447113, 21.60787964], [74.93353271, 21.60819054], [74.93258667, 21.6084919], [74.931633, 21.60880089], [74.93067932, 21.60910034], [74.92974091, 21.60942078], [74.92880249, 21.60972023], [74.92785645, 21.61003113], [74.92691803, 21.61033821], [74.92595673, 21.61065292], [74.92502594, 21.61099052], [74.92408752, 21.61131859], [74.92314911, 21.6116581], [74.92222595, 21.61202049], [74.9213028, 21.61236954], [74.92038727, 21.61275101], [74.91947937, 21.61314011], [74.9185791, 21.61352921], [74.91770172, 21.61395264], [74.91680145, 21.61437988], [74.91591644, 21.61482811], [74.91504669, 21.61531067], [74.91416168, 21.61580849], [74.91333771, 21.61634064], [74.9125061, 21.61689949], [74.91172791, 21.61749077], [74.91095734, 21.61811066], [74.91026306, 21.61876106], [74.90962219, 21.61944962], [74.90907288, 21.62020111], [74.90860748, 21.62102127], [74.90818024, 21.62187958], [74.9078064, 21.62277031], [74.90743256, 21.62366104], [74.90703583, 21.6245594], [74.90661621, 21.62543106], [74.90618134, 21.62625122], [74.90563965, 21.62702942], [74.90500641, 21.62779045], [74.90434265, 21.6285305], [74.90358734, 21.62922287], [74.90276337, 21.6298008], [74.90187836, 21.63022995], [74.90093994, 21.63047981], [74.90001678, 21.63068962], [74.89904785, 21.63086128], [74.89807129, 21.63101959], [74.8970871, 21.63116264], [74.89610291, 21.6312809], [74.89512634, 21.63138962], [74.89411926, 21.63146973], [74.89309692, 21.63155937], [74.89208221, 21.63162994], [74.89105988, 21.63167953], [74.8900528, 21.63171959], [74.88903809, 21.63175964], [74.88803101, 21.63178253], [74.8870163, 21.6317997], [74.88601685, 21.6317997], [74.8850174, 21.6317997], [74.88401031, 21.63179016], [74.88302612, 21.63171959], [74.88204956, 21.63158035], [74.88105774, 21.6314106], [74.88006592, 21.63120079], [74.87909698, 21.63099098], [74.87812805, 21.63078117], [74.87713623, 21.63059044], [74.87613678, 21.63043976], [74.87516022, 21.63034058], [74.87415314, 21.63029099], [74.87312317, 21.63026047], [74.8720932, 21.63023949], [74.87106323, 21.63023949], [74.87001038, 21.63029099], [74.8690033, 21.63039017], [74.8680191, 21.6305294], [74.86709595, 21.63074112], [74.86630249, 21.63112068], [74.86575317, 21.63212013], [74.86534119, 21.63330269], [74.86486053, 21.63402939], [74.86415863, 21.6338501], [74.86342621, 21.633461], [74.86266327, 21.6330204], [74.86193085, 21.63251114], [74.86115265, 21.63195992], [74.86038208, 21.63137054], [74.85964966, 21.63074112], [74.85884857, 21.63010979], [74.858078, 21.62944984], [74.85727692, 21.6287899], [74.85647583, 21.62811089], [74.85568237, 21.62745094], [74.85488129, 21.62681007], [74.85407257, 21.62619019], [74.85321808, 21.62560081], [74.85237885, 21.62504005], [74.85153198, 21.62451935], [74.85066223, 21.62407112], [74.84976959, 21.62366104], [74.84884644, 21.62327957], [74.84793854, 21.62294006], [74.84697723, 21.62263107], [74.84601593, 21.62232971], [74.84506989, 21.62206078], [74.84409332, 21.62179947], [74.84310913, 21.62153053], [74.8421402, 21.62128258], [74.84115601, 21.62100983], [74.84020233, 21.62072945], [74.83924866, 21.62044144], [74.83833313, 21.62013054], [74.83740997, 21.61979103], [74.8365097, 21.61940956], [74.83564758, 21.61897087], [74.8348999, 21.61833], [74.83423615, 21.6175518], [74.83370972, 21.61669922], [74.83336639, 21.61584091], [74.83329773, 21.61487007], [74.83348846, 21.61379051], [74.83368683, 21.61273956], [74.83367157, 21.61186028], [74.83320618, 21.61129951], [74.8324585, 21.61090088], [74.83156586, 21.6106205], [74.83055878, 21.61041832], [74.82946777, 21.61029243], [74.82836151, 21.61021042], [74.82726288, 21.61018944], [74.82624054, 21.61018944], [74.82524109, 21.61021042], [74.8242569, 21.61029243], [74.82327271, 21.61038017], [74.82227325, 21.6104908], [74.82128906, 21.61063194], [74.82028961, 21.61079025], [74.81928253, 21.61094093], [74.81830597, 21.61112022], [74.81732178, 21.61129951], [74.81633759, 21.61147118], [74.81536865, 21.61164093], [74.81437683, 21.61182976], [74.81339264, 21.61203194], [74.81240845, 21.61225128], [74.8114624, 21.6125412], [74.81053925, 21.61287117], [74.80963135, 21.61326981], [74.8087616, 21.61372948], [74.8079071, 21.61422157], [74.80702209, 21.61469841], [74.80613708, 21.61514282], [74.8052063, 21.6154995], [74.80404663, 21.61586952], [74.80287933, 21.61613083], [74.80207062, 21.61605072], [74.80190277, 21.61548996], [74.80207062, 21.61463928], [74.80245972, 21.61363029], [74.80284119, 21.61255836], [74.80306244, 21.61156082], [74.80288696, 21.61073112], [74.80206299, 21.6100502], [74.80103302, 21.60983086], [74.80004883, 21.60985947], [74.79907227, 21.60989952], [74.79808807, 21.60996056], [74.79708862, 21.61001968], [74.7960968, 21.61009026], [74.79509735, 21.61016273], [74.79408264, 21.61025047], [74.79308319, 21.61033821], [74.792099, 21.61046982], [74.79106903, 21.61058044], [74.79007721, 21.61071968], [74.7890625, 21.61086082], [74.78808594, 21.61102104], [74.78710175, 21.61117935], [74.78611755, 21.61136055], [74.78514862, 21.61156082], [74.78417969, 21.61177063], [74.78324127, 21.61203194], [74.78231049, 21.61235046], [74.78137207, 21.61270142], [74.78045654, 21.61308098], [74.77954865, 21.61349106], [74.77863312, 21.61391068], [74.77774048, 21.61433029], [74.77683258, 21.61475945], [74.77593231, 21.61515999], [74.77501678, 21.61553955], [74.77397156, 21.61553955], [74.77297974, 21.61551094], [74.77197266, 21.61548042], [74.77097321, 21.61547089], [74.76996613, 21.61543083], [74.76896667, 21.61541176], [74.76796722, 21.61541939], [74.76698303, 21.61547089], [74.76599121, 21.61552048], [74.76499939, 21.61561966], [74.76399994, 21.61573982], [74.76303101, 21.61585808], [74.76203156, 21.6160202], [74.76104736, 21.61618042], [74.76006317, 21.61634064], [74.75907898, 21.61651993], [74.75808716, 21.6167202], [74.75712585, 21.61691093], [74.75614929, 21.61712074], [74.75515747, 21.61731911], [74.75419617, 21.61751938], [74.75319672, 21.61771965], [74.75224304, 21.61791992], [74.75126648, 21.61812973], [74.75028992, 21.61832047], [74.74931335, 21.61853027], [74.74833679, 21.61874008], [74.7473526, 21.61894035], [74.74637604, 21.61914063], [74.7454071, 21.61935043], [74.74443817, 21.61955261], [74.74346161, 21.61976051], [74.74249268, 21.61996078], [74.74151611, 21.6201725], [74.74053955, 21.62037086], [74.73956299, 21.62059021], [74.73860168, 21.62079239], [74.73761749, 21.62100029], [74.73664093, 21.62120056], [74.73565674, 21.62142181], [74.73468781, 21.62162971], [74.73371887, 21.62183952], [74.73274231, 21.62205124], [74.73177338, 21.62226105], [74.73079681, 21.62248039], [74.72981262, 21.6226902], [74.72885132, 21.62290955], [74.72786713, 21.6231308], [74.72690582, 21.62334061], [74.72592163, 21.62356186], [74.72496796, 21.6237812], [74.72397614, 21.62399101], [74.72302246, 21.62421989], [74.72203827, 21.62445068], [74.72107697, 21.62467194], [74.72012329, 21.62489128], [74.71914673, 21.62512016], [74.71816254, 21.62537003], [74.71720886, 21.62559128], [74.71624756, 21.62581062], [74.71527863, 21.62606049], [74.71430206, 21.62629128], [74.71334076, 21.62654114], [74.71237946, 21.62680244], [74.71141815, 21.62705994], [74.71044922, 21.62732124], [74.70948792, 21.62759018], [74.70852661, 21.62787056], [74.7075882, 21.62816048], [74.70662689, 21.62844086], [74.70567322, 21.62874985], [74.70474243, 21.62905121], [74.70379639, 21.6293602], [74.70285797, 21.62968826], [74.70192719, 21.63002968], [74.70101166, 21.63035965], [74.70008087, 21.63071823], [74.69917297, 21.6310997], [74.69827271, 21.63150978], [74.69738007, 21.63195038], [74.69651794, 21.63240051], [74.69564819, 21.6328907], [74.69477844, 21.63338089], [74.6939621, 21.63389969], [74.69313049, 21.63442039], [74.69230652, 21.63496017], [74.69149017, 21.63552284], [74.69069672, 21.63607979], [74.68990326, 21.63663292], [74.68910217, 21.63721085], [74.68830872, 21.63777924], [74.68753052, 21.63836098], [74.68675232, 21.63894081], [74.68596649, 21.63953018], [74.68517303, 21.64011002], [74.68438721, 21.64069939], [74.68360901, 21.64128113], [74.68282318, 21.6418705], [74.68205261, 21.64245987], [74.68126678, 21.6430397], [74.68047333, 21.64361954], [74.67970276, 21.64418983], [74.67888641, 21.64476013], [74.67809296, 21.6453228], [74.6772995, 21.64587975], [74.67648315, 21.64641953], [74.67565918, 21.64698982], [74.67487335, 21.64754295], [74.67402649, 21.6480999], [74.67320251, 21.64862061], [74.67237091, 21.64915085], [74.67151642, 21.64965057], [74.67066193, 21.65011024], [74.66977692, 21.65055847], [74.66887665, 21.65097046], [74.66797638, 21.65134048], [74.66706085, 21.65168953], [74.66612244, 21.6520195], [74.66517639, 21.65232086], [74.66420746, 21.65261078], [74.66326141, 21.65287018], [74.66227722, 21.65312195], [74.66131592, 21.65335083], [74.66033173, 21.6535511], [74.6593399, 21.65374947], [74.65837097, 21.65393066], [74.65740204, 21.65410042], [74.65643311, 21.65427017], [74.65542603, 21.65442085], [74.65444946, 21.65457153], [74.65342712, 21.65471077], [74.65245819, 21.65484047], [74.65146637, 21.65497971], [74.65046692, 21.6551075], [74.64949036, 21.65522957], [74.64850616, 21.65534973], [74.64749908, 21.6554718], [74.64650726, 21.65559959], [74.6455307, 21.6557312], [74.64453888, 21.65583992], [74.6435318, 21.65596962], [74.64254761, 21.65610123], [74.64155579, 21.65624046], [74.64057159, 21.65637016], [74.6395874, 21.6565094], [74.63858032, 21.65666008], [74.63761139, 21.6568203], [74.63661194, 21.65698051], [74.63564301, 21.65715027], [74.63465118, 21.65733147], [74.63368988, 21.65752029], [74.63269806, 21.6577282], [74.63173676, 21.65793037], [74.63076019, 21.65814018], [74.62980652, 21.65835953], [74.62882233, 21.65859032], [74.62784576, 21.65882111], [74.62687683, 21.65904808], [74.6259079, 21.65928268], [74.62494659, 21.6595211], [74.6239624, 21.65975952], [74.6230011, 21.65999985], [74.62201691, 21.66023064], [74.62106323, 21.66047096], [74.62008667, 21.66070747], [74.619133, 21.66094971], [74.61814117, 21.66118813], [74.61717987, 21.66139984], [74.61621094, 21.66163063], [74.615242, 21.66184044], [74.61427307, 21.66205025], [74.61329651, 21.66226006], [74.61231232, 21.66246033], [74.61134338, 21.66263008], [74.61036682, 21.66282082], [74.60939026, 21.66299057], [74.60839844, 21.66315269], [74.60742188, 21.66328049], [74.60639954, 21.66337967], [74.6053772, 21.66341972], [74.60434723, 21.66343117], [74.60330963, 21.66341972], [74.60227966, 21.66337967], [74.60122681, 21.66332817], [74.60018921, 21.66328049], [74.59913635, 21.6632309], [74.59809875, 21.66319847], [74.59709167, 21.66316986], [74.59607697, 21.66316986], [74.59509277, 21.66321182], [74.5941391, 21.66328049], [74.59319305, 21.66340828], [74.59227753, 21.66358948], [74.59140778, 21.66383171], [74.59055328, 21.66415977], [74.58976746, 21.66464806], [74.58899689, 21.66526985], [74.58831024, 21.66601944], [74.587677, 21.66683006], [74.58708954, 21.66772079], [74.58657074, 21.66862106], [74.58615112, 21.66953087], [74.58574677, 21.67041016], [74.58545685, 21.67124939], [74.58547211, 21.6721096], [74.58579254, 21.67300034], [74.58627319, 21.67391968], [74.58670044, 21.67485809], [74.58693695, 21.67579269], [74.58689117, 21.67670059], [74.58677673, 21.6776619], [74.58661652, 21.67865944], [74.58644104, 21.6796627], [74.5861969, 21.68066025], [74.58589935, 21.68163109], [74.58557129, 21.68254089], [74.5851593, 21.68338013], [74.58470154, 21.68412018], [74.58416748, 21.68474007], [74.58345032, 21.68513107], [74.58248901, 21.68527985], [74.58141327, 21.68527031], [74.58027649, 21.68514061], [74.5791626, 21.68499947], [74.57814026, 21.68486977], [74.57713318, 21.68478012], [74.57611847, 21.68466949], [74.57507324, 21.68456268], [74.5740509, 21.68443108], [74.57302094, 21.68431091], [74.57200623, 21.68416023], [74.57099152, 21.68399048], [74.57000732, 21.68380165], [74.56906128, 21.68357086], [74.56813812, 21.68332291], [74.56726074, 21.68302917], [74.56652069, 21.68259811], [74.56636047, 21.68153954], [74.56626129, 21.68045044], [74.56569672, 21.67996025], [74.56476593, 21.67984962], [74.56371307, 21.67990112], [74.5626297, 21.68008995], [74.56160736, 21.68042183], [74.56072998, 21.68086052], [74.55980682, 21.68143082], [74.55887604, 21.68208122], [74.55800629, 21.68279076], [74.55729675, 21.68353271], [74.55680084, 21.68425941], [74.55661011, 21.68494034], [74.5569458, 21.68555069], [74.55773926, 21.68610954], [74.55877686, 21.68667984], [74.55977631, 21.68729019], [74.56054688, 21.68799019], [74.56086731, 21.68882751], [74.56105804, 21.68970108], [74.56121063, 21.69059944], [74.56130981, 21.69151115], [74.56137848, 21.69244194], [74.56143951, 21.69338989], [74.56147003, 21.69433975], [74.5614624, 21.69530106], [74.56141663, 21.69627953], [74.56137848, 21.69722939], [74.5613327, 21.69820023], [74.56124878, 21.69915962], [74.56115723, 21.70012093], [74.5610733, 21.7010498], [74.56096649, 21.70198059], [74.56079865, 21.7028904], [74.56056976, 21.7038002], [74.56024933, 21.70470047], [74.55989838, 21.70560074], [74.55948639, 21.70646286], [74.55903625, 21.70730972], [74.55856323, 21.7081604], [74.55806732, 21.70898056], [74.55760956, 21.70984077], [74.55713654, 21.71073914], [74.55667877, 21.71166992], [74.55621338, 21.71261024], [74.55573273, 21.71355057], [74.55522919, 21.71447945], [74.55471039, 21.71537018], [74.55417633, 21.71623039], [74.55362701, 21.71701813], [74.55303192, 21.71774101], [74.55237579, 21.71839905], [74.55171967, 21.71894836], [74.55098724, 21.71939278], [74.55020142, 21.71970749], [74.54940033, 21.7199192], [74.54852295, 21.72002983], [74.54762268, 21.72002983], [74.54664612, 21.7199707], [74.54567719, 21.71982956], [74.5446701, 21.71965027], [74.54366302, 21.71940994], [74.5426178, 21.71915054], [74.54155731, 21.7188797], [74.54049683, 21.71861076], [74.53943634, 21.71832848], [74.53839111, 21.71809006], [74.53734589, 21.71787071], [74.53631592, 21.71769905], [74.53530884, 21.7175827], [74.53431702, 21.71754074], [74.53333282, 21.71749115], [74.53231049, 21.71747017], [74.53131866, 21.71747017], [74.53031921, 21.71747971], [74.52929688, 21.71754074], [74.52832031, 21.7175827], [74.52731323, 21.71763039], [74.52630615, 21.71772194], [74.5253067, 21.71780968], [74.52433014, 21.7179184], [74.52333832, 21.71808052], [74.5223465, 21.7182827], [74.52139282, 21.71850967], [74.52041626, 21.71879005], [74.51947784, 21.71911049], [74.51854706, 21.71947098], [74.51763153, 21.71986961], [74.516716, 21.72029114], [74.51583862, 21.72076035], [74.5149765, 21.72128105], [74.51422119, 21.72187996], [74.51352692, 21.72253036], [74.51288605, 21.72326088], [74.51226044, 21.72409058], [74.5117569, 21.72495079], [74.51138306, 21.72585106], [74.51122284, 21.72674942], [74.51125336, 21.72764969], [74.51135254, 21.72854805], [74.51152039, 21.72944069], [74.51174927, 21.73033905], [74.51197815, 21.73125076], [74.51226807, 21.73216248], [74.51255798, 21.73307991], [74.51286316, 21.73398018], [74.51317596, 21.73490906], [74.51348877, 21.73582268], [74.5137558, 21.73676109], [74.51403809, 21.7376709], [74.51425934, 21.73858261], [74.51447296, 21.73950958], [74.51463318, 21.74043083], [74.5147171, 21.74135017], [74.5147171, 21.74228096], [74.51461792, 21.74323082], [74.51447296, 21.74416924], [74.51426697, 21.74513054], [74.51407623, 21.74608994], [74.51386261, 21.74703979], [74.51365662, 21.74798012], [74.51354218, 21.7489109], [74.51348877, 21.74981117], [74.51352692, 21.75069046], [74.51378632, 21.75152969], [74.51436615, 21.75226021], [74.51516724, 21.75293922], [74.51599121, 21.75361061], [74.5166626, 21.75435066], [74.51700592, 21.75518036], [74.51721191, 21.75608063], [74.51740265, 21.75699997], [74.5175705, 21.75794029], [74.51769257, 21.75889969], [74.51780701, 21.75987053], [74.5178833, 21.76083183], [74.51790619, 21.76178932], [74.51789856, 21.76276016], [74.51786041, 21.76370811], [74.51773071, 21.76463127], [74.51759338, 21.76554108], [74.51735687, 21.76639938], [74.51700592, 21.76723099], [74.5165329, 21.76803017], [74.51596832, 21.76880074], [74.51529694, 21.7695694], [74.51463318, 21.77030945], [74.51393127, 21.77103043], [74.51320648, 21.77176094], [74.51257324, 21.77247047], [74.51185608, 21.77312088], [74.51101685, 21.77370071], [74.51021576, 21.77427101], [74.50946045, 21.77490807], [74.50888062, 21.77561951], [74.50840759, 21.77642822], [74.50800323, 21.77726936], [74.50763702, 21.77814102], [74.50728607, 21.77902985], [74.50695801, 21.77993965], [74.50665283, 21.78083038], [74.5063324, 21.78174019], [74.50596619, 21.78260994], [74.50315857, 21.79780006], [74.50364685, 21.80718231], [74.50932312, 21.81587982], [74.51181793, 21.82122993], [74.51699829, 21.85649109], [74.51747894, 21.87490082], [74.51776123, 21.88624001], [74.51843262, 21.89011002], [74.52146912, 21.89550972], [74.52746582, 21.90345001], [74.52749634, 21.90878105], [74.52398682, 21.91306114], [74.51735687, 21.91755104], [74.51464081, 21.92246819], [74.51560974, 21.9278717], [74.51555634, 21.93391991], [74.4967804, 21.94641113], [74.49233246, 21.94546127], [74.48985291, 21.94714928], [74.49340057, 21.95449066], [74.48928833, 21.95676041], [74.48568726, 21.95753288], [74.48449707, 21.96075058], [74.48293304, 21.96244049], [74.4778595, 21.96154976], [74.47512054, 21.96270943], [74.47218323, 21.96552086], [74.4673233, 21.96479988], [74.4641571, 21.96321106], [74.45996857, 21.9628315], [74.45170593, 21.96750069], [74.44863892, 21.97113037], [74.4471817, 21.97627068], [74.44303894, 21.98306847], [74.44262695, 21.99362946], [74.44107819, 21.99644089], [74.4362793, 21.9994812], [74.43621826, 22.00222969], [74.44380951, 22.00616074], [74.44573212, 22.0068512], [74.44995117, 22.00546265], [74.45391846, 22.00226974], [74.45381927, 22.00617027], [74.45150757, 22.00896835], [74.44764709, 22.01247978], [74.44451904, 22.01599121], [74.44255829, 22.02160072], [74.44603729, 22.02651978], [74.43945313, 22.02651978], [74.43554688, 22.03099823], [74.4177475, 22.02581024], [74.40651703, 22.02440071], [74.3964386, 22.02370262], [74.38831329, 22.02017975], [74.38366699, 22.01175117], [74.37818146, 22.00217056], [74.37718964, 22.00085068], [74.37664032, 22.00004005], [74.37609863, 21.99925041], [74.37552643, 21.99843979], [74.37496185, 21.99767113], [74.37438202, 21.9969101], [74.37375641, 21.99618912], [74.37310791, 21.99549103], [74.37238312, 21.99487114], [74.37159729, 21.9943428], [74.37069702, 21.99391937], [74.36974335, 21.99356842], [74.36875916, 21.99324989], [74.36778259, 21.99291039], [74.36685181, 21.99253082], [74.3660202, 21.99204063], [74.36531067, 21.99144173], [74.36463928, 21.9907608], [74.36400604, 21.99003983], [74.36342621, 21.98929024], [74.36286926, 21.9885006], [74.36235046, 21.98769951], [74.36180878, 21.98689079], [74.36126709, 21.98608017], [74.36074829, 21.98526001], [74.36019135, 21.98446274], [74.35962677, 21.98368073], [74.35901642, 21.98291969], [74.35842133, 21.98220062], [74.35775757, 21.98151016], [74.35700989, 21.98088074], [74.35626221, 21.98028946], [74.35546112, 21.97972107], [74.35463715, 21.97919846], [74.35378265, 21.9786911], [74.35289764, 21.97821045], [74.35202026, 21.97774124], [74.35114288, 21.97729111], [74.35024261, 21.97682953], [74.3493576, 21.97639084], [74.34844971, 21.97599983], [74.34749603, 21.97565079], [74.3465271, 21.97541046], [74.34555817, 21.97521973], [74.34455109, 21.97509956], [74.34358215, 21.97500992], [74.3425827, 21.97492027], [74.34158325, 21.97486115], [74.34057617, 21.97477913], [74.33957672, 21.97470856], [74.33859253, 21.97466278], [74.33757782, 21.97459984], [74.33660126, 21.97455025], [74.33557892, 21.97451019], [74.3345871, 21.97445107], [74.33360291, 21.97441101], [74.33258057, 21.97437286], [74.33158875, 21.97431946], [74.33058167, 21.97426987], [74.32958984, 21.97421837], [74.32858276, 21.97417259], [74.32758331, 21.97412109], [74.3265686, 21.97405052], [74.32557678, 21.97397995], [74.32459259, 21.97392082], [74.32359314, 21.97383118], [74.32260132, 21.97372818], [74.32158661, 21.97364998], [74.32058716, 21.97359085], [74.31958008, 21.97352028], [74.318573, 21.9734211], [74.31755829, 21.97333145], [74.31655121, 21.97323036], [74.31555176, 21.97310066], [74.31455231, 21.97296906], [74.31356812, 21.97281075], [74.31260681, 21.9726181], [74.31165314, 21.97240067], [74.31067657, 21.9721508], [74.30976105, 21.97186089], [74.30883026, 21.97151947], [74.3079071, 21.97113037], [74.30699921, 21.97068977], [74.30610657, 21.97022057], [74.30523682, 21.96972084], [74.30439758, 21.96917915], [74.30358887, 21.9686203], [74.30280304, 21.96804047], [74.3020401, 21.96743965], [74.30136108, 21.96680069], [74.30079651, 21.9660511], [74.3003006, 21.9652195], [74.29987335, 21.96433067], [74.29947662, 21.96344948], [74.29910278, 21.96257019], [74.29875946, 21.9616909], [74.2984314, 21.96081924], [74.29808044, 21.95992088], [74.29776001, 21.95903015], [74.29749298, 21.95813179], [74.29721069, 21.95721817], [74.29696655, 21.95631027], [74.29677582, 21.95540047], [74.29656982, 21.95449066], [74.29641724, 21.95356941], [74.29631042, 21.952631], [74.29621124, 21.9516983], [74.29611969, 21.95075989], [74.29603577, 21.9498291], [74.29593658, 21.94889069], [74.29585266, 21.94795036], [74.2957077, 21.94703293], [74.29559326, 21.94609833], [74.29538727, 21.94518089], [74.29521179, 21.94425011], [74.29502106, 21.94330025], [74.29480743, 21.94236755], [74.29454803, 21.94145012], [74.29425812, 21.94055939], [74.29387665, 21.93970108], [74.29345703, 21.93888092], [74.29290771, 21.93806076], [74.29225922, 21.93725014], [74.29148865, 21.93658257], [74.29064941, 21.93605995], [74.289711, 21.93579102], [74.28874969, 21.9356308], [74.28779602, 21.93548012], [74.28681946, 21.93534279], [74.2858429, 21.93518829], [74.28486633, 21.93507957], [74.2838974, 21.93494987], [74.28291321, 21.93483925], [74.28190613, 21.93474007], [74.28092194, 21.93464088], [74.27992249, 21.93455124], [74.27893066, 21.93445969], [74.27793121, 21.93437958], [74.2769165, 21.93429947], [74.27591705, 21.9342308], [74.27490997, 21.93416023], [74.27390289, 21.93409157], [74.27288818, 21.93401909], [74.27189636, 21.93394089], [74.27086639, 21.93388176], [74.26988983, 21.93380928], [74.26888275, 21.93374062], [74.26786041, 21.93366814], [74.26685333, 21.93359756], [74.26584625, 21.93352127], [74.26483154, 21.93344116], [74.26383972, 21.93336105], [74.26284027, 21.9332695], [74.26183319, 21.93317032], [74.26085663, 21.93307114], [74.25985718, 21.93296051], [74.25885773, 21.93285179], [74.25785828, 21.93272972], [74.25686646, 21.93259048], [74.255867, 21.93244171], [74.25489044, 21.9323101], [74.25390625, 21.93214989], [74.2529068, 21.93200111], [74.25193024, 21.93182945], [74.25093079, 21.93168259], [74.24994659, 21.93149948], [74.2489624, 21.93134117], [74.24798584, 21.93117905], [74.24700165, 21.9310112], [74.24603271, 21.93084145], [74.24503326, 21.93069077], [74.24402618, 21.93053055], [74.24304199, 21.9303894], [74.24208069, 21.93025017], [74.24108124, 21.93011093], [74.24009705, 21.92999077], [74.2390976, 21.92987061], [74.23809052, 21.92975998], [74.23710632, 21.9296608], [74.23610687, 21.92963028], [74.23510742, 21.92963982], [74.23412323, 21.92970085], [74.23310852, 21.92978096], [74.23208618, 21.92988014], [74.23108673, 21.92996025], [74.23008728, 21.93001938], [74.22908783, 21.93004036], [74.22809601, 21.93000984], [74.22709656, 21.92990112], [74.22614288, 21.92975998], [74.2251358, 21.92958832], [74.22416687, 21.92941284], [74.22319031, 21.92920113], [74.22219849, 21.92900085], [74.22122955, 21.9287796], [74.22026825, 21.92855072], [74.21927643, 21.92831993], [74.2183075, 21.92809105], [74.21733093, 21.92784119], [74.21636963, 21.92759132], [74.21539307, 21.92736053], [74.21440887, 21.92712021], [74.21343231, 21.92687988], [74.21246338, 21.92666054], [74.21147919, 21.92645073], [74.21051788, 21.92624092], [74.20952606, 21.92605972], [74.20855713, 21.9258709], [74.20758057, 21.92571831], [74.20658875, 21.92557907], [74.20561981, 21.92547035], [74.20464325, 21.92541122], [74.20362091, 21.92539978], [74.20262146, 21.92543983], [74.20163727, 21.92552948], [74.20063782, 21.92564964], [74.19962311, 21.92580032], [74.19863129, 21.92597008], [74.19763947, 21.92613983], [74.1966629, 21.9263382], [74.19567108, 21.92651939], [74.19467926, 21.92671013], [74.19367981, 21.92690086], [74.19268799, 21.92711067], [74.19169617, 21.92733955], [74.19069672, 21.92760277], [74.18974304, 21.92790031], [74.18882751, 21.92822266], [74.18792725, 21.92864037], [74.18708801, 21.92910767], [74.18630981, 21.92963982], [74.18554688, 21.93022156], [74.18480682, 21.93084145], [74.18408966, 21.93151093], [74.18341827, 21.93219948], [74.18273163, 21.93292046], [74.18206787, 21.93365097], [74.18144226, 21.93439102], [74.18080902, 21.93514061], [74.18016052, 21.93588066], [74.17952728, 21.93661118], [74.17893219, 21.93735123], [74.1783905, 21.93814087], [74.1778717, 21.93894958], [74.17735291, 21.93976021], [74.17681122, 21.94055939], [74.17624664, 21.9413414], [74.17563629, 21.94205284], [74.17494202, 21.94273186], [74.17418671, 21.94338036], [74.17343903, 21.94398117], [74.17260742, 21.94454956], [74.17179108, 21.94509125], [74.17095184, 21.94557953], [74.17011261, 21.94608116], [74.16924286, 21.94655037], [74.168396, 21.94704056], [74.16752625, 21.94752121], [74.16665649, 21.94800949], [74.16578674, 21.94846153], [74.16490936, 21.94893837], [74.16404724, 21.94939995], [74.16316223, 21.94985008], [74.16226959, 21.95030022], [74.16140747, 21.95074081], [74.1605072, 21.95116997], [74.15962219, 21.95158958], [74.15872192, 21.95201111], [74.1578064, 21.95240974], [74.15692139, 21.95280075], [74.15598297, 21.95310974], [74.15500641, 21.95334816], [74.15400696, 21.95356941], [74.15302277, 21.95369911], [74.15202332, 21.95386124], [74.15101624, 21.95396042], [74.15003204, 21.95401001], [74.14904022, 21.95403099], [74.14803314, 21.95404053], [74.14702606, 21.95404053], [74.14601898, 21.9540596], [74.14467621, 21.95656967], [74.14890289, 21.96071053], [74.1453476, 21.96461105], [74.14335632, 21.96988106], [74.14366913, 21.97222137], [74.14560699, 21.97400093], [74.15320587, 21.97557068], [74.1518631, 21.98089027], [74.15384674, 21.98641968], [74.14959717, 21.98880959], [74.14198303, 21.99123192], [74.12773132, 21.99376106], [74.11688995, 21.99863052], [74.1082077, 21.99835968], [74.10500336, 21.99893951], [74.1003418, 22.00159264], [74.10045624, 22.01055908], [74.09770203, 22.01545906], [74.10118866, 22.01828003], [74.10890198, 22.02181053], [74.11664581, 22.02464104], [74.12088776, 22.03026962], [74.1251297, 22.03589058], [74.13208008, 22.03873062], [74.14100647, 22.04086113], [74.14523315, 22.04368019], [74.14404297, 22.04788971], [74.13939667, 22.0506897], [74.13783264, 22.05350113], [74.14906311, 22.05632019], [74.15447998, 22.0577507], [74.16298676, 22.06056976], [74.16336823, 22.06409073], [74.16179657, 22.07110977], [74.16487885, 22.07393265], [74.16602325, 22.07814026], [74.16755676, 22.08236122], [74.17064667, 22.08447075], [74.17646027, 22.08449173], [74.18070984, 22.08660126], [74.17875671, 22.09011078], [74.17527008, 22.09151077], [74.17215729, 22.09360123], [74.17411041, 22.09641075], [74.17214203, 22.09852982], [74.17021179, 22.1013298], [74.1655426, 22.10271835], [74.16204834, 22.10271072], [74.15856171, 22.10200119], [74.15621185, 22.10409927], [74.15466309, 22.10550117], [74.15000916, 22.10408974], [74.14382172, 22.10126114], [74.13800049, 22.09845161], [74.13259125, 22.09632111], [74.13027191, 22.09770966], [74.12906647, 22.10333824], [74.12905884, 22.10825157], [74.13020325, 22.11387062], [74.13134766, 22.1201992], [74.13130951, 22.12441063], [74.12782288, 22.12721062], [74.12663269, 22.13212013], [74.12738037, 22.13774109], [74.12967682, 22.14266014], [74.13355255, 22.14619255], [74.13314056, 22.15321922], [74.13349152, 22.15813065], [74.13504028, 22.1616497], [74.13189697, 22.16444016], [74.1264801, 22.16654015], [74.12490845, 22.17215919], [74.12409973, 22.17776108], [74.12291718, 22.18198013], [74.12211609, 22.18760109], [74.12364197, 22.19252014], [74.12245941, 22.19812965], [74.12124634, 22.2051506], [74.12240601, 22.20866013], [74.12277985, 22.21290016], [74.11927032, 22.21638107], [74.11383057, 22.21918106], [74.10761261, 22.22056961], [74.10177612, 22.22056007], [74.09440613, 22.221241], [74.08744049, 22.22051048], [74.08159637, 22.22050095], [74.07578278, 22.22187805], [74.07338715, 22.22960091], [74.07454681, 22.2345295], [74.07842255, 22.23735809], [74.08460999, 22.23805809], [74.0892868, 22.24019051], [74.09158325, 22.24370003], [74.08922577, 22.24720955], [74.08535004, 22.24790001], [74.08067322, 22.24999046], [74.07872772, 22.25278091], [74.07987213, 22.25842094], [74.07943726, 22.26333809], [74.07826996, 22.2682476], [74.07242584, 22.26893044], [74.06891632, 22.27243042], [74.06463623, 22.2759304], [74.06149292, 22.28084183], [74.0591507, 22.28574944], [74.05989075, 22.29067039], [74.05832672, 22.29348183], [74.0579071, 22.29980087], [74.05905151, 22.30541039], [74.06254578, 22.3068409], [74.06643677, 22.30544281], [74.06680298, 22.31105995], [74.06674194, 22.31739044], [74.06828308, 22.32582283], [74.06826782, 22.33073044], [74.07405853, 22.33638191], [74.07596588, 22.34130287], [74.0743866, 22.34621048], [74.07164764, 22.34901047], [74.07084656, 22.35462952], [74.07198334, 22.36024094], [74.07702637, 22.36238098], [74.08364105, 22.36239052], [74.08985901, 22.36241913], [74.09527588, 22.36244011], [74.09836578, 22.36876106], [74.09989929, 22.37297821], [74.10534668, 22.37299156], [74.11196136, 22.37161255], [74.11508942, 22.36740112], [74.1162796, 22.36108971], [74.11709595, 22.35757065], [74.12445831, 22.35830116], [74.12914276, 22.35268974], [74.13034821, 22.34355927], [74.13153076, 22.33794975], [74.1342926, 22.3323307], [74.14362335, 22.33026123], [74.15409851, 22.32887077], [74.16384125, 22.32678986], [74.17588806, 22.32471275], [74.18406677, 22.32261086], [74.19106293, 22.32192993], [74.19568634, 22.32543945], [74.19644165, 22.33390045], [74.19484711, 22.34371948], [74.19483185, 22.34934044], [74.19754028, 22.35073853], [74.1979599, 22.34793282], [74.198349, 22.34301949], [74.2022171, 22.34303093], [74.20533752, 22.34794998], [74.20609283, 22.35357094], [74.20565796, 22.35989952], [74.20603943, 22.36341095], [74.20680237, 22.36762047], [74.20993042, 22.36621094], [74.21111298, 22.36273003], [74.21344757, 22.35921097], [74.21656036, 22.35781288], [74.22355652, 22.35783005], [74.22704315, 22.35853958], [74.22663116, 22.36485291], [74.22738647, 22.36907005], [74.22737885, 22.37259293], [74.22582245, 22.37540054], [74.22543335, 22.37820053], [74.23085022, 22.37962151], [74.2351532, 22.37821007], [74.24019623, 22.37681961], [74.24563599, 22.37753105], [74.24600983, 22.38315964], [74.24951935, 22.38315964], [74.25300598, 22.38387108], [74.25611115, 22.38599014], [74.25685883, 22.39019966], [74.25723267, 22.39511108], [74.25798798, 22.40003014], [74.26345062, 22.39653969], [74.26850891, 22.39443016], [74.27394867, 22.3930397], [74.28135681, 22.39375114], [74.2871933, 22.39306068], [74.29106903, 22.39166069], [74.29418182, 22.39446831], [74.28830719, 22.39797974], [74.28172302, 22.40007973], [74.27820587, 22.40287971], [74.27471161, 22.40357971], [74.27120972, 22.40498161], [74.2700119, 22.41059113], [74.26999664, 22.41481018], [74.26648712, 22.4183197], [74.26412201, 22.42464066], [74.25945282, 22.42885017], [74.25402069, 22.43305969], [74.24659729, 22.4365406], [74.23725891, 22.43934059], [74.22831726, 22.44003105], [74.22364044, 22.44001007], [74.22054291, 22.4421196], [74.21856689, 22.4428196], [74.21663666, 22.43931961], [74.21626282, 22.43439102], [74.21160126, 22.43437004], [74.20461273, 22.43717194], [74.20459747, 22.44067955], [74.2045517, 22.44701004], [74.20493317, 22.45474052], [74.20450592, 22.46105003], [74.20449066, 22.46668053], [74.20252991, 22.47229958], [74.19785309, 22.47509956], [74.19082642, 22.47788048], [74.18541718, 22.46944046], [74.18270874, 22.46453094], [74.18234253, 22.46030045], [74.18430328, 22.45609093], [74.18624878, 22.45259285], [74.18743134, 22.44767189], [74.18667603, 22.44415092], [74.18280029, 22.44275093], [74.17267609, 22.44201279], [74.17153931, 22.43779182], [74.17077637, 22.4335804], [74.1672821, 22.43217087], [74.16107178, 22.43215942], [74.15873718, 22.43494987], [74.15598297, 22.43987274], [74.15596008, 22.44548988], [74.15672302, 22.45041084], [74.15628815, 22.4567318], [74.15122986, 22.45671844], [74.14424896, 22.45671082], [74.14074707, 22.4538784], [74.13728333, 22.44824982], [74.13417816, 22.44262123], [74.13111115, 22.43629074], [74.1307373, 22.42996979], [74.13037872, 22.42505074], [74.13037872, 22.42154121], [74.12689972, 22.42012978], [74.1230011, 22.4208107], [74.11637115, 22.42642021], [74.11051941, 22.42921066], [74.10507202, 22.43341064], [74.10270691, 22.4397316], [74.10073853, 22.44534111], [74.10225677, 22.4509697], [74.10573578, 22.45589066], [74.10610962, 22.4622097], [74.10334778, 22.46783066], [74.10024261, 22.46923256], [74.0951767, 22.46920967], [74.09050751, 22.46920013], [74.08583832, 22.46707916], [74.07808685, 22.46564293], [74.07843018, 22.47339058], [74.07878876, 22.48111153], [74.08030701, 22.48603058], [74.08344269, 22.48463058], [74.08538818, 22.48182106], [74.08889771, 22.47973251], [74.09043884, 22.48254967], [74.08963776, 22.48887062], [74.08727264, 22.49378014], [74.08570099, 22.4987011], [74.08644867, 22.50502014], [74.08526611, 22.50851822], [74.08136749, 22.50851822], [74.07865143, 22.50921059], [74.07396698, 22.51059914], [74.06968689, 22.50988007], [74.0650177, 22.51057053], [74.06188965, 22.51126099], [74.05879974, 22.51054955], [74.05609894, 22.50562859], [74.0545578, 22.50139809], [74.0499115, 22.49998283], [74.04640961, 22.49715996], [74.04566956, 22.49294281], [74.04293823, 22.49082947], [74.03708649, 22.49151039], [74.03591919, 22.49641991], [74.03511047, 22.50274277], [74.03466797, 22.50836945], [74.0389328, 22.51400185], [74.04358673, 22.51682091], [74.04315948, 22.52384949], [74.04078674, 22.5301609], [74.04231262, 22.53718948], [74.04463959, 22.54212189], [74.0500412, 22.54565048], [74.05628204, 22.5477829], [74.06674957, 22.55089951], [74.07805634, 22.55162811], [74.08428955, 22.54955101], [74.09327698, 22.54465103], [74.10069275, 22.54117012], [74.10575104, 22.53767014], [74.10964966, 22.53839111], [74.11351776, 22.54120064], [74.11859894, 22.53981018], [74.12211609, 22.53560829], [74.12484741, 22.53000069], [74.12760925, 22.52437973], [74.12995911, 22.52158928], [74.13347626, 22.51877975], [74.13852692, 22.52019119], [74.14321136, 22.51880074], [74.14788818, 22.51811028], [74.15332031, 22.51741982], [74.15680695, 22.52094078], [74.15795135, 22.52656937], [74.15753937, 22.53219032], [74.15869141, 22.53429985], [74.16295624, 22.53712082], [74.16802216, 22.54134941], [74.1726532, 22.54486847], [74.17887115, 22.54840088], [74.18431854, 22.54981041], [74.19171143, 22.55335045], [74.19519806, 22.55686951], [74.19557953, 22.56038094], [74.19519043, 22.56248856], [74.19007874, 22.56740189], [74.19941711, 22.57022095], [74.20332336, 22.56812096], [74.20955658, 22.5667305], [74.21383667, 22.56744003], [74.21652222, 22.57798958], [74.2184906, 22.58151054], [74.22274017, 22.58152008], [74.22622681, 22.5850296], [74.22737122, 22.59065819], [74.23008728, 22.59699059], [74.23432922, 22.6068306], [74.23665619, 22.61387062], [74.24365997, 22.61387062], [74.24754333, 22.61740112], [74.24986267, 22.62302017], [74.25374603, 22.62302971], [74.25763702, 22.62444115], [74.25840759, 22.62655067], [74.25644684, 22.63076019], [74.25641632, 22.63568115], [74.25914764, 22.63639069], [74.26226807, 22.63850975], [74.26342773, 22.64272118], [74.26535797, 22.6448307], [74.26925659, 22.64344025], [74.27160645, 22.64133263], [74.27355194, 22.64063263], [74.27472687, 22.64274025], [74.27822113, 22.64766121], [74.28991699, 22.64344978], [74.29458618, 22.64136124], [74.29888153, 22.64067078], [74.30433655, 22.63997078], [74.3094101, 22.63928032], [74.31328583, 22.63858032], [74.31720734, 22.63646126], [74.32227325, 22.63647842], [74.32537079, 22.63858986], [74.32653046, 22.64211082], [74.32807922, 22.64421082], [74.33081055, 22.64351082], [74.33434296, 22.64141083], [74.33705139, 22.64071274], [74.34406281, 22.6421299], [74.35224915, 22.63932037], [74.36395264, 22.63652039], [74.37288666, 22.63652992], [74.38108826, 22.63863945], [74.38418579, 22.64356995], [74.38456726, 22.65057945], [74.38414001, 22.66043091], [74.38490295, 22.66957092], [74.38994598, 22.67801285], [74.39424133, 22.68573952], [74.39692688, 22.69207001], [74.39691162, 22.70050049], [74.40080261, 22.70681953], [74.40117645, 22.71244049], [74.40078735, 22.72017097], [74.40307617, 22.73070908], [74.40851593, 22.73705101], [74.41438293, 22.74477959], [74.41707611, 22.75111008], [74.42057037, 22.75743103], [74.42523956, 22.76024055], [74.43107605, 22.77008057], [74.43534851, 22.77922249], [74.43923187, 22.78555107], [74.44039917, 22.79327965], [74.44078064, 22.79961014], [74.43881989, 22.80521965], [74.4391861, 22.80944061], [74.4438858, 22.81014061], [74.45168304, 22.81085968], [74.45947266, 22.81225967], [74.46494293, 22.81508064], [74.46881866, 22.82351112], [74.4719162, 22.83265114], [74.47891998, 22.85864067], [74.47540283, 22.86497116], [74.47421265, 22.86778069], [74.47380066, 22.87479973], [74.47146606, 22.88043976], [74.46871185, 22.88746071], [74.46636963, 22.8944912], [74.466362, 22.90081024], [74.46360016, 22.90714073], [74.46282196, 22.91345978], [74.45812988, 22.91628265], [74.45500946, 22.91838074], [74.45147705, 22.92399979], [74.44406128, 22.92259979], [74.43859863, 22.9176712], [74.43585968, 22.92048073], [74.4319458, 22.92258072], [74.42843628, 22.91978073], [74.42375946, 22.91978073], [74.41870117, 22.9183712], [74.41243744, 22.91274834], [74.40817261, 22.90431023], [74.400383, 22.89937973], [74.39293671, 22.90219116], [74.38826752, 22.90710258], [74.38160706, 22.90990829], [74.37769318, 22.91553116], [74.37454987, 22.9225502], [74.37140656, 22.92605972], [74.36553955, 22.92957115], [74.3620224, 22.93309021], [74.36003876, 22.94222069], [74.35417938, 22.9471302], [74.34792328, 22.95344925], [74.34438324, 22.95836258], [74.34163666, 22.96469116], [74.34971619, 22.96876907], [74.35481262, 22.97511101], [74.35713959, 22.97722054], [74.36297607, 22.97793007], [74.36805725, 22.97653008], [74.3707962, 22.97723007], [74.3707962, 22.98005295], [74.3687973, 22.98355103], [74.36546326, 22.98981094], [74.35771179, 23.00037193], [74.35536194, 23.00307083], [74.35066223, 23.01552963], [74.34919739, 23.03024101], [74.3467865, 23.03394127], [74.33886719, 23.03582954], [74.33191681, 23.03919029], [74.32772064, 23.04269028], [74.32531738, 23.04817009], [74.32277679, 23.06269073], [74.33927917, 23.06697083], [74.3478775, 23.07080078], [74.35510254, 23.07580185], [74.35954285, 23.08049965], [74.36112213, 23.09031105], [74.36696625, 23.09552002], [74.38767242, 23.11044121], [74.39118958, 23.11199951], [74.40683746, 23.11177063], [74.41409302, 23.11096191], [74.41884613, 23.10847092], [74.42610168, 23.10602951], [74.4331665, 23.10568047], [74.4393158, 23.09807968], [74.4454422, 23.09293175], [74.45823669, 23.08706093], [74.46724701, 23.08525848], [74.49140167, 23.08838272], [74.51228333, 23.08883095], [74.51360321, 23.09590149], [74.52327728, 23.09891129], [74.53543854, 23.10151291], [74.54265594, 23.10690117], [74.54650116, 23.11280823], [74.54751587, 23.11849022], [74.54570007, 23.13207054], [74.56604004, 23.13523293], [74.57363129, 23.1371994], [74.58007812, 23.13997078], [74.58863068, 23.14146996], [74.59723663, 23.14199257], [74.60806274, 23.14482117], [74.61415863, 23.14833069], [74.61782837, 23.15193176], [74.62567902, 23.16294098], [74.64198303, 23.17266273], [74.65474701, 23.18202972], [74.65983582, 23.18789101], [74.66532135, 23.19824982], [74.66915894, 23.2014904], [74.68756866, 23.19670105], [74.71552277, 23.19466972], [74.721138, 23.19697952], [74.73477936, 23.20639992], [74.74569702, 23.21211052], [74.74603271, 23.21536064], [74.75083923, 23.23038101], [74.7457962, 23.23270988], [74.74098206, 23.2293396], [74.74053955, 23.22904015], [74.73995972, 23.22863007], [74.7329483, 23.22375107], [74.72431946, 23.22011948], [74.71895599, 23.21943283], [74.712883, 23.22135925], [74.7026062, 23.21970177], [74.69960785, 23.22034073], [74.69500732, 23.22307968], [74.69554138, 23.22859001], [74.70381165, 23.23315048], [74.71324921, 23.2363205], [74.72215271, 23.24251175], [74.71853638, 23.24600983], [74.71489716, 23.25296021], [74.71026611, 23.25814056], [74.70334625, 23.26164246], [74.70162201, 23.26675034], [74.70114899, 23.27214241], [74.68048859, 23.27526283], [74.67312622, 23.27486992], [74.66649628, 23.27111053], [74.65222168, 23.26081276], [74.64624786, 23.25971985], [74.63214111, 23.26340103], [74.62956238, 23.26584053], [74.6265564, 23.27599907], [74.62229156, 23.28133965], [74.61530304, 23.28460121], [74.60669708, 23.28536034], [74.59905243, 23.28363037], [74.592659, 23.28358078], [74.58676147, 23.28446007], [74.57728577, 23.29734993], [74.5719223, 23.30089188], [74.56735229, 23.29846191], [74.56210327, 23.29208946], [74.55822754, 23.28531075], [74.5534668, 23.28252029], [74.54856873, 23.28676033], [74.54390717, 23.30005264], [74.54062653, 23.30511284], [74.53568268, 23.30952263], [74.53421021, 23.31398964], [74.53450775, 23.32036972], [74.53366089, 23.32303047], [74.53032684, 23.32414055], [74.52085114, 23.32160187], [74.51924896, 23.32193756], [74.51830292, 23.32872963], [74.52028656, 23.33169174], [74.53839874, 23.33399963], [74.54271698, 23.3386898], [74.5437088, 23.35898972], [74.54582977, 23.36379814], [74.55580902, 23.36297989], [74.56022644, 23.36449051], [74.56521606, 23.37522125], [74.57071686, 23.3777504], [74.57241058, 23.38332939], [74.57314301, 23.41924286], [74.57402039, 23.42254257], [74.57966614, 23.4224205], [74.59146881, 23.42513084], [74.59845734, 23.42975998], [74.61312103, 23.45155144], [74.61338043, 23.46136093], [74.62699127, 23.46198082], [74.63642883, 23.46406174], [74.65223694, 23.46339035], [74.65473175, 23.46442032], [74.65894318, 23.46680069], [74.66409302, 23.47334099], [74.66932678, 23.48389244], [74.67446136, 23.48568153], [74.68093872, 23.48509026], [74.68371582, 23.48658943], [74.68776703, 23.49220085], [74.68740845, 23.49580956], [74.70066071, 23.50368118], [74.71089935, 23.50563049], [74.71877289, 23.50358009], [74.72589111, 23.49846077], [74.73365784, 23.50052071], [74.73777771, 23.50678062], [74.74237061, 23.51947975], [74.75707245, 23.52217293], [74.7639389, 23.52471161], [74.77072906, 23.53577042], [74.77406311, 23.54330254], [74.78501129, 23.54803085], [74.792099, 23.5486412], [74.79633331, 23.54626083], [74.79875946, 23.54043961], [74.80288696, 23.5340519], [74.81230927, 23.53843117], [74.81575775, 23.53961945], [74.81923676, 23.54079819], [74.83009338, 23.54952049], [74.83757782, 23.55321121], [74.84542084, 23.55417061], [74.85147858, 23.55739975], [74.8589859, 23.56949997], [74.86171722, 23.57234001], [74.86933136, 23.57479858], [74.87265015, 23.57822037], [74.87502289, 23.5835495], [74.87457275, 23.59011078], [74.87732697, 23.59439087], [74.87937927, 23.59596062], [74.8849411, 23.60330963], [74.88609314, 23.60642815], [74.89803314, 23.61218262], [74.90602875, 23.62295151], [74.90956879, 23.62416077], [74.92193604, 23.62231064], [74.92787933, 23.62438011], [74.93972015, 23.63037109], [74.94034576, 23.63692284], [74.9389801, 23.64318848], [74.93061066, 23.64821815], [74.92838287, 23.6531601], [74.92421722, 23.6685009], [74.90991211, 23.67690086], [74.90762329, 23.68283081], [74.91043854, 23.68798065], [74.91745758, 23.6921196], [74.92304993, 23.69658089], [74.92289734, 23.71386909], [74.92424011, 23.71915054], [74.93199158, 23.72834015], [74.94056702, 23.73487091], [74.93810272, 23.74287987], [74.93192291, 23.75641823], [74.93187714, 23.75811005], [74.93992615, 23.76585007], [74.93947601, 23.77067184], [74.93785095, 23.77671051], [74.92993164, 23.79420853], [74.92761993, 23.79833031], [74.91500854, 23.79918861], [74.91033936, 23.80084038], [74.91191864, 23.81261063], [74.91326141, 23.83662987], [74.91581726, 23.8456707], [74.91313934, 23.84986115], [74.91024017, 23.85213089], [74.90688324, 23.85638046], [74.90518951, 23.86811066], [74.9056778, 23.8739109], [74.90724182, 23.87675095], [74.91049957, 23.88850975], [74.91385651, 23.90336037], [74.91461945, 23.91246986], [74.91742706, 23.91757011], [74.92337799, 23.92490959], [74.92360687, 23.92926979], [74.92131042, 23.93571281], [74.92431641, 23.93861008], [74.92984772, 23.94096184], [74.93112183, 23.94491005], [74.93151855, 23.94681931], [74.93760681, 23.95608139], [74.94145966, 23.96051979], [74.96334839, 23.97367096], [74.96869659, 23.97973061], [74.97292328, 23.99105263], [74.972229, 24.00362968], [74.97981262, 24.00989914], [74.98779297, 24.01433182], [74.99236298, 24.02323151], [74.99298859, 24.02970123], [74.99038696, 24.03343964], [74.98121643, 24.04104042], [74.97940826, 24.07201195], [74.97625732, 24.07600975], [74.97155762, 24.07785988], [74.96517181, 24.08272171], [74.96186066, 24.08963013], [74.96074677, 24.09416008], [74.96089172, 24.10550117], [74.95951843, 24.11009026], [74.95487213, 24.11203957], [74.93914032, 24.12111092], [74.93618011, 24.12376976], [74.9389801, 24.12788963], [74.93665314, 24.13898087], [74.92469025, 24.14523125], [74.92350769, 24.14928055], [74.92751312, 24.15715027], [74.92146301, 24.16024971], [74.9201889, 24.16284752], [74.90033722, 24.17430115], [74.89948273, 24.17844009], [74.8976593, 24.18237114], [74.89729309, 24.18704033], [74.8811264, 24.21350288], [74.88017273, 24.21648026], [74.88671112, 24.22492027], [74.88970947, 24.22689056], [74.89821625, 24.22907066], [74.90271759, 24.23101044], [74.90585327, 24.23372078], [74.90725708, 24.24081039], [74.90544128, 24.24530983], [74.90405273, 24.24587822], [74.89700317, 24.24917984], [74.89428711, 24.2616806], [74.88905334, 24.26684952], [74.88530731, 24.2687397], [74.87542725, 24.27802086], [74.86972046, 24.28070831], [74.86403656, 24.27396011], [74.86255646, 24.27370071], [74.85975647, 24.27299118], [74.85659027, 24.27219963], [74.85331726, 24.26997948], [74.84390259, 24.27016068], [74.83891296, 24.27123833], [74.83264923, 24.27157021], [74.82578278, 24.27330017], [74.81964874, 24.27626038], [74.81516266, 24.27700996], [74.79029846, 24.27187157], [74.77968597, 24.27260971], [74.77253723, 24.27198029], [74.76647949, 24.27342033], [74.75479126, 24.27897072], [74.75280762, 24.28265953], [74.75302124, 24.28939056], [74.75746155, 24.29622078], [74.7670517, 24.30446053], [74.78363037, 24.31680107], [74.78482056, 24.32113075], [74.78317261, 24.3194294], [74.78379059, 24.33609962], [74.78633881, 24.34386063], [74.78621674, 24.34880066], [74.78276062, 24.35466003], [74.78167725, 24.35835075], [74.78462219, 24.36736107], [74.7869873, 24.3716507], [74.78835297, 24.37177086], [74.79315948, 24.37614059], [74.79833221, 24.384161], [74.80227661, 24.38734055], [74.80541229, 24.39545059], [74.81231689, 24.40915108], [74.81479645, 24.41069031], [74.82524109, 24.40833282], [74.82639313, 24.41069031], [74.82723236, 24.41680908], [74.82701111, 24.42360115], [74.8351593, 24.42951965], [74.84586334, 24.44073105], [74.8477478, 24.44355965], [74.85389709, 24.44950294], [74.85749817, 24.45150185], [74.85817719, 24.4555397], [74.85695648, 24.46327972], [74.85813141, 24.46733284], [74.85411072, 24.47020912], [74.85066986, 24.4688282], [74.8493576, 24.46664047], [74.84455109, 24.46590996], [74.84085083, 24.46722031], [74.8365097, 24.46539116], [74.83378601, 24.46042061], [74.81826782, 24.4619503], [74.82010651, 24.47290039], [74.8246994, 24.47923088], [74.82419586, 24.48354912], [74.82238007, 24.4878006], [74.81684113, 24.49117088], [74.81450653, 24.49221039], [74.81083679, 24.49200058], [74.80800629, 24.49304008], [74.801651, 24.49208069], [74.79595184, 24.49324989], [74.79187775, 24.49327087], [74.78495789, 24.48989105], [74.78153229, 24.48486137], [74.77899933, 24.48338127], [74.77330017, 24.48509979], [74.7661972, 24.49065018], [74.76081848, 24.48857117], [74.75731659, 24.48882294], [74.75065613, 24.49200058], [74.73504639, 24.50362015], [74.73082733, 24.51003075], [74.72718811, 24.5107708], [74.72370911, 24.51040077], [74.71555328, 24.50823975], [74.71290588, 24.50922012], [74.71193695, 24.51094055], [74.71570587, 24.52283096], [74.72342682, 24.53115082], [74.7285614, 24.53479004], [74.74771118, 24.53623962], [74.74961853, 24.5425396], [74.74759674, 24.5476799], [74.74854279, 24.5517292], [74.75234222, 24.55237007], [74.75675201, 24.55462074], [74.75746155, 24.55681992], [74.75634766, 24.55989075], [74.7569809, 24.56365013], [74.75547791, 24.57098961], [74.75377655, 24.57838058], [74.75154114, 24.58611107], [74.75031281, 24.58866119], [74.74668884, 24.59299278], [74.74797058, 24.59680939], [74.75595093, 24.6006794], [74.76017761, 24.60139084], [74.77065277, 24.60584259], [74.77723694, 24.60539055], [74.78176117, 24.6071701], [74.78633118, 24.61010933], [74.79012299, 24.61075974], [74.79055023, 24.61740112], [74.7873764, 24.61759186], [74.78781891, 24.62078094], [74.78483582, 24.62928963], [74.78344727, 24.63676071], [74.79138947, 24.64542961], [74.79350281, 24.64944077], [74.79302216, 24.65155983], [74.79493713, 24.65470123], [74.79934692, 24.65657043], [74.80237579, 24.65691948], [74.8049469, 24.65956116], [74.80873871, 24.66996193], [74.81137848, 24.6716404], [74.81482697, 24.66977119], [74.81710815, 24.67167091], [74.81774902, 24.6764698], [74.81775665, 24.6799202], [74.81333923, 24.6861496], [74.80966949, 24.68653107], [74.79234314, 24.68432045], [74.79197693, 24.68157959], [74.78946686, 24.67893982], [74.7857132, 24.67994118], [74.77606201, 24.68605995], [74.77527618, 24.68773079], [74.77786255, 24.69321823], [74.77731323, 24.69668961], [74.77964783, 24.70066071], [74.78089142, 24.70508957], [74.78385925, 24.7095108], [74.7844162, 24.71264076], [74.78315735, 24.71821976], [74.78753662, 24.72192955], [74.78965759, 24.72663116], [74.78837585, 24.72803116], [74.78386688, 24.73035049], [74.78137207, 24.74085045], [74.78005219, 24.74274826], [74.78607941, 24.74691963], [74.79254913, 24.7501812], [74.79978943, 24.75171089], [74.80314636, 24.75485229], [74.80191803, 24.76654053], [74.80114746, 24.78668976], [74.79847717, 24.7905407], [74.79931641, 24.79564095], [74.80980682, 24.79640007], [74.81495667, 24.78145027], [74.81854248, 24.76534081], [74.8292923, 24.74590111], [74.83487701, 24.73200035], [74.84884644, 24.70872116], [74.84970856, 24.70633125], [74.84984589, 24.69865036], [74.85182953, 24.69659042], [74.85431671, 24.69671059], [74.85531616, 24.69922066], [74.85396576, 24.70412064], [74.85636139, 24.70517921], [74.85853577, 24.70218086], [74.85983276, 24.69388962], [74.86245728, 24.69234276], [74.86521149, 24.69207001], [74.86691284, 24.69052124], [74.86975861, 24.67878914], [74.87268829, 24.67592049], [74.87343597, 24.66948128], [74.87502289, 24.66748047], [74.87767029, 24.66578102], [74.88018036, 24.66801071], [74.88791656, 24.65772247], [74.89285278, 24.65534973], [74.89450836, 24.65814972], [74.8935318, 24.66098022], [74.8935318, 24.66385841], [74.89700317, 24.66555977], [74.90246582, 24.65631104], [74.90563965, 24.66033936], [74.90854645, 24.66157913], [74.90965271, 24.66043091], [74.91300964, 24.66041183], [74.91478729, 24.65942001], [74.91986847, 24.65842056], [74.92945099, 24.65917015], [74.93476105, 24.66184807], [74.93718719, 24.66015053], [74.93917847, 24.66171074], [74.94285583, 24.66039085], [74.94387817, 24.66228294], [74.94181824, 24.66682053], [74.94300842, 24.66889763], [74.95202637, 24.67031288], [74.95265961, 24.67385101], [74.95197296, 24.67646027], [74.95728302, 24.68268967], [74.95923615, 24.67990112], [74.96116638, 24.67889023], [74.96198273, 24.67958069], [74.96182251, 24.68370056], [74.96102905, 24.68609047], [74.95990753, 24.68671989], [74.9598999, 24.68875122], [74.96485901, 24.69454193], [74.96216583, 24.7008419], [74.96411133, 24.70046806], [74.99043274, 24.70634842], [74.99371338, 24.70578957], [74.99655914, 24.70684242], [74.99989319, 24.70848846], [75.00035095, 24.71056938], [74.99941254, 24.71379089], [74.99664307, 24.71599007], [74.99521637, 24.71614075], [74.99211884, 24.72826195], [74.99075317, 24.73376846], [74.99202728, 24.74381065], [74.99343109, 24.75272942], [74.9970932, 24.75420952], [75.02023315, 24.75276756], [75.02131653, 24.76716042], [75.02133942, 24.77026939], [75.02137756, 24.77285957], [75.02005005, 24.7744503], [75.01795959, 24.7807312], [75.01629639, 24.78594971], [75.01293182, 24.79380989], [75.00705719, 24.79606056], [74.99832916, 24.79771042], [74.99001312, 24.79381943], [74.97038269, 24.79086113], [74.96157837, 24.79117012], [74.95542145, 24.79244041], [74.94595337, 24.79171944], [74.93855286, 24.79479027], [74.92941284, 24.79548264], [74.92207336, 24.7884407], [74.91694641, 24.78718185], [74.90997314, 24.78821945], [74.90518188, 24.79746056], [74.89743805, 24.79920959], [74.89195251, 24.79911041], [74.8846817, 24.80243111], [74.88053894, 24.80796814], [74.88014984, 24.8105011], [74.87805176, 24.81318092], [74.87023163, 24.81205177], [74.86785126, 24.81311989], [74.85856628, 24.81306076], [74.85946655, 24.7995491], [74.85794067, 24.79462051], [74.85144806, 24.79265976], [74.84889221, 24.79265976], [74.84078217, 24.80341911], [74.83751678, 24.80846024], [74.84597778, 24.81484032], [74.85296631, 24.81553078], [74.85746002, 24.81784821], [74.85903931, 24.82015991], [74.85903168, 24.82901001], [74.85748291, 24.8429985], [74.85604858, 24.84716988], [74.85588837, 24.85320091], [74.8529129, 24.86033058], [74.84565735, 24.87210274], [74.84237671, 24.87496948], [74.84015656, 24.88055038], [74.8394165, 24.89286995], [74.83783722, 24.89721107], [74.83512115, 24.89703941], [74.83161926, 24.89892006], [74.82713318, 24.89912987], [74.82411194, 24.91481018], [74.8236084, 24.92850113], [74.82421875, 24.94009972], [74.82534027, 24.94045067], [74.82498932, 24.94589043], [74.82627106, 24.95220947], [74.83114624, 24.95730972], [74.83061218, 24.96191025], [74.83271027, 24.9674511], [74.84635162, 24.97429085], [74.85320282, 24.97472], [74.86209869, 24.96583939], [74.86203766, 24.96282959], [74.86351776, 24.95729065], [74.86387634, 24.9475708], [74.86572266, 24.94326973], [74.86720276, 24.93694115], [74.87085724, 24.93720055], [74.87728119, 24.93939018], [74.87911987, 24.9487896], [74.88469696, 24.94976044], [74.8899231, 24.94145012], [74.90054321, 24.93974113], [74.90260315, 24.93727112], [74.90265656, 24.93468094], [74.90428925, 24.93011093], [74.90735626, 24.92867088], [74.91293335, 24.9283886], [74.91100311, 24.92328072], [74.91174316, 24.91887283], [74.90688324, 24.90715981], [74.91252136, 24.89909935], [74.91615295, 24.89944077], [74.91951752, 24.8948307], [74.92008209, 24.89184952], [74.92368317, 24.89207077], [74.92695618, 24.89036942], [74.92951202, 24.88788986], [74.9307785, 24.89397049], [74.93547058, 24.8952198], [74.93969727, 24.8934803], [74.9462204, 24.8939209], [74.9487381, 24.89480019], [74.95020294, 24.89295006], [74.95043182, 24.88997078], [74.94480896, 24.87791061], [74.94883728, 24.87812042], [74.95633698, 24.87495995], [74.96353912, 24.87408066], [74.97173309, 24.8753891], [74.97733307, 24.87747955], [74.98416901, 24.87763023], [74.98751068, 24.87597275], [74.99104309, 24.87500191], [74.99767303, 24.8766098], [75.01261139, 24.87408066], [75.01508331, 24.87020111], [75.0194931, 24.86693001], [75.0229187, 24.86561966], [75.02974701, 24.86054039], [75.03411102, 24.85860062], [75.04338837, 24.85922813], [75.05108643, 24.86488914], [75.05713654, 24.87105179], [75.0598526, 24.87473106], [75.05877686, 24.87771034], [75.05626678, 24.88091087], [75.05634308, 24.88194084], [75.0592804, 24.88129997], [75.0631485, 24.87746811], [75.06620026, 24.87839127], [75.0735321, 24.88731003], [75.07685089, 24.88883972], [75.08167267, 24.88913918], [75.08532715, 24.88889122], [75.0866394, 24.88657951], [75.0870285, 24.88347054], [75.08834076, 24.8810997], [75.09011078, 24.87973022], [75.1149826, 24.88713837], [75.11886597, 24.88903999], [75.11943054, 24.89583015], [75.1177063, 24.9051609], [75.11493683, 24.91184044], [75.11942291, 24.91814041], [75.11772919, 24.94634056], [75.11569214, 24.95364952], [75.11534882, 24.96112823], [75.1157074, 24.96539116], [75.1190567, 24.97475243], [75.11982727, 24.97575951], [75.13352966, 24.97524261], [75.13471985, 24.97772026], [75.13656616, 24.97874069], [75.14685059, 24.97957993], [75.149086, 24.98122025], [75.14775848, 24.98163986], [75.13432312, 24.98266029], [75.13802338, 24.98636246], [75.14037323, 24.98713112], [75.14385986, 24.98705292], [75.14582825, 24.98643112], [75.15215302, 24.98868942], [75.1608963, 24.98761177], [75.16131592, 24.99008942], [75.16256714, 24.99170113], [75.16439819, 24.99166107], [75.16676331, 25.00610924], [75.16924286, 25.00996971], [75.16860199, 25.01319122], [75.16525269, 25.02231979], [75.15921021, 25.02407074], [75.15470886, 25.02886963], [75.15628052, 25.03544044], [75.15912628, 25.04547119], [75.16696167, 25.0442009], [75.17378235, 25.05379295], [75.18209076, 25.04758072], [75.18531036, 25.04253006], [75.1917572, 25.03836823], [75.19441986, 25.03770065], [75.19509125, 25.03751945], [75.20056152, 25.03449821], [75.20355225, 25.0388298], [75.20548248, 25.0424099], [75.21821594, 25.04144096], [75.2270813, 25.03853035], [75.2375412, 25.04191971], [75.24459076, 25.03993034], [75.25562286, 25.04004288], [75.26597595, 25.04306984], [75.27826691, 25.04470062], [75.29255676, 25.04288292], [75.30016327, 25.0440197], [75.31048584, 25.04607964], [75.32266998, 25.0442524], [75.33615875, 25.04488945], [75.34558868, 25.0428009], [75.349617, 25.04173088], [75.35424042, 25.03737068], [75.35005188, 25.03327179], [75.35362244, 25.02873039], [75.35154724, 25.02515984], [75.35061646, 25.0248394], [75.3431015, 25.02230072], [75.32949066, 25.01762962], [75.32248688, 25.01338959], [75.31894684, 25.00650978], [75.32311249, 25.00090981], [75.32203674, 24.99612999], [75.32208252, 24.98961258], [75.32312012, 24.98224068], [75.32636261, 24.97616005], [75.33127594, 24.9760704], [75.3337326, 24.9674511], [75.33541107, 24.96471024], [75.33748627, 24.96310043], [75.33426666, 24.95061111], [75.32875061, 24.94563103], [75.32540894, 24.93809128], [75.31754303, 24.90722084], [75.31387329, 24.90044022], [75.31210327, 24.8999176], [75.31217194, 24.91106033], [75.30832672, 24.92629051], [75.30610657, 24.92897987], [75.30316162, 24.93061256], [75.30229187, 24.9348793], [75.30351257, 24.94017982], [75.30267334, 24.94316101], [75.30018616, 24.94682121], [75.29429626, 24.94870949], [75.29045868, 24.95202065], [75.28980255, 24.95611191], [75.28778076, 24.95963287], [75.28814697, 24.96263123], [75.28556061, 24.96412277], [75.28536224, 24.97669029], [75.27590179, 24.97673035], [75.271492, 24.96821976], [75.26844788, 24.9655304], [75.26631165, 24.96191978], [75.26999664, 24.95627022], [75.27165222, 24.94942093], [75.27722168, 24.94790077], [75.27580261, 24.94027138], [75.28488159, 24.93712044], [75.28790283, 24.9262619], [75.29116821, 24.92496109], [75.29308319, 24.92317963], [75.29190063, 24.92091751], [75.28793335, 24.92053032], [75.28482819, 24.92280006], [75.28237152, 24.92254066], [75.27867889, 24.91749191], [75.27796936, 24.91308022], [75.27485657, 24.91432953], [75.274086, 24.9170475], [75.27171326, 24.91786957], [75.26702881, 24.91421127], [75.26425171, 24.90731049], [75.26077271, 24.90534019], [75.25965881, 24.89982033], [75.26145172, 24.88965988], [75.26508331, 24.88817024], [75.27265167, 24.88693047], [75.27928162, 24.88455009], [75.28807831, 24.87968063], [75.29411316, 24.87137985], [75.29904938, 24.87026024], [75.31130219, 24.86945915], [75.31765747, 24.87515068], [75.32124329, 24.88266182], [75.32596588, 24.88700867], [75.33534241, 24.88667107], [75.35006714, 24.88496971], [75.37197113, 24.87798119], [75.3986969, 24.88834953], [75.40753937, 24.89191055], [75.41416931, 24.89300919], [75.42421722, 24.89275169], [75.42059326, 24.88163185], [75.42063141, 24.87733078], [75.4172821, 24.86861038], [75.417099, 24.86390114], [75.4105072, 24.86123848], [75.39965057, 24.8549099], [75.36396027, 24.84252167], [75.35505676, 24.83743095], [75.34407806, 24.83279037], [75.33744049, 24.83370972], [75.33023071, 24.83172989], [75.32361603, 24.82396126], [75.31981659, 24.81779289], [75.31301117, 24.81353951], [75.30573273, 24.8133297], [75.30049133, 24.81524277], [75.29841614, 24.81990814], [75.29769897, 24.82637024], [75.29421997, 24.83037949], [75.29042053, 24.84091949], [75.28382111, 24.85001945], [75.27893829, 24.85349083], [75.27121735, 24.85635948], [75.25979614, 24.85752106], [75.25234985, 24.85950851], [75.24769592, 24.85950851], [75.24169159, 24.86094093], [75.23406982, 24.8583107], [75.22953033, 24.857481], [75.22738647, 24.85914993], [75.23667145, 24.87088966], [75.24797058, 24.88088989], [75.24994659, 24.89569092], [75.24774933, 24.8999176], [75.24437714, 24.90204048], [75.24124146, 24.90263176], [75.23612976, 24.89929962], [75.23059845, 24.89442062], [75.22341919, 24.89002991], [75.21969604, 24.89220047], [75.22135162, 24.90279961], [75.21920013, 24.90648842], [75.21264648, 24.91007042], [75.20819092, 24.90999985], [75.20742798, 24.90464973], [75.20820618, 24.89775085], [75.20609283, 24.8916111], [75.20288086, 24.88809967], [75.20131683, 24.88420105], [75.20670319, 24.8791008], [75.21038055, 24.87142944], [75.21848297, 24.8594799], [75.22170258, 24.85819054], [75.22601318, 24.85485077], [75.22550201, 24.85103989], [75.22773743, 24.84775925], [75.23378754, 24.84662056], [75.24104309, 24.84686089], [75.24616241, 24.84416962], [75.24968719, 24.84081078], [75.25192261, 24.83716965], [75.25154877, 24.83221817], [75.2494812, 24.82639122], [75.24671173, 24.82184029], [75.24134064, 24.8194294], [75.23661041, 24.82024002], [75.22247314, 24.81896019], [75.21737671, 24.82046127], [75.2064209, 24.8099308], [75.2035675, 24.80168915], [75.20269775, 24.79628754], [75.20358276, 24.79247093], [75.20271301, 24.78880119], [75.19532776, 24.789711], [75.19229889, 24.78874969], [75.18950653, 24.77464104], [75.18768311, 24.77007294], [75.18551636, 24.76805115], [75.18559265, 24.76304054], [75.1868515, 24.76032066], [75.19561768, 24.76000977], [75.19818878, 24.75690079], [75.20191193, 24.74614143], [75.21694946, 24.7224102], [75.21936798, 24.72305107], [75.22141266, 24.73345947], [75.22406006, 24.73546028], [75.22840881, 24.7351017], [75.24246979, 24.73048019], [75.24954224, 24.72914124], [75.26200104, 24.73306084], [75.26724243, 24.73271942], [75.2858429, 24.72590065], [75.30436707, 24.72074127], [75.35086823, 24.71710014], [75.36389923, 24.70951843], [75.37814331, 24.7063694], [75.3964386, 24.70455933], [75.41970062, 24.69996071], [75.43753815, 24.69552994], [75.45189667, 24.69321823], [75.4834671, 24.69762039], [75.505867, 24.70942116], [75.52748108, 24.71791077], [75.53507996, 24.72001839], [75.54122162, 24.71669006], [75.54854584, 24.71556091], [75.55210114, 24.71376991], [75.56899261, 24.71990013], [75.58190155, 24.72270012], [75.6026001, 24.70127106], [75.60943604, 24.6899929], [75.61332703, 24.68842125], [75.63400269, 24.69115067], [75.65918732, 24.70170021], [75.68004608, 24.72783089], [75.71177673, 24.74542999], [75.72306824, 24.7501297], [75.73075867, 24.75555038], [75.74180603, 24.76036072], [75.7596817, 24.76479912], [75.77259827, 24.76204109], [75.78064728, 24.76316071], [75.78618622, 24.76552963], [75.80545807, 24.75626945], [75.82781219, 24.73635292], [75.83875275, 24.72986984], [75.84202576, 24.71746063], [75.83368683, 24.68595123], [75.83154297, 24.67974091], [75.82714081, 24.67150116], [75.82818604, 24.66822243], [75.83706665, 24.66999817], [75.84390259, 24.66934967], [75.84864807, 24.66455078], [75.84880829, 24.65306091], [75.84393311, 24.63927078], [75.84411621, 24.63472176], [75.84620667, 24.63140106], [75.84287262, 24.62611961], [75.83812714, 24.62360191], [75.83428955, 24.62375069], [75.83036041, 24.61995125], [75.82814789, 24.61334991], [75.83920288, 24.60874939], [75.83544159, 24.59756279], [75.83835602, 24.59568977], [75.84233093, 24.60024261], [75.84501648, 24.6103611], [75.84816742, 24.61116028], [75.85254669, 24.61432076], [75.86345673, 24.61292076], [75.86566162, 24.60733986], [75.87407684, 24.60711098], [75.8766861, 24.59964943], [75.87581635, 24.59078026], [75.88436127, 24.58173943], [75.89372253, 24.58167076], [75.89771271, 24.58045006], [75.90287018, 24.57681084], [75.91107178, 24.57705116], [75.91512299, 24.57459068], [75.91739655, 24.5714798], [75.91584778, 24.56736946], [75.91320801, 24.56529045], [75.90956116, 24.56450844], [75.90782166, 24.56536293], [75.90570831, 24.56059265], [75.90661621, 24.55220032], [75.90703583, 24.55046082], [75.91671753, 24.54668808], [75.92051697, 24.54380989], [75.92501831, 24.53829956], [75.9250412, 24.53339958], [75.92204285, 24.52728081], [75.90934753, 24.51488113], [75.90289307, 24.51972008], [75.90216064, 24.52202034], [75.89694977, 24.52226067], [75.89256287, 24.52153015], [75.89105225, 24.50958824], [75.9054718, 24.50530815], [75.90674591, 24.49804115], [75.91181946, 24.4924202], [75.9124527, 24.48558044], [75.90811157, 24.47813034], [75.9072876, 24.46951103], [75.90943909, 24.46363068], [75.90899658, 24.45614052], [75.90335083, 24.45393944], [75.90338898, 24.44613075], [75.89862061, 24.44159126], [75.88648987, 24.4369297], [75.87522888, 24.43028069], [75.86120605, 24.42333031], [75.84725189, 24.41897011], [75.82900238, 24.42251968], [75.8241272, 24.43078995], [75.81254578, 24.43678093], [75.80964661, 24.44123077], [75.81417084, 24.4480896], [75.81646729, 24.45852089], [75.81510925, 24.46511269], [75.80502319, 24.47277069], [75.79564667, 24.47312164], [75.79113007, 24.47520256], [75.78675842, 24.47183037], [75.78409576, 24.46473122], [75.78608704, 24.4584198], [75.78575134, 24.45508957], [75.78357697, 24.45182991], [75.78128052, 24.45391083], [75.77617645, 24.45388031], [75.77567291, 24.44826126], [75.76824188, 24.44034958], [75.75241852, 24.43157005], [75.74872589, 24.42840958], [75.75640869, 24.42766953], [75.75583649, 24.42105293], [75.75527954, 24.40930939], [75.74500275, 24.4070797], [75.7432785, 24.40501022], [75.73581696, 24.40343285], [75.72979736, 24.40360832], [75.728302, 24.40749168], [75.72688293, 24.40527916], [75.72968292, 24.38949966], [75.7353363, 24.39439964], [75.73857117, 24.39529991], [75.73957825, 24.38893127], [75.73829651, 24.36618996], [75.73869324, 24.36125755], [75.74178314, 24.36107254], [75.74180603, 24.35296822], [75.74051666, 24.34974289], [75.73792267, 24.34797096], [75.7562561, 24.32722282], [75.76509094, 24.31065941], [75.77085114, 24.30877113], [75.78103638, 24.30863953], [75.79001617, 24.3110981], [75.79741669, 24.31434822], [75.8030014, 24.31233025], [75.811203, 24.30344963], [75.81299591, 24.30067825], [75.81095123, 24.29804039], [75.81682587, 24.2907505], [75.81143188, 24.28472137], [75.81289673, 24.27709007], [75.81178284, 24.27042961], [75.81852722, 24.26822281], [75.81253052, 24.26065063], [75.81269073, 24.25688171], [75.81806183, 24.24995995], [75.82250977, 24.24733925], [75.82688141, 24.24641037], [75.82636261, 24.24257088], [75.82129669, 24.24102974], [75.81659698, 24.24194908], [75.81424713, 24.23959923], [75.81060791, 24.2419796], [75.80776215, 24.24067116], [75.805336, 24.22971916], [75.79953003, 24.22923088], [75.79534912, 24.22686958], [75.79189301, 24.22324181], [75.77883911, 24.2244091], [75.77350616, 24.22089195], [75.76782227, 24.20754814], [75.76967621, 24.19774055], [75.76862335, 24.19330025], [75.76365662, 24.18978119], [75.75891113, 24.17961121], [75.75827789, 24.17455292], [75.75331879, 24.16434097], [75.75065613, 24.1616497], [75.74349213, 24.13960075], [75.75942993, 24.14035034], [75.76213837, 24.14101028], [75.7651062, 24.13663101], [75.77316284, 24.13944244], [75.77629852, 24.13896179], [75.77868652, 24.13467026], [75.77902985, 24.12462044], [75.78317261, 24.12268066], [75.78478241, 24.11834908], [75.78961182, 24.10980034], [75.80239868, 24.11833], [75.80834961, 24.11335945], [75.81218719, 24.10287094], [75.8306427, 24.10792923], [75.83579254, 24.11135101], [75.83586121, 24.10400009], [75.83267212, 24.09574127], [75.83055115, 24.08159065], [75.83139038, 24.07712173], [75.83376312, 24.07542992], [75.82950592, 24.07195282], [75.82073975, 24.07060051], [75.81334686, 24.07162094], [75.80726624, 24.06760025], [75.78901672, 24.06329918], [75.77961731, 24.06208038], [75.77771759, 24.05714035], [75.78024292, 24.0362606], [75.77778625, 24.02751923], [75.77377319, 24.01910973], [75.77127075, 24.01221085], [75.76782227, 24.0116806], [75.76319885, 24.01396751], [75.76088715, 24.01291084], [75.76008606, 24.00843048], [75.76415253, 24.00530052], [75.76405334, 24.00458145], [75.76431274, 24.00242805], [75.76203918, 23.99795151], [75.75533295, 23.99492264], [75.74957275, 23.99509048], [75.74756622, 23.99347115], [75.73784637, 23.99533272], [75.73738098, 23.99406052], [75.73815155, 23.98816109], [75.73602295, 23.98475075], [75.73626709, 23.9823494], [75.73551178, 23.9805603], [75.73309326, 23.97892952], [75.72776794, 23.9795208], [75.72647858, 23.97877121], [75.72515869, 23.97451973], [75.72331238, 23.97313118], [75.71382141, 23.97208023], [75.70040894, 23.9690609], [75.69845581, 23.97007942], [75.69789886, 23.97208023], [75.69544983, 23.98590088], [75.6964798, 23.98751068], [75.69613647, 23.99039078], [75.6931076, 23.98921013], [75.69065094, 23.98948097], [75.68638611, 23.99054909], [75.68406677, 23.99311066], [75.68354034, 23.99821091], [75.68533325, 24.00234985], [75.68431091, 24.00463104], [75.68580627, 24.01794052], [75.68228912, 24.01695251], [75.67703247, 24.02011108], [75.67269135, 24.03089905], [75.66919708, 24.03354263], [75.65936279, 24.03149986], [75.65313721, 24.02757835], [75.64766693, 24.02320099], [75.64814758, 24.02073097], [75.64591217, 24.01746941], [75.64147186, 24.01836967], [75.63922119, 24.00463104], [75.63846588, 24.00283051], [75.63474274, 23.99983025], [75.6312027, 24.00031281], [75.63051605, 23.99966812], [75.62471771, 23.99882126], [75.61174774, 23.99876022], [75.60678864, 23.99625015], [75.60412598, 23.99628067], [75.59742737, 23.99864006], [75.59262848, 23.9948597], [75.59004974, 23.9963398], [75.58693695, 23.99563026], [75.58383942, 23.99192047], [75.58036804, 23.99430275], [75.57779694, 23.99962044], [75.57596588, 24.00062943], [75.57376862, 23.99847984], [75.56932068, 23.99937057], [75.568367, 24.00114059], [75.56881714, 24.00461006], [75.57171631, 24.01740074], [75.56693268, 24.0227108], [75.56111908, 24.02357864], [75.55264282, 24.0227108], [75.54264832, 24.02556038], [75.53192139, 24.03148079], [75.51438141, 24.04873276], [75.49176788, 24.00455093], [75.48919678, 24.00031281], [75.48597717, 23.99833107], [75.48058319, 23.99233055], [75.47055817, 23.98719978], [75.46720886, 23.9845295], [75.46476746, 23.98072815], [75.46237946, 23.9681015], [75.46170044, 23.95342064], [75.46058655, 23.94762039], [75.45722961, 23.93818092], [75.45636749, 23.93214989], [75.45593262, 23.92543983], [75.45649719, 23.92074013], [75.46089935, 23.91728973], [75.47683716, 23.91473961], [75.48742676, 23.9108429], [75.49957275, 23.90052032], [75.49993134, 23.89690971], [75.50409698, 23.89191055], [75.50734711, 23.89062119], [75.51674652, 23.88875008], [75.52876282, 23.88026047], [75.53787994, 23.87672997], [75.55252838, 23.86515808], [75.55715942, 23.86279106], [75.56062317, 23.85995102], [75.56246185, 23.85814285], [75.56536865, 23.84986115], [75.56720734, 23.84762955], [75.57306671, 23.84647942], [75.57640076, 23.84329033], [75.5761795, 23.84151077], [75.57485962, 23.83801079], [75.57229614, 23.83483124], [75.56931305, 23.8346405], [75.56150818, 23.83698082], [75.56008148, 23.83685112], [75.556633, 23.83160973], [75.55606079, 23.82593155], [75.5585022, 23.82015991], [75.56253052, 23.81693077], [75.56603241, 23.81568909], [75.57279205, 23.81685066], [75.58331299, 23.81520844], [75.5844574, 23.81402016], [75.5848999, 23.80881119], [75.58294678, 23.80380058], [75.58252716, 23.80035973], [75.59168243, 23.80239105], [75.60608673, 23.80364037], [75.60797882, 23.80550003], [75.61213684, 23.80661964], [75.61662292, 23.80597115], [75.6239624, 23.80051994], [75.62594604, 23.80026054], [75.63703918, 23.80236053], [75.64108276, 23.80225945], [75.64367676, 23.80183029], [75.64930725, 23.79935074], [75.65183258, 23.80194855], [75.65680695, 23.7917881], [75.65908813, 23.78894043], [75.6626358, 23.78816032], [75.66747284, 23.78819847], [75.6712265, 23.78680038], [75.67440796, 23.7844677], [75.67605591, 23.78212929], [75.67906952, 23.76954842], [75.68447876, 23.76056862], [75.68515015, 23.76664925], [75.68734741, 23.77333069], [75.69007874, 23.7759819], [75.69671631, 23.78528976], [75.69828796, 23.78800011], [75.69866943, 23.7918396], [75.69451904, 23.79754257], [75.69403839, 23.80455017], [75.68826294, 23.81408119], [75.68692017, 23.8176899], [75.68740082, 23.81925011], [75.69024658, 23.8196106], [75.70259094, 23.81713104], [75.70878601, 23.81809807], [75.71321869, 23.8164711], [75.71569061, 23.81705093], [75.71784973, 23.81903267], [75.71588135, 23.82102013], [75.7167511, 23.82212067], [75.72083282, 23.82364082], [75.72216797, 23.82691193], [75.71872711, 23.83236122], [75.71794891, 23.84004021], [75.71572113, 23.84559059], [75.71787262, 23.84698105], [75.72067261, 23.84678078], [75.72396088, 23.84801102], [75.72637177, 23.8534317], [75.72815704, 23.85505104], [75.72911072, 23.85820961], [75.72754669, 23.86450958], [75.71753693, 23.8647728], [75.70656586, 23.86818123], [75.70474243, 23.87475967], [75.70355225, 23.87543106], [75.70131683, 23.87495995], [75.69812775, 23.87710762], [75.69773865, 23.88772011], [75.69863892, 23.89122963], [75.70094299, 23.89491081], [75.7008667, 23.90127945], [75.70233154, 23.90405083], [75.70707703, 23.90288925], [75.71057892, 23.90040016], [75.71299744, 23.89995956], [75.71549225, 23.90151978], [75.72281647, 23.90061951], [75.72821808, 23.90209961], [75.73132324, 23.9015007], [75.73420715, 23.89952278], [75.73647308, 23.89409065], [75.7400589, 23.89422035], [75.74974823, 23.89002037], [75.75712585, 23.88418961], [75.75917053, 23.88132858], [75.75994873, 23.86199188], [75.7616272, 23.85688972], [75.7696228, 23.85444069], [75.77706146, 23.85387039], [75.77992249, 23.85470009], [75.78385162, 23.85773087], [75.78505707, 23.85980988], [75.78514862, 23.8653698], [75.79102325, 23.87215042], [75.79421997, 23.87430954], [75.80265808, 23.87111092], [75.81394196, 23.87426949], [75.81785583, 23.8793602], [75.83040619, 23.8847599], [75.83703613, 23.88132858], [75.83973694, 23.88256073], [75.84142303, 23.88843918], [75.85341644, 23.89420128], [75.85661316, 23.89400101], [75.86065674, 23.89558983], [75.86351776, 23.895401], [75.86709595, 23.89398956], [75.87236786, 23.88818169], [75.87861633, 23.88455963], [75.88633728, 23.8885994], [75.88878632, 23.89171982], [75.89393616, 23.89308167], [75.89655304, 23.8927002], [75.90126038, 23.89501953], [75.9054718, 23.89606285], [75.9212265, 23.90417099], [75.92695618, 23.9018898], [75.93180847, 23.90193939], [75.93808746, 23.91220856], [75.94433594, 23.91620827], [75.94658661, 23.92071152], [75.94822693, 23.92226028], [75.96652222, 23.92987061], [75.97409058, 23.93153], [75.97582245, 23.93293953], [75.9759903, 23.93898964], [75.98092651, 23.94301987], [75.97981262, 23.95215988], [75.98123169, 23.96241951], [75.98018646, 23.96875954], [75.98018646, 23.97438049], [75.97823334, 23.98007011], [75.97675323, 23.98195076], [75.96353149, 23.99165916], [75.96131897, 23.99484062], [75.96024323, 23.99746132], [75.96092987, 24.00427055], [75.95910645, 24.00997162], [75.96018219, 24.02536964], [75.97336578, 24.03144073], [75.97962189, 24.03209114], [75.97975159, 24.03104973], [75.99008942, 24.03006935], [75.99450684, 24.03190041], [76.00028229, 24.0354805], [76.00213623, 24.03523064], [76.00894165, 24.04030037], [76.01793671, 24.04455948], [76.02672577, 24.05046272], [76.03299713, 24.0642128], [76.0399704, 24.06690979], [76.04335022, 24.07396126], [76.04695892, 24.07567024], [76.05748749, 24.07785034], [76.06372833, 24.07790947], [76.08024597, 24.0839901], [76.08454132, 24.08214951], [76.09082794, 24.08574104], [76.09899902, 24.08918953], [76.10515594, 24.09590912], [76.1085968, 24.09712982], [76.11244965, 24.09650993], [76.12327576, 24.09233284], [76.13469696, 24.09528923], [76.13469696, 24.09972954], [76.13128662, 24.10662079], [76.13005066, 24.11214066], [76.12922668, 24.11893272], [76.1307373, 24.12290955], [76.1368866, 24.13133812], [76.13442993, 24.13933945], [76.13173676, 24.14394188], [76.13047028, 24.15366936], [76.13088989, 24.16905022], [76.12889099, 24.17485809], [76.1254425, 24.17814064], [76.12059784, 24.17823982], [76.11995697, 24.18013954], [76.12085724, 24.18359947], [76.12132263, 24.19639015], [76.12335968, 24.20540047], [76.13156891, 24.21244812], [76.14180756, 24.22384071], [76.14704895, 24.22776985], [76.15236664, 24.23545837], [76.15445709, 24.24376106], [76.14977264, 24.26098061], [76.14836121, 24.26403046], [76.1455307, 24.26576042], [76.14222717, 24.28115082], [76.143013, 24.28528976], [76.14666748, 24.29031944], [76.14952087, 24.29223061], [76.1627121, 24.29336166], [76.1692276, 24.29609108], [76.17002106, 24.30340958], [76.1725769, 24.30722046], [76.1713562, 24.31032944], [76.17212677, 24.31558037], [76.18112946, 24.3248806], [76.18548584, 24.33151054], [76.19004822, 24.32995033], [76.19402313, 24.32086945], [76.20252228, 24.31315994], [76.20623016, 24.31092072], [76.20498657, 24.30570984], [76.19908905, 24.29730034], [76.19560242, 24.29009819], [76.19465637, 24.28479958], [76.20218658, 24.27675056], [76.20437622, 24.26902008], [76.20363617, 24.25058937], [76.205513, 24.2418499], [76.20622253, 24.23274994], [76.21057129, 24.22284126], [76.21556854, 24.21680832], [76.21821594, 24.21738052], [76.22335052, 24.22327042], [76.23612213, 24.22388077], [76.24046326, 24.22618103], [76.24767303, 24.22792053], [76.25180817, 24.22481918], [76.26538086, 24.22154999], [76.27639771, 24.21651077], [76.28277588, 24.21571159], [76.28716278, 24.21825027], [76.28884125, 24.22557068], [76.28964996, 24.23703003], [76.29392242, 24.24067116], [76.3028717, 24.24443054], [76.31012726, 24.24638939], [76.31787872, 24.25113106], [76.32689667, 24.25361824], [76.33499146, 24.25396919], [76.34417725, 24.25189972], [76.35299683, 24.2489109], [76.35829926, 24.24607086], [76.36120605, 24.24448967], [76.3651886, 24.24131012], [76.3735199, 24.23769951], [76.39124298, 24.22561073], [76.40009308, 24.22278976], [76.41179657, 24.20955086], [76.41443634, 24.20742035], [76.41873169, 24.20833969], [76.42253113, 24.21422005], [76.42172241, 24.2206707], [76.4181366, 24.22435951], [76.42360687, 24.22694969], [76.42945099, 24.22706032], [76.43601227, 24.22500038], [76.44184113, 24.2218895], [76.44742584, 24.21774101], [76.45324707, 24.21682167], [76.45862579, 24.22085953], [76.46102142, 24.22541046], [76.46343231, 24.22891998], [76.46994781, 24.23139954], [76.47457123, 24.22870255], [76.47941589, 24.21751022], [76.48442078, 24.21504021], [76.49693298, 24.21203995], [76.50180054, 24.20903015], [76.50538635, 24.20546913], [76.50836945, 24.20023155], [76.51048279, 24.17902946], [76.51333618, 24.1728611], [76.51737976, 24.16657829], [76.52319336, 24.1631794], [76.53143311, 24.16346931], [76.53578186, 24.16421127], [76.53985596, 24.16674995], [76.5459671, 24.16801071], [76.55475616, 24.16822052], [76.5625, 24.1724205], [76.56632996, 24.17645073], [76.57266998, 24.1772995], [76.57972717, 24.18067932], [76.57698822, 24.19131088], [76.56980896, 24.19628906], [76.5669632, 24.19715118], [76.56577301, 24.20079994], [76.567276, 24.20691109], [76.57148743, 24.21347809], [76.58586121, 24.21956062], [76.59255981, 24.22387123], [76.59738922, 24.22991943], [76.5966568, 24.2352829], [76.58747864, 24.24604988], [76.58802032, 24.2495594], [76.59324646, 24.25089073], [76.60047913, 24.24497986], [76.610466, 24.24148941], [76.61395264, 24.24217987], [76.61634827, 24.26284027], [76.62336731, 24.26460838], [76.63008118, 24.26470947], [76.63482666, 24.26405907], [76.64006042, 24.26231956], [76.64222717, 24.26624107], [76.64245605, 24.27011108], [76.64724731, 24.27240944], [76.65821075, 24.26781273], [76.66829681, 24.26738167], [76.67082977, 24.27100945], [76.67874908, 24.27063942], [76.68476868, 24.28269005], [76.69296265, 24.28504944], [76.69491577, 24.28231049], [76.69330597, 24.27404976], [76.69480896, 24.26781273], [76.69664764, 24.26119995], [76.69967651, 24.2578392], [76.70137024, 24.2543602], [76.70249939, 24.24880028], [76.69876099, 24.245121], [76.69523621, 24.24207115], [76.68778229, 24.23245049], [76.68488312, 24.22483253], [76.6767807, 24.21054077], [76.67420959, 24.19342995], [76.68438721, 24.18864059], [76.6893692, 24.18370819], [76.69519043, 24.1760006], [76.70114136, 24.17144012], [76.71247864, 24.16662979], [76.71470642, 24.16418266], [76.72071075, 24.16172028], [76.72683716, 24.16508293], [76.72939301, 24.17056084], [76.73589325, 24.17184258], [76.74938202, 24.17254066], [76.75499725, 24.17209053], [76.75733948, 24.16970253], [76.7594986, 24.16586113], [76.76261902, 24.16421127], [76.76885986, 24.16468048], [76.77308655, 24.15877914], [76.77562714, 24.15307999], [76.7909317, 24.12575912], [76.79721832, 24.12181091], [76.80111694, 24.12034035], [76.81466675, 24.12651062], [76.82183075, 24.12667274], [76.82772827, 24.12559128], [76.83547211, 24.13125038], [76.84233093, 24.13227081], [76.84607697, 24.13614082], [76.85600281, 24.13894081], [76.86628723, 24.13883018], [76.87332916, 24.13978958], [76.87657166, 24.13837814], [76.87758636, 24.13492966], [76.88625336, 24.1317482], [76.89994049, 24.13111115], [76.90579987, 24.15319252], [76.91118622, 24.17690086], [76.91487122, 24.18337059], [76.9161377, 24.1887207], [76.92723846, 24.18666077], [76.9331665, 24.18687057], [76.94386292, 24.19885063], [76.94483185, 24.20330048], [76.94444275, 24.2062912], [76.94254303, 24.20835114], [76.9368515, 24.20979118], [76.93165588, 24.20953941], [76.9282608, 24.21354103], [76.9225769, 24.21679115], [76.91928864, 24.22068977], [76.91855621, 24.22640038], [76.9164505, 24.23196983], [76.91117096, 24.23761177], [76.90389252, 24.24167824], [76.89736176, 24.24708939], [76.87419891, 24.27108955], [76.86994171, 24.27658272], [76.86705017, 24.28085136], [76.86360931, 24.28976059], [76.86380005, 24.29381943], [76.86264038, 24.29883194], [76.85980225, 24.30529022], [76.85878754, 24.31231117], [76.84490967, 24.32798195], [76.84017944, 24.33872032], [76.83888245, 24.34262276], [76.83821106, 24.35495949], [76.83696747, 24.36070824], [76.83883667, 24.36470032], [76.84906006, 24.36820984], [76.85167694, 24.37024117], [76.85231781, 24.37486839], [76.84799957, 24.37883186], [76.8501358, 24.38896942], [76.8483429, 24.39627075], [76.8423996, 24.4085083], [76.83587646, 24.41657066], [76.83769226, 24.41808128], [76.84226227, 24.4181881], [76.84603119, 24.41934013], [76.84926605, 24.42525291], [76.85109711, 24.43539047], [76.85066223, 24.43736076], [76.84117126, 24.4428196], [76.837883, 24.45058823], [76.83862305, 24.45416069], [76.84591675, 24.4532795], [76.84844971, 24.45876122], [76.84897614, 24.46438026], [76.85132599, 24.46910858], [76.85057831, 24.47394943], [76.84629822, 24.47545815], [76.8467865, 24.48755074], [76.84527588, 24.49090004], [76.8423233, 24.49374008], [76.83532715, 24.49438095], [76.83454895, 24.49830055], [76.82810974, 24.51036263], [76.8192215, 24.52462006], [76.81442261, 24.52964973], [76.81416321, 24.53227997], [76.81459045, 24.53437042], [76.81902313, 24.53656006], [76.82675171, 24.53878021], [76.83114624, 24.54319], [76.8381958, 24.54846954], [76.84604645, 24.55101967], [76.85282135, 24.55101967], [76.86620331, 24.54936028], [76.87195587, 24.54589081], [76.87413025, 24.54305077], [76.87475586, 24.54045105], [76.87290192, 24.53203964], [76.87573242, 24.52618027], [76.87954712, 24.52531052], [76.88896942, 24.5267601], [76.89359283, 24.53545952], [76.8928833, 24.53969002], [76.89776611, 24.54370117], [76.89982605, 24.5478096], [76.90238953, 24.54752159], [76.91287231, 24.54356956], [76.91568756, 24.54038048], [76.91838074, 24.53560066], [76.91877747, 24.52998161], [76.91890717, 24.52439117], [76.91734314, 24.51696968], [76.91526031, 24.51140022], [76.91464996, 24.48765945], [76.92288208, 24.48065186], [76.93083954, 24.47669983], [76.93708801, 24.47239113], [76.94108582, 24.46735001], [76.95287323, 24.46393013], [76.96016693, 24.46022987], [76.96531677, 24.46086121], [76.9749527, 24.46492958], [76.97753906, 24.47198105], [76.97966003, 24.47462845], [76.99252319, 24.47344971], [76.99819946, 24.47548294], [77.00152588, 24.47789955], [77.00255585, 24.48349953], [77.00688934, 24.48755074], [77.00496674, 24.48938942], [77.00473022, 24.49196053], [77.0059967, 24.49394989], [77.00866699, 24.4949398], [77.01233673, 24.49436951], [77.01589203, 24.49489975], [77.0206604, 24.49793053], [77.02407074, 24.50132942], [77.02478027, 24.51704979], [77.02670288, 24.5214119], [77.02910614, 24.52376175], [77.02997589, 24.52705956], [77.0319519, 24.52879906], [77.03904724, 24.5266304], [77.05030823, 24.52653122], [77.05092621, 24.53714752], [77.05195618, 24.54125023], [77.05338287, 24.54417038], [77.06153107, 24.55477905], [77.06433868, 24.56412125], [77.06469727, 24.56991005], [77.06355286, 24.5853405], [77.05845642, 24.59481049], [77.05832672, 24.6011982], [77.06034851, 24.60609055], [77.06111908, 24.61050987], [77.06112671, 24.62458992], [77.06028748, 24.63770294], [77.05945587, 24.64241982], [77.05414581, 24.65410805], [77.04894257, 24.6613102], [77.03701019, 24.6827507], [77.03491974, 24.68856049], [77.03450012, 24.69846916], [77.03346252, 24.70294952], [77.0266571, 24.71092033], [77.02265167, 24.71372032], [77.01924896, 24.71495056], [77.01407623, 24.71541977], [77.00422668, 24.71366119], [76.99214172, 24.71739769], [76.98230743, 24.72487259], [76.97197723, 24.73167038], [76.96848297, 24.73608971], [76.96533203, 24.74410057], [76.96383667, 24.75045967], [76.96330261, 24.75955009], [76.95632172, 24.76431084], [76.95173645, 24.76546097], [76.94577789, 24.76404953], [76.92169189, 24.7488308], [76.90939331, 24.74681091], [76.90325928, 24.74604988], [76.8983078, 24.74777031], [76.89692688, 24.75060081], [76.88668823, 24.75415039], [76.86812592, 24.74958038], [76.86084747, 24.74869919], [76.84729767, 24.75040054], [76.84501648, 24.75213814], [76.84702301, 24.76505089], [76.84674072, 24.76999283], [76.83587646, 24.78507042], [76.82579041, 24.79338074], [76.8157196, 24.80367088], [76.80869293, 24.81497955], [76.80410767, 24.8166008], [76.80158234, 24.81983948], [76.80066681, 24.82456017], [76.80229187, 24.82657051], [76.81118774, 24.82823944], [76.81672668, 24.83249855], [76.82308197, 24.83485031], [76.82714081, 24.83835983], [76.83164978, 24.84024239], [76.83750153, 24.84106064], [76.84217834, 24.84011269], [76.85131073, 24.84023094], [76.85748291, 24.84098053], [76.86332703, 24.84169006], [76.8780899, 24.83955193], [76.89504242, 24.83950996], [76.90843201, 24.84509277], [76.91153717, 24.84760094], [76.91506195, 24.84869957], [76.9265213, 24.84978294], [76.9332428, 24.85394096], [76.94312286, 24.86005974], [76.94425964, 24.86547279], [76.94664001, 24.86825943], [76.9489212, 24.87286949], [76.94671631, 24.87419128], [76.9432373, 24.8745594], [76.94185638, 24.87470818], [76.93572998, 24.87868118], [76.93398285, 24.88428116], [76.92176819, 24.8837204], [76.91751862, 24.88479042], [76.91385651, 24.88788033], [76.91216278, 24.89313126], [76.91269684, 24.89724159], [76.91575623, 24.90118027], [76.92032623, 24.90488052], [76.92463684, 24.91037178], [76.92353058, 24.91426086], [76.92086792, 24.91678047], [76.9074173, 24.92325974], [76.89122772, 24.91967964], [76.89015961, 24.92305946], [76.89247131, 24.9290905], [76.89322662, 24.93542099], [76.87970734, 24.94576073], [76.87520599, 24.9509697], [76.87206268, 24.95460129], [76.87336731, 24.95757294], [76.87156677, 24.96130943], [76.86727905, 24.96544075], [76.86643982, 24.97179031], [76.86965942, 24.99189186], [76.86871338, 24.99751091], [76.86805725, 25.00136948], [76.85952759, 25.00691032], [76.85434723, 25.01031113], [76.86055756, 25.01038933], [76.8693161, 25.01110268], [76.87448883, 25.01311111], [76.87680817, 25.01606178], [76.87676239, 25.01801109], [76.87671661, 25.01993942], [76.87828064, 25.02583122], [76.88202667, 25.03409958], [76.90106201, 25.03404045], [76.90976715, 25.03567123], [76.91767883, 25.04003143], [76.92987823, 25.0415802], [76.95349884, 25.0484581], [76.96131134, 25.05398941], [76.96866608, 25.05594063], [76.97126007, 25.06058121], [76.97183228, 25.06683922], [76.97466278, 25.07067108], [76.9836731, 25.07756042], [76.99372864, 25.07995033], [77.00029755, 25.07973099], [77.00595093, 25.07856941], [77.01235199, 25.07491112], [77.01764679, 25.07217026], [77.02039337, 25.07143974], [77.02472687, 25.07180023], [77.02934265, 25.07189941], [77.03929901, 25.06810951], [77.04432678, 25.0657711], [77.0549469, 25.06326294], [77.0613327, 25.06139183], [77.06801605, 25.05969048], [77.07723236, 25.05798912], [77.08426666, 25.06264114], [77.09041595, 25.06636047], [77.10249329, 25.06924057], [77.11445618, 25.06908989], [77.12827301, 25.08905029], [77.14016724, 25.09620094], [77.14045715, 25.09090042], [77.15770721, 25.08827972], [77.1645813, 25.09856987], [77.1628418, 25.10972023], [77.16957855, 25.11371994], [77.18305969, 25.11180115], [77.18876648, 25.11180115], [77.1973877, 25.11667061], [77.20581055, 25.11242104], [77.22083282, 25.11024284], [77.24164581, 25.11272049], [77.26226044, 25.11926079], [77.2755661, 25.11213112], [77.28443146, 25.10421944], [77.29133606, 25.09411049], [77.29593658, 25.08710289], [77.30285645, 25.08386993], [77.30700684, 25.08575058], [77.3098526, 25.08639145], [77.31389618, 25.08756065], [77.32038116, 25.09070969], [77.32801819, 25.09340096], [77.33244324, 25.09657097], [77.34867859, 25.09779167], [77.35714722, 25.10155106], [77.36078644, 25.10434914], [77.36850739, 25.10849953], [77.36839294, 25.11413002], [77.37516022, 25.11681938], [77.38667297, 25.12195969], [77.39227295, 25.11741066], [77.39318848, 25.11528015], [77.39554596, 25.11199951], [77.39852905, 25.11327171], [77.39810944, 25.11641121], [77.39388275, 25.12330055], [77.38861084, 25.12725067], [77.38694, 25.13296127], [77.38739014, 25.13809013], [77.38931274, 25.15103912], [77.38918304, 25.15994072], [77.38961029, 25.16838837], [77.39129639, 25.17469978], [77.3913269, 25.17964935], [77.39070892, 25.18819046], [77.40306091, 25.1865406], [77.4076767, 25.19005966], [77.41475677, 25.18943024], [77.41799164, 25.1930294], [77.41372681, 25.19952965], [77.41133881, 25.20659065], [77.40952301, 25.21243095], [77.40640259, 25.22629166], [77.40081787, 25.22770119], [77.39164734, 25.23114967], [77.38004303, 25.24542046], [77.3755722, 25.24902153], [77.37046814, 25.2509594], [77.36271667, 25.25007057], [77.36203766, 25.25593185], [77.3602829, 25.26085281], [77.35668182, 25.26579094], [77.34966278, 25.27177048], [77.36000061, 25.28022003], [77.36302948, 25.28375816], [77.36672211, 25.28540039], [77.36946869, 25.28852844], [77.37258911, 25.29429054], [77.37336731, 25.29936981], [77.37377167, 25.30018044], [77.37480164, 25.30585098], [77.37462616, 25.31057167], [77.37364197, 25.31549263], [77.37178802, 25.32022095], [77.36894989, 25.32464981], [77.36580658, 25.32850075], [77.3637619, 25.33300018], [77.35317993, 25.33234978], [77.34934235, 25.32413292], [77.33641815, 25.3255806], [77.34391785, 25.33736038], [77.35511017, 25.36437988], [77.35604095, 25.3678894], [77.3538208, 25.36954117], [77.3516922, 25.37235069], [77.34841919, 25.37555122], [77.34474945, 25.3798027], [77.34467316, 25.38334084], [77.34426117, 25.38792992], [77.34610748, 25.39249992], [77.3497467, 25.39838028], [77.35395813, 25.4036293], [77.35764313, 25.40928841], [77.36134338, 25.41296005], [77.35434723, 25.42402267], [77.34371185, 25.42243195], [77.33706665, 25.42475128], [77.32923126, 25.4285717], [77.31690979, 25.43284035], [77.30529785, 25.4364109], [77.29556274, 25.43169022], [77.28298187, 25.42358971], [77.27295685, 25.41200256], [77.25995636, 25.39945984], [77.24964142, 25.39491081], [77.24415588, 25.38961029], [77.23467255, 25.38506126], [77.22564697, 25.37924957], [77.22026062, 25.37342834], [77.22113037, 25.36108017], [77.21701813, 25.34925079], [77.2173996, 25.33724976], [77.21803284, 25.33131027], [77.21502686, 25.32450104], [77.21039581, 25.32447052], [77.20942688, 25.32864952], [77.2131958, 25.33175087], [77.21070099, 25.33369064], [77.20526123, 25.33304977], [77.19815826, 25.33052063], [77.19860077, 25.32464981], [77.2003479, 25.3187294], [77.20514679, 25.31142998], [77.1973877, 25.31097984], [77.19055176, 25.31166077], [77.18210602, 25.31331062], [77.17340851, 25.31517029], [77.16776276, 25.31552124], [77.16159058, 25.31365013], [77.15355682, 25.31324959], [77.14900208, 25.31536293], [77.13630676, 25.32413292], [77.12890625, 25.32541847], [77.12142181, 25.33125114], [77.11576843, 25.33506012], [77.10811615, 25.33527946], [77.10176849, 25.33512115], [77.09262848, 25.33727074], [77.08306122, 25.33980179], [77.07546997, 25.33969116], [77.07142639, 25.33584023], [77.06785583, 25.32966995], [77.0634613, 25.32415009], [77.05825806, 25.32191277], [77.0530014, 25.32069016], [77.04817963, 25.3210907], [77.04479218, 25.32245064], [77.03936005, 25.32505035], [77.03804779, 25.31936073], [77.03412628, 25.3118782], [77.02419281, 25.30109024], [77.01760101, 25.30155945], [77.01010132, 25.30154037], [77.00337219, 25.30183029], [76.99266815, 25.30183029], [76.95874023, 25.29718018], [76.9566803, 25.29142761], [76.95526886, 25.2845993], [76.95272064, 25.2785511], [76.94838715, 25.27652168], [76.94182587, 25.27536011], [76.93393707, 25.27590179], [76.92870331, 25.27915192], [76.93260956, 25.28746986], [76.92920685, 25.29729843], [76.92295837, 25.30137825], [76.91535187, 25.30898094], [76.90463257, 25.31785965], [76.89322662, 25.32240105], [76.88156891, 25.32286072], [76.87258911, 25.32427979], [76.86699677, 25.32516289], [76.85373688, 25.32971191], [76.84297943, 25.33054161], [76.83976746, 25.32928848], [76.83348083, 25.32685089], [76.82614899, 25.32698059], [76.82174683, 25.3270607], [76.79527283, 25.32182121], [76.77282715, 25.31591034], [76.77009583, 25.31219101], [76.75984192, 25.32267952], [76.76225281, 25.32798958], [76.76584625, 25.33204079], [76.76669312, 25.33296967], [76.76673126, 25.33623123], [76.7587204, 25.33869171], [76.75372314, 25.33934021], [76.74040222, 25.34778976], [76.73204803, 25.34787941], [76.72229767, 25.34592056], [76.7145462, 25.34243965], [76.70321655, 25.34761047], [76.68107605, 25.34547997], [76.6727829, 25.35003281], [76.66483307, 25.35750961], [76.65750122, 25.36144066], [76.64360046, 25.37639809], [76.6362915, 25.38033104], [76.62549591, 25.37511063], [76.62262726, 25.37675095], [76.61915588, 25.37873077], [76.61686707, 25.38161278], [76.61487579, 25.3841095], [76.60957336, 25.38830948], [76.60585022, 25.38866997], [76.60254669, 25.38898087], [76.59905243, 25.40530014], [76.58896637, 25.43148994], [76.58297729, 25.43569183], [76.5742569, 25.4366703], [76.56427765, 25.44240189], [76.56066895, 25.44985008], [76.5595932, 25.47326088], [76.55632019, 25.47981071], [76.55066681, 25.48430824], [76.54669189, 25.48968124], [76.54210663, 25.4974308], [76.54016876, 25.50573921], [76.53787231, 25.51020813], [76.53456879, 25.51350021], [76.52854919, 25.51770973], [76.52259827, 25.52429008], [76.52030945, 25.52993011], [76.52246094, 25.54146957], [76.52220917, 25.55035973], [76.52027893, 25.55690002], [76.51634216, 25.56553078], [76.51239777, 25.5717926], [76.50978088, 25.57982063], [76.50985718, 25.5872097], [76.51579285, 25.60700989], [76.51473236, 25.63367844], [76.51077271, 25.63816833], [76.50538635, 25.63821983], [76.50076294, 25.64330292], [76.4994278, 25.64834023], [76.51080322, 25.67283821], [76.50779724, 25.67612076], [76.48906708, 25.68340111], [76.48175812, 25.68939972], [76.4777832, 25.69506073], [76.4779129, 25.70603943], [76.48239136, 25.71813011], [76.50299835, 25.72860909], [76.51075745, 25.73001289], [76.52655029, 25.73104286], [76.53061676, 25.73397064], [76.53040314, 25.74374008], [76.52223969, 25.76634026], [76.5226593, 25.77434158], [76.52931213, 25.79797173], [76.53549194, 25.80917168], [76.54164886, 25.81740189], [76.54946136, 25.82504082], [76.56678009, 25.83967018], [76.58528137, 25.86771965], [76.59272766, 25.8741684], [76.59747314, 25.8764801], [76.61653137, 25.87125015], [76.62660217, 25.87087059], [76.63168335, 25.87524033], [76.6355896, 25.89592934], [76.63833618, 25.90151978], [76.64141846, 25.90625], [76.64612579, 25.90885162], [76.65656281, 25.91081047], [76.67436218, 25.91180038], [76.68405914, 25.91020966], [76.69645691, 25.90711021], [76.70548248, 25.9034729], [76.71452332, 25.90098953], [76.72220612, 25.90031052], [76.73332977, 25.90254974], [76.74546814, 25.90923119], [76.75563049, 25.91623116], [76.76241302, 25.92206955], [76.76278687, 25.92531013], [76.75676727, 25.92835045], [76.75344849, 25.93223953], [76.75283051, 25.93581009], [76.75356293, 25.93963051], [76.75591278, 25.94169044], [76.76065063, 25.94252968], [76.7767868, 25.93938065], [76.78591156, 25.94046974], [76.7947998, 25.9442215], [76.80631256, 25.95297813], [76.81624603, 25.96713066], [76.8188858, 25.97125053], [76.81804657, 25.98427963], [76.81984711, 25.98867989], [76.82328033, 25.99272156], [76.82962799, 25.99592972], [76.83705139, 26.00204086], [76.84024048, 26.0112896], [76.83040619, 26.02959061], [76.83809662, 26.0363903], [76.84572601, 26.04027939], [76.85176849, 26.04351044], [76.85774231, 26.0485611], [76.86392975, 26.05167961], [76.87042236, 26.05644989], [76.87255859, 26.06414986], [76.87696838, 26.07205009], [76.88223267, 26.07860947], [76.88288116, 26.0864296], [76.88777924, 26.09332275], [76.89531708, 26.09802055], [76.90631866, 26.10110092], [76.91834259, 26.10264969], [76.92897034, 26.10268021], [76.93871307, 26.1060791], [76.9418869, 26.10811043], [76.95352173, 26.11531067], [76.96856689, 26.1240406], [76.98603821, 26.13235283], [76.99447632, 26.13778114], [76.99646759, 26.14772034], [76.99968719, 26.15262985], [77.00480652, 26.15924072], [77.00773621, 26.16057968], [77.01123047, 26.16530037], [77.02388, 26.17617035], [77.03473663, 26.18193054], [77.04499054, 26.18494987], [77.05264282, 26.18617058], [77.05893707, 26.18535042], [77.06893921, 26.18540955], [77.0846405, 26.18717003], [77.09168243, 26.19087982], [77.09644318, 26.19544029], [77.09822083, 26.20225906], [77.10508728, 26.2091198], [77.10587311, 26.21936035], [77.10938263, 26.22507286], [77.11364746, 26.23135948], [77.12403107, 26.23795128], [77.12954712, 26.23965073], [77.1432724, 26.2382412], [77.15276337, 26.23795128], [77.15804291, 26.23852921], [77.16130066, 26.24222946], [77.16493988, 26.24450111], [77.17022705, 26.24451065], [77.17753601, 26.2390995], [77.18453217, 26.23682022], [77.19447327, 26.23597145], [77.20310974, 26.23740005], [77.20838928, 26.24423981], [77.23784637, 26.26272011], [77.25144958, 26.26703072], [77.26703644, 26.27617073], [77.28994751, 26.29559135], [77.3081665, 26.31500053], [77.30847931, 26.32155991], [77.31179047, 26.33382988], [77.31804657, 26.34638023], [77.32405853, 26.34810257], [77.32704163, 26.34724045], [77.32937622, 26.34810257], [77.33467102, 26.35723114], [77.3466568, 26.36038017], [77.36025238, 26.36952019], [77.36624908, 26.37151909], [77.37889862, 26.3638382], [77.38288879, 26.36240959], [77.38585663, 26.36242294], [77.39451599, 26.36670113], [77.40184021, 26.3686924], [77.40782166, 26.36898041], [77.41546631, 26.36811829], [77.43242645, 26.36499977], [77.43676758, 26.36814117], [77.43942261, 26.37298965], [77.43972778, 26.37869072], [77.43373871, 26.38753128], [77.42640686, 26.39550972], [77.42542267, 26.40205956], [77.42771912, 26.40690994], [77.43405151, 26.40920067], [77.45899963, 26.41119957], [77.47496796, 26.41463089], [77.493927, 26.41357994], [77.50591278, 26.41291046], [77.52288055, 26.41491127], [77.52986908, 26.41804123], [77.53717804, 26.4234581], [77.54250336, 26.42945099], [77.54715729, 26.4362812], [77.55148315, 26.44055939], [77.55914307, 26.44083977], [77.56912994, 26.44310951], [77.57910156, 26.45108986], [77.59908295, 26.45422173], [77.60874176, 26.45934105], [77.61538696, 26.46646118], [77.61673737, 26.47187042], [77.62007141, 26.47700119], [77.62671661, 26.48299026], [77.63938141, 26.48924065], [77.64636993, 26.49379921], [77.65470123, 26.49722099], [77.66768646, 26.50831032], [77.67102814, 26.50972939], [77.67800903, 26.5054512], [77.68598938, 26.50259018], [77.69503021, 26.50086975], [77.71398163, 26.50424957], [77.72099304, 26.50852013], [77.72698212, 26.51536179], [77.73066711, 26.52988052], [77.73935699, 26.54269028], [77.74434662, 26.54524994], [77.75, 26.54667091], [77.75801849, 26.55064964], [77.76700592, 26.55347824], [77.78299713, 26.55258942], [77.7976532, 26.55027962], [77.80430603, 26.55140114], [77.81299591, 26.55480957], [77.81765747, 26.56021118], [77.82467651, 26.57274055], [77.8243866, 26.58443069], [77.81842041, 26.59385109], [77.82041168, 26.59983826], [77.82543182, 26.60524178], [77.83409882, 26.61178017], [77.84243774, 26.61517906], [77.85144043, 26.61601067], [77.87037659, 26.61861992], [77.8793869, 26.62029076], [77.88877869, 26.63281059], [77.89015198, 26.64051819], [77.89087677, 26.65450287], [77.89457703, 26.66221046], [77.9036026, 26.66617966], [77.92391205, 26.66499138], [77.93990326, 26.66270828], [77.94789124, 26.66504097], [77.95355988, 26.66942024], [77.96053314, 26.67152977], [77.96879578, 26.67663956], [77.97572327, 26.68330193], [77.98855591, 26.69999123], [77.99221802, 26.70264053], [78.01190186, 26.70014763], [78.01920319, 26.69762039], [78.03156281, 26.69133949], [78.04312134, 26.69106293], [78.04911041, 26.68980026], [78.05622101, 26.68589973], [78.06092834, 26.68184853], [78.06511688, 26.67964172], [78.06938934, 26.67851067], [78.07537079, 26.67819023], [78.07863617, 26.68032074], [78.08573914, 26.68305016], [78.08805847, 26.68666077], [78.08898926, 26.70072174], [78.0865097, 26.72445107], [78.08676147, 26.73176956], [78.08914948, 26.73810959], [78.09600067, 26.74376106], [78.11167908, 26.74965096], [78.11605835, 26.7546196], [78.11482239, 26.75881195], [78.11104584, 26.76214027], [78.10051727, 26.76637077], [78.09709167, 26.76942062], [78.09568024, 26.77179909], [78.09442139, 26.7834301], [78.09538269, 26.78943062], [78.09983063, 26.79700851], [78.10552216, 26.80075264], [78.1129303, 26.80256081], [78.11902618, 26.80256081], [78.13131714, 26.79916954], [78.14048004, 26.79364014], [78.14581299, 26.79173088], [78.15978241, 26.79112053], [78.17611694, 26.79149246], [78.17975616, 26.79356956], [78.18044281, 26.79704094], [78.17936707, 26.80116081], [78.16340637, 26.81993103], [78.16094971, 26.82703972], [78.16355133, 26.82985115], [78.16757202, 26.83195114], [78.17327881, 26.83257103], [78.1795578, 26.83102036], [78.19210052, 26.8298111], [78.20278931, 26.83231926], [78.20979309, 26.83609009], [78.21700287, 26.83767128], [78.22299194, 26.8372097], [78.23680115, 26.83169937], [78.24754333, 26.82387924], [78.2556076, 26.82028961], [78.26088715, 26.82094955], [78.26531219, 26.82467079], [78.26677704, 26.8328228], [78.2664566, 26.8409996], [78.26779175, 26.84966087], [78.27075195, 26.85559082], [78.27623749, 26.86048126], [78.28206635, 26.86408806], [78.29470062, 26.86828995], [78.30200958, 26.86911964], [78.315979, 26.86936188], [78.32375336, 26.8686409], [78.34120178, 26.87395096], [78.35135651, 26.87437057], [78.36250305, 26.87133026], [78.36464691, 26.86884117], [78.36688232, 26.8625927], [78.37010956, 26.85758972], [78.37480927, 26.84683037], [78.38065338, 26.83609009], [78.38559723, 26.82793999], [78.38973999, 26.82489967], [78.40032196, 26.82600975], [78.41337585, 26.83043098], [78.4258728, 26.83231926], [78.430336, 26.82887268], [78.43427277, 26.82411194], [78.44557953, 26.80343056], [78.45078278, 26.79805183], [78.45813751, 26.79523277], [78.46631622, 26.79341125], [78.47632599, 26.79225159], [78.49199677, 26.78795052], [78.51557159, 26.78511047], [78.52632904, 26.77853966], [78.53427124, 26.77200127], [78.53504944, 26.77166176], [78.55490112, 26.76482964], [78.56009674, 26.76221275], [78.5658493, 26.75769043], [78.57521057, 26.75599289], [78.60196686, 26.75605965], [78.60646057, 26.75752068], [78.60938263, 26.76102066], [78.61178589, 26.76711273], [78.61569214, 26.77190018], [78.62043762, 26.77519989], [78.62857056, 26.77539063], [78.65036774, 26.76972961], [78.65901947, 26.76922989], [78.66750336, 26.77424049], [78.67282867, 26.78774834], [78.67736053, 26.79238129], [78.6834259, 26.79461288], [78.69007111, 26.79602814], [78.71534729, 26.80021286], [78.72142792, 26.79771042], [78.72033691, 26.79274178], [78.7178421, 26.78717995], [78.71837616, 26.78170013], [78.72293854, 26.77934265], [78.72586823, 26.77962112], [78.73145294, 26.78310966], [78.73596954, 26.78898048], [78.74108124, 26.79252052], [78.74479675, 26.78940964], [78.74904633, 26.78440094], [78.75447845, 26.77571106], [78.762146, 26.76683044], [78.76638031, 26.76453972], [78.77070618, 26.76419067], [78.77414703, 26.76606941], [78.79868317, 26.76911163], [78.80610657, 26.7687912], [78.81138611, 26.7654705], [78.84068298, 26.7260704], [78.85114288, 26.71642113], [78.85431671, 26.71232033], [78.8649292, 26.70466995], [78.87123871, 26.70360947], [78.87708282, 26.7035408], [78.88288879, 26.70440102], [78.90394592, 26.71338081], [78.90792084, 26.71294022], [78.91278839, 26.71038055], [78.93076324, 26.70426941], [78.94814301, 26.6967411], [78.95015717, 26.6940403], [78.94991302, 26.69194031], [78.93698883, 26.67228127], [78.93579102, 26.6679306], [78.9360733, 26.66488075], [78.93791199, 26.66269112], [78.9437027, 26.6610508], [78.94789124, 26.66262817], [78.96393585, 26.67651749], [78.9696579, 26.6805706], [78.97387695, 26.68254089], [78.98388672, 26.68571091], [78.98728943, 26.68604088], [78.99124908, 26.68444061], [78.99317932, 26.68457031], [78.99732208, 26.68099022], [79.00041199, 26.67671013], [79.0011673, 26.6739006], [78.99814606, 26.66662025], [78.99572754, 26.66356277], [78.9912796, 26.65456963], [78.98899078, 26.65142059], [78.98686981, 26.64736748], [78.98722076, 26.6441803], [78.99130249, 26.64143944], [78.99530029, 26.63596916], [79.00084686, 26.63041115], [79.0030899, 26.62665939], [79.00311279, 26.61923027], [79.00520325, 26.61413765], [79.00566101, 26.61046982], [79.00372314, 26.60637093], [78.99133301, 26.60464096], [78.9821167, 26.59417915], [78.97802734, 26.59243011], [78.98100281, 26.58600807], [78.97952271, 26.58156967], [78.97962189, 26.57407951], [78.99134064, 26.58230972], [78.9935379, 26.5788002], [78.99820709, 26.57422256], [78.99785614, 26.57215118], [78.99912262, 26.5667305], [78.99797058, 26.56401062], [79.00437927, 26.55862045], [79.00673676, 26.55780029], [79.00518799, 26.55623055], [78.99768829, 26.55586052], [78.99575043, 26.55411148], [78.99798584, 26.55093956], [79.00284576, 26.54993057], [79.00598907, 26.55142021], [79.00804138, 26.54778099], [79.01278687, 26.54871941], [79.01724243, 26.55212975], [79.02054596, 26.55166054], [79.01863098, 26.5433197], [79.01963043, 26.54144096], [79.03309631, 26.53598976], [79.03366852, 26.53341103], [79.03129578, 26.52477074], [79.03325653, 26.52262115], [79.03946686, 26.5233593], [79.04102325, 26.52276039], [79.03959656, 26.5196991], [79.03930664, 26.5157299], [79.04374695, 26.51046944], [79.04975128, 26.50666046], [79.04971313, 26.50276947], [79.05088043, 26.50077057], [79.05335999, 26.50121117], [79.0565567, 26.50316048], [79.06093597, 26.50329971], [79.06114197, 26.49095917], [79.06230927, 26.48987961], [79.06433868, 26.4868412], [79.0634613, 26.48476028], [79.04707336, 26.46142006], [79.04676056, 26.45786095], [79.04846191, 26.45605087], [79.05323029, 26.45561028], [79.05748749, 26.45614052], [79.05802917, 26.45128059], [79.06062317, 26.45182991], [79.06130219, 26.44943047], [79.06355286, 26.44895935], [79.06684875, 26.44940948], [79.06710052, 26.44700813], [79.06906891, 26.44651985], [79.07279205, 26.44779015], [79.07417297, 26.44556808], [79.07769775, 26.44723129], [79.08094025, 26.44390106], [79.08304596, 26.44973946], [79.08274841, 26.45231056], [79.08329773, 26.4530201], [79.08943176, 26.45092964], [79.09113312, 26.45240021], [79.09118652, 26.45527077], [79.09287262, 26.45730019], [79.0949173, 26.45709991], [79.09989166, 26.45602989], [79.10515594, 26.45360184], [79.11030579, 26.45301056], [79.12098694, 26.44789124], [79.12400818, 26.4455204], [79.12676239, 26.44481087], [79.12328339, 26.4406395], [79.11911011, 26.4328804], [79.11682129, 26.42421913], [79.11723328, 26.41712189], [79.11489868, 26.41558838], [79.10067749, 26.41173172], [79.09703827, 26.41259956], [79.09268951, 26.41614914], [79.09192657, 26.41674042], [79.08682251, 26.41782188], [79.08072662, 26.40550041], [79.08699799, 26.39108276], [79.08959198, 26.38820076], [79.08849335, 26.38313293], [79.09047699, 26.37939072], [79.08911896, 26.37713051], [79.07924652, 26.37288094], [79.07675934, 26.3660202], [79.07679749, 26.36269188], [79.08421326, 26.3597126], [79.08857727, 26.3599205], [79.0930481, 26.36013985], [79.0951767, 26.35981941], [79.09673309, 26.35956955], [79.09644318, 26.35560989], [79.10038757, 26.35509109], [79.10340118, 26.35951042], [79.10526276, 26.35598946], [79.10858154, 26.35449028], [79.11662292, 26.35357285], [79.11952209, 26.35103989], [79.12320709, 26.34473038], [79.13137817, 26.34589958], [79.13374329, 26.3449707], [79.13257599, 26.34276009], [79.12680054, 26.33992004], [79.12499237, 26.33793068], [79.12731171, 26.33349037], [79.12703705, 26.33165932], [79.12586212, 26.33143806], [79.12423706, 26.33114052], [79.11564636, 26.33509064], [79.11569214, 26.33130074], [79.11573029, 26.32849121], [79.11798859, 26.32634163], [79.12724304, 26.32138062], [79.12658691, 26.3160305], [79.11911774, 26.31492805], [79.11457825, 26.31314087], [79.10875702, 26.30862045], [79.10154724, 26.3138504], [79.09797668, 26.31464958], [79.09384918, 26.31194115], [79.09147644, 26.30845261], [79.09178925, 26.30404282], [79.08769226, 26.2990303], [79.083992, 26.29708099], [79.08309937, 26.29389954], [79.08635712, 26.28367043], [79.08357239, 26.27240944], [79.07964325, 26.27260971], [79.07720184, 26.27359962], [79.07610321, 26.27519035], [79.07657623, 26.27882195], [79.07872772, 26.28034019], [79.0786972, 26.28448105], [79.07769012, 26.28721809], [79.07553101, 26.28713036], [79.07206726, 26.28523064], [79.06865692, 26.28777122], [79.06726837, 26.28762054], [79.0640564, 26.28263092], [79.05789185, 26.28380013], [79.05327606, 26.27960014], [79.04679871, 26.27059174], [79.04853058, 26.26597023], [79.04677582, 26.26531982], [79.03703308, 26.26699066], [79.03793335, 26.26287079], [79.04219818, 26.25996017], [79.04535675, 26.26029968], [79.04692078, 26.25539017], [79.04892731, 26.25369072], [79.05191803, 26.25324059], [79.05551147, 26.25415039], [79.05844116, 26.25391006], [79.06266785, 26.24693108], [79.06112671, 26.24369049], [79.05652618, 26.24188995], [79.05555725, 26.23964119], [79.05705261, 26.23289108], [79.05526733, 26.23238945], [79.0521698, 26.23211288], [79.04603577, 26.23354912], [79.04055023, 26.22928047], [79.03425598, 26.23154068], [79.02960968, 26.23207092], [79.02684784, 26.23336029], [79.02466583, 26.23425293], [79.02039337, 26.23425293], [79.01714325, 26.2321682], [79.01690674, 26.22800064], [79.01761627, 26.22340012], [79.01729584, 26.22369194], [79.01872253, 26.21582985], [79.01819611, 26.2125206], [79.02070618, 26.20967293], [79.02062225, 26.20857048], [79.00990295, 26.2049408], [79.01039124, 26.20277977], [79.01257324, 26.20140076], [79.01502991, 26.19815063], [79.01494598, 26.19746971], [79.0129776, 26.19686127], [79.00232697, 26.19676971], [78.99655151, 26.19898033], [78.9944458, 26.2004509], [78.99175262, 26.20396805], [78.98403931, 26.20067024], [78.98091888, 26.19841003], [78.97737885, 26.19549942], [78.97574615, 26.19281006], [78.99178314, 26.17728043], [78.99598694, 26.17551041], [79.00340271, 26.17295837], [79.002388, 26.16472816], [79.00092316, 26.16026115], [79.00071716, 26.15497971], [78.99459839, 26.15278053], [78.99179077, 26.15205956], [78.98966217, 26.15070915], [78.98623657, 26.1505394], [78.97064209, 26.15540123], [78.96533966, 26.15578079], [78.96032715, 26.15427017], [78.95230103, 26.14260101], [78.94576263, 26.14106178], [78.94267273, 26.13914108], [78.94438934, 26.13751984], [78.95464325, 26.13286018], [78.95810699, 26.12990952], [78.96652985, 26.12565041], [78.96922302, 26.1234417], [78.97049713, 26.12028122], [78.96977997, 26.11230087], [78.9718399, 26.1086998], [78.99011993, 26.09589958], [78.99185181, 26.09526062], [79.00049591, 26.09671021], [79.00350952, 26.09431076], [79.00437927, 26.09008026], [79.00219727, 26.08660126], [79.00315094, 26.08179283], [79.00113678, 26.0783596], [78.99915314, 26.07709122], [78.99711609, 26.07393074], [78.99188232, 26.07464027], [78.98602295, 26.07608032], [78.98248291, 26.07375908], [78.9786911, 26.0646801], [78.97579956, 26.05988121], [78.9681778, 26.05916023], [78.96144867, 26.0508194], [78.95266724, 26.04203033], [78.94863129, 26.03881264], [78.94432831, 26.03695107], [78.94618988, 26.03107262], [78.95050049, 26.02582169], [78.95040131, 26.01986122], [78.94534302, 26.01390076], [78.94441986, 26.00889015], [78.94613647, 26.00616074], [78.94658661, 26.00506973], [78.94610596, 26.00155067], [78.94330597, 25.99822807], [78.9438858, 25.99324036], [78.94316864, 25.99069023], [78.93947601, 25.98637009], [78.93621826, 25.98531914], [78.93102264, 25.98553085], [78.92720032, 25.98651123], [78.92459106, 25.98431015], [78.92362213, 25.9808712], [78.9261322, 25.97776985], [78.93113708, 25.97631073], [78.92951965, 25.9716301], [78.92547607, 25.96541977], [78.92582703, 25.95889282], [78.92742157, 25.95549965], [78.93009949, 25.95158005], [78.92952728, 25.94935989], [78.92735291, 25.94832039], [78.92484283, 25.9487114], [78.92215729, 25.95012093], [78.92112732, 25.95084763], [78.92384338, 25.95275116], [78.91532898, 25.94936943], [78.90978241, 25.94608116], [78.90394592, 25.94110107], [78.90125275, 25.9375], [78.89808655, 25.93087006], [78.89427185, 25.92585182], [78.87638092, 25.91566086], [78.8768692, 25.91448021], [78.87741852, 25.91316986], [78.88034821, 25.90955162], [78.8829422, 25.90635109], [78.88719177, 25.89897156], [78.88511658, 25.89286041], [78.88134003, 25.8884201], [78.88371277, 25.87647057], [78.88345337, 25.87491989], [78.8826828, 25.87026978], [78.87689209, 25.8698597], [78.87268829, 25.87302017], [78.86798096, 25.87498093], [78.86606598, 25.87485123], [78.86358643, 25.87467194], [78.86071777, 25.87332916], [78.85782623, 25.87201118], [78.85051727, 25.86561012], [78.84662628, 25.86050034], [78.84397888, 25.84531021], [78.84622192, 25.83876038], [78.85293579, 25.84361076], [78.86575317, 25.83435059], [78.86646271, 25.8296299], [78.86396027, 25.81627083], [78.8633194, 25.80208015], [78.86192322, 25.79919815], [78.8559494, 25.79443932], [78.8496933, 25.79586029], [78.8436203, 25.80130959], [78.84129333, 25.80520058], [78.84073639, 25.81208038], [78.84179688, 25.81680107], [78.84098053, 25.82064056], [78.83512878, 25.82409286], [78.81582642, 25.83114052], [78.81124878, 25.83012009], [78.80198669, 25.82220078], [78.79885864, 25.8182106], [78.80046082, 25.81287956], [78.80401611, 25.81022072], [78.80766296, 25.81151962], [78.813797, 25.81681061], [78.81623077, 25.81758118], [78.82227325, 25.81522751], [78.82363892, 25.81236076], [78.82376862, 25.81082153], [78.82408142, 25.80760956], [78.82050323, 25.79940033], [78.8167572, 25.7992897], [78.81169891, 25.79914093], [78.80497742, 25.80019188], [78.80413055, 25.80033112], [78.79955292, 25.79936028], [78.79606628, 25.79593086], [78.79360199, 25.7935009], [78.79062653, 25.7882309], [78.77996826, 25.77511978], [78.77578735, 25.7614994], [78.76582336, 25.75891113], [78.76241302, 25.75226021], [78.75567627, 25.75299072], [78.75128174, 25.75270081], [78.74681854, 25.74909019], [78.74550629, 25.74411964], [78.7457962, 25.73801994], [78.74803925, 25.73265076], [78.75240326, 25.72741127], [78.76074982, 25.72079086], [78.77752686, 25.71370125], [78.79123688, 25.71054077], [78.79255676, 25.70717049], [78.79070282, 25.70285034], [78.78940582, 25.69983101], [78.79576111, 25.69614029], [78.80938721, 25.67807007], [78.8113327, 25.67448044], [78.81060791, 25.66506195], [78.81124878, 25.64545059], [78.80979156, 25.63836098], [78.806427, 25.63302994], [78.80519104, 25.6245575], [78.79815674, 25.61922073], [78.79454803, 25.6175499], [78.78485107, 25.61548996], [78.76597595, 25.61314964], [78.75541687, 25.60959053], [78.7489624, 25.60834122], [78.74095154, 25.60387993], [78.73284149, 25.60305977], [78.72431946, 25.60844994], [78.71116638, 25.60659027], [78.70658875, 25.60327911], [78.7003479, 25.60131073], [78.69570923, 25.59984016], [78.68798828, 25.59515953], [78.67701721, 25.59410095], [78.672966, 25.59180069], [78.66535187, 25.58484077], [78.64862061, 25.5656395], [78.64434052, 25.56541824], [78.62883759, 25.56900024], [78.62341309, 25.57100105], [78.62020874, 25.57356071], [78.62133026, 25.58218002], [78.6181488, 25.58699036], [78.60862732, 25.58908081], [78.60573578, 25.58887291], [78.6042099, 25.58728981], [78.60015106, 25.57835007], [78.59799194, 25.57561111], [78.59525299, 25.57493019], [78.59027863, 25.57522011], [78.58706665, 25.57294083], [78.583992, 25.56554985], [78.58119202, 25.56430817], [78.57608032, 25.56528854], [78.57096863, 25.56735992], [78.56548309, 25.56787109], [78.55974579, 25.56780052], [78.54714966, 25.56470108], [78.54178619, 25.56513977], [78.53604889, 25.56686974], [78.53240204, 25.57028961], [78.52751923, 25.57292938], [78.51143646, 25.57296181], [78.49149323, 25.58188057], [78.48626709, 25.58222961], [78.48108673, 25.58043289], [78.46894073, 25.57298088], [78.46212006, 25.56747055], [78.46003723, 25.56455994], [78.45733643, 25.55540085], [78.45519257, 25.55195045], [78.44915009, 25.5527401], [78.44496918, 25.55499077], [78.44303894, 25.5570507], [78.43974304, 25.55895996], [78.43707275, 25.56435013], [78.43353271, 25.56524086], [78.42933655, 25.56385994], [78.4261322, 25.56145096], [78.41230774, 25.54224968], [78.40997314, 25.53771973], [78.40866089, 25.53290176], [78.411026, 25.52738953], [78.41529846, 25.52139091], [78.41674805, 25.51777267], [78.41628265, 25.51573944], [78.41433716, 25.51531029], [78.41124725, 25.51902008], [78.40956879, 25.51864815], [78.408638, 25.50799942], [78.40940857, 25.50427055], [78.412323, 25.49766159], [78.41947937, 25.49054146], [78.42156982, 25.47970963], [78.42072296, 25.47761917], [78.41646576, 25.47750282], [78.40672302, 25.47921944], [78.40142822, 25.47297096], [78.3960495, 25.47177124], [78.39375305, 25.47125053], [78.39309692, 25.47042084], [78.39189911, 25.46884918], [78.38568878, 25.45416069], [78.38340759, 25.45193291], [78.38088989, 25.4504509], [78.37738037, 25.44837952], [78.37077332, 25.44717026], [78.36614227, 25.44631767], [78.36097717, 25.44660187], [78.35266876, 25.45531273], [78.34925842, 25.45579147], [78.34758759, 25.45483971], [78.34378815, 25.44617844], [78.33656311, 25.43498993], [78.33518982, 25.43105125], [78.33407593, 25.41815186], [78.33248901, 25.40455055], [78.33027649, 25.40099907], [78.32151031, 25.3952198], [78.31690979, 25.39090919], [78.31067657, 25.3850708], [78.30716705, 25.3841629], [78.30340576, 25.38479042], [78.29972076, 25.38375282], [78.29551697, 25.37479973], [78.2942276, 25.36762047], [78.2962265, 25.36499023], [78.30162048, 25.36437988], [78.31626892, 25.35961914], [78.32319641, 25.35526848], [78.32657623, 25.34902], [78.32756042, 25.34645081], [78.3312912, 25.33671951], [78.33078003, 25.33128929], [78.32782745, 25.32761002], [78.32710266, 25.32720947], [78.31543732, 25.32073021], [78.31057739, 25.31615829], [78.30802917, 25.31098938], [78.31163788, 25.3075695], [78.31645203, 25.30458069], [78.33007813, 25.30038071], [78.34130859, 25.29927063], [78.34516144, 25.29794121], [78.34506989, 25.28297043], [78.35526276, 25.2757206], [78.36222076, 25.26543045], [78.36029816, 25.25856972], [78.35521698, 25.24996948], [78.35453033, 25.2460804], [78.35708618, 25.24417114], [78.3645401, 25.24391174], [78.36888885, 25.24166107], [78.37075806, 25.23336029], [78.37516785, 25.22575188], [78.38108826, 25.2238102], [78.39215088, 25.22234917], [78.39553833, 25.22118187], [78.39775848, 25.21775055], [78.39450073, 25.21463966], [78.38577271, 25.20868111], [78.38394928, 25.20600128], [78.3838501, 25.20486069], [78.3835907, 25.20195007], [78.38427734, 25.19933128], [78.38536072, 25.19515991], [78.38889313, 25.1928196], [78.3913269, 25.19120026], [78.40355682, 25.18894005], [78.40725708, 25.1857605], [78.4090271, 25.18202972], [78.41726685, 25.17278099], [78.42823029, 25.16964149], [78.435112, 25.17036057], [78.43746185, 25.17140961], [78.43913269, 25.17214966], [78.44394684, 25.17255974], [78.44645691, 25.16902161], [78.44631195, 25.1667099], [78.44284821, 25.15788078], [78.44198608, 25.15735054], [78.42870331, 25.15833092], [78.42089844, 25.15764046], [78.41829681, 25.1534996], [78.41882324, 25.15109062], [78.42294312, 25.14537048], [78.43235779, 25.13754082], [78.44291687, 25.12877083], [78.43097687, 25.1244812], [78.42468262, 25.12469101], [78.41765594, 25.12697029], [78.41072845, 25.1292305], [78.40226746, 25.13097], [78.39531708, 25.1305275], [78.38968658, 25.12699127], [78.37869263, 25.11269951], [78.37441254, 25.10853958], [78.36699677, 25.1045208], [78.35784149, 25.10235023], [78.34781647, 25.09996986], [78.33265686, 25.09324265], [78.33090973, 25.09163094], [78.32776642, 25.08876991], [78.32675934, 25.08688164], [78.32524872, 25.08406067], [78.32498932, 25.07249832], [78.32717896, 25.06791115], [78.33078003, 25.0453701], [78.3380661, 25.02733994], [78.33751678, 25.0207901], [78.33460999, 25.01073837], [78.33020782, 25.00374031], [78.32753754, 24.9995594], [78.30961609, 24.99124908], [78.3066864, 24.98899269], [78.30256653, 24.98397064], [78.28959656, 24.96813965], [78.2822876, 24.96320915], [78.26271057, 24.95260048], [78.25991821, 24.94924927], [78.25604248, 24.94203949], [78.25244904, 24.93950081], [78.24936676, 24.93848038], [78.22878265, 24.9240799], [78.21391296, 24.91557121], [78.21070862, 24.91234016], [78.2039566, 24.90050125], [78.19973755, 24.8962307], [78.18917084, 24.89280128], [78.17704773, 24.88733101], [78.1704483, 24.88526917], [78.1653595, 24.88174057], [78.16470337, 24.87829971], [78.16332245, 24.87099266], [78.16355133, 24.8642807], [78.1638031, 24.85709953], [78.16532898, 24.84817123], [78.1700058, 24.84647942], [78.17357635, 24.8461895], [78.18689728, 24.84280968], [78.19158173, 24.83967018], [78.19403076, 24.83156013], [78.19587708, 24.82859039], [78.20896912, 24.8130703], [78.21836853, 24.79191971], [78.22387695, 24.78300095], [78.22582245, 24.77657127], [78.22518921, 24.76639175], [78.22428894, 24.76403046], [78.21987152, 24.75819016], [78.21888733, 24.75379944], [78.22039032, 24.74736977], [78.22631836, 24.73624992], [78.23654938, 24.72463989], [78.25078583, 24.70557022], [78.25280762, 24.70094109], [78.25460815, 24.69248962], [78.25699615, 24.68593025], [78.26799774, 24.66959953], [78.26847839, 24.66710091], [78.26789856, 24.66352081], [78.25834656, 24.65283966], [78.25669098, 24.64862061], [78.25847626, 24.63780022], [78.26339722, 24.62812042], [78.26753235, 24.62191963], [78.26985168, 24.61538124], [78.26940155, 24.60502052], [78.26808167, 24.59697914], [78.2637558, 24.57872009], [78.26035309, 24.56923294], [78.25888824, 24.55818939], [78.25531769, 24.5522995], [78.24610901, 24.5486908], [78.23654938, 24.5463295], [78.22418213, 24.54133987], [78.21839905, 24.53569031], [78.21653748, 24.53164291], [78.21971893, 24.52277946], [78.2281723, 24.51645279], [78.23806, 24.5116806], [78.24017334, 24.50958061], [78.24150848, 24.50484276], [78.23768616, 24.49617958], [78.23789978, 24.49358177], [78.23963165, 24.48945999], [78.24621582, 24.48671913], [78.2545929, 24.4858284], [78.263237, 24.48308182], [78.26682281, 24.47999954], [78.2696228, 24.47618294], [78.26966095, 24.47310829], [78.26030731, 24.46001053], [78.26074982, 24.45393944], [78.26687622, 24.44737053], [78.28121185, 24.43721008], [78.28985596, 24.43312073], [78.29985046, 24.42654991], [78.31150055, 24.41744041], [78.31520081, 24.41284943], [78.31830597, 24.4103508], [78.33244324, 24.40597153], [78.33673096, 24.40386963], [78.3449173, 24.39204025], [78.35040283, 24.38953018], [78.3588562, 24.38718987], [78.36094666, 24.38578987], [78.36292267, 24.38161087], [78.36257172, 24.37815094], [78.34651947, 24.36269951], [78.34092712, 24.35242081], [78.33544922, 24.3450985], [78.33112335, 24.34255028], [78.32657623, 24.33846855], [78.32543182, 24.33436966], [78.3259964, 24.32961845], [78.32852173, 24.32550049], [78.33181, 24.32249069], [78.33551788, 24.31917953], [78.33943176, 24.31735992], [78.34130859, 24.31151962], [78.34140015, 24.30780983], [78.34243774, 24.30538177], [78.34453583, 24.30328941], [78.35141754, 24.29927063], [78.36168671, 24.29610062], [78.3639679, 24.29235077], [78.36624908, 24.29030991], [78.36989594, 24.28908157], [78.3730011, 24.28635979], [78.37742615, 24.27806091], [78.37963867, 24.27556038], [78.38237, 24.2739296], [78.38566589, 24.27305031], [78.39296722, 24.2747612], [78.40326691, 24.27547264], [78.4069519, 24.27700996], [78.41130829, 24.28758049], [78.41448975, 24.28884125], [78.41861725, 24.28946114], [78.42315674, 24.28915024], [78.42648315, 24.29018021], [78.43477631, 24.29766083], [78.43332672, 24.30900955], [78.4335022, 24.31340981], [78.44029236, 24.32553101], [78.45082855, 24.32987976], [78.45459747, 24.33322144], [78.45892334, 24.33568954], [78.46779633, 24.33934021], [78.47077179, 24.34338188], [78.47167969, 24.35709], [78.47280121, 24.36235046], [78.47532654, 24.36742973], [78.48430634, 24.37762833], [78.48977661, 24.38605118], [78.49819183, 24.3927803], [78.49993896, 24.39433098], [78.50537109, 24.39394951], [78.51455688, 24.39055824], [78.51922607, 24.38735008], [78.52207184, 24.38414955], [78.52511597, 24.37713814], [78.52762604, 24.37447166], [78.55258179, 24.36062813], [78.5568924, 24.3611908], [78.56265259, 24.35935974], [78.56651306, 24.35732079], [78.57489777, 24.3593502], [78.57843781, 24.35708046], [78.57888031, 24.35396194], [78.58071899, 24.34983063], [78.58470154, 24.3434391], [78.58777618, 24.34135056], [78.59364319, 24.33936119], [78.59900665, 24.32318115], [78.6020813, 24.31830025], [78.6047821, 24.31574059], [78.61492157, 24.31257248], [78.61962891, 24.31184006], [78.62281036, 24.30985069], [78.62351227, 24.30690193], [78.61788177, 24.2992897], [78.61734009, 24.2961216], [78.61940002, 24.28944969], [78.62171936, 24.2862606], [78.62602234, 24.28646278], [78.6313858, 24.29018974], [78.6341629, 24.28936958], [78.63923645, 24.28619957], [78.64363861, 24.28149986], [78.65444946, 24.27374077], [78.65779877, 24.26805115], [78.66316223, 24.25263023], [78.66535187, 24.24844933], [78.66912079, 24.24501991], [78.67311096, 24.24435043], [78.67809296, 24.24489975], [78.68113708, 24.24407005], [78.69258118, 24.23701096], [78.69886017, 24.2344799], [78.7071228, 24.23876953], [78.71111298, 24.23944092], [78.71858215, 24.239151], [78.72110748, 24.24122047], [78.72653961, 24.25270081], [78.73221588, 24.25382042], [78.73526001, 24.25177956], [78.73610687, 24.24510956], [78.73751831, 24.24210167], [78.74085236, 24.24016953], [78.74371338, 24.23945045], [78.74588776, 24.23927116], [78.74977112, 24.24073982], [78.75255585, 24.24367905], [78.75428772, 24.2472496], [78.75668335, 24.25972939], [78.76027679, 24.25848961], [78.76642609, 24.25057983], [78.7607193, 24.2390995], [78.76000977, 24.23651123], [78.76053619, 24.23385048], [78.76774597, 24.21777916], [78.76983643, 24.215271], [78.77488708, 24.21228981], [78.77625275, 24.21002007], [78.77831268, 24.2010498], [78.78205872, 24.19152069], [78.7845993, 24.18514061], [78.78848267, 24.18135834], [78.79168701, 24.18024063], [78.80224609, 24.18190002], [78.80570984, 24.18429947], [78.80795288, 24.19331932], [78.80908203, 24.20465088], [78.8105011, 24.20852089], [78.81352234, 24.21027946], [78.81638336, 24.20865059], [78.81886292, 24.20243835], [78.82007599, 24.20121956], [78.8242569, 24.20129967], [78.82772064, 24.20318985], [78.83277893, 24.20928192], [78.83876801, 24.21467972], [78.84654236, 24.21693039], [78.8582077, 24.21354103], [78.86283112, 24.21404076], [78.87368011, 24.2189312], [78.87886047, 24.22305107], [78.88105011, 24.22888947], [78.87982178, 24.24411964], [78.87827301, 24.24868965], [78.87909698, 24.25401115], [78.88558197, 24.25928116], [78.90985107, 24.27292061], [78.91172028, 24.2765007], [78.91322327, 24.28590965], [78.91284943, 24.28944969], [78.9077301, 24.29487038], [78.9070816, 24.29643059], [78.90776062, 24.30123138], [78.9241333, 24.31421852], [78.92874146, 24.31620979], [78.93245697, 24.31888962], [78.94536591, 24.33130074], [78.95088959, 24.34041023], [78.95493317, 24.34392929], [78.96099091, 24.34716988], [78.9648819, 24.35044289], [78.96687317, 24.35366058], [78.96813965, 24.35695076], [78.96833801, 24.36024284], [78.96692657, 24.37034988], [78.96717072, 24.37358284], [78.97097778, 24.38472939], [78.97422028, 24.39863968], [78.97621155, 24.40289116], [78.98087311, 24.41782951], [78.9868927, 24.42324066], [78.98777771, 24.42797089], [78.98651123, 24.43403053], [78.98438263, 24.44136047], [78.981987, 24.44724083], [78.97183228, 24.44473267], [78.96203613, 24.44407082], [78.95552826, 24.44512749], [78.94713593, 24.44313049], [78.94439697, 24.44325829], [78.94065857, 24.44598007], [78.93107605, 24.4599781], [78.92724609, 24.4621315], [78.91279602, 24.46351051], [78.90859222, 24.46677017], [78.9026413, 24.47837067], [78.90088654, 24.48357964], [78.90093994, 24.4883709], [78.90808105, 24.49316025], [78.91381073, 24.50084114], [78.91757965, 24.50251007], [78.92182922, 24.50107956], [78.92436218, 24.49908066], [78.92607117, 24.49638748], [78.92569733, 24.49183083], [78.92334747, 24.48839951], [78.92517853, 24.48599052], [78.93071747, 24.48454094], [78.94313812, 24.48488045], [78.94856262, 24.4861927], [78.95455933, 24.48855972], [78.96391296, 24.49378014], [78.96639252, 24.49694824], [78.96549225, 24.50028038], [78.96340942, 24.50204086], [78.95018768, 24.50447845], [78.94708252, 24.50598907], [78.94416809, 24.50950813], [78.943367, 24.51662064], [78.94477081, 24.52363014], [78.94393921, 24.52664757], [78.94042206, 24.53120995], [78.94001007, 24.53408051], [78.94036865, 24.54314995], [78.94550323, 24.55331039], [78.94465637, 24.55620956], [78.94299316, 24.55787849], [78.93038177, 24.56439018], [78.91314697, 24.58130074], [78.90850067, 24.58880997], [78.90561676, 24.602211], [78.90438843, 24.60430908], [78.89295197, 24.6138382], [78.89186859, 24.61680031], [78.89144135, 24.62207031], [78.8817215, 24.63969994], [78.87306976, 24.64694977], [78.866539, 24.64549255], [78.86280823, 24.64112091], [78.85919189, 24.62817955], [78.85579681, 24.62298965], [78.85240173, 24.62094116], [78.84916687, 24.62166023], [78.84436798, 24.62899017], [78.83905792, 24.6282196], [78.83599854, 24.62557983], [78.83345032, 24.62079048], [78.83084869, 24.60889053], [78.82878113, 24.60781097], [78.82039642, 24.6078701], [78.8140564, 24.60560036], [78.81112671, 24.60533905], [78.80667877, 24.6071701], [78.80182648, 24.60782814], [78.79788208, 24.60531998], [78.79382324, 24.59822845], [78.77690125, 24.59309006], [78.76661682, 24.59756279], [78.75199127, 24.60246277], [78.74946594, 24.60498047], [78.74803162, 24.61152077], [78.7485733, 24.62471008], [78.74797821, 24.63705063], [78.74635315, 24.64319038], [78.74208069, 24.65063095], [78.7405777, 24.65607071], [78.74006653, 24.65995979], [78.74427032, 24.66682053], [78.74487305, 24.66930962], [78.75498962, 24.67357063], [78.75753784, 24.67715073], [78.75878143, 24.68217087], [78.75998688, 24.69356918], [78.76534271, 24.69532967], [78.76760101, 24.69692993], [78.77239227, 24.70414162], [78.77297974, 24.70691109], [78.77308655, 24.71165085], [78.76980591, 24.71884918], [78.76912689, 24.72354126], [78.76748657, 24.74341011], [78.76895142, 24.75110054], [78.76862335, 24.7548008], [78.76319885, 24.76675987], [78.76454926, 24.79499245], [78.76722717, 24.79851151], [78.77781677, 24.80487251], [78.78011322, 24.80698967], [78.78109741, 24.81051064], [78.78054047, 24.81497192], [78.77256775, 24.83048058], [78.76888275, 24.84374809], [78.76740265, 24.84891129], [78.76716614, 24.85567093], [78.76448059, 24.86136818], [78.76135254, 24.86295128], [78.75343323, 24.86496925], [78.75061035, 24.86886024], [78.74668121, 24.87084961], [78.73838043, 24.86963081], [78.73441315, 24.87099266], [78.73163605, 24.87234116], [78.72254181, 24.88071823], [78.71887207, 24.88266182], [78.7128067, 24.88379097], [78.70289612, 24.88402748], [78.70056915, 24.88648033], [78.69634247, 24.89466095], [78.69171906, 24.89590073], [78.67965698, 24.89719009], [78.6754303, 24.8985405], [78.668396, 24.90239906], [78.66301727, 24.9092617], [78.65947723, 24.91752052], [78.65709686, 24.92506027], [78.65371704, 24.94421959], [78.6421814, 24.93976974], [78.64050293, 24.94036293], [78.6400528, 24.94532967], [78.64251709, 24.95029068], [78.64243317, 24.95265007], [78.62491608, 24.96194077], [78.62204742, 24.96490097], [78.62290192, 24.9677906], [78.63201904, 24.98372078], [78.63510895, 25.00432968], [78.6361618, 25.01089287], [78.6361618, 25.02136993], [78.6371994, 25.02555084], [78.64418793, 25.03524971], [78.64192963, 25.06149101], [78.63941193, 25.06637192], [78.6355896, 25.07101059], [78.63482666, 25.07419014], [78.62948608, 25.08242989], [78.6247406, 25.08641052], [78.62032318, 25.09159279], [78.61760712, 25.09271049], [78.60555267, 25.09422112], [78.59716797, 25.09787178], [78.59667969, 25.10345078], [78.59829712, 25.10808945], [78.59816742, 25.12708092], [78.59597778, 25.14858055], [78.59371185, 25.15739059], [78.56976318, 25.20195961], [78.56456757, 25.22096062], [78.56259155, 25.22602272], [78.56149292, 25.22744942], [78.56254578, 25.23867035], [78.5657959, 25.24945068], [78.56816864, 25.25405121], [78.56858063, 25.25860977], [78.56437683, 25.26521111], [78.55702209, 25.26932907], [78.55237579, 25.27087975], [78.54226685, 25.27203941], [78.53601837, 25.27194977], [78.52849579, 25.27450943], [78.52555847, 25.27817154], [78.52516937, 25.28549957], [78.52085114, 25.28803825], [78.50531769, 25.28154755], [78.50257874, 25.28342056], [78.50080872, 25.28824806], [78.49668121, 25.29385948], [78.48932648, 25.29208946], [78.4540329, 25.27060127], [78.44445038, 25.26995087], [78.43575287, 25.27324104], [78.42871094, 25.28083038], [78.42736053, 25.28867149], [78.4298172, 25.29701042], [78.43517303, 25.30252075], [78.44059753, 25.30416107], [78.44851685, 25.30328941], [78.45680237, 25.2993412], [78.45928955, 25.29665947], [78.46705627, 25.29301071], [78.46926117, 25.30332184], [78.47175598, 25.30583954], [78.47792053, 25.30869102], [78.48324585, 25.31418991], [78.4875412, 25.32019043], [78.49217224, 25.32382965], [78.49492645, 25.32069016], [78.49581146, 25.3101902], [78.50025177, 25.30413055], [78.50511169, 25.30211067], [78.51586151, 25.30433083], [78.51872253, 25.30581284], [78.52507782, 25.30653], [78.53098297, 25.31706047], [78.53356171, 25.31870079], [78.5389328, 25.32039261], [78.54083252, 25.3224411], [78.54145813, 25.32659912], [78.53768921, 25.32949829], [78.53359222, 25.33089256], [78.53150177, 25.33485031], [78.53069305, 25.33916855], [78.53108978, 25.34859085], [78.53044891, 25.35205078], [78.52480316, 25.35474968], [78.52336884, 25.3583107], [78.52514648, 25.36301231], [78.52806091, 25.36588097], [78.53505707, 25.36400986], [78.54473114, 25.3586998], [78.55602264, 25.34860992], [78.56204987, 25.34795189], [78.57621765, 25.35193062], [78.5789032, 25.35531807], [78.57950592, 25.36057091], [78.57775879, 25.37714005], [78.57440186, 25.38223076], [78.57034302, 25.38478279], [78.56463623, 25.38396072], [78.56009674, 25.38204956], [78.55690002, 25.38414955], [78.56112671, 25.39569283], [78.56344604, 25.39792061], [78.5686264, 25.39619064], [78.5761261, 25.39109039], [78.5789032, 25.39009094], [78.58409882, 25.3902607], [78.58834076, 25.39211273], [78.59163666, 25.39653969], [78.59461212, 25.40911293], [78.59895325, 25.41522026], [78.60349274, 25.41707039], [78.61435699, 25.41633034], [78.61692047, 25.41007042], [78.61921692, 25.40703964], [78.62362671, 25.4059906], [78.62858582, 25.40646172], [78.63379669, 25.4095211], [78.63680267, 25.41411018], [78.63749695, 25.41978836], [78.63250732, 25.4330101], [78.63365936, 25.43806076], [78.63883972, 25.44042969], [78.64541626, 25.43785095], [78.64901733, 25.44239235], [78.65271759, 25.44400024], [78.65796661, 25.44383049], [78.67041016, 25.43889046], [78.67488861, 25.43814087], [78.67751312, 25.43972969], [78.67893219, 25.44389915], [78.6816864, 25.44740105], [78.6857605, 25.44779015], [78.68924713, 25.44535065], [78.69332123, 25.43922043], [78.69983673, 25.43230057], [78.70140076, 25.42885971], [78.70024109, 25.42612076], [78.68448639, 25.41601181], [78.66909027, 25.40388107], [78.66493988, 25.40446091], [78.65930176, 25.4183712], [78.65651703, 25.42012978], [78.65367889, 25.41681099], [78.6520462, 25.41314125], [78.65666962, 25.4005394], [78.65688324, 25.39599037], [78.65592957, 25.39217186], [78.65789032, 25.38797951], [78.66117096, 25.38656044], [78.66493225, 25.38800049], [78.66940308, 25.39290047], [78.67376709, 25.39116096], [78.67352295, 25.38799095], [78.67156219, 25.38456154], [78.68386078, 25.38047981], [78.68717957, 25.3806324], [78.68914032, 25.3830204], [78.6905899, 25.38673973], [78.69275665, 25.38773918], [78.69610596, 25.38552856], [78.69711304, 25.38329124], [78.69982147, 25.38170052], [78.70903015, 25.37874985], [78.70976257, 25.37626839], [78.70455933, 25.36559105], [78.70361328, 25.36170006], [78.70384979, 25.3586483], [78.70944214, 25.35432053], [78.71362305, 25.3529892], [78.71794891, 25.35280991], [78.72112274, 25.3538208], [78.72524261, 25.35398293], [78.735672, 25.34919167], [78.74978638, 25.35211945], [78.75628662, 25.35750961], [78.76438141, 25.35840034], [78.76532745, 25.36044121], [78.76574707, 25.36477089], [78.76216125, 25.37437057], [78.76122284, 25.38216019], [78.75482178, 25.38619041], [78.75286102, 25.39034081], [78.75302887, 25.39195061], [78.75437164, 25.39307022], [78.75726318, 25.39252281], [78.75888824, 25.39352036], [78.75988007, 25.39775085], [78.75962067, 25.402071], [78.75863647, 25.40409088], [78.7546463, 25.40621948], [78.75115967, 25.40526962], [78.74754333, 25.4005394], [78.74349976, 25.39767075], [78.74156189, 25.39858055], [78.74030304, 25.40307045], [78.7405014, 25.40654182], [78.74314117, 25.41270065], [78.7454071, 25.4155407], [78.74938202, 25.41756058], [78.7562027, 25.41929817], [78.77604675, 25.42119026], [78.78823853, 25.42358017], [78.79046631, 25.42568016], [78.79464722, 25.4265995], [78.80766296, 25.42523956], [78.81138611, 25.42735291], [78.81291199, 25.43042755], [78.8117981, 25.43308067], [78.80345154, 25.43819046], [78.79528809, 25.44132805], [78.7894516, 25.44202042], [78.78218079, 25.43992043], [78.77629089, 25.43696976], [78.77207947, 25.4329319], [78.76537323, 25.43003273], [78.75997162, 25.43056107], [78.75506592, 25.43385124], [78.75180817, 25.43843079], [78.74812317, 25.44844055], [78.7436676, 25.45210075], [78.7323761, 25.45566177], [78.72766876, 25.4587307], [78.72464752, 25.46330833], [78.72631836, 25.49007034], [78.73175049, 25.50065041], [78.7360611, 25.50432968], [78.73931885, 25.49987984], [78.74154663, 25.48993111], [78.74359131, 25.48489189], [78.7494812, 25.48221016], [78.75654602, 25.47615051], [78.76051331, 25.47575951], [78.76432037, 25.4766407], [78.77297211, 25.48283005], [78.77677155, 25.48339081], [78.78172302, 25.48414993], [78.78952789, 25.48351288], [78.81019592, 25.47544098], [78.81526184, 25.47241974], [78.82549286, 25.46837044], [78.82985687, 25.46569061], [78.83339691, 25.46165085], [78.83590698, 25.45998955], [78.83764648, 25.45885086], [78.84211731, 25.45714951], [78.8457489, 25.45438957], [78.84200287, 25.45000267], [78.83718872, 25.44798088], [78.83268738, 25.44765282], [78.83036041, 25.44748116], [78.81645966, 25.44890976], [78.81387329, 25.44630814], [78.81569672, 25.44175911], [78.81973267, 25.43778038], [78.83097839, 25.43203163], [78.83426666, 25.43246078], [78.83660126, 25.43424988], [78.84533691, 25.44497108], [78.85369873, 25.45230103], [78.8572464, 25.46215248], [78.8571701, 25.4671402], [78.85164642, 25.47779083], [78.84880066, 25.48757172], [78.84603882, 25.4913826], [78.83071899, 25.49837112], [78.82699585, 25.50370026], [78.82832336, 25.50998116], [78.83394623, 25.51600075], [78.83673096, 25.51678848], [78.84120178, 25.51807022], [78.84706879, 25.51853943], [78.85128784, 25.51889038], [78.87600708, 25.5243206], [78.87837219, 25.52865982], [78.87757111, 25.53318977], [78.8684082, 25.54417992], [78.8690033, 25.55116081], [78.87435913, 25.55701256], [78.88109589, 25.5601902], [78.88276672, 25.56040955], [78.88553619, 25.56077003], [78.89678955, 25.55939102], [78.90595245, 25.56060028], [78.91036987, 25.55933952], [78.91332245, 25.54552078], [78.9168396, 25.54129028], [78.9185791, 25.54332161], [78.9204483, 25.54957008], [78.92263794, 25.55682945], [78.92568207, 25.5599575], [78.93074036, 25.55972099], [78.93566132, 25.55709076], [78.94168854, 25.55144119], [78.94381714, 25.54092026], [78.9418869, 25.53115082], [78.93844604, 25.52753067], [78.93224335, 25.52435112], [78.9196167, 25.52744293], [78.91726685, 25.52547073], [78.91638184, 25.52075005], [78.91668701, 25.51675034], [78.91918182, 25.51355171], [78.92617798, 25.50761032], [78.93315125, 25.4982605], [78.93518066, 25.49430084], [78.93612671, 25.48778152], [78.93563843, 25.48002052], [78.93003845, 25.46858978], [78.92745972, 25.46569061], [78.9197464, 25.46216011], [78.91340637, 25.4520607], [78.90631104, 25.4504509], [78.90322876, 25.44693756], [78.91259003, 25.43867111], [78.92913055, 25.42832947], [78.93415833, 25.4318924], [78.93782043, 25.43753815], [78.94258881, 25.44170189], [78.94696808, 25.44254112], [78.96012878, 25.43889046], [78.96248627, 25.43635941], [78.96891022, 25.42513275], [78.97022247, 25.42045975], [78.9655304, 25.41147995], [78.96817017, 25.39655113], [78.97106171, 25.39184952], [78.97580719, 25.38869095], [78.97840881, 25.38286018], [78.978508, 25.3760128], [78.97447205, 25.3725605], [78.95527649, 25.37308121], [78.94844055, 25.37000275], [78.93871307, 25.35283089], [78.92862701, 25.35180092], [78.9171524, 25.35999107], [78.90638733, 25.36338043], [78.8969574, 25.36520958], [78.89322662, 25.36901093], [78.89245605, 25.37529755], [78.89539337, 25.38079071], [78.90912628, 25.38056183], [78.92636871, 25.37734032], [78.93113708, 25.37712288], [78.93885803, 25.38907051], [78.94725037, 25.39318085], [78.95123291, 25.39645958], [78.94935608, 25.40015984], [78.94341278, 25.40312004], [78.9310379, 25.4031601], [78.92266846, 25.4004612], [78.9154129, 25.39962959], [78.91201019, 25.39699936], [78.90830994, 25.39237022], [78.90107727, 25.38925934], [78.89055634, 25.38883018], [78.88301849, 25.38951111], [78.87474823, 25.38765907], [78.86142731, 25.37702942], [78.8453598, 25.36091042], [78.83773804, 25.35217285], [78.83586121, 25.34703064], [78.8431778, 25.34208107], [78.84541321, 25.33867073], [78.84567261, 25.33518982], [78.84350586, 25.33236122], [78.84026337, 25.33185005], [78.83566284, 25.33298111], [78.8332901, 25.33134079], [78.82659912, 25.31985283], [78.8216629, 25.31874275], [78.81667328, 25.31657028], [78.81456757, 25.31096077], [78.81022644, 25.31085968], [78.79802704, 25.31452179], [78.79193878, 25.31479263], [78.78674316, 25.30972099], [78.78328705, 25.30318069], [78.7832489, 25.29761124], [78.78692627, 25.29494095], [78.79120636, 25.29301071], [78.79328918, 25.29310036], [78.80367279, 25.30199814], [78.80699158, 25.30297089], [78.81167603, 25.29984093], [78.81272125, 25.29776001], [78.81215668, 25.29409981], [78.80635071, 25.27946091], [78.80562592, 25.27093124], [78.81128693, 25.26600075], [78.82367706, 25.25107956], [78.83505249, 25.23320007], [78.8417511, 25.22916031], [78.84462738, 25.23110962], [78.84594727, 25.23378944], [78.85028839, 25.25342751], [78.85288239, 25.2588501], [78.85791779, 25.26624107], [78.86228943, 25.28313065], [78.87059021, 25.28486824], [78.87242889, 25.28820992], [78.87185669, 25.29179955], [78.86763763, 25.30134964], [78.86686707, 25.31098938], [78.85954285, 25.31455994], [78.85643768, 25.31695938], [78.85823822, 25.3208828], [78.86245728, 25.32460976], [78.87306976, 25.33082962], [78.87560272, 25.33401108], [78.87679291, 25.33921051], [78.87651825, 25.34445953], [78.87895966, 25.34687996], [78.88524628, 25.34669113], [78.89552307, 25.34351921], [78.9034729, 25.3400898], [78.90788269, 25.33940125], [78.91121674, 25.34213066], [78.91467285, 25.34644127], [78.91886902, 25.34599113], [78.92453003, 25.34192848], [78.92546082, 25.33843994], [78.92537689, 25.33457947], [78.9276123, 25.33171082], [78.93122864, 25.33241272], [78.93547058, 25.33620071], [78.94277954, 25.34511948], [78.94581604, 25.34725952], [78.94999695, 25.34827995], [78.95285797, 25.34987068], [78.9557724, 25.34776115], [78.95202637, 25.31738091], [78.95279694, 25.3118782], [78.97027588, 25.29109192], [78.970047, 25.28520966], [78.96469879, 25.2838707], [78.95384979, 25.28562927], [78.94754028, 25.28370094], [78.94378662, 25.28007126], [78.94447327, 25.27544975], [78.94799042, 25.2717495], [78.94838715, 25.2659111], [78.94618225, 25.26377106], [78.94061279, 25.26268959], [78.93643951, 25.26267815], [78.93348694, 25.26354027], [78.92581177, 25.26782036], [78.92276764, 25.27148056], [78.91828918, 25.27517128], [78.91520691, 25.27569008], [78.90859985, 25.27436066], [78.89644623, 25.24994087], [78.89169312, 25.24546051], [78.88456726, 25.24723053], [78.88022614, 25.25362015], [78.87587738, 25.25576973], [78.87217712, 25.25078964], [78.86725616, 25.23769188], [78.86707306, 25.23254013], [78.87325287, 25.22608185], [78.88162231, 25.21547127], [78.88241577, 25.21105957], [78.88011932, 25.20589828], [78.8757019, 25.20014954], [78.87104797, 25.19616127], [78.86738586, 25.18996048], [78.86759949, 25.18634033], [78.86979675, 25.18291283], [78.86921692, 25.17811966], [78.87325287, 25.17200279], [78.87184143, 25.16600037], [78.87393188, 25.16327095], [78.87713623, 25.16218185], [78.89340973, 25.17322922], [78.9006424, 25.18053818], [78.90159607, 25.18326187], [78.90804291, 25.19352913], [78.91529083, 25.20259094], [78.91916656, 25.2062397], [78.92423248, 25.2105999], [78.94235992, 25.21836281], [78.94834137, 25.22018051], [78.95284271, 25.22069168], [78.96392059, 25.21943092], [78.96920776, 25.21663284], [78.97767639, 25.20420074], [78.98240662, 25.19915009], [78.98774719, 25.19677925], [78.99275208, 25.19652176], [78.99581146, 25.19593811], [78.99733734, 25.19828987], [78.99749756, 25.2075901], [79.00035858, 25.2160511], [78.99330902, 25.22221947], [78.99453735, 25.22545052], [78.99500275, 25.23228073], [78.99466705, 25.23374939], [78.99269867, 25.23500252], [78.98741913, 25.23592949], [78.97231293, 25.24283028], [78.97116852, 25.24492073], [78.97331238, 25.25368118], [78.97722626, 25.2616806], [78.98677063, 25.27495956], [78.99265289, 25.27773094], [79.00496674, 25.27696991], [79.01235962, 25.27404022], [79.01431274, 25.27103043], [79.01599121, 25.26515007], [79.01167297, 25.25284958], [79.01161957, 25.24933052], [79.01212311, 25.24824905], [79.01474762, 25.24775124], [79.02937317, 25.24934006], [79.03103638, 25.24628067], [79.0283432, 25.24102974], [79.02648163, 25.23467064], [79.04506683, 25.23063087], [79.05232239, 25.22813034], [79.05644226, 25.22570992], [79.05673981, 25.21922112], [79.05513, 25.21722031], [79.04847717, 25.20979118], [79.04277802, 25.21014023], [79.02459717, 25.18657112], [79.02572632, 25.18259048], [79.02796173, 25.1803112], [79.03144836, 25.17850113], [79.03578186, 25.1739006], [79.02523804, 25.15579033], [79.02162933, 25.14693069], [79.02176666, 25.14319038], [79.02823639, 25.13993073], [79.0355072, 25.13784027], [79.03888702, 25.13722992], [79.04305267, 25.13817024], [79.04889679, 25.14751053], [79.0545578, 25.14887047], [79.05805206, 25.15081978], [79.06285858, 25.16274261], [79.06407928, 25.17249107], [79.07025909, 25.17776108], [79.08429718, 25.19252968], [79.08722687, 25.18783951], [79.08841705, 25.18372917], [79.08872986, 25.17832947], [79.09057617, 25.17622948], [79.10256195, 25.17119026], [79.10710907, 25.16814041], [79.11920929, 25.1634407], [79.12042236, 25.16418076], [79.11859131, 25.15839195], [79.10781097, 25.14369965], [79.1247406, 25.12957954], [79.12510681, 25.12921906], [79.11482239, 25.11779976], [79.12084961, 25.11340141], [79.12433624, 25.11186981], [79.12917328, 25.11076927], [79.13337708, 25.1110611], [79.13820648, 25.11841011], [79.14480591, 25.1165905], [79.15661621, 25.11190033], [79.16887665, 25.11186028], [79.17236328, 25.11847115], [79.17411804, 25.11903], [79.17930603, 25.11769295], [79.17987823, 25.12882996], [79.16879272, 25.13157082], [79.16652679, 25.13953018], [79.16677856, 25.14234924], [79.16837311, 25.14530754], [79.17730713, 25.14595032], [79.18110657, 25.14762115], [79.1848526, 25.15113258], [79.18768311, 25.15092278], [79.1889801, 25.14935112], [79.19010925, 25.14565086], [79.19373322, 25.1436615], [79.19671631, 25.14293098], [79.19632721, 25.13804817], [79.19616699, 25.13167], [79.19793701, 25.12818909], [79.20709991, 25.12439156], [79.20638275, 25.1137619], [79.21067047, 25.11445045], [79.21369934, 25.11647987], [79.21843719, 25.11819077], [79.22010803, 25.12099075], [79.22278595, 25.12325096], [79.22598267, 25.12240982], [79.23488617, 25.11746025], [79.23838043, 25.11636925], [79.2396698, 25.11783981], [79.24014282, 25.12018967], [79.23810577, 25.12672043], [79.23767853, 25.13133049], [79.24353027, 25.14079094], [79.24151611, 25.14092064], [79.23980713, 25.14273071], [79.2375412, 25.1428299], [79.2248764, 25.14023018], [79.22408295, 25.14082909], [79.22399139, 25.14318085], [79.22252655, 25.14562035], [79.21391296, 25.14838028], [79.21965027, 25.15456963], [79.22518158, 25.1581707], [79.23583984, 25.16096115], [79.24584198, 25.1619606], [79.25060272, 25.16120911], [79.2559967, 25.15728188], [79.25920105, 25.15327263], [79.25934601, 25.14694023], [79.25836182, 25.14390945], [79.26194763, 25.14191055], [79.26207733, 25.14115906], [79.25454712, 25.13046074], [79.25807953, 25.12401962], [79.2600708, 25.12210083], [79.26875305, 25.12623024], [79.26999664, 25.12615013], [79.27381897, 25.12168121], [79.27654266, 25.12026024], [79.28218079, 25.13352013], [79.29110718, 25.13125992], [79.30098724, 25.13083076], [79.30322266, 25.13332939], [79.30570984, 25.13990021], [79.31388855, 25.15096092], [79.31453705, 25.15187836], [79.31060028, 25.16090012], [79.30874634, 25.16512108], [79.30188751, 25.17534065], [79.29077911, 25.18390083], [79.28872681, 25.18626976], [79.28351593, 25.18946075], [79.27880096, 25.19739914], [79.27777863, 25.20351028], [79.27802277, 25.21063995], [79.27963257, 25.22171021], [79.28106689, 25.22434044], [79.28148651, 25.22714043], [79.27822876, 25.23829079], [79.27416992, 25.24518967], [79.27391052, 25.24650002], [79.27359772, 25.24811935], [79.27855682, 25.24782944], [79.28401184, 25.24650002], [79.29332733, 25.24020004], [79.29782104, 25.23444939], [79.30047607, 25.22744942], [79.30858612, 25.22319031], [79.31078339, 25.21948051], [79.31339264, 25.21955109], [79.31491089, 25.21960068], [79.3229599, 25.22274971], [79.32433319, 25.22257042], [79.32534027, 25.22244072], [79.32508087, 25.21387291], [79.32578278, 25.21081161], [79.32656097, 25.20850945], [79.3325882, 25.20083046], [79.34337616, 25.20998955], [79.34696198, 25.21424103], [79.33490753, 25.22286987], [79.32911682, 25.22990036], [79.33078003, 25.23207092], [79.33197784, 25.23200035], [79.33953094, 25.22809029], [79.34111786, 25.23048973], [79.34127808, 25.2390995], [79.34028625, 25.24308014], [79.34086609, 25.25607109], [79.34129333, 25.25864983], [79.3445282, 25.26429939], [79.34008789, 25.27276039], [79.33789825, 25.27318764], [79.33454132, 25.27571106], [79.33190155, 25.27626991], [79.32338715, 25.26684952], [79.31873322, 25.26307106], [79.31468964, 25.26139259], [79.31004333, 25.26192093], [79.30391693, 25.26540184], [79.29830933, 25.27577019], [79.28775024, 25.29024124], [79.28646088, 25.28107071], [79.27787018, 25.27100182], [79.27529907, 25.26929092], [79.27111053, 25.26650238], [79.26877594, 25.26646042], [79.26566315, 25.26639938], [79.26196289, 25.26773071], [79.25945282, 25.27144051], [79.25901031, 25.27420998], [79.25650787, 25.27947044], [79.25627899, 25.28211975], [79.25683594, 25.28499031], [79.25601196, 25.29171944], [79.25798798, 25.29837036], [79.26013947, 25.31023979], [79.26760101, 25.31875038], [79.27651978, 25.32703018], [79.27760315, 25.32805061], [79.28341675, 25.33008957], [79.2913208, 25.32928848], [79.29371643, 25.33236122], [79.29408264, 25.33937073], [79.29473114, 25.3402195], [79.30422211, 25.33984947], [79.30930328, 25.33856964], [79.32512665, 25.33724976], [79.33023071, 25.3337307], [79.3337326, 25.33258057], [79.34458923, 25.33444977], [79.34588623, 25.33304024], [79.33837891, 25.32492828], [79.33448029, 25.31739807], [79.33769989, 25.31090927], [79.3414917, 25.30768967], [79.34187317, 25.30458069], [79.33075714, 25.29404831], [79.33104706, 25.29277992], [79.33164978, 25.29257965], [79.33249664, 25.29230118], [79.34308624, 25.29042053], [79.34970856, 25.28841972], [79.35161591, 25.27799034], [79.35109711, 25.26995087], [79.35296631, 25.26538086], [79.35829926, 25.26351929], [79.36168671, 25.26427078], [79.36573792, 25.26807022], [79.36724091, 25.27242088], [79.36717224, 25.27557945], [79.36444855, 25.29252052], [79.36741638, 25.29432106], [79.36975098, 25.29409981], [79.37256622, 25.2933197], [79.37561798, 25.29109955], [79.37931061, 25.28672028], [79.38353729, 25.28360939], [79.38600159, 25.28415108], [79.38861084, 25.28624916], [79.39229584, 25.28486061], [79.40188599, 25.2792511], [79.40122223, 25.26235962], [79.41530609, 25.25922012], [79.42665863, 25.25842285], [79.43121338, 25.25955009], [79.45157623, 25.27360916], [79.4527359, 25.27526855], [79.45307159, 25.28256035], [79.45741272, 25.2838707], [79.47312164, 25.2821312], [79.4752121, 25.27917099], [79.47525024, 25.27749062], [79.47527313, 25.27671051], [79.47532654, 25.27487946], [79.4763031, 25.27316093], [79.47772217, 25.27238274], [79.48446655, 25.27273941], [79.49040222, 25.2703495], [79.49082947, 25.26901054], [79.48973846, 25.26564026], [79.48396301, 25.26498032], [79.47911835, 25.26516914], [79.47453308, 25.26657295], [79.46401215, 25.26799965], [79.46070099, 25.26960945], [79.45919037, 25.26945114], [79.45522308, 25.26521111], [79.45285034, 25.25650024], [79.44834137, 25.25081062], [79.44490814, 25.24811935], [79.44358826, 25.2486496], [79.4417572, 25.25172043], [79.43855286, 25.24827194], [79.43418121, 25.24178123], [79.43297577, 25.23600006], [79.42701721, 25.22503853], [79.43231201, 25.22180176], [79.44239807, 25.22095108], [79.44270325, 25.21256065], [79.43578339, 25.20465851], [79.43213654, 25.20277977], [79.42800903, 25.20353127], [79.42617798, 25.20305824], [79.42460632, 25.20264816], [79.42125702, 25.20323944], [79.41734314, 25.20392036], [79.40957642, 25.20876122], [79.40809631, 25.20751953], [79.40455627, 25.19947052], [79.40421295, 25.19441032], [79.40389252, 25.18958092], [79.39150238, 25.17964935], [79.38387299, 25.17028046], [79.38006592, 25.15372086], [79.38022614, 25.14912033], [79.38212585, 25.14593124], [79.38389587, 25.14003944], [79.38704681, 25.13614273], [79.38873291, 25.13162994], [79.38928986, 25.12058067], [79.39080811, 25.11790276], [79.39317322, 25.1161499], [79.39914703, 25.11346054], [79.40196991, 25.11335945], [79.40918732, 25.11565971], [79.41496277, 25.12299919], [79.41710663, 25.12726974], [79.418396, 25.13352013], [79.4178009, 25.1350708], [79.41477203, 25.13736916], [79.41512299, 25.13909912], [79.41760254, 25.1384697], [79.42590332, 25.13839912], [79.43113708, 25.13540077], [79.43297577, 25.13141823], [79.43525696, 25.1265316], [79.4344101, 25.12170029], [79.43344879, 25.12000084], [79.43115997, 25.11594963], [79.42945862, 25.1117897], [79.42951965, 25.11148262], [79.42990875, 25.10913277], [79.43067169, 25.10806084], [79.43106842, 25.10750961], [79.43637085, 25.10782051], [79.44478607, 25.11309052], [79.45022583, 25.11783028], [79.45656586, 25.12499046], [79.46837616, 25.13445091], [79.46951294, 25.13404083], [79.4701767, 25.13380051], [79.4701767, 25.13068008], [79.46053314, 25.09633064], [79.4715271, 25.08719063], [79.48243713, 25.08510971], [79.48987579, 25.08275032], [79.49106598, 25.08329964], [79.49112701, 25.08488274], [79.49118042, 25.08612251], [79.4937973, 25.0920105], [79.50016022, 25.0992012], [79.50527191, 25.10130119], [79.5133667, 25.10025024], [79.51535797, 25.10104179], [79.51722717, 25.10178757], [79.51828766, 25.10443115], [79.51815796, 25.10770035], [79.51394653, 25.12210083], [79.51377106, 25.12572289], [79.51795959, 25.1312294], [79.52658844, 25.13563919], [79.52868652, 25.13738251], [79.52857971, 25.13801193], [79.52731323, 25.14310074], [79.52864838, 25.14497948], [79.53363037, 25.14644051], [79.53494263, 25.14762115], [79.53795624, 25.15262985], [79.5427475, 25.16055107], [79.55033875, 25.16940117], [79.5595932, 25.17597008], [79.56552124, 25.17755127], [79.56893921, 25.17552185], [79.57396698, 25.15945053], [79.5762558, 25.15705109], [79.58573914, 25.15286255], [79.58969879, 25.14727974], [79.59052277, 25.14680099], [79.59144592, 25.14627075], [79.59233856, 25.14631081], [79.59326935, 25.14635086], [79.60003662, 25.15497971], [79.60280609, 25.1547699], [79.60279083, 25.15384293], [79.60276794, 25.15310097], [79.59854889, 25.1453495], [79.59748077, 25.13955116], [79.59541321, 25.13562012], [79.59516907, 25.13413239], [79.5978775, 25.13143158], [79.60209656, 25.1313591], [79.60514832, 25.13223076], [79.60608673, 25.13249969], [79.62003326, 25.14266968], [79.63285065, 25.13282967], [79.6378479, 25.13108063], [79.64070129, 25.13239861], [79.64302826, 25.13236046], [79.65419006, 25.1304512], [79.65659332, 25.12951279], [79.66053772, 25.12796021], [79.66616821, 25.12712097], [79.67079163, 25.13208961], [79.67418671, 25.13577843], [79.6765976, 25.13698959], [79.68698883, 25.13686943], [79.70728302, 25.13331985], [79.71776581, 25.13381958], [79.72455597, 25.13540077], [79.72603607, 25.13573265], [79.73957825, 25.14295959], [79.74563599, 25.14388275], [79.74781799, 25.14260101], [79.75110626, 25.14066124], [79.75772095, 25.13452911], [79.76274872, 25.12982941], [79.76921844, 25.1252594], [79.78833771, 25.12039185], [79.79325104, 25.11837959], [79.80516815, 25.11097908], [79.81640625, 25.11086273], [79.8187027, 25.11015129], [79.82327271, 25.10640907], [79.82434082, 25.10370064], [79.8272171, 25.10012054], [79.8312912, 25.0981102], [79.84085846, 25.09639931], [79.84921265, 25.09698105], [79.855896, 25.09850121], [79.85309601, 25.10275078], [79.84580994, 25.11046982], [79.84268188, 25.1163311], [79.84657288, 25.12227058], [79.84796906, 25.12823105], [79.84767151, 25.13339043], [79.85161591, 25.13977814], [79.85740662, 25.14281082], [79.86483002, 25.14499283], [79.87217712, 25.14851189], [79.87210083, 25.15030289], [79.86300659, 25.15390968], [79.86058807, 25.15606117], [79.85965729, 25.16205025], [79.86260223, 25.17696953], [79.86154175, 25.17906952], [79.85810852, 25.18185806], [79.85878754, 25.19022942], [79.8547821, 25.19909286], [79.85185242, 25.20347977], [79.85411835, 25.21042061], [79.85618591, 25.2136097], [79.86303711, 25.2191906], [79.86136627, 25.22095108], [79.85285187, 25.2250309], [79.84716034, 25.23241043], [79.8452301, 25.23655128], [79.84572601, 25.23838234], [79.84713745, 25.24020004], [79.8509903, 25.24156952], [79.85755157, 25.2419014], [79.86097717, 25.24299049], [79.86595917, 25.24682045], [79.87245941, 25.25379181], [79.87500763, 25.25299072], [79.8866272, 25.24641037], [79.89360046, 25.2462101], [79.89615631, 25.24753952], [79.8972702, 25.24959946], [79.89834595, 25.25510025], [79.89962006, 25.25657082], [79.90239716, 25.25691986], [79.90532684, 25.25547028], [79.90629578, 25.25418091], [79.91056061, 25.24497986], [79.91062927, 25.23604965], [79.91220856, 25.23376274], [79.91345215, 25.2334404], [79.92099762, 25.25070953], [79.92410278, 25.25155067], [79.93257141, 25.25032043], [79.93196106, 25.25985909], [79.93332672, 25.26301956], [79.93437958, 25.26486969], [79.94095612, 25.26971054], [79.94256592, 25.2718792], [79.94921875, 25.26530075], [79.96304321, 25.26824951], [79.96717072, 25.26847076], [79.96951294, 25.26816177], [79.97727966, 25.26494026], [79.99221039, 25.26930046], [79.99672699, 25.26865005], [79.99733734, 25.27013016], [79.99534607, 25.27466011], [79.99559784, 25.27672958], [79.9921875, 25.28098106], [79.99125671, 25.28316116], [79.99220276, 25.28524971], [79.99385834, 25.28884125], [79.998703, 25.29376984], [80.0083313, 25.30067825], [80.01264954, 25.30171967], [80.00991058, 25.32475281], [80.01265717, 25.33011055], [80.01449585, 25.33111], [80.02073669, 25.34316063], [80.02419281, 25.34459114], [80.0371933, 25.34096909], [80.04444122, 25.34185028], [80.05486298, 25.34129906], [80.06150055, 25.34204102], [80.07002258, 25.34309959], [80.07234192, 25.34509087], [80.07839966, 25.35344124], [80.08329773, 25.35583115], [80.09337616, 25.35383034], [80.09609222, 25.35157967], [80.106987, 25.34418106], [80.119133, 25.34269905], [80.12329865, 25.3384304], [80.12708282, 25.34061813], [80.13273621, 25.35032082], [80.13712311, 25.35573006], [80.14496613, 25.36010933], [80.15315247, 25.3628006], [80.15912628, 25.36619949], [80.15828705, 25.37265968], [80.15917969, 25.37764931], [80.16668701, 25.37895012], [80.17201233, 25.38069153], [80.18261719, 25.38151932], [80.18789673, 25.38364983], [80.18916321, 25.38922119], [80.18882751, 25.4064312], [80.19093323, 25.40904045], [80.19143677, 25.41271019], [80.19391632, 25.41623116], [80.19724274, 25.4149704], [80.19832611, 25.41269112], [80.19786835, 25.41056061], [80.20244598, 25.40673065], [80.21137238, 25.40394974], [80.2140274, 25.40423012], [80.22657776, 25.41064072], [80.22956085, 25.4109211], [80.24518585, 25.40489006], [80.24739838, 25.40738106], [80.24730682, 25.41146088], [80.25241089, 25.41877174], [80.253479, 25.42346954], [80.255867, 25.42871094], [80.26123047, 25.42617989], [80.27372742, 25.42503929], [80.28431702, 25.41588974], [80.28964233, 25.41271973], [80.29532623, 25.40776062], [80.30857849, 25.39233017], [80.30905151, 25.39183998], [80.31075287, 25.38731766], [80.31121063, 25.3810997], [80.31324768, 25.37225914], [80.30861664, 25.36372948], [80.30536652, 25.36207962], [80.30262756, 25.35828018], [80.30358887, 25.35251236], [80.30980682, 25.34127045], [80.31173706, 25.33420944], [80.31069183, 25.31065178], [80.30912018, 25.30585098], [80.30267334, 25.29696083], [80.30307007, 25.2911396], [80.30404663, 25.28889275], [80.31201172, 25.28215027], [80.31983948, 25.28049088], [80.33766174, 25.27941132], [80.3409729, 25.27860069], [80.34926605, 25.26955032], [80.35041046, 25.2652626], [80.35173798, 25.26024055], [80.35359192, 25.25638962], [80.35771179, 25.25113106], [80.36289215, 25.24682999], [80.37802887, 25.23751068], [80.3813324, 25.23829842], [80.3829422, 25.24195099], [80.39070129, 25.24568748], [80.39906311, 25.24296951], [80.4016571, 25.22095108], [80.40423584, 25.21404076], [80.4095459, 25.20586014], [80.41162872, 25.19943047], [80.41812897, 25.19192123], [80.42237854, 25.18136024], [80.42369843, 25.17414284], [80.42256927, 25.17221069], [80.41548157, 25.16529274], [80.40358734, 25.16505051], [80.3867569, 25.16288185], [80.38066864, 25.16077995], [80.37343597, 25.15517807], [80.36245728, 25.14973068], [80.35614777, 25.14841843], [80.35128784, 25.14490128], [80.34861755, 25.14069176], [80.34752655, 25.13002014], [80.34411621, 25.12491989], [80.33835602, 25.12125015], [80.32283783, 25.1066494], [80.31327057, 25.10117149], [80.31472015, 25.0940609], [80.3132019, 25.0892601], [80.31051636, 25.08195114], [80.30478668, 25.07551003], [80.2947464, 25.06909943], [80.2876358, 25.06689072], [80.28195953, 25.06322098], [80.28157043, 25.06005096], [80.28115845, 25.05673981], [80.27941132, 25.05267906], [80.27780151, 25.04397964], [80.2771759, 25.04294014], [80.27487946, 25.03903961], [80.27327728, 25.0371418], [80.27078247, 25.03417969], [80.26876831, 25.03269958], [80.26727295, 25.0316124], [80.26693726, 25.03024292], [80.27849579, 25.02164841], [80.28919983, 25.02114105], [80.29897308, 25.01603127], [80.31236267, 25.00629807], [80.31278229, 25.00432014], [80.31410217, 25.00350952], [80.31462097, 25.00342178], [80.31511688, 25.0033493], [80.31564331, 25.0032692], [80.31614685, 25.00320053], [80.31665039, 25.0031414], [80.31716919, 25.0030899], [80.31768036, 25.00303078], [80.31819916, 25.0030117], [80.31871033, 25.00296974], [80.31922913, 25.00294113], [80.31973267, 25.00291824], [80.32025909, 25.00291061], [80.32079315, 25.00291061], [80.32128143, 25.00290108], [80.3217926, 25.00291061], [80.32231903, 25.00291061], [80.32285309, 25.00294113], [80.323349, 25.00296021], [80.32388306, 25.00298119], [80.3243866, 25.00303078], [80.32491302, 25.00307083], [80.32594299, 25.00311089], [80.32739258, 25.00434113], [80.3289566, 25.00543022], [80.33798218, 25.02094078], [80.34456635, 25.01947021], [80.34793854, 25.01646805], [80.35257721, 25.01988029], [80.35507202, 25.02449036], [80.35884857, 25.02607918], [80.36782074, 25.02543068], [80.36885834, 25.02383995], [80.36921692, 25.01888084], [80.37283325, 25.00832939], [80.38218689, 25.00974083], [80.38739014, 25.01242065], [80.38915253, 25.01490974], [80.38304138, 25.01869011], [80.38088226, 25.02765846], [80.37612915, 25.02799988], [80.3723526, 25.02918053], [80.37177277, 25.03276062], [80.37287903, 25.03470039], [80.3747406, 25.03660011], [80.37831116, 25.03680992], [80.38043213, 25.03890038], [80.38020325, 25.04160118], [80.37906647, 25.04440117], [80.37520599, 25.0456295], [80.36750793, 25.04609108], [80.36406708, 25.04771996], [80.36627197, 25.05307961], [80.3657608, 25.05776024], [80.36724854, 25.05886078], [80.3792572, 25.05595016], [80.38347626, 25.0616703], [80.38414764, 25.06534004], [80.38640594, 25.0673008], [80.38944244, 25.0682106], [80.39412689, 25.07202148], [80.39807892, 25.06928062], [80.39746857, 25.06562042], [80.40268707, 25.06095123], [80.40525055, 25.06085014], [80.40677643, 25.06344986], [80.40991974, 25.07671928], [80.42272949, 25.07131958], [80.42450714, 25.07150078], [80.42951202, 25.07254028], [80.4311676, 25.07394028], [80.43292236, 25.07839012], [80.43509674, 25.0809803], [80.44071198, 25.0820694], [80.4417572, 25.08101273], [80.44428253, 25.0812912], [80.44513702, 25.08017159], [80.44342041, 25.07733917], [80.44164276, 25.07600021], [80.44225311, 25.07328033], [80.44464111, 25.07081032], [80.44420624, 25.06817055], [80.445961, 25.06583023], [80.45297241, 25.06878281], [80.45593262, 25.07382011], [80.45996857, 25.06970024], [80.46142578, 25.05798912], [80.4701767, 25.04469109], [80.47331238, 25.04358292], [80.47693634, 25.04388809], [80.47901154, 25.04434967], [80.48314667, 25.04725075], [80.48583221, 25.04730988], [80.49420929, 25.04532051], [80.49317169, 25.05431938], [80.49724579, 25.0560112], [80.50019836, 25.05877113], [80.50231934, 25.06286049], [80.5021286, 25.06735039], [80.50007629, 25.07097054], [80.49059296, 25.07821083], [80.49453735, 25.07956123], [80.49842834, 25.08257103], [80.49997711, 25.08955956], [80.49777222, 25.09139061], [80.49433136, 25.09205055], [80.48729706, 25.09180069], [80.47759247, 25.09641266], [80.47471619, 25.09906006], [80.47447968, 25.10182953], [80.47612762, 25.10225105], [80.48030853, 25.10157967], [80.48391724, 25.10281944], [80.49212646, 25.10223007], [80.49471283, 25.10494041], [80.50190735, 25.10413933], [80.50950623, 25.10102081], [80.51288605, 25.0982399], [80.51425934, 25.09577751], [80.51515961, 25.08846092], [80.51731873, 25.08479118], [80.51899719, 25.08193016], [80.52812958, 25.07705116], [80.53203583, 25.07591057], [80.53882599, 25.06965828], [80.54341888, 25.06766129], [80.54676819, 25.06797028], [80.54862213, 25.06931114], [80.55245209, 25.06928062], [80.55536652, 25.07089806], [80.55766296, 25.07292175], [80.55999756, 25.07498932], [80.56117249, 25.07928276], [80.56109619, 25.08876991], [80.56243896, 25.0914402], [80.56562805, 25.08718109], [80.56804657, 25.08528137], [80.57263947, 25.08580017], [80.57866669, 25.08826256], [80.58011627, 25.08695984], [80.58757782, 25.08587074], [80.58872223, 25.08434105], [80.5932312, 25.08152962], [80.59594727, 25.07818031], [80.60452271, 25.07262993], [80.60678101, 25.07217979], [80.60710144, 25.07273293], [80.60730743, 25.07308006], [80.60675812, 25.07620049], [80.60002136, 25.09075165], [80.59435272, 25.09295082], [80.59333801, 25.09420967], [80.59188843, 25.09600258], [80.58777618, 25.10910034], [80.59137726, 25.11799049], [80.59642029, 25.12202072], [80.60144806, 25.12281036], [80.60037994, 25.1253109], [80.59757233, 25.1281395], [80.59075928, 25.13158035], [80.59011078, 25.13482094], [80.59105682, 25.14129066], [80.59458923, 25.15524101], [80.59960938, 25.15546989], [80.60269928, 25.1523819], [80.60578918, 25.14928055], [80.6056366, 25.14278984], [80.60547638, 25.13635063], [80.6083374, 25.13294983], [80.6159668, 25.13812065], [80.62245178, 25.13606071], [80.62496185, 25.13767052], [80.62802124, 25.13029099], [80.63239288, 25.12328148], [80.63123322, 25.11980057], [80.62229919, 25.12202072], [80.61923218, 25.12021065], [80.61875153, 25.11808014], [80.61823273, 25.11580086], [80.61476898, 25.11386108], [80.61506653, 25.11120987], [80.61329651, 25.10654068], [80.60682678, 25.1065197], [80.60135651, 25.10440826], [80.60655212, 25.10157967], [80.6084671, 25.09860039], [80.617836, 25.09366035], [80.62004089, 25.08958054], [80.62230682, 25.08929062], [80.62195587, 25.09338951], [80.62354279, 25.09519958], [80.62516785, 25.09555817], [80.62861633, 25.09328842], [80.63391876, 25.09379959], [80.63434601, 25.09717941], [80.63523865, 25.09756088], [80.63574982, 25.09605026], [80.63645172, 25.09395981], [80.6414566, 25.09314919], [80.64554596, 25.0906105], [80.65052795, 25.08753014], [80.65373993, 25.07645988], [80.65629578, 25.07444191], [80.66422272, 25.07839012], [80.66580963, 25.08019066], [80.66610718, 25.08053017], [80.66670227, 25.08426285], [80.66828918, 25.08675194], [80.67926025, 25.08181953], [80.67896271, 25.07578087], [80.67788696, 25.07310104], [80.67421722, 25.0680809], [80.67180634, 25.06732941], [80.67192078, 25.06456947], [80.67507935, 25.06253052], [80.67465973, 25.06019974], [80.67356873, 25.05417061], [80.67829895, 25.05457115], [80.68688965, 25.05879021], [80.69801331, 25.06155014], [80.70533752, 25.06142044], [80.70831299, 25.06492996], [80.70948792, 25.06632042], [80.71096039, 25.06726265], [80.7144165, 25.06775284], [80.72720337, 25.07182121], [80.72921753, 25.06553268], [80.7335968, 25.06244087], [80.74410248, 25.06233025], [80.7514267, 25.06399918], [80.75566864, 25.06257057], [80.76595306, 25.06114006], [80.77593994, 25.06169128], [80.77825928, 25.06386948], [80.7813797, 25.069561], [80.77961731, 25.07786942], [80.77597809, 25.08430099], [80.76703644, 25.08559036], [80.75112152, 25.09111977], [80.75100708, 25.09428978], [80.75205231, 25.09540939], [80.74931335, 25.09777069], [80.74577332, 25.09939957], [80.73343658, 25.1013298], [80.72931671, 25.09729767], [80.72524261, 25.09795952], [80.72049713, 25.10139275], [80.7190094, 25.10402107], [80.7199173, 25.11725807], [80.72537231, 25.12288284], [80.72244263, 25.12599182], [80.71730042, 25.1289196], [80.70746613, 25.12743187], [80.7008667, 25.12803841], [80.69847107, 25.13137245], [80.69963837, 25.13714981], [80.70092773, 25.1380806], [80.71061707, 25.13844109], [80.71478271, 25.14328003], [80.71530914, 25.14665985], [80.71763611, 25.14660072], [80.72305298, 25.14878273], [80.7277298, 25.14740181], [80.72865295, 25.14289856], [80.73227692, 25.14236259], [80.73206329, 25.14052963], [80.73545837, 25.13521957], [80.73809814, 25.13459969], [80.74043274, 25.13741112], [80.75086212, 25.14170074], [80.75956726, 25.14059067], [80.76605988, 25.14088821], [80.77403259, 25.1466198], [80.7766571, 25.14484024], [80.78214264, 25.13708115], [80.78369904, 25.13836288], [80.78613281, 25.13796043], [80.7906723, 25.14273071], [80.79367065, 25.14232063], [80.79786682, 25.14624023], [80.79957581, 25.14641762], [80.8032074, 25.1435318], [80.80828094, 25.14081955], [80.80771637, 25.13310051], [80.80961609, 25.13070107], [80.81864166, 25.13055038], [80.82139587, 25.12560081], [80.82168579, 25.12285042], [80.82151794, 25.1200428], [80.82315826, 25.11777115], [80.82393646, 25.11465263], [80.82769775, 25.1103096], [80.83344269, 25.11327171], [80.8377533, 25.12751007], [80.83479309, 25.13252068], [80.83209991, 25.14141083], [80.83384705, 25.14561272], [80.83744049, 25.16031075], [80.84188843, 25.16794014], [80.84230042, 25.1711998], [80.84111023, 25.17525291], [80.83589172, 25.18540955], [80.83515167, 25.19046974], [80.83628082, 25.19268036], [80.84108734, 25.19347954], [80.84858704, 25.19003105], [80.86036682, 25.1905899], [80.86315155, 25.18921089], [80.86416626, 25.18786049], [80.86953735, 25.18865967], [80.8780365, 25.19560051], [80.8861618, 25.17717171], [80.88902283, 25.17469025], [80.89597321, 25.17126083], [80.90556335, 25.16448021], [80.90492249, 25.16031075], [80.90157318, 25.15797997], [80.89029694, 25.14635086], [80.8884201, 25.14123917], [80.88526917, 25.14001274], [80.87541962, 25.14443016], [80.87275696, 25.13389015], [80.8690033, 25.12791061], [80.86585236, 25.12552071], [80.8649826, 25.1236496], [80.86650848, 25.11943054], [80.87224579, 25.10930061], [80.87298584, 25.10256958], [80.87121582, 25.09824944], [80.86730957, 25.09402084], [80.86425018, 25.08815956], [80.86480713, 25.08434105], [80.87507629, 25.07953835], [80.87065125, 25.07105064], [80.8557663, 25.06244087], [80.84687042, 25.05327988], [80.84113312, 25.05127907], [80.83522034, 25.03968048], [80.82668304, 25.03919029], [80.82911682, 25.02997971], [80.84005737, 25.02021027], [80.84192657, 25.0125103], [80.85025024, 25.0031414], [80.84818268, 24.99814034], [80.845047, 24.99349976], [80.83640289, 24.98608971], [80.82470703, 24.9860611], [80.82109833, 24.98250008], [80.81864166, 24.97363091], [80.81257629, 24.97367096], [80.8065033, 24.97500992], [80.79879761, 24.97489166], [80.79360962, 24.97365189], [80.78999329, 24.97178268], [80.78994751, 24.96718025], [80.79164124, 24.96391106], [80.80290985, 24.9569397], [80.80220032, 24.94445992], [80.81542969, 24.93790817], [80.82081604, 24.93659019], [80.82901001, 24.93844986], [80.83490753, 24.93452835], [80.84091949, 24.93556023], [80.85661316, 24.93595123], [80.87500763, 24.94071007], [80.87684631, 24.94506073], [80.88123322, 24.94820023], [80.88482666, 24.94889069], [80.88870239, 24.9474411], [80.8948288, 24.94244003], [80.89795685, 24.94169044], [80.9000473, 24.93958092], [80.90278625, 24.94016075], [80.90119934, 24.94334984], [80.89331818, 24.95046043], [80.89431763, 24.95389938], [80.89730072, 24.95672035], [80.91152191, 24.96228027], [80.91596222, 24.96479034], [80.92162323, 24.96657944], [80.9284668, 24.96769905], [80.93374634, 24.97010994], [80.93682098, 24.97249985], [80.94249725, 24.97113991], [80.94484711, 24.96800995], [80.9467392, 24.96114159], [80.94668579, 24.95691109], [80.94386292, 24.95070076], [80.94481659, 24.94713974], [80.9498291, 24.94638062], [80.9522171, 24.94288063], [80.95287323, 24.93943977], [80.95111084, 24.92702293], [80.95523071, 24.92571068], [80.95838928, 24.93224907], [80.96566772, 24.93861961], [80.97225952, 24.9396019], [80.97928619, 24.93807983], [80.97792816, 24.93315125], [80.98101044, 24.9296608], [80.98448944, 24.93258095], [80.99124146, 24.93712044], [80.99672699, 24.93959045], [81.00002289, 24.94021034], [81.0087204, 24.93246078], [81.0118866, 24.9332428], [81.01467133, 24.93160057], [81.01677704, 24.93246078], [81.01799011, 24.93554115], [81.02128601, 24.93712044], [81.02114105, 24.93825912], [81.01531219, 24.94005966], [81.01258087, 24.94371986], [81.00715637, 24.95262909], [81.00952911, 24.95432091], [81.01698303, 24.94643974], [81.01924896, 24.94499969], [81.0207901, 24.94607925], [81.02139282, 24.94839096], [81.01991272, 24.95198059], [81.02320099, 24.95235062], [81.02667236, 24.95496941], [81.04312134, 24.95263863], [81.04715729, 24.9552002], [81.0508194, 24.95527267], [81.05741882, 24.95311928], [81.07641602, 24.95226097], [81.08120728, 24.95021057], [81.08246613, 24.94769096], [81.08049774, 24.9383812], [81.08156586, 24.93575096], [81.08487701, 24.93435287], [81.08950043, 24.92448044], [81.09449768, 24.92378044], [81.09654236, 24.92253113], [81.09871674, 24.91843033], [81.10381317, 24.91270065], [81.10748291, 24.91214752], [81.11073303, 24.91068077], [81.11292267, 24.90552139], [81.11678314, 24.90182114], [81.12265015, 24.89870071], [81.1281662, 24.89361954], [81.13244629, 24.89207077], [81.1342392, 24.89384079], [81.13289642, 24.90050125], [81.13331604, 24.90557098], [81.14008331, 24.91643906], [81.14272308, 24.91736984], [81.14813995, 24.91768074], [81.15231323, 24.91628075], [81.15249634, 24.91962242], [81.15090179, 24.92374039], [81.15116119, 24.92720985], [81.15233612, 24.92937279], [81.15548706, 24.9319706], [81.15602112, 24.93982124], [81.15779877, 24.94267082], [81.1568985, 24.94571114], [81.15956116, 24.95473289], [81.16143036, 24.95851135], [81.16419983, 24.95976257], [81.16967773, 24.95675087], [81.17212677, 24.95350075], [81.17658997, 24.95496941], [81.18062592, 24.94945908], [81.1884079, 24.94505119], [81.19895935, 24.93473816], [81.19828033, 24.93404961], [81.19303894, 24.93461037], [81.18441772, 24.9292202], [81.19579315, 24.92900848], [81.19948578, 24.92694092], [81.20249939, 24.92780113], [81.20729828, 24.93110275], [81.21098328, 24.93259048], [81.21260834, 24.93452072], [81.21148682, 24.93622971], [81.20749664, 24.93725014], [81.20600128, 24.9392395], [81.20437622, 24.95047951], [81.20639038, 24.95408058], [81.20600891, 24.95808983], [81.20407867, 24.96284103], [81.20001221, 24.96685028], [81.20127869, 24.97026253], [81.21230316, 24.97774124], [81.21273041, 24.98166275], [81.21129608, 24.98680115], [81.20733643, 24.9912796], [81.2016983, 24.99572945], [81.20381927, 24.99755287], [81.20482635, 25.00280952], [81.20511627, 25.00311089], [81.20581055, 25.00342941], [81.20641327, 25.00374031], [81.20735931, 25.0035305], [81.20854187, 25.00312042], [81.20900726, 25.00291824], [81.20974731, 25.0021801], [81.21016693, 25.00181961], [81.21070099, 25.00165939], [81.2113266, 25.00169182], [81.21656799, 25.00444984], [81.22023773, 25.0072403], [81.22309875, 25.01132965], [81.23069, 25.0180912], [81.23600769, 25.02930069], [81.23921204, 25.03136063], [81.2425766, 25.03630066], [81.24756622, 25.04149246], [81.25229645, 25.05257988], [81.25338745, 25.05443001], [81.25602722, 25.05571938], [81.25527191, 25.06082916], [81.26158905, 25.06846046], [81.26222229, 25.0728302], [81.25997925, 25.07562256], [81.25302887, 25.07904816], [81.25911713, 25.08730125], [81.25443268, 25.09270096], [81.25206757, 25.09857941], [81.24878693, 25.10071945], [81.24648285, 25.10326958], [81.24569702, 25.10554123], [81.24812317, 25.1117382], [81.25617981, 25.11454964], [81.25795746, 25.1168499], [81.25817871, 25.12363243], [81.25683594, 25.12862968], [81.262146, 25.13108063], [81.25974274, 25.14118195], [81.26122284, 25.1439209], [81.26146698, 25.14434814], [81.26558685, 25.14487076], [81.27059174, 25.14843941], [81.27477264, 25.15341949], [81.27390289, 25.15836906], [81.26864624, 25.16518974], [81.26911926, 25.16773987], [81.27143097, 25.16893959], [81.27522278, 25.16899109], [81.28147888, 25.1654892], [81.28468323, 25.16530991], [81.29133606, 25.16679764], [81.29254913, 25.16798019], [81.30487061, 25.16745949], [81.30638885, 25.16599274], [81.30699921, 25.15966988], [81.30429077, 25.14529037], [81.30490112, 25.14307022], [81.30802155, 25.1388607], [81.30657959, 25.13517189], [81.30696869, 25.13339043], [81.30880737, 25.13158989], [81.30838776, 25.12583923], [81.31005096, 25.12402916], [81.31195068, 25.12343025], [81.31302643, 25.11741066], [81.31466675, 25.11629105], [81.31700897, 25.1160183], [81.31830597, 25.11684036], [81.31852722, 25.11869049], [81.32301331, 25.11839294], [81.32221222, 25.12072945], [81.32026672, 25.1224308], [81.31678009, 25.12808037], [81.31598663, 25.1350708], [81.31680298, 25.14066124], [81.31225586, 25.14621925], [81.31096649, 25.14896011], [81.31073761, 25.15263939], [81.31297302, 25.16354752], [81.31964111, 25.1680603], [81.32995605, 25.17249107], [81.33103943, 25.16955757], [81.33603668, 25.16634941], [81.34459686, 25.16547012], [81.34941101, 25.16735077], [81.35089874, 25.16391945], [81.3533783, 25.16147995], [81.35549927, 25.15764999], [81.35720825, 25.15232086], [81.36251068, 25.14571953], [81.36560822, 25.14425087], [81.36643982, 25.14172935], [81.36453247, 25.13929749], [81.36450958, 25.13785934], [81.36688232, 25.13743973], [81.37428284, 25.13877106], [81.37898254, 25.13445091], [81.3843689, 25.13508034], [81.38652039, 25.13393021], [81.38500214, 25.1301403], [81.38722992, 25.12895012], [81.38903046, 25.12426186], [81.39122009, 25.1231308], [81.39753723, 25.12170029], [81.4005661, 25.1217308], [81.40431976, 25.12216759], [81.40624237, 25.12339973], [81.40667725, 25.1251297], [81.40181732, 25.13082123], [81.40020752, 25.13380051], [81.41326904, 25.13169098], [81.41604614, 25.13228035], [81.41783905, 25.13517189], [81.41970062, 25.13560295], [81.42778015, 25.13360977], [81.43022156, 25.13363075], [81.42913818, 25.12953949], [81.43437195, 25.12194061], [81.43856812, 25.11400032], [81.43910217, 25.11198997], [81.43833923, 25.11044121], [81.43546295, 25.11103821], [81.42717743, 25.1106205], [81.41147614, 25.11230087], [81.40689087, 25.11201859], [81.40300751, 25.1115799], [81.400383, 25.10914993], [81.40084839, 25.10777092], [81.40306854, 25.10640907], [81.41314697, 25.10399055], [81.42082977, 25.1015892], [81.42479706, 25.09943962], [81.436409, 25.09616089], [81.4588623, 25.09299088], [81.45781708, 25.08934975], [81.45829773, 25.08677101], [81.46539307, 25.08184052], [81.47305298, 25.08093071], [81.47740173, 25.07925034], [81.48118591, 25.07590294], [81.4837265, 25.07493973], [81.4851532, 25.0775795], [81.4864502, 25.08410072], [81.49224091, 25.08192062], [81.49462128, 25.08210945], [81.49740601, 25.09604073], [81.4942627, 25.10169983], [81.50054932, 25.10083008], [81.50286865, 25.10172081], [81.50701904, 25.10532188], [81.50757599, 25.10680962], [81.50319672, 25.11051941], [81.49314117, 25.11065292], [81.48562622, 25.11586952], [81.48171997, 25.11732101], [81.47772217, 25.12108994], [81.47812653, 25.12792015], [81.4720459, 25.13303947], [81.47175598, 25.13499069], [81.4728775, 25.1371212], [81.4746933, 25.13812065], [81.47743225, 25.13842964], [81.4801712, 25.13770103], [81.48452759, 25.13434982], [81.48960876, 25.13422012], [81.49054718, 25.13504028], [81.48995972, 25.14191818], [81.49199677, 25.14875984], [81.4954071, 25.15234947], [81.50063324, 25.1528492], [81.50496674, 25.15122032], [81.51091003, 25.14840126], [81.51566315, 25.14533997], [81.51846313, 25.14254761], [81.52465057, 25.14364052], [81.525177, 25.14753151], [81.51873779, 25.15183067], [81.5199585, 25.15365982], [81.52884674, 25.16133118], [81.53000641, 25.16333961], [81.52728271, 25.16662025], [81.51074219, 25.17368126], [81.5078125, 25.17625046], [81.50711823, 25.17854118], [81.50778961, 25.18497086], [81.50956726, 25.18703079], [81.5128479, 25.18790054], [81.52007294, 25.1872406], [81.52321625, 25.1857605], [81.53253937, 25.18542099], [81.53333282, 25.18756104], [81.53401184, 25.18826103], [81.53991699, 25.18765831], [81.54876709, 25.18865013], [81.54902649, 25.18658066], [81.55844116, 25.18919182], [81.56639862, 25.19574928], [81.5716629, 25.1929512], [81.57718658, 25.19129944], [81.58560944, 25.18662071], [81.58799744, 25.1837883], [81.58194733, 25.17033005], [81.58177948, 25.16827011], [81.59657288, 25.16553116], [81.599823, 25.16603088], [81.60114288, 25.16736984], [81.6029129, 25.16588974], [81.60549164, 25.16562843], [81.60703278, 25.16805077], [81.60675812, 25.17057037], [81.60810852, 25.17276955], [81.61000061, 25.17365265], [81.61347198, 25.17052078], [81.61441803, 25.16506958], [81.61737061, 25.16389847], [81.61898804, 25.1596508], [81.61965942, 25.15563965], [81.618927, 25.14908981], [81.61763763, 25.14624977], [81.61506653, 25.14393044], [81.61223602, 25.14660072], [81.61001587, 25.14717102], [81.60430145, 25.14281082], [81.59918213, 25.13982964], [81.59417725, 25.13801193], [81.59211731, 25.13638115], [81.59414673, 25.12951279], [81.59146881, 25.12735939], [81.59102631, 25.12298965], [81.60230255, 25.11750984], [81.60180664, 25.1160183], [81.60280609, 25.11244965], [81.60122681, 25.10021019], [81.60426331, 25.09966278], [81.60639191, 25.10594177], [81.6100769, 25.11170959], [81.61302948, 25.11322975], [81.61483002, 25.1198597], [81.61675262, 25.12261963], [81.62329102, 25.12193108], [81.62506104, 25.12044907], [81.62534332, 25.1178112], [81.62265015, 25.11124039], [81.63195038, 25.10326958], [81.63166046, 25.10148048], [81.62930298, 25.09972954], [81.62583923, 25.09988976], [81.62153625, 25.09836006], [81.62088776, 25.09507942], [81.61486816, 25.09404755], [81.60949707, 25.08515167], [81.60443878, 25.08299065], [81.59591675, 25.08182907], [81.59379578, 25.07979965], [81.59446716, 25.07693291], [81.60280609, 25.07183075], [81.6039505, 25.06954193], [81.60811615, 25.06682014], [81.60971069, 25.06469917], [81.60855103, 25.06331062], [81.60558319, 25.0645504], [81.6032486, 25.06435966], [81.60272217, 25.06304169], [81.60434723, 25.06074905], [81.60852051, 25.05887985], [81.61725616, 25.05712128], [81.62190247, 25.05692101], [81.62525177, 25.06245995], [81.63201141, 25.06147957], [81.63559723, 25.06179047], [81.64418793, 25.06835937], [81.64598083, 25.07055092], [81.64684296, 25.07504082], [81.65307617, 25.07503128], [81.65650177, 25.07862091], [81.65869141, 25.07973099], [81.65989685, 25.07818031], [81.66040802, 25.07146072], [81.66221619, 25.06513977], [81.66398621, 25.06394958], [81.67137909, 25.06624985], [81.67582703, 25.06598091], [81.67780304, 25.06467819], [81.68306732, 25.0567627], [81.68371582, 25.05079079], [81.6818924, 25.04377174], [81.68553925, 25.04218292], [81.70536041, 25.03790283], [81.71012115, 25.03912926], [81.71338654, 25.04006004], [81.71382141, 25.04725075], [81.71640778, 25.05297279], [81.73239136, 25.04870987], [81.7350769, 25.04452133], [81.73446655, 25.0431385], [81.73723602, 25.04194069], [81.73821259, 25.03907013], [81.74150085, 25.03697014], [81.74646759, 25.0357399], [81.74740601, 25.03362274], [81.74977112, 25.03162193], [81.77139282, 25.02323914], [81.77871704, 25.01762009], [81.78011322, 25.01519012], [81.78922272, 25.01013947], [81.79165649, 25.01000977], [81.82936859, 25.01933289], [81.8349762, 25.01828194], [81.84002686, 25.01497269], [81.84629822, 25.00712013], [81.84938049, 25.00601006], [81.86371613, 25.00357056], [81.86454773, 25.00039291], [81.86683655, 25.00015068], [81.86837006, 25.00222969], [81.8735199, 25.00214005], [81.8813858, 24.99949265], [81.88331604, 24.99365044], [81.88613129, 24.99282074], [81.88772583, 24.99340057], [81.89058685, 24.99636841], [81.89309692, 24.99982071], [81.89402008, 25.00345993], [81.89160919, 25.00505066], [81.88861084, 25.00954819], [81.88822937, 25.01098061], [81.889328, 25.01311111], [81.89142609, 25.0134697], [81.89846802, 25.00962067], [81.89997101, 25.0072403], [81.89994812, 25.00344086], [81.89922333, 24.99924088], [81.89483643, 24.99109077], [81.89450073, 24.98740005], [81.90052032, 24.98483086], [81.90164185, 24.98282051], [81.89845276, 24.97686958], [81.89834595, 24.97532082], [81.90096283, 24.97305107], [81.90410614, 24.94226837], [81.90962219, 24.93714905], [81.91204071, 24.93091965], [81.91030884, 24.9204998], [81.90242004, 24.91150093], [81.89846039, 24.90518188], [81.89879608, 24.8993206], [81.89644623, 24.89250946], [81.90265656, 24.88413048], [81.90628815, 24.88354111], [81.91010284, 24.88043976], [81.91339111, 24.88041115], [81.91513062, 24.87779045], [81.92366791, 24.87627029], [81.92838287, 24.87306023], [81.92672729, 24.86079025], [81.93177032, 24.85649109], [81.93466949, 24.85144997], [81.93718719, 24.85005951], [81.94615173, 24.84671021], [81.94772339, 24.84259033], [81.95488739, 24.83924103], [81.95717621, 24.83213043], [81.95915222, 24.83061028], [81.96156311, 24.83172989], [81.96498108, 24.84142113], [81.96806335, 24.84386063], [81.97544861, 24.84246063], [81.99154663, 24.8465004], [81.99793243, 24.84744072], [82.00489044, 24.85069084], [82.02427673, 24.8446312], [82.03720093, 24.83296013], [82.04232788, 24.83424187], [82.05648804, 24.82807922], [82.06520081, 24.82344055], [82.07084656, 24.82493973], [82.08187103, 24.82211113], [82.08972931, 24.8159008], [82.0946579, 24.81036949], [82.1000061, 24.80994987], [82.10475922, 24.80560112], [82.10769653, 24.8008194], [82.10778809, 24.79368019], [82.11219025, 24.79226112], [82.12637329, 24.79394913], [82.12892151, 24.79976273], [82.13224792, 24.8044796], [82.14657593, 24.79730988], [82.15939331, 24.79226112], [82.16323853, 24.79577065], [82.17336273, 24.80096054], [82.16281128, 24.80498123], [82.17176056, 24.8088398], [82.17373657, 24.81418991], [82.18244171, 24.81678963], [82.18791962, 24.82071114], [82.19596863, 24.82452965], [82.19126892, 24.81772041], [82.18090057, 24.80821991], [82.17900848, 24.80465126], [82.1812973, 24.80084991], [82.18855286, 24.79821968], [82.19491577, 24.79694939], [82.20136261, 24.80065155], [82.20871735, 24.79776955], [82.20545959, 24.79144096], [82.20493317, 24.78550911], [82.20947266, 24.78149033], [82.20179749, 24.7806797], [82.19403839, 24.78326035], [82.18936157, 24.78228188], [82.19129181, 24.77486038], [82.19061279, 24.76955986], [82.19567108, 24.76374817], [82.1914978, 24.75316048], [82.17288208, 24.73957062], [82.18873596, 24.74377823], [82.19512939, 24.73994064], [82.2026062, 24.74078941], [82.20841217, 24.7389698], [82.21375275, 24.72866058], [82.21604919, 24.73615074], [82.21340179, 24.74420929], [82.2022171, 24.74817085], [82.19948578, 24.75206947], [82.20918274, 24.75951004], [82.22280884, 24.7517395], [82.22157288, 24.75991058], [82.21853638, 24.76498032], [82.22091675, 24.76704979], [82.22338867, 24.76417923], [82.22773743, 24.76556015], [82.2323761, 24.75814819], [82.2383728, 24.75440979], [82.24108887, 24.76827049], [82.24031067, 24.77547073], [82.24365997, 24.77575111], [82.24659729, 24.75976181], [82.24962616, 24.75636864], [82.24590302, 24.74065971], [82.24143982, 24.73846054], [82.24101257, 24.7269001], [82.24394989, 24.71638107], [82.24046326, 24.71055984], [82.24304962, 24.70176125], [82.23400116, 24.69656944], [82.2286911, 24.69075966], [82.22885132, 24.67459106], [82.22992706, 24.66963959], [82.23509979, 24.66591072], [82.23420715, 24.67193985], [82.23551941, 24.67638969], [82.24797821, 24.67556953], [82.24952698, 24.66833115], [82.25305176, 24.66609192], [82.26674652, 24.67840958], [82.25834656, 24.68209076], [82.2633667, 24.6864109], [82.2694931, 24.68186951], [82.27851105, 24.68087959], [82.28173828, 24.67174149], [82.28520966, 24.67001152], [82.29107666, 24.67086983], [82.29641724, 24.67001152], [82.29189301, 24.66477966], [82.29808807, 24.65654945], [82.29469299, 24.65385246], [82.29611206, 24.64332008], [82.29579926, 24.63624191], [82.29841614, 24.6280117], [82.29302979, 24.61689949], [82.29393005, 24.61374092], [82.29833984, 24.61242104], [82.30940247, 24.61293983], [82.31530762, 24.61535072], [82.31915283, 24.6202507], [82.32373047, 24.62254906], [82.32977295, 24.62375069], [82.33506012, 24.6229496], [82.34596252, 24.61880112], [82.35051727, 24.60820961], [82.35391998, 24.60447121], [82.36084747, 24.60200119], [82.38564301, 24.59737968], [82.39359283, 24.59749985], [82.40081787, 24.59869957], [82.40917206, 24.59782982], [82.41456604, 24.60639191], [82.40567017, 24.61751175], [82.40789032, 24.62281036], [82.40364838, 24.63097954], [82.40352631, 24.6361618], [82.40904999, 24.64306068], [82.40896606, 24.64956093], [82.41178894, 24.65784836], [82.4054718, 24.66682053], [82.40679932, 24.6744194], [82.40159607, 24.68379974], [82.40738678, 24.69514084], [82.42015076, 24.70525169], [82.43231201, 24.70628166], [82.44484711, 24.69637108], [82.44838715, 24.69062042], [82.44480896, 24.68008995], [82.44885254, 24.67790031], [82.4640274, 24.68007088], [82.47667694, 24.6835804], [82.486763, 24.67550087], [82.501297, 24.67840958], [82.50905609, 24.6790905], [82.51843262, 24.67834091], [82.52398682, 24.65714073], [82.52926636, 24.65196037], [82.54425812, 24.65487862], [82.57396698, 24.66300011], [82.58764648, 24.67373085], [82.60299683, 24.67945099], [82.62996674, 24.68670082], [82.63643646, 24.68783951], [82.64569855, 24.69454956], [82.65792847, 24.70039749], [82.66555023, 24.69986153], [82.68543243, 24.68652153], [82.69230652, 24.68022919], [82.69595337, 24.67572021], [82.69586945, 24.66871262], [82.69345856, 24.66157913], [82.69169617, 24.64863968], [82.6951828, 24.64425278], [82.70207214, 24.64211273], [82.70921326, 24.64371109], [82.71460724, 24.6421299], [82.72746277, 24.64647293], [82.74312592, 24.64406967], [82.76278687, 24.64566994], [82.76580048, 24.64163017], [82.76716614, 24.62943077], [82.76789093, 24.61061287], [82.7629776, 24.60481071], [82.76007843, 24.59981918], [82.76825714, 24.59754181], [82.78542328, 24.59951019], [82.79637146, 24.59976006], [82.79644012, 24.58749962], [82.80076599, 24.55268097], [82.78093719, 24.54606819], [82.74601746, 24.54152107], [82.74536133, 24.55251122], [82.74120331, 24.55459023], [82.73352814, 24.55162048], [82.71611023, 24.55714035], [82.71253204, 24.5562191], [82.7150116, 24.54811096], [82.71414948, 24.53619957], [82.71563721, 24.51329994], [82.73654938, 24.49977112], [82.73377991, 24.48723984], [82.72377014, 24.4763298], [82.73060608, 24.47033119], [82.72602081, 24.46084023], [82.72503662, 24.44473267], [82.72730255, 24.43414116], [82.73271179, 24.43274117], [82.72572327, 24.42625809], [82.72019196, 24.42967987], [82.71936798, 24.42163086], [82.71496582, 24.41617012], [82.70758057, 24.38937759], [82.70716095, 24.38517952], [82.71286011, 24.37520981], [82.71849823, 24.37122154], [82.73478699, 24.37117958], [82.74677277, 24.37252045], [82.7544632, 24.37951088], [82.75688934, 24.37594032], [82.76058197, 24.37304115], [82.75875854, 24.36931038], [82.75892639, 24.36314964], [82.75981903, 24.35838127], [82.76449585, 24.34754944], [82.76326752, 24.34243011], [82.76299286, 24.32982826], [82.76045227, 24.32310104], [82.75981903, 24.31908035], [82.76603699, 24.31220818], [82.76413727, 24.29243088], [82.75705719, 24.27569962], [82.75460815, 24.2716198], [82.75058746, 24.26813126], [82.74938965, 24.25662041], [82.75157166, 24.24586105], [82.74991608, 24.23612976], [82.74331665, 24.23161125], [82.73706055, 24.23031044], [82.73223114, 24.22797012], [82.72699738, 24.22326088], [82.73190308, 24.20107269], [82.73478699, 24.1830101], [82.73613739, 24.16835022], [82.72307587, 24.15681076], [82.72132111, 24.1498127], [82.72036743, 24.1389904], [82.68836212, 24.14422989], [82.6794281, 24.15673065], [82.67085266, 24.15847015], [82.66519928, 24.15112114], [82.66587067, 24.14278984], [82.65738678, 24.13479805], [82.66352844, 24.12392998], [82.70136261, 24.09707069], [82.70522308, 24.0857296], [82.70839691, 24.08076096], [82.72628021, 24.08256912], [82.73768616, 24.07872963], [82.74146271, 24.07509041], [82.74803925, 24.08053017], [82.75174713, 24.07959747], [82.75492096, 24.07324028], [82.76055145, 24.07967949], [82.76625824, 24.07786751], [82.76220703, 24.05988121], [82.75576782, 24.04359818], [82.74314117, 24.03487968], [82.73992157, 24.03104973], [82.74199677, 24.02140045], [82.74588776, 24.01311111], [82.75235748, 24.00843048], [82.76628876, 24.00605011], [82.78266907, 24.00695992], [82.78990173, 24.00677109], [82.79727173, 24.0051403], [82.8014679, 24.00106239], [82.80065155, 23.99655914], [82.80050659, 23.98533058], [82.79872131, 23.97661972], [82.79888153, 23.97089005], [82.80046844, 23.96748161], [82.8077774, 23.96305847], [82.79865265, 23.96218109], [82.79680634, 23.96142006], [82.79210663, 23.95570946], [82.7902832, 23.95061111], [82.77484894, 23.93857002], [82.75377655, 23.93588066], [82.75019836, 23.93005943], [82.75006866, 23.92653275], [82.74810028, 23.92228127], [82.74333191, 23.92064095], [82.71811676, 23.92144966], [82.70667267, 23.92461967], [82.70192719, 23.92493248], [82.68987274, 23.92042923], [82.68900299, 23.91953087], [82.68733978, 23.91777039], [82.68186188, 23.91226959], [82.67708588, 23.90982056], [82.67090607, 23.90977097], [82.66812134, 23.9076004], [82.66290283, 23.90867043], [82.65905762, 23.90863991], [82.65651703, 23.90786171], [82.65473938, 23.90629005], [82.64730072, 23.89499092], [82.64611816, 23.88873291], [82.65727234, 23.87815094], [82.65953064, 23.87458038], [82.66020966, 23.87033844], [82.65795898, 23.86558151], [82.65492249, 23.86271095], [82.65335846, 23.85778046], [82.65202332, 23.85650063], [82.64541626, 23.85782051], [82.64354706, 23.85962105], [82.64064026, 23.85803032], [82.63772583, 23.84988976], [82.63482666, 23.84767914], [82.6312561, 23.84633064], [82.63130188, 23.84168243], [82.6295166, 23.8390007], [82.60591125, 23.83616257], [82.60051727, 23.83391953], [82.58963776, 23.82479095], [82.58598328, 23.82286072], [82.57849121, 23.8224411], [82.56633759, 23.82472992], [82.56115723, 23.82278061], [82.54821777, 23.82690048], [82.54207611, 23.82674026], [82.53874969, 23.82410812], [82.53366089, 23.82499123], [82.52735138, 23.82407951], [82.52910614, 23.82159996], [82.53196716, 23.81982994], [82.53399658, 23.81479836], [82.53690338, 23.81249046], [82.53975677, 23.81182861], [82.54086304, 23.81015015], [82.54399109, 23.80282021], [82.54477692, 23.79831123], [82.54451752, 23.79418945], [82.54026794, 23.79120064], [82.53578949, 23.79210091], [82.52879333, 23.79134941], [82.5161972, 23.78423119], [82.50670624, 23.7854805], [82.4966507, 23.78504944], [82.49175262, 23.78570747], [82.4850769, 23.78837967], [82.48375702, 23.79057121], [82.4826889, 23.79751968], [82.46987915, 23.80764961], [82.46350861, 23.81084824], [82.46002197, 23.81139946], [82.44904327, 23.81165123], [82.44576263, 23.81085968], [82.44023895, 23.80572128], [82.43644714, 23.80470848], [82.42323303, 23.80608749], [82.40296936, 23.80277824], [82.39335632, 23.80241013], [82.38822937, 23.80137062], [82.3839798, 23.80487061], [82.37985229, 23.80704117], [82.36834717, 23.81110001], [82.35658264, 23.80833054], [82.34703064, 23.80371094], [82.3429184, 23.80389977], [82.33854675, 23.8060112], [82.33125305, 23.80536079], [82.32823181, 23.80367088], [82.32096863, 23.80874062], [82.31505585, 23.81030846], [82.31112671, 23.81118965], [82.30715942, 23.81116295], [82.30432129, 23.80986023], [82.29759216, 23.80816078], [82.29511261, 23.80854988], [82.28382874, 23.81290054], [82.27767181, 23.81713104], [82.27121735, 23.81869125], [82.26476288, 23.81874084], [82.25528717, 23.82188988], [82.24855042, 23.81979942], [82.23152924, 23.80779076], [82.22899628, 23.80667114], [82.22614288, 23.80693245], [82.22107697, 23.8100605], [82.21611023, 23.82096291], [82.21160126, 23.82393265], [82.20136261, 23.82829285], [82.1992569, 23.83192062], [82.20096588, 23.83453941], [82.20435333, 23.83712006], [82.20664978, 23.84103012], [82.20687103, 23.84404182], [82.20388794, 23.8529911], [82.19557953, 23.85038185], [82.18933868, 23.84370995], [82.17875671, 23.84204292], [82.17352295, 23.83909035], [82.17249298, 23.8379097], [82.16971588, 23.82467842], [82.1682663, 23.82269287], [82.16525269, 23.82075119], [82.16240692, 23.81995964], [82.15573883, 23.82197762], [82.14456177, 23.81925011], [82.13407898, 23.81816101], [82.12576294, 23.81966972], [82.11746216, 23.82312012], [82.10875702, 23.81868172], [82.10678864, 23.81849098], [82.10018158, 23.82010078], [82.08911133, 23.81789017], [82.07801819, 23.8170681], [82.07202148, 23.81978035], [82.06328583, 23.81911087], [82.04540253, 23.82058907], [82.04234314, 23.82496071], [82.04052734, 23.82632828], [82.03217316, 23.82930946], [82.03100586, 23.83189964], [82.03433228, 23.83867073], [82.03515625, 23.84255981], [82.03251648, 23.84507942], [82.02849579, 23.84770012], [82.01161194, 23.85227966], [82.00759888, 23.85495186], [82.00567627, 23.85880089], [82.00073242, 23.86314011], [81.99214935, 23.86264038], [81.98394012, 23.86199951], [81.97154999, 23.85835075], [81.96238708, 23.85707855], [81.95070648, 23.85289001], [81.94490051, 23.85692978], [81.94004822, 23.85777092], [81.93856049, 23.86096954], [81.93685913, 23.86206245], [81.93390656, 23.86193275], [81.93228149, 23.86261177], [81.93289948, 23.86675072], [81.93164825, 23.86791039], [81.91644287, 23.87298965], [81.91470337, 23.87187958], [81.90983582, 23.8640995], [81.90425873, 23.85852051], [81.90077972, 23.85122108], [81.89807129, 23.84828949], [81.89409637, 23.8440609], [81.88535309, 23.84173965], [81.87843323, 23.83790016], [81.86207581, 23.83481026], [81.85765839, 23.82876968], [81.85293579, 23.82431984], [81.83164978, 23.82130241], [81.82863617, 23.8170929], [81.82411957, 23.81641006], [81.81741333, 23.81124115], [81.81172943, 23.80949974], [81.80564117, 23.81043816], [81.80058289, 23.81355095], [81.79341888, 23.8144207], [81.78748322, 23.8119297], [81.78266144, 23.81184006], [81.77262878, 23.81419945], [81.74518585, 23.83092117], [81.73443604, 23.83619118], [81.7305069, 23.83936119], [81.72685242, 23.84095955], [81.71906281, 23.84042931], [81.71835327, 23.84338951], [81.72141266, 23.8490715], [81.72389221, 23.85071754], [81.72384644, 23.85688972], [81.7230072, 23.85898018], [81.72091675, 23.86082268], [81.71495056, 23.86188126], [81.71253204, 23.86296272], [81.7026825, 23.86339951], [81.70228577, 23.86898994], [81.70297241, 23.87285042], [81.69845581, 23.87799072], [81.69966888, 23.88149071], [81.6973877, 23.88596153], [81.68692017, 23.8849411], [81.68239594, 23.88978958], [81.67949677, 23.90764809], [81.67733002, 23.91024017], [81.66771698, 23.91570091], [81.66491699, 23.92207909], [81.66159821, 23.92559814], [81.65740967, 23.92456818], [81.6516571, 23.91782951], [81.64811707, 23.91616058], [81.6414566, 23.91517067], [81.63728333, 23.91362], [81.62921906, 23.90765953], [81.62451172, 23.90691948], [81.61444855, 23.90827942], [81.61051178, 23.90697289], [81.60756683, 23.90327072], [81.60555267, 23.89585114], [81.60338593, 23.89240074], [81.59690857, 23.88902283], [81.59757996, 23.88624191], [81.60019684, 23.88339806], [81.60874939, 23.87817955], [81.61485291, 23.87277031], [81.61142731, 23.86702919], [81.60620117, 23.86395073], [81.5983429, 23.86421967], [81.59738922, 23.86194038], [81.59738922, 23.85746002], [81.59844208, 23.85367966], [81.60456085, 23.84383965], [81.60497284, 23.84139061], [81.60582733, 23.83820915], [81.60733032, 23.83624077], [81.60942078, 23.83579063], [81.62023163, 23.8368206], [81.62570953, 23.83582115], [81.62811279, 23.83432961], [81.63053894, 23.83081055], [81.63601685, 23.81635094], [81.64256287, 23.80458069], [81.64362335, 23.79889107], [81.64348602, 23.7918396], [81.6383667, 23.77787971], [81.63816833, 23.77478981], [81.63965607, 23.77112961], [81.64415741, 23.76807976], [81.65354919, 23.76427078], [81.66178131, 23.75991058], [81.66932678, 23.75735092], [81.67408752, 23.7539711], [81.67829132, 23.74887085], [81.6733017, 23.74336052], [81.67209625, 23.74002075], [81.67749786, 23.73460007], [81.68234253, 23.72561073], [81.68688965, 23.72262001], [81.68728638, 23.72134972], [81.68464661, 23.71364021], [81.67321014, 23.69343185], [81.64949799, 23.6834507], [81.64795685, 23.66799927], [81.64640808, 23.66320992], [81.64312744, 23.66033173], [81.63500977, 23.65896988], [81.61849213, 23.66138077], [81.6132431, 23.66098022], [81.60951233, 23.63298988], [81.60652161, 23.62445831], [81.60437775, 23.62137032], [81.60108948, 23.61394119], [81.60267639, 23.60003281], [81.59984589, 23.59692192], [81.59480286, 23.59547043], [81.58024597, 23.59679031], [81.57505798, 23.59202194], [81.57077026, 23.59091949], [81.56973267, 23.58864975], [81.57042694, 23.5798111], [81.57444763, 23.56668091], [81.57550812, 23.5587101], [81.57707214, 23.55488968], [81.58392334, 23.5539608], [81.58690643, 23.55451012], [81.60227203, 23.55367279], [81.60569763, 23.55048943], [81.60665131, 23.54496956], [81.60546875, 23.5247612], [81.60632324, 23.52067947], [81.60521698, 23.51088905], [81.60704803, 23.50688934], [81.61443329, 23.49776077], [81.61721802, 23.49486923], [81.62422943, 23.49105072], [81.62822723, 23.4903698], [81.63109589, 23.49174118], [81.63524628, 23.49835968], [81.63717651, 23.49930191], [81.64398956, 23.50012016], [81.64765167, 23.50242996], [81.6536026, 23.51389122], [81.65396118, 23.5199604], [81.65309906, 23.52769279], [81.65453339, 23.53155136], [81.66203308, 23.53243828], [81.66718292, 23.53190041], [81.68187714, 23.5272007], [81.68744659, 23.5244503], [81.69309235, 23.52334023], [81.70638275, 23.53358078], [81.71034241, 23.54124069], [81.7130661, 23.5426693], [81.71675873, 23.54834938], [81.71923065, 23.55605125], [81.72344208, 23.55882835], [81.72595215, 23.56245041], [81.72923279, 23.56509972], [81.73603058, 23.5674305], [81.7407074, 23.56764984], [81.74796295, 23.5653801], [81.75060272, 23.5630703], [81.75361633, 23.55856133], [81.7563858, 23.55252075], [81.76299286, 23.55076981], [81.79756165, 23.54883194], [81.80127716, 23.54776001], [81.80461884, 23.5458107], [81.81104279, 23.53392029], [81.81150818, 23.53067017], [81.81019592, 23.52634048], [81.81006622, 23.52260971], [81.81257629, 23.51762962], [81.81653595, 23.51486015], [81.82717896, 23.5112896], [81.83410645, 23.51216125], [81.85074615, 23.51646042], [81.85507202, 23.51645088], [81.86223602, 23.51387024], [81.86968994, 23.51457024], [81.87935638, 23.51843262], [81.88448334, 23.52248001], [81.89624786, 23.53194809], [81.89997101, 23.5341301], [81.90392303, 23.53508949], [81.9094162, 23.53502274], [81.91375732, 23.53375816], [81.91635895, 23.53209114], [81.92767334, 23.51754951], [81.92829895, 23.51324081], [81.93444824, 23.50555038], [81.94471741, 23.50014114], [81.94893646, 23.49674034], [81.94702911, 23.47548103], [81.94761658, 23.4716301], [81.95033264, 23.46606064], [81.95674133, 23.46336937], [81.96124268, 23.45979118], [81.96660614, 23.45372009], [81.96821594, 23.45036125], [81.9713974, 23.44746971], [81.97190857, 23.44520187], [81.97145844, 23.44164085], [81.9750824, 23.4318409], [81.97338104, 23.42628288], [81.97054291, 23.42387009], [81.97158813, 23.41973114], [81.97360992, 23.41759109], [81.97589111, 23.41557121], [81.97612, 23.41311073], [81.97886658, 23.41152954], [81.98739624, 23.41951942], [81.99191284, 23.41929245], [81.99545288, 23.41559982], [81.99952698, 23.41281128], [82.00977325, 23.42052841], [82.01597595, 23.4235096], [82.01841736, 23.42111969], [82.02324677, 23.41018295], [82.01735687, 23.40806007], [82.01751709, 23.40551949], [82.01992035, 23.4009304], [82.01719666, 23.39639091], [82.01428986, 23.39351082], [82.0136261, 23.39026833], [82.01451874, 23.38791847], [82.02039337, 23.38430023], [82.02323914, 23.38376045], [82.02561188, 23.38593292], [82.02941895, 23.38755035], [82.03285217, 23.38539124], [82.03707123, 23.37955093], [82.04573822, 23.37787056], [82.04923248, 23.37873077], [82.052742, 23.38513947], [82.05396271, 23.39048958], [82.05677032, 23.39353943], [82.06307983, 23.39246941], [82.06929779, 23.39502907], [82.07995605, 23.39719009], [82.08364868, 23.39677238], [82.08512878, 23.39331055], [82.09488678, 23.3985405], [82.09848022, 23.39770126], [82.09876251, 23.39469147], [82.10079193, 23.3907795], [82.10411835, 23.38682175], [82.1051712, 23.38282967], [82.10546112, 23.36928177], [82.10449982, 23.36317825], [82.10788727, 23.35847092], [82.11090088, 23.35584068], [82.11444855, 23.35403061], [82.11844635, 23.35448074], [82.12905121, 23.36103821], [82.13247681, 23.36217117], [82.13783264, 23.3618412], [82.14282227, 23.35440826], [82.1452179, 23.34921074], [82.15130615, 23.3455677], [82.15358734, 23.34249115], [82.15553284, 23.33548927], [82.15808105, 23.33332062], [82.16007996, 23.33218956], [82.179039, 23.3270607], [82.18428802, 23.32689095], [82.18585968, 23.32538986], [82.18750763, 23.32222939], [82.18998718, 23.31153107], [82.18884277, 23.30873108], [82.18990326, 23.30348969], [82.188797, 23.29837036], [82.1869812, 23.29499054], [82.1869812, 23.29023933], [82.18946075, 23.28458977], [82.18638611, 23.27765846], [82.18419647, 23.27526283], [82.17402649, 23.27248955], [82.16982269, 23.27017975], [82.1681366, 23.2674408], [82.16652679, 23.26140022], [82.1598587, 23.25291824], [82.15953064, 23.24915123], [82.15371704, 23.24596977], [82.14698792, 23.23191833], [82.14248657, 23.22770119], [82.14292908, 23.22237968], [82.14634705, 23.21384048], [82.14665985, 23.20944977], [82.14057159, 23.19807053], [82.1401825, 23.19034958], [82.13765717, 23.18812943], [82.13698578, 23.18279839], [82.1374588, 23.18020058], [82.14095306, 23.17848969], [82.14170837, 23.17473984], [82.13790131, 23.16833115], [82.13732147, 23.1649704], [82.1401062, 23.16372108], [82.14494324, 23.16314125], [82.15138245, 23.16055107], [82.15376282, 23.158041], [82.15406799, 23.15114021], [82.15107727, 23.1417408], [82.13276672, 23.13162041], [82.13098907, 23.12895012], [82.12961578, 23.12507057], [82.12924194, 23.11403084], [82.12825012, 23.11211014], [82.11936188, 23.10746956], [82.11588287, 23.10379982], [82.10951996, 23.10548973], [82.10164642, 23.10851097], [82.08590698, 23.10925293], [82.0791626, 23.1121006], [82.07550812, 23.11215019], [82.07189178, 23.11359978], [82.06912231, 23.11488914], [82.06713104, 23.11681747], [82.06137085, 23.11594009], [82.04767609, 23.10335922], [82.04567719, 23.09910965], [82.03952026, 23.09151077], [82.02825165, 23.08166122], [82.024086, 23.08012009], [82.01616669, 23.07933044], [82.01278687, 23.07929993], [82.0102005, 23.08061981], [82.00218964, 23.07840919], [81.99680328, 23.08032036], [81.99253845, 23.08489037], [81.99048615, 23.08467102], [81.98545837, 23.08613014], [81.98214722, 23.08624268], [81.97997284, 23.08554268], [81.9748764, 23.08176041], [81.97215271, 23.08140945], [81.96930695, 23.0793705], [81.96507263, 23.08037186], [81.96127319, 23.08018112], [81.95262909, 23.07645035], [81.93810272, 23.07781029], [81.93747711, 23.07658005], [81.93786621, 23.06960106], [81.93501282, 23.0668602], [81.92608643, 23.06221008], [81.92394257, 23.05829811], [81.92138672, 23.04746056], [81.91842651, 23.04097939], [81.91941833, 23.03668022], [81.92597198, 23.02854156], [81.92707062, 23.02603912], [81.92679596, 23.02238083], [81.93229675, 23.01742172], [81.93721771, 23.00949287], [81.93701172, 23.00329971], [81.9385376, 23.00081062], [81.93844604, 22.99165154], [81.94120789, 22.98494911], [81.94241333, 22.97526932], [81.94256592, 22.96453094], [81.94024658, 22.95709038], [81.93327332, 22.95476151], [81.92797852, 22.95420074], [81.92344666, 22.9511795], [81.91385651, 22.94822121], [81.90567017, 22.94046021], [81.90146637, 22.93305969], [81.89488983, 22.92817116], [81.88654327, 22.9251709], [81.88027954, 22.91986084], [81.8746109, 22.91332054], [81.87050629, 22.91184044], [81.86000824, 22.91500092], [81.86194611, 22.90460968], [81.86110687, 22.89394951], [81.85634613, 22.8908596], [81.83558655, 22.88647079], [81.83142853, 22.88297081], [81.82644653, 22.88227081], [81.82065582, 22.88286018], [81.79582977, 22.88025093], [81.78592682, 22.87708092], [81.76940155, 22.87350845], [81.77005005, 22.86042976], [81.76931763, 22.85116005], [81.7648468, 22.84069061], [81.76085663, 22.83433914], [81.76159668, 22.82933044], [81.77300262, 22.8091507], [81.77590179, 22.80013847], [81.77440643, 22.78560066], [81.78128052, 22.7747097], [81.78427887, 22.76662064], [81.77815247, 22.75803947], [81.76397705, 22.74677086], [81.76277924, 22.74151039], [81.76249695, 22.73530006], [81.74912262, 22.73316956], [81.74661255, 22.72648811], [81.74833679, 22.71953964], [81.7559433, 22.69765091], [81.76288605, 22.68535995], [81.76597595, 22.67612076], [81.76506042, 22.66905975], [81.76272583, 22.66358948], [81.74893188, 22.64607048], [81.74053955, 22.64806938], [81.73934937, 22.6613903], [81.73693848, 22.66905022], [81.73014069, 22.67327118], [81.72294617, 22.6762104], [81.71962738, 22.67002106], [81.71800232, 22.66373062], [81.71411133, 22.65563011], [81.70701599, 22.64964104], [81.6988678, 22.64588165], [81.68839264, 22.64663124], [81.6785965, 22.64888], [81.66316223, 22.63272095], [81.65654755, 22.63200188], [81.65479279, 22.62158966], [81.64840698, 22.6199894], [81.64353943, 22.61440086], [81.64138794, 22.60754013], [81.64163208, 22.59209061], [81.64012146, 22.58654976], [81.64441681, 22.58337975], [81.64942169, 22.57608032], [81.64868927, 22.56895065], [81.64565277, 22.56589127], [81.63791656, 22.5621109], [81.63250732, 22.56199837], [81.6235733, 22.56427765], [81.61940765, 22.55855942], [81.61942291, 22.55327988], [81.62136078, 22.5477829], [81.62188721, 22.54383087], [81.61579132, 22.53902054], [81.60896301, 22.5364399], [81.59976959, 22.53570938], [81.59274292, 22.53765106], [81.58795929, 22.54403114], [81.5831604, 22.54453087], [81.5697403, 22.55005074], [81.56305695, 22.55100822], [81.55741882, 22.54689026], [81.55731201, 22.53759003], [81.56278229, 22.53417969], [81.55693054, 22.53216171], [81.54720306, 22.53126144], [81.54222107, 22.52992058], [81.53595734, 22.53324127], [81.52797699, 22.53979111], [81.51906586, 22.53998184], [81.51541901, 22.53675079], [81.51467133, 22.53403091], [81.5147171, 22.52869034], [81.51197052, 22.52352905], [81.50656128, 22.52177811], [81.50293732, 22.52679062], [81.49320984, 22.5196209], [81.49175262, 22.51733017], [81.49011993, 22.50843048], [81.48574829, 22.5033493], [81.4798584, 22.49331093], [81.47637177, 22.4921608], [81.46996307, 22.49398994], [81.46067047, 22.49435806], [81.45330811, 22.4910202], [81.44624329, 22.49586105], [81.43805695, 22.49394035], [81.43908691, 22.4910202], [81.44422913, 22.48702049], [81.44081116, 22.48464966], [81.43907928, 22.47947121], [81.44391632, 22.47867012], [81.44332886, 22.47154045], [81.45028687, 22.47256279], [81.44802856, 22.46739006], [81.44246674, 22.46615982], [81.43595886, 22.46948814], [81.43357086, 22.47771835], [81.43177795, 22.48049164], [81.42443848, 22.47923851], [81.41758728, 22.47363091], [81.41783142, 22.46515083], [81.42064667, 22.45940018], [81.41893005, 22.45421982], [81.41411591, 22.44852066], [81.39655304, 22.44132042], [81.38887024, 22.44483948], [81.38617706, 22.45116043], [81.38305664, 22.46260262], [81.38479614, 22.47784042], [81.38067627, 22.48534966], [81.37914276, 22.49339104], [81.37960815, 22.49790955], [81.3787384, 22.50530052], [81.37325287, 22.51075172], [81.36650085, 22.51436996], [81.36177826, 22.5153904], [81.35569, 22.51324272], [81.34794617, 22.51408958], [81.33188629, 22.52236938], [81.32293701, 22.52433014], [81.31939697, 22.51955032], [81.31481171, 22.5159111], [81.31414795, 22.4996109], [81.31591034, 22.48970985], [81.30396271, 22.48175049], [81.2977829, 22.4865799], [81.29170227, 22.48931122], [81.28019714, 22.49882126], [81.27546692, 22.49944115], [81.27146912, 22.49584961], [81.26674652, 22.49414063], [81.26045227, 22.49356079], [81.25623322, 22.48806953], [81.25551605, 22.47248268], [81.24038696, 22.45918083], [81.23310852, 22.45513153], [81.22355652, 22.45160866], [81.21839142, 22.45165062], [81.2097702, 22.45384979], [81.20214081, 22.45676994], [81.19419098, 22.46208], [81.19503784, 22.46775818], [81.1932373, 22.47370911], [81.19264221, 22.4824791], [81.18686676, 22.48921013], [81.18004608, 22.49015045], [81.17066193, 22.48800087], [81.16407013, 22.48191071], [81.15782166, 22.47448158], [81.14807892, 22.4558506], [81.13404083, 22.45199966], [81.12275696, 22.44762039], [81.10999298, 22.44112015], [81.10491943, 22.43279076], [81.10346985, 22.42208099], [81.1046524, 22.41080284], [81.10266113, 22.39126968], [81.10093689, 22.38323975], [81.1068573, 22.36218071], [81.11054993, 22.35300064], [81.11566162, 22.34408951], [81.1120224, 22.3346405], [81.10926819, 22.32963943], [81.11045837, 22.32149124], [81.11470032, 22.31258965], [81.11501312, 22.30323982], [81.11384583, 22.29438019], [81.09681702, 22.2774601], [81.09178162, 22.26786041], [81.08467865, 22.24674988], [81.07258606, 22.24174118], [81.06923676, 22.24625969], [81.06282043, 22.24685287], [81.05452728, 22.24387169], [81.04886627, 22.24419022], [81.04043579, 22.24057007], [81.03631592, 22.23771858], [81.01944733, 22.22919083], [81.01570892, 22.22021103], [81.01579285, 22.21410942], [81.01922607, 22.20779037], [81.02349091, 22.20282936], [81.02575684, 22.19769096], [81.02477264, 22.19313049], [81.02511597, 22.18882179], [81.02150726, 22.18703079], [81.01551056, 22.18840981], [81.01169586, 22.18400955], [81.01328278, 22.17749023], [81.01715088, 22.17103958], [81.0190506, 22.16526031], [81.01761627, 22.15384865], [81.01740265, 22.14027977], [81.01579285, 22.1327095], [81.00517273, 22.13272285], [80.992836, 22.13153076], [80.98670197, 22.13087082], [80.97342682, 22.12368965], [80.97175598, 22.12148094], [80.97081757, 22.11465073], [80.97226715, 22.11189079], [80.97432709, 22.11136055], [80.97666931, 22.11280823], [80.98020935, 22.11280823], [80.98725128, 22.11065102], [80.99027252, 22.10907936], [80.99282074, 22.10519028], [81.00006866, 22.10083008], [81.00369263, 22.0968895], [81.00395203, 22.0944519], [80.99991608, 22.08965111], [80.99742889, 22.08086967], [81.00427246, 22.07002068], [80.99916077, 22.06150055], [80.99282074, 22.05766106], [80.99117279, 22.05808067], [80.98972321, 22.05649757], [80.98808289, 22.05220985], [80.98776245, 22.04847908], [80.98259735, 22.04895973], [80.97885132, 22.04831123], [80.97364044, 22.05177116], [80.97181702, 22.05429077], [80.96341705, 22.05836105], [80.96208954, 22.0619297], [80.96573639, 22.07917023], [80.96553802, 22.08197975], [80.95752716, 22.0971508], [80.95052338, 22.11301041], [80.94552612, 22.11748123], [80.93891907, 22.11901093], [80.92479706, 22.12067032], [80.9171524, 22.12088966], [80.9108429, 22.1191597], [80.90608978, 22.11444092], [80.89817047, 22.1013298], [80.8947525, 22.07650948], [80.89122772, 22.06595993], [80.88844299, 22.06241035], [80.88498688, 22.06071091], [80.87895966, 22.06060028], [80.87663269, 22.0567894], [80.87735748, 22.05071259], [80.87011719, 22.03858948], [80.86894989, 22.03359032], [80.86950684, 22.01650047], [80.86859894, 22.01120949], [80.85933685, 22.0001297], [80.85929871, 21.99776077], [80.85840607, 21.99543953], [80.85719299, 21.99324036], [80.85640717, 21.99185181], [80.85546875, 21.98880959], [80.85456848, 21.9872303], [80.85312653, 21.98348045], [80.85309601, 21.98129272], [80.85253143, 21.97841072], [80.8516922, 21.97512054], [80.85037231, 21.97281075], [80.84851074, 21.97001076], [80.84745026, 21.96690941], [80.84673309, 21.96362114], [80.84577179, 21.96089935], [80.8433609, 21.95841026], [80.83938599, 21.95774078], [80.83583832, 21.95761108], [80.83178711, 21.95794106], [80.82885742, 21.95743942], [80.8245163, 21.95684052], [80.82168579, 21.95819855], [80.82022095, 21.95813179], [80.8184433, 21.95679092], [80.81958771, 21.95356941], [80.82102966, 21.95145035], [80.82115936, 21.95058823], [80.82221985, 21.94835091], [80.82338715, 21.94732094], [80.82627106, 21.94711113], [80.8289566, 21.94701958], [80.83074188, 21.94719124], [80.83184814, 21.9474411], [80.83338928, 21.94664001], [80.83502197, 21.94089127], [80.83561707, 21.93703079], [80.83656311, 21.93565941], [80.83654022, 21.93180084], [80.83589935, 21.92793083], [80.83452606, 21.92601967], [80.83251953, 21.92175102], [80.83139038, 21.92012024], [80.83006287, 21.91843033], [80.82699585, 21.91358185], [80.82620239, 21.9119606], [80.82453156, 21.9084301], [80.82544708, 21.90388107], [80.82380676, 21.89788055], [80.82456207, 21.89470863], [80.82422638, 21.89103127], [80.82405853, 21.88936043], [80.82543945, 21.88665009], [80.83010864, 21.88479042], [80.83141327, 21.88427925], [80.83406067, 21.88249969], [80.83660126, 21.87854958], [80.83959198, 21.87540054], [80.8396759, 21.87158012], [80.83763885, 21.86881256], [80.83666229, 21.86701965], [80.83702087, 21.86248016], [80.83994293, 21.85881042], [80.84117126, 21.85645294], [80.84041595, 21.85276031], [80.837677, 21.8518219], [80.8343277, 21.85069847], [80.83289337, 21.8490696], [80.8316803, 21.8461895], [80.83230591, 21.84013939], [80.83280945, 21.83749962], [80.83368683, 21.83479118], [80.83587646, 21.83214951], [80.83709717, 21.83176041], [80.837677, 21.82985115], [80.83660126, 21.82719994], [80.83558655, 21.82454109], [80.83380127, 21.8202095], [80.83304596, 21.81691933], [80.83238983, 21.81380081], [80.83183289, 21.81057167], [80.83171082, 21.80867004], [80.83170319, 21.80480957], [80.82990265, 21.80070114], [80.82797241, 21.79682159], [80.82550049, 21.79450035], [80.82388306, 21.79091072], [80.82110596, 21.78697968], [80.82081604, 21.78478813], [80.82041931, 21.78226089], [80.81918335, 21.77815819], [80.8182373, 21.77601051], [80.81682587, 21.77421761], [80.81446075, 21.76832008], [80.81355286, 21.76749992], [80.81156158, 21.7639904], [80.8106308, 21.7610302], [80.81044769, 21.75844002], [80.81033325, 21.75538063], [80.8116684, 21.7508297], [80.811203, 21.74749184], [80.80813599, 21.74644089], [80.80362701, 21.74605942], [80.79899597, 21.74535179], [80.79582977, 21.74427032], [80.79258728, 21.74322128], [80.78845978, 21.7412796], [80.78272247, 21.73957062], [80.77709198, 21.74086189], [80.77683258, 21.74430847], [80.7738266, 21.74982071], [80.76982117, 21.75205231], [80.76641846, 21.75513077], [80.76210022, 21.75791931], [80.75874329, 21.75715065], [80.75463867, 21.75700951], [80.74962616, 21.75773048], [80.74503326, 21.75826073], [80.74297333, 21.75796127], [80.74005127, 21.75649071], [80.73841858, 21.75354004], [80.73699951, 21.75065041], [80.73483276, 21.74764061], [80.73101044, 21.73919868], [80.72891235, 21.73516083], [80.72632599, 21.73102951], [80.72580719, 21.72948074], [80.72570801, 21.72578049], [80.72445679, 21.72249031], [80.72387695, 21.71970749], [80.72341919, 21.71747017], [80.72312927, 21.71562004], [80.72267151, 21.71447945], [80.7199173, 21.71364021], [80.71852875, 21.71186066], [80.7197113, 21.7097702], [80.72200775, 21.70730972], [80.72390747, 21.70583153], [80.72490692, 21.70433044], [80.72529602, 21.70100021], [80.72511292, 21.69828987], [80.72492218, 21.69777107], [80.72374725, 21.69360161], [80.72212982, 21.69059944], [80.72027588, 21.6877594], [80.71877289, 21.68481064], [80.71781921, 21.68307114], [80.71631622, 21.68081093], [80.71510315, 21.67867088], [80.71408844, 21.67728043], [80.712883, 21.67584038], [80.71190643, 21.67485046], [80.71089172, 21.67408943], [80.70923615, 21.67361069], [80.70735168, 21.67158127], [80.70874023, 21.66934967], [80.71003723, 21.66773987], [80.70944977, 21.66571045], [80.70749664, 21.66410065], [80.7078476, 21.6619606], [80.70833588, 21.66098976], [80.70909882, 21.65815926], [80.70979309, 21.65615082], [80.71050262, 21.65369034], [80.71045685, 21.65241051], [80.71121979, 21.64907074], [80.71235657, 21.64613914], [80.71463776, 21.64495087], [80.71684265, 21.64427948], [80.71910858, 21.64365959], [80.72049713, 21.64067078], [80.71955872, 21.63663292], [80.71968842, 21.63582039], [80.72025299, 21.63422012], [80.72097015, 21.63047028], [80.72117615, 21.62783051], [80.72210693, 21.62500191], [80.72245789, 21.62276077], [80.72138977, 21.62050056], [80.7216568, 21.61721992], [80.71990967, 21.61461067], [80.71781158, 21.61246109], [80.71617126, 21.60956955], [80.71351624, 21.60741043], [80.71083832, 21.60624123], [80.70939636, 21.60398102], [80.70903015, 21.60075951], [80.70935059, 21.59810066], [80.70915985, 21.59447289], [80.70905304, 21.59238815], [80.70913696, 21.58980942], [80.70923615, 21.58675003], [80.70955658, 21.58478928], [80.71164703, 21.58319092], [80.71253204, 21.58216095], [80.71369934, 21.58130074], [80.71598053, 21.57953072], [80.71689606, 21.57740974], [80.71821594, 21.57476807], [80.71884918, 21.57356071], [80.71953583, 21.57150078], [80.71922302, 21.56814957], [80.71723938, 21.56501961], [80.71608734, 21.56311035], [80.7151413, 21.5615406], [80.71383667, 21.55865097], [80.71354675, 21.55571175], [80.71492767, 21.55455971], [80.71935272, 21.55200005], [80.72087097, 21.5506897], [80.72412109, 21.54673958], [80.72583771, 21.54421043], [80.72807312, 21.54180908], [80.72972107, 21.54002953], [80.73065948, 21.53872108], [80.7308197, 21.53543091], [80.72988129, 21.53144836], [80.72833252, 21.52813911], [80.72702026, 21.52536964], [80.72583008, 21.52218819], [80.72477722, 21.51825905], [80.72442627, 21.51619148], [80.72437286, 21.51185989], [80.72426605, 21.50926018], [80.72429657, 21.50597954], [80.72464752, 21.50223923], [80.72377014, 21.49871063], [80.72197723, 21.4956398], [80.72233582, 21.49081039], [80.72426605, 21.48794174], [80.72583771, 21.48437119], [80.72727203, 21.48074913], [80.72824097, 21.4769001], [80.72891235, 21.47460175], [80.73021698, 21.47205162], [80.72911072, 21.46825981], [80.72770691, 21.46329117], [80.72624207, 21.45786095], [80.72392273, 21.45317078], [80.72120667, 21.44940186], [80.71803284, 21.44540024], [80.71482086, 21.44226074], [80.71209717, 21.43942833], [80.70818329, 21.43621063], [80.70423126, 21.43365288], [80.70162964, 21.43138123], [80.69904327, 21.42974091], [80.69754791, 21.42719841], [80.69764709, 21.42259026], [80.6985321, 21.41913033], [80.6992569, 21.41411972], [80.69814301, 21.41117859], [80.69706726, 21.40858078], [80.69507599, 21.4057312], [80.69287109, 21.40145111], [80.69335175, 21.39817047], [80.69326782, 21.3937912], [80.69165039, 21.38818169], [80.68946838, 21.3842392], [80.68781281, 21.38008118], [80.68583679, 21.37683105], [80.68416595, 21.37261009], [80.68097687, 21.36919022], [80.67827606, 21.36623001], [80.67517853, 21.36355019], [80.67150879, 21.35856056], [80.66998291, 21.35423088], [80.66845703, 21.34856987], [80.66638184, 21.34428978], [80.66494751, 21.34093285], [80.66291809, 21.3373394], [80.66130066, 21.33547974], [80.65991211, 21.3344326], [80.65653229, 21.3307724], [80.65177155, 21.33119011], [80.65042877, 21.32993126], [80.64829254, 21.32637978], [80.64438629, 21.32547951], [80.63817596, 21.32485962], [80.63356018, 21.32418823], [80.63179016, 21.32372093], [80.62832642, 21.32258987], [80.62491608, 21.32182121], [80.62328339, 21.32146072], [80.6206665, 21.32015991], [80.61775208, 21.31917191], [80.61299133, 21.32034111], [80.61096191, 21.32170105], [80.61009216, 21.32262039], [80.60851288, 21.32393265], [80.60531616, 21.3243103], [80.60234833, 21.32372093], [80.59941101, 21.32323074], [80.59739685, 21.32349968], [80.59316254, 21.32479095], [80.59127045, 21.32674026], [80.58946991, 21.32834053], [80.58672333, 21.32946014], [80.58307648, 21.33116913], [80.58188629, 21.33432961], [80.58241272, 21.33722115], [80.58162689, 21.34159088], [80.58027649, 21.34210014], [80.57788849, 21.34300041], [80.57543945, 21.34379005], [80.57176971, 21.34560966], [80.5690918, 21.34443092], [80.56636047, 21.34280014], [80.56417847, 21.34277916], [80.56136322, 21.3433094], [80.56053925, 21.34546089], [80.55982971, 21.34856987], [80.5580368, 21.35103035], [80.5583725, 21.35316277], [80.56109619, 21.35440254], [80.56376648, 21.35573959], [80.56417084, 21.3578701], [80.55967712, 21.36038017], [80.55901337, 21.36112976], [80.55821991, 21.36128807], [80.55519867, 21.36271095], [80.55023193, 21.36474037], [80.54577637, 21.36626053], [80.54424286, 21.3672905], [80.54091644, 21.36812019], [80.53964996, 21.36852074], [80.53688049, 21.36913109], [80.53424835, 21.37205124], [80.53311157, 21.37486076], [80.53203583, 21.37728119], [80.52971649, 21.38095093], [80.5268631, 21.38166809], [80.52420044, 21.3837204], [80.52166748, 21.38734055], [80.52037048, 21.38825035], [80.51943207, 21.38957024], [80.51651001, 21.39051819], [80.5147171, 21.39101982], [80.51140594, 21.39186096], [80.50887299, 21.39109039], [80.50569153, 21.39072037], [80.50289154, 21.39058113], [80.50055695, 21.3907795], [80.49633026, 21.39294052], [80.49343872, 21.39423943], [80.48989868, 21.39635086], [80.48549652, 21.39763832], [80.48396301, 21.3972702], [80.48145294, 21.39697075], [80.47897339, 21.39590836], [80.47561646, 21.39472961], [80.47476196, 21.39575005], [80.47387695, 21.3993206], [80.47135162, 21.39583969], [80.4681778, 21.39524078], [80.46676636, 21.39557076], [80.46431732, 21.39590073], [80.46285248, 21.39635086], [80.46016693, 21.3970108], [80.45635986, 21.39870071], [80.45475006, 21.39966011], [80.45333862, 21.40036011], [80.45069885, 21.40234947], [80.44831848, 21.4023304], [80.44764709, 21.39846039], [80.44706726, 21.39557076], [80.44558716, 21.39256096], [80.44426727, 21.39052963], [80.44320679, 21.38799286], [80.44329071, 21.38463974], [80.44374847, 21.37969017], [80.44364166, 21.37639999], [80.44294739, 21.37379837], [80.4404068, 21.37210083], [80.4372406, 21.37137985], [80.43560791, 21.37125015], [80.43353271, 21.37118149], [80.43048096, 21.37189293], [80.42758179, 21.37290955], [80.42685699, 21.37308121], [80.42494202, 21.37450027], [80.422966, 21.37524033], [80.42095184, 21.37568283], [80.41760254, 21.37565041], [80.41407776, 21.37527275], [80.41028595, 21.37545967], [80.40844727, 21.3760891], [80.40656281, 21.37640953], [80.40444183, 21.37581062]]]}}, {\\\"id\\\": \\\"17\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.20_1\\\", \\\"HASC_1\\\": \\\"IN.MH\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Maharashtra\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 81.3, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1861.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 844.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2706.0, \\\"geo-id\\\": 17, \\\"hpm25_child_popweighted\\\": 110.2, \\\"hpm25_female_popweighted\\\": 126.7, \\\"hpm25_male_popweighted\\\": 91.2, \\\"location\\\": \\\"Maharashtra\\\", \\\"mort_apm25_6cod_mean_total\\\": 68251.0, \\\"mort_hpm25_6cod_mean_total\\\": 30494.0, \\\"mort_tpm25_6cod_mean_total\\\": 98746.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[73.45597076, 15.88986206], [73.45597076, 15.88958359], [73.45625305, 15.88958359], [73.45625305, 15.88930607], [73.45652771, 15.88931179], [73.45652771, 15.88875198], [73.45680237, 15.88875198], [73.45680237, 15.88708115], [73.45625305, 15.88708305], [73.45625305, 15.88736057], [73.45597076, 15.88736057], [73.45597076, 15.88764191], [73.45569611, 15.88764191], [73.45569611, 15.88792038], [73.45541382, 15.88791847], [73.45541382, 15.88819313], [73.4548645, 15.88819313], [73.4548645, 15.88847446], [73.45458221, 15.88847446], [73.45458221, 15.88958359], [73.4548645, 15.88958359], [73.4548645, 15.88986206], [73.45597076, 15.88986206]]], [[[73.46263885, 15.89041996], [73.46263885, 15.89015102], [73.46347046, 15.89015102], [73.46347046, 15.8898592], [73.4640274, 15.88986206], [73.4640274, 15.88958359], [73.46430206, 15.88958359], [73.46430206, 15.88874912], [73.46457672, 15.88875198], [73.46457672, 15.88708115], [73.46430206, 15.88708305], [73.46430206, 15.88680458], [73.46375275, 15.88680458], [73.46375275, 15.88708305], [73.46347046, 15.88708115], [73.46347046, 15.88792038], [73.4631958, 15.88791847], [73.4631958, 15.88847446], [73.46263885, 15.88847065], [73.46263885, 15.88875198], [73.46180725, 15.88875198], [73.46180725, 15.88903046], [73.46152496, 15.88902664], [73.46152496, 15.88986206], [73.46180725, 15.8898592], [73.46180725, 15.89015102], [73.46208191, 15.89015102], [73.46208191, 15.89041996], [73.46263885, 15.89041996]]], [[[73.46624756, 15.89597225], [73.46624756, 15.89569378], [73.4668045, 15.89569378], [73.4668045, 15.89541626], [73.46708679, 15.89542007], [73.46708679, 15.89513969], [73.46736145, 15.89513969], [73.46736145, 15.89458179], [73.46763611, 15.8945837], [73.46763611, 15.89402771], [73.46736145, 15.89402962], [73.46736145, 15.89347172], [73.46624756, 15.89347172], [73.46624756, 15.89375019], [73.4659729, 15.89375019], [73.4659729, 15.89402962], [73.46569824, 15.89402962], [73.46568298, 15.89431095], [73.46541595, 15.89430618], [73.46541595, 15.89486217], [73.4651413, 15.89486217], [73.4651413, 15.89569378], [73.46541595, 15.89569378], [73.46541595, 15.89597225], [73.46624756, 15.89597225]]], [[[73.44319153, 16.10263824], [73.44319153, 16.10235977], [73.44347382, 16.10236168], [73.44347382, 16.10208321], [73.44374847, 16.10208321], [73.44374847, 16.10180473], [73.44403076, 16.10180473], [73.44403076, 16.10152626], [73.44431305, 16.10153008], [73.44431305, 16.10013962], [73.44403076, 16.10013962], [73.44403076, 16.09986115], [73.44374847, 16.09986115], [73.44374847, 16.09958076], [73.44346619, 16.09958076], [73.44346619, 16.09986115], [73.44319153, 16.09986115], [73.44319153, 16.10013962], [73.44291687, 16.10013962], [73.44291687, 16.10042], [73.44264221, 16.10041618], [73.44264221, 16.10097313], [73.44235992, 16.10097122], [73.44235992, 16.10263824], [73.44319153, 16.10263824]]], [[[73.46013641, 16.04569435], [73.46013641, 16.04541588], [73.4604187, 16.04541969], [73.4604187, 16.04514122], [73.46098328, 16.04514122], [73.46098328, 16.04486084], [73.46152496, 16.04486084], [73.46151733, 16.04458046], [73.46208191, 16.04458427], [73.46208191, 16.0443058], [73.46235657, 16.04430962], [73.46235657, 16.04346275], [73.46208191, 16.04347229], [73.46208191, 16.04319382], [73.46180725, 16.04319382], [73.46180725, 16.04291725], [73.46151733, 16.04292107], [73.46151733, 16.04125023], [73.46180725, 16.04125023], [73.46180725, 16.04071045], [73.46208191, 16.04071045], [73.46208191, 16.04042053], [73.46180725, 16.04042053], [73.46180725, 16.03957939], [73.46152496, 16.03958321], [73.46152496, 16.03902817], [73.46125031, 16.03903008], [73.46125031, 16.0387516], [73.4604187, 16.0387516], [73.4604187, 16.03903008], [73.45986176, 16.03902817], [73.45986176, 16.03930473], [73.4595871, 16.03930473], [73.4595871, 16.03958321], [73.45930481, 16.03958321], [73.45930481, 16.03986168], [73.45903015, 16.03986168], [73.45903015, 16.04014015], [73.45847321, 16.04014015], [73.45847321, 16.04042053], [73.45735931, 16.04042053], [73.45735931, 16.04071045], [73.45707703, 16.04071045], [73.45707703, 16.0418129], [73.45735931, 16.0418129], [73.45735931, 16.04264069], [73.4576416, 16.04263878], [73.4576416, 16.04319382], [73.45791626, 16.04319382], [73.45791626, 16.04347229], [73.45819092, 16.04346275], [73.45819092, 16.04403114], [73.45847321, 16.04403114], [73.45847321, 16.04430962], [73.45874786, 16.0443058], [73.45874786, 16.04569435], [73.46013641, 16.04569435]]], [[[73.03819275, 18.05208397], [73.03819275, 18.05152512], [73.03848267, 18.05153084], [73.03848267, 18.05097961], [73.03874969, 18.05097961], [73.03874969, 18.05014038], [73.0376358, 18.05014038], [73.0376358, 18.05042076], [73.0368042, 18.05041695], [73.0368042, 18.05069351], [73.03652954, 18.0506897], [73.03652954, 18.05153084], [73.03679657, 18.05153084], [73.03679657, 18.05181122], [73.03791809, 18.0518055], [73.03791809, 18.05208397], [73.03819275, 18.05208397]]], [[[72.9659729, 18.30125046], [72.9659729, 18.30014038], [72.96652985, 18.30014038], [72.96652985, 18.29986191], [72.9668045, 18.29986382], [72.9668045, 18.29958344], [72.96708679, 18.29958344], [72.96708679, 18.29930496], [72.96679688, 18.29931068], [72.96679688, 18.2990303], [72.96652985, 18.2990303], [72.96652985, 18.29875183], [72.9659729, 18.29875183], [72.9659729, 18.29846954], [72.96347046, 18.29846954], [72.96347046, 18.2990303], [72.9631958, 18.2990303], [72.9631958, 18.29931068], [72.96291351, 18.29930496], [72.96291351, 18.29986382], [72.96263885, 18.29986191], [72.96263885, 18.30014038], [72.96291351, 18.30013847], [72.96290588, 18.30068016], [72.96375275, 18.30069542], [72.96375275, 18.30097389], [72.96485901, 18.30097008], [72.96485901, 18.30125046], [72.9659729, 18.30125046]]], [[[73.07847595, 18.31014061], [73.07847595, 18.31041908], [73.0790329, 18.31041908], [73.0790329, 18.31014061], [73.07930756, 18.31014061], [73.07930756, 18.30987167], [73.07958221, 18.30987167], [73.07958221, 18.30931091], [73.07985687, 18.30931091], [73.07985687, 18.30903053], [73.07958221, 18.30903053], [73.07958221, 18.30874825], [73.07985687, 18.30874825], [73.07985687, 18.30846977], [73.07958221, 18.30847168], [73.07958221, 18.30708313], [73.07930756, 18.30708313], [73.07930756, 18.30624962], [73.07902527, 18.30624962], [73.07902527, 18.30597305], [73.07847595, 18.30597305], [73.07847595, 18.30569458], [73.07791901, 18.30569458], [73.07791901, 18.30541611], [73.07765198, 18.30541992], [73.07765198, 18.30513954], [73.07707977, 18.30513954], [73.07707977, 18.30486107], [73.07624817, 18.30486107], [73.07624817, 18.30541992], [73.07597351, 18.30541611], [73.07597351, 18.30569458], [73.07569122, 18.30569458], [73.07569122, 18.30597305], [73.07541656, 18.30597115], [73.07541656, 18.30652809], [73.07569122, 18.30652809], [73.07569122, 18.30792046], [73.07624817, 18.30791664], [73.07624817, 18.30847168], [73.07680511, 18.30847168], [73.07680511, 18.30874825], [73.07707977, 18.30874825], [73.07707977, 18.30931091], [73.07765198, 18.30931091], [73.07765198, 18.30987167], [73.07791901, 18.30987167], [73.07791901, 18.31014061], [73.07847595, 18.31014061]]], [[[73.08180237, 18.32180595], [73.08180237, 18.32208252], [73.08208466, 18.32208252], [73.08208466, 18.32125092], [73.08235931, 18.32125092], [73.08235931, 18.32097054], [73.08208466, 18.32097244], [73.08208466, 18.31902695], [73.08180237, 18.31903076], [73.08180237, 18.31875038], [73.08125305, 18.31875038], [73.08125305, 18.31903076], [73.08041382, 18.31902695], [73.08041382, 18.31958389], [73.08068848, 18.31958008], [73.08068848, 18.32014084], [73.08097076, 18.32013893], [73.08097076, 18.32069397], [73.08125305, 18.32069016], [73.08125305, 18.32152748], [73.08152771, 18.32152748], [73.08152771, 18.32180977], [73.08180237, 18.32180595]]], [[[73.08429718, 17.81875038], [73.08429718, 17.81847191], [73.0845871, 17.81847191], [73.0845871, 17.81819534], [73.08486176, 17.81820107], [73.08486176, 17.81792259], [73.08513641, 17.81792259], [73.08513641, 17.8176403], [73.0854187, 17.8176403], [73.0854187, 17.81736183], [73.08569336, 17.81736183], [73.08569336, 17.81708336], [73.08597565, 17.81708336], [73.08597565, 17.81652832], [73.08569336, 17.81653023], [73.08569336, 17.81568909], [73.0854187, 17.81569481], [73.0854187, 17.8148613], [73.08486176, 17.8148613], [73.08486176, 17.81458282], [73.0845871, 17.81458282], [73.0845871, 17.81430626], [73.08374786, 17.81430817], [73.08374786, 17.81402969], [73.08345795, 17.81402969], [73.08345795, 17.81430817], [73.08319092, 17.81430817], [73.08319092, 17.81541824], [73.08347321, 17.81541634], [73.08347321, 17.81569481], [73.08319092, 17.81568909], [73.08319092, 17.81653023], [73.08291626, 17.81652832], [73.08291626, 17.81708336], [73.0826416, 17.81708336], [73.0826416, 17.81736183], [73.08235931, 17.81736183], [73.08235931, 17.81820107], [73.0826416, 17.81819534], [73.0826416, 17.81847191], [73.08319092, 17.81847191], [73.08319092, 17.81875038], [73.08429718, 17.81875038]]], [[[72.78180695, 19.13541985], [72.78180695, 19.13513947], [72.78263092, 19.13513947], [72.78263092, 19.13486099], [72.78347015, 19.13486099], [72.78347015, 19.13236046], [72.78180695, 19.13236046], [72.78180695, 19.13264084], [72.78098297, 19.13264084], [72.78098297, 19.13292122], [72.7804184, 19.1329174], [72.7804184, 19.13347244], [72.78013611, 19.13347054], [72.78013611, 19.13402939], [72.7804184, 19.13402939], [72.7804184, 19.13430977], [72.78069305, 19.13430977], [72.78069305, 19.13486099], [72.78097534, 19.13486099], [72.78097534, 19.13513947], [72.78125, 19.13513947], [72.78125, 19.13541985], [72.78180695, 19.13541985]]], [[[72.81263733, 18.70652962], [72.81263733, 18.70625114], [72.81291962, 18.70625114], [72.81291962, 18.70597076], [72.81319427, 18.70597267], [72.81319427, 18.70541763], [72.81375122, 18.70541954], [72.81375122, 18.70514107], [72.81402588, 18.70514107], [72.81402588, 18.70486069], [72.81458282, 18.70486069], [72.81458282, 18.70458031], [72.81485748, 18.70458412], [72.81485748, 18.70375061], [72.81513977, 18.70375061], [72.81513977, 18.70292091], [72.81430817, 18.70292091], [72.81430817, 18.70264053], [72.81375122, 18.70264053], [72.81375122, 18.70236015], [72.81263733, 18.70236015], [72.81263733, 18.70292091], [72.81236267, 18.7029171], [72.81236267, 18.70347214], [72.81208038, 18.70347023], [72.81208038, 18.70486069], [72.81180573, 18.70486069], [72.81180573, 18.70597267], [72.81208038, 18.70597076], [72.81208038, 18.70652962], [72.81263733, 18.70652962]]], [[[72.84263611, 18.7084713], [72.84263611, 18.70819473], [72.8429184, 18.70819473], [72.8429184, 18.70736122], [72.84263611, 18.70736122], [72.84263611, 18.70625114], [72.84236145, 18.70625114], [72.84236145, 18.70569038], [72.84208679, 18.7056942], [72.84208679, 18.70513916], [72.84124756, 18.70514107], [72.84124756, 18.70625114], [72.84152985, 18.70625114], [72.84152985, 18.70709038], [72.8418045, 18.70708275], [72.8418045, 18.70819473], [72.84208679, 18.70819473], [72.84208679, 18.7084713], [72.84263611, 18.7084713]]], [[[72.86486053, 18.6356945], [72.86486053, 18.63513947], [72.86514282, 18.63513947], [72.86513519, 18.63458061], [72.86541748, 18.63458061], [72.86541748, 18.63402748], [72.86514282, 18.63402939], [72.86514282, 18.63347054], [72.86486053, 18.63347054], [72.86486053, 18.63319206], [72.86402893, 18.63319206], [72.86402893, 18.63264084], [72.86347198, 18.63264084], [72.86347198, 18.63347054], [72.86374664, 18.63347054], [72.86374664, 18.63375282], [72.86402893, 18.63375282], [72.86402893, 18.6348629], [72.86430359, 18.6348629], [72.86430359, 18.6356945], [72.86486053, 18.6356945]]], [[[72.9015274, 18.9643116], [72.9015274, 18.96402931], [72.90207672, 18.96402931], [72.90207672, 18.96375084], [72.9026413, 18.96375084], [72.9026413, 18.96347046], [72.9034729, 18.96347237], [72.9034729, 18.96319389], [72.90374756, 18.96319389], [72.90374756, 18.96152878], [72.90402985, 18.96153069], [72.90402985, 18.96096992], [72.90486145, 18.96096992], [72.90486145, 18.96125031], [72.90569305, 18.96125031], [72.90569305, 18.96070099], [72.90598297, 18.96070099], [72.90598297, 18.96014023], [72.90625, 18.96014023], [72.90625, 18.95930099], [72.90652466, 18.95930672], [72.90652466, 18.95874977], [72.90763855, 18.95874977], [72.90763855, 18.95930672], [72.90791321, 18.95930672], [72.90791321, 18.95958328], [72.90847015, 18.95958328], [72.90847015, 18.9584713], [72.90875244, 18.9584713], [72.90875244, 18.95569229], [72.90847015, 18.95569229], [72.90847015, 18.95375252], [72.90875244, 18.95375252], [72.90875244, 18.95319176], [72.90763855, 18.95319176], [72.90763855, 18.95404053], [72.90791321, 18.95404053], [72.90791321, 18.95514107], [72.90763855, 18.95513916], [72.90763855, 18.95597458], [72.90791321, 18.95597076], [72.90791321, 18.95736122], [72.90763855, 18.95736122], [72.90763855, 18.95792007], [72.90598297, 18.95792007], [72.90598297, 18.95736122], [72.90513611, 18.95736122], [72.90513611, 18.95708084], [72.90402985, 18.95708466], [72.90402985, 18.95680618], [72.90374756, 18.95681], [72.90374756, 18.95652962], [72.9034729, 18.95652962], [72.9034729, 18.95597076], [72.90319824, 18.95597458], [72.90319824, 18.95541573], [72.9026413, 18.95541954], [72.9026413, 18.95458031], [72.90235901, 18.95458221], [72.90235901, 18.95402718], [72.90207672, 18.95404053], [72.90207672, 18.95319176], [72.90180206, 18.95319366], [72.90180206, 18.95208359], [72.9015274, 18.95208359], [72.9015274, 18.95069504], [72.90125275, 18.95070076], [72.90125275, 18.9493103], [72.90097046, 18.94930077], [72.90097046, 18.94763947], [72.9006958, 18.94763947], [72.9006958, 18.94514084], [72.90040588, 18.94514084], [72.90040588, 18.94347], [72.9015274, 18.94347382], [72.9015274, 18.94291687], [72.90125275, 18.94292068], [72.90125275, 18.9426403], [72.90097046, 18.9426403], [72.90097046, 18.94235992], [72.9006958, 18.94236374], [72.9006958, 18.94208145], [72.90041351, 18.94208145], [72.90041351, 18.94152832], [72.90014648, 18.94153023], [72.90014648, 18.94124985], [72.89958191, 18.94124985], [72.89958191, 18.94096947], [72.89875031, 18.94096947], [72.89875031, 18.94181061], [72.89901733, 18.94181061], [72.89901733, 18.9426403], [72.89930725, 18.9426403], [72.89930725, 18.94431114], [72.89958191, 18.94431114], [72.89958191, 18.94625092], [72.8998642, 18.94625092], [72.8998642, 18.94791794], [72.90013885, 18.94791794], [72.90013885, 18.94958305], [72.90040588, 18.94958115], [72.90040588, 18.95124817], [72.9006958, 18.95124817], [72.9006958, 18.95264244], [72.90097046, 18.95264244], [72.90097046, 18.95430946], [72.90125275, 18.95430946], [72.90125275, 18.95514107], [72.9015274, 18.95513916], [72.9015274, 18.95569229], [72.90180206, 18.95569038], [72.90180206, 18.95625114], [72.90207672, 18.95625114], [72.90207672, 18.95681], [72.90235901, 18.95681], [72.90235901, 18.95792007], [72.90208435, 18.95791626], [72.90208435, 18.9584713], [72.90180206, 18.95846939], [72.90180206, 18.95874977], [72.9015274, 18.95874977], [72.9015274, 18.95903015], [72.90125275, 18.95902824], [72.90125275, 18.95930672], [72.90097046, 18.95930672], [72.90097046, 18.95958328], [72.9006958, 18.95958328], [72.9006958, 18.95986176], [72.90040588, 18.95985031], [72.90040588, 18.96014023], [72.89958191, 18.96014023], [72.89958191, 18.96125031], [72.89930725, 18.96125031], [72.89930725, 18.96181107], [72.89902496, 18.96180534], [72.89902496, 18.96208382], [72.89930725, 18.96208], [72.89930725, 18.96236038], [72.89958191, 18.96236038], [72.89958191, 18.96291733], [72.8998642, 18.96291733], [72.8998642, 18.96319389], [72.90013885, 18.96319389], [72.90013885, 18.96375084], [72.90040588, 18.96375084], [72.90040588, 18.9643116], [72.9015274, 18.9643116]]], [[[72.93902588, 18.97236061], [72.93902588, 18.97208023], [72.93958282, 18.97208595], [72.93958282, 18.9715271], [72.93985748, 18.97153091], [72.93985748, 18.97125053], [72.9404068, 18.97125053], [72.9404068, 18.97097015], [72.94097137, 18.97097206], [72.94097137, 18.97041702], [72.94124603, 18.97042084], [72.94124603, 18.96986008], [72.94152832, 18.96986389], [72.94152832, 18.9695816], [72.94180298, 18.9695816], [72.94180298, 18.96902847], [72.94152832, 18.96903992], [72.94152832, 18.96875191], [72.94180298, 18.96875191], [72.94180298, 18.96820068], [72.94152832, 18.96820068], [72.94152832, 18.9679203], [72.94180298, 18.9679203], [72.94180298, 18.96764183], [72.9420929, 18.96764183], [72.9420929, 18.96569061], [72.94180298, 18.96569443], [72.94180298, 18.9652195], [72.94180298, 18.96486092], [72.94152832, 18.96486092], [72.94152832, 18.9643116], [72.94124603, 18.9643116], [72.94124603, 18.96402931], [72.94097137, 18.96402931], [72.94097137, 18.96375084], [72.94069672, 18.96375084], [72.94069672, 18.96318817], [72.94041443, 18.96319389], [72.94041443, 18.96263885], [72.94013977, 18.96264076], [72.94013977, 18.96236038], [72.93985748, 18.96236038], [72.93985748, 18.96181107], [72.93958282, 18.96181107], [72.93958282, 18.96125031], [72.93930817, 18.96125031], [72.93930817, 18.96097183], [72.93902588, 18.96097183], [72.93902588, 18.96041679], [72.93875122, 18.96042061], [72.93875122, 18.96014023], [72.93846893, 18.96014023], [72.93846893, 18.95957947], [72.93819427, 18.95958328], [72.93819427, 18.95930672], [72.93791962, 18.95930672], [72.93791962, 18.95902824], [72.93763733, 18.95903015], [72.93763733, 18.95846939], [72.93736267, 18.9584713], [72.93736267, 18.95791626], [72.93708038, 18.95792007], [72.93708038, 18.95708084], [72.93680573, 18.95708466], [72.93680573, 18.95597458], [72.93653107, 18.95597458], [72.93653107, 18.95513916], [72.93624878, 18.95514107], [72.93624878, 18.95404053], [72.93596649, 18.95404053], [72.93596649, 18.95375252], [72.93569183, 18.95375252], [72.93569183, 18.95264244], [72.93514252, 18.95264244], [72.93514252, 18.95207977], [72.93402863, 18.95207977], [72.93402863, 18.95236015], [72.93374634, 18.95236015], [72.93374634, 18.95264244], [72.93347168, 18.95264244], [72.93347168, 18.95375252], [72.93318939, 18.95375252], [72.93318939, 18.95404053], [72.93289948, 18.95404053], [72.93289948, 18.95430946], [72.93264008, 18.95430565], [72.93264008, 18.95458221], [72.93041992, 18.95458031], [72.93041992, 18.95486069], [72.92986298, 18.95486069], [72.92986298, 18.95514107], [72.92930603, 18.95514107], [72.92930603, 18.95541954], [72.92903137, 18.95541573], [72.92903137, 18.95569229], [72.92874908, 18.95569229], [72.92874908, 18.95597458], [72.9284668, 18.95597076], [72.9284668, 18.95681], [72.92819214, 18.95680618], [72.92819214, 18.95708466], [72.92791748, 18.95708084], [72.92791748, 18.95763969], [72.92736053, 18.95763969], [72.92736053, 18.95792007], [72.92708588, 18.95792007], [72.92708588, 18.95763969], [72.92679596, 18.95763969], [72.92679596, 18.95792007], [72.92569733, 18.95791626], [72.92569733, 18.9584713], [72.92542267, 18.95846939], [72.92542267, 18.95903015], [72.92508698, 18.95902824], [72.92485809, 18.95902824], [72.92485809, 18.95930672], [72.92457581, 18.95930099], [72.92457581, 18.96014023], [72.92430878, 18.96013832], [72.92430878, 18.9630127], [72.92430878, 18.96347237], [72.92457581, 18.96347046], [72.92457581, 18.96402931], [72.92485809, 18.96402931], [72.92485809, 18.9643116], [72.92514038, 18.9643116], [72.92514038, 18.96486092], [72.92541504, 18.96486092], [72.92541504, 18.96513939], [72.92569733, 18.96513939], [72.92569733, 18.96598053], [72.92652893, 18.96598053], [72.92652893, 18.96653175], [72.92708588, 18.96653175], [72.92708588, 18.96681023], [72.92736053, 18.96680641], [72.92736053, 18.96736336], [72.92791748, 18.96735954], [72.92791748, 18.96764183], [72.9284668, 18.96764183], [72.9284668, 18.9679203], [72.92930603, 18.9679203], [72.92930603, 18.96820068], [72.93041992, 18.96819305], [72.93041992, 18.96847153], [72.93068695, 18.96846962], [72.93068695, 18.96875191], [72.93096924, 18.96875191], [72.93096924, 18.96903992], [72.93152618, 18.96902847], [72.93152618, 18.9695816], [72.93208313, 18.9695816], [72.93208313, 18.96986389], [72.93318939, 18.96986008], [72.93318939, 18.97014046], [72.93402863, 18.97014046], [72.93402863, 18.97042084], [72.93458557, 18.97041702], [72.93458557, 18.9706955], [72.93514252, 18.9706955], [72.93514252, 18.97097206], [72.93569183, 18.97097015], [72.93569183, 18.97125053], [72.93624878, 18.97125053], [72.93624878, 18.97180939], [72.93680573, 18.97180557], [72.93680573, 18.97208595], [72.93736267, 18.97208023], [72.93736267, 18.97236061], [72.93846893, 18.97236061], [72.93846893, 18.97208023], [72.93875122, 18.97208023], [72.93875122, 18.97236061], [72.93902588, 18.97236061]]], [[[73.02597046, 18.99986076], [73.02597046, 18.99958038], [73.02708435, 18.9995842], [73.02708435, 18.99930573], [73.02735901, 18.99930954], [73.02735901, 18.99901962], [73.0276413, 18.99902725], [73.0276413, 18.99875069], [73.02819824, 18.99875069], [73.02819824, 18.99792099], [73.0284729, 18.99792099], [73.0284729, 18.99625015], [73.02874756, 18.99625015], [73.02874756, 18.9948597], [73.0284729, 18.99486351], [73.0284729, 18.99291611], [73.0276413, 18.99291611], [73.0276413, 18.99319458], [73.02735901, 18.99319458], [73.02735901, 18.99458122], [73.02707672, 18.99458122], [73.02707672, 18.99514008], [73.02680206, 18.99514008], [73.02680206, 18.99542046], [73.0265274, 18.99541664], [73.02654266, 18.99625015], [73.02625275, 18.99625015], [73.02625275, 18.99708557], [73.02597046, 18.99707985], [73.02597046, 18.99736023], [73.0256958, 18.99736023], [73.0256958, 18.99986076], [73.02597046, 18.99986076]]], [[[72.73124695, 19.46847153], [72.73124695, 19.46819687], [72.73153687, 19.46820068], [72.73153687, 19.4679203], [72.73179626, 19.4679203], [72.73179626, 19.46735954], [72.73291779, 19.46736145], [72.73291779, 19.46708488], [72.73347473, 19.46708488], [72.73347473, 19.46736145], [72.73430634, 19.46736145], [72.73430634, 19.46680641], [72.73542023, 19.46681023], [72.73542023, 19.46652985], [72.73625183, 19.46652985], [72.73625183, 19.46569061], [72.73652649, 19.46569633], [72.73652649, 19.46541405], [72.73596954, 19.46541977], [72.73596954, 19.46513939], [72.73568726, 19.46513939], [72.73568726, 19.46458054], [72.73542023, 19.46458244], [72.73542023, 19.4640274], [72.73513794, 19.46403122], [72.73513794, 19.46375084], [72.73486328, 19.46375084], [72.73486328, 19.46347046], [72.73458099, 19.46347237], [72.73458099, 19.46263885], [72.73374939, 19.4626503], [72.73374939, 19.46236038], [72.7334671, 19.46236038], [72.7334671, 19.46042252], [72.73374939, 19.46042252], [72.73374939, 19.46014023], [72.73401642, 19.46014023], [72.73401642, 19.45959282], [72.73430634, 19.45959282], [72.73430634, 19.45929909], [72.73458099, 19.45930481], [72.73458099, 19.45902824], [72.73513794, 19.45902824], [72.73513794, 19.45846748], [72.73430634, 19.4584713], [72.73430634, 19.45819473], [72.73374939, 19.45819473], [72.73374939, 19.45791626], [72.73319244, 19.45791817], [72.73319244, 19.45763969], [72.73291779, 19.45763969], [72.73291779, 19.45736122], [72.73179626, 19.45736122], [72.73179626, 19.45791817], [72.73152924, 19.45791626], [72.73152924, 19.45819473], [72.73124695, 19.45819473], [72.73124695, 19.4584713], [72.73097229, 19.45846748], [72.73097229, 19.45874977], [72.73069763, 19.45874977], [72.73069763, 19.45902824], [72.73041534, 19.45902824], [72.73041534, 19.45930481], [72.7298584, 19.45929909], [72.7298584, 19.45959282], [72.72957611, 19.45959282], [72.72957611, 19.46014023], [72.72930908, 19.46014023], [72.72930908, 19.46042252], [72.72902679, 19.46042252], [72.72902679, 19.4607029], [72.72875214, 19.4607029], [72.72875214, 19.46125031], [72.72847748, 19.46125031], [72.72847748, 19.46153259], [72.72819519, 19.46152687], [72.72819519, 19.46208382], [72.7279129, 19.46208191], [72.7279129, 19.46403122], [72.72763824, 19.46403122], [72.72763824, 19.46430969], [72.72735596, 19.46430969], [72.72735596, 19.46486092], [72.7270813, 19.46486092], [72.7270813, 19.46569633], [72.72652435, 19.46569633], [72.72652435, 19.46708488], [72.72624969, 19.46708107], [72.72624969, 19.46763992], [72.7270813, 19.46763992], [72.7270813, 19.4679203], [72.72735596, 19.4679203], [72.72735596, 19.46820068], [72.72847748, 19.46820068], [72.72847748, 19.46763992], [72.72930908, 19.46763992], [72.72930908, 19.4679203], [72.72957611, 19.4679203], [72.72957611, 19.46820068], [72.73041534, 19.46819687], [72.73041534, 19.46847153], [72.73124695, 19.46847153]]], [[[79.51481628, 19.54076195], [79.51595306, 19.53680992], [79.51584625, 19.52235985], [79.51339722, 19.51806068], [79.49331665, 19.5051918], [79.48004913, 19.50381279], [79.47042084, 19.49745178], [79.46512604, 19.50901031], [79.45818329, 19.51896095], [79.44126129, 19.53351021], [79.43028259, 19.53510094], [79.42318726, 19.53284073], [79.41361237, 19.53347969], [79.40184784, 19.53983116], [79.38896942, 19.54891968], [79.38070679, 19.55585098], [79.37119293, 19.56154823], [79.36902618, 19.57123184], [79.34088898, 19.57377052], [79.3296814, 19.57368088], [79.32150269, 19.57175064], [79.31426239, 19.56552124], [79.30961609, 19.58201027], [79.30484009, 19.59015083], [79.29323578, 19.59672165], [79.26786041, 19.60666084], [79.25522614, 19.61120987], [79.24386597, 19.61255264], [79.23709106, 19.60948944], [79.23770142, 19.59954071], [79.24378204, 19.59334183], [79.24868011, 19.58686066], [79.25010681, 19.57768059], [79.23976898, 19.55948067], [79.23816681, 19.55093193], [79.23934174, 19.54204941], [79.23835754, 19.53276062], [79.2366333, 19.52679825], [79.23200226, 19.52075005], [79.22342682, 19.51700974], [79.21570587, 19.51058006], [79.20807648, 19.4986496], [79.20684814, 19.49167061], [79.20877838, 19.48479843], [79.22068787, 19.47558975], [79.22293854, 19.4677906], [79.21871185, 19.46450043], [79.18904114, 19.45870018], [79.17778778, 19.46069145], [79.1690979, 19.46776962], [79.15696716, 19.48554993], [79.14026642, 19.50111008], [79.12644958, 19.50649071], [79.11281586, 19.50978088], [79.10473633, 19.51274109], [79.10235596, 19.51935959], [79.10286713, 19.52795029], [79.09661102, 19.53047943], [79.07383728, 19.52861023], [79.06339264, 19.53125], [79.060112, 19.53872108], [79.0515213, 19.54527283], [79.03881836, 19.54499054], [79.01835632, 19.5399704], [79.01219177, 19.5437603], [79.00006104, 19.55937004], [78.99556732, 19.5610199], [78.99285889, 19.56204033], [78.98635101, 19.5570507], [78.97847748, 19.55092239], [78.97355652, 19.54990005], [78.96485138, 19.55033112], [78.9545517, 19.55183029], [78.94956207, 19.55747032], [78.95446014, 19.56272125], [78.96470642, 19.57028008], [78.96898651, 19.57345963], [78.97785187, 19.5799427], [78.98052979, 19.5850811], [78.978302, 19.59041023], [78.97132874, 19.59725952], [78.96562195, 19.60451126], [78.96286011, 19.61732292], [78.9646759, 19.62955284], [78.96800232, 19.63936996], [78.96895599, 19.64923286], [78.96167755, 19.65876961], [78.95419312, 19.66341019], [78.94359589, 19.66514015], [78.93498993, 19.66217995], [78.91590881, 19.66773033], [78.90379333, 19.66455841], [78.89097595, 19.65526009], [78.87793732, 19.65680122], [78.8588028, 19.65631104], [78.85912323, 19.66890907], [78.86321259, 19.67949295], [78.86398315, 19.68670082], [78.86347961, 19.69676971], [78.86167145, 19.70590019], [78.8573761, 19.71973991], [78.85691833, 19.73130035], [78.85357666, 19.73800087], [78.84562683, 19.75835037], [78.84433746, 19.75900078], [78.83830261, 19.76208115], [78.82528687, 19.76037979], [78.8171463, 19.76041985], [78.80760956, 19.75798988], [78.80317688, 19.7600708], [78.79695129, 19.76857948], [78.78486633, 19.77874947], [78.77321625, 19.77937126], [78.76322937, 19.77563095], [78.75224304, 19.77729034], [78.74308777, 19.77965927], [78.73834991, 19.77943039], [78.73184204, 19.77285004], [78.72473145, 19.76897049], [78.71644592, 19.76679993], [78.70918274, 19.7727108], [78.70178986, 19.78557968], [78.69590759, 19.789711], [78.68637085, 19.78993988], [78.64833832, 19.80146027], [78.63520813, 19.8037796], [78.61933899, 19.8087101], [78.61434174, 19.81326103], [78.60365295, 19.81750107], [78.59527588, 19.81735039], [78.5917511, 19.81541061], [78.58499146, 19.81168938], [78.57370758, 19.81380272], [78.55792236, 19.81561089], [78.52626801, 19.82165909], [78.51921082, 19.81990051], [78.51239014, 19.81427956], [78.50961304, 19.80118942], [78.50366974, 19.79241943], [78.49391937, 19.79314995], [78.48947144, 19.7985096], [78.48429108, 19.80718994], [78.47618866, 19.81636047], [78.46465302, 19.8162117], [78.44458771, 19.81923103], [78.42867279, 19.82311058], [78.40904236, 19.82986069], [78.3976593, 19.83640289], [78.38923645, 19.84617805], [78.38593292, 19.85270119], [78.38597107, 19.85569954], [78.38417816, 19.86362076], [78.38497162, 19.87389183], [78.38414764, 19.87922287], [78.37446594, 19.87927055], [78.36575317, 19.8828907], [78.34668732, 19.88140106], [78.33625031, 19.88319016], [78.32524109, 19.89048195], [78.32296753, 19.89497185], [78.32660675, 19.89937973], [78.3345871, 19.9043026], [78.3351059, 19.91011047], [78.32837677, 19.9160881], [78.31951141, 19.91546822], [78.31019592, 19.91274071], [78.30761719, 19.90849113], [78.29769135, 19.87329292], [78.29421234, 19.85555077], [78.29412842, 19.84955025], [78.30316925, 19.84583092], [78.33899689, 19.83917999], [78.34136963, 19.83294106], [78.33598328, 19.81866074], [78.33921051, 19.81351089], [78.35161591, 19.81035042], [78.36048889, 19.80574036], [78.36699677, 19.79454041], [78.36773682, 19.78108025], [78.36479187, 19.76733971], [78.3608017, 19.75398064], [78.35320282, 19.73775101], [78.34541321, 19.73442268], [78.34429932, 19.72433281], [78.34527588, 19.71356964], [78.33251953, 19.70850945], [78.32269287, 19.70364952], [78.32010651, 19.69671059], [78.31606293, 19.69055176], [78.3049469, 19.68843079], [78.28581238, 19.68967056], [78.27339172, 19.67015076], [78.26972198, 19.66312981], [78.2726593, 19.6601696], [78.28755951, 19.65446091], [78.29242706, 19.64416122], [78.29550171, 19.63183022], [78.29897308, 19.62341118], [78.3088913, 19.6114006], [78.31098938, 19.60417938], [78.31004333, 19.58671188], [78.31204224, 19.57856178], [78.3111496, 19.57176971], [78.30612183, 19.56744194], [78.2999115, 19.56678009], [78.29928589, 19.56129265], [78.29650879, 19.55838013], [78.28534698, 19.56034088], [78.27910614, 19.55820084], [78.28460693, 19.55039024], [78.2914505, 19.5431118], [78.29502869, 19.53728104], [78.29548645, 19.53083992], [78.29870605, 19.51356125], [78.29943085, 19.50412941], [78.30361176, 19.49376106], [78.31001282, 19.48643112], [78.31204987, 19.47925949], [78.31195831, 19.46590042], [78.3088913, 19.45640945], [78.29733276, 19.44882965], [78.29115295, 19.44879913], [78.28199005, 19.45298958], [78.27321625, 19.45384026], [78.26692963, 19.44792938], [78.26183319, 19.44009972], [78.2519989, 19.4300499], [78.24581146, 19.42898941], [78.23361969, 19.43288994], [78.22426605, 19.43403244], [78.21508026, 19.42705154], [78.20548248, 19.41435051], [78.19811249, 19.40744972], [78.18216705, 19.41176987], [78.18756866, 19.39562035], [78.18698883, 19.38454819], [78.18482208, 19.37629128], [78.18445587, 19.36821938], [78.18136597, 19.3607502], [78.17959595, 19.35301018], [78.18225098, 19.34544754], [78.18711853, 19.3386097], [78.19715118, 19.33172989], [78.19506073, 19.32496071], [78.19551086, 19.31438065], [78.19317627, 19.30294037], [78.18315125, 19.27896118], [78.18325806, 19.26116943], [78.186409, 19.24934959], [78.18331909, 19.24154091], [78.1700592, 19.23633003], [78.14974213, 19.23005104], [78.13926697, 19.23944092], [78.12670898, 19.24640274], [78.09938812, 19.24547958], [78.09512329, 19.24985123], [78.0822525, 19.25477028], [78.07514191, 19.24654961], [78.05755615, 19.23974991], [78.0511322, 19.24176025], [78.04804993, 19.24751282], [78.04762268, 19.25563049], [78.04944611, 19.26272964], [78.04574585, 19.27086067], [78.03288269, 19.27411079], [78.02728271, 19.2786808], [78.01824951, 19.29632759], [78.01161194, 19.30111122], [77.99588776, 19.30571747], [77.98549652, 19.30899048], [77.97690582, 19.32105064], [77.96665192, 19.3273201], [77.96270752, 19.33176994], [77.9489212, 19.34127998], [77.94062805, 19.34250069], [77.93723297, 19.33575058], [77.92632294, 19.33190918], [77.92204285, 19.32591248], [77.91227722, 19.3179512], [77.90577698, 19.31578064], [77.8995285, 19.31779099], [77.89325714, 19.32116127], [77.88804626, 19.31241035], [77.87522888, 19.30890083], [77.87111664, 19.30573082], [77.86087799, 19.30212975], [77.86264038, 19.2953701], [77.86084747, 19.28763962], [77.86192322, 19.28409958], [77.8753891, 19.27977943], [77.89305878, 19.27839279], [77.90067291, 19.27712822], [77.90570831, 19.26721954], [77.90039062, 19.25612068], [77.89187622, 19.25709915], [77.8846283, 19.26023102], [77.86738586, 19.25526047], [77.86808014, 19.24611092], [77.86540222, 19.2379303], [77.86228943, 19.23396111], [77.86152649, 19.22629166], [77.85845184, 19.21846962], [77.85233307, 19.20971107], [77.85267639, 19.20459175], [77.84654999, 19.19697952], [77.84453583, 19.18819046], [77.85839081, 19.18077278], [77.85301971, 19.17682076], [77.85423279, 19.1722908], [77.85385895, 19.16943169], [77.85035706, 19.16765022], [77.85016632, 19.16231155], [77.84874725, 19.15942955], [77.84924316, 19.15528107], [77.837677, 19.13830948], [77.83109283, 19.13565254], [77.83393097, 19.13273811], [77.83863831, 19.11885071], [77.84519196, 19.11421013], [77.84414673, 19.09607124], [77.84818268, 19.09259987], [77.8481369, 19.09008026], [77.84658813, 19.08851814], [77.84218597, 19.08677101], [77.8338089, 19.08653259], [77.82861328, 19.08494186], [77.8254776, 19.0916996], [77.82237244, 19.09639931], [77.81517029, 19.10366249], [77.80576324, 19.10334015], [77.80265045, 19.10196114], [77.80024719, 19.09887123], [77.79976654, 19.0945797], [77.80130768, 19.08440971], [77.79728699, 19.07459068], [77.79445648, 19.07336998], [77.79353333, 19.07121086], [77.79715729, 19.06488037], [77.79566956, 19.0610199], [77.79718018, 19.05130959], [77.79454041, 19.05019188], [77.7911377, 19.05065918], [77.78309631, 19.05483055], [77.77794647, 19.05437088], [77.77098846, 19.05615997], [77.76168823, 19.06204033], [77.75955963, 19.05930138], [77.76093292, 19.0512104], [77.75739288, 19.0285511], [77.76023865, 19.02264023], [77.76216125, 19.02050972], [77.76426697, 19.0196209], [77.76532745, 19.0153904], [77.76574707, 19.00737953], [77.76843262, 18.99938011], [77.76735687, 18.98142052], [77.7815094, 18.97632027], [77.78713226, 18.98428154], [77.81713867, 18.98237038], [77.81286621, 18.96006012], [77.81520081, 18.95923996], [77.81269073, 18.94945908], [77.82739258, 18.94572067], [77.83049774, 18.95020103], [77.85372925, 18.95227814], [77.84870148, 18.93138123], [77.84430695, 18.93032074], [77.84113312, 18.92146111], [77.84049988, 18.91130066], [77.85663605, 18.90607071], [77.8692627, 18.91032028], [77.88157654, 18.90853119], [77.88260651, 18.89637947], [77.88767242, 18.88512039], [77.89865875, 18.88373947], [77.89920044, 18.86792755], [77.90606689, 18.86731911], [77.92533875, 18.85921097], [77.92459869, 18.85414124], [77.93235779, 18.85093117], [77.92964935, 18.84649086], [77.94413757, 18.84229088], [77.94522858, 18.83210945], [77.94255066, 18.82229042], [77.92874908, 18.82172012], [77.90759277, 18.82951927], [77.85922241, 18.81406021], [77.83746338, 18.80746078], [77.8275528, 18.78601265], [77.82318115, 18.76850128], [77.81038666, 18.74024963], [77.80271912, 18.72924995], [77.80222321, 18.71611977], [77.78650665, 18.69432068], [77.78643799, 18.68412018], [77.76940155, 18.6905899], [77.76879883, 18.7016201], [77.76438141, 18.70793915], [77.75762939, 18.70709038], [77.74990845, 18.6978302], [77.74949646, 18.68978119], [77.74466705, 18.68388939], [77.73285675, 18.6760006], [77.72811127, 18.66420937], [77.73324585, 18.66212845], [77.73317719, 18.65570068], [77.73092651, 18.65532112], [77.73011017, 18.64812279], [77.72975922, 18.64558983], [77.72972107, 18.64273262], [77.73602295, 18.63089752], [77.74298859, 18.62140083], [77.74809265, 18.60531044], [77.74716187, 18.58908081], [77.73538208, 18.56318092], [77.73651123, 18.55480957], [77.72793579, 18.55154037], [77.71235657, 18.55443954], [77.68274689, 18.54080963], [77.67590332, 18.54133987], [77.66207886, 18.53325081], [77.65756989, 18.5272007], [77.64528656, 18.53630066], [77.64946747, 18.54133034], [77.65219879, 18.54963112], [77.64955139, 18.54966164], [77.64881134, 18.55261993], [77.64048004, 18.55393028], [77.63440704, 18.54518127], [77.62906647, 18.55064011], [77.61633301, 18.54866982], [77.61582184, 18.54294014], [77.61329651, 18.54239082], [77.61087036, 18.54776955], [77.59726715, 18.54754066], [77.59819031, 18.5350399], [77.59329224, 18.52802086], [77.59329224, 18.52314186], [77.60040283, 18.52497101], [77.60144806, 18.52194977], [77.59646606, 18.51499939], [77.58706665, 18.50984955], [77.58627319, 18.50292015], [77.59388733, 18.49386978], [77.60283661, 18.49138069], [77.60375214, 18.4852581], [77.60106659, 18.47421074], [77.59311676, 18.47351074], [77.59075928, 18.48110962], [77.57652283, 18.48377991], [77.57063293, 18.46685982], [77.56040192, 18.46749115], [77.55809021, 18.465271], [77.54651642, 18.46571922], [77.54619598, 18.46338272], [77.54888153, 18.46080971], [77.54979706, 18.45796967], [77.55908966, 18.45800018], [77.58364868, 18.45355034], [77.58328247, 18.44719124], [77.58521271, 18.44544983], [77.5826416, 18.44306946], [77.57411957, 18.4393425], [77.56693268, 18.43861008], [77.56017303, 18.43504906], [77.54644775, 18.44055939], [77.53450775, 18.44239998], [77.52848053, 18.44048119], [77.52593994, 18.427351], [77.53598022, 18.42345047], [77.53515625, 18.42118073], [77.54413605, 18.42041016], [77.5552063, 18.4178524], [77.54930115, 18.3877182], [77.54155731, 18.38521957], [77.53050232, 18.37577057], [77.52140045, 18.36465073], [77.51950073, 18.3492527], [77.52732849, 18.33940125], [77.54219055, 18.33390045], [77.55335999, 18.33122253], [77.56691742, 18.3179493], [77.57022858, 18.30817986], [77.55503082, 18.29831123], [77.54995728, 18.29134941], [77.5395813, 18.29383087], [77.52388763, 18.30303192], [77.51978302, 18.30736923], [77.50950623, 18.30673027], [77.50843048, 18.3021698], [77.51264191, 18.28198051], [77.51020813, 18.27844048], [77.4977417, 18.27334976], [77.49223328, 18.26588058], [77.48034668, 18.26865959], [77.47480774, 18.26229095], [77.46923065, 18.26316071], [77.46539307, 18.25996017], [77.45079041, 18.26596069], [77.44522095, 18.27012062], [77.44489288, 18.27724075], [77.4369278, 18.28203964], [77.43461609, 18.29298019], [77.43637085, 18.30649185], [77.42780304, 18.30917931], [77.42500305, 18.30467033], [77.4078064, 18.29956055], [77.39628601, 18.30298042], [77.3925705, 18.30093002], [77.38128662, 18.30595016], [77.36252594, 18.30829048], [77.35881042, 18.31064987], [77.35542297, 18.31851959], [77.36701965, 18.32232285], [77.37394714, 18.32950974], [77.37800598, 18.32868958], [77.38089752, 18.33193016], [77.37930298, 18.33910179], [77.38617706, 18.33819008], [77.38922882, 18.34078979], [77.3928299, 18.34054947], [77.39277649, 18.3456707], [77.39594269, 18.34464073], [77.39833069, 18.34749985], [77.39824677, 18.35353088], [77.39182281, 18.36593056], [77.40067291, 18.37017059], [77.40788269, 18.37849045], [77.41011047, 18.38853073], [77.40049744, 18.39780045], [77.39263916, 18.39702988], [77.36975098, 18.40070915], [77.3644104, 18.42984962], [77.36535645, 18.43808937], [77.36962891, 18.44765091], [77.35407257, 18.44874191], [77.34529114, 18.43437195], [77.34207916, 18.43029022], [77.33731079, 18.43544006], [77.33338165, 18.44189072], [77.33271027, 18.44845963], [77.32601929, 18.44885063], [77.32557678, 18.45512009], [77.31741333, 18.45379066], [77.31327057, 18.43938065], [77.30226135, 18.43847084], [77.29476929, 18.43268013], [77.26455688, 18.41838074], [77.25836182, 18.41041946], [77.24912262, 18.40825272], [77.24022675, 18.40864754], [77.23639679, 18.39981079], [77.23287201, 18.38612747], [77.24503326, 18.3705883], [77.24163055, 18.3663826], [77.23081207, 18.36557961], [77.22136688, 18.34720993], [77.22727203, 18.34490013], [77.22297668, 18.33780098], [77.21691132, 18.32489014], [77.2099762, 18.31374168], [77.20014954, 18.31917], [77.19541168, 18.31270981], [77.19764709, 18.29552078], [77.20446014, 18.29047966], [77.20617676, 18.27795982], [77.19882965, 18.27923012], [77.19165039, 18.27429008], [77.17784119, 18.28185081], [77.17053223, 18.28087044], [77.16738129, 18.27345085], [77.16567993, 18.25592041], [77.15719604, 18.25309181], [77.15141296, 18.23793983], [77.14776611, 18.23764992], [77.14768982, 18.22140121], [77.14879608, 18.22145271], [77.1506424, 18.22153091], [77.14998627, 18.21656036], [77.14221954, 18.21604919], [77.13949585, 18.20724106], [77.13114929, 18.20618057], [77.12098694, 18.20670128], [77.11662292, 18.20240974], [77.10659027, 18.20181084], [77.09554291, 18.19510078], [77.09886169, 18.19114113], [77.10292816, 18.18630981], [77.11633301, 18.16760826], [77.10888672, 18.15269089], [77.09661865, 18.15813065], [77.09268188, 18.15697861], [77.08925629, 18.15596008], [77.08618164, 18.15027046], [77.06910706, 18.14944077], [77.05767059, 18.15236282], [77.05767059, 18.15592957], [77.05031586, 18.16127968], [77.04944611, 18.17320824], [77.0381012, 18.18131065], [77.03283691, 18.18378067], [77.03238678, 18.18300056], [77.03032684, 18.17934036], [77.02171326, 18.17822075], [77.02274323, 18.17124939], [77.02398682, 18.16267967], [76.99775696, 18.16684914], [76.99529266, 18.17333031], [76.99547577, 18.1783905], [76.99295044, 18.1820507], [76.99146271, 18.18665123], [76.98789215, 18.18847847], [76.98055267, 18.18939972], [76.97985077, 18.18740082], [76.97090149, 18.18686104], [76.95881653, 18.18614006], [76.95410919, 18.18489075], [76.95095825, 18.17247963], [76.9437561, 18.15473938], [76.93335724, 18.15790939], [76.92536926, 18.14481926], [76.92765808, 18.13986015], [76.9317627, 18.13657951], [76.92999268, 18.13225174], [76.92417908, 18.12446022], [76.92228699, 18.12018967], [76.92256165, 18.11610985], [76.93215179, 18.11098289], [76.94252777, 18.11141014], [76.95339203, 18.11011124], [76.95857239, 18.10643005], [76.96827698, 18.09711075], [76.96734619, 18.09263992], [76.96431732, 18.08821106], [76.95482635, 18.08535957], [76.94973755, 18.0823307], [76.94702911, 18.07376099], [76.94948578, 18.06826973], [76.95266724, 18.06340981], [76.9506073, 18.0582695], [76.94844818, 18.04866028], [76.94863129, 18.04572105], [76.95430756, 18.04273033], [76.95464325, 18.03968048], [76.95205688, 18.03771019], [76.93863678, 18.03722954], [76.91771698, 18.03322983], [76.91940308, 18.0220108], [76.92024994, 18.01375961], [76.9176712, 18.01234055], [76.91816711, 18.00187111], [76.91848755, 17.99868965], [76.91763306, 17.99625969], [76.9196701, 17.99064064], [76.91958618, 17.98538017], [76.91823578, 17.9728508], [76.91726685, 17.96047974], [76.91322327, 17.93720818], [76.91918945, 17.93666077], [76.91834259, 17.92310905], [76.91644287, 17.91509056], [76.91320038, 17.91379929], [76.90020752, 17.91468811], [76.89659882, 17.90802002], [76.89366913, 17.90737152], [76.89240265, 17.9028511], [76.88938141, 17.89718056], [76.88320923, 17.89707947], [76.88117981, 17.89305115], [76.87526703, 17.89273071], [76.87185669, 17.89474106], [76.85383606, 17.89783859], [76.8469162, 17.89640045], [76.83175659, 17.89067268], [76.83307648, 17.88274956], [76.82036591, 17.88445282], [76.81713104, 17.88309097], [76.81108093, 17.88408852], [76.80822754, 17.88309097], [76.80535126, 17.87420845], [76.80625153, 17.87049294], [76.80280304, 17.86832047], [76.7974472, 17.8693409], [76.77456665, 17.87696075], [76.77326202, 17.8786602], [76.77379608, 17.8822403], [76.77310944, 17.88515091], [76.7701416, 17.89236069], [76.76595306, 17.89842987], [76.74297333, 17.89902115], [76.74067688, 17.89801025], [76.73958588, 17.89204979], [76.73964691, 17.88362122], [76.73745728, 17.85705948], [76.74578857, 17.8583107], [76.75456238, 17.85658836], [76.75972748, 17.85206032], [76.76434326, 17.84950066], [76.76573944, 17.85079956], [76.77974701, 17.83633041], [76.78546906, 17.83146286], [76.78816986, 17.82647133], [76.78481293, 17.81963921], [76.78141785, 17.8151207], [76.77947998, 17.81028938], [76.77979279, 17.80591965], [76.77628326, 17.79938126], [76.77002716, 17.79701996], [76.7663269, 17.79664993], [76.76275635, 17.78710938], [76.74887848, 17.78635025], [76.74777222, 17.78360939], [76.74401093, 17.78346062], [76.74355316, 17.78079033], [76.73943329, 17.77913094], [76.72463226, 17.78507805], [76.71938324, 17.7852993], [76.71570587, 17.78191948], [76.71244812, 17.77509117], [76.7128067, 17.7713604], [76.71720123, 17.76984978], [76.72096252, 17.76758957], [76.71909332, 17.76133156], [76.7179718, 17.74786949], [76.72193146, 17.74802971], [76.72650146, 17.7403698], [76.72760773, 17.73699951], [76.70347595, 17.72912025], [76.69815063, 17.72603989], [76.70210266, 17.72371101], [76.70345306, 17.7186203], [76.70079803, 17.70726967], [76.69235992, 17.70526123], [76.69087219, 17.70194054], [76.69122314, 17.6981411], [76.69313049, 17.69376183], [76.69055176, 17.67995262], [76.68826294, 17.67851067], [76.67814636, 17.68734169], [76.67164612, 17.68914032], [76.66313934, 17.68786049], [76.65983582, 17.69919014], [76.65812683, 17.70853043], [76.6552124, 17.71640015], [76.65083313, 17.72083092], [76.63743591, 17.72410965], [76.63065338, 17.72900009], [76.62979889, 17.74187088], [76.62695313, 17.75596046], [76.62336731, 17.7578907], [76.61444855, 17.76831245], [76.60951233, 17.76597977], [76.60690308, 17.75958061], [76.60405731, 17.75583076], [76.59880066, 17.72797012], [76.59324646, 17.71755981], [76.5870285, 17.70788956], [76.57720947, 17.70314026], [76.57322693, 17.70216942], [76.56942749, 17.70374107], [76.5681076, 17.7397995], [76.56459045, 17.7536602], [76.56936646, 17.75638008], [76.57330322, 17.76000023], [76.56754303, 17.76288986], [76.55977631, 17.76313972], [76.53820801, 17.75893974], [76.53159332, 17.75852966], [76.52632141, 17.75936127], [76.5236969, 17.75889015], [76.52503967, 17.73467255], [76.52482605, 17.72290993], [76.52363586, 17.71523094], [76.51095581, 17.71591949], [76.49225616, 17.71494102], [76.48636627, 17.71352005], [76.48562622, 17.69269943], [76.48442841, 17.68442917], [76.48464966, 17.66963005], [76.48929596, 17.66066933], [76.45230103, 17.6555481], [76.45153809, 17.65151024], [76.4408493, 17.64937019], [76.44275665, 17.6418705], [76.43477631, 17.64453125], [76.4287262, 17.64441109], [76.42723083, 17.63978004], [76.42579651, 17.62832069], [76.42410278, 17.62154007], [76.42074585, 17.61424065], [76.41818237, 17.60583115], [76.4156723, 17.60420036], [76.38207245, 17.60078049], [76.37301636, 17.59793854], [76.35948181, 17.5962925], [76.34870148, 17.59539986], [76.33641052, 17.59604073], [76.33167267, 17.59486961], [76.33290863, 17.57383156], [76.33423615, 17.56348991], [76.33724213, 17.5551796], [76.34002686, 17.54257011], [76.34583282, 17.54021072], [76.35481262, 17.53873062], [76.36090088, 17.5362606], [76.36460876, 17.52852058], [76.36612701, 17.52217293], [76.3664093, 17.51671028], [76.35601807, 17.51337051], [76.34633636, 17.51148033], [76.34372711, 17.50811958], [76.34348297, 17.49435043], [76.34594727, 17.49159813], [76.35518646, 17.49416924], [76.36659241, 17.49529266], [76.37503815, 17.49352074], [76.37229919, 17.48578072], [76.3500061, 17.47212982], [76.3427887, 17.47037125], [76.33776855, 17.47040939], [76.33080292, 17.46881866], [76.33084106, 17.46162033], [76.33365631, 17.43229294], [76.34195709, 17.43383026], [76.3638916, 17.43555069], [76.37317657, 17.43441963], [76.36988068, 17.42304039], [76.37004852, 17.40789986], [76.36199951, 17.37508011], [76.4080658, 17.3692894], [76.4105072, 17.35413933], [76.4106369, 17.34769058], [76.4020462, 17.34399033], [76.39299011, 17.33628082], [76.38389587, 17.31954193], [76.38170624, 17.31180954], [76.35936737, 17.31028938], [76.35227203, 17.31059074], [76.3506012, 17.32772064], [76.34361267, 17.34993172], [76.33473969, 17.3498497], [76.31704712, 17.34540939], [76.31301117, 17.34327126], [76.318367, 17.33184052], [76.31720734, 17.32944107], [76.30502319, 17.32845116], [76.29589844, 17.32863808], [76.2857666, 17.33035088], [76.27587891, 17.33053017], [76.27263641, 17.34794998], [76.27017975, 17.35653114], [76.26494598, 17.35816193], [76.25627899, 17.35738945], [76.25, 17.35790062], [76.248909, 17.36213112], [76.2504425, 17.36667061], [76.24671173, 17.3678894], [76.24436188, 17.37467957], [76.2303772, 17.37026024], [76.22899628, 17.36322975], [76.20352173, 17.35878944], [76.19320679, 17.35859108], [76.1829071, 17.35650063], [76.17603302, 17.35238075], [76.17233276, 17.34873009], [76.17350769, 17.33223915], [76.1763382, 17.32146072], [76.17891693, 17.31391907], [76.18260193, 17.31430054], [76.18383026, 17.31104279], [76.17575836, 17.29721069], [76.17188263, 17.29758072], [76.1638031, 17.30033112], [76.16422272, 17.31925964], [76.16314697, 17.34090996], [76.14566803, 17.34793282], [76.1375885, 17.35256958], [76.12120819, 17.36634064], [76.11667633, 17.36622047], [76.10199738, 17.36226082], [76.09596252, 17.35781288], [76.09276581, 17.35444069], [76.09046936, 17.35056114], [76.09407806, 17.34709167], [76.09252167, 17.34367943], [76.08696747, 17.33844757], [76.08685303, 17.3337307], [76.08499146, 17.3321209], [76.07874298, 17.3300705], [76.0734787, 17.33232117], [76.0632019, 17.3519001], [76.06046295, 17.35393143], [76.05452728, 17.35429955], [76.03666687, 17.34896278], [76.02127838, 17.34931183], [76.01545715, 17.35061073], [76.00914001, 17.34752274], [76.00417328, 17.3427906], [76.00026703, 17.33774948], [75.98071289, 17.33620071], [75.9715271, 17.33646011], [75.95981598, 17.33383179], [75.94174957, 17.32485962], [75.93115234, 17.32411003], [75.91622162, 17.33897018], [75.9107132, 17.34581947], [75.89808655, 17.35075951], [75.8936615, 17.35362053], [75.89198303, 17.36079979], [75.89639282, 17.3699894], [75.89697266, 17.37700081], [75.89643097, 17.39497948], [75.89435577, 17.40590286], [75.89025879, 17.41360092], [75.88723755, 17.41732979], [75.88243103, 17.41900063], [75.87844849, 17.41654015], [75.8771286, 17.41135025], [75.87909698, 17.40493965], [75.87890625, 17.40032959], [75.87666321, 17.39697075], [75.86487579, 17.38644028], [75.86196899, 17.38585091], [75.85910797, 17.38896942], [75.85600281, 17.40768242], [75.8478775, 17.41534042], [75.83889008, 17.42054176], [75.82779694, 17.42371941], [75.82472229, 17.42284966], [75.82199097, 17.41967964], [75.82025146, 17.4065609], [75.81729126, 17.40121078], [75.81627655, 17.39781189], [75.81768799, 17.38804054], [75.81759644, 17.38072968], [75.81505585, 17.37384987], [75.8113327, 17.3699398], [75.80233765, 17.37010193], [75.79102325, 17.37298012], [75.78231812, 17.37881279], [75.77661896, 17.38820267], [75.76976776, 17.40684128], [75.76412201, 17.40842056], [75.75875854, 17.40841103], [75.75052643, 17.41290092], [75.73703766, 17.4218998], [75.7339859, 17.42165947], [75.72901154, 17.41950989], [75.72236633, 17.4117794], [75.71517944, 17.40893173], [75.70806122, 17.40831947], [75.69721222, 17.41056824], [75.69119263, 17.41261101], [75.68711853, 17.41730118], [75.68080902, 17.43616295], [75.68081665, 17.45397186], [75.6775589, 17.45797157], [75.6704483, 17.45932007], [75.66230011, 17.45968056], [75.65618134, 17.46751022], [75.64955902, 17.47340965], [75.6355896, 17.47751045], [75.63288879, 17.46964073], [75.63127136, 17.46117973], [75.62532806, 17.45811081], [75.61873627, 17.43911171], [75.61543274, 17.4220295], [75.61013794, 17.41954041], [75.61055756, 17.41711998], [75.61495209, 17.40956116], [75.61672211, 17.39863968], [75.61580658, 17.39185905], [75.61057281, 17.39200974], [75.60331726, 17.38986015], [75.59815979, 17.38610077], [75.58817291, 17.3830204], [75.58371735, 17.38220024], [75.57853699, 17.38293076], [75.58405304, 17.35134125], [75.58483124, 17.34977913], [75.58994293, 17.34968948], [75.59810638, 17.34511948], [75.61310577, 17.34229088], [75.61604309, 17.32876015], [75.61374664, 17.31944084], [75.60595703, 17.3032608], [75.62468719, 17.29380035], [75.62786865, 17.28812027], [75.63109589, 17.2798481], [75.63336945, 17.27738953], [75.63231659, 17.27222061], [75.65747833, 17.27057076], [75.65988922, 17.26144028], [75.66091919, 17.23999977], [75.66281891, 17.22793961], [75.66387939, 17.21375084], [75.662117, 17.20833015], [75.65743256, 17.20378113], [75.64359283, 17.19408035], [75.64264679, 17.18815994], [75.63069916, 17.18616104], [75.63018799, 17.18144989], [75.62851715, 17.18074989], [75.62802124, 17.17012024], [75.6313858, 17.16007042], [75.64273071, 17.14763832], [75.64871216, 17.13880157], [75.64968872, 17.13318062], [75.65273285, 17.13273048], [75.65363312, 17.11313057], [75.67410278, 17.11355019], [75.67550659, 17.10112953], [75.67848969, 17.09417152], [75.67739105, 17.08774948], [75.68013763, 17.07826805], [75.68107605, 17.07114029], [75.67840576, 17.06286049], [75.6709671, 17.06157112], [75.66268921, 17.06178284], [75.65439606, 17.05508995], [75.64787292, 17.04657173], [75.64375305, 17.03639984], [75.64819336, 17.03269005], [75.65399933, 17.03063965], [75.66216278, 17.03244972], [75.67224121, 17.03573036], [75.67310333, 17.02617073], [75.67053986, 16.9988308], [75.66867828, 16.98321915], [75.66883087, 16.97776031], [75.66938019, 16.97562981], [75.67263031, 16.97408104], [75.67459106, 16.96935081], [75.67842102, 16.96394157], [75.67460632, 16.96026993], [75.67137909, 16.95853806], [75.66374969, 16.95788193], [75.65561676, 16.95611], [75.64962769, 16.95199966], [75.64502716, 16.95103264], [75.63938904, 16.95915985], [75.63633728, 16.96581078], [75.6309433, 16.96714973], [75.62101746, 16.96775055], [75.61065674, 16.96961975], [75.60965729, 16.99893951], [75.60951996, 17.00311089], [75.59944153, 17.00522041], [75.57579803, 17.00779915], [75.56991577, 17.00617027], [75.56929779, 16.99885941], [75.57034302, 16.96362114], [75.55847168, 16.96434975], [75.54281616, 16.96314049], [75.53286743, 16.96665192], [75.53000641, 16.96582985], [75.52406311, 16.95874023], [75.51700592, 16.95193291], [75.51065063, 16.94730949], [75.5092926, 16.94859123], [75.50187683, 16.94540977], [75.49249268, 16.9428997], [75.49301147, 16.94518089], [75.49263, 16.95150948], [75.49178314, 16.95783043], [75.48969269, 16.96538925], [75.48249817, 16.97595024], [75.46858978, 16.97957039], [75.46791077, 16.98533058], [75.45353699, 16.98265076], [75.44380188, 16.97949028], [75.4388504, 16.97088051], [75.43102264, 16.96346092], [75.41683197, 16.96949959], [75.39476013, 16.97639275], [75.37168884, 16.96869087], [75.36435699, 16.9636097], [75.35957336, 16.9568882], [75.34532928, 16.95252037], [75.33796692, 16.9535408], [75.30612946, 16.95466995], [75.2947464, 16.95412827], [75.28843689, 16.95477295], [75.28462219, 16.95355034], [75.28359985, 16.94294167], [75.28557587, 16.90943146], [75.29177856, 16.90113831], [75.28749847, 16.88321114], [75.28565216, 16.87879944], [75.28277588, 16.87424088], [75.26830292, 16.86086082], [75.25797272, 16.86213112], [75.24867249, 16.86452866], [75.24344635, 16.86449051], [75.24099731, 16.86296082], [75.23565674, 16.85419083], [75.23291016, 16.84554291], [75.23001099, 16.84091949], [75.21585846, 16.84033966], [75.18828583, 16.84089088], [75.18319702, 16.84204102], [75.18900299, 16.86189842], [75.19252014, 16.86955833], [75.18965912, 16.87350082], [75.18084717, 16.86751175], [75.17175293, 16.86479759], [75.16438293, 16.86557961], [75.15052795, 16.86940956], [75.14112854, 16.87354088], [75.13838959, 16.8782692], [75.13710785, 16.88459969], [75.13839722, 16.89292145], [75.12763214, 16.89718056], [75.1235733, 16.90043831], [75.12200165, 16.90723038], [75.11875916, 16.90997124], [75.10692596, 16.9095211], [75.09796906, 16.91386986], [75.0947113, 16.92115021], [75.09414673, 16.94722939], [75.09041595, 16.94865036], [75.08294678, 16.94659805], [75.0654068, 16.93926048], [75.05523682, 16.93885994], [75.05078888, 16.93966103], [75.04814911, 16.93871117], [75.04535675, 16.93425941], [75.03449249, 16.92873955], [75.03190613, 16.92567062], [75.03011322, 16.93114281], [75.03029633, 16.94153023], [75.01140594, 16.94258118], [75.00370026, 16.94582748], [74.99954224, 16.94189835], [74.99449158, 16.93503952], [74.98581696, 16.92901993], [74.98142242, 16.93061066], [74.97528839, 16.93460083], [74.96949768, 16.93591118], [74.96671295, 16.93564987], [74.95999908, 16.9329319], [74.95802307, 16.92914009], [74.95453644, 16.93000031], [74.95243073, 16.93622017], [74.94834137, 16.93581963], [74.93839264, 16.94099045], [74.9285202, 16.93520164], [74.92703247, 16.92562294], [74.93694305, 16.92073059], [74.9382019, 16.91646957], [74.94407654, 16.91327095], [74.94803619, 16.90917015], [74.95284271, 16.90648079], [74.96726227, 16.90538025], [74.96409607, 16.8778801], [74.95606995, 16.87729073], [74.94861603, 16.88009071], [74.94513702, 16.87712288], [74.93966675, 16.87652016], [74.93984985, 16.87232018], [74.93708038, 16.86916161], [74.9315033, 16.86954117], [74.92778778, 16.86334991], [74.91195679, 16.85593987], [74.91330719, 16.84144974], [74.91306305, 16.83074951], [74.91581726, 16.81022072], [74.91586304, 16.78568077], [74.9238205, 16.76995087], [74.90701294, 16.76979065], [74.89263916, 16.76869011], [74.86836243, 16.77108002], [74.85497284, 16.77076912], [74.8503418, 16.76032066], [74.80410767, 16.75076294], [74.80040741, 16.74565125], [74.79110718, 16.74814987], [74.77900696, 16.74859047], [74.77555847, 16.74399948], [74.7750473, 16.74077988], [74.76940918, 16.73946953], [74.76381683, 16.73680115], [74.75614166, 16.72962952], [74.75409698, 16.72619057], [74.74820709, 16.72212029], [74.73661804, 16.71583939], [74.72244263, 16.71329117], [74.70783234, 16.7130909], [74.69819641, 16.71520042], [74.69593811, 16.71054077], [74.69503784, 16.69244194], [74.69561005, 16.68583107], [74.68895721, 16.68412018], [74.68752289, 16.68166161], [74.68727875, 16.67901039], [74.69458008, 16.67864037], [74.69610596, 16.67498016], [74.67173767, 16.66353035], [74.66880035, 16.65555191], [74.6605072, 16.63758087], [74.66304779, 16.63216972], [74.66600037, 16.62872124], [74.67386627, 16.62845993], [74.68531036, 16.61988068], [74.69122314, 16.61814117], [74.69431305, 16.61519051], [74.69462585, 16.61082077], [74.69338226, 16.60727119], [74.69037628, 16.60445976], [74.67855072, 16.60655975], [74.67529297, 16.60598946], [74.66882324, 16.60268021], [74.66387177, 16.60107994], [74.65174866, 16.60697937], [74.64771271, 16.60807037], [74.64280701, 16.60677147], [74.64113617, 16.60469055], [74.63974762, 16.59953117], [74.63938141, 16.59435272], [74.64051819, 16.5819397], [74.6363678, 16.57574081], [74.63066101, 16.57765007], [74.62695313, 16.58093071], [74.62393951, 16.58192062], [74.62438965, 16.57755089], [74.62264252, 16.57364082], [74.61699677, 16.56797028], [74.60484314, 16.56214142], [74.59588623, 16.56439018], [74.59335327, 16.56382942], [74.59179688, 16.56072044], [74.5916214, 16.55883026], [74.59253693, 16.55727005], [74.59195709, 16.55554962], [74.58152008, 16.55500031], [74.58152008, 16.55183983], [74.5740509, 16.55196953], [74.56907654, 16.55639839], [74.56552887, 16.55779076], [74.56220245, 16.55803108], [74.55966949, 16.5597496], [74.55908966, 16.56710815], [74.55970001, 16.57137108], [74.56510162, 16.57463074], [74.56981659, 16.58122063], [74.56555939, 16.59037971], [74.55459595, 16.59242058], [74.54985046, 16.59218025], [74.55024719, 16.60902023], [74.54937744, 16.61552048], [74.55143738, 16.63321114], [74.53009033, 16.63060951], [74.51029205, 16.63145065], [74.50167084, 16.62713814], [74.49800873, 16.62664032], [74.49550629, 16.62767029], [74.49178314, 16.63233948], [74.48983765, 16.63607025], [74.48587036, 16.6391201], [74.4813385, 16.6540699], [74.47738647, 16.66077995], [74.47013855, 16.65518951], [74.46479797, 16.65295029], [74.46518707, 16.64689827], [74.46283722, 16.64448929], [74.46446991, 16.63398933], [74.46981049, 16.62347984], [74.47136688, 16.6217804], [74.47080231, 16.61495018], [74.47245789, 16.60481071], [74.44698334, 16.60033989], [74.44081879, 16.59869194], [74.43354034, 16.59436035], [74.42883301, 16.58272934], [74.42228699, 16.58350182], [74.41371918, 16.58023834], [74.40348053, 16.5786705], [74.40216064, 16.57472992], [74.40120697, 16.57094002], [74.39839935, 16.56542969], [74.40077209, 16.56347275], [74.40113068, 16.56088829], [74.39550018, 16.55952263], [74.39565277, 16.53567123], [74.39289856, 16.53107071], [74.3899231, 16.5279007], [74.38543701, 16.52740288], [74.37110138, 16.53765106], [74.36611938, 16.53763962], [74.36258698, 16.53874016], [74.36464691, 16.54368019], [74.36287689, 16.5485611], [74.36923218, 16.55327034], [74.36561584, 16.55706978], [74.36308289, 16.55620193], [74.35974884, 16.55368996], [74.35507202, 16.55311012], [74.34612274, 16.54644966], [74.34020233, 16.55013275], [74.33215332, 16.55369949], [74.32940674, 16.55347061], [74.32377625, 16.55146027], [74.32222748, 16.54450035], [74.32216644, 16.53905106], [74.3232193, 16.5322094], [74.32267761, 16.51900101], [74.32390594, 16.50629807], [74.32145691, 16.50267029], [74.31411743, 16.50209808], [74.31346893, 16.50325966], [74.31157684, 16.50692749], [74.30845642, 16.52187157], [74.30892181, 16.52399826], [74.30692291, 16.52917099], [74.29762268, 16.53193092], [74.29447937, 16.53154182], [74.29483795, 16.52929115], [74.28961945, 16.52256966], [74.28955841, 16.52526283], [74.28713226, 16.52732086], [74.28672791, 16.52940941], [74.28822327, 16.53947067], [74.28431702, 16.54309273], [74.27636719, 16.54453278], [74.27155304, 16.53866005], [74.27197266, 16.5334301], [74.2755127, 16.52515984], [74.27662659, 16.52061081], [74.28190613, 16.52055168], [74.28440094, 16.51647949], [74.28668976, 16.50677109], [74.28575897, 16.50337029], [74.27864075, 16.50102043], [74.26313019, 16.49895287], [74.25570679, 16.49677086], [74.25315857, 16.49488068], [74.26008606, 16.49090767], [74.262146, 16.48867035], [74.26452637, 16.48545074], [74.26516724, 16.48240089], [74.26877594, 16.47603035], [74.27842712, 16.47963905], [74.28253937, 16.48257065], [74.28099823, 16.48579025], [74.28051758, 16.48936081], [74.28330994, 16.49603271], [74.28894806, 16.50378036], [74.29989624, 16.50263023], [74.30055237, 16.49963188], [74.2975769, 16.48161125], [74.29483795, 16.47435188], [74.2964325, 16.46671104], [74.29631805, 16.45901108], [74.30139923, 16.45906067], [74.30239868, 16.46108055], [74.30464935, 16.46079063], [74.30709076, 16.45959091], [74.31482697, 16.45319939], [74.32193756, 16.45004082], [74.33052826, 16.45279121], [74.33555603, 16.45308113], [74.33886719, 16.45216179], [74.33998871, 16.44812965], [74.33876038, 16.44664192], [74.33904266, 16.44486046], [74.34246063, 16.44232941], [74.34223175, 16.43956947], [74.34062195, 16.43617058], [74.34052277, 16.43297958], [74.34375, 16.42554092], [74.33728027, 16.42020988], [74.33818054, 16.41337013], [74.34194183, 16.40521049], [74.34265137, 16.40049171], [74.34928131, 16.39940071], [74.34916687, 16.4039402], [74.35954285, 16.40398979], [74.36457062, 16.4032383], [74.36782074, 16.39846992], [74.36911011, 16.39432907], [74.36868286, 16.3911705], [74.35961151, 16.37882042], [74.36165619, 16.36474991], [74.35189819, 16.36630058], [74.35108185, 16.37676048], [74.34858704, 16.38038254], [74.34771729, 16.38601112], [74.34577179, 16.38952065], [74.34306335, 16.39067078], [74.34033203, 16.3909626], [74.33596039, 16.38964272], [74.33500671, 16.38871956], [74.33474731, 16.38285828], [74.33255005, 16.3755703], [74.32546234, 16.37924957], [74.32776642, 16.37034035], [74.32762909, 16.36811066], [74.33223724, 16.35695076], [74.33152008, 16.35556984], [74.32370758, 16.35361099], [74.33156586, 16.34649086], [74.33439636, 16.34052277], [74.32823181, 16.34110069], [74.32345581, 16.33989143], [74.32480621, 16.33666992], [74.32911682, 16.3325901], [74.32727814, 16.32920074], [74.32401276, 16.32742119], [74.32302094, 16.32512283], [74.32993317, 16.3223629], [74.33335876, 16.32374191], [74.33727264, 16.32339287], [74.3400116, 16.31693077], [74.33569336, 16.31500053], [74.33152008, 16.31641006], [74.33101654, 16.31502151], [74.33210754, 16.3107605], [74.34059143, 16.31162071], [74.34233093, 16.30509186], [74.34012604, 16.30398941], [74.34115601, 16.30282021], [74.34484863, 16.30326843], [74.34871674, 16.29146957], [74.34268188, 16.28877068], [74.33637238, 16.29017067], [74.33178711, 16.2861805], [74.33215332, 16.28409958], [74.32932281, 16.28106117], [74.32868958, 16.27943039], [74.33065796, 16.27293968], [74.33383942, 16.26807022], [74.33705139, 16.26572037], [74.34041595, 16.2675705], [74.34390259, 16.27212143], [74.34945679, 16.27326965], [74.3493576, 16.27506065], [74.35074615, 16.27625847], [74.35212708, 16.27448273], [74.35514069, 16.27449036], [74.35986328, 16.27960968], [74.3603363, 16.28190994], [74.35169983, 16.28820992], [74.35328674, 16.2918396], [74.35459137, 16.28976059], [74.35611725, 16.29092026], [74.35853577, 16.28880119], [74.36257172, 16.28713989], [74.36960602, 16.29072189], [74.37377167, 16.29031944], [74.38006592, 16.2935009], [74.38742065, 16.29034805], [74.39038086, 16.29024124], [74.39126587, 16.27560043], [74.40075684, 16.27625084], [74.41802216, 16.28092957], [74.4212265, 16.28059006], [74.42159271, 16.27145958], [74.42082214, 16.26387978], [74.42253113, 16.2574501], [74.4363327, 16.25476837], [74.44094086, 16.25266075], [74.44184113, 16.25415039], [74.44277954, 16.2495594], [74.46122742, 16.24843025], [74.4614563, 16.24377823], [74.46343231, 16.24183083], [74.47318268, 16.23851967], [74.47606659, 16.23903084], [74.48079681, 16.24432945], [74.48412323, 16.2467308], [74.49482727, 16.23801994], [74.49507141, 16.23596954], [74.50311279, 16.23104095], [74.5083313, 16.22294044], [74.50772095, 16.22128105], [74.50296021, 16.21622086], [74.50211334, 16.21413994], [74.5031662, 16.2115612], [74.51329803, 16.2012291], [74.51322937, 16.19922066], [74.51081085, 16.19881821], [74.51252747, 16.19584084], [74.51288605, 16.18939972], [74.51287842, 16.18826294], [74.50908661, 16.18783951], [74.50177002, 16.18543053], [74.49781799, 16.18133926], [74.49532318, 16.16900063], [74.49466705, 16.15504074], [74.48996735, 16.14722252], [74.48580933, 16.14698982], [74.48710632, 16.1430912], [74.49095154, 16.1420002], [74.49710846, 16.11236954], [74.49640656, 16.10157967], [74.49349976, 16.09859276], [74.49263, 16.09553909], [74.49279785, 16.09283829], [74.490448, 16.09037018], [74.48908997, 16.08732033], [74.4818573, 16.08696938], [74.47891235, 16.08789063], [74.47796631, 16.09189987], [74.4645462, 16.10211182], [74.46000671, 16.102911], [74.45491028, 16.10267067], [74.44452667, 16.10518074], [74.43795013, 16.10816002], [74.4345932, 16.1106205], [74.42276001, 16.10256958], [74.41845703, 16.10089111], [74.41607666, 16.09600067], [74.41520691, 16.09181976], [74.40760803, 16.09069824], [74.40406036, 16.09097862], [74.39731598, 16.08712959], [74.39830017, 16.08011818], [74.39724731, 16.07838821], [74.39045715, 16.07992935], [74.38680267, 16.07809067], [74.3809967, 16.07826042], [74.3795929, 16.07682037], [74.3806076, 16.07302094], [74.38008118, 16.06958008], [74.37510681, 16.06336975], [74.37098694, 16.05957031], [74.36815643, 16.05295944], [74.37075043, 16.05101967], [74.38014221, 16.05476761], [74.38173676, 16.05356979], [74.37888336, 16.04339981], [74.37822723, 16.03926086], [74.37858582, 16.03662109], [74.3900528, 16.03512955], [74.39607239, 16.03960037], [74.40931702, 16.04533005], [74.40960693, 16.04709816], [74.41121674, 16.04901123], [74.4155426, 16.05105972], [74.4229126, 16.05319023], [74.43213654, 16.05513191], [74.4363327, 16.05673027], [74.44048309, 16.05702019], [74.44803619, 16.05240059], [74.45587158, 16.05216026], [74.46383667, 16.0477314], [74.46795654, 16.04669952], [74.47027588, 16.0405407], [74.467659, 16.03364944], [74.46710205, 16.03026962], [74.46391296, 16.02256012], [74.45643616, 16.00890923], [74.45336914, 16.00580978], [74.44966888, 15.99853134], [74.45017242, 15.99260139], [74.44843292, 15.98829079], [74.44847107, 15.9864006], [74.4499588, 15.98323059], [74.44394684, 15.9743309], [74.44229126, 15.9654789], [74.43522644, 15.95116997], [74.41226959, 15.92520046], [74.40203857, 15.9110508], [74.39186859, 15.90115929], [74.39234924, 15.89926147], [74.39836121, 15.8977108], [74.39930725, 15.89577103], [74.40164185, 15.88726997], [74.40254974, 15.87826061], [74.39919281, 15.87434959], [74.41221619, 15.85763931], [74.41158295, 15.85259056], [74.4065094, 15.8519001], [74.40312195, 15.84895992], [74.39343262, 15.8517704], [74.39228821, 15.85744953], [74.3884964, 15.8572197], [74.38794708, 15.86394119], [74.38556671, 15.87323093], [74.38313293, 15.87776184], [74.3765564, 15.8849411], [74.37277985, 15.88768959], [74.3744812, 15.88994122], [74.37412262, 15.89161015], [74.37052155, 15.8903904], [74.3706131, 15.88000202], [74.36997986, 15.87568092], [74.36743164, 15.87321854], [74.36702728, 15.87109089], [74.3640976, 15.87016106], [74.35295868, 15.85924053], [74.35340118, 15.85573196], [74.34453583, 15.85205078], [74.3463974, 15.84934998], [74.3537674, 15.84810066], [74.38741302, 15.8471117], [74.38931274, 15.84414005], [74.38944244, 15.83631134], [74.38626862, 15.83326244], [74.37454987, 15.82750034], [74.37336731, 15.82583237], [74.3707428, 15.81722069], [74.36637115, 15.81549072], [74.36915588, 15.81216145], [74.37400818, 15.81044102], [74.37454987, 15.80452156], [74.37580109, 15.80120087], [74.37551117, 15.79671955], [74.37084198, 15.78218174], [74.36789703, 15.7816], [74.36485291, 15.77365112], [74.35093689, 15.76336002], [74.34677124, 15.76311016], [74.34227753, 15.76552105], [74.33454132, 15.76767921], [74.32975006, 15.77038002], [74.32756805, 15.76820087], [74.32495117, 15.76130009], [74.32408142, 15.75652981], [74.31864929, 15.75341034], [74.31465149, 15.75214863], [74.31299591, 15.7482996], [74.29216766, 15.73931122], [74.28494263, 15.74331093], [74.2740097, 15.75312042], [74.27086639, 15.75191021], [74.2660675, 15.74702072], [74.25892639, 15.74339104], [74.25006866, 15.74118042], [74.24386597, 15.74440002], [74.23898315, 15.75214005], [74.23523712, 15.75397015], [74.23516846, 15.75961113], [74.24034119, 15.78075027], [74.23892975, 15.78454018], [74.23549652, 15.7868309], [74.22734833, 15.78567123], [74.22247314, 15.78170109], [74.21740723, 15.77876091], [74.21570587, 15.77387047], [74.2146225, 15.76599121], [74.2113266, 15.75858974], [74.20439911, 15.7534008], [74.19706726, 15.75022125], [74.17115021, 15.74995041], [74.1676712, 15.74925041], [74.16226959, 15.74207115], [74.16013336, 15.73434925], [74.1553421, 15.73228168], [74.1505127, 15.7317009], [74.14737701, 15.73007107], [74.14296722, 15.72719097], [74.14186859, 15.72317886], [74.14045715, 15.7216711], [74.13485718, 15.72218132], [74.13062286, 15.71792126], [74.13475037, 15.71603203], [74.13553619, 15.70925236], [74.13891602, 15.70634079], [74.1415329, 15.70036125], [74.13889313, 15.69903183], [74.14042664, 15.69456005], [74.13887787, 15.68622971], [74.13359833, 15.67840099], [74.12700653, 15.67374039], [74.11752319, 15.67078018], [74.10624695, 15.67064095], [74.10056305, 15.67234993], [74.0965271, 15.6708498], [74.09802246, 15.6659708], [74.10453033, 15.65920162], [74.11205292, 15.6550312], [74.12136841, 15.65367031], [74.12602997, 15.65028954], [74.12275696, 15.64522076], [74.11263275, 15.64308071], [74.10804749, 15.63887024], [74.10243988, 15.63896084], [74.08055115, 15.62617016], [74.0735321, 15.62667179], [74.06770325, 15.62471199], [74.05680084, 15.62272167], [74.03929901, 15.62085056], [74.03557587, 15.60929108], [74.02793121, 15.60459995], [74.01317596, 15.60934067], [74.00784302, 15.60829926], [74.002388, 15.6090517], [73.998703, 15.61112976], [73.99294281, 15.61631107], [73.99021149, 15.62063026], [73.98606873, 15.62338066], [73.98142242, 15.62503147], [73.97598267, 15.62894154], [73.96926117, 15.64432144], [73.97072601, 15.64966106], [73.97422791, 15.65467072], [73.97570038, 15.65978146], [73.97158813, 15.66839123], [73.97219849, 15.67669201], [73.97130585, 15.68725109], [73.96573639, 15.69502068], [73.95723724, 15.6967392], [73.9586792, 15.70125198], [73.9560318, 15.70479107], [73.95778656, 15.70735073], [73.95886993, 15.71129131], [73.95593262, 15.71692085], [73.95082092, 15.72322941], [73.94976044, 15.73263073], [73.94536591, 15.74152184], [73.92415619, 15.74282074], [73.91793823, 15.74540138], [73.91483307, 15.74549198], [73.90860748, 15.74233055], [73.8859024, 15.74726105], [73.88244629, 15.74935055], [73.88024139, 15.75255108], [73.88260651, 15.75669193], [73.88432312, 15.76462078], [73.88684082, 15.7671299], [73.88685608, 15.77029133], [73.88024902, 15.77739143], [73.87986755, 15.779212], [73.87509918, 15.78289986], [73.87483978, 15.78634071], [73.87593079, 15.79323101], [73.87349701, 15.79532146], [73.86548615, 15.79752922], [73.86158752, 15.79388046], [73.8600769, 15.78779125], [73.85579681, 15.78326035], [73.856987, 15.77822971], [73.85190582, 15.77841187], [73.84963226, 15.77602959], [73.84716797, 15.76613045], [73.84512329, 15.76336002], [73.83878326, 15.76089001], [73.84030151, 15.75620174], [73.83846283, 15.7488308], [73.83303833, 15.73775196], [73.82039642, 15.73991013], [73.81603241, 15.73526955], [73.81262207, 15.73351955], [73.80284119, 15.73219967], [73.79756927, 15.72509193], [73.79321289, 15.72366047], [73.78649139, 15.72325039], [73.77578735, 15.73053169], [73.75824738, 15.73275185], [73.74871063, 15.73057079], [73.7440567, 15.72564125], [73.7410202, 15.71872139], [73.73703766, 15.71725082], [73.73226166, 15.72058105], [73.72764587, 15.72247982], [73.72255707, 15.7228899], [73.71856689, 15.72161961], [73.71098328, 15.7202301], [73.70658875, 15.72173023], [73.70265961, 15.72491074], [73.69734192, 15.72623062], [73.69185638, 15.72690964], [73.68530273, 15.72587109], [73.68245697, 15.7252512], [73.68013763, 15.72437096], [73.68013763, 15.72486115], [73.67986298, 15.72486115], [73.67986298, 15.72514153], [73.67930603, 15.72514153], [73.67930603, 15.72542191], [73.67708588, 15.72541714], [73.67708588, 15.72569466], [73.67680359, 15.72569466], [73.67680359, 15.72597122], [73.6765213, 15.72597122], [73.6765213, 15.7262516], [73.67624664, 15.7262516], [73.67624664, 15.72653198], [73.67597198, 15.72653198], [73.67597198, 15.72681046], [73.67569733, 15.72680473], [73.67569733, 15.72708321], [73.67514038, 15.7270813], [73.67514038, 15.72764015], [73.67485809, 15.72764015], [73.67485809, 15.72791958], [73.67458344, 15.72791767], [73.67458344, 15.72819328], [73.67430878, 15.72819138], [73.67430878, 15.72875023], [73.67402649, 15.72875023], [73.67402649, 15.72902966], [73.67375183, 15.72902966], [73.67375183, 15.72931004], [73.67319489, 15.72930622], [73.67319489, 15.72986221], [73.67263794, 15.72985935], [73.67263794, 15.73013973], [73.67208099, 15.73013973], [73.67208099, 15.73069572], [73.67180634, 15.73069572], [73.67180634, 15.73097229], [73.67151642, 15.73096943], [73.67151642, 15.73124981], [73.67124939, 15.73124981], [73.67124939, 15.73096943], [73.6709671, 15.73096943], [73.6709671, 15.73124981], [73.67041779, 15.73124981], [73.67041779, 15.73153019], [73.67014313, 15.73153019], [73.67014313, 15.73124981], [73.66902924, 15.73124981], [73.66902924, 15.73096943], [73.66819763, 15.73096943], [73.66819763, 15.73153019], [73.66792297, 15.73153019], [73.66792297, 15.73180962], [73.6673584, 15.73180962], [73.6673584, 15.73236179], [73.66707611, 15.73236179], [73.66707611, 15.73264027], [73.66680908, 15.73264027], [73.66680908, 15.73347187], [73.66652679, 15.73347187], [73.66652679, 15.73458195], [73.66625214, 15.73458195], [73.66625214, 15.73486233], [73.66596985, 15.73486042], [73.66596985, 15.73513985], [73.66569519, 15.73513794], [73.66569519, 15.73569393], [73.6654129, 15.73569393], [73.6654129, 15.7359724], [73.66513824, 15.7359724], [73.66513824, 15.7365284], [73.66485596, 15.73651886], [73.66485596, 15.73736], [73.6645813, 15.73736], [73.6645813, 15.73764038], [73.66430664, 15.73764038], [73.66430664, 15.73792076], [73.66374969, 15.73791599], [73.66374969, 15.73819447], [73.6618042, 15.73819447], [73.6618042, 15.73791599], [73.66152954, 15.73791599], [73.66152954, 15.73847198], [73.6609726, 15.73847008], [73.6609726, 15.73903084], [73.66069794, 15.73903084], [73.66069794, 15.73931122], [73.65958405, 15.73930645], [73.65958405, 15.73958206], [73.65930939, 15.73958206], [73.65930176, 15.7398634], [73.6590271, 15.73985958], [73.6590271, 15.74014091], [73.65875244, 15.74014091], [73.65875244, 15.7404213], [73.65847015, 15.74041557], [73.65847015, 15.74069405], [73.6581955, 15.74069405], [73.6581955, 15.74097347], [73.65598297, 15.74096966], [73.65598297, 15.74125099], [73.65569305, 15.74125099], [73.65569305, 15.7418108], [73.6554184, 15.74180698], [73.6554184, 15.74208164], [73.65458679, 15.74207973], [73.65458679, 15.74236107], [73.65402985, 15.74236107], [73.65402985, 15.74265003], [73.65374756, 15.74265003], [73.65374756, 15.74292088], [73.6534729, 15.74291706], [73.6534729, 15.74319458], [73.65319824, 15.74319458], [73.65319824, 15.74569511], [73.65291595, 15.74569511], [73.65291595, 15.74597263], [73.65180206, 15.74597263], [73.65180206, 15.74569511], [73.65097046, 15.74569511], [73.65097046, 15.74541664], [73.64902496, 15.74541664], [73.64902496, 15.74569511], [73.64848328, 15.74569035], [73.64848328, 15.74653053], [73.64901733, 15.74653053], [73.64901733, 15.74681187], [73.65097046, 15.74681187], [73.65097046, 15.74653053], [73.6526413, 15.74653053], [73.6526413, 15.74681187], [73.65319824, 15.74680519], [73.65319824, 15.74708271], [73.6534729, 15.7470808], [73.6534729, 15.74792194], [73.65319824, 15.74792194], [73.65319824, 15.74875069], [73.65429688, 15.74875069], [73.65429688, 15.74845886], [73.6554184, 15.74847317], [73.6554184, 15.74819469], [73.65597534, 15.74819469], [73.65597534, 15.74791718], [73.65651703, 15.74792194], [73.65651703, 15.74764061], [73.65735626, 15.74764061], [73.65735626, 15.74736118], [73.65763855, 15.74736118], [73.65763855, 15.74764061], [73.65820313, 15.74764061], [73.65820313, 15.74792194], [73.65847015, 15.74791718], [73.65847015, 15.74819469], [73.65875244, 15.74819469], [73.65875244, 15.74847317], [73.6590271, 15.74845886], [73.6590271, 15.74903202], [73.65930176, 15.74903202], [73.65930939, 15.74930954], [73.65958405, 15.74930477], [73.65958405, 15.74958324], [73.6598587, 15.74958134], [73.6598587, 15.74986076], [73.66014099, 15.74986076], [73.66014099, 15.75041962], [73.66041565, 15.75041676], [73.66041565, 15.75097084], [73.66069794, 15.75097084], [73.66069794, 15.75152683], [73.6609726, 15.75152683], [73.6609726, 15.75208282], [73.66152954, 15.75208282], [73.66152954, 15.7523613], [73.66208649, 15.7523613], [73.66208649, 15.75264168], [73.66236115, 15.75264168], [73.66236115, 15.75292015], [73.66347504, 15.75291538], [73.66347504, 15.75319576], [73.66402435, 15.75319576], [73.66402435, 15.75347137], [73.6645813, 15.75347137], [73.6645813, 15.75375175], [73.66485596, 15.75375175], [73.66485596, 15.75403023], [73.66513824, 15.75403023], [73.66513824, 15.75430965], [73.6654129, 15.75430965], [73.6654129, 15.75459003], [73.66570282, 15.75459003], [73.66570282, 15.7551403], [73.66596985, 15.7551403], [73.66596985, 15.75652981], [73.66652679, 15.75652981], [73.66652679, 15.75681019], [73.66680908, 15.75681019], [73.66680908, 15.75652981], [73.66764069, 15.75652981], [73.66764069, 15.75625038], [73.66792297, 15.75625038], [73.66791534, 15.75597191], [73.66819763, 15.75597191], [73.66819763, 15.75541782], [73.66929626, 15.75541973], [73.66929626, 15.7551403], [73.66986084, 15.7551403], [73.66986084, 15.75486183], [73.67041779, 15.75486183], [73.67041779, 15.75459003], [73.6709671, 15.75459003], [73.6709671, 15.75430965], [73.67124939, 15.75430965], [73.67124939, 15.75375175], [73.67151642, 15.75375175], [73.67151642, 15.75319099], [73.67208099, 15.75319576], [73.67208099, 15.75291538], [73.67263794, 15.75292015], [73.67263794, 15.75264168], [73.67402649, 15.75264168], [73.67402649, 15.75292015], [73.67430878, 15.75291538], [73.67430878, 15.75319576], [73.67457581, 15.75319099], [73.67457581, 15.75403023], [73.67430878, 15.75403023], [73.67430878, 15.75486183], [73.67402649, 15.75486183], [73.67402649, 15.7551403], [73.67346954, 15.7551403], [73.67346954, 15.75569344], [73.67292023, 15.75569344], [73.67292023, 15.75597191], [73.67208099, 15.75597191], [73.67208099, 15.75625038], [73.67151642, 15.75625038], [73.67151642, 15.75652981], [73.67124939, 15.75652981], [73.67124939, 15.75681019], [73.67069244, 15.75680637], [73.67069244, 15.75708389], [73.6701355, 15.75708389], [73.6701355, 15.75736237], [73.66986084, 15.75736046], [73.66986084, 15.75765133], [73.66929626, 15.75765133], [73.66929626, 15.75792027], [73.66874695, 15.75791645], [73.66874695, 15.7581892], [73.66791534, 15.75819588], [73.66791534, 15.75847244], [73.6673584, 15.75847244], [73.6673584, 15.75819588], [73.66680908, 15.75819588], [73.66680908, 15.75847244], [73.66570282, 15.75846863], [73.66570282, 15.75874996], [73.6654129, 15.75874996], [73.6654129, 15.75846863], [73.66486359, 15.75847244], [73.66486359, 15.75819588], [73.6645813, 15.7581892], [73.6645813, 15.75791645], [73.66401672, 15.75792027], [73.66401672, 15.75765133], [73.66319275, 15.75763988], [73.66319275, 15.7581892], [73.66291809, 15.75820065], [73.66291809, 15.75903034], [73.66319275, 15.75902843], [73.66319275, 15.75958443], [73.66291809, 15.75958157], [73.66291809, 15.75986195], [73.66319275, 15.75986195], [73.66319275, 15.76014042], [73.66348267, 15.76014042], [73.66348267, 15.76041985], [73.66319275, 15.76041985], [73.66319275, 15.76124954], [73.66291809, 15.76124954], [73.66291809, 15.76181126], [73.66319275, 15.76181126], [73.66319275, 15.76292133], [73.66291809, 15.76292133], [73.66291809, 15.76375008], [73.6626358, 15.76375008], [73.6626358, 15.76542091], [73.66236115, 15.76542091], [73.66236115, 15.76681995], [73.66208649, 15.76681995], [73.66208649, 15.76735973], [73.66179657, 15.76735973], [73.66179657, 15.76764107], [73.66152954, 15.76763821], [73.66153717, 15.76875114], [73.66124725, 15.76875114], [73.66124725, 15.76958942], [73.6609726, 15.76958466], [73.6609726, 15.77097321], [73.66069794, 15.7709713], [73.66069794, 15.77181244], [73.66041565, 15.77180481], [73.66041565, 15.77208328], [73.66014099, 15.77208328], [73.66014099, 15.77263927], [73.6598587, 15.77263927], [73.6598587, 15.77347088], [73.65958405, 15.77347088], [73.65958405, 15.77458286], [73.65930939, 15.77458096], [73.65930176, 15.77541924], [73.6590271, 15.77541733], [73.6590271, 15.77597332], [73.65875244, 15.77597141], [73.65875244, 15.77652931], [73.65847778, 15.77652931], [73.65847778, 15.77680969], [73.6581955, 15.77680492], [73.6581955, 15.7770834], [73.65847015, 15.7770834], [73.65847015, 15.77736092], [73.65820313, 15.77736092], [73.65820313, 15.77791977], [73.65791321, 15.77791691], [73.65791321, 15.77847099], [73.65763855, 15.77847099], [73.65763855, 15.7804203], [73.65735626, 15.7804203], [73.65735626, 15.78125191], [73.6570816, 15.78125191], [73.6570816, 15.78181934], [73.65680695, 15.78180599], [73.65680695, 15.78208447], [73.65651703, 15.78208065], [73.65651703, 15.78264046], [73.65625, 15.78264046], [73.65625, 15.78374958], [73.65598297, 15.78374958], [73.65598297, 15.78431034], [73.65569305, 15.78431034], [73.65569305, 15.78514004], [73.6554184, 15.78514004], [73.6554184, 15.78542042], [73.65569305, 15.78541565], [73.65569305, 15.78569412], [73.6554184, 15.78568935], [73.6554184, 15.78652954], [73.65513611, 15.78652763], [73.65513611, 15.78708363], [73.65486145, 15.78708363], [73.65486145, 15.7873621], [73.65458679, 15.7873621], [73.65458679, 15.78763771], [73.65429688, 15.78763103], [73.65429688, 15.78903008], [73.65402985, 15.78903008], [73.65402985, 15.79042053], [73.65374756, 15.79041576], [73.65374756, 15.79097176], [73.65402985, 15.79096985], [73.65402985, 15.79181099], [73.65458679, 15.79180622], [73.65458679, 15.79208374], [73.65625, 15.79207993], [73.65625, 15.79264069], [73.65652466, 15.79263783], [73.65652466, 15.79319382], [73.65680695, 15.79319382], [73.65680695, 15.79347229], [73.6570816, 15.79347038], [73.6570816, 15.7937603], [73.65680695, 15.7937603], [73.65680695, 15.79403114], [73.6570816, 15.79403114], [73.6570816, 15.79431057], [73.65680695, 15.79431057], [73.65680695, 15.7962513], [73.6570816, 15.7962513], [73.6570816, 15.79819489], [73.65736389, 15.79819489], [73.65736389, 15.79847336], [73.65763855, 15.79847145], [73.65763855, 15.79931164], [73.65791321, 15.79930687], [73.65791321, 15.80069542], [73.6581955, 15.80069542], [73.6581955, 15.80097294], [73.65875244, 15.80097103], [73.65875244, 15.80125141], [73.6590271, 15.80125141], [73.6590271, 15.80153084], [73.65930176, 15.80153084], [73.65930939, 15.80181026], [73.65958405, 15.80180454], [73.65958405, 15.80208302], [73.66014099, 15.80208302], [73.66014099, 15.80236053], [73.66069794, 15.80236053], [73.66069794, 15.80264091], [73.6609726, 15.80263901], [73.6609726, 15.80291653], [73.66124725, 15.80291653], [73.66124725, 15.80319309], [73.66152954, 15.80319309], [73.66152954, 15.80347347], [73.66179657, 15.80347061], [73.66179657, 15.80375099], [73.66208649, 15.80375099], [73.66208649, 15.80431175], [73.66236115, 15.80430508], [73.66236115, 15.8045826], [73.66208649, 15.80458069], [73.66208649, 15.8051424], [73.66153717, 15.8051424], [73.66153717, 15.80458069], [73.66124725, 15.8045826], [73.66124725, 15.80430508], [73.6609726, 15.80431175], [73.6609726, 15.80375099], [73.66069794, 15.80375099], [73.66069794, 15.80347061], [73.66041565, 15.80347347], [73.66041565, 15.80319309], [73.66014099, 15.80319309], [73.66014099, 15.80291653], [73.6598587, 15.80293083], [73.6598587, 15.80264091], [73.65930176, 15.80264091], [73.65930176, 15.80236053], [73.65847015, 15.80236053], [73.65847015, 15.80208302], [73.65791321, 15.80208302], [73.65791321, 15.80180454], [73.6570816, 15.80181026], [73.6570816, 15.80153084], [73.65651703, 15.80153084], [73.65651703, 15.80097103], [73.65625, 15.80097294], [73.65625, 15.80041695], [73.65598297, 15.80042171], [73.65598297, 15.80014133], [73.65625, 15.80014133], [73.65625, 15.79903126], [73.65598297, 15.79903126], [73.65598297, 15.79847145], [73.6554184, 15.79847336], [73.6554184, 15.79819489], [73.65513611, 15.79819489], [73.65513611, 15.79763889], [73.65486145, 15.7976408], [73.65486145, 15.7962513], [73.65458679, 15.7962513], [73.65458679, 15.79596996], [73.6543045, 15.79597282], [73.6543045, 15.79513836], [73.65402985, 15.79514122], [73.65402985, 15.79458046], [73.65374756, 15.79458237], [73.65374756, 15.79430676], [73.6534729, 15.79431057], [73.6534729, 15.79403114], [73.6526413, 15.79403114], [73.6526413, 15.79486275], [73.65235901, 15.79485989], [73.65235901, 15.7956953], [73.65208435, 15.7956953], [73.65208435, 15.79680538], [73.65180206, 15.79680538], [73.65180206, 15.7970829], [73.6515274, 15.79708004], [73.6515274, 15.7976408], [73.65125275, 15.7976408], [73.65125275, 15.79792118], [73.65097046, 15.79792118], [73.65097046, 15.79875088], [73.65125275, 15.79875088], [73.65125275, 15.79903126], [73.65097046, 15.79902744], [73.65097046, 15.79958344], [73.6506958, 15.79957104], [73.6506958, 15.80014133], [73.65041351, 15.80013943], [73.65041351, 15.80069542], [73.6506958, 15.8006897], [73.6506958, 15.80181026], [73.65041351, 15.80180454], [73.65041351, 15.80236053], [73.65013885, 15.80236053], [73.65013885, 15.80293083], [73.6498642, 15.80291653], [73.6498642, 15.80319309], [73.64958191, 15.80319309], [73.64958191, 15.80347347], [73.64901733, 15.80347061], [73.64901733, 15.80375099], [73.64875031, 15.80375099], [73.64875031, 15.80402946], [73.64848328, 15.80402946], [73.64848328, 15.80431175], [73.64763641, 15.80430508], [73.64763641, 15.8045826], [73.64680481, 15.8045826], [73.64680481, 15.80430508], [73.64653015, 15.80430508], [73.64653015, 15.8045826], [73.64597321, 15.80458069], [73.64597321, 15.80486107], [73.64541626, 15.80486107], [73.64541626, 15.80542183], [73.64485931, 15.80542183], [73.64485931, 15.8057003], [73.64458466, 15.80569458], [73.64458466, 15.80597115], [73.64430237, 15.80597115], [73.64430237, 15.80653191], [73.64458466, 15.80652714], [73.64458466, 15.80708313], [73.64430237, 15.80708122], [73.64430237, 15.80764198], [73.64458466, 15.80764008], [73.64458466, 15.80819321], [73.64430237, 15.80819321], [73.64430237, 15.80958366], [73.64402771, 15.8095789], [73.64402771, 15.81013966], [73.64375305, 15.81013966], [73.64375305, 15.81097221], [73.64319611, 15.81096935], [73.64319611, 15.81124973], [73.64208221, 15.81124973], [73.64208221, 15.81096935], [73.64041138, 15.81096935], [73.64041138, 15.81153011], [73.64013672, 15.81153011], [73.64013672, 15.81264019], [73.63986206, 15.81264019], [73.63986206, 15.81291962], [73.63957977, 15.8129158], [73.63957977, 15.81319427], [73.63930511, 15.81319427], [73.63931274, 15.81347179], [73.63903046, 15.81347179], [73.63903046, 15.81375027], [73.63874817, 15.81375027], [73.63874817, 15.81402969], [73.63764191, 15.81402969], [73.63764191, 15.81431103], [73.63735199, 15.81431103], [73.63735199, 15.81487083], [73.63707733, 15.81487083], [73.63707733, 15.81514168], [73.63680267, 15.81514168], [73.63680267, 15.81542015], [73.63652802, 15.81541634], [73.63652802, 15.81569386], [73.63625336, 15.81569386], [73.63625336, 15.81708431], [73.63652802, 15.81707954], [73.63652802, 15.8176403], [73.63680267, 15.8176403], [73.63680267, 15.81793022], [73.63764191, 15.81791592], [73.63764191, 15.81819439], [73.63791656, 15.81819439], [73.63791656, 15.81791592], [73.63819122, 15.81793022], [73.63819122, 15.8176403], [73.63846588, 15.8176403], [73.63846588, 15.81793022], [73.63903046, 15.81791592], [73.63903046, 15.81958199], [73.63874817, 15.81958199], [73.63874817, 15.81986332], [73.63903046, 15.81986046], [73.63903046, 15.82042122], [73.63874817, 15.82042122], [73.63874817, 15.8215313], [73.63847351, 15.82152939], [73.63847351, 15.82208157], [73.63819122, 15.82207966], [73.63819122, 15.8229208], [73.63791656, 15.82291698], [73.63791656, 15.82319546], [73.63764191, 15.82318974], [73.63764191, 15.82431126], [73.63735962, 15.82430458], [73.63735962, 15.82458305], [73.63708496, 15.82458305], [73.63708496, 15.82569504], [73.63680267, 15.82569027], [73.63680267, 15.82653141], [73.63652802, 15.82652664], [73.63652802, 15.82708263], [73.63625336, 15.82708073], [73.63625336, 15.82764053], [73.63597107, 15.82763863], [73.63597107, 15.82847309], [73.63569641, 15.82847309], [73.63569641, 15.82958317], [73.63540649, 15.82958126], [73.63540649, 15.82987022], [73.63513947, 15.82987022], [73.63513947, 15.83041859], [73.63485718, 15.83041859], [73.63485718, 15.83153152], [73.63458252, 15.83152676], [73.63458252, 15.83236122], [73.63430786, 15.83236122], [73.63430786, 15.83319473], [73.6340332, 15.83319092], [73.6340332, 15.83403015], [73.63375092, 15.83402729], [73.63375092, 15.83458328], [73.63346863, 15.83458138], [73.63346863, 15.83514023], [73.63319397, 15.83514023], [73.63319397, 15.83569336], [73.63291931, 15.83569336], [73.63291931, 15.83597088], [73.63263702, 15.83597088], [73.63263702, 15.83681011], [73.63236237, 15.83681011], [73.63236237, 15.83763981], [73.63208008, 15.83763981], [73.63208008, 15.8381958], [73.63180542, 15.8381958], [73.63180542, 15.83958435], [73.63153076, 15.83958244], [73.63153076, 15.83986187], [73.63124847, 15.83986187], [73.63124847, 15.84041977], [73.63096619, 15.84041977], [73.63096619, 15.84152985], [73.63069153, 15.84152794], [73.63069153, 15.84208393], [73.63041687, 15.84208202], [73.63041687, 15.84263992], [73.63014221, 15.84263802], [73.63014221, 15.84319401], [73.62985992, 15.84318924], [73.62985992, 15.84431076], [73.6295929, 15.84431076], [73.6295929, 15.84514046], [73.62930298, 15.84514046], [73.62930298, 15.84542084], [73.62958527, 15.84541607], [73.62958527, 15.84569359], [73.62930298, 15.84568977], [73.62930298, 15.84624958], [73.62902832, 15.84624958], [73.62902832, 15.84653091], [73.62875366, 15.84652805], [73.62875366, 15.84708214], [73.62847137, 15.84708214], [73.62847137, 15.84736347], [73.62819672, 15.84736347], [73.62819672, 15.84791565], [73.62791443, 15.84791565], [73.62791443, 15.8484726], [73.62763977, 15.84846973], [73.62763977, 15.84903145], [73.62735748, 15.84903145], [73.62735748, 15.84931087], [73.62708282, 15.84931087], [73.62708282, 15.85014057], [73.62680817, 15.85013866], [73.62680817, 15.85069466], [73.62652588, 15.8506918], [73.62652588, 15.85125065], [73.62625122, 15.85125065], [73.62625122, 15.85153103], [73.62652588, 15.85153103], [73.62652588, 15.85181141], [73.62625122, 15.85180473], [73.62625122, 15.85208321], [73.62596893, 15.85208035], [73.62596893, 15.85264111], [73.62541199, 15.85264111], [73.62541199, 15.85292053], [73.62513733, 15.85291672], [73.62513733, 15.8534708], [73.62458038, 15.8534708], [73.62458038, 15.85375118], [73.62431335, 15.85375118], [73.62431335, 15.85404015], [73.62374878, 15.85404015], [73.62374878, 15.85431194], [73.62347412, 15.85430527], [73.62347412, 15.85458279], [73.62291718, 15.85458088], [73.62291718, 15.85514069], [73.62264252, 15.85514069], [73.62264252, 15.85542202], [73.62236023, 15.85541725], [73.62236023, 15.85569477], [73.6220932, 15.85569096], [73.6220932, 15.85625076], [73.62180328, 15.85625076], [73.62180328, 15.85652924], [73.62152863, 15.85652924], [73.62152863, 15.85680962], [73.62124634, 15.85680485], [73.62124634, 15.85708332], [73.62152863, 15.85708141], [73.62152863, 15.85763931], [73.62180328, 15.85763931], [73.62180328, 15.85791969], [73.62152863, 15.85791683], [73.62152863, 15.85847092], [73.62124634, 15.85847092], [73.62124634, 15.8587513], [73.62014008, 15.8587513], [73.62014008, 15.85819054], [73.61985779, 15.8581953], [73.61985779, 15.85763931], [73.61902618, 15.85763931], [73.61902618, 15.85736084], [73.61846924, 15.85736084], [73.61846924, 15.85708141], [73.61819458, 15.85708332], [73.61819458, 15.85680485], [73.61763763, 15.85680962], [73.61763763, 15.85514069], [73.61791992, 15.85514069], [73.61791992, 15.85458088], [73.61819458, 15.85458279], [73.61819458, 15.85430527], [73.61875153, 15.85431194], [73.61875153, 15.85404015], [73.61902618, 15.85404015], [73.61902618, 15.85375118], [73.61930847, 15.85375118], [73.61930847, 15.85236073], [73.61875153, 15.85236073], [73.61875153, 15.85208035], [73.61818695, 15.85208035], [73.61818695, 15.85264111], [73.61791992, 15.85264111], [73.61791992, 15.85292053], [73.61708069, 15.85291672], [73.61708069, 15.85319519], [73.61569214, 15.85319519], [73.61569214, 15.85291672], [73.61541748, 15.85291672], [73.61541748, 15.85319519], [73.61513519, 15.85319519], [73.61513519, 15.8534708], [73.61486053, 15.8534708], [73.61486053, 15.85375118], [73.61429596, 15.85375118], [73.61429596, 15.85404015], [73.61374664, 15.85404015], [73.61374664, 15.85431194], [73.61319733, 15.85430527], [73.61319733, 15.85458279], [73.61292267, 15.85458088], [73.61292267, 15.85514069], [73.61319733, 15.85513878], [73.61319733, 15.85597324], [73.61292267, 15.85597134], [73.61292267, 15.85652924], [73.61264038, 15.85652924], [73.61264038, 15.85708332], [73.61235809, 15.85708141], [73.61235809, 15.85763931], [73.61208344, 15.85763931], [73.61208344, 15.8581953], [73.61180878, 15.8581953], [73.61180878, 15.85847092], [73.61152649, 15.85847092], [73.61152649, 15.85931015], [73.61125183, 15.85930538], [73.61125183, 15.8595829], [73.61096954, 15.8595829], [73.61096954, 15.85986137], [73.61125183, 15.85984993], [73.61125183, 15.86014175], [73.61096954, 15.86014175], [73.61096954, 15.86264038], [73.61069489, 15.86263657], [73.61069489, 15.86347198], [73.61042786, 15.86347198], [73.61042786, 15.86403179], [73.61013794, 15.86403179], [73.61013794, 15.86431026], [73.60986328, 15.86430645], [73.60986328, 15.86486244], [73.60958099, 15.86485958], [73.60958099, 15.86513996], [73.60986328, 15.86513996], [73.60986328, 15.86542034], [73.61013794, 15.86541557], [73.61013794, 15.86569405], [73.61042786, 15.86568928], [73.61042786, 15.86653042], [73.61013794, 15.86653042], [73.61013794, 15.86791992], [73.60986328, 15.86791992], [73.60986328, 15.86874962], [73.60958099, 15.86874962], [73.60958099, 15.86903858], [73.60930634, 15.86903858], [73.60930634, 15.86931133], [73.60901642, 15.86931133], [73.60902405, 15.8698597], [73.6084671, 15.8698597], [73.6084671, 15.87125015], [73.60874939, 15.87125015], [73.60874939, 15.87153053], [73.6084671, 15.87153053], [73.6084671, 15.87181091], [73.60819244, 15.87180614], [73.60819244, 15.87208366], [73.60791779, 15.87207985], [73.60791779, 15.87263966], [73.6076355, 15.87263775], [73.6076355, 15.87319374], [73.60736084, 15.87319374], [73.60736084, 15.87347221], [73.60708618, 15.87347031], [73.60708618, 15.87374973], [73.60679626, 15.87374973], [73.60679626, 15.87403107], [73.60652924, 15.87402821], [73.60652924, 15.87458229], [73.60624695, 15.87458038], [73.60624695, 15.87542057], [73.60597229, 15.8754158], [73.60597229, 15.87569523], [73.60569763, 15.87569046], [73.60569763, 15.87625122], [73.60541534, 15.87625122], [73.60541534, 15.8773613], [73.60514069, 15.8773613], [73.60514069, 15.8779211], [73.6048584, 15.8779211], [73.6048584, 15.8787508], [73.60457611, 15.8787508], [73.60457611, 15.87986088], [73.60430145, 15.87986088], [73.60430145, 15.88014126], [73.60402679, 15.88014126], [73.60402679, 15.88097954], [73.60375214, 15.88097954], [73.60375214, 15.88153076], [73.60346985, 15.88152695], [73.60346985, 15.88208294], [73.6029129, 15.88208294], [73.6029129, 15.88236141], [73.60320282, 15.88236141], [73.60320282, 15.88264084], [73.6029129, 15.88264084], [73.6029129, 15.88291931], [73.60263824, 15.8829174], [73.60263824, 15.88319302], [73.6029129, 15.88319111], [73.6029129, 15.88514233], [73.60235596, 15.88514233], [73.60235596, 15.88542175], [73.60152435, 15.88541698], [73.60152435, 15.88569546], [73.60097504, 15.88569546], [73.60097504, 15.88597107], [73.59958649, 15.88597107], [73.59958649, 15.88625145], [73.59929657, 15.88625145], [73.59929657, 15.88653183], [73.59874725, 15.88653183], [73.59874725, 15.88792038], [73.5984726, 15.88791847], [73.5984726, 15.88819313], [73.59874725, 15.88819313], [73.59874725, 15.88847446], [73.59929657, 15.88847065], [73.59929657, 15.88875198], [73.59958649, 15.88875198], [73.59958649, 15.88903046], [73.59986115, 15.88903046], [73.59986115, 15.88931179], [73.59958649, 15.88930607], [73.59958649, 15.88986206], [73.59874725, 15.8898592], [73.59874725, 15.89015102], [73.5984726, 15.89015102], [73.5984726, 15.89041996], [73.59819794, 15.89041805], [73.59819794, 15.89069366], [73.59708405, 15.89069366], [73.59708405, 15.89097214], [73.59680939, 15.89096928], [73.59680176, 15.89153004], [73.5965271, 15.89153004], [73.5965271, 15.89235973], [73.59680176, 15.89235973], [73.59680176, 15.89264202], [73.5965271, 15.89264202], [73.5965271, 15.89291954], [73.59680176, 15.89291573], [73.59680176, 15.89347172], [73.5965271, 15.89347172], [73.5965271, 15.89375019], [73.59680176, 15.89375019], [73.59680176, 15.89431095], [73.5965271, 15.89431095], [73.5965271, 15.89513969], [73.59625244, 15.89513779], [73.59625244, 15.89569378], [73.59597015, 15.89569187], [73.59597015, 15.89653015], [73.59570313, 15.89653015], [73.59570313, 15.89681053], [73.59541321, 15.89680576], [73.59541321, 15.89735985], [73.59513855, 15.89735985], [73.59513855, 15.89764023], [73.59485626, 15.89764023], [73.59485626, 15.89792061], [73.5945816, 15.89791584], [73.5945816, 15.89847183], [73.59430695, 15.89846992], [73.59430695, 15.89875031], [73.59402466, 15.89875031], [73.59402466, 15.89902782], [73.59375, 15.89901924], [73.59375, 15.89931107], [73.59319305, 15.8993063], [73.59319305, 15.89958191], [73.59263611, 15.89958382], [73.59263611, 15.89986229], [73.59208679, 15.89986038], [73.59208679, 15.90014267], [73.59179688, 15.90014267], [73.59179688, 15.90042114], [73.59124756, 15.90042114], [73.59124756, 15.90125275], [73.5909729, 15.90125275], [73.5909729, 15.90181065], [73.59124756, 15.90181065], [73.59124756, 15.9026413], [73.5909729, 15.9026413], [73.5909729, 15.90375137], [73.59069824, 15.90375137], [73.59069824, 15.90486145], [73.59041595, 15.90486145], [73.59041595, 15.90597343], [73.5901413, 15.90597057], [73.5901413, 15.90653133], [73.58985901, 15.90653133], [73.58985901, 15.90681171], [73.58957672, 15.90681171], [73.58957672, 15.90736103], [73.58930206, 15.90736103], [73.58930206, 15.90764141], [73.5890274, 15.90764141], [73.5890274, 15.90792084], [73.58875275, 15.90791702], [73.58875275, 15.90819454], [73.58847046, 15.90819454], [73.58847046, 15.90847301], [73.5881958, 15.90847111], [73.5881958, 15.90903091], [73.58791351, 15.90902901], [73.58791351, 15.90958309], [73.58985901, 15.90958309], [73.58985901, 15.90930462], [73.59069824, 15.90930462], [73.59069824, 15.90948009], [73.59069824, 15.91181183], [73.59041595, 15.91180515], [73.59041595, 15.91236115], [73.58985901, 15.91236115], [73.58985901, 15.91208267], [73.58930206, 15.91208267], [73.58930206, 15.91180515], [73.5890274, 15.91181183], [73.5890274, 15.91152859], [73.58875275, 15.91152859], [73.58875275, 15.9109602], [73.58847046, 15.9109726], [73.58847046, 15.91069508], [73.5881958, 15.91069508], [73.5881958, 15.9104166], [73.58680725, 15.9104166], [73.58680725, 15.91013908], [73.58625793, 15.91014099], [73.58625793, 15.90986061], [73.58597565, 15.90986061], [73.58597565, 15.90930462], [73.58569336, 15.90930462], [73.58569336, 15.90986061], [73.5854187, 15.90986061], [73.5854187, 15.90958309], [73.58513641, 15.90958309], [73.58513641, 15.90986061], [73.58180237, 15.90986061], [73.58180237, 15.91014099], [73.57930756, 15.91014099], [73.57930756, 15.90986061], [73.57875061, 15.90986061], [73.57875061, 15.91041946], [73.57847595, 15.91041946], [73.57847595, 15.91152859], [73.57736206, 15.91152859], [73.57736206, 15.91181183], [73.57681274, 15.91181183], [73.57681274, 15.91152859], [73.57624817, 15.91152859], [73.57624817, 15.91181183], [73.57402802, 15.91180515], [73.57402802, 15.91208267], [73.57236481, 15.91208267], [73.57236481, 15.91180515], [73.57152557, 15.91180515], [73.57152557, 15.91208267], [73.57013702, 15.91208267], [73.57013702, 15.91236115], [73.56958008, 15.91236115], [73.56958008, 15.91264153], [73.56874847, 15.91263866], [73.56874847, 15.91319466], [73.56846619, 15.91319084], [73.56846619, 15.91431046], [73.56819153, 15.91431046], [73.56819153, 15.91514015], [73.56791687, 15.91514015], [73.56791687, 15.91569328], [73.56764221, 15.91569138], [73.56764221, 15.9159708], [73.56735992, 15.9159708], [73.56735992, 15.91624928], [73.56708527, 15.91624928], [73.56708527, 15.91847229], [73.56680298, 15.91846943], [73.56680298, 15.91874981], [73.56624603, 15.91874981], [73.56624603, 15.91903019], [73.56597137, 15.91903019], [73.56597137, 15.91930962], [73.56569672, 15.9193058], [73.56569672, 15.91958427], [73.5654068, 15.91958237], [73.5654068, 15.91986179], [73.56513977, 15.91986179], [73.56513977, 15.92014027], [73.56402588, 15.92013073], [73.56402588, 15.92041969], [73.56375122, 15.92041588], [73.56375122, 15.92069435], [73.56346893, 15.92069435], [73.56346893, 15.92097187], [73.56263733, 15.92097187], [73.56263733, 15.92125034], [73.56181335, 15.92125034], [73.56181335, 15.92152977], [73.56124878, 15.92152977], [73.56124878, 15.9218111], [73.56069183, 15.92180634], [73.56069183, 15.92236233], [73.55986023, 15.92236042], [73.55986023, 15.92263985], [73.55930328, 15.92263794], [73.55930328, 15.92319393], [73.55902863, 15.92319202], [73.55902863, 15.92374992], [73.55874634, 15.92374992], [73.55874634, 15.9240303], [73.55819702, 15.9240303], [73.55819702, 15.92431068], [73.55708313, 15.92430592], [73.55708313, 15.92458439], [73.55652618, 15.92457962], [73.55652618, 15.92486], [73.55596924, 15.92486], [73.55596924, 15.92514038], [73.55568695, 15.92514038], [73.55568695, 15.92542076], [73.55541992, 15.92541599], [73.55541992, 15.92569447], [73.55513763, 15.92569447], [73.55513763, 15.92597198], [73.55486298, 15.92597008], [73.55486298, 15.9262619], [73.55403137, 15.9262619], [73.55403137, 15.92681122], [73.55208588, 15.92680645], [73.55208588, 15.9273634], [73.54957581, 15.92735958], [73.54957581, 15.92764091], [73.54930878, 15.92763805], [73.54930878, 15.92819405], [73.54875183, 15.92819405], [73.54875183, 15.92847157], [73.54846954, 15.92846966], [73.54846954, 15.92875099], [73.54792023, 15.92875099], [73.54792023, 15.92903137], [73.54763794, 15.92903137], [73.54763794, 15.92932034], [73.54708099, 15.92930698], [73.54708099, 15.92958546], [73.54680634, 15.92957973], [73.54680634, 15.93014145], [73.54651642, 15.93014145], [73.54651642, 15.93042088], [73.54624939, 15.93041706], [73.54624939, 15.93069458], [73.5459671, 15.93068981], [73.5459671, 15.93125057], [73.54585266, 15.93125057], [73.54541779, 15.93125057], [73.54541779, 15.93153095], [73.54514313, 15.93153095], [73.54514313, 15.93181133], [73.54458618, 15.93181133], [73.54458618, 15.93236065], [73.54402924, 15.93236065], [73.54402924, 15.93264103], [73.54374695, 15.93264103], [73.54374695, 15.93292141], [73.54347229, 15.93291664], [73.54347229, 15.93347263], [73.54319763, 15.93347073], [73.54319763, 15.93375111], [73.54264069, 15.93375111], [73.54264069, 15.93403053], [73.5423584, 15.93403053], [73.5423584, 15.93431187], [73.54180908, 15.93430519], [73.54180908, 15.93458271], [73.54152679, 15.93458271], [73.54152679, 15.9351387], [73.54096985, 15.9351387], [73.54096985, 15.93569469], [73.54069519, 15.93569469], [73.54069519, 15.93597317], [73.54013824, 15.93597126], [73.54013824, 15.93653107], [73.53848267, 15.93653107], [73.53848267, 15.93680954], [73.53819275, 15.93680477], [73.53819275, 15.93708324], [73.53708649, 15.93708134], [73.53708649, 15.93763924], [73.53514862, 15.93763924], [73.53514862, 15.93736076], [73.5348587, 15.93736076], [73.5348587, 15.93653107], [73.53457642, 15.93653107], [73.53457642, 15.93597126], [73.53430176, 15.93597317], [73.53430176, 15.93569469], [73.5340271, 15.93569469], [73.5340271, 15.9351387], [73.53375244, 15.9351387], [73.53375244, 15.93458271], [73.5331955, 15.93458271], [73.5331955, 15.93402672], [73.53292847, 15.93403053], [73.53291321, 15.93375111], [73.53263855, 15.93375111], [73.53263855, 15.93347073], [73.53236389, 15.93347263], [73.53236389, 15.93319511], [73.5320816, 15.93319511], [73.5320816, 15.93291664], [73.53069305, 15.93291664], [73.53069305, 15.93319511], [73.52958679, 15.93319035], [73.52958679, 15.93375111], [73.5284729, 15.93375111], [73.5284729, 15.93403053], [73.52791595, 15.93403053], [73.52791595, 15.93431187], [73.5276413, 15.93430519], [73.5276413, 15.93458271], [73.5265274, 15.93458271], [73.5265274, 15.93486118], [73.52625275, 15.93486118], [73.52625275, 15.9351387], [73.52596283, 15.93513203], [73.52596283, 15.93542194], [73.5256958, 15.93541718], [73.5256958, 15.93597317], [73.52540588, 15.93597126], [73.52540588, 15.93625069], [73.52485657, 15.93625069], [73.52485657, 15.93653107], [73.52458191, 15.93652916], [73.52458191, 15.93667126], [73.52458191, 15.93680954], [73.52402496, 15.93680477], [73.52402496, 15.93708324], [73.52375031, 15.93708134], [73.52375031, 15.93736076], [73.52348328, 15.93736076], [73.52348328, 15.93763924], [73.5229187, 15.93763924], [73.5229187, 15.93791866], [73.52263641, 15.93791866], [73.52263641, 15.9382], [73.5220871, 15.9382], [73.5220871, 15.93847084], [73.52131653, 15.93847084], [73.52041626, 15.93847084], [73.52041626, 15.93875122], [73.5201416, 15.93875122], [73.5201416, 15.93847084], [73.51957703, 15.93847084], [73.51957703, 15.9382], [73.51930237, 15.9382], [73.51930237, 15.93847084], [73.51790619, 15.93847084], [73.51790619, 15.9382], [73.51708221, 15.9382], [73.51708221, 15.93791866], [73.51680756, 15.93791866], [73.51680756, 15.9382], [73.51652527, 15.93819523], [73.5165329, 15.93875122], [73.51625061, 15.93875122], [73.51625061, 15.93931198], [73.51431274, 15.93931198], [73.51431274, 15.9390316], [73.51402283, 15.9390316], [73.51402283, 15.93875122], [73.51374817, 15.93875122], [73.51374817, 15.93847084], [73.51346588, 15.93847084], [73.51346588, 15.9382], [73.51319122, 15.9382], [73.51319122, 15.93763924], [73.51291656, 15.93763924], [73.51291656, 15.93708134], [73.51264191, 15.93708324], [73.51264191, 15.93680477], [73.51069641, 15.93680477], [73.51069641, 15.93708324], [73.51013947, 15.93708134], [73.51013947, 15.93736076], [73.50985718, 15.93736076], [73.50985718, 15.93791866], [73.50958252, 15.93791866], [73.50958252, 15.9390316], [73.50986481, 15.93902683], [73.50986481, 15.93958282], [73.51013947, 15.93958092], [73.51013947, 15.94014168], [73.50986481, 15.94013882], [73.50986481, 15.94069481], [73.50958252, 15.94069099], [73.50958252, 15.94153023], [73.50930786, 15.94153023], [73.50930786, 15.94180965], [73.5090332, 15.94180965], [73.5090332, 15.9426403], [73.50875092, 15.9426403], [73.50875092, 15.94319344], [73.50846863, 15.94319057], [73.50846863, 15.94375038], [73.50818634, 15.94375038], [73.50818634, 15.94402981], [73.50791931, 15.9440279], [73.50791931, 15.94458389], [73.50736237, 15.94458389], [73.50736237, 15.94486237], [73.50708008, 15.94485855], [73.50708008, 15.94542027], [73.50680542, 15.94541645], [73.50681305, 15.9456892], [73.50653076, 15.94569588], [73.50653076, 15.94597244], [73.50624847, 15.94597244], [73.50624847, 15.94625187], [73.50597382, 15.94624996], [73.50597382, 15.94708443], [73.50569153, 15.94708443], [73.50569153, 15.94819355], [73.50541687, 15.94819164], [73.50541687, 15.94931126], [73.50514221, 15.94930553], [73.50514221, 15.94958401], [73.50485992, 15.94958401], [73.50485992, 15.94986153], [73.5045929, 15.94985962], [73.5045929, 15.95042133], [73.50402832, 15.95041561], [73.50402832, 15.9509716], [73.50374603, 15.9509697], [73.50374603, 15.95125008], [73.50319672, 15.95125008], [73.50319672, 15.95292091], [73.5029068, 15.95292091], [73.5029068, 15.95374966], [73.50263977, 15.95374966], [73.50263977, 15.95458221], [73.50235748, 15.95458031], [73.50235748, 15.95485973], [73.50208282, 15.95485973], [73.50208282, 15.95514107], [73.50180817, 15.95514107], [73.50180817, 15.95542145], [73.50152588, 15.95542145], [73.50152588, 15.95597267], [73.50180817, 15.95597267], [73.50180817, 15.95653057], [73.50235748, 15.95652866], [73.50235748, 15.95708466], [73.50319672, 15.95708466], [73.50319672, 15.95680428], [73.50347137, 15.95680428], [73.50347137, 15.95708466], [73.50402832, 15.95708179], [73.50402832, 15.95764065], [73.50430298, 15.95764065], [73.50430298, 15.95903111], [73.50458527, 15.9590292], [73.50458527, 15.95930672], [73.50485992, 15.95930672], [73.50485992, 15.95958328], [73.50514221, 15.95958042], [73.50514221, 15.96014118], [73.50541687, 15.96014118], [73.50541687, 15.96042061], [73.50569153, 15.96041679], [73.50569153, 15.96069527], [73.50596619, 15.96068954], [73.50596619, 15.96125126], [73.50624847, 15.96125126], [73.50624847, 15.96236134], [73.50653076, 15.96236134], [73.50653076, 15.96569538], [73.50624847, 15.96569538], [73.50624847, 15.96736145], [73.50596619, 15.96736145], [73.50596619, 15.96819973], [73.50569153, 15.96819305], [73.50569153, 15.96847439], [73.50430298, 15.96847057], [73.50430298, 15.96875191], [73.50263977, 15.96875191], [73.50263977, 15.96847057], [73.50208282, 15.96847439], [73.50208282, 15.96819305], [73.50152588, 15.96819305], [73.50152588, 15.96847439], [73.50125122, 15.96847057], [73.50125122, 15.96875191], [73.50096893, 15.96875191], [73.50096893, 15.96903038], [73.50068665, 15.96903038], [73.50068665, 15.96930981], [73.50041962, 15.96930504], [73.50041962, 15.96958447], [73.49986267, 15.96958447], [73.49986267, 15.97069263], [73.49958038, 15.97069263], [73.49958038, 15.97124958], [73.49931335, 15.97124004], [73.49931335, 15.97152996], [73.49903107, 15.97152805], [73.49903107, 15.97208405], [73.49874878, 15.97207928], [73.49874878, 15.97264194], [73.49846649, 15.97264194], [73.49846649, 15.97292042], [73.49819183, 15.97291565], [73.49819183, 15.97319412], [73.49791718, 15.97319412], [73.49791718, 15.97347164], [73.49764252, 15.97347164], [73.49764252, 15.97402954], [73.49736023, 15.97402763], [73.49736023, 15.97458363], [73.49708557, 15.97458363], [73.49708557, 15.9748621], [73.49680328, 15.97486019], [73.49680328, 15.97542], [73.49652863, 15.97541809], [73.49652863, 15.9756937], [73.49624634, 15.9756918], [73.49624634, 15.97653008], [73.49597931, 15.97653008], [73.49597931, 15.97681141], [73.49541473, 15.97680569], [73.49541473, 15.97708416], [73.49514008, 15.97708035], [73.49514008, 15.97764015], [73.49485779, 15.97764015], [73.49485779, 15.97819424], [73.49458313, 15.97819424], [73.49458313, 15.97847176], [73.49430847, 15.97846985], [73.49430847, 15.97903061], [73.49402618, 15.97903061], [73.49402618, 15.97931099], [73.49375153, 15.97930622], [73.49375153, 15.97958374], [73.49346924, 15.97958374], [73.49346924, 15.97986031], [73.49291992, 15.97986031], [73.49291992, 15.98069382], [73.49263763, 15.98069382], [73.49263763, 15.98097229], [73.49236298, 15.98097038], [73.49236298, 15.98125267], [73.49208069, 15.98125267], [73.49208069, 15.98153114], [73.49180603, 15.98152828], [73.49180603, 15.98208237], [73.49153137, 15.98208046], [73.49153137, 15.98264122], [73.49124908, 15.98263836], [73.49124908, 15.9831953], [73.4909668, 15.983181], [73.4909668, 15.9837513], [73.49069214, 15.9837513], [73.49069214, 15.98403072], [73.49041748, 15.98402882], [73.49041748, 15.9845829], [73.49014282, 15.98458004], [73.49014282, 15.9851408], [73.48986053, 15.98513889], [73.48986053, 15.98569489], [73.48958588, 15.98569012], [73.48958588, 15.98681164], [73.48930359, 15.98680687], [73.48930359, 15.98708344], [73.48902893, 15.98707962], [73.48902893, 15.98792076], [73.48874664, 15.98791695], [73.48874664, 15.99102974], [73.48874664, 15.99236965], [73.48847198, 15.99236107], [73.48847198, 15.99319458], [73.48874664, 15.99319458], [73.48874664, 15.99347115], [73.48847198, 15.99347115], [73.48847198, 15.99486065], [73.48874664, 15.99486065], [73.48874664, 15.99708366], [73.48902893, 15.99708366], [73.48902893, 15.99847221], [73.48874664, 15.99846935], [73.48874664, 15.99903011], [73.48902893, 15.99903011], [73.48902893, 15.99930954], [73.48929596, 15.99930954], [73.48930359, 15.99986172], [73.48930359, 16.0023613], [73.48958588, 16.0023613], [73.48958588, 16.00319481], [73.48986053, 16.00319481], [73.48986053, 16.00708389], [73.49013519, 16.00708389], [73.49013519, 16.00736046], [73.49041748, 16.00735092], [73.49041748, 16.00764084], [73.49069214, 16.00763893], [73.49069214, 16.00958252], [73.4909668, 16.00958061], [73.4909668, 16.01153183], [73.49069214, 16.01153183], [73.49069214, 16.0118103], [73.49041748, 16.01180649], [73.49041748, 16.01236153], [73.49014282, 16.01236153], [73.49014282, 16.01264191], [73.48985291, 16.01264191], [73.48985291, 16.01375008], [73.48958588, 16.01375008], [73.48958588, 16.01597214], [73.48930359, 16.01597214], [73.48930359, 16.01708412], [73.48902893, 16.01708412], [73.48902893, 16.01847267], [73.48874664, 16.01847076], [73.48874664, 16.01902962], [73.48847198, 16.01902962], [73.48847198, 16.01931], [73.48819733, 16.01930428], [73.48819733, 16.01958275], [73.48792267, 16.01958084], [73.48792267, 16.02042007], [73.48764038, 16.02041626], [73.48764038, 16.0209713], [73.48735809, 16.02096939], [73.48735809, 16.02153015], [73.48708344, 16.02152634], [73.48708344, 16.02236176], [73.48680878, 16.02236176], [73.48680878, 16.02347183], [73.48652649, 16.02346992], [73.48652649, 16.0237484], [73.48625183, 16.0237484], [73.48625183, 16.02403069], [73.48596954, 16.02403069], [73.48596954, 16.02485847], [73.48568726, 16.02485847], [73.48568726, 16.02514076], [73.48596954, 16.02514076], [73.48596954, 16.02569389], [73.48568726, 16.02568817], [73.48568726, 16.02653122], [73.48542023, 16.02653122], [73.48542023, 16.02763939], [73.48513794, 16.02763939], [73.48513794, 16.02931023], [73.48486328, 16.02930641], [73.48486328, 16.02986145], [73.48458099, 16.02985954], [73.48458099, 16.0304203], [73.48430634, 16.03041649], [73.48430634, 16.03152847], [73.48401642, 16.03152084], [73.48401642, 16.03292084], [73.48374939, 16.03292084], [73.48374939, 16.03403091], [73.4834671, 16.03403091], [73.4834671, 16.03514099], [73.48319244, 16.03513718], [73.48319244, 16.0359726], [73.48291779, 16.03597069], [73.48291779, 16.03652954], [73.4826355, 16.03652954], [73.4826355, 16.03708267], [73.48236084, 16.03708076], [73.48236084, 16.03763962], [73.48208618, 16.03763962], [73.48208618, 16.03819466], [73.48180389, 16.03819466], [73.48180389, 16.03847313], [73.48152924, 16.03846931], [73.48152924, 16.0387516], [73.48124695, 16.0387516], [73.48124695, 16.03930473], [73.48097229, 16.03930473], [73.48097229, 16.03958321], [73.48069763, 16.03957939], [73.48069763, 16.04014015], [73.48014069, 16.04014015], [73.48014069, 16.04042053], [73.4798584, 16.04042053], [73.4798584, 16.04071045], [73.47957611, 16.04071045], [73.47957611, 16.04125023], [73.47930908, 16.04125023], [73.47930908, 16.04153061], [73.47902679, 16.04153061], [73.47902679, 16.0418129], [73.47846985, 16.04180527], [73.47846985, 16.04208374], [73.47819519, 16.04208374], [73.47820282, 16.04236031], [73.4779129, 16.04236031], [73.4779129, 16.04292107], [73.47763824, 16.04291725], [73.47763824, 16.04347229], [73.47735596, 16.04346275], [73.47735596, 16.04375076], [73.4770813, 16.04375076], [73.4770813, 16.04403114], [73.47569275, 16.04403114], [73.47569275, 16.04430962], [73.47486115, 16.0443058], [73.47486115, 16.04458427], [73.47429657, 16.04458046], [73.47429657, 16.04514122], [73.4734726, 16.04514122], [73.4734726, 16.04541969], [73.47264099, 16.04541588], [73.47264099, 16.04569435], [73.47180939, 16.04569435], [73.47180176, 16.04597282], [73.47097015, 16.04597092], [73.47097015, 16.04624939], [73.46902466, 16.04624939], [73.46902466, 16.04652786], [73.46847534, 16.04652786], [73.46847534, 16.0470829], [73.46819305, 16.04708099], [73.46819305, 16.04792023], [73.46847534, 16.04791641], [73.46847534, 16.04847145], [73.46875, 16.04847145], [73.46875, 16.04986191], [73.46848297, 16.04985809], [73.46848297, 16.05180931], [73.46819305, 16.0518055], [73.46819305, 16.05208397], [73.4679184, 16.05207825], [73.4679184, 16.05265045], [73.46763611, 16.05265045], [73.46763611, 16.05291939], [73.46736145, 16.05291748], [73.46736145, 16.05347252], [73.46708679, 16.05347252], [73.46708679, 16.0537529], [73.46679688, 16.0537529], [73.46679688, 16.05402946], [73.46624756, 16.05402946], [73.46624756, 16.05430984], [73.46569824, 16.05430603], [73.46569824, 16.0545826], [73.46541595, 16.0545826], [73.46541595, 16.05486107], [73.46347046, 16.05486107], [73.46347046, 16.05513954], [73.46263885, 16.05513954], [73.46263885, 16.05541992], [73.46097565, 16.05541611], [73.46097565, 16.05569458], [73.45930481, 16.05569458], [73.45930481, 16.05541611], [73.45903015, 16.05541992], [73.45903015, 16.05486107], [73.45874786, 16.05486107], [73.45874786, 16.05347252], [73.45847321, 16.05347252], [73.45847321, 16.05319405], [73.45652771, 16.05319405], [73.45652771, 16.05347252], [73.45625305, 16.05347252], [73.45625305, 16.0537529], [73.45597076, 16.0537529], [73.45597076, 16.05402946], [73.45569611, 16.05402946], [73.45569611, 16.05430984], [73.45541382, 16.05430603], [73.45541382, 16.0545826], [73.45513916, 16.0545826], [73.45513916, 16.05513954], [73.4548645, 16.05513954], [73.4548645, 16.05569458], [73.45513916, 16.05569458], [73.45513916, 16.05597305], [73.45569611, 16.05597305], [73.45569611, 16.05569458], [73.45625305, 16.05569458], [73.45625305, 16.05597305], [73.45652771, 16.05597115], [73.45652771, 16.05653], [73.45680237, 16.05652809], [73.45680237, 16.0573616], [73.45652771, 16.0573597], [73.45652771, 16.05764008], [73.45625305, 16.05764008], [73.45625305, 16.05792046], [73.45597076, 16.05792046], [73.45597076, 16.05820084], [73.45569611, 16.05819321], [73.45569611, 16.05847168], [73.45540619, 16.05846024], [73.45540619, 16.05875015], [73.45569611, 16.05875015], [73.45569611, 16.05931091], [73.45597076, 16.05930519], [73.45597076, 16.06069374], [73.45569611, 16.06069374], [73.45569611, 16.06097221], [73.45541382, 16.06097221], [73.45541382, 16.06152534], [73.45513916, 16.06152534], [73.45513916, 16.0620842], [73.45485687, 16.06208038], [73.45485687, 16.06291962], [73.45513916, 16.0629158], [73.45513916, 16.06319427], [73.45652771, 16.06319427], [73.45652771, 16.0629158], [73.45680237, 16.0629158], [73.45680237, 16.06319427], [73.45819092, 16.06319427], [73.45819092, 16.0629158], [73.45847321, 16.06291962], [73.45847321, 16.06264114], [73.45874786, 16.06264114], [73.45874786, 16.06236076], [73.45986938, 16.06236076], [73.45986938, 16.06264114], [73.4604187, 16.06264114], [73.4604187, 16.06291962], [73.46097565, 16.0629158], [73.46097565, 16.06319427], [73.46151733, 16.06319046], [73.46151733, 16.06375122], [73.46208191, 16.06375122], [73.46208191, 16.06430817], [73.4623642, 16.06430626], [73.4623642, 16.0648613], [73.46290588, 16.0648613], [73.46290588, 16.06542015], [73.4631958, 16.06541634], [73.4631958, 16.06569481], [73.46347046, 16.06569481], [73.46347046, 16.06680489], [73.46375275, 16.06679916], [73.46375275, 16.06764984], [73.4640274, 16.06764984], [73.4640274, 16.06792068], [73.46430206, 16.06792068], [73.46430206, 16.06875038], [73.4640274, 16.06875038], [73.4640274, 16.06903076], [73.46375275, 16.06903076], [73.46375275, 16.06931114], [73.46347046, 16.06930542], [73.46347046, 16.06958389], [73.4631958, 16.06958008], [73.4631958, 16.07042122], [73.46347046, 16.0704174], [73.46347046, 16.07069588], [73.4640274, 16.07069588], [73.4640274, 16.07097244], [73.46430206, 16.07097054], [73.46430206, 16.07125092], [73.46485901, 16.07125092], [73.46485901, 16.07152939], [73.46541595, 16.07152939], [73.46541595, 16.07125092], [73.46568298, 16.07125092], [73.46569824, 16.07097054], [73.4659729, 16.07097244], [73.4659729, 16.0704174], [73.46624756, 16.07042122], [73.46624756, 16.06986046], [73.46652985, 16.06986046], [73.46652985, 16.06958008], [73.46736145, 16.06958008], [73.46736145, 16.06986046], [73.46763611, 16.06986046], [73.46763611, 16.07125092], [73.46736145, 16.07125092], [73.46736145, 16.07208252], [73.46708679, 16.07208061], [73.46708679, 16.07263947], [73.4668045, 16.07263947], [73.4668045, 16.0731945], [73.46652985, 16.0731945], [73.46652985, 16.07347298], [73.4659729, 16.07347107], [73.4659729, 16.07374954], [73.46569824, 16.07374954], [73.46569824, 16.07402992], [73.46541595, 16.07402992], [73.46541595, 16.07542038], [73.4651413, 16.07542038], [73.4651413, 16.07570076], [73.46485901, 16.07570076], [73.46485901, 16.07764053], [73.46430206, 16.07764053], [73.46430206, 16.07819366], [73.46375275, 16.07818985], [73.46375275, 16.07902908], [73.46347046, 16.07902908], [73.46347046, 16.07930946], [73.46290588, 16.07930946], [73.46290588, 16.07959175], [73.46263885, 16.07959175], [73.46263885, 16.07986259], [73.46235657, 16.07986259], [73.46235657, 16.08014107], [73.45874786, 16.08014107], [73.45874786, 16.07986259], [73.4576416, 16.07986259], [73.4576416, 16.08014107], [73.45735931, 16.08013916], [73.45735931, 16.0806942], [73.45707703, 16.08069038], [73.45707703, 16.08181], [73.45735931, 16.08180618], [73.45735931, 16.08208275], [73.45791626, 16.08208275], [73.45791626, 16.08263969], [73.45847321, 16.08263016], [73.45847321, 16.08292007], [73.45874786, 16.08291626], [73.45874786, 16.08319473], [73.45903015, 16.08319283], [73.45903015, 16.08403015], [73.45874786, 16.08402824], [73.45874786, 16.08458328], [73.45847321, 16.08457947], [73.45847321, 16.08514023], [73.45819092, 16.08514023], [73.45819092, 16.08542061], [73.45791626, 16.08541679], [73.45791626, 16.08569527], [73.4576416, 16.08569527], [73.4576416, 16.08597183], [73.45791626, 16.08596992], [73.45791626, 16.08625031], [73.45874786, 16.08625031], [73.45874786, 16.08596992], [73.45930481, 16.08597183], [73.45930481, 16.08569527], [73.46097565, 16.08569527], [73.46097565, 16.08597183], [73.46180725, 16.08596992], [73.46180725, 16.08625031], [73.46263885, 16.08625031], [73.46263885, 16.08653069], [73.46235657, 16.08653069], [73.46235657, 16.08736038], [73.46208191, 16.08736038], [73.46208191, 16.08958244], [73.46180725, 16.08958054], [73.46180725, 16.09181976], [73.46151733, 16.09181976], [73.46151733, 16.09403038], [73.46125031, 16.09403038], [73.46125031, 16.09625053], [73.46097565, 16.09625053], [73.46097565, 16.09708214], [73.46069336, 16.09708023], [73.46069336, 16.09736061], [73.4604187, 16.09736061], [73.4604187, 16.09819412], [73.46013641, 16.09819031], [73.46013641, 16.09875107], [73.45986938, 16.09875107], [73.45986938, 16.09930992], [73.4595871, 16.09930992], [73.4595871, 16.10013962], [73.45929718, 16.10013962], [73.45929718, 16.10042], [73.45903015, 16.10042], [73.45903015, 16.10070038], [73.45874786, 16.10070038], [73.45874786, 16.10153008], [73.45847321, 16.10152626], [73.45847321, 16.10208321], [73.45819092, 16.10208321], [73.45819092, 16.10347176], [73.45791626, 16.10346985], [73.45791626, 16.10403061], [73.4576416, 16.10403061], [73.4576416, 16.10958481], [73.45735931, 16.10958481], [73.45735931, 16.10986137], [73.4576416, 16.10985947], [73.4576416, 16.11042023], [73.45791626, 16.11042023], [73.45791626, 16.11124992], [73.45819092, 16.11124992], [73.45819092, 16.11181068], [73.45791626, 16.11181068], [73.45791626, 16.11652946], [73.4576416, 16.11652946], [73.4576416, 16.11763763], [73.45735931, 16.11763763], [73.45735931, 16.11930466], [73.45708466, 16.11930466], [73.45708466, 16.11958313], [73.45735931, 16.11958313], [73.45735931, 16.12097168], [73.45707703, 16.12097168], [73.45707703, 16.12153053], [73.45680237, 16.12152863], [73.45680237, 16.12208366], [73.45652771, 16.12207985], [73.45652771, 16.12292099], [73.45625305, 16.12292099], [73.45625305, 16.12375069], [73.45597076, 16.12375069], [73.45597076, 16.1245842], [73.45569611, 16.12458038], [73.45569611, 16.12541962], [73.45540619, 16.12541962], [73.45540619, 16.12625122], [73.45513916, 16.12624931], [73.45513916, 16.12708282], [73.4548645, 16.12708282], [73.4548645, 16.12819481], [73.45458221, 16.12819099], [73.45458221, 16.12903023], [73.45430756, 16.12902641], [73.45430756, 16.12986183], [73.4540329, 16.12985992], [73.4540329, 16.1301403], [73.45374298, 16.1301403], [73.45374298, 16.13180923], [73.45347595, 16.13180923], [73.45347595, 16.13292122], [73.45318604, 16.13292122], [73.45318604, 16.13402939], [73.45291901, 16.13402939], [73.45291901, 16.13513947], [73.45263672, 16.13513947], [73.45263672, 16.1356945], [73.45236206, 16.13569069], [73.45236206, 16.13792038], [73.45207977, 16.13792038], [73.45207977, 16.13931084], [73.45180511, 16.13930511], [73.45180511, 16.13958359], [73.45207977, 16.13957977], [73.45207977, 16.14180946], [73.45180511, 16.14180565], [73.45180511, 16.14347267], [73.45153046, 16.14347076], [73.45153046, 16.14402962], [73.45124817, 16.14402962], [73.45124817, 16.14458275], [73.45097351, 16.14458275], [73.45097351, 16.14596939], [73.45067596, 16.14596939], [73.45067596, 16.14653015], [73.45041656, 16.14653015], [73.45041656, 16.14792061], [73.45014191, 16.14792061], [73.45014191, 16.14931107], [73.44985962, 16.14930534], [73.44985962, 16.15097237], [73.44958496, 16.15097237], [73.44958496, 16.15208244], [73.44985962, 16.15208054], [73.44985962, 16.15291977], [73.44958496, 16.15291405], [73.44958496, 16.1534729], [73.44930267, 16.15347099], [73.44930267, 16.15431023], [73.44902802, 16.15431023], [73.44902802, 16.15513992], [73.44875336, 16.15513992], [73.44875336, 16.1554203], [73.44847107, 16.1554203], [73.44847107, 16.15624809], [73.44819641, 16.15624809], [73.44819641, 16.15681076], [73.44791412, 16.15680504], [73.44791412, 16.15736198], [73.44763947, 16.15735817], [73.44763947, 16.15764046], [73.44736481, 16.15764046], [73.44736481, 16.15847015], [73.44708252, 16.15846825], [73.44708252, 16.15874863], [73.44680786, 16.15874863], [73.44680786, 16.15930939], [73.44652557, 16.15930557], [73.44652557, 16.16069412], [73.44625092, 16.16069031], [73.44625092, 16.16292], [73.44596863, 16.16291618], [73.44596863, 16.16486168], [73.44568634, 16.16485977], [73.44568634, 16.16625023], [73.44541931, 16.16625023], [73.44541931, 16.16764069], [73.44513702, 16.16763878], [73.44513702, 16.16847229], [73.44486237, 16.16847038], [73.44486237, 16.16903114], [73.44458008, 16.16902733], [73.44458008, 16.16986084], [73.44430542, 16.16986084], [73.44431305, 16.17124748], [73.44403076, 16.17124748], [73.44403076, 16.17235947], [73.44374847, 16.17235947], [73.44374847, 16.17319489], [73.44346619, 16.17318916], [73.44346619, 16.1740303], [73.44319153, 16.1740303], [73.44319153, 16.17514038], [73.44291687, 16.17514038], [73.44291687, 16.17597961], [73.44264221, 16.17597961], [73.44264221, 16.17681122], [73.44235992, 16.17681122], [73.44235992, 16.17791939], [73.4420929, 16.17791939], [73.4420929, 16.17875099], [73.44180298, 16.17875099], [73.44180298, 16.17986107], [73.44152832, 16.17986107], [73.44152832, 16.18569374], [73.44124603, 16.18568993], [73.44124603, 16.18625259], [73.44097137, 16.18625259], [73.44097137, 16.18680954], [73.44069672, 16.18680954], [73.44069672, 16.18736267], [73.4404068, 16.18736267], [73.4404068, 16.18764114], [73.44013977, 16.18764114], [73.44013977, 16.18875122], [73.43985748, 16.18874931], [73.43985748, 16.18958473], [73.43958282, 16.18958282], [73.43958282, 16.19042015], [73.43930817, 16.19042015], [73.43930817, 16.19124985], [73.43902588, 16.19124985], [73.43902588, 16.19208336], [73.43873596, 16.19207954], [73.43873596, 16.19292068], [73.43846893, 16.19291687], [73.43846893, 16.19402695], [73.43818665, 16.19402122], [73.43818665, 16.19486046], [73.43791962, 16.19486046], [73.43791962, 16.19597244], [73.43763733, 16.19597054], [73.43763733, 16.19652748], [73.43736267, 16.19652748], [73.43736267, 16.19680977], [73.43708038, 16.19680977], [73.43708038, 16.19735909], [73.43681335, 16.19735909], [73.43681335, 16.19791985], [73.43653107, 16.19791603], [73.43653107, 16.1981945], [73.43624878, 16.19819069], [73.43624878, 16.19875145], [73.43596649, 16.19875145], [73.43596649, 16.19903183], [73.43569183, 16.19902992], [73.43569183, 16.2009697], [73.43596649, 16.2009697], [73.43596649, 16.20125008], [73.43653107, 16.20125008], [73.43653107, 16.20153046], [73.43681335, 16.20153046], [73.43681335, 16.20125008], [73.43708038, 16.20125008], [73.43708038, 16.2009697], [73.43736267, 16.2009697], [73.43736267, 16.20069504], [73.43763733, 16.20070267], [73.43763733, 16.20042038], [73.43791962, 16.20042038], [73.43791962, 16.20014954], [73.43930817, 16.20014954], [73.43930817, 16.20042038], [73.44069672, 16.20042038], [73.44069672, 16.20014954], [73.44124603, 16.20014954], [73.44124603, 16.19986153], [73.44152832, 16.19986153], [73.44152832, 16.19958115], [73.44235992, 16.19958115], [73.44235992, 16.19902992], [73.44264221, 16.19903183], [73.44264221, 16.19846916], [73.44291687, 16.19847298], [73.44291687, 16.1981945], [73.44403076, 16.1981945], [73.44403076, 16.19847298], [73.44430542, 16.19847298], [73.44430542, 16.19875145], [73.44458008, 16.19875145], [73.44458008, 16.19903183], [73.44486237, 16.19902992], [73.44486237, 16.19986153], [73.44458008, 16.19986153], [73.44458008, 16.20181084], [73.44430542, 16.20180511], [73.44430542, 16.20236206], [73.44403076, 16.20236015], [73.44403076, 16.20264053], [73.4420929, 16.20263863], [73.44180298, 16.20264053], [73.44180298, 16.20207977], [73.44152832, 16.20208359], [73.44152832, 16.20180511], [73.44124603, 16.20181084], [73.44124603, 16.20153046], [73.44097137, 16.20153046], [73.44097137, 16.20125008], [73.43958282, 16.20125008], [73.43958282, 16.20153046], [73.43902588, 16.20153046], [73.43902588, 16.20292091], [73.43930817, 16.2029171], [73.43930817, 16.20347214], [73.43902588, 16.20347023], [73.43902588, 16.20375061], [73.43930817, 16.20375061], [73.43930817, 16.20514107], [73.43958282, 16.20514107], [73.43958282, 16.20541954], [73.43985748, 16.20541573], [73.43985748, 16.2056942], [73.44041443, 16.2056942], [73.44041443, 16.20597267], [73.44069672, 16.20596123], [73.44069672, 16.20625114], [73.44095612, 16.20624924], [73.44124603, 16.20625114], [73.44124603, 16.20596123], [73.44208527, 16.20597267], [73.44208527, 16.20541573], [73.44235992, 16.20541954], [73.44235992, 16.20486069], [73.44264221, 16.20486069], [73.44264221, 16.20430946], [73.44319153, 16.20430565], [73.44319153, 16.20458412], [73.44374847, 16.20458031], [73.44374847, 16.20486069], [73.44513702, 16.20486069], [73.44513702, 16.20514107], [73.44625092, 16.20514107], [73.44625092, 16.20541954], [73.44680786, 16.20541573], [73.44680786, 16.2056942], [73.44735718, 16.20569038], [73.44735718, 16.20625114], [73.44763947, 16.20625114], [73.44763947, 16.20652962], [73.44791412, 16.20652771], [73.44791412, 16.20708275], [73.44819641, 16.20708084], [73.44819641, 16.20736122], [73.44847107, 16.20736122], [73.44847107, 16.20763969], [73.44875336, 16.20763969], [73.44875336, 16.20792007], [73.44902802, 16.20791626], [73.44902802, 16.20819473], [73.44875336, 16.20819473], [73.44875336, 16.20986176], [73.44902802, 16.20985985], [73.44902802, 16.21042061], [73.44930267, 16.21042061], [73.44930267, 16.21153069], [73.44902802, 16.21153069], [73.44902802, 16.21208954], [73.44847107, 16.21208954], [73.44847107, 16.21180916], [73.44819641, 16.21180916], [73.44819641, 16.21042061], [73.44790649, 16.21042061], [73.44790649, 16.20902061], [73.44763947, 16.20902634], [73.44763947, 16.2084713], [73.44736481, 16.2084713], [73.44736481, 16.20791626], [73.44708252, 16.20792007], [73.44708252, 16.20763969], [73.44680786, 16.20763969], [73.44680786, 16.20736122], [73.44652557, 16.20736122], [73.44652557, 16.20708275], [73.44569397, 16.20708275], [73.44569397, 16.20680428], [73.44486237, 16.20681], [73.44486237, 16.20652962], [73.44403076, 16.20652962], [73.44403076, 16.20625114], [73.44374847, 16.20625114], [73.44374847, 16.20652962], [73.44291687, 16.20652962], [73.44291687, 16.20681], [73.44235992, 16.20680428], [73.44235992, 16.20708275], [73.44264221, 16.20708084], [73.44264221, 16.20792007], [73.44291687, 16.20791626], [73.44291687, 16.20819473], [73.44347382, 16.20819473], [73.44347382, 16.2084713], [73.44374847, 16.20846939], [73.44374847, 16.20874977], [73.44403076, 16.20874977], [73.44403076, 16.20902634], [73.44431305, 16.20902061], [73.44431305, 16.21013832], [73.44458008, 16.21013832], [73.44458008, 16.21235847], [73.44486237, 16.21235847], [73.44486237, 16.21458054], [73.44513702, 16.21458054], [73.44513702, 16.21541977], [73.44541931, 16.21541595], [73.44541931, 16.21597481], [73.44596863, 16.2159729], [73.44596863, 16.21652985], [73.44625092, 16.21652985], [73.44625092, 16.21763992], [73.44596863, 16.21763992], [73.44596863, 16.2179203], [73.44625092, 16.2179203], [73.44625092, 16.21903038], [73.44652557, 16.21902847], [73.44652557, 16.21986198], [73.44680786, 16.21986008], [73.44680786, 16.22153091], [73.44708252, 16.22152519], [73.44708252, 16.22319412], [73.44736481, 16.22319412], [73.44736481, 16.22458267], [73.44708252, 16.22458267], [73.44708252, 16.22430611], [73.4465332, 16.22430992], [73.4465332, 16.22374916], [73.44625092, 16.22374916], [73.44625092, 16.22291946], [73.44596863, 16.22291946], [73.44596863, 16.22236061], [73.44568634, 16.22236061], [73.44568634, 16.22125053], [73.44541931, 16.22125053], [73.44541931, 16.21986008], [73.44569397, 16.21986198], [73.44569397, 16.21958351], [73.44541931, 16.21958351], [73.44541931, 16.21902847], [73.44513702, 16.21903038], [73.44513702, 16.21846962], [73.44486237, 16.21847153], [73.44486237, 16.21791649], [73.44513702, 16.2179203], [73.44513702, 16.21763992], [73.44458008, 16.21763992], [73.44458008, 16.21681023], [73.44431305, 16.21681023], [73.44431305, 16.2159729], [73.44403076, 16.21597481], [73.44403076, 16.21569443], [73.44374847, 16.21569443], [73.44374847, 16.21513939], [73.44346619, 16.21515083], [73.44346619, 16.21153069], [73.44319153, 16.21153069], [73.44319153, 16.21096992], [73.44291687, 16.21097183], [73.44291687, 16.21069527], [73.44264221, 16.21069908], [73.44264221, 16.21042061], [73.44235992, 16.21042061], [73.44235992, 16.21013832], [73.4420929, 16.21013832], [73.4420929, 16.20985985], [73.44125366, 16.20986176], [73.44125366, 16.20958328], [73.44097137, 16.20958328], [73.44097137, 16.20930481], [73.44069672, 16.20930481], [73.44069672, 16.20902634], [73.44041443, 16.20902634], [73.44041443, 16.20874977], [73.44013977, 16.20874977], [73.44013977, 16.2084713], [73.43985748, 16.2084713], [73.43985748, 16.20819473], [73.43958282, 16.20819473], [73.43958282, 16.20763969], [73.43930817, 16.20763969], [73.43930817, 16.20708084], [73.43902588, 16.20708275], [73.43902588, 16.20652771], [73.43873596, 16.20652962], [73.43873596, 16.20625114], [73.43846893, 16.20625114], [73.43846893, 16.20596123], [73.43819427, 16.20597267], [73.43819427, 16.2056942], [73.43763733, 16.2056942], [73.43763733, 16.20541763], [73.43736267, 16.20541954], [73.43736267, 16.20514107], [73.43708038, 16.20514107], [73.43708038, 16.20458031], [73.43680573, 16.20458412], [73.43680573, 16.20375061], [73.43653107, 16.20375061], [73.43653107, 16.20318985], [73.43624878, 16.20319366], [73.43624878, 16.2029171], [73.43596649, 16.20292091], [73.43596649, 16.20264053], [73.43569946, 16.20264053], [73.43569946, 16.20236015], [73.43541718, 16.20236206], [73.43541718, 16.20208359], [73.43486023, 16.20208359], [73.43486023, 16.20180511], [73.43430328, 16.20181084], [73.43430328, 16.20153046], [73.43402863, 16.20153046], [73.43402863, 16.20125008], [73.43374634, 16.20125008], [73.43374634, 16.2009697], [73.43347168, 16.2009697], [73.43347168, 16.20069504], [73.4329071, 16.20070267], [73.4329071, 16.20014954], [73.43235779, 16.20014954], [73.43235779, 16.19986153], [73.43180847, 16.19986153], [73.43180847, 16.19958115], [73.43152618, 16.19958115], [73.43152618, 16.19930649], [73.43125153, 16.1993103], [73.43125153, 16.19903183], [73.43096924, 16.19903183], [73.43096924, 16.19875145], [73.43068695, 16.19875145], [73.43068695, 16.19903183], [73.42986298, 16.19903183], [73.42986298, 16.1993103], [73.42958069, 16.19930649], [73.42958069, 16.19958115], [73.42930603, 16.19958115], [73.42930603, 16.19986153], [73.42903137, 16.19986153], [73.42903137, 16.20014954], [73.42874908, 16.20014954], [73.42874908, 16.20042038], [73.4284668, 16.20042038], [73.4284668, 16.20070267], [73.42819214, 16.20069504], [73.42819214, 16.2009697], [73.42791748, 16.2009697], [73.42791748, 16.20153046], [73.42763519, 16.20152855], [73.42763519, 16.20208359], [73.42736053, 16.20207977], [73.42736053, 16.20264053], [73.42708588, 16.20263863], [73.42708588, 16.20319366], [73.42679596, 16.20318985], [73.42679596, 16.20430946], [73.42652893, 16.20430946], [73.42652893, 16.20652962], [73.42679596, 16.20652962], [73.42679596, 16.20736122], [73.42708588, 16.20736122], [73.42708588, 16.20792007], [73.42736053, 16.20791626], [73.42736053, 16.2084713], [73.42763519, 16.2084713], [73.42763519, 16.20930481], [73.42736053, 16.20930099], [73.42736053, 16.21013832], [73.42708588, 16.21013832], [73.42708588, 16.21069908], [73.42679596, 16.21069908], [73.42679596, 16.21235847], [73.42708588, 16.21235847], [73.42708588, 16.21292114], [73.42736053, 16.21292114], [73.42736053, 16.21403122], [73.42708588, 16.21403122], [73.42708588, 16.21486282], [73.42679596, 16.21486282], [73.42679596, 16.21541977], [73.42624664, 16.21541595], [73.42624664, 16.21569443], [73.42597198, 16.21569443], [73.42597198, 16.21597481], [73.42569733, 16.2159729], [73.42569733, 16.21624947], [73.42542267, 16.21624947], [73.42542267, 16.21652985], [73.42514038, 16.21652794], [73.42514038, 16.21708488], [73.42485809, 16.21708488], [73.42485809, 16.21736145], [73.42458344, 16.21736145], [73.42458344, 16.21986198], [73.42485809, 16.21986008], [73.42485809, 16.22402763], [73.42457581, 16.22402763], [73.42457581, 16.22514153], [73.42430878, 16.22514153], [73.42430878, 16.2262516], [73.42402649, 16.2262516], [73.42402649, 16.22736168], [73.42375183, 16.22736168], [73.42375183, 16.22847366], [73.42346954, 16.22847366], [73.42346954, 16.22958374], [73.42319489, 16.22958374], [73.42319489, 16.23069382], [73.42292023, 16.23069], [73.42292023, 16.23180962], [73.42263794, 16.23180962], [73.42263794, 16.23264122], [73.42236328, 16.23263931], [73.42236328, 16.23319435], [73.42208099, 16.23319054], [73.42208099, 16.23374939], [73.42180634, 16.23374939], [73.42180634, 16.23431015], [73.42152405, 16.23430634], [73.42152405, 16.23486137], [73.42124939, 16.23485947], [73.42124939, 16.23542023], [73.4209671, 16.23542023], [73.4209671, 16.2365303], [73.42070007, 16.2365303], [73.42070007, 16.23763847], [73.42041779, 16.23763847], [73.42041779, 16.24041939], [73.42014313, 16.24041939], [73.42014313, 16.24152946], [73.41986084, 16.24152946], [73.41986084, 16.24403], [73.41958618, 16.24402809], [73.41958618, 16.24430466], [73.41930389, 16.24430466], [73.41930389, 16.24458313], [73.41847229, 16.24458313], [73.41847229, 16.2448616], [73.41791534, 16.2448616], [73.41791534, 16.24513817], [73.4173584, 16.24513054], [73.4173584, 16.24542046], [73.41707611, 16.24542046], [73.41707611, 16.24570084], [73.41680908, 16.24570084], [73.41680908, 16.24681091], [73.41652679, 16.24681091], [73.41652679, 16.24736023], [73.41625214, 16.24736023], [73.41625214, 16.25041962], [73.41652679, 16.25041962], [73.41652679, 16.25126266], [73.41625214, 16.25124741], [73.41625214, 16.25208282], [73.41569519, 16.25208282], [73.41570282, 16.25375175], [73.4154129, 16.25375175], [73.4154129, 16.25458336], [73.41513824, 16.25457954], [73.41513824, 16.25653076], [73.41485596, 16.25653076], [73.41485596, 16.25764084], [73.4145813, 16.25763893], [73.4145813, 16.25819588], [73.41430664, 16.25819016], [73.41430664, 16.25875092], [73.41401672, 16.25875092], [73.41401672, 16.26013947], [73.41374969, 16.26013947], [73.41374969, 16.26097298], [73.41347504, 16.26097298], [73.41347504, 16.2634716], [73.41319275, 16.2634697], [73.41319275, 16.26542091], [73.41291809, 16.2654171], [73.41291809, 16.26597023], [73.4126358, 16.26596832], [73.4126358, 16.26680946], [73.41236115, 16.26680946], [73.41236115, 16.26736259], [73.41208649, 16.26736259], [73.41208649, 16.26902962], [73.41179657, 16.26902962], [73.41179657, 16.27042007], [73.41152954, 16.27042007], [73.41152954, 16.27153015], [73.41124725, 16.27152824], [73.41124725, 16.27347183], [73.4109726, 16.27346992], [73.4109726, 16.27486038], [73.41124725, 16.27486038], [73.41124725, 16.27514076], [73.41152954, 16.27514076], [73.41152954, 16.27543068], [73.41179657, 16.27543068], [73.41179657, 16.27625084], [73.41208649, 16.27625084], [73.41208649, 16.27708244], [73.41236115, 16.27708054], [73.41236115, 16.27791977], [73.4126358, 16.27791977], [73.4126358, 16.27820015], [73.41291809, 16.27819443], [73.41291809, 16.2784729], [73.41319275, 16.27846909], [73.41319275, 16.27875137], [73.41348267, 16.27875137], [73.41348267, 16.27931023], [73.41374969, 16.27931023], [73.41374969, 16.28014183], [73.41401672, 16.28014183], [73.41401672, 16.28070068], [73.41430664, 16.28070068], [73.41430664, 16.28264046], [73.41456604, 16.28264046], [73.41456604, 16.28292084], [73.41486359, 16.28291702], [73.41486359, 16.28319359], [73.41791534, 16.28319359], [73.41791534, 16.28291702], [73.41874695, 16.28291702], [73.41874695, 16.28319359], [73.41902924, 16.28319359], [73.41902924, 16.28347206], [73.41929626, 16.28347015], [73.41929626, 16.28375053], [73.42085266, 16.28375053], [73.42151642, 16.28375053], [73.42151642, 16.28403091], [73.42236328, 16.28403091], [73.42236328, 16.28375053], [73.42263794, 16.28375053], [73.42263794, 16.28347015], [73.42292023, 16.28347206], [73.42292023, 16.28319359], [73.42402649, 16.28319359], [73.42402649, 16.28291702], [73.42430878, 16.28291702], [73.42430878, 16.28319359], [73.42708588, 16.28319359], [73.42708588, 16.28347206], [73.42874908, 16.28347206], [73.42874908, 16.28319359], [73.42986298, 16.28319359], [73.42986298, 16.28347206], [73.43096924, 16.28347015], [73.43096924, 16.28375053], [73.43347168, 16.28375053], [73.43347168, 16.28403091], [73.43430328, 16.2840271], [73.43430328, 16.28458595], [73.4345932, 16.28458023], [73.4345932, 16.28514099], [73.43486023, 16.28514099], [73.43486023, 16.28541946], [73.43514252, 16.28541756], [73.43514252, 16.28569412], [73.43541718, 16.28569412], [73.43541718, 16.2859726], [73.43569946, 16.28597069], [73.43569946, 16.28652954], [73.43541718, 16.28652954], [73.43541718, 16.28680992], [73.43514252, 16.28680992], [73.43514252, 16.28652954], [73.4345932, 16.28652954], [73.4345932, 16.28625107], [73.43430328, 16.28625107], [73.43430328, 16.28597069], [73.43402863, 16.2859726], [73.43402863, 16.28569412], [73.43374634, 16.28569412], [73.43374634, 16.28541756], [73.43347168, 16.28541946], [73.43347168, 16.28514099], [73.43319702, 16.28514099], [73.43319702, 16.28486061], [73.4329071, 16.28486061], [73.4329071, 16.28458023], [73.43208313, 16.28458595], [73.43208313, 16.28430557], [73.43096924, 16.28430557], [73.43096924, 16.28458595], [73.42930603, 16.28458023], [73.42930603, 16.28486061], [73.4284668, 16.28486061], [73.4284668, 16.28458023], [73.42736053, 16.28458023], [73.42736053, 16.28486061], [73.42541504, 16.28486061], [73.42541504, 16.28458595], [73.42514038, 16.28458595], [73.42514038, 16.28430557], [73.42236328, 16.28430557], [73.42236328, 16.28458595], [73.42208099, 16.28458023], [73.42208099, 16.28486061], [73.42180634, 16.28486061], [73.42180634, 16.28514099], [73.42124939, 16.28514099], [73.42124939, 16.28541946], [73.42041779, 16.28541756], [73.42041779, 16.28569412], [73.42003632, 16.28569412], [73.41986084, 16.28569412], [73.41986084, 16.2859726], [73.41930389, 16.2859726], [73.41930389, 16.28569412], [73.41708374, 16.28569412], [73.41708374, 16.2859726], [73.41680908, 16.28597069], [73.41680908, 16.28625107], [73.41652679, 16.28625107], [73.41652679, 16.28652954], [73.41625214, 16.28652954], [73.41625214, 16.28680992], [73.41596985, 16.28680992], [73.41596985, 16.28737068], [73.41625214, 16.28737068], [73.41625214, 16.28763962], [73.41652679, 16.28763962], [73.41652679, 16.28792], [73.41791534, 16.28791618], [73.41791534, 16.28847313], [73.41819763, 16.28847313], [73.41819763, 16.28930473], [73.41791534, 16.28930473], [73.41791534, 16.28986168], [73.41764069, 16.28986168], [73.41764069, 16.29097176], [73.41791534, 16.29097176], [73.41791534, 16.29208374], [73.4173584, 16.29208374], [73.4173584, 16.29219055], [73.4173584, 16.2923584], [73.41680908, 16.2923584], [73.41680908, 16.29180908], [73.41652679, 16.29180908], [73.41652679, 16.29124832], [73.41625214, 16.29124832], [73.41625214, 16.29070091], [73.41596985, 16.29070091], [73.41596985, 16.28985977], [73.41569519, 16.28986168], [73.41569519, 16.28930473], [73.4154129, 16.28930473], [73.4154129, 16.28874969], [73.41513824, 16.28874969], [73.41513824, 16.28792], [73.41485596, 16.28792], [73.41485596, 16.28737068], [73.41430664, 16.28737068], [73.41430664, 16.28708076], [73.41374969, 16.28708267], [73.41374969, 16.2868042], [73.41348267, 16.28680992], [73.41348267, 16.28652954], [73.41291809, 16.28652954], [73.41291809, 16.28625107], [73.4126358, 16.28625107], [73.4126358, 16.28597069], [73.41236115, 16.2859726], [73.41236115, 16.28541756], [73.41179657, 16.28541946], [73.41179657, 16.28514099], [73.4109726, 16.28514099], [73.4109726, 16.28429985], [73.41069794, 16.28430557], [73.41069794, 16.28180504], [73.4109726, 16.28181076], [73.4109726, 16.28123856], [73.41124725, 16.28125191], [73.41124725, 16.28096962], [73.41152954, 16.28096962], [73.41152954, 16.28041649], [73.41179657, 16.2804203], [73.41179657, 16.28014183], [73.41208649, 16.28014183], [73.41208649, 16.27931023], [73.41179657, 16.27931023], [73.41179657, 16.27875137], [73.41152954, 16.27875137], [73.41152954, 16.27846909], [73.41124725, 16.2784729], [73.41124725, 16.27819443], [73.4109726, 16.27820015], [73.4109726, 16.27791977], [73.41042328, 16.27791977], [73.41042328, 16.27931023], [73.41014099, 16.27930641], [73.41014099, 16.27958107], [73.4098587, 16.27957916], [73.4098587, 16.28014183], [73.40957642, 16.28014183], [73.40957642, 16.28070068], [73.40930939, 16.28069496], [73.40930176, 16.28208351], [73.4090271, 16.2820797], [73.4090271, 16.28375053], [73.40875244, 16.28375053], [73.40876007, 16.28486061], [73.40847015, 16.28486061], [73.40847015, 16.28569412], [73.40820312, 16.28569031], [73.40820312, 16.28680992], [73.40791321, 16.28680992], [73.40791321, 16.28763962], [73.40763855, 16.28763962], [73.40763855, 16.28874969], [73.40736389, 16.28874969], [73.40736389, 16.28986168], [73.4070816, 16.28985977], [73.4070816, 16.29070091], [73.40680695, 16.29069519], [73.40680695, 16.29208374], [73.40651703, 16.29207993], [73.40651703, 16.29291916], [73.40625, 16.29291916], [73.40625, 16.29403114], [73.40598297, 16.29403114], [73.40598297, 16.29514122], [73.40569305, 16.29513931], [73.40569305, 16.29624939], [73.4054184, 16.29624939], [73.4054184, 16.29708481], [73.40513611, 16.29708481], [73.40513611, 16.29736137], [73.40486145, 16.29735947], [73.40486145, 16.29763985], [73.40458679, 16.29763985], [73.40458679, 16.29792023], [73.40429688, 16.29792023], [73.40429688, 16.2990303], [73.40402985, 16.2990303], [73.40402985, 16.29931068], [73.40374756, 16.29930687], [73.40374756, 16.29958344], [73.40180206, 16.29958344], [73.40180206, 16.29930687], [73.40125275, 16.29930687], [73.40125275, 16.29958344], [73.40041351, 16.29958344], [73.40041351, 16.29986191], [73.40013885, 16.29986], [73.40013885, 16.30042076], [73.3998642, 16.30041695], [73.39985657, 16.3006897], [73.39958191, 16.30069542], [73.39958191, 16.30097198], [73.39930725, 16.30097008], [73.39930725, 16.30153084], [73.39901733, 16.30153084], [73.39901733, 16.30402756], [73.39875031, 16.30402756], [73.39875031, 16.30514145], [73.39847565, 16.30514145], [73.39847565, 16.30569458], [73.39819336, 16.30569077], [73.39819336, 16.30820274], [73.3979187, 16.30820274], [73.3979187, 16.30875015], [73.39763641, 16.30875015], [73.39763641, 16.30903053], [73.39736176, 16.30903053], [73.39736176, 16.30931091], [73.3970871, 16.30930519], [73.3970871, 16.30958366], [73.39679718, 16.30957985], [73.39679718, 16.30986023], [73.39624786, 16.30986023], [73.39624786, 16.31014061], [73.39597321, 16.31014061], [73.39597321, 16.31042099], [73.39569092, 16.31041718], [73.39569092, 16.31069374], [73.39541626, 16.31069374], [73.39541626, 16.3120842], [73.3951416, 16.31208038], [73.3951416, 16.31264114], [73.39485931, 16.31263924], [73.39485931, 16.31319427], [73.39458466, 16.31319427], [73.39458466, 16.31347275], [73.39430237, 16.31347084], [73.39430237, 16.31431007], [73.39402771, 16.31430626], [73.39402771, 16.31458282], [73.39375305, 16.31458282], [73.39375305, 16.31736183], [73.39402771, 16.31735039], [73.39402771, 16.3176384], [73.39430237, 16.3176384], [73.39430237, 16.31792068], [73.39541626, 16.31792068], [73.39541626, 16.31819916], [73.39569092, 16.31819534], [73.39569092, 16.31847191], [73.39597321, 16.31846809], [73.39597321, 16.31986237], [73.39624786, 16.31986237], [73.39624786, 16.32208061], [73.39597321, 16.32208061], [73.39597321, 16.32291985], [73.39569092, 16.32291985], [73.39569092, 16.32374954], [73.39541626, 16.32374954], [73.39541626, 16.3243103], [73.3951416, 16.3243103], [73.3951416, 16.32514], [73.39485931, 16.32514], [73.39485931, 16.32542038], [73.39457703, 16.32542038], [73.39457703, 16.32625008], [73.39430237, 16.32625008], [73.39430237, 16.32681084], [73.39458466, 16.32680511], [73.39458466, 16.32847214], [73.39485931, 16.32847023], [73.39485931, 16.32903099], [73.3951416, 16.32903099], [73.3951416, 16.32930946], [73.39569092, 16.32930565], [73.39569092, 16.33097267], [73.39541626, 16.33097076], [73.39541626, 16.3318119], [73.3951416, 16.33180618], [73.3951416, 16.33208275], [73.39485931, 16.33208275], [73.39485931, 16.33235931], [73.39457703, 16.33234978], [73.39457703, 16.3326416], [73.39430237, 16.3326416], [73.39430237, 16.33234978], [73.39319611, 16.33234978], [73.39319611, 16.3326416], [73.39263916, 16.3326416], [73.39263916, 16.33292007], [73.3923645, 16.33291626], [73.3923645, 16.33319473], [73.39180756, 16.33319473], [73.39180756, 16.33346939], [73.39097595, 16.33346939], [73.39097595, 16.33375168], [73.39041901, 16.33375168], [73.39041901, 16.33403015], [73.39013672, 16.33402824], [73.39013672, 16.33430481], [73.38930511, 16.33430481], [73.38930511, 16.33458328], [73.38903046, 16.33458328], [73.38903046, 16.33486366], [73.38819122, 16.33486176], [73.38819122, 16.33514023], [73.38735962, 16.33514023], [73.38735962, 16.33542061], [73.38707733, 16.33542061], [73.38707733, 16.3357029], [73.38680267, 16.33569527], [73.38680267, 16.33597374], [73.38625336, 16.33597183], [73.38625336, 16.33625031], [73.38569641, 16.33625031], [73.38569641, 16.33653069], [73.38540649, 16.33653069], [73.38540649, 16.33736038], [73.38569641, 16.33736038], [73.38569641, 16.33764076], [73.38597107, 16.33763885], [73.38597107, 16.3381958], [73.38625336, 16.33819008], [73.38625336, 16.33848], [73.38652802, 16.33848], [73.38652802, 16.33875084], [73.38680267, 16.33875084], [73.38680267, 16.33903122], [73.38708496, 16.3390274], [73.38708496, 16.33958244], [73.38735962, 16.33958244], [73.38735962, 16.34236145], [73.38764954, 16.34235954], [73.38764954, 16.34320068], [73.38791656, 16.34320068], [73.38791656, 16.34403038], [73.38819122, 16.34403038], [73.38819122, 16.34458351], [73.38847351, 16.34458351], [73.38847351, 16.34486008], [73.38874817, 16.34485817], [73.38874817, 16.34542084], [73.38930511, 16.34541893], [73.38930511, 16.34569359], [73.38957977, 16.34569359], [73.38957977, 16.34597015], [73.38986206, 16.34596825], [73.38986206, 16.34624863], [73.39013672, 16.34624863], [73.39013672, 16.34653282], [73.39041901, 16.34653282], [73.39041901, 16.3476429], [73.39013672, 16.3476429], [73.39013672, 16.34791946], [73.38986206, 16.34791756], [73.38986206, 16.3484726], [73.38957977, 16.3484726], [73.38957977, 16.34875107], [73.38931274, 16.34875107], [73.38931274, 16.34902954], [73.38903046, 16.34902763], [73.38903046, 16.35069466], [73.38874817, 16.35069466], [73.38874817, 16.35208321], [73.38846588, 16.35207939], [73.38846588, 16.35292053], [73.38819122, 16.35292053], [73.38819122, 16.35403061], [73.38791656, 16.35403061], [73.38791656, 16.35486031], [73.38764191, 16.35486031], [73.38764191, 16.35597229], [73.38735962, 16.35597038], [73.38735962, 16.35736084], [73.38707733, 16.35736084], [73.38707733, 16.35791969], [73.38735962, 16.35791588], [73.38735962, 16.35853958], [73.38735962, 16.35874939], [73.38764191, 16.35874939], [73.38764191, 16.35985947], [73.38791656, 16.35985947], [73.38791656, 16.36042023], [73.38819122, 16.36041641], [73.38819122, 16.36069489], [73.38846588, 16.36068916], [73.38846588, 16.36125183], [73.38874817, 16.36125183], [73.38874817, 16.3615303], [73.38903046, 16.3615303], [73.38903046, 16.36181068], [73.38930511, 16.36180496], [73.38930511, 16.36208344], [73.38957977, 16.36208344], [73.38957977, 16.36180496], [73.38986206, 16.36181068], [73.38986206, 16.3615303], [73.39041901, 16.3615303], [73.39041901, 16.36042023], [73.39068604, 16.36042023], [73.39068604, 16.35957909], [73.39097595, 16.3595829], [73.39097595, 16.35930634], [73.39125061, 16.35931015], [73.39125061, 16.35874939], [73.3915329, 16.35874939], [73.39152527, 16.35819435], [73.39180756, 16.35819435], [73.39180756, 16.35791588], [73.39208221, 16.35791969], [73.39208221, 16.35708046], [73.3923645, 16.35708237], [73.3923645, 16.35652733], [73.39263916, 16.35652733], [73.39263916, 16.35625076], [73.39290619, 16.35625076], [73.39290619, 16.35597038], [73.39319611, 16.35597229], [73.39319611, 16.35581017], [73.39319611, 16.35569382], [73.39347076, 16.35569382], [73.39347076, 16.35541725], [73.39375305, 16.35542107], [73.39375305, 16.35514069], [73.39430237, 16.35514069], [73.39430237, 16.35486031], [73.39736176, 16.35486031], [73.39736176, 16.35514069], [73.3979187, 16.35514069], [73.3979187, 16.35542107], [73.39847565, 16.35541725], [73.39847565, 16.35569382], [73.39902496, 16.35569382], [73.39902496, 16.35597229], [73.39958191, 16.35597229], [73.39958191, 16.35625076], [73.40235901, 16.35625076], [73.40235901, 16.35597038], [73.40402985, 16.35597038], [73.40402985, 16.35625076], [73.40458679, 16.35625076], [73.40458679, 16.35652733], [73.40569305, 16.35652733], [73.40569305, 16.35708237], [73.40651703, 16.35708046], [73.40651703, 16.35736084], [73.40735626, 16.35736084], [73.40735626, 16.35764122], [73.40820312, 16.35764122], [73.40820312, 16.35791969], [73.40930176, 16.35791588], [73.40930176, 16.35805511], [73.40930939, 16.35819435], [73.41041565, 16.35819435], [73.41041565, 16.35847282], [73.41069794, 16.35847092], [73.41069794, 16.35874939], [73.4109726, 16.35874939], [73.4109726, 16.35903168], [73.41124725, 16.35902977], [73.41124725, 16.35921097], [73.41124725, 16.35930634], [73.41152954, 16.35930634], [73.41152954, 16.35985947], [73.41179657, 16.35985947], [73.41179657, 16.36042023], [73.41152954, 16.36041641], [73.41152954, 16.36069489], [73.41124725, 16.36069489], [73.41124725, 16.36208344], [73.41069794, 16.36208344], [73.41069794, 16.36180496], [73.41014099, 16.36181068], [73.41014099, 16.3615303], [73.4098587, 16.3615303], [73.4098587, 16.36125183], [73.40957642, 16.36125183], [73.40957642, 16.36096954], [73.40930176, 16.36096954], [73.40930176, 16.36069489], [73.40898132, 16.36069489], [73.40875244, 16.36069489], [73.40875244, 16.36041641], [73.40847015, 16.36042023], [73.40847015, 16.36014175], [73.40791321, 16.36014175], [73.40791321, 16.35903168], [73.40763855, 16.35903168], [73.40763855, 16.35819054], [73.40680695, 16.35819435], [73.40680695, 16.35791588], [73.40625, 16.35791588], [73.40625, 16.35819435], [73.40569305, 16.35819054], [73.40569305, 16.35903168], [73.40486145, 16.35903168], [73.40486145, 16.35931015], [73.4026413, 16.35930634], [73.4026413, 16.3595829], [73.39990997, 16.3595829], [73.39930725, 16.3595829], [73.39930725, 16.35985947], [73.39819336, 16.35985947], [73.39819336, 16.3595829], [73.39653015, 16.3595829], [73.39653015, 16.35930634], [73.39541626, 16.35931015], [73.39541626, 16.35903168], [73.3951416, 16.35903168], [73.3951416, 16.35931015], [73.39485931, 16.35931015], [73.39485931, 16.35903168], [73.39375305, 16.35903168], [73.39375305, 16.35874939], [73.39319611, 16.35874939], [73.39319611, 16.35903168], [73.39291382, 16.35902977], [73.39291382, 16.3595829], [73.39263916, 16.35957909], [73.39263916, 16.36014175], [73.39290619, 16.36014175], [73.39290619, 16.36042023], [73.39319611, 16.36041641], [73.39319611, 16.36069489], [73.39291382, 16.36069489], [73.39291382, 16.36208344], [73.39263916, 16.36208344], [73.39263916, 16.36236382], [73.39208221, 16.36236191], [73.39208221, 16.36375046], [73.39180756, 16.36375046], [73.39180756, 16.36486053], [73.3915329, 16.36486053], [73.3915329, 16.36541939], [73.39125061, 16.36541748], [73.39125061, 16.36569595], [73.38986206, 16.36569595], [73.38986206, 16.36541748], [73.38957977, 16.36541939], [73.38957977, 16.36486053], [73.38930511, 16.36486053], [73.38930511, 16.36458588], [73.38903046, 16.36458588], [73.38903046, 16.3643055], [73.38874817, 16.36431122], [73.38874817, 16.36403084], [73.38846588, 16.36403084], [73.38846588, 16.36375046], [73.38819122, 16.36375046], [73.38819122, 16.36347008], [73.38764191, 16.36347389], [73.38764191, 16.36319542], [73.38652802, 16.3631897], [73.38652802, 16.36069489], [73.38625336, 16.36069489], [73.38625336, 16.36041641], [73.38597107, 16.36042023], [73.38597107, 16.36014175], [73.38569641, 16.36014175], [73.38569641, 16.35985947], [73.38541412, 16.35985947], [73.38541412, 16.3595829], [73.38486481, 16.3595829], [73.38486481, 16.35930634], [73.38430786, 16.35931015], [73.38430786, 16.35903168], [73.38375092, 16.35903168], [73.38375092, 16.35874939], [73.38318634, 16.35874939], [73.38318634, 16.35903168], [73.38291931, 16.35902977], [73.38291931, 16.3595829], [73.38263702, 16.3595829], [73.38263702, 16.35985947], [73.38291931, 16.35985947], [73.38291931, 16.36014175], [73.38263702, 16.36014175], [73.38263702, 16.36069489], [73.38236237, 16.36069489], [73.38236237, 16.36096954], [73.38208008, 16.36096954], [73.38208008, 16.36125183], [73.38124847, 16.36125183], [73.38124847, 16.3615303], [73.37902832, 16.3615303], [73.37902832, 16.36181068], [73.37819672, 16.36180496], [73.37819672, 16.36208344], [73.37763977, 16.36208344], [73.37763977, 16.36236382], [73.37735748, 16.36236382], [73.37735748, 16.36208344], [73.37708282, 16.36208344], [73.37708282, 16.36180496], [73.37680817, 16.36181068], [73.37680817, 16.36125183], [73.37652588, 16.36125183], [73.37652588, 16.36096954], [73.37625122, 16.36096954], [73.37625122, 16.36069489], [73.37596893, 16.36069489], [73.37596893, 16.36041641], [73.37568665, 16.36042023], [73.37568665, 16.36014175], [73.37541962, 16.36014175], [73.37541962, 16.35985947], [73.37236023, 16.35985947], [73.37236023, 16.36042023], [73.37208557, 16.36041641], [73.37208557, 16.36069489], [73.37124634, 16.36069489], [73.37124634, 16.36096954], [73.37069702, 16.36096954], [73.37069702, 16.36125183], [73.3704071, 16.36125183], [73.3704071, 16.3615303], [73.37014008, 16.3615303], [73.37014008, 16.36181068], [73.36985779, 16.36180496], [73.36985779, 16.36208344], [73.36930847, 16.36208344], [73.36930847, 16.36236382], [73.36875153, 16.36236191], [73.36875153, 16.36264992], [73.36846924, 16.36264992], [73.36846924, 16.36292076], [73.36819458, 16.36291695], [73.36819458, 16.36347389], [73.36791992, 16.36347008], [73.36791992, 16.36486053], [73.36818695, 16.36486053], [73.36818695, 16.36541939], [73.36846924, 16.36541748], [73.36846924, 16.36597252], [73.36875153, 16.36597061], [73.36875153, 16.36680984], [73.36902618, 16.36680984], [73.36902618, 16.36736107], [73.36930847, 16.36736107], [73.36930847, 16.36763954], [73.36958313, 16.36763954], [73.36958313, 16.36819458], [73.36985779, 16.36819077], [73.36985779, 16.36874962], [73.37014008, 16.36874962], [73.37014008, 16.36930466], [73.37041473, 16.36930466], [73.37041473, 16.3698616], [73.37069702, 16.3698597], [73.37069702, 16.37042046], [73.37124634, 16.37041664], [73.37124634, 16.37097168], [73.37152863, 16.37096977], [73.37152863, 16.37124825], [73.37180328, 16.37124825], [73.37180328, 16.37181091], [73.37208557, 16.37180519], [73.37208557, 16.37347031], [73.37180328, 16.37347031], [73.37180328, 16.37403107], [73.37152863, 16.37403107], [73.37152863, 16.37458992], [73.37124634, 16.37458992], [73.37124634, 16.37514114], [73.37069702, 16.37514114], [73.37069702, 16.37541962], [73.3704071, 16.37541962], [73.3704071, 16.37514114], [73.36875153, 16.37514114], [73.36875153, 16.37541962], [73.36819458, 16.3754158], [73.36819458, 16.37569427], [73.36763763, 16.37569427], [73.36763763, 16.37597275], [73.36736298, 16.37597275], [73.36736298, 16.37625122], [73.36708069, 16.37625122], [73.36708069, 16.37681007], [73.36680603, 16.37680626], [73.36680603, 16.3773613], [73.36653137, 16.3773613], [73.36653137, 16.37930679], [73.36680603, 16.37930679], [73.36680603, 16.37958336], [73.36708069, 16.37958336], [73.36708069, 16.37986183], [73.36763763, 16.37985992], [73.36763763, 16.3801403], [73.36846924, 16.3801403], [73.36846924, 16.38042068], [73.36875153, 16.38041687], [73.36875153, 16.38069534], [73.36902618, 16.38068962], [73.36902618, 16.38292122], [73.36930847, 16.3829174], [73.36930847, 16.38458252], [73.36958313, 16.38458061], [73.36958313, 16.38514137], [73.36985779, 16.38514137], [73.36985779, 16.3856945], [73.37014008, 16.38569069], [73.37014008, 16.38792038], [73.37041473, 16.38791656], [73.37041473, 16.38847351], [73.37069702, 16.3884697], [73.37069702, 16.38903046], [73.37097168, 16.38903046], [73.37097168, 16.38959122], [73.37124634, 16.38959122], [73.37124634, 16.38986015], [73.37180328, 16.38986015], [73.37180328, 16.39014053], [73.37236023, 16.39014053], [73.37236023, 16.38986015], [73.37291718, 16.38986015], [73.37291718, 16.38959122], [73.37346649, 16.38959122], [73.37346649, 16.38931084], [73.37403107, 16.38931084], [73.37403107, 16.38875008], [73.37431335, 16.38875008], [73.37430573, 16.38791656], [73.37458038, 16.38792038], [73.37458038, 16.38707924], [73.37486267, 16.38708115], [73.37486267, 16.38625145], [73.37513733, 16.38625145], [73.37513733, 16.38514137], [73.37486267, 16.38514137], [73.37486267, 16.38458061], [73.37458038, 16.38458252], [73.37458038, 16.38402748], [73.37431335, 16.38402748], [73.37431335, 16.38181114], [73.37403107, 16.38181114], [73.37403107, 16.38153076], [73.37374878, 16.38153076], [73.37374878, 16.38097], [73.37347412, 16.38097191], [73.37347412, 16.38041687], [73.37319183, 16.38042068], [73.37319183, 16.37985992], [73.37291718, 16.37986183], [73.37291718, 16.37680626], [73.37319183, 16.37681007], [73.37319183, 16.37652969], [73.37346649, 16.37652969], [73.37346649, 16.37625122], [73.37374878, 16.37625122], [73.37374878, 16.37652969], [73.37431335, 16.37652969], [73.37431335, 16.37681007], [73.37458038, 16.37680626], [73.37458038, 16.3773613], [73.37486267, 16.37735939], [73.37486267, 16.37792015], [73.37513733, 16.37791634], [73.37513733, 16.37847137], [73.37541962, 16.37846947], [73.37541962, 16.37874985], [73.37568665, 16.37874985], [73.37568665, 16.37903023], [73.37625122, 16.37902832], [73.37625122, 16.37930679], [73.37735748, 16.37930679], [73.37735748, 16.37958336], [73.37763977, 16.37958336], [73.37763977, 16.37986183], [73.3779068, 16.37985992], [73.3779068, 16.38042068], [73.37819672, 16.38041687], [73.37819672, 16.38208389], [73.37845612, 16.38208008], [73.37845612, 16.38236046], [73.37874603, 16.38236046], [73.37874603, 16.38430977], [73.37902832, 16.38430977], [73.37902832, 16.38485909], [73.37930298, 16.38485909], [73.37930298, 16.38514137], [73.37902832, 16.38514137], [73.37902832, 16.38735962], [73.37930298, 16.38735962], [73.37930298, 16.38764191], [73.3795929, 16.38764191], [73.3795929, 16.38792038], [73.37985992, 16.38791656], [73.37985992, 16.38847351], [73.38041687, 16.3884697], [73.38041687, 16.38875008], [73.38096619, 16.38875008], [73.38096619, 16.38903046], [73.38152313, 16.38903046], [73.38152313, 16.38931084], [73.38181305, 16.38931084], [73.38181305, 16.38959122], [73.38208008, 16.38959122], [73.38208008, 16.38986015], [73.38263702, 16.38986015], [73.38263702, 16.39014053], [73.38318634, 16.39014053], [73.38318634, 16.39042091], [73.38430786, 16.3904171], [73.38430786, 16.39069366], [73.38458252, 16.39069366], [73.38458252, 16.39097214], [73.38486481, 16.39097214], [73.38486481, 16.39118958], [73.38485718, 16.39153099], [73.38513947, 16.39153099], [73.38513947, 16.39180946], [73.38541412, 16.39180565], [73.38541412, 16.39208412], [73.38569641, 16.39208412], [73.38569641, 16.39263916], [73.38597107, 16.39263916], [73.38597107, 16.3931942], [73.38625336, 16.3931942], [73.38625336, 16.39347267], [73.38652802, 16.39347076], [73.38652802, 16.39375114], [73.38680267, 16.39375114], [73.38680267, 16.39402962], [73.38735962, 16.39402962], [73.38735962, 16.39431], [73.38791656, 16.39430618], [73.38791656, 16.39458275], [73.38819122, 16.39458084], [73.38819122, 16.39486122], [73.38874817, 16.39486122], [73.38874817, 16.39513969], [73.39013672, 16.39513969], [73.39013672, 16.39486122], [73.39097595, 16.39486122], [73.39097595, 16.39458084], [73.39152527, 16.39458275], [73.39152527, 16.39430618], [73.39180756, 16.39431], [73.39180756, 16.39402962], [73.39208221, 16.39402962], [73.39208221, 16.39347076], [73.3923645, 16.39347267], [73.3923645, 16.39291573], [73.39263916, 16.39291954], [73.39263916, 16.39262962], [73.39291382, 16.39263916], [73.39291382, 16.39208412], [73.39319611, 16.39208412], [73.39319611, 16.39180565], [73.39346313, 16.39180946], [73.39346313, 16.39153099], [73.39375305, 16.39153099], [73.39375305, 16.39097023], [73.39402771, 16.39097214], [73.39402771, 16.39069366], [73.39430237, 16.39069366], [73.39430237, 16.3904171], [73.39485931, 16.39042091], [73.39485931, 16.39014053], [73.39541626, 16.39014053], [73.39541626, 16.38986015], [73.39597321, 16.38986015], [73.39597321, 16.38959122], [73.39653015, 16.38959122], [73.39653015, 16.38931084], [73.39819336, 16.38931084], [73.39819336, 16.38903046], [73.40013885, 16.38903046], [73.40013885, 16.38931084], [73.4006958, 16.38931084], [73.4006958, 16.38959122], [73.40125275, 16.38959122], [73.40125275, 16.38986015], [73.4015274, 16.38986015], [73.4015274, 16.39014053], [73.40180206, 16.39013863], [73.40180206, 16.39069366], [73.40208435, 16.39069366], [73.40208435, 16.39097214], [73.40235901, 16.39097023], [73.40235901, 16.39125061], [73.40262604, 16.39125061], [73.40262604, 16.39153099], [73.40291595, 16.39153099], [73.40291595, 16.39236069], [73.40319824, 16.39236069], [73.40319824, 16.39291954], [73.4034729, 16.39291573], [73.4034729, 16.3931942], [73.40374756, 16.3931942], [73.40374756, 16.39347267], [73.40402985, 16.39347076], [73.40402985, 16.39402962], [73.40429688, 16.39402962], [73.40429688, 16.39431], [73.40458679, 16.39431], [73.40458679, 16.39486122], [73.40486145, 16.39486122], [73.40486145, 16.39569473], [73.40513611, 16.39569473], [73.40513611, 16.39680481], [73.4054184, 16.39680481], [73.4054184, 16.39963913], [73.4054184, 16.40097046], [73.40513611, 16.40097046], [73.40513611, 16.40208054], [73.40486145, 16.40208054], [73.40486145, 16.40431023], [73.40513611, 16.40430641], [73.40513611, 16.40458488], [73.4054184, 16.40458488], [73.4054184, 16.40486145], [73.4034729, 16.40486145], [73.4034729, 16.40458488], [73.40319824, 16.40458488], [73.40319061, 16.40430641], [73.40291595, 16.40431023], [73.40291595, 16.40402985], [73.40262604, 16.40402985], [73.40262604, 16.40374947], [73.40235901, 16.40374947], [73.40235901, 16.4034729], [73.40180206, 16.40347481], [73.40180206, 16.40319443], [73.40125275, 16.40319443], [73.40125275, 16.40291595], [73.40097046, 16.40291977], [73.40097046, 16.40263939], [73.40040588, 16.40263939], [73.40040588, 16.40236282], [73.39985657, 16.40236282], [73.39985657, 16.40208054], [73.39958191, 16.40208054], [73.39958191, 16.40180588], [73.39930725, 16.40182114], [73.39930725, 16.40153122], [73.39848328, 16.40153122], [73.39848328, 16.40125275], [73.39736176, 16.40125275], [73.39736176, 16.40097046], [73.39653015, 16.40097046], [73.39653015, 16.40069389], [73.39541626, 16.40069389], [73.39541626, 16.40041733], [73.3951416, 16.40041733], [73.3951416, 16.40069389], [73.39430237, 16.40069389], [73.39430237, 16.40041733], [73.39291382, 16.40041733], [73.39291382, 16.40069389], [73.39069366, 16.40069389], [73.39069366, 16.40097046], [73.39041901, 16.40097046], [73.39041901, 16.40125275], [73.38986206, 16.40125275], [73.38986206, 16.40153122], [73.38931274, 16.40153122], [73.38931274, 16.40182114], [73.38874817, 16.40180588], [73.38874817, 16.40208054], [73.38819122, 16.40208054], [73.38819122, 16.40263939], [73.38791656, 16.40263939], [73.38791656, 16.40291977], [73.38735962, 16.40291595], [73.38735962, 16.40319443], [73.38708496, 16.40319443], [73.38708496, 16.40347481], [73.38625336, 16.40347481], [73.38625336, 16.40319443], [73.38597107, 16.40319443], [73.38597107, 16.40263939], [73.38569641, 16.40263939], [73.38569641, 16.40236282], [73.38540649, 16.40236282], [73.38540649, 16.40125275], [73.38513947, 16.40125275], [73.38513947, 16.40042114], [73.38485718, 16.40042114], [73.38485718, 16.40014267], [73.38459015, 16.40014267], [73.38459015, 16.39985847], [73.38430786, 16.39985847], [73.38430786, 16.39930916], [73.3840332, 16.39930916], [73.3840332, 16.39903069], [73.38375092, 16.39903069], [73.38375092, 16.39846992], [73.38346863, 16.39847183], [73.38346863, 16.39819527], [73.38291931, 16.39819908], [73.38291931, 16.39792061], [73.38263702, 16.39792061], [73.38263702, 16.39763832], [73.38208008, 16.39763832], [73.38208008, 16.39735985], [73.38153076, 16.39736176], [73.38153076, 16.39708328], [73.38124847, 16.39708328], [73.38124847, 16.39680481], [73.38097382, 16.39680481], [73.38097382, 16.39652634], [73.38069153, 16.39652824], [73.38069153, 16.39624977], [73.38014221, 16.39624977], [73.38014221, 16.39596939], [73.37985992, 16.3959713], [73.37985992, 16.39569473], [73.37864685, 16.39569473], [73.37763977, 16.39569473], [73.37763977, 16.3959713], [73.37708282, 16.39596939], [73.37708282, 16.39624977], [73.37680817, 16.39624977], [73.37680817, 16.39680481], [73.37652588, 16.39680481], [73.37652588, 16.39708328], [73.37569427, 16.39708328], [73.37569427, 16.39736176], [73.37541962, 16.39736176], [73.37541962, 16.39708328], [73.37486267, 16.39708328], [73.37486267, 16.39680481], [73.37458038, 16.39680481], [73.37458038, 16.39652634], [73.37431335, 16.39652824], [73.37431335, 16.39624977], [73.37374878, 16.39624977], [73.37374878, 16.39596939], [73.37291718, 16.3959713], [73.37291718, 16.39569473], [73.37264252, 16.39569473], [73.37264252, 16.3959713], [73.36985779, 16.3959713], [73.36985779, 16.39569473], [73.36930847, 16.39569473], [73.36930847, 16.3959713], [73.36875153, 16.3959713], [73.36875153, 16.39569473], [73.36846924, 16.39569473], [73.36846924, 16.3959713], [73.36818695, 16.39596939], [73.36818695, 16.39624977], [73.36763763, 16.39624977], [73.36763763, 16.39652824], [73.36736298, 16.39652634], [73.36736298, 16.39680481], [73.36680603, 16.39680481], [73.36680603, 16.39708328], [73.36597443, 16.39708328], [73.36597443, 16.39736176], [73.36569214, 16.39735985], [73.36569214, 16.39763832], [73.36541748, 16.39763832], [73.36541748, 16.39903069], [73.36569214, 16.39903069], [73.36569214, 16.39930916], [73.36597443, 16.39930534], [73.36597443, 16.39958382], [73.36624908, 16.39957809], [73.36624908, 16.39985847], [73.36651611, 16.39985847], [73.36651611, 16.40014267], [73.36680603, 16.40014267], [73.36680603, 16.40042114], [73.36708069, 16.40041733], [73.36708069, 16.40069389], [73.36736298, 16.40069008], [73.36736298, 16.40125275], [73.36708069, 16.40125275], [73.36708069, 16.40153122], [73.36680603, 16.40153122], [73.36680603, 16.40182114], [73.36624908, 16.40182114], [73.36624908, 16.40236282], [73.3659668, 16.40236282], [73.3659668, 16.40291977], [73.36569214, 16.40291977], [73.36569214, 16.40402985], [73.36541748, 16.40402985], [73.36541748, 16.4054203], [73.36513519, 16.40541649], [73.36513519, 16.40763855], [73.36541748, 16.40763092], [73.36541748, 16.40792084], [73.36569214, 16.40791512], [73.36569214, 16.40819359], [73.36597443, 16.40819359], [73.36597443, 16.40847206], [73.36624908, 16.40847015], [73.36624908, 16.40875053], [73.36680603, 16.40875053], [73.36680603, 16.40903091], [73.36708069, 16.40903091], [73.36708069, 16.40986061], [73.36680603, 16.40986061], [73.36680603, 16.41013908], [73.36651611, 16.41013908], [73.36651611, 16.41069984], [73.36624908, 16.41069984], [73.36624908, 16.41124916], [73.3659668, 16.41124916], [73.3659668, 16.41181183], [73.36569214, 16.41181183], [73.36569214, 16.41376114], [73.36541748, 16.4137516], [73.36541748, 16.4145813], [73.36514282, 16.41457939], [73.36514282, 16.41514015], [73.36486053, 16.41514015], [73.36486053, 16.41570282], [73.36458588, 16.41569519], [73.36458588, 16.41597366], [73.36429596, 16.41596985], [73.36429596, 16.41653061], [73.36402893, 16.4165287], [73.36402893, 16.41680527], [73.36374664, 16.41680527], [73.36374664, 16.41708374], [73.36319733, 16.41707993], [73.36319733, 16.41736031], [73.36292267, 16.41736031], [73.36292267, 16.41764069], [73.36264038, 16.41764069], [73.36264038, 16.41792107], [73.36235809, 16.41791725], [73.36235809, 16.41819572], [73.36207581, 16.41819], [73.36207581, 16.41903114], [73.36180878, 16.41903114], [73.36180878, 16.41986084], [73.36152649, 16.41986084], [73.36152649, 16.42041969], [73.36125183, 16.42041969], [73.36125183, 16.42124939], [73.36096954, 16.42124939], [73.36096954, 16.42319489], [73.36068726, 16.42319107], [73.36068726, 16.42374992], [73.36042023, 16.42374992], [73.36042023, 16.4240284], [73.35791779, 16.4240284], [73.35791779, 16.42569923], [73.35819244, 16.42569351], [73.35819244, 16.42708397], [73.3584671, 16.42708015], [73.3584671, 16.42736244], [73.35874939, 16.42736244], [73.35874939, 16.42764282], [73.35901642, 16.42764282], [73.35901642, 16.42791939], [73.35930634, 16.42791748], [73.35930634, 16.42819214], [73.35958099, 16.42819023], [73.35958099, 16.43013954], [73.35930634, 16.43013954], [73.35930634, 16.4323616], [73.35902405, 16.4323616], [73.35902405, 16.43347168], [73.35874939, 16.43346977], [73.35874939, 16.43514061], [73.35847473, 16.4351387], [73.35847473, 16.4370842], [73.35819244, 16.4370842], [73.35819244, 16.43819427], [73.35791779, 16.43819046], [73.35791779, 16.43874931], [73.35764313, 16.43874931], [73.35764313, 16.43931007], [73.35736084, 16.43930626], [73.35736084, 16.43985939], [73.35708618, 16.43985939], [73.35708618, 16.44042015], [73.35736084, 16.44042015], [73.35736084, 16.44125175], [73.35764313, 16.44125175], [73.35764313, 16.44153023], [73.3584671, 16.44153023], [73.3584671, 16.44125175], [73.35874939, 16.44125175], [73.35874939, 16.44096947], [73.36152649, 16.44096947], [73.36152649, 16.44069481], [73.36208344, 16.44069481], [73.36208344, 16.44041634], [73.36235809, 16.44042015], [73.36235809, 16.44014168], [73.36264038, 16.44014168], [73.36264038, 16.43985939], [73.36291504, 16.43985939], [73.36291504, 16.43958282], [73.36319733, 16.43958282], [73.36319733, 16.43930626], [73.36374664, 16.43931007], [73.36374664, 16.4390316], [73.36486053, 16.43902779], [73.36486053, 16.43958282], [73.36458588, 16.43958282], [73.36458588, 16.43985939], [73.36374664, 16.43985939], [73.36374664, 16.44014168], [73.36347961, 16.44014168], [73.36347961, 16.44042015], [73.36319733, 16.44041634], [73.36319733, 16.44096947], [73.36291504, 16.44096947], [73.36292267, 16.44125175], [73.36264038, 16.44125175], [73.36264038, 16.44180489], [73.36235809, 16.44180489], [73.36235809, 16.44208336], [73.36207581, 16.44207954], [73.36207581, 16.4426403], [73.36152649, 16.4426403], [73.36152649, 16.44292068], [73.36068726, 16.44292068], [73.36068726, 16.4426403], [73.36013794, 16.4426403], [73.36013794, 16.44236183], [73.35930634, 16.44236183], [73.35930634, 16.4426403], [73.35874939, 16.4426403], [73.35874939, 16.44292068], [73.35819244, 16.44292068], [73.35819244, 16.44320107], [73.3576355, 16.44319534], [73.3576355, 16.44347382], [73.35736084, 16.44347382], [73.35736084, 16.44375038], [73.35708618, 16.44374275], [73.35708618, 16.44403076], [73.35652924, 16.44402695], [73.35652924, 16.4445858], [73.35624695, 16.44458008], [73.35624695, 16.44514084], [73.35597229, 16.44513893], [73.35597229, 16.44569588], [73.35569763, 16.44569588], [73.35569763, 16.44597244], [73.35541534, 16.44597244], [73.35542297, 16.44625092], [73.35514069, 16.44625092], [73.35514069, 16.44652939], [73.35402679, 16.44652939], [73.35402679, 16.44625092], [73.35375214, 16.44625092], [73.35375214, 16.44486046], [73.35319519, 16.44486046], [73.35319519, 16.4445858], [73.3520813, 16.44458008], [73.3520813, 16.44486046], [73.35180664, 16.44486046], [73.35180664, 16.44514084], [73.35124969, 16.44514084], [73.35124969, 16.44542122], [73.35097504, 16.4454174], [73.35097504, 16.44569588], [73.35069275, 16.44569588], [73.35069275, 16.44597244], [73.35041809, 16.44597054], [73.35041809, 16.44652939], [73.3501358, 16.44652748], [73.3501358, 16.44708252], [73.34986115, 16.44708061], [73.34986115, 16.44763947], [73.34958649, 16.44763947], [73.34958649, 16.44791985], [73.34929657, 16.44791985], [73.34929657, 16.44874954], [73.34902954, 16.44874954], [73.34902954, 16.44958305], [73.34874725, 16.44958115], [73.34874725, 16.45013809], [73.34848022, 16.45013809], [73.34848022, 16.45042038], [73.34819794, 16.45042038], [73.34819794, 16.45070076], [73.34792328, 16.45070076], [73.34792328, 16.45153046], [73.34764099, 16.45153046], [73.34764099, 16.45293045], [73.3473587, 16.45293045], [73.3473587, 16.45375252], [73.34707642, 16.45375252], [73.34707642, 16.45430946], [73.3473587, 16.45430565], [73.3473587, 16.4556942], [73.34707642, 16.45568085], [73.34707642, 16.45792007], [73.34680939, 16.45791626], [73.34680176, 16.4584713], [73.3465271, 16.45846939], [73.3465271, 16.45903015], [73.34625244, 16.45902824], [73.34625244, 16.45958328], [73.34597015, 16.45957947], [73.34597015, 16.46042061], [73.3456955, 16.46041679], [73.3456955, 16.46097183], [73.34541321, 16.46097183], [73.34542084, 16.46125031], [73.34513855, 16.46125031], [73.34513855, 16.46181107], [73.34486389, 16.46180534], [73.34486389, 16.46208382], [73.3445816, 16.46208], [73.3445816, 16.46236038], [73.34430695, 16.46236038], [73.34430695, 16.46264076], [73.34402466, 16.46263885], [73.34402466, 16.46319389], [73.34375, 16.46319008], [73.34375, 16.46375084], [73.34347534, 16.46375084], [73.34347534, 16.46458244], [73.34319305, 16.46458054], [73.34319305, 16.46513748], [73.3429184, 16.46513748], [73.3429184, 16.46542168], [73.34263611, 16.46542168], [73.34263611, 16.46624947], [73.34236145, 16.46624947], [73.34236145, 16.46708107], [73.34208679, 16.46707916], [73.34208679, 16.46875191], [73.34179688, 16.46875191], [73.34179688, 16.47042084], [73.34152985, 16.47042084], [73.34152985, 16.47153091], [73.3418045, 16.4715271], [73.3418045, 16.47208595], [73.34208679, 16.47208023], [73.34208679, 16.47291946], [73.34236145, 16.47291756], [73.34236145, 16.47569466], [73.34208679, 16.47569084], [73.34208679, 16.47624969], [73.34179688, 16.47624969], [73.34179688, 16.47763824], [73.34152985, 16.47763824], [73.34152985, 16.47847176], [73.34124756, 16.47846985], [73.34124756, 16.47874832], [73.3409729, 16.47874832], [73.3409729, 16.47930908], [73.34069824, 16.47930527], [73.34069824, 16.47958374], [73.33930206, 16.47958374], [73.33930206, 16.4798584], [73.33875275, 16.4798584], [73.33875275, 16.47958374], [73.33791351, 16.47958374], [73.33791351, 16.4798584], [73.33735657, 16.47985077], [73.33735657, 16.48014259], [73.33708191, 16.48014259], [73.33708191, 16.48042107], [73.33652496, 16.48041725], [73.33652496, 16.48069382], [73.33625031, 16.48069382], [73.33625031, 16.48208427], [73.33597565, 16.48208427], [73.33597565, 16.48291588], [73.33569336, 16.48291588], [73.33569336, 16.48347473], [73.3354187, 16.48347282], [73.3354187, 16.48374939], [73.33513641, 16.48374939], [73.33513641, 16.48402977], [73.33486176, 16.48402977], [73.33486176, 16.48431015], [73.3345871, 16.48430634], [73.3345871, 16.48458481], [73.33430481, 16.48458481], [73.33430481, 16.48486137], [73.33403015, 16.48485947], [73.33403015, 16.48513985], [73.33374786, 16.48513985], [73.33374786, 16.48542023], [73.33347321, 16.48542023], [73.33347321, 16.48598099], [73.33319092, 16.48598099], [73.33319092, 16.4865303], [73.33291626, 16.4865284], [73.33291626, 16.48708344], [73.3326416, 16.48707962], [73.3326416, 16.48792076], [73.33235931, 16.48791695], [73.33235931, 16.4881897], [73.33208466, 16.48819542], [73.33208466, 16.48847198], [73.33180237, 16.48847008], [73.33180237, 16.48904037], [73.33152771, 16.48904037], [73.33152771, 16.49041748], [73.33125305, 16.49041748], [73.33125305, 16.49097252], [73.33152771, 16.49097252], [73.33152771, 16.4920826], [73.33125305, 16.4920826], [73.33125305, 16.49347115], [73.33097076, 16.49346924], [73.33097076, 16.49403191], [73.33013916, 16.49403191], [73.33013916, 16.49514008], [73.3298645, 16.49513817], [73.3298645, 16.49708366], [73.32958221, 16.49707985], [73.32958221, 16.49792099], [73.32930756, 16.49792099], [73.32930756, 16.50041962], [73.32902527, 16.5004158], [73.3290329, 16.50263977], [73.32875061, 16.50263977], [73.32875061, 16.50347137], [73.32847595, 16.50347137], [73.32847595, 16.50430489], [73.32818604, 16.50430107], [73.32818604, 16.50542068], [73.32791901, 16.50542068], [73.32791901, 16.50653076], [73.32763672, 16.50653076], [73.32763672, 16.50736237], [73.3273468, 16.50736237], [73.3273468, 16.50792122], [73.32707977, 16.5079174], [73.32707977, 16.50847054], [73.32681274, 16.50847054], [73.32681274, 16.50930977], [73.32653046, 16.50930977], [73.32653046, 16.51015091], [73.32624817, 16.51013947], [73.32624817, 16.5106945], [73.32596588, 16.51069069], [73.32596588, 16.51124954], [73.32569122, 16.51124954], [73.32569122, 16.51208305], [73.32541656, 16.51208115], [73.32541656, 16.51292038], [73.32514191, 16.51292038], [73.32514191, 16.51375008], [73.32485962, 16.51375008], [73.32485962, 16.51403046], [73.32457733, 16.51403046], [73.32457733, 16.51431084], [73.32430267, 16.51430511], [73.32430267, 16.51486206], [73.32402802, 16.51486015], [73.32402802, 16.51514053], [73.32375336, 16.51514053], [73.32375336, 16.51542091], [73.32347107, 16.51541519], [73.32347107, 16.51569366], [73.32319641, 16.51569366], [73.32319641, 16.51597214], [73.32290649, 16.51596069], [73.32290649, 16.51625061], [73.32263947, 16.51625061], [73.32263947, 16.51652908], [73.32096863, 16.51652908], [73.32096863, 16.51625061], [73.32013702, 16.51625061], [73.32013702, 16.51596069], [73.31986237, 16.51597214], [73.31986237, 16.51569366], [73.31903076, 16.51569366], [73.31903076, 16.51541519], [73.31874847, 16.51542091], [73.31874847, 16.51514053], [73.31817627, 16.51514053], [73.31817627, 16.51486015], [73.31791687, 16.51486206], [73.31791687, 16.51458359], [73.31764221, 16.51458359], [73.31764221, 16.51430511], [73.31735992, 16.51431084], [73.31735992, 16.51403046], [73.3170929, 16.51403046], [73.3170929, 16.51375008], [73.31680298, 16.51375008], [73.31680298, 16.5134697], [73.31624603, 16.5134697], [73.31624603, 16.51514053], [73.31652832, 16.51513863], [73.31652832, 16.51597214], [73.31680298, 16.51596069], [73.31680298, 16.51680946], [73.31708527, 16.51680565], [73.31708527, 16.51708412], [73.31735992, 16.51708031], [73.31735992, 16.51763916], [73.31764221, 16.51763916], [73.31764221, 16.51791763], [73.31791687, 16.51791573], [73.31791687, 16.51847267], [73.31817627, 16.51847076], [73.31817627, 16.51874924], [73.31846619, 16.51874924], [73.31846619, 16.51985931], [73.31817627, 16.51985931], [73.31817627, 16.5201416], [73.31791687, 16.5201416], [73.31791687, 16.52069473], [73.31764221, 16.52069092], [73.31764221, 16.52264023], [73.31735992, 16.52264023], [73.31735992, 16.52292061], [73.31708527, 16.52291679], [73.31708527, 16.52347374], [73.31680298, 16.52346992], [73.31680298, 16.52375031], [73.31652832, 16.52375031], [73.31652832, 16.52403069], [73.31624603, 16.52403069], [73.31624603, 16.52625084], [73.31597137, 16.52625084], [73.31597137, 16.52680969], [73.31569672, 16.52680969], [73.31569672, 16.52763939], [73.31597137, 16.52763939], [73.31597137, 16.52819443], [73.31625366, 16.52819443], [73.31625366, 16.5284729], [73.31652832, 16.52847099], [73.31652832, 16.52874947], [73.31680298, 16.52874947], [73.31680298, 16.52931023], [73.3170929, 16.52931023], [73.3170929, 16.53013992], [73.31735992, 16.53013992], [73.31735992, 16.53070068], [73.31708527, 16.53069496], [73.31708527, 16.53097153], [73.31680298, 16.53096008], [73.31680298, 16.53124809], [73.31625366, 16.53124809], [73.31625366, 16.53208351], [73.31597137, 16.53208351], [73.31597137, 16.53236008], [73.31569672, 16.53235817], [73.31569672, 16.53263855], [73.3154068, 16.53263855], [73.3154068, 16.53292084], [73.31485748, 16.53291702], [73.31485748, 16.53319359], [73.31458282, 16.53319359], [73.31458282, 16.53347015], [73.31402588, 16.53346825], [73.31402588, 16.53375244], [73.31375122, 16.53375244], [73.31375122, 16.53403282], [73.31346893, 16.53403282], [73.31346893, 16.53430939], [73.31319427, 16.53430557], [73.31319427, 16.53458405], [73.31291962, 16.53458023], [73.31291962, 16.53486252], [73.31263733, 16.53486252], [73.31263733, 16.5351429], [73.3123703, 16.5351429], [73.3123703, 16.5370903], [73.31208038, 16.5370903], [73.31208038, 16.53736115], [73.31181335, 16.53736115], [73.31181335, 16.53792], [73.31153107, 16.53791618], [73.31153107, 16.53819466], [73.31124878, 16.53819466], [73.31124878, 16.53791618], [73.31014252, 16.53792], [73.31014252, 16.53903008], [73.31041718, 16.53902817], [73.31041718, 16.53958321], [73.31124878, 16.53958321], [73.31124878, 16.53930473], [73.31180573, 16.53930473], [73.31180573, 16.53902817], [73.31263733, 16.53902817], [73.31263733, 16.53930473], [73.31236267, 16.53930473], [73.31236267, 16.53958321], [73.31208038, 16.53958321], [73.31208038, 16.53986168], [73.31180573, 16.53986168], [73.31180573, 16.54013824], [73.31124878, 16.54013062], [73.31124878, 16.54042053], [73.31097412, 16.54041672], [73.31097412, 16.54097176], [73.31069183, 16.54096985], [73.31069183, 16.54153061], [73.31097412, 16.5415287], [73.31097412, 16.54208374], [73.31124878, 16.54207993], [73.31124878, 16.54236031], [73.31208038, 16.54236031], [73.31208038, 16.54207993], [73.31236267, 16.54208374], [73.31236267, 16.54180527], [73.31263733, 16.54181099], [73.31263733, 16.54153061], [73.31291962, 16.54153061], [73.31291962, 16.54125023], [73.31318665, 16.54125023], [73.31318665, 16.54153061], [73.31430817, 16.5415287], [73.31430817, 16.54208374], [73.31458282, 16.54207993], [73.31458282, 16.54264069], [73.31430817, 16.54264069], [73.31430817, 16.54486084], [73.31458282, 16.54486084], [73.31458282, 16.54513931], [73.31485748, 16.54513931], [73.31485748, 16.5454216], [73.31513977, 16.54541588], [73.31513977, 16.54569435], [73.3154068, 16.54569054], [73.3154068, 16.54626274], [73.31569672, 16.54626274], [73.31569672, 16.54653168], [73.31597137, 16.54653168], [73.31597137, 16.54681015], [73.31625366, 16.54680634], [73.31625366, 16.5470829], [73.31652832, 16.5470829], [73.31652832, 16.54735947], [73.3170929, 16.54735947], [73.3170929, 16.54764175], [73.31735992, 16.54763794], [73.31735992, 16.54819489], [73.31764221, 16.54819489], [73.31764221, 16.54847336], [73.31791687, 16.54846954], [73.31791687, 16.5490303], [73.31817627, 16.5490303], [73.31817627, 16.54932022], [73.31847382, 16.54930305], [73.31847382, 16.54958344], [73.31874847, 16.54958344], [73.31874847, 16.54986382], [73.31903076, 16.54986191], [73.31903076, 16.55042076], [73.31930542, 16.55041695], [73.31931305, 16.55236053], [73.31903076, 16.55236053], [73.31903076, 16.55264091], [73.31874847, 16.55264091], [73.31874847, 16.55291939], [73.31847382, 16.55291748], [73.31847382, 16.55347252], [73.31817627, 16.55347061], [73.31817627, 16.55402946], [73.31791687, 16.55402946], [73.31791687, 16.55486107], [73.31764221, 16.55486107], [73.31764221, 16.55624962], [73.31817627, 16.55624962], [73.31817627, 16.55652809], [73.31874847, 16.55652618], [73.31874847, 16.55680466], [73.31930542, 16.55680466], [73.31930542, 16.55652618], [73.31986237, 16.55652809], [73.31986237, 16.55597115], [73.32013702, 16.55597305], [73.32013702, 16.55569458], [73.32041931, 16.55569458], [73.32041931, 16.55486107], [73.32068634, 16.55486107], [73.32068634, 16.55430984], [73.3215332, 16.55430984], [73.3215332, 16.55375099], [73.32180786, 16.55375099], [73.32180786, 16.55319023], [73.32152557, 16.55319595], [73.32152557, 16.55263901], [73.32125092, 16.55264091], [73.32125092, 16.55181122], [73.32208252, 16.5518055], [73.32208252, 16.55208588], [73.32263947, 16.55207062], [73.32263947, 16.55236053], [73.32290649, 16.55236053], [73.32290649, 16.55264091], [73.32319641, 16.55264091], [73.32319641, 16.55291939], [73.32430267, 16.55291748], [73.32430267, 16.55347252], [73.32457733, 16.55347061], [73.32457733, 16.55402946], [73.32485962, 16.55402756], [73.32485962, 16.5545826], [73.32514191, 16.5545826], [73.32514191, 16.55513954], [73.32541656, 16.55513], [73.32541656, 16.55541992], [73.32569122, 16.55541992], [73.32569122, 16.55624962], [73.32597351, 16.55624962], [73.32597351, 16.5573616], [73.32624817, 16.5573597], [73.32624817, 16.55792046], [73.32818604, 16.55792046], [73.32818604, 16.55763817], [73.32847595, 16.55763817], [73.32847595, 16.5573597], [73.32930756, 16.5573616], [73.32930756, 16.55708313], [73.32958221, 16.55708313], [73.32958221, 16.55680466], [73.33013916, 16.55680466], [73.33013916, 16.55652618], [73.33152771, 16.55652618], [73.33152771, 16.55680466], [73.33208466, 16.55680466], [73.33208466, 16.55708313], [73.33235931, 16.55708313], [73.33235931, 16.5573616], [73.3326416, 16.5573597], [73.3326416, 16.55763817], [73.33291626, 16.55763817], [73.33291626, 16.55792046], [73.33319092, 16.55792046], [73.33319092, 16.55903053], [73.33291626, 16.55903053], [73.33291626, 16.55958366], [73.33235931, 16.55957985], [73.33235931, 16.55985832], [73.33207703, 16.55985832], [73.33207703, 16.5601387], [73.33180237, 16.5601387], [73.33180237, 16.5604229], [73.33152771, 16.56041718], [73.33152771, 16.56097031], [73.33125305, 16.56097031], [73.33125305, 16.56180954], [73.33152771, 16.56180573], [73.33152771, 16.5620842], [73.33180237, 16.56208038], [73.33180237, 16.56236267], [73.33207703, 16.56236267], [73.33207703, 16.56208038], [73.33291626, 16.56208038], [73.33291626, 16.56236267], [73.33347321, 16.56236267], [73.33347321, 16.56208038], [73.33403015, 16.5620842], [73.33403015, 16.56180573], [73.33429718, 16.56180954], [73.33429718, 16.56153107], [73.33486176, 16.56153107], [73.33486176, 16.56126022], [73.33513641, 16.56126022], [73.33513641, 16.56097031], [73.3354187, 16.56097031], [73.3354187, 16.5601387], [73.33569336, 16.5601387], [73.33569336, 16.55846977], [73.33597565, 16.55847168], [73.33597565, 16.55791664], [73.33625031, 16.55792046], [73.33625031, 16.5573597], [73.33680725, 16.5573616], [73.33680725, 16.55708313], [73.33708191, 16.55708313], [73.33708191, 16.55680466], [73.3373642, 16.55680466], [73.3373642, 16.55652618], [73.33790588, 16.55652809], [73.33790588, 16.55569077], [73.3381958, 16.55569458], [73.3381958, 16.55486107], [73.33847046, 16.55486107], [73.33847046, 16.55458069], [73.33875275, 16.5545826], [73.33875275, 16.55430794], [73.3390274, 16.55430984], [73.3390274, 16.55401039], [73.3390274, 16.55347252], [73.33930206, 16.55347252], [73.33930206, 16.55319595], [73.33958435, 16.55319595], [73.33958435, 16.55236053], [73.33985901, 16.55236053], [73.33985901, 16.55181122], [73.3401413, 16.55181122], [73.3401413, 16.55153084], [73.34041595, 16.55153084], [73.34041595, 16.5506897], [73.34069061, 16.5506916], [73.34069061, 16.5490284], [73.34041595, 16.5490303], [73.34041595, 16.54846954], [73.3401413, 16.54847336], [73.3401413, 16.54735947], [73.34041595, 16.54735947], [73.34041595, 16.5470829], [73.34069061, 16.5470829], [73.34069824, 16.54680634], [73.34124756, 16.54681015], [73.34124756, 16.54653168], [73.34152985, 16.54653168], [73.34152985, 16.54626274], [73.34179688, 16.54626274], [73.34179688, 16.54597092], [73.34236145, 16.54597282], [73.34236145, 16.54569435], [73.34263611, 16.54569435], [73.34263611, 16.54513741], [73.3429184, 16.54513931], [73.3429184, 16.54486084], [73.34319305, 16.54486084], [73.34319305, 16.54458046], [73.34375, 16.54458237], [73.34375, 16.5443058], [73.34401703, 16.54430962], [73.34401703, 16.54403114], [73.34430695, 16.54403114], [73.34430695, 16.54375076], [73.3445816, 16.54375076], [73.3445816, 16.54319], [73.34486389, 16.54319382], [73.34486389, 16.54291725], [73.34513855, 16.54292107], [73.34513855, 16.54264069], [73.34542084, 16.54264069], [73.34542084, 16.54153061], [73.34570313, 16.54153061], [73.34570313, 16.53985977], [73.34597015, 16.53986168], [73.34597015, 16.5340271], [73.34625244, 16.53403282], [73.34625244, 16.53181076], [73.3465271, 16.53181076], [73.3465271, 16.53070068], [73.34680176, 16.53070068], [73.34680176, 16.52985954], [73.34708405, 16.52986145], [73.34708405, 16.52958298], [73.3473587, 16.52958298], [73.3473587, 16.52930641], [73.34764099, 16.52931023], [73.34764099, 16.52902985], [73.34819794, 16.52902985], [73.34819794, 16.52874947], [73.34848022, 16.52874947], [73.3484726, 16.5284729], [73.34874725, 16.5284729], [73.34874725, 16.52819443], [73.34902954, 16.52819443], [73.34902954, 16.52791786], [73.34929657, 16.52791977], [73.34929657, 16.52736092], [73.34958649, 16.52736092], [73.34958649, 16.52708054], [73.34986115, 16.52708244], [73.34986115, 16.52680588], [73.3501358, 16.52680969], [73.3501358, 16.52653122], [73.35069275, 16.52653122], [73.35069275, 16.52597046], [73.35124969, 16.52597237], [73.35124969, 16.52513885], [73.35151672, 16.5251503], [73.35151672, 16.52486038], [73.35180664, 16.52486038], [73.35180664, 16.52458], [73.3520813, 16.52458572], [73.3520813, 16.52402687], [73.35235596, 16.52403069], [73.35235596, 16.52346992], [73.3529129, 16.52347374], [73.3529129, 16.52291679], [73.35346985, 16.52292061], [73.35346985, 16.52264023], [73.35375214, 16.52264023], [73.35375214, 16.52236176], [73.35430908, 16.52236176], [73.35430908, 16.52264023], [73.3548584, 16.52264023], [73.3548584, 16.52236176], [73.35652924, 16.52236366], [73.35652924, 16.52208138], [73.35679626, 16.52209282], [73.35679626, 16.5218029], [73.35736084, 16.52180481], [73.35736084, 16.52152824], [73.35764313, 16.52153015], [73.35764313, 16.52096939], [73.35819244, 16.52096939], [73.35819244, 16.52069473], [73.35874939, 16.52069473], [73.35874939, 16.52041626], [73.35930634, 16.52042007], [73.35930634, 16.5201416], [73.35958099, 16.5201416], [73.35958099, 16.51958084], [73.35986328, 16.51958275], [73.35986328, 16.51930618], [73.36042023, 16.5193119], [73.36042023, 16.51901817], [73.36096954, 16.51902771], [73.36096954, 16.51874924], [73.36152649, 16.51874924], [73.36152649, 16.51847076], [73.36208344, 16.51847267], [73.36208344, 16.5181942], [73.36235809, 16.5181942], [73.36235809, 16.51791573], [73.36264038, 16.51791763], [73.36264038, 16.51763916], [73.36292267, 16.51763916], [73.36292267, 16.51736069], [73.36319733, 16.51736069], [73.36319733, 16.51652908], [73.36347961, 16.51652908], [73.36347961, 16.51596069], [73.36402893, 16.51597214], [73.36402893, 16.51319695], [73.36374664, 16.5132103], [73.36374664, 16.51264], [73.36347961, 16.51264], [73.36347961, 16.5118103], [73.36292267, 16.5118103], [73.36292267, 16.51152992], [73.36264038, 16.51152992], [73.36264038, 16.51124954], [73.36152649, 16.51124954], [73.36152649, 16.51097107], [73.36042023, 16.51097488], [73.36042023, 16.5106945], [73.35902405, 16.5106945], [73.35902405, 16.51041603], [73.35819244, 16.51041985], [73.35819244, 16.51015091], [73.35791779, 16.51015091], [73.35791779, 16.5098629], [73.35736084, 16.5098629], [73.35736084, 16.50958061], [73.35652924, 16.50958061], [73.35652924, 16.50902748], [73.35542297, 16.50902939], [73.35542297, 16.50875282], [73.35430908, 16.50875282], [73.35430908, 16.50847054], [73.35319519, 16.50847054], [73.35319519, 16.5079174], [73.35180664, 16.50792122], [73.35180664, 16.50764275], [73.35124969, 16.50764275], [73.35124969, 16.50736237], [73.35069275, 16.50736237], [73.35069275, 16.50708008], [73.3501358, 16.50708389], [73.3501358, 16.50680542], [73.34986115, 16.50681114], [73.34986115, 16.50653076], [73.34929657, 16.50653076], [73.34929657, 16.50624847], [73.34902954, 16.50624847], [73.34902954, 16.50430107], [73.34986115, 16.50430489], [73.34986115, 16.50486183], [73.3501358, 16.50485992], [73.3501358, 16.50569916], [73.35041809, 16.50569534], [73.35041809, 16.50597191], [73.35069275, 16.50596809], [73.35069275, 16.50624847], [73.35124969, 16.50624847], [73.35124969, 16.50653076], [73.35180664, 16.50653076], [73.35180664, 16.50681114], [73.35236359, 16.50680542], [73.35236359, 16.50708389], [73.35402679, 16.50708008], [73.35402679, 16.50736237], [73.35457611, 16.50736237], [73.35457611, 16.50708008], [73.35514069, 16.50708008], [73.35514069, 16.50736237], [73.35597229, 16.50736237], [73.35597229, 16.50764275], [73.35708618, 16.50764275], [73.35708618, 16.50792122], [73.35736084, 16.5079174], [73.35736084, 16.50819206], [73.35791779, 16.50819206], [73.35791779, 16.50847054], [73.35874939, 16.50847054], [73.35874939, 16.50902939], [73.35958099, 16.50902939], [73.35958099, 16.50930977], [73.36013794, 16.50930595], [73.36013794, 16.50958061], [73.360466, 16.50958061], [73.36068726, 16.50958061], [73.36068726, 16.5098629], [73.36207581, 16.5098629], [73.36207581, 16.51015091], [73.36429596, 16.51015091], [73.36429596, 16.51041985], [73.36513519, 16.51041603], [73.36513519, 16.5106945], [73.36541748, 16.5106945], [73.36541748, 16.51097488], [73.36569214, 16.51097107], [73.36569214, 16.51124954], [73.36597443, 16.51124954], [73.36597443, 16.51217079], [73.36597443, 16.51236153], [73.36651611, 16.51235962], [73.36651611, 16.51292038], [73.36680603, 16.51292038], [73.36680603, 16.5132103], [73.36736298, 16.5132103], [73.36736298, 16.51292038], [73.36791992, 16.51292038], [73.36791992, 16.51264], [73.36846924, 16.51264], [73.36846924, 16.51208115], [73.36875153, 16.51208305], [73.36875153, 16.51176071], [73.36875153, 16.51152802], [73.36902618, 16.51152992], [73.36902618, 16.51097107], [73.37014008, 16.51097107], [73.37014008, 16.51124954], [73.37291718, 16.51124954], [73.37291718, 16.51152992], [73.37374878, 16.51152802], [73.37374878, 16.51180458], [73.37430573, 16.51180458], [73.37430573, 16.51152802], [73.37541962, 16.51152992], [73.37541962, 16.51124954], [73.37568665, 16.51124954], [73.37568665, 16.51152992], [73.37652588, 16.51152802], [73.37652588, 16.51180077], [73.37875366, 16.51180649], [73.37875366, 16.51208305], [73.37930298, 16.51208305], [73.37930298, 16.51180649], [73.37985992, 16.51180649], [73.37985992, 16.51208305], [73.38153076, 16.51208305], [73.38153076, 16.51236153], [73.38180542, 16.51236153], [73.38180542, 16.51208305], [73.38208008, 16.51208305], [73.38208008, 16.51180649], [73.38318634, 16.51180077], [73.38319397, 16.51152802], [73.38346863, 16.51152992], [73.38346863, 16.51124954], [73.38375092, 16.51124954], [73.38375092, 16.51097107], [73.38430786, 16.51097488], [73.38430786, 16.5106945], [73.38458252, 16.5106945], [73.38458252, 16.51041603], [73.38513947, 16.51041985], [73.38513947, 16.51015091], [73.38597107, 16.51015091], [73.38597107, 16.5098629], [73.38680267, 16.5098629], [73.38680267, 16.51015091], [73.38819122, 16.51015091], [73.38819122, 16.5098629], [73.39013672, 16.5098629], [73.39013672, 16.51399231], [73.39013672, 16.51431084], [73.38931274, 16.51431084], [73.38931274, 16.51403046], [73.38903046, 16.51403046], [73.38903046, 16.5134697], [73.38874817, 16.5134716], [73.38874817, 16.51319695], [73.38764191, 16.51319695], [73.38764191, 16.5134716], [73.38680267, 16.5134697], [73.38680267, 16.51375008], [73.38540649, 16.51375008], [73.38540649, 16.51403046], [73.38485718, 16.51403046], [73.38485718, 16.51431084], [73.38430786, 16.51430511], [73.38430023, 16.515131], [73.38402557, 16.51513863], [73.3840332, 16.51529121], [73.3840332, 16.51542091], [73.38375092, 16.51541519], [73.38375092, 16.51569366], [73.38346863, 16.51569366], [73.38346863, 16.51597214], [73.38318634, 16.51596069], [73.38318634, 16.51625061], [73.38291931, 16.51625061], [73.38291931, 16.51680946], [73.38208008, 16.51680565], [73.38208008, 16.51708412], [73.38091278, 16.51708412], [73.38041687, 16.51708412], [73.38041687, 16.51680565], [73.37985992, 16.51680946], [73.37985992, 16.51652908], [73.37874603, 16.51652908], [73.37874603, 16.51680946], [73.37845612, 16.51680946], [73.37845612, 16.51652908], [73.37680817, 16.51652908], [73.37680817, 16.51680946], [73.37652588, 16.51680565], [73.37652588, 16.51708412], [73.37568665, 16.51708031], [73.37568665, 16.51736069], [73.37541962, 16.51736069], [73.37541962, 16.51763916], [73.37513733, 16.51763916], [73.37513733, 16.51791763], [73.37486267, 16.51791763], [73.37486267, 16.5181942], [73.37458038, 16.5181942], [73.37458038, 16.51847267], [73.37431335, 16.51847076], [73.37431335, 16.51874924], [73.37374878, 16.51874924], [73.37374878, 16.51902771], [73.37319183, 16.51901817], [73.37319183, 16.5193119], [73.37264252, 16.51930618], [73.37264252, 16.51958275], [73.37236023, 16.51958084], [73.37236023, 16.51985931], [73.37152863, 16.51985931], [73.37152863, 16.5201416], [73.37069702, 16.5201416], [73.37069702, 16.52042007], [73.37041473, 16.52041626], [73.37041473, 16.52069473], [73.36985779, 16.52069473], [73.36985779, 16.52096939], [73.36958313, 16.52096939], [73.36958313, 16.52153015], [73.36902618, 16.52152824], [73.36902618, 16.52180481], [73.36818695, 16.5218029], [73.36818695, 16.52209282], [73.36763763, 16.52208138], [73.36763763, 16.52236366], [73.36708069, 16.52236176], [73.36708069, 16.52264023], [73.36651611, 16.52264023], [73.36651611, 16.52292061], [73.36624908, 16.52292061], [73.36624908, 16.5232029], [73.36541748, 16.52319527], [73.36541748, 16.52347374], [73.36486053, 16.52346992], [73.36486053, 16.52375031], [73.36374664, 16.52375031], [73.36374664, 16.52403069], [73.36347961, 16.52403069], [73.36347961, 16.52431107], [73.36291504, 16.52430534], [73.36291504, 16.52458572], [73.36264038, 16.52458], [73.36264038, 16.5251503], [73.36180878, 16.5251503], [73.36180878, 16.52542114], [73.36125183, 16.52541733], [73.36125183, 16.5256958], [73.36061859, 16.5256958], [73.35958099, 16.5256958], [73.35958099, 16.52597237], [73.35901642, 16.52597046], [73.35901642, 16.52625084], [73.35791779, 16.52625084], [73.35791779, 16.52680969], [73.3576355, 16.52680588], [73.35764313, 16.52736092], [73.35736084, 16.52736092], [73.35736084, 16.52874947], [73.35597229, 16.52874947], [73.35597229, 16.52902985], [73.35569763, 16.52902794], [73.35569763, 16.52958298], [73.35542297, 16.52958107], [73.35542297, 16.53013992], [73.35514069, 16.53013611], [73.35514069, 16.53097153], [73.3548584, 16.53097153], [73.3548584, 16.53208351], [73.35514069, 16.5320797], [73.35514069, 16.53263855], [73.35542297, 16.53263855], [73.35542297, 16.53292084], [73.35569763, 16.53291702], [73.35569763, 16.53347015], [73.35542297, 16.53346825], [73.35542297, 16.53403282], [73.35514069, 16.53403282], [73.35514069, 16.53486252], [73.3548584, 16.53486252], [73.3548584, 16.53541946], [73.35458374, 16.53541756], [73.35458374, 16.5359726], [73.35430908, 16.5359726], [73.35430908, 16.53763962], [73.35402679, 16.53763962], [73.35402679, 16.53903008], [73.35430908, 16.53902817], [73.35430908, 16.53930473], [73.3548584, 16.53930473], [73.3548584, 16.53958321], [73.35541534, 16.53958321], [73.35541534, 16.5397625], [73.35541534, 16.53986168], [73.35708618, 16.53986168], [73.35708618, 16.53958321], [73.35791779, 16.53958321], [73.35791779, 16.53930473], [73.35819244, 16.53930473], [73.35819244, 16.53902817], [73.3584671, 16.53903008], [73.3584671, 16.53874969], [73.35930634, 16.53874969], [73.35930634, 16.53903008], [73.35958099, 16.53902817], [73.35958099, 16.53930473], [73.35986328, 16.53930473], [73.35986328, 16.53958321], [73.36042023, 16.53958321], [73.36042023, 16.53986168], [73.36152649, 16.53986168], [73.36152649, 16.53958321], [73.36208344, 16.53958321], [73.36208344, 16.53986168], [73.36235809, 16.53986168], [73.36235809, 16.53958321], [73.36624908, 16.53958321], [73.36624908, 16.54097176], [73.3659668, 16.54096985], [73.3659668, 16.54125023], [73.36569214, 16.54125023], [73.36569214, 16.54153061], [73.36624908, 16.54153061], [73.36624908, 16.54181099], [73.36653137, 16.54180527], [73.36653137, 16.54208374], [73.36680603, 16.54207993], [73.36680603, 16.54236031], [73.36736298, 16.54236031], [73.36736298, 16.54264069], [73.36846924, 16.54264069], [73.36846924, 16.54236031], [73.36875153, 16.54236031], [73.36875153, 16.54207993], [73.36902618, 16.54208374], [73.36902618, 16.54180527], [73.36930847, 16.54181099], [73.36930847, 16.54153061], [73.36958313, 16.54153061], [73.36958313, 16.54125023], [73.36985779, 16.54125023], [73.36985779, 16.54096985], [73.37041473, 16.54097176], [73.37041473, 16.54069519], [73.37069702, 16.54070091], [73.37069702, 16.54042053], [73.37097168, 16.54042053], [73.37097168, 16.53985977], [73.37124634, 16.53986168], [73.37124634, 16.53958321], [73.37152863, 16.53958321], [73.37152863, 16.53930473], [73.37208557, 16.53930473], [73.37208557, 16.53902817], [73.37236023, 16.53903008], [73.37236023, 16.53874969], [73.37264252, 16.53874969], [73.37264252, 16.53930473], [73.37291718, 16.53930473], [73.37291718, 16.53986168], [73.37265015, 16.53985977], [73.37265015, 16.54042053], [73.37180328, 16.54042053], [73.37180328, 16.54070091], [73.37124634, 16.54069519], [73.37124634, 16.54097176], [73.37097168, 16.54096985], [73.37097168, 16.54125023], [73.37069702, 16.54125023], [73.37069702, 16.54181099], [73.37041473, 16.54180527], [73.37041473, 16.54208374], [73.36985779, 16.54207993], [73.36985779, 16.54236031], [73.36958313, 16.54236031], [73.36958313, 16.54264069], [73.36930847, 16.54264069], [73.36930847, 16.54292107], [73.36902618, 16.54291725], [73.36902618, 16.54319382], [73.36875153, 16.54319382], [73.36875153, 16.54347229], [73.36846924, 16.54347038], [73.36846924, 16.54375076], [73.36818695, 16.54375076], [73.36818695, 16.54403114], [73.36791992, 16.54402733], [73.36791992, 16.54475021], [73.36791992, 16.54486084], [73.36708069, 16.54486084], [73.36708069, 16.54472923], [73.36708069, 16.54458427], [73.36680603, 16.54458427], [73.36680603, 16.54402733], [73.36651611, 16.54403114], [73.36651611, 16.54375076], [73.3659668, 16.54375076], [73.3659668, 16.54347038], [73.36541748, 16.54347229], [73.36541748, 16.54319382], [73.36513519, 16.54319382], [73.36513519, 16.54291725], [73.36486053, 16.54292107], [73.36486053, 16.54264069], [73.36429596, 16.54264069], [73.36429596, 16.54236031], [73.36367035, 16.54236031], [73.36319733, 16.54236031], [73.36319733, 16.54207993], [73.36291504, 16.54208374], [73.36292267, 16.54236031], [73.36235809, 16.54236031], [73.36235809, 16.54264069], [73.36152649, 16.54264069], [73.36152649, 16.54236031], [73.36068726, 16.54236031], [73.36068726, 16.54264069], [73.35958099, 16.54264069], [73.35958099, 16.54125023], [73.35930634, 16.54125023], [73.35930634, 16.54096985], [73.35902405, 16.54097176], [73.35902405, 16.54069519], [73.35847473, 16.54069519], [73.35847473, 16.54097176], [73.3576355, 16.54097176], [73.35764313, 16.54125023], [73.35708618, 16.54125023], [73.35708618, 16.54153061], [73.35652924, 16.54153061], [73.35652924, 16.54181099], [73.35514069, 16.54181099], [73.35514069, 16.54153061], [73.3548584, 16.54153061], [73.3548584, 16.54181099], [73.35473633, 16.54180527], [73.35458374, 16.54180527], [73.35458374, 16.54208374], [73.35402679, 16.54207993], [73.35402679, 16.54236031], [73.35375214, 16.54236031], [73.35375214, 16.54347229], [73.35346985, 16.54347038], [73.35346985, 16.54375076], [73.35263824, 16.54375076], [73.35263824, 16.54347038], [73.3520813, 16.54347229], [73.3520813, 16.54319382], [73.35180664, 16.54319382], [73.35180664, 16.54347229], [73.35069275, 16.54347038], [73.35069275, 16.54375076], [73.35041809, 16.54375076], [73.35041809, 16.54458427], [73.3501358, 16.54458046], [73.3501358, 16.54513931], [73.34986115, 16.54513931], [73.34986115, 16.5454216], [73.34958649, 16.54541588], [73.34958649, 16.54597282], [73.34929657, 16.54597092], [73.34929657, 16.54626274], [73.34902954, 16.54626274], [73.34902954, 16.54653168], [73.34874725, 16.54653168], [73.34874725, 16.54681015], [73.34902954, 16.54680634], [73.34902954, 16.5470829], [73.34874725, 16.54707909], [73.34874725, 16.54764175], [73.34929657, 16.54764175], [73.34929657, 16.54792023], [73.34958649, 16.54791641], [73.34958649, 16.54819489], [73.34929657, 16.54818916], [73.34929657, 16.54932022], [73.34958649, 16.54930305], [73.34958649, 16.54958344], [73.34986115, 16.54958344], [73.34986115, 16.54986382], [73.35090637, 16.54986382], [73.3520813, 16.54986191], [73.3520813, 16.55014038], [73.35235596, 16.55014038], [73.35235596, 16.55042076], [73.3520813, 16.55041695], [73.3520813, 16.5506897], [73.35180664, 16.55069542], [73.35180664, 16.55097389], [73.35124969, 16.55097389], [73.35124969, 16.55069542], [73.35069275, 16.55069542], [73.35069275, 16.55097389], [73.35041809, 16.55097008], [73.35041809, 16.55125046], [73.35024261, 16.55125046], [73.34958649, 16.55125046], [73.34958649, 16.55153084], [73.34902954, 16.55153084], [73.34902954, 16.55125046], [73.34819794, 16.55125046], [73.34819794, 16.55153084], [73.3473587, 16.55153084], [73.3473587, 16.55181122], [73.34707642, 16.55181122], [73.34707642, 16.55236053], [73.34680939, 16.55236053], [73.34680176, 16.55264091], [73.3465271, 16.55263901], [73.3465271, 16.55319595], [73.34625244, 16.55319023], [73.34625244, 16.55375099], [73.34597015, 16.55374908], [73.34597015, 16.55569458], [73.3456955, 16.55569458], [73.3456955, 16.55582047], [73.34570313, 16.55652809], [73.34597015, 16.55652618], [73.34597015, 16.55680466], [73.34625244, 16.55680466], [73.34625244, 16.55708313], [73.3501358, 16.55708313], [73.3501358, 16.5573616], [73.35152435, 16.5573616], [73.35152435, 16.55708313], [73.3520813, 16.55708313], [73.3520813, 16.55680466], [73.35236359, 16.55680466], [73.35236359, 16.55652618], [73.35263824, 16.55652809], [73.35263824, 16.55624962], [73.3529129, 16.55624962], [73.3529129, 16.55597115], [73.35319519, 16.55597305], [73.35319519, 16.55541611], [73.35346985, 16.55541992], [73.35346985, 16.55513], [73.35402679, 16.55513954], [73.35402679, 16.55486107], [73.35430908, 16.55486107], [73.35430908, 16.55458069], [73.35458374, 16.5545826], [73.35458374, 16.55430794], [73.35514069, 16.55430984], [73.35514069, 16.55402946], [73.35597229, 16.55402946], [73.35597229, 16.55375099], [73.35624695, 16.55375099], [73.35624695, 16.55319023], [73.35652924, 16.55319595], [73.35652924, 16.55291748], [73.35679626, 16.55291939], [73.35679626, 16.55264091], [73.35736084, 16.55264091], [73.35736084, 16.55291939], [73.35791779, 16.55291748], [73.35791779, 16.55319595], [73.35819244, 16.55319595], [73.35819244, 16.55291748], [73.35874939, 16.55291939], [73.35874939, 16.55264091], [73.35901642, 16.55264091], [73.35901642, 16.55236053], [73.35930634, 16.55236053], [73.35930634, 16.55207062], [73.35958099, 16.55208588], [73.35958099, 16.5518055], [73.35986328, 16.55181122], [73.35986328, 16.55153084], [73.36013794, 16.55153084], [73.36013794, 16.55125046], [73.36235809, 16.55125046], [73.36235809, 16.55153084], [73.3659668, 16.55153084], [73.3659668, 16.55125046], [73.36624908, 16.55125046], [73.36624908, 16.55153084], [73.36680603, 16.55153084], [73.36680603, 16.55125046], [73.36846924, 16.55125046], [73.36846924, 16.55097008], [73.37041473, 16.55097389], [73.37041473, 16.5506916], [73.37291718, 16.5506916], [73.37291718, 16.55041695], [73.37346649, 16.55042076], [73.37346649, 16.55014038], [73.37458038, 16.55014038], [73.37458038, 16.55042076], [73.37680817, 16.55041695], [73.37680817, 16.5506916], [73.37708282, 16.5506916], [73.37708282, 16.55097389], [73.37735748, 16.55097008], [73.37735748, 16.55125046], [73.37763977, 16.55125046], [73.37763977, 16.55208588], [73.37735748, 16.55208588], [73.37735748, 16.55319595], [73.37763977, 16.55319595], [73.37763977, 16.55347252], [73.37819672, 16.55347061], [73.37819672, 16.55375099], [73.37874603, 16.55375099], [73.37874603, 16.55402946], [73.38208008, 16.55402946], [73.38208008, 16.55430984], [73.38263702, 16.55430794], [73.38263702, 16.5545826], [73.38430786, 16.5545826], [73.38430786, 16.55430794], [73.38764954, 16.55430984], [73.38764954, 16.55402946], [73.38799286, 16.55402756], [73.38819122, 16.55402946], [73.38819122, 16.55375099], [73.38874817, 16.55375099], [73.38874817, 16.55347061], [73.38957977, 16.55347252], [73.38957977, 16.55319595], [73.39263916, 16.55319595], [73.39263916, 16.55291748], [73.39319611, 16.55291939], [73.39319611, 16.55264091], [73.39402771, 16.55264091], [73.39402771, 16.55375099], [73.39375305, 16.55375099], [73.39375305, 16.55430984], [73.39291382, 16.55430794], [73.39291382, 16.5544796], [73.39291382, 16.5545826], [73.39152527, 16.5545826], [73.3915329, 16.55486107], [73.39013672, 16.55486107], [73.39013672, 16.55458069], [73.38986206, 16.55458069], [73.38986206, 16.55486107], [73.38903046, 16.55486107], [73.38903046, 16.55513954], [73.38735962, 16.55513], [73.38735962, 16.55541992], [73.38597107, 16.55541611], [73.38597107, 16.55569458], [73.38541412, 16.55569458], [73.38541412, 16.55597305], [73.38430786, 16.55597305], [73.38430786, 16.55569458], [73.38402557, 16.55569458], [73.38402557, 16.55597305], [73.38318634, 16.55597115], [73.38318634, 16.55624962], [73.38236237, 16.55624962], [73.38236237, 16.55597115], [73.38208008, 16.55597305], [73.38208008, 16.55569458], [73.38097382, 16.55569458], [73.38097382, 16.55541611], [73.38069153, 16.55541611], [73.38069153, 16.55569458], [73.38041687, 16.55569458], [73.38041687, 16.55597305], [73.38069153, 16.55597115], [73.38069153, 16.55652809], [73.38097382, 16.55652618], [73.38097382, 16.55680466], [73.38124847, 16.55680466], [73.38124847, 16.55708313], [73.38153076, 16.55708313], [73.38153076, 16.5573616], [73.38124847, 16.5573597], [73.38124847, 16.55763817], [73.38069153, 16.55763817], [73.38069153, 16.5573597], [73.38014221, 16.5573616], [73.38014221, 16.55708313], [73.37985992, 16.55708313], [73.37985992, 16.55652618], [73.37902832, 16.55652809], [73.37902832, 16.55624962], [73.37845612, 16.55624962], [73.37845612, 16.55597115], [73.37819672, 16.55597305], [73.37819672, 16.55569458], [73.37791443, 16.55569458], [73.37791443, 16.55541611], [73.37763977, 16.55541992], [73.37763977, 16.55486107], [73.37735748, 16.55486107], [73.37735748, 16.55430984], [73.37708282, 16.55430984], [73.37708282, 16.55402946], [73.37680817, 16.55402946], [73.37680817, 16.55375099], [73.37652588, 16.55375099], [73.37652588, 16.55347061], [73.37625122, 16.55347252], [73.37625122, 16.55319595], [73.37596893, 16.55319595], [73.37596893, 16.55291748], [73.37568665, 16.55291939], [73.37568665, 16.55264091], [73.37513733, 16.55264091], [73.37513733, 16.55236053], [73.37486267, 16.55236053], [73.37486267, 16.55207062], [73.37374878, 16.55207062], [73.37374878, 16.55236053], [73.37346649, 16.55236053], [73.37346649, 16.55264091], [73.37265015, 16.55264091], [73.37265015, 16.55236053], [73.37208557, 16.55236053], [73.37208557, 16.55208588], [73.37152863, 16.55207062], [73.37152863, 16.55236053], [73.37097168, 16.55236053], [73.37097168, 16.55291939], [73.36902618, 16.55291748], [73.36902618, 16.55319595], [73.36819458, 16.55319595], [73.36819458, 16.55347252], [73.36708069, 16.55347061], [73.36708069, 16.55375099], [73.36651611, 16.55375099], [73.36651611, 16.55402946], [73.3663559, 16.55402946], [73.36624908, 16.55402946], [73.36624908, 16.55430984], [73.36541748, 16.55430984], [73.36541748, 16.55402946], [73.36514282, 16.55402946], [73.36514282, 16.55375099], [73.36429596, 16.55375099], [73.36429596, 16.55347061], [73.36374664, 16.55347061], [73.36374664, 16.55375099], [73.36264038, 16.55375099], [73.36264038, 16.55402946], [73.36235809, 16.55402756], [73.36235809, 16.5545826], [73.36152649, 16.5545826], [73.36152649, 16.55430794], [73.36069489, 16.55430794], [73.36069489, 16.5545826], [73.36042023, 16.55458069], [73.36042023, 16.55486107], [73.36013794, 16.55486107], [73.36013794, 16.55513954], [73.35930634, 16.55513], [73.35930634, 16.55541992], [73.35847473, 16.55541611], [73.35847473, 16.55569458], [73.35819244, 16.55569458], [73.35819244, 16.55597305], [73.35791779, 16.55597115], [73.35791779, 16.55624962], [73.3576355, 16.55624962], [73.3576355, 16.55597305], [73.35708618, 16.55597305], [73.35708618, 16.55569458], [73.35680389, 16.55569458], [73.35680389, 16.55541611], [73.35624695, 16.55541611], [73.35624695, 16.55569458], [73.35597229, 16.55569458], [73.35597229, 16.55597305], [73.35569763, 16.55597115], [73.35569763, 16.55652809], [73.35541534, 16.55652618], [73.35541534, 16.5573616], [73.35569763, 16.5573597], [73.35569763, 16.55763817], [73.35597229, 16.55763817], [73.35597229, 16.55820084], [73.35624695, 16.55820084], [73.35624695, 16.55874825], [73.35652924, 16.55874825], [73.35652924, 16.56069374], [73.35624695, 16.56069374], [73.35624695, 16.56097031], [73.35652924, 16.56097031], [73.35652924, 16.56153107], [73.35679626, 16.56153107], [73.35679626, 16.56264114], [73.35652924, 16.56264114], [73.35652924, 16.56291962], [73.35624695, 16.5629158], [73.35624695, 16.56319427], [73.35597229, 16.56319046], [73.35597229, 16.56402969], [73.35569763, 16.56402969], [73.35569763, 16.56431961], [73.35541534, 16.56430626], [73.35541534, 16.56458473], [73.35514069, 16.56458282], [73.35514069, 16.56513977], [73.3548584, 16.56513977], [73.3548584, 16.56597137], [73.35514069, 16.56596947], [73.35514069, 16.56624985], [73.35679626, 16.56624985], [73.35679626, 16.56653023], [73.35708618, 16.56653023], [73.35708618, 16.56624985], [73.35733795, 16.56624985], [73.35736084, 16.56653023], [73.3584671, 16.56653023], [73.3584671, 16.56624985], [73.35874939, 16.56624985], [73.35874939, 16.56596947], [73.35986328, 16.56596947], [73.35986328, 16.56624985], [73.36042023, 16.56624985], [73.36042023, 16.56653023], [73.36096954, 16.56653023], [73.36096954, 16.56624985], [73.36208344, 16.56624985], [73.36208344, 16.56680679], [73.36235809, 16.56680679], [73.36235809, 16.56847191], [73.36180878, 16.56847191], [73.36180878, 16.56819534], [73.36152649, 16.56820107], [73.36152649, 16.56792068], [73.36125183, 16.56792068], [73.36125183, 16.5676403], [73.36042023, 16.5676403], [73.36042023, 16.56735992], [73.35986328, 16.56735992], [73.35986328, 16.5676403], [73.35901642, 16.5676403], [73.35901642, 16.56820107], [73.35874939, 16.56819534], [73.35874939, 16.56847191], [73.3575058, 16.56847191], [73.35736084, 16.56847191], [73.35736084, 16.56791687], [73.35652924, 16.56792068], [73.35652924, 16.5676403], [73.35514069, 16.5676403], [73.35514069, 16.56735992], [73.3548584, 16.56736183], [73.3548584, 16.56708336], [73.35458374, 16.56708336], [73.35458374, 16.56680679], [73.35430908, 16.56680679], [73.35430908, 16.56597137], [73.35402679, 16.56597137], [73.35402679, 16.56569481], [73.35375214, 16.56569481], [73.35375214, 16.56513977], [73.35346985, 16.56513977], [73.35346985, 16.56458282], [73.3529129, 16.56458473], [73.3529129, 16.56430626], [73.3520813, 16.56430626], [73.3520813, 16.5648613], [73.35151672, 16.56485939], [73.35151672, 16.56513977], [73.34874725, 16.56513977], [73.34874725, 16.56485939], [73.34791565, 16.5648613], [73.34791565, 16.56458473], [73.34680939, 16.56458473], [73.34680176, 16.5648613], [73.3465271, 16.56485939], [73.3465271, 16.56513977], [73.34542084, 16.56513977], [73.34542084, 16.56542015], [73.3445816, 16.56541634], [73.3445816, 16.56569481], [73.34375, 16.56569481], [73.34375, 16.56597137], [73.34319305, 16.56596947], [73.34319305, 16.56624985], [73.34263611, 16.56624985], [73.34263611, 16.56680679], [73.34236145, 16.56680679], [73.34236145, 16.56708336], [73.34208679, 16.56707001], [73.34208679, 16.56792068], [73.34236145, 16.56791687], [73.34236145, 16.56847191], [73.34263611, 16.56847], [73.34263611, 16.56903076], [73.3429184, 16.56903076], [73.3429184, 16.56931114], [73.34319305, 16.56931114], [73.34319305, 16.56986046], [73.34348297, 16.56986046], [73.34348297, 16.57042122], [73.34375, 16.5704174], [73.34375, 16.57069397], [73.34430695, 16.57069016], [73.34430695, 16.57125092], [73.3445816, 16.57125092], [73.3445816, 16.57152748], [73.34486389, 16.57152748], [73.34486389, 16.57208252], [73.34513855, 16.57208061], [73.34513855, 16.57374954], [73.34485626, 16.57374954], [73.34485626, 16.57403183], [73.3445816, 16.57403183], [73.3445816, 16.5743103], [73.34430695, 16.57430649], [73.34430695, 16.57458115], [73.34401703, 16.57457924], [73.34401703, 16.57542038], [73.3445816, 16.57542038], [73.3445816, 16.57570076], [73.34485626, 16.57570076], [73.34485626, 16.57625961], [73.3445816, 16.57625961], [73.3445816, 16.57653046], [73.34430695, 16.57653046], [73.34430695, 16.57681084], [73.34402466, 16.57680511], [73.34402466, 16.57708359], [73.34375, 16.57708359], [73.34375, 16.57736206], [73.34348297, 16.57736015], [73.34348297, 16.57764053], [73.34319305, 16.57764053], [73.34319305, 16.57792091], [73.3429184, 16.5779171], [73.3429184, 16.57847214], [73.34263611, 16.57847023], [73.34263611, 16.57875061], [73.34234619, 16.57875061], [73.34234619, 16.57903099], [73.34208679, 16.57902718], [73.34208679, 16.57930565], [73.3418045, 16.57930565], [73.3418045, 16.57958412], [73.34124756, 16.57958031], [73.34124756, 16.57986069], [73.3409729, 16.57986069], [73.3409729, 16.58014107], [73.34041595, 16.58014107], [73.34041595, 16.58041954], [73.33985901, 16.58041954], [73.33985901, 16.58014107], [73.3390274, 16.58014107], [73.3390274, 16.57986069], [73.33833313, 16.57986069], [73.33680725, 16.57986069], [73.33680725, 16.57958031], [73.33625031, 16.57958412], [73.33625031, 16.57902718], [73.33598328, 16.57903099], [73.33598328, 16.57875061], [73.3354187, 16.57875061], [73.3354187, 16.57847023], [73.33513641, 16.57847214], [73.33513641, 16.57763863], [73.33486176, 16.57764053], [73.33486176, 16.57707977], [73.3345871, 16.57708359], [73.3345871, 16.57680511], [73.3326416, 16.57680511], [73.3326416, 16.57708359], [73.33097076, 16.57708359], [73.33097076, 16.57736206], [73.33040619, 16.57736015], [73.33040619, 16.57764053], [73.33013916, 16.57764053], [73.33013916, 16.57792091], [73.3298645, 16.5779171], [73.3298645, 16.57847214], [73.32958221, 16.57847023], [73.32958221, 16.57875061], [73.32930756, 16.57875061], [73.32930756, 16.57903099], [73.32875061, 16.57902718], [73.32875061, 16.57930565], [73.32791901, 16.57930565], [73.32791901, 16.57958412], [73.32763672, 16.57958031], [73.32763672, 16.57986069], [73.3273468, 16.57986069], [73.3273468, 16.58041954], [73.32707977, 16.58041763], [73.32707977, 16.5806942], [73.32680511, 16.5806942], [73.32680511, 16.58097267], [73.32624817, 16.58097076], [73.32624817, 16.58125114], [73.32541656, 16.58125114], [73.32541656, 16.58152962], [73.32457733, 16.58152962], [73.32457733, 16.58180809], [73.32402802, 16.58180618], [73.32402802, 16.58208275], [73.32375336, 16.58208084], [73.32375336, 16.58236122], [73.32347107, 16.58236122], [73.32347107, 16.58263969], [73.32319641, 16.58263969], [73.32319641, 16.58291817], [73.32291412, 16.58291626], [73.32291412, 16.58319473], [73.32263947, 16.58319092], [73.32263947, 16.58374977], [73.32236481, 16.58374977], [73.32236481, 16.58430481], [73.32208252, 16.58430481], [73.32208252, 16.58458328], [73.32235718, 16.58457947], [73.32235718, 16.58569908], [73.32263947, 16.58569908], [73.32263947, 16.5862484], [73.32290649, 16.5862484], [73.32290649, 16.58792114], [73.32263947, 16.58791733], [73.32263947, 16.58847046], [73.32290649, 16.58847046], [73.32290649, 16.58930969], [73.32263947, 16.58930969], [73.32263947, 16.58986282], [73.32236481, 16.58986282], [73.32236481, 16.59069443], [73.32208252, 16.59069443], [73.32208252, 16.59097481], [73.32180786, 16.59097481], [73.32180786, 16.59124947], [73.3215332, 16.59124184], [73.3215332, 16.59152985], [73.32068634, 16.59152985], [73.32068634, 16.59181023], [73.32013702, 16.59180641], [73.32013702, 16.59208488], [73.31986237, 16.59208488], [73.31986237, 16.59236145], [73.31958008, 16.59235954], [73.31958008, 16.59263992], [73.31931305, 16.59263992], [73.31931305, 16.59320068], [73.31903076, 16.59319687], [73.31903076, 16.59458351], [73.31874847, 16.5945797], [73.31874847, 16.59514046], [73.31846619, 16.59514046], [73.31846619, 16.59653091], [73.31874847, 16.5965271], [73.31874847, 16.59708405], [73.31903076, 16.59708023], [73.31903076, 16.59736824], [73.31958008, 16.59736824], [73.31958008, 16.59763908], [73.31986237, 16.59763908], [73.31986237, 16.59791756], [73.31958008, 16.59791756], [73.31958008, 16.59874916], [73.31931305, 16.59874916], [73.31931305, 16.59903145], [73.31903076, 16.59903145], [73.31903076, 16.59931183], [73.31874847, 16.59930611], [73.31874847, 16.59958267], [73.31846619, 16.59958076], [73.31846619, 16.59985924], [73.31791687, 16.59985924], [73.31791687, 16.60014153], [73.31735992, 16.60014153], [73.31735992, 16.60042953], [73.31708527, 16.60041618], [73.31708527, 16.60097122], [73.31680298, 16.60096931], [73.31680298, 16.60153008], [73.31708527, 16.60152817], [73.31708527, 16.6020813], [73.31735992, 16.6020813], [73.31735992, 16.60236359], [73.31764221, 16.60235977], [73.31764221, 16.60264015], [73.31791687, 16.60264015], [73.31791687, 16.60292053], [73.31846619, 16.60292053], [73.31846619, 16.60320091], [73.31903076, 16.60319519], [73.31903076, 16.60347366], [73.31931305, 16.60346985], [73.31931305, 16.60514069], [73.31958008, 16.60514069], [73.31958008, 16.60542107], [73.31986237, 16.60541725], [73.31986237, 16.60569572], [73.32013702, 16.60569572], [73.32013702, 16.60708237], [73.32041931, 16.60708046], [73.32041931, 16.60736084], [73.32180786, 16.60736084], [73.32180786, 16.60708046], [73.32236481, 16.60708237], [73.32236481, 16.6068058], [73.32290649, 16.60680962], [73.32290649, 16.60653114], [73.32347107, 16.60653114], [73.32347107, 16.60624123], [73.32375336, 16.60625076], [73.32375336, 16.60597229], [73.32402802, 16.60597229], [73.32402802, 16.60569572], [73.32485962, 16.60569572], [73.32485962, 16.60597229], [73.32514191, 16.60597229], [73.32514191, 16.60625076], [73.32541656, 16.60624123], [73.32541656, 16.60680962], [73.32569122, 16.6068058], [73.32569122, 16.60708237], [73.32596588, 16.60708046], [73.32596588, 16.60736084], [73.32624817, 16.60736084], [73.32624817, 16.60764122], [73.32818604, 16.60764122], [73.32818604, 16.60791969], [73.32902527, 16.60791779], [73.32902527, 16.60819435], [73.33041382, 16.60819435], [73.33041382, 16.60847282], [73.33069611, 16.60847282], [73.33069611, 16.60819435], [73.33180237, 16.60819435], [73.33180237, 16.60791779], [73.33291626, 16.60791969], [73.33291626, 16.60764122], [73.33347321, 16.60764122], [73.33347321, 16.60736084], [73.33403015, 16.60736084], [73.33403015, 16.60708046], [73.3345871, 16.60708237], [73.3345871, 16.6068058], [73.33486176, 16.60680962], [73.33486176, 16.60653114], [73.33513641, 16.60653114], [73.33513641, 16.60624123], [73.3354187, 16.60625076], [73.3354187, 16.60569572], [73.33597565, 16.60569572], [73.33597565, 16.60541725], [73.33652496, 16.60541725], [73.33652496, 16.60569572], [73.33791351, 16.60569572], [73.33791351, 16.60541725], [73.33847046, 16.60542107], [73.33847046, 16.60514069], [73.33875275, 16.60514069], [73.33875275, 16.60486031], [73.3392868, 16.60486031], [73.3392868, 16.60457993], [73.33958435, 16.60458374], [73.33958435, 16.60430527], [73.33985901, 16.60431099], [73.33985901, 16.60403061], [73.3401413, 16.60403061], [73.3401413, 16.60375023], [73.34041595, 16.60375023], [73.34041595, 16.60235977], [73.3401413, 16.60236359], [73.3401413, 16.60152817], [73.3409729, 16.60153008], [73.3409729, 16.6012516], [73.34124756, 16.6012516], [73.34124756, 16.60096931], [73.34152985, 16.60097122], [73.34152985, 16.60069466], [73.3418045, 16.60069466], [73.3418045, 16.60041618], [73.3429184, 16.60042953], [73.3429184, 16.60014153], [73.34375, 16.60014153], [73.34375, 16.59985924], [73.34401703, 16.59985924], [73.34401703, 16.59931183], [73.34430695, 16.59931183], [73.34430695, 16.59903145], [73.34597015, 16.59903145], [73.34597015, 16.59874916], [73.3465271, 16.59874916], [73.3465271, 16.59847069], [73.34680176, 16.5984726], [73.34680176, 16.59736061], [73.3465271, 16.59736824], [73.3465271, 16.59568977], [73.34680176, 16.59569359], [73.34680176, 16.59541512], [73.34707642, 16.59542084], [73.34707642, 16.59514046], [73.3473587, 16.59514046], [73.3473587, 16.59542084], [73.34764099, 16.59541512], [73.34764099, 16.59569359], [73.34791565, 16.59569359], [73.34791565, 16.59597206], [73.34874725, 16.59597015], [73.34874725, 16.59625053], [73.34929657, 16.59625053], [73.34929657, 16.59597015], [73.34986115, 16.59597206], [73.34986115, 16.59569359], [73.35041809, 16.59569359], [73.35041809, 16.59541512], [73.35069275, 16.59542084], [73.35069275, 16.59514046], [73.35098267, 16.59514046], [73.35098267, 16.59486008], [73.35124969, 16.59486198], [73.35124969, 16.59458351], [73.35180664, 16.59458351], [73.35180664, 16.59486198], [73.3520813, 16.59486008], [73.3520813, 16.59514046], [73.35236359, 16.59513855], [73.35235596, 16.59638023], [73.35235596, 16.59653091], [73.35263824, 16.59653091], [73.35263824, 16.59680748], [73.35236359, 16.59680557], [73.35236359, 16.59708405], [73.35180664, 16.59708405], [73.35180664, 16.59680557], [73.35163879, 16.59680557], [73.35097504, 16.59680557], [73.35097504, 16.59708405], [73.35069275, 16.59708023], [73.35069275, 16.59736824], [73.35041809, 16.59736061], [73.35041809, 16.59753036], [73.35041809, 16.59791756], [73.3501358, 16.59791756], [73.3501358, 16.59903145], [73.34986115, 16.59903145], [73.34986115, 16.59931183], [73.3501358, 16.59930611], [73.3501358, 16.59958267], [73.34986115, 16.59958076], [73.34986115, 16.59985924], [73.34958649, 16.59985924], [73.34958649, 16.60097122], [73.34929657, 16.60096931], [73.34929657, 16.6012516], [73.34958649, 16.6012516], [73.34958649, 16.60292053], [73.34929657, 16.60292053], [73.34929657, 16.60320091], [73.34902954, 16.60319519], [73.34902954, 16.60347366], [73.3484726, 16.60347366], [73.3484726, 16.60319519], [73.34819794, 16.60320091], [73.34819794, 16.60264015], [73.34792328, 16.60264015], [73.34792328, 16.60207939], [73.34764099, 16.6020813], [73.34764099, 16.60152817], [73.3473587, 16.60153008], [73.3473587, 16.6012516], [73.34680939, 16.6012516], [73.34680176, 16.60153008], [73.3456955, 16.60152817], [73.3456955, 16.60236359], [73.34542084, 16.60235977], [73.34542084, 16.60292053], [73.34513855, 16.60292053], [73.34513855, 16.60320091], [73.34485626, 16.60320091], [73.34485626, 16.60375023], [73.34430695, 16.60375023], [73.34430695, 16.60403061], [73.34401703, 16.60403061], [73.34401703, 16.60431099], [73.34375, 16.60430527], [73.34375, 16.60458374], [73.34234619, 16.60457993], [73.34234619, 16.60486031], [73.34152985, 16.60486031], [73.34152985, 16.60514069], [73.3409729, 16.60514069], [73.3409729, 16.60542107], [73.34069824, 16.60542107], [73.34069824, 16.60680962], [73.3409729, 16.6068058], [73.3409729, 16.60708237], [73.34124756, 16.60708046], [73.34124756, 16.60736084], [73.34152985, 16.60736084], [73.34152985, 16.60764122], [73.34179688, 16.60764122], [73.34179688, 16.60791969], [73.34208679, 16.60791779], [73.34208679, 16.60819435], [73.34236145, 16.60819435], [73.34236145, 16.60847282], [73.34263611, 16.60847092], [73.34263611, 16.60902977], [73.3429184, 16.60902786], [73.3429184, 16.60986137], [73.34319305, 16.60985947], [73.34319305, 16.61013985], [73.34375, 16.61013985], [73.34375, 16.61041832], [73.34430695, 16.61041641], [73.34430695, 16.61069489], [73.3445816, 16.61069107], [73.3445816, 16.61124992], [73.34485626, 16.61124992], [73.34485626, 16.61181068], [73.34541321, 16.61180496], [73.34541321, 16.61208344], [73.34570313, 16.61207962], [73.34570313, 16.61236954], [73.34597015, 16.61236954], [73.34597015, 16.61263847], [73.34680176, 16.61263847], [73.34680939, 16.61292076], [73.3473587, 16.61291695], [73.3473587, 16.61319351], [73.3484726, 16.61319351], [73.3484726, 16.61291695], [73.34874725, 16.61292076], [73.34874725, 16.61263847], [73.34902954, 16.61263847], [73.34902954, 16.61236954], [73.34929657, 16.61236954], [73.34929657, 16.61207962], [73.34958649, 16.61208344], [73.34958649, 16.61180496], [73.3501358, 16.61181068], [73.3501358, 16.6115284], [73.35069275, 16.6115284], [73.35069275, 16.61181068], [73.35098267, 16.61181068], [73.35098267, 16.61236954], [73.35124969, 16.61236191], [73.35124969, 16.61319351], [73.35151672, 16.6131897], [73.35151672, 16.61375237], [73.35180664, 16.61375237], [73.35180664, 16.61568069], [73.35180664, 16.61819458], [73.35152435, 16.61819458], [73.35152435, 16.62208366], [73.35180664, 16.62207985], [73.35180664, 16.62264061], [73.3520813, 16.62264061], [73.3520813, 16.62292099], [73.35263824, 16.62291718], [73.35263824, 16.62319374], [73.35235596, 16.62318993], [73.35235596, 16.62375069], [73.3520813, 16.62375069], [73.3520813, 16.62392998], [73.3520813, 16.6245842], [73.35180664, 16.62458038], [73.35180664, 16.62513924], [73.35124969, 16.62513924], [73.35124969, 16.62458038], [73.35069275, 16.6245842], [73.35069275, 16.62430573], [73.35041809, 16.62430954], [73.35041809, 16.62375069], [73.34986115, 16.62375069], [73.34986115, 16.62347031], [73.34958649, 16.62347221], [73.34958649, 16.62319374], [73.3493042, 16.62319374], [73.3493042, 16.62291718], [73.34874725, 16.62292099], [73.34874725, 16.62264061], [73.34848022, 16.62264061], [73.34848022, 16.62207985], [73.34791565, 16.62208366], [73.34791565, 16.62180519], [73.3473587, 16.62181091], [73.3473587, 16.62153816], [73.3465271, 16.62153816], [73.3465271, 16.62125015], [73.34541321, 16.62125015], [73.34541321, 16.62097168], [73.34069824, 16.62096977], [73.34069824, 16.62125015], [73.3401413, 16.62125015], [73.3401413, 16.62236023], [73.33985901, 16.62236023], [73.33985901, 16.62264061], [73.33958435, 16.6226387], [73.33958435, 16.62319374], [73.33930206, 16.62319374], [73.33930206, 16.62347221], [73.3390274, 16.62347031], [73.3390274, 16.62375069], [73.33875275, 16.62375069], [73.33875275, 16.62402916], [73.33735657, 16.62402916], [73.33735657, 16.62375069], [73.33708191, 16.62375069], [73.33708191, 16.62347031], [73.33680725, 16.62347221], [73.33680725, 16.62291718], [73.33651733, 16.62292099], [73.33651733, 16.62264061], [73.33625031, 16.62264061], [73.33625031, 16.62236023], [73.33597565, 16.62236023], [73.33597565, 16.62097168], [73.33569336, 16.62097168], [73.33569336, 16.6198616], [73.33513641, 16.6198616], [73.33513641, 16.61958313], [73.33486176, 16.61958313], [73.33486176, 16.61930466], [73.33291626, 16.61930466], [73.33291626, 16.61958313], [73.33180237, 16.61958313], [73.33180237, 16.6198616], [73.33125305, 16.6198597], [73.33125305, 16.62014008], [73.33069611, 16.62014008], [73.33069611, 16.62042046], [73.33040619, 16.62042046], [73.33040619, 16.62070084], [73.33013916, 16.62069511], [73.33013916, 16.62208366], [73.33040619, 16.62207985], [73.33040619, 16.62236023], [73.33069611, 16.62236023], [73.33069611, 16.62264061], [73.33097076, 16.62264061], [73.33097076, 16.62292099], [73.33125305, 16.62291718], [73.33125305, 16.62319374], [73.33152771, 16.62318993], [73.33152771, 16.62375069], [73.33180237, 16.62375069], [73.33180237, 16.62402916], [73.33207703, 16.62402916], [73.33207703, 16.62430954], [73.33235931, 16.62430573], [73.33235931, 16.6245842], [73.3326416, 16.62458038], [73.3326416, 16.62486076], [73.33291626, 16.62486076], [73.33291626, 16.62513924], [73.33319092, 16.62513924], [73.33319092, 16.62542152], [73.33374786, 16.6254158], [73.33374786, 16.62569427], [73.33403015, 16.62569427], [73.33403015, 16.62597275], [73.33429718, 16.62597084], [73.33429718, 16.62624931], [73.3345871, 16.62624931], [73.3345871, 16.6265316], [73.33486176, 16.6265316], [73.33486176, 16.62681007], [73.33513641, 16.62680626], [73.33513641, 16.62708282], [73.3354187, 16.62708282], [73.3354187, 16.62735939], [73.33680725, 16.62734985], [73.33680725, 16.62764168], [73.33708191, 16.62764168], [73.33708191, 16.62792015], [73.33791351, 16.62791634], [73.33791351, 16.62819481], [73.33847046, 16.62819481], [73.33847046, 16.62791634], [73.3390274, 16.62792015], [73.3390274, 16.62764168], [73.3392868, 16.62764168], [73.3392868, 16.62734985], [73.33958435, 16.62735939], [73.33958435, 16.62708282], [73.3401413, 16.62708282], [73.3401413, 16.62680626], [73.34069824, 16.62680626], [73.34069824, 16.62708282], [73.34124756, 16.62708282], [73.34124756, 16.62735939], [73.34152985, 16.62734985], [73.34152985, 16.62792015], [73.3418045, 16.62791634], [73.3418045, 16.62819481], [73.34208679, 16.62818909], [73.34208679, 16.62875175], [73.34179688, 16.62875175], [73.34179688, 16.62903023], [73.34152985, 16.62902832], [73.34152985, 16.62930489], [73.34124756, 16.62930489], [73.34124756, 16.62958145], [73.3409729, 16.62958145], [73.3409729, 16.62986374], [73.34069824, 16.62986183], [73.34069824, 16.6301403], [73.34041595, 16.6301403], [73.34041595, 16.63070107], [73.3401413, 16.63069534], [73.3401413, 16.63097382], [73.33985901, 16.63097], [73.33985901, 16.63125038], [73.33957672, 16.63125038], [73.33957672, 16.63181114], [73.3392868, 16.63181114], [73.3392868, 16.63292122], [73.33958435, 16.6329174], [73.33958435, 16.63319588], [73.33985901, 16.63319588], [73.33985901, 16.63344955], [73.3401413, 16.63348007], [73.3401413, 16.63402939], [73.34041595, 16.63402939], [73.34041595, 16.63486099], [73.3401413, 16.63486099], [73.3401413, 16.63541985], [73.33985901, 16.63541794], [73.33985901, 16.63597298], [73.33958435, 16.63597298], [73.33958435, 16.63708305], [73.33985901, 16.63708115], [73.33985901, 16.63820076], [73.3390274, 16.63820076], [73.3390274, 16.63792038], [73.3373642, 16.63791656], [73.3373642, 16.6380806], [73.3373642, 16.6384716], [73.33680725, 16.6384697], [73.33680725, 16.63902855], [73.33625031, 16.63902855], [73.33625031, 16.63958359], [73.33597565, 16.63958359], [73.33597565, 16.63986015], [73.33569336, 16.63985825], [73.33569336, 16.64013863], [73.33429718, 16.64013863], [73.33429718, 16.64042282], [73.33374786, 16.6404171], [73.33374786, 16.64069366], [73.33347321, 16.64069176], [73.33347321, 16.64125252], [73.33291626, 16.64125252], [73.33291626, 16.6415329], [73.32985687, 16.6415329], [73.32985687, 16.64125252], [73.32930756, 16.64125252], [73.32930756, 16.64097023], [73.32902527, 16.64097023], [73.32902527, 16.6404171], [73.32875061, 16.64042282], [73.32875061, 16.63957977], [73.32902527, 16.63958359], [73.32902527, 16.63930511], [73.32930756, 16.63931084], [73.32930756, 16.63902855], [73.32958221, 16.63902855], [73.32958221, 16.6384697], [73.32930756, 16.6384716], [73.32930756, 16.63819504], [73.3290329, 16.63820076], [73.3290329, 16.63792038], [73.32875061, 16.63792038], [73.32875061, 16.63763809], [73.32847595, 16.63763809], [73.32847595, 16.63735962], [73.32763672, 16.63736153], [73.32763672, 16.63708305], [73.32707977, 16.63708305], [73.32707977, 16.63680649], [73.32624817, 16.6368103], [73.32624817, 16.63653755], [73.32485962, 16.63653755], [73.32485962, 16.63624954], [73.32375336, 16.63624954], [73.32375336, 16.63653755], [73.32347107, 16.63653755], [73.32347107, 16.63820076], [73.32319641, 16.63819504], [73.32319641, 16.6384716], [73.32290649, 16.6384697], [73.32290649, 16.63902855], [73.32263947, 16.63902855], [73.32263947, 16.64042282], [73.32235718, 16.64042282], [73.32235718, 16.6415329], [73.32208252, 16.64152718], [73.32208252, 16.64236259], [73.32180786, 16.64236259], [73.32180786, 16.64458466], [73.32208252, 16.64458084], [73.32208252, 16.64486122], [73.32235718, 16.64486122], [73.32235718, 16.64513969], [73.32263947, 16.64513969], [73.32263947, 16.64542007], [73.32319641, 16.64541626], [73.32319641, 16.64569473], [73.32347107, 16.64569473], [73.32347107, 16.6459713], [73.32375336, 16.64596939], [73.32375336, 16.64624977], [73.32402802, 16.64624977], [73.32402802, 16.64736176], [73.32375336, 16.64735985], [73.32375336, 16.64792061], [73.32402802, 16.64792061], [73.32402802, 16.64820099], [73.3243103, 16.64820099], [73.3243103, 16.64847946], [73.32485962, 16.64847946], [73.32485962, 16.64820099], [73.32653046, 16.64820099], [73.32653046, 16.64792061], [73.32681274, 16.64792061], [73.32681274, 16.64764023], [73.32707977, 16.64764023], [73.32707977, 16.64735985], [73.32736206, 16.64736176], [73.32736206, 16.64680672], [73.32763672, 16.64680672], [73.32763672, 16.64652824], [73.32791901, 16.64653015], [73.32791901, 16.64624977], [73.32847595, 16.64624977], [73.32847595, 16.64653015], [73.32875061, 16.64652824], [73.32875061, 16.64680672], [73.32930756, 16.64680672], [73.32930756, 16.64708328], [73.3298645, 16.64708328], [73.3298645, 16.64736176], [73.33013916, 16.64735985], [73.33013916, 16.64764023], [73.33040619, 16.64764023], [73.33040619, 16.64820099], [73.33069611, 16.64820099], [73.33069611, 16.64847946], [73.33097076, 16.64847946], [73.33097076, 16.64903069], [73.33125305, 16.64902687], [73.33125305, 16.64958382], [73.33152771, 16.64958], [73.33152771, 16.65014076], [73.33180237, 16.65013885], [73.33180237, 16.65069389], [73.33208466, 16.65069389], [73.33208466, 16.65097237], [73.33235931, 16.65097046], [73.33235931, 16.65263939], [73.3326416, 16.65263939], [73.3326416, 16.65292168], [73.33291626, 16.65291595], [73.33291626, 16.6534729], [73.33319092, 16.65346909], [73.33319092, 16.65764046], [73.33291626, 16.65764046], [73.33291626, 16.65930939], [73.3326416, 16.65930557], [73.3326416, 16.66069412], [73.33235931, 16.66069031], [73.33235931, 16.66263962], [73.33207703, 16.66263962], [73.33207703, 16.66513824], [73.33180237, 16.66513824], [73.33180237, 16.66736031], [73.33152771, 16.66736031], [73.33152771, 16.66819382], [73.33125305, 16.66819382], [73.33125305, 16.66847038], [73.33152771, 16.66847038], [73.33152771, 16.66903114], [73.33125305, 16.66903114], [73.33125305, 16.66986275], [73.33097076, 16.66986275], [73.33097076, 16.67152977], [73.33069611, 16.67152977], [73.33069611, 16.6740303], [73.33040619, 16.6740303], [73.33040619, 16.67681122], [73.33013916, 16.67681122], [73.33013916, 16.67791748], [73.32985687, 16.67791748], [73.32985687, 16.67874908], [73.32958221, 16.67874718], [73.32958221, 16.6795826], [73.32930756, 16.67958069], [73.32930756, 16.68292046], [73.32958221, 16.68291664], [73.32958221, 16.68569565], [73.3298645, 16.68569565], [73.3298645, 16.68597221], [73.33403015, 16.68597221], [73.33403015, 16.68569565], [73.3345871, 16.68569565], [73.3345871, 16.68541718], [73.33486176, 16.68542099], [73.33486176, 16.68514061], [73.33680725, 16.68514061], [73.33680725, 16.68486023], [73.33735657, 16.68486023], [73.33735657, 16.68458939], [73.3392868, 16.68458939], [73.3392868, 16.68514061], [73.33958435, 16.6851387], [73.33958435, 16.68569565], [73.33930206, 16.68569565], [73.33930206, 16.68597221], [73.33875275, 16.68597031], [73.33875275, 16.68653107], [73.33790588, 16.68653107], [73.33790588, 16.68625069], [73.33735657, 16.68625069], [73.33735657, 16.68597031], [73.33597565, 16.68597221], [73.33598328, 16.68625069], [73.3354187, 16.68625069], [73.3354187, 16.68653107], [73.33513641, 16.68653107], [73.33513641, 16.68680954], [73.33486176, 16.68680954], [73.33486176, 16.68736076], [73.3345871, 16.68736076], [73.3345871, 16.68765068], [73.33429718, 16.68765068], [73.33429718, 16.68791962], [73.33235931, 16.68791962], [73.33235931, 16.68765068], [73.33152771, 16.68765068], [73.33152771, 16.68736076], [73.33013916, 16.68736076], [73.33013916, 16.68765068], [73.32985687, 16.68765068], [73.32985687, 16.68791962], [73.32958221, 16.68791771], [73.32958221, 16.68819427], [73.32930756, 16.68819427], [73.32930756, 16.68847275], [73.32875061, 16.68847084], [73.32875061, 16.68875122], [73.32847595, 16.68875122], [73.32847595, 16.68902969], [73.32818604, 16.68902969], [73.32818604, 16.68930817], [73.32763672, 16.68930626], [73.32763672, 16.68958282], [73.32680511, 16.68958282], [73.32680511, 16.6898613], [73.32624817, 16.68985939], [73.32624817, 16.69013977], [73.32569122, 16.69013977], [73.32569122, 16.69041824], [73.32541656, 16.69041634], [73.32541656, 16.69069481], [73.32485962, 16.69069481], [73.32485962, 16.69097137], [73.3243103, 16.69096947], [73.3243103, 16.69152832], [73.32402802, 16.69152832], [73.32402802, 16.69208336], [73.32347107, 16.69208336], [73.32347107, 16.69236183], [73.32319641, 16.69235992], [73.32319641, 16.6926384], [73.32290649, 16.6926384], [73.32290649, 16.69292068], [73.32263947, 16.69291687], [73.32263947, 16.69347191], [73.32235718, 16.69346809], [73.32235718, 16.69375229], [73.32180786, 16.69375229], [73.32180786, 16.69403267], [73.3215332, 16.69403267], [73.3215332, 16.69431114], [73.32125092, 16.69430542], [73.32125092, 16.69458389], [73.32096863, 16.69458008], [73.32096863, 16.69486046], [73.32068634, 16.69486046], [73.32068634, 16.69514275], [73.32013702, 16.69514275], [73.32013702, 16.69542122], [73.31958008, 16.6954174], [73.31958008, 16.69569206], [73.31930542, 16.69569206], [73.31930542, 16.69597054], [73.31903076, 16.69597054], [73.31903076, 16.69625282], [73.31846619, 16.69625282], [73.31846619, 16.69652939], [73.31817627, 16.69652939], [73.31817627, 16.6973629], [73.31791687, 16.6973629], [73.31791687, 16.69791985], [73.31764221, 16.69791603], [73.31764221, 16.69847488], [73.31735992, 16.69847107], [73.31735992, 16.70042038], [73.31764221, 16.70042038], [73.31764221, 16.70236015], [73.31791687, 16.70236206], [73.31791687, 16.70263863], [73.31846619, 16.702631], [73.31846619, 16.70292091], [73.31874847, 16.7029171], [73.31874847, 16.70347214], [73.31903076, 16.70347023], [73.31903076, 16.70430756], [73.31874847, 16.70430565], [73.31874847, 16.70458412], [73.31847382, 16.70458412], [73.31847382, 16.7056942], [73.31817627, 16.70569038], [73.31817627, 16.70624924], [73.31791687, 16.70624924], [73.31791687, 16.7068119], [73.31764221, 16.7068119], [73.31764221, 16.70735931], [73.31735992, 16.70735931], [73.31735992, 16.7076416], [73.3170929, 16.7076416], [73.3170929, 16.70876122], [73.31680298, 16.70875168], [73.31680298, 16.70958138], [73.31652832, 16.70957947], [73.31652832, 16.71070099], [73.31625366, 16.71069527], [73.31625366, 16.71097374], [73.31597137, 16.71096992], [73.31597137, 16.71153069], [73.31569672, 16.71152687], [73.31569672, 16.71208572], [73.3154068, 16.71208], [73.3154068, 16.71264076], [73.31513977, 16.71264076], [73.31513977, 16.71292114], [73.31430817, 16.71291733], [73.31430817, 16.7131958], [73.31375122, 16.7131958], [73.31375122, 16.71347237], [73.31291962, 16.71347046], [73.31291962, 16.71375084], [73.31263733, 16.71375084], [73.31263733, 16.71430969], [73.31236267, 16.71430588], [73.31236267, 16.71458244], [73.31208038, 16.714571], [73.31208038, 16.71486092], [73.31153107, 16.71486092], [73.31153107, 16.71513939], [73.31124878, 16.71513939], [73.31124878, 16.7159729], [73.31097412, 16.7159729], [73.31097412, 16.71736145], [73.31124878, 16.71736145], [73.31124878, 16.71847153], [73.31153107, 16.71846962], [73.31153107, 16.72153282], [73.31124878, 16.72153282], [73.31124878, 16.72180939], [73.31097412, 16.72180557], [73.31097412, 16.72208214], [73.31069183, 16.72208023], [73.31069183, 16.72236252], [73.31041718, 16.72236252], [73.31041718, 16.7226429], [73.30986023, 16.7226429], [73.30986023, 16.7237606], [73.31014252, 16.7237606], [73.31014252, 16.72486115], [73.30986023, 16.72486115], [73.30986023, 16.72542], [73.30958557, 16.72541618], [73.30958557, 16.72624969], [73.30930328, 16.72624969], [73.30930328, 16.72680664], [73.30735779, 16.72680664], [73.30735779, 16.72736168], [73.30708313, 16.72735977], [73.30708313, 16.72792053], [73.30680847, 16.72792053], [73.30680847, 16.72820091], [73.30652618, 16.72819519], [73.30652618, 16.72847176], [73.30596924, 16.72846985], [73.30596924, 16.72875023], [73.30568695, 16.72875023], [73.30568695, 16.72931099], [73.30541992, 16.72930527], [73.30541992, 16.73069382], [73.30569458, 16.73069382], [73.30569458, 16.73097229], [73.30596924, 16.73097038], [73.30596924, 16.73125076], [73.30623627, 16.73125076], [73.30623627, 16.73180962], [73.30652618, 16.73180962], [73.30652618, 16.73431015], [73.30623627, 16.73431015], [73.30623627, 16.73542023], [73.30596924, 16.73541641], [73.30596924, 16.73597336], [73.30568695, 16.73596954], [73.30568695, 16.7365303], [73.30541992, 16.7365303], [73.30541992, 16.73681068], [73.30568695, 16.73681068], [73.30568695, 16.73986053], [73.30541992, 16.73986053], [73.30541992, 16.74152946], [73.30569458, 16.74152756], [73.30569458, 16.7420826], [73.30596924, 16.7420826], [73.30596924, 16.74319458], [73.30568695, 16.74319077], [73.30568695, 16.74652863], [73.30623627, 16.74652863], [73.30623627, 16.74681091], [73.30652618, 16.74680519], [73.30652618, 16.74708366], [73.30680847, 16.74707985], [73.30680847, 16.74736023], [73.30708313, 16.74736023], [73.30708313, 16.74764252], [73.30735779, 16.74764252], [73.30735779, 16.74930954], [73.30708313, 16.74930573], [73.30708313, 16.7495842], [73.30652618, 16.74958038], [73.30652618, 16.74986267], [73.30596924, 16.74986267], [73.30596924, 16.75014114], [73.30568695, 16.75014114], [73.30568695, 16.75041962], [73.30486298, 16.75041962], [73.30486298, 16.75125122], [73.30513763, 16.75124931], [73.30513763, 16.75208473], [73.30541992, 16.75208473], [73.30541992, 16.75347137], [73.30513763, 16.75346947], [73.30513763, 16.75681114], [73.30541992, 16.75680542], [73.30541992, 16.7606945], [73.30568695, 16.76069069], [73.30568695, 16.76153183], [73.30541992, 16.76153183], [73.30541992, 16.76375008], [73.30513763, 16.76375008], [73.30513763, 16.76708412], [73.30541992, 16.76708412], [73.30541992, 16.76847267], [73.30568695, 16.76847076], [73.30568695, 16.76875114], [73.30596924, 16.76875114], [73.30596924, 16.76902962], [73.30623627, 16.76902962], [73.30623627, 16.76930809], [73.30652618, 16.76930809], [73.30652618, 16.76986122], [73.30680847, 16.76986122], [73.30680847, 16.77041817], [73.30708313, 16.77041817], [73.30708313, 16.77124977], [73.30735779, 16.77124977], [73.30735779, 16.77347183], [73.30708313, 16.77346992], [73.30708313, 16.77403259], [73.30680847, 16.77402687], [73.30680847, 16.77458382], [73.30652618, 16.77458191], [73.30652618, 16.77542114], [73.30680847, 16.77542114], [73.30680847, 16.77625275], [73.30708313, 16.77625275], [73.30708313, 16.77708435], [73.30735779, 16.77708054], [73.30735779, 16.77874947], [73.30764008, 16.77874947], [73.30764008, 16.78013992], [73.3079071, 16.78013992], [73.3079071, 16.78070068], [73.30819702, 16.78069687], [73.30819702, 16.78097153], [73.30847168, 16.78096962], [73.30847168, 16.78153038], [73.30874634, 16.78152847], [73.30874634, 16.78208351], [73.30902863, 16.7820797], [73.30902863, 16.78264046], [73.30930328, 16.78263855], [73.30930328, 16.78375053], [73.3095932, 16.78375053], [73.3095932, 16.78513908], [73.30986023, 16.78513718], [73.30986023, 16.78569412], [73.31014252, 16.78569031], [73.31014252, 16.78624916], [73.31041718, 16.78624916], [73.31041718, 16.78681183], [73.31069183, 16.78680611], [73.31069183, 16.78708267], [73.31096649, 16.78708076], [73.31096649, 16.78764153], [73.31124878, 16.78764153], [73.31124878, 16.78819466], [73.31153107, 16.78819466], [73.31153107, 16.78847122], [73.31180573, 16.78847122], [73.31180573, 16.78874969], [73.31236267, 16.78874969], [73.31236267, 16.78930473], [73.31263733, 16.78930473], [73.31263733, 16.78986359], [73.31318665, 16.78985023], [73.31318665, 16.79042053], [73.31346893, 16.79041672], [73.31346893, 16.79097366], [73.31375122, 16.79096985], [73.31375122, 16.79125023], [73.31402588, 16.79125023], [73.31402588, 16.79153061], [73.31430817, 16.7915287], [73.31430817, 16.79208565], [73.31458282, 16.79207993], [73.31458282, 16.79236031], [73.31485748, 16.79236031], [73.31485748, 16.79264069], [73.31513977, 16.79263878], [73.31513977, 16.79291725], [73.31541443, 16.79291725], [73.31541443, 16.79319572], [73.31569672, 16.79319572], [73.31569672, 16.79347229], [73.31597137, 16.79347038], [73.31597137, 16.79375076], [73.31624603, 16.79375076], [73.31624603, 16.79430962], [73.31652832, 16.7943058], [73.31652832, 16.79458237], [73.31708527, 16.79458427], [73.31708527, 16.79486084], [73.31735992, 16.79486084], [73.31735992, 16.79514122], [73.31764221, 16.79514122], [73.31764221, 16.79652977], [73.31735992, 16.79652977], [73.31735992, 16.79680824], [73.31708527, 16.79680634], [73.31708527, 16.79736137], [73.31680298, 16.79735947], [73.31680298, 16.79791832], [73.31652832, 16.79791832], [73.31652832, 16.80042076], [73.31624603, 16.80042076], [73.31624603, 16.80181122], [73.31652832, 16.80181122], [73.31652832, 16.80236053], [73.31680298, 16.80236053], [73.31680298, 16.80319214], [73.3170929, 16.80319023], [73.3170929, 16.80402946], [73.31735992, 16.80402946], [73.31735992, 16.80430984], [73.31764221, 16.80430603], [73.31764221, 16.80597305], [73.31817627, 16.80597115], [73.31817627, 16.80624962], [73.31846619, 16.80624962], [73.31846619, 16.80653], [73.31903076, 16.80652809], [73.31903076, 16.80680656], [73.31952667, 16.80680656], [73.32013702, 16.80680656], [73.32013702, 16.80708313], [73.32096863, 16.80708313], [73.32096863, 16.8073616], [73.3215332, 16.8073597], [73.3215332, 16.80764008], [73.32180786, 16.80764008], [73.32180786, 16.80792046], [73.32235718, 16.80792046], [73.32235718, 16.80821037], [73.32263947, 16.80819511], [73.32263947, 16.80847168], [73.32290649, 16.80846977], [73.32290649, 16.80903053], [73.32319641, 16.80902863], [73.32319641, 16.80958366], [73.32347107, 16.80957985], [73.32347107, 16.80986023], [73.32375336, 16.80986023], [73.32375336, 16.81014061], [73.32402802, 16.81014061], [73.32402802, 16.81041908], [73.32430267, 16.81041718], [73.32430267, 16.81069374], [73.32458496, 16.81069374], [73.32458496, 16.81125069], [73.32485962, 16.81125069], [73.32485962, 16.81180763], [73.32514191, 16.81180573], [73.32514191, 16.8120842], [73.32541656, 16.81208038], [73.32541656, 16.81236076], [73.32569122, 16.81236076], [73.32569122, 16.81263924], [73.32624817, 16.81263924], [73.32624817, 16.81292152], [73.32958221, 16.81292152], [73.32958221, 16.81263924], [73.33069611, 16.81263924], [73.33069611, 16.81236076], [73.33152771, 16.81236076], [73.33152771, 16.81292152], [73.33180237, 16.8129158], [73.33180237, 16.81347275], [73.33208466, 16.81347275], [73.33208466, 16.81402779], [73.33235931, 16.81402779], [73.33235931, 16.81458282], [73.3326416, 16.81458092], [73.3326416, 16.81514168], [73.33291626, 16.81514168], [73.33291626, 16.81569481], [73.33319092, 16.8156929], [73.33319092, 16.81653023], [73.3326416, 16.81652832], [73.3326416, 16.81708145], [73.33235931, 16.81708145], [73.33235931, 16.81736374], [73.33207703, 16.81735992], [73.33207703, 16.81792068], [73.33180237, 16.81792068], [73.33180237, 16.81820107], [73.33152771, 16.81820107], [73.33152771, 16.81875038], [73.33125305, 16.81875038], [73.33125305, 16.81903076], [73.33097076, 16.81902695], [73.33097076, 16.8195858], [73.33069611, 16.81958008], [73.33069611, 16.81986046], [73.32985687, 16.81986046], [73.32985687, 16.82015038], [73.3290329, 16.82015038], [73.3290329, 16.82042122], [73.32847595, 16.8204174], [73.32847595, 16.82069588], [73.32653046, 16.82069588], [73.32653046, 16.82013893], [73.32624817, 16.82015038], [73.32624817, 16.81931114], [73.32596588, 16.81931114], [73.32596588, 16.81820107], [73.32569122, 16.81820107], [73.32569122, 16.81792068], [73.32541656, 16.81792068], [73.32541656, 16.8176403], [73.32514191, 16.8176403], [73.32514191, 16.81735992], [73.32458496, 16.81736374], [73.32458496, 16.81680489], [73.32430267, 16.81680489], [73.32430267, 16.81652832], [73.32402802, 16.81653023], [73.32402802, 16.8156929], [73.32375336, 16.81569481], [73.32375336, 16.81541634], [73.32347107, 16.81542015], [73.32347107, 16.81458092], [73.32319641, 16.81458282], [73.32319641, 16.81374931], [73.32290649, 16.81374931], [73.32290649, 16.81319046], [73.32263947, 16.81319427], [73.32263947, 16.81263924], [73.32235718, 16.81263924], [73.32235718, 16.81236076], [73.32208252, 16.81236076], [73.32208252, 16.81180763], [73.3215332, 16.81180763], [73.3215332, 16.81125069], [73.32096863, 16.81125069], [73.32096863, 16.81068993], [73.32069397, 16.81069374], [73.32069397, 16.81041718], [73.32041931, 16.81041908], [73.32041931, 16.81014061], [73.31986237, 16.81014061], [73.31986237, 16.80986023], [73.31874847, 16.80986023], [73.31874847, 16.80957985], [73.31791687, 16.80958366], [73.31791687, 16.80902863], [73.31764221, 16.80903053], [73.31764221, 16.80875015], [73.31708527, 16.80875015], [73.31708527, 16.80847168], [73.31680298, 16.80847168], [73.31680298, 16.80819511], [73.31652832, 16.80821037], [73.31652832, 16.80792046], [73.31624603, 16.80792046], [73.31624603, 16.80764008], [73.31597137, 16.80764008], [73.31597137, 16.8073597], [73.31569672, 16.8073616], [73.31569672, 16.80708313], [73.31236267, 16.80708313], [73.31236267, 16.80680656], [73.31124878, 16.80680656], [73.31124878, 16.80708313], [73.31069183, 16.80708313], [73.31069183, 16.8073616], [73.31041718, 16.8073597], [73.31041718, 16.80764008], [73.30986023, 16.80764008], [73.30986023, 16.80792046], [73.30931091, 16.80792046], [73.30931091, 16.80821037], [73.30902863, 16.80819511], [73.30902863, 16.80847168], [73.30819702, 16.80846977], [73.30819702, 16.80875015], [73.3034668, 16.80875015], [73.3034668, 16.80903053], [73.30317688, 16.80903053], [73.30317688, 16.80931091], [73.30263519, 16.80930519], [73.30263519, 16.80958366], [73.30236053, 16.80957985], [73.30236053, 16.80986023], [73.30179596, 16.80986023], [73.30179596, 16.81014061], [73.30152893, 16.81014061], [73.30152893, 16.81041908], [73.30124664, 16.81041718], [73.30124664, 16.81069374], [73.30097198, 16.81068993], [73.30097198, 16.81097984], [73.30041504, 16.81097221], [73.3004303, 16.81125069], [73.30014038, 16.81125069], [73.30014038, 16.81152916], [73.29985809, 16.81152916], [73.29985809, 16.81180763], [73.29958344, 16.81180573], [73.29958344, 16.8120842], [73.29930878, 16.81208038], [73.29930878, 16.81236076], [73.29902649, 16.81236076], [73.29902649, 16.81263924], [73.29875183, 16.81263924], [73.29875183, 16.81292152], [73.29846954, 16.8129158], [73.29846954, 16.81319427], [73.29819489, 16.81319427], [73.29819489, 16.81347275], [73.29792023, 16.81347084], [73.29792023, 16.81374931], [73.29763794, 16.81374931], [73.29763794, 16.81402779], [73.29737091, 16.81401825], [73.29737091, 16.81431007], [73.29708099, 16.81430626], [73.29708099, 16.81458282], [73.29680634, 16.81458092], [73.29680634, 16.81514168], [73.29651642, 16.81514168], [73.29651642, 16.81542015], [73.29624939, 16.81541634], [73.29624939, 16.81569481], [73.2959671, 16.8156929], [73.2959671, 16.81625175], [73.29569244, 16.81625175], [73.29569244, 16.81680489], [73.29541779, 16.81679153], [73.29541779, 16.81903076], [73.29514313, 16.81903076], [73.29514313, 16.82152939], [73.29541779, 16.82152748], [73.29541779, 16.82208252], [73.2959671, 16.82208061], [73.2959671, 16.82236099], [73.29651642, 16.82236099], [73.29651642, 16.82263947], [73.29680634, 16.82263947], [73.29680634, 16.82291985], [73.29708099, 16.82291985], [73.29708099, 16.82402992], [73.29680634, 16.82402992], [73.29680634, 16.8243103], [73.29652405, 16.82430649], [73.29652405, 16.82486153], [73.29624939, 16.82485962], [73.29624939, 16.82681084], [73.29652405, 16.82680511], [73.29652405, 16.82819366], [73.29624939, 16.82819366], [73.29624939, 16.82847023], [73.2959671, 16.82847023], [73.2959671, 16.82875252], [73.29569244, 16.82875252], [73.29569244, 16.82902718], [73.29541779, 16.82902145], [73.29541779, 16.82930946], [73.2951355, 16.82930565], [73.29514313, 16.82986259], [73.29486084, 16.82986259], [73.29486084, 16.83014107], [73.29458618, 16.83014107], [73.29458618, 16.83041954], [73.29430389, 16.83041763], [73.29430389, 16.83097458], [73.29402924, 16.83097076], [73.29402924, 16.83181], [73.29429626, 16.83181], [73.29429626, 16.83292007], [73.29458618, 16.83292007], [73.29458618, 16.83374977], [73.29429626, 16.83374977], [73.29429626, 16.83403015], [73.29374695, 16.83402824], [73.29374695, 16.83430672], [73.29347229, 16.83430672], [73.29347229, 16.83458328], [73.29319763, 16.83458328], [73.29319763, 16.83486176], [73.29292297, 16.83485985], [73.29292297, 16.83542061], [73.29264069, 16.83542061], [73.29264069, 16.83625031], [73.29291534, 16.83625031], [73.29291534, 16.83736038], [73.29319763, 16.83736038], [73.29319763, 16.83819389], [73.29402924, 16.83818817], [73.29402924, 16.83875084], [73.29374695, 16.83875084], [73.29374695, 16.8393116], [73.29347229, 16.8393116], [73.29347229, 16.83986092], [73.29319763, 16.83986092], [73.29319763, 16.84042168], [73.29291534, 16.84041595], [73.29291534, 16.8409729], [73.29264069, 16.84095955], [73.29264069, 16.84153175], [73.2923584, 16.84152794], [73.2923584, 16.84208107], [73.29207611, 16.84207916], [73.29207611, 16.84264183], [73.29180908, 16.84264183], [73.29180908, 16.8429203], [73.29152679, 16.8429203], [73.29152679, 16.84320068], [73.29125214, 16.84319305], [73.29125214, 16.84347153], [73.29096985, 16.84346962], [73.29096985, 16.84375191], [73.29013824, 16.84375191], [73.29013824, 16.84346962], [73.28986359, 16.84347153], [73.28986359, 16.84319305], [73.2895813, 16.84320068], [73.2895813, 16.8429203], [73.28901672, 16.8429203], [73.28901672, 16.84320068], [73.28819275, 16.84319305], [73.28819275, 16.84347153], [73.28791809, 16.84347153], [73.28791809, 16.84486389], [73.28820038, 16.84486008], [73.28820038, 16.84514046], [73.2884903, 16.84514046], [73.2884903, 16.84542084], [73.28874969, 16.84541702], [73.28874969, 16.8456955], [73.28930664, 16.8456955], [73.28930664, 16.84597206], [73.28985596, 16.84597015], [73.28985596, 16.84653091], [73.2904129, 16.84653091], [73.2904129, 16.84680939], [73.29070282, 16.84680939], [73.29070282, 16.84708977], [73.29123688, 16.84708977], [73.29123688, 16.84736061], [73.29152679, 16.84736061], [73.29152679, 16.84764099], [73.29207611, 16.84764099], [73.29207611, 16.84791946], [73.2923584, 16.84791756], [73.2923584, 16.84819412], [73.29264069, 16.84819412], [73.29264069, 16.8484726], [73.29292297, 16.84847069], [73.29292297, 16.84902954], [73.29319763, 16.84902763], [73.29319763, 16.84958267], [73.29292297, 16.84958076], [73.29292297, 16.85152817], [73.29264069, 16.85152817], [73.29264069, 16.85180473], [73.29180908, 16.85180473], [73.29180908, 16.85152817], [73.29152679, 16.85152817], [73.29152679, 16.85124969], [73.29070282, 16.85124969], [73.29070282, 16.85152817], [73.2904129, 16.85152817], [73.2904129, 16.85208321], [73.29013824, 16.85207939], [73.29013824, 16.85292053], [73.29096985, 16.85291672], [73.29096985, 16.85319519], [73.2923584, 16.85319519], [73.2923584, 16.85347176], [73.29264069, 16.85346985], [73.29264069, 16.85542107], [73.2923584, 16.85541725], [73.2923584, 16.85569382], [73.29208374, 16.85569382], [73.29208374, 16.85597038], [73.29096985, 16.85597038], [73.29096985, 16.8562603], [73.28985596, 16.8562603], [73.28985596, 16.85653114], [73.28930664, 16.85653114], [73.28930664, 16.85680962], [73.28820038, 16.85680962], [73.28820038, 16.85764122], [73.28791809, 16.85763931], [73.28791809, 16.85819244], [73.28847504, 16.85819244], [73.28847504, 16.85847473], [73.28874969, 16.85847092], [73.28874969, 16.85874939], [73.28930664, 16.85874939], [73.28930664, 16.85902977], [73.28985596, 16.85902977], [73.28985596, 16.85931969], [73.29069519, 16.85930634], [73.29069519, 16.85958481], [73.29152679, 16.85958481], [73.29152679, 16.85986137], [73.29207611, 16.85985947], [73.29207611, 16.86013985], [73.29347229, 16.86013985], [73.29347229, 16.85985947], [73.29402924, 16.85986137], [73.29402924, 16.85930634], [73.29429626, 16.85931969], [73.29429626, 16.85847092], [73.29458618, 16.85847473], [73.29458618, 16.85819244], [73.2951355, 16.85819244], [73.2951355, 16.85958481], [73.29486084, 16.85958481], [73.29486084, 16.86208344], [73.29458618, 16.86207008], [73.29458618, 16.86375046], [73.29429626, 16.86375046], [73.29429626, 16.86403084], [73.29402924, 16.86403084], [73.29402924, 16.86653137], [73.29374695, 16.86653137], [73.29374695, 16.86763954], [73.29347229, 16.86763954], [73.29347229, 16.8682003], [73.29319763, 16.86819458], [73.29319763, 16.86986351], [73.29292297, 16.8698597], [73.29292297, 16.87070084], [73.29264069, 16.87069321], [73.29264069, 16.87097359], [73.29207611, 16.87096977], [73.29207611, 16.87125969], [73.29152679, 16.87125969], [73.29152679, 16.87070084], [73.29125214, 16.87069321], [73.29125214, 16.87097359], [73.29096985, 16.87097359], [73.29096985, 16.87041664], [73.29013824, 16.87042046], [73.29013824, 16.87070084], [73.2895813, 16.87069321], [73.2895813, 16.87097359], [73.28930664, 16.87097359], [73.28930664, 16.87208557], [73.28901672, 16.87207985], [73.28901672, 16.87264061], [73.28874969, 16.87264061], [73.28874969, 16.87292099], [73.28847504, 16.87291718], [73.28847504, 16.87319565], [73.28624725, 16.87319565], [73.28624725, 16.87347221], [73.2859726, 16.87347031], [73.2859726, 16.87625122], [73.28624725, 16.87625122], [73.28624725, 16.87680817], [73.28652954, 16.87680626], [73.28652954, 16.87708282], [73.2868042, 16.87708282], [73.2868042, 16.87819481], [73.28652954, 16.87819481], [73.28652954, 16.87847137], [73.28624725, 16.87847137], [73.28624725, 16.87930489], [73.2859726, 16.87930489], [73.2859726, 16.87958336], [73.28569794, 16.87957954], [73.28569794, 16.88070107], [73.2859726, 16.88070107], [73.2859726, 16.88125038], [73.28624725, 16.88125038], [73.28624725, 16.88153267], [73.28652954, 16.88153267], [73.28652954, 16.88181114], [73.28708649, 16.88180542], [73.28708649, 16.88208389], [73.28736115, 16.88208008], [73.28736115, 16.88236046], [73.2876358, 16.88236046], [73.2876358, 16.88264275], [73.2884903, 16.88264275], [73.2884903, 16.88292122], [73.28901672, 16.88292122], [73.28901672, 16.88319969], [73.28986359, 16.88319206], [73.28986359, 16.88347054], [73.29069519, 16.88347054], [73.29069519, 16.88375282], [73.29123688, 16.88375282], [73.29123688, 16.88402939], [73.29152679, 16.88402939], [73.29152679, 16.88430977], [73.29180908, 16.88430405], [73.29180908, 16.88458443], [73.29207611, 16.88458061], [73.29207611, 16.8848629], [73.29264069, 16.8848629], [73.29264069, 16.88513947], [73.29291534, 16.88513947], [73.29291534, 16.8856926], [73.29319763, 16.88569069], [73.29319763, 16.88652992], [73.29347229, 16.88652802], [73.29347229, 16.88708305], [73.29374695, 16.88708115], [73.29374695, 16.88764], [73.29402924, 16.88764], [73.29402924, 16.88792038], [73.29458618, 16.88792038], [73.29458618, 16.88820076], [73.2951355, 16.88819695], [73.2951355, 16.8884716], [73.29541779, 16.8884697], [73.29541779, 16.88875008], [73.29597473, 16.88875008], [73.29597473, 16.88930511], [73.29652405, 16.88930511], [73.29652405, 16.88958359], [73.29680634, 16.88957977], [73.29680634, 16.88986015], [73.29792023, 16.88986015], [73.29792023, 16.89014053], [73.30014038, 16.89014053], [73.30014038, 16.89042091], [73.30097198, 16.8904171], [73.30097198, 16.89069366], [73.30180359, 16.89069366], [73.30180359, 16.8904171], [73.30291748, 16.89042091], [73.30291748, 16.89014053], [73.30374908, 16.89014053], [73.30374908, 16.88986015], [73.30403137, 16.88986015], [73.30403137, 16.88957977], [73.30458069, 16.88958359], [73.30458069, 16.88930511], [73.30625153, 16.88930511], [73.30625153, 16.88958359], [73.30652618, 16.88957977], [73.30652618, 16.88986015], [73.30680847, 16.88986015], [73.30680847, 16.89014053], [73.30735779, 16.89014053], [73.30735779, 16.89042091], [73.30764008, 16.89042091], [73.30764008, 16.89014053], [73.30819702, 16.89014053], [73.30819702, 16.89042091], [73.30874634, 16.89042091], [73.30874634, 16.89014053], [73.31014252, 16.89014053], [73.31014252, 16.88986015], [73.31069183, 16.88986015], [73.31069183, 16.88957977], [73.31124878, 16.88958359], [73.31124878, 16.88930511], [73.31180573, 16.88930511], [73.31180573, 16.88875008], [73.31208038, 16.88875008], [73.31208038, 16.88820076], [73.3123703, 16.88820076], [73.3123703, 16.88764], [73.31291962, 16.88764], [73.31291962, 16.88792038], [73.31346893, 16.88792038], [73.31346893, 16.88903046], [73.31319427, 16.88902855], [73.31319427, 16.88958359], [73.31263733, 16.88958359], [73.31263733, 16.88986206], [73.3123703, 16.88986015], [73.3123703, 16.89014053], [73.31181335, 16.89014053], [73.31181335, 16.89042091], [73.31153107, 16.8904171], [73.31153107, 16.89069366], [73.31097412, 16.89069366], [73.31097412, 16.89097214], [73.31041718, 16.89097023], [73.31041718, 16.89125061], [73.30902863, 16.89125061], [73.30902863, 16.89152908], [73.30647278, 16.89152718], [73.30625153, 16.89152718], [73.30625153, 16.89125061], [73.30596924, 16.89125061], [73.30596924, 16.89145088], [73.30596924, 16.89152718], [73.30568695, 16.89152908], [73.30568695, 16.89141273], [73.30569458, 16.89125061], [73.30465698, 16.89125061], [73.30430603, 16.89125061], [73.30430603, 16.89097214], [73.30374908, 16.89097214], [73.30374908, 16.89110947], [73.30374908, 16.89125061], [73.30317688, 16.89125061], [73.30317688, 16.89152908], [73.30264282, 16.89152908], [73.30264282, 16.89180756], [73.30208588, 16.89180565], [73.30208588, 16.89208412], [73.30152893, 16.89208031], [73.30152893, 16.89236069], [73.30097198, 16.89236069], [73.30097198, 16.89263916], [73.30041504, 16.89263916], [73.30041504, 16.8931942], [73.30014038, 16.8931942], [73.30014038, 16.89347267], [73.29985809, 16.89347076], [73.29985809, 16.89374924], [73.29958344, 16.89374924], [73.29958344, 16.89458275], [73.29930878, 16.89458084], [73.29930878, 16.89485931], [73.29902649, 16.89485931], [73.29902649, 16.8951416], [73.29875183, 16.8951416], [73.29875183, 16.89542961], [73.29846954, 16.89541626], [73.29846954, 16.89569473], [73.29818726, 16.89569283], [73.29818726, 16.89624977], [73.29792023, 16.89624977], [73.29792023, 16.89653015], [73.29763794, 16.89652824], [73.29763794, 16.89680481], [73.29708099, 16.89680481], [73.29708099, 16.89708138], [73.29652405, 16.89708138], [73.29652405, 16.89736366], [73.29569244, 16.89735985], [73.29569244, 16.89764023], [73.29476929, 16.89763832], [73.29374695, 16.89764023], [73.29374695, 16.89792061], [73.29347229, 16.89792061], [73.29347229, 16.89764023], [73.29152679, 16.89764023], [73.29152679, 16.89735985], [73.29069519, 16.89736366], [73.29069519, 16.89680481], [73.2904129, 16.89680481], [73.2904129, 16.89652824], [73.2895813, 16.89653015], [73.2895813, 16.89624977], [73.28901672, 16.89624977], [73.28901672, 16.89653015], [73.28847504, 16.89652824], [73.28847504, 16.89680481], [73.2876358, 16.89680481], [73.2876358, 16.89652824], [73.28736115, 16.89653015], [73.28736115, 16.89624977], [73.28708649, 16.89624977], [73.28708649, 16.89596939], [73.28736115, 16.8959713], [73.28736115, 16.89569473], [73.2876358, 16.89569473], [73.2876358, 16.89374924], [73.28736115, 16.89374924], [73.28736115, 16.89319038], [73.28708649, 16.8931942], [73.28708649, 16.89291763], [73.28652954, 16.89292145], [73.28652954, 16.89263916], [73.28543091, 16.89263916], [73.28543091, 16.89292145], [73.28514099, 16.89291763], [73.28514099, 16.8931942], [73.2848587, 16.8931942], [73.2848587, 16.89291763], [73.28347015, 16.89292145], [73.28347015, 16.89263916], [73.28320313, 16.89263916], [73.28320313, 16.89208031], [73.28236389, 16.89208412], [73.28236389, 16.89180565], [73.28151703, 16.89180756], [73.28151703, 16.89152908], [73.28069305, 16.89152908], [73.28069305, 16.89180756], [73.2804184, 16.89180565], [73.2804184, 16.89208412], [73.27986145, 16.89208412], [73.27986145, 16.89180565], [73.27958679, 16.89180756], [73.27958679, 16.89152908], [73.2784729, 16.89152908], [73.2784729, 16.89180756], [73.27819824, 16.89180565], [73.27819824, 16.89208412], [73.27708435, 16.89208412], [73.27708435, 16.89347267], [73.27735901, 16.89347076], [73.27735901, 16.89403152], [73.2776413, 16.89403152], [73.2776413, 16.8943119], [73.27791595, 16.8943119], [73.27791595, 16.89485931], [73.27819824, 16.89485931], [73.27819824, 16.8951416], [73.2784729, 16.8951416], [73.2784729, 16.89542961], [73.27874756, 16.89541626], [73.27874756, 16.8959713], [73.27902985, 16.89596939], [73.27902985, 16.89624977], [73.27929688, 16.89624977], [73.27929688, 16.89653015], [73.27958679, 16.89652824], [73.27958679, 16.89680481], [73.27986145, 16.89680481], [73.27986145, 16.89708138], [73.28013611, 16.89708138], [73.28013611, 16.89847374], [73.27986145, 16.89846992], [73.27986145, 16.89875031], [73.27958679, 16.89875031], [73.27958679, 16.90263939], [73.2793045, 16.90263939], [73.2793045, 16.90319443], [73.27902985, 16.90319061], [73.27902985, 16.90402985], [73.2793045, 16.90402794], [73.2793045, 16.90430641], [73.27958679, 16.90430641], [73.27958679, 16.90486145], [73.27986145, 16.90486145], [73.27986145, 16.90458298], [73.28013611, 16.90458298], [73.28013611, 16.90486145], [73.2804184, 16.90485954], [73.2804184, 16.90513992], [73.28069305, 16.90513992], [73.28069305, 16.90570068], [73.28097534, 16.90569496], [73.28097534, 16.90597153], [73.28125, 16.90596962], [73.28125, 16.90624809], [73.28206635, 16.90624809], [73.28206635, 16.90652847], [73.28263855, 16.90652847], [73.28263855, 16.90681076], [73.28291321, 16.90680504], [73.28291321, 16.90708351], [73.28320313, 16.9070797], [73.28320313, 16.90736961], [73.28347015, 16.90736961], [73.28347015, 16.90764236], [73.28375244, 16.90764236], [73.28375244, 16.90792274], [73.2840271, 16.90792274], [73.2840271, 16.90986061], [73.28375244, 16.90986061], [73.28375244, 16.9101429], [73.2840271, 16.91013908], [73.2840271, 16.91069221], [73.28430176, 16.91069221], [73.28430939, 16.91124916], [73.28430939, 16.91152954], [73.28457642, 16.91152954], [73.28457642, 16.91180992], [73.2848587, 16.91180992], [73.2848587, 16.91236115], [73.28541565, 16.91236115], [73.28541565, 16.91263962], [73.28569794, 16.91263962], [73.28569794, 16.91319466], [73.28543091, 16.9131794], [73.28543091, 16.91403008], [73.28514099, 16.91402817], [73.28514099, 16.91458321], [73.2848587, 16.91457939], [73.2848587, 16.91514015], [73.28514099, 16.91514015], [73.28514099, 16.91542053], [73.28543091, 16.91542053], [73.28543091, 16.91570091], [73.2859726, 16.91569519], [73.2859726, 16.91597176], [73.28652954, 16.91597176], [73.28652954, 16.91625023], [73.28679657, 16.91624069], [73.28679657, 16.91764069], [73.28652954, 16.91764069], [73.28652954, 16.91931152], [73.28624725, 16.91931152], [73.28624725, 16.92013931], [73.2859726, 16.92013931], [73.2859726, 16.9204216], [73.28569794, 16.92041588], [73.28569794, 16.92069435], [73.28541565, 16.92069435], [73.28541565, 16.92097282], [73.28457642, 16.92097092], [73.28457642, 16.92181015], [73.28430939, 16.92181015], [73.28430176, 16.92237282], [73.2840271, 16.92237282], [73.2840271, 16.92292023], [73.28347015, 16.92291641], [73.28347015, 16.92347145], [73.2831955, 16.92347145], [73.28320313, 16.92374992], [73.28291321, 16.92374992], [73.28291321, 16.92431068], [73.28263855, 16.92430305], [73.28263855, 16.92486382], [73.28236389, 16.92486382], [73.28236389, 16.92569542], [73.28263855, 16.92569542], [73.28263855, 16.92597389], [73.28291321, 16.92597008], [73.28291321, 16.92653084], [73.28263855, 16.92653084], [73.28263855, 16.92681122], [73.28236389, 16.9268055], [73.28236389, 16.92708588], [73.28206635, 16.92708015], [73.28206635, 16.92930984], [73.28235626, 16.92930984], [73.28235626, 16.93041992], [73.28263855, 16.93041992], [73.28263855, 16.93124962], [73.28320313, 16.93124962], [73.28320313, 16.93154144], [73.28375244, 16.93152809], [73.28375244, 16.93180466], [73.28514099, 16.93180466], [73.28514099, 16.93208313], [73.28541565, 16.93208313], [73.28541565, 16.93180466], [73.28569794, 16.93180466], [73.28569794, 16.93152809], [73.2868042, 16.93152809], [73.2868042, 16.93180466], [73.28708649, 16.93180084], [73.28708649, 16.93291855], [73.28736115, 16.93291855], [73.28736115, 16.93514252], [73.28708649, 16.9351387], [73.28708649, 16.93597031], [73.28679657, 16.93597031], [73.28679657, 16.93625259], [73.28652954, 16.93625259], [73.28652954, 16.93708229], [73.28624725, 16.93708229], [73.28624725, 16.93736076], [73.2859726, 16.93734932], [73.2859726, 16.93875122], [73.28569794, 16.93875122], [73.28569794, 16.93931007], [73.28541565, 16.93930626], [73.28541565, 16.9398613], [73.28514099, 16.93985939], [73.28514099, 16.94013977], [73.2848587, 16.94013977], [73.2848587, 16.94069672], [73.28458405, 16.94069672], [73.28458405, 16.94097137], [73.28430939, 16.94096947], [73.28430176, 16.94153023], [73.28375244, 16.94152832], [73.28375244, 16.94180679], [73.28347015, 16.94180679], [73.28347015, 16.94208336], [73.28375244, 16.94207954], [73.28375244, 16.94292068], [73.2840271, 16.94292068], [73.2840271, 16.94320107], [73.28430176, 16.94320107], [73.28430939, 16.94347954], [73.28457642, 16.94347954], [73.28457642, 16.94375038], [73.28430939, 16.94375038], [73.28430176, 16.94431114], [73.2840271, 16.94431114], [73.2840271, 16.94542122], [73.28347015, 16.9454174], [73.28347015, 16.94597244], [73.28320313, 16.94597054], [73.28320313, 16.94681168], [73.28291321, 16.94680595], [73.28291321, 16.94708252], [73.28263855, 16.94708061], [73.28263855, 16.94735909], [73.28235626, 16.94735909], [73.28235626, 16.94763947], [73.28206635, 16.94763947], [73.28206635, 16.94792175], [73.28180695, 16.94791603], [73.28180695, 16.94958115], [73.28206635, 16.94958115], [73.28206635, 16.95042038], [73.28235626, 16.95042038], [73.28235626, 16.95125008], [73.28263855, 16.95125008], [73.28263855, 16.95181084], [73.28291321, 16.95180321], [73.28291321, 16.95236015], [73.28320313, 16.95235062], [73.28320313, 16.95264053], [73.28347015, 16.95264053], [73.28347015, 16.95292091], [73.28375244, 16.9529171], [73.28375244, 16.95347214], [73.28430176, 16.95347023], [73.28430939, 16.95375061], [73.2848587, 16.95375061], [73.2848587, 16.95347023], [73.28514099, 16.95347214], [73.28514099, 16.95319557], [73.28541565, 16.95319557], [73.28541565, 16.9529171], [73.28569794, 16.95292091], [73.28569794, 16.95264053], [73.2859726, 16.95264053], [73.2859726, 16.95235062], [73.28624725, 16.95236015], [73.28624725, 16.95208549], [73.28819275, 16.95208549], [73.28819275, 16.95319557], [73.28847504, 16.95319557], [73.28847504, 16.95347214], [73.28874969, 16.95347023], [73.28874969, 16.95430946], [73.28902435, 16.95430565], [73.28902435, 16.95458412], [73.28930664, 16.95458031], [73.28930664, 16.95486069], [73.2895813, 16.95486069], [73.2895813, 16.95514107], [73.28985596, 16.95514107], [73.28985596, 16.95541954], [73.2904129, 16.95541763], [73.2904129, 16.9556942], [73.29152679, 16.95569038], [73.29152679, 16.95625114], [73.29180908, 16.95625114], [73.29180908, 16.95680809], [73.29208374, 16.95680618], [73.29208374, 16.95930481], [73.29180908, 16.95929909], [73.29180908, 16.96264267], [73.29152679, 16.96263885], [73.29152679, 16.96347046], [73.29180908, 16.96347046], [73.29180908, 16.96375275], [73.29207611, 16.96375275], [73.29207611, 16.96403122], [73.2923584, 16.9640274], [73.2923584, 16.96458244], [73.29264069, 16.96458054], [73.29264069, 16.96486282], [73.29291534, 16.96486282], [73.29291534, 16.96513939], [73.29319763, 16.96513939], [73.29319763, 16.96541977], [73.29347229, 16.96541977], [73.29347229, 16.96624947], [73.29374695, 16.96624947], [73.29374695, 16.96681023], [73.29402924, 16.96681023], [73.29402924, 16.96763992], [73.29374695, 16.96763802], [73.29374695, 16.96958351], [73.29430389, 16.96958351], [73.29430389, 16.96986198], [73.29402924, 16.96986008], [73.29402924, 16.97180748], [73.29374695, 16.97180748], [73.29374695, 16.97236061], [73.29402924, 16.97236061], [73.29402924, 16.97292137], [73.29374695, 16.97292137], [73.29374695, 16.97403145], [73.29402924, 16.97403145], [73.29402924, 16.97764015], [73.29374695, 16.97764015], [73.29374695, 16.97820091], [73.29402924, 16.97820091], [73.29402924, 16.97875023], [73.29430389, 16.97875023], [73.29430389, 16.97958565], [73.29458618, 16.97957993], [73.29458618, 16.98042107], [73.29486084, 16.98042107], [73.29486084, 16.98125076], [73.29458618, 16.98125076], [73.29458618, 16.98153114], [73.29430389, 16.98152733], [73.29430389, 16.98597145], [73.29374695, 16.98596954], [73.29374695, 16.98624992], [73.29347229, 16.98624992], [73.29347229, 16.9865284], [73.29319763, 16.9865284], [73.29319763, 16.98681068], [73.29291534, 16.98680496], [73.29291534, 16.98708344], [73.29264069, 16.98708344], [73.29264069, 16.98736191], [73.2923584, 16.98735809], [73.2923584, 16.98764229], [73.29207611, 16.98764229], [73.29207611, 16.98792267], [73.29196167, 16.98791695], [73.29152679, 16.98791695], [73.29152679, 16.9881916], [73.29125214, 16.98819542], [73.29125214, 16.98847008], [73.29069519, 16.98847008], [73.29070282, 16.98875046], [73.2904129, 16.98875046], [73.2904129, 16.98903275], [73.28457642, 16.98903275], [73.28457642, 16.98931122], [73.2840271, 16.9893055], [73.2840271, 16.98958206], [73.28375244, 16.98958015], [73.28375244, 16.98986053], [73.28336334, 16.98986053], [73.28291321, 16.98986053], [73.28291321, 16.99014282], [73.28263855, 16.99014282], [73.28263855, 16.99041939], [73.28236389, 16.99041748], [73.28236389, 16.99069214], [73.2820816, 16.99069214], [73.2820816, 16.99097443], [73.28180695, 16.99097061], [73.28180695, 16.9912529], [73.28125, 16.9912529], [73.28125, 16.99152946], [73.28069305, 16.99152946], [73.28069305, 16.99180984], [73.2804184, 16.99180412], [73.2804184, 16.9920845], [73.27986145, 16.99208069], [73.27986145, 16.99236107], [73.27791595, 16.99236107], [73.27791595, 16.99208069], [73.27680206, 16.9920845], [73.27680206, 16.99124908], [73.2765274, 16.9912529], [73.2765274, 16.99097061], [73.27625275, 16.99097443], [73.27625275, 16.99069214], [73.27597046, 16.99069214], [73.27597046, 16.99013901], [73.2756958, 16.99014282], [73.2756958, 16.98958015], [73.27513885, 16.98958206], [73.27513885, 16.98902702], [73.27485657, 16.98903275], [73.27485657, 16.98820114], [73.27458191, 16.9881916], [73.27458191, 16.98763847], [73.27485657, 16.98764229], [73.27485657, 16.98735809], [73.27458191, 16.98736191], [73.27458191, 16.9865284], [73.27430725, 16.9865284], [73.27430725, 16.98624992], [73.27375031, 16.98624992], [73.27375031, 16.98569107], [73.2720871, 16.98569489], [73.2720871, 16.98597145], [73.27179718, 16.98596954], [73.27179718, 16.98624992], [73.27153015, 16.98624992], [73.27153015, 16.9865284], [73.27097321, 16.9865284], [73.27097321, 16.98708344], [73.27069092, 16.98707962], [73.27069092, 16.98792267], [73.27041626, 16.98791695], [73.27041626, 16.98847008], [73.27012634, 16.98846054], [73.27012634, 16.98931122], [73.26985931, 16.98931122], [73.26985931, 16.98986053], [73.26847076, 16.98986053], [73.26847076, 16.99014282], [73.26819611, 16.99014282], [73.26819611, 16.99236107], [73.26847076, 16.99236107], [73.26847076, 16.99319267], [73.26875305, 16.99319077], [73.26875305, 16.99514008], [73.26790619, 16.99514008], [73.26790619, 16.99653053], [73.26819611, 16.99653053], [73.26819611, 16.99681091], [73.26847076, 16.99681091], [73.26847076, 16.99764824], [73.26875305, 16.99764824], [73.26875305, 16.99791908], [73.26902771, 16.99791908], [73.26902771, 16.99930763], [73.26957703, 16.99930763], [73.26957703, 16.99986076], [73.26930237, 16.99986076], [73.26930237, 16.99999809], [73.26930237, 17.00013924], [73.26957703, 17.00013924], [73.26957703, 17.00042152], [73.26985931, 17.00042152], [73.26985931, 17.00013924], [73.27012634, 17.00013924], [73.27012634, 16.99986076], [73.27012634, 16.99930763], [73.27041626, 16.99930763], [73.27041626, 16.99902916], [73.27097321, 16.99902916], [73.27097321, 16.99930763], [73.27153015, 16.99930573], [73.27153015, 16.9995842], [73.27179718, 16.99958038], [73.27179718, 16.99986076], [73.27320099, 16.99986076], [73.27319336, 16.9976387], [73.27430725, 16.99764824], [73.27430725, 16.99791908], [73.27541351, 16.99791718], [73.27541351, 16.99819374], [73.2756958, 16.99819374], [73.2756958, 16.99847221], [73.27625275, 16.99847221], [73.27625275, 16.9995842], [73.27680206, 16.99958038], [73.27680206, 16.99986076], [73.27708435, 16.99986076], [73.27708435, 17.00097275], [73.2776413, 17.00097084], [73.2776413, 17.00124931], [73.27791595, 17.00124931], [73.27791595, 17.00069046], [73.27819061, 17.00069427], [73.27819824, 17.0004158], [73.28013611, 17.0004158], [73.28013611, 17.00069427], [73.28097534, 17.00069427], [73.28097534, 17.00097275], [73.28291321, 17.00097084], [73.28291321, 17.0015316], [73.28320313, 17.0015316], [73.28320313, 17.00181007], [73.28347015, 17.00180626], [73.28347015, 17.00208282], [73.28375244, 17.00208092], [73.28375244, 17.00403023], [73.2831955, 17.00402832], [73.2831955, 17.00458145], [73.28375244, 17.00457954], [73.28375244, 17.0051403], [73.28347015, 17.0051403], [73.28347015, 17.00542068], [73.28375244, 17.00542068], [73.28375244, 17.00625038], [73.2840271, 17.00625038], [73.2840271, 17.00819588], [73.28430176, 17.00819588], [73.28430176, 17.0106945], [73.2840271, 17.01069069], [73.2840271, 17.01124954], [73.28375244, 17.01124954], [73.28375244, 17.01208305], [73.28347015, 17.01208305], [73.28347015, 17.01263809], [73.28320313, 17.01263046], [73.28320313, 17.01320076], [73.28291321, 17.01320076], [73.28291321, 17.01374817], [73.28263855, 17.01374817], [73.28263855, 17.01402855], [73.28236389, 17.01402855], [73.28236389, 17.01458359], [73.2820816, 17.01458359], [73.2820816, 17.01486015], [73.28180695, 17.01486015], [73.28180695, 17.01625061], [73.28125, 17.01625061], [73.28125, 17.01680946], [73.28097534, 17.01680565], [73.28098297, 17.01736069], [73.28069305, 17.01736069], [73.28069305, 17.01756287], [73.28069305, 17.01763916], [73.2804184, 17.01763916], [73.2804184, 17.01819229], [73.28013611, 17.01819229], [73.28013611, 17.01847458], [73.27986145, 17.01847076], [73.27986145, 17.01876068], [73.27958679, 17.01876068], [73.27958679, 17.01931], [73.2793045, 17.01930618], [73.2793045, 17.01958466], [73.27902985, 17.01958084], [73.27902985, 17.01986122], [73.27874756, 17.01986122], [73.27874756, 17.02042007], [73.2784729, 17.02041435], [73.2784729, 17.0209713], [73.27819824, 17.02096939], [73.27819824, 17.02124977], [73.27791595, 17.02124977], [73.27791595, 17.02153015], [73.2776413, 17.02152824], [73.2776413, 17.02208328], [73.27735901, 17.02208328], [73.27735901, 17.02236176], [73.27707672, 17.02235985], [73.27707672, 17.02292061], [73.2765274, 17.02292061], [73.2765274, 17.02320099], [73.27625275, 17.02319527], [73.27625275, 17.02347183], [73.27458191, 17.02346992], [73.27458191, 17.02375031], [73.27347565, 17.02375031], [73.27347565, 17.02347183], [73.2729187, 17.02347183], [73.2729187, 17.02319527], [73.27263641, 17.02320099], [73.27263641, 17.02292061], [73.27236176, 17.02292061], [73.27236176, 17.02264023], [73.27124786, 17.02264023], [73.27124786, 17.02292061], [73.27153015, 17.02292061], [73.27153015, 17.02375031], [73.27124786, 17.02375031], [73.27124786, 17.02431107], [73.27069092, 17.02430534], [73.26902771, 17.02430534], [73.26902771, 17.02458382], [73.26652527, 17.02458382], [73.26652527, 17.02347183], [73.26625061, 17.02347183], [73.26625061, 17.02236176], [73.26597595, 17.02236176], [73.26597595, 17.02208328], [73.26569366, 17.02208328], [73.26569366, 17.02180672], [73.26541901, 17.02180672], [73.26541901, 17.02152824], [73.26513672, 17.02153015], [73.26513672, 17.02124977], [73.26486206, 17.02124977], [73.26486206, 17.02069092], [73.26457977, 17.02069664], [73.26457977, 17.02041435], [73.26291656, 17.02041435], [73.26291656, 17.02069664], [73.26235962, 17.02069664], [73.26235962, 17.0209713], [73.26097107, 17.0209713], [73.26097107, 17.02069664], [73.26041412, 17.02069664], [73.26041412, 17.02041435], [73.26013947, 17.02042007], [73.26013947, 17.02013969], [73.25958252, 17.02013969], [73.25958252, 17.01986122], [73.25875092, 17.01986122], [73.25875092, 17.01958084], [73.25736237, 17.01958084], [73.25736237, 17.02042007], [73.25708008, 17.02041435], [73.25708008, 17.0209713], [73.25681305, 17.02096939], [73.25681305, 17.02153015], [73.25653076, 17.02152824], [73.25653076, 17.02180672], [73.25624847, 17.02180672], [73.25624847, 17.02347183], [73.25596619, 17.02346992], [73.25596619, 17.02375031], [73.25569153, 17.02375031], [73.25569153, 17.02541924], [73.25541687, 17.02541733], [73.25541687, 17.02597237], [73.25512695, 17.02597046], [73.25512695, 17.02625084], [73.25485992, 17.02625084], [73.25485992, 17.02652931], [73.25458527, 17.0265274], [73.25458527, 17.02708244], [73.25430298, 17.02708054], [73.25430298, 17.02736092], [73.2545929, 17.02736092], [73.2545929, 17.02792168], [73.25514221, 17.02791595], [73.25514221, 17.0284729], [73.25541687, 17.02846909], [73.25541687, 17.02874947], [73.25569153, 17.02874947], [73.25569153, 17.02958107], [73.25596619, 17.02958107], [73.25596619, 17.0304203], [73.25624847, 17.03041649], [73.25624847, 17.03097153], [73.25653076, 17.03096962], [73.25653076, 17.03181076], [73.25681305, 17.03181076], [73.25681305, 17.03153038], [73.25736237, 17.03153038], [73.25736237, 17.03181076], [73.25763702, 17.03180313], [73.25763702, 17.0331955], [73.25736237, 17.03318977], [73.25736237, 17.03376007], [73.25763702, 17.03376007], [73.25763702, 17.03652954], [73.25736237, 17.03652954], [73.25736237, 17.03736115], [73.25708008, 17.03736115], [73.25708008, 17.03763962], [73.25680542, 17.03763962], [73.25680542, 17.03819466], [73.25708008, 17.03819466], [73.25708008, 17.03986168], [73.25681305, 17.03985977], [73.25681305, 17.04013824], [73.25653076, 17.04013824], [73.25653076, 17.04070091], [73.25624847, 17.04070091], [73.25624847, 17.04125023], [73.25569153, 17.04125023], [73.25569153, 17.0429306], [73.25541687, 17.0429306], [73.25541687, 17.04486084], [73.25569153, 17.04486084], [73.25569153, 17.04541969], [73.25596619, 17.04541969], [73.25596619, 17.04652977], [73.25569153, 17.04652786], [73.25569153, 17.04736137], [73.25596619, 17.04735947], [73.25596619, 17.04792023], [73.25624847, 17.04791641], [73.25624847, 17.04819679], [73.25653076, 17.04819679], [73.25653076, 17.04847145], [73.25680542, 17.04847145], [73.25680542, 17.04874992], [73.25791931, 17.04874992], [73.25791931, 17.04847145], [73.25846863, 17.04847145], [73.25846863, 17.04874992], [73.26041412, 17.04874992], [73.26041412, 17.04847145], [73.26152802, 17.04847145], [73.26152802, 17.04874992], [73.26180267, 17.04874039], [73.26180267, 17.0490303], [73.26209259, 17.0490303], [73.26209259, 17.04874039], [73.26347351, 17.04874992], [73.26347351, 17.04847145], [73.26403046, 17.04847145], [73.26403046, 17.04819679], [73.26457977, 17.04819679], [73.26457977, 17.04791641], [73.26541901, 17.04792023], [73.26541901, 17.04763985], [73.26597595, 17.04763985], [73.26597595, 17.04681015], [73.2665329, 17.04681015], [73.2665329, 17.04570007], [73.26680756, 17.04570007], [73.26680756, 17.04541969], [73.26706696, 17.04541969], [73.26706696, 17.04514122], [73.26790619, 17.04514122], [73.26790619, 17.04541969], [73.26847076, 17.04541969], [73.26847076, 17.04458046], [73.26875305, 17.04458237], [73.26875305, 17.04402733], [73.26902771, 17.04403114], [73.26902771, 17.04375267], [73.26930237, 17.04375267], [73.26930237, 17.04347038], [73.26985931, 17.04347038], [73.26985931, 17.04330063], [73.26985931, 17.04291725], [73.26957703, 17.0429306], [73.26957703, 17.04236031], [73.26930237, 17.04236031], [73.26930237, 17.04125023], [73.26902771, 17.04125023], [73.26902771, 17.04070091], [73.27012634, 17.04070091], [73.27012634, 17.03985977], [73.26958466, 17.03986168], [73.26958466, 17.03930473], [73.26985931, 17.03930473], [73.26985931, 17.03874969], [73.27070618, 17.03874969], [73.27179718, 17.03874969], [73.27179718, 17.03902817], [73.2720871, 17.03902817], [73.2720871, 17.03958321], [73.27263641, 17.03958321], [73.27263641, 17.03930473], [73.27319336, 17.03930473], [73.27319336, 17.03902817], [73.27349091, 17.03902817], [73.27349091, 17.03847122], [73.27375031, 17.03847313], [73.27375031, 17.03791618], [73.27403259, 17.03791809], [73.27403259, 17.03763962], [73.27430725, 17.03763962], [73.27430725, 17.03736115], [73.27485657, 17.03736115], [73.27485657, 17.03708076], [73.27513885, 17.03708267], [73.27513885, 17.03652763], [73.27540588, 17.03652954], [73.27540588, 17.03625107], [73.2756958, 17.03625107], [73.2756958, 17.03597069], [73.27597046, 17.0359726], [73.27597046, 17.03569412], [73.27625275, 17.03569412], [73.27625275, 17.03513908], [73.2765274, 17.03514099], [73.2765274, 17.03430939], [73.27680206, 17.03430939], [73.27680206, 17.03403091], [73.2776413, 17.03403091], [73.2776413, 17.03292084], [73.27791595, 17.03292084], [73.27791595, 17.0320797], [73.2776413, 17.03208542], [73.2776413, 17.02986145], [73.27735901, 17.02986145], [73.27735901, 17.02930641], [73.27707672, 17.02931023], [73.27707672, 17.02903175], [73.27680206, 17.02903175], [73.27680206, 17.02874947], [73.2765274, 17.02874947], [73.2765274, 17.02792168], [73.2756958, 17.02792168], [73.2756958, 17.02597046], [73.27541351, 17.02597237], [73.27541351, 17.02541733], [73.2756958, 17.02541924], [73.2756958, 17.02514076], [73.2765274, 17.02514076], [73.2765274, 17.02486038], [73.27680206, 17.02486038], [73.27680206, 17.02457047], [73.27708435, 17.02458382], [73.27708435, 17.02430534], [73.27735901, 17.02431107], [73.27735901, 17.02403069], [73.27791595, 17.02403069], [73.27791595, 17.02375031], [73.27819061, 17.02375031], [73.27819824, 17.02346992], [73.27874756, 17.02347183], [73.27874756, 17.02319527], [73.27902985, 17.02320099], [73.27902985, 17.02235985], [73.2793045, 17.02236176], [73.2793045, 17.02152824], [73.27986145, 17.02153015], [73.27986145, 17.02124977], [73.28013611, 17.02124977], [73.28013611, 17.02069092], [73.28097534, 17.02069664], [73.28097534, 17.02041435], [73.28125, 17.02042007], [73.28125, 17.01958084], [73.28152466, 17.01958466], [73.28152466, 17.01930618], [73.28180695, 17.01931], [73.28180695, 17.01876068], [73.28206635, 17.01876068], [73.28206635, 17.01848984], [73.28235626, 17.01847076], [73.28236389, 17.01819229], [73.28263855, 17.01819229], [73.28263855, 17.01791573], [73.28347015, 17.01791954], [73.28347015, 17.01876068], [73.28430176, 17.01876068], [73.28430939, 17.01902962], [73.28458405, 17.01902771], [73.28458405, 17.01958466], [73.2848587, 17.01958084], [73.2848587, 17.01986122], [73.2859726, 17.01986122], [73.2859726, 17.02013969], [73.28679657, 17.02013969], [73.28679657, 17.02042007], [73.28652954, 17.02041435], [73.28652954, 17.02069664], [73.2868042, 17.02069664], [73.2868042, 17.02095985], [73.28679657, 17.02124977], [73.28708649, 17.02124977], [73.28708649, 17.02153015], [73.28819275, 17.02152824], [73.28819275, 17.02180672], [73.28986359, 17.02180672], [73.28986359, 17.0209713], [73.2895813, 17.0209713], [73.2895813, 17.02013969], [73.28930664, 17.02013969], [73.28930664, 17.01986122], [73.28874969, 17.01986122], [73.28874969, 17.01958084], [73.28847504, 17.01958466], [73.28847504, 17.01847458], [73.2876358, 17.01847458], [73.2876358, 17.01819229], [73.28736115, 17.01819229], [73.28736115, 17.01791763], [73.28624725, 17.01791954], [73.28624725, 17.01736069], [73.28679657, 17.01736069], [73.28679657, 17.01680946], [73.28736115, 17.01680565], [73.28736115, 17.01708221], [73.28791809, 17.01708221], [73.28791809, 17.01680565], [73.2876358, 17.01680946], [73.2876358, 17.01625061], [73.28736115, 17.01625061], [73.28736115, 17.01597023], [73.2876358, 17.01597023], [73.2876358, 17.0154171], [73.28679657, 17.01542282], [73.28679657, 17.01486015], [73.28652954, 17.01486015], [73.28652954, 17.01180649], [73.28624725, 17.0118084], [73.28624725, 17.00930977], [73.28679657, 17.00930977], [73.28679657, 17.00902939], [73.28736115, 17.00902939], [73.28736115, 17.00875092], [73.2876358, 17.00875092], [73.2876358, 17.00819016], [73.28791809, 17.00819588], [73.28791809, 17.00763893], [73.28820038, 17.00764084], [73.28820038, 17.00708008], [73.28847504, 17.0070858], [73.28847504, 17.00680351], [73.28930664, 17.00682068], [73.28930664, 17.00875092], [73.28901672, 17.00875092], [73.28901672, 17.00902939], [73.28874969, 17.00902939], [73.28874969, 17.00930977], [73.2884903, 17.00930977], [73.2884903, 17.00959015], [73.28874969, 17.00959015], [73.28874969, 17.01013947], [73.28985596, 17.01013947], [73.28985596, 17.01041985], [73.29013824, 17.01041794], [73.29013824, 17.0106945], [73.28930664, 17.0106945], [73.28930664, 17.01097298], [73.28847504, 17.01097298], [73.28847504, 17.01263809], [73.28874969, 17.01263046], [73.28874969, 17.01291847], [73.28901672, 17.01291847], [73.28901672, 17.01374817], [73.28930664, 17.01374817], [73.28930664, 17.01402855], [73.2895813, 17.01402855], [73.2895813, 17.01458359], [73.28985596, 17.01458168], [73.28985596, 17.01514244], [73.29013824, 17.01514244], [73.29013824, 17.01542282], [73.2904129, 17.0154171], [73.2904129, 17.01597023], [73.29069519, 17.01597023], [73.29070282, 17.01625061], [73.2904129, 17.01625061], [73.2904129, 17.01680946], [73.29069519, 17.01680565], [73.29070282, 17.01733017], [73.29070282, 17.01764107], [73.29096985, 17.01764107], [73.29096985, 17.01902962], [73.29123688, 17.01902962], [73.29123688, 17.01931], [73.29152679, 17.01930618], [73.29152679, 17.01958466], [73.29264069, 17.01958084], [73.29264069, 17.01986122], [73.29292297, 17.01986122], [73.29292297, 17.02042007], [73.29319763, 17.02041435], [73.29319763, 17.02069664], [73.29264069, 17.02069664], [73.29264069, 17.0209713], [73.29291534, 17.0209713], [73.29291534, 17.02208328], [73.29319763, 17.02207947], [73.29319763, 17.02264023], [73.29292297, 17.02264023], [73.29292297, 17.02292061], [73.29264069, 17.02291679], [73.29264069, 17.02347183], [73.2923584, 17.02346992], [73.2923584, 17.02403069], [73.29208374, 17.02402878], [73.29208374, 17.02458382], [73.29180908, 17.02457047], [73.29180908, 17.02486038], [73.29152679, 17.02486038], [73.29152679, 17.02514076], [73.29123688, 17.02514076], [73.29123688, 17.02541924], [73.29069519, 17.02541733], [73.29069519, 17.02569389], [73.29013824, 17.02569389], [73.29013824, 17.02597237], [73.28985596, 17.02597046], [73.28985596, 17.02625084], [73.28930664, 17.02625084], [73.28930664, 17.02763939], [73.28901672, 17.02762985], [73.28901672, 17.02792168], [73.28874969, 17.02791595], [73.28874969, 17.0284729], [73.2884903, 17.02846909], [73.2884903, 17.02931023], [73.28708649, 17.02930641], [73.28708649, 17.02958107], [73.2859726, 17.02958107], [73.2859726, 17.02986145], [73.2848587, 17.02985954], [73.2848587, 17.03014183], [73.28375244, 17.03014183], [73.28375244, 17.0304203], [73.28347015, 17.0304203], [73.28347015, 17.03070068], [73.2831955, 17.03069305], [73.2831955, 17.03097153], [73.28291321, 17.03096962], [73.28291321, 17.03125], [73.28180695, 17.03125], [73.28180695, 17.03153038], [73.28125, 17.03153038], [73.28125, 17.03181076], [73.28097534, 17.03180313], [73.28097534, 17.03208542], [73.2804184, 17.0320797], [73.2804184, 17.03292084], [73.28069305, 17.03292084], [73.28069305, 17.03376007], [73.2804184, 17.03376007], [73.2804184, 17.03430939], [73.28069305, 17.03430939], [73.28069305, 17.03486061], [73.28125, 17.03486061], [73.28125, 17.03514099], [73.28180695, 17.03514099], [73.28180695, 17.03541946], [73.2820816, 17.03541756], [73.2820816, 17.03569412], [73.28263855, 17.03569412], [73.28263855, 17.0359726], [73.28291321, 17.03597069], [73.28291321, 17.03625107], [73.28320313, 17.03625107], [73.28320313, 17.03652954], [73.28347015, 17.03652763], [73.28347015, 17.03680611], [73.28375244, 17.03680038], [73.28375244, 17.03736115], [73.2840271, 17.03736115], [73.2840271, 17.03874969], [73.28430176, 17.03874969], [73.28430939, 17.04013824], [73.2848587, 17.04013824], [73.2848587, 17.04041862], [73.28514099, 17.04041672], [73.28515625, 17.04062653], [73.28541565, 17.04069519], [73.28541565, 17.04097176], [73.28624725, 17.04097176], [73.28624725, 17.04069519], [73.28708649, 17.04070091], [73.28708649, 17.04041862], [73.2876358, 17.04041862], [73.2876358, 17.04013824], [73.28820038, 17.04013824], [73.28820038, 17.03956985], [73.28791809, 17.03958321], [73.28791809, 17.03902817], [73.2876358, 17.03902817], [73.2876358, 17.03874969], [73.28736115, 17.03874969], [73.28736115, 17.03902817], [73.28708649, 17.03902817], [73.28708649, 17.03930473], [73.28662109, 17.03930473], [73.28514099, 17.03930473], [73.28514099, 17.03791618], [73.28736115, 17.03791809], [73.28736115, 17.03763962], [73.2876358, 17.03763962], [73.2876358, 17.03736115], [73.28847504, 17.03736115], [73.28847504, 17.03837967], [73.28847504, 17.03874969], [73.28930664, 17.03874969], [73.28930664, 17.03902817], [73.2904129, 17.03902817], [73.2904129, 17.03847122], [73.29069519, 17.03847313], [73.29069519, 17.03791618], [73.29096985, 17.03791809], [73.29096985, 17.03708076], [73.29069519, 17.03708267], [73.29069519, 17.03680611], [73.29208374, 17.03680611], [73.29208374, 17.03708267], [73.29220581, 17.03708267], [73.2923584, 17.03708076], [73.2923584, 17.03736115], [73.29216766, 17.03736115], [73.29180908, 17.03736115], [73.29180908, 17.03819466], [73.29207611, 17.03819084], [73.29207611, 17.03902817], [73.29152679, 17.03902817], [73.29152679, 17.03930473], [73.29125214, 17.03930473], [73.29125214, 17.03958321], [73.29152679, 17.03958321], [73.29152679, 17.03986168], [73.29374695, 17.03986168], [73.29374695, 17.03902817], [73.29402924, 17.03902817], [73.29402924, 17.03847122], [73.29486084, 17.03847122], [73.29486084, 17.03902817], [73.29458618, 17.03902817], [73.29458618, 17.03958321], [73.29430389, 17.03958321], [73.29430389, 17.03986168], [73.29569244, 17.03986168], [73.29569244, 17.03930473], [73.29597473, 17.03930473], [73.29597473, 17.03902817], [73.29624939, 17.03902817], [73.29624939, 17.03874969], [73.29651642, 17.03874969], [73.29651642, 17.03847122], [73.29680634, 17.03847313], [73.29680634, 17.03819466], [73.29708099, 17.03819466], [73.29708099, 17.03791618], [73.29818726, 17.03791809], [73.29818726, 17.03763962], [73.29792023, 17.03763962], [73.29792023, 17.03736115], [73.29846954, 17.03736115], [73.29846954, 17.03708076], [73.29902649, 17.03708267], [73.29902649, 17.03680611], [73.29930878, 17.03680611], [73.29930878, 17.03652763], [73.29985809, 17.03652954], [73.29985809, 17.03625107], [73.3004303, 17.03625107], [73.3004303, 17.03597069], [73.30097198, 17.0359726], [73.30097198, 17.03569412], [73.30152893, 17.03569412], [73.30152893, 17.03541756], [73.30208588, 17.03541946], [73.30208588, 17.03514099], [73.30264282, 17.03514099], [73.30264282, 17.03486061], [73.30319214, 17.03486061], [73.30317688, 17.03458023], [73.30403137, 17.03458595], [73.30403137, 17.03430557], [73.30486298, 17.03430939], [73.30486298, 17.03403091], [73.30680847, 17.03403091], [73.30680847, 17.03430939], [73.30708313, 17.03430557], [73.30708313, 17.03458595], [73.3079071, 17.03458023], [73.3079071, 17.03486061], [73.30819702, 17.03486061], [73.30819702, 17.03514099], [73.30902863, 17.03514099], [73.30902863, 17.03486061], [73.30931091, 17.03486061], [73.30931091, 17.03514099], [73.3095932, 17.03514099], [73.3095932, 17.03486061], [73.31069183, 17.03486061], [73.31069183, 17.03458023], [73.31180573, 17.03458595], [73.31180573, 17.03430557], [73.3119812, 17.03430748], [73.3123703, 17.03430939], [73.3123703, 17.03403091], [73.31263733, 17.03403091], [73.31263733, 17.03376007], [73.31318665, 17.03376007], [73.31318665, 17.03347015], [73.31375122, 17.03347206], [73.31375122, 17.0331955], [73.31513977, 17.0331955], [73.31513977, 17.03347206], [73.31569672, 17.03347015], [73.31569672, 17.03376007], [73.31624603, 17.03376007], [73.31624603, 17.03403091], [73.31652832, 17.03403091], [73.31652832, 17.03430939], [73.31597137, 17.03430557], [73.31597137, 17.03458595], [73.31569672, 17.03458023], [73.31569672, 17.03486061], [73.31625366, 17.03486061], [73.31625366, 17.03513908], [73.31652832, 17.03513908], [73.31652832, 17.03569412], [73.31485748, 17.03569412], [73.31485748, 17.0359726], [73.31430817, 17.03597069], [73.31430817, 17.03625107], [73.31402588, 17.03625107], [73.31402588, 17.03652954], [73.31346893, 17.03652954], [73.31346893, 17.03763962], [73.31375122, 17.03763962], [73.31375122, 17.03791809], [73.31458282, 17.03791809], [73.31458282, 17.03763962], [73.3154068, 17.03763962], [73.3154068, 17.03736115], [73.31569672, 17.03736115], [73.31569672, 17.03680038], [73.31513977, 17.03680611], [73.31513977, 17.03652763], [73.3154068, 17.03652954], [73.3154068, 17.03625107], [73.31597137, 17.03625107], [73.31597137, 17.03652954], [73.31652832, 17.03652763], [73.31652832, 17.03680611], [73.31708527, 17.03680611], [73.31708527, 17.03624916], [73.31735992, 17.03625107], [73.31735992, 17.03597069], [73.31791687, 17.0359726], [73.31791687, 17.03541756], [73.31958008, 17.03541756], [73.31958008, 17.03569412], [73.31930542, 17.03569412], [73.31930542, 17.0359726], [73.31817627, 17.03597069], [73.31817627, 17.03652954], [73.31847382, 17.03652763], [73.31847382, 17.03708267], [73.31874847, 17.03708076], [73.31874847, 17.03763962], [73.31986237, 17.03763962], [73.31986237, 17.03819466], [73.31847382, 17.03819466], [73.31847382, 17.03791618], [73.3170929, 17.03791809], [73.3170929, 17.03763962], [73.31652832, 17.03763962], [73.31652832, 17.03819466], [73.31708527, 17.03819466], [73.31708527, 17.03847313], [73.31735992, 17.03847122], [73.31735992, 17.03874969], [73.31708527, 17.03874969], [73.31708527, 17.03930473], [73.31680298, 17.03930473], [73.31680298, 17.03958321], [73.31597137, 17.03958321], [73.31597137, 17.03930473], [73.31569672, 17.03930473], [73.31569672, 17.03958321], [73.31541443, 17.03958321], [73.31541443, 17.03986168], [73.31485748, 17.03986168], [73.31485748, 17.03958321], [73.31458282, 17.03958321], [73.31458282, 17.03930473], [73.31430817, 17.03930473], [73.31430817, 17.03902817], [73.31263733, 17.03902817], [73.31263733, 17.03874969], [73.31180573, 17.03874969], [73.31180573, 17.03847313], [73.31153107, 17.03847313], [73.31153107, 17.03819466], [73.31124878, 17.03819466], [73.31124878, 17.03763962], [73.31014252, 17.03763962], [73.31014252, 17.03736115], [73.30930328, 17.03736115], [73.30930328, 17.03708267], [73.30708313, 17.03708267], [73.30708313, 17.03680611], [73.30569458, 17.03680611], [73.30569458, 17.03708267], [73.30513763, 17.03708076], [73.30513763, 17.03736115], [73.30263519, 17.03736115], [73.30263519, 17.03763962], [73.30291748, 17.03763962], [73.30291748, 17.03791809], [73.30319214, 17.03791618], [73.30319214, 17.03819466], [73.30374908, 17.03819466], [73.30374908, 17.03847313], [73.30403137, 17.03847122], [73.30403137, 17.03902817], [73.30374908, 17.03902817], [73.30374908, 17.03930473], [73.30347443, 17.03930473], [73.30347443, 17.03958321], [73.30263519, 17.03958321], [73.30263519, 17.03986168], [73.30179596, 17.03985977], [73.30179596, 17.04013824], [73.3004303, 17.04013824], [73.3004303, 17.04041862], [73.29875183, 17.04041862], [73.29875183, 17.04070091], [73.29819489, 17.04069519], [73.29819489, 17.04097176], [73.29792023, 17.04096985], [73.29792023, 17.04125023], [73.29763794, 17.04125023], [73.29763794, 17.0418129], [73.29736328, 17.04180527], [73.29736328, 17.04208374], [73.29708099, 17.04208183], [73.29708099, 17.04236031], [73.29680634, 17.04236031], [73.29680634, 17.0429306], [73.29652405, 17.04291725], [73.29652405, 17.04319382], [73.29624939, 17.04319382], [73.29624939, 17.04347038], [73.29541779, 17.04347038], [73.29541779, 17.04375267], [73.29514313, 17.04375267], [73.29514313, 17.04430962], [73.29486084, 17.0443058], [73.29486084, 17.04458237], [73.28902435, 17.04458237], [73.28902435, 17.0443058], [73.28874969, 17.04430962], [73.28874969, 17.04403114], [73.2876358, 17.04403114], [73.2876358, 17.04430962], [73.28736115, 17.0443058], [73.28736115, 17.04458237], [73.28708649, 17.04458046], [73.28708649, 17.04514122], [73.28736115, 17.04514122], [73.28736115, 17.04541969], [73.2876358, 17.04541969], [73.2876358, 17.04570007], [73.28791809, 17.04569244], [73.28791809, 17.04597473], [73.28819275, 17.04597473], [73.28819275, 17.04624939], [73.2884903, 17.04624939], [73.2884903, 17.04652977], [73.29070282, 17.04652977], [73.29070282, 17.04681015], [73.29125214, 17.04680634], [73.29125214, 17.04708481], [73.29152679, 17.04708481], [73.29152679, 17.04736137], [73.29013824, 17.04735947], [73.29013824, 17.04763985], [73.2884903, 17.04763985], [73.2884903, 17.04735947], [73.2876358, 17.04736137], [73.2876358, 17.04680634], [73.28736115, 17.04681015], [73.28736115, 17.04624939], [73.28708649, 17.04624939], [73.28708649, 17.04570007], [73.28624725, 17.04570007], [73.28624725, 17.04541969], [73.28569794, 17.04541969], [73.28569794, 17.04514122], [73.28514099, 17.04514122], [73.28514099, 17.04458046], [73.28458405, 17.04458237], [73.28458405, 17.0443058], [73.28430176, 17.04430962], [73.28430176, 17.04403114], [73.2840271, 17.04403114], [73.2840271, 17.04375267], [73.28375244, 17.04375267], [73.28375244, 17.04347038], [73.28347015, 17.04347038], [73.28347015, 17.04319382], [73.28291321, 17.04319382], [73.28291321, 17.04291725], [73.28263855, 17.0429306], [73.28263855, 17.04264259], [73.28235626, 17.04264259], [73.28235626, 17.04236031], [73.28206635, 17.04236031], [73.28206635, 17.0418129], [73.28180695, 17.0418129], [73.28180695, 17.04153252], [73.28151703, 17.04153252], [73.28151703, 17.04125023], [73.28125, 17.04125023], [73.28125, 17.04096985], [73.28097534, 17.04097176], [73.28097534, 17.04069519], [73.28069305, 17.04070091], [73.28069305, 17.04041862], [73.2804184, 17.04041862], [73.2804184, 17.03985977], [73.28013611, 17.03986168], [73.28013611, 17.03958321], [73.27986145, 17.03958321], [73.27986145, 17.03930473], [73.27958679, 17.03930473], [73.27958679, 17.03958321], [73.2793045, 17.03958321], [73.2793045, 17.03986168], [73.27902985, 17.03985977], [73.27902985, 17.04013824], [73.27874756, 17.04013824], [73.27874756, 17.04041862], [73.2784729, 17.04041862], [73.2784729, 17.04070091], [73.27874756, 17.04070091], [73.27874756, 17.04125023], [73.27929688, 17.04125023], [73.27929688, 17.04153252], [73.27958679, 17.04153252], [73.27958679, 17.0418129], [73.27986145, 17.04180527], [73.27986145, 17.04208374], [73.28013611, 17.04208183], [73.28013611, 17.04236031], [73.2804184, 17.04236031], [73.2804184, 17.04264259], [73.28069305, 17.04263878], [73.28069305, 17.04319382], [73.28097534, 17.04319382], [73.28097534, 17.04375267], [73.28125, 17.04375267], [73.28125, 17.04403114], [73.28140259, 17.04403114], [73.28180695, 17.04403114], [73.28180695, 17.04430962], [73.28206635, 17.04430962], [73.28206635, 17.04486084], [73.28235626, 17.04486084], [73.28235626, 17.04541969], [73.28263855, 17.04541588], [73.28263855, 17.04597473], [73.28291321, 17.04597092], [73.28291321, 17.04624939], [73.28320313, 17.04624939], [73.28320313, 17.04652977], [73.28347015, 17.04652977], [73.28347015, 17.04681015], [73.28375244, 17.04680634], [73.28375244, 17.04736137], [73.2840271, 17.04735947], [73.2840271, 17.04763985], [73.28430176, 17.04763985], [73.28430939, 17.04792023], [73.28458405, 17.04791641], [73.28458405, 17.04819679], [73.2848587, 17.04819679], [73.2848587, 17.04874992], [73.28514099, 17.04874039], [73.28514099, 17.04931068], [73.28541565, 17.04930687], [73.28541565, 17.04986191], [73.28569794, 17.04986], [73.28569794, 17.05042076], [73.2859726, 17.05041885], [73.2859726, 17.05097198], [73.28624725, 17.05097008], [73.28624725, 17.05125046], [73.28652954, 17.05125046], [73.28652954, 17.0518055], [73.28679657, 17.05179977], [73.28679657, 17.05236053], [73.28708649, 17.05236053], [73.28708649, 17.0529213], [73.28736115, 17.05291748], [73.28736115, 17.05347252], [73.2876358, 17.05347061], [73.2876358, 17.05431175], [73.28791809, 17.05431175], [73.28791809, 17.05653191], [73.28820038, 17.05653191], [73.28820038, 17.05792999], [73.28847504, 17.05791664], [73.28847504, 17.06347275], [73.28820038, 17.06347084], [73.28820038, 17.06652832], [73.28791809, 17.06652832], [73.28791809, 17.07042122], [73.28819275, 17.0704174], [73.28819275, 17.0731926], [73.28791809, 17.0731926], [73.28791809, 17.07347488], [73.28820038, 17.07347107], [73.28820038, 17.07542038], [73.28874969, 17.07542038], [73.28874969, 17.07570076], [73.28930664, 17.07569695], [73.28930664, 17.0759716], [73.2895813, 17.0759697], [73.2895813, 17.07653046], [73.28985596, 17.07653046], [73.28985596, 17.07681084], [73.29013824, 17.07681084], [73.29013824, 17.07736015], [73.29096985, 17.07736015], [73.29096985, 17.07707977], [73.29125214, 17.07708359], [73.29125214, 17.07680511], [73.29180908, 17.07681084], [73.29180908, 17.07653046], [73.29319763, 17.07653046], [73.29319763, 17.07625008], [73.29347229, 17.07625008], [73.29347229, 17.0759697], [73.29402924, 17.0759716], [73.29402924, 17.07569695], [73.29597473, 17.07569695], [73.29597473, 17.07708359], [73.29680634, 17.07708359], [73.29680634, 17.07652855], [73.29708099, 17.07653046], [73.29708099, 17.07625008], [73.29737091, 17.07625008], [73.29736328, 17.07569695], [73.29763794, 17.07570076], [73.29763794, 17.07514], [73.29792023, 17.07514], [73.29792023, 17.07485962], [73.29846954, 17.07485962], [73.29846954, 17.07514], [73.29875183, 17.07514], [73.29875183, 17.07570076], [73.29846954, 17.07570076], [73.29846954, 17.07625008], [73.29819489, 17.07625008], [73.29819489, 17.07847214], [73.29792023, 17.07847023], [73.29792023, 17.07875061], [73.29680634, 17.07875061], [73.29680634, 17.07847023], [73.29597473, 17.07847214], [73.29597473, 17.07819366], [73.29569244, 17.07819366], [73.29569244, 17.07847214], [73.29152679, 17.07847214], [73.29152679, 17.07819366], [73.29096985, 17.07819366], [73.29096985, 17.0779171], [73.2904129, 17.0779171], [73.2904129, 17.07819366], [73.2876358, 17.07819366], [73.2876358, 17.07847214], [73.28679657, 17.07847023], [73.28679657, 17.07875061], [73.28514099, 17.07875061], [73.28514099, 17.07902908], [73.2840271, 17.07902908], [73.2840271, 17.07930756], [73.28375244, 17.07930565], [73.28375244, 17.07958412], [73.28320313, 17.07958031], [73.28320313, 17.08042145], [73.28291321, 17.08041763], [73.28291321, 17.0806942], [73.2831955, 17.0806942], [73.2831955, 17.08097267], [73.28347015, 17.08097076], [73.28347015, 17.08124924], [73.28375244, 17.08124924], [73.28375244, 17.08152962], [73.2840271, 17.08152962], [73.2840271, 17.0818119], [73.28430176, 17.08180618], [73.28430939, 17.08208275], [73.28457642, 17.08208084], [73.28457642, 17.08235931], [73.28514099, 17.08235931], [73.28514099, 17.08292007], [73.28541565, 17.08291626], [73.28541565, 17.08319473], [73.28569794, 17.08319473], [73.28569794, 17.08430481], [73.2859726, 17.08430481], [73.2859726, 17.08458138], [73.28543091, 17.08457947], [73.28543091, 17.08542061], [73.28569794, 17.08541679], [73.28569794, 17.08597374], [73.2859726, 17.08596992], [73.2859726, 17.08681107], [73.28624725, 17.08680344], [73.28624725, 17.08708572], [73.2859726, 17.08708], [73.2859726, 17.08764076], [73.28569794, 17.08763885], [73.28569794, 17.0881958], [73.28541565, 17.0881958], [73.28543091, 17.08986092], [73.28514099, 17.08986092], [73.28514099, 17.09013939], [73.2848587, 17.09013939], [73.2848587, 17.09041977], [73.28458405, 17.09041786], [73.28458405, 17.0909729], [73.2848587, 17.0909729], [73.2848587, 17.09236145], [73.28457642, 17.09235954], [73.28457642, 17.09542274], [73.28430939, 17.09541702], [73.28430939, 17.09597015], [73.28458405, 17.09597015], [73.28458405, 17.09708214], [73.2848587, 17.09708023], [73.2848587, 17.09875107], [73.28514099, 17.09874916], [73.28514099, 17.09958458], [73.28543091, 17.09958076], [73.28543091, 17.10042], [73.28514099, 17.10041428], [73.28514099, 17.10236168], [73.2848587, 17.10236168], [73.2848587, 17.10291672], [73.28458405, 17.10291672], [73.28458405, 17.10347176], [73.2848587, 17.10346985], [73.2848587, 17.10403061], [73.28514099, 17.10403061], [73.28514099, 17.10514069], [73.28541565, 17.10513878], [73.28541565, 17.10569382], [73.28514099, 17.1056881], [73.28514099, 17.10625076], [73.2848587, 17.10625076], [73.2848587, 17.10681152], [73.28457642, 17.10681152], [73.28457642, 17.10736084], [73.2840271, 17.10736084], [73.2840271, 17.1079216], [73.28347015, 17.10791588], [73.28347015, 17.10819435], [73.28291321, 17.10819054], [73.28291321, 17.10874939], [73.28263855, 17.10874939], [73.28263855, 17.10931015], [73.28235626, 17.10931015], [73.28235626, 17.11042023], [73.2820816, 17.11041641], [73.2820816, 17.11097145], [73.28235626, 17.11096954], [73.28235626, 17.11124992], [73.28263855, 17.11124992], [73.28263855, 17.1115303], [73.28291321, 17.1115303], [73.28291321, 17.11181068], [73.28263855, 17.11180305], [73.28263855, 17.11236382], [73.28291321, 17.11236], [73.28291321, 17.11264038], [73.28320313, 17.11264038], [73.28320313, 17.11292076], [73.28347015, 17.11291695], [73.28347015, 17.11319542], [73.2832489, 17.11319542], [73.28263855, 17.11319542], [73.28263855, 17.11291695], [73.28235626, 17.11292076], [73.28235626, 17.11236], [73.28152466, 17.11236382], [73.28152466, 17.11208153], [73.28125, 17.11208153], [73.28125, 17.11180305], [73.28098297, 17.11181068], [73.28098297, 17.1115303], [73.28013611, 17.1115303], [73.28013611, 17.11181068], [73.27958679, 17.11180305], [73.27958679, 17.11236382], [73.28098297, 17.11236], [73.28098297, 17.11264038], [73.28125, 17.11263847], [73.28125, 17.11319542], [73.28152466, 17.11319542], [73.28152466, 17.11347389], [73.28263855, 17.11347008], [73.28263855, 17.11403084], [73.28125, 17.11403084], [73.28125, 17.11375046], [73.27986145, 17.11375046], [73.27986145, 17.11347008], [73.2748642, 17.11347389], [73.2748642, 17.11319542], [73.27320099, 17.1131897], [73.27319336, 17.11291695], [73.2729187, 17.11292076], [73.2729187, 17.11264038], [73.26930237, 17.11264038], [73.26930237, 17.11207962], [73.26902771, 17.11208153], [73.26902771, 17.11180305], [73.26680756, 17.11180305], [73.26680756, 17.11236382], [73.26625061, 17.11236], [73.26625061, 17.11292076], [73.26597595, 17.11291695], [73.26597595, 17.11319542], [73.26652527, 17.11319542], [73.26652527, 17.11347389], [73.26706696, 17.11347008], [73.26706696, 17.11375046], [73.26735687, 17.11375046], [73.26735687, 17.11403084], [73.26763916, 17.11402512], [73.26763916, 17.11458588], [73.26790619, 17.11458015], [73.26790619, 17.11541939], [73.26819611, 17.11541748], [73.26819611, 17.11569595], [73.26847076, 17.11569023], [73.26847076, 17.11625099], [73.26875305, 17.11625099], [73.26875305, 17.11652946], [73.26902771, 17.11652756], [73.26902771, 17.1170826], [73.26930237, 17.11708069], [73.26930237, 17.11736107], [73.26957703, 17.11736107], [73.26957703, 17.11791992], [73.26985931, 17.11791611], [73.26985931, 17.11819458], [73.27041626, 17.11819458], [73.27041626, 17.11847305], [73.27153015, 17.11847115], [73.27153015, 17.11874962], [73.27236176, 17.11874962], [73.27236176, 17.11930466], [73.27263641, 17.11930084], [73.27263641, 17.12041855], [73.27236176, 17.12041855], [73.27236176, 17.12181282], [73.2720871, 17.12181282], [73.2720871, 17.12236023], [73.27179718, 17.12236023], [73.27179718, 17.1229229], [73.27153015, 17.12291718], [73.27153015, 17.12458229], [73.27124786, 17.12458038], [73.27124786, 17.12514114], [73.27097321, 17.12513924], [73.27097321, 17.1273613], [73.27124786, 17.12735939], [73.27124786, 17.12763977], [73.27097321, 17.12763977], [73.27097321, 17.12847137], [73.27069092, 17.12847137], [73.27069092, 17.12958336], [73.26930237, 17.12957954], [73.26930237, 17.13042068], [73.26902771, 17.13042068], [73.26902771, 17.13070107], [73.26875305, 17.13069534], [73.26875305, 17.13097191], [73.26902771, 17.13097], [73.26902771, 17.13153076], [73.26875305, 17.13152885], [73.26875305, 17.13208389], [73.26847076, 17.13207817], [73.26847076, 17.13236046], [73.26819611, 17.13236046], [73.26819611, 17.13347244], [73.26791382, 17.13347244], [73.26791382, 17.1356945], [73.26819611, 17.1356945], [73.26819611, 17.13736153], [73.26735687, 17.13735962], [73.26735687, 17.13792038], [73.26763916, 17.13792038], [73.26763916, 17.13875008], [73.26790619, 17.13875008], [73.26790619, 17.13931084], [73.26763916, 17.13930321], [73.26763916, 17.13958549], [73.2673645, 17.13958549], [73.2673645, 17.14069557], [73.26706696, 17.14068985], [73.26706696, 17.14180946], [73.26680756, 17.14180946], [73.26680756, 17.14208984], [73.2665329, 17.14208984], [73.2665329, 17.14264107], [73.26625061, 17.14264107], [73.26625061, 17.14430809], [73.26597595, 17.14430809], [73.26597595, 17.14486122], [73.26569366, 17.14486122], [73.26569366, 17.14569473], [73.26597595, 17.14569092], [73.26597595, 17.14652824], [73.26569366, 17.14652824], [73.26569366, 17.14680481], [73.26541901, 17.14680481], [73.26541901, 17.14708328], [73.26513672, 17.14707756], [73.26513672, 17.14792252], [73.26486206, 17.14792252], [73.26486206, 17.14903259], [73.26457977, 17.14903259], [73.26457977, 17.14931107], [73.26486206, 17.14931107], [73.26486206, 17.14986038], [73.26457977, 17.14986038], [73.26457977, 17.15153122], [73.26430511, 17.1515274], [73.26430511, 17.15208244], [73.26346588, 17.15208054], [73.26346588, 17.15236092], [73.26374817, 17.15236092], [73.26374817, 17.15319252], [73.26347351, 17.15319252], [73.26347351, 17.15458488], [73.26374817, 17.15458107], [73.26374817, 17.15570068], [73.26346588, 17.15570068], [73.26346588, 17.15625], [73.26403046, 17.15625], [73.26403046, 17.15596962], [73.26430511, 17.15597153], [73.26430511, 17.15569687], [73.26457977, 17.15569687], [73.26457977, 17.15597153], [73.26486206, 17.15596962], [73.26486206, 17.15681076], [73.26432037, 17.15681076], [73.26432037, 17.15709114], [73.26403046, 17.15708351], [73.26403046, 17.15736198], [73.26374817, 17.15736008], [73.26374817, 17.15792084], [73.26347351, 17.15791893], [73.26347351, 17.15847206], [73.26319122, 17.15847015], [73.26319122, 17.15903091], [73.26291656, 17.1590271], [73.26291656, 17.15958405], [73.26264191, 17.15957832], [73.26264191, 17.15986061], [73.26235962, 17.15986061], [73.26235962, 17.16013908], [73.26209259, 17.16012955], [73.26209259, 17.16042137], [73.26126099, 17.16042137], [73.26126099, 17.16124916], [73.26097107, 17.16124916], [73.26097107, 17.16181183], [73.26069641, 17.16181183], [73.26069641, 17.16235924], [73.26097107, 17.16235924], [73.26097107, 17.16347122], [73.26069641, 17.16347122], [73.26069641, 17.16403008], [73.26041412, 17.16402817], [73.26041412, 17.1645813], [73.26013947, 17.1645813], [73.26013947, 17.16486359], [73.25985718, 17.16485977], [73.25985718, 17.16542053], [73.25958252, 17.16541672], [73.25958252, 17.16597176], [73.25930786, 17.16596985], [73.25930786, 17.16653061], [73.25958252, 17.1665287], [73.25958252, 17.16708565], [73.25930786, 17.16707993], [73.25930786, 17.16764069], [73.2590332, 17.16764069], [73.2590332, 17.16792107], [73.25930786, 17.16791725], [73.25930786, 17.16958237], [73.25958252, 17.16958046], [73.25958252, 17.16986084], [73.25985718, 17.16986084], [73.25985718, 17.17041969], [73.25958252, 17.17041969], [73.25958252, 17.17152977], [73.25986481, 17.17152786], [73.25986481, 17.1720829], [73.25958252, 17.1720829], [73.25958252, 17.17180634], [73.25930786, 17.17180634], [73.25930786, 17.1720829], [73.25846863, 17.17206955], [73.25846863, 17.17431068], [73.25819397, 17.17430496], [73.25819397, 17.17513847], [73.25763702, 17.17513847], [73.25763702, 17.1756916], [73.25736237, 17.17570114], [73.25736237, 17.17653275], [73.25708008, 17.17652702], [73.25708008, 17.17708206], [73.25681305, 17.17708015], [73.25681305, 17.1787529], [73.25653076, 17.1787529], [73.25653076, 17.17902946], [73.25624847, 17.17902946], [73.25624847, 17.17930984], [73.25597382, 17.17930412], [73.25597382, 17.1795826], [73.25569153, 17.17958069], [73.25569153, 17.18013954], [73.25541687, 17.18013954], [73.25541687, 17.18069649], [73.25569153, 17.18069077], [73.25569153, 17.18126106], [73.25541687, 17.18124962], [73.25541687, 17.18180656], [73.25514221, 17.18180656], [73.25514221, 17.18208313], [73.25485992, 17.18208313], [73.25485992, 17.1823616], [73.2545929, 17.1823597], [73.2545929, 17.18292046], [73.25430298, 17.18291664], [73.25430298, 17.18458366], [73.25402832, 17.18457985], [73.25402832, 17.18486023], [73.25374603, 17.18486023], [73.25374603, 17.18541908], [73.25347137, 17.18541908], [73.25347137, 17.18681145], [73.25319672, 17.18681145], [73.25319672, 17.18736076], [73.2529068, 17.18736076], [73.2529068, 17.18902969], [73.25263977, 17.18902969], [73.25263977, 17.18931007], [73.25235748, 17.18930626], [73.25235748, 17.1898613], [73.25208282, 17.1898613], [73.25209045, 17.19013977], [73.25180817, 17.19013977], [73.25180817, 17.19042015], [73.25096893, 17.19041634], [73.25096893, 17.19069481], [73.25125122, 17.19069481], [73.25125122, 17.19097137], [73.25096893, 17.19096947], [73.25096893, 17.19124985], [73.25041962, 17.19124985], [73.25041962, 17.19153023], [73.25013733, 17.19152832], [73.25013733, 17.19180489], [73.24986267, 17.19180489], [73.24986267, 17.19208145], [73.24764252, 17.19208145], [73.24764252, 17.19180489], [73.24736023, 17.19180489], [73.24736023, 17.19152832], [73.24680328, 17.19153023], [73.24680328, 17.19124985], [73.24652863, 17.19124985], [73.24652863, 17.19096947], [73.24569702, 17.19097137], [73.24569702, 17.19069481], [73.24485779, 17.19069481], [73.24485779, 17.19097137], [73.24430847, 17.19097137], [73.24430847, 17.19069481], [73.24402618, 17.19069481], [73.24402618, 17.19097137], [73.24346924, 17.19096947], [73.24346924, 17.19124985], [73.24263763, 17.19124985], [73.24263763, 17.19180489], [73.24236298, 17.19180489], [73.24236298, 17.19236374], [73.24124908, 17.19235992], [73.24124908, 17.19320107], [73.24041748, 17.19319344], [73.24041748, 17.19347382], [73.23986053, 17.19347], [73.23986053, 17.19375038], [73.23958588, 17.19375038], [73.23958588, 17.19403076], [73.23902893, 17.19403076], [73.23902893, 17.19431114], [73.23764038, 17.19431114], [73.23764038, 17.19403076], [73.23680878, 17.19403076], [73.23680878, 17.19375038], [73.23542023, 17.19375038], [73.23542023, 17.19403076], [73.23513794, 17.19403076], [73.23513794, 17.19431114], [73.23486328, 17.19430351], [73.23486328, 17.19569588], [73.23402405, 17.19569588], [73.23402405, 17.19597244], [73.23319244, 17.19597054], [73.23319244, 17.19652939], [73.2326355, 17.19652748], [73.2326355, 17.19708252], [73.23236084, 17.19708061], [73.23236084, 17.19736099], [73.23208618, 17.19736099], [73.23208618, 17.19763947], [73.23179626, 17.19763947], [73.23179626, 17.19791985], [73.23152924, 17.19791794], [73.23152924, 17.1981945], [73.23124695, 17.1981945], [73.23124695, 17.19930649], [73.23095703, 17.19930077], [73.23095703, 17.20070076], [73.23124695, 17.20069504], [73.23124695, 17.2009716], [73.23152924, 17.2009697], [73.23152924, 17.20125008], [73.23179626, 17.20125008], [73.23179626, 17.20153236], [73.23236084, 17.20153236], [73.23236084, 17.20181274], [73.2326355, 17.20180511], [73.2326355, 17.20208359], [73.23458099, 17.20208359], [73.23458099, 17.20152855], [73.23709106, 17.20153236], [73.23709106, 17.20125008], [73.23764038, 17.20125008], [73.23764038, 17.2009697], [73.23847198, 17.2009716], [73.23847198, 17.20069504], [73.23902893, 17.20070076], [73.23902893, 17.20041847], [73.23929596, 17.20041847], [73.23929596, 17.20013809], [73.23958588, 17.20013809], [73.23958588, 17.19985962], [73.23986053, 17.19986153], [73.23986053, 17.19958305], [73.24013519, 17.19958305], [73.24013519, 17.19930649], [73.24041748, 17.19930458], [73.24041748, 17.19902992], [73.2409668, 17.19902992], [73.2409668, 17.19874954], [73.24208069, 17.19874954], [73.24208069, 17.19847107], [73.24263763, 17.19847298], [73.24263763, 17.1981945], [73.24319458, 17.1981945], [73.24319458, 17.19791794], [73.24346924, 17.19791985], [73.24346924, 17.19763947], [73.24375153, 17.19763947], [73.24375153, 17.19736099], [73.24402618, 17.19736099], [73.24402618, 17.19680977], [73.24430847, 17.19680977], [73.24430847, 17.19652939], [73.24514008, 17.19652939], [73.24514008, 17.19680977], [73.2454071, 17.19680977], [73.2454071, 17.19763947], [73.24514008, 17.19763947], [73.24514008, 17.19791985], [73.24430847, 17.19791794], [73.24430847, 17.1981945], [73.24375153, 17.1981945], [73.24375153, 17.19847298], [73.24346924, 17.19847107], [73.24346924, 17.19874954], [73.24319458, 17.19874954], [73.24319458, 17.19930649], [73.24291992, 17.19930077], [73.24291992, 17.20013809], [73.24318695, 17.20013809], [73.24318695, 17.20070076], [73.24346924, 17.20070076], [73.24346924, 17.20125008], [73.24375153, 17.20125008], [73.24375153, 17.20181274], [73.24402618, 17.20180511], [73.24402618, 17.20208359], [73.24430847, 17.20208168], [73.24430847, 17.20236015], [73.24458313, 17.20236015], [73.24458313, 17.20292282], [73.24485779, 17.2029171], [73.24485779, 17.20347023], [73.24514008, 17.20347023], [73.24514008, 17.20375061], [73.2454071, 17.20375061], [73.2454071, 17.2040329], [73.24624634, 17.2040329], [73.24624634, 17.20514107], [73.24569702, 17.20514107], [73.24569702, 17.20486069], [73.24485779, 17.20486069], [73.24485779, 17.20514107], [73.24514008, 17.20513916], [73.24514008, 17.20569229], [73.24541473, 17.20569229], [73.24541473, 17.20597458], [73.24597168, 17.20597076], [73.24597168, 17.20736122], [73.24624634, 17.20736122], [73.24624634, 17.20874977], [73.24652863, 17.20874977], [73.24652863, 17.21014023], [73.2470932, 17.21014023], [73.2470932, 17.21042061], [73.24680328, 17.21042061], [73.24680328, 17.21070099], [73.24652863, 17.21070099], [73.24652863, 17.21153069], [73.24624634, 17.21153069], [73.24624634, 17.21291924], [73.24597168, 17.21291733], [73.24597168, 17.21430588], [73.24569702, 17.21429825], [73.24569702, 17.21624947], [73.24597168, 17.21624947], [73.24597168, 17.21681023], [73.24514008, 17.21681023], [73.24514008, 17.21737289], [73.24569702, 17.21737289], [73.24569702, 17.21763992], [73.2454071, 17.21763992], [73.2454071, 17.21820068], [73.24514008, 17.21819305], [73.24514008, 17.21847153], [73.24485779, 17.21846962], [73.24485779, 17.21931076], [73.24458313, 17.21930313], [73.24458313, 17.21958542], [73.24485779, 17.21958542], [73.24485779, 17.21986389], [73.24458313, 17.21986389], [73.24458313, 17.2206955], [73.24485779, 17.2206955], [73.24485779, 17.22097206], [73.24458313, 17.22097015], [73.24458313, 17.22125053], [73.24430847, 17.22125053], [73.24430847, 17.22264099], [73.24402618, 17.22263908], [73.24402618, 17.2234726], [73.24375153, 17.22347069], [73.24375153, 17.22430992], [73.24346924, 17.22430992], [73.24346924, 17.22486115], [73.24319458, 17.22486115], [73.24319458, 17.22597313], [73.24263763, 17.22597313], [73.24263763, 17.22624969], [73.24236298, 17.22624016], [73.24236298, 17.22652817], [73.24180603, 17.22652817], [73.24180603, 17.22680473], [73.24153137, 17.22680473], [73.24153137, 17.22708321], [73.24124908, 17.22708321], [73.24124908, 17.22736168], [73.2409668, 17.22735977], [73.2409668, 17.22792244], [73.24069214, 17.22792244], [73.24069214, 17.22820282], [73.24041748, 17.22819519], [73.24041748, 17.22847176], [73.23986053, 17.22847176], [73.23986053, 17.22819519], [73.23958588, 17.22820282], [73.23958588, 17.22792244], [73.23902893, 17.22792244], [73.23902893, 17.22763824], [73.23819733, 17.22763824], [73.23819733, 17.22735977], [73.23764038, 17.22736168], [73.23764038, 17.22708321], [73.23680878, 17.22708321], [73.23680878, 17.22680473], [73.23513794, 17.22680473], [73.23513794, 17.22708321], [73.23486328, 17.22707748], [73.23486328, 17.22763824], [73.23458099, 17.22763824], [73.23458099, 17.22820282], [73.23430634, 17.22819519], [73.23430634, 17.22958374], [73.23403168, 17.22958183], [73.23403168, 17.23042107], [73.23374939, 17.23041725], [73.23374939, 17.23097229], [73.2334671, 17.23097038], [73.2334671, 17.23125076], [73.23319244, 17.23125076], [73.23319244, 17.23180962], [73.23291779, 17.2318058], [73.23291779, 17.23208237], [73.23264313, 17.23208046], [73.23264313, 17.23237038], [73.23236084, 17.23237038], [73.23236084, 17.23264122], [73.23208618, 17.23263931], [73.23208618, 17.23319244], [73.23179626, 17.23319054], [73.23179626, 17.23513985], [73.23208618, 17.23513794], [73.23208618, 17.23569679], [73.23236084, 17.23569679], [73.23236084, 17.23597145], [73.2326355, 17.23597145], [73.2326355, 17.23624992], [73.23319244, 17.23624992], [73.23319244, 17.2365303], [73.2334671, 17.2365303], [73.2334671, 17.23681068], [73.23374939, 17.23680687], [73.23374939, 17.23736191], [73.23403168, 17.23736], [73.23403168, 17.23792076], [73.23430634, 17.23791885], [73.23430634, 17.23847198], [73.2334671, 17.23847008], [73.2334671, 17.23903084], [73.23319244, 17.23902893], [73.23319244, 17.23958397], [73.23291779, 17.23957825], [73.23291779, 17.24014091], [73.23264313, 17.24014091], [73.23264313, 17.24041939], [73.23236084, 17.24041748], [73.23236084, 17.24097252], [73.23208618, 17.24097061], [73.23208618, 17.24154282], [73.23180389, 17.24152756], [73.23180389, 17.2420826], [73.23152924, 17.2420826], [73.23152924, 17.24597168], [73.23124695, 17.24596977], [73.23124695, 17.24625015], [73.23095703, 17.24625015], [73.23095703, 17.24681091], [73.23069763, 17.24680328], [73.23069763, 17.24708557], [73.23014069, 17.24708557], [73.23014069, 17.24625015], [73.22821045, 17.24625015], [73.22821045, 17.24653053], [73.22651672, 17.24653053], [73.22651672, 17.24681091], [73.22541809, 17.24680328], [73.22541809, 17.24708557], [73.22402954, 17.24708557], [73.22402954, 17.24736023], [73.2234726, 17.24735069], [73.2234726, 17.24764061], [73.22319794, 17.2476387], [73.22319794, 17.24847221], [73.2234726, 17.24847031], [73.2234726, 17.24875069], [73.22374725, 17.24875069], [73.22374725, 17.24903107], [73.22402954, 17.24903107], [73.22402954, 17.24930954], [73.22486115, 17.24930763], [73.22486115, 17.2495842], [73.22597504, 17.2495842], [73.22597504, 17.24930763], [73.2270813, 17.24930763], [73.2270813, 17.2495842], [73.22735596, 17.24958038], [73.22735596, 17.25014114], [73.22763824, 17.25013924], [73.22763824, 17.25041771], [73.22846985, 17.25041771], [73.22846985, 17.25097275], [73.22875214, 17.25097084], [73.22875214, 17.25152969], [73.2279129, 17.25152779], [73.2279129, 17.25208282], [73.22763824, 17.25208092], [73.22763824, 17.25263977], [73.22736359, 17.25263977], [73.22736359, 17.25319481], [73.2270813, 17.25318909], [73.2270813, 17.25374985], [73.22680664, 17.25374985], [73.22680664, 17.25570107], [73.22624969, 17.25569534], [73.22624969, 17.25597191], [73.22597504, 17.25597191], [73.22598267, 17.25625038], [73.22458649, 17.25625038], [73.22458649, 17.25597191], [73.22402954, 17.25597191], [73.22402954, 17.25569534], [73.22374725, 17.25570107], [73.22374725, 17.25542259], [73.2234726, 17.25542259], [73.2234726, 17.2551403], [73.22209167, 17.2551403], [73.22209167, 17.25542259], [73.22180939, 17.25542259], [73.22180176, 17.25570107], [73.2215271, 17.25569534], [73.2215271, 17.25597191], [73.22180176, 17.25597191], [73.22180176, 17.25618172], [73.22180939, 17.25681114], [73.22209167, 17.25681114], [73.22209167, 17.25792122], [73.22180939, 17.2579174], [73.22180176, 17.25847244], [73.2215271, 17.25847054], [73.2215271, 17.25875282], [73.22125244, 17.25875282], [73.22125244, 17.25930977], [73.22097015, 17.25930977], [73.22097015, 17.26041985], [73.2206955, 17.26041412], [73.2206955, 17.26097488], [73.22097015, 17.26097107], [73.22097015, 17.26124954], [73.22180176, 17.26124954], [73.22180939, 17.26180077], [73.22208405, 17.26180649], [73.22208405, 17.26236153], [73.2223587, 17.26235008], [73.2223587, 17.26264], [73.22292328, 17.26264], [73.22292328, 17.26292038], [73.22319794, 17.26291656], [73.22319794, 17.26458359], [73.22291565, 17.26458359], [73.22291565, 17.26597214], [73.2234726, 17.26597023], [73.2234726, 17.26652908], [73.22264099, 17.26652908], [73.22264099, 17.26625061], [73.2223587, 17.26625061], [73.2223587, 17.26652908], [73.22209167, 17.26652908], [73.22209167, 17.26681137], [73.22180939, 17.26680565], [73.22180176, 17.26708412], [73.2215271, 17.2670784], [73.2215271, 17.26736069], [73.22125244, 17.26736069], [73.22125244, 17.26763916], [73.22097015, 17.26763916], [73.22097015, 17.26791954], [73.2206955, 17.26791763], [73.2206955, 17.2681942], [73.22041321, 17.26818848], [73.22041321, 17.2684803], [73.22070312, 17.2684803], [73.22070312, 17.26874924], [73.22097015, 17.26874924], [73.22097015, 17.2693119], [73.2206955, 17.26930618], [73.22070312, 17.27013969], [73.21901703, 17.27013969], [73.21901703, 17.26986122], [73.21875, 17.26986122], [73.21875, 17.26958084], [73.21736145, 17.26958084], [73.21736145, 17.26986122], [73.21708679, 17.26986122], [73.21708679, 17.27042007], [73.2168045, 17.27041626], [73.2168045, 17.2709713], [73.21708679, 17.2709713], [73.21708679, 17.27152824], [73.2168045, 17.27152824], [73.2168045, 17.27180481], [73.21652985, 17.27180481], [73.21652985, 17.27208138], [73.2159729, 17.27208138], [73.2159729, 17.27236366], [73.21569824, 17.27235985], [73.21569824, 17.27264023], [73.21541595, 17.27264023], [73.21541595, 17.27292061], [73.2151413, 17.27291679], [73.2151413, 17.27347183], [73.21485901, 17.27346992], [73.21485901, 17.27403069], [73.21458435, 17.27402687], [73.21458435, 17.27458572], [73.21208191, 17.27458], [73.21208191, 17.27514076], [73.21180725, 17.27513885], [73.21180725, 17.2756958], [73.21125031, 17.2756958], [73.21125031, 17.27513885], [73.21098328, 17.27514076], [73.21098328, 17.27320099], [73.21069336, 17.27320099], [73.21069336, 17.27235985], [73.2104187, 17.27236366], [73.2104187, 17.27180481], [73.21013641, 17.27180481], [73.21013641, 17.27152824], [73.2104187, 17.27152824], [73.2104187, 17.27124977], [73.21013641, 17.27124977], [73.21013641, 17.27041626], [73.20929718, 17.27042007], [73.20929718, 17.27013969], [73.20903015, 17.27013969], [73.20903015, 17.26958084], [73.20791626, 17.26958275], [73.20791626, 17.26930618], [73.20735931, 17.2693119], [73.20735931, 17.26902962], [73.20652771, 17.26902962], [73.20652771, 17.26874924], [73.20625305, 17.26874924], [73.20625305, 17.2684803], [73.20458221, 17.2684803], [73.20458221, 17.26874924], [73.20430756, 17.26874924], [73.20430756, 17.26902962], [73.20401764, 17.26902962], [73.20401764, 17.2693119], [73.20375061, 17.2693119], [73.20375061, 17.26986122], [73.20347595, 17.26986122], [73.20347595, 17.27069473], [73.20318604, 17.27069283], [73.20318604, 17.27124977], [73.20291901, 17.27124977], [73.20291901, 17.27320099], [73.20263672, 17.27320099], [73.20263672, 17.27431107], [73.20236206, 17.27431107], [73.20236206, 17.27653122], [73.20207977, 17.27653122], [73.20207977, 17.27736092], [73.20180511, 17.27736092], [73.20181274, 17.27874947], [73.20153046, 17.27874947], [73.20153046, 17.27930832], [73.20124817, 17.27930832], [73.20124817, 17.28013992], [73.20098114, 17.28013992], [73.20098114, 17.28071022], [73.20069122, 17.28071022], [73.20069122, 17.28181267], [73.20041656, 17.28181267], [73.20041656, 17.28292274], [73.20069122, 17.28291702], [73.20069122, 17.28347015], [73.20098114, 17.28346062], [73.20098114, 17.28403282], [73.20124817, 17.28403282], [73.20124817, 17.28430939], [73.20236206, 17.28430557], [73.20236206, 17.28458214], [73.20263672, 17.28458023], [73.20263672, 17.28486061], [73.20291901, 17.28486061], [73.20291901, 17.28541946], [73.20319366, 17.28541756], [73.20319366, 17.28569221], [73.20291901, 17.28569031], [73.20291901, 17.28680992], [73.20263672, 17.28680992], [73.20263672, 17.28736115], [73.20236206, 17.28736115], [73.20236206, 17.28819656], [73.20207977, 17.28819656], [73.20207977, 17.28847313], [73.20124817, 17.28847313], [73.20124817, 17.28819656], [73.20014191, 17.28819656], [73.20014191, 17.28847313], [73.19958496, 17.28847313], [73.19959259, 17.28874969], [73.19902802, 17.28874969], [73.19902802, 17.28903008], [73.19875336, 17.28902817], [73.19875336, 17.28930664], [73.19847107, 17.28930664], [73.19847107, 17.28958321], [73.19819641, 17.28958321], [73.19819641, 17.28986168], [73.19792175, 17.28985977], [73.19792175, 17.29014015], [73.19763947, 17.29014015], [73.19763947, 17.29070091], [73.19735718, 17.29070091], [73.19735718, 17.29264832], [73.19708252, 17.29264832], [73.19708252, 17.29291916], [73.19680786, 17.29291725], [73.19680786, 17.29319382], [73.19596863, 17.29319382], [73.19596863, 17.29347229], [73.19541931, 17.29347038], [73.19541931, 17.29375076], [73.19513702, 17.29375076], [73.19513702, 17.29402924], [73.19484711, 17.29402924], [73.19484711, 17.29513931], [73.19458008, 17.29513931], [73.19458008, 17.29569435], [73.19430542, 17.29569435], [73.19431305, 17.29624939], [73.19235992, 17.29624939], [73.19235992, 17.29652977], [73.19178772, 17.29652977], [73.19178772, 17.29681015], [73.19152832, 17.29680634], [73.19152832, 17.2970829], [73.19069672, 17.2970829], [73.19069672, 17.29736137], [73.18985748, 17.29735947], [73.18985748, 17.29763985], [73.18958282, 17.29763985], [73.18958282, 17.29792023], [73.18930817, 17.29792023], [73.18930817, 17.2990303], [73.18958282, 17.2990284], [73.18958282, 17.29958534], [73.19013977, 17.29958534], [73.19013977, 17.29986382], [73.19097137, 17.29986], [73.19097137, 17.30014038], [73.19124603, 17.30014038], [73.19124603, 17.30042076], [73.19152832, 17.30041695], [73.19152832, 17.30097389], [73.19178772, 17.30097008], [73.19178772, 17.30125046], [73.19124603, 17.30125046], [73.19124603, 17.30181122], [73.19097137, 17.30181122], [73.19097137, 17.30430984], [73.19124603, 17.30430984], [73.19124603, 17.30459023], [73.19152832, 17.30459023], [73.19152832, 17.30486107], [73.19430542, 17.30486107], [73.19430542, 17.30513954], [73.19484711, 17.30513954], [73.19484711, 17.30541992], [73.19513702, 17.30541611], [73.19513702, 17.30569458], [73.19541931, 17.30569077], [73.19541931, 17.30624962], [73.19569397, 17.30624962], [73.19569397, 17.30680466], [73.19680786, 17.30680466], [73.19680786, 17.30652809], [73.19708252, 17.30652809], [73.19708252, 17.30624962], [73.19735718, 17.30624962], [73.19735718, 17.30597115], [73.19763947, 17.30597305], [73.19763947, 17.30569458], [73.19819641, 17.30569458], [73.19819641, 17.30541611], [73.19847107, 17.30541992], [73.19847107, 17.30513954], [73.19875336, 17.30513954], [73.19875336, 17.30486107], [73.19930267, 17.30486107], [73.19930267, 17.30459023], [73.19959259, 17.30459023], [73.19959259, 17.30430984], [73.19985962, 17.30430984], [73.19985962, 17.30208015], [73.20069122, 17.30208588], [73.20069122, 17.30152512], [73.20153046, 17.30153084], [73.20153046, 17.30125046], [73.20173645, 17.30125046], [73.20181274, 17.30097008], [73.20236206, 17.30097389], [73.20236206, 17.30069351], [73.20263672, 17.30069351], [73.20263672, 17.30041695], [73.20291901, 17.30042076], [73.20291901, 17.30014038], [73.20318604, 17.30014038], [73.20318604, 17.29931068], [73.20347595, 17.29931068], [73.20347595, 17.2990303], [73.20401764, 17.2990303], [73.20401764, 17.29931068], [73.20430756, 17.29931068], [73.20430756, 17.2990303], [73.20485687, 17.2990303], [73.20485687, 17.29874992], [73.20569611, 17.29874992], [73.20569611, 17.29931068], [73.20597076, 17.29930305], [73.20597076, 17.29958534], [73.20680237, 17.29958534], [73.20680237, 17.29986382], [73.20735931, 17.29986], [73.20735931, 17.30014038], [73.2076416, 17.30014038], [73.2076416, 17.30042076], [73.20791626, 17.30041695], [73.20791626, 17.30069351], [73.20819092, 17.30069351], [73.20819092, 17.30097389], [73.20847321, 17.30097008], [73.20847321, 17.30125046], [73.20874786, 17.30125046], [73.20874786, 17.30208588], [73.20903015, 17.30208015], [73.20903015, 17.30291939], [73.20930481, 17.30291748], [73.20930481, 17.30319595], [73.2095871, 17.30319595], [73.2095871, 17.30347252], [73.20986176, 17.30347061], [73.20986176, 17.30375099], [73.21006012, 17.30374908], [73.21013641, 17.30374908], [73.21015167, 17.30402946], [73.2104187, 17.30402946], [73.2104187, 17.30430984], [73.21098328, 17.30430984], [73.21098328, 17.30402946], [73.21153259, 17.30402946], [73.21153259, 17.30347061], [73.21180725, 17.30347252], [73.21180725, 17.30319595], [73.21347046, 17.30319595], [73.21347046, 17.30291748], [73.21430206, 17.30291939], [73.21430206, 17.30264091], [73.21541595, 17.30264091], [73.21541595, 17.30236053], [73.21679688, 17.30236053], [73.21679688, 17.30264091], [73.21736145, 17.30264091], [73.21736145, 17.30291939], [73.21763611, 17.30291748], [73.21763611, 17.30319595], [73.2179184, 17.30319595], [73.2179184, 17.30291748], [73.21875, 17.30291939], [73.21875, 17.30264091], [73.2195816, 17.30264091], [73.2195816, 17.30236053], [73.22097015, 17.30236053], [73.22097015, 17.30291939], [73.22209167, 17.30291939], [73.22209167, 17.30264091], [73.2223587, 17.30264091], [73.2223587, 17.30236053], [73.22264099, 17.30236053], [73.22264099, 17.30181122], [73.22292328, 17.30181122], [73.22292328, 17.30153084], [73.2234726, 17.30153084], [73.2234726, 17.30125046], [73.22374725, 17.30125046], [73.22374725, 17.30097008], [73.22402954, 17.30097389], [73.22402954, 17.30083084], [73.22402954, 17.30069351], [73.2243042, 17.30069351], [73.2243042, 17.29958534], [73.22402954, 17.29958534], [73.22402954, 17.29930305], [73.22374725, 17.29931068], [73.22374725, 17.29874992], [73.2234726, 17.29874992], [73.2234726, 17.29819107], [73.22319794, 17.29819489], [73.22319794, 17.29763985], [73.22292328, 17.29763985], [73.22292328, 17.29624939], [73.22264099, 17.29624939], [73.22264099, 17.29568863], [73.2223587, 17.29569435], [73.2223587, 17.29541588], [73.22180176, 17.2954216], [73.22180176, 17.29486084], [73.22209167, 17.29486084], [73.22208405, 17.29458427], [73.2223587, 17.29458237], [73.2223587, 17.2943058], [73.22264099, 17.29431152], [73.22264099, 17.29402924], [73.22292328, 17.29402924], [73.22292328, 17.29375076], [73.22319794, 17.29375076], [73.22319794, 17.29347038], [73.2234726, 17.29347229], [73.2234726, 17.29319382], [73.22374725, 17.29319382], [73.22374725, 17.29291725], [73.22402954, 17.29291916], [73.22402954, 17.29207993], [73.22374725, 17.29208374], [73.22374725, 17.29180527], [73.22319794, 17.29180908], [73.22319794, 17.29153061], [73.22374725, 17.29153061], [73.22374725, 17.29125023], [73.22429657, 17.29125023], [73.22429657, 17.29096985], [73.22402954, 17.29097176], [73.22402954, 17.29069519], [73.22429657, 17.29070091], [73.22429657, 17.28874969], [73.22402954, 17.28874969], [73.22402954, 17.28625107], [73.22429657, 17.28625107], [73.22429657, 17.28569031], [73.22458649, 17.28569221], [73.22458649, 17.28541756], [73.22486115, 17.28541946], [73.22486115, 17.28458023], [73.22458649, 17.28458214], [73.22458649, 17.2840271], [73.22486115, 17.28403282], [73.22486115, 17.28346062], [73.2251358, 17.28347015], [73.2251358, 17.28319359], [73.22541809, 17.28319359], [73.22541809, 17.28263855], [73.22569275, 17.28264046], [73.22569275, 17.2820816], [73.22597504, 17.28208351], [73.22597504, 17.28152847], [73.22763824, 17.28153038], [73.22763824, 17.28181267], [73.22821045, 17.28181267], [73.22821045, 17.28264046], [73.22875214, 17.28264046], [73.22875214, 17.28292274], [73.22930908, 17.28291702], [73.22930908, 17.28319359], [73.2298584, 17.28319359], [73.2298584, 17.28347015], [73.23014069, 17.28346062], [73.23014069, 17.28403282], [73.23042297, 17.28403282], [73.23042297, 17.28430939], [73.23069763, 17.28430939], [73.23069763, 17.28486061], [73.23095703, 17.28486061], [73.23095703, 17.28541946], [73.23152924, 17.28541756], [73.23152924, 17.28569221], [73.23180389, 17.28569221], [73.23180389, 17.2859745], [73.23236084, 17.28597069], [73.23236084, 17.28625107], [73.23458099, 17.28625107], [73.23458099, 17.28680992], [73.23486328, 17.28680992], [73.23486328, 17.28763962], [73.23513794, 17.28763962], [73.23513794, 17.28847313], [73.23542023, 17.28847313], [73.23542023, 17.28930664], [73.23569489, 17.28930664], [73.23569489, 17.28986168], [73.23596954, 17.28985977], [73.23596954, 17.29070091], [73.23625183, 17.29070091], [73.23626709, 17.29153061], [73.23652649, 17.2915287], [73.23652649, 17.29208374], [73.23680878, 17.29207993], [73.23680878, 17.29264832], [73.23603058, 17.29263878], [73.23513794, 17.29263878], [73.23513794, 17.29319382], [73.23486328, 17.29319382], [73.23486328, 17.29347229], [73.23513794, 17.29347038], [73.23513794, 17.29431152], [73.23542023, 17.2943058], [73.23542023, 17.29458237], [73.23557281, 17.29458046], [73.23568726, 17.29458046], [73.23568726, 17.29486084], [73.23596954, 17.29486084], [73.23596954, 17.29513931], [73.23652649, 17.29513931], [73.23652649, 17.2954216], [73.23708344, 17.29541588], [73.23708344, 17.29569435], [73.23680878, 17.29568863], [73.23680878, 17.29624939], [73.23708344, 17.29624939], [73.23708344, 17.2970829], [73.23735809, 17.2970829], [73.23735809, 17.29763985], [73.23764038, 17.29763985], [73.23764038, 17.29792023], [73.23791504, 17.29791641], [73.23791504, 17.29819489], [73.23819733, 17.29819107], [73.23819733, 17.29874992], [73.23847198, 17.29874992], [73.23847198, 17.29931068], [73.23874664, 17.29930305], [73.23874664, 17.29986382], [73.23902893, 17.29986382], [73.23902893, 17.30069351], [73.23930359, 17.30069351], [73.23930359, 17.30097389], [73.23958588, 17.30097008], [73.23958588, 17.30153084], [73.23986053, 17.30153084], [73.23986053, 17.30236053], [73.23958588, 17.30236053], [73.23958588, 17.30319595], [73.23929596, 17.30319023], [73.23929596, 17.30486107], [73.23986053, 17.30486107], [73.23986053, 17.30513954], [73.24013519, 17.30513954], [73.24013519, 17.30569458], [73.24041748, 17.30569458], [73.24041748, 17.30597305], [73.24069214, 17.30597115], [73.24069214, 17.30624962], [73.2409668, 17.30624962], [73.2409668, 17.30652809], [73.24236298, 17.30652809], [73.24236298, 17.30680466], [73.24402618, 17.30680466], [73.24402618, 17.3073616], [73.24346924, 17.3073597], [73.24346924, 17.30764961], [73.24318695, 17.30764961], [73.24318695, 17.30791855], [73.24263763, 17.30791855], [73.24263763, 17.3073597], [73.24236298, 17.3073597], [73.24236298, 17.30764961], [73.24208069, 17.30764961], [73.24208069, 17.30791855], [73.24180603, 17.30791855], [73.24180603, 17.30875015], [73.24153137, 17.30875015], [73.24153137, 17.30903244], [73.24180603, 17.30903244], [73.24180603, 17.30986023], [73.24208069, 17.30986023], [73.24208069, 17.31125069], [73.24236298, 17.31125069], [73.24236298, 17.31236076], [73.24208069, 17.31236076], [73.24208069, 17.31264114], [73.24180603, 17.31263924], [73.24180603, 17.31319237], [73.24153137, 17.31319046], [73.24153137, 17.31513977], [73.24180603, 17.31513977], [73.24180603, 17.31597137], [73.24153137, 17.31596947], [73.24153137, 17.31653023], [73.24208069, 17.31653023], [73.24208069, 17.31792068], [73.24236298, 17.31791878], [73.24236298, 17.31847191], [73.24263763, 17.31846809], [73.24263763, 17.31875038], [73.24180603, 17.31875038], [73.24180603, 17.31846809], [73.24153137, 17.31847191], [73.24153137, 17.31791878], [73.24124908, 17.31792068], [73.24124908, 17.3176403], [73.2409668, 17.3176403], [73.2409668, 17.31735992], [73.23929596, 17.31735992], [73.23929596, 17.3176403], [73.23902893, 17.3176403], [73.23902893, 17.31792068], [73.23847198, 17.31792068], [73.23847198, 17.31820107], [73.23819733, 17.31819534], [73.23819733, 17.31847191], [73.23735809, 17.31846809], [73.23735809, 17.31875038], [73.23430634, 17.31875038], [73.23430634, 17.31903076], [73.23374939, 17.31903076], [73.23374939, 17.31930923], [73.23208618, 17.31930923], [73.23208618, 17.31903076], [73.22930908, 17.31903076], [73.22930908, 17.31930923], [73.22902679, 17.31930923], [73.22902679, 17.31958771], [73.22875214, 17.31958771], [73.22875214, 17.32041931], [73.22819519, 17.3204174], [73.22819519, 17.32069397], [73.2279129, 17.32069397], [73.2279129, 17.32097244], [73.22763824, 17.32097054], [73.22763824, 17.32235909], [73.22736359, 17.32235909], [73.22736359, 17.32263947], [73.22680664, 17.32262993], [73.22680664, 17.32292175], [73.22652435, 17.32291603], [73.22652435, 17.3231945], [73.22624969, 17.3231945], [73.22624969, 17.32347107], [73.22569275, 17.32347107], [73.22569275, 17.32374954], [73.22541809, 17.32374954], [73.22541809, 17.32403183], [73.22515106, 17.32403183], [73.22515106, 17.3243103], [73.22458649, 17.32430649], [73.22458649, 17.32458115], [73.2243042, 17.32458115], [73.2243042, 17.32486153], [73.22374725, 17.32485962], [73.22374725, 17.32514], [73.2234726, 17.32514], [73.2234726, 17.32542038], [73.22291565, 17.32541656], [73.22291565, 17.32569313], [73.2223587, 17.32569313], [73.2223587, 17.3259716], [73.22208405, 17.3259716], [73.22209167, 17.32625008], [73.2215271, 17.32625008], [73.2215271, 17.32653046], [73.22125244, 17.32653046], [73.22125244, 17.32681084], [73.2206955, 17.32680321], [73.2206955, 17.32708549], [73.22041321, 17.32708549], [73.22041321, 17.32736206], [73.22013855, 17.32736015], [73.22013855, 17.32792091], [73.21985626, 17.32792091], [73.21985626, 17.32876015], [73.2195816, 17.32876015], [73.2195816, 17.32903099], [73.21901703, 17.32903099], [73.21901703, 17.32930946], [73.21875, 17.32930756], [73.21875, 17.33097267], [73.21901703, 17.33097076], [73.21901703, 17.33152962], [73.21930695, 17.33152771], [73.21930695, 17.33208275], [73.2195816, 17.33208084], [73.2195816, 17.33236122], [73.21985626, 17.33236122], [73.21985626, 17.33263969], [73.22013855, 17.33263969], [73.22013855, 17.33291817], [73.22041321, 17.33291626], [73.22041321, 17.33319473], [73.22125244, 17.33319473], [73.22125244, 17.3334713], [73.2223587, 17.33346748], [73.2223587, 17.33374977], [73.22319794, 17.33374977], [73.22319794, 17.33346748], [73.22651672, 17.33346748], [73.22651672, 17.33374977], [73.22680664, 17.33374977], [73.22680664, 17.33430481], [73.22597504, 17.33430481], [73.22597504, 17.33458328], [73.22569275, 17.33458328], [73.22569275, 17.33486176], [73.22541809, 17.33486176], [73.22541809, 17.33681107], [73.2251358, 17.33680534], [73.2251358, 17.33736038], [73.22569275, 17.33736038], [73.22569275, 17.33763885], [73.22515106, 17.33762932], [73.22515106, 17.33792114], [73.22458649, 17.33791733], [73.22458649, 17.33819389], [73.22319794, 17.33819389], [73.22319794, 17.33847237], [73.22264099, 17.33847046], [73.22264099, 17.33875084], [73.2223587, 17.33875084], [73.2223587, 17.33903122], [73.22209167, 17.33903122], [73.22209167, 17.33930969], [73.22180939, 17.33930588], [73.22180176, 17.33958244], [73.22125244, 17.33958054], [73.22125244, 17.33986092], [73.22097015, 17.33986092], [73.22097015, 17.34013939], [73.22070312, 17.34013939], [73.22070312, 17.34041977], [73.22041321, 17.34041405], [73.22041321, 17.34097481], [73.22013855, 17.34097099], [73.22013855, 17.34124947], [73.21985626, 17.34124947], [73.21985626, 17.34181023], [73.2195816, 17.34180641], [73.2195816, 17.34208488], [73.21930695, 17.34208107], [73.21930695, 17.34263992], [73.21875, 17.34263992], [73.21875, 17.3429203], [73.2179184, 17.3429203], [73.2179184, 17.34320068], [73.21736145, 17.34319687], [73.21736145, 17.34347153], [73.21679688, 17.34346962], [73.21679688, 17.34375954], [73.21652985, 17.34375954], [73.21652985, 17.34403038], [73.21624756, 17.34403038], [73.21624756, 17.34431076], [73.2159729, 17.34430695], [73.2159729, 17.34458351], [73.21569824, 17.34458351], [73.21569824, 17.34486198], [73.21541595, 17.34486008], [73.21541595, 17.34514046], [73.21485901, 17.34513855], [73.21485901, 17.34569359], [73.21458435, 17.34569359], [73.21458435, 17.34680557], [73.21430206, 17.34680557], [73.21430206, 17.34819412], [73.21457672, 17.3481884], [73.21457672, 17.34902954], [73.21485901, 17.34902954], [73.21485901, 17.34931183], [73.2151413, 17.34930611], [73.2151413, 17.34958267], [73.21541595, 17.34957123], [73.21541595, 17.34986115], [73.21624756, 17.34986115], [73.21624756, 17.35013962], [73.21652985, 17.35013962], [73.21652985, 17.35069466], [73.2168045, 17.35069466], [73.2168045, 17.35097122], [73.21736145, 17.35097122], [73.21736145, 17.35124969], [73.21875, 17.35124969], [73.21875, 17.35180473], [73.21902466, 17.35180473], [73.21902466, 17.35236168], [73.2195816, 17.35235977], [73.2195816, 17.35264015], [73.21985626, 17.35264015], [73.21985626, 17.35293007], [73.22013855, 17.35293007], [73.22013855, 17.35431099], [73.21985626, 17.35431099], [73.21985626, 17.35653114], [73.2195816, 17.35653114], [73.2195816, 17.35680962], [73.21930695, 17.35680771], [73.21930695, 17.35708427], [73.21901703, 17.35708046], [73.21901703, 17.35736084], [73.21819305, 17.35736084], [73.21819305, 17.35764122], [73.21624756, 17.35763931], [73.21624756, 17.35819435], [73.21595764, 17.35819054], [73.21595764, 17.35930824], [73.21624756, 17.35930634], [73.21624756, 17.3595829], [73.21595764, 17.35957909], [73.21595764, 17.36013985], [73.21569824, 17.36013985], [73.21569824, 17.36041832], [73.21541595, 17.36041641], [73.21541595, 17.36069489], [73.2151413, 17.36068916], [73.2151413, 17.36124992], [73.21485901, 17.36124992], [73.21485901, 17.3615303], [73.21458435, 17.3615284], [73.21458435, 17.36180496], [73.21430206, 17.36180496], [73.21430206, 17.36208344], [73.2140274, 17.36208153], [73.2140274, 17.36292267], [73.21375275, 17.36292267], [73.21375275, 17.36375046], [73.2140274, 17.36375046], [73.2140274, 17.36431122], [73.21430206, 17.3643055], [73.21430206, 17.36458206], [73.21457672, 17.36458015], [73.21457672, 17.36514282], [73.21485901, 17.36513901], [73.21485901, 17.36569214], [73.2151413, 17.36569023], [73.2151413, 17.3662529], [73.21541595, 17.3662529], [73.21541595, 17.36680984], [73.21569824, 17.36680984], [73.21569824, 17.36736107], [73.21595764, 17.36736107], [73.21595764, 17.36792946], [73.21624756, 17.3679142], [73.21624756, 17.36847305], [73.21652985, 17.36847115], [73.21652985, 17.36903], [73.2168045, 17.36902809], [73.2168045, 17.36958313], [73.21652985, 17.36958122], [73.21652985, 17.37014008], [73.21624756, 17.37013626], [73.21624756, 17.37097168], [73.21485901, 17.37097168], [73.21485901, 17.37069511], [73.21457672, 17.37070084], [73.21457672, 17.37042046], [73.21375275, 17.37042046], [73.21375275, 17.37070084], [73.2095871, 17.37069511], [73.2095871, 17.37097168], [73.20929718, 17.37096977], [73.20929718, 17.37125015], [73.20903015, 17.37125015], [73.20903015, 17.37153053], [73.20874786, 17.37153053], [73.20874786, 17.37236023], [73.20903015, 17.37236023], [73.20903015, 17.37291908], [73.20930481, 17.37291718], [73.20930481, 17.37375069], [73.2095871, 17.37374115], [73.2095871, 17.37486076], [73.20986176, 17.37486076], [73.20986176, 17.37541962], [73.21013641, 17.3754158], [73.21013641, 17.37597275], [73.2104187, 17.37597275], [73.2104187, 17.3773613], [73.21015167, 17.37735939], [73.21015167, 17.37792015], [73.20986176, 17.37792015], [73.20986176, 17.37874985], [73.2095871, 17.37874985], [73.2095871, 17.37958336], [73.20929718, 17.37957954], [73.20929718, 17.3801403], [73.20903015, 17.3801403], [73.20903015, 17.38042068], [73.20874786, 17.38042068], [73.20874786, 17.38181114], [73.20847321, 17.38180351], [73.20847321, 17.3820858], [73.20819092, 17.38208008], [73.20819092, 17.38236046], [73.20791626, 17.38236046], [73.20791626, 17.3829174], [73.2076416, 17.3829174], [73.2076416, 17.38347244], [73.20735931, 17.38347054], [73.20735931, 17.38375092], [73.20707703, 17.38375092], [73.20707703, 17.38430977], [73.20652771, 17.38430786], [73.20652771, 17.38458252], [73.20625305, 17.38458061], [73.20625305, 17.38513947], [73.20540619, 17.38513947], [73.20540619, 17.38486099], [73.20513916, 17.38486099], [73.20513916, 17.38458061], [73.20430756, 17.38458252], [73.20430756, 17.38430786], [73.20295715, 17.38430786], [73.20236206, 17.38430786], [73.20236206, 17.38458252], [73.20207977, 17.38458061], [73.20207977, 17.38486099], [73.20180511, 17.38486099], [73.20181274, 17.38513947], [73.20153046, 17.38513947], [73.20153046, 17.3856945], [73.20124817, 17.3856945], [73.20124817, 17.38597298], [73.20097351, 17.38597298], [73.20097351, 17.38736153], [73.19985962, 17.38735962], [73.19985962, 17.38763809], [73.19957733, 17.38763809], [73.19957733, 17.38791847], [73.19902802, 17.38791847], [73.19902802, 17.38763809], [73.19735718, 17.38763809], [73.19735718, 17.38735962], [73.19708252, 17.38736153], [73.19708252, 17.38708305], [73.19736481, 17.38708305], [73.19736481, 17.38652992], [73.19763947, 17.38652992], [73.19763947, 17.38624954], [73.19625092, 17.38624954], [73.19625092, 17.38652992], [73.19596863, 17.38652992], [73.19596863, 17.3868084], [73.19569397, 17.38680649], [73.19569397, 17.38708305], [73.19541931, 17.38708305], [73.19541931, 17.38736153], [73.19484711, 17.38735962], [73.19484711, 17.38791847], [73.19458008, 17.38791847], [73.19458008, 17.38820267], [73.19291687, 17.38819504], [73.19291687, 17.3884716], [73.19264221, 17.3884716], [73.19264221, 17.38875008], [73.19097137, 17.38875008], [73.19097137, 17.3884716], [73.19041443, 17.3884716], [73.19041443, 17.38763809], [73.19013977, 17.38763809], [73.19013977, 17.3873024], [73.19013977, 17.38708305], [73.19041443, 17.38708305], [73.19041443, 17.38624954], [73.19069672, 17.38624954], [73.19069672, 17.38486099], [73.1904068, 17.38486099], [73.1904068, 17.38458061], [73.19013977, 17.38458252], [73.19013977, 17.38430786], [73.18958282, 17.38430977], [73.18958282, 17.38486099], [73.18930817, 17.38486099], [73.18930817, 17.38513947], [73.18875122, 17.38513947], [73.18875122, 17.38541985], [73.18763733, 17.38541985], [73.18763733, 17.38513947], [73.18541718, 17.38513947], [73.18541718, 17.38458061], [73.18514252, 17.38458061], [73.18514252, 17.38486099], [73.18374634, 17.38486099], [73.18374634, 17.38513947], [73.18347168, 17.38513947], [73.18347168, 17.3856945], [73.18291473, 17.3856945], [73.18291473, 17.38597298], [73.18235779, 17.38597107], [73.18235779, 17.38624954], [73.18152618, 17.38624954], [73.18152618, 17.3868084], [73.18125153, 17.38680649], [73.18125153, 17.38708305], [73.17958069, 17.38708305], [73.17958069, 17.38680649], [73.17903137, 17.38680649], [73.17903137, 17.38708305], [73.17708588, 17.38708305], [73.17708588, 17.38736153], [73.17652893, 17.38735962], [73.17652893, 17.38791847], [73.17624664, 17.38791656], [73.17624664, 17.3884716], [73.17597198, 17.3884716], [73.17597198, 17.38931274], [73.17569733, 17.38930511], [73.17569733, 17.38986015], [73.17485809, 17.38986015], [73.17485809, 17.39014053], [73.17458344, 17.39013863], [73.17458344, 17.39069366], [73.17430878, 17.39069176], [73.17430878, 17.3915329], [73.17402649, 17.39152718], [73.17404175, 17.39236069], [73.17375183, 17.39236069], [73.17375183, 17.39431], [73.17346954, 17.39431], [73.17346954, 17.39542007], [73.17319489, 17.39541435], [73.17319489, 17.39569664], [73.17292023, 17.39569092], [73.17292023, 17.39624977], [73.17263794, 17.39624977], [73.17263794, 17.39653015], [73.17208099, 17.39652824], [73.17208099, 17.39708328], [73.17180634, 17.39708328], [73.17180634, 17.39736176], [73.17151642, 17.39735985], [73.17151642, 17.39764023], [73.17124939, 17.39763641], [73.17124939, 17.3979187], [73.1709671, 17.39791107], [73.1709671, 17.39819908], [73.17067719, 17.39819908], [73.17067719, 17.39903069], [73.17041779, 17.39902878], [73.17041779, 17.39958382], [73.1701355, 17.39958382], [73.17014313, 17.39986038], [73.16986084, 17.39986038], [73.16986084, 17.40041924], [73.16958618, 17.40041733], [73.16958618, 17.40069389], [73.16930389, 17.40069389], [73.16930389, 17.40097237], [73.16902924, 17.40097046], [73.16902924, 17.40152931], [73.16874695, 17.40152931], [73.16874695, 17.4018116], [73.16847229, 17.4018116], [73.16847229, 17.40236092], [73.16819763, 17.40236092], [73.16819763, 17.40292168], [73.16791534, 17.40291595], [73.16791534, 17.40319443], [73.16764069, 17.40319252], [73.16764069, 17.40431023], [73.1673584, 17.40431023], [73.1673584, 17.40513992], [73.16708374, 17.40513802], [73.16708374, 17.40597153], [73.1673584, 17.40596962], [73.1673584, 17.40681076], [73.16764069, 17.40680313], [73.16764069, 17.40708542], [73.16791534, 17.40708542], [73.16791534, 17.40736389], [73.16847229, 17.40736008], [73.16847229, 17.40764046], [73.17014313, 17.40764046], [73.17014313, 17.40736008], [73.17041779, 17.40736008], [73.17041779, 17.40764046], [73.17067719, 17.40764046], [73.17067719, 17.40736008], [73.17236328, 17.40736389], [73.17236328, 17.40680313], [73.17263794, 17.40681076], [73.17263794, 17.40653038], [73.17318726, 17.40653038], [73.17318726, 17.40681076], [73.17346954, 17.40680313], [73.17346954, 17.40708542], [73.17457581, 17.4070797], [73.17457581, 17.40792084], [73.17514038, 17.40792084], [73.17514038, 17.40764046], [73.17542267, 17.40764046], [73.17542267, 17.40681076], [73.17514038, 17.40681076], [73.17514038, 17.40653038], [73.17681122, 17.40653038], [73.17681122, 17.40681076], [73.17874908, 17.40680313], [73.17874908, 17.40736389], [73.17847443, 17.40736389], [73.17847443, 17.40819359], [73.17819214, 17.40818977], [73.17819214, 17.40875053], [73.1784668, 17.40875053], [73.1784668, 17.40930939], [73.17874908, 17.40930748], [73.17874908, 17.40986061], [73.1784668, 17.40985107], [73.1784668, 17.41041946], [73.17903137, 17.41041756], [73.17903137, 17.4109726], [73.17930603, 17.41097069], [73.17930603, 17.41125107], [73.17958069, 17.41125107], [73.17958069, 17.41152954], [73.17984772, 17.41152954], [73.17984772, 17.41180992], [73.18013763, 17.41180611], [73.18013763, 17.41208267], [73.18096924, 17.41208076], [73.18096924, 17.41236115], [73.1829071, 17.41236115], [73.1829071, 17.41263962], [73.18319702, 17.41263962], [73.18319702, 17.41236115], [73.18347168, 17.41236115], [73.18347168, 17.41208076], [73.18430328, 17.41208076], [73.18430328, 17.41374969], [73.18458557, 17.41374969], [73.18458557, 17.41430473], [73.18653107, 17.41430473], [73.18653107, 17.41458321], [73.18708038, 17.41457748], [73.18708038, 17.41542244], [73.18653107, 17.41542244], [73.18653107, 17.41570282], [73.18624878, 17.41570282], [73.18624878, 17.41625023], [73.18569183, 17.41625023], [73.18569183, 17.41653252], [73.18514252, 17.41653252], [73.18514252, 17.4168129], [73.18486023, 17.4168129], [73.18486023, 17.41736031], [73.18514252, 17.41736031], [73.18514252, 17.41819382], [73.18541718, 17.41819191], [73.18541718, 17.41875076], [73.18569183, 17.41875076], [73.18569183, 17.41904068], [73.18541718, 17.41904068], [73.18541718, 17.41930962], [73.18569183, 17.41930962], [73.18569183, 17.41986084], [73.18597412, 17.41986084], [73.18597412, 17.42069244], [73.18569183, 17.42069054], [73.18569183, 17.42124939], [73.18541718, 17.42124939], [73.18541718, 17.42292023], [73.18514252, 17.42291451], [73.18514252, 17.42319679], [73.18569183, 17.42319107], [73.18569183, 17.42374992], [73.18598175, 17.42374992], [73.18597412, 17.42319679], [73.18624878, 17.42319679], [73.18624878, 17.42291451], [73.18680573, 17.42291451], [73.18680573, 17.42319679], [73.18708038, 17.42319107], [73.18708038, 17.42431068], [73.18680573, 17.42430687], [73.18680573, 17.42486191], [73.18653107, 17.42486191], [73.18653107, 17.42569351], [73.18681335, 17.4256897], [73.18681335, 17.42653084], [73.18708038, 17.42653084], [73.18708038, 17.42902946], [73.18680573, 17.42902756], [73.18680573, 17.43069458], [73.18708038, 17.43069267], [73.18708038, 17.43098068], [73.18763733, 17.43098068], [73.18763733, 17.43124962], [73.18791962, 17.43124962], [73.18791962, 17.43153191], [73.18819427, 17.43152809], [73.18819427, 17.43180466], [73.18930817, 17.43180466], [73.18930817, 17.43208122], [73.18985748, 17.43208122], [73.18985748, 17.4323616], [73.1904068, 17.4323597], [73.1904068, 17.43264008], [73.19207764, 17.43264008], [73.19207764, 17.4323597], [73.19235992, 17.4323616], [73.19235992, 17.43208122], [73.19291687, 17.43208122], [73.19291687, 17.4323616], [73.19319153, 17.4323597], [73.19319153, 17.43292046], [73.19346619, 17.43292046], [73.19346619, 17.43375015], [73.19374847, 17.43375015], [73.19374847, 17.43402863], [73.19403076, 17.4340229], [73.19403076, 17.43431091], [73.19431305, 17.43431091], [73.19431305, 17.43514061], [73.19458008, 17.43514061], [73.19458008, 17.43542099], [73.19541931, 17.43541527], [73.19541931, 17.43569565], [73.19568634, 17.43568993], [73.19568634, 17.43625069], [73.19596863, 17.43625069], [73.19596863, 17.43653107], [73.19625092, 17.43652534], [73.19625092, 17.4370842], [73.19652557, 17.4370842], [73.19652557, 17.43736076], [73.19735718, 17.43736076], [73.19735718, 17.43764114], [73.19847107, 17.43764114], [73.19847107, 17.43791962], [73.19958496, 17.43791771], [73.19958496, 17.43819427], [73.19985962, 17.43819427], [73.19985962, 17.43847275], [73.20041656, 17.43847275], [73.20041656, 17.43819427], [73.20069122, 17.43819427], [73.20069122, 17.43791771], [73.20180511, 17.43791771], [73.20180511, 17.43819427], [73.20236206, 17.43819427], [73.20236206, 17.43847275], [73.20401764, 17.43847084], [73.20401764, 17.43875122], [73.20485687, 17.43875122], [73.20485687, 17.43847084], [73.20569611, 17.43847084], [73.20569611, 17.43902969], [73.20430756, 17.43902969], [73.20430756, 17.43930817], [73.20153046, 17.43930626], [73.20153046, 17.43958282], [73.20069122, 17.43958282], [73.20069122, 17.4398613], [73.19985962, 17.43985748], [73.19985962, 17.44014931], [73.19902802, 17.44014931], [73.19902802, 17.44041824], [73.19875336, 17.44041634], [73.19875336, 17.44097137], [73.19847107, 17.44096756], [73.19847107, 17.44124985], [73.19792175, 17.44124985], [73.19792175, 17.44152832], [73.19763947, 17.44152832], [73.19763947, 17.44180489], [73.19680786, 17.44180489], [73.19680786, 17.44208336], [73.19541931, 17.44208336], [73.19541931, 17.44180489], [73.19513702, 17.44180489], [73.19513702, 17.44236183], [73.19346619, 17.44236183], [73.19346619, 17.4426403], [73.19207764, 17.4426403], [73.19207764, 17.44236183], [73.19180298, 17.44236183], [73.19180298, 17.44180489], [73.19152832, 17.44180489], [73.19152832, 17.44152832], [73.1904068, 17.44152832], [73.1904068, 17.44124985], [73.18818665, 17.44124985], [73.18818665, 17.44152832], [73.18680573, 17.44152832], [73.18680573, 17.44180489], [73.18597412, 17.44180489], [73.18597412, 17.44236183], [73.18569183, 17.44236183], [73.18569183, 17.4426403], [73.18598175, 17.4426403], [73.18598175, 17.44292259], [73.18624878, 17.44292259], [73.18624878, 17.4432106], [73.18597412, 17.44319534], [73.18598175, 17.44375038], [73.18569183, 17.44375038], [73.18569183, 17.44431114], [73.18597412, 17.44430542], [73.18597412, 17.44486046], [73.18624878, 17.44486046], [73.18624878, 17.44569206], [73.18597412, 17.44569206], [73.18597412, 17.44847488], [73.18624878, 17.44847107], [73.18624878, 17.4493103], [73.18598175, 17.4493103], [73.18598175, 17.45042038], [73.18624878, 17.45042038], [73.18624878, 17.45125008], [73.18653107, 17.45125008], [73.18653107, 17.45181084], [73.18624878, 17.45181084], [73.18624878, 17.45209122], [73.18597412, 17.45208359], [73.18597412, 17.45236206], [73.18569183, 17.45236015], [73.18569183, 17.45264053], [73.18541718, 17.45264053], [73.18541718, 17.45292091], [73.18514252, 17.4529171], [73.18514252, 17.45319366], [73.18458557, 17.45319366], [73.18458557, 17.45347214], [73.18430328, 17.45346832], [73.18430328, 17.45402908], [73.18458557, 17.45402718], [73.18458557, 17.45458412], [73.18430328, 17.4545784], [73.18430328, 17.45486069], [73.18402863, 17.45486069], [73.18402863, 17.4556942], [73.18430328, 17.45568848], [73.18430328, 17.45624924], [73.18458557, 17.45624924], [73.18458557, 17.45708275], [73.18486023, 17.45708275], [73.18486023, 17.45736122], [73.18514252, 17.45736122], [73.18514252, 17.45763969], [73.18541718, 17.45763969], [73.18541718, 17.45792007], [73.18597412, 17.45791626], [73.18597412, 17.45819473], [73.18624878, 17.45819473], [73.18624878, 17.4584713], [73.18653107, 17.45846939], [73.18653107, 17.45874977], [73.18681335, 17.45874977], [73.18682098, 17.45903015], [73.18708038, 17.45902824], [73.18708038, 17.45930481], [73.18763733, 17.45930481], [73.18763733, 17.45958328], [73.18819427, 17.45958328], [73.18819427, 17.45986176], [73.18846893, 17.45985985], [73.18846893, 17.46014023], [73.18930817, 17.46014023], [73.18930817, 17.46042061], [73.18985748, 17.46041679], [73.18985748, 17.46097183], [73.19013977, 17.46096039], [73.19013977, 17.46125031], [73.1904068, 17.46125031], [73.1904068, 17.46153069], [73.19069672, 17.46153069], [73.19069672, 17.46181107], [73.19097137, 17.46180344], [73.19097137, 17.46208572], [73.19124603, 17.46208], [73.19124603, 17.46236038], [73.19152832, 17.46236038], [73.19152832, 17.46292114], [73.19208527, 17.46291733], [73.19208527, 17.46347237], [73.19264221, 17.46347046], [73.19264221, 17.46541977], [73.19374847, 17.46541786], [73.19374847, 17.4659729], [73.19347382, 17.4659729], [73.19347382, 17.46736145], [73.19374847, 17.46736145], [73.19374847, 17.46847153], [73.19346619, 17.46847153], [73.19346619, 17.46903038], [73.19319153, 17.46902847], [73.19319153, 17.47013855], [73.19291687, 17.47013855], [73.19291687, 17.47069359], [73.19264221, 17.47069359], [73.19264221, 17.47208214], [73.19235992, 17.47208023], [73.19235992, 17.47236061], [73.19207764, 17.47236061], [73.19207764, 17.4726429], [73.19178772, 17.4726429], [73.19178772, 17.47291946], [73.19125366, 17.47291756], [73.19125366, 17.47319221], [73.19097137, 17.47319031], [73.19097137, 17.47375107], [73.19069672, 17.47375107], [73.19069672, 17.47542], [73.19041443, 17.47541428], [73.19041443, 17.47569656], [73.19013977, 17.47569656], [73.19013977, 17.47597313], [73.18985748, 17.47597122], [73.18985748, 17.47626114], [73.18958282, 17.47624969], [73.18958282, 17.47708321], [73.18930817, 17.47707939], [73.18930817, 17.47792053], [73.18902588, 17.47791862], [73.18902588, 17.47847176], [73.18875122, 17.47846985], [73.18875122, 17.47903061], [73.18846893, 17.47903061], [73.18846893, 17.47931862], [73.18875122, 17.47930527], [73.18875122, 17.47958374], [73.18902588, 17.47958374], [73.18902588, 17.48097229], [73.18875122, 17.48097038], [73.18875122, 17.48152924], [73.18846893, 17.48152924], [73.18846893, 17.48181152], [73.18818665, 17.48181152], [73.18818665, 17.48236084], [73.18791962, 17.48236084], [73.18791962, 17.48291969], [73.18763733, 17.48291588], [73.18763733, 17.48347282], [73.18736267, 17.48347282], [73.18736267, 17.48402977], [73.18708038, 17.48402786], [73.18708038, 17.48486137], [73.18681335, 17.48485947], [73.18681335, 17.48542023], [73.18653107, 17.48541641], [73.18653107, 17.48597145], [73.18624878, 17.48596954], [73.18624878, 17.48681068], [73.18597412, 17.48680305], [73.18597412, 17.48736382], [73.18569183, 17.48736], [73.18569183, 17.48792076], [73.18541718, 17.48791695], [73.18541718, 17.48847198], [73.18486023, 17.48847198], [73.18486023, 17.48958588], [73.1845932, 17.48958015], [73.1845932, 17.49014091], [73.18486023, 17.4901371], [73.18486023, 17.49069595], [73.18514252, 17.49069023], [73.18514252, 17.49126053], [73.18486023, 17.49126053], [73.18486023, 17.49180984], [73.18458557, 17.49180794], [73.18458557, 17.4920826], [73.18430328, 17.4920826], [73.18430328, 17.4948616], [73.18347168, 17.4948597], [73.18347168, 17.49514008], [73.18319702, 17.49514008], [73.18319702, 17.49570274], [73.18291473, 17.49569511], [73.18291473, 17.49597168], [73.18347168, 17.49597168], [73.18347168, 17.49625015], [73.18319702, 17.49625015], [73.18319702, 17.49681282], [73.1829071, 17.49681282], [73.1829071, 17.4979229], [73.18264008, 17.4979229], [73.18264008, 17.49875069], [73.18235779, 17.49875069], [73.18235779, 17.50041962], [73.18152618, 17.50041962], [73.18152618, 17.50125122], [73.18180847, 17.50124931], [73.18180847, 17.50208282], [73.18125153, 17.50208282], [73.18125153, 17.5023613], [73.18152618, 17.50235939], [73.18152618, 17.50292015], [73.18180847, 17.50292015], [73.18180847, 17.50320053], [73.18319702, 17.50319672], [73.18319702, 17.50347137], [73.18347168, 17.50346947], [73.18347168, 17.50374985], [73.18374634, 17.50374985], [73.18374634, 17.50403023], [73.18402863, 17.50403023], [73.18402863, 17.50569916], [73.18347168, 17.50569916], [73.18347168, 17.5051403], [73.18319702, 17.5051403], [73.18319702, 17.50457954], [73.18291473, 17.50458336], [73.18291473, 17.50402832], [73.18235779, 17.50402832], [73.18235779, 17.50430679], [73.18180847, 17.50430679], [73.18180847, 17.50458336], [73.18152618, 17.50457954], [73.18152618, 17.50764084], [73.18125153, 17.50764084], [73.18125153, 17.50791931], [73.18096924, 17.5079174], [73.18096924, 17.50819397], [73.18069458, 17.50819397], [73.18069458, 17.50847244], [73.18013763, 17.50847054], [73.18013763, 17.50985909], [73.17984772, 17.50985909], [73.17984772, 17.51042175], [73.17958069, 17.51041603], [73.17958069, 17.5106945], [73.17903137, 17.5106945], [73.17903137, 17.51041603], [73.17791748, 17.51041603], [73.17791748, 17.5106945], [73.17763519, 17.5106945], [73.17763519, 17.51097107], [73.17736053, 17.51097107], [73.17736053, 17.5118103], [73.17708588, 17.51180649], [73.17708588, 17.51236153], [73.17681122, 17.51235962], [73.17681122, 17.51320076], [73.17652893, 17.51319313], [73.17652893, 17.5134716], [73.17624664, 17.5134716], [73.17624664, 17.51458549], [73.17569733, 17.51458549], [73.17569733, 17.51486206], [73.17542267, 17.51486015], [73.17542267, 17.51514053], [73.17569733, 17.51514053], [73.17569733, 17.51653099], [73.17541504, 17.51652527], [73.17542267, 17.51736069], [73.17485809, 17.51736069], [73.17485809, 17.51764107], [73.17457581, 17.51764107], [73.17457581, 17.51791954], [73.17404175, 17.51791954], [73.17404175, 17.51819992], [73.17375183, 17.5181942], [73.17375183, 17.51847267], [73.17346954, 17.51847076], [73.17346954, 17.51875114], [73.17236328, 17.51875114], [73.17236328, 17.51847076], [73.17208099, 17.51847267], [73.17208099, 17.5181942], [73.17152405, 17.5181942], [73.17152405, 17.51847267], [73.1709671, 17.51847076], [73.1709671, 17.51875114], [73.17041779, 17.51875114], [73.17041779, 17.51930809], [73.1701355, 17.51930618], [73.1701355, 17.51958275], [73.16986084, 17.51958084], [73.16986084, 17.51986122], [73.16958618, 17.51986122], [73.16958618, 17.52041817], [73.16930389, 17.52041626], [73.16930389, 17.52124977], [73.16874695, 17.52124023], [73.16874695, 17.52152824], [73.16847229, 17.52152824], [73.16847229, 17.52180481], [73.16819763, 17.52179909], [73.16819763, 17.52292252], [73.16790771, 17.52292252], [73.16790771, 17.52375031], [73.16764069, 17.52375031], [73.16764069, 17.52403259], [73.1673584, 17.52402687], [73.1673584, 17.52430534], [73.16708374, 17.52430534], [73.16708374, 17.52458382], [73.16680908, 17.52458191], [73.16680908, 17.52514076], [73.16652679, 17.52513885], [73.16652679, 17.52597237], [73.16596985, 17.52597046], [73.16596985, 17.52625084], [73.16570282, 17.52625084], [73.16570282, 17.52653122], [73.16513824, 17.52653122], [73.16513824, 17.52680969], [73.16486359, 17.52680588], [73.16486359, 17.52708244], [73.16430664, 17.52708054], [73.16430664, 17.52737045], [73.16401672, 17.52737045], [73.16401672, 17.52763939], [73.16374969, 17.52763939], [73.16374969, 17.52791977], [73.16347504, 17.52791405], [73.16347504, 17.52819633], [73.16319275, 17.52819633], [73.16319275, 17.52847481], [73.16291809, 17.52847099], [73.16291809, 17.52874947], [73.1626358, 17.52874947], [73.1626358, 17.52931023], [73.16236115, 17.5293045], [73.16236115, 17.52986145], [73.16210175, 17.52985954], [73.16210175, 17.53013992], [73.1609726, 17.53013992], [73.1609726, 17.52985954], [73.16069794, 17.52986145], [73.16069794, 17.52958298], [73.16014099, 17.52958298], [73.16014099, 17.5293045], [73.15957642, 17.52931023], [73.15957642, 17.52902985], [73.1590271, 17.52902985], [73.1590271, 17.52874947], [73.1581955, 17.52874947], [73.1581955, 17.52847481], [73.15763855, 17.52847481], [73.15763855, 17.52819633], [73.15569305, 17.52819633], [73.15569305, 17.52847481], [73.1554184, 17.52847099], [73.1554184, 17.52874947], [73.15513611, 17.52874947], [73.15513611, 17.52902985], [73.15458679, 17.52902985], [73.15458679, 17.52931023], [73.1543045, 17.5293045], [73.1543045, 17.52986145], [73.15402985, 17.52985954], [73.15402985, 17.53125], [73.15374756, 17.53125], [73.15374756, 17.53153038], [73.1534729, 17.53152847], [73.1534729, 17.53319359], [73.15374756, 17.53318024], [73.15374756, 17.53430939], [73.15319824, 17.53430939], [73.15319061, 17.53403091], [73.1526413, 17.53403091], [73.1526413, 17.53375053], [73.15180206, 17.53375053], [73.15180206, 17.53458405], [73.1515274, 17.53457832], [73.1515274, 17.53513908], [73.15180206, 17.53513908], [73.15180206, 17.5359726], [73.15208435, 17.5359726], [73.15208435, 17.53624916], [73.15319824, 17.53623962], [73.15319824, 17.53652954], [73.15291595, 17.53652763], [73.15291595, 17.53736115], [73.15319824, 17.53736115], [73.15319824, 17.53819466], [73.15208435, 17.53819466], [73.15208435, 17.53847122], [73.1515274, 17.53847122], [73.1515274, 17.53874969], [73.15125275, 17.53874969], [73.15125275, 17.53903008], [73.15040588, 17.53903008], [73.15040588, 17.53874969], [73.1498642, 17.53874969], [73.1498642, 17.53847122], [73.14930725, 17.53847122], [73.14930725, 17.53874969], [73.14901733, 17.53874969], [73.14901733, 17.53903008], [73.14875031, 17.53902817], [73.14875031, 17.53958321], [73.14819336, 17.53958321], [73.14819336, 17.53986168], [73.14763641, 17.53985977], [73.14763641, 17.54042053], [73.14736176, 17.54042053], [73.14736176, 17.54070091], [73.1470871, 17.54070091], [73.1470871, 17.54125023], [73.14679718, 17.54125023], [73.14679718, 17.54096985], [73.14653015, 17.54096985], [73.14653015, 17.54125023], [73.14624786, 17.54125023], [73.14624786, 17.54153061], [73.14597321, 17.54153061], [73.14597321, 17.54181099], [73.14569092, 17.54180336], [73.14569092, 17.54208565], [73.14541626, 17.54207993], [73.14541626, 17.54236984], [73.14485931, 17.54236984], [73.14485931, 17.54264069], [73.14457703, 17.54264069], [73.14457703, 17.54292107], [73.14430237, 17.54291534], [73.14430237, 17.54319382], [73.14402771, 17.54319], [73.14402771, 17.54375076], [73.14373779, 17.54375076], [73.14373779, 17.54403114], [73.14347076, 17.54403114], [73.14347076, 17.54430962], [73.14291382, 17.54430771], [73.14291382, 17.54458427], [73.14263916, 17.54458046], [73.14263916, 17.54486084], [73.14235687, 17.54486084], [73.14235687, 17.54514122], [73.14208221, 17.54513931], [73.14208221, 17.54597282], [73.14180756, 17.54597282], [73.14180756, 17.54819489], [73.14152527, 17.54819489], [73.1415329, 17.54875183], [73.14125061, 17.54875183], [73.14125061, 17.54931259], [73.14097595, 17.54930496], [73.14097595, 17.54958344], [73.14069366, 17.54958344], [73.14069366, 17.54986191], [73.14041901, 17.54986191], [73.14041901, 17.55014038], [73.14013672, 17.55014038], [73.14013672, 17.55042267], [73.13986206, 17.55041695], [73.13986206, 17.5506916], [73.13957977, 17.55069542], [73.13957977, 17.55097008], [73.13930511, 17.55097008], [73.13931274, 17.55125046], [73.13903046, 17.55125046], [73.13903046, 17.55181122], [73.13874817, 17.5518055], [73.13874817, 17.55402946], [73.13874817, 17.55430984], [73.13847351, 17.55430412], [73.13847351, 17.5545826], [73.13819122, 17.55458069], [73.13819122, 17.55513954], [73.13793182, 17.55513954], [73.13793182, 17.55541992], [73.13764191, 17.5554142], [73.13764191, 17.55569649], [73.13735962, 17.55569649], [73.13735962, 17.55597305], [73.13708496, 17.55597305], [73.13708496, 17.5573616], [73.13735962, 17.55735016], [73.13735962, 17.55820084], [73.13764191, 17.55820084], [73.13764191, 17.55986023], [73.13791656, 17.55986023], [73.13791656, 17.56041718], [73.13819122, 17.56041718], [73.13819122, 17.56069374], [73.13846588, 17.56068993], [73.13846588, 17.56180954], [73.13874817, 17.56180954], [73.13874817, 17.56236076], [73.13903046, 17.56236076], [73.13903046, 17.56263924], [73.13931274, 17.56263924], [73.13931274, 17.56291962], [73.13986206, 17.56291962], [73.13986206, 17.56792068], [73.14013672, 17.56792068], [73.14013672, 17.56820107], [73.14041901, 17.56819344], [73.14041901, 17.56847191], [73.14125061, 17.56847], [73.14125061, 17.56875038], [73.14180756, 17.56875038], [73.14180756, 17.56903076], [73.14263916, 17.56903076], [73.14263916, 17.56931114], [73.14290619, 17.56931114], [73.14290619, 17.56986046], [73.14319611, 17.56986046], [73.14319611, 17.57014084], [73.14347076, 17.57014084], [73.14347076, 17.57042122], [73.14375305, 17.5704155], [73.14375305, 17.57069588], [73.14430237, 17.57069588], [73.14430237, 17.57097244], [73.14485931, 17.57097244], [73.14485931, 17.57069588], [73.14541626, 17.57069588], [73.14541626, 17.57097244], [73.14597321, 17.57097054], [73.14597321, 17.57125092], [73.14624786, 17.57125092], [73.14624786, 17.57152939], [73.14653015, 17.57152939], [73.14653015, 17.57180977], [73.14680481, 17.57180786], [73.14680481, 17.57208252], [73.14819336, 17.57208252], [73.14819336, 17.57236099], [73.14847565, 17.57236099], [73.14847565, 17.57263947], [73.14875031, 17.57263947], [73.14875031, 17.57291985], [73.14930725, 17.57291794], [73.14930725, 17.5731945], [73.14958191, 17.5731945], [73.14958191, 17.57347298], [73.1515274, 17.57347107], [73.1515274, 17.57374954], [73.15235901, 17.57374954], [73.15235901, 17.57347107], [73.1526413, 17.57347298], [73.1526413, 17.5731945], [73.15291595, 17.5731945], [73.15291595, 17.57291794], [73.1534729, 17.57291985], [73.1534729, 17.57263947], [73.15374756, 17.57263947], [73.15374756, 17.57234955], [73.15402985, 17.57236099], [73.15402985, 17.57180786], [73.15429688, 17.57180977], [73.15429688, 17.57125092], [73.15458679, 17.57125092], [73.15458679, 17.57102966], [73.15458679, 17.57069588], [73.15486145, 17.57069588], [73.15486145, 17.5704155], [73.15513611, 17.57042122], [73.15513611, 17.57014084], [73.1554184, 17.57014084], [73.1554184, 17.56986046], [73.1556778, 17.56986046], [73.1556778, 17.56847], [73.15513611, 17.56847191], [73.15513611, 17.56819344], [73.1554184, 17.56820107], [73.1554184, 17.5676403], [73.1556778, 17.5676403], [73.1556778, 17.56707954], [73.15597534, 17.56708336], [73.15597534, 17.56680489], [73.1570816, 17.56680489], [73.1570816, 17.56708336], [73.15736389, 17.56708336], [73.15736389, 17.56736183], [73.15763855, 17.56735992], [73.15763855, 17.5676403], [73.1598587, 17.5676403], [73.1598587, 17.56792068], [73.16014099, 17.56792068], [73.16014099, 17.56820107], [73.1609726, 17.56819344], [73.1609726, 17.56847191], [73.16319275, 17.56847], [73.16319275, 17.57014084], [73.16304016, 17.57014084], [73.16291809, 17.57014084], [73.16291809, 17.57042122], [73.1626358, 17.5704155], [73.1626358, 17.57069588], [73.16236115, 17.57069588], [73.16236115, 17.57097244], [73.16208649, 17.57097244], [73.16208649, 17.57125092], [73.1618042, 17.57125092], [73.1618042, 17.57236099], [73.16208649, 17.57236099], [73.16210175, 17.57430077], [73.16236115, 17.5743084], [73.16236115, 17.57513809], [73.16210175, 17.57513809], [73.16210175, 17.57542038], [73.16236115, 17.57542038], [73.16236115, 17.57570267], [73.1626358, 17.57570267], [73.1626358, 17.57625008], [73.16291809, 17.57625008], [73.16291809, 17.57653046], [73.16319275, 17.57653046], [73.16319275, 17.57681274], [73.16374969, 17.57680511], [73.16374969, 17.57708359], [73.16625214, 17.57708168], [73.16625214, 17.57736015], [73.16652679, 17.57736015], [73.16652679, 17.57792282], [73.16680908, 17.57792282], [73.16680908, 17.57875061], [73.16707611, 17.57875061], [73.16707611, 17.57930946], [73.1673584, 17.57930946], [73.1673584, 17.58014107], [73.16764069, 17.58013916], [73.16764069, 17.58069229], [73.16791534, 17.58069229], [73.16791534, 17.58152771], [73.16819763, 17.58152771], [73.16819763, 17.58208275], [73.16847229, 17.58208084], [73.16847229, 17.58236122], [73.1673584, 17.58236122], [73.1673584, 17.58292007], [73.16708374, 17.58291435], [73.16708374, 17.5834713], [73.16680908, 17.58346939], [73.16680908, 17.58374977], [73.16625214, 17.58374977], [73.16625214, 17.58403015], [73.16596985, 17.58402634], [73.16596985, 17.58430672], [73.16569519, 17.58430672], [73.16569519, 17.58486176], [73.1654129, 17.58485985], [73.1654129, 17.58514023], [73.16513824, 17.58514023], [73.16513824, 17.58569908], [73.16487122, 17.58569908], [73.16487122, 17.58680916], [73.16430664, 17.58680916], [73.16430664, 17.58764076], [73.16374969, 17.58764076], [73.16374969, 17.58791924], [73.16348267, 17.58791924], [73.16348267, 17.58902931], [73.16291809, 17.58902931], [73.16291809, 17.5893116], [73.1626358, 17.5893116], [73.16265106, 17.59013939], [73.16208649, 17.59013939], [73.16208649, 17.59032059], [73.16210175, 17.59124947], [73.16124725, 17.59124947], [73.16124725, 17.59152985], [73.16042328, 17.59152985], [73.16042328, 17.59181023], [73.15958405, 17.59180641], [73.15958405, 17.59208107], [73.15847015, 17.59208107], [73.15847015, 17.59180641], [73.15734863, 17.59180641], [73.15652466, 17.59180641], [73.15652466, 17.59208107], [73.1554184, 17.59208107], [73.1554184, 17.59236145], [73.15513611, 17.59235954], [73.15513611, 17.59263992], [73.15486145, 17.59263992], [73.15486145, 17.5929203], [73.15458679, 17.5929203], [73.15458679, 17.59320068], [73.15402985, 17.59320068], [73.15402985, 17.59375], [73.15374756, 17.59375], [73.15374756, 17.59403038], [73.1534729, 17.59403038], [73.1534729, 17.59431076], [73.15235901, 17.59431076], [73.15235901, 17.59514046], [73.15208435, 17.59513855], [73.15208435, 17.59567261], [73.15208435, 17.59597206], [73.15235901, 17.59597015], [73.15235901, 17.59680939], [73.1526413, 17.59680939], [73.1526413, 17.59736061], [73.15291595, 17.59736061], [73.15291595, 17.5984726], [73.15125275, 17.5984726], [73.15125275, 17.59819412], [73.1498642, 17.59819412], [73.1498642, 17.59791756], [73.14962769, 17.59791756], [73.14902496, 17.59791756], [73.14902496, 17.59819412], [73.14819336, 17.59819412], [73.14819336, 17.5984726], [73.1479187, 17.59847069], [73.1479187, 17.59875107], [73.14736176, 17.59875107], [73.14736176, 17.59902954], [73.1470871, 17.59902954], [73.1470871, 17.59958267], [73.14679718, 17.59958076], [73.14679718, 17.60013962], [73.14597321, 17.60013962], [73.14597321, 17.60041809], [73.14541626, 17.60041618], [73.14541626, 17.60069466], [73.14485931, 17.60069466], [73.14485931, 17.60097313], [73.14457703, 17.60097122], [73.14457703, 17.60124969], [73.14430237, 17.60124969], [73.14430237, 17.60152817], [73.14402771, 17.60152817], [73.14402771, 17.60180473], [73.14373779, 17.60180092], [73.14373779, 17.60292244], [73.14347076, 17.60292244], [73.14347076, 17.60320282], [73.14319611, 17.60320282], [73.14319611, 17.60375023], [73.14290619, 17.60375023], [73.14290619, 17.60403061], [73.1423645, 17.6040287], [73.1423645, 17.60458374], [73.14208221, 17.60458183], [73.14208221, 17.60514069], [73.14152527, 17.60513878], [73.14152527, 17.60569382], [73.14125061, 17.60569382], [73.14125061, 17.60597229], [73.14067841, 17.60597038], [73.14067841, 17.60653114], [73.14041901, 17.60653114], [73.14041901, 17.60736084], [73.14013672, 17.60736084], [73.14013672, 17.60791969], [73.13986206, 17.60791969], [73.13986206, 17.60874939], [73.13957977, 17.60874939], [73.13957977, 17.60902977], [73.13931274, 17.60902977], [73.13931274, 17.60931015], [73.13903046, 17.60930443], [73.13903046, 17.6095829], [73.13846588, 17.60958099], [73.13846588, 17.61013985], [73.13819122, 17.61013985], [73.13819122, 17.61042023], [73.13791656, 17.61041451], [73.13791656, 17.61097145], [73.13735962, 17.61096954], [73.13735962, 17.61181068], [73.13708496, 17.61180687], [73.13708496, 17.61236191], [73.13680267, 17.61235809], [73.13680267, 17.61292076], [73.13652802, 17.61291885], [73.13652802, 17.61347198], [73.13625336, 17.61346817], [73.13625336, 17.61375046], [73.13597107, 17.61375046], [73.13597107, 17.61430931], [73.13569641, 17.61430931], [73.13569641, 17.6145916], [73.13597107, 17.6145916], [73.13597107, 17.61486053], [73.13569641, 17.61486053], [73.13569641, 17.61624908], [73.13541412, 17.61624908], [73.13541412, 17.6170826], [73.13513947, 17.6170826], [73.13513947, 17.61847115], [73.13486481, 17.61847115], [73.13486481, 17.62069321], [73.13458252, 17.62069321], [73.13458252, 17.62097168], [73.13430786, 17.62096977], [73.13430786, 17.62181091], [73.1340332, 17.62181091], [73.1340332, 17.62430954], [73.13375092, 17.62430954], [73.13375092, 17.62541962], [73.13346863, 17.62541771], [73.13346863, 17.6273613], [73.13319397, 17.6273613], [73.13319397, 17.62819481], [73.13291931, 17.62818909], [73.13291931, 17.62875175], [73.13263702, 17.62875175], [73.13263702, 17.62903023], [73.13236237, 17.62903023], [73.13236237, 17.6295929], [73.13180542, 17.62958336], [73.13180542, 17.62986183], [73.13153076, 17.62986183], [73.13153076, 17.63070107], [73.13124847, 17.63069534], [73.13124847, 17.63298035], [73.13124847, 17.63319206], [73.13097382, 17.63319206], [73.13096619, 17.63356972], [73.13096619, 17.63375092], [73.13069153, 17.63375092], [73.13066864, 17.63416862], [73.13066101, 17.63430977], [73.13041687, 17.63430405], [73.13039398, 17.6347599], [73.13038635, 17.63486099], [73.13014221, 17.63486099], [73.13014221, 17.63513947], [73.12930298, 17.63513947], [73.12930298, 17.63541985], [73.12902832, 17.63541412], [73.12902832, 17.6356945], [73.12847137, 17.6356945], [73.12847137, 17.63597488], [73.1279068, 17.63597107], [73.1279068, 17.63624954], [73.12763977, 17.63624954], [73.12763977, 17.63652992], [73.12735748, 17.63652611], [73.12735748, 17.63708305], [73.12708282, 17.63708115], [73.12708282, 17.63764], [73.12735748, 17.63764], [73.12735748, 17.63875961], [73.12763977, 17.63875961], [73.12763977, 17.63903046], [73.1279068, 17.63903046], [73.1279068, 17.63931084], [73.12819672, 17.63930511], [73.12819672, 17.63986206], [73.12791443, 17.63986206], [73.12791443, 17.64069366], [73.12819672, 17.64068985], [73.12819672, 17.64125061], [73.12847137, 17.64125061], [73.12847137, 17.64152908], [73.12902832, 17.64152908], [73.12902832, 17.64182281], [73.12930298, 17.64180565], [73.12930298, 17.64208412], [73.12958527, 17.64208412], [73.12958527, 17.64236069], [73.12985992, 17.64236069], [73.12985992, 17.64263916], [73.13014221, 17.64263916], [73.13014221, 17.6431942], [73.13041687, 17.6431942], [73.13041687, 17.64347267], [73.13069153, 17.64347076], [73.13069153, 17.64375114], [73.13153076, 17.64375114], [73.13153076, 17.64402962], [73.13208008, 17.64402962], [73.13208008, 17.6443119], [73.133461, 17.6443119], [73.13346863, 17.64402962], [73.1340332, 17.64402962], [73.1340332, 17.64375114], [73.13485718, 17.64375114], [73.13485718, 17.64402962], [73.13513947, 17.64402962], [73.13513947, 17.6443119], [73.13569641, 17.64430618], [73.13569641, 17.64458275], [73.13540649, 17.6445694], [73.13540649, 17.64486122], [73.13513947, 17.64486122], [73.13513947, 17.64513969], [73.13485718, 17.64513969], [73.13485718, 17.64820099], [73.13458252, 17.64820099], [73.13458252, 17.64903069], [73.13430786, 17.64903069], [73.13430786, 17.65042114], [73.13402557, 17.65041542], [73.13402557, 17.65097237], [73.13375092, 17.65097046], [73.13375092, 17.65125084], [73.13346863, 17.65125084], [73.13346863, 17.65319443], [73.13318634, 17.65319061], [73.13318634, 17.65376091], [73.13291931, 17.65376091], [73.13291931, 17.65402985], [73.13263702, 17.65402985], [73.13263702, 17.65458298], [73.13236237, 17.65458298], [73.13236237, 17.65486145], [73.13208008, 17.65485764], [73.13208008, 17.6554203], [73.13179779, 17.6554203], [73.13179779, 17.65570259], [73.13153076, 17.65569496], [73.13153076, 17.65597153], [73.13124847, 17.65597153], [73.13124847, 17.65680504], [73.13041687, 17.65680504], [73.13041687, 17.65708351], [73.13014221, 17.6570816], [73.13014221, 17.65764046], [73.12985992, 17.65763855], [73.12985992, 17.65819359], [73.12958527, 17.65819359], [73.12958527, 17.65847206], [73.12798309, 17.65847015], [73.12708282, 17.65847015], [73.12708282, 17.65875053], [73.12652588, 17.65875053], [73.12652588, 17.65930939], [73.12625122, 17.65930939], [73.12625122, 17.66041946], [73.12652588, 17.66041946], [73.12652588, 17.66152954], [73.12625122, 17.66152954], [73.12625122, 17.66180992], [73.12596893, 17.66180992], [73.12596893, 17.66236115], [73.12513733, 17.66236115], [73.12513733, 17.66319656], [73.12541962, 17.66319656], [73.12541962, 17.66430473], [73.12403107, 17.66430473], [73.12403107, 17.66458321], [73.12291718, 17.66458321], [73.12291718, 17.66486168], [73.1220932, 17.66485977], [73.1220932, 17.66514015], [73.12180328, 17.66513634], [73.12180328, 17.66597176], [73.12152863, 17.66596985], [73.12152863, 17.66653061], [73.12124634, 17.66653061], [73.12124634, 17.66736031], [73.12097168, 17.66736031], [73.12097168, 17.66791916], [73.12069702, 17.66791725], [73.12069702, 17.66819382], [73.12097168, 17.66819382], [73.12097168, 17.66875076], [73.12124634, 17.66875076], [73.12124634, 17.67069435], [73.12069702, 17.67069435], [73.12069702, 17.67097282], [73.11985779, 17.67097282], [73.11985779, 17.67124939], [73.11930847, 17.67124939], [73.11930847, 17.67152977], [73.11902618, 17.67152786], [73.11902618, 17.67180634], [73.11875153, 17.67180634], [73.11875153, 17.67236137], [73.11846924, 17.67236137], [73.11846924, 17.67347145], [73.11819458, 17.67347145], [73.11819458, 17.67458344], [73.11791992, 17.67458344], [73.11791992, 17.6756897], [73.11763763, 17.67570114], [73.11763763, 17.67653084], [73.11791992, 17.67653084], [73.11791992, 17.67764091], [73.11763763, 17.6776371], [73.11763763, 17.67847252], [73.11653137, 17.67847061], [73.11653137, 17.67875099], [73.1159668, 17.67875099], [73.1159668, 17.67930984], [73.11569214, 17.67930984], [73.11569214, 17.67986107], [73.11541748, 17.67986107], [73.11541748, 17.68124962], [73.11514282, 17.68124962], [73.11514282, 17.68320274], [73.11541748, 17.68319511], [73.11541748, 17.68375015], [73.11458588, 17.68375015], [73.11458588, 17.68458366], [73.11430359, 17.68458366], [73.11430359, 17.68569374], [73.11458588, 17.68569183], [73.11458588, 17.68625069], [73.11486053, 17.68625069], [73.11486053, 17.68653107], [73.11458588, 17.68653107], [73.11458588, 17.68764114], [73.11429596, 17.68764114], [73.11429596, 17.68875122], [73.11402893, 17.68875122], [73.11402893, 17.68931007], [73.11374664, 17.68930435], [73.11374664, 17.69097137], [73.11402893, 17.69096947], [73.11402893, 17.69153023], [73.11430359, 17.69152641], [73.11430359, 17.69236183], [73.11458588, 17.69235992], [73.11458588, 17.69403076], [73.11402893, 17.69403076], [73.11402893, 17.69430923], [73.11429596, 17.69430923], [73.11429596, 17.69486046], [73.11458588, 17.69486046], [73.11458588, 17.69541931], [73.11486053, 17.6954174], [73.11486053, 17.69569397], [73.11513519, 17.69569397], [73.11513519, 17.69597244], [73.11541748, 17.69597054], [73.11541748, 17.69625092], [73.11569214, 17.69625092], [73.11569214, 17.69652939], [73.1159668, 17.69652939], [73.1159668, 17.69681168], [73.11624908, 17.69680595], [73.11624908, 17.69708252], [73.11653137, 17.69708252], [73.11653137, 17.69763947], [73.1167984, 17.69763947], [73.1167984, 17.69791985], [73.11708069, 17.69791603], [73.11708069, 17.6981945], [73.11736298, 17.6981926], [73.11736298, 17.69874954], [73.11902618, 17.69874954], [73.11902618, 17.69930458], [73.11985779, 17.69930458], [73.11985779, 17.69902802], [73.12097168, 17.69902802], [73.12097168, 17.69930267], [73.12124634, 17.6993103], [73.12124634, 17.70014], [73.12152863, 17.70014], [73.12152863, 17.70042038], [73.12291718, 17.70042038], [73.12291718, 17.70014], [73.12319183, 17.70014], [73.12319183, 17.70042038], [73.12374878, 17.70042038], [73.12374878, 17.70014954], [73.12458038, 17.70014], [73.12458038, 17.70042038], [73.12486267, 17.70041656], [73.12486267, 17.70087051], [73.12486267, 17.7009716], [73.12502289, 17.7009697], [73.12513733, 17.7009697], [73.12513733, 17.70125008], [73.12486267, 17.70125008], [73.12486267, 17.70181084], [73.12513733, 17.70180321], [73.12513733, 17.70208359], [73.12596893, 17.70207977], [73.12596893, 17.70236015], [73.12680054, 17.70236206], [73.12708282, 17.70236206], [73.12708282, 17.70283127], [73.12708282, 17.70319366], [73.12727356, 17.70319366], [73.12735748, 17.70319366], [73.12735748, 17.70403099], [73.12763977, 17.70402527], [73.12763977, 17.70458412], [73.1279068, 17.70458031], [73.1279068, 17.70514107], [73.12847137, 17.70516014], [73.12847137, 17.70541954], [73.12861633, 17.70541763], [73.12875366, 17.70541763], [73.12875366, 17.7056942], [73.12930298, 17.7056942], [73.12930298, 17.70597267], [73.12985992, 17.70597076], [73.12985992, 17.70625114], [73.13041687, 17.70625114], [73.13041687, 17.70652962], [73.13179779, 17.70652962], [73.13179779, 17.70625114], [73.13291931, 17.70625114], [73.13291931, 17.70652962], [73.13318634, 17.70652962], [73.13318634, 17.70680809], [73.13346863, 17.70680618], [73.13346863, 17.70708275], [73.13375092, 17.70708084], [73.13375092, 17.70736122], [73.13458252, 17.70736122], [73.13458252, 17.70791626], [73.13486481, 17.70791626], [73.13486481, 17.70763969], [73.13569641, 17.70763969], [73.13569641, 17.70791626], [73.13513947, 17.70791626], [73.13513947, 17.70819473], [73.13485718, 17.70819092], [73.13485718, 17.70874977], [73.13458252, 17.70874977], [73.13458252, 17.70930481], [73.13486481, 17.70930481], [73.13486481, 17.70986176], [73.13513947, 17.70986176], [73.13513947, 17.71153069], [73.13540649, 17.71153069], [73.13540649, 17.71181107], [73.13513947, 17.71181107], [73.13513947, 17.71292114], [73.13486481, 17.71291733], [73.13486481, 17.71319389], [73.13458252, 17.71319008], [73.13458252, 17.71486092], [73.13486481, 17.71486092], [73.13486481, 17.71569443], [73.13513947, 17.71569061], [73.13513947, 17.71624947], [73.13485718, 17.71624947], [73.13485718, 17.71652985], [73.13458252, 17.71652985], [73.13458252, 17.71681023], [73.13430786, 17.71681023], [73.13430786, 17.71763992], [73.1340332, 17.71763992], [73.1340332, 17.7179203], [73.13375092, 17.7179203], [73.13375092, 17.71874809], [73.13346863, 17.71874809], [73.13346863, 17.72125053], [73.13318634, 17.72125053], [73.13318634, 17.72180939], [73.13291931, 17.72180939], [73.13291931, 17.72236061], [73.13263702, 17.72236061], [73.13263702, 17.72319412], [73.13236237, 17.72319412], [73.13236237, 17.7234726], [73.13263702, 17.72347069], [73.13263702, 17.72402954], [73.13291931, 17.72402954], [73.13291931, 17.72431183], [73.13236237, 17.72430611], [73.13236237, 17.72458267], [73.13208008, 17.72458267], [73.13208008, 17.72513962], [73.13179779, 17.72513962], [73.13179779, 17.72624969], [73.13153076, 17.72624969], [73.13153076, 17.72680473], [73.13180542, 17.72680473], [73.13180542, 17.72708321], [73.13124847, 17.72707939], [73.13124847, 17.72792053], [73.13153076, 17.72792053], [73.13153076, 17.72820091], [73.13124847, 17.72820091], [73.13124847, 17.72875023], [73.13096619, 17.72875023], [73.13096619, 17.72931099], [73.13069153, 17.72930336], [73.13069153, 17.72958374], [73.13041687, 17.72957993], [73.13041687, 17.72986031], [73.12985992, 17.72986031], [73.12985992, 17.73014069], [73.12902832, 17.73013878], [73.12902832, 17.73097229], [73.1287384, 17.73097038], [73.1287384, 17.73180962], [73.12847137, 17.73180962], [73.12847137, 17.73264122], [73.12819672, 17.73263931], [73.12819672, 17.73319435], [73.1279068, 17.73319054], [73.1279068, 17.7365303], [73.12819672, 17.7365284], [73.12819672, 17.73736191], [73.12847137, 17.73736191], [73.12847137, 17.73792267], [73.12819672, 17.73791695], [73.12819672, 17.7381916], [73.12791443, 17.73819542], [73.12791443, 17.73847389], [73.12819672, 17.73847008], [73.12819672, 17.73875046], [73.12847137, 17.73875046], [73.12847137, 17.73903275], [73.12819672, 17.73902702], [73.12819672, 17.73958206], [73.1279068, 17.73958015], [73.1279068, 17.74014091], [73.12763977, 17.74013901], [73.12763977, 17.74069214], [73.12708282, 17.74069023], [73.12708282, 17.74098015], [73.1257019, 17.74098015], [73.1257019, 17.74125099], [73.12541962, 17.74125099], [73.12541962, 17.74152946], [73.12486267, 17.74152946], [73.12486267, 17.74263954], [73.12541962, 17.74263954], [73.12541962, 17.74291992], [73.12569427, 17.7429142], [73.12569427, 17.74319458], [73.12541962, 17.74319458], [73.12541962, 17.74347305], [73.12513733, 17.74347305], [73.12513733, 17.74458313], [73.12486267, 17.74458122], [73.12486267, 17.74570084], [73.12458038, 17.74569511], [73.12458038, 17.74597168], [73.12431335, 17.74596977], [73.12431335, 17.74653053], [73.12403107, 17.74652863], [73.12403107, 17.74708366], [73.12374878, 17.74707985], [73.12374878, 17.74791908], [73.12346649, 17.74791908], [73.12346649, 17.75125122], [73.12374878, 17.75125122], [73.12374878, 17.75181007], [73.12403107, 17.75181007], [73.12403107, 17.75263977], [73.12374878, 17.75263977], [73.12374878, 17.75292015], [73.12347412, 17.75291634], [73.12347412, 17.75319481], [73.12319183, 17.75319481], [73.12319183, 17.75347137], [73.12291718, 17.75346947], [73.12291718, 17.75374985], [73.12264252, 17.75374985], [73.12264252, 17.75430489], [73.12236023, 17.75430489], [73.12236023, 17.75486183], [73.1220932, 17.75485992], [73.1220932, 17.7551403], [73.12180328, 17.7551403], [73.12180328, 17.75542068], [73.12152863, 17.75542068], [73.12152863, 17.75625038], [73.12124634, 17.75625038], [73.12124634, 17.75653076], [73.12097168, 17.75652695], [73.12097168, 17.7570858], [73.12069702, 17.75708008], [73.12069702, 17.75736046], [73.1204071, 17.75736046], [73.1204071, 17.75764084], [73.12014008, 17.75763893], [73.12014008, 17.75819397], [73.11985779, 17.75819016], [73.11985779, 17.75875092], [73.11956787, 17.75875092], [73.11956787, 17.75930977], [73.11930847, 17.75930786], [73.11930847, 17.75947189], [73.11930847, 17.76097298], [73.11902618, 17.76096916], [73.11902618, 17.76124954], [73.11930847, 17.76124954], [73.11930847, 17.7618084], [73.11902618, 17.7618084], [73.11902618, 17.76209259], [73.11875153, 17.76209259], [73.11875153, 17.76292038], [73.11846924, 17.76291656], [73.11846924, 17.76569366], [73.11819458, 17.76569366], [73.11819458, 17.76597214], [73.11763763, 17.76597023], [73.11763763, 17.7665329], [73.11736298, 17.76652718], [73.11736298, 17.76708221], [73.11721039, 17.76708221], [73.11708069, 17.76708221], [73.11708069, 17.76756287], [73.11708069, 17.76763916], [73.1167984, 17.76764107], [73.1167984, 17.76791954], [73.11653137, 17.76791763], [73.11653137, 17.76847267], [73.11624908, 17.76847076], [73.11624908, 17.76875114], [73.11653137, 17.76874924], [73.11653137, 17.76958275], [73.11624908, 17.76958084], [73.11624908, 17.76986122], [73.11569214, 17.76986122], [73.11569214, 17.77042007], [73.11513519, 17.77041435], [73.11514282, 17.77124977], [73.11486053, 17.77124977], [73.11486053, 17.77292061], [73.11458588, 17.77292061], [73.11458588, 17.77319908], [73.11430359, 17.77319527], [73.11430359, 17.77347183], [73.11402893, 17.77346992], [73.11402893, 17.77403069], [73.1137619, 17.77403069], [73.1137619, 17.77541924], [73.11347198, 17.77541733], [73.11347198, 17.77597237], [73.11319733, 17.77596855], [73.11319733, 17.77652931], [73.11292267, 17.77652931], [73.11292267, 17.77709007], [73.11319733, 17.77708244], [73.11319733, 17.77819443], [73.11291504, 17.77819443], [73.11291504, 17.77958107], [73.11264038, 17.77958107], [73.11264038, 17.7799511], [73.11264038, 17.78013802], [73.11250305, 17.78013802], [73.11235809, 17.78013802], [73.11235809, 17.78030968], [73.11235809, 17.78097153], [73.11207581, 17.78096962], [73.11207581, 17.78153038], [73.11180878, 17.78153038], [73.11180878, 17.78292084], [73.11152649, 17.78292084], [73.11152649, 17.78430939], [73.11125183, 17.78430939], [73.11125183, 17.78541946], [73.11096954, 17.78541946], [73.11096954, 17.7862606], [73.11069489, 17.78624725], [73.11069489, 17.78708267], [73.11042023, 17.78708076], [73.11042023, 17.78763962], [73.11013794, 17.78763962], [73.11013794, 17.78791809], [73.10986328, 17.78791618], [73.10986328, 17.78819466], [73.10958099, 17.78819466], [73.10958099, 17.78847313], [73.10986328, 17.78847122], [73.10986328, 17.78903008], [73.11013794, 17.78903008], [73.11013794, 17.78874969], [73.11042023, 17.78874969], [73.11042023, 17.78847122], [73.11096954, 17.78847313], [73.11096954, 17.78791618], [73.11125183, 17.78791809], [73.11125183, 17.78763962], [73.11069489, 17.78763962], [73.11069489, 17.78736115], [73.11096954, 17.78736115], [73.11096954, 17.78708076], [73.11125183, 17.78708267], [73.11125183, 17.78680611], [73.11235809, 17.78680992], [73.11235809, 17.78736115], [73.11208344, 17.78736115], [73.11208344, 17.78819466], [73.11180878, 17.78819084], [73.11180878, 17.78903008], [73.11208344, 17.78902817], [73.11208344, 17.78958321], [73.11125183, 17.78958321], [73.11125183, 17.78986168], [73.11096954, 17.78986168], [73.11096954, 17.79014015], [73.10901642, 17.79014015], [73.10901642, 17.79042053], [73.1084671, 17.79042053], [73.1084671, 17.79070282], [73.10819244, 17.79069519], [73.10819244, 17.79097176], [73.10791779, 17.79097176], [73.10791779, 17.79125023], [73.10762787, 17.79125023], [73.10762787, 17.7918129], [73.10736084, 17.79180527], [73.10736084, 17.79208374], [73.10708618, 17.79206848], [73.10708618, 17.79264069], [73.10680389, 17.79263878], [73.10680389, 17.79319382], [73.10652924, 17.79319382], [73.10652924, 17.79347229], [73.10624695, 17.79347038], [73.10624695, 17.79375076], [73.10597229, 17.79375076], [73.10597229, 17.79486084], [73.10569763, 17.79486084], [73.10569763, 17.79513931], [73.10514069, 17.79512978], [73.10514069, 17.79541969], [73.1048584, 17.79541588], [73.1048584, 17.79597282], [73.10514069, 17.79597092], [73.10514069, 17.79652977], [73.1048584, 17.79652786], [73.1048584, 17.7970829], [73.10456848, 17.79708099], [73.10456848, 17.79763985], [73.10430908, 17.79763985], [73.10430908, 17.79820061], [73.10402679, 17.79819679], [73.10402679, 17.79847145], [73.10346985, 17.79847145], [73.10346985, 17.79986191], [73.10375214, 17.79985809], [73.10375214, 17.80042076], [73.10346985, 17.80041885], [73.10346985, 17.80097198], [73.10320282, 17.80096817], [73.10320282, 17.80291939], [73.10263824, 17.80291748], [73.10263824, 17.80319405], [73.10236359, 17.80319405], [73.10236359, 17.80347252], [73.1018219, 17.80347061], [73.1018219, 17.8037529], [73.10124969, 17.8037529], [73.10124969, 17.80318832], [73.10069275, 17.80319405], [73.10069275, 17.80347252], [73.10041809, 17.80347061], [73.10041809, 17.80486107], [73.10069275, 17.80486107], [73.10069275, 17.80569458], [73.10041809, 17.80569458], [73.10041809, 17.80597115], [73.1001358, 17.80597115], [73.1001358, 17.80624962], [73.09986115, 17.80624962], [73.09986115, 17.80653], [73.09958649, 17.80652809], [73.09958649, 17.80680466], [73.0993042, 17.80680466], [73.0993042, 17.80708313], [73.09874725, 17.80708313], [73.09874725, 17.8073616], [73.0984726, 17.8073597], [73.0984726, 17.80792046], [73.09625244, 17.80792046], [73.09625244, 17.80875015], [73.0965271, 17.80875015], [73.0965271, 17.81014061], [73.09625244, 17.81014061], [73.09625244, 17.81042099], [73.09597015, 17.81041527], [73.09597015, 17.81069374], [73.0956955, 17.81069374], [73.0956955, 17.81097221], [73.09485626, 17.81097031], [73.09485626, 17.81125069], [73.09430695, 17.81125069], [73.09430695, 17.81153107], [73.09179688, 17.81153107], [73.09179688, 17.81180954], [73.09041595, 17.81180954], [73.09041595, 17.81153107], [73.0901413, 17.81153107], [73.0901413, 17.81098747], [73.08985901, 17.81097031], [73.08985901, 17.81041527], [73.08959198, 17.81042099], [73.08959198, 17.80986023], [73.08930206, 17.80986023], [73.08930206, 17.80931091], [73.08959198, 17.80931091], [73.08959198, 17.80903053], [73.08985901, 17.80903053], [73.08985901, 17.80846977], [73.08958435, 17.80847168], [73.08958435, 17.80819321], [73.08930206, 17.80820084], [73.08930206, 17.80792046], [73.08875275, 17.80792046], [73.08875275, 17.80820084], [73.08847046, 17.80820084], [73.08847046, 17.80931091], [73.08875275, 17.80930328], [73.08875275, 17.81069374], [73.0890274, 17.81068993], [73.0890274, 17.81180954], [73.08875275, 17.81180954], [73.08875275, 17.81236076], [73.0890274, 17.81236076], [73.0890274, 17.81291962], [73.08918762, 17.81291962], [73.08959198, 17.81291962], [73.08959198, 17.81319809], [73.08985901, 17.81319809], [73.08985901, 17.81291962], [73.09069824, 17.81291962], [73.09069824, 17.81319809], [73.0909729, 17.81319809], [73.0909729, 17.81402969], [73.09069824, 17.81402969], [73.09069824, 17.81430817], [73.09041595, 17.81430626], [73.09041595, 17.81458282], [73.0901413, 17.81458282], [73.0901413, 17.8148613], [73.08930206, 17.8148613], [73.08930206, 17.81569481], [73.0890274, 17.81569481], [73.0890274, 17.81597137], [73.08930206, 17.81597137], [73.08930206, 17.81625938], [73.08959198, 17.81625938], [73.08959198, 17.81653023], [73.0901413, 17.81652832], [73.0901413, 17.81680489], [73.09263611, 17.81680489], [73.09263611, 17.81708336], [73.09319305, 17.81708336], [73.09319305, 17.81736183], [73.09348297, 17.81736183], [73.09348297, 17.81820107], [73.09319305, 17.81820107], [73.09319305, 17.81875038], [73.0929184, 17.81875038], [73.0929184, 17.81958389], [73.09319305, 17.81958008], [73.09319305, 17.82014084], [73.09375, 17.82014084], [73.09375, 17.82042122], [73.09402466, 17.8204174], [73.09402466, 17.82069206], [73.0945816, 17.82069206], [73.0945816, 17.82097244], [73.09485626, 17.82097054], [73.09485626, 17.82152939], [73.0945816, 17.82152939], [73.0945816, 17.82180977], [73.09430695, 17.82180405], [73.09430695, 17.82208252], [73.0945816, 17.82208061], [73.0945816, 17.82263947], [73.09430695, 17.82263947], [73.09430695, 17.82291985], [73.0945816, 17.82291985], [73.0945816, 17.82374954], [73.09485626, 17.82374954], [73.09485626, 17.82402992], [73.0945816, 17.82402992], [73.0945816, 17.82514], [73.09430695, 17.82514], [73.09430695, 17.82624817], [73.09402466, 17.82624817], [73.09402466, 17.82708359], [73.09375, 17.82707977], [73.09375, 17.82764053], [73.09347534, 17.82764053], [73.09347534, 17.82819366], [73.09319305, 17.82818031], [73.09319305, 17.82875061], [73.0929184, 17.82875061], [73.0929184, 17.82930946], [73.09263611, 17.82930565], [73.09263611, 17.82958412], [73.09236145, 17.8295784], [73.09236145, 17.83013916], [73.09208679, 17.83013916], [73.09208679, 17.83097267], [73.09236145, 17.83097267], [73.09236145, 17.83124924], [73.09208679, 17.83124161], [73.09208679, 17.8318119], [73.09179688, 17.8318119], [73.09179688, 17.83236122], [73.09152985, 17.83236122], [73.09152985, 17.83319473], [73.09041595, 17.83319283], [73.09041595, 17.83374977], [73.0901413, 17.83374977], [73.0901413, 17.83430481], [73.08943176, 17.83430481], [73.08875275, 17.83430481], [73.08875275, 17.83511162], [73.08875275, 17.83542061], [73.08959198, 17.83542061], [73.08959198, 17.83570099], [73.08930206, 17.83569336], [73.08930206, 17.83597183], [73.0890274, 17.83596992], [73.0890274, 17.83625031], [73.08875275, 17.83625031], [73.08875275, 17.83653069], [73.08847046, 17.83653069], [73.08847046, 17.83681107], [73.0881958, 17.83680534], [73.0881958, 17.83708382], [73.08805084, 17.83708191], [73.08790588, 17.83708], [73.08790588, 17.83736992], [73.08763885, 17.83736038], [73.08763885, 17.83819389], [73.08735657, 17.83819008], [73.08735657, 17.83875084], [73.08763885, 17.83875084], [73.08763885, 17.83903122], [73.0881958, 17.8390255], [73.0881958, 17.83961105], [73.0881958, 17.84013939], [73.08847046, 17.84013939], [73.08847046, 17.84069443], [73.08875275, 17.84069443], [73.08875275, 17.8409729], [73.0890274, 17.84096909], [73.0890274, 17.84124756], [73.08930206, 17.84124756], [73.08930206, 17.84152985], [73.08985901, 17.84152985], [73.08985901, 17.84124756], [73.09069824, 17.84124756], [73.09069824, 17.84152985], [73.09262848, 17.84152985], [73.09262848, 17.84180832], [73.09375, 17.84180832], [73.09375, 17.84152985], [73.09485626, 17.84152985], [73.09485626, 17.84096909], [73.09597015, 17.84096909], [73.09597015, 17.84124756], [73.0965271, 17.84124756], [73.0965271, 17.84152985], [73.09707642, 17.84152985], [73.09707642, 17.84124756], [73.0973587, 17.84124756], [73.0973587, 17.84096909], [73.09874725, 17.8409729], [73.09874725, 17.84069443], [73.0993042, 17.84069443], [73.0993042, 17.84041786], [73.10098267, 17.84042931], [73.10098267, 17.84013939], [73.1029129, 17.84013939], [73.1029129, 17.83986092], [73.10346985, 17.83986092], [73.10346985, 17.83958054], [73.10375214, 17.83958244], [73.10375214, 17.8390255], [73.10514069, 17.83903122], [73.10514069, 17.83875084], [73.10569763, 17.83875084], [73.10569763, 17.83847046], [73.10597229, 17.83847237], [73.10597229, 17.83791542], [73.10679626, 17.83792114], [73.10679626, 17.83764076], [73.10708618, 17.83764076], [73.10708618, 17.83736992], [73.10736084, 17.83736992], [73.10736084, 17.83708], [73.1076355, 17.83708382], [73.1076355, 17.83680534], [73.10791779, 17.83681107], [73.10791779, 17.83653069], [73.10819244, 17.83653069], [73.10819244, 17.83625031], [73.1084671, 17.83625031], [73.1084671, 17.83596992], [73.10874939, 17.83597183], [73.10874939, 17.83569336], [73.10930634, 17.83570099], [73.10930634, 17.83542061], [73.10958099, 17.83542061], [73.10958099, 17.83514023], [73.10986328, 17.83514023], [73.10986328, 17.83485985], [73.11125183, 17.83486176], [73.11125183, 17.83458328], [73.11291504, 17.83458328], [73.11291504, 17.83430481], [73.11402893, 17.83430481], [73.11402893, 17.83402824], [73.11458588, 17.83403015], [73.11458588, 17.83374977], [73.11486053, 17.83374977], [73.11486053, 17.83346939], [73.11708069, 17.83346939], [73.11708069, 17.83374977], [73.11819458, 17.83374977], [73.11819458, 17.83430481], [73.11958313, 17.83430481], [73.11958313, 17.83458328], [73.11985779, 17.83458328], [73.11985779, 17.83486176], [73.12014008, 17.83485985], [73.12014008, 17.83514023], [73.12069702, 17.83514023], [73.12069702, 17.83542061], [73.12291718, 17.83542061], [73.12291718, 17.83570099], [73.12430573, 17.83569336], [73.12430573, 17.83597183], [73.12486267, 17.83597183], [73.12486267, 17.83541679], [73.12513733, 17.83542061], [73.12513733, 17.83514023], [73.1257019, 17.83514023], [73.1257019, 17.83485985], [73.12625122, 17.83486176], [73.12625122, 17.83458328], [73.12652588, 17.83458328], [73.12652588, 17.83430481], [73.12708282, 17.83430481], [73.12708282, 17.83402824], [73.12735748, 17.83403015], [73.12735748, 17.83374977], [73.12847137, 17.83374977], [73.12847137, 17.83346939], [73.12902832, 17.8334713], [73.12902832, 17.83319473], [73.12930298, 17.83319473], [73.12930298, 17.83263969], [73.1295929, 17.83263969], [73.12958527, 17.83236122], [73.12985992, 17.83236122], [73.12985992, 17.8318119], [73.13014221, 17.8318119], [73.13014221, 17.83152962], [73.13041687, 17.83152962], [73.13041687, 17.83097267], [73.13069153, 17.83097267], [73.13069153, 17.83041573], [73.13096619, 17.83041954], [73.13096619, 17.82986069], [73.13124847, 17.82986069], [73.13124847, 17.82930946], [73.13153076, 17.82930946], [73.13153076, 17.82875061], [73.13179779, 17.82875061], [73.13179779, 17.82818031], [73.13208008, 17.82819366], [73.13208008, 17.82764053], [73.13236237, 17.82764053], [73.13236237, 17.82542992], [73.13263702, 17.82542992], [73.13263702, 17.82514], [73.13291931, 17.82514], [73.13291931, 17.82485962], [73.13319397, 17.82486153], [73.13319397, 17.82458305], [73.1340332, 17.82458115], [73.1340332, 17.82514], [73.13375092, 17.82514], [73.13375092, 17.82542992], [73.13346863, 17.82541847], [73.13346863, 17.8259716], [73.13318634, 17.8259697], [73.13318634, 17.82764053], [73.13291931, 17.82764053], [73.13291931, 17.82902908], [73.13263702, 17.82902908], [73.13263702, 17.83013916], [73.13236237, 17.83013916], [73.13236237, 17.8306942], [73.13180542, 17.8306942], [73.13180542, 17.83097267], [73.13153076, 17.83097267], [73.13153076, 17.8318119], [73.13124847, 17.8318119], [73.13124847, 17.83236122], [73.13096619, 17.83236122], [73.13096619, 17.83263969], [73.13069153, 17.83263969], [73.13069153, 17.83292007], [73.13041687, 17.83291626], [73.13041687, 17.83319473], [73.12985992, 17.83319473], [73.12985992, 17.8334713], [73.12958527, 17.8334713], [73.1295929, 17.83374977], [73.12930298, 17.83374977], [73.12930298, 17.83430481], [73.12902832, 17.83430481], [73.12902832, 17.83458328], [73.12875366, 17.83458328], [73.12875366, 17.83486176], [73.12819672, 17.83485985], [73.12819672, 17.83514023], [73.12763977, 17.83514023], [73.12763977, 17.83542061], [73.12708282, 17.83542061], [73.12708282, 17.83570099], [73.12652588, 17.83569336], [73.12652588, 17.83597183], [73.12625122, 17.83596992], [73.12625122, 17.83625031], [73.1257019, 17.83625031], [73.1257019, 17.83653069], [73.12513733, 17.83653069], [73.12513733, 17.83681107], [73.12346649, 17.83681107], [73.12346649, 17.83653069], [73.12264252, 17.83653069], [73.12264252, 17.83625031], [73.12152863, 17.83625031], [73.12152863, 17.83596992], [73.12069702, 17.83597183], [73.12069702, 17.83569336], [73.11985779, 17.83570099], [73.11985779, 17.83542061], [73.11875153, 17.83542061], [73.11875153, 17.83514023], [73.11791992, 17.83514023], [73.11791992, 17.83485985], [73.11569214, 17.83486176], [73.11569214, 17.83458328], [73.11402893, 17.83458328], [73.11402893, 17.83486176], [73.11347198, 17.83485985], [73.11347198, 17.83514023], [73.11319733, 17.83514023], [73.11319733, 17.83542061], [73.11264038, 17.83542061], [73.11264038, 17.83570099], [73.11208344, 17.83569336], [73.11208344, 17.83597183], [73.11180878, 17.83596992], [73.11180878, 17.83625031], [73.11125183, 17.83625031], [73.11125183, 17.83653069], [73.11096954, 17.83653069], [73.11096954, 17.83681107], [73.11042023, 17.83680534], [73.11042023, 17.83708382], [73.11013794, 17.83708], [73.11013794, 17.83736992], [73.10958099, 17.83736992], [73.10958099, 17.83764076], [73.10930634, 17.83764076], [73.10930634, 17.83792114], [73.10874939, 17.83791542], [73.10874939, 17.83819389], [73.10847473, 17.83819389], [73.10847473, 17.83847237], [73.10791779, 17.83847046], [73.10791779, 17.83875084], [73.10762787, 17.83875084], [73.10762787, 17.83903122], [73.10708618, 17.8390255], [73.10708618, 17.83958244], [73.10679626, 17.83958054], [73.10679626, 17.83986092], [73.10624695, 17.83986092], [73.10624695, 17.84013939], [73.10597229, 17.84013939], [73.10597229, 17.84042931], [73.10569763, 17.84041786], [73.10569763, 17.84069443], [73.1048584, 17.84069443], [73.1048584, 17.8409729], [73.10375214, 17.84096909], [73.10375214, 17.84124756], [73.1018219, 17.84124756], [73.1018219, 17.84152985], [73.10098267, 17.84152985], [73.10098267, 17.84180832], [73.10041809, 17.84180641], [73.10041809, 17.84208298], [73.09958649, 17.84208298], [73.09958649, 17.84236145], [73.09902954, 17.84236145], [73.09902954, 17.84264183], [73.09707642, 17.84264183], [73.09707642, 17.8429203], [73.09680939, 17.8429203], [73.09680939, 17.84403038], [73.09708405, 17.84402847], [73.09708405, 17.84458351], [73.09874725, 17.84458351], [73.09874725, 17.84430504], [73.09958649, 17.84431267], [73.09958649, 17.84403038], [73.10041809, 17.84403038], [73.10041809, 17.84375191], [73.10098267, 17.84375191], [73.10097504, 17.84347153], [73.10152435, 17.84347153], [73.10152435, 17.84319496], [73.10263824, 17.84320259], [73.10263824, 17.84403038], [73.10235596, 17.84403038], [73.10235596, 17.84431267], [73.10180664, 17.84430504], [73.10180664, 17.84458351], [73.10069275, 17.84458351], [73.10069275, 17.84486008], [73.09986115, 17.84486008], [73.09986115, 17.84514046], [73.09819794, 17.84514046], [73.09819794, 17.84542274], [73.09708405, 17.84541702], [73.09708405, 17.84569359], [73.0965271, 17.84569359], [73.0965271, 17.84541702], [73.09513855, 17.84541702], [73.09513855, 17.84569359], [73.0945816, 17.84569359], [73.0945816, 17.84541702], [73.09430695, 17.84542274], [73.09430695, 17.84514046], [73.09375, 17.84514046], [73.09375, 17.8445816], [73.09347534, 17.84458351], [73.09347534, 17.84430504], [73.09319305, 17.84431267], [73.09319305, 17.84375191], [73.09262848, 17.84375191], [73.09262848, 17.84347153], [73.0909729, 17.84347153], [73.0909729, 17.84375191], [73.09041595, 17.84375191], [73.09041595, 17.84403038], [73.0901413, 17.84403038], [73.0901413, 17.84431267], [73.08985901, 17.84430504], [73.08985901, 17.84458351], [73.08958435, 17.84458351], [73.08958435, 17.84486008], [73.08930206, 17.84486008], [73.08930206, 17.84514046], [73.0890274, 17.84514046], [73.0890274, 17.84542274], [73.08875275, 17.84541702], [73.08875275, 17.84569359], [73.08847046, 17.84569359], [73.08847046, 17.84597206], [73.0881958, 17.84597015], [73.0881958, 17.84653091], [73.08791351, 17.8465271], [73.08791351, 17.84708214], [73.08763885, 17.84708023], [73.08763885, 17.84736061], [73.0873642, 17.84736061], [73.0873642, 17.8484726], [73.08708191, 17.84847069], [73.08708191, 17.84875107], [73.08682251, 17.84875107], [73.08682251, 17.84930992], [73.08652496, 17.8493042], [73.08652496, 17.84958267], [73.08625031, 17.84958076], [73.08625031, 17.85013962], [73.08597565, 17.85013962], [73.08597565, 17.85069466], [73.08569336, 17.85069084], [73.08569336, 17.85153008], [73.0854187, 17.85153008], [73.0854187, 17.85237122], [73.08513641, 17.85237122], [73.08513641, 17.85403061], [73.08486176, 17.8540287], [73.08486176, 17.85597229], [73.0845871, 17.85596848], [73.0845871, 17.85652924], [73.08430481, 17.85652733], [73.08430481, 17.85708427], [73.08403015, 17.85708427], [73.08403015, 17.85847282], [73.08374786, 17.85847282], [73.08374786, 17.85874939], [73.08345795, 17.85874939], [73.08345795, 17.85902977], [73.08207703, 17.85902977], [73.08207703, 17.85931015], [73.08180237, 17.85930634], [73.08180237, 17.8595829], [73.08152771, 17.8595829], [73.08152771, 17.85986137], [73.08125305, 17.85985947], [73.08125305, 17.86013985], [73.08097076, 17.86013985], [73.08097076, 17.86069489], [73.08068848, 17.86069107], [73.08068848, 17.86124992], [73.08041382, 17.86124992], [73.08041382, 17.86208344], [73.08013916, 17.86208344], [73.08013916, 17.86239052], [73.08013916, 17.86292076], [73.08041382, 17.86291695], [73.08041382, 17.86319351], [73.08069611, 17.86319351], [73.08069611, 17.86347198], [73.08097076, 17.86347008], [73.08097076, 17.86375046], [73.08125305, 17.86375046], [73.08125305, 17.86403084], [73.08152771, 17.86403084], [73.08152771, 17.86431122], [73.08180237, 17.8643055], [73.08180237, 17.86458588], [73.08152771, 17.86458015], [73.08152771, 17.86541939], [73.08125305, 17.86541939], [73.08125305, 17.86625099], [73.08097076, 17.86625099], [73.08097076, 17.86652946], [73.08068848, 17.86652946], [73.08068848, 17.86763954], [73.08039856, 17.86763954], [73.08039856, 17.86791992], [73.08013916, 17.86791611], [73.08013916, 17.86847305], [73.07985687, 17.86846924], [73.07985687, 17.86903191], [73.07958221, 17.86902809], [73.07958221, 17.86930466], [73.07930756, 17.86930084], [73.07930756, 17.87014008], [73.07875061, 17.87013817], [73.07875061, 17.87041664], [73.07847595, 17.87041092], [73.07847595, 17.87070274], [73.07819366, 17.87069511], [73.07819366, 17.87097168], [73.07791901, 17.87097168], [73.07791901, 17.87125015], [73.07765198, 17.87125015], [73.07765198, 17.87153053], [73.07707977, 17.87153053], [73.07707977, 17.87181282], [73.07680511, 17.87180519], [73.07680511, 17.87208366], [73.07624817, 17.87208366], [73.07624817, 17.87319374], [73.07596588, 17.87319183], [73.07596588, 17.87403107], [73.07569122, 17.87403107], [73.07569122, 17.87430954], [73.07541656, 17.87430954], [73.07541656, 17.87486076], [73.07514191, 17.87486076], [73.07514191, 17.87795258], [73.07514191, 17.87958336], [73.07485962, 17.87957954], [73.07485962, 17.88042068], [73.07458496, 17.88041878], [73.07458496, 17.88208389], [73.07430267, 17.88207817], [73.07430267, 17.88291931], [73.07375336, 17.8829174], [73.07375336, 17.88319397], [73.07347107, 17.88318825], [73.07347107, 17.88402939], [73.07319641, 17.88402939], [73.07319641, 17.8848629], [73.07290649, 17.8848629], [73.07290649, 17.88541985], [73.07263947, 17.88541985], [73.07263947, 17.8868103], [73.07235718, 17.8868103], [73.07235718, 17.88764], [73.07208252, 17.88764], [73.07208252, 17.88820076], [73.07180786, 17.88820076], [73.07180786, 17.88848114], [73.07151794, 17.88848114], [73.07151794, 17.88875008], [73.07125092, 17.88875008], [73.07125092, 17.89042091], [73.07151794, 17.89042091], [73.07151794, 17.89180946], [73.07180786, 17.89180756], [73.07180786, 17.8931942], [73.07208252, 17.89319038], [73.07208252, 17.89402962], [73.07236481, 17.89402962], [73.07236481, 17.89458275], [73.07290649, 17.89458084], [73.07290649, 17.89486122], [73.07319641, 17.89486122], [73.07319641, 17.89513969], [73.07375336, 17.89513969], [73.07375336, 17.89541817], [73.07430267, 17.89541626], [73.07430267, 17.89569473], [73.07458496, 17.89569473], [73.07458496, 17.8959713], [73.07541656, 17.8959713], [73.07541656, 17.89625168], [73.07597351, 17.89625168], [73.07597351, 17.89680481], [73.07485962, 17.89680481], [73.07485962, 17.89708328], [73.07458496, 17.89708328], [73.07458496, 17.89652824], [73.07430267, 17.89653015], [73.07430267, 17.89625168], [73.07402802, 17.89625168], [73.07402802, 17.8959713], [73.07375336, 17.8959713], [73.07375336, 17.89569473], [73.07319641, 17.89569473], [73.07319641, 17.89541626], [73.07290649, 17.89541817], [73.07290649, 17.89513969], [73.07263947, 17.89513969], [73.07263947, 17.89486122], [73.07125092, 17.89486122], [73.07125092, 17.89430809], [73.07096863, 17.89430809], [73.07096863, 17.89402962], [73.07125092, 17.89402962], [73.07125092, 17.89347076], [73.07096863, 17.89347267], [73.07096863, 17.89291954], [73.07068634, 17.89291954], [73.07068634, 17.89264107], [73.07041931, 17.89264107], [73.07041931, 17.89236069], [73.06958008, 17.89236069], [73.06958008, 17.89180946], [73.06931305, 17.89180946], [73.06931305, 17.89125061], [73.06903076, 17.89125061], [73.06903076, 17.89097023], [73.06652832, 17.89097214], [73.06652832, 17.89069366], [73.06569672, 17.89069366], [73.06569672, 17.89041519], [73.06485748, 17.89041519], [73.06485748, 17.89069366], [73.06346893, 17.89069366], [73.06346893, 17.89097023], [73.0632019, 17.89097977], [73.06319427, 17.89125061], [73.06291962, 17.89125061], [73.06291962, 17.89152527], [73.06278229, 17.89152527], [73.06153107, 17.89151955], [73.06153107, 17.89180946], [73.06124878, 17.89180946], [73.06124878, 17.89236069], [73.06097412, 17.89236069], [73.06097412, 17.8931942], [73.06069183, 17.8931942], [73.06069183, 17.89347267], [73.06041718, 17.89347076], [73.06041718, 17.89375114], [73.06014252, 17.89375114], [73.06014252, 17.89402962], [73.05986023, 17.89402962], [73.05986023, 17.89430809], [73.05958557, 17.89430618], [73.05958557, 17.89458275], [73.05902863, 17.89458084], [73.05902863, 17.89513969], [73.05874634, 17.89513969], [73.05874634, 17.89569473], [73.05847168, 17.89569473], [73.05847168, 17.8959713], [73.05819702, 17.8959713], [73.05819702, 17.89625168], [73.0579071, 17.89625168], [73.0579071, 17.89653015], [73.05764008, 17.89652824], [73.05764008, 17.89680481], [73.05735779, 17.89680481], [73.05735779, 17.89736176], [73.05708313, 17.89736176], [73.05708313, 17.89764023], [73.05680847, 17.89764023], [73.05680847, 17.89792061], [73.05651855, 17.89792061], [73.05651855, 17.8982029], [73.05625153, 17.89819527], [73.05625153, 17.89847183], [73.05568695, 17.89847183], [73.05568695, 17.89875031], [73.05541992, 17.89875031], [73.05541992, 17.89903069], [73.05513763, 17.89903069], [73.05513763, 17.89931107], [73.05486298, 17.89931107], [73.05486298, 17.89986038], [73.05458069, 17.89986038], [73.05458069, 17.90014076], [73.05430603, 17.90014076], [73.05430603, 17.90042114], [73.05403137, 17.90042114], [73.05403137, 17.90153122], [73.05430603, 17.90153122], [73.05430603, 17.90180969], [73.05403137, 17.90180969], [73.05403137, 17.90236092], [73.05374908, 17.90236092], [73.05374908, 17.90291977], [73.05347443, 17.90291405], [73.05347443, 17.90319443], [73.05319214, 17.90319443], [73.05319214, 17.9034729], [73.05236053, 17.90345955], [73.05236053, 17.90374947], [73.05179596, 17.90374947], [73.05179596, 17.90402985], [73.05152893, 17.90402794], [73.05152893, 17.90458298], [73.05124664, 17.90458107], [73.05124664, 17.90513992], [73.05097198, 17.90513992], [73.05097198, 17.9054203], [73.05071259, 17.9054203], [73.05071259, 17.90570068], [73.05097198, 17.90569687], [73.05097198, 17.90597153], [73.05069733, 17.90597153], [73.05069733, 17.90652657], [73.05042267, 17.90652084], [73.05042267, 17.90681076], [73.05014038, 17.90680695], [73.05014038, 17.90736198], [73.05042267, 17.90735817], [73.05042267, 17.90764046], [73.05179596, 17.90764046], [73.05179596, 17.90735817], [73.05236053, 17.90735817], [73.05236053, 17.90764046], [73.05271149, 17.90764046], [73.05291748, 17.90764046], [73.05291748, 17.90792084], [73.05347443, 17.90791893], [73.05347443, 17.90819359], [73.05374908, 17.90818977], [73.05374908, 17.90986061], [73.05403137, 17.90986061], [73.05403137, 17.91041946], [73.05430603, 17.91041756], [73.05430603, 17.91069412], [73.05403137, 17.91069412], [73.05403137, 17.91144943], [73.05403137, 17.91208267], [73.05417633, 17.91208267], [73.05430603, 17.91208267], [73.05430603, 17.91263962], [73.05458069, 17.91263962], [73.05458069, 17.91282082], [73.05458069, 17.91319466], [73.05513763, 17.91319466], [73.05513763, 17.91347122], [73.05486298, 17.91347122], [73.05486298, 17.91374969], [73.05458069, 17.91374969], [73.05458069, 17.91514015], [73.05486298, 17.91514015], [73.05486298, 17.91571045], [73.05513763, 17.91571045], [73.05513763, 17.91625023], [73.05486298, 17.91625023], [73.05486298, 17.91708374], [73.05458069, 17.91708374], [73.05458069, 17.91847229], [73.05430603, 17.91847229], [73.05430603, 17.91958427], [73.05403137, 17.91958427], [73.05403137, 17.92097282], [73.05374908, 17.92097282], [73.05374908, 17.9220829], [73.05403137, 17.92207909], [73.05403137, 17.92263985], [73.05347443, 17.92264175], [73.05347443, 17.92319489], [73.05319214, 17.92318916], [73.05319214, 17.9240303], [73.05291748, 17.9240284], [73.05291748, 17.92486191], [73.05263519, 17.92486191], [73.05264282, 17.9256897], [73.05236053, 17.92569542], [73.05236053, 17.92732811], [73.05208588, 17.92736053], [73.05208588, 17.92902946], [73.05374908, 17.92902946], [73.05374908, 17.92875099], [73.05403137, 17.92875099], [73.05403137, 17.92847061], [73.05458069, 17.92847252], [73.05458069, 17.92819214], [73.05513763, 17.92819214], [73.05513763, 17.92791748], [73.05541992, 17.92791939], [73.05541992, 17.92765045], [73.05568695, 17.92765045], [73.05568695, 17.92736053], [73.05596924, 17.92736053], [73.05596924, 17.92708015], [73.05625153, 17.92708206], [73.05625153, 17.92652702], [73.05735779, 17.92652702], [73.05735779, 17.92690086], [73.05735779, 17.92736053], [73.05764008, 17.92736053], [73.05764008, 17.92791939], [73.05847168, 17.92791748], [73.05847168, 17.92819214], [73.05930328, 17.92819214], [73.05930328, 17.92791748], [73.05986023, 17.92791939], [73.05986023, 17.92765045], [73.06014252, 17.92765045], [73.06014252, 17.92736053], [73.06041718, 17.92736053], [73.06041718, 17.92681122], [73.06096649, 17.92681122], [73.06098938, 17.92659569], [73.06124878, 17.92653084], [73.06124878, 17.92625046], [73.06236267, 17.92625046], [73.06236267, 17.92650032], [73.06265259, 17.92653084], [73.06265259, 17.92681122], [73.06542206, 17.92681122], [73.06542206, 17.92653084], [73.06680298, 17.92653084], [73.06680298, 17.92681122], [73.06708527, 17.9268055], [73.06708527, 17.92708206], [73.06680298, 17.92708015], [73.06680298, 17.92765045], [73.06597137, 17.92765045], [73.06597137, 17.92736053], [73.06208038, 17.92736053], [73.06208038, 17.92819214], [73.06236267, 17.92819023], [73.06236267, 17.92930984], [73.06263733, 17.92930412], [73.06263733, 17.9295826], [73.06291962, 17.92958069], [73.06291962, 17.92986107], [73.06318665, 17.92986107], [73.06318665, 17.93013954], [73.06346893, 17.93013954], [73.06346893, 17.93069458], [73.06375122, 17.93069077], [73.06375122, 17.93124962], [73.06402588, 17.93124962], [73.06402588, 17.93180466], [73.06458282, 17.93180466], [73.06458282, 17.93208313], [73.06485748, 17.93208313], [73.06485748, 17.9323616], [73.06542206, 17.9323597], [73.06542206, 17.93264008], [73.06597137, 17.93264008], [73.06597137, 17.9323597], [73.06652832, 17.9323616], [73.06652832, 17.93180466], [73.06680298, 17.93180466], [73.06680298, 17.9295826], [73.06708527, 17.9295826], [73.06708527, 17.92902756], [73.06735992, 17.92902946], [73.06735992, 17.92875099], [73.06764221, 17.92875099], [73.06764221, 17.92847061], [73.06791687, 17.92847252], [73.06791687, 17.92791748], [73.06819153, 17.92791939], [73.06819153, 17.92681122], [73.07013702, 17.9268055], [73.07013702, 17.92708206], [73.07096863, 17.92708015], [73.07096863, 17.92736053], [73.07235718, 17.92736053], [73.07235718, 17.92765045], [73.07263947, 17.92763901], [73.07263947, 17.92819214], [73.07291412, 17.92819214], [73.07291412, 17.92847252], [73.07319641, 17.92847061], [73.07319641, 17.92875099], [73.07347107, 17.92875099], [73.07347107, 17.92930984], [73.07375336, 17.92930412], [73.07375336, 17.9295826], [73.07458496, 17.9295826], [73.07458496, 17.92986107], [73.07514191, 17.92986107], [73.07514191, 17.93041992], [73.07541656, 17.9304142], [73.07541656, 17.93097305], [73.07569122, 17.93097115], [73.07569122, 17.93153], [73.07596588, 17.93153], [73.07596588, 17.93292046], [73.07624817, 17.93292046], [73.07624817, 17.93320084], [73.07653046, 17.93319511], [73.07653046, 17.93347168], [73.07707977, 17.93346977], [73.07707977, 17.93374825], [73.07736206, 17.93374825], [73.07736206, 17.93403053], [73.07791901, 17.93403053], [73.07791901, 17.93431091], [73.07819366, 17.93430519], [73.07819366, 17.93458366], [73.07875061, 17.93457985], [73.07875061, 17.93485832], [73.07930756, 17.93485832], [73.07930756, 17.93514061], [73.07958221, 17.93514061], [73.07958221, 17.93541908], [73.08041382, 17.93541718], [73.08041382, 17.93569374], [73.08125305, 17.93569374], [73.08125305, 17.93597221], [73.08207703, 17.9359684], [73.08207703, 17.93652916], [73.08235931, 17.93652916], [73.08235931, 17.93682289], [73.0826416, 17.93682289], [73.0826416, 17.93736267], [73.08291626, 17.93736267], [73.08291626, 17.93764114], [73.08374786, 17.93764114], [73.08374786, 17.93791962], [73.08430481, 17.9379158], [73.08430481, 17.93819427], [73.08486176, 17.93819427], [73.08486176, 17.93847275], [73.0854187, 17.93847275], [73.0854187, 17.93875122], [73.08625031, 17.93875122], [73.08625031, 17.93902969], [73.08682251, 17.93902969], [73.08682251, 17.93931007], [73.08763885, 17.93931007], [73.08763885, 17.93959045], [73.0881958, 17.93958282], [73.0881958, 17.9398613], [73.08875275, 17.93985939], [73.08875275, 17.94013977], [73.08985901, 17.94013977], [73.08985901, 17.94042015], [73.09236145, 17.94041634], [73.09236145, 17.94069481], [73.09124756, 17.94069481], [73.09124756, 17.94097137], [73.08875275, 17.94097137], [73.08875275, 17.94069481], [73.0881958, 17.94069481], [73.0881958, 17.94041634], [73.08708191, 17.94042015], [73.08708191, 17.94013977], [73.0854187, 17.94013977], [73.0854187, 17.93985939], [73.08513641, 17.9398613], [73.08513641, 17.93958282], [73.0845871, 17.93959045], [73.0845871, 17.93931007], [73.08429718, 17.93931007], [73.08429718, 17.93902969], [73.08374786, 17.93902969], [73.08374786, 17.93875122], [73.08319092, 17.93875122], [73.08319092, 17.93847275], [73.08291626, 17.93847275], [73.08291626, 17.93819427], [73.08235931, 17.93819427], [73.08235931, 17.9379158], [73.08207703, 17.93791962], [73.08207703, 17.93764114], [73.08180237, 17.93764114], [73.08180237, 17.93736267], [73.08039856, 17.93736267], [73.08039856, 17.93707848], [73.08013916, 17.9370842], [73.08013916, 17.93680573], [73.07985687, 17.93682289], [73.07985687, 17.93652916], [73.07958221, 17.93652916], [73.07958221, 17.93625069], [73.07902527, 17.93625069], [73.07902527, 17.93597221], [73.07819366, 17.93597221], [73.07819366, 17.93569374], [73.07736206, 17.93569374], [73.07736206, 17.93541718], [73.07624817, 17.93541908], [73.07624817, 17.93514061], [73.07596588, 17.93514061], [73.07596588, 17.93457985], [73.07541656, 17.93458366], [73.07541656, 17.93402863], [73.07459259, 17.93403053], [73.07459259, 17.93374825], [73.07430267, 17.93374825], [73.07430267, 17.93346977], [73.07402802, 17.93347168], [73.07402802, 17.93291855], [73.07375336, 17.93292046], [73.07375336, 17.9323597], [73.07347107, 17.9323616], [73.07347107, 17.93180466], [73.07319641, 17.93180466], [73.07319641, 17.93097305], [73.07291412, 17.93097305], [73.07291412, 17.92986107], [73.07263947, 17.92986107], [73.07263947, 17.92958069], [73.07236481, 17.9295826], [73.07236481, 17.92930412], [73.07208252, 17.92930984], [73.07208252, 17.92902946], [73.07041931, 17.92902946], [73.07041931, 17.92930984], [73.06986237, 17.92930412], [73.06986237, 17.9295826], [73.06958008, 17.92958069], [73.06958008, 17.92986107], [73.06931305, 17.92986107], [73.06931305, 17.93041992], [73.06958008, 17.93041992], [73.06958008, 17.93124962], [73.06931305, 17.93124962], [73.06931305, 17.93153], [73.06903076, 17.93152618], [73.06903076, 17.93208313], [73.06874847, 17.93208122], [73.06874847, 17.93264008], [73.06847382, 17.93263626], [73.06847382, 17.93347168], [73.06791687, 17.93346977], [73.06791687, 17.93374825], [73.06735992, 17.93374825], [73.06735992, 17.93403053], [73.0670929, 17.93403053], [73.0670929, 17.93374825], [73.06680298, 17.93374825], [73.06680298, 17.93403053], [73.06652832, 17.93403053], [73.06652832, 17.93374825], [73.06597137, 17.93374825], [73.06597137, 17.93346977], [73.06541443, 17.93347168], [73.06541443, 17.93319511], [73.06402588, 17.93320084], [73.06402588, 17.93292046], [73.06181335, 17.93292046], [73.06181335, 17.93264008], [73.06124878, 17.93264008], [73.06124878, 17.9323597], [73.05764008, 17.9323616], [73.05764008, 17.93208313], [73.05708313, 17.93208313], [73.05708313, 17.93180466], [73.05680847, 17.93180466], [73.05680847, 17.93152618], [73.05652618, 17.93152618], [73.05652618, 17.93180466], [73.05430603, 17.93180466], [73.05430603, 17.93152618], [73.05236053, 17.93152618], [73.05236053, 17.93180466], [73.05097198, 17.93180466], [73.05097198, 17.93208313], [73.04985809, 17.93208313], [73.04985809, 17.9323616], [73.04763794, 17.9323597], [73.04763794, 17.93264008], [73.04708099, 17.93264008], [73.04708099, 17.93292046], [73.04680634, 17.93292046], [73.04680634, 17.93320084], [73.04652405, 17.93319511], [73.04652405, 17.93347168], [73.04624939, 17.93346977], [73.04624939, 17.93374825], [73.04541779, 17.93374825], [73.04541779, 17.93403053], [73.04428864, 17.93403053], [73.04428864, 17.93374825], [73.04402924, 17.93374825], [73.04402924, 17.93346977], [73.04374695, 17.93347168], [73.04374695, 17.93319511], [73.04347229, 17.93320084], [73.04347229, 17.93264008], [73.0423584, 17.93264008], [73.0423584, 17.9323597], [73.04184723, 17.9323597], [73.04154205, 17.9323597], [73.04154205, 17.93264008], [73.04125214, 17.93263626], [73.04122925, 17.93291092], [73.0404129, 17.93292046], [73.0404129, 17.93320084], [73.0395813, 17.93319511], [73.0395813, 17.93347168], [73.03930664, 17.93346977], [73.03930664, 17.93374825], [73.03874969, 17.93374825], [73.03874969, 17.93403053], [73.03848267, 17.93403053], [73.03848267, 17.93431091], [73.03791809, 17.93431091], [73.03791809, 17.93485832], [73.0376358, 17.93485832], [73.0376358, 17.93541908], [73.03736115, 17.93541718], [73.03736115, 17.93597221], [73.03708649, 17.9359684], [73.03708649, 17.93625069], [73.03679657, 17.93625069], [73.03679657, 17.93652916], [73.03652954, 17.93652916], [73.03652954, 17.93682289], [73.03624725, 17.93680573], [73.03624725, 17.9370842], [73.0359726, 17.93707848], [73.0359726, 17.93764114], [73.03569794, 17.93763924], [73.03569794, 17.93819427], [73.03542328, 17.93819046], [73.03542328, 17.93902969], [73.03514099, 17.93902969], [73.03514099, 17.93931007], [73.0340271, 17.93931007], [73.0340271, 17.93959045], [73.03375244, 17.93958282], [73.03375244, 17.9398613], [73.03347015, 17.93985939], [73.03347015, 17.94013977], [73.03263855, 17.94013977], [73.03263855, 17.94042015], [73.0320816, 17.94041634], [73.0320816, 17.94097137], [73.03180695, 17.94096947], [73.03180695, 17.94124985], [73.03152466, 17.94124985], [73.03152466, 17.94180489], [73.03125, 17.94180489], [73.03125, 17.94236183], [73.03098297, 17.94235992], [73.03098297, 17.94320107], [73.03069305, 17.94319534], [73.03069305, 17.94347191], [73.0304184, 17.94347], [73.0304184, 17.94375038], [73.03013611, 17.94375038], [73.03013611, 17.94403076], [73.02986145, 17.94403076], [73.02986145, 17.94431114], [73.02960205, 17.94431114], [73.02960205, 17.94680977], [73.02928925, 17.94680977], [73.02928925, 17.94735909], [73.02902985, 17.94735909], [73.02902985, 17.94791985], [73.02874756, 17.94791985], [73.02874756, 17.94902992], [73.0284729, 17.94902992], [73.0284729, 17.94958305], [73.02874756, 17.94957924], [73.02874756, 17.95375061], [73.02902985, 17.95375061], [73.02902985, 17.95403099], [73.02986145, 17.95403099], [73.02986145, 17.95430946], [73.03013611, 17.95430565], [73.03013611, 17.95458221], [73.0304184, 17.95457268], [73.0304184, 17.95486069], [73.03069305, 17.95486069], [73.03069305, 17.95514107], [73.03097534, 17.95513916], [73.03097534, 17.9556942], [73.03125, 17.95569038], [73.03125, 17.95736122], [73.03098297, 17.95736122], [73.03098297, 17.95792007], [73.03069305, 17.95791435], [73.03069305, 17.95819473], [73.0304184, 17.95819092], [73.0304184, 17.95874977], [73.03013611, 17.95874977], [73.03013611, 17.95958328], [73.02986145, 17.95957947], [73.02986145, 17.96125031], [73.02958679, 17.96125031], [73.02960205, 17.96513939], [73.0293045, 17.96513939], [73.0293045, 17.96680641], [73.02958679, 17.96680641], [73.02958679, 17.96736145], [73.03013611, 17.96735954], [73.03013611, 17.96763992], [73.03069305, 17.96763992], [73.03069305, 17.9679203], [73.03097534, 17.96791649], [73.03097534, 17.96847153], [73.03125, 17.96846962], [73.03125, 17.96903038], [73.03151703, 17.96903038], [73.03151703, 17.96931076], [73.03180695, 17.96930313], [73.03180695, 17.96986198], [73.0320816, 17.96986008], [73.0320816, 17.97014046], [73.03234863, 17.97014046], [73.03234863, 17.97042084], [73.03263855, 17.97041512], [73.03263855, 17.97069359], [73.0331955, 17.97069359], [73.0331955, 17.97097206], [73.03375244, 17.97097015], [73.03375244, 17.97125053], [73.03430176, 17.97125053], [73.03430939, 17.97153091], [73.03457642, 17.97153091], [73.03457642, 17.97180939], [73.0348587, 17.97180557], [73.0348587, 17.97208595], [73.03514099, 17.97208023], [73.03514099, 17.97264099], [73.03542328, 17.97264099], [73.03542328, 17.97293091], [73.03569794, 17.97291946], [73.03569794, 17.97319412], [73.03652954, 17.97319412], [73.03652954, 17.9734726], [73.03708649, 17.97347069], [73.03708649, 17.97375107], [73.03736115, 17.97375107], [73.03736115, 17.97430992], [73.0376358, 17.97430992], [73.0376358, 17.97486115], [73.03791809, 17.97486115], [73.03791809, 17.97513962], [73.03819275, 17.97513962], [73.03819275, 17.97541809], [73.03848267, 17.97541809], [73.03848267, 17.97570229], [73.03874969, 17.97570229], [73.03874969, 17.97653008], [73.03902435, 17.97652817], [73.03902435, 17.97680473], [73.03930664, 17.97680473], [73.03930664, 17.97736168], [73.0395813, 17.97736168], [73.0395813, 17.97764015], [73.03985596, 17.97764015], [73.03985596, 17.97792053], [73.04013824, 17.97792053], [73.04013824, 17.97820282], [73.03985596, 17.97820282], [73.03985596, 17.97903061], [73.0395813, 17.97903061], [73.0395813, 17.97986031], [73.03930664, 17.97986031], [73.03930664, 17.98069382], [73.03901672, 17.98069191], [73.03901672, 17.98153114], [73.03874969, 17.98153114], [73.03874969, 17.98264122], [73.03847504, 17.98263931], [73.03847504, 17.98347282], [73.03819275, 17.98347092], [73.03819275, 17.98431015], [73.03791809, 17.98430443], [73.03791809, 17.9845829], [73.0376358, 17.9845829], [73.0376358, 17.98430443], [73.03736115, 17.98431015], [73.03734589, 17.98486328], [73.03708649, 17.98489952], [73.03708649, 17.98513985], [73.03679657, 17.98513985], [73.03679657, 17.98542023], [73.03652954, 17.98541641], [73.03652954, 17.98569679], [73.03514099, 17.98569679], [73.03514099, 17.98597145], [73.03430939, 17.98596954], [73.03430176, 17.98624992], [73.0340271, 17.98624992], [73.0340271, 17.9865303], [73.03347015, 17.9865303], [73.03347015, 17.98681068], [73.0331955, 17.98680496], [73.0331955, 17.98708344], [73.03291321, 17.98708344], [73.03291321, 17.98736191], [73.03263855, 17.98735809], [73.03263855, 17.9879303], [73.03291321, 17.98791885], [73.03291321, 17.9881897], [73.03263855, 17.98819923], [73.03263855, 17.98875046], [73.03291321, 17.98875046], [73.03291321, 17.98930931], [73.03236389, 17.9893055], [73.03236389, 17.98958397], [73.03180695, 17.98957825], [73.03180695, 17.98986053], [73.03151703, 17.98986053], [73.03151703, 17.99014091], [73.03098297, 17.99014091], [73.03098297, 17.99041939], [73.03013611, 17.99041748], [73.03013611, 17.99069405], [73.02986145, 17.99069405], [73.02986145, 17.99097252], [73.02960205, 17.99097252], [73.02960205, 17.9912529], [73.02902985, 17.9912529], [73.02902985, 17.99041939], [73.02874756, 17.99041939], [73.02874756, 17.99014091], [73.0284729, 17.99014091], [73.0284729, 17.98986053], [73.02819824, 17.98986053], [73.02819061, 17.98957825], [73.02791595, 17.98958397], [73.02791595, 17.9893055], [73.02735901, 17.98930931], [73.02735901, 17.98903084], [73.02654266, 17.98903084], [73.02654266, 17.98875046], [73.02513885, 17.98875046], [73.02513885, 17.98903084], [73.02403259, 17.98903084], [73.02403259, 17.98930931], [73.02319336, 17.9893055], [73.02319336, 17.98958397], [73.02236176, 17.98957825], [73.02236176, 17.98986053], [73.02179718, 17.98986053], [73.02179718, 17.99014091], [73.02040863, 17.99014091], [73.02040863, 17.98986053], [73.01985931, 17.98986053], [73.01985931, 17.99014091], [73.01902771, 17.99014091], [73.01902771, 17.99041939], [73.01875305, 17.99041748], [73.01875305, 17.99069405], [73.01847076, 17.99069405], [73.01847076, 17.99097252], [73.01791382, 17.99097252], [73.01791382, 17.99111938], [73.01791382, 17.9920826], [73.01819611, 17.9920826], [73.01819611, 17.99263954], [73.01875305, 17.99263954], [73.01875305, 17.99291992], [73.0201416, 17.99291992], [73.0201416, 17.99263954], [73.02097321, 17.99263954], [73.02097321, 17.99291992], [73.02124786, 17.99291611], [73.02124786, 17.99319458], [73.02153015, 17.99319458], [73.02153015, 17.99374962], [73.02124786, 17.99374008], [73.02124786, 17.99403], [73.02097321, 17.99402809], [73.02097321, 17.99430466], [73.02041626, 17.99430466], [73.02041626, 17.99458313], [73.0201416, 17.99458313], [73.0201416, 17.9948616], [73.01985931, 17.9948597], [73.01985931, 17.99570084], [73.01957703, 17.99570084], [73.01957703, 17.99653053], [73.01930237, 17.99652863], [73.01930237, 17.99708366], [73.01902771, 17.99707985], [73.01902771, 17.99792099], [73.01875305, 17.99792099], [73.01875305, 17.99875069], [73.01847076, 17.99875069], [73.01847076, 17.9995842], [73.01819611, 17.99958038], [73.01819611, 18.00014114], [73.01819611, 18.00152969], [73.01791382, 18.00152969], [73.01791382, 18.00291634], [73.01763916, 18.00291061], [73.01763916, 18.00403023], [73.0173645, 18.00402832], [73.0173645, 18.00486183], [73.01708221, 18.00486183], [73.01708221, 18.00542068], [73.01680756, 18.00542068], [73.01680756, 18.00653076], [73.0165329, 18.00653076], [73.0165329, 18.00681114], [73.01625061, 18.00680542], [73.01625061, 18.00708389], [73.01597595, 18.00708008], [73.01597595, 18.00764084], [73.01568604, 18.00764084], [73.01568604, 18.00792122], [73.01541901, 18.0079174], [73.01541901, 18.00819206], [73.01513672, 18.00819206], [73.01513672, 18.00847244], [73.01457977, 18.00847054], [73.01457977, 18.00902939], [73.01431274, 18.00902939], [73.01431274, 18.00930977], [73.01403046, 18.00930977], [73.01403046, 18.00902939], [73.01319122, 18.00902939], [73.01319122, 18.00930977], [73.01291656, 18.00930405], [73.01291656, 18.00958252], [73.01264191, 18.00958061], [73.01264191, 18.00986099], [73.01235962, 18.00986099], [73.01235962, 18.01013947], [73.01209259, 18.01013947], [73.01209259, 18.01041985], [73.00985718, 18.01041985], [73.00985718, 18.01013947], [73.00914764, 18.01013947], [73.00902557, 18.01013947], [73.00902557, 18.0102787], [73.00894165, 18.01041412], [73.00846863, 18.01041412], [73.00846863, 18.0106945], [73.00819397, 18.0106945], [73.00819397, 18.01097298], [73.00791931, 18.01097107], [73.00791931, 18.01152992], [73.00763702, 18.01152611], [73.00763702, 18.01208305], [73.00736237, 18.01208305], [73.00736237, 18.01236153], [73.00681305, 18.01235962], [73.00681305, 18.01263809], [73.00653076, 18.01263809], [73.00653076, 18.01292038], [73.00624847, 18.01291847], [73.00624847, 18.0134716], [73.00597382, 18.0134716], [73.00595856, 18.01429939], [73.00569153, 18.01430511], [73.00569153, 18.01464081], [73.00569153, 18.01625061], [73.00540924, 18.01625061], [73.00540924, 18.01652908], [73.00514221, 18.01652718], [73.00514221, 18.01708412], [73.00485992, 18.0170784], [73.00485992, 18.01902962], [73.0045929, 18.01902962], [73.0045929, 18.01931], [73.00430298, 18.01930618], [73.00430298, 18.01958275], [73.00402832, 18.01958275], [73.00402832, 18.01986122], [73.00347137, 18.01986122], [73.00347137, 18.02013969], [73.00237274, 18.02013969], [73.00237274, 18.02042007], [73.00208282, 18.02042007], [73.00208282, 18.02124977], [73.00237274, 18.02124977], [73.00237274, 18.02153015], [73.00347137, 18.02152824], [73.00347137, 18.02180481], [73.00402832, 18.02180481], [73.00402832, 18.02208328], [73.00430298, 18.02208328], [73.00430298, 18.02180481], [73.00514221, 18.02180481], [73.00514221, 18.02152824], [73.00624847, 18.02152824], [73.00624847, 18.02180481], [73.00680542, 18.02180481], [73.00680542, 18.02208328], [73.00736237, 18.02208328], [73.00736237, 18.02236176], [73.00763702, 18.02235985], [73.00763702, 18.02264023], [73.00791931, 18.02264023], [73.00791931, 18.02292061], [73.00819397, 18.02291679], [73.00819397, 18.02347183], [73.00875092, 18.02346992], [73.00875092, 18.02375031], [73.0090332, 18.02375031], [73.0090332, 18.02404022], [73.00985718, 18.02404022], [73.00985718, 18.02431107], [73.01013947, 18.02430534], [73.01013947, 18.02458382], [73.01069641, 18.02458], [73.01069641, 18.02486038], [73.01125336, 18.02486038], [73.01125336, 18.02458], [73.01152802, 18.02458], [73.01152802, 18.02486038], [73.01235962, 18.02486038], [73.01235962, 18.02514076], [73.01280212, 18.02513885], [73.01291656, 18.02513885], [73.01457977, 18.02514076], [73.01457977, 18.02542114], [73.01486206, 18.02541542], [73.01486206, 18.02569389], [73.01791382, 18.02569389], [73.01791382, 18.02597237], [73.01812744, 18.02597237], [73.01902771, 18.02597237], [73.01902771, 18.02541542], [73.01930237, 18.02542114], [73.01930237, 18.02514076], [73.01957703, 18.02514076], [73.01957703, 18.02458], [73.01985931, 18.02458382], [73.01985931, 18.02430534], [73.0201416, 18.02431107], [73.0201416, 18.02404022], [73.02069092, 18.02404022], [73.02069092, 18.02375031], [73.02124786, 18.02375031], [73.02124786, 18.02346992], [73.02263641, 18.02346992], [73.02263641, 18.02375031], [73.02346802, 18.02375031], [73.02346802, 18.02431107], [73.02402496, 18.02430534], [73.02402496, 18.02458382], [73.02458191, 18.02458], [73.02458191, 18.02486038], [73.02485657, 18.02486038], [73.02485657, 18.02514076], [73.02513885, 18.02514076], [73.02513885, 18.02542114], [73.02541351, 18.02541542], [73.02541351, 18.02569389], [73.0256958, 18.02569389], [73.0256958, 18.02597237], [73.0265274, 18.02597237], [73.0265274, 18.02625084], [73.02680206, 18.02625084], [73.02680206, 18.02653122], [73.02707672, 18.02653122], [73.02707672, 18.02625084], [73.02735901, 18.02625084], [73.02735901, 18.02653122], [73.0276413, 18.02653122], [73.0276413, 18.02680969], [73.02791595, 18.02680779], [73.02791595, 18.02708244], [73.02819824, 18.02708054], [73.02819824, 18.02736092], [73.02874756, 18.02736092], [73.02874756, 18.02763748], [73.02928925, 18.02763748], [73.02928925, 18.02791977], [73.02958679, 18.02791786], [73.02958679, 18.02874756], [73.03013611, 18.02874756], [73.03013611, 18.02902985], [73.0304184, 18.02902985], [73.0304184, 18.02931023], [73.03069305, 18.02930641], [73.03069305, 18.02986145], [73.03125, 18.0298481], [73.03125, 18.0304203], [73.03151703, 18.0304203], [73.03151703, 18.03070259], [73.03180695, 18.03069496], [73.03180695, 18.03097153], [73.0320816, 18.03097153], [73.0320816, 18.03125191], [73.03234863, 18.03125191], [73.03234863, 18.03153038], [73.03291321, 18.03153038], [73.03291321, 18.03181267], [73.0331955, 18.03180504], [73.0331955, 18.03236389], [73.03430176, 18.03236008], [73.03430939, 18.03264046], [73.03458405, 18.03263855], [73.03458405, 18.03291702], [73.0348587, 18.03291702], [73.0348587, 18.03347206], [73.03514099, 18.03347015], [73.03514099, 18.03375053], [73.03569794, 18.03375053], [73.03569794, 18.03403091], [73.0359726, 18.0340271], [73.0359726, 18.03458214], [73.03652954, 18.03458023], [73.03652954, 18.03486061], [73.03679657, 18.03486061], [73.03679657, 18.03514099], [73.03708649, 18.03514099], [73.03708649, 18.03541946], [73.03736115, 18.03541756], [73.03736115, 18.03569412], [73.0376358, 18.03569031], [73.0376358, 18.03598022], [73.03791809, 18.03598022], [73.03791809, 18.03625107], [73.03848267, 18.03625107], [73.03848267, 18.03652954], [73.03874969, 18.03652954], [73.03874969, 18.03680992], [73.03901672, 18.03680992], [73.03901672, 18.03874969], [73.03930664, 18.03874969], [73.03930664, 18.03903961], [73.0395813, 18.03902626], [73.0395813, 18.03986168], [73.03985596, 18.03985977], [73.03985596, 18.04042053], [73.04013824, 18.04042053], [73.04013824, 18.04124832], [73.03986359, 18.04124832], [73.03986359, 18.04208374], [73.04013824, 18.04207993], [73.04013824, 18.0423584], [73.0404129, 18.0423584], [73.0404129, 18.04291916], [73.04069519, 18.04291725], [73.04069519, 18.04319382], [73.04125214, 18.04319382], [73.04125214, 18.04347229], [73.04152679, 18.04347229], [73.04152679, 18.04319382], [73.04291534, 18.04319382], [73.04291534, 18.04264069], [73.04319763, 18.04264069], [73.04319763, 18.04207993], [73.04347229, 18.04208374], [73.04347229, 18.04180527], [73.04374695, 18.04180908], [73.04374695, 18.04153061], [73.04428864, 18.04153061], [73.04428864, 18.04124832], [73.04457855, 18.04124832], [73.04457855, 18.04096985], [73.04486084, 18.04097176], [73.04486084, 18.04069519], [73.0451355, 18.04069519], [73.0451355, 18.04097176], [73.04541779, 18.04096985], [73.04541779, 18.04153061], [73.04514313, 18.04153061], [73.04514313, 18.04180908], [73.04486084, 18.04180527], [73.04486084, 18.04208374], [73.04457855, 18.04207993], [73.04457855, 18.04264069], [73.04428864, 18.04264069], [73.04428864, 18.04291916], [73.04402924, 18.04291725], [73.04402924, 18.04319382], [73.04374695, 18.04319382], [73.04374695, 18.04347229], [73.04347229, 18.04346848], [73.04347229, 18.04375076], [73.04319763, 18.04375076], [73.04319763, 18.04403114], [73.0423584, 18.04403114], [73.0423584, 18.04430962], [73.04070282, 18.04430962], [73.04070282, 18.04403114], [73.0404129, 18.04403114], [73.0404129, 18.04375076], [73.04013824, 18.04375076], [73.04013824, 18.04346848], [73.03986359, 18.04347229], [73.03986359, 18.04319382], [73.0395813, 18.04319382], [73.0395813, 18.04264069], [73.03930664, 18.04264069], [73.03930664, 18.04207993], [73.03902435, 18.04208374], [73.03902435, 18.04013634], [73.03874969, 18.04014015], [73.03874969, 18.03985977], [73.03847504, 18.03986168], [73.03847504, 18.03958321], [73.03819275, 18.03958321], [73.03819275, 18.03902626], [73.03791809, 18.03903961], [73.03791809, 18.03819084], [73.0376358, 18.03819466], [73.0376358, 18.03791428], [73.03736115, 18.03792], [73.03736115, 18.03736115], [73.03708649, 18.03736115], [73.03708649, 18.03708076], [73.0368042, 18.03708267], [73.0368042, 18.0368042], [73.0359726, 18.03680992], [73.0359726, 18.03652954], [73.03572083, 18.03652954], [73.03569794, 18.03625107], [73.03542328, 18.03625107], [73.03542328, 18.03569031], [73.0348587, 18.03569412], [73.0348587, 18.03541756], [73.03457642, 18.03541946], [73.03457642, 18.03514099], [73.03430176, 18.03514099], [73.03430176, 18.03486061], [73.0340271, 18.03486061], [73.0340271, 18.03458023], [73.03375244, 18.03458214], [73.03375244, 18.03430557], [73.03347015, 18.03430939], [73.03347015, 18.03375053], [73.03291321, 18.03375053], [73.03291321, 18.03347015], [73.03263855, 18.03347206], [73.03263855, 18.03319359], [73.0320816, 18.03319359], [73.0320816, 18.03291702], [73.03152466, 18.03291702], [73.03152466, 18.03263855], [73.03125, 18.03264046], [73.03125, 18.03236008], [73.03097534, 18.03236389], [73.03097534, 18.03208351], [73.02958679, 18.03208351], [73.02958679, 18.03291702], [73.0293045, 18.03291702], [73.0293045, 18.03319359], [73.02902985, 18.03319359], [73.02902985, 18.03347206], [73.02874756, 18.03347015], [73.02874756, 18.03375053], [73.02819824, 18.03375053], [73.02819824, 18.03430939], [73.02791595, 18.03430939], [73.02791595, 18.03514099], [73.0276413, 18.03514099], [73.0276413, 18.03541946], [73.02735901, 18.03541756], [73.02735901, 18.03569412], [73.02654266, 18.03569031], [73.02654266, 18.03652954], [73.02680206, 18.03652954], [73.02680206, 18.03763962], [73.02654266, 18.03763962], [73.02654266, 18.03792], [73.02625275, 18.03792], [73.02625275, 18.03763962], [73.02513885, 18.03763962], [73.02513885, 18.03736115], [73.02430725, 18.03736115], [73.02430725, 18.03708076], [73.02402496, 18.03708267], [73.02402496, 18.0368042], [73.02430725, 18.03680992], [73.02430725, 18.03652954], [73.02458191, 18.03652954], [73.02458191, 18.03625107], [73.02403259, 18.03625107], [73.02403259, 18.03652954], [73.02346802, 18.03652954], [73.02346802, 18.03680992], [73.02319336, 18.0368042], [73.02319336, 18.03708267], [73.02263641, 18.03708267], [73.02263641, 18.0368042], [73.02153015, 18.0368042], [73.02153015, 18.03930473], [73.02180481, 18.03930473], [73.02180481, 18.03958321], [73.02236176, 18.03958321], [73.02236176, 18.03986168], [73.02263641, 18.03985977], [73.02263641, 18.04014015], [73.0229187, 18.04014015], [73.0229187, 18.04042053], [73.02319336, 18.04041862], [73.02319336, 18.04097176], [73.02346802, 18.04096985], [73.02346802, 18.04124832], [73.02375031, 18.04124832], [73.02375031, 18.04153061], [73.02402496, 18.04153061], [73.02402496, 18.0423584], [73.02458191, 18.0423584], [73.02458191, 18.04264069], [73.02485657, 18.04264069], [73.02485657, 18.04291916], [73.02513885, 18.04291725], [73.02513885, 18.04319382], [73.02541351, 18.04319382], [73.02541351, 18.04347229], [73.0256958, 18.04346848], [73.0256958, 18.04375076], [73.02597046, 18.04375076], [73.02597046, 18.04458427], [73.0256958, 18.04458237], [73.0256958, 18.04514122], [73.02597046, 18.04514122], [73.02597046, 18.04541969], [73.02625275, 18.04541588], [73.02625275, 18.04569435], [73.02680206, 18.04569435], [73.02680206, 18.04597282], [73.02735901, 18.04597282], [73.02735901, 18.04624939], [73.0284729, 18.04624939], [73.0284729, 18.04652977], [73.02874756, 18.04652977], [73.02874756, 18.04681015], [73.0293045, 18.04680634], [73.0293045, 18.0470829], [73.02986145, 18.0470829], [73.02986145, 18.04736137], [73.03069305, 18.04735947], [73.03069305, 18.04763985], [73.03180695, 18.04763985], [73.03180695, 18.04792023], [73.03291321, 18.04791641], [73.03291321, 18.04819489], [73.0331955, 18.04819489], [73.0331955, 18.04847145], [73.03375244, 18.04846954], [73.03375244, 18.04874992], [73.0340271, 18.04874992], [73.0340271, 18.0490303], [73.03514099, 18.0490303], [73.03514099, 18.04931068], [73.0359726, 18.04930305], [73.0359726, 18.04958344], [73.0376358, 18.04958344], [73.0376358, 18.04930305], [73.03874969, 18.04931068], [73.03874969, 18.0490303], [73.03930664, 18.0490303], [73.03930664, 18.04874992], [73.0395813, 18.04874992], [73.0395813, 18.0490303], [73.03986359, 18.0490284], [73.03986359, 18.04958344], [73.0395813, 18.04958344], [73.0395813, 18.04986191], [73.03985596, 18.04986], [73.03985596, 18.05014038], [73.04013824, 18.05014038], [73.04013824, 18.05042076], [73.03985596, 18.05042076], [73.03985596, 18.05181122], [73.0395813, 18.0518055], [73.0395813, 18.05208397], [73.03985596, 18.05208015], [73.03985596, 18.05236053], [73.04013824, 18.05236053], [73.04013824, 18.05291939], [73.0404129, 18.05291557], [73.0404129, 18.05319405], [73.04013824, 18.05319405], [73.04013824, 18.05347252], [73.03985596, 18.05347061], [73.03985596, 18.05375099], [73.03901672, 18.05375099], [73.03901672, 18.05347061], [73.03874969, 18.05347252], [73.03874969, 18.05291557], [73.03848267, 18.05291939], [73.03848267, 18.05236053], [73.03791809, 18.05236053], [73.03791809, 18.05264091], [73.03679657, 18.05264091], [73.03679657, 18.05236053], [73.03624725, 18.05236053], [73.03624725, 18.05208015], [73.03569794, 18.05208015], [73.03569794, 18.05236053], [73.03542328, 18.05236053], [73.03542328, 18.05264091], [73.03514099, 18.05264091], [73.03514099, 18.05236053], [73.0348587, 18.05236053], [73.0348587, 18.05208015], [73.03458405, 18.05208397], [73.03458405, 18.0518055], [73.0348587, 18.05181122], [73.0348587, 18.05153084], [73.03430176, 18.05153084], [73.03430176, 18.05125046], [73.03375244, 18.05125046], [73.03375244, 18.05097961], [73.03347015, 18.05097961], [73.03347015, 18.05070114], [73.03291321, 18.0506897], [73.03291321, 18.05041695], [73.03234863, 18.05042076], [73.03234863, 18.05014038], [73.0320816, 18.05014038], [73.0320816, 18.05042076], [73.03180695, 18.05042076], [73.03180695, 18.05014038], [73.03098297, 18.05014038], [73.03098297, 18.04986], [73.02986145, 18.04986], [73.02986145, 18.05014038], [73.02928925, 18.05014038], [73.02928925, 18.05042076], [73.02902985, 18.05041695], [73.02902985, 18.05069351], [73.0284729, 18.05069351], [73.0284729, 18.05041695], [73.02819824, 18.05042076], [73.02819824, 18.04999924], [73.02819061, 18.04957962], [73.02735901, 18.04958344], [73.02735901, 18.04930305], [73.02625275, 18.04931068], [73.02625275, 18.05014038], [73.02597046, 18.05014038], [73.02597046, 18.05042076], [73.02513885, 18.05042076], [73.02513885, 18.05014038], [73.02485657, 18.05014038], [73.02485657, 18.04986], [73.02458191, 18.04986191], [73.02458191, 18.04874992], [73.02485657, 18.04874992], [73.02485657, 18.04846954], [73.02541351, 18.04847145], [73.02541351, 18.04819489], [73.02513885, 18.04819489], [73.02513885, 18.04791641], [73.02485657, 18.04792023], [73.02485657, 18.04735947], [73.02458191, 18.04736137], [73.02458191, 18.04680634], [73.02430725, 18.04680634], [73.02430725, 18.0470829], [73.02375031, 18.0470829], [73.02375031, 18.04680634], [73.02346802, 18.04681015], [73.02346802, 18.04597282], [73.02319336, 18.04597282], [73.02319336, 18.04513931], [73.0229187, 18.04514122], [73.0229187, 18.04458237], [73.02263641, 18.04458427], [73.02263641, 18.0443058], [73.0229187, 18.04430962], [73.0229187, 18.04375076], [73.02263641, 18.04375076], [73.02263641, 18.04291916], [73.0220871, 18.04291916], [73.0220871, 18.04264069], [73.02179718, 18.04264069], [73.02179718, 18.0423584], [73.02124786, 18.0423584], [73.02124786, 18.04180908], [73.02097321, 18.04180908], [73.02097321, 18.04070091], [73.02040863, 18.04070091], [73.02040863, 18.04014015], [73.0201416, 18.04014015], [73.0201416, 18.03930092], [73.01985931, 18.03930473], [73.01985931, 18.03847313], [73.01958466, 18.03847313], [73.01958466, 18.03708267], [73.01930237, 18.03708267], [73.01930237, 18.0368042], [73.01902771, 18.03680992], [73.01902771, 18.03652954], [73.01875305, 18.03652954], [73.01875305, 18.03598022], [73.01847076, 18.03598022], [73.01847076, 18.03458023], [73.01819611, 18.03458214], [73.01819611, 18.03319359], [73.01791382, 18.03319359], [73.01791382, 18.03291702], [73.0173645, 18.03291702], [73.0173645, 18.03236389], [73.01708221, 18.03236389], [73.01708221, 18.03208351], [73.01569366, 18.03208351], [73.01569366, 18.03236389], [73.01541901, 18.03236008], [73.01541901, 18.03264046], [73.01513672, 18.03263855], [73.01513672, 18.03291702], [73.01457977, 18.03291702], [73.01457977, 18.03347206], [73.01431274, 18.03347015], [73.01431274, 18.03430939], [73.01403046, 18.03430939], [73.01403046, 18.03486061], [73.01346588, 18.03486061], [73.01346588, 18.03514099], [73.01291656, 18.03514099], [73.01291656, 18.03541946], [73.01264191, 18.03541946], [73.01264191, 18.03598022], [73.01235962, 18.0359726], [73.01235962, 18.03708267], [73.01208496, 18.03708267], [73.01209259, 18.03874969], [73.01180267, 18.03874969], [73.01180267, 18.03958321], [73.01152802, 18.03958321], [73.01152802, 18.03986168], [73.01125336, 18.03985977], [73.01125336, 18.04042053], [73.01152802, 18.04042053], [73.01152802, 18.04070091], [73.01125336, 18.04069519], [73.01125336, 18.04097176], [73.01097107, 18.04096985], [73.01097107, 18.04124832], [73.01069641, 18.04124832], [73.01069641, 18.04180908], [73.01013947, 18.04180908], [73.01013947, 18.0423584], [73.01040649, 18.0423584], [73.01040649, 18.04264069], [73.01069641, 18.04264069], [73.01069641, 18.04375076], [73.01040649, 18.04375076], [73.01040649, 18.04430962], [73.01013947, 18.0443058], [73.01013947, 18.04458427], [73.00985718, 18.04458237], [73.00985718, 18.04514122], [73.00958252, 18.04514122], [73.00958252, 18.04541969], [73.00930786, 18.04541969], [73.00930786, 18.04652977], [73.0090332, 18.04652977], [73.0090332, 18.04763985], [73.00875092, 18.04763985], [73.00875092, 18.04847145], [73.00846863, 18.04846954], [73.00846863, 18.04874992], [73.00817871, 18.04874992], [73.00817871, 18.04931068], [73.00791931, 18.04930305], [73.00791931, 18.04958344], [73.00763702, 18.04958344], [73.00763702, 18.04986191], [73.00736237, 18.04986], [73.00736237, 18.05014038], [73.00708008, 18.05014038], [73.00708008, 18.05042076], [73.00653076, 18.05042076], [73.00653076, 18.05097961], [73.00624847, 18.05097961], [73.00624847, 18.05125046], [73.00596619, 18.05125046], [73.00596619, 18.05153084], [73.00569153, 18.05153084], [73.00569153, 18.05181122], [73.00541687, 18.0518055], [73.00541687, 18.05208397], [73.00514221, 18.05208015], [73.00514221, 18.05236053], [73.00485992, 18.05236053], [73.00485992, 18.05264091], [73.00430298, 18.05264091], [73.00430298, 18.05291939], [73.00375366, 18.05291557], [73.00375366, 18.05319405], [73.00319672, 18.05319405], [73.00319672, 18.05347252], [73.00237274, 18.05347061], [73.00237274, 18.05430984], [73.00208282, 18.05430794], [73.00208282, 18.0545826], [73.00152588, 18.0545826], [73.00152588, 18.05430794], [73.00125122, 18.05430984], [73.00125122, 18.05375099], [73.00096893, 18.05375099], [73.00096893, 18.05347061], [73.00069427, 18.05347252], [73.00069427, 18.05291557], [73.00041962, 18.05291939], [73.00041962, 18.05153084], [72.99986267, 18.05153084], [72.99986267, 18.05125046], [72.99958038, 18.05125046], [72.99958038, 18.05097961], [72.99931335, 18.05097961], [72.99931335, 18.05070114], [72.99903107, 18.0506897], [72.99903107, 18.05041695], [72.99874878, 18.05042076], [72.99874878, 18.05014038], [72.99846649, 18.05014038], [72.99846649, 18.04986], [72.99791718, 18.04986191], [72.99791718, 18.04958344], [72.99736023, 18.04958344], [72.99736023, 18.04930305], [72.99687958, 18.04930305], [72.99485779, 18.04930305], [72.99485779, 18.04958344], [72.99430847, 18.04958344], [72.99430847, 18.04986191], [72.99375153, 18.04986], [72.99375153, 18.05014038], [72.99346924, 18.05014038], [72.99346924, 18.05153084], [72.99317932, 18.05153084], [72.99317932, 18.05181122], [72.99291992, 18.0518055], [72.99291992, 18.05208397], [72.99263763, 18.05208015], [72.99263763, 18.05236053], [72.99208069, 18.05236053], [72.99208069, 18.05264091], [72.99180603, 18.05264091], [72.99180603, 18.05291939], [72.99153137, 18.05291557], [72.99153137, 18.05347252], [72.99124908, 18.05347061], [72.99124908, 18.05375099], [72.9909668, 18.05375099], [72.9909668, 18.05430984], [72.99069214, 18.05430794], [72.99069214, 18.0545826], [72.99041748, 18.0545826], [72.99041748, 18.05485916], [72.99013519, 18.05485916], [72.99014282, 18.05513954], [72.98986053, 18.05513954], [72.98986053, 18.05597305], [72.98958588, 18.05597305], [72.98958588, 18.05708313], [72.98986053, 18.05707932], [72.98986053, 18.05820274], [72.99013519, 18.05819511], [72.99013519, 18.05875015], [72.99043274, 18.05875015], [72.99043274, 18.05931282], [72.99069214, 18.05931282], [72.99069214, 18.06125069], [72.9909668, 18.06125069], [72.9909668, 18.06153107], [72.99124908, 18.06153107], [72.99124908, 18.06180954], [72.99153137, 18.06180573], [72.99153137, 18.0620842], [72.99180603, 18.06208038], [72.99180603, 18.06236076], [72.99208069, 18.06236076], [72.99208069, 18.06291962], [72.99236298, 18.0629158], [72.99236298, 18.06319427], [72.99263763, 18.06319427], [72.99263763, 18.06347275], [72.99291992, 18.06347084], [72.99291992, 18.06375122], [72.99319458, 18.06374931], [72.99319458, 18.06406021], [72.99319458, 18.0648613], [72.99346924, 18.06485939], [72.99346924, 18.06653023], [72.99375153, 18.06652641], [72.99375153, 18.06680489], [72.99430847, 18.06680489], [72.99430847, 18.06708336], [72.99458313, 18.06708336], [72.99458313, 18.06736183], [72.99485779, 18.06735992], [72.99485779, 18.0676403], [72.99514008, 18.0676403], [72.99514008, 18.06792068], [72.9954071, 18.06792068], [72.9954071, 18.06819916], [72.99743652, 18.06819534], [72.99764252, 18.06819534], [72.99764252, 18.06847191], [72.99819183, 18.06846809], [72.99819183, 18.06875038], [72.99847412, 18.06875038], [72.99847412, 18.06902885], [72.99874878, 18.06902885], [72.99874878, 18.06958389], [72.99903107, 18.06957817], [72.99903107, 18.06985855], [72.99931335, 18.06985855], [72.99931335, 18.07041931], [73.00013733, 18.07041931], [73.00041962, 18.0704174], [73.00041962, 18.07069397], [73.00152588, 18.07069397], [73.00152588, 18.07097244], [73.00180817, 18.07097244], [73.00180817, 18.07152939], [73.00208282, 18.07152939], [73.00208282, 18.07291985], [73.00235748, 18.07291603], [73.00235748, 18.07458305], [73.00263977, 18.07458115], [73.00263977, 18.07514954], [73.0029068, 18.07514954], [73.0029068, 18.07570076], [73.00263977, 18.07569313], [73.00263977, 18.0759716], [73.00208282, 18.0759716], [73.00208282, 18.07541656], [73.00125122, 18.07542038], [73.00125122, 18.07570076], [73.00096893, 18.07569313], [73.00096893, 18.0759716], [73.00068665, 18.0759697], [73.00068665, 18.07653046], [73.00041962, 18.07653046], [73.00041962, 18.07681084], [73.00013733, 18.07681084], [72.99986267, 18.07681084], [72.99986267, 18.07374954], [72.99958038, 18.07374954], [72.99958038, 18.07402992], [72.99931335, 18.07402992], [72.99931335, 18.0743103], [72.99903107, 18.07430649], [72.99903107, 18.07458305], [72.99874878, 18.07458115], [72.99874878, 18.07542038], [72.99846649, 18.07542038], [72.99846649, 18.07625008], [72.99819183, 18.07625008], [72.99819183, 18.07653046], [72.99764252, 18.07653046], [72.99764252, 18.07681084], [72.99736023, 18.07680511], [72.99736023, 18.07819366], [72.99708557, 18.07819366], [72.99708557, 18.07847214], [72.99680328, 18.07847023], [72.99680328, 18.07903099], [72.99652863, 18.07902527], [72.99652863, 18.07958412], [72.99680328, 18.07958031], [72.99680328, 18.08014107], [72.99652863, 18.08013725], [72.99652863, 18.0806942], [72.99624634, 18.0806942], [72.99624634, 18.08208275], [72.99597168, 18.08208275], [72.99597168, 18.08346939], [72.99569702, 18.08346939], [72.99569702, 18.08403015], [72.99541473, 18.08402824], [72.99541473, 18.08486176], [72.99514008, 18.08486176], [72.99514008, 18.08542061], [72.99485779, 18.08542061], [72.99485779, 18.0857029], [72.99458313, 18.0857029], [72.99458313, 18.08681107], [72.99430847, 18.08681107], [72.99430847, 18.08792114], [72.99402618, 18.08791733], [72.99402618, 18.08847237], [72.99375153, 18.08847046], [72.99375153, 18.08986092], [72.99346924, 18.08986092], [72.99346924, 18.09069443], [72.99317932, 18.09069061], [72.99317932, 18.09181023], [72.99291992, 18.09180832], [72.99291992, 18.09236145], [72.99263763, 18.09236145], [72.99263763, 18.09347153], [72.99236298, 18.09347153], [72.99236298, 18.09458351], [72.99208069, 18.0945797], [72.99208069, 18.09514046], [72.99180603, 18.09514046], [72.99180603, 18.09569359], [72.99153137, 18.09568977], [72.99153137, 18.09626007], [72.99124908, 18.09626007], [72.99124908, 18.09680939], [72.9909668, 18.09680939], [72.9909668, 18.0976429], [72.99069214, 18.09763908], [72.99069214, 18.09819412], [72.99043274, 18.09819031], [72.99043274, 18.09902954], [72.99013519, 18.09902763], [72.99013519, 18.09958267], [72.98986053, 18.09958267], [72.98986053, 18.10013962], [72.98958588, 18.10013962], [72.98958588, 18.10042], [72.98930359, 18.10041618], [72.98930359, 18.10069466], [72.98902893, 18.10069466], [72.98902893, 18.10097313], [72.98874664, 18.10097122], [72.98874664, 18.10124969], [72.98847198, 18.10124969], [72.98847198, 18.10153008], [72.98819733, 18.10152817], [72.98819733, 18.10180473], [72.98791504, 18.10180473], [72.98791504, 18.10208321], [72.98652649, 18.10208321], [72.98652649, 18.10180473], [72.98569489, 18.10180473], [72.98569489, 18.10208321], [72.98513794, 18.10208321], [72.98513794, 18.10236168], [72.98458099, 18.10235977], [72.98458099, 18.10264015], [72.98400879, 18.10264015], [72.98400879, 18.10292053], [72.98347473, 18.10291672], [72.98347473, 18.10347176], [72.98319244, 18.10346985], [72.98319244, 18.10403061], [72.98291779, 18.10403061], [72.98291779, 18.10431099], [72.9826355, 18.10430527], [72.9826355, 18.10513878], [72.98236084, 18.10513115], [72.98236084, 18.10542107], [72.98208618, 18.10541534], [72.98208618, 18.10569382], [72.98097229, 18.10569], [72.98097229, 18.10625076], [72.98069763, 18.10625076], [72.98069763, 18.10680962], [72.98041534, 18.10680771], [72.98042297, 18.10736084], [72.98014069, 18.10736084], [72.98014069, 18.10764122], [72.97957611, 18.10764122], [72.97957611, 18.10791969], [72.97930908, 18.10791969], [72.97930908, 18.10819817], [72.97902679, 18.10819435], [72.97902679, 18.10986137], [72.97875214, 18.10986137], [72.97875214, 18.11181068], [72.97902679, 18.11180496], [72.97902679, 18.11208344], [72.97930908, 18.11207962], [72.97930908, 18.11375046], [72.97902679, 18.11375046], [72.97902679, 18.11403084], [72.97820282, 18.11403084], [72.97820282, 18.11432076], [72.9770813, 18.11432076], [72.9770813, 18.11486053], [72.97680664, 18.11486053], [72.97680664, 18.11597252], [72.9770813, 18.11597252], [72.9770813, 18.1170826], [72.97735596, 18.11707115], [72.97735596, 18.11736107], [72.9770813, 18.11736107], [72.9770813, 18.11791992], [72.97680664, 18.1179142], [72.97680664, 18.11847305], [72.97651672, 18.11847115], [72.97651672, 18.11903], [72.97680664, 18.11902618], [72.97680664, 18.11958313], [72.97651672, 18.11958122], [72.97651672, 18.12013817], [72.97624969, 18.12013817], [72.97624969, 18.12070084], [72.97598267, 18.12070084], [72.97598267, 18.12181091], [72.97569275, 18.12181091], [72.97569275, 18.12235832], [72.97543335, 18.12235832], [72.97543335, 18.12291908], [72.9751358, 18.12291908], [72.9751358, 18.12319946], [72.97458649, 18.12319374], [72.97458649, 18.12347221], [72.9743042, 18.12347221], [72.9743042, 18.12319374], [72.97402954, 18.12319374], [72.97402954, 18.12347221], [72.97374725, 18.1234684], [72.97374725, 18.12375069], [72.97319794, 18.12375069], [72.97319794, 18.12402916], [72.97292328, 18.12402916], [72.97292328, 18.12430954], [72.97264099, 18.12430954], [72.97264099, 18.12486267], [72.9723587, 18.12486267], [72.9723587, 18.12652969], [72.97215271, 18.12652969], [72.97206879, 18.12763977], [72.97180939, 18.12763977], [72.97180176, 18.12986183], [72.9715271, 18.12986183], [72.9715271, 18.13097191], [72.97125244, 18.13097191], [72.97125244, 18.13208389], [72.97097015, 18.13208008], [72.97097015, 18.13292122], [72.97264099, 18.13292122], [72.97264099, 18.13264084], [72.97292328, 18.13264084], [72.97292328, 18.13292122], [72.97319794, 18.1329155], [72.97319794, 18.13347244], [72.9734726, 18.13347054], [72.9734726, 18.13375092], [72.97374725, 18.13375092], [72.97374725, 18.13422012], [72.97374725, 18.13430786], [72.97486115, 18.13430786], [72.97486115, 18.13458252], [72.97541809, 18.13458252], [72.97541809, 18.13485909], [72.97597504, 18.13485909], [72.97597504, 18.13513756], [72.97651672, 18.13513756], [72.97651672, 18.13542938], [72.97846985, 18.13541794], [72.97846985, 18.1356945], [72.97902679, 18.1356945], [72.97902679, 18.13597298], [72.97930908, 18.13596916], [72.97930908, 18.13625145], [72.9798584, 18.13625145], [72.9798584, 18.13653183], [72.98097229, 18.13652992], [72.98097229, 18.13680077], [72.98152924, 18.13680649], [72.98152924, 18.13708305], [72.98180389, 18.13708305], [72.98180389, 18.14097214], [72.98208618, 18.14097023], [72.98208618, 18.14153099], [72.98236084, 18.14152718], [72.98236084, 18.14208412], [72.9826355, 18.14208412], [72.9826355, 18.14236069], [72.9834671, 18.14236069], [72.9834671, 18.14264107], [72.98486328, 18.14264107], [72.98486328, 18.14291954], [72.98513794, 18.14291573], [72.98513794, 18.14347267], [72.98542023, 18.14347076], [72.98542023, 18.14736748], [72.98569489, 18.14736176], [72.98569489, 18.14847183], [72.98596954, 18.14846992], [72.98596954, 18.1487484], [72.98625183, 18.1487484], [72.98625183, 18.14903069], [72.98680878, 18.14902878], [72.98680878, 18.14958382], [72.98652649, 18.14957809], [72.98652649, 18.15014076], [72.98625183, 18.15014076], [72.98625183, 18.15097237], [72.98596954, 18.15096855], [72.98596954, 18.15153122], [72.98569489, 18.1515274], [72.98569489, 18.15208244], [72.98596954, 18.15208244], [72.98596954, 18.15263939], [72.98569489, 18.15263939], [72.98569489, 18.1534729], [72.98542023, 18.1534729], [72.98542023, 18.15431023], [72.98568726, 18.15431023], [72.98568726, 18.15513992], [72.98596954, 18.15513992], [72.98596954, 18.15570068], [72.98625183, 18.15570068], [72.98625183, 18.15681076], [72.98652649, 18.15680313], [72.98652649, 18.15736198], [72.98680878, 18.15736008], [72.98680878, 18.15764046], [72.98707581, 18.15764046], [72.98707581, 18.15792084], [72.98792267, 18.15792084], [72.98792267, 18.15764046], [72.98874664, 18.15764046], [72.98874664, 18.15736008], [72.98986053, 18.15736008], [72.98986053, 18.15764046], [72.99014282, 18.15764046], [72.99014282, 18.15792084], [72.99041748, 18.15791512], [72.99041748, 18.15986061], [72.99013519, 18.15986061], [72.99013519, 18.15958405], [72.98930359, 18.15958405], [72.98930359, 18.15930557], [72.98847198, 18.15930939], [72.98847198, 18.15986061], [72.98792267, 18.15986061], [72.98792267, 18.16041946], [72.98764038, 18.16041946], [72.98764038, 18.16152954], [72.98735809, 18.16152954], [72.98735809, 18.16319466], [72.98707581, 18.16319084], [72.98707581, 18.16403008], [72.98680878, 18.16402817], [72.98680878, 18.16486168], [72.98652649, 18.16486168], [72.98652649, 18.16570282], [72.98625183, 18.16570282], [72.98625183, 18.16764069], [72.98596954, 18.16763878], [72.98596954, 18.16819382], [72.98568726, 18.16818047], [72.98568726, 18.16875076], [72.98542023, 18.16875076], [72.98542023, 18.17041969], [72.98513794, 18.17041588], [72.98513794, 18.17097282], [72.98486328, 18.17097092], [72.98486328, 18.17154121], [72.98458099, 18.17152786], [72.98458099, 18.17347145], [72.98430634, 18.17347145], [72.98430634, 18.17486191], [72.98400879, 18.17485809], [72.98400879, 18.17542076], [72.98374939, 18.17541885], [72.98374939, 18.1756897], [72.9834671, 18.17569923], [72.9834671, 18.17653084], [72.98374939, 18.17652893], [72.98374939, 18.17708397], [72.98347473, 18.17708397], [72.98347473, 18.17735863], [72.98319244, 18.17734909], [72.98319244, 18.17791939], [72.98291779, 18.17791939], [72.98291779, 18.1787529], [72.98264313, 18.1787529], [72.98264313, 18.17930984], [72.98236084, 18.17930984], [72.98236084, 18.18013954], [72.98208618, 18.18013954], [72.98208618, 18.18208313], [72.98179626, 18.18208122], [72.98179626, 18.18292046], [72.98152924, 18.18292046], [72.98152924, 18.18348122], [72.98124695, 18.18347168], [72.98124695, 18.18458366], [72.98097229, 18.18457985], [72.98097229, 18.18514061], [72.98069763, 18.18514061], [72.98069763, 18.18542099], [72.98041534, 18.18541527], [72.98042297, 18.18625069], [72.98014069, 18.18625069], [72.98014069, 18.18736076], [72.9798584, 18.18736076], [72.9798584, 18.18875122], [72.97957611, 18.18875122], [72.97957611, 18.18930817], [72.97930908, 18.18930817], [72.97930908, 18.1926403], [72.97902679, 18.1926384], [72.97902679, 18.19347382], [72.97930908, 18.19347191], [72.97930908, 18.19375038], [72.97957611, 18.19375038], [72.97957611, 18.19403076], [72.98014069, 18.19403076], [72.98014069, 18.19375038], [72.98042297, 18.19375038], [72.98041534, 18.19347382], [72.98069763, 18.19347382], [72.98069763, 18.19319534], [72.98123932, 18.19320107], [72.98123932, 18.19292068], [72.98236084, 18.19292068], [72.98236084, 18.19320107], [72.98319244, 18.19320107], [72.98319244, 18.19292068], [72.98374939, 18.19292068], [72.98374939, 18.1926403], [72.98486328, 18.1926403], [72.98486328, 18.19292068], [72.98513794, 18.19292068], [72.98513794, 18.1926403], [72.98542023, 18.1926403], [72.98542023, 18.19292068], [72.98569489, 18.19291687], [72.98569489, 18.19347382], [72.98764038, 18.19347191], [72.98764038, 18.19403076], [72.98792267, 18.19403076], [72.98792267, 18.19431114], [72.98764038, 18.19431114], [72.98764038, 18.19514084], [72.98737335, 18.19514084], [72.98737335, 18.19542122], [72.98458099, 18.19542122], [72.98458099, 18.19514084], [72.98429871, 18.19514084], [72.98429871, 18.19542122], [72.98400879, 18.19542122], [72.98400879, 18.19514084], [72.98291779, 18.19514084], [72.98291779, 18.19486046], [72.98264313, 18.19486046], [72.98264313, 18.19514084], [72.98208618, 18.19514084], [72.98208618, 18.19542122], [72.98124695, 18.1954174], [72.98124695, 18.19597244], [72.98041534, 18.19597244], [72.98042297, 18.19625092], [72.98014069, 18.19625092], [72.98014069, 18.19652939], [72.9798584, 18.19652939], [72.9798584, 18.19680977], [72.97958374, 18.19680405], [72.97958374, 18.19708252], [72.97930908, 18.19708061], [72.97930908, 18.19736099], [72.97902679, 18.19736099], [72.97902679, 18.19763947], [72.97875214, 18.19763947], [72.97875214, 18.19791985], [72.97846985, 18.19791412], [72.97846985, 18.1981945], [72.97820282, 18.19819069], [72.97820282, 18.19848061], [72.97763824, 18.19848061], [72.97763824, 18.1993103], [72.97736359, 18.1993084], [72.97736359, 18.19958305], [72.9770813, 18.19958115], [72.9770813, 18.20013809], [72.97680664, 18.20013809], [72.97680664, 18.20042038], [72.97624969, 18.20042038], [72.97624969, 18.20070076], [72.97541809, 18.20069695], [72.97541809, 18.2009716], [72.9751358, 18.2009697], [72.9751358, 18.20124817], [72.97486115, 18.20124817], [72.97486115, 18.20153046], [72.97458649, 18.20152092], [72.97458649, 18.20181084], [72.9743042, 18.20180511], [72.9743042, 18.20208359], [72.97374725, 18.20208359], [72.97374725, 18.20236206], [72.9734726, 18.20235825], [72.9734726, 18.20264053], [72.97319794, 18.20264053], [72.97319794, 18.20319366], [72.97291565, 18.20319366], [72.97291565, 18.20347023], [72.9723587, 18.20346832], [72.9723587, 18.20375061], [72.9715271, 18.20375061], [72.9715271, 18.20346832], [72.97125244, 18.20347023], [72.97125244, 18.20319366], [72.97097015, 18.20319366], [72.97097015, 18.20347023], [72.97041321, 18.20346832], [72.97041321, 18.20375061], [72.97013855, 18.20375061], [72.97013855, 18.20458412], [72.96985626, 18.20458031], [72.96985626, 18.20514107], [72.9695816, 18.20514107], [72.9695816, 18.20541954], [72.96929932, 18.20541954], [72.96929932, 18.20514107], [72.96819305, 18.20514107], [72.96819305, 18.20541954], [72.9679184, 18.20541954], [72.9679184, 18.20625114], [72.96763611, 18.20625114], [72.96763611, 18.20681], [72.96736145, 18.20680618], [72.96736145, 18.20708275], [72.96708679, 18.20708275], [72.96708679, 18.20763969], [72.9668045, 18.20763969], [72.9668045, 18.20819473], [72.96652985, 18.20819473], [72.96652985, 18.20930481], [72.96624756, 18.20930481], [72.96624756, 18.20986176], [72.9659729, 18.20985985], [72.9659729, 18.21014023], [72.96569824, 18.21014023], [72.96569824, 18.21042061], [72.96541595, 18.21042061], [72.96541595, 18.21071053], [72.9651413, 18.21069527], [72.9651413, 18.21097183], [72.96485901, 18.21096992], [72.96485901, 18.21153069], [72.96457672, 18.21153069], [72.96457672, 18.21181107], [72.96430206, 18.21180534], [72.96430206, 18.21208382], [72.96263885, 18.21208], [72.96263885, 18.21236038], [72.96235657, 18.21236038], [72.96235657, 18.21292114], [72.96208191, 18.21291542], [72.96208191, 18.21319389], [72.96180725, 18.21319389], [72.96180725, 18.21347237], [72.96152496, 18.21347237], [72.96152496, 18.21375084], [72.96098328, 18.21375084], [72.96098328, 18.21403122], [72.96069336, 18.21403122], [72.96069336, 18.21430969], [72.9604187, 18.21430779], [72.9604187, 18.21458244], [72.96012878, 18.21458054], [72.96012878, 18.21486092], [72.95986176, 18.21486092], [72.95986176, 18.21541977], [72.9595871, 18.21541595], [72.9595871, 18.21569443], [72.95929718, 18.21569061], [72.95929718, 18.21624756], [72.95903015, 18.21624756], [72.95903015, 18.21681023], [72.95874786, 18.21680641], [72.95874786, 18.21708107], [72.95819092, 18.21708107], [72.95819092, 18.21736145], [72.95791626, 18.21736145], [72.95791626, 18.2179203], [72.95735931, 18.2179203], [72.95735931, 18.21820259], [72.95708466, 18.21819496], [72.95708466, 18.21846962], [72.95680237, 18.21846962], [72.95680237, 18.21875191], [72.95652771, 18.21875191], [72.95652771, 18.21903038], [72.95625305, 18.21903038], [72.95625305, 18.21931076], [72.95569611, 18.21931076], [72.95569611, 18.21959114], [72.95347595, 18.21959114], [72.95347595, 18.21931076], [72.95318604, 18.21931076], [72.95318604, 18.21903038], [72.95291901, 18.21903038], [72.95291901, 18.21875191], [72.95181274, 18.21875191], [72.95181274, 18.21903038], [72.95153046, 18.21903038], [72.95153046, 18.21931076], [72.95124817, 18.21930504], [72.95124817, 18.21986389], [72.95096588, 18.21986008], [72.95096588, 18.22042084], [72.95069122, 18.22041702], [72.95069122, 18.22069359], [72.95041656, 18.22069359], [72.95041656, 18.22097206], [72.95014191, 18.22097015], [72.95014191, 18.22125053], [72.94985962, 18.22125053], [72.94985962, 18.22153091], [72.94930267, 18.22153091], [72.94930267, 18.22180939], [72.94847107, 18.22180557], [72.94847107, 18.22208214], [72.94790649, 18.22208023], [72.94790649, 18.22236061], [72.94735718, 18.22236061], [72.94735718, 18.22265053], [72.94708252, 18.22265053], [72.94708252, 18.22291946], [72.94652557, 18.22291756], [72.94652557, 18.22319412], [72.94458008, 18.22319412], [72.94458008, 18.22263908], [72.94431305, 18.22265053], [72.94431305, 18.22236061], [72.94374847, 18.22236061], [72.94374847, 18.22208023], [72.94319153, 18.22208214], [72.94319153, 18.22180557], [72.94291687, 18.22180939], [72.94291687, 18.22014046], [72.94264221, 18.22014046], [72.94264221, 18.21986008], [72.94180298, 18.21986008], [72.94180298, 18.22014046], [72.94124603, 18.22014046], [72.94124603, 18.21986008], [72.94097137, 18.21986389], [72.94097137, 18.21958351], [72.9404068, 18.21959114], [72.9404068, 18.21931076], [72.9393158, 18.21931076], [72.9393158, 18.21903038], [72.93902588, 18.21903038], [72.93902588, 18.21820259], [72.9393158, 18.21820259], [72.9393158, 18.21681023], [72.93819427, 18.21680641], [72.93819427, 18.21708107], [72.93736267, 18.21708107], [72.93736267, 18.21680641], [72.93569183, 18.21680641], [72.93569183, 18.21708107], [72.93541718, 18.21708107], [72.93541718, 18.21736145], [72.93486023, 18.21736145], [72.93486023, 18.21764183], [72.93374634, 18.21764183], [72.93374634, 18.2179203], [72.93318939, 18.2179203], [72.93318939, 18.21820259], [72.93264008, 18.21819496], [72.93264008, 18.21846962], [72.93235779, 18.21846962], [72.93235779, 18.21875191], [72.93208313, 18.21875191], [72.93208313, 18.21903038], [72.93180847, 18.21903038], [72.93180847, 18.21931076], [72.93152618, 18.21930504], [72.93152618, 18.21986389], [72.93125153, 18.21986008], [72.93125153, 18.22042084], [72.93096924, 18.22041702], [72.93096924, 18.22064972], [72.93096924, 18.22125053], [72.93125153, 18.22125053], [72.93125153, 18.22153091], [72.93096924, 18.22153091], [72.93096924, 18.22375107], [72.93125153, 18.22375107], [72.93125153, 18.22402954], [72.93180847, 18.22402954], [72.93180847, 18.22430992], [72.93287659, 18.2243042], [72.93319702, 18.2243042], [72.93319702, 18.22458267], [72.93347168, 18.22458267], [72.93347168, 18.22543907], [72.93347168, 18.22597313], [72.93374634, 18.22597122], [72.93374634, 18.22653008], [72.93402863, 18.22653008], [72.93402863, 18.22763824], [72.93430328, 18.22763634], [72.93430328, 18.22847176], [72.9345932, 18.22846031], [72.9345932, 18.22903061], [72.93486023, 18.22903061], [72.93486023, 18.22930908], [72.93514252, 18.22930527], [72.93514252, 18.22958374], [72.93541718, 18.22957993], [72.93541718, 18.2298584], [72.93569183, 18.2298584], [72.93569183, 18.23014069], [72.93624878, 18.23014069], [72.93624878, 18.23041916], [72.93708038, 18.23041725], [72.93708038, 18.23069382], [72.93736267, 18.23069382], [72.93736267, 18.23097229], [72.93763733, 18.23096848], [72.93763733, 18.23264122], [72.93791962, 18.23264122], [72.93791962, 18.23291969], [72.93846893, 18.23291588], [72.93846893, 18.23319435], [72.93930817, 18.23319435], [72.93930817, 18.23291588], [72.93985748, 18.23291588], [72.93985748, 18.23319435], [72.94013977, 18.23319435], [72.94013977, 18.23347282], [72.94069672, 18.23347282], [72.94069672, 18.23374939], [72.94097137, 18.23374939], [72.94097137, 18.23402977], [72.94124603, 18.23402977], [72.94124603, 18.23459053], [72.94152832, 18.23458481], [72.94152832, 18.23736191], [72.94125366, 18.23736191], [72.94125366, 18.23847198], [72.94097137, 18.23847008], [72.94097137, 18.23875046], [72.94069672, 18.23875046], [72.94069672, 18.23903084], [72.9404068, 18.23903084], [72.9404068, 18.23986053], [72.94013977, 18.23986053], [72.94013977, 18.2420826], [72.93985748, 18.2420826], [72.93985748, 18.24319458], [72.94041443, 18.24319458], [72.94041443, 18.24347305], [72.94069672, 18.24346924], [72.94069672, 18.24375153], [72.94097137, 18.24375153], [72.94097137, 18.24430466], [72.94124603, 18.24430084], [72.94124603, 18.24514008], [72.94097137, 18.24514008], [72.94097137, 18.24542046], [72.94152832, 18.24542046], [72.94152832, 18.24570274], [72.94180298, 18.24569511], [72.94180298, 18.24597359], [72.94208527, 18.24597359], [72.94208527, 18.24625015], [72.94235992, 18.24625015], [72.94235992, 18.24682045], [72.94264221, 18.24682045], [72.94264221, 18.24792099], [72.94235992, 18.24791718], [72.94235992, 18.24847221], [72.9420929, 18.24847031], [72.9420929, 18.24903107], [72.94180298, 18.24903107], [72.94180298, 18.24930954], [72.94152832, 18.24930954], [72.94152832, 18.24986076], [72.9420929, 18.24986076], [72.9420929, 18.25014114], [72.94235992, 18.25014114], [72.94235992, 18.25181007], [72.94208527, 18.25180435], [72.94208527, 18.25208282], [72.94180298, 18.25208282], [72.94180298, 18.2523613], [72.94152832, 18.2523613], [72.94152832, 18.25347137], [72.94180298, 18.25346947], [72.94180298, 18.2551384], [72.94152832, 18.2551384], [72.94152832, 18.25542068], [72.94125366, 18.25541878], [72.94125366, 18.25597191], [72.94097137, 18.25596809], [72.94097137, 18.25680923], [72.94069672, 18.25680923], [72.94069672, 18.25735855], [72.9404068, 18.25735855], [72.9404068, 18.25792122], [72.94013977, 18.2579174], [72.94013977, 18.25847244], [72.93985748, 18.25847244], [72.93985748, 18.25902939], [72.93958282, 18.25902939], [72.93958282, 18.2598629], [72.93930817, 18.2598629], [72.93930817, 18.2606945], [72.93958282, 18.2606945], [72.93958282, 18.26097488], [72.93985748, 18.26097107], [72.93985748, 18.26264], [72.93958282, 18.26264], [72.93958282, 18.26431084], [72.93930817, 18.26430511], [72.93930817, 18.26458359], [72.93902588, 18.26458359], [72.93902588, 18.26486206], [72.93875122, 18.26486015], [72.93875122, 18.26542091], [72.93846893, 18.26541519], [72.93846893, 18.26597214], [72.93818665, 18.26597023], [72.93818665, 18.26625061], [72.93791962, 18.26625061], [72.93791962, 18.26653099], [72.93763733, 18.26653099], [72.93763733, 18.26902962], [72.93736267, 18.26902962], [72.93736267, 18.26958275], [72.93708038, 18.26958084], [72.93708038, 18.26985931], [72.93680573, 18.26985931], [72.93681335, 18.2701416], [72.93653107, 18.2701416], [72.93653107, 18.27042007], [72.93624878, 18.27042007], [72.93624878, 18.27070045], [72.93597412, 18.27069473], [72.93597412, 18.27096939], [72.93569183, 18.27096939], [72.93569183, 18.27123833], [72.93514252, 18.27125168], [72.93514252, 18.27153015], [72.93486023, 18.27152824], [72.93486023, 18.27180481], [72.9345932, 18.27179909], [72.9345932, 18.27292061], [72.93486023, 18.27291679], [72.93486023, 18.27347374], [72.93514252, 18.27347183], [72.93514252, 18.27375984], [72.93541718, 18.27375984], [72.93541718, 18.27403069], [72.93569183, 18.27403069], [72.93569183, 18.27431107], [72.93597412, 18.27430534], [72.93597412, 18.27458382], [72.93611908, 18.27458382], [72.93653107, 18.27458191], [72.93653107, 18.27486038], [72.93708038, 18.27486038], [72.93708038, 18.27514076], [72.93736267, 18.27513885], [72.93736267, 18.2756958], [72.93708038, 18.2756958], [72.93708038, 18.27597237], [72.93680573, 18.27597237], [72.93681335, 18.27625084], [72.93653107, 18.27625084], [72.93653107, 18.27653122], [72.93636322, 18.27652931], [72.93624878, 18.27653122], [72.93624878, 18.27874947], [72.93596649, 18.27874947], [72.93596649, 18.27902985], [72.93569183, 18.27902985], [72.93569183, 18.27931023], [72.93541718, 18.27930641], [72.93541718, 18.27986145], [72.93514252, 18.27986145], [72.93514252, 18.28097153], [72.93541718, 18.28096962], [72.93541718, 18.28153038], [72.93569183, 18.28153038], [72.93569183, 18.28181076], [72.93597412, 18.28180504], [72.93597412, 18.28208351], [72.93624878, 18.28208351], [72.93624878, 18.28236008], [72.93653107, 18.28235817], [72.93653107, 18.28264046], [72.93680573, 18.28264046], [72.93680573, 18.28319359], [72.93708038, 18.28319359], [72.93708038, 18.28347015], [72.93736267, 18.28346825], [72.93736267, 18.28374863], [72.93791962, 18.28374863], [72.93791962, 18.28403091], [72.93818665, 18.28403091], [72.93818665, 18.28430939], [72.93875122, 18.28430557], [72.93875122, 18.28458405], [72.93902588, 18.28458405], [72.93902588, 18.28430557], [72.93958282, 18.28430939], [72.93958282, 18.28403091], [72.94013977, 18.28403091], [72.94013977, 18.28430939], [72.94069672, 18.28430939], [72.94069672, 18.28486252], [72.94097137, 18.28486252], [72.94097137, 18.2851429], [72.94152832, 18.2851429], [72.94152832, 18.28541946], [72.9420929, 18.28541946], [72.9420929, 18.2851429], [72.94458008, 18.2851429], [72.94458008, 18.28486252], [72.94596863, 18.28486252], [72.94596863, 18.2851429], [72.9465332, 18.2851429], [72.9465332, 18.28541946], [72.94790649, 18.28541946], [72.94790649, 18.2851429], [72.94847107, 18.2851429], [72.94847107, 18.28486252], [72.94902802, 18.28486252], [72.94902802, 18.28457832], [72.94958496, 18.28458405], [72.94958496, 18.28430557], [72.95014191, 18.28430939], [72.95014191, 18.28403091], [72.95069122, 18.28403091], [72.95069122, 18.28346825], [72.95097351, 18.28347015], [72.95097351, 18.28291893], [72.9512558, 18.28293037], [72.9512558, 18.28256989], [72.95124817, 18.28153038], [72.95096588, 18.28153038], [72.95096588, 18.28013992], [72.9512558, 18.28013992], [72.9512558, 18.27985954], [72.95180511, 18.27986145], [72.95180511, 18.27958298], [72.95291901, 18.27958298], [72.95291901, 18.27930641], [72.95318604, 18.27931023], [72.95318604, 18.27902985], [72.95347595, 18.27902985], [72.95347595, 18.27874947], [72.95375061, 18.27874947], [72.95375061, 18.27819061], [72.95458221, 18.27819443], [72.95458221, 18.27791405], [72.95513916, 18.27791977], [72.95513916, 18.27763939], [72.95625305, 18.27763939], [72.95625305, 18.27791977], [72.95708466, 18.27791405], [72.95708466, 18.27819443], [72.95735931, 18.27819443], [72.95735931, 18.2784729], [72.95847321, 18.27847099], [72.95847321, 18.27902985], [72.95903015, 18.27902985], [72.95903015, 18.27931023], [72.95930481, 18.27930641], [72.95930481, 18.27986145], [72.9595871, 18.27985954], [72.9595871, 18.28013992], [72.96012878, 18.28013992], [72.96012878, 18.2804203], [72.96125031, 18.2804203], [72.96125031, 18.28070068], [72.962677, 18.28069878], [72.9631958, 18.28070068], [72.9631958, 18.2804203], [72.96375275, 18.2804203], [72.96375275, 18.28013992], [72.96457672, 18.28013992], [72.96457672, 18.27985954], [72.96485901, 18.27986145], [72.96485901, 18.27958298], [72.96541595, 18.27958298], [72.96541595, 18.27930641], [72.96569061, 18.27931023], [72.96569824, 18.27902985], [72.9659729, 18.27902985], [72.9659729, 18.27874947], [72.96626282, 18.27874947], [72.96624756, 18.2784729], [72.96652985, 18.2784729], [72.96652985, 18.27791405], [72.96679688, 18.27791977], [72.96679688, 18.27680016], [72.96652985, 18.27680588], [72.96652985, 18.27629089], [72.96652985, 18.27597237], [72.9668045, 18.27597237], [72.9668045, 18.27541733], [72.96708679, 18.27542114], [72.96708679, 18.27514076], [72.96819305, 18.27514076], [72.96819305, 18.27486038], [72.96875, 18.27486038], [72.96875, 18.27458191], [72.96930695, 18.27458382], [72.96930695, 18.27430534], [72.9695816, 18.27431107], [72.9695816, 18.27236176], [72.96986389, 18.27236176], [72.96986389, 18.27208328], [72.97041321, 18.27208328], [72.97041321, 18.27125168], [72.97070313, 18.27125168], [72.9706955, 18.26930618], [72.97041321, 18.26930809], [72.97041321, 18.26902962], [72.96985626, 18.26902962], [72.96985626, 18.26874924], [72.9695816, 18.26874924], [72.9695816, 18.26791954], [72.96985626, 18.26791954], [72.96985626, 18.26762962], [72.97013855, 18.26763725], [72.97013855, 18.26652527], [72.97041321, 18.26653099], [72.97041321, 18.26514053], [72.97013855, 18.26514053], [72.97013855, 18.26457024], [72.96986389, 18.26458359], [72.96986389, 18.26430511], [72.97070313, 18.26431084], [72.97070313, 18.26403046], [72.97125244, 18.26403046], [72.97125244, 18.26375008], [72.9715271, 18.26375008], [72.9715271, 18.2634697], [72.97374725, 18.2634716], [72.97374725, 18.26291656], [72.97402954, 18.26292038], [72.97402954, 18.26235962], [72.97374725, 18.26236153], [72.97374725, 18.26208305], [72.9734726, 18.26208305], [72.9734726, 18.26152802], [72.97319794, 18.26152992], [72.97319794, 18.26124954], [72.97291565, 18.26124954], [72.97291565, 18.26097488], [72.97264099, 18.26097488], [72.97264099, 18.2606945], [72.97208405, 18.2606945], [72.97208405, 18.26041603], [72.97180176, 18.26041985], [72.97180176, 18.26013947], [72.97125244, 18.26013947], [72.97125244, 18.25707817], [72.9715271, 18.25708389], [72.9715271, 18.25597191], [72.97180176, 18.25597191], [72.97180176, 18.2551384], [72.97206879, 18.2551384], [72.97206879, 18.25430107], [72.9723587, 18.25430489], [72.9723587, 18.25319481], [72.97264099, 18.25319481], [72.97264099, 18.25263977], [72.97291565, 18.25263977], [72.97291565, 18.25208282], [72.97319794, 18.25208282], [72.97319794, 18.25152779], [72.9734726, 18.25152969], [72.9734726, 18.25097084], [72.97374725, 18.25097275], [72.97374725, 18.2504158], [72.97402954, 18.25041962], [72.97402954, 18.24903107], [72.97374725, 18.24903107], [72.97374725, 18.24764061], [72.97402954, 18.24764061], [72.97402954, 18.24682045], [72.97429657, 18.24682045], [72.97429657, 18.24653053], [72.9751358, 18.24653053], [72.9751358, 18.24682045], [72.97598267, 18.24682045], [72.97598267, 18.24653053], [72.97651672, 18.24653053], [72.97651672, 18.24625015], [72.97735596, 18.24625015], [72.97735596, 18.24597168], [72.97819519, 18.24597359], [72.97819519, 18.24569511], [72.9798584, 18.24570274], [72.9798584, 18.24542046], [72.98042297, 18.24542046], [72.98042297, 18.2448616], [72.98069763, 18.2448616], [72.98069763, 18.24430466], [72.98097229, 18.24430466], [72.98097229, 18.24375153], [72.98123932, 18.24375153], [72.98123932, 18.24292183], [72.98152924, 18.24292183], [72.98152924, 18.24208069], [72.98236084, 18.24208069], [72.98236084, 18.24235916], [72.9826355, 18.24235916], [72.9826355, 18.24263763], [72.98291779, 18.24263763], [72.98291779, 18.24291611], [72.98319244, 18.24291611], [72.98319244, 18.24319458], [72.98430634, 18.24319458], [72.98430634, 18.24347305], [72.98486328, 18.24347305], [72.98486328, 18.24319458], [72.98652649, 18.24319458], [72.98652649, 18.24347305], [72.98791504, 18.24347305], [72.98791504, 18.24375153], [72.98847198, 18.24375153], [72.98847198, 18.24403191], [72.98930359, 18.24402809], [72.98930359, 18.24430466], [72.98986053, 18.24430466], [72.98986053, 18.24458313], [72.99041748, 18.24458313], [72.99041748, 18.2448616], [72.99069214, 18.2448616], [72.99069214, 18.24514008], [72.99124908, 18.24514008], [72.99124908, 18.24542046], [72.99153137, 18.24542046], [72.99153137, 18.24570274], [72.99180603, 18.24569511], [72.99180603, 18.24597359], [72.99263763, 18.24597168], [72.99263763, 18.24625015], [72.99317932, 18.24625015], [72.99317932, 18.24597168], [72.99402618, 18.24597359], [72.99402618, 18.24569511], [72.99458313, 18.24570274], [72.99458313, 18.24542046], [72.9954071, 18.24542046], [72.9954071, 18.24514008], [72.99623871, 18.24514008], [72.99623871, 18.2448616], [72.99764252, 18.2448616], [72.99764252, 18.24514008], [72.99791718, 18.24514008], [72.99791718, 18.24764061], [72.99819183, 18.24764061], [72.99819183, 18.24792099], [72.99847412, 18.24791718], [72.99847412, 18.24819374], [72.99874878, 18.24819374], [72.99874878, 18.24847221], [72.99993896, 18.24847221], [73.00041962, 18.24847221], [73.00041962, 18.24819374], [73.00096893, 18.24819374], [73.00096893, 18.24791718], [73.00152588, 18.24792099], [73.00152588, 18.24764061], [73.00180817, 18.24764061], [73.00180817, 18.24736023], [73.00208282, 18.24736023], [73.00208282, 18.24707985], [73.00235748, 18.24708366], [73.00235748, 18.24652863], [73.00263977, 18.24653053], [73.00263977, 18.24625015], [73.00430298, 18.24625015], [73.00430298, 18.24597168], [73.00458527, 18.24597359], [73.00458527, 18.24569511], [73.00485992, 18.24570274], [73.00485992, 18.24542046], [73.00514221, 18.24542046], [73.00514221, 18.24514008], [73.00540924, 18.24514008], [73.00540924, 18.2448616], [73.00763702, 18.2448616], [73.00763702, 18.24514008], [73.00875092, 18.24514008], [73.00875092, 18.2448616], [73.01041412, 18.2448616], [73.01041412, 18.24458313], [73.01097107, 18.24458313], [73.01097107, 18.24430466], [73.01125336, 18.24430466], [73.01125336, 18.24402809], [73.01152802, 18.24403191], [73.01152802, 18.24346924], [73.01180267, 18.24347305], [73.01180267, 18.24319458], [73.01208496, 18.24319458], [73.01208496, 18.24291611], [73.01235962, 18.24292183], [73.01235962, 18.24235916], [73.01249695, 18.24235916], [73.01264191, 18.24235916], [73.01264191, 18.24208069], [73.01319122, 18.24208069], [73.01319122, 18.24235916], [73.01364899, 18.24235916], [73.01457977, 18.24235916], [73.01457977, 18.24263763], [73.01541901, 18.24263763], [73.01541901, 18.24308968], [73.01541901, 18.24319458], [73.01569366, 18.24319458], [73.01569366, 18.24347305], [73.01541901, 18.24346924], [73.01541901, 18.24403191], [73.01569366, 18.24402809], [73.01569366, 18.24430466], [73.01597595, 18.24430466], [73.01597595, 18.24458313], [73.01625061, 18.24458313], [73.01625061, 18.2448616], [73.0165329, 18.2448616], [73.0165329, 18.24514008], [73.01680756, 18.24514008], [73.01680756, 18.24542046], [73.01708221, 18.24542046], [73.01708221, 18.24570274], [73.01790619, 18.24570274], [73.01790619, 18.24457932], [73.01819611, 18.24458313], [73.01819611, 18.24378967], [73.01819611, 18.24347305], [73.01847076, 18.24347305], [73.01847076, 18.24291611], [73.01875305, 18.24292183], [73.01875305, 18.24263763], [73.01930237, 18.24263763], [73.01930237, 18.24208069], [73.01958466, 18.2420826], [73.01958466, 18.24152756], [73.0201416, 18.24152756], [73.0201416, 18.24124908], [73.02040863, 18.24124908], [73.02040863, 18.24152756], [73.02124786, 18.24152756], [73.02124786, 18.24180984], [73.02153015, 18.24180984], [73.02153015, 18.24152756], [73.02179718, 18.24152756], [73.02179718, 18.24097061], [73.02236176, 18.24097252], [73.02236176, 18.24069405], [73.02263641, 18.24069405], [73.02263641, 18.24097252], [73.0229187, 18.24097252], [73.0229187, 18.24069405], [73.02347565, 18.24069405], [73.02347565, 18.24097252], [73.02513885, 18.24097252], [73.02513885, 18.24069405], [73.02625275, 18.24069405], [73.02625275, 18.24041939], [73.02680206, 18.24041939], [73.02680206, 18.24069405], [73.02700043, 18.24069405], [73.02735901, 18.24069405], [73.02735901, 18.24041939], [73.02819061, 18.24041939], [73.02819824, 18.24014091], [73.02874756, 18.24014091], [73.02874756, 18.23986053], [73.02928925, 18.23986053], [73.02928925, 18.23958015], [73.03013611, 18.23958397], [73.03013611, 18.2393055], [73.03069305, 18.23931122], [73.03069305, 18.23903084], [73.03125, 18.23903084], [73.03125, 18.23875046], [73.03151703, 18.23875046], [73.03151703, 18.23847008], [73.03180695, 18.23847198], [73.03180695, 18.23819351], [73.03263855, 18.23819351], [73.03263855, 18.23791695], [73.03320313, 18.23792076], [73.03320313, 18.23764992], [73.03347015, 18.23764992], [73.03347015, 18.23736], [73.0340271, 18.23736191], [73.0340271, 18.23708344], [73.0348587, 18.23708344], [73.0348587, 18.23680305], [73.03542328, 18.23681068], [73.03542328, 18.23624992], [73.0359726, 18.23624992], [73.0359726, 18.23596954], [73.03624725, 18.23597145], [73.03624725, 18.23541641], [73.03652954, 18.23542023], [73.03652954, 18.23485947], [73.03848267, 18.23485947], [73.03848267, 18.23542023], [73.03902435, 18.23541641], [73.03902435, 18.23569489], [73.04096985, 18.23569489], [73.04096985, 18.23541641], [73.04180908, 18.23542023], [73.04180908, 18.23513985], [73.0423584, 18.23513985], [73.0423584, 18.23485947], [73.04291534, 18.23486137], [73.04291534, 18.23458481], [73.04402924, 18.23459053], [73.04402924, 18.23431015], [73.04428864, 18.23431015], [73.04428864, 18.23402977], [73.04486084, 18.23402977], [73.04486084, 18.23374939], [73.04514313, 18.23374939], [73.04514313, 18.23402977], [73.04569244, 18.23402977], [73.04569244, 18.23374939], [73.04624939, 18.23374939], [73.04624939, 18.23347282], [73.04680634, 18.23347282], [73.04680634, 18.23319435], [73.04736328, 18.23319435], [73.04736328, 18.23291588], [73.04875183, 18.23291969], [73.04875183, 18.23208046], [73.04902649, 18.23208046], [73.04902649, 18.23152733], [73.04930878, 18.23153114], [73.04930878, 18.23125267], [73.04902649, 18.23125267], [73.04902649, 18.2306881], [73.04875183, 18.23069382], [73.04875183, 18.23041725], [73.04902649, 18.23041916], [73.04902649, 18.23014069], [73.04930878, 18.23014069], [73.04930878, 18.2298584], [73.04957581, 18.2298584], [73.04957581, 18.23014069], [73.04985809, 18.23014069], [73.04985809, 18.23041916], [73.05014038, 18.23041725], [73.05014038, 18.23069382], [73.05041504, 18.23069382], [73.05041504, 18.23097229], [73.05069733, 18.23097229], [73.05069733, 18.23125267], [73.05097198, 18.23125267], [73.05097198, 18.23180962], [73.05124664, 18.2318058], [73.05124664, 18.23208046], [73.05180359, 18.23208046], [73.05180359, 18.2318058], [73.05291748, 18.23180962], [73.05291748, 18.23153114], [73.05319214, 18.23153114], [73.05319214, 18.23125267], [73.05374908, 18.23125267], [73.05374908, 18.23096848], [73.05486298, 18.23097229], [73.05486298, 18.23069382], [73.05513763, 18.23069382], [73.05513763, 18.23041725], [73.05625153, 18.23041916], [73.05625153, 18.23014069], [73.05708313, 18.23014069], [73.05708313, 18.2298584], [73.0579071, 18.2298584], [73.0579071, 18.22957993], [73.05847168, 18.22958374], [73.05847168, 18.22930527], [73.05902863, 18.22930908], [73.05902863, 18.22903061], [73.05930328, 18.22903061], [73.05930328, 18.22874832], [73.06014252, 18.22874832], [73.06014252, 18.22846031], [73.06069183, 18.22847176], [73.06069183, 18.22819519], [73.06124878, 18.22820091], [73.06124878, 18.22792053], [73.06181335, 18.22792053], [73.06181335, 18.22763824], [73.06208038, 18.22763824], [73.06208038, 18.22735977], [73.06291962, 18.22736168], [73.06291962, 18.22708321], [73.06375122, 18.22708321], [73.06375122, 18.22680473], [73.06402588, 18.22680473], [73.06402588, 18.22652626], [73.06430817, 18.22653008], [73.06430817, 18.22624969], [73.06458282, 18.22624969], [73.06458282, 18.22597122], [73.06513977, 18.22597313], [73.06513977, 18.22569466], [73.06541443, 18.22569466], [73.06541443, 18.22541618], [73.06571198, 18.22542], [73.06571198, 18.22513962], [73.06625366, 18.22513962], [73.06624603, 18.22458076], [73.06652832, 18.22458267], [73.06652832, 18.2243042], [73.06680298, 18.22430992], [73.06680298, 18.22402954], [73.06735992, 18.22402954], [73.06735992, 18.22347069], [73.06791687, 18.2234726], [73.06791687, 18.22319412], [73.06819153, 18.22319412], [73.06819153, 18.22291756], [73.06845856, 18.22291946], [73.06845856, 18.22236061], [73.06903076, 18.22236061], [73.06903076, 18.22208023], [73.06930542, 18.22208214], [73.06930542, 18.22125053], [73.06958008, 18.22125053], [73.06958008, 18.22097015], [73.06986237, 18.22097206], [73.06986237, 18.21930504], [73.07013702, 18.21931076], [73.07013702, 18.21569061], [73.07041931, 18.21569443], [73.07041931, 18.21097183], [73.07069397, 18.21097183], [73.07069397, 18.20986176], [73.07096863, 18.20986176], [73.07096863, 18.20930481], [73.07069397, 18.20930481], [73.07069397, 18.20819473], [73.07041931, 18.20819473], [73.07041931, 18.20763969], [73.07068634, 18.20763969], [73.07068634, 18.20736122], [73.07041931, 18.20736122], [73.07041931, 18.20681], [73.07013702, 18.20681], [73.07013702, 18.20597267], [73.06986237, 18.20597267], [73.06986237, 18.2056942], [73.06958008, 18.2056942], [73.06958008, 18.20541763], [73.06931305, 18.20541954], [73.06931305, 18.20514107], [73.06874847, 18.20514107], [73.06874847, 18.20486259], [73.06845856, 18.20486259], [73.06845856, 18.20458031], [73.06791687, 18.20458412], [73.06791687, 18.20430565], [73.06764221, 18.20430946], [73.06764221, 18.20402908], [73.0670929, 18.20402908], [73.0670929, 18.20375061], [73.06680298, 18.20375061], [73.06680298, 18.20346832], [73.06625366, 18.20347023], [73.06625366, 18.20319366], [73.06597137, 18.20319366], [73.06597137, 18.2029171], [73.06491852, 18.20292091], [73.06485748, 18.20264053], [73.06430817, 18.20264053], [73.06430817, 18.20235825], [73.06402588, 18.20236206], [73.06402588, 18.20208359], [73.06346893, 18.20208359], [73.06346893, 18.20180511], [73.06291962, 18.20181084], [73.06291962, 18.20152092], [73.06153107, 18.20153046], [73.06153107, 18.20124817], [73.06069183, 18.20124817], [73.06069183, 18.2009697], [73.06014252, 18.2009716], [73.06014252, 18.20069695], [73.05986023, 18.20070076], [73.05986023, 18.20042038], [73.05957794, 18.20042038], [73.05957794, 18.20013809], [73.05930328, 18.20013809], [73.05930328, 18.19985962], [73.05874634, 18.19986153], [73.05874634, 18.19958305], [73.05819702, 18.19958305], [73.05819702, 18.19902611], [73.05764008, 18.19902992], [73.05764008, 18.19819069], [73.05735779, 18.1981945], [73.05735779, 18.19791412], [73.05708313, 18.19791985], [73.05708313, 18.19736099], [73.05680847, 18.19736099], [73.05680847, 18.19680977], [73.05651855, 18.19680977], [73.05651855, 18.19652939], [73.05625153, 18.19652939], [73.05625153, 18.19597054], [73.05596924, 18.19597244], [73.05596924, 18.1954174], [73.05568695, 18.19542122], [73.05568695, 18.19514084], [73.05541992, 18.19514084], [73.05541992, 18.19431114], [73.05513763, 18.19431114], [73.05513763, 18.19403076], [73.05541992, 18.19403076], [73.05541992, 18.19347191], [73.05513763, 18.19347382], [73.05513763, 18.19069481], [73.05541992, 18.19069481], [73.05541992, 18.19014168], [73.05513763, 18.19014168], [73.05513763, 18.18985939], [73.05541992, 18.18985939], [73.05541992, 18.18819427], [73.05569458, 18.18819427], [73.05569458, 18.1870842], [73.05596924, 18.1870842], [73.05596924, 18.18625069], [73.05625153, 18.18625069], [73.05625153, 18.18568993], [73.05652618, 18.18569374], [73.05652618, 18.18541527], [73.05680847, 18.18542099], [73.05680847, 18.18514061], [73.05708313, 18.18514061], [73.05708313, 18.18457985], [73.05764008, 18.18458366], [73.05764008, 18.18402863], [73.0579071, 18.18403053], [73.0579071, 18.18348122], [73.05847168, 18.18348122], [73.05847168, 18.18292046], [73.05874634, 18.18292046], [73.05874634, 18.18264008], [73.05930328, 18.18264008], [73.05930328, 18.1823597], [73.05958557, 18.1823616], [73.05958557, 18.18208313], [73.05986023, 18.18208313], [73.05986023, 18.18180466], [73.06014252, 18.18180466], [73.06014252, 18.18152809], [73.06069183, 18.18153], [73.06069183, 18.18097115], [73.06124878, 18.18097305], [73.06124878, 18.18041611], [73.06153107, 18.18041611], [73.06153107, 18.18013954], [73.06181335, 18.18013954], [73.06180573, 18.17986107], [73.06208038, 18.17986107], [73.06208038, 18.17930984], [73.06236267, 18.17930984], [73.06236267, 18.17902946], [73.06291962, 18.17902946], [73.06291962, 18.1787529], [73.06346893, 18.1787529], [73.06346893, 18.17847252], [73.06387329, 18.17847252], [73.06402588, 18.17847252], [73.06402588, 18.17819405], [73.06458282, 18.17819405], [73.06458282, 18.17748833], [73.06458282, 18.17735863], [73.06485748, 18.17735863], [73.06485748, 18.17708397], [73.06513977, 18.17708397], [73.06513977, 18.1768055], [73.06571198, 18.17680931], [73.06571198, 18.17653084], [73.06597137, 18.17653084], [73.06597137, 18.17624855], [73.06652832, 18.17624855], [73.06652832, 18.17596817], [73.06708527, 18.17597008], [73.06708527, 18.17569351], [73.06735992, 18.17569351], [73.06735992, 18.17541885], [73.06764221, 18.17542076], [73.06764221, 18.17514038], [73.06819153, 18.17514038], [73.06819153, 18.17485809], [73.06847382, 18.17486191], [73.06847382, 18.17458344], [73.06874847, 18.17458344], [73.06874847, 18.17430496], [73.06903076, 18.17430496], [73.06903076, 18.17458344], [73.06958008, 18.17458344], [73.06958008, 18.17430496], [73.06986237, 18.17431068], [73.06986237, 18.1740303], [73.07013702, 18.1740303], [73.07013702, 18.17346954], [73.07041931, 18.17347145], [73.07041931, 18.17291641], [73.07096863, 18.17292023], [73.07096863, 18.17235947], [73.07152557, 18.17236137], [73.07152557, 18.17152786], [73.07180786, 18.17154121], [73.07180786, 18.17069054], [73.07208252, 18.17069435], [73.07208252, 18.17041588], [73.07180786, 18.17041969], [73.07180786, 18.17014122], [73.07125092, 18.17014122], [73.07125092, 18.16958046], [73.07096863, 18.16958427], [73.07096863, 18.1693058], [73.07068634, 18.16930962], [73.07068634, 18.16903114], [73.07041931, 18.16903114], [73.07041931, 18.16847038], [73.07013702, 18.16847229], [73.07013702, 18.16819382], [73.06986237, 18.16819382], [73.06986237, 18.16763878], [73.06958008, 18.16764069], [73.06958008, 18.16708183], [73.06930542, 18.16708374], [73.06930542, 18.16680527], [73.06903076, 18.1668129], [73.06903076, 18.16570282], [73.06874847, 18.16570282], [73.06874847, 18.16540909], [73.06903076, 18.16541672], [73.06903076, 18.16513824], [73.06930542, 18.16513824], [73.06930542, 18.16597366], [73.06958008, 18.16597176], [73.06958008, 18.16625023], [73.06986237, 18.16625023], [73.06986237, 18.1668129], [73.07013702, 18.16680527], [73.07013702, 18.16708374], [73.07041931, 18.16708183], [73.07041931, 18.16736031], [73.07068634, 18.16736031], [73.07068634, 18.16792107], [73.07096863, 18.16791725], [73.07096863, 18.16819382], [73.07125092, 18.16819382], [73.07125092, 18.16847229], [73.07138824, 18.16847038], [73.07151794, 18.16847038], [73.07151794, 18.16903114], [73.07180786, 18.16902733], [73.07180786, 18.16958237], [73.07208252, 18.16958046], [73.07208252, 18.16986084], [73.07319641, 18.16986084], [73.07319641, 18.16958046], [73.07347107, 18.16958237], [73.07347107, 18.1693058], [73.07375336, 18.16930962], [73.07375336, 18.16875076], [73.07402802, 18.16875076], [73.07402802, 18.16818047], [73.07430267, 18.16819382], [73.07430267, 18.16763878], [73.07485962, 18.16764069], [73.07485962, 18.16708183], [73.07514191, 18.16708374], [73.07514191, 18.16680527], [73.07541656, 18.1668129], [73.07541656, 18.16597176], [73.07569122, 18.16597366], [73.07569122, 18.16569519], [73.07596588, 18.16570282], [73.07596588, 18.16540909], [73.07653046, 18.16541672], [73.07653046, 18.16513824], [73.07681274, 18.16514015], [73.07681274, 18.16486168], [73.07707977, 18.16486168], [73.07707977, 18.1637516], [73.07680511, 18.1637516], [73.07680511, 18.16263771], [73.07653046, 18.16263771], [73.07653046, 18.16180992], [73.07624817, 18.16180992], [73.07624817, 18.16097069], [73.07597351, 18.1609726], [73.07597351, 18.1608696], [73.07597351, 18.16069412], [73.07569122, 18.16069412], [73.07569122, 18.16041946], [73.07541656, 18.16041946], [73.07541656, 18.16014099], [73.07514191, 18.16014099], [73.07514191, 18.15986061], [73.07485962, 18.15986061], [73.07485962, 18.15958023], [73.07458496, 18.15958405], [73.07458496, 18.15930557], [73.07402802, 18.15930939], [73.07402802, 18.15903091], [73.07375336, 18.15903091], [73.07375336, 18.15847015], [73.07347107, 18.15847206], [73.07347107, 18.15763855], [73.07319641, 18.15764046], [73.07319641, 18.15736008], [73.07291412, 18.15736198], [73.07291412, 18.15680313], [73.07263947, 18.15681076], [73.07263947, 18.15653038], [73.07319641, 18.15653038], [73.07319641, 18.15681076], [73.07347107, 18.15680313], [73.07347107, 18.15708351], [73.07375336, 18.15708351], [73.07375336, 18.15736198], [73.07402802, 18.15736008], [73.07402802, 18.15764046], [73.07430267, 18.15764046], [73.07430267, 18.15792084], [73.07458496, 18.15791512], [73.07458496, 18.15847206], [73.07485962, 18.15847015], [73.07485962, 18.15903091], [73.07514191, 18.15903091], [73.07514191, 18.15930939], [73.07541656, 18.15930557], [73.07541656, 18.15958405], [73.07596588, 18.15958023], [73.07596588, 18.15986061], [73.07656097, 18.15986061], [73.07707977, 18.15986061], [73.07707977, 18.16014099], [73.07736206, 18.16013718], [73.07736206, 18.16069412], [73.07765198, 18.16069031], [73.07765198, 18.16152954], [73.07791901, 18.16152954], [73.07791901, 18.16208267], [73.07818604, 18.16208076], [73.07818604, 18.16237068], [73.07930756, 18.16237068], [73.07930756, 18.16208076], [73.0798645, 18.16208267], [73.0798645, 18.16180611], [73.08039856, 18.16180992], [73.08039856, 18.16152954], [73.08068848, 18.16152954], [73.08068848, 18.16069031], [73.08097076, 18.16069412], [73.08097076, 18.15986061], [73.08125305, 18.15986061], [73.08125305, 18.15903091], [73.08152771, 18.15903091], [73.08152771, 18.15818977], [73.08125305, 18.15819359], [73.08125305, 18.15652847], [73.08152771, 18.15653038], [73.08152771, 18.15624046], [73.08180237, 18.15624046], [73.08180237, 18.15653038], [73.08208466, 18.15652847], [73.08208466, 18.15736198], [73.08235931, 18.15736008], [73.08235931, 18.15764046], [73.08319092, 18.15764046], [73.08319092, 18.15792084], [73.08403015, 18.15792084], [73.08403015, 18.15736008], [73.08430481, 18.15736198], [73.08430481, 18.15680313], [73.08513641, 18.15681076], [73.08513641, 18.15653038], [73.0854187, 18.15653038], [73.0854187, 18.15596962], [73.08569336, 18.15597153], [73.08569336, 18.15541649], [73.08598328, 18.1554203], [73.08598328, 18.15485954], [73.08625031, 18.15486145], [73.08625031, 18.15402794], [73.08653259, 18.15402985], [73.08653259, 18.15263939], [73.08625031, 18.15263939], [73.08625031, 18.15134048], [73.08625031, 18.15069389], [73.08652496, 18.15069389], [73.08652496, 18.15041733], [73.08708191, 18.15041733], [73.08708191, 18.15069389], [73.0873642, 18.15069389], [73.0873642, 18.15082932], [73.0873642, 18.15097237], [73.08763885, 18.15096855], [73.08763885, 18.15125275], [73.08790588, 18.15125275], [73.08790588, 18.15153122], [73.0881958, 18.1515274], [73.0881958, 18.15208244], [73.08790588, 18.15208244], [73.08790588, 18.1554203], [73.08763885, 18.1554203], [73.08763885, 18.15570068], [73.0873642, 18.15569305], [73.0873642, 18.15625], [73.08708191, 18.15625], [73.08708191, 18.15708351], [73.08682251, 18.1570797], [73.08682251, 18.15764046], [73.08708191, 18.15764046], [73.08708191, 18.15792084], [73.0873642, 18.15791512], [73.0873642, 18.15819359], [73.08708191, 18.15819359], [73.08708191, 18.15847206], [73.08625031, 18.15847015], [73.08625031, 18.15875053], [73.08569336, 18.15875053], [73.08569336, 18.15903091], [73.0854187, 18.15903091], [73.0854187, 18.15930939], [73.08513641, 18.15930557], [73.08513641, 18.15958405], [73.08486176, 18.15958023], [73.08486176, 18.15986061], [73.08429718, 18.15986061], [73.08429718, 18.16041946], [73.08403015, 18.16041946], [73.08403015, 18.16125107], [73.08374786, 18.16125107], [73.08374786, 18.16180992], [73.08430481, 18.16180611], [73.08430481, 18.16208267], [73.08486176, 18.16208076], [73.08486176, 18.16237068], [73.08513641, 18.16237068], [73.08513641, 18.16263771], [73.08625031, 18.16263771], [73.08625031, 18.16292191], [73.08680725, 18.16291618], [73.08680725, 18.16319466], [73.08708191, 18.16319466], [73.08708191, 18.16347313], [73.08763885, 18.16346931], [73.08763885, 18.1637516], [73.0881958, 18.1637516], [73.0881958, 18.16403008], [73.0890274, 18.16402817], [73.0890274, 18.16430473], [73.08930206, 18.16430473], [73.08930206, 18.16347313], [73.08958435, 18.16347313], [73.08958435, 18.16319466], [73.08985901, 18.16319466], [73.08985901, 18.16291618], [73.0901413, 18.16292191], [73.0901413, 18.16263771], [73.09041595, 18.16263771], [73.09041595, 18.16237068], [73.09124756, 18.16237068], [73.09124756, 18.16208076], [73.09179688, 18.16208076], [73.09179688, 18.16237068], [73.09208679, 18.16237068], [73.09208679, 18.16263771], [73.09236145, 18.16263771], [73.09236145, 18.16292191], [73.09263611, 18.16291618], [73.09263611, 18.16319466], [73.09236145, 18.16319466], [73.09236145, 18.16347313], [73.09208679, 18.16346931], [73.09208679, 18.16403008], [73.0918045, 18.16402817], [73.0918045, 18.16430473], [73.09152985, 18.16430473], [73.09152985, 18.16486168], [73.09124756, 18.16486168], [73.09124756, 18.16514015], [73.09069824, 18.16513824], [73.09069824, 18.16541672], [73.09041595, 18.16541672], [73.09041595, 18.16513824], [73.0901413, 18.16513824], [73.0901413, 18.16541672], [73.08985901, 18.16540909], [73.08985901, 18.16570282], [73.08958435, 18.16569519], [73.08958435, 18.16708374], [73.08985901, 18.16708183], [73.08985901, 18.16736031], [73.0901413, 18.16736031], [73.0901413, 18.16764069], [73.09069061, 18.16764069], [73.09069824, 18.16736031], [73.09124756, 18.16736031], [73.09124756, 18.16764069], [73.09152985, 18.16764069], [73.09152985, 18.16792107], [73.09124756, 18.16791725], [73.09124756, 18.16819382], [73.0909729, 18.16819382], [73.0909729, 18.16847229], [73.09069824, 18.16847038], [73.09069824, 18.16903114], [73.09041595, 18.16903114], [73.09041595, 18.16930962], [73.08985901, 18.1693058], [73.08985901, 18.16958427], [73.08958435, 18.16958427], [73.08959198, 18.16986084], [73.08875275, 18.16986084], [73.08875275, 18.17014122], [73.0881958, 18.17014122], [73.0881958, 18.17041969], [73.08791351, 18.17041588], [73.08791351, 18.17069435], [73.08763885, 18.17069435], [73.08763885, 18.17097282], [73.0873642, 18.17097282], [73.0873642, 18.17069435], [73.08708191, 18.17069435], [73.08708191, 18.17013931], [73.08682251, 18.17014122], [73.08682251, 18.16986084], [73.08597565, 18.16986084], [73.08597565, 18.16958427], [73.08569336, 18.16958046], [73.08569336, 18.16986084], [73.0854187, 18.16986084], [73.0854187, 18.16958046], [73.08513641, 18.16958046], [73.08513641, 18.16986084], [73.08403015, 18.16986084], [73.08403015, 18.17014122], [73.08374786, 18.17014122], [73.08374786, 18.16986084], [73.08319092, 18.16986084], [73.08319092, 18.17014122], [73.08291626, 18.17014122], [73.08291626, 18.17041969], [73.0826416, 18.17041588], [73.0826416, 18.17069435], [73.08235931, 18.17069435], [73.08235931, 18.17097282], [73.08207703, 18.17097092], [73.08207703, 18.17124939], [73.08180237, 18.17124939], [73.08180237, 18.17154121], [73.08125305, 18.17152786], [73.08125305, 18.1720829], [73.08097076, 18.17208099], [73.08097076, 18.17292023], [73.08068848, 18.17292023], [73.08068848, 18.1740303], [73.08097076, 18.1740303], [73.08097076, 18.17431068], [73.08069611, 18.17430496], [73.08069611, 18.17597008], [73.08039856, 18.17596817], [73.08039856, 18.17680931], [73.08013916, 18.1768055], [73.08013916, 18.17708397], [73.07985687, 18.17707825], [73.07985687, 18.17764282], [73.08013916, 18.17764282], [73.08013916, 18.17791939], [73.08041382, 18.17791748], [73.08041382, 18.17819405], [73.08068848, 18.17819023], [73.08068848, 18.17902946], [73.08039856, 18.17902946], [73.08039856, 18.17930984], [73.08013916, 18.17930984], [73.08013916, 18.17902946], [73.07985687, 18.17902946], [73.07985687, 18.1787529], [73.07624817, 18.1787529], [73.07624817, 18.17902946], [73.07596588, 18.17902946], [73.07596588, 18.17986107], [73.07569122, 18.17986107], [73.07569122, 18.18069458], [73.07541656, 18.18069458], [73.07541656, 18.18097305], [73.07514191, 18.18097305], [73.07514191, 18.18069458], [73.07485962, 18.18069458], [73.07485962, 18.17986107], [73.07375336, 18.17986107], [73.07375336, 18.18013954], [73.07347107, 18.18013954], [73.07347107, 18.18041611], [73.07236481, 18.18041611], [73.07236481, 18.18069458], [73.07180786, 18.18069458], [73.07180786, 18.18097305], [73.07151794, 18.18097115], [73.07151794, 18.18124962], [73.07096863, 18.18124962], [73.07096863, 18.18153], [73.07041931, 18.18152809], [73.07041931, 18.18180466], [73.06986237, 18.18180466], [73.06986237, 18.18208313], [73.06958008, 18.18208313], [73.06958008, 18.1823616], [73.06903076, 18.1823597], [73.06903076, 18.18264008], [73.06874847, 18.18264008], [73.06874847, 18.18292046], [73.06819153, 18.18292046], [73.06819153, 18.18320084], [73.06764221, 18.18320084], [73.06764221, 18.18348122], [73.06708527, 18.18347168], [73.0670929, 18.18375015], [73.06680298, 18.18375015], [73.06680298, 18.18431091], [73.06652832, 18.18430519], [73.06652832, 18.18458366], [73.06597137, 18.18457985], [73.06597137, 18.18486023], [73.06571198, 18.18486023], [73.06571198, 18.18514061], [73.06513977, 18.18514061], [73.06513977, 18.18542099], [73.06458282, 18.18541527], [73.06458282, 18.18569374], [73.06430817, 18.18569374], [73.06430817, 18.18597221], [73.06402588, 18.18597031], [73.06402588, 18.18625069], [73.06346893, 18.18625069], [73.06346893, 18.18680954], [73.06319427, 18.18680573], [73.06319427, 18.1870842], [73.06291962, 18.18708038], [73.06291962, 18.18736076], [73.06265259, 18.18736076], [73.06265259, 18.18764114], [73.06236267, 18.18764114], [73.06236267, 18.18791962], [73.06208038, 18.1879158], [73.06208038, 18.18819427], [73.06180573, 18.18819427], [73.06180573, 18.18847275], [73.06153107, 18.18847084], [73.06153107, 18.18875122], [73.06124878, 18.18875122], [73.06124878, 18.18902969], [73.06096649, 18.18902969], [73.06096649, 18.18930817], [73.06069183, 18.18930626], [73.06069183, 18.18958282], [73.06041718, 18.18958092], [73.06041718, 18.19014168], [73.06014252, 18.19014168], [73.06014252, 18.19042015], [73.05986023, 18.19041634], [73.05986023, 18.19069481], [73.05958557, 18.19069481], [73.05958557, 18.19347382], [73.05986023, 18.19347191], [73.05986023, 18.19375038], [73.06014252, 18.19375038], [73.06014252, 18.19486046], [73.06041718, 18.19486046], [73.06041718, 18.19514084], [73.06069183, 18.19513893], [73.06069183, 18.19569588], [73.06124878, 18.19569588], [73.06124878, 18.19597244], [73.06153107, 18.19597054], [73.06153107, 18.19625092], [73.06181335, 18.19625092], [73.06181335, 18.19652939], [73.06265259, 18.19652939], [73.06265259, 18.19680977], [73.06291962, 18.19680405], [73.06291962, 18.19708252], [73.06346893, 18.19708061], [73.06346893, 18.19736099], [73.06402588, 18.19736099], [73.06402588, 18.19763947], [73.06485748, 18.19763947], [73.06485748, 18.19791985], [73.06513977, 18.19791985], [73.06513977, 18.19763947], [73.06533051, 18.19763947], [73.06597137, 18.19763947], [73.06597137, 18.19791985], [73.06791687, 18.19791985], [73.06791687, 18.19763947], [73.06845856, 18.19763947], [73.06845856, 18.19736099], [73.06903076, 18.19736099], [73.06903076, 18.19708061], [73.06958008, 18.19708061], [73.06958008, 18.19736099], [73.07068634, 18.19736099], [73.07068634, 18.19763947], [73.07180786, 18.19763947], [73.07180786, 18.19791985], [73.07208252, 18.19791412], [73.07208252, 18.1981945], [73.07263947, 18.19819069], [73.07263947, 18.19848061], [73.07319641, 18.19848061], [73.07319641, 18.19874954], [73.07375336, 18.19874954], [73.07375336, 18.19902992], [73.07458496, 18.19902611], [73.07459259, 18.19930077], [73.07514191, 18.1993084], [73.07514191, 18.19986153], [73.07549286, 18.19985962], [73.07569122, 18.19985962], [73.07569122, 18.20070076], [73.07596588, 18.20070076], [73.07596588, 18.20181084], [73.07624817, 18.20181084], [73.07624817, 18.20235825], [73.07653046, 18.20235825], [73.07653046, 18.20402908], [73.07624817, 18.20402908], [73.07624817, 18.20430946], [73.07653046, 18.20430565], [73.07653046, 18.20458412], [73.07624817, 18.20458031], [73.07624817, 18.20763969], [73.07653046, 18.20763969], [73.07653046, 18.20874977], [73.07680511, 18.20874977], [73.07680511, 18.20930481], [73.07707977, 18.2093029], [73.07707977, 18.21014023], [73.07736206, 18.21014023], [73.07736206, 18.21071053], [73.07791901, 18.21071053], [73.07791901, 18.21153069], [73.07819366, 18.21152687], [73.07819366, 18.21208382], [73.07847595, 18.21208], [73.07847595, 18.21264076], [73.07875061, 18.21263885], [73.07875061, 18.21319389], [73.07902527, 18.21319389], [73.07902527, 18.21375084], [73.07930756, 18.21375084], [73.07930756, 18.21403122], [73.07958221, 18.2140274], [73.07958221, 18.21458244], [73.07985687, 18.21458054], [73.07985687, 18.21513748], [73.08013916, 18.21513748], [73.08013916, 18.21541977], [73.08069611, 18.21541595], [73.08069611, 18.21569443], [73.08097076, 18.21569061], [73.08097076, 18.21624756], [73.08069611, 18.21624756], [73.08069611, 18.21652985], [73.08039856, 18.21652031], [73.08039856, 18.21681023], [73.08013916, 18.21681023], [73.08013916, 18.2179203], [73.08039856, 18.2179203], [73.08039856, 18.21820259], [73.08068848, 18.21820259], [73.08068848, 18.22153091], [73.08039856, 18.22153091], [73.08039856, 18.22180939], [73.08013916, 18.22180939], [73.08013916, 18.22236061], [73.07985687, 18.22236061], [73.07985687, 18.22265053], [73.07930756, 18.22265053], [73.07930756, 18.22291946], [73.07902527, 18.22291756], [73.07902527, 18.22319412], [73.07875061, 18.22319031], [73.07875061, 18.22375107], [73.07847595, 18.22375107], [73.07847595, 18.22513962], [73.07875061, 18.22513962], [73.07875061, 18.22597313], [73.07958221, 18.22597122], [73.07958221, 18.22624969], [73.08039856, 18.22624969], [73.08039856, 18.22653008], [73.08069611, 18.22652626], [73.08069611, 18.22708321], [73.08041382, 18.22708321], [73.08041382, 18.22736168], [73.07985687, 18.22735977], [73.07985687, 18.22763824], [73.08013916, 18.22763634], [73.08013916, 18.22847176], [73.08041382, 18.22847176], [73.08041382, 18.22958374], [73.08068848, 18.22957993], [73.08068848, 18.23014069], [73.08039856, 18.23014069], [73.08039856, 18.23125267], [73.08013916, 18.23125267], [73.08013916, 18.23153114], [73.07985687, 18.23153114], [73.07985687, 18.23180962], [73.07958221, 18.2318058], [73.07958221, 18.23208427], [73.07875061, 18.23208046], [73.07875061, 18.23236275], [73.07818604, 18.23236275], [73.07818604, 18.23374939], [73.07847595, 18.23374939], [73.07847595, 18.23569489], [73.07819366, 18.23569489], [73.07819366, 18.23597145], [73.07791901, 18.23596954], [73.07791901, 18.23624992], [73.07736206, 18.23624992], [73.07736206, 18.23596954], [73.07707977, 18.23597145], [73.07707977, 18.23569489], [73.07653046, 18.23569489], [73.07653046, 18.23597145], [73.07624817, 18.23596954], [73.07624817, 18.23875046], [73.07596588, 18.23875046], [73.07596588, 18.23903084], [73.07485962, 18.23903084], [73.07485962, 18.23931122], [73.07375336, 18.2393055], [73.07375336, 18.23958397], [73.07290649, 18.23958015], [73.07290649, 18.23986053], [73.07180786, 18.23986053], [73.07180786, 18.24014091], [73.07152557, 18.2401371], [73.07152557, 18.24069405], [73.07125092, 18.24069405], [73.07125092, 18.24097252], [73.07041931, 18.24097061], [73.07041931, 18.24124908], [73.06986237, 18.24124908], [73.06986237, 18.24152756], [73.06958008, 18.24152756], [73.06958008, 18.24180984], [73.06903076, 18.24180794], [73.06903076, 18.2420826], [73.06845856, 18.24208069], [73.06845856, 18.24263763], [73.06819153, 18.24263763], [73.06819153, 18.24319458], [73.06791687, 18.24319077], [73.06791687, 18.24403191], [73.06764221, 18.24402809], [73.06764221, 18.24458313], [73.06735992, 18.24458313], [73.06735992, 18.2448616], [73.0670929, 18.2448616], [73.0670929, 18.24542046], [73.06652832, 18.24542046], [73.06652832, 18.24570274], [73.06624603, 18.24570274], [73.06625366, 18.24625015], [73.06571198, 18.24625015], [73.06571198, 18.24682045], [73.06541443, 18.24680519], [73.06541443, 18.24708366], [73.06485748, 18.24707985], [73.06485748, 18.24792099], [73.06458282, 18.24791718], [73.06458282, 18.24819374], [73.06402588, 18.24819374], [73.06402588, 18.24847221], [73.06346893, 18.24847031], [73.06346893, 18.24903107], [73.06318665, 18.24903107], [73.06318665, 18.24930954], [73.06291962, 18.24930954], [73.06291962, 18.24958992], [73.06263733, 18.2495842], [73.06265259, 18.24986076], [73.06208038, 18.24986076], [73.06208038, 18.25041962], [73.06180573, 18.2504158], [73.06180573, 18.25097275], [73.06153107, 18.25097275], [73.06153107, 18.2523613], [73.06124878, 18.2523613], [73.06124878, 18.25263977], [73.06153107, 18.25263977], [73.06153107, 18.25430489], [73.06181335, 18.25430107], [73.06181335, 18.25680923], [73.06208038, 18.25680542], [73.06208038, 18.25708389], [73.06236267, 18.25707817], [73.06236267, 18.25735855], [73.06208038, 18.25735855], [73.06208038, 18.25764084], [73.06236267, 18.25764084], [73.06236267, 18.25819397], [73.06263733, 18.25819397], [73.06263733, 18.25847244], [73.06291962, 18.25847244], [73.06291962, 18.25876045], [73.06318665, 18.25876045], [73.06318665, 18.25902939], [73.06346893, 18.25902939], [73.06346893, 18.25930977], [73.06375122, 18.25930977], [73.06375122, 18.2598629], [73.06402588, 18.2598629], [73.06402588, 18.26013947], [73.06458282, 18.26013947], [73.06458282, 18.2606945], [73.06485748, 18.2606945], [73.06485748, 18.26097488], [73.06541443, 18.26097488], [73.06541443, 18.26124954], [73.06569672, 18.26124954], [73.06571198, 18.26180077], [73.06652832, 18.26180649], [73.06652832, 18.26208305], [73.06680298, 18.26208305], [73.06680298, 18.26236153], [73.06735992, 18.26235962], [73.06735992, 18.26292038], [73.06764221, 18.26292038], [73.06764221, 18.26320076], [73.06791687, 18.26320076], [73.06791687, 18.26403046], [73.06819153, 18.26403046], [73.06819153, 18.26431084], [73.06845856, 18.26431084], [73.06845856, 18.26514053], [73.06874847, 18.26514053], [73.06874847, 18.26542091], [73.06903076, 18.26542091], [73.06903076, 18.26680946], [73.06874847, 18.26680946], [73.06874847, 18.26791954], [73.06845856, 18.26791954], [73.06845856, 18.26902962], [73.06819153, 18.26902962], [73.06819153, 18.26930809], [73.06791687, 18.26930809], [73.06791687, 18.2701416], [73.06764221, 18.2701416], [73.06764221, 18.27042007], [73.06735992, 18.27041626], [73.06735992, 18.27096939], [73.0670929, 18.27096939], [73.0670929, 18.27153015], [73.06680298, 18.27152824], [73.06680298, 18.27180481], [73.06652832, 18.27180481], [73.06652832, 18.27208328], [73.06625366, 18.27208328], [73.06625366, 18.27236176], [73.06597137, 18.27236176], [73.06597137, 18.27264023], [73.06571198, 18.27264023], [73.06571198, 18.2732029], [73.06541443, 18.27319527], [73.06541443, 18.27347374], [73.06513977, 18.27347183], [73.06513977, 18.27431107], [73.06485748, 18.27430534], [73.06485748, 18.27458382], [73.06458282, 18.27458191], [73.06458282, 18.27486038], [73.06430817, 18.27486038], [73.06430817, 18.27514076], [73.06402588, 18.27514076], [73.06402588, 18.27542114], [73.06375122, 18.27541733], [73.06375122, 18.2756958], [73.06346893, 18.2756958], [73.06346893, 18.27597237], [73.06318665, 18.27597046], [73.06318665, 18.27653122], [73.06291962, 18.27653122], [73.06291962, 18.27763939], [73.06319427, 18.27763939], [73.06319427, 18.27819443], [73.06291962, 18.27819443], [73.06291962, 18.2784729], [73.06263733, 18.2784729], [73.06263733, 18.27819443], [73.06208038, 18.27819443], [73.06208038, 18.27791405], [73.06180573, 18.27791405], [73.06180573, 18.27819443], [73.06124878, 18.27819443], [73.06124878, 18.27791405], [73.05986023, 18.27791405], [73.05986023, 18.27819443], [73.05874634, 18.27819443], [73.05874634, 18.2784729], [73.05847168, 18.27847099], [73.05847168, 18.27874947], [73.0579071, 18.27874947], [73.0579071, 18.27902985], [73.05735779, 18.27902985], [73.05735779, 18.27931023], [73.05680847, 18.27930641], [73.05680847, 18.27958298], [73.05562592, 18.27957153], [73.05541992, 18.27956963], [73.05545044, 18.27988052], [73.05264282, 18.27985954], [73.05264282, 18.2804203], [73.05291748, 18.28041649], [73.05291748, 18.28097153], [73.05263519, 18.28097153], [73.05264282, 18.28124809], [73.05236053, 18.28124809], [73.05236053, 18.28153038], [73.05208588, 18.28153038], [73.05208588, 18.28181076], [73.05180359, 18.28180504], [73.05180359, 18.28208351], [73.05152893, 18.2820797], [73.05152893, 18.28293037], [73.05124664, 18.28291893], [73.05124664, 18.28319359], [73.05097198, 18.28318977], [73.05097198, 18.28374863], [73.05042267, 18.28374863], [73.05042267, 18.28430939], [73.05014038, 18.28430557], [73.05014038, 18.28458405], [73.04985809, 18.28458405], [73.04985809, 18.28490067], [73.04985809, 18.28569984], [73.04958344, 18.28569412], [73.04958344, 18.2859726], [73.04930878, 18.2859726], [73.04930878, 18.28680992], [73.04902649, 18.28680992], [73.04902649, 18.28792], [73.04875183, 18.28792], [73.04875183, 18.28903008], [73.04846954, 18.28902817], [73.04846954, 18.28930473], [73.04819489, 18.28930473], [73.04819489, 18.28958321], [73.04792023, 18.28957939], [73.04792023, 18.29042053], [73.04763794, 18.29041672], [73.04763794, 18.29097176], [73.04736328, 18.29096985], [73.04736328, 18.29153061], [73.04708099, 18.2915287], [73.04708099, 18.29180527], [73.04680634, 18.29179955], [73.04680634, 18.29264069], [73.04652405, 18.29263878], [73.04652405, 18.29319382], [73.04624939, 18.29319], [73.04624939, 18.29375076], [73.0459671, 18.29375076], [73.0459671, 18.29403114], [73.04569244, 18.29403114], [73.04569244, 18.29486847], [73.04541779, 18.29486847], [73.04541779, 18.29514122], [73.0451355, 18.29513741], [73.0451355, 18.29569435], [73.04458618, 18.29569435], [73.04458618, 18.29597282], [73.04402924, 18.29597092], [73.04402924, 18.29624748], [73.04337311, 18.29624748], [73.04319763, 18.29624748], [73.04319763, 18.2970829], [73.04292297, 18.29707909], [73.04292297, 18.2990303], [73.04319763, 18.2990284], [73.04319763, 18.29986382], [73.04347229, 18.29986191], [73.04347229, 18.30042076], [73.04402924, 18.30042076], [73.04402924, 18.30125046], [73.04428864, 18.30125046], [73.04428864, 18.30181122], [73.04486084, 18.3018055], [73.04486084, 18.30208206], [73.0451355, 18.30208206], [73.0451355, 18.30236053], [73.04569244, 18.30236053], [73.04569244, 18.30264091], [73.04624939, 18.30264091], [73.04624939, 18.30291939], [73.04708099, 18.30291748], [73.04708099, 18.30319595], [73.04819489, 18.30319595], [73.04819489, 18.30374908], [73.05124664, 18.30374908], [73.05124664, 18.30347252], [73.05208588, 18.30347252], [73.05208588, 18.30319595], [73.05263519, 18.30319595], [73.05263519, 18.30291748], [73.05301666, 18.30291748], [73.05319214, 18.30291939], [73.05319214, 18.30264091], [73.05374908, 18.30264091], [73.05374908, 18.30236053], [73.05403137, 18.30236053], [73.05403137, 18.30208015], [73.05486298, 18.30208206], [73.05486298, 18.3018055], [73.05513763, 18.30181122], [73.05513763, 18.30153084], [73.05541992, 18.30153084], [73.05541992, 18.30125046], [73.05568695, 18.30125046], [73.05568695, 18.30097008], [73.05596924, 18.30097389], [73.05596924, 18.30069351], [73.05625153, 18.30069351], [73.05625153, 18.30041695], [73.05708313, 18.30042076], [73.05708313, 18.30014038], [73.06069183, 18.30014038], [73.06069183, 18.29986191], [73.06180573, 18.29986382], [73.06180573, 18.29958344], [73.06319427, 18.29958344], [73.06319427, 18.29930496], [73.06513977, 18.29931068], [73.06513977, 18.2990303], [73.06597137, 18.2990303], [73.06597137, 18.29931068], [73.06625366, 18.29930496], [73.06625366, 18.29958344], [73.06791687, 18.29958344], [73.06791687, 18.29930496], [73.06874847, 18.29931068], [73.06874847, 18.2990303], [73.07013702, 18.2990303], [73.07013702, 18.29931068], [73.07041931, 18.29931068], [73.07041931, 18.2990303], [73.07208252, 18.2990303], [73.07208252, 18.29875183], [73.07290649, 18.29875183], [73.07290649, 18.29846954], [73.07680511, 18.29846954], [73.07680511, 18.29819489], [73.07653046, 18.29819489], [73.07653046, 18.29624748], [73.07681274, 18.29624748], [73.07680511, 18.29597282], [73.07707977, 18.29597282], [73.07707977, 18.29569435], [73.07736206, 18.29569435], [73.07736206, 18.29541588], [73.07958221, 18.29541969], [73.07958221, 18.29514122], [73.08152771, 18.29514122], [73.08152771, 18.29486847], [73.08180237, 18.29486847], [73.08180237, 18.29458046], [73.08208466, 18.29458237], [73.08208466, 18.29402733], [73.08235931, 18.29403114], [73.08235931, 18.29375076], [73.0826416, 18.29375076], [73.0826416, 18.29347038], [73.08291626, 18.29347229], [73.08291626, 18.29291534], [73.08319092, 18.29292107], [73.08319092, 18.29207993], [73.08347321, 18.29208374], [73.08347321, 18.2915287], [73.08374786, 18.29153061], [73.08374786, 18.29096985], [73.08403015, 18.29097176], [73.08403015, 18.29041672], [73.08429718, 18.29042053], [73.08429718, 18.29022026], [73.08430481, 18.28958321], [73.0845871, 18.28958321], [73.0845871, 18.28930473], [73.08486176, 18.28930473], [73.08486176, 18.28874969], [73.08513641, 18.28874969], [73.08513641, 18.28847313], [73.0854187, 18.28847313], [73.0854187, 18.28819466], [73.08597565, 18.28819466], [73.08597565, 18.28791618], [73.08625031, 18.28791618], [73.08625031, 18.28819466], [73.08652496, 18.28819466], [73.08652496, 18.28847313], [73.08625031, 18.28847313], [73.08625031, 18.28874969], [73.08598328, 18.28874016], [73.08598328, 18.28903008], [73.08569336, 18.28902817], [73.08569336, 18.28930473], [73.0854187, 18.28930473], [73.0854187, 18.28958321], [73.08513641, 18.28958321], [73.08513641, 18.28982925], [73.08513641, 18.29042053], [73.08486176, 18.29041672], [73.08486176, 18.29097176], [73.0845871, 18.29096985], [73.0845871, 18.29153061], [73.08430481, 18.2915287], [73.08430481, 18.29208374], [73.08403015, 18.29207993], [73.08403015, 18.29292107], [73.08374786, 18.29291534], [73.08374786, 18.29347229], [73.08345795, 18.29347038], [73.08345795, 18.29403114], [73.08319092, 18.29403114], [73.08319092, 18.29430962], [73.08291626, 18.29430962], [73.08291626, 18.29486847], [73.0826416, 18.29486084], [73.0826416, 18.29569435], [73.08235931, 18.29569435], [73.08235931, 18.29597282], [73.08207703, 18.29597092], [73.08207703, 18.29624748], [73.08097076, 18.29624748], [73.08097076, 18.29653168], [73.07847595, 18.29653168], [73.07847595, 18.29681015], [73.07819366, 18.29680634], [73.07819366, 18.2970829], [73.07791901, 18.2970829], [73.07791901, 18.29735947], [73.07763672, 18.29735947], [73.07763672, 18.29846954], [73.07791901, 18.29846954], [73.07791901, 18.29875183], [73.07818604, 18.29875183], [73.07818604, 18.2990303], [73.07847595, 18.2990284], [73.07847595, 18.29958344], [73.07875061, 18.29957962], [73.07875061, 18.30014038], [73.0790329, 18.30014038], [73.0790329, 18.30042076], [73.0798645, 18.30041695], [73.0798645, 18.30069351], [73.08041382, 18.30069351], [73.08041382, 18.30097389], [73.08235931, 18.30097008], [73.08235931, 18.30125046], [73.0826416, 18.30125046], [73.0826416, 18.30381012], [73.0826416, 18.30486107], [73.08291626, 18.30486107], [73.08291626, 18.30513954], [73.0826416, 18.30513954], [73.0826416, 18.30541992], [73.08291626, 18.30541992], [73.08291626, 18.30820084], [73.08319092, 18.30820084], [73.08319092, 18.30874825], [73.08291626, 18.30874825], [73.08291626, 18.30931091], [73.0826416, 18.30931091], [73.0826416, 18.31014061], [73.08235931, 18.31014061], [73.08235931, 18.31041908], [73.08208466, 18.31041718], [73.08208466, 18.3120842], [73.08235931, 18.3120842], [73.08235931, 18.3129158], [73.0826416, 18.3129158], [73.0826416, 18.31347275], [73.08291626, 18.31347275], [73.08291626, 18.31402969], [73.08319092, 18.31402969], [73.08319092, 18.31431007], [73.08347321, 18.31430626], [73.08347321, 18.31458473], [73.08319092, 18.31458473], [73.08319092, 18.3148613], [73.08345795, 18.31485939], [73.08345795, 18.31513977], [73.08374786, 18.31513977], [73.08374786, 18.31569481], [73.08430481, 18.31569481], [73.08430481, 18.31597137], [73.0845871, 18.31596947], [73.0845871, 18.31624985], [73.08486176, 18.31624985], [73.08486176, 18.31680489], [73.08513641, 18.31680489], [73.08513641, 18.31736183], [73.0854187, 18.31736183], [73.0854187, 18.31847191], [73.08569336, 18.31847], [73.08569336, 18.31875038], [73.08598328, 18.31875038], [73.08598328, 18.31903076], [73.08653259, 18.31903076], [73.08653259, 18.31931114], [73.08625031, 18.31930542], [73.08625031, 18.31958389], [73.08653259, 18.31958008], [73.08653259, 18.32014084], [73.08682251, 18.32014084], [73.08682251, 18.32042122], [73.08708191, 18.32042122], [73.08708191, 18.32125092], [73.08735657, 18.32125092], [73.08735657, 18.32235909], [73.08763885, 18.32235909], [73.08763885, 18.32263756], [73.08790588, 18.32263756], [73.08790588, 18.32291985], [73.0881958, 18.32291603], [73.0881958, 18.32347298], [73.08847046, 18.32346916], [73.08847046, 18.32375145], [73.0881958, 18.32375145], [73.0881958, 18.32403183], [73.08763885, 18.32403183], [73.08763885, 18.32375145], [73.08735657, 18.32375145], [73.08735657, 18.32319069], [73.08708191, 18.3231945], [73.08708191, 18.32291603], [73.08682251, 18.32291985], [73.08682251, 18.32263756], [73.08652496, 18.32263756], [73.08652496, 18.32235909], [73.08625031, 18.32235909], [73.08625031, 18.32152748], [73.08598328, 18.32152748], [73.08598328, 18.32014084], [73.08569336, 18.32014084], [73.08569336, 18.32042122], [73.08513641, 18.32041931], [73.08513641, 18.32069397], [73.08486176, 18.32069397], [73.08486176, 18.32097244], [73.0845871, 18.32097054], [73.0845871, 18.32263756], [73.08429718, 18.32263756], [73.08429718, 18.32291985], [73.08403015, 18.32291603], [73.08403015, 18.32486153], [73.08374786, 18.32484818], [73.08374786, 18.32542038], [73.08403015, 18.32542038], [73.08403015, 18.32653046], [73.08429718, 18.32653046], [73.08429718, 18.32681084], [73.08513641, 18.32681084], [73.08513641, 18.32653046], [73.08598328, 18.32653046], [73.08598328, 18.32625008], [73.08790588, 18.32625008], [73.08790588, 18.32681084], [73.08597565, 18.32680511], [73.08597565, 18.32708359], [73.0854187, 18.32708359], [73.0854187, 18.32736206], [73.08513641, 18.32736015], [73.08513641, 18.32764053], [73.08486176, 18.32763863], [73.08486176, 18.32819366], [73.08513641, 18.32819366], [73.08513641, 18.32958412], [73.08486176, 18.32958031], [73.08486176, 18.32986069], [73.0845871, 18.32986069], [73.0845871, 18.32958031], [73.08430481, 18.32958412], [73.08430481, 18.32930565], [73.08403015, 18.32930946], [73.08403015, 18.32736015], [73.08374786, 18.32736206], [73.08374786, 18.32708359], [73.08347321, 18.32708359], [73.08347321, 18.32680511], [73.08319092, 18.32681084], [73.08319092, 18.32653046], [73.08291626, 18.32653046], [73.08291626, 18.32484818], [73.0826416, 18.32486153], [73.0826416, 18.32458115], [73.08235931, 18.32458115], [73.08235931, 18.32347298], [73.08208466, 18.32347298], [73.08208466, 18.3231945], [73.08180237, 18.3231945], [73.08180237, 18.32291603], [73.08152771, 18.32291985], [73.08152771, 18.32263756], [73.08125305, 18.32263756], [73.08125305, 18.32235909], [73.08097076, 18.32235909], [73.08097076, 18.32180977], [73.08068848, 18.32180977], [73.08068848, 18.32152748], [73.08039856, 18.32152748], [73.08039856, 18.32097054], [73.08013916, 18.32097244], [73.08013916, 18.32013893], [73.07985687, 18.32014084], [73.07985687, 18.31958008], [73.07958221, 18.31958389], [73.07958221, 18.31930542], [73.07930756, 18.31931114], [73.07930756, 18.3176403], [73.0790329, 18.3176403], [73.0790329, 18.31680107], [73.07875061, 18.31680489], [73.07875061, 18.31624985], [73.0790329, 18.31624985], [73.07902527, 18.31569481], [73.07875061, 18.31569481], [73.07875061, 18.31458473], [73.07847595, 18.31458473], [73.07847595, 18.31430626], [73.07791901, 18.31431007], [73.07791901, 18.31402969], [73.07765198, 18.31402969], [73.07765198, 18.31375122], [73.07736206, 18.31375122], [73.07736206, 18.31319046], [73.07707977, 18.31319427], [73.07707977, 18.3129158], [73.07680511, 18.3129158], [73.07680511, 18.31263924], [73.07653046, 18.31264114], [73.07653046, 18.31236267], [73.07624817, 18.31236267], [73.07624817, 18.31208038], [73.07597351, 18.3120842], [73.07597351, 18.31180573], [73.07569122, 18.31180954], [73.07569122, 18.31125259], [73.07541656, 18.31125259], [73.07541656, 18.3109684], [73.07485962, 18.31097031], [73.07485962, 18.31069374], [73.07458496, 18.31069374], [73.07458496, 18.30985832], [73.07430267, 18.30987167], [73.07430267, 18.30957985], [73.07402802, 18.30958366], [73.07402802, 18.30930519], [73.07375336, 18.30931091], [73.07375336, 18.30874825], [73.07347107, 18.30874825], [73.07347107, 18.30846977], [73.07263947, 18.30847168], [73.07263947, 18.30819511], [73.07235718, 18.30820084], [73.07235718, 18.30792046], [73.07180786, 18.30792046], [73.07180786, 18.30763817], [73.07151794, 18.30763817], [73.07151794, 18.3073597], [73.07096863, 18.3073616], [73.07096863, 18.30708313], [73.07069397, 18.30708313], [73.07069397, 18.30680466], [73.06986237, 18.30681038], [73.06986237, 18.30652809], [73.06958008, 18.30652809], [73.06958008, 18.30624962], [73.06930542, 18.30624962], [73.06930542, 18.30597305], [73.06903076, 18.30597305], [73.06903076, 18.30569458], [73.06874847, 18.30569458], [73.06874847, 18.30541611], [73.06845856, 18.30541992], [73.06845856, 18.30513954], [73.06819153, 18.30513954], [73.06819153, 18.30486107], [73.06735992, 18.30486107], [73.06735992, 18.30458069], [73.06680298, 18.3045826], [73.06680298, 18.30430412], [73.06597137, 18.30430984], [73.06597137, 18.30402946], [73.06571198, 18.30402946], [73.06571198, 18.30373955], [73.06375122, 18.30374908], [73.06375122, 18.30347252], [73.06319427, 18.30347252], [73.06319427, 18.30319595], [73.06263733, 18.30319595], [73.06263733, 18.30291748], [73.06153107, 18.30291748], [73.06153107, 18.30319595], [73.06097412, 18.30319595], [73.06097412, 18.30347252], [73.05986023, 18.30347252], [73.05986023, 18.30374908], [73.05847168, 18.30373955], [73.05847168, 18.30402946], [73.05819702, 18.30402946], [73.05819702, 18.30430984], [73.05764008, 18.30430412], [73.05764008, 18.3045826], [73.05625153, 18.30458069], [73.05625153, 18.30486107], [73.05596924, 18.30486107], [73.05596924, 18.30513954], [73.05541992, 18.30513954], [73.05541992, 18.30541992], [73.05486298, 18.30541611], [73.05486298, 18.30569458], [73.05458069, 18.30569458], [73.05458069, 18.30597305], [73.05410004, 18.30597115], [73.05403137, 18.30624962], [73.05374908, 18.30624962], [73.05374908, 18.30652809], [73.05291748, 18.30652809], [73.05291748, 18.30681038], [73.05236053, 18.30680466], [73.05236053, 18.30708313], [73.05180359, 18.30708313], [73.05180359, 18.3073616], [73.05124664, 18.3073597], [73.05124664, 18.30763817], [73.05071259, 18.30763817], [73.05071259, 18.30792046], [73.05042267, 18.30792046], [73.05042267, 18.30763817], [73.04902649, 18.30763817], [73.04902649, 18.3073597], [73.04846954, 18.3073616], [73.04846954, 18.30708313], [73.04819489, 18.30708313], [73.04819489, 18.30680466], [73.04763794, 18.30681038], [73.04763794, 18.30652809], [73.04680634, 18.30652809], [73.04680634, 18.30681038], [73.04651642, 18.30681038], [73.04651642, 18.30652809], [73.04541779, 18.30652809], [73.04541779, 18.30597115], [73.04486084, 18.30597305], [73.04486084, 18.30569458], [73.04458618, 18.30569458], [73.04458618, 18.30541611], [73.04402924, 18.30541992], [73.04402924, 18.30513954], [73.04374695, 18.30513954], [73.04374695, 18.30486107], [73.04345703, 18.30486107], [73.04344177, 18.30430984], [73.04292297, 18.30430984], [73.04292297, 18.30373955], [73.0423584, 18.30374908], [73.0423584, 18.30347252], [73.04208374, 18.30347252], [73.04208374, 18.30291748], [73.04180908, 18.30291939], [73.04180908, 18.30264091], [73.04125214, 18.30264091], [73.04125214, 18.30208015], [73.04069519, 18.30208206], [73.04069519, 18.3018055], [73.0404129, 18.30181122], [73.0404129, 18.30153084], [73.04013824, 18.30153084], [73.04013824, 18.30097008], [73.03986359, 18.30097389], [73.03986359, 18.30069542], [73.0395813, 18.30068016], [73.0395813, 18.29958344], [73.03930664, 18.29958344], [73.03930664, 18.29791641], [73.0395813, 18.29792976], [73.0395813, 18.29764175], [73.03930664, 18.29764175], [73.03930664, 18.29681015], [73.0395813, 18.29681015], [73.0395813, 18.29653168], [73.03930664, 18.29653168], [73.03930664, 18.29624748], [73.0395813, 18.29624748], [73.0395813, 18.29597092], [73.03930664, 18.29597282], [73.03930664, 18.29569435], [73.0395813, 18.29569435], [73.0395813, 18.29458427], [73.03986359, 18.29458237], [73.03986359, 18.29375076], [73.04013824, 18.29375076], [73.04013824, 18.29292107], [73.0404129, 18.29292107], [73.0404129, 18.29236031], [73.04070282, 18.29236031], [73.04069519, 18.29180527], [73.04096985, 18.29180527], [73.04096985, 18.2915287], [73.04125214, 18.29153061], [73.04125214, 18.29096985], [73.04152679, 18.29097176], [73.04152679, 18.29069519], [73.04207611, 18.29070091], [73.04207611, 18.29014015], [73.0423584, 18.29014015], [73.0423584, 18.28985977], [73.04264069, 18.28986168], [73.04264069, 18.28958321], [73.04291534, 18.28958321], [73.04291534, 18.28930473], [73.04319763, 18.28930473], [73.04319763, 18.28902817], [73.04347229, 18.28903008], [73.04347229, 18.28847122], [73.04374695, 18.28847313], [73.04374695, 18.28763962], [73.04402924, 18.28763962], [73.04402924, 18.28708267], [73.04430389, 18.28708267], [73.04430389, 18.28652763], [73.04457855, 18.28652954], [73.04457855, 18.2859726], [73.04486084, 18.2859726], [73.04486084, 18.28486252], [73.04514313, 18.28486252], [73.0451355, 18.28430557], [73.04541779, 18.28430939], [73.04541779, 18.28374863], [73.0459671, 18.28374863], [73.0459671, 18.28346825], [73.04569244, 18.28347015], [73.04569244, 18.28264046], [73.0459671, 18.28264046], [73.0459671, 18.28124809], [73.04624939, 18.28124809], [73.04624939, 18.28096962], [73.04652405, 18.28097153], [73.04652405, 18.28069496], [73.04736328, 18.28070068], [73.04736328, 18.2804203], [73.04792023, 18.2804203], [73.04792023, 18.27985954], [73.04819489, 18.27986145], [73.04819489, 18.27930641], [73.04846954, 18.27931023], [73.04846954, 18.27902985], [73.04875183, 18.27902985], [73.04875183, 18.27847099], [73.04930878, 18.2784729], [73.04930878, 18.27819443], [73.04958344, 18.27819443], [73.04958344, 18.27763939], [73.04985809, 18.27763939], [73.04985809, 18.27736092], [73.05042267, 18.27736092], [73.05041504, 18.27708244], [73.05069733, 18.27708244], [73.05069733, 18.27680588], [73.05124664, 18.27680588], [73.05124664, 18.2765274], [73.05152893, 18.27653122], [73.05152893, 18.27625084], [73.05179596, 18.27625084], [73.05179596, 18.27597046], [73.05208588, 18.27597237], [73.05208588, 18.27541733], [73.05236053, 18.27542114], [73.05236053, 18.27514076], [73.05264282, 18.27514076], [73.05264282, 18.27486038], [73.05319214, 18.27486038], [73.05319214, 18.27458191], [73.05347443, 18.27458382], [73.05347443, 18.27402687], [73.05374908, 18.27403069], [73.05374908, 18.27375984], [73.05403137, 18.27375984], [73.05403137, 18.2732029], [73.05430603, 18.2732029], [73.05430603, 18.27292061], [73.05458069, 18.27292061], [73.05458069, 18.27179909], [73.05486298, 18.27180481], [73.05486298, 18.27152824], [73.05458069, 18.27153015], [73.05458069, 18.27042007], [73.05430603, 18.27042007], [73.05430603, 18.26985931], [73.05403137, 18.26985931], [73.05403137, 18.26958084], [73.05374908, 18.26958275], [73.05374908, 18.26930618], [73.05348206, 18.26930809], [73.05348206, 18.26902962], [73.05319214, 18.26902962], [73.05319214, 18.26874924], [73.05264282, 18.26874924], [73.05264282, 18.26847076], [73.05236053, 18.26847267], [73.05236053, 18.2681942], [73.05208588, 18.2681942], [73.05208588, 18.26847267], [73.05069733, 18.26847267], [73.05069733, 18.2681942], [73.04958344, 18.2681942], [73.04958344, 18.26791954], [73.04902649, 18.26791954], [73.04902649, 18.26762962], [73.04819489, 18.26763725], [73.04819489, 18.26736069], [73.04736328, 18.26736069], [73.04736328, 18.26708031], [73.04624939, 18.26708412], [73.04624939, 18.26680565], [73.04541779, 18.26680946], [73.04541779, 18.26653099], [73.04374695, 18.26653099], [73.04374695, 18.26597023], [73.04347229, 18.26597214], [73.04347229, 18.26569366], [73.04291534, 18.26569366], [73.04291534, 18.26541519], [73.0423584, 18.26542091], [73.0423584, 18.26514053], [73.04180908, 18.26514053], [73.04180908, 18.26486015], [73.04152679, 18.26486206], [73.04152679, 18.26458359], [73.03986359, 18.26458359], [73.03986359, 18.26486206], [73.03820801, 18.26486206], [73.0359726, 18.26486206], [73.0359726, 18.26458359], [73.03569794, 18.26458359], [73.03569794, 18.26486206], [73.03514099, 18.26486015], [73.03514099, 18.26514053], [73.0348587, 18.26514053], [73.0348587, 18.26542091], [73.03458405, 18.26541519], [73.03458405, 18.26569366], [73.03375244, 18.26569366], [73.03375244, 18.26597214], [73.03263855, 18.26597023], [73.03263855, 18.26625061], [73.03151703, 18.26625061], [73.03151703, 18.26597023], [73.03125, 18.26597214], [73.03125, 18.26569366], [73.03069305, 18.26569366], [73.03069305, 18.26541519], [73.0304184, 18.26542091], [73.0304184, 18.26514053], [73.03013611, 18.26514053], [73.03013611, 18.26486015], [73.02958679, 18.26486206], [73.02958679, 18.26458359], [73.02902985, 18.26458359], [73.02902985, 18.26430511], [73.02791595, 18.26430511], [73.02791595, 18.26597214], [73.02819824, 18.26597023], [73.02819824, 18.26680946], [73.02791595, 18.26680565], [73.02791595, 18.26708412], [73.02735901, 18.26708031], [73.02735901, 18.26736069], [73.02708435, 18.26736069], [73.02708435, 18.26763725], [73.02680206, 18.26762962], [73.02680206, 18.26791954], [73.02654266, 18.26791954], [73.02654266, 18.26874924], [73.02625275, 18.26874924], [73.02625275, 18.26902962], [73.02597046, 18.26902962], [73.02597046, 18.26930809], [73.02541351, 18.26930618], [73.02541351, 18.26958275], [73.02513885, 18.26958275], [73.02513885, 18.26930618], [73.02485657, 18.26930809], [73.02485657, 18.26874924], [73.02458191, 18.26874924], [73.02458191, 18.26847076], [73.02346802, 18.26847076], [73.02346802, 18.26874924], [73.0229187, 18.26874924], [73.0229187, 18.26902962], [73.02153015, 18.26902962], [73.02153015, 18.26958275], [73.02097321, 18.26958084], [73.02097321, 18.26985931], [73.02069092, 18.26985931], [73.02069092, 18.27042007], [73.02041626, 18.27041626], [73.02041626, 18.27180481], [73.02097321, 18.27180481], [73.02097321, 18.27208328], [73.02124786, 18.27208328], [73.02124786, 18.27236176], [73.02179718, 18.27236176], [73.02179718, 18.27264023], [73.0220871, 18.27264023], [73.0220871, 18.27292061], [73.02236176, 18.27292061], [73.02236176, 18.2732029], [73.02263641, 18.2732029], [73.02263641, 18.27403069], [73.02236176, 18.27403069], [73.02236176, 18.27514076], [73.0220871, 18.27514076], [73.0220871, 18.27542114], [73.02179718, 18.27542114], [73.02179718, 18.27653122], [73.0220871, 18.2765274], [73.0220871, 18.27680588], [73.02236176, 18.27680016], [73.02236176, 18.27736092], [73.0220871, 18.27736092], [73.0220871, 18.27791977], [73.02180481, 18.27791405], [73.02180481, 18.27819443], [73.02153015, 18.27819443], [73.02153015, 18.2784729], [73.02069092, 18.27847099], [73.02069092, 18.27902985], [73.02040863, 18.27902985], [73.02040863, 18.27931023], [73.0201416, 18.27930641], [73.0201416, 18.27958298], [73.01985931, 18.27958298], [73.01985931, 18.27986145], [73.01930237, 18.27985954], [73.01930237, 18.28013992], [73.01875305, 18.28013992], [73.01875305, 18.2804203], [73.01847076, 18.2804203], [73.01847076, 18.28070068], [73.01791382, 18.28069496], [73.01791382, 18.28097153], [73.01734924, 18.28096962], [73.01734924, 18.28124809], [73.01680756, 18.28124809], [73.01680756, 18.28153038], [73.01654053, 18.28153038], [73.0165329, 18.28181076], [73.01597595, 18.28180504], [73.01597595, 18.28208351], [73.01513672, 18.28208351], [73.01513672, 18.28236008], [73.01457977, 18.28235817], [73.01457977, 18.28264046], [73.01431274, 18.28264046], [73.01431274, 18.28293037], [73.01374817, 18.28291893], [73.01374817, 18.28319359], [73.01291656, 18.28319359], [73.01291656, 18.28347015], [73.01235962, 18.28346825], [73.01235962, 18.28374863], [73.01125336, 18.28374863], [73.01125336, 18.28403091], [73.00958252, 18.28403091], [73.00958252, 18.28430939], [73.00875092, 18.28430557], [73.00875092, 18.28458405], [73.00291443, 18.28458405], [73.00291443, 18.28430557], [73.00041962, 18.28430939], [73.00041962, 18.28346825], [72.99986267, 18.28347015], [72.99930573, 18.28347015], [72.99930573, 18.28319359], [72.99874878, 18.28319359], [72.99874878, 18.28291893], [72.99791718, 18.28293037], [72.99791718, 18.2820797], [72.99819183, 18.28208351], [72.99819183, 18.28124809], [72.99791718, 18.28124809], [72.99791718, 18.28070068], [72.99764252, 18.28070068], [72.99764252, 18.28013992], [72.99736023, 18.28013992], [72.99736023, 18.27956963], [72.99708557, 18.27958298], [72.99708557, 18.27819443], [72.99680328, 18.27819443], [72.99680328, 18.27708244], [72.99652863, 18.27708244], [72.99652863, 18.2765274], [72.99623871, 18.27653122], [72.99623871, 18.27625084], [72.99597168, 18.27625084], [72.99597168, 18.27597046], [72.99569702, 18.27597237], [72.99569702, 18.2756958], [72.99541473, 18.2756958], [72.99541473, 18.27541733], [72.99514008, 18.27542114], [72.99514008, 18.27514076], [72.99485779, 18.27514076], [72.99485779, 18.27486038], [72.99430847, 18.27486038], [72.99430847, 18.27431107], [72.99402618, 18.27431107], [72.99402618, 18.27347183], [72.99291992, 18.27347183], [72.99291992, 18.27514076], [72.99263763, 18.27514076], [72.99263763, 18.27625084], [72.99236298, 18.27625084], [72.99236298, 18.27680588], [72.99180603, 18.27680016], [72.99180603, 18.27902985], [72.99208069, 18.27902985], [72.99208069, 18.28013992], [72.99180603, 18.28013992], [72.99180603, 18.28070068], [72.99153137, 18.28070068], [72.99153137, 18.28124809], [72.99124908, 18.28124809], [72.99124908, 18.28153038], [72.99097443, 18.28153038], [72.99097443, 18.28208351], [72.99069214, 18.28208351], [72.99069214, 18.28236008], [72.99043274, 18.28235817], [72.99043274, 18.28403091], [72.99069214, 18.2840271], [72.99069214, 18.28458405], [72.99043274, 18.28457832], [72.99043274, 18.28541946], [72.99014282, 18.28541946], [72.99014282, 18.28652954], [72.98986053, 18.28652763], [72.98986053, 18.28708267], [72.98958588, 18.28708267], [72.98958588, 18.28736115], [72.98764038, 18.28736115], [72.98764038, 18.28708267], [72.98707581, 18.28708267], [72.98707581, 18.28763962], [72.98680878, 18.28763962], [72.98680878, 18.28847313], [72.98652649, 18.28847313], [72.98652649, 18.28958321], [72.98680878, 18.28957939], [72.98680878, 18.29042053], [72.98652649, 18.29042053], [72.98652649, 18.29153061], [72.98625183, 18.2915287], [72.98625183, 18.29180527], [72.98596954, 18.29179955], [72.98596954, 18.29236031], [72.98513794, 18.29236031], [72.98513794, 18.29264069], [72.98400879, 18.29264069], [72.98400879, 18.29292107], [72.98374939, 18.29292107], [72.98374939, 18.29403114], [72.98347473, 18.29402733], [72.98347473, 18.29458427], [72.98319244, 18.29458046], [72.98319244, 18.29514122], [72.98291779, 18.29513741], [72.98291779, 18.29597282], [72.98264313, 18.29597092], [72.98264313, 18.29681015], [72.98236084, 18.29680634], [72.98236084, 18.29717064], [72.98236084, 18.29792976], [72.98208618, 18.29791641], [72.98208618, 18.29846954], [72.98179626, 18.29846954], [72.98179626, 18.29931068], [72.98152924, 18.29930496], [72.98152924, 18.29986382], [72.98060608, 18.29986191], [72.98042297, 18.29986191], [72.98042297, 18.30014038], [72.97902679, 18.30014038], [72.97902679, 18.29957962], [72.97930908, 18.29958344], [72.97930908, 18.2990284], [72.97846985, 18.2990303], [72.97846985, 18.29875183], [72.9779129, 18.29875183], [72.9779129, 18.2990303], [72.9770813, 18.2990303], [72.9770813, 18.29931068], [72.97624969, 18.29930496], [72.97624969, 18.29958344], [72.97569275, 18.29958344], [72.97569275, 18.29986382], [72.97458649, 18.29986191], [72.97458649, 18.30014038], [72.97429657, 18.30014038], [72.97429657, 18.30042076], [72.97402954, 18.30041695], [72.97402954, 18.30068016], [72.97374725, 18.30069542], [72.97374725, 18.30097389], [72.9734726, 18.30097008], [72.9734726, 18.30125046], [72.97319794, 18.30125046], [72.97319794, 18.30181122], [72.9723587, 18.30181122], [72.9723587, 18.30153084], [72.97180176, 18.30153084], [72.97180176, 18.30125046], [72.97097015, 18.30125046], [72.97097015, 18.29957962], [72.97041321, 18.29958344], [72.97041321, 18.29986382], [72.97013855, 18.29986191], [72.97013855, 18.30014038], [72.96986389, 18.30013847], [72.96985626, 18.30068016], [72.9695816, 18.30070114], [72.9695816, 18.30125046], [72.96929932, 18.30125046], [72.96929932, 18.30181122], [72.9690094, 18.30181122], [72.9690094, 18.30236053], [72.96875, 18.30236053], [72.96875, 18.30374908], [72.96847534, 18.30374908], [72.96847534, 18.3045826], [72.96819305, 18.3045826], [72.96819305, 18.30569458], [72.9679184, 18.30569458], [72.9679184, 18.30708313], [72.96819305, 18.30708313], [72.96819305, 18.3074398], [72.96819305, 18.30792046], [72.96848297, 18.30792046], [72.96848297, 18.30903053], [72.96819305, 18.30903053], [72.96819305, 18.30931091], [72.9679184, 18.30930519], [72.9679184, 18.30958366], [72.96763611, 18.30957985], [72.96763611, 18.31014061], [72.96736145, 18.31014061], [72.96736145, 18.31041908], [72.96708679, 18.31041718], [72.96708679, 18.31069374], [72.9668045, 18.31069374], [72.9668045, 18.31097031], [72.96652985, 18.3109684], [72.96652985, 18.31125259], [72.96626282, 18.31125259], [72.96626282, 18.31153107], [72.9659729, 18.31153107], [72.9659729, 18.31180954], [72.96541595, 18.31180573], [72.96541595, 18.3120842], [72.9651413, 18.31208038], [72.9651413, 18.31236267], [72.96485901, 18.31236267], [72.96485901, 18.31264114], [72.96458435, 18.31263924], [72.96458435, 18.3129158], [72.96430206, 18.3129158], [72.96430206, 18.31319427], [72.96263885, 18.31319427], [72.96263885, 18.3129158], [72.9623642, 18.3129158], [72.9623642, 18.3120842], [72.96180725, 18.3120842], [72.96180725, 18.31180573], [72.96125031, 18.31180954], [72.96125031, 18.3116703], [72.96125031, 18.31152725], [72.95986176, 18.31153107], [72.95986176, 18.31125259], [72.9595871, 18.31125259], [72.9595871, 18.31153107], [72.95903015, 18.31153107], [72.95903015, 18.31180954], [72.95874786, 18.31180954], [72.95874786, 18.31236267], [72.95847321, 18.31236267], [72.95847321, 18.31264114], [72.95819092, 18.31263924], [72.95819092, 18.3129158], [72.95791626, 18.3129158], [72.95791626, 18.31319427], [72.9576416, 18.31319427], [72.9576416, 18.31347275], [72.95735931, 18.31347275], [72.95735931, 18.31402969], [72.9570694, 18.31402969], [72.9570694, 18.31431007], [72.95680237, 18.31430626], [72.95680237, 18.31458473], [72.95652771, 18.31458473], [72.95652771, 18.3148613], [72.95625305, 18.31485939], [72.95625305, 18.31513977], [72.95597076, 18.31513977], [72.95597076, 18.31569481], [72.95569611, 18.31569481], [72.95569611, 18.31597137], [72.95540619, 18.31596947], [72.95540619, 18.31653023], [72.95569611, 18.31652832], [72.95569611, 18.31736183], [72.95597076, 18.31735992], [72.95597076, 18.31792068], [72.95625305, 18.31792068], [72.95625305, 18.31820107], [72.95680237, 18.31819534], [72.95680237, 18.31847191], [72.95735931, 18.31847], [72.95735931, 18.31875038], [72.95791626, 18.31875038], [72.95791626, 18.31903076], [72.95819092, 18.31902695], [72.95819092, 18.31958389], [72.95847321, 18.31958008], [72.95847321, 18.31986046], [72.95874786, 18.31986046], [72.95874786, 18.31958008], [72.95930481, 18.31958389], [72.95930481, 18.31930542], [72.96097565, 18.31930542], [72.96097565, 18.31958389], [72.96069336, 18.31958008], [72.96069336, 18.31986046], [72.9604187, 18.31986046], [72.9604187, 18.32014084], [72.96012878, 18.32014084], [72.96012878, 18.32042122], [72.95986176, 18.32041931], [72.95986176, 18.32069397], [72.9595871, 18.32069397], [72.9595871, 18.32097244], [72.95929718, 18.32097054], [72.95929718, 18.32125092], [72.95903015, 18.32125092], [72.95903015, 18.32152748], [72.95874786, 18.32152748], [72.95874786, 18.32180977], [72.95847321, 18.32180595], [72.95847321, 18.32208252], [72.95819092, 18.32208061], [72.95819092, 18.32263756], [72.95791626, 18.32263756], [72.95791626, 18.32291985], [72.9576416, 18.32291603], [72.9576416, 18.3231945], [72.95735931, 18.32319069], [72.95735931, 18.32375145], [72.95680237, 18.32375145], [72.95680237, 18.3243103], [72.95652771, 18.32430649], [72.95652771, 18.32458115], [72.95625305, 18.32457924], [72.95625305, 18.32514191], [72.95597076, 18.32514191], [72.95597076, 18.32570267], [72.95569611, 18.32569504], [72.95569611, 18.3259697], [72.95540619, 18.3259697], [72.95540619, 18.32653046], [72.95513916, 18.32653046], [72.95513916, 18.32681084], [72.9548645, 18.32680511], [72.9548645, 18.3279171], [72.95458221, 18.3279171], [72.95458221, 18.32819366], [72.95432281, 18.32818985], [72.95432281, 18.32903099], [72.95402527, 18.32902718], [72.95402527, 18.32958412], [72.95375061, 18.32958031], [72.95375061, 18.33014107], [72.95347595, 18.33013916], [72.95347595, 18.3306942], [72.95318604, 18.33069038], [72.95318604, 18.33152962], [72.95291901, 18.33152962], [72.95291901, 18.33374977], [72.95263672, 18.33374977], [72.95263672, 18.33403969], [72.95207977, 18.33402634], [72.95207977, 18.33430481], [72.95180511, 18.33430481], [72.95180511, 18.33486176], [72.95153046, 18.33485985], [72.95153046, 18.33513832], [72.95096588, 18.33513832], [72.95096588, 18.3362484], [72.95069122, 18.3362484], [72.95069122, 18.33653069], [72.95041656, 18.33653069], [72.95041656, 18.33680916], [72.95014191, 18.33680534], [72.95014191, 18.33708382], [72.94985962, 18.33707809], [72.94985962, 18.33735847], [72.94957733, 18.33735847], [72.94957733, 18.33764076], [72.94902802, 18.33764076], [72.94902802, 18.33792114], [72.94875336, 18.33791733], [72.94875336, 18.33819389], [72.94763947, 18.33819389], [72.94763947, 18.33847237], [72.94680786, 18.33847237], [72.94680786, 18.33875275], [72.94625092, 18.33875275], [72.94625092, 18.33903122], [72.94568634, 18.33903122], [72.94568634, 18.33930969], [72.94541931, 18.33930588], [72.94541931, 18.34069443], [72.94512939, 18.34069061], [72.94512939, 18.34152985], [72.94431305, 18.34152985], [72.94431305, 18.34181023], [72.94403076, 18.34180641], [72.94403076, 18.34236145], [72.94374847, 18.34235954], [72.94374847, 18.34263992], [72.94347382, 18.34263802], [72.94347382, 18.34291649], [72.94291687, 18.34291077], [72.94291687, 18.34320068], [72.94235992, 18.34319305], [72.94235992, 18.34347153], [72.94208527, 18.34347153], [72.9420929, 18.34375], [72.94152832, 18.34375], [72.94152832, 18.34403038], [72.94069672, 18.34403038], [72.94069672, 18.34431076], [72.93958282, 18.34431076], [72.93958282, 18.34403038], [72.9393158, 18.34403038], [72.9393158, 18.34346962], [72.93902588, 18.34347153], [72.93902588, 18.34319305], [72.93875122, 18.34320068], [72.93875122, 18.34263992], [72.93819427, 18.34263802], [72.93819427, 18.34291649], [72.93763733, 18.34291077], [72.93763733, 18.34320068], [72.93736267, 18.34319305], [72.93736267, 18.34347153], [72.93624878, 18.34347153], [72.93624878, 18.34319305], [72.93596649, 18.34320068], [72.93596649, 18.34291077], [72.93569183, 18.34291649], [72.93569183, 18.34263802], [72.93458557, 18.34263802], [72.93458557, 18.34291649], [72.93402863, 18.34291649], [72.93402863, 18.34458351], [72.93430328, 18.3445797], [72.93430328, 18.34514046], [72.93458557, 18.34513855], [72.93458557, 18.34569359], [72.93486023, 18.34568977], [72.93486023, 18.34597969], [72.93514252, 18.34597969], [72.93514252, 18.34653091], [72.93541718, 18.34652519], [72.93541718, 18.34708405], [72.93569183, 18.34708023], [72.93569183, 18.34763908], [72.93597412, 18.34763718], [72.93597412, 18.34819412], [72.93624878, 18.34819031], [72.93624878, 18.34874916], [72.93596649, 18.34874916], [72.93596649, 18.34930992], [72.93569183, 18.34930611], [72.93569183, 18.34958267], [72.93514252, 18.34958076], [72.93514252, 18.34985924], [72.93486023, 18.34985924], [72.93486023, 18.35014153], [72.93458557, 18.35014153], [72.93458557, 18.35069466], [72.93430328, 18.35069466], [72.93430328, 18.35097313], [72.93208313, 18.35097313], [72.93208313, 18.35041618], [72.93180847, 18.35042191], [72.93180847, 18.35014153], [72.93152618, 18.35014153], [72.93152618, 18.34985924], [72.93125153, 18.34985924], [72.93125153, 18.34958076], [72.93041992, 18.34958076], [72.93041992, 18.34985924], [72.92903137, 18.34985924], [72.92903137, 18.34958076], [72.92847443, 18.34958267], [72.92847443, 18.34930611], [72.92680359, 18.34930611], [72.92680359, 18.34958267], [72.92624664, 18.34958076], [72.92624664, 18.34985924], [72.92597198, 18.34985924], [72.92597198, 18.35014153], [72.92542267, 18.35014153], [72.92542267, 18.35042191], [72.92430878, 18.35042191], [72.92430878, 18.35014153], [72.92457581, 18.35014153], [72.92457581, 18.34985924], [72.92430878, 18.34985924], [72.92430878, 18.34958076], [72.92402649, 18.34958267], [72.92402649, 18.34930611], [72.92318726, 18.34930992], [72.92318726, 18.34903908], [72.92208099, 18.34903908], [72.92208099, 18.34819031], [72.92236328, 18.34819412], [72.92236328, 18.34763718], [72.92208099, 18.34763908], [72.92208099, 18.34736061], [72.92180634, 18.34736061], [72.92180634, 18.34708023], [72.92152405, 18.34708405], [72.92152405, 18.34680557], [72.91986084, 18.34680557], [72.91986084, 18.34708405], [72.91929626, 18.34708023], [72.91929626, 18.34736061], [72.91902924, 18.34736061], [72.91902924, 18.34763908], [72.91847229, 18.34763908], [72.91847229, 18.34791946], [72.91791534, 18.34791946], [72.91791534, 18.34819412], [72.91764069, 18.34819412], [72.91764069, 18.3484726], [72.9173584, 18.34847069], [72.9173584, 18.34903908], [72.91708374, 18.34902763], [72.91708374, 18.35069466], [72.91680908, 18.35069084], [72.91680908, 18.3512516], [72.91652679, 18.3512516], [72.91652679, 18.35180473], [72.91625214, 18.35180473], [72.91625214, 18.35236168], [72.91596985, 18.35236168], [72.91596985, 18.35292053], [72.91570282, 18.35292053], [72.91570282, 18.35320282], [72.9154129, 18.35319519], [72.9154129, 18.35347366], [72.91513824, 18.35347366], [72.91514587, 18.35375023], [72.91485596, 18.35375023], [72.91485596, 18.35403061], [72.9145813, 18.3540287], [72.9145813, 18.35458374], [72.91430664, 18.35458374], [72.91430664, 18.35486031], [72.91401672, 18.35485268], [72.91401672, 18.35542107], [72.91430664, 18.35542107], [72.91430664, 18.35625076], [72.9145813, 18.35625076], [72.9145813, 18.35736084], [72.91486359, 18.35736084], [72.91486359, 18.35819435], [72.9145813, 18.35819054], [72.9145813, 18.35902977], [72.91430664, 18.35902977], [72.91430664, 18.35931015], [72.91402435, 18.35930634], [72.91402435, 18.3595829], [72.91374969, 18.3595829], [72.91374969, 18.35986137], [72.91348267, 18.35985947], [72.91348267, 18.36013985], [72.91319275, 18.36013985], [72.91319275, 18.36042023], [72.91291809, 18.36041641], [72.91291809, 18.36069489], [72.91236115, 18.36069107], [72.91236115, 18.36097908], [72.91208649, 18.36097908], [72.91208649, 18.3615303], [72.9118042, 18.36152649], [72.91179657, 18.3631897], [72.91152954, 18.36319923], [72.91152954, 18.36514282], [72.91124725, 18.36514282], [72.91124725, 18.36680984], [72.91152954, 18.36680984], [72.91152954, 18.36736107], [72.91179657, 18.36736107], [72.91179657, 18.36791992], [72.91208649, 18.36791611], [72.91208649, 18.36847305], [72.91236115, 18.36847115], [72.91236115, 18.36874962], [72.9126358, 18.36874962], [72.9126358, 18.36903], [72.91291809, 18.36902809], [72.91291809, 18.36958313], [72.91319275, 18.36958313], [72.91319275, 18.3698616], [72.91348267, 18.3698597], [72.91348267, 18.37014961], [72.91374969, 18.37014961], [72.91374969, 18.37042046], [72.91430664, 18.37042046], [72.91430664, 18.37070084], [72.9145813, 18.37069511], [72.9145813, 18.37097168], [72.91513824, 18.37097168], [72.91513824, 18.37125015], [72.9154129, 18.37125015], [72.9154129, 18.37153053], [72.91596985, 18.37153053], [72.91596985, 18.37181091], [72.91625214, 18.37180519], [72.91625214, 18.37208366], [72.91680908, 18.37207985], [72.91680908, 18.37264061], [72.91764069, 18.37264061], [72.91764069, 18.37207985], [72.91791534, 18.37208366], [72.91791534, 18.37180519], [72.91958618, 18.37180519], [72.91958618, 18.37208366], [72.9201355, 18.37208366], [72.9201355, 18.37236023], [72.92069244, 18.37236023], [72.92069244, 18.37264061], [72.92124939, 18.37264061], [72.92124939, 18.37292099], [72.92152405, 18.37291527], [72.92152405, 18.37319374], [72.92208099, 18.37319374], [72.92208099, 18.37347221], [72.92236328, 18.37347031], [72.92236328, 18.37375069], [72.92318726, 18.37375069], [72.92318726, 18.37347031], [72.92375183, 18.37347221], [72.92375183, 18.37319374], [72.92402649, 18.37319374], [72.92402649, 18.37347221], [72.92430878, 18.37347221], [72.92430878, 18.37319374], [72.92485809, 18.37319374], [72.92485809, 18.37291527], [72.92624664, 18.37291527], [72.92624664, 18.37319374], [72.92597198, 18.37319374], [72.92597198, 18.37347221], [72.92514038, 18.37347031], [72.92514038, 18.37375069], [72.92457581, 18.37375069], [72.92457581, 18.37403107], [72.92485809, 18.37403107], [72.92485809, 18.37430954], [72.92458344, 18.37430573], [72.92458344, 18.37569427], [72.92485809, 18.37569046], [72.92485809, 18.37681007], [72.92514038, 18.37681007], [72.92514038, 18.37792015], [72.92541504, 18.37791634], [72.92541504, 18.37875175], [72.92569733, 18.37875175], [72.92569733, 18.3801403], [72.92597198, 18.3801403], [72.92597198, 18.38125038], [72.92624664, 18.38125038], [72.92624664, 18.38264084], [72.92597198, 18.38264084], [72.92597198, 18.38292122], [72.92624664, 18.38292122], [72.92624664, 18.38652992], [72.92597198, 18.38652992], [72.92597198, 18.38792038], [72.92569733, 18.38791656], [72.92569733, 18.3884716], [72.92542267, 18.3884697], [72.92542267, 18.38931084], [72.92514038, 18.38931084], [72.92514038, 18.39014053], [72.92485809, 18.39014053], [72.92485809, 18.39069366], [72.92457581, 18.39068985], [72.92457581, 18.3912487], [72.92430878, 18.3912487], [72.92430878, 18.3915329], [72.92402649, 18.39152718], [72.92402649, 18.39208412], [72.92346954, 18.39208031], [72.92346954, 18.39236259], [72.92292023, 18.39236259], [72.92292023, 18.39264107], [72.92208099, 18.39264107], [72.92208099, 18.39291954], [72.92124939, 18.39291763], [72.92124939, 18.3931942], [72.9173584, 18.3931942], [72.9173584, 18.39291763], [72.91707611, 18.39291954], [72.91707611, 18.39236259], [72.91596985, 18.39236259], [72.91596985, 18.39291954], [72.9154129, 18.39291763], [72.9154129, 18.39347267], [72.91514587, 18.39347267], [72.91514587, 18.39375114], [72.91430664, 18.39375114], [72.91430664, 18.39319038], [72.91343689, 18.3931942], [72.91319275, 18.3931942], [72.91319275, 18.39347267], [72.91308594, 18.39347267], [72.91291809, 18.39347267], [72.91291809, 18.39361191], [72.91291809, 18.39375114], [72.91274261, 18.39375114], [72.9126358, 18.39375114], [72.9126358, 18.39402962], [72.91236877, 18.39404106], [72.91236115, 18.39431953], [72.91208649, 18.39431953], [72.91208649, 18.39513969], [72.91236115, 18.39513969], [72.91236115, 18.39653015], [72.91208649, 18.39653015], [72.91208649, 18.39709091], [72.91179657, 18.39709091], [72.91179657, 18.39764023], [72.91152954, 18.39764023], [72.91152954, 18.39792061], [72.91124725, 18.39792061], [72.91124725, 18.39820099], [72.9109726, 18.39819527], [72.9109726, 18.39847183], [72.91069794, 18.39846992], [72.91069794, 18.39875031], [72.90901947, 18.39875031], [72.90901947, 18.39903069], [72.90875244, 18.39903069], [72.90875244, 18.39931107], [72.90847015, 18.39931107], [72.90847015, 18.39986038], [72.90820313, 18.39986038], [72.90820313, 18.40042114], [72.90847015, 18.40041733], [72.90847015, 18.40097237], [72.90875244, 18.40097046], [72.90875244, 18.40153122], [72.90901947, 18.40153122], [72.90901947, 18.40180969], [72.90875244, 18.40180588], [72.90875244, 18.40208244], [72.90847015, 18.40208054], [72.90847015, 18.40236092], [72.9081955, 18.40236092], [72.90820313, 18.40263748], [72.90652466, 18.40263748], [72.90652466, 18.4034729], [72.90680695, 18.40346909], [72.90680695, 18.40403175], [72.90763855, 18.40403175], [72.90763855, 18.40431023], [72.90820313, 18.40431023], [72.90820313, 18.40570068], [72.90735626, 18.40570068], [72.90735626, 18.40681076], [72.90763855, 18.40681076], [72.90763855, 18.40903091], [72.90736389, 18.4090271], [72.90736389, 18.40958595], [72.9070816, 18.40958023], [72.9070816, 18.40986061], [72.90680695, 18.40986061], [72.90680695, 18.41014099], [72.90569305, 18.41014099], [72.90569305, 18.41152954], [72.9070816, 18.41152763], [72.9070816, 18.41430473], [72.90736389, 18.41430473], [72.90736389, 18.41458321], [72.90763855, 18.41457939], [72.90763855, 18.41570091], [72.90736389, 18.41569519], [72.90736389, 18.41597176], [72.90680695, 18.41596985], [72.90680695, 18.41624832], [72.90651703, 18.41624832], [72.90651703, 18.41680908], [72.90625, 18.41680908], [72.90625, 18.4173584], [72.90651703, 18.4173584], [72.90651703, 18.41764069], [72.90680695, 18.41764069], [72.90680695, 18.4173584], [72.9070816, 18.4173584], [72.9070816, 18.41764069], [72.90763855, 18.41764069], [72.90763855, 18.41819954], [72.90791321, 18.41819382], [72.90791321, 18.41847038], [72.90820313, 18.41847038], [72.90820313, 18.41903114], [72.90847015, 18.41903114], [72.90847015, 18.41986275], [72.90875244, 18.41986275], [72.90875244, 18.42069435], [72.90901947, 18.42069054], [72.90901947, 18.42181015], [72.90875244, 18.42180634], [72.90875244, 18.42236137], [72.90847015, 18.42236137], [72.90847015, 18.42319489], [72.9081955, 18.42319489], [72.90820313, 18.42374992], [72.90735626, 18.42374992], [72.90735626, 18.4240303], [72.9070816, 18.4240303], [72.9070816, 18.42432022], [72.90680695, 18.42430687], [72.90680695, 18.42458344], [72.90651703, 18.42457962], [72.90651703, 18.42514038], [72.90625, 18.42513847], [72.90625, 18.4256897], [72.90598297, 18.42570114], [72.90598297, 18.42681122], [72.90569305, 18.42681122], [72.90569305, 18.42736053], [72.9054184, 18.42736053], [72.9054184, 18.42764091], [72.90486145, 18.42764091], [72.90486145, 18.42791748], [72.9043045, 18.42791748], [72.9043045, 18.42819405], [72.90402985, 18.42819023], [72.90402985, 18.43014145], [72.9043045, 18.43014145], [72.9043045, 18.43069458], [72.90458679, 18.43069458], [72.90458679, 18.43097305], [72.90486145, 18.43096924], [72.90486145, 18.43125153], [72.90513611, 18.43125153], [72.90513611, 18.43151093], [72.90513611, 18.43180466], [72.90569305, 18.43180466], [72.90569305, 18.43208122], [72.9061203, 18.43207932], [72.90625, 18.43207932], [72.90625, 18.43292046], [72.90651703, 18.43292046], [72.90651703, 18.43514061], [72.90625, 18.43514061], [72.90625, 18.43653107], [72.90597534, 18.43652725], [72.90598297, 18.43736076], [72.90569305, 18.43736076], [72.90569305, 18.43902969], [72.9054184, 18.43902779], [72.9054184, 18.44097137], [72.90513611, 18.44096947], [72.90513611, 18.44152832], [72.90486145, 18.44152641], [72.90486145, 18.44208336], [72.90458679, 18.44207954], [72.90458679, 18.44292068], [72.9043045, 18.44291687], [72.9043045, 18.44347191], [72.90402985, 18.44346809], [72.90402985, 18.44374847], [72.90374756, 18.44374847], [72.90374756, 18.44403076], [72.9034729, 18.44402695], [72.9034729, 18.44597244], [72.90319824, 18.44597244], [72.90320587, 18.44625282], [72.90291595, 18.44625282], [72.90291595, 18.44652939], [72.9026413, 18.44652748], [72.9026413, 18.44708061], [72.90235901, 18.44708061], [72.90235901, 18.4481945], [72.90207672, 18.44818115], [72.90207672, 18.44902992], [72.90180206, 18.44902802], [72.90180206, 18.44958305], [72.9015274, 18.44958115], [72.9015274, 18.45014], [72.90125275, 18.45014], [72.90125275, 18.45153046], [72.90097046, 18.45153046], [72.90097046, 18.45181084], [72.9006958, 18.45180511], [72.9006958, 18.45236206], [72.90041351, 18.45236206], [72.90041351, 18.45319366], [72.90014648, 18.45318985], [72.90014648, 18.45403099], [72.89985657, 18.45403099], [72.89985657, 18.45486069], [72.89958191, 18.45486069], [72.89958191, 18.45541954], [72.89930725, 18.45541954], [72.89930725, 18.4556942], [72.89902496, 18.4556942], [72.89902496, 18.45597267], [72.89875031, 18.45597076], [72.89875031, 18.45624924], [72.89848328, 18.45624924], [72.89848328, 18.4568119], [72.89819336, 18.45680618], [72.89819336, 18.45708275], [72.8979187, 18.45708084], [72.8979187, 18.45737267], [72.89763641, 18.45737267], [72.89763641, 18.45792007], [72.89624786, 18.45792007], [72.89624786, 18.4576416], [72.89569092, 18.4576416], [72.89569092, 18.45737267], [72.89541626, 18.45737267], [72.89541626, 18.45708084], [72.89458466, 18.45708275], [72.89458466, 18.45819473], [72.89485931, 18.45819092], [72.89485931, 18.46375084], [72.8951416, 18.46375084], [72.8951416, 18.46486092], [72.89541626, 18.46486092], [72.89541626, 18.4679203], [72.89569092, 18.46791649], [72.89569092, 18.47097015], [72.89541626, 18.47096825], [72.89541626, 18.4726429], [72.89597321, 18.4726429], [72.89597321, 18.47291946], [72.89624786, 18.47291756], [72.89624786, 18.47319412], [72.89680481, 18.47319412], [72.89680481, 18.47291756], [72.89707947, 18.47291946], [72.89707947, 18.4726429], [72.89736176, 18.4726429], [72.89736176, 18.47237015], [72.89819336, 18.47237015], [72.89819336, 18.4726429], [72.89848328, 18.4726429], [72.89848328, 18.47291946], [72.89902496, 18.47291756], [72.89902496, 18.47319412], [72.89958191, 18.47319412], [72.89958191, 18.4734726], [72.89985657, 18.4734726], [72.89985657, 18.47402954], [72.90013885, 18.47402763], [72.90013885, 18.47458458], [72.90041351, 18.47458458], [72.90041351, 18.47569466], [72.9006958, 18.47569084], [72.9006958, 18.47624969], [72.90125275, 18.47624969], [72.90125275, 18.47820091], [72.90097046, 18.47820091], [72.90097046, 18.47875023], [72.90125275, 18.47875023], [72.90125275, 18.47903061], [72.90097046, 18.4790287], [72.90097046, 18.47958374], [72.90125275, 18.47957993], [72.90125275, 18.47986031], [72.9015274, 18.47986031], [72.9015274, 18.48291969], [72.90125275, 18.48291969], [72.90125275, 18.48764038], [72.90097046, 18.48764038], [72.90097046, 18.48792076], [72.9006958, 18.48792076], [72.9006958, 18.48986053], [72.90097046, 18.48986053], [72.90097046, 18.49097252], [72.90125275, 18.49097252], [72.90125275, 18.4920826], [72.9015274, 18.49208069], [72.9015274, 18.49291992], [72.90180206, 18.49291992], [72.90180206, 18.49348068], [72.90291595, 18.49348068], [72.90291595, 18.49374962], [72.90319824, 18.49374962], [72.90319824, 18.49430466], [72.9034729, 18.49430466], [72.9034729, 18.49458313], [72.90374756, 18.49458122], [72.90374756, 18.49570084], [72.90402985, 18.49570084], [72.90402985, 18.49791908], [72.90374756, 18.49791908], [72.90374756, 18.49875259], [72.9034729, 18.49875259], [72.9034729, 18.49930954], [72.90374756, 18.49930954], [72.90374756, 18.49986267], [72.90402985, 18.49986267], [72.90402985, 18.50152969], [72.9043045, 18.50152779], [72.9043045, 18.50208473], [72.90458679, 18.50208282], [72.90458679, 18.50263977], [72.90486145, 18.50263977], [72.90486145, 18.50292015], [72.90513611, 18.50291634], [72.90513611, 18.50319481], [72.9054184, 18.50319481], [72.9054184, 18.50347137], [72.90597534, 18.50347137], [72.90597534, 18.50374985], [72.90625, 18.50374985], [72.90625, 18.50403023], [72.90763855, 18.50403023], [72.90763855, 18.5031929], [72.9090271, 18.50319481], [72.9090271, 18.50347137], [72.9098587, 18.50347137], [72.9098587, 18.50291634], [72.91069794, 18.50291634], [72.91069794, 18.50319481], [72.91124725, 18.5031929], [72.91124725, 18.50403023], [72.90958405, 18.50402832], [72.90958405, 18.50430679], [72.9098587, 18.50430679], [72.9098587, 18.50458336], [72.91069794, 18.50457954], [72.91069794, 18.5051403], [72.9109726, 18.5051403], [72.9109726, 18.50570107], [72.91124725, 18.50570107], [72.91124725, 18.50930977], [72.9109726, 18.50930977], [72.9109726, 18.51014137], [72.91069794, 18.51014137], [72.91069794, 18.51097107], [72.91041565, 18.51097107], [72.91042328, 18.51180077], [72.91069794, 18.5118103], [72.91069794, 18.51264191], [72.91042328, 18.51264191], [72.91042328, 18.51292038], [72.91014099, 18.51292038], [72.91014099, 18.51320076], [72.91041565, 18.51319504], [72.91041565, 18.51486015], [72.91069794, 18.51486206], [72.91069794, 18.51569366], [72.9109726, 18.51568985], [72.9109726, 18.51653099], [72.91124725, 18.51652718], [72.91124725, 18.5181942], [72.9109726, 18.5181942], [72.9109726, 18.51958275], [72.91124725, 18.51958084], [72.91124725, 18.52124977], [72.9109726, 18.52124977], [72.9109726, 18.52180481], [72.91069794, 18.52180099], [72.91069794, 18.52292061], [72.9109726, 18.52292061], [72.9109726, 18.52319908], [72.91124725, 18.52319527], [72.91124725, 18.52347183], [72.9109726, 18.52347183], [72.9109726, 18.52458382], [72.91069794, 18.52457809], [72.91069794, 18.52542114], [72.91014099, 18.52541733], [72.91014099, 18.52708054], [72.9098587, 18.52708054], [72.9098587, 18.52791977], [72.90957642, 18.52791977], [72.90957642, 18.52902985], [72.90930939, 18.52902985], [72.90930176, 18.53013992], [72.90901947, 18.53013992], [72.90901947, 18.5304203], [72.90875244, 18.53041649], [72.90875244, 18.53097153], [72.90847015, 18.53096962], [72.90847015, 18.53181076], [72.9081955, 18.53180695], [72.9081955, 18.53208351], [72.90791321, 18.53208351], [72.90791321, 18.53236198], [72.90763855, 18.53236008], [72.90763855, 18.53292084], [72.9070816, 18.53291512], [72.9070816, 18.53319359], [72.90736389, 18.53319359], [72.90736389, 18.53347206], [72.9070816, 18.53347015], [72.9070816, 18.53403091], [72.90680695, 18.5340271], [72.90680695, 18.53458405], [72.90651703, 18.53458023], [72.90651703, 18.53513908], [72.90625, 18.53513908], [72.90625, 18.53652763], [72.90598297, 18.53652763], [72.90598297, 18.53681183], [72.90458679, 18.53681183], [72.90458679, 18.53735924], [72.9043045, 18.53735924], [72.9043045, 18.53847313], [72.90458679, 18.53847313], [72.90458679, 18.53930473], [72.90513611, 18.53930473], [72.90513611, 18.5395813], [72.9054184, 18.53957939], [72.9054184, 18.54014015], [72.90569305, 18.54013824], [72.90569305, 18.54097366], [72.90625, 18.54096985], [72.90625, 18.54125023], [72.9070816, 18.54125023], [72.9070816, 18.54096985], [72.90736389, 18.54097366], [72.90736389, 18.54069519], [72.90763855, 18.54070282], [72.90763855, 18.54014015], [72.90791321, 18.54014015], [72.90791321, 18.53957939], [72.9081955, 18.5395813], [72.9081955, 18.53902817], [72.90847015, 18.53903008], [72.90847015, 18.5387516], [72.90875244, 18.5387516], [72.90875244, 18.53819084], [72.9090271, 18.53819466], [72.9090271, 18.53764153], [72.90930176, 18.53764153], [72.90930176, 18.53735924], [72.90957642, 18.53735924], [72.90957642, 18.53624916], [72.9098587, 18.53624916], [72.9098587, 18.53541756], [72.91014099, 18.53541756], [72.91014099, 18.53486061], [72.91042328, 18.53486061], [72.91041565, 18.53375053], [72.91069794, 18.53375053], [72.91069794, 18.53153038], [72.9109726, 18.53153038], [72.9109726, 18.53096962], [72.91124725, 18.53097153], [72.91124725, 18.53041649], [72.91152954, 18.5304203], [72.91152954, 18.53013992], [72.91208649, 18.53013992], [72.91208649, 18.52985954], [72.91402435, 18.52986145], [72.91402435, 18.52958488], [72.9145813, 18.52959061], [72.9145813, 18.52931023], [72.91514587, 18.52931023], [72.91514587, 18.52902985], [72.91654968, 18.52902985], [72.9173584, 18.52902985], [72.9173584, 18.52931023], [72.91764069, 18.52931023], [72.91764069, 18.52959061], [72.91791534, 18.52958488], [72.91791534, 18.52986145], [72.91847229, 18.52985954], [72.91847229, 18.53013992], [72.91874695, 18.53013992], [72.91874695, 18.5304203], [72.91902924, 18.5304203], [72.91902924, 18.53070068], [72.91930389, 18.53069305], [72.91930389, 18.53097153], [72.91986084, 18.53096962], [72.91986084, 18.53125], [72.92124939, 18.53125], [72.92124939, 18.53153038], [72.92236328, 18.53153038], [72.92236328, 18.53181076], [72.92263794, 18.53180695], [72.92263794, 18.53208351], [72.92292023, 18.53208351], [72.92292023, 18.53236198], [72.92318726, 18.53236008], [72.92318726, 18.53264809], [72.92345428, 18.53270531], [72.92346954, 18.53292084], [72.92458344, 18.53291512], [72.92458344, 18.53319359], [72.92485809, 18.53319359], [72.92485809, 18.53347206], [72.92514038, 18.53347015], [72.92514038, 18.53375053], [72.92624664, 18.53375053], [72.92624664, 18.53403091], [72.92652893, 18.53403091], [72.92652893, 18.53430939], [72.92679596, 18.53430939], [72.92679596, 18.53486061], [72.92708588, 18.53486061], [72.92708588, 18.53513908], [72.92791748, 18.53513908], [72.92791748, 18.53541756], [72.92874908, 18.53541756], [72.92874908, 18.53569412], [72.9284668, 18.53569031], [72.9284668, 18.54181099], [72.92819214, 18.54180527], [72.92819214, 18.54208374], [72.92791748, 18.54207993], [72.92791748, 18.54236031], [72.92764282, 18.54236031], [72.92764282, 18.54264069], [72.92736053, 18.54264069], [72.92736053, 18.54292107], [72.92708588, 18.54291725], [72.92708588, 18.54319572], [72.92680359, 18.54319572], [72.92680359, 18.54347229], [72.92652893, 18.54347038], [72.92652893, 18.54375076], [72.92624664, 18.54375076], [72.92624664, 18.54403114], [72.92542267, 18.54403114], [72.92542267, 18.54430962], [72.92514038, 18.54430962], [72.92514038, 18.54486084], [72.92457581, 18.54486084], [72.92457581, 18.54514122], [72.92430878, 18.54514122], [72.92430878, 18.54652977], [72.92402649, 18.54652977], [72.92402649, 18.54764748], [72.92375183, 18.54764748], [72.92375183, 18.55013847], [72.92346954, 18.55013847], [72.92346954, 18.55181122], [72.92318726, 18.55181122], [72.92318726, 18.55236244], [72.92292023, 18.55236244], [72.92292023, 18.55291939], [72.92263794, 18.55291748], [72.92263794, 18.55347252], [72.92236328, 18.55347252], [72.92236328, 18.55402946], [72.92208099, 18.55402756], [72.92208099, 18.55458069], [72.92180634, 18.55458069], [72.92180634, 18.55513954], [72.92152405, 18.55513954], [72.92152405, 18.55569458], [72.92124939, 18.55569077], [72.92124939, 18.55653], [72.92097473, 18.55652809], [72.92097473, 18.5573616], [72.92069244, 18.5573597], [72.92069244, 18.55792046], [72.92041779, 18.55792046], [72.92041779, 18.55986023], [72.92014313, 18.55986023], [72.92014313, 18.56014061], [72.91986084, 18.56014061], [72.91986084, 18.56042099], [72.91958618, 18.56041527], [72.91958618, 18.56097221], [72.91929626, 18.56097031], [72.91929626, 18.56125069], [72.91902924, 18.56125069], [72.91902924, 18.56153107], [72.91874695, 18.56153107], [72.91874695, 18.56180954], [72.91847229, 18.56180954], [72.91847229, 18.56236076], [72.91819763, 18.56236076], [72.91819763, 18.56263733], [72.91791534, 18.56263733], [72.91791534, 18.56319427], [72.91764069, 18.56319427], [72.91764069, 18.56347275], [72.9173584, 18.56347084], [72.9173584, 18.5640316], [72.91707611, 18.5640316], [72.91707611, 18.56514168], [72.91680908, 18.56514168], [72.91680908, 18.56542015], [72.91652679, 18.56541634], [72.91652679, 18.56596947], [72.91625214, 18.56596947], [72.91625214, 18.56625175], [72.91596985, 18.56625175], [72.91596985, 18.56680489], [72.91569519, 18.56680489], [72.91569519, 18.56736374], [72.9154129, 18.56736183], [72.9154129, 18.5676403], [72.91514587, 18.5676403], [72.91514587, 18.56820107], [72.91485596, 18.56820107], [72.91485596, 18.56875992], [72.9145813, 18.56875038], [72.9145813, 18.5695858], [72.91430664, 18.56958008], [72.91430664, 18.57042122], [72.91402435, 18.5704174], [72.91402435, 18.57097244], [72.91374969, 18.57097054], [72.91374969, 18.57125092], [72.91348267, 18.57125092], [72.91348267, 18.57182121], [72.91319275, 18.57180405], [72.91319275, 18.57208252], [72.91291809, 18.57208061], [72.91291809, 18.57236099], [72.9126358, 18.57236099], [72.9126358, 18.57263947], [72.91236115, 18.57263947], [72.91236115, 18.5731945], [72.91208649, 18.5731945], [72.91208649, 18.57347298], [72.9118042, 18.57347298], [72.9118042, 18.57458305], [72.91152954, 18.5745697], [72.91152954, 18.57570076], [72.91124725, 18.57570076], [72.91124725, 18.57681084], [72.9109726, 18.57681084], [72.9109726, 18.57792091], [72.91069794, 18.5779171], [72.91069794, 18.57847023], [72.91041565, 18.57847023], [72.91042328, 18.57875252], [72.90930939, 18.57875252], [72.90930176, 18.57930946], [72.90901947, 18.57930946], [72.90901947, 18.57986259], [72.90875244, 18.57986259], [72.90875244, 18.58069992], [72.90847015, 18.58069992], [72.90847015, 18.58125114], [72.90820313, 18.58125114], [72.90820313, 18.58376122], [72.90847015, 18.58376122], [72.90847015, 18.58403015], [72.90875244, 18.58402824], [72.90875244, 18.58458328], [72.9090271, 18.58458328], [72.9090271, 18.58486176], [72.90930176, 18.58485985], [72.90930176, 18.58499908], [72.90930939, 18.58514023], [72.9098587, 18.58514023], [72.9098587, 18.58542061], [72.91014099, 18.58541679], [72.91014099, 18.58597183], [72.9098587, 18.58596992], [72.9098587, 18.58625031], [72.9081955, 18.58625031], [72.9081955, 18.58597183], [72.90763855, 18.58597183], [72.90763855, 18.58569527], [72.90735626, 18.58570099], [72.90735626, 18.58542061], [72.9070816, 18.58542061], [72.9070816, 18.58570099], [72.90652466, 18.58569527], [72.90652466, 18.58597183], [72.90625, 18.58596992], [72.90625, 18.58625031], [72.90569305, 18.58625031], [72.90569305, 18.58680534], [72.9054184, 18.58679962], [72.9054184, 18.58736038], [72.90513611, 18.58736038], [72.90513611, 18.58847237], [72.90486145, 18.58847046], [72.90486145, 18.58903122], [72.90458679, 18.58903122], [72.90458679, 18.58986092], [72.90429688, 18.58986092], [72.90429688, 18.59042168], [72.90402985, 18.59041595], [72.90402985, 18.59069443], [72.90374756, 18.59069061], [72.90374756, 18.59124947], [72.9034729, 18.59124947], [72.9034729, 18.59153175], [72.90320587, 18.59153175], [72.90320587, 18.59181023], [72.90291595, 18.59181023], [72.90291595, 18.59264183], [72.9026413, 18.59264183], [72.9026413, 18.59320068], [72.90235901, 18.59320068], [72.90235901, 18.59403038], [72.90207672, 18.59403038], [72.90207672, 18.59431076], [72.90180206, 18.59430504], [72.90180206, 18.59597206], [72.9015274, 18.59597015], [72.9015274, 18.59625053], [72.90125275, 18.59625053], [72.90125275, 18.59653091], [72.90097046, 18.59653091], [72.90097046, 18.59736061], [72.9006958, 18.59736061], [72.9006958, 18.59819412], [72.90041351, 18.59819412], [72.90041351, 18.5984726], [72.90014648, 18.59847069], [72.90014648, 18.59902954], [72.89985657, 18.59902954], [72.89985657, 18.59986115], [72.89958191, 18.59986115], [72.89958191, 18.60124969], [72.89930725, 18.60124969], [72.89930725, 18.60152817], [72.89902496, 18.60152626], [72.89902496, 18.60180473], [72.89847565, 18.60180473], [72.89847565, 18.60236168], [72.89819336, 18.60235977], [72.89819336, 18.60320091], [72.8979187, 18.60319519], [72.8979187, 18.60347176], [72.89763641, 18.60346985], [72.89763641, 18.60403061], [72.89736176, 18.60403061], [72.89736176, 18.60487175], [72.89707947, 18.60487175], [72.89707947, 18.60542107], [72.89678955, 18.60542107], [72.89678955, 18.60625267], [72.89653015, 18.60625267], [72.89653015, 18.60653114], [72.89624786, 18.60653114], [72.89624786, 18.60680962], [72.89597321, 18.60680962], [72.89597321, 18.60736275], [72.89569092, 18.60736275], [72.89569092, 18.60819435], [72.89541626, 18.60819435], [72.89541626, 18.60847473], [72.8951416, 18.60847282], [72.8951416, 18.60902977], [72.89485931, 18.60902977], [72.89485931, 18.61042023], [72.89457703, 18.61042023], [72.89457703, 18.61124992], [72.89430237, 18.61124992], [72.89430237, 18.61208344], [72.89402771, 18.61208344], [72.89402771, 18.61236191], [72.89375305, 18.61236], [72.89375305, 18.61264038], [72.89347076, 18.61264038], [72.89347076, 18.61292076], [72.89319611, 18.61291695], [72.89319611, 18.61347198], [72.89291382, 18.61347198], [72.89291382, 18.61375046], [72.89263916, 18.61374092], [72.89263916, 18.61431122], [72.89235687, 18.61431122], [72.89235687, 18.61514091], [72.89208221, 18.61514091], [72.89208221, 18.61541748], [72.89180756, 18.61541748], [72.89180756, 18.61597252], [72.89125061, 18.61597061], [72.89125061, 18.61624908], [72.89097595, 18.61624908], [72.89097595, 18.61735916], [72.89068604, 18.61735916], [72.89068604, 18.61792183], [72.89041901, 18.61791611], [72.89041901, 18.61847115], [72.89013672, 18.61846924], [72.89013672, 18.61903191], [72.88986206, 18.61902809], [72.88986206, 18.61930466], [72.88931274, 18.61930084], [72.88931274, 18.61987114], [72.88874817, 18.61987114], [72.88874817, 18.62014008], [72.88846588, 18.62014008], [72.88846588, 18.62042046], [72.88819122, 18.62041664], [72.88819122, 18.62097359], [72.88791656, 18.62096977], [72.88791656, 18.62153053], [72.88764191, 18.62153053], [72.88764191, 18.62264061], [72.88735962, 18.6226387], [72.88735962, 18.62291718], [72.88707733, 18.62290955], [72.88707733, 18.62375069], [72.88680267, 18.62375069], [72.88680267, 18.6245842], [72.88652802, 18.62458038], [72.88652802, 18.62486076], [72.88625336, 18.62486076], [72.88625336, 18.62541962], [72.88597107, 18.6254158], [72.88597107, 18.62597275], [72.88569641, 18.62597084], [72.88569641, 18.62625122], [72.88540649, 18.62625122], [72.88540649, 18.62763977], [72.88513947, 18.62763977], [72.88513947, 18.62986183], [72.88484955, 18.62985992], [72.88484955, 18.63264275], [72.88458252, 18.63264084], [72.88458252, 18.63458061], [72.88430786, 18.63458061], [72.88430786, 18.63513947], [72.88402557, 18.63513947], [72.88402557, 18.6384716], [72.88486481, 18.6384716], [72.88486481, 18.63819695], [72.88735962, 18.63820076], [72.88735962, 18.63791084], [72.88791656, 18.63791656], [72.88791656, 18.63763809], [72.88846588, 18.63764], [72.88846588, 18.63735962], [72.88903046, 18.63736153], [72.88903046, 18.63708305], [72.89111328, 18.63708305], [72.89125061, 18.63708305], [72.89125061, 18.63652802], [72.8915329, 18.63652992], [72.8915329, 18.63624954], [72.89180756, 18.63624954], [72.89180756, 18.63597107], [72.89208221, 18.63597488], [72.89208221, 18.6356945], [72.89597321, 18.6356945], [72.89597321, 18.63541603], [72.89707947, 18.63541985], [72.89707947, 18.63484955], [72.89736176, 18.6348629], [72.89736176, 18.63430595], [72.89763641, 18.63430977], [72.89763641, 18.63375282], [72.8979187, 18.63375282], [72.8979187, 18.63257027], [72.8979187, 18.63208389], [72.89819336, 18.63208389], [72.89819336, 18.63041687], [72.89848328, 18.63042068], [72.89848328, 18.62957954], [72.89930725, 18.62958336], [72.89930725, 18.62986183], [72.90040588, 18.62985992], [72.90040588, 18.6301384], [72.9006958, 18.6301384], [72.9006958, 18.63069916], [72.90097046, 18.63069916], [72.90097046, 18.63124847], [72.90125275, 18.63124847], [72.90125275, 18.63181114], [72.9015274, 18.63181114], [72.9015274, 18.63236237], [72.90180206, 18.63236237], [72.90180206, 18.63264275], [72.9015274, 18.63264084], [72.9015274, 18.63319206], [72.90125275, 18.63319206], [72.90125275, 18.63347054], [72.90097046, 18.63347054], [72.90097046, 18.63402939], [72.9006958, 18.63402939], [72.9006958, 18.63430977], [72.90041351, 18.63430595], [72.90041351, 18.63458061], [72.90013885, 18.63458061], [72.90013885, 18.6348629], [72.89985657, 18.63484955], [72.89985657, 18.63513947], [72.89958191, 18.63513947], [72.89958191, 18.63541985], [72.89930725, 18.63541603], [72.89930725, 18.6356945], [72.89875031, 18.6356945], [72.89875031, 18.63597488], [72.89819336, 18.63597107], [72.89819336, 18.63624954], [72.89678955, 18.63624954], [72.89678955, 18.63652992], [72.89653015, 18.63652992], [72.89653015, 18.6368103], [72.89597321, 18.63680649], [72.89597321, 18.63708305], [72.89569092, 18.63708305], [72.89569092, 18.63736153], [72.8951416, 18.63735962], [72.8951416, 18.63764], [72.89430237, 18.63763809], [72.89430237, 18.63791656], [72.89375305, 18.63791656], [72.89375305, 18.63804054], [72.89375305, 18.63820076], [72.89291382, 18.63819695], [72.89291382, 18.6384716], [72.89235687, 18.6384697], [72.89235687, 18.63875008], [72.89180756, 18.63875008], [72.89180756, 18.63903046], [72.89125061, 18.63903046], [72.89125061, 18.63931084], [72.89069366, 18.63930511], [72.89069366, 18.63958359], [72.89013672, 18.63958359], [72.89013672, 18.63986206], [72.88957977, 18.63986015], [72.88957977, 18.64014053], [72.88903046, 18.64014053], [72.88903046, 18.64042091], [72.88847351, 18.64041519], [72.88847351, 18.64069366], [72.88791656, 18.64069366], [72.88791656, 18.64097214], [72.88735962, 18.64097023], [72.88735962, 18.64125061], [72.88430786, 18.64125061], [72.88430786, 18.64097023], [72.88375092, 18.64097214], [72.88375092, 18.64069366], [72.88346863, 18.64069366], [72.88346863, 18.64041519], [72.88291931, 18.64042091], [72.88291931, 18.63903046], [72.88273621, 18.63903046], [72.88263702, 18.63902855], [72.88263702, 18.63820076], [72.88236237, 18.63820076], [72.88236237, 18.63764], [72.88208008, 18.63764], [72.88208008, 18.63735962], [72.87763977, 18.63735962], [72.87763977, 18.63764], [72.87735748, 18.63763809], [72.87735748, 18.63791656], [72.87708282, 18.63791656], [72.87708282, 18.63763809], [72.87652588, 18.63763809], [72.87652588, 18.63791656], [72.87597656, 18.63791084], [72.87597656, 18.63820076], [72.87513733, 18.63819695], [72.87513733, 18.6384716], [72.87264252, 18.6384697], [72.87264252, 18.63875008], [72.8720932, 18.63875008], [72.8720932, 18.63903046], [72.87152863, 18.63903046], [72.87152863, 18.63931084], [72.87097168, 18.63930511], [72.87097168, 18.63958359], [72.8704071, 18.63957977], [72.8704071, 18.64014053], [72.87014008, 18.64013863], [72.87014008, 18.64097214], [72.86985016, 18.64097023], [72.86985016, 18.64152908], [72.86958313, 18.64152908], [72.86958313, 18.64236069], [72.86930847, 18.64236069], [72.86930847, 18.64291763], [72.86902618, 18.64291763], [72.86902618, 18.6431942], [72.86875153, 18.64319038], [72.86875153, 18.64374924], [72.86846924, 18.64374924], [72.86846924, 18.6443119], [72.86818695, 18.6443119], [72.86818695, 18.6451416], [72.86791992, 18.6451416], [72.86791992, 18.64542007], [72.86763763, 18.64541626], [72.86763763, 18.64596939], [72.86736298, 18.64596939], [72.86736298, 18.64625168], [72.86708069, 18.64625168], [72.86708069, 18.64653015], [72.86680603, 18.64652824], [72.86680603, 18.64708138], [72.86653137, 18.64707947], [72.86653137, 18.64764023], [72.86624908, 18.64764023], [72.86624908, 18.6482029], [72.8659668, 18.6482029], [72.8659668, 18.64903069], [72.86569214, 18.64903069], [72.86569214, 18.65014076], [72.86541748, 18.65014076], [72.86541748, 18.65153122], [72.86513519, 18.6515274], [72.86513519, 18.65291786], [72.86486053, 18.65291023], [72.86486053, 18.65402985], [72.86458588, 18.65402985], [72.86458588, 18.65513992], [72.86429596, 18.65513992], [72.86430359, 18.65624809], [72.86402893, 18.65624809], [72.86402893, 18.65736008], [72.86374664, 18.65736008], [72.86374664, 18.65847015], [72.86347198, 18.65847015], [72.86347198, 18.66069221], [72.86319733, 18.66069221], [72.86319733, 18.66347313], [72.86347198, 18.66347122], [72.86347198, 18.66542053], [72.86374664, 18.66542053], [72.86374664, 18.66681099], [72.86402893, 18.66680527], [72.86402893, 18.66736031], [72.86430359, 18.66736031], [72.86430359, 18.66819382], [72.86458588, 18.66819], [72.86458588, 18.66875076], [72.86429596, 18.66875076], [72.86429596, 18.66930962], [72.86402893, 18.6693058], [72.86403656, 18.66986084], [72.86374664, 18.66986084], [72.86374664, 18.6704216], [72.86347198, 18.6704216], [72.86347198, 18.67098045], [72.86319733, 18.67098045], [72.86319733, 18.67181015], [72.86292267, 18.67181015], [72.86292267, 18.67264175], [72.86264038, 18.67264175], [72.86264038, 18.67375183], [72.86235809, 18.67375183], [72.86235809, 18.67458344], [72.86207581, 18.67457962], [72.86207581, 18.67542076], [72.86180878, 18.67542076], [72.86180878, 18.67653084], [72.86152649, 18.67653084], [72.86152649, 18.67791939], [72.86125183, 18.67791748], [72.86125183, 18.6795826], [72.86096954, 18.67958069], [72.86096954, 18.68124962], [72.86067963, 18.68124962], [72.86067963, 18.68321037], [72.86042023, 18.68321037], [72.86042023, 18.6854229], [72.86013794, 18.6854229], [72.86013794, 18.68764114], [72.85986328, 18.68763924], [72.85986328, 18.68958473], [72.85958099, 18.68958473], [72.85958099, 18.69069481], [72.85930634, 18.69069099], [72.85930634, 18.69124985], [72.85902405, 18.69124985], [72.85902405, 18.69180679], [72.85874939, 18.69180679], [72.85874939, 18.69236183], [72.8584671, 18.69235992], [72.8584671, 18.69292068], [72.85819244, 18.69292068], [72.85819244, 18.69320107], [72.8576355, 18.69319534], [72.8576355, 18.69347191], [72.85736084, 18.69347], [72.85736084, 18.69375038], [72.85708618, 18.69375038], [72.85708618, 18.69403076], [72.85680389, 18.69402695], [72.85680389, 18.69458389], [72.85652924, 18.69458008], [72.85652924, 18.69486046], [72.85624695, 18.69486046], [72.85624695, 18.69514847], [72.85597229, 18.69513893], [72.85597229, 18.69569397], [72.85569763, 18.69569397], [72.85569763, 18.69597244], [72.85542297, 18.69597054], [72.85542297, 18.69680977], [72.85514069, 18.69680977], [72.85514069, 18.69735909], [72.85569763, 18.69735909], [72.85569763, 18.6981945], [72.85597229, 18.69819069], [72.85597229, 18.69903183], [72.85624695, 18.69902992], [72.85624695, 18.69958115], [72.85652924, 18.69957924], [72.85652924, 18.70042038], [72.85680389, 18.70041656], [72.85680389, 18.70097351], [72.85708618, 18.70097351], [72.85708618, 18.70069504], [72.85736084, 18.70069504], [72.85736084, 18.70097351], [72.85791016, 18.70096016], [72.85791016, 18.70153046], [72.85819244, 18.70152855], [72.85819244, 18.70208359], [72.8584671, 18.70207977], [72.8584671, 18.70264053], [72.85874939, 18.70263863], [72.85874939, 18.70319557], [72.85902405, 18.70319557], [72.85902405, 18.70347214], [72.85930634, 18.70347023], [72.85930634, 18.70403099], [72.85958099, 18.70402718], [72.85958099, 18.70458412], [72.85986328, 18.70458031], [72.85986328, 18.70514107], [72.86013794, 18.70513916], [72.86013794, 18.7056942], [72.86042023, 18.70569038], [72.86042023, 18.70709038], [72.86067963, 18.70709038], [72.86067963, 18.70874977], [72.86096954, 18.70874977], [72.86096954, 18.70958328], [72.86125183, 18.70957947], [72.86125183, 18.71042061], [72.86152649, 18.71042061], [72.86152649, 18.7112484], [72.86180878, 18.7112484], [72.86180878, 18.71236038], [72.86208344, 18.71236038], [72.86208344, 18.71347046], [72.86235809, 18.71347046], [72.86235809, 18.71458054], [72.86264038, 18.71458054], [72.86264038, 18.71569443], [72.86292267, 18.71569061], [72.86292267, 18.71681023], [72.86319733, 18.71681023], [72.86319733, 18.7179203], [72.86347198, 18.7179203], [72.86347198, 18.71903038], [72.86374664, 18.71903038], [72.86374664, 18.72014046], [72.86402893, 18.72013855], [72.86402893, 18.72125053], [72.86429596, 18.72125053], [72.86429596, 18.73180962], [72.86402893, 18.7318058], [72.86402893, 18.7345829], [72.86374664, 18.7345829], [72.86374664, 18.73569489], [72.86347198, 18.73569107], [72.86347198, 18.7365284], [72.86319733, 18.7365284], [72.86319733, 18.73763847], [72.86291504, 18.73763847], [72.86291504, 18.73847008], [72.86264038, 18.73846817], [72.86264038, 18.73931122], [72.86235809, 18.73931122], [72.86235809, 18.7432003], [72.86264038, 18.74319458], [72.86264038, 18.74430466], [72.86292267, 18.74430084], [72.86292267, 18.74542046], [72.86319733, 18.74542046], [72.86319733, 18.74653053], [72.86347198, 18.74653053], [72.86347198, 18.74764061], [72.86374664, 18.74764061], [72.86374664, 18.74875069], [72.86402893, 18.74875069], [72.86402893, 18.74930573], [72.86429596, 18.7492981], [72.86429596, 18.75013924], [72.86458588, 18.75013924], [72.86458588, 18.7515316], [72.86486053, 18.75152779], [72.86486053, 18.75319481], [72.86513519, 18.75319481], [72.86513519, 18.75458145], [72.86541748, 18.75457954], [72.86541748, 18.75543022], [72.86569214, 18.75543022], [72.86569214, 18.75625038], [72.8659668, 18.75625038], [72.8659668, 18.75681114], [72.86680603, 18.75681114], [72.86680603, 18.75653076], [72.86708069, 18.75653076], [72.86708069, 18.75570107], [72.86736298, 18.75570107], [72.86736298, 18.75543022], [72.86791992, 18.75543022], [72.86791992, 18.75570107], [72.86818695, 18.75570107], [72.86818695, 18.75625038], [72.86791992, 18.75625038], [72.86791992, 18.75653076], [72.86763763, 18.75653076], [72.86763763, 18.75681114], [72.86736298, 18.75680542], [72.86736298, 18.7570858], [72.86708069, 18.75708008], [72.86708069, 18.75764084], [72.86680603, 18.75764084], [72.86680603, 18.75875092], [72.86624908, 18.75875092], [72.86624908, 18.75930977], [72.86597443, 18.75930405], [72.86597443, 18.75958252], [72.86569214, 18.75958061], [72.86569214, 18.76013947], [72.86541748, 18.76013947], [72.86541748, 18.7606945], [72.86513519, 18.7606945], [72.86513519, 18.76124954], [72.86486053, 18.76124001], [72.86486053, 18.76263809], [72.86458588, 18.76263809], [72.86458588, 18.76320076], [72.86486053, 18.76319504], [72.86486053, 18.76458359], [72.86458588, 18.76457977], [72.86458588, 18.7665329], [72.86429596, 18.7665329], [72.86429596, 18.76737022], [72.86541748, 18.76736259], [72.86541748, 18.76819229], [72.86513519, 18.76819229], [72.86513519, 18.76847458], [72.86486053, 18.76847267], [72.86486053, 18.76875114], [72.86458588, 18.76875114], [72.86458588, 18.76902962], [72.86429596, 18.76902962], [72.86429596, 18.76931], [72.86402893, 18.76930618], [72.86402893, 18.76958466], [72.86374664, 18.76958084], [72.86374664, 18.77013969], [72.86347198, 18.77013969], [72.86347198, 18.77069473], [72.86319733, 18.77069092], [72.86319733, 18.77124977], [72.86347198, 18.77124977], [72.86347198, 18.77264023], [72.86319733, 18.77263832], [72.86319733, 18.77347183], [72.86347198, 18.77346992], [72.86347198, 18.77403069], [72.86319733, 18.77402687], [72.86319733, 18.77458382], [72.86347198, 18.77458], [72.86347198, 18.77792168], [72.86319733, 18.77791595], [72.86319733, 18.7784729], [72.86347198, 18.7784729], [72.86347198, 18.77985954], [72.86319733, 18.77985954], [72.86319733, 18.7804203], [72.86347198, 18.7804203], [72.86347198, 18.78125191], [72.86374664, 18.78125191], [72.86374664, 18.78181076], [72.86347198, 18.78181076], [72.86347198, 18.78403091], [72.86319733, 18.78403091], [72.86319733, 18.78486061], [72.86347198, 18.78486061], [72.86347198, 18.79124832], [72.86374664, 18.79124832], [72.86374664, 18.79347038], [72.86403656, 18.79347038], [72.86403656, 18.79430962], [72.86429596, 18.79430962], [72.86429596, 18.79541969], [72.86458588, 18.79541588], [72.86458588, 18.79597473], [72.86486053, 18.79597282], [72.86486053, 18.79652977], [72.86514282, 18.79652977], [72.86514282, 18.79681015], [72.86653137, 18.79680634], [72.86653137, 18.79708481], [72.86708069, 18.79708481], [72.86708069, 18.79736137], [72.86736298, 18.79734993], [72.86736298, 18.79792023], [72.86763763, 18.79792023], [72.86763763, 18.79874992], [72.86791992, 18.79874992], [72.86791992, 18.80014038], [72.86818695, 18.80014038], [72.86818695, 18.80181122], [72.86846924, 18.80181122], [72.86846924, 18.80236053], [72.86875153, 18.80236053], [72.86875153, 18.80374908], [72.86902618, 18.80374908], [72.86902618, 18.80431175], [72.86930847, 18.80430603], [72.86930847, 18.8045826], [72.86958313, 18.8045826], [72.86958313, 18.80430603], [72.87069702, 18.80431175], [72.87069702, 18.80403137], [72.87097168, 18.80403137], [72.87097168, 18.80347824], [72.87124634, 18.80347824], [72.87124634, 18.80291748], [72.87152863, 18.80291748], [72.87152863, 18.80264091], [72.87180328, 18.80264091], [72.87180328, 18.80236053], [72.87236023, 18.80236053], [72.87236023, 18.80208015], [72.87319183, 18.80208397], [72.87319183, 18.8018055], [72.87680817, 18.8018055], [72.87680817, 18.80208397], [72.87725067, 18.80208206], [72.87763977, 18.80208015], [72.87763977, 18.80236053], [72.87847137, 18.80236053], [72.87847137, 18.80264091], [72.87903595, 18.80264091], [72.87903595, 18.80291748], [72.87930298, 18.80291748], [72.87930298, 18.80319405], [72.87985992, 18.80319023], [72.87985992, 18.80347824], [72.88041687, 18.80347824], [72.88041687, 18.80374908], [72.88069153, 18.80374908], [72.88069153, 18.80403137], [72.88124847, 18.80403137], [72.88124847, 18.80431175], [72.88153076, 18.80430603], [72.88153076, 18.8045826], [72.88208008, 18.80458069], [72.88208008, 18.80485916], [72.88263702, 18.80485916], [72.88263702, 18.80431175], [72.88291931, 18.80431175], [72.88291931, 18.80403137], [72.88597107, 18.80403137], [72.88597107, 18.80374908], [72.88707733, 18.80374908], [72.88707733, 18.80347824], [72.88764191, 18.80347824], [72.88764191, 18.80291748], [72.88791656, 18.80291748], [72.88791656, 18.80208015], [72.88764191, 18.80208397], [72.88764191, 18.80152893], [72.88735962, 18.80153084], [72.88735962, 18.80125046], [72.88707733, 18.80125046], [72.88707733, 18.80070114], [72.88680267, 18.8006897], [72.88680267, 18.79986191], [72.88708496, 18.79986191], [72.88708496, 18.7997303], [72.88708496, 18.79958344], [72.88735962, 18.79958344], [72.88735962, 18.79819679], [72.88819122, 18.79819107], [72.88819122, 18.79874992], [72.89180756, 18.79874992], [72.89180756, 18.7990303], [72.89263916, 18.7990303], [72.89263916, 18.79931068], [72.89319611, 18.79930687], [72.89319611, 18.79958344], [72.89402771, 18.79958344], [72.89402771, 18.79986191], [72.89457703, 18.79986], [72.89457703, 18.80014038], [72.8951416, 18.80013847], [72.8951416, 18.80041695], [72.89541626, 18.80041695], [72.89541626, 18.80069351], [72.89597321, 18.80069351], [72.89597321, 18.80097198], [72.89653015, 18.80097008], [72.89653015, 18.80181122], [72.89707947, 18.80181122], [72.89707947, 18.80153084], [72.8979187, 18.80153084], [72.8979187, 18.80125046], [72.89819336, 18.80125046], [72.89819336, 18.80153084], [72.89847565, 18.80152893], [72.89847565, 18.80208397], [72.89875031, 18.80208397], [72.89875031, 18.80319405], [72.89901733, 18.80319023], [72.89901733, 18.80347824], [72.89958191, 18.80347824], [72.89958191, 18.80374908], [72.89985657, 18.80374908], [72.89985657, 18.80403137], [72.9006958, 18.80403137], [72.9006958, 18.80374908], [72.90097046, 18.80374908], [72.90097046, 18.80347824], [72.90125275, 18.80347824], [72.90125275, 18.80319023], [72.9015274, 18.80319405], [72.9015274, 18.80291748], [72.9026413, 18.80291748], [72.9026413, 18.80264091], [72.90291595, 18.80264091], [72.90291595, 18.80236053], [72.90319061, 18.80236053], [72.90320587, 18.80208015], [72.90374756, 18.80208397], [72.90374756, 18.8018055], [72.90402985, 18.80181122], [72.90402985, 18.80153084], [72.90429688, 18.80153084], [72.90429688, 18.80125046], [72.90458679, 18.80125046], [72.90458679, 18.80097008], [72.90486145, 18.80097198], [72.90486145, 18.80069351], [72.90513611, 18.80069351], [72.90513611, 18.80041695], [72.9054184, 18.80041695], [72.9054184, 18.79958344], [72.90569305, 18.79958344], [72.90569305, 18.79939079], [72.90569305, 18.79874992], [72.9054184, 18.79874992], [72.9054184, 18.79763985], [72.90513611, 18.79763985], [72.90513611, 18.79652977], [72.9054184, 18.79652977], [72.9054184, 18.79541969], [72.90569305, 18.79541969], [72.90569305, 18.79458046], [72.90625, 18.79458046], [72.90625, 18.7943058], [72.90651703, 18.79430962], [72.90651703, 18.79403114], [72.9070816, 18.79403114], [72.9070816, 18.79375267], [72.90763855, 18.79375267], [72.90763855, 18.79347038], [72.9081955, 18.79347038], [72.9081955, 18.79319382], [72.90847015, 18.79319382], [72.90847015, 18.79291725], [72.90901947, 18.79292107], [72.90901947, 18.79264259], [72.90957642, 18.79264259], [72.90957642, 18.79236031], [72.91069794, 18.79236031], [72.91069794, 18.79207993], [72.91430664, 18.79207993], [72.91430664, 18.79236031], [72.91512299, 18.79236031], [72.91625214, 18.79236031], [72.91625214, 18.79264259], [72.91680908, 18.79264259], [72.91680908, 18.79292107], [72.91708374, 18.79291725], [72.91708374, 18.79319382], [72.9173584, 18.79319382], [72.9173584, 18.79347038], [72.91791534, 18.79347038], [72.91791534, 18.79375267], [72.91821289, 18.79375267], [72.91821289, 18.79403114], [72.91847229, 18.79403114], [72.91847229, 18.79430962], [72.91902924, 18.7943058], [72.91902924, 18.79458046], [72.91929626, 18.79458046], [72.91929626, 18.79486275], [72.91958618, 18.79486275], [72.91958618, 18.79541969], [72.9201355, 18.79541588], [72.9201355, 18.79569244], [72.92041779, 18.79569244], [72.92041779, 18.79597473], [72.92069244, 18.79597282], [72.92069244, 18.79624939], [72.92095947, 18.79624939], [72.92095947, 18.79652977], [72.92124939, 18.79652977], [72.92124939, 18.79681015], [72.92152405, 18.79680634], [72.92152405, 18.79708481], [72.92180634, 18.79708481], [72.92180634, 18.79736137], [72.92208099, 18.79734993], [72.92208099, 18.79763985], [72.92236328, 18.79763985], [72.92236328, 18.79792023], [72.92263794, 18.79791641], [72.92263794, 18.79847145], [72.92292023, 18.79846954], [72.92292023, 18.79874992], [72.92318726, 18.79874992], [72.92318726, 18.7990303], [72.92346954, 18.7990303], [72.92346954, 18.79931068], [72.92375183, 18.79930687], [72.92375183, 18.79986191], [72.92402649, 18.79986], [72.92402649, 18.80014038], [72.92430878, 18.80013847], [72.92430878, 18.80041695], [72.92458344, 18.80041695], [72.92458344, 18.80097198], [72.92485809, 18.80097008], [72.92485809, 18.80125046], [72.92514038, 18.80125046], [72.92514038, 18.80153084], [72.92542267, 18.80153084], [72.92542267, 18.80181122], [72.92569733, 18.8018055], [72.92569733, 18.80208397], [72.92597198, 18.80208015], [72.92597198, 18.80236053], [72.92624664, 18.80236053], [72.92624664, 18.80264091], [72.92652893, 18.8026371], [72.92652893, 18.80319405], [72.92679596, 18.80319023], [72.92679596, 18.80347824], [72.92708588, 18.80347824], [72.92708588, 18.80374908], [72.92736053, 18.80374908], [72.92736053, 18.80403137], [72.92764282, 18.80403137], [72.92764282, 18.80431175], [72.92791748, 18.80430603], [72.92791748, 18.8045826], [72.92819214, 18.80458069], [72.92819214, 18.80514145], [72.92847443, 18.80514145], [72.92847443, 18.80569458], [72.92903137, 18.80569077], [72.92903137, 18.80624962], [72.92930603, 18.80624962], [72.92930603, 18.80820084], [72.92958069, 18.80820084], [72.92958069, 18.80903053], [72.92986298, 18.80902863], [72.92986298, 18.80958366], [72.93015289, 18.80957985], [72.93015289, 18.81014061], [72.93069458, 18.8101387], [72.93069458, 18.81097221], [72.93096924, 18.81097031], [72.93096924, 18.81180954], [72.93125153, 18.81180954], [72.93125153, 18.81264114], [72.93152618, 18.81263924], [72.93152618, 18.81319427], [72.93180847, 18.81319046], [72.93180847, 18.81375122], [72.93208313, 18.81375122], [72.93208313, 18.81430817], [72.93235779, 18.81430626], [72.93235779, 18.8148613], [72.93264008, 18.81485939], [72.93264008, 18.81513977], [72.93289948, 18.81513977], [72.93289948, 18.81541824], [72.93319702, 18.81541634], [72.93319702, 18.81569481], [72.93347168, 18.81569099], [72.93347168, 18.81624985], [72.93374634, 18.81624985], [72.93374634, 18.81708336], [72.93402863, 18.81707954], [72.93402863, 18.81792068], [72.93430328, 18.81792068], [72.93430328, 18.81875229], [72.9345932, 18.81875229], [72.9345932, 18.81931114], [72.93486023, 18.81931114], [72.93486023, 18.82014275], [72.93514252, 18.82014084], [72.93514252, 18.82097054], [72.93541718, 18.82097054], [72.93541718, 18.82152748], [72.93569183, 18.82152176], [72.93569183, 18.8223629], [72.93597412, 18.8223629], [72.93597412, 18.8231945], [72.93624878, 18.82319069], [72.93624878, 18.82374954], [72.93653107, 18.82374954], [72.93653107, 18.82429123], [72.93680573, 18.82430649], [72.93680573, 18.82486153], [72.93708038, 18.82485962], [72.93708038, 18.82514], [72.93736267, 18.82514], [72.93736267, 18.82570076], [72.93763733, 18.82569695], [72.93763733, 18.8259716], [72.93791962, 18.8259697], [72.93791962, 18.82625008], [72.93818665, 18.82625008], [72.93818665, 18.82653046], [72.93846893, 18.82652855], [72.93846893, 18.82708359], [72.93902588, 18.82707977], [72.93902588, 18.82736015], [72.9393158, 18.82736015], [72.93930817, 18.82708359], [72.93985748, 18.82707977], [72.93985748, 18.82736015], [72.94069672, 18.82736015], [72.94069672, 18.82792091], [72.94346619, 18.82792091], [72.94346619, 18.82707977], [72.94374847, 18.82708359], [72.94374847, 18.82625008], [72.94403076, 18.82625008], [72.94403076, 18.82542038], [72.94431305, 18.82542038], [72.94431305, 18.82458115], [72.94458008, 18.82458305], [72.94458008, 18.82374954], [72.94486237, 18.82374954], [72.94486237, 18.82319069], [72.94513702, 18.8231945], [72.94513702, 18.8223629], [72.94541931, 18.8223629], [72.94541931, 18.82208061], [72.94596863, 18.82208443], [72.94596863, 18.82180595], [72.9465332, 18.82180977], [72.9465332, 18.82069016], [72.94708252, 18.82069206], [72.94708252, 18.8204174], [72.94735718, 18.82042122], [72.94735718, 18.82014275], [72.94763947, 18.82014275], [72.94763947, 18.81986046], [72.94790649, 18.81986046], [72.94790649, 18.81958008], [72.94819641, 18.81958389], [72.94819641, 18.81930542], [72.94847107, 18.81931114], [72.94847107, 18.81903267], [72.94875336, 18.81903267], [72.94875336, 18.81875229], [72.94902802, 18.81875229], [72.94902802, 18.81819916], [72.94930267, 18.81819916], [72.94930267, 18.81792068], [72.94957733, 18.81792068], [72.94957733, 18.81735992], [72.94985962, 18.81736183], [72.94985962, 18.81680489], [72.95014191, 18.81680489], [72.95014191, 18.81624985], [72.95041656, 18.81624985], [72.95041656, 18.81569099], [72.95069122, 18.81569481], [72.95069122, 18.8148613], [72.95097351, 18.8148613], [72.95097351, 18.81430626], [72.9512558, 18.81430817], [72.9512558, 18.81375122], [72.95153046, 18.81375122], [72.95153046, 18.81319046], [72.95180511, 18.81319427], [72.95180511, 18.81236076], [72.95207977, 18.81236076], [72.95207977, 18.81180573], [72.95236206, 18.81180954], [72.95236206, 18.81125069], [72.95263672, 18.81125069], [72.95263672, 18.81068993], [72.95291901, 18.81069565], [72.95291901, 18.8101387], [72.95318604, 18.81014061], [72.95318604, 18.80957985], [72.95347595, 18.80958366], [72.95347595, 18.80902863], [72.95375061, 18.80903053], [72.95375061, 18.80846977], [72.95402527, 18.80847359], [72.95402527, 18.80791664], [72.95432281, 18.80792046], [72.95432281, 18.8073597], [72.95458221, 18.80736351], [72.95458221, 18.80680466], [72.9548645, 18.80680466], [72.9548645, 18.80624962], [72.95513916, 18.80624962], [72.95513916, 18.80569077], [72.95541382, 18.80569458], [72.95541382, 18.80514145], [72.95569611, 18.80514145], [72.95569611, 18.80458069], [72.95597076, 18.8045826], [72.95597076, 18.80402756], [72.95625305, 18.80403137], [72.95625305, 18.80347824], [72.95652771, 18.80347824], [72.95652771, 18.80291748], [72.95680237, 18.80291748], [72.95680237, 18.80236053], [72.9570694, 18.80236053], [72.9570694, 18.80181122], [72.95735931, 18.80181122], [72.95735931, 18.80125046], [72.9576416, 18.80125046], [72.9576416, 18.80097008], [72.95791626, 18.80097198], [72.95791626, 18.80069351], [72.95819092, 18.80069351], [72.95819092, 18.80041695], [72.95847321, 18.80041695], [72.95847321, 18.79986191], [72.95874786, 18.79986191], [72.95874786, 18.79958344], [72.95903015, 18.79958344], [72.95903015, 18.79930687], [72.95929718, 18.79931068], [72.95929718, 18.7990303], [72.9595871, 18.7990303], [72.9595871, 18.79874992], [72.95986176, 18.79874992], [72.95986176, 18.79846954], [72.96013641, 18.79847145], [72.96013641, 18.79819679], [72.9604187, 18.79819679], [72.9604187, 18.79763794], [72.96069336, 18.79763985], [72.96069336, 18.79734993], [72.96097565, 18.79736137], [72.96097565, 18.79708481], [72.96125031, 18.79708481], [72.96125031, 18.79680634], [72.96151733, 18.79681015], [72.96151733, 18.79652977], [72.96180725, 18.79652977], [72.96180725, 18.79624939], [72.96208191, 18.79624939], [72.96208191, 18.79597282], [72.9623642, 18.79597473], [72.9623642, 18.79569244], [72.96263885, 18.79569244], [72.96263885, 18.79541588], [72.96290588, 18.79541969], [72.96290588, 18.79514122], [72.9631958, 18.79514122], [72.9631958, 18.79486275], [72.96347046, 18.79486275], [72.96347046, 18.79458046], [72.96375275, 18.79458046], [72.96375275, 18.7943058], [72.96430206, 18.79430962], [72.96430206, 18.79403114], [72.96457672, 18.79403114], [72.96457672, 18.79375267], [72.96485901, 18.79375267], [72.96485901, 18.79347038], [72.96541595, 18.79347038], [72.96541595, 18.79319382], [72.96569061, 18.79319382], [72.96569824, 18.79291725], [72.9659729, 18.79292107], [72.9659729, 18.79264259], [72.96652985, 18.79264259], [72.96652985, 18.79236031], [72.96679688, 18.79236031], [72.96679688, 18.79207993], [72.96736145, 18.79208374], [72.96736145, 18.79180527], [72.96763611, 18.79180908], [72.96763611, 18.79154015], [72.96819305, 18.79154015], [72.96819305, 18.79124832], [72.96848297, 18.79124832], [72.96847534, 18.79097176], [72.96902466, 18.79097176], [72.96902466, 18.79069519], [72.96929932, 18.79070091], [72.96929932, 18.79042053], [72.96985626, 18.79042053], [72.96985626, 18.79013824], [72.97041321, 18.79013824], [72.97041321, 18.78985977], [72.97125244, 18.78985977], [72.97125244, 18.79013824], [72.9715271, 18.79013824], [72.9715271, 18.79042053], [72.97180176, 18.79041672], [72.97180939, 18.79084969], [72.97180939, 18.79097176], [72.97206879, 18.79096985], [72.97206879, 18.79154015], [72.9723587, 18.79153061], [72.9723587, 18.79208374], [72.97264099, 18.79207993], [72.97264099, 18.79264259], [72.97292328, 18.79264259], [72.97292328, 18.79292107], [72.97319794, 18.79291725], [72.97319794, 18.79347038], [72.9734726, 18.79347038], [72.9734726, 18.79403114], [72.97374725, 18.79402733], [72.97374725, 18.79458046], [72.97402954, 18.79458046], [72.97402954, 18.79486275], [72.97429657, 18.79486275], [72.97429657, 18.79541969], [72.97458649, 18.79541588], [72.97458649, 18.79597473], [72.97486115, 18.79597282], [72.97486115, 18.79652977], [72.9751358, 18.79652786], [72.9751358, 18.79708481], [72.97541809, 18.79708481], [72.97541809, 18.79736137], [72.97569275, 18.79734993], [72.97569275, 18.79792023], [72.97597504, 18.79791641], [72.97597504, 18.79847145], [72.97624969, 18.79846954], [72.97624969, 18.7990303], [72.97651672, 18.7990303], [72.97651672, 18.79931068], [72.97680664, 18.79930687], [72.97680664, 18.79958344], [72.9770813, 18.79958344], [72.9770813, 18.79986191], [72.97680664, 18.79986191], [72.97680664, 18.8006897], [72.97651672, 18.80070114], [72.97651672, 18.80153084], [72.97624969, 18.80152893], [72.97624969, 18.80208397], [72.97598267, 18.80208015], [72.97598267, 18.80291748], [72.97569275, 18.80291748], [72.97569275, 18.80374908], [72.97598267, 18.80374908], [72.97598267, 18.80431175], [72.97652435, 18.80430603], [72.97652435, 18.8045826], [72.97680664, 18.80458069], [72.97680664, 18.80485916], [72.9770813, 18.80485916], [72.9770813, 18.80514145], [72.97846985, 18.80514145], [72.97846985, 18.80485916], [72.97930908, 18.80485916], [72.97930908, 18.80458069], [72.97957611, 18.80458069], [72.97957611, 18.80485916], [72.9798584, 18.80485916], [72.9798584, 18.80542183], [72.98014069, 18.80541611], [72.98014069, 18.80597115], [72.98041534, 18.80597115], [72.98041534, 18.80624962], [72.98069763, 18.80624962], [72.98069763, 18.80680466], [72.98097229, 18.80680466], [72.98097229, 18.80736351], [72.98123932, 18.8073597], [72.98123932, 18.80792046], [72.98152924, 18.80792046], [72.98152924, 18.80820084], [72.98179626, 18.80820084], [72.98179626, 18.80875015], [72.98208618, 18.80875015], [72.98208618, 18.80931091], [72.98236084, 18.80930328], [72.98236084, 18.80958366], [72.98264313, 18.80957985], [72.98264313, 18.81014061], [72.98236084, 18.81014061], [72.98236084, 18.81042099], [72.98208618, 18.81041718], [72.98208618, 18.81069565], [72.98179626, 18.81068993], [72.98179626, 18.81125069], [72.98152924, 18.81125069], [72.98152924, 18.81153107], [72.98124695, 18.81152725], [72.98124695, 18.8120842], [72.98097229, 18.81208038], [72.98097229, 18.81291962], [72.98069763, 18.81291962], [72.98069763, 18.81375122], [72.98041534, 18.81374931], [72.98041534, 18.81458282], [72.98014069, 18.81458092], [72.98014069, 18.81541824], [72.9798584, 18.81541634], [72.9798584, 18.81708336], [72.97958374, 18.81708336], [72.97958374, 18.82208443], [72.9798584, 18.82208061], [72.9798584, 18.82263947], [72.98014069, 18.82263947], [72.98014069, 18.8231945], [72.98041534, 18.8231945], [72.98041534, 18.82374954], [72.98069763, 18.82374954], [72.98069763, 18.82429123], [72.98097229, 18.82430649], [72.98097229, 18.82486153], [72.98123932, 18.82485962], [72.98123932, 18.82542038], [72.98152924, 18.82542038], [72.98152924, 18.82570076], [72.98179626, 18.82570076], [72.98179626, 18.82625008], [72.98208618, 18.82625008], [72.98208618, 18.82653046], [72.98236084, 18.82653046], [72.98236084, 18.82681084], [72.9826355, 18.82680511], [72.9826355, 18.82736015], [72.98291779, 18.82736015], [72.98291779, 18.82764053], [72.98319244, 18.82764053], [72.98319244, 18.82792091], [72.98347473, 18.8279171], [72.98347473, 18.82847214], [72.98374939, 18.82847023], [72.98374939, 18.82875061], [72.9834671, 18.82875061], [72.9834671, 18.82902908], [72.98319244, 18.82902908], [72.98319244, 18.82930756], [72.98291779, 18.82930756], [72.98291779, 18.82986069], [72.9826355, 18.82986069], [72.9826355, 18.8306942], [72.98291779, 18.8306942], [72.98291779, 18.83208275], [72.98319244, 18.83208275], [72.98319244, 18.83319473], [72.9834671, 18.83319092], [72.9834671, 18.83403015], [72.98319244, 18.83403015], [72.98319244, 18.83570099], [72.98291779, 18.83570099], [72.98291779, 18.83681107], [72.9826355, 18.83680534], [72.98264313, 18.83736038], [72.98236084, 18.83736038], [72.98236084, 18.83792114], [72.98208618, 18.83791733], [72.98208618, 18.83847237], [72.98179626, 18.83847046], [72.98179626, 18.83875084], [72.98208618, 18.83875084], [72.98208618, 18.84124947], [72.98180389, 18.84124947], [72.98180389, 18.84236145], [72.98152924, 18.84236145], [72.98152924, 18.84347153], [72.98124695, 18.84347153], [72.98124695, 18.84486008], [72.98097229, 18.84486008], [72.98097229, 18.84597015], [72.98069763, 18.84597015], [72.98069763, 18.84669113], [72.98069763, 18.84708214], [72.9808197, 18.84708214], [72.98097229, 18.84708214], [72.98097229, 18.84760094], [72.98097229, 18.84819221], [72.98124695, 18.84819221], [72.98123932, 18.84851837], [72.98123932, 18.84875107], [72.98097229, 18.84875107], [72.98097229, 18.84930992], [72.98069763, 18.84930611], [72.98069763, 18.85069466], [72.98097229, 18.85069466], [72.98097229, 18.85208321], [72.98124695, 18.85208321], [72.98124695, 18.85236168], [72.98152924, 18.85235977], [72.98152924, 18.85264015], [72.98179626, 18.85264015], [72.98179626, 18.85320091], [72.98208618, 18.85319519], [72.98208618, 18.85347176], [72.98236084, 18.85346985], [72.98236084, 18.85375023], [72.98264313, 18.85375023], [72.98264313, 18.85431099], [72.98291779, 18.85431099], [72.98291779, 18.85458946], [72.98319244, 18.85458946], [72.98319244, 18.85514069], [72.9834671, 18.85514069], [72.9834671, 18.85542107], [72.98374939, 18.85541725], [72.98374939, 18.85597229], [72.98400879, 18.85597038], [72.98400879, 18.85625076], [72.98429871, 18.85625076], [72.98429871, 18.85680962], [72.98458099, 18.8568058], [72.98458099, 18.85708237], [72.98486328, 18.85708046], [72.98486328, 18.85765266], [72.98513794, 18.85765266], [72.98513794, 18.8579216], [72.98542023, 18.85791588], [72.98542023, 18.85847282], [72.98568726, 18.85847092], [72.98568726, 18.85903168], [72.98596954, 18.85902786], [72.98596954, 18.8595829], [72.98625183, 18.85957909], [72.98625183, 18.86014175], [72.98652649, 18.86013794], [72.98652649, 18.86069489], [72.98680878, 18.86069107], [72.98680878, 18.86125183], [72.98707581, 18.86125183], [72.98707581, 18.86181068], [72.98735809, 18.86180305], [72.98735809, 18.86236382], [72.98764038, 18.86236], [72.98764038, 18.86292076], [72.98791504, 18.86291695], [72.98791504, 18.86347389], [72.98819733, 18.86347008], [72.98819733, 18.86403084], [72.98847198, 18.86403084], [72.98847198, 18.86486053], [72.98874664, 18.86486053], [72.98874664, 18.86597252], [72.98847198, 18.86597061], [72.98847198, 18.86625099], [72.98792267, 18.86625099], [72.98792267, 18.86652946], [72.98764038, 18.86652946], [72.98764038, 18.86681747], [72.98708344, 18.86680794], [72.98708344, 18.8670826], [72.98680878, 18.8670826], [72.98680878, 18.86680794], [72.98652649, 18.86681747], [72.98652649, 18.86652946], [72.98625183, 18.86652946], [72.98625183, 18.86625099], [72.98596954, 18.86625099], [72.98596954, 18.86597061], [72.98542023, 18.86597252], [72.98542023, 18.86569595], [72.98513794, 18.86569595], [72.98513794, 18.86541748], [72.98486328, 18.86541939], [72.98486328, 18.86514091], [72.98458099, 18.86514091], [72.98458099, 18.86486053], [72.98400879, 18.86486053], [72.98400879, 18.86458015], [72.98374939, 18.86458588], [72.98374939, 18.8643055], [72.98319244, 18.86431122], [72.98319244, 18.86403084], [72.98264313, 18.86403084], [72.98264313, 18.86375046], [72.98014069, 18.86375046], [72.98014069, 18.86347008], [72.97902679, 18.86347389], [72.97902679, 18.86319542], [72.97792053, 18.8631897], [72.9779129, 18.86291695], [72.97763824, 18.86292076], [72.97763824, 18.86264038], [72.97735596, 18.86264038], [72.97735596, 18.86236], [72.9770813, 18.86236382], [72.9770813, 18.86208153], [72.97652435, 18.86208153], [72.97652435, 18.86180305], [72.97624969, 18.86181068], [72.97624969, 18.8615303], [72.97576904, 18.8615303], [72.97569275, 18.8615284], [72.97569275, 18.86125183], [72.97541809, 18.86125183], [72.97541809, 18.86097336], [72.97486115, 18.86097336], [72.97486115, 18.86069489], [72.97458649, 18.86069489], [72.97458649, 18.86041641], [72.97429657, 18.86042023], [72.97429657, 18.86014175], [72.97374725, 18.86014175], [72.97374725, 18.85985947], [72.9734726, 18.85985947], [72.9734726, 18.8595829], [72.97319794, 18.8595829], [72.97319794, 18.85930634], [72.97292328, 18.85931015], [72.97292328, 18.85903168], [72.97264099, 18.85903168], [72.97264099, 18.85874939], [72.9723587, 18.85874939], [72.9723587, 18.85847092], [72.97180176, 18.85847282], [72.97180176, 18.85819435], [72.9715271, 18.85819435], [72.9715271, 18.85791588], [72.97125244, 18.8579216], [72.97125244, 18.85765266], [72.97097015, 18.85765266], [72.97097015, 18.85736084], [72.97041321, 18.85736084], [72.97041321, 18.85708046], [72.97013855, 18.85708427], [72.97013855, 18.8568058], [72.9695816, 18.85680962], [72.9695816, 18.85652924], [72.96929932, 18.85652924], [72.96929932, 18.85625076], [72.9690094, 18.85625076], [72.9690094, 18.85597038], [72.96819305, 18.85597229], [72.96819305, 18.85569382], [72.96763611, 18.85569382], [72.96763611, 18.85541725], [72.96736145, 18.85542107], [72.96736145, 18.85514069], [72.96708679, 18.85514069], [72.96708679, 18.85486031], [72.96679688, 18.85486031], [72.96679688, 18.85458946], [72.96652985, 18.85458946], [72.96652985, 18.85431099], [72.96626282, 18.85431099], [72.96626282, 18.85403061], [72.9659729, 18.85403061], [72.9659729, 18.85375023], [72.96582794, 18.85375023], [72.96569824, 18.85375023], [72.96569061, 18.85346985], [72.9651413, 18.85347176], [72.9651413, 18.85319519], [72.96485901, 18.85320091], [72.96485901, 18.85292053], [72.96430206, 18.85292053], [72.96430206, 18.85264015], [72.9640274, 18.85264015], [72.9640274, 18.85292053], [72.96347046, 18.85292053], [72.96347046, 18.85320091], [72.9631958, 18.85319519], [72.9631958, 18.85347176], [72.9623642, 18.85347176], [72.9623642, 18.85319519], [72.96208191, 18.85320091], [72.96208191, 18.85292053], [72.96151733, 18.85292053], [72.96151733, 18.85264015], [72.96125031, 18.85264015], [72.96125031, 18.85235977], [72.96097565, 18.85236168], [72.96097565, 18.85180664], [72.9604187, 18.85180664], [72.9604187, 18.85152817], [72.95986176, 18.85153008], [72.95986176, 18.85124969], [72.95903015, 18.85124969], [72.95903015, 18.85097122], [72.95847321, 18.85097313], [72.95847321, 18.85069466], [72.95791626, 18.85069466], [72.95791626, 18.85041618], [72.95680237, 18.85042], [72.95680237, 18.85013962], [72.95625305, 18.85013962], [72.95625305, 18.84986115], [72.95513916, 18.84986115], [72.95513916, 18.84958076], [72.95347595, 18.84958458], [72.95347595, 18.84930611], [72.95318604, 18.84930992], [72.95318604, 18.84902954], [72.95291901, 18.84902954], [72.95291901, 18.84875107], [72.95263672, 18.84875107], [72.95263672, 18.84845924], [72.95207977, 18.8484745], [72.95207977, 18.84819221], [72.95153046, 18.84819221], [72.95153046, 18.84791756], [72.95096588, 18.84791946], [72.95096588, 18.8476429], [72.95014191, 18.8476429], [72.95014191, 18.84736252], [72.94930267, 18.84736252], [72.94930267, 18.84708023], [72.94847107, 18.84708214], [72.94847107, 18.84680557], [72.94735718, 18.84680939], [72.94735718, 18.84653282], [72.9465332, 18.84653282], [72.9465332, 18.84625244], [72.94512939, 18.84625244], [72.94512939, 18.84597015], [72.94416046, 18.84597015], [72.94374847, 18.84597015], [72.94374847, 18.84569359], [72.94291687, 18.84569359], [72.94291687, 18.84597015], [72.94264221, 18.84597015], [72.94264221, 18.84614944], [72.94264221, 18.84625244], [72.9420929, 18.84625244], [72.9420929, 18.84653282], [72.94180298, 18.84653282], [72.94180298, 18.84680939], [72.94152832, 18.84680557], [72.94152832, 18.84708214], [72.94124603, 18.84708023], [72.94124603, 18.84736252], [72.94069672, 18.84736252], [72.94069672, 18.8476429], [72.9404068, 18.8476429], [72.9404068, 18.84791946], [72.94013977, 18.84791756], [72.94013977, 18.84819221], [72.93958282, 18.84819221], [72.93958282, 18.8484745], [72.9393158, 18.84845924], [72.9393158, 18.84875107], [72.93875122, 18.84875107], [72.93875122, 18.84902954], [72.93846893, 18.84902954], [72.93846893, 18.84930992], [72.93688965, 18.84930801], [72.93264008, 18.84930611], [72.93264008, 18.84958458], [72.93235779, 18.84958076], [72.93235779, 18.84986115], [72.93208313, 18.84986115], [72.93208313, 18.85013962], [72.93180847, 18.85013962], [72.93180847, 18.85042], [72.93152618, 18.85041618], [72.93152618, 18.85069466], [72.93125153, 18.85069466], [72.93125153, 18.85097313], [72.93068695, 18.85097122], [72.93069458, 18.85124969], [72.93015289, 18.85124969], [72.93015289, 18.85153008], [72.92764282, 18.85153008], [72.92764282, 18.85124969], [72.92736053, 18.85124969], [72.92736053, 18.85097122], [72.92652893, 18.85097122], [72.92652893, 18.85124969], [72.92624664, 18.85124969], [72.92624664, 18.85153008], [72.92569733, 18.85152817], [72.92569733, 18.85180664], [72.92541504, 18.85180664], [72.92541504, 18.85236168], [72.92514038, 18.85236168], [72.92514038, 18.85347176], [72.92485809, 18.85346985], [72.92485809, 18.85431099], [72.92430878, 18.85431099], [72.92430878, 18.85458946], [72.92402649, 18.85458946], [72.92402649, 18.85486031], [72.92263794, 18.85486031], [72.92263794, 18.85514069], [72.92292023, 18.85514069], [72.92292023, 18.85680962], [72.92319489, 18.8568058], [72.92319489, 18.85819435], [72.92346954, 18.85819054], [72.92346954, 18.85874939], [72.92375183, 18.85874939], [72.92375183, 18.86347389], [72.92346954, 18.86347389], [72.92346954, 18.86458588], [72.92318726, 18.86458015], [72.92318726, 18.86541939], [72.92292023, 18.86541748], [72.92292023, 18.86569595], [72.92263794, 18.86569595], [72.92263794, 18.86597252], [72.92236328, 18.86597061], [72.92236328, 18.86652946], [72.92208099, 18.86652946], [72.92208099, 18.86763954], [72.92180634, 18.86763954], [72.92180634, 18.86819458], [72.92124939, 18.86819458], [72.92124939, 18.86847305], [72.92095947, 18.86847115], [72.92095947, 18.86874962], [72.92069244, 18.86874962], [72.92069244, 18.86930466], [72.92014313, 18.86930084], [72.92014313, 18.87013817], [72.91986084, 18.87013817], [72.91986084, 18.87070084], [72.91958618, 18.87069511], [72.91958618, 18.87097168], [72.91929626, 18.87096977], [72.91929626, 18.87124825], [72.91902924, 18.87124825], [72.91902924, 18.87152863], [72.91874695, 18.87152863], [72.91874695, 18.87181091], [72.91847229, 18.87181091], [72.91847229, 18.87236023], [72.91819763, 18.87236023], [72.91819763, 18.8726387], [72.91792297, 18.87262917], [72.91792297, 18.8729229], [72.91764069, 18.87291718], [72.91764069, 18.87347031], [72.9173584, 18.87347031], [72.9173584, 18.87403107], [72.91708374, 18.87402725], [72.91708374, 18.87458229], [72.91680908, 18.87458038], [72.91680908, 18.87514114], [72.91652679, 18.87513924], [72.91652679, 18.87569237], [72.91625214, 18.87569046], [72.91625214, 18.87652969], [72.91596985, 18.87652779], [72.91596985, 18.87708473], [72.91570282, 18.87708092], [72.91570282, 18.87792015], [72.9154129, 18.87792015], [72.9154129, 18.87875938], [72.91513824, 18.87874985], [72.91513824, 18.87930679], [72.91486359, 18.87930679], [72.91486359, 18.87986183], [72.9145813, 18.87985992], [72.9145813, 18.8801403], [72.91430664, 18.8801403], [72.91430664, 18.88070107], [72.91402435, 18.88069534], [72.91402435, 18.88097191], [72.91374969, 18.88097], [72.91374969, 18.88125038], [72.91348267, 18.88125038], [72.91348267, 18.88182068], [72.91319275, 18.88180542], [72.91319275, 18.88208389], [72.91291809, 18.88208008], [72.91291809, 18.88236046], [72.9126358, 18.88236046], [72.9126358, 18.88292122], [72.9109726, 18.8829174], [72.9109726, 18.88347244], [72.91069794, 18.88347054], [72.91069794, 18.88375092], [72.91042328, 18.88375092], [72.91042328, 18.88431168], [72.91014099, 18.88430595], [72.91014099, 18.88458252], [72.9098587, 18.88457108], [72.9098587, 18.88485909], [72.90930939, 18.88485909], [72.90930176, 18.88513947], [72.90901947, 18.88513947], [72.90901947, 18.88542175], [72.90847015, 18.88541603], [72.90847015, 18.8856945], [72.9081955, 18.8856945], [72.9081955, 18.88847351], [72.90847015, 18.8884697], [72.90847015, 18.89125061], [72.90820313, 18.89125061], [72.90820313, 18.89264107], [72.90847015, 18.89263916], [72.90847015, 18.89708328], [72.90875244, 18.89707947], [72.90875244, 18.89819908], [72.9081955, 18.89819527], [72.9081955, 18.89847183], [72.90791321, 18.89846992], [72.90791321, 18.89903259], [72.90763855, 18.89903259], [72.90763855, 18.90042114], [72.90791321, 18.90041733], [72.90791321, 18.90208435], [72.90847015, 18.90208054], [72.90847015, 18.90236282], [72.90875244, 18.90236282], [72.90875244, 18.90263939], [72.90930176, 18.90263939], [72.90930939, 18.90293121], [72.90958405, 18.90291405], [72.90958405, 18.90319252], [72.9098587, 18.90319061], [72.9098587, 18.90374947], [72.91014099, 18.90374947], [72.91014099, 18.90431023], [72.91069794, 18.90431023], [72.91069794, 18.90402985], [72.91291809, 18.90402985], [72.91291809, 18.90374947], [72.91514587, 18.90374947], [72.91514587, 18.90402985], [72.9154129, 18.90402985], [72.9154129, 18.90431023], [72.91569519, 18.90430641], [72.91569519, 18.90458488], [72.91625214, 18.90458488], [72.91625214, 18.90486145], [72.91652679, 18.90485954], [72.91652679, 18.9054203], [72.91680908, 18.90541649], [72.91680908, 18.90597153], [72.91707611, 18.90596962], [72.91707611, 18.90653038], [72.9173584, 18.90653038], [72.9173584, 18.90792084], [72.91707611, 18.90792084], [72.91707611, 18.90903091], [72.91680908, 18.90903091], [72.91680908, 18.91041756], [72.9173584, 18.91041756], [72.9173584, 18.91013908], [72.91792297, 18.91013908], [72.91792297, 18.90986061], [72.91847229, 18.90986061], [72.91847229, 18.90958023], [72.91958618, 18.90958023], [72.91958618, 18.90986061], [72.91986084, 18.90986061], [72.91986084, 18.91041756], [72.9201355, 18.91041756], [72.9201355, 18.91069412], [72.92041779, 18.91069412], [72.92041779, 18.9109726], [72.92124939, 18.91097069], [72.92124939, 18.91153145], [72.92180634, 18.91152763], [72.92180634, 18.91180611], [72.92263794, 18.91180611], [72.92263794, 18.91208267], [72.92346954, 18.91208267], [72.92346954, 18.91180611], [72.92402649, 18.91180611], [72.92402649, 18.91152763], [72.92736053, 18.91153145], [72.92736053, 18.91124916], [72.9284668, 18.91124916], [72.9284668, 18.91097069], [72.92903137, 18.9109726], [72.92903137, 18.91069412], [72.92958069, 18.91069412], [72.92958069, 18.91041756], [72.92986298, 18.91041756], [72.92986298, 18.90958023], [72.93013763, 18.90958405], [72.93013763, 18.90875053], [72.93041992, 18.90875053], [72.93041992, 18.90763855], [72.93068695, 18.90764046], [72.93068695, 18.90736008], [72.93096924, 18.90736198], [72.93096924, 18.90708351], [72.93125153, 18.90708351], [72.93125153, 18.90652847], [72.93152618, 18.90653038], [72.93152618, 18.90596962], [72.93180847, 18.90597153], [72.93180847, 18.90569687], [72.93208313, 18.90570068], [72.93208313, 18.9054203], [72.93235779, 18.9054203], [72.93235779, 18.90513992], [72.93264008, 18.90513992], [72.93264008, 18.90485954], [72.93291473, 18.90486145], [72.93291473, 18.90430641], [72.93374634, 18.90431023], [72.93374634, 18.90402985], [72.93430328, 18.90402985], [72.93430328, 18.90374947], [72.9345932, 18.90374947], [72.93458557, 18.90347481], [72.93486023, 18.90347481], [72.93486023, 18.90319252], [72.93514252, 18.90319252], [72.93514252, 18.90291405], [72.93569183, 18.90293121], [72.93569183, 18.90236282], [72.93624878, 18.90236282], [72.93624878, 18.90208054], [72.93653107, 18.90208435], [72.93653107, 18.90180588], [72.93681335, 18.90180969], [72.93681335, 18.90153122], [72.93708038, 18.90153122], [72.93708038, 18.90125275], [72.93763733, 18.90125275], [72.93763733, 18.90097046], [72.93791962, 18.90097046], [72.93791962, 18.90041733], [72.93818665, 18.90042114], [72.93818665, 18.90014267], [72.93875122, 18.90014267], [72.93875122, 18.89986038], [72.93902588, 18.89986038], [72.93902588, 18.89957047], [72.93930817, 18.89958382], [72.93930817, 18.89930534], [72.93958282, 18.89931107], [72.93958282, 18.89903259], [72.93985748, 18.89903259], [72.93985748, 18.8987484], [72.94013977, 18.8987484], [72.94013977, 18.89846992], [72.94041443, 18.89847183], [72.94041443, 18.89819527], [72.94069672, 18.89819908], [72.94069672, 18.89792061], [72.94097137, 18.89792061], [72.94097137, 18.89652824], [72.94069672, 18.89652824], [72.94069672, 18.89541817], [72.94180298, 18.89541626], [72.94180298, 18.89708328], [72.94190979, 18.89708138], [72.9420929, 18.89707947], [72.9420929, 18.89792061], [72.94235992, 18.89792061], [72.94235992, 18.89903259], [72.94264221, 18.89903259], [72.94264221, 18.89986038], [72.94291687, 18.89986038], [72.94291687, 18.9054203], [72.94264221, 18.9054203], [72.94264221, 18.90570068], [72.94235992, 18.90570068], [72.94235992, 18.90625], [72.94208527, 18.90625], [72.94208527, 18.90875053], [72.94235992, 18.908741], [72.94235992, 18.90930748], [72.94319153, 18.90930748], [72.94319153, 18.90903091], [72.94458008, 18.90903091], [72.94458008, 18.90930748], [72.94486237, 18.90930748], [72.94486237, 18.91013908], [72.94513702, 18.91013718], [72.94513702, 18.9109726], [72.94625092, 18.9109726], [72.94625092, 18.91069412], [72.94985962, 18.91069412], [72.94985962, 18.91041756], [72.95041656, 18.91041756], [72.95041656, 18.91013908], [72.95069122, 18.91013908], [72.95069122, 18.90986061], [72.95096588, 18.90986061], [72.95096588, 18.90958023], [72.95153046, 18.90958405], [72.95153046, 18.9090271], [72.95207977, 18.90903091], [72.95207977, 18.908741], [72.95236206, 18.90875053], [72.95236206, 18.90847206], [72.95291901, 18.90847206], [72.95291901, 18.90819359], [72.95402527, 18.90819359], [72.95402527, 18.90847206], [72.95513916, 18.90847206], [72.95513916, 18.90819359], [72.95569611, 18.90819359], [72.95569611, 18.90847206], [72.95597076, 18.90847206], [72.95597076, 18.90819359], [72.95652771, 18.90819359], [72.95652771, 18.90791893], [72.95708466, 18.90791893], [72.95708466, 18.90819359], [72.95735931, 18.90819359], [72.95735931, 18.90847206], [72.9576416, 18.90847206], [72.9576416, 18.90875053], [72.95735931, 18.90875053], [72.95735931, 18.90958405], [72.9576416, 18.90958023], [72.9576416, 18.91013908], [72.95791626, 18.91013908], [72.95791626, 18.91041756], [72.95819092, 18.91041756], [72.95819092, 18.9109726], [72.95847321, 18.91097069], [72.95847321, 18.91124916], [72.95874786, 18.91124916], [72.95874786, 18.91180611], [72.95903015, 18.91180038], [72.95903015, 18.91235924], [72.95929718, 18.91235924], [72.95929718, 18.91264153], [72.9595871, 18.91264153], [72.9595871, 18.91292191], [72.95986176, 18.91291618], [72.95986176, 18.91347122], [72.96012878, 18.91346931], [72.96012878, 18.91403008], [72.9604187, 18.91402817], [72.9604187, 18.9145813], [72.96069336, 18.91457939], [72.96069336, 18.91514015], [72.96097565, 18.91513824], [72.96098328, 18.91625023], [72.96069336, 18.91625023], [72.96069336, 18.9179306], [72.96098328, 18.9179306], [72.96098328, 18.91903114], [72.96125031, 18.91902733], [72.96125031, 18.91958237], [72.96151733, 18.91958046], [72.96151733, 18.92041969], [72.96180725, 18.92041969], [72.96180725, 18.92180824], [72.96151733, 18.92180824], [72.96151733, 18.92263985], [72.96125031, 18.92263985], [72.96125031, 18.92319489], [72.96097565, 18.92319489], [72.96097565, 18.92374992], [72.95986176, 18.92374039], [72.95986176, 18.9240284], [72.95929718, 18.9240284], [72.95929718, 18.92431068], [72.95903015, 18.92430496], [72.95903015, 18.92458344], [72.95847321, 18.92458344], [72.95847321, 18.92486191], [72.95819092, 18.92485809], [72.95819092, 18.92513847], [72.9576416, 18.92513847], [72.9576416, 18.92542267], [72.95735931, 18.92541695], [72.95735931, 18.9256897], [72.95708466, 18.92569542], [72.95708466, 18.92597008], [72.95680237, 18.92597008], [72.95680237, 18.92625237], [72.95652771, 18.92625237], [72.95652771, 18.92653275], [72.95625305, 18.92653275], [72.95625305, 18.92681122], [72.95597076, 18.9268055], [72.95597076, 18.92708206], [72.95569611, 18.92708015], [72.95569611, 18.92736053], [72.95540619, 18.92736053], [72.95540619, 18.92764282], [72.95513916, 18.92764282], [72.95513916, 18.92791939], [72.9548645, 18.92791748], [72.9548645, 18.92819214], [72.95458221, 18.92819214], [72.95458221, 18.92847061], [72.95432281, 18.92847061], [72.95432281, 18.9287529], [72.9540329, 18.9287529], [72.9540329, 18.92902946], [72.95375061, 18.92902946], [72.95375061, 18.92930984], [72.95347595, 18.92930603], [72.95347595, 18.9295845], [72.95318604, 18.92958069], [72.95318604, 18.92987061], [72.95291901, 18.92987061], [72.95291901, 18.93013954], [72.95263672, 18.93013954], [72.95263672, 18.93041992], [72.95236206, 18.9304142], [72.95236206, 18.93069458], [72.95207977, 18.93069458], [72.95207977, 18.93097305], [72.95153046, 18.93097115], [72.95153046, 18.93124962], [72.9512558, 18.93124962], [72.9512558, 18.93153], [72.95097351, 18.93152809], [72.95097351, 18.93180656], [72.95069122, 18.93180656], [72.95069122, 18.93208313], [72.95014191, 18.93208313], [72.95014191, 18.9323616], [72.94985962, 18.9323597], [72.94985962, 18.93264008], [72.94958496, 18.93263817], [72.94958496, 18.93291664], [72.94930267, 18.93291092], [72.94930267, 18.93320084], [72.94902802, 18.93319511], [72.94902802, 18.93347168], [72.94875336, 18.93346977], [72.94875336, 18.93403053], [72.94847107, 18.93403053], [72.94847107, 18.93431091], [72.94819641, 18.93430519], [72.94819641, 18.93458366], [72.94790649, 18.93457985], [72.94790649, 18.93486023], [72.94763947, 18.93486023], [72.94763947, 18.93514061], [72.94735718, 18.93514061], [72.94735718, 18.93541908], [72.94680786, 18.93541718], [72.94680786, 18.93569374], [72.94652557, 18.93569374], [72.94652557, 18.93597221], [72.94625092, 18.93597031], [72.94625092, 18.93625069], [72.94596863, 18.93625069], [72.94596863, 18.93680763], [72.94569397, 18.93680573], [72.94569397, 18.93958282], [72.94541931, 18.93958092], [72.94541931, 18.94014168], [72.94512939, 18.94014168], [72.94512939, 18.94042015], [72.94486237, 18.94041634], [72.94486237, 18.94097137], [72.94458008, 18.94096947], [72.94458008, 18.94124985], [72.94431305, 18.94124985], [72.94431305, 18.94153023], [72.94374847, 18.94153023], [72.94374847, 18.94181061], [72.94347382, 18.94180489], [72.94347382, 18.94236374], [72.94319153, 18.94235992], [72.94319153, 18.94292068], [72.94291687, 18.94292068], [72.94291687, 18.94320107], [72.94264221, 18.94319534], [72.94264221, 18.94347382], [72.94208527, 18.94347382], [72.9420929, 18.94375038], [72.94180298, 18.94375038], [72.94180298, 18.94403076], [72.94152832, 18.94403076], [72.94152832, 18.94431114], [72.94125366, 18.94430542], [72.94125366, 18.9445858], [72.94097137, 18.9445858], [72.94097137, 18.94486046], [72.94069672, 18.94485283], [72.94069672, 18.94514084], [72.94013977, 18.94514084], [72.94013977, 18.94542122], [72.93958282, 18.9454174], [72.93958282, 18.94597244], [72.9393158, 18.94597054], [72.9393158, 18.94652939], [72.93958282, 18.94652748], [72.93958282, 18.94708252], [72.93985748, 18.94708061], [72.93985748, 18.94736099], [72.94013977, 18.94736099], [72.94013977, 18.94791794], [72.94041443, 18.94791794], [72.94041443, 18.9481945], [72.94069672, 18.9481945], [72.94069672, 18.94847298], [72.94097137, 18.94847107], [72.94097137, 18.94874954], [72.94124603, 18.94874954], [72.94124603, 18.94902992], [72.94152832, 18.94902611], [72.94152832, 18.94930077], [72.94180298, 18.94930649], [72.94180298, 18.94986153], [72.9420929, 18.94985962], [72.9420929, 18.95013809], [72.94264221, 18.95013809], [72.94264221, 18.95041847], [72.94291687, 18.95041847], [72.94291687, 18.95070076], [72.94319153, 18.95069504], [72.94319153, 18.9509716], [72.94346619, 18.9509697], [72.94346619, 18.95124817], [72.94403076, 18.95124817], [72.94403076, 18.95152855], [72.94431305, 18.95152855], [72.94431305, 18.95181084], [72.94458008, 18.95180511], [72.94458008, 18.95208359], [72.94486237, 18.95207977], [72.94486237, 18.95236015], [72.94512939, 18.95236015], [72.94512939, 18.95292282], [72.94541931, 18.95292282], [72.94541931, 18.95430946], [72.94569397, 18.95430565], [72.94569397, 18.95557022], [72.94569397, 18.95569229], [72.94596863, 18.95569229], [72.94596863, 18.95598984], [72.94596863, 18.95625114], [72.94613647, 18.95624924], [72.94625092, 18.95624924], [72.94625854, 18.95643044], [72.94626617, 18.95652962], [72.9465332, 18.95652962], [72.9465332, 18.95681], [72.94680786, 18.95681], [72.94680786, 18.95736122], [72.94708252, 18.95736122], [72.94708252, 18.95763969], [72.94736481, 18.95763969], [72.94736481, 18.95819664], [72.94763947, 18.95819092], [72.94763947, 18.95903015], [72.94791412, 18.95902824], [72.94791412, 18.95958328], [72.94818878, 18.95957947], [72.94818878, 18.96042061], [72.94847107, 18.96041679], [72.94847107, 18.96112061], [72.94847107, 18.96125031], [72.94875336, 18.96125031], [72.94875336, 18.96167755], [72.94875336, 18.96208382], [72.94902802, 18.96208382], [72.94902802, 18.9622097], [72.94902802, 18.96236038], [72.94930267, 18.96236038], [72.94930267, 18.96264076], [72.94958496, 18.96263885], [72.94958496, 18.96291733], [72.95041656, 18.96291733], [72.95041656, 18.96180534], [72.95014191, 18.96181107], [72.95014191, 18.96070099], [72.94985962, 18.96070099], [72.94985962, 18.96014023], [72.94957733, 18.96014023], [72.94957733, 18.95985031], [72.94930267, 18.95986176], [72.94930267, 18.95930672], [72.94902802, 18.95930672], [72.94902802, 18.95874977], [72.94875336, 18.95874977], [72.94875336, 18.95819092], [72.94847107, 18.95819664], [72.94847107, 18.95736122], [72.94818878, 18.95736122], [72.94818878, 18.95681], [72.94790649, 18.95681], [72.94790649, 18.95625114], [72.94763947, 18.95625114], [72.94763947, 18.95541954], [72.94735718, 18.95541954], [72.94735718, 18.95458031], [72.94708252, 18.95458221], [72.94708252, 18.95402718], [72.94680786, 18.95404053], [72.94680786, 18.95347023], [72.94708252, 18.95347023], [72.94708252, 18.9529171], [72.94763947, 18.95292282], [72.94763947, 18.95264244], [72.94819641, 18.95263863], [72.94819641, 18.95319366], [72.94847107, 18.95319176], [72.94847107, 18.95404053], [72.94875336, 18.95404053], [72.94875336, 18.95486069], [72.94902802, 18.95486069], [72.94902802, 18.95541954], [72.94930267, 18.95541573], [72.94930267, 18.95569229], [72.94957733, 18.95569038], [72.94957733, 18.95625114], [72.94985962, 18.95625114], [72.94985962, 18.95681], [72.95014191, 18.95681], [72.95014191, 18.95763969], [72.95041656, 18.95763969], [72.95041656, 18.95819664], [72.95069122, 18.95819092], [72.95069122, 18.95874977], [72.95097351, 18.95874977], [72.95097351, 18.95958328], [72.9512558, 18.95957947], [72.9512558, 18.96014023], [72.95153046, 18.96014023], [72.95153046, 18.96042061], [72.95181274, 18.96042061], [72.95181274, 18.96014023], [72.95263672, 18.96014023], [72.95263672, 18.96070099], [72.95291901, 18.96070099], [72.95291901, 18.96125031], [72.95318604, 18.96125031], [72.95318604, 18.96153069], [72.95347595, 18.96152878], [72.95347595, 18.96208382], [72.95375061, 18.96208], [72.95375061, 18.96236038], [72.95402527, 18.96236038], [72.95402527, 18.96291733], [72.95430756, 18.96291733], [72.95430756, 18.96347237], [72.95458221, 18.96347046], [72.95458221, 18.96375084], [72.95485687, 18.96375084], [72.95485687, 18.9643116], [72.95430756, 18.96430588], [72.95430756, 18.96458244], [72.95458221, 18.96458054], [72.95458221, 18.96486092], [72.95485687, 18.96486092], [72.95485687, 18.96513939], [72.95513916, 18.96513939], [72.95513916, 18.96569443], [72.95540619, 18.96569061], [72.95540619, 18.96681023], [72.95569611, 18.96681023], [72.95569611, 18.96820068], [72.95540619, 18.96820068], [72.95540619, 18.96875191], [72.95513916, 18.96875191], [72.95513916, 18.96903992], [72.95485687, 18.96903992], [72.95485687, 18.96931076], [72.95458221, 18.96930313], [72.95458221, 18.9695816], [72.95402527, 18.9695816], [72.95402527, 18.96986389], [72.95375061, 18.96986008], [72.95375061, 18.97014046], [72.95347595, 18.97014046], [72.95347595, 18.97125053], [72.95375061, 18.97125053], [72.95375061, 18.97153091], [72.95432281, 18.97153091], [72.95432281, 18.97180939], [72.95458221, 18.97180939], [72.95458221, 18.97236061], [72.95485687, 18.97236061], [72.95485687, 18.97264099], [72.95513916, 18.97263908], [72.95513916, 18.97319412], [72.95541382, 18.97319412], [72.95541382, 18.9734726], [72.95569611, 18.97347069], [72.95569611, 18.97402954], [72.95680237, 18.97402954], [72.95680237, 18.97347069], [72.95735931, 18.9734726], [72.95735931, 18.97319412], [72.9595871, 18.97319412], [72.9595871, 18.9734726], [72.95986176, 18.9734726], [72.95986176, 18.97319412], [72.96013641, 18.97319412], [72.96013641, 18.97263908], [72.9604187, 18.97264099], [72.9604187, 18.97236061], [72.96069336, 18.97236061], [72.96069336, 18.97208023], [72.96097565, 18.97208595], [72.96097565, 18.9715271], [72.96125031, 18.97153091], [72.96125031, 18.97125053], [72.96151733, 18.97125053], [72.96151733, 18.97068977], [72.96180725, 18.9706955], [72.96180725, 18.97041702], [72.96208191, 18.97042084], [72.96208191, 18.96986008], [72.9623642, 18.96986389], [72.9623642, 18.9695816], [72.96263885, 18.9695816], [72.96263885, 18.96902847], [72.96290588, 18.96903992], [72.96290588, 18.96875191], [72.9631958, 18.96875191], [72.9631958, 18.96846962], [72.96347046, 18.96847153], [72.96347046, 18.96791649], [72.96375275, 18.9679203], [72.96375275, 18.96764183], [72.9640274, 18.96764183], [72.9640274, 18.96735954], [72.96458435, 18.96736336], [72.96458435, 18.96708107], [72.96485901, 18.96708107], [72.96485901, 18.96680641], [72.9668045, 18.96680641], [72.9668045, 18.96708107], [72.96763611, 18.96708107], [72.96763611, 18.96680641], [72.96819305, 18.96681023], [72.96819305, 18.96653175], [72.96848297, 18.96653175], [72.96848297, 18.96624947], [72.96902466, 18.96624947], [72.9690094, 18.96598053], [72.9695816, 18.96598053], [72.9695816, 18.96569061], [72.96986389, 18.96569443], [72.96985626, 18.9654007], [72.97013855, 18.96542168], [72.97013855, 18.96513939], [72.97041321, 18.96513939], [72.97041321, 18.96458054], [72.9706955, 18.96458244], [72.9706955, 18.96430588], [72.97125244, 18.9643116], [72.97125244, 18.96402931], [72.9715271, 18.96402931], [72.9715271, 18.96375084], [72.97206879, 18.96375084], [72.97206879, 18.96347046], [72.9751358, 18.96347237], [72.9751358, 18.96319389], [72.97541809, 18.96319389], [72.97541809, 18.96291733], [72.97736359, 18.96291733], [72.97736359, 18.96263885], [72.97930908, 18.96263885], [72.97930908, 18.96291733], [72.9798584, 18.96291733], [72.9798584, 18.96319389], [72.98097229, 18.96319389], [72.98097229, 18.96347237], [72.98152924, 18.96347046], [72.98152924, 18.96375084], [72.98179626, 18.96375084], [72.98179626, 18.9643116], [72.98208618, 18.9643116], [72.98208618, 18.96486092], [72.98236084, 18.96486092], [72.98236084, 18.96542168], [72.98264313, 18.96542168], [72.98264313, 18.96598053], [72.98291779, 18.96598053], [72.98291779, 18.96624947], [72.98319244, 18.96624947], [72.98319244, 18.96681023], [72.98347473, 18.96680641], [72.98347473, 18.96736336], [72.98374939, 18.96735954], [72.98374939, 18.9679203], [72.98402405, 18.96791649], [72.98402405, 18.96847153], [72.98429871, 18.96846962], [72.98429871, 18.96903992], [72.98458099, 18.96902847], [72.98458099, 18.9695816], [72.98486328, 18.9695816], [72.98486328, 18.96986389], [72.98542023, 18.96986008], [72.98542023, 18.97014046], [72.98625183, 18.97014046], [72.98625183, 18.96986008], [72.98652649, 18.96986389], [72.98652649, 18.9695816], [72.98680878, 18.9695816], [72.98680878, 18.96902847], [72.98707581, 18.96903992], [72.98707581, 18.96875191], [72.98737335, 18.96875191], [72.98735809, 18.96847153], [72.98819733, 18.96847153], [72.98819733, 18.96819305], [72.99014282, 18.96820068], [72.99014282, 18.9679203], [72.99317932, 18.9679203], [72.99317932, 18.96820068], [72.99485779, 18.96819305], [72.99485779, 18.96847153], [72.99623871, 18.96846962], [72.99623871, 18.96875191], [72.99680328, 18.96875191], [72.99680328, 18.96903992], [72.99736023, 18.96903992], [72.99736023, 18.96931076], [72.99791718, 18.96930313], [72.99791718, 18.9695816], [72.99847412, 18.9695816], [72.99847412, 18.96986389], [72.99903107, 18.96986008], [72.99903107, 18.97014046], [72.99958038, 18.97014046], [72.99958038, 18.97042084], [73.00013733, 18.97042084], [73.00041962, 18.97041702], [73.00041962, 18.9706955], [73.00125122, 18.97068977], [73.00125122, 18.97125053], [73.00237274, 18.97125053], [73.00237274, 18.97180939], [73.00263977, 18.97180557], [73.00263977, 18.97208595], [73.0029068, 18.97208023], [73.0029068, 18.97236061], [73.00319672, 18.97236061], [73.00319672, 18.97264099], [73.00347137, 18.97264099], [73.00347137, 18.97291946], [73.00375366, 18.97291756], [73.00375366, 18.97319412], [73.00402832, 18.97319412], [73.00402832, 18.9734726], [73.00430298, 18.97347069], [73.00430298, 18.97375107], [73.00402832, 18.97375107], [73.00402832, 18.97430992], [73.00374603, 18.97430992], [73.00374603, 18.97541809], [73.00485992, 18.97541809], [73.00485992, 18.97513962], [73.00569153, 18.97513962], [73.00569153, 18.97541809], [73.00596619, 18.97541809], [73.00596619, 18.97624969], [73.00569153, 18.97624969], [73.00569153, 18.97652817], [73.00597382, 18.97652817], [73.00597382, 18.97680473], [73.00680542, 18.97680473], [73.00680542, 18.97708321], [73.00902557, 18.97708321], [73.00902557, 18.97680473], [73.01125336, 18.97680473], [73.01125336, 18.97708321], [73.01180267, 18.97708321], [73.01180267, 18.97736168], [73.01207733, 18.97735977], [73.01207733, 18.97763824], [73.01264191, 18.97763824], [73.01264191, 18.97792053], [73.01291656, 18.97791672], [73.01291656, 18.97847176], [73.01346588, 18.97846985], [73.01346588, 18.97874832], [73.01374817, 18.97874832], [73.01374817, 18.97903252], [73.01431274, 18.97903252], [73.01431274, 18.9793129], [73.01486206, 18.97930527], [73.01486206, 18.97958374], [73.01513672, 18.97958183], [73.01513672, 18.97986031], [73.01568604, 18.97986031], [73.01568604, 18.98014259], [73.01625061, 18.98014259], [73.01625061, 18.98042107], [73.0165329, 18.98042107], [73.0165329, 18.98097992], [73.01708221, 18.98097992], [73.01708221, 18.98264122], [73.01734924, 18.98264122], [73.01734924, 18.98374939], [73.01708221, 18.98374939], [73.01708221, 18.98542023], [73.01680756, 18.98541641], [73.01680756, 18.98597145], [73.01708221, 18.98596954], [73.01708221, 18.9865303], [73.01734924, 18.9865303], [73.01734924, 18.98681068], [73.01902771, 18.98680687], [73.01902771, 18.98708344], [73.01930237, 18.98708344], [73.01930237, 18.98736191], [73.01985931, 18.98736], [73.01985931, 18.98764038], [73.0201416, 18.98764038], [73.0201416, 18.98792076], [73.02041626, 18.98791885], [73.02041626, 18.98819351], [73.02069092, 18.98819351], [73.02069092, 18.98847198], [73.02097321, 18.98847008], [73.02097321, 18.98903084], [73.02124786, 18.98903084], [73.02124786, 18.98986053], [73.02153015, 18.98986053], [73.02153015, 18.99014854], [73.02179718, 18.99014854], [73.02179718, 18.99041748], [73.0220871, 18.99041748], [73.0220871, 18.99069405], [73.02236176, 18.99069405], [73.02236176, 18.99041748], [73.02263641, 18.99041748], [73.02263641, 18.99014854], [73.02319336, 18.9901371], [73.02319336, 18.99097252], [73.02402496, 18.99097252], [73.02402496, 18.99069405], [73.02430725, 18.99069405], [73.02430725, 18.99041748], [73.02458191, 18.99041748], [73.02458191, 18.99014854], [73.02430725, 18.99014854], [73.02430725, 18.98986053], [73.02458191, 18.98986053], [73.02458191, 18.98958015], [73.0248642, 18.98958397], [73.0248642, 18.9893055], [73.02513885, 18.98931122], [73.02513885, 18.98903084], [73.02625275, 18.98903084], [73.02625275, 18.98875046], [73.02735901, 18.98875046], [73.02735901, 18.98903084], [73.0276413, 18.98902893], [73.0276413, 18.98958397], [73.02735901, 18.98958015], [73.02735901, 18.99041748], [73.02708435, 18.99041748], [73.02708435, 18.99069405], [73.02735901, 18.99069023], [73.02735901, 18.99124908], [73.0276413, 18.99124908], [73.0276413, 18.9920826], [73.02819061, 18.9920826], [73.02819824, 18.99180603], [73.0284729, 18.99181175], [73.0284729, 18.99124908], [73.02902985, 18.99124908], [73.02902985, 18.99153137], [73.02960205, 18.99153137], [73.02960205, 18.99181175], [73.02986145, 18.99181175], [73.02986145, 18.99235916], [73.03013611, 18.99235916], [73.03013611, 18.99263954], [73.03098297, 18.99263954], [73.03098297, 18.99292183], [73.03125, 18.99291611], [73.03125, 18.99319458], [73.03151703, 18.99319077], [73.03151703, 18.99374962], [73.03180695, 18.99374962], [73.03180695, 18.99430466], [73.0320816, 18.99430466], [73.0320816, 18.99458122], [73.03234863, 18.99458122], [73.03234863, 18.99681091], [73.0320816, 18.99680328], [73.0320816, 18.99708557], [73.03180695, 18.99707985], [73.03180695, 18.99792099], [73.0320816, 18.99791718], [73.0320816, 18.99819565], [73.03236389, 18.99819565], [73.03234863, 18.99915123], [73.03234863, 18.99930954], [73.03180695, 18.99930573], [73.03180695, 18.9995842], [73.03151703, 18.99958038], [73.03152466, 19.00013924], [73.03152466, 19.00069427], [73.03125, 19.00069427], [73.03125, 19.00097275], [73.03098297, 19.00097084], [73.03098297, 19.00125122], [73.0304184, 19.00125122], [73.0304184, 19.00152969], [73.03013611, 19.00152969], [73.03013611, 19.00180817], [73.02986145, 19.00180817], [73.02986145, 19.00209045], [73.02928925, 19.00209045], [73.02928925, 19.00180817], [73.02819824, 19.00180817], [73.02819061, 19.00152969], [73.02625275, 19.00152969], [73.02625275, 19.00180817], [73.02597046, 19.00180817], [73.02597046, 19.00209045], [73.02541351, 19.00208282], [73.02541351, 19.0023613], [73.02375031, 19.0023613], [73.02375031, 19.00208282], [73.02319336, 19.00209045], [73.02319336, 19.00152969], [73.01985931, 19.00152969], [73.01985931, 19.00097084], [73.01958466, 19.00097275], [73.01958466, 19.00013924], [73.01957703, 18.99958038], [73.01902771, 18.9995842], [73.01902771, 18.99930573], [73.01763916, 18.99930954], [73.01763916, 18.99901962], [73.01708221, 18.99902725], [73.01708221, 18.99875069], [73.01680756, 18.99875069], [73.01680756, 18.99847031], [73.01597595, 18.99847031], [73.01597595, 18.99875069], [73.01457977, 18.99875069], [73.01457977, 18.99902725], [73.01403046, 18.99902725], [73.01403046, 18.99875069], [73.01264191, 18.99875069], [73.01264191, 18.99902725], [73.01180267, 18.99902725], [73.01180267, 18.99875069], [73.00875092, 18.99875069], [73.00875092, 18.9995842], [73.00791931, 18.99958038], [73.00791931, 19.00014114], [73.00791931, 19.00041962], [73.00763702, 19.00041771], [73.00763702, 19.00069427], [73.00680542, 19.00069427], [73.00680542, 19.00097275], [73.00653076, 19.00097084], [73.00653076, 19.00125122], [73.00596619, 19.00125122], [73.00596619, 19.00152969], [73.00374603, 19.00152969], [73.00374603, 19.00125122], [73.00319672, 19.00125122], [73.00319672, 19.00152969], [73.0029068, 19.00152969], [73.0029068, 19.00291824], [73.00263977, 19.00291634], [73.00263977, 19.00347137], [73.00235748, 19.00347137], [73.00235748, 19.00486183], [73.00208282, 19.00485992], [73.00208282, 19.00625038], [73.00180817, 19.00625038], [73.00180817, 19.00681114], [73.00152588, 19.00681114], [73.00152588, 19.0098629], [73.00180817, 19.0098629], [73.00180817, 19.0118103], [73.00152588, 19.01180649], [73.00152588, 19.01236153], [73.00180817, 19.01235962], [73.00180817, 19.01264], [73.00208282, 19.01264], [73.00208282, 19.01432037], [73.00180817, 19.01430511], [73.00180817, 19.01458359], [73.00152588, 19.01458359], [73.00152588, 19.01486206], [73.00096893, 19.01486015], [73.00096893, 19.01542091], [73.00068665, 19.01542091], [73.00068665, 19.01680756], [73.00096893, 19.01680756], [73.00096893, 19.01736069], [73.00125122, 19.01736069], [73.00125122, 19.01763916], [73.00152588, 19.01763916], [73.00152588, 19.01792145], [73.00180817, 19.01791573], [73.00180817, 19.0181942], [73.00208282, 19.0181942], [73.00208282, 19.01847267], [73.00237274, 19.01847076], [73.00237274, 19.01903152], [73.00263977, 19.01903152], [73.00263977, 19.0193119], [73.00291443, 19.01930618], [73.00291443, 19.02069473], [73.00263977, 19.02069473], [73.00263977, 19.0209713], [73.0029068, 19.02096939], [73.0029068, 19.02124977], [73.00319672, 19.02124977], [73.00319672, 19.02153015], [73.00347137, 19.02152824], [73.00347137, 19.02180481], [73.00319672, 19.02180481], [73.00319672, 19.02236366], [73.00347137, 19.02235985], [73.00347137, 19.02292061], [73.00319672, 19.02292061], [73.00319672, 19.02486038], [73.00347137, 19.02486038], [73.00347137, 19.02542114], [73.00374603, 19.02542114], [73.00374603, 19.02626038], [73.00402832, 19.02626038], [73.00402832, 19.02763939], [73.00374603, 19.02763939], [73.00374603, 19.02932167], [73.00347137, 19.02930641], [73.00347137, 19.02958298], [73.00319672, 19.02958107], [73.00319672, 19.03013992], [73.00291443, 19.03013992], [73.00291443, 19.03097153], [73.00263977, 19.03096962], [73.00263977, 19.03124809], [73.00235748, 19.03124809], [73.00235748, 19.03236008], [73.00208282, 19.03235817], [73.00208282, 19.03292274], [73.00180817, 19.03292274], [73.00180817, 19.03430939], [73.00152588, 19.03430557], [73.00152588, 19.03458214], [73.00180817, 19.03458023], [73.00180817, 19.03541946], [73.00152588, 19.03541756], [73.00152588, 19.03569221], [73.00125122, 19.03569221], [73.00125122, 19.0359745], [73.00096893, 19.03597069], [73.00096893, 19.03625107], [73.00068665, 19.03625107], [73.00068665, 19.03680992], [73.00041962, 19.03680611], [73.00041962, 19.03708458], [73.00068665, 19.03708076], [73.00068665, 19.03736115], [73.00041962, 19.03736115], [73.00041962, 19.03763962], [73.00069427, 19.03763962], [73.00069427, 19.03958321], [73.00041962, 19.03957939], [73.00041962, 19.04042053], [73.00013733, 19.04042053], [72.99958038, 19.04041672], [72.99958038, 19.04097176], [72.99930573, 19.04097176], [72.99930573, 19.04208374], [72.99903107, 19.04207993], [72.99903107, 19.04375076], [72.99874878, 19.04375076], [72.99874878, 19.04486084], [72.99846649, 19.04486084], [72.99846649, 19.04874992], [72.99819183, 19.04874992], [72.99819183, 19.0490303], [72.99791718, 19.0490284], [72.99791718, 19.04958153], [72.99764252, 19.04957962], [72.99764252, 19.05014038], [72.99736023, 19.05014038], [72.99736023, 19.05042076], [72.99708557, 19.05041695], [72.99708557, 19.05097389], [72.99680328, 19.05097008], [72.99680328, 19.05125046], [72.99652863, 19.05125046], [72.99652863, 19.05153084], [72.99623871, 19.05153084], [72.99623871, 19.05181122], [72.99597168, 19.05181122], [72.99597168, 19.05264091], [72.99569702, 19.05263901], [72.99568176, 19.05318069], [72.9954071, 19.05319977], [72.9954071, 19.05375099], [72.99514008, 19.05375099], [72.99514008, 19.05430984], [72.99485779, 19.05430984], [72.99485779, 19.05486107], [72.99458313, 19.05486107], [72.99458313, 19.05541992], [72.99430847, 19.05541611], [72.99430847, 19.05597305], [72.99402618, 19.05597115], [72.99402618, 19.05625916], [72.99430847, 19.05624962], [72.99430847, 19.05680466], [72.99402618, 19.05680466], [72.99402618, 19.05708313], [72.99375153, 19.05708122], [72.99375153, 19.05791855], [72.99346924, 19.05791664], [72.99346924, 19.05847168], [72.99317932, 19.05846977], [72.99317932, 19.05874825], [72.99291992, 19.05874825], [72.99291992, 19.05903244], [72.99236298, 19.05902863], [72.99236298, 19.05930519], [72.99208069, 19.05930519], [72.99208069, 19.05958366], [72.99124908, 19.05958176], [72.99124908, 19.05986023], [72.99069214, 19.05986023], [72.99069214, 19.06014252], [72.98986053, 19.06014252], [72.98986053, 19.0604229], [72.98874664, 19.06041718], [72.98874664, 19.06069374], [72.98847198, 19.06069374], [72.98847198, 19.06097031], [72.98819733, 19.06097031], [72.98819733, 19.06108093], [72.98819733, 19.06125259], [72.98792267, 19.06125259], [72.98792267, 19.06153107], [72.98707581, 19.06153107], [72.98707581, 19.06180954], [72.98680878, 19.06180573], [72.98680878, 19.06208229], [72.98568726, 19.06208038], [72.98568726, 19.06236076], [72.98486328, 19.06236076], [72.98486328, 19.06264114], [72.98236084, 19.06264114], [72.98236084, 19.06236076], [72.98014069, 19.06236076], [72.98014069, 19.06208038], [72.97846985, 19.06208229], [72.97846985, 19.06180573], [72.9779129, 19.06180954], [72.9779129, 19.06153107], [72.97598267, 19.06153107], [72.97598267, 19.06125259], [72.97458649, 19.06125259], [72.97458649, 19.06097031], [72.9734726, 19.06097031], [72.9734726, 19.06069374], [72.97264099, 19.06069374], [72.97264099, 19.06041718], [72.9715271, 19.0604229], [72.9715271, 19.06014252], [72.97070313, 19.06014252], [72.97070313, 19.05986023], [72.96985626, 19.05986023], [72.96985626, 19.05958176], [72.9695816, 19.05958176], [72.9695816, 19.05986023], [72.96847534, 19.05986023], [72.96847534, 19.05958366], [72.96819305, 19.05958366], [72.96819305, 19.05930519], [72.9679184, 19.05930519], [72.9679184, 19.05902863], [72.96626282, 19.05903244], [72.96626282, 19.05874825], [72.96541595, 19.05874825], [72.96541595, 19.05846977], [72.9631958, 19.05847168], [72.9631958, 19.05819511], [72.96263885, 19.05820084], [72.96263885, 19.05791855], [72.96235657, 19.05791855], [72.96235657, 19.05680084], [72.96208191, 19.05680466], [72.96208191, 19.0518055], [72.96235657, 19.05181122], [72.96235657, 19.04957962], [72.96208191, 19.04958153], [72.96208191, 19.04930305], [72.96235657, 19.04931068], [72.96235657, 19.0490303], [72.96208191, 19.0490303], [72.96208191, 19.04706764], [72.96180725, 19.0470829], [72.96180725, 19.04680634], [72.96208191, 19.04681015], [72.96208191, 19.04653168], [72.96180725, 19.04653168], [72.96180725, 19.04569054], [72.96152496, 19.04569435], [72.96152496, 19.04541588], [72.96125031, 19.0454216], [72.96125031, 19.04236031], [72.96097565, 19.04236031], [72.96097565, 19.03958321], [72.96069336, 19.03958321], [72.96069336, 19.03847313], [72.9604187, 19.03847313], [72.9604187, 19.03791428], [72.96012878, 19.03792], [72.96012878, 19.03680992], [72.95986176, 19.03680992], [72.95986176, 19.03597069], [72.9595871, 19.0359745], [72.9595871, 19.03569221], [72.95930481, 19.03569221], [72.95930481, 19.03541756], [72.95903015, 19.03541946], [72.95903015, 19.03486061], [72.95871735, 19.0348568], [72.9587326, 19.03458023], [72.95874786, 19.03430557], [72.95847321, 19.03430939], [72.95847321, 19.03403282], [72.95819092, 19.03403282], [72.95819092, 19.03347015], [72.95791626, 19.03347015], [72.95791626, 19.03319359], [72.9576416, 19.03319359], [72.9576416, 19.03263855], [72.95735931, 19.03264236], [72.95735931, 19.03206825], [72.95708466, 19.03208351], [72.95708466, 19.03157043], [72.95708466, 19.03069496], [72.95680237, 19.03070068], [72.95680237, 19.03013992], [72.95652771, 19.03013992], [72.95652771, 19.02932167], [72.95625305, 19.02932167], [72.95625305, 19.02902985], [72.95597076, 19.02902985], [72.95597076, 19.02874947], [72.95569611, 19.02874947], [72.95569611, 19.02819061], [72.95541382, 19.02819443], [72.95541382, 19.02763939], [72.95513916, 19.02763939], [72.95513916, 19.02736092], [72.95485687, 19.02736092], [72.95485687, 19.02708054], [72.95402527, 19.02708244], [72.95402527, 19.02680779], [72.95347595, 19.02680969], [72.95347595, 19.02597046], [72.95319366, 19.02597237], [72.95319366, 19.0256958], [72.95263672, 19.0256958], [72.95263672, 19.02541733], [72.95207977, 19.02542114], [72.95207977, 19.02514076], [72.95181274, 19.02514076], [72.95181274, 19.02486038], [72.95153046, 19.02486038], [72.95153046, 19.02431107], [72.95096588, 19.02431107], [72.95096588, 19.02403069], [72.95069122, 19.02403069], [72.95069122, 19.02375031], [72.95041656, 19.02375031], [72.95041656, 19.02346992], [72.95014191, 19.02347374], [72.95014191, 19.02319527], [72.94985962, 19.02319527], [72.94985962, 19.02263832], [72.94957733, 19.02264023], [72.94957733, 19.02235985], [72.94930267, 19.02236366], [72.94930267, 19.02180481], [72.94847107, 19.02180481], [72.94847107, 19.02152824], [72.94790649, 19.02153015], [72.94790649, 19.02124977], [72.94763947, 19.02124977], [72.94763947, 19.02069283], [72.94736481, 19.02069473], [72.94736481, 19.02041626], [72.9465332, 19.02042007], [72.9465332, 19.02012825], [72.94625092, 19.02013969], [72.94625092, 19.01985931], [72.94568634, 19.01985931], [72.94568634, 19.01958084], [72.94513702, 19.01958275], [72.94513702, 19.01902771], [72.94486237, 19.01903152], [72.94486237, 19.01874924], [72.94458008, 19.01874924], [72.94458008, 19.01903152], [72.94431305, 19.01903152], [72.94431305, 19.01874924], [72.94403076, 19.01874924], [72.94403076, 19.01847076], [72.94374847, 19.01847267], [72.94374847, 19.0181942], [72.94347382, 19.0181942], [72.94347382, 19.01791763], [72.94317627, 19.01792145], [72.94291687, 19.01792145], [72.94291687, 19.01763916], [72.94264221, 19.01763916], [72.94264221, 19.01736069], [72.94235992, 19.01736069], [72.94235992, 19.01708984], [72.94097137, 19.01708984], [72.94097137, 19.01680756], [72.9404068, 19.01680756], [72.9404068, 19.01652908], [72.94013977, 19.01652908], [72.94013977, 19.01625061], [72.93985748, 19.01625061], [72.93985748, 19.01597023], [72.93902588, 19.01597214], [72.93902588, 19.01569366], [72.93875122, 19.01569366], [72.93875122, 19.0154171], [72.93846893, 19.01542091], [72.93846893, 19.01514053], [72.93818665, 19.01514053], [72.93818665, 19.01486015], [72.93791962, 19.01486206], [72.93791962, 19.01458359], [72.93763733, 19.01458359], [72.93763733, 19.01430511], [72.93736267, 19.01432037], [72.93736267, 19.01403046], [72.93653107, 19.01403046], [72.93653107, 19.01375008], [72.93624878, 19.01375008], [72.93624878, 19.0134697], [72.93569183, 19.0134716], [72.93569183, 19.01319695], [72.93541718, 19.01320076], [72.93541718, 19.01292038], [72.93514252, 19.01292038], [72.93514252, 19.01264], [72.93486023, 19.01264], [72.93486023, 19.01235962], [72.93458557, 19.01236153], [72.93458557, 19.01208305], [72.93430328, 19.01208305], [72.93430328, 19.01180649], [72.93402863, 19.0118103], [72.93402863, 19.01152992], [72.93374634, 19.01152992], [72.93374634, 19.01124954], [72.93289948, 19.01124954], [72.93289948, 19.01069069], [72.93235779, 19.0106926], [72.93235779, 19.01041412], [72.93180847, 19.01041985], [72.93180847, 19.0098629], [72.93152618, 19.0098629], [72.93152618, 19.00958061], [72.93096924, 19.00958443], [72.93096924, 19.00930405], [72.93015289, 19.00930977], [72.93015289, 19.00875282], [72.92986298, 19.00875282], [72.92986298, 19.00847054], [72.92930603, 19.00847054], [72.92930603, 19.00819206], [72.92874908, 19.00819206], [72.92874908, 19.0079174], [72.9284668, 19.00792122], [72.9284668, 19.00764275], [72.92819214, 19.00764275], [72.92819214, 19.00736046], [72.92763519, 19.00736046], [72.92763519, 19.00708389], [72.92736053, 19.00708389], [72.92736053, 19.00680542], [72.92679596, 19.00681114], [72.92679596, 19.00653267], [72.92652893, 19.00653267], [72.92652893, 19.00625038], [72.92597198, 19.00625038], [72.92597198, 19.00597191], [72.92569733, 19.00597191], [72.92569733, 19.00569534], [72.92514038, 19.00570107], [72.92514038, 19.00542068], [72.92457581, 19.00542068], [72.92457581, 19.00515175], [72.92430878, 19.00515175], [72.92430878, 19.00457954], [72.92402649, 19.00458336], [72.92402649, 19.00430489], [72.92430878, 19.00430489], [72.92430878, 19.00402832], [72.92375183, 19.00402832], [72.92375183, 19.00374985], [72.92318726, 19.00374985], [72.92318726, 19.00346947], [72.92263794, 19.00347137], [72.92263794, 19.00319481], [72.92208099, 19.00319481], [72.92208099, 19.00291634], [72.92180634, 19.00291824], [72.92180634, 19.00209045], [72.92151642, 19.00209045], [72.92151642, 19.00180817], [72.92069244, 19.00180817], [72.92069244, 19.00152969], [72.92014313, 19.00152969], [72.92014313, 19.00125122], [72.91986084, 19.00125122], [72.91986084, 19.00097084], [72.91958618, 19.00097275], [72.91958618, 19.00069427], [72.91902924, 19.00069427], [72.91902924, 19.00013924], [72.91847229, 19.00014114], [72.91847229, 18.99958038], [72.91374969, 18.99958038], [72.91374969, 18.99986076], [72.91347504, 18.99986076], [72.91347504, 18.9995842], [72.91319275, 18.9995842], [72.91319275, 18.99930573], [72.91179657, 18.99930954], [72.91179657, 18.99901962], [72.91152954, 18.99901962], [72.91152954, 18.99930954], [72.90875244, 18.99930573], [72.90875244, 18.9995842], [72.90736389, 18.9995842], [72.90736389, 18.99930573], [72.90680695, 18.99930954], [72.90680695, 18.99818993], [72.90631104, 18.99819183], [72.90597534, 18.99819565], [72.90597534, 18.9976387], [72.90625, 18.99764061], [72.90625, 18.99707985], [72.90652466, 18.99708557], [72.90652466, 18.99652863], [72.90625, 18.99653053], [72.90625, 18.99681091], [72.90597534, 18.99680328], [72.90597534, 18.99708557], [72.90569305, 18.99707985], [72.90569305, 18.99736023], [72.90513611, 18.99736023], [72.90513611, 18.99653053], [72.9054184, 18.99653053], [72.9054184, 18.99596024], [72.90569305, 18.99597359], [72.90569305, 18.99569321], [72.90598297, 18.99570084], [72.90598297, 18.99542046], [72.90625, 18.99542046], [72.90625, 18.99514008], [72.90651703, 18.99514008], [72.90651703, 18.9948597], [72.90680695, 18.99486351], [72.90680695, 18.99458122], [72.9070816, 18.99458122], [72.9070816, 18.99430466], [72.90736389, 18.99430466], [72.90736389, 18.99402809], [72.90763855, 18.99403191], [72.90763855, 18.99374962], [72.90791321, 18.99374962], [72.90791321, 18.99346924], [72.9081955, 18.99347115], [72.9081955, 18.99319458], [72.90847015, 18.99319458], [72.90847015, 18.99291611], [72.90875244, 18.99292183], [72.90875244, 18.99263954], [72.90930176, 18.99263954], [72.90930176, 18.99124908], [72.90791321, 18.99124908], [72.90791321, 18.99153137], [72.9081955, 18.99152756], [72.9081955, 18.9920826], [72.90763855, 18.99208069], [72.90763855, 18.99263954], [72.90736389, 18.99263954], [72.90736389, 18.99319458], [72.9070816, 18.99319458], [72.9070816, 18.99347115], [72.90680695, 18.99346924], [72.90680695, 18.99374962], [72.90651703, 18.99374962], [72.90651703, 18.99403191], [72.90625, 18.99402809], [72.90625, 18.99430466], [72.90597534, 18.99430466], [72.90597534, 18.99486351], [72.90569305, 18.9948597], [72.90569305, 18.99514008], [72.9054184, 18.99514008], [72.9054184, 18.99542046], [72.90486145, 18.99542046], [72.90486145, 18.9948597], [72.90458679, 18.99486351], [72.90458679, 18.99402809], [72.90486145, 18.99403191], [72.90486145, 18.99346924], [72.90513611, 18.99347115], [72.90513611, 18.99263954], [72.9054184, 18.99263954], [72.9054184, 18.99181175], [72.90569305, 18.99181175], [72.90569305, 18.99153137], [72.90625, 18.99153137], [72.90625, 18.99097061], [72.90652466, 18.99097252], [72.90652466, 18.99069405], [72.90597534, 18.99069405], [72.90597534, 18.99041748], [72.9054184, 18.99041748], [72.9054184, 18.99014854], [72.90513611, 18.99014854], [72.90513611, 18.99041748], [72.90486145, 18.99041748], [72.90486145, 18.9920826], [72.90458679, 18.99208069], [72.90458679, 18.99263954], [72.9043045, 18.99263954], [72.9043045, 18.99319458], [72.90402985, 18.99319077], [72.90402985, 18.99570084], [72.90374756, 18.99570084], [72.90374756, 18.99625015], [72.9034729, 18.99625015], [72.9034729, 18.99681091], [72.90319824, 18.99680328], [72.90319824, 18.99708557], [72.90291595, 18.99707985], [72.90291595, 18.99736023], [72.89875031, 18.99736023], [72.89875031, 18.99707985], [72.89763641, 18.99708557], [72.89763641, 18.99680328], [72.89653015, 18.99681091], [72.89653015, 18.99653053], [72.89597321, 18.99652863], [72.89597321, 18.99819565], [72.89653015, 18.99819565], [72.89653015, 18.99791718], [72.89763641, 18.99791718], [72.89763641, 18.99819565], [72.89736176, 18.99819565], [72.89736176, 18.99902725], [72.89678955, 18.99901962], [72.89678955, 18.99930954], [72.89569092, 18.99930954], [72.89569092, 18.99901962], [72.89541626, 18.99902725], [72.89541626, 18.9995842], [72.89524078, 18.9995842], [72.89041901, 18.99958038], [72.89041901, 18.99986076], [72.88986206, 18.99986076], [72.88986206, 18.99958038], [72.88597107, 18.99958038], [72.88597107, 19.00014114], [72.88597107, 19.00374985], [72.88569641, 19.00374985], [72.88569641, 19.00764275], [72.88540649, 19.00764275], [72.88541412, 19.00819206], [72.88513947, 19.00819016], [72.88513947, 19.00902939], [72.88412476, 19.00902939], [72.88181305, 19.00902939], [72.88181305, 19.00875282], [72.88180542, 19.0079174], [72.88069153, 19.00792122], [72.88069153, 19.00764275], [72.87985992, 19.00764275], [72.87985992, 19.00736046], [72.87902832, 19.00736046], [72.87902832, 19.00708389], [72.87430573, 19.00708389], [72.87430573, 19.00680542], [72.87319183, 19.00681114], [72.87319183, 19.00653267], [72.87236023, 19.00653267], [72.87236023, 19.00625038], [72.87097168, 19.00625038], [72.87097168, 19.00597191], [72.87069702, 19.00597191], [72.87069702, 19.00541687], [72.87014008, 19.00542068], [72.87014008, 19.00515175], [72.86930847, 19.00515175], [72.86930847, 19.00485992], [72.86791992, 19.00486183], [72.86791992, 19.00458336], [72.86736298, 19.00458336], [72.86736298, 19.00486183], [72.86569214, 19.00486183], [72.86569214, 19.00458336], [72.86486053, 19.00458336], [72.86486053, 19.00430489], [72.86430359, 19.00430489], [72.86430359, 19.00402832], [72.86403656, 19.00402832], [72.86403656, 19.00374985], [72.86374664, 19.00374985], [72.86374664, 19.00346947], [72.86319733, 19.00347137], [72.86319733, 19.00319481], [72.86264038, 19.00319481], [72.86264038, 19.00291634], [72.86207581, 19.00291824], [72.86207581, 19.00180817], [72.86180878, 19.00180817], [72.86180878, 19.00069046], [72.86152649, 19.00069427], [72.86152649, 19.00041771], [72.86096954, 19.00041962], [72.86096954, 19.00014114], [72.86067963, 19.00014114], [72.86067963, 18.99986076], [72.86042023, 18.99986076], [72.86042023, 18.99958038], [72.86013794, 18.9995842], [72.86013794, 18.99875069], [72.85986328, 18.99875069], [72.85986328, 18.99818993], [72.86013794, 18.99819565], [72.86013794, 18.99791718], [72.86042023, 18.99792099], [72.86042023, 18.99736023], [72.86067963, 18.99736023], [72.86067963, 18.99707985], [72.86096954, 18.99708557], [72.86096954, 18.99652863], [72.86125183, 18.99653053], [72.86125183, 18.99596024], [72.86152649, 18.99597359], [72.86152649, 18.99569321], [72.86042023, 18.99570084], [72.86042023, 18.99403191], [72.86013794, 18.99403191], [72.86013794, 18.99374962], [72.85986328, 18.99374962], [72.85986328, 18.99346924], [72.85874939, 18.99347115], [72.85874939, 18.99319458], [72.85902405, 18.99319458], [72.85902405, 18.99291611], [72.85874939, 18.99292183], [72.85874939, 18.99263954], [72.8584671, 18.99263954], [72.8584671, 18.99235916], [72.85708618, 18.99235916], [72.85708618, 18.99208069], [72.85680389, 18.9920826], [72.85680389, 18.99152756], [72.85708618, 18.99153137], [72.85708618, 18.99097061], [72.85736084, 18.99097252], [72.85736084, 18.9901371], [72.85764313, 18.99014854], [72.85764313, 18.98958015], [72.85791779, 18.98958397], [72.85791779, 18.98902893], [72.85819244, 18.98903084], [72.85819244, 18.9881897], [72.85847473, 18.98819351], [72.85847473, 18.98763847], [72.85874939, 18.98764038], [72.85874939, 18.98707962], [72.85902405, 18.98708344], [72.85902405, 18.9865284], [72.85930634, 18.9865303], [72.85930634, 18.98596954], [72.85958099, 18.98597145], [72.85958099, 18.98541641], [72.85986328, 18.98542023], [72.85986328, 18.98485947], [72.86013794, 18.98486137], [72.86013794, 18.98430634], [72.86042023, 18.98431015], [72.86042023, 18.98347092], [72.86069489, 18.98347473], [72.86069489, 18.98236275], [72.86096954, 18.98236275], [72.86096954, 18.98153114], [72.86067963, 18.98153114], [72.86067963, 18.98125267], [72.86042023, 18.98125267], [72.86042023, 18.98097992], [72.86013794, 18.98097992], [72.86013794, 18.98069191], [72.85986328, 18.98069382], [72.85986328, 18.98041725], [72.85930634, 18.98042107], [72.85930634, 18.98014259], [72.85901642, 18.98014259], [72.85901642, 18.97986031], [72.85874939, 18.97986031], [72.85874939, 18.97958183], [72.85847473, 18.97958374], [72.85847473, 18.97930527], [72.85819244, 18.9793129], [72.85819244, 18.97874832], [72.85791016, 18.97874832], [72.85791016, 18.97846985], [72.8576355, 18.97847176], [72.8576355, 18.97819519], [72.85736084, 18.97819519], [72.85736084, 18.97847176], [72.85624695, 18.97846985], [72.85624695, 18.97874832], [72.85514069, 18.97874832], [72.85514069, 18.97903252], [72.85402679, 18.97903252], [72.85402679, 18.9793129], [72.85263824, 18.9793129], [72.85263824, 18.97874832], [72.8529129, 18.97874832], [72.8529129, 18.97846985], [72.85402679, 18.97847176], [72.85402679, 18.97819519], [72.85486603, 18.97821045], [72.85486603, 18.97792053], [72.85569763, 18.97792053], [72.85569763, 18.97680092], [72.85541534, 18.97680473], [72.85541534, 18.97652817], [72.8548584, 18.97652817], [72.8548584, 18.97680473], [72.85375214, 18.97680473], [72.85375214, 18.97708321], [72.85263824, 18.97708321], [72.85263824, 18.97736168], [72.85124969, 18.97736168], [72.85124969, 18.97680473], [72.85180664, 18.97680473], [72.85180664, 18.97652817], [72.85263824, 18.97652817], [72.85263824, 18.97624969], [72.85402679, 18.97624969], [72.85402679, 18.97597122], [72.85541534, 18.97597313], [72.85541534, 18.97430611], [72.8548584, 18.97430611], [72.8548584, 18.97458267], [72.85375214, 18.97458267], [72.85375214, 18.97486115], [72.85152435, 18.97486115], [72.85152435, 18.97458267], [72.85124969, 18.97458267], [72.85124969, 18.97430611], [72.85151672, 18.97430992], [72.85151672, 18.97402954], [72.8529129, 18.97402954], [72.8529129, 18.97375107], [72.85375214, 18.97375107], [72.85375214, 18.97347069], [72.85346985, 18.9734726], [72.85346985, 18.97291756], [72.85320282, 18.97291946], [72.85320282, 18.97236061], [72.8529129, 18.97236061], [72.8529129, 18.97208023], [72.85180664, 18.97208023], [72.85180664, 18.97236061], [72.85124969, 18.97236061], [72.85124969, 18.97264099], [72.8501358, 18.97264099], [72.8501358, 18.97208023], [72.85041809, 18.97208595], [72.85041809, 18.97125053], [72.85069275, 18.97125053], [72.85069275, 18.97068977], [72.85097504, 18.9706955], [72.85097504, 18.96930313], [72.85151672, 18.96931076], [72.85151672, 18.96903992], [72.8520813, 18.96903992], [72.8520813, 18.96764183], [72.85124969, 18.96764183], [72.85124969, 18.96735954], [72.85097504, 18.96736336], [72.85097504, 18.96708107], [72.85069275, 18.96708107], [72.85069275, 18.96680641], [72.85041809, 18.96681023], [72.85041809, 18.96653175], [72.8501358, 18.96653175], [72.8501358, 18.96624947], [72.84986115, 18.96624947], [72.84986115, 18.96542168], [72.84958649, 18.96542168], [72.84958649, 18.9643116], [72.84929657, 18.9643116], [72.84929657, 18.96318817], [72.84902954, 18.96319389], [72.84902954, 18.96208382], [72.84874725, 18.96208382], [72.84874725, 18.96097183], [72.8484726, 18.96097183], [72.8484726, 18.95958328], [72.84819794, 18.95958328], [72.84819794, 18.95791626], [72.84792328, 18.95792007], [72.84792328, 18.95681], [72.84764099, 18.95681], [72.84764099, 18.95597076], [72.8473587, 18.95597458], [72.8473587, 18.95486069], [72.84707642, 18.95486069], [72.84707642, 18.95375252], [72.84680176, 18.95375252], [72.84680176, 18.94819069], [72.8465271, 18.9481945], [72.8465271, 18.94736099], [72.84625244, 18.94736099], [72.84625244, 18.94625092], [72.84597015, 18.94625092], [72.84597015, 18.94431114], [72.84570313, 18.94431114], [72.84570313, 18.94153023], [72.84541321, 18.94153023], [72.84541321, 18.93985939], [72.84513855, 18.93985939], [72.84513855, 18.93930626], [72.84485626, 18.93931007], [72.84485626, 18.93736076], [72.8445816, 18.93736076], [72.8445816, 18.93708038], [72.84430695, 18.9370842], [72.84430695, 18.93680573], [72.84401703, 18.93680763], [72.84401703, 18.93652916], [72.84375, 18.93652916], [72.84375, 18.93597031], [72.84347534, 18.93597221], [72.84347534, 18.93569374], [72.84319305, 18.93569374], [72.84319305, 18.9351387], [72.84348297, 18.93514061], [72.84348297, 18.93375015], [72.84375, 18.93375015], [72.84375, 18.93208122], [72.84402466, 18.93208313], [72.84402466, 18.92986107], [72.84430695, 18.92987061], [72.84430695, 18.92902946], [72.84401703, 18.92902946], [72.84401703, 18.92847061], [72.84347534, 18.92847061], [72.84347534, 18.92819214], [72.84263611, 18.92819214], [72.84263611, 18.92847061], [72.84236145, 18.92847061], [72.84236145, 18.9287529], [72.84208679, 18.9287529], [72.84208679, 18.93124962], [72.8418045, 18.93124962], [72.8418045, 18.93208313], [72.84152985, 18.93208313], [72.84152985, 18.9323616], [72.84069824, 18.9323616], [72.84069061, 18.9304142], [72.84041595, 18.93041992], [72.84041595, 18.93013954], [72.83985901, 18.93013954], [72.83985901, 18.9295845], [72.83958435, 18.9295845], [72.83958435, 18.92930603], [72.83930206, 18.92930984], [72.83930206, 18.92902946], [72.83875275, 18.92902946], [72.83875275, 18.9287529], [72.83847046, 18.9287529], [72.83847046, 18.92847061], [72.8381958, 18.92847061], [72.8381958, 18.92819214], [72.83847046, 18.92819214], [72.83847046, 18.92791748], [72.83875275, 18.92791939], [72.83875275, 18.92764282], [72.83930206, 18.92764282], [72.83930206, 18.92791939], [72.84041595, 18.92791939], [72.84041595, 18.92764282], [72.84069061, 18.92764282], [72.84069061, 18.92736053], [72.84041595, 18.92736053], [72.84041595, 18.92681122], [72.8401413, 18.92681122], [72.8401413, 18.92653275], [72.83957672, 18.92653275], [72.83957672, 18.92625237], [72.83930206, 18.92625237], [72.83930206, 18.92597008], [72.83875275, 18.92597008], [72.83875275, 18.92569542], [72.83847046, 18.9256897], [72.83847046, 18.92541695], [72.83875275, 18.92542267], [72.83875275, 18.92485809], [72.8390274, 18.92486191], [72.8390274, 18.92430496], [72.83930206, 18.92431068], [72.83930206, 18.9240284], [72.83957672, 18.9240284], [72.83957672, 18.92346954], [72.83985901, 18.92347145], [72.83985901, 18.92291641], [72.8401413, 18.92291832], [72.8401413, 18.92235947], [72.8409729, 18.92235947], [72.8409729, 18.92263985], [72.84124756, 18.92263985], [72.84124756, 18.92291832], [72.84152985, 18.92291641], [72.84152985, 18.92319489], [72.8418045, 18.92319489], [72.8418045, 18.92347145], [72.84236145, 18.92347145], [72.84236145, 18.92374992], [72.84263611, 18.92374039], [72.84263611, 18.9240284], [72.8429184, 18.9240284], [72.8429184, 18.92458344], [72.84319305, 18.92458344], [72.84319305, 18.92486191], [72.84375, 18.92485809], [72.84375, 18.92542267], [72.84402466, 18.92541695], [72.84402466, 18.92569351], [72.84430695, 18.92569351], [72.84430695, 18.92597008], [72.84486389, 18.92597008], [72.84486389, 18.92486191], [72.8445816, 18.92486191], [72.8445816, 18.92430496], [72.84430695, 18.92431068], [72.84430695, 18.9240284], [72.84375, 18.9240284], [72.84375, 18.92374039], [72.84347534, 18.92374992], [72.84347534, 18.92347145], [72.84319305, 18.92347145], [72.84319305, 18.92319489], [72.8429184, 18.92319489], [72.8429184, 18.92291641], [72.84263611, 18.92291832], [72.84263611, 18.92235947], [72.84236145, 18.92236137], [72.84236145, 18.9220829], [72.84208679, 18.9220829], [72.84208679, 18.92180634], [72.84179688, 18.92180824], [72.84179688, 18.92152977], [72.84152985, 18.92152977], [72.84152985, 18.92097092], [72.84124756, 18.92097282], [72.84124756, 18.92069435], [72.8409729, 18.92069435], [72.8409729, 18.92041779], [72.84041595, 18.92041969], [72.84041595, 18.92014122], [72.83957672, 18.92014122], [72.83957672, 18.91986084], [72.83875275, 18.91986084], [72.83875275, 18.92014122], [72.8381958, 18.92014122], [72.8381958, 18.92041969], [72.83791351, 18.92041779], [72.83791351, 18.92069435], [72.8373642, 18.92069435], [72.8373642, 18.92097282], [72.83679962, 18.92097092], [72.83679962, 18.92124939], [72.83651733, 18.92124939], [72.83651733, 18.92152977], [72.83625031, 18.92152977], [72.83625031, 18.92180824], [72.83597565, 18.92180634], [72.83597565, 18.9220829], [72.8354187, 18.9220829], [72.8354187, 18.92236137], [72.83486176, 18.92236137], [72.83486176, 18.92180634], [72.83513641, 18.92180824], [72.83513641, 18.92124939], [72.8345871, 18.92124939], [72.8345871, 18.92152977], [72.83403015, 18.92152977], [72.83403015, 18.92124939], [72.83319092, 18.92124939], [72.83319092, 18.92041969], [72.83291626, 18.92041969], [72.83291626, 18.91930962], [72.8326416, 18.91930962], [72.8326416, 18.91847038], [72.83235931, 18.91847229], [72.83235931, 18.91791725], [72.83207703, 18.9179306], [72.83207703, 18.91736031], [72.83180237, 18.91736031], [72.83180237, 18.91707993], [72.83152771, 18.91708565], [72.83152771, 18.91680336], [72.83125305, 18.91681099], [72.83125305, 18.91653061], [72.83097076, 18.91653061], [72.83097076, 18.91625023], [72.83040619, 18.91625023], [72.83040619, 18.91596985], [72.83097076, 18.91597366], [72.83097076, 18.91569519], [72.83125305, 18.91570091], [72.83125305, 18.91457939], [72.83097076, 18.9145813], [72.83097076, 18.91430473], [72.83069611, 18.91430473], [72.83069611, 18.91402817], [72.83040619, 18.91403008], [72.83040619, 18.91374969], [72.83013916, 18.91374969], [72.83013916, 18.91403008], [72.82958221, 18.91403008], [72.82958221, 18.91319084], [72.82930756, 18.91319466], [72.82930756, 18.91291618], [72.8290329, 18.91292191], [72.8290329, 18.91264153], [72.82875061, 18.91264153], [72.82875061, 18.91235924], [72.82847595, 18.91235924], [72.82847595, 18.91208076], [72.82819366, 18.91208267], [72.82819366, 18.91180611], [72.82791901, 18.91180611], [72.82791901, 18.91152763], [72.82763672, 18.91153145], [72.82763672, 18.91124916], [72.82736206, 18.91124916], [72.82736206, 18.91097069], [72.82707977, 18.9109726], [72.82707977, 18.90986061], [72.82680511, 18.90986061], [72.82680511, 18.9090271], [72.82653046, 18.90903091], [72.82653046, 18.90847015], [72.82624817, 18.90847206], [72.82624817, 18.90819359], [72.82597351, 18.90819359], [72.82597351, 18.90791893], [72.82569122, 18.90792084], [72.82569122, 18.90764046], [72.82541656, 18.90764046], [72.82541656, 18.90736008], [72.82514191, 18.90736008], [72.82514191, 18.90764046], [72.82485962, 18.90764046], [72.82485962, 18.90792084], [72.82458496, 18.90791893], [72.82458496, 18.90819359], [72.82430267, 18.90819359], [72.82430267, 18.90847206], [72.82375336, 18.90847206], [72.82375336, 18.90875053], [72.82347107, 18.908741], [72.82347107, 18.90903091], [72.82319641, 18.90903091], [72.82319641, 18.90930748], [72.82291412, 18.90930557], [72.82291412, 18.90958405], [72.82235718, 18.90958023], [72.82235718, 18.90986061], [72.82180023, 18.90986061], [72.82180023, 18.90958023], [72.82152557, 18.90958405], [72.82152557, 18.90930557], [72.82096863, 18.90930748], [72.82096863, 18.90903091], [72.82068634, 18.90903091], [72.82068634, 18.90847015], [72.82096863, 18.90847206], [72.82096863, 18.90819359], [72.82069397, 18.90819359], [72.82069397, 18.90763855], [72.82041931, 18.90764046], [72.82041931, 18.90736008], [72.81986237, 18.90736198], [72.81986237, 18.90708351], [72.81903076, 18.90708351], [72.81903076, 18.90680695], [72.8188858, 18.90680695], [72.81874084, 18.90681076], [72.81874084, 18.90653038], [72.81846619, 18.90653038], [72.81846619, 18.9034729], [72.81819153, 18.90347481], [72.81819153, 18.90263939], [72.81791687, 18.90263939], [72.81791687, 18.90153122], [72.81764221, 18.90153122], [72.81764221, 18.90097046], [72.81735992, 18.90097046], [72.81735992, 18.90041733], [72.8170929, 18.90042114], [72.8170929, 18.90014267], [72.81680298, 18.90014267], [72.81680298, 18.89957047], [72.81652832, 18.89958382], [72.81652832, 18.89902687], [72.81624603, 18.89903259], [72.81624603, 18.8987484], [72.8154068, 18.8987484], [72.8154068, 18.89819908], [72.81513977, 18.89819908], [72.81513977, 18.89735985], [72.81485748, 18.89736176], [72.81485748, 18.89708328], [72.81458282, 18.89708328], [72.81458282, 18.89680481], [72.81430817, 18.89680481], [72.81430817, 18.89624977], [72.81402588, 18.89624977], [72.81402588, 18.89596939], [72.81375122, 18.8959713], [72.81375122, 18.89569473], [72.81346893, 18.89569473], [72.81346893, 18.89513969], [72.81318665, 18.89513969], [72.81318665, 18.89486122], [72.81291962, 18.89486122], [72.81291962, 18.89458084], [72.81263733, 18.89458275], [72.81263733, 18.89402771], [72.81181335, 18.89402962], [72.81181335, 18.89319038], [72.81153107, 18.8931942], [72.81153107, 18.89263916], [72.81096649, 18.89264107], [72.81096649, 18.89236069], [72.80986023, 18.89236069], [72.80986023, 18.89208031], [72.80930328, 18.89208412], [72.80930328, 18.89180565], [72.80847168, 18.89180946], [72.80847168, 18.89097023], [72.80819702, 18.89097214], [72.80819702, 18.89069557], [72.80791473, 18.89069557], [72.80791473, 18.89097214], [72.80764008, 18.89097023], [72.80764008, 18.89180946], [72.8079071, 18.89180946], [72.8079071, 18.89264107], [72.80819702, 18.89263916], [72.80819702, 18.89347267], [72.80847168, 18.89347076], [72.80847168, 18.89430809], [72.80819702, 18.89430618], [72.80819702, 18.89458275], [72.8079071, 18.89458084], [72.8079071, 18.89486122], [72.80764008, 18.89486122], [72.80764008, 18.89513969], [72.80735779, 18.89513969], [72.80735779, 18.89569473], [72.80708313, 18.89569473], [72.80708313, 18.8959713], [72.80680084, 18.89596939], [72.80680084, 18.89624977], [72.80652618, 18.89624977], [72.80652618, 18.89652824], [72.80625153, 18.89652824], [72.80625153, 18.89708328], [72.80596924, 18.89708328], [72.80596924, 18.89736176], [72.80568695, 18.89735985], [72.80568695, 18.89792061], [72.80541992, 18.89792061], [72.80541992, 18.89819908], [72.80513763, 18.89819908], [72.80513763, 18.8987484], [72.80486298, 18.8987484], [72.80486298, 18.89931107], [72.80458069, 18.89931107], [72.80458069, 18.90014267], [72.80430603, 18.90013885], [72.80430603, 18.90097046], [72.80403137, 18.90097046], [72.80403137, 18.90236282], [72.80374908, 18.90236282], [72.80375671, 18.90374947], [72.80347443, 18.90374947], [72.80347443, 18.90736198], [72.80374908, 18.90736198], [72.80374908, 18.90847206], [72.80403137, 18.90847015], [72.80403137, 18.90930748], [72.80430603, 18.90930557], [72.80430603, 18.90958405], [72.80458069, 18.90958023], [72.80458069, 18.91013908], [72.80486298, 18.91013908], [72.80486298, 18.91041756], [72.80513763, 18.91041756], [72.80513763, 18.9109726], [72.80541992, 18.91097069], [72.80541992, 18.91153145], [72.80569458, 18.91152763], [72.80569458, 18.91180611], [72.80596924, 18.91180038], [72.80596924, 18.91235924], [72.80625153, 18.91235924], [72.80625153, 18.91292191], [72.80652618, 18.91291618], [72.80652618, 18.91319466], [72.80680847, 18.91319466], [72.80680847, 18.91347122], [72.80708313, 18.91346931], [72.80708313, 18.91403008], [72.80735779, 18.91402817], [72.80735779, 18.91430473], [72.80764008, 18.91430473], [72.80764008, 18.9145813], [72.80819702, 18.91457939], [72.80819702, 18.91487122], [72.80847168, 18.91487122], [72.80847168, 18.91457939], [72.80874634, 18.9145813], [72.80874634, 18.91430473], [72.80902863, 18.91430473], [72.80902863, 18.91402817], [72.80930328, 18.91403008], [72.80930328, 18.91374969], [72.8095932, 18.91374969], [72.80958557, 18.91347122], [72.80986023, 18.91347122], [72.80986023, 18.91319466], [72.81014252, 18.91319466], [72.81014252, 18.91291618], [72.81069183, 18.91292191], [72.81069183, 18.91264153], [72.81096649, 18.91264153], [72.81096649, 18.91235924], [72.81124878, 18.91235924], [72.81124878, 18.91208076], [72.81153107, 18.91208267], [72.81153107, 18.91152763], [72.81181335, 18.91153145], [72.81181335, 18.91124916], [72.81291962, 18.91124916], [72.81291962, 18.91153145], [72.81346893, 18.91152763], [72.81346893, 18.91180611], [72.81375122, 18.91180611], [72.81375122, 18.91208267], [72.81402588, 18.91208076], [72.81402588, 18.91235924], [72.81458282, 18.91235924], [72.81458282, 18.91292191], [72.81485748, 18.91291618], [72.81485748, 18.91319466], [72.81541443, 18.91319466], [72.81541443, 18.9145813], [72.81569672, 18.91457939], [72.81569672, 18.91487122], [72.81597137, 18.91487122], [72.81597137, 18.91514015], [72.81624603, 18.91514015], [72.81624603, 18.91542053], [72.81652832, 18.91542053], [72.81652832, 18.91625023], [72.81624603, 18.91625023], [72.81624603, 18.91653061], [72.81597137, 18.91653061], [72.81597137, 18.91764069], [72.81625366, 18.91763878], [72.81625366, 18.91819572], [72.81652832, 18.91819572], [72.81652832, 18.91847229], [72.81764221, 18.91847229], [72.81764221, 18.91819572], [72.81847382, 18.91819572], [72.81847382, 18.91791725], [72.81958008, 18.9179306], [72.81958008, 18.91764069], [72.82096863, 18.91764069], [72.82096863, 18.91736031], [72.82125092, 18.91736031], [72.82125092, 18.91707993], [72.82152557, 18.91708565], [72.82152557, 18.91680336], [72.82236481, 18.91680336], [72.82236481, 18.91708565], [72.82263947, 18.91707993], [72.82263947, 18.91736031], [72.82290649, 18.91736031], [72.82290649, 18.9179306], [72.82319641, 18.91791725], [72.82319641, 18.91819572], [72.82347107, 18.91819], [72.82347107, 18.91875076], [72.82375336, 18.91875076], [72.82375336, 18.91903114], [72.82406616, 18.91903114], [72.82430267, 18.91903114], [72.82430267, 18.91930962], [72.82458496, 18.9193058], [72.82458496, 18.91958237], [72.82541656, 18.91958046], [72.82541656, 18.92014122], [72.82485962, 18.92013931], [72.82485962, 18.92035103], [72.82485962, 18.92180824], [72.82514191, 18.92180824], [72.82514191, 18.92263985], [72.82430267, 18.92263985], [72.82430267, 18.92235947], [72.82375336, 18.92236137], [72.82375336, 18.9220829], [72.82319641, 18.92208099], [72.82319641, 18.92263985], [72.82290649, 18.92263985], [72.82290649, 18.92291832], [72.82236481, 18.92291641], [72.82236481, 18.92319489], [72.82180786, 18.92319489], [72.82180786, 18.92347145], [72.82096863, 18.92347145], [72.82096863, 18.92374992], [72.81986237, 18.92374039], [72.81986237, 18.9240284], [72.81931305, 18.9240284], [72.81931305, 18.92431068], [72.81903076, 18.92430496], [72.81903076, 18.92458344], [72.81874847, 18.92458344], [72.81874847, 18.92486191], [72.81847382, 18.92486191], [72.81847382, 18.92569351], [72.81874084, 18.9256897], [72.81874084, 18.92653275], [72.81903076, 18.92653275], [72.81903076, 18.92681122], [72.81930542, 18.9268055], [72.81930542, 18.92708206], [72.81986237, 18.92708015], [72.81986237, 18.92736053], [72.82013702, 18.92736053], [72.82013702, 18.92791939], [72.82041931, 18.92791748], [72.82041931, 18.92819214], [72.82068634, 18.92819023], [72.82068634, 18.9287529], [72.82096863, 18.9287529], [72.82096863, 18.92930984], [72.82125092, 18.92930603], [72.82125092, 18.9295845], [72.82152557, 18.9295845], [72.82152557, 18.93013954], [72.82180023, 18.93013954], [72.82180023, 18.93041992], [72.82208252, 18.9304142], [72.82208252, 18.93097305], [72.82235718, 18.93097115], [72.82235718, 18.93153], [72.82263947, 18.93152809], [72.82263947, 18.93208313], [72.82291412, 18.93208313], [72.82291412, 18.93291664], [72.82319641, 18.93291092], [72.82319641, 18.93375015], [72.82347107, 18.93375015], [72.82347107, 18.93486023], [72.82375336, 18.93486023], [72.82375336, 18.94014168], [72.82347107, 18.94014168], [72.82347107, 18.94153023], [72.82319641, 18.94152832], [72.82319641, 18.94236374], [72.82290649, 18.94235992], [72.82290649, 18.94320107], [72.82263947, 18.94320107], [72.82263947, 18.94403076], [72.82236481, 18.94402695], [72.82236481, 18.9445858], [72.82208252, 18.94458008], [72.82208252, 18.94514084], [72.82180786, 18.94513893], [72.82180786, 18.94569588], [72.82152557, 18.94569588], [72.8215332, 18.94625092], [72.82125092, 18.94625092], [72.82125092, 18.94680977], [72.82096863, 18.94680786], [72.82096863, 18.94708252], [72.82068634, 18.94708061], [72.82068634, 18.94763947], [72.82041931, 18.94763947], [72.82041931, 18.94791794], [72.82013702, 18.94791794], [72.82013702, 18.9481945], [72.81986237, 18.9481945], [72.81986237, 18.94832039], [72.81986237, 18.94874954], [72.81958008, 18.94874954], [72.81958008, 18.94902992], [72.81931305, 18.94902992], [72.81931305, 18.9493103], [72.81903076, 18.94930649], [72.81903076, 18.94958305], [72.81874847, 18.94958305], [72.81874847, 18.94986153], [72.81819153, 18.94985962], [72.81819153, 18.95013809], [72.81791687, 18.95013809], [72.81791687, 18.95070076], [72.81764221, 18.95069504], [72.81764221, 18.9509716], [72.81708527, 18.9509716], [72.8170929, 18.95124817], [72.81680298, 18.95124817], [72.81680298, 18.95152855], [72.81624603, 18.95152855], [72.81624603, 18.95181084], [72.81569672, 18.95180511], [72.81569672, 18.95208359], [72.81541443, 18.95208359], [72.81541443, 18.95236015], [72.81485748, 18.95236015], [72.81485748, 18.95264244], [72.81458282, 18.95264244], [72.81458282, 18.95292282], [72.81430817, 18.9529171], [72.81430817, 18.95319366], [72.81402588, 18.95319366], [72.81402588, 18.95347023], [72.81346893, 18.95347023], [72.81346893, 18.95375252], [72.81291962, 18.95375252], [72.81291962, 18.95404053], [72.81263733, 18.95404053], [72.81263733, 18.95430946], [72.81236267, 18.95430565], [72.81236267, 18.95458221], [72.81041718, 18.95458031], [72.81041718, 18.95486069], [72.80819702, 18.95486069], [72.80819702, 18.95458031], [72.80791473, 18.95458221], [72.80791473, 18.95430565], [72.80764008, 18.95430946], [72.80764008, 18.95404053], [72.80735779, 18.95404053], [72.80735779, 18.95375252], [72.80708313, 18.95375252], [72.80708313, 18.95347023], [72.80680847, 18.95347023], [72.80680847, 18.9529171], [72.80625153, 18.95292282], [72.80625153, 18.95264244], [72.80580139, 18.95264244], [72.80541992, 18.95264244], [72.80541229, 18.95210075], [72.80486298, 18.95207977], [72.80486298, 18.95152855], [72.80458069, 18.95152855], [72.80458069, 18.95124817], [72.80430603, 18.95124817], [72.80430603, 18.9509697], [72.80403137, 18.9509716], [72.80403137, 18.95069504], [72.80375671, 18.95070076], [72.80375671, 18.95013809], [72.80319214, 18.95013809], [72.80319214, 18.94958115], [72.80263519, 18.94958305], [72.80263519, 18.94930649], [72.80236053, 18.9493103], [72.80236053, 18.94902992], [72.80208588, 18.94902992], [72.80208588, 18.94874954], [72.80152893, 18.94874954], [72.80152893, 18.94847107], [72.80097198, 18.94847298], [72.80097198, 18.9481945], [72.80014038, 18.9481945], [72.80014038, 18.94791794], [72.79958344, 18.94791794], [72.79958344, 18.94763947], [72.79875183, 18.94763947], [72.79875183, 18.94708061], [72.79846954, 18.94708252], [72.79846954, 18.94680786], [72.79818726, 18.94680977], [72.79818726, 18.94652939], [72.79792023, 18.94652939], [72.79792023, 18.94625092], [72.79763031, 18.94625092], [72.79763031, 18.94514084], [72.79736328, 18.94514084], [72.79736328, 18.94485283], [72.79680634, 18.94486046], [72.79680634, 18.9445858], [72.79652405, 18.9445858], [72.79652405, 18.94430542], [72.79624939, 18.94431114], [72.79624939, 18.94403076], [72.7959671, 18.94403076], [72.7959671, 18.94347], [72.79569244, 18.94347382], [72.79569244, 18.94236374], [72.79541779, 18.94236374], [72.79541779, 18.94124985], [72.7951355, 18.94124985], [72.7951355, 18.94041634], [72.79486084, 18.94042015], [72.79486084, 18.93958092], [72.79458618, 18.93958282], [72.79458618, 18.93930626], [72.79429626, 18.93931007], [72.79429626, 18.9390316], [72.79402924, 18.9390316], [72.79402924, 18.93874931], [72.79319763, 18.93874931], [72.79319763, 18.9390316], [72.79292297, 18.9390316], [72.79292297, 18.93931007], [72.79264069, 18.93930626], [72.79264069, 18.93958282], [72.79208374, 18.93958282], [72.79208374, 18.93985939], [72.79180908, 18.93985939], [72.79180908, 18.94069481], [72.79208374, 18.94069481], [72.79208374, 18.94097137], [72.7923584, 18.94096947], [72.7923584, 18.94153023], [72.79264069, 18.94152832], [72.79264069, 18.94208145], [72.79292297, 18.94207954], [72.79292297, 18.9426403], [72.79319763, 18.9426403], [72.79319763, 18.94375038], [72.79291534, 18.94375038], [72.79291534, 18.9445858], [72.79264069, 18.94458008], [72.79264069, 18.94542122], [72.7923584, 18.94542122], [72.7923584, 18.94652939], [72.79208374, 18.94652748], [72.79208374, 18.94708252], [72.79180908, 18.94708252], [72.79181671, 18.94763947], [72.79152679, 18.94763947], [72.79152679, 18.9481945], [72.79181671, 18.94819069], [72.79181671, 18.95070076], [72.7923584, 18.95070076], [72.7923584, 18.95124817], [72.79264069, 18.95124817], [72.79264069, 18.95181084], [72.79291534, 18.95180511], [72.79291534, 18.95236015], [72.79319763, 18.95236015], [72.79319763, 18.95264244], [72.79347229, 18.95264244], [72.79347229, 18.95292282], [72.79374695, 18.9529171], [72.79374695, 18.95347023], [72.79402924, 18.95347023], [72.79402924, 18.95375252], [72.79429626, 18.95375252], [72.79429626, 18.95404053], [72.79458618, 18.95404053], [72.79458618, 18.95430946], [72.79486084, 18.95430565], [72.79486084, 18.95458221], [72.7951355, 18.95458221], [72.7951355, 18.95569229], [72.79541779, 18.95569229], [72.79541779, 18.95597458], [72.79569244, 18.95597076], [72.79569244, 18.95625114], [72.7959671, 18.95625114], [72.7959671, 18.95652962], [72.79624939, 18.95652962], [72.79624939, 18.95681], [72.79652405, 18.95680618], [72.79652405, 18.95708466], [72.79708099, 18.95708084], [72.79708099, 18.95736122], [72.79736328, 18.95736122], [72.79736328, 18.95763969], [72.79763031, 18.95763969], [72.79763031, 18.95792007], [72.79818726, 18.95792007], [72.79818726, 18.95903015], [72.79930878, 18.95902824], [72.79930878, 18.95930672], [72.79957581, 18.95930099], [72.79957581, 18.96014023], [72.79930878, 18.96013832], [72.79930878, 18.96097183], [72.79957581, 18.96096992], [72.79957581, 18.96153069], [72.79985809, 18.96153069], [72.79985809, 18.96181107], [72.80014038, 18.96181107], [72.80014038, 18.96236038], [72.80042267, 18.96236038], [72.80042267, 18.96264076], [72.80069733, 18.96263885], [72.80069733, 18.96319389], [72.80097198, 18.96319389], [72.80097198, 18.96347237], [72.80124664, 18.96347046], [72.80124664, 18.96402931], [72.80152893, 18.96402931], [72.80152893, 18.96542168], [72.80208588, 18.96541595], [72.80208588, 18.96569443], [72.80263519, 18.96569443], [72.80263519, 18.96847153], [72.80208588, 18.96846962], [72.80208588, 18.96875191], [72.80179596, 18.96875191], [72.80179596, 18.96903992], [72.80152893, 18.96902847], [72.80152893, 18.96986389], [72.80180359, 18.96986389], [72.80180359, 18.9706955], [72.80208588, 18.97068977], [72.80208588, 18.97125053], [72.80236053, 18.97125053], [72.80236053, 18.97180939], [72.80263519, 18.97180557], [72.80263519, 18.97236061], [72.80319214, 18.97236061], [72.80319214, 18.97264099], [72.8034668, 18.97264099], [72.8034668, 18.97291946], [72.80374908, 18.97291756], [72.80374908, 18.97319412], [72.80403137, 18.97319412], [72.80403137, 18.9734726], [72.80430603, 18.97347069], [72.80430603, 18.97375107], [72.80458069, 18.97375107], [72.80458069, 18.97430992], [72.80486298, 18.97430611], [72.80486298, 18.97486115], [72.80513763, 18.9748497], [72.80513763, 18.97541809], [72.80569458, 18.97541618], [72.80569458, 18.97597313], [72.80596924, 18.97597122], [72.80596924, 18.97652817], [72.80568695, 18.97652817], [72.80568695, 18.97821045], [72.80847168, 18.97819519], [72.80847168, 18.97847176], [72.80874634, 18.97846985], [72.80874634, 18.97874832], [72.80902863, 18.97874832], [72.80902863, 18.97903252], [72.80930328, 18.97903252], [72.80930328, 18.97874832], [72.81124878, 18.97874832], [72.81124878, 18.97903252], [72.81153107, 18.97903252], [72.81153107, 18.9793129], [72.81180573, 18.97930527], [72.81180573, 18.97958374], [72.81208038, 18.97958183], [72.81208038, 18.97986031], [72.81236267, 18.97986031], [72.81236267, 18.98014259], [72.81263733, 18.98013878], [72.81263733, 18.98069382], [72.81318665, 18.98069191], [72.81318665, 18.98125267], [72.81375122, 18.98125267], [72.81375122, 18.98180962], [72.81402588, 18.98180962], [72.81402588, 18.98291969], [72.81430817, 18.98291969], [72.81430817, 18.98513985], [72.81402588, 18.98513985], [72.81402588, 18.98624992], [72.81375122, 18.98624992], [72.81375122, 18.9865303], [72.81346893, 18.9865284], [72.81346893, 18.98708344], [72.81291962, 18.98708344], [72.81291962, 18.98680687], [72.81236267, 18.98680687], [72.81236267, 18.98708344], [72.81124878, 18.98708344], [72.81124878, 18.98736191], [72.81097412, 18.98736191], [72.81097412, 18.98847198], [72.81069183, 18.98847008], [72.81069183, 18.98903084], [72.81097412, 18.98902893], [72.81097412, 18.98958397], [72.81124878, 18.98958015], [72.81124878, 18.99014854], [72.81153107, 18.9901371], [72.81153107, 18.99069405], [72.81181335, 18.99069023], [72.81181335, 18.99124908], [72.81208038, 18.99124908], [72.81208038, 18.99235916], [72.81236267, 18.99235916], [72.81236267, 18.99347115], [72.81208038, 18.99346924], [72.81208038, 18.99403191], [72.81153107, 18.99402809], [72.81153107, 18.99430466], [72.81180573, 18.99430466], [72.81180573, 18.99597359], [72.81153107, 18.99596024], [72.81153107, 18.99792099], [72.81124878, 18.99792099], [72.81124878, 18.99930954], [72.81096649, 18.99930954], [72.81096649, 18.99986076], [72.81124878, 18.99986076], [72.81124878, 19.0023613], [72.81153107, 19.0023613], [72.81153107, 19.00347137], [72.81181335, 19.00346947], [72.81181335, 19.00402832], [72.81208038, 19.00402832], [72.81208038, 19.00458336], [72.81236267, 19.00457954], [72.81236267, 19.00515175], [72.81263733, 19.00515175], [72.81263733, 19.00570107], [72.81291962, 19.00569534], [72.81291962, 19.00597191], [72.81318665, 19.00597191], [72.81318665, 19.00653267], [72.81346893, 19.00652695], [72.81346893, 19.00708389], [72.81375122, 19.00708389], [72.81375122, 19.00958443], [72.81402588, 19.00958061], [72.81402588, 19.0098629], [72.81430817, 19.0098629], [72.81430817, 19.01013947], [72.81458282, 19.01013947], [72.81458282, 19.0106926], [72.81485748, 19.01069069], [72.81485748, 19.01124954], [72.81513977, 19.01124954], [72.81513977, 19.01180077], [72.81541443, 19.01180649], [72.81541443, 19.01208305], [72.81569672, 19.01208305], [72.81569672, 19.01236153], [72.81597137, 19.01235962], [72.81597137, 19.01320076], [72.81624603, 19.01320076], [72.81624603, 19.01652908], [72.81597137, 19.01652908], [72.81597137, 19.01763916], [72.81569672, 19.01763916], [72.81569672, 19.02069473], [72.8154068, 19.02069283], [72.8154068, 19.02403069], [72.81513977, 19.02402687], [72.81513977, 19.02458572], [72.81485748, 19.02458], [72.81485748, 19.02514076], [72.81458282, 19.02513885], [72.81458282, 19.02708244], [72.81541443, 19.02708244], [72.81541443, 19.02680779], [72.81569672, 19.02680969], [72.81569672, 19.02569008], [72.81597137, 19.0256958], [72.81597137, 19.02513885], [72.81624603, 19.02514076], [72.81624603, 19.02486038], [72.81652832, 19.02486038], [72.81652832, 19.02458], [72.81680298, 19.02458572], [72.81680298, 19.02430344], [72.8170929, 19.02431107], [72.8170929, 19.02403069], [72.81735992, 19.02403069], [72.81735992, 19.02375031], [72.81764221, 19.02375031], [72.81764221, 19.02346992], [72.81791687, 19.02347374], [72.81791687, 19.02291679], [72.81819153, 19.02292061], [72.81819153, 19.02264023], [72.81846619, 19.02264023], [72.81846619, 19.02235985], [72.81874847, 19.02236366], [72.81874847, 19.02069473], [72.81903076, 19.02069473], [72.81903076, 19.02013969], [72.81930542, 19.02013969], [72.81930542, 19.01930618], [72.81958008, 19.0193119], [72.81958008, 19.01847076], [72.81986237, 19.01847267], [72.81986237, 19.0181942], [72.82013702, 19.0181942], [72.82013702, 19.01791573], [72.82041931, 19.01792145], [72.82041931, 19.01763916], [72.82290649, 19.01763916], [72.82290649, 19.01792145], [72.82514191, 19.01791573], [72.82514191, 19.0181942], [72.82541656, 19.0181942], [72.82541656, 19.01847267], [72.82653046, 19.01847076], [72.82653046, 19.01874924], [72.82681274, 19.01874924], [72.82681274, 19.01903152], [72.82707977, 19.01903152], [72.82707977, 19.0193119], [72.82736206, 19.01930618], [72.82736206, 19.01958275], [72.82763672, 19.01958084], [72.82763672, 19.01985931], [72.82819366, 19.01985931], [72.82819366, 19.02013969], [72.82847595, 19.02012825], [72.82847595, 19.02042007], [72.82902527, 19.02041626], [72.82902527, 19.02069473], [72.82958221, 19.02069473], [72.82958221, 19.0209713], [72.82985687, 19.02096939], [72.82985687, 19.02124977], [72.83040619, 19.02124977], [72.83040619, 19.02153015], [72.83069611, 19.02152824], [72.83069611, 19.02180481], [72.83097076, 19.02180481], [72.83097076, 19.02208138], [72.83125305, 19.02208138], [72.83125305, 19.02236366], [72.83152771, 19.02235985], [72.83152771, 19.02264023], [72.83180237, 19.02264023], [72.83180237, 19.02292061], [72.83208466, 19.02291679], [72.83208466, 19.02319527], [72.83235931, 19.02319527], [72.83235931, 19.02347374], [72.8326416, 19.02346992], [72.8326416, 19.02403069], [72.83291626, 19.02403069], [72.83291626, 19.02431107], [72.83319092, 19.02430344], [72.83319092, 19.02458572], [72.83347321, 19.02458], [72.83347321, 19.02486038], [72.83374023, 19.02486038], [72.83374023, 19.02514076], [72.83403015, 19.02514076], [72.83403015, 19.02626038], [72.83429718, 19.02626038], [72.83429718, 19.02653122], [72.83486176, 19.02653122], [72.83486176, 19.02680969], [72.83513641, 19.02680969], [72.83513641, 19.02736092], [72.8354187, 19.02736092], [72.8354187, 19.02763939], [72.83569336, 19.02763939], [72.83569336, 19.02819443], [72.83597565, 19.02819443], [72.83597565, 19.02874947], [72.83625031, 19.02874947], [72.83625031, 19.02932167], [72.83651733, 19.02932167], [72.83651733, 19.03013992], [72.83679962, 19.03013992], [72.83679962, 19.0304184], [72.83708191, 19.0304184], [72.83708191, 19.03124809], [72.8373642, 19.03124809], [72.8373642, 19.03208351], [72.83763885, 19.03206825], [72.83763885, 19.03292274], [72.83790588, 19.03292274], [72.83790588, 19.03486061], [72.8381958, 19.03486061], [72.8381958, 19.03928185], [72.83790588, 19.03930092], [72.83790588, 19.04181099], [72.83763885, 19.04180527], [72.83763885, 19.04375267], [72.83763885, 19.04458427], [72.83735657, 19.04458046], [72.83735657, 19.04513931], [72.83708191, 19.04513931], [72.83708191, 19.0454216], [72.83680725, 19.04541588], [72.83680725, 19.04597282], [72.83652496, 19.04597282], [72.83652496, 19.04819489], [72.83625031, 19.04819107], [72.83625031, 19.04874992], [72.83598328, 19.04874992], [72.83598328, 19.0490303], [72.83569336, 19.0490303], [72.83569336, 19.04931068], [72.83513641, 19.04930305], [72.83513641, 19.04958153], [72.83486176, 19.04958153], [72.83486176, 19.04986382], [72.83347321, 19.04986382], [72.83347321, 19.04958153], [72.8326416, 19.04958153], [72.8326416, 19.04930305], [72.83235931, 19.04931068], [72.83235931, 19.0490303], [72.83125305, 19.0490303], [72.83125305, 19.04819107], [72.83069611, 19.04819489], [72.83069611, 19.04791641], [72.83040619, 19.04792023], [72.83040619, 19.04735947], [72.83013916, 19.04736137], [72.83013916, 19.04680634], [72.82985687, 19.04681015], [72.82985687, 19.04653168], [72.82958221, 19.04653168], [72.82958221, 19.04597092], [72.8298645, 19.04597282], [72.8298645, 19.04569435], [72.82958221, 19.04569435], [72.82958221, 19.04541588], [72.8290329, 19.0454216], [72.8290329, 19.04513931], [72.82847595, 19.04513931], [72.82847595, 19.04486084], [72.82791901, 19.04486084], [72.82791901, 19.04458427], [72.82763672, 19.04458427], [72.82763672, 19.0443058], [72.82736206, 19.04432106], [72.82736206, 19.04402924], [72.82653046, 19.04402924], [72.82653046, 19.04375076], [72.82624817, 19.04375076], [72.82624817, 19.04347038], [72.82541656, 19.04347229], [72.82541656, 19.04319382], [72.82514191, 19.04319382], [72.82514191, 19.04291725], [72.82485962, 19.04291916], [72.82485962, 19.04264069], [72.82430267, 19.04264069], [72.82430267, 19.04236031], [72.82402802, 19.04236031], [72.82402802, 19.04207993], [72.82375336, 19.04208374], [72.82375336, 19.04041672], [72.82402802, 19.04042053], [72.82402802, 19.03985977], [72.82430267, 19.03986168], [72.82430267, 19.03930664], [72.82458496, 19.03930664], [72.82458496, 19.03819466], [72.82430267, 19.03820038], [72.82430267, 19.03763962], [72.82375336, 19.03763962], [72.82375336, 19.03792], [72.82347107, 19.03792], [72.82347107, 19.03820038], [72.82319641, 19.03819466], [72.82319641, 19.03847313], [72.82290649, 19.03847122], [72.82290649, 19.03903008], [72.82263947, 19.03902817], [72.82263947, 19.03958321], [72.82235718, 19.03957939], [72.82235718, 19.04070091], [72.82208252, 19.04070091], [72.82208252, 19.04181099], [72.82180023, 19.04181099], [72.82180786, 19.04236031], [72.8215332, 19.04236031], [72.8215332, 19.04264069], [72.82096863, 19.04264069], [72.82096863, 19.04236031], [72.82068634, 19.04236031], [72.82068634, 19.04207993], [72.82013702, 19.04208374], [72.82013702, 19.04180527], [72.81903076, 19.04181099], [72.81903076, 19.04153061], [72.81874084, 19.04153061], [72.81874084, 19.04125977], [72.81764221, 19.04125977], [72.81764221, 19.04153061], [72.81735992, 19.04153061], [72.81735992, 19.04181099], [72.81680298, 19.04181099], [72.81680298, 19.04153061], [72.81652832, 19.04153061], [72.81652832, 19.04181099], [72.81624603, 19.04181099], [72.81624603, 19.04236031], [72.81597137, 19.04236031], [72.81597137, 19.04264069], [72.81624603, 19.04264069], [72.81624603, 19.04291916], [72.81652832, 19.04291725], [72.81652832, 19.04347229], [72.8170929, 19.04347038], [72.8170929, 19.04402924], [72.81764221, 19.04402924], [72.81764221, 19.04486084], [72.81791687, 19.04486084], [72.81791687, 19.0454216], [72.81819153, 19.0454216], [72.81819153, 19.04653168], [72.81846619, 19.04653168], [72.81846619, 19.04624939], [72.81874084, 19.04624939], [72.81874084, 19.04653168], [72.81903076, 19.04653168], [72.81903076, 19.04681015], [72.81930542, 19.04680634], [72.81930542, 19.0470829], [72.81958008, 19.0470829], [72.81958008, 19.04736137], [72.81986237, 19.04736137], [72.81986237, 19.04847145], [72.82013702, 19.04846954], [72.82013702, 19.0490303], [72.82041931, 19.0490284], [72.82041931, 19.04986382], [72.82096863, 19.04986], [72.82096863, 19.05014038], [72.82125092, 19.05014038], [72.82125092, 19.05153084], [72.82152557, 19.05152512], [72.82152557, 19.05236053], [72.82180023, 19.05236053], [72.82180023, 19.05264091], [72.82208252, 19.05264091], [72.82208252, 19.05319977], [72.82235718, 19.05319977], [72.82235718, 19.05402946], [72.82263947, 19.05402946], [72.82263947, 19.05486107], [72.82347107, 19.05486107], [72.82347107, 19.05513954], [72.82375336, 19.05513954], [72.82375336, 19.05597305], [72.82347107, 19.05597115], [72.82347107, 19.05625916], [72.82319641, 19.05624962], [72.82319641, 19.05680466], [72.82291412, 19.05680466], [72.82291412, 19.0573616], [72.82263947, 19.0573597], [72.82263947, 19.05763817], [72.82096863, 19.05763817], [72.82096863, 19.05847168], [72.82069397, 19.05847168], [72.82069397, 19.06069374], [72.82096863, 19.06069374], [72.82096863, 19.06097031], [72.82152557, 19.06097031], [72.82152557, 19.06125259], [72.82180023, 19.06125259], [72.82180023, 19.06236076], [72.82208252, 19.06236076], [72.82208252, 19.06347466], [72.82180786, 19.06347466], [72.82180786, 19.0648613], [72.8215332, 19.06485939], [72.8215332, 19.06653023], [72.82125092, 19.06652832], [72.82125092, 19.06680679], [72.82096863, 19.06680107], [72.82096863, 19.06792068], [72.82152557, 19.06791687], [72.82152557, 19.06847191], [72.82235718, 19.06847], [72.82235718, 19.06875038], [72.82263947, 19.06875038], [72.82263947, 19.06986046], [72.82236481, 19.06986046], [72.82236481, 19.07097244], [72.82208252, 19.07097054], [72.82208252, 19.07235909], [72.82180023, 19.07235909], [72.82180023, 19.07570076], [72.82096863, 19.07570076], [72.82096863, 19.07764053], [72.82152557, 19.07763863], [72.82152557, 19.07819557], [72.82208252, 19.07819557], [72.82208252, 19.07847214], [72.82235718, 19.07847023], [72.82235718, 19.07875061], [72.82290649, 19.07875061], [72.82290649, 19.07903099], [72.82375336, 19.07903099], [72.82375336, 19.07930946], [72.82430267, 19.07930946], [72.82430267, 19.07875061], [72.82457733, 19.07875061], [72.82457733, 19.07847023], [72.82485962, 19.07847214], [72.82485962, 19.0779171], [72.82597351, 19.0779171], [72.82597351, 19.07819557], [72.82624817, 19.07818985], [72.82624817, 19.07986069], [72.82596588, 19.07986069], [72.82596588, 19.08152962], [72.82624817, 19.08152962], [72.82624817, 19.08236122], [72.82596588, 19.08236122], [72.82596588, 19.08291817], [72.82569122, 19.08291626], [72.82569122, 19.0834713], [72.82541656, 19.08346939], [72.82541656, 19.08542061], [72.82597351, 19.08541679], [72.82597351, 19.08625031], [72.82624817, 19.08624077], [72.82624817, 19.08764267], [72.82653046, 19.08763885], [72.82653046, 19.08847046], [72.82681274, 19.08847046], [72.82681274, 19.09403038], [72.82653046, 19.09402847], [72.82653046, 19.09541893], [72.82624817, 19.09541893], [72.82624817, 19.09819412], [72.82596588, 19.09818077], [72.82596588, 19.09874916], [72.82569122, 19.09874916], [72.82569122, 19.10013962], [72.82541656, 19.10013962], [72.82541656, 19.1020813], [72.82514191, 19.10207939], [72.82514191, 19.10264015], [72.82485962, 19.10264015], [72.82485962, 19.10320091], [72.82457733, 19.10320091], [72.82457733, 19.10431099], [72.82430267, 19.10431099], [72.82430267, 19.10514069], [72.82402802, 19.10513878], [72.82402802, 19.10597229], [72.82375336, 19.10597038], [72.82375336, 19.10764122], [72.82347107, 19.10763931], [72.82347107, 19.10986137], [72.82319641, 19.10986137], [72.82319641, 19.11097145], [72.82290649, 19.11096954], [72.82290649, 19.1115284], [72.82263947, 19.1115284], [72.82263947, 19.11236191], [72.82236481, 19.11236191], [72.82235718, 19.11374092], [72.82208252, 19.11375046], [72.82208252, 19.11431122], [72.82180023, 19.11431122], [72.82180786, 19.11486053], [72.8215332, 19.11486053], [72.8215332, 19.11541939], [72.82125092, 19.11541748], [72.82125092, 19.11597443], [72.82096863, 19.11597061], [72.82096863, 19.11654091], [72.82068634, 19.11654091], [72.82068634, 19.11736107], [72.82041931, 19.11736107], [72.82041931, 19.11763954], [72.82013702, 19.11763954], [72.82013702, 19.12042046], [72.82041931, 19.12042046], [72.82041931, 19.12070084], [72.82152557, 19.12069511], [72.82152557, 19.12208366], [72.82096863, 19.12208366], [72.82096863, 19.12236023], [72.82068634, 19.12235069], [72.82068634, 19.12291908], [72.82041931, 19.12291718], [72.82041931, 19.12319374], [72.81986237, 19.12318993], [72.81986237, 19.12375069], [72.81958008, 19.12375069], [72.81958008, 19.12402916], [72.81931305, 19.12402916], [72.81931305, 19.12431145], [72.81847382, 19.12430573], [72.81847382, 19.1245842], [72.81791687, 19.12458038], [72.81791687, 19.12486076], [72.81764221, 19.12486076], [72.81764221, 19.12513924], [72.81735992, 19.12513924], [72.81735992, 19.12542152], [72.81708527, 19.1254158], [72.81708527, 19.12569427], [72.81680298, 19.12569427], [72.81680298, 19.12597275], [72.81652832, 19.12597084], [72.81652832, 19.12624931], [72.81624603, 19.12624931], [72.81624603, 19.1265316], [72.81597137, 19.1265316], [72.81597137, 19.12681007], [72.81541443, 19.12680626], [72.81541443, 19.12708282], [72.81513977, 19.12708282], [72.81513977, 19.1273613], [72.81485748, 19.12735939], [72.81485748, 19.12763977], [72.81458282, 19.12763977], [72.81458282, 19.12819481], [72.81485748, 19.1281929], [72.81485748, 19.12848091], [72.81458282, 19.12848091], [72.81458282, 19.12903023], [72.81402588, 19.12902832], [72.81402588, 19.12930489], [72.81375122, 19.12930489], [72.81375122, 19.12902832], [72.81346893, 19.12902832], [72.81346893, 19.12958145], [72.81319427, 19.12958145], [72.81319427, 19.12986374], [72.81291962, 19.12986374], [72.81291962, 19.13097382], [72.81263733, 19.13097], [72.81263733, 19.13125038], [72.81236267, 19.13125038], [72.81236267, 19.13152695], [72.81208038, 19.13152122], [72.81208038, 19.13181114], [72.81180573, 19.13180351], [72.81180573, 19.1320858], [72.81153107, 19.13208008], [72.81153107, 19.13236046], [72.81124878, 19.13236046], [72.81124878, 19.13264084], [72.81097412, 19.13263893], [72.81097412, 19.13319588], [72.81041718, 19.13319588], [72.81041718, 19.13347244], [72.81014252, 19.13347054], [72.81014252, 19.13402939], [72.80986023, 19.13402939], [72.80986023, 19.13430977], [72.80958557, 19.13430786], [72.80958557, 19.13458252], [72.80930328, 19.13458061], [72.80930328, 19.13513947], [72.80902863, 19.13513947], [72.80902863, 19.13541985], [72.80874634, 19.13541794], [72.80874634, 19.1356945], [72.80847168, 19.1356945], [72.80847168, 19.13597298], [72.80819702, 19.13597107], [72.80819702, 19.13624954], [72.8079071, 19.13624954], [72.8079071, 19.13652992], [72.80764008, 19.13652992], [72.80764008, 19.1368084], [72.80708313, 19.13680649], [72.80708313, 19.13708305], [72.80680084, 19.13708115], [72.80680084, 19.13763809], [72.80652618, 19.13763809], [72.80652618, 19.13791847], [72.80625153, 19.13791847], [72.80625153, 19.13820076], [72.80596924, 19.13819504], [72.80596924, 19.1384716], [72.80568695, 19.1384697], [72.80568695, 19.13874817], [72.80541992, 19.13874817], [72.80541992, 19.13902855], [72.80486298, 19.13902855], [72.80486298, 19.13958359], [72.80458069, 19.13958359], [72.80458069, 19.13986015], [72.80403137, 19.13986015], [72.80403137, 19.14014244], [72.80374908, 19.14013863], [72.80374908, 19.14069366], [72.8034668, 19.14069176], [72.8034668, 19.1415329], [72.80374908, 19.14152718], [72.80374908, 19.14208221], [72.80403137, 19.14208221], [72.80403137, 19.14347458], [72.80430603, 19.14346123], [72.80430603, 19.14402962], [72.80458069, 19.14402962], [72.80458069, 19.14431], [72.80486298, 19.14431], [72.80486298, 19.14486122], [72.80541992, 19.14486122], [72.80541992, 19.14513969], [72.80569458, 19.14513969], [72.80569458, 19.14569664], [72.80596924, 19.14569092], [72.80596924, 19.14875031], [72.80625153, 19.14875031], [72.80625153, 19.14931107], [72.80652618, 19.14931107], [72.80652618, 19.14958954], [72.80708313, 19.14958954], [72.80708313, 19.15014076], [72.80764008, 19.15014076], [72.80764008, 19.15041924], [72.80791473, 19.15041733], [72.80791473, 19.15069389], [72.80819702, 19.15069389], [72.80819702, 19.15097237], [72.80847168, 19.15097046], [72.80847168, 19.15125084], [72.80874634, 19.15125084], [72.80874634, 19.15152931], [72.80902863, 19.15152931], [72.80902863, 19.1518116], [72.80930328, 19.15180588], [72.80930328, 19.15208244], [72.80958557, 19.15208244], [72.80958557, 19.15236092], [72.80986023, 19.15236092], [72.80986023, 19.15265274], [72.81014252, 19.15263939], [72.81014252, 19.15319443], [72.81069183, 19.15319443], [72.81069183, 19.1534729], [72.81096649, 19.15346909], [72.81096649, 19.15403175], [72.81153107, 19.15403175], [72.81153107, 19.15431023], [72.81208038, 19.15430641], [72.81208038, 19.15458107], [72.81236267, 19.15458107], [72.81236267, 19.15486145], [72.81291962, 19.15485954], [72.81291962, 19.1554203], [72.81319427, 19.15541649], [72.81319427, 19.15597153], [72.81375122, 19.15596962], [72.81375122, 19.15625], [72.81402588, 19.15625], [72.81402588, 19.15653038], [72.81430817, 19.15652847], [72.81430817, 19.15708542], [72.81485748, 19.15708542], [72.81485748, 19.15736389], [72.81513977, 19.15736008], [72.81513977, 19.15792084], [72.81569672, 19.15791702], [72.81569672, 19.1581955], [72.81597137, 19.1581955], [72.81597137, 19.15847206], [72.81652832, 19.15846062], [72.81652832, 19.15903091], [72.81735992, 19.15903091], [72.81735992, 19.15930939], [72.81764221, 19.15930557], [72.81764221, 19.15958595], [72.81819153, 19.15958023], [72.81819153, 19.15986061], [72.81846619, 19.15986061], [72.81846619, 19.16014099], [72.81874084, 19.16014099], [72.81874084, 19.16041946], [72.81903076, 19.16041756], [72.81903076, 19.1609726], [72.81931305, 19.16097069], [72.81931305, 19.16125107], [72.81958008, 19.16125107], [72.81958008, 19.16180992], [72.82013702, 19.16180611], [72.82013702, 19.16208267], [72.82041931, 19.16208076], [72.82041931, 19.16236115], [72.82096863, 19.16236115], [72.82096863, 19.16263962], [72.82125092, 19.16263962], [72.82125092, 19.16291809], [72.82152557, 19.16291618], [72.82152557, 19.16319466], [72.82180786, 19.16319466], [72.82180786, 19.16347313], [72.82208252, 19.16347122], [72.82208252, 19.16402817], [72.82263947, 19.16402817], [72.82263947, 19.16430473], [72.82291412, 19.16430473], [72.82291412, 19.16486168], [72.82347107, 19.16485977], [72.82347107, 19.16513824], [72.82375336, 19.16513824], [72.82375336, 19.16541862], [72.82402802, 19.16541672], [72.82402802, 19.16597176], [72.82514191, 19.16596985], [72.82514191, 19.16625023], [72.82596588, 19.16625023], [72.82596588, 19.16596985], [72.82680511, 19.16597176], [72.82680511, 19.16541672], [72.82736206, 19.16541862], [72.82736206, 19.16513824], [72.82818604, 19.16513824], [72.82818604, 19.16541862], [72.82875061, 19.16541862], [72.82875061, 19.16570091], [72.82930756, 19.16569519], [72.82930756, 19.16597176], [72.82958221, 19.16596985], [72.82958221, 19.1668129], [72.82930756, 19.1668129], [72.82930756, 19.16765022], [72.8290329, 19.16765022], [72.8290329, 19.16792107], [72.82847595, 19.16791725], [72.82847595, 19.16819382], [72.82792664, 19.16819191], [72.82792664, 19.16903114], [72.82819366, 19.16902733], [72.82819366, 19.16958237], [72.82875061, 19.16958046], [72.82875061, 19.16986084], [72.8290329, 19.16986084], [72.8290329, 19.17014122], [72.82930756, 19.17013931], [72.82930756, 19.17069244], [72.82958221, 19.17069054], [72.82958221, 19.17152977], [72.82985687, 19.17152977], [72.82985687, 19.17181015], [72.83013916, 19.17181015], [72.83013916, 19.17263985], [72.83041382, 19.17263794], [72.83041382, 19.17347145], [72.83013916, 19.17346954], [72.83013916, 19.17514038], [72.8298645, 19.17513847], [72.8298645, 19.17569351], [72.83041382, 19.17569351], [72.83041382, 19.17597198], [72.83069611, 19.17597008], [72.83069611, 19.17653084], [72.83097076, 19.17653084], [72.83097076, 19.17764091], [72.83069611, 19.1776371], [72.83069611, 19.17847252], [72.83040619, 19.17847061], [72.83040619, 19.17985916], [72.83013916, 19.17985916], [72.83013916, 19.18097115], [72.8298645, 19.18097115], [72.8298645, 19.18236351], [72.82958221, 19.18236351], [72.82958221, 19.18263817], [72.82930756, 19.18263054], [72.82930756, 19.18292046], [72.8290329, 19.18292046], [72.8290329, 19.18320084], [72.82847595, 19.18319321], [72.82847595, 19.18347168], [72.82818604, 19.18346977], [72.82819366, 19.18375015], [72.82791901, 19.18375015], [72.82791901, 19.18347168], [72.82763672, 19.18347168], [72.82763672, 19.18263817], [72.82791901, 19.18263817], [72.82791901, 19.18236351], [72.82819366, 19.18236351], [72.82819366, 19.18152809], [72.82847595, 19.18153191], [72.82847595, 19.18097115], [72.82875061, 19.18097115], [72.82875061, 19.18069458], [72.82902527, 19.18069458], [72.82902527, 19.1795826], [72.82930756, 19.17959023], [72.82930756, 19.1779213], [72.8290329, 19.1779213], [72.8290329, 19.17736053], [72.82875061, 19.17736053], [72.82875061, 19.17682076], [72.82818604, 19.17682076], [72.82818604, 19.17653084], [72.82792664, 19.17653084], [72.82792664, 19.17625046], [72.82763672, 19.17625046], [72.82763672, 19.17597008], [72.82736206, 19.17597198], [72.82736206, 19.17569542], [72.82707977, 19.1756897], [72.82707977, 19.17541885], [72.82681274, 19.17542076], [72.82681274, 19.17514038], [72.82653046, 19.17514038], [72.82653046, 19.17486], [72.82624817, 19.17486191], [72.82624817, 19.17458344], [72.82569122, 19.17458344], [72.82569122, 19.17430687], [72.82541656, 19.17431068], [72.82541656, 19.1740303], [72.82485962, 19.1740303], [72.82485962, 19.17374992], [72.82458496, 19.17374992], [72.82458496, 19.17347145], [72.82430267, 19.17347145], [72.82430267, 19.17319679], [72.82375336, 19.17319679], [72.82375336, 19.17291641], [72.82347107, 19.17292023], [72.82347107, 19.17263985], [72.82319641, 19.17263985], [72.82319641, 19.17235947], [72.82291412, 19.17236137], [72.82291412, 19.17208481], [72.82263947, 19.17208481], [72.82263947, 19.17180634], [72.82235718, 19.17181015], [72.82235718, 19.17152977], [72.82180023, 19.17152977], [72.82180023, 19.17181015], [72.82013702, 19.17181015], [72.82013702, 19.17152977], [72.81986237, 19.17152977], [72.81986237, 19.17124939], [72.81930542, 19.17124939], [72.81930542, 19.17097473], [72.81903076, 19.17097473], [72.81903076, 19.17069244], [72.81874847, 19.17069244], [72.81874847, 19.17013931], [72.81846619, 19.17014122], [72.81846619, 19.16903114], [72.81819153, 19.16903114], [72.81819153, 19.16847038], [72.81764221, 19.16847038], [72.81764221, 19.16819382], [72.81735992, 19.16819382], [72.81735992, 19.16791725], [72.8170929, 19.16792107], [72.8170929, 19.16765022], [72.81680298, 19.16765022], [72.81680298, 19.16736031], [72.81652832, 19.16736031], [72.81652832, 19.16708183], [72.81625366, 19.16708374], [72.81625366, 19.16680527], [72.81597137, 19.1668129], [72.81597137, 19.16653252], [72.81569672, 19.16653252], [72.81569672, 19.16596985], [72.81541443, 19.16597176], [72.81541443, 19.16569519], [72.81513977, 19.16570091], [72.81513977, 19.16513824], [72.81485748, 19.16513824], [72.81485748, 19.16485977], [72.81458282, 19.16486168], [72.81458282, 19.16458321], [72.81430817, 19.16459084], [72.81430817, 19.16402817], [72.81402588, 19.16402817], [72.81402588, 19.16374969], [72.81375122, 19.16374969], [72.81375122, 19.16347122], [72.81346893, 19.16347313], [72.81346893, 19.16319466], [72.81319427, 19.16319466], [72.81319427, 19.16291618], [72.81291962, 19.16291809], [72.81291962, 19.16236115], [72.81263733, 19.16236115], [72.81263733, 19.16180992], [72.81236267, 19.16180992], [72.81236267, 19.16125107], [72.81208038, 19.16125107], [72.81208038, 19.16041946], [72.81181335, 19.16041946], [72.81181335, 19.15986061], [72.81153107, 19.15986061], [72.81153107, 19.15958023], [72.81180573, 19.15958595], [72.81180573, 19.15902519], [72.81153107, 19.15903091], [72.81153107, 19.15846062], [72.81124878, 19.15847206], [72.81124878, 19.15791702], [72.81096649, 19.15792084], [72.81096649, 19.15736008], [72.81069183, 19.15736389], [72.81069183, 19.15708542], [72.81014252, 19.15708542], [72.81014252, 19.15680313], [72.80986023, 19.15681076], [72.80986023, 19.15653038], [72.80902863, 19.15653038], [72.80902863, 19.15625], [72.80847168, 19.15625], [72.80847168, 19.15596962], [72.80791473, 19.15597153], [72.80791473, 19.15569305], [72.80735779, 19.15571022], [72.80735779, 19.15514183], [72.80708313, 19.15514183], [72.80708313, 19.15485954], [72.80652618, 19.15486145], [72.80652618, 19.15458107], [72.80625153, 19.15458107], [72.80625153, 19.15486145], [72.80596924, 19.15486145], [72.80596924, 19.15458107], [72.80569458, 19.15458107], [72.80569458, 19.15402794], [72.80541992, 19.15403175], [72.80541992, 19.15374947], [72.80513763, 19.15374947], [72.80513763, 19.15319061], [72.80486298, 19.15319443], [72.80486298, 19.15263939], [72.80458069, 19.15265274], [72.80458069, 19.15152931], [72.80430603, 19.15152931], [72.80430603, 19.15097046], [72.80374908, 19.15097237], [72.80375671, 19.15125084], [72.8034668, 19.15125084], [72.8034668, 19.15152931], [72.80236053, 19.15152931], [72.80236053, 19.1518116], [72.80208588, 19.15180588], [72.80208588, 19.15208244], [72.80179596, 19.15208054], [72.80179596, 19.15236092], [72.80124664, 19.15236092], [72.80124664, 19.15265274], [72.80097198, 19.15265274], [72.80097198, 19.15292168], [72.80069733, 19.15291595], [72.80069733, 19.15319443], [72.80041504, 19.15319443], [72.80041504, 19.1534729], [72.80014038, 19.15346909], [72.80014038, 19.15374947], [72.79957581, 19.15374947], [72.79957581, 19.15403175], [72.79985809, 19.15403175], [72.79985809, 19.15431023], [72.79958344, 19.15430641], [72.79958344, 19.15458107], [72.79930878, 19.15458107], [72.79930878, 19.15514183], [72.79902649, 19.15514183], [72.79902649, 19.15571022], [72.79875183, 19.15569305], [72.79875183, 19.15597153], [72.79846954, 19.15596962], [72.79846954, 19.15625], [72.79818726, 19.15625], [72.79818726, 19.15596962], [72.79792023, 19.15597153], [72.79792023, 19.15541649], [72.79818726, 19.1554203], [72.79818726, 19.15458107], [72.79846954, 19.15458107], [72.79846954, 19.15430641], [72.79875183, 19.15431023], [72.79875183, 19.15403175], [72.79902649, 19.15403175], [72.79902649, 19.15346909], [72.79930878, 19.1534729], [72.79930878, 19.15319443], [72.79958344, 19.15319443], [72.79958344, 19.15291595], [72.80014038, 19.15292168], [72.80014038, 19.15236092], [72.79985809, 19.15236092], [72.79985809, 19.15208054], [72.80014038, 19.15208244], [72.80014038, 19.15180588], [72.80069733, 19.1518116], [72.80069733, 19.15125084], [72.80097198, 19.15125084], [72.80097198, 19.15097046], [72.80124664, 19.15097237], [72.80124664, 19.15069389], [72.80152893, 19.15069389], [72.80152893, 19.15041733], [72.80208588, 19.15041924], [72.80208588, 19.14875031], [72.80236053, 19.14875031], [72.80236053, 19.14652061], [72.80263519, 19.14652824], [72.80263519, 19.14513969], [72.80236053, 19.14513969], [72.80236053, 19.14402962], [72.80152893, 19.14402962], [72.80152893, 19.14375114], [72.80097198, 19.14375114], [72.80097198, 19.14346123], [72.80069733, 19.14347458], [72.80069733, 19.14208221], [72.80041504, 19.14208221], [72.80041504, 19.14152718], [72.80029297, 19.14152908], [72.80014038, 19.1415329], [72.80014038, 19.14125061], [72.79985809, 19.14125061], [72.79985809, 19.14097023], [72.79958344, 19.14097023], [72.79958344, 19.14069366], [72.79930878, 19.14069366], [72.79930878, 19.1404171], [72.79902649, 19.14042282], [72.79902649, 19.14014244], [72.79792023, 19.14014244], [72.79792023, 19.14042282], [72.79763794, 19.1404171], [72.79763794, 19.14069366], [72.7951355, 19.14069366], [72.7951355, 19.1404171], [72.79486084, 19.14042282], [72.79486084, 19.14014244], [72.79514313, 19.14014244], [72.79514313, 19.13986015], [72.79597473, 19.13986015], [72.7959671, 19.13708115], [72.79624939, 19.13708305], [72.79624939, 19.13652992], [72.79651642, 19.13652992], [72.79651642, 19.13624954], [72.79680634, 19.13624954], [72.79680634, 19.13347054], [72.79652405, 19.13347244], [72.79652405, 19.1329174], [72.79624939, 19.13292122], [72.79624939, 19.13264084], [72.7959671, 19.13264084], [72.7959671, 19.13236046], [72.79569244, 19.13236046], [72.79569244, 19.13208008], [72.79541779, 19.1320858], [72.79541779, 19.13152695], [72.7951355, 19.13152695], [72.7951355, 19.13097382], [72.79486084, 19.13097382], [72.79486084, 19.13069534], [72.79458618, 19.13070107], [72.79458618, 19.13042068], [72.79374695, 19.13042068], [72.79374695, 19.1301403], [72.79347229, 19.1301403], [72.79347229, 19.12985992], [72.79152679, 19.12985992], [72.79152679, 19.1301403], [72.79096985, 19.1301403], [72.79096985, 19.13042068], [72.78985596, 19.13042068], [72.78985596, 19.1301403], [72.7895813, 19.1301403], [72.7895813, 19.12957954], [72.78930664, 19.12958145], [72.78930664, 19.12930489], [72.78791809, 19.12930489], [72.78791809, 19.12902832], [72.7868042, 19.12902832], [72.7868042, 19.12930489], [72.78652954, 19.12930489], [72.78652954, 19.12958145], [72.78624725, 19.12957954], [72.78624725, 19.13042068], [72.78652954, 19.13042068], [72.78652954, 19.13070107], [72.78736115, 19.13069534], [72.78736115, 19.13097382], [72.78791809, 19.13097382], [72.78791809, 19.13152695], [72.7876358, 19.13152122], [72.7876358, 19.13181114], [72.78652954, 19.13180351], [72.78652954, 19.1320858], [72.7859726, 19.13208008], [72.7859726, 19.13264084], [72.78569031, 19.13264084], [72.78569031, 19.13292122], [72.7859726, 19.1329174], [72.7859726, 19.13347244], [72.7876358, 19.13347054], [72.7876358, 19.13402939], [72.78791809, 19.13402939], [72.78791809, 19.13486099], [72.78819275, 19.13486099], [72.78819275, 19.13958359], [72.78791809, 19.13958168], [72.78791809, 19.14014244], [72.7876358, 19.14014244], [72.7876358, 19.1415329], [72.78736115, 19.14152718], [72.78736115, 19.14319229], [72.7876358, 19.14319038], [72.7876358, 19.14375114], [72.78791809, 19.14375114], [72.78791809, 19.14431], [72.78819275, 19.14430618], [72.78819275, 19.14458466], [72.78847504, 19.14458466], [72.78847504, 19.14486122], [72.78875732, 19.14486122], [72.78875732, 19.14542007], [72.78901672, 19.14542007], [72.78901672, 19.15014076], [72.78875732, 19.15014076], [72.78875732, 19.15041924], [72.78847504, 19.15041733], [72.78847504, 19.15069389], [72.78819275, 19.15068817], [72.78819275, 19.15125084], [72.78791809, 19.15125084], [72.78791809, 19.15208244], [72.7876358, 19.15208054], [72.7876358, 19.15236092], [72.78736115, 19.15236092], [72.78736115, 19.15265274], [72.78708649, 19.15265274], [72.78708649, 19.15292168], [72.7868042, 19.15291595], [72.7868042, 19.15319443], [72.78652954, 19.15319443], [72.78652954, 19.1534729], [72.7859726, 19.15346909], [72.7859726, 19.15374947], [72.78542328, 19.15374947], [72.78542328, 19.15403175], [72.78457642, 19.15403175], [72.78457642, 19.15431023], [72.78430939, 19.15430641], [72.78430176, 19.15486145], [72.7840271, 19.15485954], [72.7840271, 19.1554203], [72.78430176, 19.1554203], [72.78430939, 19.15625], [72.78457642, 19.15625], [72.78457642, 19.15653038], [72.78430939, 19.15652847], [72.78430176, 19.15708542], [72.7840271, 19.15708542], [72.7840271, 19.15736389], [72.78347015, 19.15736008], [72.78347015, 19.15764046], [72.78125, 19.15763855], [72.78125, 19.1581955], [72.78151703, 19.15818977], [72.78151703, 19.15875053], [72.78180695, 19.15875053], [72.78180695, 19.15930939], [72.78236389, 19.15930557], [72.78236389, 19.15958595], [72.7831955, 19.15958595], [72.7831955, 19.15986061], [72.78375244, 19.15986061], [72.78375244, 19.16014099], [72.7840271, 19.16014099], [72.7840271, 19.16236115], [72.78375244, 19.16236115], [72.78375244, 19.16263962], [72.78320313, 19.16263962], [72.78320313, 19.16291809], [72.78263855, 19.16291618], [72.78263855, 19.16319466], [72.78125, 19.16319466], [72.78125, 19.16347313], [72.78097534, 19.16347313], [72.78097534, 19.16430473], [72.78069305, 19.16430092], [72.78069305, 19.16513824], [72.7804184, 19.16513824], [72.7804184, 19.16597176], [72.78013611, 19.16596985], [72.78013611, 19.16625023], [72.7804184, 19.16625023], [72.7804184, 19.16653252], [72.78069305, 19.16653252], [72.78069305, 19.16736031], [72.78098297, 19.16736031], [72.78098297, 19.16765022], [72.78125, 19.16765022], [72.78125, 19.16792107], [72.78152466, 19.16791725], [72.78152466, 19.16819382], [72.78236389, 19.16819382], [72.78236389, 19.16791725], [72.7840271, 19.16792107], [72.7840271, 19.16765022], [72.78457642, 19.16765022], [72.78457642, 19.16708183], [72.7848587, 19.16708374], [72.7848587, 19.16680527], [72.78514099, 19.1668129], [72.78514099, 19.16653252], [72.78624725, 19.16653252], [72.78624725, 19.1668129], [72.78679657, 19.1668129], [72.78679657, 19.16736031], [72.78708649, 19.16736031], [72.78708649, 19.16792107], [72.78736115, 19.16791725], [72.78736115, 19.16819382], [72.7876358, 19.16819191], [72.7876358, 19.16875267], [72.78791809, 19.16875267], [72.78791809, 19.16930962], [72.78819275, 19.1693058], [72.78819275, 19.16958237], [72.79013824, 19.16958046], [72.79013824, 19.16986084], [72.7904129, 19.16986084], [72.7904129, 19.17014122], [72.79069519, 19.17013931], [72.79069519, 19.17097473], [72.79096985, 19.17097092], [72.79096985, 19.17124939], [72.79207611, 19.17124939], [72.79207611, 19.17152977], [72.7923584, 19.17152977], [72.7923584, 19.17181015], [72.79430389, 19.17180634], [72.79430389, 19.17208481], [72.79458618, 19.17208099], [72.79458618, 19.17292023], [72.79486084, 19.17291641], [72.79486084, 19.17347145], [72.7951355, 19.17347145], [72.7951355, 19.17374992], [72.79541779, 19.17374992], [72.79541779, 19.17486191], [72.79569244, 19.17486], [72.79569244, 19.17542076], [72.7959671, 19.17542076], [72.7959671, 19.17764091], [72.79624939, 19.17764091], [72.79624939, 19.1779213], [72.79652405, 19.17791748], [72.79652405, 19.18069458], [72.79624939, 19.18069077], [72.79624939, 19.18153191], [72.79597473, 19.18152809], [72.79597473, 19.18180466], [72.79624939, 19.18180466], [72.79624939, 19.18236351], [72.7959671, 19.1823597], [72.7959671, 19.18292046], [72.79624939, 19.18292046], [72.79624939, 19.18403053], [72.79651642, 19.18403053], [72.79651642, 19.18486023], [72.79624939, 19.18486023], [72.79624939, 19.18736076], [72.7959671, 19.18736076], [72.7959671, 19.18791962], [72.79569244, 19.18791771], [72.79569244, 19.18847275], [72.7959671, 19.18847084], [72.7959671, 19.19124985], [72.79624939, 19.19124985], [72.79624939, 19.19152832], [72.79597473, 19.19152832], [72.79597473, 19.19180489], [72.79624939, 19.19179916], [72.79624939, 19.19375038], [72.79652405, 19.19375038], [72.79652405, 19.19458389], [72.79663086, 19.19457817], [72.79680634, 19.19457054], [72.79680634, 19.19486046], [72.79652405, 19.19486046], [72.79652405, 19.19542122], [72.79652405, 19.1981926], [72.79680634, 19.1981926], [72.79680634, 19.19847488], [72.79708099, 19.19847107], [72.79708099, 19.19874954], [72.79680634, 19.19874954], [72.79680634, 19.19902992], [72.79708099, 19.19902802], [72.79708099, 19.19958305], [72.79736328, 19.19958305], [72.79736328, 19.19986153], [72.79792023, 19.19986153], [72.79792023, 19.19958305], [72.79875183, 19.19958305], [72.79875183, 19.19986153], [72.79902649, 19.19986153], [72.79902649, 19.19958305], [72.80041504, 19.19958305], [72.80041504, 19.19986153], [72.80069733, 19.19985962], [72.80069733, 19.20042038], [72.80097198, 19.20042038], [72.80097198, 19.20070076], [72.80124664, 19.20069695], [72.80124664, 19.2009716], [72.80152893, 19.2009697], [72.80152893, 19.20153046], [72.80180359, 19.20152855], [72.80180359, 19.20208359], [72.80208588, 19.20207977], [72.80208588, 19.20264053], [72.80264282, 19.20264053], [72.80264282, 19.20513916], [72.80291748, 19.20513916], [72.80291748, 19.20624924], [72.80319214, 19.20624924], [72.80319214, 19.20652962], [72.80347443, 19.20652771], [72.80347443, 19.20680618], [72.80374908, 19.20680618], [72.80374908, 19.2084713], [72.80403137, 19.20846939], [72.80403137, 19.20874977], [72.80430603, 19.20874977], [72.80430603, 19.20903015], [72.80458069, 19.20902824], [72.80458069, 19.20930481], [72.80513763, 19.20930481], [72.80513763, 19.20958138], [72.80541992, 19.20958138], [72.80541992, 19.20986366], [72.80568695, 19.20985985], [72.80568695, 19.21014023], [72.80596924, 19.21014023], [72.80596924, 19.21042061], [72.80625153, 19.21042061], [72.80625153, 19.21070099], [72.80680847, 19.21069336], [72.80680847, 19.21097374], [72.80764008, 19.21096992], [72.80764008, 19.21125031], [72.8079071, 19.21125031], [72.8079071, 19.21153069], [72.80819702, 19.21153069], [72.80819702, 19.21181107], [72.80902863, 19.21180344], [72.80902863, 19.21208572], [72.80930328, 19.21208], [72.80930328, 19.21236038], [72.8095932, 19.21236038], [72.8095932, 19.21264076], [72.80986023, 19.21264076], [72.80986023, 19.21293068], [72.81014252, 19.21291733], [72.81014252, 19.2131958], [72.81041718, 19.21319008], [72.81041718, 19.21375084], [72.81069183, 19.21375084], [72.81069183, 19.21430969], [72.81124878, 19.21430779], [72.81124878, 19.21458244], [72.81153107, 19.21458054], [72.81153107, 19.21513939], [72.81124878, 19.21513939], [72.81124878, 19.21541977], [72.81096649, 19.21541977], [72.81096649, 19.21569824], [72.81124878, 19.21569824], [72.81124878, 19.21624947], [72.81096649, 19.21624947], [72.81096649, 19.22014046], [72.81124878, 19.22014046], [72.81124878, 19.22125053], [72.81153107, 19.22125053], [72.81153107, 19.22153282], [72.81180573, 19.2215271], [72.81180573, 19.22208214], [72.81208038, 19.22208023], [72.81208038, 19.22236061], [72.81236267, 19.22236061], [72.81236267, 19.22291946], [72.81263733, 19.22291756], [72.81263733, 19.2234745], [72.81430817, 19.22347069], [72.81430817, 19.22375107], [72.81513977, 19.22375107], [72.81513977, 19.22402954], [72.81569672, 19.22402954], [72.81569672, 19.22430992], [72.81597137, 19.2243042], [72.81597137, 19.22458458], [72.81652832, 19.22458076], [72.81652832, 19.22487068], [72.81680298, 19.22487068], [72.81680298, 19.22513962], [72.8170929, 19.22513962], [72.8170929, 19.22542], [72.81735992, 19.22541428], [72.81735992, 19.22569656], [72.81764221, 19.22569656], [72.81764221, 19.22597313], [72.81791687, 19.22597122], [72.81791687, 19.22624969], [72.81846619, 19.22624969], [72.81846619, 19.22653008], [72.81874847, 19.22652817], [72.81874847, 19.22680664], [72.81903076, 19.22680664], [72.81903076, 19.22708321], [72.81930542, 19.22708321], [72.81930542, 19.22736168], [72.81958008, 19.22735977], [72.81958008, 19.22792816], [72.81986237, 19.22792816], [72.81986237, 19.22820091], [72.82013702, 19.22819519], [72.82013702, 19.22847176], [72.82041931, 19.22846985], [72.82041931, 19.22875023], [72.82068634, 19.22875023], [72.82068634, 19.22903061], [72.82096863, 19.2290287], [72.82096863, 19.22958374], [72.82125092, 19.22957993], [72.82125092, 19.22986031], [72.8215332, 19.22986031], [72.8215332, 19.23041916], [72.82180786, 19.23041725], [72.82180786, 19.23069382], [72.82208252, 19.23069382], [72.82208252, 19.23097229], [72.82235718, 19.23097038], [72.82235718, 19.23152924], [72.82263947, 19.23152733], [72.82263947, 19.23208237], [72.82291412, 19.23208427], [72.82291412, 19.23347282], [72.82319641, 19.23347282], [72.82319641, 19.23374939], [72.82347107, 19.23373985], [72.82347107, 19.23431015], [72.82375336, 19.23430634], [72.82375336, 19.2345829], [72.82402802, 19.2345829], [72.82402802, 19.23486137], [72.82430267, 19.23485947], [72.82430267, 19.23542023], [72.82458496, 19.23541641], [72.82458496, 19.23624992], [72.82514191, 19.23624992], [72.82514191, 19.2365303], [72.82541656, 19.2365284], [72.82541656, 19.23708153], [72.82569122, 19.23708153], [72.82569122, 19.23958588], [72.82596588, 19.23958015], [72.82596588, 19.24041939], [72.82624817, 19.24041748], [72.82624817, 19.24069595], [72.82653046, 19.24069023], [72.82653046, 19.24152946], [72.82681274, 19.24152946], [72.82681274, 19.24180984], [72.82653046, 19.24180794], [72.82653046, 19.2420826], [72.82680511, 19.2420826], [72.82680511, 19.24263954], [72.82707977, 19.24263954], [72.82707977, 19.24291611], [72.82680511, 19.24291611], [72.82680511, 19.24319458], [72.82707977, 19.24319077], [72.82707977, 19.24374962], [72.82736206, 19.24374962], [72.82736206, 19.24430466], [72.82763672, 19.24430466], [72.82763672, 19.2448616], [72.82792664, 19.2448597], [72.82792664, 19.24513817], [72.82818604, 19.24513817], [72.82818604, 19.24570084], [72.82847595, 19.24569511], [72.82847595, 19.24596977], [72.82878876, 19.24601364], [72.82875061, 19.24625015], [72.8290329, 19.24625015], [72.8290329, 19.24653244], [72.82930756, 19.24653244], [72.82930756, 19.24681282], [72.83041382, 19.24680519], [72.83041382, 19.24708366], [72.83125305, 19.24708176], [72.83125305, 19.24736023], [72.83180237, 19.24736023], [72.83180237, 19.24764252], [72.83374023, 19.24764252], [72.83374023, 19.2479229], [72.83403015, 19.24791718], [72.83403015, 19.24819374], [72.83569336, 19.24819374], [72.83569336, 19.24847031], [72.83625031, 19.24847031], [72.83625031, 19.24875069], [72.83679962, 19.24875069], [72.83679962, 19.24903107], [72.83708191, 19.24903107], [72.83708191, 19.24930954], [72.83763885, 19.24930573], [72.83763885, 19.24958229], [72.83790588, 19.24958038], [72.83790588, 19.24986076], [72.8381958, 19.24986076], [72.8381958, 19.25014114], [72.83875275, 19.25014114], [72.83875275, 19.25041962], [72.83930206, 19.2504158], [72.83930206, 19.25069237], [72.83958435, 19.25069237], [72.83958435, 19.2523613], [72.83986664, 19.25235939], [72.83986664, 19.25292015], [72.83958435, 19.25291443], [72.83958435, 19.25347137], [72.83986664, 19.25346947], [72.83986664, 19.25403023], [72.83958435, 19.25402832], [72.83958435, 19.25458336], [72.83930206, 19.25457954], [72.83930206, 19.25542068], [72.8390274, 19.25542068], [72.8390274, 19.25570107], [72.83875275, 19.25569534], [72.83875275, 19.25597191], [72.83847046, 19.25597], [72.83847046, 19.25625038], [72.8381958, 19.25625038], [72.8381958, 19.25653076], [72.83763885, 19.25652885], [72.83763885, 19.25708389], [72.83742523, 19.25708008], [72.83735657, 19.25764084], [72.83708191, 19.25763893], [72.83708191, 19.25819397], [72.83680725, 19.25819397], [72.83680725, 19.25847244], [72.83652496, 19.25847244], [72.83652496, 19.25875092], [72.83598328, 19.25875092], [72.83598328, 19.25902939], [72.83569336, 19.25902748], [72.83569336, 19.25958252], [72.8354187, 19.25958061], [72.8354187, 19.26042175], [72.83513641, 19.26041603], [72.83513641, 19.2606945], [72.8354187, 19.26069069], [72.8354187, 19.26153183], [72.83569336, 19.26152802], [72.83569336, 19.26208115], [72.83597565, 19.26208115], [72.83597565, 19.26236153], [72.83625031, 19.26236153], [72.83625031, 19.2634716], [72.83652496, 19.2634716], [72.83652496, 19.26375008], [72.83679962, 19.26375008], [72.83679962, 19.26403999], [72.83708191, 19.26403999], [72.83708191, 19.26486015], [72.83735657, 19.26486015], [72.83735657, 19.26514053], [72.83763885, 19.26514053], [72.83763885, 19.26542091], [72.83791351, 19.2654171], [72.83791351, 19.26569557], [72.8381958, 19.26569557], [72.8381958, 19.26597214], [72.83847046, 19.26597023], [72.83847046, 19.26625061], [72.83875275, 19.26625061], [72.83875275, 19.26653099], [72.8390274, 19.26653099], [72.8390274, 19.26680946], [72.83930206, 19.26680565], [72.83930206, 19.26708412], [72.83957672, 19.26708031], [72.83957672, 19.26736069], [72.83930206, 19.26736069], [72.83930206, 19.26764107], [72.8390274, 19.26764107], [72.8390274, 19.26736069], [72.83875275, 19.26736069], [72.83875275, 19.26708031], [72.8381958, 19.26708412], [72.8381958, 19.26680565], [72.83790588, 19.26680946], [72.83790588, 19.26653099], [72.83763885, 19.26653099], [72.83763885, 19.26625061], [72.83735657, 19.26625061], [72.83735657, 19.26597023], [72.83708191, 19.26597214], [72.83708191, 19.26569557], [72.83680725, 19.26569557], [72.83680725, 19.26513863], [72.83653259, 19.26514053], [72.83653259, 19.26486015], [72.83625031, 19.26486206], [72.83625031, 19.26402855], [72.83598328, 19.26403999], [72.83598328, 19.26375008], [72.83569336, 19.26375008], [72.83569336, 19.2634697], [72.8354187, 19.2634716], [72.8354187, 19.26236153], [72.83513641, 19.26236153], [72.83513641, 19.26208115], [72.83486176, 19.26208115], [72.83486176, 19.26152802], [72.8345871, 19.26153183], [72.8345871, 19.26069069], [72.83430481, 19.2606945], [72.83430481, 19.26013947], [72.8345871, 19.26013947], [72.8345871, 19.25931168], [72.83486176, 19.25931168], [72.83486176, 19.25875092], [72.83513641, 19.25875092], [72.83513641, 19.25847054], [72.83569336, 19.25847244], [72.83569336, 19.25819397], [72.83597565, 19.25819397], [72.83597565, 19.2579174], [72.83625031, 19.2579174], [72.83625031, 19.25763893], [72.83653259, 19.25764084], [72.83653259, 19.25707817], [72.83680725, 19.25708389], [72.83680725, 19.25652885], [72.83708191, 19.25653076], [72.83708191, 19.25625038], [72.83735657, 19.25625038], [72.83735657, 19.25597], [72.83763885, 19.25597191], [72.83763885, 19.25569534], [72.83790588, 19.25570107], [72.83790588, 19.25374985], [72.83763885, 19.25374985], [72.83763885, 19.25346947], [72.8373642, 19.25347137], [72.8373642, 19.25291443], [72.83708191, 19.25292015], [72.83708191, 19.25263977], [72.83679962, 19.25263977], [72.83679962, 19.25208092], [72.83652496, 19.25208473], [72.83652496, 19.25124931], [72.83598328, 19.25125122], [72.83598328, 19.25097084], [72.8345871, 19.25097466], [72.8345871, 19.25069237], [72.83347321, 19.25069237], [72.83347321, 19.2504158], [72.83069611, 19.25041962], [72.83069611, 19.25014114], [72.8290329, 19.25014114], [72.8290329, 19.24986076], [72.82847595, 19.24986076], [72.82847595, 19.24958038], [72.82763672, 19.24958229], [72.82763672, 19.24930573], [72.82736206, 19.24930573], [72.82736206, 19.24958229], [72.82707977, 19.24958229], [72.82707977, 19.24930573], [72.82681274, 19.24930954], [72.82681274, 19.24903107], [72.82624817, 19.24903107], [72.82624817, 19.24875069], [72.82569885, 19.24875069], [72.82569122, 19.24847031], [72.82541656, 19.24847031], [72.82541656, 19.24819374], [72.82514191, 19.24819374], [72.82514191, 19.24791718], [72.82485962, 19.2479229], [72.82485962, 19.24764252], [72.82457733, 19.24764252], [72.82457733, 19.24736023], [72.82430267, 19.24736023], [72.82430267, 19.24708176], [72.82375336, 19.24708366], [72.82375336, 19.24680519], [72.82347107, 19.24681282], [72.82347107, 19.24653244], [72.82319641, 19.24653244], [72.82319641, 19.24625015], [72.82290649, 19.24625015], [72.82290649, 19.24596977], [72.82263947, 19.24597168], [72.82263947, 19.24569511], [72.82235718, 19.24570084], [72.82235718, 19.24541855], [72.82180023, 19.24541855], [72.82180023, 19.24513817], [72.82096863, 19.24513817], [72.82096863, 19.24541855], [72.82041931, 19.24541855], [72.82041931, 19.2448597], [72.82069397, 19.2448616], [72.82069397, 19.24458313], [72.82096863, 19.24458313], [72.82096863, 19.24374962], [72.8215332, 19.24374962], [72.82152557, 19.2420826], [72.82125092, 19.2420826], [72.82125092, 19.24180794], [72.8215332, 19.24180984], [72.8215332, 19.24152946], [72.82125092, 19.24152946], [72.82125092, 19.24069023], [72.82096863, 19.24069595], [72.82096863, 19.24013901], [72.82068634, 19.24014091], [72.82068634, 19.23931122], [72.82041931, 19.23931122], [72.82041931, 19.23847008], [72.82013702, 19.23847389], [72.82013702, 19.23763847], [72.81986237, 19.23764038], [72.81986237, 19.23681068], [72.81958008, 19.23681068], [72.81958008, 19.23624992], [72.81930542, 19.23624992], [72.81930542, 19.23597145], [72.81903076, 19.23597145], [72.81903076, 19.23541641], [72.81846619, 19.23542023], [72.81846619, 19.23513985], [72.81819153, 19.23513985], [72.81819153, 19.2345829], [72.81791687, 19.2345829], [72.81791687, 19.23430634], [72.81764221, 19.23431015], [72.81764221, 19.23403168], [72.8170929, 19.23403168], [72.8170929, 19.23347092], [72.81680298, 19.23347282], [72.81680298, 19.23291588], [72.81652832, 19.2329216], [72.81652832, 19.23263931], [72.81624603, 19.23263931], [72.81624603, 19.23208046], [72.81597137, 19.23208427], [72.81597137, 19.2318058], [72.81569672, 19.23181152], [72.81569672, 19.23125076], [72.81513977, 19.23125076], [72.81513977, 19.23097038], [72.81485748, 19.23097229], [72.81485748, 19.23069382], [72.81458282, 19.23069382], [72.81458282, 19.23041725], [72.81430817, 19.23041916], [72.81430817, 19.23014069], [72.81318665, 19.23014069], [72.81318665, 19.22986031], [72.81236267, 19.22986031], [72.81236267, 19.22957993], [72.81208038, 19.22958374], [72.81208038, 19.22930527], [72.81181335, 19.22930908], [72.81181335, 19.22903061], [72.81153107, 19.22903061], [72.81153107, 19.22875023], [72.81124878, 19.22875023], [72.81124878, 19.22846985], [72.81097412, 19.22847176], [72.81097412, 19.22819519], [72.81069183, 19.22820091], [72.81069183, 19.22792816], [72.81041718, 19.22792816], [72.81041718, 19.22764015], [72.81014252, 19.22764015], [72.81014252, 19.22735977], [72.80986023, 19.22736168], [72.80986023, 19.22680664], [72.80958557, 19.22680664], [72.80958557, 19.22652817], [72.80930328, 19.22653008], [72.80930328, 19.22624969], [72.80902863, 19.22624969], [72.80902863, 19.22597122], [72.80847168, 19.22597313], [72.80847168, 19.22569656], [72.80819702, 19.22569656], [72.80819702, 19.22541428], [72.8079071, 19.22542], [72.8079071, 19.22513962], [72.80764008, 19.22513962], [72.80764008, 19.22487068], [72.80735779, 19.22487068], [72.80735779, 19.22458076], [72.80708313, 19.22458458], [72.80708313, 19.22402763], [72.80680084, 19.22402954], [72.80680084, 19.22347069], [72.80652618, 19.2234745], [72.80652618, 19.22319221], [72.80625153, 19.22319221], [72.80625153, 19.22291756], [72.80596924, 19.22291946], [72.80596924, 19.22236061], [72.80568695, 19.22236061], [72.80568695, 19.22208023], [72.80541992, 19.22208214], [72.80541992, 19.22180557], [72.80513763, 19.22180557], [72.80513763, 19.22097015], [72.80430603, 19.22097015], [72.80430603, 19.22125053], [72.80403137, 19.22125053], [72.80403137, 19.22153282], [72.80347443, 19.2215271], [72.80347443, 19.22180557], [72.80291748, 19.22180557], [72.80291748, 19.22208214], [72.80236053, 19.22208023], [72.80236053, 19.22236061], [72.80069733, 19.22236061], [72.80069733, 19.22291946], [72.80041504, 19.22291756], [72.80041504, 19.22319221], [72.79985809, 19.22319221], [72.79985809, 19.2234745], [72.79875183, 19.2234745], [72.79875183, 19.22319221], [72.79846954, 19.22319221], [72.79846954, 19.22263908], [72.79875183, 19.2226429], [72.79875183, 19.22236061], [72.79930878, 19.22236061], [72.79930878, 19.22208023], [72.80014038, 19.22208214], [72.80014038, 19.22180557], [72.80069733, 19.22180557], [72.80069733, 19.2215271], [72.80124664, 19.22153282], [72.80124664, 19.22125053], [72.80152893, 19.22125053], [72.80152893, 19.22097015], [72.80263519, 19.22097015], [72.80263519, 19.22069359], [72.80291748, 19.22069359], [72.80291748, 19.22041702], [72.80319214, 19.22042274], [72.80319214, 19.22014046], [72.8034668, 19.22014046], [72.8034668, 19.21986008], [72.80374908, 19.21986008], [72.80374908, 19.21930504], [72.80403137, 19.21931267], [72.80403137, 19.21874046], [72.80374908, 19.21874809], [72.80374908, 19.21736145], [72.80347443, 19.21736145], [72.80347443, 19.21680641], [72.80319214, 19.21680832], [72.80319214, 19.21652985], [72.80291748, 19.21652985], [72.80291748, 19.21624947], [72.80264282, 19.21624947], [72.80264282, 19.21652985], [72.80236053, 19.21652985], [72.80236053, 19.21624947], [72.80208588, 19.21624947], [72.80208588, 19.21569824], [72.80179596, 19.21569824], [72.80179596, 19.21541977], [72.80152893, 19.21541977], [72.80152893, 19.21513939], [72.80124664, 19.21513939], [72.80124664, 19.21486092], [72.80097198, 19.21486092], [72.80097198, 19.21458054], [72.80069733, 19.21458244], [72.80069733, 19.21430779], [72.80014038, 19.21430969], [72.80014038, 19.21347046], [72.79985809, 19.21347237], [72.79985809, 19.21291733], [72.79957581, 19.21293068], [72.79957581, 19.21264076], [72.79930878, 19.21264076], [72.79930878, 19.21236038], [72.79902649, 19.21236038], [72.79902649, 19.21208], [72.79875183, 19.21208572], [72.79875183, 19.21180344], [72.79846954, 19.21181107], [72.79846954, 19.21153069], [72.79818726, 19.21153069], [72.79818726, 19.21125031], [72.79792023, 19.21125031], [72.79792023, 19.21070099], [72.79763031, 19.21070099], [72.79763031, 19.21042061], [72.79736328, 19.21042061], [72.79736328, 19.20985985], [72.79708099, 19.20986366], [72.79708099, 19.20930481], [72.79680634, 19.20930481], [72.79680634, 19.20874977], [72.79651642, 19.20874977], [72.79651642, 19.20792007], [72.79624939, 19.20792007], [72.79624939, 19.20763969], [72.7959671, 19.20763969], [72.7959671, 19.20708084], [72.79486084, 19.20708275], [72.79486084, 19.20680618], [72.79458618, 19.20680618], [72.79458618, 19.20652771], [72.79429626, 19.20652962], [72.79429626, 19.20624924], [72.79402924, 19.20624924], [72.79402924, 19.20597076], [72.79374695, 19.20597267], [72.79374695, 19.20541763], [72.79319763, 19.20542145], [72.79319763, 19.20513916], [72.79292297, 19.20513916], [72.79292297, 19.20458031], [72.79264069, 19.20458412], [72.79264069, 19.20430565], [72.7923584, 19.20430756], [72.7923584, 19.20375824], [72.79207611, 19.20375824], [72.79207611, 19.20264053], [72.79181671, 19.20264053], [72.79181671, 19.20070076], [72.79207611, 19.20070076], [72.79207611, 19.20014], [72.7923584, 19.20014], [72.7923584, 19.19985962], [72.79264069, 19.19986153], [72.79264069, 19.19958305], [72.79291534, 19.19958305], [72.79291534, 19.19902802], [72.79319763, 19.19902992], [72.79319763, 19.19847107], [72.79347229, 19.19847488], [72.79347229, 19.19763947], [72.79374695, 19.19763947], [72.79374695, 19.19597435], [72.79347229, 19.19597435], [72.79347229, 19.19569206], [72.79319763, 19.19569206], [72.79319763, 19.19513893], [72.79292297, 19.19514275], [72.79292297, 19.19486046], [72.79264069, 19.19486046], [72.79264069, 19.19457054], [72.7923584, 19.19458389], [72.7923584, 19.19430542], [72.79207611, 19.19431114], [72.79207611, 19.19403267], [72.79181671, 19.19403267], [72.79181671, 19.19375038], [72.79152679, 19.19375038], [72.79152679, 19.19347191], [72.79125214, 19.19347191], [72.79125214, 19.19319534], [72.79096985, 19.19320107], [72.79096985, 19.19292259], [72.79013824, 19.19292259], [72.79013824, 19.1926403], [72.78901672, 19.1926403], [72.78901672, 19.19292259], [72.78875732, 19.19292259], [72.78875732, 19.19320107], [72.78847504, 19.19319534], [72.78847504, 19.19347191], [72.78791809, 19.19347191], [72.78791809, 19.19319534], [72.78708649, 19.19320107], [72.78708649, 19.19292259], [72.7859726, 19.19292259], [72.7859726, 19.1926403], [72.78569031, 19.1926403], [72.78569031, 19.19235992], [72.78542328, 19.19235992], [72.78542328, 19.1926403], [72.78457642, 19.1926403], [72.78457642, 19.19235992], [72.78375244, 19.19235992], [72.78375244, 19.1926403], [72.78347015, 19.1926403], [72.78347015, 19.19292259], [72.78320313, 19.19292259], [72.78320313, 19.19320107], [72.78236389, 19.19319534], [72.78236389, 19.19347191], [72.7820816, 19.19347191], [72.7820816, 19.19375038], [72.78180695, 19.19375038], [72.78180695, 19.19403267], [72.78152466, 19.19402695], [72.78152466, 19.19458389], [72.78125, 19.19457054], [72.78125, 19.19652939], [72.78152466, 19.19652748], [72.78152466, 19.19708252], [72.78180695, 19.19708252], [72.78180695, 19.19930077], [72.7820816, 19.1993103], [72.7820816, 19.20014], [72.78235626, 19.20014], [72.78235626, 19.20070076], [72.78263855, 19.20069695], [72.78263855, 19.2009716], [72.78291321, 19.2009697], [72.78291321, 19.20125008], [72.78457642, 19.20125008], [72.78457642, 19.2009697], [72.78514099, 19.2009697], [72.78514099, 19.20125008], [72.78569031, 19.20125008], [72.78569031, 19.20153046], [72.7859726, 19.20153046], [72.7859726, 19.20181084], [72.78624725, 19.20181084], [72.78624725, 19.20264053], [72.7859726, 19.20263863], [72.7859726, 19.20347214], [72.78569031, 19.20347023], [72.78569031, 19.20375824], [72.78514099, 19.20375824], [72.78514099, 19.20513916], [72.7848587, 19.20513916], [72.7848587, 19.20542145], [72.78458405, 19.20541763], [72.78458405, 19.2056942], [72.78430939, 19.2056942], [72.78430176, 19.20597267], [72.78375244, 19.20597076], [72.78375244, 19.20624924], [72.78151703, 19.20624924], [72.78151703, 19.20597076], [72.78125, 19.20597267], [72.78125, 19.2056942], [72.78097534, 19.2056942], [72.78097534, 19.20541763], [72.77929688, 19.20542145], [72.77929688, 19.20735931], [72.77958679, 19.20735931], [72.77958679, 19.20763969], [72.77986145, 19.20763969], [72.77986145, 19.20792007], [72.78013611, 19.20791626], [72.78013611, 19.2084713], [72.7804184, 19.20846939], [72.7804184, 19.20903015], [72.78069305, 19.20902824], [72.78069305, 19.20930481], [72.78098297, 19.2093029], [72.78098297, 19.21014023], [72.78125, 19.21014023], [72.78125, 19.21153069], [72.78151703, 19.21153069], [72.78151703, 19.21513939], [72.78125, 19.21513939], [72.78125, 19.21569824], [72.78098297, 19.21569824], [72.78098297, 19.21652985], [72.78069305, 19.21652985], [72.78069305, 19.21680832], [72.7804184, 19.21680641], [72.7804184, 19.21708298], [72.78013611, 19.21708298], [72.78013611, 19.21736145], [72.77986145, 19.21735954], [72.77986145, 19.21763992], [72.77958679, 19.21763992], [72.77958679, 19.2179184], [72.77902985, 19.2179184], [72.77902985, 19.21931267], [72.77874756, 19.21930504], [72.77874756, 19.21986008], [72.7784729, 19.21986008], [72.7784729, 19.22014046], [72.77819824, 19.22014046], [72.77819824, 19.21999931], [72.77819061, 19.21986008], [72.77791595, 19.21986008], [72.77791595, 19.22014046], [72.7776413, 19.22013855], [72.7776413, 19.22069359], [72.77735901, 19.22069359], [72.77735901, 19.22097015], [72.77680206, 19.22097015], [72.77680206, 19.22125053], [72.7765274, 19.22125053], [72.7765274, 19.22153282], [72.77625275, 19.2215271], [72.77625275, 19.22208214], [72.77597046, 19.22208214], [72.77597046, 19.22458458], [72.77625275, 19.22458458], [72.77625275, 19.22569656], [72.7765274, 19.22569084], [72.7765274, 19.22624969], [72.77680206, 19.22624969], [72.77680206, 19.22680664], [72.77735901, 19.22680664], [72.77735901, 19.22708321], [72.7776413, 19.22708321], [72.7776413, 19.22736168], [72.77791595, 19.22735977], [72.77791595, 19.22764015], [72.7784729, 19.22764015], [72.7784729, 19.22792816], [72.77874756, 19.22792816], [72.77874756, 19.22820091], [72.77902985, 19.22820091], [72.77902985, 19.22875023], [72.77929688, 19.22875023], [72.77929688, 19.22986031], [72.77958679, 19.22986031], [72.77958679, 19.23041916], [72.77986145, 19.23041725], [72.77986145, 19.23319435], [72.77958679, 19.23319054], [72.77958679, 19.23542023], [72.7793045, 19.23541641], [72.7793045, 19.23597145], [72.77902985, 19.23596954], [72.77902985, 19.23624992], [72.77874756, 19.23624992], [72.77874756, 19.2365303], [72.77819824, 19.2365284], [72.77819824, 19.23708153], [72.77791595, 19.23707962], [72.77791595, 19.23792076], [72.77958679, 19.23791695], [72.77958679, 19.23819542], [72.77986145, 19.23819542], [72.77986145, 19.23847389], [72.78013611, 19.23847008], [72.78013611, 19.23931122], [72.7804184, 19.23931122], [72.7804184, 19.23987007], [72.78069305, 19.23986053], [72.78069305, 19.24097252], [72.7804184, 19.24097061], [72.7804184, 19.24125099], [72.78013611, 19.24125099], [72.78013611, 19.24236107], [72.7804184, 19.24236107], [72.7804184, 19.24319458], [72.78069305, 19.24319458], [72.78069305, 19.24347305], [72.78097534, 19.24347305], [72.78097534, 19.24374962], [72.78125, 19.24374962], [72.78125, 19.24430466], [72.78098297, 19.24430084], [72.78098297, 19.24541855], [72.78125, 19.24541664], [72.78125, 19.24597168], [72.78151703, 19.24596977], [72.78151703, 19.24681282], [72.78180695, 19.24681282], [72.78180695, 19.2479229], [72.7820816, 19.2479229], [72.7820816, 19.24903107], [72.78235626, 19.24903107], [72.78235626, 19.24986076], [72.78263092, 19.24986076], [72.78263092, 19.25014114], [72.78291321, 19.25014114], [72.78291321, 19.25181007], [72.78263855, 19.25180626], [72.78263855, 19.25319672], [72.78235626, 19.25319099], [72.78235626, 19.25653076], [72.7820816, 19.25652885], [72.7820816, 19.25708389], [72.78180695, 19.25708389], [72.78180695, 19.25819397], [72.78152466, 19.25819397], [72.78152466, 19.25958252], [72.78180695, 19.25958061], [72.78180695, 19.26013947], [72.78291321, 19.26013947], [72.78291321, 19.26042175], [72.7831955, 19.26041603], [72.7831955, 19.2606945], [72.78347015, 19.26069069], [72.78347015, 19.26153183], [72.78375244, 19.26152802], [72.78375244, 19.26180267], [72.7840271, 19.26180649], [72.7840271, 19.2634716], [72.78375244, 19.2634697], [72.78375244, 19.26403999], [72.78347015, 19.26403999], [72.78347015, 19.26514053], [72.78375244, 19.26514053], [72.78375244, 19.26542091], [72.78430176, 19.2654171], [72.78430939, 19.26569557], [72.78458405, 19.26569557], [72.78458405, 19.26597214], [72.78430939, 19.26597214], [72.78430176, 19.2681942], [72.7840271, 19.2681942], [72.7840271, 19.26847267], [72.78375244, 19.26847076], [72.78375244, 19.26875114], [72.78347015, 19.26875114], [72.78347015, 19.26902962], [72.7820816, 19.26902962], [72.7820816, 19.26930809], [72.78152466, 19.26930618], [72.78152466, 19.26958275], [72.78125, 19.26958275], [72.78125, 19.27180481], [72.78097534, 19.27180481], [72.78097534, 19.27208328], [72.78069305, 19.27208328], [72.78069305, 19.27291679], [72.7804184, 19.27291679], [72.7804184, 19.27347183], [72.78013611, 19.27347183], [72.78013611, 19.27542114], [72.77986145, 19.27542114], [72.77986145, 19.27625275], [72.77958679, 19.27625275], [72.77958679, 19.27653122], [72.7793045, 19.2765274], [72.7793045, 19.27708244], [72.77902985, 19.27708054], [72.77902985, 19.27791977], [72.77874756, 19.27791405], [72.77874756, 19.27819252], [72.7784729, 19.27819252], [72.7784729, 19.27847481], [72.77819824, 19.27847099], [72.77819824, 19.27903938], [72.77874756, 19.27903938], [72.77874756, 19.27931023], [72.77986145, 19.27930641], [72.77986145, 19.27958488], [72.78180695, 19.27958488], [72.78180695, 19.27930641], [72.7831955, 19.27930641], [72.7831955, 19.27986145], [72.78347015, 19.27985954], [72.78347015, 19.2804203], [72.78375244, 19.2804203], [72.78375244, 19.28763962], [72.7840271, 19.28763962], [72.7840271, 19.28847122], [72.78430176, 19.28847122], [72.78430939, 19.28903008], [72.78457642, 19.28903008], [72.78457642, 19.29153061], [72.78430939, 19.29153061], [72.78430939, 19.29375076], [72.78457642, 19.29375076], [72.78457642, 19.30042267], [72.78430939, 19.30042267], [72.78430939, 19.30264282], [72.78458405, 19.30263901], [72.78458405, 19.30347443], [72.7848587, 19.30347061], [72.7848587, 19.3037529], [72.78514099, 19.3037529], [72.78514099, 19.30402946], [72.78542328, 19.30402946], [72.78542328, 19.30430984], [72.78569794, 19.30430412], [72.78569794, 19.30597305], [72.7859726, 19.3059597], [72.7859726, 19.30624962], [72.78624725, 19.30624962], [72.78624725, 19.30653], [72.78652954, 19.30652809], [72.78652954, 19.30680656], [72.78624725, 19.30680656], [72.78624725, 19.30708313], [72.78652954, 19.30708313], [72.78652954, 19.3073616], [72.78679657, 19.3073597], [72.78679657, 19.30764008], [72.78708649, 19.30764008], [72.78708649, 19.30792046], [72.78736115, 19.30792046], [72.78736115, 19.30820084], [72.78791809, 19.30819511], [72.78791809, 19.30847168], [72.78847504, 19.30847168], [72.78847504, 19.30875015], [72.78902435, 19.30875015], [72.78902435, 19.30902863], [72.7895813, 19.309021], [72.7895813, 19.30931091], [72.78986359, 19.30930519], [72.78986359, 19.30958366], [72.79096985, 19.30957985], [72.79096985, 19.30986023], [72.79181671, 19.30986023], [72.79181671, 19.31014061], [72.7923584, 19.31014061], [72.7923584, 19.31041908], [72.79319763, 19.31042862], [72.79319763, 19.31125069], [72.79347229, 19.31125069], [72.79347229, 19.31209183], [72.79374695, 19.3120842], [72.79374695, 19.31319427], [72.79402924, 19.31318855], [72.79402924, 19.31431007], [72.79429626, 19.31431007], [72.79429626, 19.31515121], [72.79458618, 19.31515121], [72.79458618, 19.31624985], [72.79486084, 19.31624985], [72.79486084, 19.31708145], [72.7951355, 19.31708145], [72.7951355, 19.31819344], [72.79541779, 19.31818962], [72.79541779, 19.31931114], [72.79569244, 19.31931114], [72.79569244, 19.32014084], [72.7959671, 19.32014084], [72.7959671, 19.32125092], [72.79624939, 19.32125092], [72.79624939, 19.32208252], [72.79652405, 19.32208252], [72.79652405, 19.3231945], [72.79680634, 19.3231945], [72.79680634, 19.32430077], [72.79708099, 19.32432175], [72.79708099, 19.32513809], [72.79736328, 19.32513809], [72.79736328, 19.32625008], [72.79763031, 19.32625008], [72.79763031, 19.32709122], [72.79792023, 19.32708359], [72.79792023, 19.32819366], [72.79818726, 19.32819176], [72.79818726, 19.32930946], [72.79846954, 19.32930565], [72.79846954, 19.33013916], [72.79875183, 19.33013916], [72.79875183, 19.33097458], [72.79902649, 19.33097076], [72.79902649, 19.33125114], [72.79846954, 19.33125114], [72.79846954, 19.33152962], [72.79818726, 19.33152962], [72.79818726, 19.33181], [72.79792023, 19.33180428], [72.79792023, 19.33208466], [72.79763031, 19.33208084], [72.79763031, 19.33236122], [72.79708099, 19.33236122], [72.79708099, 19.33263969], [72.79680634, 19.33263969], [72.79680634, 19.33292007], [72.79652405, 19.33291435], [72.79652405, 19.33319664], [72.79624939, 19.33319092], [72.79624939, 19.33374977], [72.79569244, 19.33374977], [72.79569244, 19.33403015], [72.79541779, 19.33402824], [72.79541779, 19.33458328], [72.7951355, 19.33458328], [72.7951355, 19.33486176], [72.79486084, 19.33485985], [72.79486084, 19.33514023], [72.79429626, 19.33514023], [72.79429626, 19.33570099], [72.79374695, 19.33569527], [72.79374695, 19.33597183], [72.79347229, 19.33596992], [72.79347229, 19.33653069], [72.79319763, 19.33653069], [72.79319763, 19.33680916], [72.79291534, 19.33680534], [72.79292297, 19.33736038], [72.79264069, 19.33736038], [72.79264069, 19.33764076], [72.7923584, 19.33764076], [72.7923584, 19.33791924], [72.79208374, 19.33791733], [72.79208374, 19.33819389], [72.79180908, 19.33819389], [72.79180908, 19.33847237], [72.79152679, 19.33847046], [72.79152679, 19.33875084], [72.79125214, 19.33875084], [72.79125214, 19.33932114], [72.79069519, 19.33930588], [72.79070282, 19.33986092], [72.7904129, 19.33986092], [72.7904129, 19.34042168], [72.79013824, 19.34041595], [72.79013824, 19.34069443], [72.78986359, 19.34069443], [72.78986359, 19.3409729], [72.7895813, 19.34096909], [72.7895813, 19.34153175], [72.78930664, 19.34153175], [72.78930664, 19.34181023], [72.78902435, 19.34180641], [72.78902435, 19.34208107], [72.78875732, 19.34207153], [72.78875732, 19.34263992], [72.78848267, 19.34263992], [72.78848267, 19.3429203], [72.78791809, 19.3429203], [72.78791809, 19.34320068], [72.7876358, 19.34319305], [72.7876358, 19.34347153], [72.78708649, 19.34346962], [72.78708649, 19.34403038], [72.7868042, 19.34402847], [72.7868042, 19.34458542], [72.78652954, 19.34458542], [72.78652954, 19.34486389], [72.78569031, 19.34486008], [72.78569031, 19.34542084], [72.78541565, 19.34541512], [72.78541565, 19.3456955], [72.78514099, 19.3456955], [72.78514099, 19.34597206], [72.7848587, 19.34597015], [72.7848587, 19.34625053], [72.78457642, 19.34625053], [72.78457642, 19.34653091], [72.78430939, 19.34653091], [72.78430176, 19.34680939], [72.7840271, 19.34680367], [72.7840271, 19.34708595], [72.78375244, 19.34708023], [72.78375244, 19.34736061], [72.78347015, 19.34736061], [72.78347015, 19.34819984], [72.7831955, 19.34819412], [72.7831955, 19.3484726], [72.78291321, 19.34847069], [72.78291321, 19.34902954], [72.78263092, 19.34902954], [72.78263092, 19.34930992], [72.7820816, 19.34930611], [72.7820816, 19.34958267], [72.78180695, 19.34958076], [72.78180695, 19.34986115], [72.78151703, 19.34986115], [72.78151703, 19.35013962], [72.78125, 19.35013962], [72.78125, 19.35041809], [72.7804184, 19.35041618], [72.7804184, 19.35069466], [72.78013611, 19.35069466], [72.78013611, 19.35097313], [72.77986145, 19.35097122], [72.77986145, 19.35125923], [72.77791595, 19.35125923], [72.77791595, 19.35152817], [72.7776413, 19.35152817], [72.7776413, 19.35180473], [72.77735901, 19.35180473], [72.77735901, 19.35236168], [72.77707672, 19.35235977], [72.77707672, 19.35263824], [72.7765274, 19.35263824], [72.7765274, 19.35292244], [72.7756958, 19.35292244], [72.7756958, 19.35320282], [72.77540588, 19.35320282], [72.77540588, 19.35403252], [72.77513885, 19.3540287], [72.77513885, 19.35458374], [72.77485657, 19.35458183], [72.77485657, 19.35486031], [72.77458191, 19.35486031], [72.77458191, 19.35542107], [72.77430725, 19.35541725], [72.77430725, 19.35597229], [72.77401733, 19.35597038], [72.77401733, 19.35653114], [72.77375031, 19.35652733], [72.77375031, 19.35708237], [72.77347565, 19.35708237], [72.77348328, 19.35736084], [72.77319336, 19.35736084], [72.77319336, 19.35819244], [72.7729187, 19.35819054], [72.7729187, 19.35874939], [72.77263641, 19.35874939], [72.77263641, 19.35958481], [72.77236176, 19.35958099], [72.77236176, 19.36013985], [72.7720871, 19.36013985], [72.7720871, 19.3615303], [72.77179718, 19.3615303], [72.77179718, 19.36181068], [72.77153015, 19.36180687], [72.77153015, 19.36208344], [72.77124786, 19.36208344], [72.77124786, 19.36236191], [72.77097321, 19.36236], [72.77097321, 19.36264038], [72.77069092, 19.36264038], [72.77069092, 19.36292076], [72.77041626, 19.36292076], [72.77041626, 19.36320114], [72.7701416, 19.36319542], [72.7701416, 19.36347198], [72.76985931, 19.36346817], [72.76985931, 19.36375046], [72.76957703, 19.36375046], [72.76957703, 19.36430931], [72.76930237, 19.3643055], [72.76930237, 19.36458397], [72.76902771, 19.36457825], [72.76902771, 19.36486053], [72.76875305, 19.36486053], [72.76875305, 19.36514091], [72.76847076, 19.36514091], [72.76847076, 19.36541939], [72.76819611, 19.36541748], [72.76819611, 19.36597252], [72.76764679, 19.36597061], [72.76764679, 19.36626053], [72.76735687, 19.36626053], [72.76735687, 19.36652946], [72.76680756, 19.36652946], [72.76680756, 19.36681175], [72.76652527, 19.36680603], [72.7665329, 19.36735916], [72.76625061, 19.36735916], [72.76625061, 19.36763954], [72.76568604, 19.36763954], [72.76568604, 19.36792183], [72.76541901, 19.36791611], [72.76541901, 19.36819458], [72.76513672, 19.36819458], [72.76513672, 19.36847115], [72.76486206, 19.36847115], [72.76486206, 19.36874962], [72.7645874, 19.36874962], [72.7645874, 19.36903191], [72.76403046, 19.36902809], [72.76403046, 19.36930466], [72.76374817, 19.36930466], [72.76374817, 19.36958122], [72.76319122, 19.36958122], [72.76319122, 19.3698616], [72.76291656, 19.3698597], [72.76291656, 19.37014008], [72.76264191, 19.37014008], [72.76264191, 19.37042046], [72.76235962, 19.37042046], [72.76235962, 19.37070084], [72.76208496, 19.37069321], [72.76208496, 19.37097168], [72.76152039, 19.37096977], [72.76152039, 19.37125015], [72.76125336, 19.37125015], [72.76125336, 19.37181091], [72.76097107, 19.37180328], [72.76097107, 19.37208557], [72.76069641, 19.37207985], [72.76069641, 19.37236023], [72.76013947, 19.37236023], [72.76013947, 19.37264061], [72.75986481, 19.3726387], [72.75986481, 19.37319565], [72.75958252, 19.37319565], [72.75958252, 19.37347221], [72.7590332, 19.37347031], [72.7590332, 19.37403107], [72.75875092, 19.37403107], [72.75875092, 19.37430954], [72.758461, 19.37430954], [72.758461, 19.37486076], [72.75818634, 19.37486076], [72.75818634, 19.37542915], [72.75791931, 19.37541771], [72.75791931, 19.37597275], [72.75763702, 19.37597275], [72.75763702, 19.37819481], [72.75736237, 19.37819481], [72.75736237, 19.37958336], [72.75763702, 19.37957764], [72.75763702, 19.3801403], [72.75791931, 19.3801384], [72.75791931, 19.38125038], [72.75818634, 19.38124084], [72.75818634, 19.38264275], [72.758461, 19.38264275], [72.758461, 19.38402939], [72.75875092, 19.38402748], [72.75875092, 19.38430405], [72.75902557, 19.38430405], [72.75902557, 19.38513947], [72.75930786, 19.38513947], [72.75930786, 19.38569641], [72.75958252, 19.38569641], [72.75958252, 19.38597488], [72.75985718, 19.38597107], [72.75985718, 19.38652992], [72.76013947, 19.38652992], [72.76013947, 19.38764], [72.76040649, 19.38764], [72.76040649, 19.38820076], [72.76069641, 19.38820076], [72.76069641, 19.38903046], [72.76097107, 19.38903046], [72.76097107, 19.38931084], [72.76125336, 19.38930511], [72.76125336, 19.38958359], [72.76152039, 19.38957977], [72.76152039, 19.39042854], [72.76180267, 19.3904171], [72.76180267, 19.39069366], [72.76208496, 19.39069366], [72.76208496, 19.39097214], [72.76235962, 19.39097023], [72.76235962, 19.39152908], [72.76568604, 19.39152908], [72.76568604, 19.39181137], [72.76597595, 19.39180565], [72.76597595, 19.3931942], [72.76569366, 19.3931942], [72.76569366, 19.39347267], [72.76513672, 19.39347076], [72.76513672, 19.39374924], [72.7645874, 19.39374924], [72.7645874, 19.39402962], [72.76403046, 19.39402962], [72.76403046, 19.3943119], [72.76374817, 19.39430618], [72.76374817, 19.39458275], [72.76346588, 19.39458275], [72.76346588, 19.39486122], [72.76319122, 19.39486122], [72.76319122, 19.39513969], [72.76291656, 19.39513969], [72.76291656, 19.39542007], [72.76235962, 19.39541626], [72.76235962, 19.3959713], [72.76208496, 19.3959713], [72.76208496, 19.39624977], [72.76180267, 19.39624977], [72.76180267, 19.39847183], [72.76152039, 19.39846992], [72.76152039, 19.40014076], [72.76180267, 19.40014076], [72.76180267, 19.40291977], [72.76152802, 19.40291786], [72.76152802, 19.40541649], [72.76125336, 19.40541649], [72.76125336, 19.40708351], [72.76097107, 19.4070816], [72.76097107, 19.40792274], [72.76069641, 19.40792274], [72.76069641, 19.40903282], [72.76040649, 19.40903282], [72.76040649, 19.40986061], [72.76013947, 19.40986061], [72.76013947, 19.41041946], [72.76041412, 19.41041756], [72.76041412, 19.41486168], [72.76013947, 19.41486168], [72.76013947, 19.41597176], [72.75985718, 19.41596985], [72.75985718, 19.41653061], [72.75958252, 19.41653061], [72.75958252, 19.41791916], [72.75930786, 19.41791916], [72.75930786, 19.41875076], [72.75902557, 19.41875076], [72.75902557, 19.41958427], [72.75875092, 19.41958046], [72.75875092, 19.42124939], [72.75818634, 19.42124939], [72.75818634, 19.42292023], [72.75791931, 19.42292023], [72.75791931, 19.4240303], [72.75763702, 19.4240284], [72.75763702, 19.42486382], [72.75736237, 19.42486382], [72.75736237, 19.42597389], [72.75708008, 19.42597008], [72.75708008, 19.42681122], [72.75680542, 19.42680359], [72.75681305, 19.42736053], [72.75653076, 19.42736053], [72.75653076, 19.42819595], [72.75624847, 19.42819595], [72.75624847, 19.42847252], [72.75596619, 19.42847061], [72.75596619, 19.42930984], [72.75569153, 19.42930794], [72.75569153, 19.43180466], [72.75514221, 19.43180466], [72.75514221, 19.43208313], [72.75485992, 19.43208313], [72.75485992, 19.4323616], [72.7545929, 19.43235016], [72.7545929, 19.43320274], [72.75430298, 19.43320274], [72.75430298, 19.43403244], [72.75402832, 19.43403244], [72.75402832, 19.43486023], [72.75375366, 19.43486023], [72.75375366, 19.43597031], [72.75347137, 19.43597031], [72.75347137, 19.43625069], [72.75319672, 19.43625069], [72.75319672, 19.43680954], [72.7529068, 19.43680954], [72.75291443, 19.43736076], [72.7526474, 19.43736076], [72.7526474, 19.43848038], [72.75235748, 19.43848038], [72.75235748, 19.43931007], [72.75208282, 19.43931007], [72.75208282, 19.44042015], [72.75180817, 19.44042015], [72.75180817, 19.44124985], [72.75152588, 19.44124985], [72.75152588, 19.44180679], [72.75125122, 19.44180679], [72.75125122, 19.44208336], [72.75096893, 19.44207954], [72.75096893, 19.44292068], [72.75125122, 19.44292068], [72.75125122, 19.44319916], [72.75068665, 19.44319916], [72.75068665, 19.44375038], [72.75041962, 19.44375038], [72.75041962, 19.44458389], [72.75013733, 19.44457817], [72.75013733, 19.44541931], [72.74986267, 19.44541931], [72.74986267, 19.44625092], [72.74958038, 19.44625092], [72.74958038, 19.44681168], [72.74930573, 19.44680595], [72.74931335, 19.44763947], [72.74903107, 19.44763947], [72.74903107, 19.4481945], [72.74874878, 19.4481945], [72.74874878, 19.44986153], [72.74846649, 19.44985962], [72.74846649, 19.45042038], [72.74819183, 19.45042038], [72.74819183, 19.4507103], [72.74791718, 19.4507103], [72.74791718, 19.45125008], [72.74764252, 19.45125008], [72.74764252, 19.4515686], [72.74764252, 19.45236206], [72.74736023, 19.45236206], [72.74736023, 19.45319557], [72.7470932, 19.45318985], [72.7470932, 19.45403099], [72.74680328, 19.45403099], [72.74680328, 19.45430946], [72.74652863, 19.45430756], [72.74652863, 19.45458412], [72.74597168, 19.45458031], [72.74597168, 19.45486069], [72.74569702, 19.45486069], [72.74569702, 19.45541954], [72.74541473, 19.45541763], [72.74541473, 19.4556942], [72.74514008, 19.4556942], [72.74514008, 19.45708275], [72.74485779, 19.45708084], [72.74485779, 19.45874977], [72.74458313, 19.45874977], [72.74458313, 19.46210098], [72.74458313, 19.46292114], [72.74485779, 19.46291733], [72.74485779, 19.46347237], [72.74514008, 19.46347046], [72.74514008, 19.46403122], [72.7454071, 19.46403122], [72.7454071, 19.46430969], [72.74569702, 19.46430588], [72.74569702, 19.46458244], [72.74597168, 19.46458054], [72.74597168, 19.46486092], [72.74624634, 19.46486092], [72.74624634, 19.46513939], [72.746521, 19.46513939], [72.746521, 19.46541977], [72.74680328, 19.46541405], [72.74680328, 19.46569633], [72.74708557, 19.46569633], [72.74708557, 19.46597481], [72.74764252, 19.46597099], [72.74764252, 19.46624947], [72.74791718, 19.46624947], [72.74791718, 19.46652985], [72.74819183, 19.46652985], [72.74819183, 19.46681023], [72.74847412, 19.46680641], [72.74847412, 19.46708488], [72.74903107, 19.46708107], [72.74903107, 19.46763992], [72.74958038, 19.46763992], [72.74958038, 19.4679203], [72.74986267, 19.4679203], [72.74986267, 19.46820068], [72.75013733, 19.46819687], [72.75013733, 19.46847153], [72.75041962, 19.46846008], [72.75041962, 19.46903038], [72.75068665, 19.46903038], [72.75068665, 19.46931076], [72.75096893, 19.46930695], [72.75096893, 19.46986198], [72.75125122, 19.46986008], [72.75125122, 19.47014046], [72.75152588, 19.47013855], [72.75152588, 19.47069359], [72.75180817, 19.47068977], [72.75180817, 19.47125053], [72.75235748, 19.47125053], [72.75235748, 19.47153091], [72.7526474, 19.47153091], [72.7526474, 19.47180939], [72.75291443, 19.47180557], [72.75291443, 19.47208405], [72.75319672, 19.47207832], [72.75319672, 19.47236061], [72.75347137, 19.47236061], [72.75347137, 19.47263908], [72.75375366, 19.47263908], [72.75375366, 19.47319412], [72.75402832, 19.47319412], [72.75402832, 19.4734726], [72.75430298, 19.47347069], [72.75430298, 19.47374916], [72.7545929, 19.47374916], [72.7545929, 19.47431183], [72.75541687, 19.47431183], [72.75541687, 19.4745903], [72.75596619, 19.4745903], [72.75596619, 19.47513962], [72.75653076, 19.47513962], [72.75653076, 19.47542191], [72.75736237, 19.47541618], [72.75736237, 19.47569466], [72.75986481, 19.47569466], [72.75986481, 19.47597122], [72.75995636, 19.47597122], [72.76069641, 19.47597122], [72.76069641, 19.47624969], [72.76125336, 19.47624969], [72.76125336, 19.47653008], [72.76208496, 19.47652817], [72.76208496, 19.47680473], [72.76291656, 19.47680473], [72.76291656, 19.47652817], [72.76346588, 19.47653008], [72.76346588, 19.47624969], [72.76431274, 19.47624969], [72.76431274, 19.47653008], [72.76457977, 19.47652817], [72.76457977, 19.47680473], [72.76486206, 19.47680473], [72.76486206, 19.47736168], [72.76541901, 19.47735977], [72.76541901, 19.47820091], [72.76568604, 19.47820091], [72.76568604, 19.47875023], [72.76597595, 19.47875023], [72.76597595, 19.47931099], [72.76625061, 19.47931099], [72.76625061, 19.47986031], [72.7665329, 19.47986031], [72.7665329, 19.48042107], [72.76680756, 19.48041725], [72.76680756, 19.48097229], [72.76708221, 19.48097038], [72.76708221, 19.48153114], [72.76735687, 19.48153114], [72.76735687, 19.48236084], [72.76708221, 19.48236084], [72.76708221, 19.48347282], [72.76735687, 19.48347092], [72.76735687, 19.48402977], [72.76790619, 19.48402977], [72.76790619, 19.48430824], [72.76819611, 19.48430634], [72.76819611, 19.4845829], [72.76847076, 19.4845829], [72.76847076, 19.48486137], [72.76875305, 19.48485947], [72.76875305, 19.48513985], [72.76930237, 19.48513985], [72.76930237, 19.48541832], [72.76958466, 19.48541641], [72.76958466, 19.48597145], [72.76985931, 19.48596764], [72.76985931, 19.48624992], [72.7701416, 19.48624992], [72.7701416, 19.4865303], [72.77097321, 19.4865303], [72.77097321, 19.48682022], [72.77236176, 19.48682022], [72.77236176, 19.48596764], [72.77263641, 19.48597145], [72.77263641, 19.48541641], [72.7729187, 19.48541832], [72.7729187, 19.48513985], [72.77319336, 19.48513985], [72.77319336, 19.48374939], [72.77348328, 19.48374939], [72.77348328, 19.48402977], [72.77403259, 19.48402977], [72.77403259, 19.48430824], [72.77430725, 19.48430634], [72.77430725, 19.4845829], [72.77458191, 19.4845829], [72.77458191, 19.48486137], [72.77485657, 19.48485947], [72.77485657, 19.48541832], [72.77513885, 19.48541641], [72.77513885, 19.48597145], [72.7748642, 19.48597145], [72.77485657, 19.4881916], [72.77458191, 19.48820114], [72.77458191, 19.48903275], [72.77485657, 19.48903275], [72.77485657, 19.48986053], [72.77513885, 19.48986053], [72.77513885, 19.49014282], [72.77540588, 19.49014282], [72.77540588, 19.49041939], [72.7756958, 19.49041748], [72.7756958, 19.49069214], [72.77625275, 19.49069214], [72.77625275, 19.49097252], [72.7765274, 19.49097061], [72.7765274, 19.4912529], [72.77819824, 19.4912529], [72.77819824, 19.49152946], [72.77874756, 19.49152946], [72.77874756, 19.4912529], [72.78013611, 19.4912529], [72.78013611, 19.49152946], [72.77986145, 19.49152756], [72.77986145, 19.49597168], [72.77958679, 19.49596977], [72.77958679, 19.50542068], [72.77986145, 19.50541687], [72.77986145, 19.50597191], [72.77958679, 19.50597], [72.77958679, 19.50653076], [72.77929688, 19.50653076], [72.77929688, 19.50681114], [72.77902985, 19.50681114], [72.77902985, 19.50736046], [72.77874756, 19.50736046], [72.77874756, 19.50875092], [72.77929688, 19.50875092], [72.77929688, 19.50930977], [72.77958679, 19.50930786], [72.77958679, 19.50958252], [72.78013611, 19.50958061], [72.78013611, 19.50986099], [72.7804184, 19.50986099], [72.7804184, 19.51013947], [72.78069305, 19.51013947], [72.78069305, 19.51041985], [72.78097534, 19.51041794], [72.78097534, 19.51097298], [72.78125, 19.51097107], [72.78125, 19.51124954], [72.78151703, 19.51124954], [72.78151703, 19.51152992], [72.7820816, 19.51152992], [72.7820816, 19.51180077], [72.78236389, 19.51180649], [72.78236389, 19.51236153], [72.78291321, 19.51235962], [72.78291321, 19.51263809], [72.78320313, 19.51263809], [72.78320313, 19.51291847], [72.78347015, 19.51291847], [72.78347015, 19.51320267], [72.78375244, 19.51320267], [72.78375244, 19.51403046], [72.7840271, 19.51402855], [72.7840271, 19.51458359], [72.78430176, 19.51458168], [72.78430939, 19.51514053], [72.78458405, 19.51513863], [72.78458405, 19.51597023], [72.7848587, 19.51597023], [72.7848587, 19.5165329], [72.78514099, 19.5165329], [72.78514099, 19.51736069], [72.78541565, 19.51736069], [72.78541565, 19.51819229], [72.78569031, 19.51819038], [72.78569031, 19.51875114], [72.78542328, 19.51875114], [72.78542328, 19.51931], [72.78569031, 19.51931], [72.78569031, 19.52042007], [72.7859726, 19.52042007], [72.7859726, 19.52124977], [72.78652954, 19.52124977], [72.78652954, 19.52430916], [72.78624725, 19.52430534], [72.78624725, 19.52597237], [72.7859726, 19.52597046], [72.7859726, 19.5268116], [72.78569031, 19.5268116], [72.78569794, 19.52736092], [72.78542328, 19.52736092], [72.78542328, 19.52792168], [72.7848587, 19.52791595], [72.7848587, 19.52819443], [72.78375244, 19.52819443], [72.78375244, 19.5284729], [72.7831955, 19.5284729], [72.7831955, 19.52874947], [72.77874756, 19.52874947], [72.77874756, 19.5284729], [72.7784729, 19.5284729], [72.7784729, 19.52819443], [72.77791595, 19.52819443], [72.77791595, 19.52791595], [72.77735901, 19.52792168], [72.77735901, 19.52763939], [72.77680206, 19.52763939], [72.77680206, 19.52736092], [72.7765274, 19.52736092], [72.7765274, 19.52708054], [72.77625275, 19.52708244], [72.77625275, 19.52680588], [72.7756958, 19.5268116], [72.7756958, 19.52652931], [72.77540588, 19.52652931], [72.77540588, 19.52597046], [72.7765274, 19.52597046], [72.7765274, 19.52625084], [72.77707672, 19.52625084], [72.77707672, 19.52652931], [72.7776413, 19.52652931], [72.7776413, 19.5268116], [72.77791595, 19.52680588], [72.77791595, 19.52708244], [72.77874756, 19.52708054], [72.77874756, 19.52736092], [72.77986145, 19.52736092], [72.77986145, 19.52763939], [72.78013611, 19.52763939], [72.78013611, 19.52736092], [72.78125, 19.52736092], [72.78125, 19.52708054], [72.7820816, 19.52708244], [72.7820816, 19.5265274], [72.78235626, 19.52652931], [72.78235626, 19.52625084], [72.78291321, 19.52625084], [72.78291321, 19.52597046], [72.78347015, 19.52597237], [72.78347015, 19.52569389], [72.7840271, 19.52570152], [72.7840271, 19.52235985], [72.78375244, 19.52236176], [72.78375244, 19.52124977], [72.78347015, 19.52124977], [72.78347015, 19.51625061], [72.7831955, 19.51625061], [72.7831955, 19.51569366], [72.78291321, 19.51569366], [72.78291321, 19.5154171], [72.78263092, 19.51542282], [72.78263092, 19.51514053], [72.78235626, 19.51514053], [72.78235626, 19.51486015], [72.7820816, 19.51486015], [72.7820816, 19.51430511], [72.78180695, 19.51431274], [72.78180695, 19.51403046], [72.78151703, 19.51403046], [72.78151703, 19.51375961], [72.78125, 19.51375961], [72.78125, 19.51320267], [72.78069305, 19.51320267], [72.78069305, 19.51291847], [72.78013611, 19.51291847], [72.78013611, 19.51263809], [72.77986145, 19.51263809], [72.77986145, 19.51235962], [72.77958679, 19.51236153], [72.77958679, 19.51208305], [72.7793045, 19.51208305], [72.7793045, 19.51152992], [72.77902985, 19.51152992], [72.77902985, 19.51124954], [72.77874756, 19.51124954], [72.77874756, 19.51097107], [72.7784729, 19.51097298], [72.7784729, 19.5106945], [72.77819824, 19.51069832], [72.77819061, 19.51041985], [72.77791595, 19.51041985], [72.77791595, 19.50986099], [72.77735901, 19.50986099], [72.77735901, 19.50958061], [72.77680206, 19.50958252], [72.77680206, 19.50902557], [72.7765274, 19.50902939], [72.7765274, 19.50875092], [72.7756958, 19.50875092], [72.7756958, 19.50847054], [72.77541351, 19.50847244], [72.77541351, 19.50763893], [72.77513885, 19.50763893], [72.77513885, 19.5070858], [72.7748642, 19.5070858], [72.7748642, 19.50680351], [72.77458191, 19.50681114], [72.77458191, 19.50653076], [72.77403259, 19.50653076], [72.77403259, 19.50625038], [72.77375031, 19.50625038], [72.77375031, 19.50570107], [72.77348328, 19.50570107], [72.77348328, 19.50542068], [72.77319336, 19.50542068], [72.77319336, 19.5051403], [72.7729187, 19.5051403], [72.7729187, 19.50485992], [72.77263641, 19.50486374], [72.77263641, 19.50458336], [72.76958466, 19.50458336], [72.76958466, 19.50430489], [72.76486206, 19.50430489], [72.76486206, 19.50486374], [72.7645874, 19.50485992], [72.7645874, 19.5051403], [72.76319122, 19.5051403], [72.76319122, 19.50542068], [72.76264191, 19.50542068], [72.76264191, 19.50570107], [72.76235962, 19.50569344], [72.76235962, 19.50597191], [72.76152039, 19.50597], [72.76152039, 19.50625038], [72.76069641, 19.50625038], [72.76069641, 19.50653076], [72.75985718, 19.50653076], [72.75985718, 19.50681114], [72.75875092, 19.50680351], [72.75875092, 19.5070858], [72.75818634, 19.50708008], [72.75819397, 19.50736046], [72.75680542, 19.50736046], [72.75680542, 19.5070858], [72.75653076, 19.50708008], [72.75653076, 19.50736046], [72.75569153, 19.50736046], [72.75569153, 19.50763893], [72.75541687, 19.50763893], [72.75541687, 19.50819588], [72.75514221, 19.50819588], [72.75514221, 19.50847244], [72.75458527, 19.50847244], [72.7545929, 19.50875092], [72.7529068, 19.50875092], [72.7529068, 19.50902939], [72.7526474, 19.50902939], [72.7526474, 19.50930977], [72.75235748, 19.50930786], [72.75235748, 19.50958252], [72.75208282, 19.50958061], [72.75208282, 19.50986099], [72.75180817, 19.50986099], [72.75180817, 19.51013947], [72.75125122, 19.51013947], [72.75125122, 19.51041985], [72.75041962, 19.51041985], [72.75041962, 19.51069832], [72.75013733, 19.5106945], [72.75013733, 19.51097298], [72.74986267, 19.51097107], [72.74986267, 19.51124954], [72.74903107, 19.51124954], [72.74903107, 19.51152992], [72.74819183, 19.51152992], [72.74819183, 19.5118084], [72.74764252, 19.51180649], [72.74764252, 19.51236153], [72.74736023, 19.51235962], [72.74736023, 19.51263809], [72.74680328, 19.51263809], [72.74680328, 19.51291847], [72.746521, 19.51291847], [72.746521, 19.51320267], [72.74597168, 19.51320267], [72.74597168, 19.51375961], [72.74569702, 19.51375961], [72.74569702, 19.51403046], [72.74485779, 19.51403046], [72.74485779, 19.51431274], [72.74458313, 19.51430511], [72.74458313, 19.51458359], [72.74402618, 19.51458359], [72.74402618, 19.51486015], [72.74347687, 19.51486015], [72.74347687, 19.51514053], [72.74291992, 19.51514053], [72.74291992, 19.51542282], [72.74236298, 19.5154171], [72.74236298, 19.51569366], [72.74180603, 19.51569366], [72.74180603, 19.51597023], [72.74153137, 19.51597023], [72.74153137, 19.5165329], [72.74124908, 19.51652718], [72.74124908, 19.51680565], [72.74097443, 19.51680565], [72.74097443, 19.51708221], [72.74069214, 19.51708031], [72.74066162, 19.51764107], [72.74041748, 19.51764107], [72.74041748, 19.51791954], [72.74013519, 19.51791763], [72.74013519, 19.51847458], [72.73986053, 19.51847076], [72.73986053, 19.51902962], [72.73929596, 19.51902962], [72.73929596, 19.51931], [72.73902893, 19.51931], [72.73902893, 19.51986122], [72.73874664, 19.51986122], [72.73874664, 19.52099037], [72.73874664, 19.52236176], [72.73847198, 19.52235985], [72.73847198, 19.52264023], [72.73819733, 19.52264023], [72.73819733, 19.52292824], [72.73735809, 19.5229187], [72.73735809, 19.52347183], [72.73707581, 19.52346992], [72.73707581, 19.52430916], [72.73680878, 19.52430916], [72.73680878, 19.52514076], [72.73652649, 19.52514076], [72.73652649, 19.52652931], [72.73486328, 19.52652931], [72.73486328, 19.5268116], [72.73313904, 19.52680588], [72.73291779, 19.5268116], [72.73291779, 19.52652931], [72.73153687, 19.52652931], [72.73153687, 19.5268116], [72.73124695, 19.5268116], [72.73124695, 19.52736092], [72.73097229, 19.52736092], [72.73097229, 19.52763939], [72.73014069, 19.52763939], [72.73014069, 19.52792168], [72.7298584, 19.52791595], [72.7298584, 19.5284729], [72.72958374, 19.5284729], [72.72958374, 19.52874947], [72.72902679, 19.52874947], [72.72902679, 19.52958107], [72.72875214, 19.52958107], [72.72875214, 19.53180313], [72.72846985, 19.53180313], [72.72846985, 19.53236389], [72.72820282, 19.53236008], [72.72820282, 19.53264046], [72.72763824, 19.53264046], [72.72763824, 19.53292084], [72.72736359, 19.53291512], [72.72736359, 19.53347206], [72.7270813, 19.53347015], [72.7270813, 19.53375053], [72.72680664, 19.53375053], [72.72680664, 19.53403091], [72.72651672, 19.53403091], [72.72651672, 19.53375053], [72.72624969, 19.53375053], [72.72624969, 19.53264046], [72.72598267, 19.53264046], [72.72598267, 19.5320797], [72.72569275, 19.53208542], [72.72569275, 19.53180313], [72.72458649, 19.53180313], [72.72458649, 19.53236389], [72.72486115, 19.53236008], [72.72486115, 19.53292084], [72.7251358, 19.53291512], [72.7251358, 19.53347206], [72.72569275, 19.53347015], [72.72569275, 19.53375053], [72.72598267, 19.53375053], [72.72598267, 19.53487015], [72.72624969, 19.53487015], [72.72624969, 19.53514099], [72.72651672, 19.53514099], [72.72651672, 19.53680992], [72.72624969, 19.53680611], [72.72624969, 19.53708267], [72.72597504, 19.53708267], [72.72598267, 19.53736115], [72.72541809, 19.53736115], [72.72541809, 19.53792953], [72.7251358, 19.53791618], [72.7251358, 19.53819466], [72.72486115, 19.53819084], [72.72486115, 19.53874969], [72.72458649, 19.53874969], [72.72458649, 19.53902817], [72.72402954, 19.53902817], [72.72402954, 19.53930473], [72.72291565, 19.53930473], [72.72291565, 19.53902817], [72.72235107, 19.53902817], [72.72235107, 19.53874969], [72.72180176, 19.53874969], [72.72180176, 19.53847122], [72.72125244, 19.53847122], [72.72125244, 19.53874969], [72.72070313, 19.53874969], [72.72070313, 19.53902817], [72.72013855, 19.53902817], [72.72013855, 19.53874969], [72.71985626, 19.53874969], [72.71985626, 19.53847122], [72.71901703, 19.53847122], [72.71901703, 19.53874969], [72.71819305, 19.53874969], [72.71819305, 19.54042244], [72.71848297, 19.54042244], [72.71848297, 19.54070282], [72.71875, 19.54069519], [72.71875, 19.54097176], [72.71901703, 19.54097176], [72.71901703, 19.54236031], [72.72013855, 19.54236031], [72.72013855, 19.54264069], [72.7206955, 19.54263878], [72.7206955, 19.54347229], [72.72041321, 19.54347229], [72.72041321, 19.54375076], [72.71930695, 19.54374123], [72.71930695, 19.54403114], [72.71708679, 19.54402733], [72.71708679, 19.54458237], [72.71679688, 19.54458046], [72.71679688, 19.54541969], [72.71848297, 19.54541969], [72.71848297, 19.54514122], [72.71875, 19.54514122], [72.71875, 19.54486084], [72.71930695, 19.54486084], [72.71930695, 19.54458046], [72.7195816, 19.54458237], [72.7195816, 19.5443058], [72.72013855, 19.54430962], [72.72013855, 19.54403114], [72.72125244, 19.54403114], [72.72125244, 19.54374123], [72.72180176, 19.54375076], [72.72180176, 19.54347229], [72.7223587, 19.54347229], [72.7223587, 19.54375076], [72.72264099, 19.54374123], [72.72264099, 19.54403114], [72.72292328, 19.54403114], [72.72292328, 19.54514122], [72.72180939, 19.54514122], [72.72180176, 19.54541969], [72.72125244, 19.54541588], [72.72125244, 19.54569244], [72.7206955, 19.54569244], [72.7206955, 19.54597473], [72.72041321, 19.54597092], [72.72041321, 19.54624939], [72.72013855, 19.54624939], [72.72013855, 19.54708481], [72.72041321, 19.54708099], [72.72041321, 19.54763985], [72.7215271, 19.54763985], [72.7215271, 19.54792023], [72.72180176, 19.54791451], [72.72180939, 19.54819679], [72.72208405, 19.54819679], [72.72208405, 19.55208397], [72.72180939, 19.55207825], [72.72180176, 19.55236053], [72.7215271, 19.55236053], [72.7215271, 19.55319405], [72.72180176, 19.55319405], [72.72180176, 19.55347252], [72.7215271, 19.55347061], [72.7215271, 19.55374908], [72.72180176, 19.55374908], [72.72180176, 19.55486107], [72.7215271, 19.55486107], [72.7215271, 19.55569458], [72.72125244, 19.55567932], [72.72125244, 19.55624962], [72.72097015, 19.55624962], [72.72097015, 19.55653191], [72.7206955, 19.55652809], [72.7206955, 19.5573616], [72.72041321, 19.5573597], [72.72041321, 19.55792046], [72.72013855, 19.55792046], [72.72013855, 19.55931091], [72.71985626, 19.55931091], [72.71985626, 19.55986023], [72.7195816, 19.55986023], [72.7195816, 19.56069374], [72.71985626, 19.56068993], [72.71985626, 19.56236076], [72.72013855, 19.56236076], [72.72013855, 19.56375122], [72.72041321, 19.56374931], [72.72041321, 19.5648613], [72.72070313, 19.56484985], [72.72070313, 19.56541824], [72.72097015, 19.56541824], [72.72097015, 19.56653023], [72.72013855, 19.56652832], [72.72013855, 19.56680489], [72.71985626, 19.56679916], [72.71985626, 19.5676403], [72.7195816, 19.5676384], [72.7195816, 19.56791687], [72.71902466, 19.56791687], [72.71902466, 19.56847191], [72.71875, 19.56847191], [72.71875, 19.56903267], [72.71848297, 19.56903267], [72.71848297, 19.56931114], [72.71819305, 19.56931114], [72.71819305, 19.56986046], [72.7179184, 19.56986046], [72.7179184, 19.57014275], [72.71763611, 19.57014275], [72.71763611, 19.57042122], [72.71736145, 19.5704174], [72.71736145, 19.57097244], [72.71708679, 19.57097054], [72.71708679, 19.57152939], [72.7168045, 19.57152748], [72.7168045, 19.57208252], [72.71652985, 19.57208252], [72.71653748, 19.57263947], [72.71624756, 19.57263947], [72.71624756, 19.57514], [72.7159729, 19.57514], [72.7159729, 19.57542038], [72.71624756, 19.57542038], [72.71624756, 19.57625008], [72.71652985, 19.57625008], [72.71652985, 19.57708359], [72.71679688, 19.57707977], [72.71679688, 19.57792091], [72.71708679, 19.57792091], [72.71708679, 19.57930946], [72.71736145, 19.57930565], [72.71736145, 19.57986069], [72.71763611, 19.57985115], [72.71763611, 19.5818119], [72.7179184, 19.5818119], [72.7179184, 19.58263969], [72.71763611, 19.58263969], [72.71763611, 19.58403015], [72.71736145, 19.58402824], [72.71736145, 19.58430481], [72.71708679, 19.58430481], [72.71708679, 19.58486176], [72.71679688, 19.58485985], [72.71679688, 19.58681107], [72.71652985, 19.58680344], [72.71652985, 19.5881958], [72.71569824, 19.58819008], [72.71569824, 19.59013939], [72.71541595, 19.59013939], [72.71541595, 19.59041977], [72.71485901, 19.59041786], [72.71485901, 19.59069443], [72.71430206, 19.59069443], [72.71430206, 19.5909729], [72.7140274, 19.59097099], [72.7140274, 19.59124947], [72.71347046, 19.59124947], [72.71347046, 19.59263992], [72.7131958, 19.59263992], [72.7131958, 19.5929184], [72.71290588, 19.5929184], [72.71290588, 19.59320259], [72.71263885, 19.59319496], [72.71263885, 19.59347153], [72.71235657, 19.59347153], [72.71235657, 19.59403038], [72.71263885, 19.59402847], [72.71263885, 19.59597015], [72.71347046, 19.59597015], [72.71347046, 19.59569359], [72.71458435, 19.59569359], [72.71458435, 19.59541702], [72.71541595, 19.59541702], [72.71541595, 19.59569359], [72.7159729, 19.59569359], [72.7159729, 19.59513855], [72.71848297, 19.59514046], [72.71848297, 19.59542274], [72.7195816, 19.59541702], [72.7195816, 19.59569359], [72.72013855, 19.59569359], [72.72013855, 19.59597015], [72.72041321, 19.59597015], [72.72041321, 19.59653282], [72.72097015, 19.59653282], [72.72097015, 19.59680939], [72.7215271, 19.59680557], [72.7215271, 19.59708214], [72.72235107, 19.59708023], [72.72235107, 19.59736061], [72.72319794, 19.59736061], [72.72319794, 19.59680939], [72.72374725, 19.59680939], [72.72374725, 19.59625053], [72.72402954, 19.59625053], [72.72402954, 19.59597015], [72.7243042, 19.59597015], [72.7243042, 19.59569359], [72.72458649, 19.59569359], [72.72458649, 19.59541702], [72.7251358, 19.59542274], [72.7251358, 19.59486008], [72.72569275, 19.59486008], [72.72569275, 19.59458351], [72.72763824, 19.59458351], [72.72763824, 19.59486008], [72.72847748, 19.59486008], [72.72847748, 19.59514046], [72.72875214, 19.59514046], [72.72875214, 19.59542274], [72.72902679, 19.59541702], [72.72902679, 19.59597015], [72.72930908, 19.59597015], [72.72930908, 19.59625053], [72.72958374, 19.59625053], [72.72958374, 19.59708214], [72.73014069, 19.59708023], [72.73014069, 19.59736061], [72.73041534, 19.59736061], [72.73041534, 19.5984726], [72.73097229, 19.59847069], [72.73097229, 19.59875107], [72.73285675, 19.59875107], [72.73291779, 19.59847069], [72.73347473, 19.5984726], [72.73347473, 19.59819221], [72.73374939, 19.59819221], [72.73374939, 19.59791756], [72.73401642, 19.59791946], [72.73401642, 19.5976429], [72.73430634, 19.5976429], [72.73430634, 19.59736061], [72.73735809, 19.59736061], [72.73735809, 19.5976429], [72.73792267, 19.5976429], [72.73792267, 19.59791946], [72.73680878, 19.59791756], [72.73680878, 19.5984726], [72.73652649, 19.59847069], [72.73652649, 19.59875107], [72.73568726, 19.59875107], [72.73568726, 19.59930992], [72.73542023, 19.59930992], [72.73542023, 19.59986115], [72.73458099, 19.59986115], [72.73458099, 19.60013962], [72.73430634, 19.60013962], [72.73430634, 19.60042], [72.73402405, 19.60041428], [72.73402405, 19.60069656], [72.73374939, 19.60069084], [72.73374939, 19.60098076], [72.7335968, 19.60097313], [72.73179626, 19.60098076], [72.73179626, 19.60042], [72.73097229, 19.60041428], [72.73097229, 19.60069656], [72.73069763, 19.60069084], [72.73069763, 19.60098076], [72.73041534, 19.60097313], [72.73042297, 19.60124969], [72.73014069, 19.60124969], [72.73014069, 19.60264015], [72.7298584, 19.60263634], [72.7298584, 19.60569382], [72.73014069, 19.60569382], [72.73014069, 19.60541725], [72.73041534, 19.60541725], [72.73041534, 19.60569382], [72.73069763, 19.60569382], [72.73069763, 19.60847282], [72.73042297, 19.60847282], [72.73042297, 19.61014938], [72.73014069, 19.61014938], [72.73014069, 19.61124992], [72.7298584, 19.61124992], [72.7298584, 19.61292076], [72.72957611, 19.61292076], [72.72957611, 19.61375046], [72.72930908, 19.61375046], [72.72930908, 19.61514091], [72.72902679, 19.6151371], [72.72902679, 19.61569595], [72.72875214, 19.61569023], [72.72875214, 19.61625099], [72.72846985, 19.61624718], [72.72846985, 19.6170826], [72.72819519, 19.6170826], [72.72820282, 19.61763954], [72.7279129, 19.61763954], [72.7279129, 19.61791992], [72.72736359, 19.61791611], [72.72736359, 19.62097168], [72.72763824, 19.62097168], [72.72763824, 19.62125015], [72.7279129, 19.62125015], [72.7279129, 19.62177086], [72.7279129, 19.62208939], [72.72819519, 19.62208366], [72.72819519, 19.62347221], [72.7279129, 19.62347031], [72.7279129, 19.62486076], [72.72735596, 19.62486076], [72.72735596, 19.62541962], [72.7270813, 19.6254158], [72.7270813, 19.62569237], [72.72680664, 19.62569237], [72.72680664, 19.62597466], [72.72651672, 19.62597084], [72.72651672, 19.62681007], [72.72624969, 19.62680435], [72.72624969, 19.6273613], [72.72597504, 19.6273613], [72.72597504, 19.62847137], [72.72569275, 19.62846947], [72.72569275, 19.62874985], [72.7251358, 19.62874985], [72.7251358, 19.62846947], [72.72486115, 19.62847137], [72.72486115, 19.62763977], [72.7251358, 19.62763977], [72.7251358, 19.62708092], [72.72541809, 19.62708282], [72.72541809, 19.62652779], [72.72569275, 19.62652969], [72.72569275, 19.62597084], [72.72486115, 19.62597466], [72.72486115, 19.62569237], [72.72458649, 19.62569237], [72.72458649, 19.62597466], [72.7234726, 19.62597084], [72.7234726, 19.62625122], [72.72319794, 19.62625122], [72.72319794, 19.62652969], [72.72291565, 19.62652779], [72.72291565, 19.62708282], [72.72264099, 19.62708092], [72.72264099, 19.62763977], [72.72235107, 19.62763977], [72.72235107, 19.62792015], [72.72208405, 19.62791443], [72.72208405, 19.62819672], [72.72180939, 19.62819099], [72.72180176, 19.62874985], [72.7215271, 19.62874985], [72.7215271, 19.62930679], [72.72125244, 19.62930679], [72.72125244, 19.62958336], [72.72097015, 19.62958336], [72.72097015, 19.62986183], [72.72041321, 19.62985992], [72.72041321, 19.6301403], [72.72013855, 19.6301403], [72.72013855, 19.63042068], [72.71985626, 19.63042068], [72.71985626, 19.63125038], [72.7195816, 19.63125038], [72.7195816, 19.63180923], [72.71930695, 19.63180923], [72.71930695, 19.63236046], [72.71901703, 19.63236046], [72.71901703, 19.63264084], [72.71875, 19.63264084], [72.71875, 19.63347244], [72.71847534, 19.63347244], [72.71848297, 19.63375092], [72.71819305, 19.63375092], [72.71819305, 19.63458252], [72.7179184, 19.63458061], [72.7179184, 19.63542175], [72.71763611, 19.63541603], [72.71763611, 19.6356945], [72.71736145, 19.6356926], [72.71736145, 19.63624954], [72.71708679, 19.63624954], [72.71708679, 19.6368103], [72.71679688, 19.6368103], [72.71679688, 19.63709068], [72.71652985, 19.63708115], [72.71652985, 19.63736153], [72.71624756, 19.63735962], [72.71624756, 19.63764], [72.7159729, 19.63764], [72.7159729, 19.63820076], [72.71569824, 19.63819313], [72.71569824, 19.6384716], [72.71541595, 19.6384697], [72.71541595, 19.63903046], [72.7151413, 19.63903046], [72.7151413, 19.63931084], [72.71485901, 19.63930321], [72.71485901, 19.64013863], [72.71457672, 19.640131], [72.71457672, 19.64125061], [72.71430206, 19.64125061], [72.71430206, 19.64208412], [72.7140274, 19.64208412], [72.7140274, 19.6431942], [72.71375275, 19.64319038], [72.71375275, 19.64375114], [72.71347046, 19.64375114], [72.71347046, 19.64430809], [72.7131958, 19.64430618], [72.7131958, 19.64458275], [72.71290588, 19.64458084], [72.71290588, 19.64652824], [72.71263885, 19.64652824], [72.71263885, 19.64708328], [72.71235657, 19.64708138], [72.71235657, 19.64764023], [72.71208191, 19.64763832], [72.71208191, 19.64958382], [72.71180725, 19.64958191], [72.71180725, 19.65042114], [72.71153259, 19.65042114], [72.71153259, 19.65291977], [72.71125031, 19.65291405], [72.71125031, 19.65347481], [72.71097565, 19.65347481], [72.71097565, 19.65597153], [72.71069336, 19.65596962], [72.71069336, 19.65681076], [72.71098328, 19.65681076], [72.71098328, 19.65819931], [72.71069336, 19.65819359], [72.71069336, 19.65847206], [72.71097565, 19.65847206], [72.71097565, 19.65958405], [72.71125031, 19.65957832], [72.71125031, 19.66013908], [72.71097565, 19.66013908], [72.71097565, 19.66069412], [72.71069336, 19.6606884], [72.71069336, 19.66181183], [72.71097565, 19.66180611], [72.71097565, 19.66208267], [72.71125031, 19.66208267], [72.71125031, 19.66263962], [72.71098328, 19.66263962], [72.71098328, 19.66292191], [72.71069336, 19.66291618], [72.71069336, 19.66319466], [72.7104187, 19.66319466], [72.7104187, 19.66347122], [72.71069336, 19.66347122], [72.71069336, 19.66681099], [72.71097565, 19.66680336], [72.71098328, 19.66736031], [72.71069336, 19.66736031], [72.71069336, 19.66764069], [72.71013641, 19.66764069], [72.71013641, 19.66792107], [72.70986176, 19.66791534], [72.70986176, 19.66819382], [72.7095871, 19.66819], [72.7095871, 19.66903114], [72.70929718, 19.66903114], [72.70929718, 19.66986084], [72.70903015, 19.66986084], [72.70903015, 19.67041969], [72.70874786, 19.67045021], [72.70874786, 19.67152977], [72.70847321, 19.67152977], [72.70847321, 19.67180824], [72.70819092, 19.67180634], [72.70819092, 19.6720829], [72.7076416, 19.6720829], [72.7076416, 19.67236137], [72.70735168, 19.67235756], [72.70735168, 19.67375183], [72.70707703, 19.67375183], [72.70707703, 19.67902946], [72.70680237, 19.67902756], [72.70680237, 19.68097305], [72.70652771, 19.68097305], [72.70652771, 19.6823616], [72.70625305, 19.6823597], [72.70625305, 19.68292046], [72.70652771, 19.68291855], [72.70652771, 19.68458366], [72.70680237, 19.68457985], [72.70680237, 19.68625069], [72.70707703, 19.68625069], [72.70707703, 19.68680954], [72.70735931, 19.68680573], [72.70735931, 19.6870842], [72.70791626, 19.68707848], [72.70791626, 19.68736076], [72.70819092, 19.68736076], [72.70819092, 19.68819427], [72.70847321, 19.68818092], [72.70847321, 19.68902969], [72.70874786, 19.68902779], [72.70874786, 19.68958282], [72.70903015, 19.68958282], [72.70903015, 19.69013977], [72.70930481, 19.69013977], [72.70930481, 19.69069481], [72.7095871, 19.69069481], [72.7095871, 19.69124985], [72.70986176, 19.69124031], [72.70986176, 19.6926403], [72.71013641, 19.6926384], [72.71013641, 19.69430733], [72.7104187, 19.69430733], [72.7104187, 19.69847298], [72.71069336, 19.69847298], [72.71069336, 19.70208359], [72.71041107, 19.70208168], [72.71041107, 19.70375061], [72.71013641, 19.70375061], [72.71013641, 19.70514107], [72.70986176, 19.70514107], [72.70986176, 19.70681], [72.7095871, 19.70681], [72.7095871, 19.70763969], [72.70930481, 19.70763969], [72.70930481, 19.70819664], [72.70903015, 19.70819092], [72.70903015, 19.70874977], [72.70874786, 19.70874977], [72.70874786, 19.70931053], [72.70847321, 19.70930672], [72.70847321, 19.70986176], [72.70819092, 19.70985985], [72.70819092, 19.71042061], [72.70791626, 19.7104187], [72.70791626, 19.71097183], [72.7076416, 19.71096992], [72.7076416, 19.71153069], [72.70735931, 19.71152878], [72.70735931, 19.71208382], [72.70707703, 19.71207809], [72.70707703, 19.71237183], [72.70680237, 19.71237183], [72.70680237, 19.71291924], [72.70652771, 19.71291733], [72.70652771, 19.71319389], [72.70625305, 19.71319389], [72.70625305, 19.71347237], [72.70597076, 19.71347046], [72.70597076, 19.71402931], [72.70569611, 19.71402931], [72.70569611, 19.7143116], [72.70541382, 19.71430588], [72.70541382, 19.71458244], [72.70513916, 19.71457863], [72.70513916, 19.71513939], [72.7048645, 19.71513939], [72.7048645, 19.71541595], [72.70458221, 19.71541595], [72.70458221, 19.71569443], [72.70430756, 19.71569443], [72.70430756, 19.71624947], [72.7040329, 19.71624947], [72.7040329, 19.71652985], [72.70375061, 19.71652794], [72.70375061, 19.71708107], [72.70347595, 19.71708107], [72.70347595, 19.71736145], [72.70318604, 19.71735954], [72.70318604, 19.71763992], [72.70291901, 19.71763992], [72.70291901, 19.71820068], [72.70236206, 19.71819305], [72.70236206, 19.71847153], [72.70207977, 19.71846962], [72.70207977, 19.71875], [72.70181274, 19.71875], [72.70181274, 19.71903038], [72.70153046, 19.71903038], [72.70153046, 19.71931076], [72.70124817, 19.71930313], [72.70124817, 19.71958351], [72.70069122, 19.71958351], [72.70069122, 19.71986198], [72.70041656, 19.71986008], [72.70041656, 19.72042084], [72.70014191, 19.72041512], [72.70014191, 19.72097206], [72.69985962, 19.72097015], [72.69985962, 19.72125053], [72.69959259, 19.72125053], [72.69959259, 19.72180939], [72.69930267, 19.72180748], [72.69930267, 19.72208595], [72.69902802, 19.72208023], [72.69902802, 19.72236061], [72.69819641, 19.72236061], [72.69819641, 19.72291946], [72.69763947, 19.72291756], [72.69763947, 19.7234726], [72.69735718, 19.72347069], [72.69735718, 19.72375107], [72.69680786, 19.72375107], [72.69680786, 19.72402954], [72.6965332, 19.72402954], [72.6965332, 19.72430992], [72.69625092, 19.72430611], [72.69625092, 19.72458267], [72.69596863, 19.72458076], [72.69596863, 19.72513962], [72.69568634, 19.72513962], [72.69568634, 19.72541809], [72.69541931, 19.72541618], [72.69541931, 19.72597313], [72.69513702, 19.72597122], [72.69513702, 19.72624969], [72.69486237, 19.72624969], [72.69486237, 19.72652817], [72.69458008, 19.72652817], [72.69458008, 19.72680473], [72.69430542, 19.72680473], [72.69430542, 19.72708321], [72.69403076, 19.72708321], [72.69403076, 19.72736168], [72.69374847, 19.72734833], [72.69374847, 19.7293129], [72.69403076, 19.72930527], [72.69403076, 19.73041725], [72.69430542, 19.73041725], [72.69430542, 19.72986031], [72.69458008, 19.72986031], [72.69458008, 19.72958183], [72.69486237, 19.72958374], [72.69486237, 19.72930527], [72.69513702, 19.7293129], [72.69513702, 19.72875023], [72.69568634, 19.72875023], [72.69568634, 19.72847176], [72.69596863, 19.72847176], [72.69596863, 19.72791672], [72.69625092, 19.72792244], [72.69625092, 19.72764015], [72.6965332, 19.72764015], [72.6965332, 19.72734833], [72.69708252, 19.72736168], [72.69708252, 19.72708321], [72.69736481, 19.72708321], [72.69736481, 19.72652817], [72.69819641, 19.72652817], [72.69819641, 19.72680473], [72.69875336, 19.72680473], [72.69875336, 19.72624969], [72.70236206, 19.72624969], [72.70236206, 19.72652817], [72.70652771, 19.72652817], [72.70652771, 19.72624969], [72.70874786, 19.72624969], [72.70874786, 19.72792244], [72.70903015, 19.72792244], [72.70903015, 19.7293129], [72.70929718, 19.7293129], [72.70929718, 19.72986031], [72.7095871, 19.72986031], [72.7095871, 19.73041725], [72.70986176, 19.73041725], [72.70986176, 19.73069382], [72.7104187, 19.73069382], [72.7104187, 19.73097229], [72.71098328, 19.73097038], [72.71098328, 19.73153114], [72.71125031, 19.73152733], [72.71125031, 19.73208237], [72.71153259, 19.73208046], [72.71153259, 19.73264122], [72.71180725, 19.73264122], [72.71180725, 19.73374939], [72.71208191, 19.73374939], [72.71208191, 19.73764038], [72.71235657, 19.73764038], [72.71235657, 19.74181175], [72.71263885, 19.74181175], [72.71263885, 19.74292183], [72.71291351, 19.74291611], [72.71291351, 19.74430466], [72.7131958, 19.74430275], [72.7131958, 19.74625015], [72.71347046, 19.74625015], [72.71347046, 19.74792099], [72.71375275, 19.74792099], [72.71375275, 19.74875069], [72.7140274, 19.74875069], [72.7140274, 19.74930954], [72.71430206, 19.74930954], [72.71430206, 19.74986076], [72.71457672, 19.74986076], [72.71457672, 19.75041962], [72.71485901, 19.75041771], [72.71485901, 19.75097275], [72.71541595, 19.75097275], [72.71541595, 19.75152969], [72.7159729, 19.75152969], [72.7159729, 19.7523613], [72.71624756, 19.75235748], [72.71624756, 19.75263977], [72.71653748, 19.75263977], [72.71653748, 19.75291824], [72.7168045, 19.75291634], [72.7168045, 19.75347137], [72.71736145, 19.75346756], [72.71736145, 19.75375175], [72.7179184, 19.75375175], [72.7179184, 19.75403023], [72.71819305, 19.75402832], [72.71819305, 19.75430489], [72.71875, 19.75430489], [72.71875, 19.75458336], [72.71930695, 19.75458145], [72.71930695, 19.7551403], [72.71848297, 19.7551403], [72.71848297, 19.75542259], [72.71736145, 19.75542259], [72.71736145, 19.7551403], [72.71679688, 19.7551403], [72.71679688, 19.75486183], [72.71653748, 19.75486183], [72.71653748, 19.7551403], [72.7159729, 19.7551403], [72.7159729, 19.75486183], [72.71541595, 19.75486183], [72.71541595, 19.75458336], [72.7151413, 19.75458336], [72.7151413, 19.75402832], [72.71485901, 19.75403023], [72.71485901, 19.75346756], [72.71458435, 19.75347137], [72.71458435, 19.75291634], [72.71430206, 19.75291824], [72.71430206, 19.75263977], [72.7140274, 19.75263977], [72.7140274, 19.75208092], [72.71375275, 19.75208282], [72.71375275, 19.75124741], [72.71347046, 19.75125122], [72.71347046, 19.75069046], [72.7131958, 19.75069427], [72.7131958, 19.75041771], [72.71290588, 19.75041962], [72.71290588, 19.74986076], [72.71263885, 19.74986076], [72.71263885, 19.74903107], [72.71235657, 19.74903107], [72.71235657, 19.74818993], [72.71208191, 19.74819374], [72.71208191, 19.74791527], [72.71180725, 19.74792099], [72.71180725, 19.74764061], [72.71153259, 19.74764061], [72.71153259, 19.74681091], [72.71125031, 19.74681091], [72.71125031, 19.74625015], [72.71097565, 19.74625015], [72.71097565, 19.74402809], [72.71069336, 19.74403], [72.71069336, 19.74235153], [72.7104187, 19.74236107], [72.7104187, 19.74152756], [72.71013641, 19.74152946], [72.71013641, 19.74041939], [72.70986176, 19.74041939], [72.70986176, 19.73986053], [72.7095871, 19.73986053], [72.7095871, 19.73903084], [72.70929718, 19.73903084], [72.70929718, 19.73846817], [72.70903015, 19.73847198], [72.70903015, 19.73763657], [72.70874786, 19.73764038], [72.70874786, 19.73624992], [72.70847321, 19.73624992], [72.70847321, 19.73569107], [72.70819092, 19.73569679], [72.70819092, 19.73513985], [72.70791626, 19.73513985], [72.70791626, 19.73485947], [72.7076416, 19.73486137], [72.7076416, 19.73374939], [72.70735168, 19.73374939], [72.70735168, 19.73319054], [72.70708466, 19.73319435], [72.70708466, 19.73291588], [72.70680237, 19.73291969], [72.70680237, 19.73236084], [72.70458221, 19.73236084], [72.70458221, 19.73208046], [72.70069122, 19.73208046], [72.70069122, 19.73236084], [72.69985962, 19.73236084], [72.69985962, 19.73264122], [72.69902802, 19.73264122], [72.69902802, 19.73291969], [72.69847107, 19.73291588], [72.69847107, 19.73319435], [72.69708252, 19.73319054], [72.69708252, 19.73348045], [72.69680786, 19.73348045], [72.69680786, 19.73374939], [72.69625092, 19.73374939], [72.69625092, 19.73431015], [72.69596863, 19.73431015], [72.69596863, 19.73542023], [72.69569397, 19.73541451], [72.69569397, 19.73569679], [72.69346619, 19.73569107], [72.69346619, 19.73624992], [72.69319153, 19.73624992], [72.69319153, 19.73653984], [72.69291687, 19.7365284], [72.69291687, 19.7381897], [72.69236755, 19.73819923], [72.69236755, 19.73930931], [72.69208527, 19.7393055], [72.69208527, 19.73958397], [72.69152832, 19.73957825], [72.69152832, 19.73986053], [72.69125366, 19.73986053], [72.69125366, 19.74097252], [72.69097137, 19.74097061], [72.69097137, 19.74152946], [72.69069672, 19.74152756], [72.69069672, 19.74236107], [72.69041443, 19.74236107], [72.69041443, 19.74319458], [72.6901474, 19.74319267], [72.69013977, 19.74374962], [72.68985748, 19.74374962], [72.68985748, 19.7448616], [72.68958282, 19.7448616], [72.68958282, 19.74542046], [72.68958282, 19.74570084], [72.68930817, 19.74569321], [72.68930817, 19.74597168], [72.68902588, 19.74596977], [72.68902588, 19.74653053], [72.68875122, 19.74653053], [72.68875122, 19.74681091], [72.68846893, 19.74680328], [72.68846893, 19.74708366], [72.68818665, 19.74707985], [72.68818665, 19.74736023], [72.68763733, 19.74736023], [72.68763733, 19.74764061], [72.68736267, 19.74764061], [72.68736267, 19.74930954], [72.68708038, 19.74930954], [72.68708038, 19.75014114], [72.68680573, 19.75013924], [72.68680573, 19.75069427], [72.68653107, 19.75069046], [72.68653107, 19.75180817], [72.68624878, 19.75180626], [72.68624878, 19.7523613], [72.68596649, 19.75235748], [72.68596649, 19.75291824], [72.68624878, 19.75291634], [72.68624878, 19.75458336], [72.68596649, 19.75458145], [72.68596649, 19.75625038], [72.68569183, 19.75625038], [72.68569183, 19.75708389], [72.68541718, 19.75708008], [72.68541718, 19.76013947], [72.68569183, 19.76013947], [72.68569183, 19.76152992], [72.68597412, 19.76152611], [72.68597412, 19.76236153], [72.68624878, 19.76236153], [72.68624878, 19.76263618], [72.68641663, 19.76264], [72.68653107, 19.76264], [72.68653107, 19.76375008], [72.68681335, 19.76375008], [72.68681335, 19.76403046], [72.68708038, 19.76403046], [72.68708038, 19.76431084], [72.68736267, 19.76431084], [72.68736267, 19.76485825], [72.68763733, 19.76485825], [72.68763733, 19.76680946], [72.68791962, 19.76680946], [72.68791962, 19.76875114], [72.68819427, 19.76874924], [72.68819427, 19.77069473], [72.68846893, 19.77069283], [72.68846893, 19.77320099], [72.68818665, 19.77320099], [72.68818665, 19.77431107], [72.68791962, 19.77431107], [72.68791962, 19.77625084], [72.68763733, 19.77625084], [72.68763733, 19.77930832], [72.68736267, 19.77930641], [72.68736267, 19.77986145], [72.68708038, 19.77985764], [72.68708038, 19.78070259], [72.68736267, 19.78070259], [72.68736267, 19.78514099], [72.68763733, 19.78514099], [72.68763733, 19.78680992], [72.68791962, 19.78680992], [72.68791962, 19.78874969], [72.68819427, 19.78874969], [72.68819427, 19.78958321], [72.68846893, 19.78957939], [72.68846893, 19.79014015], [72.68875122, 19.79013634], [72.68875122, 19.79069519], [72.68902588, 19.79068947], [72.68902588, 19.79125023], [72.68930817, 19.79125023], [72.68930817, 19.79180908], [72.68958282, 19.79180527], [72.68958282, 19.79208374], [72.68985748, 19.79207993], [72.68985748, 19.79236031], [72.69013977, 19.79236031], [72.69013977, 19.79291916], [72.69041443, 19.79291725], [72.69041443, 19.79347229], [72.69069672, 19.79346848], [72.69069672, 19.79402924], [72.69097137, 19.79402924], [72.69097137, 19.79430962], [72.69124603, 19.79430962], [72.69124603, 19.79514122], [72.69097137, 19.79513931], [72.69097137, 19.79569435], [72.69069672, 19.79569244], [72.69069672, 19.79763985], [72.6904068, 19.79763985], [72.6904068, 19.79792023], [72.69013977, 19.79791641], [72.69013977, 19.79847145], [72.68985748, 19.79846954], [72.68985748, 19.79931068], [72.68958282, 19.79930305], [72.68958282, 19.8006897], [72.68930817, 19.80070114], [72.68930817, 19.80153084], [72.68958282, 19.80153084], [72.68958282, 19.80291939], [72.68985748, 19.80291557], [72.68985748, 19.80319595], [72.69013977, 19.80319023], [72.69013977, 19.80375099], [72.6904068, 19.80375099], [72.6904068, 19.80430984], [72.69169617, 19.80430794], [72.69208527, 19.80430794], [72.69208527, 19.8045826], [72.69319153, 19.8045826], [72.69319153, 19.80430794], [72.69374847, 19.80430984], [72.69374847, 19.80376053], [72.69386292, 19.80375671], [72.69403076, 19.80375099], [72.69403076, 19.80291939], [72.69513702, 19.80291557], [72.69513702, 19.80319595], [72.69569397, 19.80319595], [72.69568634, 19.80422974], [72.69568634, 19.80486107], [72.69513702, 19.80486107], [72.69513702, 19.80513954], [72.69403076, 19.80513954], [72.69403076, 19.80541992], [72.69347382, 19.80541611], [72.69347382, 19.80569458], [72.69097137, 19.80569458], [72.69097137, 19.80597305], [72.68943787, 19.80597305], [72.68902588, 19.80597305], [72.68902588, 19.80569458], [72.68846893, 19.80569458], [72.68846893, 19.80486107], [72.68818665, 19.80486107], [72.68818665, 19.80430984], [72.68791962, 19.80430984], [72.68791962, 19.80402946], [72.68763733, 19.80402946], [72.68763733, 19.80375099], [72.68736267, 19.80375099], [72.68736267, 19.80208015], [72.68763733, 19.80208588], [72.68763733, 19.80041695], [72.68791962, 19.80042076], [72.68791962, 19.79846954], [72.68819427, 19.79847145], [72.68819427, 19.79513931], [72.68846893, 19.79514122], [72.68846893, 19.79486084], [72.68818665, 19.79486084], [72.68818665, 19.79430962], [72.68708038, 19.79430962], [72.68708038, 19.79514122], [72.68680573, 19.79513931], [72.68680573, 19.79569435], [72.68653107, 19.79569435], [72.68653107, 19.79597282], [72.68624115, 19.79597282], [72.68624115, 19.79652977], [72.68596649, 19.79652977], [72.68596649, 19.79681969], [72.68624878, 19.79680634], [72.68624878, 19.7970829], [72.68597412, 19.7970829], [72.68597412, 19.79736137], [72.68569183, 19.79735947], [72.68569183, 19.7990303], [72.68541718, 19.7990303], [72.68541718, 19.79959106], [72.68514252, 19.79959106], [72.68514252, 19.80181122], [72.68486023, 19.80181122], [72.68486023, 19.80236053], [72.68458557, 19.80236053], [72.68458557, 19.8026371], [72.68430328, 19.8026371], [72.68430328, 19.80319595], [72.68402863, 19.80319023], [72.68402863, 19.80375099], [72.68374634, 19.80375099], [72.68374634, 19.80541992], [72.68347168, 19.80541611], [72.68347168, 19.80569458], [72.68319702, 19.80569458], [72.68319702, 19.80597305], [72.6829071, 19.80597115], [72.6829071, 19.80624962], [72.68264008, 19.80624962], [72.68264008, 19.80652809], [72.68235779, 19.80652809], [72.68235779, 19.80680466], [72.68208313, 19.80680466], [72.68208313, 19.80708313], [72.68180847, 19.80707932], [72.68180847, 19.80764008], [72.68152618, 19.80764008], [72.68152618, 19.80792046], [72.68125153, 19.80791664], [72.68125153, 19.80847168], [72.68152618, 19.80847168], [72.68152618, 19.80875969], [72.68125153, 19.80875969], [72.68125153, 19.80931282], [72.68096924, 19.80931282], [72.68096924, 19.81014061], [72.68069458, 19.8101387], [72.68069458, 19.81069374], [72.68042755, 19.81069183], [72.68042755, 19.81182098], [72.68013763, 19.81182098], [72.68013763, 19.81236076], [72.67986298, 19.81236076], [72.67986298, 19.81291962], [72.67958069, 19.8129158], [72.67958069, 19.81347275], [72.67903137, 19.81347084], [72.67903137, 19.81375122], [72.67874908, 19.81375122], [72.67874908, 19.81402969], [72.67791748, 19.81402779], [72.67791748, 19.81458282], [72.67763519, 19.81458282], [72.67763519, 19.8148613], [72.67708588, 19.81485939], [72.67708588, 19.81513977], [72.67680359, 19.81513977], [72.67680359, 19.81569672], [72.67652893, 19.81569672], [72.67652893, 19.81680679], [72.67624664, 19.81680679], [72.67624664, 19.81708336], [72.6756897, 19.81708336], [72.67541504, 19.81708336], [72.67541504, 19.81736183], [72.67514038, 19.81735992], [72.67514038, 19.81792068], [72.67485809, 19.81792068], [72.67485809, 19.81819916], [72.67402649, 19.81819534], [72.67402649, 19.81847191], [72.67292023, 19.81847191], [72.67292023, 19.81819534], [72.67263794, 19.81819916], [72.67263794, 19.81792068], [72.67069244, 19.81792068], [72.67069244, 19.81819916], [72.6701355, 19.81819534], [72.67014313, 19.81875038], [72.66902924, 19.81875038], [72.66902924, 19.81903076], [72.66874695, 19.81903076], [72.66874695, 19.81930923], [72.66847229, 19.81930542], [72.66847229, 19.81958389], [72.66819763, 19.81957817], [72.66819763, 19.81986046], [72.66764069, 19.81986046], [72.66764069, 19.82014084], [72.6673584, 19.82014084], [72.6673584, 19.82041931], [72.66707611, 19.82041931], [72.66707611, 19.8207016], [72.66652679, 19.82069397], [72.66652679, 19.82097244], [72.66625214, 19.82097054], [72.66625214, 19.82125092], [72.66570282, 19.82125092], [72.66570282, 19.82152939], [72.6654129, 19.82152939], [72.6654129, 19.82181168], [72.66430664, 19.82181168], [72.66430664, 19.82041931], [72.66401672, 19.82041931], [72.66374969, 19.82041931], [72.66374969, 19.81986046], [72.66347504, 19.81986046], [72.66347504, 19.81958389], [72.66179657, 19.81957817], [72.66179657, 19.81986046], [72.66208649, 19.81986046], [72.66208649, 19.82041931], [72.66152954, 19.82041931], [72.66152954, 19.8207016], [72.66124725, 19.82069397], [72.66124725, 19.82097244], [72.6598587, 19.82097244], [72.6598587, 19.82069397], [72.65958405, 19.82069397], [72.65958405, 19.82097244], [72.65930176, 19.82097054], [72.65930176, 19.82181168], [72.6590271, 19.82181168], [72.6590271, 19.8223629], [72.66014099, 19.8223629], [72.66014099, 19.82376099], [72.65957642, 19.82376099], [72.65957642, 19.82402992], [72.6590271, 19.82402802], [72.6590271, 19.82458115], [72.65763855, 19.82458115], [72.65763855, 19.82486153], [72.65735626, 19.82485962], [72.65735626, 19.82514], [72.65680695, 19.82514], [72.65680695, 19.82542038], [72.65651703, 19.82542038], [72.65651703, 19.82570076], [72.65625, 19.82569313], [72.65625, 19.82625008], [72.65598297, 19.82625008], [72.65598297, 19.82653046], [72.6554184, 19.82652855], [72.6554184, 19.82680321], [72.65513611, 19.82679939], [72.65513611, 19.82736015], [72.6554184, 19.82736015], [72.6554184, 19.82930946], [72.65513611, 19.82930756], [72.65513611, 19.82958412], [72.6534729, 19.82958412], [72.6534729, 19.83097267], [72.65319824, 19.83097076], [72.65319824, 19.83152962], [72.65291595, 19.83152962], [72.65291595, 19.83263969], [72.6526413, 19.83263969], [72.6526413, 19.83458328], [72.65235901, 19.83458138], [72.65235901, 19.83514023], [72.6526413, 19.83513832], [72.6526413, 19.83597183], [72.65235901, 19.83597183], [72.65235901, 19.83681107], [72.65208435, 19.83680534], [72.65208435, 19.83708382], [72.6515274, 19.83708191], [72.6515274, 19.83792114], [72.65125275, 19.83791733], [72.65125275, 19.83875084], [72.65097046, 19.83875084], [72.65097046, 19.83958244], [72.6506958, 19.83958054], [72.6506958, 19.83986092], [72.65125275, 19.83986092], [72.65125275, 19.84013939], [72.6515274, 19.84013939], [72.6515274, 19.84041977], [72.65180206, 19.84041405], [72.65180206, 19.84069443], [72.65207672, 19.84069061], [72.65207672, 19.84152985], [72.65180206, 19.84152794], [72.65180206, 19.8418045], [72.6515274, 19.8418045], [72.6515274, 19.84236145], [72.65208435, 19.84236145], [72.65208435, 19.84208298], [72.65319824, 19.84208298], [72.65319824, 19.84236145], [72.65458679, 19.84235954], [72.65458679, 19.84263992], [72.65486145, 19.84263992], [72.65486145, 19.84403038], [72.65458679, 19.84403038], [72.65458679, 19.84653091], [72.65429688, 19.84653091], [72.65429688, 19.84680939], [72.65402985, 19.84680939], [72.65402985, 19.84736061], [72.65374756, 19.84736061], [72.65374756, 19.84763908], [72.6534729, 19.84763908], [72.6534729, 19.85124969], [72.65319824, 19.85124969], [72.65319824, 19.85153008], [72.65291595, 19.85152817], [72.65291595, 19.85180473], [72.6526413, 19.85180473], [72.6526413, 19.85208321], [72.65235901, 19.85208321], [72.65235901, 19.85236168], [72.65207672, 19.85235977], [72.65207672, 19.85264015], [72.6515274, 19.85264015], [72.6515274, 19.85292053], [72.65125275, 19.85292053], [72.65125275, 19.85320091], [72.6506958, 19.85320091], [72.6506958, 19.85431099], [72.65097046, 19.85431099], [72.65097046, 19.85542107], [72.65125275, 19.85542107], [72.65125275, 19.85791969], [72.6515274, 19.85791779], [72.6515274, 19.85819435], [72.65180206, 19.85819435], [72.65180206, 19.85847282], [72.65319824, 19.85847092], [72.65319824, 19.85874748], [72.6534729, 19.85874748], [72.6534729, 19.85847092], [72.65374756, 19.85847092], [72.65374756, 19.85902977], [72.65458679, 19.85902977], [72.65458679, 19.85819054], [72.65486145, 19.85819435], [72.65486145, 19.85791779], [72.6554184, 19.85791969], [72.6554184, 19.85764122], [72.65598297, 19.85764122], [72.65598297, 19.85708046], [72.65652466, 19.85708237], [72.65652466, 19.85680771], [72.65664673, 19.85680771], [72.65680695, 19.85680962], [72.65680695, 19.85653114], [72.6570816, 19.85653114], [72.6570816, 19.85625076], [72.65735626, 19.85625076], [72.65735626, 19.85597038], [72.65791321, 19.85597229], [72.65791321, 19.85569382], [72.65875244, 19.85569382], [72.65875244, 19.85513878], [72.6590271, 19.85514069], [72.6590271, 19.85403061], [72.65930176, 19.85403061], [72.65930176, 19.85374069], [72.65958405, 19.85375023], [72.65958405, 19.85347176], [72.66041565, 19.85347176], [72.66041565, 19.85319328], [72.66069794, 19.85320091], [72.66069794, 19.85292053], [72.6609726, 19.85292053], [72.6609726, 19.85264015], [72.66152954, 19.85264015], [72.66152954, 19.85235977], [72.66208649, 19.85236168], [72.66208649, 19.85208321], [72.6626358, 19.85208321], [72.6626358, 19.85180473], [72.66291809, 19.85180473], [72.66291809, 19.85097122], [72.66402435, 19.85097122], [72.66402435, 19.85180473], [72.66625214, 19.85180473], [72.66625214, 19.85208321], [72.66652679, 19.85208321], [72.66652679, 19.85236168], [72.66680908, 19.85235977], [72.66680908, 19.85264015], [72.66707611, 19.85264015], [72.66707611, 19.85292053], [72.6673584, 19.85292053], [72.6673584, 19.85320091], [72.66874695, 19.85320091], [72.66874695, 19.85292053], [72.66902924, 19.85292053], [72.66902924, 19.85235977], [72.66930389, 19.85236168], [72.66930389, 19.85180473], [72.6701355, 19.85180473], [72.6701355, 19.85208321], [72.67069244, 19.85208321], [72.67069244, 19.85236168], [72.67180634, 19.85235977], [72.67180634, 19.85264015], [72.67263794, 19.85264015], [72.67263794, 19.85292053], [72.67318726, 19.85292053], [72.67318726, 19.85320091], [72.67346954, 19.85319328], [72.67346954, 19.85347176], [72.67375183, 19.85346985], [72.67375183, 19.85403061], [72.67346954, 19.85403061], [72.67346954, 19.85514069], [72.67319489, 19.85513878], [72.67319489, 19.85597229], [72.67346954, 19.85597038], [72.67346954, 19.85653114], [72.67375183, 19.85653114], [72.67375183, 19.85680962], [72.67402649, 19.85680962], [72.67402649, 19.85736084], [72.67430115, 19.85736084], [72.67430115, 19.85791969], [72.67457581, 19.85791969], [72.67457581, 19.85874748], [72.67485809, 19.85874748], [72.67485809, 19.85930824], [72.67541504, 19.85930634], [72.67541504, 19.8595829], [72.67569733, 19.85957909], [72.67569733, 19.85987091], [72.67597198, 19.85987091], [72.67597198, 19.86013985], [72.67624664, 19.86013985], [72.67624664, 19.86042023], [72.67652893, 19.86041641], [72.67652893, 19.86097145], [72.67679596, 19.86097145], [72.67679596, 19.8615303], [72.67708588, 19.8615284], [72.67708588, 19.86208344], [72.6772995, 19.86208344], [72.67763519, 19.86208344], [72.67763519, 19.86236191], [72.67791748, 19.86236191], [72.67791748, 19.86291695], [72.67847443, 19.86291695], [72.67847443, 19.86319351], [72.67903137, 19.86319351], [72.67903137, 19.86347389], [72.67930603, 19.86347008], [72.67930603, 19.86375046], [72.67958069, 19.86375046], [72.67958069, 19.86403275], [72.68013763, 19.86403275], [72.68013763, 19.86431122], [72.68041992, 19.8643055], [72.68041992, 19.86458206], [72.68070221, 19.86457253], [72.68068695, 19.86486053], [72.68093872, 19.86486053], [72.68096924, 19.86514091], [72.68112183, 19.86513901], [72.68125153, 19.86513901], [72.68125153, 19.86533165], [72.68125153, 19.86541748], [72.68096924, 19.86541748], [72.68096924, 19.86569214], [72.68069458, 19.86569214], [72.68069458, 19.86597252], [72.68096924, 19.86597061], [72.68096924, 19.86625099], [72.68068695, 19.86625099], [72.68069458, 19.86736107], [72.68041992, 19.86736107], [72.68041992, 19.86847305], [72.68013763, 19.86847305], [72.68013763, 19.8698616], [72.68041992, 19.8698616], [72.68041992, 19.87235832], [72.68069458, 19.87235832], [72.68069458, 19.87486076], [72.68096924, 19.87486076], [72.68096924, 19.87597275], [72.68125153, 19.87597275], [72.68125153, 19.87652969], [72.68152618, 19.87652969], [72.68152618, 19.87763977], [72.68180847, 19.87763977], [72.68180847, 19.8801403], [72.68208313, 19.8801403], [72.68208313, 19.88070107], [72.68235779, 19.88070107], [72.68235779, 19.88292122], [72.68264008, 19.8829155], [72.68264008, 19.88736153], [72.68291473, 19.88736153], [72.68291473, 19.8884716], [72.68264008, 19.8884716], [72.68264008, 19.88903046], [72.68235779, 19.88902855], [72.68235779, 19.88958359], [72.68264008, 19.88958359], [72.68264008, 19.89073753], [72.68264008, 19.89125061], [72.68235779, 19.89125061], [72.68235016, 19.89141083], [72.68234253, 19.8915329], [72.68208313, 19.8915329], [72.68208313, 19.89180946], [72.68152618, 19.89180946], [72.68152618, 19.89236069], [72.68125153, 19.89236069], [72.68125153, 19.8931942], [72.68096924, 19.89319038], [72.68096924, 19.89486122], [72.68068695, 19.89486122], [72.68068695, 19.89542007], [72.68041992, 19.89541435], [72.68041992, 19.89641953], [72.68042755, 19.89764023], [72.68069458, 19.89763641], [72.68069458, 19.90069389], [72.68041992, 19.90069389], [72.68041992, 19.90097237], [72.67986298, 19.90096855], [72.67986298, 19.90125084], [72.67903137, 19.90125084], [72.67903137, 19.90152931], [72.67819214, 19.90152931], [72.67819214, 19.90180969], [72.67791748, 19.90180588], [72.67791748, 19.90208244], [72.67763519, 19.90208244], [72.67763519, 19.90263939], [72.67736816, 19.90263939], [72.67736816, 19.90291977], [72.67708588, 19.90291595], [72.67708588, 19.90319443], [72.67652893, 19.90319252], [72.67652893, 19.90402985], [72.67624664, 19.90402794], [72.67624664, 19.90458107], [72.67597198, 19.90458107], [72.67597198, 19.90486145], [72.67569733, 19.90486145], [72.67569733, 19.90736198], [72.67542267, 19.90736008], [72.67542267, 19.90792084], [72.67569733, 19.90791512], [72.67569733, 19.90847206], [72.67597198, 19.90847015], [72.67597198, 19.90903091], [72.67652893, 19.90902519], [72.67652893, 19.90958595], [72.676651, 19.90958214], [72.67679596, 19.90958023], [72.67679596, 19.91041946], [72.67708588, 19.91041946], [72.67708588, 19.91236115], [72.67736816, 19.91236115], [72.67736816, 19.91291809], [72.67763519, 19.91291618], [72.67763519, 19.91374969], [72.67791748, 19.91374969], [72.67791748, 19.91486168], [72.67763519, 19.91486168], [72.67763519, 19.91625023], [72.67736816, 19.91625023], [72.67736816, 19.91653061], [72.67708588, 19.91653061], [72.67708588, 19.91930962], [72.67680359, 19.9193058], [72.67680359, 19.91958237], [72.67652893, 19.91958046], [72.67652893, 19.91986084], [72.67624664, 19.91986084], [72.67624664, 19.92041969], [72.67597198, 19.92041588], [72.67597198, 19.92069435], [72.67541504, 19.92069435], [72.67541504, 19.92097282], [72.67514038, 19.92097092], [72.67514038, 19.92124939], [72.67485809, 19.92124939], [72.67485809, 19.92181015], [72.67458344, 19.92180443], [72.67458344, 19.92236137], [72.67430115, 19.92235947], [72.67430115, 19.92292023], [72.67402649, 19.92291832], [72.67402649, 19.92319679], [72.67375183, 19.92319679], [72.67375183, 19.92347145], [72.67346954, 19.92346954], [72.67346954, 19.92374992], [72.67292023, 19.92374992], [72.67292023, 19.9240303], [72.67263794, 19.92402649], [72.67263794, 19.92486191], [72.67236328, 19.92485809], [72.67236328, 19.92514038], [72.67208099, 19.92514038], [72.67208099, 19.92542076], [72.67180634, 19.92541885], [72.67180634, 19.92597198], [72.67151642, 19.92596054], [72.67151642, 19.92653084], [72.67124176, 19.92653084], [72.67124176, 19.92680931], [72.67097473, 19.9268055], [72.67097473, 19.92708397], [72.67069244, 19.92707825], [72.67069244, 19.92764091], [72.66764069, 19.92764091], [72.66764069, 19.92791939], [72.6673584, 19.92791748], [72.6673584, 19.92819405], [72.66707611, 19.92819405], [72.66680908, 19.92819405], [72.66680908, 19.92847252], [72.66625214, 19.92847061], [72.66625214, 19.9287529], [72.66569519, 19.92874908], [72.66569519, 19.92902756], [72.6654129, 19.92902184], [72.6654129, 19.92931175], [72.66513824, 19.92930603], [72.66513824, 19.9295826], [72.66485596, 19.9295826], [72.66485596, 19.92986107], [72.6645813, 19.92986107], [72.6645813, 19.93013954], [72.66430664, 19.93013954], [72.66430664, 19.93292046], [72.6645813, 19.93291664], [72.6645813, 19.93347168], [72.66485596, 19.93346977], [72.66485596, 19.93403053], [72.66513824, 19.93402863], [72.66513824, 19.93458366], [72.6654129, 19.93457985], [72.6654129, 19.93486023], [72.66680908, 19.93486023], [72.66680908, 19.93457985], [72.66707611, 19.93457985], [72.66707611, 19.93486023], [72.6673584, 19.93486023], [72.6673584, 19.93515015], [72.66764069, 19.93515015], [72.66764069, 19.93542099], [72.66847229, 19.93541527], [72.66847229, 19.93569374], [72.66874695, 19.93569374], [72.66874695, 19.93597221], [72.66902924, 19.93597031], [72.66902924, 19.93625069], [72.66986084, 19.93625069], [72.66986084, 19.93653107], [72.67014313, 19.93653107], [72.67014313, 19.93680954], [72.67041779, 19.93680763], [72.67041779, 19.9370842], [72.67069244, 19.93708038], [72.67069244, 19.93764114], [72.6709671, 19.93764114], [72.6709671, 19.93791962], [72.67124939, 19.93791771], [72.67124939, 19.93819427], [72.67152405, 19.93819427], [72.67152405, 19.93847275], [72.67236328, 19.93847084], [72.67236328, 19.93875122], [72.67263794, 19.93875122], [72.67263794, 19.93902969], [72.67318726, 19.93902969], [72.67318726, 19.93930817], [72.67430878, 19.93930626], [72.67430878, 19.93958282], [72.67541504, 19.93958282], [72.67541504, 19.9398613], [72.67597198, 19.93985748], [72.67597198, 19.94013977], [72.67624664, 19.94013977], [72.67624664, 19.94041824], [72.67652893, 19.94041634], [72.67652893, 19.94069481], [72.67791748, 19.94069481], [72.67791748, 19.94097137], [72.67819214, 19.94095993], [72.67819214, 19.94125175], [72.67903137, 19.94125175], [72.67903137, 19.94153023], [72.67930603, 19.94152832], [72.67930603, 19.94180489], [72.67958069, 19.94180489], [72.67958069, 19.94208336], [72.67986298, 19.94208336], [72.67986298, 19.94236183], [72.68013763, 19.94236183], [72.68013763, 19.94292259], [72.68042755, 19.94292259], [72.68042755, 19.94320107], [72.68096924, 19.94319534], [72.68096924, 19.94347191], [72.68152618, 19.94347191], [72.68152618, 19.94375038], [72.68180847, 19.94375038], [72.68180847, 19.94403076], [72.68235779, 19.94403076], [72.68235779, 19.94432068], [72.68264008, 19.94430542], [72.68264008, 19.94458389], [72.6829071, 19.94458008], [72.6829071, 19.94486046], [72.68319702, 19.94486046], [72.68319702, 19.94514084], [72.68347168, 19.94514084], [72.68347168, 19.94542122], [72.68374634, 19.94542122], [72.68374634, 19.94625092], [72.68402863, 19.94625092], [72.68402863, 19.94709015], [72.68430328, 19.94709015], [72.68430328, 19.94763947], [72.68458557, 19.94763947], [72.68458557, 19.9481945], [72.68486023, 19.94819069], [72.68486023, 19.94874954], [72.68514252, 19.94874954], [72.68514252, 19.94902992], [72.68541718, 19.94902611], [72.68541718, 19.94958305], [72.68569183, 19.94958305], [72.68569183, 19.95013618], [72.68597412, 19.95013618], [72.68597412, 19.9509716], [72.68624115, 19.9509697], [72.68624115, 19.95181084], [72.68653107, 19.95181084], [72.68653107, 19.95235825], [72.68681335, 19.95235825], [72.68681335, 19.95292091], [72.68708038, 19.9529171], [72.68708038, 19.95319366], [72.68736267, 19.95318985], [72.68736267, 19.95375061], [72.68763733, 19.95375061], [72.68763733, 19.95430946], [72.68791962, 19.95430946], [72.68791962, 19.95486069], [72.68818665, 19.95486069], [72.68818665, 19.95541954], [72.68846893, 19.95541573], [72.68846893, 19.95597267], [72.68875122, 19.95597267], [72.68875122, 19.95626068], [72.68902588, 19.95624924], [72.68902588, 19.95708275], [72.68930817, 19.95708275], [72.68930817, 19.95736122], [72.68958282, 19.95736122], [72.68958282, 19.95763969], [72.68985748, 19.95763969], [72.68985748, 19.95792007], [72.69013977, 19.95791626], [72.69013977, 19.95819473], [72.69097137, 19.95819473], [72.69097137, 19.9584713], [72.69180298, 19.95846939], [72.69180298, 19.95874977], [72.69236755, 19.95874977], [72.69236755, 19.95903015], [72.69264221, 19.95902824], [72.69264221, 19.95930481], [72.69319153, 19.95930481], [72.69319153, 19.95958328], [72.69374847, 19.95958328], [72.69374847, 19.95986176], [72.69403076, 19.95985985], [72.69403076, 19.96014023], [72.69625092, 19.96013832], [72.69625092, 19.96097183], [72.6965332, 19.96096992], [72.6965332, 19.96153069], [72.69680786, 19.96153069], [72.69680786, 19.96096992], [72.69736481, 19.96097183], [72.69736481, 19.96069336], [72.69958496, 19.96069336], [72.69958496, 19.96097183], [72.70041656, 19.96096992], [72.70041656, 19.96125031], [72.70096588, 19.96125031], [72.70096588, 19.96153069], [72.70124817, 19.96153069], [72.70124817, 19.96181107], [72.70153046, 19.96180534], [72.70153046, 19.96208382], [72.70180511, 19.96208382], [72.70180511, 19.96236038], [72.70207977, 19.96236038], [72.70207977, 19.96264076], [72.70236206, 19.96263885], [72.70236206, 19.96319389], [72.70263672, 19.96319389], [72.70263672, 19.96347237], [72.70318604, 19.96347046], [72.70318604, 19.96375084], [72.70347595, 19.96375084], [72.70347595, 19.96403122], [72.70375061, 19.9640255], [72.70375061, 19.96513939], [72.7040329, 19.96512985], [72.7040329, 19.96541977], [72.70430756, 19.96541786], [72.70430756, 19.96569443], [72.70458221, 19.96569443], [72.70458221, 19.9659729], [72.70485687, 19.96596909], [72.70485687, 19.96624756], [72.70540619, 19.96624756], [72.70540619, 19.96652985], [72.70569611, 19.96652985], [72.70569611, 19.96680832], [72.70625305, 19.96680641], [72.70625305, 19.96708298], [72.70680237, 19.96708298], [72.70680237, 19.96736145], [72.70707703, 19.96736145], [72.70707703, 19.96764183], [72.7076416, 19.96764183], [72.7076416, 19.9679203], [72.70791626, 19.9679203], [72.70791626, 19.96820259], [72.71013641, 19.96819496], [72.71013641, 19.96847153], [72.71041107, 19.96847153], [72.71041107, 19.96875191], [72.71069336, 19.96875191], [72.71069336, 19.96903038], [72.71098328, 19.96903038], [72.71098328, 19.96931267], [72.71263885, 19.96930504], [72.71263885, 19.96958351], [72.71375275, 19.96958351], [72.71375275, 19.96930504], [72.7179184, 19.96931267], [72.7179184, 19.96903038], [72.71819305, 19.96903038], [72.71819305, 19.96875191], [72.71985626, 19.96875191], [72.71985626, 19.96847153], [72.72041321, 19.96847153], [72.72041321, 19.96791649], [72.72070313, 19.9679203], [72.72070313, 19.96764183], [72.72097015, 19.96764183], [72.72097015, 19.96736145], [72.72125244, 19.96736145], [72.72125244, 19.96680641], [72.72180176, 19.96680832], [72.72180176, 19.96652985], [72.72207642, 19.96652985], [72.72207642, 19.96624756], [72.72264099, 19.96624756], [72.72264099, 19.96569061], [72.72319794, 19.96569443], [72.72319794, 19.96486092], [72.7234726, 19.96486092], [72.7234726, 19.96458054], [72.72402954, 19.96458244], [72.72402954, 19.96430779], [72.72429657, 19.96430969], [72.72429657, 19.96403122], [72.72458649, 19.96403122], [72.72458649, 19.96375084], [72.72486115, 19.96375084], [72.72486115, 19.96347046], [72.7251358, 19.96347237], [72.7251358, 19.96291542], [72.72541809, 19.96292114], [72.72541809, 19.96264076], [72.72598267, 19.96264076], [72.72598267, 19.96236038], [72.72652435, 19.96236038], [72.72651672, 19.96207047], [72.72624969, 19.96208382], [72.72624969, 19.96152687], [72.72651672, 19.96153069], [72.72651672, 19.96125031], [72.7270813, 19.96125031], [72.7270813, 19.96096992], [72.72736359, 19.96097183], [72.72736359, 19.96069336], [72.72763824, 19.96070099], [72.72763824, 19.96042061], [72.72820282, 19.96042061], [72.72820282, 19.95985985], [72.72846985, 19.95986176], [72.72846985, 19.95958328], [72.72875214, 19.95958328], [72.72875214, 19.95930481], [72.72902679, 19.95930481], [72.72902679, 19.95902824], [72.72957611, 19.95903015], [72.72957611, 19.95874977], [72.73014069, 19.95874977], [72.73014069, 19.95846939], [72.73041534, 19.9584713], [72.73041534, 19.95819473], [72.73069763, 19.95819473], [72.73069763, 19.95708275], [72.73097229, 19.95708275], [72.73097229, 19.95157051], [72.73097229, 19.95013618], [72.73124695, 19.95013618], [72.73124695, 19.94791412], [72.73153687, 19.94791985], [72.73153687, 19.94736099], [72.73180389, 19.94736099], [72.73179626, 19.94597054], [72.73208618, 19.94597244], [72.73208618, 19.9454174], [72.73236084, 19.94542122], [72.73236084, 19.94514084], [72.73264313, 19.94514084], [72.73264313, 19.94458008], [72.73291779, 19.94458389], [72.73291779, 19.94430542], [72.73319244, 19.94432068], [72.73319244, 19.94403076], [72.7334671, 19.94403076], [72.7334671, 19.94375038], [72.73374939, 19.94375038], [72.73374939, 19.94347191], [72.73430634, 19.94347191], [72.73430634, 19.94318962], [72.73430634, 19.9426384], [72.73513794, 19.9426403], [72.73513794, 19.94236183], [72.73542023, 19.94236183], [72.73542023, 19.94208336], [72.73596954, 19.94208336], [72.73596954, 19.94152832], [72.73874664, 19.94153023], [72.73874664, 19.94125175], [72.73986053, 19.94125175], [72.73986053, 19.94095993], [72.74013519, 19.94097137], [72.74013519, 19.94069481], [72.74263763, 19.94069481], [72.74263763, 19.94097137], [72.74318695, 19.94095993], [72.74318695, 19.94125175], [72.74347687, 19.94125175], [72.74347687, 19.94153023], [72.74541473, 19.94152832], [72.74541473, 19.94180489], [72.74597168, 19.94180489], [72.74597168, 19.94208336], [72.74652863, 19.94208336], [72.74652863, 19.94236183], [72.7470932, 19.94236183], [72.7470932, 19.9426403], [72.74986267, 19.9426403], [72.74986267, 19.94236183], [72.75069427, 19.94236183], [72.75069427, 19.94208336], [72.75096893, 19.94208336], [72.75096893, 19.94180489], [72.75152588, 19.94180489], [72.75152588, 19.94152832], [72.75180817, 19.94153023], [72.75180817, 19.94095993], [72.75235748, 19.94097137], [72.75235748, 19.94041634], [72.7526474, 19.94041824], [72.7526474, 19.94013977], [72.75291443, 19.94013977], [72.7529068, 19.93985748], [72.75319672, 19.9398613], [72.75319672, 19.93958282], [72.75347137, 19.93958282], [72.75347137, 19.93930626], [72.75374603, 19.93930817], [72.75374603, 19.93902969], [72.75402832, 19.93902969], [72.75402832, 19.93457985], [72.75375366, 19.93458366], [72.75375366, 19.93263817], [72.75347137, 19.93264008], [72.75347137, 19.92791939], [72.75374603, 19.92791939], [72.75374603, 19.92736053], [72.75485992, 19.92736053], [72.75485992, 19.93431091], [72.75514221, 19.93431091], [72.75514221, 19.93542099], [72.75541687, 19.93542099], [72.75541687, 19.93902969], [72.75514221, 19.93902969], [72.75514221, 19.93930817], [72.75485992, 19.93930626], [72.75485992, 19.9398613], [72.7545929, 19.93985748], [72.7545929, 19.94041824], [72.75430298, 19.94041634], [72.75430298, 19.94069481], [72.75402832, 19.94069481], [72.75402832, 19.94097137], [72.75375366, 19.94097137], [72.75375366, 19.94180489], [72.75347137, 19.94180489], [72.75347137, 19.94208336], [72.75374603, 19.94208145], [72.75374603, 19.9426403], [72.75347137, 19.9426403], [72.75347137, 19.94292259], [72.75319672, 19.94292259], [72.75319672, 19.94320107], [72.75291443, 19.94319534], [72.75291443, 19.94347191], [72.75235748, 19.94347191], [72.75235748, 19.94403076], [72.74680328, 19.94403076], [72.74680328, 19.94375038], [72.74485779, 19.94375038], [72.74485779, 19.94347191], [72.74458313, 19.94347191], [72.74458313, 19.94319534], [72.74097443, 19.94319534], [72.74097443, 19.94347191], [72.74069214, 19.94347191], [72.74069214, 19.94375038], [72.73958588, 19.94375038], [72.73958588, 19.94403076], [72.73847198, 19.94403076], [72.73847198, 19.94432068], [72.73791504, 19.94430542], [72.73791504, 19.94458389], [72.73764038, 19.94458008], [72.73764038, 19.94514084], [72.73735809, 19.94514084], [72.73735809, 19.94542122], [72.73708344, 19.9454174], [72.73708344, 19.94569206], [72.73680878, 19.94569016], [72.73680878, 19.94625092], [72.73652649, 19.94625092], [72.73652649, 19.94652939], [72.73639679, 19.94652748], [72.73625183, 19.94652939], [72.73625183, 19.94709015], [72.73596954, 19.94709015], [72.73596954, 19.94791985], [72.73568726, 19.94791985], [72.73568726, 19.94902992], [72.73542023, 19.94902611], [72.73542023, 19.9509716], [72.73513794, 19.9509716], [72.73513794, 19.95112038], [72.73513794, 19.95430946], [72.73486328, 19.95430946], [72.73486328, 19.95652962], [72.73458099, 19.95652962], [72.73458099, 19.95763969], [72.73430634, 19.95763969], [72.73430634, 19.95792007], [72.73402405, 19.95791626], [72.73402405, 19.9584713], [72.7334671, 19.95846939], [72.7334671, 19.96014023], [72.73319244, 19.96014023], [72.73319244, 19.96070099], [72.73291779, 19.96070099], [72.73291779, 19.96125031], [72.73264313, 19.96125031], [72.73264313, 19.96153069], [72.73097229, 19.96153069], [72.73097229, 19.96181107], [72.73069763, 19.96180534], [72.73069763, 19.96208382], [72.73041534, 19.96208382], [72.73042297, 19.96236038], [72.73014069, 19.96236038], [72.73014069, 19.96264076], [72.7298584, 19.96264076], [72.7298584, 19.96292114], [72.73014069, 19.96291542], [72.73014069, 19.96319389], [72.7298584, 19.96319389], [72.7298584, 19.96347237], [72.72957611, 19.96347046], [72.72957611, 19.96375084], [72.72930908, 19.96375084], [72.72930908, 19.96403122], [72.72902679, 19.96403122], [72.72902679, 19.96430969], [72.72875214, 19.96430779], [72.72875214, 19.96458244], [72.72846985, 19.96458244], [72.72846985, 19.96486092], [72.72819519, 19.96486092], [72.72819519, 19.96513939], [72.7279129, 19.96513939], [72.7279129, 19.96569443], [72.72763824, 19.96569443], [72.72763824, 19.9659729], [72.72735596, 19.96596909], [72.72735596, 19.96652985], [72.7270813, 19.96652985], [72.7270813, 19.96680832], [72.72680664, 19.96680641], [72.72680664, 19.96708298], [72.72651672, 19.96707916], [72.72651672, 19.96764183], [72.72624969, 19.96764183], [72.72624969, 19.9679203], [72.72598267, 19.9679203], [72.72598267, 19.96820259], [72.72541809, 19.96820259], [72.72541809, 19.96875191], [72.7251358, 19.96875191], [72.7251358, 19.96903038], [72.72486115, 19.96903038], [72.72486115, 19.96931267], [72.7243042, 19.96930504], [72.7243042, 19.96958351], [72.72374725, 19.96958351], [72.72374725, 19.96986008], [72.72264099, 19.96986008], [72.72264099, 19.97014046], [72.7215271, 19.97013855], [72.7215271, 19.97069359], [72.72097015, 19.97069359], [72.72097015, 19.97097206], [72.72013855, 19.97097015], [72.72013855, 19.97153091], [72.7168045, 19.9715271], [72.7168045, 19.97208214], [72.71652985, 19.97208214], [72.71653748, 19.97236061], [72.71624756, 19.97236061], [72.71624756, 19.97402954], [72.71652985, 19.97402763], [72.71652985, 19.97486115], [72.71679688, 19.97486115], [72.71679688, 19.97513962], [72.71708679, 19.97513962], [72.71708679, 19.97542], [72.71736145, 19.97542], [72.71736145, 19.97624969], [72.71763611, 19.97624969], [72.71763611, 19.97708321], [72.7179184, 19.97708321], [72.7179184, 19.97736168], [72.71819305, 19.97735977], [72.71819305, 19.97764015], [72.71848297, 19.97764015], [72.71848297, 19.97820091], [72.71875, 19.97820091], [72.71875, 19.97875023], [72.71901703, 19.97875023], [72.71901703, 19.98041916], [72.71930695, 19.98041725], [72.71930695, 19.98097229], [72.7195816, 19.98096848], [72.7195816, 19.98180962], [72.71986389, 19.9818058], [72.71986389, 19.98208237], [72.72013855, 19.98208427], [72.72013855, 19.98347282], [72.72041321, 19.98347282], [72.72041321, 19.98402977], [72.7206955, 19.98402786], [72.7206955, 19.98597145], [72.72097015, 19.98597145], [72.72097015, 19.98624992], [72.72125244, 19.98624039], [72.72125244, 19.9865303], [72.7215271, 19.9865284], [72.7215271, 19.98736191], [72.72180176, 19.98736191], [72.72180939, 19.9893055], [72.72208405, 19.9893055], [72.72208405, 19.98958588], [72.72180939, 19.98958015], [72.72180939, 19.99152946], [72.72207642, 19.99152946], [72.72207642, 19.99291992], [72.72180939, 19.99291992], [72.72180176, 19.99736023], [72.7215271, 19.99736023], [72.7215271, 19.99903107], [72.72125244, 19.99903107], [72.72125244, 19.99998283], [72.72125244, 20.00069427], [72.7215271, 20.00069427], [72.7215271, 20.00124931], [72.72125244, 20.00123978], [72.72125244, 20.00152969], [72.72097015, 20.00152779], [72.72097015, 20.0023613], [72.72070313, 20.00235939], [72.72070313, 20.00569916], [72.72041321, 20.00569534], [72.72041321, 20.00597191], [72.72013855, 20.00596809], [72.72013855, 20.00680923], [72.71986389, 20.00680542], [72.71986389, 20.00847244], [72.7195816, 20.00846863], [72.7195816, 20.00902939], [72.71986389, 20.00902748], [72.71986389, 20.00958252], [72.7195816, 20.00958252], [72.7195816, 20.01042938], [72.71930695, 20.01041603], [72.71930695, 20.0106945], [72.71901703, 20.0106926], [72.71901703, 20.01152992], [72.71875, 20.01152802], [72.71875, 20.01208305], [72.71901703, 20.01208115], [72.71901703, 20.01320076], [72.71875, 20.01320076], [72.71875, 20.01375008], [72.71847534, 20.01375008], [72.71847534, 20.01486206], [72.71819305, 20.01486015], [72.71819305, 20.01542091], [72.7179184, 20.01542091], [72.7179184, 20.01764107], [72.71763611, 20.01764107], [72.71763611, 20.01791954], [72.71708679, 20.01791954], [72.71708679, 20.01847267], [72.71679688, 20.01847076], [72.71679688, 20.01902962], [72.71652985, 20.01902962], [72.71653748, 20.01986122], [72.71624756, 20.01986122], [72.71624756, 20.02041817], [72.7159729, 20.02041626], [72.7159729, 20.0209713], [72.71569824, 20.0209713], [72.71569824, 20.02125168], [72.71541595, 20.02125168], [72.71541595, 20.02180481], [72.7151413, 20.02179909], [72.7151413, 20.02264023], [72.71485901, 20.02264023], [72.71485901, 20.02514076], [72.7151413, 20.02514076], [72.7151413, 20.02653122], [72.71541595, 20.0265274], [72.71541595, 20.02819443], [72.71569824, 20.02819443], [72.71569824, 20.02986145], [72.71541595, 20.02985954], [72.71541595, 20.03153992], [72.7151413, 20.03153992], [72.7151413, 20.03264046], [72.71541595, 20.03264046], [72.71541595, 20.03403091], [72.7151413, 20.03403091], [72.7151413, 20.03625107], [72.71541595, 20.03624916], [72.71541595, 20.03708267], [72.7151413, 20.03708267], [72.7151413, 20.03736115], [72.71485901, 20.03735161], [72.71485901, 20.03792], [72.7151413, 20.03792], [72.7151413, 20.03874969], [72.71485901, 20.03874969], [72.71485901, 20.03930473], [72.7151413, 20.03930473], [72.7151413, 20.04041672], [72.71485901, 20.0404129], [72.71485901, 20.04264069], [72.71457672, 20.04264069], [72.71457672, 20.04292107], [72.71430206, 20.04292107], [72.71430206, 20.04347992], [72.71457672, 20.04347992], [72.71457672, 20.04403114], [72.71430206, 20.04403114], [72.71430206, 20.04430962], [72.7140274, 20.04430962], [72.7140274, 20.04541969], [72.71375275, 20.04541969], [72.71375275, 20.04624748], [72.71347046, 20.04624748], [72.71347046, 20.04764175], [72.7131958, 20.04764175], [72.7131958, 20.04819489], [72.71290588, 20.04818916], [72.71290588, 20.0490303], [72.71263885, 20.0490284], [72.71263885, 20.0506897], [72.7123642, 20.05069542], [72.7123642, 20.05097389], [72.71208191, 20.05097008], [72.71208191, 20.05181122], [72.71180725, 20.0518055], [72.71180725, 20.05236053], [72.71152496, 20.05236053], [72.71152496, 20.05347252], [72.71125031, 20.05347252], [72.71125031, 20.0545826], [72.71097565, 20.0545826], [72.71098328, 20.05624962], [72.71069336, 20.05624962], [72.71069336, 20.05708313], [72.71041107, 20.05708122], [72.71041107, 20.06041908], [72.71013641, 20.06041718], [72.71013641, 20.0620842], [72.70986176, 20.0620842], [72.70986176, 20.06319427], [72.7095871, 20.06319046], [72.7095871, 20.06513977], [72.70929718, 20.06513977], [72.70929718, 20.06624985], [72.70903015, 20.06624985], [72.70903015, 20.06653023], [72.70874786, 20.06652832], [72.70874786, 20.06736183], [72.70847321, 20.06735992], [72.70847321, 20.06820107], [72.70819092, 20.06820107], [72.70819092, 20.06875038], [72.70791626, 20.06875038], [72.70791626, 20.07014084], [72.7076416, 20.07014084], [72.7076416, 20.07042122], [72.70791626, 20.07042122], [72.70791626, 20.07125092], [72.70819092, 20.07125092], [72.70819092, 20.07208252], [72.70847321, 20.07208061], [72.70847321, 20.07263947], [72.70874786, 20.07263947], [72.70874786, 20.07347298], [72.70903015, 20.07347298], [72.70903015, 20.07430077], [72.70929718, 20.0743103], [72.70929718, 20.07514191], [72.7095871, 20.07513809], [72.7095871, 20.0759716], [72.70986176, 20.0759716], [72.70986176, 20.07681274], [72.71013641, 20.07681274], [72.71013641, 20.07736015], [72.71041107, 20.07736015], [72.71041107, 20.07764053], [72.71069336, 20.07763863], [72.71069336, 20.07819366], [72.71097565, 20.07819366], [72.71097565, 20.07875061], [72.71125031, 20.07875061], [72.71125031, 20.07903099], [72.71153259, 20.07903099], [72.71153259, 20.07930946], [72.71208191, 20.07930946], [72.71208191, 20.07958984], [72.71235657, 20.07958984], [72.71235657, 20.07986069], [72.71290588, 20.07986069], [72.71290588, 20.07958984], [72.7131958, 20.07958984], [72.7131958, 20.07986069], [72.71430206, 20.07986069], [72.71430206, 20.08014107], [72.7151413, 20.08014107], [72.7151413, 20.08041954], [72.71624756, 20.08041573], [72.71624756, 20.0806942], [72.71644592, 20.0806942], [72.71708679, 20.0806942], [72.71708679, 20.08097267], [72.71847534, 20.08097267], [72.71847534, 20.0806942], [72.7206955, 20.0806942], [72.7206955, 20.08097267], [72.72486115, 20.08097076], [72.72486115, 20.08125114], [72.72541809, 20.08125114], [72.72541809, 20.08152962], [72.72598267, 20.08152962], [72.72598267, 20.08181], [72.72569275, 20.08180428], [72.72569275, 20.08208275], [72.72541809, 20.08208084], [72.72541809, 20.08265114], [72.72569275, 20.08265114], [72.72569275, 20.08236122], [72.72598267, 20.08236122], [72.72597504, 20.08208275], [72.72624969, 20.08208084], [72.72624969, 20.08265114], [72.72652435, 20.08263969], [72.72652435, 20.08319473], [72.72680664, 20.08319092], [72.72680664, 20.08403015], [72.7270813, 20.08402634], [72.7270813, 20.08458328], [72.72735596, 20.08457947], [72.72735596, 20.08542061], [72.72763824, 20.0854187], [72.72763824, 20.08597183], [72.7279129, 20.08596992], [72.7279129, 20.08680916], [72.72819519, 20.08680534], [72.72819519, 20.08819389], [72.72846985, 20.08819389], [72.72846985, 20.08875084], [72.72875214, 20.08875084], [72.72875214, 20.09013939], [72.72902679, 20.09013939], [72.72902679, 20.09236145], [72.72930908, 20.09235954], [72.72930908, 20.0929203], [72.72958374, 20.09291649], [72.72958374, 20.09347153], [72.7298584, 20.09346962], [72.7298584, 20.09403038], [72.73014069, 20.09402847], [72.73014069, 20.09486198], [72.73041534, 20.09486198], [72.73041534, 20.09569359], [72.73097229, 20.09568977], [72.73097229, 20.09625053], [72.73124695, 20.09625053], [72.73124695, 20.09653091], [72.73152924, 20.09652519], [72.73152924, 20.09708595], [72.73179626, 20.09708023], [72.73179626, 20.09765053], [72.73208618, 20.09763718], [72.73208618, 20.09819412], [72.73236084, 20.09819031], [72.73236084, 20.09902954], [72.7326355, 20.09902954], [72.7326355, 20.09986115], [72.73291779, 20.09986115], [72.73291779, 20.10069466], [72.73319244, 20.10069084], [72.73319244, 20.10153008], [72.73347473, 20.10152817], [72.73347473, 20.10236168], [72.73374939, 20.10236168], [72.73374939, 20.10320282], [72.73401642, 20.10320282], [72.73401642, 20.10375023], [72.73430634, 20.10375023], [72.73430634, 20.10458374], [72.73458099, 20.10458183], [72.73458099, 20.10514069], [72.73486328, 20.10513878], [72.73486328, 20.10597229], [72.73513794, 20.10597038], [72.73513794, 20.10653114], [72.73542023, 20.10653114], [72.73542023, 20.10736084], [72.73568726, 20.10736084], [72.73568726, 20.10791969], [72.73596954, 20.10791969], [72.73596954, 20.10874939], [72.73625183, 20.10874939], [72.73625183, 20.10931015], [72.73652649, 20.10931015], [72.73652649, 20.11013985], [72.73680878, 20.11013985], [72.73680878, 20.11042023], [72.73708344, 20.11041641], [72.73708344, 20.11069679], [72.73735809, 20.11069107], [72.73735809, 20.11292076], [72.73764038, 20.11292076], [72.73764038, 20.11375046], [72.73791504, 20.11375046], [72.73791504, 20.11458397], [72.73819733, 20.11458397], [72.73819733, 20.11840057], [72.73819733, 20.12292099], [72.73791504, 20.12291527], [72.73791504, 20.12569427], [72.73764038, 20.12569427], [72.73764038, 20.1273613], [72.73792267, 20.12735748], [72.73792267, 20.12903023], [72.73764038, 20.12903023], [72.73764038, 20.13264084], [72.73735809, 20.13264084], [72.73735809, 20.13541985], [72.73764038, 20.13541412], [72.73764038, 20.13653946], [72.74106598, 20.13595963], [72.74830627, 20.13441086], [72.7546463, 20.13303947], [72.7618103, 20.13149834], [72.7745285, 20.13080025], [72.78761292, 20.13008118], [72.79447174, 20.12817955], [72.80184937, 20.12501907], [72.80352783, 20.12601089], [72.80519867, 20.12701035], [72.8012619, 20.13780975], [72.80066681, 20.14526939], [72.80148315, 20.14711761], [72.80206299, 20.14846992], [72.80536652, 20.15003014], [72.80912781, 20.15180016], [72.81195068, 20.15242004], [72.81585693, 20.15328026], [72.82604218, 20.14628029], [72.83229828, 20.14402008], [72.83534241, 20.14464188], [72.83416748, 20.14973068], [72.82884216, 20.15657043], [72.83361816, 20.18357086], [72.8346405, 20.18577003], [72.83553314, 20.18766022], [72.83725739, 20.18868065], [72.84220123, 20.18886948], [72.84352112, 20.19004059], [72.84967041, 20.18925095], [72.84905243, 20.19094276], [72.84571838, 20.19413948], [72.8441391, 20.19779015], [72.846138, 20.20356941], [72.85028839, 20.20794106], [72.85508728, 20.20911026], [72.86438751, 20.20862961], [72.87200165, 20.20824051], [72.87287903, 20.21251106], [72.87188721, 20.22256088], [72.87454224, 20.2258091], [72.88432312, 20.22657967], [72.88873291, 20.22582054], [72.89984131, 20.22167015], [72.90538025, 20.22623253], [72.91086578, 20.22606087], [72.91680908, 20.22476959], [72.92218781, 20.22359848], [72.92842865, 20.2233696], [72.94181061, 20.21780968], [72.95101929, 20.21598053], [72.96082306, 20.21404076], [72.96924591, 20.2109108], [72.97042847, 20.21232986], [72.97592163, 20.18959808], [72.97619629, 20.18001938], [72.98603821, 20.17654991], [72.98668671, 20.17131042], [72.98623657, 20.16271973], [72.98596191, 20.15752983], [72.97322845, 20.13080025], [72.97962952, 20.12529945], [72.98532104, 20.113451], [72.98924255, 20.11321259], [72.9941864, 20.11390114], [73.00431061, 20.11791992], [73.00665283, 20.12125015], [73.00727844, 20.12412071], [73.00778198, 20.12639046], [73.00771332, 20.12940025], [73.00763702, 20.13246918], [73.00875854, 20.13701057], [73.01051331, 20.14022255], [73.01747894, 20.13495827], [73.01702118, 20.1324501], [73.01667023, 20.13049126], [73.01499176, 20.12486076], [73.01020813, 20.11040115], [73.01954651, 20.10502052], [73.02468109, 20.09630013], [73.03177643, 20.08442116], [73.03852844, 20.0780983], [73.04527283, 20.07178116], [73.05281067, 20.06767082], [73.05921173, 20.06793022], [73.05799103, 20.09673119], [73.06063843, 20.09906006], [73.07823181, 20.09527016], [73.08831787, 20.09446907], [73.09844971, 20.09366989], [73.1051712, 20.08721924], [73.10794067, 20.08732033], [73.11038208, 20.08461189], [73.11183167, 20.08301163], [73.11754608, 20.07880974], [73.1231308, 20.07793999], [73.12612152, 20.07809067], [73.12773895, 20.07816124], [73.12967682, 20.07884026], [73.13140106, 20.07942963], [73.13669586, 20.08525085], [73.13954163, 20.08427048], [73.1444931, 20.07785988], [73.15674591, 20.07395935], [73.16329956, 20.07311058], [73.17022705, 20.06560135], [73.17539215, 20.05805016], [73.18144226, 20.05162048], [73.18379974, 20.0522995], [73.18586731, 20.05290031], [73.19890594, 20.06227112], [73.19803619, 20.07781029], [73.20289612, 20.08105087], [73.20691681, 20.08371162], [73.21393585, 20.09064102], [73.21911621, 20.09749985], [73.21774292, 20.10634041], [73.21631622, 20.12199974], [73.22148895, 20.12079811], [73.22672272, 20.12257957], [73.23033142, 20.12816048], [73.22952271, 20.13315964], [73.23046875, 20.13771057], [73.23264313, 20.1406002], [73.23548889, 20.14099121], [73.23690796, 20.13692284], [73.23667908, 20.1297226], [73.23812103, 20.12811089], [73.24391937, 20.12903976], [73.25361633, 20.12852097], [73.25614929, 20.12788963], [73.25946808, 20.12463951], [73.2612915, 20.12559128], [73.26280975, 20.12795067], [73.2649765, 20.13376045], [73.26846313, 20.13928986], [73.28347015, 20.14575958], [73.28907776, 20.14956284], [73.29363251, 20.15388107], [73.29321289, 20.16216087], [73.29065704, 20.17440987], [73.29073334, 20.177351], [73.29374695, 20.18597984], [73.29405975, 20.19386101], [73.2948761, 20.19621086], [73.29821777, 20.19616127], [73.3111496, 20.20721054], [73.31416321, 20.20767021], [73.32047272, 20.20433235], [73.32787323, 20.20249939], [73.33642578, 20.20409966], [73.34806061, 20.1990509], [73.35285187, 20.19847107], [73.35481262, 20.1996212], [73.35721588, 20.20249939], [73.35930634, 20.20911026], [73.36178589, 20.21198845], [73.36759949, 20.21337128], [73.36923981, 20.21170807], [73.36760712, 20.20940018], [73.3647995, 20.20099831], [73.36691284, 20.19634056], [73.37431335, 20.19265938], [73.37594604, 20.19497108], [73.37528992, 20.20290947], [73.37632751, 20.20532036], [73.38366699, 20.20239067], [73.38851929, 20.20630074], [73.39528656, 20.20916939], [73.39736176, 20.20594025], [73.39626312, 20.20163155], [73.39807892, 20.19600105], [73.40281677, 20.19502068], [73.4054718, 20.19796944], [73.40920258, 20.20049095], [73.41681671, 20.20030975], [73.42682648, 20.20157051], [73.42991638, 20.20623016], [73.43031311, 20.21232033], [73.42788696, 20.21543121], [73.42607117, 20.22359848], [73.42237854, 20.23176193], [73.42280579, 20.23676109], [73.42032623, 20.24228096], [73.42227936, 20.24809074], [73.42160797, 20.25371933], [73.42041016, 20.25699997], [73.42180634, 20.26356125], [73.42442322, 20.26914024], [73.42314148, 20.27368927], [73.42462158, 20.27683067], [73.436203, 20.27902031], [73.43694305, 20.28212166], [73.43076324, 20.29804993], [73.42854309, 20.31191063], [73.42611694, 20.31592941], [73.42531586, 20.32072067], [73.42539978, 20.33767128], [73.42373657, 20.34181023], [73.4234314, 20.35209084], [73.42173767, 20.35560036], [73.41478729, 20.38157082], [73.41200256, 20.38352966], [73.4076767, 20.38392067], [73.40310669, 20.3817997], [73.39807892, 20.3747406], [73.39454651, 20.3729496], [73.39157867, 20.37289047], [73.39025116, 20.3801899], [73.39134979, 20.39019966], [73.39550781, 20.39801979], [73.39772797, 20.39923286], [73.40762329, 20.39628983], [73.40952301, 20.40134811], [73.40879059, 20.40422058], [73.41306305, 20.40784836], [73.41461182, 20.40566063], [73.41583252, 20.40619087], [73.41633606, 20.41065979], [73.42288971, 20.41432953], [73.42974091, 20.41439056], [73.42928314, 20.41996956], [73.43080902, 20.42881966], [73.43585968, 20.43606949], [73.43792725, 20.44572258], [73.44901276, 20.4666996], [73.45204163, 20.47140121], [73.45594025, 20.47537041], [73.46109009, 20.47813034], [73.46523285, 20.48415947], [73.46669769, 20.48830032], [73.46983337, 20.49233055], [73.47593689, 20.49501991], [73.47413635, 20.50106049], [73.47226715, 20.51404953], [73.47380829, 20.51531982], [73.47690582, 20.52203751], [73.48474121, 20.52570915], [73.49729919, 20.53622246], [73.50074005, 20.54024124], [73.49327087, 20.54220009], [73.48179626, 20.54335976], [73.48584747, 20.56405067], [73.4837265, 20.57843018], [73.4808197, 20.58359909], [73.47670746, 20.58630943], [73.46855927, 20.58876991], [73.45482635, 20.59458923], [73.44036102, 20.59511948], [73.4375, 20.59747124], [73.43908691, 20.60126114], [73.43382263, 20.61471939], [73.43078613, 20.62053108], [73.42764282, 20.62449074], [73.41596222, 20.62616158], [73.41512299, 20.62805939], [73.41797638, 20.63047028], [73.414711, 20.63570023], [73.41134644, 20.63858032], [73.40273285, 20.64259911], [73.40158081, 20.64920998], [73.40364838, 20.65237045], [73.40983582, 20.65501022], [73.41496277, 20.65604019], [73.41752625, 20.65789032], [73.41916656, 20.66047096], [73.43035889, 20.66088104], [73.43551636, 20.66237259], [73.43991852, 20.6648407], [73.44325256, 20.67437935], [73.443573, 20.6779995], [73.4500885, 20.68075943], [73.45288086, 20.68300056], [73.45452881, 20.68605042], [73.45654297, 20.69339943], [73.44729614, 20.70111084], [73.4536972, 20.7104702], [73.45868683, 20.71431923], [73.47518921, 20.72167015], [73.48049927, 20.71965027], [73.48261261, 20.71722984], [73.48416901, 20.70907021], [73.48873901, 20.70660019], [73.49336243, 20.6942997], [73.49375916, 20.68952942], [73.49729156, 20.6860199], [73.4972229, 20.6809597], [73.49205017, 20.68033028], [73.48918915, 20.67850113], [73.4874115, 20.67555046], [73.48777771, 20.67212105], [73.4895401, 20.66963959], [73.49250793, 20.66843033], [73.49336243, 20.66555977], [73.49547577, 20.66269112], [73.49843597, 20.65341949], [73.50087738, 20.65274048], [73.50788116, 20.65864944], [73.5123291, 20.66302109], [73.51780701, 20.67014122], [73.51998901, 20.66633987], [73.52516174, 20.66714287], [73.52697754, 20.67012978], [73.53040314, 20.6731205], [73.53837585, 20.67386055], [73.54476166, 20.6692009], [73.55365753, 20.65533066], [73.5629425, 20.64739037], [73.56732941, 20.64791107], [73.57419586, 20.65105057], [73.58418274, 20.64789963], [73.59120941, 20.64511108], [73.60275269, 20.63786125], [73.60730743, 20.63630104], [73.62219238, 20.62529945], [73.62594604, 20.62111092], [73.62948608, 20.61230087], [73.63038635, 20.60602951], [73.63217163, 20.60223961], [73.63506317, 20.59165955], [73.63448334, 20.58229065], [73.63677216, 20.57929039], [73.63949585, 20.57790947], [73.64328766, 20.57715988], [73.64710236, 20.57749939], [73.65093994, 20.57641029], [73.65705109, 20.57219124], [73.6618576, 20.56574059], [73.66584015, 20.5628109], [73.6707077, 20.56233978], [73.67617798, 20.56415939], [73.68136597, 20.56767082], [73.68550873, 20.57168961], [73.69243622, 20.57534981], [73.70101929, 20.57838058], [73.70964813, 20.57450294], [73.71985626, 20.57632065], [73.72428131, 20.57580185], [73.72902679, 20.5741291], [73.73766327, 20.57398987], [73.74154663, 20.57261848], [73.74820709, 20.56735992], [73.76394653, 20.58333015], [73.76906586, 20.58716965], [73.7756958, 20.58876038], [73.77997589, 20.59185982], [73.78135681, 20.59507942], [73.78705597, 20.60225868], [73.79273224, 20.60431099], [73.80237579, 20.60579109], [73.80596161, 20.60152054], [73.81656647, 20.60936928], [73.82538605, 20.61401939], [73.83068848, 20.61491966], [73.83390808, 20.61412048], [73.83828735, 20.6157608], [73.84641266, 20.6235199], [73.84310913, 20.64441109], [73.8434906, 20.65032959], [73.84707642, 20.65636253], [73.84535217, 20.66707039], [73.84150696, 20.67513847], [73.83425903, 20.67353821], [73.82543182, 20.67361832], [73.82264709, 20.69382095], [73.82874298, 20.69646072], [73.83362579, 20.69960976], [73.83917999, 20.70190048], [73.84275818, 20.70211983], [73.86360168, 20.6942997], [73.87362671, 20.7077198], [73.87728119, 20.72133064], [73.88194275, 20.72687912], [73.88556671, 20.72961044], [73.88886261, 20.73108101], [73.90379333, 20.73064041], [73.90875244, 20.72522926], [73.92090607, 20.72352982], [73.92756653, 20.73044014], [73.93506622, 20.73461914], [73.93596649, 20.73150063], [73.94953156, 20.74230957], [73.94845581, 20.74670029], [73.94523621, 20.74929047], [73.94750214, 20.75247002], [73.9471817, 20.76078033], [73.93834686, 20.76078987], [73.94056702, 20.76885986], [73.93811798, 20.78967094], [73.94114685, 20.80378151], [73.94019318, 20.80886078], [73.94626617, 20.81867027], [73.94763947, 20.82509041], [73.94760895, 20.82939911], [73.94509888, 20.84013176], [73.93589783, 20.8434391], [73.93373108, 20.8449707], [73.93106079, 20.84839058], [73.9315567, 20.85250282], [73.93013, 20.86011124], [73.9316864, 20.86473274], [73.92967987, 20.86887169], [73.93123627, 20.8766098], [73.9310379, 20.88591766], [73.92732239, 20.89911079], [73.92443848, 20.90283966], [73.92273712, 20.90774918], [73.92032623, 20.91123009], [73.91681671, 20.91505051], [73.91221619, 20.91794014], [73.90956116, 20.92140007], [73.90396118, 20.92536926], [73.89633942, 20.93300056], [73.89501953, 20.94013977], [73.89509583, 20.94652176], [73.89694214, 20.95255089], [73.9017868, 20.96170044], [73.91123199, 20.96235275], [73.91538239, 20.96482086], [73.91396332, 20.96996117], [73.91116333, 20.97542953], [73.90644836, 20.98315048], [73.89863586, 20.98222923], [73.87918854, 20.98647118], [73.87268829, 20.99073029], [73.85721588, 20.99770927], [73.8537674, 20.99911118], [73.85012817, 21.00141907], [73.84683228, 20.99398994], [73.84078217, 20.99313927], [73.83769226, 20.99483109], [73.82752991, 20.99607086], [73.82050323, 20.99504089], [73.81640625, 20.99605179], [73.81404877, 21.00080109], [73.81208038, 21.01066017], [73.80770111, 21.02255821], [73.79382324, 21.01976967], [73.78470612, 21.0195694], [73.77485657, 21.01045036], [73.76944733, 21.01452065], [73.77392578, 21.0216198], [73.7756424, 21.02760124], [73.7660675, 21.04005051], [73.76300049, 21.03864098], [73.7569809, 21.03917122], [73.747612, 21.03997993], [73.7421875, 21.05550003], [73.74373627, 21.0641613], [73.74079895, 21.07287025], [73.744133, 21.08167076], [73.74224091, 21.08156967], [73.74046326, 21.08486938], [73.73906708, 21.0948391], [73.74946594, 21.1077404], [73.75260925, 21.11408997], [73.74337006, 21.10824966], [73.7388916, 21.1013298], [73.7358017, 21.10322952], [73.71478271, 21.10719109], [73.70897675, 21.11234093], [73.71058655, 21.11902237], [73.70323944, 21.10896111], [73.69338989, 21.1009903], [73.68937683, 21.10598946], [73.67890167, 21.10925102], [73.65994263, 21.10837936], [73.6577301, 21.12104988], [73.65537262, 21.12179947], [73.6530304, 21.12254143], [73.64924622, 21.12274933], [73.64546204, 21.12295914], [73.63802338, 21.12170982], [73.62872314, 21.12014961], [73.62359619, 21.13799095], [73.62634277, 21.1398201], [73.62908173, 21.14166069], [73.61885071, 21.14417267], [73.61422729, 21.14698029], [73.61345673, 21.15043068], [73.61258698, 21.15219116], [73.61147308, 21.15446091], [73.60491943, 21.15505981], [73.60027313, 21.15433121], [73.59667969, 21.15273094], [73.59229279, 21.15294075], [73.58879852, 21.15419006], [73.58751678, 21.15674019], [73.58875275, 21.16086006], [73.58830261, 21.16790009], [73.59819794, 21.17472076], [73.60691833, 21.17846107], [73.60991669, 21.17667961], [73.61316681, 21.17605972], [73.61418915, 21.17245102], [73.61384583, 21.16797066], [73.61470032, 21.16348076], [73.61969757, 21.15794945], [73.63745117, 21.15313911], [73.63897705, 21.14734077], [73.63639832, 21.13265991], [73.67150879, 21.14513969], [73.67460632, 21.15102005], [73.68131256, 21.15212059], [73.68943024, 21.15116119], [73.69824219, 21.15011024], [73.7131958, 21.1504612], [73.71517944, 21.14310074], [73.71707153, 21.1417408], [73.72235107, 21.13924026], [73.73668671, 21.13828087], [73.73983765, 21.14016151], [73.74318695, 21.1468029], [73.74603271, 21.14760971], [73.74797058, 21.15153122], [73.74619293, 21.15483093], [73.7407608, 21.16039848], [73.74162292, 21.16711044], [73.75306702, 21.16818047], [73.77966309, 21.16455269], [73.78366089, 21.16506004], [73.78720093, 21.1663208], [73.78975677, 21.16867828], [73.7911377, 21.17622948], [73.79631042, 21.18173027], [73.80253601, 21.1785717], [73.80753326, 21.1746006], [73.81212616, 21.17206764], [73.81793976, 21.17143822], [73.82254791, 21.17192078], [73.82917786, 21.18234062], [73.83048248, 21.18439293], [73.83232117, 21.1853981], [73.83590698, 21.19518089], [73.83405304, 21.19719124], [73.82134247, 21.19532013], [73.81951141, 21.19960976], [73.81877899, 21.20385933], [73.81859589, 21.20857048], [73.81841278, 21.21372032], [73.82013702, 21.22186089], [73.82316589, 21.22756958], [73.8274765, 21.23314095], [73.83634949, 21.24234009], [73.83650208, 21.245821], [73.83223724, 21.25830269], [73.83213806, 21.26745033], [73.85840607, 21.26995087], [73.87174225, 21.26737976], [73.88432312, 21.26263046], [73.89199066, 21.26241112], [73.92354584, 21.28101921], [73.93358612, 21.28532982], [73.94848633, 21.2975502], [73.94992065, 21.30658913], [73.95015717, 21.30805016], [73.95127869, 21.31500816], [73.9519577, 21.33060074], [73.95700836, 21.3444519], [73.95658875, 21.36161041], [73.95530701, 21.37425995], [73.95562744, 21.39001083], [73.95284271, 21.40237045], [73.95545959, 21.4025383], [73.96193695, 21.39311028], [73.96869659, 21.39206123], [73.97193909, 21.39479828], [73.97741699, 21.39496994], [73.98155975, 21.39733124], [73.98529053, 21.40191078], [73.98883057, 21.40448952], [74.00547791, 21.4118309], [74.00765991, 21.41257286], [74.00949097, 21.41337013], [74.01107788, 21.4145298], [74.01251984, 21.41584015], [74.0140686, 21.41703033], [74.01579285, 21.41798019], [74.0177002, 21.41855812], [74.01959991, 21.41798019], [74.02133942, 21.4170208], [74.02332306, 21.41710091], [74.0252533, 21.41751099], [74.0271759, 21.41804123], [74.02908325, 21.41862106], [74.03098297, 21.41916084], [74.03292084, 21.41958046], [74.03491211, 21.41981125], [74.03690338, 21.41966057], [74.03885651, 21.41930008], [74.04081726, 21.41896057], [74.04280853, 21.41876984], [74.04479218, 21.41852951], [74.04679108, 21.41852188], [74.04854584, 21.41942978], [74.0496521, 21.42098045], [74.05046082, 21.42270088], [74.05110168, 21.42448997], [74.05162811, 21.42628098], [74.05208588, 21.42811012], [74.05251312, 21.42995071], [74.05285645, 21.4317894], [74.05316925, 21.43366051], [74.05343628, 21.43551064], [74.05371094, 21.4373703], [74.05396271, 21.43923187], [74.05417633, 21.44110107], [74.05426025, 21.44297028], [74.05432129, 21.44485092], [74.05444336, 21.44672966], [74.05471802, 21.44860077], [74.05513, 21.45041847], [74.05565643, 21.45223999], [74.05634308, 21.45399094], [74.05716705, 21.45570946], [74.0580368, 21.45738983], [74.05893707, 21.45907021], [74.05988312, 21.4607296], [74.06082916, 21.46236992], [74.0623703, 21.46508026], [74.0632782, 21.4667511], [74.06413269, 21.46842957], [74.06497192, 21.47014999], [74.06569672, 21.47190094], [74.06616974, 21.47372055], [74.06648254, 21.47557068], [74.06665802, 21.47744179], [74.06642914, 21.47930145], [74.06598663, 21.4811306], [74.06716156, 21.48193169], [74.06891632, 21.48106956], [74.07042694, 21.47986031], [74.07176971, 21.47845078], [74.07301331, 21.47698021], [74.07418823, 21.47546959], [74.07527161, 21.4738903], [74.07624054, 21.47224808], [74.07701111, 21.47051811], [74.07740021, 21.46867943], [74.07752228, 21.46681023], [74.07758331, 21.46494293], [74.07740784, 21.46305847], [74.0770874, 21.46121025], [74.07704926, 21.45934105], [74.07814789, 21.45781136], [74.08001709, 21.45720291], [74.08197784, 21.45684052], [74.08394623, 21.45652962], [74.08592224, 21.45625114], [74.08789825, 21.45597076], [74.0898819, 21.4557209], [74.09185791, 21.45548058], [74.09382629, 21.45524025], [74.09581757, 21.45500946], [74.09778595, 21.45474052], [74.09976959, 21.45449066], [74.10175323, 21.45420074], [74.10372925, 21.45388985], [74.10536194, 21.45293999], [74.10558319, 21.45108986], [74.10560608, 21.44922066], [74.106987, 21.44812012], [74.1089859, 21.44802284], [74.11097717, 21.44810104], [74.11297607, 21.44831085], [74.1149292, 21.44861031], [74.11688995, 21.44896126], [74.11885834, 21.4493084], [74.12081909, 21.4496994], [74.12245941, 21.45070076], [74.12290192, 21.45251274], [74.1228714, 21.45438004], [74.12269592, 21.45625114], [74.12255859, 21.45812988], [74.122612, 21.46000099], [74.12332916, 21.46170998], [74.12506104, 21.46267128], [74.12697601, 21.46320152], [74.12892151, 21.46352005], [74.1309433, 21.46367073], [74.13292694, 21.46370125], [74.13491058, 21.46360016], [74.1368866, 21.46339035], [74.13887024, 21.4630394], [74.14076996, 21.46249008], [74.14187622, 21.46099091], [74.14258575, 21.4577198], [74.14318085, 21.45593071], [74.14465332, 21.45471954], [74.14659119, 21.45428085], [74.14858246, 21.45409012], [74.1505661, 21.45388985], [74.15252686, 21.45360947], [74.15450287, 21.45334053], [74.15648651, 21.45313072], [74.15847015, 21.45308113], [74.16046906, 21.45335007], [74.16127777, 21.4549675], [74.16159821, 21.45683098], [74.16322327, 21.45759964], [74.1652298, 21.4574604], [74.16664124, 21.4586525], [74.16723633, 21.46044159], [74.16786957, 21.46222115], [74.16931915, 21.4634304], [74.17128754, 21.46371078], [74.17325592, 21.46352005], [74.17507172, 21.46273994], [74.17650604, 21.46145058], [74.1783371, 21.46087074], [74.18017578, 21.4615612], [74.18154907, 21.46291924], [74.18274689, 21.46442032], [74.18395996, 21.46590042], [74.18553925, 21.46702194], [74.18752289, 21.46702957], [74.1894989, 21.46681023], [74.19145203, 21.46636963], [74.19328308, 21.46562195], [74.19497681, 21.4646492], [74.19661713, 21.46355247], [74.19815063, 21.46236038], [74.19940186, 21.46090126], [74.20091248, 21.45969963], [74.20287323, 21.45944023], [74.20485687, 21.45959091], [74.20684052, 21.45988083], [74.2088089, 21.46014023], [74.21082306, 21.46018982], [74.21279144, 21.45998001], [74.21475983, 21.4596405], [74.21671295, 21.45927048], [74.21868896, 21.45895004], [74.22065735, 21.45877838], [74.22263336, 21.4589901], [74.22358704, 21.46056747], [74.22376251, 21.46241951], [74.22383118, 21.4643116], [74.22373199, 21.46618271], [74.22350311, 21.46805954], [74.22323608, 21.46990967], [74.22302246, 21.47178268], [74.22290039, 21.47365952], [74.22303009, 21.47552109], [74.22374725, 21.47726059], [74.22525024, 21.47846031], [74.22709656, 21.4791584], [74.22904968, 21.47960091], [74.23103333, 21.47982025], [74.23303223, 21.47986984], [74.23501587, 21.47970772], [74.23696136, 21.4792881], [74.23873138, 21.47841263], [74.24059296, 21.47555923], [74.24121094, 21.47376823], [74.24169922, 21.47195053], [74.24215698, 21.47013283], [74.24269104, 21.46831131], [74.24333191, 21.46653938], [74.24430084, 21.46491051], [74.24581909, 21.46370125], [74.24769592, 21.46310043], [74.24967194, 21.46286964], [74.2516861, 21.46286964], [74.25367737, 21.4630394], [74.25563812, 21.46333122], [74.25759125, 21.46375084], [74.2594986, 21.46426964], [74.26138306, 21.46491051], [74.26319122, 21.46570015], [74.26415253, 21.46729279], [74.26439667, 21.46915245], [74.26454926, 21.47101021], [74.26502991, 21.47284126], [74.26654053, 21.47402], [74.26837921, 21.47473907], [74.27028656, 21.47525024], [74.27224731, 21.47562027], [74.27423096, 21.47590065], [74.27620697, 21.4761219], [74.27819824, 21.47631073], [74.28018188, 21.47649956], [74.28217316, 21.47672081], [74.28414154, 21.47696114], [74.28613281, 21.47717285], [74.28811646, 21.4773407], [74.29013062, 21.47747993], [74.29210663, 21.4776001], [74.2940979, 21.47774124], [74.2960968, 21.47788048], [74.29807281, 21.4780407], [74.30005646, 21.47824097], [74.30204773, 21.47850037], [74.30400848, 21.47887039], [74.30591583, 21.4793911], [74.30776215, 21.48011971], [74.30943298, 21.48118019], [74.31057739, 21.48266029], [74.31125641, 21.48443985], [74.31173706, 21.48625946], [74.31236267, 21.48805809], [74.3134079, 21.48962021], [74.31497955, 21.49078178], [74.31678009, 21.49156952], [74.3187027, 21.49217033], [74.32061005, 21.4926796], [74.32253265, 21.49319267], [74.32443237, 21.4937706], [74.32624054, 21.49454117], [74.32772064, 21.49575043], [74.32821655, 21.4975605], [74.32859802, 21.49939919], [74.32907104, 21.50123024], [74.32950592, 21.50306129], [74.32995605, 21.50488281], [74.33039093, 21.50672913], [74.33082581, 21.50855064], [74.33125305, 21.51037979], [74.33165741, 21.51222992], [74.3320694, 21.51402092], [74.33335876, 21.51980972], [74.33551788, 21.5402298], [74.33274078, 21.54116058], [74.33164978, 21.54117966], [74.33065033, 21.54117966], [74.32962036, 21.54116058], [74.32861328, 21.54115105], [74.32762146, 21.54112053], [74.32727051, 21.54112053], [74.32659149, 21.54111099], [74.32559204, 21.54109955], [74.32457733, 21.54111099], [74.32406616, 21.54112053], [74.32357788, 21.54113007], [74.32260895, 21.54117966], [74.32161713, 21.54125023], [74.32064819, 21.54137039], [74.31968689, 21.54152107], [74.31867218, 21.54175949], [74.31764984, 21.54211998], [74.31665802, 21.54259109], [74.31581879, 21.54317093], [74.31520081, 21.54385948], [74.31484985, 21.54466248], [74.31461334, 21.54551125], [74.31443024, 21.54636955], [74.31430054, 21.54726982], [74.3141861, 21.54818153], [74.31410217, 21.54911995], [74.3140564, 21.55006981], [74.31404877, 21.55055046], [74.31402588, 21.55103111], [74.31401825, 21.55200958], [74.31401062, 21.55298042], [74.31401062, 21.55395126], [74.3139801, 21.5549202], [74.31391144, 21.55589104], [74.31387329, 21.55655289], [74.3138504, 21.55685043], [74.31378174, 21.55779266], [74.31369781, 21.55828285], [74.31363678, 21.55871964], [74.31346893, 21.55965042], [74.3132782, 21.56056023], [74.3130188, 21.56149101], [74.3127594, 21.56240082], [74.31246185, 21.56328964], [74.31212616, 21.56417084], [74.31175995, 21.56507111], [74.31127167, 21.56604958], [74.31066895, 21.56688118], [74.30996704, 21.56732178], [74.30909729, 21.56732178], [74.30805969, 21.56705284], [74.30706024, 21.56656265], [74.30623627, 21.56595993], [74.30568695, 21.56520081], [74.30532837, 21.56429291], [74.30523682, 21.56398964], [74.30504608, 21.56328011], [74.30478668, 21.5622406], [74.30451202, 21.56126976], [74.30409241, 21.56043053], [74.30354309, 21.55982018], [74.30275726, 21.55945969], [74.30190277, 21.55922127], [74.30095673, 21.55909157], [74.30052185, 21.55906105], [74.29995728, 21.55903244], [74.29892731, 21.55901909], [74.29785156, 21.55904007], [74.29677582, 21.55909157], [74.29633331, 21.55912018], [74.2957077, 21.55912971], [74.29516602, 21.55912971], [74.29464722, 21.55914116], [74.29360962, 21.55909157], [74.2926178, 21.55898094], [74.2917099, 21.55878067], [74.29103088, 21.55817032], [74.29052734, 21.55725288], [74.2899704, 21.55641174], [74.28916931, 21.5559597], [74.28819275, 21.55574989], [74.28713226, 21.55562973], [74.28656006, 21.55549049], [74.28617096, 21.55540085], [74.28534698, 21.5549202], [74.28460693, 21.55428123], [74.28396606, 21.5535202], [74.28343201, 21.55270958], [74.28327179, 21.552351], [74.28305817, 21.55185127], [74.28292084, 21.5508194], [74.28282166, 21.54981041], [74.2824173, 21.54906845], [74.28163147, 21.54868126], [74.28063202, 21.54850006], [74.27951813, 21.54841995], [74.27839661, 21.54833031], [74.27735138, 21.54816818], [74.27651215, 21.54780006], [74.27590942, 21.54718018], [74.2754364, 21.54639053], [74.27501678, 21.54552078], [74.27469635, 21.54455948], [74.27440643, 21.54356956], [74.27413177, 21.5425396], [74.27387238, 21.54150009], [74.27361298, 21.5404911], [74.27332306, 21.53950119], [74.27297974, 21.5385685], [74.27258301, 21.53775024], [74.27211761, 21.53701973], [74.27155304, 21.53642082], [74.27086639, 21.53597069], [74.27011108, 21.53563118], [74.26924133, 21.53536987], [74.26834106, 21.53517914], [74.26737213, 21.53507042], [74.26638031, 21.53499985], [74.26535034, 21.53499031], [74.26426697, 21.53502083], [74.26368713, 21.53507042], [74.26319122, 21.53510094], [74.26209259, 21.53520012], [74.26098633, 21.53534126], [74.25992584, 21.5354805], [74.2588501, 21.53564072], [74.2578125, 21.53580093], [74.25679779, 21.53595161], [74.25583649, 21.53611946], [74.25496674, 21.53646088], [74.25414276, 21.53701019], [74.25335693, 21.53770065], [74.25267029, 21.53844261], [74.25197601, 21.53915024], [74.25138092, 21.53989983], [74.25078583, 21.54068947], [74.25025177, 21.54150963], [74.24970245, 21.54232979], [74.24936676, 21.54282951], [74.24916077, 21.54314041], [74.2485733, 21.54391289], [74.24796295, 21.54462051], [74.24732208, 21.5452404], [74.24646759, 21.54561043], [74.24539185, 21.54556274], [74.24429321, 21.54549026], [74.2434082, 21.54574013], [74.24279022, 21.54640961], [74.24237061, 21.54730988], [74.24194336, 21.54829979], [74.24147797, 21.54919815], [74.24125671, 21.54951286], [74.24093628, 21.54989815], [74.24017334, 21.5502491], [74.23919678, 21.55029106], [74.23810577, 21.5501194], [74.23705292, 21.54985046], [74.23668671, 21.54976082], [74.23607635, 21.54959106], [74.23506927, 21.54924011], [74.23406982, 21.54883957], [74.23323822, 21.54833031], [74.23258972, 21.54771996], [74.23246765, 21.54737091], [74.23232269, 21.54691124], [74.2323761, 21.54588127], [74.2325058, 21.54482079], [74.2325058, 21.54387093], [74.23233032, 21.54356194], [74.23213196, 21.54322052], [74.23111725, 21.54305077], [74.22994995, 21.54304123], [74.22910309, 21.54269981], [74.22875977, 21.54187965], [74.22866058, 21.5408802], [74.22856903, 21.53982162], [74.22834015, 21.53890038], [74.2277832, 21.53827095], [74.2269516, 21.53787994], [74.22595215, 21.53762054], [74.2248764, 21.53745079], [74.22383118, 21.53730965], [74.22283173, 21.53716087], [74.2218399, 21.53707123], [74.22077942, 21.53703117], [74.21974182, 21.53698921], [74.21869659, 21.53693962], [74.21820831, 21.53689957], [74.21769714, 21.53685188], [74.21673584, 21.5367012], [74.21586609, 21.53647041], [74.21514893, 21.53600121], [74.21478271, 21.53508949], [74.21444702, 21.53405952], [74.21386719, 21.53334999], [74.21304321, 21.53293037], [74.21208954, 21.53261948], [74.21108246, 21.53236008], [74.21054077, 21.53222084], [74.21009064, 21.53211021], [74.20915222, 21.53178024], [74.20897675, 21.53168106], [74.20831299, 21.53128052], [74.20797729, 21.5309124], [74.20762634, 21.53050995], [74.20726013, 21.53009987], [74.2069397, 21.52975082], [74.20617676, 21.52930069], [74.20523834, 21.52921104], [74.204216, 21.52924919], [74.20314789, 21.52939034], [74.20211792, 21.52963066], [74.20115662, 21.5299511], [74.20030975, 21.53033829], [74.19969177, 21.53100014], [74.19930267, 21.53193855], [74.19901276, 21.53290939], [74.19890594, 21.53342056], [74.19882965, 21.53383064], [74.1987915, 21.53420067], [74.19873047, 21.53475952], [74.19869995, 21.5352211], [74.19866943, 21.53570938], [74.19860077, 21.5366497], [74.19850159, 21.53759956], [74.19831848, 21.53849983], [74.19801331, 21.53938103], [74.19758606, 21.5402298], [74.19711304, 21.54107285], [74.19654083, 21.54186058], [74.19595337, 21.54261971], [74.19532013, 21.54334068], [74.19464111, 21.54402924], [74.19391632, 21.54470825], [74.1932373, 21.5453701], [74.19251251, 21.54603958], [74.19184875, 21.54673958], [74.19122314, 21.54746819], [74.19068146, 21.54823112], [74.19011688, 21.54902267], [74.18961334, 21.54982758], [74.18933105, 21.55027962], [74.18910217, 21.55065918], [74.18863678, 21.55150032], [74.18821716, 21.552351], [74.18782806, 21.55321121], [74.18750763, 21.55409813], [74.18736267, 21.55505943], [74.18725586, 21.5560627], [74.18718719, 21.55706024], [74.18704987, 21.5580101], [74.1867981, 21.55887032], [74.18634033, 21.55960083], [74.18569183, 21.56021118], [74.18483734, 21.5607605], [74.18387604, 21.56121063], [74.18286896, 21.56155968], [74.18183136, 21.56176949], [74.18081665, 21.56183815], [74.17984772, 21.56183052], [74.17888641, 21.56182098], [74.1778717, 21.56178093], [74.17687988, 21.56175041], [74.1758728, 21.56167984], [74.17485809, 21.56161118], [74.17383575, 21.56153107], [74.17282104, 21.56142807], [74.17182159, 21.56132126], [74.17079926, 21.56118011], [74.17034149, 21.56112099], [74.1697998, 21.56104279], [74.16945648, 21.56098938], [74.16879272, 21.56088066], [74.1678009, 21.56072044], [74.16681671, 21.56052971], [74.16584778, 21.5603199], [74.16488647, 21.56010056], [74.16394806, 21.55986023], [74.16301727, 21.55960083], [74.16213989, 21.55927086], [74.16133118, 21.55875969], [74.16057587, 21.55813026], [74.15988922, 21.55741119], [74.15921021, 21.55665016], [74.15854645, 21.55587959], [74.15789795, 21.55517006], [74.15735626, 21.55438042], [74.15686035, 21.5535202], [74.15632629, 21.55273056], [74.15563965, 21.55212975], [74.15473938, 21.55171967], [74.1537323, 21.55143166], [74.15276337, 21.55122948], [74.15180206, 21.55105019], [74.15078735, 21.5508709], [74.14980316, 21.55070114], [74.14879608, 21.55056953], [74.14782715, 21.55045128], [74.14681244, 21.55038071], [74.14582825, 21.55034065], [74.14483643, 21.55034065], [74.14444733, 21.55035973], [74.14380646, 21.55038071], [74.14274597, 21.55046082], [74.14170074, 21.55060959], [74.14071655, 21.55085945], [74.13983917, 21.5512104], [74.13910675, 21.55173111], [74.1385498, 21.55251122], [74.13809967, 21.55348015], [74.1377182, 21.55450058], [74.13729858, 21.55548096], [74.13677216, 21.55623055], [74.13609314, 21.55669975], [74.1352005, 21.55688095], [74.13430786, 21.55698013], [74.13334656, 21.55702972], [74.13288116, 21.55701828], [74.13240051, 21.55701828], [74.13143921, 21.5569706], [74.13041687, 21.55689049], [74.12940979, 21.5567894], [74.12840271, 21.55665016], [74.12734985, 21.55649948], [74.12631989, 21.55636024], [74.12526703, 21.55622101], [74.1242218, 21.55607986], [74.12319183, 21.55598068], [74.12216949, 21.55590057], [74.12114716, 21.55584908], [74.12016296, 21.55586052], [74.11917114, 21.55590057], [74.11821747, 21.55615044], [74.11728668, 21.55652809], [74.11637115, 21.5569706], [74.11546326, 21.55744171], [74.11453247, 21.55783081], [74.11358643, 21.55809975], [74.11260986, 21.55815125], [74.11160278, 21.55815125], [74.11062622, 21.55813026], [74.10964203, 21.55811119], [74.10913849, 21.55808067], [74.10864258, 21.55804825], [74.10813904, 21.55801964], [74.10765839, 21.55798912], [74.10665894, 21.55792236], [74.10566711, 21.55784035], [74.10463715, 21.55774117], [74.10367584, 21.55763817], [74.10264587, 21.55754089], [74.10166931, 21.55742836], [74.10064697, 21.55731964], [74.09966278, 21.55721092], [74.09866333, 21.5571003], [74.09764862, 21.55700111], [74.0966568, 21.55690956], [74.09564972, 21.55682182], [74.0946579, 21.55673981], [74.09416199, 21.5567112], [74.09365082, 21.55668259], [74.09321594, 21.55665016], [74.09266663, 21.55661964], [74.09168243, 21.55657959], [74.09068298, 21.55655289], [74.08970642, 21.55656052], [74.08914185, 21.55657005], [74.08872223, 21.55657005], [74.08776855, 21.55677032], [74.08683014, 21.55714035], [74.08592987, 21.55758286], [74.08522797, 21.5579319], [74.08502197, 21.55804062], [74.08407593, 21.55842972], [74.08315277, 21.55869293], [74.08216095, 21.5588398], [74.08117676, 21.5589695], [74.08019257, 21.55907822], [74.07920837, 21.55919075], [74.07818604, 21.55927086], [74.07727051, 21.55933952], [74.07621002, 21.55941963], [74.07518768, 21.55945969], [74.07483673, 21.55948067], [74.07418823, 21.55949974], [74.07367706, 21.55952263], [74.07318115, 21.55953026], [74.07285309, 21.55953026], [74.07218933, 21.55953979], [74.07118988, 21.55953979], [74.07019043, 21.55953979], [74.06978607, 21.55953026], [74.06920624, 21.55950928], [74.06822205, 21.55937195], [74.06723022, 21.55914116], [74.06626892, 21.55886078], [74.06534576, 21.55852127], [74.06440735, 21.55817986], [74.06349945, 21.55779266], [74.06260681, 21.55738068], [74.0617218, 21.55695152], [74.06082916, 21.55652046], [74.05993652, 21.5560894], [74.05905914, 21.55568123], [74.0542984, 21.5521698], [74.04714966, 21.54968071], [74.04168701, 21.55134964], [74.02555847, 21.55261993], [74.0190506, 21.55051041], [74.00534058, 21.54076958], [73.98352051, 21.54204178], [73.98178864, 21.53977013], [73.98252106, 21.53573036], [73.9875412, 21.52240944], [73.98568726, 21.5213604], [73.98219299, 21.5218029], [73.97445679, 21.52408028], [73.97335815, 21.53141022], [73.96985626, 21.5385685], [73.96631622, 21.53907013], [73.96276093, 21.53787994], [73.96111298, 21.51929855], [73.95728302, 21.51647186], [73.95358276, 21.51580048], [73.93940735, 21.51011086], [73.93762207, 21.5206604], [73.93614197, 21.52244949], [73.93377686, 21.52359009], [73.93099213, 21.52299118], [73.92839813, 21.52062988], [73.9260788, 21.51959991], [73.91047668, 21.52017021], [73.91004944, 21.51330185], [73.9036026, 21.50875282], [73.89707184, 21.50604248], [73.8866272, 21.50468063], [73.88256836, 21.50978279], [73.88020325, 21.5078907], [73.87684631, 21.50118828], [73.87030029, 21.49725914], [73.86078644, 21.49582291], [73.85401154, 21.50726128], [73.84989166, 21.51098061], [73.84503174, 21.5215683], [73.84015656, 21.5369091], [73.83376312, 21.55348015], [73.82905579, 21.57295036], [73.82450104, 21.59828949], [73.82315063, 21.6006794], [73.81845093, 21.60233116], [73.80683899, 21.60237122], [73.79057312, 21.61850929], [73.78952789, 21.62091064], [73.78761292, 21.62504959], [73.79086304, 21.6287899], [73.80013275, 21.63463974], [73.80882263, 21.63571167], [73.8290329, 21.63978958], [73.83854675, 21.63537979], [73.84523773, 21.63315964], [73.8530426, 21.63586998], [73.86025238, 21.64184761], [73.87026978, 21.63879013], [73.88562775, 21.64505959], [73.89126587, 21.65151024], [73.89444733, 21.6570797], [73.89810181, 21.66727066], [73.8963623, 21.70028114], [73.89396667, 21.70314026], [73.8902359, 21.71064949], [73.88504791, 21.71442986], [73.8783493, 21.71693039], [73.87123108, 21.72191811], [73.86511993, 21.72937965], [73.86029816, 21.73301125], [73.85633087, 21.73464012], [73.84635925, 21.74200058], [73.83120728, 21.76288986], [73.84129333, 21.76865005], [73.84294891, 21.77213097], [73.83837891, 21.7841301], [73.8441391, 21.78711128], [73.84496307, 21.79068184], [73.83567047, 21.79347992], [73.83421326, 21.79661179], [73.83893585, 21.8001709], [73.83351898, 21.80516052], [73.83210754, 21.81085014], [73.82759857, 21.81193924], [73.81759644, 21.80850029], [73.81356812, 21.81011963], [73.81051636, 21.82333755], [73.8162384, 21.82856941], [73.82792664, 21.83485985], [73.84152222, 21.83850098], [73.86374664, 21.83665085], [73.87960052, 21.83864021], [73.89951324, 21.85449028], [73.90666962, 21.85363007], [73.92192841, 21.85658264], [73.93636322, 21.86314964], [73.9491806, 21.87034035], [73.9608078, 21.87599182], [73.97973633, 21.88750076], [74.00489044, 21.89936066], [74.01168823, 21.9005394], [74.02304077, 21.90597153], [74.03560638, 21.9160099], [74.04666901, 21.9228096], [74.056427, 21.92641068], [74.06162262, 21.92805099], [74.07151031, 21.92960167], [74.09867096, 21.9376297], [74.11364746, 21.94470024], [74.13816071, 21.95337105], [74.14601898, 21.9540596], [74.14702606, 21.95404053], [74.14803314, 21.95404053], [74.14904022, 21.95403099], [74.15003204, 21.95401001], [74.15101624, 21.95396042], [74.15202332, 21.95386124], [74.15302277, 21.95369911], [74.15400696, 21.95356941], [74.15500641, 21.95334816], [74.15598297, 21.95310974], [74.15692139, 21.95280075], [74.1578064, 21.95240974], [74.15872192, 21.95201111], [74.15962219, 21.95158958], [74.1605072, 21.95116997], [74.16140747, 21.95074081], [74.16226959, 21.95030022], [74.16316223, 21.94985008], [74.16404724, 21.94939995], [74.16490936, 21.94893837], [74.16578674, 21.94846153], [74.16665649, 21.94800949], [74.16752625, 21.94752121], [74.168396, 21.94704056], [74.16924286, 21.94655037], [74.17011261, 21.94608116], [74.17095184, 21.94557953], [74.17179108, 21.94509125], [74.17260742, 21.94454956], [74.17343903, 21.94398117], [74.17418671, 21.94338036], [74.17494202, 21.94273186], [74.17563629, 21.94205284], [74.17624664, 21.9413414], [74.17681122, 21.94055939], [74.17735291, 21.93976021], [74.1778717, 21.93894958], [74.1783905, 21.93814087], [74.17893219, 21.93735123], [74.17952728, 21.93661118], [74.18016052, 21.93588066], [74.18080902, 21.93514061], [74.18144226, 21.93439102], [74.18206787, 21.93365097], [74.18273163, 21.93292046], [74.18341827, 21.93219948], [74.18408966, 21.93151093], [74.18480682, 21.93084145], [74.18554688, 21.93022156], [74.18630981, 21.92963982], [74.18708801, 21.92910767], [74.18792725, 21.92864037], [74.18882751, 21.92822266], [74.18974304, 21.92790031], [74.19069672, 21.92760277], [74.19169617, 21.92733955], [74.19268799, 21.92711067], [74.19367981, 21.92690086], [74.19467926, 21.92671013], [74.19567108, 21.92651939], [74.1966629, 21.9263382], [74.19763947, 21.92613983], [74.19863129, 21.92597008], [74.19962311, 21.92580032], [74.20063782, 21.92564964], [74.20163727, 21.92552948], [74.20262146, 21.92543983], [74.20362091, 21.92539978], [74.20464325, 21.92541122], [74.20561981, 21.92547035], [74.20658875, 21.92557907], [74.20758057, 21.92571831], [74.20855713, 21.9258709], [74.20952606, 21.92605972], [74.21051788, 21.92624092], [74.21147919, 21.92645073], [74.21246338, 21.92666054], [74.21343231, 21.92687988], [74.21440887, 21.92712021], [74.21539307, 21.92736053], [74.21636963, 21.92759132], [74.21733093, 21.92784119], [74.2183075, 21.92809105], [74.21927643, 21.92831993], [74.22026825, 21.92855072], [74.22122955, 21.9287796], [74.22219849, 21.92900085], [74.22319031, 21.92920113], [74.22416687, 21.92941284], [74.2251358, 21.92958832], [74.22614288, 21.92975998], [74.22709656, 21.92990112], [74.22809601, 21.93000984], [74.22908783, 21.93004036], [74.23008728, 21.93001938], [74.23108673, 21.92996025], [74.23208618, 21.92988014], [74.23310852, 21.92978096], [74.23412323, 21.92970085], [74.23510742, 21.92963982], [74.23610687, 21.92963028], [74.23710632, 21.9296608], [74.23809052, 21.92975998], [74.2390976, 21.92987061], [74.24009705, 21.92999077], [74.24108124, 21.93011093], [74.24208069, 21.93025017], [74.24304199, 21.9303894], [74.24402618, 21.93053055], [74.24503326, 21.93069077], [74.24603271, 21.93084145], [74.24700165, 21.9310112], [74.24798584, 21.93117905], [74.2489624, 21.93134117], [74.24994659, 21.93149948], [74.25093079, 21.93168259], [74.25193024, 21.93182945], [74.2529068, 21.93200111], [74.25390625, 21.93214989], [74.25489044, 21.9323101], [74.255867, 21.93244171], [74.25686646, 21.93259048], [74.25785828, 21.93272972], [74.25885773, 21.93285179], [74.25985718, 21.93296051], [74.26085663, 21.93307114], [74.26183319, 21.93317032], [74.26284027, 21.9332695], [74.26383972, 21.93336105], [74.26483154, 21.93344116], [74.26584625, 21.93352127], [74.26685333, 21.93359756], [74.26786041, 21.93366814], [74.26888275, 21.93374062], [74.26988983, 21.93380928], [74.27086639, 21.93388176], [74.27189636, 21.93394089], [74.27288818, 21.93401909], [74.27390289, 21.93409157], [74.27490997, 21.93416023], [74.27591705, 21.9342308], [74.2769165, 21.93429947], [74.27793121, 21.93437958], [74.27893066, 21.93445969], [74.27992249, 21.93455124], [74.28092194, 21.93464088], [74.28190613, 21.93474007], [74.28291321, 21.93483925], [74.2838974, 21.93494987], [74.28486633, 21.93507957], [74.2858429, 21.93518829], [74.28681946, 21.93534279], [74.28779602, 21.93548012], [74.28874969, 21.9356308], [74.289711, 21.93579102], [74.29064941, 21.93605995], [74.29148865, 21.93658257], [74.29225922, 21.93725014], [74.29290771, 21.93806076], [74.29345703, 21.93888092], [74.29387665, 21.93970108], [74.29425812, 21.94055939], [74.29454803, 21.94145012], [74.29480743, 21.94236755], [74.29502106, 21.94330025], [74.29521179, 21.94425011], [74.29538727, 21.94518089], [74.29559326, 21.94609833], [74.2957077, 21.94703293], [74.29585266, 21.94795036], [74.29593658, 21.94889069], [74.29603577, 21.9498291], [74.29611969, 21.95075989], [74.29621124, 21.9516983], [74.29631042, 21.952631], [74.29641724, 21.95356941], [74.29656982, 21.95449066], [74.29677582, 21.95540047], [74.29696655, 21.95631027], [74.29721069, 21.95721817], [74.29749298, 21.95813179], [74.29776001, 21.95903015], [74.29808044, 21.95992088], [74.2984314, 21.96081924], [74.29875946, 21.9616909], [74.29910278, 21.96257019], [74.29947662, 21.96344948], [74.29987335, 21.96433067], [74.3003006, 21.9652195], [74.30079651, 21.9660511], [74.30136108, 21.96680069], [74.3020401, 21.96743965], [74.30280304, 21.96804047], [74.30358887, 21.9686203], [74.30439758, 21.96917915], [74.30523682, 21.96972084], [74.30610657, 21.97022057], [74.30699921, 21.97068977], [74.3079071, 21.97113037], [74.30883026, 21.97151947], [74.30976105, 21.97186089], [74.31067657, 21.9721508], [74.31165314, 21.97240067], [74.31260681, 21.9726181], [74.31356812, 21.97281075], [74.31455231, 21.97296906], [74.31555176, 21.97310066], [74.31655121, 21.97323036], [74.31755829, 21.97333145], [74.318573, 21.9734211], [74.31958008, 21.97352028], [74.32058716, 21.97359085], [74.32158661, 21.97364998], [74.32260132, 21.97372818], [74.32359314, 21.97383118], [74.32459259, 21.97392082], [74.32557678, 21.97397995], [74.3265686, 21.97405052], [74.32758331, 21.97412109], [74.32858276, 21.97417259], [74.32958984, 21.97421837], [74.33058167, 21.97426987], [74.33158875, 21.97431946], [74.33258057, 21.97437286], [74.33360291, 21.97441101], [74.3345871, 21.97445107], [74.33557892, 21.97451019], [74.33660126, 21.97455025], [74.33757782, 21.97459984], [74.33859253, 21.97466278], [74.33957672, 21.97470856], [74.34057617, 21.97477913], [74.34158325, 21.97486115], [74.3425827, 21.97492027], [74.34358215, 21.97500992], [74.34455109, 21.97509956], [74.34555817, 21.97521973], [74.3465271, 21.97541046], [74.34749603, 21.97565079], [74.34844971, 21.97599983], [74.3493576, 21.97639084], [74.35024261, 21.97682953], [74.35114288, 21.97729111], [74.35202026, 21.97774124], [74.35289764, 21.97821045], [74.35378265, 21.9786911], [74.35463715, 21.97919846], [74.35546112, 21.97972107], [74.35626221, 21.98028946], [74.35700989, 21.98088074], [74.35775757, 21.98151016], [74.35842133, 21.98220062], [74.35901642, 21.98291969], [74.35962677, 21.98368073], [74.36019135, 21.98446274], [74.36074829, 21.98526001], [74.36126709, 21.98608017], [74.36180878, 21.98689079], [74.36235046, 21.98769951], [74.36286926, 21.9885006], [74.36342621, 21.98929024], [74.36400604, 21.99003983], [74.36463928, 21.9907608], [74.36531067, 21.99144173], [74.3660202, 21.99204063], [74.36685181, 21.99253082], [74.36778259, 21.99291039], [74.36875916, 21.99324989], [74.36974335, 21.99356842], [74.37069702, 21.99391937], [74.37159729, 21.9943428], [74.37238312, 21.99487114], [74.37310791, 21.99549103], [74.37375641, 21.99618912], [74.37438202, 21.9969101], [74.37496185, 21.99767113], [74.37552643, 21.99843979], [74.37609863, 21.99925041], [74.37664032, 22.00004005], [74.37718964, 22.00085068], [74.37818146, 22.00217056], [74.38366699, 22.01175117], [74.38831329, 22.02017975], [74.3964386, 22.02370262], [74.40651703, 22.02440071], [74.4177475, 22.02581024], [74.43554688, 22.03099823], [74.43945313, 22.02651978], [74.44603729, 22.02651978], [74.44255829, 22.02160072], [74.44451904, 22.01599121], [74.44764709, 22.01247978], [74.45150757, 22.00896835], [74.45381927, 22.00617027], [74.45391846, 22.00226974], [74.44995117, 22.00546265], [74.44573212, 22.0068512], [74.44380951, 22.00616074], [74.43621826, 22.00222969], [74.4362793, 21.9994812], [74.44107819, 21.99644089], [74.44262695, 21.99362946], [74.44303894, 21.98306847], [74.4471817, 21.97627068], [74.44863892, 21.97113037], [74.45170593, 21.96750069], [74.45996857, 21.9628315], [74.4641571, 21.96321106], [74.4673233, 21.96479988], [74.47218323, 21.96552086], [74.47512054, 21.96270943], [74.4778595, 21.96154976], [74.48293304, 21.96244049], [74.48449707, 21.96075058], [74.48568726, 21.95753288], [74.48928833, 21.95676041], [74.49340057, 21.95449066], [74.48985291, 21.94714928], [74.49233246, 21.94546127], [74.4967804, 21.94641113], [74.51555634, 21.93391991], [74.51560974, 21.9278717], [74.51464081, 21.92246819], [74.51735687, 21.91755104], [74.52398682, 21.91306114], [74.52749634, 21.90878105], [74.52746582, 21.90345001], [74.52146912, 21.89550972], [74.51843262, 21.89011002], [74.51776123, 21.88624001], [74.51747894, 21.87490082], [74.51699829, 21.85649109], [74.51181793, 21.82122993], [74.50932312, 21.81587982], [74.50364685, 21.80718231], [74.50315857, 21.79780006], [74.50596619, 21.78260994], [74.5063324, 21.78174019], [74.50665283, 21.78083038], [74.50695801, 21.77993965], [74.50728607, 21.77902985], [74.50763702, 21.77814102], [74.50800323, 21.77726936], [74.50840759, 21.77642822], [74.50888062, 21.77561951], [74.50946045, 21.77490807], [74.51021576, 21.77427101], [74.51101685, 21.77370071], [74.51185608, 21.77312088], [74.51257324, 21.77247047], [74.51320648, 21.77176094], [74.51393127, 21.77103043], [74.51463318, 21.77030945], [74.51529694, 21.7695694], [74.51596832, 21.76880074], [74.5165329, 21.76803017], [74.51700592, 21.76723099], [74.51735687, 21.76639938], [74.51759338, 21.76554108], [74.51773071, 21.76463127], [74.51786041, 21.76370811], [74.51789856, 21.76276016], [74.51790619, 21.76178932], [74.5178833, 21.76083183], [74.51780701, 21.75987053], [74.51769257, 21.75889969], [74.5175705, 21.75794029], [74.51740265, 21.75699997], [74.51721191, 21.75608063], [74.51700592, 21.75518036], [74.5166626, 21.75435066], [74.51599121, 21.75361061], [74.51516724, 21.75293922], [74.51436615, 21.75226021], [74.51378632, 21.75152969], [74.51352692, 21.75069046], [74.51348877, 21.74981117], [74.51354218, 21.7489109], [74.51365662, 21.74798012], [74.51386261, 21.74703979], [74.51407623, 21.74608994], [74.51426697, 21.74513054], [74.51447296, 21.74416924], [74.51461792, 21.74323082], [74.5147171, 21.74228096], [74.5147171, 21.74135017], [74.51463318, 21.74043083], [74.51447296, 21.73950958], [74.51425934, 21.73858261], [74.51403809, 21.7376709], [74.5137558, 21.73676109], [74.51348877, 21.73582268], [74.51317596, 21.73490906], [74.51286316, 21.73398018], [74.51255798, 21.73307991], [74.51226807, 21.73216248], [74.51197815, 21.73125076], [74.51174927, 21.73033905], [74.51152039, 21.72944069], [74.51135254, 21.72854805], [74.51125336, 21.72764969], [74.51122284, 21.72674942], [74.51138306, 21.72585106], [74.5117569, 21.72495079], [74.51226044, 21.72409058], [74.51288605, 21.72326088], [74.51352692, 21.72253036], [74.51422119, 21.72187996], [74.5149765, 21.72128105], [74.51583862, 21.72076035], [74.516716, 21.72029114], [74.51763153, 21.71986961], [74.51854706, 21.71947098], [74.51947784, 21.71911049], [74.52041626, 21.71879005], [74.52139282, 21.71850967], [74.5223465, 21.7182827], [74.52333832, 21.71808052], [74.52433014, 21.7179184], [74.5253067, 21.71780968], [74.52630615, 21.71772194], [74.52731323, 21.71763039], [74.52832031, 21.7175827], [74.52929688, 21.71754074], [74.53031921, 21.71747971], [74.53131866, 21.71747017], [74.53231049, 21.71747017], [74.53333282, 21.71749115], [74.53431702, 21.71754074], [74.53530884, 21.7175827], [74.53631592, 21.71769905], [74.53734589, 21.71787071], [74.53839111, 21.71809006], [74.53943634, 21.71832848], [74.54049683, 21.71861076], [74.54155731, 21.7188797], [74.5426178, 21.71915054], [74.54366302, 21.71940994], [74.5446701, 21.71965027], [74.54567719, 21.71982956], [74.54664612, 21.7199707], [74.54762268, 21.72002983], [74.54852295, 21.72002983], [74.54940033, 21.7199192], [74.55020142, 21.71970749], [74.55098724, 21.71939278], [74.55171967, 21.71894836], [74.55237579, 21.71839905], [74.55303192, 21.71774101], [74.55362701, 21.71701813], [74.55417633, 21.71623039], [74.55471039, 21.71537018], [74.55522919, 21.71447945], [74.55573273, 21.71355057], [74.55621338, 21.71261024], [74.55667877, 21.71166992], [74.55713654, 21.71073914], [74.55760956, 21.70984077], [74.55806732, 21.70898056], [74.55856323, 21.7081604], [74.55903625, 21.70730972], [74.55948639, 21.70646286], [74.55989838, 21.70560074], [74.56024933, 21.70470047], [74.56056976, 21.7038002], [74.56079865, 21.7028904], [74.56096649, 21.70198059], [74.5610733, 21.7010498], [74.56115723, 21.70012093], [74.56124878, 21.69915962], [74.5613327, 21.69820023], [74.56137848, 21.69722939], [74.56141663, 21.69627953], [74.5614624, 21.69530106], [74.56147003, 21.69433975], [74.56143951, 21.69338989], [74.56137848, 21.69244194], [74.56130981, 21.69151115], [74.56121063, 21.69059944], [74.56105804, 21.68970108], [74.56086731, 21.68882751], [74.56054688, 21.68799019], [74.55977631, 21.68729019], [74.55877686, 21.68667984], [74.55773926, 21.68610954], [74.5569458, 21.68555069], [74.55661011, 21.68494034], [74.55680084, 21.68425941], [74.55729675, 21.68353271], [74.55800629, 21.68279076], [74.55887604, 21.68208122], [74.55980682, 21.68143082], [74.56072998, 21.68086052], [74.56160736, 21.68042183], [74.5626297, 21.68008995], [74.56371307, 21.67990112], [74.56476593, 21.67984962], [74.56569672, 21.67996025], [74.56626129, 21.68045044], [74.56636047, 21.68153954], [74.56652069, 21.68259811], [74.56726074, 21.68302917], [74.56813812, 21.68332291], [74.56906128, 21.68357086], [74.57000732, 21.68380165], [74.57099152, 21.68399048], [74.57200623, 21.68416023], [74.57302094, 21.68431091], [74.5740509, 21.68443108], [74.57507324, 21.68456268], [74.57611847, 21.68466949], [74.57713318, 21.68478012], [74.57814026, 21.68486977], [74.5791626, 21.68499947], [74.58027649, 21.68514061], [74.58141327, 21.68527031], [74.58248901, 21.68527985], [74.58345032, 21.68513107], [74.58416748, 21.68474007], [74.58470154, 21.68412018], [74.5851593, 21.68338013], [74.58557129, 21.68254089], [74.58589935, 21.68163109], [74.5861969, 21.68066025], [74.58644104, 21.6796627], [74.58661652, 21.67865944], [74.58677673, 21.6776619], [74.58689117, 21.67670059], [74.58693695, 21.67579269], [74.58670044, 21.67485809], [74.58627319, 21.67391968], [74.58579254, 21.67300034], [74.58547211, 21.6721096], [74.58545685, 21.67124939], [74.58574677, 21.67041016], [74.58615112, 21.66953087], [74.58657074, 21.66862106], [74.58708954, 21.66772079], [74.587677, 21.66683006], [74.58831024, 21.66601944], [74.58899689, 21.66526985], [74.58976746, 21.66464806], [74.59055328, 21.66415977], [74.59140778, 21.66383171], [74.59227753, 21.66358948], [74.59319305, 21.66340828], [74.5941391, 21.66328049], [74.59509277, 21.66321182], [74.59607697, 21.66316986], [74.59709167, 21.66316986], [74.59809875, 21.66319847], [74.59913635, 21.6632309], [74.60018921, 21.66328049], [74.60122681, 21.66332817], [74.60227966, 21.66337967], [74.60330963, 21.66341972], [74.60434723, 21.66343117], [74.6053772, 21.66341972], [74.60639954, 21.66337967], [74.60742188, 21.66328049], [74.60839844, 21.66315269], [74.60939026, 21.66299057], [74.61036682, 21.66282082], [74.61134338, 21.66263008], [74.61231232, 21.66246033], [74.61329651, 21.66226006], [74.61427307, 21.66205025], [74.615242, 21.66184044], [74.61621094, 21.66163063], [74.61717987, 21.66139984], [74.61814117, 21.66118813], [74.619133, 21.66094971], [74.62008667, 21.66070747], [74.62106323, 21.66047096], [74.62201691, 21.66023064], [74.6230011, 21.65999985], [74.6239624, 21.65975952], [74.62494659, 21.6595211], [74.6259079, 21.65928268], [74.62687683, 21.65904808], [74.62784576, 21.65882111], [74.62882233, 21.65859032], [74.62980652, 21.65835953], [74.63076019, 21.65814018], [74.63173676, 21.65793037], [74.63269806, 21.6577282], [74.63368988, 21.65752029], [74.63465118, 21.65733147], [74.63564301, 21.65715027], [74.63661194, 21.65698051], [74.63761139, 21.6568203], [74.63858032, 21.65666008], [74.6395874, 21.6565094], [74.64057159, 21.65637016], [74.64155579, 21.65624046], [74.64254761, 21.65610123], [74.6435318, 21.65596962], [74.64453888, 21.65583992], [74.6455307, 21.6557312], [74.64650726, 21.65559959], [74.64749908, 21.6554718], [74.64850616, 21.65534973], [74.64949036, 21.65522957], [74.65046692, 21.6551075], [74.65146637, 21.65497971], [74.65245819, 21.65484047], [74.65342712, 21.65471077], [74.65444946, 21.65457153], [74.65542603, 21.65442085], [74.65643311, 21.65427017], [74.65740204, 21.65410042], [74.65837097, 21.65393066], [74.6593399, 21.65374947], [74.66033173, 21.6535511], [74.66131592, 21.65335083], [74.66227722, 21.65312195], [74.66326141, 21.65287018], [74.66420746, 21.65261078], [74.66517639, 21.65232086], [74.66612244, 21.6520195], [74.66706085, 21.65168953], [74.66797638, 21.65134048], [74.66887665, 21.65097046], [74.66977692, 21.65055847], [74.67066193, 21.65011024], [74.67151642, 21.64965057], [74.67237091, 21.64915085], [74.67320251, 21.64862061], [74.67402649, 21.6480999], [74.67487335, 21.64754295], [74.67565918, 21.64698982], [74.67648315, 21.64641953], [74.6772995, 21.64587975], [74.67809296, 21.6453228], [74.67888641, 21.64476013], [74.67970276, 21.64418983], [74.68047333, 21.64361954], [74.68126678, 21.6430397], [74.68205261, 21.64245987], [74.68282318, 21.6418705], [74.68360901, 21.64128113], [74.68438721, 21.64069939], [74.68517303, 21.64011002], [74.68596649, 21.63953018], [74.68675232, 21.63894081], [74.68753052, 21.63836098], [74.68830872, 21.63777924], [74.68910217, 21.63721085], [74.68990326, 21.63663292], [74.69069672, 21.63607979], [74.69149017, 21.63552284], [74.69230652, 21.63496017], [74.69313049, 21.63442039], [74.6939621, 21.63389969], [74.69477844, 21.63338089], [74.69564819, 21.6328907], [74.69651794, 21.63240051], [74.69738007, 21.63195038], [74.69827271, 21.63150978], [74.69917297, 21.6310997], [74.70008087, 21.63071823], [74.70101166, 21.63035965], [74.70192719, 21.63002968], [74.70285797, 21.62968826], [74.70379639, 21.6293602], [74.70474243, 21.62905121], [74.70567322, 21.62874985], [74.70662689, 21.62844086], [74.7075882, 21.62816048], [74.70852661, 21.62787056], [74.70948792, 21.62759018], [74.71044922, 21.62732124], [74.71141815, 21.62705994], [74.71237946, 21.62680244], [74.71334076, 21.62654114], [74.71430206, 21.62629128], [74.71527863, 21.62606049], [74.71624756, 21.62581062], [74.71720886, 21.62559128], [74.71816254, 21.62537003], [74.71914673, 21.62512016], [74.72012329, 21.62489128], [74.72107697, 21.62467194], [74.72203827, 21.62445068], [74.72302246, 21.62421989], [74.72397614, 21.62399101], [74.72496796, 21.6237812], [74.72592163, 21.62356186], [74.72690582, 21.62334061], [74.72786713, 21.6231308], [74.72885132, 21.62290955], [74.72981262, 21.6226902], [74.73079681, 21.62248039], [74.73177338, 21.62226105], [74.73274231, 21.62205124], [74.73371887, 21.62183952], [74.73468781, 21.62162971], [74.73565674, 21.62142181], [74.73664093, 21.62120056], [74.73761749, 21.62100029], [74.73860168, 21.62079239], [74.73956299, 21.62059021], [74.74053955, 21.62037086], [74.74151611, 21.6201725], [74.74249268, 21.61996078], [74.74346161, 21.61976051], [74.74443817, 21.61955261], [74.7454071, 21.61935043], [74.74637604, 21.61914063], [74.7473526, 21.61894035], [74.74833679, 21.61874008], [74.74931335, 21.61853027], [74.75028992, 21.61832047], [74.75126648, 21.61812973], [74.75224304, 21.61791992], [74.75319672, 21.61771965], [74.75419617, 21.61751938], [74.75515747, 21.61731911], [74.75614929, 21.61712074], [74.75712585, 21.61691093], [74.75808716, 21.6167202], [74.75907898, 21.61651993], [74.76006317, 21.61634064], [74.76104736, 21.61618042], [74.76203156, 21.6160202], [74.76303101, 21.61585808], [74.76399994, 21.61573982], [74.76499939, 21.61561966], [74.76599121, 21.61552048], [74.76698303, 21.61547089], [74.76796722, 21.61541939], [74.76896667, 21.61541176], [74.76996613, 21.61543083], [74.77097321, 21.61547089], [74.77197266, 21.61548042], [74.77297974, 21.61551094], [74.77397156, 21.61553955], [74.77501678, 21.61553955], [74.77593231, 21.61515999], [74.77683258, 21.61475945], [74.77774048, 21.61433029], [74.77863312, 21.61391068], [74.77954865, 21.61349106], [74.78045654, 21.61308098], [74.78137207, 21.61270142], [74.78231049, 21.61235046], [74.78324127, 21.61203194], [74.78417969, 21.61177063], [74.78514862, 21.61156082], [74.78611755, 21.61136055], [74.78710175, 21.61117935], [74.78808594, 21.61102104], [74.7890625, 21.61086082], [74.79007721, 21.61071968], [74.79106903, 21.61058044], [74.792099, 21.61046982], [74.79308319, 21.61033821], [74.79408264, 21.61025047], [74.79509735, 21.61016273], [74.7960968, 21.61009026], [74.79708862, 21.61001968], [74.79808807, 21.60996056], [74.79907227, 21.60989952], [74.80004883, 21.60985947], [74.80103302, 21.60983086], [74.80206299, 21.6100502], [74.80288696, 21.61073112], [74.80306244, 21.61156082], [74.80284119, 21.61255836], [74.80245972, 21.61363029], [74.80207062, 21.61463928], [74.80190277, 21.61548996], [74.80207062, 21.61605072], [74.80287933, 21.61613083], [74.80404663, 21.61586952], [74.8052063, 21.6154995], [74.80613708, 21.61514282], [74.80702209, 21.61469841], [74.8079071, 21.61422157], [74.8087616, 21.61372948], [74.80963135, 21.61326981], [74.81053925, 21.61287117], [74.8114624, 21.6125412], [74.81240845, 21.61225128], [74.81339264, 21.61203194], [74.81437683, 21.61182976], [74.81536865, 21.61164093], [74.81633759, 21.61147118], [74.81732178, 21.61129951], [74.81830597, 21.61112022], [74.81928253, 21.61094093], [74.82028961, 21.61079025], [74.82128906, 21.61063194], [74.82227325, 21.6104908], [74.82327271, 21.61038017], [74.8242569, 21.61029243], [74.82524109, 21.61021042], [74.82624054, 21.61018944], [74.82726288, 21.61018944], [74.82836151, 21.61021042], [74.82946777, 21.61029243], [74.83055878, 21.61041832], [74.83156586, 21.6106205], [74.8324585, 21.61090088], [74.83320618, 21.61129951], [74.83367157, 21.61186028], [74.83368683, 21.61273956], [74.83348846, 21.61379051], [74.83329773, 21.61487007], [74.83336639, 21.61584091], [74.83370972, 21.61669922], [74.83423615, 21.6175518], [74.8348999, 21.61833], [74.83564758, 21.61897087], [74.8365097, 21.61940956], [74.83740997, 21.61979103], [74.83833313, 21.62013054], [74.83924866, 21.62044144], [74.84020233, 21.62072945], [74.84115601, 21.62100983], [74.8421402, 21.62128258], [74.84310913, 21.62153053], [74.84409332, 21.62179947], [74.84506989, 21.62206078], [74.84601593, 21.62232971], [74.84697723, 21.62263107], [74.84793854, 21.62294006], [74.84884644, 21.62327957], [74.84976959, 21.62366104], [74.85066223, 21.62407112], [74.85153198, 21.62451935], [74.85237885, 21.62504005], [74.85321808, 21.62560081], [74.85407257, 21.62619019], [74.85488129, 21.62681007], [74.85568237, 21.62745094], [74.85647583, 21.62811089], [74.85727692, 21.6287899], [74.858078, 21.62944984], [74.85884857, 21.63010979], [74.85964966, 21.63074112], [74.86038208, 21.63137054], [74.86115265, 21.63195992], [74.86193085, 21.63251114], [74.86266327, 21.6330204], [74.86342621, 21.633461], [74.86415863, 21.6338501], [74.86486053, 21.63402939], [74.86534119, 21.63330269], [74.86575317, 21.63212013], [74.86630249, 21.63112068], [74.86709595, 21.63074112], [74.8680191, 21.6305294], [74.8690033, 21.63039017], [74.87001038, 21.63029099], [74.87106323, 21.63023949], [74.8720932, 21.63023949], [74.87312317, 21.63026047], [74.87415314, 21.63029099], [74.87516022, 21.63034058], [74.87613678, 21.63043976], [74.87713623, 21.63059044], [74.87812805, 21.63078117], [74.87909698, 21.63099098], [74.88006592, 21.63120079], [74.88105774, 21.6314106], [74.88204956, 21.63158035], [74.88302612, 21.63171959], [74.88401031, 21.63179016], [74.8850174, 21.6317997], [74.88601685, 21.6317997], [74.8870163, 21.6317997], [74.88803101, 21.63178253], [74.88903809, 21.63175964], [74.8900528, 21.63171959], [74.89105988, 21.63167953], [74.89208221, 21.63162994], [74.89309692, 21.63155937], [74.89411926, 21.63146973], [74.89512634, 21.63138962], [74.89610291, 21.6312809], [74.8970871, 21.63116264], [74.89807129, 21.63101959], [74.89904785, 21.63086128], [74.90001678, 21.63068962], [74.90093994, 21.63047981], [74.90187836, 21.63022995], [74.90276337, 21.6298008], [74.90358734, 21.62922287], [74.90434265, 21.6285305], [74.90500641, 21.62779045], [74.90563965, 21.62702942], [74.90618134, 21.62625122], [74.90661621, 21.62543106], [74.90703583, 21.6245594], [74.90743256, 21.62366104], [74.9078064, 21.62277031], [74.90818024, 21.62187958], [74.90860748, 21.62102127], [74.90907288, 21.62020111], [74.90962219, 21.61944962], [74.91026306, 21.61876106], [74.91095734, 21.61811066], [74.91172791, 21.61749077], [74.9125061, 21.61689949], [74.91333771, 21.61634064], [74.91416168, 21.61580849], [74.91504669, 21.61531067], [74.91591644, 21.61482811], [74.91680145, 21.61437988], [74.91770172, 21.61395264], [74.9185791, 21.61352921], [74.91947937, 21.61314011], [74.92038727, 21.61275101], [74.9213028, 21.61236954], [74.92222595, 21.61202049], [74.92314911, 21.6116581], [74.92408752, 21.61131859], [74.92502594, 21.61099052], [74.92595673, 21.61065292], [74.92691803, 21.61033821], [74.92785645, 21.61003113], [74.92880249, 21.60972023], [74.92974091, 21.60942078], [74.93067932, 21.60910034], [74.931633, 21.60880089], [74.93258667, 21.6084919], [74.93353271, 21.60819054], [74.93447113, 21.60787964], [74.93541718, 21.60757065], [74.93636322, 21.60728073], [74.93731689, 21.60697174], [74.93824768, 21.60667038], [74.93920135, 21.60637093], [74.94016266, 21.60608292], [74.94108582, 21.60577965], [74.94204712, 21.60548973], [74.94300079, 21.60518265], [74.94394684, 21.60490036], [74.94489288, 21.60460091], [74.94584656, 21.60432053], [74.94682312, 21.60403061], [74.94776154, 21.60375023], [74.94869995, 21.60346985], [74.94966888, 21.60318184], [74.9506073, 21.6029129], [74.95157623, 21.60263062], [74.95252991, 21.60235023], [74.95349884, 21.60207939], [74.95443726, 21.60181046], [74.95539856, 21.60155106], [74.95635986, 21.60128975], [74.95732117, 21.60103035], [74.95826721, 21.60077286], [74.95923615, 21.60050964], [74.96018982, 21.60026932], [74.96116638, 21.60001945], [74.96214294, 21.59980965], [74.96312714, 21.59959984], [74.96408844, 21.59941101], [74.96507263, 21.5992012], [74.96604919, 21.5990181], [74.96702576, 21.59883118], [74.96800232, 21.59864998], [74.96898651, 21.59847069], [74.96997833, 21.59828949], [74.97096252, 21.59811974], [74.97194672, 21.59793282], [74.97293091, 21.59774971], [74.97390747, 21.59756088], [74.9748764, 21.59737015], [74.9758606, 21.59717178], [74.97683716, 21.59696007], [74.97780609, 21.59674072], [74.97875977, 21.59651947], [74.9797287, 21.59626961], [74.98068237, 21.59601974], [74.98162842, 21.59574127], [74.98258972, 21.59546089], [74.98353577, 21.59517288], [74.98449707, 21.59486961], [74.98544312, 21.59456062], [74.98638916, 21.59424973], [74.98731232, 21.59392166], [74.9882431, 21.59358978], [74.98918152, 21.59325027], [74.99011993, 21.59290123], [74.99104309, 21.59255028], [74.99195862, 21.5921917], [74.99289703, 21.59183121], [74.9937973, 21.59144974], [74.99474335, 21.59109116], [74.99565125, 21.59070015], [74.99656677, 21.59033012], [74.99745941, 21.58992958], [74.99835205, 21.58950043], [74.99923706, 21.58905029], [75.00009918, 21.58859062], [75.0009613, 21.58811951], [75.00183105, 21.58764267], [75.00267792, 21.58716965], [75.00356293, 21.58670807], [75.004776, 21.5860424], [75.01341248, 21.5811882], [75.01584625, 21.57788086], [75.01783752, 21.57261086], [75.03183746, 21.56930923], [75.05356598, 21.56719017], [75.05774689, 21.5649395], [75.06018829, 21.55933952], [75.06359863, 21.55500031], [75.06503296, 21.5508194], [75.07221985, 21.54165077], [75.07624054, 21.53801918], [75.07832336, 21.5321312], [75.08355713, 21.52575111], [75.08999634, 21.51433182], [75.09266663, 21.50090981], [75.09487915, 21.49381256], [75.10044098, 21.48531151], [75.10666656, 21.46962929], [75.11509705, 21.45956039], [75.12297821, 21.4533329], [75.129776, 21.44927979], [75.14743805, 21.4433403], [75.15737152, 21.43827248], [75.18802643, 21.42731094], [75.19599915, 21.42285919], [75.20372009, 21.41731834], [75.2074585, 21.41584015], [75.21055603, 21.41422081], [75.21985626, 21.4108696], [75.23226166, 21.41658974], [75.23636627, 21.41710091], [75.24347687, 21.41493988], [75.24768066, 21.41067123], [75.2539978, 21.40613937], [75.2591095, 21.40521812], [75.26702118, 21.4088707], [75.27662659, 21.4088707], [75.28856659, 21.41181183], [75.29162598, 21.41390991], [75.29962921, 21.41566086], [75.30184937, 21.41483116], [75.30316162, 21.39519119], [75.30182648, 21.39241982], [75.30190277, 21.3892498], [75.30866241, 21.39450073], [75.31195831, 21.39528084], [75.32090759, 21.39240265], [75.32681274, 21.39423943], [75.33487701, 21.39466858], [75.35378265, 21.39348984], [75.35800171, 21.3961792], [75.36138153, 21.40323067], [75.36694336, 21.39891052], [75.37866211, 21.39241982], [75.3813324, 21.38763046], [75.38448334, 21.3855896], [75.39308929, 21.38406944], [75.39537811, 21.38467979], [75.39839172, 21.38298035], [75.40091705, 21.3839798], [75.40381622, 21.38377953], [75.40925598, 21.38992119], [75.41337585, 21.3910675], [75.41996765, 21.39027023], [75.43165588, 21.39394951], [75.43628693, 21.39072037], [75.44361877, 21.39101982], [75.44615173, 21.3904705], [75.45007324, 21.39240265], [75.45443726, 21.3920517], [75.46005249, 21.39302254], [75.46559906, 21.39136124], [75.46840668, 21.39420128], [75.48480225, 21.39126015], [75.49643707, 21.39073181], [75.50048828, 21.39157295], [75.51013184, 21.38799286], [75.51628113, 21.38673019], [75.52458191, 21.38716125], [75.52939606, 21.38472939], [75.53994751, 21.37719154], [75.54530334, 21.37579918], [75.54714966, 21.37265968], [75.54814911, 21.37248993], [75.55133057, 21.37544823], [75.555336, 21.37745094], [75.55980682, 21.38226128], [75.56111145, 21.38117027], [75.56027222, 21.37881088], [75.56420898, 21.37809944], [75.56598663, 21.37915039], [75.57209015, 21.37822914], [75.58125305, 21.37985992], [75.5815506, 21.38084984], [75.57655334, 21.38552094], [75.58486176, 21.38759995], [75.5877533, 21.38890076], [75.59126282, 21.3917408], [75.60295105, 21.39052963], [75.60891724, 21.39500046], [75.6194458, 21.39346123], [75.62111664, 21.38787079], [75.62361145, 21.38428116], [75.62679291, 21.38200951], [75.6294632, 21.3812294], [75.63263702, 21.38177109], [75.63986206, 21.38149071], [75.64575958, 21.38247108], [75.65487671, 21.38202095], [75.65882111, 21.38274956], [75.67341614, 21.38035011], [75.67507935, 21.38145065], [75.6784668, 21.38217163], [75.68479156, 21.38223076], [75.68782043, 21.38433075], [75.68972015, 21.38750076], [75.69483185, 21.38956261], [75.70675659, 21.39132118], [75.71385193, 21.3916111], [75.72158813, 21.39099121], [75.72271729, 21.38915253], [75.73294067, 21.39332962], [75.73558044, 21.39270973], [75.73834991, 21.39343262], [75.74408722, 21.39319038], [75.74610138, 21.39171028], [75.75467682, 21.38838959], [75.75894165, 21.38549042], [75.76013947, 21.38570023], [75.7738266, 21.38664818], [75.79220581, 21.38921165], [75.80140686, 21.39015007], [75.80545807, 21.38903046], [75.8125, 21.38733101], [75.83262634, 21.38330078], [75.84342194, 21.38945007], [75.84662628, 21.38813972], [75.85135651, 21.38935089], [75.85932922, 21.38730049], [75.86277771, 21.38730049], [75.86818695, 21.39048958], [75.87226105, 21.39550018], [75.87615204, 21.39819145], [75.88212585, 21.39842987], [75.8881073, 21.39962959], [75.89563751, 21.39874077], [75.89705658, 21.39726067], [75.9050827, 21.39563942], [75.91227722, 21.3906498], [75.91654205, 21.38982773], [75.93234253, 21.39151001], [75.93737793, 21.39286995], [75.94796753, 21.39298058], [75.95939636, 21.39619064], [75.96874237, 21.39397049], [75.98487854, 21.37717819], [75.99160767, 21.3760891], [76.00023651, 21.37481117], [76.01597595, 21.36988258], [76.02749634, 21.36813927], [76.0345993, 21.36527061], [76.04202271, 21.35889244], [76.04704285, 21.35519981], [76.05237579, 21.35270119], [76.06565857, 21.35919952], [76.07724762, 21.36426926], [76.08815002, 21.3699894], [76.095047, 21.37267113], [76.09867096, 21.37392807], [76.10694885, 21.36020279], [76.1159668, 21.33877945], [76.12224579, 21.32163811], [76.12726593, 21.30734062], [76.1292572, 21.29751015], [76.13497162, 21.29150009], [76.13987732, 21.28899956], [76.14499664, 21.28777122], [76.1471405, 21.28137016], [76.14980316, 21.27420998], [76.15386963, 21.26881981], [76.15603638, 21.2632103], [76.15921783, 21.25914192], [76.15809631, 21.25354958], [76.15428925, 21.24913979], [76.15091705, 21.24561119], [76.14412689, 21.24258041], [76.14409637, 21.24147987], [76.14440155, 21.23809052], [76.1455307, 21.23319054], [76.14801025, 21.2316494], [76.15328979, 21.22981834], [76.15933228, 21.22725105], [76.16403198, 21.22417259], [76.16314697, 21.22195053], [76.16152191, 21.21668816], [76.16427612, 21.21181107], [76.16794586, 21.20812035], [76.16770935, 21.20588112], [76.16705322, 21.20358086], [76.16571808, 21.20004845], [76.16590881, 21.19548988], [76.16908264, 21.19188118], [76.17272186, 21.18828964], [76.17063904, 21.18217278], [76.16913605, 21.17448044], [76.16684723, 21.17072105], [76.16088867, 21.17200089], [76.15505981, 21.17256165], [76.14298248, 21.17313194], [76.13070679, 21.17555046], [76.12741852, 21.17791939], [76.1193924, 21.17468071], [76.11431885, 21.17045975], [76.11396027, 21.16464043], [76.11891174, 21.1601181], [76.12409973, 21.15909958], [76.12841797, 21.15670967], [76.13169098, 21.15267944], [76.1399231, 21.14006805], [76.14092255, 21.13602257], [76.13934326, 21.13363075], [76.13417053, 21.1303196], [76.13566589, 21.12621117], [76.14214325, 21.12107086], [76.15146637, 21.11499977], [76.16221619, 21.10996056], [76.16744232, 21.10629845], [76.16845703, 21.10541153], [76.16911316, 21.10371971], [76.16931152, 21.10141945], [76.16927338, 21.09865952], [76.1681366, 21.0932312], [76.16702271, 21.089571], [76.16864777, 21.08582115], [76.17263794, 21.08460045], [76.17727661, 21.08549118], [76.1807785, 21.08741951], [76.18386078, 21.08995056], [76.18907166, 21.09031105], [76.20868683, 21.09017944], [76.22749329, 21.09144974], [76.23510742, 21.09391022], [76.26210785, 21.09470177], [76.26924896, 21.09295082], [76.27324677, 21.08541107], [76.27776337, 21.07802963], [76.2817688, 21.07530975], [76.2857666, 21.07649994], [76.29711914, 21.07718086], [76.33481598, 21.07718086], [76.35697937, 21.07966995], [76.3613205, 21.08000183], [76.36579132, 21.07907104], [76.36862183, 21.07870102], [76.37198639, 21.07855988], [76.37637329, 21.07731056], [76.37961578, 21.07847977], [76.38104248, 21.07907104], [76.38275909, 21.07956123], [76.3901062, 21.08805084], [76.39682007, 21.09057045], [76.40943909, 21.09408951], [76.41182709, 21.10726929], [76.43373871, 21.10668945], [76.4375, 21.10758972], [76.44107056, 21.11213112], [76.44770813, 21.11285973], [76.45269012, 21.11486816], [76.45291901, 21.1244297], [76.45593262, 21.13191986], [76.4575119, 21.13834], [76.46549988, 21.13924026], [76.46700287, 21.14319038], [76.46675873, 21.1472683], [76.46897125, 21.15056992], [76.47489166, 21.152071], [76.47702026, 21.15530014], [76.47673798, 21.16128922], [76.47828674, 21.17568016], [76.48245239, 21.18823051], [76.48737335, 21.19606018], [76.49117279, 21.19782066], [76.49807739, 21.19614029], [76.52078247, 21.18922043], [76.52919769, 21.18929291], [76.54129791, 21.19629097], [76.55938721, 21.20581055], [76.57518005, 21.20407295], [76.5760498, 21.20366287], [76.58674622, 21.19868279], [76.60562897, 21.19716263], [76.61231995, 21.19591141], [76.61678314, 21.19857025], [76.62003326, 21.19544029], [76.62336731, 21.19265938], [76.6268692, 21.19881058], [76.63157654, 21.20536995], [76.63134003, 21.21564102], [76.63169098, 21.22890091], [76.63728333, 21.23911285], [76.64257813, 21.24772072], [76.64987946, 21.24901962], [76.65849304, 21.24781036], [76.6590271, 21.25324821], [76.65944672, 21.26213074], [76.66017914, 21.27359962], [76.66107178, 21.28242111], [76.64862823, 21.3000412], [76.63973236, 21.31064987], [76.62583923, 21.32974052], [76.62452698, 21.33510017], [76.62864685, 21.33977127], [76.66841125, 21.3694706], [76.71909332, 21.40065002], [76.73208618, 21.40880966], [76.73722839, 21.41529083], [76.73842621, 21.42938042], [76.74339294, 21.44314003], [76.75654602, 21.44992828], [76.77578735, 21.46013069], [76.78418732, 21.46648979], [76.78513336, 21.47672081], [76.79017639, 21.48236084], [76.79180145, 21.48989105], [76.78649139, 21.49922943], [76.77023315, 21.51074982], [76.76293182, 21.52264977], [76.76751709, 21.52754021], [76.7753067, 21.53202057], [76.78553772, 21.53530121], [76.78782654, 21.54013062], [76.78457642, 21.54605293], [76.78283691, 21.5514698], [76.78024292, 21.56246758], [76.78359222, 21.5779705], [76.79148865, 21.58741951], [76.793396, 21.59517288], [76.79534912, 21.5975399], [76.80387115, 21.59683037], [76.82318115, 21.59268188], [76.8335495, 21.59306908], [76.83863068, 21.60050011], [76.84776306, 21.61330032], [76.85214996, 21.61503029], [76.86073303, 21.61230278], [76.89174652, 21.60070038], [76.90112305, 21.6008091], [76.90567017, 21.60449982], [76.91155243, 21.61493111], [76.97866821, 21.66597939], [76.99727631, 21.68161011], [77.00158691, 21.68215942], [77.01016235, 21.68439102], [77.0181427, 21.69079971], [77.02333832, 21.6937809], [77.02916718, 21.69606018], [77.03427124, 21.70051193], [77.05948639, 21.70940018], [77.0620575, 21.71504974], [77.06903839, 21.72180939], [77.07232666, 21.72293091], [77.07406616, 21.72261047], [77.07530975, 21.72237015], [77.08024597, 21.71869278], [77.08377838, 21.71862984], [77.09393311, 21.7196312], [77.10330963, 21.7226429], [77.10411072, 21.72289085], [77.11416626, 21.72486115], [77.12110138, 21.72534943], [77.13333893, 21.72232056], [77.14750671, 21.71465111], [77.15777588, 21.71340942], [77.16004944, 21.7137394], [77.16242218, 21.71410751], [77.16506195, 21.71692085], [77.16803741, 21.72575951], [77.17144775, 21.72726059], [77.18383026, 21.72450066], [77.18802643, 21.72257042], [77.18766022, 21.72072983], [77.18432617, 21.70446014], [77.20136261, 21.69631958], [77.20742035, 21.69400978], [77.21021271, 21.69712067], [77.21797943, 21.69842911], [77.22159576, 21.70010948], [77.22223663, 21.70167923], [77.22323608, 21.70418167], [77.22460175, 21.71788979], [77.23993683, 21.71712112], [77.25518036, 21.71519089], [77.25802612, 21.71582985], [77.26277161, 21.72363091], [77.26737976, 21.72907066], [77.28314972, 21.72422028], [77.28581238, 21.7288208], [77.28690338, 21.73644257], [77.28501892, 21.73750114], [77.28328705, 21.73849106], [77.28308868, 21.74164963], [77.28446198, 21.74644852], [77.28227234, 21.7481308], [77.27826691, 21.74913979], [77.27774811, 21.75375938], [77.27707672, 21.75980949], [77.27997589, 21.76126289], [77.28623962, 21.76275063], [77.29367065, 21.75991821], [77.3088913, 21.75964928], [77.32129669, 21.75703049], [77.32598114, 21.75736046], [77.33738708, 21.76156044], [77.33912659, 21.76165962], [77.34229279, 21.76183128], [77.35338593, 21.75946045], [77.37592316, 21.7571106], [77.40113068, 21.75617981], [77.40531158, 21.75673103], [77.41298676, 21.75773048], [77.42665863, 21.76040077], [77.43850708, 21.76272011], [77.44387817, 21.76351929], [77.44988251, 21.76341057], [77.45262909, 21.76432037], [77.45868683, 21.76818085], [77.47138214, 21.77124977], [77.4754715, 21.77144051], [77.47776794, 21.77022171], [77.47701263, 21.76795959], [77.47515106, 21.76573944], [77.47550964, 21.76185036], [77.47586823, 21.75788116], [77.48882294, 21.75024986], [77.4923172, 21.74979019], [77.49687195, 21.74920082], [77.49986267, 21.74489021], [77.50605011, 21.74121284], [77.50836182, 21.7352829], [77.51790619, 21.72701073], [77.51832581, 21.72437096], [77.51882935, 21.72116089], [77.52104187, 21.7141304], [77.52308655, 21.71362114], [77.52345276, 21.71354103], [77.52610779, 21.71503258], [77.53338623, 21.71269035], [77.53592682, 21.70825958], [77.54218292, 21.70103073], [77.54457092, 21.6924324], [77.54566956, 21.6860714], [77.54736328, 21.68156052], [77.55050659, 21.67628288], [77.55856323, 21.66867256], [77.55754089, 21.65558815], [77.56037903, 21.64518166], [77.5655365, 21.63503265], [77.57132721, 21.62704086], [77.570961, 21.6235199], [77.56784058, 21.62105942], [77.56817627, 21.61623192], [77.56993103, 21.6111412], [77.57219696, 21.58767128], [77.57022858, 21.57566833], [77.56999969, 21.56978989], [77.57099915, 21.56262016], [77.57408905, 21.55750084], [77.57972717, 21.55815125], [77.58551788, 21.55880928], [77.59068298, 21.56161118], [77.60575867, 21.55091095], [77.6071167, 21.54277039], [77.59488678, 21.5331707], [77.58924866, 21.53034973], [77.57789612, 21.52921104], [77.56698608, 21.52975082], [77.55339813, 21.53617287], [77.54073334, 21.53891945], [77.53533936, 21.53904915], [77.52919006, 21.54076958], [77.51191711, 21.54751015], [77.50726318, 21.5508194], [77.50435638, 21.55466843], [77.48400116, 21.55330276], [77.46872711, 21.55449104], [77.46472931, 21.55597115], [77.4575119, 21.55657005], [77.45195007, 21.55561066], [77.45030975, 21.55194092], [77.45024872, 21.5483799], [77.44664001, 21.54561043], [77.44207001, 21.54464912], [77.43187714, 21.54640007], [77.42894745, 21.54566002], [77.42350769, 21.54256058], [77.41990662, 21.5386982], [77.4169693, 21.53306007], [77.41880035, 21.52083969], [77.42079926, 21.51628113], [77.43112946, 21.50222015], [77.43921661, 21.48932266], [77.43737793, 21.48353195], [77.43515015, 21.48163986], [77.43785095, 21.47820282], [77.43808746, 21.47555923], [77.43830872, 21.47291946], [77.43875885, 21.47278023], [77.4489212, 21.46967125], [77.45236206, 21.46799088], [77.45378876, 21.46729279], [77.45716095, 21.46707153], [77.46930695, 21.45689964], [77.46858215, 21.45290947], [77.46975708, 21.44868088], [77.46884155, 21.44292068], [77.46920776, 21.43704987], [77.47302246, 21.43268967], [77.47709656, 21.42086029], [77.48175049, 21.41566849], [77.48419189, 21.39850998], [77.48298645, 21.39038086], [77.4870224, 21.3777504], [77.50173187, 21.37924957], [77.51052856, 21.37676048], [77.516922, 21.37803268], [77.51785278, 21.37784958], [77.52072144, 21.37730026], [77.52427673, 21.37973022], [77.52876282, 21.37907028], [77.5398407, 21.38117027], [77.54840851, 21.3812294], [77.5625, 21.37338066], [77.56533051, 21.37262917], [77.57089233, 21.3732605], [77.5759964, 21.37047005], [77.58081055, 21.36913109], [77.58262634, 21.36680031], [77.58444214, 21.36447906], [77.58701324, 21.36775017], [77.60148621, 21.36527061], [77.60481262, 21.36699295], [77.60575867, 21.37035179], [77.60204315, 21.38420105], [77.60066223, 21.3859024], [77.60064697, 21.3891201], [77.59938812, 21.39208984], [77.59919739, 21.39254951], [77.60067749, 21.39318085], [77.60154724, 21.3935585], [77.61145782, 21.39381027], [77.61519623, 21.39065933], [77.62931061, 21.39097977], [77.63617706, 21.38949966], [77.63920593, 21.38793945], [77.6414566, 21.3886795], [77.6425705, 21.39141083], [77.64589691, 21.39336014], [77.65097046, 21.39339066], [77.65158081, 21.39019012], [77.66208649, 21.38797188], [77.66335297, 21.38562965], [77.66307831, 21.37745094], [77.66481018, 21.37363052], [77.66722107, 21.37149048], [77.66877747, 21.3723011], [77.6700058, 21.3729229], [77.67520142, 21.37881088], [77.68109131, 21.38549042], [77.68827057, 21.39673042], [77.69113159, 21.39706993], [77.69352722, 21.3965416], [77.69425201, 21.39454269], [77.69259644, 21.38064957], [77.69554138, 21.37775993], [77.70433044, 21.37770081], [77.70514679, 21.37345123], [77.70519257, 21.36728096], [77.70524597, 21.35906982], [77.72489929, 21.36415291], [77.73387909, 21.36473083], [77.73834991, 21.36663055], [77.74336243, 21.38006973], [77.74649048, 21.38421059], [77.74993896, 21.38570976], [77.75689697, 21.38640976], [77.76140594, 21.38442039], [77.76506805, 21.38466263], [77.77655029, 21.3880291], [77.78552246, 21.38939095], [77.7901001, 21.38924026], [77.7934494, 21.39073944], [77.7939682, 21.39961052], [77.79522705, 21.40377808], [77.79598999, 21.40625954], [77.79847717, 21.41070938], [77.79936981, 21.41230011], [77.80449677, 21.41200066], [77.81801605, 21.40872955], [77.83392334, 21.40151978], [77.84661102, 21.39410973], [77.85473633, 21.39072037], [77.86321259, 21.38812065], [77.8762207, 21.38643074], [77.88337708, 21.38549042], [77.88186646, 21.37769127], [77.88664246, 21.38042068], [77.8923111, 21.3790493], [77.89904022, 21.37841988], [77.90071869, 21.3787117], [77.90550995, 21.37957001], [77.91176605, 21.382761], [77.91825104, 21.38474083], [77.92488861, 21.38606071], [77.9317627, 21.38581848], [77.93878174, 21.38690948], [77.94111633, 21.39895058], [77.95774841, 21.40114021], [77.95995331, 21.40142822], [77.97154999, 21.40138054], [77.97599792, 21.40209961], [77.98027802, 21.40279961], [77.99582672, 21.41378021], [77.99973297, 21.41616249], [78.00443268, 21.4158802], [78.00707245, 21.41841125], [78.01957703, 21.42058945], [78.0291214, 21.42535973], [78.04345703, 21.43503189], [78.05105591, 21.4370327], [78.06371307, 21.43885994], [78.0785675, 21.44571114], [78.09249115, 21.45601082], [78.10074615, 21.46095085], [78.10906219, 21.4641819], [78.12722778, 21.47340012], [78.14280701, 21.48211098], [78.16934204, 21.49850082], [78.17057037, 21.50205994], [78.17134094, 21.50850105], [78.17764282, 21.51431847], [78.1680069, 21.52604103], [78.17106628, 21.52873993], [78.17167664, 21.53576279], [78.17061615, 21.54219055], [78.17273712, 21.55330276], [78.17726898, 21.55669975], [78.18094635, 21.55868149], [78.21547699, 21.55373001], [78.22666931, 21.55644035], [78.23871613, 21.56549072], [78.24655914, 21.56401062], [78.26925659, 21.57071114], [78.27024841, 21.57237053], [78.26902008, 21.57472992], [78.25853729, 21.58189964], [78.25540924, 21.58523941], [78.25517273, 21.58984184], [78.25762177, 21.59184074], [78.26220703, 21.59375954], [78.26612091, 21.59428024], [78.27107239, 21.59296036], [78.2816391, 21.58675957], [78.30000305, 21.58505821], [78.3017807, 21.58040047], [78.30184937, 21.57287025], [78.30410767, 21.57143021], [78.30882263, 21.57369041], [78.31874084, 21.57558823], [78.32293701, 21.57738113], [78.32846069, 21.58118057], [78.33677673, 21.59052086], [78.34203339, 21.58287048], [78.34768677, 21.57886124], [78.35468292, 21.57690811], [78.36096191, 21.57829857], [78.36605072, 21.58192062], [78.37415314, 21.58996964], [78.37763214, 21.59560013], [78.37203979, 21.61076927], [78.37165833, 21.61503029], [78.37571716, 21.61745071], [78.3795166, 21.61865044], [78.38355255, 21.61663818], [78.38932037, 21.61056137], [78.39256287, 21.61009979], [78.39904785, 21.61108017], [78.40448761, 21.61009979], [78.41086578, 21.60659981], [78.41925812, 21.60429955], [78.42256165, 21.60194969], [78.41584778, 21.58815002], [78.41349792, 21.57773972], [78.41594696, 21.57308006], [78.41906738, 21.57160187], [78.42225647, 21.5637207], [78.42073059, 21.55479813], [78.42060089, 21.54878044], [78.42195129, 21.54584122], [78.42550659, 21.54227066], [78.42752838, 21.53832054], [78.42685699, 21.53019905], [78.42782593, 21.52675056], [78.43218231, 21.51991081], [78.43026733, 21.5091629], [78.43009949, 21.50175095], [78.43858337, 21.50375938], [78.44467926, 21.5019207], [78.4516983, 21.49733162], [78.45419312, 21.49831009], [78.45627594, 21.50445175], [78.45922852, 21.50463104], [78.46167755, 21.50353813], [78.46530151, 21.50353813], [78.47090912, 21.50486946], [78.47209167, 21.5069294], [78.48040009, 21.50612068], [78.48339844, 21.50774002], [78.48561859, 21.51203918], [78.49075317, 21.51797104], [78.49600983, 21.51797104], [78.49791718, 21.52296066], [78.50208282, 21.5266304], [78.50434875, 21.52670288], [78.50856018, 21.52843285], [78.52007294, 21.52537918], [78.52474213, 21.52583122], [78.52835083, 21.52462006], [78.53727722, 21.52456284], [78.54647064, 21.51996994], [78.55239868, 21.51939011], [78.55648804, 21.51581955], [78.56004333, 21.51461029], [78.56652832, 21.51569748], [78.56468964, 21.50932121], [78.56529999, 21.50597954], [78.57325745, 21.49850082], [78.58119202, 21.48964119], [78.58486938, 21.48688126], [78.59326172, 21.48768997], [78.59863281, 21.48480988], [78.60102081, 21.48715973], [78.6053772, 21.4883709], [78.61606598, 21.4815197], [78.62097168, 21.47754097], [78.62532806, 21.47783089], [78.63046265, 21.48133087], [78.63745117, 21.48419762], [78.64354706, 21.48425102], [78.65065765, 21.48282051], [78.65908813, 21.47888947], [78.66417694, 21.48073006], [78.68406677, 21.4819603], [78.68444061, 21.47795105], [78.68830109, 21.47886086], [78.6919632, 21.47868156], [78.69618225, 21.47741127], [78.69574738, 21.47443008], [78.70162201, 21.47470093], [78.70388031, 21.47120094], [78.71391296, 21.46795082], [78.71975708, 21.46462059], [78.72418976, 21.46438026], [78.7297287, 21.47136116], [78.73512268, 21.47141075], [78.7388382, 21.47290039], [78.74040222, 21.48371124], [78.74648285, 21.49386978], [78.7505188, 21.4907608], [78.76103973, 21.48975945], [78.76078796, 21.48471069], [78.76438141, 21.4742794], [78.77218628, 21.46713066], [78.77552032, 21.47351265], [78.7770462, 21.47907829], [78.78016663, 21.48080826], [78.78462219, 21.48913956], [78.78968811, 21.4885006], [78.79281616, 21.48986053], [78.81009674, 21.49086952], [78.81313324, 21.48872948], [78.81925964, 21.48962975], [78.82337952, 21.49111938], [78.82794952, 21.48995972], [78.84417725, 21.48997116], [78.84771729, 21.4914608], [78.85154724, 21.49570084], [78.87513733, 21.48792839], [78.87985229, 21.48497009], [78.88537598, 21.48559189], [78.89048767, 21.49823952], [78.89576721, 21.50056839], [78.90273285, 21.49801826], [78.90792847, 21.49425125], [78.92057037, 21.48763084], [78.93183136, 21.48740005], [78.93379974, 21.49238968], [78.93689728, 21.51044083], [78.94064331, 21.51370049], [78.93869781, 21.51728821], [78.9363327, 21.51939011], [78.92623901, 21.52164078], [78.92343903, 21.52378845], [78.92340088, 21.53308105], [78.92457581, 21.53868103], [78.92179871, 21.5431881], [78.90442657, 21.55484009], [78.90909576, 21.56175041], [78.91271973, 21.56312943], [78.92398071, 21.56015015], [78.92782593, 21.56028938], [78.9283905, 21.56443024], [78.91989899, 21.56895828], [78.91433716, 21.56964111], [78.91163635, 21.5709095], [78.91217804, 21.58518028], [78.91323853, 21.59235954], [78.92267609, 21.59260941], [78.92906189, 21.5946312], [78.94034576, 21.59375954], [78.94586182, 21.59604073], [78.96227264, 21.60588074], [78.97476196, 21.61755943], [78.98149109, 21.6171608], [78.9944458, 21.61874962], [78.99738312, 21.61577988], [78.99999237, 21.60979843], [79.00579834, 21.60402107], [79.009552, 21.60149956], [79.03096008, 21.60560989], [79.0429306, 21.60470963], [79.0479126, 21.60569], [79.05075073, 21.60394287], [79.07608032, 21.60768127], [79.0815506, 21.60715103], [79.08808899, 21.59918976], [79.09203339, 21.60342979], [79.09809875, 21.60284042], [79.10411072, 21.60935974], [79.09947968, 21.61227036], [79.09873199, 21.61631012], [79.09916687, 21.6189003], [79.11123657, 21.62556267], [79.12773895, 21.62805939], [79.13707733, 21.63685036], [79.14109039, 21.63953018], [79.14713287, 21.6565609], [79.14782715, 21.66052055], [79.18618774, 21.65442848], [79.21660614, 21.65019035], [79.21990204, 21.65081024], [79.22157288, 21.65690994], [79.22693634, 21.65764999], [79.22840118, 21.67139053], [79.22682953, 21.67439079], [79.22455597, 21.67588043], [79.22016144, 21.67700005], [79.21817017, 21.68126106], [79.22091675, 21.69659042], [79.22187805, 21.70059967], [79.23477173, 21.71520805], [79.22892761, 21.7204895], [79.22808075, 21.72191048], [79.2286911, 21.72392845], [79.25766754, 21.71754074], [79.26486969, 21.71492004], [79.27175903, 21.70903969], [79.27478027, 21.70523071], [79.27680206, 21.70022964], [79.28481293, 21.6939106], [79.31733704, 21.68581963], [79.32025146, 21.68659973], [79.32213593, 21.6883812], [79.34261322, 21.68451118], [79.34832001, 21.68440819], [79.34902191, 21.67889023], [79.36178589, 21.67951012], [79.38307953, 21.67539024], [79.39473724, 21.67459106], [79.3970871, 21.67564011], [79.40045166, 21.67964935], [79.40772247, 21.68556023], [79.41139984, 21.69096756], [79.41577911, 21.69144821], [79.42298126, 21.69057274], [79.42796326, 21.68526077], [79.43224335, 21.68349075], [79.44072723, 21.68223953], [79.45101166, 21.68433762], [79.45851135, 21.68732262], [79.4885788, 21.67412186], [79.48963928, 21.66580009], [79.4908905, 21.66370964], [79.49456024, 21.66053963], [79.49738312, 21.65193939], [79.49929047, 21.64784813], [79.50113678, 21.64571762], [79.50026703, 21.6405201], [79.50263977, 21.63459969], [79.50959778, 21.63336182], [79.51161957, 21.63113022], [79.5124588, 21.6264801], [79.50850677, 21.62286186], [79.50473022, 21.62326813], [79.50324249, 21.62236023], [79.50112915, 21.61964989], [79.49819183, 21.61236954], [79.50308228, 21.60750961], [79.50681305, 21.60238075], [79.50582123, 21.59028053], [79.51066589, 21.5831604], [79.52171326, 21.58032036], [79.52765656, 21.57480049], [79.53214264, 21.57298088], [79.53755951, 21.56899071], [79.53952026, 21.56520081], [79.53605652, 21.55496979], [79.5338974, 21.55076027], [79.53423309, 21.54816818], [79.53662109, 21.54421806], [79.54738617, 21.54429817], [79.56031036, 21.54801941], [79.57135773, 21.54380035], [79.57614899, 21.54335976], [79.58952332, 21.54955864], [79.59490967, 21.54965973], [79.59938812, 21.55076981], [79.60871124, 21.55593109], [79.61682129, 21.55721092], [79.62534332, 21.55486107], [79.63426971, 21.55495071], [79.64074707, 21.55548096], [79.6474762, 21.55717278], [79.65061951, 21.55880928], [79.65394592, 21.56345177], [79.65814209, 21.57733154], [79.66294098, 21.57971001], [79.68483734, 21.58069038], [79.68934631, 21.58364105], [79.69122314, 21.58789063], [79.69380951, 21.59095192], [79.69934082, 21.5923214], [79.70617676, 21.59090042], [79.71382141, 21.59113121], [79.73262024, 21.60252953], [79.74488831, 21.59786987], [79.76879883, 21.59043121], [79.79181671, 21.58140945], [79.80319214, 21.57262993], [79.81165314, 21.56430054], [79.81819153, 21.55900955], [79.82504272, 21.5467205], [79.84153748, 21.54181862], [79.85056305, 21.5375309], [79.85475922, 21.53252029], [79.85707855, 21.53092194], [79.87187958, 21.52956009], [79.8766861, 21.52847099], [79.88582611, 21.5296402], [79.88976288, 21.52388], [79.89228821, 21.52326012], [79.90119171, 21.52436066], [79.91581726, 21.52448082], [79.91831207, 21.54031181], [79.92124939, 21.5461998], [79.92719269, 21.55373001], [79.9310379, 21.55561066], [79.93638611, 21.55680084], [79.94709778, 21.55525017], [79.96144867, 21.55800056], [79.96624756, 21.55727005], [79.97177887, 21.55512047], [79.98558044, 21.5367794], [79.99355316, 21.53471184], [79.99669647, 21.53531075], [79.99819946, 21.53664017], [80.00208282, 21.53897095], [80.00476074, 21.54087067], [80.00746918, 21.54256821], [80.01000977, 21.5445919], [80.01223755, 21.54598045], [80.01465607, 21.54735184], [80.01689911, 21.54885101], [80.01912689, 21.55079079], [80.02265167, 21.55381966], [80.02617645, 21.55665016], [80.02822876, 21.55734062], [80.03199005, 21.55755806], [80.03439331, 21.55747032], [80.03840637, 21.55685997], [80.04155731, 21.55624962], [80.04403687, 21.55514908], [80.04557037, 21.55475044], [80.04815674, 21.55414963], [80.05007172, 21.55411911], [80.0507431, 21.55411911], [80.05419922, 21.55354118], [80.05719757, 21.55360031], [80.05964661, 21.55373001], [80.06118774, 21.55401993], [80.06211853, 21.55424118], [80.06356812, 21.55458069], [80.06658936, 21.5568409], [80.06845856, 21.55847168], [80.07002258, 21.56038094], [80.07115936, 21.56200027], [80.07332611, 21.5638504], [80.07508087, 21.56513977], [80.07704163, 21.56675911], [80.07875824, 21.56839943], [80.08201599, 21.57176971], [80.08483887, 21.5761795], [80.08669281, 21.57855988], [80.0896759, 21.58228111], [80.09081268, 21.58356285], [80.09329987, 21.58537102], [80.09401703, 21.5862999], [80.09632111, 21.58743286], [80.09874725, 21.58865929], [80.10040283, 21.5887394], [80.10209656, 21.5893898], [80.10560608, 21.59111023], [80.10793304, 21.59211922], [80.10990143, 21.59341049], [80.11157227, 21.59647942], [80.11219025, 21.59955025], [80.11242676, 21.6008091], [80.11286926, 21.60377121], [80.11493683, 21.60700989], [80.11857605, 21.60889816], [80.12145233, 21.60906029], [80.12409973, 21.60861015], [80.12622833, 21.60830116], [80.13298798, 21.60560989], [80.13751984, 21.60519981], [80.14068604, 21.60472107], [80.1439209, 21.60497284], [80.14787292, 21.60630035], [80.14998627, 21.60741997], [80.1526413, 21.60970116], [80.15499115, 21.61179924], [80.15673828, 21.61412048], [80.15991974, 21.61749077], [80.16210175, 21.61948967], [80.16499329, 21.6217308], [80.16895294, 21.62320137], [80.17112732, 21.62374115], [80.17339325, 21.62412071], [80.1749115, 21.62396049], [80.17672729, 21.62392044], [80.18031311, 21.62552071], [80.18237305, 21.62704086], [80.18369293, 21.62849045], [80.18519592, 21.63064003], [80.18618774, 21.63266945], [80.18821716, 21.63420105], [80.18942261, 21.63425064], [80.19210815, 21.63462067], [80.19515228, 21.63493919], [80.20040131, 21.63470078], [80.20469666, 21.63354111], [80.20797729, 21.62965012], [80.21039581, 21.62627983], [80.21203613, 21.62421989], [80.21465302, 21.62124062], [80.21630859, 21.62034035], [80.22058868, 21.61963081], [80.22688293, 21.62010193], [80.23207092, 21.62045288], [80.23596954, 21.6207695], [80.24014282, 21.62051964], [80.24269867, 21.62049103], [80.24762726, 21.62249947], [80.25206757, 21.6222496], [80.25527954, 21.62072945], [80.25665283, 21.62028122], [80.26022339, 21.62014961], [80.2649765, 21.61655807], [80.27086639, 21.6106205], [80.27237701, 21.60712051], [80.27374268, 21.60263062], [80.2754364, 21.59907913], [80.27980042, 21.59613037], [80.28282928, 21.59511948], [80.28658295, 21.59343147], [80.28800964, 21.59229088], [80.28864288, 21.58965111], [80.28909302, 21.5884304], [80.28978729, 21.5859127], [80.29026794, 21.58263016], [80.29191589, 21.57802963], [80.29537201, 21.57547951], [80.29908752, 21.57538986], [80.30336761, 21.57612991], [80.30764008, 21.57674026], [80.30988312, 21.57734108], [80.31299591, 21.57709122], [80.31693268, 21.57568169], [80.31884003, 21.57455063], [80.3201828, 21.57357979], [80.32139587, 21.57059097], [80.32283783, 21.5674305], [80.324646, 21.56410027], [80.32628632, 21.56158066], [80.32746887, 21.55964088], [80.32858276, 21.5582695], [80.32977295, 21.55631065], [80.33009338, 21.55470085], [80.3290863, 21.55365944], [80.32728577, 21.55174065], [80.32559204, 21.55034065], [80.32443237, 21.5487175], [80.32740784, 21.54609108], [80.32968903, 21.54444122], [80.33097839, 21.54370117], [80.33294678, 21.54220963], [80.33516693, 21.54074097], [80.3380127, 21.53874969], [80.3396759, 21.53790283], [80.34229279, 21.53742027], [80.3463974, 21.53572083], [80.35189056, 21.53300285], [80.35691071, 21.53079987], [80.36219025, 21.52849007], [80.36582947, 21.52634048], [80.36762238, 21.52467918], [80.36923218, 21.52291107], [80.3706131, 21.52096939], [80.3707962, 21.51786995], [80.37085724, 21.51709175], [80.37117767, 21.51514816], [80.3724823, 21.51279068], [80.3735733, 21.50945091], [80.37386322, 21.50508118], [80.37388611, 21.50306129], [80.37422943, 21.50110054], [80.3745575, 21.49897957], [80.37483978, 21.49591064], [80.37486267, 21.49483109], [80.37494659, 21.49287033], [80.37532806, 21.49114037], [80.37578583, 21.49094009], [80.37767792, 21.49012947], [80.37858582, 21.48933029], [80.38021088, 21.48727036], [80.38170624, 21.48480034], [80.38272095, 21.48244095], [80.38366699, 21.47900009], [80.38445282, 21.47635078], [80.38685608, 21.47343254], [80.38994598, 21.47092819], [80.39209747, 21.46939087], [80.39528656, 21.46787071], [80.39659119, 21.46723938], [80.39904022, 21.46640015], [80.40096283, 21.46543121], [80.40223694, 21.46337128], [80.40367889, 21.46130943], [80.40453339, 21.45861053], [80.40467834, 21.45635986], [80.40535736, 21.45440102], [80.40644073, 21.45119286], [80.40825653, 21.44721985], [80.40947723, 21.4435997], [80.41055298, 21.44016075], [80.41130829, 21.4382019], [80.41024017, 21.43639946], [80.40862274, 21.43482971], [80.40600586, 21.43245125], [80.40426636, 21.4307003], [80.40161133, 21.42807961], [80.39891815, 21.42494011], [80.39803314, 21.42308998], [80.39996338, 21.41948128], [80.39924622, 21.41790962], [80.39678192, 21.41534996], [80.39347076, 21.41267014], [80.38990021, 21.40888977], [80.38907623, 21.40737915], [80.38906097, 21.40431976], [80.38983154, 21.40087128], [80.3915329, 21.39663124], [80.39389801, 21.39215088], [80.39653778, 21.38784981], [80.39792633, 21.3841095], [80.39935303, 21.38049126], [80.40112305, 21.3782711], [80.40196991, 21.37781143], [80.40336609, 21.37648964], [80.40444183, 21.37581062], [80.40656281, 21.37640953], [80.40844727, 21.3760891], [80.41028595, 21.37545967], [80.41407776, 21.37527275], [80.41760254, 21.37565041], [80.42095184, 21.37568283], [80.422966, 21.37524033], [80.42494202, 21.37450027], [80.42685699, 21.37308121], [80.42758179, 21.37290955], [80.43048096, 21.37189293], [80.43353271, 21.37118149], [80.43560791, 21.37125015], [80.4372406, 21.37137985], [80.4404068, 21.37210083], [80.44294739, 21.37379837], [80.44364166, 21.37639999], [80.44374847, 21.37969017], [80.44329071, 21.38463974], [80.44320679, 21.38799286], [80.44426727, 21.39052963], [80.44558716, 21.39256096], [80.44706726, 21.39557076], [80.44764709, 21.39846039], [80.44831848, 21.4023304], [80.45069885, 21.40234947], [80.45333862, 21.40036011], [80.45475006, 21.39966011], [80.45635986, 21.39870071], [80.46016693, 21.3970108], [80.46285248, 21.39635086], [80.46431732, 21.39590073], [80.46676636, 21.39557076], [80.4681778, 21.39524078], [80.47135162, 21.39583969], [80.47387695, 21.3993206], [80.47476196, 21.39575005], [80.47561646, 21.39472961], [80.47897339, 21.39590836], [80.48145294, 21.39697075], [80.48396301, 21.3972702], [80.48549652, 21.39763832], [80.48989868, 21.39635086], [80.49343872, 21.39423943], [80.49633026, 21.39294052], [80.50055695, 21.3907795], [80.50289154, 21.39058113], [80.50569153, 21.39072037], [80.50887299, 21.39109039], [80.51140594, 21.39186096], [80.5147171, 21.39101982], [80.51651001, 21.39051819], [80.51943207, 21.38957024], [80.52037048, 21.38825035], [80.52166748, 21.38734055], [80.52420044, 21.3837204], [80.5268631, 21.38166809], [80.52971649, 21.38095093], [80.53203583, 21.37728119], [80.53311157, 21.37486076], [80.53424835, 21.37205124], [80.53688049, 21.36913109], [80.53964996, 21.36852074], [80.54091644, 21.36812019], [80.54424286, 21.3672905], [80.54577637, 21.36626053], [80.55023193, 21.36474037], [80.55519867, 21.36271095], [80.55821991, 21.36128807], [80.55901337, 21.36112976], [80.55967712, 21.36038017], [80.56417084, 21.3578701], [80.56376648, 21.35573959], [80.56109619, 21.35440254], [80.5583725, 21.35316277], [80.5580368, 21.35103035], [80.55982971, 21.34856987], [80.56053925, 21.34546089], [80.56136322, 21.3433094], [80.56417847, 21.34277916], [80.56636047, 21.34280014], [80.5690918, 21.34443092], [80.57176971, 21.34560966], [80.57543945, 21.34379005], [80.57788849, 21.34300041], [80.58027649, 21.34210014], [80.58162689, 21.34159088], [80.58241272, 21.33722115], [80.58188629, 21.33432961], [80.58307648, 21.33116913], [80.58672333, 21.32946014], [80.58946991, 21.32834053], [80.59127045, 21.32674026], [80.59316254, 21.32479095], [80.59739685, 21.32349968], [80.59941101, 21.32323074], [80.60234833, 21.32372093], [80.60531616, 21.3243103], [80.60851288, 21.32393265], [80.61009216, 21.32262039], [80.61096191, 21.32170105], [80.61299133, 21.32034111], [80.61775208, 21.31917191], [80.6206665, 21.32015991], [80.62328339, 21.32146072], [80.62491608, 21.32182121], [80.62832642, 21.32258987], [80.63179016, 21.32372093], [80.63356018, 21.32418823], [80.63817596, 21.32485962], [80.64438629, 21.32547951], [80.64829254, 21.32637978], [80.65042877, 21.32993126], [80.65177155, 21.33119011], [80.65653229, 21.3307724], [80.6579361, 21.3293705], [80.65986633, 21.32777023], [80.66239929, 21.32612038], [80.66355896, 21.32485962], [80.66559601, 21.32211113], [80.66654205, 21.3193512], [80.66699982, 21.31618118], [80.6680603, 21.31381989], [80.67095184, 21.31228065], [80.67273712, 21.31126976], [80.67378998, 21.30908012], [80.67237091, 21.30588913], [80.67308807, 21.30117989], [80.67295074, 21.29828835], [80.67095947, 21.29590988], [80.66828918, 21.29399109], [80.66526794, 21.29229164], [80.66332245, 21.29095078], [80.6608963, 21.28977966], [80.65808868, 21.28940964], [80.65480804, 21.28951073], [80.65368652, 21.28604126], [80.65215302, 21.28325272], [80.65080261, 21.28158951], [80.64862061, 21.28017044], [80.64676666, 21.27814293], [80.64488983, 21.27600288], [80.64340973, 21.27229118], [80.64264679, 21.2690506], [80.64190674, 21.26442909], [80.64111328, 21.26143074], [80.63948059, 21.25749969], [80.63873291, 21.25478172], [80.63735962, 21.25269127], [80.63530731, 21.25013924], [80.6322403, 21.24729919], [80.62767029, 21.24570084], [80.62464142, 21.2442894], [80.62010193, 21.24236107], [80.61572266, 21.24002075], [80.61344147, 21.23682976], [80.61170959, 21.23456955], [80.61048889, 21.23329163], [80.60868835, 21.23179054], [80.60766602, 21.23125076], [80.60608673, 21.22997093], [80.60507965, 21.22875977], [80.60344696, 21.22742271], [80.60099792, 21.22618294], [80.59889984, 21.22512817], [80.59622192, 21.22453117], [80.5923233, 21.22484016], [80.58938599, 21.22471046], [80.58447266, 21.22306061], [80.5815506, 21.22177124], [80.57810211, 21.21990013], [80.57483673, 21.21825981], [80.57183838, 21.21685028], [80.56842804, 21.21388245], [80.56661224, 21.21080971], [80.56611633, 21.21027946], [80.56402588, 21.20802116], [80.56124115, 21.20581055], [80.55779266, 21.20393944], [80.55367279, 21.20251083], [80.55063629, 21.20117188], [80.54930115, 21.20098114], [80.54656982, 21.20066833], [80.54351044, 21.20001984], [80.54187775, 21.19919014], [80.53888702, 21.19928932], [80.53498077, 21.19960976], [80.532341, 21.20022011], [80.53045654, 21.20084], [80.5279007, 21.20202065], [80.52501678, 21.2026329], [80.52073669, 21.2035408], [80.51822662, 21.20108032], [80.51624298, 21.19829941], [80.51480103, 21.1960392], [80.51316833, 21.19361115], [80.5115509, 21.19111061], [80.51081085, 21.18890953], [80.5103302, 21.18649101], [80.50932312, 21.18347931], [80.50763702, 21.18244171], [80.50453186, 21.18304062], [80.50257111, 21.18330956], [80.49989319, 21.18404007], [80.49787903, 21.18403244], [80.49549866, 21.18325806], [80.49230957, 21.17994118], [80.48953247, 21.17756081], [80.48600006, 21.17719078], [80.48181152, 21.17657089], [80.47943878, 21.17493057], [80.47709656, 21.17307091], [80.47490692, 21.17143059], [80.4733429, 21.17131042], [80.46784973, 21.17148972], [80.46418762, 21.17209053], [80.46163177, 21.17282104], [80.45729828, 21.17284012], [80.45526886, 21.16908073], [80.45426941, 21.1654377], [80.45400238, 21.16174126], [80.45391846, 21.15862274], [80.45281982, 21.15434074], [80.45157623, 21.14965057], [80.45009613, 21.14691925], [80.44921875, 21.14442825], [80.44821167, 21.14152908], [80.44696045, 21.13814926], [80.44602966, 21.13578033], [80.44402313, 21.13060951], [80.44246674, 21.12816048], [80.44072723, 21.12547112], [80.43865204, 21.12140083], [80.44037628, 21.12030983], [80.44387054, 21.11925125], [80.44618988, 21.11816978], [80.44822693, 21.1162796], [80.44914246, 21.11531067], [80.44933319, 21.114851], [80.44924927, 21.11194038], [80.44696045, 21.1110611], [80.44550323, 21.11125946], [80.44371796, 21.11165047], [80.44226074, 21.11186981], [80.43950653, 21.11178017], [80.4390564, 21.10917091], [80.43872833, 21.10696983], [80.43766022, 21.10453033], [80.4367218, 21.10267067], [80.4360733, 21.10104752], [80.43518066, 21.09901047], [80.43419647, 21.09802246], [80.43331909, 21.0971508], [80.43550873, 21.09518051], [80.43640137, 21.09271049], [80.43813324, 21.08880806], [80.44000244, 21.08531952], [80.44095612, 21.08325195], [80.4420166, 21.08060074], [80.44254303, 21.07743073], [80.44275665, 21.07419014], [80.44261169, 21.07246017], [80.44097137, 21.07040024], [80.44259644, 21.06698036], [80.44297791, 21.06592941], [80.44399261, 21.06324005], [80.44474792, 21.06158066], [80.44610596, 21.05998993], [80.44727325, 21.0566597], [80.44763184, 21.05448914], [80.44822693, 21.05196953], [80.44850159, 21.04961014], [80.44786835, 21.04687119], [80.44706726, 21.04432106], [80.44734955, 21.04076195], [80.44754791, 21.03961945], [80.44734192, 21.03662109], [80.4465332, 21.03362083], [80.44523621, 21.03094292], [80.44325256, 21.02918816], [80.44085693, 21.02800941], [80.43860626, 21.02717018], [80.43675995, 21.02501106], [80.43596649, 21.02205086], [80.43454742, 21.01923943], [80.43247223, 21.01713181], [80.43010712, 21.01635933], [80.42881012, 21.01357079], [80.42758179, 21.01246071], [80.42375946, 21.00959015], [80.42475128, 21.00733948], [80.42662811, 21.00505066], [80.42948914, 21.00263977], [80.43334198, 20.99975014], [80.43808746, 20.99209976], [80.43894196, 20.97155952], [80.44069672, 20.96545982], [80.4437561, 20.96103287], [80.448349, 20.95101166], [80.4487915, 20.94530106], [80.45658875, 20.93724823], [80.45555878, 20.93210983], [80.45909119, 20.92815018], [80.46531677, 20.92728806], [80.47392273, 20.92736053], [80.48274994, 20.92847061], [80.4912796, 20.92785072], [80.50067902, 20.92891121], [80.51062012, 20.92880058], [80.52641296, 20.93210983], [80.5352478, 20.93132019], [80.5418396, 20.93391991], [80.53813171, 20.9260807], [80.53910065, 20.92106056], [80.54618835, 20.90307999], [80.54975891, 20.88891029], [80.54891205, 20.86808968], [80.55060577, 20.85991096], [80.55036926, 20.8456707], [80.55478668, 20.82942009], [80.55589294, 20.81968117], [80.55076599, 20.81546021], [80.54889679, 20.80841064], [80.54569244, 20.80137253], [80.54334259, 20.79179955], [80.54545593, 20.78227806], [80.54553223, 20.76536942], [80.54817963, 20.75908089], [80.55200958, 20.75345039], [80.55454254, 20.74715042], [80.55587006, 20.72257042], [80.56018829, 20.71177292], [80.56394958, 20.70718956], [80.57492065, 20.69842911], [80.57772064, 20.69407082], [80.5792923, 20.68997955], [80.58011627, 20.68364143], [80.57833862, 20.67877007], [80.57279205, 20.6742897], [80.56680298, 20.67292976], [80.55271149, 20.67308998], [80.54738617, 20.67126083], [80.53742218, 20.66402054], [80.5255661, 20.66319084], [80.51891327, 20.66176033], [80.50760651, 20.65460014], [80.50203705, 20.6491909], [80.48964691, 20.6398983], [80.48484802, 20.63517952], [80.48159027, 20.62976265], [80.48095703, 20.62355042], [80.4815979, 20.61709976], [80.48419189, 20.61195946], [80.49291229, 20.60408974], [80.49717712, 20.59580994], [80.50009918, 20.58686256], [80.51190186, 20.58511925], [80.51950836, 20.58468056], [80.52983093, 20.59008026], [80.55140686, 20.59907913], [80.55903625, 20.60997963], [80.56730652, 20.61240768], [80.57866669, 20.61412048], [80.58573151, 20.61415291], [80.59246826, 20.61309814], [80.60256958, 20.60738945], [80.60896301, 20.60598946], [80.61767578, 20.60617065], [80.62232208, 20.60386276], [80.61949158, 20.59791946], [80.61286163, 20.59057808], [80.61460876, 20.58527184], [80.61746979, 20.58103752], [80.61424255, 20.576931], [80.61972046, 20.56731987], [80.61707306, 20.56223106], [80.6121521, 20.55958939], [80.6099472, 20.55632973], [80.61178589, 20.55096054], [80.61029816, 20.5450592], [80.61341095, 20.54157066], [80.61273956, 20.53726006], [80.61003113, 20.53198051], [80.60852814, 20.51620293], [80.60688782, 20.51254082], [80.6072464, 20.50391006], [80.60620117, 20.48707008], [80.60494232, 20.48115158], [80.60331726, 20.46241951], [80.60166931, 20.45726013], [80.59468842, 20.44642067], [80.59715271, 20.44207001], [80.60144806, 20.4373703], [80.60343933, 20.43325043], [80.5998764, 20.42692184], [80.5944519, 20.42070961], [80.59173584, 20.41505051], [80.5897522, 20.41277122], [80.58651733, 20.40072823], [80.58602142, 20.39561081], [80.58598328, 20.39204979], [80.58744049, 20.38789177], [80.59017181, 20.38434982], [80.5983963, 20.38068008], [80.60222626, 20.37644005], [80.60072327, 20.37260056], [80.60089874, 20.36919022], [80.60513306, 20.36615944], [80.60620117, 20.36079025], [80.60601044, 20.35642052], [80.61149597, 20.34934235], [80.61071014, 20.34526062], [80.61667633, 20.33761024], [80.61776733, 20.33368111], [80.61669159, 20.32574081], [80.60671234, 20.32534981], [80.60542297, 20.32019043], [80.58423615, 20.3192997], [80.55158234, 20.31153107], [80.54202271, 20.30684853], [80.53930664, 20.30039024], [80.53582001, 20.29467964], [80.52667999, 20.2847805], [80.51082611, 20.26961136], [80.49447632, 20.27479935], [80.47587585, 20.27368927], [80.46544647, 20.2716217], [80.45646667, 20.26890945], [80.44838715, 20.26388168], [80.43730927, 20.25847816], [80.42294312, 20.25260925], [80.4196167, 20.25156021], [80.41526794, 20.25229073], [80.4090271, 20.24913025], [80.40371704, 20.24769974], [80.3862381, 20.24461174], [80.38295746, 20.2417202], [80.38803864, 20.23061943], [80.39800262, 20.21278], [80.40982056, 20.20528984], [80.41201782, 20.20220947], [80.41398621, 20.19023132], [80.41340637, 20.18753052], [80.40406036, 20.1844101], [80.39827728, 20.18344116], [80.39459229, 20.18158913], [80.39279938, 20.17740059], [80.39190674, 20.17073059], [80.39045715, 20.16627121], [80.38601685, 20.16280937], [80.38456726, 20.15851021], [80.38762665, 20.15158081], [80.39383698, 20.14402008], [80.40149689, 20.13951111], [80.42695618, 20.13023949], [80.4319458, 20.13134003], [80.4396286, 20.12911987], [80.44413757, 20.13034248], [80.44787598, 20.14157104], [80.45133972, 20.14487076], [80.45865631, 20.14455032], [80.46678162, 20.14268112], [80.47730255, 20.13853073], [80.48293304, 20.13788986], [80.4911499, 20.14147949], [80.49803162, 20.13891983], [80.50358582, 20.1287899], [80.51053619, 20.12693024], [80.51815033, 20.12683105], [80.52359009, 20.12447166], [80.52668762, 20.12137985], [80.52880859, 20.11750031], [80.53575897, 20.11384964], [80.54036713, 20.10983276], [80.54125214, 20.10494995], [80.53523254, 20.09218025], [80.53495789, 20.08539963], [80.54183197, 20.07668114], [80.54615784, 20.06571007], [80.54522705, 20.05957031], [80.54109192, 20.04818916], [80.54158783, 20.03722191], [80.53542328, 20.01120949], [80.53253937, 20.00393295], [80.53578949, 19.99991989], [80.53994751, 19.99772072], [80.54353333, 19.99508286], [80.54554749, 19.98718071], [80.54415131, 19.98151016], [80.53775787, 19.97356033], [80.53473663, 19.97092056], [80.53237152, 19.96706009], [80.53383636, 19.95302963], [80.52628326, 19.94862747], [80.52600861, 19.94112015], [80.52037811, 19.93087959], [80.50875092, 19.92591095], [80.5017395, 19.92475128], [80.48047638, 19.92780113], [80.47289276, 19.93124962], [80.469841, 19.93366051], [80.46875, 19.94026947], [80.46450043, 19.94625092], [80.45300293, 19.94523811], [80.4437027, 19.95267105], [80.43855286, 19.9471302], [80.43100739, 19.94094086], [80.42510986, 19.93730927], [80.42059326, 19.93622971], [80.40931702, 19.93538094], [80.40629578, 19.93250084], [80.40577698, 19.92545128], [80.40265656, 19.90960121], [80.4076767, 19.90590286], [80.41474915, 19.90291977], [80.43100739, 19.8984108], [80.43579865, 19.89551926], [80.44444275, 19.89355087], [80.45278931, 19.90000916], [80.46121979, 19.90343094], [80.46895599, 19.90336037], [80.48265076, 19.89889908], [80.48983765, 19.89367294], [80.49166107, 19.89053917], [80.4969101, 19.8771801], [80.49752045, 19.86874962], [80.48764038, 19.86512947], [80.47502136, 19.85705948], [80.47103119, 19.8426609], [80.46861267, 19.83753014], [80.46363068, 19.8358326], [80.46029663, 19.82802963], [80.45511627, 19.82379913], [80.44696808, 19.82032013], [80.43165588, 19.81030083], [80.42459106, 19.80804062], [80.41731262, 19.8091507], [80.40497589, 19.81542015], [80.3975296, 19.81623077], [80.39842987, 19.80319023], [80.39470673, 19.79457855], [80.40014648, 19.7936306], [80.41768646, 19.79714012], [80.42900848, 19.7951107], [80.43579102, 19.79185104], [80.44270325, 19.7905407], [80.44953918, 19.79265976], [80.45243835, 19.79290009], [80.46176147, 19.7882328], [80.46679688, 19.78487968], [80.47808838, 19.77240944], [80.4825592, 19.78071022], [80.48207092, 19.78950119], [80.48023987, 19.79544067], [80.47714233, 19.80122948], [80.47480774, 19.8033905], [80.46290588, 19.80575943], [80.45954895, 19.8113308], [80.46916199, 19.82466125], [80.47602844, 19.82800102], [80.4907074, 19.82536125], [80.49839783, 19.82947159], [80.50750732, 19.82994843], [80.51780701, 19.82886124], [80.5353775, 19.81813049], [80.54242706, 19.81927109], [80.54424286, 19.8112011], [80.54194641, 19.80315018], [80.54244232, 19.79424286], [80.53887177, 19.78070259], [80.53967285, 19.77459908], [80.55021667, 19.76455116], [80.56765747, 19.75667953], [80.57052612, 19.75473976], [80.57868195, 19.74392128], [80.58207703, 19.73807144], [80.59033203, 19.73443031], [80.61313629, 19.72892952], [80.62020874, 19.72377014], [80.63350677, 19.7184906], [80.64029694, 19.71245956], [80.64563751, 19.7064991], [80.66133881, 19.69750023], [80.66584015, 19.69221115], [80.66455078, 19.69075012], [80.666008, 19.68626976], [80.66538239, 19.67296982], [80.66220093, 19.66258049], [80.6561203, 19.62515068], [80.65589142, 19.6169796], [80.65685272, 19.61226082], [80.66203308, 19.60873032], [80.6830368, 19.61060905], [80.69668579, 19.61083031], [80.7077713, 19.61045837], [80.72099304, 19.60839081], [80.75795746, 19.59017181], [80.76426697, 19.58483124], [80.76503754, 19.57426071], [80.76641083, 19.56831932], [80.78515625, 19.56040955], [80.80922699, 19.56451035], [80.8196106, 19.56540108], [80.8276062, 19.56267166], [80.83352661, 19.55597115], [80.83605194, 19.54898071], [80.83737946, 19.54063034], [80.84082794, 19.53357124], [80.84538269, 19.5291729], [80.85225677, 19.52416992], [80.86334991, 19.52194977], [80.87359619, 19.52235031], [80.87905121, 19.51902962], [80.88553619, 19.50925064], [80.88970184, 19.49925041], [80.8914032, 19.49084091], [80.89215851, 19.4815197], [80.89206696, 19.46568108], [80.88562775, 19.45650291], [80.87599945, 19.44795036], [80.86749268, 19.44346046], [80.85748291, 19.44254112], [80.83508301, 19.44238091], [80.82524872, 19.43912125], [80.80799866, 19.43161964], [80.79432678, 19.42876816], [80.78793335, 19.42670059], [80.79244995, 19.42266083], [80.79538727, 19.4187603], [80.79795074, 19.4116497], [80.80854797, 19.39703941], [80.81273651, 19.38274002], [80.815979, 19.37907028], [80.8232193, 19.3747406], [80.83499908, 19.37068176], [80.84282684, 19.36610985], [80.84500885, 19.36091042], [80.83908081, 19.35515022], [80.82641602, 19.34803963], [80.81649017, 19.34247017], [80.81282806, 19.33813095], [80.80634308, 19.33490944], [80.80282593, 19.33228111], [80.79934692, 19.32516289], [80.7950058, 19.32476044], [80.78790283, 19.32411194], [80.78246307, 19.3217411], [80.77809143, 19.31854057], [80.7661972, 19.30813026], [80.76397705, 19.30527115], [80.75974274, 19.29975128], [80.75505066, 19.2952404], [80.74923706, 19.28674126], [80.7434082, 19.28597069], [80.73673248, 19.2869606], [80.73065948, 19.28403091], [80.7183075, 19.28549957], [80.70918274, 19.28330994], [80.70043945, 19.2822628], [80.6987381, 19.28227043], [80.69374847, 19.28232193], [80.68860626, 19.28348923], [80.68356323, 19.28691101], [80.68180084, 19.29584122], [80.68528748, 19.31260109], [80.68419647, 19.32002831], [80.67922211, 19.32414055], [80.67189026, 19.32644844], [80.66439056, 19.32657814], [80.65788269, 19.32427979], [80.63530731, 19.3128376], [80.62549591, 19.30681038], [80.61772156, 19.30481911], [80.6101532, 19.30714035], [80.60394287, 19.31176949], [80.60006714, 19.31809044], [80.59851837, 19.3246727], [80.59568024, 19.33131981], [80.59266663, 19.3352108], [80.58862305, 19.34440041], [80.58558655, 19.35301971], [80.58226013, 19.36833954], [80.5847168, 19.3737011], [80.5839386, 19.37715912], [80.57286072, 19.39842033], [80.57084656, 19.39942169], [80.56781769, 19.40092087], [80.55934143, 19.39755249], [80.53153992, 19.3743], [80.52612305, 19.36721039], [80.52271271, 19.35975075], [80.51898193, 19.35400963], [80.51383972, 19.34819984], [80.50720978, 19.34359169], [80.5003891, 19.34129906], [80.48110199, 19.33782005], [80.47558594, 19.33504295], [80.47049713, 19.32892036], [80.46530151, 19.31591988], [80.46450043, 19.31395149], [80.46212769, 19.3081398], [80.45680237, 19.2991581], [80.44542694, 19.26988983], [80.43702698, 19.26107025], [80.42807007, 19.25438118], [80.41916656, 19.25028038], [80.41446686, 19.24918938], [80.40818024, 19.24770164], [80.40157318, 19.24682999], [80.39684296, 19.2462101], [80.38845062, 19.24331093], [80.38334656, 19.23913956], [80.37918091, 19.2326107], [80.37702179, 19.21736908], [80.37993622, 19.20870972], [80.38611603, 19.19563293], [80.38667297, 19.18902016], [80.38111115, 19.18073082], [80.37290192, 19.1751194], [80.36235809, 19.16932106], [80.34546661, 19.16291046], [80.34411621, 19.16180992], [80.34059143, 19.15891838], [80.33963013, 19.15302086], [80.3355484, 19.14756966], [80.32485199, 19.1415329], [80.32086182, 19.12449074], [80.32235718, 19.12022018], [80.3296814, 19.10741997], [80.33154297, 19.10107994], [80.32411957, 19.09493065], [80.31994629, 19.0882206], [80.32256317, 19.08216095], [80.32211304, 19.07487106], [80.31996155, 19.06940269], [80.31577301, 19.06458092], [80.30224609, 19.05554962], [80.29170227, 19.04980087], [80.28884125, 19.04628944], [80.2905426, 19.04001045], [80.29528809, 19.02873993], [80.29341125, 19.02159119], [80.28811646, 19.01393127], [80.27230835, 18.99744034], [80.26772308, 18.98732948], [80.26753235, 18.98396111], [80.26734924, 18.98067093], [80.26902008, 18.96416092], [80.26747894, 18.95257187], [80.26531982, 18.94699287], [80.26412964, 18.94052124], [80.26468658, 18.93732071], [80.26516724, 18.93456078], [80.26763916, 18.92878914], [80.27046967, 18.92491913], [80.29138947, 18.90759087], [80.29810333, 18.9004612], [80.30856323, 18.88616753], [80.30990601, 18.88480186], [80.31346893, 18.88117981], [80.3216629, 18.87483025], [80.32565308, 18.86996078], [80.33573151, 18.85611916], [80.33963776, 18.8483429], [80.34558105, 18.83393097], [80.34850311, 18.82394028], [80.34778595, 18.81594086], [80.34622192, 18.81108093], [80.33470154, 18.80611038], [80.31873322, 18.79598045], [80.30589294, 18.79434967], [80.29943848, 18.79353142], [80.29415894, 18.79059029], [80.29017639, 18.78625107], [80.27953339, 18.76785278], [80.27655029, 18.76485062], [80.27182007, 18.76222038], [80.26541901, 18.76316071], [80.26291656, 18.76428986], [80.26145172, 18.76497078], [80.26065063, 18.7650795], [80.25456238, 18.76595116], [80.24900055, 18.76525116], [80.24215698, 18.75974846], [80.2405014, 18.75661087], [80.23956299, 18.75221062], [80.24079895, 18.74868965], [80.24745178, 18.74355125], [80.25480652, 18.73613167], [80.25753784, 18.7312603], [80.26753998, 18.71796989], [80.26036835, 18.71409988], [80.24666595, 18.70132065], [80.24169159, 18.70022011], [80.23557281, 18.70042038], [80.22998047, 18.69753075], [80.22531891, 18.69614983], [80.22000885, 18.69919014], [80.2143631, 18.70112991], [80.20787811, 18.70046043], [80.20191193, 18.6974411], [80.19410706, 18.68853188], [80.19165802, 18.6836319], [80.19095612, 18.67897034], [80.18895721, 18.67558098], [80.17565155, 18.67589951], [80.1709671, 18.67733955], [80.16739655, 18.68007088], [80.16462708, 18.69029808], [80.1619873, 18.69403076], [80.15808105, 18.69594002], [80.15220642, 18.69527817], [80.14874268, 18.69324112], [80.14227295, 18.68625259], [80.13658905, 18.68680191], [80.130867, 18.68541145], [80.12129211, 18.68120956], [80.11841583, 18.67913246], [80.11599731, 18.67584991], [80.11081696, 18.67618942], [80.10655975, 18.67752838], [80.10054779, 18.68495941], [80.08695221, 18.6975708], [80.08444214, 18.70084], [80.0821228, 18.7024498], [80.0789032, 18.70133972], [80.07470703, 18.70256042], [80.06790924, 18.70870972], [80.06549072, 18.71326256], [80.06189728, 18.71651268], [80.05326843, 18.71779823], [80.0463562, 18.72092056], [80.0328598, 18.74644089], [80.02966309, 18.74869919], [80.01870728, 18.75101089], [80.0165329, 18.75702095], [80.01448822, 18.76012993], [80.01235199, 18.76675987], [80.00908661, 18.76857948], [79.99291992, 18.77351952], [79.98153687, 18.77428055], [79.95014954, 18.77990913], [79.94007111, 18.78179169], [79.93199158, 18.78442955], [79.9162674, 18.79734039], [79.90909576, 18.80669022], [79.89401245, 18.83083916], [79.90409851, 18.83488083], [79.92082214, 18.83621025], [79.92550659, 18.83754158], [79.93332672, 18.84504128], [79.93900299, 18.85889244], [79.94094849, 18.87738991], [79.94011688, 18.89673805], [79.94135284, 18.91576958], [79.94094086, 18.93766022], [79.93588257, 18.95763969], [79.93221283, 18.97158051], [79.93134308, 18.97479057], [79.93279266, 18.99570084], [79.93448639, 19.02169991], [79.93306732, 19.02968979], [79.92597961, 19.04249001], [79.91610718, 19.04735947], [79.90293884, 19.04797935], [79.89084625, 19.04545021], [79.88111115, 19.04138947], [79.87103271, 19.03554153], [79.85958862, 19.03462982], [79.85700989, 19.04220009], [79.86109924, 19.05994987], [79.8600769, 19.09095955], [79.85804749, 19.10411072], [79.86310577, 19.11582184], [79.87120819, 19.12269974], [79.90596771, 19.14178848], [79.92230988, 19.15712929], [79.92611694, 19.16094971], [79.94069672, 19.1644001], [79.94320679, 19.17060089], [79.94243622, 19.17588043], [79.93525696, 19.18385124], [79.92250824, 19.20340919], [79.91932678, 19.21501923], [79.92016602, 19.22640991], [79.93190002, 19.25932121], [79.9451828, 19.28412056], [79.94895935, 19.28886032], [79.96177673, 19.29749107], [79.96364594, 19.30653954], [79.9573822, 19.32447052], [79.95715332, 19.33456993], [79.96452332, 19.3506794], [79.96652222, 19.36088943], [79.96724701, 19.37458038], [79.9707489, 19.38212967], [79.97260284, 19.39158058], [79.97305298, 19.40102005], [79.97000122, 19.40946007], [79.95923615, 19.42591095], [79.94577026, 19.44078064], [79.94621277, 19.45093918], [79.94499969, 19.45881844], [79.94020844, 19.46450996], [79.93725586, 19.46696091], [79.93286896, 19.46912193], [79.92354584, 19.47758102], [79.91779327, 19.48554039], [79.911026, 19.49234009], [79.90223694, 19.49649048], [79.87822723, 19.5007019], [79.87021637, 19.50496101], [79.86379242, 19.51359749], [79.85623169, 19.51711082], [79.82821655, 19.53701019], [79.82315826, 19.54430962], [79.82063293, 19.552351], [79.81954956, 19.56148911], [79.81659698, 19.56900978], [79.81109619, 19.57384109], [79.8052063, 19.57675934], [79.79329681, 19.58008957], [79.78629303, 19.58965111], [79.78542328, 19.59358978], [79.77754974, 19.59767914], [79.76628876, 19.60015106], [79.7542572, 19.60233116], [79.74032593, 19.60313988], [79.7299118, 19.59656906], [79.71292877, 19.58333015], [79.70511627, 19.58122063], [79.69568634, 19.58109093], [79.68479156, 19.57916832], [79.67801666, 19.57656288], [79.66504669, 19.57716942], [79.65261841, 19.57669258], [79.6397171, 19.57500076], [79.6213913, 19.56509972], [79.61580658, 19.55862999], [79.61090851, 19.54917908], [79.60721588, 19.53946114], [79.60293579, 19.52106857], [79.60243988, 19.51452065], [79.60085297, 19.50795174], [79.59805298, 19.50377083], [79.59134674, 19.50173187], [79.58265686, 19.50305176], [79.57344055, 19.50663948], [79.56559753, 19.5109005], [79.55249786, 19.52004242], [79.54769897, 19.52608109], [79.54519653, 19.5340004], [79.5447464, 19.54271126], [79.54265594, 19.54852295], [79.53499603, 19.54807091], [79.52622223, 19.54606056], [79.51499176, 19.54195023], [79.51481628, 19.54076195]]]]}}, {\\\"id\\\": \\\"18\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.21_1\\\", \\\"HASC_1\\\": \\\"IN.MN\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Manipur\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 28.7, \\\"dalys_apm25_rate_6cod_mean_total\\\": 826.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1782.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2608.0, \\\"geo-id\\\": 18, \\\"hpm25_child_popweighted\\\": 149.0, \\\"hpm25_female_popweighted\\\": 171.3, \\\"hpm25_male_popweighted\\\": 123.3, \\\"location\\\": \\\"Manipur\\\", \\\"mort_apm25_6cod_mean_total\\\": 839.0, \\\"mort_hpm25_6cod_mean_total\\\": 1814.0, \\\"mort_tpm25_6cod_mean_total\\\": 2653.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[94.25923157, 24.11981964], [94.2567215, 24.1066494], [94.25833893, 24.10159111], [94.26004791, 24.096241], [94.25969696, 24.08955956], [94.25403595, 24.0776825], [94.25022125, 24.07047844], [94.24717712, 24.06256294], [94.24645233, 24.06290054], [94.23993683, 24.06595039], [94.23307037, 24.06690025], [94.23522186, 24.05866051], [94.23677063, 24.05667877], [94.24357605, 24.04795074], [94.24532318, 24.04424286], [94.2315979, 24.02148056], [94.2256012, 24.0141201], [94.2203064, 24.00602913], [94.2154007, 23.99746132], [94.21029663, 23.99236107], [94.20130157, 23.97796822], [94.19449615, 23.96500969], [94.19354248, 23.95120049], [94.19683075, 23.9440403], [94.19596863, 23.93772125], [94.19042206, 23.93406105], [94.1834259, 23.9371109], [94.18180084, 23.93782043], [94.17690277, 23.93884087], [94.17077637, 23.93509293], [94.16951752, 23.92868996], [94.16896057, 23.91150093], [94.16822815, 23.88913918], [94.16503906, 23.86486053], [94.16146088, 23.85277939], [94.15766907, 23.85194778], [94.15544891, 23.8514595], [94.14714813, 23.85611916], [94.14614868, 23.85609245], [94.13929749, 23.85589981], [94.13514709, 23.84607124], [94.12882996, 23.84277916], [94.1228714, 23.84273148], [94.12264252, 23.84272957], [94.11479187, 23.85245132], [94.11476135, 23.85316277], [94.11411285, 23.86663055], [94.11161041, 23.87088013], [94.10418701, 23.87717056], [94.10096741, 23.88902283], [94.09609222, 23.89357185], [94.09060669, 23.89450073], [94.08545685, 23.89318085], [94.075737, 23.89306068], [94.06848145, 23.89562035], [94.06092834, 23.89730263], [94.05661011, 23.89760017], [94.05111694, 23.90043068], [94.04931641, 23.90739059], [94.04691315, 23.91337013], [94.04322052, 23.91800117], [94.03794098, 23.92056084], [94.03410339, 23.9221096], [94.02774811, 23.92604256], [94.021492, 23.93149185], [94.01769257, 23.93395042], [94.0133667, 23.93452072], [94.00804138, 23.93320084], [94.00152588, 23.93115997], [93.99543762, 23.93153954], [93.98963165, 23.93202972], [93.98158264, 23.93325996], [93.97638702, 23.93526077], [93.96938324, 23.93394089], [93.96224213, 23.93714905], [93.96179199, 23.94338989], [93.95996857, 23.94692039], [93.95378113, 23.95019913], [93.94161987, 23.95279121], [93.93580627, 23.95337105], [93.92637634, 23.95541], [93.9209671, 23.95677948], [93.91390228, 23.95745087], [93.90702057, 23.95713997], [93.90207672, 23.95561028], [93.89608002, 23.95482826], [93.89103699, 23.95178032], [93.88706207, 23.94746971], [93.88156128, 23.94713974], [93.87702179, 23.94688034], [93.87316895, 23.94391823], [93.8662262, 23.93791962], [93.84863281, 23.93807983], [93.8375473, 23.93208122], [93.82821655, 23.9314003], [93.81598663, 23.92982864], [93.80928802, 23.93261147], [93.80805969, 23.93312073], [93.80573273, 23.9373703], [93.80531311, 23.94721985], [93.80356598, 23.95111084], [93.80113983, 23.95555115], [93.79721832, 23.95664978], [93.79428864, 23.96282005], [93.79354858, 23.96751022], [93.78562164, 23.96944046], [93.77934265, 23.97787094], [93.77349091, 23.98240089], [93.77027893, 23.99001122], [93.7665863, 23.99698067], [93.76222229, 24.00414085], [93.75694275, 24.00949287], [93.74661255, 24.00854111], [93.7443924, 24.00123024], [93.73995209, 23.9991703], [93.73280334, 24.00180817], [93.72677612, 24.00383186], [93.72020721, 24.00556946], [93.71272278, 24.00523949], [93.70613098, 24.00643921], [93.69699097, 24.00747108], [93.68647766, 24.00967979], [93.67752075, 24.01106834], [93.67444611, 24.00808907], [93.6675415, 24.00540924], [93.66281891, 24.00470924], [93.65880585, 24.00724983], [93.65497589, 24.00998116], [93.65244293, 24.01350975], [93.6449585, 24.01408005], [93.63532257, 24.01338005], [93.62766266, 24.01522064], [93.62065887, 24.01424026], [93.61630249, 24.01074028], [93.61666107, 24.00296974], [93.61959839, 24.00000381], [93.62007904, 23.99952126], [93.62075043, 23.99529076], [93.62091064, 23.99119949], [93.61593628, 23.98147011], [93.61225891, 23.97714806], [93.60929108, 23.97344971], [93.60614777, 23.97136879], [93.60346222, 23.96959114], [93.59715271, 23.96726036], [93.59263611, 23.96799088], [93.58386993, 23.96846962], [93.58049011, 23.97008514], [93.58006287, 23.97029114], [93.57714844, 23.97789001], [93.57244873, 23.98324013], [93.56884003, 23.98867035], [93.5635376, 23.98957825], [93.56124878, 23.9856205], [93.55725861, 23.97966003], [93.55751801, 23.9701004], [93.55493164, 23.9652195], [93.5463562, 23.96326065], [93.53946686, 23.96327972], [93.53050232, 23.96077919], [93.52416992, 23.95473099], [93.51986694, 23.95049667], [93.51941681, 23.95005035], [93.51508331, 23.94716835], [93.50871277, 23.94890022], [93.50254059, 23.95578003], [93.49594879, 23.95716095], [93.48938751, 23.9615097], [93.48577118, 23.9675808], [93.47802734, 23.96949005], [93.47220612, 23.97068024], [93.46885681, 23.9739399], [93.46615601, 23.97919083], [93.46669769, 23.9875927], [93.46739197, 23.99201965], [93.46735382, 23.99282837], [93.46697998, 23.99930954], [93.46614075, 24.00024033], [93.46312714, 24.00358963], [93.45881653, 24.00966072], [93.45736694, 24.01506805], [93.45326233, 24.02285004], [93.44403076, 24.02775955], [93.44111633, 24.03471947], [93.43995667, 24.04356956], [93.43286896, 24.06166267], [93.42473602, 24.07171059], [93.42022705, 24.0760498], [93.41542816, 24.07921982], [93.4105072, 24.08167076], [93.40422058, 24.08429909], [93.39112854, 24.0882206], [93.38336182, 24.08932114], [93.37046051, 24.09222984], [93.36863708, 24.09255981], [93.36643219, 24.09296989], [93.36151886, 24.10020256], [93.35674286, 24.10906982], [93.3514328, 24.11241913], [93.3469162, 24.11296844], [93.34903717, 24.10510063], [93.35089874, 24.10156822], [93.35383606, 24.09768105], [93.34681702, 24.0922699], [93.34358215, 24.09436035], [93.33934021, 24.09320068], [93.33400726, 24.09012985], [93.33583069, 24.08537483], [93.33598328, 24.08497047], [93.33761597, 24.07892036], [93.33886719, 24.07232094], [93.3420105, 24.06743813], [93.33734894, 24.06093979], [93.33634949, 24.05669975], [93.33737183, 24.05340004], [93.31254578, 24.05413055], [93.29824829, 24.05158997], [93.28819275, 24.05154991], [93.28536987, 24.04652023], [93.27677917, 24.04021072], [93.27394867, 24.03392029], [93.25528717, 24.02379036], [93.25670624, 24.0288105], [93.25238037, 24.03383064], [93.2623291, 24.05772972], [93.26374054, 24.05774117], [93.26660919, 24.06026077], [93.26373291, 24.06778908], [93.26371765, 24.07282066], [93.24801636, 24.08533859], [93.24233246, 24.08657074], [93.2366333, 24.08403969], [93.22667694, 24.08653069], [93.22383881, 24.08401108], [93.22241974, 24.08148956], [93.22525024, 24.07396126], [93.22242737, 24.06767273], [93.22100067, 24.06137085], [93.21673584, 24.05006027], [93.19825745, 24.05249977], [93.19400787, 24.0562706], [93.17838287, 24.05409622], [93.17552185, 24.05369949], [93.16983795, 24.05495262], [93.16697693, 24.06121826], [93.16986847, 24.07127953], [93.1698761, 24.0750618], [93.16131592, 24.07756042], [93.15846252, 24.08381844], [93.14791107, 24.0880909], [93.14219666, 24.08678818], [93.13508606, 24.07921028], [93.13507843, 24.07291985], [93.12937164, 24.06408119], [93.12081909, 24.06026077], [93.11940765, 24.05647278], [93.11231232, 24.05519104], [93.11087799, 24.05014992], [93.10662842, 24.04886055], [93.10092163, 24.04508972], [93.09951019, 24.04883957], [93.1037674, 24.05262947], [93.10092926, 24.05639076], [93.1023407, 24.06269264], [93.10090637, 24.06645012], [93.10234833, 24.07401085], [93.09520721, 24.0802803], [93.08950806, 24.08405113], [93.08522797, 24.0903511], [93.07949066, 24.10297012], [93.07377625, 24.10049057], [93.06519318, 24.09427071], [93.05368805, 24.09069061], [93.03769684, 24.09518051], [93.03469849, 24.09924126], [93.03029633, 24.10083008], [93.02729797, 24.1036396], [93.021492, 24.10145187], [93.01410675, 24.10453033], [93.0096817, 24.10995293], [93.00068665, 24.11519241], [92.99642181, 24.11672974], [92.98929596, 24.1163311], [92.98477936, 24.11482048], [92.97637939, 24.11482048], [92.97486877, 24.11701965], [92.97360229, 24.12388039], [92.97756195, 24.12639046], [92.98606873, 24.12887955], [92.9894104, 24.13178062], [92.99286652, 24.1403904], [92.99092102, 24.14686966], [92.99112701, 24.15032959], [92.99308014, 24.15317917], [93.00067139, 24.15673065], [93.00544739, 24.1606102], [93.00550079, 24.16321182], [93.00331116, 24.17404938], [93.01091766, 24.18221283], [93.00309753, 24.19431114], [93.0030365, 24.19752121], [93.01236725, 24.19754028], [93.01661682, 24.20003128], [93.01799774, 24.20754814], [93.02229309, 24.21006012], [93.02368164, 24.21756935], [93.01940155, 24.22508812], [93.01940918, 24.22884941], [93.02658844, 24.23263168], [93.01803589, 24.23637009], [93.00670624, 24.25395966], [93.00673676, 24.26279068], [93.01391602, 24.27166939], [93.00821686, 24.28047943], [93.01107788, 24.28808022], [93.01821899, 24.29315948], [93.02391815, 24.3007412], [93.03523254, 24.31839943], [93.04337311, 24.34338951], [93.03176117, 24.34449005], [93.0215683, 24.34682083], [93.01933289, 24.35884857], [93.02011108, 24.36597252], [93.0220871, 24.37421989], [93.01709747, 24.37996101], [93.02435303, 24.3904705], [93.00049591, 24.40327072], [93.00644684, 24.41193008], [93.00889587, 24.40537071], [93.01599121, 24.40253067], [93.02921295, 24.40633965], [93.03916931, 24.41113091], [93.03932953, 24.41756821], [93.03215027, 24.42885971], [93.03674316, 24.44394112], [93.03790283, 24.46115112], [93.04825592, 24.46396065], [93.04852295, 24.47548294], [93.04572296, 24.48181915], [93.0357666, 24.49694824], [93.04432678, 24.50580025], [93.04001617, 24.51081085], [93.04141998, 24.51459122], [93.05282593, 24.51964951], [93.05282593, 24.52466965], [93.04846954, 24.53091049], [93.05130005, 24.53718948], [93.05268097, 24.5447197], [93.06121826, 24.55477905], [93.0655365, 24.54726982], [93.07269287, 24.56109047], [93.06111908, 24.57483292], [93.07122803, 24.57613182], [93.07845306, 24.57491112], [93.08714294, 24.57118034], [93.09622955, 24.58022118], [93.09726715, 24.58254051], [93.10447693, 24.58257294], [93.10697937, 24.58356094], [93.10675049, 24.58395958], [93.10444641, 24.58760262], [93.09866333, 24.59134293], [93.08854675, 24.59003067], [93.07981873, 24.59250069], [93.07541656, 24.59622955], [93.07538605, 24.60000038], [93.07678223, 24.60377121], [93.08676147, 24.61133003], [93.08673096, 24.61382103], [93.08233643, 24.61758041], [93.079422, 24.62132263], [93.07935333, 24.62634087], [93.08220673, 24.62760162], [93.08938599, 24.62763023], [93.08930206, 24.63389015], [93.0848465, 24.64767075], [93.08625793, 24.65143967], [93.08912659, 24.65270996], [93.09628296, 24.6527195], [93.09626007, 24.6564827], [93.09765625, 24.6590004], [93.09763336, 24.66276169], [93.09903717, 24.66653061], [93.103302, 24.67156029], [93.10470581, 24.67534256], [93.10469055, 24.67910004], [93.1018219, 24.68035126], [93.09754181, 24.67782021], [93.09324646, 24.67654991], [93.09179688, 24.67781067], [93.09179688, 24.68032074], [93.09320068, 24.68408012], [93.09319305, 24.68785286], [93.09028625, 24.69286919], [93.08452606, 24.69787025], [93.08306885, 24.70164108], [93.08020782, 24.70414162], [93.0758667, 24.71039009], [93.0786972, 24.71417046], [93.08878326, 24.70919037], [93.09303284, 24.71548271], [93.09443665, 24.72050858], [93.09298706, 24.72426033], [93.09442902, 24.7242794], [93.09729004, 24.72805023], [93.09725952, 24.73180962], [93.10441589, 24.73686981], [93.1072464, 24.74189949], [93.10579681, 24.74566078], [93.10292053, 24.74690056], [93.10293579, 24.74315071], [93.10150146, 24.74188042], [93.09864044, 24.74438095], [93.10147095, 24.74941063], [93.10003662, 24.75066948], [93.10002899, 24.75444031], [93.10427856, 24.76324081], [93.10566711, 24.76953125], [93.10280609, 24.77329063], [93.10132599, 24.77831078], [93.10706329, 24.78334045], [93.10562897, 24.78460121], [93.10558319, 24.78837013], [93.10845947, 24.7908802], [93.11270142, 24.80220985], [93.10978699, 24.80974007], [93.11122131, 24.81226158], [93.11979675, 24.81731033], [93.12267303, 24.81982994], [93.12269592, 24.8148098], [93.11984253, 24.81102943], [93.12127686, 24.80853081], [93.12700653, 24.80854034], [93.13134003, 24.80604172], [93.13706207, 24.81109047], [93.13994598, 24.80480957], [93.14285278, 24.80105972], [93.14428711, 24.79980087], [93.14861298, 24.7985611], [93.15148163, 24.79605103], [93.15293121, 24.79353905], [93.15294647, 24.78977966], [93.15724182, 24.79231071], [93.16153717, 24.79734039], [93.16581726, 24.79861069], [93.16867828, 24.80112839], [93.17442322, 24.80367088], [93.1758728, 24.79738808], [93.1772995, 24.79611969], [93.17875671, 24.79614067], [93.18017578, 24.79865074], [93.18017578, 24.80241966], [93.18158722, 24.80493927], [93.18589783, 24.80495071], [93.19020081, 24.80622101], [93.19307709, 24.80623055], [93.19449615, 24.80875015], [93.19735718, 24.81126022], [93.19877625, 24.81504059], [93.19590759, 24.8162899], [93.19159698, 24.82256126], [93.19300079, 24.82632065], [93.19728851, 24.83388138], [93.19297791, 24.83386993], [93.19297028, 24.83638191], [93.19438934, 24.83764076], [93.1958313, 24.83764076], [93.19870758, 24.83638954], [93.20155334, 24.84017181], [93.20012665, 24.84143066], [93.19869995, 24.84016037], [93.19727325, 24.84016037], [93.19438171, 24.84391975], [93.19580078, 24.84644127], [93.20155334, 24.84394073], [93.20152283, 24.85021973], [93.19864655, 24.8527298], [93.19719696, 24.85649109], [93.20007324, 24.85775948], [93.20584106, 24.85526085], [93.20870209, 24.85653114], [93.21013641, 24.85904121], [93.2142868, 24.86194992], [93.21618652, 24.86469078], [93.21906281, 24.86972046], [93.22194672, 24.87099266], [93.22480774, 24.87478065], [93.22908783, 24.87730026], [93.22621918, 24.88106918], [93.22908783, 24.88484001], [93.23339081, 24.88484955], [93.23483276, 24.88989067], [93.23049164, 24.89490128], [93.23338318, 24.89491081], [93.23338318, 24.89869118], [93.23622131, 24.90245056], [93.24195099, 24.90122032], [93.24337769, 24.90374184], [93.24336243, 24.90750122], [93.24188995, 24.91127014], [93.23899078, 24.91502953], [93.24043274, 24.91628075], [93.24185944, 24.91504097], [93.25045776, 24.91506195], [93.25325775, 24.91883087], [93.25019836, 24.93008041], [93.24450684, 24.93008041], [93.24304962, 24.93132973], [93.24720001, 24.93634033], [93.24849701, 24.94009972], [93.24707794, 24.94009972], [93.24143982, 24.93758965], [93.24003601, 24.93758011], [93.2399826, 24.93884277], [93.24131775, 24.94133949], [93.24407959, 24.94384003], [93.24693298, 24.94384956], [93.24983978, 24.94260025], [93.25411987, 24.94261932], [93.25110626, 24.94634819], [93.25092316, 24.95009995], [93.24938965, 24.95259285], [93.24923706, 24.95508003], [93.25354004, 24.95508957], [93.25950623, 24.9513607], [93.26241302, 24.95137024], [93.26082611, 24.95387077], [93.2605896, 24.95887184], [93.26332855, 24.96388054], [93.263237, 24.96637917], [93.25871277, 24.97265053], [93.2529068, 24.97262955], [93.25287628, 24.97514915], [93.25432587, 24.97891998], [93.25152588, 24.98142052], [93.25302124, 24.98266029], [93.25325775, 24.98637009], [93.25202179, 24.98880959], [93.25525665, 24.99240112], [93.25695801, 24.99602127], [93.25705719, 24.99847031], [93.25562286, 24.99971008], [93.25567627, 25.00220108], [93.2571106, 25.00094032], [93.26143646, 25.00092125], [93.26332092, 25.00423813], [93.26245117, 25.00602913], [93.25990295, 25.00645065], [93.25800323, 25.00420952], [93.2576828, 25.00350189], [93.25710297, 25.00319099], [93.2564621, 25.00311089], [93.25580597, 25.00325966], [93.25533295, 25.00364113], [93.25521088, 25.00420952], [93.253479, 25.00637054], [93.2518158, 25.00418091], [93.25121307, 25.00348091], [93.25064087, 25.00316048], [93.25, 25.00295067], [93.24935913, 25.00287247], [93.24868774, 25.00290108], [93.24807739, 25.00303078], [93.24746704, 25.00328064], [93.24694824, 25.00363159], [93.24669647, 25.00416756], [93.24916077, 25.01316071], [93.25171661, 25.01601982], [93.24884033, 25.01880074], [93.25382996, 25.02135086], [93.25778961, 25.02174187], [93.25836945, 25.02519989], [93.2556076, 25.0286808], [93.25984955, 25.03207016], [93.2638092, 25.0359211], [93.26391602, 25.03890991], [93.26291656, 25.0418396], [93.26835632, 25.04409027], [93.26946259, 25.04659081], [93.26779938, 25.04880905], [93.26818085, 25.04968071], [93.28449249, 25.05154991], [93.28687286, 25.04680061], [93.29189301, 25.04709053], [93.29698181, 25.04767036], [93.29933929, 25.05046082], [93.30008698, 25.05260086], [93.30240631, 25.05194092], [93.30245972, 25.04818916], [93.30459595, 25.04799271], [93.30425262, 25.05603027], [93.30892944, 25.05852127], [93.30607605, 25.0644207], [93.30879211, 25.07059288], [93.31079102, 25.07262993], [93.31272125, 25.07795906], [93.32234192, 25.08838081], [93.32363129, 25.09167099], [93.32950592, 25.09449959], [93.33577728, 25.09584045], [93.33917236, 25.10640907], [93.34046173, 25.11441994], [93.34435272, 25.1161499], [93.34436035, 25.12133026], [93.34644318, 25.12508965], [93.34921265, 25.12540817], [93.3470459, 25.12746048], [93.34607697, 25.12986946], [93.34889984, 25.13479042], [93.34686279, 25.13770103], [93.35101318, 25.14454079], [93.34855652, 25.15349007], [93.34883881, 25.15717125], [93.3473587, 25.16389084], [93.34915161, 25.16673088], [93.35307312, 25.18180084], [93.36081696, 25.19195938], [93.36222076, 25.19560814], [93.3685379, 25.20005035], [93.37056732, 25.20359039], [93.36958313, 25.20806122], [93.3780899, 25.21610069], [93.37950134, 25.22079086], [93.38198853, 25.22386932], [93.38479614, 25.2257309], [93.38551331, 25.22855759], [93.38762665, 25.23204041], [93.38710022, 25.24239159], [93.38871765, 25.24592018], [93.39459229, 25.25029945], [93.40357208, 25.26307106], [93.40634155, 25.26408005], [93.41205597, 25.26345062], [93.4207077, 25.26626015], [93.42330933, 25.27216148], [93.42331696, 25.27791023], [93.42642975, 25.28106117], [93.43863678, 25.28655052], [93.44481659, 25.29231071], [93.45197296, 25.29474831], [93.45996857, 25.29473114], [93.46559143, 25.29905128], [93.47402191, 25.3092804], [93.4751358, 25.29968071], [93.47463226, 25.29241943], [93.47258759, 25.28544044], [93.47675323, 25.27903938], [93.48338318, 25.27663994], [93.4875412, 25.2759304], [93.49489594, 25.27872086], [93.50437927, 25.27577019], [93.51078796, 25.27560806], [93.50417328, 25.25338173], [93.50514221, 25.24413109], [93.50843048, 25.24370956], [93.51642609, 25.24477005], [93.52060699, 25.2487812], [93.52935791, 25.24835968], [93.54120636, 25.2453804], [93.54717255, 25.24849129], [93.55471039, 25.25052834], [93.56313324, 25.24658966], [93.57009888, 25.23560905], [93.57076263, 25.23245049], [93.57485199, 25.22755051], [93.57820129, 25.22569084], [93.58164978, 25.22600937], [93.58584595, 25.22231102], [93.58805847, 25.22216988], [93.59028625, 25.21994972], [93.59197998, 25.21390915], [93.594841, 25.21113014], [93.59285736, 25.20667076], [93.59303284, 25.20391273], [93.5970993, 25.20429993], [93.60103607, 25.20239258], [93.60428619, 25.20432091], [93.60801697, 25.20205116], [93.61257935, 25.20619011], [93.62114716, 25.22491264], [93.62890625, 25.23574829], [93.63186646, 25.24291992], [93.63809204, 25.25039864], [93.64311981, 25.26001167], [93.64354706, 25.26588249], [93.64990997, 25.26911926], [93.65136719, 25.27366066], [93.65161896, 25.27902031], [93.66561127, 25.29842949], [93.66474915, 25.30424118], [93.66609192, 25.30828094], [93.67294312, 25.31151009], [93.67395782, 25.31728172], [93.67207336, 25.32871056], [93.68392181, 25.3296299], [93.68712616, 25.33121109], [93.69145203, 25.34741974], [93.69277954, 25.36158943], [93.69998169, 25.35942268], [93.711586, 25.35808945], [93.71804047, 25.36160088], [93.71897888, 25.37035942], [93.72310638, 25.37558174], [93.73100281, 25.38037109], [93.73979187, 25.38441849], [93.74131775, 25.38944054], [93.74006653, 25.39517975], [93.74198914, 25.39991951], [93.74666595, 25.40571022], [93.76033783, 25.41411972], [93.76441956, 25.41813087], [93.78106689, 25.42471123], [93.78053284, 25.42950058], [93.78447723, 25.43193817], [93.78810883, 25.43588066], [93.79020691, 25.44338036], [93.79374695, 25.4486599], [93.79836273, 25.45393181], [93.8024292, 25.46040916], [93.80522919, 25.46342087], [93.80899811, 25.46558952], [93.81388855, 25.48472977], [93.80760956, 25.49555969], [93.80404663, 25.49902916], [93.79724884, 25.50438118], [93.78846741, 25.50649071], [93.77339172, 25.49784088], [93.76934814, 25.49677277], [93.76579285, 25.49990082], [93.76428986, 25.51548195], [93.76931763, 25.51770973], [93.76818085, 25.52529144], [93.76895142, 25.53071022], [93.77097321, 25.53602028], [93.77063751, 25.54027939], [93.77182007, 25.54080963], [93.77948761, 25.5380497], [93.80784607, 25.54451942], [93.81594086, 25.5454483], [93.81971741, 25.54438972], [93.823349, 25.54816246], [93.82504272, 25.55599976], [93.83325958, 25.55642128], [93.83347321, 25.56137276], [93.83648682, 25.56306076], [93.84420776, 25.56169128], [93.85231781, 25.55864906], [93.86223602, 25.55752945], [93.87837219, 25.5619812], [93.89196014, 25.56842041], [93.90023804, 25.5687294], [93.90484619, 25.56742859], [93.9108963, 25.56752968], [93.91709137, 25.56672096], [93.91932678, 25.56402969], [93.93012238, 25.56538963], [93.94351959, 25.56343269], [93.94516754, 25.56263924], [93.95738983, 25.55675125], [93.96521759, 25.55657768], [93.97264862, 25.56118011], [93.97785187, 25.5661602], [93.98046875, 25.57125282], [94.00061035, 25.57388115], [94.00744629, 25.56985092], [94.01042175, 25.57131195], [94.01159668, 25.57274818], [94.01228333, 25.57529831], [94.0117569, 25.57909012], [94.00782776, 25.58752823], [94.00765228, 25.59094048], [94.01039886, 25.59539986], [94.01473236, 25.59613037], [94.0255127, 25.59338951], [94.02726746, 25.58798981], [94.03340912, 25.58470154], [94.03489685, 25.58148956], [94.03791809, 25.58192825], [94.03916168, 25.5830307], [94.03900909, 25.57986069], [94.04361725, 25.57748032], [94.04599762, 25.58094978], [94.05412292, 25.57675934], [94.06469727, 25.56637001], [94.06941986, 25.55898094], [94.08003998, 25.56159973], [94.08595276, 25.55973053], [94.09496307, 25.54644012], [94.09619904, 25.54171944], [94.09252167, 25.53796959], [94.09210968, 25.5327301], [94.1060791, 25.52890015], [94.12850952, 25.52588081], [94.13873291, 25.52370071], [94.14523315, 25.52763939], [94.14820099, 25.5316906], [94.15184021, 25.54185104], [94.15287781, 25.54784012], [94.16011047, 25.55525017], [94.16352844, 25.54992104], [94.16790771, 25.54701042], [94.17954254, 25.55018997], [94.18276978, 25.55325127], [94.19184875, 25.550951], [94.19487, 25.5524292], [94.19390869, 25.54219818], [94.19013977, 25.53462982], [94.19072723, 25.53078079], [94.19924927, 25.52276993], [94.20688629, 25.51395035], [94.20690155, 25.51164055], [94.21292877, 25.50817108], [94.2128067, 25.50282097], [94.21485138, 25.50024033], [94.21985626, 25.49962997], [94.22297668, 25.49677277], [94.22914124, 25.49600983], [94.23174286, 25.49831009], [94.25205994, 25.49907112], [94.25726318, 25.50341988], [94.26693726, 25.5024395], [94.27414703, 25.50299072], [94.27986908, 25.5054512], [94.28674316, 25.51169968], [94.29074097, 25.50951958], [94.29899597, 25.50070953], [94.30264282, 25.49463272], [94.30898285, 25.49380112], [94.3135376, 25.4944706], [94.32068634, 25.49928093], [94.32901001, 25.50835037], [94.3646698, 25.5214901], [94.38854218, 25.5365696], [94.40448761, 25.54089928], [94.4108963, 25.54351807], [94.41680908, 25.54194069], [94.42027283, 25.54265022], [94.42559052, 25.55291939], [94.4263916, 25.56145096], [94.42510223, 25.57299995], [94.42237854, 25.57599068], [94.42565918, 25.58147049], [94.43002319, 25.59272194], [94.43773651, 25.59585953], [94.44428253, 25.59601021], [94.44782257, 25.59804153], [94.44927216, 25.60108948], [94.47403717, 25.62164116], [94.49118042, 25.61979866], [94.49111176, 25.61865044], [94.49341583, 25.61433029], [94.4992981, 25.61650276], [94.49993896, 25.61881828], [94.5, 25.61885643], [94.50183105, 25.62002182], [94.50537109, 25.61699295], [94.50779724, 25.61894989], [94.50866699, 25.62689972], [94.5109024, 25.62990952], [94.51451111, 25.63049126], [94.52419281, 25.64343262], [94.52818298, 25.64429092], [94.53066254, 25.64258957], [94.53154755, 25.65012932], [94.53954315, 25.65108109], [94.54473877, 25.65754128], [94.5517807, 25.66246033], [94.55222321, 25.6674118], [94.56507874, 25.68082047], [94.56799316, 25.69222069], [94.57301331, 25.69765091], [94.57861328, 25.69599915], [94.58297729, 25.69320107], [94.58705139, 25.69189072], [94.5956192, 25.69128036], [94.59694672, 25.68691063], [94.58996582, 25.68124962], [94.58812714, 25.67727089], [94.58532715, 25.67485046], [94.58737183, 25.67180061], [94.58558655, 25.67000961], [94.58344269, 25.66522026], [94.58522034, 25.6617794], [94.58204651, 25.6606102], [94.58135223, 25.6573925], [94.57678986, 25.65283012], [94.57723236, 25.64833069], [94.57608795, 25.644701], [94.58693695, 25.64659119], [94.59519958, 25.64385033], [94.59455109, 25.6426506], [94.59050751, 25.64027023], [94.58377075, 25.63449097], [94.57850647, 25.62625122], [94.57691956, 25.62037277], [94.57282257, 25.61131287], [94.5686264, 25.6077919], [94.56690979, 25.60410118], [94.5651474, 25.6026001], [94.55957031, 25.59411049], [94.55574036, 25.58581161], [94.5615387, 25.57833099], [94.56040955, 25.56798935], [94.56465912, 25.56793976], [94.56137848, 25.56051064], [94.56289673, 25.54951096], [94.55986786, 25.54570961], [94.56347656, 25.53967285], [94.55827332, 25.53487968], [94.56125641, 25.53069115], [94.55899811, 25.52433968], [94.55741882, 25.5127697], [94.56817627, 25.50658989], [94.57459259, 25.50522995], [94.58500671, 25.49687004], [94.58719635, 25.49245071], [94.5908432, 25.48974991], [94.59488678, 25.48814964], [94.59736633, 25.48625946], [94.60748291, 25.48244095], [94.62534332, 25.46908951], [94.63297272, 25.46565819], [94.64823151, 25.46162033], [94.65645599, 25.458601], [94.65873718, 25.45705032], [94.66597748, 25.45540047], [94.66976166, 25.45536041], [94.68242645, 25.45973015], [94.68229675, 25.45659065], [94.68205261, 25.45050049], [94.67965698, 25.44240189], [94.67912292, 25.4329319], [94.67811584, 25.42653084], [94.67624664, 25.42058945], [94.67382813, 25.41620064], [94.67095184, 25.4125309], [94.65879822, 25.40951538], [94.65627289, 25.40889168], [94.64919281, 25.40635109], [94.64441681, 25.40160942], [94.6438446, 25.40029335], [94.64176941, 25.39902115], [94.638237, 25.39351082], [94.63495636, 25.39235115], [94.63117981, 25.38729095], [94.62741852, 25.37466812], [94.62760925, 25.36207008], [94.62770844, 25.35539818], [94.62211609, 25.33675957], [94.62162018, 25.33605766], [94.61898041, 25.33193016], [94.61519623, 25.32520103], [94.61315918, 25.32196045], [94.60957336, 25.31352043], [94.60688782, 25.30831718], [94.60192108, 25.29870033], [94.59867859, 25.28907013], [94.59887695, 25.28112984], [94.59809113, 25.27463913], [94.59925842, 25.2668705], [94.59716797, 25.25696182], [94.59353638, 25.24616814], [94.59192657, 25.23743057], [94.58872986, 25.22987938], [94.586586, 25.2250309], [94.58535767, 25.21574974], [94.59208679, 25.20548058], [94.59758759, 25.2000103], [94.60167694, 25.19519043], [94.60887146, 25.19104767], [94.61312866, 25.18947983], [94.61738586, 25.18979836], [94.62268066, 25.19128036], [94.63092041, 25.1903801], [94.63385773, 25.18720055], [94.63813782, 25.18156052], [94.64354706, 25.17653847], [94.64778137, 25.17441177], [94.6576767, 25.1724205], [94.66696167, 25.16818047], [94.67743683, 25.16500092], [94.68115997, 25.16126823], [94.68718719, 25.15787125], [94.6936264, 25.1595211], [94.69863892, 25.16063118], [94.70347595, 25.1597805], [94.70816803, 25.15385056], [94.71357727, 25.14990997], [94.72888184, 25.14371109], [94.73581696, 25.1428299], [94.74194336, 25.13941956], [94.74565887, 25.13659096], [94.74521637, 25.12684059], [94.74568939, 25.11870956], [94.74529266, 25.11123085], [94.74539948, 25.10689926], [94.7455368, 25.10166168], [94.74814606, 25.08989906], [94.74977875, 25.07995033], [94.75100708, 25.07542992], [94.75063324, 25.07064247], [94.75071716, 25.06351852], [94.74923706, 25.05793953], [94.74771881, 25.04927826], [94.74568176, 25.04442978], [94.74501038, 25.0394783], [94.74298096, 25.03010941], [94.74221039, 25.02524948], [94.73945618, 25.02049255], [94.73519135, 25.01268959], [94.73446655, 25.01178741], [94.72609711, 25.00131989], [94.71318817, 24.99369049], [94.70580292, 24.9835701], [94.70314026, 24.97827148], [94.70302582, 24.97736931], [94.70189667, 24.96844101], [94.70381165, 24.96355057], [94.70572662, 24.9596405], [94.70913696, 24.95582008], [94.71357727, 24.95297813], [94.71714783, 24.94645119], [94.71907043, 24.94247055], [94.7146759, 24.93952942], [94.70585632, 24.9342804], [94.70150757, 24.92756081], [94.70097351, 24.92631912], [94.69379425, 24.90971184], [94.69300842, 24.90789032], [94.6920929, 24.89986229], [94.68894196, 24.89502144], [94.68601227, 24.8924427], [94.67971039, 24.88689995], [94.67201233, 24.8821907], [94.66162872, 24.87742043], [94.65683746, 24.8735981], [94.65792084, 24.86717033], [94.65608978, 24.86285019], [94.65445709, 24.8612442], [94.64816284, 24.85507011], [94.64122009, 24.84873962], [94.63967896, 24.84581947], [94.6378479, 24.84235954], [94.63478851, 24.82930946], [94.63540649, 24.82306099], [94.63536072, 24.8224926], [94.63478851, 24.81476021], [94.63244629, 24.81092072], [94.62732697, 24.80429077], [94.62483215, 24.7958107], [94.62530518, 24.78602982], [94.62536621, 24.78479958], [94.62961578, 24.77727127], [94.63301849, 24.77281189], [94.63330841, 24.76496124], [94.62504578, 24.75402069], [94.62408447, 24.75285339], [94.62121582, 24.74936104], [94.61767578, 24.74407005], [94.61238861, 24.73356056], [94.61219025, 24.73279953], [94.61134338, 24.72960091], [94.61084747, 24.72211266], [94.60721588, 24.71994972], [94.59937286, 24.7152729], [94.59098816, 24.71092987], [94.5845108, 24.71486282], [94.58650208, 24.72233963], [94.58580017, 24.73002815], [94.58165741, 24.73134041], [94.5776062, 24.73019028], [94.57456207, 24.72561836], [94.57344055, 24.7220211], [94.57537079, 24.71857071], [94.57556152, 24.71751022], [94.57656097, 24.71206093], [94.57061768, 24.71157074], [94.56739044, 24.7139492], [94.56247711, 24.71833038], [94.55665588, 24.7191906], [94.55098724, 24.71653938], [94.54662323, 24.7074604], [94.5493927, 24.70217705], [94.55076599, 24.6995697], [94.55294037, 24.69277954], [94.5507431, 24.67491913], [94.54714966, 24.66646004], [94.54059601, 24.64901161], [94.53771973, 24.64376068], [94.53148651, 24.63239098], [94.52079773, 24.61679077], [94.50753021, 24.60154915], [94.50241852, 24.59635925], [94.5, 24.5942955], [94.49823761, 24.5927906], [94.48987579, 24.58916092], [94.4853363, 24.58224106], [94.47828674, 24.57905006], [94.47252655, 24.57793999], [94.46549225, 24.57555962], [94.45954895, 24.56676102], [94.45829773, 24.56291008], [94.45584106, 24.55532074], [94.45015717, 24.54273033], [94.44547272, 24.53148842], [94.44049072, 24.52042961], [94.43657684, 24.51594925], [94.43512726, 24.51107979], [94.43238831, 24.50424004], [94.42959595, 24.49333954], [94.42154694, 24.49051094], [94.42021942, 24.49041748], [94.40898132, 24.48963165], [94.40341949, 24.48777962], [94.40618134, 24.48158836], [94.41149902, 24.46965027], [94.4031601, 24.46503067], [94.40045166, 24.46207047], [94.40796661, 24.45379066], [94.40891266, 24.44412041], [94.40748596, 24.43122101], [94.40390778, 24.42114067], [94.39916992, 24.41314125], [94.39163971, 24.40969086], [94.39093781, 24.40950966], [94.38340759, 24.40757942], [94.37438965, 24.40476036], [94.36680603, 24.40455055], [94.36534119, 24.39967918], [94.36752319, 24.39831924], [94.37631989, 24.3928299], [94.3861084, 24.38462067], [94.38336945, 24.37940979], [94.37754822, 24.37105942], [94.36936188, 24.36190987], [94.35573578, 24.34648132], [94.35175323, 24.3420105], [94.34706879, 24.33942032], [94.3400116, 24.33896255], [94.33481598, 24.33862114], [94.32634735, 24.3389492], [94.3252182, 24.33416939], [94.32685852, 24.33064079], [94.32753754, 24.32300949], [94.32789612, 24.31899071], [94.32824707, 24.30607033], [94.32798767, 24.29243088], [94.32177734, 24.27594948], [94.31478882, 24.25975037], [94.31324768, 24.25407982], [94.30725861, 24.24864006], [94.3037796, 24.24548149], [94.29514313, 24.239851], [94.29161072, 24.22307968], [94.29037476, 24.22000885], [94.28765869, 24.21327019], [94.28507233, 24.20261955], [94.28444672, 24.19161987], [94.28372955, 24.17988014], [94.27973938, 24.17593193], [94.27861023, 24.17561531], [94.26650238, 24.17224121], [94.2627182, 24.1677475], [94.26010895, 24.15575981], [94.25992584, 24.15466118], [94.25798798, 24.14294815], [94.25905609, 24.13165092], [94.25923157, 24.11981964]]]}}, {\\\"id\\\": \\\"19\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.22_1\\\", \\\"HASC_1\\\": \\\"IN.ML\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Meghalaya\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 45.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 994.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1813.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2807.0, \\\"geo-id\\\": 19, \\\"hpm25_child_popweighted\\\": 186.6, \\\"hpm25_female_popweighted\\\": 214.5, \\\"hpm25_male_popweighted\\\": 154.4, \\\"location\\\": \\\"Meghalaya\\\", \\\"mort_apm25_6cod_mean_total\\\": 1240.0, \\\"mort_hpm25_6cod_mean_total\\\": 2232.0, \\\"mort_tpm25_6cod_mean_total\\\": 3471.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[91.28647614, 25.1854763], [91.28707123, 25.18662834], [91.28801727, 25.18741226], [91.28809357, 25.18811798], [91.2885437, 25.18954086], [91.28861237, 25.18993759], [91.28858185, 25.19023323], [91.2893219, 25.19075584], [91.29007721, 25.19115067], [91.29115295, 25.19153023], [91.29141998, 25.19176674], [91.2919693, 25.19232368], [91.29203033, 25.19238281], [91.29213715, 25.19343758], [91.2912674, 25.19379044], [91.29042816, 25.19431114], [91.28981018, 25.19463539], [91.28913879, 25.19499016], [91.28797913, 25.19537544], [91.28616333, 25.19593811], [91.28512573, 25.19630432], [91.28462982, 25.19644737], [91.28256989, 25.19673729], [91.28166199, 25.19681358], [91.27887726, 25.19792366], [91.27613068, 25.19916725], [91.27527618, 25.20006752], [91.27488708, 25.20043373], [91.27358246, 25.20149994], [91.27256012, 25.20249939], [91.27159882, 25.20339966], [91.27098083, 25.20397758], [91.26966095, 25.20382118], [91.26580811, 25.20246124], [91.2637558, 25.2005806], [91.26117706, 25.19952011], [91.25881195, 25.19874191], [91.25798798, 25.19618034], [91.2557373, 25.19511032], [91.25154877, 25.19462013], [91.2505722, 25.19459534], [91.25053406, 25.19507599], [91.25058746, 25.19527626], [91.25063324, 25.19548416], [91.25074768, 25.19577599], [91.25019073, 25.19610596], [91.24925995, 25.19669724], [91.24861145, 25.19710922], [91.24813843, 25.19738007], [91.24768066, 25.19768333], [91.24726105, 25.19789505], [91.24649811, 25.19768906], [91.24638367, 25.1979084], [91.24613953, 25.19782448], [91.24597931, 25.19761467], [91.24494934, 25.19734192], [91.24391937, 25.19707298], [91.24312592, 25.19706345], [91.24274445, 25.19703484], [91.24121094, 25.19687653], [91.24088287, 25.19685364], [91.24063873, 25.19683647], [91.23990631, 25.19687271], [91.23802185, 25.19577026], [91.2354126, 25.1953392], [91.2335434, 25.1955204], [91.23139191, 25.19703102], [91.23091125, 25.19711304], [91.2305069, 25.1970005], [91.23022461, 25.19700623], [91.22995758, 25.19705772], [91.22988129, 25.19707108], [91.22920227, 25.19740677], [91.2289505, 25.19745064], [91.22858429, 25.1977272], [91.22803497, 25.19824028], [91.22789001, 25.19837379], [91.22763824, 25.19860268], [91.22756958, 25.1985321], [91.22740936, 25.19836235], [91.22673798, 25.19885254], [91.22511292, 25.19993019], [91.22491455, 25.20002937], [91.22441864, 25.20028305], [91.22328186, 25.19920349], [91.22319794, 25.19912529], [91.22184753, 25.1995182], [91.22108459, 25.19985199], [91.22079468, 25.19998169], [91.21971893, 25.20016098], [91.21912384, 25.20018005], [91.21814728, 25.20023918], [91.21729279, 25.20025635], [91.21697998, 25.20029831], [91.2166748, 25.20025063], [91.21577454, 25.20035934], [91.21521759, 25.20038414], [91.21458435, 25.20028305], [91.21450043, 25.20028305], [91.21401978, 25.20029068], [91.21376038, 25.20032501], [91.21352386, 25.20035553], [91.21324921, 25.20034981], [91.21156311, 25.20041466], [91.2110672, 25.20043373], [91.21076202, 25.20045662], [91.20987701, 25.20057678], [91.20851135, 25.20070648], [91.20781708, 25.20081329], [91.20701599, 25.20092773], [91.20693207, 25.20094109], [91.20623016, 25.20100975], [91.20565033, 25.20106888], [91.2046814, 25.20107651], [91.20249176, 25.20109749], [91.20052338, 25.20111656], [91.19957733, 25.20121002], [91.19868469, 25.20144272], [91.19776154, 25.20176888], [91.19709015, 25.20184517], [91.19631195, 25.20185661], [91.19513702, 25.20190811], [91.1946106, 25.20192528], [91.19374847, 25.20179939], [91.19291687, 25.20163727], [91.19303131, 25.20137596], [91.19364929, 25.1999321], [91.1937027, 25.19980049], [91.19377136, 25.19958305], [91.19378662, 25.19945145], [91.19384003, 25.19927788], [91.19389343, 25.19913292], [91.19393921, 25.19894409], [91.19400787, 25.19874001], [91.1940918, 25.19850731], [91.1941452, 25.19835281], [91.18997192, 25.19712067], [91.18353271, 25.19590187], [91.17736053, 25.19483948], [91.17215729, 25.19433022], [91.16526794, 25.19422913], [91.16055298, 25.19442749], [91.15608215, 25.19608116], [91.1525116, 25.19556046], [91.14576721, 25.19490051], [91.14420319, 25.19474983], [91.13828278, 25.19357109], [91.13201904, 25.19332123], [91.12754059, 25.19336128], [91.12119293, 25.1939106], [91.11734009, 25.19458961], [91.11673737, 25.19457436], [91.11507416, 25.19471359], [91.1129837, 25.19485092], [91.10875702, 25.19496918], [91.10845184, 25.19500923], [91.10810852, 25.19501305], [91.10784149, 25.19504929], [91.10736084, 25.19512177], [91.10597229, 25.19533348], [91.10562134, 25.19537163], [91.10498047, 25.19560051], [91.10439301, 25.19581032], [91.10384369, 25.19598007], [91.10295868, 25.19611168], [91.10194397, 25.1962471], [91.10047913, 25.19645882], [91.09929657, 25.19651985], [91.09909821, 25.19650269], [91.09823608, 25.19653893], [91.09731293, 25.19656944], [91.09382629, 25.19685173], [91.09331512, 25.19688225], [91.09129333, 25.19700432], [91.09085846, 25.19690323], [91.08905792, 25.19669724], [91.08853912, 25.1967144], [91.0872879, 25.19647598], [91.08683014, 25.19642639], [91.08520508, 25.19643784], [91.08482361, 25.19643211], [91.08290863, 25.19673538], [91.08290863, 25.19688225], [91.08118439, 25.19696236], [91.08057404, 25.19691277], [91.08016968, 25.1969738], [91.0797348, 25.19707489], [91.07872009, 25.19731331], [91.07730865, 25.19769287], [91.0769043, 25.19776154], [91.07535553, 25.19835281], [91.07495117, 25.1985054], [91.07442474, 25.19870186], [91.07424927, 25.19874001], [91.07395172, 25.19880295], [91.0735321, 25.19880295], [91.07341003, 25.1987648], [91.07234192, 25.19851112], [91.07150269, 25.19837952], [91.07110596, 25.19835472], [91.06996918, 25.19842911], [91.06957245, 25.19852066], [91.06951904, 25.19807625], [91.06950378, 25.19746971], [91.06956482, 25.19699669], [91.06957245, 25.19692039], [91.06967926, 25.19656372], [91.06977844, 25.19631195], [91.07001495, 25.19614029], [91.07089996, 25.19572258], [91.07119751, 25.1955471], [91.07143402, 25.19535446], [91.07170105, 25.19489479], [91.07165527, 25.19424057], [91.07167053, 25.19372368], [91.07181549, 25.19347], [91.07009888, 25.19234467], [91.06951141, 25.19239235], [91.06908417, 25.19210625], [91.06829834, 25.19199371], [91.0680542, 25.19187737], [91.06781006, 25.19164276], [91.06748199, 25.19173241], [91.06703186, 25.1916523], [91.06581116, 25.19164467], [91.06539917, 25.19151115], [91.06461334, 25.1913681], [91.06390381, 25.19136047], [91.06286621, 25.19134712], [91.06195068, 25.19149971], [91.06082153, 25.19175529], [91.05774689, 25.19205666], [91.05702972, 25.19223404], [91.05581665, 25.19244576], [91.05508423, 25.19255066], [91.054245, 25.19238853], [91.05413055, 25.19236946], [91.05340576, 25.19219589], [91.05324554, 25.19213104], [91.05290985, 25.19194221], [91.0524826, 25.19158936], [91.05223083, 25.19135666], [91.05190277, 25.19113159], [91.05157471, 25.19099236], [91.05149841, 25.19099045], [91.0511322, 25.19098282], [91.05107117, 25.19070053], [91.05086517, 25.1903553], [91.0506897, 25.19018364], [91.05033112, 25.19001579], [91.05019379, 25.18996239], [91.04992676, 25.18986511], [91.04969025, 25.1898613], [91.04901886, 25.18999481], [91.04888916, 25.19004822], [91.0488205, 25.19007683], [91.04850006, 25.19040108], [91.04795837, 25.19028854], [91.04748535, 25.18979454], [91.04724121, 25.18960381], [91.04677582, 25.18935776], [91.04524994, 25.18891144], [91.04512024, 25.18887711], [91.04340363, 25.18826675], [91.04264069, 25.18825722], [91.04226685, 25.18812561], [91.04153442, 25.18776894], [91.04118347, 25.18775368], [91.04084015, 25.18773842], [91.04023743, 25.1877594], [91.04023743, 25.18811035], [91.04017639, 25.18838882], [91.0401001, 25.18872261], [91.03948212, 25.18863487], [91.03935242, 25.18806839], [91.03913879, 25.18723106], [91.03900909, 25.18694115], [91.03847504, 25.1864624], [91.03833771, 25.18639565], [91.03813934, 25.18638039], [91.03797913, 25.18640327], [91.03786469, 25.18642235], [91.03773499, 25.18644333], [91.03697968, 25.18673897], [91.03670502, 25.18686104], [91.03630829, 25.18690872], [91.03538513, 25.18682671], [91.03522491, 25.18673325], [91.03477478, 25.18639183], [91.03425598, 25.18643951], [91.03406525, 25.18644524], [91.03395081, 25.18644142], [91.03348541, 25.1864357], [91.03214264, 25.18640709], [91.03193665, 25.18576813], [91.03070068, 25.18578529], [91.03033447, 25.18524361], [91.02967072, 25.18541527], [91.027771, 25.18587875], [91.02700043, 25.18593788], [91.02666473, 25.18557549], [91.02597809, 25.18566132], [91.02561951, 25.18572426], [91.02477264, 25.18580437], [91.02465057, 25.1857872], [91.02437592, 25.18574905], [91.0236969, 25.1856575], [91.02326965, 25.185812], [91.02272034, 25.1861763], [91.02232361, 25.18654251], [91.02185059, 25.18656731], [91.02137756, 25.18682098], [91.02095795, 25.1870842], [91.02063751, 25.18679428], [91.02011871, 25.1870842], [91.01967621, 25.18708992], [91.01903534, 25.18708611], [91.01903534, 25.18679047], [91.01908875, 25.18632126], [91.0190506, 25.18589783], [91.01885223, 25.18464088], [91.01869202, 25.18392944], [91.01735687, 25.18385887], [91.01609802, 25.18377876], [91.01594543, 25.18317604], [91.01284027, 25.18313599], [91.01221466, 25.18306541], [91.01184082, 25.18297768], [91.01137543, 25.18281555], [91.01092529, 25.18264389], [91.01048279, 25.18247032], [91.01011658, 25.18268394], [91.00957489, 25.18317604], [91.00939178, 25.18331146], [91.00809479, 25.18281555], [91.00817871, 25.1815052], [91.00730133, 25.18090439], [91.00682831, 25.18064117], [91.00653076, 25.18053246], [91.00543976, 25.18025589], [91.0045929, 25.18030548], [91.00360107, 25.18048668], [91.00357819, 25.18058205], [91.00335693, 25.18152046], [91.00191498, 25.18141747], [91.00195313, 25.18102455], [91.00195313, 25.18069458], [91.00196075, 25.18051338], [91.00165558, 25.18051147], [91.00119019, 25.18055344], [91.00065613, 25.18020058], [90.99910736, 25.17941666], [90.99887848, 25.17934799], [90.9985733, 25.17928314], [90.99797058, 25.17918205], [90.99784851, 25.17944145], [90.99777985, 25.17959023], [90.99728394, 25.1794014], [90.99718475, 25.17898369], [90.99596405, 25.17877769], [90.99555969, 25.17871094], [90.99554443, 25.17856216], [90.99455261, 25.17841339], [90.99367523, 25.17825699], [90.9927597, 25.177948], [90.99235535, 25.17827797], [90.99188995, 25.1779995], [90.99127197, 25.17770195], [90.98944855, 25.17673111], [90.98908234, 25.17652702], [90.98786926, 25.17603111], [90.98726654, 25.17632103], [90.98554993, 25.17552185], [90.98530579, 25.17535782], [90.98493958, 25.17517471], [90.98468781, 25.17511559], [90.98432922, 25.17506218], [90.98339081, 25.17500496], [90.98309326, 25.17499542], [90.98287201, 25.17501259], [90.98208618, 25.17506599], [90.9803009, 25.17527008], [90.98009491, 25.1750946], [90.98000336, 25.17503166], [90.97952271, 25.17477608], [90.97919464, 25.17464447], [90.97763824, 25.17420769], [90.97727966, 25.17412758], [90.9770813, 25.17414093], [90.97593689, 25.174263], [90.97528839, 25.17438507], [90.97377777, 25.17499352], [90.97354126, 25.1751461], [90.97322083, 25.17502403], [90.97303772, 25.17516899], [90.97251129, 25.17469788], [90.97237396, 25.17484474], [90.97144318, 25.1746254], [90.97097778, 25.17442322], [90.97033691, 25.17374039], [90.96920013, 25.17306519], [90.96846008, 25.17253113], [90.96792603, 25.17232132], [90.96729279, 25.17196655], [90.96595764, 25.17141533], [90.96533203, 25.17102814], [90.96508026, 25.17101288], [90.96507263, 25.17183304], [90.96485138, 25.17187881], [90.96418762, 25.17201042], [90.96413422, 25.17142677], [90.9631424, 25.17146111], [90.96303558, 25.17146492], [90.96192169, 25.17103004], [90.96157837, 25.17105293], [90.96131134, 25.17089081], [90.96109009, 25.17080688], [90.96096802, 25.17059708], [90.96077728, 25.17043495], [90.96070099, 25.17040443], [90.96065521, 25.17028427], [90.96033478, 25.17035294], [90.96014404, 25.17037582], [90.95983887, 25.17038345], [90.95874023, 25.17028427], [90.95864868, 25.17043495], [90.95870209, 25.17053413], [90.95830536, 25.17056084], [90.95738983, 25.17064095], [90.95691681, 25.1707077], [90.95645142, 25.17081833], [90.95555878, 25.17097092], [90.95484924, 25.17090988], [90.9540329, 25.17080116], [90.95353699, 25.17071533], [90.95272064, 25.17050552], [90.95237732, 25.17039108], [90.95191956, 25.17020988], [90.95154572, 25.17030144], [90.95162201, 25.17053223], [90.95094299, 25.17062378], [90.95056915, 25.17068863], [90.95024109, 25.17071533], [90.9499588, 25.17074966], [90.94876099, 25.17089272], [90.94829559, 25.17002296], [90.94802856, 25.16952515], [90.94769287, 25.16883659], [90.94759369, 25.16838837], [90.94644165, 25.16768456], [90.94497681, 25.16765976], [90.94307709, 25.16764259], [90.94242859, 25.16713142], [90.9416275, 25.16652298], [90.94058228, 25.16644669], [90.93930817, 25.16599274], [90.93822479, 25.16564941], [90.93771362, 25.16535378], [90.93687439, 25.16488647], [90.93597412, 25.1648941], [90.93497467, 25.16490364], [90.93375397, 25.16471672], [90.9331665, 25.16472244], [90.93187714, 25.16425705], [90.93051147, 25.16387558], [90.92878723, 25.16340637], [90.92871857, 25.16342926], [90.92850494, 25.16338539], [90.92857361, 25.16324615], [90.92848206, 25.16308594], [90.9282608, 25.16307068], [90.92816925, 25.16299057], [90.92815399, 25.16275024], [90.92796326, 25.1625042], [90.92789459, 25.16233826], [90.92657471, 25.16254234], [90.92210388, 25.16321564], [90.92191315, 25.16321182], [90.92127991, 25.16322708], [90.92067719, 25.16322327], [90.91996002, 25.16320419], [90.91957092, 25.16336823], [90.91929626, 25.16335487], [90.91915131, 25.1633873], [90.91887665, 25.16345596], [90.9187088, 25.16347313], [90.91847229, 25.16343689], [90.91828918, 25.16321564], [90.91817474, 25.16318893], [90.91808319, 25.16314507], [90.91794586, 25.1628952], [90.91747284, 25.16288376], [90.91573334, 25.16274071], [90.9146347, 25.16277313], [90.9136734, 25.16280937], [90.91307068, 25.16274261], [90.91307831, 25.16293716], [90.91278076, 25.16317749], [90.91255951, 25.16313362], [90.91249847, 25.16333389], [90.91207123, 25.16316605], [90.91220093, 25.16289902], [90.91203308, 25.16270638], [90.9108963, 25.16265678], [90.91002655, 25.16262627], [90.90953064, 25.16253853], [90.90885925, 25.16249847], [90.90785217, 25.16239548], [90.90764618, 25.16265869], [90.9074707, 25.16269684], [90.9072876, 25.162714], [90.90724945, 25.16252708], [90.90718842, 25.1624279], [90.90692902, 25.16237831], [90.90679932, 25.16230774], [90.90550232, 25.16210938], [90.90448761, 25.16200066], [90.90407562, 25.16211128], [90.90401459, 25.16230202], [90.90372467, 25.16261292], [90.90352631, 25.16267586], [90.90338898, 25.16275215], [90.90322876, 25.16285706], [90.90297699, 25.16296768], [90.902771, 25.16275406], [90.90262604, 25.16277122], [90.9022522, 25.162817], [90.90171051, 25.16268158], [90.90158844, 25.16266441], [90.90142822, 25.16283035], [90.90129089, 25.16292], [90.90114594, 25.16307068], [90.90080261, 25.16334152], [90.90084839, 25.16348839], [90.90060425, 25.16353989], [90.90026855, 25.16378593], [90.90032196, 25.16385651], [90.9005661, 25.16414642], [90.89990234, 25.16405487], [90.90015411, 25.16437149], [90.8996582, 25.16464424], [90.89903259, 25.16444969], [90.89480591, 25.16280174], [90.88568878, 25.16426277], [90.87934875, 25.16115189], [90.87610626, 25.15857124], [90.8758316, 25.15834999], [90.87091064, 25.1587429], [90.86695862, 25.1561203], [90.86358643, 25.15785027], [90.85835266, 25.15584946], [90.85353851, 25.15577126], [90.8499527, 25.15666008], [90.84636688, 25.1580677], [90.84615326, 25.158041], [90.84511566, 25.15835762], [90.84439087, 25.15857697], [90.84420013, 25.15891647], [90.84342194, 25.15921974], [90.84028625, 25.15899086], [90.83670044, 25.15974045], [90.82726288, 25.1609211], [90.82446289, 25.16113091], [90.82357788, 25.16288376], [90.82328033, 25.16296577], [90.82305145, 25.16301918], [90.82212067, 25.1632328], [90.82144165, 25.16336823], [90.82040405, 25.16314507], [90.82032776, 25.16305542], [90.82021332, 25.16307259], [90.81984711, 25.16292191], [90.81971741, 25.16292763], [90.81948853, 25.16274261], [90.81912231, 25.16305161], [90.81904602, 25.16324234], [90.81913757, 25.16356277], [90.81923676, 25.16394424], [90.81917572, 25.16425323], [90.81874847, 25.16520691], [90.81713104, 25.16419029], [90.81440735, 25.16250038], [90.80896759, 25.16504097], [90.80879211, 25.16512108], [90.80858612, 25.16521835], [90.80851746, 25.16525078], [90.80831909, 25.16535759], [90.80779266, 25.16550446], [90.80769348, 25.16557121], [90.80751038, 25.16558647], [90.80710602, 25.1658268], [90.80691528, 25.1658268], [90.80661774, 25.16588593], [90.80623627, 25.16601181], [90.80583191, 25.16605377], [90.80529785, 25.16638374], [90.80501556, 25.16640091], [90.80487061, 25.16646194], [90.80477142, 25.1667347], [90.80467224, 25.16682434], [90.80467987, 25.16692352], [90.80471802, 25.16723251], [90.80450439, 25.16742897], [90.80440521, 25.16730118], [90.80418396, 25.16750526], [90.80394745, 25.16810989], [90.80406189, 25.16968536], [90.80444336, 25.17102432], [90.80450439, 25.17112923], [90.80462646, 25.17139626], [90.80443573, 25.17180061], [90.80439758, 25.17187881], [90.80445099, 25.17197037], [90.80423737, 25.1720295], [90.80312347, 25.17325211], [90.80306244, 25.17317581], [90.80273438, 25.17296982], [90.80263519, 25.17284966], [90.80214691, 25.17305183], [90.80168915, 25.17318726], [90.8014679, 25.17328453], [90.80116272, 25.17336273], [90.80104065, 25.17340851], [90.80032349, 25.17359924], [90.80014038, 25.17369461], [90.79992676, 25.17390633], [90.79954529, 25.17410278], [90.79884338, 25.17437363], [90.79867554, 25.17447662], [90.79839325, 25.17472267], [90.79758453, 25.17542267], [90.79745483, 25.17560196], [90.79701233, 25.17598343], [90.79654694, 25.17663956], [90.79627228, 25.17697144], [90.79620361, 25.17699814], [90.79593658, 25.17730331], [90.79589081, 25.17738152], [90.79581451, 25.17762947], [90.7957077, 25.17779922], [90.79560852, 25.17807579], [90.79560852, 25.17819023], [90.79534149, 25.17853546], [90.79523468, 25.17914581], [90.79504395, 25.18023682], [90.79489136, 25.18129158], [90.79464722, 25.18137932], [90.79386139, 25.18122101], [90.79370117, 25.18091774], [90.79268646, 25.18032646], [90.79235077, 25.18039322], [90.79226685, 25.18060684], [90.79190826, 25.18057251], [90.79149628, 25.18042374], [90.78983307, 25.17980385], [90.78904724, 25.17972755], [90.78822327, 25.17934418], [90.78790283, 25.17925835], [90.78723907, 25.1788311], [90.78713989, 25.17887878], [90.78694916, 25.17892075], [90.78668213, 25.17914009], [90.78657532, 25.17923355], [90.78546143, 25.1791153], [90.78543091, 25.17900467], [90.78525543, 25.17892265], [90.78491211, 25.17922783], [90.78474426, 25.17925453], [90.78443146, 25.17962646], [90.7842865, 25.17967796], [90.78412628, 25.179636], [90.78407288, 25.1795845], [90.78398895, 25.17951393], [90.78392792, 25.1794529], [90.7838974, 25.17957497], [90.78388977, 25.17988586], [90.78404236, 25.18004608], [90.78411865, 25.18023491], [90.78421021, 25.18045235], [90.78408813, 25.18071175], [90.78404236, 25.18089104], [90.78409576, 25.18142319], [90.78382874, 25.1812439], [90.78367615, 25.18124771], [90.78353119, 25.18124962], [90.78304291, 25.18110085], [90.78300476, 25.18094444], [90.78266907, 25.18041801], [90.78258514, 25.18038177], [90.78239441, 25.1804142], [90.7822113, 25.1804924], [90.78214264, 25.18059921], [90.78195953, 25.18061256], [90.7817688, 25.18065643], [90.78166962, 25.18073082], [90.78150177, 25.18081474], [90.78142548, 25.18103409], [90.78151703, 25.18126488], [90.78166962, 25.18149376], [90.78119659, 25.18118286], [90.77854156, 25.17977905], [90.77445984, 25.17900085], [90.77197266, 25.17788124], [90.76970673, 25.17686081], [90.76724243, 25.1739006], [90.7652359, 25.1718998], [90.7639389, 25.16999245], [90.76537323, 25.1683712], [90.76586151, 25.16781044], [90.76449585, 25.16624069], [90.76290894, 25.1664505], [90.75896454, 25.16697121], [90.75797272, 25.16710281], [90.75473022, 25.164711], [90.7544632, 25.16451073], [90.75100708, 25.16406059], [90.75029755, 25.16472054], [90.74878693, 25.16610909], [90.74838257, 25.16548538], [90.74803162, 25.16488266], [90.74756622, 25.16412354], [90.74738312, 25.16420937], [90.74699402, 25.16441917], [90.7454834, 25.16523361], [90.74510193, 25.16543579], [90.74501038, 25.16547775], [90.74474335, 25.16560364], [90.74307251, 25.16581917], [90.74208832, 25.16598892], [90.74200439, 25.16600227], [90.74178314, 25.16691589], [90.74172974, 25.16699409], [90.74176788, 25.16710091], [90.74156952, 25.16734886], [90.74153137, 25.1677494], [90.74180603, 25.16831398], [90.74185944, 25.168396], [90.74189758, 25.16859818], [90.74201965, 25.16912651], [90.74219513, 25.16965294], [90.74229431, 25.16996002], [90.74230194, 25.17007637], [90.74197388, 25.17017174], [90.74197388, 25.17025757], [90.74180603, 25.17034912], [90.74136353, 25.17030144], [90.74146271, 25.17011261], [90.74137115, 25.1700573], [90.7412262, 25.17013741], [90.74069977, 25.16940498], [90.74073029, 25.16923332], [90.74061584, 25.16917229], [90.73985291, 25.16938591], [90.73973846, 25.1688633], [90.73968506, 25.16851997], [90.73960114, 25.1682663], [90.73950195, 25.16790581], [90.73944092, 25.16735077], [90.73947144, 25.16722488], [90.73959351, 25.16719818], [90.73978424, 25.16715622], [90.73972321, 25.16691971], [90.73959351, 25.16677475], [90.73937225, 25.16676521], [90.73919678, 25.16659546], [90.73912048, 25.16659927], [90.73912048, 25.16669655], [90.73825073, 25.16671371], [90.73648071, 25.16684914], [90.73583984, 25.16685486], [90.73535156, 25.16685486], [90.73512268, 25.16692162], [90.73416901, 25.1669445], [90.73421478, 25.16610909], [90.734375, 25.16602707], [90.73455811, 25.16593552], [90.7346344, 25.165802], [90.73455048, 25.16556931], [90.73455811, 25.16548157], [90.73461151, 25.16537857], [90.73423767, 25.16533279], [90.73410034, 25.16531563], [90.7336731, 25.16533661], [90.73353577, 25.16530609], [90.73339081, 25.16534233], [90.73316956, 25.16527367], [90.73309326, 25.16492653], [90.73331451, 25.16489601], [90.73326874, 25.16475487], [90.73392487, 25.16456985], [90.73382568, 25.16421509], [90.73362732, 25.16424561], [90.73360443, 25.16411781], [90.7335968, 25.16377258], [90.73358154, 25.16347122], [90.73351288, 25.16315079], [90.73349762, 25.16293526], [90.73331451, 25.16254044], [90.73313904, 25.16251183], [90.73313904, 25.16212082], [90.73339081, 25.16205978], [90.73360443, 25.16203117], [90.73407745, 25.16196823], [90.73410797, 25.16214371], [90.73439789, 25.16203499], [90.73442841, 25.16231346], [90.73466492, 25.1624279], [90.73477173, 25.16295815], [90.73542786, 25.16323471], [90.73610687, 25.16360092], [90.73623657, 25.1637001], [90.73612213, 25.16385078], [90.73645782, 25.16412354], [90.73658752, 25.1641674], [90.73659515, 25.16427231], [90.73680878, 25.16431427], [90.73738861, 25.16432953], [90.73767853, 25.1644268], [90.73783875, 25.16441917], [90.7383728, 25.16432762], [90.73859406, 25.16387177], [90.73871613, 25.16380692], [90.73886108, 25.16363525], [90.73913574, 25.16344452], [90.73931122, 25.16335487], [90.73931885, 25.16322899], [90.73958588, 25.16312027], [90.73988342, 25.16265106], [90.7399826, 25.16257095], [90.74008942, 25.16251755], [90.74012756, 25.16238785], [90.74023438, 25.16226578], [90.74034882, 25.16218758], [90.74289703, 25.16180038], [90.74584961, 25.16037941], [90.74640656, 25.15870094], [90.74534607, 25.15661049], [90.74217987, 25.15677834], [90.7392807, 25.15443039], [90.73861694, 25.15451241], [90.73645782, 25.1554203], [90.73431396, 25.15739441], [90.73423767, 25.15714455], [90.73419952, 25.15707779], [90.73407745, 25.15681458], [90.7335968, 25.15582848], [90.73319244, 25.15501404], [90.73228455, 25.15509415], [90.73209381, 25.15509796], [90.73186493, 25.15510368], [90.73183441, 25.15540695], [90.73184204, 25.15555191], [90.73184204, 25.15571022], [90.73182678, 25.15595818], [90.73177338, 25.15619469], [90.73155975, 25.15658951], [90.73138428, 25.15688324], [90.73123932, 25.15712166], [90.73134613, 25.15728188], [90.73139191, 25.15748024], [90.73117065, 25.15750694], [90.73110199, 25.15753746], [90.73046875, 25.15757751], [90.7303772, 25.15767479], [90.7301178, 25.15784264], [90.72984314, 25.15750504], [90.7298584, 25.157341], [90.72962952, 25.157341], [90.72947693, 25.15737343], [90.72881317, 25.15733528], [90.72866058, 25.15725136], [90.72855377, 25.15732193], [90.72846985, 25.15741348], [90.72817993, 25.15769768], [90.72800446, 25.15748405], [90.72792053, 25.1573658], [90.72724152, 25.1577549], [90.72716522, 25.15779495], [90.72688293, 25.15792274], [90.72678375, 25.15804482], [90.72665405, 25.15813065], [90.72657013, 25.15818977], [90.72651672, 25.15856934], [90.72655487, 25.15874672], [90.72662354, 25.15901947], [90.7265625, 25.1590786], [90.72635651, 25.15918922], [90.72622681, 25.15927505], [90.72612, 25.15934753], [90.72606659, 25.15939903], [90.72599792, 25.15967178], [90.72577667, 25.160429], [90.72567749, 25.16046715], [90.72560883, 25.16060448], [90.72554016, 25.16074371], [90.72556305, 25.16093254], [90.72585297, 25.16106606], [90.7259903, 25.16129112], [90.72599792, 25.16136742], [90.72606659, 25.16146851], [90.72609711, 25.16157913], [90.72610474, 25.16175652], [90.7259903, 25.16205406], [90.72587585, 25.16229439], [90.724617, 25.16334534], [90.72453308, 25.16329002], [90.72441101, 25.16337585], [90.72425842, 25.16363907], [90.72399139, 25.16361427], [90.72405243, 25.16381264], [90.72393799, 25.16388893], [90.72372437, 25.16403389], [90.72314453, 25.164505], [90.72277069, 25.16462517], [90.72200775, 25.16482162], [90.72132111, 25.16422653], [90.72116089, 25.16413307], [90.72068024, 25.16400909], [90.72041321, 25.16396713], [90.72019196, 25.16391945], [90.71969604, 25.16392708], [90.71828461, 25.16386986], [90.71819305, 25.16381645], [90.71767426, 25.1638279], [90.71756744, 25.16386414], [90.71743011, 25.1639843], [90.71737671, 25.16413689], [90.7170639, 25.16469955], [90.71662903, 25.16485023], [90.71607208, 25.16558647], [90.7159729, 25.1657238], [90.71578979, 25.16588593], [90.71576691, 25.16599274], [90.71574402, 25.16612625], [90.71470642, 25.16766167], [90.71353912, 25.16786766], [90.71307373, 25.16792679], [90.71271515, 25.16796303], [90.71033478, 25.16818428], [90.70992279, 25.16821098], [90.7093811, 25.16796684], [90.7091217, 25.16777611], [90.7086792, 25.16730881], [90.70856476, 25.16722298], [90.70800018, 25.16666031], [90.7077713, 25.16616631], [90.70757294, 25.16558266], [90.70749664, 25.16526794], [90.70749664, 25.16503716], [90.70772552, 25.16432571], [90.70774841, 25.16410255], [90.70780182, 25.16353035], [90.70761108, 25.16353416], [90.70714569, 25.16344833], [90.7065506, 25.16330719], [90.70638275, 25.16287994], [90.70670319, 25.16238022], [90.70685577, 25.16210175], [90.70665741, 25.16178322], [90.70650482, 25.16121292], [90.70597839, 25.16137505], [90.7053299, 25.16140556], [90.70381165, 25.16178894], [90.70340729, 25.16189575], [90.70269775, 25.16208267], [90.70231628, 25.16218376], [90.70172882, 25.16278458], [90.701828, 25.1633358], [90.70171356, 25.16399956], [90.70166779, 25.16427422], [90.70059204, 25.16493416], [90.70020294, 25.1635952], [90.70056915, 25.16287422], [90.7004776, 25.16270638], [90.69999695, 25.16189766], [90.69959259, 25.16168213], [90.69924164, 25.1613121], [90.69947052, 25.16097832], [90.69949341, 25.16080284], [90.69944, 25.16031837], [90.69934845, 25.16032982], [90.6993103, 25.16015434], [90.69953156, 25.16023254], [90.69983673, 25.16003227], [90.69985962, 25.15995407], [90.69978333, 25.1597805], [90.69988251, 25.15981865], [90.69997406, 25.15985298], [90.70011139, 25.15984917], [90.70052338, 25.15946007], [90.70044708, 25.15936661], [90.69995117, 25.15877533], [90.69984436, 25.15864563], [90.69963837, 25.15797424], [90.69940948, 25.15740776], [90.69895172, 25.15695381], [90.69850159, 25.15685463], [90.69801331, 25.15695381], [90.69659424, 25.15786362], [90.69560242, 25.15859413], [90.69542694, 25.15872574], [90.69519806, 25.15871239], [90.69513702, 25.15882683], [90.69499969, 25.15929794], [90.69499207, 25.15976524], [90.69501495, 25.15995598], [90.69498444, 25.16013908], [90.69415283, 25.16039848], [90.69307709, 25.16068649], [90.69281769, 25.16066742], [90.69256592, 25.16067314], [90.69248199, 25.16065407], [90.69211578, 25.16080093], [90.69197845, 25.16087151], [90.69177246, 25.16097641], [90.69169617, 25.16101456], [90.6917572, 25.16138458], [90.69169617, 25.16155052], [90.69176483, 25.16181374], [90.69174957, 25.16192245], [90.69141388, 25.16266251], [90.69111633, 25.16331863], [90.69096375, 25.16365051], [90.68984985, 25.1642704], [90.68830872, 25.16395569], [90.68814087, 25.16406441], [90.68791199, 25.164217], [90.68753052, 25.16446304], [90.68680573, 25.16493416], [90.68669891, 25.16480827], [90.68649292, 25.16464233], [90.68613434, 25.16432571], [90.68544769, 25.16373062], [90.68514252, 25.16351318], [90.68411255, 25.16340828], [90.68379974, 25.16334724], [90.68365479, 25.16334343], [90.68345642, 25.16341209], [90.68315887, 25.16356468], [90.68273926, 25.16378212], [90.68218994, 25.16439629], [90.68208313, 25.16437721], [90.68196869, 25.1646595], [90.68183136, 25.16493034], [90.68180084, 25.16559792], [90.68184662, 25.16582489], [90.68172455, 25.16607285], [90.68136597, 25.16731644], [90.68128967, 25.16757584], [90.68109131, 25.16777992], [90.68117523, 25.16794586], [90.68115997, 25.1680584], [90.68109894, 25.16814041], [90.6809845, 25.16818237], [90.68066406, 25.16829872], [90.68045807, 25.16844368], [90.68050385, 25.16859627], [90.68049622, 25.16866875], [90.68044281, 25.1688118], [90.68048096, 25.16910934], [90.6804657, 25.16931725], [90.68042755, 25.16942787], [90.68055725, 25.16954422], [90.68064117, 25.16939926], [90.68087006, 25.16942406], [90.68100739, 25.16966438], [90.68169403, 25.16972923], [90.68196106, 25.16988945], [90.68235016, 25.17023468], [90.68347168, 25.17081451], [90.68397522, 25.17120934], [90.68462372, 25.17171478], [90.68543243, 25.17234802], [90.68549347, 25.17256927], [90.68549347, 25.17409134], [90.6856842, 25.17423058], [90.68584442, 25.1742878], [90.68603516, 25.17439461], [90.68585205, 25.17448425], [90.6856308, 25.17458725], [90.68545532, 25.17463112], [90.68447876, 25.17410851], [90.68440247, 25.17424774], [90.68400574, 25.17400551], [90.68402863, 25.17390823], [90.68354797, 25.17373848], [90.68309021, 25.17357635], [90.68291473, 25.17359161], [90.68230438, 25.17331123], [90.68190002, 25.17273521], [90.68154144, 25.17233086], [90.6812439, 25.1722641], [90.68093872, 25.17224693], [90.68058777, 25.17251587], [90.68047333, 25.17250824], [90.68039703, 25.17248726], [90.68015289, 25.17238808], [90.67957306, 25.17226219], [90.67953491, 25.17271614], [90.67922211, 25.17260361], [90.67900848, 25.17243004], [90.67891693, 25.17228699], [90.67871094, 25.17233467], [90.67868042, 25.17247963], [90.6787262, 25.17270851], [90.67850494, 25.17268562], [90.67835236, 25.17238235], [90.67797089, 25.17239571], [90.67782593, 25.17243767], [90.67768097, 25.17253304], [90.67760468, 25.17254639], [90.67746735, 25.17254639], [90.67720795, 25.17259598], [90.67713928, 25.1724968], [90.67709351, 25.17241669], [90.67685699, 25.17247963], [90.67687988, 25.1727829], [90.676651, 25.1729641], [90.67536163, 25.17310333], [90.6752243, 25.1726265], [90.67507935, 25.17259979], [90.67500305, 25.17262459], [90.67454529, 25.17276192], [90.67481232, 25.17338181], [90.67487335, 25.17354393], [90.67486572, 25.17380333], [90.67482758, 25.17405891], [90.67481232, 25.17424965], [90.6749115, 25.17443085], [90.67523193, 25.17479706], [90.67542267, 25.17501259], [90.6756897, 25.17522049], [90.67613983, 25.17565155], [90.67620087, 25.17575836], [90.67626953, 25.17592239], [90.67630005, 25.17607307], [90.67630768, 25.17630768], [90.67614746, 25.17639923], [90.67601013, 25.17643738], [90.67559814, 25.17651367], [90.67523956, 25.17654991], [90.67455292, 25.17666626], [90.67433929, 25.17648697], [90.67428589, 25.1761322], [90.67427826, 25.17604256], [90.67404938, 25.1755619], [90.67378998, 25.17528152], [90.67351532, 25.17461395], [90.67326355, 25.17393684], [90.67303467, 25.17343903], [90.67274475, 25.17298508], [90.67254639, 25.17243576], [90.67235565, 25.17231941], [90.67224121, 25.17230225], [90.67211151, 25.17209435], [90.67218018, 25.17196274], [90.67227173, 25.17176056], [90.67230988, 25.17098427], [90.6723175, 25.17086792], [90.67227936, 25.17056847], [90.67224121, 25.17036057], [90.67219543, 25.17019272], [90.67212677, 25.1699028], [90.67208099, 25.16983604], [90.67201996, 25.16975403], [90.67189789, 25.16966438], [90.67180634, 25.16958427], [90.67178345, 25.16944885], [90.67175293, 25.16916275], [90.6717453, 25.16884613], [90.67163849, 25.16875458], [90.67151642, 25.16875076], [90.67106628, 25.16897202], [90.67098236, 25.16901398], [90.67082977, 25.16906738], [90.6706543, 25.16906357], [90.67055511, 25.16899681], [90.6704483, 25.16890907], [90.67024994, 25.16863823], [90.67019653, 25.16851997], [90.6701889, 25.16827965], [90.67024231, 25.16804695], [90.67031097, 25.16790771], [90.67034912, 25.16773224], [90.67004395, 25.16754913], [90.6700058, 25.16744423], [90.67003632, 25.16717148], [90.66996765, 25.16687775], [90.66993713, 25.16652489], [90.6698761, 25.1664257], [90.66976166, 25.16630936], [90.66965485, 25.16627502], [90.66956329, 25.16627693], [90.66944122, 25.16635132], [90.66938019, 25.16644287], [90.66931152, 25.16654205], [90.66916656, 25.16684151], [90.66910553, 25.16691208], [90.66902924, 25.16693306], [90.66891479, 25.1668644], [90.66881561, 25.16677094], [90.66860199, 25.16656685], [90.66848755, 25.16654587], [90.66840363, 25.16653633], [90.66830444, 25.16653252], [90.66783905, 25.16627121], [90.66767883, 25.16608047], [90.66734314, 25.16619682], [90.66728973, 25.16638184], [90.66709137, 25.1665535], [90.66671753, 25.1663208], [90.66614532, 25.16605186], [90.66593933, 25.1659565], [90.66592407, 25.16617203], [90.66588593, 25.16628456], [90.66585541, 25.16646385], [90.66576385, 25.16667366], [90.66574097, 25.16679192], [90.6657486, 25.16747284], [90.66567993, 25.16769981], [90.66562653, 25.16786575], [90.66609955, 25.16790771], [90.6659317, 25.16917229], [90.66622925, 25.1691761], [90.66647339, 25.16918182], [90.66648102, 25.16966629], [90.66629028, 25.16978645], [90.6656189, 25.1698246], [90.66571045, 25.17033195], [90.66578674, 25.17061424], [90.66602325, 25.17063332], [90.66604614, 25.17080116], [90.66580963, 25.17084312], [90.66566467, 25.17088127], [90.66563416, 25.17119408], [90.66562653, 25.17131042], [90.6654892, 25.17133331], [90.66555023, 25.17148209], [90.66549683, 25.17159081], [90.66563416, 25.17164993], [90.66563416, 25.17203903], [90.66544342, 25.17210388], [90.66539764, 25.17227554], [90.66521454, 25.17233658], [90.66477203, 25.17256927], [90.664711, 25.17263412], [90.66455078, 25.1726799], [90.66434479, 25.17276955], [90.6639328, 25.17294884], [90.66375732, 25.1730423], [90.66404724, 25.17370224], [90.66415405, 25.17373466], [90.66426849, 25.17397308], [90.66453552, 25.17420578], [90.66467285, 25.17455101], [90.66475677, 25.17485428], [90.6651001, 25.17640686], [90.66506958, 25.17656326], [90.6649704, 25.17681694], [90.66442871, 25.17690277], [90.66355896, 25.17757988], [90.6635437, 25.17849922], [90.6633606, 25.17897415], [90.66344452, 25.17965508], [90.66357422, 25.1796608], [90.66371918, 25.18001556], [90.66375732, 25.18009949], [90.66403198, 25.18032646], [90.66416168, 25.18049431], [90.66432953, 25.18085289], [90.66440582, 25.18066406], [90.66464233, 25.180439], [90.66495514, 25.18070602], [90.66539001, 25.18088341], [90.66546631, 25.18109512], [90.66526031, 25.18112564], [90.66532898, 25.18128967], [90.66532135, 25.18136978], [90.66525269, 25.18157578], [90.66523743, 25.18173981], [90.66527557, 25.1818943], [90.66526794, 25.18206406], [90.66508484, 25.18315887], [90.66505432, 25.18334389], [90.66500854, 25.18375397], [90.66499329, 25.18401909], [90.66495514, 25.18429565], [90.66480255, 25.18466949], [90.66468048, 25.18518829], [90.66472626, 25.18545532], [90.66418457, 25.18549347], [90.66390991, 25.1854744], [90.66377258, 25.18546486], [90.66370392, 25.18542862], [90.66342926, 25.18533134], [90.66326904, 25.18543625], [90.66262054, 25.18540192], [90.6606369, 25.18581009], [90.65814209, 25.18364906], [90.65804291, 25.18345451], [90.65795898, 25.18356514], [90.6579361, 25.18373871], [90.65792084, 25.18389511], [90.65788269, 25.18405151], [90.65785217, 25.18412971], [90.65785217, 25.18422508], [90.65782166, 25.18444061], [90.65779114, 25.18458939], [90.65777588, 25.18473053], [90.6577301, 25.18488312], [90.65766907, 25.18498611], [90.65762329, 25.18509674], [90.65765381, 25.18546104], [90.65730286, 25.18558693], [90.65721893, 25.18566513], [90.65667725, 25.18621254], [90.65592957, 25.18710518], [90.6556015, 25.18843842], [90.65493774, 25.19027519], [90.6530838, 25.19192314], [90.65192413, 25.19330788], [90.6506424, 25.19498825], [90.64962769, 25.19524574], [90.64793396, 25.1943531], [90.64736176, 25.1943779], [90.64743042, 25.19392776], [90.64755249, 25.19391251], [90.64770508, 25.19396782], [90.64783478, 25.19393158], [90.64793396, 25.19392586], [90.64825439, 25.19381523], [90.64835358, 25.19383621], [90.64853668, 25.19372177], [90.64874268, 25.19360161], [90.64892578, 25.19347572], [90.64948273, 25.19306374], [90.65009308, 25.19240952], [90.65034485, 25.19219398], [90.6505127, 25.19197273], [90.65063477, 25.19175529], [90.65102386, 25.1911335], [90.65114594, 25.19094849], [90.65126801, 25.19080162], [90.651474, 25.19050217], [90.65187073, 25.1897831], [90.65193939, 25.18968773], [90.65214539, 25.18934059], [90.65234375, 25.18900681], [90.65251923, 25.18878365], [90.65238953, 25.18872452], [90.6521759, 25.18862152], [90.65184021, 25.18858719], [90.65146637, 25.18836594], [90.65133667, 25.18822861], [90.65143585, 25.18806839], [90.65148926, 25.18800926], [90.65158844, 25.18794441], [90.65227509, 25.18754578], [90.65232086, 25.18698692], [90.65135956, 25.1852169], [90.65153503, 25.18480301], [90.65156555, 25.18455505], [90.65153503, 25.1843586], [90.65148163, 25.18425179], [90.65116119, 25.18354416], [90.65100861, 25.18275833], [90.65102386, 25.18257141], [90.65104675, 25.18234062], [90.65110016, 25.18217468], [90.65109253, 25.18209076], [90.65055084, 25.18179512], [90.65008545, 25.18153], [90.64982605, 25.18137741], [90.64942169, 25.18110657], [90.64904785, 25.18083572], [90.64893341, 25.18078804], [90.64868927, 25.18073273], [90.64846802, 25.1807003], [90.64833069, 25.18068886], [90.64787292, 25.18083572], [90.64768219, 25.1803112], [90.64700317, 25.17851067], [90.64832306, 25.17679977], [90.64878082, 25.17333984], [90.64232635, 25.17459106], [90.6397171, 25.17328835], [90.63687897, 25.17217827], [90.63391113, 25.17243004], [90.6333313, 25.17247009], [90.62742615, 25.17300034], [90.62719727, 25.17290306], [90.62733459, 25.17259979], [90.6269455, 25.1723156], [90.62670135, 25.17237854], [90.62666321, 25.17268181], [90.62592316, 25.17237091], [90.62463379, 25.17413712], [90.62363434, 25.17411423], [90.62200928, 25.17410851], [90.62200928, 25.17398071], [90.6219101, 25.17402267], [90.62184143, 25.17421722], [90.62166595, 25.17404747], [90.62153625, 25.17414665], [90.62122345, 25.17437935], [90.6210022, 25.17437172], [90.62081146, 25.17433929], [90.62049866, 25.17440987], [90.62029266, 25.17430878], [90.62030792, 25.17422104], [90.62000275, 25.17407036], [90.61994934, 25.17383575], [90.61987305, 25.17361641], [90.61981964, 25.17334938], [90.61981964, 25.17323112], [90.61960602, 25.17312622], [90.61927795, 25.17321205], [90.61920166, 25.1731987], [90.61869812, 25.17302704], [90.61846924, 25.17368889], [90.61821747, 25.17350769], [90.61821747, 25.17267418], [90.61814117, 25.17269516], [90.6179657, 25.17274857], [90.61788177, 25.17277527], [90.61782837, 25.1728363], [90.61779785, 25.17290497], [90.61687469, 25.17424393], [90.61679077, 25.17438698], [90.61682892, 25.17461014], [90.61677551, 25.17474174], [90.61668396, 25.17537498], [90.6166687, 25.17601395], [90.61651611, 25.17601013], [90.61632538, 25.1760788], [90.61637878, 25.17636681], [90.61637115, 25.17646217], [90.61643219, 25.17677116], [90.61636353, 25.1770401], [90.6164093, 25.17734528], [90.61642456, 25.17747116], [90.61624908, 25.17739105], [90.61561584, 25.17755127], [90.61553955, 25.17754555], [90.61550903, 25.17747498], [90.61521149, 25.17708015], [90.61499023, 25.17652893], [90.61476898, 25.17591095], [90.61474609, 25.17570686], [90.61456299, 25.17549706], [90.61425781, 25.17505455], [90.61418152, 25.17479706], [90.61412811, 25.17439079], [90.61403656, 25.17420578], [90.61382294, 25.17381859], [90.6134491, 25.17519188], [90.61334991, 25.17530251], [90.60954285, 25.17525291], [90.60482025, 25.17609024], [90.60469055, 25.17607307], [90.60468292, 25.17588997], [90.60466003, 25.17579842], [90.60464478, 25.17570877], [90.60466003, 25.17558861], [90.60481262, 25.17521477], [90.60461426, 25.17479324], [90.60454559, 25.17499924], [90.60423279, 25.17544365], [90.60415649, 25.17543983], [90.60405731, 25.17503738], [90.60366058, 25.17507172], [90.60353088, 25.17485619], [90.60308838, 25.17506218], [90.60308838, 25.17515182], [90.60247803, 25.17533493], [90.60237122, 25.1751709], [90.60214996, 25.17519379], [90.60165405, 25.17513847], [90.60116577, 25.17513466], [90.60092926, 25.17523384], [90.60071564, 25.17536545], [90.60018158, 25.17547798], [90.60010529, 25.17549324], [90.59994507, 25.17550087], [90.59988403, 25.17564011], [90.59965515, 25.17572594], [90.59945679, 25.17584038], [90.59938812, 25.17617989], [90.5993576, 25.17654037], [90.59934235, 25.17664909], [90.59923553, 25.17664337], [90.59907532, 25.17661095], [90.59889221, 25.17656136], [90.59864044, 25.17658043], [90.59814453, 25.17676163], [90.59706879, 25.17663193], [90.59486389, 25.17635727], [90.59381866, 25.17625809], [90.59359741, 25.17619324], [90.59356689, 25.1757679], [90.59355164, 25.17542267], [90.59358215, 25.17531204], [90.59349823, 25.1752739], [90.5933609, 25.17529297], [90.59269714, 25.17555046], [90.5925827, 25.17573738], [90.59254456, 25.17581177], [90.59209442, 25.1759243], [90.59192657, 25.17593575], [90.59128571, 25.17594719], [90.59077454, 25.17579651], [90.5905304, 25.17572212], [90.59042358, 25.17566299], [90.59021759, 25.17557907], [90.58986664, 25.17535591], [90.58968353, 25.17526245], [90.58911896, 25.17530823], [90.5890274, 25.17556763], [90.58894348, 25.17605209], [90.58887482, 25.17618752], [90.58869934, 25.17651367], [90.58862305, 25.17664337], [90.58782196, 25.17662621], [90.58763123, 25.17636871], [90.5872345, 25.17578506], [90.58700562, 25.17529678], [90.58683014, 25.17521667], [90.58656311, 25.17532539], [90.58625793, 25.17464447], [90.58613586, 25.17447281], [90.58610535, 25.1742115], [90.58615112, 25.1738987], [90.58625793, 25.17384338], [90.58621216, 25.17359924], [90.58560181, 25.17363167], [90.58551788, 25.17383194], [90.58517456, 25.17388916], [90.58505249, 25.17389488], [90.58479309, 25.17390633], [90.58451843, 25.17415047], [90.58432007, 25.17411804], [90.58412933, 25.17374611], [90.583992, 25.17370224], [90.58361816, 25.17373848], [90.58350372, 25.17361069], [90.58342743, 25.17348289], [90.58300781, 25.17350197], [90.58301544, 25.17386818], [90.58293152, 25.17394829], [90.58280945, 25.17405891], [90.58269501, 25.17492485], [90.58231354, 25.17483521], [90.58240509, 25.17435837], [90.5823288, 25.17403603], [90.58223724, 25.17392159], [90.58205414, 25.17367744], [90.58197021, 25.17378998], [90.58179474, 25.17397308], [90.5815506, 25.17416763], [90.58143616, 25.17454529], [90.58135223, 25.17466545], [90.58101654, 25.17465019], [90.58106995, 25.17427063], [90.58105469, 25.17385864], [90.58085632, 25.1739006], [90.5806427, 25.17393684], [90.58052826, 25.17397308], [90.58020782, 25.17407036], [90.5800705, 25.17407608], [90.57894135, 25.17487335], [90.57840729, 25.17445564], [90.57814789, 25.17412567], [90.57789612, 25.17368889], [90.57776642, 25.17372513], [90.57775116, 25.17364693], [90.57757568, 25.17354012], [90.57752991, 25.17347908], [90.57723236, 25.17292023], [90.57717896, 25.17274857], [90.57705688, 25.17255783], [90.57696533, 25.17194176], [90.57683563, 25.17206764], [90.57675934, 25.17185783], [90.57624817, 25.17187309], [90.57595825, 25.17176056], [90.57565308, 25.17181206], [90.57540894, 25.17180252], [90.57491302, 25.17186737], [90.57454681, 25.17189598], [90.57444763, 25.17191315], [90.5743103, 25.17197418], [90.57389069, 25.17220306], [90.57393646, 25.17244911], [90.5738678, 25.17251205], [90.57368469, 25.17255783], [90.57368469, 25.17273903], [90.57359314, 25.17285347], [90.57349396, 25.17292213], [90.5719223, 25.17144012], [90.57147217, 25.1710186], [90.57058716, 25.17131042], [90.5687027, 25.17192078], [90.56416321, 25.1719017], [90.56404114, 25.17151451], [90.56360626, 25.17189217], [90.56076813, 25.17176819], [90.55961609, 25.17359734], [90.55893707, 25.17341042], [90.55874634, 25.17350388], [90.55867004, 25.17353439], [90.55847168, 25.17336082], [90.55834961, 25.17318344], [90.55809021, 25.17287636], [90.55786133, 25.17257118], [90.55769348, 25.17257118], [90.55741882, 25.17266273], [90.55755615, 25.17313957], [90.55740356, 25.17327309], [90.55703735, 25.17328644], [90.55680084, 25.1727066], [90.5557251, 25.171978], [90.55536652, 25.1719532], [90.55522156, 25.17183495], [90.55503845, 25.17188644], [90.55493164, 25.17177391], [90.55456543, 25.17192268], [90.55438995, 25.17200661], [90.55427551, 25.17208862], [90.55412292, 25.17224121], [90.55404663, 25.17228889], [90.55395508, 25.1723156], [90.55379486, 25.17232132], [90.5537262, 25.17254066], [90.55368805, 25.17272186], [90.55327606, 25.1728878], [90.5531311, 25.17289543], [90.55270386, 25.17310524], [90.55261993, 25.17318153], [90.55253601, 25.17332649], [90.55231476, 25.17359352], [90.55210114, 25.17403603], [90.55192566, 25.17441177], [90.55171967, 25.17480659], [90.55146027, 25.17530441], [90.55126953, 25.17533875], [90.55093384, 25.17491531], [90.55045319, 25.17500305], [90.55033875, 25.17473602], [90.54992676, 25.1747818], [90.54988098, 25.17468071], [90.54955292, 25.17473793], [90.54915619, 25.17484283], [90.54904938, 25.17469597], [90.5480957, 25.17472649], [90.54764557, 25.17458344], [90.54740906, 25.17436409], [90.54710388, 25.1740036], [90.54649353, 25.17381668], [90.5459137, 25.17368507], [90.54550171, 25.17371368], [90.54535675, 25.17372322], [90.54516602, 25.1736908], [90.54071808, 25.17292976], [90.53617096, 25.17307091], [90.53321838, 25.17344666], [90.53200531, 25.17353058], [90.53179169, 25.17354774], [90.52848816, 25.17274094], [90.5247879, 25.17200279], [90.5223999, 25.17314529], [90.52205658, 25.17331123], [90.52153778, 25.17321205], [90.5211792, 25.17304611], [90.52107239, 25.17304802], [90.52096558, 25.17293167], [90.52050781, 25.17273331], [90.52019501, 25.17261696], [90.51997375, 25.17258263], [90.51945496, 25.17254066], [90.51942444, 25.17244339], [90.51859283, 25.17232704], [90.51846313, 25.17233467], [90.51737976, 25.17275429], [90.51694489, 25.17294884], [90.51667023, 25.1730423], [90.51663971, 25.17058945], [90.51573944, 25.16982079], [90.5118866, 25.17040253], [90.50964355, 25.17098618], [90.50980377, 25.16987038], [90.50982666, 25.1697197], [90.50982666, 25.16952133], [90.50882721, 25.16986275], [90.50884247, 25.17010117], [90.50816345, 25.16996384], [90.50754547, 25.16983986], [90.50720978, 25.16979408], [90.50697327, 25.16979218], [90.5067749, 25.16991615], [90.50662231, 25.17003059], [90.50260162, 25.16638947], [90.49756622, 25.16505814], [90.49608612, 25.16356087], [90.49571991, 25.1631794], [90.49402618, 25.1614399], [90.48787689, 25.16002846], [90.48442841, 25.15909004], [90.4763031, 25.15689087], [90.46510315, 25.15328026], [90.462677, 25.15282249], [90.4596405, 25.15225029], [90.45939636, 25.15180969], [90.45791626, 25.14896965], [90.45658112, 25.14596939], [90.45497894, 25.14443016], [90.45236206, 25.14450264], [90.44928741, 25.14528656], [90.44924927, 25.14504623], [90.44913483, 25.14504051], [90.44863129, 25.14501381], [90.44782257, 25.14497375], [90.44659424, 25.14490891], [90.44592285, 25.14487648], [90.44482422, 25.14482117], [90.44409943, 25.14478493], [90.44268799, 25.14471245], [90.44181061, 25.14466858], [90.440979, 25.14462662], [90.44032288, 25.14490128], [90.43943024, 25.14527321], [90.43891907, 25.14552307], [90.43894196, 25.14560699], [90.4380188, 25.14596367], [90.43727875, 25.14624786], [90.43653107, 25.14653587], [90.43580627, 25.14681435], [90.43481445, 25.14707565], [90.43385315, 25.14732742], [90.43156433, 25.14791298], [90.43125153, 25.14797592], [90.43008423, 25.14821053], [90.42830658, 25.14861107], [90.42734528, 25.14885139], [90.4254303, 25.14931679], [90.4246521, 25.14950371], [90.42388153, 25.14969063], [90.42311096, 25.14987755], [90.42224121, 25.15064621], [90.42198181, 25.15065384], [90.42192841, 25.1507473], [90.42176819, 25.15061951], [90.42153931, 25.15069389], [90.42093658, 25.15077782], [90.42053223, 25.15064621], [90.42046356, 25.15079689], [90.41999817, 25.1511116], [90.41984558, 25.15112114], [90.41968536, 25.15114403], [90.41934967, 25.15123367], [90.41928864, 25.1511631], [90.41909027, 25.15120506], [90.41885376, 25.15104485], [90.41860199, 25.150877], [90.41863251, 25.15112686], [90.41864014, 25.15122795], [90.41872406, 25.15144157], [90.41884613, 25.15164375], [90.41769409, 25.15209579], [90.41574097, 25.15286064], [90.41455078, 25.15334511], [90.41362762, 25.15372467], [90.41252899, 25.15459824], [90.41156006, 25.1553688], [90.41049194, 25.15622711], [90.40794373, 25.15828133], [90.40743256, 25.15869904], [90.40705109, 25.1590023], [90.40605927, 25.15939713], [90.40535736, 25.15967178], [90.40440369, 25.16004562], [90.40365601, 25.15988159], [90.40171814, 25.15944862], [90.40016174, 25.15909386], [90.39976501, 25.15920448], [90.39900208, 25.15940857], [90.39822388, 25.15961838], [90.39746857, 25.15982437], [90.39730835, 25.15977859], [90.39498901, 25.16012573], [90.39393616, 25.1602211], [90.39342499, 25.16020775], [90.39274597, 25.16055679], [90.39203644, 25.16091919], [90.39128113, 25.16094398], [90.39048767, 25.16096878], [90.38957214, 25.1612072], [90.38890839, 25.16138077], [90.3885498, 25.16141701], [90.38796997, 25.16147423], [90.38707733, 25.1615696], [90.38604736, 25.16147804], [90.38519287, 25.16145515], [90.38417053, 25.16130829], [90.38352966, 25.16124916], [90.38288879, 25.16119194], [90.38206482, 25.16111755], [90.38109589, 25.16120148], [90.38048553, 25.16125107], [90.37960052, 25.16131592], [90.37737274, 25.16153145], [90.37574005, 25.16173744], [90.37421417, 25.16211128], [90.37387085, 25.16219711], [90.37308502, 25.16238403], [90.37299347, 25.16243362], [90.37258911, 25.16253281], [90.37220001, 25.16263771], [90.3717804, 25.16270447], [90.371521, 25.16277122], [90.3709259, 25.16287994], [90.3705368, 25.16293335], [90.37010193, 25.16330147], [90.36952209, 25.16378021], [90.36862946, 25.16452789], [90.36817932, 25.16490364], [90.36651611, 25.16628456], [90.36593628, 25.16676712], [90.36527252, 25.16732979], [90.3649826, 25.16745186], [90.36473083, 25.16760063], [90.36288452, 25.16864204], [90.36116028, 25.16958046], [90.35934448, 25.17056656], [90.35826874, 25.17115211], [90.35566711, 25.17255974], [90.35399628, 25.17348289], [90.3521347, 25.17477417], [90.35157776, 25.17510605], [90.34812164, 25.1774826], [90.34671021, 25.17845535], [90.34621429, 25.1788826], [90.34606934, 25.17897797], [90.34591675, 25.17913818], [90.34577179, 25.17922974], [90.34560394, 25.17940521], [90.34545898, 25.17951584], [90.34526825, 25.17969513], [90.34519196, 25.17974091], [90.34359741, 25.18114662], [90.34318542, 25.18151283], [90.34242249, 25.18219185], [90.34135437, 25.18315125], [90.34128571, 25.18333626], [90.34041595, 25.18448067], [90.34012604, 25.18485832], [90.33982086, 25.18525505], [90.33860779, 25.18684387], [90.33816528, 25.18748665], [90.33718109, 25.18889999], [90.33670044, 25.18958855], [90.33565521, 25.19029999], [90.33565521, 25.19046021], [90.33546448, 25.19055367], [90.33531952, 25.19056892], [90.33519745, 25.19060707], [90.33508301, 25.19069672], [90.33495331, 25.19080544], [90.33480072, 25.19091606], [90.33467865, 25.19102669], [90.33356476, 25.19180679], [90.33283997, 25.19227219], [90.33218384, 25.19268799], [90.33207703, 25.19282913], [90.33190155, 25.19292068], [90.33162689, 25.1930294], [90.33097076, 25.19342995], [90.33026886, 25.19381905], [90.33013153, 25.19389343], [90.32953644, 25.19375229], [90.32940674, 25.19373512], [90.32926941, 25.19371796], [90.32909393, 25.19369507], [90.32874298, 25.19366074], [90.32515717, 25.19284058], [90.32142639, 25.19100189], [90.31807709, 25.18965912], [90.31391144, 25.19120979], [90.31326294, 25.19077492], [90.31315613, 25.19074249], [90.31293488, 25.19067192], [90.31290436, 25.19060516], [90.31288147, 25.19052315], [90.31058502, 25.18908119], [90.31035614, 25.1888752], [90.30997467, 25.18898964], [90.3087616, 25.18935204], [90.30748749, 25.18972778], [90.30609894, 25.19013405], [90.30488586, 25.19049454], [90.30378723, 25.19082642], [90.30335236, 25.19075012], [90.30223083, 25.19064903], [90.30223083, 25.1907959], [90.30093384, 25.19091988], [90.29990387, 25.19109917], [90.29943848, 25.19127083], [90.29903412, 25.19138908], [90.29718781, 25.19192314], [90.29659271, 25.19209671], [90.29637909, 25.19205475], [90.29614258, 25.19208336], [90.29605103, 25.19208145], [90.29566956, 25.19212723], [90.29549408, 25.19220924], [90.29534912, 25.19231033], [90.29521179, 25.19236374], [90.2948761, 25.19244957], [90.29464722, 25.19246292], [90.29371643, 25.19272423], [90.29328156, 25.19291496], [90.29290009, 25.19308281], [90.29157257, 25.19366837], [90.28987885, 25.19422722], [90.2881012, 25.19505882], [90.28651428, 25.1958046], [90.2844162, 25.19599533], [90.28382874, 25.19598579], [90.283638, 25.195755], [90.28299713, 25.19590187], [90.28282166, 25.19539452], [90.28269958, 25.195364], [90.28253937, 25.19551659], [90.28253174, 25.19566345], [90.28248596, 25.19574547], [90.282341, 25.19575882], [90.28227997, 25.19550323], [90.28192139, 25.19537735], [90.28153229, 25.19543457], [90.27971649, 25.19583321], [90.27890778, 25.19605255], [90.27759552, 25.19639397], [90.27693176, 25.19656754], [90.27585602, 25.19684792], [90.27410889, 25.19730377], [90.27275848, 25.19765663], [90.27193451, 25.19786835], [90.27191162, 25.19796562], [90.27144623, 25.19805145], [90.26925659, 25.19835663], [90.26886749, 25.19840813], [90.26847076, 25.19845963], [90.2682724, 25.19848442], [90.26805115, 25.19851303], [90.26792145, 25.19841194], [90.26663971, 25.19784546], [90.26629639, 25.19763756], [90.26470947, 25.19649124], [90.26421356, 25.19639206], [90.26399231, 25.19634628], [90.26302338, 25.19664574], [90.26261902, 25.19676781], [90.26209259, 25.19693184], [90.26128387, 25.19693375], [90.26063538, 25.19706345], [90.25994873, 25.19720268], [90.25865173, 25.1979847], [90.25811005, 25.19831276], [90.25691986, 25.19903183], [90.25578308, 25.19972229], [90.25460815, 25.20000839], [90.25352478, 25.20027351], [90.25293732, 25.20023346], [90.25217438, 25.20016861], [90.25187683, 25.20013428], [90.25167847, 25.20010948], [90.25146484, 25.20008469], [90.25106049, 25.2000351], [90.25042725, 25.19998741], [90.2492981, 25.20011711], [90.24909973, 25.20014381], [90.2489624, 25.20016289], [90.24859619, 25.20028305], [90.24836731, 25.20038033], [90.24713135, 25.20093727], [90.24703217, 25.20100212], [90.24510956, 25.20223808], [90.24462891, 25.20254898], [90.24420166, 25.20257187], [90.24356079, 25.20260429], [90.2409668, 25.20326805], [90.24082184, 25.20326805], [90.24069214, 25.20328712], [90.24060059, 25.20330811], [90.24007416, 25.20345116], [90.23961639, 25.20368195], [90.23912811, 25.20392799], [90.23857117, 25.20408058], [90.23836517, 25.20409966], [90.2358551, 25.20461273], [90.23574829, 25.20463753], [90.2352829, 25.20476532], [90.23511505, 25.20480156], [90.23490143, 25.20484734], [90.23392487, 25.20501709], [90.2338028, 25.20501518], [90.23339844, 25.20494461], [90.233284, 25.20492744], [90.2326889, 25.2047081], [90.23239899, 25.20454407], [90.23210144, 25.20437431], [90.23193359, 25.20427895], [90.23152924, 25.20419121], [90.23130035, 25.20413208], [90.23000336, 25.20379448], [90.2296524, 25.20370674], [90.22912598, 25.20358276], [90.22895813, 25.20343971], [90.22883606, 25.2033329], [90.22856903, 25.20294571], [90.22780609, 25.20184326], [90.22663879, 25.20124245], [90.22547913, 25.20056725], [90.22514343, 25.20077515], [90.2248764, 25.20093918], [90.22479248, 25.20098495], [90.22454834, 25.20113373], [90.22396088, 25.20141792], [90.22350311, 25.20163918], [90.2233963, 25.20235443], [90.22324371, 25.20342064], [90.22322083, 25.20354843], [90.22272491, 25.20398903], [90.22205353, 25.20457268], [90.22120667, 25.20531464], [90.22065735, 25.20579147], [90.22002411, 25.2063446], [90.21971893, 25.20654297], [90.21942139, 25.2067318], [90.21936035, 25.20677185], [90.21909332, 25.20652199], [90.21898651, 25.20642281], [90.21868896, 25.20613861], [90.21843719, 25.20617104], [90.21832275, 25.20618629], [90.2175827, 25.20628548], [90.21727753, 25.20632744], [90.21696472, 25.2063694], [90.21646118, 25.20643616], [90.21619415, 25.2057991], [90.21603394, 25.20540619], [90.2154541, 25.2054615], [90.21516418, 25.20549011], [90.21460724, 25.20573997], [90.21398163, 25.20601845], [90.21357727, 25.20619965], [90.212883, 25.20651436], [90.21279144, 25.20655251], [90.21250153, 25.20674324], [90.21192932, 25.2071209], [90.21122742, 25.20758247], [90.20929718, 25.20825768], [90.20881653, 25.20893288], [90.20851898, 25.20934868], [90.20791626, 25.21018791], [90.20781708, 25.21032906], [90.20733643, 25.21031761], [90.20722961, 25.2103157], [90.20632172, 25.210392], [90.20600128, 25.21039391], [90.20410156, 25.21043205], [90.20277405, 25.21046829], [90.20201111, 25.21052551], [90.20077515, 25.21082497], [90.20029449, 25.21059418], [90.19980621, 25.21068954], [90.19855499, 25.21093559], [90.19690704, 25.21105957], [90.19585419, 25.21113396], [90.19534302, 25.21139145], [90.19526672, 25.21143532], [90.19467163, 25.21173477], [90.1940155, 25.21261787], [90.19277191, 25.2131958], [90.19226837, 25.2134304], [90.19213104, 25.21369362], [90.19190216, 25.21414757], [90.19189453, 25.21476936], [90.19189453, 25.21516418], [90.19109344, 25.21523476], [90.18958282, 25.21528053], [90.18910217, 25.21530724], [90.1889801, 25.21531296], [90.18847656, 25.21527672], [90.18792725, 25.21522141], [90.18733215, 25.21554184], [90.1868515, 25.21579933], [90.18447113, 25.21708679], [90.18208313, 25.21832848], [90.1796875, 25.21934891], [90.17713165, 25.22044563], [90.17676544, 25.22060394], [90.17611694, 25.22088051], [90.17584991, 25.22100449], [90.17401123, 25.22184181], [90.1727066, 25.22251129], [90.17142487, 25.22317123], [90.17058563, 25.22319031], [90.1676712, 25.22325134], [90.16634369, 25.22327614], [90.16423035, 25.2233429], [90.16146851, 25.22356606], [90.1606369, 25.22365761], [90.16023254, 25.22370338], [90.15795898, 25.22408867], [90.15527344, 25.22414589], [90.15323639, 25.22418976], [90.15172577, 25.22422218], [90.15085602, 25.22426605], [90.14894867, 25.22435951], [90.1463089, 25.22444534], [90.14428711, 25.22444725], [90.14401245, 25.22444725], [90.14295197, 25.22444916], [90.14170074, 25.22444344], [90.14002228, 25.2244339], [90.13801575, 25.22451401], [90.13706207, 25.22455406], [90.13682556, 25.22458649], [90.13613892, 25.22467422], [90.13512421, 25.22480583], [90.13349915, 25.22500801], [90.13261414, 25.22511482], [90.1313324, 25.22526169], [90.13062286, 25.2253418], [90.12885284, 25.22561646], [90.12857056, 25.22565842], [90.12806702, 25.22573662], [90.1270752, 25.22570419], [90.12607574, 25.22567177], [90.12527466, 25.22564697], [90.12471008, 25.2255764], [90.12422943, 25.22551727], [90.12224579, 25.22527885], [90.1214447, 25.22518349], [90.12135315, 25.22501373], [90.12103271, 25.22443771], [90.12063599, 25.22432709], [90.11920166, 25.22390366], [90.11806488, 25.22356606], [90.11786652, 25.22364426], [90.11759186, 25.2237606], [90.11630249, 25.2242794], [90.11495972, 25.22481918], [90.11441803, 25.22503853], [90.11345673, 25.22522163], [90.11278534, 25.22536469], [90.11226654, 25.22547531], [90.11194611, 25.22566032], [90.11149597, 25.22591782], [90.1108551, 25.22627831], [90.11030579, 25.22658157], [90.10868073, 25.22748566], [90.10758209, 25.22809601], [90.10629272, 25.22880745], [90.10527039, 25.22937584], [90.10466003, 25.22990608], [90.10449982, 25.23004723], [90.10358429, 25.23085403], [90.10340118, 25.23101234], [90.10333252, 25.23107529], [90.10286713, 25.23148918], [90.10259247, 25.23171997], [90.10230255, 25.2319622], [90.10037231, 25.23310852], [90.10002899, 25.23359489], [90.09975433, 25.23398399], [90.09920502, 25.23475075], [90.09902191, 25.23481369], [90.09753418, 25.23532486], [90.0971756, 25.23544693], [90.09612274, 25.23614311], [90.09562683, 25.2364502], [90.09499359, 25.23689842], [90.09418488, 25.23743248], [90.0938797, 25.23756409], [90.0920105, 25.23835945], [90.08997345, 25.23897171], [90.08966064, 25.23904228], [90.08797455, 25.23919678], [90.08760071, 25.23923111], [90.08664703, 25.23931503], [90.08584595, 25.2393856], [90.08488464, 25.23956299], [90.08351898, 25.23981667], [90.0819931, 25.24025917], [90.08123779, 25.24047661], [90.08068085, 25.24075127], [90.0785675, 25.24182892], [90.07844543, 25.24188614], [90.07836151, 25.24192619], [90.07757568, 25.24233055], [90.07683563, 25.2426815], [90.07676697, 25.24271584], [90.07628632, 25.24295044], [90.07617188, 25.24302292], [90.07591248, 25.24313354], [90.07510376, 25.24354935], [90.07406616, 25.24405861], [90.07324982, 25.24487495], [90.07311249, 25.24497795], [90.07203674, 25.24602127], [90.07077026, 25.24718666], [90.06985474, 25.24787331], [90.06967163, 25.24799728], [90.06930542, 25.24827576], [90.06903839, 25.24846268], [90.0688858, 25.24857712], [90.06647491, 25.25001526], [90.06480408, 25.25098801], [90.06343079, 25.25180054], [90.06326294, 25.25189972], [90.06206512, 25.25259781], [90.06143951, 25.25309944], [90.06100464, 25.25347519], [90.05978394, 25.25394821], [90.05948639, 25.25473595], [90.059021, 25.25557327], [90.05840302, 25.25670433], [90.05817413, 25.25712967], [90.05808258, 25.25731087], [90.0579071, 25.2576313], [90.05762482, 25.25813484], [90.05741119, 25.25852013], [90.05727386, 25.2587738], [90.0568924, 25.25947762], [90.05673981, 25.25981712], [90.05664063, 25.2599411], [90.05657196, 25.26007652], [90.05632019, 25.2605381], [90.0558548, 25.26075935], [90.0555954, 25.26089668], [90.05504608, 25.26119041], [90.05445862, 25.26146317], [90.0533371, 25.26135063], [90.05235291, 25.26120949], [90.05012512, 25.26103401], [90.04828644, 25.26088524], [90.04735565, 25.26081276], [90.04665375, 25.26074219], [90.04571533, 25.26091003], [90.04399109, 25.26120949], [90.04338837, 25.26124191], [90.04119873, 25.26133919], [90.04075623, 25.26130295], [90.03916168, 25.26116943], [90.03777313, 25.2612896], [90.0373764, 25.26132202], [90.03546143, 25.26177597], [90.03404236, 25.26226044], [90.03366852, 25.26239014], [90.03334808, 25.26260757], [90.03243256, 25.26324463], [90.03196716, 25.26363373], [90.03146362, 25.26407814], [90.03134918, 25.26412964], [90.02922058, 25.26502037], [90.02772522, 25.26565361], [90.02671051, 25.26627731], [90.02655029, 25.26636124], [90.02479553, 25.26730919], [90.02337646, 25.26811981], [90.02139282, 25.26920891], [90.02108765, 25.26960945], [90.02077484, 25.27005768], [90.02059937, 25.27034378], [90.02053833, 25.27043343], [90.02027893, 25.27079391], [90.02007294, 25.2711277], [90.01999664, 25.27120781], [90.01985168, 25.27142906], [90.01969147, 25.27166939], [90.01963806, 25.27174568], [90.01934052, 25.27215576], [90.0191803, 25.27224159], [90.01869202, 25.27247429], [90.01822662, 25.27267456], [90.0168457, 25.27331352], [90.01641083, 25.27349663], [90.01609039, 25.27365303], [90.01538086, 25.27397728], [90.01527405, 25.27403641], [90.01418304, 25.27444649], [90.0140152, 25.27451324], [90.01364899, 25.27465248], [90.01145172, 25.27549744], [90.01135254, 25.27553558], [90.01136017, 25.27562714], [90.01096344, 25.27568245], [90.01082611, 25.27573967], [90.01013947, 25.27605629], [90.00983429, 25.27621078], [90.0093689, 25.27649117], [90.00904846, 25.27670097], [90.00806427, 25.27742004], [90.00786591, 25.27759743], [90.00751495, 25.27792549], [90.00714874, 25.27831078], [90.0069046, 25.27860069], [90.00676727, 25.27877235], [90.00632477, 25.27921295], [90.00549316, 25.27961159], [90.00482178, 25.28016853], [90.00466156, 25.28033257], [90.00445557, 25.28052521], [90.00432587, 25.28059387], [90.00419617, 25.28063202], [90.00410461, 25.28064919], [90.00399017, 25.28063011], [90.00327301, 25.28033829], [90.00296783, 25.28024101], [90.00267029, 25.27991295], [90.00254059, 25.27979851], [90.00241089, 25.27968788], [90.00228882, 25.27964401], [90.00217438, 25.27953529], [90.00126648, 25.27909851], [90.00067139, 25.2788372], [89.99992371, 25.27842903], [89.9993515, 25.27826309], [89.99925995, 25.27824783], [89.99874115, 25.2781353], [89.99855042, 25.27791214], [89.99762726, 25.27707481], [89.99719238, 25.2769928], [89.99595642, 25.27675629], [89.99485779, 25.27720261], [89.99333191, 25.27777481], [89.9932251, 25.27779198], [89.9927063, 25.27786446], [89.99209595, 25.27798462], [89.99147797, 25.27812767], [89.99111938, 25.278265], [89.9908371, 25.27843666], [89.99074554, 25.27850342], [89.99065399, 25.27865982], [89.99049377, 25.2786808], [89.98763275, 25.2795639], [89.98690796, 25.27977562], [89.98552704, 25.28022575], [89.98500061, 25.28027725], [89.98461914, 25.2803421], [89.98423767, 25.28039169], [89.98088837, 25.28094673], [89.98070526, 25.28097725], [89.98052216, 25.28278923], [89.98049927, 25.28345871], [89.98043823, 25.28462029], [89.98046112, 25.28477287], [89.98058319, 25.28560638], [89.98052979, 25.28602219], [89.98052216, 25.28621864], [89.98042297, 25.2874279], [89.98039246, 25.28773499], [89.98029327, 25.28998756], [89.98029327, 25.29015541], [89.98028564, 25.29031563], [89.9803009, 25.29043961], [89.98030853, 25.29062653], [89.9803009, 25.29079437], [89.97908783, 25.29292107], [89.978302, 25.29439545], [89.97811127, 25.29474831], [89.9773407, 25.29620171], [89.97718048, 25.29651451], [89.97688293, 25.29707718], [89.97669983, 25.29720688], [89.97528076, 25.29815674], [89.97483063, 25.29843903], [89.97457886, 25.29859734], [89.97380066, 25.29907799], [89.9728241, 25.29976654], [89.97249603, 25.29999733], [89.97194672, 25.30037498], [89.97159576, 25.30060196], [89.97106171, 25.3010006], [89.9694519, 25.30219841], [89.96910858, 25.30241013], [89.96833801, 25.30278778], [89.9678421, 25.30303001], [89.96735382, 25.30331612], [89.96716309, 25.30332947], [89.96498108, 25.30306053], [89.96424103, 25.30266571], [89.96412659, 25.30241203], [89.96391296, 25.30203438], [89.96375275, 25.30199814], [89.96360779, 25.30201149], [89.96349335, 25.30202293], [89.962677, 25.30209732], [89.9616394, 25.30219269], [89.96115112, 25.30227661], [89.96055603, 25.30212975], [89.95658875, 25.29994011], [89.9561615, 25.29931068], [89.9546814, 25.29718971], [89.95337677, 25.29564857], [89.95092773, 25.29590988], [89.95056152, 25.29626274], [89.95021057, 25.29538155], [89.94992828, 25.29469872], [89.94972992, 25.29420471], [89.9495163, 25.29367638], [89.94917297, 25.2928257], [89.94855499, 25.29335785], [89.94839478, 25.2935009], [89.94820404, 25.29366302], [89.94781494, 25.29400063], [89.94726563, 25.29446793], [89.94685364, 25.29482079], [89.94677734, 25.29596519], [89.94676208, 25.29644203], [89.94672394, 25.29681396], [89.94670868, 25.29724312], [89.94623566, 25.29820442], [89.94582367, 25.29912567], [89.94568634, 25.30030441], [89.94551849, 25.3015995], [89.94551849, 25.30264854], [89.94559479, 25.30290413], [89.94467926, 25.30370522], [89.94439697, 25.30395317], [89.94407654, 25.30423737], [89.94384003, 25.30445099], [89.94322968, 25.30377007], [89.94252777, 25.302948], [89.9413681, 25.30166054], [89.94114685, 25.30141258], [89.94094849, 25.3011837], [89.94078827, 25.3010273], [89.94037628, 25.30059624], [89.93978119, 25.29998207], [89.93894958, 25.29914474], [89.93836975, 25.29925728], [89.93810272, 25.29931641], [89.93795013, 25.29935074], [89.9371109, 25.29954338], [89.93654633, 25.29966927], [89.93618011, 25.29975319], [89.93516541, 25.29998207], [89.93501282, 25.3000164], [89.9348526, 25.30010223], [89.93473053, 25.30020332], [89.9339447, 25.30081749], [89.93371582, 25.30083656], [89.93357849, 25.30084801], [89.93238831, 25.30092812], [89.9322052, 25.30095291], [89.93188477, 25.30098915], [89.93099976, 25.30111313], [89.93069458, 25.30113983], [89.92942047, 25.30130005], [89.9291687, 25.30127335], [89.92906189, 25.30127907], [89.92850494, 25.30130196], [89.92835999, 25.3013134], [89.92733765, 25.30141068], [89.92701721, 25.30142593], [89.92668915, 25.30171585], [89.92661285, 25.30179214], [89.92608643, 25.3022728], [89.92591095, 25.30246162], [89.92545319, 25.30288887], [89.92388153, 25.30406189], [89.92345428, 25.30436325], [89.92301941, 25.30439377], [89.92261505, 25.30442047], [89.92205048, 25.30446053], [89.92114258, 25.30451965], [89.9208374, 25.30454063], [89.92025757, 25.30458641], [89.91977692, 25.30463982], [89.91937256, 25.30467606], [89.91899872, 25.304739], [89.9187088, 25.30477715], [89.9183197, 25.30485344], [89.91801453, 25.30496979], [89.9174118, 25.30522537], [89.91702271, 25.30538368], [89.91670227, 25.30551529], [89.91611481, 25.30595779], [89.915802, 25.30616188], [89.91517639, 25.30661774], [89.9144516, 25.30712891], [89.91365814, 25.30730629], [89.91329956, 25.30738258], [89.9131012, 25.30741501], [89.91281128, 25.30748177], [89.9123764, 25.30751991], [89.91216278, 25.30753517], [89.91139984, 25.30757523], [89.9101181, 25.30790901], [89.90965271, 25.30799294], [89.90908813, 25.30812454], [89.9063797, 25.30742073], [89.905159, 25.30632019], [89.90164948, 25.30321121], [89.89412689, 25.29536057], [89.88968658, 25.28988075], [89.8864212, 25.2877903], [89.88259888, 25.28720284], [89.88210297, 25.28672218], [89.88079071, 25.28647041], [89.87765503, 25.28570938], [89.87653351, 25.28544617], [89.87522888, 25.28556061], [89.87451935, 25.28583336], [89.87421417, 25.28594398], [89.87375641, 25.28609657], [89.87257385, 25.28681374], [89.8720932, 25.28682327], [89.87091827, 25.28684616], [89.87086487, 25.28677177], [89.87055969, 25.28684807], [89.86988068, 25.28685951], [89.86945343, 25.28689003], [89.86934662, 25.2869091], [89.8684845, 25.28713226], [89.86811066, 25.28723717], [89.86755371, 25.28739166], [89.86655426, 25.28760529], [89.86608887, 25.28770447], [89.8655777, 25.28781128], [89.86472321, 25.28786087], [89.86452484, 25.28788948], [89.86429596, 25.28786469], [89.86309814, 25.28803253], [89.86267853, 25.28781319], [89.86251831, 25.28772926], [89.86238098, 25.28765678], [89.86186218, 25.28738403], [89.86079407, 25.28738022], [89.86000061, 25.28737831], [89.85923767, 25.28615761], [89.85888672, 25.28624725], [89.85795593, 25.28647995], [89.85680389, 25.28676987], [89.85678101, 25.28685951], [89.85671997, 25.28715706], [89.85664368, 25.28751373], [89.85624695, 25.28762054], [89.85540009, 25.28785133], [89.85497284, 25.28796577], [89.85440826, 25.28876686], [89.85387421, 25.28953362], [89.85370636, 25.28953171], [89.85311127, 25.28952789], [89.85186005, 25.28955841], [89.85157776, 25.2895813], [89.85124969, 25.28960228], [89.85094452, 25.28959274], [89.85025787, 25.28959465], [89.84971619, 25.28956413], [89.84926605, 25.28956032], [89.84849548, 25.28949165], [89.84836578, 25.29024696], [89.84822845, 25.29096603], [89.84709167, 25.29101372], [89.84692383, 25.29102135], [89.84618378, 25.29105377], [89.84609222, 25.29105759], [89.84607697, 25.29120445], [89.84603882, 25.29180145], [89.84490204, 25.29203224], [89.84487915, 25.29210472], [89.84476471, 25.29249382], [89.84300995, 25.29267693], [89.84256744, 25.29268265], [89.84194183, 25.29273796], [89.84086609, 25.29281998], [89.84033203, 25.29287148], [89.83934784, 25.29307175], [89.83837891, 25.29327202], [89.83791351, 25.29403114], [89.83752441, 25.2946682], [89.83698273, 25.29467773], [89.83649445, 25.29468727], [89.83622742, 25.29469299], [89.83538055, 25.29471207], [89.83478546, 25.29472542], [89.83447266, 25.29484558], [89.83390808, 25.29506683], [89.83280945, 25.29549599], [89.831604, 25.29566193], [89.8311615, 25.29614067], [89.83193207, 25.29683876], [89.83204651, 25.29693985], [89.832901, 25.2977066], [89.83401489, 25.29854393], [89.83486176, 25.29924774], [89.83617401, 25.30059814], [89.83666992, 25.3011055], [89.8367691, 25.30124283], [89.83690643, 25.30145454], [89.83719635, 25.30183601], [89.83764648, 25.30247307], [89.83763885, 25.30392838], [89.83760071, 25.30402756], [89.83724976, 25.30522346], [89.83718872, 25.30542564], [89.83896637, 25.30703545], [89.84013367, 25.30758858], [89.84046173, 25.30774307], [89.84155273, 25.30826378], [89.84080505, 25.30948448], [89.84113312, 25.31085396], [89.84134674, 25.31249428], [89.84136963, 25.31273079], [89.84135437, 25.31301498], [89.841362, 25.31415558], [89.84123993, 25.31558418], [89.84113312, 25.31620979], [89.84107971, 25.3165226], [89.84034729, 25.31780243], [89.84014893, 25.31818581], [89.84049988, 25.31903267], [89.83972168, 25.32036972], [89.83844757, 25.32308197], [89.83827209, 25.32353783], [89.83665466, 25.32634735], [89.83551788, 25.3279171], [89.835289, 25.32820129], [89.8345108, 25.32915115], [89.83344269, 25.33039474], [89.83324432, 25.33060646], [89.83300018, 25.33089828], [89.83290863, 25.33109283], [89.8328476, 25.33123398], [89.83272552, 25.33148766], [89.83249664, 25.3319912], [89.83105469, 25.33512688], [89.8303833, 25.33659744], [89.83026886, 25.33693695], [89.8291626, 25.3397789], [89.82898712, 25.34030151], [89.82886505, 25.34057999], [89.82855225, 25.34139633], [89.82788849, 25.34349632], [89.8273468, 25.34510422], [89.82674408, 25.34688187], [89.82531738, 25.34668541], [89.82511902, 25.34668159], [89.82386017, 25.34754181], [89.82350159, 25.34797478], [89.82332611, 25.3482666], [89.8230896, 25.34880638], [89.82299042, 25.34904289], [89.82279205, 25.34965706], [89.82269287, 25.34996605], [89.82262421, 25.35012627], [89.82247925, 25.35080528], [89.82245636, 25.35095787], [89.8224411, 25.35119629], [89.82238007, 25.35157967], [89.82217407, 25.35322571], [89.82221985, 25.35387611], [89.82196808, 25.35439682], [89.82190704, 25.35462189], [89.82136536, 25.35562515], [89.8212738, 25.35657883], [89.8212204, 25.35706139], [89.82112885, 25.3578949], [89.82105255, 25.35887337], [89.82096863, 25.35977745], [89.82090759, 25.36159134], [89.82084656, 25.36355782], [89.820961, 25.36481476], [89.8211441, 25.3670578], [89.82115936, 25.36856461], [89.82109833, 25.37005234], [89.82103729, 25.37130547], [89.82118988, 25.37244415], [89.82121277, 25.37283516], [89.82119751, 25.37320518], [89.82121277, 25.37343216], [89.82115936, 25.37450027], [89.82093048, 25.375], [89.82060242, 25.37579918], [89.81999969, 25.37743187], [89.81959534, 25.37909126], [89.81950378, 25.37947273], [89.81958008, 25.3807869], [89.81972504, 25.38148499], [89.81990814, 25.38216019], [89.81997681, 25.38259697], [89.82051086, 25.38360405], [89.82066345, 25.3839016], [89.82250977, 25.38736725], [89.82279968, 25.38805008], [89.82325745, 25.38868141], [89.82339478, 25.38887215], [89.82344055, 25.38909912], [89.82349396, 25.38926888], [89.82351685, 25.38945961], [89.82370758, 25.3907814], [89.82398224, 25.39255524], [89.82410431, 25.393116], [89.82418823, 25.39380836], [89.82479095, 25.39632034], [89.8263092, 25.39944458], [89.82675934, 25.40065193], [89.82678986, 25.40077209], [89.82700348, 25.40163231], [89.82720947, 25.40301514], [89.82730865, 25.40406418], [89.82733917, 25.40466499], [89.82732391, 25.40561676], [89.8272934, 25.40598488], [89.82728577, 25.40634537], [89.82590485, 25.4066658], [89.82530975, 25.40781593], [89.82529449, 25.40835381], [89.82523346, 25.40890694], [89.82518768, 25.40948296], [89.8252182, 25.41018867], [89.82524872, 25.41091156], [89.82531738, 25.41227722], [89.82530975, 25.41286278], [89.82534027, 25.41332436], [89.82536316, 25.41347694], [89.82550049, 25.41387177], [89.82559204, 25.41419983], [89.82561493, 25.41498184], [89.82562256, 25.41521835], [89.82565308, 25.41661453], [89.82855988, 25.42372131], [89.83052063, 25.42851257], [89.83123016, 25.43238449], [89.83155823, 25.43415642], [89.83181763, 25.43554878], [89.83194733, 25.43585587], [89.83209229, 25.43618202], [89.83226013, 25.43697357], [89.83246613, 25.43759537], [89.83260345, 25.43836021], [89.83266449, 25.43887138], [89.83291626, 25.43932915], [89.83448792, 25.4422226], [89.8345871, 25.44238091], [89.83472443, 25.44260025], [89.83479309, 25.44271088], [89.83496094, 25.44299126], [89.83576965, 25.44445801], [89.83627319, 25.44534874], [89.83782196, 25.44842339], [89.83811951, 25.44884682], [89.83818054, 25.44898987], [89.83852386, 25.44960976], [89.83854675, 25.44969749], [89.83863831, 25.44979095], [89.83868408, 25.44989014], [89.83892822, 25.45027924], [89.83900452, 25.45049858], [89.83945465, 25.4511528], [89.84029388, 25.45248985], [89.84053802, 25.45290184], [89.8409729, 25.45360565], [89.84112549, 25.45379448], [89.84135437, 25.45414734], [89.84146881, 25.45433807], [89.84210968, 25.45525551], [89.84243774, 25.45579338], [89.84375763, 25.45745659], [89.84436035, 25.4581089], [89.84462738, 25.45851326], [89.84502411, 25.45882607], [89.84544373, 25.45916557], [89.84562683, 25.45942116], [89.8458252, 25.45969391], [89.84627533, 25.46016312], [89.84651947, 25.46045303], [89.84698486, 25.46095276], [89.84716797, 25.46120644], [89.84796143, 25.4624157], [89.84870911, 25.46303368], [89.84882355, 25.4631443], [89.84841919, 25.46318817], [89.8473053, 25.46330833], [89.84820557, 25.46333694], [89.84881592, 25.46347618], [89.84923553, 25.46357155], [89.84942627, 25.46372223], [89.84965515, 25.46393394], [89.85015106, 25.46425056], [89.85015869, 25.46450424], [89.85030365, 25.46466446], [89.85057068, 25.46487427], [89.85115051, 25.46535683], [89.85144043, 25.46558952], [89.85164642, 25.46572304], [89.85197449, 25.46588898], [89.85211945, 25.46595001], [89.85215759, 25.4662075], [89.85215759, 25.46629906], [89.8522644, 25.46636963], [89.852005, 25.46675301], [89.85202789, 25.46690369], [89.85202789, 25.46698761], [89.85202789, 25.46707535], [89.85206604, 25.46717453], [89.85205841, 25.46724701], [89.85181427, 25.46741676], [89.85173798, 25.46747017], [89.85159302, 25.46757507], [89.85159302, 25.46788025], [89.85160065, 25.46834564], [89.85166168, 25.46848106], [89.85176086, 25.46866608], [89.85185242, 25.46886253], [89.85193634, 25.4691143], [89.85193634, 25.46936417], [89.85197449, 25.46992302], [89.85201263, 25.4700489], [89.852005, 25.47020149], [89.85198212, 25.47059059], [89.85197449, 25.47071075], [89.85206604, 25.47137451], [89.85208893, 25.47175026], [89.85205841, 25.47219849], [89.85220337, 25.47242546], [89.85214233, 25.47261429], [89.85205841, 25.47273827], [89.85195923, 25.47286224], [89.85182953, 25.47295189], [89.85157013, 25.47307777], [89.85137939, 25.47317314], [89.85083008, 25.47358322], [89.8507309, 25.47364616], [89.85060883, 25.47372437], [89.85040283, 25.47380829], [89.84997559, 25.47392845], [89.84972382, 25.47397232], [89.84922791, 25.47401428], [89.84923553, 25.47411728], [89.84928894, 25.47513962], [89.84933472, 25.4753685], [89.84944153, 25.47681999], [89.84949493, 25.47724533], [89.84954071, 25.47840309], [89.84955597, 25.4789238], [89.84962463, 25.48045731], [89.84960938, 25.48068428], [89.8495636, 25.48085594], [89.84949493, 25.48133469], [89.84957886, 25.48199654], [89.84976959, 25.48278999], [89.84988403, 25.48330688], [89.8501358, 25.48406219], [89.85021973, 25.48424149], [89.85038757, 25.4846077], [89.85022736, 25.48469925], [89.85001373, 25.48478699], [89.84989929, 25.48483467], [89.84998322, 25.48497963], [89.85005188, 25.48511124], [89.8502655, 25.48513794], [89.85032654, 25.48519325], [89.85037231, 25.48538589], [89.85045624, 25.48585892], [89.85028076, 25.48615456], [89.85015869, 25.48631096], [89.84973907, 25.48683929], [89.849617, 25.48725128], [89.8495636, 25.48760796], [89.8494339, 25.48791313], [89.84938049, 25.48812866], [89.84928131, 25.48831749], [89.84916687, 25.48853493], [89.84912872, 25.48866081], [89.84907532, 25.48890877], [89.84905243, 25.48908043], [89.84898376, 25.48945427], [89.84896851, 25.49003601], [89.84910583, 25.49032021], [89.84920502, 25.49119186], [89.84936523, 25.49203491], [89.84926605, 25.49206924], [89.84912872, 25.49211502], [89.84913635, 25.49223709], [89.84915924, 25.4925251], [89.84921265, 25.49272156], [89.84962463, 25.49349213], [89.84983063, 25.49380302], [89.85048676, 25.49391174], [89.85094452, 25.49400902], [89.85113525, 25.4940815], [89.85131073, 25.49412727], [89.8514328, 25.49413109], [89.85155487, 25.49419022], [89.85170746, 25.49422836], [89.85179901, 25.49429321], [89.85223389, 25.49449921], [89.85258484, 25.49471474], [89.85277557, 25.49481773], [89.85293579, 25.49492264], [89.85313416, 25.49512482], [89.85345459, 25.49537849], [89.85355377, 25.49549484], [89.8536911, 25.49559212], [89.85388947, 25.49577141], [89.8547821, 25.49701118], [89.85504913, 25.49729729], [89.85514832, 25.4975338], [89.85516357, 25.49775505], [89.85486603, 25.49829102], [89.854599, 25.49906921], [89.85453033, 25.49941826], [89.85423279, 25.50017166], [89.85409546, 25.50050926], [89.85391235, 25.50106812], [89.85377502, 25.50152588], [89.85366821, 25.50203705], [89.85359192, 25.50244904], [89.85356903, 25.50294685], [89.85359955, 25.50349236], [89.85370636, 25.50403976], [89.85385132, 25.50434494], [89.85393524, 25.50428009], [89.85412598, 25.50423622], [89.85558319, 25.50363922], [89.85700989, 25.50445366], [89.85704041, 25.50454903], [89.85753632, 25.50603867], [89.85788727, 25.50650406], [89.8579483, 25.50670052], [89.85823059, 25.50781822], [89.85829926, 25.50816727], [89.85848999, 25.5089016], [89.8585434, 25.50972748], [89.8587265, 25.51025772], [89.85883331, 25.51025772], [89.85909271, 25.51124382], [89.85933685, 25.51220894], [89.85936737, 25.51241493], [89.85945892, 25.5129528], [89.85953522, 25.51320839], [89.85960388, 25.51371384], [89.8596344, 25.51390457], [89.85965729, 25.5142231], [89.85967255, 25.51436806], [89.85974121, 25.51464844], [89.85982513, 25.51531219], [89.8599472, 25.51598358], [89.85998535, 25.51639938], [89.8600769, 25.51692963], [89.86012268, 25.51728439], [89.86018372, 25.51772308], [89.85997009, 25.51821327], [89.85964966, 25.51896477], [89.85933685, 25.51961517], [89.85864258, 25.5210762], [89.8584137, 25.52163124], [89.85812378, 25.52229309], [89.85758972, 25.523489], [89.85748291, 25.52377129], [89.85738373, 25.52415276], [89.85709381, 25.52495956], [89.85695648, 25.52534294], [89.85676575, 25.52571297], [89.85652924, 25.52636909], [89.85648346, 25.52646065], [89.8562088, 25.52723312], [89.85610199, 25.52758408], [89.85559082, 25.52884674], [89.85553741, 25.5291481], [89.85529327, 25.52970123], [89.85509491, 25.5301857], [89.85494995, 25.5305481], [89.85478973, 25.53093338], [89.85464478, 25.53121948], [89.85437775, 25.53189278], [89.85430145, 25.53206062], [89.85426331, 25.53220749], [89.85401917, 25.53277779], [89.85397339, 25.53295326], [89.85373688, 25.53343964], [89.85356903, 25.53388214], [89.8532486, 25.53458595], [89.85308838, 25.53494072], [89.85302734, 25.53512192], [89.85294342, 25.53526115], [89.85286713, 25.53538895], [89.85280609, 25.53561974], [89.85266876, 25.53580856], [89.85236359, 25.53642464], [89.8521347, 25.53688812], [89.8513031, 25.53854942], [89.85121918, 25.53871918], [89.85144806, 25.53909683], [89.85208893, 25.53929138], [89.85502625, 25.54023933], [89.85575104, 25.54033089], [89.85612488, 25.54055214], [89.85630798, 25.54066277], [89.85673523, 25.54080582], [89.85785675, 25.54154396], [89.85817719, 25.54178238], [89.85848999, 25.54200172], [89.85914612, 25.54227257], [89.8595047, 25.54243088], [89.85972595, 25.54250336], [89.86039734, 25.54270172], [89.8608551, 25.54276085], [89.86110687, 25.54281616], [89.86196899, 25.54297256], [89.86217499, 25.5430069], [89.86235809, 25.54302216], [89.86273193, 25.54319382], [89.86621094, 25.54284096], [89.87015533, 25.54494286], [89.87010193, 25.54422188], [89.87380219, 25.54928017], [89.87758636, 25.54893112], [89.88636017, 25.55787086], [89.90441132, 25.55949974], [89.91809845, 25.5626297], [89.92605591, 25.56352997], [89.93583679, 25.56270981], [89.94164276, 25.56762123], [89.94937897, 25.56825066], [89.95675659, 25.57046127], [89.96646118, 25.57170105], [89.97280884, 25.57460976], [89.97505188, 25.58350945], [89.97915649, 25.59073067], [89.98950195, 25.58880997], [89.99536133, 25.58634949], [90.00212097, 25.58419037], [90.00582123, 25.58836937], [90.01106262, 25.59835052], [90.01729584, 25.60219193], [90.01844025, 25.60839081], [90.00453949, 25.62382126], [90.00138092, 25.62443161], [89.99933624, 25.62185097], [89.99529266, 25.62302971], [89.98332214, 25.62671089], [89.98230743, 25.62843132], [89.98043823, 25.63756943], [89.94695282, 25.65883064], [89.94184875, 25.67365074], [89.94172668, 25.67811966], [89.93699646, 25.68663025], [89.93235016, 25.68996048], [89.92112732, 25.69442177], [89.91954803, 25.69676971], [89.91850281, 25.70268822], [89.91427612, 25.7040081], [89.9126358, 25.70706177], [89.90487671, 25.71478081], [89.89424133, 25.72723961], [89.89261627, 25.73500061], [89.89541626, 25.74411964], [89.899086, 25.74405098], [89.91137695, 25.74156952], [89.9161377, 25.73919106], [89.92186737, 25.73916817], [89.92794037, 25.74135017], [89.93350983, 25.7445507], [89.93464661, 25.74753952], [89.93371582, 25.75253105], [89.94351959, 25.76054192], [89.94668579, 25.76472092], [89.95239258, 25.77017021], [89.95524597, 25.77445984], [89.95501709, 25.78164101], [89.9526062, 25.78342056], [89.95081329, 25.79198074], [89.95199585, 25.81091118], [89.94935608, 25.81442261], [89.94561768, 25.81610107], [89.94581604, 25.82023048], [89.94458008, 25.82447815], [89.95056915, 25.82487106], [89.95886993, 25.8265686], [89.96795654, 25.82615089], [89.97354889, 25.82814026], [89.97589874, 25.83403969], [89.99080658, 25.83551025], [89.99471283, 25.83876038], [89.99780273, 25.83967018], [90.00160217, 25.84224129], [89.99983215, 25.84369087], [89.99743652, 25.84420967], [89.99756622, 25.84670067], [90.00026703, 25.84860039], [90.00831604, 25.84683037], [90.01152039, 25.84967041], [90.02076721, 25.86161041], [90.02191925, 25.86552811], [90.02137756, 25.86849022], [90.01872253, 25.87137032], [90.01436615, 25.87178993], [90.00977325, 25.87573051], [90.00473785, 25.87868118], [90.01525116, 25.88862038], [90.02126312, 25.89319038], [90.02791595, 25.89431], [90.03450775, 25.89351082], [90.042099, 25.89075089], [90.05219269, 25.89868927], [90.0550766, 25.90809059], [90.05892181, 25.91027069], [90.06330872, 25.91554832], [90.06761932, 25.91616058], [90.07242584, 25.91933823], [90.07797241, 25.91768074], [90.07945251, 25.9192791], [90.08072662, 25.92452812], [90.08738708, 25.92626953], [90.09192657, 25.92876053], [90.08795929, 25.93619919], [90.09612274, 25.93951988], [90.09913635, 25.93926048], [90.10051727, 25.9420681], [90.10536957, 25.94193077], [90.10788727, 25.95059013], [90.11091614, 25.9541111], [90.11377716, 25.95743942], [90.11865234, 25.96125984], [90.12000275, 25.9577198], [90.12322998, 25.95716286], [90.12844849, 25.95877075], [90.13407898, 25.95780945], [90.14002991, 25.95813942], [90.14739227, 25.96447945], [90.15339661, 25.9647007], [90.15448761, 25.9602108], [90.15838623, 25.95825958], [90.16349792, 25.95736122], [90.16848755, 25.95738029], [90.1726532, 25.95874977], [90.17611694, 25.95708275], [90.18052673, 25.9470005], [90.18251038, 25.94445038], [90.18566895, 25.94556999], [90.18945313, 25.95323944], [90.1939621, 25.95700073], [90.20844269, 25.96157265], [90.21112061, 25.95564079], [90.21276093, 25.95388985], [90.22737122, 25.95513916], [90.27781677, 25.96317291], [90.28658295, 25.96389961], [90.32434082, 25.97438049], [90.32905579, 25.98269844], [90.32994843, 25.9885006], [90.33692169, 25.99016953], [90.33931732, 25.9968605], [90.34485626, 26.00123978], [90.3466568, 26.00295258], [90.36499023, 26.01032066], [90.38080597, 26.01164818], [90.38736725, 26.01126289], [90.39395142, 26.01410103], [90.39649963, 26.01415062], [90.39729309, 26.01222992], [90.40019226, 26.00928116], [90.40756226, 26.00756073], [90.41104126, 26.00587082], [90.41394043, 26.00131989], [90.41649628, 25.99685097], [90.41742706, 25.99234009], [90.42862701, 25.98904037], [90.44711304, 25.99653053], [90.45751953, 25.99957275], [90.45791626, 26.00134087], [90.45909882, 26.00323105], [90.46530151, 26.00722122], [90.47090149, 26.01259995], [90.47728729, 26.0152607], [90.48121643, 26.01402283], [90.48958588, 26.00963974], [90.49236298, 26.00650978], [90.49793243, 26.00365067], [90.50013733, 26.00136185], [90.5057373, 25.99602127], [90.51355743, 25.98237038], [90.52406311, 25.96990013], [90.52983856, 25.96186066], [90.53446198, 25.95802116], [90.53479767, 25.94564056], [90.53378296, 25.93629265], [90.5322113, 25.93255234], [90.52616119, 25.92827988], [90.51851654, 25.90940094], [90.51110077, 25.90014076], [90.51254272, 25.89624023], [90.518013, 25.89648056], [90.52548218, 25.90101051], [90.53360748, 25.90880013], [90.53917694, 25.91546059], [90.54682159, 25.91987991], [90.55335999, 25.92912102], [90.56324005, 25.93556976], [90.57137299, 25.93902969], [90.57273865, 25.94400024], [90.57277679, 25.94815063], [90.57879639, 25.9580307], [90.5824585, 25.95979118], [90.58727264, 25.95391273], [90.59185028, 25.95211983], [90.60193634, 25.95178032], [90.60539246, 25.94695091], [90.62901306, 25.93742943], [90.60756683, 25.91958046], [90.60650635, 25.91228104], [90.60809326, 25.90801811], [90.61074829, 25.90744972], [90.61419678, 25.89950943], [90.62480927, 25.89889908], [90.62671661, 25.90135956], [90.62893677, 25.90654945], [90.62686157, 25.91127014], [90.62732697, 25.91699028], [90.63783264, 25.92333031], [90.6539917, 25.9296627], [90.6701889, 25.93425941], [90.67565155, 25.93647957], [90.68604279, 25.95080948], [90.71309662, 25.95218277], [90.71774292, 25.9547081], [90.72068024, 25.94917107], [90.72540283, 25.94877052], [90.73226929, 25.95256042], [90.74028778, 25.95491028], [90.74355316, 25.95667267], [90.74743652, 25.95732117], [90.74604797, 25.95264053], [90.74378967, 25.94943047], [90.74469757, 25.94650078], [90.74030304, 25.94089127], [90.744133, 25.93279076], [90.74746704, 25.93231964], [90.75070953, 25.93408012], [90.75263977, 25.93395996], [90.74619293, 25.92193031], [90.74053955, 25.91521072], [90.74234009, 25.91295052], [90.74543762, 25.91229057], [90.75006104, 25.91924095], [90.75894928, 25.9216404], [90.75762939, 25.91657066], [90.75772095, 25.91107178], [90.7690506, 25.90851021], [90.77806091, 25.90829086], [90.77848816, 25.91430092], [90.78167725, 25.92124939], [90.79170227, 25.93573952], [90.79709625, 25.9414711], [90.80869293, 25.94718933], [90.80989075, 25.95215988], [90.82044983, 25.94842911], [90.82388306, 25.94510078], [90.82800293, 25.94742966], [90.83226013, 25.94528008], [90.8361969, 25.9472599], [90.83676147, 25.93819046], [90.83983612, 25.93843269], [90.84104156, 25.94317055], [90.84323883, 25.94481087], [90.85679626, 25.94433022], [90.86960602, 25.94239998], [90.87288666, 25.94292259], [90.87240601, 25.94672966], [90.87523651, 25.94911957], [90.88022614, 25.94625092], [90.88143921, 25.95063972], [90.88298035, 25.9517498], [90.88835907, 25.94362068], [90.89238739, 25.93906021], [90.89646149, 25.93746948], [90.89704132, 25.93538094], [90.89537811, 25.93151093], [90.90119171, 25.92959023], [90.91252899, 25.92029953], [90.91607666, 25.91505814], [90.91911316, 25.913311], [90.91629791, 25.92814064], [90.9158783, 25.94316101], [90.91834259, 25.94316101], [90.93206787, 25.93967247], [90.93466187, 25.94114113], [90.93749237, 25.94476128], [90.94274902, 25.9475708], [90.9455719, 25.93912125], [90.95384979, 25.93670273], [90.95791626, 25.93394279], [90.96063995, 25.92769814], [90.96689606, 25.90533066], [90.96730804, 25.89664078], [90.96660614, 25.89100075], [90.967453, 25.88718033], [90.97132874, 25.88767052], [90.97538757, 25.88945007], [90.98480225, 25.88993263], [90.99688721, 25.8886795], [91.00132751, 25.88648987], [91.01373291, 25.88431931], [91.02060699, 25.88727951], [91.02568054, 25.88838005], [91.02828979, 25.88857079], [91.02922058, 25.88804817], [91.02910614, 25.87985039], [91.02651978, 25.86662102], [91.0218277, 25.86133194], [91.01512909, 25.85906029], [91.0131073, 25.85719109], [91.01274109, 25.84884071], [91.00866699, 25.83823967], [91.00158691, 25.82579994], [91.00078583, 25.82225037], [91.00611115, 25.8207798], [91.01270294, 25.8210907], [91.02081299, 25.82262039], [91.02494049, 25.82756042], [91.0419693, 25.83940125], [91.04910278, 25.84880829], [91.06590271, 25.84642029], [91.07853699, 25.85261917], [91.07299805, 25.84247971], [91.07287598, 25.83833122], [91.06751251, 25.83630943], [91.0617981, 25.83608055], [91.05722046, 25.83204269], [91.04988098, 25.82889938], [91.059021, 25.82226944], [91.06326294, 25.82036972], [91.06653595, 25.82575989], [91.08135223, 25.82934189], [91.12078094, 25.83134079], [91.12634277, 25.83819962], [91.13168335, 25.84194946], [91.13790894, 25.84213066], [91.14539337, 25.84733963], [91.15286255, 25.85007286], [91.16165161, 25.84931946], [91.16819, 25.84563065], [91.17901611, 25.84275055], [91.1817627, 25.84412193], [91.18547058, 25.84996986], [91.19303894, 25.85523033], [91.1964798, 25.8590107], [91.19812012, 25.8548317], [91.1986618, 25.84763908], [91.20262909, 25.84054184], [91.19451904, 25.83061028], [91.19431305, 25.82640076], [91.18987274, 25.8207798], [91.18815613, 25.81557083], [91.19095612, 25.81069946], [91.18724823, 25.80328941], [91.18474579, 25.79503059], [91.18396759, 25.78259087], [91.17993164, 25.7763195], [91.18118286, 25.77334976], [91.18591309, 25.76993942], [91.18569946, 25.76687813], [91.18917847, 25.7634697], [91.18871307, 25.73892975], [91.19233704, 25.73608971], [91.19198608, 25.72958183], [91.19799805, 25.73097992], [91.21586609, 25.72390938], [91.22144318, 25.72604942], [91.22387695, 25.72341919], [91.23249817, 25.7291584], [91.25537109, 25.74782944], [91.26228333, 25.74929047], [91.27562714, 25.74694061], [91.27646637, 25.75167084], [91.27958679, 25.75666237], [91.28729248, 25.76411057], [91.29689789, 25.77824974], [91.30632782, 25.79636955], [91.32498932, 25.8237896], [91.33242798, 25.83209038], [91.33217621, 25.83370018], [91.33355713, 25.83884048], [91.33642578, 25.83840942], [91.34249115, 25.83609962], [91.3443985, 25.83943939], [91.34855652, 25.8403511], [91.35330963, 25.83773994], [91.35688782, 25.84146118], [91.36370087, 25.84049034], [91.37049866, 25.84430122], [91.3768692, 25.84487915], [91.38211823, 25.84693909], [91.38851929, 25.84729958], [91.40119171, 25.85110092], [91.40509033, 25.84988022], [91.41272736, 25.85391808], [91.41889954, 25.85472107], [91.42430115, 25.85355949], [91.43084717, 25.84776115], [91.44122314, 25.84163094], [91.44439697, 25.84102058], [91.44740295, 25.84566116], [91.45495605, 25.85131264], [91.46872711, 25.85902977], [91.47496033, 25.85719109], [91.47840118, 25.85768127], [91.48303986, 25.86289978], [91.49603271, 25.86234093], [91.50788116, 25.8647995], [91.51275635, 25.86655807], [91.51911926, 25.87312126], [91.52176666, 25.87434959], [91.52540588, 25.87289047], [91.52887726, 25.88087082], [91.53262329, 25.88406944], [91.53205872, 25.88815117], [91.52973938, 25.88968086], [91.52577972, 25.89010811], [91.5222168, 25.88593292], [91.51976776, 25.87802124], [91.51725006, 25.87467194], [91.5135498, 25.8709507], [91.50778198, 25.86744118], [91.49830627, 25.86720276], [91.49369049, 25.86552811], [91.47738647, 25.86872292], [91.47476196, 25.87123108], [91.47593689, 25.87803841], [91.47867584, 25.8846817], [91.48338318, 25.89105988], [91.48853302, 25.89484978], [91.49291992, 25.89557838], [91.49861145, 25.8924675], [91.50325775, 25.89216042], [91.50115204, 25.89846992], [91.50853729, 25.90975952], [91.52478027, 25.92078972], [91.53132629, 25.92371178], [91.5358963, 25.93400192], [91.521698, 25.92485046], [91.51685333, 25.92002106], [91.51078033, 25.91543007], [91.50557709, 25.91308022], [91.50334167, 25.9143219], [91.50163269, 25.92076111], [91.51628876, 25.9383297], [91.51978302, 25.94089127], [91.51818848, 25.95280266], [91.51850128, 25.95815086], [91.52379608, 25.95940971], [91.52584839, 25.96132088], [91.53240967, 25.96224022], [91.53717041, 25.96210098], [91.53727722, 25.96838951], [91.54894257, 25.97509766], [91.5512619, 25.97489929], [91.55484009, 25.98661041], [91.56536865, 26.00184059], [91.56608582, 26.00375938], [91.56513214, 26.00750923], [91.56859589, 26.01194954], [91.56971741, 26.01684189], [91.56880951, 26.02174187], [91.57003021, 26.02748108], [91.57583618, 26.03310966], [91.58409882, 26.03198051], [91.58812714, 26.03014946], [91.59706116, 26.01706123], [91.59680939, 26.02079964], [91.60186768, 26.02263069], [91.61654663, 26.02472115], [91.62029266, 26.02703094], [91.62610626, 26.02396965], [91.63215637, 26.02240944], [91.63339996, 26.01785088], [91.63210297, 26.01395988], [91.63302612, 26.00490952], [91.63207245, 26.00187111], [91.63044739, 25.99982834], [91.62671661, 25.99765015], [91.62866974, 25.99513054], [91.62471771, 25.98590279], [91.62679291, 25.98238945], [91.62802124, 25.97697067], [91.63214111, 25.97079086], [91.63794708, 25.96484947], [91.63408661, 25.96050072], [91.63011932, 25.94463921], [91.62462616, 25.94597054], [91.6109314, 25.94460106], [91.61115265, 25.93992043], [91.62275696, 25.93099022], [91.63282776, 25.92576981], [91.6479187, 25.91374016], [91.65148926, 25.90766907], [91.65688324, 25.90788078], [91.66194153, 25.90987968], [91.66723633, 25.90818977], [91.66931152, 25.90538979], [91.67598724, 25.91183281], [91.6785965, 25.91732025], [91.68641663, 25.92124939], [91.69232178, 25.92910194], [91.70197296, 25.93792915], [91.70091248, 25.94189072], [91.70816803, 25.94437027], [91.71393585, 25.94722939], [91.7201767, 25.95407104], [91.72162628, 25.96507835], [91.71977997, 25.97830009], [91.72116852, 26.00184059], [91.72276306, 26.01979828], [91.72466278, 26.02725983], [91.72318268, 26.03032112], [91.72640991, 26.04691124], [91.73295593, 26.05102921], [91.73458862, 26.05664063], [91.73126221, 26.05920982], [91.75948334, 26.07129288], [91.77206421, 26.08448219], [91.77851868, 26.09124947], [91.78042603, 26.0883007], [91.78457642, 26.08658028], [91.79036713, 26.08702087], [91.80178833, 26.10494041], [91.80805969, 26.10382271], [91.81080627, 26.1051712], [91.81555939, 26.11144066], [91.81931305, 26.11874008], [91.82655334, 26.11814117], [91.85383606, 26.10478973], [91.86470032, 26.10034752], [91.87578583, 26.09773064], [91.87523651, 26.08456039], [91.86934662, 26.05685997], [91.87016296, 26.05219078], [91.88323212, 26.03000069], [91.89195251, 26.02955246], [91.90091705, 26.02626991], [91.90746307, 26.02711105], [91.91165161, 26.02383041], [91.9169693, 26.02146149], [91.91684723, 26.01375961], [91.91565704, 26.01032829], [91.91871643, 26.0072403], [91.91953278, 26.00159073], [91.91957092, 26.0001297], [91.92209625, 25.99953079], [91.92582703, 25.9997406], [91.92681122, 26.0016098], [91.93396759, 26.01466942], [91.94129181, 26.01400185], [91.94631958, 26.01449966], [91.9524231, 26.01781273], [91.95781708, 26.01889038], [91.9781723, 26.0258503], [91.98423004, 26.03054047], [91.98739624, 26.03872108], [91.99106598, 26.04103279], [91.99765015, 26.03884125], [92.0004425, 26.03918076], [92.00337982, 26.03803062], [92.00817871, 26.03944969], [92.01761627, 26.03959084], [92.02218628, 26.03926086], [92.02387238, 26.03843117], [92.02789307, 26.03989983], [92.03475189, 26.03968811], [92.03610229, 26.0394001], [92.03961182, 26.03622055], [92.05018616, 26.033041], [92.05285645, 26.03283119], [92.06321716, 26.03471756], [92.07045746, 26.03784943], [92.07363129, 26.04027939], [92.0788269, 26.04178047], [92.08113098, 26.04362106], [92.0933609, 26.04852104], [92.10888672, 26.04971123], [92.1162262, 26.04655266], [92.12338257, 26.04488945], [92.12702179, 26.04590034], [92.13311768, 26.04589081], [92.13816833, 26.0528183], [92.14377594, 26.05764008], [92.14621735, 26.05855942], [92.14898682, 26.06163025], [92.15052032, 26.06489944], [92.15467834, 26.06805992], [92.16909027, 26.07759094], [92.17830658, 26.07950974], [92.18094635, 26.0761795], [92.17888641, 26.06921005], [92.18044281, 26.06850052], [92.18232727, 26.07034111], [92.18460083, 26.06918907], [92.18834686, 26.06887054], [92.1893692, 26.06688118], [92.20182037, 26.07002068], [92.20826721, 26.06856918], [92.20934296, 26.06918907], [92.2088089, 26.07065964], [92.21042633, 26.07110023], [92.21201324, 26.07097054], [92.21356201, 26.06967926], [92.21611023, 26.0692997], [92.21835327, 26.07015038], [92.22834015, 26.0676403], [92.24117279, 26.06254005], [92.25145721, 26.06436157], [92.26568604, 26.06539917], [92.26864624, 26.0679493], [92.27231598, 26.0666008], [92.27372742, 26.06589127], [92.27368927, 26.06501961], [92.2807312, 26.06918907], [92.28806305, 26.06999016], [92.29014587, 26.07279968], [92.29004669, 26.0737896], [92.29392242, 26.07779121], [92.29598236, 26.07888985], [92.2973175, 26.07914925], [92.29966736, 26.07673073], [92.30158234, 26.0764904], [92.25572205, 26.02893257], [92.22141266, 26.00225067], [92.22168732, 25.99860191], [92.2191925, 26.00078011], [92.21520233, 25.99627113], [92.21100616, 25.99465942], [92.2077179, 25.99174118], [92.2091217, 25.9896698], [92.20738983, 25.98823166], [92.20089722, 25.98560905], [92.19161987, 25.98520279], [92.18097687, 25.97523117], [92.17694092, 25.97310066], [92.17311096, 25.97219849], [92.16739655, 25.96769905], [92.16555023, 25.96443939], [92.16732788, 25.95876122], [92.16532898, 25.95395088], [92.16075897, 25.95152092], [92.15631866, 25.94479942], [92.15609741, 25.94300079], [92.15751648, 25.93927956], [92.16142273, 25.93254089], [92.16017151, 25.92596054], [92.15992737, 25.91518974], [92.16369629, 25.91179085], [92.17431641, 25.90918922], [92.18089294, 25.90859032], [92.18315125, 25.91091919], [92.18364716, 25.91283035], [92.1867218, 25.91580963], [92.19203949, 25.91578293], [92.1971817, 25.91802979], [92.19700623, 25.91366005], [92.19773102, 25.91125107], [92.20059967, 25.90824127], [92.20513916, 25.90871048], [92.20752716, 25.91053009], [92.2175293, 25.90991974], [92.22260284, 25.91131973], [92.22380066, 25.91036034], [92.22547913, 25.90704918], [92.22503662, 25.90162086], [92.22384644, 25.90068817], [92.2182312, 25.90019989], [92.21560669, 25.89384079], [92.21286011, 25.8921299], [92.20641327, 25.89145279], [92.20332336, 25.89009094], [92.19496155, 25.88126945], [92.18694305, 25.87481117], [92.1810379, 25.87162018], [92.17988586, 25.8701725], [92.17910004, 25.86791039], [92.18078613, 25.86321068], [92.18096161, 25.85136032], [92.17830658, 25.84807968], [92.17524719, 25.84654236], [92.17144012, 25.83773041], [92.16934204, 25.8353405], [92.16551971, 25.83304024], [92.16326141, 25.82575035], [92.16308594, 25.82183075], [92.15573883, 25.81659126], [92.15310669, 25.81274986], [92.15368652, 25.79549026], [92.15116882, 25.78745079], [92.15099335, 25.78364944], [92.15479279, 25.77977943], [92.15518188, 25.77864265], [92.15421295, 25.77672958], [92.15410614, 25.77292061], [92.15596771, 25.76454163], [92.15738678, 25.76197052], [92.15824127, 25.75719833], [92.1648407, 25.74475098], [92.16552734, 25.73444939], [92.16423035, 25.72873116], [92.16092682, 25.72625923], [92.15629578, 25.72481155], [92.15371704, 25.72270012], [92.15101624, 25.71936989], [92.14956665, 25.71450806], [92.15106201, 25.71183014], [92.15585327, 25.70914268], [92.15757751, 25.70103836], [92.16104889, 25.69729042], [92.16145325, 25.69598007], [92.16044617, 25.69090271], [92.16435242, 25.68485069], [92.16546631, 25.67840958], [92.1605072, 25.67329025], [92.16069794, 25.67185974], [92.16445923, 25.66931915], [92.16976166, 25.66640091], [92.17095184, 25.66687965], [92.17495728, 25.67021751], [92.18477631, 25.6811409], [92.18791962, 25.68343163], [92.19198608, 25.68632126], [92.19407654, 25.68611908], [92.19692993, 25.68695068], [92.19831085, 25.68635941], [92.2000885, 25.68728828], [92.20156097, 25.68972015], [92.21063995, 25.69592094], [92.22490692, 25.71397018], [92.22899628, 25.71620941], [92.23262787, 25.71511078], [92.23384857, 25.71006966], [92.23475647, 25.70882034], [92.23684692, 25.70839119], [92.24804688, 25.71096039], [92.25357819, 25.71012115], [92.25570679, 25.7107296], [92.260849, 25.7103405], [92.27052307, 25.71093178], [92.28460693, 25.71586037], [92.28797913, 25.71590042], [92.29358673, 25.71730042], [92.30610657, 25.72313118], [92.30825806, 25.72615051], [92.31150055, 25.72607994], [92.3139267, 25.72468185], [92.31768036, 25.72379112], [92.33354187, 25.72523117], [92.33901215, 25.72685051], [92.34805298, 25.73193169], [92.35179901, 25.73487091], [92.36299896, 25.73651123], [92.36830902, 25.74044037], [92.36753845, 25.74238014], [92.37146759, 25.7464695], [92.38510132, 25.75356293], [92.38694763, 25.752491], [92.38433838, 25.75032997], [92.38353729, 25.7474308], [92.38495636, 25.74475098], [92.38696289, 25.74311066], [92.39212799, 25.74259949], [92.39476776, 25.74147987], [92.40479279, 25.74369049], [92.41073608, 25.74312973], [92.41639709, 25.7404995], [92.41246796, 25.73739052], [92.41326141, 25.73396111], [92.41277313, 25.73298073], [92.41697693, 25.72968102], [92.42134857, 25.72945023], [92.43200684, 25.7319603], [92.4331665, 25.73145294], [92.4420166, 25.72085953], [92.43644714, 25.71560097], [92.42962646, 25.71326828], [92.42722321, 25.71041107], [92.43152618, 25.70425034], [92.43334198, 25.69523048], [92.43213654, 25.69100952], [92.43434143, 25.68753052], [92.44046783, 25.68812943], [92.44001007, 25.68922043], [92.44303894, 25.68765259], [92.45128632, 25.68661118], [92.45524597, 25.6842308], [92.45987701, 25.68297005], [92.46544647, 25.68246078], [92.47154999, 25.67494965], [92.47466278, 25.67331123], [92.48134613, 25.66389275], [92.48828888, 25.64999008], [92.49326324, 25.63613129], [92.49790192, 25.62696075], [92.50170898, 25.62293053], [92.51055145, 25.61720085], [92.51727295, 25.62008286], [92.5332489, 25.61594963], [92.54043579, 25.61777115], [92.54453278, 25.61425018], [92.55323792, 25.6138401], [92.55761719, 25.61198807], [92.55861664, 25.60895157], [92.55618286, 25.6058712], [92.55724335, 25.59621048], [92.55632019, 25.59280014], [92.56092834, 25.58273125], [92.56095886, 25.57425117], [92.56468201, 25.56825829], [92.56954193, 25.56446075], [92.57250214, 25.56042099], [92.57610321, 25.55965042], [92.58141327, 25.55977249], [92.58747864, 25.55298805], [92.59346771, 25.55393028], [92.60259247, 25.55738068], [92.60349274, 25.56108284], [92.60871124, 25.56573105], [92.61248779, 25.56550026], [92.62110138, 25.56830978], [92.62610626, 25.5680294], [92.6288681, 25.56949043], [92.63056946, 25.57066917], [92.63323212, 25.57479095], [92.63414764, 25.57888031], [92.64063263, 25.58736992], [92.64833832, 25.59235001], [92.65119171, 25.59272957], [92.65345764, 25.59218025], [92.65760803, 25.58906174], [92.66047668, 25.58506012], [92.66072083, 25.58184052], [92.66065216, 25.57031822], [92.65735626, 25.5633812], [92.64987946, 25.56001091], [92.64496613, 25.54660034], [92.6446991, 25.53744125], [92.63762665, 25.52852821], [92.62760925, 25.52221107], [92.62162781, 25.51575089], [92.60959625, 25.51260948], [92.60559082, 25.50811958], [92.59358215, 25.50308037], [92.58950043, 25.49951935], [92.58104706, 25.49515915], [92.57559204, 25.49043083], [92.56783295, 25.48077011], [92.56655121, 25.47512054], [92.56741333, 25.46747017], [92.56912994, 25.46479034], [92.5714798, 25.46407127], [92.58229065, 25.47289085], [92.58544159, 25.4675808], [92.59369659, 25.47101021], [92.59815979, 25.47165108], [92.60138702, 25.46413994], [92.59976959, 25.45705032], [92.60018921, 25.45387268], [92.60114288, 25.45239067], [92.60450745, 25.4501915], [92.60555267, 25.44836044], [92.60529327, 25.4419117], [92.60775757, 25.43035126], [92.60697174, 25.42718124], [92.60700989, 25.41853905], [92.60909271, 25.41657066], [92.61183929, 25.41612053], [92.61477661, 25.41743088], [92.6178894, 25.42202187], [92.62063599, 25.42371941], [92.62864685, 25.42502975], [92.62931061, 25.42699051], [92.62851715, 25.43061066], [92.62930298, 25.43464088], [92.63265991, 25.43314171], [92.63791656, 25.42881966], [92.63791656, 25.42266083], [92.63922882, 25.4203701], [92.63961029, 25.41963005], [92.64163208, 25.41953278], [92.65054321, 25.43166924], [92.65428162, 25.43534088], [92.65365601, 25.42394066], [92.65688324, 25.41570091], [92.66010284, 25.41036034], [92.66368866, 25.40937042], [92.66703796, 25.41407967], [92.67093658, 25.41671944], [92.67376709, 25.41714096], [92.68004608, 25.40858078], [92.68817139, 25.40442085], [92.69351959, 25.39999008], [92.70037842, 25.38779068], [92.70292664, 25.38661957], [92.70973206, 25.38611984], [92.71289825, 25.38454056], [92.716362, 25.37934113], [92.7181015, 25.37498283], [92.7205658, 25.37490273], [92.72136688, 25.37549019], [92.72543335, 25.38043022], [92.73480988, 25.38249969], [92.73705292, 25.38125038], [92.73610687, 25.37380981], [92.74059296, 25.36678123], [92.74009705, 25.36464119], [92.74060822, 25.36372948], [92.7456665, 25.3611393], [92.74823761, 25.35811043], [92.75009918, 25.35437965], [92.75115967, 25.34847069], [92.75875854, 25.33986092], [92.76056671, 25.33527946], [92.76326752, 25.33559036], [92.76947021, 25.33950806], [92.77245331, 25.33961105], [92.78246307, 25.33428955], [92.78437042, 25.3325386], [92.78801727, 25.31760979], [92.78473663, 25.31152916], [92.78383636, 25.30800056], [92.78691101, 25.30067062], [92.78882599, 25.29154015], [92.79222107, 25.28679848], [92.79222107, 25.28518105], [92.78913879, 25.27852249], [92.78211975, 25.27592087], [92.77947235, 25.27376175], [92.76976013, 25.26893044], [92.77617645, 25.26293945], [92.77670288, 25.2605381], [92.76464844, 25.24934959], [92.77028656, 25.24020004], [92.77223969, 25.2332592], [92.78630829, 25.23140144], [92.79434967, 25.22600937], [92.80309296, 25.22150993], [92.80442047, 25.21932983], [92.80356598, 25.21723938], [92.7984314, 25.21344948], [92.79289246, 25.21235275], [92.78775024, 25.20952988], [92.77957153, 25.20310974], [92.76764679, 25.2047596], [92.76345062, 25.20384979], [92.75889587, 25.20402908], [92.75453949, 25.20537186], [92.7516861, 25.20734978], [92.74713898, 25.20776939], [92.74202728, 25.20309067], [92.7333374, 25.20322037], [92.72416687, 25.19919968], [92.71621704, 25.19415855], [92.70461273, 25.19052124], [92.69393921, 25.18135071], [92.68762207, 25.18231964], [92.68284607, 25.18204117], [92.6794281, 25.18309021], [92.6770401, 25.18218994], [92.67224121, 25.17815971], [92.66690826, 25.17706108], [92.66433716, 25.17535973], [92.66297913, 25.1729908], [92.66081238, 25.16225243], [92.65953827, 25.15912056], [92.65571594, 25.15413094], [92.65120697, 25.15240097], [92.64826965, 25.15265274], [92.6440506, 25.15117073], [92.63800812, 25.1452198], [92.6324234, 25.13755989], [92.63079834, 25.13183975], [92.62996674, 25.12503052], [92.62470245, 25.11869049], [92.62164307, 25.11770058], [92.61003113, 25.12409973], [92.60314941, 25.12499046], [92.59842682, 25.12471008], [92.59443665, 25.12829018], [92.58168793, 25.13187027], [92.5790329, 25.13200951], [92.56803894, 25.13009071], [92.56549835, 25.1312809], [92.55784607, 25.12997055], [92.55316925, 25.1307106], [92.54312897, 25.1350193], [92.53993988, 25.13727951], [92.53562927, 25.13441277], [92.53018951, 25.13682175], [92.52746582, 25.13994026], [92.52466583, 25.14002991], [92.52522278, 25.12557983], [92.53024292, 25.1218605], [92.53132629, 25.11990166], [92.53305817, 25.11214828], [92.54081726, 25.10412979], [92.54294586, 25.09959984], [92.53804779, 25.09931183], [92.53201294, 25.10396004], [92.52651215, 25.10585022], [92.50978088, 25.10547066], [92.49910736, 25.10814857], [92.48429871, 25.10806084], [92.48031616, 25.10040855], [92.47975922, 25.09574127], [92.48017883, 25.08584023], [92.47654724, 25.07825279], [92.474617, 25.07080078], [92.47091675, 25.06689072], [92.46750641, 25.06137085], [92.46598816, 25.05715752], [92.46366882, 25.0555706], [92.46203613, 25.05583], [92.45983887, 25.0546608], [92.46015167, 25.04959106], [92.46286011, 25.05014992], [92.46466064, 25.04722977], [92.46325684, 25.03712845], [92.45976257, 25.03518105], [92.45680237, 25.03503036], [92.45420837, 25.03660965], [92.45101929, 25.04095078], [92.4465332, 25.04204178], [92.44178009, 25.03985023], [92.43788147, 25.03375244], [92.43192291, 25.03290749], [92.42590332, 25.0318203], [92.4262619, 25.03164101], [92.42782593, 25.03157043], [92.4306488, 25.03226089], [92.43284607, 25.03102112], [92.43325043, 25.02808952], [92.43219757, 25.02507973], [92.43099976, 25.0216198], [92.43105316, 25.01581955], [92.43036652, 25.01280975], [92.42945099, 25.00969124], [92.4258728, 25.00319099], [92.42363739, 24.99609947], [92.42446899, 24.98257065], [92.42948151, 24.97988129], [92.42855072, 24.97290993], [92.42849731, 24.97257996], [92.43161011, 24.97066116], [92.43515778, 24.96637917], [92.44003296, 24.96680069], [92.44590759, 24.96696281], [92.44904327, 24.97154808], [92.44940948, 24.97208977], [92.45445251, 24.97318077], [92.4605484, 24.97615051], [92.4640274, 24.97077942], [92.46711731, 24.96858025], [92.47103119, 24.96409988], [92.47371674, 24.95709991], [92.47158051, 24.9559803], [92.46470642, 24.95478058], [92.46328735, 24.95591736], [92.46361542, 24.95598793], [92.46416473, 24.95616913], [92.46488953, 24.95653915], [92.4657135, 24.95697021], [92.46607971, 24.95719337], [92.46646881, 24.95757866], [92.46718597, 24.95828438], [92.46768188, 24.95890999], [92.46796417, 24.9593544], [92.46833038, 24.96022606], [92.46839142, 24.96099281], [92.46842957, 24.96180725], [92.46842957, 24.96230125], [92.46831512, 24.96273232], [92.46777344, 24.96351051], [92.46661377, 24.96440125], [92.46561432, 24.96507454], [92.46498871, 24.96560097], [92.46382904, 24.96648788], [92.46258545, 24.96781731], [92.46178436, 24.96884918], [92.460289, 24.96983147], [92.45940399, 24.97033119], [92.45875549, 24.97052193], [92.45801544, 24.97062111], [92.45787811, 24.97063446], [92.45738983, 24.97068024], [92.45608521, 24.97016335], [92.45520782, 24.96963501], [92.45500183, 24.96945381], [92.45413971, 24.96870422], [92.45276642, 24.96755028], [92.45158386, 24.96673393], [92.44959259, 24.96604538], [92.44778442, 24.96584892], [92.44618988, 24.96575737], [92.44350433, 24.96627998], [92.44276428, 24.96639633], [92.44199371, 24.96632767], [92.4407196, 24.96639442], [92.44017792, 24.96640015], [92.43971252, 24.96634293], [92.43897247, 24.96634293], [92.43863678, 24.96638489], [92.43733978, 24.96626854], [92.43585968, 24.96608353], [92.43041992, 24.96556091], [92.42863464, 24.96540451], [92.42765808, 24.96540642], [92.42673492, 24.96523094], [92.42597961, 24.96509743], [92.42553711, 24.96508408], [92.4249649, 24.96503258], [92.42446899, 24.96497536], [92.42360687, 24.96494102], [92.42186737, 24.96559525], [92.42068481, 24.96608734], [92.41943359, 24.96756744], [92.41952515, 24.96957588], [92.42008209, 24.97143745], [92.42042542, 24.97277832], [92.42072296, 24.97448158], [92.42095184, 24.97575378], [92.42126465, 24.97771835], [92.4214325, 24.97871208], [92.42163086, 24.97998047], [92.42176056, 24.98139], [92.42189026, 24.9829998], [92.42193604, 24.9840889], [92.42195892, 24.98516273], [92.42201996, 24.98624039], [92.42211151, 24.98732376], [92.42205048, 24.98848915], [92.42196655, 24.98873711], [92.42160797, 24.98911095], [92.4214859, 24.98922729], [92.42132568, 24.98994255], [92.42115784, 24.99017143], [92.42087555, 24.99031067], [92.4203949, 24.99048996], [92.41977692, 24.9905262], [92.41938782, 24.99053192], [92.41886139, 24.99048805], [92.41832733, 24.99041367], [92.41790009, 24.99026871], [92.41716766, 24.99015617], [92.41627502, 24.99005127], [92.41516876, 24.98978996], [92.4149704, 24.98974419], [92.41429901, 24.98978233], [92.41433716, 24.99031448], [92.41647339, 24.9919281], [92.41671753, 24.9924984], [92.41708374, 24.99329758], [92.41738892, 24.99396324], [92.41753387, 24.99428558], [92.418396, 24.99625969], [92.41877747, 24.99711418], [92.41938019, 24.99843407], [92.42056274, 25.00104523], [92.42173767, 25.00362015], [92.42238617, 25.00492096], [92.42279053, 25.00605965], [92.42325592, 25.00749779], [92.42372894, 25.00907135], [92.4240799, 25.01024818], [92.42449951, 25.01199341], [92.42463684, 25.01260948], [92.4246521, 25.0126915], [92.42467499, 25.01281738], [92.42480469, 25.01340675], [92.42450714, 25.01400757], [92.42433167, 25.01434135], [92.42430878, 25.01531601], [92.42429352, 25.01608658], [92.42427826, 25.01677513], [92.42424774, 25.0178299], [92.42421722, 25.01894951], [92.42420197, 25.01950455], [92.42431641, 25.01958466], [92.42440796, 25.01962471], [92.42449188, 25.01950073], [92.42454529, 25.01940536], [92.42460632, 25.01936722], [92.42469788, 25.01938629], [92.42485809, 25.01947212], [92.4249649, 25.01952744], [92.42525482, 25.01959419], [92.42532349, 25.01962662], [92.42538452, 25.01970863], [92.42554474, 25.0197506], [92.4257431, 25.01980019], [92.4258728, 25.02019119], [92.42586517, 25.02058029], [92.42584991, 25.02132797], [92.42584991, 25.0219574], [92.42584229, 25.02272034], [92.42583466, 25.02332687], [92.42582703, 25.02443314], [92.42581177, 25.02544212], [92.42578888, 25.02653503], [92.42577362, 25.02759933], [92.42576599, 25.02879524], [92.42562866, 25.02901077], [92.42521667, 25.02965927], [92.42420959, 25.02994728], [92.42382813, 25.03014183], [92.4236908, 25.03013992], [92.42337036, 25.02986336], [92.42320251, 25.0296669], [92.42306519, 25.02932358], [92.42274475, 25.02884102], [92.42218781, 25.02867889], [92.42201996, 25.02833557], [92.42140961, 25.02793312], [92.42116547, 25.02802658], [92.42082214, 25.02815437], [92.42030334, 25.0284481], [92.41911316, 25.02904701], [92.41899109, 25.02969933], [92.41821289, 25.03002167], [92.41740417, 25.03013229], [92.41692352, 25.03040695], [92.41629028, 25.03034592], [92.41598511, 25.03016472], [92.41576385, 25.03003693], [92.41545868, 25.029953], [92.41481781, 25.02977371], [92.41371155, 25.0291996], [92.41307068, 25.02895737], [92.41301727, 25.02890778], [92.41285706, 25.02876472], [92.41259766, 25.02883339], [92.41236115, 25.02889824], [92.41204071, 25.02913475], [92.41118622, 25.02956009], [92.41101837, 25.02971077], [92.41053009, 25.02994156], [92.41028595, 25.03036308], [92.40995026, 25.03060341], [92.40959167, 25.03069878], [92.40905762, 25.03063393], [92.40850067, 25.03064156], [92.40814209, 25.03107452], [92.40782928, 25.03117943], [92.407547, 25.03139687], [92.40717316, 25.03165436], [92.40657806, 25.03197098], [92.40615845, 25.03203011], [92.40542603, 25.03241158], [92.40504456, 25.03274727], [92.4041748, 25.03250885], [92.40394592, 25.03242874], [92.40283203, 25.03203583], [92.40251923, 25.03217125], [92.40241241, 25.03215408], [92.4023056, 25.03213501], [92.40216827, 25.03222466], [92.40225983, 25.03203583], [92.40218353, 25.03193855], [92.40214539, 25.03203583], [92.40190887, 25.03214836], [92.40161896, 25.0322361], [92.40155792, 25.03232765], [92.40111542, 25.0324955], [92.40053558, 25.0329895], [92.40048218, 25.0330925], [92.40065765, 25.03385925], [92.40060425, 25.03399849], [92.40060425, 25.03415489], [92.40039063, 25.03421211], [92.40033722, 25.03414536], [92.3996582, 25.03420067], [92.39936829, 25.03408432], [92.39926147, 25.03403282], [92.39916992, 25.03360176], [92.39912415, 25.0333786], [92.3990097, 25.03338623], [92.39898682, 25.03292847], [92.39872742, 25.03303528], [92.39852905, 25.03311539], [92.39793396, 25.03386879], [92.39709473, 25.0346489], [92.39630127, 25.03509903], [92.39576721, 25.03557205], [92.39461517, 25.03676414], [92.39411163, 25.03730392], [92.39334869, 25.03794098], [92.39304352, 25.0391407], [92.39272308, 25.03990936], [92.39110565, 25.03996468], [92.38921356, 25.03995705], [92.38825226, 25.03985786], [92.38814545, 25.0398674], [92.3881073, 25.03998947], [92.38787079, 25.04009819], [92.38768005, 25.04010201], [92.38639069, 25.04061317], [92.3861084, 25.0405426], [92.38582611, 25.04068184], [92.38549805, 25.04060745], [92.3853302, 25.04066467], [92.38513184, 25.04084778], [92.38483429, 25.04090691], [92.38469696, 25.04099464], [92.38470459, 25.04111862], [92.38481903, 25.04128456], [92.3849411, 25.04158974], [92.3848877, 25.04173851], [92.38481903, 25.04177856], [92.3846817, 25.04183197], [92.38457489, 25.0419445], [92.38456726, 25.04214478], [92.38412476, 25.04221344], [92.38397217, 25.04226303], [92.3838501, 25.04241753], [92.3837204, 25.0424633], [92.38363647, 25.04229546], [92.38356018, 25.04221344], [92.38356018, 25.04196167], [92.38365936, 25.04179382], [92.38388062, 25.04190254], [92.38417053, 25.04152489], [92.38433075, 25.04141045], [92.38458252, 25.04146194], [92.384552, 25.04132271], [92.38442993, 25.04116631], [92.38424683, 25.04088974], [92.38427734, 25.04055595], [92.38425446, 25.04046631], [92.3841095, 25.0403595], [92.38375854, 25.04018211], [92.3837204, 25.04007721], [92.38372803, 25.03973579], [92.38346863, 25.03915215], [92.38336182, 25.03883553], [92.38327026, 25.03873634], [92.38317108, 25.03861809], [92.38302612, 25.03863716], [92.38295746, 25.03892708], [92.38287354, 25.03896713], [92.38273621, 25.03903198], [92.38267517, 25.03930283], [92.38233948, 25.03934288], [92.38280487, 25.04008102], [92.38285828, 25.04034805], [92.38263702, 25.04050636], [92.38250732, 25.04058266], [92.38240814, 25.04057693], [92.38233185, 25.04044342], [92.38225555, 25.04000664], [92.38200378, 25.03985596], [92.38208008, 25.03968048], [92.38202667, 25.03960991], [92.38188171, 25.03941154], [92.38175201, 25.03934479], [92.38167572, 25.0391674], [92.38152313, 25.03918648], [92.38130188, 25.03921127], [92.3812027, 25.03926849], [92.38108826, 25.03943825], [92.381073, 25.03961563], [92.38131714, 25.03994751], [92.38124847, 25.0400753], [92.38118744, 25.04012108], [92.38100433, 25.04019165], [92.3809967, 25.04033279], [92.38106537, 25.04051971], [92.38098145, 25.04055786], [92.38097382, 25.04065514], [92.38072968, 25.04060364], [92.38071442, 25.04077911], [92.38057709, 25.04091835], [92.38061523, 25.04144859], [92.38053894, 25.04152107], [92.38026428, 25.04125977], [92.38013458, 25.0410347], [92.38007355, 25.04092407], [92.38015747, 25.04084587], [92.38085175, 25.04019928], [92.38097382, 25.0400219], [92.38095093, 25.03985977], [92.38084412, 25.03975868], [92.38072968, 25.03964615], [92.38063812, 25.039608], [92.38031769, 25.03962708], [92.37996674, 25.03962898], [92.37942505, 25.0396328], [92.37928772, 25.03967667], [92.37902832, 25.04014778], [92.37887573, 25.04019547], [92.37844086, 25.04030418], [92.37830353, 25.04034996], [92.37807465, 25.04066277], [92.37753296, 25.04102707], [92.37738037, 25.04118538], [92.37742615, 25.04162025], [92.37714386, 25.042099], [92.37690735, 25.04229736], [92.37683105, 25.04246902], [92.37684631, 25.04258537], [92.37695313, 25.04280663], [92.37680054, 25.04293251], [92.37609863, 25.04272652], [92.37585449, 25.04265594], [92.37551117, 25.0427227], [92.37537384, 25.04275322], [92.37498474, 25.0427742], [92.37467957, 25.04257584], [92.37441254, 25.04249573], [92.37412262, 25.04254913], [92.37400818, 25.04261589], [92.37368774, 25.04280281], [92.37377167, 25.04320335], [92.37397766, 25.04339981], [92.37411499, 25.04343414], [92.37419891, 25.04324913], [92.37458801, 25.04312325], [92.37505341, 25.04335022], [92.37502289, 25.04363251], [92.37470245, 25.04371643], [92.37462616, 25.0436039], [92.37441254, 25.04369354], [92.37425232, 25.0436039], [92.37409973, 25.04359436], [92.3735199, 25.0437851], [92.37351227, 25.04366493], [92.37349701, 25.04345512], [92.37319183, 25.04327583], [92.37298584, 25.04302979], [92.37284088, 25.04311371], [92.37281036, 25.04337311], [92.3727417, 25.04350662], [92.37265778, 25.04359436], [92.37252808, 25.04360008], [92.37245178, 25.04350471], [92.37252808, 25.04314423], [92.37255859, 25.04298401], [92.37284088, 25.04266167], [92.3727951, 25.04252052], [92.3724823, 25.04236794], [92.37207794, 25.04238701], [92.37184906, 25.04267883], [92.3716507, 25.0423851], [92.37143707, 25.04231834], [92.37119293, 25.04219246], [92.37103271, 25.04226112], [92.3710022, 25.04239082], [92.37116241, 25.04249763], [92.37108612, 25.0426178], [92.37088013, 25.04252434], [92.37076569, 25.04283905], [92.37065887, 25.04273224], [92.37050629, 25.04210091], [92.37050629, 25.04199982], [92.3707428, 25.0418396], [92.37084961, 25.041605], [92.37062836, 25.04150391], [92.37039948, 25.04161644], [92.37015533, 25.04173088], [92.36981964, 25.04189301], [92.3697052, 25.0417099], [92.36960602, 25.0415535], [92.36958313, 25.04146194], [92.36978912, 25.04133987], [92.3699646, 25.04122543], [92.36977386, 25.04107094], [92.36962128, 25.04100037], [92.3693924, 25.04117966], [92.36902618, 25.04146767], [92.36831665, 25.04202271], [92.36771393, 25.04251289], [92.36816406, 25.04305267], [92.36834717, 25.04319191], [92.36872864, 25.04348183], [92.36888123, 25.04368019], [92.36896515, 25.04387093], [92.36882019, 25.04395676], [92.36894226, 25.04416466], [92.36897278, 25.04427147], [92.368927, 25.04443932], [92.36870575, 25.04474831], [92.36858368, 25.0447731], [92.3684845, 25.0453186], [92.36857605, 25.04559898], [92.3685379, 25.04571724], [92.36824799, 25.04605865], [92.36830902, 25.04634666], [92.36811829, 25.04636383], [92.36794281, 25.04631615], [92.36695862, 25.04733658], [92.36670685, 25.0477562], [92.36657715, 25.04788208], [92.36636353, 25.04803276], [92.36598206, 25.04822731], [92.36565399, 25.04850006], [92.3651123, 25.04867554], [92.36486816, 25.04887772], [92.36481476, 25.04910469], [92.36449432, 25.04916], [92.36437988, 25.04918861], [92.3640213, 25.04937935], [92.36375427, 25.04950142], [92.36357117, 25.04958534], [92.36339569, 25.0496273], [92.36323547, 25.04966736], [92.36316681, 25.04973412], [92.36304474, 25.04995346], [92.36290741, 25.05002213], [92.36260986, 25.04994392], [92.36224365, 25.04994774], [92.36218262, 25.04986763], [92.36211395, 25.04970551], [92.3616333, 25.048666], [92.36167145, 25.04839325], [92.3616333, 25.04813957], [92.36157227, 25.04789162], [92.36148071, 25.04766464], [92.36115265, 25.04706001], [92.36079407, 25.04686928], [92.36064148, 25.046875], [92.36024475, 25.04688835], [92.35999298, 25.04689026], [92.35960388, 25.04711914], [92.35907745, 25.04718208], [92.35869598, 25.04724884], [92.35836792, 25.04735184], [92.35829926, 25.04752159], [92.358284, 25.04792213], [92.35824585, 25.04828072], [92.35813904, 25.04857635], [92.35808563, 25.048666], [92.35786438, 25.04879951], [92.35778809, 25.04889679], [92.35769653, 25.04916191], [92.35766602, 25.04924774], [92.35779572, 25.04939079], [92.35786438, 25.04941559], [92.35790253, 25.04927444], [92.35797882, 25.04924011], [92.35822296, 25.04938126], [92.35832977, 25.04935074], [92.3585434, 25.04929161], [92.35873413, 25.04931831], [92.35873413, 25.0494194], [92.35861206, 25.04995728], [92.35860443, 25.05003548], [92.35807037, 25.05015564], [92.35801697, 25.05025101], [92.35704803, 25.05021858], [92.35692596, 25.0502491], [92.35652924, 25.05013847], [92.35653687, 25.04977608], [92.35654449, 25.04944229], [92.35653687, 25.04925156], [92.35633087, 25.04900551], [92.35623932, 25.04881477], [92.35627747, 25.04856682], [92.35636139, 25.04813957], [92.35639191, 25.04791832], [92.35662079, 25.04790306], [92.35662842, 25.04756546], [92.35617828, 25.04754829], [92.35549927, 25.04757118], [92.35515594, 25.04781151], [92.35513306, 25.04806709], [92.35440826, 25.04789352], [92.35430908, 25.04795456], [92.35417938, 25.0486145], [92.35448456, 25.04917336], [92.35415649, 25.0495739], [92.3538208, 25.04931259], [92.35368347, 25.04920769], [92.35324097, 25.04939079], [92.35292053, 25.04938126], [92.35251617, 25.04932785], [92.35202026, 25.04896164], [92.35172272, 25.04868317], [92.35118866, 25.04852104], [92.35114288, 25.04858208], [92.35109711, 25.0486393], [92.35095978, 25.04855347], [92.35085297, 25.04854012], [92.35070801, 25.0486908], [92.35036469, 25.04868889], [92.35033417, 25.04876137], [92.35041046, 25.0493412], [92.35034943, 25.04956245], [92.35018158, 25.04968643], [92.34990692, 25.04953766], [92.34947968, 25.04950142], [92.34931183, 25.04926682], [92.34922791, 25.04880905], [92.34925842, 25.0486908], [92.34864044, 25.04840469], [92.34853363, 25.04840469], [92.34824371, 25.04840469], [92.34809875, 25.04836273], [92.34798431, 25.04821587], [92.34775543, 25.04791069], [92.34729767, 25.04779625], [92.34645081, 25.04816818], [92.34615326, 25.04870987], [92.34601593, 25.04874039], [92.34597015, 25.0491848], [92.34547424, 25.04916763], [92.34537506, 25.04896164], [92.34528351, 25.04876328], [92.34518433, 25.04881287], [92.34506989, 25.04878044], [92.34492493, 25.04882431], [92.34484863, 25.04880333], [92.34460449, 25.04876518], [92.34442902, 25.04869652], [92.34396362, 25.04865074], [92.34375763, 25.04866791], [92.34368134, 25.04867363], [92.34333801, 25.04877472], [92.3428421, 25.04911232], [92.34267426, 25.04922867], [92.34207153, 25.04896545], [92.34184265, 25.04892159], [92.3418045, 25.04876518], [92.34168243, 25.04866028], [92.34140778, 25.04866409], [92.34137726, 25.04887581], [92.34142303, 25.04894066], [92.34130096, 25.04920578], [92.34124756, 25.04931641], [92.34040833, 25.04967117], [92.3394165, 25.05009842], [92.3392334, 25.05047607], [92.33940125, 25.05062866], [92.33978271, 25.05097961], [92.34022522, 25.05142212], [92.34052277, 25.05187607], [92.34083557, 25.05236244], [92.34114075, 25.05264854], [92.34123993, 25.05285645], [92.3414917, 25.05333519], [92.34181976, 25.05374527], [92.34230042, 25.05434799], [92.34197235, 25.05417824], [92.34159088, 25.05379486], [92.34119415, 25.05308151], [92.34111023, 25.052845], [92.34091949, 25.05259132], [92.34052277, 25.05220604], [92.34025574, 25.05172348], [92.3398819, 25.05130196], [92.33911133, 25.05058289], [92.33895874, 25.0507412], [92.33809662, 25.05163956], [92.33829498, 25.05171585], [92.33846283, 25.05184555], [92.33864594, 25.05204964], [92.33907318, 25.05255127], [92.34016418, 25.05358696], [92.34047699, 25.05379486], [92.3405838, 25.05386543], [92.34094238, 25.05410194], [92.341362, 25.0543499], [92.3421936, 25.05471992], [92.34255981, 25.05485916], [92.34327698, 25.055233], [92.34382629, 25.05545616], [92.34414673, 25.05564499], [92.34436035, 25.05582428], [92.34449768, 25.05645752], [92.3447113, 25.05778503], [92.34553528, 25.05811882], [92.34552765, 25.05831528], [92.34601593, 25.05830956], [92.34651947, 25.05817032], [92.34679413, 25.05809402], [92.34696198, 25.05818939], [92.34736633, 25.05849075], [92.34773254, 25.05888748], [92.34791565, 25.05908585], [92.3483429, 25.05986023], [92.34887695, 25.06097031], [92.34898376, 25.06125641], [92.34902191, 25.06160736], [92.34902954, 25.0620842], [92.34902191, 25.06233788], [92.34899139, 25.06346893], [92.34912109, 25.06399155], [92.34929657, 25.06461143], [92.34931183, 25.06477928], [92.34918213, 25.06517792], [92.34899902, 25.06559181], [92.34883118, 25.06602287], [92.34857941, 25.06645584], [92.348526, 25.06657791], [92.34832764, 25.0670681], [92.34802246, 25.06716537], [92.34777832, 25.06724739], [92.34767914, 25.06826401], [92.34802246, 25.06854248], [92.34841156, 25.06885529], [92.3480072, 25.0695076], [92.34766388, 25.07007027], [92.3477478, 25.07074738], [92.3477478, 25.07134438], [92.34804535, 25.07201195], [92.34822845, 25.0724411], [92.34848022, 25.07277298], [92.34849548, 25.07304001], [92.34841919, 25.0731163], [92.34848022, 25.07363701], [92.34777069, 25.07413292], [92.34721375, 25.07406616], [92.34662628, 25.0739975], [92.34618378, 25.07383347], [92.34547424, 25.07392311], [92.34526062, 25.07405853], [92.34352875, 25.07516479], [92.34204865, 25.07559395], [92.34177399, 25.07561302], [92.34086609, 25.07567787], [92.3406601, 25.07568359], [92.34010315, 25.07569885], [92.338974, 25.07607651], [92.33834076, 25.07583618], [92.33812714, 25.07585716], [92.3380661, 25.07593727], [92.33750153, 25.07665443], [92.33659363, 25.07714081], [92.33618164, 25.07719994], [92.33575439, 25.07726479], [92.33534241, 25.07732391], [92.33446503, 25.07861328], [92.33438873, 25.07846642], [92.33422089, 25.07815933], [92.33388519, 25.07813644], [92.33364868, 25.07812119], [92.33339691, 25.07810402], [92.33330536, 25.07824516], [92.3328476, 25.07900047], [92.3318634, 25.07916451], [92.33176422, 25.07916069], [92.33156586, 25.07915497], [92.33146667, 25.07913399], [92.33119965, 25.07904816], [92.33024597, 25.07906914], [92.33020782, 25.0788765], [92.32956696, 25.07805061], [92.32919312, 25.07780075], [92.32880402, 25.07756996], [92.32805634, 25.07759285], [92.32746887, 25.0778389], [92.32707977, 25.07800293], [92.32681274, 25.07785606], [92.32555389, 25.07822418], [92.32543182, 25.07843971], [92.32454681, 25.07720947], [92.32250214, 25.07442093], [92.31961823, 25.07464027], [92.31951904, 25.07440758], [92.31910706, 25.07439041], [92.31890106, 25.07438278], [92.31886292, 25.07420921], [92.31877899, 25.07382202], [92.31891632, 25.07322693], [92.31871796, 25.07317352], [92.31854248, 25.07312965], [92.31851196, 25.07283211], [92.31877136, 25.07283974], [92.31877899, 25.0726223], [92.31891632, 25.07264328], [92.3190155, 25.07265854], [92.31909943, 25.07261848], [92.31928253, 25.07243347], [92.31904602, 25.07187653], [92.31930542, 25.07139397], [92.31897736, 25.07105446], [92.31898499, 25.07086945], [92.3192215, 25.07044601], [92.31907654, 25.07038879], [92.31902313, 25.07003212], [92.3187561, 25.07004929], [92.318367, 25.07012558], [92.31832123, 25.07005119], [92.31817627, 25.06979942], [92.31807709, 25.06981277], [92.31790924, 25.07008743], [92.31783295, 25.07021332], [92.31764984, 25.07027817], [92.31759644, 25.07063675], [92.31744385, 25.07082748], [92.31735229, 25.07094193], [92.31684113, 25.07068253], [92.31661224, 25.07102776], [92.31656647, 25.07118607], [92.31620789, 25.07142067], [92.31622314, 25.07156563], [92.31614685, 25.07165337], [92.31604004, 25.07167053], [92.31599426, 25.07161331], [92.31594086, 25.07143784], [92.31581116, 25.07138824], [92.31549072, 25.07152176], [92.31495667, 25.07148552], [92.31486511, 25.07147789], [92.31490326, 25.07156944], [92.31477356, 25.07169533], [92.31421661, 25.07207108], [92.31403351, 25.07209396], [92.31368256, 25.07201767], [92.31356812, 25.07199097], [92.3131485, 25.07135963], [92.31269836, 25.07087326], [92.31220245, 25.07044411], [92.31182098, 25.07000732], [92.31185913, 25.06945992], [92.31157684, 25.06932068], [92.31139374, 25.06938362], [92.3111496, 25.06934929], [92.31091309, 25.06937599], [92.31072235, 25.06947708], [92.31064606, 25.06949806], [92.31056976, 25.0694561], [92.31058502, 25.06932259], [92.31059265, 25.06923485], [92.31054688, 25.06916809], [92.31036377, 25.06933403], [92.31032562, 25.06940269], [92.3102951, 25.06954956], [92.31022644, 25.06968689], [92.31015015, 25.06969452], [92.30988312, 25.06970596], [92.30988312, 25.06952286], [92.30970001, 25.06972504], [92.30954742, 25.06969643], [92.30937195, 25.06958199], [92.30927277, 25.06970596], [92.30912018, 25.06989098], [92.30896759, 25.06995964], [92.3088913, 25.06995392], [92.3087616, 25.06974602], [92.30867004, 25.06970787], [92.30857849, 25.0697403], [92.30836487, 25.06991959], [92.30827332, 25.07001114], [92.30774689, 25.07015419], [92.30757141, 25.07013321], [92.30731201, 25.070158], [92.30701447, 25.07022285], [92.30699921, 25.0704422], [92.3068924, 25.07048035], [92.30690765, 25.07058716], [92.30683136, 25.07064819], [92.30671692, 25.07058525], [92.30651855, 25.07050705], [92.30645752, 25.07037926], [92.30619049, 25.07042885], [92.30612946, 25.07053566], [92.30592346, 25.07057953], [92.30579376, 25.07065773], [92.30593109, 25.07090569], [92.30631256, 25.07130432], [92.30638885, 25.07143593], [92.30661011, 25.07146835], [92.30661774, 25.07156181], [92.30661774, 25.07167244], [92.30678558, 25.07164764], [92.30685425, 25.07172966], [92.30639648, 25.07202148], [92.30641174, 25.07209778], [92.30630493, 25.07211494], [92.30619812, 25.0721035], [92.30612183, 25.07205009], [92.30634308, 25.07177162], [92.30638123, 25.07162857], [92.30612183, 25.0714016], [92.30586243, 25.07127571], [92.30548859, 25.07100487], [92.30539703, 25.07097435], [92.30529022, 25.07087135], [92.30499268, 25.07087517], [92.30497742, 25.07061768], [92.30487823, 25.07065392], [92.30445099, 25.07081413], [92.3035965, 25.07108688], [92.30317688, 25.07125092], [92.30271912, 25.07123756], [92.3022995, 25.0712986], [92.30171967, 25.07130241], [92.30059052, 25.0717659], [92.30051422, 25.07195473], [92.30010986, 25.07199478], [92.29988098, 25.07193947], [92.29972839, 25.07190132], [92.29951477, 25.07180214], [92.29925537, 25.07190895], [92.29890442, 25.07198906], [92.29841614, 25.07220459], [92.29823303, 25.07229614], [92.29733276, 25.07274246], [92.29614258, 25.07331276], [92.29561615, 25.07339859], [92.2952652, 25.0734539], [92.29388428, 25.07395554], [92.29221344, 25.07450676], [92.29205322, 25.07455826], [92.29199219, 25.07466507], [92.29187775, 25.07473946], [92.29149628, 25.07485771], [92.29144287, 25.07478523], [92.29101563, 25.07499695], [92.29091644, 25.0751152], [92.29079437, 25.07519913], [92.29039764, 25.07560349], [92.29019928, 25.07564163], [92.28978729, 25.07583427], [92.2896347, 25.07598495], [92.28947449, 25.07595253], [92.28939819, 25.07596779], [92.28905487, 25.07613373], [92.28895569, 25.07612801], [92.28883362, 25.07606697], [92.28878784, 25.07597351], [92.28890228, 25.07572746], [92.28884888, 25.0756321], [92.28876495, 25.07559776], [92.28852081, 25.07593155], [92.28840637, 25.07595062], [92.28824615, 25.07570648], [92.28794861, 25.07575607], [92.28780365, 25.07574654], [92.28768921, 25.07591629], [92.2877121, 25.07600784], [92.28755188, 25.07608986], [92.28765869, 25.07619476], [92.28775024, 25.07668114], [92.28765869, 25.07675934], [92.28744507, 25.07673073], [92.28696442, 25.07695389], [92.28593445, 25.07715797], [92.28523254, 25.07732773], [92.28475189, 25.07701302], [92.2844162, 25.07683945], [92.28429413, 25.07679749], [92.28374481, 25.07662201], [92.28331757, 25.07702255], [92.28252411, 25.07739258], [92.28171539, 25.07765198], [92.28145599, 25.07773781], [92.28022766, 25.07812691], [92.28001404, 25.07819366], [92.2795639, 25.07805634], [92.27922058, 25.07795143], [92.27911377, 25.07791328], [92.27885437, 25.07787132], [92.2786026, 25.07785988], [92.27854156, 25.07795715], [92.27838135, 25.07768822], [92.27819061, 25.07767487], [92.27796936, 25.07810974], [92.27771759, 25.07844925], [92.27771759, 25.07873917], [92.27754974, 25.07896805], [92.27701569, 25.07955742], [92.27692413, 25.07938004], [92.27680969, 25.07893562], [92.2766571, 25.07891273], [92.27646637, 25.07884789], [92.27626801, 25.07897377], [92.27587891, 25.07921791], [92.27576447, 25.0794735], [92.27545929, 25.07933044], [92.27537537, 25.07933998], [92.27516174, 25.07951927], [92.275177, 25.07964134], [92.27519989, 25.07987595], [92.27497864, 25.08004761], [92.27458954, 25.08025551], [92.27436829, 25.0803566], [92.27336884, 25.08081818], [92.27326202, 25.08066368], [92.27310181, 25.08055496], [92.27288055, 25.0807476], [92.27255249, 25.08092117], [92.27246857, 25.08096504], [92.27207184, 25.08099747], [92.27185822, 25.08124924], [92.271492, 25.08101082], [92.27133179, 25.08089066], [92.27098083, 25.0808773], [92.27042389, 25.0811367], [92.27028656, 25.08124352], [92.27013397, 25.08137131], [92.26969147, 25.08175278], [92.26959229, 25.08183289], [92.26906586, 25.08202744], [92.26908112, 25.0825386], [92.26836395, 25.08269501], [92.26805115, 25.08288383], [92.26750946, 25.08302307], [92.26696014, 25.08324814], [92.26667023, 25.08333588], [92.26622009, 25.08343506], [92.26563263, 25.08347511], [92.26527405, 25.08345413], [92.26493835, 25.08337402], [92.26473999, 25.08356476], [92.26409149, 25.08340263], [92.26326752, 25.08361435], [92.26262665, 25.08369064], [92.26152039, 25.08390999], [92.26126099, 25.0839653], [92.26103973, 25.08383751], [92.26082611, 25.08379173], [92.26089478, 25.08400154], [92.26083374, 25.08430099], [92.26041412, 25.08436203], [92.26004028, 25.08434105], [92.25978851, 25.08439636], [92.259552, 25.0845089], [92.25938416, 25.08462715], [92.25917053, 25.0846386], [92.25912476, 25.08456993], [92.25854492, 25.08476448], [92.25827789, 25.08475685], [92.25754547, 25.08519554], [92.25713348, 25.08513832], [92.2565918, 25.08512688], [92.25643158, 25.08515358], [92.25595856, 25.08528709], [92.25549316, 25.08534241], [92.25521851, 25.08537674], [92.25481415, 25.08555412], [92.25478363, 25.08563232], [92.25430298, 25.08686829], [92.25413513, 25.08683586], [92.25396729, 25.08684158], [92.25357056, 25.08685493], [92.25340271, 25.08687782], [92.25281525, 25.08704376], [92.25254059, 25.08730316], [92.25226593, 25.08734894], [92.25206757, 25.08739281], [92.25153351, 25.08750725], [92.25102234, 25.08767128], [92.25029755, 25.08790207], [92.25021362, 25.0879631], [92.24983978, 25.08823395], [92.24914551, 25.08851624], [92.24897003, 25.08860016], [92.24884033, 25.0886116], [92.24872589, 25.08871841], [92.24849701, 25.08883095], [92.24832916, 25.0889492], [92.24812317, 25.08899498], [92.24801636, 25.08908272], [92.24776459, 25.08919716], [92.24743652, 25.08927917], [92.24729919, 25.08923912], [92.24720001, 25.08926392], [92.24705505, 25.08926964], [92.24695587, 25.08938599], [92.24685669, 25.08948326], [92.24668121, 25.08944511], [92.24662781, 25.08960533], [92.24643707, 25.08974075], [92.24636078, 25.08970261], [92.24621582, 25.08974648], [92.24613953, 25.0898838], [92.24597168, 25.08986092], [92.24582672, 25.08988953], [92.24573517, 25.09001923], [92.24559021, 25.09002686], [92.24549103, 25.09010696], [92.24542236, 25.09014702], [92.24533844, 25.09016418], [92.24515533, 25.09022903], [92.24474335, 25.09039879], [92.2438736, 25.09077263], [92.24349976, 25.09104919], [92.24275208, 25.09140587], [92.24268341, 25.09147453], [92.24246979, 25.09157562], [92.24236298, 25.09166908], [92.2421875, 25.09178352], [92.24202728, 25.0918045], [92.24182129, 25.09180069], [92.24156952, 25.09179497], [92.24121857, 25.09189987], [92.24085999, 25.09204674], [92.24061584, 25.09216309], [92.24024963, 25.09233093], [92.23999023, 25.09244919], [92.23937225, 25.09284973], [92.23873138, 25.09324646], [92.23825836, 25.09337044], [92.23789215, 25.09347916], [92.23743439, 25.09396744], [92.23690033, 25.09404755], [92.2365036, 25.09408951], [92.2363739, 25.09414673], [92.23589325, 25.09435654], [92.23496246, 25.09468079], [92.23405457, 25.09477043], [92.23324585, 25.09498024], [92.23259735, 25.09543228], [92.2323761, 25.09558868], [92.23148346, 25.09623337], [92.23149109, 25.09694099], [92.23116302, 25.09713554], [92.2310791, 25.09709358], [92.23059082, 25.09684563], [92.22969055, 25.09607887], [92.22928619, 25.09591675], [92.22834778, 25.09553528], [92.22822571, 25.09493446], [92.22810364, 25.09436607], [92.22812653, 25.0941391], [92.22773743, 25.0936985], [92.2273941, 25.09385681], [92.2271347, 25.09403229], [92.22683716, 25.09423256], [92.22687531, 25.09451675], [92.22645569, 25.09516907], [92.22640991, 25.09568977], [92.22634125, 25.09576797], [92.22564697, 25.09617996], [92.22518921, 25.09649086], [92.22485352, 25.09665108], [92.22453308, 25.0969696], [92.22410583, 25.09716225], [92.22400665, 25.09751892], [92.22370148, 25.0977459], [92.22312927, 25.09817886], [92.22298431, 25.09833717], [92.22292328, 25.09869385], [92.22278595, 25.09915352], [92.22274017, 25.09947014], [92.22270966, 25.09967995], [92.22268677, 25.10012054], [92.22292328, 25.10093307], [92.22309113, 25.10119629], [92.22328949, 25.10149384], [92.22338867, 25.10178757], [92.22341919, 25.10206604], [92.22345734, 25.10254478], [92.22328186, 25.10282516], [92.22325134, 25.10317612], [92.2230072, 25.10339546], [92.22234344, 25.10367966], [92.2220993, 25.10388374], [92.22202301, 25.10395432], [92.22179413, 25.10417747], [92.22125244, 25.10412025], [92.22031403, 25.10438538], [92.21994781, 25.104496], [92.21959686, 25.10454941], [92.21906281, 25.10466576], [92.21883392, 25.10476494], [92.21865082, 25.10486603], [92.21857452, 25.10490799], [92.21820068, 25.10496902], [92.21809387, 25.10499954], [92.21786499, 25.10507011], [92.21749115, 25.10518265], [92.21736908, 25.10524178], [92.21715546, 25.10534668], [92.21649933, 25.10570145], [92.216362, 25.10583687], [92.21577454, 25.10615921], [92.21548462, 25.10620117], [92.21517181, 25.10658646], [92.21432495, 25.10686874], [92.21392059, 25.10703659], [92.21376801, 25.10709953], [92.21279907, 25.10741043], [92.2124939, 25.10750771], [92.21240234, 25.10752106], [92.21157837, 25.10763168], [92.21146393, 25.10770798], [92.21103668, 25.10778236], [92.2105484, 25.10801125], [92.21044159, 25.10806084], [92.21032715, 25.10807991], [92.20986176, 25.10815239], [92.20935059, 25.10825539], [92.20884705, 25.10837555], [92.20872498, 25.10838699], [92.20829773, 25.10852814], [92.20780182, 25.10859489], [92.20741272, 25.10868454], [92.20690918, 25.10877419], [92.20664215, 25.10856628], [92.20637512, 25.1083622], [92.20631409, 25.1083107], [92.20599365, 25.1081543], [92.20558167, 25.10795021], [92.2049408, 25.10790634], [92.2047348, 25.10771751], [92.20385742, 25.10691261], [92.2036972, 25.10677528], [92.20355225, 25.10664749], [92.20344543, 25.1066246], [92.20322418, 25.10657501], [92.20266724, 25.10650444], [92.20258331, 25.10678482], [92.20233154, 25.10695648], [92.20226288, 25.10700417], [92.20207214, 25.10714531], [92.20144653, 25.10754776], [92.20096588, 25.10767937], [92.20045471, 25.10777664], [92.19994354, 25.10783195], [92.19961548, 25.10788345], [92.19934082, 25.10788918], [92.19906616, 25.10794067], [92.19889069, 25.10780716], [92.19865417, 25.10749435], [92.19824982, 25.10749245], [92.19818115, 25.10753632], [92.19785309, 25.1077404], [92.19777679, 25.10774422], [92.19743347, 25.10776711], [92.1973114, 25.10805702], [92.19694519, 25.10808754], [92.19642639, 25.108078], [92.1963501, 25.10809517], [92.1960907, 25.10816574], [92.19635773, 25.10891914], [92.19658661, 25.10956573], [92.19702911, 25.11081314], [92.19718933, 25.11127853], [92.19767761, 25.11265564], [92.19790649, 25.11330032], [92.19812775, 25.11314201], [92.1985321, 25.112854], [92.1982193, 25.11340904], [92.19805145, 25.11370468], [92.19837189, 25.1145916], [92.19867706, 25.11547089], [92.19893646, 25.11621475], [92.19921112, 25.11696815], [92.19966125, 25.11733055], [92.19994354, 25.11736488], [92.20042419, 25.1174221], [92.20050049, 25.1179142], [92.20056915, 25.11836433], [92.2006073, 25.11865425], [92.20061493, 25.11875534], [92.20018768, 25.11877441], [92.19986725, 25.11878777], [92.19996643, 25.11914063], [92.20034027, 25.12011909], [92.2010498, 25.12031746], [92.20186615, 25.12032509], [92.20290375, 25.12015152], [92.20397186, 25.11997223], [92.20513916, 25.11976624], [92.20623016, 25.11957359], [92.20632172, 25.11955833], [92.20722961, 25.11925888], [92.20871735, 25.11878204], [92.20939636, 25.11856079], [92.21022034, 25.11829376], [92.21043396, 25.1182251], [92.21102905, 25.11803818], [92.21174622, 25.11780739], [92.21261597, 25.11752892], [92.21305847, 25.11738586], [92.21377563, 25.11715508], [92.21524811, 25.11668396], [92.21624756, 25.11636353], [92.21736145, 25.11600685], [92.21899414, 25.11548233], [92.21929932, 25.11538887], [92.21961975, 25.11536598], [92.21953583, 25.11610985], [92.2193222, 25.11713219], [92.21871948, 25.11753273], [92.21839142, 25.11796761], [92.21802521, 25.11795425], [92.21775055, 25.11794281], [92.21675873, 25.11869049], [92.21614838, 25.11908531], [92.21511841, 25.11969757], [92.21503448, 25.11975288], [92.21476746, 25.11995888], [92.21417236, 25.12035179], [92.21364594, 25.12067223], [92.21296692, 25.12108994], [92.21100616, 25.12169647], [92.20968628, 25.12211418], [92.20948029, 25.12217331], [92.20921326, 25.1222496], [92.20900726, 25.12249756], [92.20793915, 25.12279892], [92.20768738, 25.12262726], [92.20726013, 25.12282181], [92.20728302, 25.12298393], [92.2067337, 25.12309265], [92.20600891, 25.12346649], [92.20578766, 25.12357903], [92.20549011, 25.12373543], [92.2042923, 25.12390137], [92.20291901, 25.12440491], [92.20224762, 25.12462234], [92.20174408, 25.12478256], [92.20064545, 25.12516403], [92.20050049, 25.12521744], [92.19923401, 25.12564659], [92.1989212, 25.1257534], [92.19515991, 25.12475014], [92.19309998, 25.12288284], [92.19198608, 25.12091827], [92.18754578, 25.12195969], [92.18657684, 25.12277985], [92.18584442, 25.12338257], [92.18558502, 25.12293625], [92.18382263, 25.11819649], [92.18338776, 25.11831284], [92.18263245, 25.11851501], [92.18241119, 25.11860275], [92.18193817, 25.11885834], [92.18151855, 25.11919975], [92.18115234, 25.11992836], [92.18108368, 25.12004471], [92.1810379, 25.12013817], [92.18099976, 25.12020302], [92.18087006, 25.120327], [92.18069458, 25.12058258], [92.1804657, 25.12082481], [92.18042755, 25.12093544], [92.180336, 25.12102318], [92.1802597, 25.12102509], [92.18006134, 25.12133026], [92.18018341, 25.12149048], [92.17996216, 25.12151337], [92.17978668, 25.12149239], [92.17978668, 25.12157249], [92.1796875, 25.12161255], [92.17906189, 25.1218586], [92.17858887, 25.121912], [92.17845154, 25.12197113], [92.17824554, 25.12209702], [92.17745972, 25.12233162], [92.17689514, 25.12269211], [92.17665863, 25.12298203], [92.17810822, 25.1233139], [92.17837524, 25.12345695], [92.17886353, 25.12377357], [92.17892456, 25.12395096], [92.17913818, 25.12403679], [92.17923737, 25.12408829], [92.17932892, 25.12420082], [92.17935944, 25.12429428], [92.17931366, 25.1244278], [92.17916107, 25.12458992], [92.17919922, 25.12474442], [92.17922974, 25.12488556], [92.1791153, 25.12522507], [92.17904663, 25.12566757], [92.17891693, 25.12576103], [92.17879486, 25.12584305], [92.17882538, 25.12592888], [92.17888641, 25.12598419], [92.17896271, 25.12609863], [92.17890167, 25.12638283], [92.17865753, 25.12628555], [92.17842865, 25.12631607], [92.17834473, 25.12631798], [92.1782074, 25.12631035], [92.17796326, 25.12616158], [92.17787933, 25.12605476], [92.1778717, 25.12579346], [92.17774963, 25.12557793], [92.17759705, 25.12525368], [92.17755127, 25.12504768], [92.1776123, 25.12473679], [92.17761993, 25.12460518], [92.17758179, 25.12453651], [92.1774292, 25.12461281], [92.17736053, 25.12470245], [92.17732239, 25.12479782], [92.17734528, 25.12506104], [92.17718506, 25.1250782], [92.17695618, 25.12451172], [92.17684937, 25.12412071], [92.17665863, 25.12399864], [92.17654419, 25.12407303], [92.17645264, 25.12424088], [92.17636871, 25.12436295], [92.1762619, 25.12455368], [92.17625427, 25.12467766], [92.17623138, 25.12485695], [92.17617798, 25.12512589], [92.17614746, 25.12527466], [92.17604828, 25.12553215], [92.17608643, 25.12577248], [92.1761322, 25.1259079], [92.17620087, 25.12603569], [92.17616272, 25.12643433], [92.17554474, 25.12634659], [92.17467499, 25.12667084], [92.17398834, 25.12655258], [92.17378235, 25.12653923], [92.17357635, 25.12652969], [92.17327118, 25.12657738], [92.17259216, 25.12686348], [92.17247772, 25.12690926], [92.17243958, 25.1269722], [92.17240143, 25.12721634], [92.17230988, 25.12724876], [92.17216492, 25.12722588], [92.17201996, 25.12720299], [92.17190552, 25.12718773], [92.1717453, 25.12723732], [92.17164612, 25.12751961], [92.17157745, 25.12767601], [92.1714859, 25.12777519], [92.17134857, 25.12793541], [92.1714325, 25.12804413], [92.17192078, 25.12825966], [92.17195892, 25.12833405], [92.17182922, 25.12849045], [92.17167664, 25.12851143], [92.17157745, 25.12852478], [92.17140198, 25.12852859], [92.1712265, 25.12853432], [92.17110443, 25.12857437], [92.17086029, 25.12870026], [92.17073822, 25.12868881], [92.17049408, 25.12851524], [92.1704483, 25.12843513], [92.17038727, 25.12830925], [92.17034912, 25.12822342], [92.17012787, 25.1280365], [92.17012787, 25.12793541], [92.17011261, 25.12776947], [92.17011261, 25.12765884], [92.16999054, 25.12767029], [92.16986084, 25.12776756], [92.16976166, 25.12796021], [92.16970062, 25.12807846], [92.16954803, 25.12803268], [92.16950989, 25.12792015], [92.16950226, 25.12783051], [92.169487, 25.12768364], [92.16947174, 25.12758255], [92.16941833, 25.1274662], [92.16873932, 25.12695313], [92.16721344, 25.12691879], [92.16644287, 25.12690353], [92.16539001, 25.12645531], [92.16413879, 25.12555313], [92.16383362, 25.12578011], [92.16378784, 25.12584496], [92.16329956, 25.12604523], [92.16259003, 25.12636566], [92.162323, 25.12668991], [92.16140747, 25.12628746], [92.16093445, 25.12652969], [92.1605835, 25.12662315], [92.16035461, 25.12656975], [92.16000366, 25.12655258], [92.15949249, 25.12671089], [92.15920258, 25.1272049], [92.15927887, 25.12766838], [92.15950012, 25.12788963], [92.15981293, 25.12788963], [92.16060638, 25.1280899], [92.16074371, 25.1280632], [92.16086578, 25.12804031], [92.16122437, 25.12808037], [92.16175079, 25.12807083], [92.16247559, 25.12846756], [92.16265869, 25.12853432], [92.16279602, 25.12856674], [92.1630249, 25.12867165], [92.16351318, 25.12907219], [92.16381073, 25.12931252], [92.16401672, 25.12947845], [92.16461182, 25.13017273], [92.16481018, 25.13060379], [92.16478729, 25.13069534], [92.16441345, 25.13067627], [92.1643219, 25.13067055], [92.16402435, 25.13059616], [92.16355896, 25.13047409], [92.16268921, 25.13014603], [92.16217804, 25.13002586], [92.16138458, 25.12971115], [92.16099548, 25.12984467], [92.1608429, 25.12998581], [92.16046143, 25.13000107], [92.16009521, 25.13005066], [92.15976715, 25.13007355], [92.15943146, 25.1301136], [92.15924835, 25.13048363], [92.15911102, 25.13070488], [92.15925598, 25.13101387], [92.15925598, 25.13110924], [92.15911865, 25.13173866], [92.15899658, 25.13193512], [92.15895081, 25.13200569], [92.15891266, 25.13208771], [92.15886688, 25.13220978], [92.15884399, 25.13229179], [92.15883636, 25.13238335], [92.15877533, 25.13289261], [92.15874481, 25.13310814], [92.15904999, 25.13315392], [92.16036224, 25.13356209], [92.16046143, 25.13365936], [92.16108704, 25.13362312], [92.16190338, 25.1335659], [92.16216278, 25.13354492], [92.16268158, 25.13350296], [92.16291809, 25.13358116], [92.16322327, 25.13407898], [92.16324615, 25.1342659], [92.16329193, 25.13458061], [92.1635437, 25.13464165], [92.16436005, 25.134758], [92.16481018, 25.1348114], [92.16518402, 25.13495636], [92.16567993, 25.13512993], [92.1656723, 25.13582993], [92.16566467, 25.13602066], [92.16539001, 25.13609695], [92.16494751, 25.13605118], [92.16436768, 25.13599014], [92.16409302, 25.13600159], [92.16394043, 25.13605309], [92.16371155, 25.13617897], [92.16352844, 25.13625526], [92.1632843, 25.13635826], [92.16298676, 25.13614655], [92.16287231, 25.13618469], [92.16260529, 25.13634491], [92.16242218, 25.13629341], [92.16213226, 25.13616562], [92.16184998, 25.13598061], [92.16179657, 25.13527107], [92.16146851, 25.13501167], [92.16120148, 25.13515854], [92.16081238, 25.13518333], [92.16054535, 25.13515663], [92.16013336, 25.13496208], [92.16013336, 25.13471985], [92.15987396, 25.13430977], [92.15968323, 25.13416862], [92.15934753, 25.13418579], [92.15903473, 25.13406372], [92.15879059, 25.13399696], [92.15820312, 25.13382721], [92.15791321, 25.13363266], [92.15765381, 25.13350105], [92.15749359, 25.13334846], [92.15727997, 25.1333847], [92.15692139, 25.13336372], [92.15577698, 25.13334084], [92.15546417, 25.13334846], [92.15499878, 25.13342094], [92.15431213, 25.13352966], [92.15418243, 25.13368607], [92.1541748, 25.13385963], [92.1539917, 25.13390541], [92.15390778, 25.13383675], [92.15371704, 25.13365173], [92.15306854, 25.13374901], [92.15262604, 25.13381767], [92.15274811, 25.13448524], [92.15293121, 25.13543701], [92.15309143, 25.13633728], [92.15248871, 25.13728905], [92.1521225, 25.13772774], [92.15112305, 25.1381855], [92.15076447, 25.13835335], [92.14978027, 25.13782501], [92.14900208, 25.13741112], [92.14820862, 25.13659286], [92.14775848, 25.13585091], [92.14743805, 25.13578796], [92.14737701, 25.13565063], [92.14732361, 25.13540268], [92.14717102, 25.13541794], [92.14665985, 25.13558197], [92.1461792, 25.13570023], [92.14564514, 25.13569641], [92.14452362, 25.13588333], [92.14310455, 25.1358757], [92.14238739, 25.13606071], [92.14196014, 25.13616943], [92.14173126, 25.13635254], [92.14162445, 25.13647461], [92.14154816, 25.13661766], [92.14163971, 25.13684654], [92.14173126, 25.13696289], [92.1420517, 25.1373024], [92.14212036, 25.13743973], [92.14209747, 25.13752174], [92.1420517, 25.1376667], [92.14186859, 25.13771057], [92.14160919, 25.13768196], [92.14146423, 25.13759232], [92.14122772, 25.13742638], [92.14102173, 25.13754654], [92.14076996, 25.13769722], [92.14054871, 25.13783836], [92.14009857, 25.13805962], [92.13981628, 25.13812637], [92.13889313, 25.1382637], [92.13834381, 25.13829613], [92.13816833, 25.13830757], [92.13795471, 25.13822556], [92.1378479, 25.13818359], [92.13722992, 25.13843536], [92.13669586, 25.1386261], [92.13660431, 25.13862991], [92.13650513, 25.13860893], [92.13640594, 25.13866615], [92.13637543, 25.13851357], [92.13576508, 25.13885498], [92.13578033, 25.13910294], [92.13582611, 25.13964653], [92.13607788, 25.13983536], [92.13637543, 25.13990784], [92.13728333, 25.14010048], [92.13806152, 25.14019966], [92.13841248, 25.14013672], [92.13848877, 25.14023209], [92.13838959, 25.14052963], [92.13847351, 25.14056969], [92.13900757, 25.14066315], [92.13930511, 25.14047623], [92.13937378, 25.14076233], [92.1394577, 25.14107323], [92.14000702, 25.14073944], [92.14013672, 25.14050484], [92.13972473, 25.14020157], [92.13944244, 25.14012718], [92.13946533, 25.13997841], [92.14029694, 25.14020348], [92.14044952, 25.14024353], [92.14064026, 25.14020348], [92.1408844, 25.1402626], [92.14096069, 25.14027977], [92.14105225, 25.14003563], [92.14112854, 25.1399231], [92.14118958, 25.13978386], [92.14144135, 25.13986206], [92.14131927, 25.14024162], [92.14128876, 25.1403389], [92.14179993, 25.14059639], [92.14186096, 25.14025879], [92.1419754, 25.14008141], [92.14225769, 25.14008331], [92.14233398, 25.14008331], [92.14253998, 25.13983345], [92.14261627, 25.13977623], [92.14287567, 25.13992882], [92.14375305, 25.1395607], [92.14393616, 25.13947868], [92.144104, 25.13956833], [92.14450073, 25.13978767], [92.14438629, 25.14002228], [92.14411163, 25.14000702], [92.1437912, 25.13983345], [92.14324951, 25.14011002], [92.14278412, 25.14040375], [92.14208984, 25.14085388], [92.14186859, 25.14101601], [92.14161682, 25.14112854], [92.14151001, 25.14117622], [92.14125061, 25.14088821], [92.14085388, 25.14106178], [92.14070129, 25.14112854], [92.14031219, 25.14149857], [92.14025116, 25.14155769], [92.14012146, 25.14168167], [92.13980865, 25.1415329], [92.13950348, 25.14139175], [92.13812256, 25.14154625], [92.13802338, 25.14143181], [92.13754272, 25.14153481], [92.13697052, 25.14152908], [92.13678741, 25.14162064], [92.13631439, 25.14188194], [92.13504791, 25.14216805], [92.13461304, 25.1426239], [92.13446808, 25.14274979], [92.13430023, 25.14296913], [92.13414764, 25.14372253], [92.13443756, 25.14462852], [92.134758, 25.14467049], [92.13509369, 25.14574432], [92.13478088, 25.14723206], [92.13456726, 25.14738083], [92.13415527, 25.14804649], [92.13380432, 25.14846802], [92.13420105, 25.14904594], [92.1341629, 25.14952278], [92.13466644, 25.14977455], [92.13580322, 25.15151978], [92.13574982, 25.15190887], [92.13524628, 25.15224838], [92.13412476, 25.1525898], [92.13409424, 25.15329552], [92.1348877, 25.15328407], [92.13588715, 25.15268898], [92.13613892, 25.15254402], [92.1367569, 25.15232849], [92.13794708, 25.15189362], [92.13828278, 25.15220451], [92.13842773, 25.15234756], [92.13902283, 25.15367508], [92.13915253, 25.15398788], [92.13959503, 25.15473557], [92.13906097, 25.15530777], [92.13867188, 25.15499878], [92.13840485, 25.15505219], [92.13800812, 25.15519333], [92.13721466, 25.15544891], [92.13668823, 25.15537453], [92.13616943, 25.15529823], [92.13594818, 25.15533066], [92.13568878, 25.15540314], [92.13398743, 25.15612793], [92.13359833, 25.15646172], [92.133461, 25.15650177], [92.13272858, 25.15645599], [92.13262939, 25.15660095], [92.13196564, 25.15756416], [92.13233948, 25.1587429], [92.13259888, 25.1595459], [92.13278961, 25.16014481], [92.13283539, 25.16027069], [92.13172913, 25.16014481], [92.130867, 25.16004944], [92.13077545, 25.16003799], [92.13017273, 25.16120911], [92.12953949, 25.16150856], [92.12903595, 25.16174316], [92.128479, 25.16200638], [92.1272583, 25.16183472], [92.12578583, 25.16223526], [92.12479401, 25.16250038], [92.12340546, 25.16295052], [92.12243652, 25.16326523], [92.12130737, 25.16361809], [92.1210556, 25.1636982], [92.1198349, 25.16449928], [92.11975098, 25.16460037], [92.11880493, 25.16570473], [92.11806488, 25.16656113], [92.11768341, 25.16674614], [92.11753845, 25.16681671], [92.11735535, 25.16690826], [92.11707306, 25.16704941], [92.11371613, 25.16870308], [92.11329651, 25.16890907], [92.11296844, 25.16902924], [92.11185455, 25.16942406], [92.10944366, 25.17027855], [92.10894012, 25.17045784], [92.10839844, 25.17138672], [92.10777283, 25.17245865], [92.10762024, 25.17272949], [92.10700226, 25.17272186], [92.10562134, 25.17271042], [92.10547638, 25.17271042], [92.10514832, 25.17270851], [92.10472107, 25.17380142], [92.10435486, 25.17474937], [92.10373688, 25.17487907], [92.1026535, 25.17510223], [92.10179138, 25.17528152], [92.10093689, 25.17545891], [92.09999847, 25.17565346], [92.09947205, 25.17575836], [92.09871674, 25.17591476], [92.09746552, 25.17653084], [92.09516144, 25.17765427], [92.09506226, 25.17769814], [92.09428406, 25.17807579], [92.0921936, 25.1776619], [92.09038544, 25.17847061], [92.08955383, 25.17884445], [92.0890274, 25.17907906], [92.08805847, 25.17951393], [92.0875473, 25.17974091], [92.08673859, 25.18023491], [92.08627319, 25.1805191], [92.08496857, 25.18131256], [92.08426666, 25.18173599], [92.08383942, 25.18198967], [92.0831604, 25.18240356], [92.08205414, 25.18257713], [92.08112335, 25.182724], [92.08097839, 25.18274498], [92.08053589, 25.18240738], [92.07952118, 25.18163681], [92.0789032, 25.18117142], [92.07875061, 25.18105316], [92.076828, 25.18261909], [92.07489014, 25.18416977], [92.07427979, 25.18465614], [92.07376099, 25.18505859], [92.07141113, 25.18514442], [92.07086182, 25.18516159], [92.06817627, 25.18524933], [92.06768799, 25.18526459], [92.06708527, 25.18528366], [92.06653595, 25.18549538], [92.06636047, 25.18555832], [92.06496429, 25.18604851], [92.06426239, 25.18629265], [92.06282806, 25.1867981], [92.0622406, 25.18698883], [92.06183624, 25.18711853], [92.06049347, 25.18655014], [92.05973816, 25.18621635], [92.05935669, 25.18604279], [92.05884552, 25.185812], [92.05846405, 25.18564224], [92.05836487, 25.18576813], [92.0582962, 25.18585968], [92.05821991, 25.18595886], [92.05792999, 25.18639565], [92.05776215, 25.18652153], [92.05756378, 25.1866684], [92.05742645, 25.18674278], [92.05721283, 25.18672562], [92.05700684, 25.1866951], [92.05680084, 25.18650246], [92.056427, 25.18596649], [92.0561676, 25.18575859], [92.0561142, 25.18570518], [92.05593109, 25.18553925], [92.05590057, 25.18540955], [92.05584717, 25.1853447], [92.05571747, 25.18523026], [92.05545044, 25.18443108], [92.05538177, 25.18439865], [92.05513763, 25.18440437], [92.05492401, 25.1844883], [92.05418396, 25.18489647], [92.0539093, 25.18514442], [92.05381012, 25.18530846], [92.05383301, 25.18537903], [92.05392456, 25.1855278], [92.05409241, 25.18582153], [92.05416107, 25.18599892], [92.05432892, 25.18635559], [92.05410767, 25.18658066], [92.05400848, 25.18652534], [92.05391693, 25.18647957], [92.05378723, 25.1864109], [92.05361176, 25.18638802], [92.05343628, 25.18636513], [92.0530014, 25.1864624], [92.05251312, 25.18665314], [92.05212402, 25.18678474], [92.05184174, 25.18679237], [92.05160522, 25.1867485], [92.05150604, 25.18672943], [92.05130005, 25.18675804], [92.05113983, 25.18681908], [92.0508728, 25.18692589], [92.05066681, 25.18692589], [92.0506134, 25.18679237], [92.05046844, 25.18642426], [92.05021667, 25.18670082], [92.04982758, 25.18675232], [92.04961395, 25.18688011], [92.04949951, 25.18694878], [92.04930115, 25.18707275], [92.04883575, 25.18679047], [92.04862213, 25.18657875], [92.04855347, 25.18651581], [92.04827881, 25.1863575], [92.04781342, 25.18637276], [92.04740906, 25.18647385], [92.04697418, 25.18651581], [92.04660034, 25.18639755], [92.04647064, 25.18640518], [92.04601288, 25.18645668], [92.04595184, 25.18650246], [92.04582977, 25.18659401], [92.04558563, 25.18645668], [92.04551697, 25.18641853], [92.0453186, 25.18636894], [92.04505157, 25.18623734], [92.04489899, 25.18619919], [92.04460144, 25.18629265], [92.04451752, 25.18630791], [92.04429626, 25.18634415], [92.04341888, 25.18622017], [92.04317474, 25.18631363], [92.04055023, 25.18580055], [92.04016113, 25.18570709], [92.04004669, 25.1853714], [92.04006958, 25.18505096], [92.03983307, 25.18481445], [92.03955841, 25.1847229], [92.03938293, 25.1846962], [92.03922272, 25.18472481], [92.03903961, 25.18446922], [92.03890991, 25.18407822], [92.03887939, 25.18380356], [92.0389328, 25.18358994], [92.03901672, 25.18333054], [92.03903961, 25.18325043], [92.03902435, 25.18299866], [92.03900909, 25.18283653], [92.03900146, 25.18272972], [92.03898621, 25.18258667], [92.03890228, 25.18242073], [92.03866577, 25.18240929], [92.03839874, 25.18239594], [92.03817749, 25.18235588], [92.03783417, 25.18224525], [92.03726196, 25.18209076], [92.03701782, 25.18218231], [92.03691101, 25.18221855], [92.03640747, 25.18234253], [92.03585815, 25.18266869], [92.03540039, 25.18298531], [92.03504181, 25.1832428], [92.0341568, 25.1834774], [92.03411865, 25.18429565], [92.03392792, 25.18439293], [92.03366089, 25.18431091], [92.03355408, 25.18402672], [92.03348541, 25.18392372], [92.03339386, 25.18386078], [92.03323364, 25.18382072], [92.03330231, 25.18373299], [92.03336334, 25.18367767], [92.03340912, 25.18359756], [92.03336334, 25.18353844], [92.03327179, 25.18348503], [92.0331192, 25.18352127], [92.03296661, 25.18355942], [92.03265381, 25.18358612], [92.03213501, 25.18358803], [92.03149414, 25.18370819], [92.02988434, 25.18323326], [92.02845764, 25.18359947], [92.02820587, 25.18353271], [92.0279541, 25.18360138], [92.02783203, 25.18353653], [92.02772522, 25.18324852], [92.02766418, 25.1830368], [92.02764893, 25.18278122], [92.02766418, 25.18192863], [92.02761841, 25.18177032], [92.02742767, 25.18139458], [92.02722168, 25.18112755], [92.02687836, 25.18085289], [92.02651978, 25.18061638], [92.02623749, 25.1803627], [92.02616119, 25.18004608], [92.02613831, 25.17964172], [92.02610779, 25.17930603], [92.02598572, 25.1793251], [92.02536774, 25.17960548], [92.02452087, 25.17999458], [92.02348328, 25.18047333], [92.02217102, 25.18107605], [92.02084351, 25.18168449], [92.02030945, 25.18192863], [92.01984406, 25.18214226], [92.01835632, 25.18282509], [92.01805878, 25.1832428], [92.01774597, 25.18450546], [92.01746368, 25.18561172], [92.01702881, 25.18618584], [92.01691437, 25.18622398], [92.01205444, 25.18662453], [92.01180267, 25.18664551], [92.01109314, 25.18654633], [92.00933075, 25.18629646], [92.00913239, 25.18630981], [92.00823975, 25.18637657], [92.00717926, 25.18640327], [92.00640869, 25.18638992], [92.00485992, 25.18636131], [92.00461578, 25.1863575], [92.00341797, 25.18624115], [92.00291443, 25.18609238], [92.00246429, 25.18595886], [91.99970245, 25.18362999], [91.99582672, 25.17959023], [91.99221039, 25.17698288], [91.98925781, 25.17578316], [91.98795319, 25.17456818], [91.98699951, 25.17397499], [91.98532104, 25.17288399], [91.9849472, 25.1727829], [91.98439789, 25.17253494], [91.9838028, 25.17228317], [91.98352051, 25.17216301], [91.98329926, 25.17206383], [91.98286438, 25.17201042], [91.98225403, 25.17198181], [91.98123932, 25.17185211], [91.9805069, 25.17178917], [91.97956085, 25.17188454], [91.97891998, 25.17201233], [91.97859192, 25.17212868], [91.97826385, 25.17230034], [91.97789764, 25.17261887], [91.97682953, 25.17337418], [91.97637939, 25.17360115], [91.97601318, 25.17374802], [91.97535706, 25.1739521], [91.97449493, 25.17416763], [91.97338867, 25.17467499], [91.97232056, 25.17504501], [91.97197723, 25.17525101], [91.97172546, 25.17536926], [91.97136688, 25.17547989], [91.97094727, 25.17562294], [91.97009277, 25.17594528], [91.96954346, 25.1759491], [91.96911621, 25.17599297], [91.96875763, 25.17605591], [91.96733856, 25.1762867], [91.96696472, 25.17643738], [91.96673584, 25.17650223], [91.96651459, 25.17654419], [91.96601868, 25.17655182], [91.96435547, 25.17637825], [91.96295929, 25.17638206], [91.9626236, 25.1764679], [91.96203613, 25.17665482], [91.96004486, 25.17704773], [91.95853424, 25.17740631], [91.95803833, 25.17746162], [91.95731354, 25.17760658], [91.95545959, 25.17772675], [91.95314789, 25.17773247], [91.95200348, 25.17769432], [91.9499054, 25.17747879], [91.94855499, 25.17738533], [91.94705963, 25.17720413], [91.94596863, 25.17777634], [91.94572449, 25.17761993], [91.94536591, 25.17777443], [91.9451828, 25.17785263], [91.94457245, 25.17797852], [91.94387054, 25.17799759], [91.94360352, 25.17796898], [91.94255066, 25.17802429], [91.94200897, 25.17811394], [91.94155121, 25.17817879], [91.94054413, 25.17825699], [91.93780518, 25.17866707], [91.93743896, 25.17870712], [91.93650818, 25.17862892], [91.93561554, 25.17849541], [91.93530273, 25.17839241], [91.93476868, 25.17825127], [91.93451691, 25.17819977], [91.93434906, 25.17819977], [91.93425751, 25.17819786], [91.93395996, 25.17844582], [91.93352509, 25.17930984], [91.93345642, 25.1794281], [91.93281555, 25.18056107], [91.93247986, 25.18045998], [91.93157959, 25.18089867], [91.93093872, 25.18121147], [91.93060303, 25.18027878], [91.92928314, 25.18025017], [91.92777252, 25.18021202], [91.92731476, 25.18015671], [91.92661285, 25.18011093], [91.92591858, 25.18006516], [91.92520905, 25.18027115], [91.92436218, 25.18048668], [91.92333984, 25.18058968], [91.9223175, 25.18069267], [91.92172241, 25.18118477], [91.92070007, 25.18134499], [91.91934204, 25.18117905], [91.91833496, 25.18116379], [91.91732788, 25.18115044], [91.91616058, 25.18148041], [91.91537476, 25.18135834], [91.91452026, 25.18142891], [91.91310883, 25.18125725], [91.9118576, 25.18083572], [91.91124725, 25.18061638], [91.91083527, 25.18050575], [91.91043091, 25.1803875], [91.90984344, 25.18022728], [91.90917206, 25.18004036], [91.90812683, 25.17968941], [91.90734863, 25.17944145], [91.90682983, 25.17952347], [91.90583038, 25.17966461], [91.90493011, 25.1797905], [91.90460205, 25.17984009], [91.90399933, 25.17992973], [91.90305328, 25.17998505], [91.9019165, 25.18004608], [91.90097809, 25.18008614], [91.90003967, 25.18013191], [91.89925385, 25.18016815], [91.8984375, 25.18020248], [91.89759827, 25.1795311], [91.89741516, 25.17938042], [91.89735413, 25.17875099], [91.89730072, 25.17819214], [91.89555359, 25.1783371], [91.89459229, 25.17842102], [91.89422607, 25.17845154], [91.89382172, 25.17848778], [91.89426422, 25.17733383], [91.89451599, 25.1766758], [91.89463043, 25.17637253], [91.89349365, 25.17622948], [91.89282227, 25.17613983], [91.89225006, 25.17606163], [91.89092255, 25.17618179], [91.88956451, 25.17629051], [91.88821411, 25.1764164], [91.88732147, 25.17663956], [91.88468933, 25.17715836], [91.88442993, 25.17720795], [91.88302612, 25.17610741], [91.8824234, 25.17559624], [91.88183594, 25.17510223], [91.88152313, 25.17459488], [91.8812027, 25.17407227], [91.88082123, 25.17344475], [91.88056183, 25.17302895], [91.87944794, 25.17346764], [91.87825012, 25.17393875], [91.87767029, 25.17440414], [91.87709808, 25.17486], [91.87606812, 25.1756897], [91.87599182, 25.17647934], [91.87588501, 25.17754555], [91.87541199, 25.17725563], [91.87407684, 25.17644119], [91.8735733, 25.1761322], [91.87284088, 25.17567825], [91.87147522, 25.17482376], [91.87081909, 25.17442131], [91.87042999, 25.17447853], [91.87000275, 25.17454147], [91.8685379, 25.17477417], [91.86801147, 25.17485619], [91.86711884, 25.17501068], [91.86638641, 25.17512703], [91.86516571, 25.17531204], [91.86450195, 25.17539978], [91.86431122, 25.17542458], [91.86308289, 25.17420959], [91.86227417, 25.17342567], [91.86196899, 25.17312813], [91.86142731, 25.17259407], [91.86096954, 25.17268372], [91.86049652, 25.17277527], [91.85947418, 25.17298317], [91.85849762, 25.17316246], [91.8582077, 25.17311668], [91.85791016, 25.17306709], [91.85774231, 25.17304993], [91.8572464, 25.17299652], [91.85683441, 25.17290878], [91.85642242, 25.17282295], [91.85551453, 25.17262077], [91.85507965, 25.17266655], [91.85443878, 25.17274475], [91.85263062, 25.17319298], [91.85131073, 25.17348099], [91.85050201, 25.1734066], [91.84973145, 25.17333603], [91.84880066, 25.17362404], [91.84792328, 25.17389679], [91.84638977, 25.1743927], [91.84487152, 25.17487907], [91.8445282, 25.17498779], [91.84405518, 25.17544937], [91.84365082, 25.17584991], [91.84309387, 25.17640114], [91.84207153, 25.176651], [91.84158325, 25.17676926], [91.84120178, 25.17687035], [91.84069824, 25.17705154], [91.83956146, 25.1770134], [91.83879852, 25.17719078], [91.83785248, 25.17731667], [91.83686829, 25.17746353], [91.83608246, 25.17746925], [91.835289, 25.17747307], [91.8347702, 25.17759514], [91.83418274, 25.17773247], [91.83339691, 25.17790794], [91.83256531, 25.17813301], [91.83244324, 25.17799759], [91.8323288, 25.17798233], [91.8322525, 25.17793655], [91.8320694, 25.17792511], [91.83206177, 25.17774391], [91.83205414, 25.17747307], [91.83203888, 25.17736053], [91.83189392, 25.17737389], [91.83180237, 25.1775856], [91.83174133, 25.17776871], [91.83165741, 25.17791557], [91.83154297, 25.1779232], [91.83148193, 25.17780113], [91.83146667, 25.17772293], [91.83146667, 25.17764282], [91.83151245, 25.17739487], [91.83153534, 25.1773243], [91.83157349, 25.17724609], [91.83157349, 25.17713547], [91.83144379, 25.17714691], [91.83136749, 25.17725563], [91.83126068, 25.17741203], [91.83118439, 25.17747307], [91.83107758, 25.17753601], [91.8306427, 25.17754745], [91.83053589, 25.17738342], [91.83043671, 25.177248], [91.8303833, 25.17703247], [91.83018494, 25.17711067], [91.83013153, 25.17725372], [91.83009338, 25.17736626], [91.82989502, 25.17743683], [91.82983398, 25.17755127], [91.82967377, 25.1775856], [91.82962036, 25.1775341], [91.82946014, 25.17745781], [91.82935333, 25.17733383], [91.82923126, 25.17749214], [91.82909393, 25.17750931], [91.82899475, 25.17752266], [91.82894897, 25.17786789], [91.82886505, 25.17793465], [91.82879639, 25.17788506], [91.82876587, 25.17780495], [91.82872009, 25.1776123], [91.82855225, 25.17771721], [91.82847595, 25.17779732], [91.82842255, 25.17787361], [91.82830811, 25.17790604], [91.82819366, 25.17785072], [91.82807159, 25.17766571], [91.82788086, 25.17770958], [91.82780457, 25.1777668], [91.82769775, 25.17785454], [91.82761383, 25.17789268], [91.8274765, 25.17793846], [91.82733917, 25.17794037], [91.82726288, 25.17794037], [91.8271637, 25.17794991], [91.82698822, 25.17792702], [91.82646942, 25.17778015], [91.82649231, 25.17768669], [91.82652283, 25.17759323], [91.82658386, 25.17705917], [91.82658386, 25.17692757], [91.82653809, 25.17650223], [91.82652283, 25.17633057], [91.82598114, 25.17631149], [91.82543945, 25.17625999], [91.8250885, 25.17618942], [91.82453918, 25.1764164], [91.82369232, 25.17673683], [91.82318115, 25.17641068], [91.82228088, 25.1762104], [91.8221283, 25.176054], [91.82202148, 25.17584801], [91.82191467, 25.17563629], [91.82152557, 25.17521858], [91.82058716, 25.17453003], [91.81984711, 25.17387009], [91.81976318, 25.1737957], [91.81904602, 25.17319489], [91.81859589, 25.1729126], [91.81841278, 25.17279434], [91.81813812, 25.17248917], [91.81800079, 25.17220497], [91.81758881, 25.17133141], [91.81687164, 25.17130661], [91.81639862, 25.17136574], [91.81607056, 25.171381], [91.81554413, 25.1714077], [91.81492615, 25.17143822], [91.81429291, 25.17146301], [91.81385803, 25.17147255], [91.81349182, 25.17148972], [91.81295013, 25.17149353], [91.81245422, 25.1715126], [91.81171417, 25.17154121], [91.81124115, 25.17156029], [91.81080627, 25.17156982], [91.81034851, 25.17158508], [91.80974579, 25.17161369], [91.80930328, 25.17160606], [91.80860901, 25.1715889], [91.80819702, 25.17159081], [91.80783844, 25.17162514], [91.80735016, 25.17165184], [91.80697632, 25.17166138], [91.80661774, 25.17167854], [91.80590057, 25.17170715], [91.80529022, 25.17173386], [91.80480957, 25.17171669], [91.80477142, 25.17181396], [91.80442047, 25.1718502], [91.8041153, 25.17188263], [91.80393982, 25.17185211], [91.80386353, 25.17140388], [91.80368042, 25.17096329], [91.80352783, 25.17068481], [91.80355072, 25.17056847], [91.80376434, 25.17031479], [91.80410004, 25.17019653], [91.80432129, 25.17020226], [91.80447388, 25.17015457], [91.80461884, 25.16988564], [91.80535889, 25.16957283], [91.80544281, 25.16986084], [91.80545807, 25.17005157], [91.80550385, 25.17020226], [91.80561829, 25.17035103], [91.80596924, 25.17036057], [91.80627441, 25.1702652], [91.80696869, 25.16985512], [91.80695343, 25.16953659], [91.80679321, 25.1691494], [91.80667114, 25.16887093], [91.80661774, 25.16872025], [91.80656433, 25.16854858], [91.80643463, 25.16836357], [91.80627441, 25.16831398], [91.8052063, 25.16807175], [91.80513, 25.16817856], [91.80403137, 25.16823006], [91.80266571, 25.16834259], [91.8017807, 25.16823578], [91.80037689, 25.1681881], [91.800354, 25.16829491], [91.79998779, 25.16848373], [91.79965973, 25.16857338], [91.79885864, 25.16870117], [91.79878998, 25.16851044], [91.7978363, 25.16872787], [91.7973175, 25.16884613], [91.79718018, 25.16891861], [91.7970047, 25.1688118], [91.79679871, 25.16869736], [91.79668427, 25.1686554], [91.79655457, 25.16859627], [91.79632568, 25.16856575], [91.79611206, 25.16851425], [91.79594421, 25.1684227], [91.79576111, 25.16833305], [91.7951889, 25.16814232], [91.79484558, 25.16809082], [91.79415894, 25.1680336], [91.79349518, 25.16804314], [91.79335785, 25.16803551], [91.79292297, 25.16801834], [91.79281616, 25.16800308], [91.7927475, 25.1679554], [91.7926178, 25.16784286], [91.79257202, 25.16777611], [91.79241943, 25.16765213], [91.79219055, 25.16769028], [91.79209137, 25.16777992], [91.79176331, 25.1678009], [91.79151917, 25.16781044], [91.79138184, 25.16778946], [91.79110718, 25.16777039], [91.79075623, 25.16770744], [91.79061127, 25.16766548], [91.79037476, 25.16769981], [91.79029846, 25.16767883], [91.7902298, 25.16763115], [91.79008484, 25.16751862], [91.78990173, 25.1674881], [91.78983307, 25.16753578], [91.78973389, 25.16756058], [91.78960419, 25.16755867], [91.78946686, 25.1675663], [91.78913116, 25.16755295], [91.7884903, 25.16751671], [91.78825378, 25.16752434], [91.78788757, 25.1674614], [91.78742218, 25.16724014], [91.78707886, 25.1670742], [91.78603363, 25.16701889], [91.78497314, 25.1669426], [91.78418732, 25.16685104], [91.78360748, 25.16676521], [91.78281403, 25.16656876], [91.78194427, 25.16637802], [91.7809906, 25.16618347], [91.78026581, 25.1660347], [91.77945709, 25.16545486], [91.77939606, 25.16540718], [91.77874756, 25.16491508], [91.7774353, 25.16429329], [91.77663422, 25.16383362], [91.77573395, 25.16332245], [91.77446747, 25.16328049], [91.77416992, 25.16336632], [91.77400208, 25.16344261], [91.77389526, 25.16351318], [91.77332306, 25.16392708], [91.77321625, 25.16402245], [91.7729187, 25.16433907], [91.77216339, 25.1651783], [91.77204132, 25.16536331], [91.77191925, 25.16553688], [91.77173615, 25.16541481], [91.77174377, 25.16526031], [91.77160645, 25.16521645], [91.77153015, 25.1651516], [91.77144623, 25.16513062], [91.7713623, 25.16513443], [91.77122498, 25.16535759], [91.77115631, 25.16521645], [91.77085876, 25.16540146], [91.77067566, 25.1654911], [91.77022552, 25.16563034], [91.76982117, 25.16584015], [91.7697525, 25.16590118], [91.76940155, 25.16617966], [91.76889038, 25.16606522], [91.76863098, 25.16626167], [91.76820374, 25.16635513], [91.76792145, 25.16637802], [91.76778412, 25.166399], [91.76735687, 25.16640091], [91.76712799, 25.16643143], [91.76659393, 25.16697311], [91.76629639, 25.16728973], [91.76622772, 25.16736221], [91.76623535, 25.16761971], [91.76499939, 25.16754532], [91.7639389, 25.16734695], [91.76344299, 25.1664257], [91.76208496, 25.16727066], [91.76132965, 25.16748619], [91.7611084, 25.16754913], [91.76097107, 25.16759109], [91.76056671, 25.16769981], [91.76025391, 25.16779327], [91.7598114, 25.16793823], [91.75982666, 25.16827011], [91.75944519, 25.16835213], [91.75891876, 25.168396], [91.75865936, 25.16845322], [91.75846863, 25.16849709], [91.75832367, 25.16866112], [91.75805664, 25.16909027], [91.75788879, 25.16934013], [91.7576828, 25.16963196], [91.75759125, 25.16986847], [91.75730896, 25.17006683], [91.75712585, 25.17036247], [91.75708008, 25.17042923], [91.75692749, 25.17056274], [91.7568512, 25.17061043], [91.75657654, 25.17112732], [91.75640869, 25.17135429], [91.75567627, 25.17146111], [91.75493622, 25.17156601], [91.75376129, 25.17269897], [91.75466156, 25.17293167], [91.75476074, 25.17295837], [91.75476074, 25.17331314], [91.75483704, 25.17359924], [91.75512695, 25.1741581], [91.75512695, 25.17443275], [91.75558472, 25.17522621], [91.75597382, 25.17591858], [91.7563324, 25.17656136], [91.75636292, 25.17670441], [91.75610352, 25.1774292], [91.75595093, 25.17760086], [91.75515747, 25.17749214], [91.75359344, 25.17695045], [91.75267792, 25.17650795], [91.75158691, 25.17601967], [91.75176239, 25.1749897], [91.75094604, 25.17283058], [91.75022125, 25.17181969], [91.74925232, 25.17048264], [91.74681091, 25.1667881], [91.74625397, 25.16596603], [91.74633026, 25.16553116], [91.7463913, 25.16521454], [91.74668884, 25.16462326], [91.74702454, 25.16411209], [91.74741364, 25.1635952], [91.74776459, 25.16306686], [91.74816132, 25.16260338], [91.74887848, 25.16143608], [91.74902344, 25.16119385], [91.74924469, 25.1607933], [91.7495575, 25.16014481], [91.74973297, 25.15938187], [91.74959564, 25.15864372], [91.74951172, 25.15820885], [91.74947357, 25.15803146], [91.74938965, 25.15781784], [91.74929047, 25.15755463], [91.74916077, 25.15722275], [91.74909973, 25.15711594], [91.74892426, 25.15681648], [91.74887085, 25.15672302], [91.74874878, 25.15654945], [91.74856567, 25.15630722], [91.74800873, 25.15592003], [91.74658966, 25.15519524], [91.74602509, 25.15498161], [91.7456665, 25.15473938], [91.74539948, 25.15449715], [91.74539185, 25.15434647], [91.74533844, 25.15289116], [91.7440033, 25.15122032], [91.74356079, 25.15115547], [91.74358368, 25.15055847], [91.74359131, 25.15023232], [91.7436142, 25.1496315], [91.74373627, 25.14912605], [91.74404144, 25.1479187], [91.74398804, 25.14763451], [91.74395752, 25.14744186], [91.74401855, 25.14703178], [91.74395752, 25.14656258], [91.7433548, 25.14605331], [91.74308014, 25.14587212], [91.74256897, 25.14531517], [91.74240112, 25.14498138], [91.74243164, 25.14448929], [91.74385071, 25.14354324], [91.74447632, 25.14307022], [91.74472046, 25.1428566], [91.74584198, 25.14233971], [91.74697113, 25.14173889], [91.74716187, 25.1414299], [91.74772644, 25.14053535], [91.74767303, 25.14044189], [91.74757385, 25.14027214], [91.74704742, 25.14033318], [91.74677277, 25.1403656], [91.74575806, 25.14048767], [91.74436951, 25.14091682], [91.74301147, 25.14128494], [91.74290466, 25.14153671], [91.74256134, 25.14185524], [91.74221039, 25.14175224], [91.74183655, 25.14164352], [91.74166107, 25.14153671], [91.74133301, 25.14168549], [91.74121094, 25.14174843], [91.74084473, 25.14224052], [91.74047089, 25.14239311], [91.73983765, 25.14210701], [91.73971558, 25.14223671], [91.73945618, 25.14236641], [91.73912811, 25.14231682], [91.73896027, 25.14229202], [91.73878479, 25.14245605], [91.73865509, 25.14257622], [91.73843384, 25.1425972], [91.73809814, 25.14263153], [91.73762512, 25.14252853], [91.73751831, 25.14272881], [91.73766327, 25.14284325], [91.73760223, 25.14305878], [91.73751831, 25.14310265], [91.73641205, 25.14368057], [91.73628235, 25.14351082], [91.73616028, 25.14363861], [91.73631287, 25.14391708], [91.73604584, 25.14549446], [91.73596954, 25.14574051], [91.73590851, 25.14587402], [91.7358017, 25.14740753], [91.73577881, 25.14782715], [91.73575592, 25.14832497], [91.7355957, 25.14913177], [91.73539734, 25.14982796], [91.73477173, 25.149786], [91.73434448, 25.14970398], [91.73392487, 25.14958572], [91.73358154, 25.14921761], [91.73282623, 25.14814758], [91.73266602, 25.14791107], [91.73254395, 25.14792252], [91.73196411, 25.14808273], [91.73168945, 25.14822197], [91.73175812, 25.14850616], [91.73213196, 25.14905739], [91.7323761, 25.14944458], [91.7325592, 25.14972878], [91.73288727, 25.1503315], [91.73264313, 25.15038681], [91.7317276, 25.1505909], [91.73165131, 25.15060616], [91.73027039, 25.15091515], [91.72840881, 25.15124893], [91.7266922, 25.1514225], [91.72632599, 25.15146065], [91.72454071, 25.15163803], [91.72276306, 25.15181541], [91.71964264, 25.1521244], [91.71813965, 25.15227509], [91.71646881, 25.15243912], [91.71651459, 25.15276146], [91.71626282, 25.15290833], [91.71619415, 25.15308571], [91.71607208, 25.15333748], [91.71591949, 25.15363121], [91.71559143, 25.15426826], [91.71534729, 25.15490532], [91.71530914, 25.15529251], [91.71517181, 25.15599823], [91.71504974, 25.15656662], [91.71473694, 25.15732765], [91.71442413, 25.15763283], [91.71430969, 25.15766335], [91.71286011, 25.15805626], [91.71212769, 25.15799904], [91.71133423, 25.15804863], [91.71057892, 25.15820885], [91.71009064, 25.15831375], [91.70915985, 25.1587677], [91.70867157, 25.15907288], [91.70852661, 25.15913391], [91.70841217, 25.15915298], [91.70822144, 25.15918159], [91.70774078, 25.15895844], [91.70754242, 25.15886497], [91.70745087, 25.15878677], [91.70728302, 25.15864372], [91.70719147, 25.15856743], [91.70670319, 25.15786552], [91.70619965, 25.15718269], [91.70611572, 25.15714645], [91.70585632, 25.15702438], [91.70540619, 25.15701866], [91.70488739, 25.15725136], [91.7046814, 25.15745163], [91.70453644, 25.1575985], [91.70438385, 25.15782356], [91.70423126, 25.15907097], [91.70433807, 25.1596489], [91.7040329, 25.16007233], [91.70363617, 25.16008568], [91.70352173, 25.1600132], [91.70307159, 25.15947342], [91.70291901, 25.15919876], [91.70236206, 25.157938], [91.70227051, 25.1576786], [91.70222473, 25.15754509], [91.70188141, 25.15712547], [91.70178223, 25.15707588], [91.70147705, 25.15691948], [91.70068359, 25.15656662], [91.70050812, 25.15634155], [91.70045471, 25.15607071], [91.70057678, 25.15551567], [91.70072937, 25.15532112], [91.70103455, 25.15504837], [91.7013092, 25.15486908], [91.70139313, 25.15481186], [91.70174408, 25.15469551], [91.70278931, 25.15412712], [91.70306396, 25.1537571], [91.70318604, 25.15359497], [91.70331573, 25.15306282], [91.70333862, 25.15281487], [91.70336914, 25.15190315], [91.70352936, 25.15153885], [91.70363617, 25.15133476], [91.70375061, 25.15102959], [91.70391846, 25.15096855], [91.70399475, 25.15094185], [91.70410156, 25.15088844], [91.70422363, 25.15084076], [91.70432281, 25.15080452], [91.70450592, 25.15076065], [91.70465088, 25.1507225], [91.70478821, 25.15055847], [91.70490265, 25.15017128], [91.70491791, 25.1500988], [91.70484924, 25.14994621], [91.70479584, 25.14982224], [91.70419312, 25.14949989], [91.70262146, 25.14715004], [91.70127106, 25.14698029], [91.70020294, 25.14683914], [91.69930267, 25.14502907], [91.69921875, 25.14439011], [91.69880676, 25.14149094], [91.69584656, 25.13908005], [91.69265747, 25.13840103], [91.69235229, 25.13774872], [91.69231415, 25.13766861], [91.69194794, 25.13737869], [91.69185638, 25.13733101], [91.69163513, 25.13721657], [91.69152069, 25.13720322], [91.69081879, 25.13724709], [91.69041443, 25.13726234], [91.68960571, 25.13708305], [91.68920898, 25.13698578], [91.6884613, 25.13731384], [91.68811798, 25.13730431], [91.68790436, 25.13738823], [91.68779755, 25.13736534], [91.68756866, 25.13765907], [91.68742371, 25.13784599], [91.68621826, 25.13784981], [91.68627167, 25.13758659], [91.68585205, 25.13734818], [91.68526459, 25.13701248], [91.68476105, 25.13672638], [91.6835022, 25.13639259], [91.68243408, 25.13605118], [91.68186951, 25.13586807], [91.68120575, 25.13546181], [91.68062592, 25.13506889], [91.67919159, 25.13590431], [91.6788559, 25.13619232], [91.67791748, 25.13676834], [91.67744446, 25.13709641], [91.67665863, 25.13741493], [91.67521667, 25.13692093], [91.67262268, 25.13528824], [91.67080688, 25.1334095], [91.67003632, 25.13159943], [91.6684494, 25.13027954], [91.66530609, 25.1304512], [91.66472626, 25.13086128], [91.66480255, 25.12998962], [91.6648407, 25.12992668], [91.6648941, 25.12983131], [91.66488647, 25.12911224], [91.66490173, 25.1289463], [91.66493225, 25.12867165], [91.66494751, 25.12855148], [91.6647644, 25.12852097], [91.66399384, 25.12845802], [91.66351318, 25.12843895], [91.66318512, 25.12837791], [91.66192627, 25.12789917], [91.66105652, 25.12735939], [91.66093445, 25.12723351], [91.6605835, 25.12714767], [91.66007996, 25.12712669], [91.65966797, 25.12724686], [91.65940094, 25.12748528], [91.65913391, 25.12832069], [91.65869141, 25.12886429], [91.65855408, 25.12900162], [91.65833282, 25.12963867], [91.6583786, 25.13027763], [91.65892029, 25.13076782], [91.65919495, 25.13109016], [91.65930939, 25.13127136], [91.65914154, 25.13120079], [91.6550293, 25.12945938], [91.65172577, 25.12756729], [91.65125275, 25.1273098], [91.65115356, 25.12719154], [91.65032196, 25.12739563], [91.64958191, 25.12766075], [91.64945221, 25.12769508], [91.64862061, 25.12791252], [91.64854431, 25.12791061], [91.64845276, 25.1279068], [91.64680481, 25.12709427], [91.64537048, 25.12733269], [91.64469147, 25.12664795], [91.64457703, 25.12654877], [91.64437866, 25.12636948], [91.64356995, 25.12565422], [91.64308167, 25.12504005], [91.64295197, 25.12487411], [91.64244843, 25.12397957], [91.64216614, 25.12347412], [91.64199066, 25.12316704], [91.64161682, 25.12306595], [91.64057159, 25.12299538], [91.64028168, 25.12304115], [91.63964844, 25.12364388], [91.63897705, 25.12324142], [91.63847351, 25.123106], [91.63828278, 25.12310791], [91.63785553, 25.12265396], [91.63657379, 25.12282753], [91.63619995, 25.12297821], [91.63583374, 25.12325287], [91.63581085, 25.1236763], [91.63569641, 25.12411118], [91.63552856, 25.12425995], [91.6352005, 25.12412453], [91.63505554, 25.12393761], [91.63488007, 25.12381744], [91.63451385, 25.12380409], [91.63398743, 25.123909], [91.63389587, 25.12397385], [91.63389587, 25.12418365], [91.6337738, 25.12432098], [91.63357544, 25.12446022], [91.63289642, 25.12439919], [91.63265991, 25.12442589], [91.63258362, 25.12443352], [91.63205719, 25.12449265], [91.63108063, 25.12466812], [91.63087463, 25.1246891], [91.62979889, 25.12479782], [91.62953949, 25.12487411], [91.62911224, 25.12499809], [91.62692261, 25.12552643], [91.62665558, 25.12566948], [91.62602997, 25.12610435], [91.62521362, 25.12680817], [91.62460327, 25.12726593], [91.62411499, 25.12754631], [91.62332153, 25.127882], [91.62310791, 25.12801743], [91.62295532, 25.1282692], [91.62272644, 25.12867737], [91.62258911, 25.12891579], [91.622612, 25.12901306], [91.62265015, 25.12916756], [91.62264252, 25.12949371], [91.62239075, 25.13067055], [91.6223526, 25.13096046], [91.62232971, 25.13109398], [91.62231445, 25.13149643], [91.6224823, 25.13212204], [91.62261963, 25.13246536], [91.62274933, 25.13277054], [91.62306213, 25.13425255], [91.62295532, 25.13571358], [91.62297058, 25.13593483], [91.62300873, 25.13613319], [91.62308502, 25.13649178], [91.62306976, 25.13663864], [91.6227417, 25.1381588], [91.62268829, 25.13840675], [91.62249756, 25.13855171], [91.62199402, 25.13894081], [91.62173462, 25.13915634], [91.62161255, 25.13942337], [91.62160492, 25.139534], [91.621521, 25.14010239], [91.62128448, 25.14056587], [91.62129211, 25.14075279], [91.62162018, 25.14151192], [91.62138367, 25.14200211], [91.62123108, 25.142416], [91.62122345, 25.14254761], [91.62133789, 25.14304543], [91.62142181, 25.14325142], [91.62141418, 25.14351463], [91.62081146, 25.14369774], [91.62034607, 25.14383888], [91.62010956, 25.14390945], [91.61891174, 25.14424133], [91.61703491, 25.14476585], [91.61614227, 25.14500999], [91.6157074, 25.14513016], [91.61536407, 25.14522362], [91.61506653, 25.14468002], [91.61470032, 25.14380646], [91.61450195, 25.14334488], [91.61434937, 25.14298439], [91.61404419, 25.14247131], [91.61389923, 25.14217186], [91.61374664, 25.14187622], [91.6133194, 25.14113617], [91.61312866, 25.14120293], [91.61260223, 25.14138794], [91.61244202, 25.14108467], [91.61221313, 25.14106941], [91.61186981, 25.14122391], [91.61156464, 25.14163208], [91.61159515, 25.14204025], [91.61174011, 25.14232254], [91.6120224, 25.14258957], [91.61240387, 25.1428318], [91.61239624, 25.14305496], [91.61239624, 25.14339447], [91.61228943, 25.14419556], [91.6121521, 25.14480782], [91.61207581, 25.14513969], [91.61188507, 25.14528275], [91.61160278, 25.14508057], [91.61003876, 25.14397049], [91.60714722, 25.14305115], [91.60682678, 25.14361954], [91.60643768, 25.14430237], [91.60612488, 25.14363289], [91.60599518, 25.14328766], [91.60587311, 25.14273262], [91.60475159, 25.14223099], [91.60446167, 25.14160538], [91.60430908, 25.14126778], [91.60371399, 25.14032555], [91.60351563, 25.14037514], [91.60321808, 25.14070892], [91.60284424, 25.14139557], [91.60241699, 25.14219284], [91.60224915, 25.14241982], [91.60160828, 25.14369965], [91.60137177, 25.144207], [91.60057831, 25.14593506], [91.60048676, 25.14618683], [91.60028076, 25.14691925], [91.60029602, 25.14716148], [91.59999847, 25.14834213], [91.599823, 25.1491909], [91.59951019, 25.15068626], [91.59938812, 25.15129662], [91.60097504, 25.15293694], [91.60158539, 25.15368843], [91.60190582, 25.1541214], [91.60228729, 25.15457344], [91.60248566, 25.15485764], [91.60259247, 25.15504074], [91.60275269, 25.15574455], [91.6031723, 25.15755272], [91.60344696, 25.15840912], [91.60349274, 25.15873337], [91.60355377, 25.1591301], [91.60335541, 25.15914536], [91.60139465, 25.15924644], [91.60044098, 25.15921974], [91.59992981, 25.15929031], [91.59984589, 25.15956688], [91.59990692, 25.15972519], [91.60043335, 25.16036797], [91.60063934, 25.16057587], [91.60106659, 25.16100883], [91.60124207, 25.16116524], [91.60150146, 25.1614151], [91.60206604, 25.16210747], [91.6021347, 25.16220665], [91.60223389, 25.16239357], [91.60293579, 25.16392899], [91.60329437, 25.16513443], [91.603302, 25.16526413], [91.60317993, 25.16568184], [91.6036911, 25.16688156], [91.60396576, 25.16755295], [91.60414124, 25.16761589], [91.60434723, 25.16769218], [91.60528564, 25.16809464], [91.60647583, 25.16885185], [91.60680389, 25.16911125], [91.60704041, 25.16932487], [91.60719299, 25.16939545], [91.60818481, 25.16985321], [91.60960388, 25.17009544], [91.6102829, 25.17000008], [91.61123657, 25.17002869], [91.61148071, 25.17003632], [91.6121521, 25.17033005], [91.6124649, 25.17031288], [91.61315918, 25.17004776], [91.6140213, 25.1696949], [91.61438751, 25.16969681], [91.61465454, 25.16969872], [91.61536407, 25.16970062], [91.61528015, 25.17041016], [91.6151886, 25.1710453], [91.61516571, 25.17192078], [91.61511993, 25.17374992], [91.61511993, 25.17435646], [91.61511993, 25.17485619], [91.61505127, 25.1748867], [91.61471558, 25.17503929], [91.61411285, 25.17534828], [91.60824585, 25.17435074], [91.60616302, 25.1742382], [91.60612488, 25.17411423], [91.60540771, 25.17376518], [91.60516357, 25.17400932], [91.60439301, 25.17404556], [91.60294342, 25.17405701], [91.6029129, 25.17421532], [91.59856415, 25.17425346], [91.59807587, 25.17429161], [91.59727478, 25.17435646], [91.59629822, 25.17448807], [91.5956955, 25.17443085], [91.59470367, 25.17384911], [91.59449005, 25.17372131], [91.59429932, 25.1737957], [91.59354401, 25.17408371], [91.59324646, 25.17416763], [91.59238434, 25.17434502], [91.59197235, 25.17443085], [91.59151459, 25.17431831], [91.59122467, 25.17424965], [91.59123993, 25.17386055], [91.59114838, 25.17377853], [91.59077454, 25.17376328], [91.59036255, 25.17306709], [91.59021759, 25.17282677], [91.59013367, 25.1726284], [91.58983612, 25.17256546], [91.58969116, 25.17201996], [91.58906555, 25.1717701], [91.58847809, 25.17172432], [91.58809662, 25.17176056], [91.58681488, 25.17233276], [91.58660126, 25.17228699], [91.58631897, 25.17189026], [91.58621979, 25.17173958], [91.58605957, 25.17162895], [91.58449554, 25.17178345], [91.58306885, 25.1719265], [91.58106232, 25.17214775], [91.58081055, 25.17261887], [91.58017731, 25.17252731], [91.57817078, 25.16819954], [91.57637787, 25.1643219], [91.5791626, 25.16060066], [91.57572937, 25.16072464], [91.57588196, 25.16056824], [91.5762558, 25.16003418], [91.57598877, 25.15974808], [91.57591248, 25.15966606], [91.57585144, 25.15960121], [91.57571411, 25.15968323], [91.57557678, 25.15976334], [91.57518005, 25.15989685], [91.5749054, 25.15990829], [91.57396698, 25.1598053], [91.57379913, 25.15990639], [91.57339478, 25.16020966], [91.57314301, 25.16012955], [91.56919098, 25.15942955], [91.56694794, 25.15875053], [91.56115723, 25.15121078], [91.55885315, 25.14929008], [91.55686951, 25.14884567], [91.54627991, 25.14647102], [91.53777313, 25.14437294], [91.53353882, 25.1441803], [91.52954865, 25.14398003], [91.5218811, 25.14464188], [91.51819611, 25.1449585], [91.51364899, 25.1453495], [91.51258087, 25.14516068], [91.51026917, 25.14472961], [91.50830841, 25.14324951], [91.50672913, 25.14068031], [91.50595856, 25.139431], [91.50463867, 25.13729668], [91.5042572, 25.1366806], [91.50263214, 25.13548088], [91.49946594, 25.13541985], [91.49932861, 25.13544464], [91.49882507, 25.1355381], [91.49827576, 25.1356411], [91.49693298, 25.13589096], [91.49684906, 25.13590622], [91.49607086, 25.13579941], [91.49562836, 25.13578987], [91.49552155, 25.13580322], [91.49514008, 25.135849], [91.49478912, 25.13615608], [91.49427795, 25.13638306], [91.4925766, 25.13669968], [91.49038696, 25.13620377], [91.48995209, 25.13591766], [91.48970795, 25.13568306], [91.48920441, 25.13521576], [91.48886108, 25.13546753], [91.4884491, 25.13566589], [91.48812866, 25.13573074], [91.48741913, 25.13576698], [91.48682404, 25.13563156], [91.48674011, 25.13578606], [91.48651886, 25.13593292], [91.48542786, 25.13631058], [91.48512268, 25.13632965], [91.48236847, 25.13557053], [91.48240662, 25.13525963], [91.48255157, 25.13406944], [91.48152161, 25.13401985], [91.47843933, 25.13387108], [91.47813416, 25.13387108], [91.47732544, 25.13401222], [91.47690582, 25.13386726], [91.47640228, 25.13373375], [91.47520447, 25.13354301], [91.47432709, 25.13351822], [91.47190094, 25.13363838], [91.47055054, 25.13374901], [91.47032928, 25.13383102], [91.4699173, 25.13412094], [91.46949005, 25.13446808], [91.46915436, 25.13445091], [91.46756744, 25.1343708], [91.46643066, 25.13440514], [91.46457672, 25.13495827], [91.4641571, 25.13491249], [91.46411133, 25.13576126], [91.46463013, 25.13668442], [91.4647522, 25.13689995], [91.4649353, 25.13710785], [91.46542358, 25.13733292], [91.4655304, 25.13738251], [91.4657135, 25.13737488], [91.46604156, 25.13735771], [91.46682739, 25.13736916], [91.4675827, 25.13758278], [91.46800232, 25.13796616], [91.46851349, 25.13862419], [91.46870422, 25.1389389], [91.46920776, 25.13965034], [91.46977234, 25.13972282], [91.4703598, 25.13983536], [91.47041321, 25.1403141], [91.47026825, 25.14066315], [91.47000885, 25.14124489], [91.46972656, 25.14117432], [91.46915436, 25.14103699], [91.46863556, 25.14099503], [91.46792603, 25.14172554], [91.46787262, 25.14213371], [91.4678421, 25.14236641], [91.46768188, 25.14299202], [91.46740723, 25.14361954], [91.4669342, 25.14391327], [91.46720123, 25.14450073], [91.46733856, 25.1448822], [91.46743774, 25.14530563], [91.4675293, 25.14565659], [91.4675827, 25.1460762], [91.46794128, 25.14645958], [91.4680481, 25.14657211], [91.46805573, 25.14668655], [91.46798706, 25.14682388], [91.46775818, 25.147295], [91.46788788, 25.14740944], [91.46840668, 25.14777946], [91.46850586, 25.14790916], [91.46869659, 25.14817047], [91.46862793, 25.14840126], [91.46853638, 25.14853477], [91.4681778, 25.1490593], [91.4682312, 25.14932823], [91.46835327, 25.14952087], [91.46848297, 25.14972687], [91.46865845, 25.14997673], [91.46791077, 25.14980125], [91.4621582, 25.14851952], [91.45652008, 25.14803123], [91.45065308, 25.14818001], [91.445961, 25.14910126], [91.44288635, 25.15071869], [91.44272614, 25.15068626], [91.44232178, 25.15039635], [91.44204712, 25.15025902], [91.44109344, 25.1498642], [91.44090271, 25.14980125], [91.44072723, 25.14975357], [91.44049072, 25.14975357], [91.44034576, 25.15003204], [91.44004059, 25.15058327], [91.43992615, 25.15098381], [91.43991089, 25.15105438], [91.43978119, 25.15108871], [91.43923187, 25.15123177], [91.43912506, 25.15146828], [91.4389267, 25.15168571], [91.43856049, 25.15216255], [91.43845367, 25.15216446], [91.43732452, 25.15320015], [91.43726349, 25.15386009], [91.43714142, 25.15422821], [91.43659973, 25.15426064], [91.43624115, 25.15427971], [91.43550873, 25.15501213], [91.4354248, 25.15509415], [91.43488312, 25.15550995], [91.43482208, 25.15555763], [91.43457031, 25.15569115], [91.43424225, 25.15576744], [91.43390656, 25.15584564], [91.43358612, 25.15621376], [91.43341827, 25.15636063], [91.43287659, 25.1567688], [91.43264771, 25.15687752], [91.43257904, 25.15690613], [91.43247223, 25.15681839], [91.43236542, 25.15680695], [91.43188477, 25.15699387], [91.43134308, 25.15720367], [91.43051147, 25.15737343], [91.43013, 25.15739632], [91.42996216, 25.15737152], [91.42974854, 25.1573391], [91.42952728, 25.15733528], [91.42912292, 25.15740395], [91.42849731, 25.15751076], [91.42725372, 25.15736771], [91.42631531, 25.15728951], [91.42610931, 25.15731621], [91.42544556, 25.15708733], [91.42514801, 25.15704536], [91.42494965, 25.15717697], [91.42485809, 25.15729904], [91.42462158, 25.1575985], [91.42434692, 25.1582737], [91.42419434, 25.15830612], [91.42388153, 25.15820122], [91.42378998, 25.15823746], [91.42359161, 25.15831375], [91.42350006, 25.15846825], [91.42344666, 25.15887642], [91.42338562, 25.15956688], [91.4233551, 25.15969086], [91.4230423, 25.1606369], [91.42294312, 25.16082954], [91.42279053, 25.16111374], [91.42249298, 25.16159248], [91.42256927, 25.16183472], [91.42259979, 25.1620121], [91.42261505, 25.16212654], [91.42242432, 25.16233826], [91.42230988, 25.16247177], [91.42201233, 25.16266632], [91.42189026, 25.1627636], [91.42158508, 25.16299629], [91.42137146, 25.16305923], [91.42120361, 25.16302109], [91.42115784, 25.16308022], [91.42053223, 25.16385078], [91.41975403, 25.16482162], [91.41880035, 25.16599274], [91.41814423, 25.16680527], [91.4178772, 25.16713524], [91.41603088, 25.16942215], [91.41527557, 25.17036438], [91.41456604, 25.17124176], [91.41419983, 25.17075348], [91.41388702, 25.17040634], [91.41368103, 25.17022133], [91.41313934, 25.16986465], [91.41243744, 25.16959953], [91.41207886, 25.1695385], [91.4119873, 25.1693325], [91.4119873, 25.16892815], [91.41179657, 25.16869354], [91.41186523, 25.16855431], [91.4122467, 25.16813087], [91.41277313, 25.16758919], [91.41277313, 25.16734695], [91.41249847, 25.16689301], [91.41196442, 25.16600609], [91.41149902, 25.16506004], [91.41143799, 25.16493988], [91.41100311, 25.16409111], [91.4108429, 25.16378021], [91.40990448, 25.16387558], [91.40966034, 25.1639328], [91.4090271, 25.16402245], [91.40886688, 25.16404533], [91.40879059, 25.16410828], [91.40853119, 25.16431808], [91.40796661, 25.16483116], [91.40766907, 25.16514969], [91.40711975, 25.16572571], [91.40672302, 25.16621399], [91.40575409, 25.16612434], [91.40548706, 25.16609764], [91.40457916, 25.16582298], [91.40441132, 25.16577148], [91.40399933, 25.16572762], [91.40372467, 25.16569901], [91.40350342, 25.16569328], [91.40261078, 25.16555977], [91.4024353, 25.16579247], [91.40179443, 25.1656971], [91.40086365, 25.16549683], [91.3996048, 25.16517448], [91.39936066, 25.16509056], [91.3990097, 25.16496468], [91.39886475, 25.16482735], [91.39855194, 25.16457176], [91.39844513, 25.16463089], [91.39745331, 25.1651783], [91.39678955, 25.1654911], [91.396492, 25.16556931], [91.39602661, 25.16570473], [91.39454651, 25.16609573], [91.39401245, 25.16626358], [91.39270782, 25.16659737], [91.39135742, 25.16690636], [91.3911438, 25.16695786], [91.39048767, 25.16711617], [91.38976288, 25.16730118], [91.38903809, 25.16752434], [91.38894653, 25.16757584], [91.38884735, 25.16659164], [91.38861084, 25.16710472], [91.38853455, 25.16750908], [91.38848114, 25.16782761], [91.38774109, 25.16822433], [91.38622284, 25.16904068], [91.38453674, 25.1698494], [91.38435364, 25.16993713], [91.38374329, 25.16984558], [91.38323975, 25.16973686], [91.38265991, 25.16926384], [91.38202667, 25.16874313], [91.38156891, 25.16843987], [91.38114166, 25.16834641], [91.3796463, 25.16826439], [91.3779068, 25.16815186], [91.37739563, 25.16813469], [91.37614441, 25.16809273], [91.37592316, 25.16815186], [91.37549591, 25.16826248], [91.37454224, 25.16858482], [91.37419128, 25.16867256], [91.37401581, 25.16874123], [91.37387085, 25.16879845], [91.37334442, 25.16902733], [91.37274933, 25.1693306], [91.37205505, 25.16959953], [91.37177277, 25.1697216], [91.3711319, 25.1700592], [91.36955261, 25.170784], [91.36875153, 25.17071533], [91.36843872, 25.17082405], [91.36814117, 25.17100143], [91.36769104, 25.1713028], [91.36685181, 25.17253113], [91.36651611, 25.17305946], [91.36633301, 25.17331505], [91.36571503, 25.17411804], [91.36527252, 25.1746273], [91.36508942, 25.17482185], [91.36508179, 25.17518616], [91.36506653, 25.17579842], [91.36476898, 25.17694664], [91.36471558, 25.17728996], [91.36464691, 25.17753029], [91.36444092, 25.17801476], [91.36418915, 25.17807388], [91.36373138, 25.17816544], [91.36301422, 25.17824173], [91.36211395, 25.17823601], [91.36110687, 25.17799759], [91.36064148, 25.17770958], [91.3596344, 25.17692375], [91.35959625, 25.17679787], [91.35939789, 25.17611694], [91.35929108, 25.17592239], [91.35900116, 25.17558289], [91.35884094, 25.17546654], [91.35832977, 25.17530632], [91.35804749, 25.17520714], [91.35739136, 25.17489815], [91.3571167, 25.17462158], [91.35643768, 25.17377281], [91.35569763, 25.17307854], [91.35531616, 25.17283249], [91.35476685, 25.17234802], [91.35448456, 25.1721077], [91.35429382, 25.17194176], [91.35366821, 25.17133331], [91.35354614, 25.1715374], [91.35346985, 25.17152214], [91.35321808, 25.17199898], [91.35295868, 25.17248344], [91.35240173, 25.17353821], [91.35230255, 25.17375565], [91.35225677, 25.17393303], [91.35211182, 25.1744957], [91.35198975, 25.17496872], [91.35190582, 25.17528534], [91.35168457, 25.17576218], [91.35148621, 25.17592239], [91.35107422, 25.17592621], [91.35072327, 25.17588425], [91.35041046, 25.17580605], [91.34954834, 25.17540932], [91.34931183, 25.1752758], [91.34850311, 25.17466354], [91.34804535, 25.17446518], [91.34770966, 25.1744175], [91.34718323, 25.17429161], [91.34580231, 25.17429543], [91.34522247, 25.17428017], [91.34375, 25.17415619], [91.34324646, 25.17406082], [91.3429184, 25.17398453], [91.3419342, 25.17371941], [91.34054565, 25.17369843], [91.34014893, 25.17366028], [91.33912659, 25.17366982], [91.33712006, 25.17365074], [91.33680725, 25.17378235], [91.33624268, 25.17401314], [91.33566284, 25.17424965], [91.33519745, 25.17459679], [91.33503723, 25.17481804], [91.33468628, 25.17604065], [91.33443451, 25.17675972], [91.33329773, 25.17710495], [91.33303833, 25.17718315], [91.33232117, 25.17739677], [91.33130646, 25.17760468], [91.33094788, 25.17753792], [91.32998657, 25.1771698], [91.32966614, 25.17703056], [91.32910156, 25.17684746], [91.32832336, 25.17657852], [91.32752228, 25.17631149], [91.32739258, 25.17629814], [91.32713318, 25.17626953], [91.32694244, 25.17629623], [91.32665253, 25.1764183], [91.32639313, 25.1765976], [91.32602692, 25.17712975], [91.32591248, 25.1778698], [91.32584381, 25.17832375], [91.32536316, 25.17951393], [91.32527161, 25.17974663], [91.32478333, 25.1803894], [91.3242569, 25.18083191], [91.32380676, 25.18120193], [91.32265472, 25.18190575], [91.32228088, 25.18207741], [91.32123566, 25.18239975], [91.32097626, 25.18247986], [91.32022858, 25.18247986], [91.32017517, 25.18234253], [91.31955719, 25.18248367], [91.31937408, 25.18264771], [91.31903076, 25.18323517], [91.31897736, 25.18331909], [91.31768036, 25.18379211], [91.31671143, 25.18384361], [91.31635284, 25.18386269], [91.31571198, 25.18394279], [91.31374359, 25.18410873], [91.31265259, 25.18421555], [91.31040192, 25.18411636], [91.30886078, 25.18395615], [91.30789948, 25.18377686], [91.30765533, 25.1836834], [91.30670929, 25.18315125], [91.3065033, 25.1830349], [91.30591583, 25.18272781], [91.3045578, 25.18270683], [91.30439758, 25.18272018], [91.30268097, 25.18336296], [91.30054474, 25.18416595], [91.30005646, 25.18435097], [91.29975891, 25.18432999], [91.29886627, 25.18426323], [91.29663849, 25.18408966], [91.29388428, 25.18396568], [91.29240417, 25.18392372], [91.29206085, 25.18410492], [91.29151154, 25.18447495], [91.29019928, 25.18542099], [91.28952789, 25.18587685], [91.28835297, 25.18661118], [91.2876358, 25.18617439], [91.28664398, 25.1855793], [91.28647614, 25.1854763]]]}}, {\\\"id\\\": \\\"20\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.23_1\\\", \\\"HASC_1\\\": \\\"IN.MZ\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Mizoram\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 32.8, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1301.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 899.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2200.0, \\\"geo-id\\\": 20, \\\"hpm25_child_popweighted\\\": 105.4, \\\"hpm25_female_popweighted\\\": 121.1, \\\"hpm25_male_popweighted\\\": 87.2, \\\"location\\\": \\\"Mizoram\\\", \\\"mort_apm25_6cod_mean_total\\\": 600.0, \\\"mort_hpm25_6cod_mean_total\\\": 409.0, \\\"mort_tpm25_6cod_mean_total\\\": 1009.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[92.856987, 22.06563187], [92.85463715, 22.06488991], [92.84902191, 22.06235123], [92.84464264, 22.06343269], [92.84464264, 22.06813049], [92.84144592, 22.07201004], [92.8365097, 22.07635117], [92.83249664, 22.07644081], [92.82563782, 22.07966995], [92.82028961, 22.09033966], [92.8170929, 22.09556961], [92.81040955, 22.09764099], [92.80332947, 22.10225105], [92.79515839, 22.10621071], [92.78878784, 22.10890961], [92.78312683, 22.10863113], [92.77741241, 22.1097908], [92.77675629, 22.11001587], [92.77374268, 22.11104965], [92.77305603, 22.11178017], [92.76925659, 22.11584091], [92.77012634, 22.12306976], [92.76567078, 22.12631989], [92.751297, 22.1327095], [92.74314117, 22.13594818], [92.73781586, 22.13900948], [92.73275757, 22.14958954], [92.71788788, 22.15262985], [92.70797729, 22.15351105], [92.70343781, 22.15378189], [92.70034027, 22.14964294], [92.69935608, 22.1483326], [92.70062256, 22.13838959], [92.69966888, 22.12239075], [92.69896698, 22.11822128], [92.69713593, 22.09930992], [92.69754791, 22.08622169], [92.69695282, 22.08088112], [92.69355774, 22.07724953], [92.69132233, 22.08113098], [92.69062805, 22.09478951], [92.68955994, 22.1070919], [92.68644714, 22.10942078], [92.68383789, 22.10534859], [92.68453217, 22.09205055], [92.68530273, 22.08555031], [92.68550873, 22.08173943], [92.68578339, 22.07650948], [92.68685913, 22.06991005], [92.68725586, 22.06312752], [92.68628693, 22.05859947], [92.68667603, 22.05001068], [92.68997955, 22.04097939], [92.6894989, 22.0357399], [92.6879425, 22.03239059], [92.68817139, 22.03071976], [92.68843842, 22.02858925], [92.68727112, 22.0238781], [92.68435669, 22.01791], [92.6807785, 22.01419067], [92.67681122, 22.01409149], [92.67154694, 22.01471138], [92.66322327, 22.01550102], [92.65924072, 22.01472282], [92.64929962, 22.00341415], [92.6446991, 21.99818993], [92.64100647, 21.99221039], [92.63791656, 21.98867035], [92.63006592, 21.98495293], [92.62895203, 21.98461723], [92.61812592, 21.98138046], [92.61231995, 21.98028946], [92.61193085, 21.98184967], [92.61178589, 21.9817028], [92.60968018, 21.97683716], [92.60926819, 21.97923088], [92.60923004, 21.98274994], [92.60878754, 21.98384285], [92.60877991, 21.98409462], [92.61048889, 21.98500443], [92.61130524, 21.98616982], [92.61185455, 21.98840332], [92.61183929, 21.99004555], [92.6126709, 21.9913826], [92.61228943, 21.99279213], [92.61045837, 21.99459839], [92.61003876, 21.99501228], [92.61024475, 21.99621201], [92.60983276, 21.99775505], [92.60997009, 21.99818993], [92.60929871, 21.9984169], [92.60876465, 21.99947357], [92.60635376, 21.99961281], [92.60577393, 21.99964523], [92.60578156, 21.99996376], [92.60579681, 22.00054359], [92.60424805, 22.00224686], [92.6025238, 22.00336838], [92.60250092, 22.00427628], [92.60144806, 22.00697708], [92.59914398, 22.00862885], [92.59914398, 22.00904083], [92.59804535, 22.01124763], [92.597435, 22.01196098], [92.597435, 22.01211166], [92.59745026, 22.01298332], [92.59764862, 22.01314926], [92.59902191, 22.01429749], [92.5990448, 22.01539612], [92.59867859, 22.01641655], [92.5993042, 22.01816177], [92.59991455, 22.01987457], [92.60054016, 22.0224781], [92.59988403, 22.02490044], [92.59947968, 22.02871895], [92.59815979, 22.02953911], [92.59784698, 22.02973175], [92.59715271, 22.03016281], [92.59660339, 22.03050423], [92.59661102, 22.03060722], [92.59662628, 22.03161049], [92.59451294, 22.03232002], [92.59402466, 22.03248405], [92.59383392, 22.03293037], [92.59335327, 22.03404617], [92.59339905, 22.03628922], [92.5931778, 22.03810883], [92.59263611, 22.04113007], [92.59352875, 22.04196358], [92.59910583, 22.04241371], [92.59786224, 22.04454041], [92.59790802, 22.04681587], [92.59785461, 22.0479393], [92.59837341, 22.04939842], [92.60027313, 22.05315781], [92.60033417, 22.0559864], [92.60035706, 22.05781746], [92.60018921, 22.0590992], [92.60089111, 22.06030846], [92.60115051, 22.06050491], [92.60227203, 22.06137085], [92.60263824, 22.06185913], [92.60220337, 22.06214714], [92.60119629, 22.06163788], [92.60079193, 22.06162453], [92.59844208, 22.0615406], [92.59622955, 22.06199837], [92.59528351, 22.06219292], [92.59479523, 22.06275558], [92.59365845, 22.06407166], [92.59225464, 22.06564903], [92.59140778, 22.06833839], [92.58979797, 22.07079315], [92.59063721, 22.07176781], [92.5900116, 22.07458496], [92.58959961, 22.07611084], [92.59039307, 22.0777626], [92.59015656, 22.07916832], [92.59056854, 22.08104324], [92.58907318, 22.08129692], [92.58856201, 22.08138466], [92.58622742, 22.08199692], [92.58496094, 22.08248329], [92.58525085, 22.08471489], [92.58532715, 22.08528137], [92.5845108, 22.08592796], [92.58367157, 22.08658981], [92.58322906, 22.08729935], [92.58330536, 22.08748245], [92.58417511, 22.08942795], [92.58410645, 22.09050179], [92.58165741, 22.09178352], [92.58197021, 22.09243774], [92.58274841, 22.09316635], [92.58207703, 22.09474564], [92.58236694, 22.09610176], [92.58253479, 22.09770775], [92.58124542, 22.09943962], [92.58050537, 22.10090637], [92.57924652, 22.10263634], [92.578125, 22.10347366], [92.57781982, 22.10442924], [92.57662201, 22.10511017], [92.57598114, 22.10761452], [92.57579041, 22.1090374], [92.57620239, 22.11008453], [92.57582855, 22.11136246], [92.57483673, 22.1124115], [92.57530975, 22.11531639], [92.57516479, 22.1162014], [92.57369995, 22.11742401], [92.57246399, 22.11977386], [92.56926727, 22.12200356], [92.56729126, 22.12407684], [92.56552887, 22.12449646], [92.56369781, 22.12581825], [92.56250763, 22.12827301], [92.56357574, 22.12998581], [92.56317902, 22.13090134], [92.56381989, 22.13253975], [92.56388092, 22.13374329], [92.56583405, 22.13503647], [92.56668091, 22.13534355], [92.56775665, 22.13573456], [92.56827545, 22.13578415], [92.57097626, 22.13603973], [92.57637787, 22.13595581], [92.57745361, 22.13752937], [92.5762558, 22.13973808], [92.57845306, 22.14200783], [92.57831573, 22.14291382], [92.57820129, 22.14360428], [92.57904816, 22.14324188], [92.5816803, 22.14211273], [92.58395386, 22.14149475], [92.58646393, 22.14103508], [92.58840942, 22.14068604], [92.59149933, 22.13965797], [92.5918808, 22.13953209], [92.59322357, 22.13764191], [92.59096527, 22.1337738], [92.59046936, 22.13334274], [92.58888245, 22.13194656], [92.58930206, 22.13075066], [92.59075165, 22.12911034], [92.59133911, 22.12844467], [92.59308624, 22.12657928], [92.5940094, 22.12558937], [92.59633636, 22.12425232], [92.59959412, 22.12315178], [92.6003952, 22.12365723], [92.6029129, 22.12311554], [92.60548401, 22.1233139], [92.60626221, 22.12473869], [92.60691071, 22.12592888], [92.60775757, 22.12809944], [92.6081543, 22.13005638], [92.6080246, 22.13221931], [92.60777283, 22.13304901], [92.60824585, 22.13454247], [92.6100769, 22.13523483], [92.61054993, 22.13794899], [92.61094666, 22.13853455], [92.61047363, 22.13933563], [92.60980988, 22.14200592], [92.61013794, 22.14414406], [92.60916901, 22.14651489], [92.60882568, 22.14916039], [92.60897064, 22.15167427], [92.60803223, 22.15354919], [92.60795593, 22.15614891], [92.60823059, 22.1584549], [92.60738373, 22.160532], [92.60820007, 22.1612606], [92.60928345, 22.16421127], [92.60788727, 22.16518593], [92.60662079, 22.16607475], [92.60719299, 22.16788101], [92.60755157, 22.16831017], [92.60752869, 22.17087936], [92.60751343, 22.17213249], [92.60683441, 22.17279625], [92.60507965, 22.17274666], [92.60482788, 22.17229652], [92.60476685, 22.17222595], [92.60424042, 22.17166519], [92.60144806, 22.17285538], [92.59857941, 22.17447662], [92.59645844, 22.17547989], [92.59505463, 22.17546463], [92.59666443, 22.1767807], [92.59706116, 22.17762375], [92.59636688, 22.17857742], [92.59568787, 22.17878342], [92.59555054, 22.17882347], [92.59555054, 22.17905998], [92.59555817, 22.18100929], [92.59477997, 22.18106842], [92.59440613, 22.18109703], [92.59545135, 22.18288422], [92.59557343, 22.18296242], [92.59688568, 22.18379021], [92.59488678, 22.18395042], [92.59577942, 22.18525505], [92.59622192, 22.18673134], [92.59574127, 22.18910599], [92.59568787, 22.18938255], [92.59599304, 22.18972206], [92.59654999, 22.1903553], [92.59533691, 22.19351387], [92.59626007, 22.1934967], [92.5953598, 22.19453621], [92.59486389, 22.19649315], [92.59417725, 22.19607544], [92.59397125, 22.19594955], [92.59433746, 22.19730568], [92.5944519, 22.19770622], [92.5951767, 22.19863319], [92.59407043, 22.20166779], [92.59392548, 22.20207214], [92.59400177, 22.20228767], [92.59474945, 22.20441628], [92.59370422, 22.2041893], [92.59368134, 22.20732498], [92.59356689, 22.20856476], [92.59308624, 22.20939827], [92.59263611, 22.21006775], [92.59304047, 22.21072006], [92.59246826, 22.21099472], [92.59248352, 22.21180344], [92.59039307, 22.21332741], [92.59195709, 22.21389198], [92.59142303, 22.21442986], [92.58802795, 22.21603775], [92.58894348, 22.21780968], [92.58807373, 22.21865082], [92.59024811, 22.2210865], [92.59029388, 22.22308159], [92.58908081, 22.22437477], [92.58821869, 22.2239933], [92.58802032, 22.22467422], [92.5892868, 22.22582436], [92.58842468, 22.2269783], [92.58927155, 22.22838211], [92.58840942, 22.23028755], [92.58820343, 22.23074532], [92.58877563, 22.23085022], [92.59059143, 22.23118019], [92.58943939, 22.23204231], [92.59040833, 22.23270035], [92.58901978, 22.23281097], [92.58876801, 22.23283005], [92.58932495, 22.23381042], [92.5904007, 22.23431206], [92.59153748, 22.2348423], [92.58965302, 22.23568153], [92.58961487, 22.23576736], [92.58969879, 22.23651505], [92.58986664, 22.23795128], [92.59066772, 22.23854256], [92.5917511, 22.23933601], [92.59143066, 22.24028587], [92.59124756, 22.24082184], [92.59039307, 22.24451828], [92.59059906, 22.24457169], [92.59169769, 22.24486542], [92.59133148, 22.24677849], [92.5898056, 22.24727249], [92.58905792, 22.24751282], [92.58964539, 22.2479744], [92.59089661, 22.24896431], [92.59049988, 22.24953651], [92.58985901, 22.25046921], [92.58958435, 22.25217438], [92.58995819, 22.25274849], [92.58985138, 22.25365257], [92.5894165, 22.25415802], [92.58986664, 22.25437737], [92.59044647, 22.25466347], [92.59072876, 22.25527191], [92.59036255, 22.2562027], [92.58914185, 22.25584412], [92.58872223, 22.25572205], [92.58879852, 22.25634766], [92.58895111, 22.25754929], [92.58808899, 22.25742912], [92.58738708, 22.25733185], [92.5870285, 22.25868988], [92.58692932, 22.25907326], [92.58660126, 22.25894356], [92.5854187, 22.25847244], [92.585289, 22.25902748], [92.58518219, 22.25946808], [92.58659363, 22.25972176], [92.58476257, 22.26123619], [92.58428955, 22.2616291], [92.58467102, 22.26360893], [92.5848465, 22.26450729], [92.58686829, 22.26409149], [92.58493805, 22.26516533], [92.58432007, 22.26744652], [92.58099365, 22.26928139], [92.58257294, 22.27061462], [92.58319855, 22.27274895], [92.58228302, 22.27416039], [92.58081818, 22.27357674], [92.58076477, 22.27485847], [92.58071899, 22.27588272], [92.58071136, 22.27603722], [92.58342743, 22.2762928], [92.58325958, 22.27739334], [92.58528137, 22.27654839], [92.58641815, 22.2768898], [92.58509827, 22.27733421], [92.58430481, 22.27848625], [92.58441925, 22.27936935], [92.5848999, 22.27988434], [92.58598328, 22.28001595], [92.58653259, 22.28040314], [92.58540344, 22.28075409], [92.58427429, 22.28169823], [92.58182526, 22.28184319], [92.58167267, 22.28339386], [92.58254242, 22.28428268], [92.5840683, 22.28449249], [92.58429718, 22.28481865], [92.58329773, 22.28578568], [92.58109283, 22.28660965], [92.5827179, 22.28798294], [92.58210754, 22.28923225], [92.5812149, 22.29069328], [92.58261108, 22.29120255], [92.58283234, 22.2947979], [92.58268738, 22.29656601], [92.58272552, 22.29841423], [92.58343506, 22.29922485], [92.58139038, 22.30038643], [92.58182526, 22.30216026], [92.58126831, 22.30202484], [92.58101654, 22.30195999], [92.58074951, 22.30268097], [92.58068085, 22.3028698], [92.58057404, 22.30315781], [92.58166504, 22.30288887], [92.58202362, 22.30280113], [92.58347321, 22.30414391], [92.58227539, 22.3037529], [92.58159637, 22.3038044], [92.58057404, 22.3038826], [92.58062744, 22.30448341], [92.58074951, 22.30592728], [92.5800705, 22.30607605], [92.5796814, 22.30615997], [92.58092499, 22.30669022], [92.58113098, 22.30677795], [92.58144379, 22.30871964], [92.57936859, 22.30982971], [92.57796478, 22.3104744], [92.57792664, 22.31067085], [92.57769012, 22.3120079], [92.5789032, 22.31107712], [92.58000946, 22.31185722], [92.58026886, 22.31204224], [92.57994843, 22.31218529], [92.57854462, 22.31281662], [92.57989502, 22.31479836], [92.58000946, 22.31497574], [92.5794754, 22.31542206], [92.57796478, 22.31666374], [92.57892609, 22.31800842], [92.5796814, 22.31875229], [92.58045959, 22.31951523], [92.57946777, 22.32098579], [92.58122253, 22.32180405], [92.57858276, 22.3236084], [92.57997131, 22.32401276], [92.58028412, 22.32519722], [92.57836914, 22.32544518], [92.57686615, 22.32524681], [92.57673645, 22.32522774], [92.57671356, 22.32533836], [92.57644653, 22.32676125], [92.57630157, 22.32980919], [92.57588196, 22.33151627], [92.57434082, 22.3321228], [92.57577515, 22.33283806], [92.5763092, 22.33348846], [92.57432556, 22.33452415], [92.5741806, 22.33460045], [92.57444, 22.33469963], [92.57601166, 22.33530998], [92.57505798, 22.33640099], [92.5760498, 22.33725739], [92.57540131, 22.33790398], [92.57509613, 22.33821487], [92.57450867, 22.33764839], [92.57379913, 22.33827209], [92.57486725, 22.34003448], [92.57491302, 22.34052086], [92.57509613, 22.34242439], [92.57320404, 22.34259415], [92.57279205, 22.34263039], [92.57315826, 22.34431458], [92.57343292, 22.34559059], [92.57269287, 22.34581375], [92.57232666, 22.34592438], [92.57221985, 22.34734535], [92.573349, 22.34793663], [92.57317352, 22.34905815], [92.57276154, 22.35169411], [92.57187653, 22.35390472], [92.57100677, 22.35677528], [92.57201385, 22.35877991], [92.57211304, 22.35923386], [92.57055664, 22.3603878], [92.56861115, 22.36016655], [92.56803131, 22.36071014], [92.56835938, 22.36161041], [92.56693268, 22.36543274], [92.56812286, 22.36750793], [92.56718445, 22.36873055], [92.56651306, 22.37095451], [92.56275177, 22.37145233], [92.56352997, 22.37387276], [92.56415558, 22.37547493], [92.56365204, 22.37597466], [92.56250763, 22.37586784], [92.56217957, 22.37583542], [92.56201172, 22.37633133], [92.56161499, 22.37750244], [92.56209564, 22.37798309], [92.56227875, 22.37843323], [92.56351471, 22.38018608], [92.55934143, 22.38207817], [92.55968475, 22.38284302], [92.56018066, 22.38396072], [92.56122589, 22.38534355], [92.5594101, 22.38756371], [92.56116486, 22.38881111], [92.56034851, 22.38959312], [92.55943298, 22.39046669], [92.55838776, 22.39146233], [92.5598526, 22.3915596], [92.55853271, 22.39414215], [92.55989075, 22.3956852], [92.55978394, 22.39609146], [92.55716705, 22.39746857], [92.55596161, 22.39876938], [92.55749512, 22.39994431], [92.55908966, 22.39990997], [92.55931854, 22.39990425], [92.55934906, 22.40004349], [92.55980682, 22.40208244], [92.5577774, 22.40264702], [92.55741119, 22.40275002], [92.55711365, 22.40283394], [92.55690765, 22.40317917], [92.55608368, 22.40454483], [92.5552597, 22.40516663], [92.5546875, 22.4056015], [92.55578613, 22.40705109], [92.55738831, 22.40732574], [92.55770874, 22.4081955], [92.55796814, 22.40888596], [92.55680847, 22.40944099], [92.55444336, 22.41076279], [92.55361176, 22.40929413], [92.55299377, 22.40918922], [92.55205536, 22.40903282], [92.55307007, 22.41115952], [92.55236053, 22.41307068], [92.5528183, 22.41378784], [92.55290985, 22.41392708], [92.55284119, 22.41408157], [92.55223083, 22.41550827], [92.55358887, 22.41667938], [92.55452728, 22.41703415], [92.55400848, 22.41836548], [92.55347443, 22.41973686], [92.55194092, 22.42087173], [92.55181122, 22.42096329], [92.55078888, 22.42279816], [92.55133057, 22.4234066], [92.55300903, 22.42279816], [92.55413818, 22.42333031], [92.55453491, 22.42351341], [92.55518341, 22.42267609], [92.55638885, 22.42523003], [92.55492401, 22.42523956], [92.55505371, 22.42734146], [92.55450439, 22.42714119], [92.55331421, 22.42671204], [92.55220795, 22.42693901], [92.55124664, 22.42761803], [92.55188751, 22.42851257], [92.55345917, 22.42753601], [92.55464935, 22.428442], [92.55531311, 22.42894554], [92.5548172, 22.43283463], [92.5534668, 22.43397331], [92.55435944, 22.43630981], [92.55177307, 22.43788338], [92.55262756, 22.43856812], [92.55142975, 22.44077682], [92.55208588, 22.44241714], [92.55036163, 22.44326019], [92.54953766, 22.44365883], [92.54987335, 22.44485092], [92.55095673, 22.44581413], [92.55146027, 22.44626617], [92.55105591, 22.44675446], [92.55007172, 22.44794083], [92.55146027, 22.44857597], [92.55045319, 22.45127678], [92.55066681, 22.45268822], [92.55097198, 22.45465279], [92.54930115, 22.45546722], [92.54871368, 22.45615005], [92.54825592, 22.45668221], [92.54916382, 22.45653915], [92.54972076, 22.45644951], [92.5502243, 22.45714188], [92.55002594, 22.45718002], [92.54836273, 22.45750618], [92.5485611, 22.45824432], [92.54940796, 22.45851898], [92.54814911, 22.46077538], [92.5477829, 22.46143723], [92.54724121, 22.46182823], [92.54637909, 22.46245193], [92.54652405, 22.46307945], [92.54686737, 22.46459007], [92.54800415, 22.46555901], [92.54647064, 22.46657753], [92.54579926, 22.46865273], [92.54576111, 22.47092247], [92.5461731, 22.47359848], [92.5472641, 22.47473335], [92.54755402, 22.47600746], [92.54694366, 22.47667885], [92.54679108, 22.47771454], [92.54614258, 22.4787159], [92.54537201, 22.48005104], [92.54553223, 22.48116302], [92.5456543, 22.48293495], [92.54532623, 22.48302269], [92.54433441, 22.48328781], [92.54524231, 22.48643684], [92.5459137, 22.48689079], [92.54542542, 22.48785019], [92.54613495, 22.48886871], [92.54421234, 22.48973465], [92.54327393, 22.49015808], [92.5438385, 22.49145699], [92.54414368, 22.49216461], [92.54364777, 22.49269676], [92.54320526, 22.49317169], [92.54390717, 22.49476814], [92.54612732, 22.49520302], [92.54680634, 22.49533463], [92.54823303, 22.49592781], [92.54920959, 22.49574661], [92.54956818, 22.49672318], [92.54957581, 22.4983387], [92.54892731, 22.49838638], [92.54590607, 22.49825668], [92.54325867, 22.49825859], [92.54319, 22.49828911], [92.54261017, 22.49853897], [92.54264832, 22.49957657], [92.54322815, 22.50051689], [92.54379272, 22.50046158], [92.54478455, 22.49973488], [92.54494476, 22.49961662], [92.5456543, 22.49960709], [92.54631805, 22.50018311], [92.54658508, 22.5009079], [92.54675293, 22.50137138], [92.54708862, 22.50172615], [92.54784393, 22.50159073], [92.5486145, 22.50119019], [92.5487442, 22.50111961], [92.54915619, 22.50130653], [92.54923248, 22.50146484], [92.54940796, 22.50183487], [92.54949188, 22.50271606], [92.54918671, 22.50281334], [92.5490799, 22.50284576], [92.54754639, 22.50309372], [92.54724884, 22.50336838], [92.54714966, 22.50345993], [92.54701233, 22.50376892], [92.54774475, 22.50454712], [92.54785156, 22.50466919], [92.54824829, 22.50596237], [92.54827881, 22.50605202], [92.54811859, 22.5068512], [92.54805756, 22.50716591], [92.54826355, 22.50752449], [92.54872894, 22.50765038], [92.54922485, 22.50712395], [92.55017853, 22.50678635], [92.55003357, 22.50821495], [92.54993439, 22.50980949], [92.55005646, 22.51007462], [92.54924774, 22.5098877], [92.54885101, 22.50979805], [92.54727936, 22.50979614], [92.54670715, 22.50990677], [92.54649353, 22.50995064], [92.54650116, 22.51036835], [92.54669189, 22.51068115], [92.54826355, 22.51134682], [92.54953003, 22.51174355], [92.55056763, 22.51226234], [92.55078125, 22.51252556], [92.55102539, 22.51282501], [92.55117035, 22.5130024], [92.55117798, 22.51373291], [92.55104065, 22.51382256], [92.5500946, 22.51444626], [92.54934692, 22.51458168], [92.54771423, 22.51488113], [92.54737091, 22.51499557], [92.54693604, 22.51514244], [92.54668427, 22.51566315], [92.54681396, 22.51696014], [92.54655457, 22.51704788], [92.54612732, 22.51680183], [92.54559326, 22.51524734], [92.54496765, 22.51369286], [92.54405212, 22.5133667], [92.543396, 22.51393318], [92.54330444, 22.51401138], [92.54312134, 22.51455116], [92.54341125, 22.51568794], [92.54380798, 22.51645851], [92.5448761, 22.51708794], [92.54547119, 22.51743889], [92.54538727, 22.51805115], [92.54530334, 22.51861954], [92.54471588, 22.51984787], [92.54384613, 22.52149582], [92.54317474, 22.52165031], [92.54211426, 22.52150345], [92.54177094, 22.52160072], [92.54153442, 22.52217293], [92.54149628, 22.52227402], [92.54128265, 22.52309608], [92.54155731, 22.52409172], [92.54222107, 22.52465439], [92.54333496, 22.52487755], [92.54364777, 22.5249424], [92.54042816, 22.52603149], [92.54032898, 22.52628136], [92.54092407, 22.52713585], [92.54112244, 22.52742195], [92.54085541, 22.5277729], [92.53944397, 22.52859879], [92.53910828, 22.52906799], [92.53899384, 22.52927208], [92.53936005, 22.52949333], [92.53994751, 22.52964592], [92.54122925, 22.5296669], [92.54131317, 22.53014755], [92.54109955, 22.53069305], [92.54090118, 22.53117752], [92.54058075, 22.53196526], [92.54068756, 22.53281212], [92.54103088, 22.5330925], [92.54136658, 22.53336143], [92.54146576, 22.53372955], [92.54127502, 22.53396797], [92.5408783, 22.53446579], [92.54057312, 22.53486061], [92.53918457, 22.5342083], [92.53896332, 22.5341053], [92.53871155, 22.53425217], [92.53833771, 22.53521538], [92.53840637, 22.53575516], [92.5388031, 22.53639793], [92.53953552, 22.53696632], [92.53981781, 22.53718567], [92.53942108, 22.5378685], [92.53903961, 22.53853607], [92.53967285, 22.54045105], [92.53981018, 22.54085922], [92.53918457, 22.54130363], [92.53820038, 22.54151344], [92.53755188, 22.54177856], [92.53694153, 22.54202461], [92.53688812, 22.54260445], [92.5371933, 22.54374504], [92.53723145, 22.54434013], [92.53701782, 22.54494286], [92.53688049, 22.54532814], [92.53627014, 22.54530907], [92.53529358, 22.54503059], [92.53405762, 22.5443058], [92.53154755, 22.54525948], [92.53096008, 22.54615593], [92.53134918, 22.54809761], [92.53219604, 22.55027962], [92.53201294, 22.55169487], [92.53195953, 22.55210304], [92.53164673, 22.55283356], [92.53010559, 22.55547523], [92.52766418, 22.55721474], [92.52607727, 22.55777931], [92.52548218, 22.55780411], [92.52416992, 22.55786324], [92.52315521, 22.5586071], [92.52248383, 22.5590992], [92.52177429, 22.56025124], [92.52392578, 22.56116104], [92.52788544, 22.56571198], [92.52787018, 22.56581688], [92.52768707, 22.56732178], [92.52729034, 22.57006454], [92.52695465, 22.57255173], [92.52714539, 22.57286072], [92.52737427, 22.57323265], [92.5293045, 22.57331848], [92.53063965, 22.57292747], [92.53245544, 22.57165527], [92.53327179, 22.57218742], [92.53358459, 22.57239151], [92.53372955, 22.57498932], [92.53449249, 22.57538033], [92.53505707, 22.57519913], [92.53575134, 22.57568932], [92.5368576, 22.57517052], [92.53808594, 22.57535934], [92.53807831, 22.57701874], [92.53645325, 22.57881355], [92.53638458, 22.57888985], [92.53643799, 22.57894897], [92.53729248, 22.57990646], [92.537323, 22.58047485], [92.53743744, 22.58246231], [92.5373764, 22.58279991], [92.53704071, 22.58477974], [92.53723907, 22.58496666], [92.53838348, 22.58603668], [92.53741455, 22.58633423], [92.5366745, 22.58573151], [92.53625488, 22.58538818], [92.53448486, 22.58517265], [92.53440857, 22.58522415], [92.53314972, 22.58604813], [92.53250122, 22.5867424], [92.53250122, 22.58704185], [92.53247833, 22.58792114], [92.53292084, 22.58827591], [92.53329468, 22.58857918], [92.53572845, 22.58670235], [92.53700256, 22.58779907], [92.5389328, 22.58945465], [92.53916931, 22.58965302], [92.53865814, 22.58964157], [92.53765106, 22.58962059], [92.53607178, 22.58958626], [92.53484344, 22.59163094], [92.53476715, 22.59175491], [92.53704834, 22.59318733], [92.53757477, 22.59352112], [92.53721619, 22.59401131], [92.53585052, 22.59586334], [92.53572083, 22.59763908], [92.53497314, 22.59885025], [92.53512573, 22.59925079], [92.53540039, 22.59999847], [92.53205872, 22.60233498], [92.53049469, 22.60342979], [92.53043365, 22.60409164], [92.5302887, 22.60569382], [92.5300293, 22.6084919], [92.529953, 22.60938263], [92.53322601, 22.60758972], [92.53423309, 22.60845184], [92.53479004, 22.60892487], [92.53482056, 22.60913658], [92.53504944, 22.61061478], [92.53521729, 22.61184692], [92.53208923, 22.61182022], [92.52946472, 22.61450958], [92.52909851, 22.61510468], [92.52879333, 22.61560631], [92.52861786, 22.61588669], [92.52849579, 22.61673737], [92.52873993, 22.61836624], [92.52950287, 22.61969185], [92.52988434, 22.62041664], [92.53000641, 22.62064934], [92.52935791, 22.62091446], [92.52774811, 22.62097359], [92.52748108, 22.62098312], [92.52745819, 22.6215744], [92.52837372, 22.62346268], [92.52894592, 22.62432289], [92.52981567, 22.62564659], [92.53255463, 22.62770271], [92.53220367, 22.62908745], [92.5318985, 22.63027382], [92.53222656, 22.63208389], [92.53224945, 22.63254738], [92.53227234, 22.63332176], [92.53219604, 22.63332558], [92.52980042, 22.63344002], [92.52626801, 22.63360977], [92.52627563, 22.63468933], [92.52627563, 22.63479042], [92.52771759, 22.63573265], [92.52787781, 22.63583565], [92.52763367, 22.63604546], [92.5265274, 22.63698959], [92.52639771, 22.63767815], [92.52663422, 22.63890457], [92.52675629, 22.63952827], [92.52667999, 22.63987541], [92.52503204, 22.63997269], [92.52479553, 22.64029884], [92.52448273, 22.64073181], [92.52457428, 22.64273071], [92.52470398, 22.64338493], [92.5250473, 22.64515686], [92.52446747, 22.6471653], [92.52417755, 22.64937782], [92.52458954, 22.65071106], [92.52481842, 22.6509285], [92.52510071, 22.65118599], [92.52696228, 22.6507988], [92.5271225, 22.65076637], [92.52648163, 22.65421104], [92.5244751, 22.65398216], [92.52348328, 22.6554203], [92.5242157, 22.65909004], [92.52423096, 22.65917969], [92.52433014, 22.65917015], [92.52603149, 22.65902328], [92.52720642, 22.65892029], [92.52823639, 22.65913582], [92.52842712, 22.65937233], [92.52867889, 22.6597023], [92.52840424, 22.6601429], [92.5265274, 22.66044044], [92.52697754, 22.66161728], [92.52829742, 22.66506958], [92.52842712, 22.66541862], [92.52856445, 22.66577148], [92.52799988, 22.66560364], [92.52632141, 22.66510201], [92.52548981, 22.67169762], [92.52547455, 22.67182922], [92.52584076, 22.67271614], [92.52598572, 22.67305756], [92.5247345, 22.67361641], [92.52276611, 22.67398071], [92.5226059, 22.67400932], [92.52246094, 22.67445755], [92.5223999, 22.67464447], [92.52220917, 22.67523575], [92.52233887, 22.67563438], [92.52287292, 22.6773243], [92.5231781, 22.67925835], [92.52172089, 22.68180275], [92.52112579, 22.68251228], [92.52108002, 22.68257332], [92.52113342, 22.68334961], [92.52119446, 22.68418884], [92.52019501, 22.68577003], [92.51880646, 22.68796349], [92.51880646, 22.68814659], [92.51872253, 22.69352913], [92.51740265, 22.69838905], [92.51637268, 22.70459938], [92.51526642, 22.70736122], [92.5147171, 22.70750809], [92.51435852, 22.70760536], [92.51428986, 22.70775795], [92.51376343, 22.70893288], [92.51409912, 22.71047592], [92.51504517, 22.71169853], [92.51567078, 22.71281242], [92.5150528, 22.71443939], [92.5134201, 22.71931076], [92.51052856, 22.72492981], [92.50717926, 22.73236847], [92.50434113, 22.73554039], [92.50589752, 22.73576927], [92.50792694, 22.73608017], [92.50773621, 22.73688316], [92.5071106, 22.73752594], [92.50531769, 22.73936081], [92.50510406, 22.73958015], [92.50444031, 22.73909378], [92.50242615, 22.73762131], [92.50209808, 22.73766708], [92.49937439, 22.73803902], [92.49795532, 22.73997116], [92.4957962, 22.7400589], [92.49425507, 22.74011993], [92.49421692, 22.74042511], [92.493927, 22.74276733], [92.49100494, 22.74129486], [92.49034119, 22.74475098], [92.49015808, 22.74568176], [92.48819733, 22.74658394], [92.48218536, 22.74720192], [92.48016357, 22.74657822], [92.47649384, 22.74544525], [92.47463989, 22.74583244], [92.47386932, 22.74634933], [92.47399902, 22.74708176], [92.47584534, 22.74865913], [92.47775269, 22.75055122], [92.47868347, 22.75147438], [92.47935486, 22.75392151], [92.478302, 22.75408745], [92.47698975, 22.75429344], [92.47610474, 22.75681114], [92.47637177, 22.75698853], [92.47737122, 22.75787926], [92.4765625, 22.75979233], [92.47623444, 22.75985909], [92.47545624, 22.7600174], [92.47377014, 22.759552], [92.4744873, 22.76100349], [92.47626495, 22.76462555], [92.47525787, 22.76520157], [92.47429657, 22.7650528], [92.47297668, 22.76484871], [92.47279358, 22.76528358], [92.47319794, 22.76664162], [92.47373962, 22.76775742], [92.47389984, 22.76809311], [92.4756012, 22.77088737], [92.47521973, 22.77323532], [92.47431946, 22.77446938], [92.47357178, 22.77550125], [92.47263336, 22.77638817], [92.47242737, 22.7817421], [92.47200012, 22.78272438], [92.47151184, 22.78383827], [92.47012329, 22.78275299], [92.4693222, 22.78212738], [92.46930695, 22.78718948], [92.47061157, 22.78951836], [92.47116852, 22.79432869], [92.47221375, 22.79575539], [92.47120667, 22.79807663], [92.47013092, 22.79868317], [92.46755981, 22.80013084], [92.467453, 22.80029488], [92.46501923, 22.80403519], [92.46474457, 22.80445671], [92.46525574, 22.80526161], [92.46679688, 22.80768204], [92.46655273, 22.80887604], [92.46461487, 22.81093597], [92.46315765, 22.8119545], [92.46243286, 22.8113327], [92.46264648, 22.80761337], [92.46193695, 22.80739021], [92.46135712, 22.80720711], [92.46028137, 22.81274796], [92.45829773, 22.81728363], [92.458992, 22.81865883], [92.45864105, 22.81919861], [92.45858002, 22.81930161], [92.4584198, 22.81929016], [92.45420074, 22.81900597], [92.45401001, 22.82018471], [92.45507813, 22.82125092], [92.45661926, 22.82217598], [92.4575119, 22.82279015], [92.45748901, 22.82298851], [92.45812225, 22.82321358], [92.45782471, 22.82406044], [92.45576477, 22.82495117], [92.45517731, 22.82575798], [92.45567322, 22.82605171], [92.45727539, 22.82700157], [92.45950317, 22.82885361], [92.46021271, 22.82944298], [92.46180725, 22.83077049], [92.46154022, 22.83106995], [92.45960236, 22.83327675], [92.45736694, 22.83798027], [92.45281219, 22.84198189], [92.45263672, 22.84273911], [92.45324707, 22.84346008], [92.45391846, 22.84320259], [92.45506287, 22.84276772], [92.45769501, 22.84098816], [92.45832062, 22.84102821], [92.4575119, 22.84173012], [92.46125031, 22.84339142], [92.46313477, 22.84255409], [92.46343231, 22.84291077], [92.45832062, 22.8454361], [92.45926666, 22.84603882], [92.458992, 22.84784317], [92.45996857, 22.85055161], [92.45672607, 22.85058212], [92.45802307, 22.85295486], [92.45870209, 22.85277939], [92.45962524, 22.85254097], [92.46121216, 22.85213089], [92.46323395, 22.85292053], [92.46336365, 22.85313606], [92.46430969, 22.85473633], [92.46308136, 22.85615158], [92.46286011, 22.85632133], [92.46008301, 22.85774803], [92.45951843, 22.85845184], [92.46006775, 22.85941696], [92.46165466, 22.86080551], [92.4618454, 22.86097527], [92.46192932, 22.86105156], [92.46115875, 22.8616848], [92.46060181, 22.8616066], [92.4566803, 22.8610611], [92.45594025, 22.8609581], [92.45329285, 22.86133385], [92.45212555, 22.86300468], [92.4519043, 22.86507416], [92.45367432, 22.86756134], [92.45392609, 22.86846542], [92.45495605, 22.87015724], [92.45606232, 22.87036896], [92.45721436, 22.87029648], [92.4574585, 22.87046814], [92.45826721, 22.87195969], [92.4569397, 22.87313843], [92.45629883, 22.87337685], [92.45140076, 22.87540245], [92.44927979, 22.87648392], [92.44821167, 22.87702751], [92.44818878, 22.87752342], [92.44825745, 22.87777138], [92.44837952, 22.87821388], [92.4486618, 22.88246918], [92.44953156, 22.88587189], [92.44837189, 22.88669014], [92.44789886, 22.89056969], [92.44753265, 22.89359093], [92.44552612, 22.89489365], [92.44521332, 22.89509964], [92.44507599, 22.89495659], [92.4432373, 22.89307022], [92.44193268, 22.89158058], [92.44168091, 22.89116478], [92.44113159, 22.89027023], [92.44082642, 22.88957024], [92.44039917, 22.88858032], [92.43940735, 22.88689041], [92.43829346, 22.8867054], [92.43784332, 22.8866291], [92.43765259, 22.88667107], [92.43726349, 22.88675499], [92.43649292, 22.88589859], [92.4363327, 22.88554955], [92.43621826, 22.88559723], [92.43418121, 22.8856678], [92.43404388, 22.88579369], [92.43302155, 22.88671875], [92.43304443, 22.88687325], [92.43289948, 22.88693047], [92.43071747, 22.88972092], [92.4309082, 22.89382935], [92.42750549, 22.89639473], [92.42641449, 22.8972187], [92.42355347, 22.90264511], [92.42341614, 22.9029026], [92.42118073, 22.90753555], [92.42092896, 22.90806389], [92.420784, 22.90893555], [92.41876221, 22.91296005], [92.42037964, 22.91719055], [92.42050171, 22.91745186], [92.42006683, 22.9186306], [92.41927338, 22.91935539], [92.41849518, 22.91875648], [92.41602325, 22.91576195], [92.41508484, 22.91462898], [92.41226196, 22.91378593], [92.41168213, 22.91388702], [92.40975189, 22.91537285], [92.40874481, 22.91623116], [92.40715027, 22.91605949], [92.40563202, 22.91609955], [92.40441132, 22.91653061], [92.4040451, 22.91702652], [92.40392303, 22.91719055], [92.40354156, 22.91773224], [92.40345764, 22.91697121], [92.4032135, 22.91476059], [92.40312958, 22.91398239], [92.40259552, 22.91228867], [92.40133667, 22.91199875], [92.40055084, 22.91270256], [92.39854431, 22.91451454], [92.3974762, 22.91771126], [92.3972702, 22.91833496], [92.39868164, 22.92036057], [92.39907837, 22.92092896], [92.40114594, 22.92402458], [92.40068054, 22.92471695], [92.40047455, 22.92499733], [92.3999176, 22.92576218], [92.39782715, 22.92943001], [92.39606476, 22.93039322], [92.39498901, 22.93065834], [92.39363098, 22.93075943], [92.39279175, 22.93082047], [92.39078522, 22.93058968], [92.38974762, 22.93016624], [92.38919067, 22.92993927], [92.38576508, 22.92943001], [92.38516235, 22.92934036], [92.38354492, 22.92925453], [92.38144684, 22.92914581], [92.38057709, 22.92937469], [92.37986755, 22.92956161], [92.37930298, 22.92942619], [92.37647247, 22.92875862], [92.37623596, 22.92942429], [92.37620544, 22.92951584], [92.3761673, 22.93039894], [92.37731171, 22.93175125], [92.3757782, 22.9337616], [92.37542725, 22.93488121], [92.37541199, 22.93526649], [92.37471771, 22.93503952], [92.37290955, 22.93477249], [92.37197113, 22.9358902], [92.3717041, 22.93621254], [92.37197113, 22.93626213], [92.37477875, 22.93677521], [92.37506104, 22.93682671], [92.37534332, 22.9368782], [92.37532806, 22.93731117], [92.37534332, 22.93741798], [92.37269592, 22.94020081], [92.37316895, 22.9411068], [92.37347412, 22.94169044], [92.37343597, 22.94388008], [92.37458038, 22.94635391], [92.37468719, 22.94757462], [92.37567139, 22.94758224], [92.37582397, 22.94714928], [92.37683868, 22.94735527], [92.37713623, 22.94795036], [92.37741089, 22.94850159], [92.37630463, 22.94956207], [92.3757019, 22.95014191], [92.37632751, 22.9506073], [92.37788391, 22.95177269], [92.37757874, 22.95532799], [92.37670135, 22.95582199], [92.37622833, 22.95500183], [92.37545776, 22.9536705], [92.3743515, 22.95331001], [92.37475586, 22.95662117], [92.37278748, 22.95853806], [92.37483978, 22.95908356], [92.37713623, 22.95969391], [92.37669373, 22.96022224], [92.37475586, 22.96102715], [92.37397766, 22.96134949], [92.37395477, 22.96208572], [92.37472534, 22.9628582], [92.37538147, 22.96352196], [92.37445068, 22.96518898], [92.37482452, 22.96674347], [92.37431335, 22.97010422], [92.37562561, 22.97268295], [92.37730408, 22.97428131], [92.37760162, 22.97530365], [92.37823486, 22.97701645], [92.37915039, 22.977108], [92.37941742, 22.97577667], [92.37967682, 22.97696114], [92.38012695, 22.97962379], [92.37987518, 22.97968864], [92.37947083, 22.97984314], [92.37911224, 22.97989082], [92.37947845, 22.98114014], [92.38010406, 22.98204231], [92.38111877, 22.98265076], [92.383461, 22.98549843], [92.38485718, 22.98648071], [92.38473511, 22.98688507], [92.38430023, 22.98703575], [92.38332367, 22.98674393], [92.3825531, 22.98712349], [92.38239288, 22.9872303], [92.3819809, 22.98749733], [92.38217163, 22.98839188], [92.38218689, 22.98849869], [92.38223267, 22.98890305], [92.38231659, 22.98970413], [92.38246155, 22.99040413], [92.38269043, 22.99099541], [92.38308716, 22.99135208], [92.38333893, 22.99155807], [92.38399506, 22.99188805], [92.38414764, 22.99204254], [92.38498688, 22.99287415], [92.38478088, 22.99336624], [92.38409424, 22.99433899], [92.38382721, 22.99508286], [92.38326263, 22.99665642], [92.38272858, 22.99795341], [92.38257599, 22.99814415], [92.382164, 22.9986248], [92.38211823, 23.00020218], [92.38187408, 23.00113106], [92.38219452, 23.00173759], [92.38240051, 23.00178146], [92.38290405, 23.00189018], [92.38337708, 23.00321198], [92.38367462, 23.00416374], [92.38393402, 23.00567055], [92.38383484, 23.00649834], [92.38378906, 23.00684547], [92.38333893, 23.00801277], [92.38304901, 23.00875664], [92.38343811, 23.008955], [92.38446045, 23.00947762], [92.38407898, 23.01013565], [92.38313293, 23.0104332], [92.3822403, 23.01052094], [92.38191986, 23.01055336], [92.38121796, 23.01062202], [92.38004303, 23.01099586], [92.37960815, 23.01194], [92.37957764, 23.0120163], [92.37953186, 23.01211166], [92.37961578, 23.01221085], [92.38045502, 23.01317024], [92.38011932, 23.01440811], [92.38008881, 23.01451302], [92.38014221, 23.0162468], [92.38054657, 23.01736259], [92.38168335, 23.01945686], [92.38173676, 23.0206871], [92.38191223, 23.02112961], [92.38239288, 23.02191353], [92.38309479, 23.02272034], [92.38337708, 23.02309418], [92.38354492, 23.02332306], [92.38314056, 23.02401733], [92.3829422, 23.02435684], [92.38301086, 23.02452278], [92.38337708, 23.02539825], [92.38330078, 23.02598953], [92.38323975, 23.02641678], [92.3839035, 23.02680206], [92.38476563, 23.02729988], [92.38419342, 23.02926636], [92.38328552, 23.03053856], [92.38297272, 23.03097916], [92.38298035, 23.03199577], [92.38298035, 23.03246498], [92.38262177, 23.03290939], [92.38227081, 23.03333664], [92.38249207, 23.03380775], [92.3829422, 23.03476143], [92.38305664, 23.03608131], [92.38336945, 23.03679466], [92.38353729, 23.03785706], [92.38609314, 23.0393486], [92.38789368, 23.03986549], [92.38749695, 23.04120255], [92.38745117, 23.04135704], [92.38755035, 23.0418911], [92.38808441, 23.04469872], [92.38903046, 23.04578209], [92.38931274, 23.04738617], [92.38895416, 23.04787445], [92.38830566, 23.04876709], [92.38838196, 23.04924393], [92.38907623, 23.04920959], [92.39086914, 23.04911995], [92.39110565, 23.04964447], [92.39097595, 23.04982185], [92.38973236, 23.05154991], [92.39001465, 23.05208206], [92.39104462, 23.05202293], [92.39141846, 23.05295753], [92.39176178, 23.05343437], [92.3921051, 23.05390358], [92.39067078, 23.05475426], [92.39055634, 23.0549736], [92.3903656, 23.05534554], [92.39053345, 23.05545044], [92.39225006, 23.0565033], [92.39156342, 23.05808258], [92.3903656, 23.06072998], [92.38873291, 23.06099701], [92.38827515, 23.06106949], [92.38726807, 23.06201172], [92.38706207, 23.06272507], [92.3879776, 23.06392479], [92.38813782, 23.06410599], [92.38866425, 23.0646801], [92.38777924, 23.06530762], [92.38712311, 23.0657711], [92.38736725, 23.0666523], [92.38744354, 23.06692314], [92.38725281, 23.06703758], [92.38532257, 23.06819725], [92.3848877, 23.06959152], [92.38458252, 23.06998825], [92.38284302, 23.07226944], [92.38280487, 23.07304573], [92.38467407, 23.07411194], [92.38478851, 23.07417679], [92.38513184, 23.07589722], [92.38542175, 23.07689857], [92.38459778, 23.07818413], [92.38284302, 23.07953453], [92.38174438, 23.08007431], [92.38148499, 23.08015633], [92.38098145, 23.08031845], [92.3804245, 23.0810051], [92.3802948, 23.08164215], [92.38062286, 23.08252907], [92.37917328, 23.08376694], [92.37923431, 23.08442688], [92.37986755, 23.08498192], [92.38034821, 23.08539963], [92.38000488, 23.08628845], [92.37910461, 23.08711243], [92.37796021, 23.08723068], [92.37784576, 23.08722687], [92.37705231, 23.08718872], [92.37663269, 23.08669281], [92.37673187, 23.08525276], [92.37575531, 23.08460999], [92.37502289, 23.08466339], [92.37445831, 23.08551407], [92.37389374, 23.08643341], [92.37364197, 23.08668327], [92.37337494, 23.08696175], [92.37329865, 23.08695412], [92.37243652, 23.08686256], [92.37246704, 23.08718681], [92.37256622, 23.08816338], [92.3722229, 23.0883007], [92.37171936, 23.08850098], [92.37123108, 23.08902168], [92.37096405, 23.08973312], [92.37046051, 23.09105682], [92.3704071, 23.09214783], [92.37039948, 23.09224701], [92.37026978, 23.09240723], [92.36975861, 23.09304237], [92.36953735, 23.09372711], [92.36923218, 23.09467697], [92.36903381, 23.09519386], [92.36999512, 23.09621811], [92.36976624, 23.09683228], [92.36882019, 23.09659767], [92.36689758, 23.09612083], [92.36588287, 23.09708977], [92.36503601, 23.0979023], [92.36417389, 23.09809113], [92.36366272, 23.09784317], [92.36297607, 23.09751511], [92.36207581, 23.09837341], [92.36121368, 23.0985527], [92.36165619, 23.10017395], [92.36174011, 23.10049248], [92.36157227, 23.10056114], [92.35970306, 23.1013279], [92.36068726, 23.10160828], [92.35951233, 23.10306549], [92.35813904, 23.10303879], [92.35786438, 23.10353088], [92.35900879, 23.10430336], [92.35916901, 23.10440826], [92.35988617, 23.10520554], [92.35990143, 23.10624695], [92.35849762, 23.10592651], [92.35821533, 23.10586166], [92.35826874, 23.10604286], [92.35895538, 23.10821152], [92.36034393, 23.11050034], [92.36094666, 23.11252022], [92.36036682, 23.11290169], [92.3604126, 23.11326408], [92.36050415, 23.11336327], [92.36260223, 23.11546707], [92.36264038, 23.11607742], [92.36290741, 23.11692238], [92.36237335, 23.11745834], [92.36231232, 23.11751938], [92.36238098, 23.11778259], [92.36269379, 23.11803818], [92.36460114, 23.11958694], [92.36377716, 23.12034416], [92.36480713, 23.12091255], [92.36644745, 23.1225605], [92.3666153, 23.12320328], [92.36621094, 23.123909], [92.36592102, 23.12442017], [92.36621857, 23.12511635], [92.36682892, 23.12520981], [92.36714935, 23.12525749], [92.36790466, 23.12710381], [92.3680191, 23.12753868], [92.36561584, 23.12715912], [92.3655014, 23.12719727], [92.36501312, 23.12851524], [92.36290741, 23.13040733], [92.36184692, 23.13125229], [92.36219788, 23.13066673], [92.36131287, 23.13121986], [92.36022186, 23.13169098], [92.3586731, 23.13320351], [92.35868835, 23.13383865], [92.35767365, 23.13458252], [92.35681915, 23.13426781], [92.35738373, 23.13565254], [92.3571701, 23.13611412], [92.35704041, 23.1363945], [92.35718536, 23.13698578], [92.35744476, 23.13698196], [92.35790253, 23.13697433], [92.35852051, 23.13873863], [92.3587265, 23.14049149], [92.3588028, 23.14111328], [92.3595047, 23.14135551], [92.35982513, 23.14146805], [92.35988617, 23.14284515], [92.35962677, 23.14307785], [92.35940552, 23.14326668], [92.35961151, 23.14424515], [92.36022186, 23.14475822], [92.36083221, 23.14526558], [92.36053467, 23.14609718], [92.35997009, 23.14697266], [92.35874176, 23.14634895], [92.35834503, 23.14614868], [92.35810852, 23.14660835], [92.35936737, 23.14811516], [92.3596344, 23.14838219], [92.36027527, 23.14904022], [92.36022186, 23.14968491], [92.35985565, 23.14994431], [92.35967255, 23.15007401], [92.36030579, 23.1506176], [92.36076355, 23.15101433], [92.36036682, 23.15201759], [92.3602066, 23.15241051], [92.36039734, 23.1531353], [92.36138153, 23.15305901], [92.36205292, 23.15300751], [92.36158752, 23.1536274], [92.36128998, 23.15403557], [92.36158752, 23.15556717], [92.36199188, 23.15569305], [92.36200714, 23.15655136], [92.36345673, 23.15655518], [92.36412811, 23.15655708], [92.36289215, 23.15857697], [92.36257935, 23.16034889], [92.36158752, 23.16143608], [92.3608017, 23.16229439], [92.36235809, 23.16505051], [92.36138916, 23.16697502], [92.36141968, 23.16772652], [92.35871124, 23.16883659], [92.35814667, 23.17059708], [92.35775757, 23.17134666], [92.35752106, 23.17178726], [92.35733032, 23.17407036], [92.35649109, 23.1761322], [92.35649109, 23.17710686], [92.35669708, 23.17741966], [92.35713196, 23.17807007], [92.35616302, 23.17833328], [92.35437775, 23.17881966], [92.35532379, 23.17958641], [92.35546112, 23.17970085], [92.35548401, 23.18012428], [92.35549164, 23.18025398], [92.35746002, 23.17978287], [92.35795593, 23.17989159], [92.35952759, 23.18023491], [92.3598175, 23.18029785], [92.36083984, 23.18024635], [92.36063385, 23.18115807], [92.3611145, 23.18279457], [92.36011505, 23.18271255], [92.36032867, 23.183815], [92.3591156, 23.18427277], [92.3584137, 23.18448257], [92.358284, 23.18516159], [92.35732269, 23.18507957], [92.3559494, 23.18541527], [92.35606384, 23.18495178], [92.35395813, 23.1847477], [92.35424805, 23.18575859], [92.35331726, 23.18585587], [92.35379028, 23.18733406], [92.3537674, 23.18836784], [92.35312653, 23.18898964], [92.35411835, 23.19025993], [92.3535614, 23.19088936], [92.35342407, 23.19155312], [92.35281372, 23.19209862], [92.35323334, 23.19314194], [92.35294342, 23.19424438], [92.35280609, 23.19423485], [92.35240936, 23.19420433], [92.35254669, 23.19459724], [92.35218811, 23.19477654], [92.35279846, 23.19500732], [92.35274506, 23.19590759], [92.35289764, 23.19611168], [92.35325623, 23.19659233], [92.35427094, 23.19722748], [92.35413361, 23.19818878], [92.35464478, 23.19925308], [92.35314178, 23.19982338], [92.35485077, 23.2003231], [92.35362244, 23.20182228], [92.3539505, 23.20240402], [92.35358429, 23.20279121], [92.35316467, 23.20324135], [92.35348511, 23.20330048], [92.35399628, 23.20339394], [92.35406494, 23.20421791], [92.35340118, 23.2043457], [92.35332489, 23.2048912], [92.35314178, 23.20497894], [92.3527832, 23.2051487], [92.35308838, 23.20529366], [92.35340881, 23.20544243], [92.353302, 23.20567513], [92.35325623, 23.20577621], [92.35334778, 23.20616341], [92.35241699, 23.20639229], [92.35343933, 23.20674706], [92.35362244, 23.20724869], [92.35427094, 23.2072525], [92.35437775, 23.2072525], [92.35455322, 23.20661354], [92.35506439, 23.20696831], [92.35418701, 23.20918846], [92.35404205, 23.20954514], [92.35379028, 23.21025085], [92.35372925, 23.21615791], [92.35333252, 23.22132492], [92.35332489, 23.22351456], [92.35334778, 23.22429848], [92.35312653, 23.22473526], [92.35137177, 23.22817039], [92.35118866, 23.22905159], [92.35083771, 23.23078156], [92.35081482, 23.23124695], [92.35071564, 23.23360634], [92.35068512, 23.23425293], [92.35043335, 23.23426628], [92.34873199, 23.23435783], [92.34738159, 23.23482132], [92.34671021, 23.23578835], [92.34996033, 23.23584938], [92.36125946, 23.23604012], [92.36109924, 23.23753738], [92.36251831, 23.23851967], [92.36437225, 23.23841858], [92.36795807, 23.23854828], [92.36934662, 23.23885727], [92.37264252, 23.23958588], [92.37316132, 23.23970032], [92.37631226, 23.23974991], [92.3782196, 23.23997116], [92.38342285, 23.23991013], [92.38484955, 23.23994064], [92.38620758, 23.24002266], [92.38684082, 23.24008179], [92.38928986, 23.24008942], [92.39029694, 23.24040985], [92.39154816, 23.24053001], [92.39260101, 23.24064255], [92.39756012, 23.24060059], [92.39839172, 23.24070358], [92.39933777, 23.24081993], [92.40022278, 23.24094009], [92.40337372, 23.24142838], [92.40245819, 23.2425499], [92.39958191, 23.24189568], [92.39697266, 23.24999237], [92.39563751, 23.25005722], [92.39743042, 23.25250435], [92.39838409, 23.25579071], [92.39440918, 23.25821304], [92.38951874, 23.25949287], [92.38935089, 23.26209641], [92.38922119, 23.26243019], [92.38834381, 23.26549911], [92.38860321, 23.26609612], [92.38871765, 23.26636124], [92.38947296, 23.26614189], [92.39021301, 23.26513672], [92.39051819, 23.26472092], [92.3918457, 23.26416016], [92.39338684, 23.26394463], [92.39458466, 23.26448631], [92.3942337, 23.26639175], [92.39362335, 23.2671032], [92.39186859, 23.27079201], [92.39009857, 23.27500916], [92.38924408, 23.27721214], [92.38904572, 23.27918053], [92.38852692, 23.28033829], [92.38799286, 23.28152847], [92.38668823, 23.28274536], [92.3860321, 23.28335381], [92.38472748, 23.28385353], [92.38425446, 23.28403282], [92.38092804, 23.28528023], [92.38182068, 23.28815651], [92.38227081, 23.2907505], [92.38278198, 23.29163361], [92.38318634, 23.2918663], [92.38437653, 23.29235268], [92.38450623, 23.29240608], [92.38451385, 23.2925415], [92.38452911, 23.2926693], [92.38247681, 23.29652786], [92.3833847, 23.29717445], [92.38440704, 23.29846954], [92.38284302, 23.30153465], [92.38298798, 23.30216026], [92.38482666, 23.30251694], [92.38574982, 23.30374146], [92.38568878, 23.30626106], [92.38511658, 23.30713844], [92.38381958, 23.30806732], [92.38289642, 23.30882645], [92.38061523, 23.30998039], [92.37611389, 23.31312943], [92.37722778, 23.31847763], [92.37688446, 23.3191452], [92.37619781, 23.3197155], [92.37615967, 23.3196106], [92.37557983, 23.31900978], [92.37532806, 23.31818962], [92.37451935, 23.31957817], [92.37380981, 23.31916618], [92.37342072, 23.31893921], [92.37253571, 23.31862259], [92.37190247, 23.31813812], [92.37145233, 23.31814575], [92.37086487, 23.31844521], [92.36968231, 23.32139587], [92.36945343, 23.32189941], [92.36895752, 23.32297707], [92.36784363, 23.32316208], [92.36704254, 23.32267952], [92.36842346, 23.31976509], [92.36872864, 23.31868172], [92.3687973, 23.31843758], [92.36857605, 23.31736755], [92.36795044, 23.31729507], [92.36606598, 23.32044983], [92.36443329, 23.32263947], [92.36425018, 23.32326317], [92.36466217, 23.32366943], [92.36564636, 23.32422256], [92.36815643, 23.325634], [92.3684082, 23.32619858], [92.36846924, 23.32633018], [92.3706665, 23.33034134], [92.37199402, 23.33180618], [92.37297821, 23.33379555], [92.37348938, 23.33500099], [92.3744812, 23.33688354], [92.37471008, 23.33803749], [92.37502289, 23.34050941], [92.37511444, 23.34267998], [92.37593079, 23.3468132], [92.37715149, 23.34844398], [92.37943268, 23.35001564], [92.38079071, 23.35168648], [92.38059998, 23.35379982], [92.3804245, 23.35573959], [92.38007355, 23.35611725], [92.37937927, 23.35625267], [92.37767029, 23.35677719], [92.37683105, 23.35671234], [92.37632751, 23.35675812], [92.37634277, 23.35732841], [92.37718964, 23.3580246], [92.37766266, 23.35875893], [92.37815857, 23.36019516], [92.37874603, 23.36138344], [92.37904358, 23.36210632], [92.37779236, 23.36309242], [92.37750244, 23.36318779], [92.37713623, 23.36372375], [92.37654877, 23.36439323], [92.37585449, 23.36510086], [92.3757782, 23.36527824], [92.37574005, 23.36554909], [92.37484741, 23.36566162], [92.37368011, 23.36571693], [92.37083435, 23.36585236], [92.36938477, 23.36709404], [92.36769867, 23.36688042], [92.36640167, 23.36738014], [92.36587524, 23.36766624], [92.36525726, 23.36696243], [92.36389923, 23.36625671], [92.36133575, 23.36696053], [92.35973358, 23.36826897], [92.35933685, 23.36870003], [92.35842133, 23.36969376], [92.35829926, 23.36971474], [92.35813904, 23.36973953], [92.35610962, 23.37274742], [92.35617065, 23.37332535], [92.35726929, 23.37475204], [92.35988617, 23.37572479], [92.3609848, 23.37711334], [92.36167908, 23.37777519], [92.36278534, 23.37816048], [92.36382294, 23.37847328], [92.36425018, 23.37900543], [92.36471558, 23.37952614], [92.36488342, 23.37971306], [92.36460114, 23.380373], [92.36431885, 23.38088417], [92.3637085, 23.38109779], [92.36332703, 23.38123322], [92.36192322, 23.38102722], [92.36136627, 23.38094521], [92.3605423, 23.38082504], [92.35878754, 23.38072968], [92.35715485, 23.38026237], [92.35604095, 23.37984657], [92.35584259, 23.37977219], [92.35372162, 23.38009644], [92.35277557, 23.38066483], [92.35256195, 23.38119698], [92.35277557, 23.38286209], [92.35404205, 23.38376617], [92.35540009, 23.38446999], [92.3560257, 23.38447762], [92.35661316, 23.38488007], [92.35659027, 23.38570595], [92.35581207, 23.38724709], [92.35578156, 23.38782692], [92.35614777, 23.38823318], [92.35676575, 23.38851166], [92.35707855, 23.38871384], [92.35790253, 23.38890648], [92.35837555, 23.39003181], [92.35871124, 23.39081764], [92.35852051, 23.39130211], [92.3579483, 23.39178848], [92.35715485, 23.3917923], [92.35614777, 23.39075279], [92.35567474, 23.3891983], [92.35490417, 23.38899612], [92.35478973, 23.38910103], [92.35440063, 23.38945961], [92.35413361, 23.39056206], [92.35377502, 23.39143562], [92.35371399, 23.39219666], [92.35349274, 23.39367104], [92.35372162, 23.39484024], [92.35360718, 23.39593697], [92.35355377, 23.39636993], [92.35346222, 23.39703178], [92.35317993, 23.39764023], [92.35292053, 23.39947891], [92.35308075, 23.40096283], [92.35305786, 23.40193748], [92.35273743, 23.40311623], [92.35286713, 23.40451813], [92.35294342, 23.40539932], [92.35381317, 23.40623665], [92.35417175, 23.40585899], [92.35433197, 23.40519524], [92.35479736, 23.40405655], [92.35487366, 23.40358543], [92.35495758, 23.40307808], [92.35501099, 23.40132713], [92.35534668, 23.40092468], [92.3558197, 23.40124702], [92.35683441, 23.40304756], [92.35721588, 23.40397453], [92.35780334, 23.40447617], [92.3580246, 23.40525818], [92.35812378, 23.4056282], [92.35781097, 23.40715981], [92.35730743, 23.41030693], [92.35734558, 23.41062164], [92.3571701, 23.41088867], [92.35547638, 23.41207314], [92.35480499, 23.41249657], [92.35422516, 23.41306877], [92.35247803, 23.41365051], [92.35150909, 23.41341972], [92.35089111, 23.41347122], [92.3483963, 23.41276932], [92.34776306, 23.41282082], [92.34751892, 23.41332054], [92.34785461, 23.41494942], [92.34816742, 23.41847038], [92.34803772, 23.41971207], [92.34725189, 23.42134857], [92.34729767, 23.42226982], [92.34767151, 23.42310524], [92.34790039, 23.42394829], [92.34786224, 23.42550087], [92.34755707, 23.42637062], [92.34719086, 23.42691231], [92.34648132, 23.42788124], [92.34630585, 23.42860031], [92.34648132, 23.42943382], [92.34682465, 23.43026352], [92.34748077, 23.43115044], [92.34714508, 23.43240929], [92.34645844, 23.43311882], [92.34626007, 23.43341064], [92.34555054, 23.43366241], [92.34527588, 23.43368149], [92.34455109, 23.43372917], [92.34409332, 23.43340683], [92.34303284, 23.43408394], [92.34233093, 23.43500519], [92.34225464, 23.43558311], [92.34198761, 23.43567085], [92.34159088, 23.43571854], [92.34000397, 23.43475342], [92.33985901, 23.43452454], [92.33946991, 23.43389702], [92.33840942, 23.4321785], [92.33781433, 23.43194008], [92.33746338, 23.43209457], [92.33725739, 23.43229675], [92.33603668, 23.43347359], [92.33559418, 23.43362999], [92.33544922, 23.43323517], [92.33522797, 23.43095016], [92.33535004, 23.43032837], [92.3351593, 23.4295063], [92.3350296, 23.42866516], [92.3346405, 23.42840004], [92.33395386, 23.42860031], [92.33346558, 23.42900085], [92.33302307, 23.42975426], [92.33298492, 23.42998505], [92.33281708, 23.43103218], [92.33308411, 23.43329811], [92.3323822, 23.43649101], [92.33208466, 23.43712234], [92.3313446, 23.4382], [92.33061981, 23.4400959], [92.33105469, 23.44171524], [92.33099365, 23.4432869], [92.33080292, 23.44378471], [92.33070374, 23.44477844], [92.33035278, 23.44573402], [92.33037567, 23.44598961], [92.32951355, 23.4479351], [92.32858276, 23.44840622], [92.32810211, 23.44852066], [92.32791138, 23.44826698], [92.32726288, 23.44830322], [92.32699585, 23.44855499], [92.327034, 23.44913292], [92.32704926, 23.45004082], [92.32826233, 23.45002174], [92.3285675, 23.45001602], [92.32862091, 23.45029831], [92.32905579, 23.45275879], [92.33084869, 23.45303535], [92.33139801, 23.45346451], [92.33210754, 23.45425987], [92.33319855, 23.45547485], [92.33325958, 23.45649719], [92.3323822, 23.45713997], [92.3319397, 23.45739555], [92.33157349, 23.45731735], [92.33161926, 23.45537376], [92.33162689, 23.45523643], [92.33061981, 23.4541378], [92.32939148, 23.45442772], [92.32917786, 23.45451355], [92.32905579, 23.45483971], [92.32860565, 23.45521927], [92.32832336, 23.45581055], [92.32780457, 23.45686722], [92.32697296, 23.45739365], [92.32569885, 23.45881844], [92.32527161, 23.45923805], [92.32531738, 23.45956802], [92.3258667, 23.4598732], [92.32762146, 23.46002579], [92.32854462, 23.45968056], [92.32939148, 23.4594841], [92.33045197, 23.45951653], [92.33065796, 23.46009254], [92.33082581, 23.46014786], [92.33207703, 23.46457863], [92.3316803, 23.46635246], [92.33068848, 23.46707916], [92.33004761, 23.46721268], [92.32915497, 23.46681213], [92.32845306, 23.46649742], [92.32728577, 23.46688652], [92.32710266, 23.46715927], [92.3267746, 23.46766472], [92.32561493, 23.46774101], [92.3210907, 23.4696312], [92.3197937, 23.46975327], [92.31887054, 23.47027779], [92.31874084, 23.47035599], [92.31786346, 23.47125435], [92.3170166, 23.4718132], [92.31747437, 23.47234344], [92.31790924, 23.47297096], [92.3189621, 23.47317696], [92.3188324, 23.47431183], [92.32010651, 23.47534752], [92.32019806, 23.47471046], [92.32042694, 23.47397995], [92.32083893, 23.47393227], [92.32202911, 23.4737606], [92.32254028, 23.47357368], [92.32325745, 23.47356224], [92.32341003, 23.47363853], [92.32371521, 23.47379494], [92.32372284, 23.47439194], [92.32368469, 23.4746685], [92.32359314, 23.4752903], [92.32344818, 23.47681999], [92.32312775, 23.47727966], [92.32238007, 23.47830772], [92.32293701, 23.47905922], [92.32388306, 23.47858429], [92.32454681, 23.4782486], [92.32517242, 23.47815514], [92.32559204, 23.47846603], [92.32614899, 23.47888184], [92.32520294, 23.47965813], [92.32500458, 23.47980881], [92.32431793, 23.48031616], [92.32324982, 23.48044205], [92.32274628, 23.48043633], [92.32234955, 23.48043251], [92.32199097, 23.48019028], [92.32090759, 23.48062134], [92.32074738, 23.4808712], [92.32184601, 23.48217392], [92.3219223, 23.48244667], [92.3216095, 23.48308754], [92.32054138, 23.48402214], [92.3197937, 23.48485184], [92.31830597, 23.48560333], [92.31695557, 23.48613739], [92.31637573, 23.48643494], [92.31603241, 23.48697853], [92.31630707, 23.48740387], [92.31721497, 23.48803329], [92.31821442, 23.48871803], [92.31881714, 23.48932838], [92.31955719, 23.48972893], [92.32110596, 23.49028206], [92.32180786, 23.49022865], [92.32199097, 23.49142265], [92.32185364, 23.49192047], [92.32123566, 23.49205589], [92.32015991, 23.49207306], [92.31881714, 23.49228477], [92.31807709, 23.49313927], [92.31742859, 23.49430656], [92.31742859, 23.49455452], [92.3177948, 23.49471283], [92.31893921, 23.49462128], [92.32038116, 23.49450493], [92.32041168, 23.49545479], [92.32043457, 23.49642181], [92.32044983, 23.49687576], [92.32001495, 23.49851799], [92.31939697, 23.49986649], [92.31915283, 23.50039101], [92.31933594, 23.50061798], [92.31942749, 23.5006485], [92.32015228, 23.50086975], [92.32271576, 23.50103378], [92.32266235, 23.5013237], [92.32042694, 23.50152588], [92.31885529, 23.50338554], [92.31941986, 23.50497055], [92.31906128, 23.50658798], [92.31876373, 23.50803757], [92.31995392, 23.50938034], [92.31971741, 23.5109539], [92.31970215, 23.51256561], [92.31925964, 23.51269531], [92.31895447, 23.51268005], [92.31867218, 23.51266479], [92.31764221, 23.5122261], [92.31606293, 23.51196289], [92.31533051, 23.51354599], [92.31590271, 23.5139904], [92.31616974, 23.51408958], [92.31826782, 23.51487732], [92.31838226, 23.51521301], [92.31796265, 23.51606941], [92.31724548, 23.5175209], [92.31680298, 23.51769257], [92.31607819, 23.51725006], [92.31505585, 23.51549149], [92.313797, 23.5152626], [92.31352997, 23.51535034], [92.31345367, 23.51617813], [92.3141861, 23.51690865], [92.3139267, 23.51760483], [92.31360626, 23.51844978], [92.3131485, 23.51965141], [92.3130722, 23.52027321], [92.31309509, 23.52076721], [92.31365204, 23.52166748], [92.31374359, 23.52173424], [92.31728363, 23.52437592], [92.31771851, 23.52521133], [92.31781769, 23.52624893], [92.31726837, 23.52724648], [92.31609344, 23.52939224], [92.31469727, 23.52957916], [92.31416321, 23.52963066], [92.31398773, 23.52992249], [92.31406403, 23.53144836], [92.31378937, 23.53240395], [92.31388855, 23.53274345], [92.31394196, 23.533144], [92.31376648, 23.53332329], [92.31360626, 23.53347969], [92.31311798, 23.53359604], [92.31298065, 23.53354263], [92.31056213, 23.53257942], [92.30957794, 23.53241348], [92.30831146, 23.53273201], [92.30679321, 23.53400421], [92.30615997, 23.53517151], [92.30686951, 23.536026], [92.30735779, 23.53829002], [92.30793762, 23.54121399], [92.30860138, 23.54159355], [92.31002045, 23.54240227], [92.30989075, 23.54304123], [92.30981445, 23.54341316], [92.30983734, 23.54461098], [92.31032562, 23.54606628], [92.31054688, 23.5467453], [92.31059265, 23.54716682], [92.31049347, 23.5474968], [92.31009674, 23.54877663], [92.30927277, 23.54936981], [92.30862427, 23.5500412], [92.30884552, 23.55135918], [92.31069946, 23.55560684], [92.31110382, 23.55480766], [92.311409, 23.55420685], [92.31255341, 23.5531559], [92.31297302, 23.55352211], [92.31330109, 23.554739], [92.31324768, 23.55669785], [92.31203461, 23.5588398], [92.31166077, 23.55990219], [92.30976105, 23.56179237], [92.30794525, 23.56267357], [92.30764008, 23.56294632], [92.30706024, 23.56346321], [92.30667877, 23.56451035], [92.30666351, 23.56472969], [92.30661011, 23.56572533], [92.3068924, 23.56625938], [92.30754089, 23.56500816], [92.30802917, 23.56496048], [92.30860901, 23.56623077], [92.30905151, 23.57020569], [92.30901337, 23.57040787], [92.30882263, 23.57136536], [92.30860901, 23.5717659], [92.30807495, 23.57188034], [92.30754852, 23.57169151], [92.30735016, 23.57162094], [92.30673218, 23.57187843], [92.30685425, 23.57128143], [92.30771637, 23.57063484], [92.30796051, 23.57045364], [92.30821228, 23.56964874], [92.30757141, 23.56918907], [92.30658722, 23.57014656], [92.30622101, 23.57115936], [92.30506134, 23.57368088], [92.30549622, 23.57422447], [92.30685425, 23.57594109], [92.30722046, 23.57633018], [92.30736542, 23.57686615], [92.30809784, 23.5777626], [92.3073349, 23.57866287], [92.30661011, 23.57952118], [92.30653381, 23.58008194], [92.30635071, 23.58139229], [92.30628967, 23.58185768], [92.30621338, 23.58241844], [92.30582428, 23.58304405], [92.305336, 23.58329964], [92.30519104, 23.58328056], [92.30479431, 23.58322716], [92.30438995, 23.58286095], [92.30393982, 23.58295059], [92.30363464, 23.58341026], [92.30384827, 23.58505821], [92.3037796, 23.58525848], [92.30342102, 23.58638763], [92.3030014, 23.58678246], [92.30211639, 23.58760643], [92.30139923, 23.5884037], [92.30141449, 23.58856201], [92.30129242, 23.58871078], [92.29943085, 23.59033966], [92.29914093, 23.59106064], [92.29808044, 23.59215355], [92.29786682, 23.59126854], [92.29761505, 23.58985138], [92.29673767, 23.58814812], [92.29653168, 23.58832359], [92.29470825, 23.5898819], [92.29394531, 23.59236526], [92.29331207, 23.59321404], [92.29311371, 23.59347725], [92.29309082, 23.59427834], [92.29317474, 23.59449196], [92.29346466, 23.59522247], [92.29290009, 23.59517097], [92.29230499, 23.59511757], [92.29131317, 23.59542274], [92.2909317, 23.59589767], [92.28990173, 23.59718895], [92.28929901, 23.59793282], [92.28886414, 23.59827042], [92.28849792, 23.59790421], [92.2885437, 23.59571457], [92.28799438, 23.59531021], [92.287117, 23.59615135], [92.28713226, 23.59626389], [92.28769684, 23.60076714], [92.28742981, 23.60221672], [92.28786469, 23.60349083], [92.28738403, 23.60552216], [92.28818512, 23.60736847], [92.28730774, 23.61010742], [92.2878952, 23.61131287], [92.28747559, 23.61250114], [92.28757477, 23.61394501], [92.28740692, 23.61539078], [92.28723907, 23.61684227], [92.2873764, 23.61716461], [92.28752136, 23.6174984], [92.28800964, 23.61848068], [92.28881073, 23.61925316], [92.28971863, 23.61989021], [92.29077911, 23.61986542], [92.29206085, 23.62035751], [92.29319, 23.62066841], [92.29547119, 23.62063217], [92.29592133, 23.62081528], [92.29584503, 23.62147713], [92.29529572, 23.62239456], [92.29410553, 23.62435532], [92.29058838, 23.62773323], [92.28966522, 23.6284008], [92.28848267, 23.62722969], [92.28655243, 23.62783051], [92.2857666, 23.62765503], [92.28476715, 23.62778854], [92.28379822, 23.6280899], [92.28356934, 23.62899971], [92.28144836, 23.63000679], [92.28134918, 23.62999535], [92.2806015, 23.63070297], [92.28031158, 23.63050652], [92.27964783, 23.63005638], [92.27906799, 23.6292572], [92.27907562, 23.62833023], [92.27993011, 23.62656593], [92.27999115, 23.6259613], [92.27986145, 23.62551308], [92.27977753, 23.62523842], [92.27877045, 23.6249485], [92.27826691, 23.62574196], [92.27820587, 23.62760162], [92.27804565, 23.62818336], [92.27697754, 23.62976837], [92.27663422, 23.6306591], [92.27642822, 23.63160324], [92.27668762, 23.63218498], [92.27711487, 23.63277245], [92.27731323, 23.63304329], [92.27818298, 23.6343174], [92.27933502, 23.63491821], [92.27957153, 23.63559151], [92.27934265, 23.63630676], [92.27957153, 23.63674927], [92.28013611, 23.6367569], [92.28092957, 23.63627243], [92.28138733, 23.63676834], [92.28153992, 23.63779068], [92.28171539, 23.63869667], [92.28141022, 23.63877678], [92.27975464, 23.63920784], [92.27775574, 23.6404953], [92.2771225, 23.64116669], [92.27507782, 23.64212418], [92.27332306, 23.64155769], [92.27293396, 23.64172935], [92.27302551, 23.64280128], [92.27336121, 23.64395332], [92.27359772, 23.64439964], [92.27484131, 23.64682007], [92.27433014, 23.64770317], [92.2750473, 23.65012169], [92.27637482, 23.65206528], [92.27748108, 23.65305519], [92.27790833, 23.6534214], [92.27805328, 23.65383148], [92.27835846, 23.65440559], [92.27855682, 23.65543365], [92.27839661, 23.65630341], [92.28022766, 23.65829849], [92.28088379, 23.65989876], [92.28108215, 23.66101074], [92.28141022, 23.66141891], [92.28204346, 23.66171455], [92.28284454, 23.66168404], [92.28329468, 23.66170311], [92.28343201, 23.66193199], [92.28356171, 23.66406822], [92.28429413, 23.66467667], [92.284729, 23.66557884], [92.28469086, 23.66610527], [92.28457642, 23.66760445], [92.28510284, 23.66962051], [92.28529358, 23.67019463], [92.28599548, 23.67173767], [92.28630829, 23.67310333], [92.2868042, 23.67394638], [92.28837585, 23.676548], [92.28842926, 23.67704201], [92.28875732, 23.67769814], [92.28894806, 23.67835617], [92.28897858, 23.68008995], [92.28958893, 23.68123627], [92.2902298, 23.68118858], [92.29102325, 23.68113136], [92.29133606, 23.68129158], [92.29138947, 23.68170357], [92.2909317, 23.68225098], [92.29069519, 23.6828289], [92.29093933, 23.6840229], [92.29064178, 23.68497849], [92.28955078, 23.68635941], [92.28957367, 23.68751526], [92.29084778, 23.69096375], [92.28953552, 23.69255447], [92.28984833, 23.69490433], [92.28914642, 23.69569969], [92.28935242, 23.69817352], [92.28937531, 23.6985054], [92.28934479, 23.69862556], [92.28920746, 23.6991272], [92.28940582, 23.69944191], [92.2897644, 23.70002747], [92.28937531, 23.70004654], [92.28855133, 23.7000885], [92.28901672, 23.70061684], [92.28879547, 23.70095062], [92.28903961, 23.70149231], [92.28926086, 23.70197678], [92.28885651, 23.70176506], [92.2884903, 23.70157623], [92.28800201, 23.70178986], [92.28701782, 23.70180702], [92.28713226, 23.70252991], [92.28717041, 23.70279503], [92.2868042, 23.70282936], [92.28609467, 23.70289421], [92.28538513, 23.70331955], [92.28535461, 23.7039814], [92.28486633, 23.704319], [92.28469849, 23.70490074], [92.28436279, 23.70606232], [92.28451538, 23.70709229], [92.28463745, 23.70741653], [92.28353119, 23.70710754], [92.28321075, 23.70686531], [92.28294373, 23.70711708], [92.28250122, 23.70741463], [92.28179169, 23.7075901], [92.28063965, 23.70847702], [92.28069305, 23.70853424], [92.28128052, 23.70916748], [92.28020477, 23.70910263], [92.27941132, 23.70977592], [92.27873993, 23.70992661], [92.27842712, 23.70999908], [92.27830505, 23.71074486], [92.27812958, 23.7111187], [92.27827454, 23.7113781], [92.27850342, 23.71181488], [92.27877808, 23.71193504], [92.27878571, 23.71243095], [92.27919769, 23.71267128], [92.27845001, 23.71346855], [92.27859497, 23.71408463], [92.27841949, 23.71446037], [92.27861023, 23.71503448], [92.27941895, 23.71526909], [92.27965546, 23.71568108], [92.27670288, 23.72106171], [92.27626038, 23.72187042], [92.2691803, 23.72811127], [92.26850128, 23.72861099], [92.26848602, 23.72869682], [92.26647949, 23.7387085], [92.26824188, 23.75640488], [92.26824951, 23.75651741], [92.26711273, 23.76189995], [92.26728058, 23.76273346], [92.26802826, 23.7665081], [92.26779938, 23.76997185], [92.26374054, 23.79168892], [92.26348877, 23.79968262], [92.2623291, 23.80487061], [92.26068115, 23.80712891], [92.25939941, 23.814991], [92.25953674, 23.81502914], [92.26947784, 23.81777954], [92.2766571, 23.81520844], [92.27911377, 23.81671143], [92.28084564, 23.81515884], [92.28374481, 23.81623459], [92.28588867, 23.81567383], [92.28681183, 23.81676102], [92.28568268, 23.82263184], [92.28346252, 23.82349968], [92.28366852, 23.82418633], [92.28159332, 23.82616043], [92.28160858, 23.82630157], [92.28210449, 23.83087158], [92.27713013, 23.8366127], [92.2770462, 23.83670998], [92.27587891, 23.83990479], [92.27393341, 23.84169769], [92.2741394, 23.84361076], [92.27474976, 23.84905815], [92.2765274, 23.8528862], [92.28530121, 23.85747147], [92.28592682, 23.85886574], [92.28790283, 23.86309814], [92.28790283, 23.86688232], [92.29201508, 23.87140846], [92.29338074, 23.87134743], [92.29388428, 23.87127686], [92.29514313, 23.87010956], [92.29510498, 23.86547852], [92.30068207, 23.8664608], [92.30426025, 23.8638649], [92.30432129, 23.86382294], [92.30731201, 23.8638916], [92.30987549, 23.8626709], [92.31552887, 23.86352539], [92.3156662, 23.86354637], [92.31954956, 23.86524773], [92.31968689, 23.86530876], [92.32022095, 23.86581039], [92.3203125, 23.86590576], [92.31824493, 23.86713982], [92.31845856, 23.86799431], [92.32198334, 23.86982536], [92.32208252, 23.86987305], [92.32209015, 23.87379074], [92.32209015, 23.87390327], [92.32198334, 23.87415886], [92.32041168, 23.8780098], [92.3190918, 23.87768555], [92.31710815, 23.87918091], [92.31712341, 23.87926483], [92.31747437, 23.8813858], [92.31750488, 23.88153076], [92.31671143, 23.88171387], [92.31628418, 23.88330078], [92.31642151, 23.88343811], [92.31713104, 23.88408852], [92.31932831, 23.88372421], [92.31952667, 23.88610077], [92.31832886, 23.88793182], [92.31902313, 23.88915443], [92.3184967, 23.89048958], [92.31863403, 23.89053917], [92.31919861, 23.89066887], [92.3192749, 23.89068604], [92.31988525, 23.88989258], [92.32067871, 23.89129639], [92.32157898, 23.8914547], [92.32171631, 23.89147949], [92.32315063, 23.90426636], [92.32331085, 23.90441322], [92.32360077, 23.90467834], [92.32372284, 23.90466881], [92.32579041, 23.90449524], [92.32592773, 23.90447998], [92.32778168, 23.90621948], [92.32989502, 23.90551758], [92.33048248, 23.90759659], [92.330513, 23.90771484], [92.33052826, 23.90783119], [92.33114624, 23.91180229], [92.32939148, 23.91885948], [92.33065796, 23.92144966], [92.32971191, 23.9230957], [92.3278656, 23.92401695], [92.32128906, 23.92607498], [92.32116699, 23.92611122], [92.31807709, 23.93035126], [92.31347656, 23.93450928], [92.31268311, 23.94128418], [92.31347656, 23.94329834], [92.31123352, 23.94568443], [92.31265259, 23.95750618], [92.31144714, 23.96058273], [92.31155396, 23.96060562], [92.31333923, 23.96096992], [92.3133316, 23.96108818], [92.31269836, 23.9702301], [92.31360626, 23.97049141], [92.31530762, 23.97088623], [92.31513977, 23.97216606], [92.31768036, 23.97210121], [92.31964111, 23.97532082], [92.32208252, 23.97528076], [92.32274628, 23.97981071], [92.32285309, 23.97978592], [92.32409668, 23.97949219], [92.32552338, 23.98326111], [92.32614899, 23.98365974], [92.32778931, 23.98470116], [92.32769775, 23.98571777], [92.32736969, 23.98604584], [92.32579803, 23.98747063], [92.32589722, 23.98753548], [92.32905579, 23.98965073], [92.32727051, 24.00189209], [92.32746124, 24.00420952], [92.32470703, 24.00653076], [92.31713867, 24.01761246], [92.31750488, 24.0189209], [92.31890869, 24.01928711], [92.32092285, 24.0178833], [92.32165527, 24.0188446], [92.32171631, 24.0189209], [92.31848145, 24.02270508], [92.3190918, 24.0255127], [92.31669617, 24.02797127], [92.3167572, 24.02802467], [92.3192749, 24.03027344], [92.3192749, 24.03131104], [92.31413269, 24.03471184], [92.31506348, 24.0355587], [92.31719971, 24.03750038], [92.31754303, 24.03952026], [92.31549072, 24.04492188], [92.31526947, 24.0486908], [92.31682587, 24.05135155], [92.31904602, 24.0501194], [92.32028961, 24.05116272], [92.31999969, 24.05231667], [92.31871033, 24.05735016], [92.32176971, 24.05866051], [92.3190918, 24.0612793], [92.31880188, 24.06202126], [92.3168869, 24.06689835], [92.3182373, 24.06904411], [92.31828308, 24.06912422], [92.3192749, 24.06951904], [92.32128906, 24.06848145], [92.32330322, 24.06970215], [92.32293701, 24.07180023], [92.32292175, 24.07187462], [92.32369232, 24.07326317], [92.32727051, 24.07452393], [92.3270874, 24.07647705], [92.32287598, 24.07695961], [92.32284546, 24.07726669], [92.32282257, 24.07748032], [92.32805634, 24.08062744], [92.32814026, 24.08068085], [92.32904816, 24.08225632], [92.32811737, 24.08502007], [92.32814026, 24.08515549], [92.32878113, 24.08912086], [92.32794952, 24.09370232], [92.33014679, 24.09602356], [92.33027649, 24.09615326], [92.33068085, 24.09697342], [92.33142853, 24.09874535], [92.32834625, 24.09859848], [92.32967377, 24.10109329], [92.3296814, 24.10132408], [92.32950592, 24.10293007], [92.33227539, 24.10528564], [92.33229065, 24.10680962], [92.33229065, 24.10688782], [92.32937622, 24.11036682], [92.33188629, 24.11176109], [92.33187103, 24.11187363], [92.33174133, 24.11314583], [92.32867432, 24.11590576], [92.32832336, 24.12468338], [92.33101654, 24.12799072], [92.33111572, 24.12811279], [92.32888031, 24.1296463], [92.32878113, 24.12972069], [92.329216, 24.13162613], [92.32816315, 24.13516998], [92.32830048, 24.13862038], [92.32928467, 24.13989258], [92.33227539, 24.14050293], [92.33227539, 24.14402962], [92.33296967, 24.14419365], [92.33353424, 24.14426804], [92.3336792, 24.14428711], [92.33532715, 24.14367676], [92.33627319, 24.14432335], [92.33688354, 24.14677811], [92.33691406, 24.14691162], [92.33447266, 24.15087891], [92.33190918, 24.16369629], [92.32946777, 24.16452026], [92.32855988, 24.1661129], [92.32993317, 24.17465019], [92.33002472, 24.1800499], [92.33002472, 24.18013763], [92.33087158, 24.18212891], [92.33040619, 24.18483162], [92.3270874, 24.18609619], [92.32958221, 24.18818855], [92.32971191, 24.18829346], [92.32891083, 24.18911171], [92.32949066, 24.19114113], [92.32476044, 24.19476128], [92.32470703, 24.19628906], [92.32557678, 24.19753647], [92.32510376, 24.1989994], [92.32506561, 24.19908333], [92.3203125, 24.20269775], [92.3203125, 24.20430946], [92.32480621, 24.20470428], [92.32489014, 24.20471191], [92.32470703, 24.20587158], [92.3190918, 24.20910645], [92.31610107, 24.21331787], [92.31265259, 24.21109772], [92.30974579, 24.21479988], [92.30966949, 24.21612167], [92.31359863, 24.22113037], [92.31375122, 24.22288322], [92.31083679, 24.2225399], [92.30353546, 24.22163582], [92.30342102, 24.22165298], [92.30088043, 24.22204018], [92.30113983, 24.22448158], [92.30187988, 24.22509766], [92.30105591, 24.22553444], [92.29769897, 24.22731781], [92.29920959, 24.22934151], [92.29931641, 24.22949219], [92.29946899, 24.23162079], [92.29632568, 24.23388672], [92.29632568, 24.23608398], [92.296875, 24.23809814], [92.29492188, 24.24072266], [92.29412842, 24.24432373], [92.2953186, 24.24806976], [92.29709625, 24.24954033], [92.29668427, 24.25174141], [92.30349731, 24.25269127], [92.3105011, 24.2513485], [92.31407166, 24.25260162], [92.37652588, 24.25131035], [92.39570618, 24.25252914], [92.40683746, 24.25193977], [92.4164505, 24.25342941], [92.42237854, 24.25311089], [92.42253113, 24.24817085], [92.42005157, 24.23520279], [92.41851807, 24.22164917], [92.42018127, 24.21788979], [92.41822052, 24.2109108], [92.41971588, 24.20247078], [92.41897583, 24.19436073], [92.42214966, 24.18852997], [92.43321228, 24.1832695], [92.43419647, 24.18138123], [92.43445587, 24.17414093], [92.43775177, 24.1704998], [92.43814087, 24.16913033], [92.43522644, 24.16257858], [92.43656921, 24.15242958], [92.43743134, 24.15135002], [92.43875885, 24.15125084], [92.44182587, 24.1528511], [92.4438858, 24.15309906], [92.45063019, 24.14369011], [92.45722198, 24.14350128], [92.4630661, 24.13636971], [92.46483612, 24.13663101], [92.4659729, 24.13475037], [92.46682739, 24.13504028], [92.46858978, 24.13800049], [92.47335052, 24.13996124], [92.47332001, 24.14203072], [92.474823, 24.14291], [92.47960663, 24.14089966], [92.48087311, 24.14132118], [92.48149872, 24.14294052], [92.47875214, 24.14871025], [92.48062897, 24.15011024], [92.48065948, 24.15229988], [92.48293304, 24.1527195], [92.48355865, 24.15393066], [92.48118591, 24.1570797], [92.48264313, 24.15709114], [92.48396301, 24.15814018], [92.48490143, 24.15930939], [92.48493958, 24.16138077], [92.48586273, 24.16220093], [92.48808289, 24.16221809], [92.49475861, 24.15994072], [92.50013733, 24.16052055], [92.50245667, 24.16211128], [92.50325775, 24.16666985], [92.50488281, 24.16731071], [92.50678253, 24.16682053], [92.50953674, 24.16288948], [92.51283264, 24.16257858], [92.51200104, 24.16481972], [92.50863647, 24.1692009], [92.51373291, 24.16926003], [92.5147934, 24.17020035], [92.51357269, 24.17358017], [92.51512909, 24.17548752], [92.51759338, 24.1762104], [92.52175903, 24.17292976], [92.52539825, 24.17292976], [92.52966309, 24.17480087], [92.52990723, 24.17641068], [92.53151703, 24.17741966], [92.53289032, 24.18053055], [92.53346252, 24.18083191], [92.53147888, 24.18346024], [92.53781891, 24.19647026], [92.53639984, 24.19989967], [92.53726959, 24.201931], [92.54147339, 24.20622826], [92.54242706, 24.21062088], [92.54223633, 24.21417809], [92.54574585, 24.21990013], [92.54738617, 24.2244091], [92.5477829, 24.23188972], [92.54693604, 24.23476028], [92.54709625, 24.23769951], [92.54882812, 24.24323082], [92.55063629, 24.2458992], [92.55893707, 24.24789047], [92.56455994, 24.25008965], [92.58184052, 24.24535942], [92.5880127, 24.2448616], [92.59140015, 24.24598122], [92.59356689, 24.24858856], [92.59596252, 24.24930954], [92.60595703, 24.24920082], [92.60795593, 24.25008011], [92.61158752, 24.2533493], [92.61308289, 24.25583839], [92.61550903, 24.26362038], [92.61576843, 24.2705307], [92.61682129, 24.27531052], [92.61904144, 24.28132057], [92.61940002, 24.2867794], [92.6190567, 24.28787041], [92.61723328, 24.28906059], [92.61678314, 24.29123116], [92.61830902, 24.29970932], [92.61802673, 24.30435944], [92.61963654, 24.30846024], [92.61943817, 24.31150818], [92.62310028, 24.32028961], [92.62335205, 24.33077049], [92.62428284, 24.33265114], [92.6261673, 24.33447266], [92.63063812, 24.33337021], [92.6359024, 24.33574104], [92.6377182, 24.33551979], [92.638237, 24.33443069], [92.63654327, 24.33423805], [92.63668823, 24.33269119], [92.63925934, 24.33175087], [92.63983917, 24.32973099], [92.64099121, 24.32871056], [92.6450119, 24.32767105], [92.64594269, 24.32923126], [92.64524841, 24.33181], [92.64904022, 24.32875061], [92.64978027, 24.32922173], [92.6493988, 24.33082008], [92.65184021, 24.33033943], [92.65203857, 24.33286095], [92.65239716, 24.33529091], [92.65645599, 24.33912086], [92.65759277, 24.34155083], [92.65751648, 24.34350967], [92.65847015, 24.34346008], [92.66072083, 24.34514999], [92.6622467, 24.3434391], [92.6632309, 24.34379959], [92.66410828, 24.34674072], [92.66525269, 24.34521103], [92.66699982, 24.34560966], [92.6747818, 24.34980011], [92.67964172, 24.34778023], [92.68379974, 24.34748077], [92.684021, 24.34988976], [92.68799591, 24.35201073], [92.6906662, 24.35480118], [92.69167328, 24.35642052], [92.69177246, 24.36216927], [92.69391632, 24.36363029], [92.69420624, 24.36495972], [92.69325256, 24.36782074], [92.69500732, 24.36956978], [92.69687653, 24.37400055], [92.69827271, 24.37496185], [92.70240784, 24.3752327], [92.70410919, 24.3762207], [92.70343781, 24.38380051], [92.70745087, 24.38701057], [92.70742035, 24.39241028], [92.71421814, 24.40532112], [92.71412659, 24.40777969], [92.71508789, 24.40876961], [92.71420288, 24.41036987], [92.71411896, 24.41296005], [92.71511841, 24.41452026], [92.71813965, 24.41621971], [92.72376251, 24.43594933], [92.73053741, 24.45275116], [92.74360657, 24.47462845], [92.74884033, 24.48854065], [92.7507782, 24.49149132], [92.75132751, 24.49436951], [92.75450134, 24.50111961], [92.75364685, 24.50704193], [92.75918579, 24.51176071], [92.76451111, 24.51883125], [92.76519775, 24.52084923], [92.77913666, 24.48649979], [92.78222656, 24.47480011], [92.78437805, 24.47120285], [92.78624725, 24.4637394], [92.78987885, 24.45607948], [92.79390717, 24.4440403], [92.7977829, 24.43470955], [92.80031586, 24.4319706], [92.80284882, 24.42728043], [92.80425262, 24.4229908], [92.80381775, 24.42172241], [92.80004883, 24.42146111], [92.80079651, 24.41905022], [92.80370331, 24.41879082], [92.80715942, 24.41986275], [92.80948639, 24.41930008], [92.80887604, 24.4168911], [92.80944061, 24.4152317], [92.81140137, 24.41537285], [92.8111496, 24.41364288], [92.81645203, 24.41225052], [92.81832886, 24.41272926], [92.82112885, 24.40678024], [92.82479095, 24.40418053], [92.8303299, 24.40175056], [92.83136749, 24.40050125], [92.83167267, 24.39934158], [92.82659912, 24.39355278], [92.82504272, 24.39049149], [92.82541656, 24.38842964], [92.82826233, 24.38557816], [92.82816315, 24.37931061], [92.82898712, 24.37776947], [92.83270264, 24.37636948], [92.8396225, 24.38080025], [92.84427643, 24.37986946], [92.84690857, 24.38229942], [92.84909058, 24.38613129], [92.85164642, 24.39237022], [92.85447693, 24.39400101], [92.85906219, 24.3984108], [92.86289978, 24.39949989], [92.87178802, 24.39705086], [92.87386322, 24.39725113], [92.87819672, 24.39888954], [92.88424683, 24.40303993], [92.88800812, 24.4016304], [92.89077759, 24.40229034], [92.89173126, 24.40179062], [92.89438629, 24.39530945], [92.8963623, 24.39430046], [92.90097809, 24.39343071], [92.90516663, 24.39445114], [92.90587616, 24.39537048], [92.9057312, 24.3990593], [92.90930939, 24.40316963], [92.91153717, 24.41290092], [92.92339325, 24.40571976], [92.92259979, 24.40415955], [92.92366028, 24.40261078], [92.92537689, 24.40221977], [92.92765045, 24.39862823], [92.93570709, 24.39554024], [92.93773651, 24.39670944], [92.93855286, 24.39902115], [92.94055176, 24.40105057], [92.94415283, 24.40183258], [92.95124817, 24.40483093], [92.95388794, 24.40462112], [92.95469666, 24.40388107], [92.95813751, 24.39805031], [92.96032715, 24.39588165], [92.97083282, 24.40121269], [92.97564697, 24.40776062], [92.98026276, 24.40969086], [92.98542786, 24.40756035], [92.98832703, 24.40764999], [92.99192047, 24.40549278], [92.99534607, 24.40195084], [92.99804688, 24.40157127], [93.00049591, 24.40327072], [93.02435303, 24.3904705], [93.01709747, 24.37996101], [93.0220871, 24.37421989], [93.02011108, 24.36597252], [93.01933289, 24.35884857], [93.0215683, 24.34682083], [93.03176117, 24.34449005], [93.04337311, 24.34338951], [93.03523254, 24.31839943], [93.02391815, 24.3007412], [93.01821899, 24.29315948], [93.01107788, 24.28808022], [93.00821686, 24.28047943], [93.01391602, 24.27166939], [93.00673676, 24.26279068], [93.00670624, 24.25395966], [93.01803589, 24.23637009], [93.02658844, 24.23263168], [93.01940918, 24.22884941], [93.01940155, 24.22508812], [93.02368164, 24.21756935], [93.02229309, 24.21006012], [93.01799774, 24.20754814], [93.01661682, 24.20003128], [93.01236725, 24.19754028], [93.0030365, 24.19752121], [93.00309753, 24.19431114], [93.01091766, 24.18221283], [93.00331116, 24.17404938], [93.00550079, 24.16321182], [93.00544739, 24.1606102], [93.00067139, 24.15673065], [92.99308014, 24.15317917], [92.99112701, 24.15032959], [92.99092102, 24.14686966], [92.99286652, 24.1403904], [92.9894104, 24.13178062], [92.98606873, 24.12887955], [92.97756195, 24.12639046], [92.97360229, 24.12388039], [92.97486877, 24.11701965], [92.97637939, 24.11482048], [92.98477936, 24.11482048], [92.98929596, 24.1163311], [92.99642181, 24.11672974], [93.00068665, 24.11519241], [93.0096817, 24.10995293], [93.01410675, 24.10453033], [93.021492, 24.10145187], [93.02729797, 24.1036396], [93.03029633, 24.10083008], [93.03469849, 24.09924126], [93.03769684, 24.09518051], [93.05368805, 24.09069061], [93.06519318, 24.09427071], [93.07377625, 24.10049057], [93.07949066, 24.10297012], [93.08522797, 24.0903511], [93.08950806, 24.08405113], [93.09520721, 24.0802803], [93.10234833, 24.07401085], [93.10090637, 24.06645012], [93.1023407, 24.06269264], [93.10092926, 24.05639076], [93.1037674, 24.05262947], [93.09951019, 24.04883957], [93.10092163, 24.04508972], [93.10662842, 24.04886055], [93.11087799, 24.05014992], [93.11231232, 24.05519104], [93.11940765, 24.05647278], [93.12081909, 24.06026077], [93.12937164, 24.06408119], [93.13507843, 24.07291985], [93.13508606, 24.07921028], [93.14219666, 24.08678818], [93.14791107, 24.0880909], [93.15846252, 24.08381844], [93.16131592, 24.07756042], [93.1698761, 24.0750618], [93.16986847, 24.07127953], [93.16697693, 24.06121826], [93.16983795, 24.05495262], [93.17552185, 24.05369949], [93.17838287, 24.05409622], [93.19400787, 24.0562706], [93.19825745, 24.05249977], [93.21673584, 24.05006027], [93.22100067, 24.06137085], [93.22242737, 24.06767273], [93.22525024, 24.07396126], [93.22241974, 24.08148956], [93.22383881, 24.08401108], [93.22667694, 24.08653069], [93.2366333, 24.08403969], [93.24233246, 24.08657074], [93.24801636, 24.08533859], [93.26371765, 24.07282066], [93.26373291, 24.06778908], [93.26660919, 24.06026077], [93.26374054, 24.05774117], [93.2623291, 24.05772972], [93.25238037, 24.03383064], [93.25670624, 24.0288105], [93.25528717, 24.02379036], [93.27394867, 24.03392029], [93.27677917, 24.04021072], [93.28536987, 24.04652023], [93.28819275, 24.05154991], [93.29824829, 24.05158997], [93.31254578, 24.05413055], [93.33737183, 24.05340004], [93.33828735, 24.05019188], [93.34221649, 24.0445919], [93.33600616, 24.04261017], [93.33323669, 24.03980064], [93.33764648, 24.0342083], [93.34216309, 24.03067017], [93.33810425, 24.02535629], [93.33692169, 24.02380943], [93.33750153, 24.0212307], [93.33779144, 24.01992035], [93.34031677, 24.01243019], [93.33934784, 24.00291824], [93.33927155, 24.00221062], [93.33895874, 23.99588966], [93.33442688, 23.98694992], [93.33744812, 23.98278999], [93.34236908, 23.98232841], [93.34739685, 23.98069954], [93.35160828, 23.97798157], [93.35315704, 23.9720211], [93.35587311, 23.96125984], [93.35988617, 23.95465279], [93.36241913, 23.95075989], [93.36493683, 23.94597054], [93.36781311, 23.94343948], [93.37104034, 23.94054031], [93.37573242, 23.93782043], [93.38124847, 23.93619156], [93.39097595, 23.93400002], [93.39871979, 23.93028069], [93.39961243, 23.92440033], [93.39919281, 23.91899109], [93.39758301, 23.91292953], [93.39673615, 23.89866829], [93.39559174, 23.88727951], [93.39544678, 23.87670135], [93.39642334, 23.87094116], [93.3968811, 23.86377907], [93.39656067, 23.85853958], [93.39671326, 23.85070038], [93.39705658, 23.84093285], [93.40010071, 23.83532143], [93.39916229, 23.82421112], [93.40141296, 23.81941032], [93.4068985, 23.81714821], [93.40982819, 23.81361008], [93.41098022, 23.80772972], [93.41005707, 23.79879189], [93.40756989, 23.79021072], [93.40444946, 23.77505112], [93.40422821, 23.76898956], [93.4052887, 23.76159096], [93.40712738, 23.75562096], [93.41053772, 23.7486496], [93.41442871, 23.74348068], [93.41539764, 23.73842049], [93.41773224, 23.73254967], [93.41584015, 23.72686005], [93.41493225, 23.72261047], [93.41551971, 23.71809959], [93.41694641, 23.71212959], [93.41912079, 23.70842171], [93.4233017, 23.70399094], [93.42957306, 23.7007103], [93.43651581, 23.69617844], [93.43865967, 23.69219971], [93.44139862, 23.68832016], [93.44470215, 23.68242836], [93.44094086, 23.67819977], [93.43908691, 23.67573929], [93.43611908, 23.67178917], [93.4334259, 23.66719055], [93.43036652, 23.66023064], [93.42827606, 23.65354919], [93.42861938, 23.64515114], [93.42867279, 23.64480972], [93.43271637, 23.61876106], [93.43341064, 23.59509087], [93.43474579, 23.58884048], [93.43305206, 23.58243942], [93.42710876, 23.57169151], [93.42397308, 23.5693512], [93.42402649, 23.56158066], [93.42724609, 23.55298042], [93.42809296, 23.54520035], [93.42775726, 23.53824806], [93.42764282, 23.53437042], [93.42556, 23.53121185], [93.42192841, 23.52716064], [93.41620636, 23.52048111], [93.41116333, 23.51325035], [93.40762329, 23.50848007], [93.4072876, 23.50197029], [93.40814972, 23.49646187], [93.40437317, 23.48498917], [93.40593719, 23.48101044], [93.40706635, 23.47531128], [93.40596008, 23.4672699], [93.40141296, 23.45697975], [93.39977264, 23.44687271], [93.39850616, 23.44288063], [93.39718628, 23.43331146], [93.3973465, 23.42617035], [93.3968277, 23.42247009], [93.39759827, 23.41550064], [93.39826202, 23.4112606], [93.40390778, 23.40166855], [93.40576172, 23.39760017], [93.40975189, 23.39190102], [93.41423798, 23.38801193], [93.40460968, 23.38349915], [93.4016571, 23.37953949], [93.39644623, 23.37402916], [93.39652252, 23.36806107], [93.39875031, 23.36427116], [93.38983917, 23.36275101], [93.37631989, 23.36259079], [93.37162018, 23.3597908], [93.36746979, 23.35808945], [93.36580658, 23.35448074], [93.36629486, 23.35347748], [93.36802673, 23.34994125], [93.37201691, 23.34424973], [93.37534332, 23.34099007], [93.3777771, 23.33754921], [93.37932587, 23.33267975], [93.37754822, 23.32679939], [93.37673187, 23.3194809], [93.37699127, 23.31278992], [93.3776474, 23.30655289], [93.379776, 23.30122185], [93.3812027, 23.29361916], [93.3812027, 23.28992081], [93.37825012, 23.28676033], [93.37539673, 23.28261948], [93.37506104, 23.27457047], [93.37726593, 23.26416969], [93.37841797, 23.25613022], [93.38326263, 23.2448101], [93.38841248, 23.23496056], [93.39470673, 23.2242794], [93.39480591, 23.2195797], [93.38743591, 23.21120071], [93.38659668, 23.20198059], [93.38526154, 23.18797112], [93.38150024, 23.17488289], [93.38057709, 23.16690826], [93.37811279, 23.16349983], [93.3760376, 23.15888023], [93.37394714, 23.15030098], [93.37911224, 23.14361], [93.38292694, 23.14468193], [93.39066315, 23.14792061], [93.39447784, 23.14440155], [93.39364624, 23.13861275], [93.38195801, 23.12751007], [93.37609863, 23.12399101], [93.37227631, 23.12264252], [93.3690567, 23.12058067], [93.36502075, 23.11668968], [93.3640213, 23.11273003], [93.36399841, 23.10621071], [93.36353302, 23.10309029], [93.36308289, 23.10007095], [93.36199951, 23.09537125], [93.35736847, 23.09095001], [93.35246277, 23.08462906], [93.35108948, 23.08030128], [93.35820007, 23.07794189], [93.35781097, 23.07539368], [93.35740662, 23.07278061], [93.35296631, 23.06483078], [93.34516907, 23.06476021], [93.34503937, 23.06448364], [93.34063721, 23.05519104], [93.33676147, 23.04362106], [93.3326416, 23.03567123], [93.32959747, 23.03161049], [93.32408905, 23.02493095], [93.32124329, 23.02186012], [93.31550598, 23.02211761], [93.31498718, 23.0221405], [93.31176758, 23.01871109], [93.3061676, 23.01365089], [93.30195618, 23.00831985], [93.29772186, 23.00579834], [93.29590607, 23.00546455], [93.29332733, 23.00498962], [93.28816223, 23.00462914], [93.27858734, 23.00564003], [93.27391815, 23.01025963], [93.26806641, 23.01234055], [93.25905609, 23.00872993], [93.25319672, 23.00648117], [93.2477417, 23.00955963], [93.24120331, 23.01408005], [93.2378006, 23.01761818], [93.23409271, 23.02186012], [93.23166656, 23.02711105], [93.22815704, 23.03281975], [93.2201767, 23.04520035], [93.21405792, 23.04935074], [93.20616913, 23.05686951], [93.2011795, 23.05778122], [93.19445038, 23.06031036], [93.19093323, 23.05822945], [93.1871109, 23.05715179], [93.18693542, 23.05718422], [93.18302155, 23.05796814], [93.17682648, 23.0530777], [93.17672729, 23.0529995], [93.17211914, 23.05083084], [93.16783142, 23.04902077], [93.16197968, 23.05191994], [93.15563965, 23.05807114], [93.14733887, 23.06169128], [93.14185333, 23.06060982], [93.14028931, 23.0564518], [93.13848114, 23.05482101], [93.13761902, 23.05404282], [93.13687134, 23.05336952], [93.1329422, 23.04750061], [93.13335419, 23.04636955], [93.1350708, 23.04162979], [93.13582611, 23.03520966], [93.13436127, 23.03123093], [93.13162994, 23.02589989], [93.13414001, 23.01984024], [93.13578796, 23.01288033], [93.13021088, 23.00645065], [93.12919617, 23.00076866], [93.13340759, 22.99607086], [93.13739014, 22.99417114], [93.1425705, 22.9937191], [93.14499664, 22.98775101], [93.14762115, 22.98060036], [93.14808655, 22.97555161], [93.14652252, 22.97084808], [93.14272308, 22.96858978], [93.14250183, 22.96442032], [93.14620972, 22.96118164], [93.1488266, 22.95647049], [93.15164185, 22.94997025], [93.15260315, 22.9414711], [93.15344238, 22.93062019], [93.15724945, 22.92673111], [93.16172028, 22.9244709], [93.16610718, 22.92247963], [93.16835022, 22.91913033], [93.16648865, 22.9158802], [93.16366577, 22.91409492], [93.16277313, 22.91353035], [93.15857697, 22.91362], [93.15233612, 22.91291046], [93.14597321, 22.91290283], [93.1387558, 22.9131794], [93.13522339, 22.90722084], [93.1388092, 22.90017128], [93.13832855, 22.89339066], [93.137146, 22.88959122], [93.13555145, 22.88255119], [93.1332016, 22.87520981], [93.13024902, 22.86943054], [93.12387848, 22.86591148], [93.12166595, 22.86275291], [93.12084961, 22.85479164], [93.12151337, 22.84340286], [93.1207962, 22.8373394], [93.11664581, 22.83261871], [93.1156311, 22.83146286], [93.11122131, 22.82821274], [93.11266327, 22.82216072], [93.11544037, 22.82125854], [93.11656952, 22.82089043], [93.11618805, 22.81628036], [93.11435699, 22.81537056], [93.10925293, 22.81283951], [93.10426331, 22.81176186], [93.09926605, 22.81040955], [93.10283661, 22.79214287], [93.10365295, 22.7887001], [93.10402679, 22.78711128], [93.10797119, 22.77026939], [93.11134338, 22.75300026], [93.11268616, 22.74423981], [93.10916138, 22.73781967], [93.10456085, 22.73167038], [93.10192108, 22.72742081], [93.10083771, 22.71955109], [93.09906006, 22.71430969], [93.09545135, 22.71107101], [93.0917511, 22.70934105], [93.09794617, 22.70129967], [93.10417175, 22.69614983], [93.10688782, 22.68629074], [93.10668945, 22.68177032], [93.10315704, 22.67869949], [93.10354614, 22.67408943], [93.10482025, 22.67020035], [93.1074295, 22.6641407], [93.11062622, 22.65908051], [93.11451721, 22.65492058], [93.11849976, 22.65148163], [93.11477661, 22.63919067], [93.11689758, 22.63512039], [93.12428284, 22.63005066], [93.12954712, 22.62924194], [93.13635254, 22.62290955], [93.1390686, 22.61820984], [93.14292908, 22.60762978], [93.14437103, 22.59885979], [93.14560699, 22.58612251], [93.13664246, 22.5818367], [93.13595581, 22.58151054], [93.13371277, 22.57733917], [93.13352966, 22.57722282], [93.12921906, 22.57446289], [93.12442017, 22.56705093], [93.12159729, 22.56000137], [93.11778259, 22.55891037], [93.11553192, 22.55474854], [93.11562347, 22.5538826], [93.11649323, 22.54580116], [93.11599731, 22.54047012], [93.11441803, 22.53685951], [93.11192322, 22.53223228], [93.11168671, 22.53178978], [93.11206818, 22.53164673], [93.11985016, 22.52870941], [93.12578583, 22.52853966], [93.13085175, 22.52610016], [93.13365936, 22.51993942], [93.13062286, 22.51398087], [93.12886047, 22.50982094], [93.13059235, 22.50592995], [93.13272095, 22.50177193], [93.13526154, 22.49897003], [93.13777924, 22.49509048], [93.13832855, 22.48658943], [93.13626862, 22.47961998], [93.13452148, 22.4748497], [93.13514709, 22.47390556], [93.13819122, 22.4693203], [93.14206696, 22.46326065], [93.14575195, 22.45846939], [93.14972687, 22.45593071], [93.15672302, 22.45214081], [93.16277313, 22.45376015], [93.17542267, 22.45132065], [93.17811584, 22.44662094], [93.18218994, 22.43875122], [93.18789673, 22.43367004], [93.19081116, 22.42725945], [93.18904114, 22.42328072], [93.18826294, 22.41893959], [93.1889267, 22.41351128], [93.19425964, 22.40890121], [93.19551086, 22.40330124], [93.19325256, 22.3991394], [93.19149017, 22.39587975], [93.19226837, 22.3908329], [93.19641113, 22.38412285], [93.19738007, 22.37997246], [93.19258881, 22.37083817], [93.19451141, 22.36343002], [93.1971283, 22.35863113], [93.19998169, 22.34361839], [93.19948578, 22.33719826], [93.20266724, 22.33366966], [93.20656586, 22.32953072], [93.20287323, 22.32726288], [93.19634247, 22.32464027], [93.19843292, 22.32011032], [93.1995163, 22.3177681], [93.20057678, 22.31315041], [93.20133972, 22.30610085], [93.2016983, 22.29986], [93.20108795, 22.29199028], [93.20155334, 22.28647995], [93.20192719, 22.28087044], [93.2039566, 22.2757225], [93.2073288, 22.26967049], [93.20925903, 22.26622009], [93.20858002, 22.26106834], [93.19641113, 22.25564957], [93.19036865, 22.24969292], [93.18366241, 22.24913979], [93.17093658, 22.24970055], [93.16597748, 22.24888039], [93.16033936, 22.24707985], [93.15718842, 22.24743271], [93.15463257, 22.24771881], [93.15149689, 22.24806976], [93.14710999, 22.24654007], [93.14643097, 22.24111176], [93.15194702, 22.23468971], [93.1565094, 22.22871971], [93.15764618, 22.22311974], [93.15627289, 22.21742058], [93.15856934, 22.21120262], [93.15907288, 22.20984077], [93.16594696, 22.20522118], [93.16982269, 22.20005989], [93.16677094, 22.19434166], [93.16639709, 22.19363976], [93.16537476, 22.19028473], [93.16295624, 22.18234062], [93.15441132, 22.17819023], [93.14839172, 22.17683029], [93.14286804, 22.1767807], [93.13868713, 22.17674065], [93.13070679, 22.1790905], [93.1275177, 22.18235016], [93.12277985, 22.18904114], [93.11988068, 22.1985302], [93.11717987, 22.20133018], [93.11238861, 22.20080376], [93.11154175, 22.2007103], [93.10221863, 22.19880104], [93.09726715, 22.19934082], [93.08882141, 22.20260048], [93.08769226, 22.20357513], [93.08589935, 22.20512962], [93.08154297, 22.20839119], [93.07698822, 22.21010971], [93.07247162, 22.20852661], [93.07154083, 22.20820045], [93.06764984, 22.20639038], [93.05977631, 22.20395279], [93.0538559, 22.2032299], [93.0491333, 22.19954491], [93.04830933, 22.19890022], [93.04666138, 22.19762039], [93.04608917, 22.19658852], [93.0456543, 22.19579697], [93.04450989, 22.1937294], [93.04653931, 22.19001961], [93.05370331, 22.1758194], [93.05493927, 22.16543007], [93.05200958, 22.15666008], [93.05082703, 22.15014076], [93.04801941, 22.14581108], [93.04698944, 22.13905907], [93.04692841, 22.13866997], [93.05409241, 22.13170052], [93.05921936, 22.12754059], [93.06260681, 22.12086105], [93.06648254, 22.11326981], [93.06556702, 22.10205269], [93.05976105, 22.09979057], [93.05208588, 22.09924126], [93.04627228, 22.10132027], [93.03917694, 22.10493088], [93.03649139, 22.10493088], [93.03219604, 22.10493088], [93.02297974, 22.10564995], [93.01597595, 22.10547066], [93.01326752, 22.102211], [93.01325226, 22.09805107], [93.01558685, 22.09308052], [93.01449585, 22.0852108], [93.0117569, 22.07933044], [93.0080719, 22.06991959], [93.00377655, 22.0611496], [93.00076294, 22.05564117], [92.99996948, 22.05038071], [92.99994659, 22.03954124], [93.00066376, 22.03629875], [93.00158691, 22.03212166], [93.00671387, 22.02301216], [93.00845337, 22.01992035], [93.01037598, 22.01115036], [93.00958252, 22.00265121], [93.01014709, 21.99578094], [93.00985718, 21.9917202], [93.00924683, 21.98393059], [93.00662994, 21.97986031], [92.99897766, 21.97794914], [92.99238586, 21.98084068], [92.98802948, 21.98291969], [92.98739624, 21.98496056], [92.98580933, 21.99006271], [92.98175049, 22.00189972], [92.97953033, 22.0064106], [92.9731369, 22.00995255], [92.9694519, 22.01411057], [92.96692657, 22.02025986], [92.96656799, 22.02712059], [92.9609375, 22.03018951], [92.95580292, 22.02992058], [92.95281982, 22.02738571], [92.95111847, 22.02593994], [92.94843292, 22.02286148], [92.94210815, 22.01834106], [92.94023895, 22.0187664], [92.93463898, 22.02004051], [92.93161011, 22.01750946], [92.93395996, 22.01475143], [92.93569183, 22.01272011], [92.93908691, 22.00855827], [92.93216705, 22.00186157], [92.92771149, 21.99588966], [92.92479706, 21.98711014], [92.92225647, 21.98080254], [92.91944885, 21.97382164], [92.91575623, 21.96504974], [92.91446686, 21.95663071], [92.91610718, 21.94940948], [92.91088867, 21.94622993], [92.90797424, 21.95045471], [92.90583801, 21.95355034], [92.90471649, 21.98076057], [92.90133667, 21.99035072], [92.89640808, 22.00390053], [92.89425659, 22.01196289], [92.88942719, 22.01818275], [92.88574219, 22.02152061], [92.87953949, 22.02593994], [92.87467957, 22.03009987], [92.87246704, 22.03651047], [92.87130737, 22.04664993], [92.87014771, 22.05424118], [92.87016296, 22.06075096], [92.86773682, 22.06536293], [92.86328125, 22.06762123], [92.856987, 22.06563187]]]}}, {\\\"id\\\": \\\"21\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.24_1\\\", \\\"HASC_1\\\": \\\"IN.NL\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Nagaland\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 22.7, \\\"dalys_apm25_rate_6cod_mean_total\\\": 711.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1847.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2558.0, \\\"geo-id\\\": 21, \\\"hpm25_child_popweighted\\\": 152.5, \\\"hpm25_female_popweighted\\\": 175.2, \\\"hpm25_male_popweighted\\\": 126.2, \\\"location\\\": \\\"Nagaland\\\", \\\"mort_apm25_6cod_mean_total\\\": 419.0, \\\"mort_hpm25_6cod_mean_total\\\": 1085.0, \\\"mort_tpm25_6cod_mean_total\\\": 1504.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[93.33174133, 25.54681015], [93.33338165, 25.54902077], [93.34126282, 25.55485916], [93.34546661, 25.56112099], [93.34831238, 25.56321907], [93.35439301, 25.56520081], [93.36070251, 25.56043816], [93.36418152, 25.56064987], [93.36598206, 25.56326103], [93.36515808, 25.56976128], [93.36943817, 25.57025909], [93.37342072, 25.56917191], [93.37599182, 25.57104111], [93.37683868, 25.57374001], [93.37648773, 25.57731056], [93.38269806, 25.5761795], [93.38474274, 25.57792091], [93.38503265, 25.58119965], [93.38311005, 25.58279991], [93.38240051, 25.58475113], [93.39063263, 25.58909988], [93.3900528, 25.59472084], [93.40019989, 25.59628105], [93.40683746, 25.59647942], [93.40924835, 25.60041046], [93.40963745, 25.60410118], [93.40722656, 25.60649109], [93.40763855, 25.60942078], [93.40904999, 25.61169052], [93.41227722, 25.61367989], [93.41677856, 25.61488914], [93.41487122, 25.61664009], [93.41829681, 25.62105942], [93.42247009, 25.62226105], [93.42753601, 25.63145828], [93.43102264, 25.62920189], [93.43418121, 25.62986946], [93.43908691, 25.63233948], [93.4391861, 25.63439941], [93.44152069, 25.63478088], [93.44439697, 25.63804245], [93.4467926, 25.63881111], [93.44993591, 25.63493156], [93.45198059, 25.63747978], [93.45935822, 25.63312912], [93.46195984, 25.63339043], [93.46121979, 25.6365509], [93.45860291, 25.6384201], [93.45713806, 25.64059067], [93.46070099, 25.64154816], [93.46556854, 25.64419174], [93.46852875, 25.64376068], [93.47477722, 25.64429092], [93.47593689, 25.64798927], [93.48335266, 25.64576912], [93.4835968, 25.6517601], [93.48721313, 25.65047073], [93.49072266, 25.65343857], [93.49019623, 25.65596962], [93.49394226, 25.65526009], [93.49991608, 25.65652084], [93.50208282, 25.66201973], [93.50829315, 25.66681099], [93.51019287, 25.67102051], [93.52028656, 25.68367004], [93.51938629, 25.68597031], [93.51683807, 25.6880703], [93.52272797, 25.69320107], [93.52593994, 25.6996727], [93.52855682, 25.69376945], [93.53057098, 25.69269943], [93.53149414, 25.69400597], [93.53797913, 25.70319939], [93.54355621, 25.70170021], [93.54441833, 25.70590019], [93.54592896, 25.71018982], [93.54881287, 25.7147007], [93.5497818, 25.71897125], [93.54619598, 25.72151947], [93.54483795, 25.72697067], [93.54669952, 25.73447037], [93.54988098, 25.73244095], [93.55692291, 25.73773956], [93.55626678, 25.7419281], [93.56194305, 25.74094963], [93.56548309, 25.74134064], [93.57006073, 25.7517395], [93.56925201, 25.7550106], [93.57341766, 25.75661087], [93.57382202, 25.75966072], [93.57324982, 25.76079941], [93.58377075, 25.75774956], [93.58718872, 25.75945091], [93.58712006, 25.76555061], [93.58822632, 25.76815033], [93.59266663, 25.76624107], [93.59371185, 25.76428986], [93.5983429, 25.76836014], [93.60275269, 25.77082062], [93.60556793, 25.76745987], [93.60571289, 25.77263069], [93.60807037, 25.77687073], [93.61141205, 25.77649117], [93.62232971, 25.77983093], [93.62355804, 25.78392029], [93.6211319, 25.78523064], [93.62381744, 25.79042816], [93.62695313, 25.79160118], [93.62753296, 25.79862976], [93.62979889, 25.79998016], [93.6289978, 25.80439949], [93.63334656, 25.80524063], [93.63405609, 25.80997086], [93.63611603, 25.81368065], [93.64029694, 25.81343079], [93.64099884, 25.81792068], [93.64435577, 25.81957054], [93.64849091, 25.82397079], [93.65235901, 25.82282066], [93.65673828, 25.82635117], [93.66082764, 25.82438087], [93.66860962, 25.82463074], [93.66950989, 25.82879257], [93.67256165, 25.82812119], [93.67806244, 25.82887077], [93.68287659, 25.83575058], [93.68250275, 25.84070015], [93.6920166, 25.84412956], [93.6905365, 25.84756851], [93.69377136, 25.84724998], [93.69785309, 25.85131264], [93.70359039, 25.85350037], [93.70363617, 25.84970093], [93.70237732, 25.84699059], [93.70548248, 25.84863091], [93.70643616, 25.85329056], [93.69090271, 25.88927078], [93.68582916, 25.90493965], [93.68768311, 25.90944099], [93.69767761, 25.91706848], [93.70506287, 25.92127991], [93.71250916, 25.92267036], [93.71650696, 25.9217205], [93.72894287, 25.92839813], [93.7364502, 25.93053818], [93.75009155, 25.93728065], [93.75184631, 25.93637085], [93.75202179, 25.9396019], [93.74941254, 25.94205093], [93.7588501, 25.94869041], [93.76278687, 25.95492935], [93.76841736, 25.95504951], [93.77025604, 25.95350075], [93.76954651, 25.95799065], [93.77301788, 25.96602058], [93.77881622, 25.96325111], [93.78028107, 25.96060944], [93.78518677, 25.95829964], [93.78660583, 25.95423126], [93.78942108, 25.95258141], [93.7891922, 25.94901085], [93.78659821, 25.9474411], [93.78940582, 25.94602013], [93.79067993, 25.94419098], [93.79141998, 25.94005013], [93.7932663, 25.93674088], [93.78862, 25.93296051], [93.79321289, 25.93098068], [93.79360962, 25.92604065], [93.79226685, 25.92251968], [93.7963028, 25.91819191], [93.79833221, 25.90969276], [93.79811096, 25.90628815], [93.79573059, 25.90121078], [93.79514313, 25.89804077], [93.79184723, 25.89491272], [93.79145813, 25.89005852], [93.7874527, 25.87892914], [93.78827667, 25.87572098], [93.79064178, 25.8737812], [93.79181671, 25.86969185], [93.78578186, 25.86689949], [93.78528595, 25.86326027], [93.78147125, 25.8592701], [93.78359222, 25.85392952], [93.78296661, 25.85140038], [93.78380585, 25.84996033], [93.7798233, 25.84630966], [93.78108978, 25.84464073], [93.78259277, 25.8382206], [93.78452301, 25.8357811], [93.78734589, 25.82796288], [93.78875732, 25.82601929], [93.79070282, 25.82080078], [93.7913208, 25.8160305], [93.79576111, 25.81435013], [93.80758667, 25.81633759], [93.81157684, 25.82126999], [93.81884003, 25.8262291], [93.82137299, 25.83240128], [93.82430267, 25.84709167], [93.83274078, 25.85625076], [93.84233856, 25.86260986], [93.85170746, 25.86297035], [93.86872864, 25.85540962], [93.87362671, 25.85091972], [93.88273621, 25.84590912], [93.8885498, 25.85246086], [93.89161682, 25.85864067], [93.89340973, 25.86481094], [93.89861298, 25.86375046], [93.90184021, 25.87103081], [93.91382599, 25.88176918], [93.91590118, 25.88766289], [93.92385101, 25.88980293], [93.93463135, 25.8914299], [93.94019318, 25.90096092], [93.94835663, 25.90120125], [93.95983887, 25.90525055], [93.96075439, 25.90585518], [93.96916962, 25.91142273], [93.97197723, 25.9175396], [93.97939301, 25.91967964], [93.98268127, 25.92626953], [93.97109222, 25.94485283], [93.97084808, 25.95326042], [93.96920776, 25.96084023], [93.95600891, 25.97418976], [93.95804596, 25.9815712], [93.96058655, 25.99700928], [93.95897675, 26.00245857], [93.95598602, 26.00457001], [93.95488739, 26.00732994], [93.95838165, 26.01189041], [93.96266174, 26.02215958], [93.96312714, 26.0333519], [93.96588898, 26.04240036], [93.97263336, 26.04496193], [93.97450256, 26.05216026], [93.98081207, 26.0586319], [93.99111938, 26.07263947], [93.98938751, 26.07411957], [93.98602295, 26.08356857], [93.98642731, 26.0883007], [93.9909668, 26.08949089], [93.99249268, 26.09278107], [93.99217224, 26.09782982], [93.994133, 26.10608864], [93.99957275, 26.10847092], [94.00216675, 26.11137962], [94.00213623, 26.11486053], [93.99986267, 26.11590958], [93.99495697, 26.11570168], [93.99124146, 26.11812019], [93.99282074, 26.12026978], [93.99648285, 26.12236977], [93.99661255, 26.1281395], [93.99832916, 26.12935829], [93.99830627, 26.13097954], [93.99326324, 26.13281822], [93.99075317, 26.13387108], [93.99320221, 26.13739014], [93.99627686, 26.13741112], [93.99965668, 26.1364994], [94.00309753, 26.13902092], [94.00522614, 26.14186096], [94.00636292, 26.14723969], [94.0029068, 26.15133858], [93.99965668, 26.15824127], [94.00434875, 26.16407013], [94.00389862, 26.16938019], [94.00480652, 26.17327118], [94.00876617, 26.18053055], [94.01300049, 26.1862812], [94.0219574, 26.19145966], [94.02661896, 26.19714928], [94.03109741, 26.19939041], [94.03573608, 26.20318985], [94.03681946, 26.20972061], [94.03656006, 26.21771049], [94.04046631, 26.22351074], [94.03816986, 26.22951126], [94.04178619, 26.23389053], [94.04421997, 26.23996925], [94.0491333, 26.25021172], [94.05285645, 26.25579071], [94.06463623, 26.26177025], [94.07047272, 26.26003075], [94.07601929, 26.26923943], [94.07781982, 26.27535057], [94.07682037, 26.28520012], [94.08006287, 26.28881073], [94.08444214, 26.28860092], [94.08722687, 26.29042053], [94.09028625, 26.29713058], [94.09807587, 26.30294037], [94.10267639, 26.30869102], [94.10447693, 26.32204056], [94.10804749, 26.32640076], [94.11128998, 26.3260498], [94.1184082, 26.32271957], [94.12872314, 26.32324982], [94.11936188, 26.33049011], [94.11936951, 26.33370018], [94.12397003, 26.3359108], [94.13565826, 26.33821869], [94.13877106, 26.34155273], [94.14264679, 26.34213066], [94.14383698, 26.34020042], [94.14224243, 26.3360405], [94.14671326, 26.33542061], [94.14932251, 26.33908081], [94.15453339, 26.33998108], [94.16452026, 26.33934021], [94.17214966, 26.34440994], [94.17550659, 26.34421921], [94.17928314, 26.35083961], [94.17999268, 26.35412025], [94.17533875, 26.35513115], [94.16938019, 26.35406113], [94.1676712, 26.35330963], [94.16446686, 26.36012077], [94.17357635, 26.36757851], [94.17560577, 26.37175941], [94.17549133, 26.37445068], [94.17404938, 26.37782288], [94.17909241, 26.38872147], [94.17694092, 26.39956093], [94.17684174, 26.41341019], [94.17401123, 26.42089081], [94.1765213, 26.42807007], [94.17575836, 26.43180084], [94.18654633, 26.46051025], [94.20111847, 26.46990013], [94.20936584, 26.48372269], [94.21148682, 26.48984909], [94.22361755, 26.5005703], [94.22891998, 26.50326157], [94.23989105, 26.51143074], [94.24482727, 26.51692009], [94.25205231, 26.52773285], [94.25331879, 26.53252983], [94.26257324, 26.54394913], [94.27674103, 26.5588398], [94.2822876, 26.56353951], [94.28978729, 26.5641098], [94.28890991, 26.55990028], [94.28530884, 26.55824089], [94.28483582, 26.5553627], [94.28562164, 26.54656982], [94.28494263, 26.54029083], [94.28562164, 26.53409195], [94.2890625, 26.52517128], [94.28878784, 26.51831818], [94.28707123, 26.51496124], [94.28723907, 26.50852013], [94.29023743, 26.49596977], [94.29242706, 26.49003029], [94.29392242, 26.4807415], [94.30330658, 26.46726036], [94.31098175, 26.46606064], [94.31347656, 26.46500015], [94.31651306, 26.46293068], [94.32430267, 26.47070122], [94.32478333, 26.47220993], [94.32388306, 26.47937965], [94.32932281, 26.48384094], [94.33259583, 26.48502922], [94.33693695, 26.48481941], [94.34340668, 26.49003983], [94.34963226, 26.49284172], [94.35206604, 26.49575043], [94.3518219, 26.49920273], [94.3535614, 26.50215912], [94.35552979, 26.50345039], [94.35372162, 26.50481033], [94.35111237, 26.50862122], [94.35459137, 26.51028061], [94.35874939, 26.50914192], [94.36445618, 26.5103302], [94.36924744, 26.50999069], [94.37761688, 26.51312065], [94.37806702, 26.51716042], [94.37690735, 26.52317047], [94.37827301, 26.52526093], [94.39141083, 26.53282928], [94.39408875, 26.53264046], [94.39656067, 26.52973175], [94.39945221, 26.53232002], [94.39891815, 26.53454971], [94.40248108, 26.53880119], [94.40133667, 26.54408073], [94.40267944, 26.54686165], [94.40674591, 26.5482502], [94.40795135, 26.54971123], [94.40763855, 26.55240059], [94.40479279, 26.55523109], [94.40609741, 26.55738068], [94.40896606, 26.55713081], [94.41195679, 26.5584507], [94.41057587, 26.56059837], [94.40776062, 26.56142807], [94.40930939, 26.56899071], [94.41188049, 26.5734005], [94.41484833, 26.58328056], [94.40600586, 26.60193062], [94.40857697, 26.6097908], [94.40786743, 26.61433029], [94.40988159, 26.61643982], [94.43448639, 26.62537956], [94.45452118, 26.63902092], [94.45681, 26.63664055], [94.46250153, 26.6354599], [94.46482086, 26.63871002], [94.46446228, 26.64036942], [94.46166229, 26.64384079], [94.46141815, 26.64809036], [94.45857239, 26.65534973], [94.46183014, 26.66316032], [94.46452332, 26.66751099], [94.46794128, 26.66982079], [94.48574829, 26.67370033], [94.49279785, 26.67225266], [94.49826813, 26.67371178], [94.5, 26.67516708], [94.50300598, 26.67769051], [94.50714111, 26.68297958], [94.50994873, 26.68342972], [94.51550293, 26.68729973], [94.51967621, 26.69460106], [94.52009583, 26.70145035], [94.52272797, 26.70436859], [94.52776337, 26.70128059], [94.54087067, 26.70963287], [94.5450592, 26.71090126], [94.55036926, 26.71017075], [94.55467224, 26.70844078], [94.56112671, 26.70813942], [94.56343842, 26.70737076], [94.56472778, 26.70600128], [94.56233215, 26.69383049], [94.56295013, 26.69063187], [94.56608582, 26.68992805], [94.57086945, 26.69005966], [94.57469177, 26.69102097], [94.57150269, 26.69622231], [94.58278656, 26.70557976], [94.58538818, 26.70331001], [94.58898163, 26.70244026], [94.59240723, 26.70273018], [94.59493256, 26.7065506], [94.59501648, 26.71236038], [94.59616852, 26.7181797], [94.59831238, 26.71994019], [94.60372162, 26.71617126], [94.60468292, 26.71721077], [94.60463715, 26.71985245], [94.60318756, 26.7238102], [94.60048676, 26.72525978], [94.59333038, 26.72613144], [94.5951767, 26.72989082], [94.59993744, 26.73772049], [94.60414886, 26.7392807], [94.61006165, 26.74010277], [94.61044312, 26.73586082], [94.61194611, 26.73265076], [94.61740112, 26.73055077], [94.62014771, 26.72673988], [94.62108612, 26.72117043], [94.62271881, 26.71953011], [94.6282959, 26.71862984], [94.63197327, 26.71965027], [94.64028931, 26.72397041], [94.64621735, 26.72451019], [94.65338898, 26.72363091], [94.65853882, 26.72480011], [94.66513824, 26.72776031], [94.68660736, 26.73258972], [94.69148254, 26.73575974], [94.69687653, 26.73969078], [94.71140289, 26.75282288], [94.71969604, 26.75803947], [94.73188019, 26.76400948], [94.73651123, 26.76741028], [94.73773193, 26.76885033], [94.74167633, 26.77357101], [94.74236298, 26.77864075], [94.7457962, 26.78214073], [94.75071716, 26.77967072], [94.75409698, 26.77431107], [94.75637054, 26.7722683], [94.75934601, 26.7741375], [94.76003265, 26.77662849], [94.76235962, 26.77993011], [94.76832581, 26.78339767], [94.76906586, 26.79109955], [94.77308655, 26.79496193], [94.7856369, 26.79857063], [94.79078674, 26.80145264], [94.79496002, 26.80373192], [94.80220795, 26.80606079], [94.80535889, 26.81219101], [94.80161285, 26.81381035], [94.79664612, 26.81851959], [94.80671692, 26.82122993], [94.80918121, 26.82328033], [94.81305695, 26.82476044], [94.81507111, 26.8300209], [94.8154068, 26.83680916], [94.81669617, 26.84147072], [94.8210907, 26.84486961], [94.82173157, 26.84930992], [94.82108307, 26.85445976], [94.82628632, 26.85931015], [94.83226013, 26.86271095], [94.8364563, 26.8684597], [94.83878326, 26.87400055], [94.84584045, 26.876791], [94.85153198, 26.88134003], [94.85334778, 26.88533974], [94.85900879, 26.89328003], [94.8653183, 26.90690994], [94.86862183, 26.90989113], [94.86963654, 26.91500854], [94.88154602, 26.92671013], [94.88622284, 26.93246078], [94.89447021, 26.93733025], [94.90129089, 26.94034004], [94.90882111, 26.94227028], [94.91385651, 26.94256973], [94.91799164, 26.94514275], [94.92376709, 26.95033073], [94.92816162, 26.95210075], [94.93360138, 26.93853951], [94.93855286, 26.93797112], [94.94122314, 26.93927193], [94.94709015, 26.94020081], [94.95728302, 26.94355011], [94.96417236, 26.9406414], [94.96676636, 26.93618011], [94.96794128, 26.93148994], [94.97067261, 26.92836189], [94.97425842, 26.92760277], [94.97966003, 26.92462158], [94.985672, 26.91824913], [94.98944855, 26.91782951], [94.99205017, 26.91838837], [94.99118805, 26.92292023], [94.99305725, 26.92616081], [94.99946594, 26.9242897], [95.00579071, 26.92486954], [95.01657104, 26.92435265], [95.02134705, 26.92539978], [95.02855682, 26.93251038], [95.03804779, 26.93848038], [95.05464935, 26.94087982], [95.06533813, 26.94819069], [95.08686066, 26.95274162], [95.11004639, 26.96690941], [95.11322021, 26.97232056], [95.1135025, 26.97758102], [95.11694336, 26.98368073], [95.12638092, 26.98690987], [95.13698578, 26.99357986], [95.14276123, 26.99830055], [95.14948273, 26.99983978], [95.15450287, 27.00604057], [95.19551849, 27.04294968], [95.19579315, 27.03250122], [95.19785309, 27.01984024], [95.19761658, 27.01568985], [95.20008087, 27.0062294], [95.19982147, 26.99935913], [95.19626617, 26.99781036], [95.19519806, 26.98999023], [95.20043945, 26.98555946], [95.20775604, 26.98470116], [95.20996094, 26.98262978], [95.20522308, 26.9821701], [95.20655823, 26.9788208], [95.20877075, 26.97508049], [95.21504211, 26.97037125], [95.21366882, 26.96812057], [95.20883942, 26.9653511], [95.20675659, 26.96259117], [95.20851135, 26.9607296], [95.21341705, 26.95878983], [95.20923615, 26.95667076], [95.21219635, 26.94334984], [95.21444702, 26.93695068], [95.21705627, 26.93420029], [95.22556305, 26.93442917], [95.22930908, 26.93063164], [95.23184967, 26.92614174], [95.23396301, 26.92060089], [95.23396301, 26.91875267], [95.23195648, 26.91789055], [95.23208618, 26.91483116], [95.23410034, 26.9096508], [95.23377228, 26.90590286], [95.23132324, 26.89834976], [95.2338562, 26.89084053], [95.22992706, 26.88566971], [95.21782684, 26.88686943], [95.21285248, 26.88560295], [95.21135712, 26.88173294], [95.20642853, 26.87787056], [95.18450165, 26.86483002], [95.18576813, 26.85963058], [95.19304657, 26.85116959], [95.19561005, 26.84962082], [95.19732666, 26.84939194], [95.19770813, 26.85153961], [95.20423889, 26.8489399], [95.20860291, 26.85071945], [95.20641327, 26.84628105], [95.20050812, 26.84287834], [95.19904327, 26.83992958], [95.20056152, 26.83288956], [95.20258331, 26.82875061], [95.20355225, 26.82131958], [95.20684052, 26.81169128], [95.21511841, 26.7983799], [95.22157288, 26.79354095], [95.2274704, 26.79234123], [95.23501587, 26.78928947], [95.24025726, 26.78917122], [95.24172211, 26.78693008], [95.24491882, 26.78733063], [95.24253845, 26.78451157], [95.23467255, 26.78034973], [95.23163605, 26.77769279], [95.23330688, 26.77371979], [95.23317719, 26.77193069], [95.22920227, 26.76847076], [95.22408295, 26.76172256], [95.2201004, 26.75982094], [95.21926117, 26.75555038], [95.22136688, 26.75152016], [95.22097778, 26.7474308], [95.21685028, 26.74130058], [95.21614075, 26.73531914], [95.22820282, 26.72384834], [95.2296524, 26.71688271], [95.23610687, 26.7122097], [95.23369598, 26.69709969], [95.23596954, 26.69152069], [95.23597717, 26.68823051], [95.23763275, 26.68629074], [95.23449707, 26.68307114], [95.23166656, 26.6776104], [95.22805786, 26.67307091], [95.22743225, 26.67202187], [95.22473145, 26.66752052], [95.21948242, 26.66065025], [95.21485901, 26.6556797], [95.20983887, 26.65150833], [95.20780945, 26.65019608], [95.20616913, 26.64912987], [95.1969986, 26.64735985], [95.19127655, 26.64771843], [95.18202209, 26.64326096], [95.17431641, 26.63418007], [95.17141724, 26.63006973], [95.16478729, 26.62660217], [95.16137695, 26.62482262], [95.15833282, 26.62322998], [95.15470886, 26.61948967], [95.1537323, 26.60957909], [95.15248871, 26.60183907], [95.15220642, 26.59761047], [95.1530304, 26.59361839], [95.15622711, 26.58681107], [95.15448761, 26.58080292], [95.15081787, 26.57681847], [95.14875031, 26.5745697], [95.14450073, 26.56788063], [95.14442444, 26.56365013], [95.14441681, 26.56301117], [95.14274597, 26.56228828], [95.1385498, 26.56047249], [95.13384247, 26.56235123], [95.1268158, 26.56235123], [95.12468719, 26.55661011], [95.12132263, 26.55295181], [95.11479187, 26.54800034], [95.11642456, 26.5447979], [95.1190567, 26.53964806], [95.12077332, 26.53447914], [95.12078094, 26.52979088], [95.11315155, 26.51871109], [95.11251068, 26.51838112], [95.10684967, 26.51547813], [95.10349274, 26.51288986], [95.10462189, 26.50909996], [95.10241699, 26.50317955], [95.09599304, 26.49847984], [95.09099579, 26.49459076], [95.08790588, 26.49065971], [95.08403015, 26.48594284], [95.08200836, 26.48358917], [95.08042145, 26.48174095], [95.07920074, 26.48060799], [95.07602692, 26.47766113], [95.07578278, 26.47587013], [95.07543945, 26.47333908], [95.07232666, 26.46982956], [95.07196045, 26.46941948], [95.06878662, 26.4666729], [95.06720734, 26.46154976], [95.06630707, 26.45677948], [95.06640625, 26.45037079], [95.07171631, 26.4503994], [95.07508087, 26.45243263], [95.07630157, 26.4525795], [95.08161926, 26.4532299], [95.08702087, 26.45198822], [95.09056091, 26.44725037], [95.09681702, 26.43939972], [95.09998322, 26.43602943], [95.10151672, 26.43267059], [95.10618591, 26.42999077], [95.1086731, 26.42373085], [95.1076889, 26.41880035], [95.1058197, 26.41502953], [95.10544586, 26.41106033], [95.10495758, 26.40646935], [95.10476685, 26.40125084], [95.12166595, 26.39804077], [95.12503815, 26.39546967], [95.13085175, 26.39060974], [95.13574219, 26.38783264], [95.13594055, 26.38323021], [95.13458252, 26.37568283], [95.13191223, 26.36670113], [95.12973022, 26.36203957], [95.1282959, 26.35466194], [95.13165283, 26.3465004], [95.13347626, 26.34259987], [95.12753296, 26.3359108], [95.1280365, 26.33068085], [95.12822723, 26.32925987], [95.12874603, 26.32534981], [95.12937164, 26.32164192], [95.12989807, 26.3172226], [95.13123322, 26.30737114], [95.13153839, 26.30258179], [95.13082886, 26.29655075], [95.13114929, 26.29249954], [95.12979126, 26.28872108], [95.12709045, 26.28498077], [95.12126923, 26.27937126], [95.12069702, 26.27487183], [95.12268829, 26.26870918], [95.12490845, 26.2642498], [95.1287384, 26.26023293], [95.12966919, 26.25617027], [95.12831879, 26.25258064], [95.1257782, 26.24583817], [95.12290192, 26.2425499], [95.12123108, 26.23870087], [95.12313843, 26.23298073], [95.12837219, 26.22949028], [95.13320923, 26.22564125], [95.14058685, 26.21813011], [95.14253998, 26.21424103], [95.13822937, 26.20924187], [95.13420105, 26.20767021], [95.1282959, 26.2031498], [95.12467194, 26.19662094], [95.12773132, 26.19395828], [95.12581635, 26.18272018], [95.12298584, 26.1763382], [95.12021637, 26.17225075], [95.11805725, 26.16893959], [95.11683655, 26.16300964], [95.12049866, 26.15510941], [95.12378693, 26.14911079], [95.12787628, 26.13697052], [95.12535858, 26.13132286], [95.12317657, 26.12766266], [95.12088776, 26.12199974], [95.12056732, 26.10974121], [95.12325287, 26.1042099], [95.12671661, 26.10099983], [95.13150024, 26.10031128], [95.13804626, 26.10255814], [95.14422607, 26.10095024], [95.14797974, 26.09791946], [95.15162659, 26.09489059], [95.15746307, 26.0961628], [95.16591644, 26.09901047], [95.17098999, 26.09678268], [95.17698669, 26.09227943], [95.18015289, 26.08980942], [95.18535614, 26.08468246], [95.18569946, 26.08035088], [95.18357086, 26.07451057], [95.18161011, 26.07258797], [95.18031311, 26.07131004], [95.17752838, 26.0675602], [95.17302704, 26.06175995], [95.16805267, 26.05776978], [95.16557312, 26.05337906], [95.16519165, 26.04455948], [95.16500092, 26.03887177], [95.16488647, 26.03725052], [95.16471863, 26.03500175], [95.1626358, 26.03141975], [95.16140747, 26.0302906], [95.14891052, 26.01881027], [95.14264679, 26.01086807], [95.14066315, 26.00647163], [95.1366272, 26.00418091], [95.13154602, 26.00010109], [95.12798309, 25.99527931], [95.11753845, 25.9877491], [95.11010742, 25.9756794], [95.10971832, 25.9748764], [95.1064682, 25.96815109], [95.10016632, 25.96494675], [95.09335327, 25.96148109], [95.08847809, 25.95757294], [95.07894897, 25.95083809], [95.07344055, 25.94902992], [95.06549835, 25.94767952], [95.05741119, 25.94697762], [95.05306244, 25.94450188], [95.04995728, 25.93922043], [95.04489899, 25.93478966], [95.03669739, 25.93507004], [95.0358429, 25.93147087], [95.03617859, 25.92861176], [95.03636169, 25.9270401], [95.03311157, 25.92438126], [95.0280304, 25.9198494], [95.02186584, 25.90999985], [95.02146149, 25.90901947], [95.02009583, 25.90570068], [95.01933289, 25.90102005], [95.01978302, 25.89800072], [95.02030182, 25.89451027], [95.02217102, 25.88754082], [95.01902771, 25.88479042], [95.01747894, 25.8829422], [95.01557159, 25.88067245], [95.01557159, 25.88053703], [95.01541138, 25.87202072], [95.01824188, 25.86783028], [95.02142334, 25.86185074], [95.02436829, 25.85847092], [95.02754974, 25.85148048], [95.0300293, 25.84931946], [95.03322601, 25.84653091], [95.03371429, 25.84041977], [95.03423309, 25.83389091], [95.03462982, 25.82896042], [95.03475189, 25.8274498], [95.03497314, 25.82641983], [95.03604889, 25.82376289], [95.03748322, 25.82022285], [95.04032898, 25.81703949], [95.04384613, 25.81302071], [95.04937744, 25.81007195], [95.05179596, 25.80517006], [95.05149078, 25.79911995], [95.04759216, 25.78771019], [95.04550171, 25.78279114], [95.04564667, 25.7786293], [95.05252838, 25.76265907], [95.04440308, 25.75329971], [95.04238892, 25.75019646], [95.04068756, 25.74757957], [95.03369141, 25.74143982], [95.02719879, 25.74061966], [95.01888275, 25.73846817], [95.00939941, 25.73851013], [95.00241089, 25.73262978], [94.99931335, 25.72663116], [94.9987793, 25.72210121], [94.99872589, 25.72167969], [94.99323273, 25.7142601], [94.98903656, 25.70907974], [94.9836731, 25.70428085], [94.97991943, 25.70189285], [94.9763031, 25.69950104], [94.97386932, 25.69735718], [94.97316742, 25.6967411], [94.95376587, 25.68344116], [94.94287109, 25.67527962], [94.93757629, 25.66903114], [94.93509674, 25.66455078], [94.9341507, 25.6610527], [94.93263245, 25.65402031], [94.93186951, 25.65201569], [94.92983246, 25.64665985], [94.92662811, 25.64056015], [94.92550659, 25.63235092], [94.92227936, 25.62446976], [94.92090607, 25.61483192], [94.91967773, 25.6111412], [94.91722107, 25.60765266], [94.91146088, 25.60330009], [94.90468597, 25.60140419], [94.90345764, 25.60106087], [94.89572144, 25.59799957], [94.88897705, 25.59311104], [94.88892365, 25.59287453], [94.88916779, 25.59218025], [94.88871765, 25.59200287], [94.88770294, 25.58761978], [94.89189148, 25.58205986], [94.89707947, 25.57740021], [94.90415955, 25.57118034], [94.90499115, 25.56711006], [94.88783264, 25.56541824], [94.85855103, 25.56340218], [94.85678101, 25.56344032], [94.85647583, 25.56332588], [94.85301208, 25.56330109], [94.84993744, 25.56087494], [94.84944153, 25.56068993], [94.84799957, 25.55934906], [94.84342194, 25.55574036], [94.83686066, 25.55048943], [94.83392334, 25.54673004], [94.82979584, 25.53839111], [94.82967377, 25.53486061], [94.82961273, 25.53297997], [94.82884216, 25.52811813], [94.82533264, 25.52094078], [94.82209015, 25.51719093], [94.82023621, 25.51368141], [94.81864929, 25.5068512], [94.81555939, 25.49992752], [94.81249237, 25.49537086], [94.80587769, 25.49336052], [94.79711914, 25.49373055], [94.78983307, 25.49119949], [94.78452301, 25.49017906], [94.77896118, 25.48427963], [94.77274323, 25.48129272], [94.76705933, 25.4824295], [94.76452637, 25.48543167], [94.76232147, 25.49150085], [94.75668335, 25.49201965], [94.75576019, 25.48900032], [94.75541687, 25.48788071], [94.75154877, 25.48250961], [94.74651337, 25.47912979], [94.73921204, 25.47677994], [94.73088837, 25.47470093], [94.7217865, 25.47245979], [94.71463013, 25.47100258], [94.70243073, 25.46860123], [94.70092773, 25.46849632], [94.69567108, 25.46813011], [94.68863678, 25.46549988], [94.68242645, 25.45973015], [94.66976166, 25.45536041], [94.66597748, 25.45540047], [94.65873718, 25.45705032], [94.65645599, 25.458601], [94.64823151, 25.46162033], [94.63297272, 25.46565819], [94.62534332, 25.46908951], [94.60748291, 25.48244095], [94.59736633, 25.48625946], [94.59488678, 25.48814964], [94.5908432, 25.48974991], [94.58719635, 25.49245071], [94.58500671, 25.49687004], [94.57459259, 25.50522995], [94.56817627, 25.50658989], [94.55741882, 25.5127697], [94.55899811, 25.52433968], [94.56125641, 25.53069115], [94.55827332, 25.53487968], [94.56347656, 25.53967285], [94.55986786, 25.54570961], [94.56289673, 25.54951096], [94.56137848, 25.56051064], [94.56465912, 25.56793976], [94.56040955, 25.56798935], [94.5615387, 25.57833099], [94.55574036, 25.58581161], [94.55957031, 25.59411049], [94.5651474, 25.6026001], [94.56690979, 25.60410118], [94.5686264, 25.6077919], [94.57282257, 25.61131287], [94.57691956, 25.62037277], [94.57850647, 25.62625122], [94.58377075, 25.63449097], [94.59050751, 25.64027023], [94.59455109, 25.6426506], [94.59519958, 25.64385033], [94.58693695, 25.64659119], [94.57608795, 25.644701], [94.57723236, 25.64833069], [94.57678986, 25.65283012], [94.58135223, 25.6573925], [94.58204651, 25.6606102], [94.58522034, 25.6617794], [94.58344269, 25.66522026], [94.58558655, 25.67000961], [94.58737183, 25.67180061], [94.58532715, 25.67485046], [94.58812714, 25.67727089], [94.58996582, 25.68124962], [94.59694672, 25.68691063], [94.5956192, 25.69128036], [94.58705139, 25.69189072], [94.58297729, 25.69320107], [94.57861328, 25.69599915], [94.57301331, 25.69765091], [94.56799316, 25.69222069], [94.56507874, 25.68082047], [94.55222321, 25.6674118], [94.5517807, 25.66246033], [94.54473877, 25.65754128], [94.53954315, 25.65108109], [94.53154755, 25.65012932], [94.53066254, 25.64258957], [94.52818298, 25.64429092], [94.52419281, 25.64343262], [94.51451111, 25.63049126], [94.5109024, 25.62990952], [94.50866699, 25.62689972], [94.50779724, 25.61894989], [94.50537109, 25.61699295], [94.50183105, 25.62002182], [94.5, 25.61885643], [94.49993896, 25.61881828], [94.4992981, 25.61650276], [94.49341583, 25.61433029], [94.49111176, 25.61865044], [94.49118042, 25.61979866], [94.47403717, 25.62164116], [94.44927216, 25.60108948], [94.44782257, 25.59804153], [94.44428253, 25.59601021], [94.43773651, 25.59585953], [94.43002319, 25.59272194], [94.42565918, 25.58147049], [94.42237854, 25.57599068], [94.42510223, 25.57299995], [94.4263916, 25.56145096], [94.42559052, 25.55291939], [94.42027283, 25.54265022], [94.41680908, 25.54194069], [94.4108963, 25.54351807], [94.40448761, 25.54089928], [94.38854218, 25.5365696], [94.3646698, 25.5214901], [94.32901001, 25.50835037], [94.32068634, 25.49928093], [94.3135376, 25.4944706], [94.30898285, 25.49380112], [94.30264282, 25.49463272], [94.29899597, 25.50070953], [94.29074097, 25.50951958], [94.28674316, 25.51169968], [94.27986908, 25.5054512], [94.27414703, 25.50299072], [94.26693726, 25.5024395], [94.25726318, 25.50341988], [94.25205994, 25.49907112], [94.23174286, 25.49831009], [94.22914124, 25.49600983], [94.22297668, 25.49677277], [94.21985626, 25.49962997], [94.21485138, 25.50024033], [94.2128067, 25.50282097], [94.21292877, 25.50817108], [94.20690155, 25.51164055], [94.20688629, 25.51395035], [94.19924927, 25.52276993], [94.19072723, 25.53078079], [94.19013977, 25.53462982], [94.19390869, 25.54219818], [94.19487, 25.5524292], [94.19184875, 25.550951], [94.18276978, 25.55325127], [94.17954254, 25.55018997], [94.16790771, 25.54701042], [94.16352844, 25.54992104], [94.16011047, 25.55525017], [94.15287781, 25.54784012], [94.15184021, 25.54185104], [94.14820099, 25.5316906], [94.14523315, 25.52763939], [94.13873291, 25.52370071], [94.12850952, 25.52588081], [94.1060791, 25.52890015], [94.09210968, 25.5327301], [94.09252167, 25.53796959], [94.09619904, 25.54171944], [94.09496307, 25.54644012], [94.08595276, 25.55973053], [94.08003998, 25.56159973], [94.06941986, 25.55898094], [94.06469727, 25.56637001], [94.05412292, 25.57675934], [94.04599762, 25.58094978], [94.04361725, 25.57748032], [94.03900909, 25.57986069], [94.03916168, 25.5830307], [94.03791809, 25.58192825], [94.03489685, 25.58148956], [94.03340912, 25.58470154], [94.02726746, 25.58798981], [94.0255127, 25.59338951], [94.01473236, 25.59613037], [94.01039886, 25.59539986], [94.00765228, 25.59094048], [94.00782776, 25.58752823], [94.0117569, 25.57909012], [94.01228333, 25.57529831], [94.01159668, 25.57274818], [94.01042175, 25.57131195], [94.00744629, 25.56985092], [94.00061035, 25.57388115], [93.98046875, 25.57125282], [93.97785187, 25.5661602], [93.97264862, 25.56118011], [93.96521759, 25.55657768], [93.95738983, 25.55675125], [93.94516754, 25.56263924], [93.94351959, 25.56343269], [93.93012238, 25.56538963], [93.91932678, 25.56402969], [93.91709137, 25.56672096], [93.9108963, 25.56752968], [93.90484619, 25.56742859], [93.90023804, 25.5687294], [93.89196014, 25.56842041], [93.87837219, 25.5619812], [93.86223602, 25.55752945], [93.85231781, 25.55864906], [93.84420776, 25.56169128], [93.83648682, 25.56306076], [93.83347321, 25.56137276], [93.83325958, 25.55642128], [93.82504272, 25.55599976], [93.823349, 25.54816246], [93.81971741, 25.54438972], [93.81594086, 25.5454483], [93.80784607, 25.54451942], [93.77948761, 25.5380497], [93.77182007, 25.54080963], [93.77063751, 25.54027939], [93.77097321, 25.53602028], [93.76895142, 25.53071022], [93.76818085, 25.52529144], [93.76931763, 25.51770973], [93.76428986, 25.51548195], [93.76579285, 25.49990082], [93.76934814, 25.49677277], [93.77339172, 25.49784088], [93.78846741, 25.50649071], [93.79724884, 25.50438118], [93.80404663, 25.49902916], [93.80760956, 25.49555969], [93.81388855, 25.48472977], [93.80899811, 25.46558952], [93.80522919, 25.46342087], [93.8024292, 25.46040916], [93.79836273, 25.45393181], [93.79374695, 25.4486599], [93.79020691, 25.44338036], [93.78810883, 25.43588066], [93.78447723, 25.43193817], [93.78053284, 25.42950058], [93.78106689, 25.42471123], [93.76441956, 25.41813087], [93.76033783, 25.41411972], [93.74666595, 25.40571022], [93.74198914, 25.39991951], [93.74006653, 25.39517975], [93.74131775, 25.38944054], [93.73979187, 25.38441849], [93.73100281, 25.38037109], [93.72310638, 25.37558174], [93.71897888, 25.37035942], [93.71804047, 25.36160088], [93.711586, 25.35808945], [93.69998169, 25.35942268], [93.69277954, 25.36158943], [93.69145203, 25.34741974], [93.68712616, 25.33121109], [93.68392181, 25.3296299], [93.67207336, 25.32871056], [93.67395782, 25.31728172], [93.67294312, 25.31151009], [93.66609192, 25.30828094], [93.66474915, 25.30424118], [93.66561127, 25.29842949], [93.65161896, 25.27902031], [93.65136719, 25.27366066], [93.64990997, 25.26911926], [93.64354706, 25.26588249], [93.64311981, 25.26001167], [93.63809204, 25.25039864], [93.63186646, 25.24291992], [93.62890625, 25.23574829], [93.62114716, 25.22491264], [93.61257935, 25.20619011], [93.60801697, 25.20205116], [93.60428619, 25.20432091], [93.60103607, 25.20239258], [93.5970993, 25.20429993], [93.59303284, 25.20391273], [93.59285736, 25.20667076], [93.594841, 25.21113014], [93.59197998, 25.21390915], [93.59028625, 25.21994972], [93.58805847, 25.22216988], [93.58584595, 25.22231102], [93.58164978, 25.22600937], [93.57820129, 25.22569084], [93.57485199, 25.22755051], [93.57076263, 25.23245049], [93.57009888, 25.23560905], [93.56313324, 25.24658966], [93.55471039, 25.25052834], [93.54717255, 25.24849129], [93.54120636, 25.2453804], [93.52935791, 25.24835968], [93.52060699, 25.2487812], [93.51642609, 25.24477005], [93.50843048, 25.24370956], [93.50514221, 25.24413109], [93.50417328, 25.25338173], [93.51078796, 25.27560806], [93.50437927, 25.27577019], [93.49489594, 25.27872086], [93.4875412, 25.2759304], [93.48338318, 25.27663994], [93.47675323, 25.27903938], [93.47258759, 25.28544044], [93.47463226, 25.29241943], [93.4751358, 25.29968071], [93.47402191, 25.3092804], [93.46797943, 25.31381035], [93.46312714, 25.31986046], [93.45670319, 25.32526016], [93.45796967, 25.33005142], [93.46193695, 25.33658981], [93.45790863, 25.34091949], [93.45188904, 25.3441906], [93.45374298, 25.34811974], [93.46231842, 25.35886955], [93.46626282, 25.36173058], [93.47821808, 25.37988281], [93.47728729, 25.38600922], [93.47393799, 25.39311028], [93.46718597, 25.40306091], [93.46325684, 25.41096115], [93.46540833, 25.41587067], [93.46514893, 25.42340279], [93.46186829, 25.4346981], [93.45687103, 25.44194984], [93.44359589, 25.45060921], [93.43495941, 25.45477295], [93.42751312, 25.45526123], [93.42201996, 25.45479965], [93.41710663, 25.45279121], [93.40291595, 25.45918274], [93.3959198, 25.46412086], [93.39041901, 25.46916962], [93.39190674, 25.4742012], [93.39103699, 25.4780426], [93.39131165, 25.48143005], [93.39050293, 25.48562813], [93.38710022, 25.49031067], [93.3863678, 25.49335098], [93.38304138, 25.49756813], [93.37181854, 25.50113106], [93.37114716, 25.50514984], [93.36689758, 25.50786972], [93.36502075, 25.51013947], [93.36682129, 25.5128727], [93.36472321, 25.51616859], [93.36004639, 25.5203228], [93.35756683, 25.52766991], [93.35417938, 25.53119087], [93.35016632, 25.53367043], [93.3523407, 25.53757095], [93.34922791, 25.53832817], [93.3445816, 25.53607941], [93.34039307, 25.53729057], [93.33574677, 25.54541016], [93.33174133, 25.54681015]]]}}, {\\\"id\\\": \\\"22\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.25_1\\\", \\\"HASC_1\\\": \\\"IN.DL\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"NCT of Delhi\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 104.8, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1589.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1536.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3125.0, \\\"geo-id\\\": 22, \\\"hpm25_child_popweighted\\\": 260.0, \\\"hpm25_female_popweighted\\\": 299.0, \\\"hpm25_male_popweighted\\\": 215.0, \\\"location\\\": \\\"NCT of Delhi\\\", \\\"mort_apm25_6cod_mean_total\\\": 5127.0, \\\"mort_hpm25_6cod_mean_total\\\": 4994.0, \\\"mort_tpm25_6cod_mean_total\\\": 10121.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[77.32713318, 28.68515968], [77.32538605, 28.68250275], [77.31791687, 28.67934036], [77.31756592, 28.67161942], [77.31542969, 28.66327095], [77.31533051, 28.651371], [77.31307983, 28.64666939], [77.31121063, 28.64464188], [77.31358337, 28.64320183], [77.32095337, 28.63602066], [77.33045959, 28.6314106], [77.33422089, 28.62699127], [77.33708191, 28.62190056], [77.33753204, 28.61749268], [77.33618164, 28.60886955], [77.33315277, 28.60671234], [77.32784271, 28.60488129], [77.31694031, 28.59996033], [77.30992126, 28.59896088], [77.30713654, 28.59691048], [77.29490662, 28.58242989], [77.29364777, 28.57971954], [77.29380035, 28.5667305], [77.2951889, 28.5612011], [77.30306244, 28.55045128], [77.31069946, 28.54368973], [77.314888, 28.54149055], [77.32151031, 28.53585052], [77.330513, 28.52410126], [77.33396912, 28.52070236], [77.33682251, 28.51568031], [77.33773804, 28.50897026], [77.33447266, 28.51108932], [77.32898712, 28.50831985], [77.32668304, 28.50345039], [77.32170105, 28.49938965], [77.31488037, 28.49456978], [77.30686951, 28.49068069], [77.3009491, 28.49011993], [77.29627228, 28.4911499], [77.28578949, 28.49627113], [77.27805328, 28.49814987], [77.27111053, 28.49703026], [77.26010132, 28.48842812], [77.25396729, 28.48554039], [77.24265289, 28.48460007], [77.23673248, 28.47969055], [77.23239899, 28.47579956], [77.22763062, 28.46974945], [77.22574615, 28.46401024], [77.2264328, 28.46026039], [77.23311615, 28.45944977], [77.23986816, 28.45360756], [77.2432785, 28.44749069], [77.24430084, 28.44166946], [77.24318695, 28.43367958], [77.24061584, 28.42885971], [77.2227478, 28.41897011], [77.21530914, 28.41574097], [77.20590973, 28.41340065], [77.19522095, 28.4125309], [77.17948914, 28.41237068], [77.16577148, 28.40846062], [77.15434265, 28.4213028], [77.1518631, 28.42831993], [77.14243317, 28.43571091], [77.1313858, 28.43870163], [77.12407684, 28.43923759], [77.11830139, 28.4424305], [77.11251068, 28.45023155], [77.10874939, 28.45735168], [77.10604858, 28.46590042], [77.10273743, 28.47044945], [77.10154724, 28.47647858], [77.10334015, 28.48310852], [77.10766602, 28.49386978], [77.10352325, 28.49745941], [77.09031677, 28.5054512], [77.08598328, 28.51086044], [77.07247925, 28.52028084], [77.06746674, 28.52065086], [77.05696106, 28.5138607], [77.04876709, 28.51524162], [77.04165649, 28.51896095], [77.03314209, 28.52833939], [77.01963806, 28.53327179], [77.01566315, 28.53331947], [77.00609589, 28.54277992], [77.00020599, 28.54199982], [76.99594879, 28.53689957], [76.99820709, 28.53215027], [77.00499725, 28.52873993], [77.01139832, 28.52411079], [77.01093292, 28.51803017], [77.00554657, 28.51444054], [76.99027252, 28.51978111], [76.97653198, 28.52380943], [76.96846771, 28.52758026], [76.94462585, 28.51362991], [76.93321991, 28.5160408], [76.9226532, 28.51926994], [76.90847778, 28.51490974], [76.89745331, 28.51777077], [76.89372253, 28.51614189], [76.8868103, 28.51122856], [76.87937164, 28.50905037], [76.87380981, 28.51439095], [76.8794632, 28.52399826], [76.87631226, 28.52840042], [76.85920715, 28.54191971], [76.85674286, 28.54782104], [76.83761597, 28.55698967], [76.83291626, 28.58250809], [76.8350296, 28.59140015], [76.85022736, 28.59011841], [76.85481262, 28.59235191], [76.86090088, 28.60251045], [76.87793732, 28.63763046], [76.89367676, 28.63275146], [76.8972702, 28.63280106], [76.90400696, 28.63793945], [76.91034698, 28.63783073], [76.92366028, 28.62865067], [76.92597961, 28.62924957], [76.93390656, 28.63764954], [76.91821289, 28.65327072], [76.9174881, 28.65727043], [76.92310333, 28.66921043], [76.92973328, 28.6744194], [76.94255066, 28.67511177], [76.94725037, 28.67716026], [76.94595337, 28.68348122], [76.94838715, 28.68799019], [76.94999695, 28.69412994], [76.954216, 28.7005291], [76.95459747, 28.70537186], [76.95095825, 28.70976067], [76.94126129, 28.71702957], [76.95066071, 28.73645973], [76.94919586, 28.74150276], [76.95031738, 28.7466507], [76.9474411, 28.75113106], [76.93820953, 28.75962067], [76.94657135, 28.77403069], [76.94396973, 28.77853012], [76.94233704, 28.78775978], [76.94309235, 28.79512024], [76.93746948, 28.80350113], [76.93736267, 28.8091507], [76.94230652, 28.82068062], [76.94822693, 28.81766129], [76.95578003, 28.82002068], [76.95800781, 28.8303299], [76.96083069, 28.83167076], [76.9705658, 28.82510185], [76.97368622, 28.82583046], [76.97955322, 28.83670044], [76.98349762, 28.83908081], [76.98972321, 28.83916092], [77.00662994, 28.83526039], [77.01880646, 28.83706284], [77.02466583, 28.83628082], [77.03153992, 28.83679008], [77.03766632, 28.85277748], [77.04975891, 28.87318993], [77.06565857, 28.8730011], [77.07013702, 28.8800106], [77.07585144, 28.88451195], [77.08335114, 28.87461853], [77.09945679, 28.87244034], [77.10713196, 28.86845016], [77.10970306, 28.86613274], [77.12854004, 28.86539078], [77.13508606, 28.85848999], [77.1355896, 28.85268974], [77.13381195, 28.84472275], [77.1391983, 28.84166908], [77.14237976, 28.84247017], [77.15065002, 28.84844971], [77.1595993, 28.85744286], [77.16458893, 28.86063004], [77.18363953, 28.86230087], [77.18686676, 28.86681938], [77.19348907, 28.86535072], [77.199646, 28.86494064], [77.20479584, 28.86291122], [77.20783234, 28.86021996], [77.21147156, 28.85493088], [77.21061707, 28.84529114], [77.2173233, 28.83527946], [77.21364594, 28.81349945], [77.1946106, 28.81536293], [77.19444275, 28.80229187], [77.1969223, 28.79528046], [77.20269012, 28.78940964], [77.20845032, 28.78718948], [77.21305084, 28.7864399], [77.21826935, 28.78762817], [77.22467804, 28.78762817], [77.22206879, 28.783741], [77.21710205, 28.78168106], [77.22090912, 28.7779007], [77.22904205, 28.77243805], [77.23799133, 28.75922012], [77.24585724, 28.75735092], [77.24846649, 28.75753021], [77.25319672, 28.75279045], [77.25187683, 28.74550056], [77.25617218, 28.73991966], [77.25991821, 28.73812294], [77.26637268, 28.7392807], [77.27111816, 28.7381897], [77.2768631, 28.7343998], [77.28069305, 28.73002052], [77.2844162, 28.72393036], [77.28365326, 28.7189827], [77.28489685, 28.71245956], [77.29294586, 28.7097702], [77.29563141, 28.7130394], [77.30146027, 28.71673012], [77.30622101, 28.71767044], [77.31716156, 28.71722031], [77.32348633, 28.71587181], [77.32167816, 28.71183014], [77.31983948, 28.70364189], [77.32092285, 28.69967079], [77.32758331, 28.69184113], [77.32713318, 28.68515968]]]}}, {\\\"id\\\": \\\"23\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.26_1\\\", \\\"HASC_1\\\": \\\"IN.OR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Odisha\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 77.9, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1022.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 2177.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3199.0, \\\"geo-id\\\": 23, \\\"hpm25_child_popweighted\\\": 248.9, \\\"hpm25_female_popweighted\\\": 286.1, \\\"hpm25_male_popweighted\\\": 206.0, \\\"location\\\": \\\"Odisha\\\", \\\"mort_apm25_6cod_mean_total\\\": 14108.0, \\\"mort_hpm25_6cod_mean_total\\\": 29616.0, \\\"mort_tpm25_6cod_mean_total\\\": 43724.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[84.73021698, 19.08930588], [84.73236084, 19.08930588], [84.73236084, 19.08958244], [84.73291779, 19.08958054], [84.73291779, 19.08986282], [84.7334671, 19.08986282], [84.7334671, 19.09013939], [84.73374939, 19.09013939], [84.73374939, 19.09041977], [84.73402405, 19.09041405], [84.73402405, 19.09069252], [84.73432159, 19.09069061], [84.73432159, 19.09152985], [84.73596954, 19.09152985], [84.73596954, 19.09181023], [84.73764038, 19.09180641], [84.73764038, 19.09208488], [84.73930359, 19.09208488], [84.73930359, 19.09152794], [84.73958588, 19.09152985], [84.73958588, 19.09069061], [84.73986053, 19.09069252], [84.73986053, 19.09041405], [84.74014282, 19.09041977], [84.74014282, 19.08986282], [84.74097443, 19.08986282], [84.7409668, 19.08930969], [84.74124908, 19.08930969], [84.74124908, 19.08847046], [84.74180603, 19.08847046], [84.74180603, 19.08819389], [84.74208069, 19.08819389], [84.74208069, 19.08791733], [84.74263763, 19.08792114], [84.74263763, 19.08764267], [84.74375153, 19.08764267], [84.74375153, 19.08792114], [84.74402618, 19.08791733], [84.74402618, 19.08819389], [84.74430847, 19.08819389], [84.74430847, 19.08847046], [84.74485779, 19.08847046], [84.74485779, 19.08875275], [84.74514008, 19.08875275], [84.74514008, 19.08903122], [84.7454071, 19.08903122], [84.7454071, 19.08930969], [84.74569702, 19.08930969], [84.74569702, 19.09041977], [84.74597168, 19.09041405], [84.74597168, 19.09069252], [84.74736023, 19.09069252], [84.74736023, 19.09041405], [84.74819183, 19.09041977], [84.74819183, 19.09013939], [84.74903107, 19.09013939], [84.74903107, 19.08986282], [84.7492981, 19.08986282], [84.7492981, 19.08958054], [84.74958038, 19.08958244], [84.74958038, 19.08847046], [84.74930573, 19.08847046], [84.74930573, 19.08763885], [84.75013733, 19.08764267], [84.75013733, 19.08736038], [84.75125122, 19.08736038], [84.75125122, 19.08764267], [84.75152588, 19.08764267], [84.75152588, 19.08792114], [84.75208282, 19.08792114], [84.75208282, 19.08708191], [84.75152588, 19.08708382], [84.75152588, 19.08680534], [84.75096893, 19.08681107], [84.75096893, 19.08597183], [84.75069427, 19.08597183], [84.75069427, 19.08458328], [84.75041962, 19.08458328], [84.75041962, 19.08263969], [84.75068665, 19.08263969], [84.75068665, 19.08208084], [84.75096893, 19.08208084], [84.75096893, 19.08236122], [84.75152588, 19.08236122], [84.75152588, 19.08291817], [84.75180817, 19.08291817], [84.75180817, 19.08402824], [84.75208282, 19.08402824], [84.75208282, 19.08430481], [84.75235748, 19.08430481], [84.75235748, 19.08458328], [84.75263977, 19.08458328], [84.75263977, 19.08486176], [84.7529068, 19.08485985], [84.7529068, 19.08513832], [84.75319672, 19.08513832], [84.75319672, 19.08542061], [84.75514221, 19.08542061], [84.75514221, 19.0857029], [84.75541687, 19.08569527], [84.75541687, 19.08597183], [84.75597382, 19.08597183], [84.75597382, 19.08625031], [84.75708008, 19.08624077], [84.75708008, 19.08653259], [84.75736237, 19.08653259], [84.75736237, 19.08681107], [84.75763702, 19.08680534], [84.75763702, 19.08708382], [84.75791931, 19.08708191], [84.75791931, 19.08736038], [84.75819397, 19.08736038], [84.7582016, 19.08875275], [84.75791931, 19.08875275], [84.75791931, 19.08958244], [84.7582016, 19.08958054], [84.7582016, 19.09152985], [84.75791931, 19.09152985], [84.75791931, 19.09181023], [84.7582016, 19.09181023], [84.7582016, 19.09237099], [84.75846863, 19.09236145], [84.75846863, 19.09486198], [84.75819397, 19.09486198], [84.75819397, 19.09569359], [84.75791931, 19.09568977], [84.75791931, 19.09625053], [84.75763702, 19.09625053], [84.75763702, 19.09736061], [84.75736237, 19.09736061], [84.75736237, 19.0984726], [84.75763702, 19.09847069], [84.75763702, 19.09874916], [84.75791931, 19.09874916], [84.75791931, 19.09903145], [84.7582016, 19.09903145], [84.7582016, 19.09931183], [84.75875092, 19.09930611], [84.75875092, 19.09958267], [84.75902557, 19.09958267], [84.75902557, 19.10013962], [84.75930786, 19.10013962], [84.75930786, 19.10069466], [84.75958252, 19.10069466], [84.75958252, 19.10041618], [84.76040649, 19.10042191], [84.76040649, 19.10013962], [84.76180267, 19.10013962], [84.76180267, 19.10042191], [84.76486206, 19.10042191], [84.76486206, 19.09985924], [84.76513672, 19.09985924], [84.76513672, 19.09958076], [84.76568604, 19.09958076], [84.76568604, 19.10042191], [84.76625061, 19.10041618], [84.76625061, 19.10069466], [84.76680756, 19.10069466], [84.76680756, 19.10097122], [84.76708221, 19.10097122], [84.76708221, 19.10124969], [84.76763916, 19.10124969], [84.76763916, 19.10153961], [84.76819611, 19.10152817], [84.76819611, 19.1020813], [84.76847076, 19.1020813], [84.76847076, 19.10236359], [84.76902771, 19.10235977], [84.76902771, 19.10264015], [84.76930237, 19.10264015], [84.76930237, 19.10292053], [84.76957703, 19.10292053], [84.76957703, 19.10320091], [84.76985931, 19.10319328], [84.76985931, 19.10347366], [84.7701416, 19.10346985], [84.7701416, 19.10375023], [84.77043152, 19.10375023], [84.77043152, 19.10403061], [84.77069092, 19.10403061], [84.77069092, 19.10431099], [84.7720871, 19.10430336], [84.7720871, 19.10458565], [84.77236176, 19.10457993], [84.77236176, 19.10486031], [84.7729187, 19.10486031], [84.7729187, 19.10514069], [84.77346802, 19.10514069], [84.77346802, 19.10542107], [84.77402496, 19.10541725], [84.77402496, 19.10569572], [84.77458191, 19.10569572], [84.77458191, 19.10597229], [84.77513885, 19.10597038], [84.77513885, 19.10625076], [84.7756958, 19.10625076], [84.7756958, 19.10653114], [84.77623749, 19.10653114], [84.77623749, 19.10680962], [84.7765274, 19.10680771], [84.7765274, 19.10708237], [84.77680206, 19.10708427], [84.77680206, 19.10736084], [84.77707672, 19.1073494], [84.77707672, 19.10764122], [84.77735901, 19.10764122], [84.77735901, 19.10791969], [84.77791595, 19.10791779], [84.77791595, 19.10819435], [84.7784729, 19.10819435], [84.7784729, 19.10847282], [84.77902985, 19.10847092], [84.77902985, 19.10874939], [84.77931213, 19.10874939], [84.77931213, 19.10902977], [84.78013611, 19.10902977], [84.78013611, 19.10930824], [84.7804184, 19.10930634], [84.7804184, 19.1095829], [84.78069305, 19.1095829], [84.78069305, 19.10986137], [84.78098297, 19.10985947], [84.78098297, 19.11013985], [84.78125, 19.11013985], [84.78125, 19.11041641], [84.78180695, 19.11041641], [84.78180695, 19.11069489], [84.78236389, 19.11069489], [84.78236389, 19.11097145], [84.7831955, 19.11097145], [84.7831955, 19.11069489], [84.78347015, 19.11069489], [84.78347015, 19.11013985], [84.78320313, 19.11013985], [84.78320313, 19.10985947], [84.78263855, 19.10986137], [84.78263855, 19.10847282], [84.78236389, 19.10847282], [84.78236389, 19.10791779], [84.7820816, 19.10791969], [84.7820816, 19.10764122], [84.78180695, 19.10764122], [84.78180695, 19.10542107], [84.78151703, 19.10542107], [84.78151703, 19.10457993], [84.78125, 19.10458565], [84.78125, 19.1040287], [84.78098297, 19.10403061], [84.78098297, 19.10320091], [84.78069305, 19.10320091], [84.78069305, 19.10292053], [84.7804184, 19.10292053], [84.7804184, 19.10264015], [84.78013611, 19.10264015], [84.78013611, 19.10235977], [84.77986145, 19.10236359], [84.77986145, 19.1020813], [84.77958679, 19.1020813], [84.77958679, 19.10180473], [84.7793045, 19.10180473], [84.7793045, 19.10152817], [84.77902985, 19.10153961], [84.77902985, 19.10097122], [84.77874756, 19.10097122], [84.77874756, 19.10041618], [84.7784729, 19.10042191], [84.7784729, 19.10013962], [84.77819824, 19.10013962], [84.77819061, 19.09985924], [84.77791595, 19.09985924], [84.77791595, 19.09958076], [84.7776413, 19.09958267], [84.7776413, 19.09930611], [84.77735901, 19.09931183], [84.77735901, 19.09792137], [84.77707672, 19.09792137], [84.77707672, 19.09763908], [84.77680206, 19.09763908], [84.77680206, 19.09708023], [84.7765274, 19.09708405], [84.7765274, 19.0965271], [84.7756958, 19.09653091], [84.7756958, 19.09597015], [84.77541351, 19.09597206], [84.77541351, 19.09569359], [84.77513885, 19.09569359], [84.77513885, 19.09541893], [84.7748642, 19.09541893], [84.7748642, 19.09430695], [84.77458191, 19.09431076], [84.77458191, 19.09375], [84.77430725, 19.09375], [84.77430725, 19.0929203], [84.77403259, 19.0929203], [84.77403259, 19.09208107], [84.77375031, 19.09208488], [84.77375031, 19.09152794], [84.77346802, 19.09152985], [84.77346802, 19.09124947], [84.7731781, 19.09124947], [84.7731781, 19.09069061], [84.7729187, 19.09069252], [84.7729187, 19.09041405], [84.77263641, 19.09041977], [84.77263641, 19.09013939], [84.7720871, 19.09013939], [84.7720871, 19.08958054], [84.77180481, 19.08958244], [84.77180481, 19.08875275], [84.77153015, 19.08875275], [84.77153015, 19.08792114], [84.77124786, 19.08792114], [84.77124786, 19.08736038], [84.77097321, 19.08736038], [84.77097321, 19.08653259], [84.77069092, 19.08653259], [84.77069092, 19.08624077], [84.77041626, 19.08625031], [84.77041626, 19.08569527], [84.7701416, 19.0857029], [84.7701416, 19.08513832], [84.76985931, 19.08513832], [84.76985931, 19.08457947], [84.76958466, 19.08458328], [84.76958466, 19.08402824], [84.76930237, 19.08402824], [84.76930237, 19.08374977], [84.76902771, 19.08374977], [84.76902771, 19.08317947], [84.76875305, 19.08319473], [84.76875305, 19.08263969], [84.76847076, 19.08263969], [84.76847076, 19.08208084], [84.76819611, 19.08208275], [84.76819611, 19.08152771], [84.76790619, 19.08152962], [84.76790619, 19.08125114], [84.76763916, 19.08125114], [84.76763916, 19.08097076], [84.7673645, 19.08097267], [84.7673645, 19.08041763], [84.76708221, 19.08042908], [84.76708221, 19.07986069], [84.76680756, 19.07986069], [84.76680756, 19.07958031], [84.76652527, 19.07958412], [84.76652527, 19.07902718], [84.76625061, 19.07903099], [84.76625061, 19.07847023], [84.76597595, 19.07847214], [84.76597595, 19.07819557], [84.76569366, 19.07819557], [84.76569366, 19.0779171], [84.76541901, 19.07792091], [84.76541901, 19.07736969], [84.76513672, 19.07736969], [84.76513672, 19.07707977], [84.76486206, 19.07708549], [84.76486206, 19.07569313], [84.76457977, 19.07570076], [84.76457977, 19.07485962], [84.76430511, 19.07486343], [84.76430511, 19.07458115], [84.76347351, 19.07458115], [84.76347351, 19.07430649], [84.76319122, 19.07430649], [84.76319122, 19.07374954], [84.76291656, 19.07374954], [84.76291656, 19.07346916], [84.76264191, 19.07347107], [84.76264191, 19.0731945], [84.76235962, 19.0731945], [84.76235962, 19.07263947], [84.76208496, 19.07263947], [84.76208496, 19.07235909], [84.76180267, 19.07235909], [84.76180267, 19.07208061], [84.76152802, 19.07208252], [84.76152802, 19.07152748], [84.7612381, 19.07152939], [84.76125336, 19.07125092], [84.76114655, 19.07127762], [84.76101685, 19.07131195], [84.73021698, 19.08930588]]], [[[84.76985931, 19.10597229], [84.76985931, 19.10486031], [84.76957703, 19.10486031], [84.76957703, 19.10431099], [84.76930237, 19.10431099], [84.76930237, 19.10403061], [84.76902771, 19.10403061], [84.76902771, 19.10375023], [84.76875305, 19.10375023], [84.76875305, 19.10346985], [84.76847076, 19.10347366], [84.76847076, 19.10319328], [84.76790619, 19.10320091], [84.76790619, 19.10264015], [84.76763916, 19.10264015], [84.76763916, 19.10207939], [84.7673645, 19.1020813], [84.7673645, 19.10180473], [84.76680756, 19.10180473], [84.76680756, 19.10152817], [84.7665329, 19.10153961], [84.7665329, 19.10124969], [84.76597595, 19.10124969], [84.76597595, 19.10097122], [84.76568604, 19.10097122], [84.76568604, 19.10124969], [84.76513672, 19.10124969], [84.76513672, 19.10153961], [84.76486206, 19.10152817], [84.76486206, 19.10180473], [84.76513672, 19.10180473], [84.76513672, 19.1020813], [84.76541901, 19.1020813], [84.76541901, 19.10236359], [84.76568604, 19.10235977], [84.76568604, 19.10292053], [84.76597595, 19.10292053], [84.76597595, 19.10320091], [84.76625061, 19.10320091], [84.76625061, 19.10375023], [84.76652527, 19.10375023], [84.76652527, 19.10458565], [84.76708221, 19.10457993], [84.76708221, 19.10486031], [84.76737213, 19.10486031], [84.76737213, 19.10514069], [84.76791382, 19.10513878], [84.76791382, 19.10569572], [84.76875305, 19.10569572], [84.76875305, 19.10597229], [84.76985931, 19.10597229]]], [[[84.75653076, 19.11097145], [84.75653076, 19.11041641], [84.75680542, 19.11041641], [84.75680542, 19.10986137], [84.75708008, 19.10986137], [84.75708008, 19.1095829], [84.75736237, 19.1095829], [84.75736237, 19.10902786], [84.75708008, 19.10902977], [84.75708008, 19.10847092], [84.75791931, 19.10847092], [84.75791931, 19.10930824], [84.7582016, 19.10930824], [84.7582016, 19.11013985], [84.75875092, 19.11013985], [84.75875092, 19.10958099], [84.76069641, 19.1095829], [84.76069641, 19.10902786], [84.75985718, 19.10902977], [84.75985718, 19.10874939], [84.75958252, 19.10874939], [84.75958252, 19.10819054], [84.75930786, 19.10819435], [84.75930786, 19.10763931], [84.7590332, 19.10764122], [84.7590332, 19.1073494], [84.75763702, 19.10736084], [84.75763702, 19.10680771], [84.75791931, 19.10680962], [84.75791931, 19.10569], [84.75819397, 19.10569572], [84.75819397, 19.10513878], [84.75846863, 19.10514069], [84.75846863, 19.10486031], [84.75985718, 19.10486031], [84.75985718, 19.10514069], [84.76069641, 19.10514069], [84.76069641, 19.10542107], [84.76125336, 19.10541725], [84.76125336, 19.10569572], [84.76235962, 19.10569572], [84.76235962, 19.10597229], [84.76264191, 19.10597229], [84.76264191, 19.10736084], [84.76291656, 19.10736084], [84.76291656, 19.10708427], [84.76430511, 19.10708427], [84.76430511, 19.10736084], [84.76541901, 19.10736084], [84.76541901, 19.10708427], [84.76569366, 19.10708427], [84.76569366, 19.10486031], [84.76541901, 19.10486031], [84.76541901, 19.10403061], [84.76513672, 19.10403061], [84.76513672, 19.10375023], [84.76457977, 19.10375023], [84.76457977, 19.10320091], [84.76429749, 19.10320091], [84.76429749, 19.10292053], [84.76403046, 19.10292053], [84.76403046, 19.10264015], [84.76374817, 19.10264015], [84.76374817, 19.10235977], [84.76291656, 19.10236359], [84.76291656, 19.1020813], [84.76208496, 19.1020813], [84.76208496, 19.10236359], [84.76040649, 19.10235977], [84.76040649, 19.10264015], [84.75930786, 19.10264015], [84.75930786, 19.10235977], [84.75875092, 19.10236359], [84.75875092, 19.1020813], [84.75846863, 19.1020813], [84.75846863, 19.10180473], [84.75819397, 19.10180473], [84.75819397, 19.10152817], [84.75680542, 19.10152817], [84.75680542, 19.10180473], [84.75653076, 19.10180283], [84.75653076, 19.10431099], [84.75708008, 19.10430336], [84.75708008, 19.10458565], [84.75736237, 19.10457993], [84.75736237, 19.10542107], [84.75708008, 19.10541725], [84.75708008, 19.10569572], [84.75680542, 19.10569572], [84.75680542, 19.10597229], [84.75653076, 19.10597038], [84.75653076, 19.10625076], [84.75624847, 19.10625076], [84.75624847, 19.10680962], [84.75597382, 19.10680771], [84.75597382, 19.10708427], [84.75624847, 19.10708427], [84.75624847, 19.10736084], [84.75596619, 19.1073494], [84.75596619, 19.10764122], [84.75624847, 19.10764122], [84.75624847, 19.10874939], [84.75596619, 19.10874939], [84.75596619, 19.10902977], [84.75569153, 19.10902977], [84.75569153, 19.10930824], [84.75541687, 19.10930634], [84.75541687, 19.10986137], [84.75514221, 19.10986137], [84.75514221, 19.11069489], [84.75541687, 19.11069489], [84.75541687, 19.11097145], [84.75653076, 19.11097145]]], [[[86.38694763, 19.96277618], [86.38694763, 19.96223068], [86.38582611, 19.96111107], [86.38555908, 19.96111107], [86.38471985, 19.96027946], [86.38445282, 19.96027946], [86.3842392, 19.96007347], [86.3841629, 19.95999908], [86.38388824, 19.95972061], [86.38361359, 19.95972252], [86.3833313, 19.95944214], [86.38277435, 19.95944214], [86.38249969, 19.95916748], [86.38166809, 19.95916748], [86.38137817, 19.95893669], [86.38083649, 19.95889091], [86.38054657, 19.95861053], [86.37999725, 19.95861053], [86.3797226, 19.95889091], [86.37944794, 19.95888901], [86.37889099, 19.95944214], [86.37916565, 19.95972252], [86.3797226, 19.95972061], [86.37999725, 19.96000099], [86.38054657, 19.96000099], [86.38111115, 19.96055984], [86.3813858, 19.96055412], [86.38166809, 19.9608326], [86.38194275, 19.96083069], [86.38249969, 19.96138954], [86.38276672, 19.96138954], [86.38305664, 19.96166992], [86.3833313, 19.9616642], [86.38361359, 19.96194458], [86.38388824, 19.96194458], [86.38444519, 19.96249962], [86.38500214, 19.96249962], [86.38527679, 19.96278], [86.38555908, 19.96277618], [86.3859024, 19.96312523], [86.3861084, 19.96333313], [86.38639069, 19.96333313], [86.38694763, 19.96277618]]], [[[86.39248657, 19.96610832], [86.39221954, 19.96582985], [86.39194489, 19.96583366], [86.39104462, 19.96551132], [86.39047241, 19.96550941], [86.39047241, 19.96618843], [86.39061737, 19.96645927], [86.39194489, 19.96722221], [86.39221954, 19.96722221], [86.39264679, 19.96765137], [86.39407349, 19.9688015], [86.39570618, 19.97007942], [86.39620972, 19.97063065], [86.39723969, 19.97145271], [86.39837646, 19.97225952], [86.39877319, 19.97238731], [86.39905548, 19.97252464], [86.3992691, 19.97238731], [86.39935303, 19.97232056], [86.39913177, 19.97150993], [86.39836121, 19.97074127], [86.39778137, 19.97028351], [86.39649963, 19.96900368], [86.39499664, 19.96805573], [86.39332581, 19.96639061], [86.39305878, 19.96639061], [86.39277649, 19.96610832], [86.39248657, 19.96610832]]], [[[86.37249756, 19.95444489], [86.37166595, 19.95361137], [86.37150574, 19.95375824], [86.37093353, 19.95389366], [86.37043762, 19.95389366], [86.37020111, 19.95380402], [86.37007904, 19.95375824], [86.36962128, 19.95331955], [86.36908722, 19.9529705], [86.36824036, 19.95235825], [86.36782074, 19.95215988], [86.36660004, 19.95222282], [86.36620331, 19.95216179], [86.36572266, 19.9519043], [86.36447906, 19.95166016], [86.36326599, 19.95158958], [86.3629303, 19.95152473], [86.3611145, 19.95111084], [86.36083221, 19.95083046], [86.36000061, 19.95083427], [86.35972595, 19.95055771], [86.35945129, 19.95055962], [86.35939026, 19.95050049], [86.35916901, 19.95029068], [86.35861206, 19.95029068], [86.35832977, 19.95000076], [86.35703278, 19.94972038], [86.35639191, 19.94972229], [86.35540771, 19.94958878], [86.35513306, 19.94992065], [86.35526276, 19.95020103], [86.35547638, 19.95033073], [86.35700989, 19.95075607], [86.35730743, 19.95083427], [86.35740662, 19.95085907], [86.35876465, 19.95113182], [86.36018372, 19.95140266], [86.36289215, 19.95228004], [86.36517334, 19.95318985], [86.36746216, 19.95346069], [86.36846161, 19.95421028], [86.36917877, 19.95441055], [86.36989594, 19.95462608], [86.37007904, 19.95479012], [86.37082672, 19.95497513], [86.37110901, 19.95531082], [86.37125397, 19.95578766], [86.37132263, 19.95599174], [86.37132263, 19.95653343], [86.3713913, 19.9569397], [86.3720932, 19.95763969], [86.37229919, 19.95763969], [86.37265778, 19.95722961], [86.37258148, 19.95654106], [86.37223053, 19.95601082], [86.3722229, 19.9552803], [86.37249756, 19.95472145], [86.37249756, 19.95444489]]], [[[86.24055481, 19.90944672], [86.24028015, 19.90916443], [86.23990631, 19.90916443], [86.23972321, 19.90916443], [86.23944092, 19.90944672], [86.23860931, 19.90944672], [86.23777771, 19.9086113], [86.23777771, 19.90833282], [86.23722076, 19.90777779], [86.23694611, 19.90805435], [86.23665619, 19.90833092], [86.23666382, 19.90888977], [86.23722076, 19.90944672], [86.23722076, 19.90971947], [86.23777771, 19.91027641], [86.23777771, 19.91055489], [86.23799896, 19.91077423], [86.23833466, 19.91111183], [86.24021912, 19.91111183], [86.24055481, 19.91111183], [86.24111176, 19.91055489], [86.24111176, 19.91027641], [86.24054718, 19.90971947], [86.24055481, 19.90944672]]], [[[86.36860657, 19.9738903], [86.36888885, 19.97360992], [86.37046051, 19.97361183], [86.37232971, 19.97351837], [86.37252808, 19.97351074], [86.37281036, 19.97336769], [86.37302399, 19.97296715], [86.37301636, 19.97270012], [86.37281036, 19.97243118], [86.37252808, 19.97216034], [86.3713913, 19.9719429], [86.3713913, 19.97166634], [86.3722229, 19.97083282], [86.3722229, 19.9691658], [86.37169647, 19.96864128], [86.37088776, 19.96820259], [86.3706665, 19.96805954], [86.36972046, 19.96805573], [86.36958313, 19.96819496], [86.3694458, 19.9683342], [86.36916351, 19.96805573], [86.36805725, 19.96805573], [86.36777496, 19.9683342], [86.36723328, 19.96832848], [86.36694336, 19.96861076], [86.36499786, 19.96861076], [86.36486816, 19.96874046], [86.36416626, 19.96944427], [86.36444092, 19.96972275], [86.36444092, 19.96999931], [86.36528015, 19.97083282], [86.36528015, 19.97110176], [86.36499786, 19.97138977], [86.36499786, 19.97194481], [86.36555481, 19.97249985], [86.3658371, 19.97278023], [86.36611176, 19.97277832], [86.36638641, 19.97305489], [86.3666687, 19.97305489], [86.36694336, 19.97333336], [86.36722565, 19.97333336], [86.36750031, 19.97361183], [86.36808014, 19.97363663], [86.36831665, 19.9738903], [86.36860657, 19.9738903]]], [[[87.05751038, 20.74435806], [87.05760956, 20.74394989], [87.05742645, 20.74367905], [87.05712891, 20.74386978], [87.05671692, 20.74406052], [87.05628204, 20.7440815], [87.05608368, 20.74400711], [87.05589294, 20.74393463], [87.05547333, 20.74382019], [87.05510712, 20.74357414], [87.05477142, 20.74335289], [87.05421448, 20.7435112], [87.05369568, 20.74359322], [87.05317688, 20.74358177], [87.0526123, 20.74346352], [87.05195618, 20.74331474], [87.05164337, 20.74329185], [87.05132294, 20.74314308], [87.0508728, 20.7429924], [87.05047607, 20.74273109], [87.05013275, 20.74258995], [87.04981232, 20.74273109], [87.04953003, 20.74307632], [87.04927826, 20.74347115], [87.04902649, 20.74384117], [87.04911804, 20.74421883], [87.04953003, 20.74452209], [87.04995728, 20.74473953], [87.05036163, 20.74498749], [87.05075073, 20.74517059], [87.05116272, 20.74525833], [87.05158997, 20.74529076], [87.05201721, 20.74537086], [87.05246735, 20.74551773], [87.05293274, 20.74559975], [87.05335999, 20.74578094], [87.05378723, 20.74598122], [87.05430603, 20.7460804], [87.05488586, 20.74591064], [87.0554657, 20.74568367], [87.05599213, 20.7454052], [87.05648041, 20.74518013], [87.05692291, 20.74498177], [87.05728912, 20.74480057], [87.05742645, 20.74460983], [87.05751038, 20.74435806]]], [[[87.09083557, 20.75752068], [87.09111023, 20.75718689], [87.09140015, 20.75688171], [87.09172058, 20.75662231], [87.09210205, 20.7563858], [87.09249878, 20.75613022], [87.09290314, 20.75584602], [87.09333801, 20.75556946], [87.09379578, 20.75536919], [87.09422302, 20.75517082], [87.09440613, 20.75484848], [87.09442139, 20.7544899], [87.0943222, 20.75416756], [87.09414673, 20.75386047], [87.09393311, 20.75352097], [87.09368134, 20.7531414], [87.09334564, 20.7528019], [87.09288025, 20.75252533], [87.0923233, 20.75234032], [87.09205627, 20.75222969], [87.09176636, 20.75222015], [87.09136963, 20.75223923], [87.09088898, 20.75231743], [87.09059143, 20.75240135], [87.09037018, 20.75246048], [87.08983612, 20.75250053], [87.08930969, 20.75255966], [87.08882904, 20.75272369], [87.08837128, 20.75276947], [87.08792877, 20.75278091], [87.08750153, 20.75278091], [87.08706665, 20.75279045], [87.08664703, 20.75284004], [87.08624268, 20.75294113], [87.08583832, 20.75280952], [87.0854187, 20.75269127], [87.08493805, 20.75267982], [87.08439636, 20.75290108], [87.08393097, 20.75307655], [87.08349609, 20.75325203], [87.0830307, 20.7533226], [87.08268738, 20.75332642], [87.08257294, 20.75333023], [87.0823822, 20.75330544], [87.08213043, 20.7532692], [87.0817337, 20.75313568], [87.0812912, 20.7530899], [87.08088684, 20.75304031], [87.08048248, 20.7531414], [87.08003998, 20.7532444], [87.07985687, 20.75318527], [87.07958984, 20.75310326], [87.0790863, 20.75303078], [87.07860565, 20.75290489], [87.07816315, 20.75276375], [87.07779694, 20.75260544], [87.07752228, 20.75247955], [87.07731628, 20.75237846], [87.0769043, 20.75245094], [87.07653046, 20.75248337], [87.07639313, 20.75246811], [87.0761795, 20.75244522], [87.07582855, 20.75226974], [87.07543182, 20.75217056], [87.07502747, 20.7520771], [87.07460022, 20.75223923], [87.07418823, 20.75247955], [87.07382965, 20.75267982], [87.07345581, 20.75280952], [87.07311249, 20.75299835], [87.07272339, 20.75332069], [87.07247925, 20.7541008], [87.0725174, 20.75455856], [87.07264709, 20.75502968], [87.07285309, 20.75555038], [87.073349, 20.75587082], [87.07395935, 20.75612259], [87.07457733, 20.75637817], [87.07520294, 20.75658035], [87.07578278, 20.75674248], [87.07628632, 20.75692749], [87.07676697, 20.75705719], [87.0772171, 20.75723267], [87.07766724, 20.75745964], [87.07818604, 20.75766945], [87.07861328, 20.75799179], [87.07901764, 20.75830078], [87.07942963, 20.75847054], [87.07995605, 20.75831032], [87.08044434, 20.7579422], [87.08079529, 20.75763321], [87.08110046, 20.75741768], [87.08142853, 20.75729942], [87.08180237, 20.75726128], [87.0821991, 20.75727844], [87.08257294, 20.75735855], [87.08291626, 20.75748062], [87.08325195, 20.75765991], [87.08352661, 20.75789833], [87.08374023, 20.75823021], [87.08383942, 20.75866127], [87.08383942, 20.75917053], [87.08376312, 20.75970078], [87.08362579, 20.7602005], [87.08342743, 20.76067162], [87.08318329, 20.76108932], [87.08287048, 20.76151276], [87.08249664, 20.76200294], [87.08216095, 20.76264], [87.08200836, 20.76303291], [87.08216858, 20.76325035], [87.08250427, 20.76336479], [87.08283234, 20.76355362], [87.08317566, 20.76375389], [87.08349609, 20.76402092], [87.08394623, 20.76424026], [87.08452606, 20.76439095], [87.08469391, 20.76436996], [87.08534241, 20.76428986], [87.08615112, 20.76411057], [87.08642578, 20.76387024], [87.08666992, 20.76358986], [87.08690643, 20.76325417], [87.08714294, 20.76287079], [87.08737183, 20.76250076], [87.08759308, 20.76214027], [87.0878067, 20.76176834], [87.08805847, 20.76137161], [87.08833313, 20.76092148], [87.08862305, 20.76045036], [87.08893585, 20.76003456], [87.08929443, 20.75972557], [87.0896225, 20.75943947], [87.08991241, 20.75912094], [87.0901413, 20.75872993], [87.09034729, 20.75828552], [87.09057617, 20.75788116], [87.09083557, 20.75752068]]], [[[87.07055664, 20.73621368], [87.07038879, 20.73551559], [87.06999969, 20.73527718], [87.06944275, 20.73583412], [87.06916809, 20.73583412], [87.06824493, 20.73674393], [87.06804657, 20.73694038], [87.06804657, 20.73777962], [87.06833649, 20.73805618], [87.06833649, 20.73861122], [87.06916809, 20.73944473], [87.06948853, 20.73944473], [87.06972504, 20.73944473], [87.06999969, 20.7397213], [87.06977844, 20.7400074], [87.06965637, 20.7401619], [87.06955719, 20.74061012], [87.06967926, 20.74086761], [87.06971741, 20.74119186], [87.06973267, 20.74156952], [87.06972504, 20.74201775], [87.06972504, 20.74252129], [87.06976318, 20.74304962], [87.06990814, 20.74352837], [87.07003021, 20.74401093], [87.07023621, 20.74446106], [87.07026672, 20.74502945], [87.07028198, 20.74560928], [87.0703125, 20.74614716], [87.07048035, 20.74661064], [87.07056427, 20.74704552], [87.07068634, 20.74748039], [87.07087708, 20.74798965], [87.07116699, 20.74846077], [87.07149506, 20.74878311], [87.0717926, 20.74881172], [87.07192993, 20.74867249], [87.07205963, 20.74853897], [87.07205963, 20.74818993], [87.07212067, 20.74776077], [87.07200623, 20.74724007], [87.07195282, 20.74671364], [87.07194519, 20.74621964], [87.07195282, 20.7457695], [87.07194519, 20.74536133], [87.07194519, 20.74495888], [87.07193756, 20.7445507], [87.07187653, 20.74411011], [87.07174683, 20.74370003], [87.07170868, 20.74323082], [87.07174683, 20.74273109], [87.07161713, 20.7422905], [87.07144165, 20.74187469], [87.07138824, 20.74140167], [87.07132721, 20.74094772], [87.07113647, 20.74057961], [87.07104492, 20.7403717], [87.07097626, 20.74022293], [87.07084656, 20.73981667], [87.07071686, 20.73937035], [87.0705719, 20.7389946], [87.07043457, 20.73861885], [87.0703125, 20.73822021], [87.07028961, 20.73775864], [87.07032013, 20.73727036], [87.07045746, 20.7367897], [87.07055664, 20.73621368]]], [[[87.12388611, 21.51972008], [87.12388611, 21.5177784], [87.12375641, 21.51749992], [87.12361145, 21.51499939], [87.12387848, 21.51472092], [87.12361145, 21.51444435], [87.12304688, 21.51444054], [87.12249756, 21.51499939], [87.12243652, 21.51528931], [87.1222229, 21.51555824], [87.12210083, 21.51570129], [87.12194824, 21.51571083], [87.1213913, 21.51555824], [87.12110901, 21.51556396], [87.12083435, 21.51556396], [87.12055206, 21.51555634], [87.1202774, 21.51555824], [87.11916351, 21.51666641], [87.11888123, 21.51721954], [87.11888885, 21.51749992], [87.11888885, 21.5177784], [87.11909485, 21.51812363], [87.11915588, 21.51833153], [87.1194458, 21.51874924], [87.1194458, 21.51889038], [87.11972046, 21.51909065], [87.1202774, 21.51944351], [87.12055206, 21.5194416], [87.12166595, 21.5205555], [87.12243652, 21.52082443], [87.1230545, 21.52082443], [87.12365723, 21.52050209], [87.12388611, 21.51972008]]], [[[86.87416077, 20.67361069], [86.87388611, 20.67333031], [86.87361145, 20.67333412], [86.87319946, 20.67314339], [86.87241364, 20.67267227], [86.87206268, 20.67267036], [86.87197876, 20.67308998], [86.8722229, 20.67388916], [86.8722229, 20.67416954], [86.87333679, 20.67527771], [86.87333679, 20.67555046], [86.87555695, 20.67778015], [86.8758316, 20.67778015], [86.87611389, 20.67805862], [86.87695313, 20.67889023], [86.87722015, 20.67889023], [86.8777771, 20.6794529], [86.87832642, 20.6794529], [86.87889099, 20.67889023], [86.87889099, 20.67861176], [86.87833405, 20.67805481], [86.87833405, 20.67777824], [86.87638855, 20.67583084], [86.87638855, 20.67555618], [86.87444305, 20.67361069], [86.87416077, 20.67361069]]], [[[86.80278015, 20.42083359], [86.80361176, 20.41999817], [86.80388641, 20.41999817], [86.8041687, 20.4197197], [86.80444336, 20.4197216], [86.80472565, 20.41944504], [86.80555725, 20.41944504], [86.80583191, 20.4197216], [86.80722046, 20.4197216], [86.8077774, 20.41916656], [86.80805206, 20.41917038], [86.80832672, 20.41945076], [86.80860901, 20.41945076], [86.8088913, 20.41917038], [86.8088913, 20.41888809], [86.80944824, 20.41833115], [86.80944824, 20.41805649], [86.8097229, 20.41777992], [86.80999756, 20.41777992], [86.81223297, 20.41555977], [86.81223297, 20.41527939], [86.81305695, 20.41444016], [86.81305695, 20.4141674], [86.8133316, 20.41389084], [86.81305695, 20.41362], [86.81305695, 20.41333008], [86.8133316, 20.41305542], [86.8133316, 20.41250038], [86.81360626, 20.41222191], [86.81361389, 20.41166687], [86.81388092, 20.4113903], [86.81388092, 20.41111183], [86.81416321, 20.41083336], [86.81416321, 20.41055489], [86.81445313, 20.41028023], [86.81445313, 20.40806007], [86.81472015, 20.40777969], [86.81472015, 20.40722084], [86.81486511, 20.4066906], [86.81468201, 20.40624619], [86.81446075, 20.40584946], [86.81434631, 20.40545273], [86.81446075, 20.40504074], [86.81463623, 20.40462112], [86.81465912, 20.40414047], [86.81450653, 20.40367889], [86.81439209, 20.40316963], [86.81420135, 20.40267944], [86.81404877, 20.40218735], [86.81391144, 20.40172005], [86.81377411, 20.40130043], [86.81373596, 20.40076828], [86.81360626, 20.40028], [86.81360626, 20.39999962], [86.81276703, 20.39916992], [86.81276703, 20.39862061], [86.8125, 20.3983326], [86.8125, 20.39777756], [86.81223297, 20.3975029], [86.81223297, 20.39722252], [86.81194305, 20.39694405], [86.81194305, 20.39639091], [86.8116684, 20.39610863], [86.81141663, 20.39571953], [86.81118011, 20.39534187], [86.81095886, 20.39491653], [86.81079102, 20.39444923], [86.81054688, 20.39402962], [86.81031799, 20.39363289], [86.81015778, 20.39322281], [86.81010437, 20.39276695], [86.810112, 20.39227104], [86.80992889, 20.39190292], [86.80966949, 20.3915596], [86.80950165, 20.3911705], [86.80944824, 20.3908329], [86.80944824, 20.39027786], [86.80916595, 20.38999939], [86.80916595, 20.38943291], [86.80860901, 20.38888931], [86.80860901, 20.38861084], [86.80832672, 20.38833046], [86.80833435, 20.38722229], [86.80805206, 20.38694382], [86.80805206, 20.38638878], [86.8077774, 20.38611031], [86.8077774, 20.38528061], [86.80750275, 20.38500023], [86.80750275, 20.38389015], [86.8077774, 20.38362122], [86.8077774, 20.38194084], [86.80750275, 20.38166618], [86.80750275, 20.38110924], [86.8077774, 20.38083076], [86.8077774, 20.38055611], [86.80750275, 20.38027954], [86.80750275, 20.37833023], [86.80722046, 20.37805557], [86.80722046, 20.375], [86.8069458, 20.37471962], [86.8069458, 20.37444305], [86.80665588, 20.3741703], [86.80665588, 20.37388992], [86.80444336, 20.37166977], [86.8041687, 20.37166977], [86.80388641, 20.37138939], [86.80361176, 20.37166595], [86.80361176, 20.37194443], [86.8033371, 20.3722229], [86.8033371, 20.37249947], [86.80361176, 20.37277985], [86.80361176, 20.37388802], [86.80444336, 20.37472153], [86.80304718, 20.37611008], [86.80304718, 20.37667084], [86.80444336, 20.37805939], [86.80444336, 20.37861061], [86.80473328, 20.37889099], [86.80472565, 20.37916946], [86.80500031, 20.37944412], [86.80500031, 20.37972069], [86.80526733, 20.37999916], [86.80527496, 20.38027954], [86.80555725, 20.38055038], [86.80555725, 20.38110924], [86.80565643, 20.38121033], [86.80583191, 20.38139153], [86.80583191, 20.38166618], [86.8061142, 20.38194466], [86.80610657, 20.38221931], [86.80583191, 20.3825016], [86.80583191, 20.38333321], [86.80580902, 20.38389969], [86.80578613, 20.38443947], [86.80563354, 20.38495445], [86.80570984, 20.38542938], [86.80580902, 20.38588905], [86.80583191, 20.38636208], [86.80587769, 20.38685226], [86.80606079, 20.38735008], [86.80605316, 20.38786125], [86.80589294, 20.38834], [86.80587006, 20.38884926], [86.80589294, 20.38931084], [86.80570221, 20.38962173], [86.80543518, 20.38975143], [86.80508423, 20.38950157], [86.80474091, 20.38900757], [86.80466461, 20.38887405], [86.80440521, 20.38843536], [86.80404663, 20.38792038], [86.80370331, 20.38748169], [86.80269623, 20.3864975], [86.80220032, 20.38609505], [86.80169678, 20.38610268], [86.80155182, 20.38656807], [86.8015213, 20.38713074], [86.80145264, 20.38766098], [86.80124664, 20.38812065], [86.80105591, 20.38863754], [86.80073547, 20.38921356], [86.80049133, 20.3895874], [86.80030823, 20.3898716], [86.80041504, 20.39044952], [86.80057526, 20.39105225], [86.80083466, 20.39155006], [86.80110931, 20.39194107], [86.80194092, 20.3927803], [86.80194092, 20.39305496], [86.80222321, 20.39333344], [86.80222321, 20.39471817], [86.80194092, 20.39499855], [86.80194092, 20.3955555], [86.80166626, 20.39582825], [86.80166626, 20.39610863], [86.80110931, 20.39666939], [86.80098724, 20.39692116], [86.8006897, 20.39712524], [86.80033112, 20.3973484], [86.80000305, 20.39770508], [86.79977417, 20.39822388], [86.79973602, 20.39883995], [86.79989624, 20.39937782], [86.80055237, 20.39964294], [86.80097198, 20.4000206], [86.80122375, 20.40039063], [86.8013916, 20.40083122], [86.80222321, 20.40167999], [86.80222321, 20.40195084], [86.80110931, 20.40305519], [86.80110931, 20.40332985], [86.8013916, 20.40361023], [86.8013916, 20.40416527], [86.80166626, 20.40443039], [86.80166626, 20.40611076], [86.8013916, 20.40639114], [86.8013916, 20.4066658], [86.80110931, 20.40694046], [86.80110931, 20.40750122], [86.80082703, 20.40777969], [86.80110931, 20.40806007], [86.80110931, 20.40889168], [86.8013916, 20.40916634], [86.8013916, 20.40971947], [86.80083466, 20.41027832], [86.80047607, 20.41052055], [86.80046844, 20.4109211], [86.80059052, 20.41135979], [86.80086517, 20.41177559], [86.8013916, 20.41222382], [86.80166626, 20.41222191], [86.80194092, 20.41250038], [86.80222321, 20.41250038], [86.80249786, 20.41278076], [86.80278015, 20.41278076], [86.8033371, 20.41222191], [86.80361176, 20.41222382], [86.80388641, 20.41194534], [86.8041687, 20.41195107], [86.80473328, 20.4113903], [86.80500031, 20.4113903], [86.80555725, 20.41082954], [86.80555725, 20.41055489], [86.80583191, 20.41028023], [86.80638885, 20.41027832], [86.8069458, 20.41082954], [86.8061142, 20.41166687], [86.80610657, 20.41222191], [86.80638885, 20.41250038], [86.80638885, 20.41277695], [86.8069458, 20.41333389], [86.80583191, 20.41444588], [86.80500031, 20.41444016], [86.8041687, 20.41527748], [86.8041687, 20.41583061], [86.80361176, 20.41638947], [86.8033371, 20.41638947], [86.80304718, 20.41666031], [86.80305481, 20.41777611], [86.80222321, 20.41860962], [86.80222321, 20.41888809], [86.80166626, 20.41945076], [86.80166626, 20.41999817], [86.80249786, 20.42083359], [86.80278015, 20.42083359]]], [[[86.80272675, 20.45947266], [86.80259705, 20.45947266], [86.80202484, 20.45953751], [86.8015213, 20.45967293], [86.80130768, 20.45994377], [86.80123901, 20.46047974], [86.80123901, 20.46115685], [86.80137634, 20.46183014], [86.80145264, 20.46224976], [86.80194855, 20.46250725], [86.80245209, 20.46264267], [86.80281067, 20.46264267], [86.80330658, 20.46250725], [86.8035965, 20.46197128], [86.8035965, 20.46149063], [86.80323792, 20.46081924], [86.80287933, 20.46027756], [86.80272675, 20.45947266]]], [[[86.80527496, 20.49194527], [86.80638885, 20.49083328], [86.80638885, 20.49055481], [86.8069458, 20.49000168], [86.8069458, 20.48971939], [86.80722046, 20.48944473], [86.80722046, 20.48916626], [86.80750275, 20.48887825], [86.80750275, 20.48860931], [86.8077774, 20.48833084], [86.8077774, 20.48777962], [86.80805206, 20.48749924], [86.8077774, 20.48722076], [86.8077774, 20.4869442], [86.80805206, 20.48666573], [86.80805206, 20.48639107], [86.80832672, 20.48611069], [86.80832672, 20.48555946], [86.80860901, 20.48528099], [86.80860901, 20.48443985], [86.80944824, 20.48361206], [86.80916595, 20.48333359], [86.80916595, 20.48305511], [86.80860901, 20.48250008], [86.8088913, 20.4822197], [86.8088913, 20.48166656], [86.80860901, 20.48139], [86.80944824, 20.4805603], [86.80944824, 20.47999954], [86.80916595, 20.47970963], [86.80916595, 20.4794445], [86.8088913, 20.47916603], [86.8088913, 20.47805977], [86.80916595, 20.47777939], [86.80916595, 20.47722244], [86.80944824, 20.47694206], [86.80944824, 20.4766674], [86.80860901, 20.47582817], [86.80833435, 20.47444534], [86.80832672, 20.47417068], [86.80805206, 20.47390175], [86.8077774, 20.47390175], [86.80715179, 20.47326279], [86.8069458, 20.47305489], [86.8069458, 20.47277641], [86.80665588, 20.47249985], [86.80665588, 20.47194099], [86.80583191, 20.4711113], [86.80583191, 20.4691658], [86.80603027, 20.46838188], [86.80603027, 20.46757126], [86.80594635, 20.46689034], [86.80573273, 20.46669006], [86.80558777, 20.46648788], [86.8055191, 20.46600914], [86.80530548, 20.46567726], [86.80523682, 20.46521187], [86.80487823, 20.46459961], [86.80478668, 20.46445274], [86.80444336, 20.46388817], [86.8041687, 20.4636116], [86.80361176, 20.4636116], [86.80249786, 20.46470833], [86.80278015, 20.46500015], [86.80278015, 20.46555519], [86.80304718, 20.46582985], [86.80305481, 20.46666718], [86.80278015, 20.46694374], [86.80278015, 20.46776962], [86.80249786, 20.46805573], [86.80249786, 20.46972084], [86.80222321, 20.47000122], [86.80222321, 20.47056007], [86.80194092, 20.47083282], [86.80194092, 20.47222137], [86.80110931, 20.47305489], [86.80110931, 20.47333336], [86.80082703, 20.47360992], [86.80082703, 20.47390175], [86.80110931, 20.47417068], [86.80110931, 20.47444534], [86.8013916, 20.47471809], [86.8013916, 20.47527695], [86.80153656, 20.47542572], [86.80166626, 20.47555542], [86.80166626, 20.47582817], [86.80194092, 20.47610855], [86.80194092, 20.47639084], [86.80388641, 20.47833061], [86.80526733, 20.47970963], [86.80527496, 20.48027802], [86.80583191, 20.48083305], [86.80583191, 20.48110962], [86.8041687, 20.48278046], [86.80388641, 20.48277855], [86.8033371, 20.48332977], [86.80388641, 20.48389053], [86.80388641, 20.48416519], [86.80361176, 20.48443985], [86.80361176, 20.48500061], [86.8041687, 20.48555946], [86.8041687, 20.48583984], [86.80388641, 20.48611069], [86.80388641, 20.48639107], [86.8041687, 20.48666954], [86.80444336, 20.48666573], [86.80472565, 20.4869442], [86.80473328, 20.48722076], [86.80500031, 20.48749733], [86.80500031, 20.48833275], [86.80444336, 20.48887825], [86.80444336, 20.48916626], [86.8041687, 20.48944473], [86.8041687, 20.48971939], [86.80444336, 20.49000168], [86.80444336, 20.49083328], [86.8041687, 20.49111176], [86.8041687, 20.49139023], [86.80444336, 20.49167061], [86.80500031, 20.49166679], [86.80527496, 20.49194527]]], [[[87.0085144, 20.70812225], [87.00765991, 20.70798874], [87.00522614, 20.70799065], [87.00444794, 20.70806122], [87.00366211, 20.70833015], [87.00243378, 20.70866585], [87.00243378, 20.70900345], [87.00286102, 20.70953751], [87.00328827, 20.70994949], [87.00378418, 20.71042061], [87.00443268, 20.71089172], [87.00463867, 20.71108437], [87.00508118, 20.71150017], [87.00585938, 20.71237946], [87.00628662, 20.71305084], [87.00656891, 20.71359062], [87.00714111, 20.71426964], [87.00734711, 20.71480942], [87.00764465, 20.7154808], [87.00814056, 20.71622276], [87.0087204, 20.71696281], [87.00928497, 20.71770668], [87.00992584, 20.7183094], [87.01064301, 20.71905518], [87.01107025, 20.71937943], [87.0114975, 20.7198658], [87.01199341, 20.72040558], [87.01264954, 20.72081184], [87.01328278, 20.72114754], [87.01391602, 20.72154808], [87.01441956, 20.7218895], [87.01513672, 20.72216034], [87.01550293, 20.72223091], [87.01572418, 20.72222328], [87.01583099, 20.72222137], [87.01611328, 20.72194481], [87.01642609, 20.72154045], [87.01657867, 20.72120094], [87.01686096, 20.72079659], [87.01706696, 20.72032928], [87.01721191, 20.71992111], [87.01743317, 20.71945], [87.01750183, 20.71898079], [87.0175705, 20.71857071], [87.0175705, 20.71768951], [87.01763916, 20.71742439], [87.01778412, 20.71722031], [87.01778412, 20.71668434], [87.01750183, 20.71610832], [87.01748657, 20.71602058], [87.01743317, 20.7156105], [87.01743317, 20.71500587], [87.01721954, 20.71433067], [87.01693726, 20.71393013], [87.01657867, 20.71325111], [87.01615143, 20.71244049], [87.01586914, 20.7121048], [87.01551056, 20.71183205], [87.01486969, 20.7110939], [87.01415253, 20.71041679], [87.01373291, 20.7100811], [87.01315308, 20.70981026], [87.01258087, 20.70935249], [87.01180267, 20.70900154], [87.01115417, 20.70879745], [87.01072693, 20.70853043], [87.00987244, 20.70833015], [87.0091629, 20.70819092], [87.0085144, 20.70812225]]], [[[87.00302124, 20.71079063], [87.00230408, 20.71033287], [87.00216675, 20.7105999], [87.00216675, 20.71087265], [87.00238037, 20.71114159], [87.0025177, 20.71141052], [87.00266266, 20.71181488], [87.00295258, 20.71215057], [87.0030899, 20.71249008], [87.00323486, 20.71289635], [87.00330353, 20.71343231], [87.00402069, 20.71423912], [87.00430298, 20.71471977], [87.0045929, 20.71525955], [87.00502014, 20.71572876], [87.00526428, 20.71611595], [87.005867, 20.71707916], [87.0063858, 20.71762085], [87.00686646, 20.71870041], [87.00786591, 20.7197094], [87.00830078, 20.72005081], [87.00872803, 20.72024918], [87.00901794, 20.72024918], [87.0091629, 20.71997833], [87.00908661, 20.7197094], [87.00879669, 20.7193718], [87.00880432, 20.71883392], [87.00865936, 20.71849442], [87.0085144, 20.71809006], [87.00830078, 20.71767807], [87.00815582, 20.71707726], [87.00765991, 20.7166729], [87.00737762, 20.71640205], [87.00694275, 20.71559334], [87.00687408, 20.71518707], [87.00630188, 20.71430969], [87.00601959, 20.71336555], [87.00559235, 20.71289063], [87.00523376, 20.71242142], [87.00504303, 20.71223831], [87.00487518, 20.71208382], [87.00437927, 20.71174622], [87.00395203, 20.71147919], [87.00358582, 20.71128273], [87.00337982, 20.71114159], [87.00302124, 20.71079063]]], [[[87.01651001, 20.80282974], [87.01651001, 20.80067062], [87.0167923, 20.79904938], [87.0167923, 20.79824066], [87.01651001, 20.79770088], [87.01566315, 20.79743958], [87.01499939, 20.79722023], [87.01444244, 20.79722023], [87.01416779, 20.79750252], [87.01389313, 20.79750252], [87.01333618, 20.79805946], [87.01333618, 20.79861259], [87.01361084, 20.79888153], [87.01361084, 20.79916573], [87.01399994, 20.79958344], [87.01399994, 20.80120277], [87.01342773, 20.80201149], [87.01314545, 20.80228233], [87.01315308, 20.80255127], [87.01228333, 20.80282974], [87.01200104, 20.80282974], [87.01171875, 20.80308914], [87.01142883, 20.80336189], [87.00858307, 20.80606079], [87.00743103, 20.80714035], [87.00685883, 20.80795097], [87.00657654, 20.80821991], [87.00572205, 20.80957031], [87.00543213, 20.81038094], [87.00514984, 20.81118965], [87.00457764, 20.81226921], [87.00457764, 20.81578827], [87.00430298, 20.81659126], [87.00401306, 20.8168602], [87.00343323, 20.81793594], [87.00343323, 20.81874084], [87.00286865, 20.81955528], [87.00257874, 20.82090378], [87.00229645, 20.82198334], [87.00200653, 20.82333374], [87.00172424, 20.8244133], [87.00115204, 20.8257637], [87.00086975, 20.82683945], [87.00057983, 20.82846069], [87.00086975, 20.82953835], [87.00250244, 20.83222198], [87.0027771, 20.83222198], [87.00487518, 20.83232117], [87.0065918, 20.83232117], [87.00830078, 20.83177948], [87.00944519, 20.83097267], [87.01087189, 20.82989311], [87.01258087, 20.82827568], [87.01429749, 20.82665443], [87.01544189, 20.82584381], [87.01629639, 20.82449532], [87.0174408, 20.82368088], [87.01857758, 20.82287407], [87.01914978, 20.82152748], [87.01972198, 20.81991005], [87.01999664, 20.81855965], [87.01999664, 20.81478119], [87.0194397, 20.81343079], [87.0187912, 20.81226921], [87.0187912, 20.81064987], [87.01822662, 20.80903244], [87.01822662, 20.80768585], [87.0173645, 20.80444527], [87.0167923, 20.80336952], [87.01651001, 20.80282974]]], [[[86.98416901, 20.78222275], [86.98444366, 20.78194427], [86.98500061, 20.78194427], [86.9861145, 20.7808342], [86.98665619, 20.78083992], [86.98722076, 20.78028107], [86.98750305, 20.78028107], [86.98750305, 20.77943993], [86.98666382, 20.77861023], [86.98527527, 20.77861023], [86.98500061, 20.77833366], [86.98305511, 20.77833366], [86.98278046, 20.77805519], [86.98194122, 20.77805519], [86.98166656, 20.77833366], [86.98139191, 20.77832985], [86.98055267, 20.77916718], [86.98055267, 20.77944374], [86.98027802, 20.77972031], [86.98027802, 20.78000069], [86.98055267, 20.78028107], [86.98055267, 20.78055954], [86.98166656, 20.78166771], [86.98222351, 20.7816658], [86.98249817, 20.78194427], [86.98278046, 20.78194427], [86.98305511, 20.78222275], [86.98416901, 20.78222275]]], [[[86.87527466, 20.77583313], [86.87555695, 20.77555466], [86.87611389, 20.77555466], [86.8769455, 20.77472305], [86.87722015, 20.77472305], [86.8777771, 20.77416611], [86.8777771, 20.77318954], [86.8777771, 20.77305603], [86.87750244, 20.77277946], [86.87695313, 20.77277946], [86.87666321, 20.77305984], [86.87611389, 20.77305603], [86.8758316, 20.7733345], [86.87555695, 20.77333069], [86.87526703, 20.77361107], [86.875, 20.77361107], [86.87444305, 20.77416611], [86.87444305, 20.77444077], [86.87388611, 20.77499962], [86.87388611, 20.77555466], [86.8741684, 20.77583313], [86.87472534, 20.77583313], [86.875, 20.77555466], [86.87516022, 20.77571869], [86.87527466, 20.77583313]]], [[[86.86499023, 20.78111076], [86.86528015, 20.78083992], [86.86554718, 20.78083992], [86.8658371, 20.78055954], [86.86638641, 20.78055954], [86.8666687, 20.78028107], [86.86723328, 20.78028107], [86.86776733, 20.77972031], [86.86805725, 20.77972221], [86.86833191, 20.77944374], [86.8686142, 20.77944374], [86.87166595, 20.77638817], [86.87166595, 20.7761097], [86.87083435, 20.77527809], [86.8702774, 20.77527809], [86.87000275, 20.77555466], [86.8694458, 20.77555466], [86.86916351, 20.77583313], [86.8686142, 20.77583313], [86.86833191, 20.7761116], [86.86805725, 20.7761097], [86.86750031, 20.77667046], [86.86722565, 20.77666664], [86.8666687, 20.77722168], [86.86638641, 20.77722168], [86.8658371, 20.77777863], [86.86554718, 20.777771], [86.86444092, 20.77889061], [86.86444092, 20.77916718], [86.86416626, 20.77943993], [86.86416626, 20.78055954], [86.86472321, 20.78111076], [86.86499023, 20.78111076]]], [[[86.88194275, 20.78861046], [86.88223267, 20.78833008], [86.88666534, 20.7883358], [86.88694763, 20.78805542], [86.89083099, 20.78806114], [86.89111328, 20.78778076], [86.89277649, 20.78778076], [86.89305878, 20.78750038], [86.89417267, 20.78750038], [86.89444733, 20.78722382], [86.89666748, 20.78722382], [86.89694214, 20.78694534], [86.89833069, 20.78694534], [86.89861298, 20.78666687], [86.90000153, 20.78667068], [86.90027618, 20.7863903], [86.90083313, 20.7863903], [86.90110016, 20.78611183], [86.90193176, 20.78611374], [86.90249634, 20.78611374], [86.90277863, 20.78583145], [86.90305328, 20.78583145], [86.90333557, 20.78555489], [86.90416718, 20.78555489], [86.90444183, 20.78527832], [86.90471649, 20.78528023], [86.90499878, 20.78500175], [86.90556335, 20.78500175], [86.90583038, 20.78471947], [86.90611267, 20.78471947], [86.90638733, 20.78444481], [86.90777588, 20.78444481], [86.90805817, 20.78416634], [86.90888977, 20.78417015], [86.9091568, 20.78390121], [86.90999603, 20.78390121], [86.91028595, 20.78360939], [86.91139221, 20.78360939], [86.91166687, 20.78333282], [86.91305542, 20.78333282], [86.91333008, 20.78305626], [86.91361237, 20.78306007], [86.91388702, 20.7827816], [86.91443634, 20.7827816], [86.91471863, 20.78249931], [86.91694641, 20.78249931], [86.91722107, 20.78222084], [86.91777802, 20.78222275], [86.91805267, 20.78194427], [86.91944122, 20.78194427], [86.91972351, 20.7816658], [86.92193604, 20.78166771], [86.92222595, 20.78138924], [86.92415619, 20.78138924], [86.92444611, 20.78111076], [86.92610931, 20.78111076], [86.9263916, 20.78083992], [86.92694092, 20.78083992], [86.92722321, 20.78055954], [86.92778015, 20.78055954], [86.92804718, 20.78083992], [86.92861176, 20.78083992], [86.92888641, 20.78055954], [86.93055725, 20.78055954], [86.93083191, 20.78028107], [86.93222046, 20.78028107], [86.93250275, 20.78055954], [86.93360901, 20.78055954], [86.9338913, 20.78028107], [86.93638611, 20.78028107], [86.9366684, 20.78028107], [86.93694305, 20.78000069], [86.93723297, 20.78000069], [86.9375, 20.78028107], [86.9383316, 20.78028107], [86.93860626, 20.78000069], [86.94026947, 20.78000069], [86.94055176, 20.77972031], [86.94194794, 20.77972221], [86.9422226, 20.77944374], [86.94249725, 20.77944374], [86.94277954, 20.77916718], [86.94361115, 20.77917099], [86.94481659, 20.77840805], [86.94610596, 20.77786827], [86.94760895, 20.77726173], [86.94944, 20.77667046], [86.95024872, 20.77639961], [86.95096588, 20.77579117], [86.95153046, 20.77518082], [86.95153046, 20.7747097], [86.95054626, 20.77388954], [86.94999695, 20.77333069], [86.94944763, 20.7733345], [86.94927979, 20.77316666], [86.94916534, 20.77305603], [86.94902802, 20.77305603], [86.9486084, 20.77305984], [86.94832611, 20.77277946], [86.94695282, 20.77277946], [86.9466629, 20.7725029], [86.94555664, 20.7725029], [86.94526672, 20.77277946], [86.9422226, 20.77277946], [86.94194794, 20.7725029], [86.9411087, 20.7725029], [86.94082642, 20.77222061], [86.94055176, 20.77222061], [86.94026947, 20.77194023], [86.93972015, 20.7725029], [86.93945313, 20.7725029], [86.93916321, 20.77277946], [86.93527985, 20.77277946], [86.93499756, 20.77305984], [86.93416595, 20.77305603], [86.9338913, 20.7733345], [86.93222046, 20.77333069], [86.9319458, 20.77361107], [86.93110657, 20.77361107], [86.93083191, 20.77388954], [86.92804718, 20.77388954], [86.92778015, 20.77416992], [86.92666626, 20.77416992], [86.9263916, 20.77388954], [86.92555237, 20.77388954], [86.92527008, 20.77416992], [86.92082977, 20.77416992], [86.92073822, 20.77407646], [86.92055511, 20.77388954], [86.92028046, 20.77388954], [86.91999817, 20.77416992], [86.91832733, 20.77416992], [86.91805267, 20.77388954], [86.91777802, 20.77388954], [86.91750336, 20.77416992], [86.91666412, 20.77416611], [86.91638947, 20.77444458], [86.91444397, 20.77444458], [86.91416931, 20.77472305], [86.91388702, 20.77472305], [86.91361237, 20.77444458], [86.91333008, 20.77472305], [86.91194153, 20.77472305], [86.91166687, 20.77444458], [86.91083527, 20.77444458], [86.91055298, 20.77472305], [86.90777588, 20.77472305], [86.90750122, 20.77444458], [86.90694427, 20.77444458], [86.90638733, 20.77388954], [86.90611267, 20.77388954], [86.90583038, 20.77361107], [86.90471649, 20.77361107], [86.90444183, 20.77333069], [86.90333557, 20.7733345], [86.90313721, 20.77313805], [86.90305328, 20.77305603], [86.90277863, 20.77305984], [86.90249634, 20.77277946], [86.90222168, 20.77277946], [86.90194702, 20.7725029], [86.90139008, 20.7725029], [86.90110016, 20.77222061], [86.90027618, 20.77222061], [86.90000153, 20.77194214], [86.89722443, 20.77194214], [86.89694214, 20.77166748], [86.89527893, 20.77166748], [86.89499664, 20.77194214], [86.89083099, 20.77194214], [86.89055634, 20.77222061], [86.88722229, 20.77222061], [86.88694763, 20.7725029], [86.88500214, 20.7725029], [86.88471985, 20.77277946], [86.88360596, 20.77277946], [86.8833313, 20.77305984], [86.88083649, 20.77305603], [86.8805542, 20.7733345], [86.87999725, 20.7733345], [86.87889099, 20.77444077], [86.87944794, 20.77499962], [86.88028717, 20.77499962], [86.8805542, 20.77472305], [86.88111115, 20.77472305], [86.8813858, 20.77444458], [86.88222504, 20.77444458], [86.88249969, 20.77416611], [86.88361359, 20.77416611], [86.88388824, 20.77444458], [86.8841629, 20.77444458], [86.88445282, 20.7747097], [86.8841629, 20.77499962], [86.88388824, 20.77499962], [86.88360596, 20.77528], [86.88277435, 20.77527809], [86.88249969, 20.77555466], [86.88222504, 20.77555466], [86.88194275, 20.77583313], [86.88166809, 20.77583313], [86.8813858, 20.7761116], [86.88083649, 20.7761097], [86.88054657, 20.77639008], [86.87999725, 20.77639008], [86.8797226, 20.77667046], [86.87944794, 20.77667046], [86.87917328, 20.77695084], [86.87889099, 20.77695084], [86.87722015, 20.77861023], [86.87670135, 20.77861023], [86.87638855, 20.77861023], [86.87631226, 20.77853584], [86.87611389, 20.77833366], [86.8758316, 20.77833366], [86.87555695, 20.77806091], [86.87444305, 20.77917099], [86.87388611, 20.77916718], [86.87361145, 20.77944374], [86.8730545, 20.77944374], [86.87277985, 20.77916718], [86.87249756, 20.77944374], [86.87194824, 20.77944374], [86.87166595, 20.77972221], [86.87082672, 20.77972031], [86.87055206, 20.78000069], [86.87000275, 20.78000069], [86.86972046, 20.78028107], [86.8694458, 20.78028107], [86.86915588, 20.78055954], [86.86888885, 20.78055954], [86.86860657, 20.78083992], [86.86833191, 20.78083992], [86.86805725, 20.78111076], [86.86776733, 20.78111076], [86.86750031, 20.78138924], [86.86723328, 20.78138924], [86.86694336, 20.78166771], [86.8666687, 20.7816658], [86.86638641, 20.78194427], [86.86611176, 20.78194427], [86.8658371, 20.78222275], [86.86554718, 20.78222084], [86.86528015, 20.78249931], [86.86528015, 20.78305626], [86.86555481, 20.78333282], [86.86555481, 20.78360939], [86.86638641, 20.78444481], [86.8666687, 20.78444481], [86.86722565, 20.78500175], [86.86750031, 20.78500175], [86.86805725, 20.78555489], [86.86833191, 20.78555489], [86.8686142, 20.78583145], [86.86888885, 20.78583145], [86.86916351, 20.78611374], [86.86972046, 20.78611183], [86.87000275, 20.7863903], [86.87082672, 20.7863903], [86.87111664, 20.78667068], [86.8713913, 20.78666687], [86.87194824, 20.78722382], [86.87304688, 20.78722], [86.87333679, 20.78750038], [86.87472534, 20.78750038], [86.87490845, 20.78768539], [86.875, 20.78778076], [86.87555695, 20.78778076], [86.8758316, 20.78806114], [86.87638855, 20.78805542], [86.87666321, 20.7883358], [86.87906647, 20.78833389], [86.88083649, 20.78833008], [86.88111115, 20.78861046], [86.88194275, 20.78861046]]], [[[86.94812775, 20.78457069], [86.94813538, 20.78423691], [86.94777679, 20.78390121], [86.94728088, 20.78390121], [86.94670868, 20.78396988], [86.94556427, 20.78430557], [86.94535065, 20.78437233], [86.94456482, 20.78437233], [86.94428253, 20.78423691], [86.94371033, 20.78430939], [86.94364166, 20.78443909], [86.94361115, 20.78500175], [86.94361115, 20.78528023], [86.94499969, 20.78667068], [86.94610596, 20.78667068], [86.94621277, 20.78619003], [86.94656372, 20.78565407], [86.94734955, 20.78531647], [86.94783783, 20.78498077], [86.94812775, 20.78457069]]], [[[86.79166412, 20.37361145], [86.79194641, 20.37333488], [86.79222107, 20.37333488], [86.79250336, 20.37305641], [86.79360962, 20.37305641], [86.79380035, 20.37324142], [86.79389191, 20.37333488], [86.79416656, 20.37333488], [86.79444122, 20.37305641], [86.79471588, 20.37306023], [86.79556274, 20.3722229], [86.79582977, 20.3722229], [86.79582977, 20.37166595], [86.79528046, 20.37111282], [86.79528046, 20.37000275], [86.7950058, 20.36965942], [86.79483795, 20.36925697], [86.79466248, 20.3687706], [86.79444122, 20.36832047], [86.79424286, 20.36791039], [86.79411316, 20.36748505], [86.79389954, 20.36713028], [86.79360962, 20.36667061], [86.79232788, 20.36538696], [86.79222107, 20.36527634], [86.79166412, 20.36527634], [86.79111481, 20.36583328], [86.79111481, 20.36611176], [86.7910614, 20.36624908], [86.79083252, 20.36681938], [86.7906189, 20.36735725], [86.79046631, 20.36792183], [86.79038239, 20.36857986], [86.79038239, 20.36929512], [86.79037476, 20.36997414], [86.79042816, 20.37067032], [86.79052734, 20.37136078], [86.79055786, 20.37205124], [86.79062653, 20.37269974], [86.79103088, 20.37322044], [86.79166412, 20.37361145]]], [[[86.79390717, 20.3799305], [86.7943573, 20.37966919], [86.79469299, 20.37936974], [86.79490662, 20.37907028], [86.79503632, 20.37874413], [86.79521179, 20.37842369], [86.79534912, 20.37804222], [86.79554749, 20.37770081], [86.79574585, 20.37741089], [86.7958374, 20.37722015], [86.79676819, 20.37661171], [86.79711914, 20.37607193], [86.79698181, 20.37505913], [86.79638672, 20.37471962], [86.79638672, 20.37444305], [86.7958374, 20.37445068], [86.79555511, 20.37416649], [86.79499817, 20.37471962], [86.79416656, 20.37556076], [86.79389191, 20.37556076], [86.79389191, 20.375], [86.79360962, 20.37471962], [86.79277802, 20.37471962], [86.79250336, 20.375], [86.79222107, 20.375], [86.79166412, 20.37555695], [86.79165649, 20.3758297], [86.79110718, 20.37639046], [86.79110718, 20.37778091], [86.79083252, 20.37805557], [86.79083252, 20.37833023], [86.79110718, 20.37861061], [86.79111481, 20.37888718], [86.79194641, 20.3797226], [86.79222107, 20.37972069], [86.79250336, 20.37999916], [86.79332733, 20.37999916], [86.79390717, 20.3799305]]], [[[86.79305267, 20.38417053], [86.79277802, 20.38389015], [86.79110718, 20.3855629], [86.79165649, 20.38611031], [86.79194641, 20.38611031], [86.79332733, 20.38750076], [86.79389191, 20.38750076], [86.79444122, 20.38694], [86.79444122, 20.38666725], [86.79416656, 20.38639069], [86.79389191, 20.38639069], [86.79389191, 20.38445282], [86.79389191, 20.38417053], [86.79305267, 20.38417053]]], [[[86.50166321, 20.17584038], [86.50195312, 20.17556], [86.50250244, 20.17556], [86.5027771, 20.17527962], [86.5036087, 20.17527962], [86.50417328, 20.17472076], [86.50444794, 20.17472267], [86.5047226, 20.1744442], [86.50499725, 20.1744442], [86.50527954, 20.17416573], [86.50583649, 20.17416954], [86.50611115, 20.17389107], [86.50723267, 20.17389107], [86.50805664, 20.17305946], [86.50805664, 20.17250061], [86.50694275, 20.17139053], [86.50666809, 20.17139053], [86.50554657, 20.17028046], [86.50499725, 20.17028046], [86.50499725, 20.17000008], [86.50388336, 20.16889191], [86.5027771, 20.16889191], [86.50250244, 20.16861153], [86.50236511, 20.16875076], [86.50222015, 20.16889191], [86.50166321, 20.16832924], [86.50027466, 20.16833305], [86.5, 20.16805649], [86.5, 20.16778183], [86.49994659, 20.16721916], [86.49978638, 20.16676712], [86.49951172, 20.16634941], [86.4992218, 20.16589737], [86.4989624, 20.16539001], [86.49861908, 20.16489983], [86.4982605, 20.1644268], [86.49793243, 20.16390991], [86.49773407, 20.1632309], [86.49746704, 20.16254997], [86.49710846, 20.16195869], [86.49656677, 20.1616993], [86.49594879, 20.1616993], [86.4956665, 20.1616993], [86.4953537, 20.16183662], [86.49488831, 20.16197395], [86.49440765, 20.16221237], [86.49395752, 20.16245079], [86.49363708, 20.16277122], [86.49346924, 20.16312027], [86.49358368, 20.16348457], [86.49371338, 20.16383934], [86.49388885, 20.16419029], [86.4940567, 20.16455078], [86.49423218, 20.16489029], [86.49446869, 20.16519928], [86.49462891, 20.1654644], [86.49440002, 20.16570282], [86.49394226, 20.16586685], [86.4938736, 20.16589355], [86.49352264, 20.16594124], [86.49311829, 20.16580009], [86.49272156, 20.16556931], [86.49228668, 20.16530991], [86.49185944, 20.16489029], [86.49156952, 20.1648922], [86.4913559, 20.16525078], [86.49111938, 20.16572762], [86.49091339, 20.16628075], [86.49085999, 20.16685677], [86.4908905, 20.16739464], [86.49079132, 20.16788101], [86.49054718, 20.16834259], [86.49025726, 20.16883278], [86.48993683, 20.16935921], [86.48960876, 20.16990089], [86.48963928, 20.17038727], [86.49008179, 20.17073059], [86.49066162, 20.17098045], [86.49117279, 20.17128944], [86.4916687, 20.17152023], [86.49222565, 20.1716671], [86.49250031, 20.17194366], [86.49277496, 20.17194366], [86.49305725, 20.17222214], [86.49333191, 20.17222023], [86.49388885, 20.17278099], [86.49388885, 20.17305565], [86.49416351, 20.17333221], [86.4944458, 20.17333221], [86.49500275, 20.17277718], [86.4952774, 20.17278099], [86.49555206, 20.17305946], [86.49583435, 20.17305565], [86.49610901, 20.17345238], [86.49645233, 20.1738205], [86.49675751, 20.17416954], [86.49700928, 20.17451096], [86.49717712, 20.17484283], [86.49732208, 20.17519951], [86.4974823, 20.17556763], [86.49767303, 20.17597198], [86.49798584, 20.17632675], [86.49835968, 20.176651], [86.49884033, 20.17681122], [86.49944305, 20.17661095], [86.50004578, 20.17637062], [86.50061798, 20.17613029], [86.50119019, 20.17588997], [86.50166321, 20.17584038]]], [[[86.43722534, 20.05944443], [86.43805695, 20.05861092], [86.43776703, 20.058321], [86.4375, 20.05833244], [86.43694305, 20.05777931], [86.4366684, 20.05778122], [86.43638611, 20.05750084], [86.43611145, 20.05750084], [86.43527985, 20.05667114], [86.43527985, 20.05611038], [86.43444824, 20.05528069], [86.43444824, 20.05500031], [86.43360901, 20.05417061], [86.43360901, 20.05278015], [86.43416595, 20.05221939], [86.43444824, 20.0522213], [86.4347229, 20.05194473], [86.4347229, 20.05166626], [86.43416595, 20.05111122], [86.43360901, 20.05111122], [86.43332672, 20.05083275], [86.43305206, 20.05111122], [86.43222046, 20.05111122], [86.43222046, 20.05221939], [86.4319458, 20.05251122], [86.4319458, 20.05444336], [86.43165588, 20.05471992], [86.43166351, 20.05527687], [86.43222046, 20.05583], [86.43222046, 20.05611038], [86.43250275, 20.05638885], [86.43250275, 20.05694389], [86.4338913, 20.05833244], [86.43416595, 20.058321], [86.43444824, 20.05861092], [86.43527985, 20.05861092], [86.43554688, 20.05888748], [86.43611145, 20.05888748], [86.43638611, 20.05916977], [86.4366684, 20.05916786], [86.43694305, 20.05944443], [86.43722534, 20.05944443]]], [[[86.49111176, 20.14972305], [86.49138641, 20.14944458], [86.4916687, 20.14944458], [86.4916687, 20.14805412], [86.49223328, 20.14750099], [86.49276733, 20.14750099], [86.49333191, 20.14805984], [86.49333191, 20.14861107], [86.49360657, 20.14890099], [86.49472046, 20.14890099], [86.49472046, 20.14805984], [86.49360657, 20.14694023], [86.4936142, 20.14666748], [86.49276733, 20.14583015], [86.49250031, 20.14583206], [86.49222565, 20.1455555], [86.49111176, 20.1455555], [86.4908371, 20.14583206], [86.49028015, 20.14583015], [86.48999786, 20.14611053], [86.48972321, 20.14611053], [86.48916626, 20.14666748], [86.48916626, 20.14694595], [86.48944092, 20.14722061], [86.48944092, 20.14805412], [86.48916626, 20.14833069], [86.48916626, 20.14861107], [86.48999786, 20.14944458], [86.49055481, 20.14944458], [86.4908371, 20.14972305], [86.49111176, 20.14972305]]], [[[86.55297089, 20.20527077], [86.5526123, 20.20527077], [86.5526886, 20.20581055], [86.55332947, 20.20641708], [86.554039, 20.20681953], [86.55503845, 20.20735931], [86.55532837, 20.20708847], [86.55539703, 20.20675468], [86.55511475, 20.20628166], [86.55432892, 20.20614624], [86.55368042, 20.20569038], [86.55297089, 20.20527077]]], [[[86.4263916, 20.03861046], [86.42610931, 20.03833008], [86.42555237, 20.03833389], [86.42472076, 20.03750038], [86.42472076, 20.03722191], [86.42500305, 20.03694534], [86.42500305, 20.0363903], [86.42444611, 20.03582954], [86.42444611, 20.03555489], [86.42305756, 20.03416634], [86.42279053, 20.03417015], [86.42279053, 20.03388977], [86.42166901, 20.03277969], [86.42166901, 20.03250122], [86.42138672, 20.03222084], [86.42111206, 20.03222275], [86.42082977, 20.03194427], [86.42056274, 20.03222084], [86.42056274, 20.03250122], [86.42028046, 20.03277969], [86.42055511, 20.03305626], [86.42055511, 20.03333282], [86.42082977, 20.03360748], [86.42082977, 20.03416634], [86.42111206, 20.03444481], [86.42111206, 20.03472137], [86.42138672, 20.03500175], [86.42138672, 20.03555489], [86.42166901, 20.03583336], [86.42166901, 20.03611183], [86.42138672, 20.0363903], [86.42138672, 20.03750992], [86.42166901, 20.03777695], [86.42166901, 20.03833008], [86.42360687, 20.04027939], [86.42360687, 20.04057121], [86.42415619, 20.04111099], [86.42415619, 20.04138947], [86.42444611, 20.04166412], [86.42444611, 20.0419445], [86.42472076, 20.04222107], [86.42472076, 20.04249954], [86.42583466, 20.04361153], [86.4263916, 20.04361153], [86.42722321, 20.04277611], [86.42722321, 20.04249954], [86.42749786, 20.04222107], [86.42749786, 20.04166412], [86.42722321, 20.04138947], [86.42722321, 20.04111099], [86.42694092, 20.04083061], [86.42694092, 20.04027748], [86.42666626, 20.04000092], [86.42666626, 20.03944016], [86.4263916, 20.0391674], [86.4263916, 20.03861046]]], [[[86.41085052, 20.01832962], [86.41027832, 20.01777649], [86.40999603, 20.0177803], [86.40972137, 20.01749992], [86.40944672, 20.01749992], [86.4088974, 20.01805115], [86.40888977, 20.01889038], [86.40916443, 20.01916885], [86.4091568, 20.01971817], [86.40944672, 20.02000046], [86.40944672, 20.0205555], [86.40972137, 20.02082825], [86.40972137, 20.02166748], [86.41004181, 20.02203941], [86.41027069, 20.02240944], [86.41049957, 20.02272987], [86.41083527, 20.02305603], [86.41085052, 20.02361107], [86.41110992, 20.02388954], [86.41110992, 20.02416611], [86.41139221, 20.02444458], [86.41139221, 20.02472115], [86.41166687, 20.02499962], [86.41166687, 20.02527809], [86.41222382, 20.02583313], [86.41249847, 20.02583313], [86.41293335, 20.02540016], [86.41305542, 20.02527809], [86.41278076, 20.02499962], [86.41278076, 20.02472115], [86.41249847, 20.02444458], [86.41249847, 20.02388954], [86.41221619, 20.02361107], [86.41221619, 20.0233326], [86.41166687, 20.02277756], [86.41166687, 20.02166939], [86.41221619, 20.02111053], [86.41221619, 20.02055931], [86.4119873, 20.02011108], [86.41178894, 20.01963806], [86.41158295, 20.01908684], [86.41118622, 20.01863289], [86.41085052, 20.01832962]]], [[[86.32110596, 19.98806], [86.32055664, 19.98806], [86.31999969, 19.98861122], [86.31999969, 19.98916435], [86.31972504, 19.98944473], [86.31972504, 19.99055481], [86.31887054, 19.99183273], [86.31879425, 19.9925766], [86.31861115, 19.99332047], [86.31861115, 19.99360847], [86.31833649, 19.99389076], [86.31833649, 19.99471855], [86.31861115, 19.99500084], [86.31944275, 19.99416924], [86.31944275, 19.99360847], [86.31973267, 19.99332809], [86.31972504, 19.99305534], [86.32073212, 19.9914093], [86.32094574, 19.9907341], [86.32137299, 19.98945808], [86.32150269, 19.98908043], [86.32144928, 19.98839569], [86.32110596, 19.98806]]], [[[86.32138824, 19.99888992], [86.32138824, 19.99777985], [86.3216629, 19.99749947], [86.3216629, 19.99666977], [86.32195282, 19.99638939], [86.32194519, 19.99500084], [86.3216629, 19.99472237], [86.3216629, 19.99389076], [86.32110596, 19.99332809], [86.3208313, 19.99332809], [86.32027435, 19.99389076], [86.31999969, 19.99443817], [86.31999969, 19.99500084], [86.31973267, 19.99526978], [86.31972504, 19.99555588], [86.31944275, 19.99583244], [86.31944275, 19.99611282], [86.31861115, 19.99694443], [86.31861115, 19.9972229], [86.31833649, 19.99749947], [86.31833649, 19.99777794], [86.31777954, 19.99833107], [86.31749725, 19.99833107], [86.3172226, 19.99861145], [86.3161087, 19.99860954], [86.31583405, 19.99888802], [86.31561279, 19.99916458], [86.31604004, 19.99943352], [86.31667328, 20.0], [86.31685638, 20.00038719], [86.31735229, 20.00065231], [86.31749725, 20.00083351], [86.31777954, 20.00111008], [86.31817627, 20.00119019], [86.31826782, 20.00172806], [86.31859589, 20.00213051], [86.31900787, 20.00233269], [86.31944275, 20.00226021], [86.31990051, 20.00214577], [86.32021332, 20.00188065], [86.32032776, 20.00148201], [86.32047272, 20.00112534], [86.32064056, 20.00078964], [86.32095337, 20.00043488], [86.32055664, 20.0], [86.32110596, 19.9991703], [86.32138824, 19.99888992]]], [[[86.33557129, 19.99082947], [86.33556366, 19.98981667], [86.33557129, 19.98954964], [86.33528137, 19.98888969], [86.33528137, 19.98861122], [86.33499908, 19.98833084], [86.3347168, 19.98833084], [86.33389282, 19.98917007], [86.33361053, 19.98916435], [86.33305359, 19.9897213], [86.33277893, 19.98971939], [86.33249664, 19.98999977], [86.33220673, 19.98999977], [86.33140564, 19.99081421], [86.33028412, 19.99238205], [86.32993317, 19.99394035], [86.32927704, 19.99570274], [86.32800293, 19.99698639], [86.3272171, 19.99860954], [86.3272171, 20.0], [86.32694244, 20.00027847], [86.32694244, 20.00111008], [86.32672882, 20.00132942], [86.3266983, 20.00140381], [86.32655334, 20.00179291], [86.3263855, 20.00229836], [86.32623291, 20.00284004], [86.32620239, 20.00337791], [86.32640076, 20.00381088], [86.32662201, 20.00419235], [86.32743835, 20.00574112], [86.32779694, 20.00682259], [86.32804871, 20.00797844], [86.32816315, 20.00851059], [86.32836914, 20.00905037], [86.32888794, 20.01000023], [86.32943726, 20.0105629], [86.330513, 20.00975037], [86.33065033, 20.00926971], [86.33095551, 20.00894928], [86.3312912, 20.00859833], [86.33333588, 20.00720978], [86.33333588, 20.00694466], [86.33455658, 20.00572395], [86.33472443, 20.00555611], [86.33472443, 20.00513077], [86.33472443, 20.00499725], [86.33499908, 20.00472069], [86.33499908, 20.00444412], [86.33528137, 20.00416565], [86.33528137, 20.00389099], [86.33557129, 20.00361061], [86.33555603, 20.00333595], [86.33583069, 20.00305557], [86.33557129, 20.00278091], [86.33561707, 20.00242996], [86.33583069, 20.00208092], [86.33603668, 20.00172997], [86.33613586, 20.00131989], [86.33625793, 20.0009594], [86.33634949, 20.00062561], [86.3364563, 20.00031853], [86.33666992, 20.0], [86.33657074, 19.99971962], [86.33686066, 19.99776077], [86.33677673, 19.99613953], [86.33642578, 19.99416924], [86.33637238, 19.99401093], [86.33555603, 19.9916687], [86.33557129, 19.99082947]]], [[[86.32213593, 20.01102448], [86.32194519, 20.01083374], [86.32194519, 20.01055527], [86.32138824, 20.01000023], [86.32111359, 20.01000023], [86.3208313, 20.01026917], [86.3208313, 20.0105629], [86.32027435, 20.01111031], [86.32027435, 20.01194382], [86.31999969, 20.01222229], [86.31999969, 20.01249123], [86.31999969, 20.01305962], [86.31972504, 20.01333427], [86.31973267, 20.01361084], [86.31944275, 20.01389122], [86.31944275, 20.01416588], [86.3188858, 20.01472092], [86.3188858, 20.01499939], [86.31861115, 20.01527977], [86.31861115, 20.01556015], [86.31777954, 20.01638794], [86.31777954, 20.01694679], [86.31749725, 20.01721954], [86.31749725, 20.01749992], [86.3172226, 20.01777649], [86.3172226, 20.01833344], [86.31694794, 20.01860809], [86.31694794, 20.01917076], [86.31672668, 20.01954079], [86.31661987, 20.0199604], [86.31643677, 20.02037048], [86.31638336, 20.02078056], [86.31639099, 20.02111053], [86.3161087, 20.02139091], [86.31582642, 20.02166939], [86.3152771, 20.02111053], [86.31472015, 20.02111053], [86.31414795, 20.02055931], [86.31361389, 20.0205555], [86.3133316, 20.02083397], [86.31305695, 20.02082825], [86.31276703, 20.02111053], [86.3125, 20.02111053], [86.31223297, 20.02139091], [86.31194305, 20.02139091], [86.31111145, 20.02222252], [86.31027985, 20.02139091], [86.30833435, 20.0233326], [86.30750275, 20.0233326], [86.30722046, 20.02361107], [86.3069458, 20.02361107], [86.30665588, 20.02388954], [86.30638885, 20.02388954], [86.30610657, 20.02416992], [86.30555725, 20.02416611], [86.30527496, 20.02444458], [86.30473328, 20.02444267], [86.3041687, 20.02499962], [86.30361176, 20.02499962], [86.3033371, 20.02528], [86.30223083, 20.02528], [86.30110931, 20.02639008], [86.30110931, 20.02667046], [86.30194092, 20.02750015], [86.30223083, 20.02750015], [86.30249786, 20.02778053], [86.3033371, 20.02777863], [86.30377197, 20.02792168], [86.30419922, 20.02806282], [86.30666351, 20.02777863], [86.3069458, 20.02778053], [86.30722046, 20.02750015], [86.3077774, 20.02750015], [86.30805206, 20.02778053], [86.30805206, 20.02806091], [86.30832672, 20.02833939], [86.30860901, 20.02833939], [86.3088913, 20.02861023], [86.30944824, 20.02861023], [86.31027985, 20.02944374], [86.30999756, 20.02972031], [86.30999756, 20.03000069], [86.31027985, 20.03028107], [86.31027985, 20.03055763], [86.3105545, 20.0308342], [86.31138611, 20.0308342], [86.3116684, 20.03055763], [86.31194305, 20.03055954], [86.31276703, 20.02972031], [86.31472015, 20.03166962], [86.31500244, 20.03166962], [86.31555176, 20.03111076], [86.31582642, 20.03111076], [86.3161087, 20.03083038], [86.31555176, 20.03027534], [86.31555176, 20.03000069], [86.31582642, 20.02972031], [86.31583405, 20.02861023], [86.3161087, 20.02833939], [86.3161087, 20.02806091], [86.31667328, 20.02750015], [86.31666565, 20.02722168], [86.31694794, 20.02694321], [86.31694794, 20.0261097], [86.3172226, 20.02583313], [86.3172226, 20.02555466], [86.31777954, 20.02499962], [86.31777954, 20.02472115], [86.31833649, 20.02416611], [86.31833649, 20.02388954], [86.31861115, 20.02361107], [86.3187561, 20.02339172], [86.31902313, 20.02324104], [86.31926727, 20.02301025], [86.31973267, 20.02277946], [86.31973267, 20.0225029], [86.31999969, 20.02220917], [86.32027435, 20.02222252], [86.32055664, 20.02194405], [86.3208313, 20.02194405], [86.32138824, 20.02139091], [86.3216629, 20.02139091], [86.32195282, 20.02111053], [86.32221985, 20.02111053], [86.32305908, 20.02028084], [86.32334137, 20.02028084], [86.32389069, 20.01971817], [86.32389069, 20.01888657], [86.32444763, 20.01832962], [86.32444763, 20.01805496], [86.32472229, 20.0177803], [86.32472229, 20.01721954], [86.32499695, 20.01694679], [86.32499695, 20.01666641], [86.32527924, 20.01639938], [86.32499695, 20.01610947], [86.32499695, 20.01555443], [86.32478333, 20.01503944], [86.32443237, 20.0147171], [86.32401276, 20.01441956], [86.32363129, 20.01400185], [86.32332611, 20.01348686], [86.32305908, 20.01278114], [86.32277679, 20.01250076], [86.32277679, 20.01194191], [86.32221985, 20.01138878], [86.32221985, 20.01111031], [86.32213593, 20.01102448]]], [[[86.3104248, 20.0162468], [86.3105545, 20.01611137], [86.31138611, 20.01611137], [86.31194305, 20.01555443], [86.3125, 20.01555443], [86.31305695, 20.01611137], [86.3133316, 20.01611137], [86.31361389, 20.0158329], [86.31416321, 20.0158329], [86.31472015, 20.01527786], [86.31472015, 20.01499939], [86.31500244, 20.01472092], [86.31500244, 20.01333427], [86.31472015, 20.01305962], [86.31472015, 20.01222038], [86.3144455, 20.01194382], [86.3144455, 20.01138878], [86.31472015, 20.01111031], [86.31472015, 20.01083183], [86.3152771, 20.0102787], [86.3152771, 20.01000023], [86.31555176, 20.00972176], [86.31555176, 20.00916672], [86.31582642, 20.00889015], [86.31582642, 20.00861168], [86.3152771, 20.00805473], [86.3133316, 20.00805473], [86.31305695, 20.00833321], [86.31305695, 20.00861168], [86.31276703, 20.00889015], [86.3133316, 20.00945282], [86.3133316, 20.01000023], [86.31194305, 20.01139069], [86.31140137, 20.01139069], [86.31111145, 20.01111031], [86.31083679, 20.01111031], [86.31054688, 20.01139069], [86.31027985, 20.01139069], [86.30999756, 20.01166725], [86.31027985, 20.01194382], [86.31027985, 20.01222038], [86.31054688, 20.01250076], [86.31054688, 20.01278114], [86.31111145, 20.01334], [86.31111145, 20.01389122], [86.31083679, 20.01416588], [86.31083679, 20.01444054], [86.31027985, 20.01499939], [86.31027985, 20.01527977], [86.30999756, 20.01555443], [86.31003571, 20.01615143], [86.31027985, 20.01639938], [86.3104248, 20.0162468]]], [[[81.75829315, 17.89336014], [81.72631836, 17.87409973], [81.70317078, 17.86112976], [81.69927216, 17.8697319], [81.69787598, 17.87553978], [81.68828583, 17.88479996], [81.6832428, 17.87948036], [81.67774963, 17.87758064], [81.66805267, 17.87842941], [81.66306305, 17.87693024], [81.6569519, 17.8728199], [81.65270233, 17.86819077], [81.64906311, 17.86246872], [81.64601898, 17.85626984], [81.64614105, 17.84687042], [81.64279175, 17.83928108], [81.6365509, 17.83628082], [81.63143921, 17.83044052], [81.62397766, 17.82442284], [81.61569977, 17.82201004], [81.61115265, 17.81536293], [81.59973907, 17.81544113], [81.59395599, 17.81911087], [81.57486725, 17.82734108], [81.56874084, 17.82788086], [81.56459045, 17.82569122], [81.55393982, 17.8163681], [81.52572632, 17.81087112], [81.51130676, 17.80656052], [81.49632263, 17.80647087], [81.48583984, 17.8026104], [81.48117828, 17.80286026], [81.47870636, 17.80470848], [81.47457123, 17.80999947], [81.47271729, 17.81789017], [81.47012329, 17.82318115], [81.46684265, 17.82492065], [81.45942688, 17.82471085], [81.43756866, 17.81529045], [81.43387604, 17.81575966], [81.42592621, 17.82127953], [81.41941833, 17.8205986], [81.41433716, 17.81643105], [81.41445923, 17.81011009], [81.40925598, 17.80483818], [81.40276337, 17.80532074], [81.39431, 17.80812073], [81.38497162, 17.80659294], [81.38310242, 17.81414032], [81.38304901, 17.81695175], [81.38300323, 17.82057953], [81.38378906, 17.82348824], [81.38442993, 17.82579041], [81.39334106, 17.83582115], [81.39736938, 17.84364128], [81.39805603, 17.84678078], [81.38987732, 17.85943031], [81.38954926, 17.8621006], [81.39050293, 17.87429047], [81.39382935, 17.88513947], [81.39585114, 17.88755989], [81.39901733, 17.88849068], [81.40376282, 17.88859177], [81.41166687, 17.88539124], [81.42312622, 17.87742043], [81.4302063, 17.87467957], [81.43450928, 17.87490082], [81.43595886, 17.87544823], [81.43725586, 17.87593842], [81.44026184, 17.87914085], [81.44274902, 17.88516045], [81.4437027, 17.89323044], [81.44827271, 17.90302086], [81.44818115, 17.9050808], [81.44806671, 17.90714073], [81.44621277, 17.91028023], [81.44592285, 17.91717911], [81.44445801, 17.92210007], [81.44510651, 17.92546844], [81.44523621, 17.92617035], [81.45479584, 17.94655991], [81.46695709, 17.95490074], [81.47325897, 17.96532059], [81.47567749, 17.96708107], [81.47644043, 17.96763039], [81.47731018, 17.97002029], [81.47688293, 17.97265053], [81.47666931, 17.97389984], [81.47307587, 17.98328972], [81.47451019, 17.98870277], [81.47767639, 17.9935112], [81.47894287, 18.00370026], [81.47750092, 18.01999283], [81.47389221, 18.02851105], [81.47751617, 18.03872108], [81.48149872, 18.04992294], [81.49465942, 18.05800056], [81.49488068, 18.06266022], [81.49516296, 18.06868935], [81.49600983, 18.07069969], [81.49684906, 18.07271194], [81.50865936, 18.09241104], [81.51072693, 18.10387993], [81.51187897, 18.1292305], [81.51580048, 18.13993073], [81.52173615, 18.14830971], [81.5226059, 18.15727043], [81.51487732, 18.17217064], [81.50892639, 18.17407036], [81.50524902, 18.17778969], [81.504776, 18.18381119], [81.50878906, 18.1925106], [81.51113892, 18.20194054], [81.52287292, 18.22737122], [81.52577209, 18.23652077], [81.52368164, 18.24865913], [81.52796173, 18.25908089], [81.53945923, 18.26210976], [81.54807281, 18.26213074], [81.56759644, 18.27321053], [81.57401276, 18.28116989], [81.58178711, 18.28816032], [81.58624268, 18.29215813], [81.59050751, 18.29333115], [81.59203339, 18.29747963], [81.59340668, 18.30128098], [81.59687042, 18.30211067], [81.60611725, 18.2994194], [81.61588287, 18.30084038], [81.6213913, 18.30372238], [81.62761688, 18.30487061], [81.63214111, 18.3080101], [81.64675903, 18.31150055], [81.65866852, 18.3110981], [81.6603775, 18.31575966], [81.65245819, 18.32478905], [81.64937592, 18.33057976], [81.64916992, 18.33100128], [81.65280914, 18.33667946], [81.65809631, 18.33929062], [81.68078613, 18.34103012], [81.69924164, 18.34357071], [81.71750641, 18.34320068], [81.73707581, 18.34422112], [81.74491119, 18.34535027], [81.74607849, 18.35174179], [81.74675751, 18.35550117], [81.75554657, 18.38624954], [81.76036835, 18.39982986], [81.76210022, 18.4113102], [81.76738739, 18.41477013], [81.79756927, 18.43976021], [81.82892609, 18.46895027], [81.84430695, 18.48154068], [81.84958649, 18.48904991], [81.84896088, 18.50060081], [81.85302734, 18.50732994], [81.85794067, 18.51305962], [81.86296082, 18.51727295], [81.86805725, 18.51748276], [81.8707962, 18.51758957], [81.87361908, 18.51993942], [81.87538147, 18.5214119], [81.87867737, 18.52627945], [81.88259888, 18.52918053], [81.89607239, 18.52843094], [81.8968277, 18.52839279], [81.90029144, 18.53251839], [81.89865112, 18.53615952], [81.89794159, 18.53773117], [81.89763641, 18.54271126], [81.89975739, 18.54904175], [81.90080261, 18.55717087], [81.90859985, 18.56422806], [81.91316986, 18.56118965], [81.91639709, 18.559021], [81.92019653, 18.55730057], [81.92545319, 18.55768013], [81.92984772, 18.55800056], [81.93624115, 18.55770111], [81.94352722, 18.55541992], [81.94625854, 18.55841064], [81.94690704, 18.5591507], [81.94534302, 18.56245041], [81.943573, 18.56615829], [81.94576263, 18.57491112], [81.95452881, 18.58670998], [81.94888306, 18.58954048], [81.93847656, 18.59179115], [81.9330368, 18.59465027], [81.92971802, 18.59638977], [81.92623138, 18.60322952], [81.91303253, 18.6129303], [81.89993286, 18.61960983], [81.8883667, 18.62099075], [81.88729095, 18.62438965], [81.88780212, 18.63162994], [81.88820648, 18.6373806], [81.88931274, 18.64112854], [81.89000702, 18.64347076], [81.88537598, 18.65032959], [81.89317322, 18.65388107], [81.89483643, 18.65196037], [81.9048996, 18.64639282], [81.90914154, 18.6409893], [81.91552734, 18.63582039], [81.93557739, 18.63289833], [81.9474411, 18.62882042], [81.94832611, 18.63278961], [81.94608307, 18.64048958], [81.94592285, 18.64637947], [81.9473877, 18.65571022], [81.95163727, 18.66098022], [81.96063232, 18.66772079], [81.95507813, 18.68022919], [81.95716095, 18.68341064], [81.96386719, 18.68779945], [81.96768188, 18.69061279], [81.97603607, 18.69514847], [81.99186707, 18.69769096], [81.99772644, 18.7004509], [82.00998688, 18.7105999], [82.01561737, 18.71353149], [82.03373718, 18.71879959], [82.03949738, 18.71704102], [82.04943085, 18.7175808], [82.05175781, 18.71183968], [82.05799103, 18.71251106], [82.05912781, 18.71778107], [82.06128693, 18.71800995], [82.06739044, 18.71710968], [82.07398224, 18.7130909], [82.07858276, 18.71208191], [82.08048248, 18.72274017], [82.0848999, 18.73269081], [82.08674622, 18.74693108], [82.08141327, 18.75587082], [82.08470917, 18.75839996], [82.09129333, 18.75617981], [82.10572815, 18.75844955], [82.11392212, 18.76066017], [82.12906647, 18.75765038], [82.1281662, 18.76432037], [82.13066101, 18.77009964], [82.13897705, 18.76954079], [82.14547729, 18.77327919], [82.15001678, 18.77869987], [82.15170288, 18.78380013], [82.15921783, 18.78811073], [82.16114807, 18.79096031], [82.15891266, 18.79507065], [82.15429688, 18.7963028], [82.15611267, 18.79994011], [82.16101074, 18.80356979], [82.16184235, 18.80496025], [82.15867615, 18.80920029], [82.15830994, 18.81147003], [82.16493988, 18.83020973], [82.16175079, 18.83786011], [82.16242218, 18.8451004], [82.15802765, 18.85197067], [82.16126251, 18.8577404], [82.16279602, 18.86551094], [82.15820313, 18.86945915], [82.16310883, 18.87193108], [82.17041016, 18.87757111], [82.17076874, 18.89159012], [82.17272949, 18.89528847], [82.17714691, 18.89690018], [82.18538666, 18.89698029], [82.1987381, 18.90554047], [82.21378326, 18.91213989], [82.22486115, 18.90924835], [82.22767639, 18.9066906], [82.23121643, 18.90522003], [82.23429108, 18.90526962], [82.23956299, 18.91045952], [82.22666168, 18.99398041], [82.22506714, 19.01459122], [82.22248077, 19.02111053], [82.1940918, 19.06022072], [82.19683075, 19.06786919], [82.20855713, 19.07852173], [82.21122742, 19.08575821], [82.21211243, 19.09054947], [82.21058655, 19.09225082], [82.19986725, 19.09217834], [82.1985321, 19.09416962], [82.19948578, 19.09982109], [82.19689941, 19.10115051], [82.20149994, 19.11576271], [82.19975281, 19.11746025], [82.19101715, 19.11631012], [82.17623901, 19.12506104], [82.16982269, 19.11285973], [82.16480255, 19.11469078], [82.15978241, 19.1264801], [82.16117096, 19.12975121], [82.16655731, 19.13214111], [82.1681366, 19.13384056], [82.16471863, 19.13947105], [82.1658783, 19.14314079], [82.16990662, 19.14364052], [82.17198944, 19.14249992], [82.17478943, 19.14523125], [82.17238617, 19.14764977], [82.16500092, 19.15044975], [82.16413879, 19.15463829], [82.16760254, 19.15687943], [82.1714859, 19.15390968], [82.17471313, 19.15275002], [82.17684174, 19.15497971], [82.17878723, 19.15885925], [82.17823792, 19.16147995], [82.17298126, 19.16476059], [82.17112732, 19.16827011], [82.17516327, 19.16963959], [82.17459869, 19.17358017], [82.16940308, 19.17670059], [82.17339325, 19.18431091], [82.16478729, 19.18732071], [82.15804291, 19.19317818], [82.15570831, 19.19652939], [82.16117859, 19.20838928], [82.15376282, 19.21577835], [82.15164948, 19.22356987], [82.15196228, 19.23890114], [82.15099335, 19.25842285], [82.15172577, 19.26546288], [82.15487671, 19.27477837], [82.15836334, 19.28148079], [82.16853333, 19.29066086], [82.1700058, 19.29572105], [82.17008972, 19.3024807], [82.17368317, 19.31630135], [82.1831665, 19.31970024], [82.18025208, 19.33220291], [82.17749023, 19.33237076], [82.17320251, 19.33407974], [82.16895294, 19.33723068], [82.16314697, 19.33780289], [82.15722656, 19.34284019], [82.14955139, 19.34437943], [82.14234924, 19.34817123], [82.14225769, 19.35511017], [82.14083099, 19.3619194], [82.14118195, 19.36578178], [82.14456177, 19.37011909], [82.15080261, 19.37034035], [82.16636658, 19.36593056], [82.17398071, 19.37693977], [82.17777252, 19.40557289], [82.18348694, 19.41246033], [82.18305969, 19.41761017], [82.17925262, 19.41913986], [82.17045593, 19.42949104], [82.1672287, 19.42984962], [82.16069031, 19.42951965], [82.13410187, 19.42482758], [82.11930847, 19.4239006], [82.10679626, 19.44307137], [82.10716248, 19.45261192], [82.09689331, 19.46108055], [82.09986877, 19.46606064], [82.10182953, 19.47365952], [82.09902954, 19.48957062], [82.09101868, 19.49405861], [82.09207916, 19.50984001], [82.08822632, 19.51044273], [82.07084656, 19.51592064], [82.0671463, 19.51102066], [82.05979156, 19.50364113], [82.02239227, 19.50180244], [82.0302124, 19.51420975], [82.03246307, 19.52129173], [82.04102325, 19.52570152], [82.04257202, 19.53156853], [82.04612732, 19.5386219], [82.0430069, 19.5444603], [82.04042053, 19.55220985], [82.0426178, 19.55800056], [82.04413605, 19.56479836], [82.04323578, 19.56767082], [82.0422287, 19.57092094], [82.03779602, 19.5771904], [82.03489685, 19.58327293], [82.03395844, 19.59069061], [82.03727722, 19.59791946], [82.0450592, 19.60165024], [82.04471588, 19.61079025], [82.04847717, 19.61581039], [82.05134583, 19.62444115], [82.05082703, 19.63162041], [82.04728699, 19.63828087], [82.04638672, 19.64402962], [82.04830933, 19.64937019], [82.04603577, 19.65359116], [82.04766846, 19.66268921], [82.04677582, 19.66937065], [82.03848267, 19.69277954], [82.03756714, 19.70391083], [82.04160309, 19.70828819], [82.0437088, 19.71391106], [82.04255676, 19.72313118], [82.04425812, 19.72912979], [82.04400635, 19.73768997], [82.04659271, 19.74302101], [82.05719757, 19.75341034], [82.05541992, 19.7610302], [82.05898285, 19.77507019], [82.05938721, 19.77903938], [82.05982971, 19.78309822], [82.05219269, 19.79134178], [82.04827881, 19.78841019], [82.04444122, 19.78924942], [82.04107666, 19.79219055], [82.03494263, 19.79265976], [82.02906036, 19.79219055], [82.02419281, 19.79297829], [82.00818634, 19.79656982], [82.00305176, 19.79851913], [82.00289154, 19.7985096], [81.99932098, 19.79830933], [81.99237061, 19.79442978], [81.98741913, 19.79174042], [81.98014832, 19.79578018], [81.97020721, 19.81274033], [81.9614563, 19.82443237], [81.95741272, 19.83600998], [81.96037292, 19.85473824], [81.93942261, 19.86484146], [81.92447662, 19.86872292], [81.89805603, 19.87851906], [81.86924744, 19.89281082], [81.85840607, 19.89954948], [81.84963226, 19.90805054], [81.84580994, 19.91486168], [81.84567261, 19.92295265], [81.84883118, 19.938591], [81.84651184, 19.94144058], [81.83895111, 19.94549942], [81.83730316, 19.95008087], [81.84026337, 19.95513916], [81.84689331, 19.9703598], [81.85031891, 19.98260117], [81.85101318, 19.98975182], [81.85161591, 19.99605942], [81.85205078, 19.99715996], [81.85546112, 20.00352097], [81.85762024, 20.00908089], [81.85891724, 20.01637077], [81.86016846, 20.02336121], [81.86458588, 20.02864075], [81.86548615, 20.03388023], [81.86611176, 20.03518105], [81.866539, 20.03603935], [81.87375641, 20.04618073], [81.8762207, 20.04438972], [81.880867, 20.04241943], [81.88504028, 20.04171944], [81.8894577, 20.04327011], [81.8941803, 20.04824829], [81.90142822, 20.05912018], [81.91027069, 20.06705093], [81.91542816, 20.07382965], [81.92188263, 20.08694839], [81.92563629, 20.09011841], [81.93392944, 20.09930992], [81.93696594, 20.10115051], [81.94135284, 20.10225105], [81.94420624, 20.10160255], [81.95477295, 20.09148026], [81.96264648, 20.08556938], [81.97357178, 20.07561111], [81.97849274, 20.06917953], [81.98329926, 20.05702972], [81.98660278, 20.05207253], [81.9927063, 20.04782104], [81.99555206, 20.04753113], [82.00102997, 20.04926109], [82.00689697, 20.04733086], [82.00995636, 20.0447998], [82.01270294, 20.04103088], [82.014328, 20.0364399], [82.01449585, 20.03025055], [82.01551819, 20.02683067], [82.01478577, 20.01951027], [82.02440643, 20.01004028], [82.03070068, 20.01503944], [82.03156281, 20.01666069], [82.03102875, 20.02288055], [82.03875732, 20.02891922], [82.04897308, 20.03524017], [82.05789948, 20.04986954], [82.06980133, 20.04804039], [82.07630157, 20.04404068], [82.08304596, 20.03273964], [82.08943939, 20.03454971], [82.09319305, 20.03267288], [82.0952301, 20.02680016], [82.09773254, 20.02337074], [82.10273743, 20.02082825], [82.10547638, 20.01781273], [82.1160965, 20.01040077], [82.12142181, 20.00979042], [82.12841034, 20.01258087], [82.13169861, 20.01268959], [82.14834595, 20.00300026], [82.15557861, 20.0023098], [82.16583252, 19.99814987], [82.16607666, 19.99584007], [82.17578125, 19.98553085], [82.1784668, 19.97808266], [82.18418121, 19.98116112], [82.19381714, 19.98130989], [82.2042923, 19.98033905], [82.21058655, 19.99081039], [82.21425629, 19.99334145], [82.2194519, 19.9934597], [82.22438049, 19.99587059], [82.23062897, 19.99808121], [82.23335266, 19.99587059], [82.25271606, 19.97647858], [82.25863647, 19.97174072], [82.26169586, 19.97155952], [82.26864624, 19.95792961], [82.26946259, 19.94524956], [82.28333282, 19.91806984], [82.29532623, 19.89895821], [82.29823303, 19.883461], [82.31794739, 19.85915947], [82.32132721, 19.85191917], [82.32511902, 19.84049034], [82.32675171, 19.83833122], [82.33944702, 19.82996178], [82.35624695, 19.84662056], [82.35736084, 19.84950066], [82.35607147, 19.85513115], [82.35845184, 19.85688019], [82.36804962, 19.85448074], [82.37725067, 19.86296844], [82.37798309, 19.86869049], [82.38617706, 19.87684059], [82.38881683, 19.88175964], [82.39700317, 19.88454056], [82.40040588, 19.8888092], [82.41043854, 19.89340019], [82.41388702, 19.89652061], [82.42090607, 19.89833069], [82.42492676, 19.89760971], [82.43225861, 19.89948082], [82.43949127, 19.90291977], [82.44239044, 19.90298271], [82.45835114, 19.89464951], [82.46556091, 19.89657974], [82.46808624, 19.89948082], [82.47569275, 19.90052986], [82.48692322, 19.89653015], [82.49423981, 19.89735985], [82.497612, 19.8950882], [82.49848175, 19.88516998], [82.5022583, 19.88244057], [82.51241302, 19.88412094], [82.51795959, 19.87631035], [82.52305603, 19.87278938], [82.5298996, 19.88212967], [82.53636169, 19.87689018], [82.54428864, 19.86903], [82.54721832, 19.87330055], [82.5508728, 19.8745594], [82.55488586, 19.86950111], [82.56674957, 19.87172127], [82.57758331, 19.86343956], [82.59076691, 19.86621857], [82.59349823, 19.8645401], [82.59738159, 19.86046982], [82.59146881, 19.85243034], [82.58982086, 19.8481884], [82.58573151, 19.8463707], [82.58149719, 19.84049034], [82.58349609, 19.83832169], [82.57894135, 19.83662987], [82.57419586, 19.83197975], [82.57182312, 19.82780838], [82.57126617, 19.82238007], [82.57382965, 19.82370949], [82.57183838, 19.80760956], [82.57303619, 19.80555916], [82.57157898, 19.80200958], [82.57927704, 19.7972126], [82.57779694, 19.79232979], [82.57781219, 19.78780937], [82.5792923, 19.78466034], [82.57791138, 19.77959061], [82.57847595, 19.77581978], [82.5812912, 19.77269173], [82.58506012, 19.7710495], [82.59513855, 19.77306938], [82.59828186, 19.7751503], [82.59900665, 19.78127289], [82.60327911, 19.78355026], [82.60813141, 19.78512955], [82.61886597, 19.78610039], [82.62296295, 19.78931046], [82.62734222, 19.79615021], [82.62890625, 19.80376053], [82.6362915, 19.80799294], [82.64179993, 19.8137207], [82.64573669, 19.82537079], [82.65410614, 19.8255291], [82.66001892, 19.82372093], [82.66913605, 19.82520294], [82.68331909, 19.82372093], [82.6905365, 19.82575989], [82.69844055, 19.82686043], [82.70271301, 19.83103943], [82.70588684, 19.8380909], [82.70471191, 19.84460068], [82.71100616, 19.84856033], [82.71385956, 19.86209106], [82.71750641, 19.87080956], [82.70935059, 19.870121], [82.70636749, 19.87851906], [82.70269012, 19.88584137], [82.70053101, 19.89328957], [82.70147705, 19.90073013], [82.70040894, 19.90661049], [82.70587921, 19.91123009], [82.70426178, 19.91833115], [82.70632172, 19.92685127], [82.70649719, 19.93353081], [82.71061707, 19.93947029], [82.71156311, 19.9444809], [82.70944977, 19.94667053], [82.71092987, 19.98326111], [82.70748901, 19.99021912], [82.70063019, 19.99287033], [82.69802094, 19.99273109], [82.69230652, 19.9924202], [82.68644714, 19.99463081], [82.68102264, 19.99545097], [82.65048218, 19.99940109], [82.64189911, 19.99790955], [82.63625336, 19.99829102], [82.63175964, 20.00008965], [82.62358093, 19.99764061], [82.62088776, 19.99555969], [82.61875916, 19.99156952], [82.61438751, 19.9869709], [82.59836578, 19.98563957], [82.58235931, 19.98994064], [82.57872009, 19.9956398], [82.57594299, 19.99895287], [82.54361725, 20.01213074], [82.53198242, 20.01222992], [82.52424622, 20.01044083], [82.5021286, 20.01353073], [82.49006653, 20.01857185], [82.48159027, 20.02456093], [82.47590637, 20.03005028], [82.47077179, 20.03202057], [82.46409607, 20.03154945], [82.45832825, 20.0338707], [82.45149994, 20.03526115], [82.44142914, 20.03535271], [82.43192291, 20.03897095], [82.4247818, 20.04354095], [82.41713715, 20.04534912], [82.40618896, 20.04631042], [82.39576721, 20.04899979], [82.39086151, 20.05958939], [82.39034271, 20.06423187], [82.39260101, 20.07331085], [82.39466858, 20.08916092], [82.39264679, 20.10824966], [82.39073944, 20.11905098], [82.38775635, 20.12693977], [82.38658142, 20.13338089], [82.38228607, 20.13817024], [82.37892914, 20.14463043], [82.38719177, 20.14885139], [82.38330078, 20.16045952], [82.39048767, 20.16731262], [82.40574646, 20.17898941], [82.40763092, 20.19409943], [82.41359711, 20.20227051], [82.41308594, 20.20795059], [82.41365051, 20.21327972], [82.41277313, 20.21744919], [82.40818787, 20.22063065], [82.40727997, 20.22764015], [82.40432739, 20.23960114], [82.40837097, 20.24166107], [82.41407776, 20.24155045], [82.40537262, 20.25587273], [82.4050827, 20.26353073], [82.412323, 20.26990128], [82.42082214, 20.27260017], [82.42804718, 20.27861023], [82.42922974, 20.2829628], [82.4283371, 20.28986168], [82.42395782, 20.29650116], [82.42243958, 20.30965996], [82.41629791, 20.31695938], [82.40717316, 20.32207108], [82.40045929, 20.32467079], [82.40029907, 20.32925034], [82.39878845, 20.33165169], [82.39377594, 20.3355217], [82.39441681, 20.34013748], [82.39795685, 20.34677124], [82.39794159, 20.35585976], [82.40251923, 20.36133003], [82.40307617, 20.36526108], [82.41040802, 20.37720108], [82.41060638, 20.38247108], [82.41274261, 20.38824272], [82.40989685, 20.40267944], [82.41768646, 20.4056282], [82.42428589, 20.41015053], [82.42295837, 20.41833115], [82.4291687, 20.42575264], [82.427742, 20.43206978], [82.42565155, 20.43631935], [82.41771698, 20.43830109], [82.41940308, 20.44557953], [82.41938782, 20.45728111], [82.41609955, 20.4661808], [82.41007996, 20.47330093], [82.40640259, 20.46614075], [82.39731598, 20.45191956], [82.38809204, 20.45251083], [82.39006805, 20.45939064], [82.38960266, 20.46536064], [82.38513947, 20.4704895], [82.38613129, 20.47552109], [82.38375092, 20.48266029], [82.38123322, 20.50180054], [82.38131714, 20.50777054], [82.38049316, 20.50984955], [82.36994934, 20.51394081], [82.35851288, 20.51623917], [82.34879303, 20.52293015], [82.34224701, 20.53769112], [82.33609009, 20.54323959], [82.32775879, 20.54927063], [82.32401276, 20.55388069], [82.32446289, 20.55664825], [82.32637787, 20.55657959], [82.3274765, 20.55789757], [82.32782745, 20.56196022], [82.33235168, 20.56227112], [82.33715057, 20.56517982], [82.34063721, 20.56973267], [82.3425293, 20.57522011], [82.33766937, 20.58493042], [82.33837128, 20.59082985], [82.33867645, 20.5943203], [82.3454895, 20.59790039], [82.34799957, 20.6016407], [82.35582733, 20.60349083], [82.35785675, 20.60921097], [82.35665894, 20.61136055], [82.35817719, 20.61516953], [82.36633301, 20.6202507], [82.36823273, 20.62405968], [82.36754608, 20.62957001], [82.36380005, 20.6395607], [82.36225128, 20.65047073], [82.36580658, 20.66114998], [82.36522675, 20.66376114], [82.36068726, 20.67191124], [82.35428619, 20.6750412], [82.35131836, 20.67807007], [82.3455658, 20.69491005], [82.34329987, 20.69885254], [82.34426117, 20.7095108], [82.34699249, 20.71423912], [82.33940887, 20.72583008], [82.34586334, 20.72871971], [82.3404007, 20.74671936], [82.33512878, 20.75851822], [82.33692932, 20.77930069], [82.33879089, 20.79017067], [82.33567047, 20.79737282], [82.33310699, 20.8196907], [82.3355484, 20.82783127], [82.33403778, 20.84058952], [82.33687592, 20.8492527], [82.34121704, 20.86806107], [82.34661865, 20.88384819], [82.35917664, 20.8827095], [82.35617828, 20.87635994], [82.35591888, 20.8699398], [82.35903931, 20.86654091], [82.36801147, 20.8640995], [82.37667084, 20.86692047], [82.38279724, 20.8699398], [82.40141296, 20.86243057], [82.40246582, 20.85795975], [82.40225983, 20.85328102], [82.40727997, 20.84802055], [82.40737152, 20.84349823], [82.40563202, 20.8372097], [82.4134903, 20.82956123], [82.41552734, 20.82646942], [82.42294312, 20.82600021], [82.43650055, 20.82953072], [82.43939209, 20.8271904], [82.44108582, 20.82376289], [82.44465637, 20.82406998], [82.44837189, 20.82217979], [82.45350647, 20.8212204], [82.45905304, 20.82384109], [82.46246338, 20.8275795], [82.46231079, 20.83035088], [82.45983124, 20.83564949], [82.46338654, 20.83967018], [82.46826172, 20.84263039], [82.47762299, 20.84671974], [82.48192596, 20.85531044], [82.48136902, 20.86145973], [82.48452759, 20.87289047], [82.48467255, 20.87955093], [82.48313904, 20.8996582], [82.485672, 20.90351105], [82.49363708, 20.90934944], [82.50309753, 20.91389084], [82.51344299, 20.91721916], [82.51924133, 20.92469025], [82.52625275, 20.92770958], [82.53585052, 20.92952156], [82.54573822, 20.93494034], [82.55294037, 20.94148064], [82.56651306, 20.96700096], [82.57813263, 20.97894096], [82.58207703, 20.98677826], [82.59514618, 20.99712944], [82.60444641, 21.00587273], [82.60772705, 21.01216125], [82.60861969, 21.01819992], [82.62230682, 21.0365696], [82.62003326, 21.04439926], [82.60912323, 21.06392097], [82.60938263, 21.07119751], [82.61524963, 21.07517052], [82.62194061, 21.07520103], [82.62587738, 21.07682037], [82.63183594, 21.08695984], [82.63536072, 21.09198952], [82.64299774, 21.09776115], [82.64502716, 21.10187912], [82.63833618, 21.10647011], [82.63710022, 21.11161995], [82.63955688, 21.11700058], [82.64531708, 21.12066841], [82.64775848, 21.12496185], [82.6446228, 21.12881088], [82.6383667, 21.13161278], [82.63408661, 21.13635063], [82.63279724, 21.14266014], [82.63594055, 21.1494503], [82.64582825, 21.15171051], [82.66204834, 21.15075111], [82.68453217, 21.15806007], [82.6919632, 21.15685081], [82.69403839, 21.15280151], [82.70053864, 21.15326118], [82.70553589, 21.15489006], [82.7114563, 21.15576935], [82.72115326, 21.15894127], [82.72724152, 21.15919113], [82.73535156, 21.15787125], [82.75229645, 21.15974045], [82.75752258, 21.1585598], [82.78208923, 21.14101982], [82.78884888, 21.13927269], [82.79176331, 21.14511108], [82.79559326, 21.1505909], [82.80381012, 21.15307045], [82.80684662, 21.15664101], [82.81247711, 21.1585598], [82.83999634, 21.1633606], [82.84712982, 21.16268158], [82.84677124, 21.1581707], [82.85402679, 21.15700912], [82.85949707, 21.15730286], [82.86367035, 21.15538025], [82.86882782, 21.15974998], [82.87285614, 21.1510582], [82.87922668, 21.14908981], [82.88741302, 21.15377235], [82.8951416, 21.15982056], [82.90231323, 21.16296959], [82.90795898, 21.1602726], [82.91442108, 21.16064072], [82.92192841, 21.15821075], [82.9280014, 21.16103172], [82.93739319, 21.16114807], [82.94232941, 21.16304016], [82.9489975, 21.16977119], [82.95606995, 21.17548943], [82.95964813, 21.17385101], [82.96363831, 21.16167068], [82.96514893, 21.15575981], [82.97161102, 21.15631104], [82.97992706, 21.15746117], [82.98342133, 21.14826965], [82.99297333, 21.15427971], [82.99912262, 21.14813995], [83.00554657, 21.14583015], [83.00772858, 21.14653015], [83.01048279, 21.14537048], [83.01589203, 21.13972092], [83.01862335, 21.13817978], [83.02954102, 21.13132286], [83.02908325, 21.12602997], [83.03275299, 21.12436295], [83.03643036, 21.1212101], [83.04058075, 21.11893082], [83.04682922, 21.12021065], [83.05139923, 21.11717033], [83.05976105, 21.11591148], [83.06436157, 21.11110115], [83.07144165, 21.10807037], [83.08156586, 21.1067009], [83.08870697, 21.10745049], [83.09208679, 21.10597038], [83.0951767, 21.1043129], [83.10827637, 21.10770035], [83.11984253, 21.10106087], [83.13400269, 21.10523033], [83.13771057, 21.1098175], [83.14875031, 21.11987114], [83.15339661, 21.12577057], [83.16139221, 21.13145065], [83.16986847, 21.13151932], [83.17662048, 21.13074112], [83.18297577, 21.13204956], [83.19010162, 21.13552856], [83.19274902, 21.13944054], [83.19373322, 21.1576519], [83.1993866, 21.16197014], [83.20007324, 21.16889954], [83.19953156, 21.17404938], [83.20201874, 21.17743111], [83.20520782, 21.18404007], [83.2100296, 21.1880703], [83.21121216, 21.19118118], [83.20757294, 21.20139122], [83.21536255, 21.21549034], [83.21438599, 21.22058105], [83.21520996, 21.22369194], [83.21906281, 21.22371101], [83.21469879, 21.24041939], [83.21414185, 21.25086975], [83.21835327, 21.26012039], [83.22489929, 21.26696968], [83.23187256, 21.26534081], [83.2424469, 21.27643967], [83.24836731, 21.27730179], [83.25730133, 21.27555084], [83.26275635, 21.27260971], [83.26767731, 21.26857758], [83.2713089, 21.28050041], [83.27455902, 21.28567123], [83.27480316, 21.29057121], [83.27268219, 21.29613113], [83.25879669, 21.30212975], [83.25409698, 21.31237984], [83.25421143, 21.31958961], [83.26085663, 21.32674026], [83.25578308, 21.32932281], [83.25495911, 21.33192062], [83.26064301, 21.33717918], [83.26609039, 21.34543037], [83.27078247, 21.35923958], [83.26951599, 21.36721039], [83.27001953, 21.37503815], [83.27614594, 21.37592125], [83.2813797, 21.37514114], [83.2872467, 21.3714695], [83.30164337, 21.36783981], [83.3095932, 21.36456108], [83.31933594, 21.35814285], [83.33460236, 21.35579109], [83.37481689, 21.3399601], [83.37663269, 21.34329987], [83.3879776, 21.33893967], [83.39385986, 21.34208107], [83.40265656, 21.34843063], [83.40444946, 21.35511971], [83.4018631, 21.3583107], [83.39415741, 21.3611412], [83.39317322, 21.36519051], [83.3963089, 21.36927032], [83.39655304, 21.37227058], [83.39308929, 21.38321114], [83.39376068, 21.39944267], [83.38967133, 21.40166283], [83.38140869, 21.40957832], [83.37393951, 21.42222023], [83.37137604, 21.42835999], [83.37014008, 21.43610001], [83.36579132, 21.43984032], [83.36094666, 21.44218063], [83.35028839, 21.44398117], [83.34732819, 21.45514107], [83.34335327, 21.46488953], [83.34197998, 21.47413063], [83.34205627, 21.48533058], [83.33561707, 21.49191093], [83.33463287, 21.49555016], [83.33589935, 21.49963951], [83.3377533, 21.50263023], [83.3458786, 21.50823975], [83.34896851, 21.51596069], [83.35426331, 21.53531837], [83.36577606, 21.54968071], [83.36692047, 21.55302048], [83.36686707, 21.55931282], [83.3633194, 21.56777954], [83.36232758, 21.57252121], [83.36818695, 21.59707069], [83.37725067, 21.60467911], [83.38072205, 21.61275101], [83.38683319, 21.61536026], [83.38981628, 21.62054062], [83.39524078, 21.62419128], [83.40180969, 21.62675095], [83.40518951, 21.63181114], [83.40862274, 21.63420105], [83.41352844, 21.63631058], [83.42405701, 21.63848114], [83.42650604, 21.64353943], [83.44123077, 21.64927292], [83.44757843, 21.64459991], [83.44139099, 21.63246155], [83.44048309, 21.62669945], [83.44142151, 21.62502289], [83.44133759, 21.61809158], [83.44993591, 21.6169796], [83.45001221, 21.61339951], [83.44872284, 21.60822105], [83.45279694, 21.60732269], [83.45275879, 21.60519028], [83.46296692, 21.60551071], [83.46990204, 21.62677002], [83.4765625, 21.62729263], [83.48454285, 21.62556267], [83.48647308, 21.63317108], [83.4833374, 21.6371727], [83.483078, 21.63960075], [83.47477722, 21.64121819], [83.46621704, 21.64412117], [83.44077301, 21.65517044], [83.43535614, 21.66312027], [83.4286499, 21.66889], [83.4197464, 21.67502022], [83.42111206, 21.68654823], [83.42488098, 21.68901062], [83.42796326, 21.69232941], [83.43183136, 21.6939106], [83.4407959, 21.69338989], [83.44970703, 21.69095993], [83.45633698, 21.69432068], [83.45762634, 21.69967079], [83.46160889, 21.70627975], [83.46692657, 21.71056938], [83.47801971, 21.7279911], [83.47986603, 21.7341404], [83.48413086, 21.74155235], [83.47733307, 21.74588966], [83.47390747, 21.7496109], [83.47541809, 21.75341034], [83.47902679, 21.75869942], [83.47789001, 21.76459122], [83.47592163, 21.77379036], [83.46717834, 21.78273964], [83.47429657, 21.78614998], [83.48404694, 21.79434013], [83.48545837, 21.80322075], [83.49133301, 21.80866051], [83.49091339, 21.81454086], [83.49771881, 21.80618095], [83.50614166, 21.80039978], [83.51412201, 21.79780006], [83.52218628, 21.79411125], [83.53656769, 21.79393005], [83.5357666, 21.79896164], [83.53866577, 21.80061913], [83.53478241, 21.80681992], [83.53639984, 21.81834984], [83.52765656, 21.82299042], [83.53124237, 21.83189964], [83.54094696, 21.83465958], [83.54853821, 21.83523178], [83.55745697, 21.83440971], [83.56453705, 21.83036995], [83.5735321, 21.82966042], [83.57489777, 21.83260155], [83.57948303, 21.83712006], [83.58447266, 21.84360123], [83.5859375, 21.84762955], [83.58405304, 21.85279274], [83.57151794, 21.87187004], [83.57330322, 21.87636948], [83.57810974, 21.87978935], [83.57670593, 21.8861599], [83.57988739, 21.88925171], [83.58333588, 21.89096069], [83.58319855, 21.89406967], [83.58151245, 21.89743042], [83.58325195, 21.89856911], [83.59263611, 21.90075111], [83.59931183, 21.90600014], [83.60047913, 21.91084099], [83.58776855, 21.92612076], [83.55335999, 21.9321804], [83.55397034, 21.9362812], [83.55771637, 21.9439106], [83.54949188, 21.95038986], [83.53517151, 21.96350098], [83.53447723, 21.97624969], [83.53544617, 21.9796505], [83.54010773, 21.98533058], [83.54083252, 21.99323273], [83.543396, 21.99436951], [83.54663849, 21.99827957], [83.54496765, 21.99938965], [83.54673767, 22.00335121], [83.5485611, 22.00670242], [83.53885651, 22.01437187], [83.53399658, 22.02227974], [83.5326767, 22.02863121], [83.53244781, 22.03404808], [83.53414917, 22.04343987], [83.53836823, 22.05537987], [83.5430069, 22.05939102], [83.55095673, 22.05564117], [83.56562805, 22.0567894], [83.58351135, 22.05495071], [83.58595276, 22.0555706], [83.59056854, 22.05934143], [83.60031891, 22.0655098], [83.58917999, 22.07635117], [83.58306885, 22.08049011], [83.57369995, 22.08880043], [83.56482697, 22.09397125], [83.55892181, 22.0954895], [83.55726624, 22.0999794], [83.55916595, 22.10386086], [83.56575775, 22.11285019], [83.56730652, 22.1137085], [83.59253693, 22.13998032], [83.60233307, 22.1518383], [83.60594177, 22.15760994], [83.61183929, 22.17714119], [83.61927032, 22.19635963], [83.62628174, 22.20585823], [83.64575195, 22.22458839], [83.65457153, 22.2238903], [83.65744019, 22.22479057], [83.66461945, 22.2319603], [83.67273712, 22.2374382], [83.67904663, 22.2406311], [83.69300079, 22.24550056], [83.70043182, 22.24588013], [83.71898651, 22.2432518], [83.74565125, 22.24122047], [83.75279999, 22.24286079], [83.7568512, 22.25037956], [83.76180267, 22.25415039], [83.76583862, 22.25601959], [83.77131653, 22.25733948], [83.77471924, 22.26733971], [83.77855682, 22.27450943], [83.78862762, 22.28025055], [83.79078674, 22.28464127], [83.79364777, 22.28769112], [83.79751587, 22.28948975], [83.79798889, 22.28996277], [83.80478668, 22.28988075], [83.81598663, 22.29120255], [83.81944275, 22.29245186], [83.82080841, 22.29603958], [83.82010651, 22.30508232], [83.82065582, 22.31025124], [83.82248688, 22.31563759], [83.82520294, 22.31962967], [83.82940674, 22.32394028], [83.84303284, 22.32634926], [83.84757996, 22.33083916], [83.85330963, 22.33880043], [83.86100769, 22.34378052], [83.86414337, 22.34361839], [83.86714935, 22.34102058], [83.87194824, 22.33893013], [83.89697266, 22.33968925], [83.9053421, 22.35261154], [83.9155426, 22.35967064], [83.91929626, 22.35978127], [83.92402649, 22.35749054], [83.92958069, 22.35628128], [83.9432373, 22.35845947], [83.95231628, 22.36120987], [83.95661163, 22.3610611], [83.96698761, 22.35784912], [83.97820282, 22.36510849], [83.98536682, 22.36637115], [83.99297333, 22.36923981], [83.99739838, 22.36853981], [84.00119019, 22.36967087], [84.00421143, 22.36766052], [84.00167847, 22.37585068], [84.00166321, 22.38036919], [84.00898743, 22.39139938], [84.00994873, 22.39608955], [84.01248932, 22.39889908], [84.01444244, 22.40409279], [84.01875305, 22.40678024], [84.02216339, 22.41016006], [84.02599335, 22.41909027], [84.02398682, 22.42218018], [84.03270721, 22.42603111], [84.04000854, 22.43289948], [84.04139709, 22.43792915], [84.03951263, 22.44872284], [84.04155731, 22.46410942], [84.03872681, 22.46888161], [84.03465271, 22.46989822], [84.0238266, 22.47071075], [84.02168274, 22.47205925], [84.01548767, 22.48242188], [84.01302338, 22.48524094], [83.99707794, 22.4907608], [83.99298096, 22.49398041], [83.990448, 22.49439049], [83.98069, 22.49873161], [83.97609711, 22.50221062], [83.97384644, 22.50913811], [83.97445679, 22.51398087], [83.97657013, 22.51839066], [83.98010254, 22.52201271], [83.98584747, 22.52548027], [83.99298096, 22.52737808], [83.99429321, 22.5288105], [84.00250244, 22.52086067], [84.00963593, 22.52029037], [84.01554108, 22.52168083], [84.01914978, 22.52107048], [84.02472687, 22.51621246], [84.0330658, 22.5120697], [84.05065918, 22.51235962], [84.05758667, 22.51015091], [84.06047821, 22.50502014], [84.06668854, 22.50223923], [84.06900024, 22.49954987], [84.0670929, 22.49812126], [84.07164001, 22.49419022], [84.07920837, 22.48885155], [84.0877533, 22.48493004], [84.0998764, 22.48033905], [84.1029129, 22.48129082], [84.10347748, 22.47933006], [84.10211945, 22.47731018], [84.10611725, 22.47384834], [84.117836, 22.47142029], [84.12557983, 22.47359276], [84.12914276, 22.47348976], [84.13069153, 22.47001076], [84.13492584, 22.47094917], [84.13743591, 22.46710014], [84.13751984, 22.45718956], [84.13522339, 22.4490509], [84.13310242, 22.44531059], [84.13587952, 22.42068291], [84.14229584, 22.41539955], [84.15248871, 22.4009304], [84.17516327, 22.38894081], [84.18344116, 22.38368034], [84.19410706, 22.37181091], [84.22612762, 22.37412071], [84.24046326, 22.3744812], [84.24655914, 22.3737011], [84.25141144, 22.37041092], [84.26088715, 22.35370064], [84.26616669, 22.34782982], [84.27324677, 22.34509277], [84.28501892, 22.34211159], [84.28922272, 22.33732033], [84.31461334, 22.33892059], [84.31874847, 22.34049988], [84.32396698, 22.33892059], [84.333992, 22.34291077], [84.33838654, 22.34209824], [84.34496307, 22.34404945], [84.35328674, 22.34510994], [84.35909271, 22.34504128], [84.36171722, 22.34852982], [84.36741638, 22.34956932], [84.37200165, 22.34905052], [84.37758636, 22.34590912], [84.38786316, 22.34642029], [84.3944931, 22.34385109], [84.41911316, 22.35077095], [84.42608643, 22.3488102], [84.42584229, 22.3520298], [84.43144226, 22.36001015], [84.42719269, 22.36198044], [84.42694092, 22.36465073], [84.44207764, 22.37302017], [84.44785309, 22.37907982], [84.45565033, 22.37522125], [84.47280884, 22.38269043], [84.47759247, 22.38368034], [84.48020935, 22.38723946], [84.47572327, 22.39018822], [84.47595978, 22.39353943], [84.47447968, 22.40173149], [84.47666931, 22.40598106], [84.48126984, 22.40569115], [84.50179291, 22.41531944], [84.50582886, 22.41620064], [84.52101135, 22.41489029], [84.52662659, 22.42002106], [84.54065704, 22.42058945], [84.54329681, 22.41719818], [84.57215881, 22.42301178], [84.58907318, 22.42537117], [84.59395599, 22.42884064], [84.5953064, 22.4249382], [84.61364746, 22.42757988], [84.6255188, 22.42758942], [84.63210297, 22.4286499], [84.66160583, 22.41391945], [84.66934967, 22.41629982], [84.67282104, 22.41493034], [84.6815033, 22.41492081], [84.69149017, 22.41251183], [84.7113266, 22.41390038], [84.72614288, 22.41664124], [84.74385071, 22.41475105], [84.75269318, 22.44201279], [84.77805328, 22.44354057], [84.79128265, 22.4428196], [84.80124664, 22.44371033], [84.80779266, 22.44686127], [84.81047058, 22.44125175], [84.81047821, 22.43522835], [84.81269073, 22.43161011], [84.82842255, 22.42917061], [84.83162689, 22.4299202], [84.83254242, 22.42637825], [84.83574677, 22.42755127], [84.83946991, 22.43403053], [84.84136963, 22.43486977], [84.84780121, 22.43441963], [84.85534668, 22.43197823], [84.86371613, 22.43453026], [84.87124634, 22.43822289], [84.87525177, 22.44117928], [84.87652588, 22.44325066], [84.87779999, 22.4425106], [84.87947083, 22.43219948], [84.88150024, 22.42943954], [84.88198853, 22.42624855], [84.88024902, 22.41759109], [84.89379883, 22.41801071], [84.90770721, 22.41963959], [84.91639709, 22.4233799], [84.91986847, 22.42599106], [84.91815186, 22.42856979], [84.91739655, 22.43437958], [84.92533875, 22.43660927], [84.93136597, 22.43964958], [84.94077301, 22.44742966], [84.94728088, 22.45108032], [84.95244598, 22.45277023], [84.95336151, 22.4455204], [84.95243835, 22.43944931], [84.95458221, 22.4389019], [84.95728302, 22.44185829], [84.96024323, 22.44371986], [84.97779083, 22.45092964], [84.994133, 22.45827103], [85.00049591, 22.45836067], [85.02157593, 22.46710968], [85.02810669, 22.46820259], [85.03156281, 22.46978188], [85.03330994, 22.47692108], [85.03544617, 22.47729111], [85.03733063, 22.47508049], [85.04223633, 22.47694016], [85.04672241, 22.47739029], [85.05139923, 22.47941971], [85.06249237, 22.47841072], [85.07319641, 22.47286987], [85.07363892, 22.46668053], [85.07093811, 22.46116066], [85.07110596, 22.45590019], [85.06048584, 22.44951057], [85.05703735, 22.44470978], [85.05815125, 22.4397316], [85.06289673, 22.43608284], [85.06369019, 22.42322159], [85.06809235, 22.41806984], [85.07459259, 22.41345978], [85.07726288, 22.40830994], [85.07720184, 22.4030304], [85.08068085, 22.39546013], [85.08307648, 22.37844086], [85.07788086, 22.3691597], [85.07504272, 22.36096954], [85.07549286, 22.35577965], [85.07405853, 22.34859085], [85.07990265, 22.34439087], [85.08216095, 22.34132957], [85.09295654, 22.34109116], [85.09046173, 22.32487106], [85.08590698, 22.31698036], [85.08795929, 22.31408119], [85.09512329, 22.31239128], [85.10122681, 22.31432915], [85.10772705, 22.31523132], [85.11403656, 22.3142128], [85.11218262, 22.30507088], [85.11483765, 22.30038071], [85.11445618, 22.2904892], [85.10836029, 22.28947258], [85.10529327, 22.2911396], [85.09857178, 22.28792], [85.08235168, 22.27770805], [85.07051086, 22.27215958], [85.06941986, 22.26758194], [85.06990051, 22.26029015], [85.07431793, 22.25094032], [85.07206726, 22.24571991], [85.0681076, 22.24344063], [85.0694809, 22.23064995], [85.06253815, 22.21615982], [85.05879974, 22.20595169], [85.04692078, 22.18579292], [85.04960632, 22.17930984], [85.04779053, 22.17429924], [85.0414505, 22.17066002], [85.03322601, 22.1608429], [85.02802277, 22.15735817], [85.02539825, 22.15400124], [85.02619934, 22.14845085], [85.03031158, 22.14246178], [85.03115082, 22.13735962], [85.02735138, 22.1225605], [85.02429199, 22.11794281], [85.02374268, 22.11199188], [85.0194931, 22.10839081], [84.99362946, 22.09794807], [84.98586273, 22.09256935], [84.9834671, 22.09148979], [84.98049927, 22.09126091], [84.97982025, 22.08468056], [84.98104095, 22.08242035], [84.98742676, 22.07673836], [84.99359894, 22.07720947], [85.00231934, 22.0799427], [85.00720215, 22.08312988], [85.00901794, 22.09065056], [85.0140686, 22.09370995], [85.01995087, 22.10337067], [85.0271225, 22.10113907], [85.03118134, 22.10247993], [85.03513336, 22.1081295], [85.04389954, 22.11070061], [85.06945038, 22.10712814], [85.07623291, 22.10297012], [85.08409882, 22.10043907], [85.0954361, 22.09945107], [85.09900665, 22.09612083], [85.09970856, 22.08453941], [85.10447693, 22.08278084], [85.10897064, 22.0800209], [85.1102829, 22.07586288], [85.11329651, 22.07107925], [85.11888123, 22.0664711], [85.12539673, 22.06912041], [85.13506317, 22.07114029], [85.14083862, 22.07355118], [85.14891052, 22.07263947], [85.1555481, 22.07045937], [85.1578064, 22.06698036], [85.15896606, 22.06192017], [85.16374969, 22.0529995], [85.16720581, 22.0486908], [85.17080688, 22.04819107], [85.16983032, 22.05310059], [85.16436768, 22.06522942], [85.16960907, 22.06609917], [85.17246246, 22.06818962], [85.17675018, 22.06671906], [85.17913055, 22.06479073], [85.18345642, 22.05492973], [85.18699646, 22.05273056], [85.19232178, 22.05115128], [85.21074677, 22.04318047], [85.21460724, 22.03728104], [85.21389771, 22.02716064], [85.21383667, 22.01628113], [85.21488953, 22.01071167], [85.21835327, 22.00667], [85.22212982, 22.00344849], [85.23094177, 22.00027084], [85.24105835, 22.01251984], [85.24652863, 22.0254097], [85.25609589, 22.04245949], [85.25998688, 22.05285263], [85.26545715, 22.06025124], [85.26995087, 22.06896019], [85.27416229, 22.08008957], [85.28089905, 22.08764076], [85.28742218, 22.0931797], [85.30007935, 22.10705948], [85.30970001, 22.11338997], [85.31536865, 22.11584091], [85.32301331, 22.12499046], [85.33850098, 22.12471962], [85.34536743, 22.12699127], [85.35356903, 22.12057114], [85.35813141, 22.1196003], [85.36138153, 22.12144089], [85.36171722, 22.12475967], [85.35865784, 22.13280106], [85.35807037, 22.1379509], [85.36292267, 22.14657974], [85.36242676, 22.15004921], [85.36319733, 22.15456963], [85.36937714, 22.15521049], [85.37217712, 22.15244102], [85.37931824, 22.15168953], [85.38536835, 22.15234184], [85.39035034, 22.15513039], [85.3944397, 22.15859985], [85.40236664, 22.15653038], [85.41028595, 22.15608025], [85.41781616, 22.15335846], [85.43578339, 22.14417076], [85.45700836, 22.1357708], [85.46517944, 22.1312027], [85.47173309, 22.12413979], [85.47940063, 22.12177086], [85.4858017, 22.11648941], [85.50567627, 22.11145973], [85.5148468, 22.10820961], [85.52416992, 22.10305023], [85.52873993, 22.0987606], [85.53350067, 22.09679985], [85.53604889, 22.09440994], [85.53734589, 22.09029961], [85.53954315, 22.08658981], [85.54862213, 22.08855057], [85.55433655, 22.09082031], [85.56022644, 22.08490944], [85.56623077, 22.08703995], [85.57110596, 22.08605957], [85.58223724, 22.08098984], [85.5867691, 22.07681847], [85.59108734, 22.07444], [85.59664917, 22.07472038], [85.60176086, 22.07634163], [85.60359955, 22.0792408], [85.60732269, 22.08179092], [85.6085968, 22.07895088], [85.61110687, 22.07679939], [85.61958313, 22.07784081], [85.62623596, 22.0796299], [85.63124847, 22.08154106], [85.63639069, 22.08576965], [85.6400528, 22.09023285], [85.64460754, 22.09028053], [85.64805603, 22.08681107], [85.65033722, 22.08130074], [85.65532684, 22.07781029], [85.65750885, 22.07427979], [85.66472626, 22.06657028], [85.66757202, 22.06102943], [85.67236328, 22.05972099], [85.67195129, 22.05147171], [85.6815033, 22.04878044], [85.68788147, 22.05607986], [85.69600677, 22.0568409], [85.70465088, 22.05433083], [85.70780182, 22.05628967], [85.71277618, 22.0564003], [85.71755981, 22.05772972], [85.72235107, 22.05813026], [85.73381805, 22.06452942], [85.74606323, 22.06987953], [85.7504425, 22.07439041], [85.75213623, 22.0792408], [85.75782013, 22.08498192], [85.76502228, 22.08820915], [85.77339172, 22.09024048], [85.77903748, 22.09342003], [85.78425598, 22.09898758], [85.79091644, 22.10038948], [85.79397583, 22.10536957], [85.79718018, 22.10630035], [85.80204773, 22.11083031], [85.81474304, 22.10211182], [85.81521606, 22.09902], [85.80870819, 22.09184074], [85.81542206, 22.09282112], [85.8189621, 22.08963013], [85.82491302, 22.08712959], [85.82808685, 22.08266068], [85.83075714, 22.07697105], [85.8143692, 22.07007027], [85.80272675, 22.07176018], [85.79676056, 22.07450104], [85.78794098, 22.0771904], [85.78511047, 22.07191086], [85.77033234, 22.05128288], [85.7712326, 22.04714966], [85.77330017, 22.04330826], [85.77893829, 22.0362606], [85.77559662, 22.02827072], [85.77217102, 22.02470016], [85.76184845, 22.01794052], [85.75869751, 22.01480293], [85.7561264, 22.00839043], [85.76052094, 21.99694061], [85.76074982, 21.98971939], [85.77140045, 21.98371124], [85.78050232, 21.98104095], [85.78218842, 21.9793911], [85.78427887, 21.97859955], [85.80097961, 21.98166084], [85.80515289, 21.98022079], [85.81265259, 21.98096085], [85.81539154, 21.98013115], [85.81606293, 21.9753418], [85.81558228, 21.97130013], [85.81832886, 21.97001076], [85.82227325, 21.97013092], [85.82859802, 21.97294044], [85.84041595, 21.97648048], [85.8469696, 21.97707939], [85.87132263, 21.97475052], [85.88175201, 21.97483063], [85.88613129, 21.97542], [85.89115143, 21.97851944], [85.89417267, 21.97829056], [85.90284729, 21.96659088], [85.90542603, 21.96663094], [85.90599823, 21.96809006], [85.90445709, 21.9726696], [85.90921021, 21.97554016], [85.90966797, 21.97758102], [85.90725708, 21.98130989], [85.90924835, 21.99012947], [85.91306305, 21.9966507], [85.91223907, 22.0048008], [85.91954041, 22.00979042], [85.92340088, 22.01407814], [85.92488861, 22.01735115], [85.92877197, 22.01935959], [85.93309021, 22.0174408], [85.93856049, 22.01662064], [85.94258118, 22.01913071], [85.94470978, 22.02326965], [85.95153809, 22.0316391], [85.95358276, 22.03610039], [85.95797729, 22.04251099], [85.96331024, 22.0544281], [85.96737671, 22.05978012], [85.97122955, 22.06682014], [85.97528839, 22.0717907], [85.97738647, 22.07673836], [85.97731781, 22.08003998], [85.97899628, 22.08336067], [85.98919678, 22.09345055], [85.99259949, 22.10025024], [86.00047302, 22.10897064], [86.00258636, 22.11302185], [85.99608612, 22.12065125], [85.99508667, 22.12356949], [85.99462891, 22.13178062], [85.99909973, 22.13710976], [85.99968719, 22.14240074], [85.99923706, 22.14492989], [86.00385284, 22.15105057], [86.01140594, 22.15765953], [86.01312256, 22.16361046], [86.01257324, 22.16785812], [86.01477814, 22.17264175], [86.02671814, 22.18522263], [86.0255661, 22.18921089], [86.01738739, 22.19876289], [85.992836, 22.21548271], [85.98513031, 22.22384262], [85.97779083, 22.23554993], [85.97135925, 22.23838043], [85.9697876, 22.24340057], [85.98181152, 22.2520504], [85.98544312, 22.25745964], [85.98519135, 22.2672081], [85.99304199, 22.2732811], [85.99752808, 22.27534103], [86.00074005, 22.27933121], [86.00222015, 22.28146172], [86.00023651, 22.28437042], [86.00849915, 22.2926712], [86.01605988, 22.29652977], [86.0197525, 22.29781914], [86.02339172, 22.29767036], [86.02732086, 22.29949951], [86.0293808, 22.30076027], [86.03031921, 22.30298805], [86.03996277, 22.30355072], [86.04328918, 22.30619049], [86.04225922, 22.30824089], [86.03930664, 22.30865097], [86.03407288, 22.30793953], [86.03230286, 22.30523109], [86.02816772, 22.30768967], [86.02471924, 22.30417061], [86.02040863, 22.30554008], [86.01777649, 22.30455017], [86.01139832, 22.30939102], [86.01117706, 22.31056976], [86.00842285, 22.30995941], [86.008461, 22.31324005], [86.00589752, 22.31591034], [86.01328278, 22.32396126], [86.01918793, 22.32713127], [86.02043152, 22.32939911], [86.01399994, 22.33450127], [86.00476074, 22.33564949], [85.99842834, 22.33107948], [85.99582672, 22.33311844], [85.99288177, 22.33815956], [86.0061264, 22.34875107], [86.01686096, 22.3622303], [86.01526642, 22.36600113], [86.01596832, 22.37297058], [86.01841736, 22.37153053], [86.01891327, 22.37475967], [86.02124786, 22.37504005], [86.0196228, 22.37815094], [86.02149963, 22.38176155], [86.02050781, 22.38420105], [86.0175705, 22.38612175], [86.01906586, 22.39066124], [86.01802063, 22.39324188], [86.01574707, 22.39334106], [86.01477814, 22.39705086], [86.01226807, 22.39899063], [86.01365662, 22.40388107], [86.01204681, 22.41473007], [86.00961304, 22.41889], [86.00974274, 22.42165947], [86.00874329, 22.42432022], [86.0059967, 22.42536163], [86.00283813, 22.42506027], [86.00002289, 22.42264748], [85.99685669, 22.4216404], [85.99297333, 22.42214012], [85.98213196, 22.42898941], [85.96697998, 22.44122124], [85.96311188, 22.44512177], [85.96140289, 22.45269966], [85.95350647, 22.45597267], [85.95826721, 22.46590042], [85.9593277, 22.47038078], [85.95813751, 22.47618103], [85.96079254, 22.47861862], [85.9667511, 22.48216057], [85.9670105, 22.48601151], [85.96560669, 22.4901619], [85.96637726, 22.49381065], [85.96924591, 22.49978065], [85.98071289, 22.50974083], [85.98413849, 22.51062012], [85.99297333, 22.50892067], [85.99591827, 22.50896263], [85.9998703, 22.51497269], [86.00179291, 22.51486015], [86.00868225, 22.51855087], [86.01544952, 22.52448082], [86.02202606, 22.52054977], [86.02826691, 22.53433037], [86.01834106, 22.5436306], [86.0384903, 22.5635891], [86.04664612, 22.55788994], [86.0533905, 22.55465126], [86.05813599, 22.55342102], [86.06182861, 22.5485096], [86.06920624, 22.54306984], [86.07834625, 22.53041077], [86.09155273, 22.50915909], [86.09350586, 22.50822067], [86.0981369, 22.49563026], [86.10137939, 22.49015045], [86.10733032, 22.48489761], [86.11192322, 22.48293114], [86.11992645, 22.48555946], [86.1462326, 22.47914124], [86.14514923, 22.47513962], [86.1555481, 22.4790802], [86.16602325, 22.47674751], [86.17370605, 22.47643089], [86.19668579, 22.46774101], [86.20239258, 22.47027969], [86.20913696, 22.46284103], [86.21653748, 22.46504974], [86.2175827, 22.46824837], [86.21820831, 22.46821022], [86.21694946, 22.46403122], [86.21150208, 22.45971107], [86.22038269, 22.44909096], [86.22103119, 22.45059967], [86.22849274, 22.44958115], [86.2425766, 22.44453049], [86.25956726, 22.44127083], [86.2651825, 22.43954086], [86.27137756, 22.44282913], [86.2798233, 22.4455204], [86.28795624, 22.42536163], [86.29292297, 22.42014122], [86.30065155, 22.41531944], [86.30223846, 22.40520287], [86.30979919, 22.39726067], [86.31770325, 22.39059067], [86.31986237, 22.38035965], [86.32534027, 22.37308121], [86.33931732, 22.36605072], [86.34736633, 22.35900116], [86.35266113, 22.35153008], [86.35273743, 22.34542084], [86.36303711, 22.33960915], [86.37552643, 22.33711815], [86.39060974, 22.32528114], [86.40130615, 22.31941032], [86.41137695, 22.31555939], [86.42169189, 22.31389046], [86.42469788, 22.30920982], [86.42437744, 22.3062706], [86.43335724, 22.30154037], [86.4393158, 22.30578041], [86.44019318, 22.3114109], [86.43881226, 22.31645966], [86.43839264, 22.32336807], [86.44181824, 22.32534027], [86.44954681, 22.3230629], [86.45823669, 22.32211113], [86.46026611, 22.32641983], [86.46395874, 22.32699966], [86.4670105, 22.32891083], [86.46842194, 22.33228111], [86.47457886, 22.33422089], [86.47853088, 22.33446121], [86.48171234, 22.34201813], [86.48371887, 22.34441948], [86.49994659, 22.34095192], [86.50125885, 22.33146095], [86.50798798, 22.32402039], [86.51957703, 22.32057953], [86.52365112, 22.31857109], [86.52509308, 22.3123703], [86.52083588, 22.31148911], [86.52320099, 22.30783844], [86.52455139, 22.30285072], [86.53237915, 22.29819107], [86.53988647, 22.30373001], [86.54573822, 22.29892921], [86.55206299, 22.29528999], [86.561203, 22.29701042], [86.56771088, 22.29700279], [86.57068634, 22.29294968], [86.57433319, 22.29393959], [86.5752182, 22.2963295], [86.57846069, 22.29781914], [86.58130646, 22.29491806], [86.58217621, 22.29101944], [86.58560181, 22.29088974], [86.58561707, 22.28663063], [86.58992767, 22.28214073], [86.59092712, 22.27483177], [86.59845734, 22.27437973], [86.60263062, 22.27843285], [86.60851288, 22.27876091], [86.61605835, 22.27600288], [86.62715149, 22.26683044], [86.63025665, 22.26902962], [86.63465881, 22.26914978], [86.63729095, 22.26620293], [86.63761902, 22.26309013], [86.64137268, 22.26419258], [86.64227295, 22.26184273], [86.64557648, 22.26136971], [86.64589691, 22.25728035], [86.64833832, 22.25323105], [86.64729309, 22.24969292], [86.6481781, 22.23569107], [86.65114594, 22.23320007], [86.66034698, 22.2342205], [86.66269684, 22.23748016], [86.66514587, 22.23855972], [86.66989136, 22.2368412], [86.66995239, 22.23010063], [86.67399597, 22.22496986], [86.68216705, 22.21951103], [86.69178772, 22.2173996], [86.71147156, 22.21772003], [86.72097015, 22.21684074], [86.72278595, 22.21524811], [86.71996307, 22.21018982], [86.71766663, 22.19792938], [86.71607208, 22.19379997], [86.71721649, 22.18556976], [86.71335602, 22.18135262], [86.71277618, 22.17828941], [86.71534729, 22.17440987], [86.71689606, 22.16376114], [86.71520996, 22.15872002], [86.71544647, 22.14349174], [86.72280884, 22.14274025], [86.73233795, 22.14491081], [86.73953247, 22.14508247], [86.75222015, 22.14396095], [86.75670624, 22.14519119], [86.77153778, 22.14678001], [86.77694702, 22.1490097], [86.78283691, 22.15014076], [86.78681183, 22.15372276], [86.79032135, 22.1539402], [86.80045319, 22.1459198], [86.799263, 22.13908958], [86.80047607, 22.1304512], [86.79984283, 22.12848091], [86.79709625, 22.12613106], [86.79785919, 22.12528038], [86.80396271, 22.12613106], [86.806633, 22.12536049], [86.80796814, 22.12382126], [86.80438232, 22.11707115], [86.80621338, 22.11416054], [86.81217194, 22.11367035], [86.81484985, 22.11244011], [86.8208313, 22.11362076], [86.82331085, 22.11292076], [86.82540131, 22.10863113], [86.83132935, 22.10069084], [86.83200836, 22.09510994], [86.84169006, 22.09180069], [86.84603119, 22.09514999], [86.84790039, 22.09835052], [86.90876007, 22.08638], [86.92225647, 22.08576012], [86.92901611, 22.08453941], [86.93203735, 22.08584976], [86.94426727, 22.08197975], [86.95197296, 22.08134079], [86.95723724, 22.0833683], [86.96705627, 22.07775116], [86.97046661, 22.07399178], [86.97190857, 22.06627083], [86.98754883, 22.05507278], [86.99048615, 22.04938126], [86.99517822, 22.04579926], [87.00093079, 22.04500008], [87.00470734, 22.04278946], [87.0094223, 22.04148102], [87.01761627, 22.04128075], [87.02469635, 22.03269005], [87.02604675, 22.02874947], [87.02350616, 22.02102089], [87.02226257, 22.0120697], [87.02500916, 22.00395012], [87.02796936, 21.99842262], [87.0319519, 21.99567032], [87.03431702, 21.98919106], [87.03224182, 21.98610115], [87.03085327, 21.97883987], [87.02030945, 21.96836281], [87.01490021, 21.95326042], [87.00554657, 21.94065094], [87.00408173, 21.9354229], [87.0025177, 21.92235947], [86.99939728, 21.91814041], [87.00061035, 21.91438103], [86.99793243, 21.90750122], [87.00125885, 21.90584183], [87.00483704, 21.8955307], [87.01478577, 21.88968277], [87.0167923, 21.88722992], [87.01996613, 21.88574982], [87.02511597, 21.87034988], [87.03024292, 21.86531067], [87.05377197, 21.86094284], [87.06210327, 21.86018944], [87.0777359, 21.85980034], [87.09464264, 21.86034012], [87.0929184, 21.87420273], [87.09626007, 21.88210106], [87.09612274, 21.88624954], [87.09314728, 21.88986969], [87.0894165, 21.89240074], [87.08853912, 21.89507294], [87.08876801, 21.89812088], [87.09101868, 21.89923096], [87.09353638, 21.90789986], [87.09955597, 21.91098022], [87.10180664, 21.91608047], [87.10468292, 21.91781998], [87.10785675, 21.91741943], [87.1103363, 21.91802025], [87.11255646, 21.92115021], [87.11424255, 21.92217064], [87.11618042, 21.92064095], [87.12351227, 21.92024994], [87.13091278, 21.91801071], [87.1367569, 21.91797066], [87.14112854, 21.91969109], [87.14782715, 21.92592812], [87.15168762, 21.9279995], [87.15641785, 21.9289093], [87.15828705, 21.93054962], [87.15989685, 21.93392944], [87.15976715, 21.94908142], [87.16127777, 21.95389938], [87.16056061, 21.96244049], [87.16520691, 21.96751022], [87.16744232, 21.97340965], [87.17085266, 21.97261047], [87.17497253, 21.96619987], [87.18837738, 21.95701027], [87.19510651, 21.95356941], [87.20291138, 21.95643997], [87.20957184, 21.95737076], [87.22119141, 21.95321083], [87.22323608, 21.95323181], [87.22440338, 21.95401955], [87.22561646, 21.9571209], [87.22873688, 21.95607948], [87.23484802, 21.95438004], [87.23500061, 21.95298958], [87.23232269, 21.94646263], [87.23223114, 21.94036102], [87.23542786, 21.93374062], [87.25208282, 21.92097282], [87.25240326, 21.91780281], [87.25054932, 21.91518021], [87.23937225, 21.90682983], [87.23651886, 21.90272141], [87.23480988, 21.89560127], [87.24732971, 21.87172127], [87.24897766, 21.86651993], [87.24900055, 21.86380005], [87.24475098, 21.85637093], [87.24762726, 21.84820747], [87.25527191, 21.8438797], [87.25714874, 21.84137917], [87.25888824, 21.83501053], [87.26169586, 21.83329964], [87.26226044, 21.82982826], [87.26357269, 21.82719994], [87.26346588, 21.82501984], [87.26756287, 21.82149124], [87.26780701, 21.81970978], [87.26326752, 21.81604195], [87.26242065, 21.81385994], [87.26542664, 21.81289101], [87.27147675, 21.81307983], [87.27379608, 21.81171989], [87.27314758, 21.80579948], [87.27165222, 21.80471992], [87.27156067, 21.80340004], [87.27333832, 21.80360031], [87.27350616, 21.8020401], [87.28060913, 21.7991581], [87.2869873, 21.80384827], [87.29281616, 21.80546951], [87.29480743, 21.80389023], [87.294487, 21.79842186], [87.29656982, 21.79533005], [87.29872131, 21.79444122], [87.30605316, 21.79385948], [87.30755615, 21.79268265], [87.30916595, 21.78890991], [87.31796265, 21.79055023], [87.31685638, 21.78854942], [87.31730652, 21.78572083], [87.32286072, 21.78596115], [87.32427216, 21.78537941], [87.32618713, 21.78564072], [87.33011627, 21.78770256], [87.33270264, 21.78720093], [87.33534241, 21.78363037], [87.33573151, 21.78121185], [87.33500671, 21.78013039], [87.33666992, 21.77918053], [87.33922577, 21.7808094], [87.34046173, 21.78395844], [87.34449768, 21.78596115], [87.3520813, 21.78573036], [87.35504913, 21.77927971], [87.35736084, 21.77724075], [87.36779785, 21.77463913], [87.37045288, 21.76802063], [87.36873627, 21.76263046], [87.37011719, 21.76007271], [87.37166595, 21.76039124], [87.37306213, 21.76204109], [87.37348938, 21.76641083], [87.37542725, 21.76799965], [87.38330078, 21.77086067], [87.39096069, 21.77044106], [87.39240265, 21.76898193], [87.38990021, 21.76654053], [87.39315796, 21.76613808], [87.39377594, 21.76377106], [87.39524078, 21.76242256], [87.39993286, 21.76256943], [87.40101624, 21.76486015], [87.40283203, 21.7655201], [87.41208649, 21.76375008], [87.42481995, 21.76565933], [87.43139648, 21.76440048], [87.43930817, 21.76436043], [87.44367218, 21.76088905], [87.44245911, 21.75533104], [87.44330597, 21.74212074], [87.44563293, 21.7379303], [87.45111084, 21.7354126], [87.45137024, 21.73241043], [87.44441986, 21.732481], [87.44293213, 21.72904968], [87.45419312, 21.72943115], [87.46276855, 21.72640038], [87.46517944, 21.72636032], [87.46605682, 21.72519112], [87.46573639, 21.7235775], [87.46231842, 21.72224998], [87.46083069, 21.72050095], [87.46264648, 21.71706009], [87.47083282, 21.70718002], [87.46929169, 21.69845009], [87.4675293, 21.69565964], [87.46969604, 21.6916008], [87.46839142, 21.68378067], [87.46826172, 21.67727089], [87.46520233, 21.67513084], [87.46507263, 21.67110062], [87.46349335, 21.66876984], [87.46491241, 21.65855026], [87.4604187, 21.65712929], [87.45864868, 21.64493942], [87.46090698, 21.64445114], [87.46776581, 21.64565086], [87.47074127, 21.64307022], [87.47751617, 21.63175964], [87.4785614, 21.62794113], [87.48208618, 21.62586975], [87.48265839, 21.61803246], [87.48171234, 21.61383057], [87.48175812, 21.60946274], [87.48203278, 21.60870361], [87.48110962, 21.60777855], [87.48082733, 21.60778046], [87.4799881, 21.60771751], [87.47948456, 21.60771751], [87.47861481, 21.60785294], [87.47833252, 21.60777855], [87.47782898, 21.60750008], [87.4774704, 21.60705757], [87.47695923, 21.60679054], [87.47635651, 21.60679054], [87.47580719, 21.60698128], [87.47466278, 21.60686493], [87.47389984, 21.60678482], [87.47354126, 21.60638046], [87.47270966, 21.60647202], [87.47214508, 21.60612106], [87.47145081, 21.6061058], [87.47071838, 21.60632324], [87.46992493, 21.60650444], [87.46920776, 21.60645103], [87.46852112, 21.60639], [87.46788025, 21.60630989], [87.46722412, 21.60644722], [87.46673584, 21.6065197], [87.46639252, 21.60667038], [87.4658432, 21.60667038], [87.46565247, 21.60648537], [87.46555328, 21.60638618], [87.46389008, 21.60639], [87.46360779, 21.60610962], [87.46333313, 21.60611153], [87.46305847, 21.60583305], [87.46277618, 21.60583305], [87.4624939, 21.60555649], [87.46221924, 21.60527611], [87.46193695, 21.60527992], [87.46166992, 21.60499954], [87.46138763, 21.60499954], [87.46055603, 21.60416985], [87.46028137, 21.60416985], [87.4597168, 21.60361099], [87.4597168, 21.60305977], [87.46055603, 21.60222054], [87.45972443, 21.60179329], [87.45944214, 21.6016674], [87.45889282, 21.60167122], [87.45870209, 21.60148239], [87.45861053, 21.60138893], [87.45833588, 21.60139275], [87.45777893, 21.60083008], [87.45761871, 21.6006794], [87.45707703, 21.60037422], [87.45639038, 21.60000038], [87.45582581, 21.60000038], [87.45500946, 21.59917259], [87.45471954, 21.5988903], [87.45443726, 21.5988903], [87.454216, 21.59865761], [87.45388794, 21.59861183], [87.45361328, 21.59833336], [87.45305634, 21.59833336], [87.45249939, 21.59777832], [87.45276642, 21.59749985], [87.45276642, 21.59693909], [87.45305634, 21.59694481], [87.45333099, 21.59722137], [87.45388794, 21.59721756], [87.45417023, 21.59749985], [87.45500946, 21.59749985], [87.45542908, 21.59707642], [87.45555878, 21.59694481], [87.45500183, 21.59638977], [87.45471954, 21.59638977], [87.45417023, 21.59583282], [87.45388794, 21.59583282], [87.45333099, 21.59527969], [87.45305634, 21.59527969], [87.4522171, 21.59444046], [87.45178986, 21.59422684], [87.45124054, 21.59387016], [87.44972229, 21.5933342], [87.44721985, 21.59083557], [87.4466629, 21.59083557], [87.44638824, 21.59055328], [87.44610596, 21.59057045], [87.44581604, 21.59028053], [87.44555664, 21.59028053], [87.44444275, 21.58917046], [87.44361115, 21.58917046], [87.44194794, 21.58751106], [87.44139099, 21.58751106], [87.44114685, 21.58726311], [87.44083405, 21.58722115], [87.44055176, 21.58694458], [87.4402771, 21.58694458], [87.44000244, 21.58666611], [87.43972015, 21.58667183], [87.43860626, 21.58556175], [87.4383316, 21.58556175], [87.43776703, 21.58499908], [87.4375, 21.58499908], [87.43742371, 21.58492088], [87.43731689, 21.58481216], [87.43694305, 21.58444405], [87.4366684, 21.58444405], [87.43611145, 21.58389091], [87.43583679, 21.58389091], [87.43444824, 21.58250046], [87.43416595, 21.58250046], [87.43332672, 21.58167076], [87.43305206, 21.58167076], [87.4327774, 21.58138084], [87.43250275, 21.58138847], [87.43138885, 21.5802784], [87.43110657, 21.5802803], [87.4306488, 21.579813], [87.43055725, 21.57971954], [87.43055725, 21.57944679], [87.43027496, 21.57916451], [87.43000031, 21.57917023], [87.42944336, 21.57860947], [87.4291687, 21.57861137], [87.42875671, 21.57819557], [87.4283371, 21.57777786], [87.4283371, 21.57749939], [87.42778015, 21.57694054], [87.42694092, 21.57694244], [87.42666626, 21.57666588], [87.42582703, 21.57639122], [87.42415619, 21.57472038], [87.42388916, 21.57472229], [87.4236145, 21.57444382], [87.42333221, 21.57444382], [87.42319489, 21.57430649], [87.42305756, 21.57416725], [87.4227829, 21.57417107], [87.42193604, 21.57333183], [87.42166901, 21.57333374], [87.42138672, 21.57305527], [87.42111206, 21.5730629], [87.42028046, 21.57389069], [87.41971588, 21.57389069], [87.41916656, 21.57333183], [87.41916656, 21.57305527], [87.41887665, 21.57278252], [87.41887665, 21.57250023], [87.41805267, 21.57167244], [87.41805267, 21.57055092], [87.41694641, 21.56944466], [87.41666412, 21.56944466], [87.41576385, 21.5688324], [87.41555023, 21.5684967], [87.41570282, 21.56829262], [87.41619873, 21.56829453], [87.4168396, 21.56816292], [87.4168396, 21.5680294], [87.41677094, 21.56776047], [87.41619873, 21.56709099], [87.41567993, 21.56651115], [87.41503906, 21.56637001], [87.41444397, 21.56583595], [87.41416931, 21.56583023], [87.41333008, 21.56666946], [87.41339874, 21.56701088], [87.41346741, 21.56777954], [87.41352844, 21.56805992], [87.4136734, 21.56916618], [87.41333008, 21.56972313], [87.41278076, 21.56916618], [87.41278076, 21.56861115], [87.41249847, 21.56833076], [87.41249847, 21.56749916], [87.41166687, 21.56666946], [87.41166687, 21.56640053], [87.41139221, 21.56611061], [87.41139221, 21.56555939], [87.41110992, 21.56528091], [87.41110992, 21.56500053], [87.4108429, 21.56472015], [87.41083527, 21.56416512], [87.40970612, 21.56306076], [87.40952301, 21.56285095], [87.40910339, 21.56243324], [87.40916443, 21.56222153], [87.40916443, 21.56194305], [87.40944672, 21.5616703], [87.40952301, 21.56151962], [87.40994263, 21.56131172], [87.41166687, 21.56272125], [87.41207886, 21.56236076], [87.41207886, 21.56215477], [87.4119339, 21.56173134], [87.41007233, 21.56004906], [87.40970612, 21.56011963], [87.40943909, 21.56001663], [87.40937042, 21.55999184], [87.4091568, 21.56005859], [87.40888977, 21.55999947], [87.40860748, 21.55999947], [87.40791321, 21.55977821], [87.40776825, 21.55983734], [87.40727997, 21.55962944], [87.40693665, 21.55888939], [87.40673065, 21.55861092], [87.40611267, 21.55777931], [87.40596771, 21.55750084], [87.40499878, 21.5566597], [87.40444183, 21.55639076], [87.40409851, 21.55631065], [87.40291595, 21.55644989], [87.40222168, 21.55666924], [87.40090179, 21.55686951], [87.40027618, 21.55721092], [87.39923859, 21.55755806], [87.39861298, 21.55777931], [87.39833069, 21.55777931], [87.39805603, 21.5580616], [87.39778137, 21.55805588], [87.39749908, 21.55833244], [87.3972168, 21.55833054], [87.39569092, 21.55918312], [87.39533997, 21.5597229], [87.39520264, 21.55986977], [87.39499664, 21.55999947], [87.39303589, 21.56113052], [87.39261627, 21.56139946], [87.39248657, 21.56167984], [87.39235687, 21.56167984], [87.39193726, 21.56182098], [87.39179993, 21.56208801], [87.3915329, 21.56223106], [87.39111328, 21.5625], [87.39027405, 21.56333542], [87.38967133, 21.56386948], [87.38947296, 21.56417084], [87.38906097, 21.56484032], [87.38863373, 21.56511688], [87.38814545, 21.5652504], [87.38692474, 21.56630898], [87.38638306, 21.56656265], [87.38679504, 21.5662632], [87.38703918, 21.56541443], [87.38676453, 21.564991], [87.38684845, 21.56478119], [87.38663483, 21.56451225], [87.3864975, 21.56423569], [87.38642883, 21.56388855], [87.38643646, 21.56360054], [87.38630676, 21.56333542], [87.3861084, 21.56278038], [87.3861084, 21.5625], [87.38556671, 21.5616703], [87.38527679, 21.56138992], [87.38533783, 21.56110954], [87.3852005, 21.56083107], [87.38492584, 21.5602932], [87.3848877, 21.56021309], [87.38459778, 21.55999184], [87.38406372, 21.55921555], [87.3844223, 21.55796814], [87.38443756, 21.55708122], [87.3842926, 21.55652046], [87.38444519, 21.55611038], [87.38401794, 21.55399704], [87.38340759, 21.55352974], [87.38285065, 21.55346107], [87.38201904, 21.55335045], [87.38276672, 21.55249977], [87.38305664, 21.55249977], [87.3833313, 21.55221939], [87.38388824, 21.5522213], [87.3841629, 21.55194664], [87.38444519, 21.55194664], [87.38471985, 21.5522213], [87.38500214, 21.5522213], [87.38527679, 21.55194664], [87.3861084, 21.55194664], [87.38639069, 21.55166435], [87.38694763, 21.55167007], [87.38722229, 21.55140114], [87.38791656, 21.55104065], [87.38944244, 21.55083084], [87.3895874, 21.55089569], [87.39026642, 21.55120087], [87.39065552, 21.55122375], [87.39083099, 21.55140114], [87.39111328, 21.55140114], [87.39138794, 21.55111122], [87.39138794, 21.55000114], [87.39111328, 21.55000114], [87.39026642, 21.54916954], [87.38999939, 21.54916954], [87.38916779, 21.54833031], [87.3888855, 21.54833221], [87.38833618, 21.54777718], [87.38804626, 21.5477829], [87.38777924, 21.54750061], [87.38749695, 21.54750061], [87.38722229, 21.5477829], [87.38694763, 21.54777718], [87.38639069, 21.54833221], [87.3861084, 21.54833031], [87.38582611, 21.54861069], [87.38527679, 21.54861069], [87.38500214, 21.54889107], [87.38500214, 21.54916573], [87.38471985, 21.54944229], [87.38444519, 21.54944229], [87.3841629, 21.54916573], [87.38388824, 21.54916954], [87.38360596, 21.54889107], [87.3833313, 21.54889107], [87.38276672, 21.54833031], [87.38277435, 21.54805565], [87.38249969, 21.5477829], [87.38249969, 21.54750061], [87.38111115, 21.54611015], [87.38083649, 21.54611015], [87.3805542, 21.54583359], [87.38027954, 21.54583359], [87.37999725, 21.54555511], [87.37944794, 21.54555511], [87.37916565, 21.54583359], [87.37889099, 21.54583359], [87.3786087, 21.54611015], [87.3777771, 21.54611015], [87.37750244, 21.54639053], [87.37722015, 21.54639053], [87.37696075, 21.54611015], [87.37610626, 21.54611015], [87.3758316, 21.54639053], [87.375, 21.54639053], [87.37473297, 21.54667282], [87.3741684, 21.5466671], [87.37388611, 21.54694366], [87.37359619, 21.54694176], [87.37249756, 21.54805565], [87.37249756, 21.54833031], [87.37277985, 21.54861069], [87.3741684, 21.54861069], [87.37444305, 21.54889107], [87.3741684, 21.54916573], [87.3741684, 21.54944038], [87.37359619, 21.55000114], [87.37277985, 21.55000114], [87.3722229, 21.55055428], [87.3722229, 21.55083275], [87.37166595, 21.55083084], [87.3713913, 21.55111122], [87.37110901, 21.55083084], [87.3694458, 21.55083275], [87.36916351, 21.55055428], [87.36860657, 21.55056], [87.36833191, 21.55027962], [87.36776733, 21.55027962], [87.36750031, 21.55000114], [87.36723328, 21.55000114], [87.36694336, 21.55027962], [87.3666687, 21.55027962], [87.36638641, 21.55056], [87.36611176, 21.55056], [87.36528015, 21.55138969], [87.36528015, 21.5522213], [87.36416626, 21.55333328], [87.3638916, 21.55305672], [87.3638916, 21.55277824], [87.36305237, 21.55194092], [87.36222076, 21.55194664], [87.36208344, 21.55180359], [87.36194611, 21.55166435], [87.3602829, 21.55167007], [87.36000061, 21.55140114], [87.35943604, 21.55140114], [87.35916901, 21.55167007], [87.35805511, 21.55166435], [87.35778046, 21.55194664], [87.35749817, 21.55194664], [87.35722351, 21.5522213], [87.35639191, 21.55138969], [87.35582733, 21.55140114], [87.3555603, 21.55167007], [87.35500336, 21.55167007], [87.35472107, 21.55140114], [87.35388947, 21.55140114], [87.35360718, 21.55167007], [87.35221863, 21.55167007], [87.35193634, 21.55140114], [87.35109711, 21.55140114], [87.35083008, 21.55167007], [87.35063171, 21.55166435], [87.34972382, 21.55166435], [87.34916687, 21.5522213], [87.34889221, 21.55194664], [87.34833527, 21.55194664], [87.34805298, 21.55166435], [87.34777832, 21.55194664], [87.34666443, 21.55194664], [87.34638977, 21.5522213], [87.34610748, 21.55221939], [87.34555817, 21.55278015], [87.34416962, 21.55277824], [87.34388733, 21.55305672], [87.34361267, 21.55305672], [87.34336853, 21.55282021], [87.34166718, 21.55277824], [87.34139252, 21.55305672], [87.34083557, 21.55305672], [87.34054565, 21.55327988], [87.34027863, 21.55333328], [87.33999634, 21.55361176], [87.33916473, 21.55361176], [87.33865356, 21.55309868], [87.33833313, 21.55277824], [87.33721924, 21.55277824], [87.33694458, 21.55305672], [87.33666992, 21.55305672], [87.33638763, 21.55333328], [87.33499908, 21.55333328], [87.33374786, 21.55424118], [87.33333588, 21.55446053], [87.33203125, 21.55438042], [87.3312912, 21.55442429], [87.33072662, 21.55450249], [87.33059692, 21.55451965], [87.3299408, 21.5544796], [87.32928467, 21.55446243], [87.32863617, 21.55446053], [87.32795715, 21.55442047], [87.3272171, 21.55446053], [87.32694244, 21.55446053], [87.32666779, 21.55417061], [87.32639313, 21.55446053], [87.32305908, 21.55444527], [87.32277679, 21.55472183], [87.32221985, 21.55472183], [87.32195282, 21.55446053], [87.31890106, 21.55424118], [87.31833649, 21.5541687], [87.31777954, 21.55417061], [87.31742859, 21.55444527], [87.3172226, 21.55451012], [87.31694794, 21.55465508], [87.31555176, 21.55472183], [87.31520844, 21.55466461], [87.31361389, 21.55473137], [87.3133316, 21.55472183], [87.3132019, 21.55472183], [87.31305695, 21.55471992], [87.31138611, 21.55500031], [87.30999756, 21.55500031], [87.3097229, 21.55508041], [87.3077774, 21.55528069], [87.30735779, 21.55523109], [87.30444336, 21.55555534], [87.30392456, 21.55570412], [87.30361176, 21.55555534], [87.3033371, 21.55555916], [87.30304718, 21.55569839], [87.30272675, 21.55565834], [87.30251312, 21.55563164], [87.30136108, 21.55563164], [87.30014801, 21.55542946], [87.29611206, 21.55501938], [87.29528046, 21.5549202], [87.29472351, 21.55472183], [87.29444122, 21.55479813], [87.29277802, 21.55500031], [87.29242706, 21.5549202], [87.29083252, 21.5549202], [87.2902832, 21.55500984], [87.29000092, 21.55500984], [87.2894516, 21.55505943], [87.28923035, 21.55498123], [87.28853607, 21.5546875], [87.28806305, 21.55468941], [87.28749847, 21.55463982], [87.28722382, 21.55456924], [87.28666687, 21.55472183], [87.28639221, 21.55451202], [87.28610992, 21.55472183], [87.28527832, 21.55471992], [87.28472137, 21.55480766], [87.28451538, 21.55487442], [87.28409576, 21.55473137], [87.28388977, 21.55472183], [87.28367615, 21.55456924], [87.2831192, 21.55462074], [87.28291321, 21.55449104], [87.28277588, 21.55449486], [87.28221893, 21.55444527], [87.28193665, 21.55446053], [87.28132629, 21.55439949], [87.28083038, 21.55447006], [87.28041077, 21.55431747], [87.2800827, 21.55433273], [87.27944183, 21.55433273], [87.27861023, 21.55417061], [87.27777863, 21.55417061], [87.27429199, 21.55425072], [87.27271271, 21.55417824], [87.27111053, 21.55360985], [87.26944733, 21.55361176], [87.26773071, 21.55307198], [87.26568604, 21.55329704], [87.26529694, 21.55334091], [87.26465607, 21.55340958], [87.26286316, 21.55321121], [87.2612915, 21.55321121], [87.26051331, 21.55301094], [87.25863647, 21.55266953], [87.25327301, 21.55266953], [87.25269318, 21.55280304], [87.2514801, 21.55273628], [87.24983215, 21.55247116], [87.24846649, 21.55186081], [87.24782562, 21.55179405], [87.24568176, 21.55158997], [87.24446106, 21.55152512], [87.24310303, 21.55158997], [87.24188232, 21.55166054], [87.24082184, 21.55200005], [87.23960876, 21.55120087], [87.23912048, 21.55125237], [87.23851776, 21.55121231], [87.23782349, 21.55107117], [87.23709106, 21.55092812], [87.23638153, 21.55084038], [87.23573303, 21.55079079], [87.23513031, 21.55064011], [87.23456573, 21.55035782], [87.23416901, 21.55000114], [87.23220825, 21.55000114], [87.23194122, 21.54972076], [87.23082733, 21.54972076], [87.22956848, 21.54980087], [87.22720337, 21.54980087], [87.22648621, 21.54957008], [87.22596741, 21.5494709], [87.22538757, 21.54943275], [87.22514343, 21.54947281], [87.224823, 21.54953003], [87.22416687, 21.54944992], [87.22368622, 21.54938316], [87.22333527, 21.54944229], [87.22211456, 21.54931641], [87.22090149, 21.54891014], [87.22025299, 21.5485096], [87.21837616, 21.54824066], [87.21746063, 21.54797173], [87.21723175, 21.54780006], [87.21694183, 21.54770279], [87.21424103, 21.54722977], [87.21322632, 21.54689026], [87.21187592, 21.54675865], [87.21037292, 21.54676056], [87.2099762, 21.54672623], [87.2095871, 21.54668999], [87.20901489, 21.54628754], [87.20835114, 21.54639053], [87.20803833, 21.54639053], [87.20780182, 21.54613876], [87.20749664, 21.54611015], [87.20722198, 21.54639053], [87.20694733, 21.54639053], [87.20666504, 21.5466671], [87.20575714, 21.5471611], [87.20548248, 21.54729843], [87.20492554, 21.54765129], [87.20437622, 21.54784966], [87.20417023, 21.54807091], [87.20361328, 21.5481987], [87.20333099, 21.54834175], [87.20305634, 21.54833031], [87.20276642, 21.54840279], [87.20236206, 21.54841995], [87.20188141, 21.54849052], [87.20139313, 21.54849052], [87.20089722, 21.54849052], [87.20027924, 21.54805946], [87.19999695, 21.54805946], [87.19944763, 21.54750061], [87.19944763, 21.54694176], [87.19984436, 21.54653358], [87.20021057, 21.54618645], [87.20052338, 21.54580116], [87.20069122, 21.54536057], [87.20059204, 21.54493141], [87.20037842, 21.54450035], [87.20005035, 21.54413033], [87.19963837, 21.54379082], [87.19922638, 21.5434494], [87.19877625, 21.54323006], [87.19834137, 21.54305077], [87.19788361, 21.54289436], [87.19741821, 21.54274368], [87.19696045, 21.54255676], [87.19645691, 21.54243279], [87.19602966, 21.54223061], [87.19558716, 21.54203033], [87.19509125, 21.54189873], [87.19461823, 21.5417099], [87.19425201, 21.54157639], [87.1941452, 21.54153824], [87.19365692, 21.54138947], [87.19319153, 21.54123116], [87.19272614, 21.54105186], [87.1922226, 21.54087067], [87.19166565, 21.5408268], [87.19151306, 21.54081154], [87.19110107, 21.54077339], [87.19057465, 21.54060936], [87.19000244, 21.54050064], [87.18942261, 21.54032326], [87.18881226, 21.54021645], [87.18821716, 21.54002953], [87.18761444, 21.53991318], [87.18704987, 21.53970337], [87.18651581, 21.53946114], [87.18598938, 21.53920174], [87.18541718, 21.53902817], [87.18480682, 21.53887939], [87.18421936, 21.53868103], [87.1836319, 21.53849983], [87.18305206, 21.53830147], [87.18251801, 21.5380497], [87.18199921, 21.5377903], [87.18147278, 21.53755188], [87.18090057, 21.5373764], [87.180336, 21.53721046], [87.17980194, 21.53703308], [87.1792984, 21.53680801], [87.17877197, 21.53655815], [87.1782608, 21.5363369], [87.1778717, 21.53627777], [87.17751312, 21.53634071], [87.17707062, 21.53635979], [87.17648315, 21.53619003], [87.17582703, 21.53593063], [87.17537689, 21.53565025], [87.17505646, 21.53536987], [87.17471313, 21.53517342], [87.17433167, 21.53497505], [87.17392731, 21.53475952], [87.17349243, 21.53460121], [87.17304993, 21.5344429], [87.17260742, 21.53427124], [87.17216492, 21.53410149], [87.17172241, 21.53390884], [87.17124939, 21.53373909], [87.17077637, 21.53357506], [87.17032623, 21.53337097], [87.1698761, 21.53320122], [87.16943359, 21.53304863], [87.16899109, 21.53289032], [87.16854095, 21.53273964], [87.16810608, 21.53254128], [87.16765594, 21.53238106], [87.16722107, 21.53222084], [87.16677094, 21.53206825], [87.16630554, 21.5319767], [87.16580963, 21.53193855], [87.16532135, 21.53186989], [87.16487885, 21.53165817], [87.16445923, 21.53140259], [87.16404724, 21.53116035], [87.16362, 21.53095818], [87.16319275, 21.53077507], [87.16279602, 21.5305481], [87.1624527, 21.53032112], [87.16207886, 21.53012085], [87.16165924, 21.53001022], [87.16122437, 21.52992439], [87.16078949, 21.52972984], [87.16033173, 21.52951813], [87.15986633, 21.52930832], [87.15947723, 21.52905273], [87.15911865, 21.52879333], [87.15870667, 21.52859116], [87.15830231, 21.52837944], [87.15785217, 21.52824974], [87.15738678, 21.52808952], [87.15638733, 21.52743912], [87.15473938, 21.52683067], [87.15380859, 21.52602768], [87.15231323, 21.5250206], [87.15087128, 21.52408028], [87.14966583, 21.52361107], [87.1492157, 21.52345657], [87.14853668, 21.52346039], [87.14785004, 21.52310944], [87.14720154, 21.52273941], [87.14658356, 21.52234459], [87.14594269, 21.52199745], [87.14533997, 21.52164078], [87.1446991, 21.52136612], [87.14404297, 21.52109909], [87.14337921, 21.52083015], [87.14277649, 21.52050018], [87.14228058, 21.52011299], [87.14176941, 21.51984024], [87.14128113, 21.51963043], [87.14083099, 21.51944351], [87.13968658, 21.51861572], [87.13896942, 21.51828194], [87.13846588, 21.51781082], [87.13817596, 21.51740074], [87.13796997, 21.51720238], [87.13718414, 21.51700211], [87.1366806, 21.51673317], [87.13648224, 21.51650429], [87.13592529, 21.51619148], [87.13542938, 21.51584625], [87.13498688, 21.51551056], [87.134552, 21.51521111], [87.13414001, 21.51492119], [87.13374329, 21.51499939], [87.13275909, 21.51472092], [87.13194275, 21.51415825], [87.13173676, 21.51403046], [87.1314621, 21.51403236], [87.1305542, 21.51333427], [87.1297226, 21.51292992], [87.1286087, 21.51303291], [87.12832642, 21.5128994], [87.12805176, 21.51303864], [87.12722015, 21.51333046], [87.12722015, 21.51361084], [87.12917328, 21.51555824], [87.12944794, 21.51582527], [87.12957764, 21.51609993], [87.12978363, 21.5161705], [87.13040924, 21.51651955], [87.13069153, 21.51672554], [87.13082123, 21.51679993], [87.13166046, 21.51756859], [87.1313858, 21.51779175], [87.13111115, 21.5177784], [87.13083649, 21.5177784], [87.13054657, 21.51749992], [87.13027954, 21.51749992], [87.1297226, 21.51693916], [87.12944794, 21.51694489], [87.1286087, 21.51611137], [87.12833405, 21.51611137], [87.12805176, 21.5158329], [87.1277771, 21.5158329], [87.12722015, 21.51527977], [87.12693787, 21.51528931], [87.12666321, 21.51499939], [87.12638855, 21.51499939], [87.12610626, 21.51472092], [87.12555695, 21.51472282], [87.12527466, 21.51471329], [87.12472534, 21.51499939], [87.12472534, 21.5158329], [87.12458801, 21.51610947], [87.12472534, 21.51638985], [87.12473297, 21.51721954], [87.125, 21.51749992], [87.125, 21.51833344], [87.12526703, 21.51861191], [87.12527466, 21.51916695], [87.125, 21.5194416], [87.125, 21.52000046], [87.12361145, 21.52139282], [87.12333679, 21.52138901], [87.12277985, 21.52147484], [87.12242889, 21.52147484], [87.12194824, 21.52138901], [87.1213913, 21.52112007], [87.12110901, 21.52109909], [87.12083435, 21.52111053], [87.12055206, 21.52083206], [87.1202774, 21.52083206], [87.12000275, 21.5205555], [87.11972046, 21.52056122], [87.11915588, 21.52028275], [87.11807251, 21.51917267], [87.11778259, 21.51917267], [87.11759186, 21.51898384], [87.11750031, 21.51889038], [87.11723328, 21.51889038], [87.11638641, 21.51806259], [87.1159668, 21.51791954], [87.11562347, 21.51764107], [87.11521149, 21.51737213], [87.11459351, 21.51667595], [87.11416626, 21.51666832], [87.1138916, 21.51638985], [87.11305237, 21.51625061], [87.11277771, 21.51617813], [87.11242676, 21.51625061], [87.11138916, 21.51638985], [87.11110687, 21.51666832], [87.10944366, 21.51666641], [87.10916901, 21.51694489], [87.10888672, 21.51694489], [87.10861206, 21.51722145], [87.10749817, 21.51722145], [87.10694885, 21.51773453], [87.10697174, 21.51732063], [87.10668945, 21.51669121], [87.10643768, 21.51634026], [87.10722351, 21.51555634], [87.10849762, 21.51478004], [87.10928345, 21.51485252], [87.11107635, 21.51458359], [87.11164856, 21.51431465], [87.11229706, 21.51424789], [87.11422729, 21.5137825], [87.11472321, 21.51333046], [87.11472321, 21.51277542], [87.11472321, 21.51250076], [87.1147995, 21.51222992], [87.11473083, 21.51151276], [87.11444092, 21.50972176], [87.11416626, 21.50944328], [87.11416626, 21.50889015], [87.1138916, 21.50860977], [87.1138916, 21.5083313], [87.11360931, 21.50805473], [87.11333466, 21.50805473], [87.11222076, 21.50694466], [87.11222076, 21.50666618], [87.11193848, 21.50638962], [87.11193848, 21.5060997], [87.11166382, 21.50583267], [87.11166382, 21.50555611], [87.11138916, 21.50527954], [87.11138916, 21.50499916], [87.10916901, 21.50278091], [87.10887909, 21.50278091], [87.10861206, 21.50250053], [87.10805511, 21.50250053], [87.10694122, 21.50138855], [87.10666656, 21.50139046], [87.10652924, 21.50125122], [87.10639191, 21.50111198], [87.10618591, 21.50097656], [87.10597229, 21.50077057], [87.10569763, 21.50036049], [87.10398102, 21.4985466], [87.10382843, 21.49833488], [87.10361481, 21.49805641], [87.10305786, 21.49749947], [87.10305786, 21.49722099], [87.10194397, 21.49611092], [87.10193634, 21.49583054], [87.10166931, 21.49555588], [87.10138702, 21.49555969], [87.09967804, 21.4938488], [87.09944153, 21.49361038], [87.0983429, 21.49250031], [87.09812927, 21.49229813], [87.09722137, 21.49160194], [87.09694672, 21.49138832], [87.09664917, 21.49111938], [87.09645844, 21.49098015], [87.09636688, 21.4908886], [87.09625244, 21.49077415], [87.09563446, 21.49027824], [87.09527588, 21.48999977], [87.09443665, 21.48916817], [87.09416962, 21.48916817], [87.09310913, 21.4881115], [87.09194183, 21.4869442], [87.09194183, 21.48666763], [87.09139252, 21.48611069], [87.09083557, 21.48611069], [87.09046936, 21.48574448], [87.09027863, 21.48555756], [87.09027863, 21.48528099], [87.08999634, 21.48499107], [87.08999634, 21.48444557], [87.08944702, 21.48388863], [87.0891571, 21.48389053], [87.08776855, 21.48250008], [87.08750153, 21.48250008], [87.08583069, 21.48083115], [87.08555603, 21.48083115], [87.08499908, 21.48027802], [87.08444214, 21.48028183], [87.08361053, 21.47972107], [87.08333588, 21.4794445], [87.08277893, 21.4794445], [87.08222961, 21.47893333], [87.08166504, 21.4781189], [87.08110046, 21.47758293], [87.08027649, 21.47722054], [87.08027649, 21.47694397], [87.08000183, 21.4766674], [87.07971954, 21.47666931], [87.07943726, 21.47639084], [87.0789032, 21.47639084], [87.07805634, 21.47555923], [87.07776642, 21.47555923], [87.07704163, 21.47482491], [87.07694244, 21.47471809], [87.07694244, 21.4738884], [87.07444763, 21.47138977], [87.07389069, 21.4711895], [87.0736084, 21.47110939], [87.07333374, 21.47105217], [87.07305908, 21.47105026], [87.07276917, 21.47112083], [87.07250214, 21.47110939], [87.07118225, 21.47090912], [87.07105255, 21.47088051], [87.0708313, 21.47083473], [87.07026672, 21.47083092], [87.06929779, 21.47139549], [87.06902313, 21.47146034], [87.06881714, 21.47167778], [87.06861115, 21.47194672], [87.06777954, 21.47205162], [87.0661087, 21.47278023], [87.06583405, 21.47291183], [87.06548309, 21.47324944], [87.06495667, 21.47377968], [87.0644455, 21.47402954], [87.06419373, 21.47439194], [87.06382751, 21.47465134], [87.06359863, 21.47471809], [87.06276703, 21.47555923], [87.06194305, 21.47639084], [87.06138611, 21.47639084], [87.06111145, 21.47666931], [87.0605545, 21.4766674], [87.06027985, 21.47694397], [87.05999756, 21.4766674], [87.05916595, 21.4766674], [87.0588913, 21.47694397], [87.05833435, 21.47694397], [87.05805206, 21.4766674], [87.0577774, 21.47694397], [87.0533371, 21.47694397], [87.05305481, 21.4766674], [87.05249786, 21.47666931], [87.05222321, 21.47639084], [87.0513916, 21.47639084], [87.05110931, 21.47666931], [87.05000305, 21.47666931], [87.04972076, 21.47680855], [87.04924011, 21.47673988], [87.04888916, 21.4766674], [87.04833221, 21.47666931], [87.04805756, 21.47687912], [87.04750061, 21.47687912], [87.04722595, 21.47666931], [87.04666901, 21.47666931], [87.04638672, 21.47639084], [87.04611206, 21.47639084], [87.04582977, 21.4761219], [87.04556274, 21.4761219], [87.04547119, 21.47602463], [87.04528046, 21.47582817], [87.04499817, 21.47583389], [87.04444122, 21.47527885], [87.04416656, 21.47528076], [87.04379272, 21.47490692], [87.04360962, 21.47471809], [87.04360962, 21.47444534], [87.04332733, 21.47417068], [87.04332733, 21.47360992], [87.04360962, 21.47333336], [87.04360962, 21.47305679], [87.04389191, 21.47277832], [87.04389191, 21.47249985], [87.04380798, 21.47221947], [87.04373932, 21.47201157], [87.04360199, 21.47166443], [87.04389191, 21.47056007], [87.04400635, 21.47044182], [87.04416656, 21.47027779], [87.04416656, 21.46972084], [87.04444122, 21.46944237], [87.04464722, 21.46925163], [87.04499817, 21.46918678], [87.04573822, 21.46899033], [87.04581451, 21.46936798], [87.04582977, 21.46998978], [87.04576874, 21.47027969], [87.04576874, 21.47055435], [87.04582977, 21.47083473], [87.04605103, 21.47110939], [87.04611206, 21.47138977], [87.04611206, 21.47166443], [87.04626465, 21.47194672], [87.04633331, 21.4721508], [87.04611206, 21.47249985], [87.04611969, 21.47277832], [87.04605103, 21.47305679], [87.04611206, 21.47333336], [87.04618073, 21.47375107], [87.04722595, 21.47500038], [87.04839325, 21.4754715], [87.04888916, 21.47527885], [87.04944611, 21.47528076], [87.04972076, 21.47500038], [87.05000305, 21.47500038], [87.05027771, 21.47471809], [87.05083466, 21.47472191], [87.05133057, 21.47439957], [87.05194092, 21.47413445], [87.05263519, 21.47371292], [87.05326843, 21.47335815], [87.0538559, 21.4731102], [87.05444336, 21.47305679], [87.05527496, 21.47359467], [87.05555725, 21.47373962], [87.05610657, 21.47417831], [87.0569458, 21.4742012], [87.05750275, 21.4742012], [87.05805206, 21.47417831], [87.05833435, 21.47418404], [87.05860901, 21.47417641], [87.0588913, 21.47417831], [87.05944824, 21.4738903], [87.0597229, 21.47360992], [87.06083679, 21.47361183], [87.06111145, 21.47333336], [87.06138611, 21.47333336], [87.06194305, 21.47277832], [87.06194305, 21.47249985], [87.0616684, 21.47221947], [87.0616684, 21.47166443], [87.06138611, 21.47138977], [87.06138611, 21.47083092], [87.06222534, 21.46999931], [87.06222534, 21.46694374], [87.06305695, 21.46611023], [87.06305695, 21.46583176], [87.0633316, 21.46555519], [87.0633316, 21.46500015], [87.06359863, 21.46472168], [87.06361389, 21.46444511], [87.06416321, 21.46388817], [87.06305695, 21.46277809], [87.06305695, 21.46222115], [87.0625, 21.46166611], [87.0625, 21.46138954], [87.0616684, 21.46055984], [87.06138611, 21.46055984], [87.06053925, 21.45972061], [87.0597229, 21.45972061], [87.05944824, 21.46000099], [87.05944824, 21.46138954], [87.05916595, 21.46166992], [87.05916595, 21.46277809], [87.05944824, 21.46305466], [87.05916595, 21.46333313], [87.05805206, 21.46333313], [87.0577774, 21.4636116], [87.05722046, 21.4636116], [87.0569458, 21.46333313], [87.05638885, 21.46333313], [87.0561142, 21.4636116], [87.05555725, 21.4636116], [87.05548096, 21.46353722], [87.05527496, 21.46333313], [87.05477905, 21.46320152], [87.05435181, 21.46300888], [87.05393219, 21.46275902], [87.05349731, 21.46247101], [87.05309296, 21.46217155], [87.05275726, 21.46185112], [87.0524292, 21.46158028], [87.05212402, 21.46130371], [87.05179596, 21.46101952], [87.05149078, 21.46066284], [87.05114746, 21.46030235], [87.0508194, 21.45993423], [87.05050659, 21.45957565], [87.05039978, 21.45944786], [87.05023956, 21.45924377], [87.05001068, 21.45895576], [87.0497818, 21.45869827], [87.04944611, 21.45842934], [87.04899597, 21.45824051], [87.04854584, 21.45800972], [87.04815674, 21.45769691], [87.04769897, 21.45741272], [87.04722595, 21.4571209], [87.04682159, 21.45679283], [87.04646301, 21.45644188], [87.04615784, 21.45609665], [87.04588318, 21.45576286], [87.04556274, 21.45546913], [87.04521179, 21.4552002], [87.04482269, 21.45492363], [87.04440308, 21.45463371], [87.04397583, 21.45432854], [87.04351807, 21.45401955], [87.04299927, 21.45368195], [87.04251862, 21.45330238], [87.04202271, 21.45285034], [87.04151154, 21.45243263], [87.04103851, 21.45204353], [87.04063416, 21.45158958], [87.0402298, 21.45116806], [87.03975677, 21.45086098], [87.03926086, 21.45054817], [87.03876495, 21.45025253], [87.03829193, 21.44995117], [87.03785706, 21.44964981], [87.03748322, 21.44933128], [87.03710938, 21.44903183], [87.03678894, 21.44870949], [87.03650665, 21.44836044], [87.03620148, 21.44805145], [87.03585815, 21.44776154], [87.03546143, 21.44748878], [87.03504181, 21.44721985], [87.03462219, 21.44695091], [87.03422546, 21.44669533], [87.03388214, 21.44639969], [87.03349304, 21.44610977], [87.03304291, 21.44580269], [87.032547, 21.44547653], [87.03203583, 21.44516945], [87.03157043, 21.44487381], [87.03118134, 21.44451141], [87.03084564, 21.44411469], [87.03048706, 21.44373131], [87.03006744, 21.44339371], [87.02961731, 21.44302368], [87.02915192, 21.4425869], [87.02864838, 21.44209099], [87.02805328, 21.44166946], [87.02805328, 21.4413929], [87.02749634, 21.44083023], [87.02722168, 21.44083214], [87.02694702, 21.44055557], [87.0266571, 21.44055939], [87.02555847, 21.43944168], [87.02527618, 21.43944359], [87.02500153, 21.43916702], [87.02416992, 21.43917274], [87.02361298, 21.43861008], [87.02333069, 21.43861008], [87.02278137, 21.43805504], [87.02249908, 21.43806267], [87.0222168, 21.43778229], [87.02194214, 21.43778229], [87.0211792, 21.43730164], [87.02057648, 21.4369297], [87.02005768, 21.43658638], [87.01957703, 21.4362812], [87.01911163, 21.43602943], [87.01863861, 21.43575096], [87.01815033, 21.43544006], [87.01767731, 21.43511009], [87.01724243, 21.43473053], [87.01681519, 21.43437195], [87.01638031, 21.4340229], [87.01593781, 21.43370628], [87.01552582, 21.43338013], [87.01512909, 21.43307495], [87.01473236, 21.43279076], [87.01434326, 21.43251038], [87.01396179, 21.43223953], [87.01355743, 21.43196106], [87.01313019, 21.43168068], [87.01267242, 21.43139076], [87.0121994, 21.43109131], [87.01174164, 21.43075371], [87.01131439, 21.4303894], [87.01087189, 21.43008995], [87.0104599, 21.4297924], [87.01004791, 21.42954826], [87.0096817, 21.42926979], [87.00930786, 21.42901039], [87.00895691, 21.42869949], [87.00857544, 21.42841148], [87.00812531, 21.42812538], [87.00763702, 21.42780113], [87.00708771, 21.42744064], [87.00653076, 21.42702293], [87.00591278, 21.42664909], [87.00533295, 21.4262867], [87.00484467, 21.42592239], [87.00435638, 21.42571831], [87.00395966, 21.42550278], [87.0036087, 21.42527962], [87.00305176, 21.42472076], [87.0027771, 21.42472267], [87.00250244, 21.4244442], [87.00222015, 21.4244442], [87.0019455, 21.42416573], [87.00166321, 21.42388916], [87.00138855, 21.42388916], [87.00110626, 21.42361069], [87.0008316, 21.42361069], [87.0002594, 21.42277908], [87.0, 21.42250061], [86.99973297, 21.42222023], [86.99861145, 21.4216671], [86.99833679, 21.42139053], [86.99777985, 21.42111015], [86.99610901, 21.42083359], [86.99555206, 21.42055511], [86.99555206, 21.42028046], [86.9952774, 21.42000008], [86.9952774, 21.4197197], [86.99472046, 21.41916656], [86.99415588, 21.41888046], [86.99333191, 21.41861153], [86.9916687, 21.4169426], [86.99111176, 21.41666412], [86.99054718, 21.41611099], [86.98999786, 21.41584015], [86.98972321, 21.41555977], [86.98916626, 21.41527939], [86.9883194, 21.41500282], [86.9883194, 21.41472054], [86.98694611, 21.41333389], [86.98583221, 21.41277695], [86.98554993, 21.41250038], [86.98500061, 21.41222191], [86.98472595, 21.41194534], [86.98472595, 21.41167259], [86.98361206, 21.4113903], [86.98332977, 21.41110992], [86.98278046, 21.41083336], [86.98278046, 21.41055489], [86.98166656, 21.41055489], [86.98166656, 21.41083336], [86.98110962, 21.41083336], [86.98027802, 21.40999985], [86.98027802, 21.40970993], [86.98000336, 21.40944481], [86.98000336, 21.40916634], [86.97972107, 21.40888977], [86.97972107, 21.40833092], [86.97944641, 21.40805626], [86.97944641, 21.40777969], [86.97915649, 21.40750122], [86.97915649, 21.40722084], [86.97888947, 21.40694427], [86.97888947, 21.40666771], [86.97833252, 21.40611076], [86.97833252, 21.40583038], [86.97750092, 21.40500069], [86.97693634, 21.40472031], [86.97638702, 21.40416718], [86.97583008, 21.40390015], [86.97556305, 21.40361023], [86.97555542, 21.40305328], [86.97528076, 21.40278053], [86.97528076, 21.40250015], [86.97389221, 21.4011097], [86.97333527, 21.40083122], [86.97083282, 21.39833069], [86.97083282, 21.39805603], [86.97027588, 21.39749908], [86.96971893, 21.39722061], [86.96916962, 21.39666748], [86.96861267, 21.39639091], [86.96806335, 21.39582825], [86.96805573, 21.3955555], [86.96721649, 21.39471054], [86.96722412, 21.39444351], [86.96694183, 21.39416885], [86.96611023, 21.39389038], [86.96555328, 21.39332962], [86.96555328, 21.39305687], [86.96305847, 21.39056015], [86.96221924, 21.39027977], [86.96138, 21.38944054], [86.96138763, 21.38916588], [86.95944214, 21.38722038], [86.95944214, 21.38694382], [86.95888519, 21.38666725], [86.95833588, 21.38611031], [86.95833588, 21.3855629], [86.95777893, 21.38500023], [86.95777893, 21.38472176], [86.95722198, 21.38416672], [86.95667267, 21.38388824], [86.95610809, 21.38332748], [86.95527649, 21.38305473], [86.95500183, 21.38277817], [86.95500183, 21.38249969], [86.95417023, 21.38166809], [86.95361328, 21.38138962], [86.95305634, 21.38083076], [86.95305634, 21.38055611], [86.95249939, 21.38000107], [86.95194244, 21.37973022], [86.95083618, 21.37861061], [86.95083618, 21.37833023], [86.95055389, 21.37805367], [86.95054626, 21.37778091], [86.94999695, 21.37750053], [86.94889069, 21.37639046], [86.94777679, 21.3758297], [86.94721985, 21.37527847], [86.94721985, 21.375], [86.94695282, 21.37471962], [86.94694519, 21.37444305], [86.9466629, 21.3741703], [86.9466629, 21.37389183], [86.94610596, 21.37333107], [86.94611359, 21.37305641], [86.9458313, 21.37278175], [86.94526672, 21.37249947], [86.94526672, 21.37221909], [86.94472504, 21.37166595], [86.94473267, 21.37138939], [86.94444275, 21.37111092], [86.94444275, 21.37083054], [86.94416809, 21.37055588], [86.94402313, 21.37041092], [86.9438858, 21.37000084], [86.94330597, 21.3698597], [86.94167328, 21.36750031], [86.94138336, 21.36722183], [86.94055176, 21.36611176], [86.94033813, 21.3659687], [86.94000244, 21.36555099], [86.93916321, 21.3647213], [86.93873596, 21.36444092], [86.93784332, 21.36346817], [86.93776703, 21.36313057], [86.93638611, 21.36139107], [86.93638611, 21.36111069], [86.93611145, 21.36055946], [86.93583679, 21.3602829], [86.93554688, 21.3602829], [86.93499756, 21.35972023], [86.93499756, 21.35944366], [86.93360901, 21.35805511], [86.93332672, 21.35806274], [86.93305206, 21.35778236], [86.93305206, 21.35749817], [86.93222046, 21.35666847], [86.93222046, 21.35610962], [86.9291687, 21.35305786], [86.9291687, 21.35279083], [86.92861176, 21.35222054], [86.92861176, 21.3516674], [86.92804718, 21.35111046], [86.92804718, 21.35083008], [86.92472076, 21.34749985], [86.92472076, 21.34721947], [86.9236145, 21.3461113], [86.92333221, 21.3461113], [86.92028046, 21.34305573], [86.91999817, 21.34306145], [86.91971588, 21.34277916], [86.91944122, 21.34277916], [86.91722107, 21.34056091], [86.91638947, 21.34056091], [86.91583252, 21.34000015], [86.91555786, 21.34000015], [86.9152832, 21.33971977], [86.91333008, 21.33972168], [86.91306305, 21.34000015], [86.91278076, 21.34000015], [86.91249847, 21.34028053], [86.91166687, 21.34028053], [86.91139221, 21.34056091], [86.91110992, 21.34056091], [86.91098022, 21.34042168], [86.9108429, 21.34028053], [86.9108429, 21.33971977], [86.91027832, 21.33916664], [86.91028595, 21.33889008], [86.90999603, 21.3386097], [86.91000366, 21.33694649], [86.91055298, 21.33638954], [86.91055298, 21.33611107], [86.91166687, 21.3350029], [86.91166687, 21.33472061], [86.91139221, 21.33444214], [86.91139221, 21.33416748], [86.91110992, 21.33389282], [86.91110992, 21.33333015], [86.91083527, 21.3330555], [86.9108429, 21.33278275], [86.91055298, 21.33250046], [86.91055298, 21.33222008], [86.91000366, 21.33166695], [86.90999603, 21.33139038], [86.90972137, 21.33111191], [86.90972137, 21.33083344], [86.90944672, 21.33055496], [86.90944672, 21.3302784], [86.90888977, 21.32971954], [86.90888977, 21.32944489], [86.90777588, 21.3283329], [86.90777588, 21.32805634], [86.90389252, 21.32417107], [86.90361023, 21.32417107], [86.90277863, 21.32332993], [86.90277863, 21.32305336], [86.90110016, 21.32139015], [86.90083313, 21.32139015], [86.89861298, 21.31917191], [86.89833069, 21.31917191], [86.89694214, 21.31777954], [86.89666748, 21.31777954], [86.89639282, 21.31749916], [86.89528656, 21.31749916], [86.89499664, 21.31777954], [86.89417267, 21.31777954], [86.89360809, 21.31722069], [86.89305878, 21.3172226], [86.89221954, 21.31638908], [86.89222717, 21.31611061], [86.89194489, 21.31583405], [86.89194489, 21.31500053], [86.89167023, 21.31472015], [86.89167023, 21.31138611], [86.89138794, 21.31110954], [86.89138794, 21.31055641], [86.89111328, 21.31027794], [86.89111328, 21.30972099], [86.89083099, 21.30944252], [86.89083099, 21.30916405], [86.89111328, 21.30888939], [86.89055634, 21.30833054], [86.89055634, 21.30750275], [86.89027405, 21.30722427], [86.89027405, 21.30694389], [86.88999939, 21.30666733], [86.88999939, 21.30611038], [86.88944244, 21.30556107], [86.88944244, 21.30528259], [86.88899994, 21.30483437], [86.88889313, 21.30472565], [86.88861084, 21.30444527], [86.88861084, 21.30417252], [86.88809204, 21.30360413], [86.88804626, 21.30332756], [86.88777924, 21.30305481], [86.88777924, 21.30277824], [86.88749695, 21.30249977], [86.88749695, 21.30194092], [86.88722229, 21.30166626], [86.88722229, 21.30111122], [86.88694763, 21.30083084], [86.88694763, 21.30027771], [86.88680267, 21.30013275], [86.8861084, 21.2994442], [86.8861084, 21.29916763], [86.88582611, 21.29889107], [86.88582611, 21.29861069], [86.88555908, 21.29832077], [86.88555908, 21.29805565], [86.88527679, 21.29778099], [86.88527679, 21.29750061], [86.88500214, 21.29722023], [86.88500214, 21.29694557], [86.88444519, 21.29638863], [86.88445282, 21.29611015], [86.8841629, 21.29583549], [86.8841629, 21.29555321], [86.88388824, 21.29527855], [86.88388824, 21.29500008], [86.88360596, 21.2947197], [86.88361359, 21.29444313], [86.88276672, 21.29360962], [86.88277435, 21.29333115], [86.88194275, 21.29249954], [86.88194275, 21.29221916], [86.88027954, 21.29055595], [86.88028717, 21.29027939], [86.8797226, 21.28972054], [86.8797226, 21.28944397], [86.87750244, 21.28722], [86.87750244, 21.28694534], [86.87526703, 21.28471947], [86.87527466, 21.28444672], [86.87472534, 21.28388977], [86.87472534, 21.2836113], [86.8741684, 21.28305626], [86.87416077, 21.28277969], [86.87388611, 21.28250122], [86.87388611, 21.28222084], [86.87361145, 21.28194237], [86.87361145, 21.2816658], [86.87304688, 21.28111076], [86.87304688, 21.28083038], [86.8722229, 21.28000259], [86.87194824, 21.28000259], [86.8713913, 21.27944183], [86.87110901, 21.27944374], [86.87083435, 21.27916718], [86.87082672, 21.27889252], [86.86972046, 21.27778244], [86.86972046, 21.27750969], [86.86833191, 21.2761097], [86.86833191, 21.27583313], [86.86805725, 21.27555466], [86.86805725, 21.27527809], [86.86833191, 21.27499962], [86.86833191, 21.27472115], [86.86750031, 21.27388954], [86.86750031, 21.27361107], [86.86694336, 21.27305984], [86.86694336, 21.27277946], [86.86638641, 21.27222061], [86.86638641, 21.27194595], [86.86611176, 21.27166748], [86.86611176, 21.27083015], [86.86555481, 21.27027512], [86.86528015, 21.27028084], [86.86499023, 21.27000046], [86.86472321, 21.27000046], [86.86444092, 21.26972008], [86.86444092, 21.26916695], [86.86416626, 21.26889038], [86.86416626, 21.26861], [86.86360931, 21.26805305], [86.86360931, 21.2677803], [86.86305237, 21.26721954], [86.86305237, 21.26694489], [86.86166382, 21.26555634], [86.86165619, 21.26528168], [86.86138916, 21.26499939], [86.86138916, 21.2641716], [86.86055756, 21.26333046], [86.86055756, 21.2630558], [86.85943604, 21.2619381], [86.85944366, 21.26166725], [86.85917664, 21.26139069], [86.85917664, 21.26111031], [86.85888672, 21.26083374], [86.85888672, 21.26055527], [86.85832977, 21.26000023], [86.85832977, 21.25971985], [86.85758972, 21.25760841], [86.85694122, 21.25667], [86.85694122, 21.25611115], [86.85666656, 21.25583076], [86.85666656, 21.2555542], [86.85639191, 21.25527954], [86.85639191, 21.25500107], [86.85500336, 21.25361061], [86.85500336, 21.25333977], [86.85444641, 21.25278282], [86.85444641, 21.25250053], [86.85415649, 21.25222015], [86.85416412, 21.25194359], [86.85444641, 21.25166702], [86.85360718, 21.2508297], [86.85361481, 21.25055504], [86.85333252, 21.25027084], [86.85333252, 21.24999809], [86.85305023, 21.24971962], [86.85305786, 21.24944496], [86.85250092, 21.24888992], [86.85250092, 21.24860954], [86.85277557, 21.24833298], [86.85221863, 21.24777794], [86.85221863, 21.24749947], [86.85166931, 21.24694061], [86.85166931, 21.24666786], [86.85111237, 21.24611092], [86.85111237, 21.24555969], [86.85056305, 21.24500084], [86.85055542, 21.24472237], [86.85028076, 21.2444458], [86.85028076, 21.24388885], [86.84999084, 21.24361038], [86.84999084, 21.24333], [86.84944153, 21.24277687], [86.84944153, 21.24250031], [86.84916687, 21.24221992], [86.84916687, 21.24194527], [86.84860992, 21.24139977], [86.84860992, 21.24110985], [86.84833527, 21.24083138], [86.84833527, 21.24027824], [86.84777832, 21.23971939], [86.84777832, 21.23944473], [86.84750366, 21.23916626], [86.84749603, 21.23888969], [86.84722137, 21.23860931], [86.84722137, 21.23833084], [86.84694672, 21.23805618], [86.84694672, 21.23778152], [86.84638977, 21.23722076], [86.84638977, 21.2369442], [86.84610748, 21.23666573], [86.84610748, 21.23611069], [86.84583282, 21.23583031], [86.84583282, 21.23555565], [86.84527588, 21.23500061], [86.84527588, 21.23472023], [86.84500122, 21.23444366], [86.84500122, 21.23388863], [86.84471893, 21.23361015], [86.84471893, 21.23333359], [86.84444427, 21.23305511], [86.84443665, 21.23278046], [86.84471893, 21.23250008], [86.84500122, 21.23250008], [86.84527588, 21.23221016], [86.84583282, 21.2322216], [86.84610748, 21.23194695], [86.84638977, 21.23195076], [86.84675598, 21.23158455], [86.84889221, 21.2294426], [86.84889221, 21.22888947], [86.84916687, 21.2286129], [86.84916687, 21.22805977], [86.84889221, 21.22777939], [86.84889221, 21.22667122], [86.8483429, 21.22611046], [86.84777832, 21.22667122], [86.84750366, 21.2266674], [86.84722137, 21.22694206], [86.84722137, 21.22722054], [86.84694672, 21.22750282], [86.84694672, 21.22805405], [86.84555817, 21.2294426], [86.8454361, 21.2294426], [86.84500122, 21.2294426], [86.84471893, 21.22972488], [86.84444427, 21.22972488], [86.84417725, 21.22999954], [86.84388733, 21.22999954], [86.84361267, 21.23027992], [86.84333038, 21.22999954], [86.84333038, 21.22972107], [86.84278107, 21.22916412], [86.84278107, 21.22888947], [86.84361267, 21.22805977], [86.84361267, 21.22777939], [86.84378815, 21.2276001], [86.84388733, 21.22750282], [86.84388733, 21.22722054], [86.84361267, 21.22694206], [86.84361267, 21.2266674], [86.84333038, 21.22639275], [86.84333038, 21.22583008], [86.84305573, 21.22555542], [86.84306335, 21.22500038], [86.84278107, 21.22472191], [86.84278107, 21.22416687], [86.84249878, 21.2238884], [86.84249878, 21.22360992], [86.84222412, 21.22333336], [86.84222412, 21.22305489], [86.84194183, 21.22277832], [86.84194183, 21.22138977], [86.84139252, 21.22083092], [86.84139252, 21.22055626], [86.84111023, 21.22027016], [86.84111023, 21.21972275], [86.84055328, 21.21916771], [86.84055328, 21.21861076], [86.84027863, 21.21833038], [86.84027863, 21.21722221], [86.83944702, 21.21639061], [86.83944702, 21.21611023], [86.83972168, 21.21582985], [86.83972168, 21.21527863], [86.83944702, 21.21500015], [86.83944702, 21.21471977], [86.83805847, 21.21333122], [86.83805847, 21.21110916], [86.83833313, 21.2108326], [86.83889008, 21.21083069], [86.83944702, 21.21138954], [86.83944702, 21.21166611], [86.83972168, 21.21194458], [86.83972168, 21.21221924], [86.84027863, 21.21277809], [86.84027863, 21.21305466], [86.84055328, 21.21333122], [86.84055328, 21.21389008], [86.84111023, 21.21445084], [86.84111023, 21.21500015], [86.84166718, 21.21555328], [86.84166718, 21.21582985], [86.84222412, 21.2163887], [86.84221649, 21.21693993], [86.84249878, 21.21722984], [86.84249878, 21.21750069], [86.84305573, 21.21805573], [86.84306335, 21.21861076], [86.84333038, 21.21889114], [86.84333038, 21.21916771], [86.84361267, 21.21944427], [86.84361267, 21.21972275], [86.84416962, 21.22027779], [86.84444427, 21.22027779], [86.84471893, 21.21999931], [86.84500122, 21.22000122], [86.84527588, 21.21972084], [86.84527588, 21.21916771], [86.84500122, 21.21889114], [86.84500122, 21.21833038], [86.84471893, 21.21805573], [86.84471893, 21.21778107], [86.84388733, 21.21693993], [86.84388733, 21.2163887], [86.84333038, 21.21582985], [86.84333038, 21.21555328], [86.84306335, 21.21528053], [86.84306335, 21.21500015], [86.84278107, 21.21472359], [86.84278107, 21.21416664], [86.84194183, 21.21333122], [86.84194183, 21.21305466], [86.84166718, 21.21277809], [86.84166718, 21.21249962], [86.84139252, 21.21221924], [86.84139252, 21.21194458], [86.84111023, 21.21166611], [86.84111023, 21.21109962], [86.84083557, 21.2108326], [86.84083557, 21.21055603], [86.84055328, 21.21027946], [86.84055328, 21.20999908], [86.83999634, 21.20943832], [86.83944702, 21.20944405], [86.83889008, 21.2088871], [86.83889008, 21.20806122], [86.83944702, 21.20750046], [86.83944702, 21.20722008], [86.83777618, 21.20555687], [86.83750153, 21.20583344], [86.83666992, 21.20583344], [86.83638763, 21.20555687], [86.83611298, 21.20555687], [86.83555603, 21.20611191], [86.83528137, 21.20611], [86.83500671, 21.20639038], [86.83416748, 21.20639038], [86.83389282, 21.20611], [86.83361053, 21.20611191], [86.83333588, 21.20583344], [86.83305359, 21.20583344], [86.83222198, 21.20499992], [86.83139038, 21.20499992], [86.83110809, 21.20528984], [86.83082581, 21.20499992], [86.83055878, 21.20499992], [86.82971954, 21.20417023], [86.82971954, 21.20306015], [86.82943726, 21.20277977], [86.82943726, 21.20223045], [86.82917023, 21.20194054], [86.82917023, 21.20153999], [86.82917023, 21.20138931], [86.82888031, 21.20111275], [86.82888031, 21.20083046], [86.82971954, 21.20000267], [86.83000183, 21.20000267], [86.83082581, 21.19916153], [86.83083344, 21.19888878], [86.83110809, 21.19861031], [86.83110809, 21.19778252], [86.83000183, 21.19666862], [86.83027649, 21.19638824], [86.83027649, 21.19610023], [86.83083344, 21.19555473], [86.83055878, 21.19527817], [86.83055878, 21.19444084], [86.83000183, 21.19388962], [86.83000183, 21.19361115], [86.82943726, 21.19305992], [86.82917023, 21.19305611], [86.82888794, 21.19333267], [86.82776642, 21.19333076], [86.82749939, 21.19361115], [86.82749939, 21.19388962], [86.82694244, 21.19444466], [86.82694244, 21.19472122], [86.82666779, 21.19499969], [86.82666779, 21.19527817], [86.82678986, 21.19539833], [86.82749939, 21.19611168], [86.82777405, 21.19611168], [86.82796478, 21.1962986], [86.82805634, 21.19638824], [86.82861328, 21.19638824], [86.82888794, 21.19666672], [86.82888031, 21.19721985], [86.82917023, 21.19750023], [86.82861328, 21.1980629], [86.82776642, 21.1980629], [86.82722473, 21.19861031], [86.8263855, 21.19861031], [86.8263855, 21.19833374], [86.82611084, 21.19805527], [86.82611084, 21.19721985], [86.82555389, 21.19666672], [86.82527924, 21.19666672], [86.82472229, 21.19722176], [86.82389069, 21.19638824], [86.82389069, 21.19582748], [86.82416534, 21.19555473], [86.82416534, 21.19527817], [86.82306671, 21.19416809], [86.82277679, 21.19416809], [86.82250214, 21.19388962], [86.82250214, 21.19333076], [86.82277679, 21.19305611], [86.82277679, 21.19277954], [86.82306671, 21.19250107], [86.82306671, 21.19194031], [86.82333374, 21.19166756], [86.82332611, 21.19111061], [86.82306671, 21.19083023], [86.82305908, 21.19055557], [86.82250214, 21.19000053], [86.82250214, 21.18943977], [86.82221985, 21.18916702], [86.82221985, 21.18889046], [86.82195282, 21.18861008], [86.82194519, 21.1883316], [86.8216629, 21.18805313], [86.8216629, 21.1866703], [86.82138824, 21.18639183], [86.82138824, 21.18528175], [86.82110596, 21.18499947], [86.82110596, 21.18471909], [86.8208313, 21.18444443], [86.8208313, 21.18361092], [86.82055664, 21.18333054], [86.82055664, 21.1827774], [86.82026672, 21.18250084], [86.82026672, 21.18193817], [86.81972504, 21.18138885], [86.81973267, 21.18082809], [86.81916809, 21.18027878], [86.81916809, 21.17945099], [86.8188858, 21.17917061], [86.8188858, 21.17860985], [86.81861115, 21.17833328], [86.81861115, 21.17805672], [86.81916809, 21.17749977], [86.81944275, 21.17749977], [86.82027435, 21.17833328], [86.82055664, 21.17833328], [86.8208313, 21.17861176], [86.82108307, 21.17861176], [86.82138824, 21.17860985], [86.8216629, 21.17889023], [86.82194519, 21.17888832], [86.82211304, 21.17906189], [86.82221985, 21.17917061], [86.82250214, 21.17917061], [86.82277679, 21.17945099], [86.82306671, 21.17945099], [86.82332611, 21.17917061], [86.82389069, 21.17917061], [86.82389069, 21.17860985], [86.82305908, 21.17777824], [86.82306671, 21.17749977], [86.82333374, 21.1772213], [86.8236084, 21.1772213], [86.82416534, 21.17666435], [86.82444763, 21.17667007], [86.82583618, 21.17806053], [86.82611084, 21.17806053], [86.8272171, 21.17694092], [86.82833099, 21.17694664], [86.82833099, 21.17638969], [86.82805634, 21.17611122], [86.82805634, 21.17361069], [86.82694244, 21.17250252], [86.82694244, 21.17222023], [86.82722473, 21.17194366], [86.82722473, 21.1716671], [86.82749939, 21.17139244], [86.82749939, 21.17056274], [86.82666779, 21.1697197], [86.82666779, 21.16944504], [86.82694244, 21.16918182], [86.82694244, 21.1680584], [86.8272171, 21.16777992], [86.8272171, 21.16694069], [86.82694244, 21.16666794], [86.82694244, 21.16500092], [86.82666779, 21.16472054], [86.82666779, 21.1641674], [86.82639313, 21.16389084], [86.82639313, 21.16250038], [86.82583618, 21.16194534], [86.82583618, 21.16055107], [86.82611084, 21.16027832], [86.82611084, 21.15806007], [86.82554626, 21.15749931], [86.82527924, 21.15749931], [86.82513428, 21.15735817], [86.82499695, 21.15722275], [86.82499695, 21.15694427], [86.82472229, 21.15667152], [86.82472229, 21.15611076], [86.82554626, 21.15527916], [86.82554626, 21.15221977], [86.82583618, 21.15194511], [86.82583618, 21.15167046], [86.82554626, 21.15139008], [86.82552338, 21.15051842], [86.82527924, 21.15027809], [86.82527924, 21.14972115], [86.82499695, 21.14944458], [86.82499695, 21.14861107], [86.82417297, 21.14777946], [86.82472229, 21.14722061], [86.82472229, 21.14694214], [86.82499695, 21.14666748], [86.82499695, 21.14611053], [86.82472229, 21.14583015], [86.82472229, 21.14500046], [86.82444763, 21.14472008], [86.82444763, 21.14333344], [86.82472229, 21.14305496], [86.82472229, 21.14138985], [86.82417297, 21.14083099], [86.8236084, 21.1408329], [86.8236084, 21.13999939], [86.82389069, 21.13972092], [86.8236084, 21.13944435], [86.8236084, 21.13888931], [86.82332611, 21.13861084], [86.82332611, 21.13833046], [86.82389069, 21.13777733], [86.82417297, 21.13778114], [86.82666779, 21.13528061], [86.82666779, 21.13500023], [86.82694244, 21.13471985], [86.82694244, 21.13361359], [86.82749939, 21.13305473], [86.82749939, 21.13194466], [86.82777405, 21.13166618], [86.82776642, 21.13056183], [86.82805634, 21.13028145], [86.82805634, 21.12805748], [86.82833099, 21.12778091], [86.82833099, 21.12693977], [86.82805634, 21.12666893], [86.82805634, 21.1258297], [86.82833099, 21.12555695], [86.82833099, 21.12528038], [86.82861328, 21.125], [86.82861328, 21.12445068], [86.82888031, 21.1241703], [86.82888031, 21.12388039], [86.82917023, 21.12361145], [86.82917023, 21.12333488], [86.82944489, 21.12305641], [86.82943726, 21.12277985], [86.83000183, 21.1222229], [86.83000183, 21.12194252], [86.83027649, 21.12166405], [86.83027649, 21.12111282], [86.83055878, 21.12082291], [86.83055878, 21.12055588], [86.83082581, 21.12028122], [86.83082581, 21.11944008], [86.83055878, 21.11916733], [86.83082581, 21.11889267], [86.83055878, 21.11861038], [86.83082581, 21.11861038], [86.83082581, 21.11750031], [86.83110809, 21.11721992], [86.83110809, 21.11694527], [86.83139038, 21.11667061], [86.83139038, 21.11610985], [86.83166504, 21.11583328], [86.83166504, 21.11555481], [86.83194733, 21.11527824], [86.83194733, 21.11444092], [86.83222198, 21.11416626], [86.83222198, 21.11333084], [86.83305359, 21.11249924], [86.83304596, 21.11222076], [86.83333588, 21.1119442], [86.83333588, 21.11166763], [86.83361053, 21.11139107], [86.83361053, 21.11083031], [86.83388519, 21.11055565], [86.83389282, 21.11028099], [86.83416748, 21.11000061], [86.83416748, 21.10972023], [86.83444214, 21.10944557], [86.83444214, 21.10888863], [86.83472443, 21.10861206], [86.83472443, 21.10833168], [86.83499908, 21.10805321], [86.83500671, 21.10750008], [86.83472443, 21.10722351], [86.83472443, 21.10666656], [86.83583069, 21.1055603], [86.83583069, 21.10499954], [86.83555603, 21.10471916], [86.83555603, 21.1044445], [86.83583069, 21.10416603], [86.83583069, 21.10333061], [86.83611298, 21.10305595], [86.83611298, 21.10277939], [86.83666992, 21.10222054], [86.83666992, 21.10194397], [86.83694458, 21.1016674], [86.83693695, 21.10056114], [86.83666992, 21.10028076], [86.83666992, 21.09971046], [86.83694458, 21.09944534], [86.83721924, 21.09945107], [86.83750153, 21.09917068], [86.83777618, 21.09917068], [86.8391571, 21.09778023], [86.8391571, 21.09721947], [86.83944702, 21.09694672], [86.83944702, 21.09638977], [86.83972168, 21.09610939], [86.83972168, 21.09583473], [86.83999634, 21.09555626], [86.83999634, 21.09527969], [86.84055328, 21.09472084], [86.84055328, 21.09444237], [86.84083557, 21.0941658], [86.8408432, 21.09390068], [86.84055328, 21.09361267], [86.84055328, 21.09333038], [86.84111023, 21.09277725], [86.84111023, 21.09250259], [86.84166718, 21.09194183], [86.84166718, 21.09166718], [86.84194183, 21.09139252], [86.84194183, 21.09111023], [86.84221649, 21.09083939], [86.84221649, 21.08999825], [86.84249878, 21.08971977], [86.84249878, 21.08916664], [86.84278107, 21.08888817], [86.84278107, 21.08722115], [86.84305573, 21.08694458], [86.84305573, 21.08666611], [86.84333038, 21.08638954], [86.84333038, 21.08611107], [86.84361267, 21.08583069], [86.84361267, 21.08527756], [86.84388733, 21.08500099], [86.84388733, 21.08444023], [86.84361267, 21.08416748], [86.84361267, 21.08389091], [86.84388733, 21.08361053], [86.84388733, 21.08306122], [86.84417725, 21.08278084], [86.84417725, 21.08222008], [86.84388733, 21.08194542], [86.84388733, 21.08166695], [86.84443665, 21.08111], [86.84471893, 21.08111382], [86.84500122, 21.08083153], [86.84527588, 21.08083153], [86.84555817, 21.08055305], [86.84583282, 21.08056068], [86.84805298, 21.07832909], [86.84805298, 21.07805634], [86.84860992, 21.07749939], [86.84860992, 21.07722092], [86.84889221, 21.07694435], [86.84916687, 21.07666588], [86.84916687, 21.07638931], [86.84944153, 21.07611084], [86.84944153, 21.07583046], [86.84972382, 21.0755558], [86.84971619, 21.07527924], [86.85028076, 21.07472038], [86.85028076, 21.07444382], [86.85055542, 21.07416725], [86.85056305, 21.07389069], [86.85083008, 21.07361031], [86.85083008, 21.07332993], [86.85111237, 21.07305527], [86.85111237, 21.07277107], [86.85138702, 21.07250023], [86.85138702, 21.07139015], [86.85221863, 21.07055092], [86.85221863, 21.07027817], [86.8527832, 21.06973076], [86.8527832, 21.06944084], [86.85305786, 21.06916618], [86.85305023, 21.06888962], [86.85333252, 21.06861115], [86.85333252, 21.06833076], [86.85361481, 21.06805611], [86.85360718, 21.06722069], [86.85388947, 21.06694221], [86.85388947, 21.06666756], [86.85444641, 21.06611061], [86.85444641, 21.06555939], [86.85472107, 21.06528282], [86.85472107, 21.06500244], [86.85527802, 21.06444168], [86.85555267, 21.06444359], [86.85583496, 21.06416702], [86.85582733, 21.06360054], [86.85610962, 21.06333351], [86.85610962, 21.06277847], [86.85639191, 21.06249809], [86.85639191, 21.06195068], [86.85666656, 21.0616684], [86.85666656, 21.06138992], [86.85694122, 21.06110954], [86.85694122, 21.06055641], [86.85721588, 21.06027985], [86.85721588, 21.05972099], [86.85694122, 21.05944443], [86.85694122, 21.05888939], [86.85721588, 21.05861092], [86.85721588, 21.05833054], [86.85749817, 21.05805779], [86.85749817, 21.05779076], [86.85778046, 21.05750084], [86.85778046, 21.05694008], [86.85805511, 21.05666733], [86.85806274, 21.05611038], [86.85832977, 21.05611038], [86.85806274, 21.05583], [86.85805511, 21.05555534], [86.85832977, 21.05528069], [86.85832977, 21.05500031], [86.85917664, 21.05417061], [86.85943604, 21.05417061], [86.86055756, 21.0530529], [86.86055756, 21.05277824], [86.86110687, 21.05221939], [86.8611145, 21.05194473], [86.86166382, 21.0513916], [86.86165619, 21.05110931], [86.86222076, 21.0505619], [86.86222076, 21.05028152], [86.86332703, 21.04917145], [86.86360931, 21.04917145], [86.8638916, 21.04888916], [86.86416626, 21.04888916], [86.86611176, 21.04693985], [86.86611176, 21.04638863], [86.86638641, 21.04611015], [86.86638641, 21.04583359], [86.86777496, 21.04444695], [86.86776733, 21.04417038], [86.86833191, 21.04360962], [86.86833191, 21.04305649], [86.86888885, 21.04249954], [86.86888885, 21.04222107], [86.87000275, 21.0411129], [86.87000275, 21.04083061], [86.8702774, 21.04055595], [86.8702774, 21.04027939], [86.87055206, 21.04000282], [86.87055206, 21.03972054], [86.87083435, 21.03944206], [86.87083435, 21.0391674], [86.87111664, 21.03889275], [86.87111664, 21.03861046], [86.8730545, 21.03666687], [86.8730545, 21.0363884], [86.87361145, 21.03582954], [86.87361145, 21.03555489], [86.87388611, 21.03527832], [86.87388611, 21.03499985], [86.87610626, 21.03277969], [86.87610626, 21.03222084], [86.87666321, 21.03166771], [86.87666321, 21.03139114], [86.87722015, 21.03083038], [86.87722015, 21.03027725], [86.87889099, 21.02861023], [86.87917328, 21.02861023], [86.88083649, 21.02694511], [86.88083649, 21.02667046], [86.88111115, 21.02639008], [86.88111115, 21.0261097], [86.8813858, 21.02583122], [86.8813858, 21.02555466], [86.88166809, 21.02527809], [86.88166809, 21.02499962], [86.88249969, 21.02417183], [86.88249969, 21.02388954], [86.88276672, 21.02360916], [86.88276672, 21.02333069], [86.88361359, 21.02249908], [86.88360596, 21.02222061], [86.8841629, 21.02166748], [86.8841629, 21.02139091], [86.88471985, 21.02083015], [86.88471985, 21.0205555], [86.88500214, 21.02028084], [86.88500214, 21.01972008], [86.88527679, 21.01972198], [86.88583374, 21.01916695], [86.88610077, 21.01917076], [86.88889313, 21.01638985], [86.88889313, 21.01610947], [86.88916779, 21.01583481], [86.88916779, 21.01555634], [86.88944244, 21.01527977], [86.88944244, 21.01499939], [86.8897171, 21.01472282], [86.88972473, 21.01416588], [86.89026642, 21.01361275], [86.89026642, 21.01333046], [86.89055634, 21.0130558], [86.89055634, 21.01278114], [86.89083099, 21.01248932], [86.89083099, 21.01194382], [86.89111328, 21.01166725], [86.89111328, 21.01111031], [86.89138794, 21.01083183], [86.89138794, 21.0102787], [86.89167023, 21.00999832], [86.89167023, 21.00945091], [86.89193726, 21.00917053], [86.89193726, 21.00888824], [86.89332581, 21.00749969], [86.89332581, 21.00722122], [86.89360809, 21.00694466], [86.89360809, 21.00666618], [86.89389038, 21.00638962], [86.89389038, 21.00555992], [86.89417267, 21.00527954], [86.89417267, 21.00500107], [86.89444733, 21.00472069], [86.89444733, 21.00444412], [86.89472198, 21.00416756], [86.89472198, 21.00389099], [86.89528656, 21.00333023], [86.89527893, 21.00305557], [86.89554596, 21.00278091], [86.89554596, 21.00250053], [86.89666748, 21.00139046], [86.89666748, 21.00055122], [86.89666748, 21.00027847], [86.89694214, 21.00000191], [86.89749908, 20.99945068], [86.89749908, 20.9991703], [86.89778137, 20.99889183], [86.89778137, 20.99860954], [86.89861298, 20.99777794], [86.89861298, 20.99694061], [86.89888763, 20.99666595], [86.89888763, 20.99611092], [86.89916992, 20.99583054], [86.89916992, 20.99472237], [86.89944458, 20.99444389], [86.89943695, 20.99417114], [86.89971924, 20.99389076], [86.89971924, 20.99333], [86.90000153, 20.99305534], [86.90000153, 20.99278069], [86.90027618, 20.99250031], [86.90027618, 20.99221992], [86.90055847, 20.99194527], [86.90055847, 20.99110985], [86.90067291, 20.99006081], [86.9016571, 20.98890114], [86.90209961, 20.98749733], [86.9023819, 20.98689079], [86.90294647, 20.98669052], [86.90331268, 20.98641968], [86.90331268, 20.9860096], [86.90316772, 20.98486519], [86.90294647, 20.98411942], [86.90345001, 20.98317719], [86.90400696, 20.98311043], [86.90416718, 20.98237038], [86.90416718, 20.97999954], [86.90444183, 20.97972107], [86.90444183, 20.97916794], [86.90499115, 20.97777939], [86.90585327, 20.97662926], [86.90628052, 20.97616005], [86.90663147, 20.97534943], [86.90670776, 20.9743309], [86.90734863, 20.97338867], [86.90734863, 20.97250938], [86.90749359, 20.97122955], [86.90798187, 20.96980286], [86.90847778, 20.96912193], [86.90854645, 20.96858215], [86.90833282, 20.96804237], [86.90805054, 20.96750259], [86.90783691, 20.96696091], [86.90798187, 20.96662521], [86.90904999, 20.96664047], [86.90956116, 20.96628952], [86.90985107, 20.96587944], [86.9101181, 20.96507263], [86.9101181, 20.96345139], [86.9101944, 20.96298027], [86.91026306, 20.96244049], [86.91026306, 20.9617691], [86.9101181, 20.96142769], [86.90985107, 20.96089172], [86.90990448, 20.96035004], [86.91047668, 20.96006966], [86.91104889, 20.95974159], [86.91104889, 20.95927048], [86.9108429, 20.95880127], [86.9108429, 20.95750237], [86.91055298, 20.95722008], [86.91055298, 20.95638847], [86.91028595, 20.95610809], [86.91000366, 20.95611191], [86.91000366, 20.95583344], [86.91055298, 20.9552784], [86.91110992, 20.9552784], [86.91139221, 20.95499992], [86.91166687, 20.95499992], [86.91194153, 20.95471954], [86.91194153, 20.95444489], [86.91249847, 20.95388794], [86.91249847, 20.95360947], [86.91278076, 20.9533329], [86.91278076, 20.95277786], [86.91249847, 20.95249939], [86.91249847, 20.95111084], [86.91361237, 20.95000076], [86.91361237, 20.94972038], [86.91378784, 20.94891739], [86.91378784, 20.94831085], [86.91414642, 20.94750023], [86.91464996, 20.94696236], [86.91514587, 20.94581413], [86.9153595, 20.9448719], [86.91578674, 20.94425964], [86.91657257, 20.94264412], [86.91693115, 20.94129562], [86.91728973, 20.93981171], [86.91779327, 20.93919945], [86.91835785, 20.93893242], [86.9193573, 20.93866348], [86.91999817, 20.93805695], [86.92056274, 20.9375], [86.92055511, 20.93722153], [86.92082977, 20.93694687], [86.92082977, 20.9366703], [86.92056274, 20.93638992], [86.92056274, 20.93583107], [86.92028046, 20.93555641], [86.92028046, 20.93499947], [86.92056274, 20.9347229], [86.92055511, 20.93444443], [86.92082977, 20.93416405], [86.92082977, 20.93388939], [86.92166901, 20.93305969], [86.92166901, 20.93250275], [86.92193604, 20.93222046], [86.92194366, 20.93194389], [86.92222595, 20.93166733], [86.92222595, 20.93111038], [86.92250061, 20.93083191], [86.92250061, 20.93055534], [86.9227829, 20.93028259], [86.9227829, 20.9299984], [86.92305756, 20.92972183], [86.92305756, 20.92861176], [86.92472076, 20.92694473], [86.92472076, 20.92666626], [86.92582703, 20.92555809], [86.92582703, 20.92527008], [86.92610931, 20.92499924], [86.92610931, 20.92472076], [86.9263916, 20.9244442], [86.9263916, 20.92416573], [86.92694092, 20.92361069], [86.92694092, 20.92333031], [86.92722321, 20.92305565], [86.92722321, 20.92278099], [86.92861176, 20.92139053], [86.92861176, 20.92082977], [86.92888641, 20.92055321], [86.92888641, 20.92000008], [86.9291687, 20.9197197], [86.9291687, 20.91944504], [86.93055725, 20.9180603], [86.93055725, 20.91694069], [86.93083191, 20.91666603], [86.93083191, 20.91638947], [86.93110657, 20.91610909], [86.93110657, 20.91556168], [86.93139648, 20.91527748], [86.93139648, 20.91500092], [86.9319458, 20.91444397], [86.9319458, 20.9141674], [86.93250275, 20.91361046], [86.93250275, 20.91333008], [86.9327774, 20.91305542], [86.9327774, 20.91250038], [86.93305206, 20.91222], [86.9327774, 20.91194534], [86.9327774, 20.9113903], [86.93305206, 20.91110992], [86.93305206, 20.91083336], [86.9338913, 20.90999985], [86.9338913, 20.90971947], [86.93416595, 20.90944481], [86.93416595, 20.90916634], [86.93445587, 20.90888977], [86.93444824, 20.9086113], [86.9347229, 20.90833473], [86.93499756, 20.90833473], [86.93499756, 20.9066658], [86.93527985, 20.90639114], [86.93527985, 20.90583038], [86.9355545, 20.90555573], [86.93554688, 20.90528107], [86.93583679, 20.90500259], [86.93583679, 20.90472031], [86.93638611, 20.90416718], [86.93638611, 20.90389252], [86.9366684, 20.90360832], [86.9366684, 20.90332985], [86.93694305, 20.90305519], [86.93694305, 20.90277863], [86.93723297, 20.90249825], [86.93722534, 20.90222168], [86.9375, 20.90194511], [86.9375, 20.90167046], [86.93888855, 20.90027809], [86.93888855, 20.89916992], [86.93860626, 20.89888954], [86.93860626, 20.89861107], [86.93888855, 20.89833069], [86.93888855, 20.89777756], [86.9383316, 20.89722061], [86.9383316, 20.89694595], [86.9394455, 20.89583588], [86.9394455, 20.8955555], [86.93972015, 20.89529037], [86.94082642, 20.89306068], [86.94108582, 20.89232063], [86.94129944, 20.89145088], [86.94165802, 20.89097023], [86.94237518, 20.89016151], [86.9430542, 20.88972282], [86.94416809, 20.88861084], [86.94416809, 20.88833046], [86.94444275, 20.8880558], [86.94444275, 20.88777924], [86.94452667, 20.8868103], [86.94460297, 20.88626862], [86.94474792, 20.8853302], [86.9451828, 20.88479042], [86.94589233, 20.8841095], [86.94645691, 20.88323402], [86.94681549, 20.88242531], [86.94682312, 20.88167953], [86.94689178, 20.88114357], [86.94745636, 20.88040161], [86.94810486, 20.88019753], [86.94860077, 20.87985992], [86.94895935, 20.87925339], [86.94966888, 20.87851143], [86.95002747, 20.87790489], [86.95083618, 20.87722015], [86.95166779, 20.87638855], [86.95166779, 20.87610817], [86.95194244, 20.87583351], [86.95194244, 20.87555504], [86.95276642, 20.87471962], [86.95277405, 20.87444496], [86.95333099, 20.87388992], [86.95305634, 20.87360954], [86.95305634, 20.87305641], [86.95361328, 20.87249947], [86.95361328, 20.87222099], [86.95417023, 20.87166786], [86.95417023, 20.87083054], [86.95583344, 20.86916733], [86.95582581, 20.86833], [86.95777893, 20.86638832], [86.95777893, 20.86610985], [86.95805359, 20.86583138], [86.95805359, 20.86555481], [86.95888519, 20.86471939], [86.95888519, 20.86444473], [86.95916748, 20.86416626], [86.95916748, 20.8638916], [86.95944214, 20.86360931], [86.95944214, 20.86249924], [86.9597168, 20.86222076], [86.95972443, 20.8619442], [86.95999908, 20.86166573], [86.95999908, 20.86111069], [86.96028137, 20.86083031], [86.96028137, 20.86055565], [86.96055603, 20.86027908], [86.96055603, 20.85972023], [86.96083069, 20.85944366], [86.96083069, 20.8591671], [86.96055603, 20.85889053], [86.96138, 20.85806084], [86.96138, 20.85778046], [86.96166992, 20.85750008], [86.96166992, 20.85639], [86.96193695, 20.85612106], [86.96193695, 20.85472107], [86.96221924, 20.8544445], [86.96225739, 20.85354996], [86.96253967, 20.85280609], [86.96253967, 20.85098267], [86.96282196, 20.85031128], [86.96325684, 20.84922981], [86.96339417, 20.84801674], [86.96353912, 20.84707069], [86.96368408, 20.84612656], [86.96396637, 20.84504128], [86.96453857, 20.84390068], [86.9647522, 20.84289169], [86.96517944, 20.84193993], [86.9653244, 20.84079742], [86.96533203, 20.83971977], [86.96553802, 20.83910942], [86.96575165, 20.8379612], [86.96553802, 20.83721924], [86.9659729, 20.83641052], [86.96639252, 20.83539963], [86.96681976, 20.83466148], [86.96695709, 20.83337021], [86.96717834, 20.83256531], [86.96775055, 20.83128166], [86.9681778, 20.83067322], [86.96868134, 20.8300705], [86.96897125, 20.82925987], [86.96944427, 20.82833481], [86.97000122, 20.82777786], [86.97000122, 20.82639122], [86.97027588, 20.82611275], [86.97027588, 20.82332993], [86.97000122, 20.82305527], [86.97000122, 20.82195091], [86.96971893, 20.82167053], [86.96971893, 20.82138824], [86.96943665, 20.82110977], [86.96944427, 20.82027626], [86.96916962, 20.82000923], [86.96916962, 20.81944084], [86.96888733, 20.81916618], [86.96888733, 20.81888962], [86.96861267, 20.81861115], [86.96861267, 20.81805992], [86.96833038, 20.81777954], [86.96833038, 20.81666946], [86.96806335, 20.81639099], [86.96806335, 20.81583023], [86.96778107, 20.81555557], [86.96778107, 20.81472015], [86.96749878, 20.81444168], [86.96749878, 20.81388855], [86.96722412, 20.81361389], [86.96722412, 20.81222343], [86.96694183, 20.81194496], [86.96694183, 20.81081963], [86.96666718, 20.81055641], [86.96666718, 20.80861092], [86.96639252, 20.80833054], [86.96639252, 20.80750084], [86.96611023, 20.80722046], [86.96611023, 20.80500031], [86.9658432, 20.80471992], [86.96583557, 20.80361176], [86.96555328, 20.80333328], [86.96555328, 20.80277824], [86.96527863, 20.80249977], [86.96466827, 20.80175018], [86.96466827, 20.80025864], [86.96472168, 20.79916573], [86.96472168, 20.79805946], [86.96443939, 20.7977829], [86.96472168, 20.79750252], [86.96443939, 20.79722023], [86.96444702, 20.7966671], [86.96414948, 20.79638863], [86.96414948, 20.79527855], [86.96389008, 20.79499817], [86.96389008, 20.7947197], [86.96416473, 20.79444504], [86.96414948, 20.79417038], [86.96389008, 20.79388809], [86.96389008, 20.79360962], [86.96360779, 20.79333305], [86.96360779, 20.79249954], [86.96333313, 20.79222107], [86.96333313, 20.79166794], [86.96305847, 20.79138947], [86.96305847, 20.79111099], [86.96277618, 20.79083061], [86.96277618, 20.79055405], [86.96260834, 20.7903862], [86.96250153, 20.79027748], [86.96250153, 20.79000092], [86.96221924, 20.78971291], [86.96221924, 20.78944588], [86.96111298, 20.7883358], [86.96111298, 20.78805542], [86.95804596, 20.78500175], [86.95777893, 20.78500175], [86.95749664, 20.78471947], [86.95722198, 20.78500175], [86.95639038, 20.78500175], [86.95582581, 20.78443909], [86.95556641, 20.78443909], [86.95471954, 20.78528023], [86.95444489, 20.78527832], [86.95417023, 20.78555489], [86.95388794, 20.78555489], [86.95333099, 20.78611374], [86.95276642, 20.78611183], [86.95249939, 20.7863903], [86.95194244, 20.7863903], [86.95166779, 20.78667068], [86.95111084, 20.78666687], [86.95083618, 20.78694534], [86.95055389, 20.78694534], [86.95027924, 20.78722382], [86.94917297, 20.78722], [86.94889069, 20.78750038], [86.94805908, 20.78750038], [86.94777679, 20.78778076], [86.94721985, 20.78778076], [86.94695282, 20.78806114], [86.9466629, 20.78805542], [86.94638824, 20.7883358], [86.94555664, 20.78833008], [86.94527435, 20.78861046], [86.94473267, 20.78861046], [86.94444275, 20.78889084], [86.9438858, 20.78889084], [86.94361115, 20.78917122], [86.9430542, 20.7891674], [86.94277954, 20.78944588], [86.9422226, 20.78944588], [86.94194794, 20.78972244], [86.94026947, 20.78971291], [86.94000244, 20.79000092], [86.93972015, 20.79000092], [86.93945313, 20.79027939], [86.93527985, 20.79027939], [86.93499756, 20.79055977], [86.93333435, 20.79055405], [86.93305206, 20.79083252], [86.93083191, 20.79083252], [86.93055725, 20.79055405], [86.92973328, 20.79055977], [86.92944336, 20.79027939], [86.9291687, 20.79027939], [86.92888641, 20.79055977], [86.92583466, 20.79055405], [86.92555237, 20.79083252], [86.92527771, 20.79083252], [86.92500305, 20.79055405], [86.92388916, 20.79055405], [86.9236145, 20.79083252], [86.92166901, 20.79083252], [86.92138672, 20.79055405], [86.92111206, 20.79055405], [86.92082977, 20.79083252], [86.91944122, 20.79083061], [86.91916656, 20.79111099], [86.91805267, 20.79111099], [86.91777802, 20.79138947], [86.91694641, 20.79138947], [86.91665649, 20.79166985], [86.91583252, 20.79166794], [86.91555786, 20.7919445], [86.91500092, 20.7919445], [86.91471863, 20.79222298], [86.90999603, 20.79222107], [86.90972137, 20.79249954], [86.90305328, 20.79249954], [86.90277863, 20.79277992], [86.90249634, 20.79277992], [86.90222168, 20.7930603], [86.9016571, 20.7930603], [86.90110016, 20.79249954], [86.90055847, 20.79249954], [86.90027618, 20.79277992], [86.89833069, 20.79277992], [86.89805603, 20.7930603], [86.89666748, 20.79305649], [86.89638519, 20.79333305], [86.89499664, 20.79333305], [86.89472198, 20.79361153], [86.89417267, 20.79360962], [86.89389038, 20.79388809], [86.89332581, 20.79388809], [86.89305878, 20.79417038], [86.89193726, 20.79417038], [86.89167023, 20.79445076], [86.89055634, 20.79445076], [86.89026642, 20.79417038], [86.88944244, 20.79417038], [86.88916016, 20.79445076], [86.88833618, 20.79444504], [86.88805389, 20.7947216], [86.88722229, 20.7947197], [86.88694763, 20.79499817], [86.88639069, 20.79499817], [86.88610077, 20.79527855], [86.88582611, 20.79527855], [86.88555908, 20.79556084], [86.88527679, 20.79556084], [86.88500214, 20.79583931], [86.88471985, 20.79583359], [86.88444519, 20.79611015], [86.8841629, 20.79610825], [86.88388824, 20.79638863], [86.88360596, 20.79638863], [86.8833313, 20.79667282], [86.88305664, 20.7966671], [86.88277435, 20.79694366], [86.88222504, 20.79694366], [86.88194275, 20.79722023], [86.88166809, 20.79722023], [86.8813858, 20.79750252], [86.87944794, 20.79638863], [86.87917328, 20.79638863], [86.87889099, 20.79610825], [86.87808228, 20.79610825], [86.8769455, 20.79611015], [86.87666321, 20.79583359], [86.87638855, 20.79583931], [86.87610626, 20.79556084], [86.8758316, 20.79556084], [86.87555695, 20.79527855], [86.87361145, 20.79527855], [86.87333679, 20.79499817], [86.87277985, 20.79499817], [86.87249756, 20.7947197], [86.87166595, 20.7947216], [86.8713913, 20.79444504], [86.87068176, 20.79445076], [86.87055206, 20.79445076], [86.8702774, 20.79417038], [86.86972046, 20.79417038], [86.8694458, 20.79388809], [86.86860657, 20.79388809], [86.86833191, 20.79360962], [86.86805725, 20.79361153], [86.86798096, 20.79353714], [86.86777496, 20.79333305], [86.86750031, 20.79333305], [86.86722565, 20.79305649], [86.8666687, 20.7930603], [86.86638641, 20.79277992], [86.86611176, 20.79277992], [86.8658371, 20.79249954], [86.86528015, 20.79249954], [86.86499023, 20.79222107], [86.86444092, 20.79222298], [86.86416626, 20.7919445], [86.8638916, 20.7919445], [86.86360931, 20.79166794], [86.86332703, 20.79166985], [86.86277771, 20.79111099], [86.86250305, 20.79111099], [86.86222076, 20.79083061], [86.86194611, 20.79083252], [86.86138916, 20.79027748], [86.86110687, 20.79027939], [86.86083221, 20.79000092], [86.86055756, 20.79000092], [86.8602829, 20.78971291], [86.86000061, 20.78972244], [86.85944366, 20.7891674], [86.85917664, 20.78917122], [86.85806274, 20.78806114], [86.85778046, 20.78806114], [86.85721588, 20.78750038], [86.85694122, 20.78750038], [86.85666656, 20.78722], [86.85610962, 20.78722382], [86.85527802, 20.7863884], [86.85500336, 20.7863903], [86.8548584, 20.78624916], [86.85472107, 20.78611374], [86.85444641, 20.78611374], [86.85434723, 20.78601456], [86.85416412, 20.78583145], [86.85388947, 20.78583145], [86.85361481, 20.78555489], [86.85333252, 20.78555489], [86.85305786, 20.78527832], [86.8527832, 20.78528023], [86.85221863, 20.78471947], [86.85194397, 20.78471947], [86.85138702, 20.78416634], [86.85111237, 20.78417015], [86.85083008, 20.78390121], [86.85056305, 20.78417015], [86.85028076, 20.78390121], [86.84999084, 20.78390121], [86.84916687, 20.78306007], [86.8483429, 20.78306007], [86.84777832, 20.78249931], [86.84749603, 20.78249931], [86.84722137, 20.78222084], [86.84694672, 20.78222275], [86.84684753, 20.78212738], [86.84666443, 20.78194427], [86.84638977, 20.78194427], [86.84625244, 20.78180885], [86.84610748, 20.7816658], [86.84555817, 20.78166771], [86.84527588, 20.78138924], [86.84500122, 20.78138924], [86.84471893, 20.78111076], [86.84416962, 20.78111076], [86.84388733, 20.7808342], [86.84361267, 20.78083992], [86.84333038, 20.78055954], [86.84278107, 20.78055954], [86.84249878, 20.78028107], [86.84221649, 20.78028107], [86.84194183, 20.78000069], [86.84139252, 20.78000069], [86.84111023, 20.77972031], [86.84083557, 20.77972221], [86.84055328, 20.77944374], [86.84027863, 20.77944374], [86.83999634, 20.77916718], [86.83944702, 20.77917099], [86.83889008, 20.77861023], [86.83860779, 20.77861023], [86.83833313, 20.77832985], [86.83805847, 20.77833366], [86.83777618, 20.77805519], [86.83721924, 20.77806091], [86.83693695, 20.777771], [86.83666992, 20.77777863], [86.83638763, 20.77750015], [86.83611298, 20.77750015], [86.83583069, 20.77721977], [86.83555603, 20.77722168], [86.83528137, 20.77694511], [86.83500671, 20.77695084], [86.8347168, 20.77667046], [86.83444214, 20.77667046], [86.83389282, 20.7761116], [86.83333588, 20.77555084], [86.83305359, 20.77555466], [86.83249664, 20.77499962], [86.83222198, 20.77499962], [86.83139038, 20.77416992], [86.83110809, 20.77416992], [86.83082581, 20.77388954], [86.83055878, 20.77388954], [86.83027649, 20.77361107], [86.83027649, 20.77333069], [86.82971954, 20.77277756], [86.82943726, 20.77277946], [86.82917023, 20.7725029], [86.82888031, 20.7725029], [86.82805634, 20.77166939], [86.82776642, 20.77166939], [86.82485962, 20.76874924], [86.82195282, 20.76583099], [86.82194519, 20.76555634], [86.82157135, 20.7651844], [86.8208313, 20.76444435], [86.8208313, 20.76416779], [86.82055664, 20.76389122], [86.82055664, 20.76361084], [86.82000732, 20.76305962], [86.82000732, 20.7627697], [86.8188858, 20.76166725], [86.8188858, 20.76139069], [86.81804657, 20.76056099], [86.81804657, 20.76028061], [86.81777954, 20.76000023], [86.81777954, 20.75972939], [86.81749725, 20.75945091], [86.81749725, 20.75917053], [86.8172226, 20.75889015], [86.8172226, 20.75832939], [86.81694794, 20.75805473], [86.81694794, 20.7575016], [86.81667328, 20.75721931], [86.81666565, 20.75694466], [86.81639099, 20.75666618], [86.81639099, 20.75639153], [86.8161087, 20.75610924], [86.8161087, 20.75444031], [86.81583405, 20.75416756], [86.81582642, 20.75360107], [86.81555176, 20.75333405], [86.81555176, 20.75305557], [86.81532288, 20.75282097], [86.8152771, 20.75250053], [86.81500244, 20.75222015], [86.81500244, 20.75138855], [86.81472015, 20.75111008], [86.81472015, 20.75083351], [86.8133316, 20.74944687], [86.8133316, 20.7491703], [86.81305695, 20.74888992], [86.81305695, 20.74860954], [86.81277466, 20.74833488], [86.81277466, 20.74805641], [86.81356049, 20.7462101], [86.81369781, 20.74588776], [86.81412506, 20.74494362], [86.8146286, 20.74372864], [86.81576538, 20.74420166], [86.81666565, 20.74444389], [86.81694031, 20.74444008], [86.81749725, 20.74500275], [86.81777954, 20.74500275], [86.81861115, 20.74417114], [86.81861115, 20.74389267], [86.81833649, 20.74361038], [86.81861115, 20.74332809], [86.81861115, 20.74027634], [86.81833649, 20.73999977], [86.81833649, 20.73859978], [86.8180542, 20.73833275], [86.81807709, 20.7378006], [86.81778717, 20.73624039], [86.81771088, 20.73496246], [86.81771088, 20.73347664], [86.81742859, 20.73266983], [86.81749725, 20.73110962], [86.81749725, 20.72999954], [86.8172226, 20.72971916], [86.8172226, 20.7294445], [86.81694794, 20.72916603], [86.81694031, 20.72889137], [86.81667328, 20.72860909], [86.81666565, 20.72833252], [86.81639099, 20.72805595], [86.81639099, 20.72722054], [86.8161087, 20.72694397], [86.8161087, 20.72611046], [86.81639099, 20.72583008], [86.8161087, 20.72555542], [86.8161087, 20.72442055], [86.8161087, 20.7238884], [86.81555176, 20.72332954], [86.81555176, 20.72277832], [86.8152771, 20.72249985], [86.8152771, 20.72221947], [86.81500244, 20.72194481], [86.81500244, 20.72166634], [86.81416321, 20.72083282], [86.81388855, 20.72083473], [86.81361389, 20.72055626], [86.8133316, 20.72056007], [86.81305695, 20.72027969], [86.81276703, 20.72027969], [86.80665588, 20.71417046], [86.80665588, 20.71388817], [86.8033371, 20.71055984], [86.80207825, 20.70965958], [86.80136108, 20.70885468], [86.80065155, 20.70777321], [86.80014801, 20.70656013], [86.79972076, 20.7052803], [86.79972076, 20.70471954], [86.79916382, 20.70416641], [86.79915619, 20.70389175], [86.79860687, 20.70332909], [86.7986145, 20.70305634], [86.79805756, 20.70248985], [86.79805756, 20.70222282], [86.79722595, 20.70138741], [86.79722595, 20.70111084], [86.79638672, 20.70028114], [86.79638672, 20.70000076], [86.7958374, 20.69943047], [86.79582977, 20.69916725], [86.79556274, 20.69889069], [86.79556274, 20.69861031], [86.79499817, 20.69805527], [86.79499817, 20.69778061], [86.79444122, 20.69721985], [86.79444122, 20.69666672], [86.79416656, 20.69639015], [86.79416656, 20.69610977], [86.79389191, 20.69583321], [86.79389191, 20.69555473], [86.79360962, 20.69527817], [86.79360962, 20.69499969], [86.79332733, 20.69472122], [86.79333496, 20.69416618], [86.79305267, 20.69388962], [86.79305267, 20.69333076], [86.79277802, 20.69305611], [86.79277802, 20.69277954], [86.79250336, 20.69250107], [86.79250336, 20.69194031], [86.79222107, 20.69166756], [86.79222107, 20.6913929], [86.79194641, 20.69111252], [86.79194641, 20.69055176], [86.79166412, 20.6902771], [86.79165649, 20.69000244], [86.79138947, 20.68971825], [86.79138947, 20.68944359], [86.79111481, 20.68916702], [86.79110718, 20.68860817], [86.79083252, 20.68833351], [86.79083252, 20.68805504], [86.79055786, 20.68778038], [86.79055786, 20.68721962], [86.79027557, 20.68694496], [86.7902832, 20.6866703], [86.79000092, 20.68638992], [86.79000092, 20.68583107], [86.78971863, 20.68555641], [86.789711, 20.68527985], [86.78943634, 20.68499947], [86.78943634, 20.68445015], [86.78916931, 20.68416977], [86.78916931, 20.68388939], [86.78888702, 20.68361092], [86.78888702, 20.68305969], [86.78861237, 20.68278122], [86.78861237, 20.68250084], [86.78833008, 20.68222046], [86.78833008, 20.68138885], [86.78806305, 20.68111038], [86.78805542, 20.68083382], [86.78833008, 20.68055534], [86.78833008, 20.68028069], [86.78861237, 20.68000031], [86.78861237, 20.67861176], [86.78888702, 20.67833138], [86.78888702, 20.67805481], [86.78861237, 20.67777824], [86.78861237, 20.67721939], [86.78833008, 20.67694473], [86.78833008, 20.67666626], [86.78861237, 20.6763916], [86.78861237, 20.67528152], [86.78833008, 20.67499924], [86.78833008, 20.67472076], [86.78805542, 20.6744442], [86.78805542, 20.67416573], [86.78778076, 20.67388916], [86.78778076, 20.67361069], [86.78749847, 20.67333031], [86.78749847, 20.67277718], [86.78721619, 20.67250824], [86.78721619, 20.67222023], [86.78694153, 20.67194366], [86.78694153, 20.67166519], [86.78610992, 20.67082977], [86.78610992, 20.67055511], [86.78555298, 20.67000008], [86.78555298, 20.66945076], [86.78499603, 20.66889], [86.78499603, 20.66860962], [86.78444672, 20.66805649], [86.78444672, 20.66777992], [86.7838974, 20.66722107], [86.78388977, 20.66666603], [86.78360748, 20.66638184], [86.78360748, 20.6661129], [86.78277588, 20.66527939], [86.78277588, 20.66500282], [86.78083801, 20.66306114], [86.78083801, 20.66278076], [86.77971649, 20.66167068], [86.77944183, 20.66167068], [86.77861023, 20.66082954], [86.77833557, 20.66083336], [86.77805328, 20.66055489], [86.77777863, 20.66055489], [86.77500153, 20.65777779], [86.77500153, 20.65751076], [86.77471161, 20.65722084], [86.77471924, 20.65694427], [86.77388763, 20.65611076], [86.77388763, 20.65583038], [86.77278137, 20.65472221], [86.77278137, 20.65444565], [86.77222443, 20.6538887], [86.7722168, 20.65361023], [86.77194214, 20.65332985], [86.77194214, 20.65305519], [86.77166748, 20.65278053], [86.77166748, 20.65250015], [86.77083588, 20.65167046], [86.77083588, 20.65137863], [86.77027893, 20.65083122], [86.77027893, 20.65055466], [86.76999664, 20.65027809], [86.76999664, 20.64971924], [86.76833344, 20.64805603], [86.76832581, 20.64777756], [86.76805878, 20.64749908], [86.76805878, 20.64722061], [86.76777649, 20.64694405], [86.76777649, 20.64666748], [86.76750183, 20.64639091], [86.76750183, 20.64611053], [86.76721954, 20.64583015], [86.76721954, 20.64527512], [86.76693726, 20.64500046], [86.76693726, 20.64472008], [86.76667023, 20.64444351], [86.76667023, 20.63944435], [86.76638794, 20.63916588], [86.76638794, 20.63694191], [86.76618958, 20.63487434], [86.76597595, 20.63224411], [86.76583862, 20.63008499], [86.76541138, 20.62799072], [86.7650528, 20.62650871], [86.76416779, 20.62471962], [86.76416779, 20.62444496], [86.76361084, 20.62389183], [86.76361084, 20.62360954], [86.76249695, 20.62249947], [86.76249695, 20.62221909], [86.76194763, 20.62166595], [86.76194763, 20.62111092], [86.76139069, 20.62055969], [86.76139069, 20.62028122], [86.76055908, 20.61944008], [86.76055908, 20.61916733], [86.75972748, 20.61833], [86.75944519, 20.61833382], [86.75805664, 20.61694527], [86.75776672, 20.61695099], [86.75749969, 20.61667061], [86.75723267, 20.61667061], [86.75694275, 20.61639023], [86.7563858, 20.61639023], [86.75624847, 20.61624908], [86.75611115, 20.61610985], [86.75583649, 20.61611176], [86.75577545, 20.61449242], [86.75569916, 20.61388206], [86.75569916, 20.61334419], [86.75741577, 20.61355019], [86.75805664, 20.61388969], [86.7583313, 20.61417007], [86.75888824, 20.61416626], [86.7591629, 20.61444473], [86.75971985, 20.61444473], [86.76000214, 20.6147213], [86.76027679, 20.61471939], [86.76055908, 20.61499977], [86.76083374, 20.61499977], [86.7611084, 20.61527824], [86.76139069, 20.61527824], [86.76166534, 20.61555481], [86.76194763, 20.61555099], [86.76277161, 20.61639023], [86.76304626, 20.61639023], [86.76333618, 20.61667061], [86.76361084, 20.61667061], [86.76389313, 20.61695099], [86.76416779, 20.61695099], [86.76583099, 20.61861038], [86.76583099, 20.61889076], [86.76750183, 20.62055588], [86.76750183, 20.62083054], [86.76777649, 20.62111092], [86.76777649, 20.62138748], [86.76860809, 20.62221909], [86.76860809, 20.62249947], [86.76889038, 20.62277985], [86.76889038, 20.62333107], [86.76917267, 20.62360954], [86.76917267, 20.6241703], [86.76944733, 20.62444496], [86.76944733, 20.62471962], [86.76999664, 20.62527847], [86.76999664, 20.6258297], [86.77083588, 20.62667084], [86.77083588, 20.62750053], [86.77111053, 20.62778091], [86.77111053, 20.62805557], [86.77138519, 20.62833595], [86.77139282, 20.62972069], [86.77166748, 20.62999916], [86.77166748, 20.63027], [86.77194214, 20.63055992], [86.77194214, 20.63166618], [86.77166748, 20.63194466], [86.77194214, 20.63222122], [86.77194214, 20.63277626], [86.77222443, 20.63305473], [86.7722168, 20.63360977], [86.77194214, 20.63388824], [86.77194214, 20.63444519], [86.77166748, 20.63471985], [86.77166748, 20.63528061], [86.77138519, 20.63555527], [86.77139282, 20.63582993], [86.77111053, 20.6361084], [86.77166748, 20.63666725], [86.77166748, 20.63722038], [86.77139282, 20.63750267], [86.77166748, 20.63778114], [86.77166748, 20.6380558], [86.77139282, 20.63833046], [86.77139282, 20.63889122], [86.77153015, 20.64017105], [86.77138519, 20.64166641], [86.77111053, 20.64194489], [86.77111053, 20.64221001], [86.77194214, 20.64305687], [86.77194214, 20.64361], [86.7722168, 20.64389038], [86.7722168, 20.64417076], [86.77305603, 20.64500046], [86.77333069, 20.64500046], [86.77361298, 20.64528084], [86.77555847, 20.64528084], [86.77583313, 20.64557076], [86.77722168, 20.64557076], [86.77749634, 20.64528084], [86.77916718, 20.64528084], [86.77944183, 20.64500046], [86.77999878, 20.64500046], [86.78056335, 20.6444397], [86.78083038, 20.64444351], [86.78111267, 20.64416695], [86.78138733, 20.64417076], [86.78193665, 20.64361], [86.78194427, 20.64333344], [86.78221893, 20.64305687], [86.78250122, 20.64306068], [86.78277588, 20.6427803], [86.78305817, 20.6427784], [86.78324127, 20.64296341], [86.78360748, 20.64333344], [86.78416443, 20.6427784], [86.78472137, 20.6427803], [86.78499603, 20.64306068], [86.78555298, 20.64305687], [86.78583527, 20.64333344], [86.78833008, 20.64333344], [86.78861237, 20.64361191], [86.79055786, 20.64361], [86.79083252, 20.64389038], [86.79110718, 20.64389038], [86.79138947, 20.64417076], [86.79166412, 20.64416695], [86.79187012, 20.64436913], [86.79194641, 20.64444351], [86.79250336, 20.6444397], [86.79305267, 20.64500046], [86.79416656, 20.64500046], [86.79444122, 20.64528084], [86.79499817, 20.64528084], [86.79528046, 20.64500046], [86.79722595, 20.64500046], [86.79750061, 20.64472008], [86.79777527, 20.64472198], [86.79805756, 20.64444351], [86.7986145, 20.64444351], [86.79916382, 20.64388847], [86.79973602, 20.64394379], [86.79988098, 20.64390755], [86.8001709, 20.64383888], [86.80062866, 20.6437397], [86.80116272, 20.64381027], [86.80171967, 20.64385033], [86.80231476, 20.64386177], [86.80291748, 20.64387131], [86.80350494, 20.64387321], [86.80405426, 20.64384842], [86.80452728, 20.64376068], [86.80497742, 20.64362907], [86.80555725, 20.64361], [86.80583191, 20.64333344], [86.8069458, 20.64333344], [86.80722046, 20.64305687], [86.80750275, 20.64306068], [86.8077774, 20.6427803], [86.80805206, 20.6427803], [86.80860901, 20.64221001], [86.8088913, 20.64222145], [86.80999756, 20.64111137], [86.80999756, 20.64083481], [86.81027985, 20.64055634], [86.81027985, 20.64027977], [86.81083679, 20.63972282], [86.81083679, 20.63944435], [86.81111145, 20.63916588], [86.81134033, 20.63888168], [86.8117218, 20.63856316], [86.81212616, 20.63824654], [86.81254578, 20.6379509], [86.81297302, 20.63764954], [86.81344604, 20.63739586], [86.81396484, 20.63713074], [86.81459808, 20.63686943], [86.81524658, 20.63661194], [86.81552887, 20.6364727], [86.81587219, 20.63640022], [86.81636047, 20.63635445], [86.81687927, 20.63645935], [86.81731415, 20.63668442], [86.81771851, 20.63694191], [86.81816101, 20.63722038], [86.81861115, 20.63754082], [86.81903839, 20.63791084], [86.81945038, 20.63832092], [86.81985474, 20.63874817], [86.82022858, 20.6391716], [86.82055664, 20.63958359], [86.8208313, 20.63997269], [86.82105255, 20.64035034], [86.8212204, 20.64074707], [86.82142639, 20.64112663], [86.82164764, 20.64147949], [86.82187653, 20.64183807], [86.82211304, 20.64217949], [86.82227325, 20.64253044], [86.82242584, 20.64286995], [86.82254791, 20.64322853], [86.82267761, 20.64359283], [86.82279968, 20.64397621], [86.82290649, 20.6443882], [86.82301331, 20.64487839], [86.82306671, 20.64541054], [86.82306671, 20.64597511], [86.82298279, 20.64651108], [86.82283783, 20.64703178], [86.82264709, 20.64749908], [86.82247162, 20.64793587], [86.82229614, 20.64834023], [86.82216644, 20.64874268], [86.822052, 20.64912033], [86.82190704, 20.64946747], [86.82177734, 20.64977837], [86.82162476, 20.6500473], [86.82147217, 20.65030098], [86.82131958, 20.6505661], [86.82115173, 20.6508007], [86.82097626, 20.6510601], [86.82083893, 20.65133286], [86.8207016, 20.65160179], [86.82057953, 20.65190125], [86.82047272, 20.6522007], [86.82034302, 20.65249252], [86.82021332, 20.65278053], [86.82006836, 20.65304947], [86.81991577, 20.65335464], [86.81970215, 20.6536808], [86.81942749, 20.6540699], [86.81909943, 20.65454102], [86.81877136, 20.65510368], [86.81848145, 20.65571976], [86.81819153, 20.65631104], [86.81794739, 20.65683937], [86.81772614, 20.65732956], [86.81751251, 20.65777969], [86.81730652, 20.65824127], [86.81710815, 20.65871429], [86.81694031, 20.65921021], [86.81677246, 20.65975189], [86.81656647, 20.66027641], [86.81630707, 20.6607399], [86.81601715, 20.66114998], [86.81574249, 20.66151047], [86.81547546, 20.66187859], [86.81521606, 20.66224289], [86.81495667, 20.66261101], [86.81468201, 20.66294861], [86.81439972, 20.66331482], [86.81408691, 20.66365814], [86.81373596, 20.66396713], [86.81334686, 20.66422081], [86.81299591, 20.66451263], [86.81265259, 20.66483116], [86.81226349, 20.66513252], [86.81185913, 20.66540146], [86.81147766, 20.66573906], [86.8110733, 20.66609955], [86.81060791, 20.66643524], [86.81013489, 20.66676331], [86.80961609, 20.66703033], [86.80912018, 20.66727066], [86.8086319, 20.66750145], [86.80817413, 20.66774368], [86.80771637, 20.66798019], [86.80724335, 20.66819954], [86.80666351, 20.66833305], [86.80638885, 20.66861153], [86.80610657, 20.66860962], [86.80583191, 20.66889], [86.80500031, 20.66889], [86.80473328, 20.66917038], [86.80361176, 20.66917038], [86.8033371, 20.66889], [86.80194092, 20.66889], [86.80180359, 20.66875076], [86.80166626, 20.66861153], [86.8013916, 20.66861153], [86.80097198, 20.66819572], [86.80055237, 20.66777802], [86.80055237, 20.66749954], [86.79915619, 20.6661129], [86.79915619, 20.66583061], [86.79869843, 20.66535759], [86.79837036, 20.66505051], [86.79802704, 20.6648407], [86.7976532, 20.66476059], [86.79727173, 20.66480064], [86.79695892, 20.66493797], [86.79672241, 20.66519928], [86.79650879, 20.66557121], [86.7963028, 20.66604996], [86.79618073, 20.66666985], [86.79612732, 20.66736984], [86.79613495, 20.66810036], [86.79621124, 20.66883278], [86.79638672, 20.66953087], [86.7966156, 20.67018509], [86.79686737, 20.67074013], [86.79709625, 20.67123985], [86.79733276, 20.67168045], [86.79762268, 20.67208099], [86.79795837, 20.67250633], [86.79831696, 20.67287254], [86.7986908, 20.67311859], [86.79907227, 20.67337036], [86.79946136, 20.6736908], [86.79988861, 20.6740284], [86.80039978, 20.67435455], [86.8010025, 20.67466354], [86.80164337, 20.67494965], [86.80223846, 20.67521095], [86.80285645, 20.67538071], [86.80345917, 20.67547035], [86.80397797, 20.67547035], [86.80444336, 20.67551804], [86.80484772, 20.67555046], [86.8052597, 20.67561913], [86.80568695, 20.6757412], [86.80618286, 20.67578125], [86.80648041, 20.67576218], [86.80665588, 20.67575073], [86.8070755, 20.67566872], [86.80745697, 20.67560005], [86.80782318, 20.67562866], [86.80818939, 20.6757412], [86.80860138, 20.67579079], [86.80905914, 20.67580032], [86.80950928, 20.67579079], [86.80995178, 20.67575073], [86.81040192, 20.67567062], [86.81080627, 20.6757412], [86.81125641, 20.67579079], [86.81171417, 20.67580223], [86.81217194, 20.67579651], [86.81262207, 20.67579079], [86.81304932, 20.67578125], [86.8134613, 20.67572975], [86.81385803, 20.67562675], [86.81427002, 20.6756115], [86.81469727, 20.67569351], [86.81512451, 20.67568207], [86.8155365, 20.6756115], [86.81596375, 20.6756115], [86.81639862, 20.67556763], [86.81685638, 20.67554092], [86.81735229, 20.67551994], [86.81784821, 20.67546082], [86.81830597, 20.67534065], [86.81881714, 20.67528152], [86.81936646, 20.67525101], [86.81993866, 20.67518997], [86.82047272, 20.6750412], [86.82099915, 20.67493057], [86.82150269, 20.67477036], [86.82202148, 20.67464828], [86.82253265, 20.67448997], [86.82308197, 20.67437935], [86.82360077, 20.6742382], [86.82411194, 20.67410851], [86.82457733, 20.67394066], [86.8250885, 20.67381859], [86.82559204, 20.67366028], [86.82611847, 20.6735363], [86.82660675, 20.67332077], [86.82710266, 20.67304993], [86.82758331, 20.67278099], [86.82805634, 20.67252159], [86.82853699, 20.67226982], [86.82897186, 20.67198181], [86.82939911, 20.67169952], [86.82982635, 20.67141914], [86.83024597, 20.67114067], [86.83067322, 20.6708107], [86.83110046, 20.67044258], [86.83153534, 20.67004395], [86.83200836, 20.6696434], [86.83246613, 20.66921043], [86.83291626, 20.66873741], [86.83331299, 20.66822815], [86.83370209, 20.6677475], [86.83409119, 20.66737938], [86.83441162, 20.66703987], [86.83463287, 20.66673279], [86.83474731, 20.6664505], [86.83487701, 20.66621017], [86.83502197, 20.66596031], [86.83518982, 20.66571236], [86.83531952, 20.66542244], [86.83547211, 20.66514778], [86.83560181, 20.66484833], [86.83574677, 20.66456032], [86.83586884, 20.66424942], [86.83600616, 20.66395569], [86.83608246, 20.66365051], [86.83612061, 20.66333771], [86.83615875, 20.66303062], [86.83627319, 20.66275978], [86.83641052, 20.66244125], [86.83659363, 20.66205788], [86.8367691, 20.66152763], [86.8368988, 20.6608696], [86.83699799, 20.66016006], [86.83715057, 20.65949059], [86.83721161, 20.6588707], [86.8372345, 20.65832901], [86.8372879, 20.65785027], [86.83744049, 20.65742111], [86.83753967, 20.65695953], [86.83769989, 20.65650368], [86.83792877, 20.65607643], [86.83817291, 20.65563965], [86.83841705, 20.65523911], [86.83863068, 20.65481949], [86.83882904, 20.65439987], [86.83899689, 20.65390015], [86.83930206, 20.65341949], [86.83969879, 20.65294266], [86.84012604, 20.65242767], [86.84056091, 20.65197945], [86.84100342, 20.65162659], [86.84142303, 20.65134811], [86.84181976, 20.65116119], [86.84217072, 20.65100098], [86.8425293, 20.65088844], [86.84291077, 20.6508007], [86.84332275, 20.65075493], [86.84375763, 20.65073967], [86.84421539, 20.65073776], [86.8446579, 20.65076256], [86.84506226, 20.65081978], [86.84541321, 20.65088081], [86.84572601, 20.65092087], [86.84606171, 20.6510601], [86.84645844, 20.65124321], [86.84692383, 20.65144348], [86.84739685, 20.65166283], [86.8478775, 20.65187263], [86.84835815, 20.65197945], [86.84879303, 20.65209007], [86.8491745, 20.65222359], [86.84955597, 20.65241051], [86.84998322, 20.65269089], [86.8504715, 20.65304947], [86.85099792, 20.65343666], [86.85154724, 20.65377045], [86.85206604, 20.65406036], [86.85253906, 20.65439034], [86.8529892, 20.65471268], [86.85350037, 20.65501976], [86.85399628, 20.65539169], [86.85452271, 20.65578079], [86.85504913, 20.6561203], [86.85553741, 20.65647888], [86.85597992, 20.65682983], [86.85639191, 20.65718079], [86.85681915, 20.65748978], [86.85728455, 20.65776825], [86.85777283, 20.65805054], [86.85822296, 20.65837288], [86.85861206, 20.658741], [86.8589859, 20.65912247], [86.85942841, 20.65942955], [86.85985565, 20.65978432], [86.8602066, 20.66024971], [86.86060333, 20.66069031], [86.86107635, 20.66107559], [86.86164093, 20.66138268], [86.86226654, 20.66166115], [86.86295319, 20.66194916], [86.86362457, 20.66226959], [86.864151, 20.66274071], [86.86464691, 20.66324806], [86.86527252, 20.66357613], [86.86585999, 20.66387939], [86.86641693, 20.66418076], [86.86688232, 20.66451073], [86.86724091, 20.66489983], [86.86753845, 20.66531944], [86.867836, 20.66573906], [86.86821747, 20.6660881], [86.86867523, 20.66638565], [86.86917877, 20.66666031], [86.86969757, 20.66694641], [86.87017822, 20.66725922], [86.87058258, 20.66761017], [86.87098694, 20.66790009], [86.87136078, 20.66819], [86.87169647, 20.66848946], [86.87207794, 20.6687603], [86.87240601, 20.66908073], [86.87272644, 20.66940117], [86.87304688, 20.66971016], [86.87338257, 20.67000008], [86.87371063, 20.67027664], [86.87403107, 20.67054939], [86.87435913, 20.67084122], [86.87468719, 20.67115974], [86.87499237, 20.67152977], [86.8752594, 20.67194939], [86.87548828, 20.67239952], [86.87580109, 20.67274284], [86.87610626, 20.67301178], [86.87639618, 20.67324066], [86.87665558, 20.67343903], [86.87690735, 20.67365074], [86.87716675, 20.67391586], [86.87741852, 20.67422295], [86.87766266, 20.6745739], [86.87800598, 20.67482376], [86.87831879, 20.67511177], [86.87858582, 20.6754303], [86.87883759, 20.67577553], [86.87913513, 20.67606163], [86.87943268, 20.6763401], [86.87970734, 20.67664909], [86.87999725, 20.67695045], [86.88027954, 20.67726326], [86.88054657, 20.67757988], [86.88082886, 20.67790604], [86.88110352, 20.6782341], [86.88135529, 20.67856979], [86.88166046, 20.67885208], [86.88195038, 20.67912102], [86.88223267, 20.67938042], [86.88249969, 20.67962074], [86.88275146, 20.67987061], [86.88305664, 20.68028069], [86.8833313, 20.68056107], [86.88360596, 20.68056107], [86.8841629, 20.68111038], [86.88445282, 20.68111038], [86.88610077, 20.68278122], [86.88639069, 20.68278122], [86.88666534, 20.68305588], [86.88683319, 20.68349838], [86.88712311, 20.68381119], [86.88739014, 20.68414116], [86.8877182, 20.68438911], [86.88804626, 20.68464851], [86.88835907, 20.68494987], [86.88870239, 20.68525124], [86.88909912, 20.68548965], [86.88948822, 20.68571091], [86.88987732, 20.68587112], [86.89016724, 20.68615723], [86.89055634, 20.68645096], [86.89097595, 20.68668175], [86.89134979, 20.68693542], [86.89167023, 20.68721962], [86.89187622, 20.68742943], [86.89250183, 20.68806076], [86.89277649, 20.68805504], [86.89444733, 20.68972015], [86.89472198, 20.68971825], [86.89527893, 20.6902771], [86.89528656, 20.69083023], [86.89778137, 20.69333458], [86.89861298, 20.69417], [86.89888763, 20.69416618], [86.89888763, 20.69444466], [86.90018463, 20.69574165], [86.90083313, 20.69639015], [86.90110016, 20.69639015], [86.90249634, 20.69778061], [86.90305328, 20.6977787], [86.90361023, 20.69833374], [86.90389252, 20.69832993], [86.90416718, 20.69861031], [86.90444183, 20.69861031], [86.90471649, 20.69889069], [86.90499878, 20.69889069], [86.90528107, 20.69917107], [86.90555573, 20.69916725], [86.90583038, 20.69944382], [86.9059906, 20.69944382], [86.90611267, 20.69944382], [86.90638733, 20.69972229], [86.90666962, 20.69972038], [86.90693665, 20.70000076], [86.90721893, 20.70000076], [86.90740967, 20.70018768], [86.90750122, 20.70028114], [86.90777588, 20.70028114], [86.90805817, 20.70055962], [86.90860748, 20.7005558], [86.90888977, 20.70083427], [86.9091568, 20.70083046], [86.90972137, 20.70139122], [86.90999603, 20.70139122], [86.91028595, 20.70166969], [86.91083527, 20.70166588], [86.91110992, 20.70194435], [86.91166687, 20.70194435], [86.91194153, 20.70222282], [86.91249847, 20.70222282], [86.91278076, 20.70249939], [86.91306305, 20.70248985], [86.91333008, 20.70278168], [86.91500092, 20.70278168], [86.9152832, 20.70306015], [86.91583252, 20.70305634], [86.91611481, 20.7033329], [86.91638947, 20.7033329], [86.91666412, 20.70360947], [86.91694641, 20.70360947], [86.91722107, 20.70388794], [86.91765594, 20.7040081], [86.91822052, 20.70420074], [86.91873932, 20.70451546], [86.91936493, 20.70472336], [86.91997528, 20.70498466], [86.92056274, 20.70523071], [86.92112732, 20.70539093], [86.92166901, 20.70557976], [86.92218781, 20.70587921], [86.92271423, 20.70623779], [86.92338562, 20.70626259], [86.92391205, 20.70644951], [86.92432404, 20.7067585], [86.92487335, 20.70683479], [86.925354, 20.70698166], [86.92578125, 20.70722008], [86.92619324, 20.70750046], [86.92664337, 20.70778084], [86.92708588, 20.70802116], [86.92758179, 20.70816612], [86.9280014, 20.70833588], [86.92835999, 20.70849991], [86.92871094, 20.70862961], [86.92900848, 20.70880127], [86.9292984, 20.70901108], [86.92970276, 20.70919991], [86.93014526, 20.70937347], [86.9306488, 20.70946121], [86.93112183, 20.70960808], [86.93157196, 20.70974541], [86.93198395, 20.70990372], [86.93209076, 20.70993614], [86.93239594, 20.71003151], [86.93279266, 20.71026993], [86.93328094, 20.71050072], [86.93393707, 20.71071053], [86.93468475, 20.71088028], [86.93540955, 20.71108055], [86.93612671, 20.71119118], [86.93682098, 20.71125984], [86.93742371, 20.71136665], [86.93802643, 20.71139908], [86.938591, 20.7115097], [86.93916321, 20.71161079], [86.93979645, 20.71146965], [86.94050598, 20.71139908], [86.94123077, 20.71138954], [86.9419632, 20.71138954], [86.94267273, 20.71136665], [86.94335175, 20.71124077], [86.94402313, 20.71112061], [86.94468689, 20.71103096], [86.94535828, 20.71092033], [86.9460144, 20.71083832], [86.94668579, 20.7107811], [86.94734192, 20.71077728], [86.94798279, 20.7107811], [86.94848633, 20.71058083], [86.94898224, 20.71044731], [86.94944, 20.71027946], [86.94986725, 20.71013069], [86.95027161, 20.71001816], [86.95069885, 20.71000099], [86.95115662, 20.71000099], [86.95160675, 20.70996094], [86.95198822, 20.70974922], [86.95231628, 20.7096405], [86.95258331, 20.70947838], [86.95288086, 20.70957375], [86.95321655, 20.70968056], [86.95358276, 20.70972061], [86.95397949, 20.70972061], [86.95440674, 20.70968056], [86.95481873, 20.7094841], [86.9552536, 20.70942879], [86.95565796, 20.70935249], [86.9560318, 20.70922279], [86.95642853, 20.70918083], [86.95684052, 20.70916939], [86.95726776, 20.70916939], [86.95770264, 20.70916939], [86.95812225, 20.70916939], [86.95852661, 20.70916939], [86.95889282, 20.70916939], [86.95916748, 20.70916748], [86.95944214, 20.70944595], [86.95972443, 20.70944595], [86.95999908, 20.70916748], [86.96194458, 20.70916748], [86.96221924, 20.70944595], [86.96305847, 20.70944595], [86.96333313, 20.70916748], [86.9658432, 20.70916939], [86.96611023, 20.70889091], [86.96669006, 20.70889091], [86.9672699, 20.70889091], [86.96787262, 20.70889091], [86.96843719, 20.70887947], [86.96899414, 20.70885658], [86.96952057, 20.7088623], [86.97000885, 20.70883179], [86.97044373, 20.70862961], [86.97088623, 20.70849991], [86.97133636, 20.70840645], [86.97171783, 20.70820427], [86.9720993, 20.70802116], [86.97245789, 20.70779037], [86.97286224, 20.70759964], [86.97336578, 20.7074604], [86.97387695, 20.70722008], [86.97447205, 20.70695114], [86.97614288, 20.70610046], [86.97673035, 20.70566177], [86.97714233, 20.70535469], [86.97821808, 20.70467949], [86.9797287, 20.70421982], [86.98030853, 20.70421028], [86.98091125, 20.70413971], [86.98150635, 20.70396042], [86.98213959, 20.70386124], [86.98274994, 20.7036705], [86.98335266, 20.70359039], [86.98387909, 20.70347404], [86.98442078, 20.70335007], [86.98501587, 20.70331001], [86.98562622, 20.70331955], [86.9861908, 20.70331001], [86.98670197, 20.70318031], [86.98722839, 20.70297813], [86.98777008, 20.70279121], [86.98823547, 20.70263672], [86.98870087, 20.70252037], [86.98924255, 20.7024498], [86.98984528, 20.70226097], [86.99064636, 20.70222282], [86.9911499, 20.70220566], [86.99166107, 20.70219421], [86.99238586, 20.7021122], [86.99311829, 20.70203209], [86.99427795, 20.70196342], [86.99544525, 20.70189667], [87.0, 20.70028114], [87.00305176, 20.70028114], [87.00405884, 20.7003212], [87.00491333, 20.70024109], [87.00519562, 20.7002449], [87.00548553, 20.70010757], [87.00569916, 20.69984055], [87.00569916, 20.69936943], [87.00554657, 20.69875908], [87.00527191, 20.69848824], [87.00454712, 20.6982193], [87.0041275, 20.69795036], [87.00376892, 20.69782066], [87.00327301, 20.69748116], [87.00263214, 20.69728088], [87.00226593, 20.69713974], [87.00177002, 20.69713974], [87.0, 20.69668007], [86.99973297, 20.69695091], [86.99973297, 20.69717026], [86.99960327, 20.69723129], [86.99930573, 20.69722176], [86.99897003, 20.69721413], [86.99859619, 20.69722939], [86.99820709, 20.69729805], [86.99780273, 20.69742966], [86.99734497, 20.6974926], [86.99687958, 20.69754028], [86.99643707, 20.6977005], [86.99595642, 20.69781685], [86.99549103, 20.69799423], [86.99497986, 20.69812393], [86.99449921, 20.69831085], [86.99401093, 20.69848824], [86.99346161, 20.69864273], [86.99295044, 20.69881058], [86.99238586, 20.69888115], [86.99186707, 20.69889641], [86.99138641, 20.69894218], [86.99095917, 20.69906044], [86.99053192, 20.69910812], [86.99009705, 20.6990509], [86.98968506, 20.69891167], [86.98924255, 20.69882011], [86.9888382, 20.69874001], [86.98854065, 20.69861031], [86.98828888, 20.69855499], [86.98812103, 20.69853973], [86.98783875, 20.6984005], [86.98721313, 20.69820023], [86.98750305, 20.69721031], [86.98810577, 20.69742012], [86.9883194, 20.69750023], [86.9888382, 20.69762039], [86.98922729, 20.6976738], [86.98995972, 20.69766235], [86.99044037, 20.69771194], [86.99088287, 20.69767189], [86.9912796, 20.69754028], [86.99171448, 20.69748306], [86.99214935, 20.69741249], [86.99253845, 20.69725227], [86.99295044, 20.69712257], [86.99333954, 20.69697952], [86.99375916, 20.69688606], [86.994133, 20.6967411], [86.99452209, 20.69663429], [86.99491119, 20.69649887], [86.99533081, 20.69635963], [86.9957962, 20.69619942], [86.99633789, 20.69606972], [86.99687958, 20.69592094], [86.99743652, 20.69583321], [86.99803925, 20.69576645], [86.9988327, 20.69569969], [87.0, 20.69528008], [87.0011673, 20.69549942], [87.00159454, 20.69563675], [87.00216675, 20.69577217], [87.00293732, 20.69597054], [87.00359344, 20.69617653], [87.00408936, 20.69624329], [87.00479889, 20.69632149], [87.00522614, 20.69639015], [87.005867, 20.69639015], [87.00644684, 20.69645119], [87.00715637, 20.69664955], [87.00787354, 20.69691849], [87.0085907, 20.69725609], [87.00894165, 20.69739151], [87.00951385, 20.69772911], [87.01029968, 20.69792747], [87.01065826, 20.69799805], [87.01114655, 20.69812012], [87.01151276, 20.69833946], [87.01208496, 20.69853783], [87.01243591, 20.69866943], [87.01287079, 20.69880867], [87.01315308, 20.69894028], [87.01344299, 20.69901085], [87.01358032, 20.69930077], [87.01442719, 20.69963074], [87.01515198, 20.69997025], [87.01571655, 20.70030594], [87.01657867, 20.70064354], [87.01715088, 20.70091057], [87.01772308, 20.70111847], [87.01843262, 20.70165634], [87.0187149, 20.7017231], [87.01900482, 20.7017231], [87.01957703, 20.70165634], [87.01999664, 20.70145035], [87.02043152, 20.7010498], [87.02070618, 20.70084953], [87.02107239, 20.70078278], [87.0213623, 20.7007103], [87.02163696, 20.70064163], [87.02285767, 20.70064163], [87.02313995, 20.7007103], [87.02342987, 20.70084572], [87.02407074, 20.70145226], [87.02428436, 20.7017231], [87.02457428, 20.70199203], [87.02493286, 20.70226097], [87.02513885, 20.70232964], [87.0252533, 20.7023716], [87.02574158, 20.70265007], [87.0265274, 20.70304108], [87.02709961, 20.70345116], [87.02767181, 20.70358086], [87.02831268, 20.70384979], [87.02880859, 20.70412064], [87.0293808, 20.70458984], [87.02967072, 20.70493126], [87.03009796, 20.70540237], [87.03038025, 20.7056675], [87.03067017, 20.70587921], [87.03116608, 20.70587921], [87.03180695, 20.70573807], [87.0326004, 20.70560074], [87.03344727, 20.70560074], [87.03373718, 20.70573807], [87.03423309, 20.70594025], [87.03452301, 20.70607948], [87.03495026, 20.70621109], [87.03530884, 20.70641518], [87.03573608, 20.70648003], [87.03601837, 20.7065506], [87.03637695, 20.70668411], [87.03665924, 20.70675087], [87.03697968, 20.70706177], [87.03733826, 20.7074604], [87.03733826, 20.70800018], [87.03826141, 20.70853996], [87.03875732, 20.70887947], [87.03911591, 20.70907974], [87.03946686, 20.70922279], [87.03990173, 20.70941734], [87.0404129, 20.70955086], [87.04068756, 20.70975494], [87.04090118, 20.70981979], [87.04125977, 20.70996094], [87.04168701, 20.71002579], [87.04219055, 20.71009064], [87.04247284, 20.71022987], [87.04276276, 20.71029472], [87.04325867, 20.71036148], [87.0446167, 20.71036148], [87.04483032, 20.71022987], [87.04489136, 20.71015358], [87.04512024, 20.70988846], [87.0451889, 20.7094841], [87.0446167, 20.70887756], [87.04403687, 20.70845985], [87.04319, 20.70800018], [87.04234314, 20.70759964], [87.04154968, 20.70725822], [87.04067993, 20.70650864], [87.04032135, 20.70624161], [87.03974915, 20.70556641], [87.03846741, 20.70543098], [87.03760529, 20.70468712], [87.03653717, 20.7038784], [87.03568268, 20.70334053], [87.03497314, 20.70280075], [87.03417969, 20.70192337], [87.03318024, 20.70145035], [87.0324707, 20.70083809], [87.03153992, 20.70010376], [87.03070831, 20.69924927], [87.03042603, 20.69898033], [87.02970886, 20.69856071], [87.02921295, 20.69823837], [87.02884674, 20.6977005], [87.02700043, 20.69634819], [87.02635956, 20.69615173], [87.02578735, 20.69581032], [87.02542877, 20.69547272], [87.0241394, 20.69466019], [87.02364349, 20.69445992], [87.02307129, 20.69406128], [87.02258301, 20.6936512], [87.0213623, 20.69277191], [87.02072144, 20.69223213], [87.02028656, 20.69182777], [87.01950073, 20.6914196], [87.01885986, 20.69108772], [87.01821899, 20.69082069], [87.01735687, 20.69033813], [87.01657104, 20.68965912], [87.01635742, 20.68939972], [87.01535797, 20.68844032], [87.01457214, 20.68776894], [87.01364899, 20.68722916], [87.01136017, 20.68601036], [87.01065063, 20.6854744], [87.00993347, 20.6848011], [87.00921631, 20.68419075], [87.00665283, 20.68264198], [87.00565338, 20.68196869], [87.00465393, 20.68142891], [87.00222778, 20.67974091], [87.00144196, 20.67918968], [87.00086975, 20.67866135], [87.0, 20.67721939], [86.99834442, 20.67666245], [86.9972229, 20.67610931], [86.99694824, 20.67610931], [86.99610901, 20.67528152], [86.99582672, 20.67528152], [86.99536896, 20.67481232], [86.9952774, 20.67472267], [86.99500275, 20.67472267], [86.99472046, 20.6744442], [86.9944458, 20.6744442], [86.99416351, 20.67416573], [86.99388885, 20.67416954], [86.99360657, 20.67388916], [86.99333191, 20.67388916], [86.99305725, 20.67361069], [86.99276733, 20.67361069], [86.99194336, 20.67278099], [86.9916687, 20.67278099], [86.99111176, 20.67222023], [86.99055481, 20.67222214], [86.98972321, 20.67138863], [86.98944092, 20.67139053], [86.98860931, 20.67056084], [86.9883194, 20.67056084], [86.98722076, 20.66945076], [86.98722076, 20.66917038], [86.98694611, 20.66889], [86.98694611, 20.66860962], [86.98666382, 20.66833305], [86.98638916, 20.66833305], [86.9861145, 20.66805649], [86.98583221, 20.6680603], [86.98554993, 20.66777992], [86.9852829, 20.66777992], [86.98477173, 20.66727448], [86.98444366, 20.6669445], [86.98332977, 20.6669445], [86.98278046, 20.66638947], [86.98249817, 20.66638947], [86.98194122, 20.66583061], [86.98083496, 20.66583061], [86.98027802, 20.66527748], [86.98000336, 20.66527939], [86.97972107, 20.66500282], [86.97860718, 20.66500282], [86.97833252, 20.66472054], [86.97805786, 20.66472054], [86.97638702, 20.66305542], [86.97611237, 20.66306114], [86.97471619, 20.66167068], [86.97444153, 20.66167068], [86.97407532, 20.66129684], [86.97389221, 20.66111183], [86.97360992, 20.66111183], [86.97305298, 20.66055489], [86.97277832, 20.66055489], [86.97250366, 20.66027832], [86.97222137, 20.66027832], [86.97194672, 20.65999985], [86.9716568, 20.65999985], [86.97138214, 20.65977097], [86.97083282, 20.65972137], [86.97027588, 20.65916634], [86.97000122, 20.65917015], [86.96916962, 20.65833092], [86.96888733, 20.65833282], [86.96833038, 20.65777779], [86.96806335, 20.65777969], [86.96778107, 20.65751076], [86.96750641, 20.65751076], [86.96721649, 20.65722084], [86.96666718, 20.65722275], [86.96648407, 20.65703964], [86.96611023, 20.6566658], [86.9658432, 20.65666962], [86.96527863, 20.65611076], [86.96499634, 20.65611076], [86.96333313, 20.65443993], [86.96250153, 20.65444565], [86.96221924, 20.65416718], [86.96193695, 20.65417099], [86.96166992, 20.65389061], [86.96111298, 20.65389061], [86.96103668, 20.6538105], [86.96092987, 20.65370369], [86.96055603, 20.65333366], [86.96055603, 20.65305519], [86.95999908, 20.65306091], [86.9597168, 20.65278053], [86.95916748, 20.65278053], [86.95833588, 20.65195084], [86.95804596, 20.65195084], [86.95769501, 20.65159035], [86.95749664, 20.65138817], [86.95722198, 20.65138817], [86.95639038, 20.65055466], [86.95639038, 20.65027809], [86.95582581, 20.64971924], [86.95471954, 20.64972115], [86.95444489, 20.64944458], [86.95417023, 20.64944458], [86.95381927, 20.64909554], [86.95277405, 20.64805603], [86.95249939, 20.64805984], [86.95220947, 20.64777756], [86.95139313, 20.64777756], [86.9511795, 20.64756966], [86.95110321, 20.64755249], [86.95083618, 20.64749908], [86.95054626, 20.64722061], [86.95055389, 20.64694405], [86.94944763, 20.64583397], [86.94916534, 20.64583397], [86.94889069, 20.6455555], [86.94832611, 20.64557076], [86.94805908, 20.64528084], [86.94777679, 20.64528084], [86.9466629, 20.64417076], [86.94639587, 20.64417076], [86.94610596, 20.64389038], [86.9458313, 20.64389038], [86.94526672, 20.64332962], [86.94499969, 20.64333344], [86.9430542, 20.64138794], [86.94194794, 20.64138985], [86.94139099, 20.6408329], [86.94083405, 20.64083481], [86.94055176, 20.64111137], [86.94000244, 20.64111137], [86.93972015, 20.64083481], [86.9394455, 20.64083481], [86.93916321, 20.64055634], [86.93860626, 20.64056015], [86.9383316, 20.64027977], [86.93805695, 20.64027977], [86.93638611, 20.63861275], [86.93638611, 20.63833046], [86.9355545, 20.63750267], [86.93527985, 20.63750267], [86.93499756, 20.63722038], [86.9347229, 20.63722038], [86.93453979, 20.63703918], [86.93416595, 20.63666725], [86.9338913, 20.63667107], [86.93360901, 20.63640022], [86.93332672, 20.63640022], [86.93305206, 20.6361084], [86.9327774, 20.6361084], [86.93250275, 20.63582993], [86.93222046, 20.63582993], [86.9319458, 20.6361084], [86.93000031, 20.63417053], [86.92973328, 20.63417053], [86.92944336, 20.63388824], [86.9291687, 20.63388824], [86.92778015, 20.63249969], [86.92722321, 20.63249969], [86.92694092, 20.63222122], [86.92666626, 20.63222313], [86.9263916, 20.63194466], [86.92610931, 20.63194466], [86.92583466, 20.63166618], [86.92555237, 20.63166809], [86.92500305, 20.63111115], [86.92472076, 20.63111115], [86.92444611, 20.63083076], [86.92388916, 20.63083267], [86.92166901, 20.62861061], [86.92138672, 20.62861061], [86.92056274, 20.62778091], [86.92056274, 20.62721062], [86.91999817, 20.62666702], [86.91916656, 20.62667084], [86.91889191, 20.62639046], [86.91832733, 20.62639046], [86.91809845, 20.62615967], [86.91694641, 20.62611389], [86.91684723, 20.62601471], [86.91666412, 20.62583351], [86.91500092, 20.62583351], [86.91416931, 20.62500191], [86.91416931, 20.62446022], [86.91443634, 20.6241703], [86.91416931, 20.62389183], [86.91416931, 20.62332916], [86.91388702, 20.62305641], [86.91278076, 20.62306023], [86.91249847, 20.62278175], [86.91221619, 20.62278175], [86.91166687, 20.62221909], [86.91139221, 20.6222229], [86.91110992, 20.62194443], [86.91083527, 20.62194443], [86.91027832, 20.62138748], [86.90972137, 20.62140274], [86.90944672, 20.62111092], [86.90860748, 20.62111092], [86.90805817, 20.62055969], [86.90777588, 20.62055969], [86.90759277, 20.62037468], [86.90721893, 20.62000084], [86.90693665, 20.62000084], [86.90666962, 20.61972046], [86.90638733, 20.61972237], [86.90555573, 20.61888885], [86.90556335, 20.61861038], [86.90528107, 20.61833382], [86.90416718, 20.61833382], [86.90361023, 20.61777687], [86.9033432, 20.61778069], [86.90139008, 20.61582947], [86.90110779, 20.61583328], [86.90055847, 20.61527824], [86.90083313, 20.61499977], [86.90083313, 20.61471939], [86.90027618, 20.61416626], [86.89916992, 20.61417007], [86.89888763, 20.61388969], [86.8972168, 20.61220932], [86.89694214, 20.61222267], [86.89638519, 20.61166573], [86.89611053, 20.61166954], [86.89583588, 20.61139107], [86.89554596, 20.61139107], [86.89515686, 20.61099434], [86.89499664, 20.61083412], [86.89472198, 20.61083412], [86.89444733, 20.61055565], [86.89389038, 20.61055946], [86.89332581, 20.61000252], [86.89305878, 20.61000252], [86.89277649, 20.60971832], [86.89250183, 20.61000252], [86.89221954, 20.61000252], [86.89194489, 20.60972023], [86.89194489, 20.60944366], [86.89027405, 20.60778046], [86.88999939, 20.60778046], [86.88944244, 20.6072197], [86.8888855, 20.6072216], [86.88805389, 20.60638618], [86.88723755, 20.60606194], [86.8866272, 20.60611725], [86.88641357, 20.60699654], [86.88645172, 20.60822105], [86.88666534, 20.6091671], [86.88694763, 20.60943985], [86.88694763, 20.61000252], [86.88722229, 20.6102829], [86.88722229, 20.61166573], [86.88694763, 20.61194038], [86.88694763, 20.61250114], [86.88722229, 20.61277771], [86.88722229, 20.61333275], [86.88749695, 20.61361122], [86.88749695, 20.61388969], [86.88777924, 20.61416626], [86.88777924, 20.61721992], [86.88722229, 20.61778069], [86.88694763, 20.61778069], [86.88610077, 20.61695099], [86.88610077, 20.61667061], [86.88582611, 20.61639023], [86.88500214, 20.61639023], [86.88388824, 20.61527061], [86.88444519, 20.6147213], [86.88444519, 20.61444473], [86.88471985, 20.61416626], [86.88471985, 20.61361122], [86.88582611, 20.61250114], [86.88582611, 20.60806084], [86.88555908, 20.60749817], [86.8850708, 20.60630989], [86.88500214, 20.60583115], [86.88500214, 20.60527611], [86.88527679, 20.60499954], [86.88527679, 20.60472107], [86.88500214, 20.6044445], [86.88471985, 20.6044445], [86.88444519, 20.60416794], [86.8841629, 20.60416985], [86.88388824, 20.60388947], [86.88360596, 20.60388947], [86.8833313, 20.60361099], [86.88249969, 20.60361099], [86.88194275, 20.60305977], [86.88166809, 20.60305977], [86.8813858, 20.60277939], [86.88028717, 20.60277939], [86.87999725, 20.60250092], [86.8797226, 20.60250092], [86.87832642, 20.60111046], [86.87750244, 20.60111046], [86.87722015, 20.60083008], [86.87527466, 20.5988884], [86.875, 20.5988903], [86.87444305, 20.59832954], [86.87388611, 20.59833336], [86.87361145, 20.59861374], [86.87333679, 20.59833336], [86.87277985, 20.59833336], [86.87249756, 20.59805489], [86.8722229, 20.59805489], [86.87203979, 20.59786987], [86.87194824, 20.59777832], [86.87194824, 20.59750175], [86.87082672, 20.59639168], [86.87055206, 20.59639168], [86.87000275, 20.59583092], [86.8694458, 20.59583282], [86.86888885, 20.59527969], [86.86860657, 20.5952816], [86.86833191, 20.59499931], [86.86805725, 20.59499931], [86.86694336, 20.59389114], [86.8666687, 20.59389114], [86.86554718, 20.59278107], [86.86528015, 20.59278107], [86.86416626, 20.59167099], [86.8638916, 20.59167099], [86.86360931, 20.59139061], [86.86332703, 20.59139061], [86.8631897, 20.59124756], [86.86305237, 20.59110069], [86.86277771, 20.59111023], [86.86250305, 20.59083366], [86.86222076, 20.59083366], [86.86194611, 20.59055519], [86.86165619, 20.59056091], [86.86138916, 20.59028053], [86.86083221, 20.59028053], [86.86055756, 20.59000015], [86.86027527, 20.59000015], [86.86000061, 20.58972168], [86.85972595, 20.58972168], [86.85972595, 20.58944511], [86.85943604, 20.58917046], [86.85943604, 20.58889008], [86.85888672, 20.58833122], [86.85861206, 20.58833313], [86.85778046, 20.58749962], [86.85749817, 20.58749962], [86.85694122, 20.58694077], [86.85666656, 20.58694458], [86.85610962, 20.58638954], [86.85582733, 20.58638954], [86.85555267, 20.58666992], [86.85527802, 20.58666611], [86.85472107, 20.58722115], [86.85472107, 20.58777809], [86.85500336, 20.5880394], [86.85575867, 20.58814812], [86.85668945, 20.5883503], [86.85675812, 20.58862114], [86.85661316, 20.58903122], [86.85611725, 20.58916092], [86.85504913, 20.58909035], [86.85375977, 20.58909225], [86.85305023, 20.5883503], [86.85276794, 20.58794975], [86.85240173, 20.58727074], [86.85231781, 20.58653069], [86.85231781, 20.58579063], [86.85260773, 20.58484077], [86.85333252, 20.58416939], [86.85333252, 20.58389282], [86.8527832, 20.58333015], [86.85250092, 20.58333397], [86.85194397, 20.58277702], [86.85166931, 20.58278084], [86.85056305, 20.58167076], [86.84999084, 20.58167076], [86.84916687, 20.58082962], [86.84889221, 20.58083344], [86.84805298, 20.57999992], [86.84777832, 20.57999992], [86.84694672, 20.57916069], [86.84610748, 20.57916641], [86.84590149, 20.57895851], [86.8458252, 20.57894135], [86.84555817, 20.57888985], [86.84471893, 20.57806015], [86.84443665, 20.57806015], [86.84372711, 20.57733917], [86.84361267, 20.57722282], [86.84361267, 20.57694435], [86.84305573, 20.57638931], [86.84249878, 20.57694435], [86.84166718, 20.57694435], [86.83916473, 20.57444572], [86.83889008, 20.57444572], [86.83860779, 20.57416725], [86.83833313, 20.57417107], [86.83750153, 20.57332993], [86.83721924, 20.57333374], [86.83638763, 20.57250023], [86.83611298, 20.57221985], [86.83583069, 20.57222366], [86.83528137, 20.57166672], [86.83500671, 20.57167053], [86.83416748, 20.57082939], [86.83361053, 20.5708313], [86.83251953, 20.57007599], [86.83101654, 20.56906128], [86.8303833, 20.56865883], [86.82959747, 20.56851959], [86.82917023, 20.56805611], [86.82749939, 20.56638908], [86.8272171, 20.56638908], [86.82499695, 20.56415939], [86.82472229, 20.56416512], [86.82416534, 20.56361198], [86.82389069, 20.56389046], [86.82332611, 20.56389046], [86.82256317, 20.56311798], [86.82195282, 20.5625], [86.8216629, 20.5625], [86.81916809, 20.55999947], [86.81861115, 20.55999947], [86.81833649, 20.5597229], [86.8180542, 20.55972481], [86.81777954, 20.55944443], [86.81639099, 20.55944443], [86.81620026, 20.55925369], [86.81583405, 20.55888939], [86.81555176, 20.55888939], [86.8152771, 20.55861282], [86.81500244, 20.55861282], [86.81472015, 20.55833054], [86.81445313, 20.55833054], [86.81416321, 20.55861282], [86.81388092, 20.55861282], [86.8133316, 20.55805969], [86.81305695, 20.55805969], [86.81276703, 20.55778122], [86.8125, 20.55778122], [86.81240845, 20.55768967], [86.81223297, 20.55750275], [86.81194305, 20.55750275], [86.8116684, 20.55722046], [86.8116684, 20.55694389], [86.81222534, 20.55639076], [86.81194305, 20.55610847], [86.81194305, 20.55582809], [86.81138611, 20.55527687], [86.81111145, 20.55528069], [86.80999756, 20.55417061], [86.8097229, 20.55417061], [86.80860901, 20.55305099], [86.80833435, 20.55305481], [86.80805206, 20.55277634], [86.8077774, 20.55277824], [86.80750275, 20.55249977], [86.80722046, 20.55249977], [86.8069458, 20.55221939], [86.80638885, 20.5522213], [86.8061142, 20.55194473], [86.80583191, 20.55194473], [86.8041687, 20.55027771], [86.80388641, 20.55027962], [86.8033371, 20.54972076], [86.80305481, 20.54972267], [86.80288696, 20.5495491], [86.80278015, 20.5494442], [86.80194092, 20.5494442], [86.79972076, 20.54722214], [86.79944611, 20.54722214], [86.79916382, 20.54694366], [86.79888916, 20.54694366], [86.79833221, 20.54638863], [86.79805756, 20.54639053], [86.79676819, 20.54570007], [86.79634094, 20.5454998], [86.79531097, 20.54516029], [86.79453278, 20.54482079], [86.79387665, 20.54482079], [86.7934494, 20.54475021], [86.7928772, 20.54454994], [86.79216766, 20.5440712], [86.79166412, 20.54333115], [86.79166412, 20.54250145], [86.79110718, 20.54194069], [86.79111481, 20.54166603], [86.79083252, 20.54138756], [86.79083252, 20.54110909], [86.78943634, 20.53972054], [86.78916931, 20.53972244], [86.78694153, 20.53750038], [86.78639221, 20.53750038], [86.7858429, 20.53695107], [86.78555298, 20.53695107], [86.78444672, 20.53582954], [86.78444672, 20.53527832], [86.7841568, 20.53499985], [86.7841568, 20.53417969], [86.78221893, 20.53222275], [86.78221893, 20.53194427], [86.78194427, 20.5316658], [86.78153229, 20.53049278], [86.78055573, 20.52916718], [86.78028107, 20.52889061], [86.78028107, 20.52860832], [86.77999878, 20.52832985], [86.77999878, 20.52805519], [86.77944183, 20.52749825], [86.77944183, 20.52721977], [86.77972412, 20.52694511], [86.77971649, 20.52638817], [86.77889252, 20.52555084], [86.77889252, 20.52527618], [86.77861023, 20.52500916], [86.77861023, 20.52472115], [86.77805328, 20.52416611], [86.77805328, 20.52361107], [86.777771, 20.52333069], [86.77777863, 20.52305412], [86.77694702, 20.52222061], [86.77694702, 20.52083588], [86.77666473, 20.5205555], [86.7766571, 20.52028084], [86.77610779, 20.51972008], [86.77610779, 20.51888847], [86.77583313, 20.51861191], [86.77583313, 20.51805496], [86.77555847, 20.5177803], [86.77555847, 20.51721954], [86.77527618, 20.51694489], [86.77527618, 20.51472282], [86.77555847, 20.51444435], [86.77555847, 20.51389122], [86.77527618, 20.51361084], [86.77527618, 20.51306915], [86.77500153, 20.51278114], [86.77500153, 20.51167107], [86.77471161, 20.51139069], [86.77500153, 20.51111031], [86.77500153, 20.51082993], [86.77471924, 20.51055527], [86.77471161, 20.51028061], [86.77443695, 20.51000977], [86.77443695, 20.50945091], [86.77471161, 20.50917053], [86.77443695, 20.50889015], [86.77443695, 20.50832939], [86.77388763, 20.50777817], [86.77388763, 20.50749969], [86.77278137, 20.50638962], [86.77278137, 20.50611115], [86.77111053, 20.50444031], [86.76866913, 20.50444412], [86.76805878, 20.50444412], [86.76777649, 20.50416756], [86.76667023, 20.50416946], [86.76611328, 20.50361252], [86.7638855, 20.50361252], [86.76361084, 20.50333405], [86.76333618, 20.50333023], [86.76304626, 20.50361252], [86.76222229, 20.50361252], [86.76139069, 20.50444412], [86.76139069, 20.5047226], [86.76055908, 20.50555992], [86.75945282, 20.50555992], [86.75740051, 20.50266075], [86.75640106, 20.50124741], [86.75617981, 20.50064278], [86.75553894, 20.49956322], [86.7555542, 20.49916649], [86.75527954, 20.4991703], [86.75389099, 20.49777985], [86.75360107, 20.49777985], [86.75332642, 20.49749947], [86.75332642, 20.49722099], [86.75305176, 20.49694443], [86.75333405, 20.49666405], [86.75332642, 20.49555969], [86.75235748, 20.49458122], [86.7519455, 20.49416733], [86.75195313, 20.49389076], [86.75166321, 20.49361038], [86.75138855, 20.49155045], [86.75138855, 20.49000168], [86.75110626, 20.48971939], [86.75111389, 20.48944473], [86.7508316, 20.48916626], [86.7508316, 20.48887825], [86.75055695, 20.48860931], [86.75055695, 20.48722076], [86.7508316, 20.4869442], [86.7508316, 20.48611069], [86.75055695, 20.48583984], [86.75055695, 20.48500061], [86.75026703, 20.48472023], [86.75027466, 20.48416519], [86.75, 20.48389053], [86.75, 20.48332977], [86.74972534, 20.48305511], [86.74973297, 20.4822197], [86.74944305, 20.48194313], [86.74944305, 20.48167038], [86.7491684, 20.48139], [86.7491684, 20.48083115], [86.74888611, 20.48055649], [86.74888611, 20.48027992], [86.74861145, 20.47999954], [86.74861145, 20.47970963], [86.74833679, 20.4794445], [86.74833679, 20.4786129], [86.74804688, 20.47833061], [86.7480545, 20.47777748], [86.74778748, 20.47750282], [86.74777985, 20.47694206], [86.74749756, 20.4766674], [86.74749756, 20.47582817], [86.7472229, 20.47555542], [86.7472229, 20.47528076], [86.74666595, 20.47471809], [86.74666595, 20.47416878], [86.7463913, 20.47390175], [86.7463913, 20.47305107], [86.74555206, 20.47222137], [86.74555206, 20.47194481], [86.7452774, 20.47166634], [86.7452774, 20.47110939], [86.74500275, 20.47083282], [86.74500275, 20.47027969], [86.74472809, 20.47000122], [86.74472809, 20.46972084], [86.7436142, 20.46861076], [86.74276733, 20.46861076], [86.74250031, 20.46889114], [86.74222565, 20.46888924], [86.74166107, 20.46944046], [86.74166107, 20.47000122], [86.74138641, 20.47027969], [86.74138641, 20.47056007], [86.74166107, 20.47084045], [86.7416687, 20.47166634], [86.74138641, 20.47194099], [86.74138641, 20.47249985], [86.74111176, 20.47278023], [86.74111176, 20.47390175], [86.74055481, 20.47444534], [86.74054718, 20.47471809], [86.73999786, 20.47528076], [86.73999786, 20.47555923], [86.73916626, 20.47639275], [86.73916626, 20.4766674], [86.7388916, 20.47694206], [86.7388916, 20.47722244], [86.73832703, 20.47777939], [86.73832703, 20.47805977], [86.73777771, 20.4786129], [86.73750305, 20.4786129], [86.73722076, 20.47888947], [86.73665619, 20.47888947], [86.73638916, 20.47916985], [86.7361145, 20.47916603], [86.73583221, 20.4794445], [86.73416901, 20.4794445], [86.73388672, 20.47916603], [86.73388672, 20.4786129], [86.73472595, 20.4786129], [86.73500061, 20.47833061], [86.73583221, 20.47833061], [86.73638916, 20.47777748], [86.73665619, 20.47777939], [86.73777771, 20.47667122], [86.73777771, 20.47639275], [86.73805237, 20.47610855], [86.73805237, 20.47582817], [86.73860931, 20.47527695], [86.73860168, 20.47499847], [86.73832703, 20.47471809], [86.73860931, 20.47444534], [86.73860168, 20.47249985], [86.73832703, 20.47221947], [86.73833466, 20.46888924], [86.73805237, 20.46861076], [86.73803711, 20.46748161], [86.73777771, 20.46722221], [86.73777771, 20.46694374], [86.73750305, 20.46666718], [86.73750305, 20.46639061], [86.73722076, 20.46611023], [86.73722076, 20.46582985], [86.73694611, 20.46555519], [86.73694611, 20.46500015], [86.73665619, 20.46470833], [86.73666382, 20.46388817], [86.73638916, 20.4636116], [86.73638916, 20.46305466], [86.7361145, 20.46277809], [86.73610687, 20.46139145], [86.73583221, 20.46110916], [86.73583221, 20.46027756], [86.73555756, 20.45999908], [86.73555756, 20.45972061], [86.73527527, 20.45944405], [86.73527527, 20.4588871], [86.73500061, 20.45861053], [86.73500061, 20.45806122], [86.73472595, 20.45778084], [86.73472595, 20.45750046], [86.73443604, 20.45722008], [86.73444366, 20.45694351], [86.73388672, 20.45638847], [86.73388672, 20.45611], [86.73361206, 20.45583344], [86.73361206, 20.4552784], [86.73332977, 20.45499992], [86.73332977, 20.4543705], [86.73332977, 20.45388794], [86.73306274, 20.45360947], [86.73361206, 20.45305634], [86.73361206, 20.45249939], [86.73337555, 20.4522171], [86.73336029, 20.45205879], [86.73332977, 20.45166588], [86.73361206, 20.45139122], [86.73361206, 20.44889069], [86.73332977, 20.4486084], [86.73332977, 20.44778061], [86.73361206, 20.44749832], [86.73361206, 20.44696045], [86.73332977, 20.44667053], [86.73332977, 20.44638824], [86.73306274, 20.44610977], [86.73305511, 20.44527626], [86.73278809, 20.44499969], [86.73278046, 20.44444466], [86.73332977, 20.44388962], [86.73306274, 20.4435997], [86.73305511, 20.4430542], [86.73332977, 20.44277954], [86.73332977, 20.44166946], [86.73306274, 20.44139099], [86.73306274, 20.44028091], [86.73278809, 20.44000053], [86.73278046, 20.43972206], [86.73249817, 20.43944359], [86.73249817, 20.43916702], [86.73306274, 20.43861008], [86.73305511, 20.43805504], [86.73249817, 20.43750191], [86.73249817, 20.43639183], [86.73221588, 20.43611145], [86.73222351, 20.43500137], [86.73249817, 20.43473244], [86.73249817, 20.43222046], [86.73278046, 20.43194389], [86.73278046, 20.42666626], [86.73306274, 20.42638969], [86.73305511, 20.42611122], [86.73332977, 20.42583466], [86.73332977, 20.42499924], [86.73306274, 20.42472267], [86.73305511, 20.42361259], [86.73332977, 20.42333412], [86.73332977, 20.42305565], [86.73361206, 20.42279053], [86.73361206, 20.41860962], [86.73388672, 20.41833305], [86.73388672, 20.41777611], [86.73332977, 20.41722107], [86.73332977, 20.4169445], [86.73305511, 20.41666412], [86.73305511, 20.41638947], [86.73361206, 20.41583252], [86.73305511, 20.41527748], [86.73306274, 20.41472054], [86.73332977, 20.41444588], [86.73332977, 20.41388893], [86.73306274, 20.41362], [86.73306274, 20.41333008], [86.73278046, 20.41305542], [86.73278809, 20.41082954], [86.73305511, 20.41055489], [86.73249817, 20.41000175], [86.73278809, 20.40971947], [86.73222351, 20.40916634], [86.73221588, 20.40889168], [86.73194122, 20.40860939], [86.73194122, 20.40833282], [86.73166656, 20.40805626], [86.73166656, 20.40777969], [86.73139191, 20.40750122], [86.73105621, 20.40707016], [86.73000336, 20.40582085], [86.72943115, 20.40488052], [86.73107147, 20.40365982], [86.73171234, 20.40319252], [86.73271179, 20.40251732], [86.73278046, 20.40277863], [86.73332977, 20.40333366], [86.73361206, 20.40332985], [86.73388672, 20.40361023], [86.73416901, 20.40361023], [86.73583221, 20.40389061], [86.73610687, 20.40417099], [86.73638916, 20.40416527], [86.73649597, 20.40427589], [86.73666382, 20.40444374], [86.73750305, 20.40444374], [86.73777771, 20.40472221], [86.73944092, 20.40472031], [86.73972321, 20.40500069], [86.74054718, 20.40500069], [86.7408371, 20.40472031], [86.74111176, 20.40472031], [86.74138641, 20.40500069], [86.74305725, 20.40500069], [86.74333191, 20.40528107], [86.74360657, 20.40528107], [86.74388885, 20.40555954], [86.74416351, 20.40555573], [86.7444458, 20.4058342], [86.74500275, 20.4058342], [86.7452774, 20.40555573], [86.74555206, 20.40555954], [86.74582672, 20.40528107], [86.74666595, 20.40528107], [86.74694824, 20.40500069], [86.74833679, 20.40500069], [86.74888611, 20.40555954], [86.7491684, 20.40555954], [86.74973297, 20.40500069], [86.74972534, 20.40472221], [86.75055695, 20.4038887], [86.75055695, 20.40361023], [86.75195313, 20.40221977], [86.7519455, 20.40166664], [86.75222015, 20.40139008], [86.75222015, 20.40055084], [86.7519455, 20.40027809], [86.75195313, 20.39999962], [86.75027466, 20.3983326], [86.75, 20.3983326], [86.74972534, 20.39805794], [86.74944305, 20.39777756], [86.7491684, 20.39777946], [86.74888611, 20.39749908], [86.74861145, 20.39722252], [86.74833679, 20.39722252], [86.7480545, 20.39694405], [86.7472229, 20.39694405], [86.74694824, 20.39666748], [86.74610901, 20.39666939], [86.74582672, 20.39639282], [86.74472809, 20.39639282], [86.7444458, 20.39610863], [86.74388885, 20.39610863], [86.74360657, 20.39582825], [86.74277496, 20.39583397], [86.74250031, 20.3955555], [86.74194336, 20.39555931], [86.74166107, 20.39528084], [86.74111176, 20.39528084], [86.73999786, 20.39417076], [86.74028015, 20.39389038], [86.74054718, 20.39389038], [86.7408371, 20.39360809], [86.74111176, 20.39360809], [86.74124908, 20.39374733], [86.74138641, 20.39389038], [86.7416687, 20.39389038], [86.74192047, 20.39414024], [86.74222565, 20.39444351], [86.74250031, 20.39444351], [86.74277496, 20.39472008], [86.74388885, 20.39477539], [86.74415588, 20.39499855], [86.74582672, 20.39499855], [86.74610901, 20.39528084], [86.7463913, 20.39528084], [86.74666595, 20.39555931], [86.7472229, 20.3955555], [86.74749756, 20.39583397], [86.74833679, 20.39583397], [86.748703, 20.3962059], [86.74888611, 20.39639282], [86.74944305, 20.39639091], [86.74951935, 20.39646339], [86.74973297, 20.39666939], [86.75, 20.39666748], [86.75027466, 20.39694405], [86.75138855, 20.39694405], [86.75166321, 20.39722252], [86.75195313, 20.39722252], [86.75222015, 20.3975029], [86.75250244, 20.3975029], [86.7527771, 20.39777946], [86.75332642, 20.39777946], [86.75360107, 20.39805984], [86.75444794, 20.39805603], [86.7547226, 20.3983326], [86.75499725, 20.3983326], [86.75527954, 20.39862061], [86.75554657, 20.39862061], [86.75611115, 20.39916992], [86.75666809, 20.39916992], [86.75749969, 20.3983326], [86.75777435, 20.3983326], [86.75805664, 20.39805603], [86.7583313, 20.39805984], [86.75860596, 20.39777946], [86.75860596, 20.39582825], [86.7583313, 20.3955555], [86.7583313, 20.39528084], [86.75805664, 20.39499855], [86.75805664, 20.39360809], [86.75777435, 20.39333344], [86.75777435, 20.39222145], [86.75749969, 20.39194489], [86.75749969, 20.39138794], [86.75723267, 20.39110947], [86.75722504, 20.3908329], [86.75694275, 20.39055634], [86.75694275, 20.39027977], [86.75666809, 20.38999939], [86.75611115, 20.38943291], [86.75611115, 20.38916588], [86.75666809, 20.38861084], [86.75694275, 20.38861084], [86.75722504, 20.38888931], [86.75777435, 20.38944435], [86.75776672, 20.38972092], [86.75805664, 20.38999939], [86.75805664, 20.39027977], [86.7583313, 20.39055634], [86.7583313, 20.39110947], [86.75861359, 20.39138794], [86.75861359, 20.39194489], [86.75888824, 20.39221954], [86.75888824, 20.39305496], [86.7591629, 20.39333344], [86.7591629, 20.39444351], [86.75944519, 20.39472008], [86.75972748, 20.39499855], [86.75971985, 20.39527893], [86.76027679, 20.39582825], [86.76027679, 20.39610863], [86.7611084, 20.39694405], [86.76249695, 20.39694405], [86.76277924, 20.39722252], [86.76304626, 20.39722252], [86.76333618, 20.3975029], [86.76360321, 20.39755249], [86.7636795, 20.39756775], [86.76389313, 20.39777946], [86.76416779, 20.39777946], [86.76444244, 20.3975029], [86.76499939, 20.3975029], [86.76526642, 20.39777946], [86.76555634, 20.39777756], [86.76611328, 20.3983326], [86.76638794, 20.3983326], [86.76667023, 20.39805603], [86.76693726, 20.39805984], [86.76721954, 20.39777946], [86.76805878, 20.39777946], [86.76832581, 20.39805984], [86.76889801, 20.39805984], [86.76917267, 20.39777946], [86.76999664, 20.39777946], [86.77027893, 20.3975029], [86.77054596, 20.3975029], [86.77083588, 20.39722252], [86.77111053, 20.39722252], [86.77138519, 20.39694405], [86.77249908, 20.39694405], [86.77278137, 20.39666748], [86.77305603, 20.39666939], [86.77388763, 20.39582825], [86.77416992, 20.39583397], [86.77444458, 20.3955555], [86.77471161, 20.39555931], [86.77500153, 20.39528084], [86.77527618, 20.39528084], [86.77610779, 20.3944397], [86.77639008, 20.39444351], [86.77666473, 20.39416885], [86.77722168, 20.39417076], [86.77971649, 20.39167023], [86.77971649, 20.39138985], [86.77999878, 20.39110947], [86.77999878, 20.3908329], [86.78083038, 20.38999939], [86.78083038, 20.38972282], [86.78111267, 20.38944435], [86.78111267, 20.38888931], [86.78166962, 20.38833046], [86.78166962, 20.38777733], [86.78193665, 20.38750076], [86.78193665, 20.3866806], [86.78221893, 20.38639069], [86.78221893, 20.38582993], [86.78194427, 20.38555527], [86.78221893, 20.38528061], [86.78221893, 20.38362122], [86.78193665, 20.38332939], [86.78194427, 20.38305473], [86.78166962, 20.38277817], [86.78166962, 20.38221931], [86.78111267, 20.38166618], [86.78111267, 20.38139153], [86.77971649, 20.37999916], [86.77916718, 20.37999916], [86.77889252, 20.37972069], [86.77833557, 20.3797226], [86.77805328, 20.37944412], [86.77639008, 20.37944412], [86.77610779, 20.37916946], [86.77555847, 20.37916946], [86.77527618, 20.37889099], [86.77471924, 20.37888718], [86.77444458, 20.37861061], [86.77388763, 20.37861061], [86.77361298, 20.37833023], [86.77333069, 20.37833405], [86.77305603, 20.37805557], [86.77278137, 20.37805939], [86.77222443, 20.37749863], [86.77166748, 20.37693977], [86.77166748, 20.37666512], [86.76972198, 20.37471962], [86.76972198, 20.37444305], [86.76917267, 20.37388992], [86.76917267, 20.37360954], [86.76889038, 20.37333488], [86.76889038, 20.37305641], [86.76860809, 20.37277985], [86.76860809, 20.3722229], [86.76721954, 20.37083244], [86.76694489, 20.37083244], [86.76611328, 20.37000275], [86.76611328, 20.36972237], [86.76583099, 20.36944389], [86.76583099, 20.36889076], [86.76526642, 20.36832047], [86.76527405, 20.36805534], [86.76499939, 20.36778069], [86.76499939, 20.3674984], [86.7647171, 20.36721992], [86.76472473, 20.36694527], [86.76416779, 20.36638832], [86.76416779, 20.36582947], [86.76472473, 20.36527634], [86.76555634, 20.36610985], [86.76555634, 20.36638832], [86.76583099, 20.36667061], [86.76583099, 20.36694527], [86.76611328, 20.36721992], [86.76611328, 20.3674984], [86.76638794, 20.36778069], [86.76638794, 20.36805916], [86.76693726, 20.36860847], [86.76694489, 20.36889076], [86.76750183, 20.36944389], [86.76750183, 20.36972237], [86.76794434, 20.36998177], [86.76838684, 20.37033272], [86.7688446, 20.37068176], [86.76927948, 20.37105942], [86.76972961, 20.37138939], [86.77017212, 20.37170982], [86.77056122, 20.37207794], [86.77091217, 20.37244034], [86.7712326, 20.37275124], [86.771492, 20.37301826], [86.77172089, 20.37329102], [86.7719574, 20.37360191], [86.77222443, 20.37395668], [86.7725296, 20.37439156], [86.7728653, 20.37487793], [86.77321625, 20.3753624], [86.77379608, 20.37560463], [86.77444458, 20.37583351], [86.77471924, 20.37583351], [86.77500153, 20.37611198], [86.77527618, 20.37611008], [86.77555847, 20.37639046], [86.77583313, 20.37611008], [86.77597046, 20.37611008], [86.77639008, 20.37611198], [86.77666473, 20.37583351], [86.77777863, 20.37583351], [86.77805328, 20.37555695], [86.77861023, 20.37555695], [86.77889252, 20.37583351], [86.77944183, 20.37583351], [86.77955627, 20.37594414], [86.77972412, 20.37611198], [86.78028107, 20.37611008], [86.78056335, 20.37639046], [86.78083801, 20.37639046], [86.78134918, 20.37634087], [86.78188324, 20.37652969], [86.78250122, 20.37661743], [86.78312683, 20.37668037], [86.78376007, 20.37690163], [86.78436279, 20.37742043], [86.78495026, 20.37746239], [86.78552246, 20.37720108], [86.78607941, 20.37691498], [86.78637695, 20.37651253], [86.78623199, 20.3759613], [86.78598022, 20.37540627], [86.78573608, 20.37490082], [86.78553009, 20.37447357], [86.78522491, 20.37412071], [86.78491974, 20.37380028], [86.78464508, 20.37347984], [86.78457642, 20.37301636], [86.78472137, 20.37239075], [86.78465271, 20.37207031], [86.78446198, 20.37183952], [86.78427887, 20.37158585], [86.78410339, 20.37127113], [86.78380585, 20.37092972], [86.78343201, 20.37051964], [86.78301239, 20.37001991], [86.78256989, 20.36947441], [86.78208923, 20.36894035], [86.78166962, 20.36837959], [86.78125763, 20.36786652], [86.78085327, 20.36742973], [86.78056335, 20.36699104], [86.78027344, 20.36655998], [86.78000641, 20.36610985], [86.77971649, 20.36555099], [86.77972412, 20.36527634], [86.77944183, 20.36499977], [86.77944183, 20.36471939], [86.77916718, 20.36444473], [86.77916718, 20.36416626], [86.77889252, 20.36388969], [86.77889252, 20.36361122], [86.77861023, 20.36333084], [86.77861023, 20.36305428], [86.7783432, 20.36277962], [86.7783432, 20.36222076], [86.77805328, 20.3619442], [86.77805328, 20.36166573], [86.77783966, 20.36138344], [86.77777863, 20.36083412], [86.77749634, 20.36055565], [86.77749634, 20.35917091], [86.77722168, 20.35889053], [86.77749634, 20.35861015], [86.77749634, 20.35833359], [86.77757263, 20.3582592], [86.77777863, 20.35805511], [86.777771, 20.3555603], [86.77861023, 20.35471916], [86.77861023, 20.35528183], [86.77889252, 20.35555649], [86.77889252, 20.35611153], [86.77916718, 20.35638046], [86.77916718, 20.35667038], [86.77889252, 20.35695267], [86.77889252, 20.35889053], [86.77916718, 20.35917091], [86.77916718, 20.35944366], [86.77944183, 20.35972023], [86.77944183, 20.36028099], [86.77971649, 20.36055946], [86.77972412, 20.36166573], [86.77999878, 20.3619442], [86.77999878, 20.36222076], [86.78083038, 20.36305428], [86.78083801, 20.36361122], [86.78111267, 20.36388969], [86.78250122, 20.36527634], [86.78250122, 20.36555099], [86.78388977, 20.36694527], [86.7838974, 20.36721992], [86.78444672, 20.36778069], [86.78444672, 20.36805916], [86.78666687, 20.3702774], [86.78666687, 20.37083244], [86.78749847, 20.37166977], [86.78833008, 20.37083244], [86.78833008, 20.37055588], [86.78861237, 20.37028122], [86.78861237, 20.37000275], [86.78888702, 20.36972237], [86.78861237, 20.36944389], [86.78861237, 20.36805534], [86.78916931, 20.3674984], [86.78916931, 20.36721992], [86.78944397, 20.36694527], [86.78943634, 20.36667061], [86.78916931, 20.36638832], [86.78916931, 20.36610985], [86.78861237, 20.36555481], [86.78884125, 20.36532593], [86.78944397, 20.3647213], [86.78916931, 20.36444473], [86.78916931, 20.36361122], [86.79000092, 20.36277962], [86.79000092, 20.36111069], [86.78943634, 20.36055946], [86.78943634, 20.36028099], [86.789711, 20.36000061], [86.78943634, 20.35972023], [86.78971863, 20.35944366], [86.789711, 20.35917091], [86.78916931, 20.35861015], [86.78916931, 20.35833359], [86.78861237, 20.35777855], [86.78833008, 20.35750008], [86.78833008, 20.3572216], [86.78805542, 20.35694504], [86.78806305, 20.35667038], [86.78694153, 20.3555603], [86.78694153, 20.35528183], [86.78666687, 20.35500145], [86.78666687, 20.35471916], [86.78444672, 20.35250092], [86.78444672, 20.35222054], [86.78416443, 20.35194397], [86.78416443, 20.35166931], [86.7838974, 20.35139084], [86.7838974, 20.35111046], [86.78360748, 20.35083389], [86.78360748, 20.35055542], [86.78277588, 20.34972], [86.78277588, 20.34944534], [86.78221893, 20.3488903], [86.78221893, 20.34860992], [86.78194427, 20.34833336], [86.78194427, 20.34805489], [86.78166962, 20.34777832], [86.78166962, 20.34721947], [86.78111267, 20.34666634], [86.78111267, 20.34638977], [86.78083801, 20.34610939], [86.78083038, 20.34583473], [86.77777863, 20.34277725], [86.77749634, 20.34278107], [86.77722168, 20.34250069], [86.77694702, 20.34250069], [86.77610779, 20.34333038], [86.77610779, 20.34361267], [86.77583313, 20.34389114], [86.77610779, 20.3441658], [86.77610779, 20.34472275], [86.77583313, 20.34499931], [86.77583313, 20.34583473], [86.77555847, 20.34610939], [86.77555847, 20.34638977], [86.77527618, 20.34666634], [86.77527618, 20.34694481], [86.77475739, 20.34745979], [86.77443695, 20.34750938], [86.77419281, 20.34724617], [86.77388763, 20.34722137], [86.77361298, 20.34694481], [86.77361298, 20.34666634], [86.77388763, 20.34638977], [86.77388763, 20.34610939], [86.77471924, 20.34527779], [86.77471161, 20.34416962], [86.77443695, 20.34389114], [86.77443695, 20.34305954], [86.77416992, 20.34278107], [86.77416992, 20.3422184], [86.77471924, 20.34166718], [86.77471161, 20.34056091], [86.77500153, 20.34028053], [86.77500153, 20.33971977], [86.77471924, 20.33944511], [86.77471161, 20.33917046], [86.77443695, 20.33888817], [86.77443695, 20.33834076], [86.77471161, 20.33806038], [86.7743988, 20.33777809], [86.77416992, 20.33777809], [86.77249908, 20.33611107], [86.77249908, 20.33583069], [86.77138519, 20.33472252], [86.77138519, 20.33444595], [86.77111053, 20.33416748], [86.77111053, 20.33361053], [86.77054596, 20.33306122], [86.77054596, 20.33250046], [86.76917267, 20.33111191], [86.76889038, 20.33111382], [86.76860809, 20.33083344], [86.76833344, 20.33083344], [86.76805878, 20.33055496], [86.76777649, 20.33056068], [86.76721954, 20.33000183], [86.76693726, 20.33000183], [86.76667023, 20.32971954], [86.76638794, 20.32971954], [86.76611328, 20.32944489], [86.76583099, 20.32944489], [86.76472473, 20.32833481], [86.76416779, 20.32777977], [86.76389313, 20.32778168], [86.76333618, 20.32722092], [86.76305389, 20.32722282], [86.76277924, 20.32694435], [86.76249695, 20.32694435], [86.76222229, 20.32666588], [86.76194763, 20.32666969], [86.76167297, 20.32640076], [86.76139069, 20.32640076], [86.7611084, 20.32611084], [86.76082611, 20.32611084], [86.76027679, 20.32555962], [86.76000214, 20.32555962], [86.7591629, 20.32472038], [86.75888824, 20.32472229], [86.75879669, 20.32462883], [86.75861359, 20.32444382], [86.7583313, 20.32444382], [86.75819397, 20.3243084], [86.75805664, 20.32416534], [86.75776672, 20.32417107], [86.75749969, 20.32389069], [86.75723267, 20.32389069], [86.75694275, 20.32361031], [86.7563858, 20.32361031], [86.75583649, 20.32306099], [86.75554657, 20.32306099], [86.75499725, 20.32250023], [86.75332642, 20.32250023], [86.7527771, 20.32195091], [86.75222015, 20.32195091], [86.75166321, 20.32139015], [86.75138855, 20.32139015], [86.75, 20.31999969], [86.74972534, 20.31999969], [86.7491684, 20.31944466], [86.74888611, 20.31944466], [86.74861145, 20.31916618], [86.74833679, 20.31917], [86.74804688, 20.31888962], [86.74777985, 20.31888962], [86.74694824, 20.31805611], [86.74666595, 20.31805992], [86.74610901, 20.31750107], [86.74582672, 20.31750107], [86.74570465, 20.31737137], [86.74555206, 20.31720924], [86.7452774, 20.3172226], [86.74472046, 20.31666756], [86.74415588, 20.31611252], [86.74388885, 20.31611252], [86.74305725, 20.31528091], [86.74305725, 20.31500053], [86.74223328, 20.31417084], [86.74194336, 20.31417084], [86.74166107, 20.31389046], [86.74166107, 20.31360817], [86.74111176, 20.31305504], [86.74111176, 20.31278038], [86.73805237, 20.30972099], [86.73777771, 20.30944443], [86.73750305, 20.30944443], [86.73694611, 20.30888939], [86.73665619, 20.30888939], [86.73638916, 20.30861092], [86.73610687, 20.30861092], [86.73583221, 20.30833054], [86.73555756, 20.30833244], [86.73500061, 20.3077774], [86.73472595, 20.30778122], [86.73443604, 20.30750084], [86.73361206, 20.30750084], [86.73332977, 20.30722046], [86.73222351, 20.30722237], [86.73205566, 20.30705452], [86.73194122, 20.30694389], [86.72972107, 20.30694389], [86.72958374, 20.30680466], [86.72944641, 20.30666733], [86.72721863, 20.30667114], [86.72693634, 20.30639076], [86.72638702, 20.30638885], [86.72583008, 20.30694389], [86.72555542, 20.30694389], [86.72528076, 20.30722237], [86.72499847, 20.30722237], [86.72472382, 20.30694389], [86.72472382, 20.30666733], [86.72444153, 20.30639076], [86.72389221, 20.30639076], [86.72381592, 20.30631065], [86.72333527, 20.30583382], [86.72249603, 20.30583191], [86.72194672, 20.30639076], [86.7216568, 20.30639076], [86.72138977, 20.30611038], [86.72110748, 20.30611038], [86.72083282, 20.30583191], [86.72055817, 20.30583382], [86.72044373, 20.30572128], [86.72027588, 20.30555534], [86.72000122, 20.30556107], [86.71986389, 20.30541992], [86.71971893, 20.30527687], [86.71944427, 20.30527687], [86.71888733, 20.30472374], [86.71861267, 20.30472374], [86.71833038, 20.30444527], [86.71806335, 20.3044529], [86.71778107, 20.30417061], [86.71749878, 20.30417061], [86.71721649, 20.30389023], [86.71694183, 20.30389023], [86.71675873, 20.30370331], [86.71639252, 20.30333328], [86.71611023, 20.30333328], [86.71583557, 20.30305481], [86.71555328, 20.30305481], [86.71527863, 20.30277824], [86.71499634, 20.30278015], [86.71444702, 20.30220985], [86.71416473, 20.30221939], [86.71360779, 20.30166626], [86.71333313, 20.30167007], [86.71305847, 20.3013916], [86.71277618, 20.3013916], [86.71193695, 20.30055809], [86.71167755, 20.30055809], [86.71056366, 20.29944992], [86.70999908, 20.29888725], [86.7097168, 20.29889107], [86.70833588, 20.29750061], [86.70853424, 20.29389], [86.70861053, 20.29249954], [86.70944214, 20.29249954], [86.7097168, 20.29277992], [86.70999908, 20.29277992], [86.71028137, 20.29249954], [86.71221924, 20.29249954], [86.71250153, 20.29277992], [86.71277618, 20.29249954], [86.71305847, 20.29249954], [86.71333313, 20.29277992], [86.71360779, 20.29277992], [86.7141571, 20.29222107], [86.71444702, 20.29222488], [86.71472168, 20.2919445], [86.71555328, 20.2919426], [86.71639252, 20.29277992], [86.71721649, 20.29277992], [86.71806335, 20.2919426], [86.71805573, 20.29166603], [86.71848297, 20.2912426], [86.71861267, 20.2911129], [86.71888733, 20.2911129], [86.71888733, 20.29029083], [86.71861267, 20.29000282], [86.71861267, 20.28972244], [86.71833038, 20.28944397], [86.71833038, 20.28889084], [86.71806335, 20.28860855], [86.71805573, 20.28777885], [86.71721649, 20.28694916], [86.71694183, 20.28694916], [86.71639252, 20.2863903], [86.7158432, 20.2863903], [86.71527863, 20.28582954], [86.71472168, 20.28583336], [86.71444702, 20.28555489], [86.71416473, 20.28555489], [86.71360779, 20.28499985], [86.71305847, 20.28499985], [86.71277618, 20.28471947], [86.71250153, 20.28472137], [86.71221924, 20.28444481], [86.71194458, 20.28444481], [86.71180725, 20.28430557], [86.71166992, 20.28416634], [86.71138763, 20.28417015], [86.71111298, 20.28388977], [86.71083069, 20.28388977], [86.71028137, 20.28333092], [86.70972443, 20.28333282], [86.70944214, 20.28305435], [86.70889282, 20.28306007], [86.70861816, 20.28277969], [86.70804596, 20.28277969], [86.70777893, 20.28250122], [86.70722198, 20.28250122], [86.70708466, 20.28236008], [86.70694733, 20.28222084], [86.70666504, 20.28222275], [86.70639038, 20.28194427], [86.70610809, 20.28194427], [86.70583344, 20.2816658], [86.70527649, 20.28166962], [86.70500183, 20.28139114], [86.70471954, 20.28139114], [86.70443726, 20.28110123], [86.70388794, 20.28111076], [86.70361328, 20.2808342], [86.70333099, 20.2808342], [86.70277405, 20.28027725], [86.70194244, 20.28028107], [86.70166779, 20.28000069], [86.7013855, 20.28000069], [86.70111084, 20.27972221], [86.70083618, 20.27972221], [86.700737, 20.27962494], [86.70055389, 20.27944374], [86.70027924, 20.27944374], [86.69999695, 20.27916718], [86.69917297, 20.2791729], [86.69889069, 20.27889061], [86.69805908, 20.27889061], [86.69777679, 20.27861023], [86.69721985, 20.27861023], [86.69695282, 20.27833176], [86.69638824, 20.27833366], [86.69611359, 20.27805519], [86.6958313, 20.27806282], [86.69555664, 20.27778053], [86.69526672, 20.27778053], [86.69499969, 20.27750015], [86.69472504, 20.27750015], [86.69444275, 20.27722168], [86.6938858, 20.27722168], [86.69333649, 20.27666664], [86.69304657, 20.27667046], [86.69277954, 20.27639008], [86.69249725, 20.27639008], [86.6922226, 20.2761116], [86.69194794, 20.27583313], [86.69166565, 20.27583313], [86.69139099, 20.27555466], [86.6911087, 20.27555466], [86.6902771, 20.27472305], [86.69000244, 20.27472305], [86.68861389, 20.2733326], [86.68805695, 20.2733326], [86.68777466, 20.27305794], [86.68749237, 20.27305984], [86.68723297, 20.27277946], [86.6866684, 20.27277946], [86.68554688, 20.27166939], [86.68527985, 20.27194405], [86.6847229, 20.27194405], [86.6838913, 20.27111053], [86.68332672, 20.27111053], [86.68305206, 20.27083015], [86.6827774, 20.27083397], [86.68250275, 20.2705555], [86.68222046, 20.27056122], [86.6819458, 20.27028084], [86.68165588, 20.27028084], [86.68138885, 20.27000046], [86.68110657, 20.27000046], [86.68026733, 20.26916122], [86.68027496, 20.26888847], [86.68000031, 20.26861], [86.68000031, 20.26805305], [86.68026733, 20.2677803], [86.68026733, 20.26694107], [86.68000031, 20.26666641], [86.68000031, 20.26610184], [86.68027496, 20.26583481], [86.68027496, 20.26527786], [86.68055725, 20.26499939], [86.68055725, 20.26468086], [86.68055725, 20.26388931], [86.68000031, 20.26333237], [86.67973328, 20.26333237], [86.67888641, 20.26416588], [86.67888641, 20.26444054], [86.67805481, 20.26527786], [86.67804718, 20.26610184], [86.67749786, 20.26666641], [86.67749786, 20.26694489], [86.67722321, 20.26694489], [86.67707825, 20.26680374], [86.67694092, 20.26666641], [86.67666626, 20.26667023], [86.67610931, 20.26610184], [86.67555237, 20.26667023], [86.67527771, 20.26667023], [86.67416382, 20.2677784], [86.67416382, 20.26833344], [86.67388916, 20.26861191], [86.67388916, 20.26916695], [86.67360687, 20.2694397], [86.67360687, 20.27139091], [86.67333221, 20.27166939], [86.67333221, 20.27249908], [86.67305756, 20.27277946], [86.67305756, 20.27305984], [86.67416382, 20.27416611], [86.67415619, 20.27444077], [86.67472076, 20.27500153], [86.67472076, 20.27527809], [86.67500305, 20.27555466], [86.67500305, 20.27582932], [86.67583466, 20.27666664], [86.67582703, 20.27722168], [86.67610931, 20.27750015], [86.67610931, 20.27778053], [86.6763916, 20.27806282], [86.6763916, 20.27861023], [86.67582703, 20.2791729], [86.67555237, 20.2791729], [86.67500305, 20.27861023], [86.67500305, 20.27833176], [86.67444611, 20.27777863], [86.67444611, 20.27722168], [86.67416382, 20.27694511], [86.67415619, 20.27667046], [86.67388916, 20.27639008], [86.67388916, 20.2761116], [86.6736145, 20.27583313], [86.6736145, 20.27555466], [86.67305756, 20.27500153], [86.67305756, 20.27471924], [86.67277527, 20.27444458], [86.67277527, 20.27416611], [86.67250824, 20.27388763], [86.67250061, 20.2733326], [86.67222595, 20.27333069], [86.67193604, 20.27360916], [86.67111206, 20.27360916], [86.67056274, 20.27416992], [86.67028046, 20.27416992], [86.66928864, 20.27515984], [86.66957092, 20.27563286], [86.66999817, 20.27722168], [86.67028046, 20.27750015], [86.67028046, 20.27778053], [86.67055511, 20.27805519], [86.67055511, 20.27833366], [86.67193604, 20.27972031], [86.67193604, 20.28000069], [86.67222595, 20.28027725], [86.67222595, 20.28110123], [86.67194366, 20.28138924], [86.67194366, 20.28194427], [86.67166901, 20.28222275], [86.67111206, 20.28222275], [86.67082977, 20.28194427], [86.67082977, 20.2816658], [86.67056274, 20.28139114], [86.67056274, 20.28110123], [86.67028046, 20.2808342], [86.67028046, 20.28027725], [86.66999817, 20.28000069], [86.66999817, 20.27943993], [86.66972351, 20.27916718], [86.66971588, 20.27861023], [86.66944885, 20.27833176], [86.66944122, 20.27805519], [86.66916656, 20.27778053], [86.66777802, 20.2761116], [86.66666412, 20.27500153], [86.66665649, 20.27444077], [86.66638947, 20.27416611], [86.66638184, 20.27333069], [86.66694641, 20.27277946], [86.66694641, 20.27249908], [86.66722107, 20.27222824], [86.66750336, 20.27222824], [86.66832733, 20.27139091], [86.66832733, 20.27111053], [86.66860962, 20.27083015], [86.66860962, 20.2705555], [86.66889191, 20.27028084], [86.66889191, 20.27000046], [86.66916656, 20.26972008], [86.66944122, 20.26972198], [86.66972351, 20.26944351], [86.67055511, 20.26944351], [86.67082977, 20.26916695], [86.67111206, 20.26916695], [86.67250061, 20.2677784], [86.67250824, 20.26749992], [86.67277527, 20.26722145], [86.67277527, 20.26666641], [86.67360687, 20.2658329], [86.6736145, 20.26555634], [86.67333221, 20.26527977], [86.67333221, 20.26499939], [86.67305756, 20.26472282], [86.67305756, 20.26444435], [86.67277527, 20.26416588], [86.6727829, 20.26250076], [86.6736145, 20.26166725], [86.67388916, 20.26166916], [86.67444611, 20.2611084], [86.67472076, 20.2611084], [86.67500305, 20.26082993], [86.67555237, 20.26083374], [86.67583466, 20.26055527], [86.67610931, 20.26055908], [86.6763916, 20.26029015], [86.67666626, 20.26029015], [86.67694092, 20.25999832], [86.67778015, 20.25999832], [86.67804718, 20.25971985], [86.67972565, 20.25972176], [86.68027496, 20.25916862], [86.68055725, 20.25917053], [86.68055725, 20.25888824], [86.67973328, 20.25805092], [86.6783371, 20.25805473], [86.67805481, 20.25833321], [86.67694092, 20.25832939], [86.67591095, 20.25834274], [86.67539978, 20.25834846], [86.67404938, 20.25788116], [86.67183685, 20.25761032], [86.66932678, 20.25653076], [86.6682663, 20.25630379], [86.66712189, 20.25605392], [86.66388702, 20.2547226], [86.66204071, 20.25406837], [86.66068268, 20.25392914], [86.65860748, 20.25305557], [86.65619659, 20.25259972], [86.65333557, 20.25138855], [86.6516571, 20.25056267], [86.64977264, 20.25002098], [86.64733887, 20.24908066], [86.6446228, 20.24818993], [86.64319611, 20.24745369], [86.64095306, 20.24693871], [86.6388092, 20.24605942], [86.63630676, 20.24552155], [86.6348114, 20.24417114], [86.63210297, 20.2428894], [86.62953186, 20.2422142], [86.62617493, 20.24072838], [86.62333679, 20.23971939], [86.62220001, 20.23877335], [86.61977386, 20.23789978], [86.61776733, 20.23722267], [86.6166687, 20.23611259], [86.61638641, 20.23612022], [86.6158371, 20.23555946], [86.61554718, 20.23555946], [86.61527252, 20.23527908], [86.61472321, 20.23527908], [86.61444092, 20.23500061], [86.6138916, 20.23500061], [86.61360931, 20.23471832], [86.61333466, 20.23472214], [86.61305237, 20.23444366], [86.61277771, 20.23444366], [86.61222076, 20.23389053], [86.61194611, 20.23389053], [86.61165619, 20.23360825], [86.6111145, 20.23361206], [86.61055756, 20.23305511], [86.61027527, 20.23305511], [86.61000061, 20.23277664], [86.60972595, 20.23278046], [86.60943604, 20.23249817], [86.60916901, 20.23249817], [86.60694122, 20.23167038], [86.60639191, 20.23110962], [86.60610962, 20.23111153], [86.60555267, 20.2305584], [86.60527802, 20.2305603], [86.60500336, 20.23027992], [86.60472107, 20.23027992], [86.60444641, 20.22999001], [86.60416412, 20.22999954], [86.60388947, 20.22972298], [86.60361481, 20.22972298], [86.60333252, 20.2294445], [86.60277557, 20.2294445], [86.60227203, 20.22894287], [86.60194397, 20.22861099], [86.60166931, 20.22861099], [86.60111237, 20.22805977], [86.60083008, 20.22805977], [86.59999847, 20.22722054], [86.59972382, 20.22722244], [86.59944153, 20.22694206], [86.59916687, 20.22694969], [86.59860992, 20.22639084], [86.5983429, 20.22639084], [86.59777832, 20.22583008], [86.59750366, 20.22583389], [86.59722137, 20.22555542], [86.59610748, 20.22555542], [86.59583282, 20.22583389], [86.59555817, 20.22583008], [86.59527588, 20.22611046], [86.59500122, 20.22611046], [86.59471893, 20.22639084], [86.59416962, 20.22583008], [86.59388733, 20.22583389], [86.59361267, 20.22555733], [86.59333038, 20.22527695], [86.59306335, 20.22528076], [86.59278107, 20.22500038], [86.59221649, 20.22500038], [86.59199524, 20.22477722], [86.59194183, 20.22472191], [86.59083557, 20.22472382], [86.58963776, 20.22352982], [86.58916473, 20.22305489], [86.58889008, 20.22305489], [86.58750153, 20.22166634], [86.58721924, 20.22167015], [86.58693695, 20.22139168], [86.58666992, 20.22139168], [86.58555603, 20.22027969], [86.585289, 20.22027969], [86.58499908, 20.22000122], [86.5847168, 20.22000122], [86.58448792, 20.21976852], [86.58416748, 20.21972275], [86.58398438, 20.21953964], [86.58361053, 20.2191658], [86.58333588, 20.21916962], [86.58304596, 20.21889114], [86.58304596, 20.21861076], [86.58277893, 20.21833038], [86.58249664, 20.2183342], [86.58222198, 20.21805573], [86.58194733, 20.21805], [86.58139038, 20.21861076], [86.58082581, 20.21861076], [86.58055878, 20.21889114], [86.58055878, 20.21916962], [86.58027649, 20.2191658], [86.58000183, 20.21944427], [86.57971954, 20.21944427], [86.57955933, 20.21928406], [86.57917023, 20.21888733], [86.57861328, 20.21889114], [86.57833099, 20.21861076], [86.5772171, 20.21861076], [86.57694244, 20.21833038], [86.57555389, 20.2183342], [86.57527924, 20.21805573], [86.57499695, 20.21805573], [86.57472229, 20.21777534], [86.57417297, 20.21778107], [86.5736084, 20.21722031], [86.57333374, 20.21722221], [86.57305908, 20.21694374], [86.57277679, 20.21694374], [86.57263947, 20.2168045], [86.57250214, 20.21666527], [86.57221985, 20.21667099], [86.57211304, 20.21656036], [86.57194519, 20.2163887], [86.5716629, 20.21639061], [86.5707016, 20.21542549], [86.56972504, 20.21444321], [86.56944275, 20.21445084], [86.56916809, 20.21417046], [86.5680542, 20.21416664], [86.56749725, 20.21472168], [86.56694794, 20.21472168], [86.56666565, 20.21444321], [86.56639099, 20.21445084], [86.5661087, 20.21417046], [86.56582642, 20.21417046], [86.56535339, 20.2136898], [86.5652771, 20.2136097], [86.56500244, 20.2136116], [86.56472015, 20.21333313], [86.5644455, 20.21333313], [86.56416321, 20.21305466], [86.56388855, 20.21305466], [86.5633316, 20.21249962], [86.56305695, 20.21249962], [86.56194305, 20.21138954], [86.56194305, 20.21111107], [86.56111908, 20.21027946], [86.56111908, 20.2100029], [86.56027985, 20.20916939], [86.55999756, 20.20916939], [86.5597229, 20.20889091], [86.5588913, 20.20889091], [86.55860901, 20.20860863], [86.55832672, 20.20860863], [86.55805969, 20.20832825], [86.5577774, 20.20833397], [86.55750275, 20.2080555], [86.55722046, 20.20805931], [86.5569458, 20.20778084], [86.55638885, 20.20778084], [86.55610657, 20.20805931], [86.55527496, 20.2080555], [86.55473328, 20.20860863], [86.55472565, 20.20916748], [86.55444336, 20.20944405], [86.55444336, 20.20972252], [86.5541687, 20.2100029], [86.55361176, 20.2100029], [86.55347443, 20.20986176], [86.5533371, 20.20972252], [86.55305481, 20.20972252], [86.55249786, 20.20916748], [86.55222321, 20.20916939], [86.55110931, 20.20805931], [86.55110931, 20.20778084], [86.54944611, 20.20610809], [86.54916382, 20.20611191], [86.54777527, 20.20472145], [86.54777527, 20.20444489], [86.54750061, 20.20416641], [86.54750061, 20.20388985], [86.54582977, 20.20222092], [86.54582977, 20.20194435], [86.54611206, 20.20166588], [86.54582977, 20.20139122], [86.54614258, 20.20055008], [86.54564667, 20.19967079], [86.54556274, 20.19833183], [86.54555511, 20.19805527], [86.54471588, 20.19722176], [86.54389191, 20.19722176], [86.54360962, 20.19750023], [86.54277802, 20.19750023], [86.54222107, 20.19805527], [86.54222107, 20.19833183], [86.54194641, 20.19861031], [86.54194641, 20.19889069], [86.54165649, 20.19917107], [86.54165649, 20.20028114], [86.54164886, 20.20119858], [86.541008, 20.20187187], [86.53888702, 20.20111084], [86.53861237, 20.20111084], [86.53833008, 20.20083046], [86.53778076, 20.20083427], [86.53749847, 20.2005558], [86.53721619, 20.20055962], [86.53666687, 20.2000103], [86.53610992, 20.2000103], [86.53472137, 20.19861031], [86.53472137, 20.19833183], [86.53305817, 20.19666672], [86.53277588, 20.19667053], [86.53277588, 20.19639015], [86.53250122, 20.19611168], [86.53250122, 20.19555473], [86.53166962, 20.19472313], [86.53083038, 20.19472313], [86.52972412, 20.19360924], [86.52944183, 20.19360924], [86.52916718, 20.19387817], [86.52916718, 20.19416618], [86.52889252, 20.19444466], [86.52889252, 20.19471931], [86.52861023, 20.1950016], [86.52805328, 20.1950016], [86.52749634, 20.19444084], [86.52749634, 20.19416618], [86.5266571, 20.19333076], [86.52666473, 20.19305611], [86.52583313, 20.19222069], [86.52583313, 20.19138718], [86.52527618, 20.19082069], [86.52471924, 20.19083405], [86.52444458, 20.19055557], [86.52443695, 20.19028091], [86.52388763, 20.18972015], [86.52305603, 20.18972206], [86.52278137, 20.18944359], [86.52249908, 20.18944359], [86.52138519, 20.18833351], [86.52055359, 20.18833351], [86.51810455, 20.18728447], [86.51721954, 20.18638802], [86.51693726, 20.18610954], [86.51694489, 20.18583488], [86.51611328, 20.18499947], [86.51582336, 20.18499947], [86.51499939, 20.18416977], [86.51499939, 20.18388939], [86.51444244, 20.18333244], [86.51444244, 20.18305588], [86.51416779, 20.18278122], [86.51416779, 20.18250275], [86.51361084, 20.18193817], [86.51333618, 20.18194389], [86.51305389, 20.18166733], [86.51277924, 20.18166924], [86.51235962, 20.18125153], [86.51194763, 20.18082809], [86.51166534, 20.18083382], [86.51148224, 20.1806488], [86.51139069, 20.18055534], [86.51139069, 20.18028069], [86.5111084, 20.1799984], [86.5111084, 20.17860985], [86.51139069, 20.17833328], [86.51083374, 20.17777634], [86.51055908, 20.17805481], [86.50971985, 20.1772213], [86.50945282, 20.17721939], [86.5091629, 20.17749977], [86.50888824, 20.17721939], [86.50805664, 20.1772213], [86.50777435, 20.17694473], [86.50723267, 20.17749977], [86.50694275, 20.17749977], [86.5055542, 20.17888641], [86.5047226, 20.17888641], [86.50389099, 20.17972183], [86.5036087, 20.17944527], [86.50332642, 20.17944908], [86.50297546, 20.17908859], [86.5027771, 20.17888641], [86.50195312, 20.17888069], [86.50166321, 20.17917061], [86.50138855, 20.17917061], [86.50110626, 20.17944908], [86.50055695, 20.17944527], [86.50027466, 20.17972183], [86.49861145, 20.17971992], [86.49833679, 20.1799984], [86.49804688, 20.1799984], [86.49749756, 20.18055916], [86.49555206, 20.18055534], [86.4952774, 20.18083382], [86.49500275, 20.18082809], [86.49472046, 20.18110847], [86.4944458, 20.18110847], [86.49415588, 20.18139076], [86.49388885, 20.18139076], [86.49360657, 20.18166924], [86.49360657, 20.18278122], [86.49582672, 20.18499947], [86.49610901, 20.18499947], [86.49666595, 20.18556023], [86.49694824, 20.18555641], [86.4972229, 20.18583488], [86.49749756, 20.18583107], [86.4991684, 20.1875], [86.4991684, 20.18805313], [86.49944305, 20.18833351], [86.49944305, 20.18861198], [86.49973297, 20.18861008], [86.50027466, 20.18916512], [86.5, 20.18944359], [86.49972534, 20.18944359], [86.49944305, 20.18972206], [86.4991684, 20.18972015], [86.49888611, 20.19000053], [86.49861145, 20.19000053], [86.49833679, 20.19028091], [86.49749756, 20.19028091], [86.4972229, 20.19000053], [86.4972229, 20.18972015], [86.49777985, 20.18916512], [86.49804688, 20.18917084], [86.49833679, 20.18889046], [86.4972229, 20.18778038], [86.49694824, 20.18778038], [86.49610901, 20.18695068], [86.49582672, 20.18695068], [86.49555206, 20.1866703], [86.4952774, 20.1866703], [86.49417114, 20.1855545], [86.49305725, 20.18444252], [86.49277496, 20.18444443], [86.49277496, 20.18388939], [86.49223328, 20.18333244], [86.49194336, 20.18333244], [86.49194336, 20.18305588], [86.49223328, 20.18278122], [86.49223328, 20.18221855], [86.49250031, 20.18194389], [86.49250031, 20.18055534], [86.49276733, 20.18028069], [86.49276733, 20.1799984], [86.49333191, 20.17944908], [86.49360657, 20.17944908], [86.49388885, 20.17917061], [86.49415588, 20.17917061], [86.4944458, 20.17888069], [86.49472046, 20.17888641], [86.4952774, 20.17833328], [86.4952774, 20.17777634], [86.49500275, 20.17749977], [86.4952774, 20.17721939], [86.49500275, 20.17694473], [86.49472046, 20.17694473], [86.49388885, 20.17611122], [86.49388885, 20.17556], [86.49415588, 20.17527962], [86.49388885, 20.17500114], [86.49388885, 20.17472076], [86.49250031, 20.17333221], [86.49222565, 20.17333221], [86.49194336, 20.17305565], [86.4916687, 20.17305946], [86.49138641, 20.17278099], [86.49054718, 20.17278099], [86.49028015, 20.17250061], [86.48972321, 20.17250061], [86.48944092, 20.17222023], [86.48833466, 20.17222214], [86.48805237, 20.17194366], [86.48777771, 20.17194366], [86.48750305, 20.1716671], [86.48638916, 20.1716671], [86.48583221, 20.17222214], [86.48416901, 20.17222214], [86.48388672, 20.17194366], [86.48361206, 20.17194366], [86.48347473, 20.17180824], [86.48332977, 20.1716671], [86.48306274, 20.17167282], [86.4828949, 20.1715107], [86.48278046, 20.17138863], [86.48249817, 20.17139053], [86.48055267, 20.16945267], [86.48055267, 20.16861153], [86.47972107, 20.16777992], [86.47970581, 20.16749763], [86.47944641, 20.16721916], [86.47944641, 20.1669445], [86.47861481, 20.16610909], [86.47833252, 20.16610909], [86.47805786, 20.16583061], [86.47777557, 20.16583252], [86.47750092, 20.16555786], [86.47666931, 20.16555786], [86.47528076, 20.16694069], [86.47528076, 20.16889191], [86.47499847, 20.16917038], [86.47444153, 20.16917038], [86.47416687, 20.16889191], [86.47416687, 20.16778183], [86.47389984, 20.16749763], [86.47389221, 20.16638756], [86.47416687, 20.16610909], [86.47416687, 20.16583061], [86.47472382, 20.16527939], [86.47583008, 20.16417122], [86.47528076, 20.16361046], [86.47499847, 20.16361046], [86.47471619, 20.16333008], [86.47444153, 20.16333389], [86.47416687, 20.16305542], [86.47389984, 20.16306114], [86.47362518, 20.16278648], [86.47277832, 20.16194534], [86.47277832, 20.16167068], [86.47249603, 20.1613903], [86.47249603, 20.16110992], [86.47222137, 20.16083336], [86.47222137, 20.16055107], [86.47194672, 20.16027832], [86.47194672, 20.15888977], [86.4716568, 20.15860939], [86.47194672, 20.15833282], [86.47194672, 20.15805626], [86.47222137, 20.15777016], [86.47250366, 20.15777779], [86.47277832, 20.15749931], [86.47277832, 20.15722275], [86.47305298, 20.15694427], [86.47305298, 20.1566658], [86.4733429, 20.15639114], [86.4733429, 20.15500069], [86.47360992, 20.15472221], [86.47360992, 20.15305519], [86.4733429, 20.15278053], [86.4733429, 20.15221977], [86.47277832, 20.15166855], [86.47277832, 20.15138817], [86.47249603, 20.1511097], [86.47250366, 20.15055466], [86.47166443, 20.14972305], [86.47138977, 20.14972305], [86.47083282, 20.1491642], [86.47084045, 20.14890099], [86.47055817, 20.14890099], [86.46943665, 20.14777946], [86.46916962, 20.14777946], [86.46888733, 20.14750099], [86.46861267, 20.14750099], [86.46847534, 20.14736176], [86.46833038, 20.14722061], [86.4658432, 20.14722061], [86.46555328, 20.14750099], [86.46527863, 20.14750099], [86.46499634, 20.14777946], [86.46472168, 20.14777756], [86.46376801, 20.14855194], [86.46305847, 20.1511097], [86.46305847, 20.15138817], [86.46277618, 20.15167046], [86.46277618, 20.15194511], [86.46250153, 20.15221977], [86.46193695, 20.15389061], [86.46194458, 20.15416718], [86.46166992, 20.15443993], [86.46166992, 20.15500069], [86.46045685, 20.15732002], [86.46038055, 20.15812874], [86.46053314, 20.15906906], [86.46083069, 20.16084099], [86.46083069, 20.16194534], [86.46055603, 20.16222191], [86.45999908, 20.16222191], [86.45972443, 20.16194534], [86.4597168, 20.16167068], [86.45944214, 20.1613903], [86.45944214, 20.16084099], [86.45916748, 20.16055107], [86.45916748, 20.15777779], [86.45944214, 20.15749931], [86.45944214, 20.15639114], [86.4597168, 20.15611267], [86.4597168, 20.15527916], [86.45999908, 20.15500069], [86.45999908, 20.15389061], [86.46055603, 20.15332985], [86.46055603, 20.15305519], [86.46111298, 20.15249825], [86.46111298, 20.15221977], [86.46138763, 20.15194511], [86.46138763, 20.1511097], [86.46166992, 20.15083313], [86.46166992, 20.14999962], [86.46277618, 20.14833069], [86.46472168, 20.14638901], [86.46499634, 20.14639091], [86.46604156, 20.14599037], [86.46761322, 20.14603996], [86.46861267, 20.14611053], [86.46888733, 20.14611053], [86.46916962, 20.14639091], [86.46944427, 20.14638901], [86.47027588, 20.14722252], [86.47055817, 20.14722061], [86.47110748, 20.14777946], [86.47138977, 20.14777946], [86.47222137, 20.14861107], [86.47249603, 20.14861107], [86.47305298, 20.1491642], [86.47305298, 20.14944077], [86.47389221, 20.15027618], [86.47389221, 20.15055466], [86.47416687, 20.15083122], [86.47416687, 20.15138817], [86.47444153, 20.15167046], [86.47444153, 20.15194511], [86.47471619, 20.15221977], [86.47472382, 20.15278053], [86.47528076, 20.15332985], [86.47528076, 20.15360832], [86.47499847, 20.15389061], [86.47499847, 20.15416718], [86.47472382, 20.15444374], [86.47471619, 20.15583229], [86.47444153, 20.15611267], [86.47444153, 20.15777016], [86.47416687, 20.15805626], [86.47416687, 20.16110992], [86.47444153, 20.1613903], [86.47444153, 20.16167068], [86.47528076, 20.16250038], [86.47556305, 20.16250038], [86.47583008, 20.16278076], [86.47750092, 20.16278076], [86.4777832, 20.16306114], [86.47805786, 20.16305542], [86.47833252, 20.16333389], [86.47860718, 20.16333008], [86.48027802, 20.16500092], [86.48027802, 20.16527939], [86.48082733, 20.16583061], [86.48083496, 20.16610909], [86.48444366, 20.1697216], [86.48472595, 20.16970825], [86.48500061, 20.17000008], [86.4852829, 20.17000008], [86.48555756, 20.1697216], [86.48833466, 20.1669445], [86.48833466, 20.16638756], [86.48860931, 20.16610909], [86.48860931, 20.16583061], [86.4888916, 20.16555786], [86.48887634, 20.16500092], [86.48916626, 20.16472054], [86.48916626, 20.16361046], [86.48944092, 20.16333008], [86.48944092, 20.16277695], [86.48972321, 20.16250038], [86.48972321, 20.16222], [86.48916626, 20.16166687], [86.48916626, 20.16110992], [86.48944092, 20.16083336], [86.48944092, 20.16028023], [86.48972321, 20.15999985], [86.48972321, 20.15971947], [86.4908371, 20.1586113], [86.4908371, 20.15805626], [86.49111176, 20.15777016], [86.49111176, 20.15749931], [86.4908371, 20.15722275], [86.4908371, 20.1566658], [86.49054718, 20.15639114], [86.49054718, 20.15611267], [86.48972321, 20.15527916], [86.48972321, 20.15500069], [86.48944092, 20.15471077], [86.48944092, 20.15278053], [86.48972321, 20.15249825], [86.48972321, 20.15221977], [86.48944092, 20.15194511], [86.48944092, 20.15167046], [86.48916626, 20.15138817], [86.48916626, 20.1511097], [86.48805237, 20.14999962], [86.48777771, 20.14999962], [86.48750305, 20.14972115], [86.48722076, 20.14972305], [86.4861145, 20.14861107], [86.48610687, 20.14722061], [86.48583221, 20.14694595], [86.48583221, 20.14666748], [86.48555756, 20.14639091], [86.48555756, 20.14556122], [86.48443604, 20.1444397], [86.48361206, 20.14444351], [86.48332977, 20.14472389], [86.48249817, 20.14472389], [86.48240662, 20.14463043], [86.48222351, 20.14444351], [86.48194122, 20.14444351], [86.48180389, 20.14430618], [86.48166656, 20.14416695], [86.48139191, 20.14417076], [86.48110962, 20.14389038], [86.48082733, 20.14389038], [86.48059845, 20.14365959], [86.47972107, 20.14361191], [86.47944641, 20.14333344], [86.47888947, 20.14333344], [86.47861481, 20.14305496], [86.47805786, 20.14306259], [86.47798157, 20.14297867], [86.47777557, 20.1427784], [86.47694397, 20.1427784], [86.47666931, 20.14250183], [86.47611237, 20.14250183], [86.47538757, 20.14188957], [86.47460175, 20.14141846], [86.47445679, 20.14075089], [86.474823, 20.13953018], [86.47553253, 20.13838196], [86.4761734, 20.13791084], [86.47666931, 20.13805771], [86.47666931, 20.13833046], [86.47583008, 20.13916588], [86.47583008, 20.13944054], [86.47556305, 20.13972855], [86.47556305, 20.14055824], [86.47638702, 20.14139175], [86.47721863, 20.14139175], [86.47750092, 20.14167023], [86.47805786, 20.14166641], [86.47833252, 20.14194489], [86.47944641, 20.14194489], [86.47972107, 20.14222145], [86.48166656, 20.14222145], [86.48194122, 20.14250183], [86.48221588, 20.14250183], [86.48249817, 20.14222145], [86.48332977, 20.14222145], [86.48361206, 20.14194489], [86.48388672, 20.14194489], [86.48416901, 20.14166641], [86.48416901, 20.14082909], [86.48444366, 20.14055634], [86.48443604, 20.14027977], [86.48416901, 20.13999748], [86.48388672, 20.13999748], [86.48361206, 20.13972855], [86.48332977, 20.13972855], [86.48221588, 20.13861084], [86.48166656, 20.13861084], [86.48110962, 20.13805962], [86.48055267, 20.13805962], [86.48000336, 20.13750076], [86.48000336, 20.13722038], [86.47888947, 20.13611031], [86.47888947, 20.13582993], [86.47861481, 20.13555527], [86.47860718, 20.13528061], [86.47833252, 20.13500023], [86.47833252, 20.13278008], [86.47888947, 20.13222122], [86.47916412, 20.13222313], [86.48000336, 20.13138962], [86.48000336, 20.1297226], [86.48027802, 20.12944412], [86.48027802, 20.12639046], [86.48000336, 20.12610817], [86.48000336, 20.12583351], [86.47888947, 20.12472153], [86.47666931, 20.12472916], [86.47638702, 20.12445068], [86.47471619, 20.12445068], [86.47444153, 20.12472916], [86.47416687, 20.12472916], [86.47360992, 20.1241703], [86.4733429, 20.1241703], [86.4730072, 20.12383461], [86.47250366, 20.12333298], [86.47222137, 20.12333298], [86.47194672, 20.12305832], [86.4716568, 20.12306023], [86.4716568, 20.12277985], [86.47110748, 20.12222099], [86.47110748, 20.12194443], [86.47083282, 20.12194443], [86.47083282, 20.12166405], [86.47000122, 20.12083244], [86.46971893, 20.12083244], [86.46944427, 20.12055588], [86.46916962, 20.12055969], [86.46888733, 20.12028122], [86.46861267, 20.12028122], [86.46833038, 20.12000084], [86.46805573, 20.12000084], [86.46749878, 20.11944389], [86.46722412, 20.11944389], [86.46694183, 20.11916733], [86.46639252, 20.11916733], [86.46583557, 20.11972237], [86.46555328, 20.11972237], [86.46527863, 20.11944389], [86.46527863, 20.11888885], [86.46499634, 20.11860275], [86.46499634, 20.11777687], [86.46470642, 20.11750031], [86.46470642, 20.11722183], [86.46333313, 20.11583328], [86.46305847, 20.11583328], [86.46277618, 20.11555481], [86.46277618, 20.11528015], [86.46221924, 20.11471939], [86.46221924, 20.11444473], [86.46250153, 20.11416626], [86.46250153, 20.11361122], [86.46277618, 20.11333084], [86.46277618, 20.1119442], [86.46305847, 20.11166573], [86.46305847, 20.11111069], [86.46277618, 20.11083031], [86.46277618, 20.11000061], [86.46250153, 20.10972023], [86.46250153, 20.10916519], [86.46277618, 20.10889053], [86.46277618, 20.10861015], [86.46333313, 20.10805321], [86.46470642, 20.10666084], [86.46472168, 20.10638809], [86.4658432, 20.10527992], [86.4658432, 20.10499954], [86.46611023, 20.10472107], [86.46611023, 20.1044445], [86.46694183, 20.1036129], [86.46721649, 20.10362053], [86.46749878, 20.10333252], [86.46833038, 20.10333252], [86.46861267, 20.10305595], [86.46916962, 20.10305977], [86.46943665, 20.10277939], [86.46971893, 20.10277939], [86.47000122, 20.10250282], [86.47027588, 20.10250282], [86.47084045, 20.10193825], [86.47083282, 20.10083389], [86.47055817, 20.10055542], [86.47055817, 20.10028076], [86.47000122, 20.09971809], [86.47000122, 20.09944534], [86.46943665, 20.0988903], [86.46971893, 20.09860992], [86.46971893, 20.09833336], [86.46944427, 20.09805489], [86.46944427, 20.09777641], [86.46971893, 20.09749985], [86.47138977, 20.09749985], [86.47194672, 20.09805489], [86.47222137, 20.09805107], [86.47333527, 20.09916878], [86.47250366, 20.09972191], [86.47222137, 20.09944534], [86.47138977, 20.09944534], [86.47138977, 20.09971809], [86.4716568, 20.10000038], [86.4716568, 20.10028076], [86.47194672, 20.10055542], [86.47194672, 20.10082817], [86.47222137, 20.10110855], [86.47222137, 20.10139084], [86.47250366, 20.1016674], [86.47250366, 20.10194397], [86.47222137, 20.10221863], [86.47222137, 20.10277748], [86.47166443, 20.10333252], [86.47138977, 20.10333252], [86.47110748, 20.10362053], [86.47083282, 20.1036129], [86.46983337, 20.10461044], [86.46971893, 20.10472107], [86.46944427, 20.1044445], [86.46861267, 20.1044445], [86.46806335, 20.10499954], [86.46749878, 20.10499954], [86.46721649, 20.10527992], [86.46722412, 20.10555649], [86.46694183, 20.10583305], [86.46694183, 20.10610962], [86.46555328, 20.10750008], [86.46555328, 20.10777855], [86.46499634, 20.10833359], [86.46499634, 20.10861015], [86.46470642, 20.10889053], [86.46470642, 20.11000061], [86.46527863, 20.11055565], [86.46499634, 20.11083031], [86.46499634, 20.11111069], [86.46444702, 20.11166954], [86.46444702, 20.11250114], [86.46416473, 20.11277962], [86.4641571, 20.11333084], [86.46389008, 20.11361122], [86.46389008, 20.11471939], [86.46499634, 20.11583328], [86.46527863, 20.11582947], [86.46611023, 20.11666679], [86.46611023, 20.11722183], [86.46694183, 20.11806107], [86.46778107, 20.11805534], [86.46805573, 20.11833382], [86.46888733, 20.11833382], [86.46916962, 20.11861038], [86.46971893, 20.11860275], [86.47000122, 20.11889076], [86.47027588, 20.11889076], [86.47055817, 20.11917114], [86.47084045, 20.11917114], [86.47444153, 20.12277985], [86.47556305, 20.12277985], [86.47583008, 20.12249947], [86.47666931, 20.12249947], [86.47693634, 20.12277985], [86.47805786, 20.12277985], [86.47833252, 20.12306023], [86.47888947, 20.12306023], [86.48139191, 20.12555504], [86.48139191, 20.12583351], [86.48166656, 20.12610817], [86.48166656, 20.13138962], [86.48139191, 20.13166618], [86.48139191, 20.13194466], [86.48110962, 20.13222122], [86.48110962, 20.13249969], [86.48083496, 20.13277817], [86.48083496, 20.13333321], [86.48472595, 20.13722229], [86.48500061, 20.13722229], [86.48518372, 20.1374073], [86.48555756, 20.13778114], [86.48583984, 20.13778114], [86.48665619, 20.13861084], [86.48666382, 20.13888741], [86.48722076, 20.13944054], [86.48722076, 20.14027977], [86.48750305, 20.14055824], [86.48777771, 20.14055824], [86.48832703, 20.13999748], [86.48832703, 20.13972855], [86.48887634, 20.13916969], [86.48887634, 20.13833046], [86.48916626, 20.13805771], [86.48916626, 20.13667107], [86.48944092, 20.13639069], [86.48944092, 20.13556099], [86.48972321, 20.13528061], [86.48972321, 20.13471985], [86.48944092, 20.13444328], [86.48944092, 20.13389015], [86.48999786, 20.13332939], [86.49028015, 20.13333321], [86.49055481, 20.13361168], [86.4908371, 20.13361168], [86.49111176, 20.13333321], [86.49111176, 20.13305473], [86.49028015, 20.13222313], [86.48999786, 20.13222313], [86.4888916, 20.13111115], [86.48887634, 20.13083267], [86.48805237, 20.12999916], [86.48805237, 20.1297226], [86.48777771, 20.12944412], [86.48777771, 20.12861061], [86.48750305, 20.12832832], [86.48750305, 20.12750053], [86.48722076, 20.12721825], [86.48722076, 20.12694359], [86.48750305, 20.12666893], [86.48750305, 20.12556076], [86.48777771, 20.12528038], [86.48777771, 20.12333107], [86.48805237, 20.12305832], [86.48777771, 20.12277985], [86.48777771, 20.12222099], [86.48750305, 20.12194443], [86.48750305, 20.12166405], [86.48833466, 20.12083244], [86.48860931, 20.12083054], [86.48916626, 20.12138939], [86.48916626, 20.12194443], [86.48944092, 20.12222099], [86.48944092, 20.12499809], [86.48916626, 20.12528038], [86.48916626, 20.12555504], [86.48887634, 20.1258297], [86.48887634, 20.12639046], [86.48860931, 20.12666893], [86.48860931, 20.12694359], [86.48832703, 20.12721825], [86.48832703, 20.12750053], [86.48860931, 20.12779045], [86.48887634, 20.12779045], [86.4888916, 20.12805557], [86.48860931, 20.12832832], [86.48860931, 20.12861061], [86.48887634, 20.12888908], [86.4888916, 20.12916756], [86.49055481, 20.13083267], [86.49111176, 20.13083267], [86.4916687, 20.13138962], [86.4916687, 20.13166618], [86.49194336, 20.13194466], [86.49194336, 20.13222313], [86.49222565, 20.13249969], [86.49222565, 20.13333321], [86.49194336, 20.13360023], [86.49194336, 20.13389015], [86.4916687, 20.13417053], [86.4916687, 20.13444328], [86.49138641, 20.13471985], [86.49138641, 20.13500023], [86.49111176, 20.13528061], [86.49111176, 20.13611031], [86.49138641, 20.13639069], [86.49138641, 20.13666534], [86.4916687, 20.13694382], [86.4916687, 20.13722038], [86.49194336, 20.13750076], [86.49194336, 20.13805771], [86.49223328, 20.13833046], [86.49222565, 20.13916588], [86.49250031, 20.13944054], [86.49222565, 20.13972282], [86.49223328, 20.13999748], [86.49194336, 20.14027977], [86.49194336, 20.14055634], [86.49222565, 20.1408329], [86.49223328, 20.14111137], [86.49194336, 20.14139175], [86.49194336, 20.14167023], [86.49111176, 20.14250183], [86.48999786, 20.14250183], [86.48972321, 20.14222145], [86.4888916, 20.14305496], [86.48916626, 20.14333344], [86.48944092, 20.14333344], [86.48972321, 20.14361191], [86.48999786, 20.14361191], [86.49028015, 20.14389038], [86.49194336, 20.14389038], [86.49223328, 20.14417076], [86.49276733, 20.14417076], [86.49500275, 20.14639091], [86.49500275, 20.14666748], [86.4952774, 20.14694023], [86.4952774, 20.14750099], [86.49582672, 20.14805984], [86.49582672, 20.14861107], [86.49555206, 20.14888954], [86.49555206, 20.14972115], [86.4952774, 20.14999962], [86.4952774, 20.15027618], [86.49500275, 20.15055466], [86.49500275, 20.15083313], [86.49472046, 20.1511116], [86.49472046, 20.15221977], [86.4944458, 20.15249825], [86.49472046, 20.15278053], [86.49472046, 20.15332985], [86.49500275, 20.15360832], [86.49500275, 20.15389061], [86.49610901, 20.15500069], [86.49666595, 20.15500069], [86.49694824, 20.15527916], [86.49749756, 20.15527916], [86.49777985, 20.15555954], [86.49804688, 20.15555954], [86.49861145, 20.15611267], [86.49888611, 20.15611267], [86.4991684, 20.15639114], [86.49944305, 20.15638924], [86.5, 20.15694427], [86.50027466, 20.15694427], [86.50111389, 20.15777779], [86.50138855, 20.15777779], [86.50222015, 20.15860939], [86.50222015, 20.15888977], [86.50250244, 20.15916634], [86.50250244, 20.15944481], [86.5027771, 20.15971947], [86.5027771, 20.16028023], [86.50333405, 20.16083336], [86.50332642, 20.16110992], [86.5036087, 20.1613884], [86.5036087, 20.16222], [86.50388336, 20.16250038], [86.50388336, 20.16306114], [86.50332642, 20.16361046], [86.50389099, 20.1641655], [86.50388336, 20.16444016], [86.50554657, 20.16610909], [86.5055542, 20.16638756], [86.50749969, 20.16833305], [86.50776672, 20.16832924], [86.50860596, 20.16917038], [86.50888824, 20.16916656], [86.50944519, 20.1697216], [86.51000977, 20.16970825], [86.51027679, 20.17000008], [86.51055908, 20.17000008], [86.51082611, 20.17028046], [86.5111084, 20.17027855], [86.51304626, 20.17222023], [86.51304626, 20.17250061], [86.51416779, 20.17361069], [86.51416779, 20.17389107], [86.51444244, 20.17416954], [86.51527405, 20.17416573], [86.51555634, 20.1744442], [86.51611328, 20.1744442], [86.51638794, 20.17472267], [86.51667023, 20.17472076], [86.51689148, 20.17494392], [86.51777649, 20.17584038], [86.51805878, 20.17584038], [86.51832581, 20.17611122], [86.51860809, 20.17611122], [86.51888275, 20.17638969], [86.51916504, 20.17638969], [86.51935577, 20.17657661], [86.51944733, 20.17667007], [86.51972198, 20.17666626], [86.51999664, 20.17694473], [86.52027893, 20.17694092], [86.52083588, 20.17749977], [86.52111053, 20.17749977], [86.52139282, 20.17778015], [86.52222443, 20.17777634], [86.52278137, 20.17833328], [86.52305603, 20.17833328], [86.52361298, 20.17888641], [86.52388763, 20.17888069], [86.52416992, 20.17917061], [86.52416992, 20.17944527], [86.52443695, 20.17971992], [86.52444458, 20.1799984], [86.52527618, 20.18083382], [86.52555847, 20.18083382], [86.52694702, 20.18221855], [86.52694702, 20.18250275], [86.52749634, 20.18305588], [86.52749634, 20.18333244], [86.52777863, 20.18361282], [86.52777863, 20.18388939], [86.52861023, 20.1847229], [86.52861023, 20.18499947], [86.52889252, 20.18527985], [86.52889252, 20.18555641], [86.52916718, 20.18583488], [86.53028107, 20.18583488], [86.53055573, 20.18611145], [86.53082275, 20.18610954], [86.53111267, 20.18638992], [86.53166962, 20.18638992], [86.53221893, 20.18695068], [86.53250122, 20.18694305], [86.53277588, 20.18722153], [86.53305817, 20.18721962], [86.53333282, 20.1875], [86.53360748, 20.1875], [86.5341568, 20.1880703], [86.53472137, 20.18805313], [86.53500366, 20.18833351], [86.53500366, 20.18861198], [86.53555298, 20.18861198], [86.53610992, 20.18805313], [86.53666687, 20.18805313], [86.53682709, 20.18821716], [86.53694153, 20.18833351], [86.53722382, 20.18805313], [86.53794098, 20.18864632], [86.53881073, 20.18944359], [86.53902435, 20.18972206], [86.5393219, 20.19041061], [86.54081726, 20.1917305], [86.54059601, 20.19219971], [86.53959656, 20.19226074], [86.53916931, 20.19308281], [86.53939056, 20.1936264], [86.53959656, 20.1937027], [86.53965759, 20.1938324], [86.53986359, 20.19382858], [86.54000092, 20.19388962], [86.54055786, 20.19388962], [86.54083252, 20.19360924], [86.54161072, 20.19333839], [86.54167938, 20.19330406], [86.54201508, 20.19311523], [86.54250336, 20.19333267], [86.54277802, 20.19333076], [86.54305267, 20.19360924], [86.54360962, 20.19360924], [86.54389191, 20.19333076], [86.54416656, 20.19360924], [86.54444122, 20.19360924], [86.54472351, 20.19388962], [86.54499817, 20.19388962], [86.54528046, 20.19360924], [86.54694366, 20.19360924], [86.54722595, 20.19388962], [86.5477829, 20.19387817], [86.54805756, 20.19416809], [86.54833221, 20.19416618], [86.5486145, 20.19444466], [86.54916382, 20.19444466], [86.54944611, 20.19472313], [86.55000305, 20.19472313], [86.55110931, 20.19583321], [86.5513916, 20.19582939], [86.55304718, 20.19750023], [86.55305481, 20.1977787], [86.55361176, 20.19833183], [86.55361176, 20.19861031], [86.55472565, 20.19972229], [86.55499268, 20.19972038], [86.55526733, 20.2000103], [86.55555725, 20.2000103], [86.55722046, 20.20166969], [86.5577774, 20.20166969], [86.5588913, 20.20055962], [86.5588913, 20.20028114], [86.55805969, 20.19944191], [86.5577774, 20.19944382], [86.55750275, 20.19916725], [86.55722046, 20.19917107], [86.55444336, 20.19639015], [86.5541687, 20.19639015], [86.55361176, 20.19582939], [86.5533371, 20.19583321], [86.55278015, 20.19527817], [86.55249786, 20.19528008], [86.55110931, 20.19387817], [86.55083466, 20.19388962], [86.55027771, 20.19333267], [86.55000305, 20.19333267], [86.5499115, 20.19324112], [86.54972076, 20.19305611], [86.54915619, 20.19305992], [86.54888916, 20.19277954], [86.54860687, 20.19277954], [86.5477829, 20.19194031], [86.54750061, 20.19194412], [86.54611206, 20.19055557], [86.54582977, 20.19055939], [86.54471588, 20.18943977], [86.54389191, 20.18944359], [86.54222107, 20.18777847], [86.54110718, 20.18778038], [86.54055786, 20.18721962], [86.54027557, 20.18722153], [86.53944397, 20.18638802], [86.53916931, 20.18638992], [86.53861237, 20.18583107], [86.53833008, 20.18583488], [86.53694153, 20.18444443], [86.53666687, 20.18444443], [86.53444672, 20.18222237], [86.53416443, 20.18222237], [86.53388977, 20.18194389], [86.53360748, 20.18194389], [86.53138733, 20.17972183], [86.53111267, 20.17972183], [86.52722168, 20.17583275], [86.52694702, 20.17584038], [86.52639008, 20.17527962], [86.52610779, 20.17527962], [86.52555847, 20.17472076], [86.52555847, 20.1744442], [86.52249908, 20.17138863], [86.52249908, 20.17111015], [86.52055359, 20.16916656], [86.52054596, 20.16889191], [86.51999664, 20.16832924], [86.51999664, 20.16805649], [86.51917267, 20.16721916], [86.51916504, 20.1669445], [86.51833344, 20.16610909], [86.51832581, 20.16583061], [86.51805878, 20.16555786], [86.51805878, 20.16527939], [86.51777649, 20.16500092], [86.51777649, 20.16472054], [86.51667023, 20.16361046], [86.51667023, 20.16333008], [86.51555634, 20.16222191], [86.51555634, 20.16194534], [86.51526642, 20.16167068], [86.51526642, 20.1613903], [86.51499939, 20.16110992], [86.51499939, 20.16083336], [86.51444244, 20.16028023], [86.51444244, 20.15999985], [86.51389313, 20.1594429], [86.5138855, 20.15888977], [86.51361084, 20.1586113], [86.51361084, 20.15833282], [86.51249695, 20.15722275], [86.51249695, 20.1566658], [86.51222229, 20.15639114], [86.51222229, 20.15611267], [86.51139069, 20.15527916], [86.51139069, 20.15500069], [86.5111084, 20.15471077], [86.5111084, 20.15444374], [86.5091629, 20.15249825], [86.5091629, 20.15195847], [86.50888824, 20.15167046], [86.50888824, 20.15138817], [86.50860596, 20.1511097], [86.50861359, 20.15055466], [86.5083313, 20.15027618], [86.5083313, 20.14972115], [86.50805664, 20.14944458], [86.50805664, 20.1491642], [86.50776672, 20.14890099], [86.50776672, 20.14861107], [86.50723267, 20.14805984], [86.50723267, 20.14777946], [86.50666809, 20.14722061], [86.50666809, 20.14694595], [86.5063858, 20.14666748], [86.5063858, 20.14611053], [86.50611115, 20.14583015], [86.50611115, 20.1455555], [86.50583649, 20.14528084], [86.50583649, 20.14500046], [86.50554657, 20.14472008], [86.5055542, 20.14416695], [86.5047226, 20.14332962], [86.50444794, 20.14333344], [86.50416565, 20.14305496], [86.50388336, 20.14306259], [86.5036087, 20.14277077], [86.5036087, 20.14222145], [86.50416565, 20.14166641], [86.5036087, 20.14111137], [86.50250244, 20.14111137], [86.5022583, 20.14086914], [86.5008316, 20.13944435], [86.50055695, 20.13944435], [86.50048065, 20.13936806], [86.50027466, 20.13916588], [86.5, 20.13916969], [86.49989319, 20.13905907], [86.49972534, 20.13888741], [86.49973297, 20.13861084], [86.50055695, 20.13777542], [86.49973297, 20.13694], [86.49972534, 20.13638878], [86.49944305, 20.13611031], [86.49944305, 20.13582993], [86.49777985, 20.13416672], [86.49777985, 20.13389015], [86.49749756, 20.13360023], [86.49749756, 20.13305473], [86.4972229, 20.13277817], [86.4972229, 20.13249969], [86.49694824, 20.13222122], [86.49694824, 20.13138962], [86.49666595, 20.13111115], [86.49666595, 20.1297226], [86.4963913, 20.12944412], [86.4963913, 20.12916756], [86.49666595, 20.12888908], [86.49666595, 20.12861061], [86.4963913, 20.12832832], [86.49610901, 20.12833405], [86.49583435, 20.12805557], [86.49582672, 20.12779045], [86.4952774, 20.12721825], [86.4952774, 20.12639046], [86.49472046, 20.1258297], [86.49472046, 20.12555504], [86.49415588, 20.12499809], [86.49415588, 20.12472916], [86.49388885, 20.12445068], [86.49388885, 20.12360954], [86.49277496, 20.12249947], [86.49250031, 20.12249947], [86.49223328, 20.12222099], [86.49194336, 20.1222229], [86.4908371, 20.12111092], [86.4908371, 20.12083054], [86.49055481, 20.12055588], [86.49028015, 20.12028122], [86.49028015, 20.12000084], [86.48999786, 20.11972046], [86.48972321, 20.11972237], [86.48944092, 20.11944389], [86.48916626, 20.11944389], [86.48833466, 20.11861038], [86.48777771, 20.11861038], [86.48777771, 20.11777687], [86.48722076, 20.11722183], [86.48694611, 20.11722374], [86.486763, 20.11703873], [86.48638916, 20.11666679], [86.48638916, 20.11639023], [86.48665619, 20.11611176], [86.48666382, 20.11583328], [86.48638916, 20.11555481], [86.48603058, 20.11522293], [86.48574829, 20.11474991], [86.48532104, 20.11421013], [86.48500061, 20.11388969], [86.48332977, 20.11555481], [86.48332977, 20.11611176], [86.48388672, 20.11666679], [86.48388672, 20.11722183], [86.48416901, 20.11750031], [86.48416901, 20.11777687], [86.48472595, 20.11833191], [86.48416901, 20.11889076], [86.48388672, 20.11889076], [86.48332977, 20.11833191], [86.48332977, 20.11805534], [86.48278046, 20.11750031], [86.48278046, 20.11722183], [86.48249817, 20.11694527], [86.48249817, 20.11667061], [86.48110962, 20.11528015], [86.48110962, 20.11500168], [86.48082733, 20.11471939], [86.48083496, 20.11416626], [86.48110962, 20.11388969], [86.48110962, 20.11361122], [86.48221588, 20.11250114], [86.48306274, 20.11250114], [86.48332977, 20.11222076], [86.48332977, 20.1119442], [86.48361206, 20.11166573], [86.48361206, 20.11111069], [86.48388672, 20.11083031], [86.48388672, 20.11027527], [86.48332977, 20.10972023], [86.48278046, 20.11028099], [86.48249817, 20.11028099], [86.48139191, 20.10917091], [86.48139191, 20.10889053], [86.47970581, 20.1072197], [86.47944641, 20.1072197], [86.47915649, 20.10750008], [86.47888947, 20.10750008], [86.47888947, 20.10778046], [86.47916412, 20.10805321], [86.47916412, 20.10833359], [86.47944641, 20.10861015], [86.47944641, 20.10889053], [86.47972107, 20.10916519], [86.47972107, 20.10944366], [86.48000336, 20.10972023], [86.48000336, 20.11000061], [86.48027802, 20.11028099], [86.48055267, 20.11028099], [86.48082733, 20.11055946], [86.48139191, 20.11055946], [86.48194122, 20.11111069], [86.48139191, 20.11166573], [86.48083496, 20.11222267], [86.48055267, 20.11222267], [86.48000336, 20.11166573], [86.47970581, 20.11166954], [86.47915649, 20.11111069], [86.47860718, 20.11111069], [86.47833252, 20.11083031], [86.47777557, 20.11083412], [86.47721863, 20.11027527], [86.47721863, 20.11000061], [86.47693634, 20.10972023], [86.47694397, 20.10944366], [86.47666931, 20.10916519], [86.47666931, 20.10750008], [86.47638702, 20.1072197], [86.47638702, 20.10638809], [86.47611237, 20.10610962], [86.47611237, 20.10583305], [86.47583008, 20.10555649], [86.47583008, 20.10527992], [86.47528076, 20.10472107], [86.47528076, 20.1044445], [86.47499847, 20.10416603], [86.47499847, 20.10388947], [86.47556305, 20.10333252], [86.47583008, 20.10333252], [86.47611237, 20.10305595], [86.47638702, 20.10305977], [86.47666931, 20.10277939], [86.47666931, 20.10221863], [86.47638702, 20.10194397], [86.47638702, 20.1016674], [86.47611237, 20.10139084], [86.47611237, 20.10110855], [86.47583008, 20.10082817], [86.47583008, 20.10055542], [86.47471619, 20.09944916], [86.4716568, 20.09638977], [86.47138977, 20.09638977], [86.47138977, 20.09610939], [86.47110748, 20.09583282], [86.47110748, 20.09555435], [86.47055817, 20.09500122], [86.47027588, 20.09500122], [86.47027588, 20.09472084], [86.46250153, 20.08694458], [86.46250153, 20.08666611], [86.46138763, 20.08555984], [86.46083069, 20.08555984], [86.45999908, 20.08472061], [86.45972443, 20.08472252], [86.45916748, 20.08416557], [86.45861053, 20.08416939], [86.45777893, 20.08333015], [86.45777893, 20.0830555], [86.45749664, 20.08278084], [86.45749664, 20.08249092], [86.45694733, 20.08194351], [86.45694733, 20.08111191], [86.45500183, 20.07916641], [86.45471954, 20.07917023], [86.45443726, 20.07888985], [86.45417023, 20.07888985], [86.45388794, 20.07860947], [86.45388794, 20.07805634], [86.45333099, 20.07749939], [86.4522171, 20.07749939], [86.45166779, 20.07694244], [86.45121765, 20.07666969], [86.45072937, 20.07636833], [86.4502182, 20.07605553], [86.44970703, 20.07563972], [86.4493866, 20.07496071], [86.44908142, 20.07432938], [86.44863892, 20.07389069], [86.44819641, 20.07354927], [86.44783783, 20.0732708], [86.44754028, 20.07299232], [86.44728088, 20.07270622], [86.44700623, 20.07242966], [86.44673157, 20.07215309], [86.44642639, 20.0718174], [86.4460907, 20.07143974], [86.44564819, 20.07113075], [86.44439697, 20.0706234], [86.44368744, 20.0699482], [86.44288635, 20.06867027], [86.44248962, 20.06837845], [86.44207001, 20.06805992], [86.44164276, 20.06772995], [86.44124603, 20.06735992], [86.44082642, 20.06694984], [86.4404068, 20.06653023], [86.43990326, 20.06610107], [86.43937683, 20.06565857], [86.43898773, 20.06508064], [86.43869781, 20.06443024], [86.43849182, 20.0638504], [86.43818665, 20.06339073], [86.43785858, 20.06301117], [86.43754578, 20.06255913], [86.43730164, 20.06196213], [86.43708038, 20.06139946], [86.43678284, 20.0609684], [86.43641663, 20.06067085], [86.43601227, 20.06049538], [86.43559265, 20.06032944], [86.43512726, 20.06018066], [86.43466949, 20.05999756], [86.43412018, 20.05985069], [86.43344116, 20.05983353], [86.43273163, 20.05989456], [86.43224335, 20.05978012], [86.43179321, 20.05955124], [86.4312973, 20.05919266], [86.43078613, 20.05879021], [86.43032837, 20.05827332], [86.43000031, 20.05768776], [86.42973328, 20.05711174], [86.42951202, 20.05656433], [86.42945099, 20.05602455], [86.42944336, 20.0555191], [86.42942047, 20.05507088], [86.42935181, 20.05467987], [86.42919159, 20.05438232], [86.4283371, 20.05361176], [86.42805481, 20.05361176], [86.42694092, 20.05471992], [86.42694092, 20.05500031], [86.42583466, 20.05611038], [86.42555237, 20.05611038], [86.42472076, 20.05694389], [86.42444611, 20.05694389], [86.42416382, 20.05722237], [86.42388916, 20.05722046], [86.42360687, 20.05750084], [86.42193604, 20.05750084], [86.42166901, 20.05778122], [86.41971588, 20.05778122], [86.41944122, 20.05750084], [86.41889191, 20.05750084], [86.41860962, 20.05722046], [86.41805267, 20.05722237], [86.41777802, 20.05694389], [86.41722107, 20.05694389], [86.41708374, 20.05680466], [86.41694641, 20.05666542], [86.41638947, 20.05667114], [86.41610718, 20.05639076], [86.41500092, 20.05639076], [86.41471863, 20.05611038], [86.41388702, 20.05611038], [86.41362, 20.05583], [86.41176605, 20.05554008], [86.41176605, 20.05513954], [86.41311646, 20.05500031], [86.41610718, 20.05500031], [86.41638947, 20.05528069], [86.41722107, 20.05527687], [86.41733551, 20.0553894], [86.41750336, 20.05555534], [86.41916656, 20.05555534], [86.41944122, 20.05583382], [86.42028046, 20.05583382], [86.42055511, 20.05611038], [86.42166901, 20.05611038], [86.42193604, 20.05639076], [86.42250061, 20.05639076], [86.42279053, 20.05611038], [86.42388916, 20.05611038], [86.42556, 20.05445099], [86.42556, 20.05332947], [86.42583466, 20.05305481], [86.42610931, 20.05305481], [86.4263916, 20.05277824], [86.4263916, 20.05251122], [86.42722321, 20.05167007], [86.42694092, 20.05138969], [86.42694092, 20.05027962], [86.42722321, 20.05000114], [86.42722321, 20.04972267], [86.42694092, 20.0494442], [86.42694092, 20.04889107], [86.4263916, 20.0483284], [86.4263916, 20.04750061], [86.42610931, 20.04721832], [86.42556, 20.04721832], [86.42527771, 20.04750061], [86.42527771, 20.04777908], [86.42500305, 20.04805565], [86.42500305, 20.0483284], [86.42388916, 20.04945183], [86.42360687, 20.04945183], [86.42360687, 20.04916954], [86.42166901, 20.04721832], [86.42138672, 20.04722214], [86.42111206, 20.04694366], [86.42056274, 20.04693985], [86.41971588, 20.04777908], [86.41972351, 20.04805565], [86.41944122, 20.0483284], [86.41944122, 20.04861069], [86.41916656, 20.04889107], [86.41898346, 20.04870415], [86.41860962, 20.04833412], [86.41860962, 20.04611206], [86.41833496, 20.04583359], [86.41833496, 20.04555511], [86.41805267, 20.04528046], [86.41718292, 20.04488182], [86.41660309, 20.04447746], [86.41574097, 20.04346085], [86.4153595, 20.04224396], [86.41511536, 20.04189873], [86.41488647, 20.04152107], [86.41471863, 20.04111099], [86.41443634, 20.04083061], [86.41444397, 20.04055405], [86.41471863, 20.04027939], [86.41471863, 20.03833008], [86.41444397, 20.03805542], [86.41443634, 20.03722191], [86.41471863, 20.03694534], [86.41471863, 20.03667068], [86.41500092, 20.0363903], [86.4152832, 20.0363903], [86.41610718, 20.03554916], [86.41611481, 20.03500175], [86.41638947, 20.03472137], [86.41638947, 20.03416634], [86.41610718, 20.03388977], [86.41610718, 20.03305817], [86.41583252, 20.03277969], [86.41583252, 20.03222084], [86.41555786, 20.03194427], [86.41583252, 20.0316658], [86.41583252, 20.03111076], [86.41500092, 20.03028107], [86.41361237, 20.0316658], [86.41361237, 20.03194427], [86.41333008, 20.03222084], [86.41333008, 20.03388977], [86.41361237, 20.03416634], [86.41361237, 20.03444481], [86.41305542, 20.03500175], [86.41305542, 20.03555489], [86.41278076, 20.03583336], [86.41278076, 20.03611183], [86.41249847, 20.0363903], [86.41249847, 20.03667068], [86.41221619, 20.03695107], [86.41166687, 20.0363903], [86.41166687, 20.03554916], [86.41156769, 20.03492165], [86.41152954, 20.03435707], [86.41160583, 20.03380966], [86.41158295, 20.03329277], [86.41143799, 20.03277016], [86.41133881, 20.03221893], [86.41114807, 20.0316925], [86.41101837, 20.03117943], [86.41086578, 20.03070068], [86.41078186, 20.03024864], [86.41065216, 20.02981949], [86.41065979, 20.02938461], [86.41077423, 20.02890968], [86.41078186, 20.02837944], [86.41069031, 20.02779007], [86.41059113, 20.02715492], [86.41054535, 20.0264473], [86.41046143, 20.02572823], [86.4101944, 20.02513695], [86.40983582, 20.02472115], [86.40950012, 20.02436066], [86.40923309, 20.02399063], [86.4090271, 20.02358627], [86.40888214, 20.0231781], [86.40872955, 20.02279282], [86.40857697, 20.02240944], [86.40840912, 20.02202988], [86.40827179, 20.02158737], [86.4080658, 20.02116013], [86.40782928, 20.02073097], [86.40750122, 20.02028084], [86.40750122, 20.02000046], [86.40721893, 20.01971817], [86.40721893, 20.01861191], [86.40777588, 20.01805496], [86.40777588, 20.01749992], [86.40805817, 20.01721954], [86.40805817, 20.01694679], [86.40833282, 20.01666641], [86.40860748, 20.01667023], [86.4091568, 20.01610947], [86.40972137, 20.01611137], [86.41027832, 20.01555443], [86.41027832, 20.01527977], [86.41085052, 20.01472092], [86.41083527, 20.01444435], [86.41139221, 20.01388931], [86.41110992, 20.01361084], [86.41110992, 20.01305962], [86.41139221, 20.01278114], [86.41194153, 20.01278114], [86.41221619, 20.01305962], [86.41249847, 20.01278114], [86.41249847, 20.01250076], [86.41278076, 20.01222038], [86.41278076, 20.01083374], [86.41249847, 20.01055527], [86.41249847, 20.01000023], [86.41221619, 20.00972176], [86.41222382, 20.00916672], [86.41194153, 20.00861168], [86.41194153, 20.00805473], [86.41166687, 20.00777817], [86.41166687, 20.0075016], [86.41194153, 20.00720978], [86.41194153, 20.00694466], [86.41166687, 20.00666618], [86.41194153, 20.00638962], [86.41194153, 20.00555992], [86.41166687, 20.00527954], [86.41166687, 20.00361061], [86.41139221, 20.00333023], [86.41139221, 20.00222206], [86.41110992, 20.00194359], [86.41110992, 20.0], [86.40999603, 19.99945068], [86.40833282, 19.99777985], [86.40833282, 19.99749947], [86.40805817, 19.9972229], [86.40805817, 19.99583244], [86.40750122, 19.9952774], [86.40721893, 19.9952774], [86.40638733, 19.99444389], [86.40611267, 19.99444389], [86.40583038, 19.99416733], [86.40556335, 19.99416924], [86.40537262, 19.99398232], [86.40528107, 19.99389076], [86.40499878, 19.99389076], [86.40442657, 19.99332809], [86.40416718, 19.99333382], [86.40361023, 19.99277878], [86.4033432, 19.99278069], [86.40110779, 19.99055099], [86.40083313, 19.99055481], [86.39916992, 19.98888969], [86.39916992, 19.98861122], [86.39749908, 19.98694038], [86.39749908, 19.98666573], [86.3972168, 19.98666954], [86.39694214, 19.98639107], [86.39666748, 19.98639107], [86.39601898, 19.98574066], [86.39472198, 19.98444176], [86.39444733, 19.9841671], [86.39417267, 19.98417282], [86.39398193, 19.98398209], [86.39389038, 19.98389053], [86.39360809, 19.98389053], [86.39305878, 19.98333168], [86.39305878, 19.98277855], [86.39221954, 19.98195267], [86.39167023, 19.98195267], [86.39167023, 19.98167038], [86.39055634, 19.9805603], [86.39055634, 19.98028946], [86.38999939, 19.97971916], [86.38999939, 19.97888947], [86.3897171, 19.97860909], [86.38970184, 19.97832108], [86.38916779, 19.97777939], [86.38916779, 19.97750092], [86.38889313, 19.97722816], [86.38861084, 19.97722816], [86.38833618, 19.97694016], [86.38805389, 19.97694397], [86.38749695, 19.97638893], [86.38722229, 19.97639084], [86.38694763, 19.97611046], [86.38640594, 19.97611046], [86.38360596, 19.97611046], [86.3833313, 19.97639084], [86.38223267, 19.97639084], [86.38194275, 19.97667122], [86.3813858, 19.97667122], [86.38083649, 19.97722816], [86.38054657, 19.97722816], [86.38027954, 19.97750092], [86.3797226, 19.97750092], [86.37917328, 19.97805977], [86.37889099, 19.97805977], [86.37832642, 19.97860909], [86.37805176, 19.97860909], [86.3777771, 19.97888947], [86.3777771, 19.9794445], [86.37805176, 19.97971916], [86.37805176, 19.97999763], [86.37833405, 19.98027992], [86.37833405, 19.98083305], [86.3786087, 19.98111153], [86.3786087, 19.98139191], [86.37889099, 19.98166656], [86.37889099, 19.9822216], [86.37917328, 19.98250008], [86.37916565, 19.98277855], [86.3797226, 19.98333359], [86.3797226, 19.98361206], [86.38083649, 19.98472023], [86.38083649, 19.98611069], [86.38111115, 19.98639107], [86.38083649, 19.98666954], [86.38083649, 19.98750114], [86.38054657, 19.98777962], [86.3805542, 19.98916435], [86.38083649, 19.98944092], [86.38083649, 19.98999977], [86.3813858, 19.99055481], [86.38166809, 19.99055481], [86.38283539, 19.99083328], [86.3833313, 19.99083328], [86.38360596, 19.99110985], [86.38384247, 19.99115753], [86.38500214, 19.99139023], [86.38582611, 19.99139023], [86.3861084, 19.99167061], [86.38639069, 19.99167061], [86.3866806, 19.99194908], [86.38694763, 19.99194527], [86.38722229, 19.99221039], [86.38722229, 19.99250031], [86.38694763, 19.99278069], [86.38581085, 19.99250031], [86.38424683, 19.99229813], [86.38276672, 19.99250031], [86.38249969, 19.99305534], [86.38243103, 19.99526978], [86.38223267, 19.99555969], [86.38166809, 19.99555969], [86.3813858, 19.99526978], [86.3813858, 19.99500084], [86.38111115, 19.99471855], [86.38111115, 19.99333382], [86.3805542, 19.99277878], [86.38054657, 19.99250031], [86.37982178, 19.99176979], [86.37895203, 19.99115944], [86.37853241, 19.99048424], [86.37838745, 19.98892784], [86.37853241, 19.98805046], [86.37889099, 19.98690033], [86.37889099, 19.98500061], [86.37832642, 19.98444176], [86.37805176, 19.98444366], [86.3777771, 19.9841671], [86.3777771, 19.98389053], [86.37748718, 19.98361015], [86.37750244, 19.98333359], [86.37666321, 19.98250008], [86.37666321, 19.9822216], [86.37611389, 19.98166656], [86.37610626, 19.98139191], [86.37526703, 19.9805603], [86.375, 19.9805603], [86.3747406, 19.98028946], [86.3741684, 19.98028946], [86.37384796, 19.97999763], [86.37249756, 19.97999763], [86.3722229, 19.97971916], [86.37166595, 19.97971916], [86.3713913, 19.97999763], [86.3702774, 19.97999763], [86.37000275, 19.98028946], [86.36915588, 19.98028946], [86.36915588, 19.97999763], [86.36888885, 19.97971916], [86.3686142, 19.97972298], [86.36833191, 19.9794445], [86.36777496, 19.9794445], [86.36750031, 19.97972298], [86.36723328, 19.97971916], [86.36694336, 19.97999763], [86.36360931, 19.97999763], [86.36332703, 19.98028946], [86.36222076, 19.98028946], [86.36194611, 19.9805603], [86.36165619, 19.98028946], [86.36055756, 19.98028946], [86.3602829, 19.97999763], [86.35972595, 19.97999763], [86.35945129, 19.98028946], [86.35888672, 19.98028946], [86.35861206, 19.9805603], [86.35832977, 19.98055649], [86.35805511, 19.98083305], [86.35527802, 19.98083305], [86.35500336, 19.98055649], [86.35444641, 19.98111153], [86.35360718, 19.98111153], [86.35331726, 19.98139191], [86.35256958, 19.98139191], [86.35221863, 19.98139191], [86.35193634, 19.98167038], [86.35166931, 19.98167038], [86.35138702, 19.98195267], [86.35111237, 19.98194504], [86.35057068, 19.98250008], [86.35055542, 19.98277855], [86.34999847, 19.98333359], [86.34999847, 19.98360062], [86.34999847, 19.98444366], [86.34971619, 19.98472023], [86.34971619, 19.98500061], [86.34999847, 19.9852829], [86.34999847, 19.98611069], [86.35028076, 19.98639107], [86.35028076, 19.98666573], [86.35012054, 19.98682785], [86.34972382, 19.98722267], [86.34944153, 19.9869442], [86.34916687, 19.98666573], [86.34916687, 19.98639107], [86.34889221, 19.98611069], [86.34889221, 19.98583031], [86.34833527, 19.98527718], [86.3483429, 19.98472023], [86.34860992, 19.98444366], [86.34860992, 19.98388863], [86.34889221, 19.98361015], [86.34889221, 19.98277855], [86.34944153, 19.9822216], [86.34944153, 19.98166656], [86.34916687, 19.98139191], [86.34860992, 19.98195267], [86.34805298, 19.98194504], [86.34777832, 19.9822216], [86.34751129, 19.9822216], [86.34722137, 19.98250008], [86.34722137, 19.98278046], [86.34583282, 19.98417282], [86.34555817, 19.9841671], [86.34500122, 19.98472214], [86.34471893, 19.98472214], [86.34455872, 19.98488235], [86.34333038, 19.98611069], [86.34306335, 19.98611069], [86.34278107, 19.98639107], [86.34221649, 19.98639107], [86.34127045, 19.98746872], [86.340271, 19.98888969], [86.33999634, 19.98916435], [86.33999634, 19.98944473], [86.33972168, 19.98971939], [86.33972168, 19.98999977], [86.33944702, 19.99027634], [86.33944702, 19.99110985], [86.33946991, 19.99309921], [86.33961487, 19.99472427], [86.33996582, 19.99567223], [86.34017944, 19.99682236], [86.34011078, 19.99763107], [86.33994293, 19.99830055], [86.3391571, 20.0], [86.33889008, 20.00036049], [86.33883667, 20.00071716], [86.33866119, 20.00106049], [86.33863068, 20.00144958], [86.33860779, 20.0018425], [86.33860779, 20.00218582], [86.33857727, 20.00251961], [86.33843994, 20.00283051], [86.33831787, 20.00317955], [86.33812714, 20.00354004], [86.33770752, 20.00486755], [86.33728027, 20.00608063], [86.33692169, 20.00777054], [86.33656311, 20.00898552], [86.33621216, 20.01066971], [86.33528137, 20.01250076], [86.33499908, 20.01278114], [86.33499908, 20.01305962], [86.33444214, 20.01361084], [86.33444214, 20.01444435], [86.33389282, 20.01499939], [86.33389282, 20.01527977], [86.33361053, 20.01555443], [86.33361053, 20.01583099], [86.33277893, 20.01667023], [86.33241272, 20.01703644], [86.33207703, 20.01736069], [86.3316803, 20.01768112], [86.33129883, 20.01802444], [86.3309021, 20.01832199], [86.33048248, 20.01857185], [86.3300705, 20.01881981], [86.3298111, 20.0191803], [86.32956696, 20.01958084], [86.3292923, 20.01998711], [86.32900238, 20.02042961], [86.32888031, 20.02102089], [86.32874298, 20.02160263], [86.32849121, 20.02207947], [86.32832336, 20.02256966], [86.32832336, 20.02312279], [86.32833862, 20.02370071], [86.32833099, 20.02416611], [86.32861328, 20.02444267], [86.32861328, 20.02499962], [86.32888794, 20.02527809], [86.32888794, 20.02583313], [86.32861328, 20.0261097], [86.32861328, 20.02695084], [86.32853699, 20.02816963], [86.32818604, 20.02952003], [86.32740021, 20.03067017], [86.32640076, 20.03180885], [86.32575226, 20.03275108], [86.3248291, 20.03369904], [86.32418823, 20.03437042], [86.32290649, 20.03469086], [86.32242584, 20.03500175], [86.32195282, 20.03524971], [86.3214798, 20.03540993], [86.32111359, 20.03569603], [86.32076263, 20.03604126], [86.32034302, 20.03637123], [86.31986237, 20.03666496], [86.3194046, 20.03692818], [86.31897736, 20.03715134], [86.31863403, 20.03741264], [86.31838226, 20.03772354], [86.3181076, 20.03800964], [86.31787109, 20.03832245], [86.31759644, 20.03860283], [86.31726074, 20.03885841], [86.31695557, 20.03917122], [86.31667328, 20.03955078], [86.31638336, 20.03993034], [86.31600189, 20.04017067], [86.31556702, 20.04031944], [86.31517029, 20.04050064], [86.31475067, 20.04061127], [86.31437683, 20.04079056], [86.31391907, 20.04092979], [86.31343842, 20.04109192], [86.31292725, 20.04124069], [86.31238556, 20.04137611], [86.31183624, 20.04150963], [86.31136322, 20.04171181], [86.31095886, 20.04195786], [86.31059265, 20.04222107], [86.31021881, 20.04248047], [86.30983734, 20.04265022], [86.3094101, 20.04278946], [86.30898285, 20.04294968], [86.30857086, 20.04311562], [86.30819702, 20.0433197], [86.30784607, 20.04354095], [86.30749512, 20.04372787], [86.30715942, 20.04390335], [86.3068161, 20.04408073], [86.30641174, 20.04421043], [86.30600739, 20.0443573], [86.30552673, 20.04447365], [86.30503845, 20.04467964], [86.30451965, 20.04491043], [86.30400085, 20.04510117], [86.30356598, 20.0453968], [86.30310059, 20.04561806], [86.30265045, 20.04585075], [86.30223846, 20.04611206], [86.30183411, 20.04639053], [86.30145264, 20.04667091], [86.30108643, 20.04700089], [86.30081177, 20.04738998], [86.30053711, 20.04777908], [86.30027771, 20.04817963], [86.30002594, 20.04862022], [86.29985809, 20.0491066], [86.29960632, 20.04951477], [86.29930878, 20.04975319], [86.29905701, 20.04999161], [86.29884338, 20.05022049], [86.2986145, 20.05055618], [86.29694366, 20.0522213], [86.29666901, 20.05221939], [86.29611206, 20.05278015], [86.29564667, 20.05308723], [86.29528809, 20.05328178], [86.29483795, 20.05336761], [86.29445648, 20.05360985], [86.29409027, 20.05391502], [86.29373932, 20.05433846], [86.293396, 20.05489922], [86.29305267, 20.05539894], [86.29270935, 20.05589485], [86.29244232, 20.05639076], [86.29213715, 20.05677795], [86.29189301, 20.05714035], [86.29164886, 20.05743027], [86.29147339, 20.05767822], [86.29139709, 20.05797958], [86.29138184, 20.05830002], [86.29133606, 20.05861092], [86.29122925, 20.05891991], [86.29113007, 20.05925941], [86.2910614, 20.05965042], [86.29099274, 20.06007957], [86.29087067, 20.06043053], [86.2906723, 20.06072044], [86.29046631, 20.06098175], [86.29007721, 20.06113052], [86.28987122, 20.06081009], [86.28978729, 20.06034851], [86.28983307, 20.05991554], [86.28991699, 20.05952072], [86.28990936, 20.05920219], [86.28981781, 20.05895233], [86.289711, 20.05872154], [86.28951263, 20.05859756], [86.28922272, 20.05855942], [86.2888031, 20.05854416], [86.28826141, 20.05852127], [86.28749847, 20.05861092], [86.28749847, 20.05750084], [86.28778076, 20.05722046], [86.28944397, 20.05722237], [86.29194641, 20.05472183], [86.29194641, 20.05416679], [86.29222107, 20.05389023], [86.29165649, 20.05332947], [86.29138947, 20.05333328], [86.29083252, 20.05277824], [86.29110718, 20.05251122], [86.29055786, 20.05194283], [86.29027557, 20.05194473], [86.29000092, 20.05166626], [86.29000092, 20.05138969], [86.28971863, 20.05111122], [86.28916931, 20.05111122], [86.28861237, 20.0505619], [86.28833008, 20.0505619], [86.28806305, 20.05027962], [86.28778076, 20.05027962], [86.28768921, 20.05018616], [86.28722382, 20.04972267], [86.28610992, 20.04972267], [86.2858429, 20.05000114], [86.28527832, 20.05000114], [86.28499603, 20.05027962], [86.28417206, 20.05027962], [86.28333282, 20.05111122], [86.28333282, 20.05166626], [86.28388977, 20.05221939], [86.28388977, 20.05249977], [86.28305817, 20.05333328], [86.28221893, 20.05332947], [86.28166962, 20.05389023], [86.28138733, 20.05389023], [86.28109741, 20.05417061], [86.28083038, 20.05417061], [86.28055573, 20.05388832], [86.27889252, 20.05555534], [86.27861023, 20.05554962], [86.2766571, 20.05750084], [86.27666473, 20.05777931], [86.27630615, 20.05930328], [86.27581024, 20.06011009], [86.27445221, 20.06160164], [86.27381134, 20.0617981], [86.27194214, 20.06195259], [86.27083588, 20.06194496], [86.27055359, 20.06222153], [86.26999664, 20.06222153], [86.26972198, 20.06250191], [86.26944733, 20.06250191], [86.26915741, 20.06278038], [86.26805878, 20.06278038], [86.26777649, 20.06250191], [86.26721954, 20.06250191], [86.26693726, 20.06278038], [86.26609802, 20.06278038], [86.26583099, 20.06250191], [86.26444244, 20.06250191], [86.26416779, 20.06222153], [86.26361084, 20.06222153], [86.26333618, 20.06194496], [86.26249695, 20.06195259], [86.26222229, 20.0616703], [86.26194763, 20.0616703], [86.26167297, 20.06139183], [86.26139069, 20.06139183], [86.2611084, 20.06111145], [86.26077271, 20.06113243], [86.26042938, 20.06096268], [86.26006317, 20.06063652], [86.25959778, 20.06031036], [86.25905609, 20.05999756], [86.25850677, 20.05971909], [86.25797272, 20.05944061], [86.25746918, 20.05916977], [86.25699615, 20.05892944], [86.25649261, 20.05879974], [86.25602722, 20.05859947], [86.25562286, 20.05837631], [86.25528717, 20.05811119], [86.25499725, 20.05784035], [86.25469208, 20.05760956], [86.25435638, 20.05741119], [86.2539978, 20.05719948], [86.25358582, 20.05698586], [86.25309753, 20.05682945], [86.25259399, 20.05665779], [86.25211334, 20.05647087], [86.2516098, 20.05633926], [86.25121307, 20.05611992], [86.2508316, 20.05592537], [86.25047302, 20.05574036], [86.25016785, 20.05553627], [86.24989319, 20.05528069], [86.24961853, 20.05500031], [86.24932098, 20.0547142], [86.24900055, 20.05439949], [86.248703, 20.0539875], [86.24829865, 20.05359268], [86.24785614, 20.05318832], [86.24752045, 20.05264091], [86.24726868, 20.05207253], [86.24716949, 20.05151176], [86.24698639, 20.05101967], [86.24687958, 20.05046844], [86.24677277, 20.04986191], [86.24689484, 20.0492897], [86.24685669, 20.04873085], [86.24669647, 20.04823112], [86.24666595, 20.04772949], [86.24668884, 20.04725075], [86.24675751, 20.04679871], [86.24668884, 20.04636002], [86.24666595, 20.04590034], [86.24666595, 20.0454464], [86.24664307, 20.04499817], [86.24650574, 20.04456902], [86.24636841, 20.04409981], [86.24632263, 20.04360008], [86.24623108, 20.0431881], [86.24610901, 20.04284096], [86.24598694, 20.0425396], [86.24585724, 20.04228973], [86.24582672, 20.04199982], [86.24580383, 20.04173088], [86.24568176, 20.04150963], [86.24555206, 20.04138947], [86.24555206, 20.04083061], [86.24500275, 20.04027748], [86.24472046, 20.04027939], [86.2444458, 20.04000092], [86.24388885, 20.04000092], [86.24333191, 20.03944016], [86.24305725, 20.03944206], [86.24277496, 20.0391674], [86.24250031, 20.03917122], [86.2419281, 20.03861046], [86.2408371, 20.03861046], [86.24054718, 20.03833008], [86.24028015, 20.03833389], [86.23916626, 20.03722382], [86.23916626, 20.03694534], [86.23972321, 20.0363903], [86.24028015, 20.0363903], [86.24111176, 20.03554916], [86.24138641, 20.03555489], [86.24194336, 20.03500175], [86.24250031, 20.03500175], [86.24276733, 20.03472137], [86.24333191, 20.03472137], [86.24333191, 20.03444481], [86.2436142, 20.03416634], [86.24360657, 20.03360748], [86.24305725, 20.03305626], [86.24305725, 20.03277969], [86.24250031, 20.03222084], [86.24250031, 20.03194427], [86.24222565, 20.0316658], [86.24221802, 20.0313797], [86.2419281, 20.03108025], [86.24194336, 20.0308342], [86.24055481, 20.02944374], [86.23999786, 20.03000069], [86.23944092, 20.03000069], [86.23918152, 20.02972031], [86.2388916, 20.02972221], [86.23860931, 20.02944374], [86.23833466, 20.02944374], [86.23805237, 20.02916527], [86.23777771, 20.02917099], [86.23750305, 20.02889061], [86.23694611, 20.02889061], [86.23665619, 20.02861023], [86.23665619, 20.02695084], [86.23972321, 20.02695084], [86.23999786, 20.02667046], [86.2419281, 20.02667046], [86.24221802, 20.02639008], [86.24254608, 20.02637291], [86.24291229, 20.02625084], [86.24323273, 20.02607918], [86.24352264, 20.02583122], [86.2437973, 20.02555275], [86.244133, 20.02526283], [86.24449921, 20.02495766], [86.24489594, 20.02465057], [86.24519348, 20.02425766], [86.24549866, 20.02388954], [86.24581909, 20.02353859], [86.24614716, 20.0231781], [86.24655914, 20.02287865], [86.24698639, 20.02254105], [86.24742126, 20.02219963], [86.24780273, 20.02177048], [86.24819946, 20.0214138], [86.24861145, 20.02115631], [86.24907684, 20.02114105], [86.24954987, 20.02130127], [86.25003815, 20.02133179], [86.25058746, 20.02116013], [86.25120544, 20.02108765], [86.2518158, 20.0209198], [86.25233459, 20.02060127], [86.25283051, 20.02033806], [86.25328827, 20.02013969], [86.25369263, 20.01991272], [86.25400543, 20.01964951], [86.25424194, 20.01927376], [86.25455475, 20.01893044], [86.25495911, 20.01863289], [86.25543976, 20.01839066], [86.25598145, 20.01833534], [86.25649261, 20.01832962], [86.25691986, 20.01833344], [86.25732422, 20.01833344], [86.25772858, 20.01832008], [86.25813293, 20.01823997], [86.25852966, 20.01813126], [86.2589798, 20.01828957], [86.25942993, 20.01828957], [86.25992584, 20.01810074], [86.26049805, 20.01805878], [86.26107788, 20.01806068], [86.2616272, 20.01806068], [86.26212311, 20.01805115], [86.26254272, 20.01799965], [86.26287079, 20.01781273], [86.26317596, 20.01775551], [86.26335144, 20.0177803], [86.26361084, 20.01749992], [86.26416779, 20.01749992], [86.26444244, 20.01721954], [86.26472473, 20.01722145], [86.26499939, 20.01694679], [86.26555634, 20.01694679], [86.26583099, 20.01722145], [86.26667023, 20.01721954], [86.26693726, 20.01749992], [86.26721954, 20.01749992], [86.26750183, 20.0177803], [86.26889038, 20.0177803], [86.26915741, 20.01749992], [86.26999664, 20.01749992], [86.27027893, 20.0177803], [86.27223206, 20.0177803], [86.27259064, 20.0177803], [86.27303314, 20.0177803], [86.27349091, 20.01777077], [86.27394867, 20.01772499], [86.27435303, 20.01754951], [86.27471924, 20.01753426], [86.27507019, 20.0176506], [86.27542114, 20.01776123], [86.27581024, 20.0178299], [86.27615356, 20.01800537], [86.27659607, 20.01805305], [86.27706146, 20.01808167], [86.27749634, 20.01819992], [86.27790833, 20.01834869], [86.27826691, 20.01852417], [86.27863312, 20.01866341], [86.27894592, 20.01885986], [86.27932739, 20.01903915], [86.27973175, 20.01920128], [86.28011322, 20.01942062], [86.28050232, 20.01960182], [86.2808609, 20.01986122], [86.28125763, 20.02013016], [86.28172302, 20.02038002], [86.28222656, 20.02060127], [86.28268433, 20.02090263], [86.28304291, 20.02127075], [86.28333282, 20.02164078], [86.28361511, 20.02193642], [86.28388214, 20.02219009], [86.28411865, 20.02243042], [86.28436279, 20.02260971], [86.28453827, 20.02287102], [86.28471375, 20.02317047], [86.28494263, 20.02351952], [86.28530121, 20.02388954], [86.28582764, 20.02416992], [86.28636932, 20.02434921], [86.28687286, 20.02420807], [86.287323, 20.0241909], [86.28774261, 20.02433968], [86.28818512, 20.02456856], [86.28868103, 20.02461243], [86.28920746, 20.02451515], [86.28967285, 20.02452087], [86.29006958, 20.02466965], [86.29049683, 20.02472115], [86.2909317, 20.02472687], [86.29133606, 20.02477074], [86.29171753, 20.02495003], [86.29211426, 20.02500534], [86.29234314, 20.02503014], [86.29252625, 20.02504921], [86.29296875, 20.02510834], [86.29344177, 20.02499008], [86.29393005, 20.02478981], [86.29444885, 20.02461243], [86.29494476, 20.02441978], [86.29532623, 20.02407837], [86.2954483, 20.02331352], [86.29568481, 20.02288055], [86.29576111, 20.0227356], [86.29608154, 20.02220917], [86.29640198, 20.0217495], [86.29670715, 20.02135086], [86.29693604, 20.02095985], [86.29689026, 20.02046013], [86.29699707, 20.02008438], [86.29720306, 20.01973152], [86.29738617, 20.01930809], [86.29766846, 20.01876068], [86.29798126, 20.01809311], [86.29836273, 20.01753044], [86.29884338, 20.01703072], [86.29940796, 20.0166893], [86.29992676, 20.01638031], [86.30036926, 20.01605988], [86.30072021, 20.01567841], [86.30104828, 20.01534081], [86.30139923, 20.0150528], [86.30178833, 20.01486969], [86.30217743, 20.01470184], [86.3025589, 20.01451111], [86.30297852, 20.01445198], [86.30343628, 20.01442337], [86.30396271, 20.01435471], [86.30454254, 20.01424026], [86.30516052, 20.01416206], [86.30540466, 20.01388931], [86.30561066, 20.01357841], [86.30587769, 20.01327133], [86.30612946, 20.01289177], [86.30639648, 20.01250076], [86.30661774, 20.01210976], [86.30665588, 20.01167107], [86.3069458, 20.01139069], [86.3069458, 20.01083183], [86.30722046, 20.01055527], [86.30722046, 20.01026917], [86.30833435, 20.00916672], [86.30832672, 20.00889015], [86.3088913, 20.00832939], [86.3088913, 20.00805473], [86.30916595, 20.00777817], [86.30916595, 20.0075016], [86.30944824, 20.00720978], [86.3105545, 20.00611115], [86.31054688, 20.00599289], [86.31079865, 20.00571632], [86.31098175, 20.00539017], [86.31114197, 20.00501251], [86.31141663, 20.00467491], [86.31178284, 20.00438118], [86.31195831, 20.00396919], [86.31175232, 20.00333977], [86.31170654, 20.00285339], [86.31179047, 20.00245857], [86.31172943, 20.00196838], [86.31171417, 20.0014267], [86.31181335, 20.00085068], [86.3122406, 20.0003891], [86.3125, 20.0], [86.31333923, 19.99916077], [86.31383514, 19.99882317], [86.31399536, 19.9985466], [86.3144455, 19.99777794], [86.31446075, 19.99749947], [86.3152771, 19.99666595], [86.3152771, 19.99638939], [86.31582642, 19.99583244], [86.31583405, 19.9952774], [86.3161087, 19.99500084], [86.3161087, 19.99471855], [86.31639099, 19.99444389], [86.31639099, 19.99416733], [86.31777954, 19.99278069], [86.31777954, 19.99250031], [86.31804657, 19.99221039], [86.3180542, 19.99194527], [86.31833649, 19.99167061], [86.31833649, 19.99028015], [86.31861115, 19.98999977], [86.31861115, 19.98944092], [86.31916809, 19.98888969], [86.31916809, 19.98861122], [86.31973267, 19.98806], [86.31973267, 19.98777962], [86.31999969, 19.98750114], [86.31999969, 19.98722076], [86.3216629, 19.98555565], [86.3216629, 19.98472023], [86.32194519, 19.98444366], [86.32194519, 19.98388863], [86.32138824, 19.98333168], [86.32138824, 19.98305511], [86.32013702, 19.98180962], [86.31906891, 19.98101044], [86.31715393, 19.98060417], [86.31646729, 19.98069954], [86.31518555, 19.98070526], [86.31414795, 19.98111153], [86.31181335, 19.98180962], [86.31130981, 19.9820652], [86.30995178, 19.9824028], [86.30887604, 19.98294067], [86.30802917, 19.98314857], [86.30690002, 19.98351097], [86.30487061, 19.9838829], [86.30390167, 19.98400116], [86.30323792, 19.98408318], [86.30266571, 19.98408318], [86.30252075, 19.98401642], [86.30252075, 19.98381042], [86.30266571, 19.9835434], [86.30308533, 19.9832592], [86.30349731, 19.98329544], [86.30388641, 19.98333359], [86.3041687, 19.98305511], [86.30473328, 19.98306274], [86.30500031, 19.98278046], [86.3069458, 19.98278046], [86.30722046, 19.98250008], [86.3077774, 19.98250008], [86.30860901, 19.98167038], [86.30916595, 19.98167038], [86.30944824, 19.98139191], [86.31027985, 19.98139191], [86.31054688, 19.98111153], [86.31138611, 19.98111153], [86.31359863, 19.98013496], [86.3157959, 19.9798584], [86.31711578, 19.97971916], [86.31789398, 19.97991562], [86.31839752, 19.97998047], [86.31907654, 19.98023033], [86.31999969, 19.9805603], [86.32097626, 19.98103905], [86.32168579, 19.98171616], [86.32195282, 19.9822216], [86.32277679, 19.98305511], [86.32315063, 19.98347282], [86.32327271, 19.98361206], [86.32389069, 19.98361206], [86.32472229, 19.98277855], [86.32472229, 19.98250008], [86.32640076, 19.98082924], [86.3263855, 19.98055649], [86.32694244, 19.97999763], [86.3272171, 19.97999763], [86.32861328, 19.97860909], [86.32888794, 19.97860909], [86.32917023, 19.97833061], [86.32944489, 19.97833252], [86.32971954, 19.97805786], [86.33055878, 19.97805977], [86.33082581, 19.97777939], [86.33110809, 19.97777939], [86.33139038, 19.97750092], [86.33167267, 19.97750092], [86.33194733, 19.97722244], [86.33304596, 19.97722816], [86.33333588, 19.97694016], [86.33444214, 19.97694397], [86.33472443, 19.9766655], [86.33528137, 19.97667122], [86.33557129, 19.97639084], [86.33583069, 19.97639084], [86.33611298, 19.97611046], [86.33638763, 19.97611046], [86.33666992, 19.97583008], [86.33721924, 19.9758358], [86.33750153, 19.97555542], [86.33777618, 19.97556114], [86.33805847, 19.97528076], [86.33834076, 19.97528076], [86.33917999, 19.97454071], [86.3397522, 19.97393036], [86.34060669, 19.97284889], [86.34102631, 19.97237968], [86.34137726, 19.97116089], [86.34137726, 19.97056007], [86.34027863, 19.96944237], [86.33999634, 19.96944427], [86.33972168, 19.9691658], [86.33944702, 19.96916962], [86.3391571, 19.96889114], [86.33889008, 19.96889114], [86.33834076, 19.96832848], [86.33805847, 19.9683342], [86.33792114, 19.96819687], [86.33777618, 19.96805573], [86.33777618, 19.96777916], [86.33583069, 19.96582985], [86.33472443, 19.96388626], [86.3347168, 19.9636097], [86.33305359, 19.96194458], [86.33277893, 19.96194458], [86.33073425, 19.95990181], [86.32944489, 19.95861053], [86.32943726, 19.95778084], [86.32953644, 19.95768166], [86.32971954, 19.95750046], [86.3290329, 19.95681381], [86.32888794, 19.95666695], [86.32888794, 19.95656013], [86.32888794, 19.95638847], [86.32863617, 19.9561367], [86.32805634, 19.95555496], [86.32776642, 19.95556259], [86.32749939, 19.9552803], [86.32694244, 19.9552803], [86.32666779, 19.95500183], [86.3263855, 19.95500183], [86.32583618, 19.95444489], [86.32555389, 19.95444489], [86.32499695, 19.95388985], [86.32472229, 19.95389175], [86.32463074, 19.95379448], [86.32417297, 19.95332909], [86.32389069, 19.9533329], [86.3236084, 19.95305634], [86.32305908, 19.95305824], [86.32277679, 19.95277977], [86.32250214, 19.95277977], [86.32221985, 19.95249748], [86.3216629, 19.95249748], [86.32138824, 19.95222092], [86.32111359, 19.95222282], [86.3208313, 19.95194435], [86.32027435, 19.95194435], [86.31999969, 19.95166779], [86.31944275, 19.95166969], [86.31916809, 19.95139122], [86.3188858, 19.95139122], [86.31861115, 19.95111084], [86.31833649, 19.95111084], [86.31720734, 19.95000076], [86.31694794, 19.94972038], [86.31749725, 19.94916534], [86.31833649, 19.94916534], [86.31847382, 19.94930458], [86.31861115, 19.94944382], [86.3188858, 19.94944382], [86.31916809, 19.94972229], [86.31944275, 19.94972038], [86.31999969, 19.95029068], [86.32027435, 19.95027542], [86.3208313, 19.95083427], [86.32110596, 19.95083046], [86.32138824, 19.95111084], [86.3216629, 19.95111084], [86.32195282, 19.95139122], [86.32221985, 19.95139122], [86.32250214, 19.95166969], [86.32305908, 19.95166779], [86.32333374, 19.95194435], [86.32389069, 19.95194435], [86.32416534, 19.95222282], [86.32444763, 19.95222092], [86.32499695, 19.95277977], [86.32527924, 19.95277977], [86.32554626, 19.95305824], [86.32611084, 19.95305824], [86.32694244, 19.95389175], [86.32722473, 19.95388985], [86.32749939, 19.95416641], [86.32777405, 19.95416641], [86.32805634, 19.95444489], [86.32833099, 19.95444489], [86.33110809, 19.95722008], [86.33416748, 19.96055984], [86.33444214, 19.96055412], [86.33472443, 19.9608326], [86.33499908, 19.96083069], [86.33666992, 19.96249962], [86.33777618, 19.96499825], [86.33777618, 19.96528816], [86.33805847, 19.96555519], [86.33805847, 19.96583366], [86.33834076, 19.96610832], [86.33834076, 19.96639061], [86.33944702, 19.96750069], [86.33972168, 19.96750069], [86.33999634, 19.96777916], [86.34027863, 19.96777725], [86.34135437, 19.96863747], [86.34243774, 19.9695034], [86.34331512, 19.96925926], [86.34381104, 19.9691906], [86.34467316, 19.96865082], [86.3451767, 19.96858025], [86.34554291, 19.96813583], [86.34632111, 19.96759033], [86.34696198, 19.96711922], [86.34767151, 19.96651077], [86.34806824, 19.96610832], [86.34913635, 19.96547127], [86.3500061, 19.96467972], [86.35086823, 19.9642086], [86.3514328, 19.96393967], [86.35164642, 19.96372986], [86.35165405, 19.96339417], [86.35111237, 19.96333122], [86.35083008, 19.96333313], [86.34899902, 19.96389961], [86.34814453, 19.96430969], [86.34714508, 19.96485138], [86.34671783, 19.96512032], [86.34622192, 19.96533012], [86.34593964, 19.96533012], [86.34586334, 19.96512032], [86.34593964, 19.96478462], [86.34650421, 19.96437645], [86.34694672, 19.96417046], [86.34751129, 19.9636097], [86.34777832, 19.9636116], [86.34833527, 19.96305466], [86.34860992, 19.96305466], [86.34889221, 19.96277618], [86.34971619, 19.96278], [86.34999847, 19.96249962], [86.35083008, 19.96249962], [86.35111237, 19.96223068], [86.35250092, 19.96223068], [86.3527832, 19.96194077], [86.35361481, 19.96194458], [86.35388947, 19.9616642], [86.35500336, 19.96166992], [86.35527802, 19.96138954], [86.35584259, 19.96138954], [86.35610962, 19.96111107], [86.35666656, 19.96111107], [86.35694122, 19.96083069], [86.35749817, 19.9608326], [86.35778046, 19.96055412], [86.35832977, 19.96055984], [86.35861206, 19.96027946], [86.35888672, 19.96027946], [86.35945129, 19.95972061], [86.35972595, 19.95972252], [86.36000061, 19.95944214], [86.36027527, 19.95944214], [86.36055756, 19.95916748], [86.3611145, 19.95916748], [86.36138916, 19.95888901], [86.36222076, 19.95889091], [86.36251068, 19.95861053], [86.36277771, 19.95861053], [86.36305237, 19.95833015], [86.3638916, 19.95833206], [86.36416626, 19.9580555], [86.36472321, 19.95806122], [86.36499786, 19.95778084], [86.36554718, 19.95778084], [86.3658371, 19.95750046], [86.3658371, 19.95583153], [86.3655777, 19.9551506], [86.36422729, 19.95372963], [86.36266327, 19.95277977], [86.36065674, 19.9522419], [86.35788727, 19.95156288], [86.35634613, 19.95125961], [86.35546875, 19.95108795], [86.35169983, 19.95055008], [86.34992218, 19.95013046], [86.34664917, 19.94966888], [86.34500885, 19.94872284], [86.34395599, 19.94819069], [86.34261322, 19.94819069], [86.34131622, 19.94765091], [86.3395462, 19.9474411], [86.33691406, 19.94683456], [86.33413696, 19.94636154], [86.33200073, 19.94602013], [86.33113861, 19.94584656], [86.32971954, 19.94555473], [86.32746887, 19.94473839], [86.32462311, 19.94412994], [86.32398224, 19.94406128], [86.32319641, 19.94392395], [86.32205963, 19.94372368], [86.32149506, 19.94350624], [86.32042694, 19.94299126], [86.31977844, 19.94279289], [86.318573, 19.94218063], [86.31742859, 19.94197083], [86.31593323, 19.94190025], [86.31443787, 19.94123077], [86.31279755, 19.94067955], [86.31180573, 19.94047737], [86.31059265, 19.93988991], [86.30912781, 19.93950081], [86.30713654, 19.93917084], [86.30535889, 19.93856239], [86.30420685, 19.93802071], [86.30172729, 19.93721008], [86.3003006, 19.93659019], [86.29880524, 19.93585396], [86.29766846, 19.93564987], [86.29611206, 19.93551064], [86.29475403, 19.93497276], [86.29375458, 19.93463516], [86.2926178, 19.93367958], [86.29192352, 19.93335724], [86.2903595, 19.9327507], [86.28956604, 19.93227005], [86.28843689, 19.93193626], [86.28730011, 19.93112564], [86.28565979, 19.93085289], [86.28424072, 19.9303112], [86.28309631, 19.92963982], [86.28217316, 19.92923164], [86.2806778, 19.92821884], [86.27867889, 19.92733955], [86.2770462, 19.92658806], [86.2736969, 19.92496872], [86.27220917, 19.92436028], [86.26999664, 19.92307091], [86.26717377, 19.9215641], [86.26574707, 19.92068481], [86.26475525, 19.92020988], [86.26347351, 19.91926193], [86.26183319, 19.91892242], [86.25930023, 19.91778755], [86.25666809, 19.91642952], [86.25421143, 19.91516685], [86.25258636, 19.91434097], [86.25016785, 19.91270828], [86.24867249, 19.91183662], [86.24739075, 19.91123009], [86.24617767, 19.91115952], [86.24524689, 19.91115952], [86.2444458, 19.91194534], [86.24278259, 19.91250038], [86.24138641, 19.91389084], [86.24138641, 19.9141674], [86.2408371, 19.91471863], [86.2408371, 19.91500092], [86.24028015, 19.91555977], [86.24028015, 19.9161129], [86.2416687, 19.91749954], [86.2419281, 19.91749954], [86.24221802, 19.91777992], [86.24250031, 19.91777802], [86.24333191, 19.91860962], [86.24305725, 19.91889], [86.24305725, 19.91944313], [86.24278259, 19.9197197], [86.24278259, 19.92028046], [86.24250031, 19.92055321], [86.24250031, 19.92083359], [86.24222565, 19.92111206], [86.24175262, 19.92205048], [86.24160004, 19.92205048], [86.24138641, 19.92192268], [86.24138641, 19.92099762], [86.24173737, 19.92004967], [86.24173737, 19.91917038], [86.24102783, 19.91822052], [86.24010468, 19.91727448], [86.2388916, 19.91638947], [86.2388916, 19.9159584], [86.2388916, 19.91583252], [86.23944092, 19.91527748], [86.23944092, 19.91500092], [86.23972321, 19.91471863], [86.23972321, 19.9141674], [86.23999786, 19.91389084], [86.23999786, 19.91361046], [86.24028015, 19.91332817], [86.23999786, 19.91305542], [86.23999786, 19.91278076], [86.23972321, 19.91250038], [86.23832703, 19.91389084], [86.23805237, 19.91389084], [86.23750305, 19.91332817], [86.23750305, 19.91222191], [86.23722076, 19.91194534], [86.23722076, 19.91167068], [86.23694611, 19.9113903], [86.23694611, 19.91082954], [86.23583221, 19.90972137], [86.23583221, 19.90916443], [86.23443604, 19.90777969], [86.23388672, 19.90777969], [86.23332977, 19.90722084], [86.23305511, 19.90722275], [86.23278046, 19.90694427], [86.23222351, 19.90694427], [86.23194122, 19.9066658], [86.23166656, 19.90666962], [86.23139191, 19.90639114], [86.23110962, 19.90639114], [86.22972107, 19.90501022], [86.22944641, 19.90501022], [86.22833252, 19.90389061], [86.2277832, 19.90361023], [86.22666931, 19.90361023], [86.22638702, 19.90389061], [86.22583008, 19.9038887], [86.22499847, 19.90472031], [86.22499847, 19.90501022], [86.22360992, 19.90639114], [86.22360992, 19.9066658], [86.22333527, 19.90694427], [86.22333527, 19.90722275], [86.22250366, 19.90805435], [86.22249603, 19.90833092], [86.22166443, 19.90916443], [86.22166443, 19.90944672], [86.22138977, 19.90972137], [86.22138977, 19.91055489], [86.22110748, 19.91082954], [86.22110748, 19.91138649], [86.22305298, 19.91332817], [86.22305298, 19.91361046], [86.22389221, 19.91444397], [86.22389221, 19.91471863], [86.22528076, 19.9161129], [86.22556305, 19.9161129], [86.22606659, 19.91662025], [86.22634125, 19.91731071], [86.22657013, 19.91855049], [86.22657013, 19.91949844], [86.22632599, 19.92052078], [86.22606659, 19.92087936], [86.22583008, 19.92111015], [86.22551727, 19.9217701], [86.22480774, 19.92251015], [86.22431183, 19.92332268], [86.2237854, 19.9246521], [86.22354126, 19.92498016], [86.22328186, 19.92533112], [86.22289276, 19.92562103], [86.22252655, 19.92562103], [86.22249603, 19.92547607], [86.22246552, 19.92534447], [86.2227478, 19.92480278], [86.22305298, 19.92416954], [86.22354889, 19.9229393], [86.22397614, 19.92213058], [86.22421265, 19.9218998], [86.22505951, 19.92095184], [86.22556305, 19.92033958], [86.22576904, 19.91966438], [86.22555542, 19.91861153], [86.22528076, 19.91833305], [86.22528076, 19.91805649], [86.22499847, 19.91777992], [86.22499847, 19.91749954], [86.22389221, 19.91638947], [86.22389221, 19.9161129], [86.22081757, 19.91305923], [86.22081757, 19.91278076], [86.22055817, 19.91250038], [86.22055817, 19.91221809], [86.22027588, 19.91194534], [86.22027588, 19.91167068], [86.22000122, 19.9113903], [86.21943665, 19.91194916], [86.21888733, 19.91194916], [86.21868134, 19.91214943], [86.21775818, 19.91290092], [86.21720123, 19.91323662], [86.21689606, 19.91332054], [86.21671295, 19.91337013], [86.21656036, 19.9134407], [86.21627808, 19.913311], [86.21613312, 19.9131012], [86.21606445, 19.91269875], [86.21556091, 19.91242027], [86.21472168, 19.91222191], [86.21416473, 19.91222191], [86.21389008, 19.91194534], [86.21360779, 19.91194916], [86.21298218, 19.91131973], [86.21277618, 19.91110992], [86.21250153, 19.91111183], [86.21250153, 19.91083336], [86.21221924, 19.91055489], [86.21221924, 19.90916443], [86.21250153, 19.90888977], [86.21221924, 19.90833092], [86.21250153, 19.90805435], [86.21250153, 19.90611076], [86.21221924, 19.90583038], [86.21221924, 19.90555573], [86.21138763, 19.90472031], [86.20944214, 19.90472031], [86.20887756, 19.90528107], [86.20887756, 19.90555954], [86.20848083, 19.90600014], [86.20812988, 19.90607071], [86.20791626, 19.90607071], [86.20791626, 19.90553093], [86.20804596, 19.90472031], [86.20944214, 19.90333366], [86.21111298, 19.90333176], [86.21138763, 19.90361023], [86.21194458, 19.90361023], [86.21305847, 19.90472031], [86.21305847, 19.90501022], [86.21360779, 19.90555573], [86.21360779, 19.90583038], [86.21389008, 19.90611076], [86.21389008, 19.90639114], [86.21416473, 19.9066658], [86.21416473, 19.90694427], [86.21389008, 19.90722275], [86.21389008, 19.90833282], [86.21360779, 19.90860939], [86.21360779, 19.90888977], [86.21389008, 19.90916443], [86.21389008, 19.90971947], [86.2141571, 19.90999985], [86.21416473, 19.91027641], [86.21444702, 19.91055489], [86.21444702, 19.91082954], [86.2150116, 19.9113903], [86.21555328, 19.91138649], [86.21565247, 19.91148567], [86.2158432, 19.91167068], [86.21678925, 19.91166878], [86.21721649, 19.91167068], [86.21749878, 19.9113903], [86.21778107, 19.9113903], [86.21833038, 19.91082954], [86.21888733, 19.91083336], [86.21916962, 19.91055489], [86.21916962, 19.91027641], [86.21971893, 19.90971947], [86.21971893, 19.90888977], [86.22000122, 19.90860939], [86.22000122, 19.90805435], [86.22027588, 19.90777779], [86.22027588, 19.90722084], [86.22110748, 19.90638924], [86.22138977, 19.90639114], [86.22194672, 19.90583038], [86.22194672, 19.90527725], [86.22305298, 19.9041729], [86.22305298, 19.90389061], [86.22471619, 19.90222168], [86.22558594, 19.9016819], [86.22657776, 19.90160942], [86.22735596, 19.90175056], [86.22807312, 19.90184021], [86.22838593, 19.90184021], [86.22867584, 19.90157127], [86.22796631, 19.90088081], [86.22753143, 19.90075493], [86.2247467, 19.89953995], [86.22238922, 19.89898109], [86.2199707, 19.89810562], [86.21837616, 19.89743614], [86.21705627, 19.89688492], [86.21613312, 19.89689064], [86.21440887, 19.89621162], [86.21250153, 19.89546013], [86.20986938, 19.89458275], [86.20710754, 19.89394379], [86.20603943, 19.89347076], [86.20461273, 19.89286041], [86.20226288, 19.89204979], [86.19906616, 19.8908329], [86.19629669, 19.89007187], [86.19473267, 19.88966751], [86.19210052, 19.88879013], [86.19061279, 19.88796806], [86.18804932, 19.8872261], [86.18527985, 19.88628006], [86.18392181, 19.88594055], [86.18171692, 19.88525963], [86.17887115, 19.88438225], [86.17778015, 19.88388634], [86.1763916, 19.88376617], [86.17575073, 19.88343239], [86.17489624, 19.88295174], [86.17440033, 19.88288498], [86.1727829, 19.88278008], [86.17082977, 19.88217926], [86.16696167, 19.88101006], [86.1651001, 19.88030052], [86.16268158, 19.8796196], [86.1607666, 19.87887955], [86.15888977, 19.87833023], [86.15833282, 19.87833214], [86.15777588, 19.8777771], [86.1550827, 19.87730026], [86.15399933, 19.87686729], [86.15248871, 19.87615013], [86.15019989, 19.87568092], [86.14985657, 19.87568092], [86.14885712, 19.87528992], [86.14705658, 19.87456322], [86.14585114, 19.87415886], [86.14408112, 19.87401962], [86.14266968, 19.87341499], [86.14111328, 19.87267113], [86.14017487, 19.87246704], [86.13939667, 19.87220001], [86.13752747, 19.87181091], [86.1366806, 19.87140656], [86.13553619, 19.87141037], [86.13446808, 19.87072945], [86.13340759, 19.87053108], [86.13247681, 19.87005997], [86.13166809, 19.86972046], [86.1305542, 19.86972237], [86.12809753, 19.8693161], [86.12696075, 19.86890984], [86.12539673, 19.86844254], [86.12412262, 19.86796188], [86.12247467, 19.86750031], [86.1222229, 19.86750031], [86.12076569, 19.86750412], [86.12032318, 19.8674736], [86.11977386, 19.86743736], [86.1182785, 19.86668968], [86.11685181, 19.86655617], [86.1155014, 19.8658123], [86.11351776, 19.86547279], [86.11138916, 19.8647213], [86.11055756, 19.86444473], [86.11000061, 19.86416626], [86.10961151, 19.86404037], [86.10845947, 19.86347961], [86.10726166, 19.86347961], [86.10610962, 19.86361122], [86.10584259, 19.86333275], [86.10444641, 19.86333275], [86.10416412, 19.86305618], [86.10305786, 19.8630619], [86.1027832, 19.86277962], [86.10250092, 19.86277962], [86.10221863, 19.86250114], [86.10138702, 19.86250114], [86.10124969, 19.86236191], [86.10111237, 19.86222267], [86.10083008, 19.86222267], [86.10055542, 19.8619442], [86.09999847, 19.8619442], [86.09972382, 19.86166573], [86.09916687, 19.86166954], [86.09770966, 19.86129951], [86.0966568, 19.86055946], [86.09514618, 19.85991096], [86.09465027, 19.85984612], [86.09278107, 19.85971069], [86.09194183, 19.85972214], [86.09166718, 19.85944366], [86.09083557, 19.85944366], [86.09055328, 19.8591671], [86.09027863, 19.85917091], [86.08999634, 19.85889053], [86.08947754, 19.85889053], [86.08777618, 19.85847092], [86.08586121, 19.85819817], [86.08436584, 19.85773277], [86.08296967, 19.85741043], [86.08062744, 19.85713959], [86.07920074, 19.85674095], [86.07861328, 19.85667038], [86.07805634, 19.85666847], [86.07777405, 19.85694695], [86.07722473, 19.85694695], [86.07694244, 19.8572216], [86.0763855, 19.8572216], [86.07611084, 19.85694695], [86.07583618, 19.85694695], [86.07555389, 19.85666847], [86.07333374, 19.85666847], [86.07305908, 19.85694695], [86.07250214, 19.85694695], [86.07221985, 19.85666847], [86.0716629, 19.85667038], [86.07138824, 19.85639], [86.07054901, 19.85639], [86.06999969, 19.85583115], [86.06972504, 19.85611153], [86.06833649, 19.85611153], [86.0680542, 19.85583305], [86.0661087, 19.85583305], [86.06583405, 19.85555458], [86.0652771, 19.8555603], [86.06500244, 19.85527992], [86.06472015, 19.85527992], [86.06445313, 19.85499954], [86.0633316, 19.85499954], [86.06305695, 19.85472107], [86.06222534, 19.85472488], [86.06138611, 19.85388947], [86.06111145, 19.85390091], [86.06083679, 19.85416985], [86.05999756, 19.85416985], [86.0597229, 19.85390091], [86.05916595, 19.85390091], [86.0588913, 19.85416985], [86.05665588, 19.85416985], [86.05464172, 19.85373116], [86.05349731, 19.85338974], [86.05193329, 19.8531208], [86.05076599, 19.8526783], [86.04865265, 19.85222054], [86.04833221, 19.85222244], [86.04805756, 19.85194206], [86.04777527, 19.85194206], [86.04750061, 19.8516674], [86.04360962, 19.8516674], [86.04333496, 19.85194206], [86.04222107, 19.85194206], [86.04194641, 19.85222244], [86.04138947, 19.85222054], [86.04110718, 19.85250092], [86.04083252, 19.85250092], [86.0402832, 19.85305977], [86.03971863, 19.85305977], [86.03916931, 19.85361099], [86.03888702, 19.85361099], [86.03805542, 19.8544445], [86.03778076, 19.8544445], [86.03749847, 19.85472488], [86.03721619, 19.85472107], [86.03694153, 19.85499954], [86.03666687, 19.85499954], [86.03639221, 19.85527992], [86.03610992, 19.85527992], [86.0358429, 19.85499954], [86.03555298, 19.85499954], [86.03527832, 19.85527992], [86.03499603, 19.85527992], [86.03472137, 19.85499954], [86.03414917, 19.85499954], [86.03392029, 19.85475159], [86.03333282, 19.85472488], [86.03305817, 19.8544445], [86.03250122, 19.8544445], [86.03236389, 19.85430527], [86.03221893, 19.85416412], [86.03193665, 19.85416985], [86.03098297, 19.85288048], [86.03044128, 19.85232353], [86.03044128, 19.85198402], [86.03083801, 19.85174561], [86.03091431, 19.85153961], [86.03090668, 19.8512001], [86.03055573, 19.85059357], [86.03055573, 19.85027695], [86.03028107, 19.85000038], [86.03028107, 19.84972191], [86.02999878, 19.84944534], [86.02999878, 19.84917259], [86.02916718, 19.84833145], [86.02889252, 19.84833336], [86.02805328, 19.84750175], [86.02805328, 19.84722137], [86.02777863, 19.84694481], [86.02777863, 19.84666634], [86.02668762, 19.84560013], [86.02611542, 19.84519768], [86.02526093, 19.84513092], [86.02481842, 19.84500122], [86.02353668, 19.84487724], [86.02353668, 19.84453964], [86.02371216, 19.84424973], [86.02464294, 19.84408951], [86.02527618, 19.84416962], [86.02583313, 19.84416771], [86.02607727, 19.84428787], [86.02694702, 19.84472275], [86.02722168, 19.8447094], [86.02777863, 19.84527969], [86.02805328, 19.84527969], [86.02833557, 19.84555626], [86.0283432, 19.84583092], [86.02889252, 19.84638977], [86.02916718, 19.84638977], [86.03083038, 19.84805489], [86.03083038, 19.84833336], [86.03111267, 19.84861183], [86.03111267, 19.8488903], [86.03166962, 19.84944534], [86.03166962, 19.84972191], [86.03193665, 19.85000038], [86.03193665, 19.85056114], [86.03221893, 19.85083961], [86.03221893, 19.85111046], [86.03250122, 19.85138893], [86.03250122, 19.85194206], [86.03277588, 19.85222054], [86.03277588, 19.85250092], [86.03414917, 19.85390091], [86.03666687, 19.85390091], [86.03694153, 19.85361099], [86.0375061, 19.85361099], [86.03778076, 19.85333252], [86.03805542, 19.85333252], [86.03861237, 19.85277748], [86.03888702, 19.85277939], [86.04057312, 19.85111046], [86.04111481, 19.85111046], [86.04334259, 19.8488903], [86.04416656, 19.84804916], [86.04499054, 19.84777832], [86.04548645, 19.84757614], [86.04563141, 19.84737015], [86.04563141, 19.84723663], [86.04556274, 19.84710121], [86.0450592, 19.84691048], [86.04432678, 19.84682274], [86.04403687, 19.84674072], [86.04302216, 19.84657097], [86.04189301, 19.84622955], [86.04142761, 19.84614944], [86.04029846, 19.84601784], [86.03845215, 19.84534073], [86.0378418, 19.84528923], [86.03620148, 19.84507942], [86.03499603, 19.84454346], [86.03356934, 19.84427071], [86.03214264, 19.84406853], [86.03050995, 19.8439312], [86.02980804, 19.84362602], [86.02752686, 19.84329033], [86.02632904, 19.84282112], [86.02490234, 19.84262085], [86.02348328, 19.84249115], [86.02134705, 19.84227943], [86.02068329, 19.84214592], [86.01847839, 19.84160614], [86.01641083, 19.84086037], [86.01486969, 19.84062576], [86.01394653, 19.84049034], [86.01251984, 19.8402195], [86.01145935, 19.84008026], [86.00999451, 19.83998108], [86.00914001, 19.83991432], [86.00821686, 19.83984947], [86.00737, 19.83937073], [86.00658417, 19.83910179], [86.00543976, 19.83910179], [86.00479889, 19.83883286], [86.0031662, 19.83835793], [86.0017395, 19.83829117], [86.0, 19.83805275], [85.99822998, 19.83774948], [85.99749756, 19.83778], [85.99555206, 19.83778], [85.99500275, 19.83749962], [85.99472046, 19.83749962], [85.9944458, 19.83722115], [85.99416351, 19.83722115], [85.99388885, 19.83694458], [85.99111176, 19.83694458], [85.99055481, 19.83638954], [85.9888916, 19.83638954], [85.98860931, 19.83611107], [85.98583221, 19.83611107], [85.98555756, 19.8358326], [85.98500061, 19.8358326], [85.98472595, 19.83555603], [85.98361206, 19.83556175], [85.98332977, 19.83527946], [85.98278046, 19.83527946], [85.98249817, 19.83499908], [85.98110962, 19.83499908], [85.98084259, 19.83472061], [85.97915649, 19.83472061], [85.97888947, 19.83499908], [85.97860718, 19.83499908], [85.9783783, 19.83476639], [85.97805786, 19.83472252], [85.97750092, 19.83416748], [85.97638702, 19.83416939], [85.97611237, 19.83389091], [85.97583008, 19.83389091], [85.97556305, 19.83361053], [85.97499847, 19.83361053], [85.97471619, 19.83389091], [85.97444153, 19.83389091], [85.97416687, 19.83361053], [85.97360992, 19.83361053], [85.9733429, 19.83332825], [85.97305298, 19.83361053], [85.97277832, 19.83361053], [85.97249603, 19.83332825], [85.97166443, 19.83333397], [85.97138977, 19.8330555], [85.97055817, 19.83305931], [85.97027588, 19.83276939], [85.96861267, 19.83277893], [85.96833038, 19.83250046], [85.96749878, 19.83250046], [85.96721649, 19.83221817], [85.96694183, 19.83222198], [85.96666718, 19.83194351], [85.96444702, 19.83194351], [85.96416473, 19.83166885], [85.96193695, 19.83167076], [85.96166992, 19.83139038], [85.96028137, 19.83139038], [85.96014404, 19.83124733], [85.95999908, 19.83110809], [85.95916748, 19.83111191], [85.95888519, 19.83083344], [85.95833588, 19.83083344], [85.95805359, 19.83055687], [85.95749664, 19.83056068], [85.95722198, 19.8302803], [85.95527649, 19.8302803], [85.95500183, 19.82999992], [85.95333099, 19.82999992], [85.95305634, 19.82973099], [85.95276642, 19.82973099], [85.95249939, 19.82944107], [85.9513855, 19.82944679], [85.95111084, 19.82916451], [85.94999695, 19.82917023], [85.94972229, 19.82888985], [85.9486084, 19.82888985], [85.94832611, 19.82860947], [85.94777679, 19.82861137], [85.94750214, 19.8283329], [85.9466629, 19.8283329], [85.94657135, 19.82824135], [85.94638824, 19.82805443], [85.94499969, 19.82806015], [85.94489288, 19.82795143], [85.94473267, 19.82777977], [85.94444275, 19.82777977], [85.94416046, 19.82749939], [85.94277954, 19.82749939], [85.94249725, 19.82722092], [85.9422226, 19.82722282], [85.94194794, 19.82694435], [85.94083405, 19.82694435], [85.94055176, 19.82666588], [85.93888855, 19.82666969], [85.93860626, 19.82639122], [85.93776703, 19.82639122], [85.9375, 19.82611084], [85.93583679, 19.82611084], [85.93554688, 19.82583046], [85.93527985, 19.82583237], [85.93499756, 19.8255558], [85.93444824, 19.82555962], [85.9338913, 19.82500076], [85.93110657, 19.82444191], [85.92972565, 19.82444382], [85.9291687, 19.82388878], [85.92749786, 19.82389069], [85.92722321, 19.82360077], [85.92694092, 19.82361031], [85.92666626, 19.82333374], [85.92610931, 19.82333374], [85.92597961, 19.82320213], [85.92583466, 19.82305527], [85.92472076, 19.82305527], [85.92455292, 19.82322693], [85.92444611, 19.82333374], [85.92416382, 19.82305527], [85.9236145, 19.82305527], [85.92333221, 19.82333374], [85.92138672, 19.82333374], [85.92082977, 19.8227787], [85.92028046, 19.82278061], [85.91999054, 19.82250023], [85.91971588, 19.82250023], [85.91944122, 19.82222176], [85.91750336, 19.82222176], [85.91722107, 19.82250023], [85.91694641, 19.82222176], [85.91638947, 19.82222176], [85.91611481, 19.82250023], [85.91416931, 19.82250023], [85.91361237, 19.82194519], [85.91333008, 19.82195282], [85.91306305, 19.82167053], [85.91278076, 19.82167053], [85.91221619, 19.82111168], [85.91083527, 19.82111168], [85.91027832, 19.82055473], [85.90972137, 19.82111168], [85.90972137, 19.82139015], [85.90860748, 19.82250023], [85.90860748, 19.82360077], [85.90833282, 19.82388878], [85.90833282, 19.82472038], [85.90805817, 19.82500076], [85.90805054, 19.82583046], [85.90777588, 19.82611084], [85.90777588, 19.82694435], [85.90750122, 19.82722092], [85.90750122, 19.82777977], [85.90721893, 19.82805443], [85.90721893, 19.82860947], [85.90694427, 19.82888794], [85.90693665, 19.82944107], [85.90666962, 19.82973099], [85.90666962, 19.82999992], [85.90694427, 19.8302784], [85.90638733, 19.83083344], [85.90638733, 19.83110809], [85.90583038, 19.83166885], [85.90583038, 19.83194351], [85.90555573, 19.83222198], [85.90499878, 19.83222198], [85.90460205, 19.83182716], [85.90444183, 19.83166885], [85.90416718, 19.83167076], [85.90416718, 19.82973099], [85.90471649, 19.82917023], [85.90471649, 19.82888985], [85.90500641, 19.82860947], [85.90499878, 19.82805443], [85.90528107, 19.82777977], [85.90528107, 19.82500076], [85.90556335, 19.82472038], [85.90555573, 19.82305527], [85.90583038, 19.82278061], [85.90583038, 19.82222176], [85.90611267, 19.82194519], [85.90611267, 19.82111168], [85.90638733, 19.82083321], [85.90638733, 19.82055473], [85.90777588, 19.81916618], [85.90834045, 19.81858063], [85.9080658, 19.8178997], [85.90721893, 19.81777954], [85.90596771, 19.81768036], [85.90338898, 19.81699944], [85.90084076, 19.81604958], [85.89813995, 19.81524086], [85.89514923, 19.81456184], [85.893013, 19.81402016], [85.8897171, 19.81278038], [85.88861084, 19.81278038], [85.88833618, 19.8125], [85.88639069, 19.8125], [85.8861084, 19.81221962], [85.88555908, 19.81222153], [85.88527679, 19.81194305], [85.88500214, 19.81195068], [85.88471985, 19.81166267], [85.8841629, 19.81166649], [85.88388824, 19.81138802], [85.88360596, 19.81138992], [85.8833313, 19.81110954], [85.88249969, 19.81111145], [85.88222504, 19.81083107], [85.88083649, 19.81083107], [85.8805542, 19.81055641], [85.87944794, 19.81056023], [85.8793335, 19.81044769], [85.87917328, 19.81027985], [85.87889099, 19.81027985], [85.8786087, 19.80999947], [85.8769455, 19.80999947], [85.87666321, 19.8097229], [85.87611389, 19.8097229], [85.8758316, 19.80944443], [85.87472534, 19.80944443], [85.87444305, 19.80916595], [85.8741684, 19.80916977], [85.87388611, 19.80888939], [85.87277985, 19.80888939], [85.87249756, 19.80859756], [85.8722229, 19.80861282], [85.87194824, 19.80833244], [85.8713913, 19.80833244], [85.87110901, 19.80805588], [85.8702774, 19.80805969], [85.87000275, 19.80777931], [85.86972046, 19.80777931], [85.8694458, 19.80750084], [85.86805725, 19.80750084], [85.86778259, 19.80721855], [85.8666687, 19.80722237], [85.86638641, 19.80694389], [85.86555481, 19.80694389], [85.86528015, 19.80666733], [85.86499786, 19.80666924], [85.86472321, 19.80639076], [85.86444092, 19.80639076], [85.86416626, 19.80611038], [85.86360931, 19.80611038], [85.86305237, 19.80555916], [85.86194611, 19.80555916], [85.86165619, 19.80528069], [85.86055756, 19.80528069], [85.85943604, 19.80417061], [85.85888672, 19.80389023], [85.85861206, 19.80360985], [85.85749817, 19.80361176], [85.85562897, 19.80340576], [85.85475922, 19.80258751], [85.85391998, 19.80273056], [85.8527832, 19.80273056], [85.85106659, 19.80165291], [85.84951019, 19.80165291], [85.84908295, 19.80111122], [85.84751129, 19.80070114], [85.8466568, 19.80124092], [85.84552002, 19.80124092], [85.8445282, 19.80056], [85.8431015, 19.80042839], [85.84139252, 19.79948044], [85.8395462, 19.7992115], [85.83798218, 19.79879951], [85.83750153, 19.79805565], [85.83444214, 19.79722023], [85.83346558, 19.79723167], [85.83190918, 19.79684448], [85.83112335, 19.79664993], [85.82900238, 19.79570007], [85.82685089, 19.79556465], [85.82492828, 19.79479408], [85.82234955, 19.7940731], [85.82006836, 19.79312515], [85.81838226, 19.79236031], [85.8169632, 19.79236031], [85.81321716, 19.79145813], [85.81027985, 19.79027557], [85.80999756, 19.79055977], [85.80916595, 19.79055977], [85.8088913, 19.79027939], [85.80832672, 19.79027939], [85.80722046, 19.78917122], [85.8069458, 19.78917122], [85.80665588, 19.78889084], [85.80528259, 19.78889084], [85.80375671, 19.78812027], [85.80119324, 19.78730965], [85.79934692, 19.78689957], [85.7977829, 19.7863903], [85.79750061, 19.78610992], [85.79524231, 19.78536606], [85.79296112, 19.78428078], [85.79138947, 19.7836113], [85.78900909, 19.78355408], [85.78843689, 19.78288078], [85.78701019, 19.7824707], [85.78527832, 19.78277969], [85.7841568, 19.78277969], [85.78388977, 19.78250122], [85.78333282, 19.78250122], [85.7831955, 19.78236008], [85.78305817, 19.78222275], [85.78250122, 19.78222275], [85.78221893, 19.78194427], [85.78193665, 19.78194237], [85.78138733, 19.78250122], [85.78138733, 19.78277779], [85.78083038, 19.78333282], [85.78083038, 19.7836113], [85.78055573, 19.78388977], [85.78083038, 19.78444481], [85.78083038, 19.78472137], [85.78055573, 19.78499985], [85.77993011, 19.78504181], [85.77983856, 19.78499794], [85.77964783, 19.78490639], [85.77964783, 19.78403282], [85.77971649, 19.78360939], [85.77972412, 19.78333282], [85.77999878, 19.78305626], [85.77999878, 19.78055954], [85.77971649, 19.78027916], [85.77971649, 19.7797184], [85.77944183, 19.77944374], [85.77916718, 19.77944374], [85.77889252, 19.77916718], [85.77861786, 19.77916908], [85.7783432, 19.77889061], [85.77805328, 19.77889061], [85.77722168, 19.77806091], [85.77694702, 19.77806091], [85.77639008, 19.77750015], [85.77555847, 19.77750015], [85.77527618, 19.77721977], [85.77500153, 19.77722168], [85.77471924, 19.77694511], [85.77444458, 19.77722168], [85.77388763, 19.77722168], [85.77333069, 19.77666855], [85.77305603, 19.77667046], [85.77249146, 19.7761097], [85.77222443, 19.7761116], [85.77194214, 19.77589989], [85.77027893, 19.77583313], [85.76999664, 19.77555466], [85.76972198, 19.77556038], [85.76944733, 19.77528], [85.76917267, 19.77528], [85.76889038, 19.77499962], [85.76721954, 19.77499962], [85.76693726, 19.77472115], [85.76667023, 19.77472305], [85.76638794, 19.77444649], [85.76611328, 19.77472305], [85.76438141, 19.77413177], [85.76281738, 19.77359009], [85.76027679, 19.77277946], [85.76000214, 19.77248955], [85.75971985, 19.77249908], [85.75944519, 19.77222252], [85.75861359, 19.77222252], [85.7583313, 19.77194214], [85.75805664, 19.77194214], [85.75777435, 19.77166748], [85.75749207, 19.77166939], [85.75694275, 19.77111053], [85.75554657, 19.77111053], [85.75527954, 19.77083015], [85.75499725, 19.7705555], [85.75444794, 19.77056122], [85.75258636, 19.76982117], [85.75131226, 19.76928139], [85.74833679, 19.76861191], [85.7480545, 19.76833344], [85.74749756, 19.76833344], [85.74739075, 19.76822662], [85.7472229, 19.76805496], [85.74666595, 19.76806259], [85.7463913, 19.7677803], [85.74610901, 19.7677803], [85.74582672, 19.76750183], [85.74555206, 19.76750183], [85.7452774, 19.76722145], [85.74472046, 19.76722145], [85.7444458, 19.76694489], [85.74305725, 19.76694489], [85.74250031, 19.76638985], [85.7416687, 19.76638985], [85.7408371, 19.76555824], [85.74054718, 19.76555824], [85.74028015, 19.76527977], [85.73860931, 19.76527977], [85.7360611, 19.76436806], [85.73420715, 19.76355934], [85.73264313, 19.76275063], [85.73065186, 19.7620697], [85.72805786, 19.76166534], [85.7277832, 19.76139069], [85.72750854, 19.76139069], [85.72721863, 19.76111031], [85.72638702, 19.76111031], [85.72583008, 19.76054955], [85.72555542, 19.76055336], [85.72528076, 19.7602787], [85.72444153, 19.76028061], [85.72055817, 19.75889015], [85.71611023, 19.75749016], [85.71555328, 19.75749969], [85.71527863, 19.75722122], [85.71499634, 19.75722122], [85.71472168, 19.75694466], [85.71444702, 19.75694466], [85.71416473, 19.75666618], [85.71389008, 19.75667191], [85.71305847, 19.75583267], [85.71069336, 19.75563812], [85.70897675, 19.75510025], [85.70767975, 19.75472069], [85.70639801, 19.75445175], [85.70582581, 19.75445175], [85.70555878, 19.75416946], [85.70527649, 19.75416946], [85.70500183, 19.75388908], [85.70443726, 19.75388908], [85.70313263, 19.75331116], [85.70198822, 19.75275993], [85.70027924, 19.75222206], [85.69999695, 19.75194359], [85.69972229, 19.75194359], [85.69889069, 19.75111198], [85.6986084, 19.75111198], [85.69851685, 19.75101852], [85.69833374, 19.75083351], [85.69721985, 19.75083351], [85.69704437, 19.75065422], [85.69694519, 19.75055695], [85.69610596, 19.75056076], [85.6958313, 19.75028038], [85.69526672, 19.75028038], [85.69499969, 19.75], [85.69444275, 19.75], [85.6938858, 19.74945068], [85.69304657, 19.74945068], [85.69277954, 19.7491703], [85.69249725, 19.7491703], [85.6922226, 19.74888992], [85.69194794, 19.74888992], [85.69167328, 19.74860954], [85.6911087, 19.74861145], [85.69083405, 19.74833298], [85.6902771, 19.74833298], [85.68999481, 19.74811172], [85.68945313, 19.74806023], [85.68926239, 19.74787521], [85.68916321, 19.74777794], [85.68860626, 19.74777985], [85.6883316, 19.74749947], [85.6875, 19.74749947], [85.68723297, 19.74722099], [85.68694305, 19.74722481], [85.6866684, 19.74694443], [85.68611145, 19.74694443], [85.68583679, 19.74666405], [85.68499756, 19.74666977], [85.6847229, 19.74638939], [85.68444824, 19.74638939], [85.68248749, 19.74596977], [85.68049622, 19.74570084], [85.67888641, 19.74472046], [85.6783371, 19.74416733], [85.67804718, 19.74417114], [85.67778015, 19.74389076], [85.67694092, 19.74389076], [85.67582703, 19.74278069], [85.67527771, 19.74278069], [85.67500305, 19.74250984], [85.67388916, 19.74250984], [85.67360687, 19.74222183], [85.67277527, 19.74222183], [85.67250061, 19.74194527], [85.67193604, 19.7419529], [85.67166901, 19.74167252], [85.67138672, 19.74167252], [85.67111206, 19.74139023], [85.67082977, 19.74139023], [85.67056274, 19.74111176], [85.67028046, 19.74111176], [85.66999817, 19.74083328], [85.66916656, 19.74083328], [85.66889191, 19.74055481], [85.66860962, 19.74055481], [85.66833496, 19.74027824], [85.66777802, 19.74028015], [85.66768646, 19.7401886], [85.66722107, 19.7397213], [85.66666412, 19.7397213], [85.66638947, 19.73944473], [85.66471863, 19.73944855], [85.66443634, 19.73916817], [85.66361237, 19.73916817], [85.66305542, 19.73860741], [85.66278076, 19.73833275], [85.66278076, 19.73805618], [85.66249847, 19.73777962], [85.66249847, 19.73666954], [85.66221619, 19.73637962], [85.66222382, 19.73555756], [85.66249847, 19.73528099], [85.66221619, 19.73500061], [85.66221619, 19.73472023], [85.66194153, 19.73444366], [85.66194153, 19.73388863], [85.66166687, 19.73361015], [85.66166687, 19.73333359], [85.66027832, 19.73194313], [85.65999603, 19.73195076], [85.65972137, 19.73167038], [85.65944672, 19.73195076], [85.65888977, 19.73195076], [85.65805817, 19.73110962], [85.65750122, 19.73110962], [85.65666962, 19.73195076], [85.65555573, 19.73194313], [85.65528107, 19.7322216], [85.65472412, 19.7322216], [85.65444183, 19.73195076], [85.65361023, 19.73195076], [85.6533432, 19.73167038], [85.65277863, 19.73167038], [85.65194702, 19.73083115], [85.65166473, 19.73083115], [85.65110779, 19.73027802], [85.65083313, 19.73027992], [85.65055847, 19.73000145], [85.65000153, 19.7294445], [85.64971924, 19.7294445], [85.64944458, 19.72972107], [85.64888763, 19.72972107], [85.64861298, 19.7294445], [85.64749908, 19.7294445], [85.64722443, 19.72916603], [85.64694214, 19.72916985], [85.64666748, 19.72888947], [85.64638519, 19.72888947], [85.64611053, 19.7286129], [85.64554596, 19.7286129], [85.64527893, 19.7283287], [85.64472198, 19.72833252], [85.64444733, 19.72805595], [85.64417267, 19.72806168], [85.64398193, 19.72787094], [85.64389038, 19.72777748], [85.64360809, 19.72777939], [85.64332581, 19.72751045], [85.64305878, 19.72751045], [85.64266205, 19.72710228], [85.64250183, 19.72694397], [85.64221954, 19.72694397], [85.64111328, 19.72583389], [85.64055634, 19.72583389], [85.64027405, 19.72555542], [85.6397171, 19.72555923], [85.63944244, 19.72528076], [85.63916779, 19.72528076], [85.63833618, 19.72500038], [85.63777924, 19.72500038], [85.63722229, 19.72443962], [85.63694763, 19.72444534], [85.63666534, 19.72416878], [85.63639069, 19.72417068], [85.63582611, 19.72360992], [85.63527679, 19.72361183], [85.63500214, 19.72333336], [85.63444519, 19.72333336], [85.6341629, 19.72305679], [85.63388824, 19.72333336], [85.63305664, 19.72249985], [85.63166809, 19.72249985], [85.6313858, 19.72221947], [85.63083649, 19.72222137], [85.62944794, 19.72083282], [85.62916565, 19.72083282], [85.62897491, 19.72063637], [85.62889099, 19.72055435], [85.6277771, 19.72056007], [85.62750244, 19.72027969], [85.62722015, 19.72027969], [85.62695313, 19.72000122], [85.62666321, 19.72000122], [85.62638855, 19.71972084], [85.62611389, 19.71972275], [85.6258316, 19.71944427], [85.62555695, 19.71944427], [85.62527466, 19.7191658], [85.62499237, 19.71916962], [85.62481689, 19.7189846], [85.62473297, 19.71889114], [85.62444305, 19.71889114], [85.6241684, 19.71861076], [85.62388611, 19.71861076], [85.62277985, 19.71750069], [85.62249756, 19.71750069], [85.6222229, 19.71722031], [85.61937714, 19.71676636], [85.6186676, 19.71635818], [85.61781311, 19.71581841], [85.61638641, 19.71528053], [85.61532593, 19.7148304], [85.61434174, 19.71442032], [85.61333466, 19.7136116], [85.61305237, 19.71333313], [85.61250305, 19.71333313], [85.61222076, 19.71305466], [85.61194611, 19.71305466], [85.6111145, 19.71222305], [85.60892487, 19.71161652], [85.60769653, 19.71083832], [85.60749817, 19.71055984], [85.60721588, 19.71027946], [85.60666656, 19.71027946], [85.60639191, 19.71000099], [85.60610962, 19.71000099], [85.60582733, 19.70972061], [85.60500336, 19.70972252], [85.60472107, 19.70944595], [85.60444641, 19.70944595], [85.60388947, 19.7088871], [85.60360718, 19.70889091], [85.60321808, 19.70849419], [85.60305786, 19.70833588], [85.60277557, 19.70833588], [85.60227203, 19.70783043], [85.60194397, 19.70750046], [85.60111237, 19.70750046], [85.60082245, 19.70722008], [85.60055542, 19.70722198], [85.60015869, 19.70682716], [85.59999847, 19.70666695], [85.59944153, 19.70667076], [85.59916687, 19.70639992], [85.59889221, 19.70639992], [85.59864807, 19.70615005], [85.59805298, 19.70611191], [85.59727478, 19.70558739], [85.59649658, 19.70506859], [85.59616089, 19.70471954], [85.59604645, 19.7044239], [85.59541321, 19.70441628], [85.5949173, 19.70428085], [85.59401703, 19.70407867], [85.59361267, 19.70360947], [85.59333038, 19.70361137], [85.59305573, 19.7033329], [85.59278107, 19.70334053], [85.59249878, 19.70306015], [85.59194946, 19.70306015], [85.59175873, 19.70286942], [85.59166718, 19.70277786], [85.59139252, 19.70277977], [85.5908432, 19.70222282], [85.59055328, 19.70222282], [85.59027863, 19.70194435], [85.58999634, 19.70194435], [85.58916473, 19.70111084], [85.58888245, 19.70111084], [85.58869934, 19.70092583], [85.58860779, 19.70083427], [85.58833313, 19.70083427], [85.5881958, 19.70069504], [85.58805847, 19.7005558], [85.58721924, 19.70055962], [85.58693695, 19.7002697], [85.58666992, 19.70027733], [85.58638763, 19.70000076], [85.58611298, 19.70000076], [85.58582306, 19.69971848], [85.58555603, 19.69972229], [85.58528137, 19.69944382], [85.58499908, 19.69944382], [85.58472443, 19.69916725], [85.58444214, 19.69916916], [85.58389282, 19.69861031], [85.58361053, 19.69861031], [85.58333588, 19.69832993], [85.58305359, 19.69833374], [85.58277893, 19.69805527], [85.58249664, 19.69805908], [85.58194733, 19.69750023], [85.58166504, 19.69750023], [85.58118439, 19.69728279], [85.58062744, 19.69742012], [85.57943726, 19.6972599], [85.57830048, 19.69671059], [85.57688141, 19.69617271], [85.57545471, 19.69536018], [85.57460022, 19.69536018], [85.57250214, 19.69444084], [85.57221985, 19.69416428], [85.57195282, 19.69417], [85.5716629, 19.69388962], [85.57138824, 19.69388962], [85.57110596, 19.69361115], [85.57081604, 19.69361115], [85.56999969, 19.69277954], [85.56916809, 19.69277954], [85.5688858, 19.69250107], [85.56861115, 19.69250107], [85.56833649, 19.69222069], [85.56804657, 19.69250107], [85.56667328, 19.69111061], [85.56639099, 19.69111061], [85.56582642, 19.69055939], [85.5652771, 19.69000053], [85.56500244, 19.69000053], [85.56472015, 19.68972015], [85.5644455, 19.68972015], [85.56416321, 19.68944359], [85.56388855, 19.68944359], [85.56361389, 19.68916702], [85.5633316, 19.68917274], [85.56305695, 19.68889046], [85.56276703, 19.68889046], [85.56252289, 19.68863487], [85.56223297, 19.6883316], [85.5616684, 19.68833351], [85.56111145, 19.68777847], [85.56054688, 19.68778038], [85.56027985, 19.68750191], [85.5597229, 19.68750191], [85.55944824, 19.68722153], [85.5588913, 19.68722153], [85.55833435, 19.68666649], [85.55805206, 19.6866684], [85.55750275, 19.68610764], [85.5569458, 19.68611145], [85.55666351, 19.68583298], [85.55638885, 19.68583298], [85.55583191, 19.68527985], [85.55555725, 19.68527985], [85.55527496, 19.68499947], [85.55500031, 19.68499947], [85.55473328, 19.68472099], [85.55388641, 19.6847229], [85.55361176, 19.68444443], [85.5533371, 19.68444443], [85.55278015, 19.68388939], [85.55249786, 19.68388939], [85.55222321, 19.68361092], [85.55194092, 19.68361092], [85.54971313, 19.68250084], [85.54944611, 19.68250084], [85.54888916, 19.68194008], [85.5486145, 19.6819458], [85.54833221, 19.68166542], [85.54805756, 19.68167114], [85.5477829, 19.68139076], [85.54722595, 19.68139076], [85.54693604, 19.68111038], [85.54252625, 19.67981911], [85.53954315, 19.67819023], [85.53639221, 19.67638969], [85.53362274, 19.67556953], [85.53092194, 19.6746254], [85.52892303, 19.67272949], [85.52536774, 19.6715107], [85.52279663, 19.66988945], [85.51893616, 19.66802979], [85.51638031, 19.66723061], [85.51352692, 19.66546059], [85.51139832, 19.66423988], [85.50926208, 19.66316032], [85.50694275, 19.66167259], [85.5027771, 19.65916824], [85.50138855, 19.65888977], [85.50110626, 19.65888977], [85.50026703, 19.65805817], [85.49944305, 19.65805817], [85.4991684, 19.65777969], [85.49888611, 19.65777969], [85.49859619, 19.65750122], [85.49833679, 19.65750122], [85.49804688, 19.65722084], [85.49777985, 19.65722275], [85.49749756, 19.65694427], [85.4972229, 19.65694427], [85.49694824, 19.65666771], [85.4963913, 19.65666962], [85.49610901, 19.65639114], [85.49582672, 19.65639114], [85.49555969, 19.65611076], [85.4952774, 19.65611076], [85.49472046, 19.65555954], [85.4944458, 19.65555954], [85.49388885, 19.65500069], [85.49360657, 19.65500069], [85.49276733, 19.65417099], [85.49250031, 19.65417099], [85.49239349, 19.65405846], [85.49222565, 19.6538887], [85.4916687, 19.65389061], [85.49138641, 19.65361023], [85.49111176, 19.65361023], [85.49054718, 19.65306091], [85.49028015, 19.65306091], [85.48999786, 19.65278053], [85.48916626, 19.65278053], [85.4888916, 19.65250015], [85.48860931, 19.65250015], [85.48832703, 19.65223122], [85.48805237, 19.65223122], [85.48777771, 19.65195084], [85.48694611, 19.65195084], [85.48665619, 19.65167046], [85.48555756, 19.65167046], [85.4852829, 19.65139008], [85.48500061, 19.65139008], [85.48486328, 19.65124893], [85.48472595, 19.6511116], [85.48416901, 19.6511116], [85.48388672, 19.65083122], [85.48332977, 19.65083122], [85.48305511, 19.65055466], [85.48278046, 19.65055466], [85.48249817, 19.65027809], [85.48221588, 19.65028], [85.48194122, 19.64999962], [85.48166656, 19.64999962], [85.48139191, 19.64972115], [85.48110962, 19.64972115], [85.48055267, 19.64916611], [85.48027802, 19.64916611], [85.48000336, 19.64888954], [85.47972107, 19.64888954], [85.47944641, 19.64861107], [85.47888947, 19.64861107], [85.47860718, 19.6483326], [85.47833252, 19.6483326], [85.47805786, 19.64805603], [85.4777832, 19.64806175], [85.47744751, 19.64772224], [85.47693634, 19.64722061], [85.47638702, 19.64722252], [85.47611237, 19.64694405], [85.47499847, 19.64694405], [85.47444153, 19.64639091], [85.47389221, 19.64639091], [85.47360992, 19.646101], [85.47333527, 19.64611053], [85.47305298, 19.64583397], [85.47277832, 19.64583397], [85.47250366, 19.6455555], [85.47222137, 19.64555931], [85.47194672, 19.64528084], [85.47138977, 19.64528084], [85.47101593, 19.64490509], [85.47083282, 19.64471817], [85.47027588, 19.64472198], [85.46971893, 19.64416885], [85.46943665, 19.64417076], [85.46888733, 19.64360809], [85.46749878, 19.64361191], [85.46722412, 19.64333344], [85.46694183, 19.64333344], [85.46683502, 19.64322472], [85.46666718, 19.64305687], [85.46639252, 19.64306068], [85.46615601, 19.64282036], [85.4658432, 19.64249992], [85.46555328, 19.64249992], [85.46527863, 19.64222145], [85.46472168, 19.64222145], [85.46444702, 19.64194679], [85.46416473, 19.64194679], [85.46389008, 19.64166451], [85.46360779, 19.64167023], [85.46333313, 19.64138985], [85.46277618, 19.64138985], [85.46248627, 19.64110947], [85.46221924, 19.64111137], [85.46166992, 19.64055443], [85.46111298, 19.64056015], [85.46083069, 19.64029121], [85.4597168, 19.64029121], [85.45942688, 19.63999939], [85.45888519, 19.63999939], [85.45833588, 19.63944435], [85.45805359, 19.63944435], [85.45749664, 19.63888931], [85.45722198, 19.63889122], [85.45694733, 19.63861084], [85.4566803, 19.63889122], [85.45582581, 19.63889122], [85.45500183, 19.63805962], [85.45471954, 19.63805962], [85.45443726, 19.63778114], [85.45417023, 19.63778114], [85.45388794, 19.63750076], [85.45361328, 19.63750076], [85.45333099, 19.63722038], [85.45305634, 19.63722229], [85.45277405, 19.63694382], [85.45249939, 19.63694382], [85.45222473, 19.63666725], [85.45111084, 19.63667107], [85.45083618, 19.63639069], [85.44972229, 19.63639069], [85.44944763, 19.63611031], [85.44796753, 19.63562012], [85.4478302, 19.63563156], [85.44647217, 19.63495636], [85.44576263, 19.63475227], [85.44497681, 19.63455009], [85.4438858, 19.63389015], [85.44361115, 19.63416672], [85.44333649, 19.63416672], [85.44166565, 19.63249969], [85.44139099, 19.63249969], [85.4411087, 19.63222122], [85.44055176, 19.63222313], [85.4402771, 19.63194466], [85.43916321, 19.63194466], [85.43888855, 19.63166618], [85.43860626, 19.63166809], [85.43805695, 19.63112068], [85.43776703, 19.63112068], [85.4375, 19.63083076], [85.43722534, 19.63083267], [85.43275452, 19.62917519], [85.4310379, 19.62823105], [85.42904663, 19.62742043], [85.42549896, 19.62552071], [85.42378998, 19.62457275], [85.42222595, 19.62416649], [85.41919708, 19.62306976], [85.41777802, 19.62198639], [85.41635132, 19.62117958], [85.41471863, 19.62027931], [85.41443634, 19.62027931], [85.41416931, 19.62000084], [85.41388702, 19.62000084], [85.41361237, 19.61972046], [85.41305542, 19.61972237], [85.41047668, 19.6183548], [85.40919495, 19.61767769], [85.40721893, 19.61667061], [85.40486908, 19.61561012], [85.40344238, 19.61466789], [85.40159607, 19.61384964], [85.40045166, 19.61317635], [85.39888763, 19.61250114], [85.39787292, 19.61166191], [85.39743805, 19.61125565], [85.39573669, 19.61071014], [85.39431, 19.61017227], [85.39260101, 19.60909081], [85.39103699, 19.60855293], [85.38976288, 19.60801125], [85.3887558, 19.60705948], [85.38719177, 19.60638046], [85.38555908, 19.60611153], [85.38471985, 19.60527992], [85.38446045, 19.60527992], [85.38431549, 19.60514832], [85.3841629, 19.60499954], [85.38414764, 19.60472107], [85.38249969, 19.60305786], [85.38140106, 19.60305977], [85.38083649, 19.60250092], [85.38054657, 19.60250092], [85.37999725, 19.60194016], [85.37944794, 19.60194588], [85.37916565, 19.6016674], [85.3786087, 19.60167122], [85.3777771, 19.60083008], [85.37750244, 19.6008358], [85.37722015, 19.60055351], [85.37666321, 19.60056114], [85.37638855, 19.60028076], [85.37610626, 19.60028076], [85.37563324, 19.59980011], [85.37555695, 19.59972191], [85.375, 19.59972191], [85.37472534, 19.59944344], [85.3741684, 19.59945107], [85.37388611, 19.59917068], [85.37361145, 19.59917068], [85.3730545, 19.59860992], [85.37249756, 19.59805107], [85.37194824, 19.59805489], [85.37166595, 19.59777832], [85.37110901, 19.59778023], [85.37082672, 19.59749985], [85.3702774, 19.59749985], [85.36794281, 19.59664917], [85.36672211, 19.59576988], [85.36553192, 19.59543037], [85.3640976, 19.59461975], [85.36267853, 19.59338951], [85.36011505, 19.59231949], [85.35868835, 19.59123611], [85.35639191, 19.59000015], [85.35582733, 19.58945084], [85.35555267, 19.58945084], [85.35527802, 19.58917046], [85.35500336, 19.58917046], [85.3549118, 19.589077], [85.35472107, 19.58888626], [85.35444641, 19.58888626], [85.35416412, 19.5886116], [85.35388947, 19.5886116], [85.35333252, 19.58805656], [85.35305786, 19.58805656], [85.35277557, 19.58777618], [85.35250092, 19.58778], [85.35193634, 19.58722115], [85.35166931, 19.58722305], [85.35138702, 19.58694649], [85.35111237, 19.58694649], [85.35083008, 19.5866642], [85.35056305, 19.58666992], [85.35028076, 19.58638954], [85.34999847, 19.58638954], [85.34971619, 19.58666992], [85.34944153, 19.58666992], [85.34889221, 19.58611107], [85.34860992, 19.58611107], [85.34749603, 19.58500099], [85.34749603, 19.58472061], [85.34722137, 19.58472252], [85.34694672, 19.58444214], [85.34666443, 19.58444214], [85.34555817, 19.58333206], [85.34527588, 19.58333206], [85.34471893, 19.58277702], [85.3422699, 19.58205032], [85.34085083, 19.58135986], [85.33860779, 19.5802803], [85.33805847, 19.57971764], [85.33750153, 19.57972145], [85.33666992, 19.57888985], [85.33638763, 19.57888985], [85.33583069, 19.57832909], [85.33555603, 19.5783329], [85.33528137, 19.57805824], [85.33499908, 19.57777977], [85.3347168, 19.57777977], [85.33444214, 19.57749939], [85.33222198, 19.57528114], [85.33167267, 19.57528114], [85.33139038, 19.57500076], [85.33110809, 19.57500076], [85.33082581, 19.57472038], [85.33027649, 19.57472229], [85.33000183, 19.57444572], [85.32971954, 19.57444572], [85.32888794, 19.57361031], [85.32861328, 19.57361031], [85.32749939, 19.57250023], [85.3272171, 19.57250023], [85.32666779, 19.57195091], [85.32639313, 19.57195091], [85.32554626, 19.57110977], [85.32499695, 19.57111168], [85.32472229, 19.5708313], [85.32416534, 19.5708313], [85.3236084, 19.57027817], [85.32277679, 19.57028008], [85.32249451, 19.56999969], [85.32221985, 19.56972122], [85.32221985, 19.56944466], [85.3208313, 19.56805611], [85.32055664, 19.56806946], [85.32026672, 19.56777954], [85.31999969, 19.56777954], [85.31944275, 19.56722069], [85.3188858, 19.5672226], [85.31861115, 19.56694412], [85.31773376, 19.56694221], [85.31658936, 19.56653595], [85.31555176, 19.56528091], [85.31555176, 19.56500053], [85.3152771, 19.56471825], [85.3152771, 19.56444359], [85.31500244, 19.56416893], [85.31388855, 19.56417084], [85.3133316, 19.56361008], [85.31305695, 19.56361198], [85.31277466, 19.56333351], [85.3125, 19.56333351], [85.31194305, 19.56277847], [85.3116684, 19.56278038], [85.31138611, 19.5625], [85.30944824, 19.5625], [85.3088913, 19.56194115], [85.30860901, 19.56194687], [85.3077774, 19.56111145], [85.3077774, 19.56083488], [85.30716705, 19.56039047], [85.30666351, 19.55944633], [85.3061142, 19.55944633], [85.30583191, 19.55916405], [85.30526733, 19.55916977], [85.30446625, 19.55900955], [85.30361176, 19.55833054], [85.30194092, 19.55666733], [85.3013916, 19.55667114], [85.30110931, 19.55639076], [85.30082703, 19.55639076], [85.30055237, 19.55611038], [85.30027771, 19.55611038], [85.29998779, 19.55583954], [85.29943848, 19.55583954], [85.29753113, 19.55472183], [85.29528809, 19.55361176], [85.29244232, 19.55159569], [85.29045105, 19.55051041], [85.28902435, 19.54970169], [85.28778076, 19.54888916], [85.28721619, 19.54833031], [85.28694153, 19.54833412], [85.28666687, 19.54805756], [85.28639221, 19.54805946], [85.28639221, 19.54778099], [85.28527832, 19.54667091], [85.28501129, 19.54667091], [85.28444672, 19.54611015], [85.28416443, 19.54611206], [85.28360748, 19.54555321], [85.28333282, 19.54556084], [85.28305817, 19.54528046], [85.28277588, 19.54528046], [85.28166962, 19.54417038], [85.28111267, 19.54417038], [85.28095245, 19.54400826], [85.28055573, 19.54361153], [85.28028107, 19.54361153], [85.27916718, 19.54249954], [85.27887726, 19.54249954], [85.27861023, 19.54222107], [85.27805328, 19.54222107], [85.27666473, 19.54083252], [85.27639008, 19.54084015], [85.27610779, 19.54056168], [85.27456665, 19.53973961], [85.27222443, 19.53777885], [85.27194214, 19.53777885], [85.27141571, 19.53725052], [85.27055359, 19.5363884], [85.27027893, 19.5363903], [85.26917267, 19.53528023], [85.26917267, 19.53499985], [85.26889038, 19.53499985], [85.26860809, 19.53470993], [85.26833344, 19.53472137], [85.26694489, 19.53333282], [85.26667023, 19.53333282], [85.26499939, 19.5316658], [85.26444244, 19.53166962], [85.26416779, 19.53139114], [85.26333618, 19.53139114], [85.26304626, 19.53111076], [85.26277924, 19.53111076], [85.2611084, 19.52944183], [85.26083374, 19.52944374], [85.25777435, 19.52638817], [85.25694275, 19.52638817], [85.2568512, 19.52629662], [85.25666809, 19.5261116], [85.2563858, 19.5261116], [85.25611115, 19.52583313], [85.25583649, 19.52583313], [85.2555542, 19.52555275], [85.25527954, 19.52527809], [85.25499725, 19.52527809], [85.25332642, 19.52361107], [85.25305176, 19.52361107], [85.25222015, 19.52276993], [85.25166321, 19.52277756], [85.25138855, 19.52249718], [85.25110626, 19.52250099], [85.25087738, 19.5222683], [85.25055695, 19.52222252], [85.25, 19.52166748], [85.24973297, 19.52166939], [85.24822998, 19.5201683], [85.2472229, 19.51917076], [85.24694824, 19.51917076], [85.2465744, 19.51879692], [85.2463913, 19.51861382], [85.24610901, 19.51861382], [85.24583435, 19.51833344], [85.24555206, 19.51833344], [85.24500275, 19.5177784], [85.24472046, 19.5177803], [85.24360657, 19.51667023], [85.24333191, 19.51667023], [85.24305725, 19.51638985], [85.24278259, 19.51638985], [85.24111176, 19.51472282], [85.23999786, 19.51472282], [85.23972321, 19.51444435], [85.23944092, 19.51444435], [85.23916626, 19.51416588], [85.2388916, 19.5141716], [85.23860931, 19.51388931], [85.23832703, 19.51388931], [85.23777771, 19.51333046], [85.23777771, 19.5130558], [85.23722076, 19.51250076], [85.23694611, 19.51250076], [85.23638916, 19.51194382], [85.2361145, 19.51194382], [85.23555756, 19.51138878], [85.2352829, 19.51139069], [85.23472595, 19.51082993], [85.23444366, 19.51083374], [85.23352051, 19.50991058], [85.23305511, 19.50944519], [85.23278046, 19.50945091], [85.23194122, 19.50860977], [85.23166656, 19.50861168], [85.23139191, 19.50833321], [85.23110962, 19.50833321], [85.23027802, 19.50749969], [85.23000336, 19.50749969], [85.22972107, 19.50722122], [85.22944641, 19.50722313], [85.22916412, 19.50694656], [85.22888947, 19.50694656], [85.22833252, 19.50638962], [85.22776794, 19.50638962], [85.22732544, 19.50594139], [85.22721863, 19.50583267], [85.22694397, 19.50583267], [85.22583008, 19.5047226], [85.22556305, 19.50473022], [85.22470856, 19.5038929], [85.22470856, 19.50361061], [85.22444153, 19.50333023], [85.22416687, 19.50333214], [85.22333527, 19.50250053], [85.22277832, 19.50250053], [85.22222137, 19.50194168], [85.22194672, 19.50194359], [85.22083282, 19.50083351], [85.22083282, 19.50055504], [85.22055817, 19.50028038], [85.22027588, 19.50028038], [85.22000122, 19.50000191], [85.21971893, 19.50000191], [85.21943665, 19.49971962], [85.21916962, 19.49972153], [85.21888733, 19.49944496], [85.21861267, 19.49945068], [85.21806335, 19.49888992], [85.21778107, 19.49888992], [85.21611023, 19.49722099], [85.21583557, 19.4972229], [85.21527863, 19.49666786], [85.21499634, 19.49666977], [85.2141571, 19.49583054], [85.21389008, 19.49583244], [85.21360779, 19.49555779], [85.21333313, 19.49555969], [85.21276855, 19.49500084], [85.21250153, 19.49500084], [85.21193695, 19.49444008], [85.21166992, 19.4944458], [85.21153259, 19.49430656], [85.21138763, 19.49416733], [85.21111298, 19.49417114], [85.21055603, 19.49361038], [85.21028137, 19.49361038], [85.20833588, 19.49167061], [85.20804596, 19.49167061], [85.20777893, 19.49139023], [85.20749664, 19.49139023], [85.20667267, 19.4905529], [85.20639038, 19.49055481], [85.20527649, 19.48999977], [85.20359802, 19.48833275], [85.20333099, 19.48833275], [85.20277405, 19.48777771], [85.20249939, 19.48777962], [85.2022171, 19.48749924], [85.20194244, 19.48749924], [85.20139313, 19.48693848], [85.20111084, 19.4869442], [85.20083618, 19.48666573], [85.20055389, 19.48666573], [85.20027924, 19.48638916], [85.19999695, 19.48638916], [85.19832611, 19.48472023], [85.19805908, 19.48472214], [85.19777679, 19.48444366], [85.19721985, 19.48444366], [85.19611359, 19.48333359], [85.1958313, 19.48333359], [85.19472504, 19.4822216], [85.19416809, 19.4822216], [85.1938858, 19.48194695], [85.19361115, 19.48195076], [85.19277954, 19.48110962], [85.19249725, 19.48111153], [85.1911087, 19.47972488], [85.19083405, 19.47972488], [85.18972015, 19.47861099], [85.1894455, 19.47861099], [85.18916321, 19.47833252], [85.18888855, 19.47833252], [85.18861389, 19.47805405], [85.1883316, 19.47805977], [85.18776703, 19.47750092], [85.1875, 19.47750092], [85.18723297, 19.47722054], [85.18694305, 19.47722244], [85.18638611, 19.4766674], [85.18611145, 19.47667122], [85.18583679, 19.47638893], [85.18556213, 19.47639275], [85.18527985, 19.47611046], [85.18499756, 19.47611046], [85.18444824, 19.47556114], [85.18416595, 19.47556114], [85.18360901, 19.47500038], [85.18302155, 19.47435951], [85.18131256, 19.4735527], [85.17722321, 19.47000122], [85.17694092, 19.47000122], [85.17665863, 19.46972084], [85.1763916, 19.46972275], [85.17610931, 19.46944427], [85.17555237, 19.46944427], [85.17500305, 19.46888924], [85.17472076, 19.46889114], [85.17415619, 19.46833038], [85.17388916, 19.4683342], [85.17333221, 19.46777534], [85.17305756, 19.46778107], [85.17166901, 19.46639061], [85.17138672, 19.46639061], [85.16971588, 19.46471977], [85.16944122, 19.46472168], [85.16916656, 19.46444321], [85.16889191, 19.46445084], [85.16860962, 19.46417046], [85.16832733, 19.46417046], [85.16722107, 19.46305275], [85.16694641, 19.46305466], [85.16661072, 19.46271896], [85.16611481, 19.46222115], [85.16555786, 19.46222115], [85.16499329, 19.46171761], [85.16471863, 19.46167183], [85.16442871, 19.46138954], [85.16416931, 19.46138954], [85.16388702, 19.46110916], [85.16361237, 19.46110916], [85.16306305, 19.46056175], [85.16278076, 19.46056175], [85.16221619, 19.45999908], [85.16179657, 19.45946121], [85.15849304, 19.45721054], [85.15499878, 19.45416451], [85.15471649, 19.45417023], [85.15444183, 19.45388985], [85.15416718, 19.45388985], [85.15277863, 19.45249939], [85.15248871, 19.45249939], [85.15221405, 19.45227051], [85.15194702, 19.45222473], [85.14638519, 19.44833374], [85.14611053, 19.44805527], [85.14583588, 19.4480629], [85.14221954, 19.44527817], [85.14167023, 19.44472122], [85.14138794, 19.44472313], [85.14083099, 19.44416618], [85.14025879, 19.44416809], [85.13944244, 19.44333076], [85.13555908, 19.44000053], [85.13388824, 19.43832016], [85.13201141, 19.43688393], [85.12916565, 19.43444443], [85.12805176, 19.43333244], [85.1277771, 19.43333244], [85.12638855, 19.43194389], [85.12611389, 19.43194389], [85.1258316, 19.43166733], [85.12554932, 19.43166924], [85.12296295, 19.4300499], [85.12182617, 19.42922974], [85.12068939, 19.42814827], [85.11869812, 19.42654037], [85.11727142, 19.42543983], [85.11585236, 19.42381859], [85.11443329, 19.42246056], [85.11250305, 19.42111015], [85.11166382, 19.42027855], [85.11165619, 19.42000008], [85.11083221, 19.41916847], [85.10785675, 19.41669273], [85.10558319, 19.41480064], [85.1047287, 19.41377068], [85.10430145, 19.4132328], [85.10380554, 19.41255569], [85.10324097, 19.41188049], [85.10280609, 19.41134071], [85.10231018, 19.41073036], [85.10195923, 19.41018867], [85.10131836, 19.40950966], [85.10108948, 19.40917015], [85.1006012, 19.40842438], [85.10045624, 19.40794945], [85.09989166, 19.4075489], [85.09954071, 19.40700912], [85.09916687, 19.40638924], [85.0983429, 19.40557289], [85.0983429, 19.40527916], [85.09805298, 19.40500069], [85.09805298, 19.40472031], [85.09722137, 19.4038887], [85.09722137, 19.40361023], [85.09694672, 19.40332985], [85.09694672, 19.40305519], [85.09638977, 19.40250015], [85.09638977, 19.40195084], [85.09610748, 19.40167046], [85.09610748, 19.40139008], [85.09388733, 19.39916992], [85.09361267, 19.39916992], [85.09361267, 19.39888954], [85.09278107, 19.39805984], [85.09278107, 19.39777946], [85.09220886, 19.39722061], [85.09222412, 19.39666748], [85.09166718, 19.39611053], [85.09166718, 19.39556122], [85.09139252, 19.39528275], [85.09139252, 19.39500046], [85.09111023, 19.39472008], [85.09083557, 19.39472008], [85.09023285, 19.39265442], [85.08740997, 19.38991737], [85.08612823, 19.38775063], [85.08526611, 19.38585091], [85.0851059, 19.38446426], [85.08389282, 19.38276672], [85.08304596, 19.38195038], [85.08175659, 19.38100433], [85.08055878, 19.38027954], [85.07971954, 19.3794384], [85.07971954, 19.37916756], [85.07776642, 19.37722015], [85.07611084, 19.37888908], [85.07554626, 19.37888908], [85.07446289, 19.37778091], [85.07417297, 19.37778091], [85.07389069, 19.37750053], [85.0736084, 19.37750053], [85.07332611, 19.37722015], [85.07305908, 19.37722206], [85.07277679, 19.37694359], [85.07250214, 19.37694359], [85.0716629, 19.37611198], [85.0716629, 19.37583351], [85.0688858, 19.37305641], [85.06861115, 19.37306023], [85.06804657, 19.37249947], [85.06777954, 19.37249947], [85.06749725, 19.37220955], [85.0663681, 19.37176132], [85.066185, 19.37166214], [85.06562042, 19.36904335], [85.06506348, 19.36691666], [85.06516266, 19.36689758], [85.06594086, 19.36675453], [85.06622314, 19.36648369], [85.06622314, 19.36580658], [85.06600952, 19.36553383], [85.06536865, 19.36499214], [85.06472015, 19.36444473], [85.06415558, 19.36414528], [85.063797, 19.36380959], [85.06310272, 19.36367035], [85.0625, 19.36333275], [85.0616684, 19.36333275], [85.06157684, 19.3632412], [85.06138611, 19.36305618], [85.06083679, 19.36305809], [85.06054688, 19.36277962], [85.06027985, 19.36277962], [85.05999756, 19.36250114], [85.0597229, 19.36250114], [85.05945587, 19.36222076], [85.05916595, 19.36222267], [85.05860901, 19.36166763], [85.05832672, 19.36166954], [85.05805206, 19.36139107], [85.05750275, 19.36139107], [85.05722046, 19.36111069], [85.0569458, 19.36111069], [85.05665588, 19.36083031], [85.05638885, 19.36083412], [85.05583191, 19.36027527], [85.05555725, 19.36000061], [85.05555725, 19.35972023], [85.05527496, 19.35944557], [85.05500031, 19.35944557], [85.05472565, 19.35916519], [85.05332947, 19.35917091], [85.05303955, 19.35889053], [85.05278015, 19.35889053], [85.05249786, 19.35861015], [85.05222321, 19.35861206], [85.05166626, 19.35805321], [85.0513916, 19.35806084], [85.05082703, 19.35750008], [85.05027771, 19.35750008], [85.05000305, 19.3572216], [85.04944611, 19.35723114], [85.04915619, 19.35695076], [85.04860687, 19.35695076], [85.04833221, 19.35667038], [85.04805756, 19.35667038], [85.04768372, 19.35629654], [85.04750061, 19.35610962], [85.04722595, 19.35611153], [85.04694366, 19.35583115], [85.04666901, 19.35583115], [85.04657745, 19.3557415], [85.04638672, 19.35555649], [85.04611206, 19.3555603], [85.04582977, 19.35528183], [85.04556274, 19.35528183], [85.04499817, 19.35472107], [85.04472351, 19.35472107], [85.04389191, 19.35388947], [85.04360962, 19.35388947], [85.04305267, 19.35333061], [85.04277802, 19.35333252], [85.04222107, 19.35277748], [85.04194641, 19.35277939], [85.04109955, 19.35193825], [85.04027557, 19.35194397], [85.03971863, 19.35138893], [85.03943634, 19.35139084], [85.03929901, 19.35124397], [85.03916931, 19.35111046], [85.03888702, 19.35111046], [85.03853607, 19.35076141], [85.03833008, 19.35055542], [85.03806305, 19.35055923], [85.03796387, 19.35046577], [85.03778076, 19.35028076], [85.03749847, 19.35028076], [85.03721619, 19.35000038], [85.03639221, 19.35000038], [85.03610992, 19.34971809], [85.03555298, 19.34972191], [85.03500366, 19.34916878], [85.03444672, 19.34860992], [85.03416443, 19.34861183], [85.03360748, 19.34805679], [85.03333282, 19.34805679], [85.03305817, 19.34777832], [85.03250122, 19.34778023], [85.03222656, 19.34749985], [85.03166962, 19.34749985], [85.03138733, 19.34721947], [85.03111267, 19.34722137], [85.03055573, 19.34666443], [85.03028107, 19.34667015], [85.02915955, 19.34556007], [85.02889252, 19.34556007], [85.0283432, 19.34500122], [85.02805328, 19.34500122], [85.02777863, 19.34472084], [85.02749634, 19.34472466], [85.02722168, 19.34444237], [85.02666473, 19.34444237], [85.02639008, 19.3441658], [85.02610016, 19.34416962], [85.02583313, 19.34389114], [85.02555847, 19.34389114], [85.02443695, 19.34278107], [85.02416992, 19.34278107], [85.02388763, 19.34250069], [85.02361298, 19.34250069], [85.02305603, 19.34194183], [85.02278137, 19.34194374], [85.02264404, 19.34180641], [85.02249908, 19.34166718], [85.0222168, 19.3416729], [85.02166748, 19.34111023], [85.02138519, 19.34111023], [85.02083588, 19.34055519], [85.02054596, 19.34056282], [85.01999664, 19.34000015], [85.01944733, 19.34000015], [85.01917267, 19.33972168], [85.01889038, 19.33972168], [85.01833344, 19.33916664], [85.01805878, 19.33916664], [85.01784515, 19.33895683], [85.01776886, 19.33894157], [85.01750183, 19.33888817], [85.01692963, 19.33833122], [85.01667023, 19.33833313], [85.01638794, 19.33805275], [85.01611328, 19.33777809], [85.01583099, 19.33777809], [85.01555634, 19.33749962], [85.01526642, 19.33749962], [85.0150528, 19.33727455], [85.01499939, 19.33722115], [85.01472473, 19.33722305], [85.01416779, 19.33666611], [85.01389313, 19.33666992], [85.01361084, 19.33638954], [85.01333618, 19.33638954], [85.01167297, 19.33472061], [85.01139069, 19.33472252], [85.01129913, 19.33463287], [85.01083374, 19.33416748], [85.01055908, 19.33416939], [85.01027679, 19.33389091], [85.01000214, 19.33389091], [85.00971985, 19.33361053], [85.0091629, 19.33361053], [85.00888824, 19.33333015], [85.00861359, 19.33333588], [85.0083313, 19.33305359], [85.00805664, 19.33306122], [85.00694275, 19.3319397], [85.00666809, 19.33194351], [85.0063858, 19.33166695], [85.00583649, 19.33167076], [85.00554657, 19.33139038], [85.00527954, 19.33139038], [85.0047226, 19.33082962], [85.00444794, 19.33083534], [85.0036087, 19.32999992], [85.00332642, 19.32999992], [85.00013733, 19.32866859], [85.00013733, 19.32875061], [84.99986267, 19.32875061], [84.99986267, 19.32847023], [84.99958038, 19.32847023], [84.99958038, 19.32819366], [84.99903107, 19.32819366], [84.99903107, 19.3279171], [84.99846649, 19.32792282], [84.99846649, 19.32764053], [84.99764252, 19.32764053], [84.99764252, 19.32709122], [84.99736023, 19.32709122], [84.99736023, 19.32681274], [84.9970932, 19.32681274], [84.9970932, 19.32625008], [84.99652863, 19.32625008], [84.99652863, 19.3259697], [84.99597168, 19.3259716], [84.99597168, 19.32569504], [84.99569702, 19.32570076], [84.99569702, 19.32541847], [84.99514008, 19.32541847], [84.99514008, 19.32513809], [84.99485779, 19.32513809], [84.99485779, 19.32485962], [84.99430847, 19.32486153], [84.99430847, 19.32402992], [84.99375153, 19.32402992], [84.99375153, 19.32374954], [84.99346924, 19.32374954], [84.99346924, 19.32347107], [84.99263763, 19.32347298], [84.99263763, 19.3231945], [84.99236298, 19.3231945], [84.99236298, 19.32291794], [84.99153137, 19.32291985], [84.99153137, 19.32263947], [84.99124908, 19.32263947], [84.99124908, 19.32208061], [84.99069214, 19.32208252], [84.99069214, 19.32180786], [84.99041748, 19.32180977], [84.99041748, 19.32152939], [84.99015045, 19.32152939], [84.99015045, 19.320961], [84.98958588, 19.32097244], [84.98958588, 19.3204174], [84.98847198, 19.32042122], [84.98847198, 19.32014084], [84.98735809, 19.32014084], [84.98735809, 19.31986046], [84.98680878, 19.31986046], [84.98680878, 19.31958008], [84.98625183, 19.3195858], [84.98625183, 19.31930351], [84.98568726, 19.31931114], [84.98568726, 19.31903076], [84.98513794, 19.31903076], [84.98513794, 19.31847], [84.98486328, 19.31847382], [84.98486328, 19.31819344], [84.98430634, 19.31819344], [84.98430634, 19.3176384], [84.98401642, 19.3176403], [84.98401642, 19.31735992], [84.98374939, 19.31736374], [84.98374939, 19.31708145], [84.98347473, 19.31708145], [84.98347473, 19.31680489], [84.98291779, 19.31680489], [84.98291779, 19.31652832], [84.98236084, 19.31653023], [84.98236084, 19.31624985], [84.98152924, 19.31624985], [84.98152924, 19.31596947], [84.98097229, 19.31597137], [84.98097229, 19.31569481], [84.98041534, 19.31569481], [84.98041534, 19.31541634], [84.98014069, 19.31542015], [84.98014069, 19.31458282], [84.97958374, 19.31458282], [84.97958374, 19.31402779], [84.97875214, 19.31402969], [84.97875214, 19.31347084], [84.97819519, 19.31347275], [84.97819519, 19.31319427], [84.97763824, 19.31319427], [84.97763824, 19.3129158], [84.97735596, 19.31292152], [84.97735596, 19.31263924], [84.97680664, 19.31263924], [84.97680664, 19.31209183], [84.97598267, 19.31209183], [84.97598267, 19.31181145], [84.97569275, 19.31181145], [84.97569275, 19.31152916], [84.9751358, 19.31152916], [84.9751358, 19.31097031], [84.97486115, 19.31097221], [84.97486115, 19.31041718], [84.97458649, 19.31041908], [84.97458649, 19.31014061], [84.97429657, 19.31014061], [84.97429657, 19.30986023], [84.97402954, 19.30986023], [84.97402954, 19.30957985], [84.97319794, 19.30958366], [84.97319794, 19.30930519], [84.97292328, 19.30931091], [84.97292328, 19.309021], [84.97264099, 19.30902863], [84.97264099, 19.30875015], [84.97207642, 19.30875015], [84.97207642, 19.30846977], [84.9715271, 19.30847168], [84.9715271, 19.30819511], [84.97125244, 19.30820084], [84.97125244, 19.30792046], [84.97041321, 19.30792046], [84.97041321, 19.30764008], [84.97013855, 19.30764008], [84.97013855, 19.3073597], [84.96986389, 19.3073616], [84.96986389, 19.30708313], [84.9695816, 19.30708313], [84.9695816, 19.30652809], [84.96930695, 19.30653], [84.96930695, 19.30624962], [84.96875, 19.30624962], [84.96875, 19.3059597], [84.96847534, 19.30597305], [84.96847534, 19.30569649], [84.9679184, 19.30569649], [84.9679184, 19.3054142], [84.96763611, 19.30541992], [84.96763611, 19.30486107], [84.96736145, 19.30486107], [84.96736145, 19.30430984], [84.96708679, 19.30430984], [84.96708679, 19.30402946], [84.96679688, 19.30402946], [84.96679688, 19.3037529], [84.96652985, 19.3037529], [84.96652985, 19.30347061], [84.9668045, 19.30347443], [84.9668045, 19.30291748], [84.96708679, 19.30291939], [84.96708679, 19.30236053], [84.96736145, 19.30236053], [84.96736145, 19.30208015], [84.96763611, 19.30208206], [84.96763611, 19.30152702], [84.9679184, 19.30153275], [84.9679184, 19.30125046], [84.96652985, 19.30125046], [84.96652985, 19.30097008], [84.9668045, 19.30097008], [84.9668045, 19.30069351], [84.96708679, 19.30069351], [84.96708679, 19.30041695], [84.96736145, 19.30042267], [84.96736145, 19.30015182], [84.96763611, 19.30015182], [84.96763611, 19.29957771], [84.9679184, 19.29958344], [84.9679184, 19.29930496], [84.96848297, 19.29931068], [84.96848297, 19.2990284], [84.96901703, 19.2990284], [84.96901703, 19.29846954], [84.96736145, 19.29846954], [84.96736145, 19.29874992], [84.96708679, 19.29874992], [84.96708679, 19.2991581], [84.96708679, 19.29931068], [84.9668045, 19.29930496], [84.9668045, 19.29958344], [84.96624756, 19.29958344], [84.96624756, 19.29986191], [84.96598053, 19.29986191], [84.96598053, 19.30015182], [84.96569824, 19.30015182], [84.96569824, 19.30042267], [84.96541595, 19.30041695], [84.96541595, 19.30097008], [84.9651413, 19.30097008], [84.9651413, 19.30125046], [84.96485901, 19.30125046], [84.96485901, 19.30153275], [84.96457672, 19.30153275], [84.96457672, 19.30125046], [84.96430206, 19.30125046], [84.96430206, 19.30097008], [84.9640274, 19.30097008], [84.9640274, 19.30069542], [84.96375275, 19.3006916], [84.96375275, 19.30041695], [84.96347046, 19.30042267], [84.96347046, 19.30015182], [84.9631958, 19.30015182], [84.9631958, 19.29986191], [84.96291351, 19.29986191], [84.96291351, 19.29958344], [84.96263885, 19.29958344], [84.96263885, 19.29930496], [84.96235657, 19.29931068], [84.96235657, 19.2990284], [84.96180725, 19.2990284], [84.96180725, 19.29874992], [84.96151733, 19.29874992], [84.96151733, 19.29846954], [84.96125031, 19.29847145], [84.96125031, 19.29819489], [84.96097565, 19.29819489], [84.96097565, 19.29791641], [84.9604187, 19.29791832], [84.9604187, 19.29763985], [84.96013641, 19.29763985], [84.96013641, 19.29735947], [84.95986176, 19.29736137], [84.95986176, 19.2970829], [84.95903015, 19.2970829], [84.95903015, 19.29680634], [84.95847321, 19.29680824], [84.95847321, 19.29652977], [84.95819092, 19.29652977], [84.95819092, 19.29624939], [84.9576416, 19.29624939], [84.9576416, 19.29597092], [84.95652771, 19.29597282], [84.95652771, 19.29569435], [84.95569611, 19.29569435], [84.95569611, 19.29541779], [84.95540619, 19.29541969], [84.95540619, 19.29514122], [84.95485687, 19.29514122], [84.95485687, 19.29458046], [84.95458221, 19.29458427], [84.95458221, 19.29430771], [84.95404053, 19.29430962], [84.95404053, 19.2940197], [84.95375061, 19.29402733], [84.95375061, 19.29375076], [84.95347595, 19.29375076], [84.95347595, 19.29347038], [84.95319366, 19.29347229], [84.95319366, 19.29291725], [84.95291901, 19.29292107], [84.95291901, 19.29264069], [84.95207977, 19.29264069], [84.95207977, 19.29236031], [84.95180511, 19.29236031], [84.95180511, 19.29208565], [84.95124817, 19.29208565], [84.95124817, 19.29180336], [84.95096588, 19.29181099], [84.95096588, 19.29153061], [84.95041656, 19.29153061], [84.95041656, 19.29125023], [84.94985962, 19.29125023], [84.94985962, 19.29097939], [84.94930267, 19.29097939], [84.94930267, 19.29070091], [84.94902802, 19.29070091], [84.94902802, 19.29042053], [84.94875336, 19.29042053], [84.94875336, 19.29014015], [84.94847107, 19.29014015], [84.94847107, 19.28985977], [84.94791412, 19.28986359], [84.94791412, 19.28902817], [84.94763947, 19.28903008], [84.94763947, 19.28874969], [84.94708252, 19.28874969], [84.94708252, 19.28847122], [84.94625092, 19.28847122], [84.94625092, 19.28791618], [84.94568634, 19.28792191], [84.94568634, 19.28763962], [84.94513702, 19.28763962], [84.94513702, 19.28735924], [84.94458008, 19.28735924], [84.94458008, 19.28708076], [84.94430542, 19.28708267], [84.94430542, 19.28652763], [84.94403076, 19.28652954], [84.94403076, 19.28624916], [84.94374847, 19.28624916], [84.94374847, 19.28597069], [84.94319153, 19.2859726], [84.94319153, 19.28569412], [84.94291687, 19.28569412], [84.94291687, 19.28541756], [84.94210052, 19.28541946], [84.94210052, 19.28513908], [84.94181061, 19.28513908], [84.94181061, 19.28486061], [84.94152832, 19.28486061], [84.94152832, 19.28457832], [84.94097137, 19.28458405], [84.94097137, 19.28430557], [84.94069672, 19.28430748], [84.94069672, 19.28403091], [84.94013977, 19.28403091], [84.94013977, 19.28375053], [84.93985748, 19.28375053], [84.93985748, 19.28347015], [84.93958282, 19.28347206], [84.93958282, 19.28319359], [84.93930817, 19.28319359], [84.93930817, 19.28291893], [84.93902588, 19.28292084], [84.93902588, 19.28264046], [84.93846893, 19.28264046], [84.93846893, 19.28236008], [84.93819427, 19.28236198], [84.93819427, 19.28208351], [84.93791962, 19.28208351], [84.93791962, 19.28180695], [84.93763733, 19.28181076], [84.93763733, 19.28153038], [84.93736267, 19.28153038], [84.93736267, 19.28125], [84.93680573, 19.28125], [84.93680573, 19.28097153], [84.93624878, 19.28097153], [84.93624878, 19.28069687], [84.93596649, 19.28070068], [84.93596649, 19.2804203], [84.93567657, 19.2804203], [84.93567657, 19.28013992], [84.93541718, 19.28013992], [84.93541718, 19.27985954], [84.93514252, 19.27986145], [84.93514252, 19.27958488], [84.93486023, 19.27958488], [84.93486023, 19.27930641], [84.93430328, 19.27931023], [84.93430328, 19.27903938], [84.93402863, 19.27903938], [84.93402863, 19.27874947], [84.93374634, 19.27874947], [84.93374634, 19.27847099], [84.93347168, 19.27847481], [84.93347168, 19.27819252], [84.93291473, 19.27819252], [84.93291473, 19.27791405], [84.93235779, 19.27791977], [84.93235779, 19.27763939], [84.93208313, 19.27763939], [84.93208313, 19.27736092], [84.93152618, 19.27736092], [84.93152618, 19.27708054], [84.93125153, 19.27708244], [84.93125153, 19.27680588], [84.93096924, 19.27680969], [84.93096924, 19.27653122], [84.93068695, 19.27653122], [84.93068695, 19.27625275], [84.93041992, 19.27625275], [84.93041992, 19.27598], [84.93013763, 19.27598], [84.93013763, 19.27569008], [84.92986298, 19.27569389], [84.92986298, 19.27541733], [84.92958069, 19.27542114], [84.92958069, 19.27458191], [84.92930603, 19.27458382], [84.92930603, 19.27430534], [84.92903137, 19.27431107], [84.92903137, 19.27403259], [84.92874908, 19.27403259], [84.92874908, 19.27375031], [84.9284668, 19.27375031], [84.9284668, 19.27347183], [84.92819214, 19.27347183], [84.92819214, 19.27319527], [84.92791748, 19.2732029], [84.92791748, 19.27290916], [84.92763519, 19.27291679], [84.92763519, 19.27263832], [84.92736053, 19.27263832], [84.92736053, 19.27235985], [84.92708588, 19.27236176], [84.92708588, 19.27208328], [84.92652893, 19.27208328], [84.92652893, 19.27180481], [84.92597198, 19.27180481], [84.92597198, 19.27152824], [84.92542267, 19.27152824], [84.92542267, 19.27124977], [84.92485809, 19.27124977], [84.92485809, 19.27096748], [84.92458344, 19.2709713], [84.92458344, 19.27069473], [84.92430878, 19.27069473], [84.92430878, 19.27041626], [84.92373657, 19.27041817], [84.92373657, 19.27013969], [84.92346954, 19.27013969], [84.92346954, 19.26984978], [84.92319489, 19.26986122], [84.92319489, 19.26958275], [84.92292023, 19.26958275], [84.92292023, 19.26930618], [84.92263794, 19.26930809], [84.92263794, 19.26875114], [84.92236328, 19.26875114], [84.92236328, 19.26847076], [84.92208099, 19.26847267], [84.92208099, 19.2681942], [84.92180634, 19.2681942], [84.92180634, 19.26791763], [84.92124939, 19.26791954], [84.92124939, 19.26764107], [84.9209671, 19.26764107], [84.9209671, 19.26708031], [84.92069244, 19.26708412], [84.92069244, 19.26647949], [84.92069244, 19.26597214], [84.92041779, 19.26597214], [84.92041779, 19.26569557], [84.91986084, 19.26569557], [84.91986084, 19.2654171], [84.91958618, 19.26542091], [84.91958618, 19.26514053], [84.91905212, 19.2651329], [84.91902924, 19.26486206], [84.91874695, 19.26486206], [84.91874695, 19.26458549], [84.91832733, 19.26458549], [84.91819763, 19.26458549], [84.91819763, 19.26430321], [84.91794586, 19.26430321], [84.91570282, 19.26431084], [84.91570282, 19.26403999], [84.9154129, 19.26403999], [84.9154129, 19.26375008], [84.91401672, 19.26375008], [84.91401672, 19.2634697], [84.91347504, 19.2634716], [84.91347504, 19.26319313], [84.91319275, 19.26320076], [84.91319275, 19.26292038], [84.91291809, 19.26292038], [84.91291809, 19.26264191], [84.9126358, 19.26264191], [84.9126358, 19.26235962], [84.91236115, 19.26236153], [84.91236115, 19.26208115], [84.91124725, 19.26208115], [84.91124725, 19.26236153], [84.91042328, 19.26235962], [84.91042328, 19.26264191], [84.9098587, 19.26264191], [84.9098587, 19.26292038], [84.9090271, 19.26292038], [84.9090271, 19.26320076], [84.90847015, 19.26319313], [84.90847015, 19.2634716], [84.90820313, 19.2634697], [84.90820313, 19.26431084], [84.90791321, 19.26430321], [84.90791321, 19.26708412], [84.90763855, 19.26708031], [84.90763855, 19.26930809], [84.90736389, 19.26930618], [84.90736389, 19.26986122], [84.90625, 19.26986122], [84.90625, 19.26958275], [84.90569305, 19.26958275], [84.90569305, 19.26930618], [84.9054184, 19.26930809], [84.9054184, 19.26847076], [84.90513611, 19.26847267], [84.90513611, 19.2681942], [84.90486145, 19.2681942], [84.90486145, 19.26791763], [84.90458679, 19.26791954], [84.90458679, 19.26708031], [84.90486145, 19.26708412], [84.90486145, 19.26680565], [84.90513611, 19.26680946], [84.90513611, 19.26653099], [84.9054184, 19.26653099], [84.9054184, 19.26625061], [84.90570068, 19.26625061], [84.90569305, 19.2634716], [84.90597534, 19.2634716], [84.90597534, 19.26319313], [84.90625, 19.26320076], [84.90625, 19.26264191], [84.90735626, 19.26264191], [84.90735626, 19.26235962], [84.90763855, 19.26236153], [84.90763855, 19.26208115], [84.9081955, 19.26208115], [84.9081955, 19.26152802], [84.90847015, 19.26153183], [84.90847015, 19.26124954], [84.90957642, 19.26124954], [84.90957642, 19.26097107], [84.91041565, 19.26097107], [84.91041565, 19.2606945], [84.91152954, 19.2606945], [84.91152954, 19.26041603], [84.91236115, 19.26042175], [84.91236877, 19.26013947], [84.9126358, 19.26013947], [84.9126358, 19.25958061], [84.91236115, 19.25958252], [84.91236115, 19.25930595], [84.91179657, 19.25931168], [84.91179657, 19.25902939], [84.91152954, 19.25902939], [84.91152954, 19.25875092], [84.91124725, 19.25875092], [84.91124725, 19.25847054], [84.9109726, 19.25847244], [84.9109726, 19.25819397], [84.91041565, 19.25819397], [84.91041565, 19.2579174], [84.91014099, 19.2579174], [84.91014099, 19.25763893], [84.9098587, 19.25764084], [84.9098587, 19.25736046], [84.90957642, 19.25736046], [84.90957642, 19.25707817], [84.90930176, 19.25708389], [84.90930176, 19.25680542], [84.9090271, 19.25681114], [84.9090271, 19.25653076], [84.90873718, 19.25653076], [84.90873718, 19.25625038], [84.90847015, 19.25625038], [84.90847015, 19.25597], [84.9081955, 19.25597191], [84.9081955, 19.25569534], [84.90791321, 19.25570107], [84.90791321, 19.25542068], [84.90763855, 19.25542068], [84.90763855, 19.2551403], [84.90735626, 19.2551403], [84.90735626, 19.25457954], [84.90680695, 19.25458336], [84.90680695, 19.25430679], [84.90652466, 19.25430679], [84.90652466, 19.25402832], [84.90625, 19.25403023], [84.90625, 19.25374985], [84.90597534, 19.25374985], [84.90597534, 19.25319672], [84.90569305, 19.25319672], [84.90569305, 19.25291443], [84.9054184, 19.25292015], [84.9054184, 19.25263977], [84.90486145, 19.25263977], [84.90486145, 19.25235939], [84.90374756, 19.2523613], [84.90374756, 19.25208473], [84.90319824, 19.25208473], [84.90319061, 19.25152779], [84.90293121, 19.25152969], [84.90293121, 19.25125122], [84.9026413, 19.25125122], [84.9026413, 19.25069046], [84.90235901, 19.25069237], [84.90235901, 19.2504158], [84.90207672, 19.25041962], [84.90207672, 19.25014114], [84.9015274, 19.25014114], [84.9015274, 19.24986076], [84.90125275, 19.24986076], [84.90125275, 19.24958038], [84.90097046, 19.24958229], [84.90097046, 19.24930573], [84.9006958, 19.24930954], [84.9006958, 19.24903107], [84.90040588, 19.24903107], [84.90040588, 19.24847031], [84.89958191, 19.24847031], [84.89958191, 19.24819374], [84.89875031, 19.24819374], [84.89875031, 19.24791718], [84.89848328, 19.2479229], [84.89848328, 19.24764252], [84.89816284, 19.24764252], [84.8979187, 19.24764252], [84.8979187, 19.24736023], [84.89783478, 19.24736023], [84.89736176, 19.24736023], [84.89736176, 19.24708176], [84.8970871, 19.24708366], [84.8970871, 19.24680519], [84.89653015, 19.24681282], [84.89653015, 19.24653244], [84.89624786, 19.24653244], [84.89624786, 19.24625015], [84.89597321, 19.24625015], [84.89597321, 19.24596977], [84.89569092, 19.24597168], [84.89569092, 19.24569511], [84.89541626, 19.24570084], [84.89541626, 19.24541855], [84.8951416, 19.24541855], [84.8951416, 19.24513817], [84.89457703, 19.24513817], [84.89457703, 19.24458122], [84.89430237, 19.24458313], [84.89430237, 19.24430466], [84.89402771, 19.24430466], [84.89402771, 19.24402809], [84.89376068, 19.24402809], [84.89376068, 19.24377251], [84.89347076, 19.24374962], [84.89342499, 19.24352837], [84.89335632, 19.24347305], [84.89319611, 19.24347305], [84.89319611, 19.24332047], [84.89319611, 19.24319458], [84.89305115, 19.24319458], [84.89263916, 19.24319458], [84.89263916, 19.24291611], [84.89208221, 19.24291611], [84.89208221, 19.24263954], [84.89180756, 19.24263954], [84.89180756, 19.24236107], [84.89152527, 19.24236107], [84.89152527, 19.2420826], [84.89125061, 19.2420826], [84.89125061, 19.24180794], [84.89070129, 19.24180984], [84.89070129, 19.24152946], [84.89041901, 19.24152946], [84.89041901, 19.24097061], [84.89013672, 19.24097252], [84.89013672, 19.24069595], [84.88986206, 19.24069595], [84.88986206, 19.24041748], [84.88957977, 19.24041939], [84.88954926, 19.24014091], [84.88903046, 19.24014091], [84.88903046, 19.23987007], [84.88874817, 19.23987007], [84.88874817, 19.23958015], [84.88847351, 19.23958588], [84.88847351, 19.23930359], [84.88819122, 19.23931122], [84.88819122, 19.23903084], [84.88791656, 19.23903084], [84.88791656, 19.23875046], [84.88762665, 19.23875046], [84.88762665, 19.23847961], [84.88709259, 19.23847008], [84.88708496, 19.23819542], [84.88680267, 19.2381897], [84.88680267, 19.23791695], [84.88625336, 19.23792076], [84.88625336, 19.23764038], [84.88597107, 19.23764038], [84.88597107, 19.23736], [84.88569641, 19.23736382], [84.88569641, 19.23708153], [84.88541412, 19.23708153], [84.88541412, 19.23680305], [84.88513947, 19.23681068], [84.88513947, 19.2365303], [84.88485718, 19.2365303], [84.88485718, 19.23624992], [84.88456726, 19.23624992], [84.88458252, 19.23583031], [84.88458252, 19.23569489], [84.8844223, 19.23569489], [84.88430786, 19.23569489], [84.88430786, 19.23541641], [84.88402557, 19.23541641], [84.88402557, 19.23533058], [84.88402557, 19.23513985], [84.88375092, 19.23513985], [84.88375092, 19.23485947], [84.88346863, 19.23486137], [84.88346863, 19.2345829], [84.88319397, 19.2345829], [84.88319397, 19.23430634], [84.88291931, 19.23431015], [84.88291931, 19.23373985], [84.88263702, 19.23374939], [84.88263702, 19.23347282], [84.88208008, 19.23347282], [84.88208008, 19.23319435], [84.88192749, 19.23319435], [84.88180542, 19.23319435], [84.88180542, 19.23291588], [84.88172913, 19.23291588], [84.88153076, 19.2329216], [84.88153076, 19.23263931], [84.88124847, 19.23263931], [84.88124847, 19.2322197], [84.88124847, 19.23208427], [84.88041687, 19.23208427], [84.88041687, 19.23152733], [84.88014221, 19.23152924], [84.88014221, 19.23125076], [84.87985992, 19.23125076], [84.87985992, 19.23097038], [84.87958527, 19.23097229], [84.87958527, 19.23069382], [84.87902832, 19.23069382], [84.87902832, 19.23041725], [84.87876129, 19.23041916], [84.87876129, 19.23014069], [84.87847137, 19.23014069], [84.87847137, 19.22957993], [84.87791443, 19.22958374], [84.87791443, 19.2290287], [84.87763977, 19.22903061], [84.87763977, 19.22875023], [84.87708282, 19.22875023], [84.87708282, 19.22846985], [84.87680817, 19.22847176], [84.87680817, 19.22819519], [84.87652588, 19.22820091], [84.87652588, 19.22792816], [84.87625122, 19.22792816], [84.87625122, 19.22764015], [84.87596893, 19.22764015], [84.87596893, 19.22707939], [84.87569427, 19.22708321], [84.87569427, 19.22680664], [84.87513733, 19.22680664], [84.87513733, 19.22652817], [84.87458038, 19.22653008], [84.87458038, 19.22597122], [84.87430573, 19.22597313], [84.87430573, 19.22569656], [84.87403107, 19.22569656], [84.87403107, 19.22541428], [84.87346649, 19.22542], [84.87346649, 19.22513962], [84.87291718, 19.22513962], [84.87291718, 19.22487068], [84.87262726, 19.22487068], [84.87262726, 19.22430992], [84.87236023, 19.22430992], [84.87236023, 19.22402954], [84.8720932, 19.22402954], [84.8720932, 19.22375107], [84.87152863, 19.22375107], [84.87152863, 19.22319031], [84.87124634, 19.22319221], [84.87124634, 19.22291756], [84.87097168, 19.22291946], [84.87097168, 19.2226429], [84.87069702, 19.2226429], [84.87069702, 19.22236061], [84.8704071, 19.22236061], [84.8704071, 19.22208023], [84.87014008, 19.22208214], [84.87014008, 19.22180557], [84.86985779, 19.22180557], [84.86985779, 19.2215271], [84.86902618, 19.22153282], [84.86902618, 19.22125053], [84.86875153, 19.22125053], [84.86875153, 19.22097015], [84.86846924, 19.22097015], [84.86846924, 19.22069359], [84.86791992, 19.22069359], [84.86791992, 19.22041702], [84.86763763, 19.22042274], [84.86763763, 19.22014046], [84.86736298, 19.22014046], [84.86736298, 19.2195816], [84.86680603, 19.21958351], [84.86680603, 19.21902847], [84.86653137, 19.21902847], [84.86653137, 19.21874046], [84.86624908, 19.21874809], [84.86624908, 19.21847153], [84.86597443, 19.21847153], [84.86597443, 19.21819496], [84.86569214, 19.21820068], [84.86569214, 19.2179184], [84.86541748, 19.2179184], [84.86541748, 19.21763992], [84.86514282, 19.21763992], [84.86514282, 19.21708107], [84.86486053, 19.21708298], [84.86486053, 19.21652985], [84.86458588, 19.21652985], [84.86458588, 19.21624947], [84.86429596, 19.21624947], [84.86429596, 19.21597099], [84.86402893, 19.2159729], [84.86402893, 19.21569443], [84.86374664, 19.21569824], [84.86374664, 19.21541977], [84.86347198, 19.21541977], [84.86347198, 19.21513939], [84.86319733, 19.21513939], [84.86319733, 19.21486092], [84.86291504, 19.21486092], [84.86291504, 19.21430779], [84.86264038, 19.21430969], [84.86264038, 19.21403122], [84.86207581, 19.21403122], [84.86207581, 19.21375084], [84.86152649, 19.21375084], [84.86152649, 19.21347046], [84.86125183, 19.21347237], [84.86125183, 19.2131958], [84.86096954, 19.2131958], [84.86096954, 19.21291733], [84.86068726, 19.21293068], [84.86068726, 19.21264076], [84.86042023, 19.21264076], [84.86042023, 19.21236038], [84.86013794, 19.21236038], [84.86013794, 19.21208], [84.85986328, 19.21208572], [84.85986328, 19.21180344], [84.85930634, 19.21181107], [84.85930634, 19.21153069], [84.85901642, 19.21153069], [84.85901642, 19.21125031], [84.85874939, 19.21125031], [84.85874939, 19.21070099], [84.8584671, 19.21070099], [84.8584671, 19.21042061], [84.85819244, 19.21042061], [84.85819244, 19.20985985], [84.85791779, 19.20986366], [84.85791779, 19.20958138], [84.8576355, 19.20958138], [84.8576355, 19.20930481], [84.85708618, 19.20930481], [84.85708618, 19.20874977], [84.85679626, 19.20874977], [84.85679626, 19.20846939], [84.85652924, 19.2084713], [84.85652924, 19.20819473], [84.85624695, 19.20819473], [84.85624695, 19.20791626], [84.85597229, 19.20792007], [84.85597229, 19.20763969], [84.85569763, 19.20763969], [84.85569763, 19.20735931], [84.85541534, 19.20735931], [84.85541534, 19.20708275], [84.85514069, 19.20708275], [84.85514069, 19.20680618], [84.8548584, 19.20680618], [84.8548584, 19.20652771], [84.85459137, 19.20652962], [84.85459137, 19.20624924], [84.85430908, 19.20624924], [84.85430908, 19.20597076], [84.85375214, 19.20597267], [84.85375214, 19.2056942], [84.85346985, 19.2056942], [84.85346985, 19.20541763], [84.85320282, 19.20542145], [84.85320282, 19.20513916], [84.8529129, 19.20513916], [84.8529129, 19.20486069], [84.85263824, 19.20486069], [84.85263824, 19.20458031], [84.85236359, 19.20458412], [84.85236359, 19.20402718], [84.8520813, 19.20402908], [84.8520813, 19.20375824], [84.85153198, 19.20375824], [84.85153198, 19.20318985], [84.85124969, 19.20319366], [84.85124969, 19.2029171], [84.85098267, 19.20292091], [84.85098267, 19.20264053], [84.85069275, 19.20264053], [84.85069275, 19.20207977], [84.85041809, 19.20208359], [84.85041809, 19.20180511], [84.84958649, 19.20181084], [84.84958649, 19.20153046], [84.84929657, 19.20153046], [84.84929657, 19.20125008], [84.84902954, 19.20125008], [84.84902954, 19.2009697], [84.84874725, 19.2009716], [84.84874725, 19.20069695], [84.84845734, 19.20070076], [84.84845734, 19.20042038], [84.84819794, 19.20042038], [84.84819794, 19.19985962], [84.84791565, 19.19986153], [84.84791565, 19.19958305], [84.84764099, 19.19958305], [84.84764099, 19.19930649], [84.8473587, 19.1993103], [84.8473587, 19.19902992], [84.84707642, 19.19902992], [84.84707642, 19.19847107], [84.84680176, 19.19847488], [84.84680176, 19.1981926], [84.8465271, 19.1981926], [84.8465271, 19.19763947], [84.84625244, 19.19763947], [84.84625244, 19.1973629], [84.84617615, 19.1973629], [84.84597015, 19.1973629], [84.84597015, 19.19715118], [84.84541321, 19.19708252], [84.84541321, 19.19680405], [84.84485626, 19.19680977], [84.84485626, 19.19652939], [84.8445816, 19.19652939], [84.8445816, 19.19625282], [84.84430695, 19.19625282], [84.84430695, 19.19569016], [84.84402466, 19.19569206], [84.84402466, 19.19513893], [84.84348297, 19.19514275], [84.84346771, 19.19458961], [84.8429184, 19.19457054], [84.8429184, 19.19430542], [84.84265137, 19.19431114], [84.84265137, 19.19403267], [84.84236145, 19.19403267], [84.84236145, 19.19375038], [84.84208679, 19.19375038], [84.84208679, 19.19347191], [84.8418045, 19.19347191], [84.8418045, 19.19319534], [84.84152985, 19.19320107], [84.84152985, 19.19235992], [84.84124756, 19.19236183], [84.84124756, 19.19192123], [84.84124756, 19.19180489], [84.8409729, 19.19180489], [84.8409729, 19.19152832], [84.84069824, 19.19152832], [84.84066772, 19.19125938], [84.8401413, 19.19124985], [84.8401413, 19.19096947], [84.83985901, 19.19097137], [84.83985901, 19.19069481], [84.83958435, 19.19069481], [84.83958435, 19.19041634], [84.83930206, 19.19041824], [84.83930206, 19.19013977], [84.8390274, 19.19013977], [84.8390274, 19.18985939], [84.83875275, 19.1898613], [84.83875275, 19.18958282], [84.83847046, 19.18958282], [84.83847046, 19.18902779], [84.8381958, 19.18902969], [84.8381958, 19.18876076], [84.83790588, 19.18876076], [84.83791351, 19.18836021], [84.83791351, 19.18819427], [84.8377533, 19.18819427], [84.83763885, 19.18819427], [84.83763885, 19.18806839], [84.83763885, 19.18763924], [84.83735657, 19.18764114], [84.83735657, 19.18708038], [84.83708191, 19.1870842], [84.83708191, 19.18652725], [84.83680725, 19.18653107], [84.83680725, 19.18625069], [84.83651733, 19.18625069], [84.83651733, 19.18597031], [84.83569336, 19.18597221], [84.83569336, 19.18569565], [84.83538055, 19.18569565], [84.83513641, 19.18569565], [84.83513641, 19.18543053], [84.83513641, 19.18486023], [84.83486176, 19.18486023], [84.83486176, 19.18457985], [84.8345871, 19.18458557], [84.8345871, 19.18430328], [84.83429718, 19.18431091], [84.83429718, 19.18375015], [84.83403015, 19.18375015], [84.83403015, 19.18320084], [84.83374786, 19.18320084], [84.83374786, 19.18292046], [84.83345795, 19.18292046], [84.83345795, 19.18263054], [84.83319092, 19.18263817], [84.83319092, 19.18236351], [84.83291626, 19.18236351], [84.83291626, 19.18208122], [84.8326416, 19.18208122], [84.8326416, 19.18180466], [84.83208466, 19.18180466], [84.83208466, 19.18152809], [84.83180237, 19.18153191], [84.83180237, 19.18124962], [84.83152771, 19.18124962], [84.83152771, 19.18069077], [84.83125305, 19.18069458], [84.83125305, 19.18041611], [84.83097076, 19.18042183], [84.83097076, 19.18013954], [84.83069611, 19.18013954], [84.83069611, 19.18000984], [84.83069611, 19.17985916], [84.83041382, 19.17985916], [84.83041382, 19.1795826], [84.83013916, 19.17959023], [84.83013916, 19.17931175], [84.82985687, 19.17931175], [84.82985687, 19.17902946], [84.82958221, 19.17902946], [84.82958221, 19.17874908], [84.82930756, 19.17874908], [84.82930756, 19.17847061], [84.82902527, 19.17847252], [84.82902527, 19.17791748], [84.82875061, 19.1779213], [84.82875061, 19.17708015], [84.82819366, 19.17708397], [84.82819366, 19.17652893], [84.82791901, 19.17653084], [84.82791138, 19.17625809], [84.82736206, 19.17625046], [84.82736206, 19.17597008], [84.82653046, 19.17597198], [84.82653046, 19.17541885], [84.82624817, 19.17542076], [84.82624817, 19.17515945], [84.82596588, 19.17514038], [84.82595825, 19.17487907], [84.82569122, 19.17486], [84.82569122, 19.17458344], [84.82541656, 19.17458344], [84.82541656, 19.17427254], [84.82541656, 19.1740284], [84.82521057, 19.1740303], [84.82514191, 19.17374992], [84.82496643, 19.17374992], [84.82457733, 19.17374992], [84.82457733, 19.17346954], [84.82375336, 19.17347145], [84.82375336, 19.17291641], [84.82347107, 19.17292023], [84.82347107, 19.17235947], [84.82319641, 19.17236137], [84.82319641, 19.17180634], [84.82290649, 19.17181015], [84.82290649, 19.17152977], [84.82263947, 19.17152977], [84.82260895, 19.17098045], [84.82236481, 19.17097473], [84.82236481, 19.17069244], [84.82180786, 19.17069244], [84.82180786, 19.17041588], [84.82151794, 19.17041969], [84.82151794, 19.17014122], [84.82125092, 19.17014122], [84.82125092, 19.16986084], [84.82096863, 19.16986084], [84.82096863, 19.16958046], [84.82069397, 19.16958237], [84.82069397, 19.16902733], [84.82041931, 19.16903114], [84.82041931, 19.16847038], [84.82013702, 19.16847038], [84.82013702, 19.16819382], [84.81986237, 19.16819382], [84.81986237, 19.1678009], [84.81986237, 19.16763878], [84.81973267, 19.16763878], [84.81958008, 19.16765022], [84.81958008, 19.16747093], [84.81958008, 19.16708374], [84.81930542, 19.16708374], [84.81930542, 19.16680527], [84.81903076, 19.1668129], [84.81903076, 19.16653252], [84.81874847, 19.16651917], [84.81874847, 19.16597176], [84.81847382, 19.16597176], [84.81847382, 19.16569519], [84.81819153, 19.16570091], [84.81819153, 19.16513824], [84.81791687, 19.16513824], [84.81791687, 19.16459084], [84.81764221, 19.16459084], [84.81764221, 19.16430092], [84.81735992, 19.16430473], [84.81735992, 19.16374969], [84.81708527, 19.16374969], [84.81708527, 19.16347313], [84.81680298, 19.16347313], [84.81680298, 19.16319466], [84.81652832, 19.16319466], [84.81652832, 19.16291618], [84.81614685, 19.16291618], [84.81597137, 19.16291809], [84.81597137, 19.16264915], [84.81569672, 19.16263962], [84.81569672, 19.16236115], [84.81541443, 19.16236115], [84.81541443, 19.16208267], [84.81513977, 19.16208267], [84.81513977, 19.16152763], [84.81485748, 19.16152954], [84.81485748, 19.16125107], [84.81458282, 19.16125107], [84.81458282, 19.16097069], [84.81430817, 19.1609726], [84.81430817, 19.16041756], [84.81402588, 19.16041946], [84.81402588, 19.16014099], [84.81375122, 19.16014099], [84.81375122, 19.15986061], [84.81346893, 19.15986061], [84.81346893, 19.15930939], [84.81291962, 19.15930939], [84.81291962, 19.15875053], [84.81263733, 19.15875053], [84.81263733, 19.15846062], [84.81236267, 19.15847206], [84.81236267, 19.1581955], [84.81208038, 19.1581955], [84.81208038, 19.15763855], [84.81181335, 19.15764046], [84.81181335, 19.15736008], [84.81124878, 19.15736389], [84.81124878, 19.15708542], [84.81097412, 19.15708542], [84.81097412, 19.15680313], [84.81069183, 19.15681076], [84.81069183, 19.15653038], [84.81041718, 19.15653038], [84.81041718, 19.15625], [84.81014252, 19.15625], [84.81014252, 19.15596962], [84.80986023, 19.15597153], [84.80986023, 19.15569305], [84.80957794, 19.15571022], [84.80957794, 19.1554203], [84.80928802, 19.1554203], [84.80928802, 19.15514183], [84.80902863, 19.15514183], [84.80902863, 19.15485954], [84.80874634, 19.15486145], [84.80874634, 19.15402794], [84.80847168, 19.15403175], [84.80847168, 19.15236092], [84.80819702, 19.15236092], [84.80819702, 19.15152931], [84.8079071, 19.15152931], [84.80791473, 19.15117836], [84.80791473, 19.15097237], [84.80764008, 19.15097237], [84.80764008, 19.15041733], [84.80735779, 19.15041924], [84.80735779, 19.15014076], [84.80696106, 19.15014076], [84.80680847, 19.15014076], [84.80680847, 19.14997101], [84.80680847, 19.14958382], [84.80654144, 19.14958954], [84.80654144, 19.14931107], [84.80619812, 19.14931107], [84.80596924, 19.14931107], [84.80596161, 19.14903831], [84.80568695, 19.14903069], [84.80568695, 19.14875031], [84.80541992, 19.14875031], [84.80541992, 19.14845085], [84.80541992, 19.14819527], [84.80516052, 19.14820099], [84.80513763, 19.14792061], [84.80486298, 19.14791679], [84.80486298, 19.14782715], [84.80486298, 19.14652824], [84.80458069, 19.14652824], [84.80458069, 19.14569664], [84.80430603, 19.14569664], [84.80430603, 19.14513969], [84.80403137, 19.14513969], [84.80403137, 19.14486122], [84.80374908, 19.14486122], [84.80374908, 19.14458084], [84.80319214, 19.14458466], [84.80319214, 19.14402771], [84.80291748, 19.14402962], [84.80291748, 19.14346123], [84.80263519, 19.14347458], [84.80263519, 19.14291763], [84.80236053, 19.14291954], [84.80236053, 19.14208031], [84.80208588, 19.14208221], [84.80208588, 19.14152718], [84.80179596, 19.1415329], [84.80179596, 19.14097023], [84.80152893, 19.14097023], [84.80152893, 19.1404171], [84.80124664, 19.14042282], [84.80124664, 19.14014244], [84.80097198, 19.14014244], [84.80097198, 19.13958168], [84.80069733, 19.13958359], [84.80069733, 19.13930511], [84.80040741, 19.13931274], [84.80040741, 19.13874817], [84.79985809, 19.13874817], [84.79985809, 19.1384697], [84.79958344, 19.1384716], [84.79958344, 19.13763809], [84.79930878, 19.13763809], [84.79930878, 19.1368084], [84.79902649, 19.1368084], [84.79902649, 19.13624954], [84.79875183, 19.13624954], [84.79875183, 19.13569069], [84.79846954, 19.1356945], [84.79846954, 19.13513947], [84.79792023, 19.13513947], [84.79792023, 19.13375092], [84.79763794, 19.13375092], [84.79763794, 19.13347054], [84.79736328, 19.13347244], [84.79736328, 19.13319588], [84.79708099, 19.13319588], [84.79708099, 19.13125038], [84.79680634, 19.13125038], [84.79680634, 19.13042068], [84.79651642, 19.13042068], [84.79651642, 19.12930107], [84.79624939, 19.12930489], [84.79624939, 19.12874985], [84.7959671, 19.12874985], [84.7959671, 19.12848091], [84.79569244, 19.12848091], [84.79569244, 19.1281929], [84.7951355, 19.12819481], [84.7951355, 19.12791634], [84.79486084, 19.12792015], [84.79486084, 19.12763977], [84.79402924, 19.12763977], [84.79402924, 19.12708092], [84.79374695, 19.12708282], [84.79374695, 19.12680626], [84.79319763, 19.12681007], [84.79319763, 19.1265316], [84.79264069, 19.1265316], [84.79264069, 19.12624931], [84.79207611, 19.12624931], [84.79207611, 19.12597084], [84.79180908, 19.12597275], [84.79180908, 19.12569427], [84.79152679, 19.12569427], [84.79152679, 19.1254158], [84.79103851, 19.12542152], [84.79099274, 19.12524414], [84.79096985, 19.12513924], [84.78985596, 19.12513924], [84.78985596, 19.12458038], [84.7895813, 19.1245842], [84.7895813, 19.12402725], [84.78930664, 19.12402916], [84.78930664, 19.12375069], [84.78901672, 19.12375069], [84.78901672, 19.12318993], [84.78874969, 19.12319374], [84.78874969, 19.12291718], [84.78846741, 19.12291908], [84.78846741, 19.12264061], [84.78817749, 19.12264061], [84.78817749, 19.12207985], [84.78791809, 19.12208366], [84.78791809, 19.12180519], [84.7876358, 19.12181091], [84.7876358, 19.12153053], [84.78708649, 19.12153053], [84.78708649, 19.12125015], [84.78624725, 19.12125015], [84.78624725, 19.12096977], [84.7859726, 19.12097168], [84.7859726, 19.12069511], [84.78569794, 19.12070084], [84.78569794, 19.12042046], [84.78540802, 19.12042046], [84.78540802, 19.12014008], [84.78514099, 19.12014008], [84.78514099, 19.1198597], [84.7848587, 19.1198616], [84.7848587, 19.11930656], [84.78458405, 19.11930656], [84.78458405, 19.11902809], [84.78430176, 19.11903], [84.78430176, 19.11874962], [84.7840271, 19.11874962], [84.7840271, 19.11819077], [84.78375244, 19.11819267], [84.78375244, 19.1179142], [84.78347015, 19.11791992], [84.78347015, 19.11736107], [84.7831955, 19.11736107], [84.7831955, 19.1170845], [84.78291321, 19.1170845], [84.78291321, 19.11680412], [84.78263855, 19.11680984], [84.78263855, 19.1162529], [84.78237152, 19.1162529], [84.78237152, 19.11597061], [84.7820816, 19.11597443], [84.7820816, 19.11541748], [84.78291321, 19.11541939], [84.78291321, 19.11514282], [84.78320313, 19.11514282], [84.78320313, 19.11403275], [84.78291321, 19.11403275], [84.78291321, 19.11375046], [84.78263855, 19.11375046], [84.78263855, 19.11347961], [84.78237152, 19.11347961], [84.78237152, 19.11320114], [84.7804184, 19.1131916], [84.7804184, 19.11291695], [84.78013611, 19.11292267], [84.78013611, 19.11235809], [84.77986145, 19.11236191], [84.77986145, 19.11208344], [84.77958679, 19.11208344], [84.77958679, 19.11180496], [84.77931213, 19.11181068], [84.77931213, 19.1115284], [84.77874756, 19.1115284], [84.77874756, 19.11124992], [84.7784729, 19.11124992], [84.7784729, 19.11069107], [84.77819824, 19.11069489], [84.77819061, 19.11041641], [84.77791595, 19.11041641], [84.77791595, 19.11013985], [84.77735901, 19.11013985], [84.77735901, 19.10985947], [84.7765274, 19.10986137], [84.7765274, 19.1095829], [84.77597046, 19.1095829], [84.77597046, 19.10986137], [84.77541351, 19.10986137], [84.77541351, 19.1095829], [84.77402496, 19.1095829], [84.77402496, 19.10986137], [84.77375031, 19.10986137], [84.77375031, 19.1095829], [84.77263641, 19.1095829], [84.77263641, 19.10930634], [84.76930237, 19.10930634], [84.76930237, 19.1095829], [84.76902771, 19.1095829], [84.76902771, 19.10930634], [84.76819611, 19.10930634], [84.76819611, 19.1095829], [84.76763916, 19.1095829], [84.76763916, 19.10986137], [84.76737213, 19.10985947], [84.76737213, 19.11013985], [84.76708221, 19.11013985], [84.76708221, 19.10985947], [84.76680756, 19.10985947], [84.76680756, 19.11013985], [84.76569366, 19.11013985], [84.76569366, 19.11041641], [84.76541901, 19.11041641], [84.76541901, 19.11069489], [84.76457977, 19.11069107], [84.76457977, 19.1115284], [84.76264191, 19.1115284], [84.76264191, 19.11181068], [84.76208496, 19.11180496], [84.76208496, 19.11208344], [84.76180267, 19.11208344], [84.76180267, 19.11236191], [84.76152802, 19.11235809], [84.76152802, 19.11264038], [84.76097107, 19.11264038], [84.76097107, 19.11292267], [84.76069641, 19.11291695], [84.76069641, 19.1131916], [84.75985718, 19.11320114], [84.75985718, 19.11347961], [84.75930786, 19.11347961], [84.75930786, 19.11375046], [84.75902557, 19.11375046], [84.75902557, 19.11347008], [84.75875092, 19.11347961], [84.75875092, 19.11320114], [84.7582016, 19.11320114], [84.7582016, 19.11347961], [84.75763702, 19.11347961], [84.75763702, 19.11375046], [84.75736237, 19.11375046], [84.75736237, 19.11403275], [84.75763702, 19.11403275], [84.75763702, 19.11486053], [84.75736237, 19.11486053], [84.75736237, 19.11514282], [84.75708008, 19.11514282], [84.75708008, 19.11541939], [84.75653076, 19.11541939], [84.75653076, 19.11514282], [84.75596619, 19.11514282], [84.75596619, 19.11486053], [84.75569153, 19.11486053], [84.75569153, 19.11458015], [84.75541687, 19.11458206], [84.75541687, 19.1143055], [84.75569153, 19.11431122], [84.75569153, 19.11375046], [84.75596619, 19.11375046], [84.75596619, 19.11264038], [84.75569153, 19.11264038], [84.75569153, 19.11207962], [84.75541687, 19.11208344], [84.75541687, 19.11180496], [84.75485992, 19.11181068], [84.75485992, 19.11124992], [84.75430298, 19.11124992], [84.75430298, 19.1115284], [84.75374603, 19.1115284], [84.75374603, 19.11124992], [84.75347137, 19.11124992], [84.75347137, 19.1115284], [84.75319672, 19.1115284], [84.75319672, 19.11292267], [84.75430298, 19.11292267], [84.75430298, 19.11375046], [84.75402832, 19.11375046], [84.75402832, 19.11431122], [84.75347137, 19.1143055], [84.75347137, 19.11458206], [84.7529068, 19.11458015], [84.7529068, 19.11514282], [84.75263977, 19.11513901], [84.75263977, 19.11569214], [84.75208282, 19.11569214], [84.75208282, 19.11597443], [84.75096893, 19.11597061], [84.75096893, 19.1162529], [84.74986267, 19.1162529], [84.74986267, 19.11654091], [84.74958038, 19.11654091], [84.74958038, 19.11680984], [84.74930573, 19.11680412], [84.74930573, 19.1170845], [84.74764252, 19.11708069], [84.74764252, 19.11736107], [84.74708557, 19.11736107], [84.7470932, 19.11763954], [84.74569702, 19.11763954], [84.74569702, 19.11736107], [84.7454071, 19.11736107], [84.7454071, 19.11708069], [84.74514008, 19.1170845], [84.74514008, 19.11680412], [84.74485779, 19.11680984], [84.74485779, 19.11654091], [84.74430847, 19.11654091], [84.74430847, 19.1162529], [84.74402618, 19.1162529], [84.74402618, 19.11597061], [84.74375153, 19.11597443], [84.74375153, 19.11569214], [84.74346924, 19.11569214], [84.74346924, 19.11541748], [84.74291992, 19.11541939], [84.74291992, 19.11514282], [84.74263763, 19.11514282], [84.74263763, 19.11486053], [84.74208069, 19.11486053], [84.74208069, 19.11458015], [84.74124908, 19.11458206], [84.74124908, 19.1143055], [84.7409668, 19.11431122], [84.7409668, 19.11403275], [84.74069214, 19.11403275], [84.74069214, 19.11375046], [84.74041748, 19.11375046], [84.74041748, 19.11320114], [84.74014282, 19.1131916], [84.74013519, 19.11291695], [84.73986053, 19.11292267], [84.73986053, 19.11264038], [84.73958588, 19.11264038], [84.73958588, 19.11235809], [84.73847198, 19.11236191], [84.73847198, 19.11180496], [84.73819733, 19.11181068], [84.73819733, 19.11096954], [84.73791504, 19.11097145], [84.73791504, 19.11069489], [84.73708344, 19.11069489], [84.73708344, 19.11041641], [84.73680878, 19.11041641], [84.73680878, 19.11013985], [84.73652649, 19.11013985], [84.73652649, 19.10930824], [84.73625183, 19.10930824], [84.73625183, 19.10874939], [84.73652649, 19.10874939], [84.73652649, 19.1073494], [84.73625183, 19.10736084], [84.73625183, 19.10680771], [84.73596954, 19.10680962], [84.73596954, 19.10653114], [84.73568726, 19.10653114], [84.73568726, 19.10625076], [84.73542023, 19.10625076], [84.73542023, 19.10597038], [84.73513794, 19.10597229], [84.73513794, 19.10569572], [84.73486328, 19.10569572], [84.73486328, 19.10347366], [84.73458099, 19.10347366], [84.73458099, 19.10319328], [84.73486328, 19.10320091], [84.73486328, 19.10235977], [84.73513794, 19.10236359], [84.73513794, 19.10124969], [84.73486328, 19.10124969], [84.73486328, 19.10097122], [84.73458099, 19.10097122], [84.73458099, 19.10069466], [84.73374939, 19.10069466], [84.73374939, 19.10013962], [84.7334671, 19.10013962], [84.7334671, 19.09985924], [84.73319244, 19.09985924], [84.73319244, 19.09958076], [84.73291779, 19.09958267], [84.73291779, 19.09902763], [84.73264313, 19.09903145], [84.73264313, 19.09818077], [84.73236084, 19.09819412], [84.73236084, 19.09791756], [84.73208618, 19.09792137], [84.73208618, 19.09763908], [84.73152924, 19.09763908], [84.73152924, 19.09736061], [84.73124695, 19.09736061], [84.73124695, 19.09708405], [84.73097229, 19.09708405], [84.73097229, 19.09680557], [84.73042297, 19.09680748], [84.73042297, 19.09653091], [84.72875214, 19.09653091], [84.72875214, 19.09625053], [84.72846985, 19.09625053], [84.72846985, 19.09597015], [84.7279129, 19.09597206], [84.7279129, 19.09569359], [84.72736359, 19.09569359], [84.72736359, 19.09597206], [84.72680664, 19.09597015], [84.72680664, 19.09625053], [84.72624969, 19.09625053], [84.72624969, 19.09653091], [84.72541809, 19.09653091], [84.72541809, 19.09736061], [84.72512817, 19.09736061], [84.72512817, 19.09792137], [84.72569275, 19.09791756], [84.72569275, 19.0984726], [84.72597504, 19.0984726], [84.72598267, 19.10013962], [84.72569275, 19.10013962], [84.72569275, 19.10264015], [84.72598267, 19.10264015], [84.72598267, 19.10320091], [84.72624969, 19.10320091], [84.72624969, 19.10375023], [84.72651672, 19.10375023], [84.72651672, 19.10403061], [84.72680664, 19.10403061], [84.72680664, 19.10431099], [84.7270813, 19.10430336], [84.7270813, 19.10458565], [84.72763824, 19.10457993], [84.72763824, 19.10486031], [84.7279129, 19.10486031], [84.7279129, 19.10542107], [84.72819519, 19.10541725], [84.72819519, 19.10569572], [84.72930908, 19.10569], [84.72930908, 19.10653114], [84.72958374, 19.10652733], [84.72958374, 19.10708237], [84.7298584, 19.10708427], [84.7298584, 19.10736084], [84.73014069, 19.1073494], [84.73014069, 19.10764122], [84.73042297, 19.10764122], [84.73042297, 19.10791969], [84.73069763, 19.10791779], [84.73069763, 19.10819435], [84.73097229, 19.10819435], [84.73097229, 19.10847282], [84.73152924, 19.10847092], [84.73152924, 19.10930824], [84.73180389, 19.10930634], [84.73180389, 19.1095829], [84.73208618, 19.10958099], [84.73208618, 19.11013985], [84.73236084, 19.11013985], [84.73236084, 19.11041641], [84.7326355, 19.11041641], [84.7326355, 19.11097145], [84.73291779, 19.11096954], [84.73291779, 19.11181068], [84.73264313, 19.11181068], [84.73264313, 19.11264038], [84.73291779, 19.11264038], [84.73291779, 19.11292267], [84.73400879, 19.11292267], [84.73400879, 19.11264038], [84.73432159, 19.11264038], [84.73432159, 19.11235809], [84.73458099, 19.11236191], [84.73458099, 19.11208344], [84.73513794, 19.11208344], [84.73513794, 19.11180496], [84.73542023, 19.11181068], [84.73542023, 19.1115284], [84.73568726, 19.1115284], [84.73568726, 19.11096954], [84.73652649, 19.11097145], [84.73652649, 19.11208344], [84.73708344, 19.11208344], [84.73708344, 19.11236191], [84.73792267, 19.11235809], [84.73792267, 19.11264038], [84.73819733, 19.11263847], [84.73819733, 19.1131916], [84.73706818, 19.11320114], [84.73706818, 19.11347961], [84.73680878, 19.11347008], [84.73680878, 19.11458206], [84.73652649, 19.11458206], [84.73652649, 19.1143055], [84.73625183, 19.11431122], [84.73625183, 19.11403275], [84.73596954, 19.11402702], [84.73596954, 19.11569214], [84.73568726, 19.11569023], [84.73568726, 19.1162529], [84.73542023, 19.1162529], [84.73542023, 19.11654091], [84.73513794, 19.11654091], [84.73513794, 19.11680984], [84.73486328, 19.11680984], [84.73486328, 19.11736107], [84.73513794, 19.11736107], [84.73513794, 19.11791992], [84.73542023, 19.11791992], [84.73542023, 19.11763954], [84.73596954, 19.11763954], [84.73596954, 19.11791992], [84.73625183, 19.1179142], [84.73625183, 19.11958313], [84.73596954, 19.11958313], [84.73596954, 19.1198616], [84.73568726, 19.1198597], [84.73568726, 19.12014008], [84.73486328, 19.12014008], [84.73486328, 19.12042046], [84.73432159, 19.12042046], [84.73432159, 19.12014008], [84.73374939, 19.12014008], [84.73374939, 19.12070084], [84.73347473, 19.12069511], [84.73347473, 19.12208366], [84.73374939, 19.12208366], [84.73374939, 19.12236023], [84.73542023, 19.12236023], [84.73542023, 19.12208366], [84.73569489, 19.12208366], [84.73569489, 19.12180519], [84.73708344, 19.12180519], [84.73708344, 19.12208366], [84.73735809, 19.12207985], [84.73735809, 19.12291908], [84.73708344, 19.12291718], [84.73708344, 19.12319374], [84.73680878, 19.12319374], [84.73680878, 19.12347221], [84.73596954, 19.12347031], [84.73596954, 19.12375069], [84.73568726, 19.12375069], [84.73568726, 19.12402916], [84.73542023, 19.12402916], [84.73542023, 19.12486076], [84.73596954, 19.12486076], [84.73596954, 19.12458038], [84.73847198, 19.1245842], [84.73847198, 19.12402725], [84.73874664, 19.12402916], [84.73874664, 19.12375069], [84.73929596, 19.12375069], [84.73929596, 19.12347031], [84.74013519, 19.12347221], [84.74013519, 19.12319374], [84.74097443, 19.12319374], [84.74097443, 19.12291718], [84.74153137, 19.12291908], [84.74153137, 19.12264061], [84.74180603, 19.12264061], [84.74180603, 19.12235069], [84.74236298, 19.12235069], [84.74236298, 19.12264061], [84.74346924, 19.12264061], [84.74346924, 19.12235069], [84.74375153, 19.12236023], [84.74375153, 19.12208366], [84.74402618, 19.12208366], [84.74402618, 19.12152863], [84.74458313, 19.12153053], [84.74458313, 19.12096977], [84.74541473, 19.12097168], [84.74541473, 19.12069511], [84.74569702, 19.12069511], [84.74569702, 19.12097168], [84.74597168, 19.12096977], [84.74597168, 19.12125015], [84.7462616, 19.12125015], [84.7462616, 19.12153053], [84.74652863, 19.12152863], [84.74652863, 19.12319374], [84.74624634, 19.12319374], [84.7462616, 19.12375069], [84.74597168, 19.12375069], [84.74597168, 19.12431145], [84.7454071, 19.12431145], [84.7454071, 19.12486076], [84.74514008, 19.12486076], [84.74514008, 19.12513924], [84.74430847, 19.12513924], [84.74430847, 19.12624931], [84.74402618, 19.12624931], [84.74402618, 19.12708282], [84.74430847, 19.12708092], [84.74430847, 19.12792015], [84.74458313, 19.12791634], [84.74458313, 19.12819481], [84.74485779, 19.1281929], [84.74485779, 19.12848091], [84.74569702, 19.12848091], [84.74569702, 19.12874985], [84.7462616, 19.12874985], [84.7462616, 19.12903023], [84.74652863, 19.12902832], [84.74652863, 19.12930489], [84.74680328, 19.12930489], [84.74680328, 19.12958145], [84.74652863, 19.12958145], [84.74652863, 19.12986374], [84.7462616, 19.12985992], [84.7462616, 19.13070107], [84.74652863, 19.13069534], [84.74652863, 19.13097382], [84.74680328, 19.13097], [84.74680328, 19.13181114], [84.74541473, 19.13180351], [84.74541473, 19.1320858], [84.74485779, 19.13208008], [84.74485779, 19.13236046], [84.74458313, 19.13236046], [84.74458313, 19.13292122], [84.74485779, 19.1329174], [84.74485779, 19.13319588], [84.74514008, 19.13319588], [84.74514008, 19.13347244], [84.7454071, 19.13347054], [84.7454071, 19.13402939], [84.7470932, 19.13402939], [84.7470932, 19.13430977], [84.74764252, 19.13430786], [84.74764252, 19.13458252], [84.74791718, 19.13458061], [84.74791718, 19.13486099], [84.74819183, 19.13486099], [84.74819183, 19.13513947], [84.74847412, 19.13513947], [84.74847412, 19.1356945], [84.74874878, 19.1356945], [84.74874878, 19.13597298], [84.75041962, 19.13597107], [84.75041962, 19.13652992], [84.75013733, 19.13652992], [84.75013733, 19.13708305], [84.74986267, 19.13708115], [84.74986267, 19.14042282], [84.74958038, 19.14042282], [84.74958038, 19.14125061], [84.7492981, 19.14125061], [84.7492981, 19.14180946], [84.74903107, 19.14180565], [84.74903107, 19.14208221], [84.74874878, 19.14208031], [84.74874878, 19.14236069], [84.74819183, 19.14236069], [84.74819183, 19.14264107], [84.74736023, 19.14263916], [84.74736023, 19.14319229], [84.74708557, 19.14319229], [84.74708557, 19.14347458], [84.74514008, 19.14346123], [84.74514008, 19.14375114], [84.74485779, 19.14375114], [84.74485779, 19.14402962], [84.74458313, 19.14402771], [84.74458313, 19.14458466], [84.74375153, 19.14458466], [84.74375153, 19.14430618], [84.74346924, 19.14431], [84.74346924, 19.14402962], [84.74014282, 19.14402962], [84.74014282, 19.14375114], [84.73986053, 19.14375114], [84.73986053, 19.14346123], [84.73958588, 19.14347458], [84.73958588, 19.14291763], [84.73929596, 19.14291954], [84.73929596, 19.14236069], [84.73819733, 19.14236069], [84.73819733, 19.14264107], [84.73792267, 19.14264107], [84.73792267, 19.14291954], [84.73764038, 19.14291763], [84.73764038, 19.14319229], [84.73708344, 19.14319229], [84.73708344, 19.14347458], [84.73680878, 19.14346123], [84.73680878, 19.14375114], [84.73542023, 19.14375114], [84.73542023, 19.14346123], [84.73458099, 19.14347458], [84.73458099, 19.14319229], [84.73430634, 19.14319229], [84.73430634, 19.14291763], [84.7334671, 19.14291954], [84.7334671, 19.14264107], [84.73291779, 19.14264107], [84.73291779, 19.14208031], [84.73236084, 19.14208221], [84.73236084, 19.14180565], [84.73097229, 19.14180946], [84.73097229, 19.1415329], [84.7298584, 19.1415329], [84.7298584, 19.14125061], [84.72957611, 19.14125061], [84.72957611, 19.14097023], [84.72902679, 19.14097023], [84.72902679, 19.14069366], [84.72875214, 19.14069366], [84.72875214, 19.1404171], [84.72846985, 19.14042282], [84.72846985, 19.14014244], [84.72820282, 19.14014244], [84.72820282, 19.13986015], [84.72736359, 19.13986015], [84.72736359, 19.13958359], [84.72680664, 19.13958359], [84.72680664, 19.13986015], [84.72624969, 19.13986015], [84.72624969, 19.14014244], [84.72486115, 19.14014244], [84.72486115, 19.14042282], [84.72374725, 19.14042282], [84.72374725, 19.14014244], [84.7234726, 19.14014244], [84.7234726, 19.13986015], [84.72264099, 19.13986015], [84.72264099, 19.13958359], [84.7223587, 19.13958359], [84.7223587, 19.13930511], [84.72206879, 19.13931274], [84.72206879, 19.1384697], [84.72180176, 19.1384716], [84.72180176, 19.13819504], [84.7215271, 19.13820076], [84.7215271, 19.13791847], [84.72125244, 19.13791847], [84.72125244, 19.13763809], [84.72097015, 19.13763809], [84.72097015, 19.13735962], [84.7206955, 19.13736153], [84.7206955, 19.13680649], [84.72097015, 19.13680077], [84.72097015, 19.13652992], [84.72125244, 19.13652992], [84.72125244, 19.13597107], [84.7215271, 19.13597298], [84.7215271, 19.13513947], [84.72125244, 19.13513947], [84.72125244, 19.13458061], [84.7215271, 19.13458252], [84.7215271, 19.13402748], [84.72180176, 19.13402939], [84.72180176, 19.13347054], [84.72125244, 19.13347244], [84.72125244, 19.13319588], [84.72097015, 19.13319588], [84.72097015, 19.1329174], [84.72041321, 19.13292122], [84.72041321, 19.13264084], [84.72013855, 19.13264084], [84.72013855, 19.13236046], [84.71985626, 19.13236046], [84.71985626, 19.13181114], [84.7195816, 19.13181114], [84.7195816, 19.13125038], [84.71985626, 19.13125038], [84.71985626, 19.13097], [84.7195816, 19.13097382], [84.7195816, 19.13069534], [84.7193222, 19.13070107], [84.7193222, 19.1301403], [84.71903229, 19.1301403], [84.71903229, 19.12985992], [84.7179184, 19.12986374], [84.7179184, 19.12958145], [84.71736145, 19.12958145], [84.71736145, 19.12930489], [84.71708679, 19.12930489], [84.71708679, 19.12902832], [84.71679688, 19.12903023], [84.71679688, 19.12874985], [84.71624756, 19.12874985], [84.71624756, 19.12847137], [84.71569824, 19.12848091], [84.71569061, 19.1281929], [84.71541595, 19.12819481], [84.71541595, 19.12791634], [84.7140274, 19.12792015], [84.7140274, 19.12763977], [84.71375275, 19.12763977], [84.71375275, 19.12735939], [84.71347046, 19.1273613], [84.71347046, 19.12708282], [84.7131958, 19.12708282], [84.7131958, 19.12652779], [84.71289825, 19.1265316], [84.71289825, 19.12624931], [84.71263885, 19.12624931], [84.71263885, 19.12597084], [84.7123642, 19.12597275], [84.7123642, 19.1254158], [84.71208191, 19.12542152], [84.71208191, 19.12486076], [84.71180725, 19.12486076], [84.71180725, 19.12458038], [84.71152496, 19.1245842], [84.71152496, 19.12347221], [84.71097565, 19.12347221], [84.71097565, 19.12319374], [84.71069336, 19.12319374], [84.71069336, 19.12291718], [84.7104187, 19.12291908], [84.7104187, 19.12235069], [84.70847321, 19.12236023], [84.70847321, 19.12208366], [84.70680237, 19.12208366], [84.70680237, 19.12180519], [84.70652771, 19.12181091], [84.70652771, 19.12153053], [84.70569611, 19.12153053], [84.70569611, 19.12096977], [84.70541382, 19.12097168], [84.70541382, 19.12041664], [84.70402527, 19.12041664], [84.70402527, 19.12097168], [84.70347595, 19.12097168], [84.70347595, 19.12069511], [84.70318604, 19.12070084], [84.70318604, 19.1198597], [84.70291901, 19.1198616], [84.70291901, 19.11874962], [84.70318604, 19.11874962], [84.70318604, 19.11763954], [84.70347595, 19.11763954], [84.70347595, 19.11680984], [84.70375061, 19.11680984], [84.70375061, 19.1162529], [84.7040329, 19.1162529], [84.7040329, 19.11597061], [84.70430756, 19.11597443], [84.70430756, 19.11458206], [84.7048645, 19.11458206], [84.7048645, 19.1143055], [84.70540619, 19.11431122], [84.70540619, 19.11403275], [84.70569611, 19.11403275], [84.70569611, 19.11375046], [84.70652771, 19.11375046], [84.70652771, 19.11320114], [84.70597076, 19.1131916], [84.70597076, 19.11124992], [84.70625305, 19.11124992], [84.70625305, 19.11096954], [84.70652771, 19.11097145], [84.70652771, 19.11069489], [84.70680237, 19.11069489], [84.70680237, 19.11013985], [84.70709229, 19.11013985], [84.70709229, 19.10902977], [84.70680237, 19.10902977], [84.70680237, 19.10874939], [84.70652771, 19.10874939], [84.70652771, 19.10847092], [84.70680237, 19.10847282], [84.70680237, 19.10819435], [84.70708466, 19.10819435], [84.70708466, 19.10791779], [84.70791626, 19.10791779], [84.70791626, 19.10819435], [84.71013641, 19.10819435], [84.71013641, 19.10847282], [84.7104187, 19.10847282], [84.7104187, 19.10819435], [84.71097565, 19.10819435], [84.71097565, 19.10763931], [84.71125031, 19.10764122], [84.71125031, 19.1073494], [84.71152496, 19.10736084], [84.71152496, 19.10708427], [84.71125031, 19.10708427], [84.71125031, 19.10652733], [84.71153259, 19.10653114], [84.71153259, 19.10625076], [84.71180725, 19.10625076], [84.71180725, 19.10514069], [84.71208191, 19.10514069], [84.71208191, 19.10486031], [84.71235657, 19.10486031], [84.71235657, 19.10457993], [84.71291351, 19.10458565], [84.71291351, 19.10375023], [84.71318817, 19.10375023], [84.71318817, 19.10320091], [84.71347046, 19.10320091], [84.71347046, 19.10292053], [84.71375275, 19.10292053], [84.71375275, 19.10042191], [84.7140274, 19.10042191], [84.7140274, 19.09958076], [84.71430206, 19.09958267], [84.71430206, 19.09930611], [84.71457672, 19.09931183], [84.71457672, 19.09903145], [84.71626282, 19.09903145], [84.71626282, 19.09874916], [84.71652985, 19.09874916], [84.71652985, 19.09792137], [84.71679688, 19.09792137], [84.71679688, 19.09763908], [84.71708679, 19.09763908], [84.71708679, 19.09736061], [84.71763611, 19.09736061], [84.71763611, 19.09708023], [84.71875, 19.09708405], [84.71875, 19.09680557], [84.71903229, 19.09680748], [84.71903229, 19.09653091], [84.71875, 19.09653091], [84.71875, 19.09625053], [84.71903229, 19.09625053], [84.71903229, 19.09584427], [84.71185303, 19.1000309], [84.69754791, 19.10881805], [84.69832611, 19.1103096], [84.69776917, 19.1156311], [84.69381714, 19.11952019], [84.69391632, 19.12155151], [84.69731903, 19.1251297], [84.70648193, 19.14356041], [84.70522308, 19.1490097], [84.7020874, 19.15114975], [84.69756317, 19.15029144], [84.69213867, 19.15170097], [84.68141174, 19.14974976], [84.67807007, 19.15346909], [84.67333221, 19.15689087], [84.66929626, 19.15568161], [84.66501617, 19.15673065], [84.66326904, 19.14748001], [84.6654129, 19.14470291], [84.66590118, 19.13527107], [84.66451263, 19.12815094], [84.66117096, 19.1218605], [84.65731812, 19.12138939], [84.65342712, 19.12290955], [84.64729309, 19.12037086], [84.64170837, 19.12478828], [84.64037323, 19.12223816], [84.62931824, 19.12070084], [84.62554932, 19.11827087], [84.60939789, 19.11745071], [84.59464264, 19.12354851], [84.59184265, 19.12384033], [84.59168243, 19.12112045], [84.59577179, 19.11520958], [84.60293579, 19.09657097], [84.6055603, 19.09263039], [84.60962677, 19.09089279], [84.6144104, 19.09231758], [84.61678314, 19.09000015], [84.61656952, 19.08520126], [84.61982727, 19.07650948], [84.62444305, 19.07442093], [84.63144684, 19.07262039], [84.63360596, 19.07463837], [84.63474274, 19.07868958], [84.64460754, 19.08445168], [84.64871216, 19.08419991], [84.65416718, 19.08101273], [84.65962219, 19.07093048], [84.66458893, 19.06629181], [84.66320038, 19.06445122], [84.65901184, 19.06364822], [84.65453339, 19.05231094], [84.64772797, 19.0560894], [84.63683319, 19.05714989], [84.63437653, 19.05554008], [84.63005829, 19.04959106], [84.62608337, 19.05029106], [84.62541199, 19.05278015], [84.62329102, 19.05566025], [84.61271667, 19.05483055], [84.61152649, 19.05373001], [84.61235809, 19.04973984], [84.61418915, 19.0467205], [84.60946655, 19.04673958], [84.60756683, 19.04540825], [84.60048676, 19.03293037], [84.59697723, 19.01974106], [84.59011841, 19.01338005], [84.58769226, 19.01299095], [84.57813263, 19.01890182], [84.57531738, 19.02719116], [84.57364655, 19.03511047], [84.57509613, 19.03753853], [84.57811737, 19.06212807], [84.57644653, 19.06456184], [84.57060242, 19.06041145], [84.56852722, 19.06064034], [84.56797028, 19.06347084], [84.56613922, 19.06503868], [84.5597229, 19.05956078], [84.5535965, 19.04740906], [84.54772186, 19.04609108], [84.53481293, 19.04536057], [84.53147125, 19.0441494], [84.52715302, 19.03871918], [84.50991821, 19.03746033], [84.5071106, 19.03544807], [84.5030899, 19.02926254], [84.49777985, 19.02487946], [84.48938751, 19.02095032], [84.48206329, 19.00990868], [84.47782898, 19.0078907], [84.47551727, 18.99603271], [84.47569275, 18.99173927], [84.47306061, 18.98264122], [84.4716568, 18.98122025], [84.46282959, 18.98328972], [84.45218658, 18.98833084], [84.44815063, 18.99173927], [84.44406128, 18.99455833], [84.43739319, 18.99745941], [84.43297577, 19.00185966], [84.42980194, 19.00118065], [84.42218781, 19.00853157], [84.42002106, 19.01251984], [84.41513062, 19.0138607], [84.41464996, 19.01235962], [84.4154129, 19.00813293], [84.41803741, 19.00498962], [84.42003632, 19.00084114], [84.42526245, 18.99534035], [84.42610931, 18.99176979], [84.42555237, 18.989151], [84.42640686, 18.98397064], [84.42796326, 18.98264122], [84.4347229, 18.97682953], [84.44064331, 18.96693039], [84.43772888, 18.96570969], [84.43454742, 18.96315956], [84.42030334, 18.94935989], [84.41559601, 18.93803978], [84.41713715, 18.93330193], [84.41998291, 18.92971039], [84.42938995, 18.91368294], [84.42032623, 18.90487099], [84.41796875, 18.90065956], [84.40956879, 18.90810013], [84.40615082, 18.9061203], [84.40769958, 18.90112114], [84.41072083, 18.89825821], [84.41208649, 18.89393997], [84.40981293, 18.89063072], [84.39782715, 18.88611984], [84.39396667, 18.88586998], [84.38687134, 18.88986969], [84.37845612, 18.89324188], [84.37406921, 18.89402962], [84.36976624, 18.89581108], [84.3653183, 18.89625931], [84.36490631, 18.8932209], [84.36767578, 18.88932991], [84.37422943, 18.8888607], [84.37903595, 18.88546944], [84.38609314, 18.88302994], [84.38762665, 18.87766838], [84.38622284, 18.87170982], [84.38323212, 18.86927986], [84.37808228, 18.87409973], [84.37406921, 18.87649918], [84.37135315, 18.8754406], [84.35473633, 18.88293076], [84.35144806, 18.88319969], [84.35183716, 18.87779045], [84.35382843, 18.87506294], [84.35962677, 18.87190056], [84.3613205, 18.87268066], [84.36624908, 18.87170982], [84.37156677, 18.86721992], [84.37146759, 18.86338234], [84.36933899, 18.85897064], [84.3624115, 18.85106087], [84.3583374, 18.85134125], [84.35521698, 18.85264015], [84.35411835, 18.85149956], [84.35146332, 18.85090065], [84.3469696, 18.85997963], [84.34438324, 18.86276245], [84.33979034, 18.86592102], [84.33602142, 18.86671066], [84.33442688, 18.86384964], [84.33413696, 18.85799026], [84.33413696, 18.85156059], [84.33598328, 18.84142113], [84.3380661, 18.83621979], [84.34435272, 18.8327198], [84.34516907, 18.82678032], [84.3442688, 18.8227005], [84.34243011, 18.82150841], [84.34075928, 18.81825066], [84.34410095, 18.81194115], [84.32932281, 18.80899811], [84.32952881, 18.8045311], [84.33358765, 18.79505157], [84.33222198, 18.79202271], [84.3269577, 18.78967285], [84.3157196, 18.78617096], [84.31292725, 18.78218079], [84.31249237, 18.77919006], [84.30885315, 18.77841949], [84.30716705, 18.78166008], [84.30432129, 18.78071976], [84.30036926, 18.78174019], [84.28392029, 18.79082108], [84.27854919, 18.78968048], [84.27533722, 18.78718185], [84.27321625, 18.78248978], [84.26818848, 18.78030968], [84.26422119, 18.78051949], [84.25888824, 18.77482986], [84.25218964, 18.77248192], [84.24603271, 18.7734108], [84.23116302, 18.78012085], [84.23069, 18.78564072], [84.22698975, 18.78716087], [84.22429657, 18.78426933], [84.22145844, 18.78647995], [84.21671295, 18.78728104], [84.2038269, 18.78264046], [84.19033813, 18.77673912], [84.18651581, 18.77960014], [84.18151093, 18.77752113], [84.1798172, 18.76897049], [84.16703033, 18.77013969], [84.16262817, 18.76856995], [84.15818787, 18.76918983], [84.16027069, 18.77231979], [84.15934753, 18.77503967], [84.15493011, 18.77601051], [84.15136719, 18.77576065], [84.14811707, 18.77176094], [84.14042664, 18.76769066], [84.13497925, 18.76678848], [84.13136292, 18.76480293], [84.12793732, 18.76126862], [84.12948608, 18.75286293], [84.12294006, 18.74826813], [84.118927, 18.75303078], [84.11406708, 18.7551403], [84.10758972, 18.7548008], [84.10072327, 18.75267982], [84.09163666, 18.74523926], [84.08878326, 18.74711037], [84.08557892, 18.74518013], [84.08177948, 18.74464035], [84.07933044, 18.74611092], [84.07788086, 18.74888039], [84.06989288, 18.74975967], [84.06577301, 18.75169945], [84.06046295, 18.76267052], [84.05860901, 18.76810074], [84.05355835, 18.76836967], [84.04920197, 18.77065086], [84.04804993, 18.77440262], [84.04972076, 18.77730942], [84.04760742, 18.77987289], [84.04794312, 18.78347969], [84.03871918, 18.78742981], [84.0342865, 18.79012108], [84.03077698, 18.79544067], [84.03071594, 18.80027962], [84.02706146, 18.80220032], [84.02372742, 18.80115128], [84.02231598, 18.79862976], [84.01966095, 18.79762268], [84.01586914, 18.80141068], [84.01249695, 18.80063057], [84.00739288, 18.80421066], [83.99997711, 18.8047905], [83.991539, 18.8046627], [83.98232269, 18.80001068], [83.96938324, 18.80382919], [83.9640274, 18.80410957], [83.95561218, 18.80306053], [83.95121002, 18.8000412], [83.94902039, 18.79704094], [83.94368744, 18.79628754], [83.93978882, 18.79660034], [83.93657684, 18.79920006], [83.93572235, 18.8031292], [83.93358612, 18.80685806], [83.9263916, 18.80656052], [83.9226532, 18.80853271], [83.92059326, 18.81157112], [83.90775299, 18.81638908], [83.90197754, 18.81692123], [83.89855194, 18.81644058], [83.89547729, 18.81487846], [83.89064026, 18.80686951], [83.88687897, 18.80540848], [83.88535309, 18.81004143], [83.88463593, 18.8178196], [83.88323975, 18.8196907], [83.87391663, 18.8177681], [83.87017822, 18.81842995], [83.86686707, 18.82345009], [83.86434174, 18.83904076], [83.85906982, 18.84301186], [83.84797668, 18.8476181], [83.84366608, 18.85140038], [83.83709717, 18.86470985], [83.83600616, 18.8691082], [83.83669281, 18.87272072], [83.8423233, 18.88824081], [83.84163666, 18.89763069], [83.840271, 18.90406036], [83.83772278, 18.90860939], [83.83487701, 18.90929985], [83.82305145, 18.90546036], [83.81845093, 18.90711975], [83.81693268, 18.90940285], [83.82116699, 18.92196083], [83.81890106, 18.92609978], [83.814888, 18.93003845], [83.8134079, 18.9335804], [83.81606293, 18.9486599], [83.81476593, 18.95317841], [83.81063843, 18.9648304], [83.80809021, 18.96840286], [83.80253601, 18.98180962], [83.79116821, 18.99235916], [83.78894806, 18.99833107], [83.78830719, 19.00781059], [83.78704071, 19.00836945], [83.7859726, 19.00878906], [83.78486633, 19.00909042], [83.78375244, 19.00933075], [83.78263855, 19.00957108], [83.78148651, 19.00979042], [83.78037262, 19.0099411], [83.77887726, 19.01000977], [83.77774048, 19.00988007], [83.77664948, 19.00951958], [83.77565002, 19.00896072], [83.77474213, 19.00824928], [83.77392578, 19.00745964], [83.77320099, 19.00658989], [83.77259827, 19.00566101], [83.77204895, 19.0046711], [83.7715683, 19.00366974], [83.77111816, 19.00263977], [83.7706604, 19.0016098], [83.77021027, 19.00059128], [83.76941681, 18.99977112], [83.76850128, 18.99908066], [83.76747894, 18.99842834], [83.7664032, 18.99795914], [83.7652359, 18.99760056], [83.76405334, 18.99731064], [83.76288605, 18.99705124], [83.76171112, 18.99677849], [83.76056671, 18.9964695], [83.75946808, 18.99605942], [83.75845337, 18.99547005], [83.75778961, 18.99455833], [83.75695801, 18.99390984], [83.75582886, 18.99361038], [83.75469208, 18.99337006], [83.75354767, 18.99316978], [83.75242615, 18.99333191], [83.75128174, 18.99328041], [83.75061798, 18.99241829], [83.74923706, 18.99067116], [83.74108124, 18.98389053], [83.73956299, 18.97844124], [83.74172211, 18.96705818], [83.74597168, 18.9632206], [83.74900055, 18.95844078], [83.74836731, 18.95137024], [83.75036621, 18.94437027], [83.75520325, 18.94202995], [83.76148224, 18.94460106], [83.76525116, 18.93642044], [83.76986694, 18.93297005], [83.77715302, 18.9190712], [83.78006744, 18.90772057], [83.77739716, 18.90439987], [83.77127075, 18.90130043], [83.77050018, 18.90159035], [83.76750183, 18.90236282], [83.7628479, 18.90653992], [83.75614929, 18.91669083], [83.74582672, 18.91817284], [83.74214935, 18.92313957], [83.74140167, 18.93029022], [83.73992157, 18.93406105], [83.73649597, 18.93897057], [83.73002625, 18.9601593], [83.72746277, 18.96607971], [83.7263031, 18.97556114], [83.71689606, 18.98253822], [83.71140289, 18.98495102], [83.70880127, 18.9838028], [83.70574188, 18.98524094], [83.70484924, 18.99200821], [83.70469666, 18.99248123], [83.70436096, 18.99530983], [83.70500183, 18.99946976], [83.70941925, 19.00195122], [83.71478271, 19.00213051], [83.71984863, 19.00428963], [83.72325134, 19.01189995], [83.72128296, 19.0134182], [83.71682739, 19.01444817], [83.69983673, 19.01503181], [83.69702148, 19.01647949], [83.69415283, 19.02114105], [83.68438721, 19.04393005], [83.67637634, 19.05245018], [83.66673279, 19.06446075], [83.66261292, 19.06649017], [83.65969849, 19.0697403], [83.65685272, 19.07493973], [83.65809631, 19.08210945], [83.65748596, 19.08777237], [83.65026855, 19.10009956], [83.6479187, 19.10225105], [83.647789, 19.10594177], [83.64588165, 19.10873032], [83.64472961, 19.11329079], [83.64627075, 19.11449814], [83.64974976, 19.11482048], [83.65072632, 19.11840057], [83.64943695, 19.12187958], [83.64556122, 19.12310028], [83.63331604, 19.1244297], [83.62983704, 19.12699127], [83.62844086, 19.13150024], [83.63018799, 19.14479065], [83.62850952, 19.14974022], [83.62328339, 19.15363121], [83.62116241, 19.15192032], [83.62023926, 19.14862823], [83.62271881, 19.14468765], [83.619133, 19.14188194], [83.61408997, 19.13381958], [83.61060333, 19.13093758], [83.60521698, 19.13103294], [83.60051727, 19.12770081], [83.59429932, 19.12033081], [83.59365082, 19.11548996], [83.59429932, 19.11058044], [83.59677887, 19.10519981], [83.60440063, 19.09287071], [83.60441589, 19.08818054], [83.59986115, 19.08480263], [83.59320831, 19.08489037], [83.58763123, 19.08307076], [83.58444977, 19.07973099], [83.5821991, 19.07563972], [83.58178711, 19.06277275], [83.58078003, 19.05514908], [83.57876587, 19.04978943], [83.56735992, 19.05225945], [83.56105042, 19.05038834], [83.55766296, 19.05138016], [83.556427, 19.05583954], [83.55710602, 19.05998993], [83.56038666, 19.06396103], [83.56067657, 19.06622124], [83.55497742, 19.07813072], [83.55149078, 19.07785034], [83.5464325, 19.07382965], [83.54485321, 19.06940269], [83.54486847, 19.06208038], [83.55148315, 19.05038071], [83.5522995, 19.04718971], [83.54772949, 19.04496956], [83.54277802, 19.03684044], [83.53578949, 19.03034973], [83.53482819, 19.02861977], [83.53309631, 19.01938248], [83.53311157, 19.01246071], [83.53138733, 19.00542068], [83.51529694, 19.00490952], [83.50460052, 19.01009941], [83.49539948, 19.01109123], [83.49292755, 19.01803017], [83.49263, 19.02398109], [83.49355316, 19.02680016], [83.49931335, 19.02708054], [83.50392914, 19.02620125], [83.50817871, 19.02197075], [83.51367188, 19.02478027], [83.51322937, 19.03032112], [83.51008606, 19.03617287], [83.50979614, 19.04008102], [83.51074982, 19.04800034], [83.50847626, 19.0499115], [83.50617981, 19.05430984], [83.50538635, 19.06477165], [83.50287628, 19.06466103], [83.50036621, 19.06208038], [83.49633026, 19.05550957], [83.49362946, 19.05308914], [83.49249268, 19.05495071], [83.48043823, 19.06648064], [83.47817993, 19.07022095], [83.47698975, 19.07533073], [83.47323608, 19.0777626], [83.47202301, 19.07274055], [83.47027588, 19.07032013], [83.46746826, 19.06987953], [83.46382904, 19.0714016], [83.45939636, 19.06967163], [83.45826721, 19.06713295], [83.45913696, 19.06348991], [83.45736694, 19.0598011], [83.45670319, 19.05611038], [83.46327209, 19.05260086], [83.46279907, 19.04395103], [83.46543884, 19.03619003], [83.47735596, 19.02551842], [83.47796631, 19.02119064], [83.47511292, 19.01152992], [83.47663879, 19.00407028], [83.47460175, 19.00031281], [83.4718399, 18.99897957], [83.46750641, 18.99891853], [83.45848083, 19.00209808], [83.45327759, 19.00246048], [83.45017242, 19.00188828], [83.44851685, 18.99963188], [83.44822693, 18.99594116], [83.44908905, 18.99261093], [83.45022583, 18.98242188], [83.4577179, 18.98250008], [83.46029663, 18.98077965], [83.45831299, 18.97247124], [83.45894623, 18.97044945], [83.46147156, 18.9679203], [83.46224213, 18.96359062], [83.46227264, 18.95922089], [83.45548248, 18.94557953], [83.45120239, 18.94445992], [83.44684601, 18.94564819], [83.44267273, 18.94774055], [83.44001007, 18.95022011], [83.43647766, 18.95787811], [83.43292236, 18.96139908], [83.4148407, 18.97787285], [83.40878296, 18.97989082], [83.41142273, 18.98871994], [83.41057587, 18.99261093], [83.40885162, 18.99619102], [83.4068985, 18.99508095], [83.4046402, 18.99320984], [83.40231323, 18.99516106], [83.40142059, 18.99638176], [83.39605713, 18.99583054], [83.39295959, 18.99912834], [83.3887558, 19.00001907], [83.38471985, 18.99727249], [83.37719727, 18.99472046], [83.36747742, 18.99361992], [83.36232758, 18.99473], [83.35800934, 19.00613976], [83.35498047, 19.00938988], [83.34633636, 19.0098896], [83.34091187, 19.0091629], [83.3349762, 19.00671959], [83.33271027, 18.99983978], [83.33067322, 18.99842834], [83.33010101, 18.99695969], [83.33075714, 18.99257088], [83.33120728, 18.99007034], [83.32917786, 18.98818016], [83.32537842, 18.98880959], [83.31643677, 18.99040031], [83.30783844, 18.99094963], [83.30526733, 18.98968124], [83.30432892, 18.98698997], [83.30774689, 18.98324966], [83.30914307, 18.98035049], [83.30961609, 18.9768219], [83.31334686, 18.96663094], [83.31980896, 18.96133041], [83.32055664, 18.96103096], [83.32556152, 18.95897102], [83.32691956, 18.95734024], [83.32565308, 18.95292282], [83.32601166, 18.95016289], [83.32704163, 18.94790077], [83.32888794, 18.94682121], [83.33104706, 18.94581032], [83.3324585, 18.94337082], [83.33302307, 18.93931961], [83.33113098, 18.93763924], [83.32119751, 18.93602943], [83.3184967, 18.93362045], [83.31887817, 18.92843819], [83.31991577, 18.92581749], [83.32202911, 18.9232502], [83.32901001, 18.91690826], [83.33454132, 18.91582108], [83.33905792, 18.91620064], [83.34136963, 18.91839981], [83.33957672, 18.92620087], [83.33953857, 18.9294796], [83.33952332, 18.93191147], [83.33972931, 18.93275261], [83.33983612, 18.93321991], [83.34326172, 18.93516159], [83.34480286, 18.94524956], [83.34501648, 18.95630074], [83.34575653, 18.95709991], [83.34903717, 18.95609093], [83.35440826, 18.95445061], [83.35890198, 18.95471191], [83.36022949, 18.95389938], [83.36106873, 18.95340157], [83.36084747, 18.94811058], [83.36389923, 18.93793106], [83.36741638, 18.93349075], [83.38022614, 18.92328262], [83.37966156, 18.92152023], [83.37634277, 18.91777039], [83.37384033, 18.91679192], [83.3710022, 18.91708946], [83.36406708, 18.92278862], [83.36276245, 18.93007088], [83.35523987, 18.93303108], [83.34902954, 18.9338398], [83.34792328, 18.93214035], [83.34661102, 18.92687035], [83.34768677, 18.92098808], [83.35016632, 18.91592979], [83.35649872, 18.90480995], [83.35777283, 18.9036808], [83.36052704, 18.90117073], [83.36631012, 18.9004612], [83.36715698, 18.90036011], [83.37684631, 18.90246964], [83.3809967, 18.90182114], [83.38391113, 18.89969063], [83.38326263, 18.89723969], [83.37444305, 18.89194107], [83.37248993, 18.88983917], [83.37390137, 18.88591194], [83.37890625, 18.88027954], [83.38568115, 18.87549019], [83.38539124, 18.87326241], [83.38780975, 18.87103081], [83.39425659, 18.8682003], [83.40177917, 18.86707115], [83.40432739, 18.86598015], [83.40585327, 18.86532974], [83.41133881, 18.85934067], [83.41073608, 18.85676193], [83.40875244, 18.85445023], [83.40680695, 18.85367966], [83.39985657, 18.85365105], [83.39787292, 18.85259056], [83.39694214, 18.84921074], [83.39871216, 18.83352852], [83.39630127, 18.83070946], [83.38648987, 18.82576942], [83.38313293, 18.82607079], [83.3763504, 18.82195091], [83.37283325, 18.82121086], [83.36226654, 18.83210945], [83.36032104, 18.83204079], [83.35887909, 18.83200073], [83.35349274, 18.82748985], [83.35011292, 18.82163811], [83.35999298, 18.80735016], [83.36022949, 18.80447006], [83.35848236, 18.80179977], [83.35629272, 18.8001194], [83.3524704, 18.80018997], [83.34780884, 18.80125809], [83.34429169, 18.80293083], [83.34073639, 18.8035202], [83.33927917, 18.80309105], [83.33812714, 18.80035019], [83.33761597, 18.79570007], [83.33687592, 18.79465294], [83.33587646, 18.79321289], [83.33333588, 18.7926712], [83.32978821, 18.79372978], [83.32614136, 18.79482079], [83.32302094, 18.79828072], [83.31826019, 18.79584122], [83.31404114, 18.79580116], [83.30422211, 18.79887009], [83.30036926, 18.79791069], [83.29210663, 18.79253006], [83.27950287, 18.78960037], [83.2752533, 18.78536987], [83.26992035, 18.77528763], [83.26914978, 18.77075958], [83.27124786, 18.76732063], [83.27171326, 18.76317978], [83.26991272, 18.75980949], [83.26609802, 18.75700951], [83.2593689, 18.75760078], [83.25541687, 18.75881958], [83.24508667, 18.75808907], [83.23956299, 18.75878143], [83.22931671, 18.76414108], [83.22651672, 18.76490021], [83.22271729, 18.76593018], [83.22103119, 18.76587105], [83.21939087, 18.76581955], [83.21707916, 18.76356125], [83.21733093, 18.75895119], [83.22189331, 18.75202179], [83.22268677, 18.74861908], [83.2230072, 18.74798012], [83.22235107, 18.74505043], [83.22033691, 18.74204826], [83.21446228, 18.73719978], [83.21363831, 18.73602104], [83.2125473, 18.7344799], [83.20918274, 18.72454071], [83.20677948, 18.71749115], [83.20506287, 18.71586037], [83.20332336, 18.7195797], [83.20366669, 18.72350121], [83.20641327, 18.72742081], [83.20633698, 18.72803116], [83.20626068, 18.7287426], [83.2024231, 18.73254967], [83.20188904, 18.73613167], [83.20342255, 18.74035263], [83.20170593, 18.74222946], [83.19181824, 18.74178123], [83.1853714, 18.74414253], [83.18080139, 18.74825096], [83.17701721, 18.75440979], [83.17394257, 18.75676918], [83.16854858, 18.75906944], [83.15622711, 18.75731087], [83.15083313, 18.75868988], [83.14686584, 18.76317978], [83.14491272, 18.76690102], [83.13884735, 18.77113914], [83.13295746, 18.77244949], [83.11580658, 18.76208115], [83.11219025, 18.7582798], [83.11752319, 18.75048065], [83.11650085, 18.74797058], [83.10600281, 18.73849106], [83.09921265, 18.72689056], [83.09546661, 18.72309113], [83.09259033, 18.7217617], [83.09079742, 18.71925926], [83.08960724, 18.71627045], [83.0880661, 18.71240044], [83.08574677, 18.70998001], [83.07788086, 18.70533943], [83.07073212, 18.69719124], [83.0690918, 18.69405174], [83.06987762, 18.69188118], [83.07080841, 18.68930054], [83.05584717, 18.66714096], [83.05146027, 18.6632309], [83.05097198, 18.65415955], [83.03616333, 18.64768982], [83.0226059, 18.64435959], [83.01154327, 18.63903046], [83.0096817, 18.63652992], [83.00948334, 18.63354111], [83.00934601, 18.63148117], [83.01132202, 18.62771034], [83.01461029, 18.62626076], [83.01737976, 18.62339973], [83.02126312, 18.61045074], [83.02030182, 18.60541153], [83.00948334, 18.5914402], [83.00804138, 18.58842087], [83.01586914, 18.58477974], [83.02770233, 18.58227158], [83.03114319, 18.58358955], [83.03781891, 18.58871269], [83.03970337, 18.59207916], [83.04065704, 18.59526253], [83.04110718, 18.59673119], [83.04891968, 18.59526253], [83.04946899, 18.59486961], [83.05208588, 18.59305954], [83.05297852, 18.58993912], [83.05394745, 18.58646965], [83.0511322, 18.58307076], [83.0447464, 18.57817078], [83.04203796, 18.57730293], [83.04171753, 18.5773201], [83.03650665, 18.57757187], [83.03376007, 18.57571983], [83.03114319, 18.5717907], [83.0268631, 18.56796074], [83.02545929, 18.56430054], [83.03370667, 18.55829048], [83.03247833, 18.54788971], [83.04023743, 18.54489136], [83.04509735, 18.53932953], [83.05117798, 18.5349102], [83.05414581, 18.53479958], [83.05735779, 18.53469086], [83.0714798, 18.54249191], [83.08705139, 18.54105949], [83.08933258, 18.53791046], [83.08850861, 18.53276062], [83.08230591, 18.52717018], [83.07315826, 18.51473999], [83.06881714, 18.50202942], [83.06511688, 18.4975605], [83.06035614, 18.49442101], [83.05517578, 18.48812294], [83.05179596, 18.47748947], [83.04384613, 18.47211075], [83.03701782, 18.46313095], [83.03414917, 18.46076965], [83.02672577, 18.45692062], [83.02455902, 18.45369911], [83.01644897, 18.44767952], [83.01541138, 18.4444294], [83.01803589, 18.44040108], [83.02484131, 18.43666077], [83.032341, 18.43618965], [83.037323, 18.43482971], [83.03900909, 18.43204117], [83.03819275, 18.42671013], [83.03330231, 18.42333984], [83.03555298, 18.42007065], [83.03743744, 18.41894913], [83.04261017, 18.41829109], [83.0485611, 18.42486], [83.05825806, 18.42905998], [83.05982971, 18.42863274], [83.061203, 18.42394066], [83.06208801, 18.42088127], [83.06062317, 18.41924286], [83.06046295, 18.41348839], [83.06035614, 18.41337967], [83.05531311, 18.40811157], [83.05581665, 18.40436935], [83.05903625, 18.3990097], [83.06373596, 18.39570999], [83.06582642, 18.39315987], [83.0664978, 18.3922596], [83.06582642, 18.38940048], [83.05619812, 18.37726021], [83.0533905, 18.37529945], [83.03952026, 18.37008095], [83.03697968, 18.36984253], [83.03188324, 18.3732605], [83.02375793, 18.37644958], [83.02005005, 18.38348007], [83.0171814, 18.3845005], [83.01161194, 18.37821007], [83.00348663, 18.3769207], [82.99711609, 18.37486076], [82.99286652, 18.37482071], [82.99196625, 18.37499809], [82.98761749, 18.36950111], [82.98610687, 18.36590195], [82.9812088, 18.36581993], [82.9784317, 18.36098862], [82.97644806, 18.3549118], [82.96878052, 18.35758018], [82.95979309, 18.35724068], [82.95597076, 18.35581017], [82.95204926, 18.35434914], [82.94816589, 18.35206032], [82.94550323, 18.35046959], [82.93268585, 18.35136986], [82.9276123, 18.36098862], [82.9200592, 18.3597393], [82.91513062, 18.35639954], [82.91166687, 18.35737991], [82.90838623, 18.35943031], [82.90274811, 18.35591125], [82.89852142, 18.35930061], [82.89186096, 18.36688042], [82.88490295, 18.37862015], [82.89095306, 18.39221954], [82.89077759, 18.39859962], [82.88835907, 18.40625954], [82.88461304, 18.41275978], [82.87935638, 18.41464043], [82.87706757, 18.4118309], [82.87001038, 18.40620041], [82.86296844, 18.40792084], [82.85597992, 18.41080093], [82.84863281, 18.41500854], [82.84490967, 18.40977287], [82.83978271, 18.41177177], [82.83698273, 18.4142704], [82.83634186, 18.41954041], [82.83576965, 18.42423058], [82.83014679, 18.42612076], [82.82417297, 18.4299202], [82.81874847, 18.43337059], [82.81835938, 18.43852997], [82.79917145, 18.43940163], [82.79197693, 18.4331398], [82.78710938, 18.42674065], [82.77622223, 18.41969109], [82.77620697, 18.41551971], [82.77845764, 18.40947914], [82.78160858, 18.4042511], [82.78118134, 18.3994503], [82.78739166, 18.39982033], [82.79329681, 18.39496994], [82.78748322, 18.3902092], [82.78675842, 18.38458061], [82.78761292, 18.37816048], [82.78096771, 18.37252045], [82.77790833, 18.37092018], [82.78421783, 18.35415077], [82.7714386, 18.33967972], [82.7670517, 18.33107948], [82.76184845, 18.32781029], [82.75849915, 18.32718086], [82.7544632, 18.32982063], [82.7510376, 18.3283329], [82.7506485, 18.32329941], [82.74642944, 18.31985092], [82.73781586, 18.31990051], [82.73280334, 18.3178997], [82.73432922, 18.3132515], [82.72531128, 18.31157112], [82.71726227, 18.31482124], [82.71090698, 18.31282043], [82.70670319, 18.31063271], [82.7025528, 18.30846977], [82.70169067, 18.30484009], [82.70050049, 18.29978943], [82.69809723, 18.29627037], [82.69374084, 18.29733086], [82.69032288, 18.29706955], [82.68177795, 18.29277992], [82.67539978, 18.29236984], [82.6725769, 18.29220009], [82.66493988, 18.2906208], [82.65883636, 18.28660965], [82.65648651, 18.27880096], [82.65222931, 18.2721405], [82.64910889, 18.26383972], [82.64485931, 18.25707817], [82.64758301, 18.2447319], [82.64530945, 18.24044991], [82.63716888, 18.23493004], [82.63165283, 18.22853088], [82.6288681, 18.22866058], [82.62687683, 18.22874069], [82.62039185, 18.23637009], [82.6164093, 18.23812103], [82.61341858, 18.23942947], [82.61103058, 18.24384117], [82.61181641, 18.24651146], [82.60948181, 18.24925041], [82.60076904, 18.25201988], [82.5982666, 18.25447273], [82.58920288, 18.25672913], [82.58866882, 18.26211929], [82.58724976, 18.2657795], [82.58547211, 18.26612091], [82.58318329, 18.26655006], [82.58074188, 18.27009964], [82.58428192, 18.27322006], [82.58846283, 18.27504921], [82.58840179, 18.27833939], [82.58722687, 18.27943993], [82.58558655, 18.28096008], [82.58757782, 18.2847805], [82.59031677, 18.28778076], [82.59095001, 18.29195976], [82.58783722, 18.3020401], [82.58270264, 18.30080032], [82.58107758, 18.30093956], [82.57978058, 18.30104065], [82.5764389, 18.30681038], [82.57805634, 18.30935097], [82.58325195, 18.3114109], [82.58596039, 18.3159008], [82.58863831, 18.31847954], [82.58966827, 18.3194828], [82.59229279, 18.31792068], [82.59568787, 18.3159008], [82.60214233, 18.31726074], [82.60382843, 18.32037163], [82.60031891, 18.33076096], [82.59757996, 18.33361816], [82.59651184, 18.3408699], [82.59783173, 18.34164047], [82.59915161, 18.34242058], [82.60787964, 18.34167099], [82.61128235, 18.34646034], [82.60865784, 18.35123062], [82.60566711, 18.35280991], [82.59857941, 18.35401154], [82.5976181, 18.35621834], [82.59931183, 18.35997009], [82.59768677, 18.3625927], [82.60087585, 18.36605072], [82.60050964, 18.36870956], [82.59902191, 18.37161827], [82.59364319, 18.37049103], [82.58917236, 18.37713814], [82.58080292, 18.37885094], [82.57733154, 18.37732124], [82.57556152, 18.37986946], [82.57060242, 18.38418961], [82.56521606, 18.38398933], [82.55603027, 18.38850975], [82.55172729, 18.38708115], [82.54944611, 18.38351059], [82.54234314, 18.38904953], [82.53515625, 18.3895607], [82.53230286, 18.39344978], [82.5326004, 18.39682007], [82.54032135, 18.40187073], [82.54057312, 18.40343094], [82.53968811, 18.40362167], [82.53697968, 18.4041996], [82.53591156, 18.40831947], [82.5376358, 18.41222954], [82.53968048, 18.41686821], [82.54512024, 18.41724968], [82.54605865, 18.42414284], [82.55021667, 18.42650032], [82.55107117, 18.43390083], [82.55377197, 18.43765068], [82.55011749, 18.43889046], [82.54772949, 18.44178963], [82.54421234, 18.44129944], [82.5383606, 18.44318008], [82.53900909, 18.43808937], [82.53560638, 18.43665123], [82.53308105, 18.43406105], [82.53015137, 18.43431091], [82.52879333, 18.44034004], [82.5293808, 18.44293976], [82.52670288, 18.44730949], [82.52316284, 18.44577026], [82.52120209, 18.44711113], [82.52043915, 18.45053291], [82.52319336, 18.45277977], [82.51613617, 18.45588112], [82.51676178, 18.45721054], [82.51774597, 18.45928955], [82.52176666, 18.46175957], [82.5275116, 18.46821976], [82.52572632, 18.470541], [82.52101135, 18.47237015], [82.52752686, 18.47772026], [82.52448273, 18.48284912], [82.51951599, 18.48251152], [82.51979065, 18.48488998], [82.52005768, 18.48726082], [82.52449799, 18.48978043], [82.52321625, 18.4935112], [82.52202606, 18.4969902], [82.52390289, 18.49929047], [82.52313232, 18.50392914], [82.51751709, 18.50563812], [82.51426697, 18.50363922], [82.50740814, 18.50807953], [82.50418091, 18.50549126], [82.50202179, 18.50173187], [82.49915314, 18.50175095], [82.49880981, 18.5032711], [82.49820709, 18.50604057], [82.48145294, 18.51506042], [82.47573853, 18.5294075], [82.47783661, 18.53153038], [82.48191833, 18.53271103], [82.48532104, 18.53370094], [82.48161316, 18.53845978], [82.47400665, 18.53683281], [82.45342255, 18.51702118], [82.44993591, 18.5114212], [82.43712616, 18.4973011], [82.42913818, 18.48514175], [82.42687225, 18.47699165], [82.42032623, 18.46988106], [82.41220093, 18.46467018], [82.39737701, 18.45160103], [82.38227081, 18.43169975], [82.38065338, 18.42642975], [82.37760162, 18.42198944], [82.37174225, 18.42016983], [82.36702728, 18.41716957], [82.36599731, 18.41301155], [82.36128998, 18.4099102], [82.36599731, 18.40335274], [82.37251282, 18.39809036], [82.37490845, 18.39281082], [82.37523651, 18.38306046], [82.37841034, 18.37813187], [82.38443756, 18.37240982], [82.38442993, 18.36911011], [82.38109589, 18.36668968], [82.37879944, 18.3616581], [82.37970734, 18.3574295], [82.3763504, 18.35326958], [82.36947632, 18.35036278], [82.36013794, 18.34370041], [82.35656738, 18.33357048], [82.35021973, 18.32891083], [82.34542084, 18.32181931], [82.33641815, 18.32011986], [82.33444214, 18.31713295], [82.34101105, 18.31065941], [82.34290314, 18.30734062], [82.34874725, 18.30615044], [82.35456085, 18.309021], [82.35797119, 18.30824089], [82.36524963, 18.31642914], [82.3691864, 18.31775284], [82.37510681, 18.31800079], [82.38049316, 18.31931114], [82.3843689, 18.31870079], [82.38842773, 18.3112011], [82.393013, 18.30644035], [82.38735199, 18.30062294], [82.38540649, 18.28909111], [82.3822403, 18.28429031], [82.37187958, 18.27410126], [82.3670578, 18.27094078], [82.34365082, 18.27165031], [82.3368988, 18.26624107], [82.33390045, 18.25229073], [82.33180237, 18.24679184], [82.33203888, 18.24012947], [82.33100891, 18.23336029], [82.33022308, 18.23134041], [82.32253265, 18.22812843], [82.32131958, 18.22245979], [82.32673645, 18.21623039], [82.33281708, 18.21578979], [82.31973267, 18.20104027], [82.30609894, 18.19565964], [82.30943298, 18.18938065], [82.30821991, 18.18128014], [82.31030273, 18.17460251], [82.31931305, 18.17143059], [82.32479095, 18.16641998], [82.33302307, 18.16341972], [82.34160614, 18.16343117], [82.34873199, 18.16183281], [82.35897827, 18.1491394], [82.36515808, 18.13966942], [82.36429596, 18.13485909], [82.361763, 18.12919807], [82.35756683, 18.12510109], [82.34487152, 18.13462067], [82.33825684, 18.13796043], [82.33336639, 18.14237976], [82.33535767, 18.1272583], [82.33030701, 18.11899948], [82.33248901, 18.10704994], [82.33216095, 18.09412193], [82.33466339, 18.08988762], [82.34055328, 18.08708954], [82.34316254, 18.08247948], [82.34362793, 18.07499123], [82.34194183, 18.07130051], [82.3431778, 18.0678196], [82.33692932, 18.04910088], [82.33634949, 18.04726028], [82.32977295, 18.040411], [82.32491302, 18.04269028], [82.3261795, 18.0465107], [82.32182312, 18.05018044], [82.31964874, 18.04857063], [82.31730652, 18.04853058], [82.31572723, 18.04668045], [82.31299591, 18.04519081], [82.3169632, 18.03602028], [82.31320953, 18.03475761], [82.30961609, 18.03842926], [82.30552673, 18.03780937], [82.30441284, 18.03961945], [82.30634308, 18.04499054], [82.30105591, 18.04404068], [82.2964859, 18.04614067], [82.29280853, 18.05433273], [82.29640198, 18.05755806], [82.29789734, 18.06196022], [82.28777313, 18.06056023], [82.28505707, 18.0594101], [82.28302765, 18.05577087], [82.27894592, 18.05492973], [82.26695251, 18.04827118], [82.2651062, 18.0430603], [82.26460266, 18.039011], [82.26220703, 18.03630066], [82.25815582, 18.03487015], [82.26624298, 18.02569008], [82.26893616, 18.01993942], [82.27081299, 18.01066971], [82.27052307, 17.9977417], [82.26885223, 17.99198914], [82.26725006, 17.98644066], [82.26107788, 17.98240089], [82.25318909, 17.98019028], [82.24170685, 17.97976112], [82.2383194, 17.98390007], [82.23699188, 17.99201012], [82.23079681, 17.99370956], [82.22297668, 17.99287987], [82.2181778, 17.99419022], [82.20775604, 18.00070953], [82.1969223, 18.00868988], [82.19101715, 18.00895119], [82.18508911, 18.00735283], [82.17740631, 18.01057053], [82.17424774, 18.01550293], [82.17694092, 18.02089119], [82.17314911, 18.0255928], [82.16374969, 18.04162025], [82.16034698, 18.04359818], [82.14730835, 18.04042053], [82.14229584, 18.04356956], [82.13237, 18.03561974], [82.13041687, 18.04090118], [82.12924194, 18.04866982], [82.12708282, 18.0510006], [82.1193161, 18.05120087], [82.11326599, 18.05782127], [82.11058807, 18.05766106], [82.10797882, 18.05401993], [82.09236145, 18.05276108], [82.0891571, 18.05741119], [82.08006287, 18.0604496], [82.07221222, 18.06563759], [82.06989288, 18.06043053], [82.06440735, 18.05837059], [82.05898285, 18.0584507], [82.06098938, 18.05398178], [82.06546783, 18.05130005], [82.06564331, 18.04891968], [82.0597229, 18.04511833], [82.05085754, 18.0444603], [82.04516602, 18.04558945], [82.03263855, 18.05171013], [82.02986145, 18.05653191], [82.0246582, 18.0578804], [82.01677704, 18.0551281], [82.00663757, 18.04919815], [82.00157928, 18.04481125], [82.00473022, 18.03430939], [82.00211334, 18.0282402], [82.0016861, 18.02366066], [81.99147797, 18.02182007], [81.98886108, 18.02034187], [81.98587799, 18.01427078], [81.98046112, 18.01128006], [81.97305298, 18.00567055], [81.96404266, 17.99986839], [81.95713043, 17.99707031], [81.95176697, 17.99209976], [81.93609619, 17.98409081], [81.92471313, 17.98088074], [81.91369629, 17.97989082], [81.90454865, 17.97347069], [81.89927673, 17.96854973], [81.88507843, 17.96583939], [81.87413788, 17.95984077], [81.84681702, 17.95079994], [81.83969879, 17.95006943], [81.83333588, 17.95103073], [81.81980133, 17.94546127], [81.80104065, 17.93608093], [81.79405212, 17.9296608], [81.7893219, 17.92136955], [81.78601074, 17.91361046], [81.7824173, 17.90974045], [81.77574921, 17.9047699], [81.76222229, 17.89658928], [81.75829315, 17.89336014]]], [[[86.26335144, 20.05805969], [86.26167297, 20.05639076], [86.26139069, 20.05639076], [86.26029205, 20.05528069], [86.26000214, 20.05528069], [86.25971985, 20.05500031], [86.2591629, 20.05500031], [86.25860596, 20.05445099], [86.2583313, 20.05445099], [86.25805664, 20.05417061], [86.25776672, 20.05417061], [86.25749969, 20.05389023], [86.25721741, 20.05389023], [86.25692749, 20.05360985], [86.25666809, 20.05361176], [86.2563858, 20.05333328], [86.25611115, 20.05333328], [86.25590515, 20.05312538], [86.25527954, 20.05249977], [86.25444794, 20.05251122], [86.25415802, 20.05221939], [86.25389099, 20.05251122], [86.25332642, 20.05251122], [86.25307465, 20.05224609], [86.2527771, 20.0522213], [86.25250244, 20.05194473], [86.25222015, 20.05194473], [86.2519455, 20.05166626], [86.25166321, 20.05167007], [86.25138855, 20.05138969], [86.2508316, 20.05138969], [86.25055695, 20.05166626], [86.25055695, 20.05221939], [86.25026703, 20.05251122], [86.25055695, 20.05277824], [86.25055695, 20.0530529], [86.25195313, 20.05445099], [86.25222015, 20.05444336], [86.25333405, 20.05555534], [86.2536087, 20.05555534], [86.25389099, 20.05583382], [86.25415802, 20.05583], [86.25444794, 20.05611038], [86.2547226, 20.05611038], [86.25499725, 20.05639076], [86.25527954, 20.05638885], [86.25583649, 20.05694389], [86.25611115, 20.05694389], [86.2563858, 20.05722237], [86.25669861, 20.05725288], [86.25692749, 20.05750084], [86.25721741, 20.05750084], [86.25749969, 20.05778122], [86.2583313, 20.05778122], [86.25860596, 20.05805969], [86.2591629, 20.05805779], [86.25944519, 20.05833244], [86.2611084, 20.05833244], [86.26166534, 20.05888748], [86.26249695, 20.05888748], [86.26335144, 20.05805969]]], [[[86.25305176, 20.02528], [86.25332642, 20.02499962], [86.25444794, 20.02499962], [86.2547226, 20.02472115], [86.25527954, 20.02472115], [86.25583649, 20.02416611], [86.25611115, 20.02416992], [86.2583313, 20.02193832], [86.25749969, 20.02111053], [86.25721741, 20.02139091], [86.25692749, 20.02139091], [86.25666809, 20.02166939], [86.2563858, 20.02166748], [86.25611115, 20.02194405], [86.2547226, 20.02194405], [86.25444794, 20.02222252], [86.25415802, 20.02220917], [86.2536087, 20.02277946], [86.25333405, 20.02277756], [86.25166321, 20.02444458], [86.25166321, 20.02472115], [86.25195313, 20.02472115], [86.25250244, 20.02528], [86.25305176, 20.02528]]], [[[86.30999756, 20.04083252], [86.31027985, 20.04055405], [86.31083679, 20.04057121], [86.31111145, 20.04027939], [86.3125, 20.04027939], [86.31276703, 20.04000092], [86.3133316, 20.04000092], [86.31360626, 20.03861046], [86.3133316, 20.03833008], [86.31083679, 20.03833008], [86.31054688, 20.03861046], [86.31027985, 20.03861046], [86.30999756, 20.03889084], [86.30916595, 20.03889084], [86.3088913, 20.0391674], [86.3088913, 20.03972054], [86.30944824, 20.04027939], [86.30944824, 20.04055405], [86.3097229, 20.04083252], [86.30999756, 20.04083252]]], [[[86.32027435, 20.02944374], [86.32055664, 20.02916527], [86.32098389, 20.0291729], [86.32130432, 20.02913666], [86.32160187, 20.02897835], [86.32196045, 20.02890015], [86.32235718, 20.02882957], [86.32271576, 20.02861786], [86.32305908, 20.02833939], [86.32417297, 20.02721977], [86.32416534, 20.02694321], [86.32444763, 20.02667046], [86.32444763, 20.02639008], [86.32554626, 20.02528], [86.32583618, 20.02528], [86.32666779, 20.02444267], [86.32666779, 20.02416611], [86.32640076, 20.02388954], [86.3263855, 20.02361107], [86.32583618, 20.02305603], [86.32527924, 20.02305984], [86.32417297, 20.02193832], [86.32334137, 20.02193832], [86.32221985, 20.02305603], [86.32213593, 20.02330017], [86.32190704, 20.02361107], [86.32157898, 20.02390099], [86.32125854, 20.0241909], [86.32095337, 20.02449989], [86.3207016, 20.02482986], [86.32055664, 20.02524567], [86.32042694, 20.02565956], [86.3203125, 20.02607918], [86.32026672, 20.02650642], [86.32022095, 20.02695656], [86.32021332, 20.02742958], [86.32019043, 20.0279007], [86.31999969, 20.02833366], [86.31973267, 20.02861023], [86.31972504, 20.02916527], [86.31999969, 20.02944374], [86.32027435, 20.02944374]]], [[[86.26583099, 20.0336113], [86.26611328, 20.03333282], [86.26638794, 20.03333282], [86.26667023, 20.03305626], [86.26693726, 20.03305817], [86.26721954, 20.03277969], [86.26750183, 20.03277969], [86.26777649, 20.03250122], [86.26832581, 20.03250122], [86.26832581, 20.0313797], [86.26777649, 20.0308342], [86.26750183, 20.0308342], [86.26721954, 20.03055763], [86.26694489, 20.03055763], [86.26667023, 20.0308342], [86.26638794, 20.03083038], [86.26609802, 20.03111076], [86.26555634, 20.03111076], [86.26527405, 20.03138733], [86.26416779, 20.0313797], [86.26389313, 20.03166962], [86.26333618, 20.0316658], [86.26305389, 20.03194427], [86.26277924, 20.03194427], [86.26249695, 20.03222084], [86.26333618, 20.03305626], [86.26305389, 20.03333282], [86.26333618, 20.0336113], [86.26583099, 20.0336113]]], [[[86.27249908, 20.02444458], [86.27194214, 20.02388954], [86.27166748, 20.02388954], [86.26972198, 20.02193832], [86.26944733, 20.02222252], [86.26833344, 20.02111053], [86.26805878, 20.02111053], [86.26777649, 20.02082825], [86.26667023, 20.02082825], [86.26583099, 20.02166939], [86.26527405, 20.02166748], [86.2647171, 20.02220917], [86.2647171, 20.02277946], [86.26555634, 20.02361107], [86.26583099, 20.02361107], [86.26609802, 20.02388954], [86.26638794, 20.02388954], [86.26667023, 20.02416992], [86.26694489, 20.02416611], [86.26721954, 20.02444458], [86.26805878, 20.02444458], [86.26833344, 20.02472115], [86.26860809, 20.02472115], [86.26944733, 20.02555466], [86.26944733, 20.02583313], [86.27083588, 20.02722168], [86.27138519, 20.02722168], [86.27194214, 20.02666664], [86.27194214, 20.02639008], [86.27249908, 20.02583122], [86.27249908, 20.02527809], [86.27278137, 20.02499962], [86.27249908, 20.02472115], [86.27249908, 20.02444458]]], [[[86.28814697, 20.02861023], [86.28749847, 20.02861023], [86.28723145, 20.02833939], [86.28666687, 20.02833939], [86.28639221, 20.02861023], [86.28555298, 20.02861023], [86.28527832, 20.02833939], [86.28472137, 20.02833939], [86.28444672, 20.02806091], [86.28417206, 20.02806091], [86.2840271, 20.02791786], [86.28388977, 20.02778053], [86.28333282, 20.02778053], [86.28305817, 20.02750015], [86.28221893, 20.02750015], [86.28193665, 20.02721977], [86.28055573, 20.02722168], [86.28028107, 20.02694321], [86.27999878, 20.02695084], [86.27971649, 20.02667046], [86.27889252, 20.02667046], [86.27861023, 20.02695084], [86.27833557, 20.02694321], [86.27803802, 20.02721977], [86.27803802, 20.02806091], [86.27835083, 20.02833939], [86.27803802, 20.02861023], [86.27803802, 20.02889061], [86.27777863, 20.02916527], [86.27777863, 20.02943993], [86.27722168, 20.03000069], [86.27610779, 20.03000069], [86.27583313, 20.02972031], [86.27443695, 20.02972031], [86.27416992, 20.03000069], [86.27388763, 20.03000069], [86.27361298, 20.03028107], [86.27333069, 20.03028107], [86.27249908, 20.03111076], [86.27249908, 20.0313797], [86.27222443, 20.0316658], [86.27222443, 20.03194427], [86.27194214, 20.03222084], [86.27194214, 20.03250122], [86.27138519, 20.03305626], [86.27111053, 20.03333282], [86.26999664, 20.03333092], [86.26944733, 20.03388977], [86.26915741, 20.03388977], [86.26889038, 20.03417015], [86.26860809, 20.03416634], [86.26805878, 20.03472137], [86.26777649, 20.03472137], [86.26750183, 20.03500175], [86.26721954, 20.03500175], [86.26693726, 20.03528023], [86.26638794, 20.03528023], [86.26609802, 20.03500175], [86.26555634, 20.03500175], [86.26526642, 20.03472137], [86.26444244, 20.03472137], [86.26416779, 20.03500175], [86.26305389, 20.03500175], [86.26277924, 20.03472137], [86.26249695, 20.03472137], [86.26222229, 20.03444481], [86.26083374, 20.03444481], [86.26008606, 20.03369904], [86.25971985, 20.03333282], [86.25944519, 20.03333282], [86.2591629, 20.03305626], [86.25888824, 20.03305817], [86.2583313, 20.03250122], [86.25805664, 20.03250122], [86.25776672, 20.03222084], [86.25749969, 20.03222275], [86.25694275, 20.0316658], [86.2563858, 20.03166962], [86.25630951, 20.0315876], [86.25611115, 20.0313797], [86.25583649, 20.03138733], [86.2555542, 20.03111076], [86.25527954, 20.03111076], [86.25499725, 20.03083038], [86.2547226, 20.0308342], [86.25389099, 20.03000069], [86.25389099, 20.02972031], [86.25222015, 20.02972221], [86.25195313, 20.03000069], [86.25138855, 20.03000069], [86.25112152, 20.02972031], [86.2508316, 20.02972031], [86.25026703, 20.03028107], [86.25, 20.03028107], [86.24964905, 20.03026962], [86.24923706, 20.03027153], [86.24887085, 20.03023148], [86.24854279, 20.03004074], [86.24819946, 20.02980042], [86.24781799, 20.02927017], [86.24740601, 20.02885818], [86.2470932, 20.02891922], [86.24677277, 20.02907181], [86.24637604, 20.02907181], [86.24591064, 20.02891922], [86.24568176, 20.02902985], [86.24546051, 20.02917099], [86.24523163, 20.02935982], [86.24499512, 20.02956963], [86.24476624, 20.02981949], [86.24459076, 20.03013611], [86.24446869, 20.03046989], [86.24447632, 20.03079987], [86.24465942, 20.03108025], [86.24472046, 20.0313797], [86.24472046, 20.03170967], [86.24472046, 20.03208923], [86.24472046, 20.03255844], [86.24472046, 20.03310204], [86.24472046, 20.03368378], [86.24475861, 20.03425217], [86.24488068, 20.03473282], [86.24498749, 20.0352211], [86.24505615, 20.03570175], [86.24524689, 20.03616905], [86.24541473, 20.03666496], [86.24556732, 20.03713036], [86.24578857, 20.03750992], [86.2459259, 20.03784943], [86.24610901, 20.03812027], [86.24629211, 20.03839111], [86.24645996, 20.03868294], [86.24665833, 20.03897095], [86.24684143, 20.03926086], [86.24697113, 20.03963089], [86.24716949, 20.03993607], [86.24742126, 20.04024124], [86.24767303, 20.04057121], [86.24787903, 20.04088974], [86.24806976, 20.04122162], [86.24828339, 20.04150963], [86.24846649, 20.04181099], [86.2486496, 20.04210854], [86.24886322, 20.04236794], [86.24903107, 20.04269028], [86.24919891, 20.04306984], [86.24947357, 20.04341125], [86.24987793, 20.04373169], [86.25028992, 20.0440712], [86.25076294, 20.04440498], [86.25123596, 20.0447197], [86.25170135, 20.04502678], [86.25215912, 20.04529953], [86.25250244, 20.04556084], [86.25305176, 20.04555511], [86.2538681, 20.04636955], [86.25416565, 20.0466671], [86.25415802, 20.04721832], [86.25444794, 20.04750061], [86.25444794, 20.04861069], [86.2547226, 20.04888916], [86.25485229, 20.04929924], [86.25502014, 20.04965973], [86.25525665, 20.04999161], [86.25550079, 20.05034256], [86.25575256, 20.05072975], [86.25610352, 20.05112076], [86.25653839, 20.05153084], [86.25704193, 20.05195999], [86.25754547, 20.05238533], [86.2580719, 20.05276108], [86.25862122, 20.0530529], [86.25915527, 20.05331802], [86.25971985, 20.05360985], [86.25971985, 20.05389023], [86.26000214, 20.05417061], [86.26029205, 20.05417061], [86.26055908, 20.05445099], [86.26082611, 20.05445099], [86.26148224, 20.05509567], [86.26167297, 20.05528069], [86.26194763, 20.05528069], [86.26249695, 20.05471992], [86.26277924, 20.05472183], [86.26305389, 20.05444336], [86.26335144, 20.05445099], [86.26361084, 20.05417061], [86.26389313, 20.05417061], [86.26444244, 20.05360985], [86.26499939, 20.05416679], [86.26555634, 20.05471992], [86.26555634, 20.05500031], [86.26499939, 20.05554962], [86.26499939, 20.05611038], [86.26526642, 20.05639076], [86.26526642, 20.05667114], [86.26638794, 20.05778122], [86.26667023, 20.05778122], [86.26693726, 20.05805969], [86.26833344, 20.05805779], [86.26860809, 20.05833244], [86.26999664, 20.05833244], [86.27027893, 20.05805779], [86.26999664, 20.05778122], [86.26999664, 20.05722046], [86.27027893, 20.05694389], [86.27027893, 20.05638885], [86.26915741, 20.05528069], [86.26889038, 20.05528069], [86.26832581, 20.05471992], [86.26805878, 20.05472183], [86.26777649, 20.05444336], [86.26750183, 20.05445099], [86.26721954, 20.05417061], [86.26721954, 20.05332947], [86.26750183, 20.05305481], [86.26777649, 20.05305481], [86.26805878, 20.05333328], [86.26833344, 20.05333328], [86.26860809, 20.05361176], [86.26916504, 20.05305481], [86.26972198, 20.05277824], [86.27054596, 20.05194283], [86.27083588, 20.05194283], [86.27166748, 20.05277824], [86.27166748, 20.05305481], [86.27194214, 20.05332947], [86.27194214, 20.05389023], [86.27223206, 20.05417061], [86.27223206, 20.05445099], [86.27278137, 20.05500031], [86.27305603, 20.05500031], [86.27333069, 20.05528069], [86.27361298, 20.05500031], [86.27388763, 20.05500031], [86.27500153, 20.05389023], [86.27500153, 20.05360985], [86.27444458, 20.05305481], [86.27444458, 20.05277824], [86.27471924, 20.05251122], [86.27480316, 20.05246735], [86.2750473, 20.05234146], [86.27539063, 20.05221367], [86.27577972, 20.05204964], [86.27620697, 20.05185127], [86.27679443, 20.05198479], [86.27719116, 20.05185699], [86.27749634, 20.05164909], [86.277771, 20.05138969], [86.27800751, 20.05115128], [86.27828217, 20.05101967], [86.27854919, 20.0508709], [86.27892303, 20.05078888], [86.27929688, 20.0505619], [86.27973175, 20.05030251], [86.28016663, 20.0500164], [86.28058624, 20.0497303], [86.28096008, 20.04946327], [86.28128052, 20.04923058], [86.2816391, 20.04912949], [86.28192902, 20.04894066], [86.28232574, 20.04886246], [86.28276062, 20.04875183], [86.28320313, 20.04857826], [86.28363037, 20.04834175], [86.28410339, 20.04809952], [86.28465271, 20.04792976], [86.28514099, 20.04764938], [86.2856369, 20.04740524], [86.28605652, 20.04710388], [86.28630829, 20.04659843], [86.28675079, 20.04648972], [86.28723145, 20.046381], [86.28749847, 20.04611206], [86.28749847, 20.04527664], [86.28723145, 20.04499817], [86.28749847, 20.0447216], [86.28778076, 20.0447216], [86.28805542, 20.04444695], [86.28916931, 20.04445076], [86.28943634, 20.04417038], [86.28971863, 20.04417038], [86.29000092, 20.04388809], [86.29000092, 20.0433197], [86.29055786, 20.04277611], [86.29083252, 20.0430603], [86.29111481, 20.0430584], [86.29138947, 20.0433197], [86.29138947, 20.04445076], [86.29250336, 20.04556084], [86.29277802, 20.04556084], [86.29303741, 20.04528046], [86.29332733, 20.04528046], [86.29360962, 20.04499817], [86.29389191, 20.04499817], [86.29444122, 20.04445076], [86.29471588, 20.04445076], [86.29611206, 20.0430603], [86.29638672, 20.0430603], [86.29666901, 20.04277992], [86.29666901, 20.04249954], [86.29750061, 20.04166985], [86.29750061, 20.04111099], [86.29722595, 20.04083061], [86.29722595, 20.04055405], [86.29693604, 20.04027939], [86.29693604, 20.04000092], [86.29666901, 20.03972054], [86.29777527, 20.03861046], [86.29888916, 20.03861046], [86.29917145, 20.03833008], [86.30000305, 20.03833389], [86.30027771, 20.03805542], [86.30082703, 20.03806114], [86.30110931, 20.03778076], [86.30194092, 20.03778076], [86.30223083, 20.03750992], [86.30249786, 20.03750992], [86.30304718, 20.03695107], [86.3033371, 20.03695107], [86.30361176, 20.03667068], [86.30388641, 20.03667068], [86.3041687, 20.0363903], [86.30500031, 20.0363903], [86.30526733, 20.03611183], [86.30555725, 20.03611183], [86.3061142, 20.03555489], [86.30638885, 20.03555489], [86.30666351, 20.03527832], [86.30722046, 20.03528023], [86.3077774, 20.03472137], [86.30805206, 20.03472137], [86.30805206, 20.03444481], [86.30722046, 20.0336113], [86.3069458, 20.0336113], [86.3067627, 20.03342819], [86.30638885, 20.03305626], [86.30583191, 20.03305817], [86.30526733, 20.03250122], [86.30444336, 20.03250122], [86.30388641, 20.03305817], [86.30361176, 20.03277969], [86.3033371, 20.03277969], [86.30304718, 20.03250122], [86.30278015, 20.03250122], [86.30166626, 20.0313797], [86.30110931, 20.03194427], [86.30055237, 20.03194427], [86.29944611, 20.0308342], [86.29916382, 20.0308342], [86.29805756, 20.02972221], [86.29805756, 20.02944374], [86.29777527, 20.02916527], [86.29722595, 20.02916527], [86.29666901, 20.02972031], [86.29666901, 20.03000069], [86.29638672, 20.03028107], [86.29582977, 20.03028107], [86.29528046, 20.02972031], [86.29499817, 20.02972221], [86.29490662, 20.02962875], [86.29472351, 20.02944374], [86.29166412, 20.02944374], [86.29138947, 20.02916527], [86.29055786, 20.02917099], [86.29029083, 20.02889061], [86.29000092, 20.02889061], [86.28971863, 20.02861023], [86.28916931, 20.02861023], [86.28888702, 20.02889061], [86.28861237, 20.02861023], [86.28814697, 20.02861023]]], [[[86.30055237, 20.04249954], [86.30082703, 20.04222107], [86.30110931, 20.04222298], [86.30305481, 20.04027748], [86.3033371, 20.04027939], [86.30388641, 20.03972054], [86.3033371, 20.0391674], [86.3033371, 20.03889084], [86.30304718, 20.03861046], [86.30249786, 20.03861046], [86.30223083, 20.03889084], [86.3013916, 20.03889084], [86.30110931, 20.03917122], [86.30083466, 20.0391674], [86.30055237, 20.03944206], [86.30027771, 20.03944206], [86.30000305, 20.03972244], [86.29972076, 20.03972054], [86.29917145, 20.04027939], [86.29916382, 20.04055405], [86.29888916, 20.04083061], [86.29888916, 20.04111099], [86.29860687, 20.04138947], [86.2986145, 20.04166412], [86.29891205, 20.04196739], [86.29916382, 20.04222298], [86.29946136, 20.04222107], [86.29972076, 20.04249954], [86.30055237, 20.04249954]]], [[[86.29499817, 20.04972267], [86.29555511, 20.04916573], [86.29582977, 20.04916573], [86.29638672, 20.04972267], [86.29694366, 20.04972267], [86.29833221, 20.04833412], [86.29833221, 20.04805565], [86.29860687, 20.04777908], [86.29860687, 20.04750061], [86.29888916, 20.04721832], [86.29888916, 20.04694366], [86.29916382, 20.0466671], [86.29917145, 20.046381], [86.29944611, 20.04611206], [86.29944611, 20.04583359], [86.29972076, 20.04555511], [86.29972076, 20.04528046], [86.30027771, 20.0447197], [86.30027771, 20.04444695], [86.29972076, 20.04388809], [86.29888916, 20.04388809], [86.29833221, 20.04445076], [86.29805756, 20.04445076], [86.29750061, 20.04499817], [86.29722595, 20.04499817], [86.29693604, 20.04528046], [86.29638672, 20.04528046], [86.29611206, 20.04556084], [86.29582977, 20.04555511], [86.29555511, 20.04583359], [86.29528046, 20.04583359], [86.29499817, 20.04611206], [86.29472351, 20.04611206], [86.29444122, 20.04639053], [86.29416656, 20.046381], [86.29389191, 20.04667091], [86.29333496, 20.0466671], [86.29305267, 20.04694366], [86.29222107, 20.04694366], [86.29194641, 20.04722214], [86.29165649, 20.04721832], [86.29110718, 20.04777908], [86.29110718, 20.04861069], [86.29083252, 20.04889107], [86.29111481, 20.04916573], [86.29110718, 20.04972267], [86.29165649, 20.05027962], [86.29250336, 20.05027962], [86.29277802, 20.05055618], [86.29277802, 20.05083275], [86.29389191, 20.05083275], [86.29499817, 20.04972267]]], [[[86.78972626, 20.38760948], [86.78939819, 20.38754082], [86.78897858, 20.3877697], [86.78904724, 20.38815117], [86.7891922, 20.38869095], [86.7891922, 20.38923073], [86.78904724, 20.38997269], [86.78911591, 20.39059258], [86.78916168, 20.39103127], [86.78910828, 20.39144516], [86.78897858, 20.39182091], [86.78890228, 20.39217758], [86.78888702, 20.39252281], [86.78888702, 20.39285851], [86.78894043, 20.39317894], [86.78910065, 20.39346123], [86.78917694, 20.3937912], [86.78927612, 20.39413261], [86.78942108, 20.39447975], [86.78951263, 20.39485931], [86.78967285, 20.39520836], [86.78971863, 20.39558411], [86.78972626, 20.39596939], [86.78972626, 20.39638519], [86.78972626, 20.39682961], [86.78972626, 20.39731979], [86.78972626, 20.39782906], [86.78972626, 20.39836121], [86.78972626, 20.39888954], [86.79000092, 20.40018082], [86.78979492, 20.40098953], [86.78929138, 20.40200043], [86.78879547, 20.40301514], [86.78858185, 20.40389252], [86.78779602, 20.4050808], [86.78788757, 20.4056263], [86.78806305, 20.40611076], [86.78833008, 20.40639114], [86.78833008, 20.4066658], [86.78861237, 20.40694046], [86.78861237, 20.40777969], [86.78943634, 20.40860939], [86.78943634, 20.40889168], [86.78971863, 20.40916634], [86.78971863, 20.40944481], [86.79000092, 20.40971947], [86.79000092, 20.41055489], [86.7902832, 20.41082954], [86.7902832, 20.41167068], [86.79055786, 20.41195107], [86.79055786, 20.41278076], [86.7902832, 20.41306114], [86.7902832, 20.41389084], [86.79000092, 20.41417122], [86.79000092, 20.41527939], [86.789711, 20.41555977], [86.78971863, 20.41611099], [86.79027557, 20.41666412], [86.79000092, 20.41694069], [86.79000092, 20.41749954], [86.78971863, 20.41777611], [86.789711, 20.4197197], [86.79000092, 20.41999817], [86.79000092, 20.42110825], [86.7902832, 20.42139053], [86.79027557, 20.4216671], [86.79000092, 20.42193985], [86.79000092, 20.42416573], [86.7902832, 20.42444038], [86.7902832, 20.42500114], [86.79000092, 20.42527771], [86.79000092, 20.42583466], [86.79027557, 20.42611122], [86.7902832, 20.42638969], [86.7904129, 20.42679977], [86.79057312, 20.42728043], [86.79083252, 20.42777824], [86.79055786, 20.42805481], [86.79055786, 20.42860031], [86.79083252, 20.42888641], [86.79110718, 20.42917061], [86.79138947, 20.42917061], [86.79151154, 20.42904663], [86.79194641, 20.42861176], [86.79194641, 20.42833328], [86.79222107, 20.42805481], [86.79222107, 20.42777824], [86.79250336, 20.42749977], [86.79250336, 20.42721939], [86.79277802, 20.42694473], [86.79277802, 20.42666626], [86.79305267, 20.42638969], [86.79305267, 20.42611122], [86.79332733, 20.42583275], [86.79332733, 20.42534637], [86.79332733, 20.42494011], [86.79335785, 20.42450333], [86.79345703, 20.42404556], [86.79358673, 20.4235611], [86.79360962, 20.42305756], [86.79360962, 20.42255974], [86.79361725, 20.42210007], [86.79366302, 20.42168045], [86.79380035, 20.42128944], [86.79383087, 20.42088127], [86.79366302, 20.42042923], [86.7935791, 20.41996765], [86.79344177, 20.41953087], [86.79335022, 20.41909981], [86.79332733, 20.41868019], [86.79333496, 20.41829872], [86.79332733, 20.4179306], [86.79338074, 20.41757011], [86.79354095, 20.41726112], [86.79366302, 20.41692734], [86.79386902, 20.41661835], [86.79402161, 20.41625023], [86.79413605, 20.41584778], [86.79416656, 20.41537094], [86.79416656, 20.41484261], [86.79421997, 20.41428947], [86.79440308, 20.41380119], [86.79444122, 20.4133091], [86.79445648, 20.41286087], [86.79454041, 20.41242981], [86.79467773, 20.41201973], [86.79467773, 20.41156006], [86.7946167, 20.41106987], [86.79476929, 20.41048241], [86.79454803, 20.41004944], [86.79415894, 20.40966034], [86.79389954, 20.40917015], [86.79370117, 20.40864754], [86.79344177, 20.40813065], [86.79329681, 20.40752029], [86.79309845, 20.40691185], [86.79305267, 20.40626144], [86.79302216, 20.40561104], [86.79289246, 20.40496254], [86.79283905, 20.40431976], [86.79297638, 20.40367126], [86.79305267, 20.40303993], [86.79305267, 20.40245438], [86.7930603, 20.40193367], [86.79310608, 20.40147781], [86.79328156, 20.40107918], [86.79332733, 20.40065956], [86.79332733, 20.40023994], [86.79332733, 20.3998394], [86.79338074, 20.39947128], [86.79354095, 20.3991375], [86.79354095, 20.39874268], [86.7935791, 20.39835739], [86.79358673, 20.39817047], [86.79360199, 20.39796829], [86.79360962, 20.39760017], [86.79361725, 20.39723969], [86.79368591, 20.39690971], [86.79384613, 20.39658928], [86.79396057, 20.3962307], [86.79412079, 20.39587593], [86.79418945, 20.39549446], [86.79436493, 20.39511299], [86.79473114, 20.39473343], [86.7951889, 20.39431763], [86.79535675, 20.39381981], [86.79534149, 20.39335251], [86.79470825, 20.39292145], [86.79428864, 20.39253044], [86.79412079, 20.39211273], [86.79395294, 20.3916893], [86.7938385, 20.39120865], [86.79360962, 20.39076805], [86.79334259, 20.39033127], [86.79308319, 20.38990021], [86.79281616, 20.38952065], [86.79251099, 20.38927078], [86.79220581, 20.38904953], [86.79193115, 20.38886261], [86.79168701, 20.38865089], [86.79141998, 20.38849068], [86.79116821, 20.38829613], [86.79087067, 20.38805008], [86.7904129, 20.3877964], [86.78972626, 20.38760948]]], [[[86.79805756, 20.69194221], [86.79784393, 20.69030571], [86.79763031, 20.68982124], [86.79763031, 20.68922615], [86.79727936, 20.68862152], [86.79656982, 20.6878109], [86.79577637, 20.68558121], [86.79528046, 20.68416786], [86.79528046, 20.68388939], [86.79499817, 20.68361092], [86.79499817, 20.68333054], [86.79472351, 20.68305588], [86.79471588, 20.68278122], [86.79444122, 20.68250084], [86.79444122, 20.68222046], [86.79416656, 20.6819458], [86.79416656, 20.68166733], [86.79389191, 20.68139076], [86.79389191, 20.68083], [86.79360962, 20.68055534], [86.79360962, 20.68028069], [86.79332733, 20.68000031], [86.79332733, 20.67971992], [86.79305267, 20.67944527], [86.79305267, 20.67917061], [86.79250336, 20.67861176], [86.79250336, 20.67833138], [86.79222107, 20.67805481], [86.79222107, 20.67777824], [86.79110718, 20.67667007], [86.79110718, 20.6763916], [86.79083252, 20.67610931], [86.79055786, 20.67583084], [86.79016876, 20.67534065], [86.78967285, 20.67493057], [86.78924561, 20.67513847], [86.78924561, 20.67689133], [86.78931427, 20.67824173], [86.78931427, 20.67925262], [86.78943634, 20.68083], [86.789711, 20.68111038], [86.789711, 20.68278122], [86.79000092, 20.68305588], [86.79000092, 20.68333244], [86.79027557, 20.68361092], [86.7902832, 20.68388939], [86.79055786, 20.68416977], [86.79055786, 20.68499947], [86.79083252, 20.68527985], [86.79083252, 20.68555641], [86.79111481, 20.68583298], [86.79110718, 20.68610954], [86.79138947, 20.68638992], [86.79138947, 20.68694496], [86.79166412, 20.68722153], [86.79165649, 20.68749046], [86.79194641, 20.68778038], [86.79194641, 20.68805504], [86.79222107, 20.68833351], [86.79222107, 20.68860817], [86.79277802, 20.68916702], [86.79277802, 20.68971825], [86.79305267, 20.69000244], [86.79305267, 20.69055557], [86.79332733, 20.69083023], [86.79332733, 20.69111252], [86.79360962, 20.6913929], [86.79389191, 20.69138908], [86.79389191, 20.69194221], [86.79416656, 20.6922226], [86.79416656, 20.69277763], [86.79471588, 20.69333076], [86.79471588, 20.69388962], [86.79499817, 20.69416618], [86.79499817, 20.69444466], [86.79528046, 20.69472313], [86.79528046, 20.69582939], [86.79582977, 20.69638824], [86.7958374, 20.69721985], [86.79638672, 20.69778061], [86.79638672, 20.69806099], [86.79693604, 20.69861031], [86.79694366, 20.69888878], [86.79750061, 20.69944382], [86.79750061, 20.69972038], [86.79833221, 20.70055962], [86.79860687, 20.70055962], [86.79915619, 20.70000076], [86.79915619, 20.69972038], [86.79888916, 20.69944382], [86.79854584, 20.69907761], [86.79847717, 20.69861031], [86.79847717, 20.69684982], [86.79854584, 20.69617653], [86.79840851, 20.69495964], [86.79833221, 20.69416618], [86.79833221, 20.6922226], [86.79805756, 20.69194221]]], [[[86.80426788, 20.67662048], [86.80347443, 20.67656708], [86.80271149, 20.67645073], [86.80207825, 20.67624092], [86.80153656, 20.67603111], [86.80103302, 20.67583275], [86.80051422, 20.67566872], [86.80008698, 20.67547035], [86.79971313, 20.67526627], [86.79932404, 20.67507362], [86.7990036, 20.67481995], [86.7986908, 20.67455101], [86.79833984, 20.6742897], [86.79805756, 20.67416954], [86.79805756, 20.67388916], [86.79666901, 20.67250824], [86.79666901, 20.67222023], [86.79638672, 20.67194366], [86.79638672, 20.67166519], [86.7958374, 20.67111015], [86.79582977, 20.67083359], [86.79555511, 20.67055511], [86.79556274, 20.67000008], [86.79528046, 20.6697216], [86.79528046, 20.66916656], [86.79499817, 20.66889], [86.79499817, 20.66860962], [86.79528046, 20.66833305], [86.79528046, 20.66749954], [86.79499817, 20.66722107], [86.79528046, 20.6669445], [86.79528046, 20.66638947], [86.79541016, 20.66562271], [86.79575348, 20.66504669], [86.7961731, 20.6645298], [86.79666138, 20.66414833], [86.79712677, 20.6638298], [86.79750824, 20.6635704], [86.79788971, 20.66345978], [86.79823303, 20.66348267], [86.79852295, 20.66362953], [86.79876709, 20.66389275], [86.79904938, 20.66423798], [86.7993927, 20.66460419], [86.79981232, 20.66493988], [86.80021667, 20.66529846], [86.80056763, 20.66570282], [86.80088043, 20.6661396], [86.8012085, 20.66655731], [86.80156708, 20.6668911], [86.80197144, 20.66716957], [86.80243683, 20.66739082], [86.80304718, 20.66754723], [86.80374908, 20.66757393], [86.80437469, 20.6674881], [86.80491638, 20.66739082], [86.80545044, 20.66732025], [86.80593109, 20.66732979], [86.80609894, 20.66729736], [86.806427, 20.66723061], [86.80691528, 20.66712379], [86.80737305, 20.66693687], [86.80784607, 20.66673279], [86.8083725, 20.66652107], [86.80885315, 20.66620064], [86.80931854, 20.66584015], [86.80982208, 20.66546822], [86.81030273, 20.66508484], [86.81079102, 20.66470909], [86.81124115, 20.66431046], [86.81167603, 20.66390038], [86.81213379, 20.66351891], [86.81253815, 20.66311073], [86.81295013, 20.66275024], [86.81335449, 20.66238976], [86.81363678, 20.66194916], [86.81391144, 20.66150093], [86.8141861, 20.66106033], [86.81443787, 20.66059113], [86.81469727, 20.66012955], [86.81494141, 20.65971184], [86.81512451, 20.65933037], [86.81526947, 20.65901947], [86.81539917, 20.65875816], [86.81550598, 20.65853119], [86.81562042, 20.65826988], [86.81573486, 20.65799713], [86.81582642, 20.65768051], [86.81597137, 20.65737915], [86.8161087, 20.6570797], [86.81628418, 20.65678215], [86.8164444, 20.65642357], [86.81664276, 20.65605164], [86.81684113, 20.65566063], [86.81698608, 20.65526009], [86.81717682, 20.65488815], [86.81741333, 20.65450287], [86.81768036, 20.65407944], [86.81793976, 20.65364647], [86.81817627, 20.65316963], [86.81841278, 20.65270996], [86.8186264, 20.65229988], [86.81884766, 20.65193176], [86.81912231, 20.65155983], [86.81945801, 20.65113068], [86.81984711, 20.65065956], [86.82021332, 20.65014267], [86.82052612, 20.64965057], [86.82080841, 20.6491909], [86.82106018, 20.64877701], [86.82129669, 20.64836121], [86.8215332, 20.64795494], [86.82171631, 20.64752007], [86.82186127, 20.64706993], [86.8219223, 20.64660835], [86.82195282, 20.64614105], [86.82194519, 20.64571381], [86.8219223, 20.64530182], [86.82186127, 20.64492035], [86.82176208, 20.64455032], [86.82157898, 20.64413261], [86.82139587, 20.6436615], [86.82115936, 20.64320374], [86.82089233, 20.64274597], [86.82063293, 20.64228058], [86.82039642, 20.64183044], [86.82022095, 20.64142036], [86.82003784, 20.64105988], [86.81984711, 20.64068985], [86.81968689, 20.64031792], [86.81954193, 20.63992119], [86.81935883, 20.6395607], [86.81912231, 20.63924217], [86.81880188, 20.63892555], [86.81842804, 20.63858032], [86.81800842, 20.63826942], [86.81755066, 20.63803101], [86.81707001, 20.63788033], [86.8165741, 20.6378727], [86.81616974, 20.63780022], [86.81581879, 20.63775826], [86.81547546, 20.63776779], [86.81510925, 20.63784027], [86.81472778, 20.63803101], [86.81428528, 20.63824844], [86.81376648, 20.63848305], [86.81324768, 20.63878059], [86.81280518, 20.63917923], [86.81241608, 20.63961029], [86.81204987, 20.64003754], [86.8117218, 20.64045906], [86.81140137, 20.6408577], [86.81109619, 20.64125061], [86.81079102, 20.64165306], [86.81045532, 20.64203262], [86.810112, 20.64237022], [86.80969238, 20.64268494], [86.80921936, 20.64300156], [86.80874634, 20.64335442], [86.8082962, 20.64373016], [86.80786896, 20.64409065], [86.80745697, 20.64443588], [86.80700684, 20.64471245], [86.80652618, 20.64493942], [86.80610657, 20.64500046], [86.80583191, 20.64528084], [86.80500031, 20.64528084], [86.80371094, 20.64500046], [86.8024292, 20.64487076], [86.80082703, 20.64500046], [86.80027771, 20.6455555], [86.80027771, 20.64583015], [86.80000305, 20.64611053], [86.79611206, 20.64611053], [86.79437256, 20.64603806], [86.79401398, 20.64583397], [86.79305267, 20.64583015], [86.79277802, 20.64611053], [86.79250336, 20.64611053], [86.79222107, 20.64583015], [86.79111481, 20.64583397], [86.79083252, 20.6455555], [86.79055786, 20.64557076], [86.7902832, 20.64528084], [86.789711, 20.64528084], [86.78943634, 20.64500046], [86.78888702, 20.64500046], [86.78861237, 20.64472008], [86.78694153, 20.64472198], [86.78666687, 20.64444351], [86.78583527, 20.64444351], [86.78562927, 20.64424133], [86.78555298, 20.64416695], [86.78472137, 20.64416695], [86.78444672, 20.64444351], [86.78360748, 20.64444351], [86.78333282, 20.64472198], [86.78305817, 20.64472008], [86.78277588, 20.64500046], [86.78277588, 20.64528084], [86.78250122, 20.64557076], [86.78166962, 20.6455555], [86.78138733, 20.64583397], [86.78056335, 20.64583015], [86.78028107, 20.64611053], [86.77971649, 20.64611053], [86.77944183, 20.64639091], [86.77889252, 20.64639091], [86.77861023, 20.64666748], [86.77805328, 20.64666748], [86.77777863, 20.64694405], [86.77749634, 20.64694405], [86.77722168, 20.64666748], [86.77694702, 20.64666748], [86.7766571, 20.64639091], [86.77602386, 20.64639473], [86.77523804, 20.64618874], [86.77459717, 20.64639091], [86.77379608, 20.6463871], [86.77394104, 20.64672279], [86.77429962, 20.64744949], [86.77416992, 20.64805984], [86.77416992, 20.64834023], [86.77471161, 20.64889145], [86.77471924, 20.64916611], [86.77527618, 20.64971924], [86.77527618, 20.65000153], [86.77555847, 20.65027809], [86.77555847, 20.65082932], [86.77639008, 20.65167046], [86.77639008, 20.65195084], [86.77805328, 20.65361023], [86.77805328, 20.65389061], [86.77833557, 20.65416718], [86.7783432, 20.65443993], [86.77889252, 20.65500069], [86.77889252, 20.65528107], [86.77916718, 20.65555573], [86.77916718, 20.65583038], [86.78111267, 20.65777969], [86.78138733, 20.65777779], [86.78194427, 20.65833282], [86.78250122, 20.65833092], [86.78916931, 20.66500282], [86.78916931, 20.66527748], [86.789711, 20.66583061], [86.789711, 20.6661129], [86.79000092, 20.6661129], [86.79000092, 20.66638947], [86.79055786, 20.66694069], [86.79055786, 20.66749954], [86.79194641, 20.66889], [86.79194641, 20.66916656], [86.79250336, 20.6697197], [86.79250336, 20.67000008], [86.79277802, 20.67028046], [86.79277802, 20.67055511], [86.79305267, 20.67083359], [86.79305267, 20.67111015], [86.79499817, 20.67305565], [86.79499817, 20.67333031], [86.79556274, 20.67388916], [86.79555511, 20.67416573], [86.7958374, 20.67444038], [86.7958374, 20.67499924], [86.79611206, 20.67527771], [86.79611206, 20.67555618], [86.7977829, 20.67721939], [86.79750061, 20.67750168], [86.79750061, 20.67777824], [86.79777527, 20.67805481], [86.7977829, 20.67831993], [86.79860687, 20.67917061], [86.7986145, 20.67944527], [86.79888153, 20.67971992], [86.79888153, 20.68000031], [86.79944611, 20.68055534], [86.79944611, 20.68083], [86.79972076, 20.68111038], [86.80072021, 20.6822567], [86.80150604, 20.68340492], [86.80214691, 20.68522072], [86.80207825, 20.68657494], [86.80251312, 20.68798828], [86.80361176, 20.69111252], [86.80361176, 20.69305611], [86.80388641, 20.69333458], [86.80388641, 20.69444466], [86.8041687, 20.69472122], [86.8041687, 20.69527817], [86.80444336, 20.69555473], [86.80444336, 20.69833374], [86.80473328, 20.69861031], [86.80444336, 20.69889069], [86.80472565, 20.69916725], [86.80473328, 20.70248985], [86.80500031, 20.70277786], [86.80500031, 20.70360947], [86.80527496, 20.70388794], [86.80526733, 20.70471954], [86.80555725, 20.70500183], [86.80555725, 20.7052784], [86.80750275, 20.70722008], [86.80750275, 20.70750046], [86.80832672, 20.70833015], [86.80832672, 20.70862007], [86.80860901, 20.70889091], [86.80916595, 20.70889091], [86.80944824, 20.70916939], [86.8097229, 20.70916748], [86.81027985, 20.70972252], [86.81054688, 20.70944023], [86.8116684, 20.71055412], [86.8116684, 20.71083069], [86.81194305, 20.71111107], [86.81194305, 20.71138954], [86.81277466, 20.71222305], [86.81305695, 20.71194458], [86.81472015, 20.7136097], [86.81472015, 20.71388817], [86.81555176, 20.71471977], [86.81555176, 20.71499825], [86.81667328, 20.71610832], [86.81666565, 20.7163887], [86.8172226, 20.71694374], [86.8172226, 20.71722031], [86.81777954, 20.71778107], [86.81777954, 20.71805573], [86.81804657, 20.71833038], [86.81804657, 20.71861267], [86.81833649, 20.71889114], [86.81833649, 20.7191658], [86.81861115, 20.71944046], [86.81861115, 20.72000122], [86.8188858, 20.72027779], [86.8188858, 20.72083473], [86.81916809, 20.72110939], [86.81916809, 20.72138977], [86.81944275, 20.72166634], [86.81944275, 20.72222137], [86.81972504, 20.72249985], [86.81973267, 20.72332954], [86.81944275, 20.72361946], [86.81944275, 20.7238903], [86.81973267, 20.72417068], [86.81972504, 20.72444534], [86.81999969, 20.72472191], [86.82000732, 20.72500038], [86.82026672, 20.72528076], [86.82027435, 20.72555542], [86.82055664, 20.72583389], [86.82055664, 20.7266674], [86.8208313, 20.72694016], [86.8208313, 20.72777748], [86.82111359, 20.72805595], [86.82111359, 20.7294445], [86.82138824, 20.72971916], [86.82138824, 20.73028183], [86.8216629, 20.7305603], [86.8216629, 20.73250008], [86.82195282, 20.73278999], [86.82195282, 20.73528099], [86.82221985, 20.73555946], [86.82221985, 20.73611069], [86.82250214, 20.73639107], [86.82250214, 20.73750114], [86.82277679, 20.73777771], [86.82277679, 20.73944473], [86.82306671, 20.73971939], [86.82305908, 20.74027634], [86.82332611, 20.74055099], [86.82382965, 20.74240112], [86.82411957, 20.74360085], [86.82444763, 20.74528122], [86.82444763, 20.74555588], [86.82472229, 20.74583054], [86.82472229, 20.74611282], [86.82499695, 20.74638939], [86.82499695, 20.74666595], [86.82527924, 20.74694443], [86.82527924, 20.74728966], [86.82527924, 20.74749947], [86.82554626, 20.74778938], [86.82554626, 20.74888992], [86.82583618, 20.7491703], [86.82583618, 20.74944687], [86.82611084, 20.74971962], [86.82611084, 20.75028038], [86.8263855, 20.75055695], [86.8263855, 20.75083351], [86.82666779, 20.75111008], [86.82666779, 20.75166512], [86.8272171, 20.75222015], [86.8272171, 20.75250053], [86.82777405, 20.75305557], [86.82776642, 20.75360107], [86.82805634, 20.75388718], [86.82805634, 20.75444412], [86.82833099, 20.75472069], [86.82833099, 20.75528145], [86.82861328, 20.75556183], [86.82861328, 20.75610924], [86.82917023, 20.75667191], [86.82917023, 20.7575016], [86.82944489, 20.75777817], [86.82944489, 20.75805473], [86.82971954, 20.7583313], [86.82971954, 20.75860977], [86.83000183, 20.75889015], [86.83000183, 20.76000023], [86.83583069, 20.7658329], [86.83611298, 20.7658329], [86.83622742, 20.76594925], [86.83693695, 20.76667023], [86.83721924, 20.76667023], [86.83805084, 20.76749992], [86.83833313, 20.76749992], [86.83860779, 20.7677784], [86.83889008, 20.7677784], [86.8391571, 20.76806068], [86.83944702, 20.76805496], [86.83972168, 20.76833344], [86.83999634, 20.76833344], [86.84013367, 20.76847267], [86.84055328, 20.76890182], [86.8408432, 20.76890182], [86.84111023, 20.76917076], [86.84139252, 20.76916695], [86.84152985, 20.76930618], [86.84166718, 20.76944351], [86.84194183, 20.7694397], [86.84249878, 20.76999855], [86.84278107, 20.76999855], [86.84417725, 20.77139282], [86.84443665, 20.77139282], [86.84751129, 20.77308083], [86.84951019, 20.77429008], [86.85101318, 20.77482986], [86.85416412, 20.77583313], [86.85527802, 20.77583313], [86.85891724, 20.77569771], [86.86110687, 20.77555084], [86.86301422, 20.77508354], [86.86457825, 20.77454376], [86.86657715, 20.77393532], [86.86808014, 20.77313042], [86.86929321, 20.77259064], [86.87065125, 20.77177811], [86.87185669, 20.77164078], [86.87277985, 20.77166939], [86.87416077, 20.77166939], [86.87444305, 20.77139282], [86.87608337, 20.77071953], [86.87728882, 20.77031517], [86.87843323, 20.76997948], [86.881073, 20.76903534], [86.88299561, 20.76856041], [86.88484955, 20.76822472], [86.88713837, 20.76788902], [86.88906097, 20.76754951], [86.89056396, 20.76734924], [86.89305878, 20.76721954], [86.89555359, 20.76722145], [86.89583588, 20.76694489], [86.89694214, 20.76694489], [86.89722443, 20.76722145], [86.89916992, 20.76722145], [86.89944458, 20.76694489], [86.89971924, 20.76694489], [86.90000153, 20.76722145], [86.90305328, 20.76722145], [86.90333557, 20.76749992], [86.90416718, 20.76749992], [86.90444183, 20.7677784], [86.90499878, 20.7677784], [86.90528107, 20.76806068], [86.90721893, 20.76805496], [86.90750122, 20.76833344], [86.91004944, 20.76832962], [86.91140747, 20.76847076], [86.91340637, 20.76867104], [86.91454315, 20.76867104], [86.9155426, 20.7687397], [86.91796875, 20.76860809], [86.91883087, 20.76853752], [86.91999054, 20.76849365], [86.92053986, 20.76846886], [86.92189789, 20.76832962], [86.92325592, 20.76819992], [86.92524719, 20.76792908], [86.92669678, 20.76781464], [86.92696381, 20.76779366], [86.92711639, 20.76784134], [86.9278183, 20.76806068], [86.9283371, 20.76805496], [86.92861176, 20.76833344], [86.92888641, 20.76805496], [86.93032074, 20.76805496], [86.93055725, 20.76806068], [86.93083191, 20.7677784], [86.93139648, 20.7677784], [86.93165588, 20.76806068], [86.93222046, 20.76749992], [86.93250275, 20.7677784], [86.9327774, 20.7677784], [86.93305206, 20.76749992], [86.9338913, 20.76749992], [86.93509674, 20.76729965], [86.93659973, 20.76689148], [86.93838501, 20.76655579], [86.93952942, 20.76657295], [86.94110107, 20.76649284], [86.94210052, 20.76657295], [86.94361115, 20.76667023], [86.94611359, 20.76666641], [86.94625092, 20.76680565], [86.94638824, 20.76694489], [86.9466629, 20.76694489], [86.94721985, 20.76638794], [86.94777679, 20.76638985], [86.94805908, 20.76667023], [86.9486084, 20.76666641], [86.94874573, 20.76680374], [86.94889069, 20.76694489], [86.94972229, 20.76694489], [86.94999695, 20.76666641], [86.95166779, 20.76666641], [86.95194244, 20.76694489], [86.95220947, 20.76694107], [86.95249939, 20.76722145], [86.95305634, 20.76722145], [86.95333099, 20.76694489], [86.95722198, 20.76694489], [86.95749664, 20.76666641], [86.96089935, 20.76667023], [86.96296692, 20.7667408], [86.96496582, 20.76713943], [86.96639252, 20.76753998], [86.96846771, 20.76828575], [86.9701767, 20.76920319], [86.97167206, 20.76974487], [86.97303009, 20.77028275], [86.97453308, 20.77102089], [86.97538757, 20.77130127], [86.97731018, 20.77130127], [86.97805786, 20.77166748], [86.97833252, 20.77194214], [86.98055267, 20.77194214], [86.98249817, 20.77222061], [86.98278046, 20.77222061], [86.98305511, 20.77194214], [86.98317719, 20.77194214], [86.98332977, 20.77194214], [86.98447418, 20.77174377], [86.98668671, 20.77180862], [86.98770142, 20.77180862], [86.98804474, 20.77180862], [86.98916626, 20.77166748], [86.99054718, 20.77166939], [86.9908371, 20.77139282], [86.99111176, 20.77139282], [86.99138641, 20.77111244], [86.99194336, 20.77111244], [86.99223328, 20.77083015], [86.99250031, 20.77083206], [86.99277496, 20.7705555], [86.99305725, 20.77056122], [86.99415588, 20.7694397], [86.99416351, 20.76916695], [86.99472046, 20.76860809], [86.99472046, 20.76833344], [86.99500275, 20.76805496], [86.99500275, 20.7677784], [86.9952774, 20.76749992], [86.9952774, 20.76667023], [86.99555206, 20.76638985], [86.99555206, 20.76583099], [86.99583435, 20.76555634], [86.99582672, 20.76527977], [86.9963913, 20.76472092], [86.9963913, 20.76444435], [86.99666595, 20.76416779], [86.99666595, 20.76361084], [86.99694824, 20.76333046], [86.99694824, 20.7630558], [86.9972229, 20.7627697], [86.9972229, 20.76250076], [86.99748993, 20.76222038], [86.99749756, 20.76194572], [86.99777985, 20.76166725], [86.99777985, 20.76111031], [86.99833679, 20.76056099], [86.99833679, 20.76000023], [86.99861145, 20.75972939], [86.99861145, 20.75860977], [86.99888611, 20.7583313], [86.99888611, 20.75583267], [86.9991684, 20.75555611], [86.9991684, 20.75499916], [86.99944305, 20.75472069], [86.99944305, 20.75444412], [86.99972534, 20.75305557], [87.0, 20.75333405], [87.00027466, 20.75305557], [87.00054932, 20.75305939], [87.00054932, 20.75278091], [87.0008316, 20.75250053], [87.0008316, 20.75167084], [87.00138855, 20.75111008], [87.00138855, 20.75027847], [87.00195313, 20.75], [87.0019455, 20.74972153], [87.00305176, 20.74861145], [87.0036087, 20.74833488], [87.00389099, 20.74805641], [87.00389099, 20.74749947], [87.00332642, 20.74694061], [87.0036087, 20.74666595], [87.0036087, 20.74638939], [87.00444794, 20.74611282], [87.00444794, 20.74583054], [87.00499725, 20.74555588], [87.0047226, 20.74528122], [87.00499725, 20.74500275], [87.00583649, 20.7447319], [87.00583649, 20.74417114], [87.00694275, 20.74305916], [87.00694275, 20.74138832], [87.00723267, 20.74110985], [87.00694275, 20.74083328], [87.00694275, 20.73944473], [87.0063858, 20.73916626], [87.00668335, 20.73888969], [87.0063858, 20.73861122], [87.0063858, 20.73777771], [87.00611115, 20.73750114], [87.00611115, 20.73611069], [87.00583649, 20.73583031], [87.00583649, 20.73472214], [87.0055542, 20.73444366], [87.0055542, 20.73277855], [87.00527954, 20.73250008], [87.00527954, 20.73139191], [87.00499725, 20.73110962], [87.00499725, 20.7294445], [87.0047226, 20.72916603], [87.0047226, 20.72833061], [87.00416565, 20.72777748], [87.00417328, 20.72639084], [87.00389099, 20.72611046], [87.00389099, 20.72500038], [87.00372314, 20.72483635], [87.0036087, 20.72472191], [87.0036087, 20.72305679], [87.00333405, 20.72277832], [87.00332642, 20.72167015], [87.0027771, 20.72110939], [87.0027771, 20.71999931], [87.00222015, 20.71944046], [87.00222015, 20.7183342], [87.00166321, 20.71777725], [87.00166321, 20.71694183], [87.00138855, 20.71666718], [87.00138855, 20.71582985], [87.00111389, 20.71555519], [87.00110626, 20.71528053], [87.0008316, 20.71499825], [87.0008316, 20.71471977], [87.00055695, 20.71444511], [87.00054932, 20.71417046], [87.0, 20.71388817], [86.99973297, 20.71340752], [86.9994278, 20.71280861], [86.99899292, 20.71223831], [86.99855804, 20.71174049], [86.99811554, 20.71137428], [86.99773407, 20.71105957], [86.99740601, 20.71076012], [86.99700165, 20.71053123], [86.99658966, 20.71027946], [86.9961319, 20.71004295], [86.99559021, 20.70981026], [86.99500275, 20.70951271], [86.99429321, 20.70946121], [86.99356079, 20.70952034], [86.99285126, 20.70968628], [86.99214172, 20.70972061], [86.99146271, 20.70975876], [86.99088287, 20.70994949], [86.99040222, 20.71014786], [86.9899826, 20.71027946], [86.98957062, 20.71042061], [86.98912048, 20.71058083], [86.98860931, 20.71080971], [86.98808289, 20.71101189], [86.9875412, 20.71120071], [86.98701477, 20.71135521], [86.98641968, 20.71138954], [86.98581696, 20.71145058], [86.98583221, 20.71167946], [86.98555756, 20.71166611], [86.98527527, 20.71194458], [86.98500061, 20.71194458], [86.98472595, 20.71222305], [86.98443604, 20.71222115], [86.98416901, 20.71249962], [86.98306274, 20.71249962], [86.98278046, 20.71277809], [86.98222351, 20.71277618], [86.98194122, 20.71305466], [86.98166656, 20.71305466], [86.98139191, 20.71333313], [86.98083496, 20.71333313], [86.98055267, 20.7136116], [86.98007202, 20.71364975], [86.97962952, 20.71374512], [86.9792099, 20.71385956], [86.97873688, 20.71390152], [86.9782486, 20.71393776], [86.97780609, 20.71409988], [86.97734833, 20.71416092], [86.97688293, 20.71417046], [86.97641754, 20.71418953], [86.97598267, 20.71430969], [86.97553253, 20.71442032], [86.97506714, 20.71445084], [86.97460938, 20.71450806], [86.97416687, 20.71471024], [86.97370148, 20.71488762], [86.97318268, 20.7149868], [86.97277832, 20.71499443], [86.97261047, 20.71499825], [86.97197723, 20.71495056], [86.97130585, 20.71477127], [86.97059631, 20.71478081], [86.96985626, 20.71495056], [86.96910095, 20.71493912], [86.96766663, 20.7151413], [86.96639252, 20.71499825], [86.96577454, 20.71499825], [86.96531677, 20.71500015], [86.96486664, 20.71499825], [86.96440887, 20.71500015], [86.96394348, 20.71499443], [86.9634552, 20.7149334], [86.96292877, 20.71475983], [86.96232605, 20.71471977], [86.9617157, 20.71468163], [86.96115875, 20.71452522], [86.96060181, 20.71449089], [86.96009064, 20.71446991], [86.95962524, 20.71445084], [86.95921326, 20.71445084], [86.9588089, 20.71442986], [86.95838928, 20.71444321], [86.95793152, 20.71444321], [86.95742035, 20.71446037], [86.95690155, 20.714571], [86.95635986, 20.71466064], [86.95580292, 20.71471405], [86.95523071, 20.71472168], [86.95466614, 20.71474266], [86.95419312, 20.71486092], [86.95375061, 20.71498108], [86.95333099, 20.71499825], [86.95294952, 20.71499825], [86.9525528, 20.71499825], [86.95214844, 20.71499825], [86.95174408, 20.71504211], [86.95139313, 20.71522331], [86.9512558, 20.71520805], [86.95104218, 20.71518517], [86.95065308, 20.71503067], [86.95024109, 20.71499825], [86.94980621, 20.7150383], [86.94934082, 20.71515274], [86.94886017, 20.71529961], [86.94838715, 20.71550179], [86.94786835, 20.71557045], [86.9473877, 20.71568108], [86.94698334, 20.71583939], [86.94658661, 20.71602631], [86.9461441, 20.7161026], [86.94563293, 20.71615028], [86.94509125, 20.71635056], [86.94444275, 20.7163887], [86.94368744, 20.71640015], [86.94288635, 20.71645927], [86.94211578, 20.71663094], [86.94130707, 20.71664429], [86.94078064, 20.71656418], [86.94052124, 20.71652985], [86.93978882, 20.71640968], [86.93911743, 20.7163887], [86.93850708, 20.71640015], [86.93797302, 20.71648979], [86.93746185, 20.71664047], [86.93694305, 20.7166729], [86.93641663, 20.7166729], [86.93615723, 20.71666527], [86.93589783, 20.71665764], [86.93539429, 20.71660042], [86.93492126, 20.71643066], [86.9344101, 20.71635056], [86.93393707, 20.71615982], [86.93344116, 20.71609116], [86.93292236, 20.71597672], [86.93239594, 20.71585274], [86.93187714, 20.7157402], [86.93141174, 20.71556664], [86.93096924, 20.71540833], [86.93054199, 20.71525192], [86.93015289, 20.71503067], [86.92970276, 20.7148819], [86.92919922, 20.71474266], [86.92871094, 20.71465111], [86.92825317, 20.71446991], [86.92777252, 20.71430016], [86.92733002, 20.71414566], [86.92690277, 20.71390915], [86.92642975, 20.71366119], [86.92592621, 20.71340752], [86.92547607, 20.71311951], [86.92500305, 20.7129097], [86.92450714, 20.71272087], [86.92407227, 20.71249008], [86.92363739, 20.71223068], [86.92314911, 20.7120266], [86.92260742, 20.71186066], [86.92212677, 20.71157074], [86.92167664, 20.71121979], [86.9212265, 20.71084976], [86.92077637, 20.71055031], [86.92037201, 20.71027756], [86.91998291, 20.71003151], [86.91951752, 20.70991135], [86.9190979, 20.70970917], [86.91871643, 20.70946121], [86.91828918, 20.70926857], [86.9178009, 20.70914268], [86.91736603, 20.70890808], [86.91689301, 20.70870018], [86.91638184, 20.7085743], [86.916008, 20.70833588], [86.91567993, 20.70809746], [86.91545868, 20.70801353], [86.91529083, 20.70795059], [86.91487885, 20.70776939], [86.91441345, 20.70755005], [86.91390991, 20.70732117], [86.91343689, 20.70704079], [86.91303253, 20.70675278], [86.91261292, 20.70651436], [86.91216278, 20.70632362], [86.91173553, 20.70610046], [86.91131592, 20.70583916], [86.91086578, 20.70560074], [86.91039276, 20.70536995], [86.90994263, 20.70507813], [86.90946198, 20.70482063], [86.90901184, 20.70455742], [86.90862274, 20.70425034], [86.90822601, 20.70392036], [86.9078064, 20.70363426], [86.90737915, 20.70334053], [86.90692902, 20.70305634], [86.90647888, 20.70278168], [86.90602875, 20.70248985], [86.9056015, 20.70222282], [86.90516663, 20.70194435], [86.90470886, 20.70166969], [86.90419006, 20.70143127], [86.90361023, 20.70124054], [86.90302277, 20.70106697], [86.9025116, 20.70083046], [86.90203094, 20.70054817], [86.90157318, 20.70027733], [86.90110016, 20.70003128], [86.90058136, 20.69985962], [86.90011597, 20.69965172], [86.89978027, 20.69932365], [86.89949799, 20.69896317], [86.89919281, 20.69864655], [86.8988266, 20.69839096], [86.89832306, 20.69829178], [86.8979187, 20.69804001], [86.89752197, 20.6977787], [86.89711761, 20.69754028], [86.89666748, 20.69736099], [86.8962326, 20.69718361], [86.89585114, 20.69692802], [86.89550018, 20.69664955], [86.89520264, 20.69634056], [86.89482117, 20.69615173], [86.89437866, 20.69602966], [86.8939209, 20.69581032], [86.89341736, 20.69549942], [86.89289093, 20.69512177], [86.89231873, 20.69468117], [86.89175415, 20.69419861], [86.89116669, 20.69377708], [86.89067841, 20.69334984], [86.89022064, 20.69299126], [86.88981628, 20.69259071], [86.8894043, 20.69226074], [86.88897705, 20.69194984], [86.88854218, 20.69166183], [86.88813782, 20.6913681], [86.88777924, 20.69106102], [86.88743591, 20.69077873], [86.88704681, 20.69054031], [86.88667297, 20.69028282], [86.88626862, 20.69000244], [86.88585663, 20.68971825], [86.88546753, 20.68943977], [86.88513947, 20.68913078], [86.88487244, 20.6887722], [86.88455963, 20.68844795], [86.88420105, 20.68810081], [86.88375092, 20.68774033], [86.88331604, 20.68731499], [86.88286591, 20.68686104], [86.88247681, 20.68634415], [86.88201141, 20.68590164], [86.88148499, 20.6855278], [86.88098145, 20.68514061], [86.88056946, 20.68469048], [86.88020325, 20.68424988], [86.87976074, 20.68392181], [86.87937927, 20.68359947], [86.87908173, 20.6832695], [86.8787384, 20.68303108], [86.87843323, 20.68276024], [86.87812042, 20.68243027], [86.87782288, 20.68197823], [86.87746429, 20.68152618], [86.87708282, 20.68118858], [86.8767395, 20.68089294], [86.87644196, 20.68060684], [86.87615204, 20.68032074], [86.87583923, 20.68003273], [86.8755188, 20.67969131], [86.87517548, 20.67934036], [86.87482452, 20.67898941], [86.8744812, 20.6786499], [86.87412262, 20.67835045], [86.87374115, 20.67806053], [86.87335205, 20.67778778], [86.87301636, 20.67745972], [86.87275696, 20.67707062], [86.87245178, 20.67671013], [86.87210083, 20.67639923], [86.87172699, 20.67610931], [86.87135315, 20.67583084], [86.87097931, 20.67555046], [86.87062836, 20.67525101], [86.87032318, 20.67490959], [86.87008667, 20.67454529], [86.86988831, 20.67420006], [86.86966705, 20.67391968], [86.86943817, 20.6736908], [86.8691864, 20.67345047], [86.86897278, 20.67314529], [86.86868286, 20.67283058], [86.86843109, 20.67236519], [86.8682785, 20.67171288], [86.86794281, 20.67116547], [86.86750031, 20.67071915], [86.86705017, 20.67030907], [86.86663818, 20.66994858], [86.8663559, 20.66954041], [86.86608887, 20.66921043], [86.8658371, 20.66892052], [86.86560059, 20.66862106], [86.86532593, 20.66831207], [86.86502075, 20.6679821], [86.86470032, 20.66760826], [86.86433411, 20.66723442], [86.86392975, 20.66685867], [86.86351776, 20.6664505], [86.86302948, 20.6661377], [86.86252594, 20.66584969], [86.86199188, 20.66550255], [86.86138916, 20.66500282], [86.86110687, 20.66500282], [86.86083221, 20.66477394], [86.85917664, 20.66472054], [86.85888672, 20.66500282], [86.85832977, 20.66500282], [86.85722351, 20.6661129], [86.85721588, 20.66722107], [86.85749817, 20.66749954], [86.85749817, 20.66833305], [86.85778046, 20.66860962], [86.85778046, 20.66916656], [86.85832977, 20.6697197], [86.85832977, 20.67000008], [86.86027527, 20.67194366], [86.8602829, 20.67222023], [86.86083221, 20.67278099], [86.86083221, 20.67305946], [86.86138916, 20.67361069], [86.86444092, 20.67666626], [86.86444092, 20.67694092], [86.86499023, 20.67750168], [86.86499786, 20.67777824], [86.86528015, 20.67804909], [86.86528015, 20.67889023], [86.86499023, 20.67917061], [86.86499786, 20.67944527], [86.86472321, 20.67971992], [86.86472321, 20.68000031], [86.86444092, 20.68028069], [86.86444092, 20.68056107], [86.86332703, 20.68167114], [86.86277771, 20.68166733], [86.86250305, 20.6819458], [86.86222076, 20.6819458], [86.86194611, 20.68222237], [86.86055756, 20.68222237], [86.8602829, 20.68250084], [86.85832977, 20.68250084], [86.85806274, 20.68278122], [86.85778046, 20.68278122], [86.85749817, 20.68305969], [86.85722351, 20.68305588], [86.85694122, 20.68333054], [86.85694122, 20.68416977], [86.85806274, 20.68527985], [86.85806274, 20.68556023], [86.85944366, 20.68694496], [86.85944366, 20.68722153], [86.85972595, 20.68749046], [86.85972595, 20.68778038], [86.86027527, 20.68833351], [86.86027527, 20.68861008], [86.86250305, 20.69083405], [86.86305237, 20.69083023], [86.86332703, 20.69111252], [86.86360931, 20.69111252], [86.8638916, 20.6913929], [86.86694336, 20.6913929], [86.86723328, 20.69166946], [86.86805725, 20.69166756], [86.8681488, 20.69175911], [86.86833191, 20.69194221], [86.86888885, 20.69194221], [86.86916351, 20.6922226], [86.8694458, 20.6922226], [86.87000275, 20.69277954], [86.8702774, 20.69277954], [86.87110901, 20.69361115], [86.87110901, 20.69388962], [86.87166595, 20.69444466], [86.87166595, 20.69472122], [86.87194824, 20.69499969], [86.87194824, 20.69528008], [86.87416077, 20.69750023], [86.87416077, 20.69778061], [86.875, 20.69861031], [86.87526703, 20.69861031], [86.87555695, 20.69889069], [86.87582397, 20.69894218], [86.87590027, 20.69895554], [86.87638855, 20.69944382], [86.87666321, 20.69944382], [86.8769455, 20.69972229], [86.87722015, 20.69972038], [86.8777771, 20.70028114], [86.87805176, 20.70028114], [86.87832642, 20.70055962], [86.8786087, 20.70055962], [86.87944794, 20.70139122], [86.8797226, 20.70139122], [86.87999725, 20.70166969], [86.8805542, 20.70166588], [86.88083649, 20.70194435], [86.88111115, 20.70194435], [86.88388824, 20.70471954], [86.88388824, 20.70500183], [86.8841629, 20.7052803], [86.8841629, 20.70555305], [86.88444519, 20.70583344], [86.88445282, 20.70611191], [86.88471985, 20.70639038], [86.88471985, 20.70666695], [86.88527679, 20.70722008], [86.88527679, 20.7080555], [86.88500214, 20.70833015], [86.88500214, 20.70862007], [86.88471985, 20.70889091], [86.88471985, 20.70916748], [86.88444519, 20.70944595], [86.88445282, 20.70972061], [86.8841629, 20.71000099], [86.8841629, 20.71027756], [86.88360596, 20.71083069], [86.88360596, 20.71111107], [86.88194275, 20.71277809], [86.88166809, 20.71277618], [86.8813858, 20.71305466], [86.88111115, 20.71305466], [86.8805542, 20.7136116], [86.88028717, 20.7136097], [86.87999725, 20.71388817], [86.8797226, 20.71388817], [86.87944794, 20.71417046], [86.87917328, 20.71417046], [86.87889099, 20.71445084], [86.8786087, 20.71444511], [86.87833405, 20.71472168], [86.87805176, 20.71471977], [86.87805176, 20.71499825], [86.8777771, 20.71528053], [86.8777771, 20.71555519], [86.87750244, 20.71582985], [86.87750244, 20.71610832], [86.87722015, 20.7163887], [86.87722015, 20.71944427], [86.87750244, 20.71972466], [86.87750244, 20.72083473], [86.8777771, 20.72110939], [86.8777771, 20.72138977], [86.87805176, 20.72166634], [86.87805176, 20.72194481], [86.87832642, 20.72221947], [86.87833405, 20.72277832], [86.8786087, 20.72305107], [86.8786087, 20.7238903], [86.87889099, 20.72416687], [86.87889099, 20.72472191], [86.87916565, 20.72500038], [86.87917328, 20.72583008], [86.87944794, 20.72611046], [86.87944794, 20.72694397], [86.8797226, 20.72722054], [86.8797226, 20.72750092], [86.87944794, 20.72777748], [86.87944794, 20.72805977], [86.87889099, 20.72860909], [86.87889099, 20.73250008], [86.87832642, 20.73306084], [86.87805176, 20.73278999], [86.87805176, 20.73250008], [86.8777771, 20.7322197], [86.8777771, 20.73027992], [86.87750244, 20.72999954], [86.87750244, 20.72944069], [86.8777771, 20.72916603], [86.8777771, 20.72833061], [86.87805176, 20.72805595], [86.87805176, 20.72611046], [86.8777771, 20.72583008], [86.8777771, 20.72527695], [86.87750244, 20.72500038], [86.87750244, 20.72472], [86.87722015, 20.72444534], [86.87722015, 20.72417068], [86.87695313, 20.7238903], [86.87695313, 20.72361946], [86.87666321, 20.72332954], [86.87666321, 20.72277832], [86.87638855, 20.72249985], [86.87638855, 20.72194099], [86.87611389, 20.72166634], [86.87610626, 20.72027969], [86.8758316, 20.72000122], [86.8758316, 20.71889114], [86.87555695, 20.71861267], [86.87555695, 20.71833038], [86.8758316, 20.71805573], [86.8758316, 20.71722031], [86.87611389, 20.71694374], [86.87611389, 20.71610832], [86.87638855, 20.71582985], [86.87638855, 20.71528053], [86.87750244, 20.71417046], [86.87750244, 20.71388817], [86.87805176, 20.71333122], [86.87833405, 20.71333313], [86.8786087, 20.71305466], [86.87889099, 20.71305466], [86.87916565, 20.71277618], [86.87944794, 20.71277809], [86.87999725, 20.71222115], [86.88027954, 20.71222305], [86.88083649, 20.71166611], [86.88111115, 20.71167946], [86.88223267, 20.71055984], [86.88249969, 20.71055984], [86.8833313, 20.70972061], [86.8833313, 20.70916748], [86.88388824, 20.70862007], [86.88388824, 20.70722008], [86.88361359, 20.7069416], [86.88361359, 20.70666695], [86.88305664, 20.70611191], [86.88305664, 20.70583344], [86.88277435, 20.70583344], [86.8805542, 20.70360947], [86.88027954, 20.70360947], [86.8797226, 20.70305634], [86.87944794, 20.70306015], [86.8786087, 20.70222092], [86.87833405, 20.70222282], [86.8777771, 20.70166588], [86.87750244, 20.70166969], [86.87666321, 20.70083046], [86.87638855, 20.70083427], [86.87611389, 20.7005558], [86.8758316, 20.70055962], [86.87526703, 20.70000076], [86.875, 20.70000076], [86.87473297, 20.69972038], [86.87444305, 20.69972229], [86.87402344, 20.69930458], [86.87361145, 20.69888878], [86.87333679, 20.69889069], [86.8713913, 20.69695091], [86.8713913, 20.69668007], [86.87111664, 20.69639015], [86.87111664, 20.69610977], [86.87083435, 20.69583321], [86.87083435, 20.69555473], [86.87055206, 20.69527817], [86.87055206, 20.69499969], [86.8702774, 20.69472122], [86.8702774, 20.69444466], [86.86916351, 20.69333458], [86.86888885, 20.69333458], [86.8686142, 20.69305611], [86.86833191, 20.69305992], [86.86805725, 20.69277954], [86.86750031, 20.69277954], [86.86723328, 20.69305992], [86.86694336, 20.69305992], [86.8666687, 20.69277954], [86.8638916, 20.69277954], [86.86332703, 20.6922226], [86.86277771, 20.6922226], [86.86250305, 20.69194221], [86.86222076, 20.69194221], [86.86206055, 20.69178391], [86.86166382, 20.69138908], [86.86138916, 20.6913929], [86.85832977, 20.6883297], [86.85832977, 20.68805504], [86.85639191, 20.68610954], [86.85639191, 20.68583298], [86.85610962, 20.68555641], [86.85611725, 20.68527985], [86.85582733, 20.68499947], [86.85582733, 20.68472099], [86.85555267, 20.68444443], [86.85555267, 20.68305969], [86.85694122, 20.68167114], [86.85721588, 20.68167114], [86.85749817, 20.68139076], [86.85778046, 20.68139076], [86.85806274, 20.68111038], [86.85832977, 20.68111038], [86.85861206, 20.68083], [86.85944366, 20.68083382], [86.85972595, 20.68055534], [86.86000061, 20.68056107], [86.8602829, 20.68028069], [86.86083221, 20.68028069], [86.86110687, 20.68000031], [86.86194611, 20.68000031], [86.86222076, 20.67971992], [86.86277771, 20.67972374], [86.86360931, 20.67888832], [86.86360931, 20.67831993], [86.86166382, 20.6763916], [86.86138916, 20.6763916], [86.8602829, 20.67528152], [86.86000061, 20.67528152], [86.86000061, 20.67499924], [86.85861206, 20.67361069], [86.85861206, 20.67333031], [86.85832977, 20.67305565], [86.85832977, 20.67278099], [86.85806274, 20.67250824], [86.85806274, 20.67222023], [86.85666656, 20.67083359], [86.85666656, 20.67055511], [86.85639191, 20.67028046], [86.85639191, 20.66945076], [86.85611725, 20.66917038], [86.85611725, 20.66833115], [86.85583496, 20.66805649], [86.85582733, 20.66777992], [86.85555267, 20.66749954], [86.85555267, 20.66638184], [86.85583496, 20.6661129], [86.85582733, 20.66555977], [86.85694122, 20.66444016], [86.85722351, 20.66444206], [86.85778046, 20.66389084], [86.85806274, 20.66389275], [86.85832977, 20.66361237], [86.85888672, 20.66361237], [86.85972595, 20.66278076], [86.85917664, 20.66221809], [86.85916901, 20.66194534], [86.85871887, 20.66163063], [86.85832214, 20.66127968], [86.85791779, 20.66097641], [86.85752869, 20.66067123], [86.85721588, 20.66033554], [86.85692596, 20.66003036], [86.85665131, 20.65977097], [86.85637665, 20.65954971], [86.85611725, 20.6593399], [86.85582733, 20.65909004], [86.85555267, 20.65878105], [86.85523224, 20.65845108], [86.85484314, 20.65815163], [86.85449219, 20.65781784], [86.85415649, 20.65747261], [86.85385895, 20.65706062], [86.85352325, 20.65672493], [86.85312653, 20.65644073], [86.85276031, 20.65615463], [86.85237885, 20.65585709], [86.8519516, 20.65555954], [86.85150909, 20.65526772], [86.85106659, 20.65496826], [86.85058594, 20.65471268], [86.85012054, 20.65443993], [86.84964752, 20.65416718], [86.84915161, 20.65388107], [86.8486557, 20.65361595], [86.84815979, 20.6533699], [86.84765625, 20.65315819], [86.84716797, 20.65300941], [86.84668732, 20.65281105], [86.84623718, 20.65261078], [86.84578705, 20.65237999], [86.84532166, 20.65217972], [86.84487152, 20.65199852], [86.84436035, 20.65191078], [86.84383392, 20.65188789], [86.84332275, 20.65190125], [86.84287262, 20.65197945], [86.842453, 20.65211105], [86.84200287, 20.65223885], [86.84155273, 20.65244293], [86.84115601, 20.6527729], [86.84083557, 20.65315628], [86.84055328, 20.65350914], [86.84030151, 20.6538105], [86.84011078, 20.65409279], [86.83999634, 20.65439987], [86.8398819, 20.65469933], [86.83975983, 20.65498924], [86.8396759, 20.65530968], [86.83955383, 20.65563774], [86.83944702, 20.65603065], [86.83933258, 20.6565094], [86.83921051, 20.65703964], [86.83912659, 20.65759087], [86.83900452, 20.65811729], [86.83892059, 20.6586113], [86.83888245, 20.65906143], [86.83882141, 20.65945435], [86.83868408, 20.65979195], [86.83862305, 20.6601696], [86.83853912, 20.66057777], [86.83838654, 20.66096306], [86.83827209, 20.66140175], [86.83809662, 20.66183853], [86.83795166, 20.66230011], [86.83777618, 20.66274071], [86.83760071, 20.66319084], [86.83744812, 20.66365814], [86.8372345, 20.66414833], [86.83699036, 20.66469955], [86.83673859, 20.66533089], [86.83644867, 20.66597939], [86.83609009, 20.66654968], [86.83570099, 20.66707039], [86.83534241, 20.66752815], [86.8350296, 20.66794586], [86.83474731, 20.66834068], [86.83451843, 20.6687603], [86.83421326, 20.66912842], [86.83387756, 20.6695118], [86.83351898, 20.6699028], [86.83313751, 20.67028618], [86.83274841, 20.67066956], [86.83235931, 20.67103958], [86.83193207, 20.67136955], [86.83149719, 20.67167091], [86.83107758, 20.67196083], [86.8306427, 20.67222977], [86.83022308, 20.67250824], [86.82978821, 20.67277527], [86.82936096, 20.67304039], [86.82892609, 20.67331123], [86.82847595, 20.67359543], [86.82800293, 20.67387009], [86.82745361, 20.67412949], [86.82686615, 20.67436028], [86.82624054, 20.67455101], [86.82563782, 20.67475128], [86.82508087, 20.67497063], [86.82454681, 20.67515945], [86.82404327, 20.67531967], [86.82357025, 20.67547607], [86.82309723, 20.67560005], [86.82266998, 20.67575645], [86.8221817, 20.6758709], [86.82171631, 20.67601967], [86.82124329, 20.67613029], [86.82077026, 20.67624092], [86.8203125, 20.67633057], [86.81985474, 20.67640114], [86.81939697, 20.67649078], [86.81890869, 20.6765995], [86.81838989, 20.67667961], [86.81785583, 20.67679024], [86.81729889, 20.67687798], [86.81672668, 20.67699432], [86.8161087, 20.67706108], [86.81552887, 20.67707062], [86.81505585, 20.67699814], [86.81459045, 20.67701149], [86.81408691, 20.67703819], [86.81350708, 20.67704964], [86.81291962, 20.67713737], [86.81229401, 20.67717171], [86.81202698, 20.67711067], [86.81172943, 20.67704201], [86.811203, 20.67695045], [86.81069183, 20.6769104], [86.81015015, 20.67690659], [86.80955505, 20.67694473], [86.80885315, 20.67694092], [86.80815125, 20.67688942], [86.80741882, 20.67686081], [86.80665588, 20.67679024], [86.80587769, 20.67671776], [86.80506897, 20.67667961], [86.80426788, 20.67662048]]]]}}, {\\\"id\\\": \\\"24\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"Union Territory\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.27_1\\\", \\\"HASC_1\\\": \\\"IN.PY\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Puducherry\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"Union Territor\\\", \\\"VARNAME_1\\\": \\\"Pondicherry|Puduchcheri|Pondich\\\\u00e9ry\\\", \\\"apm25_popweighted\\\": 66.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1272.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1686.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2957.0, \\\"geo-id\\\": 24, \\\"hpm25_child_popweighted\\\": 260.0, \\\"hpm25_female_popweighted\\\": 299.0, \\\"hpm25_male_popweighted\\\": 215.0, \\\"location\\\": \\\"Puducherry\\\", \\\"mort_apm25_6cod_mean_total\\\": 245.0, \\\"mort_hpm25_6cod_mean_total\\\": 327.0, \\\"mort_tpm25_6cod_mean_total\\\": 572.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[79.84485626, 10.82653236], [79.84485626, 10.82625103], [79.84541321, 10.82625103], [79.84541321, 10.82569122], [79.84486389, 10.82569504], [79.84486389, 10.82541656], [79.84401703, 10.82541943], [79.84401703, 10.82514095], [79.84348297, 10.82514095], [79.84348297, 10.82486057], [79.8429184, 10.82486057], [79.8429184, 10.82458305], [79.84208679, 10.82458305], [79.84208679, 10.82430458], [79.84152985, 10.82430935], [79.84152985, 10.82403088], [79.84040833, 10.82403088], [79.84040833, 10.82375145], [79.8401413, 10.82375145], [79.8401413, 10.82430935], [79.84041595, 10.82430458], [79.84041595, 10.82458305], [79.8409729, 10.82458305], [79.8409729, 10.82486057], [79.84124756, 10.82486057], [79.84124756, 10.82514095], [79.84179688, 10.82514095], [79.84179688, 10.82541943], [79.84236145, 10.82541656], [79.84236145, 10.82569504], [79.8429184, 10.82569504], [79.8429184, 10.82597256], [79.84348297, 10.82597065], [79.84348297, 10.82625103], [79.84401703, 10.82625103], [79.84401703, 10.82653236], [79.84485626, 10.82653236]]], [[[79.85124969, 10.81377125], [79.84329224, 10.81225109], [79.83571625, 10.8117218], [79.8319931, 10.81137085], [79.81976318, 10.81110191], [79.81333923, 10.81408119], [79.81167603, 10.8157692], [79.81368256, 10.81837177], [79.81326294, 10.82874012], [79.81204224, 10.83282185], [79.80819702, 10.8313818], [79.80589294, 10.82804012], [79.80307007, 10.83368969], [79.79667664, 10.83589172], [79.7931366, 10.83949089], [79.79113007, 10.84570122], [79.7922821, 10.84883118], [79.79563141, 10.84381199], [79.79940796, 10.84468269], [79.80338287, 10.84731007], [79.80815887, 10.8488903], [79.80745697, 10.8526907], [79.80345917, 10.85748005], [79.79727173, 10.85809135], [79.78956604, 10.8617506], [79.79178619, 10.86394978], [79.80558014, 10.86365032], [79.81138611, 10.86443138], [79.80898285, 10.86744022], [79.80278778, 10.8711319], [79.79245758, 10.87000179], [79.78833008, 10.87292957], [79.78486633, 10.87355042], [79.78026581, 10.87131023], [79.77562714, 10.87578106], [79.7724762, 10.87325191], [79.76698303, 10.87276173], [79.76735687, 10.87555122], [79.77005768, 10.87798119], [79.77493286, 10.87890244], [79.77635956, 10.88167953], [79.77317047, 10.8895607], [79.76122284, 10.8914299], [79.76045227, 10.88315201], [79.75694275, 10.88010025], [79.75186157, 10.88085938], [79.75415802, 10.88665962], [79.74919891, 10.88941956], [79.74794769, 10.8952198], [79.74532318, 10.89307976], [79.74578094, 10.88724136], [79.74302673, 10.8819418], [79.7414093, 10.88329124], [79.74220276, 10.89054966], [79.74180603, 10.89444065], [79.74485016, 10.89674854], [79.74298096, 10.89936066], [79.72688293, 10.8974514], [79.72838593, 10.90229034], [79.72557068, 10.90358925], [79.72590637, 10.90690136], [79.72389984, 10.90802193], [79.72119141, 10.9052], [79.71958923, 10.90579128], [79.72083282, 10.91070175], [79.70922852, 10.91320038], [79.70863342, 10.91415501], [79.70803833, 10.91510105], [79.71034241, 10.9174099], [79.71042633, 10.91913986], [79.70423126, 10.91887093], [79.70437622, 10.92103958], [79.70848083, 10.9211607], [79.70767212, 10.92341137], [79.70847321, 10.92671108], [79.71299744, 10.9279213], [79.71585083, 10.93050957], [79.72022247, 10.93222046], [79.72122955, 10.93531036], [79.7191925, 10.94054127], [79.71555328, 10.9382906], [79.71481323, 10.93412971], [79.70934296, 10.93558121], [79.70435333, 10.93518925], [79.70323944, 10.9382906], [79.70287323, 10.94562054], [79.70391846, 10.94761086], [79.70365143, 10.95186138], [79.71150208, 10.95227146], [79.71546173, 10.95328999], [79.72093201, 10.95060062], [79.7266922, 10.95235062], [79.73169708, 10.94816017], [79.73265076, 10.94116116], [79.74009705, 10.94365025], [79.7455368, 10.9433403], [79.74572754, 10.94929028], [79.74456024, 10.95447063], [79.73992157, 10.95578098], [79.73813629, 10.95860958], [79.73914337, 10.96146107], [79.74131012, 10.96326065], [79.74381256, 10.96701145], [79.73951721, 10.9660902], [79.7381897, 10.96931934], [79.73015594, 10.97101116], [79.73163605, 10.97529125], [79.72986603, 10.9813509], [79.73017883, 10.98510933], [79.73190308, 10.98703957], [79.73721313, 10.98910046], [79.74305725, 10.98506069], [79.74823761, 10.98153114], [79.75260162, 10.97989178], [79.76051331, 10.98058128], [79.76521301, 10.97919941], [79.77227783, 10.97956181], [79.77435303, 10.97724247], [79.77392578, 10.97101116], [79.77723694, 10.96793079], [79.78341675, 10.96733189], [79.78705597, 10.9698], [79.78962708, 10.97338104], [79.79036713, 10.97853184], [79.79191589, 10.98092937], [79.79644775, 10.98306942], [79.79741669, 10.98490047], [79.80145264, 10.98621178], [79.80256653, 10.9848814], [79.80454254, 10.98287964], [79.80979919, 10.9820509], [79.81202698, 10.98295975], [79.81302643, 10.98485184], [79.81389618, 10.98714924], [79.82478333, 10.98662853], [79.82491302, 10.98479939], [79.82441711, 10.97949123], [79.8344574, 10.97681999], [79.83448029, 10.97671127], [79.83537292, 10.97662163], [79.83763885, 10.97643948], [79.84440613, 10.97597027], [79.85058594, 10.97579002], [79.85457611, 10.97602177], [79.85457611, 10.97431087], [79.85430908, 10.97431087], [79.85430908, 10.97264004], [79.85402679, 10.97264004], [79.85402679, 10.97097015], [79.85375214, 10.97097206], [79.85375214, 10.96930599], [79.85346985, 10.96931934], [79.85346985, 10.96403027], [79.85320282, 10.96403027], [79.85320282, 10.96208096], [79.8529129, 10.96208286], [79.8529129, 10.96152687], [79.85320282, 10.96153164], [79.85320282, 10.96097088], [79.85346985, 10.96097088], [79.85346985, 10.9598608], [79.85319519, 10.9598608], [79.85319519, 10.95958328], [79.8529129, 10.95958328], [79.8529129, 10.95930481], [79.85320282, 10.95930862], [79.85320282, 10.95514107], [79.8529129, 10.95514107], [79.8529129, 10.95347023], [79.85319519, 10.95347309], [79.85319519, 10.95291615], [79.85346985, 10.95292091], [79.85346985, 10.95153141], [79.85320282, 10.95153141], [79.85320282, 10.95069027], [79.8529129, 10.95069408], [79.8529129, 10.94847202], [79.85319519, 10.94847202], [79.85319519, 10.94569397], [79.8529129, 10.94569397], [79.8529129, 10.94513988], [79.85320282, 10.94515133], [79.85320282, 10.94347191], [79.8529129, 10.94347191], [79.8529129, 10.94180584], [79.85320282, 10.94180965], [79.85320282, 10.94153023], [79.85346985, 10.94153023], [79.85346985, 10.93931007], [79.85375214, 10.93931007], [79.85375214, 10.93236065], [79.85402679, 10.93236065], [79.85402679, 10.92319393], [79.85430908, 10.92319393], [79.85430908, 10.9179163], [79.85402679, 10.91792011], [79.85402679, 10.91652966], [79.85375214, 10.91652966], [79.85375214, 10.91514015], [79.85346985, 10.91514015], [79.85346985, 10.91374969], [79.85320282, 10.91374969], [79.85320282, 10.91346931], [79.85097504, 10.91347122], [79.85097504, 10.91319561], [79.85041809, 10.91319561], [79.85041809, 10.91291809], [79.84764099, 10.91292], [79.84764099, 10.91235924], [79.84819794, 10.9123621], [79.84819794, 10.91208267], [79.84874725, 10.91208267], [79.84874725, 10.91180515], [79.84928894, 10.91180992], [79.84928894, 10.91125202], [79.85098267, 10.91125202], [79.85098267, 10.91152954], [79.85124969, 10.91152668], [79.85124969, 10.91208267], [79.85152435, 10.91208267], [79.85152435, 10.9123621], [79.85263824, 10.9123621], [79.85263824, 10.91208267], [79.8529129, 10.91208267], [79.8529129, 10.91069317], [79.85263824, 10.91069317], [79.85263824, 10.9090271], [79.85234833, 10.9090414], [79.85234833, 10.90819073], [79.8520813, 10.90819454], [79.8520813, 10.90736103], [79.85236359, 10.90736103], [79.85234833, 10.90486145], [79.85263824, 10.90486145], [79.85263824, 10.90236092], [79.85234833, 10.90236092], [79.85234833, 10.89513969], [79.8520813, 10.89513969], [79.8520813, 10.89264011], [79.85234833, 10.89264011], [79.85234833, 10.89235973], [79.85263824, 10.89235973], [79.85263824, 10.89013767], [79.8529129, 10.89013958], [79.8529129, 10.88986015], [79.85236359, 10.88986206], [79.85236359, 10.88958359], [79.8520813, 10.88958359], [79.8520813, 10.88930607], [79.85180664, 10.88931274], [79.85180664, 10.88903046], [79.85151672, 10.88903046], [79.85151672, 10.88875198], [79.85124969, 10.88875198], [79.85124969, 10.88791084], [79.85097504, 10.88791561], [79.85097504, 10.88652802], [79.85069275, 10.88652992], [79.85069275, 10.88569069], [79.84986115, 10.8856926], [79.84986115, 10.88541794], [79.84874725, 10.88541985], [79.84874725, 10.88487053], [79.8484726, 10.88487053], [79.8484726, 10.88430977], [79.84819794, 10.88430977], [79.84819794, 10.88403034], [79.84874725, 10.88403034], [79.84874725, 10.88375187], [79.85041809, 10.88375187], [79.85041809, 10.88403034], [79.85098267, 10.88403034], [79.85098267, 10.88430977], [79.85151672, 10.88430977], [79.85151672, 10.88375187], [79.85124969, 10.88375187], [79.85124969, 10.88264179], [79.85098267, 10.88264179], [79.85098267, 10.88153172], [79.85124969, 10.88153172], [79.85124969, 10.88069057], [79.85152435, 10.88069534], [79.85152435, 10.88013935], [79.85180664, 10.88014126], [79.85180664, 10.87958145], [79.8520813, 10.87958336], [79.8520813, 10.87930489], [79.85234833, 10.87930965], [79.85234833, 10.87874889], [79.85263824, 10.87874889], [79.85263824, 10.87847328], [79.8529129, 10.87847328], [79.8529129, 10.87458324], [79.85263824, 10.87458324], [79.85263824, 10.8698616], [79.85234833, 10.86986923], [79.85234833, 10.86847019], [79.8520813, 10.8684721], [79.8520813, 10.86708355], [79.85180664, 10.86708355], [79.85180664, 10.86541557], [79.85151672, 10.86542034], [79.85151672, 10.86485958], [79.85180664, 10.86486244], [79.85180664, 10.86402798], [79.8520813, 10.86403179], [79.8520813, 10.85902977], [79.85234833, 10.85902977], [79.85234833, 10.85403156], [79.85263824, 10.85403156], [79.85263824, 10.839571], [79.85236359, 10.83958435], [79.85236359, 10.83874989], [79.85263824, 10.83875179], [79.85263824, 10.8376379], [79.8529129, 10.8376379], [79.8529129, 10.83708382], [79.85263824, 10.83708382], [79.85263824, 10.8368063], [79.85236359, 10.8368063], [79.85236359, 10.83652782], [79.85263824, 10.83652973], [79.85263824, 10.83096886], [79.85236359, 10.83097363], [79.85236359, 10.8293047], [79.8520813, 10.82931042], [79.8520813, 10.82763004], [79.85180664, 10.82763863], [79.85180664, 10.82680511], [79.8473587, 10.82681179], [79.8473587, 10.82653236], [79.84625244, 10.82653236], [79.84625244, 10.82681179], [79.84541321, 10.82680511], [79.84541321, 10.82708263], [79.84486389, 10.82708263], [79.84486389, 10.82736111], [79.84402466, 10.82736111], [79.84402466, 10.82708263], [79.84347534, 10.82708263], [79.84347534, 10.82680511], [79.8429184, 10.82681179], [79.8429184, 10.82653236], [79.84236145, 10.82653236], [79.84236145, 10.82625103], [79.84179688, 10.82625103], [79.84179688, 10.82597065], [79.84124756, 10.82597256], [79.84124756, 10.82569504], [79.8409729, 10.82569504], [79.8409729, 10.82541656], [79.84040833, 10.82541943], [79.84040833, 10.82514095], [79.83985901, 10.82514095], [79.83985901, 10.82541943], [79.83957672, 10.82541943], [79.83957672, 10.82514095], [79.83930206, 10.82514095], [79.83930206, 10.82457161], [79.8390274, 10.82458305], [79.8390274, 10.82374859], [79.83930206, 10.82375145], [79.83930206, 10.82347107], [79.8381958, 10.82347298], [79.8381958, 10.82319546], [79.8373642, 10.82319546], [79.8373642, 10.82291698], [79.83680725, 10.82291889], [79.83680725, 10.82264137], [79.83625031, 10.82264137], [79.83625031, 10.82236099], [79.83597565, 10.82236099], [79.83597565, 10.82208347], [79.8354187, 10.82208347], [79.8354187, 10.82180691], [79.83513641, 10.82182121], [79.83513641, 10.8215313], [79.83460236, 10.8215313], [79.83460236, 10.82125092], [79.83403015, 10.82125092], [79.83403015, 10.82096958], [79.83374786, 10.8209734], [79.83374786, 10.82069492], [79.83319092, 10.82069492], [79.83319092, 10.8204174], [79.8326416, 10.82042122], [79.8326416, 10.82014084], [79.83207703, 10.82014084], [79.83207703, 10.81986141], [79.83149719, 10.81986141], [79.83097076, 10.81986141], [79.83097076, 10.81958199], [79.83013916, 10.81958199], [79.83013916, 10.81930447], [79.8290329, 10.81931114], [79.8290329, 10.81902885], [79.82817841, 10.81902885], [79.82817841, 10.81876183], [79.82707977, 10.81876183], [79.82707977, 10.81847], [79.82541656, 10.81847286], [79.82541656, 10.81819439], [79.82402802, 10.81819439], [79.82402802, 10.81791592], [79.82375336, 10.81792068], [79.82375336, 10.81764126], [79.82402802, 10.81764126], [79.82402802, 10.81735992], [79.82540894, 10.81735992], [79.82540894, 10.81764126], [79.82707977, 10.81764126], [79.82707977, 10.81792068], [79.82819366, 10.81791592], [79.82819366, 10.81819439], [79.82902527, 10.81819439], [79.82902527, 10.81847286], [79.83013916, 10.81847], [79.83013916, 10.81876183], [79.83097076, 10.81876183], [79.83097076, 10.81902885], [79.83149719, 10.81902885], [79.83207703, 10.81902885], [79.83207703, 10.81931114], [79.8326416, 10.81930447], [79.8326416, 10.81958199], [79.83319092, 10.81958199], [79.83319092, 10.81986141], [79.83374786, 10.81986141], [79.83374786, 10.82014084], [79.83403015, 10.82014084], [79.83403015, 10.82042122], [79.8345871, 10.8204174], [79.8345871, 10.82069492], [79.83513641, 10.82069492], [79.83513641, 10.8209734], [79.8354187, 10.82096958], [79.8354187, 10.82125092], [79.83598328, 10.82125092], [79.83598328, 10.8215313], [79.83625031, 10.8215313], [79.83625031, 10.82182121], [79.83680725, 10.82180691], [79.83680725, 10.82208347], [79.83734894, 10.82207966], [79.83734894, 10.82236099], [79.8381958, 10.82236099], [79.8381958, 10.82264137], [79.83930206, 10.82264137], [79.83930206, 10.82291889], [79.84041595, 10.82291698], [79.84041595, 10.82319546], [79.84152985, 10.82319546], [79.84152985, 10.82347298], [79.84208679, 10.82347107], [79.84208679, 10.82375145], [79.8429184, 10.82375145], [79.8429184, 10.82403088], [79.84348297, 10.82403088], [79.84348297, 10.82430935], [79.84402466, 10.82430458], [79.84402466, 10.82458305], [79.84486389, 10.82458305], [79.84486389, 10.82486057], [79.84541321, 10.82486057], [79.84541321, 10.82514095], [79.84625244, 10.82514095], [79.84625244, 10.82541943], [79.84680176, 10.82541656], [79.84680939, 10.8255558], [79.84680939, 10.82569504], [79.8473587, 10.82569504], [79.8473587, 10.82597256], [79.85152435, 10.82597256], [79.85152435, 10.82375145], [79.85124969, 10.82375145], [79.85124969, 10.82236099], [79.85097504, 10.82236099], [79.85097504, 10.81986141], [79.85124969, 10.81986141], [79.85124969, 10.81930447], [79.85098267, 10.81931114], [79.85098267, 10.81902885], [79.85069275, 10.81902885], [79.85069275, 10.81792068], [79.85098267, 10.81792068], [79.85098267, 10.81764126], [79.85124969, 10.81764126], [79.85124969, 10.81735992], [79.85097504, 10.81735992], [79.85097504, 10.81708241], [79.85124969, 10.81708241], [79.85124969, 10.81486225], [79.85097504, 10.81486225], [79.85097504, 10.81402779], [79.85124969, 10.81403065], [79.85124969, 10.81377125]]], [[[75.28013611, 11.98874855], [75.2804184, 11.98874855], [75.2804184, 11.98819065], [75.28069305, 11.98819256], [75.28069305, 11.9879179], [75.28098297, 11.98791981], [75.28098297, 11.98764038], [75.28125, 11.98764038], [75.28125, 11.98736095], [75.28151703, 11.98736095], [75.28151703, 11.98708057], [75.28180695, 11.98708344], [75.28180695, 11.98680496], [75.2820816, 11.98680973], [75.2820816, 11.98625183], [75.28235626, 11.98625183], [75.28235626, 11.98569107], [75.28263855, 11.98569489], [75.28263855, 11.98541737], [75.28291321, 11.98542023], [75.28291321, 11.98513889], [75.28320313, 11.98513889], [75.28320313, 11.98403168], [75.28347015, 11.98403168], [75.28347015, 11.98348045], [75.28376007, 11.98348045], [75.28376007, 11.98319054], [75.2840271, 11.9831953], [75.2840271, 11.98263931], [75.28430176, 11.98264122], [75.28430176, 11.98208141], [75.28458405, 11.98208332], [75.28458405, 11.98180485], [75.28430176, 11.98180866], [75.28430176, 11.98152924], [75.28457642, 11.98152924], [75.28457642, 11.98097134], [75.2848587, 11.98097324], [75.2848587, 11.98041725], [75.28514099, 11.98041725], [75.28514099, 11.97958279], [75.28541565, 11.97958279], [75.28541565, 11.97875118], [75.28569794, 11.97875118], [75.28569794, 11.97792053], [75.2859726, 11.97792053], [75.2859726, 11.97708035], [75.28614807, 11.97708035], [75.28652954, 11.97708321], [75.28652954, 11.97625065], [75.28679657, 11.97625065], [75.28679657, 11.97597027], [75.28708649, 11.97597313], [75.28708649, 11.97569466], [75.28736115, 11.97569466], [75.28736115, 11.97513771], [75.2876358, 11.97514057], [75.2876358, 11.97486019], [75.28791809, 11.97486019], [75.28791809, 11.97402859], [75.28848267, 11.97403145], [75.28848267, 11.97346973], [75.28874969, 11.97347164], [75.28874969, 11.97319412], [75.28847504, 11.97319412], [75.28847504, 11.97263813], [75.28874969, 11.97264099], [75.28874969, 11.97235966], [75.28902435, 11.97235966], [75.28901672, 11.97124958], [75.28930664, 11.97124958], [75.28930664, 11.97097015], [75.2895813, 11.97097206], [75.2895813, 11.97041607], [75.28985596, 11.97042274], [75.28985596, 11.96986008], [75.29013824, 11.96986008], [75.29013824, 11.96931076], [75.2904129, 11.96931076], [75.2904129, 11.96903038], [75.29070282, 11.96903038], [75.29070282, 11.9681797], [75.29096985, 11.96819401], [75.29096985, 11.96791553], [75.29125214, 11.9679203], [75.29125214, 11.96708202], [75.29180908, 11.96708393], [75.29180908, 11.96652794], [75.29207611, 11.96652985], [75.29207611, 11.96625042], [75.2923584, 11.96625042], [75.2923584, 11.96569061], [75.29264069, 11.96569443], [75.29264069, 11.96541786], [75.29291534, 11.96541786], [75.29291534, 11.96513844], [75.29319763, 11.96514034], [75.29319763, 11.96486187], [75.29374695, 11.96486187], [75.29374695, 11.96430969], [75.29402924, 11.96430969], [75.29402924, 11.96375179], [75.29429626, 11.96375179], [75.29429626, 11.96347237], [75.29486084, 11.96347237], [75.29486084, 11.9631958], [75.2951355, 11.9631958], [75.2951355, 11.96291542], [75.29541779, 11.96292019], [75.29541779, 11.96263981], [75.29570007, 11.96263981], [75.29569244, 11.96236229], [75.2959671, 11.96237087], [75.2959671, 11.96208096], [75.29624939, 11.96208382], [75.29624939, 11.96152687], [75.29651642, 11.96152973], [75.29651642, 11.96097088], [75.29708099, 11.96097088], [75.29708099, 11.96069336], [75.29736328, 11.96069336], [75.29736328, 11.96041775], [75.29763794, 11.96041965], [75.29763794, 11.96013927], [75.29792023, 11.96013927], [75.29792023, 11.95985889], [75.29846954, 11.9598608], [75.29846954, 11.95958328], [75.29875183, 11.95958328], [75.29875183, 11.95930481], [75.29902649, 11.95930958], [75.29902649, 11.95903015], [75.29957581, 11.95903015], [75.29957581, 11.9584713], [75.29985809, 11.9584713], [75.29985809, 11.95819473], [75.30014038, 11.95819473], [75.30014038, 11.95791721], [75.30042267, 11.95792198], [75.30042267, 11.9576416], [75.30069733, 11.9576416], [75.30069733, 11.95736122], [75.30097198, 11.95736122], [75.30097198, 11.95708275], [75.30124664, 11.95708275], [75.30124664, 11.95680523], [75.30152893, 11.9568119], [75.30152893, 11.95653152], [75.30179596, 11.95653152], [75.30179596, 11.9562397], [75.30208588, 11.95625114], [75.30208588, 11.95569515], [75.30236053, 11.95569515], [75.30236053, 11.95541668], [75.30264282, 11.95541859], [75.30264282, 11.95486069], [75.30291748, 11.95486069], [75.30291748, 11.95430946], [75.30319214, 11.95430946], [75.30319214, 11.95403099], [75.3034668, 11.95403099], [75.3034668, 11.95347118], [75.30374908, 11.95347309], [75.30374908, 11.95319462], [75.30403137, 11.95319462], [75.30403137, 11.95263863], [75.30430603, 11.95264053], [75.30430603, 11.95236111], [75.30458069, 11.95236111], [75.30458069, 11.95180511], [75.30486298, 11.95181084], [75.30486298, 11.95125103], [75.30458069, 11.95125103], [75.30458069, 11.95069027], [75.30430603, 11.95069504], [75.30430603, 11.95041656], [75.30403137, 11.95042992], [75.30403137, 11.94986057], [75.30374908, 11.94986057], [75.30374908, 11.94958305], [75.30319214, 11.94958305], [75.30319214, 11.94930363], [75.30291748, 11.94931126], [75.30291748, 11.94903088], [75.30236053, 11.94903088], [75.30236053, 11.94875145], [75.30208588, 11.94875145], [75.30208588, 11.94847012], [75.30097198, 11.94847298], [75.30097198, 11.94819546], [75.29985809, 11.94819546], [75.29985809, 11.94791603], [75.29886627, 11.94791603], [75.29875183, 11.94791603], [75.29875183, 11.94819546], [75.29846954, 11.94819546], [75.29846954, 11.94847298], [75.29818726, 11.94847012], [75.29818726, 11.94903088], [75.29736328, 11.94903088], [75.29736328, 11.94875145], [75.29708099, 11.94875145], [75.29708099, 11.94847012], [75.29680634, 11.94847298], [75.29680634, 11.94819546], [75.29624939, 11.94819546], [75.29624939, 11.94791603], [75.29597473, 11.94791603], [75.29597473, 11.94819546], [75.29569244, 11.94819546], [75.29569244, 11.94847298], [75.29541779, 11.94847012], [75.29541779, 11.94875145], [75.29514313, 11.94875145], [75.29514313, 11.94931126], [75.29486084, 11.94930363], [75.29486084, 11.94958305], [75.29458618, 11.94958305], [75.29458618, 11.94986057], [75.29430389, 11.94986057], [75.29430389, 11.95069504], [75.29374695, 11.95069504], [75.29374695, 11.95097256], [75.29347229, 11.9509697], [75.29347229, 11.95125103], [75.29292297, 11.95125103], [75.29292297, 11.95153141], [75.29264069, 11.95153141], [75.29264069, 11.95181084], [75.2923584, 11.95180511], [75.2923584, 11.95208263], [75.29208374, 11.95208263], [75.29208374, 11.95236111], [75.29180908, 11.95236111], [75.29180908, 11.95292091], [75.29125214, 11.9529171], [75.29125214, 11.95319462], [75.29096985, 11.95319462], [75.29096985, 11.95347309], [75.29070282, 11.95347118], [75.29070282, 11.95375061], [75.29013824, 11.95375061], [75.29013824, 11.95403099], [75.28956604, 11.95403099], [75.28956604, 11.95430946], [75.28930664, 11.95430946], [75.28930664, 11.95486069], [75.28901672, 11.95486069], [75.28901672, 11.95514107], [75.28874969, 11.95514107], [75.28874969, 11.95541859], [75.28847504, 11.95541668], [75.28847504, 11.95569515], [75.28819275, 11.95569515], [75.28819275, 11.95597267], [75.28791809, 11.95597267], [75.28791809, 11.95625114], [75.2876358, 11.9562397], [75.2876358, 11.9568119], [75.28736115, 11.95680523], [75.28736115, 11.95736122], [75.28708649, 11.95736122], [75.28708649, 11.9576416], [75.2868042, 11.95763874], [75.2868042, 11.95819473], [75.28652954, 11.95819473], [75.28652954, 11.9584713], [75.28624725, 11.9584713], [75.28624725, 11.95903015], [75.2859726, 11.95902729], [75.2859726, 11.95958328], [75.28569794, 11.95958328], [75.28569794, 11.9598608], [75.28542328, 11.95985889], [75.28542328, 11.96013927], [75.28514099, 11.96013927], [75.28514099, 11.96069336], [75.28457642, 11.96069145], [75.28457642, 11.96124935], [75.28430939, 11.96124935], [75.28430176, 11.96181011], [75.2840271, 11.96181011], [75.2840271, 11.96237087], [75.28375244, 11.96236229], [75.28376007, 11.96263981], [75.28347015, 11.96263981], [75.28347015, 11.96292019], [75.2831955, 11.96291542], [75.2831955, 11.96347237], [75.28291321, 11.96347237], [75.28291321, 11.96375179], [75.28263855, 11.96375179], [75.28263855, 11.96403027], [75.28236389, 11.96402836], [75.28236389, 11.96458435], [75.2820816, 11.96458054], [75.2820816, 11.96514034], [75.28152466, 11.96514034], [75.28152466, 11.96597195], [75.28098297, 11.96597195], [75.28098297, 11.96652985], [75.28070068, 11.96652985], [75.28070068, 11.96681023], [75.2804184, 11.96680641], [75.2804184, 11.9673624], [75.28013611, 11.96735954], [75.28013611, 11.9679203], [75.27986145, 11.9679203], [75.27986145, 11.96903038], [75.27958679, 11.96902847], [75.27958679, 11.96958447], [75.27902985, 11.9695797], [75.27902985, 11.96986008], [75.27874756, 11.96986008], [75.27874756, 11.97014046], [75.27819824, 11.9701376], [75.27819824, 11.97069359], [75.27791595, 11.97069359], [75.27791595, 11.97097206], [75.27762604, 11.97097015], [75.27762604, 11.97154045], [75.27735901, 11.97152805], [75.27735901, 11.97208214], [75.27708435, 11.97208214], [75.27708435, 11.97236156], [75.27680206, 11.97235966], [75.27680206, 11.97292137], [75.27625275, 11.97291565], [75.27625275, 11.97319412], [75.27597046, 11.97319031], [75.27597046, 11.97375011], [75.2756958, 11.97375011], [75.2756958, 11.97431087], [75.27541351, 11.9743042], [75.27541351, 11.97486019], [75.27513885, 11.97486019], [75.27513885, 11.97514057], [75.27485657, 11.97514057], [75.27485657, 11.97542095], [75.27458191, 11.97541714], [75.27458191, 11.97569466], [75.27430725, 11.9756918], [75.27430725, 11.97625065], [75.27401733, 11.97625065], [75.27401733, 11.97653103], [75.27375031, 11.97652912], [75.27375031, 11.97708321], [75.27348328, 11.97708035], [75.27348328, 11.97764111], [75.27319336, 11.97764111], [75.27319336, 11.97792053], [75.27263641, 11.97791672], [75.27263641, 11.97847271], [75.27236176, 11.9784708], [75.27236176, 11.97903061], [75.27180481, 11.97902679], [75.27180481, 11.97958279], [75.27153015, 11.97958279], [75.27153015, 11.97986126], [75.27124786, 11.97986126], [75.27124786, 11.98041725], [75.27097321, 11.98041725], [75.27097321, 11.98097324], [75.27069092, 11.98097324], [75.27069092, 11.98124886], [75.27041626, 11.98124886], [75.27041626, 11.98180866], [75.2701416, 11.98180485], [75.2701416, 11.98208332], [75.26985931, 11.98208141], [75.26985931, 11.98236084], [75.26930237, 11.98236084], [75.26930237, 11.98264122], [75.26902771, 11.98263931], [75.26902771, 11.9831953], [75.26875305, 11.9831953], [75.26876068, 11.9837513], [75.26847076, 11.9837513], [75.26847076, 11.98431015], [75.26819611, 11.98430538], [75.26819611, 11.9845829], [75.26763916, 11.98458099], [75.26763916, 11.98513889], [75.26735687, 11.98513889], [75.26735687, 11.98542023], [75.26708221, 11.98541737], [75.26708221, 11.98597336], [75.26680756, 11.98597145], [75.26680756, 11.98625183], [75.2665329, 11.98625183], [75.2665329, 11.98654079], [75.26625061, 11.98654079], [75.26625061, 11.98680973], [75.26597595, 11.98680496], [75.26597595, 11.98708344], [75.26568604, 11.98708057], [75.26568604, 11.98736095], [75.26513672, 11.98736095], [75.26513672, 11.98791981], [75.26486206, 11.9879179], [75.26486206, 11.98847103], [75.26430511, 11.98847103], [75.26431274, 11.98874855], [75.26403046, 11.98874855], [75.26403046, 11.98931026], [75.26374817, 11.98930645], [75.26374817, 11.98986244], [75.26346588, 11.98986244], [75.26346588, 11.99014187], [75.26291656, 11.99013996], [75.26291656, 11.99069405], [75.26235962, 11.99069118], [75.26235962, 11.99125195], [75.26207733, 11.99125195], [75.26207733, 11.99180984], [75.26180267, 11.99180603], [75.26180267, 11.99208355], [75.26152802, 11.99208164], [75.26152802, 11.99263954], [75.26125336, 11.99263954], [75.26125336, 11.99291992], [75.26097107, 11.99291801], [75.26097107, 11.99319363], [75.26069641, 11.99319363], [75.26069641, 11.9934721], [75.26040649, 11.99347019], [75.26040649, 11.99374962], [75.26013947, 11.99374962], [75.26013947, 11.99431133], [75.25959015, 11.99431133], [75.25959015, 11.99514008], [75.25930786, 11.99514008], [75.25930786, 11.99542046], [75.25902557, 11.99541569], [75.25902557, 11.99569416], [75.25875092, 11.99568939], [75.25875092, 11.99625015], [75.25846863, 11.99625015], [75.25846863, 11.99652958], [75.25819397, 11.99652767], [75.25819397, 11.99708366], [75.25763702, 11.99707985], [75.25763702, 11.99763966], [75.25736237, 11.99763966], [75.25736237, 11.99792099], [75.25708008, 11.99792099], [75.25708008, 11.9984808], [75.25682068, 11.9984808], [75.25682068, 11.99874973], [75.25653076, 11.99874973], [75.25653076, 11.99931145], [75.25624847, 11.99930573], [75.25624847, 11.99958229], [75.25596619, 11.99958038], [75.25596619, 12.00014114], [75.25541687, 12.00014114], [75.25541687, 12.00042057], [75.25514221, 12.0004158], [75.25514221, 12.00069427], [75.25485992, 12.00069046], [75.25485992, 12.00125122], [75.25430298, 12.00125122], [75.25430298, 12.00181103], [75.25402832, 12.00180435], [75.25402832, 12.00208473], [75.25374603, 12.00207996], [75.25374603, 12.00264072], [75.25319672, 12.00264072], [75.25319672, 12.0029211], [75.25291443, 12.00291729], [75.25291443, 12.00347328], [75.25263977, 12.00347042], [75.25263977, 12.00403118], [75.25208282, 12.00402641], [75.25208282, 12.00458336], [75.25180817, 12.00457954], [75.25180817, 12.00486088], [75.25152588, 12.00486088], [75.25152588, 12.00514126], [75.25125122, 12.00513935], [75.25125122, 12.00569534], [75.25096893, 12.00568962], [75.25096893, 12.00625134], [75.25041962, 12.00625134], [75.25041962, 12.00653076], [75.24986267, 12.00652885], [75.24986267, 12.00708294], [75.24958038, 12.00708294], [75.24958038, 12.00736141], [75.24946594, 12.00736141], [75.24931335, 12.00736141], [75.24931335, 12.00791931], [75.24874878, 12.0079174], [75.24874878, 12.00819016], [75.24846649, 12.00819969], [75.24846649, 12.00875092], [75.24819183, 12.00875092], [75.24819183, 12.0090313], [75.24765015, 12.0090313], [75.24765015, 12.00931168], [75.24736023, 12.00931168], [75.24736023, 12.00986099], [75.2470932, 12.00986099], [75.2470932, 12.01041889], [75.24680328, 12.01041698], [75.24680328, 12.01069546], [75.24624634, 12.01069546], [75.24624634, 12.01097107], [75.24569702, 12.01097107], [75.24569702, 12.01153183], [75.2454071, 12.01153183], [75.2454071, 12.0118103], [75.24485779, 12.01180458], [75.24485779, 12.01236057], [75.24430847, 12.01236057], [75.24430847, 12.01264191], [75.24402618, 12.01264191], [75.24402618, 12.01292038], [75.24375153, 12.01291656], [75.24375153, 12.01319313], [75.24346924, 12.01319313], [75.24346924, 12.01347446], [75.24318695, 12.01346016], [75.24318695, 12.01375198], [75.24291992, 12.01375198], [75.24291992, 12.01431179], [75.24236298, 12.01430511], [75.24236298, 12.01458263], [75.24180603, 12.01458263], [75.24180603, 12.01486206], [75.24124908, 12.0148592], [75.24124908, 12.01541996], [75.24069214, 12.01541805], [75.24069214, 12.01569557], [75.24041748, 12.01569557], [75.24041748, 12.01597118], [75.23986053, 12.01596928], [75.23986053, 12.0162487], [75.23958588, 12.0162487], [75.23958588, 12.01652813], [75.23929596, 12.01652145], [75.23929596, 12.01681042], [75.23874664, 12.01680565], [75.23874664, 12.01708412], [75.23851013, 12.01708412], [75.23819733, 12.01708412], [75.23819733, 12.01719093], [75.23819733, 12.01736164], [75.23792267, 12.01736164], [75.23792267, 12.01764202], [75.23735809, 12.01764202], [75.23735809, 12.01791954], [75.23680878, 12.01791573], [75.23680878, 12.0181942], [75.23652649, 12.0181942], [75.23652649, 12.01847172], [75.23596954, 12.01846886], [75.23596954, 12.01875019], [75.23568726, 12.01875019], [75.23568726, 12.01902962], [75.23513794, 12.01902962], [75.23513794, 12.01931], [75.23430634, 12.01930618], [75.23430634, 12.0195837], [75.23374939, 12.0195837], [75.23374939, 12.01986217], [75.2334671, 12.01986027], [75.2334671, 12.02013969], [75.23319244, 12.02013969], [75.23319244, 12.02042007], [75.23291779, 12.02041626], [75.23291779, 12.02069378], [75.2326355, 12.02069378], [75.2326355, 12.02097225], [75.23236084, 12.02097034], [75.23236084, 12.02265167], [75.23208618, 12.02265167], [75.23208618, 12.02292061], [75.23236084, 12.02291584], [75.23236084, 12.02347183], [75.23208618, 12.02346992], [75.23208618, 12.02375031], [75.23179626, 12.02375031], [75.23179626, 12.02402973], [75.23069763, 12.02402782], [75.23069763, 12.02414036], [75.23105621, 12.02456188], [75.22492218, 12.03195], [75.22735596, 12.04430103], [75.22367096, 12.05447102], [75.2231369, 12.06444168], [75.22424316, 12.07438087], [75.22225952, 12.07815075], [75.22245789, 12.08556938], [75.22113037, 12.10095119], [75.22306061, 12.10484028], [75.23660278, 12.11023045], [75.24053192, 12.10926056], [75.24344635, 12.10467052], [75.24739075, 12.1036911], [75.25588989, 12.10857964], [75.25985718, 12.10893059], [75.26602173, 12.10366058], [75.2745285, 12.10026073], [75.27781677, 12.1017704], [75.28198242, 12.1091404], [75.28392792, 12.11498165], [75.29277039, 12.11613274], [75.31067657, 12.12473202], [75.3098526, 12.13204956], [75.31115723, 12.1364603], [75.31429291, 12.14009953], [75.32064056, 12.14352131], [75.32515717, 12.14489079], [75.33112335, 12.14515114], [75.33522797, 12.14400196], [75.34194946, 12.13718033], [75.34616089, 12.13861179], [75.34784698, 12.13530922], [75.36360931, 12.13496971], [75.36669159, 12.13537979], [75.36826324, 12.14007854], [75.37149048, 12.14262962], [75.37201691, 12.14647007], [75.37460327, 12.14908028], [75.37838745, 12.14603043], [75.38852692, 12.14629173], [75.39392853, 12.14548111], [75.39982605, 12.14050102], [75.40251923, 12.13684082], [75.4021759, 12.13414001], [75.39823914, 12.12987137], [75.39215088, 12.12634087], [75.38308716, 12.12397957], [75.38228607, 12.12912083], [75.37993622, 12.12639141], [75.37930298, 12.12213993], [75.37548065, 12.12341022], [75.3685379, 12.12126064], [75.36592102, 12.11693001], [75.36267853, 12.11610985], [75.35790253, 12.11290073], [75.3553009, 12.10936069], [75.35193634, 12.10885143], [75.3398819, 12.09825134], [75.33598328, 12.09864044], [75.32998657, 12.10258961], [75.32817841, 12.10727978], [75.31962585, 12.10665131], [75.31288147, 12.10531139], [75.30906677, 12.10266113], [75.30964661, 12.09063053], [75.3147583, 12.08760929], [75.30916595, 12.07843971], [75.29917145, 12.06679153], [75.29737091, 12.06365108], [75.2961731, 12.05924129], [75.30066681, 12.05802059], [75.30480957, 12.0529213], [75.30879211, 12.05379105], [75.3116684, 12.04930592], [75.31014252, 12.04931068], [75.31014252, 12.0490303], [75.30986023, 12.0490303], [75.30986023, 12.04931068], [75.30847168, 12.04931068], [75.30847168, 12.0490303], [75.30819702, 12.0490303], [75.30819702, 12.04874992], [75.3079071, 12.04874992], [75.3079071, 12.04846954], [75.30764008, 12.0484724], [75.30764008, 12.04819393], [75.30735779, 12.04819393], [75.30735779, 12.04708385], [75.30764008, 12.04708385], [75.30764008, 12.04680634], [75.30735779, 12.04681969], [75.30735779, 12.04597187], [75.30708313, 12.04597187], [75.30708313, 12.04514027], [75.30680847, 12.04514027], [75.30680847, 12.04486179], [75.30652618, 12.04486179], [75.30652618, 12.04458141], [75.30625153, 12.04458427], [75.30625153, 12.04402828], [75.30596924, 12.04403019], [75.30596924, 12.04319096], [75.30569458, 12.04319572], [75.30569458, 12.04263973], [75.30541992, 12.04263973], [75.30541992, 12.04208088], [75.30513763, 12.04208374], [75.30513763, 12.04152679], [75.30486298, 12.04152966], [75.30486298, 12.04124928], [75.30458069, 12.04124928], [75.30458069, 12.0401392], [75.30430603, 12.0401392], [75.30430603, 12.03903198], [75.30458069, 12.03903198], [75.30458069, 12.03792191], [75.30486298, 12.03792191], [75.30486298, 12.03736115], [75.30513763, 12.03736115], [75.30513763, 12.03708267], [75.30486298, 12.03708267], [75.30486298, 12.03680515], [75.30458069, 12.03680515], [75.30458069, 12.03708267], [75.30403137, 12.03708267], [75.30403137, 12.03736115], [75.30347443, 12.03736115], [75.30347443, 12.03708267], [75.30319214, 12.03708267], [75.30319214, 12.03680515], [75.30291748, 12.03681183], [75.30291748, 12.0365324], [75.30264282, 12.0365324], [75.30264282, 12.03625107], [75.30291748, 12.03625107], [75.30291748, 12.03569126], [75.30319214, 12.03569508], [75.30319214, 12.0354166], [75.3034668, 12.03541946], [75.3034668, 12.03514099], [75.30374908, 12.03514099], [75.30374908, 12.03403091], [75.3034668, 12.03403091], [75.3034668, 12.03375053], [75.30319214, 12.03375053], [75.30319214, 12.03347111], [75.30291748, 12.03347301], [75.30291748, 12.03319454], [75.30180359, 12.03319454], [75.30180359, 12.03347301], [75.30152893, 12.03347111], [75.30152893, 12.03375053], [75.30097198, 12.03375053], [75.30097198, 12.03347111], [75.30069733, 12.03347301], [75.30069733, 12.03319454], [75.30041504, 12.03319454], [75.30041504, 12.03263855], [75.30014038, 12.03264141], [75.30014038, 12.03151989], [75.29985809, 12.03152657], [75.29985809, 12.03041744], [75.29957581, 12.03042126], [75.29957581, 12.02931118], [75.29930878, 12.02931118], [75.29930878, 12.02818966], [75.29958344, 12.02819443], [75.29958344, 12.02791595], [75.29985809, 12.02792072], [75.29985809, 12.02735996], [75.30014038, 12.02735996], [75.30014038, 12.02707958], [75.30041504, 12.0270853], [75.30041504, 12.02680588], [75.30069733, 12.02681065], [75.30069733, 12.02653122], [75.30097198, 12.02653122], [75.30097198, 12.02597046], [75.30124664, 12.02597237], [75.30124664, 12.02541637], [75.30152893, 12.02542114], [75.30152893, 12.02460003], [75.30097198, 12.02458382], [75.30097198, 12.02486229], [75.29985809, 12.02486038], [75.29985809, 12.02514267], [75.29902649, 12.0251379], [75.29902649, 12.02569389], [75.29930878, 12.02569199], [75.29930878, 12.02625275], [75.29902649, 12.02625275], [75.29902649, 12.02681065], [75.29875183, 12.02680588], [75.29875183, 12.0270853], [75.29846954, 12.02707958], [75.29846954, 12.0276413], [75.29819489, 12.02763844], [75.29819489, 12.02819443], [75.29792023, 12.02819443], [75.29792023, 12.0284729], [75.29736328, 12.02846146], [75.29736328, 12.02875137], [75.29708099, 12.02875137], [75.29708099, 12.0290308], [75.29651642, 12.0290308], [75.29651642, 12.02931118], [75.29624939, 12.02930355], [75.29624939, 12.02985954], [75.2959671, 12.02985954], [75.2959671, 12.03042126], [75.29569244, 12.03041744], [75.29569244, 12.03069496], [75.2951355, 12.03069496], [75.2951355, 12.03097343], [75.29486084, 12.03097343], [75.29486084, 12.03152657], [75.29458618, 12.03151989], [75.29458618, 12.03181076], [75.29319763, 12.03181076], [75.29319763, 12.03151989], [75.29292297, 12.03151989], [75.29292297, 12.03181076], [75.29207611, 12.03181076], [75.29207611, 12.03151989], [75.29180908, 12.03152657], [75.29180908, 12.03069496], [75.29152679, 12.03069496], [75.29152679, 12.03041744], [75.29180908, 12.03042126], [75.29180908, 12.02985954], [75.29208374, 12.02985954], [75.29208374, 12.02958202], [75.2923584, 12.02958202], [75.2923584, 12.02930355], [75.29264069, 12.02931118], [75.29264069, 12.0290308], [75.29292297, 12.0290308], [75.29292297, 12.02846146], [75.29319763, 12.0284729], [75.29319763, 12.02791595], [75.29347229, 12.02792072], [75.29347229, 12.0276413], [75.29402924, 12.0276413], [75.29402924, 12.02792072], [75.29541779, 12.02792072], [75.29541779, 12.0276413], [75.29570007, 12.0276413], [75.29570007, 12.02735996], [75.29624939, 12.02735996], [75.29624939, 12.02707958], [75.29680634, 12.0270853], [75.29680634, 12.02680588], [75.29736328, 12.02681065], [75.29736328, 12.02653122], [75.29763794, 12.02653122], [75.29763794, 12.02597046], [75.29736328, 12.02597237], [75.29736328, 12.02569389], [75.29652405, 12.02569389], [75.29652405, 12.02541637], [75.29541779, 12.02542114], [75.29541779, 12.02514267], [75.29486084, 12.02514267], [75.29486084, 12.02486038], [75.29458618, 12.02486229], [75.29458618, 12.02458382], [75.29430389, 12.02458191], [75.29430389, 12.02375031], [75.29402924, 12.02375031], [75.29402924, 12.02292061], [75.29374695, 12.02292061], [75.29374695, 12.02181053], [75.29402924, 12.02181053], [75.29402924, 12.02125168], [75.29458618, 12.02125168], [75.29458618, 12.02097034], [75.29486084, 12.02097225], [75.29486084, 12.02069378], [75.2951355, 12.02069378], [75.2951355, 12.02041626], [75.29541779, 12.02042007], [75.29541779, 12.02013969], [75.29570007, 12.02013969], [75.29570007, 12.01958179], [75.29597473, 12.0195837], [75.29597473, 12.01902771], [75.29624939, 12.01902962], [75.29624939, 12.01791954], [75.2959671, 12.01791954], [75.2959671, 12.01764202], [75.29458618, 12.01764202], [75.29458618, 12.01791954], [75.29402924, 12.01791954], [75.29402924, 12.01764202], [75.29319763, 12.01764202], [75.29319763, 12.01791954], [75.29291534, 12.01791573], [75.29291534, 12.01847172], [75.29264069, 12.01846886], [75.29264069, 12.01902962], [75.2923584, 12.01902962], [75.2923584, 12.01931], [75.29180908, 12.01930618], [75.29180908, 12.0195837], [75.29125214, 12.01958179], [75.29125214, 12.02013969], [75.29096985, 12.02013779], [75.29096985, 12.02069378], [75.29125214, 12.02069187], [75.29125214, 12.02125168], [75.29152679, 12.02124977], [75.29152679, 12.02208424], [75.29096985, 12.02208424], [75.29096985, 12.02235985], [75.29070282, 12.02235985], [75.29070282, 12.02265167], [75.2904129, 12.02264023], [75.2904129, 12.02319431], [75.29069519, 12.02319431], [75.29069519, 12.02375031], [75.29096985, 12.02375031], [75.29096985, 12.02402973], [75.29125214, 12.02402973], [75.29125214, 12.02431107], [75.29180908, 12.02431107], [75.29180908, 12.02542114], [75.29152679, 12.02541637], [75.29152679, 12.02597237], [75.29125214, 12.02597046], [75.29125214, 12.02681065], [75.29152679, 12.02681065], [75.29152679, 12.02735996], [75.29125214, 12.02735996], [75.29125214, 12.0276413], [75.29096985, 12.0276413], [75.29096985, 12.02792072], [75.28986359, 12.02791595], [75.28986359, 12.02819443], [75.28930664, 12.02819443], [75.28930664, 12.0284729], [75.28901672, 12.02846146], [75.28902435, 12.02875137], [75.28848267, 12.02875137], [75.28848267, 12.0290308], [75.28708649, 12.0290308], [75.28708649, 12.02931118], [75.2868042, 12.02930355], [75.2868042, 12.02958202], [75.28652954, 12.02958202], [75.28652954, 12.02985954], [75.2859726, 12.02985954], [75.2859726, 12.02958202], [75.28569794, 12.02958202], [75.28569794, 12.02930355], [75.28542328, 12.02931118], [75.28542328, 12.02875137], [75.28514099, 12.02875137], [75.28514099, 12.02818966], [75.2848587, 12.02819443], [75.2848587, 12.02791595], [75.28430176, 12.02792072], [75.28430176, 12.0276413], [75.28376007, 12.0276413], [75.28376007, 12.02681065], [75.2840271, 12.02681065], [75.2840271, 12.02653122], [75.2848587, 12.02653122], [75.2848587, 12.02625275], [75.28542328, 12.02625275], [75.28542328, 12.02597046], [75.28569794, 12.02597237], [75.28569794, 12.02569389], [75.2859726, 12.02569389], [75.2859726, 12.02541637], [75.28624725, 12.02542114], [75.28624725, 12.02486038], [75.28652954, 12.02486229], [75.28652954, 12.0243063], [75.28624725, 12.02431107], [75.28624725, 12.02375031], [75.2859726, 12.02375031], [75.2859726, 12.02402973], [75.28542328, 12.02402973], [75.28542328, 12.02431107], [75.28514099, 12.0243063], [75.28514099, 12.02458191], [75.2848587, 12.02458382], [75.2848587, 12.02486229], [75.28430939, 12.02486038], [75.28430176, 12.02514267], [75.2840271, 12.02514267], [75.2840271, 12.02542114], [75.28347015, 12.02541637], [75.28347015, 12.02569389], [75.2804184, 12.02569389], [75.2804184, 12.02541637], [75.27986145, 12.02542114], [75.27986145, 12.02514267], [75.27929688, 12.02514267], [75.27929688, 12.02486038], [75.27791595, 12.02486038], [75.27791595, 12.02514267], [75.27707672, 12.02514267], [75.27707672, 12.02542114], [75.27625275, 12.02541637], [75.27625275, 12.02569389], [75.2748642, 12.02569389], [75.2748642, 12.02597237], [75.27401733, 12.02597046], [75.27401733, 12.02653122], [75.27348328, 12.02653122], [75.27348328, 12.02681065], [75.27319336, 12.02681065], [75.27319336, 12.02735996], [75.2729187, 12.02735996], [75.2729187, 12.0276413], [75.27263641, 12.02763844], [75.27263641, 12.02819443], [75.2729187, 12.02818966], [75.2729187, 12.02875137], [75.27263641, 12.02875137], [75.27263641, 12.02931118], [75.27236176, 12.02930355], [75.27236176, 12.02958202], [75.27097321, 12.02958202], [75.27097321, 12.02930355], [75.27069092, 12.02931118], [75.27069092, 12.0290308], [75.27041626, 12.0290308], [75.27041626, 12.02875137], [75.2701416, 12.02875137], [75.2701416, 12.02846146], [75.27041626, 12.0284729], [75.27041626, 12.02819443], [75.27069092, 12.02819443], [75.27069092, 12.02791595], [75.27097321, 12.02792072], [75.27097321, 12.02681065], [75.2701416, 12.02681065], [75.2701416, 12.02653122], [75.26985931, 12.02653122], [75.26985931, 12.02625275], [75.26930237, 12.02625275], [75.26930237, 12.02569199], [75.26847076, 12.02569389], [75.26847076, 12.02541637], [75.26763916, 12.02542114], [75.26763916, 12.02486038], [75.2673645, 12.02486229], [75.2673645, 12.02402782], [75.26708221, 12.02402973], [75.26708221, 12.02318859], [75.26652527, 12.02319431], [75.26652527, 12.02264023], [75.26625061, 12.02265167], [75.26625061, 12.02208042], [75.26597595, 12.02208424], [75.26597595, 12.02152824], [75.26568604, 12.02153015], [75.26568604, 12.02097034], [75.26541901, 12.02097225], [75.26541901, 12.02041626], [75.26513672, 12.02042007], [75.26513672, 12.01986027], [75.26486206, 12.01986217], [75.26486206, 12.01930618], [75.26457977, 12.01931], [75.26457977, 12.01846886], [75.26430511, 12.01847172], [75.26430511, 12.01764011], [75.26403046, 12.01764202], [75.26403046, 12.01708126], [75.26374817, 12.01708412], [75.26374817, 12.01597118], [75.26347351, 12.01597118], [75.26347351, 12.01458263], [75.26319122, 12.01458263], [75.26319122, 12.01347446], [75.26291656, 12.01347446], [75.26291656, 12.01208305], [75.26264191, 12.01208305], [75.26264191, 12.00902653], [75.26235962, 12.0090313], [75.26235962, 12.00625134], [75.26262665, 12.00625134], [75.26262665, 12.00542068], [75.26291656, 12.00542068], [75.26291656, 12.00431061], [75.26319122, 12.00431061], [75.26319122, 12.00347042], [75.26347351, 12.00347328], [75.26347351, 12.00291729], [75.26374817, 12.0029211], [75.26374817, 12.00264072], [75.26403046, 12.00264072], [75.26403046, 12.00236034], [75.26430511, 12.00236034], [75.26430511, 12.00208473], [75.26457977, 12.00208473], [75.26457977, 12.00180435], [75.26486206, 12.00181103], [75.26486206, 12.0015192], [75.26513672, 12.00152874], [75.26513672, 12.00125122], [75.26568604, 12.00125122], [75.26568604, 12.00097179], [75.26597595, 12.00097179], [75.26597595, 12.00069046], [75.26652527, 12.00069427], [75.26652527, 12.0004158], [75.26819611, 12.00042057], [75.26819611, 12.00014114], [75.26876068, 12.00014114], [75.26876068, 11.99986267], [75.26930237, 11.99986267], [75.26930237, 11.99958038], [75.2701416, 11.99958229], [75.2701416, 11.99930573], [75.27069092, 11.99931145], [75.27069092, 11.99874973], [75.27097321, 11.99874973], [75.27097321, 11.9984808], [75.27153015, 11.9984808], [75.27153015, 11.99819183], [75.2720871, 11.99819374], [75.2720871, 11.99791622], [75.27236176, 11.99792099], [75.27236176, 11.99736023], [75.2729187, 11.99736214], [75.2729187, 11.99680614], [75.27319336, 11.99681091], [75.27319336, 11.99625015], [75.27375031, 11.99625015], [75.27375031, 11.99597168], [75.27430725, 11.99597168], [75.27430725, 11.99569416], [75.27458191, 11.99569416], [75.27458191, 11.99514008], [75.27485657, 11.99514008], [75.27485657, 11.9948597], [75.27513885, 11.9948597], [75.27513885, 11.99457932], [75.2756958, 11.99458408], [75.2756958, 11.99374962], [75.27597046, 11.99374962], [75.27597046, 11.99347019], [75.27625275, 11.9934721], [75.27625275, 11.99319363], [75.2765274, 11.99319363], [75.2765274, 11.99291801], [75.27680206, 11.99291992], [75.27680206, 11.99234962], [75.27735901, 11.99236202], [75.27735901, 11.99180603], [75.27762604, 11.99180984], [75.27762604, 11.99153042], [75.27791595, 11.99153042], [75.27791595, 11.99125195], [75.27819061, 11.99125195], [75.27819824, 11.99069118], [75.2784729, 11.99069405], [75.2784729, 11.99041462], [75.27874756, 11.99042034], [75.27874756, 11.99014187], [75.27902985, 11.99014187], [75.27902985, 11.98986244], [75.2793045, 11.98986244], [75.2793045, 11.98930645], [75.27958679, 11.98931026], [75.27958679, 11.98903179], [75.28013611, 11.98903179], [75.28013611, 11.98874855]]], [[[82.25875092, 16.69011116], [82.25875092, 16.69069481], [82.25846863, 16.69069481], [82.25846863, 16.69180489], [82.25819397, 16.69180489], [82.25819397, 16.69208336], [82.25791931, 16.69207954], [82.25791931, 16.69292068], [82.25763702, 16.69292068], [82.25763702, 16.6973629], [82.25736237, 16.6973629], [82.25736237, 16.69791985], [82.25763702, 16.69791603], [82.25763702, 16.6981945], [82.25791931, 16.69819069], [82.25791931, 16.70181084], [82.25930786, 16.70180511], [82.25930786, 16.70208359], [82.26069641, 16.70208359], [82.26069641, 16.70236206], [82.26235962, 16.70236206], [82.26235962, 16.70263863], [82.26291656, 16.702631], [82.26291656, 16.70292091], [82.26568604, 16.70292091], [82.26568604, 16.702631], [82.26791382, 16.70263863], [82.26791382, 16.70236206], [82.2701416, 16.70236206], [82.2701416, 16.70208359], [82.27069092, 16.70208359], [82.27069092, 16.70180511], [82.27179718, 16.70181084], [82.27179718, 16.70153046], [82.27319336, 16.70153046], [82.27319336, 16.70125008], [82.27401733, 16.70125008], [82.27401733, 16.7009697], [82.27513885, 16.7009716], [82.27513885, 16.70069695], [82.27597046, 16.70070076], [82.27597046, 16.70042038], [82.27707672, 16.70042038], [82.27707672, 16.70014], [82.27791595, 16.70014], [82.27791595, 16.69985962], [82.27874756, 16.69986153], [82.27874756, 16.69958305], [82.27929688, 16.69959068], [82.27929688, 16.6993103], [82.2804184, 16.6993103], [82.2804184, 16.69902992], [82.28124237, 16.69902992], [82.28124237, 16.69874954], [82.28235626, 16.69874954], [82.28235626, 16.69847107], [82.2831955, 16.69847488], [82.2831955, 16.6981945], [82.28458405, 16.6981945], [82.28458405, 16.69791603], [82.28514099, 16.69791985], [82.28514099, 16.69763947], [82.28539276, 16.69763947], [82.28515625, 16.6974411], [82.27633667, 16.69310951], [82.26467133, 16.69053078], [82.25875092, 16.69011116]]], [[[82.29938507, 16.71402931], [82.29930878, 16.71388054], [82.29930878, 16.71375084], [82.29902649, 16.71375084], [82.29902649, 16.71347046], [82.29846954, 16.71347237], [82.29846954, 16.71291733], [82.29818726, 16.71292114], [82.29818726, 16.71236038], [82.29763794, 16.71236038], [82.29763794, 16.7118206], [82.29736328, 16.7118206], [82.29736328, 16.71153069], [82.29708099, 16.71153069], [82.29708099, 16.71125031], [82.29680634, 16.71125031], [82.29680634, 16.71096992], [82.29652405, 16.71097374], [82.29652405, 16.71041679], [82.29624176, 16.71042061], [82.29624176, 16.71014023], [82.2959671, 16.71014023], [82.2959671, 16.70985985], [82.29541779, 16.70986366], [82.29541779, 16.70958138], [82.2951355, 16.70958138], [82.2951355, 16.70930481], [82.29486084, 16.70930481], [82.29486084, 16.70902824], [82.29458618, 16.70903015], [82.29458618, 16.70876122], [82.29429626, 16.70876122], [82.29429626, 16.70846939], [82.29402924, 16.70846939], [82.29402924, 16.70819473], [82.29347229, 16.70819473], [82.29347229, 16.70791626], [82.29207611, 16.70792007], [82.29207611, 16.7076416], [82.29125214, 16.7076416], [82.29125214, 16.70735931], [82.28847504, 16.70735931], [82.28847504, 16.70708275], [82.28791809, 16.70708084], [82.28791809, 16.70735931], [82.28708649, 16.70735931], [82.28708649, 16.70708084], [82.28624725, 16.70708084], [82.28624725, 16.70735931], [82.28569794, 16.70735931], [82.28569794, 16.7076416], [82.28069305, 16.7076416], [82.28069305, 16.70792007], [82.2793045, 16.70791626], [82.2793045, 16.70819473], [82.27180481, 16.70819473], [82.27180481, 16.70846939], [82.27069092, 16.70846939], [82.27069092, 16.70903015], [82.2701416, 16.70902824], [82.2701416, 16.70930481], [82.26958466, 16.70930481], [82.26958466, 16.70958138], [82.26930237, 16.70958138], [82.26930237, 16.70986366], [82.26902771, 16.70985985], [82.26902771, 16.71014023], [82.26875305, 16.71014023], [82.26875305, 16.71042061], [82.26847076, 16.71042061], [82.26847076, 16.71070099], [82.26790619, 16.71070099], [82.26790619, 16.71125031], [82.26735687, 16.71125031], [82.26735687, 16.71153069], [82.2665329, 16.71153069], [82.2665329, 16.7118206], [82.26625061, 16.71180534], [82.26625061, 16.71208572], [82.26541901, 16.71208], [82.26541901, 16.71236038], [82.26513672, 16.71236038], [82.26513672, 16.71264076], [82.26486206, 16.71264076], [82.26486206, 16.71292114], [82.26457977, 16.71291733], [82.26457977, 16.7131958], [82.26430511, 16.7131958], [82.26430511, 16.71347237], [82.26374817, 16.71347046], [82.26374817, 16.71375084], [82.26319885, 16.71375084], [82.26319885, 16.71403122], [82.26264191, 16.71403122], [82.26264191, 16.71430969], [82.26208496, 16.71430588], [82.26208496, 16.71458244], [82.26152802, 16.714571], [82.26152802, 16.71486092], [82.26125336, 16.71486092], [82.26125336, 16.71513939], [82.26040649, 16.71513939], [82.26040649, 16.71541977], [82.25958252, 16.71541786], [82.25958252, 16.71569443], [82.25875092, 16.71569443], [82.25875092, 16.7159729], [82.25818634, 16.71597099], [82.25818634, 16.71624947], [82.25763702, 16.71624947], [82.25763702, 16.71652985], [82.25707245, 16.71652985], [82.25707245, 16.71681023], [82.25597382, 16.71680641], [82.25597382, 16.71708298], [82.25458527, 16.71708298], [82.25458527, 16.71736145], [82.25347137, 16.71736145], [82.25347137, 16.71763992], [82.25125885, 16.71763039], [82.25125885, 16.7179184], [82.25068665, 16.7179184], [82.25068665, 16.71763039], [82.24903107, 16.71763992], [82.24903107, 16.71736145], [82.24847412, 16.71736145], [82.24847412, 16.71708298], [82.24624634, 16.71708298], [82.24624634, 16.71680641], [82.24569702, 16.71681023], [82.24569702, 16.71597099], [82.24541473, 16.7159729], [82.24541473, 16.71513939], [82.24513245, 16.71513939], [82.24513245, 16.71403122], [82.24485779, 16.71403122], [82.24485779, 16.71319008], [82.24458313, 16.7131958], [82.24458313, 16.71236038], [82.24430847, 16.71236038], [82.24430847, 16.71125031], [82.24402618, 16.71125031], [82.24402618, 16.71042061], [82.24375153, 16.71042061], [82.24375153, 16.7093029], [82.24346924, 16.70930481], [82.24346924, 16.70875168], [82.24318695, 16.70876122], [82.24318695, 16.70846939], [82.24291992, 16.70846939], [82.24291992, 16.70819473], [82.24263763, 16.70819473], [82.24263763, 16.7076416], [82.24291992, 16.7076416], [82.24291992, 16.70792007], [82.24346924, 16.70792007], [82.24346924, 16.7076416], [82.24402618, 16.7076416], [82.24402618, 16.70735931], [82.24430847, 16.70735931], [82.24430847, 16.70708084], [82.24458313, 16.70708275], [82.24458313, 16.70680618], [82.24485779, 16.7068119], [82.24485779, 16.70653152], [82.24597168, 16.70653152], [82.24597168, 16.70624924], [82.24624634, 16.70624924], [82.24624634, 16.70597076], [82.24652863, 16.70597267], [82.24652863, 16.7056942], [82.24736023, 16.7056942], [82.24736023, 16.70541573], [82.24764252, 16.70541763], [82.24764252, 16.70513916], [82.24791718, 16.70513916], [82.24791718, 16.70486069], [82.24819946, 16.70486069], [82.24819183, 16.70430565], [82.24846649, 16.70430756], [82.24846649, 16.70402908], [82.24874878, 16.70402908], [82.24874878, 16.70375061], [82.24903107, 16.70375061], [82.24903107, 16.70347023], [82.24930573, 16.70347214], [82.24930573, 16.7029171], [82.24958038, 16.70292091], [82.24958038, 16.702631], [82.24986267, 16.70263863], [82.24986267, 16.70208359], [82.25013733, 16.70208359], [82.25013733, 16.70180511], [82.25041962, 16.70181084], [82.25041962, 16.70153046], [82.25068665, 16.70153046], [82.25068665, 16.70125008], [82.25096893, 16.70125008], [82.25096893, 16.7009697], [82.25125122, 16.7009716], [82.25125122, 16.70069695], [82.25152588, 16.70070076], [82.25152588, 16.70042038], [82.25180817, 16.70042038], [82.25180817, 16.70014], [82.25208282, 16.70014], [82.25208282, 16.69985962], [82.25235748, 16.69986153], [82.25235748, 16.69958305], [82.25263977, 16.69959068], [82.25263977, 16.69902992], [82.25319672, 16.69902992], [82.25319672, 16.69874954], [82.25374603, 16.69874954], [82.25374603, 16.69847107], [82.25402832, 16.69847488], [82.25402832, 16.69791603], [82.25430298, 16.69791985], [82.25430298, 16.6973629], [82.2545929, 16.6973629], [82.25458527, 16.69708443], [82.25485992, 16.69708443], [82.25485992, 16.69652748], [82.25514221, 16.69652939], [82.25514221, 16.69597054], [82.25541687, 16.69597054], [82.25541687, 16.69569206], [82.25569153, 16.69569206], [82.25569153, 16.6954174], [82.25596619, 16.69542122], [82.25596619, 16.69514275], [82.25624847, 16.69514275], [82.25624847, 16.69486046], [82.25653076, 16.69486046], [82.25653076, 16.69458008], [82.25680542, 16.69458389], [82.25680542, 16.69430542], [82.25653076, 16.69431114], [82.25653076, 16.69346809], [82.25708008, 16.69347191], [82.25708008, 16.69236183], [82.25736237, 16.69236183], [82.25736237, 16.69152832], [82.25763702, 16.69152832], [82.25763702, 16.69011307], [82.25344849, 16.68972015], [82.24653625, 16.69144058], [82.22740936, 16.70465088], [82.21543884, 16.70976067], [82.20252991, 16.70769119], [82.19358063, 16.70845032], [82.17907715, 16.71630096], [82.17463684, 16.7251091], [82.18032074, 16.72809982], [82.18875122, 16.72721291], [82.19677734, 16.73647118], [82.20722961, 16.74370956], [82.21113586, 16.74822044], [82.21768188, 16.75168991], [82.22181702, 16.75035286], [82.2197876, 16.74486923], [82.2100296, 16.73127174], [82.21096802, 16.72793961], [82.21478271, 16.72520065], [82.22042084, 16.7183094], [82.22704315, 16.71718025], [82.24494934, 16.71895981], [82.26370239, 16.71936989], [82.28070068, 16.72274971], [82.28507996, 16.73450851], [82.28909302, 16.74098969], [82.29370117, 16.74304008], [82.29773712, 16.74037933], [82.30105591, 16.73333931], [82.30282593, 16.72283936], [82.29951477, 16.71433258], [82.29943848, 16.71412849], [82.29938507, 16.71402931]]], [[[79.81014252, 11.87486076], [79.81014252, 11.87514973], [79.80930328, 11.87514973], [79.80930328, 11.87542152], [79.80874634, 11.87541676], [79.80874634, 11.87569523], [79.80764008, 11.87569523], [79.80764008, 11.87541676], [79.80680847, 11.87542152], [79.80680847, 11.87514973], [79.80625153, 11.87514973], [79.80625153, 11.87486076], [79.80581665, 11.87486076], [79.80541992, 11.87486076], [79.80541992, 11.87458134], [79.80458069, 11.87458324], [79.80458069, 11.87430477], [79.80513763, 11.87430859], [79.80513763, 11.87403107], [79.80541992, 11.87403107], [79.80541992, 11.87430859], [79.80568695, 11.87430859], [79.80652618, 11.87430477], [79.80652618, 11.87458324], [79.80737305, 11.87458134], [79.80737305, 11.87486076], [79.8079071, 11.87486076], [79.8079071, 11.87458134], [79.80958557, 11.87458324], [79.80958557, 11.87430477], [79.81014252, 11.87430859], [79.81014252, 11.87403107], [79.81043243, 11.87403107], [79.81043243, 11.87347126], [79.81069183, 11.87347317], [79.81069183, 11.87319469], [79.81097412, 11.87319469], [79.81097412, 11.87291718], [79.81153107, 11.87292099], [79.81153107, 11.87264061], [79.81208038, 11.87264061], [79.81208038, 11.87236118], [79.81291962, 11.87236118], [79.81291962, 11.87208271], [79.81430817, 11.87209034], [79.81430817, 11.87181187], [79.81458282, 11.87181187], [79.81458282, 11.87209034], [79.81485748, 11.87209034], [79.81485748, 11.87181187], [79.81597137, 11.87181187], [79.81597137, 11.87153053], [79.8162384, 11.87153053], [79.8162384, 11.87125111], [79.81652832, 11.87125111], [79.81652832, 11.87097073], [79.81764221, 11.87097073], [79.81764221, 11.87125111], [79.81846619, 11.87125111], [79.81846619, 11.87097073], [79.81874847, 11.87097263], [79.81874847, 11.87069511], [79.81903076, 11.87069511], [79.81903076, 11.87013912], [79.81931305, 11.87014103], [79.81931305, 11.86986065], [79.81958008, 11.86986065], [79.81958008, 11.86958027], [79.81986237, 11.86958313], [79.81986237, 11.86930466], [79.81958008, 11.86931133], [79.81958008, 11.8681879], [79.81930542, 11.86819458], [79.81930542, 11.86736012], [79.81903076, 11.86736012], [79.81903076, 11.8668108], [79.81874847, 11.8668108], [79.81874847, 11.86625004], [79.81846619, 11.86625004], [79.81846619, 11.86569023], [79.81819153, 11.86569405], [79.81819153, 11.86402798], [79.81764221, 11.86403275], [79.81764221, 11.86347008], [79.81735992, 11.86347198], [79.81735992, 11.86319447], [79.81708527, 11.86319447], [79.81708527, 11.86263847], [79.81680298, 11.86264038], [79.81680298, 11.86181068], [79.81652832, 11.86181068], [79.81652832, 11.86124992], [79.8162384, 11.86124992], [79.8162384, 11.86042023], [79.81597137, 11.86042023], [79.81597137, 11.85958195], [79.81625366, 11.85958385], [79.81625366, 11.85930634], [79.81597137, 11.85931015], [79.81597137, 11.85875034], [79.81569672, 11.85875034], [79.81569672, 11.85819054], [79.81541443, 11.85819435], [79.81541443, 11.85736179], [79.81513977, 11.85736179], [79.81513977, 11.85653019], [79.81485748, 11.85653019], [79.81485748, 11.85569096], [79.81458282, 11.85569572], [79.81458282, 11.85541534], [79.81430817, 11.85542011], [79.81430817, 11.85513973], [79.81402588, 11.85513973], [79.81402588, 11.85458088], [79.81375122, 11.85458374], [79.81375122, 11.85430622], [79.81346893, 11.85431004], [79.81346893, 11.85346889], [79.81291962, 11.8534708], [79.81291962, 11.85319328], [79.81263733, 11.85319328], [79.81263733, 11.8526392], [79.81236267, 11.8526392], [79.81236267, 11.85181046], [79.81208038, 11.85181046], [79.81208038, 11.8509798], [79.81181335, 11.8509798], [79.81181335, 11.85042191], [79.81153107, 11.85042191], [79.81153107, 11.84958076], [79.81124878, 11.84958267], [79.81124878, 11.84874916], [79.81096649, 11.84875107], [79.81096649, 11.84819126], [79.81069183, 11.84819508], [79.81069183, 11.84736061], [79.81041718, 11.84736061], [79.81041718, 11.84652901], [79.81014252, 11.84653091], [79.81014252, 11.84514141], [79.81043243, 11.84514141], [79.81043243, 11.84431171], [79.81014252, 11.84431171], [79.81014252, 11.84403133], [79.80986023, 11.84403133], [79.80986023, 11.84375095], [79.8095932, 11.84375095], [79.8095932, 11.84347057], [79.80902863, 11.84347343], [79.80902863, 11.84319496], [79.80930328, 11.84319496], [79.80930328, 11.84208298], [79.80902863, 11.84208298], [79.80902863, 11.84180355], [79.80874634, 11.84181118], [79.80874634, 11.83985996], [79.80847168, 11.83985996], [79.80847168, 11.83931065], [79.80819702, 11.83931065], [79.80819702, 11.8390398], [79.8079071, 11.8390398], [79.8079071, 11.83875275], [79.80764008, 11.83875275], [79.80764008, 11.83819199], [79.80735779, 11.83819389], [79.80735779, 11.8376379], [79.80764008, 11.83764267], [79.80764008, 11.83653069], [79.80708313, 11.83653069], [79.80708313, 11.83681107], [79.80625153, 11.83681107], [79.80625153, 11.83764267], [79.80652618, 11.83764267], [79.80652618, 11.83792114], [79.80680847, 11.83791637], [79.80680847, 11.83847237], [79.80652618, 11.83847046], [79.80652618, 11.8390398], [79.80625153, 11.83902836], [79.80625153, 11.83958244], [79.80569458, 11.83958244], [79.80569458, 11.83930683], [79.80179596, 11.83931065], [79.80179596, 11.84181118], [79.80123901, 11.84181118], [79.80123901, 11.8415308], [79.80097198, 11.8415308], [79.80097198, 11.84097004], [79.80069733, 11.8409729], [79.80069733, 11.84069538], [79.80041504, 11.84069538], [79.80041504, 11.84041595], [79.79985809, 11.84042072], [79.79985809, 11.8401413], [79.79957581, 11.8401413], [79.79957581, 11.83931065], [79.80042267, 11.83931065], [79.80042267, 11.8390398], [79.80097198, 11.8390398], [79.80097198, 11.83875275], [79.80123901, 11.83875275], [79.80123901, 11.83819199], [79.80152893, 11.83819389], [79.80152893, 11.83736229], [79.80180359, 11.83736229], [79.80180359, 11.83625031], [79.80208588, 11.83625031], [79.80208588, 11.83514023], [79.80236053, 11.83514023], [79.80236053, 11.83458042], [79.80291748, 11.83458424], [79.80291748, 11.83430576], [79.80319214, 11.83431053], [79.80319214, 11.83403015], [79.80403137, 11.83403015], [79.80403137, 11.83375168], [79.80513763, 11.83375168], [79.80513763, 11.83347034], [79.80541992, 11.83347225], [79.80541992, 11.83291626], [79.80569458, 11.83291626], [79.80569458, 11.83236217], [79.80596924, 11.83236217], [79.80596924, 11.82819557], [79.80569458, 11.82819557], [79.80569458, 11.82791805], [79.80541992, 11.82791996], [79.80541992, 11.82763958], [79.80568695, 11.82763958], [79.80568695, 11.8273592], [79.80541992, 11.82736206], [79.80541992, 11.82680511], [79.80513763, 11.82681179], [79.80513763, 11.82458115], [79.80458069, 11.82458305], [79.80458069, 11.82402706], [79.8042984, 11.82404137], [79.8042984, 11.82347107], [79.80403137, 11.82347107], [79.80403137, 11.82208347], [79.80374908, 11.82208347], [79.80374908, 11.821805], [79.80403137, 11.82180977], [79.80403137, 11.82097054], [79.80347443, 11.8209734], [79.80347443, 11.8204174], [79.80319214, 11.82041931], [79.80319214, 11.81986141], [79.80291748, 11.81986141], [79.80291748, 11.81902695], [79.80264282, 11.81903076], [79.80264282, 11.81681061], [79.80236053, 11.81681061], [79.80236053, 11.81653118], [79.80208588, 11.81653118], [79.80208588, 11.81597042], [79.80236053, 11.81597328], [79.80236053, 11.8148613], [79.80208588, 11.81487179], [79.80208588, 11.81403065], [79.80179596, 11.81403065], [79.80179596, 11.81236267], [79.80152893, 11.81236267], [79.80152893, 11.81208038], [79.80124664, 11.81208229], [79.80124664, 11.81124973], [79.80097198, 11.81124973], [79.80097198, 11.81042099], [79.80069733, 11.81042099], [79.80069733, 11.81013966], [79.80042267, 11.81013966], [79.80041504, 11.8083992], [79.79682159, 11.81153965], [79.79397583, 11.81564045], [79.79296875, 11.81764984], [79.79281616, 11.81945992], [79.79176331, 11.82697201], [79.79402161, 11.83020973], [79.79097748, 11.83181], [79.78787231, 11.83508968], [79.78616333, 11.83840179], [79.78176117, 11.840271], [79.77849579, 11.83882999], [79.76712036, 11.84047985], [79.76539612, 11.83333111], [79.76360321, 11.83250999], [79.76043701, 11.82303143], [79.75811005, 11.82210064], [79.75213623, 11.82445145], [79.74730682, 11.83270168], [79.74871063, 11.83584023], [79.75028229, 11.83598137], [79.7515564, 11.84166145], [79.75393677, 11.84224033], [79.7557373, 11.85046959], [79.75495148, 11.85783958], [79.75099945, 11.85894966], [79.74980927, 11.8605299], [79.74363708, 11.85972118], [79.74339294, 11.85363102], [79.73944855, 11.84986115], [79.73840332, 11.83500099], [79.72776031, 11.83233929], [79.73034668, 11.84687996], [79.71817017, 11.84836197], [79.71798706, 11.84762955], [79.70668793, 11.84708977], [79.70379639, 11.83829021], [79.69766998, 11.85242081], [79.69345093, 11.85389137], [79.69573212, 11.87337971], [79.69050598, 11.87406063], [79.68205261, 11.87335014], [79.68036652, 11.87062168], [79.67838287, 11.86957073], [79.67315674, 11.86995029], [79.67090607, 11.86983109], [79.67118073, 11.86660099], [79.65907288, 11.86566925], [79.65907288, 11.87212181], [79.66036987, 11.87732029], [79.66821289, 11.87625122], [79.6687088, 11.87463093], [79.67591095, 11.87932968], [79.67987061, 11.87926197], [79.68065643, 11.8819418], [79.6799469, 11.88615036], [79.68382263, 11.88745975], [79.68229675, 11.89185047], [79.67983246, 11.89344978], [79.68286133, 11.90470886], [79.70258331, 11.90250015], [79.70250702, 11.89843178], [79.69168854, 11.89777088], [79.69153595, 11.8784008], [79.70173645, 11.87654972], [79.70437622, 11.87460136], [79.70831299, 11.87395191], [79.71537018, 11.87497044], [79.71692657, 11.87684155], [79.71601868, 11.8866806], [79.71750641, 11.88924026], [79.72489929, 11.89151001], [79.70407867, 11.91299057], [79.7060318, 11.92870998], [79.6964798, 11.93245029], [79.6946106, 11.93133068], [79.69451141, 11.92593193], [79.69608307, 11.92010021], [79.69782257, 11.91668129], [79.69277954, 11.9211998], [79.69200134, 11.92448044], [79.69023895, 11.92618275], [79.68414307, 11.92722034], [79.67819977, 11.93653202], [79.6776886, 11.93935108], [79.68148041, 11.94336033], [79.68312836, 11.94650078], [79.68543243, 11.9451704], [79.68667603, 11.94728088], [79.69315338, 11.95079041], [79.70155334, 11.95218086], [79.70192719, 11.95643139], [79.69525909, 11.96103096], [79.69921875, 11.97003078], [79.6990509, 11.97205925], [79.69480133, 11.97511101], [79.68997955, 11.9756403], [79.68689728, 11.9739809], [79.68416595, 11.97472954], [79.68113708, 11.97284126], [79.67749786, 11.97399044], [79.67344666, 11.97236919], [79.67114258, 11.97476006], [79.6653595, 11.96752167], [79.66143036, 11.97285938], [79.65960693, 11.97705078], [79.65122223, 11.97201061], [79.64420319, 11.97321033], [79.64234161, 11.975811], [79.64428711, 11.98627186], [79.64441681, 11.98627186], [79.64434052, 11.99267197], [79.6470108, 11.99332142], [79.64731598, 11.99722958], [79.65236664, 11.99830055], [79.65930939, 11.99689102], [79.66326141, 12.00638103], [79.66890717, 12.00729179], [79.67151642, 12.01162148], [79.67645264, 12.0128603], [79.679039, 12.01926041], [79.69155884, 12.0174408], [79.69242096, 12.01107121], [79.69048309, 12.00112057], [79.69075775, 11.99627972], [79.69539642, 11.99268055], [79.7016983, 11.98608971], [79.70359039, 11.98005009], [79.70584869, 11.97737026], [79.7098999, 11.97622108], [79.71259308, 11.97563076], [79.71695709, 11.97544193], [79.71985626, 11.97646046], [79.72493744, 11.97790146], [79.72711182, 11.97996998], [79.72885895, 11.98602104], [79.72899628, 11.98602104], [79.73468018, 11.99431133], [79.74964905, 11.98613071], [79.75260925, 11.97945976], [79.75244141, 11.97612953], [79.74906921, 11.97236919], [79.74513245, 11.97085094], [79.74240875, 11.96704102], [79.73816681, 11.9670496], [79.73544312, 11.96361065], [79.72692108, 11.96249199], [79.72209167, 11.96743965], [79.71790314, 11.96887112], [79.71570587, 11.9674511], [79.7144928, 11.95525074], [79.73361206, 11.94721031], [79.73356628, 11.93729973], [79.73690033, 11.92739105], [79.73658752, 11.91020966], [79.73690033, 11.9071703], [79.74053955, 11.90716076], [79.7408371, 11.90945053], [79.74751282, 11.91516113], [79.7472229, 11.91783047], [79.74784088, 11.92890167], [79.75814056, 11.93040085], [79.76420593, 11.93459034], [79.76544952, 11.93916035], [79.76937866, 11.94145107], [79.77181244, 11.94640064], [79.77272034, 11.9467907], [79.77575684, 11.94601059], [79.77879333, 11.94640064], [79.78333282, 11.94373035], [79.78756714, 11.9383707], [79.79030609, 11.94255066], [79.79165649, 11.94774055], [79.79242706, 11.95705128], [79.79527283, 11.96189022], [79.7979126, 11.96352196], [79.79972839, 11.96428967], [79.80458832, 11.96314144], [79.80602264, 11.95922089], [79.80632782, 11.95526886], [79.8081131, 11.94651031], [79.8110199, 11.94250965], [79.81420135, 11.94062138], [79.81800079, 11.94039059], [79.82540131, 11.94001007], [79.82540131, 11.94014931], [79.83069611, 11.94024944], [79.83763885, 11.94054985], [79.83763885, 11.93986225], [79.8373642, 11.93986225], [79.8373642, 11.93875027], [79.83708191, 11.93875027], [79.83708191, 11.93624973], [79.83680725, 11.93624973], [79.83680725, 11.93543053], [79.83653259, 11.93543053], [79.83653259, 11.93347073], [79.83625031, 11.93347359], [79.83625031, 11.93319321], [79.83652496, 11.93319321], [79.83652496, 11.93291664], [79.83625031, 11.93292046], [79.83625031, 11.93125057], [79.83598328, 11.93125057], [79.83598328, 11.92958069], [79.83625031, 11.9295826], [79.83625031, 11.92930508], [79.83597565, 11.92930508], [79.83597565, 11.9290266], [79.83569336, 11.92903233], [79.83569336, 11.92819118], [79.8354187, 11.928195], [79.8354187, 11.92791653], [79.83513641, 11.92791939], [79.83513641, 11.92764091], [79.8354187, 11.92764091], [79.8354187, 11.92736053], [79.83513641, 11.92736053], [79.83513641, 11.92625141], [79.83486176, 11.92625999], [79.83486176, 11.92457962], [79.8345871, 11.92458344], [79.8345871, 11.92375088], [79.83431244, 11.92375088], [79.83431244, 11.92292118], [79.83403015, 11.92292118], [79.83403015, 11.9226408], [79.83374786, 11.9226408], [79.83374786, 11.9218111], [79.83347321, 11.9218111], [79.83347321, 11.91986275], [79.83319092, 11.91986275], [79.83319092, 11.91958046], [79.83291626, 11.91958237], [79.83291626, 11.91874981], [79.8326416, 11.91875267], [79.8326416, 11.91763973], [79.83235931, 11.91763973], [79.83235931, 11.91681099], [79.83207703, 11.91681099], [79.83207703, 11.91625023], [79.83180237, 11.91625023], [79.83180237, 11.91596985], [79.83152771, 11.91597176], [79.83152771, 11.91569424], [79.83125305, 11.91569424], [79.83125305, 11.91541576], [79.83097076, 11.91542053], [79.83097076, 11.91347027], [79.83069611, 11.91347218], [79.83069611, 11.9131937], [79.83041382, 11.9131937], [79.83041382, 11.91263771], [79.83013916, 11.91263962], [79.83013916, 11.91180992], [79.82985687, 11.91180992], [79.82985687, 11.91069126], [79.82958221, 11.91069412], [79.82958221, 11.91041565], [79.82985687, 11.91042042], [79.82985687, 11.90957928], [79.83013916, 11.90958405], [79.83013916, 11.90791798], [79.83069611, 11.90792179], [79.83069611, 11.90764046], [79.83097076, 11.90764046], [79.83097076, 11.90708065], [79.83069611, 11.90708256], [79.83069611, 11.90680504], [79.82985687, 11.90680981], [79.82985687, 11.90653038], [79.82875061, 11.90653038], [79.82875061, 11.90680981], [79.82819366, 11.90680504], [79.82819366, 11.90708256], [79.82791901, 11.90708065], [79.82791901, 11.90736198], [79.82763672, 11.90736198], [79.82763672, 11.90792179], [79.82736206, 11.90791798], [79.82736206, 11.90847111], [79.82707977, 11.9084692], [79.82707977, 11.90902996], [79.82736206, 11.90902996], [79.82736206, 11.91042042], [79.82763672, 11.91042042], [79.82763672, 11.9143219], [79.82736206, 11.9143219], [79.82736206, 11.91486168], [79.82707977, 11.91486168], [79.82707977, 11.91514015], [79.82681274, 11.91514015], [79.82681274, 11.91542053], [79.82653046, 11.91541576], [79.82653046, 11.91569424], [79.82624817, 11.91569424], [79.82624817, 11.91597176], [79.82569122, 11.91596985], [79.82569122, 11.91625023], [79.82540894, 11.91625023], [79.82540894, 11.91652966], [79.82430267, 11.91652966], [79.82430267, 11.91596985], [79.82458496, 11.91597176], [79.82458496, 11.91541576], [79.82485962, 11.91542053], [79.82485962, 11.91486168], [79.82514191, 11.91486168], [79.82514191, 11.91458035], [79.82569122, 11.91458416], [79.82569122, 11.91430569], [79.82596588, 11.9143219], [79.82596588, 11.91403008], [79.82624817, 11.91403008], [79.82624817, 11.91347027], [79.82653046, 11.91347218], [79.82653046, 11.91263771], [79.82624817, 11.91263962], [79.82624817, 11.91207886], [79.82653046, 11.91208363], [79.82653046, 11.90958405], [79.82624817, 11.90958405], [79.82624817, 11.90902805], [79.82596588, 11.90902996], [79.82596588, 11.90792179], [79.82569122, 11.90792179], [79.82569122, 11.90764046], [79.82514191, 11.90764046], [79.82514191, 11.90902996], [79.82485962, 11.90902996], [79.82485962, 11.90931034], [79.82459259, 11.90931034], [79.82459259, 11.90874958], [79.82290649, 11.90874958], [79.82290649, 11.90902996], [79.82263947, 11.90902996], [79.82263947, 11.90931034], [79.82237244, 11.90931034], [79.82237244, 11.90902996], [79.82180786, 11.90902996], [79.82180786, 11.90874958], [79.8215332, 11.90874958], [79.8215332, 11.9084692], [79.82125092, 11.90847111], [79.82125092, 11.90819645], [79.82013702, 11.90819645], [79.82013702, 11.90791798], [79.81986237, 11.90792179], [79.81986237, 11.90764046], [79.81958008, 11.90764046], [79.81958008, 11.90736198], [79.81930542, 11.90736198], [79.81930542, 11.90708256], [79.81903076, 11.90708256], [79.81903076, 11.90680504], [79.81874847, 11.90680981], [79.81874847, 11.90625191], [79.81846619, 11.90625191], [79.81846619, 11.90431023], [79.81819153, 11.90431023], [79.81819153, 11.90207195], [79.81791687, 11.9020834], [79.81791687, 11.9015274], [79.81819153, 11.90152931], [79.81819153, 11.90180969], [79.81874847, 11.90180969], [79.81874847, 11.90236092], [79.81903076, 11.90236092], [79.81903076, 11.9026413], [79.81930542, 11.90263939], [79.81930542, 11.90375137], [79.81958008, 11.90375137], [79.81958008, 11.90513897], [79.81986237, 11.90513897], [79.81986237, 11.90569305], [79.82013702, 11.90569115], [79.82013702, 11.90625191], [79.82041931, 11.90625191], [79.82041931, 11.90653038], [79.82068634, 11.90653038], [79.82068634, 11.90680981], [79.82125092, 11.90680504], [79.82125092, 11.90708256], [79.82152557, 11.90708256], [79.82152557, 11.90736198], [79.82375336, 11.90736198], [79.82375336, 11.90708065], [79.82402802, 11.90708256], [79.82402802, 11.90680504], [79.82459259, 11.90680981], [79.82459259, 11.90625191], [79.82653046, 11.90625191], [79.82653046, 11.90597057], [79.82736206, 11.90597439], [79.82736206, 11.90569305], [79.82930756, 11.90569305], [79.82930756, 11.90541744], [79.82958221, 11.9054203], [79.82958221, 11.90486145], [79.8298645, 11.90486145], [79.8298645, 11.90458298], [79.83041382, 11.90458298], [79.83041382, 11.90402699], [79.83097076, 11.90402699], [79.83097076, 11.90486145], [79.83125305, 11.90486145], [79.83125305, 11.90513897], [79.83154297, 11.90513039], [79.83154297, 11.9054203], [79.83207703, 11.9054203], [79.83207703, 11.90402889], [79.83180237, 11.90402889], [79.83180237, 11.90375137], [79.83125305, 11.90375137], [79.83125305, 11.90347099], [79.82847595, 11.90347099], [79.82847595, 11.90291691], [79.82817841, 11.90292168], [79.82817841, 11.90207195], [79.82791901, 11.9020834], [79.82791901, 11.90097332], [79.82763672, 11.90097332], [79.82763672, 11.90041733], [79.82736206, 11.90041924], [79.82736206, 11.89847088], [79.82791901, 11.89847279], [79.82791901, 11.89680672], [79.82763672, 11.89681053], [79.82763672, 11.89625072], [79.82736206, 11.89625072], [79.82736206, 11.89597034], [79.82707977, 11.89597321], [79.82707977, 11.89486027], [79.82736206, 11.89486027], [79.82736206, 11.89458466], [79.82707977, 11.89458466], [79.82707977, 11.89430428], [79.82681274, 11.89431095], [79.82681274, 11.89403057], [79.82653046, 11.89403057], [79.82653046, 11.89375114], [79.82624817, 11.89375114], [79.82624817, 11.89097023], [79.82653046, 11.89097214], [79.82653046, 11.89069366], [79.82624817, 11.89069366], [79.82624817, 11.88958359], [79.82597351, 11.88958359], [79.82597351, 11.88930607], [79.82569122, 11.88931084], [79.82569122, 11.88875008], [79.82540894, 11.88875008], [79.82540894, 11.88818932], [79.82514191, 11.88819408], [79.82514191, 11.88680553], [79.82485962, 11.88681126], [79.82485962, 11.88624954], [79.82459259, 11.88624954], [79.82459259, 11.88569069], [79.82430267, 11.88569355], [79.82430267, 11.88486195], [79.82459259, 11.88486195], [79.82458496, 11.88374996], [79.82430267, 11.88375187], [79.82430267, 11.88319969], [79.82402802, 11.88319111], [79.82402802, 11.88291645], [79.82375336, 11.88292027], [79.82375336, 11.88181019], [79.82290649, 11.88181019], [79.82290649, 11.88152981], [79.82208252, 11.88152981], [79.82208252, 11.88124943], [79.82180786, 11.88124943], [79.82180786, 11.88096046], [79.82125092, 11.88097095], [79.82125092, 11.88069344], [79.82013702, 11.88069344], [79.82013702, 11.88041782], [79.81958008, 11.88041973], [79.81958008, 11.8801403], [79.81931305, 11.8801403], [79.81931305, 11.87986088], [79.81903076, 11.87986088], [79.81903076, 11.87958145], [79.81846619, 11.87958145], [79.81846619, 11.87986088], [79.81791687, 11.87986088], [79.81791687, 11.8801403], [79.8162384, 11.8801403], [79.8162384, 11.88041973], [79.81513977, 11.88041782], [79.81513977, 11.88069344], [79.81485748, 11.88069344], [79.81485748, 11.88041782], [79.81430817, 11.88041782], [79.81430817, 11.88069344], [79.81402588, 11.88069344], [79.81402588, 11.88097095], [79.81346893, 11.88096046], [79.81346893, 11.88124943], [79.81317902, 11.88124943], [79.81317902, 11.88152981], [79.81208038, 11.88152981], [79.81208038, 11.88181019], [79.81097412, 11.88180637], [79.81097412, 11.88208389], [79.81041718, 11.88208389], [79.81041718, 11.88236237], [79.8079071, 11.88235855], [79.8079071, 11.88264179], [79.80761719, 11.88263988], [79.80737305, 11.88264179], [79.80737305, 11.88292027], [79.80652618, 11.88292027], [79.80652618, 11.88264179], [79.80625153, 11.88264179], [79.80625153, 11.88292027], [79.80486298, 11.88291645], [79.80486298, 11.88319111], [79.80347443, 11.88319588], [79.80347443, 11.88347244], [79.80208588, 11.88347244], [79.80208588, 11.88375187], [79.80097198, 11.88375187], [79.80097198, 11.88347244], [79.80041504, 11.88347244], [79.80041504, 11.88319588], [79.80014038, 11.88319111], [79.80014038, 11.88291645], [79.79957581, 11.88292027], [79.79957581, 11.88264179], [79.79792023, 11.88264179], [79.79792023, 11.88235855], [79.79736328, 11.88236237], [79.79736328, 11.88208389], [79.79680634, 11.88208389], [79.79680634, 11.88180637], [79.79624939, 11.88181019], [79.79624939, 11.88152981], [79.79569244, 11.88152981], [79.79569244, 11.88124943], [79.79541779, 11.88124943], [79.79541779, 11.88097095], [79.79374695, 11.88097095], [79.79374695, 11.88069344], [79.79347229, 11.88069344], [79.79347229, 11.8801403], [79.79319763, 11.8801403], [79.79319763, 11.87986088], [79.79347229, 11.87986088], [79.79347229, 11.87958145], [79.79319763, 11.87958336], [79.79319763, 11.87902737], [79.79207611, 11.87903023], [79.79207611, 11.87874889], [79.79069519, 11.87874889], [79.79069519, 11.87847137], [79.79152679, 11.87847137], [79.79152679, 11.87819481], [79.79180908, 11.87819481], [79.79180908, 11.87791729], [79.79374695, 11.87792015], [79.79374695, 11.87764168], [79.79458618, 11.87764168], [79.79458618, 11.87792015], [79.79486084, 11.87791729], [79.79486084, 11.87819481], [79.79541779, 11.87819481], [79.79541779, 11.87847137], [79.79569244, 11.87847137], [79.79569244, 11.87903023], [79.79624939, 11.87903023], [79.79624939, 11.87930965], [79.79651642, 11.87930965], [79.79651642, 11.87986088], [79.79680634, 11.87986088], [79.79680634, 11.8801403], [79.79736328, 11.8801403], [79.79736328, 11.88041973], [79.79763794, 11.88041782], [79.79763794, 11.88069344], [79.79846954, 11.88069344], [79.79846954, 11.88097095], [79.79875183, 11.88096046], [79.79875183, 11.88124943], [79.79902649, 11.88124943], [79.79902649, 11.88152981], [79.79930878, 11.88152981], [79.79930878, 11.88181019], [79.79957581, 11.88181019], [79.79957581, 11.88152981], [79.80069733, 11.88152981], [79.80069733, 11.88096046], [79.80041504, 11.88097095], [79.80041504, 11.88069344], [79.80097198, 11.88069344], [79.80097198, 11.88041782], [79.80180359, 11.88041782], [79.80180359, 11.88069344], [79.80263519, 11.88069344], [79.80263519, 11.88041782], [79.80347443, 11.88041782], [79.80347443, 11.88069344], [79.80374908, 11.88069057], [79.80374908, 11.88152981], [79.80403137, 11.88152981], [79.80403137, 11.88181019], [79.80458069, 11.88180637], [79.80458069, 11.88208389], [79.80486298, 11.88208389], [79.80486298, 11.88180637], [79.80513763, 11.88180637], [79.80513763, 11.88208389], [79.80569458, 11.88208389], [79.80569458, 11.88180637], [79.80652618, 11.88181019], [79.80652618, 11.88152981], [79.80680847, 11.88152981], [79.80680847, 11.88124943], [79.80708313, 11.88124943], [79.80708313, 11.88096046], [79.80724335, 11.88096714], [79.80735779, 11.88097095], [79.80735779, 11.88069344], [79.80847168, 11.88069344], [79.80847168, 11.88041782], [79.8095932, 11.88041973], [79.8095932, 11.8801403], [79.80986023, 11.8801403], [79.80986023, 11.87986088], [79.81043243, 11.87986088], [79.81041718, 11.87958336], [79.81097412, 11.87958336], [79.81097412, 11.87930489], [79.81153107, 11.87930965], [79.81153107, 11.87903023], [79.81208038, 11.87903023], [79.81208038, 11.87847137], [79.81236267, 11.87847137], [79.81236267, 11.87819481], [79.81291962, 11.87819481], [79.81291962, 11.87791729], [79.81317902, 11.87792015], [79.81317902, 11.87764168], [79.81485748, 11.87764168], [79.81485748, 11.8773613], [79.81513977, 11.8773613], [79.81513977, 11.87708282], [79.81541443, 11.87708282], [79.81541443, 11.87680531], [79.81597137, 11.87681198], [79.81597137, 11.8765316], [79.81652832, 11.8765316], [79.81652832, 11.87625122], [79.81680298, 11.87625122], [79.81680298, 11.87597084], [79.81735992, 11.87597084], [79.81735992, 11.87542152], [79.81764221, 11.87542152], [79.81764221, 11.87514973], [79.81819153, 11.87514973], [79.81819153, 11.87458134], [79.81903076, 11.87458324], [79.81903076, 11.87430477], [79.81958008, 11.87430859], [79.81958008, 11.87347126], [79.81930542, 11.87347317], [79.81930542, 11.87319469], [79.81847382, 11.87319469], [79.81847382, 11.87347317], [79.81791687, 11.87347126], [79.81791687, 11.87375069], [79.81680298, 11.87375069], [79.81680298, 11.87347126], [79.81485748, 11.87347126], [79.81485748, 11.87375069], [79.81375122, 11.87375069], [79.81375122, 11.87403107], [79.81263733, 11.87403107], [79.81263733, 11.87430859], [79.81236267, 11.87430477], [79.81236267, 11.87458324], [79.81096649, 11.87458134], [79.81096649, 11.87486076], [79.81014252, 11.87486076]]]]}}, {\\\"id\\\": \\\"25\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.28_1\\\", \\\"HASC_1\\\": \\\"IN.PB\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Punjab\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 64.1, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1687.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 940.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2627.0, \\\"geo-id\\\": 25, \\\"hpm25_child_popweighted\\\": 164.2, \\\"hpm25_female_popweighted\\\": 188.8, \\\"hpm25_male_popweighted\\\": 135.9, \\\"location\\\": \\\"Punjab\\\", \\\"mort_apm25_6cod_mean_total\\\": 17382.0, \\\"mort_hpm25_6cod_mean_total\\\": 9834.0, \\\"mort_tpm25_6cod_mean_total\\\": 27216.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[74.27902985, 29.95508957], [74.26030731, 29.9556694], [74.25190735, 29.95525932], [74.24067688, 29.95628929], [74.22380066, 29.95971107], [74.21276093, 29.96039009], [74.18596649, 29.96038055], [74.15444946, 29.96329117], [74.08332825, 29.96737289], [74.06919861, 29.96887016], [74.00274658, 29.97006035], [73.9960022, 29.97089005], [73.99092102, 29.97122955], [73.97646332, 29.96911049], [73.9569397, 29.96951294], [73.93295288, 29.97074127], [73.89118195, 29.97006989], [73.88944244, 29.97760963], [73.8884964, 29.9817791], [73.88302612, 29.99129105], [73.8811264, 29.99628067], [73.88186646, 30.01124001], [73.88551331, 30.01742935], [73.89261627, 30.03853035], [73.89480591, 30.0468502], [73.89840698, 30.0536499], [73.90854645, 30.06011009], [73.91821289, 30.06814957], [73.93152618, 30.08381081], [73.94291687, 30.09909058], [73.94410706, 30.10423088], [73.94998932, 30.1097908], [73.95794678, 30.11956024], [73.96665192, 30.12118912], [73.96393585, 30.12438011], [73.96247101, 30.12750053], [73.96118164, 30.13422966], [73.96082306, 30.14323044], [73.96337128, 30.17182922], [73.96643829, 30.17703056], [73.96810913, 30.18429947], [73.96640778, 30.19449425], [73.96631622, 30.19504929], [73.96459961, 30.2244606], [73.96391296, 30.23080063], [73.96383667, 30.23130035], [73.96115875, 30.24121284], [73.9598465, 30.25517273], [73.95909119, 30.25562096], [73.9578476, 30.26169014], [73.95574951, 30.2630291], [73.954422, 30.26619911], [73.95205688, 30.26798058], [73.95155334, 30.26999092], [73.95072174, 30.27054977], [73.94944, 30.27135086], [73.94872284, 30.27382278], [73.94795227, 30.27425003], [73.94734192, 30.27471161], [73.94448853, 30.28183174], [73.94394684, 30.28207016], [73.94329834, 30.28495979], [73.94229126, 30.28619957], [73.94126129, 30.2868309], [73.94124603, 30.28751945], [73.94045258, 30.28795052], [73.93699646, 30.29634285], [73.9363327, 30.2968998], [73.93432617, 30.30302048], [73.93308258, 30.30375099], [73.93209839, 30.30533028], [73.93138123, 30.30653954], [73.92685699, 30.30931854], [73.92662048, 30.30995941], [73.92608643, 30.31018066], [73.9254303, 30.31064034], [73.9241333, 30.31402969], [73.92305756, 30.31491089], [73.92253113, 30.31511116], [73.92015839, 30.32006073], [73.91963959, 30.32029915], [73.9190979, 30.32051086], [73.91828156, 30.32322121], [73.91620636, 30.3250103], [73.91590118, 30.32726097], [73.91436005, 30.32816124], [73.91422272, 30.32862091], [73.91304779, 30.3308506], [73.9122467, 30.33128929], [73.91118622, 30.33196831], [73.90854645, 30.33669281], [73.90750885, 30.33711052], [73.90647125, 30.33756828], [73.90647125, 30.33823013], [73.90569305, 30.33980942], [73.9048996, 30.34025955], [73.90461731, 30.34091949], [73.90329742, 30.34136963], [73.90096283, 30.3429203], [73.89980316, 30.34492111], [73.89952087, 30.34581184], [73.89875031, 30.34626961], [73.897789, 30.34695816], [73.89727783, 30.34900093], [73.89392853, 30.35056496], [73.88564301, 30.3544426], [73.88069153, 30.35715294], [73.88043213, 30.35775185], [73.87874603, 30.35897827], [73.87555695, 30.36079025], [73.87554932, 30.36130333], [73.87530518, 30.36138535], [73.87125397, 30.36857224], [73.87088776, 30.37499619], [73.87321472, 30.38343811], [73.87975311, 30.39111137], [73.88179016, 30.39276886], [73.89352417, 30.40231323], [73.90119934, 30.41271591], [73.90341949, 30.41679764], [73.92016602, 30.42014122], [73.92785645, 30.4209137], [73.93034363, 30.4249897], [73.93161011, 30.43322182], [73.93309021, 30.43609619], [73.93663025, 30.44298363], [73.93226624, 30.45843124], [73.93528748, 30.46295738], [73.93974304, 30.46269417], [73.94450378, 30.46241379], [73.94691467, 30.46227264], [73.95307922, 30.45910835], [73.95527649, 30.45798111], [73.962677, 30.45760727], [73.96652985, 30.46349144], [73.96828461, 30.47631454], [73.96881866, 30.48018646], [73.97273254, 30.48813248], [73.98365021, 30.50053024], [73.98851776, 30.50456047], [73.99977875, 30.51087952], [74.00652313, 30.5146637], [74.01862335, 30.52145195], [74.02561188, 30.52537537], [74.02948761, 30.53172112], [74.03060913, 30.53228951], [74.0329361, 30.53466988], [74.03401184, 30.5362606], [74.04023743, 30.53768539], [74.04071808, 30.53710365], [74.04767609, 30.52859497], [74.05570221, 30.5220108], [74.06085205, 30.52114105], [74.06651306, 30.52018738], [74.07761383, 30.52936172], [74.07996368, 30.53305054], [74.08480835, 30.54067993], [74.08439636, 30.54504013], [74.08226776, 30.54645157], [74.07642365, 30.55031776], [74.07213593, 30.54927063], [74.06817627, 30.5508194], [74.06777191, 30.5535202], [74.06790161, 30.55487061], [74.06932831, 30.5560112], [74.07087708, 30.55714035], [74.07138824, 30.55761147], [74.07594299, 30.56102943], [74.08409882, 30.56619263], [74.08512115, 30.56740952], [74.08999634, 30.57172012], [74.0904007, 30.57204819], [74.09120941, 30.57285118], [74.09262848, 30.57534981], [74.09307098, 30.57987976], [74.09323883, 30.58144951], [74.09213257, 30.5884304], [74.09204865, 30.59813118], [74.09445953, 30.60468292], [74.0944519, 30.60580063], [74.09430695, 30.6062603], [74.09015656, 30.60849953], [74.09001923, 30.61028099], [74.09099579, 30.61279106], [74.09583282, 30.61507988], [74.09841919, 30.61552048], [74.09922028, 30.61486053], [74.0994873, 30.61351013], [74.10056305, 30.61150169], [74.10108185, 30.6112709], [74.10205841, 30.6100235], [74.10212708, 30.60993004], [74.10212708, 30.60926056], [74.1047287, 30.60744286], [74.10473633, 30.60655975], [74.10891724, 30.60568047], [74.10945892, 30.60593033], [74.11048889, 30.60704994], [74.11148834, 30.61498833], [74.11171722, 30.61678123], [74.11686707, 30.62330818], [74.11691284, 30.62433052], [74.1174469, 30.62433052], [74.11837006, 30.63216019], [74.12095642, 30.63239098], [74.12177277, 30.63241005], [74.12359619, 30.62902069], [74.12986755, 30.62792015], [74.13122559, 30.62864876], [74.13491058, 30.62880135], [74.14394379, 30.6291008], [74.15077209, 30.63254166], [74.15093231, 30.63262177], [74.17874146, 30.65572166], [74.18323517, 30.65945244], [74.18336487, 30.65944862], [74.18569946, 30.65940094], [74.1861496, 30.6593914], [74.19683838, 30.67177582], [74.20818329, 30.68826866], [74.22200775, 30.70814705], [74.22724915, 30.71407318], [74.23215485, 30.71962166], [74.23305511, 30.71988106], [74.24098206, 30.72217941], [74.25400543, 30.72304535], [74.26831055, 30.73144531], [74.27966309, 30.7293644], [74.28180695, 30.73023415], [74.28246307, 30.73457336], [74.2736969, 30.7432518], [74.27322388, 30.74447441], [74.26628876, 30.76243973], [74.26220703, 30.76803017], [74.26499939, 30.77278328], [74.26647949, 30.77278137], [74.27372742, 30.77276993], [74.27910614, 30.77612114], [74.2840271, 30.77703094], [74.2848053, 30.77697945], [74.28555298, 30.77692986], [74.29113007, 30.77841187], [74.29631805, 30.78157806], [74.29737854, 30.7827301], [74.29914093, 30.78596115], [74.2990799, 30.78732681], [74.29901123, 30.78883934], [74.29810333, 30.78996277], [74.29759216, 30.79018021], [74.29677582, 30.79243088], [74.2962265, 30.79286957], [74.29537964, 30.79306793], [74.2906189, 30.79418945], [74.28684998, 30.79578018], [74.286026, 30.79667091], [74.28575897, 30.79959106], [74.29225922, 30.80233192], [74.29331207, 30.80323029], [74.29458618, 30.81022072], [74.29532623, 30.81158257], [74.29833221, 30.81431961], [74.30237579, 30.81637955], [74.30760193, 30.82114029], [74.30845642, 30.82384109], [74.31047821, 30.83468056], [74.31162262, 30.84053993], [74.3140564, 30.84370041], [74.31614685, 30.84758186], [74.31997681, 30.84962082], [74.32048035, 30.84985161], [74.32334137, 30.85033035], [74.32935333, 30.84877968], [74.33114624, 30.84898949], [74.33122253, 30.85027122], [74.3312912, 30.85079002], [74.33139801, 30.85239029], [74.3324585, 30.85307121], [74.33461761, 30.85352516], [74.33743286, 30.85411835], [74.34089661, 30.85402107], [74.342659, 30.8544693], [74.34604645, 30.85425758], [74.34604645, 30.85357094], [74.34658813, 30.85335922], [74.34733582, 30.85289955], [74.3473587, 30.85128975], [74.35118103, 30.84996986], [74.3536377, 30.84865189], [74.35875702, 30.8459034], [74.36300659, 30.84580612], [74.37198639, 30.85294151], [74.37114716, 30.86029625], [74.36532593, 30.86818886], [74.36494446, 30.86870384], [74.36221313, 30.87241936], [74.36188507, 30.87930107], [74.36552429, 30.88540649], [74.36618042, 30.88565826], [74.37627411, 30.88952255], [74.38272095, 30.89166832], [74.39503479, 30.90353775], [74.41292572, 30.90634155], [74.41610718, 30.90604019], [74.41920471, 30.9116993], [74.42031097, 30.92218399], [74.42070007, 30.92587662], [74.42761993, 30.93327713], [74.42867279, 30.93440628], [74.44639587, 30.94889641], [74.46434021, 30.96154976], [74.46782684, 30.96261215], [74.47058868, 30.96598816], [74.48509216, 30.97046471], [74.48963165, 30.96970367], [74.49143982, 30.96940041], [74.49661255, 30.96718407], [74.49698639, 30.96756935], [74.4997406, 30.96902084], [74.50444794, 30.97784805], [74.50888062, 30.98003006], [74.50966644, 30.9803524], [74.51435089, 30.98487091], [74.52272034, 30.98897934], [74.53263855, 30.99056816], [74.53658295, 30.99217033], [74.53811646, 30.99354172], [74.53851318, 30.9973526], [74.53800201, 30.99757004], [74.53704071, 31.00029945], [74.53618622, 31.00089073], [74.53504944, 31.00213051], [74.53360748, 31.00505066], [74.53231812, 31.00806999], [74.53179932, 31.0092907], [74.53179169, 31.01268959], [74.53469086, 31.01569176], [74.53572083, 31.01676178], [74.53800201, 31.03166962], [74.54058838, 31.03481293], [74.54611206, 31.03868103], [74.54967499, 31.04321861], [74.55310822, 31.0608902], [74.55344391, 31.06260109], [74.55839539, 31.06752586], [74.57170105, 31.06743622], [74.57330322, 31.06625366], [74.59249878, 31.05204201], [74.59736633, 31.04619598], [74.60018158, 31.04354668], [74.60262299, 31.04470062], [74.6054306, 31.04528046], [74.61441803, 31.04618073], [74.62251282, 31.04702187], [74.63350677, 31.05291939], [74.64240265, 31.05316162], [74.64605713, 31.05294037], [74.64892578, 31.05318069], [74.65600586, 31.05451012], [74.66660309, 31.05881119], [74.67221832, 31.06157112], [74.67378998, 31.0635891], [74.67823792, 31.06675911], [74.68319702, 31.07217979], [74.6840744, 31.07422066], [74.68504333, 31.07646942], [74.68492889, 31.07996941], [74.68418884, 31.08136177], [74.68422699, 31.08641052], [74.68628693, 31.08956909], [74.69101715, 31.09205055], [74.69442749, 31.09543991], [74.69441986, 31.09815025], [74.69075012, 31.10399818], [74.6906662, 31.11013222], [74.69061279, 31.11448097], [74.69059753, 31.11503029], [74.69059753, 31.11551094], [74.68991089, 31.11709023], [74.68624115, 31.11935234], [74.68206024, 31.12023926], [74.68060303, 31.12545967], [74.67913055, 31.12903023], [74.67809296, 31.1294899], [74.67730713, 31.1297226], [74.67732239, 31.13060951], [74.67655182, 31.13104057], [74.66892242, 31.13038826], [74.66368866, 31.12676048], [74.65898895, 31.1274395], [74.65738678, 31.13260078], [74.65634918, 31.13350868], [74.65267944, 31.13508034], [74.65109253, 31.13484955], [74.64980316, 31.1337204], [74.63983917, 31.13010025], [74.63774109, 31.12849045], [74.63566589, 31.12421989], [74.6312027, 31.12128067], [74.62490845, 31.12258911], [74.62465668, 31.12733078], [74.62596893, 31.13236046], [74.62631989, 31.13569069], [74.6261673, 31.13636971], [74.62515259, 31.13726044], [74.62410736, 31.13680077], [74.62306213, 31.13656998], [74.62252045, 31.13680077], [74.62145996, 31.13703156], [74.61474609, 31.13600159], [74.61414337, 31.13568115], [74.61089325, 31.13376808], [74.6102066, 31.13339996], [74.60782623, 31.13273048], [74.60653687, 31.13294983], [74.60128021, 31.13541985], [74.59500885, 31.13495064], [74.59236908, 31.13335037], [74.59187317, 31.13196945], [74.59176636, 31.12833023], [74.59214783, 31.12725067], [74.59329224, 31.12677956], [74.59422302, 31.12659836], [74.59578705, 31.12479019], [74.59659576, 31.12433052], [74.59726715, 31.12251091], [74.59796906, 31.11541939], [74.59820557, 31.11484718], [74.59926605, 31.11224174], [74.60031891, 31.11149979], [74.6006012, 31.10880089], [74.6000824, 31.10337067], [74.59815979, 31.09980965], [74.59642792, 31.09749031], [74.59648895, 31.09094048], [74.59279633, 31.08740807], [74.59140778, 31.0891304], [74.58937836, 31.08958054], [74.58907318, 31.09064102], [74.58886719, 31.09140015], [74.58802795, 31.09320068], [74.58542633, 31.09521103], [74.58270264, 31.09475136], [74.58165741, 31.09292984], [74.58126831, 31.09180069], [74.57814026, 31.09020996], [74.57602692, 31.09000015], [74.5746994, 31.09020996], [74.57289886, 31.08949852], [74.57145691, 31.08870125], [74.57051849, 31.08838081], [74.56581879, 31.08434105], [74.55768585, 31.08702278], [74.55323029, 31.08617973], [74.55193329, 31.08562088], [74.54721069, 31.08742905], [74.54693604, 31.08834267], [74.54640198, 31.08856964], [74.54585266, 31.09850121], [74.54519653, 31.0991497], [74.54387665, 31.10345078], [74.54347229, 31.1052494], [74.54380035, 31.11100006], [74.54432678, 31.11235809], [74.544487, 31.11562157], [74.544487, 31.11696053], [74.54382324, 31.12035942], [74.54341125, 31.12170982], [74.54264069, 31.12214088], [74.54236603, 31.12282944], [74.53634644, 31.12506104], [74.53437805, 31.12457085], [74.53015137, 31.12309265], [74.52832031, 31.12194061], [74.52648163, 31.12240028], [74.525177, 31.12529945], [74.52465057, 31.12553024], [74.52424622, 31.1271801], [74.52371216, 31.12739944], [74.52319336, 31.12956047], [74.51761627, 31.1320591], [74.51584625, 31.13223076], [74.50615692, 31.13579941], [74.50538635, 31.1364994], [74.5045929, 31.13850975], [74.50556946, 31.14954948], [74.50543976, 31.15068054], [74.50491333, 31.15089989], [74.50396729, 31.15854073], [74.50382996, 31.16500092], [74.5045929, 31.16739082], [74.50377655, 31.17098045], [74.50325775, 31.17121124], [74.50128937, 31.1799202], [74.50128937, 31.18104172], [74.50126648, 31.18157959], [74.50228882, 31.18429947], [74.50242615, 31.18497086], [74.5043869, 31.1856575], [74.50752258, 31.18523026], [74.50882721, 31.18567085], [74.50948334, 31.18703079], [74.50945282, 31.18861008], [74.50776672, 31.19289017], [74.50826263, 31.19740105], [74.51088715, 31.20057106], [74.51184845, 31.20296288], [74.51341248, 31.20672226], [74.51451874, 31.2093811], [74.51428223, 31.21214294], [74.51381683, 31.21750069], [74.51299286, 31.21829033], [74.51080322, 31.22293091], [74.51127625, 31.23127174], [74.51374817, 31.23670006], [74.5196228, 31.24167061], [74.52181244, 31.24666023], [74.52220154, 31.24753952], [74.52207184, 31.24867058], [74.52193451, 31.24908066], [74.52115631, 31.25136948], [74.52065277, 31.25159264], [74.52062988, 31.25228119], [74.51876831, 31.25360107], [74.51760864, 31.25666809], [74.51586914, 31.26330948], [74.51534271, 31.2635498], [74.51455688, 31.26624107], [74.51164246, 31.26805115], [74.51111603, 31.27233124], [74.51277924, 31.27549171], [74.5163269, 31.27752113], [74.51686096, 31.27799034], [74.51840973, 31.28386116], [74.51917267, 31.28547096], [74.52179718, 31.28987885], [74.52466583, 31.29470062], [74.53023529, 31.29867554], [74.55187225, 31.29845428], [74.56752014, 31.33480644], [74.56808472, 31.33723831], [74.56964111, 31.34082031], [74.57212067, 31.34653854], [74.59457397, 31.39709473], [74.60120392, 31.40403748], [74.62431335, 31.42268944], [74.62534332, 31.42361832], [74.63199615, 31.44094467], [74.63632965, 31.45223808], [74.64079285, 31.45590973], [74.64206696, 31.45996094], [74.64206696, 31.46154976], [74.64072418, 31.4636898], [74.64022827, 31.46447945], [74.63378906, 31.46868134], [74.63231659, 31.46964073], [74.63204193, 31.47122002], [74.63072968, 31.47235107], [74.62837982, 31.47356987], [74.6207428, 31.47797966], [74.62084961, 31.4786396], [74.62032318, 31.47887039], [74.62071228, 31.47999191], [74.62380981, 31.48241043], [74.62574005, 31.48553276], [74.62645721, 31.48669052], [74.62394714, 31.4869175], [74.62203217, 31.48708916], [74.61412811, 31.48583984], [74.61309052, 31.48613167], [74.60912323, 31.48718071], [74.60439301, 31.48965263], [74.60279083, 31.49482918], [74.60175323, 31.4957428], [74.5973587, 31.49810982], [74.59707642, 31.49875069], [74.5956955, 31.49979019], [74.59510803, 31.5002327], [74.59303284, 31.49999809], [74.59012604, 31.49841118], [74.58831787, 31.49863243], [74.58616638, 31.49885941], [74.5825119, 31.4983902], [74.57964325, 31.49567032], [74.57512665, 31.49658966], [74.56620026, 31.50083923], [74.5657959, 31.50172806], [74.56593323, 31.50287056], [74.56765747, 31.50317764], [74.568573, 31.50332069], [74.57171631, 31.50534058], [74.57247925, 31.50581169], [74.5734024, 31.50919914], [74.57328033, 31.50987053], [74.57247925, 31.51032066], [74.57139587, 31.51144981], [74.57139587, 31.51448631], [74.57139587, 31.51593971], [74.57298279, 31.51956177], [74.57467651, 31.52069092], [74.57480621, 31.5211525], [74.57937622, 31.52382088], [74.58241272, 31.52478981], [74.58822632, 31.52519989], [74.59348297, 31.5255127], [74.59897614, 31.52754021], [74.60106659, 31.52960014], [74.60269165, 31.53326988], [74.60385132, 31.53411102], [74.60434723, 31.53590965], [74.60478973, 31.54018974], [74.60523224, 31.54100418], [74.6023407, 31.55893135], [74.60028076, 31.55977249], [74.60011292, 31.56285095], [74.60167694, 31.56306648], [74.60090637, 31.56783867], [74.60030365, 31.5696106], [74.59260559, 31.59231186], [74.58634949, 31.60643578], [74.57849884, 31.62340546], [74.57181549, 31.63394737], [74.56254578, 31.64857483], [74.55711365, 31.65713692], [74.54148865, 31.68072891], [74.53022766, 31.69808578], [74.51978302, 31.71768761], [74.51728058, 31.72291183], [74.51810455, 31.74057579], [74.51815796, 31.74164772], [74.51804352, 31.74520111], [74.52886963, 31.74974823], [74.53646851, 31.7511425], [74.54205322, 31.75071907], [74.54545593, 31.75049019], [74.55098724, 31.75255013], [74.55179596, 31.7532196], [74.55219269, 31.75434113], [74.5520401, 31.75749969], [74.54940796, 31.75930023], [74.54750824, 31.76335907], [74.5448761, 31.7653904], [74.54402924, 31.77643013], [74.54428101, 31.77781105], [74.54717255, 31.78432083], [74.55454254, 31.79021072], [74.55493927, 31.79157066], [74.55478668, 31.79449081], [74.5534668, 31.79540062], [74.54953003, 31.79653168], [74.5493927, 31.79833031], [74.54949188, 31.79902267], [74.55763245, 31.80782127], [74.56022644, 31.81528091], [74.55960846, 31.81869125], [74.55625153, 31.82156944], [74.55615997, 31.82177925], [74.55584717, 31.82249069], [74.55574036, 31.82766914], [74.55638123, 31.82882118], [74.56466675, 31.83243752], [74.57256317, 31.84171295], [74.58046722, 31.84354019], [74.58065033, 31.84477997], [74.58119965, 31.8452301], [74.58229065, 31.85505295], [74.58329773, 31.85686111], [74.5855484, 31.85881805], [74.58811188, 31.86028481], [74.59599304, 31.86479187], [74.59632111, 31.86750031], [74.59593201, 31.8771801], [74.59642792, 31.8792305], [74.59803009, 31.8835125], [74.59910583, 31.88511086], [74.60028076, 31.88602066], [74.60250092, 31.88648987], [74.60383606, 31.88535118], [74.60437775, 31.88400269], [74.61178589, 31.88128853], [74.61521912, 31.8808918], [74.62261963, 31.88134956], [74.6265564, 31.88293076], [74.629776, 31.88543129], [74.63091278, 31.88705063], [74.63368988, 31.88970757], [74.63552856, 31.89447021], [74.63788605, 31.89672089], [74.6389389, 31.89694977], [74.64424896, 31.89696121], [74.64715576, 31.89585114], [74.64846802, 31.89629173], [74.65081024, 31.8980999], [74.65161896, 31.90081024], [74.65133667, 31.90464973], [74.65158844, 31.90917969], [74.6519928, 31.90986061], [74.65637207, 31.91143036], [74.65899658, 31.91348076], [74.65986633, 31.91823006], [74.66187286, 31.91867256], [74.66662598, 31.91687012], [74.66794586, 31.91664124], [74.66927338, 31.91687965], [74.67019653, 31.91805077], [74.670578, 31.91868973], [74.67404175, 31.92097092], [74.67614746, 31.9216404], [74.68470764, 31.92309952], [74.6872406, 31.92290115], [74.68959808, 31.92255974], [74.69303894, 31.92098999], [74.69436646, 31.92010117], [74.69477081, 31.9194355], [74.70326233, 31.92489815], [74.70506287, 31.93057632], [74.709198, 31.95794868], [74.7177887, 31.95773506], [74.72665405, 31.94217873], [74.73591614, 31.93738937], [74.73963928, 31.93853951], [74.74578094, 31.9416008], [74.74577332, 31.94565964], [74.74517822, 31.94922066], [74.74595642, 31.95177269], [74.74772644, 31.95228004], [74.75013733, 31.95009041], [74.75174713, 31.94753838], [74.75509644, 31.94703102], [74.75948334, 31.94619942], [74.76294708, 31.94824982], [74.76461029, 31.94971085], [74.76521301, 31.95021057], [74.76596069, 31.95069122], [74.76860046, 31.95181847], [74.78365326, 31.95545959], [74.78829193, 31.95724106], [74.79364014, 31.95934105], [74.80137634, 31.96179008], [74.80269623, 31.96066856], [74.80297089, 31.95750999], [74.80631256, 31.95543289], [74.80671692, 31.9539299], [74.80914307, 31.95513916], [74.81038666, 31.95616913], [74.81217957, 31.96216965], [74.81510162, 31.97174072], [74.81987762, 31.97649193], [74.81990051, 31.9781208], [74.82012939, 31.98438072], [74.81774139, 31.99385071], [74.81835175, 31.99744987], [74.81904602, 31.9979229], [74.82012939, 31.9979229], [74.82048798, 32.00016022], [74.82141113, 32.00083923], [74.82778168, 32.00513077], [74.83840942, 32.00696945], [74.84416962, 32.00831223], [74.84496307, 32.00875854], [74.84574127, 32.00923157], [74.84615326, 32.01079941], [74.84548187, 32.01327896], [74.84069824, 32.01736069], [74.84020233, 32.01826096], [74.84033966, 32.02025986], [74.85234833, 32.02188873], [74.85501099, 32.02320862], [74.8564682, 32.02592087], [74.85949707, 32.02661133], [74.86058044, 32.02614975], [74.86107635, 32.0259285], [74.86160278, 32.02479935], [74.86427307, 32.02368927], [74.86508179, 32.02391052], [74.86750793, 32.03115082], [74.86769104, 32.0333786], [74.8673172, 32.03450012], [74.86477661, 32.03699112], [74.86212158, 32.04330063], [74.86199188, 32.04463959], [74.86225128, 32.0451088], [74.86873627, 32.04782104], [74.87242889, 32.05052948], [74.87934113, 32.05187988], [74.89730072, 32.0494194], [74.89803314, 32.04964066], [74.89894867, 32.04988098], [74.89971924, 32.05031204], [74.90312195, 32.0571022], [74.90421295, 32.05778885], [74.90529633, 32.06035995], [74.90686035, 32.06251144], [74.91337585, 32.06492996], [74.91426086, 32.06521988], [74.92592621, 32.06565094], [74.93874359, 32.06197357], [74.93914032, 32.06185913], [74.94335175, 32.05958557], [74.94629669, 32.05938721], [74.96031952, 32.05503082], [74.96463776, 32.0517807], [74.96614075, 32.05101013], [74.96620178, 32.05060577], [74.96666718, 32.04738998], [74.96614075, 32.04703903], [74.96404266, 32.04492188], [74.96364594, 32.04402924], [74.96378326, 32.04312897], [74.96826172, 32.04201889], [74.97039032, 32.04177094], [74.97072601, 32.04217148], [74.97223663, 32.04222107], [74.97331238, 32.04198074], [74.977211, 32.04232788], [74.98691559, 32.03502655], [74.98741913, 32.0346489], [74.99841309, 32.02866745], [75.0, 32.02869034], [75.00344849, 32.02873611], [75.00492859, 32.02875519], [75.01061249, 32.03039932], [75.02302551, 32.03904724], [75.0309906, 32.04058075], [75.04588318, 32.03923416], [75.05084991, 32.04130936], [75.06893158, 32.05837631], [75.06902313, 32.05846405], [75.07258606, 32.05958939], [75.07446289, 32.05978012], [75.07524872, 32.06047058], [75.07603455, 32.06072235], [75.08119202, 32.05624008], [75.0774231, 32.06116867], [75.07866669, 32.06158066], [75.07919312, 32.06203079], [75.08583069, 32.0628891], [75.08624268, 32.06208038], [75.09005737, 32.05995941], [75.09216309, 32.0594902], [75.09427643, 32.06087112], [75.09483337, 32.06132889], [75.0953598, 32.06650925], [75.09747314, 32.0703392], [75.09866333, 32.0712204], [75.10806274, 32.07485962], [75.10941315, 32.07600021], [75.11048889, 32.07664108], [75.11353302, 32.08119202], [75.11625671, 32.08280945], [75.11785126, 32.0830307], [75.12001038, 32.08317184], [75.12320709, 32.08203888], [75.12982941, 32.08068085], [75.13141632, 32.08135986], [75.13828278, 32.08293915], [75.14180756, 32.08330154], [75.14438629, 32.082901], [75.1519165, 32.08045959], [75.15270996, 32.07910919], [75.15338135, 32.07883072], [75.15419769, 32.07593918], [75.15480804, 32.07548904], [75.15705872, 32.07229996], [75.15757751, 32.07205963], [75.15836334, 32.06845856], [75.16284943, 32.06777191], [75.1644516, 32.06797028], [75.1667099, 32.07025909], [75.16816711, 32.07138062], [75.17163849, 32.07902908], [75.17479706, 32.08129883], [75.18091583, 32.08218002], [75.18147278, 32.08197021], [75.18358612, 32.08263016], [75.18437195, 32.08306885], [75.18514252, 32.08375168], [75.18550873, 32.08716202], [75.18517303, 32.09526062], [75.18769073, 32.09931183], [75.18917084, 32.10020065], [75.19156647, 32.10065079], [75.19315338, 32.10020065], [75.1937027, 32.10065079], [75.19320679, 32.11463928], [75.19333649, 32.11529922], [75.19532013, 32.11664963], [75.1989975, 32.11732864], [75.20459747, 32.11598969], [75.20503235, 32.11560822], [75.21128082, 32.11875534], [75.21204376, 32.11914063], [75.22270966, 32.11252975], [75.22496033, 32.10689926], [75.22360229, 32.09107208], [75.22776031, 32.08455658], [75.23342896, 32.08436203], [75.23916626, 32.08715057], [75.27197266, 32.11275101], [75.27481079, 32.11884689], [75.2772522, 32.13524246], [75.28326416, 32.14216995], [75.2880249, 32.14443207], [75.30940247, 32.15460968], [75.31423187, 32.15918732], [75.3177948, 32.17081833], [75.31719208, 32.19280624], [75.32284546, 32.20132065], [75.33328247, 32.20471954], [75.33307648, 32.20486069], [75.31964111, 32.20824051], [75.31358337, 32.21239853], [75.31420135, 32.2149086], [75.31494141, 32.21567917], [75.31629944, 32.21707916], [75.31774139, 32.21813202], [75.3232193, 32.21889114], [75.33004761, 32.21875], [75.33341217, 32.21910858], [75.34015656, 32.21760178], [75.34333038, 32.21850204], [75.34438324, 32.21828079], [75.34623718, 32.21804047], [75.3496933, 32.21958923], [75.35263062, 32.22275162], [75.35794067, 32.22589111], [75.35927582, 32.22703934], [75.36048126, 32.23175049], [75.36128998, 32.23221207], [75.36277771, 32.23377991], [75.36315155, 32.23468018], [75.36370087, 32.23828125], [75.36354065, 32.23918915], [75.36251068, 32.23986053], [75.36173248, 32.24032974], [75.3604126, 32.2441597], [75.35933685, 32.24485016], [75.35830688, 32.2457695], [75.35695648, 32.24895096], [75.35700226, 32.25186157], [75.35864258, 32.25860214], [75.35957336, 32.25951004], [75.36315155, 32.26177979], [75.36502075, 32.26243973], [75.36598206, 32.26401901], [75.36620331, 32.26501846], [75.36699677, 32.26874924], [75.36415863, 32.27180862], [75.36161804, 32.27393341], [75.36107635, 32.27439117], [75.36107635, 32.27484894], [75.35632324, 32.27848053], [75.35326385, 32.27816391], [75.34938812, 32.28395081], [75.33992004, 32.28856659], [75.33622742, 32.29573822], [75.33512115, 32.30076218], [75.3343277, 32.30436707], [75.33666992, 32.32259369], [75.33042145, 32.33171082], [75.32232666, 32.33732605], [75.32440186, 32.34165955], [75.32530212, 32.3428421], [75.33177948, 32.34469986], [75.3440094, 32.34020996], [75.34526825, 32.33916092], [75.35919189, 32.33491898], [75.37346649, 32.33057022], [75.37853241, 32.3288002], [75.38595581, 32.32769012], [75.39745331, 32.32625198], [75.41499329, 32.32427216], [75.43107605, 32.32648849], [75.43257904, 32.32669067], [75.44859314, 32.33132172], [75.45178986, 32.33176041], [75.45635223, 32.33351898], [75.46660614, 32.33885193], [75.47223663, 32.34004974], [75.473526, 32.33919907], [75.46775818, 32.3175621], [75.47142029, 32.31465149], [75.47992706, 32.31034851], [75.48475647, 32.31029129], [75.49022675, 32.31021118], [75.49111938, 32.30672073], [75.49212646, 32.30279922], [75.49002075, 32.28797913], [75.49472046, 32.27690887], [75.49894714, 32.27532959], [75.50123596, 32.27605057], [75.50450134, 32.27952957], [75.50559998, 32.28134155], [75.51582336, 32.29798889], [75.5242691, 32.34004974], [75.52921295, 32.34888077], [75.54515076, 32.36082077], [75.55731964, 32.36695862], [75.56700134, 32.37184143], [75.59263611, 32.38169861], [75.63697815, 32.38737869], [75.64807129, 32.3888092], [75.66274261, 32.39350891], [75.68495941, 32.40061951], [75.69822693, 32.40953064], [75.71153259, 32.41815948], [75.71534729, 32.42383194], [75.71974945, 32.43032074], [75.72515106, 32.43832016], [75.72970581, 32.44506073], [75.73532104, 32.45468903], [75.74373627, 32.46910858], [75.74505615, 32.47426224], [75.7459259, 32.47634888], [75.75296021, 32.4752388], [75.77246857, 32.47510147], [75.77886963, 32.47504044], [75.79014587, 32.47879028], [75.80433655, 32.48706055], [75.81569672, 32.4992218], [75.82357788, 32.50764084], [75.82504272, 32.50922012], [75.82892609, 32.51996994], [75.83055115, 32.52450943], [75.83783722, 32.5376091], [75.85653687, 32.55842209], [75.87177277, 32.57529068], [75.87254333, 32.57619095], [75.87545013, 32.57086182], [75.87030029, 32.55876923], [75.85636902, 32.53768921], [75.85138702, 32.5213089], [75.85096741, 32.50786972], [75.85527802, 32.49958038], [75.86876678, 32.48868179], [75.88712311, 32.47203064], [75.89541626, 32.46186066], [75.91549683, 32.44869995], [75.92443848, 32.4389801], [75.93141174, 32.43078995], [75.93463135, 32.42475891], [75.93216705, 32.41682053], [75.92592621, 32.41178131], [75.91542053, 32.41025925], [75.91110992, 32.40919113], [75.87193298, 32.39844894], [75.86631012, 32.39456177], [75.8438797, 32.37931061], [75.83740234, 32.37302017], [75.81887054, 32.35503006], [75.81391907, 32.35055923], [75.79927826, 32.33737183], [75.79371643, 32.3323822], [75.78549194, 32.3237915], [75.78314209, 32.32220078], [75.7633667, 32.30215073], [75.76185608, 32.29611206], [75.75467682, 32.28607941], [75.75183868, 32.28417206], [75.73639679, 32.27376175], [75.70487976, 32.26723862], [75.68489075, 32.26501846], [75.67584229, 32.26401901], [75.65487671, 32.25585175], [75.65244293, 32.25543976], [75.64092255, 32.2473793], [75.63407898, 32.24473953], [75.62254333, 32.23468018], [75.62177277, 32.23003006], [75.62011719, 32.22021103], [75.61833191, 32.19702148], [75.6194458, 32.18984985], [75.62021637, 32.18516922], [75.64958954, 32.17969131], [75.65615845, 32.17662048], [75.66182709, 32.16466904], [75.65547943, 32.14606094], [75.64787292, 32.13766098], [75.6312027, 32.11949921], [75.61055756, 32.09960937], [75.57875824, 32.0816803], [75.598526, 32.06600952], [75.60955811, 32.06946945], [75.62532043, 32.07266998], [75.6400528, 32.07674026], [75.64936066, 32.07717133], [75.67310333, 32.06692123], [75.68981934, 32.06153107], [75.692276, 32.05945206], [75.70040894, 32.04359055], [75.71048737, 32.03602219], [75.72322845, 32.03617096], [75.73397827, 32.03733063], [75.73800659, 32.03580093], [75.74003601, 32.03448105], [75.74836731, 32.02716064], [75.75380707, 32.0198822], [75.76154327, 32.01390076], [75.76644897, 32.00764084], [75.77429962, 32.00078964], [75.7842865, 31.99432945], [75.79512024, 31.9885807], [75.80560303, 31.98501968], [75.81404877, 31.98340034], [75.83637238, 31.9816494], [75.84162903, 31.97361946], [75.8513031, 31.97253036], [75.85679626, 31.96945953], [75.86617279, 31.96882057], [75.8685379, 31.96690941], [75.86972046, 31.96597099], [75.87771606, 31.96198082], [75.89454651, 31.94980049], [75.89595795, 31.94025993], [75.90276337, 31.92791939], [75.91268921, 31.91657829], [75.92617035, 31.88979149], [75.93144226, 31.88383102], [75.93840027, 31.8678894], [75.94425201, 31.85751915], [75.94972992, 31.84810066], [75.95358276, 31.83995056], [75.95575714, 31.83237076], [75.96762848, 31.82351112], [75.97091675, 31.81921005], [75.97146606, 31.81454849], [75.96697998, 31.81488991], [75.96031189, 31.81847954], [75.95289612, 31.82396126], [75.94877625, 31.8231411], [75.9360733, 31.81826019], [75.93325043, 31.81501961], [75.92932892, 31.81524086], [75.92675018, 31.81644058], [75.92182922, 31.81718063], [75.92722321, 31.80514908], [75.93300629, 31.7971096], [75.93582153, 31.78974915], [75.93644714, 31.78434944], [75.94506073, 31.78128052], [75.95189667, 31.76301956], [75.9595108, 31.74953842], [75.95974731, 31.74430275], [75.95755005, 31.7404995], [75.96100616, 31.73677254], [75.96602631, 31.73345947], [75.96936798, 31.71967125], [75.97257996, 31.71515274], [75.97737122, 31.70499992], [75.97579193, 31.69532967], [75.98562622, 31.68539047], [75.99066162, 31.6847496], [75.99098969, 31.68575096], [75.99214935, 31.68452072], [75.99469757, 31.68154907], [75.99742126, 31.6760006], [75.99736023, 31.66888046], [76.00473022, 31.66303062], [76.00392151, 31.65689087], [76.00624847, 31.65142822], [76.00274658, 31.64657021], [76.01760101, 31.62167168], [76.02319336, 31.61547089], [76.03140259, 31.60946083], [76.03671265, 31.60679817], [76.03997803, 31.60845947], [76.04402924, 31.60303116], [76.04268646, 31.59588051], [76.04315948, 31.59197044], [76.05150604, 31.58179092], [76.06490326, 31.56179047], [76.06601715, 31.56051826], [76.07158661, 31.55414963], [76.07681274, 31.54595947], [76.08399963, 31.53718185], [76.08895874, 31.52763939], [76.09062195, 31.51898956], [76.09455109, 31.51420975], [76.10410309, 31.5023098], [76.10816193, 31.49510956], [76.10795593, 31.48221016], [76.11472321, 31.47354126], [76.11551666, 31.46544075], [76.12127686, 31.46097946], [76.122612, 31.45372963], [76.12824249, 31.44375992], [76.13507843, 31.43750954], [76.14346313, 31.43229103], [76.14713287, 31.42560959], [76.14707184, 31.41884041], [76.15349579, 31.41401291], [76.15674591, 31.4045105], [76.15303802, 31.39725113], [76.14713287, 31.39190292], [76.1386261, 31.38685989], [76.13408661, 31.38264275], [76.13503265, 31.36175919], [76.13961029, 31.3531208], [76.14774323, 31.34814835], [76.1580658, 31.34694099], [76.1663208, 31.34145927], [76.16607666, 31.3261795], [76.16845703, 31.31412125], [76.17282867, 31.30673981], [76.18569946, 31.3046608], [76.20639801, 31.30526161], [76.21495819, 31.30764008], [76.22319031, 31.31306076], [76.24414063, 31.31371117], [76.25562286, 31.31495094], [76.26116943, 31.30583], [76.26840973, 31.30660057], [76.27735901, 31.3099308], [76.28439331, 31.31356049], [76.29039001, 31.31563187], [76.2960968, 31.31920052], [76.30226898, 31.3263607], [76.2959671, 31.34222984], [76.29991913, 31.34383011], [76.3157959, 31.34749985], [76.31783295, 31.35222054], [76.32446289, 31.34711075], [76.33007813, 31.34527969], [76.33666229, 31.35301971], [76.33129883, 31.35909271], [76.33001709, 31.36771011], [76.32958221, 31.37951851], [76.3182373, 31.3810997], [76.31877136, 31.38817978], [76.31584167, 31.40237808], [76.32952118, 31.40113831], [76.33460236, 31.40373993], [76.34689331, 31.40571022], [76.35312653, 31.41246033], [76.35914612, 31.41563034], [76.35677338, 31.4296093], [76.36313629, 31.44135094], [76.36917114, 31.42814064], [76.37526703, 31.4221611], [76.37303162, 31.41364861], [76.38162994, 31.41061974], [76.39039612, 31.39733124], [76.37924957, 31.3911705], [76.39105225, 31.37863159], [76.39924622, 31.36547089], [76.40883636, 31.35374832], [76.41284943, 31.34765816], [76.41816711, 31.33731079], [76.42801666, 31.32518005], [76.43744659, 31.31742287], [76.44827271, 31.30599022], [76.44558716, 31.30041122], [76.43580627, 31.29463959], [76.42849731, 31.28923035], [76.43113708, 31.28284073], [76.44577789, 31.28970909], [76.45101166, 31.29620934], [76.46208954, 31.30681038], [76.46671295, 31.31021118], [76.47245026, 31.30669975], [76.47505951, 31.29899979], [76.47564697, 31.29220009], [76.4797287, 31.28910255], [76.4832077, 31.28427124], [76.48858643, 31.27340126], [76.49823761, 31.27329063], [76.50340271, 31.27788925], [76.51091003, 31.28261948], [76.51426697, 31.28307915], [76.5165863, 31.27738953], [76.51428223, 31.26450157], [76.51811218, 31.26231003], [76.52789307, 31.2699604], [76.53122711, 31.28354073], [76.53717041, 31.28395081], [76.53481293, 31.27233124], [76.53264618, 31.26651192], [76.53495026, 31.25535011], [76.54592133, 31.25588036], [76.55224609, 31.26485252], [76.57050323, 31.28014946], [76.60161591, 31.25090981], [76.59268188, 31.24615097], [76.58470917, 31.23964119], [76.58252716, 31.2309494], [76.57596588, 31.22578812], [76.57935333, 31.2204895], [76.58061218, 31.21635246], [76.5867691, 31.21606064], [76.61625671, 31.22944069], [76.62594604, 31.22709084], [76.62452698, 31.22104073], [76.63414764, 31.21533966], [76.63542175, 31.21298027], [76.62011719, 31.20666122], [76.61869812, 31.20390129], [76.61221313, 31.20264053], [76.6057663, 31.19712067], [76.60066223, 31.1910305], [76.59831238, 31.18647957], [76.59039307, 31.18285942], [76.59246826, 31.1722908], [76.58943939, 31.16476059], [76.5914917, 31.16032028], [76.59007263, 31.15726852], [76.59467316, 31.15134048], [76.59874725, 31.15117073], [76.59395599, 31.1364994], [76.58931732, 31.12770081], [76.59744263, 31.12619972], [76.60727692, 31.11964035], [76.61559296, 31.12158012], [76.62371063, 31.11800957], [76.62573242, 31.11024284], [76.61184692, 31.09638977], [76.60782623, 31.08350182], [76.60489655, 31.07837868], [76.60952759, 31.06067085], [76.59896851, 31.05355072], [76.60151672, 31.04356194], [76.60518646, 31.03351974], [76.61360168, 31.02198982], [76.61006927, 31.0042305], [76.61241913, 31.0020504], [76.62094879, 30.99830055], [76.62592316, 30.9924984], [76.63334656, 30.99072266], [76.65306091, 30.98180962], [76.6626358, 30.97113037], [76.66819, 30.96988106], [76.69423676, 30.97249031], [76.69615936, 30.97179031], [76.69837952, 30.96889114], [76.70507813, 30.9633007], [76.71260071, 30.96342087], [76.72413635, 30.9505825], [76.72547913, 30.9425106], [76.72602081, 30.93933105], [76.7383728, 30.93005943], [76.74382019, 30.92904091], [76.74862671, 30.92916107], [76.74868774, 30.92379951], [76.75411987, 30.92295265], [76.75383759, 30.91781807], [76.76985931, 30.90639114], [76.76254272, 30.89340973], [76.76904297, 30.87652969], [76.77333832, 30.87115097], [76.78494263, 30.8612709], [76.80121613, 30.84252167], [76.8065567, 30.84025192], [76.81894684, 30.83710098], [76.82775116, 30.83256912], [76.83209991, 30.82542038], [76.83335876, 30.81589127], [76.83351135, 30.80457115], [76.84134674, 30.79908943], [76.8467865, 30.79252052], [76.83081818, 30.76793289], [76.82818604, 30.76379013], [76.81198883, 30.76663971], [76.80145264, 30.7627697], [76.7931366, 30.76651955], [76.79136658, 30.76950073], [76.80345154, 30.77760124], [76.80387878, 30.77902031], [76.8021698, 30.78182983], [76.79776764, 30.78527069], [76.79612732, 30.78577042], [76.78872681, 30.78097153], [76.78093719, 30.77387047], [76.7755661, 30.77605057], [76.76930237, 30.77697945], [76.77266693, 30.78308105], [76.77629089, 30.78404045], [76.77732849, 30.78545952], [76.77334595, 30.78790092], [76.76760101, 30.79511833], [76.75933838, 30.79903984], [76.75092316, 30.7968483], [76.74575043, 30.79463768], [76.74298859, 30.79148293], [76.73999023, 30.79108047], [76.73822021, 30.78985023], [76.73922729, 30.78607941], [76.7351532, 30.78300095], [76.7305069, 30.78100967], [76.73123169, 30.77701759], [76.72924042, 30.77625084], [76.7227478, 30.77071953], [76.71832275, 30.76909256], [76.70786285, 30.77010918], [76.69062805, 30.76008034], [76.69293213, 30.75739098], [76.69332123, 30.75266075], [76.69068146, 30.74666023], [76.69267273, 30.74471283], [76.69545746, 30.74409294], [76.70127106, 30.74529076], [76.70992279, 30.73548126], [76.71115875, 30.73229027], [76.71614075, 30.72863007], [76.71795654, 30.72063065], [76.71759796, 30.71746826], [76.71533966, 30.71497917], [76.71520233, 30.7133007], [76.72154999, 30.71208954], [76.72545624, 30.70998955], [76.72690582, 30.70755005], [76.72609711, 30.70491982], [76.72458649, 30.70379066], [76.7263031, 30.6959095], [76.72749329, 30.69565964], [76.73044586, 30.69749832], [76.73288727, 30.69716072], [76.73847961, 30.68915176], [76.74503326, 30.6904583], [76.77069092, 30.67794037], [76.78930664, 30.67058182], [76.79437256, 30.66931915], [76.80293274, 30.6754818], [76.80591583, 30.6802597], [76.81050873, 30.68495178], [76.81980896, 30.68582916], [76.818367, 30.67296028], [76.81881714, 30.66059113], [76.82409668, 30.66007042], [76.82694244, 30.66333008], [76.83006287, 30.66493034], [76.83499908, 30.66411018], [76.83479309, 30.65582085], [76.83985901, 30.65678024], [76.84983826, 30.66485977], [76.85540771, 30.67320251], [76.86222839, 30.6792717], [76.86310577, 30.6715107], [76.86186218, 30.65971947], [76.85897064, 30.65155983], [76.85858154, 30.64063072], [76.86194611, 30.64027023], [76.86795807, 30.64163971], [76.87267303, 30.64002037], [76.87709045, 30.63702011], [76.88063049, 30.6330719], [76.88360596, 30.62709045], [76.89453888, 30.62333107], [76.89959717, 30.62002945], [76.90154266, 30.60840988], [76.91060638, 30.60582924], [76.91342926, 30.59970284], [76.9072113, 30.59140968], [76.89855957, 30.5884304], [76.90453339, 30.58057022], [76.90390778, 30.57518005], [76.89888763, 30.56671906], [76.89888763, 30.56402969], [76.90384674, 30.56171989], [76.90592957, 30.55838966], [76.90223694, 30.55104065], [76.89218903, 30.54444122], [76.88504028, 30.54042053], [76.88775635, 30.53815079], [76.89821625, 30.53470039], [76.90724945, 30.5298996], [76.91429901, 30.52655029], [76.92006683, 30.52469063], [76.92032623, 30.51802063], [76.91828918, 30.50723076], [76.91590881, 30.49942017], [76.91236877, 30.49365997], [76.9078064, 30.49078941], [76.90114594, 30.48884964], [76.89385986, 30.48964119], [76.88891602, 30.48458862], [76.8898468, 30.47932816], [76.89663696, 30.47537994], [76.8980484, 30.46778107], [76.89518738, 30.45556831], [76.89071655, 30.45106125], [76.88884735, 30.44111061], [76.88993073, 30.43669128], [76.90167999, 30.42832947], [76.90370941, 30.42488098], [76.90370178, 30.41823006], [76.90524292, 30.41319084], [76.90392303, 30.40995026], [76.90384674, 30.40670967], [76.90518188, 30.40468979], [76.90925598, 30.40327072], [76.91947174, 30.4030304], [76.92579651, 30.40159035], [76.92904663, 30.3998909], [76.93139648, 30.39707184], [76.93026733, 30.39258957], [76.9272995, 30.38863945], [76.92077637, 30.38478279], [76.91699219, 30.38275909], [76.90348816, 30.36750984], [76.89776611, 30.36260033], [76.89227295, 30.35967827], [76.88722229, 30.35838127], [76.88022614, 30.35970116], [76.87644196, 30.36333847], [76.87571716, 30.36954117], [76.88043213, 30.38298988], [76.88022614, 30.38622284], [76.87441254, 30.39128113], [76.86624146, 30.3948307], [76.86756134, 30.40151978], [76.86473083, 30.40879059], [76.84726715, 30.41489983], [76.83972931, 30.42074966], [76.8324585, 30.43388176], [76.82789612, 30.43033028], [76.82314301, 30.42254829], [76.80845642, 30.41185951], [76.79728699, 30.41512108], [76.78069305, 30.4150219], [76.77082062, 30.41830063], [76.764328, 30.42501068], [76.76674652, 30.43600082], [76.76332855, 30.43972969], [76.75786591, 30.43889046], [76.7543869, 30.43280983], [76.74887085, 30.42663193], [76.73786163, 30.42486954], [76.72516632, 30.42041969], [76.72654724, 30.40500069], [76.71289063, 30.39824295], [76.70014954, 30.39361191], [76.70168304, 30.38482857], [76.70487976, 30.38083267], [76.71572113, 30.38026047], [76.71808624, 30.37710953], [76.7089386, 30.36816978], [76.71135712, 30.36512947], [76.73039246, 30.36744118], [76.73501587, 30.36491013], [76.73853302, 30.35964966], [76.73462677, 30.35393906], [76.72901154, 30.34843254], [76.72392273, 30.34436989], [76.71515656, 30.33990097], [76.71515656, 30.33291054], [76.71096039, 30.32987022], [76.70475006, 30.33168983], [76.70025635, 30.32985115], [76.69767761, 30.32485771], [76.68846893, 30.32598114], [76.67949677, 30.32137108], [76.67462921, 30.32595062], [76.67088318, 30.31917], [76.67307281, 30.31277084], [76.66242981, 30.29955101], [76.65128326, 30.2993412], [76.626297, 30.28392982], [76.62283325, 30.29138947], [76.61969757, 30.28784943], [76.61437988, 30.27527046], [76.6098175, 30.27061081], [76.60449982, 30.27226067], [76.58094025, 30.26987076], [76.55792999, 30.26426125], [76.54763794, 30.26492119], [76.54582214, 30.25863075], [76.54692841, 30.24953079], [76.5459671, 30.24353981], [76.54219818, 30.23637962], [76.53292084, 30.23207855], [76.53253174, 30.22713089], [76.54438019, 30.23085976], [76.54766846, 30.23444176], [76.56904602, 30.2513504], [76.57588959, 30.25586128], [76.58399963, 30.25653076], [76.59031677, 30.25412178], [76.59590912, 30.24394035], [76.59942627, 30.24032974], [76.60930634, 30.23488045], [76.61199951, 30.23096848], [76.61186981, 30.22562981], [76.60627747, 30.22001076], [76.60427856, 30.21517181], [76.60941315, 30.21277046], [76.61675262, 30.21105957], [76.63282013, 30.21001053], [76.63891602, 30.20594025], [76.63716888, 30.19695091], [76.64198303, 30.19366837], [76.641716, 30.18925095], [76.63925171, 30.18521118], [76.6227417, 30.17029953], [76.62763977, 30.1551075], [76.62326813, 30.14940262], [76.62309265, 30.14466095], [76.62940216, 30.13476944], [76.62872314, 30.13019943], [76.62520599, 30.12103081], [76.62474823, 30.11688995], [76.62663269, 30.11396027], [76.62755585, 30.11048126], [76.62667084, 30.10564995], [76.62515259, 30.10184097], [76.61947632, 30.09536171], [76.61769867, 30.09406281], [76.6158905, 30.09278107], [76.61411285, 30.09150124], [76.61235046, 30.09020996], [76.61061096, 30.08886909], [76.60896301, 30.08745956], [76.60742188, 30.08589935], [76.60595703, 30.08428955], [76.6044693, 30.08272171], [76.60286713, 30.08131981], [76.60105133, 30.08023071], [76.59877777, 30.07970047], [76.59642029, 30.07947159], [76.59406281, 30.0795517], [76.59168243, 30.07974052], [76.58953094, 30.07929993], [76.58763885, 30.07814026], [76.58583069, 30.07674026], [76.58399963, 30.07543945], [76.58194733, 30.07467079], [76.57917023, 30.07459068], [76.57676697, 30.07509995], [76.57637787, 30.07611084], [76.57787323, 30.07771111], [76.57977295, 30.07953072], [76.58104706, 30.08127975], [76.58194733, 30.08312988], [76.5819397, 30.08521271], [76.58080292, 30.08685112], [76.57879639, 30.08784294], [76.57663727, 30.08876038], [76.57478333, 30.08995819], [76.57301331, 30.09123993], [76.57124329, 30.09255981], [76.5694809, 30.0938797], [76.56767273, 30.09511948], [76.56575012, 30.09626007], [76.56363678, 30.09711075], [76.56143951, 30.09763908], [76.55916595, 30.09804916], [76.55487061, 30.0987606], [76.533638, 30.08278084], [76.52554321, 30.0808506], [76.50894165, 30.07953072], [76.50112152, 30.07662964], [76.49713898, 30.08156967], [76.49501038, 30.08708191], [76.49517059, 30.09238815], [76.49082947, 30.0971508], [76.48348999, 30.09955978], [76.46157074, 30.09900093], [76.4520874, 30.10070992], [76.44909668, 30.10480118], [76.44664001, 30.11123085], [76.4444809, 30.12288094], [76.44618988, 30.12895966], [76.44645691, 30.1371212], [76.44104004, 30.13595963], [76.43631744, 30.13702965], [76.43135071, 30.14071083], [76.42604065, 30.14756012], [76.42488861, 30.15462112], [76.42227173, 30.15870094], [76.42243195, 30.16357994], [76.42642975, 30.16757965], [76.42900848, 30.1729908], [76.42858124, 30.1797924], [76.4200058, 30.19787979], [76.41020203, 30.20228958], [76.39884186, 30.1989994], [76.39100647, 30.19225121], [76.38674164, 30.18699074], [76.3809967, 30.18324089], [76.38304138, 30.17902946], [76.38861847, 30.17410088], [76.40164185, 30.1577282], [76.39951324, 30.15517044], [76.39251709, 30.15026093], [76.3861618, 30.14824104], [76.38456726, 30.14581108], [76.38832855, 30.13832855], [76.38845062, 30.13396835], [76.39000702, 30.12754059], [76.3843689, 30.1238327], [76.37471771, 30.12372971], [76.36374664, 30.12754059], [76.35816193, 30.13330269], [76.3483429, 30.15052032], [76.34306335, 30.1534481], [76.32588196, 30.14924049], [76.3286972, 30.14476967], [76.33570862, 30.13926125], [76.34829712, 30.13166046], [76.34892273, 30.12766075], [76.33790588, 30.11585045], [76.32837677, 30.10951042], [76.32289886, 30.10822105], [76.31275177, 30.10851288], [76.29308319, 30.11862946], [76.28636169, 30.11682129], [76.27984619, 30.11365128], [76.27202606, 30.11433983], [76.26551056, 30.11769295], [76.25115967, 30.11899948], [76.24458313, 30.1218605], [76.24299622, 30.12746811], [76.24095917, 30.12865829], [76.23816681, 30.13091087], [76.23680115, 30.13255119], [76.23539734, 30.13414955], [76.23375702, 30.13556862], [76.23191833, 30.13677979], [76.22997284, 30.1378994], [76.2280426, 30.1390419], [76.22628784, 30.14031029], [76.2247467, 30.14180946], [76.22336578, 30.14343834], [76.22202301, 30.14509964], [76.2205658, 30.14668083], [76.21897888, 30.14817047], [76.2173233, 30.1497612], [76.21565247, 30.15139008], [76.21395111, 30.1530304], [76.21224976, 30.15460968], [76.21053314, 30.15607834], [76.20884705, 30.15739059], [76.20720673, 30.15851021], [76.20558929, 30.15934944], [76.20387268, 30.15890121], [76.20236206, 30.15671158], [76.20195007, 30.15457153], [76.20259857, 30.15281105], [76.20375824, 30.15103912], [76.20511627, 30.14924049], [76.20632172, 30.14740944], [76.20706177, 30.14550018], [76.20744324, 30.14348984], [76.20851898, 30.14172173], [76.2100296, 30.1400795], [76.21156311, 30.1384716], [76.21266174, 30.13683128], [76.21192932, 30.13506126], [76.21008301, 30.13360977], [76.20794678, 30.13314819], [76.20580292, 30.13376045], [76.20365143, 30.13473129], [76.20162964, 30.13582993], [76.19969177, 30.13721085], [76.19777679, 30.13870049], [76.19590759, 30.13999176], [76.19410706, 30.1407795], [76.19230652, 30.14045906], [76.19055176, 30.13862991], [76.18962097, 30.13669014], [76.19061279, 30.13496017], [76.19249725, 30.13351059], [76.1943512, 30.13235092], [76.19632721, 30.13126945], [76.19837189, 30.13025093], [76.20038605, 30.12930107], [76.20262909, 30.12865829], [76.20471191, 30.12786102], [76.20639801, 30.12648964], [76.20791626, 30.12495995], [76.20928955, 30.12330055], [76.21058655, 30.12161064], [76.21193695, 30.11996269], [76.21343994, 30.11845016], [76.21518707, 30.11717987], [76.2171402, 30.11610985], [76.21920013, 30.11512184], [76.22123718, 30.11412048], [76.22316742, 30.11301994], [76.2248764, 30.11165047], [76.22667694, 30.11040115], [76.2286911, 30.10933113], [76.23082733, 30.10852051], [76.233078, 30.10822105], [76.23539734, 30.108181], [76.23771667, 30.10823059], [76.24006653, 30.10827827], [76.24238586, 30.10819054], [76.24469757, 30.10792923], [76.2470932, 30.10762024], [76.2494812, 30.1072197], [76.2517395, 30.1067028], [76.25377655, 30.10602951], [76.25499725, 30.10457993], [76.2545929, 30.10239983], [76.25358582, 30.10053062], [76.25237274, 30.0986824], [76.25093079, 30.09706116], [76.2492218, 30.09603119], [76.24672699, 30.09638977], [76.24455261, 30.09614944], [76.242836, 30.09490967], [76.24120331, 30.09353065], [76.23963165, 30.09203911], [76.23808289, 30.09046173], [76.23660278, 30.08884811], [76.2351532, 30.08719826], [76.23381042, 30.08558083], [76.23246002, 30.08394051], [76.23116302, 30.08226013], [76.22991943, 30.08056831], [76.22869873, 30.07886124], [76.22749329, 30.07713127], [76.22632599, 30.0753994], [76.22509766, 30.07366943], [76.22395325, 30.07194138], [76.22273254, 30.0702076], [76.2215271, 30.06848907], [76.22035217, 30.06674957], [76.21916199, 30.06502914], [76.21798706, 30.06329918], [76.21681976, 30.06155014], [76.21566772, 30.05981064], [76.2144928, 30.05808067], [76.21330261, 30.05633163], [76.2121582, 30.05458832], [76.21102905, 30.05282021], [76.20987701, 30.05106926], [76.20864105, 30.04939079], [76.20723724, 30.04779053], [76.2056427, 30.04628944], [76.20404053, 30.04483986], [76.20252991, 30.04331017], [76.20111084, 30.04164124], [76.19962311, 30.03977966], [76.19838715, 30.03792953], [76.19793701, 30.03625107], [76.19890594, 30.03482819], [76.20111847, 30.03367233], [76.20345306, 30.03273964], [76.20580292, 30.03203011], [76.20838928, 30.03144836], [76.21098328, 30.03092957], [76.21333313, 30.03035164], [76.21514893, 30.0296402], [76.21613312, 30.0286808], [76.21543884, 30.02713013], [76.21354675, 30.02530861], [76.21140289, 30.02373123], [76.20947266, 30.02272987], [76.20720673, 30.02211952], [76.20490265, 30.02166939], [76.20263672, 30.02120018], [76.2003479, 30.02085114], [76.19803619, 30.02052116], [76.19581604, 30.02006149], [76.19346619, 30.01938057], [76.19156647, 30.01823044], [76.19091797, 30.01641273], [76.19050598, 30.01449013], [76.19020844, 30.01249123], [76.18998718, 30.01044846], [76.18981171, 30.00838089], [76.1896286, 30.00632286], [76.18937683, 30.00419044], [76.19303131, 29.99662018], [76.19577789, 29.9904995], [76.19713593, 29.98511124], [76.19748688, 29.97981071], [76.19901276, 29.97317123], [76.19473267, 29.96567917], [76.20345306, 29.95206833], [76.2050705, 29.94750023], [76.20387268, 29.94412041], [76.19087219, 29.94445992], [76.18480682, 29.94627953], [76.1789093, 29.94626808], [76.1696167, 29.93655968], [76.16629028, 29.92865944], [76.1714859, 29.92323112], [76.18199158, 29.92324066], [76.18358612, 29.91571808], [76.18270874, 29.89388084], [76.18463898, 29.88858032], [76.19740295, 29.88401985], [76.20812988, 29.88651085], [76.21694946, 29.88385963], [76.22529602, 29.88506126], [76.23245239, 29.88132095], [76.23869324, 29.87590027], [76.24201202, 29.86902809], [76.23795319, 29.86545944], [76.23522949, 29.85980988], [76.2318573, 29.85637093], [76.22852325, 29.85452843], [76.22290039, 29.85559082], [76.21582794, 29.85470963], [76.21176147, 29.85314941], [76.20965576, 29.8501606], [76.21111298, 29.8432312], [76.20964813, 29.84274292], [76.2022171, 29.84530067], [76.19418335, 29.8449707], [76.18936157, 29.84047127], [76.18582153, 29.83123016], [76.16665649, 29.81832123], [76.15312958, 29.81627274], [76.13926697, 29.81676292], [76.13210297, 29.81205177], [76.12718201, 29.80542946], [76.12140656, 29.7994709], [76.11638641, 29.79640007], [76.11026764, 29.80331993], [76.10321045, 29.80841064], [76.09438324, 29.81156158], [76.09056091, 29.81083107], [76.08605957, 29.80989838], [76.07766724, 29.80577278], [76.07557678, 29.79704857], [76.07543945, 29.78790092], [76.07434082, 29.78124046], [76.06990051, 29.77602005], [76.0632019, 29.7774601], [76.0584259, 29.77314949], [76.04148102, 29.7487812], [76.03565216, 29.74668121], [76.03292084, 29.74959946], [76.03170776, 29.7508812], [76.02424622, 29.75560188], [76.01759338, 29.75607109], [76.01127625, 29.75282097], [76.00382996, 29.75093079], [75.98927307, 29.74230957], [75.98000336, 29.73616982], [75.97254944, 29.73237038], [75.97045898, 29.73210907], [75.96485901, 29.73138046], [75.95748901, 29.73212051], [75.9500885, 29.73391151], [75.94235229, 29.73427963], [75.9386673, 29.73351288], [75.93662262, 29.73308182], [75.93401337, 29.7325325], [75.9289093, 29.73365021], [75.92314911, 29.73491096], [75.91394806, 29.73876953], [75.90313721, 29.74628258], [75.89723206, 29.7555294], [75.89068604, 29.75321007], [75.87928009, 29.74707031], [75.87201691, 29.75012016], [75.86377716, 29.75233078], [75.85459137, 29.76966095], [75.84362793, 29.77596092], [75.84124756, 29.78083992], [75.83338928, 29.79066086], [75.82927704, 29.80070114], [75.82901764, 29.81232071], [75.81997681, 29.8153801], [75.79605103, 29.80712128], [75.78320313, 29.81532097], [75.77243805, 29.82467079], [75.7716217, 29.82538986], [75.76698303, 29.82345009], [75.76342773, 29.82196045], [75.76059723, 29.81866074], [75.74839783, 29.81212044], [75.73272705, 29.81126022], [75.7259903, 29.81151962], [75.70987701, 29.81225967], [75.70593262, 29.80862045], [75.69744873, 29.75521088], [75.68743134, 29.75177956], [75.67830658, 29.75706291], [75.66616821, 29.77270126], [75.65638733, 29.7760601], [75.6496582, 29.77456093], [75.64087677, 29.77111053], [75.62535858, 29.7732296], [75.6235199, 29.76688957], [75.62261963, 29.75362015], [75.61322784, 29.74645805], [75.60048676, 29.74740028], [75.59274292, 29.74915123], [75.56878662, 29.74262047], [75.56308746, 29.74423981], [75.55639648, 29.7658329], [75.54418182, 29.77176094], [75.53019714, 29.7727108], [75.52397919, 29.76724052], [75.51171112, 29.76004982], [75.5063324, 29.77407074], [75.4983902, 29.77775002], [75.44426727, 29.80784988], [75.43547058, 29.79884911], [75.44315338, 29.79417038], [75.44378662, 29.7861805], [75.43463898, 29.78028107], [75.42720795, 29.77794075], [75.41976929, 29.77437973], [75.40999603, 29.77532005], [75.39723206, 29.76102066], [75.39679718, 29.74867058], [75.39087677, 29.73859978], [75.3837204, 29.7340107], [75.38218689, 29.72705841], [75.3835907, 29.72030258], [75.37877655, 29.7112999], [75.37003326, 29.71306038], [75.36194611, 29.71289063], [75.35855865, 29.70576096], [75.35269165, 29.70449066], [75.34121704, 29.69524002], [75.33535004, 29.69384956], [75.33384705, 29.68805122], [75.34603882, 29.67142105], [75.34932709, 29.66563988], [75.35044861, 29.65928078], [75.34850311, 29.65907097], [75.34680939, 29.65888977], [75.3414917, 29.66213036], [75.33014679, 29.67227936], [75.32260895, 29.67240906], [75.31772614, 29.67070007], [75.31623077, 29.66082191], [75.31169891, 29.64875984], [75.30753326, 29.63256073], [75.30105591, 29.62709045], [75.28785706, 29.61976814], [75.28056335, 29.61010933], [75.28034973, 29.6032505], [75.29361725, 29.59767151], [75.30203247, 29.59198952], [75.30451202, 29.58847809], [75.30486298, 29.58361053], [75.30304718, 29.57905006], [75.29606628, 29.5680809], [75.29064941, 29.56176186], [75.27503204, 29.56110954], [75.26748657, 29.55928993], [75.25453949, 29.55418015], [75.23806763, 29.55154037], [75.22348022, 29.54617119], [75.22432709, 29.55002975], [75.2281723, 29.55855751], [75.2217865, 29.57028008], [75.21788788, 29.57846069], [75.21118927, 29.58239937], [75.21936798, 29.59250259], [75.2232132, 29.5988903], [75.22123718, 29.60655022], [75.19937134, 29.6226902], [75.18473053, 29.62254143], [75.17333984, 29.63008118], [75.1724472, 29.63862991], [75.1733017, 29.64948082], [75.16854858, 29.65423012], [75.16275787, 29.65802956], [75.15783691, 29.66271019], [75.15892029, 29.66936111], [75.16783905, 29.67327118], [75.17531586, 29.67805099], [75.17986298, 29.67830276], [75.18888855, 29.68082809], [75.19528198, 29.6877594], [75.19766998, 29.69647026], [75.19243622, 29.69952965], [75.1884079, 29.70374107], [75.18724823, 29.71191978], [75.19368744, 29.72520065], [75.19809723, 29.73080063], [75.2061615, 29.73525047], [75.21067047, 29.73089027], [75.21660614, 29.72999001], [75.22136688, 29.73307037], [75.23097992, 29.75206757], [75.22733307, 29.75612068], [75.22328186, 29.76353836], [75.21673584, 29.77149963], [75.21617889, 29.7798996], [75.21238708, 29.78652], [75.20536041, 29.79000092], [75.1979599, 29.79622078], [75.19645691, 29.80511093], [75.19777679, 29.81344032], [75.20250702, 29.8213501], [75.20091248, 29.82999992], [75.18860626, 29.83457947], [75.18234253, 29.83870125], [75.17855835, 29.83690834], [75.17603302, 29.83506966], [75.1751709, 29.82951927], [75.16699982, 29.82495117], [75.15995789, 29.82364082], [75.15542603, 29.81981087], [75.15130615, 29.80183983], [75.14894867, 29.79611969], [75.14951324, 29.79164124], [75.15486145, 29.78910065], [75.15918732, 29.78421974], [75.15405273, 29.78101921], [75.141716, 29.77700806], [75.1354599, 29.78038025], [75.13141632, 29.78486061], [75.12491608, 29.80562019], [75.10228729, 29.80255127], [75.09552765, 29.8043499], [75.09017944, 29.80666161], [75.08905029, 29.81282997], [75.09333801, 29.81931114], [75.1071167, 29.82653046], [75.10408783, 29.83801079], [75.09895325, 29.84142113], [75.08574677, 29.84481049], [75.08125305, 29.84937286], [75.08098602, 29.85414124], [75.08468628, 29.85859108], [75.10058594, 29.8678894], [75.1042099, 29.87319183], [75.10309601, 29.87677956], [75.10267639, 29.89702034], [75.09475708, 29.90507126], [75.08978271, 29.91171074], [75.08480072, 29.91514015], [75.0777359, 29.91230965], [75.07000732, 29.8933506], [75.06548309, 29.87903976], [75.06040192, 29.87611961], [75.05175781, 29.87486076], [75.03749847, 29.88178062], [75.02348328, 29.87286949], [75.01412964, 29.86462975], [75.00566101, 29.86757088], [74.99411011, 29.86320114], [74.9899292, 29.85646057], [74.96946716, 29.88067055], [74.96988678, 29.88992119], [74.95786285, 29.89773941], [74.94317627, 29.9025383], [74.93566895, 29.9154129], [74.93192291, 29.92277908], [74.9285965, 29.92916107], [74.92408752, 29.94153023], [74.91573334, 29.94915962], [74.89437866, 29.93944168], [74.88523865, 29.9391098], [74.88960266, 29.94501114], [74.89309692, 29.9472599], [74.89435577, 29.95293999], [74.88976288, 29.95903015], [74.88543701, 29.9623394], [74.88149261, 29.96834946], [74.87741089, 29.96256828], [74.87195587, 29.95912933], [74.86566162, 29.95889091], [74.85935974, 29.9611702], [74.84963226, 29.95912933], [74.83660889, 29.96416092], [74.82898712, 29.96947098], [74.82138824, 29.97305107], [74.81968689, 29.97945976], [74.81668091, 29.98451996], [74.80902863, 29.99047089], [74.80117798, 29.99257278], [74.79440308, 29.98961067], [74.78421783, 29.98042107], [74.77599335, 29.97439957], [74.76737213, 29.9727211], [74.75868225, 29.97363091], [74.75071716, 29.97122955], [74.73723602, 29.96904945], [74.72400665, 29.96186066], [74.70613861, 29.96887016], [74.69737244, 29.97114944], [74.69550323, 29.97153091], [74.69078827, 29.96927071], [74.68319702, 29.96107292], [74.68096161, 29.94919014], [74.66570282, 29.94169044], [74.64892578, 29.93092918], [74.63986206, 29.92249107], [74.63886261, 29.91444969], [74.64697266, 29.90467072], [74.63963318, 29.90394974], [74.63263702, 29.90566254], [74.62638855, 29.90600967], [74.62201691, 29.90777969], [74.58580017, 29.91476059], [74.58084869, 29.91830254], [74.57295227, 29.92588806], [74.56183624, 29.92930984], [74.55200195, 29.92922974], [74.54901886, 29.93316269], [74.53024292, 29.94497108], [74.52464294, 29.95156097], [74.51906586, 29.94334984], [74.46660614, 29.94467926], [74.44403839, 29.94672012], [74.44197845, 29.94708824], [74.42807007, 29.94954109], [74.40379333, 29.94734001], [74.37245178, 29.95001984], [74.35585022, 29.95033073], [74.32151031, 29.95396042], [74.2899704, 29.95626068], [74.27902985, 29.95508957]]]}}, {\\\"id\\\": \\\"26\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.29_1\\\", \\\"HASC_1\\\": \\\"IN.RJ\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Rajasthan\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Greater Rajasthan|Rajputana\\\", \\\"apm25_popweighted\\\": 95.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1394.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1724.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3118.0, \\\"geo-id\\\": 26, \\\"hpm25_child_popweighted\\\": 213.3, \\\"hpm25_female_popweighted\\\": 245.2, \\\"hpm25_male_popweighted\\\": 176.5, \\\"location\\\": \\\"Rajasthan\\\", \\\"mort_apm25_6cod_mean_total\\\": 33116.0, \\\"mort_hpm25_6cod_mean_total\\\": 40456.0, \\\"mort_tpm25_6cod_mean_total\\\": 73572.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[75.68447876, 23.76056862], [75.67906952, 23.76954842], [75.67605591, 23.78212929], [75.67440796, 23.7844677], [75.6712265, 23.78680038], [75.66747284, 23.78819847], [75.6626358, 23.78816032], [75.65908813, 23.78894043], [75.65680695, 23.7917881], [75.65183258, 23.80194855], [75.64930725, 23.79935074], [75.64367676, 23.80183029], [75.64108276, 23.80225945], [75.63703918, 23.80236053], [75.62594604, 23.80026054], [75.6239624, 23.80051994], [75.61662292, 23.80597115], [75.61213684, 23.80661964], [75.60797882, 23.80550003], [75.60608673, 23.80364037], [75.59168243, 23.80239105], [75.58252716, 23.80035973], [75.58294678, 23.80380058], [75.5848999, 23.80881119], [75.5844574, 23.81402016], [75.58331299, 23.81520844], [75.57279205, 23.81685066], [75.56603241, 23.81568909], [75.56253052, 23.81693077], [75.5585022, 23.82015991], [75.55606079, 23.82593155], [75.556633, 23.83160973], [75.56008148, 23.83685112], [75.56150818, 23.83698082], [75.56931305, 23.8346405], [75.57229614, 23.83483124], [75.57485962, 23.83801079], [75.5761795, 23.84151077], [75.57640076, 23.84329033], [75.57306671, 23.84647942], [75.56720734, 23.84762955], [75.56536865, 23.84986115], [75.56246185, 23.85814285], [75.56062317, 23.85995102], [75.55715942, 23.86279106], [75.55252838, 23.86515808], [75.53787994, 23.87672997], [75.52876282, 23.88026047], [75.51674652, 23.88875008], [75.50734711, 23.89062119], [75.50409698, 23.89191055], [75.49993134, 23.89690971], [75.49957275, 23.90052032], [75.48742676, 23.9108429], [75.47683716, 23.91473961], [75.46089935, 23.91728973], [75.45649719, 23.92074013], [75.45593262, 23.92543983], [75.45636749, 23.93214989], [75.45722961, 23.93818092], [75.46058655, 23.94762039], [75.46170044, 23.95342064], [75.46237946, 23.9681015], [75.46476746, 23.98072815], [75.46720886, 23.9845295], [75.47055817, 23.98719978], [75.48058319, 23.99233055], [75.48597717, 23.99833107], [75.48919678, 24.00031281], [75.49176788, 24.00455093], [75.51438141, 24.04873276], [75.53192139, 24.03148079], [75.54264832, 24.02556038], [75.55264282, 24.0227108], [75.56111908, 24.02357864], [75.56693268, 24.0227108], [75.57171631, 24.01740074], [75.56881714, 24.00461006], [75.568367, 24.00114059], [75.56932068, 23.99937057], [75.57376862, 23.99847984], [75.57596588, 24.00062943], [75.57779694, 23.99962044], [75.58036804, 23.99430275], [75.58383942, 23.99192047], [75.58693695, 23.99563026], [75.59004974, 23.9963398], [75.59262848, 23.9948597], [75.59742737, 23.99864006], [75.60412598, 23.99628067], [75.60678864, 23.99625015], [75.61174774, 23.99876022], [75.62471771, 23.99882126], [75.63051605, 23.99966812], [75.6312027, 24.00031281], [75.63474274, 23.99983025], [75.63846588, 24.00283051], [75.63922119, 24.00463104], [75.64147186, 24.01836967], [75.64591217, 24.01746941], [75.64814758, 24.02073097], [75.64766693, 24.02320099], [75.65313721, 24.02757835], [75.65936279, 24.03149986], [75.66919708, 24.03354263], [75.67269135, 24.03089905], [75.67703247, 24.02011108], [75.68228912, 24.01695251], [75.68580627, 24.01794052], [75.68431091, 24.00463104], [75.68533325, 24.00234985], [75.68354034, 23.99821091], [75.68406677, 23.99311066], [75.68638611, 23.99054909], [75.69065094, 23.98948097], [75.6931076, 23.98921013], [75.69613647, 23.99039078], [75.6964798, 23.98751068], [75.69544983, 23.98590088], [75.69789886, 23.97208023], [75.69845581, 23.97007942], [75.70040894, 23.9690609], [75.71382141, 23.97208023], [75.72331238, 23.97313118], [75.72515869, 23.97451973], [75.72647858, 23.97877121], [75.72776794, 23.9795208], [75.73309326, 23.97892952], [75.73551178, 23.9805603], [75.73626709, 23.9823494], [75.73602295, 23.98475075], [75.73815155, 23.98816109], [75.73738098, 23.99406052], [75.73784637, 23.99533272], [75.74756622, 23.99347115], [75.74957275, 23.99509048], [75.75533295, 23.99492264], [75.76203918, 23.99795151], [75.76431274, 24.00242805], [75.76405334, 24.00458145], [75.76415253, 24.00530052], [75.76008606, 24.00843048], [75.76088715, 24.01291084], [75.76319885, 24.01396751], [75.76782227, 24.0116806], [75.77127075, 24.01221085], [75.77377319, 24.01910973], [75.77778625, 24.02751923], [75.78024292, 24.0362606], [75.77771759, 24.05714035], [75.77961731, 24.06208038], [75.78901672, 24.06329918], [75.80726624, 24.06760025], [75.81334686, 24.07162094], [75.82073975, 24.07060051], [75.82950592, 24.07195282], [75.83376312, 24.07542992], [75.83139038, 24.07712173], [75.83055115, 24.08159065], [75.83267212, 24.09574127], [75.83586121, 24.10400009], [75.83579254, 24.11135101], [75.8306427, 24.10792923], [75.81218719, 24.10287094], [75.80834961, 24.11335945], [75.80239868, 24.11833], [75.78961182, 24.10980034], [75.78478241, 24.11834908], [75.78317261, 24.12268066], [75.77902985, 24.12462044], [75.77868652, 24.13467026], [75.77629852, 24.13896179], [75.77316284, 24.13944244], [75.7651062, 24.13663101], [75.76213837, 24.14101028], [75.75942993, 24.14035034], [75.74349213, 24.13960075], [75.75065613, 24.1616497], [75.75331879, 24.16434097], [75.75827789, 24.17455292], [75.75891113, 24.17961121], [75.76365662, 24.18978119], [75.76862335, 24.19330025], [75.76967621, 24.19774055], [75.76782227, 24.20754814], [75.77350616, 24.22089195], [75.77883911, 24.2244091], [75.79189301, 24.22324181], [75.79534912, 24.22686958], [75.79953003, 24.22923088], [75.805336, 24.22971916], [75.80776215, 24.24067116], [75.81060791, 24.2419796], [75.81424713, 24.23959923], [75.81659698, 24.24194908], [75.82129669, 24.24102974], [75.82636261, 24.24257088], [75.82688141, 24.24641037], [75.82250977, 24.24733925], [75.81806183, 24.24995995], [75.81269073, 24.25688171], [75.81253052, 24.26065063], [75.81852722, 24.26822281], [75.81178284, 24.27042961], [75.81289673, 24.27709007], [75.81143188, 24.28472137], [75.81682587, 24.2907505], [75.81095123, 24.29804039], [75.81299591, 24.30067825], [75.811203, 24.30344963], [75.8030014, 24.31233025], [75.79741669, 24.31434822], [75.79001617, 24.3110981], [75.78103638, 24.30863953], [75.77085114, 24.30877113], [75.76509094, 24.31065941], [75.7562561, 24.32722282], [75.73792267, 24.34797096], [75.74051666, 24.34974289], [75.74180603, 24.35296822], [75.74178314, 24.36107254], [75.73869324, 24.36125755], [75.73829651, 24.36618996], [75.73957825, 24.38893127], [75.73857117, 24.39529991], [75.7353363, 24.39439964], [75.72968292, 24.38949966], [75.72688293, 24.40527916], [75.728302, 24.40749168], [75.72979736, 24.40360832], [75.73581696, 24.40343285], [75.7432785, 24.40501022], [75.74500275, 24.4070797], [75.75527954, 24.40930939], [75.75583649, 24.42105293], [75.75640869, 24.42766953], [75.74872589, 24.42840958], [75.75241852, 24.43157005], [75.76824188, 24.44034958], [75.77567291, 24.44826126], [75.77617645, 24.45388031], [75.78128052, 24.45391083], [75.78357697, 24.45182991], [75.78575134, 24.45508957], [75.78608704, 24.4584198], [75.78409576, 24.46473122], [75.78675842, 24.47183037], [75.79113007, 24.47520256], [75.79564667, 24.47312164], [75.80502319, 24.47277069], [75.81510925, 24.46511269], [75.81646729, 24.45852089], [75.81417084, 24.4480896], [75.80964661, 24.44123077], [75.81254578, 24.43678093], [75.8241272, 24.43078995], [75.82900238, 24.42251968], [75.84725189, 24.41897011], [75.86120605, 24.42333031], [75.87522888, 24.43028069], [75.88648987, 24.4369297], [75.89862061, 24.44159126], [75.90338898, 24.44613075], [75.90335083, 24.45393944], [75.90899658, 24.45614052], [75.90943909, 24.46363068], [75.9072876, 24.46951103], [75.90811157, 24.47813034], [75.9124527, 24.48558044], [75.91181946, 24.4924202], [75.90674591, 24.49804115], [75.9054718, 24.50530815], [75.89105225, 24.50958824], [75.89256287, 24.52153015], [75.89694977, 24.52226067], [75.90216064, 24.52202034], [75.90289307, 24.51972008], [75.90934753, 24.51488113], [75.92204285, 24.52728081], [75.9250412, 24.53339958], [75.92501831, 24.53829956], [75.92051697, 24.54380989], [75.91671753, 24.54668808], [75.90703583, 24.55046082], [75.90661621, 24.55220032], [75.90570831, 24.56059265], [75.90782166, 24.56536293], [75.90956116, 24.56450844], [75.91320801, 24.56529045], [75.91584778, 24.56736946], [75.91739655, 24.5714798], [75.91512299, 24.57459068], [75.91107178, 24.57705116], [75.90287018, 24.57681084], [75.89771271, 24.58045006], [75.89372253, 24.58167076], [75.88436127, 24.58173943], [75.87581635, 24.59078026], [75.8766861, 24.59964943], [75.87407684, 24.60711098], [75.86566162, 24.60733986], [75.86345673, 24.61292076], [75.85254669, 24.61432076], [75.84816742, 24.61116028], [75.84501648, 24.6103611], [75.84233093, 24.60024261], [75.83835602, 24.59568977], [75.83544159, 24.59756279], [75.83920288, 24.60874939], [75.82814789, 24.61334991], [75.83036041, 24.61995125], [75.83428955, 24.62375069], [75.83812714, 24.62360191], [75.84287262, 24.62611961], [75.84620667, 24.63140106], [75.84411621, 24.63472176], [75.84393311, 24.63927078], [75.84880829, 24.65306091], [75.84864807, 24.66455078], [75.84390259, 24.66934967], [75.83706665, 24.66999817], [75.82818604, 24.66822243], [75.82714081, 24.67150116], [75.83154297, 24.67974091], [75.83368683, 24.68595123], [75.84202576, 24.71746063], [75.83875275, 24.72986984], [75.82781219, 24.73635292], [75.80545807, 24.75626945], [75.78618622, 24.76552963], [75.78064728, 24.76316071], [75.77259827, 24.76204109], [75.7596817, 24.76479912], [75.74180603, 24.76036072], [75.73075867, 24.75555038], [75.72306824, 24.7501297], [75.71177673, 24.74542999], [75.68004608, 24.72783089], [75.65918732, 24.70170021], [75.63400269, 24.69115067], [75.61332703, 24.68842125], [75.60943604, 24.6899929], [75.6026001, 24.70127106], [75.58190155, 24.72270012], [75.56899261, 24.71990013], [75.55210114, 24.71376991], [75.54854584, 24.71556091], [75.54122162, 24.71669006], [75.53507996, 24.72001839], [75.52748108, 24.71791077], [75.505867, 24.70942116], [75.4834671, 24.69762039], [75.45189667, 24.69321823], [75.43753815, 24.69552994], [75.41970062, 24.69996071], [75.3964386, 24.70455933], [75.37814331, 24.7063694], [75.36389923, 24.70951843], [75.35086823, 24.71710014], [75.30436707, 24.72074127], [75.2858429, 24.72590065], [75.26724243, 24.73271942], [75.26200104, 24.73306084], [75.24954224, 24.72914124], [75.24246979, 24.73048019], [75.22840881, 24.7351017], [75.22406006, 24.73546028], [75.22141266, 24.73345947], [75.21936798, 24.72305107], [75.21694946, 24.7224102], [75.20191193, 24.74614143], [75.19818878, 24.75690079], [75.19561768, 24.76000977], [75.1868515, 24.76032066], [75.18559265, 24.76304054], [75.18551636, 24.76805115], [75.18768311, 24.77007294], [75.18950653, 24.77464104], [75.19229889, 24.78874969], [75.19532776, 24.789711], [75.20271301, 24.78880119], [75.20358276, 24.79247093], [75.20269775, 24.79628754], [75.2035675, 24.80168915], [75.2064209, 24.8099308], [75.21737671, 24.82046127], [75.22247314, 24.81896019], [75.23661041, 24.82024002], [75.24134064, 24.8194294], [75.24671173, 24.82184029], [75.2494812, 24.82639122], [75.25154877, 24.83221817], [75.25192261, 24.83716965], [75.24968719, 24.84081078], [75.24616241, 24.84416962], [75.24104309, 24.84686089], [75.23378754, 24.84662056], [75.22773743, 24.84775925], [75.22550201, 24.85103989], [75.22601318, 24.85485077], [75.22170258, 24.85819054], [75.21848297, 24.8594799], [75.21038055, 24.87142944], [75.20670319, 24.8791008], [75.20131683, 24.88420105], [75.20288086, 24.88809967], [75.20609283, 24.8916111], [75.20820618, 24.89775085], [75.20742798, 24.90464973], [75.20819092, 24.90999985], [75.21264648, 24.91007042], [75.21920013, 24.90648842], [75.22135162, 24.90279961], [75.21969604, 24.89220047], [75.22341919, 24.89002991], [75.23059845, 24.89442062], [75.23612976, 24.89929962], [75.24124146, 24.90263176], [75.24437714, 24.90204048], [75.24774933, 24.8999176], [75.24994659, 24.89569092], [75.24797058, 24.88088989], [75.23667145, 24.87088966], [75.22738647, 24.85914993], [75.22953033, 24.857481], [75.23406982, 24.8583107], [75.24169159, 24.86094093], [75.24769592, 24.85950851], [75.25234985, 24.85950851], [75.25979614, 24.85752106], [75.27121735, 24.85635948], [75.27893829, 24.85349083], [75.28382111, 24.85001945], [75.29042053, 24.84091949], [75.29421997, 24.83037949], [75.29769897, 24.82637024], [75.29841614, 24.81990814], [75.30049133, 24.81524277], [75.30573273, 24.8133297], [75.31301117, 24.81353951], [75.31981659, 24.81779289], [75.32361603, 24.82396126], [75.33023071, 24.83172989], [75.33744049, 24.83370972], [75.34407806, 24.83279037], [75.35505676, 24.83743095], [75.36396027, 24.84252167], [75.39965057, 24.8549099], [75.4105072, 24.86123848], [75.417099, 24.86390114], [75.4172821, 24.86861038], [75.42063141, 24.87733078], [75.42059326, 24.88163185], [75.42421722, 24.89275169], [75.41416931, 24.89300919], [75.40753937, 24.89191055], [75.3986969, 24.88834953], [75.37197113, 24.87798119], [75.35006714, 24.88496971], [75.33534241, 24.88667107], [75.32596588, 24.88700867], [75.32124329, 24.88266182], [75.31765747, 24.87515068], [75.31130219, 24.86945915], [75.29904938, 24.87026024], [75.29411316, 24.87137985], [75.28807831, 24.87968063], [75.27928162, 24.88455009], [75.27265167, 24.88693047], [75.26508331, 24.88817024], [75.26145172, 24.88965988], [75.25965881, 24.89982033], [75.26077271, 24.90534019], [75.26425171, 24.90731049], [75.26702881, 24.91421127], [75.27171326, 24.91786957], [75.274086, 24.9170475], [75.27485657, 24.91432953], [75.27796936, 24.91308022], [75.27867889, 24.91749191], [75.28237152, 24.92254066], [75.28482819, 24.92280006], [75.28793335, 24.92053032], [75.29190063, 24.92091751], [75.29308319, 24.92317963], [75.29116821, 24.92496109], [75.28790283, 24.9262619], [75.28488159, 24.93712044], [75.27580261, 24.94027138], [75.27722168, 24.94790077], [75.27165222, 24.94942093], [75.26999664, 24.95627022], [75.26631165, 24.96191978], [75.26844788, 24.9655304], [75.271492, 24.96821976], [75.27590179, 24.97673035], [75.28536224, 24.97669029], [75.28556061, 24.96412277], [75.28814697, 24.96263123], [75.28778076, 24.95963287], [75.28980255, 24.95611191], [75.29045868, 24.95202065], [75.29429626, 24.94870949], [75.30018616, 24.94682121], [75.30267334, 24.94316101], [75.30351257, 24.94017982], [75.30229187, 24.9348793], [75.30316162, 24.93061256], [75.30610657, 24.92897987], [75.30832672, 24.92629051], [75.31217194, 24.91106033], [75.31210327, 24.8999176], [75.31387329, 24.90044022], [75.31754303, 24.90722084], [75.32540894, 24.93809128], [75.32875061, 24.94563103], [75.33426666, 24.95061111], [75.33748627, 24.96310043], [75.33541107, 24.96471024], [75.3337326, 24.9674511], [75.33127594, 24.9760704], [75.32636261, 24.97616005], [75.32312012, 24.98224068], [75.32208252, 24.98961258], [75.32203674, 24.99612999], [75.32311249, 25.00090981], [75.31894684, 25.00650978], [75.32248688, 25.01338959], [75.32949066, 25.01762962], [75.3431015, 25.02230072], [75.35061646, 25.0248394], [75.35154724, 25.02515984], [75.35362244, 25.02873039], [75.35005188, 25.03327179], [75.35424042, 25.03737068], [75.349617, 25.04173088], [75.34558868, 25.0428009], [75.33615875, 25.04488945], [75.32266998, 25.0442524], [75.31048584, 25.04607964], [75.30016327, 25.0440197], [75.29255676, 25.04288292], [75.27826691, 25.04470062], [75.26597595, 25.04306984], [75.25562286, 25.04004288], [75.24459076, 25.03993034], [75.2375412, 25.04191971], [75.2270813, 25.03853035], [75.21821594, 25.04144096], [75.20548248, 25.0424099], [75.20355225, 25.0388298], [75.20056152, 25.03449821], [75.19509125, 25.03751945], [75.19441986, 25.03770065], [75.1917572, 25.03836823], [75.18531036, 25.04253006], [75.18209076, 25.04758072], [75.17378235, 25.05379295], [75.16696167, 25.0442009], [75.15912628, 25.04547119], [75.15628052, 25.03544044], [75.15470886, 25.02886963], [75.15921021, 25.02407074], [75.16525269, 25.02231979], [75.16860199, 25.01319122], [75.16924286, 25.00996971], [75.16676331, 25.00610924], [75.16439819, 24.99166107], [75.16256714, 24.99170113], [75.16131592, 24.99008942], [75.1608963, 24.98761177], [75.15215302, 24.98868942], [75.14582825, 24.98643112], [75.14385986, 24.98705292], [75.14037323, 24.98713112], [75.13802338, 24.98636246], [75.13432312, 24.98266029], [75.14775848, 24.98163986], [75.149086, 24.98122025], [75.14685059, 24.97957993], [75.13656616, 24.97874069], [75.13471985, 24.97772026], [75.13352966, 24.97524261], [75.11982727, 24.97575951], [75.1190567, 24.97475243], [75.1157074, 24.96539116], [75.11534882, 24.96112823], [75.11569214, 24.95364952], [75.11772919, 24.94634056], [75.11942291, 24.91814041], [75.11493683, 24.91184044], [75.1177063, 24.9051609], [75.11943054, 24.89583015], [75.11886597, 24.88903999], [75.1149826, 24.88713837], [75.09011078, 24.87973022], [75.08834076, 24.8810997], [75.0870285, 24.88347054], [75.0866394, 24.88657951], [75.08532715, 24.88889122], [75.08167267, 24.88913918], [75.07685089, 24.88883972], [75.0735321, 24.88731003], [75.06620026, 24.87839127], [75.0631485, 24.87746811], [75.0592804, 24.88129997], [75.05634308, 24.88194084], [75.05626678, 24.88091087], [75.05877686, 24.87771034], [75.0598526, 24.87473106], [75.05713654, 24.87105179], [75.05108643, 24.86488914], [75.04338837, 24.85922813], [75.03411102, 24.85860062], [75.02974701, 24.86054039], [75.0229187, 24.86561966], [75.0194931, 24.86693001], [75.01508331, 24.87020111], [75.01261139, 24.87408066], [74.99767303, 24.8766098], [74.99104309, 24.87500191], [74.98751068, 24.87597275], [74.98416901, 24.87763023], [74.97733307, 24.87747955], [74.97173309, 24.8753891], [74.96353912, 24.87408066], [74.95633698, 24.87495995], [74.94883728, 24.87812042], [74.94480896, 24.87791061], [74.95043182, 24.88997078], [74.95020294, 24.89295006], [74.9487381, 24.89480019], [74.9462204, 24.8939209], [74.93969727, 24.8934803], [74.93547058, 24.8952198], [74.9307785, 24.89397049], [74.92951202, 24.88788986], [74.92695618, 24.89036942], [74.92368317, 24.89207077], [74.92008209, 24.89184952], [74.91951752, 24.8948307], [74.91615295, 24.89944077], [74.91252136, 24.89909935], [74.90688324, 24.90715981], [74.91174316, 24.91887283], [74.91100311, 24.92328072], [74.91293335, 24.9283886], [74.90735626, 24.92867088], [74.90428925, 24.93011093], [74.90265656, 24.93468094], [74.90260315, 24.93727112], [74.90054321, 24.93974113], [74.8899231, 24.94145012], [74.88469696, 24.94976044], [74.87911987, 24.9487896], [74.87728119, 24.93939018], [74.87085724, 24.93720055], [74.86720276, 24.93694115], [74.86572266, 24.94326973], [74.86387634, 24.9475708], [74.86351776, 24.95729065], [74.86203766, 24.96282959], [74.86209869, 24.96583939], [74.85320282, 24.97472], [74.84635162, 24.97429085], [74.83271027, 24.9674511], [74.83061218, 24.96191025], [74.83114624, 24.95730972], [74.82627106, 24.95220947], [74.82498932, 24.94589043], [74.82534027, 24.94045067], [74.82421875, 24.94009972], [74.8236084, 24.92850113], [74.82411194, 24.91481018], [74.82713318, 24.89912987], [74.83161926, 24.89892006], [74.83512115, 24.89703941], [74.83783722, 24.89721107], [74.8394165, 24.89286995], [74.84015656, 24.88055038], [74.84237671, 24.87496948], [74.84565735, 24.87210274], [74.8529129, 24.86033058], [74.85588837, 24.85320091], [74.85604858, 24.84716988], [74.85748291, 24.8429985], [74.85903168, 24.82901001], [74.85903931, 24.82015991], [74.85746002, 24.81784821], [74.85296631, 24.81553078], [74.84597778, 24.81484032], [74.83751678, 24.80846024], [74.84078217, 24.80341911], [74.84889221, 24.79265976], [74.85144806, 24.79265976], [74.85794067, 24.79462051], [74.85946655, 24.7995491], [74.85856628, 24.81306076], [74.86785126, 24.81311989], [74.87023163, 24.81205177], [74.87805176, 24.81318092], [74.88014984, 24.8105011], [74.88053894, 24.80796814], [74.8846817, 24.80243111], [74.89195251, 24.79911041], [74.89743805, 24.79920959], [74.90518188, 24.79746056], [74.90997314, 24.78821945], [74.91694641, 24.78718185], [74.92207336, 24.7884407], [74.92941284, 24.79548264], [74.93855286, 24.79479027], [74.94595337, 24.79171944], [74.95542145, 24.79244041], [74.96157837, 24.79117012], [74.97038269, 24.79086113], [74.99001312, 24.79381943], [74.99832916, 24.79771042], [75.00705719, 24.79606056], [75.01293182, 24.79380989], [75.01629639, 24.78594971], [75.01795959, 24.7807312], [75.02005005, 24.7744503], [75.02137756, 24.77285957], [75.02133942, 24.77026939], [75.02131653, 24.76716042], [75.02023315, 24.75276756], [74.9970932, 24.75420952], [74.99343109, 24.75272942], [74.99202728, 24.74381065], [74.99075317, 24.73376846], [74.99211884, 24.72826195], [74.99521637, 24.71614075], [74.99664307, 24.71599007], [74.99941254, 24.71379089], [75.00035095, 24.71056938], [74.99989319, 24.70848846], [74.99655914, 24.70684242], [74.99371338, 24.70578957], [74.99043274, 24.70634842], [74.96411133, 24.70046806], [74.96216583, 24.7008419], [74.96485901, 24.69454193], [74.9598999, 24.68875122], [74.95990753, 24.68671989], [74.96102905, 24.68609047], [74.96182251, 24.68370056], [74.96198273, 24.67958069], [74.96116638, 24.67889023], [74.95923615, 24.67990112], [74.95728302, 24.68268967], [74.95197296, 24.67646027], [74.95265961, 24.67385101], [74.95202637, 24.67031288], [74.94300842, 24.66889763], [74.94181824, 24.66682053], [74.94387817, 24.66228294], [74.94285583, 24.66039085], [74.93917847, 24.66171074], [74.93718719, 24.66015053], [74.93476105, 24.66184807], [74.92945099, 24.65917015], [74.91986847, 24.65842056], [74.91478729, 24.65942001], [74.91300964, 24.66041183], [74.90965271, 24.66043091], [74.90854645, 24.66157913], [74.90563965, 24.66033936], [74.90246582, 24.65631104], [74.89700317, 24.66555977], [74.8935318, 24.66385841], [74.8935318, 24.66098022], [74.89450836, 24.65814972], [74.89285278, 24.65534973], [74.88791656, 24.65772247], [74.88018036, 24.66801071], [74.87767029, 24.66578102], [74.87502289, 24.66748047], [74.87343597, 24.66948128], [74.87268829, 24.67592049], [74.86975861, 24.67878914], [74.86691284, 24.69052124], [74.86521149, 24.69207001], [74.86245728, 24.69234276], [74.85983276, 24.69388962], [74.85853577, 24.70218086], [74.85636139, 24.70517921], [74.85396576, 24.70412064], [74.85531616, 24.69922066], [74.85431671, 24.69671059], [74.85182953, 24.69659042], [74.84984589, 24.69865036], [74.84970856, 24.70633125], [74.84884644, 24.70872116], [74.83487701, 24.73200035], [74.8292923, 24.74590111], [74.81854248, 24.76534081], [74.81495667, 24.78145027], [74.80980682, 24.79640007], [74.79931641, 24.79564095], [74.79847717, 24.7905407], [74.80114746, 24.78668976], [74.80191803, 24.76654053], [74.80314636, 24.75485229], [74.79978943, 24.75171089], [74.79254913, 24.7501812], [74.78607941, 24.74691963], [74.78005219, 24.74274826], [74.78137207, 24.74085045], [74.78386688, 24.73035049], [74.78837585, 24.72803116], [74.78965759, 24.72663116], [74.78753662, 24.72192955], [74.78315735, 24.71821976], [74.7844162, 24.71264076], [74.78385925, 24.7095108], [74.78089142, 24.70508957], [74.77964783, 24.70066071], [74.77731323, 24.69668961], [74.77786255, 24.69321823], [74.77527618, 24.68773079], [74.77606201, 24.68605995], [74.7857132, 24.67994118], [74.78946686, 24.67893982], [74.79197693, 24.68157959], [74.79234314, 24.68432045], [74.80966949, 24.68653107], [74.81333923, 24.6861496], [74.81775665, 24.6799202], [74.81774902, 24.6764698], [74.81710815, 24.67167091], [74.81482697, 24.66977119], [74.81137848, 24.6716404], [74.80873871, 24.66996193], [74.8049469, 24.65956116], [74.80237579, 24.65691948], [74.79934692, 24.65657043], [74.79493713, 24.65470123], [74.79302216, 24.65155983], [74.79350281, 24.64944077], [74.79138947, 24.64542961], [74.78344727, 24.63676071], [74.78483582, 24.62928963], [74.78781891, 24.62078094], [74.7873764, 24.61759186], [74.79055023, 24.61740112], [74.79012299, 24.61075974], [74.78633118, 24.61010933], [74.78176117, 24.6071701], [74.77723694, 24.60539055], [74.77065277, 24.60584259], [74.76017761, 24.60139084], [74.75595093, 24.6006794], [74.74797058, 24.59680939], [74.74668884, 24.59299278], [74.75031281, 24.58866119], [74.75154114, 24.58611107], [74.75377655, 24.57838058], [74.75547791, 24.57098961], [74.7569809, 24.56365013], [74.75634766, 24.55989075], [74.75746155, 24.55681992], [74.75675201, 24.55462074], [74.75234222, 24.55237007], [74.74854279, 24.5517292], [74.74759674, 24.5476799], [74.74961853, 24.5425396], [74.74771118, 24.53623962], [74.7285614, 24.53479004], [74.72342682, 24.53115082], [74.71570587, 24.52283096], [74.71193695, 24.51094055], [74.71290588, 24.50922012], [74.71555328, 24.50823975], [74.72370911, 24.51040077], [74.72718811, 24.5107708], [74.73082733, 24.51003075], [74.73504639, 24.50362015], [74.75065613, 24.49200058], [74.75731659, 24.48882294], [74.76081848, 24.48857117], [74.7661972, 24.49065018], [74.77330017, 24.48509979], [74.77899933, 24.48338127], [74.78153229, 24.48486137], [74.78495789, 24.48989105], [74.79187775, 24.49327087], [74.79595184, 24.49324989], [74.801651, 24.49208069], [74.80800629, 24.49304008], [74.81083679, 24.49200058], [74.81450653, 24.49221039], [74.81684113, 24.49117088], [74.82238007, 24.4878006], [74.82419586, 24.48354912], [74.8246994, 24.47923088], [74.82010651, 24.47290039], [74.81826782, 24.4619503], [74.83378601, 24.46042061], [74.8365097, 24.46539116], [74.84085083, 24.46722031], [74.84455109, 24.46590996], [74.8493576, 24.46664047], [74.85066986, 24.4688282], [74.85411072, 24.47020912], [74.85813141, 24.46733284], [74.85695648, 24.46327972], [74.85817719, 24.4555397], [74.85749817, 24.45150185], [74.85389709, 24.44950294], [74.8477478, 24.44355965], [74.84586334, 24.44073105], [74.8351593, 24.42951965], [74.82701111, 24.42360115], [74.82723236, 24.41680908], [74.82639313, 24.41069031], [74.82524109, 24.40833282], [74.81479645, 24.41069031], [74.81231689, 24.40915108], [74.80541229, 24.39545059], [74.80227661, 24.38734055], [74.79833221, 24.384161], [74.79315948, 24.37614059], [74.78835297, 24.37177086], [74.7869873, 24.3716507], [74.78462219, 24.36736107], [74.78167725, 24.35835075], [74.78276062, 24.35466003], [74.78621674, 24.34880066], [74.78633881, 24.34386063], [74.78379059, 24.33609962], [74.78317261, 24.3194294], [74.78482056, 24.32113075], [74.78363037, 24.31680107], [74.7670517, 24.30446053], [74.75746155, 24.29622078], [74.75302124, 24.28939056], [74.75280762, 24.28265953], [74.75479126, 24.27897072], [74.76647949, 24.27342033], [74.77253723, 24.27198029], [74.77968597, 24.27260971], [74.79029846, 24.27187157], [74.81516266, 24.27700996], [74.81964874, 24.27626038], [74.82578278, 24.27330017], [74.83264923, 24.27157021], [74.83891296, 24.27123833], [74.84390259, 24.27016068], [74.85331726, 24.26997948], [74.85659027, 24.27219963], [74.85975647, 24.27299118], [74.86255646, 24.27370071], [74.86403656, 24.27396011], [74.86972046, 24.28070831], [74.87542725, 24.27802086], [74.88530731, 24.2687397], [74.88905334, 24.26684952], [74.89428711, 24.2616806], [74.89700317, 24.24917984], [74.90405273, 24.24587822], [74.90544128, 24.24530983], [74.90725708, 24.24081039], [74.90585327, 24.23372078], [74.90271759, 24.23101044], [74.89821625, 24.22907066], [74.88970947, 24.22689056], [74.88671112, 24.22492027], [74.88017273, 24.21648026], [74.8811264, 24.21350288], [74.89729309, 24.18704033], [74.8976593, 24.18237114], [74.89948273, 24.17844009], [74.90033722, 24.17430115], [74.9201889, 24.16284752], [74.92146301, 24.16024971], [74.92751312, 24.15715027], [74.92350769, 24.14928055], [74.92469025, 24.14523125], [74.93665314, 24.13898087], [74.9389801, 24.12788963], [74.93618011, 24.12376976], [74.93914032, 24.12111092], [74.95487213, 24.11203957], [74.95951843, 24.11009026], [74.96089172, 24.10550117], [74.96074677, 24.09416008], [74.96186066, 24.08963013], [74.96517181, 24.08272171], [74.97155762, 24.07785988], [74.97625732, 24.07600975], [74.97940826, 24.07201195], [74.98121643, 24.04104042], [74.99038696, 24.03343964], [74.99298859, 24.02970123], [74.99236298, 24.02323151], [74.98779297, 24.01433182], [74.97981262, 24.00989914], [74.972229, 24.00362968], [74.97292328, 23.99105263], [74.96869659, 23.97973061], [74.96334839, 23.97367096], [74.94145966, 23.96051979], [74.93760681, 23.95608139], [74.93151855, 23.94681931], [74.93112183, 23.94491005], [74.92984772, 23.94096184], [74.92431641, 23.93861008], [74.92131042, 23.93571281], [74.92360687, 23.92926979], [74.92337799, 23.92490959], [74.91742706, 23.91757011], [74.91461945, 23.91246986], [74.91385651, 23.90336037], [74.91049957, 23.88850975], [74.90724182, 23.87675095], [74.9056778, 23.8739109], [74.90518951, 23.86811066], [74.90688324, 23.85638046], [74.91024017, 23.85213089], [74.91313934, 23.84986115], [74.91581726, 23.8456707], [74.91326141, 23.83662987], [74.91191864, 23.81261063], [74.91033936, 23.80084038], [74.91500854, 23.79918861], [74.92761993, 23.79833031], [74.92993164, 23.79420853], [74.93785095, 23.77671051], [74.93947601, 23.77067184], [74.93992615, 23.76585007], [74.93187714, 23.75811005], [74.93192291, 23.75641823], [74.93810272, 23.74287987], [74.94056702, 23.73487091], [74.93199158, 23.72834015], [74.92424011, 23.71915054], [74.92289734, 23.71386909], [74.92304993, 23.69658089], [74.91745758, 23.6921196], [74.91043854, 23.68798065], [74.90762329, 23.68283081], [74.90991211, 23.67690086], [74.92421722, 23.6685009], [74.92838287, 23.6531601], [74.93061066, 23.64821815], [74.9389801, 23.64318848], [74.94034576, 23.63692284], [74.93972015, 23.63037109], [74.92787933, 23.62438011], [74.92193604, 23.62231064], [74.90956879, 23.62416077], [74.90602875, 23.62295151], [74.89803314, 23.61218262], [74.88609314, 23.60642815], [74.8849411, 23.60330963], [74.87937927, 23.59596062], [74.87732697, 23.59439087], [74.87457275, 23.59011078], [74.87502289, 23.5835495], [74.87265015, 23.57822037], [74.86933136, 23.57479858], [74.86171722, 23.57234001], [74.8589859, 23.56949997], [74.85147858, 23.55739975], [74.84542084, 23.55417061], [74.83757782, 23.55321121], [74.83009338, 23.54952049], [74.81923676, 23.54079819], [74.81575775, 23.53961945], [74.81230927, 23.53843117], [74.80288696, 23.5340519], [74.79875946, 23.54043961], [74.79633331, 23.54626083], [74.792099, 23.5486412], [74.78501129, 23.54803085], [74.77406311, 23.54330254], [74.77072906, 23.53577042], [74.7639389, 23.52471161], [74.75707245, 23.52217293], [74.74237061, 23.51947975], [74.73777771, 23.50678062], [74.73365784, 23.50052071], [74.72589111, 23.49846077], [74.71877289, 23.50358009], [74.71089935, 23.50563049], [74.70066071, 23.50368118], [74.68740845, 23.49580956], [74.68776703, 23.49220085], [74.68371582, 23.48658943], [74.68093872, 23.48509026], [74.67446136, 23.48568153], [74.66932678, 23.48389244], [74.66409302, 23.47334099], [74.65894318, 23.46680069], [74.65473175, 23.46442032], [74.65223694, 23.46339035], [74.63642883, 23.46406174], [74.62699127, 23.46198082], [74.61338043, 23.46136093], [74.61312103, 23.45155144], [74.59845734, 23.42975998], [74.59146881, 23.42513084], [74.57966614, 23.4224205], [74.57402039, 23.42254257], [74.57314301, 23.41924286], [74.57241058, 23.38332939], [74.57071686, 23.3777504], [74.56521606, 23.37522125], [74.56022644, 23.36449051], [74.55580902, 23.36297989], [74.54582977, 23.36379814], [74.5437088, 23.35898972], [74.54271698, 23.3386898], [74.53839874, 23.33399963], [74.52028656, 23.33169174], [74.51830292, 23.32872963], [74.51924896, 23.32193756], [74.52085114, 23.32160187], [74.53032684, 23.32414055], [74.53366089, 23.32303047], [74.53450775, 23.32036972], [74.53421021, 23.31398964], [74.53568268, 23.30952263], [74.54062653, 23.30511284], [74.54390717, 23.30005264], [74.54856873, 23.28676033], [74.5534668, 23.28252029], [74.55822754, 23.28531075], [74.56210327, 23.29208946], [74.56735229, 23.29846191], [74.5719223, 23.30089188], [74.57728577, 23.29734993], [74.58676147, 23.28446007], [74.592659, 23.28358078], [74.59905243, 23.28363037], [74.60669708, 23.28536034], [74.61530304, 23.28460121], [74.62229156, 23.28133965], [74.6265564, 23.27599907], [74.62956238, 23.26584053], [74.63214111, 23.26340103], [74.64624786, 23.25971985], [74.65222168, 23.26081276], [74.66649628, 23.27111053], [74.67312622, 23.27486992], [74.68048859, 23.27526283], [74.70114899, 23.27214241], [74.70162201, 23.26675034], [74.70334625, 23.26164246], [74.71026611, 23.25814056], [74.71489716, 23.25296021], [74.71853638, 23.24600983], [74.72215271, 23.24251175], [74.71324921, 23.2363205], [74.70381165, 23.23315048], [74.69554138, 23.22859001], [74.69500732, 23.22307968], [74.69960785, 23.22034073], [74.7026062, 23.21970177], [74.712883, 23.22135925], [74.71895599, 23.21943283], [74.72431946, 23.22011948], [74.7329483, 23.22375107], [74.73995972, 23.22863007], [74.74053955, 23.22904015], [74.74098206, 23.2293396], [74.7457962, 23.23270988], [74.75083923, 23.23038101], [74.74603271, 23.21536064], [74.74569702, 23.21211052], [74.73477936, 23.20639992], [74.721138, 23.19697952], [74.71552277, 23.19466972], [74.68756866, 23.19670105], [74.66915894, 23.2014904], [74.66532135, 23.19824982], [74.65983582, 23.18789101], [74.65474701, 23.18202972], [74.64198303, 23.17266273], [74.62567902, 23.16294098], [74.61782837, 23.15193176], [74.61415863, 23.14833069], [74.60806274, 23.14482117], [74.59723663, 23.14199257], [74.58863068, 23.14146996], [74.58007812, 23.13997078], [74.57363129, 23.1371994], [74.56604004, 23.13523293], [74.54570007, 23.13207054], [74.54751587, 23.11849022], [74.54650116, 23.11280823], [74.54265594, 23.10690117], [74.53543854, 23.10151291], [74.52327728, 23.09891129], [74.51360321, 23.09590149], [74.51228333, 23.08883095], [74.49140167, 23.08838272], [74.46724701, 23.08525848], [74.45823669, 23.08706093], [74.4454422, 23.09293175], [74.4393158, 23.09807968], [74.4331665, 23.10568047], [74.42610168, 23.10602951], [74.41884613, 23.10847092], [74.41409302, 23.11096191], [74.40683746, 23.11177063], [74.39118958, 23.11199951], [74.38767242, 23.11044121], [74.36696625, 23.09552002], [74.36112213, 23.09031105], [74.35954285, 23.08049965], [74.35510254, 23.07580185], [74.3478775, 23.07080078], [74.33927917, 23.06697083], [74.32277679, 23.06269073], [74.31829071, 23.06725121], [74.31552124, 23.07212067], [74.31017303, 23.07954025], [74.30391693, 23.08389282], [74.28678131, 23.0916996], [74.28253937, 23.09501266], [74.28077698, 23.10098076], [74.2820282, 23.10643005], [74.28814697, 23.11873055], [74.28491211, 23.12458038], [74.27954102, 23.12997055], [74.27762604, 23.13397026], [74.27661896, 23.13977242], [74.2718277, 23.15600967], [74.26706696, 23.16596985], [74.26185608, 23.17160034], [74.25701904, 23.17472076], [74.25242615, 23.17616844], [74.24977875, 23.17843056], [74.24603271, 23.18825912], [74.2370224, 23.18270111], [74.2293396, 23.184021], [74.20754242, 23.19205093], [74.2041626, 23.18909073], [74.20008087, 23.18374062], [74.19412231, 23.17856026], [74.18953705, 23.17184067], [74.18914795, 23.15790939], [74.18660736, 23.15252113], [74.18299103, 23.15221977], [74.16493988, 23.15648079], [74.16069031, 23.15554047], [74.15516663, 23.15775108], [74.14845276, 23.17205048], [74.14569092, 23.17523003], [74.13617706, 23.17770958], [74.13051605, 23.17764282], [74.12702179, 23.17885017], [74.1244812, 23.18799973], [74.12452698, 23.19044113], [74.12252045, 23.19157028], [74.12349701, 23.20170021], [74.12470245, 23.20656967], [74.13391113, 23.21517944], [74.13510132, 23.22006989], [74.13948059, 23.2268219], [74.13865662, 23.23092079], [74.1388092, 23.23637962], [74.13652039, 23.24480057], [74.1361084, 23.26472092], [74.13378143, 23.26945114], [74.12989044, 23.27272034], [74.11856079, 23.27536964], [74.11387634, 23.27734947], [74.11106873, 23.28572083], [74.10658264, 23.2941227], [74.10166168, 23.29574966], [74.08973694, 23.29799271], [74.07652283, 23.29819107], [74.04873657, 23.29506111], [74.04447174, 23.29609108], [74.04968262, 23.30709076], [74.04769897, 23.31093979], [74.04138184, 23.30700111], [74.03759766, 23.30574036], [74.03592682, 23.31261063], [74.03006744, 23.31994057], [74.03266144, 23.33234978], [74.02361298, 23.33288193], [74.00380707, 23.33620071], [73.99077606, 23.33762932], [73.98696899, 23.34123993], [73.98446655, 23.34945107], [73.98348999, 23.35984039], [73.97889709, 23.36783981], [73.97103119, 23.37713814], [73.96247101, 23.38138962], [73.95691681, 23.37763977], [73.94729614, 23.3735199], [73.94371033, 23.36634064], [73.9438324, 23.35359955], [73.94262695, 23.34593964], [73.93889618, 23.34141922], [73.92784119, 23.33788109], [73.91398621, 23.33597946], [73.90122986, 23.3359127], [73.89427185, 23.33713913], [73.89492798, 23.35258102], [73.89118195, 23.35860062], [73.87944031, 23.36811066], [73.87708282, 23.37833023], [73.86676025, 23.39577103], [73.85743713, 23.40479279], [73.8364563, 23.43069077], [73.83679962, 23.44013977], [73.83213043, 23.44675064], [73.82688904, 23.44684029], [73.79416656, 23.43556976], [73.7830658, 23.43461037], [73.77784729, 23.44231987], [73.7739563, 23.44586945], [73.77099609, 23.45257759], [73.7647171, 23.45857811], [73.76065063, 23.4568119], [73.7565918, 23.4495697], [73.7513504, 23.44246101], [73.7339859, 23.42489243], [73.72881317, 23.41829109], [73.72614288, 23.41266251], [73.7203064, 23.4148407], [73.71721649, 23.41884041], [73.71356201, 23.43367958], [73.70960236, 23.44449043], [73.704216, 23.45578194], [73.69394684, 23.45890045], [73.68190765, 23.45708084], [73.6687088, 23.451931], [73.66081238, 23.44725037], [73.65320587, 23.44049072], [73.63806915, 23.45034027], [73.63275146, 23.45239258], [73.64064789, 23.47304153], [73.64382172, 23.4967804], [73.64491272, 23.49873924], [73.65258789, 23.50093079], [73.65841675, 23.50411987], [73.65844727, 23.51415253], [73.65733337, 23.51618004], [73.65219879, 23.52140236], [73.63700104, 23.53112984], [73.63713074, 23.54801941], [73.63825989, 23.56254959], [73.64286804, 23.56962013], [73.6497879, 23.57534027], [73.65120697, 23.58086967], [73.64872742, 23.59067917], [73.64804077, 23.59864044], [73.64998627, 23.60769272], [73.66073608, 23.62290192], [73.65039825, 23.62688065], [73.64225769, 23.63126945], [73.63295746, 23.63853073], [73.61901855, 23.6514225], [73.60853577, 23.65430832], [73.57727051, 23.65536118], [73.57074738, 23.65351105], [73.55297852, 23.63134956], [73.54141998, 23.62265015], [73.53224182, 23.61354065], [73.52672577, 23.6106205], [73.51348877, 23.61681175], [73.51024628, 23.62068939], [73.50569153, 23.62885094], [73.50109863, 23.63383102], [73.50137329, 23.63544083], [73.50845337, 23.63939095], [73.5116272, 23.64508057], [73.50052643, 23.65073013], [73.50720978, 23.6577301], [73.50779724, 23.66263008], [73.51094055, 23.67338943], [73.51122284, 23.68008041], [73.51035309, 23.69697952], [73.50853729, 23.70333099], [73.50192261, 23.70664978], [73.48561096, 23.70500946], [73.47927094, 23.70897293], [73.47661591, 23.72103119], [73.47289276, 23.72578049], [73.46276855, 23.73430824], [73.45493317, 23.73971939], [73.45128632, 23.74884033], [73.45082092, 23.75259018], [73.43218994, 23.76208115], [73.42765808, 23.7664299], [73.42048645, 23.77933121], [73.41349792, 23.78110123], [73.408638, 23.78359032], [73.40000916, 23.78397751], [73.39391327, 23.77846146], [73.3898468, 23.76926041], [73.37590027, 23.76667023], [73.37133789, 23.77787018], [73.36769867, 23.78364944], [73.36264801, 23.78742981], [73.36112976, 23.79165077], [73.36283112, 23.79775047], [73.37042236, 23.81438065], [73.37267303, 23.8219223], [73.3719101, 23.83208275], [73.36952209, 23.83855057], [73.35984802, 23.85462952], [73.36207581, 23.86186981], [73.36606598, 23.86907005], [73.37124634, 23.87585068], [73.37695313, 23.88879967], [73.38237762, 23.89500046], [73.3864975, 23.90577126], [73.39611053, 23.91679192], [73.40225983, 23.91822052], [73.40775299, 23.91612053], [73.42012024, 23.92340088], [73.42346954, 23.92760086], [73.42468262, 23.93106079], [73.42038727, 23.93644905], [73.41912842, 23.95379829], [73.42146301, 23.97467041], [73.41957855, 23.98266029], [73.41396332, 23.98843193], [73.40505981, 23.99054909], [73.41060638, 23.99833107], [73.41081238, 24.00255013], [73.40925598, 24.01585007], [73.41146851, 24.02518272], [73.41140747, 24.03484154], [73.41375732, 24.05106926], [73.40419006, 24.06520081], [73.39659119, 24.07253075], [73.38526917, 24.07958031], [73.37979126, 24.08415031], [73.37475586, 24.08708191], [73.36962891, 24.08798027], [73.36962128, 24.11249161], [73.37346649, 24.1281395], [73.36081696, 24.11409187], [73.34276581, 24.11582947], [73.33518219, 24.1151104], [73.33188629, 24.10400963], [73.33451843, 24.08256912], [73.33249664, 24.07368279], [73.32656097, 24.0625], [73.31845856, 24.0567894], [73.31140137, 24.05461121], [73.3068161, 24.05145073], [73.2979126, 24.03676987], [73.29103088, 24.02740288], [73.28275299, 24.02881813], [73.2753067, 24.02802086], [73.26390839, 24.02009964], [73.25637817, 24.01317978], [73.25254059, 24.01111984], [73.24582672, 24.01070976], [73.2425766, 24.01279831], [73.24032593, 24.01831818], [73.23513794, 24.02011108], [73.22940063, 24.02403069], [73.22933197, 24.02811813], [73.2232666, 24.03239059], [73.20812225, 24.03948021], [73.20063782, 24.0452404], [73.19893646, 24.05146027], [73.20108795, 24.05739021], [73.20910645, 24.06664085], [73.21366882, 24.07578087], [73.21438599, 24.08019066], [73.21672058, 24.08526039], [73.22041321, 24.08930016], [73.22264862, 24.09350967], [73.22381592, 24.09822083], [73.21578979, 24.10169983], [73.21227264, 24.10414124], [73.19999695, 24.10839081], [73.19760132, 24.11079025], [73.19386292, 24.10518265], [73.19190216, 24.10654831], [73.18686676, 24.10770035], [73.17173004, 24.1113224], [73.16755676, 24.11628914], [73.16114807, 24.12005997], [73.1554718, 24.12186813], [73.14715576, 24.12255096], [73.13846588, 24.12807083], [73.12339783, 24.14030075], [73.11416626, 24.13858986], [73.11650848, 24.15286064], [73.11303711, 24.15779114], [73.10243988, 24.16519928], [73.09095001, 24.17527962], [73.08268738, 24.18498039], [73.08130646, 24.19185829], [73.08196259, 24.19664955], [73.08722687, 24.20079994], [73.09172821, 24.22088051], [73.10119629, 24.22327042], [73.10600281, 24.22615051], [73.11120605, 24.23111153], [73.10617065, 24.23238945], [73.10193634, 24.23485184], [73.10090637, 24.23771095], [73.10575867, 24.24431038], [73.10690308, 24.24895287], [73.10987854, 24.25399017], [73.11606598, 24.26259041], [73.13894653, 24.28005028], [73.14385223, 24.29948044], [73.1449585, 24.30785751], [73.15123749, 24.31079292], [73.1733017, 24.30105019], [73.18062592, 24.30149078], [73.18479919, 24.30911064], [73.18643951, 24.3201828], [73.18612671, 24.32697105], [73.18701172, 24.33494949], [73.19294739, 24.34357071], [73.19792938, 24.33977127], [73.20140076, 24.33409119], [73.21105957, 24.33423042], [73.21644592, 24.35046959], [73.22561646, 24.35647964], [73.23147583, 24.36466026], [73.21098328, 24.37541962], [73.20072937, 24.36679077], [73.19039154, 24.35577011], [73.18017578, 24.35066986], [73.16996765, 24.35066986], [73.16200256, 24.35268021], [73.15455627, 24.35642815], [73.14531708, 24.36305046], [73.13730621, 24.36444092], [73.127388, 24.36882973], [73.11863708, 24.37574005], [73.11119843, 24.38680077], [73.10865021, 24.38746262], [73.09825897, 24.38552094], [73.08496094, 24.39447021], [73.08442688, 24.39764977], [73.08862305, 24.40008926], [73.09072113, 24.40878105], [73.0930481, 24.41312981], [73.09673309, 24.41720963], [73.10624695, 24.42032051], [73.10832977, 24.42632103], [73.10883331, 24.43241119], [73.1065979, 24.44536972], [73.10762787, 24.45181084], [73.10719299, 24.45681953], [73.098526, 24.47261047], [73.09892273, 24.49149132], [73.09438324, 24.49472809], [73.08381653, 24.49020958], [73.07485962, 24.48269081], [73.07006073, 24.48088074], [73.06713867, 24.47458267], [73.05728149, 24.4726181], [73.0533905, 24.4664917], [73.05104065, 24.46525955], [73.03320313, 24.46371078], [73.02719879, 24.46511269], [73.02185059, 24.46511269], [73.01278687, 24.48240089], [73.00676727, 24.47628021], [73.00034332, 24.47063065], [72.9980011, 24.46804047], [72.98912048, 24.45700073], [72.98100281, 24.4510498], [72.98324585, 24.44029808], [72.98931122, 24.43272972], [72.99061584, 24.42089081], [72.97939301, 24.40563965], [72.97245026, 24.40192986], [72.96418762, 24.39222145], [72.96327972, 24.38373947], [72.9661026, 24.38303185], [72.974617, 24.38343048], [72.98127747, 24.38005066], [72.98748016, 24.37511063], [72.99201202, 24.3682003], [72.99146271, 24.36397171], [72.97749329, 24.35884094], [72.96537018, 24.35110855], [72.96177673, 24.34877014], [72.94602203, 24.33928108], [72.9337616, 24.33618927], [72.92903137, 24.33265114], [72.92391205, 24.32632256], [72.9210968, 24.32723999], [72.91557312, 24.33280945], [72.91002655, 24.34049988], [72.90055847, 24.35144806], [72.8842926, 24.36084938], [72.86811829, 24.36581039], [72.85367584, 24.36601067], [72.83905029, 24.36478043], [72.82924652, 24.36498833], [72.81534576, 24.35819054], [72.79325104, 24.36016083], [72.77282715, 24.36074066], [72.74871826, 24.35752106], [72.73928833, 24.35884094], [72.73253632, 24.3612709], [72.71747589, 24.37555122], [72.70664215, 24.39133263], [72.69346619, 24.41928101], [72.69264221, 24.4414196], [72.69753265, 24.452631], [72.69725037, 24.45721054], [72.69301605, 24.46016121], [72.68460846, 24.45919991], [72.67443085, 24.45696259], [72.658638, 24.45643044], [72.63932037, 24.46146011], [72.60412598, 24.46910858], [72.58850098, 24.47250175], [72.5823822, 24.47746086], [72.57422638, 24.48814011], [72.55914307, 24.49464035], [72.55181122, 24.50032806], [72.54772186, 24.50559235], [72.54457855, 24.5068512], [72.54213715, 24.50486946], [72.51877594, 24.47299194], [72.51387787, 24.46455956], [72.51174164, 24.4473896], [72.50055695, 24.45029068], [72.50441742, 24.43089104], [72.51000214, 24.41834259], [72.50771332, 24.40993118], [72.50099945, 24.4073391], [72.48744202, 24.4054203], [72.4646759, 24.40711975], [72.46375275, 24.42094994], [72.46127319, 24.42685127], [72.45761871, 24.43285179], [72.45623779, 24.43812943], [72.44616699, 24.44826126], [72.43667603, 24.46051025], [72.43863678, 24.47907257], [72.44558716, 24.4877491], [72.44815063, 24.49332047], [72.44561005, 24.49962044], [72.44248962, 24.50424957], [72.4360199, 24.50536919], [72.4260025, 24.50832939], [72.42111206, 24.50806808], [72.39772034, 24.50028038], [72.39052582, 24.49884987], [72.38632202, 24.50051117], [72.37088013, 24.52876091], [72.37486267, 24.5299511], [72.37523651, 24.53164291], [72.37419891, 24.53354073], [72.373909, 24.53735924], [72.36860657, 24.5365181], [72.36546326, 24.53934097], [72.3615799, 24.54331017], [72.35793304, 24.55251122], [72.34860992, 24.55348969], [72.34327698, 24.55496979], [72.34057617, 24.55751038], [72.3348999, 24.55867958], [72.33362579, 24.55583954], [72.33701324, 24.5441494], [72.33241272, 24.54244041], [72.30182648, 24.54055977], [72.29512024, 24.5384407], [72.29338837, 24.53999138], [72.29393005, 24.54491043], [72.29191589, 24.55046082], [72.29170227, 24.55528069], [72.29003906, 24.55828094], [72.28508759, 24.55743027], [72.27168274, 24.55015945], [72.25099945, 24.58016014], [72.27671051, 24.59918022], [72.27925873, 24.60000038], [72.29305267, 24.59708977], [72.30033112, 24.60015106], [72.30458069, 24.59727287], [72.30890656, 24.5908699], [72.31402588, 24.58539009], [72.31784821, 24.58496094], [72.3259964, 24.58686066], [72.34221649, 24.59352112], [72.34546661, 24.59945107], [72.34915161, 24.60231018], [72.34896851, 24.61199188], [72.35011292, 24.6146698], [72.35309601, 24.61624908], [72.35378265, 24.61810112], [72.34797668, 24.62132263], [72.34020233, 24.62298965], [72.33100891, 24.61188126], [72.3237381, 24.60894012], [72.31505585, 24.60887146], [72.30932617, 24.6119709], [72.30619812, 24.61497116], [72.29969788, 24.61619949], [72.29366302, 24.61320114], [72.27474976, 24.62223053], [72.27414703, 24.62214279], [72.26059723, 24.62074089], [72.25421906, 24.62138939], [72.24893188, 24.62078094], [72.24202728, 24.62334061], [72.23362732, 24.63080978], [72.2299881, 24.63288116], [72.21637726, 24.62021255], [72.21096802, 24.61901093], [72.20828247, 24.61725044], [72.21063995, 24.61256981], [72.20697021, 24.61207008], [72.20144653, 24.6161499], [72.18589783, 24.60943031], [72.17559052, 24.61271095], [72.16539764, 24.61450005], [72.16166687, 24.61581039], [72.16101074, 24.61944962], [72.15357971, 24.63110924], [72.15072632, 24.63410187], [72.14595032, 24.63487053], [72.13475037, 24.63380051], [72.12529755, 24.63163948], [72.12100983, 24.63196182], [72.11654663, 24.63336945], [72.10186005, 24.64333916], [72.09091187, 24.64869118], [72.0848999, 24.65275192], [72.08547974, 24.65872002], [72.08239746, 24.66847038], [72.0923233, 24.67476082], [72.08525085, 24.69700813], [72.07958221, 24.70033836], [72.05249023, 24.70578957], [72.04087067, 24.69547081], [72.03161621, 24.69181061], [72.00730896, 24.68598175], [72.001091, 24.68297005], [71.99407959, 24.67755127], [71.98987579, 24.66704941], [71.99339294, 24.65670967], [71.99324799, 24.65312958], [71.99077606, 24.65139961], [71.98282623, 24.65085983], [71.97914886, 24.64696121], [71.96740723, 24.63793945], [71.96218109, 24.63845062], [71.95079041, 24.6325798], [71.94744873, 24.62758064], [71.94419098, 24.62677956], [71.93952179, 24.62760162], [71.93450928, 24.62685013], [71.92800903, 24.63381195], [71.91879272, 24.64620018], [71.91723633, 24.65089035], [71.92137909, 24.65223122], [71.92405701, 24.65448189], [71.92597961, 24.65871048], [71.92592621, 24.66208267], [71.92008209, 24.66735077], [71.91210175, 24.66959953], [71.90416718, 24.66904068], [71.89379883, 24.6657505], [71.89095306, 24.67008972], [71.8813324, 24.67567062], [71.87647247, 24.67515945], [71.87110138, 24.67221832], [71.86495972, 24.66291046], [71.86276245, 24.65475273], [71.86255646, 24.64948082], [71.867836, 24.63002014], [71.86868286, 24.62347984], [71.86470032, 24.6195507], [71.8609314, 24.61405945], [71.85839081, 24.60416985], [71.85553741, 24.60609055], [71.84657288, 24.61486053], [71.83860779, 24.61638069], [71.82141113, 24.61658096], [71.8155365, 24.61832809], [71.81176758, 24.62182045], [71.81153107, 24.62593079], [71.81259155, 24.63252068], [71.81738281, 24.64587975], [71.81508636, 24.65468025], [71.81292725, 24.66087914], [71.80912781, 24.66592026], [71.80459595, 24.66905975], [71.79898834, 24.67052078], [71.79094696, 24.67012024], [71.78450775, 24.66885948], [71.75830841, 24.66027069], [71.74577332, 24.65427971], [71.73734283, 24.65344048], [71.71631622, 24.6543293], [71.68599701, 24.63984108], [71.66977692, 24.6365509], [71.66156006, 24.63326073], [71.65027618, 24.63993073], [71.65122223, 24.64315987], [71.64836121, 24.64640999], [71.64494324, 24.65254021], [71.64057159, 24.65608025], [71.6341629, 24.65805054], [71.6307373, 24.66255951], [71.62711334, 24.66193008], [71.62338257, 24.66424942], [71.62081909, 24.66698265], [71.61833191, 24.66836166], [71.61659241, 24.670681], [71.61003876, 24.66854095], [71.60486603, 24.66553116], [71.59783173, 24.66385078], [71.592453, 24.66558838], [71.58965302, 24.67016983], [71.58309937, 24.67653084], [71.57717896, 24.67740059], [71.5684433, 24.67352104], [71.55142212, 24.67063141], [71.54364014, 24.67358017], [71.53697205, 24.67892075], [71.52731323, 24.67716026], [71.52275085, 24.67526054], [71.52092743, 24.67548943], [71.51618958, 24.67634964], [71.50353241, 24.67380905], [71.4883194, 24.67385101], [71.47424316, 24.66320038], [71.4668808, 24.66076279], [71.45889282, 24.66127968], [71.45146942, 24.65884018], [71.4453125, 24.65397072], [71.43241882, 24.64616013], [71.42897034, 24.64256096], [71.42230988, 24.63810158], [71.41295624, 24.63531113], [71.40703583, 24.63467026], [71.40280151, 24.63153076], [71.39962769, 24.62696075], [71.39451599, 24.62701035], [71.38977051, 24.6282196], [71.38835144, 24.62393951], [71.38305664, 24.62168121], [71.3807373, 24.62138176], [71.37518311, 24.62305069], [71.37269592, 24.62576103], [71.36765289, 24.62726021], [71.36702728, 24.63190079], [71.36196899, 24.64160919], [71.35671234, 24.65405083], [71.35103607, 24.65321922], [71.34276581, 24.6482296], [71.32649231, 24.64292908], [71.32164001, 24.64031982], [71.31777191, 24.63591957], [71.31006622, 24.62108994], [71.30745697, 24.61987114], [71.29773712, 24.60764122], [71.28714752, 24.61271095], [71.26095581, 24.62053108], [71.25298309, 24.62363052], [71.24154663, 24.6266098], [71.23789215, 24.62850952], [71.2073288, 24.63954926], [71.19709778, 24.64292908], [71.17164612, 24.64886093], [71.14673615, 24.65801048], [71.11927795, 24.66864967], [71.11334229, 24.67362976], [71.10713959, 24.68065071], [71.10040283, 24.68333817], [71.08651733, 24.6978302], [71.077034, 24.70766068], [71.07285309, 24.71199989], [71.07177734, 24.71487427], [71.06276703, 24.73892975], [71.06231689, 24.73971939], [71.06095123, 24.74217987], [71.05381012, 24.75551033], [71.05029297, 24.7606411], [71.03530884, 24.7987709], [71.0235672, 24.82118034], [71.01243591, 24.83587074], [71.01111603, 24.83854103], [71.00955963, 24.84165001], [71.0039978, 24.85289192], [70.98957062, 24.87247086], [70.98532104, 24.87718964], [70.97865295, 24.88972282], [70.96190643, 24.90824127], [70.95625305, 24.91440964], [70.94548798, 24.9345417], [70.93260956, 24.97347069], [70.92560577, 24.99471092], [70.91467285, 25.04155159], [70.91372681, 25.04552078], [70.91203308, 25.05788994], [70.90538025, 25.09503174], [70.90013123, 25.11969185], [70.89431, 25.14405823], [70.88456726, 25.15357971], [70.87477875, 25.16321945], [70.8608017, 25.17575073], [70.85597229, 25.18218994], [70.85423279, 25.18377113], [70.80934906, 25.2237606], [70.79618835, 25.2397728], [70.79560089, 25.24027061], [70.79353333, 25.24205971], [70.76644897, 25.2649498], [70.75905609, 25.27495956], [70.75354767, 25.29630089], [70.7442627, 25.320961], [70.73226929, 25.33476257], [70.72315216, 25.34514999], [70.7059021, 25.36009026], [70.70194244, 25.3640995], [70.68704987, 25.37829018], [70.67871094, 25.38535118], [70.67668152, 25.38710022], [70.67572021, 25.38711357], [70.67562866, 25.38719368], [70.67417145, 25.38932037], [70.67366028, 25.39495087], [70.6762619, 25.40108109], [70.67899323, 25.41175079], [70.67974091, 25.41650963], [70.67957306, 25.44745064], [70.6829071, 25.47352028], [70.68499756, 25.48952293], [70.68521118, 25.50340271], [70.68596649, 25.51066017], [70.68553925, 25.51120186], [70.68786621, 25.51734924], [70.68773651, 25.51823044], [70.68551636, 25.51921082], [70.67621613, 25.52387047], [70.6765213, 25.53107071], [70.67662048, 25.53256035], [70.67585754, 25.53309059], [70.67685699, 25.53334999], [70.67693329, 25.53518295], [70.67694092, 25.53614616], [70.67727661, 25.5886898], [70.67735291, 25.59049034], [70.67935181, 25.61403084], [70.67986298, 25.6198101], [70.6799469, 25.62203789], [70.68035889, 25.6325531], [70.68090057, 25.64641953], [70.68110657, 25.65213966], [70.68113708, 25.66076088], [70.67613983, 25.68029022], [70.67328644, 25.68535614], [70.67292786, 25.68600082], [70.66596222, 25.69722939], [70.66079712, 25.70112038], [70.65921783, 25.7017498], [70.65891266, 25.70191765], [70.65542603, 25.70378113], [70.64885712, 25.70590019], [70.64686584, 25.70654106], [70.64395905, 25.70658112], [70.64247894, 25.70587921], [70.63842773, 25.70675087], [70.63085938, 25.70672035], [70.61705017, 25.70663071], [70.60170746, 25.70325089], [70.57470703, 25.69058037], [70.5657959, 25.68638992], [70.53705597, 25.67700958], [70.53623199, 25.67673111], [70.53277588, 25.67618942], [70.49030304, 25.67596054], [70.47035217, 25.67436981], [70.4597702, 25.67346954], [70.42533875, 25.66957092], [70.40879822, 25.66627121], [70.3996582, 25.66379929], [70.39443207, 25.6641407], [70.39229584, 25.66460037], [70.37520599, 25.66846085], [70.36567688, 25.67169952], [70.28526306, 25.69893074], [70.27961731, 25.70125961], [70.27594757, 25.70342064], [70.27231598, 25.7087307], [70.26964569, 25.71651649], [70.26726532, 25.72345352], [70.26078796, 25.74230957], [70.24639893, 25.76348877], [70.24450684, 25.76626968], [70.244133, 25.76666832], [70.24249268, 25.76838112], [70.23620605, 25.77494621], [70.22379303, 25.78791046], [70.20671844, 25.80229187], [70.20321655, 25.80524063], [70.17796326, 25.81949997], [70.17144775, 25.83228874], [70.1663208, 25.84235954], [70.16536713, 25.84423065], [70.16150665, 25.84887123], [70.15473938, 25.85874939], [70.15392303, 25.86027527], [70.14501953, 25.86852264], [70.1416626, 25.87537956], [70.10668182, 25.92420959], [70.09737396, 25.94186592], [70.09607697, 25.94431686], [70.09130096, 25.96515846], [70.09111023, 25.98373795], [70.09098053, 25.99682236], [70.08656311, 26.03120804], [70.08045197, 26.05823708], [70.08257294, 26.07385826], [70.08604431, 26.08214951], [70.09427643, 26.09736252], [70.12638855, 26.13938522], [70.13728333, 26.15489769], [70.14519501, 26.16615486], [70.1594162, 26.19448853], [70.16163635, 26.20185089], [70.16725922, 26.22387505], [70.17266846, 26.24507713], [70.17222595, 26.24832916], [70.17076111, 26.25906372], [70.16681671, 26.27257347], [70.16524506, 26.2771492], [70.16460419, 26.29091644], [70.16674042, 26.3069973], [70.17830658, 26.3497715], [70.17790222, 26.36583519], [70.17933655, 26.37525558], [70.17848969, 26.38442993], [70.17804718, 26.40416336], [70.17599487, 26.4332962], [70.18099976, 26.46959877], [70.18389893, 26.48683357], [70.18225861, 26.49852562], [70.17854309, 26.51410294], [70.17273712, 26.53494453], [70.1678009, 26.55056], [70.16773987, 26.5507431], [70.16051483, 26.55895424], [70.15022278, 26.56828499], [70.13893127, 26.57439613], [70.10688019, 26.58952141], [70.08843994, 26.59556961], [70.06619263, 26.59929085], [70.04782104, 26.59913635], [70.0404129, 26.59953308], [70.02484894, 26.59871101], [70.0, 26.59449768], [69.996315, 26.59387207], [69.95478058, 26.58730316], [69.91834259, 26.58260345], [69.91094208, 26.58230591], [69.87931061, 26.58108521], [69.85555267, 26.58292007], [69.83175659, 26.58773422], [69.81536102, 26.59215736], [69.79483795, 26.59998322], [69.77194214, 26.61374664], [69.74327087, 26.63846397], [69.72187042, 26.65384293], [69.69898224, 26.66506958], [69.68975067, 26.66795158], [69.67665863, 26.6726265], [69.60830688, 26.70030975], [69.60184479, 26.70505524], [69.59210205, 26.70723724], [69.58053589, 26.71191978], [69.57460785, 26.71552467], [69.55044556, 26.72464561], [69.52241516, 26.73601151], [69.51544952, 26.74005508], [69.51135254, 26.74446678], [69.50765228, 26.74845123], [69.48751068, 26.7936554], [69.48443604, 26.80388832], [69.48373413, 26.80623055], [69.48387909, 26.80763817], [69.48551178, 26.82346916], [69.4957428, 26.87249184], [69.50093842, 26.9003315], [69.50359344, 26.94329071], [69.51287842, 27.01438141], [69.51320648, 27.01686859], [69.53726196, 27.06927299], [69.54020691, 27.07757187], [69.5426178, 27.08334923], [69.55678558, 27.11725426], [69.56483459, 27.1375885], [69.56518555, 27.13847542], [69.578125, 27.1654892], [69.58666229, 27.17798424], [69.60060883, 27.18939781], [69.60363007, 27.1931057], [69.66594696, 27.25143623], [69.69870758, 27.27773857], [69.70013428, 27.27867126], [69.72467804, 27.29477692], [69.79387665, 27.34646225], [69.81254578, 27.35961151], [69.83253479, 27.3787632], [69.84881592, 27.39292717], [69.86196899, 27.40277863], [69.90762329, 27.45957756], [69.92113495, 27.47939873], [69.93624878, 27.50210762], [70.0, 27.54504204], [70.01626587, 27.55599594], [70.02456665, 27.5696907], [70.05142212, 27.63533974], [70.08312988, 27.70836639], [70.10781097, 27.76687241], [70.1569519, 27.83404922], [70.18078613, 27.8551445], [70.18127441, 27.85557938], [70.20716858, 27.88489914], [70.20759583, 27.88538361], [70.28133392, 27.93042374], [70.30290985, 27.94617271], [70.32187653, 27.96488953], [70.33289337, 27.97712326], [70.33646393, 27.98311424], [70.36616516, 28.00824928], [70.40859985, 28.0172863], [70.43235779, 28.02154922], [70.4597168, 28.02950287], [70.47908783, 28.03373718], [70.48375702, 28.03401184], [70.50983429, 28.03554344], [70.53033447, 28.03248787], [70.5626297, 28.01980209], [70.58232117, 28.00265884], [70.59876251, 27.98834229], [70.60411072, 27.98344994], [70.61162567, 27.97656822], [70.61174774, 27.97646141], [70.61607361, 27.97250175], [70.62825775, 27.96135521], [70.65086365, 27.93985558], [70.66069794, 27.93050194], [70.67210388, 27.91431808], [70.67284393, 27.86979294], [70.67577362, 27.85098076], [70.67841339, 27.8390522], [70.6879425, 27.82188988], [70.68935394, 27.8193512], [70.69818115, 27.80767822], [70.70311737, 27.80035019], [70.70438385, 27.79647827], [70.70521545, 27.79393387], [70.71431732, 27.77950287], [70.71484375, 27.77628708], [70.72158813, 27.76896667], [70.72575378, 27.76025963], [70.73795319, 27.74216652], [70.74073792, 27.73894882], [70.74080658, 27.73886871], [70.75143433, 27.72660065], [70.75766754, 27.71720886], [70.76721191, 27.71494293], [70.76904297, 27.71483231], [70.76967621, 27.71449089], [70.78881836, 27.71001053], [70.8013382, 27.70812035], [70.81899261, 27.70426941], [70.84137726, 27.70333099], [70.85793304, 27.70220947], [70.86958313, 27.70070076], [70.87137604, 27.70020103], [70.88345337, 27.69850159], [70.88417053, 27.6984005], [70.89795685, 27.70022964], [70.90686035, 27.70063972], [70.94995117, 27.71883965], [70.95175171, 27.71959114], [70.96156311, 27.7227211], [70.96969604, 27.72654915], [70.98433685, 27.7342205], [71.03398895, 27.75726128], [71.05593109, 27.76391029], [71.07047272, 27.76834106], [71.08701324, 27.77679253], [71.12506104, 27.79225159], [71.13994598, 27.79829979], [71.1736908, 27.81199074], [71.18379211, 27.81441116], [71.20865631, 27.82435036], [71.23013306, 27.82878113], [71.23379517, 27.83000374], [71.24267578, 27.83296967], [71.25521851, 27.83704948], [71.27295685, 27.84192848], [71.32578278, 27.85174942], [71.34189606, 27.85472107], [71.38105011, 27.86193085], [71.409729, 27.86578941], [71.4126358, 27.86520767], [71.41876221, 27.86398125], [71.44787598, 27.86605263], [71.49971008, 27.86557007], [71.52362823, 27.86535072], [71.53079987, 27.86530113], [71.54905701, 27.86623001], [71.58657837, 27.87030029], [71.6044693, 27.86815071], [71.62077332, 27.86838913], [71.64443207, 27.86873055], [71.65828705, 27.86893082], [71.66394043, 27.87265015], [71.68099213, 27.87723923], [71.69803619, 27.88256264], [71.7199173, 27.89157104], [71.74344635, 27.90061951], [71.7596283, 27.90730286], [71.76560974, 27.90994072], [71.82628632, 27.93048096], [71.85851288, 27.94140053], [71.89311218, 27.95511055], [71.89630127, 27.95684052], [71.89737701, 27.95742035], [71.90154266, 27.96899033], [71.90361023, 27.98343277], [71.90547943, 27.99745178], [71.90867615, 28.01393127], [71.91194916, 28.02614975], [71.91253662, 28.03467941], [71.91316223, 28.03832817], [71.91236115, 28.04807091], [71.91569519, 28.0589447], [71.91760254, 28.06517029], [71.92021942, 28.07555008], [71.92207336, 28.09140015], [71.92530823, 28.10544968], [71.92790985, 28.11462021], [71.93057251, 28.12195015], [71.93325806, 28.12685966], [71.94265747, 28.13973808], [71.95347595, 28.15266991], [71.96604156, 28.16526031], [71.97484589, 28.17822075], [71.99588013, 28.20695686], [72.00543976, 28.2154007], [72.01911163, 28.22663116], [72.02536011, 28.23110962], [72.04427338, 28.24346161], [72.06626129, 28.26082993], [72.09078979, 28.2784996], [72.09253693, 28.27954292], [72.09375763, 28.28026962], [72.0981369, 28.28285027], [72.10856628, 28.28989029], [72.12612915, 28.30350113], [72.13633728, 28.31485939], [72.15092468, 28.33109283], [72.15612793, 28.33688164], [72.18442535, 28.35800552], [72.19802856, 28.3813858], [72.20228577, 28.38525963], [72.20358276, 28.38845062], [72.20710754, 28.3969841], [72.20884705, 28.39998245], [72.23577118, 28.47483635], [72.24324799, 28.49635506], [72.24437714, 28.50575638], [72.24935913, 28.51076698], [72.25341797, 28.52703285], [72.27961731, 28.60142136], [72.2855072, 28.61881828], [72.30195618, 28.6648159], [72.32628632, 28.69889259], [72.34435272, 28.71603966], [72.34638977, 28.72047806], [72.36579132, 28.74187088], [72.37506104, 28.75210762], [72.3783493, 28.75574112], [72.38469696, 28.76394081], [72.38996887, 28.76801491], [72.40273285, 28.77787971], [72.40957642, 28.78084946], [72.43093109, 28.7885704], [72.44657135, 28.79315948], [72.45922089, 28.79922104], [72.46811676, 28.80252075], [72.48480988, 28.81042099], [72.50382996, 28.82028961], [72.51985168, 28.82860947], [72.54417419, 28.84358025], [72.5515976, 28.84815025], [72.58792877, 28.86601067], [72.59012604, 28.86734962], [72.59153748, 28.86804962], [72.64351654, 28.89910126], [72.65065002, 28.90335083], [72.65841675, 28.90690041], [72.6665802, 28.91192055], [72.66838837, 28.91282082], [72.67177582, 28.91378975], [72.6745224, 28.91629982], [72.71129608, 28.93502998], [72.74143982, 28.94829941], [72.78582001, 28.96537018], [72.78970337, 28.96686172], [72.84401703, 28.9877224], [72.8454361, 28.9883194], [72.84599304, 28.98855972], [72.84880829, 28.98990059], [72.86197662, 28.99623108], [72.88774109, 29.00370026], [72.89898682, 29.00938988], [72.91279602, 29.01438141], [72.9282074, 29.01993942], [72.93551636, 29.02294922], [72.93943787, 29.02524185], [72.94069672, 29.02627945], [72.94171906, 29.0272007], [72.9437561, 29.02991104], [72.95053864, 29.04591942], [72.95361328, 29.05317116], [72.95806885, 29.06110954], [72.96061707, 29.06810951], [72.97570801, 29.09918022], [72.97878265, 29.10707092], [72.98335266, 29.11388969], [72.98397827, 29.11478233], [72.9850769, 29.11634827], [72.98565674, 29.11764908], [72.98587036, 29.11857033], [72.99981689, 29.14652252], [73.00003052, 29.14736557], [73.01570892, 29.16432953], [73.02033997, 29.16818047], [73.02416229, 29.17402077], [73.03180695, 29.18342209], [73.03553772, 29.18801117], [73.03664398, 29.18886757], [73.04013824, 29.19157028], [73.05516815, 29.20714188], [73.05636597, 29.20850945], [73.07846069, 29.23340034], [73.07946777, 29.23483086], [73.08434296, 29.24192429], [73.08927155, 29.24909019], [73.09229279, 29.25377274], [73.09844208, 29.26575089], [73.10153198, 29.2725296], [73.10943604, 29.28273964], [73.10991669, 29.28466988], [73.11221313, 29.28932953], [73.11392212, 29.29212952], [73.11470032, 29.29269028], [73.11524963, 29.29356194], [73.11524963, 29.29467964], [73.1370163, 29.32930946], [73.13957214, 29.33542061], [73.14686584, 29.34988976], [73.15101624, 29.35724831], [73.15735626, 29.3678112], [73.16900635, 29.38599968], [73.16982269, 29.38755035], [73.17103577, 29.389431], [73.19129181, 29.42856979], [73.20236206, 29.44190979], [73.22164154, 29.47943115], [73.22315979, 29.48034096], [73.22381592, 29.48200035], [73.22751617, 29.48661995], [73.22815704, 29.48834038], [73.2324295, 29.49299812], [73.23810577, 29.50611115], [73.24295807, 29.51247978], [73.24759674, 29.52086067], [73.26213837, 29.54120064], [73.26341248, 29.54316139], [73.27131653, 29.55696106], [73.27488708, 29.56666946], [73.28392029, 29.59768295], [73.2859726, 29.60463905], [73.29760742, 29.63355064], [73.31202698, 29.68622017], [73.31257629, 29.68761063], [73.31478882, 29.69145012], [73.31523132, 29.69299126], [73.31607819, 29.6944809], [73.31732941, 29.69895172], [73.32546234, 29.72772026], [73.32669067, 29.73106766], [73.32772827, 29.73220062], [73.3336792, 29.74969101], [73.33571625, 29.75759125], [73.34030914, 29.76885033], [73.34568787, 29.79204941], [73.34957123, 29.80516052], [73.35430908, 29.81760979], [73.35869598, 29.83613968], [73.36582184, 29.85284042], [73.37146759, 29.87400055], [73.38539886, 29.92601967], [73.39137268, 29.93787003], [73.39924622, 29.94341087], [73.40738678, 29.94688606], [73.41280365, 29.94919968], [73.46694183, 29.96907806], [73.53329468, 29.99363518], [73.53985596, 29.9953804], [73.54685211, 29.99865341], [73.56176758, 30.00563049], [73.57958221, 30.01172066], [73.5994873, 30.01853943], [73.61118317, 30.02240944], [73.65339661, 30.03120041], [73.67189026, 30.03693008], [73.67843628, 30.0389595], [73.70915985, 30.04712105], [73.75398254, 30.05653954], [73.78721619, 30.06640053], [73.79408264, 30.06965828], [73.80046082, 30.07639122], [73.80632019, 30.08250046], [73.83770752, 30.10870171], [73.84842682, 30.11609077], [73.85430145, 30.12026024], [73.87255859, 30.13231087], [73.88349152, 30.13885117], [73.89550018, 30.14941025], [73.90392303, 30.15500069], [73.92346954, 30.16789818], [73.95796204, 30.18574715], [73.96631622, 30.19504929], [73.96640778, 30.19449425], [73.96810913, 30.18429947], [73.96643829, 30.17703056], [73.96337128, 30.17182922], [73.96082306, 30.14323044], [73.96118164, 30.13422966], [73.96247101, 30.12750053], [73.96393585, 30.12438011], [73.96665192, 30.12118912], [73.95794678, 30.11956024], [73.94998932, 30.1097908], [73.94410706, 30.10423088], [73.94291687, 30.09909058], [73.93152618, 30.08381081], [73.91821289, 30.06814957], [73.90854645, 30.06011009], [73.89840698, 30.0536499], [73.89480591, 30.0468502], [73.89261627, 30.03853035], [73.88551331, 30.01742935], [73.88186646, 30.01124001], [73.8811264, 29.99628067], [73.88302612, 29.99129105], [73.8884964, 29.9817791], [73.88944244, 29.97760963], [73.89118195, 29.97006989], [73.93295288, 29.97074127], [73.9569397, 29.96951294], [73.97646332, 29.96911049], [73.99092102, 29.97122955], [73.9960022, 29.97089005], [74.00274658, 29.97006035], [74.06919861, 29.96887016], [74.08332825, 29.96737289], [74.15444946, 29.96329117], [74.18596649, 29.96038055], [74.21276093, 29.96039009], [74.22380066, 29.95971107], [74.24067688, 29.95628929], [74.25190735, 29.95525932], [74.26030731, 29.9556694], [74.27902985, 29.95508957], [74.2899704, 29.95626068], [74.32151031, 29.95396042], [74.35585022, 29.95033073], [74.37245178, 29.95001984], [74.40379333, 29.94734001], [74.42807007, 29.94954109], [74.44197845, 29.94708824], [74.44403839, 29.94672012], [74.46660614, 29.94467926], [74.51906586, 29.94334984], [74.51278687, 29.93003845], [74.50502777, 29.90776062], [74.51091003, 29.90429115], [74.5255127, 29.90256119], [74.53369141, 29.90262032], [74.54345703, 29.88871956], [74.54521942, 29.88072968], [74.55179596, 29.8735199], [74.55356598, 29.86564064], [74.54747009, 29.85692024], [74.53253174, 29.83928108], [74.50588989, 29.83258057], [74.4916687, 29.82650948], [74.48060608, 29.8152504], [74.4705658, 29.80200005], [74.46526337, 29.78754997], [74.46911621, 29.75823975], [74.47200012, 29.74403], [74.48319244, 29.74403], [74.49680328, 29.74182129], [74.51155853, 29.7406826], [74.52583313, 29.74136925], [74.53185272, 29.74934959], [74.53778839, 29.75386047], [74.54933167, 29.7548008], [74.56402588, 29.75461006], [74.57139587, 29.75324821], [74.57816315, 29.76696014], [74.5866394, 29.76851082], [74.59253693, 29.76671982], [74.59751129, 29.75797081], [74.60540009, 29.7528801], [74.60598755, 29.7466507], [74.60161591, 29.74066925], [74.60347748, 29.72142982], [74.60037994, 29.71310806], [74.59902954, 29.70621109], [74.59287262, 29.70071983], [74.59387207, 29.69143295], [74.59085083, 29.68272018], [74.58513641, 29.67502975], [74.57852173, 29.65475273], [74.58203888, 29.64406967], [74.58603668, 29.63525963], [74.58127594, 29.63054085], [74.57536316, 29.62732124], [74.57699585, 29.62082291], [74.57467651, 29.6144104], [74.57028198, 29.58591843], [74.57060242, 29.56854057], [74.56653595, 29.56349945], [74.57174683, 29.55558014], [74.58178711, 29.54768944], [74.59117889, 29.54342079], [74.5994873, 29.53686905], [74.61142731, 29.53149986], [74.61440277, 29.52711105], [74.61168671, 29.52000809], [74.60452271, 29.51044083], [74.60074615, 29.50354958], [74.592659, 29.49212265], [74.59030914, 29.48612976], [74.59156036, 29.47985077], [74.58553314, 29.4689827], [74.58042145, 29.46349907], [74.57891083, 29.45862007], [74.57170868, 29.46230125], [74.55947113, 29.46437073], [74.55037689, 29.46447945], [74.54280853, 29.4665699], [74.53462982, 29.46503258], [74.53074646, 29.45754814], [74.52910614, 29.44953918], [74.52955627, 29.43499947], [74.53129578, 29.42498016], [74.5411377, 29.42314911], [74.5521698, 29.42240143], [74.55780792, 29.4186306], [74.56439972, 29.41077995], [74.57003021, 29.40615845], [74.56909943, 29.39730072], [74.57289886, 29.38644981], [74.57978058, 29.37873077], [74.59053802, 29.37067032], [74.59671783, 29.36219025], [74.60003662, 29.35433006], [74.59577942, 29.32831192], [74.60603333, 29.3275795], [74.64182281, 29.33119965], [74.64412689, 29.33534813], [74.64370728, 29.35440063], [74.650177, 29.37236977], [74.65851593, 29.36997986], [74.67601776, 29.36817169], [74.68868256, 29.36515999], [74.71124268, 29.36890984], [74.71688843, 29.36635971], [74.72255707, 29.36084938], [74.73169708, 29.35378838], [74.75663757, 29.35596085], [74.77591705, 29.36015129], [74.78578186, 29.37054062], [74.79878235, 29.38465118], [74.80954742, 29.39847946], [74.8351059, 29.40147972], [74.84113312, 29.4040699], [74.84951782, 29.40279007], [74.85719299, 29.39937019], [74.86393738, 29.39635086], [74.86656952, 29.38846016], [74.87058258, 29.38511276], [74.88848114, 29.38667107], [74.89530945, 29.3841095], [74.89907074, 29.3782196], [74.91021729, 29.37115288], [74.92196655, 29.36603165], [74.92714691, 29.36463928], [74.93592072, 29.33794975], [74.94608307, 29.33280945], [74.95096588, 29.32607079], [74.95056915, 29.31851006], [74.94584656, 29.31102753], [74.94010925, 29.30481911], [74.94256592, 29.29518127], [74.94753265, 29.28815842], [74.95310974, 29.28194046], [74.95996094, 29.28015137], [74.96806335, 29.28244019], [74.97690582, 29.28111839], [74.98291779, 29.27826118], [74.99104309, 29.2717495], [75.005867, 29.28380966], [75.02385712, 29.29153061], [75.03991699, 29.28714943], [75.05047607, 29.2723999], [75.05066681, 29.26888084], [75.05094147, 29.26371193], [75.06062317, 29.25331116], [75.06532288, 29.24661064], [75.06270599, 29.23892021], [75.07807922, 29.23245049], [75.09250641, 29.22911263], [75.10817719, 29.2267704], [75.11374664, 29.24290085], [75.12467194, 29.24496078], [75.1474762, 29.24584961], [75.16082001, 29.25374985], [75.16401672, 29.2643795], [75.17999268, 29.26861954], [75.18850708, 29.25863075], [75.1953125, 29.24422073], [75.21195984, 29.2345295], [75.22345734, 29.23495102], [75.23522949, 29.25193977], [75.24946594, 29.25646019], [75.27172852, 29.25436974], [75.27671814, 29.27345085], [75.27937317, 29.27682114], [75.28968811, 29.27770042], [75.29969025, 29.28198051], [75.30857849, 29.28891754], [75.31926727, 29.29343987], [75.32424927, 29.29018974], [75.32537079, 29.27831078], [75.32318115, 29.25175095], [75.31492615, 29.23596001], [75.33454132, 29.22883034], [75.3453064, 29.22616005], [75.34719849, 29.23011971], [75.35016632, 29.24738121], [75.35797882, 29.25461006], [75.37246704, 29.26003075], [75.37954712, 29.26393127], [75.3879776, 29.2643528], [75.39570618, 29.26194], [75.39868927, 29.25498962], [75.39968109, 29.24677849], [75.39936829, 29.24027061], [75.3936615, 29.23423958], [75.38729858, 29.22904015], [75.38611603, 29.2212429], [75.39229584, 29.21807098], [75.39646149, 29.21342087], [75.39985657, 29.20148277], [75.40065002, 29.18890953], [75.39438629, 29.17427063], [75.38857269, 29.17070007], [75.37845612, 29.17152023], [75.36895752, 29.16995811], [75.36763, 29.15042114], [75.36115265, 29.14262009], [75.37380981, 29.13706017], [75.38508606, 29.134161], [75.39620972, 29.12844086], [75.39134216, 29.11931992], [75.38069916, 29.11071968], [75.38130188, 29.10256958], [75.38315582, 29.09537125], [75.3813858, 29.08967018], [75.38218689, 29.08359909], [75.38065338, 29.07032013], [75.39025116, 29.06822968], [75.4302597, 29.06472015], [75.42975616, 29.05617905], [75.4375, 29.05047989], [75.44055939, 29.04152107], [75.43264008, 29.02206993], [75.43473816, 29.01654053], [75.4586792, 29.02015114], [75.47342682, 29.02020073], [75.48362732, 29.01885033], [75.50511932, 29.01515007], [75.51110077, 29.01082993], [75.51107025, 29.00414085], [75.51113892, 29.00332069], [75.51525116, 28.99105072], [75.51651764, 28.97538948], [75.50891876, 28.9657383], [75.50293732, 28.96148109], [75.50354767, 28.95182037], [75.49756622, 28.94148827], [75.46888733, 28.93799019], [75.46707916, 28.92625046], [75.48462677, 28.90166092], [75.48842621, 28.89831924], [75.48799133, 28.85964966], [75.49771881, 28.85618973], [75.49915314, 28.85036087], [75.50267792, 28.84597969], [75.51049805, 28.84342003], [75.5133667, 28.83658981], [75.50878906, 28.81529045], [75.50312042, 28.80928993], [75.50392151, 28.79673958], [75.49854279, 28.7876606], [75.50502777, 28.78279114], [75.51608276, 28.77222824], [75.5219574, 28.7561512], [75.52892303, 28.75028038], [75.52603149, 28.74291992], [75.53093719, 28.73282051], [75.53148651, 28.71729088], [75.53547668, 28.68839073], [75.53663635, 28.68217087], [75.53980255, 28.67601967], [75.53793335, 28.66128922], [75.54071808, 28.65527916], [75.53956604, 28.64887047], [75.54901123, 28.64312172], [75.55570984, 28.6145916], [75.57699585, 28.61667061], [75.58495331, 28.60638046], [75.60933685, 28.60588074], [75.61804962, 28.60220909], [75.62001801, 28.59922981], [75.61904907, 28.58872986], [75.6252594, 28.55850983], [75.62909698, 28.54597092], [75.63665009, 28.54751015], [75.64351654, 28.54290962], [75.65355682, 28.54057121], [75.66333008, 28.53611183], [75.6654892, 28.53327942], [75.6639328, 28.52086067], [75.6710968, 28.51692963], [75.69007874, 28.49909973], [75.70069122, 28.49533081], [75.72395325, 28.49129295], [75.73654938, 28.48720169], [75.73500061, 28.47264099], [75.74713898, 28.46937943], [75.77822876, 28.45761108], [75.78515625, 28.45074081], [75.78513336, 28.43921089], [75.77683258, 28.43047142], [75.76544952, 28.42078018], [75.77031708, 28.40761948], [75.78256226, 28.40723038], [75.78759003, 28.40444183], [75.79405212, 28.40987968], [75.80258942, 28.41422844], [75.81671143, 28.41150093], [75.81813812, 28.40588951], [75.82823944, 28.40907288], [75.83508301, 28.39770126], [75.84120178, 28.39727974], [75.87213135, 28.39085007], [75.88315582, 28.38669968], [75.88353729, 28.39199066], [75.88922882, 28.39365959], [75.89686584, 28.38999939], [75.89713287, 28.38008118], [75.90467072, 28.37606049], [75.92237854, 28.36890984], [75.92498016, 28.36469841], [75.92840576, 28.35601997], [75.92740631, 28.3451004], [75.95630646, 28.33837128], [75.95659637, 28.33558083], [75.95143127, 28.33349991], [75.95449066, 28.32870865], [75.95466614, 28.31853104], [75.96762848, 28.32409286], [75.97470856, 28.31586075], [75.97933197, 28.30633163], [75.98657227, 28.29589081], [75.99124146, 28.29519081], [76.01872253, 28.28095818], [76.00740051, 28.25315285], [76.01119232, 28.24175072], [76.02577972, 28.23591995], [76.03634644, 28.22710991], [76.05300903, 28.22422981], [76.05227661, 28.21443939], [76.04975128, 28.20983124], [76.04382324, 28.20549011], [76.04506683, 28.20293045], [76.05665588, 28.201231], [76.06561279, 28.19894981], [76.06929779, 28.19425011], [76.07157135, 28.17922974], [76.07480621, 28.17242813], [76.08042908, 28.16810989], [76.09288788, 28.15521812], [76.09287262, 28.15162086], [76.09179688, 28.14641953], [76.0879364, 28.14353943], [76.08319855, 28.14225006], [76.07491302, 28.14195061], [76.06505585, 28.14447021], [76.0636673, 28.1498909], [76.0654068, 28.15564919], [76.06635284, 28.16777039], [76.06072998, 28.169981], [76.02774811, 28.17272186], [76.0161972, 28.16107941], [76.01119995, 28.15767288], [76.00602722, 28.15656281], [75.99975586, 28.15644073], [75.99466705, 28.15060043], [75.99571991, 28.13532066], [75.99429321, 28.13111115], [75.99111176, 28.12817955], [75.97706604, 28.12720108], [75.96761322, 28.11939049], [75.95749664, 28.11555099], [75.94740295, 28.10968971], [75.94249725, 28.10563087], [75.93608856, 28.09353065], [75.95896912, 28.08406067], [75.97706604, 28.08418083], [75.98206329, 28.08022118], [75.98763275, 28.07058907], [75.97640991, 28.0589447], [75.97458649, 28.0570507], [75.97740936, 28.05220032], [75.98455048, 28.0507412], [75.99106598, 28.0564518], [75.99762726, 28.05746841], [75.99957275, 28.0589447], [76.00192261, 28.06073189], [76.01242828, 28.07635117], [76.01486206, 28.08107948], [76.01564789, 28.08885193], [76.03121185, 28.08389282], [76.03420258, 28.07995033], [76.03562927, 28.07398033], [76.0331192, 28.0686512], [76.02229309, 28.06230927], [76.01924133, 28.0589447], [76.01667023, 28.05611038], [76.00535583, 28.0545311], [76.00995636, 28.04990959], [76.01088715, 28.04704094], [76.01007843, 28.03671074], [75.99105072, 28.03991127], [75.9805069, 28.03870964], [75.9743576, 28.03693962], [75.96998596, 28.03094864], [75.97083282, 28.02375031], [75.97267914, 28.01814079], [75.97915649, 28.01545906], [75.98581696, 28.01474953], [75.99053955, 28.01017189], [75.98911285, 28.00432968], [75.97988892, 28.00145149], [75.97226715, 28.00134087], [75.96687317, 28.00222969], [75.96452332, 28.00266075], [75.96051788, 28.00209999], [75.95639801, 28.00102043], [75.95527649, 27.99418068], [75.95546722, 27.98863983], [75.9656601, 27.98657036], [75.97316742, 27.98396111], [75.98207855, 27.98698044], [75.98690796, 27.98463058], [75.98647308, 27.98110962], [75.98182678, 27.97831154], [75.97384644, 27.96993828], [75.96833038, 27.96231079], [75.97319794, 27.95800018], [75.96317291, 27.93695068], [75.95394897, 27.93943977], [75.9446106, 27.94008827], [75.94169617, 27.94634056], [75.93850708, 27.95109177], [75.92858887, 27.94174957], [75.92362213, 27.93309021], [75.9287796, 27.92648125], [75.92883301, 27.91680908], [75.94174957, 27.91908073], [75.95588684, 27.91954994], [75.96753693, 27.91537094], [75.97738647, 27.9092598], [75.96724701, 27.89931107], [75.97518921, 27.8930912], [75.97280121, 27.88537979], [75.97345734, 27.87745285], [75.96425629, 27.87150955], [75.96308136, 27.86473083], [75.97544861, 27.86462975], [75.98427582, 27.86286926], [75.99447632, 27.86091995], [75.99662018, 27.86016846], [76.00524902, 27.85744095], [76.00930786, 27.86260986], [76.0207901, 27.85752106], [76.02961731, 27.85388947], [76.03383636, 27.85418129], [76.03839874, 27.85250092], [76.04368591, 27.84885025], [76.04962921, 27.84786034], [76.05478668, 27.8518219], [76.06002808, 27.85717964], [76.08009338, 27.8510704], [76.08476257, 27.85639], [76.08563995, 27.86522293], [76.0880661, 27.86844826], [76.09577179, 27.8647995], [76.10334778, 27.86237907], [76.11258698, 27.85858154], [76.12213898, 27.85440063], [76.12845612, 27.84692192], [76.12822723, 27.83784103], [76.12776947, 27.83320045], [76.14267731, 27.82783127], [76.15319061, 27.82129288], [76.1628418, 27.81484032], [76.16734314, 27.80914116], [76.17292023, 27.80746078], [76.18041992, 27.81241035], [76.18624115, 27.81904984], [76.1904068, 27.82676125], [76.19412994, 27.83121109], [76.20054626, 27.82891083], [76.20773315, 27.82849121], [76.21380615, 27.8325882], [76.22328186, 27.84093094], [76.21063232, 27.84481812], [76.20594788, 27.84799004], [76.2050705, 27.85552025], [76.19895172, 27.85967064], [76.1931076, 27.86391258], [76.19135284, 27.86942863], [76.18901062, 27.87636948], [76.19032288, 27.88157845], [76.19444275, 27.88394165], [76.19975281, 27.88809967], [76.20012665, 27.8923111], [76.19863892, 27.89899063], [76.19095612, 27.90269089], [76.18261719, 27.90507126], [76.17516327, 27.90710068], [76.1697464, 27.90974998], [76.16645813, 27.91506958], [76.16607666, 27.92098999], [76.16765594, 27.92835045], [76.17037201, 27.93329048], [76.17476654, 27.94124985], [76.17636871, 27.94831085], [76.17693329, 27.95506096], [76.17629242, 27.96105957], [76.17817688, 27.96747017], [76.17946625, 27.97284126], [76.17421722, 27.97521019], [76.16703796, 27.97915268], [76.16098022, 27.98010063], [76.16246796, 27.98830986], [76.15386963, 27.99253082], [76.15493774, 27.99899101], [76.15872192, 28.00455093], [76.16938782, 28.01685905], [76.174263, 28.02190971], [76.1795578, 28.02329254], [76.1838913, 28.0235405], [76.19068146, 28.02141953], [76.19587708, 28.02173805], [76.20038605, 28.02567101], [76.20346069, 28.03036118], [76.21382904, 28.03168106], [76.21356201, 28.04018021], [76.2041626, 28.04224968], [76.19818115, 28.03494835], [76.19342804, 28.03523064], [76.18318176, 28.04302025], [76.17688751, 28.04895973], [76.17545319, 28.05425072], [76.17722321, 28.0589447], [76.17733765, 28.05925941], [76.19284821, 28.05981064], [76.19991302, 28.06075096], [76.20363617, 28.05952072], [76.20431519, 28.0589447], [76.20833588, 28.05556107], [76.22593689, 28.05518913], [76.23336792, 28.05642128], [76.23542786, 28.0589447], [76.24356842, 28.06893921], [76.25109863, 28.07092094], [76.2649231, 28.06874084], [76.27178955, 28.06638908], [76.28200531, 28.0589447], [76.29007721, 28.04911041], [76.28811646, 28.04204941], [76.29012299, 28.0298996], [76.29715729, 28.02596092], [76.31659698, 28.02099037], [76.32367706, 28.02384186], [76.32995605, 28.02487946], [76.33679962, 28.02966118], [76.34126282, 28.0360508], [76.34591675, 28.04578972], [76.35081482, 28.0589447], [76.35328674, 28.06557274], [76.354599, 28.07420158], [76.35048676, 28.07578087], [76.34436798, 28.07386971], [76.33734894, 28.07306099], [76.33213806, 28.07678986], [76.33126831, 28.08164978], [76.32879639, 28.08776093], [76.32488251, 28.09215927], [76.32054901, 28.09431267], [76.31344604, 28.09467125], [76.30716705, 28.09645271], [76.29740143, 28.10104942], [76.30132294, 28.10620117], [76.30802917, 28.11128044], [76.31417847, 28.11212921], [76.33188629, 28.10671806], [76.3395462, 28.10969925], [76.34350586, 28.11321831], [76.35560608, 28.12845039], [76.34934235, 28.13215065], [76.34321594, 28.13277054], [76.33759308, 28.13484764], [76.33100891, 28.13896942], [76.32274628, 28.14921761], [76.31732941, 28.15306091], [76.31111908, 28.15467072], [76.30821228, 28.15088081], [76.30155945, 28.15100098], [76.29590607, 28.15467072], [76.29506683, 28.15705109], [76.29846954, 28.15944862], [76.29852295, 28.16254807], [76.2930069, 28.16527939], [76.27818298, 28.16857147], [76.2767868, 28.17276001], [76.27906799, 28.17872047], [76.28885651, 28.1826725], [76.29802704, 28.18287086], [76.30496216, 28.18386078], [76.30871582, 28.18336105], [76.32595825, 28.17743111], [76.33590698, 28.17734146], [76.34259796, 28.17393112], [76.3532486, 28.1661911], [76.35597229, 28.1597805], [76.35740662, 28.14785194], [76.35983276, 28.14338112], [76.37677002, 28.13807106], [76.3840332, 28.13986015], [76.38851166, 28.13952065], [76.39302826, 28.14105034], [76.39704132, 28.14779282], [76.4122467, 28.1474781], [76.42729187, 28.14594078], [76.43135834, 28.14757156], [76.43712616, 28.15215111], [76.45604706, 28.15142822], [76.46109009, 28.15237045], [76.46517944, 28.15561104], [76.47099304, 28.15474129], [76.47233582, 28.14960098], [76.46996307, 28.13850021], [76.47319031, 28.13573074], [76.47722626, 28.13467026], [76.48329163, 28.13484764], [76.48509216, 28.13490105], [76.48972321, 28.13367844], [76.48574066, 28.12812042], [76.4868927, 28.12281036], [76.49809265, 28.12253952], [76.49729156, 28.11597824], [76.49780273, 28.10662079], [76.48874664, 28.10473061], [76.47728729, 28.10598946], [76.47254181, 28.11271095], [76.4662323, 28.11297035], [76.46092987, 28.11190033], [76.45688629, 28.11038971], [76.4539032, 28.10589027], [76.45121765, 28.09766006], [76.44857025, 28.09317017], [76.45343018, 28.08778954], [76.45881653, 28.08500099], [76.46360779, 28.0840683], [76.46988678, 28.08632088], [76.48590088, 28.07512093], [76.49537659, 28.0676403], [76.49765778, 28.0647316], [76.49453735, 28.0610714], [76.48957825, 28.05924034], [76.48780823, 28.0589447], [76.48381805, 28.05828094], [76.48087311, 28.0589447], [76.47129822, 28.06110954], [76.45797729, 28.06197166], [76.45624542, 28.0589447], [76.4540329, 28.05507278], [76.45372772, 28.04966927], [76.45574188, 28.04648018], [76.46170044, 28.04457283], [76.47570801, 28.04405975], [76.48307037, 28.0463295], [76.49221802, 28.04709816], [76.49604797, 28.04364014], [76.49848938, 28.04018021], [76.49949646, 28.03635979], [76.50522614, 28.03503036], [76.51140594, 28.03536034], [76.51859283, 28.03896141], [76.52585602, 28.0454483], [76.53124237, 28.0431118], [76.53852081, 28.03911972], [76.53553009, 28.02571106], [76.53855133, 28.01670074], [76.53862, 28.01206017], [76.53774261, 28.00751114], [76.53845215, 28.00537109], [76.53640747, 28.00473022], [76.53553772, 27.99306107], [76.53193665, 27.98570061], [76.53103638, 27.97932816], [76.53350067, 27.97372818], [76.53819275, 27.970541], [76.54659271, 27.9713707], [76.55343628, 27.9750309], [76.55979156, 27.98178291], [76.56749725, 27.98357964], [76.57382965, 27.98901939], [76.57727051, 27.99487114], [76.58381653, 28.0003109], [76.59175873, 28.00365829], [76.59523773, 28.00614929], [76.59896851, 28.00984001], [76.60389709, 28.01079178], [76.6159668, 28.0112896], [76.62534332, 28.01046944], [76.63687897, 28.01066017], [76.64671326, 28.01262093], [76.65455627, 28.01556969], [76.66007233, 28.0190506], [76.66240692, 28.02294159], [76.66146088, 28.0293026], [76.65962219, 28.03367043], [76.65341949, 28.03992081], [76.65099335, 28.0444603], [76.65162659, 28.05548286], [76.6501236, 28.0589447], [76.64892578, 28.06171036], [76.64792633, 28.06767082], [76.64804077, 28.07908058], [76.64697266, 28.08510971], [76.64785004, 28.09221077], [76.65122986, 28.0967598], [76.6579895, 28.0990715], [76.6639328, 28.0978508], [76.67790985, 28.09781075], [76.68218231, 28.09777069], [76.68564606, 28.10688019], [76.6894989, 28.1135006], [76.69024658, 28.11478996], [76.69494629, 28.11529922], [76.69876099, 28.11571121], [76.70543671, 28.12772751], [76.708992, 28.13138008], [76.70996094, 28.13236046], [76.720047, 28.13153076], [76.7315979, 28.12845039], [76.73295593, 28.12857246], [76.73912811, 28.12903976], [76.75508118, 28.14661026], [76.76216888, 28.1500206], [76.77294159, 28.15142059], [76.7830658, 28.1556797], [76.79148865, 28.15724182], [76.79614258, 28.17048073], [76.79228973, 28.17566109], [76.79225922, 28.18292046], [76.79025269, 28.19375992], [76.79309845, 28.19832993], [76.79384613, 28.19955063], [76.79788971, 28.19437981], [76.8026123, 28.19607162], [76.80560303, 28.20038033], [76.80246735, 28.20463181], [76.80136871, 28.21160126], [76.80580902, 28.21589088], [76.81323242, 28.21631241], [76.8189621, 28.21469116], [76.82382965, 28.2147007], [76.82724762, 28.21749115], [76.83342743, 28.2248497], [76.85048676, 28.22666931], [76.8543396, 28.22524071], [76.85772705, 28.22317123], [76.8636322, 28.22463989], [76.86580658, 28.21795845], [76.86618042, 28.21152115], [76.8792572, 28.21038055], [76.88668823, 28.21049118], [76.89668274, 28.20763016], [76.89984894, 28.20476913], [76.88574219, 28.1967411], [76.88387299, 28.19473076], [76.88404846, 28.19165993], [76.89009094, 28.18782806], [76.8991394, 28.17932129], [76.91204834, 28.17185974], [76.92105103, 28.16225052], [76.92753601, 28.15891266], [76.93781281, 28.15534973], [76.94156647, 28.15517044], [76.94052887, 28.15092087], [76.94174194, 28.14870071], [76.95654297, 28.14600945], [76.96176147, 28.14401054], [76.95582581, 28.12371826], [76.955513, 28.11174965], [76.95107269, 28.09608841], [76.94806671, 28.0786705], [76.94655609, 28.07134056], [76.94252777, 28.06682014], [76.93802643, 28.05961037], [76.93777466, 28.0589447], [76.93364716, 28.04813004], [76.93186188, 28.04202271], [76.93074036, 28.03050041], [76.92658234, 28.01250076], [76.92163086, 28.00568962], [76.91864777, 27.99761009], [76.9223175, 27.9858284], [76.92492676, 27.97836113], [76.92276764, 27.96577072], [76.91954041, 27.95283127], [76.91909027, 27.94082069], [76.9190979, 27.92486], [76.92127991, 27.92105293], [76.92993927, 27.92136002], [76.93881989, 27.91902924], [76.93673706, 27.90754128], [76.93817902, 27.89599037], [76.92608643, 27.89442062], [76.92610931, 27.88837051], [76.9247818, 27.876791], [76.92829895, 27.86713028], [76.92990875, 27.85523033], [76.92809296, 27.84398079], [76.92664337, 27.83422089], [76.92193604, 27.83183098], [76.91499329, 27.83461952], [76.90788269, 27.83591843], [76.90377808, 27.83266068], [76.90106964, 27.82541847], [76.900383, 27.82114983], [76.90524292, 27.81255913], [76.90660095, 27.80765915], [76.90280151, 27.80128098], [76.90392303, 27.79488945], [76.89865112, 27.79108047], [76.89560699, 27.78614044], [76.89363861, 27.7792511], [76.89232635, 27.77203178], [76.8914032, 27.76119041], [76.89060974, 27.74201965], [76.88786316, 27.73721123], [76.88407898, 27.73090935], [76.88334656, 27.72442245], [76.88854218, 27.71955109], [76.89539337, 27.71850967], [76.90278625, 27.7164402], [76.90830994, 27.71208954], [76.91220093, 27.70610046], [76.91456604, 27.70082092], [76.91036224, 27.69664955], [76.90600586, 27.69584084], [76.9003067, 27.69462967], [76.89350891, 27.69826126], [76.88802338, 27.70167923], [76.88284302, 27.70337105], [76.88092041, 27.69936943], [76.88311768, 27.69549942], [76.8886261, 27.69284058], [76.89473724, 27.68965912], [76.89673615, 27.68596077], [76.89401245, 27.68333054], [76.89164734, 27.67988968], [76.89322662, 27.67687988], [76.89715576, 27.67243004], [76.90009308, 27.66803932], [76.90052795, 27.6634407], [76.90262604, 27.65851974], [76.90540314, 27.65596962], [76.90947723, 27.65680122], [76.91382599, 27.65960121], [76.91899109, 27.66148186], [76.92385101, 27.66073036], [76.92684174, 27.66543007], [76.93028259, 27.67170906], [76.93419647, 27.67510033], [76.93844604, 27.67366982], [76.94478607, 27.67057037], [76.95153809, 27.66625023], [76.96022797, 27.66242027], [76.97049713, 27.65714264], [76.97033691, 27.66545105], [76.97229767, 27.67287064], [76.97312927, 27.68042183], [76.97608185, 27.69285011], [76.97910309, 27.70615959], [76.98277283, 27.71850014], [76.98744965, 27.72928047], [76.98912811, 27.73377991], [76.9913559, 27.73642921], [76.9935379, 27.74170113], [76.99437714, 27.74204254], [77.00099182, 27.73851967], [77.00337219, 27.73855019], [77.00502014, 27.73913956], [77.01140594, 27.74651909], [77.01680756, 27.74776077], [77.02485657, 27.74712944], [77.02894592, 27.74937057], [77.03196716, 27.74841118], [77.03649902, 27.74462128], [77.0393219, 27.7415905], [77.0402832, 27.73835945], [77.04271698, 27.73590279], [77.04427338, 27.73224068], [77.05065918, 27.72811127], [77.0532074, 27.7278595], [77.05944824, 27.73135948], [77.06572723, 27.73241043], [77.07113647, 27.73574066], [77.07797241, 27.73734093], [77.079216, 27.73841095], [77.07943726, 27.74019051], [77.07840729, 27.74287987], [77.07253265, 27.74909973], [77.07118988, 27.75192261], [77.0707016, 27.75884056], [77.06733704, 27.76375961], [77.06181335, 27.76568985], [77.05603027, 27.7643795], [77.05422974, 27.76189995], [77.05010223, 27.76104164], [77.04692841, 27.76798058], [77.03943634, 27.77490044], [77.02841187, 27.78029823], [77.02672577, 27.77791023], [77.024086, 27.77700996], [77.02276611, 27.77794838], [77.02066803, 27.77812004], [77.0197525, 27.78032112], [77.0230484, 27.78718948], [77.02398682, 27.79817009], [77.03038025, 27.81142998], [77.03457642, 27.81252289], [77.03539276, 27.81410027], [77.03504944, 27.81666183], [77.03827667, 27.82004166], [77.04514313, 27.81698036], [77.04682159, 27.81809044], [77.05182648, 27.81516075], [77.05625153, 27.81146049], [77.06529236, 27.81258011], [77.06848145, 27.81157112], [77.07241058, 27.80952072], [77.07427216, 27.80435181], [77.07663727, 27.8014698], [77.08023071, 27.80039024], [77.09362793, 27.78970146], [77.10116577, 27.78549194], [77.10263062, 27.78518105], [77.10748291, 27.78665924], [77.11476898, 27.78988075], [77.11741638, 27.79019165], [77.11997223, 27.78947067], [77.12210846, 27.7883091], [77.12467194, 27.78483963], [77.12520599, 27.77693176], [77.12652588, 27.77646065], [77.13535309, 27.78395081], [77.14142609, 27.78623009], [77.14727783, 27.78665924], [77.15142822, 27.79181099], [77.15329742, 27.79785919], [77.15354156, 27.80243111], [77.14972687, 27.81243134], [77.15061951, 27.81555939], [77.15209961, 27.8157711], [77.15666199, 27.81360054], [77.16108704, 27.81318855], [77.17237854, 27.81632042], [77.1758728, 27.81445122], [77.18065643, 27.80865288], [77.18044281, 27.80443192], [77.17814636, 27.80252075], [77.16924286, 27.80056953], [77.16660309, 27.79591942], [77.16216278, 27.79059029], [77.16400909, 27.78691101], [77.16870117, 27.78490067], [77.17556, 27.78722191], [77.18894196, 27.79842949], [77.18659973, 27.81048012], [77.18747711, 27.81504822], [77.19384766, 27.82193947], [77.19676208, 27.81944084], [77.20210266, 27.81257057], [77.20571136, 27.80548096], [77.20677185, 27.80105972], [77.21684265, 27.7954998], [77.22215271, 27.79764938], [77.22685242, 27.79610062], [77.22870636, 27.79310036], [77.22724915, 27.78865814], [77.23174286, 27.78580093], [77.23455811, 27.78581047], [77.24088287, 27.7903595], [77.24794769, 27.79375076], [77.25284576, 27.79763985], [77.25699615, 27.80525017], [77.25805664, 27.80929947], [77.26249695, 27.81611061], [77.26748657, 27.81196022], [77.27577972, 27.80654907], [77.27932739, 27.80280113], [77.29064178, 27.80170059], [77.29538727, 27.79984093], [77.29794312, 27.79785919], [77.30110931, 27.79368019], [77.30414581, 27.78800964], [77.30368805, 27.77598], [77.3014679, 27.77170944], [77.30152893, 27.76896095], [77.30296326, 27.76465034], [77.30280304, 27.76119041], [77.30169678, 27.76006126], [77.30134583, 27.75645828], [77.305336, 27.74922943], [77.30599976, 27.74469948], [77.30966949, 27.74278831], [77.31210327, 27.74017143], [77.31233215, 27.73867989], [77.31067657, 27.73686981], [77.29634094, 27.72982979], [77.29760742, 27.71868134], [77.30235291, 27.71321106], [77.30845642, 27.71390915], [77.31725311, 27.71124077], [77.32034302, 27.71268272], [77.32447815, 27.71319008], [77.33053589, 27.71113968], [77.3339386, 27.70792007], [77.33444214, 27.69948959], [77.33654785, 27.69618034], [77.33679199, 27.68546295], [77.33500671, 27.68142128], [77.33746338, 27.67580986], [77.33716583, 27.6696701], [77.33934784, 27.66242027], [77.34276581, 27.65720177], [77.3423233, 27.6530304], [77.33233643, 27.6377697], [77.31321716, 27.61732101], [77.31121063, 27.61169052], [77.32578278, 27.59687805], [77.32811737, 27.59604073], [77.33516693, 27.60153008], [77.35011292, 27.59340096], [77.3483963, 27.59012032], [77.3434906, 27.58550262], [77.33838654, 27.57660294], [77.33306122, 27.57604027], [77.33109283, 27.57344055], [77.33039856, 27.57110977], [77.33120728, 27.56862831], [77.33067322, 27.56375122], [77.33357239, 27.55459023], [77.33843994, 27.54964256], [77.34015656, 27.54673958], [77.33545685, 27.54170036], [77.33252716, 27.53854942], [77.33513641, 27.53002167], [77.34026337, 27.52477264], [77.35222626, 27.51997948], [77.35816956, 27.51947975], [77.36122894, 27.51851082], [77.37619019, 27.51860046], [77.38241577, 27.51655006], [77.38326263, 27.51148987], [77.38955688, 27.50542259], [77.39202881, 27.50204277], [77.39155579, 27.49356079], [77.39234924, 27.48610115], [77.39359283, 27.48194122], [77.39642334, 27.47780991], [77.40738678, 27.47636986], [77.41136932, 27.47269058], [77.41545105, 27.46614075], [77.42543793, 27.46480942], [77.42959595, 27.46204948], [77.42878723, 27.45545959], [77.42727661, 27.45100975], [77.42295074, 27.44943047], [77.42073059, 27.44729042], [77.41828156, 27.4421711], [77.41703033, 27.43824005], [77.41517639, 27.42537117], [77.42508698, 27.41887283], [77.42677307, 27.41661072], [77.42999268, 27.4050293], [77.4295578, 27.4043808], [77.4318924, 27.39915848], [77.43578339, 27.39678955], [77.44326019, 27.39332962], [77.461586, 27.38759041], [77.46660614, 27.3842907], [77.47586823, 27.38772964], [77.48696136, 27.38562965], [77.49724579, 27.38136292], [77.50219727, 27.37735939], [77.50385284, 27.37405968], [77.50802612, 27.37278175], [77.50936127, 27.36782074], [77.51567841, 27.36273003], [77.52200317, 27.35763931], [77.53074646, 27.35276985], [77.53539276, 27.35293961], [77.53909302, 27.35307121], [77.5404129, 27.34758949], [77.5427475, 27.34242821], [77.56173706, 27.33543968], [77.56671906, 27.33361053], [77.56777191, 27.33323097], [77.57273865, 27.33008957], [77.57454681, 27.32673073], [77.58043671, 27.32845116], [77.58229828, 27.33163071], [77.58661652, 27.33527184], [77.5929718, 27.3379612], [77.60481262, 27.33794975], [77.60753632, 27.34215927], [77.61036682, 27.34439278], [77.61411285, 27.34338951], [77.61634064, 27.33831024], [77.61559296, 27.33453941], [77.61553192, 27.32541084], [77.6135025, 27.31476021], [77.60887909, 27.3119297], [77.603302, 27.30992126], [77.6000824, 27.30470085], [77.59702301, 27.30470085], [77.59172821, 27.30273056], [77.59166718, 27.30055809], [77.59832764, 27.29635048], [77.60307312, 27.29487991], [77.60909271, 27.28799057], [77.60935211, 27.28166962], [77.61414337, 27.27916145], [77.61125183, 27.27433968], [77.60661316, 27.2727108], [77.60900116, 27.2650795], [77.61284637, 27.26030159], [77.62329865, 27.26382065], [77.62581635, 27.26234055], [77.62957764, 27.25549126], [77.6342392, 27.25368118], [77.63890839, 27.24714088], [77.63913727, 27.24712944], [77.63800812, 27.24253845], [77.63839722, 27.24065018], [77.64420319, 27.23887825], [77.64318085, 27.23180962], [77.6394577, 27.22323036], [77.63951874, 27.2172718], [77.64202881, 27.21476936], [77.64778137, 27.21454811], [77.65500641, 27.21178055], [77.65664673, 27.21302032], [77.66719055, 27.20709991], [77.67299652, 27.20036125], [77.67199707, 27.19506073], [77.6654129, 27.1861496], [77.66124725, 27.18278122], [77.65461731, 27.17558098], [77.64334106, 27.17440033], [77.63591766, 27.17012978], [77.63079834, 27.17020988], [77.6282959, 27.17312241], [77.6254425, 27.17436028], [77.62252045, 27.1749897], [77.61480713, 27.17478943], [77.6051178, 27.16847992], [77.60407257, 27.16431999], [77.6059494, 27.15890121], [77.60653687, 27.15414047], [77.59807587, 27.14800072], [77.59365845, 27.14795113], [77.59210968, 27.14476967], [77.59239197, 27.14011955], [77.59591675, 27.13721085], [77.59455109, 27.13368034], [77.59726715, 27.12905121], [77.59567261, 27.12615967], [77.59078217, 27.12308121], [77.58587646, 27.12424088], [77.58342743, 27.12068176], [77.57466888, 27.1221199], [77.55612183, 27.11581993], [77.54576874, 27.11512947], [77.54444885, 27.11560059], [77.53948212, 27.11125946], [77.53209686, 27.10968971], [77.52937317, 27.10414124], [77.52082062, 27.1058197], [77.51383972, 27.10808945], [77.50821686, 27.1028595], [77.50231934, 27.09922028], [77.49903107, 27.09584045], [77.49841309, 27.09519005], [77.49938965, 27.09398079], [77.51100159, 27.09391975], [77.51474762, 27.09189987], [77.51377869, 27.09137917], [77.51738739, 27.08949089], [77.51822662, 27.0880928], [77.51773834, 27.0797596], [77.51468658, 27.07406044], [77.51429749, 27.07042122], [77.52136993, 27.0672226], [77.52654266, 27.06650925], [77.52915955, 27.06711006], [77.53366089, 27.06981087], [77.54139709, 27.07739067], [77.54631805, 27.08073044], [77.55422974, 27.07722092], [77.56324005, 27.07862282], [77.56568146, 27.07801056], [77.5684433, 27.07248116], [77.56572723, 27.06903076], [77.56694031, 27.06632042], [77.56680298, 27.06026077], [77.56523895, 27.05397987], [77.56112671, 27.05157089], [77.55893707, 27.04878998], [77.55739594, 27.03689957], [77.56067657, 27.03565025], [77.56820679, 27.03932953], [77.57509613, 27.04157066], [77.58392334, 27.03931999], [77.58875275, 27.03705978], [77.59059143, 27.03166008], [77.5943222, 27.03119087], [77.59881592, 27.02882957], [77.6034317, 27.02909279], [77.61559296, 27.02739906], [77.61949921, 27.02490807], [77.62201691, 27.02186966], [77.62425232, 27.01689911], [77.62740326, 27.01550102], [77.63092041, 27.0234108], [77.63426208, 27.02701187], [77.64334106, 27.02719116], [77.65196991, 27.02257919], [77.6570282, 27.02273178], [77.6598587, 27.02503967], [77.66329956, 27.03030968], [77.67076874, 27.0489006], [77.67331696, 27.05155945], [77.67816925, 27.05052948], [77.68430328, 27.04491997], [77.68486023, 27.0398407], [77.68202209, 27.03294182], [77.69374084, 27.01951981], [77.69567108, 27.01605034], [77.69661713, 27.00695038], [77.69896698, 27.0057106], [77.70358276, 27.0003109], [77.70858002, 27.00110245], [77.71392059, 26.99796104], [77.71761322, 27.00002098], [77.72231293, 27.00033951], [77.72336578, 27.00390816], [77.72104645, 27.00570107], [77.7201767, 27.01404953], [77.72216034, 27.02614021], [77.72648621, 27.03153992], [77.7355423, 27.033741], [77.73840332, 27.03268051], [77.73935699, 27.0275898], [77.74085236, 27.02552032], [77.74389648, 27.02374077], [77.75311279, 27.02363014], [77.75501251, 27.02276039], [77.74768066, 27.01762962], [77.74529266, 27.01336098], [77.74616241, 27.01086044], [77.74546051, 27.00868988], [77.74254608, 27.00634956], [77.74246216, 27.00570107], [77.74607849, 27.00294113], [77.74771118, 26.99850082], [77.74336243, 26.99765968], [77.73969269, 26.9979496], [77.73900604, 26.99106026], [77.73634338, 26.98822021], [77.72328186, 26.98823929], [77.71459198, 26.99166107], [77.70992279, 26.98769951], [77.70123291, 26.98431969], [77.69191742, 26.97899246], [77.67028046, 26.97710991], [77.66861725, 26.96917915], [77.66529846, 26.96692085], [77.65960693, 26.96808052], [77.65660858, 26.97406006], [77.65260315, 26.97494125], [77.64894104, 26.9738102], [77.64227295, 26.96730042], [77.60482788, 26.94595909], [77.59812927, 26.94026947], [77.59379578, 26.93770981], [77.59176636, 26.94398117], [77.58744812, 26.94454956], [77.5847702, 26.94227028], [77.57975006, 26.93087006], [77.55735779, 26.92603111], [77.5453186, 26.92204094], [77.51856995, 26.91547966], [77.49584198, 26.90578079], [77.48246765, 26.90377998], [77.47377777, 26.89978981], [77.46478271, 26.89266014], [77.45517731, 26.8895607], [77.455513, 26.88043976], [77.45417786, 26.8767395], [77.45052338, 26.87501144], [77.44182587, 26.87759018], [77.43650818, 26.8678875], [77.4318161, 26.8658905], [77.42648315, 26.8670311], [77.42247009, 26.86701965], [77.42347717, 26.85762024], [77.42616272, 26.85305977], [77.4214859, 26.84877968], [77.4174881, 26.8427906], [77.4228363, 26.83680916], [77.42584991, 26.83567047], [77.42719269, 26.8316803], [77.43421173, 26.82541084], [77.43921661, 26.81915092], [77.43824005, 26.80887985], [77.43192291, 26.79235077], [77.42858887, 26.78578949], [77.42726898, 26.77609253], [77.4285965, 26.77011108], [77.43428802, 26.77239037], [77.43894196, 26.77581024], [77.44528198, 26.77753067], [77.45095062, 26.78067017], [77.45597076, 26.78038025], [77.46431732, 26.76955032], [77.46166992, 26.76584816], [77.45730591, 26.76214027], [77.44831085, 26.74674988], [77.48036194, 26.75387955], [77.48635864, 26.76101112], [77.49334717, 26.76699066], [77.49668884, 26.77411079], [77.48932648, 26.77724838], [77.48432159, 26.78239059], [77.48098755, 26.78779984], [77.48232269, 26.7940712], [77.48664856, 26.80120087], [77.48932648, 26.80861092], [77.49698639, 26.83797073], [77.49797821, 26.84794998], [77.50197601, 26.84653091], [77.50666809, 26.84738159], [77.51367188, 26.84510231], [77.51535034, 26.84140015], [77.51233673, 26.83826065], [77.5120163, 26.82798958], [77.51435852, 26.8245697], [77.52069092, 26.82200813], [77.52838135, 26.8245697], [77.5357132, 26.82542992], [77.54740906, 26.82172012], [77.55641937, 26.82199097], [77.56476593, 26.82456017], [77.5687561, 26.82741165], [77.57211304, 26.83196068], [77.57746887, 26.83310127], [77.5881424, 26.83337975], [77.59615326, 26.84165192], [77.60016632, 26.84250069], [77.60083771, 26.83423042], [77.60450745, 26.83280182], [77.60853577, 26.8345108], [77.61186218, 26.83964157], [77.61319733, 26.84446907], [77.61620331, 26.84847069], [77.62487793, 26.84674835], [77.65730286, 26.85641098], [77.66462708, 26.85984039], [77.66697693, 26.86238289], [77.67166901, 26.87407112], [77.67468262, 26.87462997], [77.67835236, 26.87832069], [77.68235016, 26.87916946], [77.68636322, 26.87832069], [77.68937683, 26.87347031], [77.69371796, 26.87289047], [77.69637299, 26.87659073], [77.69773102, 26.8800106], [77.70540619, 26.88027954], [77.7158432, 26.88133049], [77.719841, 26.88673973], [77.72054291, 26.89301109], [77.71987915, 26.89673042], [77.71788025, 26.89958954], [77.71083832, 26.90302086], [77.71891022, 26.91641045], [77.72392273, 26.92295074], [77.72895813, 26.92580032], [77.74064636, 26.92691994], [77.74433136, 26.92321014], [77.748703, 26.9269104], [77.75337982, 26.93773842], [77.76509857, 26.93799019], [77.77348328, 26.93626976], [77.77313995, 26.9325695], [77.78148651, 26.92770958], [77.78885651, 26.92228127], [77.79588318, 26.92340088], [77.79923248, 26.92825127], [77.8052597, 26.9285202], [77.80860901, 26.92566109], [77.8146286, 26.92279053], [77.82132721, 26.92620087], [77.82633209, 26.92103958], [77.83637238, 26.9195919], [77.84104156, 26.91644096], [77.84940338, 26.91242027], [77.87146759, 26.90550041], [77.87677765, 26.89920998], [77.88214111, 26.89603996], [77.88479614, 26.89232063], [77.8901062, 26.88945961], [77.89612579, 26.88972092], [77.90083313, 26.89513969], [77.90284729, 26.90114021], [77.90090179, 26.91171265], [77.89858246, 26.91542053], [77.89692688, 26.92000008], [77.89994049, 26.9245491], [77.90661621, 26.92395973], [77.90925598, 26.92082977], [77.9082489, 26.91683006], [77.90956879, 26.9142704], [77.92189026, 26.91455078], [77.92884064, 26.91283989], [77.93212891, 26.90999985], [77.93474579, 26.9051609], [77.93769836, 26.90205002], [77.94197083, 26.89978981], [77.96295929, 26.91257095], [77.96579742, 26.91098022], [77.96481323, 26.90724945], [77.96675873, 26.90302086], [77.97062683, 26.89970016], [77.9751358, 26.89752769], [77.98027802, 26.89770126], [77.98501587, 26.90138054], [77.99188995, 26.91090012], [77.99838257, 26.90985107], [78.00666046, 26.9106617], [78.01406097, 26.90839195], [78.01629639, 26.90497971], [78.01911926, 26.89743996], [78.02171326, 26.89479065], [78.02207184, 26.89019012], [78.01756287, 26.88203049], [78.02009583, 26.87961006], [78.02793121, 26.87615013], [78.02731323, 26.87347984], [78.01635742, 26.86381912], [78.01761627, 26.86164093], [78.02202606, 26.86087036], [78.02722168, 26.86218071], [78.03114319, 26.86548233], [78.03540039, 26.8745594], [78.03755951, 26.87696266], [78.03965759, 26.87734985], [78.04589081, 26.87488174], [78.04780579, 26.87480927], [78.04772949, 26.8777504], [78.04482269, 26.88211823], [78.04429626, 26.88453102], [78.04522705, 26.90286255], [78.04223633, 26.91542053], [78.04862976, 26.91377068], [78.0524826, 26.91488266], [78.05712128, 26.91329956], [78.06053925, 26.91590118], [78.06291962, 26.91485023], [78.06788635, 26.91028023], [78.07280731, 26.90755081], [78.08682251, 26.90200806], [78.0894165, 26.90286255], [78.08992004, 26.90574837], [78.08830261, 26.90993118], [78.09104919, 26.9116497], [78.09346008, 26.91008949], [78.09861755, 26.90397263], [78.10147095, 26.90498924], [78.10276031, 26.90993118], [78.09908295, 26.92061234], [78.09662628, 26.92304039], [78.09535217, 26.92905045], [78.09866333, 26.93061066], [78.10214233, 26.93085289], [78.10630798, 26.93001175], [78.11270905, 26.92749023], [78.11431122, 26.93058014], [78.11522675, 26.93819046], [78.11305237, 26.94194984], [78.10943604, 26.94487953], [78.1079483, 26.94831085], [78.10804749, 26.9500103], [78.11134338, 26.95323181], [78.11489868, 26.95486069], [78.12706757, 26.9554882], [78.13407135, 26.95700836], [78.13947296, 26.95713043], [78.14608002, 26.95305061], [78.15265656, 26.95214081], [78.16314697, 26.95269012], [78.17373657, 26.94869041], [78.19049835, 26.94676971], [78.2012558, 26.94032288], [78.20524597, 26.93889046], [78.20826721, 26.93975258], [78.21219635, 26.94961929], [78.21589661, 26.95395088], [78.22052765, 26.94767952], [78.2233963, 26.9450798], [78.22731781, 26.94358063], [78.22940063, 26.94131088], [78.23060608, 26.93678284], [78.23274231, 26.93369293], [78.24024963, 26.93363953], [78.24733734, 26.93074989], [78.25219727, 26.9349823], [78.25831604, 26.9340229], [78.26122284, 26.93177986], [78.2617569, 26.93017006], [78.26223755, 26.92351151], [78.25953674, 26.91621971], [78.25432587, 26.90974808], [78.25267029, 26.90460968], [78.24817657, 26.90063095], [78.23249817, 26.89545822], [78.22978973, 26.89389992], [78.22657013, 26.88262939], [78.20485687, 26.87738991], [78.20053864, 26.87858009], [78.19352722, 26.88952065], [78.19113922, 26.88861084], [78.19017792, 26.88346291], [78.19689178, 26.87212181], [78.20075226, 26.86240005], [78.20448303, 26.85555077], [78.20755768, 26.85233116], [78.21395111, 26.84852028], [78.21164703, 26.83846092], [78.20979309, 26.83609009], [78.20278931, 26.83231926], [78.19210052, 26.8298111], [78.1795578, 26.83102036], [78.17327881, 26.83257103], [78.16757202, 26.83195114], [78.16355133, 26.82985115], [78.16094971, 26.82703972], [78.16340637, 26.81993103], [78.17936707, 26.80116081], [78.18044281, 26.79704094], [78.17975616, 26.79356956], [78.17611694, 26.79149246], [78.15978241, 26.79112053], [78.14581299, 26.79173088], [78.14048004, 26.79364014], [78.13131714, 26.79916954], [78.11902618, 26.80256081], [78.1129303, 26.80256081], [78.10552216, 26.80075264], [78.09983063, 26.79700851], [78.09538269, 26.78943062], [78.09442139, 26.7834301], [78.09568024, 26.77179909], [78.09709167, 26.76942062], [78.10051727, 26.76637077], [78.11104584, 26.76214027], [78.11482239, 26.75881195], [78.11605835, 26.7546196], [78.11167908, 26.74965096], [78.09600067, 26.74376106], [78.08914948, 26.73810959], [78.08676147, 26.73176956], [78.0865097, 26.72445107], [78.08898926, 26.70072174], [78.08805847, 26.68666077], [78.08573914, 26.68305016], [78.07863617, 26.68032074], [78.07537079, 26.67819023], [78.06938934, 26.67851067], [78.06511688, 26.67964172], [78.06092834, 26.68184853], [78.05622101, 26.68589973], [78.04911041, 26.68980026], [78.04312134, 26.69106293], [78.03156281, 26.69133949], [78.01920319, 26.69762039], [78.01190186, 26.70014763], [77.99221802, 26.70264053], [77.98855591, 26.69999123], [77.97572327, 26.68330193], [77.96879578, 26.67663956], [77.96053314, 26.67152977], [77.95355988, 26.66942024], [77.94789124, 26.66504097], [77.93990326, 26.66270828], [77.92391205, 26.66499138], [77.9036026, 26.66617966], [77.89457703, 26.66221046], [77.89087677, 26.65450287], [77.89015198, 26.64051819], [77.88877869, 26.63281059], [77.8793869, 26.62029076], [77.87037659, 26.61861992], [77.85144043, 26.61601067], [77.84243774, 26.61517906], [77.83409882, 26.61178017], [77.82543182, 26.60524178], [77.82041168, 26.59983826], [77.81842041, 26.59385109], [77.8243866, 26.58443069], [77.82467651, 26.57274055], [77.81765747, 26.56021118], [77.81299591, 26.55480957], [77.80430603, 26.55140114], [77.7976532, 26.55027962], [77.78299713, 26.55258942], [77.76700592, 26.55347824], [77.75801849, 26.55064964], [77.75, 26.54667091], [77.74434662, 26.54524994], [77.73935699, 26.54269028], [77.73066711, 26.52988052], [77.72698212, 26.51536179], [77.72099304, 26.50852013], [77.71398163, 26.50424957], [77.69503021, 26.50086975], [77.68598938, 26.50259018], [77.67800903, 26.5054512], [77.67102814, 26.50972939], [77.66768646, 26.50831032], [77.65470123, 26.49722099], [77.64636993, 26.49379921], [77.63938141, 26.48924065], [77.62671661, 26.48299026], [77.62007141, 26.47700119], [77.61673737, 26.47187042], [77.61538696, 26.46646118], [77.60874176, 26.45934105], [77.59908295, 26.45422173], [77.57910156, 26.45108986], [77.56912994, 26.44310951], [77.55914307, 26.44083977], [77.55148315, 26.44055939], [77.54715729, 26.4362812], [77.54250336, 26.42945099], [77.53717804, 26.4234581], [77.52986908, 26.41804123], [77.52288055, 26.41491127], [77.50591278, 26.41291046], [77.493927, 26.41357994], [77.47496796, 26.41463089], [77.45899963, 26.41119957], [77.43405151, 26.40920067], [77.42771912, 26.40690994], [77.42542267, 26.40205956], [77.42640686, 26.39550972], [77.43373871, 26.38753128], [77.43972778, 26.37869072], [77.43942261, 26.37298965], [77.43676758, 26.36814117], [77.43242645, 26.36499977], [77.41546631, 26.36811829], [77.40782166, 26.36898041], [77.40184021, 26.3686924], [77.39451599, 26.36670113], [77.38585663, 26.36242294], [77.38288879, 26.36240959], [77.37889862, 26.3638382], [77.36624908, 26.37151909], [77.36025238, 26.36952019], [77.3466568, 26.36038017], [77.33467102, 26.35723114], [77.32937622, 26.34810257], [77.32704163, 26.34724045], [77.32405853, 26.34810257], [77.31804657, 26.34638023], [77.31179047, 26.33382988], [77.30847931, 26.32155991], [77.3081665, 26.31500053], [77.28994751, 26.29559135], [77.26703644, 26.27617073], [77.25144958, 26.26703072], [77.23784637, 26.26272011], [77.20838928, 26.24423981], [77.20310974, 26.23740005], [77.19447327, 26.23597145], [77.18453217, 26.23682022], [77.17753601, 26.2390995], [77.17022705, 26.24451065], [77.16493988, 26.24450111], [77.16130066, 26.24222946], [77.15804291, 26.23852921], [77.15276337, 26.23795128], [77.1432724, 26.2382412], [77.12954712, 26.23965073], [77.12403107, 26.23795128], [77.11364746, 26.23135948], [77.10938263, 26.22507286], [77.10587311, 26.21936035], [77.10508728, 26.2091198], [77.09822083, 26.20225906], [77.09644318, 26.19544029], [77.09168243, 26.19087982], [77.0846405, 26.18717003], [77.06893921, 26.18540955], [77.05893707, 26.18535042], [77.05264282, 26.18617058], [77.04499054, 26.18494987], [77.03473663, 26.18193054], [77.02388, 26.17617035], [77.01123047, 26.16530037], [77.00773621, 26.16057968], [77.00480652, 26.15924072], [76.99968719, 26.15262985], [76.99646759, 26.14772034], [76.99447632, 26.13778114], [76.98603821, 26.13235283], [76.96856689, 26.1240406], [76.95352173, 26.11531067], [76.9418869, 26.10811043], [76.93871307, 26.1060791], [76.92897034, 26.10268021], [76.91834259, 26.10264969], [76.90631866, 26.10110092], [76.89531708, 26.09802055], [76.88777924, 26.09332275], [76.88288116, 26.0864296], [76.88223267, 26.07860947], [76.87696838, 26.07205009], [76.87255859, 26.06414986], [76.87042236, 26.05644989], [76.86392975, 26.05167961], [76.85774231, 26.0485611], [76.85176849, 26.04351044], [76.84572601, 26.04027939], [76.83809662, 26.0363903], [76.83040619, 26.02959061], [76.84024048, 26.0112896], [76.83705139, 26.00204086], [76.82962799, 25.99592972], [76.82328033, 25.99272156], [76.81984711, 25.98867989], [76.81804657, 25.98427963], [76.8188858, 25.97125053], [76.81624603, 25.96713066], [76.80631256, 25.95297813], [76.7947998, 25.9442215], [76.78591156, 25.94046974], [76.7767868, 25.93938065], [76.76065063, 25.94252968], [76.75591278, 25.94169044], [76.75356293, 25.93963051], [76.75283051, 25.93581009], [76.75344849, 25.93223953], [76.75676727, 25.92835045], [76.76278687, 25.92531013], [76.76241302, 25.92206955], [76.75563049, 25.91623116], [76.74546814, 25.90923119], [76.73332977, 25.90254974], [76.72220612, 25.90031052], [76.71452332, 25.90098953], [76.70548248, 25.9034729], [76.69645691, 25.90711021], [76.68405914, 25.91020966], [76.67436218, 25.91180038], [76.65656281, 25.91081047], [76.64612579, 25.90885162], [76.64141846, 25.90625], [76.63833618, 25.90151978], [76.6355896, 25.89592934], [76.63168335, 25.87524033], [76.62660217, 25.87087059], [76.61653137, 25.87125015], [76.59747314, 25.8764801], [76.59272766, 25.8741684], [76.58528137, 25.86771965], [76.56678009, 25.83967018], [76.54946136, 25.82504082], [76.54164886, 25.81740189], [76.53549194, 25.80917168], [76.52931213, 25.79797173], [76.5226593, 25.77434158], [76.52223969, 25.76634026], [76.53040314, 25.74374008], [76.53061676, 25.73397064], [76.52655029, 25.73104286], [76.51075745, 25.73001289], [76.50299835, 25.72860909], [76.48239136, 25.71813011], [76.4779129, 25.70603943], [76.4777832, 25.69506073], [76.48175812, 25.68939972], [76.48906708, 25.68340111], [76.50779724, 25.67612076], [76.51080322, 25.67283821], [76.4994278, 25.64834023], [76.50076294, 25.64330292], [76.50538635, 25.63821983], [76.51077271, 25.63816833], [76.51473236, 25.63367844], [76.51579285, 25.60700989], [76.50985718, 25.5872097], [76.50978088, 25.57982063], [76.51239777, 25.5717926], [76.51634216, 25.56553078], [76.52027893, 25.55690002], [76.52220917, 25.55035973], [76.52246094, 25.54146957], [76.52030945, 25.52993011], [76.52259827, 25.52429008], [76.52854919, 25.51770973], [76.53456879, 25.51350021], [76.53787231, 25.51020813], [76.54016876, 25.50573921], [76.54210663, 25.4974308], [76.54669189, 25.48968124], [76.55066681, 25.48430824], [76.55632019, 25.47981071], [76.5595932, 25.47326088], [76.56066895, 25.44985008], [76.56427765, 25.44240189], [76.5742569, 25.4366703], [76.58297729, 25.43569183], [76.58896637, 25.43148994], [76.59905243, 25.40530014], [76.60254669, 25.38898087], [76.60585022, 25.38866997], [76.60957336, 25.38830948], [76.61487579, 25.3841095], [76.61686707, 25.38161278], [76.61915588, 25.37873077], [76.62262726, 25.37675095], [76.62549591, 25.37511063], [76.6362915, 25.38033104], [76.64360046, 25.37639809], [76.65750122, 25.36144066], [76.66483307, 25.35750961], [76.6727829, 25.35003281], [76.68107605, 25.34547997], [76.70321655, 25.34761047], [76.7145462, 25.34243965], [76.72229767, 25.34592056], [76.73204803, 25.34787941], [76.74040222, 25.34778976], [76.75372314, 25.33934021], [76.7587204, 25.33869171], [76.76673126, 25.33623123], [76.76669312, 25.33296967], [76.76584625, 25.33204079], [76.76225281, 25.32798958], [76.75984192, 25.32267952], [76.77009583, 25.31219101], [76.77282715, 25.31591034], [76.79527283, 25.32182121], [76.82174683, 25.3270607], [76.82614899, 25.32698059], [76.83348083, 25.32685089], [76.83976746, 25.32928848], [76.84297943, 25.33054161], [76.85373688, 25.32971191], [76.86699677, 25.32516289], [76.87258911, 25.32427979], [76.88156891, 25.32286072], [76.89322662, 25.32240105], [76.90463257, 25.31785965], [76.91535187, 25.30898094], [76.92295837, 25.30137825], [76.92920685, 25.29729843], [76.93260956, 25.28746986], [76.92870331, 25.27915192], [76.93393707, 25.27590179], [76.94182587, 25.27536011], [76.94838715, 25.27652168], [76.95272064, 25.2785511], [76.95526886, 25.2845993], [76.9566803, 25.29142761], [76.95874023, 25.29718018], [76.99266815, 25.30183029], [77.00337219, 25.30183029], [77.01010132, 25.30154037], [77.01760101, 25.30155945], [77.02419281, 25.30109024], [77.03412628, 25.3118782], [77.03804779, 25.31936073], [77.03936005, 25.32505035], [77.04479218, 25.32245064], [77.04817963, 25.3210907], [77.0530014, 25.32069016], [77.05825806, 25.32191277], [77.0634613, 25.32415009], [77.06785583, 25.32966995], [77.07142639, 25.33584023], [77.07546997, 25.33969116], [77.08306122, 25.33980179], [77.09262848, 25.33727074], [77.10176849, 25.33512115], [77.10811615, 25.33527946], [77.11576843, 25.33506012], [77.12142181, 25.33125114], [77.12890625, 25.32541847], [77.13630676, 25.32413292], [77.14900208, 25.31536293], [77.15355682, 25.31324959], [77.16159058, 25.31365013], [77.16776276, 25.31552124], [77.17340851, 25.31517029], [77.18210602, 25.31331062], [77.19055176, 25.31166077], [77.1973877, 25.31097984], [77.20514679, 25.31142998], [77.2003479, 25.3187294], [77.19860077, 25.32464981], [77.19815826, 25.33052063], [77.20526123, 25.33304977], [77.21070099, 25.33369064], [77.2131958, 25.33175087], [77.20942688, 25.32864952], [77.21039581, 25.32447052], [77.21502686, 25.32450104], [77.21803284, 25.33131027], [77.2173996, 25.33724976], [77.21701813, 25.34925079], [77.22113037, 25.36108017], [77.22026062, 25.37342834], [77.22564697, 25.37924957], [77.23467255, 25.38506126], [77.24415588, 25.38961029], [77.24964142, 25.39491081], [77.25995636, 25.39945984], [77.27295685, 25.41200256], [77.28298187, 25.42358971], [77.29556274, 25.43169022], [77.30529785, 25.4364109], [77.31690979, 25.43284035], [77.32923126, 25.4285717], [77.33706665, 25.42475128], [77.34371185, 25.42243195], [77.35434723, 25.42402267], [77.36134338, 25.41296005], [77.35764313, 25.40928841], [77.35395813, 25.4036293], [77.3497467, 25.39838028], [77.34610748, 25.39249992], [77.34426117, 25.38792992], [77.34467316, 25.38334084], [77.34474945, 25.3798027], [77.34841919, 25.37555122], [77.3516922, 25.37235069], [77.3538208, 25.36954117], [77.35604095, 25.3678894], [77.35511017, 25.36437988], [77.34391785, 25.33736038], [77.33641815, 25.3255806], [77.34934235, 25.32413292], [77.35317993, 25.33234978], [77.3637619, 25.33300018], [77.36580658, 25.32850075], [77.36894989, 25.32464981], [77.37178802, 25.32022095], [77.37364197, 25.31549263], [77.37462616, 25.31057167], [77.37480164, 25.30585098], [77.37377167, 25.30018044], [77.37336731, 25.29936981], [77.37258911, 25.29429054], [77.36946869, 25.28852844], [77.36672211, 25.28540039], [77.36302948, 25.28375816], [77.36000061, 25.28022003], [77.34966278, 25.27177048], [77.35668182, 25.26579094], [77.3602829, 25.26085281], [77.36203766, 25.25593185], [77.36271667, 25.25007057], [77.37046814, 25.2509594], [77.3755722, 25.24902153], [77.38004303, 25.24542046], [77.39164734, 25.23114967], [77.40081787, 25.22770119], [77.40640259, 25.22629166], [77.40952301, 25.21243095], [77.41133881, 25.20659065], [77.41372681, 25.19952965], [77.41799164, 25.1930294], [77.41475677, 25.18943024], [77.4076767, 25.19005966], [77.40306091, 25.1865406], [77.39070892, 25.18819046], [77.3913269, 25.17964935], [77.39129639, 25.17469978], [77.38961029, 25.16838837], [77.38918304, 25.15994072], [77.38931274, 25.15103912], [77.38739014, 25.13809013], [77.38694, 25.13296127], [77.38861084, 25.12725067], [77.39388275, 25.12330055], [77.39810944, 25.11641121], [77.39852905, 25.11327171], [77.39554596, 25.11199951], [77.39318848, 25.11528015], [77.39227295, 25.11741066], [77.38667297, 25.12195969], [77.37516022, 25.11681938], [77.36839294, 25.11413002], [77.36850739, 25.10849953], [77.36078644, 25.10434914], [77.35714722, 25.10155106], [77.34867859, 25.09779167], [77.33244324, 25.09657097], [77.32801819, 25.09340096], [77.32038116, 25.09070969], [77.31389618, 25.08756065], [77.3098526, 25.08639145], [77.30700684, 25.08575058], [77.30285645, 25.08386993], [77.29593658, 25.08710289], [77.29133606, 25.09411049], [77.28443146, 25.10421944], [77.2755661, 25.11213112], [77.26226044, 25.11926079], [77.24164581, 25.11272049], [77.22083282, 25.11024284], [77.20581055, 25.11242104], [77.1973877, 25.11667061], [77.18876648, 25.11180115], [77.18305969, 25.11180115], [77.16957855, 25.11371994], [77.1628418, 25.10972023], [77.1645813, 25.09856987], [77.15770721, 25.08827972], [77.14045715, 25.09090042], [77.14016724, 25.09620094], [77.12827301, 25.08905029], [77.11445618, 25.06908989], [77.10249329, 25.06924057], [77.09041595, 25.06636047], [77.08426666, 25.06264114], [77.07723236, 25.05798912], [77.06801605, 25.05969048], [77.0613327, 25.06139183], [77.0549469, 25.06326294], [77.04432678, 25.0657711], [77.03929901, 25.06810951], [77.02934265, 25.07189941], [77.02472687, 25.07180023], [77.02039337, 25.07143974], [77.01764679, 25.07217026], [77.01235199, 25.07491112], [77.00595093, 25.07856941], [77.00029755, 25.07973099], [76.99372864, 25.07995033], [76.9836731, 25.07756042], [76.97466278, 25.07067108], [76.97183228, 25.06683922], [76.97126007, 25.06058121], [76.96866608, 25.05594063], [76.96131134, 25.05398941], [76.95349884, 25.0484581], [76.92987823, 25.0415802], [76.91767883, 25.04003143], [76.90976715, 25.03567123], [76.90106201, 25.03404045], [76.88202667, 25.03409958], [76.87828064, 25.02583122], [76.87671661, 25.01993942], [76.87676239, 25.01801109], [76.87680817, 25.01606178], [76.87448883, 25.01311111], [76.8693161, 25.01110268], [76.86055756, 25.01038933], [76.85434723, 25.01031113], [76.85952759, 25.00691032], [76.86805725, 25.00136948], [76.86871338, 24.99751091], [76.86965942, 24.99189186], [76.86643982, 24.97179031], [76.86727905, 24.96544075], [76.87156677, 24.96130943], [76.87336731, 24.95757294], [76.87206268, 24.95460129], [76.87520599, 24.9509697], [76.87970734, 24.94576073], [76.89322662, 24.93542099], [76.89247131, 24.9290905], [76.89015961, 24.92305946], [76.89122772, 24.91967964], [76.9074173, 24.92325974], [76.92086792, 24.91678047], [76.92353058, 24.91426086], [76.92463684, 24.91037178], [76.92032623, 24.90488052], [76.91575623, 24.90118027], [76.91269684, 24.89724159], [76.91216278, 24.89313126], [76.91385651, 24.88788033], [76.91751862, 24.88479042], [76.92176819, 24.8837204], [76.93398285, 24.88428116], [76.93572998, 24.87868118], [76.94185638, 24.87470818], [76.9432373, 24.8745594], [76.94671631, 24.87419128], [76.9489212, 24.87286949], [76.94664001, 24.86825943], [76.94425964, 24.86547279], [76.94312286, 24.86005974], [76.9332428, 24.85394096], [76.9265213, 24.84978294], [76.91506195, 24.84869957], [76.91153717, 24.84760094], [76.90843201, 24.84509277], [76.89504242, 24.83950996], [76.8780899, 24.83955193], [76.86332703, 24.84169006], [76.85748291, 24.84098053], [76.85131073, 24.84023094], [76.84217834, 24.84011269], [76.83750153, 24.84106064], [76.83164978, 24.84024239], [76.82714081, 24.83835983], [76.82308197, 24.83485031], [76.81672668, 24.83249855], [76.81118774, 24.82823944], [76.80229187, 24.82657051], [76.80066681, 24.82456017], [76.80158234, 24.81983948], [76.80410767, 24.8166008], [76.80869293, 24.81497955], [76.8157196, 24.80367088], [76.82579041, 24.79338074], [76.83587646, 24.78507042], [76.84674072, 24.76999283], [76.84702301, 24.76505089], [76.84501648, 24.75213814], [76.84729767, 24.75040054], [76.86084747, 24.74869919], [76.86812592, 24.74958038], [76.88668823, 24.75415039], [76.89692688, 24.75060081], [76.8983078, 24.74777031], [76.90325928, 24.74604988], [76.90939331, 24.74681091], [76.92169189, 24.7488308], [76.94577789, 24.76404953], [76.95173645, 24.76546097], [76.95632172, 24.76431084], [76.96330261, 24.75955009], [76.96383667, 24.75045967], [76.96533203, 24.74410057], [76.96848297, 24.73608971], [76.97197723, 24.73167038], [76.98230743, 24.72487259], [76.99214172, 24.71739769], [77.00422668, 24.71366119], [77.01407623, 24.71541977], [77.01924896, 24.71495056], [77.02265167, 24.71372032], [77.0266571, 24.71092033], [77.03346252, 24.70294952], [77.03450012, 24.69846916], [77.03491974, 24.68856049], [77.03701019, 24.6827507], [77.04894257, 24.6613102], [77.05414581, 24.65410805], [77.05945587, 24.64241982], [77.06028748, 24.63770294], [77.06112671, 24.62458992], [77.06111908, 24.61050987], [77.06034851, 24.60609055], [77.05832672, 24.6011982], [77.05845642, 24.59481049], [77.06355286, 24.5853405], [77.06469727, 24.56991005], [77.06433868, 24.56412125], [77.06153107, 24.55477905], [77.05338287, 24.54417038], [77.05195618, 24.54125023], [77.05092621, 24.53714752], [77.05030823, 24.52653122], [77.03904724, 24.5266304], [77.0319519, 24.52879906], [77.02997589, 24.52705956], [77.02910614, 24.52376175], [77.02670288, 24.5214119], [77.02478027, 24.51704979], [77.02407074, 24.50132942], [77.0206604, 24.49793053], [77.01589203, 24.49489975], [77.01233673, 24.49436951], [77.00866699, 24.4949398], [77.0059967, 24.49394989], [77.00473022, 24.49196053], [77.00496674, 24.48938942], [77.00688934, 24.48755074], [77.00255585, 24.48349953], [77.00152588, 24.47789955], [76.99819946, 24.47548294], [76.99252319, 24.47344971], [76.97966003, 24.47462845], [76.97753906, 24.47198105], [76.9749527, 24.46492958], [76.96531677, 24.46086121], [76.96016693, 24.46022987], [76.95287323, 24.46393013], [76.94108582, 24.46735001], [76.93708801, 24.47239113], [76.93083954, 24.47669983], [76.92288208, 24.48065186], [76.91464996, 24.48765945], [76.91526031, 24.51140022], [76.91734314, 24.51696968], [76.91890717, 24.52439117], [76.91877747, 24.52998161], [76.91838074, 24.53560066], [76.91568756, 24.54038048], [76.91287231, 24.54356956], [76.90238953, 24.54752159], [76.89982605, 24.5478096], [76.89776611, 24.54370117], [76.8928833, 24.53969002], [76.89359283, 24.53545952], [76.88896942, 24.5267601], [76.87954712, 24.52531052], [76.87573242, 24.52618027], [76.87290192, 24.53203964], [76.87475586, 24.54045105], [76.87413025, 24.54305077], [76.87195587, 24.54589081], [76.86620331, 24.54936028], [76.85282135, 24.55101967], [76.84604645, 24.55101967], [76.8381958, 24.54846954], [76.83114624, 24.54319], [76.82675171, 24.53878021], [76.81902313, 24.53656006], [76.81459045, 24.53437042], [76.81416321, 24.53227997], [76.81442261, 24.52964973], [76.8192215, 24.52462006], [76.82810974, 24.51036263], [76.83454895, 24.49830055], [76.83532715, 24.49438095], [76.8423233, 24.49374008], [76.84527588, 24.49090004], [76.8467865, 24.48755074], [76.84629822, 24.47545815], [76.85057831, 24.47394943], [76.85132599, 24.46910858], [76.84897614, 24.46438026], [76.84844971, 24.45876122], [76.84591675, 24.4532795], [76.83862305, 24.45416069], [76.837883, 24.45058823], [76.84117126, 24.4428196], [76.85066223, 24.43736076], [76.85109711, 24.43539047], [76.84926605, 24.42525291], [76.84603119, 24.41934013], [76.84226227, 24.4181881], [76.83769226, 24.41808128], [76.83587646, 24.41657066], [76.8423996, 24.4085083], [76.8483429, 24.39627075], [76.8501358, 24.38896942], [76.84799957, 24.37883186], [76.85231781, 24.37486839], [76.85167694, 24.37024117], [76.84906006, 24.36820984], [76.83883667, 24.36470032], [76.83696747, 24.36070824], [76.83821106, 24.35495949], [76.83888245, 24.34262276], [76.84017944, 24.33872032], [76.84490967, 24.32798195], [76.85878754, 24.31231117], [76.85980225, 24.30529022], [76.86264038, 24.29883194], [76.86380005, 24.29381943], [76.86360931, 24.28976059], [76.86705017, 24.28085136], [76.86994171, 24.27658272], [76.87419891, 24.27108955], [76.89736176, 24.24708939], [76.90389252, 24.24167824], [76.91117096, 24.23761177], [76.9164505, 24.23196983], [76.91855621, 24.22640038], [76.91928864, 24.22068977], [76.9225769, 24.21679115], [76.9282608, 24.21354103], [76.93165588, 24.20953941], [76.9368515, 24.20979118], [76.94254303, 24.20835114], [76.94444275, 24.2062912], [76.94483185, 24.20330048], [76.94386292, 24.19885063], [76.9331665, 24.18687057], [76.92723846, 24.18666077], [76.9161377, 24.1887207], [76.91487122, 24.18337059], [76.91118622, 24.17690086], [76.90579987, 24.15319252], [76.89994049, 24.13111115], [76.88625336, 24.1317482], [76.87758636, 24.13492966], [76.87657166, 24.13837814], [76.87332916, 24.13978958], [76.86628723, 24.13883018], [76.85600281, 24.13894081], [76.84607697, 24.13614082], [76.84233093, 24.13227081], [76.83547211, 24.13125038], [76.82772827, 24.12559128], [76.82183075, 24.12667274], [76.81466675, 24.12651062], [76.80111694, 24.12034035], [76.79721832, 24.12181091], [76.7909317, 24.12575912], [76.77562714, 24.15307999], [76.77308655, 24.15877914], [76.76885986, 24.16468048], [76.76261902, 24.16421127], [76.7594986, 24.16586113], [76.75733948, 24.16970253], [76.75499725, 24.17209053], [76.74938202, 24.17254066], [76.73589325, 24.17184258], [76.72939301, 24.17056084], [76.72683716, 24.16508293], [76.72071075, 24.16172028], [76.71470642, 24.16418266], [76.71247864, 24.16662979], [76.70114136, 24.17144012], [76.69519043, 24.1760006], [76.6893692, 24.18370819], [76.68438721, 24.18864059], [76.67420959, 24.19342995], [76.6767807, 24.21054077], [76.68488312, 24.22483253], [76.68778229, 24.23245049], [76.69523621, 24.24207115], [76.69876099, 24.245121], [76.70249939, 24.24880028], [76.70137024, 24.2543602], [76.69967651, 24.2578392], [76.69664764, 24.26119995], [76.69480896, 24.26781273], [76.69330597, 24.27404976], [76.69491577, 24.28231049], [76.69296265, 24.28504944], [76.68476868, 24.28269005], [76.67874908, 24.27063942], [76.67082977, 24.27100945], [76.66829681, 24.26738167], [76.65821075, 24.26781273], [76.64724731, 24.27240944], [76.64245605, 24.27011108], [76.64222717, 24.26624107], [76.64006042, 24.26231956], [76.63482666, 24.26405907], [76.63008118, 24.26470947], [76.62336731, 24.26460838], [76.61634827, 24.26284027], [76.61395264, 24.24217987], [76.610466, 24.24148941], [76.60047913, 24.24497986], [76.59324646, 24.25089073], [76.58802032, 24.2495594], [76.58747864, 24.24604988], [76.5966568, 24.2352829], [76.59738922, 24.22991943], [76.59255981, 24.22387123], [76.58586121, 24.21956062], [76.57148743, 24.21347809], [76.567276, 24.20691109], [76.56577301, 24.20079994], [76.5669632, 24.19715118], [76.56980896, 24.19628906], [76.57698822, 24.19131088], [76.57972717, 24.18067932], [76.57266998, 24.1772995], [76.56632996, 24.17645073], [76.5625, 24.1724205], [76.55475616, 24.16822052], [76.5459671, 24.16801071], [76.53985596, 24.16674995], [76.53578186, 24.16421127], [76.53143311, 24.16346931], [76.52319336, 24.1631794], [76.51737976, 24.16657829], [76.51333618, 24.1728611], [76.51048279, 24.17902946], [76.50836945, 24.20023155], [76.50538635, 24.20546913], [76.50180054, 24.20903015], [76.49693298, 24.21203995], [76.48442078, 24.21504021], [76.47941589, 24.21751022], [76.47457123, 24.22870255], [76.46994781, 24.23139954], [76.46343231, 24.22891998], [76.46102142, 24.22541046], [76.45862579, 24.22085953], [76.45324707, 24.21682167], [76.44742584, 24.21774101], [76.44184113, 24.2218895], [76.43601227, 24.22500038], [76.42945099, 24.22706032], [76.42360687, 24.22694969], [76.4181366, 24.22435951], [76.42172241, 24.2206707], [76.42253113, 24.21422005], [76.41873169, 24.20833969], [76.41443634, 24.20742035], [76.41179657, 24.20955086], [76.40009308, 24.22278976], [76.39124298, 24.22561073], [76.3735199, 24.23769951], [76.3651886, 24.24131012], [76.36120605, 24.24448967], [76.35829926, 24.24607086], [76.35299683, 24.2489109], [76.34417725, 24.25189972], [76.33499146, 24.25396919], [76.32689667, 24.25361824], [76.31787872, 24.25113106], [76.31012726, 24.24638939], [76.3028717, 24.24443054], [76.29392242, 24.24067116], [76.28964996, 24.23703003], [76.28884125, 24.22557068], [76.28716278, 24.21825027], [76.28277588, 24.21571159], [76.27639771, 24.21651077], [76.26538086, 24.22154999], [76.25180817, 24.22481918], [76.24767303, 24.22792053], [76.24046326, 24.22618103], [76.23612213, 24.22388077], [76.22335052, 24.22327042], [76.21821594, 24.21738052], [76.21556854, 24.21680832], [76.21057129, 24.22284126], [76.20622253, 24.23274994], [76.205513, 24.2418499], [76.20363617, 24.25058937], [76.20437622, 24.26902008], [76.20218658, 24.27675056], [76.19465637, 24.28479958], [76.19560242, 24.29009819], [76.19908905, 24.29730034], [76.20498657, 24.30570984], [76.20623016, 24.31092072], [76.20252228, 24.31315994], [76.19402313, 24.32086945], [76.19004822, 24.32995033], [76.18548584, 24.33151054], [76.18112946, 24.3248806], [76.17212677, 24.31558037], [76.1713562, 24.31032944], [76.1725769, 24.30722046], [76.17002106, 24.30340958], [76.1692276, 24.29609108], [76.1627121, 24.29336166], [76.14952087, 24.29223061], [76.14666748, 24.29031944], [76.143013, 24.28528976], [76.14222717, 24.28115082], [76.1455307, 24.26576042], [76.14836121, 24.26403046], [76.14977264, 24.26098061], [76.15445709, 24.24376106], [76.15236664, 24.23545837], [76.14704895, 24.22776985], [76.14180756, 24.22384071], [76.13156891, 24.21244812], [76.12335968, 24.20540047], [76.12132263, 24.19639015], [76.12085724, 24.18359947], [76.11995697, 24.18013954], [76.12059784, 24.17823982], [76.1254425, 24.17814064], [76.12889099, 24.17485809], [76.13088989, 24.16905022], [76.13047028, 24.15366936], [76.13173676, 24.14394188], [76.13442993, 24.13933945], [76.1368866, 24.13133812], [76.1307373, 24.12290955], [76.12922668, 24.11893272], [76.13005066, 24.11214066], [76.13128662, 24.10662079], [76.13469696, 24.09972954], [76.13469696, 24.09528923], [76.12327576, 24.09233284], [76.11244965, 24.09650993], [76.1085968, 24.09712982], [76.10515594, 24.09590912], [76.09899902, 24.08918953], [76.09082794, 24.08574104], [76.08454132, 24.08214951], [76.08024597, 24.0839901], [76.06372833, 24.07790947], [76.05748749, 24.07785034], [76.04695892, 24.07567024], [76.04335022, 24.07396126], [76.0399704, 24.06690979], [76.03299713, 24.0642128], [76.02672577, 24.05046272], [76.01793671, 24.04455948], [76.00894165, 24.04030037], [76.00213623, 24.03523064], [76.00028229, 24.0354805], [75.99450684, 24.03190041], [75.99008942, 24.03006935], [75.97975159, 24.03104973], [75.97962189, 24.03209114], [75.97336578, 24.03144073], [75.96018219, 24.02536964], [75.95910645, 24.00997162], [75.96092987, 24.00427055], [75.96024323, 23.99746132], [75.96131897, 23.99484062], [75.96353149, 23.99165916], [75.97675323, 23.98195076], [75.97823334, 23.98007011], [75.98018646, 23.97438049], [75.98018646, 23.96875954], [75.98123169, 23.96241951], [75.97981262, 23.95215988], [75.98092651, 23.94301987], [75.9759903, 23.93898964], [75.97582245, 23.93293953], [75.97409058, 23.93153], [75.96652222, 23.92987061], [75.94822693, 23.92226028], [75.94658661, 23.92071152], [75.94433594, 23.91620827], [75.93808746, 23.91220856], [75.93180847, 23.90193939], [75.92695618, 23.9018898], [75.9212265, 23.90417099], [75.9054718, 23.89606285], [75.90126038, 23.89501953], [75.89655304, 23.8927002], [75.89393616, 23.89308167], [75.88878632, 23.89171982], [75.88633728, 23.8885994], [75.87861633, 23.88455963], [75.87236786, 23.88818169], [75.86709595, 23.89398956], [75.86351776, 23.895401], [75.86065674, 23.89558983], [75.85661316, 23.89400101], [75.85341644, 23.89420128], [75.84142303, 23.88843918], [75.83973694, 23.88256073], [75.83703613, 23.88132858], [75.83040619, 23.8847599], [75.81785583, 23.8793602], [75.81394196, 23.87426949], [75.80265808, 23.87111092], [75.79421997, 23.87430954], [75.79102325, 23.87215042], [75.78514862, 23.8653698], [75.78505707, 23.85980988], [75.78385162, 23.85773087], [75.77992249, 23.85470009], [75.77706146, 23.85387039], [75.7696228, 23.85444069], [75.7616272, 23.85688972], [75.75994873, 23.86199188], [75.75917053, 23.88132858], [75.75712585, 23.88418961], [75.74974823, 23.89002037], [75.7400589, 23.89422035], [75.73647308, 23.89409065], [75.73420715, 23.89952278], [75.73132324, 23.9015007], [75.72821808, 23.90209961], [75.72281647, 23.90061951], [75.71549225, 23.90151978], [75.71299744, 23.89995956], [75.71057892, 23.90040016], [75.70707703, 23.90288925], [75.70233154, 23.90405083], [75.7008667, 23.90127945], [75.70094299, 23.89491081], [75.69863892, 23.89122963], [75.69773865, 23.88772011], [75.69812775, 23.87710762], [75.70131683, 23.87495995], [75.70355225, 23.87543106], [75.70474243, 23.87475967], [75.70656586, 23.86818123], [75.71753693, 23.8647728], [75.72754669, 23.86450958], [75.72911072, 23.85820961], [75.72815704, 23.85505104], [75.72637177, 23.8534317], [75.72396088, 23.84801102], [75.72067261, 23.84678078], [75.71787262, 23.84698105], [75.71572113, 23.84559059], [75.71794891, 23.84004021], [75.71872711, 23.83236122], [75.72216797, 23.82691193], [75.72083282, 23.82364082], [75.7167511, 23.82212067], [75.71588135, 23.82102013], [75.71784973, 23.81903267], [75.71569061, 23.81705093], [75.71321869, 23.8164711], [75.70878601, 23.81809807], [75.70259094, 23.81713104], [75.69024658, 23.8196106], [75.68740082, 23.81925011], [75.68692017, 23.8176899], [75.68826294, 23.81408119], [75.69403839, 23.80455017], [75.69451904, 23.79754257], [75.69866943, 23.7918396], [75.69828796, 23.78800011], [75.69671631, 23.78528976], [75.69007874, 23.7759819], [75.68734741, 23.77333069], [75.68515015, 23.76664925], [75.68447876, 23.76056862]]]}}, {\\\"id\\\": \\\"27\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.30_1\\\", \\\"HASC_1\\\": \\\"IN.SK\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Sikkim\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 8.8, \\\"dalys_apm25_rate_6cod_mean_total\\\": 507.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1466.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 1974.0, \\\"geo-id\\\": 27, \\\"hpm25_child_popweighted\\\": 117.4, \\\"hpm25_female_popweighted\\\": 135.0, \\\"hpm25_male_popweighted\\\": 97.2, \\\"location\\\": \\\"Sikkim\\\", \\\"mort_apm25_6cod_mean_total\\\": 216.0, \\\"mort_hpm25_6cod_mean_total\\\": 565.0, \\\"mort_tpm25_6cod_mean_total\\\": 781.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[88.80600739, 27.41423988], [88.80712128, 27.41119957], [88.80805969, 27.40864182], [88.80932617, 27.40518951], [88.81009674, 27.40475845], [88.81009674, 27.40430069], [88.81136322, 27.40318108], [88.81175995, 27.40302086], [88.81175995, 27.40256119], [88.81745148, 27.40071106], [88.81920624, 27.39932251], [88.81925964, 27.39925575], [88.81932068, 27.39918327], [88.82083893, 27.39736938], [88.82170105, 27.39571953], [88.82238007, 27.39408112], [88.82536316, 27.39143944], [88.82536316, 27.39099121], [88.82536316, 27.39056015], [88.83119965, 27.38875008], [88.8327179, 27.38651085], [88.83316803, 27.38651085], [88.83349609, 27.38651085], [88.83348846, 27.38605118], [88.83423615, 27.38583946], [88.83444214, 27.38460732], [88.83473206, 27.38290024], [88.83551788, 27.38244057], [88.83831024, 27.37882996], [88.83982849, 27.37815857], [88.84134674, 27.37770081], [88.84234619, 27.37794113], [88.84411621, 27.37907982], [88.84451294, 27.37973022], [88.84718323, 27.38085938], [88.84829712, 27.38268089], [88.84835815, 27.38276863], [88.84895325, 27.38360023], [88.85270691, 27.38632965], [88.85653687, 27.38677979], [88.85883331, 27.38586998], [88.8616333, 27.38361931], [88.86213684, 27.38250923], [88.86313629, 27.38068008], [88.86466217, 27.37977028], [88.86721802, 27.36824989], [88.86875153, 27.36736107], [88.86942291, 27.36718178], [88.87046814, 27.36688614], [88.87915039, 27.36444092], [88.87924957, 27.36437416], [88.88098907, 27.3631897], [88.88320923, 27.35766029], [88.88506317, 27.34680939], [88.88561249, 27.34550858], [88.88861084, 27.33844185], [88.88910675, 27.3382206], [88.88986206, 27.33640099], [88.89393616, 27.33394051], [88.89395142, 27.33346939], [88.89599609, 27.33305168], [88.89714813, 27.333395], [88.90054321, 27.33440971], [88.90693665, 27.33067322], [88.90786743, 27.33012962], [88.90916443, 27.33041573], [88.91194916, 27.33102989], [88.91416168, 27.3302002], [88.9153595, 27.32963371], [88.91945648, 27.32769966], [88.91963196, 27.3269043], [88.91938019, 27.3246212], [88.91956329, 27.32340431], [88.91962433, 27.32299614], [88.91965485, 27.32242203], [88.91973114, 27.32100105], [88.91811371, 27.31842422], [88.91690826, 27.31633759], [88.91537476, 27.314291], [88.91402435, 27.31240845], [88.91353607, 27.31085777], [88.91268921, 27.30901909], [88.91215515, 27.30811882], [88.91016388, 27.30631447], [88.90944672, 27.30516815], [88.90939331, 27.30491829], [88.90914154, 27.30382156], [88.9091568, 27.30219269], [88.90916443, 27.30173302], [88.90917206, 27.3004837], [88.90916443, 27.30033302], [88.90913391, 27.29909897], [88.91040802, 27.29741096], [88.91077423, 27.29692841], [88.9111557, 27.29570007], [88.91218567, 27.29349518], [88.91339111, 27.2918644], [88.91441345, 27.29006958], [88.91387939, 27.28891754], [88.91123962, 27.28643799], [88.91043091, 27.28421974], [88.90834808, 27.28149796], [88.90791321, 27.27911758], [88.90785217, 27.27667809], [88.90583801, 27.27516747], [88.90428925, 27.27384377], [88.90058899, 27.27396393], [88.89971924, 27.27266312], [88.89579773, 27.27017403], [88.89333344, 27.26908875], [88.89031219, 27.26808167], [88.88747406, 27.2675705], [88.88609314, 27.26764107], [88.88398743, 27.26713371], [88.87896729, 27.26123619], [88.87776184, 27.26146698], [88.87693024, 27.26171684], [88.87621307, 27.26193237], [88.87521362, 27.26222229], [88.87413788, 27.26251411], [88.87283325, 27.26281929], [88.87123108, 27.26330757], [88.86985779, 27.26379776], [88.86728668, 27.2646389], [88.86647797, 27.26477623], [88.8631134, 27.26467705], [88.86006927, 27.26465416], [88.85734558, 27.2645607], [88.85349274, 27.26403046], [88.84916687, 27.26385307], [88.84468079, 27.26345825], [88.84211731, 27.26322365], [88.83631134, 27.26281357], [88.83410645, 27.26265717], [88.83300781, 27.26269722], [88.83245087, 27.26261711], [88.83132172, 27.26245308], [88.82805634, 27.2574482], [88.82294464, 27.25533104], [88.81911469, 27.25393677], [88.81535339, 27.25261688], [88.81048584, 27.25099945], [88.8032074, 27.2479744], [88.80292511, 27.24640656], [88.80345154, 27.24470711], [88.80401611, 27.24323273], [88.80449677, 27.24126434], [88.80438995, 27.24005318], [88.80400085, 27.23856544], [88.80310059, 27.23582649], [88.80265045, 27.2329464], [88.80266571, 27.23155022], [88.80268097, 27.23015213], [88.8026886, 27.22933006], [88.80265808, 27.22830582], [88.80266571, 27.22744942], [88.80261993, 27.22621346], [88.80270386, 27.2238369], [88.8028717, 27.22298241], [88.80325317, 27.22151184], [88.80285645, 27.22037888], [88.80241394, 27.21853447], [88.80155945, 27.21757698], [88.80130768, 27.21662331], [88.80078888, 27.2151947], [88.80013275, 27.21382332], [88.79981995, 27.21221733], [88.7995224, 27.20853233], [88.79883575, 27.20664024], [88.79767609, 27.20572853], [88.79689026, 27.20453262], [88.795578, 27.20295334], [88.79495239, 27.20142555], [88.79154205, 27.19683266], [88.78980255, 27.19638634], [88.78900909, 27.19558144], [88.78875732, 27.19532776], [88.7888031, 27.19466209], [88.78877258, 27.19392776], [88.78890228, 27.19270325], [88.78915405, 27.19135666], [88.7891922, 27.19113159], [88.78916931, 27.19073486], [88.78910828, 27.18955994], [88.78909302, 27.18925858], [88.78890228, 27.18866348], [88.78878021, 27.18771172], [88.78839111, 27.18651962], [88.78807831, 27.18467522], [88.78684998, 27.18199348], [88.78470612, 27.18201637], [88.78379059, 27.18202591], [88.7828598, 27.18231583], [88.78179169, 27.18266296], [88.78079224, 27.18307114], [88.77979279, 27.18341827], [88.77872467, 27.18370628], [88.77706146, 27.18357468], [88.77488708, 27.18266487], [88.77322388, 27.18235397], [88.77176666, 27.18216324], [88.76965332, 27.18119621], [88.76851654, 27.18031693], [88.76675415, 27.17903328], [88.76622772, 27.17858315], [88.76556396, 27.17801476], [88.76431274, 27.17723083], [88.76301575, 27.17440605], [88.76229858, 27.17281723], [88.7615509, 27.17196274], [88.76072693, 27.17102242], [88.7600708, 27.17048264], [88.75902557, 27.16875076], [88.75852966, 27.16798019], [88.75752258, 27.16641998], [88.75693512, 27.1654644], [88.75701141, 27.1642189], [88.75756073, 27.16279793], [88.75797272, 27.16119766], [88.75693512, 27.15881157], [88.75747681, 27.15798569], [88.75844574, 27.15692139], [88.75935364, 27.15621948], [88.75958252, 27.15492439], [88.75963593, 27.15461731], [88.76019287, 27.15283966], [88.75839996, 27.15139771], [88.75678253, 27.14823723], [88.75163269, 27.14818192], [88.75152588, 27.14815331], [88.75138092, 27.14811707], [88.74920654, 27.14765358], [88.74711609, 27.14557457], [88.74694061, 27.14536476], [88.73718262, 27.13952065], [88.73253632, 27.13735008], [88.72454071, 27.13852119], [88.71779633, 27.14397049], [88.71496582, 27.15023994], [88.71180725, 27.16514969], [88.70197296, 27.17411041], [88.6914978, 27.17869949], [88.6844101, 27.18022919], [88.68036652, 27.17951012], [88.67350006, 27.17661095], [88.66806793, 27.17198944], [88.6595993, 27.16221046], [88.65645599, 27.1624012], [88.64248657, 27.16715813], [88.6387558, 27.16772079], [88.63327789, 27.17453003], [88.61901855, 27.18785286], [88.60678864, 27.18966103], [88.60352325, 27.19115257], [88.59810638, 27.19137192], [88.59751892, 27.19271088], [88.59400177, 27.19118118], [88.59147644, 27.19445992], [88.58702087, 27.19053268], [88.58509064, 27.19283295], [88.56629181, 27.18786049], [88.55899048, 27.18875122], [88.54084015, 27.1837101], [88.52899933, 27.17776108], [88.52075195, 27.17818069], [88.52047729, 27.17502975], [88.52980804, 27.16579056], [88.52672577, 27.1602726], [88.5320282, 27.1543293], [88.52993011, 27.1501503], [88.52674103, 27.14977264], [88.52171326, 27.15034294], [88.51870728, 27.14780045], [88.51596069, 27.1437397], [88.51222992, 27.14103127], [88.50750732, 27.13599014], [88.50295258, 27.13405037], [88.49890137, 27.13121986], [88.49640656, 27.12815285], [88.4956131, 27.12536049], [88.49185181, 27.1248703], [88.48668671, 27.12677956], [88.48127747, 27.12285042], [88.47377777, 27.12070084], [88.46907806, 27.11730194], [88.46672058, 27.11394119], [88.46479797, 27.10479164], [88.46018219, 27.09584999], [88.45449829, 27.0896492], [88.44628143, 27.08539963], [88.43962097, 27.08416939], [88.4319458, 27.08160973], [88.42914581, 27.08362007], [88.41100311, 27.09070015], [88.3976593, 27.09443092], [88.38751984, 27.09840965], [88.37065125, 27.09941292], [88.36387634, 27.0984211], [88.35230255, 27.1010704], [88.34793854, 27.10332108], [88.34516144, 27.10690117], [88.34079742, 27.11067009], [88.33174133, 27.10816765], [88.32383728, 27.10490036], [88.32007599, 27.10732079], [88.32048798, 27.11664009], [88.31881714, 27.1193409], [88.31127167, 27.12535095], [88.30449677, 27.12860107], [88.29988861, 27.12799835], [88.29490662, 27.12477112], [88.27813721, 27.13083076], [88.27735138, 27.13119125], [88.27088928, 27.13013077], [88.26345825, 27.12737083], [88.25154877, 27.12536049], [88.24006653, 27.12037086], [88.2325058, 27.11976814], [88.22690582, 27.12138939], [88.22151184, 27.12527084], [88.21383667, 27.1351223], [88.20986938, 27.13340187], [88.19561768, 27.13623047], [88.18850708, 27.13442039], [88.18367767, 27.1352005], [88.17899323, 27.13471031], [88.17260742, 27.1303196], [88.15843964, 27.11435127], [88.15544128, 27.1121006], [88.15231323, 27.11170959], [88.14377594, 27.11707115], [88.1366272, 27.11687851], [88.12690735, 27.12308121], [88.12329102, 27.12379074], [88.09593964, 27.13550949], [88.09266663, 27.13627815], [88.08863831, 27.13875008], [88.08584595, 27.14151001], [88.08383179, 27.14501953], [88.08299255, 27.14893913], [88.08390808, 27.16106987], [88.08325958, 27.16504288], [88.0786972, 27.16792107], [88.07309723, 27.1744175], [88.07232666, 27.17934036], [88.06926727, 27.18494987], [88.06745148, 27.19026947], [88.0688324, 27.1943512], [88.07540894, 27.19880104], [88.07495117, 27.20084], [88.0682373, 27.20473099], [88.06433868, 27.20783043], [88.06173706, 27.2112999], [88.05819702, 27.21389008], [88.04676056, 27.21611023], [88.03292847, 27.22103119], [88.02398682, 27.22066116], [88.01696777, 27.21887207], [88.021492, 27.22472954], [88.02162933, 27.22888565], [88.02185822, 27.23554611], [88.02431488, 27.23741531], [88.02745819, 27.23690796], [88.02684021, 27.24175644], [88.03031921, 27.24911499], [88.03341675, 27.24971581], [88.03338623, 27.25157928], [88.03321838, 27.26301575], [88.0344162, 27.26561546], [88.03291321, 27.27171516], [88.03561401, 27.28141594], [88.03429413, 27.28599548], [88.04076385, 27.29143524], [88.04650879, 27.29244232], [88.04364014, 27.30112648], [88.04411316, 27.30401611], [88.04771423, 27.30985641], [88.05111694, 27.31231499], [88.05203247, 27.31844711], [88.05522156, 27.32430077], [88.06273651, 27.32825661], [88.06611633, 27.33411598], [88.06921387, 27.33558083], [88.06885529, 27.33664131], [88.06731415, 27.34101486], [88.06563568, 27.34269524], [88.06441498, 27.34391594], [88.06243896, 27.34927559], [88.06026459, 27.35534096], [88.0528183, 27.35831451], [88.04441833, 27.37071609], [88.04761505, 27.37971497], [88.04672241, 27.38429642], [88.0473175, 27.38961601], [88.04846191, 27.39548111], [88.05111694, 27.40061569], [88.04941559, 27.40521622], [88.05219269, 27.40691376], [88.05321503, 27.41261482], [88.0594635, 27.41804504], [88.0607605, 27.41822243], [88.06912994, 27.42461395], [88.06971741, 27.4250145], [88.08261871, 27.42641449], [88.08288574, 27.429533], [88.08213043, 27.43057823], [88.08211517, 27.43071556], [88.0819931, 27.43076897], [88.08126831, 27.43176842], [88.07541656, 27.43361473], [88.07525635, 27.43377876], [88.07086945, 27.43816185], [88.07048035, 27.43853188], [88.07410431, 27.44385338], [88.07501984, 27.44521904], [88.06981659, 27.44931602], [88.06896973, 27.45215034], [88.06812286, 27.4527359], [88.06970978, 27.45761871], [88.06300354, 27.46084785], [88.06274414, 27.46129227], [88.05931854, 27.46721458], [88.05873108, 27.46761513], [88.05380249, 27.47153664], [88.05251312, 27.4718895], [88.0466156, 27.47841454], [88.04780579, 27.48134232], [88.04660034, 27.48470879], [88.04720306, 27.49265862], [88.04633331, 27.49576569], [88.04921722, 27.50121498], [88.05342865, 27.50409698], [88.05741882, 27.50431442], [88.06011963, 27.5092144], [88.06411743, 27.51181602], [88.06002045, 27.516716], [88.06401825, 27.52511597], [88.06983948, 27.52609253], [88.06781769, 27.52931595], [88.06613159, 27.52990913], [88.06241608, 27.53121567], [88.0620575, 27.53271866], [88.06166077, 27.53463364], [88.06163025, 27.53479195], [88.06350708, 27.53975487], [88.06771851, 27.54451561], [88.07120514, 27.54610062], [88.07182312, 27.55554581], [88.0786438, 27.55841637], [88.08361816, 27.56461525], [88.08201599, 27.56809807], [88.07781982, 27.57181549], [88.08713531, 27.5890007], [88.09541321, 27.59731483], [88.10821533, 27.6023159], [88.11631775, 27.61034966], [88.11688232, 27.61403847], [88.11791992, 27.62081528], [88.12213135, 27.62702942], [88.11991882, 27.62951469], [88.12329102, 27.63921356], [88.12262726, 27.64526749], [88.13381958, 27.65511513], [88.13981628, 27.65721512], [88.14026642, 27.65771103], [88.14725494, 27.66540337], [88.14822388, 27.67155266], [88.14941406, 27.67881584], [88.15032959, 27.68122292], [88.15135956, 27.68379593], [88.15742493, 27.69042015], [88.15099335, 27.70168114], [88.15090942, 27.70166016], [88.15071106, 27.70200729], [88.15197754, 27.70790482], [88.1581192, 27.71721458], [88.15733337, 27.72915459], [88.16104889, 27.74061775], [88.17235565, 27.74134064], [88.18121338, 27.74681473], [88.17931366, 27.75811577], [88.18344116, 27.76150322], [88.18603516, 27.7660656], [88.1852417, 27.76721954], [88.18421936, 27.76881599], [88.18423462, 27.76921272], [88.18441772, 27.77451515], [88.18789673, 27.77700043], [88.19075012, 27.78123665], [88.19794464, 27.78632927], [88.19992065, 27.79052925], [88.19649506, 27.79600334], [88.19252014, 27.79791451], [88.18951416, 27.80121613], [88.18789673, 27.81030655], [88.18152618, 27.8155365], [88.17998505, 27.81602859], [88.17611694, 27.81731606], [88.17572021, 27.82021523], [88.19013214, 27.82509613], [88.19721985, 27.83551598], [88.1993866, 27.83609581], [88.20392609, 27.83731461], [88.20401001, 27.84240532], [88.20069122, 27.84551048], [88.20016479, 27.84796906], [88.19891357, 27.85351563], [88.19552612, 27.85453224], [88.19101715, 27.8537159], [88.18789673, 27.85653687], [88.1834259, 27.85645676], [88.18093872, 27.85641289], [88.17705536, 27.86096954], [88.17521667, 27.86312294], [88.17462158, 27.86336708], [88.16975403, 27.86536026], [88.16856384, 27.86655235], [88.16689301, 27.86821747], [88.15657806, 27.8704567], [88.15634918, 27.87072182], [88.15131378, 27.87651443], [88.14561462, 27.8781147], [88.14191437, 27.8774147], [88.13754272, 27.88149261], [88.12998199, 27.8815155], [88.13020325, 27.88191986], [88.12992859, 27.88593864], [88.12738037, 27.89129066], [88.12628174, 27.8950901], [88.12576294, 27.89532089], [88.12522888, 27.8964386], [88.12294769, 27.89759064], [88.12245941, 27.89883041], [88.1216507, 27.90027046], [88.11959076, 27.902071], [88.1187973, 27.90250969], [88.11750793, 27.90559959], [88.11675262, 27.90602112], [88.11660004, 27.90718079], [88.1138916, 27.91219139], [88.11366272, 27.91583824], [88.1135788, 27.91761017], [88.11680603, 27.92578125], [88.12586975, 27.93442917], [88.1288681, 27.93829918], [88.12895203, 27.93984985], [88.12880707, 27.94552994], [88.123703, 27.94798088], [88.12365723, 27.95024109], [88.123909, 27.9509201], [88.12998199, 27.95594025], [88.13308716, 27.96161079], [88.13474274, 27.96298027], [88.13906097, 27.96348], [88.13981628, 27.96326065], [88.14000702, 27.96318245], [88.14676666, 27.96051407], [88.14720154, 27.96034241], [88.15368652, 27.95778084], [88.1672287, 27.94827271], [88.17362213, 27.94470978], [88.17566681, 27.94427109], [88.18276215, 27.94356155], [88.18865967, 27.94367981], [88.19293213, 27.94545174], [88.19476318, 27.94621086], [88.19554901, 27.94691849], [88.19576263, 27.94711113], [88.19713593, 27.95050049], [88.19922638, 27.95796967], [88.19970703, 27.96047974], [88.20028687, 27.96148491], [88.20259094, 27.9654808], [88.20349121, 27.96615028], [88.20347595, 27.96661949], [88.20980835, 27.96778107], [88.21130371, 27.96715927], [88.21411896, 27.96599007], [88.215271, 27.96557045], [88.2158432, 27.96536064], [88.21663666, 27.96496773], [88.21801758, 27.96446037], [88.22157288, 27.96401978], [88.22233582, 27.9642601], [88.22312927, 27.96447754], [88.22615051, 27.96722031], [88.22969818, 27.9679203], [88.23018646, 27.96777344], [88.23046875, 27.96768951], [88.23097992, 27.96722031], [88.23277283, 27.96587944], [88.23297119, 27.96492195], [88.23517609, 27.95413971], [88.23747253, 27.95259094], [88.23771667, 27.95146942], [88.23773193, 27.95055008], [88.23825073, 27.95034981], [88.23825836, 27.94989014], [88.24388885, 27.94853973], [88.24793243, 27.95010185], [88.24817657, 27.95019531], [88.24824524, 27.95028305], [88.24843597, 27.95083046], [88.25882721, 27.95631981], [88.26085663, 27.95656967], [88.2616272, 27.95634079], [88.26519775, 27.95659065], [88.27052307, 27.95831108], [88.27102661, 27.95808029], [88.2712326, 27.95817184], [88.27153778, 27.95831108], [88.27204895, 27.95844078], [88.27482605, 27.96051025], [88.27561188, 27.96123505], [88.27671051, 27.96436119], [88.27681732, 27.9654808], [88.27948761, 27.9673214], [88.28005981, 27.96761131], [88.28038025, 27.96778107], [88.28607178, 27.96846199], [88.29007721, 27.96894073], [88.29386139, 27.96806908], [88.30478668, 27.96996117], [88.3088913, 27.97268105], [88.31005096, 27.97398949], [88.31391907, 27.97836113], [88.31619263, 27.97972107], [88.32290649, 27.98131943], [88.3239212, 27.98110008], [88.32749939, 27.98192024], [88.32914734, 27.98250008], [88.33183289, 27.98475075], [88.33242798, 27.98590088], [88.33502197, 27.98702049], [88.33776093, 27.98798943], [88.34519196, 27.98948097], [88.3502121, 27.98962975], [88.35098267, 27.98985291], [88.3542099, 27.98941994], [88.3637619, 27.98814011], [88.37474823, 27.98367119], [88.38166046, 27.97986984], [88.38166046, 27.97940826], [88.38880157, 27.97784042], [88.38980103, 27.97808075], [88.39402008, 27.97973061], [88.39605713, 27.98110008], [88.40071869, 27.98334122], [88.40200043, 27.98359108], [88.40428925, 27.98674011], [88.40656281, 27.98789978], [88.40879822, 27.99244118], [88.40994263, 27.99356842], [88.41172791, 27.99562073], [88.41233063, 27.99698067], [88.42350006, 28.00563049], [88.42347717, 28.00606918], [88.42475891, 28.00653076], [88.42653656, 28.00811958], [88.42707062, 28.00832939], [88.43258667, 28.01040077], [88.45094299, 28.01501083], [88.45585632, 28.01719856], [88.46160126, 28.01980972], [88.4646225, 28.02319908], [88.46917725, 28.0328598], [88.4716568, 28.03680992], [88.47798157, 28.04257965], [88.4818573, 28.04500961], [88.48311615, 28.04558754], [88.4896698, 28.04807854], [88.50113678, 28.04893112], [88.50167084, 28.04869843], [88.50166321, 28.0482502], [88.50167847, 28.04779053], [88.50292969, 28.04713058], [88.50699615, 28.04648018], [88.516716, 28.0440197], [88.52083588, 28.0410881], [88.52110291, 28.04018021], [88.52108002, 28.03973961], [88.52236938, 28.03905106], [88.52236176, 28.03858948], [88.52776337, 28.03682137], [88.53154755, 28.03638077], [88.53334045, 28.03661919], [88.53801727, 28.03848076], [88.53824615, 28.0385704], [88.53894806, 28.03889084], [88.54097748, 28.04047966], [88.54273987, 28.04412079], [88.5428772, 28.04968262], [88.5429306, 28.05046082], [88.54367828, 28.05252075], [88.54505157, 28.05387115], [88.54881287, 28.0589447], [88.55042267, 28.06112099], [88.55177307, 28.06381035], [88.55227661, 28.06540108], [88.55246735, 28.07761955], [88.55445099, 28.08483124], [88.55828094, 28.08756065], [88.56691742, 28.08898163], [88.56774902, 28.08846092], [88.57076263, 28.0865097], [88.57483673, 28.08560944], [88.57657623, 28.08628082], [88.58551025, 28.09017181], [88.58756256, 28.09130096], [88.58908081, 28.09153938], [88.59037018, 28.09131813], [88.59516907, 28.09563065], [88.59604645, 28.09692955], [88.60279083, 28.0983696], [88.60540771, 28.09966087], [88.6134491, 28.10256004], [88.61646271, 28.10367966], [88.6135788, 28.10869026], [88.61215973, 28.10993195], [88.61155701, 28.11577988], [88.61083221, 28.11874008], [88.610466, 28.11963081], [88.60688782, 28.12281036], [88.6067276, 28.12618065], [88.60746765, 28.12755013], [88.61181641, 28.12961006], [88.62123871, 28.13096809], [88.62523651, 28.12826157], [88.62687683, 28.12714958], [88.62687683, 28.12668991], [88.62689209, 28.12626076], [88.62895203, 28.1246891], [88.62969971, 28.12446976], [88.62970734, 28.12401962], [88.63049316, 28.12379837], [88.63173676, 28.12109756], [88.63226318, 28.12086105], [88.63276672, 28.12063026], [88.63506317, 28.1130619], [88.63639069, 28.10868263], [88.63768768, 28.10437012], [88.63935852, 28.10311127], [88.64124298, 28.10172081], [88.64525604, 28.09912109], [88.65410614, 28.08983994], [88.66110229, 28.07963943], [88.66677094, 28.07407951], [88.67280579, 28.07283974], [88.67331696, 28.07307053], [88.67363739, 28.07327271], [88.67510986, 28.07420158], [88.67711639, 28.07737923], [88.68579865, 28.07897949], [88.69522095, 28.07698059], [88.69785309, 28.07736969], [88.70388794, 28.07813072], [88.71434021, 28.07569122], [88.71943665, 28.07637024], [88.72914124, 28.07528114], [88.74034882, 28.07599068], [88.7480545, 28.07406616], [88.75108337, 28.07331276], [88.75361633, 28.07193947], [88.75363922, 28.07150078], [88.75614929, 28.06971169], [88.76803589, 28.06124115], [88.7682724, 28.0606308], [88.76880646, 28.0606308], [88.76912689, 28.06040001], [88.77075195, 28.05912018], [88.77074432, 28.0589447], [88.77073669, 28.05866051], [88.77076721, 28.05820084], [88.77332306, 28.05686188], [88.7822876, 28.05076981], [88.782547, 28.04961967], [88.7828064, 28.04849052], [88.78356171, 28.04803276], [88.78431702, 28.0476017], [88.78562164, 28.04424095], [88.78663635, 28.04355049], [88.78663635, 28.04310036], [88.79471588, 28.03704262], [88.79473114, 28.03659821], [88.79498291, 28.0363903], [88.7960968, 28.03590012], [88.79749298, 28.03277969], [88.79766083, 28.0324707], [88.79943085, 28.0311203], [88.79944611, 28.03069115], [88.80226898, 28.02877426], [88.80532837, 28.02670097], [88.80532837, 28.02625084], [88.80560303, 28.02609062], [88.80786896, 28.02527046], [88.8167038, 28.02098083], [88.81925964, 28.01974106], [88.82070923, 28.01897812], [88.8253479, 28.01705933], [88.82905579, 28.01515961], [88.832901, 28.01153946], [88.83463287, 28.00040817], [88.83564758, 27.99949074], [88.83571625, 27.99912071], [88.83625031, 27.99889946], [88.83625031, 27.99821281], [88.83677673, 27.99685097], [88.83905792, 27.99505997], [88.84088135, 27.99100113], [88.84029388, 27.97680283], [88.83981323, 27.96523094], [88.83995819, 27.96410942], [88.84300995, 27.96161079], [88.84407043, 27.95642281], [88.83972931, 27.95279121], [88.83644867, 27.94735909], [88.83641815, 27.94491959], [88.83625031, 27.93200111], [88.8395462, 27.93041992], [88.84178162, 27.92983055], [88.85353088, 27.92673111], [88.85443878, 27.92648888], [88.85894775, 27.92527008], [88.86123657, 27.92346191], [88.86480713, 27.91306114], [88.86682892, 27.90909958], [88.87023163, 27.90242958], [88.87071991, 27.90243912], [88.8707428, 27.90197945], [88.87146759, 27.90181923], [88.87725067, 27.89749146], [88.87967682, 27.89567947], [88.87966156, 27.89525986], [88.88018799, 27.89524078], [88.88046265, 27.89365959], [88.88050079, 27.89320946], [88.88101196, 27.89320946], [88.8813858, 27.89253044], [88.88136292, 27.88904953], [88.88093567, 27.88638306], [88.87996674, 27.88031006], [88.88076782, 27.87014008], [88.88089752, 27.86984062], [88.88176727, 27.86787033], [88.88456726, 27.86539078], [88.88574219, 27.86133766], [88.88564301, 27.85905838], [88.88539886, 27.85891724], [88.88297272, 27.85749054], [88.88286591, 27.85703087], [88.88209534, 27.85544205], [88.88208771, 27.85530853], [88.8809967, 27.83896065], [88.88038635, 27.83760071], [88.87896729, 27.83714104], [88.87782288, 27.83624077], [88.87709045, 27.83397102], [88.87666321, 27.83337975], [88.87623596, 27.83263016], [88.87528229, 27.83106995], [88.87303162, 27.82739067], [88.86830139, 27.82454109], [88.86752319, 27.82460022], [88.86553955, 27.82368088], [88.86234283, 27.82175064], [88.85573578, 27.81812286], [88.8553772, 27.81788826], [88.85426331, 27.8165226], [88.85412598, 27.81495094], [88.85463715, 27.81474113], [88.85476685, 27.81360054], [88.85527039, 27.81245041], [88.85732269, 27.81134033], [88.85745239, 27.80816269], [88.85682678, 27.79887962], [88.85233307, 27.77832031], [88.85260773, 27.7683506], [88.85431671, 27.76037025], [88.85457611, 27.75933075], [88.85592651, 27.75694084], [88.85694885, 27.75601959], [88.85752869, 27.75459099], [88.85852814, 27.75369072], [88.85952759, 27.7530098], [88.86136627, 27.74894142], [88.86238098, 27.73900032], [88.86107635, 27.73583031], [88.85428619, 27.7301712], [88.85372925, 27.72914505], [88.85151672, 27.72405052], [88.85051727, 27.71820068], [88.8500061, 27.7175312], [88.84127808, 27.71206284], [88.83888245, 27.71116257], [88.83862305, 27.7104702], [88.83863831, 27.70821953], [88.83940125, 27.7057209], [88.83988953, 27.70551109], [88.84040833, 27.7052784], [88.84117889, 27.70281029], [88.84552765, 27.70031166], [88.84552002, 27.6944313], [88.84416962, 27.68892288], [88.84449768, 27.6859417], [88.84500885, 27.68161964], [88.84526062, 27.6807003], [88.84545898, 27.68008041], [88.84673309, 27.67558289], [88.84661102, 27.66904068], [88.84661102, 27.66889954], [88.84562683, 27.66723824], [88.84310913, 27.6629982], [88.83843994, 27.65871048], [88.83679199, 27.65756989], [88.8341217, 27.65332222], [88.83223724, 27.65032959], [88.82601929, 27.64546967], [88.82232666, 27.64283943], [88.82073212, 27.64229012], [88.81981659, 27.64194107], [88.81552887, 27.64266968], [88.81375122, 27.64332008], [88.8132019, 27.64352036], [88.81067657, 27.64282036], [88.80990601, 27.64191818], [88.80713654, 27.63625908], [88.80639648, 27.6321907], [88.8082428, 27.61912918], [88.8085022, 27.61433029], [88.80797577, 27.61363983], [88.80548859, 27.6032505], [88.80195618, 27.59984016], [88.80095673, 27.59961128], [88.80098724, 27.59918022], [88.80046082, 27.59917259], [88.80046082, 27.59871101], [88.79789734, 27.59646034], [88.79740906, 27.59646034], [88.79741669, 27.59600258], [88.79457092, 27.59399986], [88.79406738, 27.59399986], [88.79280853, 27.59198952], [88.79177856, 27.5906105], [88.78853607, 27.58806992], [88.78726959, 27.58557129], [88.78557587, 27.57628059], [88.78481293, 27.57538033], [88.78368378, 27.57448006], [88.78227997, 27.57336044], [88.76847839, 27.56799889], [88.76822662, 27.5678997], [88.76822662, 27.56743813], [88.76732635, 27.56677246], [88.76706696, 27.56496048], [88.76786804, 27.55997086], [88.7684021, 27.5597496], [88.76891327, 27.55952263], [88.77311707, 27.54450989], [88.77510071, 27.53759956], [88.77554321, 27.53728294], [88.77635956, 27.53672028], [88.77913666, 27.53400993], [88.77990723, 27.5326519], [88.77987671, 27.53222084], [88.78424835, 27.52951813], [88.78601837, 27.52906036], [88.78703308, 27.52930069], [88.78806305, 27.5290699], [88.78856659, 27.52860069], [88.78894806, 27.52613068], [88.78882599, 27.52501106], [88.78768921, 27.52453041], [88.7869873, 27.52083969], [88.78666687, 27.51917267], [88.78617096, 27.51510048], [88.78613281, 27.51362991], [88.786026, 27.51148987], [88.78517151, 27.50646019], [88.78322601, 27.49648094], [88.78333282, 27.49452972], [88.7842865, 27.49373055], [88.78501129, 27.49297905], [88.78555298, 27.49241829], [88.78543091, 27.48767281], [88.78524017, 27.48725319], [88.78474426, 27.48616409], [88.78390503, 27.48432732], [88.78315735, 27.48270035], [88.78259277, 27.47958374], [88.78231812, 27.47806549], [88.78144073, 27.47319031], [88.78144073, 27.47253227], [88.78145599, 27.46775818], [88.78216553, 27.46325684], [88.78338623, 27.45555115], [88.7842865, 27.45399094], [88.78733826, 27.45242119], [88.78736877, 27.45129967], [88.78759766, 27.45017052], [88.79243469, 27.44802666], [88.79473114, 27.44701004], [88.79459381, 27.4449501], [88.79402161, 27.43660927], [88.79490662, 27.43276978], [88.7950058, 27.43264961], [88.79653168, 27.43078041], [88.80032349, 27.4287014], [88.80316925, 27.42713928], [88.80406952, 27.42533112], [88.80407715, 27.42509079], [88.80600739, 27.41423988]]]}}, {\\\"id\\\": \\\"28\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.31_1\\\", \\\"HASC_1\\\": \\\"IN.TN\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Tamil Nadu\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Madras|Tamilnad\\\", \\\"apm25_popweighted\\\": 45.2, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1489.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 857.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2346.0, \\\"geo-id\\\": 28, \\\"hpm25_child_popweighted\\\": 100.5, \\\"hpm25_female_popweighted\\\": 115.5, \\\"hpm25_male_popweighted\\\": 83.2, \\\"location\\\": \\\"Tamil Nadu\\\", \\\"mort_apm25_6cod_mean_total\\\": 33761.0, \\\"mort_hpm25_6cod_mean_total\\\": 18950.0, \\\"mort_tpm25_6cod_mean_total\\\": 52710.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[77.55596161, 8.07903099], [77.55596161, 8.07875061], [77.55625153, 8.07875061], [77.55625153, 8.07847118], [77.55652618, 8.07847309], [77.55652618, 8.07736111], [77.55625153, 8.07736111], [77.55625153, 8.07708263], [77.55596924, 8.07708263], [77.55596924, 8.07680511], [77.55513763, 8.07680511], [77.55513763, 8.07652569], [77.55458069, 8.07652569], [77.55458069, 8.07680511], [77.55374908, 8.07680511], [77.55374908, 8.07708263], [77.55347443, 8.07708263], [77.55347443, 8.07736111], [77.55319214, 8.07736111], [77.55319214, 8.07847309], [77.5534668, 8.07847118], [77.5534668, 8.07875061], [77.55486298, 8.07875061], [77.55486298, 8.07903099], [77.55596161, 8.07903099]]], [[[78.22486115, 8.87374973], [78.22486115, 8.87319183], [78.22541809, 8.87319374], [78.22541809, 8.87291622], [78.22598267, 8.87292004], [78.22598267, 8.87263966], [78.22624969, 8.87263966], [78.22624969, 8.87236023], [78.22652435, 8.87236214], [78.22652435, 8.87152767], [78.22680664, 8.87154102], [78.22680664, 8.87125015], [78.2270813, 8.87125015], [78.22706604, 8.86958122], [78.22736359, 8.86958408], [78.22736359, 8.86902809], [78.22763824, 8.86903191], [78.22763824, 8.86874866], [78.22706604, 8.86874866], [78.22706604, 8.86791992], [78.22735596, 8.86791992], [78.22735596, 8.86736107], [78.22569275, 8.86736107], [78.22569275, 8.86763954], [78.22597504, 8.86763954], [78.22597504, 8.86819553], [78.22569275, 8.86819553], [78.22569275, 8.86847115], [78.22541809, 8.86846924], [78.22541809, 8.86903191], [78.22486115, 8.86902809], [78.22486115, 8.86958408], [78.22458649, 8.86958122], [78.22458649, 8.87014198], [78.22429657, 8.87014198], [78.22429657, 8.87042046], [78.22402954, 8.87041569], [78.22402954, 8.87097168], [78.22429657, 8.87097168], [78.22429657, 8.87154102], [78.22402954, 8.87152767], [78.22402954, 8.87208366], [78.2234726, 8.87208366], [78.2234726, 8.87236214], [78.22291565, 8.87236214], [78.22291565, 8.87319374], [78.22319794, 8.87319374], [78.22319794, 8.87347221], [78.22374725, 8.87347031], [78.22374725, 8.87374973], [78.22486115, 8.87374973]]], [[[78.20847321, 8.84097099], [78.20847321, 8.84069347], [78.20903015, 8.84069347], [78.20903015, 8.84041786], [78.2095871, 8.84041977], [78.2095871, 8.84013939], [78.21013641, 8.84013939], [78.21013641, 8.83986092], [78.2104187, 8.83986092], [78.2104187, 8.83930492], [78.21098328, 8.83930969], [78.21098328, 8.83903027], [78.21206665, 8.83903027], [78.21206665, 8.83847141], [78.2123642, 8.83847332], [78.2123642, 8.83791733], [78.21263885, 8.83792019], [78.21263885, 8.83708096], [78.21291351, 8.83708286], [78.21291351, 8.83652687], [78.21263885, 8.83653164], [78.21263885, 8.83625126], [78.21180725, 8.83625126], [78.21180725, 8.83597088], [78.21152496, 8.83597088], [78.21152496, 8.83541679], [78.21013641, 8.83541679], [78.21013641, 8.83569527], [78.2104187, 8.83569527], [78.2104187, 8.83625126], [78.20986176, 8.83625126], [78.20986176, 8.83653164], [78.2095871, 8.83652687], [78.2095871, 8.83708286], [78.20929718, 8.83708096], [78.20929718, 8.83930969], [78.20903015, 8.83930492], [78.20903015, 8.83986092], [78.20874786, 8.83986092], [78.20874786, 8.84041977], [78.20819092, 8.84041786], [78.20819092, 8.84069347], [78.2076416, 8.84069347], [78.2076416, 8.84097099], [78.20847321, 8.84097099]]], [[[78.12763977, 8.64792156], [78.12763977, 8.64514065], [78.1279068, 8.64514065], [78.1279068, 8.6434679], [78.12819672, 8.64347267], [78.12819672, 8.64291668], [78.12791443, 8.64291668], [78.12791443, 8.64319515], [78.12596893, 8.64319515], [78.12596893, 8.64347267], [78.12625122, 8.6434679], [78.12625122, 8.64403057], [78.12652588, 8.64403057], [78.12652588, 8.6465292], [78.12625122, 8.6465292], [78.12625122, 8.6473608], [78.12735748, 8.64735889], [78.12735748, 8.64792156], [78.12763977, 8.64792156]]], [[[78.11541748, 8.61680889], [78.11541748, 8.61597061], [78.11569214, 8.61597347], [78.11569214, 8.615695], [78.11597443, 8.615695], [78.11597443, 8.61541653], [78.11624908, 8.6154213], [78.11624908, 8.61514091], [78.11653137, 8.61514091], [78.11653137, 8.61486053], [78.11680603, 8.61486053], [78.11680603, 8.61458302], [78.11763763, 8.61458302], [78.11763763, 8.61486053], [78.11791992, 8.61486053], [78.11791992, 8.61514091], [78.11818695, 8.61514091], [78.11818695, 8.6154213], [78.11875153, 8.6154213], [78.11875153, 8.61514091], [78.11902618, 8.61514091], [78.11902618, 8.61486053], [78.11930847, 8.61486053], [78.11930847, 8.61458302], [78.12014008, 8.61458302], [78.12014008, 8.61430359], [78.12069702, 8.61431122], [78.12069702, 8.61375141], [78.1204071, 8.61375141], [78.1204071, 8.61347008], [78.12014008, 8.61347294], [78.12014008, 8.61319542], [78.11875153, 8.61319542], [78.11875153, 8.61263847], [78.11846924, 8.61264992], [78.11846924, 8.61207962], [78.11819458, 8.61208153], [78.11819458, 8.61124992], [78.11846924, 8.61124992], [78.11846924, 8.61069202], [78.11791992, 8.61069393], [78.11791992, 8.61041641], [78.11736298, 8.61042118], [78.11736298, 8.6101408], [78.1159668, 8.6101408], [78.1159668, 8.61042118], [78.11569214, 8.61041641], [78.11569214, 8.61069393], [78.11513519, 8.61069393], [78.11513519, 8.6109724], [78.11541748, 8.6109724], [78.11541748, 8.61208153], [78.11569214, 8.61208153], [78.11569214, 8.61347294], [78.11486053, 8.61347008], [78.11486053, 8.6137476], [78.11458588, 8.61375141], [78.11458588, 8.61458302], [78.11430359, 8.61458302], [78.11430359, 8.61486053], [78.11402893, 8.61486053], [78.11402893, 8.61514091], [78.11207581, 8.61514091], [78.11207581, 8.61486053], [78.11042023, 8.61486053], [78.11042023, 8.61458302], [78.10986328, 8.61458302], [78.10986328, 8.61597347], [78.11013794, 8.61597061], [78.11013794, 8.61625099], [78.11042023, 8.61625099], [78.11042023, 8.61653137], [78.11319733, 8.61653137], [78.11319733, 8.61680889], [78.11541748, 8.61680889]]], [[[78.12124634, 8.61736107], [78.12124634, 8.61680698], [78.12097168, 8.61680889], [78.12097168, 8.61653137], [78.12069702, 8.61653137], [78.12069702, 8.61625099], [78.1204071, 8.61625099], [78.1204071, 8.61569023], [78.12014008, 8.615695], [78.12014008, 8.61541653], [78.11985779, 8.6154213], [78.11985779, 8.61514091], [78.11958313, 8.61514091], [78.11958313, 8.6154213], [78.11902618, 8.61541653], [78.11902618, 8.615695], [78.11930847, 8.61569023], [78.11930847, 8.61625099], [78.11958313, 8.61625099], [78.11958313, 8.61653137], [78.11985779, 8.6165266], [78.11985779, 8.6170826], [78.12014008, 8.61707973], [78.12014008, 8.61764145], [78.1204071, 8.61764145], [78.1204071, 8.61792088], [78.12152863, 8.61792088], [78.12152863, 8.61736107], [78.12124634, 8.61736107]]], [[[78.12014008, 8.63792133], [78.12014008, 8.63764095], [78.1204071, 8.63764095], [78.1204071, 8.63735962], [78.12097168, 8.63736343], [78.12097168, 8.6370821], [78.12124634, 8.6370821], [78.12124634, 8.63680553], [78.12152863, 8.63681984], [78.12152863, 8.63653088], [78.12210083, 8.63653088], [78.12210083, 8.63597012], [78.12236023, 8.63597202], [78.12236023, 8.63541603], [78.12097168, 8.6354208], [78.12097168, 8.63514042], [78.12069702, 8.63514042], [78.12069702, 8.63457966], [78.12041473, 8.63458443], [78.12041473, 8.63430595], [78.12014008, 8.63431072], [78.12014008, 8.63374996], [78.11985779, 8.63374996], [78.11985779, 8.633461], [78.11958313, 8.63347244], [78.11958313, 8.63319397], [78.11930847, 8.63319397], [78.11930847, 8.63291645], [78.11875153, 8.63292027], [78.11875153, 8.63236046], [78.11846924, 8.63236237], [78.11846924, 8.63180637], [78.11818695, 8.63181114], [78.11818695, 8.63125038], [78.11680603, 8.63125038], [78.11680603, 8.63153172], [78.11567688, 8.63153172], [78.11567688, 8.62846947], [78.11597443, 8.62847233], [78.11597443, 8.62763977], [78.11680603, 8.62765121], [78.11680603, 8.62735939], [78.11846924, 8.62735939], [78.11846924, 8.62792015], [78.12180328, 8.62791538], [78.12180328, 8.62819576], [78.12069702, 8.62819576], [78.12069702, 8.62847233], [78.11958313, 8.62847233], [78.11958313, 8.62874985], [78.12014008, 8.62874985], [78.12014008, 8.62903023], [78.12069702, 8.62903023], [78.12069702, 8.62930965], [78.12124634, 8.62930584], [78.12124634, 8.62958431], [78.12181091, 8.62958241], [78.12181091, 8.6301403], [78.12069702, 8.6301403], [78.12069702, 8.63069439], [78.12097168, 8.63069439], [78.12097168, 8.6331892], [78.12124634, 8.63320065], [78.12124634, 8.63374996], [78.12210083, 8.63374996], [78.12210083, 8.63403034], [78.12264252, 8.63403034], [78.12264252, 8.63208199], [78.12236023, 8.63208389], [78.12236023, 8.63041782], [78.12264252, 8.63041973], [78.12264252, 8.62986183], [78.12291718, 8.62986183], [78.12291718, 8.62930584], [78.12264252, 8.62930965], [78.12264252, 8.62874985], [78.12236023, 8.62874985], [78.12236023, 8.62819576], [78.12208557, 8.62819576], [78.12208557, 8.62763977], [78.12181091, 8.62765121], [78.12181091, 8.62708092], [78.12152863, 8.62708378], [78.12152863, 8.62680626], [78.12124634, 8.62681007], [78.12124634, 8.62652969], [78.12097168, 8.62652969], [78.12097168, 8.62597084], [78.12069702, 8.62597084], [78.12069702, 8.62569332], [78.12041473, 8.62569332], [78.12041473, 8.62514019], [78.12014008, 8.62514019], [78.12014008, 8.62430954], [78.11985779, 8.62430954], [78.11985779, 8.62319088], [78.11958313, 8.62319469], [78.11958313, 8.62236118], [78.11930847, 8.62236118], [78.11930847, 8.62180519], [78.11958313, 8.62181187], [78.11958313, 8.62152004], [78.11930847, 8.62152672], [78.11930847, 8.62097263], [78.11958313, 8.62097263], [78.11958313, 8.61958313], [78.11930847, 8.61958313], [78.11930847, 8.61874866], [78.11902618, 8.61875057], [78.11902618, 8.61846161], [78.11875153, 8.61847305], [78.11875153, 8.61791706], [78.11846924, 8.61792088], [78.11846924, 8.61764145], [78.11818695, 8.61764145], [78.11818695, 8.61736107], [78.11791992, 8.61736107], [78.11791992, 8.61875057], [78.11818695, 8.61875057], [78.11819458, 8.61986065], [78.11791992, 8.61986065], [78.11791992, 8.62041855], [78.11763763, 8.62041664], [78.11763763, 8.62097263], [78.11736298, 8.62097263], [78.11736298, 8.6212492], [78.11708069, 8.6212492], [78.11708069, 8.62181187], [78.11680603, 8.62180519], [78.11680603, 8.62208271], [78.11708069, 8.62208271], [78.11708069, 8.62236118], [78.11846924, 8.62236118], [78.11846924, 8.62375164], [78.11819458, 8.62374878], [78.11819458, 8.62486076], [78.11846924, 8.62485886], [78.11846924, 8.62514019], [78.11875153, 8.62514019], [78.11875153, 8.62541962], [78.11902618, 8.62541771], [78.11902618, 8.62569332], [78.11958313, 8.62569332], [78.11958313, 8.62597084], [78.11985779, 8.62597084], [78.11985779, 8.62736225], [78.11902618, 8.62736225], [78.11902618, 8.62708378], [78.11708069, 8.62708378], [78.11708069, 8.62680626], [78.11680603, 8.62681007], [78.11680603, 8.62652969], [78.11653137, 8.62652969], [78.11653137, 8.62597084], [78.11624908, 8.62597084], [78.11624908, 8.62569332], [78.11569214, 8.62569332], [78.11569214, 8.62597084], [78.11514282, 8.62597084], [78.11514282, 8.62792015], [78.11486053, 8.62791538], [78.11486053, 8.62986183], [78.11458588, 8.62986183], [78.11458588, 8.6301403], [78.11402893, 8.6301403], [78.11402893, 8.63041973], [78.11374664, 8.63041782], [78.11374664, 8.63069439], [78.11319733, 8.63069439], [78.11319733, 8.63097191], [78.11235809, 8.63097191], [78.11235809, 8.63125038], [78.11180878, 8.63125038], [78.11180878, 8.63153172], [78.11125183, 8.6315279], [78.11125183, 8.63236237], [78.11152649, 8.63236046], [78.11152649, 8.63292027], [78.11180878, 8.63291645], [78.11180878, 8.63347244], [78.11207581, 8.633461], [78.11207581, 8.63374996], [78.11235809, 8.63374996], [78.11235809, 8.63403034], [78.11264038, 8.63403034], [78.11264038, 8.63431072], [78.11291504, 8.63430595], [78.11291504, 8.63458443], [78.11319733, 8.63458443], [78.11319733, 8.63486004], [78.11374664, 8.63486004], [78.11374664, 8.63514042], [78.11429596, 8.63514042], [78.11429596, 8.6354208], [78.11486053, 8.63541603], [78.11486053, 8.63569355], [78.11541748, 8.63569355], [78.11541748, 8.63597202], [78.1159668, 8.63597012], [78.1159668, 8.63624954], [78.11624908, 8.63624954], [78.11624908, 8.63653088], [78.11680603, 8.63653088], [78.11680603, 8.63681984], [78.11736298, 8.63680553], [78.11736298, 8.6370821], [78.11791992, 8.6370821], [78.11791992, 8.63736343], [78.11875153, 8.63735962], [78.11875153, 8.63764095], [78.11930847, 8.63764095], [78.11930847, 8.63792133], [78.12014008, 8.63792133]]], [[[78.11708069, 8.65653038], [78.11708069, 8.6554203], [78.11736298, 8.6554203], [78.11736298, 8.65485859], [78.11763763, 8.6548624], [78.11763763, 8.65458393], [78.11791992, 8.65458393], [78.11791992, 8.65430641], [78.11846924, 8.65431023], [78.11846924, 8.65402985], [78.11875153, 8.65402985], [78.11875153, 8.65374947], [78.11930847, 8.65374947], [78.11930847, 8.65347099], [78.11985779, 8.65347099], [78.11985779, 8.65180492], [78.12014008, 8.65181923], [78.12014008, 8.65125179], [78.1204071, 8.65125179], [78.1204071, 8.65097141], [78.12208557, 8.65097141], [78.12208557, 8.65069485], [78.12291718, 8.65069485], [78.12291718, 8.65041733], [78.12374878, 8.65042019], [78.12374878, 8.65014172], [78.12403107, 8.65014172], [78.12403107, 8.64986134], [78.12430573, 8.64986134], [78.12430573, 8.64958286], [78.12458038, 8.64958286], [78.12458038, 8.64624882], [78.1248703, 8.64625072], [78.1248703, 8.64568996], [78.12513733, 8.64569473], [78.12513733, 8.64236069], [78.12541962, 8.64236069], [78.12541962, 8.64208317], [78.12486267, 8.64208317], [78.12486267, 8.6418047], [78.12403107, 8.64181137], [78.12403107, 8.64125061], [78.12431335, 8.64125061], [78.12431335, 8.64014053], [78.12458038, 8.64014053], [78.12458038, 8.63931084], [78.12541962, 8.63931084], [78.12541962, 8.63903141], [78.12513733, 8.63903141], [78.12513733, 8.63875103], [78.12458038, 8.63875103], [78.12458038, 8.6384697], [78.12403107, 8.6384716], [78.12403107, 8.63819408], [78.12319183, 8.63819027], [78.12319183, 8.63875103], [78.12264252, 8.63875103], [78.12264252, 8.63903141], [78.12236023, 8.63903141], [78.12236023, 8.63931084], [78.12264252, 8.63930416], [78.12264252, 8.63986015], [78.12291718, 8.63986015], [78.12291718, 8.64042091], [78.12319183, 8.6404171], [78.12319183, 8.64097309], [78.12152863, 8.64097023], [78.12152863, 8.64125061], [78.11985779, 8.64125061], [78.11985779, 8.64181137], [78.12014008, 8.6418047], [78.12014008, 8.64208317], [78.1204071, 8.64208031], [78.1204071, 8.64236069], [78.12097168, 8.64236069], [78.12097168, 8.64263916], [78.12124634, 8.64262962], [78.12124634, 8.64292145], [78.12152863, 8.64291668], [78.12152863, 8.64319515], [78.12180328, 8.64319515], [78.12180328, 8.64347267], [78.12210083, 8.6434679], [78.12210083, 8.64403057], [78.12236023, 8.64403057], [78.12236023, 8.6443119], [78.12152863, 8.64430523], [78.12152863, 8.64458275], [78.12014008, 8.64458275], [78.12014008, 8.64402676], [78.11985779, 8.64403057], [78.11985779, 8.64375114], [78.11958313, 8.64375114], [78.11958313, 8.64319515], [78.11930847, 8.64319515], [78.11930847, 8.64291668], [78.11902618, 8.64292145], [78.11902618, 8.64262962], [78.11875153, 8.64263916], [78.11875153, 8.64208317], [78.11846924, 8.64208317], [78.11846924, 8.6418047], [78.11736298, 8.6418047], [78.11736298, 8.64236069], [78.11708069, 8.64236069], [78.11708069, 8.64403057], [78.11680603, 8.64402676], [78.11680603, 8.64486122], [78.11708069, 8.64486122], [78.11708069, 8.64514065], [78.11763763, 8.64514065], [78.11763763, 8.64542198], [78.11791992, 8.64541721], [78.11791992, 8.64569473], [78.11846924, 8.64569473], [78.11846924, 8.64597321], [78.11875153, 8.64597321], [78.11875153, 8.64958286], [78.11846924, 8.64958286], [78.11846924, 8.64986134], [78.11791992, 8.64986134], [78.11791992, 8.65014172], [78.11763763, 8.65013885], [78.11763763, 8.65069485], [78.11791992, 8.65069103], [78.11791992, 8.65181923], [78.11763763, 8.65181923], [78.11763763, 8.65264034], [78.11736298, 8.65264034], [78.11736298, 8.65319347], [78.11708069, 8.65319347], [78.11708069, 8.65374947], [78.11680603, 8.65374947], [78.11680603, 8.65458393], [78.11653137, 8.65456963], [78.11653137, 8.6554203], [78.11680603, 8.6554203], [78.11680603, 8.65653038], [78.11708069, 8.65653038]]], [[[78.69458008, 9.15486145], [78.69458008, 9.15514088], [78.69625092, 9.15514088], [78.69625092, 9.15375137], [78.69652557, 9.15375137], [78.69652557, 9.15125084], [78.69596863, 9.15125084], [78.69596863, 9.15097332], [78.69374847, 9.15097332], [78.69374847, 9.15125084], [78.69319153, 9.1512394], [78.69319153, 9.15153122], [78.69291687, 9.15152645], [78.69291687, 9.1520834], [78.69319153, 9.15207958], [78.69319153, 9.1526413], [78.69347382, 9.15263939], [78.69347382, 9.1534729], [78.6937561, 9.15347099], [78.6937561, 9.15402889], [78.69403076, 9.15402889], [78.69403076, 9.15430546], [78.69430542, 9.15430546], [78.69430542, 9.15486145], [78.69458008, 9.15486145]]], [[[78.72986603, 9.15569019], [78.72986603, 9.15625095], [78.73069763, 9.15625095], [78.73069763, 9.15597057], [78.73097229, 9.15597343], [78.73097229, 9.15569496], [78.73152924, 9.15569496], [78.73152924, 9.15541744], [78.73208618, 9.15542126], [78.73208618, 9.15318966], [78.73180389, 9.15319538], [78.73180389, 9.15125084], [78.73042297, 9.1512394], [78.73042297, 9.15153122], [78.72986603, 9.15153122], [78.72986603, 9.15181065], [78.72958374, 9.15180683], [78.72958374, 9.1520834], [78.72902679, 9.1520834], [78.72902679, 9.15236092], [78.72875214, 9.15236092], [78.72875214, 9.1526413], [78.72902679, 9.1526413], [78.72902679, 9.15292072], [78.72930908, 9.15291691], [78.72930908, 9.15319538], [78.72957611, 9.15318966], [78.72957611, 9.15375137], [78.7298584, 9.15375137], [78.7298584, 9.15486145], [78.73014069, 9.15486145], [78.73014069, 9.15569496], [78.72986603, 9.15569019]]], [[[78.49097443, 9.09291553], [78.49097443, 9.09319401], [78.49180603, 9.09319401], [78.49180603, 9.09291553], [78.49208832, 9.09292126], [78.49208832, 9.09235954], [78.49236298, 9.0923624], [78.49236298, 9.09208202], [78.49263763, 9.09208202], [78.49263763, 9.09180641], [78.49318695, 9.09181118], [78.49318695, 9.09152985], [78.49375153, 9.09152985], [78.49375153, 9.09125042], [78.49430847, 9.09125042], [78.49430847, 9.09097195], [78.49485779, 9.09097195], [78.49485779, 9.09069443], [78.49514008, 9.09069443], [78.49514008, 9.09013844], [78.49485779, 9.09014034], [78.49485779, 9.08931065], [78.49458313, 9.08931065], [78.49458313, 9.08847046], [78.49430847, 9.08847237], [78.49430847, 9.08791637], [78.49402618, 9.08792019], [78.49402618, 9.08736038], [78.49375153, 9.08736229], [78.49375153, 9.0868063], [78.49346924, 9.08681011], [78.49346924, 9.08597183], [78.49319458, 9.08597183], [78.49319458, 9.08569431], [78.49263763, 9.08569431], [78.49263763, 9.08597183], [78.49236298, 9.08597183], [78.49236298, 9.08652973], [78.49208069, 9.08652782], [78.49208069, 9.08708382], [78.49180603, 9.08708382], [78.49180603, 9.08763981], [78.49124908, 9.08763981], [78.49124908, 9.08792019], [78.49069214, 9.08791637], [78.49069214, 9.08819389], [78.49013519, 9.08819389], [78.49013519, 9.08847237], [78.48958588, 9.08847046], [78.48958588, 9.08875179], [78.4890213, 9.08875179], [78.4890213, 9.08903027], [78.48874664, 9.08903027], [78.48874664, 9.08931065], [78.48847198, 9.08930588], [78.48847198, 9.08985996], [78.48819733, 9.08985996], [78.48819733, 9.09014034], [78.48792267, 9.09014034], [78.48792267, 9.09041977], [78.48847198, 9.09041595], [78.48847198, 9.09069443], [78.48930359, 9.09069443], [78.48930359, 9.09097195], [78.48986053, 9.09097195], [78.48986053, 9.09125042], [78.49014282, 9.09125042], [78.49014282, 9.09181118], [78.49041748, 9.09180641], [78.49041748, 9.0923624], [78.49069214, 9.09235954], [78.49069214, 9.09292126], [78.49097443, 9.09291553]]], [[[78.57902527, 9.11208439], [78.57902527, 9.11236191], [78.58041382, 9.11236191], [78.58041382, 9.11208439], [78.58097076, 9.11208439], [78.58097076, 9.11180592], [78.58180237, 9.11180973], [78.58180237, 9.1115303], [78.58319092, 9.1115303], [78.58319092, 9.11125183], [78.5845871, 9.11125183], [78.5845871, 9.11097145], [78.58486176, 9.11097145], [78.58486176, 9.11069584], [78.58513641, 9.11069584], [78.58513641, 9.11041546], [78.58541107, 9.11042023], [78.58541107, 9.11013985], [78.58569336, 9.11013985], [78.58569336, 9.10986233], [78.58625031, 9.10986233], [78.58625031, 9.1095829], [78.58652496, 9.1095829], [78.58652496, 9.10930538], [78.58625031, 9.10932064], [78.58625031, 9.10874939], [78.58597565, 9.10874939], [78.58597565, 9.10847092], [78.58569336, 9.10847092], [78.58569336, 9.1081953], [78.58513641, 9.1081953], [78.58513641, 9.10791683], [78.58347321, 9.10791969], [78.58347321, 9.10763931], [78.58319092, 9.10763931], [78.58319092, 9.10736084], [78.58291626, 9.10736084], [78.58291626, 9.10680962], [78.5826416, 9.10680962], [78.5826416, 9.10652924], [78.58236694, 9.10652924], [78.58236694, 9.10625076], [78.58207703, 9.10625076], [78.58207703, 9.10597134], [78.58180237, 9.10597324], [78.58180237, 9.10541725], [78.58152771, 9.10542202], [78.58152771, 9.10514069], [78.58125305, 9.10514069], [78.58125305, 9.10486126], [78.58097076, 9.10486126], [78.58097076, 9.10458279], [78.58069611, 9.10458279], [78.58069611, 9.10402679], [78.58040619, 9.10403061], [78.58040619, 9.10375118], [78.58013916, 9.10375118], [78.58013916, 9.1034708], [78.57902527, 9.1034708], [78.57902527, 9.10319519], [78.57791901, 9.10319519], [78.57791901, 9.10291672], [78.57347107, 9.10292244], [78.57347107, 9.10264111], [78.57319641, 9.10264111], [78.57319641, 9.1020813], [78.57180786, 9.1020813], [78.57180786, 9.10292244], [78.57208252, 9.10292244], [78.57208252, 9.10403061], [78.57180786, 9.10402679], [78.57180786, 9.10458279], [78.57208252, 9.10458279], [78.57208252, 9.10486126], [78.57263947, 9.10486126], [78.57263947, 9.10514069], [78.57290649, 9.10514069], [78.57290649, 9.10542202], [78.57319641, 9.10541725], [78.57319641, 9.10569477], [78.57347107, 9.10569477], [78.57347107, 9.10597324], [78.57402802, 9.10597134], [78.57402802, 9.10625076], [78.57430267, 9.10625076], [78.57430267, 9.10652924], [78.57457733, 9.10652924], [78.57457733, 9.10680962], [78.57485962, 9.10680485], [78.57485962, 9.10708332], [78.57541656, 9.10708141], [78.57541656, 9.10736084], [78.57569122, 9.10736084], [78.57569122, 9.10763931], [78.57597351, 9.10763931], [78.57597351, 9.10847092], [78.57624817, 9.10847092], [78.57624817, 9.1095829], [78.57653046, 9.10958099], [78.57653046, 9.11042023], [78.57680511, 9.11041546], [78.57680511, 9.11069584], [78.57736206, 9.11069584], [78.57736206, 9.11097145], [78.57763672, 9.11097145], [78.57763672, 9.11125183], [78.57791901, 9.11125183], [78.57791901, 9.1115303], [78.57818604, 9.1115303], [78.57818604, 9.11180973], [78.57875061, 9.11180592], [78.57875061, 9.11208439], [78.57902527, 9.11208439]]], [[[78.48735809, 9.13458347], [78.48735809, 9.13486099], [78.48791504, 9.13486099], [78.48791504, 9.134305], [78.48764038, 9.13430977], [78.48764038, 9.13319969], [78.48735809, 9.13319969], [78.48735809, 9.13236141], [78.48708344, 9.13236141], [78.48708344, 9.13208294], [78.48680878, 9.13208294], [78.48680878, 9.13097095], [78.48652649, 9.13097095], [78.48652649, 9.13069534], [78.48542023, 9.13069534], [78.48542023, 9.13097095], [78.48513794, 9.13097095], [78.48513794, 9.13125134], [78.48458099, 9.13125134], [78.48458099, 9.13181019], [78.48486328, 9.13180542], [78.48486328, 9.13236141], [78.48513794, 9.13236141], [78.48513794, 9.13264084], [78.48486328, 9.13263893], [78.48486328, 9.1334734], [78.48513794, 9.13347054], [78.48513794, 9.13375092], [78.48542023, 9.13375092], [78.48542023, 9.13402939], [78.48625183, 9.13402939], [78.48625183, 9.13430977], [78.48708344, 9.134305], [78.48708344, 9.13458347], [78.48735809, 9.13458347]]], [[[78.53819275, 9.10569477], [78.53819275, 9.10597324], [78.53930664, 9.10597324], [78.53930664, 9.10569477], [78.5395813, 9.10569477], [78.5395813, 9.10541725], [78.53930664, 9.10542202], [78.53930664, 9.10514069], [78.53901672, 9.10514069], [78.53901672, 9.10458088], [78.53874969, 9.10458279], [78.53874969, 9.10430527], [78.53848267, 9.10431194], [78.53848267, 9.1034708], [78.53819275, 9.1034708], [78.53819275, 9.10291672], [78.5376358, 9.10292244], [78.5376358, 9.10264111], [78.53708649, 9.10264111], [78.53708649, 9.10236073], [78.53624725, 9.10236073], [78.53624725, 9.1020813], [78.53514099, 9.1020813], [78.53514099, 9.10236073], [78.5348587, 9.10236073], [78.5348587, 9.10292244], [78.53514099, 9.10291672], [78.53514099, 9.10319519], [78.53541565, 9.10319519], [78.53541565, 9.1034708], [78.5359726, 9.10347271], [78.5359726, 9.10375118], [78.53624725, 9.10375118], [78.53624725, 9.10403061], [78.53652954, 9.10403061], [78.53652954, 9.10431194], [78.5368042, 9.10430527], [78.5368042, 9.10458279], [78.53736115, 9.10458279], [78.53736115, 9.10486126], [78.5376358, 9.10486126], [78.5376358, 9.10514069], [78.53791809, 9.10513878], [78.53791809, 9.10569477], [78.53819275, 9.10569477]]], [[[78.82819366, 9.17125034], [78.82818604, 9.17097187], [78.82847595, 9.17097187], [78.82847595, 9.17041588], [78.82875061, 9.17041969], [78.82875061, 9.16903019], [78.8290329, 9.16903019], [78.8290329, 9.16708088], [78.82875061, 9.16708374], [78.82875061, 9.16597176], [78.82847595, 9.16597176], [78.82847595, 9.16541767], [78.82818604, 9.16541958], [78.82818604, 9.16514015], [78.82791901, 9.16514015], [78.82791901, 9.16486168], [78.82541656, 9.16486168], [78.82541656, 9.16458416], [78.82485962, 9.16458416], [78.82485962, 9.16430569], [78.82430267, 9.16431046], [78.82430267, 9.16403198], [78.82375336, 9.16403198], [78.82375336, 9.1637516], [78.82289886, 9.1637516], [78.82289886, 9.16347122], [78.82236481, 9.16347122], [78.82236481, 9.16124916], [78.82125092, 9.16125107], [78.82125092, 9.16097069], [78.82096863, 9.1609726], [78.82096863, 9.1604166], [78.82068634, 9.16043091], [78.82068634, 9.15958118], [78.82041931, 9.15958309], [78.82041931, 9.15847111], [78.82013702, 9.15847111], [78.82013702, 9.15763855], [78.81931305, 9.15764141], [78.81931305, 9.15792179], [78.81485748, 9.15792179], [78.81485748, 9.15875053], [78.8170929, 9.15875053], [78.8170929, 9.15903187], [78.81735992, 9.15903187], [78.81735992, 9.15931034], [78.81764221, 9.15930462], [78.81764221, 9.15958309], [78.81791687, 9.15958309], [78.81791687, 9.15986061], [78.81819153, 9.15986061], [78.81819153, 9.16014194], [78.81847382, 9.16013908], [78.81847382, 9.16069317], [78.81874847, 9.16069126], [78.81874847, 9.16152954], [78.81903076, 9.16152668], [78.81903076, 9.16208267], [78.81930542, 9.16208267], [78.81930542, 9.16236115], [78.81958008, 9.16235924], [78.81958008, 9.16263866], [78.81986237, 9.16263866], [78.81986237, 9.16292191], [78.82013702, 9.16291809], [78.82013702, 9.16319561], [78.82041931, 9.16319561], [78.82041931, 9.16347122], [78.82068634, 9.16347122], [78.82068634, 9.1637516], [78.82096863, 9.1637516], [78.82096863, 9.16403198], [78.82208252, 9.16403198], [78.82208252, 9.16431046], [78.82263947, 9.16430569], [78.82263947, 9.16458416], [78.82318878, 9.1645813], [78.82318878, 9.16486168], [78.82347107, 9.16486168], [78.82347107, 9.16514015], [78.82402802, 9.16514015], [78.82402802, 9.16541958], [78.82458496, 9.16541767], [78.82458496, 9.16569424], [78.82485962, 9.16569424], [78.82485962, 9.16597176], [78.82514191, 9.16597366], [78.82514191, 9.16625023], [78.82541656, 9.16623974], [78.82541656, 9.16681004], [78.82569122, 9.16680622], [78.82569122, 9.16708374], [78.82596588, 9.16708088], [78.82596588, 9.16763973], [78.82624817, 9.16763973], [78.82624817, 9.16847229], [78.82653046, 9.16846943], [78.82653046, 9.16903019], [78.82681274, 9.16903019], [78.82681274, 9.16986179], [78.82707977, 9.16985989], [78.82707977, 9.17069435], [78.82736206, 9.17069435], [78.82736206, 9.17125034], [78.82819366, 9.17125034]]], [[[78.94069672, 9.18458271], [78.94069672, 9.18430519], [78.94042206, 9.18431187], [78.94042206, 9.18403053], [78.94013977, 9.18403053], [78.94013977, 9.18375111], [78.93958282, 9.18375111], [78.93958282, 9.18347263], [78.93930817, 9.18347263], [78.93930817, 9.18319511], [78.93875122, 9.18319511], [78.93875122, 9.18263912], [78.93763733, 9.18264103], [78.93763733, 9.18292141], [78.93680573, 9.18291664], [78.93680573, 9.18319511], [78.93514252, 9.18319511], [78.93514252, 9.18291664], [78.93347168, 9.18292141], [78.93347168, 9.18264103], [78.9329071, 9.18264103], [78.9329071, 9.18236065], [78.93235779, 9.18236065], [78.93235779, 9.18208313], [78.93208313, 9.18208313], [78.93208313, 9.18180466], [78.93154144, 9.18180943], [78.93154144, 9.18153954], [78.92958069, 9.18153954], [78.92958069, 9.18180943], [78.92847443, 9.18180466], [78.92847443, 9.18208313], [78.92736053, 9.18208313], [78.92736053, 9.18236065], [78.92624664, 9.18236065], [78.92624664, 9.18264103], [78.91902924, 9.18264103], [78.91902924, 9.18236065], [78.91791534, 9.18236065], [78.91791534, 9.18208313], [78.91652679, 9.18208313], [78.91652679, 9.18180466], [78.9154129, 9.18180943], [78.9154129, 9.18153954], [78.9145813, 9.18153954], [78.9145813, 9.18125057], [78.91348267, 9.18125057], [78.91348267, 9.18097115], [78.9126358, 9.18097305], [78.9126358, 9.18069458], [78.91152954, 9.18069458], [78.91152954, 9.18041706], [78.91069794, 9.18042088], [78.91069794, 9.18014145], [78.90875244, 9.18014145], [78.90875244, 9.18042088], [78.90847015, 9.18041706], [78.90847015, 9.18069458], [78.9070816, 9.18069458], [78.9070816, 9.18041706], [78.90569305, 9.18042088], [78.90569305, 9.18014145], [78.9054184, 9.18014145], [78.9054184, 9.17986107], [78.90486145, 9.17986107], [78.90486145, 9.1795826], [78.90458679, 9.1795826], [78.90458679, 9.17930698], [78.90431213, 9.17930889], [78.90431213, 9.17903137], [78.90374756, 9.17903137], [78.90374756, 9.17875099], [78.9034729, 9.17875099], [78.9034729, 9.17846966], [78.90319824, 9.17847347], [78.90319824, 9.178195], [78.9026413, 9.178195], [78.9026413, 9.17791653], [78.90125275, 9.17791653], [78.90125275, 9.178195], [78.90013885, 9.178195], [78.90013885, 9.17847347], [78.89930725, 9.17846966], [78.89930725, 9.17875099], [78.89901733, 9.17875099], [78.89901733, 9.17903137], [78.89875031, 9.17903137], [78.89875031, 9.17930889], [78.89847565, 9.17930698], [78.89847565, 9.1795826], [78.89875031, 9.1795826], [78.89875031, 9.17986107], [78.89930725, 9.17986107], [78.89930725, 9.18014145], [78.89958191, 9.18014145], [78.89958191, 9.18042088], [78.8998642, 9.18041706], [78.8998642, 9.18069458], [78.90041351, 9.18069458], [78.90041351, 9.18097305], [78.9006958, 9.18097115], [78.9006958, 9.18125057], [78.90097046, 9.18125057], [78.90097046, 9.18153954], [78.90154266, 9.18153954], [78.90154266, 9.18180943], [78.90180206, 9.18180466], [78.90180206, 9.18208313], [78.90235901, 9.18208313], [78.90235901, 9.18236065], [78.90291595, 9.18236065], [78.90291595, 9.18264103], [78.90374756, 9.18264103], [78.90374756, 9.18292141], [78.9043045, 9.18291664], [78.9043045, 9.18319511], [78.90486145, 9.18319511], [78.90486145, 9.18347263], [78.90597534, 9.18347263], [78.90597534, 9.18319511], [78.90625, 9.18319511], [78.90625, 9.18291664], [78.90680695, 9.18292141], [78.90680695, 9.18264103], [78.90734863, 9.18264103], [78.90734863, 9.18180943], [78.90820313, 9.18180943], [78.90820313, 9.18153954], [78.90875244, 9.18153954], [78.90875244, 9.18125057], [78.91040802, 9.18125057], [78.91040802, 9.18153954], [78.91179657, 9.18153954], [78.91179657, 9.18180943], [78.91291809, 9.18180466], [78.91291809, 9.18236065], [78.91401672, 9.18236065], [78.91401672, 9.18264103], [78.9154129, 9.18264103], [78.9154129, 9.18292141], [78.91652679, 9.18291664], [78.91652679, 9.18319511], [78.91791534, 9.18319511], [78.91791534, 9.18347263], [78.91902924, 9.18347263], [78.91902924, 9.18375111], [78.92041779, 9.18375111], [78.92041779, 9.18403053], [78.92542267, 9.18403053], [78.92542267, 9.18375111], [78.92597198, 9.18375111], [78.92597198, 9.18403053], [78.92652893, 9.18403053], [78.92652893, 9.18431187], [78.92874908, 9.18431187], [78.92874908, 9.18403053], [78.93041992, 9.18403053], [78.93041992, 9.18375111], [78.93069458, 9.18375111], [78.93068695, 9.18347073], [78.93514252, 9.18347263], [78.93514252, 9.18375111], [78.93681335, 9.18375111], [78.93681335, 9.18403053], [78.93736267, 9.18403053], [78.93736267, 9.18431187], [78.93763733, 9.18430519], [78.93763733, 9.18458271], [78.93819427, 9.18458271], [78.93819427, 9.18486118], [78.93875122, 9.18486118], [78.93875122, 9.18514061], [78.93902588, 9.18514061], [78.93902588, 9.18542194], [78.94152832, 9.18542194], [78.94152832, 9.18514061], [78.94124603, 9.18514061], [78.94124603, 9.18486118], [78.94097137, 9.18486118], [78.94097137, 9.18458271], [78.94069672, 9.18458271]]], [[[78.96765137, 9.18931007], [78.96765137, 9.18902969], [78.96819305, 9.18902969], [78.96819305, 9.18847084], [78.96847534, 9.18847084], [78.96847534, 9.18791676], [78.96875, 9.18791962], [78.96875, 9.18735027], [78.96902466, 9.18736076], [78.96902466, 9.18708324], [78.9695816, 9.18708324], [78.9695816, 9.18680477], [78.97039795, 9.18680954], [78.97039795, 9.18625069], [78.97068787, 9.18625069], [78.97068787, 9.18597126], [78.97097015, 9.18597317], [78.97097015, 9.18569469], [78.97013855, 9.18569469], [78.97013855, 9.18541718], [78.96985626, 9.18542194], [78.96985626, 9.18514061], [78.9695816, 9.18514061], [78.9695816, 9.18486118], [78.96902466, 9.18486118], [78.96902466, 9.18458271], [78.96875, 9.18458271], [78.96875, 9.18430519], [78.96848297, 9.18431187], [78.96848297, 9.18403053], [78.96736145, 9.18402672], [78.96736145, 9.18486118], [78.96708679, 9.18486118], [78.96708679, 9.18569469], [78.96679688, 9.18569088], [78.96679688, 9.18653202], [78.96652985, 9.18652725], [78.96652985, 9.18708324], [78.96624756, 9.18708324], [78.96624756, 9.18736076], [78.9659729, 9.18735027], [78.9659729, 9.18763924], [78.96569824, 9.18763924], [78.96569061, 9.18847084], [78.96541595, 9.18847084], [78.96541595, 9.18874931], [78.96624756, 9.18874931], [78.96624756, 9.18902969], [78.96679688, 9.18902969], [78.96679688, 9.18931007], [78.96765137, 9.18931007]]], [[[79.07013702, 9.20819473], [79.07013702, 9.20708275], [79.06986237, 9.20708275], [79.06986237, 9.20680523], [79.06958008, 9.20681095], [79.06958008, 9.20653057], [79.06931305, 9.20653057], [79.06931305, 9.20625114], [79.06903076, 9.20625114], [79.06903076, 9.20597267], [79.06874847, 9.20597267], [79.06874847, 9.20541668], [79.06958008, 9.20542145], [79.06958008, 9.20514107], [79.06984711, 9.20514107], [79.06984711, 9.20485973], [79.07041931, 9.20485973], [79.07041931, 9.20458221], [79.07069397, 9.20458221], [79.07069397, 9.20375061], [79.07096863, 9.20375061], [79.07096863, 9.20347023], [79.07208252, 9.20347214], [79.07208252, 9.20236015], [79.07263947, 9.20236015], [79.07263947, 9.20208359], [79.07319641, 9.20208359], [79.07319641, 9.20180416], [79.07375336, 9.20181084], [79.07375336, 9.20153141], [79.07430267, 9.20153141], [79.07430267, 9.20125008], [79.07459259, 9.20125008], [79.07459259, 9.2009697], [79.07514191, 9.2009716], [79.07514191, 9.20069408], [79.07541656, 9.20069408], [79.07541656, 9.20041561], [79.07598114, 9.20042133], [79.07598114, 9.20014], [79.07681274, 9.20014], [79.07681274, 9.19985962], [79.08040619, 9.19985962], [79.08040619, 9.20042133], [79.08069611, 9.20041561], [79.08069611, 9.20069408], [79.08152771, 9.20069408], [79.08152771, 9.20041561], [79.08178711, 9.20042133], [79.08178711, 9.20014], [79.08235931, 9.20014], [79.08235931, 9.19958019], [79.0826416, 9.1995821], [79.0826416, 9.19902802], [79.08291626, 9.19902992], [79.08291626, 9.19847202], [79.08347321, 9.19847202], [79.08347321, 9.19819355], [79.08430481, 9.19819355], [79.08430481, 9.19791603], [79.0848465, 9.19791985], [79.0848465, 9.19764042], [79.08513641, 9.19764042], [79.08513641, 9.19736195], [79.08569336, 9.19736195], [79.08569336, 9.19708443], [79.08680725, 9.19708443], [79.08680725, 9.19652843], [79.08653259, 9.19654179], [79.08653259, 9.19624996], [79.08680725, 9.19624996], [79.08680725, 9.19596958], [79.08708191, 9.19597244], [79.08708191, 9.19486237], [79.08680725, 9.19486237], [79.08680725, 9.19458389], [79.08597565, 9.19458389], [79.08597565, 9.19430637], [79.08625031, 9.19431019], [79.08625031, 9.19375038], [79.08653259, 9.19375038], [79.08653259, 9.19431019], [79.08708191, 9.19430637], [79.08708191, 9.19458389], [79.08792114, 9.19458199], [79.08792114, 9.19514179], [79.0881958, 9.19513988], [79.0881958, 9.19597244], [79.08847046, 9.19596958], [79.08847046, 9.19681072], [79.08821106, 9.19681072], [79.08821106, 9.19791985], [79.08875275, 9.19791603], [79.08875275, 9.19819355], [79.0890274, 9.19819164], [79.0890274, 9.19874954], [79.08930206, 9.19874954], [79.08930206, 9.19986153], [79.09041595, 9.19985962], [79.09041595, 9.20014], [79.09098053, 9.20014], [79.09098053, 9.19958019], [79.09124756, 9.1995821], [79.09124756, 9.19902802], [79.09152985, 9.19902992], [79.09152985, 9.19596958], [79.09124756, 9.19597244], [79.09124756, 9.19569397], [79.0909729, 9.19569397], [79.0909729, 9.19541645], [79.09069824, 9.19542027], [79.09069824, 9.19486046], [79.09041595, 9.19486237], [79.09041595, 9.19458389], [79.0901413, 9.19458389], [79.0901413, 9.19430637], [79.08985901, 9.19431019], [79.08985901, 9.1940279], [79.08930206, 9.1940279], [79.08930206, 9.19348145], [79.0890274, 9.19348145], [79.0890274, 9.19291973], [79.08847046, 9.19291973], [79.08847046, 9.1926403], [79.08792114, 9.1926403], [79.08792114, 9.19236183], [79.08763885, 9.19236183], [79.08763885, 9.19208431], [79.08708191, 9.19208431], [79.08708191, 9.19180584], [79.08513641, 9.19180584], [79.08513641, 9.19208431], [79.0845871, 9.19208431], [79.0845871, 9.19236183], [79.08429718, 9.19236183], [79.08429718, 9.1926403], [79.08374786, 9.1926403], [79.08374786, 9.19291973], [79.08347321, 9.19291782], [79.08347321, 9.19319439], [79.08291626, 9.19319057], [79.08291626, 9.19348145], [79.0826416, 9.19347191], [79.0826416, 9.19375038], [79.08207703, 9.19375038], [79.08207703, 9.1940279], [79.08180237, 9.1940279], [79.08180237, 9.19458389], [79.08152771, 9.19458389], [79.08152771, 9.19486237], [79.08125305, 9.19486046], [79.08125305, 9.19514179], [79.08097076, 9.19514179], [79.08097076, 9.19542027], [79.08041382, 9.19541645], [79.08041382, 9.19569397], [79.08013916, 9.19569397], [79.08013916, 9.19597244], [79.07904053, 9.19596958], [79.07904053, 9.19624996], [79.07818604, 9.19624996], [79.07818604, 9.19654179], [79.07791901, 9.19654179], [79.07791901, 9.19681072], [79.07707977, 9.19680595], [79.07707977, 9.19708443], [79.07624817, 9.19708443], [79.07624817, 9.19736195], [79.07569122, 9.19736195], [79.07569122, 9.19764042], [79.07485962, 9.19764042], [79.07485962, 9.19791985], [79.07430267, 9.19791603], [79.07430267, 9.19819355], [79.07347107, 9.19819355], [79.07347107, 9.19847202], [79.07290649, 9.19847202], [79.07290649, 9.19874954], [79.07180786, 9.19874954], [79.07180786, 9.19902992], [79.07068634, 9.19902992], [79.07068634, 9.19931126], [79.06930542, 9.19930553], [79.06930542, 9.1995821], [79.06791687, 9.1995821], [79.06791687, 9.19986153], [79.06513977, 9.19986153], [79.06513977, 9.1995821], [79.06458282, 9.1995821], [79.06458282, 9.19986153], [79.06430817, 9.19986153], [79.06430817, 9.1995821], [79.06402588, 9.1995821], [79.06402588, 9.19930553], [79.06346893, 9.19931126], [79.06346893, 9.19902992], [79.06318665, 9.19902992], [79.06318665, 9.19874954], [79.06263733, 9.19874954], [79.06263733, 9.19847202], [79.06236267, 9.19847202], [79.06236267, 9.19819355], [79.06208038, 9.19819355], [79.06208038, 9.19791603], [79.06153107, 9.19791985], [79.06153107, 9.19736195], [79.06124878, 9.19736195], [79.06124878, 9.19708443], [79.06097412, 9.19708443], [79.06097412, 9.19680595], [79.06041718, 9.19681072], [79.06041718, 9.19654179], [79.05902863, 9.19654179], [79.05902863, 9.19681072], [79.05847168, 9.19680595], [79.05847168, 9.19708443], [79.05819702, 9.1970787], [79.05819702, 9.19764042], [79.05847168, 9.19764042], [79.05847168, 9.19791985], [79.05874634, 9.19791603], [79.05874634, 9.19847202], [79.05902863, 9.19847202], [79.05902863, 9.19902992], [79.05930328, 9.19902802], [79.05930328, 9.1995821], [79.0595932, 9.19958019], [79.0595932, 9.20014], [79.05986023, 9.20014], [79.05986023, 9.20042133], [79.06014252, 9.20041561], [79.06014252, 9.2009716], [79.05986023, 9.2009716], [79.05986023, 9.20236015], [79.06014252, 9.20235062], [79.06014252, 9.20264053], [79.06069183, 9.20264053], [79.06069183, 9.20292091], [79.06124878, 9.20291615], [79.06124878, 9.20319366], [79.06153107, 9.20319366], [79.06153107, 9.20347214], [79.06181335, 9.20347023], [79.06181335, 9.20375061], [79.06208038, 9.20375061], [79.06208038, 9.20403099], [79.06236267, 9.20403099], [79.06236267, 9.20431137], [79.06263733, 9.2043066], [79.06263733, 9.20458221], [79.06291962, 9.20458221], [79.06291962, 9.20485973], [79.06318665, 9.20485973], [79.06318665, 9.20514107], [79.06346893, 9.20514107], [79.06346893, 9.20542145], [79.06402588, 9.20541668], [79.06402588, 9.20569515], [79.06458282, 9.20569515], [79.06458282, 9.20597267], [79.06485748, 9.20597267], [79.06485748, 9.20625114], [79.0654068, 9.20625114], [79.0654068, 9.20653057], [79.06597137, 9.20653057], [79.06597137, 9.20681095], [79.06625366, 9.20680523], [79.06625366, 9.20708275], [79.06652832, 9.20707989], [79.06652832, 9.20764065], [79.06681061, 9.20764065], [79.06681061, 9.20792103], [79.06874847, 9.20791721], [79.06874847, 9.20819473], [79.07013702, 9.20819473]]], [[[79.14206696, 9.21486092], [79.14206696, 9.21402931], [79.14180756, 9.21402931], [79.14180756, 9.21347141], [79.14152527, 9.21347332], [79.14152527, 9.21319485], [79.14125061, 9.21319485], [79.14125061, 9.21291733], [79.14041901, 9.21291924], [79.14041901, 9.21264076], [79.14013672, 9.21264076], [79.14013672, 9.21236134], [79.13957977, 9.21236134], [79.13957977, 9.21208286], [79.13903046, 9.21208286], [79.13903046, 9.21236134], [79.13846588, 9.21236134], [79.13846588, 9.21375084], [79.13874817, 9.21375084], [79.13874817, 9.21402931], [79.13932037, 9.21402931], [79.13932037, 9.21430969], [79.14013672, 9.21430492], [79.14013672, 9.2145834], [79.14068604, 9.21458054], [79.14068604, 9.21486092], [79.14206696, 9.21486092]]], [[[79.12568665, 9.2179203], [79.12568665, 9.21764183], [79.12819672, 9.21764183], [79.12819672, 9.2173624], [79.12875366, 9.2173624], [79.12875366, 9.21708298], [79.12930298, 9.21708298], [79.12930298, 9.21680546], [79.1295929, 9.21681023], [79.1295929, 9.21652985], [79.13485718, 9.21652985], [79.13485718, 9.21624947], [79.13513947, 9.21624947], [79.13513947, 9.21597099], [79.13541412, 9.21597099], [79.13541412, 9.21569538], [79.13569641, 9.21569538], [79.13569641, 9.21541691], [79.13597107, 9.21541977], [79.13597107, 9.21486092], [79.13513947, 9.21486092], [79.13513947, 9.2145834], [79.13430786, 9.2145834], [79.13430786, 9.21430492], [79.13375092, 9.21430969], [79.13375092, 9.21402931], [79.13208008, 9.21402931], [79.13208008, 9.21375084], [79.13153076, 9.21375084], [79.13153076, 9.21347141], [79.13097382, 9.21347332], [79.13097382, 9.21319485], [79.13041687, 9.21319485], [79.13041687, 9.21291733], [79.12985992, 9.21291733], [79.12985992, 9.21319485], [79.12847137, 9.21319485], [79.12847137, 9.21347332], [79.12763977, 9.21347141], [79.12763977, 9.21375084], [79.12625122, 9.21375084], [79.12625122, 9.21402931], [79.12568665, 9.21402931], [79.12568665, 9.21430969], [79.12513733, 9.21430492], [79.12513733, 9.2145834], [79.12403107, 9.2145834], [79.12403107, 9.21486092], [79.12319183, 9.21486092], [79.12319183, 9.21513939], [79.12236023, 9.21513939], [79.12236023, 9.21541977], [79.12124634, 9.21541691], [79.12124634, 9.21597099], [79.12095642, 9.21597099], [79.12095642, 9.21624947], [79.12152863, 9.21624947], [79.12152863, 9.21652985], [79.12291718, 9.21652985], [79.12291718, 9.21624947], [79.12431335, 9.21624947], [79.12431335, 9.21681023], [79.12403107, 9.21680546], [79.12403107, 9.2173624], [79.12431335, 9.2173624], [79.12431335, 9.2179203], [79.12568665, 9.2179203]]], [[[79.18235779, 9.24874973], [79.18235779, 9.24903011], [79.18402863, 9.24903011], [79.18402863, 9.24874973], [79.18430328, 9.24874973], [79.18430328, 9.24819088], [79.18458557, 9.24819374], [79.18458557, 9.24625015], [79.18374634, 9.24625015], [79.18374634, 9.24652958], [79.18208313, 9.24652958], [79.18208313, 9.2456913], [79.18180847, 9.24569321], [79.18180847, 9.24541759], [79.18096924, 9.24542046], [79.18096924, 9.24458981], [79.18068695, 9.24458981], [79.18068695, 9.24403191], [79.18096924, 9.24403191], [79.18096924, 9.24375153], [79.18123627, 9.24375153], [79.18123627, 9.24431038], [79.18208313, 9.24431038], [79.18208313, 9.24403191], [79.18235779, 9.24403191], [79.18235779, 9.24375153], [79.18264008, 9.24375153], [79.18264008, 9.24347115], [79.18291473, 9.24347115], [79.18291473, 9.24263859], [79.18264008, 9.24263859], [79.18264008, 9.24208069], [79.18291473, 9.2420826], [79.18291473, 9.24180508], [79.18319702, 9.24180984], [79.18319702, 9.24151993], [79.18347168, 9.24151993], [79.18347168, 9.24180984], [79.18596649, 9.24180984], [79.18596649, 9.24151993], [79.18624878, 9.24151993], [79.18624878, 9.24180984], [79.1873703, 9.24180984], [79.1873703, 9.24151993], [79.18763733, 9.2415266], [79.18763733, 9.24124908], [79.18818665, 9.24125099], [79.18818665, 9.24097061], [79.18846893, 9.24097347], [79.18846893, 9.24069309], [79.18958282, 9.24069309], [79.18958282, 9.24041653], [79.18985748, 9.24042034], [79.18985748, 9.23986053], [79.19013977, 9.23986053], [79.19013977, 9.23958302], [79.19041443, 9.23958302], [79.19041443, 9.23875141], [79.19013977, 9.23875141], [79.19013977, 9.23819065], [79.18985748, 9.23819542], [79.18985748, 9.23791695], [79.1904068, 9.23792171], [79.1904068, 9.23764133], [79.19069672, 9.23764133], [79.19069672, 9.23736095], [79.19430542, 9.23736095], [79.19430542, 9.23625088], [79.19458008, 9.23625088], [79.19458008, 9.23597145], [79.19513702, 9.23597336], [79.19513702, 9.23569489], [79.19569397, 9.23569489], [79.19569397, 9.23541737], [79.19624329, 9.23541927], [79.19624329, 9.23513889], [79.19708252, 9.23513889], [79.19708252, 9.23458004], [79.19791412, 9.2345829], [79.19791412, 9.23402882], [79.19819641, 9.23403072], [79.19819641, 9.23346996], [79.19847107, 9.23346996], [79.19847107, 9.23403072], [79.19875336, 9.23402882], [79.19875336, 9.2345829], [79.19957733, 9.23458004], [79.19957733, 9.23513889], [79.19930267, 9.23513889], [79.19930267, 9.23708344], [79.19957733, 9.23708057], [79.19957733, 9.23792171], [79.19985962, 9.23791695], [79.19985962, 9.23847103], [79.20014191, 9.23845863], [79.20014191, 9.23903179], [79.20041656, 9.23903179], [79.20041656, 9.23931026], [79.20069122, 9.23930454], [79.20069122, 9.23958302], [79.20041656, 9.23958111], [79.20041656, 9.24042034], [79.20069122, 9.24041653], [79.20069122, 9.24069309], [79.20124817, 9.24069309], [79.20124817, 9.24041653], [79.20153046, 9.24042034], [79.20153046, 9.24014091], [79.20181274, 9.24014091], [79.20181274, 9.23792171], [79.20153046, 9.23792171], [79.20153046, 9.23764133], [79.20124817, 9.23764133], [79.20124817, 9.23681164], [79.20096588, 9.23681164], [79.20096588, 9.23625088], [79.20124817, 9.23625088], [79.20124817, 9.23541927], [79.20153046, 9.23541927], [79.20153046, 9.23403072], [79.20124817, 9.23403072], [79.20124817, 9.2337513], [79.20069122, 9.2337513], [79.20069122, 9.23347282], [79.20041656, 9.23347282], [79.20041656, 9.2331953], [79.20014191, 9.2331953], [79.20014191, 9.23291683], [79.19985962, 9.23292065], [79.19985962, 9.2326498], [79.19957733, 9.2326498], [79.19957733, 9.23236275], [79.19790649, 9.23236275], [79.19790649, 9.2326498], [79.19740295, 9.23264503], [79.19708252, 9.2326498], [79.19708252, 9.23292065], [79.19625092, 9.23291683], [79.19625092, 9.2331953], [79.19596863, 9.2331953], [79.19596863, 9.23347282], [79.19513702, 9.23347282], [79.19513702, 9.2337513], [79.19486237, 9.2337513], [79.19486237, 9.23403072], [79.19374847, 9.23403072], [79.19374847, 9.2343092], [79.19347382, 9.23430538], [79.19347382, 9.2345829], [79.19208527, 9.2345829], [79.19208527, 9.23486137], [79.19180298, 9.23486137], [79.19180298, 9.23513889], [79.19152832, 9.23513889], [79.19152832, 9.23541927], [79.19069672, 9.23541737], [79.19069672, 9.23597336], [79.1904068, 9.23597145], [79.1904068, 9.23625088], [79.18958282, 9.23625088], [79.18958282, 9.23653126], [79.18875122, 9.23653126], [79.18875122, 9.23681164], [79.18819427, 9.23680496], [79.18819427, 9.23708344], [79.18736267, 9.23708344], [79.18736267, 9.23736095], [79.18681335, 9.23736095], [79.18681335, 9.23792171], [79.18653107, 9.23791695], [79.18653107, 9.23819542], [79.18597412, 9.23819542], [79.18597412, 9.23847103], [79.18569183, 9.23845863], [79.18569183, 9.23874855], [79.18430328, 9.23875141], [79.18430328, 9.23903179], [79.18264008, 9.23903179], [79.18264008, 9.23931026], [79.18208313, 9.23930454], [79.18208313, 9.23958302], [79.18180847, 9.23958302], [79.18180847, 9.23986053], [79.18152618, 9.23986053], [79.18152618, 9.24014091], [79.18096924, 9.24014091], [79.18096924, 9.24042034], [79.18069458, 9.24041653], [79.18069458, 9.24069309], [79.18041992, 9.24069118], [79.18041992, 9.24125099], [79.18013763, 9.24124908], [79.18013763, 9.2415266], [79.17986298, 9.2415266], [79.17986298, 9.2420826], [79.17958069, 9.24208069], [79.17958069, 9.24263859], [79.17930603, 9.24263859], [79.17930603, 9.24291992], [79.17903137, 9.24291706], [79.17903137, 9.24347115], [79.17874908, 9.24347115], [79.17874908, 9.24431038], [79.17903137, 9.24431038], [79.17903137, 9.24542046], [79.17930603, 9.24542046], [79.17930603, 9.24652958], [79.17958069, 9.24652767], [79.17958069, 9.24708366], [79.17986298, 9.2470789], [79.17986298, 9.2476511], [79.18013763, 9.24763966], [79.18013763, 9.24819374], [79.18041992, 9.24819374], [79.18041992, 9.24847221], [79.18152618, 9.24846935], [79.18152618, 9.24874973], [79.18235779, 9.24874973]]], [[[79.23152924, 9.24403191], [79.23152924, 9.24458981], [79.23235321, 9.24458981], [79.23235321, 9.24431038], [79.23264313, 9.24431038], [79.23264313, 9.24403191], [79.23291779, 9.24403191], [79.23291779, 9.24375153], [79.23374939, 9.24375153], [79.23374939, 9.24347115], [79.23625183, 9.24347115], [79.23625183, 9.24319553], [79.23652649, 9.24319553], [79.23652649, 9.24347115], [79.23680878, 9.24347115], [79.23680878, 9.24375153], [79.23707581, 9.24375153], [79.23707581, 9.24403191], [79.23735809, 9.24403191], [79.23735809, 9.24431038], [79.23819733, 9.24431038], [79.23819733, 9.24375153], [79.23847961, 9.24375153], [79.23847961, 9.24319077], [79.23874664, 9.24319553], [79.23874664, 9.2420826], [79.23930359, 9.2420826], [79.23930359, 9.24097347], [79.23874664, 9.24097347], [79.23874664, 9.24069309], [79.23791504, 9.24069309], [79.23791504, 9.24041653], [79.23735809, 9.24042034], [79.23735809, 9.24014091], [79.23652649, 9.24014091], [79.23652649, 9.23986053], [79.23625183, 9.23986053], [79.23625183, 9.23958302], [79.23458099, 9.23958111], [79.23458099, 9.24014091], [79.23430634, 9.24013901], [79.23430634, 9.24069309], [79.23402405, 9.24069309], [79.23402405, 9.24097347], [79.23374939, 9.24097061], [79.23374939, 9.24125099], [79.23347473, 9.24124908], [79.23347473, 9.2415266], [79.23319244, 9.2415266], [79.23319244, 9.2420826], [79.23291779, 9.2420826], [79.23291779, 9.24236107], [79.23264313, 9.24236107], [79.23264313, 9.24263859], [79.23235321, 9.24263859], [79.23235321, 9.24291992], [79.23208618, 9.24291706], [79.23208618, 9.24319553], [79.23180389, 9.24319553], [79.23180389, 9.24347115], [79.23152924, 9.24347115], [79.23152924, 9.24375153], [79.23124695, 9.24375153], [79.23124695, 9.24403191], [79.23152924, 9.24403191]]], [[[78.2529068, 8.95792103], [78.2529068, 8.95736027], [78.25319672, 8.95736217], [78.25319672, 8.9570837], [78.25347137, 8.9570837], [78.25347137, 8.95680618], [78.25374603, 8.95681095], [78.25374603, 8.95652962], [78.25402832, 8.95652962], [78.25402832, 8.95597172], [78.25458527, 8.95597172], [78.25458527, 8.9556942], [78.25485992, 8.9556942], [78.25485992, 8.95541573], [78.25541687, 8.95541954], [78.25541687, 8.95431137], [78.25514221, 8.95431137], [78.25514221, 8.95403004], [78.25485992, 8.95403004], [78.25485992, 8.95347023], [78.25458527, 8.95347214], [78.25458527, 8.95291805], [78.25402832, 8.95291805], [78.25402832, 8.95319366], [78.25291443, 8.95319366], [78.25291443, 8.95291805], [78.25235748, 8.95291805], [78.25235748, 8.95319366], [78.25180817, 8.95319366], [78.25180817, 8.95485973], [78.25152588, 8.95485973], [78.25152588, 8.95763969], [78.25123596, 8.95763969], [78.25123596, 8.95792103], [78.2529068, 8.95792103]]], [[[79.5293045, 9.38419724], [79.5293045, 9.38402843], [79.52913666, 9.38402843], [79.5293045, 9.38419724]]], [[[79.53009033, 9.38595772], [79.53013611, 9.38569355], [79.52998352, 9.38569355], [79.53009033, 9.38595772]]], [[[79.53009033, 9.38595772], [79.5300827, 9.38611794], [79.53006744, 9.3863802], [79.53012085, 9.38658524], [79.53020477, 9.38689518], [79.53013611, 9.38708401], [79.5304184, 9.38708401], [79.5304184, 9.38597202], [79.53009033, 9.38595772]]], [[[79.53013611, 9.38831711], [79.52993011, 9.38863564], [79.52986145, 9.38875008], [79.53013611, 9.38875008], [79.53013611, 9.38831711]]], [[[79.52986145, 9.38875008], [79.52970886, 9.38895512], [79.52967834, 9.38911533], [79.52986145, 9.38902092], [79.52986145, 9.38875008]]], [[[79.52958679, 9.38916016], [79.5293045, 9.38930416], [79.52958679, 9.38931084], [79.52958679, 9.38916016]]], [[[79.37374878, 9.21958447], [79.37403107, 9.21958447], [79.37403107, 9.21930599], [79.37431335, 9.2193079], [79.37431335, 9.21903038], [79.37458038, 9.21903038], [79.37458038, 9.21875191], [79.37486267, 9.21875191], [79.37486267, 9.21847057], [79.37541962, 9.21847057], [79.37541962, 9.21819305], [79.37569427, 9.21819305], [79.37569427, 9.2179184], [79.37596893, 9.2179203], [79.37596893, 9.21764183], [79.37625122, 9.21764183], [79.37625122, 9.2173624], [79.37652588, 9.2173624], [79.37652588, 9.21708298], [79.37708282, 9.21708298], [79.37708282, 9.21680546], [79.37735748, 9.21681023], [79.37735748, 9.21652985], [79.37763977, 9.21652985], [79.37763977, 9.21624947], [79.37791443, 9.21624947], [79.3779068, 9.21597099], [79.37847137, 9.21597099], [79.37847137, 9.21569538], [79.37875366, 9.21569538], [79.37875366, 9.21541691], [79.37930298, 9.21541977], [79.37930298, 9.21513939], [79.3795929, 9.21513939], [79.3795929, 9.21486092], [79.37985992, 9.21486092], [79.37985992, 9.2145834], [79.38041687, 9.2145834], [79.38041687, 9.21430492], [79.38069153, 9.21430969], [79.38069153, 9.21402931], [79.38124847, 9.21402931], [79.38124847, 9.21375084], [79.38153076, 9.21375084], [79.38153076, 9.21347141], [79.38208008, 9.21347332], [79.38208008, 9.21319485], [79.38236237, 9.21319485], [79.38236237, 9.21291733], [79.38291168, 9.21291924], [79.38291168, 9.21264076], [79.38346863, 9.21264076], [79.38346863, 9.21236134], [79.38430786, 9.21236134], [79.38430786, 9.21208286], [79.38486481, 9.21208286], [79.38486481, 9.21180534], [79.38513947, 9.21181202], [79.38513947, 9.21125126], [79.38541412, 9.21125126], [79.38540649, 9.21097088], [79.38569641, 9.21097088], [79.38569641, 9.21069527], [79.38652802, 9.21069527], [79.38652802, 9.21041679], [79.38680267, 9.21042156], [79.38680267, 9.21014118], [79.38764191, 9.21014118], [79.38764191, 9.2098608], [79.38791656, 9.2098608], [79.38791656, 9.20958328], [79.38819122, 9.20958328], [79.38819122, 9.20930481], [79.38846588, 9.20931244], [79.38846588, 9.20903111], [79.38903809, 9.20903111], [79.38903809, 9.20875072], [79.38957977, 9.20875072], [79.38957977, 9.20818996], [79.38986206, 9.20819473], [79.38986206, 9.20791721], [79.39041901, 9.20792103], [79.39041901, 9.20764065], [79.39068604, 9.20764065], [79.39068604, 9.20736122], [79.39097595, 9.20736122], [79.39097595, 9.20680523], [79.39125061, 9.20681095], [79.39125061, 9.20653057], [79.39180756, 9.20653057], [79.39180756, 9.20625114], [79.3923645, 9.20625114], [79.39235687, 9.20569038], [79.39263916, 9.20569515], [79.39263916, 9.20541668], [79.39319611, 9.20542145], [79.39319611, 9.20514107], [79.39375305, 9.20514107], [79.39375305, 9.20458031], [79.39430237, 9.20458221], [79.39430237, 9.2043066], [79.39457703, 9.20431137], [79.39457703, 9.20403099], [79.39485168, 9.20403099], [79.39485168, 9.20347023], [79.39541626, 9.20347214], [79.39541626, 9.20319366], [79.39569092, 9.20319366], [79.39569092, 9.20291615], [79.39624786, 9.20292091], [79.39624786, 9.20235062], [79.39680481, 9.20236015], [79.39680481, 9.20208359], [79.39736176, 9.20208359], [79.39736176, 9.20180416], [79.39763641, 9.20181084], [79.39763641, 9.20153141], [79.3979187, 9.20153141], [79.3979187, 9.20125008], [79.39819336, 9.20125008], [79.39819336, 9.2009697], [79.39875031, 9.2009716], [79.39875031, 9.20069408], [79.39902496, 9.20069408], [79.39902496, 9.20013809], [79.39930725, 9.20014], [79.39930725, 9.19985962], [79.3998642, 9.19986153], [79.3998642, 9.1995821], [79.40013885, 9.1995821], [79.40013885, 9.19930553], [79.40040588, 9.19931126], [79.40040588, 9.19902992], [79.4006958, 9.19902992], [79.4006958, 9.19874954], [79.40097046, 9.19874954], [79.40097809, 9.19847202], [79.4015274, 9.19847202], [79.4015274, 9.19819355], [79.40180206, 9.19819355], [79.40180206, 9.19791603], [79.40207672, 9.19791985], [79.40207672, 9.19764042], [79.4026413, 9.19764042], [79.4026413, 9.19736195], [79.40291595, 9.19736195], [79.40291595, 9.19652843], [79.4034729, 9.19654179], [79.4034729, 9.19624996], [79.40402222, 9.19624996], [79.40402222, 9.19596958], [79.4043045, 9.19597244], [79.4043045, 9.19541645], [79.40486145, 9.19542027], [79.40486145, 9.19514179], [79.4054184, 9.19514179], [79.4054184, 9.19486046], [79.40569305, 9.19486237], [79.40569305, 9.19458389], [79.40597534, 9.19458389], [79.40597534, 9.19430637], [79.40625, 9.19431019], [79.40625, 9.1940279], [79.40680695, 9.1940279], [79.40680695, 9.19375038], [79.4070816, 9.19375038], [79.4070816, 9.19347191], [79.40735626, 9.19348145], [79.40735626, 9.19319057], [79.40763855, 9.19319439], [79.40763855, 9.1926403], [79.40820313, 9.1926403], [79.40820313, 9.19208145], [79.40875244, 9.19208431], [79.40875244, 9.19180584], [79.40930176, 9.19180965], [79.40930939, 9.19153023], [79.4098587, 9.19153023], [79.4098587, 9.19124889], [79.41014099, 9.19124889], [79.41014099, 9.19069576], [79.41069794, 9.19069576], [79.41069794, 9.19041538], [79.4109726, 9.19041538], [79.4109726, 9.19013977], [79.41124725, 9.19014168], [79.41124725, 9.1898613], [79.41152954, 9.1898613], [79.41152954, 9.18958282], [79.41208649, 9.18958282], [79.41208649, 9.18930531], [79.41179657, 9.18931007], [79.41179657, 9.18874931], [79.41236115, 9.18874931], [79.41236115, 9.18847084], [79.4126358, 9.18847084], [79.4126358, 9.18819523], [79.41291809, 9.18819523], [79.41291809, 9.18791676], [79.41374969, 9.18791962], [79.41374969, 9.18735027], [79.41402435, 9.18736076], [79.41402435, 9.18708324], [79.41430664, 9.18708324], [79.41430664, 9.18652725], [79.41485596, 9.18653202], [79.41485596, 9.18625069], [79.4145813, 9.18625069], [79.4145813, 9.18597126], [79.4154129, 9.18597126], [79.4154129, 9.18625069], [79.41596222, 9.18625069], [79.41596222, 9.18569088], [79.41625214, 9.18569469], [79.41625214, 9.18541718], [79.41652679, 9.18542194], [79.41652679, 9.18514061], [79.41680908, 9.18514061], [79.41680908, 9.1845808], [79.41708374, 9.18458271], [79.41708374, 9.18430519], [79.4173584, 9.18431187], [79.4173584, 9.18403053], [79.41764069, 9.18403053], [79.41764069, 9.18375111], [79.41791534, 9.18375111], [79.41791534, 9.18347263], [79.41819763, 9.18347263], [79.41819763, 9.18319511], [79.41874695, 9.18319511], [79.41874695, 9.18291664], [79.41902161, 9.18292141], [79.41902161, 9.18264103], [79.41929626, 9.18264103], [79.41929626, 9.18236065], [79.41958618, 9.18236065], [79.41958618, 9.18208313], [79.41986084, 9.18208313], [79.41986084, 9.18180466], [79.42041779, 9.18180943], [79.42041779, 9.18153954], [79.4209671, 9.18153954], [79.4209671, 9.18097115], [79.42124939, 9.18097305], [79.42124939, 9.18041706], [79.42208862, 9.18042088], [79.42208862, 9.18014145], [79.42236328, 9.18014145], [79.42236328, 9.17986107], [79.42263794, 9.17986107], [79.42263794, 9.1795826], [79.42319489, 9.1795826], [79.42319489, 9.17930698], [79.42346954, 9.17930889], [79.42346954, 9.17903137], [79.42375183, 9.17903137], [79.42375183, 9.17875099], [79.42402649, 9.17875099], [79.42402649, 9.17846966], [79.42458344, 9.17847347], [79.42458344, 9.178195], [79.42485809, 9.178195], [79.42485809, 9.17791653], [79.42514801, 9.1779213], [79.42514801, 9.17764091], [79.42542267, 9.17764091], [79.42542267, 9.17708015], [79.42569733, 9.17708206], [79.42569733, 9.17652893], [79.42597198, 9.17653084], [79.42597198, 9.17625046], [79.42652893, 9.17625046], [79.42652893, 9.17597198], [79.42708588, 9.17597198], [79.42708588, 9.17569447], [79.42736053, 9.17569447], [79.42736053, 9.17513847], [79.42764282, 9.17514133], [79.42764282, 9.17486], [79.42847443, 9.17486], [79.42847443, 9.17458439], [79.42874908, 9.17458439], [79.42874908, 9.17430592], [79.42903137, 9.17431068], [79.42903137, 9.17403126], [79.42930603, 9.17403126], [79.42930603, 9.17374992], [79.42986298, 9.17374992], [79.42986298, 9.17346954], [79.43013763, 9.1734724], [79.43013763, 9.17291641], [79.43041992, 9.17292118], [79.43041992, 9.17263985], [79.43068695, 9.17263985], [79.43068695, 9.17208195], [79.43096924, 9.17208195], [79.43096924, 9.17180634], [79.43125153, 9.1718111], [79.43125153, 9.17152977], [79.43152618, 9.17152977], [79.43152618, 9.17125034], [79.43180847, 9.17125034], [79.43180847, 9.17069435], [79.43208313, 9.17069435], [79.43208313, 9.17041588], [79.43235779, 9.17041969], [79.43235779, 9.17014027], [79.43264008, 9.17014027], [79.43264008, 9.16986179], [79.4329071, 9.16986179], [79.4329071, 9.16957855], [79.43319702, 9.16958427], [79.43319702, 9.1693058], [79.43347168, 9.16930962], [79.43347168, 9.16903019], [79.43374634, 9.16903019], [79.43374634, 9.16874981], [79.43402863, 9.16874981], [79.43402863, 9.16847229], [79.43430328, 9.16847229], [79.43430328, 9.16819382], [79.43458557, 9.16819382], [79.43458557, 9.1679163], [79.43486023, 9.16792011], [79.43486023, 9.16763973], [79.43514252, 9.16763973], [79.43514252, 9.16708088], [79.43541718, 9.16708374], [79.43541718, 9.16680622], [79.43569183, 9.16681004], [79.43569183, 9.16623974], [79.43597412, 9.16625023], [79.43597412, 9.16597366], [79.43624878, 9.16597176], [79.43624878, 9.16569424], [79.43653107, 9.16569424], [79.43653107, 9.16514015], [79.43681335, 9.16514015], [79.43681335, 9.16486168], [79.43708038, 9.16486168], [79.43708038, 9.16458416], [79.43763733, 9.16458416], [79.43763733, 9.16430569], [79.43791962, 9.16431046], [79.43791962, 9.16403198], [79.43846893, 9.16403198], [79.43846893, 9.1637516], [79.43875122, 9.1637516], [79.43875122, 9.16347122], [79.43902588, 9.16347122], [79.43902588, 9.16319561], [79.43930817, 9.16319561], [79.43930817, 9.16291809], [79.43958282, 9.16292191], [79.43958282, 9.16263866], [79.43985748, 9.16263866], [79.43985748, 9.16208076], [79.44013977, 9.16208267], [79.44013977, 9.16152668], [79.43930817, 9.16152668], [79.43930817, 9.16208267], [79.43902588, 9.16208267], [79.43902588, 9.16236115], [79.43875122, 9.16235924], [79.43875122, 9.16263866], [79.43846893, 9.16263866], [79.43846893, 9.16292191], [79.43791962, 9.16291809], [79.43791962, 9.16319561], [79.43763733, 9.16319561], [79.43763733, 9.16347122], [79.43708801, 9.16347122], [79.43708801, 9.1637516], [79.43681335, 9.1637516], [79.43681335, 9.16403198], [79.43653107, 9.16403198], [79.43653107, 9.16431046], [79.43624878, 9.16430569], [79.43624878, 9.16458416], [79.43596649, 9.1645813], [79.43597412, 9.16486168], [79.43569183, 9.16486168], [79.43569183, 9.16514015], [79.43541718, 9.16514015], [79.43541718, 9.16541958], [79.43514252, 9.16541767], [79.43514252, 9.16569424], [79.43486023, 9.16569424], [79.43486023, 9.16597176], [79.4345932, 9.16596889], [79.4345932, 9.16652966], [79.43430328, 9.16652966], [79.43430328, 9.16681004], [79.43402863, 9.16680622], [79.43402863, 9.16708374], [79.43374634, 9.16708374], [79.43374634, 9.16736221], [79.43347168, 9.16736031], [79.43347168, 9.16763973], [79.43319702, 9.16763973], [79.43319702, 9.16819382], [79.43291473, 9.16819382], [79.43291473, 9.16847229], [79.43264008, 9.16847229], [79.43264008, 9.16874981], [79.43235779, 9.16874981], [79.43235779, 9.16930962], [79.43208313, 9.1693058], [79.43208313, 9.16958427], [79.43125153, 9.16957855], [79.43125153, 9.16986179], [79.43068695, 9.16986179], [79.43068695, 9.17014027], [79.43041992, 9.17014027], [79.43041992, 9.17041969], [79.43013763, 9.17041588], [79.43013763, 9.17069435], [79.42986298, 9.17069435], [79.42986298, 9.17125034], [79.42958069, 9.17125034], [79.42958069, 9.17152977], [79.42930603, 9.17152977], [79.42930603, 9.1718111], [79.42903137, 9.17180634], [79.42903137, 9.17208195], [79.42874908, 9.17208195], [79.42874908, 9.17237091], [79.4284668, 9.17237091], [79.4284668, 9.17263985], [79.42819214, 9.17263985], [79.42819214, 9.17292118], [79.42791748, 9.17291641], [79.42791748, 9.1734724], [79.42764282, 9.17346954], [79.42764282, 9.17374992], [79.42736053, 9.17374992], [79.42736053, 9.17403126], [79.42708588, 9.17403126], [79.42708588, 9.17431068], [79.42680359, 9.17430592], [79.42680359, 9.17458439], [79.42652893, 9.17458439], [79.42652893, 9.17486], [79.42624664, 9.17486], [79.42624664, 9.17514133], [79.42597198, 9.17513847], [79.42597198, 9.17541599], [79.42569733, 9.17541599], [79.42569733, 9.17569447], [79.42541504, 9.17569447], [79.42541504, 9.17597198], [79.42514801, 9.17597008], [79.42514038, 9.17625046], [79.42485809, 9.17625046], [79.42485809, 9.17653084], [79.42457581, 9.17653084], [79.42457581, 9.17681122], [79.42430878, 9.1768074], [79.42430878, 9.17708206], [79.42292023, 9.17708206], [79.42292023, 9.17735958], [79.42263794, 9.17735958], [79.42263794, 9.1779213], [79.42208099, 9.17791653], [79.42208099, 9.178195], [79.42152405, 9.178195], [79.42152405, 9.17847347], [79.42124939, 9.17846966], [79.42124939, 9.17903137], [79.42097473, 9.17902565], [79.42097473, 9.1795826], [79.42069244, 9.1795826], [79.42069244, 9.17986107], [79.42041779, 9.17986107], [79.42041779, 9.18014145], [79.41986084, 9.18014145], [79.41986084, 9.18042088], [79.41958618, 9.18041706], [79.41958618, 9.18069458], [79.41929626, 9.1806879], [79.41929626, 9.18125057], [79.41902161, 9.18125057], [79.41902161, 9.18153954], [79.41847229, 9.18153954], [79.41847229, 9.18180943], [79.41819763, 9.18180466], [79.41819763, 9.18208313], [79.41791534, 9.18208313], [79.41791534, 9.18236065], [79.41764069, 9.18236065], [79.41764069, 9.18264103], [79.4173584, 9.18264103], [79.4173584, 9.18292141], [79.41708374, 9.18291664], [79.41708374, 9.18319511], [79.41680908, 9.18319511], [79.41680908, 9.18347263], [79.41652679, 9.18347263], [79.41652679, 9.18375111], [79.41625214, 9.18375111], [79.41625214, 9.18347263], [79.41486359, 9.18347263], [79.41486359, 9.18263912], [79.4145813, 9.18264103], [79.4145813, 9.18208027], [79.41486359, 9.18208313], [79.41486359, 9.18097305], [79.4154129, 9.18097305], [79.4154129, 9.18069458], [79.41569519, 9.18069458], [79.41569519, 9.18013859], [79.41596222, 9.18014145], [79.41596222, 9.17986107], [79.41652679, 9.17986107], [79.41652679, 9.1795826], [79.41680908, 9.1795826], [79.41680908, 9.17930698], [79.41707611, 9.17930889], [79.41707611, 9.17903137], [79.41792297, 9.17903137], [79.41792297, 9.17875099], [79.41986084, 9.17875099], [79.41986084, 9.17764091], [79.42014313, 9.17764091], [79.42014313, 9.17735958], [79.42041779, 9.17735958], [79.42041779, 9.1779213], [79.42151642, 9.1779213], [79.42151642, 9.17764091], [79.42208862, 9.17764091], [79.42208862, 9.17597008], [79.42236328, 9.17597198], [79.42236328, 9.17541599], [79.42263794, 9.17541599], [79.42263794, 9.17486], [79.42292023, 9.17486], [79.42292023, 9.17430592], [79.42318726, 9.17431068], [79.42318726, 9.17403126], [79.42375183, 9.17403126], [79.42375183, 9.17374992], [79.42402649, 9.17374992], [79.42402649, 9.17346954], [79.42458344, 9.1734724], [79.42458344, 9.17319393], [79.42485809, 9.17319393], [79.42485809, 9.17291641], [79.42542267, 9.17292118], [79.42542267, 9.17263985], [79.42569733, 9.17263985], [79.42569733, 9.17208195], [79.42597198, 9.17208195], [79.42597198, 9.17180634], [79.42624664, 9.1718111], [79.42624664, 9.17152977], [79.42652893, 9.17152977], [79.42652893, 9.17125034], [79.42680359, 9.17125034], [79.42679596, 9.17097187], [79.42708588, 9.17097187], [79.42708588, 9.17041588], [79.42736053, 9.17041969], [79.42736053, 9.17014027], [79.42764282, 9.17014027], [79.42764282, 9.16986179], [79.42791748, 9.16986179], [79.42791748, 9.16957855], [79.42819214, 9.16958427], [79.42819214, 9.1693058], [79.4284668, 9.16930962], [79.4284668, 9.16903019], [79.42874908, 9.16903019], [79.42874908, 9.16874981], [79.42903137, 9.16874981], [79.42903137, 9.16819382], [79.42930603, 9.16819382], [79.42930603, 9.16763973], [79.42958069, 9.16763973], [79.42958069, 9.16736031], [79.43041992, 9.16736221], [79.43041992, 9.16708374], [79.43152618, 9.16708374], [79.43152618, 9.16680622], [79.43180847, 9.16681004], [79.43180847, 9.16623974], [79.43208313, 9.16625023], [79.43208313, 9.16597366], [79.43235779, 9.16597176], [79.43235779, 9.16569424], [79.43264008, 9.16569424], [79.43264008, 9.16514015], [79.4329071, 9.16514015], [79.4329071, 9.16486168], [79.43319702, 9.16486168], [79.43319702, 9.16458416], [79.43347168, 9.16458416], [79.43347168, 9.16430569], [79.43374634, 9.16431046], [79.43374634, 9.16403198], [79.43402863, 9.16403198], [79.43402863, 9.1637516], [79.43430328, 9.1637516], [79.43430328, 9.16347122], [79.43458557, 9.16347122], [79.43458557, 9.16319561], [79.43486023, 9.16319561], [79.43486023, 9.16291809], [79.43514252, 9.16292191], [79.43514252, 9.16263866], [79.43541718, 9.16263866], [79.43541718, 9.16235924], [79.43569183, 9.16236115], [79.43569183, 9.16208267], [79.43597412, 9.16208267], [79.43597412, 9.16180515], [79.43624878, 9.16180992], [79.43624878, 9.16152954], [79.43653107, 9.16152954], [79.43653107, 9.16125107], [79.43681335, 9.16125107], [79.43681335, 9.16097069], [79.43736267, 9.1609726], [79.43736267, 9.16069317], [79.43763733, 9.16069317], [79.43763733, 9.1604166], [79.43791962, 9.16043091], [79.43791962, 9.16014194], [79.43818665, 9.16014194], [79.43818665, 9.15986061], [79.43846893, 9.15986061], [79.43846893, 9.15958309], [79.43875122, 9.15958309], [79.43875122, 9.15930462], [79.43902588, 9.15931034], [79.43902588, 9.15903187], [79.43930817, 9.15903187], [79.43930817, 9.15875053], [79.43958282, 9.15875053], [79.43958282, 9.15847111], [79.43985748, 9.15847111], [79.43985748, 9.15819454], [79.43902588, 9.15819454], [79.43902588, 9.15847111], [79.43875122, 9.15847111], [79.43875122, 9.15875053], [79.43846893, 9.15875053], [79.43846893, 9.15903187], [79.43818665, 9.15903187], [79.43818665, 9.15931034], [79.43791962, 9.15930462], [79.43791962, 9.15958309], [79.43763733, 9.15958309], [79.43763733, 9.15986061], [79.43736267, 9.15986061], [79.43736267, 9.16014194], [79.43681335, 9.16014194], [79.43681335, 9.16043091], [79.43653107, 9.1604166], [79.43653107, 9.16069317], [79.43597412, 9.16069317], [79.43597412, 9.1609726], [79.43569183, 9.16097069], [79.43569183, 9.16125107], [79.43541718, 9.16125107], [79.43541718, 9.16152954], [79.43486023, 9.16152954], [79.43486023, 9.16180992], [79.43458557, 9.16180515], [79.43458557, 9.16208267], [79.43430328, 9.16208267], [79.43430328, 9.16236115], [79.43402863, 9.16235924], [79.43402863, 9.16263866], [79.43374634, 9.16263866], [79.43374634, 9.16292191], [79.43347168, 9.16291809], [79.43347168, 9.16319561], [79.43319702, 9.16319561], [79.43319702, 9.16347122], [79.43264008, 9.16347122], [79.43264008, 9.1637516], [79.43235779, 9.1637516], [79.43235779, 9.16403198], [79.43208313, 9.16403198], [79.43208313, 9.16431046], [79.43180847, 9.16430569], [79.43180847, 9.16458416], [79.43152618, 9.16458416], [79.43152618, 9.16486168], [79.43125153, 9.16486168], [79.43125153, 9.16514015], [79.43096924, 9.16514015], [79.43096924, 9.16569424], [79.43069458, 9.16569424], [79.43069458, 9.16597176], [79.43041992, 9.16597176], [79.43041992, 9.16625023], [79.43013763, 9.16623974], [79.43013763, 9.16652966], [79.42958069, 9.16652966], [79.42958069, 9.16681004], [79.42930603, 9.16680622], [79.42930603, 9.16708374], [79.42903137, 9.16708374], [79.42903137, 9.16736221], [79.42874908, 9.16736031], [79.42874908, 9.16763973], [79.42819214, 9.16763973], [79.42819214, 9.16792011], [79.42791748, 9.1679163], [79.42791748, 9.16819382], [79.42763519, 9.16819382], [79.42763519, 9.16847229], [79.42736053, 9.16847229], [79.42736053, 9.16874981], [79.42708588, 9.16874981], [79.42708588, 9.16903019], [79.42679596, 9.16903019], [79.42679596, 9.16930962], [79.42652893, 9.16930962], [79.42652893, 9.16986179], [79.42624664, 9.16986179], [79.42624664, 9.17041969], [79.42541504, 9.17041588], [79.42541504, 9.17069435], [79.42458344, 9.17069435], [79.42458344, 9.17097187], [79.42318726, 9.17097187], [79.42319489, 9.17125034], [79.42292023, 9.17125034], [79.42292023, 9.1718111], [79.42236328, 9.1718111], [79.42236328, 9.17237091], [79.42208862, 9.17237091], [79.42208862, 9.17374992], [79.42180634, 9.17374992], [79.42180634, 9.17403126], [79.42124939, 9.17403126], [79.42124939, 9.17431068], [79.42097473, 9.17430592], [79.42097473, 9.17458439], [79.42069244, 9.17458439], [79.42069244, 9.17486], [79.42014313, 9.17486], [79.42014313, 9.17514133], [79.41986084, 9.17513847], [79.41986084, 9.17541599], [79.41930389, 9.17541599], [79.41930389, 9.17569447], [79.41902924, 9.17569447], [79.41902924, 9.17597198], [79.41764069, 9.17597008], [79.41764069, 9.17625046], [79.4173584, 9.17625046], [79.4173584, 9.17653084], [79.41680908, 9.17653084], [79.41680908, 9.17681122], [79.41652679, 9.1768074], [79.41652679, 9.17708206], [79.41596985, 9.17708206], [79.41596985, 9.17735958], [79.41570282, 9.17735958], [79.41570282, 9.17764091], [79.41513824, 9.17764091], [79.41513824, 9.1779213], [79.41486359, 9.17791653], [79.41486359, 9.178195], [79.41430664, 9.178195], [79.41430664, 9.17847347], [79.41348267, 9.17846966], [79.41348267, 9.17875099], [79.41319275, 9.17875099], [79.41319275, 9.17930889], [79.41208649, 9.17930698], [79.41208649, 9.1795826], [79.41179657, 9.17957973], [79.4118042, 9.17986107], [79.41152954, 9.17986107], [79.41152954, 9.18014145], [79.4109726, 9.18014145], [79.4109726, 9.18042088], [79.41069794, 9.18041706], [79.41069794, 9.18069458], [79.41041565, 9.18069458], [79.41041565, 9.18097305], [79.4090271, 9.18097115], [79.4090271, 9.18125057], [79.40875244, 9.18125057], [79.40875244, 9.18153954], [79.40820313, 9.18153954], [79.40820313, 9.18180943], [79.40791321, 9.18180466], [79.40791321, 9.18208313], [79.40763855, 9.18208313], [79.40763855, 9.18236065], [79.4070816, 9.18236065], [79.4070816, 9.18264103], [79.40680695, 9.18264103], [79.40680695, 9.18292141], [79.40652466, 9.18291664], [79.40652466, 9.18347263], [79.40625, 9.18347263], [79.40625, 9.18375111], [79.40513611, 9.18375111], [79.40513611, 9.18403053], [79.40486145, 9.18403053], [79.40486145, 9.18431187], [79.4043045, 9.18430519], [79.4043045, 9.18458271], [79.40402985, 9.18458271], [79.40402985, 9.18486118], [79.4034729, 9.18486118], [79.4034729, 9.18542194], [79.40291595, 9.18541718], [79.40291595, 9.18569469], [79.40235901, 9.18569469], [79.40235901, 9.18597317], [79.40207672, 9.18597126], [79.40207672, 9.18653202], [79.40097809, 9.18653202], [79.40097809, 9.18680954], [79.4006958, 9.18680477], [79.4006958, 9.18708324], [79.39958191, 9.18708324], [79.39958191, 9.18736076], [79.39930725, 9.18735027], [79.39930725, 9.18763924], [79.39901733, 9.18763924], [79.39901733, 9.18791962], [79.39875031, 9.18791676], [79.39875031, 9.18819523], [79.39819336, 9.18819523], [79.39819336, 9.18847084], [79.39763641, 9.18847084], [79.39763641, 9.18874931], [79.39736176, 9.18874931], [79.39736176, 9.18902969], [79.39653015, 9.18902683], [79.39653015, 9.19041538], [79.39541626, 9.19041538], [79.39541626, 9.19069576], [79.39485931, 9.19069576], [79.39485931, 9.19097137], [79.39457703, 9.19097137], [79.39458466, 9.19124889], [79.39402771, 9.19124889], [79.39402771, 9.19153023], [79.39375305, 9.19153023], [79.39375305, 9.19180965], [79.39319611, 9.19180584], [79.39319611, 9.19208431], [79.39235687, 9.19208145], [79.3923645, 9.19236183], [79.39180756, 9.19236183], [79.39180756, 9.1926403], [79.3915329, 9.1926403], [79.3915329, 9.19291973], [79.39125061, 9.19291782], [79.39125061, 9.19319439], [79.39068604, 9.19319057], [79.39068604, 9.19348145], [79.39013672, 9.19347191], [79.39013672, 9.19375038], [79.38986206, 9.19375038], [79.38986206, 9.1940279], [79.38931274, 9.1940279], [79.38931274, 9.19431019], [79.38874817, 9.19430637], [79.38874817, 9.19458389], [79.38819122, 9.19458389], [79.38819122, 9.19486237], [79.38764191, 9.19486046], [79.38764191, 9.19514179], [79.38707733, 9.19514179], [79.38707733, 9.19542027], [79.38680267, 9.19541645], [79.38680267, 9.19569397], [79.38625336, 9.19569397], [79.38625336, 9.19597244], [79.38569641, 9.19596958], [79.38569641, 9.19624996], [79.38513947, 9.19624996], [79.38513947, 9.19654179], [79.38485718, 9.19654179], [79.38485718, 9.19681072], [79.38458252, 9.19680595], [79.38458252, 9.19708443], [79.38430786, 9.19708443], [79.38430786, 9.19736195], [79.38375092, 9.19736195], [79.38375092, 9.19764042], [79.38346863, 9.19764042], [79.38346863, 9.19791985], [79.38291931, 9.19791603], [79.38291931, 9.19819355], [79.38263702, 9.19819355], [79.38263702, 9.19847202], [79.38153076, 9.19847202], [79.38153076, 9.19874954], [79.38124847, 9.19874954], [79.38124847, 9.19902992], [79.38069153, 9.19902992], [79.38069153, 9.19931126], [79.38041687, 9.19930553], [79.38041687, 9.1995821], [79.37985992, 9.1995821], [79.37985992, 9.19986153], [79.3795929, 9.19985962], [79.3795929, 9.20014], [79.37902832, 9.20014], [79.37902832, 9.20042133], [79.37847137, 9.20041561], [79.37847137, 9.20069408], [79.37791443, 9.20069408], [79.37791443, 9.2009716], [79.37763977, 9.2009697], [79.37763977, 9.20125008], [79.37708282, 9.20125008], [79.37708282, 9.20153141], [79.37652588, 9.20153141], [79.37652588, 9.20181084], [79.37625122, 9.20180416], [79.37625122, 9.20208359], [79.37569427, 9.20208359], [79.37569427, 9.20236015], [79.37541962, 9.20235062], [79.37541962, 9.20264053], [79.37486267, 9.20264053], [79.37486267, 9.20292091], [79.37458038, 9.20291615], [79.37458038, 9.20319366], [79.37431335, 9.20318985], [79.37431335, 9.20375061], [79.37346649, 9.20375061], [79.37346649, 9.20403099], [79.37264252, 9.20403099], [79.37264252, 9.20431137], [79.37208557, 9.2043066], [79.37208557, 9.20458221], [79.37180328, 9.20458221], [79.37180328, 9.20485973], [79.37152863, 9.20485973], [79.37152863, 9.20514107], [79.37124634, 9.20514107], [79.37124634, 9.20542145], [79.37041473, 9.20541668], [79.37041473, 9.20569515], [79.37014008, 9.20569515], [79.37014008, 9.20597267], [79.36958313, 9.20597267], [79.36958313, 9.20625114], [79.36930847, 9.20625114], [79.36930847, 9.20653057], [79.36875153, 9.20653057], [79.36875153, 9.20681095], [79.36846924, 9.20680523], [79.36846924, 9.20708275], [79.36819458, 9.20708275], [79.36819458, 9.20736122], [79.36763763, 9.20736122], [79.36763763, 9.20764065], [79.36708069, 9.20764065], [79.36708069, 9.20792103], [79.36653137, 9.20791721], [79.36653137, 9.20819473], [79.36624908, 9.20818996], [79.36624908, 9.20848179], [79.36569214, 9.20848179], [79.36569214, 9.20875072], [79.36541748, 9.20875072], [79.36541748, 9.20903111], [79.36486816, 9.20903111], [79.36486816, 9.20931244], [79.36458588, 9.20930481], [79.36458588, 9.20958328], [79.36402893, 9.20958328], [79.36402893, 9.2098608], [79.36374664, 9.2098608], [79.36374664, 9.21014118], [79.36347198, 9.21013927], [79.36347198, 9.21069527], [79.36319733, 9.21069527], [79.36319733, 9.21097088], [79.36264038, 9.21097088], [79.36264038, 9.21125126], [79.36235809, 9.21125126], [79.36235809, 9.21154118], [79.36180878, 9.21154118], [79.36180878, 9.21181202], [79.36152649, 9.21180534], [79.36152649, 9.21208286], [79.36096954, 9.21208286], [79.36096954, 9.21236134], [79.36068726, 9.21236134], [79.36068726, 9.21264076], [79.36042023, 9.21264076], [79.36042023, 9.21291924], [79.36013794, 9.21291733], [79.36013794, 9.21319485], [79.35958099, 9.21319485], [79.35958099, 9.21347332], [79.35930634, 9.21347141], [79.35930634, 9.21402931], [79.35819244, 9.21402931], [79.35819244, 9.21430969], [79.3576355, 9.21430492], [79.3576355, 9.2145834], [79.35708618, 9.2145834], [79.35708618, 9.21486092], [79.35679626, 9.21486092], [79.35679626, 9.21541977], [79.35652924, 9.21541691], [79.35652924, 9.21569538], [79.35569763, 9.21569538], [79.35569763, 9.21597099], [79.35514069, 9.21597099], [79.35514069, 9.21624947], [79.35430908, 9.21624947], [79.35430908, 9.21652985], [79.35375214, 9.21652985], [79.35375214, 9.21681023], [79.35319519, 9.21680546], [79.35319519, 9.21708298], [79.3529129, 9.21708298], [79.3529129, 9.2173624], [79.35235596, 9.2173624], [79.35235596, 9.21764183], [79.3520813, 9.21764183], [79.3520813, 9.2179203], [79.35152435, 9.2179184], [79.35152435, 9.21819305], [79.35098267, 9.21819115], [79.35098267, 9.21903038], [79.3501358, 9.21903038], [79.3501358, 9.2193079], [79.3493042, 9.21930599], [79.3493042, 9.21958447], [79.34902954, 9.21958447], [79.34902954, 9.21986198], [79.34874725, 9.21986198], [79.34874725, 9.22014046], [79.3484726, 9.22014046], [79.3484726, 9.22042179], [79.34819794, 9.22041798], [79.34819794, 9.22069359], [79.3473587, 9.22069359], [79.3473587, 9.22097206], [79.34680939, 9.2209692], [79.34680939, 9.22124958], [79.3465271, 9.22124958], [79.3465271, 9.22152996], [79.34597015, 9.22152996], [79.34597015, 9.22181034], [79.34541321, 9.22180557], [79.34541321, 9.22208405], [79.34513855, 9.22208405], [79.34513855, 9.22235966], [79.3445816, 9.22235966], [79.3445816, 9.22264004], [79.34430695, 9.22264004], [79.34430695, 9.22292042], [79.34374237, 9.22292042], [79.34374237, 9.22348118], [79.34348297, 9.22348118], [79.34348297, 9.22402954], [79.34208679, 9.22402954], [79.34208679, 9.22431087], [79.3418045, 9.22430611], [79.3418045, 9.22458363], [79.34124756, 9.22458363], [79.34124756, 9.2248621], [79.3409729, 9.22486019], [79.3409729, 9.22513962], [79.34069824, 9.22513962], [79.34068298, 9.22542095], [79.33958435, 9.22541809], [79.33958435, 9.2256937], [79.33930206, 9.2256937], [79.33930206, 9.22597218], [79.33847046, 9.22597027], [79.33847046, 9.22624969], [79.33791351, 9.22624969], [79.33791351, 9.22652817], [79.33763885, 9.22652054], [79.33763885, 9.22681141], [79.3373642, 9.22680569], [79.3373642, 9.22708416], [79.33708191, 9.22708416], [79.33708191, 9.22735977], [79.33680725, 9.22735977], [79.33680725, 9.22764015], [79.33625031, 9.22764015], [79.33625031, 9.22792053], [79.33597565, 9.22791576], [79.33597565, 9.22819424], [79.33569336, 9.22819424], [79.33569336, 9.22847176], [79.3354187, 9.22847176], [79.3354187, 9.22875023], [79.33486938, 9.22875023], [79.33486938, 9.22903061], [79.3345871, 9.22903061], [79.3345871, 9.22931099], [79.33291626, 9.22930431], [79.33291626, 9.22958469], [79.3326416, 9.22958469], [79.3326416, 9.22986031], [79.33207703, 9.22986031], [79.33207703, 9.23014069], [79.33180237, 9.23014069], [79.33180237, 9.23042107], [79.33125305, 9.2304163], [79.33125305, 9.23069382], [79.33069611, 9.23069382], [79.33069611, 9.23097324], [79.33013916, 9.23097324], [79.33013916, 9.23125076], [79.32985687, 9.2312479], [79.32985687, 9.23153114], [79.32930756, 9.23153114], [79.32930756, 9.23181057], [79.32875061, 9.23180676], [79.32875061, 9.23208237], [79.32818604, 9.23208046], [79.32818604, 9.23236275], [79.32681274, 9.23236275], [79.32681274, 9.2326498], [79.32624817, 9.2326498], [79.32624817, 9.23292065], [79.32597351, 9.23291683], [79.32597351, 9.2331953], [79.32569122, 9.2331953], [79.32569122, 9.23347282], [79.32541656, 9.23347282], [79.32541656, 9.2337513], [79.32457733, 9.2337513], [79.32457733, 9.23403072], [79.32430267, 9.23403072], [79.32430267, 9.2343092], [79.32402802, 9.23430538], [79.32402802, 9.23486137], [79.32375336, 9.23486137], [79.32375336, 9.23513889], [79.32347107, 9.23513889], [79.32347107, 9.23541927], [79.32236481, 9.23541737], [79.32236481, 9.23569489], [79.32208252, 9.23569012], [79.32208252, 9.23625088], [79.32180786, 9.23625088], [79.32180786, 9.23653126], [79.3215332, 9.23653126], [79.3215332, 9.23681164], [79.32068634, 9.23681164], [79.32068634, 9.23653126], [79.32041931, 9.23653126], [79.32041931, 9.23625088], [79.32013702, 9.23625088], [79.32013702, 9.23653126], [79.31986237, 9.23653126], [79.31986237, 9.23681164], [79.31930542, 9.23680496], [79.31930542, 9.23708344], [79.31903076, 9.23708344], [79.31903076, 9.23736095], [79.31791687, 9.23736095], [79.31791687, 9.23764133], [79.31735992, 9.23763943], [79.31735992, 9.23819542], [79.31680298, 9.23819542], [79.31680298, 9.23847103], [79.31624603, 9.23845863], [79.31624603, 9.23875141], [79.3154068, 9.23875141], [79.3154068, 9.23903179], [79.31485748, 9.23903179], [79.31485748, 9.23931026], [79.31402588, 9.23930454], [79.31402588, 9.23958302], [79.31319427, 9.23958302], [79.31319427, 9.23986053], [79.31291962, 9.23986053], [79.31291962, 9.24014091], [79.31263733, 9.24014091], [79.31263733, 9.24042034], [79.31180573, 9.24041653], [79.31180573, 9.24069309], [79.31153107, 9.24069309], [79.31153107, 9.24097347], [79.31109619, 9.24097347], [79.31097412, 9.24097347], [79.31096649, 9.24114037], [79.31096649, 9.24125099], [79.31014252, 9.24124908], [79.31014252, 9.2415266], [79.30930328, 9.24151993], [79.30930328, 9.24180984], [79.30902863, 9.24180508], [79.30902863, 9.2420826], [79.30874634, 9.2420826], [79.30874634, 9.24236107], [79.30847168, 9.24236107], [79.30847168, 9.24263859], [79.30735779, 9.24263859], [79.30735779, 9.24291992], [79.30652618, 9.24291706], [79.30652618, 9.24319553], [79.30596924, 9.24319553], [79.30596924, 9.24347115], [79.30568695, 9.24347115], [79.30568695, 9.24375153], [79.30486298, 9.24375153], [79.30486298, 9.24403191], [79.30403137, 9.24403191], [79.30403137, 9.24431038], [79.30319214, 9.24431038], [79.30319214, 9.24458981], [79.30263519, 9.24458408], [79.30263519, 9.2448616], [79.30236053, 9.2448616], [79.30236053, 9.24514198], [79.30152893, 9.24514198], [79.30152893, 9.24542046], [79.30097198, 9.24541759], [79.30097198, 9.24569321], [79.30041504, 9.24569321], [79.30041504, 9.24597168], [79.29985809, 9.24597168], [79.29985809, 9.24625015], [79.29930878, 9.24625015], [79.29930878, 9.24652958], [79.29875946, 9.24652958], [79.29875946, 9.24680996], [79.29792023, 9.24680614], [79.29792023, 9.24708366], [79.29736328, 9.24708366], [79.29736328, 9.24736214], [79.29651642, 9.24735928], [79.29651642, 9.2476511], [79.29569244, 9.2476511], [79.29569244, 9.24792004], [79.29486084, 9.24791622], [79.29486084, 9.24819374], [79.29430389, 9.24819374], [79.29430389, 9.24847221], [79.29347229, 9.24846935], [79.29347229, 9.24874973], [79.29263306, 9.24874973], [79.29263306, 9.24903011], [79.29207611, 9.24903011], [79.29207611, 9.24930954], [79.29125214, 9.24930573], [79.29125214, 9.2495842], [79.29069519, 9.2495842], [79.29069519, 9.24985981], [79.28985596, 9.24985981], [79.28985596, 9.25014019], [79.28930664, 9.25014019], [79.28930664, 9.25041962], [79.28847504, 9.2504158], [79.28847504, 9.25069427], [79.28791809, 9.25069427], [79.28791809, 9.25097179], [79.28708649, 9.25097179], [79.28708649, 9.25125027], [79.28652954, 9.25125027], [79.28652954, 9.25152969], [79.2859726, 9.25152969], [79.2859726, 9.25181103], [79.2848587, 9.25180626], [79.2848587, 9.25208378], [79.2840271, 9.25208378], [79.2840271, 9.25236225], [79.28320313, 9.25236034], [79.28320313, 9.25263977], [79.28263855, 9.25263786], [79.28263855, 9.25319386], [79.28180695, 9.25319386], [79.28180695, 9.25347233], [79.28069305, 9.25347233], [79.28069305, 9.25374985], [79.27958679, 9.25374985], [79.27958679, 9.25347233], [79.27874756, 9.25347233], [79.27874756, 9.25374985], [79.27819824, 9.25374985], [79.27819061, 9.25403118], [79.27764893, 9.25403118], [79.27764893, 9.25431061], [79.27708435, 9.25430584], [79.27708435, 9.25458431], [79.27485657, 9.25457954], [79.27485657, 9.25485992], [79.27401733, 9.25485992], [79.27401733, 9.2551403], [79.27319336, 9.2551403], [79.27319336, 9.25542068], [79.27180481, 9.25541592], [79.27180481, 9.25569439], [79.27124786, 9.25569439], [79.27124786, 9.25597191], [79.26846313, 9.25597], [79.26847076, 9.25625038], [79.26763916, 9.25625038], [79.26763916, 9.2565279], [79.26708221, 9.2565279], [79.26708221, 9.25681973], [79.26625061, 9.25680733], [79.26625061, 9.25708199], [79.26457977, 9.25708199], [79.26457977, 9.25736046], [79.26374817, 9.25736046], [79.26374817, 9.25708199], [79.26152802, 9.25708199], [79.26152802, 9.25736046], [79.26125336, 9.25736046], [79.26125336, 9.25764084], [79.26097107, 9.25764084], [79.26097107, 9.25792122], [79.25930786, 9.25791645], [79.25930786, 9.25819492], [79.25846863, 9.25819492], [79.25846863, 9.2584734], [79.25736237, 9.25846958], [79.25736237, 9.25875092], [79.25541687, 9.25875092], [79.25541687, 9.2590313], [79.25514221, 9.2590313], [79.25514221, 9.25931072], [79.25345612, 9.25931072], [79.25345612, 9.2595892], [79.25096893, 9.2595892], [79.25096893, 9.25931072], [79.24931335, 9.25931072], [79.24931335, 9.2595892], [79.24874878, 9.25958157], [79.24874878, 9.25986099], [79.24819183, 9.25986099], [79.24819183, 9.26014137], [79.24624634, 9.26014137], [79.24624634, 9.25986099], [79.24597168, 9.25986099], [79.24597168, 9.25958157], [79.2454071, 9.2595892], [79.2454071, 9.25931072], [79.24402618, 9.25931072], [79.24402618, 9.2595892], [79.23902893, 9.2595892], [79.23902893, 9.25931072], [79.23764038, 9.25931072], [79.23764038, 9.2590313], [79.23458099, 9.2590313], [79.23458099, 9.25931072], [79.23319244, 9.25931072], [79.23319244, 9.2595892], [79.23124695, 9.2595892], [79.23124695, 9.25931072], [79.23097229, 9.25931072], [79.23097229, 9.2595892], [79.22680664, 9.2595892], [79.22680664, 9.25931072], [79.22402954, 9.25931072], [79.22402954, 9.2590313], [79.22348022, 9.2590313], [79.22348022, 9.25875092], [79.22292328, 9.25875092], [79.22292328, 9.25846958], [79.2223587, 9.2584734], [79.2223587, 9.25819492], [79.22208405, 9.25819492], [79.22208405, 9.25791645], [79.2215271, 9.25792122], [79.2215271, 9.25764084], [79.22125244, 9.25764084], [79.22125244, 9.25736046], [79.21930695, 9.25736046], [79.21930695, 9.25708199], [79.21902466, 9.25708199], [79.21902466, 9.25680733], [79.21875, 9.25681973], [79.21875, 9.25625038], [79.21847534, 9.25625038], [79.21847534, 9.25597191], [79.21819305, 9.25597191], [79.21819305, 9.25569439], [79.21736145, 9.25569439], [79.21736145, 9.2551403], [79.21708679, 9.2551403], [79.21708679, 9.25319195], [79.2168045, 9.25319386], [79.2168045, 9.25263786], [79.2159729, 9.25263977], [79.2159729, 9.2529211], [79.21569824, 9.25291634], [79.21569061, 9.25319386], [79.21541595, 9.25319386], [79.21541595, 9.25347233], [79.2151413, 9.25347233], [79.2151413, 9.25374985], [79.21485901, 9.25374985], [79.21485901, 9.25403118], [79.21458435, 9.25402832], [79.21458435, 9.25458431], [79.21430206, 9.25458431], [79.21430206, 9.25597191], [79.21457672, 9.25597], [79.21457672, 9.2565279], [79.21485901, 9.2565279], [79.21485901, 9.25681973], [79.2151413, 9.25680733], [79.2151413, 9.25708199], [79.21541595, 9.25708199], [79.21541595, 9.25736046], [79.21569061, 9.25736046], [79.21569824, 9.25764084], [79.2159729, 9.25764084], [79.2159729, 9.25792122], [79.21624756, 9.25791645], [79.21624756, 9.2584734], [79.21679688, 9.25846958], [79.21679688, 9.25875092], [79.21708679, 9.25875092], [79.21708679, 9.25931072], [79.21734619, 9.25931072], [79.21734619, 9.25986099], [79.21763611, 9.25986099], [79.21763611, 9.26041889], [79.2179184, 9.26041889], [79.2179184, 9.26153088], [79.21819305, 9.26153088], [79.21819305, 9.26180935], [79.21847534, 9.26180458], [79.21847534, 9.26236057], [79.21875, 9.26236057], [79.21875, 9.26263905], [79.2195816, 9.26263046], [79.2195816, 9.26292133], [79.22097015, 9.26292133], [79.22097015, 9.26403141], [79.22070313, 9.26403141], [79.22070313, 9.26431179], [79.22097015, 9.26430511], [79.22097015, 9.26458263], [79.2206955, 9.26458263], [79.2206955, 9.26486111], [79.22097015, 9.26486111], [79.22097015, 9.26542187], [79.2206955, 9.2654171], [79.2206955, 9.26597309], [79.22097015, 9.26597118], [79.22097015, 9.26625061], [79.22125244, 9.2662487], [79.22125244, 9.26708317], [79.22097015, 9.26708126], [79.22097015, 9.26764202], [79.22041321, 9.26764202], [79.22041321, 9.26791954], [79.22013855, 9.26791668], [79.22013855, 9.26819324], [79.21986389, 9.26819324], [79.21986389, 9.26847076], [79.2195816, 9.26847076], [79.2195816, 9.26902962], [79.21902466, 9.26902676], [79.21902466, 9.26958275], [79.21875, 9.26958275], [79.21875, 9.26986122], [79.21901703, 9.26986122], [79.21901703, 9.2701416], [79.21930695, 9.2701416], [79.21930695, 9.27042198], [79.21902466, 9.27041531], [79.21902466, 9.27069569], [79.21763611, 9.27069569], [79.21763611, 9.2709713], [79.21679688, 9.2709713], [79.21679688, 9.27125168], [79.2159729, 9.27125168], [79.2159729, 9.27153015], [79.21569824, 9.27153015], [79.21569061, 9.27182102], [79.21541595, 9.27180576], [79.21541595, 9.27208424], [79.21485901, 9.27208424], [79.21485901, 9.27236176], [79.21430969, 9.27235889], [79.21430969, 9.27264023], [79.21375275, 9.27264023], [79.21375275, 9.27291965], [79.21347046, 9.27291775], [79.21347046, 9.27319336], [79.2131958, 9.27319336], [79.2131958, 9.27347183], [79.21180725, 9.27347183], [79.21180725, 9.27375031], [79.20986176, 9.27375031], [79.20986176, 9.27402973], [79.20929718, 9.27402973], [79.20929718, 9.27431011], [79.20847321, 9.2743063], [79.20847321, 9.27458382], [79.20791626, 9.27458382], [79.20791626, 9.27486229], [79.20652771, 9.27486229], [79.20652771, 9.2743063], [79.20680237, 9.27431011], [79.20680237, 9.27402973], [79.20707703, 9.27402973], [79.20707703, 9.27375031], [79.20735931, 9.27375031], [79.20735931, 9.27347183], [79.20708466, 9.27347183], [79.20708466, 9.27319336], [79.20680237, 9.27319336], [79.20680237, 9.27291775], [79.20625305, 9.27291965], [79.20625305, 9.27264023], [79.20569611, 9.27264023], [79.20569611, 9.27291965], [79.20541382, 9.27291775], [79.20541382, 9.27319336], [79.20513916, 9.27319336], [79.20513916, 9.27347183], [79.20485687, 9.27347183], [79.20485687, 9.27431011], [79.20458221, 9.2743063], [79.20458221, 9.27458382], [79.20430756, 9.27458382], [79.20430756, 9.27736187], [79.20458221, 9.27736187], [79.20458221, 9.27791977], [79.2048645, 9.27791595], [79.2048645, 9.27871132], [79.2048645, 9.27958202], [79.20513916, 9.27958202], [79.20513916, 9.28042126], [79.20680237, 9.28041553], [79.20680237, 9.28097153], [79.20707703, 9.28096962], [79.20707703, 9.28125], [79.2076416, 9.28125], [79.2076416, 9.28153133], [79.20818329, 9.28153133], [79.20818329, 9.28180885], [79.20847321, 9.28180599], [79.20847321, 9.28208447], [79.20874786, 9.28208447], [79.20874786, 9.28236008], [79.20929718, 9.28236008], [79.20929718, 9.28264141], [79.2095871, 9.28264141], [79.2095871, 9.28292084], [79.2104187, 9.28291607], [79.2104187, 9.28319359], [79.2123642, 9.28319359], [79.2123642, 9.28347206], [79.21290588, 9.28347015], [79.21290588, 9.28376198], [79.2131958, 9.28376198], [79.2131958, 9.28403091], [79.21347046, 9.28403091], [79.21347046, 9.28431129], [79.21375275, 9.28430653], [79.21375275, 9.28458214], [79.21430206, 9.28458214], [79.21430206, 9.28486347], [79.21457672, 9.28485966], [79.21457672, 9.28514099], [79.2151413, 9.28514099], [79.2151413, 9.28542137], [79.21541595, 9.2854166], [79.21541595, 9.28569508], [79.2159729, 9.28569508], [79.2159729, 9.2859726], [79.21624756, 9.28596973], [79.21624756, 9.28625107], [79.21652985, 9.28625107], [79.21652985, 9.2868042], [79.2168045, 9.2868042], [79.2168045, 9.28736115], [79.21708679, 9.28736115], [79.21708679, 9.28792095], [79.21736145, 9.28791714], [79.21736145, 9.28819466], [79.21763611, 9.28818989], [79.21763611, 9.28875065], [79.2179184, 9.28875065], [79.2179184, 9.28931236], [79.21819305, 9.28930473], [79.21819305, 9.28986073], [79.21848297, 9.28986073], [79.21848297, 9.29042053], [79.21875, 9.29041672], [79.21875, 9.29069519], [79.21902466, 9.29069519], [79.21902466, 9.2909708], [79.2195816, 9.29097271], [79.2195816, 9.29125118], [79.21985626, 9.29125118], [79.21985626, 9.29153061], [79.22013855, 9.29153061], [79.22013855, 9.29181194], [79.22041321, 9.29180527], [79.22041321, 9.29208279], [79.2223587, 9.29208279], [79.2223587, 9.29180527], [79.22569275, 9.29181194], [79.22569275, 9.29153061], [79.22624969, 9.29153061], [79.22624969, 9.29181194], [79.22846985, 9.29180527], [79.22846985, 9.29208279], [79.2298584, 9.29208279], [79.2298584, 9.29236126], [79.23042297, 9.29236126], [79.23042297, 9.29264069], [79.23152924, 9.29264069], [79.23152924, 9.29236126], [79.23430634, 9.29236126], [79.23430634, 9.29208279], [79.23652649, 9.29208279], [79.23652649, 9.29180527], [79.23764038, 9.29180527], [79.23764038, 9.29208279], [79.23930359, 9.29208279], [79.23930359, 9.29180527], [79.23986053, 9.29180527], [79.23986053, 9.29208279], [79.24180603, 9.29208279], [79.24180603, 9.29236126], [79.24236298, 9.29236126], [79.24236298, 9.29264069], [79.24263763, 9.29264069], [79.24263763, 9.29236126], [79.24346924, 9.29236126], [79.24346924, 9.29208279], [79.24624634, 9.29208279], [79.24624634, 9.29180527], [79.24931335, 9.29181194], [79.24931335, 9.29153061], [79.25345612, 9.29153061], [79.25345612, 9.29181194], [79.25485992, 9.29181194], [79.25485992, 9.29153061], [79.25541687, 9.29153061], [79.25541687, 9.29181194], [79.25569153, 9.29180527], [79.25569153, 9.29208279], [79.25680542, 9.29208279], [79.25680542, 9.29236126], [79.25875092, 9.29236126], [79.25875092, 9.29208279], [79.26168823, 9.29208279], [79.26235962, 9.29208279], [79.26235962, 9.29236126], [79.26403046, 9.29236126], [79.26403046, 9.29264069], [79.26513672, 9.29264069], [79.26513672, 9.29292202], [79.26569366, 9.29291725], [79.26569366, 9.29319477], [79.26763916, 9.29319477], [79.26763916, 9.29347324], [79.26790619, 9.29347134], [79.26790619, 9.29375076], [79.26819611, 9.29375076], [79.26819611, 9.29402924], [79.26875305, 9.29402924], [79.26875305, 9.29430962], [79.26930237, 9.29430485], [79.26930237, 9.29458332], [79.26985931, 9.29458141], [79.26985931, 9.29486084], [79.2701416, 9.29486084], [79.2701416, 9.29513931], [79.27041626, 9.29513931], [79.27041626, 9.29541969], [79.27069092, 9.29541969], [79.27069092, 9.29570007], [79.27097321, 9.2956953], [79.27097321, 9.29624939], [79.27124786, 9.29624939], [79.27124786, 9.29653168], [79.27152252, 9.29653168], [79.27152252, 9.29763985], [79.27180481, 9.29763985], [79.27180481, 9.29847145], [79.27236176, 9.29847145], [79.27236176, 9.2990303], [79.27263641, 9.2990303], [79.27263641, 9.29930973], [79.27236176, 9.29930973], [79.27236176, 9.3004179], [79.27263641, 9.3004179], [79.27263641, 9.30097198], [79.2729187, 9.30097198], [79.2729187, 9.30180645], [79.27263641, 9.30180073], [79.27263641, 9.30263996], [79.2729187, 9.30263996], [79.2729187, 9.30292034], [79.27319336, 9.30291557], [79.27319336, 9.30319405], [79.27347565, 9.30319405], [79.27347565, 9.30347157], [79.27375031, 9.30346966], [79.27375031, 9.30375004], [79.27402496, 9.30375004], [79.27402496, 9.30387974], [79.27401733, 9.30403042], [79.27430725, 9.30402756], [79.27430725, 9.30458355], [79.27458954, 9.30458164], [79.27458954, 9.30513954], [79.2748642, 9.30513763], [79.2748642, 9.30569363], [79.27513885, 9.30568886], [79.27513885, 9.30624962], [79.27540588, 9.30624962], [79.27540588, 9.30653], [79.2756958, 9.30653], [79.2756958, 9.30681133], [79.27597046, 9.30680561], [79.27597046, 9.30708408], [79.27625275, 9.30708408], [79.27625275, 9.3073597], [79.2765274, 9.3073597], [79.2765274, 9.3079319], [79.27680206, 9.30791569], [79.27680206, 9.30847168], [79.27707672, 9.30846977], [79.27707672, 9.30903053], [79.27735901, 9.30903053], [79.27735901, 9.30931091], [79.2776413, 9.30930424], [79.2776413, 9.30986023], [79.27791595, 9.30986023], [79.27791595, 9.31014061], [79.27819061, 9.31014061], [79.27819824, 9.31042099], [79.2784729, 9.31041622], [79.2784729, 9.31069374], [79.27874756, 9.31069374], [79.27874756, 9.31097221], [79.27902985, 9.31097031], [79.27902985, 9.31125069], [79.2793045, 9.31125069], [79.2793045, 9.31208229], [79.27986145, 9.31208229], [79.27986145, 9.31180668], [79.28013611, 9.31180668], [79.28013611, 9.31235981], [79.2804184, 9.3123579], [79.2804184, 9.31264114], [79.28069305, 9.31264114], [79.28069305, 9.31292057], [79.28236389, 9.31291676], [79.28236389, 9.31375122], [79.28291321, 9.31374168], [79.28291321, 9.31403065], [79.28346252, 9.31403065], [79.28346252, 9.31431103], [79.2840271, 9.31430531], [79.2840271, 9.31458473], [79.28430176, 9.31458473], [79.28430176, 9.3148613], [79.2848587, 9.3148613], [79.2848587, 9.3154192], [79.28514099, 9.31541729], [79.28514099, 9.31569481], [79.28541565, 9.31569481], [79.28541565, 9.31597328], [79.28569794, 9.31597328], [79.28569794, 9.3162508], [79.2859726, 9.3162508], [79.2859726, 9.31681156], [79.28624725, 9.31680489], [79.28624725, 9.31708336], [79.28652954, 9.31708336], [79.28652954, 9.31736088], [79.2876358, 9.31736088], [79.2876358, 9.31764126], [79.28848267, 9.31764126], [79.28848267, 9.31792164], [79.28902435, 9.31791687], [79.28902435, 9.31847095], [79.28930664, 9.31847095], [79.28930664, 9.31987], [79.29013824, 9.31987], [79.29013824, 9.32014084], [79.29070282, 9.32014084], [79.29070282, 9.32041931], [79.29152679, 9.3204174], [79.29152679, 9.32069302], [79.29319763, 9.32069492], [79.29319763, 9.3209734], [79.29347229, 9.32097054], [79.29347229, 9.32125092], [79.29402924, 9.32125092], [79.29402924, 9.32152939], [79.29429626, 9.32152939], [79.29429626, 9.32180977], [79.29624939, 9.321805], [79.29624939, 9.32208347], [79.29680634, 9.32208347], [79.29680634, 9.32236099], [79.29819489, 9.32236099], [79.29818726, 9.32208061], [79.29846954, 9.32208347], [79.29846954, 9.32236099], [79.29930878, 9.32236099], [79.29930878, 9.32263947], [79.30042267, 9.32263947], [79.30042267, 9.32293129], [79.30069733, 9.32291698], [79.30069733, 9.32347107], [79.30097198, 9.32347107], [79.30097198, 9.3237524], [79.30124664, 9.3237524], [79.30124664, 9.3243103], [79.30152893, 9.32430458], [79.30152893, 9.32458305], [79.30236053, 9.32458305], [79.30236053, 9.32486153], [79.30264282, 9.32486153], [79.30264282, 9.32514191], [79.30291748, 9.32514191], [79.30291748, 9.32542038], [79.30347443, 9.32541847], [79.30347443, 9.32569313], [79.30403137, 9.32569313], [79.30403137, 9.32597065], [79.30596924, 9.32597065], [79.30596924, 9.32625198], [79.30652618, 9.32625198], [79.30652618, 9.32653046], [79.30680847, 9.32653046], [79.30680847, 9.32681179], [79.30735779, 9.32680607], [79.30735779, 9.32708359], [79.30791473, 9.32708359], [79.30791473, 9.32736206], [79.30847168, 9.3273592], [79.30847168, 9.32763958], [79.30902863, 9.32763958], [79.30902863, 9.32791996], [79.30958557, 9.32791805], [79.30958557, 9.32819366], [79.31014252, 9.32819366], [79.31014252, 9.32847214], [79.31236267, 9.32847214], [79.31236267, 9.32819366], [79.31291962, 9.32819366], [79.31291962, 9.32791805], [79.31458282, 9.32791996], [79.31458282, 9.32763958], [79.31485748, 9.32763958], [79.31485748, 9.3273592], [79.31569672, 9.32736206], [79.31569672, 9.32708359], [79.31652832, 9.32708359], [79.31652832, 9.32680607], [79.31680298, 9.32681179], [79.31680298, 9.32653046], [79.31764221, 9.32653046], [79.31764221, 9.32625198], [79.31819153, 9.32625198], [79.31819153, 9.32597065], [79.31874847, 9.32597065], [79.31874847, 9.32569313], [79.31930542, 9.32569313], [79.31930542, 9.32541847], [79.32013702, 9.32542038], [79.32013702, 9.32514191], [79.32068634, 9.32514191], [79.32068634, 9.32486153], [79.32125092, 9.32486153], [79.32125092, 9.32430458], [79.3215332, 9.3243103], [79.3215332, 9.32403183], [79.32208252, 9.32403183], [79.32208252, 9.3237524], [79.32263947, 9.32374859], [79.32263947, 9.32347107], [79.32347107, 9.32347107], [79.32347107, 9.32319546], [79.32402802, 9.32319546], [79.32402802, 9.32291698], [79.32430267, 9.32293129], [79.32430267, 9.32263947], [79.32457733, 9.32263947], [79.32457733, 9.32236099], [79.32514191, 9.32236099], [79.32514191, 9.32208347], [79.32541656, 9.32208347], [79.32541656, 9.321805], [79.32624817, 9.32180977], [79.32624817, 9.32152939], [79.32681274, 9.32152939], [79.32681274, 9.32125092], [79.32707977, 9.32125092], [79.32707977, 9.32097054], [79.32736206, 9.3209734], [79.32736206, 9.32069492], [79.32791901, 9.32069302], [79.32791901, 9.3204174], [79.32847595, 9.32041931], [79.32847595, 9.32014084], [79.3290329, 9.32014084], [79.3290329, 9.31987], [79.32930756, 9.31987], [79.32930756, 9.31958103], [79.3298645, 9.31958294], [79.3298645, 9.31930542], [79.33040619, 9.31931019], [79.33040619, 9.31903076], [79.33069611, 9.31903076], [79.33069611, 9.31875134], [79.33097076, 9.31875134], [79.33097076, 9.31847095], [79.33125305, 9.31847095], [79.33125305, 9.31763935], [79.33152771, 9.31764126], [79.33152771, 9.31708145], [79.33208466, 9.31708336], [79.33208466, 9.31597328], [79.33235931, 9.31597328], [79.33235931, 9.31569481], [79.33319092, 9.31569481], [79.33319092, 9.31513882], [79.33347321, 9.31514072], [79.33347321, 9.3148613], [79.33374786, 9.3148613], [79.33374786, 9.31430531], [79.33403015, 9.31431103], [79.33403015, 9.31403065], [79.33429718, 9.31403065], [79.33429718, 9.31346989], [79.3345871, 9.31347275], [79.3345871, 9.31263828], [79.33486938, 9.31264114], [79.33486938, 9.31153107], [79.33513641, 9.31153107], [79.33513641, 9.30986023], [79.33486176, 9.30986023], [79.33486176, 9.30847168], [79.3345871, 9.30847168], [79.3345871, 9.30791569], [79.33403015, 9.3079319], [79.33403015, 9.3073597], [79.33374786, 9.3073597], [79.33374786, 9.30680561], [79.33319092, 9.30681133], [79.33319092, 9.30597019], [79.33291626, 9.3059721], [79.33291626, 9.30402756], [79.3326416, 9.30403042], [79.3326416, 9.30346966], [79.33235931, 9.30347157], [79.33235931, 9.30319405], [79.33208466, 9.30319405], [79.33208466, 9.30291557], [79.33152771, 9.30292034], [79.33152771, 9.30263996], [79.33069611, 9.30263996], [79.33069611, 9.3020792], [79.33041382, 9.30208397], [79.33041382, 9.30152798], [79.32985687, 9.30153179], [79.32985687, 9.30125046], [79.32930756, 9.30125046], [79.32930756, 9.30097198], [79.32902527, 9.30097198], [79.32902527, 9.30069447], [79.32875061, 9.30069447], [79.32875061, 9.3004179], [79.32847595, 9.3004179], [79.32847595, 9.30014038], [79.32818604, 9.30014038], [79.32818604, 9.29958057], [79.32791901, 9.29958439], [79.32791901, 9.29930592], [79.32763672, 9.29930973], [79.32763672, 9.2990303], [79.32736206, 9.2990303], [79.32736206, 9.29874039], [79.32707977, 9.29874897], [79.32707977, 9.29791546], [79.32736206, 9.29792023], [79.32736206, 9.29486084], [79.32791901, 9.29486084], [79.32791901, 9.29430962], [79.32707977, 9.29430962], [79.32707977, 9.29402924], [79.32653046, 9.29402924], [79.32653046, 9.29264069], [79.32514191, 9.29264069], [79.32514191, 9.29236126], [79.32485962, 9.29236126], [79.32485962, 9.29208279], [79.32458496, 9.29208279], [79.32458496, 9.29180527], [79.32402802, 9.29181194], [79.32402802, 9.29153061], [79.32375336, 9.29153061], [79.32375336, 9.29125118], [79.32347107, 9.29125118], [79.32347107, 9.29069519], [79.32319641, 9.29069519], [79.32319641, 9.29041672], [79.32235718, 9.29042053], [79.32235718, 9.28986073], [79.32180786, 9.28986073], [79.32180786, 9.28958321], [79.32152557, 9.28958321], [79.32152557, 9.28930473], [79.32125092, 9.28931236], [79.32125092, 9.28903103], [79.32096863, 9.28903103], [79.32096863, 9.28764057], [79.32013702, 9.28764057], [79.32013702, 9.28736115], [79.31958008, 9.28736115], [79.31958008, 9.2868042], [79.31930542, 9.2868042], [79.31930542, 9.28625107], [79.31819153, 9.28625107], [79.31819153, 9.28596973], [79.31764221, 9.2859726], [79.31764221, 9.28569508], [79.31708527, 9.28569508], [79.31708527, 9.2854166], [79.31652832, 9.28542137], [79.31652832, 9.28514099], [79.31624603, 9.28514099], [79.31624603, 9.28485966], [79.31597137, 9.28485966], [79.31597137, 9.28347206], [79.31569672, 9.28347206], [79.31569672, 9.2826376], [79.31513977, 9.28264141], [79.31513977, 9.28236008], [79.31458282, 9.28236008], [79.31458282, 9.28180599], [79.31541443, 9.28180599], [79.31541443, 9.28208447], [79.31569672, 9.28208447], [79.31569672, 9.28236008], [79.31708527, 9.28236008], [79.31708527, 9.28208447], [79.31735992, 9.28208447], [79.31735992, 9.28152847], [79.31764221, 9.28153133], [79.31764221, 9.28125], [79.31791687, 9.28125], [79.31791687, 9.28070068], [79.31764221, 9.28070068], [79.31764221, 9.27985954], [79.31735992, 9.2798624], [79.31735992, 9.27875042], [79.31764221, 9.27875042], [79.31764221, 9.27819443], [79.31791687, 9.27819443], [79.31791687, 9.27763844], [79.31764221, 9.27763844], [79.31764221, 9.27569389], [79.31791687, 9.27569389], [79.31791687, 9.27541637], [79.31846619, 9.27542019], [79.31846619, 9.27486038], [79.31819153, 9.27486229], [79.31819153, 9.27375031], [79.31847382, 9.27375031], [79.31846619, 9.27319145], [79.31874847, 9.27319336], [79.31874847, 9.27264023], [79.31903076, 9.27264023], [79.31903076, 9.27235889], [79.31930542, 9.27236176], [79.31930542, 9.27180576], [79.31957245, 9.27182102], [79.31957245, 9.27153015], [79.31986237, 9.27153015], [79.31986237, 9.2709713], [79.32013702, 9.2709713], [79.32013702, 9.27041531], [79.32041931, 9.27042198], [79.32041931, 9.26986122], [79.32069397, 9.26986122], [79.32069397, 9.26930523], [79.32096863, 9.26931], [79.32096863, 9.26902962], [79.32125092, 9.26902962], [79.32125092, 9.26876068], [79.3215332, 9.26876068], [79.3215332, 9.26819134], [79.32208252, 9.26819324], [79.32208252, 9.26791668], [79.32235718, 9.26791954], [79.32235718, 9.26736069], [79.32263947, 9.26736069], [79.32263947, 9.2668047], [79.32290649, 9.26681042], [79.32290649, 9.26653194], [79.32319641, 9.26653194], [79.32319641, 9.26597118], [79.32347107, 9.26597309], [79.32347107, 9.26569462], [79.32375336, 9.26569462], [79.32375336, 9.26513863], [79.32402802, 9.26514053], [79.32402802, 9.26458073], [79.32430267, 9.26458263], [79.32430267, 9.26430511], [79.32457733, 9.26431179], [79.32457733, 9.26375103], [79.32485962, 9.26375103], [79.32485962, 9.26347065], [79.32514191, 9.26347256], [79.32514191, 9.26319504], [79.32541656, 9.26319504], [79.32541656, 9.26263905], [79.32569122, 9.26263905], [79.32569122, 9.26236057], [79.32597351, 9.26236057], [79.32597351, 9.26180458], [79.32624817, 9.26180935], [79.32624817, 9.26153088], [79.32653046, 9.26153088], [79.32653046, 9.26125145], [79.32680511, 9.26124859], [79.32681274, 9.26097012], [79.32707977, 9.26097298], [79.32707977, 9.26069546], [79.32736206, 9.26069546], [79.32736206, 9.26041698], [79.32763672, 9.26041889], [79.32763672, 9.25986099], [79.32791901, 9.25986099], [79.32791901, 9.25958157], [79.32818604, 9.2595892], [79.32818604, 9.25931072], [79.32847595, 9.25931072], [79.32847595, 9.2590313], [79.32874298, 9.2590313], [79.32874298, 9.25875092], [79.3290329, 9.25875092], [79.3290329, 9.25820065], [79.32930756, 9.25819016], [79.32930756, 9.25791645], [79.32958221, 9.25792122], [79.32958221, 9.25764084], [79.32985687, 9.25764084], [79.32985687, 9.25736046], [79.33041382, 9.25736046], [79.33041382, 9.25708199], [79.33069611, 9.25708199], [79.33069611, 9.2565279], [79.33097076, 9.2565279], [79.33097076, 9.25625038], [79.33125305, 9.25625038], [79.33125305, 9.25597191], [79.33152771, 9.25597191], [79.33152771, 9.25569439], [79.33180237, 9.25569439], [79.33180237, 9.25541592], [79.33207703, 9.25542068], [79.33207703, 9.2551403], [79.33235931, 9.2551403], [79.33235931, 9.25485992], [79.3326416, 9.25485992], [79.3326416, 9.25458431], [79.33291626, 9.25458431], [79.33291626, 9.25430584], [79.33319092, 9.25431061], [79.33319092, 9.25403118], [79.33347321, 9.25403118], [79.33347321, 9.25374985], [79.33374786, 9.25374985], [79.33374786, 9.25347233], [79.33403015, 9.25347233], [79.33403015, 9.25319386], [79.33430481, 9.25319386], [79.33430481, 9.25291634], [79.3345871, 9.2529211], [79.3345871, 9.25263977], [79.33486938, 9.25263977], [79.33486938, 9.25236034], [79.3354187, 9.25236225], [79.3354187, 9.25208378], [79.33569336, 9.25208378], [79.33569336, 9.25180626], [79.33598328, 9.25181103], [79.33598328, 9.25152969], [79.33625031, 9.25152969], [79.33625031, 9.25125027], [79.33652496, 9.25125027], [79.33651733, 9.25097179], [79.33680725, 9.25097179], [79.33680725, 9.25069427], [79.33708191, 9.25069427], [79.33708191, 9.2504158], [79.33735657, 9.25041962], [79.33735657, 9.25014019], [79.33763885, 9.25014019], [79.33763885, 9.24985981], [79.3381958, 9.24985981], [79.3381958, 9.2495842], [79.33847046, 9.2495842], [79.33847046, 9.24930573], [79.33875275, 9.24930954], [79.33875275, 9.24903011], [79.3390274, 9.24903011], [79.3390274, 9.24874973], [79.33930206, 9.24874973], [79.33930206, 9.24846935], [79.33958435, 9.24847221], [79.33958435, 9.24819374], [79.33985901, 9.24819374], [79.33985901, 9.24791622], [79.34041595, 9.24792004], [79.34041595, 9.2476511], [79.34069824, 9.2476511], [79.34069824, 9.24735928], [79.3409729, 9.24736214], [79.3409729, 9.24708366], [79.34124756, 9.24708366], [79.34124756, 9.24680614], [79.34152985, 9.24680996], [79.34152985, 9.24652958], [79.34179688, 9.24652958], [79.34179688, 9.24625015], [79.34236145, 9.24625015], [79.34236145, 9.24597168], [79.34263611, 9.24597168], [79.34263611, 9.24569321], [79.34319305, 9.24569321], [79.34319305, 9.24541759], [79.34348297, 9.24542046], [79.34348297, 9.24514198], [79.34374237, 9.24514198], [79.34374237, 9.2448616], [79.34430695, 9.2448616], [79.34430695, 9.24458408], [79.3445816, 9.24458981], [79.3445816, 9.24431038], [79.34485626, 9.24431038], [79.34485626, 9.24403191], [79.34541321, 9.24403191], [79.34541321, 9.24375153], [79.34570313, 9.24375153], [79.34570313, 9.24347115], [79.34597015, 9.24347115], [79.34597015, 9.24319553], [79.3465271, 9.24319553], [79.3465271, 9.24291706], [79.34680939, 9.24291992], [79.34680939, 9.24263859], [79.34707642, 9.24263859], [79.34707642, 9.24236107], [79.34764099, 9.24236107], [79.34764099, 9.2420826], [79.34791565, 9.2420826], [79.34791565, 9.24180508], [79.34819794, 9.24180984], [79.34819794, 9.24151993], [79.34874725, 9.2415266], [79.34874725, 9.24124908], [79.34902954, 9.24125099], [79.34902954, 9.24097061], [79.3493042, 9.24097347], [79.3493042, 9.24069309], [79.34958649, 9.24069309], [79.34958649, 9.24041653], [79.34986877, 9.24042034], [79.34986877, 9.24014091], [79.35041809, 9.24014091], [79.35041809, 9.23986053], [79.35069275, 9.23986053], [79.35069275, 9.23958302], [79.35097504, 9.23958302], [79.35097504, 9.23930454], [79.35124969, 9.23931026], [79.35124969, 9.23903179], [79.35151672, 9.23903179], [79.35151672, 9.23875141], [79.35180664, 9.23875141], [79.35180664, 9.23847103], [79.35236359, 9.23847103], [79.35236359, 9.23819542], [79.35263824, 9.23819542], [79.35263824, 9.23791695], [79.3529129, 9.23792171], [79.3529129, 9.23764133], [79.35320282, 9.23764133], [79.35320282, 9.23736095], [79.35346985, 9.23736095], [79.35346985, 9.23708344], [79.35402679, 9.23708344], [79.35402679, 9.23680496], [79.35430908, 9.23681164], [79.35430908, 9.23653126], [79.35457611, 9.23653126], [79.35457611, 9.23625088], [79.3548584, 9.23625088], [79.3548584, 9.23597145], [79.35514069, 9.23597336], [79.35514069, 9.23569489], [79.35569763, 9.23569489], [79.35569763, 9.23541737], [79.35597229, 9.23541927], [79.35597229, 9.23513889], [79.35624695, 9.23513889], [79.35624695, 9.23486137], [79.35652924, 9.23486137], [79.35652924, 9.2345829], [79.35680389, 9.2345829], [79.35680389, 9.23430538], [79.35736084, 9.2343092], [79.35736084, 9.23403072], [79.35764313, 9.23403072], [79.35764313, 9.2337513], [79.35791779, 9.2337513], [79.35791779, 9.23347282], [79.35819244, 9.23347282], [79.35819244, 9.2331953], [79.35847473, 9.2331953], [79.35847473, 9.23291683], [79.35901642, 9.23292065], [79.35901642, 9.2326498], [79.35930634, 9.2326498], [79.35930634, 9.23236275], [79.35958099, 9.23236275], [79.35958099, 9.23208046], [79.35986328, 9.23208237], [79.35986328, 9.23180676], [79.36013794, 9.23181057], [79.36013794, 9.23153114], [79.36068726, 9.23153114], [79.36068726, 9.2312479], [79.36096954, 9.23125076], [79.36096954, 9.23097324], [79.36125183, 9.23097324], [79.36125183, 9.23069382], [79.36152649, 9.23069382], [79.36152649, 9.2304163], [79.36207581, 9.23042107], [79.36207581, 9.23014069], [79.36235809, 9.23014069], [79.36235809, 9.22986031], [79.36264038, 9.22986031], [79.36264038, 9.22930431], [79.36292267, 9.22931099], [79.36292267, 9.22903061], [79.36319733, 9.22903061], [79.36319733, 9.22875023], [79.36347198, 9.22875023], [79.36347198, 9.22847176], [79.36374664, 9.22847176], [79.36374664, 9.22819424], [79.36402893, 9.22819424], [79.36402893, 9.22791576], [79.36429596, 9.22792053], [79.36429596, 9.22764015], [79.36458588, 9.22764015], [79.36458588, 9.22735977], [79.36486053, 9.22735977], [79.36486053, 9.22708416], [79.36513519, 9.22708416], [79.36513519, 9.22680569], [79.36541748, 9.22681141], [79.36541748, 9.22652054], [79.36597443, 9.22652817], [79.36597443, 9.22624969], [79.36624908, 9.22624969], [79.36624908, 9.22597027], [79.36680603, 9.22597218], [79.36680603, 9.2256937], [79.36708069, 9.2256937], [79.36708069, 9.22541809], [79.36763763, 9.22542095], [79.36763763, 9.22513962], [79.36791229, 9.22513962], [79.36791229, 9.22486019], [79.36819458, 9.2248621], [79.36819458, 9.22458363], [79.36846924, 9.22458363], [79.36846924, 9.22430611], [79.36875153, 9.22431087], [79.36875153, 9.22402954], [79.36902618, 9.22402954], [79.36902618, 9.22375202], [79.36930847, 9.22375202], [79.36930847, 9.22348118], [79.36958313, 9.22348118], [79.36958313, 9.22318935], [79.36985779, 9.22319412], [79.36985779, 9.22291565], [79.37014008, 9.22292042], [79.37014008, 9.22264004], [79.3704071, 9.22264004], [79.3704071, 9.22235966], [79.37069702, 9.22236156], [79.37069702, 9.22208405], [79.37097168, 9.22208405], [79.37097168, 9.22180557], [79.37124634, 9.22181034], [79.37124634, 9.22152996], [79.37152863, 9.22152996], [79.37152863, 9.22124958], [79.3720932, 9.22124958], [79.3720932, 9.2209692], [79.37236023, 9.22097206], [79.37236023, 9.22069359], [79.37264252, 9.22069359], [79.37264252, 9.22041798], [79.37291718, 9.22042179], [79.37291718, 9.22014046], [79.37319183, 9.22014046], [79.37319183, 9.21986198], [79.37374878, 9.21986198], [79.37374878, 9.21958447]]], [[[79.21485901, 9.25069427], [79.21485901, 9.25097179], [79.21902466, 9.25097179], [79.21902466, 9.25069427], [79.21930695, 9.25069427], [79.21930695, 9.2504158], [79.2195816, 9.25041962], [79.2195816, 9.25014019], [79.21985626, 9.25014019], [79.21985626, 9.24985981], [79.22013855, 9.24985981], [79.22013855, 9.24930573], [79.22041321, 9.24930954], [79.22041321, 9.24903011], [79.22097015, 9.24903011], [79.22097015, 9.24874973], [79.2215271, 9.24874973], [79.2215271, 9.24846935], [79.22208405, 9.24847221], [79.22208405, 9.24819374], [79.2223587, 9.24819374], [79.2223587, 9.24763966], [79.22207642, 9.2476511], [79.22207642, 9.2470789], [79.2215271, 9.24708366], [79.2215271, 9.24680614], [79.22013855, 9.24680614], [79.22013855, 9.24708366], [79.21930695, 9.24708366], [79.21930695, 9.24680614], [79.2179184, 9.24680614], [79.2179184, 9.24708366], [79.2168045, 9.24708366], [79.2168045, 9.24680614], [79.21624756, 9.24680996], [79.21624756, 9.24652958], [79.21604156, 9.24652958], [79.21456909, 9.24652767], [79.21430969, 9.24652958], [79.21430969, 9.24640179], [79.21430206, 9.24625015], [79.21401978, 9.24625015], [79.21290588, 9.24625015], [79.21290588, 9.24597168], [79.21208191, 9.24597168], [79.21208191, 9.24569321], [79.21152496, 9.24569321], [79.21152496, 9.24541759], [79.21069336, 9.24542046], [79.21069336, 9.24514198], [79.2104187, 9.24514198], [79.2104187, 9.2448616], [79.20986176, 9.2448616], [79.20986176, 9.24458408], [79.2095871, 9.24458981], [79.2095871, 9.24431038], [79.20903015, 9.24431038], [79.20903015, 9.24403191], [79.20791626, 9.24403191], [79.20791626, 9.24375153], [79.20735931, 9.24375153], [79.20735931, 9.24347115], [79.20680237, 9.24347115], [79.20680237, 9.24319553], [79.20652771, 9.24319553], [79.20652771, 9.24291706], [79.20625305, 9.24291992], [79.20623779, 9.24270821], [79.20597076, 9.24263859], [79.20597076, 9.24236107], [79.20485687, 9.24236107], [79.20485687, 9.24208069], [79.20458221, 9.2420826], [79.20458221, 9.24180508], [79.20347595, 9.24180984], [79.20347595, 9.24151993], [79.20319366, 9.2415266], [79.20319366, 9.24124908], [79.20096588, 9.24125099], [79.20096588, 9.24180984], [79.20124817, 9.24180508], [79.20124817, 9.24319553], [79.20153046, 9.24319553], [79.20153046, 9.24373055], [79.20181274, 9.24375153], [79.20181274, 9.24431038], [79.20207977, 9.24431038], [79.20207977, 9.24458981], [79.20291901, 9.24458981], [79.20291901, 9.24542046], [79.20319366, 9.24541759], [79.20319366, 9.24597168], [79.20347595, 9.24597168], [79.20347595, 9.24625015], [79.20625305, 9.24625015], [79.20625305, 9.24736214], [79.20791626, 9.24736214], [79.20791626, 9.24819374], [79.2076416, 9.24819088], [79.2076416, 9.24930954], [79.20847321, 9.24930573], [79.20847321, 9.2495842], [79.21097565, 9.2495842], [79.21097565, 9.24985981], [79.2131958, 9.24985981], [79.2131958, 9.25014019], [79.21430969, 9.25014019], [79.21430969, 9.25041962], [79.21458435, 9.2504158], [79.21458435, 9.25069427], [79.21485901, 9.25069427]]], [[[79.5293045, 9.38930416], [79.52894592, 9.38960266], [79.52864838, 9.38985252], [79.5293045, 9.38986015], [79.5293045, 9.38930416]]], [[[79.52864838, 9.38985252], [79.52835846, 9.39013767], [79.52874756, 9.39014053], [79.52864838, 9.38985252]]], [[[79.8390274, 11.2365303], [79.8390274, 11.23625183], [79.83985901, 11.23625183], [79.83985901, 11.23597145], [79.8401413, 11.23597145], [79.8401413, 11.23569584], [79.84041595, 11.23569584], [79.84041595, 11.23513985], [79.84152985, 11.23513985], [79.84152985, 11.23486233], [79.8418045, 11.23486233], [79.8418045, 11.23430538], [79.84208679, 11.23431015], [79.84208679, 11.23402119], [79.8418045, 11.23402691], [79.8418045, 11.23374939], [79.84152985, 11.23374939], [79.84152985, 11.23347092], [79.84069824, 11.23347092], [79.84069824, 11.2331953], [79.8390274, 11.2331953], [79.8390274, 11.23347092], [79.83791351, 11.23347092], [79.83791351, 11.2331953], [79.83734894, 11.23319054], [79.83734894, 11.23513985], [79.83708191, 11.23513985], [79.83708191, 11.23542023], [79.8373642, 11.23541546], [79.8373642, 11.23569584], [79.83763885, 11.23569584], [79.83763885, 11.23597145], [79.83790588, 11.23597145], [79.83790588, 11.23625183], [79.83875275, 11.23625183], [79.83875275, 11.2365303], [79.8390274, 11.2365303]]], [[[79.82707977, 11.23736191], [79.82707977, 11.23708057], [79.82819366, 11.23708439], [79.82819366, 11.23680592], [79.82846832, 11.23680973], [79.82846832, 11.23625183], [79.82817841, 11.23625183], [79.82817841, 11.23597145], [79.82791901, 11.23597145], [79.82791901, 11.23569584], [79.82736206, 11.23569584], [79.82736206, 11.23597145], [79.82680511, 11.23597145], [79.82680511, 11.23569584], [79.82624817, 11.23569584], [79.82624817, 11.23541546], [79.82540894, 11.23542023], [79.82540894, 11.23513985], [79.82514191, 11.23513985], [79.82514191, 11.23486233], [79.82430267, 11.23486233], [79.82430267, 11.2345829], [79.82375336, 11.2345829], [79.82375336, 11.23569584], [79.82402802, 11.23569107], [79.82402802, 11.23625183], [79.82430267, 11.23625183], [79.82430267, 11.2365303], [79.82457733, 11.2365303], [79.82457733, 11.23680973], [79.82624817, 11.23680973], [79.82624817, 11.23736191], [79.82707977, 11.23736191]]], [[[79.98902893, 12.25097084], [79.98902893, 12.25125122], [79.99124908, 12.25125122], [79.99124908, 12.25097084], [79.99153137, 12.25097084], [79.99153137, 12.25069141], [79.99180603, 12.25069523], [79.99180603, 12.25041676], [79.99153137, 12.25042152], [79.99153137, 12.24958134], [79.99124908, 12.24958324], [79.99124908, 12.24930477], [79.9909668, 12.2493124], [79.9909668, 12.24903107], [79.99069214, 12.24903107], [79.99069214, 12.24875069], [79.99014282, 12.24875069], [79.99014282, 12.24847126], [79.98986053, 12.24847317], [79.98986053, 12.24819469], [79.98929596, 12.24819946], [79.98929596, 12.24792099], [79.98902893, 12.24792099], [79.98902893, 12.24764061], [79.98874664, 12.24764061], [79.98874664, 12.24736118], [79.98847198, 12.24736118], [79.98847198, 12.24708271], [79.98791504, 12.24708271], [79.98791504, 12.24652863], [79.98735809, 12.24653053], [79.98735809, 12.24625111], [79.98707581, 12.24625111], [79.98707581, 12.24596977], [79.98680878, 12.24597263], [79.98680878, 12.24569511], [79.98652649, 12.24569511], [79.98652649, 12.24541664], [79.98625183, 12.24542999], [79.98625183, 12.24514103], [79.98513794, 12.24514103], [79.98513794, 12.24542999], [79.98542023, 12.24541664], [79.98542023, 12.24597263], [79.98568726, 12.24596977], [79.98568726, 12.24681091], [79.98596954, 12.24680519], [79.98596954, 12.24736118], [79.98625183, 12.24736118], [79.98625183, 12.24792099], [79.98652649, 12.24791718], [79.98652649, 12.24847317], [79.98680878, 12.24847126], [79.98680878, 12.24903107], [79.98708344, 12.24902916], [79.98708344, 12.24958324], [79.98735809, 12.24958134], [79.98735809, 12.25014114], [79.98790741, 12.25014114], [79.98790741, 12.25042152], [79.98847198, 12.25042152], [79.98847198, 12.25097084], [79.98902893, 12.25097084]]], [[[80.32290649, 13.43847084], [80.32290649, 13.43791962], [80.32347107, 13.43791962], [80.32347107, 13.43763924], [80.32375336, 13.43763924], [80.32375336, 13.43736076], [80.32430267, 13.43736076], [80.32430267, 13.43708992], [80.32457733, 13.43708992], [80.32457733, 13.43653202], [80.32485199, 13.43653202], [80.32485199, 13.43597126], [80.32514191, 13.43597317], [80.32514191, 13.4351387], [80.32485199, 13.43514061], [80.32485199, 13.43431187], [80.32347107, 13.43431187], [80.32347107, 13.43403053], [80.32290649, 13.43403053], [80.32290649, 13.43431187], [80.32208252, 13.43430519], [80.32208252, 13.43458271], [80.32152557, 13.43458271], [80.32152557, 13.43486118], [80.32125092, 13.43486118], [80.32125092, 13.43680954], [80.32152557, 13.43680477], [80.32152557, 13.43819523], [80.32208252, 13.43819141], [80.32208252, 13.43847084], [80.32290649, 13.43847084]]], [[[80.22735596, 13.49403191], [80.22735596, 13.49347115], [80.22763824, 13.49347115], [80.22763824, 13.49291706], [80.2279129, 13.49292183], [80.2279129, 13.49236107], [80.22763824, 13.49236107], [80.22763824, 13.49181175], [80.22735596, 13.49181175], [80.22735596, 13.49123955], [80.2270813, 13.49124908], [80.2270813, 13.49069309], [80.2251358, 13.49069309], [80.2251358, 13.49041653], [80.22486115, 13.49042034], [80.22486115, 13.49014091], [80.22402954, 13.49014091], [80.22402954, 13.49181175], [80.22458649, 13.49180508], [80.22458649, 13.4920826], [80.22486115, 13.49208069], [80.22486115, 13.49236107], [80.22541809, 13.49236107], [80.22541809, 13.49263859], [80.22598267, 13.49263859], [80.22598267, 13.49292183], [80.22624969, 13.49291706], [80.22624969, 13.49319553], [80.22680664, 13.49319077], [80.22680664, 13.49403191], [80.22735596, 13.49403191]]], [[[80.27458191, 13.45958328], [80.27458191, 13.4590292], [80.27485657, 13.45903111], [80.27485657, 13.45875072], [80.27513885, 13.45875072], [80.27513885, 13.45819855], [80.27540588, 13.45819855], [80.27540588, 13.45792103], [80.2756958, 13.45792103], [80.2756958, 13.45764065], [80.27597046, 13.45764065], [80.27597046, 13.45708275], [80.27625275, 13.45708275], [80.27625275, 13.45680523], [80.2765274, 13.45681095], [80.2765274, 13.45625114], [80.27680969, 13.45625114], [80.27680206, 13.45597267], [80.27708435, 13.45597267], [80.27708435, 13.45569515], [80.2776413, 13.45569515], [80.2776413, 13.45541668], [80.27791595, 13.45542145], [80.27791595, 13.45513153], [80.2784729, 13.45513821], [80.2784729, 13.45485973], [80.27874756, 13.45485973], [80.27874756, 13.45458031], [80.2793045, 13.45458221], [80.2793045, 13.4543066], [80.27958679, 13.45431137], [80.27958679, 13.45403099], [80.2804184, 13.45403099], [80.2804184, 13.45374966], [80.28125, 13.45374966], [80.28125, 13.45347023], [80.2820816, 13.45347214], [80.2820816, 13.45319366], [80.2831955, 13.45319366], [80.2831955, 13.45291615], [80.2840271, 13.45292091], [80.2840271, 13.45264053], [80.2848587, 13.45264053], [80.2848587, 13.45236015], [80.28514099, 13.45236015], [80.28514099, 13.45180416], [80.28542328, 13.45181084], [80.28542328, 13.45125008], [80.28569794, 13.45125008], [80.28569794, 13.4509697], [80.2859726, 13.4509716], [80.2859726, 13.45041561], [80.28624725, 13.45042133], [80.28624725, 13.44985962], [80.28652954, 13.44986153], [80.28652954, 13.44902802], [80.28624725, 13.44902992], [80.28624725, 13.44847202], [80.28569794, 13.44847202], [80.28569794, 13.44874954], [80.28542328, 13.44874954], [80.28542328, 13.44932175], [80.28514099, 13.44930553], [80.28514099, 13.4495821], [80.2848587, 13.4495821], [80.2848587, 13.44986153], [80.28457642, 13.44985962], [80.28457642, 13.45014], [80.28430176, 13.45013809], [80.28430176, 13.45069408], [80.2840271, 13.45069408], [80.2840271, 13.4509716], [80.28375244, 13.4509697], [80.28375244, 13.45125008], [80.28291321, 13.45125008], [80.28291321, 13.45153141], [80.2820816, 13.45153141], [80.2820816, 13.45181084], [80.28152466, 13.45180416], [80.28152466, 13.45208359], [80.28069305, 13.45208359], [80.28069305, 13.45236015], [80.28013611, 13.45236015], [80.28013611, 13.45264053], [80.27986908, 13.45264053], [80.27986908, 13.45292091], [80.2793045, 13.45291615], [80.2793045, 13.45319366], [80.27874756, 13.45319366], [80.27874756, 13.45347214], [80.27819824, 13.45347023], [80.27819061, 13.45374966], [80.27791595, 13.45374966], [80.27791595, 13.45403099], [80.27735901, 13.45403099], [80.27735901, 13.45431137], [80.27708435, 13.4543066], [80.27708435, 13.45458221], [80.2765274, 13.45458031], [80.2765274, 13.45485973], [80.27625275, 13.45485973], [80.27625275, 13.45513821], [80.2756958, 13.45513153], [80.2756958, 13.45542145], [80.27541351, 13.45541668], [80.27541351, 13.45569515], [80.27513885, 13.45569038], [80.27513885, 13.45625114], [80.27485657, 13.45625114], [80.27485657, 13.45681095], [80.27458191, 13.45680523], [80.27458191, 13.45736122], [80.27430725, 13.45736122], [80.27430725, 13.45792103], [80.27402496, 13.45791721], [80.27402496, 13.45847321], [80.27374268, 13.4584713], [80.27374268, 13.45931244], [80.27402496, 13.45930481], [80.27402496, 13.45958328], [80.27458191, 13.45958328]]], [[[80.23236084, 13.49458313], [80.23236084, 13.49430466], [80.23291779, 13.49430466], [80.23291779, 13.49402714], [80.23319244, 13.49403191], [80.23319244, 13.49375153], [80.23374939, 13.49375153], [80.23374939, 13.49347115], [80.23430634, 13.49347115], [80.23430634, 13.49291706], [80.23457336, 13.49292183], [80.23457336, 13.49236107], [80.23486328, 13.49236107], [80.23486328, 13.49208069], [80.23458099, 13.4920826], [80.23458099, 13.49180508], [80.23430634, 13.49181175], [80.23430634, 13.49123955], [80.23402405, 13.49124908], [80.23402405, 13.49097347], [80.23374939, 13.49097347], [80.23374939, 13.49069309], [80.23041534, 13.49069309], [80.23041534, 13.49124908], [80.23014069, 13.49123955], [80.23014069, 13.49152946], [80.2298584, 13.4915266], [80.2298584, 13.4920826], [80.22957611, 13.49208069], [80.22957611, 13.49263859], [80.22930908, 13.49263859], [80.22930908, 13.49292183], [80.22958374, 13.49291706], [80.22958374, 13.49347115], [80.2298584, 13.49347115], [80.2298584, 13.49375153], [80.23042297, 13.49375153], [80.23042297, 13.49403191], [80.23069763, 13.49402714], [80.23069763, 13.49430466], [80.23124695, 13.49430466], [80.23124695, 13.49458313], [80.23236084, 13.49458313]]], [[[80.26875305, 13.56245422], [80.26875305, 13.56208038], [80.26902771, 13.56208229], [80.26902771, 13.56152916], [80.26930237, 13.56153107], [80.26930237, 13.56097031], [80.26958466, 13.56097221], [80.26958466, 13.56013775], [80.26985931, 13.56014061], [80.26985931, 13.55957985], [80.2701416, 13.55958366], [80.2701416, 13.55902767], [80.27041626, 13.55903053], [80.27041626, 13.55846977], [80.27069092, 13.55847168], [80.27069092, 13.55791569], [80.27097321, 13.55792141], [80.27097321, 13.5573597], [80.27124786, 13.5573597], [80.27124786, 13.55653], [80.27153015, 13.55653], [80.27153015, 13.55597019], [80.27180481, 13.5559721], [80.27180481, 13.55513763], [80.2720871, 13.55513954], [80.2720871, 13.55458164], [80.27236176, 13.55458355], [80.27236176, 13.55375004], [80.27263641, 13.55375004], [80.27263641, 13.55292034], [80.2729187, 13.55292034], [80.2729187, 13.55235958], [80.27319336, 13.55236244], [80.27319336, 13.55152798], [80.27347565, 13.55152798], [80.27347565, 13.55097198], [80.27375031, 13.55097198], [80.27375031, 13.55013657], [80.27401733, 13.55014038], [80.27401733, 13.54958057], [80.27430725, 13.54958439], [80.27430725, 13.54874897], [80.27458191, 13.54875183], [80.27458191, 13.54792023], [80.27485657, 13.54792023], [80.27485657, 13.54736137], [80.27513885, 13.54736137], [80.27513885, 13.54652691], [80.27540588, 13.54653168], [80.27540588, 13.54597092], [80.2756958, 13.54597092], [80.2756958, 13.54513931], [80.27597046, 13.54513931], [80.27597046, 13.54458141], [80.27625275, 13.54458332], [80.27625275, 13.54374886], [80.2765274, 13.54375076], [80.2765274, 13.54292202], [80.27680969, 13.54292202], [80.27680969, 13.54234982], [80.27708435, 13.54236126], [80.27708435, 13.54152679], [80.27735901, 13.54153061], [80.27735901, 13.5409708], [80.2776413, 13.5409708], [80.2776413, 13.5401392], [80.27791595, 13.54014111], [80.27791595, 13.53958035], [80.27819061, 13.53958321], [80.27819824, 13.53874874], [80.2784729, 13.53875065], [80.2784729, 13.53792095], [80.27874756, 13.53792095], [80.27874756, 13.53736115], [80.27902985, 13.53736115], [80.27902985, 13.53652859], [80.27929688, 13.53654003], [80.27929688, 13.53596973], [80.27958679, 13.5359726], [80.27958679, 13.53513813], [80.27986908, 13.53514099], [80.27986908, 13.53458023], [80.28013611, 13.53458214], [80.28013611, 13.53374958], [80.2804184, 13.53374958], [80.2804184, 13.53292084], [80.28069305, 13.53292084], [80.28069305, 13.53236008], [80.28098297, 13.53236008], [80.28097534, 13.53152847], [80.28125, 13.53153133], [80.28125, 13.53096962], [80.28152466, 13.53097153], [80.28152466, 13.53041553], [80.28180695, 13.53041553], [80.28180695, 13.52958202], [80.2820816, 13.52958202], [80.2820816, 13.52902794], [80.28235626, 13.52902985], [80.28235626, 13.52847195], [80.28263855, 13.52847195], [80.28263855, 13.52763844], [80.28291321, 13.52764034], [80.28291321, 13.52707863], [80.2831955, 13.52708435], [80.2831955, 13.52652836], [80.28347015, 13.52653027], [80.28347015, 13.52569103], [80.28375244, 13.5256958], [80.28375244, 13.52486229], [80.2840271, 13.52486229], [80.2840271, 13.52402782], [80.28430176, 13.52402973], [80.28430176, 13.52347183], [80.28458405, 13.52347183], [80.28458405, 13.52264023], [80.2848587, 13.52264023], [80.2848587, 13.52180958], [80.28514099, 13.52180958], [80.28514099, 13.5209713], [80.28541565, 13.5209713], [80.28541565, 13.52013874], [80.28569794, 13.5201416], [80.28569794, 13.51958084], [80.2859726, 13.51958275], [80.2859726, 13.51874924], [80.28624725, 13.51874924], [80.28624725, 13.51791954], [80.28652954, 13.51791954], [80.28652954, 13.51708126], [80.2868042, 13.51708317], [80.2868042, 13.5162487], [80.28708649, 13.51625061], [80.28708649, 13.51541042], [80.28736115, 13.5154171], [80.28736115, 13.51458263], [80.2876358, 13.51458263], [80.2876358, 13.51347256], [80.28791809, 13.51347256], [80.28791809, 13.51263905], [80.28819275, 13.51264095], [80.28819275, 13.51180935], [80.28848267, 13.51180935], [80.28848267, 13.51097012], [80.28874969, 13.51097298], [80.28874969, 13.51013947], [80.28901672, 13.51014137], [80.28901672, 13.50931072], [80.28930664, 13.50931072], [80.28930664, 13.50846958], [80.2895813, 13.5084734], [80.2895813, 13.50763798], [80.28985596, 13.50764084], [80.28985596, 13.50681114], [80.29013824, 13.50681114], [80.29013824, 13.50568962], [80.2904129, 13.50569439], [80.2904129, 13.50485992], [80.29070282, 13.50485992], [80.29069519, 13.50402832], [80.29096985, 13.50403118], [80.29096985, 13.50317955], [80.29125214, 13.50319386], [80.29125214, 13.50236225], [80.29152679, 13.50236225], [80.29152679, 13.50125027], [80.29180908, 13.50125027], [80.29180908, 13.50014019], [80.29207611, 13.50014019], [80.29207611, 13.49903011], [80.2923584, 13.49903011], [80.2923584, 13.49792004], [80.29264069, 13.49792004], [80.29264069, 13.49763966], [80.29292297, 13.49763966], [80.29292297, 13.4970789], [80.29319763, 13.49708366], [80.29319763, 13.49652767], [80.29347229, 13.49652958], [80.29347229, 13.4956913], [80.29374695, 13.49569321], [80.29374695, 13.4948616], [80.29402924, 13.4948616], [80.29402924, 13.49403191], [80.29429626, 13.49403191], [80.29429626, 13.49292183], [80.29458618, 13.49292183], [80.29458618, 13.49181175], [80.29486847, 13.49181175], [80.29486847, 13.49069118], [80.2951355, 13.49069309], [80.2951355, 13.48958302], [80.29541779, 13.48958302], [80.29541779, 13.48847103], [80.29569244, 13.48847103], [80.29569244, 13.48763943], [80.2959671, 13.48764133], [80.2959671, 13.48653126], [80.29624939, 13.48653126], [80.29624939, 13.48569012], [80.29652405, 13.48569489], [80.29652405, 13.48513889], [80.29680634, 13.48513889], [80.29680634, 13.48458004], [80.29708099, 13.4845829], [80.29708099, 13.4837513], [80.29736328, 13.4837513], [80.29736328, 13.48318958], [80.29763794, 13.4831953], [80.29763794, 13.48235989], [80.2979126, 13.48236275], [80.2979126, 13.48181057], [80.29818726, 13.48181057], [80.29818726, 13.48125076], [80.29846954, 13.48125076], [80.29846954, 13.48042107], [80.29875183, 13.48042107], [80.29875183, 13.47986031], [80.29902649, 13.47986031], [80.29902649, 13.47930431], [80.29930878, 13.47930431], [80.29930878, 13.47875023], [80.29957581, 13.47875023], [80.29957581, 13.47819042], [80.29985809, 13.47819424], [80.29985809, 13.47791576], [80.30014038, 13.47792053], [80.30014038, 13.47735977], [80.30042267, 13.47735977], [80.30041504, 13.47680569], [80.30069733, 13.47681141], [80.30069733, 13.47653008], [80.30097198, 13.47653008], [80.30097198, 13.47597027], [80.30124664, 13.47597218], [80.30124664, 13.4756937], [80.30152893, 13.4756937], [80.30152893, 13.47513771], [80.30179596, 13.47513962], [80.30179596, 13.47457981], [80.30152893, 13.47458363], [80.30152893, 13.47375011], [80.30124664, 13.47375202], [80.30124664, 13.4732008], [80.30097198, 13.4732008], [80.30097198, 13.47264004], [80.30124664, 13.47264004], [80.30124664, 13.47235966], [80.30152893, 13.47235966], [80.30152893, 13.47207928], [80.30180359, 13.47208405], [80.30180359, 13.47180557], [80.30208588, 13.47181034], [80.30208588, 13.47152996], [80.30236053, 13.47152996], [80.30236053, 13.47124958], [80.30264282, 13.47124958], [80.30264282, 13.4709692], [80.30319214, 13.47097206], [80.30319214, 13.47069359], [80.30403137, 13.47069359], [80.30403137, 13.47041798], [80.30430603, 13.47042179], [80.30430603, 13.47014046], [80.30458069, 13.47014046], [80.30458069, 13.46986198], [80.30486298, 13.46986198], [80.30486298, 13.46958065], [80.30513763, 13.46958447], [80.30513763, 13.46930599], [80.30541992, 13.46930981], [80.30541992, 13.46903038], [80.30568695, 13.46903038], [80.30568695, 13.46875191], [80.30596924, 13.46875191], [80.30596924, 13.46847057], [80.30625153, 13.46847057], [80.30625153, 13.46819305], [80.30652618, 13.46819305], [80.30652618, 13.4679184], [80.30680847, 13.4679203], [80.30680847, 13.46764183], [80.30708313, 13.46764183], [80.30708313, 13.46736145], [80.30735779, 13.46736145], [80.30735779, 13.46708298], [80.30764008, 13.46708298], [80.30764008, 13.46652699], [80.3079071, 13.46653175], [80.3079071, 13.46597099], [80.30819702, 13.46597099], [80.30819702, 13.46541691], [80.30847168, 13.46541977], [80.30847168, 13.46486092], [80.30874634, 13.46486092], [80.30874634, 13.46402931], [80.30902863, 13.46402931], [80.30902863, 13.46319103], [80.30930328, 13.46319485], [80.30930328, 13.46263885], [80.3095932, 13.46264076], [80.3095932, 13.46181202], [80.3098526, 13.46181202], [80.3098526, 13.4612627], [80.31014252, 13.4612627], [80.31014252, 13.46042156], [80.31041718, 13.46042156], [80.31041718, 13.45958138], [80.31069183, 13.45958328], [80.31069183, 13.4590292], [80.31096649, 13.45903111], [80.31096649, 13.45792103], [80.31124878, 13.45792103], [80.31124878, 13.45653057], [80.31153107, 13.45653057], [80.31153107, 13.45513153], [80.31180573, 13.45513821], [80.31180573, 13.45402908], [80.31208038, 13.45403099], [80.31208038, 13.45292091], [80.31181335, 13.45292091], [80.31181335, 13.45207119], [80.31153107, 13.45208359], [80.31153107, 13.4515276], [80.31124878, 13.45153141], [80.31124878, 13.4509697], [80.31236267, 13.4509716], [80.31236267, 13.45069408], [80.31291962, 13.45069408], [80.31291962, 13.45041561], [80.31346893, 13.45042133], [80.31346893, 13.44985962], [80.31375122, 13.44986153], [80.31375122, 13.44680595], [80.31402588, 13.44681263], [80.31402588, 13.44624996], [80.31430817, 13.44624996], [80.31430817, 13.4456892], [80.31458282, 13.44569397], [80.31458282, 13.44513988], [80.31485748, 13.44514179], [80.31485748, 13.44458199], [80.31513977, 13.44458389], [80.31513977, 13.44375038], [80.31485748, 13.44375038], [80.31485748, 13.44347191], [80.31513977, 13.44347191], [80.31513977, 13.4426403], [80.3154068, 13.4426403], [80.3154068, 13.44180965], [80.31513977, 13.44180965], [80.31513977, 13.44042015], [80.3154068, 13.44042015], [80.3154068, 13.43736076], [80.31569672, 13.43736076], [80.31569672, 13.43708992], [80.315979, 13.43708992], [80.315979, 13.43597126], [80.31541443, 13.43597317], [80.31541443, 13.43569469], [80.31513977, 13.43569469], [80.31513977, 13.43541718], [80.3154068, 13.43542194], [80.3154068, 13.4345808], [80.31513977, 13.43458271], [80.31513977, 13.43375111], [80.31485748, 13.43375111], [80.31485748, 13.43347073], [80.31291962, 13.43347263], [80.31291962, 13.43319511], [80.31208038, 13.43319511], [80.31208038, 13.43291664], [80.31153107, 13.43292141], [80.31153107, 13.43264103], [80.31069183, 13.43264103], [80.31069183, 13.43292141], [80.31041718, 13.43292141], [80.31041718, 13.43264103], [80.3098526, 13.43264103], [80.3098526, 13.43292141], [80.30819702, 13.43291664], [80.30819702, 13.43319511], [80.30764008, 13.43319511], [80.30764008, 13.43347263], [80.30735779, 13.43347073], [80.30735779, 13.43375111], [80.30680847, 13.43375111], [80.30680847, 13.43403053], [80.30652618, 13.43403053], [80.30652618, 13.43431187], [80.30596924, 13.43430519], [80.30596924, 13.43458271], [80.30569458, 13.43458271], [80.30569458, 13.43486118], [80.30541992, 13.43486118], [80.30541992, 13.43542194], [80.30513763, 13.43541718], [80.30513763, 13.43569469], [80.30486298, 13.43569469], [80.30486298, 13.43597317], [80.30458069, 13.43597126], [80.30457306, 13.43653202], [80.30430603, 13.43653202], [80.30430603, 13.43680954], [80.304039, 13.43680954], [80.304039, 13.43708992], [80.30374908, 13.43708992], [80.30374908, 13.43763924], [80.3034668, 13.43763924], [80.3034668, 13.43791962], [80.30319214, 13.43791676], [80.30319214, 13.43819523], [80.30291748, 13.43819141], [80.30291748, 13.43874931], [80.30264282, 13.43874931], [80.30264282, 13.43902969], [80.30236053, 13.43902969], [80.30236053, 13.43931007], [80.30208588, 13.43930531], [80.30208588, 13.4398613], [80.30180359, 13.4398613], [80.30180359, 13.44013977], [80.30152893, 13.44013023], [80.30152893, 13.44042015], [80.30097198, 13.44041538], [80.30097198, 13.44069576], [80.30069733, 13.44069576], [80.30069733, 13.44097137], [80.30014038, 13.44097137], [80.30014038, 13.44124889], [80.29985809, 13.44124889], [80.29985809, 13.44153023], [80.29957581, 13.44153023], [80.29957581, 13.44180965], [80.29902649, 13.44180584], [80.29902649, 13.44208431], [80.29875183, 13.44208145], [80.29875183, 13.44236183], [80.29846954, 13.44236183], [80.29846954, 13.4426403], [80.2979126, 13.4426403], [80.2979126, 13.44291973], [80.29763794, 13.44291782], [80.29763794, 13.44319439], [80.29680634, 13.44319439], [80.29680634, 13.44347191], [80.29651642, 13.44347191], [80.29651642, 13.44375038], [80.29624939, 13.44375038], [80.29624939, 13.44402981], [80.2959671, 13.44402981], [80.2959671, 13.44431019], [80.29569244, 13.44430637], [80.29569244, 13.44458389], [80.29541779, 13.44458389], [80.29541779, 13.44486237], [80.29514313, 13.44486046], [80.29514313, 13.44514179], [80.29486847, 13.44514179], [80.29486847, 13.44542027], [80.29458618, 13.44541645], [80.29458618, 13.4456892], [80.29430389, 13.44569588], [80.29430389, 13.44597244], [80.29402924, 13.44596958], [80.29402924, 13.44624996], [80.29374695, 13.44624996], [80.29374695, 13.44653034], [80.29347229, 13.44653034], [80.29347229, 13.44681263], [80.29319763, 13.44680595], [80.29319763, 13.44708443], [80.29292297, 13.44708157], [80.29292297, 13.44764042], [80.29264069, 13.44763756], [80.29264069, 13.44847202], [80.2923584, 13.44847202], [80.2923584, 13.44932175], [80.29207611, 13.44932175], [80.29207611, 13.45042133], [80.29180908, 13.45042133], [80.29180908, 13.45125008], [80.29152679, 13.45125008], [80.29152679, 13.45208359], [80.29125214, 13.45207119], [80.29125214, 13.45264053], [80.29096985, 13.45263767], [80.29096985, 13.45319366], [80.29070282, 13.45318985], [80.29070282, 13.45374966], [80.2904129, 13.45374966], [80.2904129, 13.45458221], [80.29013824, 13.45458221], [80.29013824, 13.45513821], [80.28986359, 13.45513821], [80.28986359, 13.45569515], [80.2895813, 13.45569038], [80.2895813, 13.45625114], [80.28930664, 13.45625114], [80.28930664, 13.45681095], [80.28902435, 13.45680523], [80.28902435, 13.45736122], [80.28874969, 13.45736122], [80.28874969, 13.45764065], [80.28848267, 13.45764065], [80.28848267, 13.45819855], [80.28819275, 13.45819855], [80.28819275, 13.45875072], [80.28791809, 13.45875072], [80.28791809, 13.45931244], [80.2876358, 13.45931244], [80.2876358, 13.46014118], [80.28736115, 13.46013927], [80.28736115, 13.46097088], [80.28708649, 13.46097088], [80.28708649, 13.46208286], [80.28679657, 13.46208096], [80.28679657, 13.46291924], [80.28652954, 13.46291733], [80.28652954, 13.46347332], [80.28624725, 13.46347141], [80.28624725, 13.46375084], [80.2859726, 13.46375084], [80.2859726, 13.46486092], [80.28569794, 13.46486092], [80.28569794, 13.46625233], [80.28541565, 13.46625233], [80.28541565, 13.46708298], [80.28624725, 13.46708298], [80.28624725, 13.46652699], [80.28652954, 13.46653175], [80.28652954, 13.46625233], [80.28679657, 13.46625233], [80.28679657, 13.46513939], [80.28708649, 13.46513939], [80.28708649, 13.46541977], [80.28736115, 13.46541691], [80.28736115, 13.46597099], [80.2876358, 13.46597099], [80.2876358, 13.46736145], [80.28736115, 13.46736145], [80.28736115, 13.46903038], [80.2876358, 13.46903038], [80.2876358, 13.46930981], [80.28791809, 13.46930599], [80.28791809, 13.47069359], [80.28819275, 13.47069073], [80.28819275, 13.47124958], [80.28791809, 13.47124958], [80.28791809, 13.47152996], [80.28819275, 13.47152996], [80.28819275, 13.4732008], [80.28791809, 13.47319412], [80.28791809, 13.47347164], [80.28819275, 13.47346973], [80.28819275, 13.47431087], [80.28791809, 13.47430611], [80.28791809, 13.47458363], [80.2876358, 13.47458363], [80.2876358, 13.4748621], [80.28736115, 13.47486019], [80.28736115, 13.47513962], [80.28708649, 13.47513771], [80.28708649, 13.4756937], [80.28736115, 13.4756918], [80.28736115, 13.47625923], [80.28708649, 13.47625923], [80.28708649, 13.47681141], [80.2868042, 13.47680569], [80.2868042, 13.47708416], [80.28652954, 13.47708416], [80.28652954, 13.47680569], [80.2859726, 13.47681141], [80.2859726, 13.47653008], [80.28569794, 13.47653008], [80.28569794, 13.47625923], [80.2848587, 13.47625923], [80.2848587, 13.47681141], [80.28457642, 13.47681141], [80.28457642, 13.47735977], [80.2848587, 13.47735977], [80.2848587, 13.47847176], [80.28514099, 13.47847176], [80.28514099, 13.47958469], [80.2848587, 13.47958469], [80.2848587, 13.47986031], [80.28458405, 13.47986031], [80.28458405, 13.48069382], [80.28430939, 13.48069382], [80.28430176, 13.48097229], [80.2840271, 13.48097038], [80.2840271, 13.48181057], [80.28375244, 13.48181057], [80.28375244, 13.48236275], [80.28347015, 13.48236275], [80.28347015, 13.48292065], [80.28375244, 13.48291683], [80.28375244, 13.4831953], [80.2840271, 13.48318958], [80.2840271, 13.4837513], [80.28430176, 13.4837513], [80.28430176, 13.48403072], [80.2840271, 13.48403072], [80.2840271, 13.4843092], [80.28347015, 13.48430538], [80.28347015, 13.4845829], [80.2831955, 13.4845829], [80.2831955, 13.48486137], [80.28291321, 13.48486137], [80.28291321, 13.48513889], [80.28263855, 13.48513889], [80.28263855, 13.48542976], [80.28236389, 13.48541737], [80.28236389, 13.48597336], [80.2820816, 13.48597145], [80.2820816, 13.48653126], [80.28180695, 13.48652744], [80.28180695, 13.48708344], [80.28151703, 13.48708057], [80.28151703, 13.48764133], [80.28180695, 13.48763943], [80.28180695, 13.48847103], [80.28151703, 13.48847103], [80.28151703, 13.48903179], [80.28125, 13.48902702], [80.28125, 13.49124908], [80.28151703, 13.49123955], [80.28151703, 13.49181175], [80.28180695, 13.49180508], [80.28180695, 13.49985981], [80.28152466, 13.49985981], [80.28152466, 13.50069427], [80.28125, 13.50069237], [80.28125, 13.50125027], [80.28097534, 13.50125027], [80.28097534, 13.50208378], [80.28069305, 13.50208378], [80.28069305, 13.50236225], [80.2804184, 13.50236034], [80.2804184, 13.5029211], [80.28013611, 13.50291634], [80.28013611, 13.50319386], [80.27986145, 13.50319386], [80.27986908, 13.50374985], [80.27958679, 13.50374985], [80.27958679, 13.50431061], [80.27929688, 13.50431061], [80.27929688, 13.50485992], [80.27902985, 13.50485992], [80.27902985, 13.50625038], [80.27874756, 13.50625038], [80.27874756, 13.50708199], [80.2784729, 13.50708199], [80.2784729, 13.50819016], [80.27819824, 13.50820065], [80.27819824, 13.50931072], [80.27791595, 13.50931072], [80.27791595, 13.51237202], [80.2776413, 13.51237202], [80.2776413, 13.51264095], [80.27735901, 13.51264095], [80.27735901, 13.51292133], [80.2776413, 13.51292133], [80.2776413, 13.51764202], [80.27791595, 13.51763916], [80.27791595, 13.52069569], [80.2776413, 13.52069092], [80.2776413, 13.52125168], [80.27735901, 13.52124882], [80.27735901, 13.52208424], [80.27707672, 13.52208138], [80.27707672, 13.52291965], [80.27680206, 13.52291775], [80.27680206, 13.52347183], [80.2765274, 13.52347183], [80.2765274, 13.52431011], [80.27625275, 13.5243063], [80.27625275, 13.52486229], [80.27597046, 13.52486038], [80.27597046, 13.52513981], [80.27540588, 13.52513981], [80.27540588, 13.52486038], [80.27513885, 13.52486229], [80.27513885, 13.52402782], [80.27540588, 13.52402973], [80.27540588, 13.52291965], [80.2756958, 13.52291965], [80.2756958, 13.52125168], [80.27597046, 13.52125168], [80.27597046, 13.51902962], [80.27625275, 13.51902962], [80.27625275, 13.51708126], [80.27597046, 13.51708317], [80.27597046, 13.51569462], [80.2756958, 13.51569462], [80.2756958, 13.51513863], [80.27540588, 13.51514053], [80.27540588, 13.51458073], [80.2748642, 13.51458263], [80.2748642, 13.51430511], [80.27430725, 13.51430511], [80.27430725, 13.51458263], [80.27374268, 13.51458073], [80.27374268, 13.51653194], [80.27263641, 13.51653194], [80.27263641, 13.51874924], [80.27236176, 13.51874924], [80.27236176, 13.52042198], [80.2720871, 13.52041531], [80.2720871, 13.52236176], [80.27180481, 13.52236176], [80.27180481, 13.52347183], [80.27124786, 13.52347183], [80.27124786, 13.52375031], [80.27068329, 13.52375031], [80.27068329, 13.52402973], [80.2701416, 13.52402973], [80.2701416, 13.52431011], [80.26985931, 13.52431011], [80.26985931, 13.52402973], [80.26957703, 13.52402973], [80.26957703, 13.52375031], [80.26902771, 13.52375031], [80.26902771, 13.52347183], [80.26875305, 13.52347183], [80.26875305, 13.52319336], [80.26847076, 13.52319336], [80.26847076, 13.52291775], [80.26819611, 13.52291965], [80.26819611, 13.52264023], [80.26790619, 13.52264023], [80.26790619, 13.52235889], [80.26763916, 13.52236176], [80.26763916, 13.52208424], [80.2673645, 13.52208424], [80.2673645, 13.52180481], [80.26597595, 13.52180481], [80.26597595, 13.52208424], [80.26569366, 13.52208424], [80.26569366, 13.52236176], [80.26541901, 13.52235889], [80.26541901, 13.52264023], [80.26513672, 13.52264023], [80.26513672, 13.52291965], [80.26486206, 13.52291775], [80.26486206, 13.52319336], [80.26457977, 13.52319336], [80.26457977, 13.52347183], [80.26431274, 13.52347183], [80.26431274, 13.52431011], [80.26457977, 13.5243063], [80.26457977, 13.52458382], [80.26513672, 13.52458382], [80.26513672, 13.52486229], [80.26568604, 13.52486038], [80.26568604, 13.52513981], [80.26625061, 13.52513981], [80.26625061, 13.52542019], [80.26680756, 13.52541637], [80.26680756, 13.5256958], [80.2673645, 13.5256958], [80.2673645, 13.52597237], [80.26763916, 13.52596855], [80.26763916, 13.52625179], [80.26819611, 13.52625179], [80.26819611, 13.52653027], [80.26847076, 13.52653027], [80.26848602, 13.52680969], [80.26902771, 13.52680588], [80.26902771, 13.52708435], [80.26930237, 13.52708435], [80.26930237, 13.52819443], [80.2701416, 13.52819443], [80.2701416, 13.52847195], [80.27041626, 13.52847195], [80.27041626, 13.52902985], [80.2701416, 13.52902794], [80.2701416, 13.5298624], [80.26985931, 13.5298624], [80.26985931, 13.53041553], [80.26957703, 13.53040886], [80.26957703, 13.53125], [80.26930237, 13.53125], [80.26930237, 13.53181076], [80.26902771, 13.53181076], [80.26902771, 13.53236008], [80.26875305, 13.53236008], [80.26875305, 13.53292084], [80.26847076, 13.53292084], [80.26847076, 13.5334816], [80.26819611, 13.5334816], [80.26819611, 13.53403091], [80.26791382, 13.53402805], [80.26791382, 13.53458214], [80.26763916, 13.53458023], [80.26763916, 13.53542137], [80.26735687, 13.53542137], [80.26735687, 13.53654003], [80.26708221, 13.53654003], [80.26708221, 13.53764057], [80.2673645, 13.53763866], [80.2673645, 13.53819466], [80.26763916, 13.5381918], [80.26763916, 13.53875065], [80.26790619, 13.53875065], [80.26790619, 13.53986073], [80.26763916, 13.53986073], [80.26763916, 13.54125118], [80.26735687, 13.54125118], [80.26735687, 13.54264069], [80.26708221, 13.54264069], [80.26708221, 13.54402924], [80.26680756, 13.54402924], [80.26680756, 13.54486084], [80.2665329, 13.54486084], [80.2665329, 13.54541969], [80.26625061, 13.54541683], [80.26625061, 13.54597092], [80.26597595, 13.54597092], [80.26597595, 13.54653168], [80.26569366, 13.54652691], [80.26569366, 13.5470829], [80.26541901, 13.54708099], [80.26541901, 13.54764175], [80.26513672, 13.54763889], [80.26513672, 13.54819584], [80.26486969, 13.54819107], [80.26486969, 13.54875183], [80.26457977, 13.54874897], [80.26457977, 13.55152798], [80.26486969, 13.5515213], [80.26486969, 13.55263996], [80.26513672, 13.55263996], [80.26513672, 13.55541992], [80.26486206, 13.55541801], [80.26486206, 13.55847168], [80.26457977, 13.55846977], [80.26457977, 13.56014061], [80.26431274, 13.56014061], [80.26875305, 13.56245422]]], [[[80.26541901, 13.51958275], [80.26541901, 13.51930523], [80.26568604, 13.51931], [80.26568604, 13.51902962], [80.26597595, 13.51902962], [80.26597595, 13.51874924], [80.2665329, 13.51874924], [80.26652527, 13.51819324], [80.26680756, 13.51819324], [80.26680756, 13.51763916], [80.26708221, 13.51764202], [80.26708221, 13.51708126], [80.26680756, 13.51708317], [80.26680756, 13.51652718], [80.2665329, 13.51653194], [80.2665329, 13.5156908], [80.26625061, 13.51569462], [80.26625061, 13.51458263], [80.26652527, 13.51458263], [80.26652527, 13.51347256], [80.26680756, 13.51347256], [80.26680756, 13.51236057], [80.26708221, 13.51237202], [80.26708221, 13.51180935], [80.26735687, 13.51180935], [80.26735687, 13.51097012], [80.26763916, 13.51097298], [80.26763916, 13.51041698], [80.26790619, 13.51041889], [80.26790619, 13.50931072], [80.26763916, 13.50931072], [80.26763916, 13.50792122], [80.26735687, 13.50792122], [80.26735687, 13.50653076], [80.26708221, 13.50653076], [80.26708221, 13.50485992], [80.26680756, 13.50485992], [80.26680756, 13.50317955], [80.26652527, 13.50319386], [80.26652527, 13.50152779], [80.26625061, 13.50152969], [80.26625061, 13.50014019], [80.26597595, 13.50014019], [80.26597595, 13.49957943], [80.26541901, 13.4995842], [80.26541901, 13.49985981], [80.26513672, 13.49985981], [80.26513672, 13.50125027], [80.26486206, 13.50125027], [80.26486206, 13.50319386], [80.26513672, 13.50317955], [80.26513672, 13.5051403], [80.26541901, 13.5051403], [80.26541901, 13.50597191], [80.26569366, 13.50597191], [80.26569366, 13.50708199], [80.26597595, 13.50708199], [80.26597595, 13.50819016], [80.26625061, 13.50820065], [80.26625061, 13.50931072], [80.2665329, 13.50931072], [80.2665329, 13.51041889], [80.26625061, 13.51041889], [80.26625061, 13.51125145], [80.26597595, 13.51124859], [80.26597595, 13.51208305], [80.26569366, 13.51208305], [80.26569366, 13.51319504], [80.26541901, 13.51319027], [80.26541901, 13.51403141], [80.26513672, 13.51402664], [80.26513672, 13.51486111], [80.26486206, 13.51486111], [80.26486206, 13.5154171], [80.26457977, 13.51541042], [80.26457977, 13.51625061], [80.26430511, 13.5162487], [80.26430511, 13.51736069], [80.26457977, 13.51736069], [80.26457977, 13.51902962], [80.26486206, 13.51902676], [80.26486206, 13.51958275], [80.26541901, 13.51958275]]], [[[79.70680237, 10.28819466], [79.70680237, 10.28791714], [79.70707703, 10.28792191], [79.70707703, 10.28764057], [79.70735931, 10.28764057], [79.70735931, 10.2870779], [79.7076416, 10.28708267], [79.7076416, 10.28680515], [79.70791626, 10.28681183], [79.70791626, 10.28625107], [79.7076416, 10.28625107], [79.7076416, 10.28569031], [79.70708466, 10.28569508], [79.70708466, 10.2854166], [79.70680237, 10.28542137], [79.70680237, 10.28514099], [79.70540619, 10.28514099], [79.70540619, 10.28542137], [79.7048645, 10.2854166], [79.7048645, 10.28569508], [79.70458221, 10.28569031], [79.70458221, 10.28598022], [79.7040329, 10.28598022], [79.7040329, 10.28625107], [79.70375061, 10.28625107], [79.70375061, 10.28653145], [79.70318604, 10.28653145], [79.70318604, 10.28681183], [79.70291901, 10.28680515], [79.70291901, 10.28708267], [79.70236206, 10.28708267], [79.70236206, 10.28736115], [79.70263672, 10.28736115], [79.70263672, 10.28792191], [79.70291901, 10.28791714], [79.70291901, 10.28819466], [79.70680237, 10.28819466]]], [[[79.69790649, 10.2901392], [79.69790649, 10.28986073], [79.69904327, 10.28986073], [79.69902802, 10.28958321], [79.70041656, 10.28958321], [79.70041656, 10.28930473], [79.70096588, 10.28931046], [79.70096588, 10.28875065], [79.70069122, 10.28875065], [79.70069122, 10.28819084], [79.69847107, 10.28819466], [79.69847107, 10.28847313], [79.69763947, 10.28847122], [79.69763947, 10.28875065], [79.69708252, 10.28875065], [79.69708252, 10.2901392], [79.69790649, 10.2901392]]], [[[79.69569397, 10.2909708], [79.69569397, 10.29041672], [79.69597626, 10.29041958], [79.69597626, 10.2901392], [79.6965332, 10.2901392], [79.6965332, 10.28986073], [79.69625092, 10.28986073], [79.69625092, 10.28958321], [79.69569397, 10.28958321], [79.69569397, 10.28930473], [79.69430542, 10.28930473], [79.69430542, 10.28958321], [79.69346619, 10.2895813], [79.69346619, 10.29124928], [79.69486237, 10.29124928], [79.69486237, 10.29097271], [79.69569397, 10.2909708]]], [[[79.69124603, 10.29792023], [79.69124603, 10.29763985], [79.69152832, 10.29763985], [79.69152832, 10.29736042], [79.69180298, 10.29736233], [79.69180298, 10.29708385], [79.69235992, 10.29708385], [79.69235992, 10.29680634], [79.69264221, 10.29681015], [79.69264221, 10.29652977], [79.69290924, 10.29652977], [79.69291687, 10.29596043], [79.69291687, 10.29541779], [79.69264221, 10.29541969], [79.69264221, 10.29458141], [79.69235992, 10.29458427], [79.69235992, 10.29402733], [79.6920929, 10.29403019], [79.6920929, 10.29374886], [79.69152832, 10.29374886], [79.69152832, 10.29347134], [79.69041443, 10.29347134], [79.69041443, 10.29374886], [79.69013977, 10.29374886], [79.69013977, 10.29403019], [79.68958282, 10.29403019], [79.68958282, 10.29430962], [79.68930817, 10.2943058], [79.68930817, 10.29458427], [79.68902588, 10.29458141], [79.68902588, 10.29514027], [79.68875122, 10.29514027], [79.68875122, 10.29569435], [79.68902588, 10.29569435], [79.68902588, 10.29625034], [79.68930817, 10.29625034], [79.68930817, 10.29636097], [79.68930817, 10.29681015], [79.68958282, 10.29680634], [79.68958282, 10.29708385], [79.68985748, 10.29708385], [79.68985748, 10.29736233], [79.69013977, 10.29736042], [79.69013977, 10.29763985], [79.6904068, 10.29763985], [79.6904068, 10.29792023], [79.69124603, 10.29792023]]], [[[79.68597412, 10.2984724], [79.68597412, 10.29819584], [79.68624878, 10.29819584], [79.68624878, 10.29763985], [79.68653107, 10.29763985], [79.68653107, 10.29736042], [79.68680573, 10.29736233], [79.68680573, 10.29708385], [79.68653107, 10.29708385], [79.68653107, 10.29690075], [79.68653107, 10.29652786], [79.68624878, 10.29652977], [79.68624878, 10.29597187], [79.68597412, 10.29597187], [79.68597412, 10.29541779], [79.68486023, 10.29541779], [79.68486023, 10.29569435], [79.68430328, 10.29569435], [79.68430328, 10.29597187], [79.68402863, 10.29597187], [79.68402863, 10.29625034], [79.68374634, 10.29625034], [79.68374634, 10.29681015], [79.68347168, 10.29680634], [79.68347168, 10.29776096], [79.68347168, 10.29819584], [79.68514252, 10.29819584], [79.68514252, 10.2984724], [79.68597412, 10.2984724]]], [[[79.62264252, 10.29986191], [79.62264252, 10.29958439], [79.62458038, 10.29958439], [79.62458038, 10.29930592], [79.62652588, 10.29931068], [79.62652588, 10.2990303], [79.62930298, 10.2990303], [79.62930298, 10.29819107], [79.62902832, 10.29819584], [79.62902832, 10.29791641], [79.62874603, 10.29792023], [79.62874603, 10.29763985], [79.62819672, 10.29763985], [79.62819672, 10.29736042], [79.62236023, 10.29736042], [79.62236023, 10.29763985], [79.6220932, 10.29763985], [79.6220932, 10.29792023], [79.62152863, 10.29791641], [79.62152863, 10.29819584], [79.62124634, 10.29819584], [79.62124634, 10.2984724], [79.62069702, 10.29846954], [79.62069702, 10.29874992], [79.6204071, 10.29874992], [79.6204071, 10.2990303], [79.62014008, 10.2990303], [79.62014008, 10.29931068], [79.62041473, 10.29930592], [79.62041473, 10.29958439], [79.62069702, 10.29958439], [79.62069702, 10.29986191], [79.62264252, 10.29986191]]], [[[79.60819244, 10.30263996], [79.60819244, 10.30235958], [79.60847473, 10.30236244], [79.60847473, 10.30208206], [79.60902405, 10.30208206], [79.60902405, 10.30097198], [79.60652924, 10.30098057], [79.60652924, 10.30125046], [79.60597229, 10.30125046], [79.60597229, 10.30140018], [79.60597229, 10.30153275], [79.60569763, 10.30152798], [79.60569763, 10.30236244], [79.60597229, 10.30235958], [79.60597229, 10.30263996], [79.60819244, 10.30263996]]], [[[79.69985962, 10.30958271], [79.69985962, 10.30930519], [79.70041656, 10.30931091], [79.70041656, 10.30903053], [79.70096588, 10.30903053], [79.70096588, 10.30875111], [79.70153046, 10.30875111], [79.70153046, 10.30847263], [79.70180511, 10.30847263], [79.70180511, 10.30819511], [79.70236206, 10.30819511], [79.70236206, 10.30791664], [79.70291901, 10.30792141], [79.70291901, 10.30764103], [79.70347595, 10.30764103], [79.70347595, 10.3073597], [79.70375061, 10.3073597], [79.70375061, 10.30708218], [79.70430756, 10.30708218], [79.70430756, 10.30680656], [79.70484924, 10.30681133], [79.70484924, 10.30653095], [79.70540619, 10.30653095], [79.70540619, 10.30681133], [79.70735931, 10.30680656], [79.70735931, 10.30708218], [79.70903015, 10.30708218], [79.70903015, 10.3073597], [79.70986176, 10.3073597], [79.70986176, 10.30764103], [79.71069336, 10.30764103], [79.71069336, 10.3073597], [79.7104187, 10.3073597], [79.7104187, 10.30708218], [79.71013641, 10.30708218], [79.71013641, 10.30680656], [79.70986176, 10.30681133], [79.70986176, 10.30597019], [79.7095871, 10.3059721], [79.7095871, 10.30541611], [79.70929718, 10.30542088], [79.70929718, 10.30514145], [79.70874786, 10.30514145], [79.70874786, 10.30486012], [79.70847321, 10.30486012], [79.70847321, 10.30458355], [79.70791626, 10.30458355], [79.70791626, 10.30430603], [79.7076416, 10.3043108], [79.7076416, 10.30402088], [79.70708466, 10.30402756], [79.70708466, 10.30375004], [79.70375061, 10.30375004], [79.70375061, 10.30458355], [79.70347595, 10.30457973], [79.70347595, 10.30542088], [79.70319366, 10.30541611], [79.70319366, 10.3059721], [79.70263672, 10.30597019], [79.70263672, 10.30624962], [79.70236206, 10.30624962], [79.70236206, 10.30653095], [79.70181274, 10.30653095], [79.70181274, 10.30681133], [79.70124817, 10.30680656], [79.70124817, 10.30708218], [79.70096588, 10.30708027], [79.70097351, 10.3073597], [79.70041656, 10.3073597], [79.70041656, 10.30764103], [79.69985962, 10.30764103], [79.69985962, 10.30792141], [79.69958496, 10.30791664], [79.69958496, 10.30819511], [79.69902802, 10.30819511], [79.69902802, 10.30958271], [79.69985962, 10.30958271]]], [[[79.62403107, 10.30875111], [79.62403107, 10.30791664], [79.62375641, 10.30792141], [79.62375641, 10.30708027], [79.62347412, 10.30708218], [79.62347412, 10.30652905], [79.62319183, 10.30653095], [79.62319183, 10.30624962], [79.62264252, 10.30624962], [79.62264252, 10.30597019], [79.62236023, 10.3059721], [79.62236023, 10.30569363], [79.62180328, 10.30569363], [79.62180328, 10.30541611], [79.62124634, 10.30541611], [79.62124634, 10.30569363], [79.62097168, 10.30569172], [79.62097168, 10.30624962], [79.62152863, 10.30624962], [79.62152863, 10.30653095], [79.6220932, 10.30653095], [79.6220932, 10.30792141], [79.62264252, 10.30791664], [79.62264252, 10.30819511], [79.62291718, 10.30819511], [79.62291718, 10.30847263], [79.62346649, 10.30846977], [79.62346649, 10.30875111], [79.62403107, 10.30875111]]], [[[79.67736053, 10.30986118], [79.67736053, 10.30958271], [79.67791748, 10.30958271], [79.67791748, 10.30930519], [79.6784668, 10.30931091], [79.6784668, 10.30903053], [79.67903137, 10.30903053], [79.67903137, 10.30875111], [79.68180847, 10.30875111], [79.68180847, 10.30847263], [79.68208313, 10.30847263], [79.68208313, 10.30819511], [79.68264008, 10.30819511], [79.68264008, 10.30791664], [79.6829071, 10.30792141], [79.6829071, 10.30764103], [79.68347168, 10.30764103], [79.68347168, 10.30708027], [79.68319702, 10.30708218], [79.68319702, 10.30652905], [79.6829071, 10.30653095], [79.6829071, 10.30597019], [79.68264008, 10.3059721], [79.68264008, 10.30541611], [79.68096924, 10.30542088], [79.68096924, 10.30514145], [79.67903137, 10.30514145], [79.67903137, 10.30486012], [79.67652893, 10.30486012], [79.67652893, 10.30514145], [79.67263794, 10.30514145], [79.67263794, 10.30542088], [79.67208099, 10.30541611], [79.67208099, 10.30569363], [79.67152405, 10.30569363], [79.67152405, 10.3059721], [79.67069244, 10.30597019], [79.67069244, 10.30624962], [79.67014313, 10.30624962], [79.67014313, 10.30653095], [79.66958618, 10.30653095], [79.66958618, 10.30681133], [79.66986084, 10.30680656], [79.66986084, 10.3073597], [79.67236328, 10.3073597], [79.67236328, 10.30764103], [79.67263794, 10.30764103], [79.67263794, 10.30792141], [79.67319489, 10.30791664], [79.67319489, 10.30819511], [79.67375183, 10.30819511], [79.67375183, 10.30847263], [79.67402649, 10.30847263], [79.67402649, 10.30875111], [79.67457581, 10.30875111], [79.67457581, 10.30903053], [79.67514038, 10.30903053], [79.67514038, 10.30931091], [79.67541504, 10.30930519], [79.67541504, 10.30958271], [79.67597198, 10.30958271], [79.67597198, 10.30986118], [79.67736053, 10.30986118]]], [[[79.68984985, 10.31042099], [79.68984985, 10.31015015], [79.6904068, 10.31015015], [79.6904068, 10.30986118], [79.69069672, 10.30986118], [79.69069672, 10.30930519], [79.69097137, 10.30931091], [79.69097137, 10.30903053], [79.69180298, 10.30903053], [79.69180298, 10.30846977], [79.69208527, 10.30847263], [79.69208527, 10.30819511], [79.69235992, 10.30819511], [79.69235992, 10.30791664], [79.69264221, 10.30791664], [79.69264221, 10.30819511], [79.69319153, 10.30819511], [79.69319153, 10.30847263], [79.69374847, 10.30847263], [79.69374847, 10.30819511], [79.69403076, 10.30819511], [79.69403076, 10.30763817], [79.69374847, 10.30764103], [79.69374847, 10.30708027], [79.69347382, 10.30708218], [79.69347382, 10.30680656], [79.69319153, 10.30681133], [79.69319153, 10.30644035], [79.69319153, 10.30569363], [79.69291687, 10.30569363], [79.69291687, 10.30513763], [79.69264221, 10.30514145], [79.69264221, 10.30457973], [79.69235992, 10.30458355], [79.69235992, 10.30430603], [79.69152832, 10.30430603], [79.69152832, 10.30458355], [79.69124603, 10.30457973], [79.69125366, 10.30486012], [79.69069672, 10.30486012], [79.69069672, 10.30514145], [79.6904068, 10.30514145], [79.6904068, 10.30542088], [79.69013977, 10.30541611], [79.69013977, 10.30569363], [79.68984985, 10.30569172], [79.68984985, 10.30624962], [79.68958282, 10.30624962], [79.68958282, 10.30681133], [79.68930817, 10.30680656], [79.68930817, 10.30828953], [79.68930817, 10.30875111], [79.68902588, 10.30875111], [79.68902588, 10.30931091], [79.68875122, 10.30931091], [79.68875122, 10.31042099], [79.68984985, 10.31042099]]], [[[79.60875702, 10.31125069], [79.60875702, 10.31097126], [79.60930634, 10.31097317], [79.60930634, 10.31069469], [79.60958099, 10.31069469], [79.60958099, 10.30986118], [79.60986328, 10.30986118], [79.60986328, 10.30930519], [79.60930634, 10.30931091], [79.60930634, 10.30903053], [79.60875702, 10.30903053], [79.60875702, 10.30875111], [79.6084671, 10.30875111], [79.6084671, 10.30846977], [79.60819244, 10.30847263], [79.60819244, 10.30819511], [79.60791779, 10.30819511], [79.60791779, 10.30791664], [79.60764313, 10.30792141], [79.60764313, 10.30764103], [79.60736084, 10.30764103], [79.60736084, 10.3073597], [79.60708618, 10.3073597], [79.60708618, 10.30708218], [79.60680389, 10.30708218], [79.60680389, 10.30680656], [79.60652924, 10.30681133], [79.60652924, 10.30653095], [79.60569, 10.30653095], [79.60569, 10.30624962], [79.60514069, 10.30624962], [79.60514069, 10.30653095], [79.6048584, 10.30652905], [79.6048584, 10.30847263], [79.60514069, 10.30846977], [79.60514069, 10.30931091], [79.60542297, 10.30931091], [79.60542297, 10.31015015], [79.60569, 10.31015015], [79.60569, 10.31042099], [79.60624695, 10.31041718], [79.60624695, 10.31069469], [79.60736084, 10.31069469], [79.60736084, 10.31097317], [79.60764313, 10.31097126], [79.60764313, 10.31125069], [79.60875702, 10.31125069]]], [[[79.61875153, 10.30875111], [79.61875153, 10.30847263], [79.62041473, 10.30847263], [79.62041473, 10.30819511], [79.62097168, 10.30819511], [79.62097168, 10.30791664], [79.62124634, 10.30792141], [79.62124634, 10.3073597], [79.62097168, 10.3073597], [79.62097168, 10.30680656], [79.62069702, 10.30681133], [79.62069702, 10.30653095], [79.62014008, 10.30653095], [79.62014008, 10.30624962], [79.61930847, 10.30624962], [79.61930847, 10.30764103], [79.61875153, 10.30764103], [79.61875153, 10.3073597], [79.61846924, 10.3073597], [79.61846924, 10.30708218], [79.61819458, 10.30708218], [79.61819458, 10.30680656], [79.61791992, 10.30681133], [79.61791992, 10.30653095], [79.61624908, 10.30653095], [79.61624908, 10.30792141], [79.61597443, 10.30791664], [79.61597443, 10.30819511], [79.61680603, 10.30819511], [79.61680603, 10.30847263], [79.61736298, 10.30847263], [79.61736298, 10.30875111], [79.61875153, 10.30875111]]], [[[79.63153076, 10.30875111], [79.63153076, 10.30819511], [79.63180542, 10.30819511], [79.63180542, 10.3073597], [79.63153076, 10.3073597], [79.63153076, 10.30680656], [79.63069153, 10.30681133], [79.63069153, 10.30653095], [79.62902832, 10.30653095], [79.62902832, 10.30681133], [79.62791443, 10.30680656], [79.62791443, 10.30819511], [79.62847137, 10.30819511], [79.62847137, 10.30847263], [79.62930298, 10.30847263], [79.62930298, 10.30875111], [79.63153076, 10.30875111]]], [[[79.69597626, 10.32125187], [79.69597626, 10.32097054], [79.69652557, 10.32097054], [79.69652557, 10.32069588], [79.69680786, 10.32069302], [79.69680786, 10.32041836], [79.69735718, 10.32042027], [79.69735718, 10.32014179], [79.69790649, 10.32014179], [79.69790649, 10.31986141], [79.69819641, 10.31986141], [79.69819641, 10.31958294], [79.69875336, 10.31958294], [79.69875336, 10.31930542], [79.69930267, 10.31931019], [79.69930267, 10.31902027], [79.69985962, 10.31902695], [79.69985962, 10.31874943], [79.70014191, 10.31874943], [79.70014191, 10.31847095], [79.70069122, 10.31847095], [79.70069122, 10.31819534], [79.70097351, 10.31819534], [79.70097351, 10.31791687], [79.70124817, 10.31791973], [79.70124817, 10.31736088], [79.70153046, 10.31736088], [79.70153046, 10.31708336], [79.70180511, 10.31708336], [79.70180511, 10.31680489], [79.70207977, 10.31680965], [79.70207977, 10.31624889], [79.70236206, 10.31624889], [79.70236206, 10.31597328], [79.70263672, 10.31597328], [79.70263672, 10.31569481], [79.70847321, 10.31569481], [79.70847321, 10.31597328], [79.71013641, 10.31597328], [79.71013641, 10.31624889], [79.7123642, 10.31624889], [79.71235657, 10.31596184], [79.71291351, 10.31597328], [79.71291351, 10.31569481], [79.7131958, 10.31569481], [79.7131958, 10.31541729], [79.71375275, 10.3154192], [79.71375275, 10.31514072], [79.71652985, 10.31514072], [79.71652985, 10.31431198], [79.71624756, 10.31431198], [79.71624756, 10.31264114], [79.7159729, 10.31264114], [79.7159729, 10.31153107], [79.71569824, 10.31153107], [79.71569824, 10.31125069], [79.71541595, 10.31125069], [79.71541595, 10.31097126], [79.71485901, 10.31097317], [79.71485901, 10.31069469], [79.71404266, 10.31069469], [79.71375275, 10.31069469], [79.71375275, 10.31097317], [79.7131958, 10.31097317], [79.7131958, 10.31152916], [79.71291351, 10.31152916], [79.71291351, 10.31174088], [79.71291351, 10.31236076], [79.71263885, 10.31236076], [79.71263885, 10.31347084], [79.71235657, 10.31347084], [79.71235657, 10.31403065], [79.71180725, 10.31403065], [79.71180725, 10.31431198], [79.71125031, 10.31430531], [79.71125031, 10.31458282], [79.71097565, 10.31458282], [79.71097565, 10.31430531], [79.71069336, 10.31431198], [79.71069336, 10.31379032], [79.71069336, 10.31347084], [79.7104187, 10.31347084], [79.7104187, 10.31291676], [79.71013641, 10.31292152], [79.71013641, 10.31264114], [79.7095871, 10.31263924], [79.7095871, 10.31319523], [79.70929718, 10.31319046], [79.70930481, 10.31347084], [79.70903015, 10.31347084], [79.70903015, 10.31402016], [79.7076416, 10.31403065], [79.7076416, 10.31375122], [79.70735931, 10.31375122], [79.70735931, 10.31357098], [79.70735931, 10.31347084], [79.70697021, 10.31347084], [79.70680237, 10.31347084], [79.70680237, 10.31319523], [79.70652771, 10.31319523], [79.70652771, 10.31291676], [79.70318604, 10.31292152], [79.70318604, 10.31264114], [79.70207977, 10.31264114], [79.70207977, 10.31235886], [79.70069122, 10.31236076], [79.70069122, 10.31208324], [79.69736481, 10.31208324], [79.69736481, 10.31236076], [79.69680786, 10.31235886], [79.69680786, 10.31264114], [79.6965332, 10.31264114], [79.6965332, 10.31292152], [79.69596863, 10.31291676], [79.69596863, 10.31319523], [79.69568634, 10.31319046], [79.69569397, 10.31347084], [79.69513702, 10.31347084], [79.69513702, 10.31375122], [79.69290924, 10.31375122], [79.69290924, 10.31403065], [79.69264221, 10.31403065], [79.69264221, 10.31431198], [79.69208527, 10.31430531], [79.69208527, 10.31458282], [79.69152832, 10.31458282], [79.69152832, 10.3148613], [79.69124603, 10.3148613], [79.69124603, 10.31514072], [79.69069672, 10.31514072], [79.69069672, 10.3154192], [79.69041443, 10.31541729], [79.69041443, 10.31574059], [79.69041443, 10.31597328], [79.69013977, 10.31596184], [79.69013977, 10.31652927], [79.68984985, 10.31652927], [79.68984985, 10.31680965], [79.68958282, 10.31680489], [79.68958282, 10.31736088], [79.68930817, 10.31736088], [79.68930817, 10.31791973], [79.68902588, 10.31791687], [79.68902588, 10.31847095], [79.68875122, 10.31847095], [79.68875122, 10.31874943], [79.69069672, 10.31874943], [79.69069672, 10.31902695], [79.69264221, 10.31902027], [79.69264221, 10.31931019], [79.69291687, 10.31930542], [79.69291687, 10.31958294], [79.69347382, 10.31958294], [79.69347382, 10.31986141], [79.69374847, 10.31986141], [79.69374847, 10.32014179], [79.69431305, 10.32014179], [79.69431305, 10.32042027], [79.69458008, 10.32041836], [79.69458008, 10.32069302], [79.69513702, 10.32069588], [79.69513702, 10.32097054], [79.69541931, 10.32097054], [79.69541931, 10.32125187], [79.69597626, 10.32125187]]], [[[79.62568665, 10.34375095], [79.62568665, 10.34347057], [79.62680817, 10.34347343], [79.62680817, 10.34319305], [79.62708282, 10.34319305], [79.62708282, 10.34291744], [79.62763977, 10.34291935], [79.62763977, 10.34264088], [79.6279068, 10.34264088], [79.6279068, 10.34236145], [79.62847137, 10.34236145], [79.62847137, 10.34208298], [79.62875366, 10.34208298], [79.62875366, 10.34125137], [79.62847137, 10.34125137], [79.62847137, 10.34013939], [79.62819672, 10.34013939], [79.62819672, 10.33875084], [79.62847137, 10.33875084], [79.62847137, 10.33819008], [79.62875366, 10.33819485], [79.62875366, 10.33791733], [79.62902832, 10.33791924], [79.62902832, 10.33736134], [79.62875366, 10.33736134], [79.62875366, 10.33708286], [79.62819672, 10.33708858], [79.62819672, 10.33681107], [79.62708282, 10.33680534], [79.62708282, 10.33736134], [79.62680054, 10.33736134], [79.62680054, 10.33791924], [79.62625122, 10.33791733], [79.62625122, 10.33819485], [79.62569427, 10.33819485], [79.62569427, 10.33847332], [79.62541962, 10.33847141], [79.62541962, 10.33875084], [79.62486267, 10.33875084], [79.62486267, 10.34069538], [79.62513733, 10.34069538], [79.62513733, 10.34125137], [79.62486267, 10.34125137], [79.62486267, 10.34236145], [79.62513733, 10.34236145], [79.62513733, 10.34319305], [79.62541962, 10.34319305], [79.62541962, 10.34347343], [79.62513733, 10.34347057], [79.62513733, 10.34375095], [79.62568665, 10.34375095]]], [[[79.63208008, 10.33319378], [79.63208008, 10.33291626], [79.63236237, 10.33292103], [79.63236237, 10.33264065], [79.63263702, 10.33264065], [79.63263702, 10.33236027], [79.63375092, 10.33236027], [79.63375092, 10.33180428], [79.63346863, 10.33181095], [79.63346863, 10.33096123], [79.63319397, 10.33097172], [79.63319397, 10.33041573], [79.63291931, 10.33042145], [79.63291931, 10.32985973], [79.63263702, 10.32985973], [79.63263702, 10.32958412], [79.63236237, 10.32958412], [79.63236237, 10.32902813], [79.63208008, 10.32903004], [79.63208008, 10.32874966], [79.63181305, 10.32874966], [79.63181305, 10.32847023], [79.63153076, 10.32847214], [79.63153076, 10.32791805], [79.63124847, 10.32792091], [79.63124847, 10.32736015], [79.63069153, 10.32736206], [79.63069153, 10.32708359], [79.62930298, 10.32708359], [79.62930298, 10.32680607], [79.62902832, 10.32681274], [79.62902832, 10.32653046], [79.62874603, 10.32653046], [79.62874603, 10.32625008], [79.62847137, 10.32625008], [79.62847137, 10.3259697], [79.62763977, 10.3259697], [79.62763977, 10.32625008], [79.62735748, 10.32625008], [79.62735748, 10.32708359], [79.62763977, 10.32708359], [79.62763977, 10.32736206], [79.6279068, 10.32736015], [79.6279068, 10.32763958], [79.62819672, 10.32763958], [79.62819672, 10.32792091], [79.62735748, 10.32791805], [79.62735748, 10.32847214], [79.62763977, 10.32847023], [79.62763977, 10.32903004], [79.6279068, 10.32903004], [79.6279068, 10.33042145], [79.62819672, 10.33041573], [79.62819672, 10.3306942], [79.62902832, 10.3306942], [79.62902832, 10.33041573], [79.62958527, 10.33041573], [79.62958527, 10.3306942], [79.62985992, 10.3306942], [79.62985992, 10.33097172], [79.63041687, 10.33097172], [79.63041687, 10.33125019], [79.63069153, 10.33125019], [79.63069153, 10.33153057], [79.63097382, 10.33152771], [79.63097382, 10.3320837], [79.63124847, 10.33208179], [79.63124847, 10.33264065], [79.63153076, 10.33263779], [79.63153076, 10.33319378], [79.63208008, 10.33319378]]], [[[79.74597168, 10.27735996], [79.7454071, 10.27735996], [79.7454071, 10.27764034], [79.74514008, 10.27764034], [79.74514008, 10.27792072], [79.74541473, 10.27791595], [79.74541473, 10.27819443], [79.74569702, 10.27819443], [79.74569702, 10.27847195], [79.74597168, 10.27847004], [79.74597168, 10.2790308], [79.74624634, 10.2790308], [79.74624634, 10.27931118], [79.74652863, 10.27930737], [79.74652863, 10.27958202], [79.74764252, 10.27958202], [79.74764252, 10.27930737], [79.74791718, 10.27931118], [79.74791718, 10.2790308], [79.74846649, 10.2790308], [79.74846649, 10.27875042], [79.74903107, 10.27875042], [79.74903107, 10.27847195], [79.74958038, 10.27847195], [79.74958038, 10.27819443], [79.74986267, 10.27819443], [79.74986267, 10.27791595], [79.75041962, 10.27792072], [79.75041962, 10.27625179], [79.75096893, 10.27625179], [79.75096893, 10.27597046], [79.75180817, 10.27597237], [79.75180817, 10.27569389], [79.75235748, 10.27569389], [79.75235748, 10.27541637], [79.75569153, 10.27541637], [79.75569153, 10.27597237], [79.75541687, 10.27597237], [79.75541687, 10.27708435], [79.75514221, 10.27707958], [79.75514221, 10.27764034], [79.75235748, 10.27764034], [79.75235748, 10.27792072], [79.75208282, 10.27791595], [79.75208282, 10.27819443], [79.75152588, 10.27819443], [79.75152588, 10.27847195], [79.75125122, 10.27847195], [79.75125122, 10.27875042], [79.75096893, 10.27875042], [79.75096893, 10.2790308], [79.75068665, 10.2790308], [79.75068665, 10.27931118], [79.75013733, 10.27930737], [79.75013733, 10.27958202], [79.74986267, 10.27958202], [79.74986267, 10.27985954], [79.74931335, 10.27985096], [79.74931335, 10.28014088], [79.74903107, 10.28014088], [79.74903107, 10.28042126], [79.74847412, 10.28041553], [79.74847412, 10.28069496], [79.74819183, 10.28069496], [79.74819183, 10.28097343], [79.74764252, 10.28096962], [79.74764252, 10.28153133], [79.74736023, 10.28152561], [79.74736023, 10.28236103], [79.74708557, 10.28236103], [79.74708557, 10.28291702], [79.74736023, 10.28291702], [79.74736023, 10.28319454], [79.74791718, 10.28319454], [79.74791718, 10.28347301], [79.74819183, 10.28347111], [79.74819183, 10.28375053], [79.74874878, 10.28375053], [79.74874878, 10.28403091], [79.74958038, 10.28403091], [79.74958038, 10.28347111], [79.74986267, 10.28347301], [79.74986267, 10.28319454], [79.7501297, 10.28318977], [79.7501297, 10.28375053], [79.75041962, 10.28375053], [79.75041962, 10.28430939], [79.75069427, 10.28430462], [79.75069427, 10.28486061], [79.75096893, 10.28486061], [79.75096893, 10.28542137], [79.75125122, 10.28543091], [79.75125122, 10.28598022], [79.75096893, 10.28598022], [79.75096893, 10.28653145], [79.75068665, 10.28653145], [79.75068665, 10.28681183], [79.75041962, 10.28680515], [79.75041962, 10.28708267], [79.7501297, 10.2870779], [79.7501297, 10.28764057], [79.74986267, 10.28764057], [79.74986267, 10.28792191], [79.74958038, 10.28791714], [79.74958038, 10.28819466], [79.74931335, 10.28819084], [79.74931335, 10.28875065], [79.74903107, 10.28875065], [79.74903107, 10.28904057], [79.74958038, 10.28904057], [79.74958038, 10.28931046], [79.75013733, 10.28930473], [79.75013733, 10.28958321], [79.75041962, 10.28958321], [79.75041962, 10.28986073], [79.75096893, 10.28986073], [79.75096893, 10.2901392], [79.75208282, 10.2901392], [79.75208282, 10.28986073], [79.75235748, 10.28986073], [79.75235748, 10.28958321], [79.75263977, 10.28958321], [79.75263977, 10.28902721], [79.75289917, 10.28904057], [79.75289917, 10.28875065], [79.75318909, 10.28875065], [79.75318909, 10.28847122], [79.75374603, 10.28847122], [79.75374603, 10.28904057], [79.75402832, 10.28902721], [79.75402832, 10.28958321], [79.75430298, 10.2895813], [79.75430298, 10.2901392], [79.75875092, 10.2901392], [79.75875092, 10.2895813], [79.75902557, 10.28958321], [79.75902557, 10.28902721], [79.75932312, 10.28904057], [79.75932312, 10.28875065], [79.75958252, 10.28875065], [79.75958252, 10.28819084], [79.75986481, 10.28819466], [79.75986481, 10.28791714], [79.76013947, 10.28792191], [79.76013947, 10.28736115], [79.76041412, 10.28736115], [79.76041412, 10.28680515], [79.76069641, 10.28681183], [79.76069641, 10.28653145], [79.76040649, 10.28653145], [79.76040649, 10.28625107], [79.76013947, 10.28625107], [79.76013947, 10.28598022], [79.75985718, 10.28598022], [79.75985718, 10.28569031], [79.75958252, 10.28569508], [79.75958252, 10.2854166], [79.75932312, 10.28542137], [79.75932312, 10.28514099], [79.7590332, 10.28514099], [79.7590332, 10.28486061], [79.75875092, 10.28486061], [79.75875092, 10.28458309], [79.75819397, 10.28458309], [79.75819397, 10.28430462], [79.75791931, 10.28430939], [79.75791931, 10.28403091], [79.75958252, 10.28403091], [79.75958252, 10.28375053], [79.75985718, 10.28375053], [79.75985718, 10.28318977], [79.76013947, 10.28319454], [79.76013947, 10.28291702], [79.76041412, 10.28291702], [79.76041412, 10.28236103], [79.76069641, 10.28236103], [79.76069641, 10.28291702], [79.76097107, 10.28291702], [79.76097107, 10.28347301], [79.76125336, 10.28347111], [79.76125336, 10.28375053], [79.76152802, 10.28375053], [79.76152802, 10.28430939], [79.76180267, 10.28430462], [79.76180267, 10.28458309], [79.7620697, 10.28458023], [79.7620697, 10.28514099], [79.76235962, 10.28513908], [79.76235962, 10.28569508], [79.76264191, 10.28569031], [79.76264191, 10.28598022], [79.76291656, 10.28598022], [79.76291656, 10.28653145], [79.76319122, 10.28652668], [79.76319122, 10.28708267], [79.76680756, 10.28708267], [79.76680756, 10.28736115], [79.76763916, 10.28736115], [79.76763916, 10.28764057], [79.76847076, 10.28764057], [79.76847076, 10.28792191], [79.76985931, 10.28792191], [79.76985931, 10.28764057], [79.77041626, 10.28764057], [79.77041626, 10.28736115], [79.77069092, 10.28736115], [79.77069092, 10.28708267], [79.77124786, 10.28708267], [79.77124786, 10.28569508], [79.77153015, 10.28569508], [79.77153015, 10.28430462], [79.77347565, 10.28430462], [79.77347565, 10.28486061], [79.77375031, 10.28486061], [79.77375031, 10.28569508], [79.77625275, 10.28569508], [79.77625275, 10.2854166], [79.7765274, 10.28542137], [79.7765274, 10.28514099], [79.77680206, 10.28514099], [79.77680206, 10.28486061], [79.77708435, 10.28486061], [79.77708435, 10.28458309], [79.77735901, 10.28458309], [79.77735901, 10.28430462], [79.7776413, 10.28430939], [79.7776413, 10.28403091], [79.77791595, 10.28403091], [79.77791595, 10.28375053], [79.77819061, 10.28375053], [79.77819824, 10.28347111], [79.7784729, 10.28347301], [79.7784729, 10.28291702], [79.77874756, 10.28291702], [79.77874756, 10.28180695], [79.77902985, 10.28181076], [79.77902985, 10.28153133], [79.78098297, 10.28153133], [79.78098297, 10.28181076], [79.78347015, 10.28181076], [79.78347015, 10.28069019], [79.7848587, 10.28069496], [79.7848587, 10.28097343], [79.78514099, 10.28096962], [79.78514099, 10.28153133], [79.78542328, 10.28153133], [79.78542328, 10.28181076], [79.78569794, 10.28180695], [79.78569794, 10.28208256], [79.7859726, 10.2820797], [79.7859726, 10.28264141], [79.78624725, 10.28263855], [79.78624725, 10.28291702], [79.78652954, 10.28291702], [79.78652954, 10.28347301], [79.78679657, 10.28347111], [79.78679657, 10.28403091], [79.78652954, 10.28402901], [79.78652954, 10.28458309], [79.78626251, 10.28458023], [79.78626251, 10.28514099], [79.7859726, 10.28513908], [79.7859726, 10.28569508], [79.78569794, 10.28569031], [79.78569794, 10.28625107], [79.78542328, 10.28625107], [79.78542328, 10.28681183], [79.78514099, 10.28680515], [79.78514099, 10.28708267], [79.7848587, 10.28708267], [79.7848587, 10.28736115], [79.78457642, 10.28736115], [79.78457642, 10.28764057], [79.78430939, 10.28764057], [79.78430176, 10.28792191], [79.7840271, 10.28791714], [79.7840271, 10.28819466], [79.78347015, 10.28819466], [79.78347015, 10.28847313], [79.78320313, 10.28847122], [79.78320313, 10.28875065], [79.78291321, 10.28875065], [79.78291321, 10.28904057], [79.78263855, 10.28904057], [79.78263855, 10.28931046], [79.78236389, 10.28930473], [79.78236389, 10.28958321], [79.7820816, 10.28958321], [79.7820816, 10.28986073], [79.78180695, 10.28986073], [79.78180695, 10.2901392], [79.78151703, 10.2901392], [79.78151703, 10.29041958], [79.78125, 10.29041672], [79.78125, 10.29069328], [79.78097534, 10.29069328], [79.78097534, 10.2909708], [79.7804184, 10.29097271], [79.7804184, 10.29124928], [79.78012848, 10.29124928], [79.78012848, 10.29152966], [79.77986145, 10.29152966], [79.77986145, 10.29181004], [79.77958679, 10.29180527], [79.77958679, 10.29208279], [79.77902985, 10.29208279], [79.77902985, 10.29236126], [79.7784729, 10.29236126], [79.7784729, 10.29264164], [79.77791595, 10.29264164], [79.77791595, 10.29292202], [79.77735901, 10.29291534], [79.77735901, 10.29319572], [79.77708435, 10.29319572], [79.77708435, 10.29347134], [79.7765274, 10.29347134], [79.7765274, 10.29374886], [79.77597046, 10.29374886], [79.77597046, 10.29403019], [79.77540588, 10.29403019], [79.77540588, 10.29430962], [79.7748642, 10.2943058], [79.7748642, 10.29458427], [79.77430725, 10.29458427], [79.77430725, 10.29486179], [79.7740097, 10.29485035], [79.7740097, 10.29514027], [79.77348328, 10.29514027], [79.77348328, 10.29541969], [79.77319336, 10.29541779], [79.77319336, 10.29569435], [79.77263641, 10.29569435], [79.77263641, 10.29597187], [79.7720871, 10.29597187], [79.7720871, 10.29625034], [79.77179718, 10.29625034], [79.77179718, 10.29652977], [79.77126312, 10.29652977], [79.77126312, 10.29681015], [79.77069092, 10.29680634], [79.77069092, 10.29708385], [79.77041626, 10.29708385], [79.77041626, 10.29736233], [79.76985931, 10.29736042], [79.76985931, 10.29763985], [79.76930237, 10.29763985], [79.76930237, 10.29792023], [79.76875305, 10.29791641], [79.76875305, 10.29819584], [79.76847076, 10.29819584], [79.76847076, 10.2984724], [79.76790619, 10.29846954], [79.76790619, 10.29874992], [79.76735687, 10.29874992], [79.76735687, 10.2990303], [79.76708221, 10.2990303], [79.76708221, 10.29931068], [79.76652527, 10.29930592], [79.76652527, 10.29958439], [79.76597595, 10.29958439], [79.76597595, 10.29986191], [79.76568604, 10.29986191], [79.76568604, 10.30014038], [79.76512909, 10.30014038], [79.76512909, 10.30042267], [79.76457977, 10.30041599], [79.76457977, 10.30069447], [79.76431274, 10.3006916], [79.76431274, 10.30098057], [79.76374817, 10.30097198], [79.76374817, 10.30125046], [79.76346588, 10.30125046], [79.76346588, 10.30153275], [79.76319122, 10.30153275], [79.76319122, 10.30181122], [79.76291656, 10.30180645], [79.76291656, 10.30208206], [79.76264191, 10.30208015], [79.76264191, 10.30263996], [79.76235962, 10.30263996], [79.76235962, 10.3029213], [79.76208496, 10.30291557], [79.76208496, 10.30319405], [79.76180267, 10.30319405], [79.76180267, 10.30347157], [79.76152802, 10.30346966], [79.76152802, 10.30375004], [79.76125336, 10.30375004], [79.76125336, 10.30402756], [79.76097107, 10.30402088], [79.76097107, 10.3043108], [79.76069641, 10.30430603], [79.76069641, 10.30458355], [79.76040649, 10.30457973], [79.76040649, 10.30514145], [79.76013947, 10.30514145], [79.76013947, 10.30542088], [79.75986481, 10.30541611], [79.75986481, 10.30569363], [79.75958252, 10.30569363], [79.75958252, 10.3059721], [79.75932312, 10.30597019], [79.75932312, 10.30624962], [79.7590332, 10.30624962], [79.7590332, 10.30653095], [79.75875092, 10.30652905], [79.75875092, 10.30708218], [79.75846863, 10.30708027], [79.75846863, 10.30764103], [79.75818634, 10.30764103], [79.75818634, 10.30792141], [79.75791931, 10.30791664], [79.75791931, 10.30847263], [79.75763702, 10.30846977], [79.75763702, 10.30903053], [79.75736237, 10.30903053], [79.75736237, 10.30931091], [79.75763702, 10.30930519], [79.75763702, 10.30958271], [79.75819397, 10.30958271], [79.75819397, 10.30986118], [79.75846863, 10.30986118], [79.75846863, 10.31015015], [79.75819397, 10.3101387], [79.75819397, 10.31069469], [79.75791931, 10.31069469], [79.75791931, 10.31097317], [79.75763702, 10.31097126], [79.75763702, 10.31125069], [79.75736237, 10.31125069], [79.75736237, 10.3118124], [79.75708008, 10.31180477], [79.75708008, 10.31208324], [79.75986481, 10.31208324], [79.75986481, 10.31180477], [79.76013947, 10.3118124], [79.76013947, 10.31125069], [79.76040649, 10.31125069], [79.76040649, 10.31097126], [79.76125336, 10.31097317], [79.76125336, 10.31069469], [79.76208496, 10.31069469], [79.76208496, 10.31041718], [79.76264191, 10.31042099], [79.76264191, 10.31015015], [79.76291656, 10.31015015], [79.76291656, 10.30957985], [79.76319122, 10.30958271], [79.76319122, 10.30930519], [79.76346588, 10.30931091], [79.76346588, 10.30875111], [79.76374817, 10.30875111], [79.76374817, 10.30847263], [79.76403046, 10.30847263], [79.76403046, 10.30819511], [79.76430511, 10.30819511], [79.76430511, 10.30763817], [79.76457977, 10.30764103], [79.76457977, 10.3073597], [79.76486206, 10.3073597], [79.76486206, 10.30680656], [79.76512909, 10.30681133], [79.76512909, 10.30653095], [79.76568604, 10.30653095], [79.76568604, 10.30624962], [79.76597595, 10.30624962], [79.76597595, 10.30597019], [79.76652527, 10.3059721], [79.76652527, 10.30569363], [79.76708221, 10.30569363], [79.76708221, 10.30541611], [79.76735687, 10.30542088], [79.76735687, 10.30514145], [79.76763916, 10.30514145], [79.76763916, 10.30486012], [79.76791382, 10.30486012], [79.76790619, 10.30457973], [79.76819611, 10.30458355], [79.76819611, 10.30430603], [79.76847076, 10.3043108], [79.76847076, 10.30402088], [79.76875305, 10.30402756], [79.76875305, 10.30375004], [79.76930237, 10.30375004], [79.76930237, 10.30346966], [79.76985931, 10.30347157], [79.76985931, 10.30319405], [79.77069092, 10.30319405], [79.77069092, 10.30291557], [79.77126312, 10.3029213], [79.77126312, 10.30263996], [79.77179718, 10.30263996], [79.77179718, 10.30235958], [79.77236176, 10.30236244], [79.77236176, 10.30208206], [79.77319336, 10.30208206], [79.77319336, 10.30180645], [79.7756958, 10.30181122], [79.7756958, 10.30153275], [79.77735901, 10.30153275], [79.77735901, 10.30181122], [79.7784729, 10.30180645], [79.7784729, 10.30236244], [79.77819824, 10.30235958], [79.77819824, 10.30263996], [79.77513885, 10.30263996], [79.77513885, 10.3029213], [79.77458191, 10.30291557], [79.77458191, 10.30319405], [79.77430725, 10.30319405], [79.77430725, 10.30347157], [79.7740097, 10.30346966], [79.7740097, 10.30375004], [79.77347565, 10.30375004], [79.77347565, 10.30402756], [79.7729187, 10.30402088], [79.7729187, 10.3043108], [79.77236176, 10.30430603], [79.77236176, 10.30458355], [79.77180481, 10.30458355], [79.77180481, 10.30486012], [79.77126312, 10.30486012], [79.77126312, 10.30514145], [79.77041626, 10.30514145], [79.77041626, 10.30542088], [79.76985931, 10.30541611], [79.76985931, 10.30569363], [79.76930237, 10.30569363], [79.76930237, 10.3059721], [79.76875305, 10.30597019], [79.76875305, 10.30624962], [79.76818848, 10.30624962], [79.76818848, 10.30653095], [79.76763916, 10.30653095], [79.76763916, 10.30681133], [79.76625061, 10.30680656], [79.76625061, 10.30708218], [79.76597595, 10.30708027], [79.76597595, 10.30764103], [79.76568604, 10.30764103], [79.76568604, 10.30792141], [79.76541901, 10.30791664], [79.76541901, 10.30819511], [79.76513672, 10.30819511], [79.76513672, 10.30847263], [79.76486206, 10.30847263], [79.76486206, 10.30875111], [79.76457977, 10.30875111], [79.76457977, 10.30931091], [79.76430511, 10.30930519], [79.76430511, 10.30958271], [79.76403046, 10.30958271], [79.76403046, 10.30986118], [79.76374817, 10.30986118], [79.76374817, 10.31015015], [79.76346588, 10.31015015], [79.76346588, 10.31042099], [79.76319122, 10.31041718], [79.76319122, 10.31097317], [79.76291656, 10.31097126], [79.76291656, 10.31125069], [79.76264191, 10.31125069], [79.76264191, 10.31153107], [79.76235962, 10.31153107], [79.76235962, 10.3118124], [79.76208496, 10.31180477], [79.76208496, 10.31208324], [79.76180267, 10.31208134], [79.76180267, 10.31264114], [79.76152802, 10.31264114], [79.76152802, 10.31292152], [79.76125336, 10.31291676], [79.76125336, 10.31319523], [79.75930786, 10.31319523], [79.75930786, 10.31347084], [79.75763702, 10.31347084], [79.75763702, 10.31375122], [79.74986267, 10.31375122], [79.74986267, 10.31347084], [79.74375153, 10.31347084], [79.74375153, 10.31319523], [79.74319458, 10.31319523], [79.74319458, 10.31291676], [79.74291992, 10.31292152], [79.74291992, 10.31264114], [79.74236298, 10.31264114], [79.74236298, 10.31235886], [79.74180603, 10.31236076], [79.74180603, 10.31208324], [79.74097443, 10.31208324], [79.74097443, 10.31180477], [79.74041748, 10.3118124], [79.74041748, 10.31153107], [79.73958588, 10.31153107], [79.73958588, 10.31125069], [79.73902893, 10.31125069], [79.73902893, 10.31097126], [79.73819733, 10.31097317], [79.73819733, 10.31069469], [79.73764038, 10.31069469], [79.73764038, 10.31041718], [79.73430634, 10.31041718], [79.73430634, 10.31069469], [79.73236084, 10.31069469], [79.73236084, 10.31097317], [79.73014069, 10.31097126], [79.73014069, 10.31125069], [79.7298584, 10.31125069], [79.7298584, 10.31153107], [79.72957611, 10.31153107], [79.72957611, 10.3118124], [79.72902679, 10.31180477], [79.72902679, 10.31208324], [79.72875214, 10.31208324], [79.72875214, 10.31236076], [79.72846985, 10.31235886], [79.72846985, 10.31264114], [79.72820282, 10.31264114], [79.72820282, 10.31292152], [79.7279129, 10.31291676], [79.7279129, 10.31319523], [79.72763824, 10.31319523], [79.72763824, 10.31347084], [79.7270813, 10.31347084], [79.7270813, 10.31375122], [79.72680664, 10.31375122], [79.72680664, 10.31403065], [79.72651672, 10.31403065], [79.72651672, 10.31431198], [79.72624969, 10.31430531], [79.72624969, 10.31458282], [79.72597504, 10.31458282], [79.72597504, 10.3148613], [79.72541809, 10.3148613], [79.72541809, 10.31514072], [79.7251358, 10.31514072], [79.7251358, 10.3154192], [79.72486115, 10.31541729], [79.72486115, 10.31569481], [79.72458649, 10.31569481], [79.72458649, 10.31597328], [79.72429657, 10.31596184], [79.7243042, 10.31624889], [79.72374725, 10.31624889], [79.72374725, 10.31652927], [79.7234726, 10.31652927], [79.7234726, 10.31680965], [79.72319794, 10.31680489], [79.72319794, 10.31708336], [79.72291565, 10.31708336], [79.72291565, 10.31736088], [79.72264099, 10.31736088], [79.72264099, 10.31763935], [79.7223587, 10.31763935], [79.7223587, 10.31791973], [79.72180939, 10.31791687], [79.72180176, 10.31819534], [79.7215271, 10.31819534], [79.7215271, 10.31847095], [79.72125244, 10.31847095], [79.72125244, 10.31874943], [79.7206955, 10.31874943], [79.7206955, 10.31902695], [79.72014618, 10.31902027], [79.72014618, 10.31931019], [79.71930695, 10.31930542], [79.71930695, 10.31958294], [79.71875, 10.31958294], [79.71875, 10.31986141], [79.71819305, 10.31986141], [79.71819305, 10.32014179], [79.71707916, 10.32014179], [79.71707916, 10.32042027], [79.71624756, 10.32041836], [79.71624756, 10.32069302], [79.7151413, 10.32069588], [79.7151413, 10.32097054], [79.71430206, 10.32097054], [79.71430206, 10.32125187], [79.7131958, 10.32125187], [79.7131958, 10.32153034], [79.71263885, 10.32153034], [79.71263885, 10.32180977], [79.71208191, 10.32180977], [79.71208191, 10.32209015], [79.71151733, 10.32209015], [79.71152496, 10.32236195], [79.71069336, 10.32236195], [79.71069336, 10.32264042], [79.71013641, 10.32264042], [79.71013641, 10.32291985], [79.7095871, 10.32291794], [79.7095871, 10.32319355], [79.70903015, 10.32319355], [79.70903015, 10.32347202], [79.70847321, 10.32347202], [79.70847321, 10.32374954], [79.71151733, 10.32374954], [79.71151733, 10.32402992], [79.71180725, 10.32402802], [79.71180725, 10.32486153], [79.7104187, 10.32485962], [79.7104187, 10.32515144], [79.70874786, 10.32515144], [79.70874786, 10.32485962], [79.70819092, 10.32486153], [79.70819092, 10.32458401], [79.7076416, 10.32458401], [79.7076416, 10.32430553], [79.70707703, 10.3243103], [79.70707703, 10.32402992], [79.70652771, 10.32402992], [79.70652771, 10.32374954], [79.70597076, 10.32374954], [79.70597076, 10.32347202], [79.7040329, 10.32347202], [79.70402527, 10.32374954], [79.70291901, 10.32374954], [79.70291901, 10.32402992], [79.70181274, 10.32402992], [79.70181274, 10.3243103], [79.69985962, 10.32430553], [79.69985962, 10.32458401], [79.69763947, 10.32458401], [79.69763947, 10.32486153], [79.69568634, 10.32485962], [79.69568634, 10.32515144], [79.69374847, 10.32515144], [79.69374847, 10.32542038], [79.68708038, 10.32542038], [79.68708038, 10.32515144], [79.68653107, 10.32515144], [79.68653107, 10.32485962], [79.68569183, 10.32486153], [79.68569183, 10.32458401], [79.68514252, 10.32458401], [79.68514252, 10.32430553], [79.68430328, 10.3243103], [79.68430328, 10.32402992], [79.68374634, 10.32402992], [79.68374634, 10.32374954], [79.68264008, 10.32374954], [79.68264008, 10.32347202], [79.68152618, 10.32347202], [79.68152618, 10.32319355], [79.68041992, 10.32319355], [79.68041992, 10.32291794], [79.67930603, 10.32291985], [79.67930603, 10.32264042], [79.67903137, 10.32264042], [79.67903137, 10.32236195], [79.67874908, 10.32236195], [79.67874908, 10.32180595], [79.6784668, 10.32180977], [79.6784668, 10.32153034], [79.67819214, 10.32153034], [79.67819214, 10.32125187], [79.67790985, 10.32125187], [79.67790985, 10.32097054], [79.67680359, 10.32097054], [79.67680359, 10.32069588], [79.67597198, 10.32069302], [79.67597198, 10.32041836], [79.67487335, 10.32042027], [79.67487335, 10.32014179], [79.67402649, 10.32014179], [79.67402649, 10.31986141], [79.67292023, 10.31986141], [79.67292023, 10.31958294], [79.67208099, 10.31958294], [79.67208099, 10.31930542], [79.66041565, 10.31930542], [79.66041565, 10.31958294], [79.65875244, 10.31958294], [79.65875244, 10.31930542], [79.65820312, 10.31931019], [79.65820312, 10.31902027], [79.65791321, 10.31902695], [79.65791321, 10.31874943], [79.65652466, 10.31874943], [79.65652466, 10.31902695], [79.65569305, 10.31902027], [79.65569305, 10.31931019], [79.65513611, 10.31930542], [79.65513611, 10.31958294], [79.65125275, 10.31958294], [79.65125275, 10.31986141], [79.65040588, 10.31986141], [79.65040588, 10.32014179], [79.6470871, 10.32014179], [79.6470871, 10.31986141], [79.64653015, 10.31986141], [79.64653015, 10.31958294], [79.64597321, 10.31958294], [79.64597321, 10.31930542], [79.64541626, 10.31931019], [79.64541626, 10.31902027], [79.63930511, 10.31902695], [79.63930511, 10.31874943], [79.63903046, 10.31874943], [79.63903046, 10.31791687], [79.63764191, 10.31791687], [79.63764191, 10.31819534], [79.63699341, 10.31819344], [79.63652802, 10.31819057], [79.63652802, 10.32264042], [79.63625336, 10.32264042], [79.63625336, 10.32374954], [79.63652802, 10.32374954], [79.63652802, 10.32486153], [79.63680267, 10.32486153], [79.63680267, 10.3259716], [79.63708496, 10.3259716], [79.63708496, 10.32708359], [79.63735962, 10.32708168], [79.63735962, 10.32792091], [79.63708496, 10.32791805], [79.63708496, 10.32847214], [79.63680267, 10.32847023], [79.63680267, 10.32903004], [79.63652802, 10.32902813], [79.63652802, 10.32958412], [79.63625336, 10.32958031], [79.63625336, 10.33181095], [79.63597107, 10.33180428], [79.63597107, 10.33236027], [79.63569641, 10.33236027], [79.63569641, 10.33292103], [79.63540649, 10.33292103], [79.63540649, 10.33375072], [79.63513947, 10.33375072], [79.63513947, 10.33542061], [79.63485718, 10.33542061], [79.63485718, 10.33485985], [79.63458252, 10.33485985], [79.63458252, 10.3340292], [79.63430786, 10.33403111], [79.63430786, 10.33375072], [79.63375092, 10.33375072], [79.63375092, 10.33403111], [79.63346863, 10.33403111], [79.63346863, 10.33431053], [79.63319397, 10.33430672], [79.63319397, 10.33458233], [79.63291931, 10.33458233], [79.63291931, 10.33485985], [79.63236237, 10.33485985], [79.63236237, 10.33514118], [79.63208008, 10.33514118], [79.63208008, 10.33542061], [79.63180542, 10.33541679], [79.63180542, 10.33569527], [79.63153076, 10.33569527], [79.63153076, 10.33597279], [79.63124847, 10.33596992], [79.63124847, 10.33791924], [79.63096619, 10.33791924], [79.63097382, 10.33986092], [79.63069153, 10.33986092], [79.63069153, 10.34013939], [79.63041687, 10.34013939], [79.63041687, 10.34069538], [79.63014221, 10.34069538], [79.63014221, 10.34097099], [79.62985992, 10.34097099], [79.62985992, 10.34125137], [79.6295929, 10.34125137], [79.6295929, 10.34152889], [79.62930298, 10.34152699], [79.62930298, 10.34208298], [79.62902832, 10.34208298], [79.62902832, 10.34236145], [79.62874603, 10.34236145], [79.62874603, 10.34291935], [79.62847137, 10.34291744], [79.62847137, 10.34347343], [79.62819672, 10.34347057], [79.62819672, 10.34402943], [79.6279068, 10.34402943], [79.62791443, 10.34486103], [79.62763977, 10.34486103], [79.62763977, 10.34542179], [79.62735748, 10.34542179], [79.62735748, 10.34764194], [79.62708282, 10.34764004], [79.62708282, 10.3498621], [79.62735748, 10.34985924], [79.62735748, 10.35013962], [79.62763977, 10.35013962], [79.62763977, 10.3506937], [79.62791443, 10.3506937], [79.62791443, 10.35097218], [79.62819672, 10.35096931], [79.62819672, 10.35124969], [79.62847137, 10.35124969], [79.62847137, 10.35181046], [79.62875366, 10.35180569], [79.62875366, 10.35208416], [79.62902832, 10.35208416], [79.62902832, 10.35235977], [79.62930298, 10.35235977], [79.62930298, 10.35291958], [79.62958527, 10.35291576], [79.62958527, 10.35319424], [79.62930298, 10.35319424], [79.62930298, 10.35347176], [79.62902832, 10.35347176], [79.62902832, 10.35375023], [79.62874603, 10.35375023], [79.62874603, 10.35402966], [79.62847137, 10.35402966], [79.62847137, 10.35431099], [79.62819672, 10.35430622], [79.62819672, 10.35486221], [79.6279068, 10.35486031], [79.6279068, 10.35542107], [79.62763977, 10.35542107], [79.62763977, 10.35653019], [79.62735748, 10.35652828], [79.62735748, 10.35708427], [79.62763977, 10.35708046], [79.62763977, 10.35764027], [79.6279068, 10.35764027], [79.6279068, 10.35792065], [79.62819672, 10.35791588], [79.62819672, 10.35847187], [79.62847137, 10.35846996], [79.62847137, 10.35903072], [79.62874603, 10.35903072], [79.62874603, 10.3593111], [79.62902832, 10.35930634], [79.62902832, 10.35958195], [79.62930298, 10.35958195], [79.62930298, 10.35986042], [79.6295929, 10.35986042], [79.6295929, 10.3601408], [79.62985992, 10.3601408], [79.62985992, 10.36042118], [79.63014221, 10.36041641], [79.63014221, 10.36097336], [79.63041687, 10.36096954], [79.63041687, 10.36126041], [79.63069153, 10.36126041], [79.63069153, 10.36153126], [79.63096619, 10.36153126], [79.63096619, 10.36181068], [79.63124847, 10.36180687], [79.63124847, 10.36208153], [79.63153076, 10.36208153], [79.63153076, 10.36236095], [79.63096619, 10.36236095], [79.63096619, 10.36264133], [79.63041687, 10.36264133], [79.63041687, 10.36291885], [79.63014221, 10.36291695], [79.63014221, 10.36319542], [79.62985992, 10.36319542], [79.62985992, 10.36208153], [79.62930298, 10.36208153], [79.62930298, 10.36236095], [79.62847137, 10.36236095], [79.62847137, 10.36291885], [79.62763977, 10.36291885], [79.62763977, 10.36264133], [79.62708282, 10.36264133], [79.62708282, 10.36236095], [79.62680054, 10.36236095], [79.62680054, 10.36207962], [79.62625122, 10.36208153], [79.62625122, 10.36180687], [79.62596893, 10.36181068], [79.62596893, 10.36153126], [79.62568665, 10.36153126], [79.62568665, 10.36126041], [79.62541962, 10.36126041], [79.62541962, 10.36096954], [79.62513733, 10.36097336], [79.62513733, 10.36041641], [79.62486267, 10.36042118], [79.62486267, 10.35986042], [79.62458038, 10.35986042], [79.62458038, 10.35930634], [79.62431335, 10.3593111], [79.62431335, 10.35875034], [79.62403107, 10.35875034], [79.62403107, 10.35791588], [79.62431335, 10.35792065], [79.62431335, 10.35625172], [79.62458038, 10.35625172], [79.62458038, 10.35458183], [79.62486267, 10.35458374], [79.62486267, 10.35291576], [79.62513733, 10.35291958], [79.62513733, 10.35153008], [79.62486267, 10.35153008], [79.62486267, 10.35042], [79.62458038, 10.35042], [79.62458038, 10.35013962], [79.62403107, 10.35013962], [79.62403107, 10.34985924], [79.62374878, 10.3498621], [79.62374878, 10.34958363], [79.62347412, 10.34958363], [79.62347412, 10.34930611], [79.62291718, 10.34931946], [79.62291718, 10.34902954], [79.62264252, 10.34902954], [79.62264252, 10.34875202], [79.6220932, 10.34875202], [79.6220932, 10.34847069], [79.62124634, 10.34847069], [79.62124634, 10.34819317], [79.62180328, 10.34819317], [79.62180328, 10.34791756], [79.62236023, 10.34792042], [79.62236023, 10.34736156], [79.62208557, 10.34736156], [79.62208557, 10.34680462], [79.62180328, 10.34681034], [79.62180328, 10.34653187], [79.62152863, 10.34653187], [79.62152863, 10.34625244], [79.62180328, 10.34625244], [79.62180328, 10.34569073], [79.62124634, 10.34569454], [79.62124634, 10.34513855], [79.62097168, 10.34513855], [79.62097168, 10.34486103], [79.62069702, 10.34486103], [79.62069702, 10.34430504], [79.6204071, 10.34430981], [79.6204071, 10.34375095], [79.61985779, 10.34375095], [79.61985779, 10.34347057], [79.61930847, 10.34347343], [79.61930847, 10.34319305], [79.61569214, 10.34319305], [79.61569214, 10.34291744], [79.61486053, 10.34291935], [79.61486053, 10.34264088], [79.61402893, 10.34264088], [79.61402893, 10.34236145], [79.61319733, 10.34236145], [79.61319733, 10.34208298], [79.61235809, 10.34208298], [79.61235809, 10.34180546], [79.61152649, 10.34181023], [79.61152649, 10.34152889], [79.61042023, 10.34152889], [79.61042023, 10.34068966], [79.61069489, 10.34069538], [79.61069489, 10.34013939], [79.61235809, 10.34013939], [79.61235809, 10.33986092], [79.61264038, 10.33986092], [79.61264038, 10.3395834], [79.61374664, 10.3395834], [79.61374664, 10.34013939], [79.61402893, 10.34013939], [79.61402893, 10.34069538], [79.61430359, 10.34069538], [79.61430359, 10.34097099], [79.61486053, 10.34097099], [79.61486053, 10.34069538], [79.61597443, 10.34069538], [79.61597443, 10.33986092], [79.61624908, 10.33986092], [79.61624908, 10.33875084], [79.61653137, 10.33875084], [79.61653137, 10.33819008], [79.61708069, 10.33819485], [79.61708069, 10.33847332], [79.61736298, 10.33847141], [79.61736298, 10.33875084], [79.61763, 10.33875084], [79.61763, 10.3393116], [79.61791992, 10.33930492], [79.61791992, 10.33986092], [79.61819458, 10.33986092], [79.61819458, 10.34013939], [79.61846924, 10.34013939], [79.61846924, 10.34069538], [79.61875153, 10.34069538], [79.61875153, 10.34097099], [79.61930847, 10.34097099], [79.61930847, 10.34069538], [79.62069702, 10.34069538], [79.62069702, 10.33930492], [79.6204071, 10.3393116], [79.6204071, 10.33763885], [79.62069702, 10.33763885], [79.62069702, 10.33708286], [79.62097168, 10.33708858], [79.62097168, 10.33653069], [79.62124634, 10.33653069], [79.62124634, 10.33596992], [79.62152863, 10.33597279], [79.62152863, 10.33485985], [79.62180328, 10.33485985], [79.62180328, 10.3340292], [79.6220932, 10.33403111], [79.6220932, 10.33318996], [79.62180328, 10.33319378], [79.62180328, 10.3320837], [79.62152863, 10.3320837], [79.62152863, 10.33097172], [79.62124634, 10.33097172], [79.62124634, 10.33041573], [79.62097168, 10.33042145], [79.62097168, 10.33014011], [79.62069702, 10.33014011], [79.62069702, 10.32958031], [79.62041473, 10.32958412], [79.62041473, 10.32930565], [79.62014008, 10.32931137], [79.62014008, 10.32903004], [79.61985779, 10.32903004], [79.61985779, 10.32874966], [79.61958313, 10.32874966], [79.61958313, 10.32847023], [79.61930847, 10.32847214], [79.61930847, 10.32791805], [79.61902618, 10.32792091], [79.61902618, 10.32763958], [79.61875153, 10.32763958], [79.61875153, 10.32736015], [79.61846924, 10.32736206], [79.61846924, 10.32708359], [79.61819458, 10.32708359], [79.61819458, 10.32680607], [79.61791992, 10.32681274], [79.61791992, 10.32625008], [79.61763, 10.32625008], [79.61763, 10.3259697], [79.61736298, 10.3259716], [79.61736298, 10.32569408], [79.61708069, 10.32569408], [79.61708069, 10.32514], [79.61680603, 10.32515144], [79.61680603, 10.32457924], [79.61653137, 10.32458401], [79.61653137, 10.32374954], [79.61624908, 10.32374954], [79.61624908, 10.32291985], [79.61569214, 10.32291985], [79.61569214, 10.32264042], [79.61541748, 10.32264042], [79.61541748, 10.32209015], [79.61514282, 10.32209015], [79.61514282, 10.32153034], [79.61486053, 10.32153034], [79.61486053, 10.32069969], [79.61458588, 10.32069111], [79.61458588, 10.3201189], [79.61458588, 10.31986141], [79.61430359, 10.31986141], [79.61430359, 10.31930542], [79.61402893, 10.31931019], [79.61402893, 10.31874943], [79.61374664, 10.31874943], [79.61374664, 10.31791687], [79.61347198, 10.31791973], [79.61347198, 10.31736088], [79.61235809, 10.31736088], [79.61235809, 10.31708336], [79.61125183, 10.31708336], [79.61125183, 10.31680489], [79.61023712, 10.31680489], [79.60986328, 10.31680965], [79.60986328, 10.31652927], [79.60875702, 10.31652927], [79.60875702, 10.31624889], [79.6076355, 10.31624889], [79.6076355, 10.31597328], [79.60680389, 10.31597328], [79.60680389, 10.31569481], [79.60624695, 10.31569481], [79.60624695, 10.31541729], [79.60597229, 10.3154192], [79.60597229, 10.31514072], [79.60542297, 10.31514072], [79.60542297, 10.3148613], [79.60514069, 10.3148613], [79.60514069, 10.31458282], [79.6048584, 10.31458282], [79.6048584, 10.31430531], [79.60457611, 10.31431198], [79.60457611, 10.31403065], [79.60430908, 10.31403065], [79.60430908, 10.31375122], [79.60375214, 10.31375122], [79.60375214, 10.31347084], [79.60346985, 10.31347084], [79.60346985, 10.31319523], [79.60319519, 10.31319523], [79.60319519, 10.31291676], [79.6029129, 10.31292152], [79.6029129, 10.31264114], [79.60263062, 10.31264114], [79.60263062, 10.31235886], [79.6020813, 10.31236076], [79.6020813, 10.31208324], [79.60180664, 10.31208324], [79.60180664, 10.31180477], [79.60151672, 10.3118124], [79.60151672, 10.31153107], [79.60124969, 10.31153107], [79.60124969, 10.31125069], [79.60098267, 10.31125069], [79.60098267, 10.31097126], [79.60041809, 10.31097317], [79.60041809, 10.31069469], [79.6001358, 10.31069469], [79.6001358, 10.31041718], [79.59958649, 10.31042099], [79.59958649, 10.31015015], [79.59929657, 10.31015015], [79.59929657, 10.30986118], [79.59958649, 10.30986118], [79.59958649, 10.30958271], [79.59874725, 10.30958271], [79.59874725, 10.30930519], [79.59792328, 10.30931091], [79.59792328, 10.30903053], [79.59680176, 10.30903053], [79.59680176, 10.30875111], [79.59625244, 10.30875111], [79.59625244, 10.30931091], [79.59430695, 10.30931091], [79.59430695, 10.30903053], [79.59401703, 10.30903053], [79.59401703, 10.30875111], [79.58930206, 10.30875111], [79.58930206, 10.30903053], [79.5881958, 10.30903053], [79.5881958, 10.30931091], [79.58625031, 10.30930519], [79.58625031, 10.30958271], [79.5854187, 10.30958271], [79.5854187, 10.30986118], [79.58486176, 10.30986118], [79.58486176, 10.31015015], [79.58513641, 10.3101387], [79.58513641, 10.31069469], [79.5854187, 10.31068993], [79.5854187, 10.31125069], [79.58569336, 10.31125069], [79.58569336, 10.31153107], [79.58513641, 10.31153107], [79.58513641, 10.31125069], [79.58486176, 10.31125069], [79.58486176, 10.31097126], [79.5845871, 10.31097317], [79.5845871, 10.31069469], [79.58403015, 10.31069469], [79.58403015, 10.31041718], [79.58374786, 10.31042099], [79.58374786, 10.31015015], [79.58319092, 10.31015015], [79.58319092, 10.30986118], [79.58291626, 10.30986118], [79.58291626, 10.30958271], [79.5826416, 10.30958271], [79.5826416, 10.30930519], [79.58152008, 10.30931091], [79.58152008, 10.30903053], [79.58097076, 10.30903053], [79.58097076, 10.30875111], [79.57653046, 10.30875111], [79.57653046, 10.30903053], [79.57514191, 10.30903053], [79.57514191, 10.30931091], [79.57402802, 10.30930519], [79.57402802, 10.30958271], [79.57347107, 10.30958271], [79.57347107, 10.30986118], [79.57290649, 10.30986118], [79.57290649, 10.31015015], [79.57264709, 10.31015015], [79.57264709, 10.31042099], [79.57208252, 10.31041718], [79.57208252, 10.31069469], [79.57152557, 10.31069469], [79.57152557, 10.31041718], [79.56624603, 10.31042099], [79.56624603, 10.31015015], [79.56402588, 10.31015015], [79.56402588, 10.31042099], [79.56319427, 10.31041718], [79.56319427, 10.31069469], [79.56208038, 10.31069469], [79.56208038, 10.31097317], [79.56153107, 10.31097126], [79.56153107, 10.31125069], [79.56069183, 10.31125069], [79.56069183, 10.31153107], [79.56014252, 10.31153107], [79.56014252, 10.3118124], [79.55958557, 10.31180477], [79.55958557, 10.31208324], [79.55486298, 10.31208324], [79.55486298, 10.31236076], [79.55403137, 10.31235886], [79.55403137, 10.31264114], [79.5534668, 10.31264114], [79.5534668, 10.31292152], [79.55263519, 10.31291676], [79.55263519, 10.31319523], [79.55208588, 10.31319523], [79.55208588, 10.31347084], [79.55124664, 10.31347084], [79.55124664, 10.31375122], [79.55069733, 10.31375122], [79.55069733, 10.31347084], [79.55097198, 10.31347084], [79.55097198, 10.31291676], [79.55124664, 10.31292152], [79.55124664, 10.31235886], [79.55152893, 10.31236076], [79.55152893, 10.31208324], [79.55180359, 10.31208324], [79.55180359, 10.31180477], [79.55208588, 10.3118124], [79.55208588, 10.31153107], [79.55236053, 10.31153107], [79.55236053, 10.31125069], [79.55264282, 10.31125069], [79.55264282, 10.31097126], [79.55291748, 10.31097317], [79.55291748, 10.31069469], [79.55319214, 10.31069469], [79.55319214, 10.31041718], [79.55374908, 10.31042099], [79.55374908, 10.31015015], [79.55403137, 10.31015015], [79.55403137, 10.30986118], [79.55430603, 10.30986118], [79.55430603, 10.30958271], [79.55458069, 10.30958271], [79.55458069, 10.30930519], [79.55486298, 10.30931091], [79.55486298, 10.30903053], [79.55513763, 10.30903053], [79.55513763, 10.30875111], [79.55541992, 10.30875111], [79.55541992, 10.30847263], [79.55708313, 10.30847263], [79.55708313, 10.30819511], [79.55874634, 10.30819511], [79.55874634, 10.30791664], [79.56041718, 10.30792141], [79.56041718, 10.30764103], [79.56236267, 10.30764103], [79.56236267, 10.3073597], [79.56402588, 10.3073597], [79.56402588, 10.30708218], [79.56680298, 10.30708218], [79.56680298, 10.3073597], [79.56930542, 10.3073597], [79.56930542, 10.30708218], [79.57041931, 10.30708218], [79.57041931, 10.30680656], [79.57125092, 10.30681133], [79.57125092, 10.30653095], [79.57235718, 10.30653095], [79.57235718, 10.30624962], [79.57319641, 10.30624962], [79.57319641, 10.30514145], [79.57402802, 10.30514145], [79.57402802, 10.30486012], [79.57958221, 10.30486012], [79.57958221, 10.30458355], [79.5798645, 10.30458355], [79.5798645, 10.30430603], [79.58013916, 10.3043108], [79.58013916, 10.30402088], [79.58041382, 10.30402756], [79.58041382, 10.30375004], [79.58097076, 10.30375004], [79.58097076, 10.30346966], [79.58180237, 10.30347157], [79.58180237, 10.30319405], [79.58235931, 10.30319405], [79.58235931, 10.30291557], [79.58486176, 10.30291557], [79.58486176, 10.30319405], [79.58513641, 10.30319405], [79.58513641, 10.30347157], [79.5854187, 10.30346966], [79.5854187, 10.30375004], [79.58597565, 10.30375004], [79.58597565, 10.30402756], [79.58625031, 10.30402088], [79.58625031, 10.3043108], [79.58652496, 10.30430603], [79.58652496, 10.30458355], [79.58680725, 10.30458355], [79.58680725, 10.30486012], [79.58763885, 10.30486012], [79.58763885, 10.30402756], [79.58791351, 10.30402756], [79.58791351, 10.30291557], [79.5881958, 10.3029213], [79.5881958, 10.30235958], [79.58847046, 10.30236244], [79.58847046, 10.30208206], [79.58958435, 10.30208206], [79.58958435, 10.30236244], [79.58930206, 10.30235958], [79.58930206, 10.3029213], [79.5890274, 10.30291557], [79.5890274, 10.30319405], [79.59124756, 10.30319405], [79.59124756, 10.30291557], [79.59348297, 10.3029213], [79.59348297, 10.30235958], [79.59319305, 10.30236244], [79.59319305, 10.30180645], [79.5929184, 10.30181122], [79.5929184, 10.30125046], [79.59401703, 10.30125046], [79.59401703, 10.30263996], [79.59570313, 10.30263996], [79.59570313, 10.30235958], [79.59708405, 10.30236244], [79.59708405, 10.30208206], [79.59819794, 10.30208206], [79.59819794, 10.30180645], [79.59958649, 10.30181122], [79.59958649, 10.30153275], [79.60069275, 10.30153275], [79.60069275, 10.30125046], [79.6020813, 10.30125046], [79.6020813, 10.30098057], [79.60320282, 10.30098057], [79.60320282, 10.3006916], [79.6029129, 10.30069447], [79.6029129, 10.30013847], [79.60263062, 10.30014038], [79.60263062, 10.29986191], [79.60430908, 10.29986191], [79.60430908, 10.29958439], [79.60597229, 10.29958439], [79.60597229, 10.29930592], [79.60736084, 10.29930592], [79.60736084, 10.29986191], [79.60847473, 10.29986191], [79.6084671, 10.29957867], [79.60902405, 10.29958439], [79.60902405, 10.29930592], [79.60986328, 10.29931068], [79.60986328, 10.2990303], [79.61624908, 10.2990303], [79.61624908, 10.29874992], [79.6159668, 10.29874992], [79.6159668, 10.29846954], [79.61569214, 10.2984724], [79.61569214, 10.29819584], [79.61541748, 10.29819584], [79.61541748, 10.29791641], [79.61514282, 10.29792023], [79.61514282, 10.29763985], [79.61486053, 10.29763985], [79.61486053, 10.29736042], [79.61624908, 10.29736042], [79.61624908, 10.29763985], [79.61653137, 10.29763985], [79.61653137, 10.29819584], [79.61680603, 10.29819107], [79.61680603, 10.29874992], [79.61985779, 10.29874992], [79.61985779, 10.29846954], [79.61958313, 10.2984724], [79.61958313, 10.29791641], [79.61930847, 10.29792023], [79.61930847, 10.29763985], [79.62014008, 10.29763985], [79.62014008, 10.29736042], [79.62124634, 10.29736233], [79.62124634, 10.29708385], [79.62180328, 10.29708385], [79.62180328, 10.29680634], [79.62264252, 10.29681015], [79.62264252, 10.29652977], [79.62319183, 10.29652977], [79.62319183, 10.29625034], [79.62403107, 10.29625034], [79.62403107, 10.29597187], [79.62458038, 10.29597187], [79.62458038, 10.29569435], [79.62541962, 10.29569435], [79.62541962, 10.29541779], [79.62763977, 10.29541969], [79.62763977, 10.29514027], [79.62985992, 10.29514027], [79.62985992, 10.29485035], [79.63208008, 10.29485035], [79.63208008, 10.29514027], [79.63236237, 10.29514027], [79.63236237, 10.29541969], [79.63263702, 10.29541779], [79.63263702, 10.29569435], [79.63375092, 10.29569435], [79.63375092, 10.29541779], [79.63430786, 10.29541969], [79.63430786, 10.29514027], [79.63485718, 10.29514027], [79.63485718, 10.29485035], [79.63569641, 10.29486179], [79.63569641, 10.29458427], [79.63625336, 10.29458427], [79.63625336, 10.2943058], [79.63708496, 10.2943058], [79.63708496, 10.29458427], [79.63764191, 10.29458427], [79.63764191, 10.29486179], [79.63874817, 10.29486179], [79.63874817, 10.29458427], [79.63903046, 10.29458427], [79.63903046, 10.2943058], [79.63931274, 10.29430962], [79.63931274, 10.29403019], [79.64457703, 10.29403019], [79.64457703, 10.29374886], [79.64485931, 10.29374886], [79.64485931, 10.29319572], [79.6451416, 10.29319572], [79.6451416, 10.29263878], [79.64569092, 10.29264164], [79.64569092, 10.29236126], [79.65180206, 10.29236126], [79.65180206, 10.29264164], [79.65429688, 10.29264164], [79.65429688, 10.29236126], [79.65625, 10.29236126], [79.65625, 10.29208279], [79.65680695, 10.29208279], [79.65680695, 10.29180527], [79.65735626, 10.29181004], [79.65735626, 10.29152966], [79.65791321, 10.29152966], [79.65791321, 10.29124928], [79.65847015, 10.29124928], [79.65847015, 10.2909708], [79.6590271, 10.2909708], [79.6590271, 10.29069328], [79.65958405, 10.29069328], [79.65958405, 10.29041672], [79.66014099, 10.29041958], [79.66014099, 10.2901392], [79.66069794, 10.2901392], [79.66069794, 10.28986073], [79.66124725, 10.28986073], [79.66124725, 10.28958321], [79.6618042, 10.28958321], [79.6618042, 10.28930473], [79.66236115, 10.28931046], [79.66236115, 10.28904057], [79.66319275, 10.28904057], [79.66319275, 10.28931046], [79.66430664, 10.28931046], [79.66430664, 10.28904057], [79.66513824, 10.28902721], [79.66513824, 10.28958321], [79.6654129, 10.28958321], [79.6654129, 10.28988171], [79.6654129, 10.29124928], [79.66569519, 10.29124928], [79.66569519, 10.29208279], [79.6654129, 10.29208088], [79.6654129, 10.29264164], [79.66513824, 10.29264164], [79.66513824, 10.29292202], [79.66486359, 10.29291534], [79.66486359, 10.29347134], [79.6645813, 10.29347134], [79.6645813, 10.29403019], [79.66430664, 10.29403019], [79.66430664, 10.29430962], [79.66402435, 10.2943058], [79.66402435, 10.29486179], [79.66374969, 10.29485035], [79.66374969, 10.29514027], [79.66347504, 10.29514027], [79.66347504, 10.29569435], [79.66319275, 10.29569435], [79.66319275, 10.29625034], [79.66293335, 10.29625034], [79.66293335, 10.29681015], [79.6626358, 10.29680634], [79.6626358, 10.29736233], [79.66236115, 10.29736042], [79.66236115, 10.29763985], [79.6626358, 10.29763985], [79.6626358, 10.29819584], [79.66291809, 10.29819584], [79.66291809, 10.2984724], [79.66348267, 10.29846954], [79.66348267, 10.29874992], [79.66374969, 10.29874992], [79.66374969, 10.2990303], [79.66401672, 10.2990303], [79.66401672, 10.29931068], [79.6645813, 10.29930592], [79.6645813, 10.29958439], [79.66485596, 10.29957867], [79.66485596, 10.29986191], [79.66513824, 10.29986191], [79.66513824, 10.30042267], [79.6654129, 10.30041599], [79.6654129, 10.30069447], [79.66570282, 10.3006916], [79.66570282, 10.30125046], [79.66596985, 10.30125046], [79.66596985, 10.30153275], [79.6673584, 10.30153275], [79.6673584, 10.30181122], [79.66874695, 10.30181122], [79.66874695, 10.30098057], [79.66847229, 10.30098057], [79.66847229, 10.3006916], [79.66819763, 10.30069447], [79.66819763, 10.30041599], [79.66764069, 10.30042267], [79.66764069, 10.30014038], [79.6673584, 10.30014038], [79.6673584, 10.29986191], [79.66707611, 10.29986191], [79.66707611, 10.29957867], [79.66680908, 10.29958439], [79.66680908, 10.29930592], [79.66652679, 10.29931068], [79.66652679, 10.2990303], [79.66596985, 10.2990303], [79.66596985, 10.29874992], [79.66570282, 10.29874992], [79.66570282, 10.29846954], [79.66513824, 10.2984724], [79.66513824, 10.29819584], [79.66486359, 10.29819584], [79.66486359, 10.29791641], [79.6645813, 10.29792023], [79.6645813, 10.29763985], [79.66430664, 10.29763985], [79.66430664, 10.29708195], [79.66402435, 10.29708385], [79.66402435, 10.29680634], [79.66374969, 10.29681015], [79.66374969, 10.29652977], [79.66430664, 10.29652977], [79.66430664, 10.29625034], [79.6645813, 10.29625034], [79.6645813, 10.29597187], [79.66513824, 10.29597187], [79.66513824, 10.29569435], [79.6654129, 10.29569435], [79.6654129, 10.29541779], [79.66625214, 10.29541779], [79.66625214, 10.29569435], [79.66652679, 10.29569435], [79.66652679, 10.29625034], [79.66680908, 10.29625034], [79.66680908, 10.29681015], [79.66707611, 10.29681015], [79.66707611, 10.29763985], [79.6673584, 10.29763985], [79.6673584, 10.29819584], [79.66764069, 10.29819107], [79.66764069, 10.29874992], [79.66792297, 10.29874992], [79.66792297, 10.29931068], [79.66819763, 10.29930592], [79.66819763, 10.29958439], [79.66847229, 10.29958439], [79.66847229, 10.29986191], [79.66874695, 10.29986191], [79.66874695, 10.30014038], [79.66929626, 10.30014038], [79.66929626, 10.30042267], [79.66986084, 10.30041599], [79.66986084, 10.30069447], [79.67041779, 10.3006916], [79.67041779, 10.30098057], [79.6709671, 10.30098057], [79.6709671, 10.30125046], [79.67151642, 10.30125046], [79.67151642, 10.30153275], [79.67346954, 10.30153275], [79.67346954, 10.30125046], [79.67430878, 10.30125046], [79.67430878, 10.30098057], [79.67494202, 10.30097675], [79.67542267, 10.30098057], [79.67544556, 10.30075836], [79.67559052, 10.30069447], [79.67652893, 10.30069447], [79.67652893, 10.30041599], [79.67679596, 10.30042267], [79.67679596, 10.30015182], [79.67708588, 10.30014038], [79.67708588, 10.30004025], [79.67708588, 10.29986191], [79.67736053, 10.29986191], [79.67736053, 10.29958439], [79.67763519, 10.29958439], [79.67763519, 10.29930592], [79.67790985, 10.29931068], [79.67790985, 10.29874992], [79.67819214, 10.29874992], [79.67819214, 10.29846954], [79.67847443, 10.2984724], [79.67847443, 10.29819584], [79.67874908, 10.29819584], [79.67874908, 10.29791641], [79.67903137, 10.29792023], [79.67903137, 10.29763985], [79.67930603, 10.29763985], [79.67930603, 10.29736042], [79.67986298, 10.29736233], [79.67986298, 10.29708385], [79.68013763, 10.29708385], [79.68013763, 10.29680634], [79.68068695, 10.29681015], [79.68068695, 10.29652977], [79.68125153, 10.29652977], [79.68125153, 10.29625034], [79.68152618, 10.29625034], [79.68152618, 10.29597187], [79.68208313, 10.29597187], [79.68208313, 10.29569435], [79.68264008, 10.29569435], [79.68264008, 10.29541779], [79.6829071, 10.29541969], [79.6829071, 10.29514027], [79.68347168, 10.29514027], [79.68347168, 10.29485035], [79.68430328, 10.29486179], [79.68430328, 10.29458427], [79.68514252, 10.29458427], [79.68514252, 10.2943058], [79.68596649, 10.29430962], [79.68596649, 10.29403019], [79.68681335, 10.29403019], [79.68681335, 10.29374886], [79.68791962, 10.29374886], [79.68791962, 10.29347134], [79.68875122, 10.29347134], [79.68875122, 10.29319572], [79.68958282, 10.29319572], [79.68958282, 10.29291534], [79.6904068, 10.29292202], [79.6904068, 10.29208088], [79.69069672, 10.29208279], [79.69069672, 10.29124928], [79.68930817, 10.29124928], [79.68930817, 10.29097271], [79.68624878, 10.29097271], [79.68624878, 10.29124928], [79.68514252, 10.29124928], [79.68514252, 10.29152966], [79.68403625, 10.29152966], [79.68403625, 10.29181004], [79.68319702, 10.29180527], [79.68319702, 10.29208279], [79.68208313, 10.29208279], [79.68208313, 10.29236126], [79.68013763, 10.29236126], [79.68013763, 10.29208279], [79.68041992, 10.29208279], [79.68041992, 10.29180527], [79.68068695, 10.29181004], [79.68068695, 10.29152966], [79.68096924, 10.29152966], [79.68096924, 10.29096889], [79.68125153, 10.2909708], [79.68125153, 10.29069328], [79.68152618, 10.29069328], [79.68152618, 10.29041672], [79.68180847, 10.29041958], [79.68180847, 10.2901392], [79.68319702, 10.2901392], [79.68319702, 10.28986073], [79.68430328, 10.28986073], [79.68430328, 10.28958321], [79.68569183, 10.28958321], [79.68569183, 10.28930473], [79.68681335, 10.28931046], [79.68681335, 10.28904057], [79.68818665, 10.28904057], [79.68818665, 10.28875065], [79.68930817, 10.28875065], [79.68930817, 10.28847122], [79.69041443, 10.28847313], [79.69041443, 10.28819466], [79.69125366, 10.28819466], [79.69125366, 10.28791714], [79.69235992, 10.28792191], [79.69235992, 10.28764057], [79.69346619, 10.28764057], [79.69346619, 10.28736115], [79.69458008, 10.28736115], [79.69458008, 10.28708267], [79.69569397, 10.28708267], [79.69569397, 10.28680515], [79.69680786, 10.28681183], [79.69680786, 10.28653145], [79.69763947, 10.28653145], [79.69763947, 10.28625107], [79.69875336, 10.28625107], [79.69875336, 10.28598022], [79.69985962, 10.28598022], [79.69985962, 10.28569031], [79.70124817, 10.28569031], [79.70124817, 10.28598022], [79.70236206, 10.28598022], [79.70236206, 10.28569031], [79.70319366, 10.28569508], [79.70319366, 10.2854166], [79.70375061, 10.28542137], [79.70375061, 10.28514099], [79.70458221, 10.28514099], [79.70458221, 10.28486061], [79.70513916, 10.28486061], [79.70513916, 10.28458309], [79.70597076, 10.28458309], [79.70597076, 10.28430462], [79.70652771, 10.28430939], [79.70652771, 10.28403091], [79.70735931, 10.28403091], [79.70735931, 10.28375053], [79.70791626, 10.28375053], [79.70791626, 10.28347111], [79.70874786, 10.28347301], [79.70874786, 10.28319454], [79.70903015, 10.28318977], [79.70903015, 10.28403091], [79.70874786, 10.28402901], [79.70874786, 10.28569508], [79.70847321, 10.28569031], [79.70847321, 10.28681183], [79.71375275, 10.28681183], [79.71375275, 10.28625107], [79.71401978, 10.28625107], [79.71401978, 10.28598022], [79.71430206, 10.28598022], [79.71430206, 10.28542137], [79.71457672, 10.28542137], [79.71457672, 10.28486061], [79.71485901, 10.28486061], [79.71485901, 10.28458309], [79.7151413, 10.28458309], [79.7151413, 10.28402901], [79.71541595, 10.28403091], [79.71541595, 10.28375053], [79.71678925, 10.28375053], [79.71678925, 10.28347111], [79.7179184, 10.28347301], [79.7179184, 10.28319454], [79.71930695, 10.28319454], [79.71930695, 10.28291702], [79.72041321, 10.28291702], [79.72041321, 10.28263855], [79.72099304, 10.28263855], [79.72180176, 10.28264141], [79.72180176, 10.28236103], [79.72291565, 10.28236103], [79.72291565, 10.28208256], [79.7243042, 10.28208256], [79.7243042, 10.28180695], [79.72541809, 10.28181076], [79.72541809, 10.28153133], [79.72680664, 10.28153133], [79.72680664, 10.28125095], [79.7279129, 10.28125095], [79.7279129, 10.28096962], [79.72930908, 10.28097343], [79.72930908, 10.28069496], [79.73041534, 10.28069496], [79.73041534, 10.28041553], [79.73052979, 10.28041553], [79.73179626, 10.28042126], [79.73179626, 10.28014088], [79.73208618, 10.28014088], [79.73208618, 10.27985096], [79.7326355, 10.27985954], [79.7326355, 10.27958202], [79.73291779, 10.27958202], [79.73291779, 10.27930737], [79.7334671, 10.27931118], [79.7334671, 10.2790308], [79.73374939, 10.2790308], [79.73374939, 10.27875042], [79.73402405, 10.27875042], [79.73401642, 10.27847004], [79.73458099, 10.27847195], [79.73458099, 10.27819443], [79.73486328, 10.27819443], [79.73486328, 10.27791595], [79.73596954, 10.27791595], [79.73596954, 10.27819443], [79.73764038, 10.27819443], [79.73764038, 10.27847195], [79.73792267, 10.27847004], [79.73792267, 10.2790308], [79.7381897, 10.2790308], [79.7381897, 10.27931118], [79.73958588, 10.27931118], [79.73958588, 10.27847004], [79.73930359, 10.27847195], [79.73930359, 10.27791595], [79.73902893, 10.27792072], [79.73902893, 10.27735996], [79.73764038, 10.27735996], [79.73764038, 10.27708435], [79.73458099, 10.27708435], [79.73458099, 10.27680588], [79.73430634, 10.27681065], [79.73430634, 10.27653122], [79.73374939, 10.27653122], [79.73374939, 10.27625179], [79.7334671, 10.27625179], [79.7334671, 10.27569199], [79.73319244, 10.27569389], [79.73319244, 10.2751379], [79.73264313, 10.27514267], [79.73264313, 10.27486038], [79.73239136, 10.27486038], [79.73180389, 10.27486229], [79.73180389, 10.27458382], [79.73124695, 10.27458191], [79.73124695, 10.2743063], [79.73042297, 10.27431107], [79.73042297, 10.27403927], [79.7270813, 10.27403927], [79.7270813, 10.27431107], [79.72486115, 10.2743063], [79.72486115, 10.27458191], [79.72291565, 10.27458382], [79.72291565, 10.27486229], [79.72125244, 10.27486038], [79.72125244, 10.27514267], [79.71930695, 10.27514267], [79.71930695, 10.27542114], [79.71763611, 10.27541637], [79.71763611, 10.27569389], [79.71569824, 10.27569389], [79.71569824, 10.27597237], [79.71401978, 10.27597046], [79.71401978, 10.27625179], [79.71208191, 10.27625179], [79.71208191, 10.27653122], [79.71013641, 10.27653122], [79.71013641, 10.27681065], [79.70819092, 10.27680588], [79.70819092, 10.27708435], [79.70652771, 10.27708435], [79.70652771, 10.27735996], [79.70458221, 10.27735996], [79.70458221, 10.27764034], [79.70263672, 10.27764034], [79.70263672, 10.27792072], [79.70069122, 10.27791595], [79.70069122, 10.27819443], [79.69875336, 10.27819443], [79.69875336, 10.27847195], [79.69708252, 10.27847195], [79.69708252, 10.27875042], [79.69513702, 10.27875042], [79.69513702, 10.2790308], [79.69319153, 10.2790308], [79.69319153, 10.27931118], [79.69125366, 10.27930737], [79.69125366, 10.27958202], [79.68958282, 10.27958202], [79.68958282, 10.27985954], [79.68763733, 10.27985096], [79.68763733, 10.28014088], [79.68569183, 10.28014088], [79.68569183, 10.28042126], [79.68180847, 10.28041553], [79.68180847, 10.28069496], [79.67970276, 10.28069496], [79.67791748, 10.28069496], [79.67791748, 10.28097343], [79.67402649, 10.28096962], [79.67402649, 10.28125095], [79.67292023, 10.28125095], [79.67292023, 10.28153133], [79.67151642, 10.28153133], [79.67151642, 10.28181076], [79.67041779, 10.28180695], [79.67041779, 10.28208256], [79.66929626, 10.2820797], [79.66930389, 10.28236103], [79.66819763, 10.28236103], [79.66819763, 10.28264141], [79.66680908, 10.28263855], [79.66680908, 10.28291702], [79.66569519, 10.28291702], [79.66569519, 10.28319454], [79.6645813, 10.28319454], [79.6645813, 10.28347301], [79.66319275, 10.28347111], [79.66319275, 10.28375053], [79.66208649, 10.28375053], [79.66208649, 10.28403091], [79.6609726, 10.28403091], [79.6609726, 10.28430939], [79.6598587, 10.28430462], [79.6598587, 10.28458309], [79.65847015, 10.28458309], [79.65847015, 10.28486061], [79.65735626, 10.28486061], [79.65735626, 10.28514099], [79.6554184, 10.28514099], [79.6554184, 10.28542137], [79.65374756, 10.2854166], [79.65374756, 10.28569508], [79.65207672, 10.28569031], [79.65207672, 10.28598022], [79.65040588, 10.28598022], [79.65040588, 10.28625107], [79.64848328, 10.28625107], [79.64848328, 10.28653145], [79.64679718, 10.28653145], [79.64679718, 10.28681183], [79.64541626, 10.28680515], [79.64541626, 10.28708267], [79.64402771, 10.28708267], [79.64402771, 10.28736115], [79.64263916, 10.28736115], [79.64263916, 10.28764057], [79.64125061, 10.28764057], [79.64125061, 10.28792191], [79.63957977, 10.28791714], [79.63957977, 10.28819466], [79.63819122, 10.28819466], [79.63819122, 10.28847313], [79.63680267, 10.28847122], [79.63680267, 10.28875065], [79.63540649, 10.28875065], [79.63540649, 10.28904057], [79.6340332, 10.28904057], [79.6340332, 10.28931046], [79.62930298, 10.28930473], [79.62930298, 10.28958321], [79.62763977, 10.28958321], [79.62763977, 10.28986073], [79.62596893, 10.28986073], [79.62596893, 10.2901392], [79.62431335, 10.2901392], [79.62431335, 10.29041958], [79.62291718, 10.29041672], [79.62291718, 10.29069328], [79.62124634, 10.29069328], [79.62124634, 10.2909708], [79.61958313, 10.29097271], [79.61958313, 10.29124928], [79.61791992, 10.29124928], [79.61791992, 10.29152966], [79.61624908, 10.29152966], [79.61624908, 10.29181004], [79.61458588, 10.29180527], [79.61458588, 10.29208279], [79.61291504, 10.29208279], [79.61291504, 10.29236126], [79.61152649, 10.29236126], [79.61152649, 10.29264164], [79.60986328, 10.29264164], [79.60986328, 10.29292202], [79.60819244, 10.29291534], [79.60819244, 10.29319572], [79.60652924, 10.29319572], [79.60652924, 10.29347134], [79.6048584, 10.29347134], [79.6048584, 10.29374886], [79.6029129, 10.29374886], [79.6029129, 10.29403019], [79.60124969, 10.29403019], [79.60124969, 10.29430962], [79.59958649, 10.2943058], [79.59958649, 10.29458427], [79.59764099, 10.29458427], [79.59764099, 10.29486179], [79.59597015, 10.29485035], [79.59597015, 10.29514027], [79.59430695, 10.29514027], [79.59430695, 10.29541969], [79.59236145, 10.29541779], [79.59236145, 10.29569435], [79.59069824, 10.29569435], [79.59069824, 10.29597187], [79.5890274, 10.29597187], [79.5890274, 10.29625034], [79.58708191, 10.29625034], [79.58708191, 10.29652977], [79.5854187, 10.29652977], [79.5854187, 10.29681015], [79.5826416, 10.29680634], [79.5826416, 10.29708385], [79.58180237, 10.29708385], [79.58180237, 10.29736233], [79.57847595, 10.29736233], [79.57847595, 10.29708385], [79.57736206, 10.29708385], [79.57736206, 10.29680634], [79.57707977, 10.29680634], [79.57707977, 10.29708385], [79.57653046, 10.29708385], [79.57653046, 10.29736233], [79.57624817, 10.29736042], [79.57624817, 10.29763985], [79.57541656, 10.29763985], [79.57541656, 10.29792023], [79.57347107, 10.29791641], [79.57347107, 10.2984724], [79.57319641, 10.29846954], [79.57319641, 10.29874992], [79.57235718, 10.29874992], [79.57235718, 10.29846954], [79.57125092, 10.29846954], [79.57125092, 10.29874992], [79.57068634, 10.29874992], [79.57068634, 10.2990303], [79.56958008, 10.2990303], [79.56958008, 10.29931068], [79.56708527, 10.29930592], [79.56708527, 10.29958439], [79.56624603, 10.29957867], [79.56625366, 10.29986191], [79.56402588, 10.29986191], [79.56402588, 10.30014038], [79.56181335, 10.30014038], [79.56181335, 10.30042267], [79.56124878, 10.30042267], [79.56124878, 10.30014038], [79.55902863, 10.30014038], [79.55902863, 10.30042267], [79.55791473, 10.30041599], [79.55791473, 10.30069447], [79.55513763, 10.3006916], [79.55513763, 10.30098057], [79.55263519, 10.30097198], [79.55263519, 10.30125046], [79.55069733, 10.30125046], [79.55069733, 10.30097198], [79.55041504, 10.30097198], [79.55042267, 10.30125046], [79.54957581, 10.30125046], [79.54957581, 10.30153275], [79.54847717, 10.30153275], [79.54847717, 10.30181122], [79.54763794, 10.30180645], [79.54763794, 10.30208206], [79.54569244, 10.30208206], [79.54569244, 10.30236244], [79.54541779, 10.30235958], [79.54541779, 10.30263996], [79.54402924, 10.30263996], [79.54402924, 10.3029213], [79.5423584, 10.30291557], [79.5423584, 10.30319405], [79.54096985, 10.30319405], [79.54096985, 10.30347157], [79.54013824, 10.30347157], [79.54013824, 10.30319405], [79.53986359, 10.30319405], [79.53986359, 10.30347157], [79.53901672, 10.30346966], [79.53901672, 10.30375004], [79.53791809, 10.30375004], [79.53791809, 10.30346966], [79.53679657, 10.30346966], [79.53679657, 10.30375004], [79.53652954, 10.30375004], [79.53652954, 10.30402756], [79.53542328, 10.30402088], [79.53542328, 10.3043108], [79.53375244, 10.30430603], [79.53375244, 10.30458355], [79.5333786, 10.30458355], [79.5320816, 10.30458355], [79.5320816, 10.30486012], [79.52986145, 10.30486012], [79.52986145, 10.30514145], [79.5284729, 10.30514145], [79.5284729, 10.30542088], [79.5265274, 10.30541611], [79.5265274, 10.30569363], [79.52625275, 10.30569363], [79.52625275, 10.3059721], [79.5256958, 10.30597019], [79.5256958, 10.30624962], [79.52540588, 10.30624962], [79.52540588, 10.30653095], [79.52513885, 10.30653095], [79.52513885, 10.30681133], [79.52458191, 10.30680656], [79.52458191, 10.30708218], [79.52430725, 10.30708218], [79.52430725, 10.3073597], [79.52401733, 10.3073597], [79.52401733, 10.30764103], [79.52348328, 10.30764103], [79.52348328, 10.30792141], [79.52319336, 10.30792141], [79.52319336, 10.31125069], [79.52348328, 10.31125069], [79.52348328, 10.3118124], [79.52375031, 10.31180477], [79.52375031, 10.31236076], [79.52401733, 10.31235886], [79.52401733, 10.31292152], [79.52430725, 10.31291676], [79.52430725, 10.31375122], [79.52458191, 10.31375122], [79.52458191, 10.31431198], [79.5248642, 10.31430531], [79.5248642, 10.3148613], [79.52513885, 10.3148613], [79.52513885, 10.3154192], [79.5256958, 10.31541729], [79.5256958, 10.31569481], [79.52625275, 10.31569481], [79.52625275, 10.31597328], [79.52680206, 10.31597328], [79.52680206, 10.31624889], [79.52707672, 10.31624889], [79.52707672, 10.31652927], [79.5276413, 10.31652927], [79.5276413, 10.31680965], [79.53151703, 10.31680965], [79.53151703, 10.31652927], [79.53180695, 10.31652927], [79.53180695, 10.31624889], [79.53236389, 10.31624889], [79.53235626, 10.31596184], [79.53263855, 10.31597328], [79.53263855, 10.31569481], [79.53291321, 10.31569481], [79.53291321, 10.31541729], [79.53320313, 10.3154192], [79.53320313, 10.31514072], [79.53347778, 10.31514072], [79.53347778, 10.3148613], [79.53375244, 10.3148613], [79.53375244, 10.31458282], [79.5340271, 10.31458282], [79.5340271, 10.31430531], [79.53430176, 10.31431198], [79.53430176, 10.31403065], [79.53457642, 10.31403065], [79.53457642, 10.31375122], [79.53514099, 10.31375122], [79.53514099, 10.31347084], [79.53541565, 10.31347084], [79.53541565, 10.31319523], [79.5359726, 10.31319523], [79.5359726, 10.31291676], [79.53624725, 10.31292152], [79.53624725, 10.31272984], [79.53624725, 10.31263924], [79.53679657, 10.31264114], [79.53679657, 10.31235886], [79.53708649, 10.31236076], [79.53708649, 10.31208324], [79.53791809, 10.31208324], [79.53791809, 10.31236076], [79.53848267, 10.31235886], [79.53848267, 10.31264114], [79.53901672, 10.31264114], [79.53901672, 10.31292152], [79.53930664, 10.31291676], [79.53930664, 10.31319523], [79.53985596, 10.31319046], [79.53985596, 10.31347084], [79.5404129, 10.31347084], [79.5404129, 10.31375122], [79.54096985, 10.31375122], [79.54096985, 10.31403065], [79.54207611, 10.31403065], [79.54207611, 10.31431198], [79.54264069, 10.31430531], [79.54264069, 10.31458282], [79.54347229, 10.31458282], [79.54347229, 10.3148613], [79.54429626, 10.3148613], [79.54429626, 10.31514072], [79.54514313, 10.31514072], [79.54514313, 10.3154192], [79.54569244, 10.31541729], [79.54569244, 10.31569481], [79.54652405, 10.31569481], [79.54652405, 10.31597328], [79.54736328, 10.31597328], [79.54736328, 10.31624889], [79.54818726, 10.31624889], [79.54818726, 10.31652927], [79.54875183, 10.31652927], [79.54875183, 10.31680965], [79.54958344, 10.31680489], [79.54958344, 10.31708336], [79.54985809, 10.31708145], [79.54985809, 10.31763935], [79.55014038, 10.31763935], [79.55014038, 10.31791973], [79.55041504, 10.31791687], [79.55041504, 10.31847095], [79.55069733, 10.31847095], [79.55069733, 10.31874943], [79.55097198, 10.31874943], [79.55097198, 10.31931019], [79.55124664, 10.31930542], [79.55124664, 10.31958294], [79.55153656, 10.31958103], [79.55153656, 10.32014179], [79.55180359, 10.32013988], [79.55180359, 10.32236195], [79.55153656, 10.32236195], [79.55153656, 10.32515144], [79.55180359, 10.32514], [79.55180359, 10.32569408], [79.55208588, 10.32568932], [79.55208588, 10.32653046], [79.55236053, 10.3265276], [79.55236053, 10.32708359], [79.55264282, 10.32708168], [79.55264282, 10.32792091], [79.55291748, 10.32791805], [79.55291748, 10.32847214], [79.55319214, 10.32847023], [79.55319214, 10.32903004], [79.55374908, 10.32903004], [79.55374908, 10.32931137], [79.55401611, 10.32930756], [79.55430603, 10.32930565], [79.55430603, 10.32958412], [79.55486298, 10.32958412], [79.55486298, 10.32985973], [79.55541992, 10.32985973], [79.55541992, 10.33014011], [79.55568695, 10.33014011], [79.55568695, 10.33042145], [79.55625153, 10.33041573], [79.55625153, 10.3306942], [79.55680847, 10.3306942], [79.55680847, 10.33097172], [79.55735779, 10.33097172], [79.55735779, 10.33125019], [79.5579071, 10.33125019], [79.5579071, 10.33153057], [79.55819702, 10.33153057], [79.55819702, 10.33181095], [79.55874634, 10.33180428], [79.55874634, 10.3320837], [79.55930328, 10.3320837], [79.55930328, 10.33236027], [79.55986023, 10.33236027], [79.55986023, 10.33264065], [79.56153107, 10.33264065], [79.56153107, 10.33292103], [79.56208038, 10.33292103], [79.56208038, 10.33264065], [79.56263733, 10.33264065], [79.56263733, 10.33236027], [79.56291962, 10.33236027], [79.56291962, 10.3320837], [79.56346893, 10.3320837], [79.56346893, 10.33236027], [79.56430817, 10.33236027], [79.56430817, 10.3320837], [79.56485748, 10.3320837], [79.56485748, 10.33180428], [79.56624603, 10.33181095], [79.56624603, 10.33153057], [79.56764221, 10.33153057], [79.56764221, 10.33125019], [79.56903076, 10.33125019], [79.56903076, 10.33097172], [79.57041931, 10.33097172], [79.57041931, 10.3306942], [79.57180786, 10.3306942], [79.57180786, 10.33041573], [79.57319641, 10.33042145], [79.57319641, 10.33014011], [79.57430267, 10.33014011], [79.57430267, 10.32985973], [79.57489014, 10.32985973], [79.57541656, 10.32985973], [79.57541656, 10.32958412], [79.57653046, 10.32958412], [79.57653046, 10.32930565], [79.57763672, 10.32931137], [79.57763672, 10.32903004], [79.5790329, 10.32903004], [79.5790329, 10.32874966], [79.58013916, 10.32874966], [79.58013916, 10.32847023], [79.58125305, 10.32847214], [79.58125305, 10.32819366], [79.58235931, 10.32819366], [79.58235931, 10.32791805], [79.58652496, 10.32791805], [79.58652496, 10.32847214], [79.58680725, 10.32847023], [79.58680725, 10.32903004], [79.58708191, 10.32902813], [79.58708191, 10.32958412], [79.58735657, 10.32958031], [79.58735657, 10.33042145], [79.58763885, 10.33041573], [79.58763885, 10.33125019], [79.58791351, 10.33125019], [79.58791351, 10.3320837], [79.5881958, 10.33208179], [79.5881958, 10.33264065], [79.58875275, 10.33263779], [79.58875275, 10.33319378], [79.58847046, 10.33318996], [79.58847046, 10.33403111], [79.58875275, 10.3340292], [79.58875275, 10.33485985], [79.5890274, 10.33485985], [79.5890274, 10.33597279], [79.58930206, 10.33596992], [79.58930206, 10.33708858], [79.58958435, 10.33708286], [79.58958435, 10.33819485], [79.58985901, 10.33819008], [79.58985901, 10.3393116], [79.5901413, 10.33930492], [79.5901413, 10.34013939], [79.58985901, 10.34012985], [79.58985901, 10.34042168], [79.58958435, 10.34041691], [79.58958435, 10.34097099], [79.58930206, 10.34097099], [79.58930206, 10.34125137], [79.5890274, 10.34125137], [79.5890274, 10.34152889], [79.5881958, 10.34152889], [79.5881958, 10.34181023], [79.58791351, 10.34180546], [79.58791351, 10.34208298], [79.5873642, 10.34208298], [79.5873642, 10.34319305], [79.58708191, 10.34319305], [79.58708191, 10.34347343], [79.58625031, 10.34347343], [79.58625031, 10.34291744], [79.58598328, 10.34291935], [79.58598328, 10.34236145], [79.58569336, 10.34236145], [79.58569336, 10.34208298], [79.58430481, 10.34208298], [79.58430481, 10.34180546], [79.58403015, 10.34181023], [79.58403015, 10.34152889], [79.58347321, 10.34152889], [79.58347321, 10.34125137], [79.58207703, 10.34125137], [79.58207703, 10.34152889], [79.58180237, 10.34152889], [79.58180237, 10.34125137], [79.58152008, 10.34125137], [79.58152008, 10.34097099], [79.58097076, 10.34097099], [79.58097076, 10.34125137], [79.57818604, 10.34125137], [79.57818604, 10.34097099], [79.57707977, 10.34097099], [79.57707977, 10.34069538], [79.57624817, 10.34069538], [79.57624817, 10.34097099], [79.57457733, 10.34097099], [79.57458496, 10.34125137], [79.57375336, 10.34125137], [79.57375336, 10.34152889], [79.57319641, 10.34152889], [79.57319641, 10.34181023], [79.57208252, 10.34180546], [79.57208252, 10.34208298], [79.57096863, 10.34208298], [79.57096863, 10.34236145], [79.56986237, 10.34236145], [79.56986237, 10.34264088], [79.56846619, 10.34264088], [79.56846619, 10.34236145], [79.56819153, 10.34236145], [79.56819153, 10.34264088], [79.56764221, 10.34264088], [79.56764221, 10.34291935], [79.56680298, 10.34291744], [79.56680298, 10.34319305], [79.56541443, 10.34319305], [79.56541443, 10.34347343], [79.56430817, 10.34347057], [79.56430817, 10.34375095], [79.56402588, 10.34375095], [79.56402588, 10.34402943], [79.5634613, 10.34402943], [79.5634613, 10.34430981], [79.56291962, 10.34430504], [79.56291962, 10.34458256], [79.56263733, 10.34458256], [79.56263733, 10.34430504], [79.56124878, 10.34430504], [79.56124878, 10.34458256], [79.56014252, 10.34458256], [79.56014252, 10.34486103], [79.55902863, 10.34486103], [79.55902863, 10.34513855], [79.55819702, 10.34513855], [79.55819702, 10.34542179], [79.55708313, 10.34541702], [79.55708313, 10.34569454], [79.55596924, 10.34569454], [79.55596924, 10.34597111], [79.55486298, 10.34597111], [79.55486298, 10.34625244], [79.55374908, 10.34625244], [79.55374908, 10.34653187], [79.55264282, 10.34653187], [79.55264282, 10.34681034], [79.55180359, 10.34680462], [79.55180359, 10.34708309], [79.55014038, 10.34708309], [79.55014038, 10.34736156], [79.54847717, 10.34736156], [79.54847717, 10.34764194], [79.54708099, 10.34764194], [79.54708099, 10.34792042], [79.54514313, 10.34792042], [79.54514313, 10.34764194], [79.54347229, 10.34764194], [79.54347229, 10.34708118], [79.54319763, 10.34708309], [79.54319763, 10.34680462], [79.54292297, 10.34681034], [79.54292297, 10.34625244], [79.54264069, 10.34625244], [79.54264069, 10.34597111], [79.5423584, 10.34597111], [79.5423584, 10.34513855], [79.54264069, 10.34513855], [79.54264069, 10.34402943], [79.54292297, 10.34402943], [79.54292297, 10.34375095], [79.54319763, 10.34375095], [79.54319763, 10.34347057], [79.54347229, 10.34347343], [79.54347229, 10.34208298], [79.54319763, 10.34208298], [79.54319763, 10.34125137], [79.54291534, 10.34125137], [79.54291534, 10.33986092], [79.54319763, 10.33986092], [79.54319763, 10.3395834], [79.54347229, 10.3395834], [79.54347229, 10.33930492], [79.54292297, 10.3393116], [79.54292297, 10.33903122], [79.54264069, 10.33903122], [79.54264069, 10.3393116], [79.54208374, 10.33930492], [79.54208374, 10.3395834], [79.54180908, 10.3395834], [79.54180908, 10.33986092], [79.54152679, 10.33986092], [79.54152679, 10.34042168], [79.54125214, 10.34041691], [79.54125214, 10.34097099], [79.54096985, 10.34097099], [79.54096985, 10.34152889], [79.54069519, 10.34152699], [79.54069519, 10.34208298], [79.5404129, 10.34208298], [79.5404129, 10.34319305], [79.54069519, 10.34319305], [79.54069519, 10.34347343], [79.54096985, 10.34347057], [79.54096985, 10.34402943], [79.54069519, 10.34402657], [79.54069519, 10.34458256], [79.5404129, 10.34458256], [79.5404129, 10.34486103], [79.53985596, 10.34486103], [79.53985596, 10.34513855], [79.5395813, 10.34513855], [79.5395813, 10.34569454], [79.53930664, 10.34569073], [79.53930664, 10.34653187], [79.53902435, 10.3465271], [79.53902435, 10.34708309], [79.53819275, 10.34708309], [79.53819275, 10.34569454], [79.53847504, 10.34569454], [79.53847504, 10.34458256], [79.53874969, 10.34458256], [79.53874969, 10.34430504], [79.53901672, 10.34430981], [79.53901672, 10.34402943], [79.53930664, 10.34402943], [79.53930664, 10.34291935], [79.53874969, 10.34291935], [79.53874969, 10.34236145], [79.53902435, 10.34236145], [79.53902435, 10.34180546], [79.53930664, 10.34181023], [79.53930664, 10.34125137], [79.5395813, 10.34125137], [79.5395813, 10.34069538], [79.53986359, 10.34069538], [79.53986359, 10.3395834], [79.54013824, 10.3395834], [79.54013824, 10.33847332], [79.54096985, 10.33847141], [79.54096985, 10.33903122], [79.54152679, 10.33903122], [79.54152679, 10.33847141], [79.54235077, 10.33847141], [79.54235077, 10.33875084], [79.54347229, 10.33875084], [79.54347229, 10.33847141], [79.54374695, 10.33847332], [79.54374695, 10.33819485], [79.54347229, 10.33819485], [79.54347229, 10.33763885], [79.54291534, 10.33763885], [79.54291534, 10.33736134], [79.5423584, 10.33736134], [79.5423584, 10.33708477], [79.54207611, 10.33708858], [79.54207611, 10.33681107], [79.54152679, 10.33681107], [79.54152679, 10.33653069], [79.5404129, 10.33653069], [79.5404129, 10.33681107], [79.54013824, 10.33681107], [79.54013824, 10.33708858], [79.53986359, 10.33708477], [79.53986359, 10.33736134], [79.5395813, 10.33736134], [79.5395813, 10.33763885], [79.53930664, 10.33763885], [79.53930664, 10.33791924], [79.53653717, 10.33791924], [79.53653717, 10.33763885], [79.53624725, 10.33763885], [79.53624725, 10.33736134], [79.53514099, 10.33736134], [79.53514099, 10.33708477], [79.5348587, 10.33708858], [79.5348587, 10.33681107], [79.53457642, 10.33681107], [79.53457642, 10.33596992], [79.53430176, 10.33597279], [79.53430176, 10.33569527], [79.53458405, 10.33569527], [79.53458405, 10.33541679], [79.5348587, 10.33542061], [79.5348587, 10.33514118], [79.53514099, 10.33514118], [79.53514099, 10.33458042], [79.53541565, 10.33458233], [79.53541565, 10.3340292], [79.53569794, 10.33403111], [79.53569794, 10.33375072], [79.53624725, 10.33375072], [79.53624725, 10.33318996], [79.53652954, 10.33319378], [79.53652954, 10.33291626], [79.53679657, 10.33292103], [79.53679657, 10.33264065], [79.53708649, 10.33264065], [79.53708649, 10.33236027], [79.53736115, 10.33236027], [79.53736115, 10.3320837], [79.53791809, 10.3320837], [79.53791809, 10.33180428], [79.53819275, 10.33181095], [79.53819275, 10.33153057], [79.53874969, 10.33153057], [79.53874969, 10.33125019], [79.53902435, 10.33125019], [79.53901672, 10.33096123], [79.53930664, 10.33097172], [79.53930664, 10.3306942], [79.5395813, 10.3306942], [79.5395813, 10.33041573], [79.53985596, 10.33042145], [79.53985596, 10.33014011], [79.54013824, 10.33014011], [79.54013824, 10.32958031], [79.5404129, 10.32958412], [79.5404129, 10.32930565], [79.54070282, 10.32931137], [79.54070282, 10.32903004], [79.54096985, 10.32903004], [79.54096985, 10.32874966], [79.54125214, 10.32874966], [79.54125214, 10.32847023], [79.54152679, 10.32847214], [79.54152679, 10.32791805], [79.54180908, 10.32792091], [79.54180908, 10.32708168], [79.54208374, 10.32708359], [79.54208374, 10.3265276], [79.54235077, 10.32653046], [79.54235077, 10.3259697], [79.54264069, 10.3259716], [79.54264069, 10.32569408], [79.54291534, 10.32569408], [79.54291534, 10.32541561], [79.54319763, 10.32542038], [79.54319763, 10.32515144], [79.54347229, 10.32515144], [79.54347229, 10.3243103], [79.54070282, 10.3243103], [79.54070282, 10.32264042], [79.53874969, 10.32264042], [79.53874969, 10.32236195], [79.53791809, 10.32236195], [79.53791809, 10.32208443], [79.53736115, 10.32209015], [79.53736115, 10.32180977], [79.53542328, 10.32180977], [79.53542328, 10.32209015], [79.5348587, 10.32208443], [79.5348587, 10.32236195], [79.53235626, 10.32236195], [79.53235626, 10.32209015], [79.53125, 10.32209015], [79.53125, 10.32180977], [79.52986145, 10.32180977], [79.52986145, 10.32153034], [79.52874756, 10.32153034], [79.52874756, 10.32125187], [79.5284729, 10.32125187], [79.5284729, 10.32097054], [79.52819824, 10.32097054], [79.52819061, 10.32069588], [79.5276413, 10.32069302], [79.5276413, 10.32041836], [79.52735138, 10.32042027], [79.52735138, 10.32014179], [79.52680206, 10.32014179], [79.52680206, 10.31986141], [79.52625275, 10.31986141], [79.52625275, 10.31930542], [79.52597046, 10.31931019], [79.52597046, 10.31874943], [79.5256958, 10.31874943], [79.5256958, 10.31847095], [79.52347565, 10.31847095], [79.52347565, 10.31874943], [79.52319336, 10.31874943], [79.52319336, 10.31902695], [79.5229187, 10.31902027], [79.5229187, 10.31931019], [79.52263641, 10.31930542], [79.52263641, 10.31958294], [79.52236176, 10.31958294], [79.52236176, 10.31986141], [79.5220871, 10.31986141], [79.5220871, 10.32014179], [79.52097321, 10.32014179], [79.52097321, 10.32042027], [79.52041626, 10.32041836], [79.52041626, 10.32069302], [79.51930237, 10.32069302], [79.51930237, 10.32041836], [79.51597595, 10.32041836], [79.51597595, 10.32069302], [79.51541901, 10.32069588], [79.51541901, 10.32097054], [79.51509857, 10.32097054], [79.51486206, 10.32097054], [79.51486206, 10.32114029], [79.51486206, 10.32125187], [79.51467896, 10.32124901], [79.51457977, 10.32124901], [79.51457977, 10.32153034], [79.5141449, 10.32157803], [79.51403046, 10.32159138], [79.51403046, 10.32180977], [79.51361847, 10.32180595], [79.51350403, 10.32186508], [79.51346588, 10.32209015], [79.51308441, 10.32208443], [79.51291656, 10.32208443], [79.51291656, 10.32217026], [79.51291656, 10.32236195], [79.51255035, 10.32236195], [79.51238251, 10.32242584], [79.51236725, 10.32264042], [79.5120163, 10.3226366], [79.51180267, 10.3226366], [79.51180267, 10.32272625], [79.51180267, 10.32291985], [79.51147461, 10.32291794], [79.51125336, 10.32291794], [79.51125336, 10.32300663], [79.51125336, 10.32319355], [79.51097107, 10.32319355], [79.51097107, 10.32347202], [79.51040649, 10.32347202], [79.51040649, 10.32374954], [79.50985718, 10.32376099], [79.50985718, 10.32402992], [79.50933075, 10.32402992], [79.50930786, 10.3243103], [79.50872803, 10.32430553], [79.50819397, 10.32430553], [79.50819397, 10.32458401], [79.50808716, 10.32458401], [79.50763702, 10.32458401], [79.50763702, 10.32486153], [79.50744629, 10.32486153], [79.50736237, 10.32486153], [79.50736237, 10.32515144], [79.50708008, 10.32514], [79.50708008, 10.32569408], [79.50736237, 10.32568932], [79.50736237, 10.32653046], [79.50763702, 10.3265276], [79.50763702, 10.32736206], [79.50818634, 10.32736015], [79.50818634, 10.32763958], [79.5090332, 10.32763958], [79.5090332, 10.32792091], [79.51013947, 10.32792091], [79.51013947, 10.32763958], [79.51040649, 10.32763958], [79.51040649, 10.32736015], [79.51069641, 10.32736206], [79.51069641, 10.32708359], [79.51097107, 10.32708359], [79.51097107, 10.32680607], [79.51152802, 10.32681274], [79.51152802, 10.32653046], [79.51180267, 10.32653046], [79.51180267, 10.32625008], [79.51486206, 10.32625008], [79.51486206, 10.3259697], [79.51625061, 10.3259716], [79.51625061, 10.32569408], [79.51763916, 10.32569408], [79.51763916, 10.32541561], [79.51902771, 10.32542038], [79.51902771, 10.32515144], [79.52041626, 10.32515144], [79.52041626, 10.32542038], [79.52097321, 10.32542038], [79.52097321, 10.32515144], [79.52153778, 10.32515144], [79.52153778, 10.32542038], [79.5220871, 10.32542038], [79.5220871, 10.32515144], [79.52236176, 10.32515144], [79.52236176, 10.32542038], [79.52319336, 10.32541561], [79.52319336, 10.3259716], [79.5229187, 10.3259697], [79.5229187, 10.32625008], [79.52263641, 10.32625008], [79.52263641, 10.32681274], [79.52236176, 10.32680607], [79.52236176, 10.32708359], [79.52263641, 10.32708359], [79.52263641, 10.32736206], [79.5229187, 10.32736015], [79.5229187, 10.32763958], [79.52319336, 10.32763958], [79.52319336, 10.32792091], [79.52401733, 10.32792091], [79.52401733, 10.32763958], [79.52458191, 10.32763958], [79.52458191, 10.32736015], [79.52513885, 10.32736206], [79.52513885, 10.32514], [79.52540588, 10.32515144], [79.52540588, 10.32485962], [79.5256958, 10.32486153], [79.5256958, 10.32458401], [79.5284729, 10.32457924], [79.5284729, 10.32625008], [79.52874756, 10.32625008], [79.52874756, 10.32708359], [79.52902985, 10.32708168], [79.52902985, 10.32763958], [79.52958679, 10.32763767], [79.52958679, 10.32819366], [79.5293045, 10.32819366], [79.5293045, 10.32847214], [79.52902985, 10.32847023], [79.52902985, 10.32931137], [79.5284729, 10.32930565], [79.5284729, 10.32958412], [79.52819824, 10.32958412], [79.52819824, 10.32985973], [79.5276413, 10.32985973], [79.5276413, 10.33014011], [79.52735138, 10.33014011], [79.52735138, 10.33042145], [79.5265274, 10.33042145], [79.5265274, 10.33014011], [79.52540588, 10.33014011], [79.52540588, 10.33042145], [79.5248642, 10.33041573], [79.5248642, 10.3306942], [79.52180481, 10.3306942], [79.52180481, 10.33041573], [79.52124786, 10.33042145], [79.52124786, 10.33014011], [79.52097321, 10.33014011], [79.52097321, 10.32985973], [79.52041626, 10.32985973], [79.52041626, 10.32958412], [79.5201416, 10.32958412], [79.5201416, 10.32930565], [79.51985931, 10.32931137], [79.51985931, 10.32874966], [79.51957703, 10.32874966], [79.51957703, 10.32903004], [79.51930237, 10.32903004], [79.51930237, 10.32874966], [79.51902771, 10.32874966], [79.51902771, 10.32847023], [79.51875305, 10.32847214], [79.51875305, 10.32819366], [79.51819611, 10.32819366], [79.51819611, 10.32791805], [79.51790619, 10.32792091], [79.51790619, 10.32763958], [79.51735687, 10.32763958], [79.51735687, 10.32736015], [79.51600647, 10.32736015], [79.51568604, 10.32736015], [79.51568604, 10.32763958], [79.5150528, 10.32763767], [79.51457977, 10.32763767], [79.51457977, 10.32778072], [79.51457977, 10.32792091], [79.51430511, 10.32791805], [79.51430511, 10.32819366], [79.51319122, 10.32819366], [79.51319122, 10.32847214], [79.51264191, 10.32847023], [79.51264191, 10.32874966], [79.51236725, 10.32874966], [79.51236725, 10.32903004], [79.51207733, 10.32903004], [79.51207733, 10.32931137], [79.51152802, 10.32930565], [79.51152802, 10.32958412], [79.51097107, 10.32958412], [79.51097107, 10.32985973], [79.51040649, 10.32985973], [79.51040649, 10.33042145], [79.50985718, 10.33042145], [79.50985718, 10.33153057], [79.51180267, 10.33152771], [79.51180267, 10.3320837], [79.51235962, 10.3320837], [79.51235962, 10.33236027], [79.51291656, 10.33236027], [79.51291656, 10.33264065], [79.51346588, 10.33264065], [79.51346588, 10.33292103], [79.51374817, 10.33291626], [79.51374817, 10.33319378], [79.51403046, 10.33318996], [79.51403046, 10.33375072], [79.51430511, 10.33375072], [79.51430511, 10.33458233], [79.51403046, 10.33458233], [79.51403046, 10.33485985], [79.51374817, 10.33485985], [79.51374817, 10.33542061], [79.51346588, 10.33542061], [79.51347351, 10.33625126], [79.51319122, 10.33625126], [79.51319122, 10.33653069], [79.51291656, 10.33653069], [79.51291656, 10.33708858], [79.51264191, 10.33708477], [79.51264191, 10.33736134], [79.51235962, 10.33736134], [79.51235962, 10.33763885], [79.51180267, 10.33763885], [79.51180267, 10.33736134], [79.51069641, 10.33736134], [79.51069641, 10.33763885], [79.51040649, 10.33763885], [79.51040649, 10.33791924], [79.51013947, 10.33791733], [79.51013947, 10.33819485], [79.50977325, 10.33819485], [79.50958252, 10.33819485], [79.50958252, 10.33847332], [79.50819397, 10.33847332], [79.50819397, 10.33819485], [79.50763702, 10.33819485], [79.50763702, 10.33791733], [79.50708008, 10.33791924], [79.50708008, 10.33763885], [79.50653076, 10.33763885], [79.50653076, 10.33736134], [79.50624847, 10.33736134], [79.50624847, 10.33652878], [79.50541687, 10.33653069], [79.50541687, 10.33625126], [79.50514221, 10.33625126], [79.50514221, 10.33569527], [79.50430298, 10.33569527], [79.50430298, 10.33541679], [79.50402832, 10.33541679], [79.50402832, 10.33569527], [79.50375366, 10.33569527], [79.50375366, 10.33541679], [79.50347137, 10.33542061], [79.50347137, 10.33485985], [79.50319672, 10.33485985], [79.50319672, 10.33458233], [79.50291443, 10.33458233], [79.50291443, 10.3340292], [79.50235748, 10.33403111], [79.50235748, 10.33375072], [79.50180817, 10.33375072], [79.50180817, 10.33318996], [79.50152588, 10.33319378], [79.50152588, 10.33263779], [79.50180817, 10.33264065], [79.50180817, 10.33208179], [79.50180817, 10.33152771], [79.50208282, 10.33153057], [79.50208282, 10.32985973], [79.50235748, 10.32985973], [79.50235748, 10.32958412], [79.50263977, 10.32958412], [79.50263977, 10.32930565], [79.50514221, 10.32931137], [79.50514221, 10.32903004], [79.50541687, 10.32903004], [79.50541687, 10.3281889], [79.50514221, 10.32819366], [79.50514221, 10.32586002], [79.50514221, 10.32319355], [79.50485992, 10.32319355], [79.50485992, 10.3226366], [79.5045929, 10.32264042], [79.5045929, 10.32209015], [79.50402832, 10.32209015], [79.50402832, 10.32180977], [79.50374603, 10.32180977], [79.50374603, 10.32153034], [79.50319672, 10.32153034], [79.50319672, 10.32125187], [79.50263977, 10.32125187], [79.50263977, 10.32097054], [79.50208282, 10.32097054], [79.50208282, 10.32069588], [79.50180817, 10.32069302], [79.50180817, 10.32041836], [79.50125122, 10.32042027], [79.50125122, 10.32014179], [79.49931335, 10.32014179], [79.49931335, 10.32042027], [79.49847412, 10.32041836], [79.49847412, 10.32069302], [79.49736023, 10.32069588], [79.49736023, 10.32097054], [79.49652863, 10.32097054], [79.49652863, 10.32125187], [79.49569702, 10.32125187], [79.49569702, 10.32153034], [79.49514008, 10.32153034], [79.49514008, 10.32209015], [79.4954071, 10.32209015], [79.4954071, 10.32264042], [79.49569702, 10.3226366], [79.49569702, 10.32347202], [79.49597168, 10.32347202], [79.49597168, 10.32486153], [79.49624634, 10.32485962], [79.49624634, 10.32542038], [79.49652863, 10.32541561], [79.49652863, 10.32736206], [79.49680328, 10.32736206], [79.49680328, 10.32819366], [79.49652863, 10.32819366], [79.49652863, 10.32791805], [79.49624634, 10.32792091], [79.49624634, 10.32763958], [79.49597168, 10.32763958], [79.49597168, 10.32708168], [79.49569702, 10.32708359], [79.49569702, 10.32680607], [79.4954071, 10.32681274], [79.4954071, 10.32653046], [79.49514008, 10.32653046], [79.49514008, 10.32625008], [79.49485779, 10.32625008], [79.49485779, 10.3259697], [79.49458313, 10.3259716], [79.49458313, 10.32541561], [79.49430084, 10.32542038], [79.49430084, 10.32515144], [79.49402618, 10.32515144], [79.49402618, 10.32347202], [79.49375153, 10.32347202], [79.49375153, 10.32236195], [79.49402618, 10.32236195], [79.49402618, 10.32208443], [79.49430084, 10.32209015], [79.49430084, 10.32153034], [79.49458313, 10.32153034], [79.49458313, 10.32097054], [79.49485779, 10.32097054], [79.49485779, 10.32013988], [79.49514008, 10.32014179], [79.49514008, 10.31986141], [79.49541473, 10.31986141], [79.49541473, 10.31958294], [79.49569702, 10.31958294], [79.49569702, 10.31902695], [79.49597168, 10.31902695], [79.49597168, 10.31874943], [79.49541473, 10.31874943], [79.49541473, 10.31902695], [79.49485779, 10.31902027], [79.49485779, 10.31931019], [79.49458313, 10.31930542], [79.49458313, 10.31958294], [79.49402618, 10.31958294], [79.49402618, 10.31986141], [79.49346924, 10.31986141], [79.49346924, 10.32014179], [79.49291992, 10.32014179], [79.49291992, 10.32042027], [79.49263763, 10.32041836], [79.49263763, 10.32069111], [79.49236298, 10.32069969], [79.49236298, 10.32125187], [79.49208069, 10.32125187], [79.49208069, 10.32209015], [79.49236298, 10.32208443], [79.49236298, 10.32236195], [79.49263763, 10.32236195], [79.49263763, 10.32264042], [79.49291992, 10.32264042], [79.49291992, 10.32374954], [79.49208069, 10.32374954], [79.49208069, 10.32402992], [79.49180603, 10.32402992], [79.49180603, 10.3243103], [79.49013519, 10.32430553], [79.49013519, 10.32458401], [79.48958588, 10.32458401], [79.48958588, 10.32486153], [79.48874664, 10.32485962], [79.48874664, 10.32515144], [79.48764038, 10.32514], [79.48764038, 10.32569408], [79.48791504, 10.32569408], [79.48791504, 10.3259716], [79.48819733, 10.3259697], [79.48819733, 10.32625008], [79.48847198, 10.32625008], [79.48847198, 10.32736206], [79.48819733, 10.32736015], [79.48819733, 10.32763958], [79.48764038, 10.32763958], [79.48764038, 10.32792091], [79.48735809, 10.32791805], [79.48735809, 10.32847214], [79.48764038, 10.32847023], [79.48764038, 10.32874966], [79.48902893, 10.32874966], [79.48902893, 10.32847023], [79.48958588, 10.32847214], [79.48958588, 10.32819366], [79.49013519, 10.32819366], [79.49013519, 10.32847214], [79.49124908, 10.32847214], [79.49124908, 10.32819366], [79.49236298, 10.32819366], [79.49236298, 10.32791805], [79.49318695, 10.32792091], [79.49318695, 10.32763958], [79.49430084, 10.32763958], [79.49430084, 10.32792091], [79.49458313, 10.32791805], [79.49458313, 10.32847214], [79.49485779, 10.32847214], [79.49485779, 10.3303318], [79.49485779, 10.3306942], [79.49402618, 10.3306942], [79.49402618, 10.33097172], [79.49337006, 10.33097172], [79.49319458, 10.33097172], [79.49319458, 10.3306942], [79.49263763, 10.3306942], [79.49263763, 10.33041573], [79.49236298, 10.33042145], [79.49236298, 10.33014011], [79.49208069, 10.33014011], [79.49208069, 10.32985973], [79.49124146, 10.32985973], [79.49124146, 10.32931137], [79.48930359, 10.32930565], [79.48930359, 10.32958412], [79.48874664, 10.32958412], [79.48874664, 10.32985973], [79.48792267, 10.32985973], [79.48792267, 10.33014011], [79.48735809, 10.33013821], [79.48735809, 10.3306942], [79.48707581, 10.33069038], [79.48708344, 10.33125019], [79.48680878, 10.33125019], [79.48680878, 10.33181095], [79.48652649, 10.33180428], [79.48652649, 10.33236027], [79.48680878, 10.33236027], [79.48680878, 10.33264065], [79.48625183, 10.33264065], [79.48625183, 10.33375072], [79.48596954, 10.33375072], [79.48596954, 10.33403111], [79.48652649, 10.3340292], [79.48652649, 10.3353796], [79.48652649, 10.33569527], [79.48603058, 10.33569527], [79.48569489, 10.33569527], [79.48561859, 10.33591557], [79.48208618, 10.33597279], [79.48208618, 10.33625126], [79.48179626, 10.33625126], [79.48179626, 10.33653069], [79.48014069, 10.33653069], [79.48014069, 10.33625126], [79.4798584, 10.33625126], [79.4798584, 10.33597279], [79.47958374, 10.33597279], [79.47958374, 10.33569527], [79.47930908, 10.33569527], [79.47930908, 10.33541679], [79.47902679, 10.33542061], [79.47902679, 10.33514118], [79.47763824, 10.33513927], [79.47763824, 10.33569527], [79.47736359, 10.33569527], [79.47736359, 10.33597279], [79.47680664, 10.33597279], [79.47680664, 10.33625126], [79.47625732, 10.33625126], [79.47625732, 10.33653069], [79.4751358, 10.33653069], [79.4751358, 10.33681107], [79.47402954, 10.33681107], [79.47402954, 10.33653069], [79.4715271, 10.33653069], [79.4715271, 10.33681107], [79.47097015, 10.33680534], [79.47097015, 10.33736134], [79.4706955, 10.33736134], [79.4706955, 10.33763885], [79.47041321, 10.33763885], [79.47041321, 10.33819485], [79.47013855, 10.33819485], [79.47013855, 10.33847332], [79.46985626, 10.33847141], [79.46985626, 10.33903122], [79.4695816, 10.33903122], [79.4695816, 10.3393116], [79.46902466, 10.33930492], [79.46902466, 10.3395834], [79.46847534, 10.3395834], [79.46847534, 10.33986092], [79.4679184, 10.33986092], [79.4679184, 10.34013939], [79.46569824, 10.34013939], [79.46569061, 10.33986092], [79.46541595, 10.33986092], [79.46541595, 10.3395834], [79.4651413, 10.3395834], [79.4651413, 10.33930492], [79.46235657, 10.3393116], [79.46235657, 10.33903122], [79.46208191, 10.33903122], [79.46208191, 10.33875084], [79.46180725, 10.33875084], [79.46180725, 10.33847141], [79.46152496, 10.33847332], [79.46152496, 10.33819485], [79.46125031, 10.33819485], [79.46125031, 10.33791733], [79.4576416, 10.33791924], [79.4576416, 10.33875084], [79.45735931, 10.33875084], [79.45735931, 10.34013939], [79.45708466, 10.34013939], [79.45708466, 10.34069538], [79.45680237, 10.34069538], [79.45680237, 10.34097099], [79.45652771, 10.34097099], [79.45652771, 10.34152889], [79.45625305, 10.34152699], [79.45625305, 10.34208298], [79.45597076, 10.34208298], [79.45597076, 10.34152699], [79.45569611, 10.34152889], [79.45569611, 10.33986092], [79.45540619, 10.33986092], [79.45540619, 10.33875084], [79.45513153, 10.33875084], [79.45513153, 10.33791924], [79.45485687, 10.33791924], [79.45485687, 10.33653069], [79.45513153, 10.33653069], [79.45513153, 10.33625126], [79.45569611, 10.33625126], [79.45569611, 10.33653069], [79.45847321, 10.33653069], [79.45847321, 10.33596992], [79.45874786, 10.33597279], [79.45874786, 10.33513927], [79.45903015, 10.33514118], [79.45903015, 10.33542061], [79.45930481, 10.33541679], [79.45930481, 10.33597279], [79.4595871, 10.33597279], [79.4595871, 10.33625126], [79.45986176, 10.33625126], [79.45986176, 10.33653069], [79.46013641, 10.33653069], [79.46013641, 10.33681107], [79.4604187, 10.33681107], [79.4604187, 10.33708858], [79.46153259, 10.33708858], [79.46153259, 10.33681107], [79.46180725, 10.33681107], [79.46180725, 10.33653069], [79.46235657, 10.33653069], [79.46235657, 10.33625126], [79.46263885, 10.33625126], [79.46263885, 10.33763885], [79.4631958, 10.33763885], [79.4631958, 10.33791924], [79.46375275, 10.33791733], [79.46375275, 10.33819485], [79.46430206, 10.33819485], [79.46430206, 10.33847332], [79.46485901, 10.33847141], [79.46485901, 10.33875084], [79.46541595, 10.33875084], [79.46541595, 10.33903122], [79.46652985, 10.33903122], [79.46652985, 10.33875084], [79.46679688, 10.33875084], [79.46679688, 10.33819008], [79.46708679, 10.33819485], [79.46708679, 10.33791733], [79.46736145, 10.33791924], [79.46736145, 10.33763885], [79.46763611, 10.33763885], [79.46763611, 10.33708286], [79.4679184, 10.33708858], [79.4679184, 10.33653069], [79.46848297, 10.33653069], [79.46848297, 10.33596992], [79.46875, 10.33597279], [79.46875, 10.33569527], [79.47597504, 10.33569527], [79.47597504, 10.33541679], [79.47625732, 10.33542061], [79.47625732, 10.33514118], [79.47680664, 10.33514118], [79.47680664, 10.33485985], [79.4770813, 10.33485985], [79.4770813, 10.33458233], [79.47763824, 10.33458233], [79.47763824, 10.33430672], [79.4779129, 10.33431053], [79.4779129, 10.33403111], [79.48069763, 10.33403111], [79.48069763, 10.33375072], [79.48097229, 10.33375072], [79.48097229, 10.33347034], [79.48124695, 10.33347225], [79.48124695, 10.33319378], [79.48152924, 10.33319378], [79.48152924, 10.33263779], [79.48179626, 10.33264065], [79.48179626, 10.33181095], [79.48208618, 10.33181095], [79.48208618, 10.33125019], [79.48236084, 10.33125019], [79.48236084, 10.3306942], [79.4826355, 10.3306942], [79.4826355, 10.33013821], [79.48291779, 10.33014011], [79.48291779, 10.32985973], [79.48319244, 10.32985973], [79.48319244, 10.32958412], [79.48347473, 10.32958412], [79.48347473, 10.32902813], [79.48374939, 10.32903004], [79.48374939, 10.32874966], [79.48401642, 10.32874966], [79.48401642, 10.32847023], [79.48430634, 10.32847214], [79.48430634, 10.32819366], [79.48458099, 10.32819366], [79.48458099, 10.32791805], [79.48486328, 10.32792091], [79.48486328, 10.32763958], [79.48513794, 10.32763958], [79.48513794, 10.32736015], [79.48542023, 10.32736206], [79.48542023, 10.32708359], [79.48569489, 10.32708359], [79.48569489, 10.32680607], [79.48596954, 10.32681274], [79.48596954, 10.32653046], [79.48625183, 10.32653046], [79.48625183, 10.32625008], [79.48652649, 10.32625008], [79.48652649, 10.3259697], [79.48625183, 10.3259716], [79.48625183, 10.32541561], [79.48596954, 10.32542038], [79.48596954, 10.32485962], [79.48402405, 10.32486153], [79.48402405, 10.32458401], [79.48319244, 10.32458401], [79.48319244, 10.32430553], [79.48097229, 10.3243103], [79.48097229, 10.32402992], [79.47875214, 10.32402992], [79.47875214, 10.3243103], [79.47846985, 10.32430553], [79.47846985, 10.32458401], [79.47680664, 10.32458401], [79.47680664, 10.32486153], [79.47625732, 10.32485962], [79.47625732, 10.32515144], [79.47569275, 10.32515144], [79.47569275, 10.32542038], [79.47541809, 10.32541561], [79.47541809, 10.32569408], [79.4751358, 10.32569408], [79.4751358, 10.3259716], [79.47291565, 10.3259716], [79.47291565, 10.32569408], [79.47125244, 10.32569408], [79.47125244, 10.32541561], [79.47097015, 10.32542038], [79.47097015, 10.32485962], [79.4679184, 10.32485962], [79.4679184, 10.32515144], [79.46624756, 10.32515144], [79.46624756, 10.32542038], [79.46290588, 10.32542038], [79.46290588, 10.32515144], [79.46069336, 10.32515144], [79.46069336, 10.32542038], [79.4604187, 10.32541561], [79.4604187, 10.3259716], [79.46013641, 10.3259697], [79.46013641, 10.32653046], [79.45986176, 10.3265276], [79.45986176, 10.32708359], [79.45819092, 10.32708359], [79.45819092, 10.32625008], [79.45791626, 10.32625008], [79.45791626, 10.32515144], [79.45735931, 10.32515144], [79.45735931, 10.3243103], [79.4576416, 10.3243103], [79.4576416, 10.32153034], [79.45707703, 10.32153034], [79.45707703, 10.32097054], [79.45680237, 10.32097054], [79.45680237, 10.32069302], [79.45708466, 10.32069302], [79.45708466, 10.32041836], [79.46069336, 10.32042027], [79.46069336, 10.32014179], [79.46153259, 10.32014179], [79.46153259, 10.31986141], [79.46263885, 10.31986141], [79.46263885, 10.31958294], [79.46347046, 10.31958294], [79.46347046, 10.31930542], [79.4679184, 10.31931019], [79.4679184, 10.31902027], [79.47041321, 10.31902695], [79.47041321, 10.31874943], [79.4723587, 10.31874943], [79.4723587, 10.31847095], [79.47374725, 10.31847095], [79.47374725, 10.31819534], [79.48097229, 10.31819534], [79.48097229, 10.31791687], [79.48430634, 10.31791973], [79.48430634, 10.31763935], [79.48542786, 10.31763935], [79.48542786, 10.31736088], [79.48652649, 10.31736088], [79.48652649, 10.31708336], [79.49291992, 10.31708336], [79.49291992, 10.31680489], [79.49764252, 10.31680489], [79.49764252, 10.31708336], [79.49819183, 10.31708336], [79.49819183, 10.31736088], [79.49846649, 10.31736088], [79.49846649, 10.31763935], [79.49931335, 10.31763935], [79.49931335, 10.31624889], [79.50125122, 10.31624889], [79.50125122, 10.31597328], [79.50347137, 10.31597328], [79.50347137, 10.31569481], [79.50541687, 10.31569481], [79.50541687, 10.31541729], [79.50763702, 10.3154192], [79.50763702, 10.31514072], [79.51374817, 10.31514072], [79.51374817, 10.3154192], [79.51430511, 10.31541729], [79.51430511, 10.31569481], [79.51541901, 10.31569481], [79.51541901, 10.31597328], [79.51597595, 10.31597328], [79.51597595, 10.31624889], [79.51763916, 10.31624889], [79.51763916, 10.31597328], [79.51791382, 10.31597328], [79.51791382, 10.31541729], [79.51819611, 10.3154192], [79.51819611, 10.31514072], [79.51790619, 10.31514072], [79.51790619, 10.3148613], [79.51763916, 10.3148613], [79.51763916, 10.31458282], [79.51708221, 10.31458282], [79.51708221, 10.31430531], [79.51680756, 10.31431198], [79.51680756, 10.31403065], [79.5165329, 10.31403065], [79.5165329, 10.31375122], [79.51625061, 10.31375122], [79.51625061, 10.31347084], [79.51568604, 10.31347084], [79.51568604, 10.31319046], [79.51541901, 10.31319523], [79.51541901, 10.31291676], [79.51513672, 10.31292152], [79.51513672, 10.31264114], [79.51486206, 10.31264114], [79.51486206, 10.31235886], [79.51457977, 10.31236076], [79.51457977, 10.31180477], [79.51431274, 10.3118124], [79.51431274, 10.31153107], [79.51403046, 10.31153107], [79.51403046, 10.31125069], [79.51374817, 10.31125069], [79.51374817, 10.31068993], [79.51347351, 10.31069469], [79.51347351, 10.31041718], [79.51319122, 10.31042099], [79.51319122, 10.31015015], [79.51291656, 10.31015015], [79.51291656, 10.30957985], [79.51264191, 10.30958271], [79.51264191, 10.30930519], [79.51236725, 10.30931091], [79.51236725, 10.30903053], [79.51097107, 10.30903053], [79.51097107, 10.30875111], [79.51013947, 10.30875111], [79.51013947, 10.30847263], [79.50985718, 10.30846977], [79.50986481, 10.30875111], [79.50958252, 10.30875111], [79.50958252, 10.30847263], [79.50680542, 10.30847263], [79.50680542, 10.30875111], [79.50514221, 10.30875111], [79.50514221, 10.30903053], [79.5045929, 10.30903053], [79.5045929, 10.30931091], [79.50402832, 10.30930519], [79.50402832, 10.30958271], [79.50263977, 10.30958271], [79.50263977, 10.30986118], [79.50180817, 10.30986118], [79.50180817, 10.30930519], [79.50125122, 10.30930519], [79.50125122, 10.30958271], [79.50096893, 10.30958271], [79.50096893, 10.30930519], [79.50069427, 10.30930519], [79.50069427, 10.30958271], [79.49986267, 10.30958271], [79.49986267, 10.30986118], [79.49931335, 10.30986118], [79.49931335, 10.31015015], [79.49819183, 10.31015015], [79.49819183, 10.30986118], [79.49791718, 10.30986118], [79.49791718, 10.31015015], [79.49652863, 10.31015015], [79.49652863, 10.30986118], [79.49569702, 10.30986118], [79.49569702, 10.31015015], [79.49263763, 10.31015015], [79.49263763, 10.30986118], [79.49208069, 10.30986118], [79.49208069, 10.31015015], [79.49153137, 10.31015015], [79.49153137, 10.30986118], [79.49069214, 10.30986118], [79.49069214, 10.31015015], [79.48986053, 10.31015015], [79.48986053, 10.31042099], [79.48680878, 10.31041718], [79.48680878, 10.31069469], [79.48097229, 10.31069469], [79.48097229, 10.31097317], [79.4770813, 10.31097126], [79.4770813, 10.31125069], [79.4751358, 10.31125069], [79.4751358, 10.31153107], [79.47319794, 10.31153107], [79.47319794, 10.3118124], [79.4723587, 10.3118124], [79.4723587, 10.31153107], [79.47207642, 10.31153107], [79.47207642, 10.3118124], [79.4706955, 10.31180477], [79.4706955, 10.31208324], [79.46819305, 10.31208324], [79.46819305, 10.31236076], [79.4659729, 10.31235886], [79.4659729, 10.31264114], [79.4651413, 10.31264114], [79.4651413, 10.31235886], [79.46485901, 10.31235886], [79.46485901, 10.31264114], [79.4631958, 10.31264114], [79.4631958, 10.31292152], [79.46180725, 10.31292152], [79.46180725, 10.31264114], [79.46153259, 10.31264114], [79.46153259, 10.31292152], [79.45986176, 10.31291676], [79.45986176, 10.31319523], [79.45707703, 10.31319046], [79.45707703, 10.31347084], [79.45540619, 10.31347084], [79.45540619, 10.31375122], [79.45485687, 10.31375122], [79.45485687, 10.31347084], [79.45458221, 10.31347084], [79.45458221, 10.31375122], [79.45263672, 10.31375122], [79.45263672, 10.31403065], [79.45124817, 10.31403065], [79.45124817, 10.31431198], [79.45041656, 10.31430531], [79.45041656, 10.31458282], [79.44985962, 10.31458282], [79.44985962, 10.31430531], [79.44625092, 10.31431198], [79.44625092, 10.31403065], [79.44541931, 10.31403065], [79.44541931, 10.31375122], [79.44403076, 10.31375122], [79.44403076, 10.31403065], [79.44069672, 10.31403065], [79.44069672, 10.31431198], [79.44041443, 10.31430531], [79.44041443, 10.31458282], [79.44013977, 10.31458282], [79.44013977, 10.3148613], [79.43958282, 10.3148613], [79.43958282, 10.31458282], [79.43930817, 10.31458282], [79.43930817, 10.3148613], [79.43902588, 10.3148613], [79.43902588, 10.31514072], [79.43875122, 10.31514072], [79.43875122, 10.3154192], [79.43708038, 10.31541729], [79.43708038, 10.31569481], [79.43680573, 10.31569481], [79.43680573, 10.31541729], [79.43402863, 10.3154192], [79.43402863, 10.31514072], [79.43319702, 10.31514072], [79.43319702, 10.3148613], [79.4329071, 10.3148613], [79.4329071, 10.31514072], [79.43235779, 10.31514072], [79.43235779, 10.3154192], [79.43041992, 10.3154192], [79.43041992, 10.31514072], [79.43013763, 10.31514072], [79.43013763, 10.3154192], [79.42930603, 10.3154192], [79.42930603, 10.31514072], [79.42791748, 10.31514072], [79.42791748, 10.3154192], [79.42764282, 10.3154192], [79.42764282, 10.31514072], [79.42708588, 10.31514072], [79.42708588, 10.3154192], [79.42652893, 10.31541729], [79.42652893, 10.31569481], [79.42541504, 10.31569481], [79.42541504, 10.31597328], [79.42514038, 10.31597328], [79.42514038, 10.31569481], [79.42485809, 10.31569481], [79.42485809, 10.31597328], [79.42430878, 10.31597328], [79.42430878, 10.31569481], [79.42402649, 10.31569481], [79.42402649, 10.31597328], [79.42346954, 10.31597328], [79.42346954, 10.31624889], [79.42263794, 10.31624889], [79.42263794, 10.31597328], [79.42208099, 10.31597328], [79.42208099, 10.31624889], [79.41819763, 10.31624889], [79.41819763, 10.31652927], [79.41680908, 10.31652927], [79.41680908, 10.31680965], [79.41402435, 10.31680489], [79.41402435, 10.31708336], [79.41347504, 10.31708336], [79.41347504, 10.31680489], [79.4126358, 10.31680489], [79.4126358, 10.31708336], [79.40875244, 10.31708336], [79.40875244, 10.31736088], [79.40847015, 10.31736088], [79.40847015, 10.31680489], [79.4081955, 10.31680489], [79.4081955, 10.31736088], [79.40763855, 10.31736088], [79.40763855, 10.31708336], [79.4070816, 10.31708336], [79.4070816, 10.31736088], [79.40486145, 10.31736088], [79.40486145, 10.31763935], [79.40458679, 10.31763935], [79.40458679, 10.31736088], [79.40291595, 10.31736088], [79.40291595, 10.31763935], [79.4015274, 10.31763935], [79.4015274, 10.31736088], [79.40125275, 10.31736088], [79.40125275, 10.31763935], [79.39903259, 10.31763935], [79.39903259, 10.31736088], [79.39736176, 10.31736088], [79.39736176, 10.31763935], [79.39679718, 10.31763935], [79.39679718, 10.31791973], [79.39485168, 10.31791973], [79.39485168, 10.31763935], [79.39347076, 10.31763935], [79.39347076, 10.31736088], [79.39235687, 10.31736088], [79.39235687, 10.31763935], [79.3915329, 10.31763935], [79.3915329, 10.31736088], [79.39068604, 10.31736088], [79.39068604, 10.31708145], [79.38819122, 10.31708336], [79.38819122, 10.31680489], [79.38709259, 10.31680965], [79.38709259, 10.31652927], [79.38625336, 10.31652927], [79.38625336, 10.31680965], [79.38569641, 10.31680965], [79.38569641, 10.31652927], [79.38513947, 10.31652927], [79.38513947, 10.31624889], [79.38430786, 10.31624889], [79.38430786, 10.31597328], [79.38291931, 10.31597328], [79.38291931, 10.31569481], [79.38236237, 10.31569481], [79.38236237, 10.31541729], [79.38208008, 10.3154192], [79.38208008, 10.31458092], [79.38180542, 10.31458282], [79.38180542, 10.31430531], [79.38153076, 10.31431198], [79.38153076, 10.31375122], [79.38124847, 10.31375122], [79.38124847, 10.31347084], [79.38096619, 10.31347084], [79.38096619, 10.31319046], [79.38069153, 10.31319523], [79.38069153, 10.31291676], [79.38041687, 10.31292152], [79.38041687, 10.31264114], [79.38014221, 10.31264114], [79.38014221, 10.31235886], [79.37985992, 10.31236076], [79.37985992, 10.31180477], [79.3795929, 10.3118124], [79.3795929, 10.31125069], [79.37930298, 10.31125069], [79.37930298, 10.31068993], [79.37902832, 10.31069469], [79.37902832, 10.30986118], [79.37875366, 10.30986118], [79.37875366, 10.3092289], [79.37875366, 10.30875111], [79.37847137, 10.30875111], [79.37847137, 10.30791664], [79.37819672, 10.30792141], [79.37819672, 10.30708027], [79.37791443, 10.30708218], [79.37791443, 10.30680656], [79.37763977, 10.30681133], [79.37763977, 10.30597019], [79.37735748, 10.3059721], [79.37735748, 10.30569363], [79.37763977, 10.30569363], [79.37763977, 10.30513763], [79.37735748, 10.30514145], [79.37735748, 10.30457973], [79.37708282, 10.30458355], [79.37708282, 10.30402756], [79.37680817, 10.30402756], [79.37680817, 10.30347157], [79.37652588, 10.30347157], [79.37652588, 10.30291557], [79.37625122, 10.3029213], [79.37625122, 10.30235958], [79.37596893, 10.30236244], [79.37596893, 10.30208206], [79.37569427, 10.30208206], [79.37569427, 10.30152798], [79.37541962, 10.30153275], [79.37541962, 10.30125046], [79.37513733, 10.30125046], [79.37513733, 10.30069447], [79.37486267, 10.30069447], [79.37486267, 10.30041599], [79.37458038, 10.30042267], [79.37458038, 10.30014038], [79.37431335, 10.30014038], [79.37431335, 10.29957867], [79.37403107, 10.29958439], [79.37403107, 10.29930592], [79.37374878, 10.29931068], [79.37374878, 10.29874992], [79.37346649, 10.29874992], [79.37346649, 10.29846954], [79.37319183, 10.2984724], [79.37319183, 10.29819584], [79.37291718, 10.29819584], [79.37291718, 10.29791641], [79.37264252, 10.29792023], [79.37264252, 10.29763985], [79.37236023, 10.29763985], [79.37236023, 10.29736042], [79.37208557, 10.29736233], [79.37208557, 10.29708385], [79.37180328, 10.29708385], [79.37180328, 10.29680634], [79.37152863, 10.29681015], [79.37152863, 10.29652977], [79.37124634, 10.29652977], [79.37124634, 10.29625034], [79.37097168, 10.29625034], [79.37097168, 10.29597187], [79.37069702, 10.29597187], [79.37069702, 10.29569435], [79.37014008, 10.29569435], [79.37014008, 10.29541779], [79.36985779, 10.29541969], [79.36985779, 10.29514027], [79.36958313, 10.29514027], [79.36958313, 10.29485035], [79.36875153, 10.29485035], [79.36875153, 10.29514027], [79.36846924, 10.29514027], [79.36846924, 10.29569435], [79.36819458, 10.29569435], [79.36819458, 10.29597187], [79.36791229, 10.29597187], [79.36791992, 10.29625034], [79.36763763, 10.29625034], [79.36763763, 10.29681015], [79.36708069, 10.29680634], [79.36708069, 10.29708385], [79.36653137, 10.29708385], [79.36653137, 10.29736233], [79.36624908, 10.29736042], [79.36624908, 10.29763985], [79.3659668, 10.29763985], [79.3659668, 10.29792023], [79.36569214, 10.29791641], [79.36569214, 10.29819584], [79.36541748, 10.29819584], [79.36541748, 10.2984724], [79.36486816, 10.29846954], [79.36486816, 10.29874992], [79.36429596, 10.29874992], [79.36429596, 10.2990303], [79.36402893, 10.2990303], [79.36402893, 10.29931068], [79.36374664, 10.29930592], [79.36374664, 10.29958439], [79.36347198, 10.29958439], [79.36347198, 10.29986191], [79.36319733, 10.29986191], [79.36319733, 10.30014038], [79.36264038, 10.30014038], [79.36264038, 10.30042267], [79.36208344, 10.30041599], [79.36208344, 10.30069447], [79.36125183, 10.3006916], [79.36123657, 10.30098057], [79.36042023, 10.30097198], [79.36042023, 10.30125046], [79.35986328, 10.30125046], [79.35986328, 10.30153275], [79.35930634, 10.30153275], [79.35930634, 10.30181122], [79.35902405, 10.30180645], [79.35902405, 10.30208206], [79.35847473, 10.30208206], [79.35847473, 10.30069447], [79.35902405, 10.30069447], [79.35902405, 10.30041599], [79.35958099, 10.30042267], [79.35958099, 10.30014038], [79.36013794, 10.30014038], [79.36013794, 10.30000973], [79.36013794, 10.29986191], [79.36069489, 10.29986191], [79.36068726, 10.29957867], [79.36096954, 10.29958439], [79.36096954, 10.29930592], [79.36152649, 10.29931068], [79.36152649, 10.2990303], [79.36207581, 10.2990303], [79.36207581, 10.29874992], [79.36264038, 10.29874992], [79.36264038, 10.29846954], [79.36291504, 10.2984724], [79.36291504, 10.29819584], [79.36319733, 10.29819584], [79.36319733, 10.29791641], [79.36347198, 10.29792023], [79.36347198, 10.29763985], [79.36374664, 10.29763985], [79.36374664, 10.29736042], [79.36402893, 10.29736233], [79.36402893, 10.29708385], [79.36430359, 10.29708385], [79.36430359, 10.29680634], [79.36458588, 10.29681015], [79.36458588, 10.29652977], [79.36486816, 10.29652977], [79.36486816, 10.29625034], [79.36513519, 10.29625034], [79.36513519, 10.29569435], [79.36541748, 10.29569435], [79.36541748, 10.29541779], [79.36569214, 10.29541969], [79.36569214, 10.29514027], [79.3659668, 10.29514027], [79.3659668, 10.29458141], [79.36624908, 10.29458427], [79.36624908, 10.2943058], [79.36653137, 10.29430962], [79.36653137, 10.29319096], [79.36624908, 10.29319572], [79.36624908, 10.29263878], [79.3659668, 10.29264164], [79.3659668, 10.29208088], [79.36430359, 10.29208279], [79.36430359, 10.29236126], [79.36291504, 10.29236126], [79.36291504, 10.29208279], [79.36235809, 10.29208279], [79.36235809, 10.29180527], [79.36180878, 10.29181004], [79.36180878, 10.29152966], [79.36125183, 10.29152966], [79.36125183, 10.29124928], [79.36068726, 10.29124928], [79.36068726, 10.29096889], [79.36013794, 10.2909708], [79.36013794, 10.29069328], [79.35958099, 10.29069328], [79.35958099, 10.29041672], [79.35901642, 10.29041958], [79.35901642, 10.2901392], [79.3584671, 10.2901392], [79.3584671, 10.28986073], [79.35791779, 10.28986073], [79.35791779, 10.28958321], [79.35708618, 10.28958321], [79.35708618, 10.28930473], [79.35597229, 10.28931046], [79.35597229, 10.28904057], [79.35514069, 10.28904057], [79.35514069, 10.28875065], [79.35402679, 10.28875065], [79.35402679, 10.28847122], [79.35319519, 10.28847313], [79.35319519, 10.28791714], [79.3529129, 10.28792191], [79.3529129, 10.28764057], [79.35263824, 10.28764057], [79.35263824, 10.28736115], [79.35236359, 10.28736115], [79.35236359, 10.28708267], [79.3520813, 10.28708267], [79.3520813, 10.28652668], [79.35180664, 10.28653145], [79.35180664, 10.28625107], [79.35151672, 10.28625107], [79.35151672, 10.28598022], [79.35098267, 10.28598022], [79.35098267, 10.28625107], [79.35069275, 10.28625107], [79.35069275, 10.28736115], [79.35041809, 10.28736115], [79.35041809, 10.28847313], [79.3501358, 10.28847313], [79.3501358, 10.28958321], [79.34986877, 10.2895813], [79.34986877, 10.2901392], [79.3484726, 10.2901392], [79.3484726, 10.29208279], [79.34874725, 10.29208279], [79.34874725, 10.29319572], [79.34902954, 10.29319572], [79.34902954, 10.29374886], [79.34874725, 10.29374886], [79.34874725, 10.29403019], [79.3484726, 10.29403019], [79.3484726, 10.29430962], [79.34819794, 10.2943058], [79.34819794, 10.29486179], [79.34791565, 10.29486179], [79.34791565, 10.29597187], [79.34764099, 10.29597187], [79.34764099, 10.29541779], [79.3473587, 10.29541969], [79.3473587, 10.29514027], [79.34707642, 10.29514027], [79.34707642, 10.29458141], [79.3473587, 10.29458427], [79.3473587, 10.29180527], [79.34764099, 10.29181004], [79.34764099, 10.29096889], [79.34791565, 10.2909708], [79.34791565, 10.29041672], [79.34764099, 10.29041958], [79.34764099, 10.2901392], [79.3473587, 10.2901392], [79.3473587, 10.2895813], [79.34708405, 10.28958321], [79.34708405, 10.28847313], [79.3473587, 10.28847313], [79.3473587, 10.28819466], [79.34764099, 10.28819466], [79.34764099, 10.28791714], [79.34792328, 10.28792191], [79.34792328, 10.28736115], [79.34764099, 10.28736115], [79.34764099, 10.28708267], [79.3473587, 10.28708267], [79.3473587, 10.28680515], [79.3465271, 10.28681183], [79.3465271, 10.28653145], [79.34541321, 10.28653145], [79.34541321, 10.28681183], [79.34263611, 10.28680515], [79.34263611, 10.28708267], [79.34124756, 10.28708267], [79.34124756, 10.28680515], [79.3401413, 10.28681183], [79.3401413, 10.28653145], [79.33875275, 10.28653145], [79.33875275, 10.28625107], [79.33763885, 10.28625107], [79.33763885, 10.28598022], [79.33680725, 10.28598022], [79.33680725, 10.28569031], [79.33625031, 10.28569508], [79.33625031, 10.2854166], [79.33374786, 10.28542137], [79.33374786, 10.28514099], [79.33319092, 10.28514099], [79.33319092, 10.28486061], [79.33235931, 10.28486061], [79.33235931, 10.28458309], [79.33180237, 10.28458309], [79.33180237, 10.28430462], [79.33097076, 10.28430939], [79.33097076, 10.28403091], [79.33040619, 10.28403091], [79.33040619, 10.28375053], [79.32985687, 10.28375053], [79.32985687, 10.28347111], [79.32930756, 10.28347301], [79.32930756, 10.28319454], [79.32875061, 10.28319454], [79.32875061, 10.28291702], [79.32819366, 10.28291702], [79.32819366, 10.28263855], [79.32763672, 10.28264141], [79.32763672, 10.28236103], [79.32707977, 10.28236103], [79.32707977, 10.28208256], [79.32653046, 10.28208256], [79.32653046, 10.28180695], [79.32596588, 10.28181076], [79.32596588, 10.28153133], [79.32569885, 10.28153133], [79.32569885, 10.28125095], [79.32514191, 10.28125095], [79.32514191, 10.28096962], [79.32485962, 10.28097343], [79.32485962, 10.28069496], [79.32430267, 10.28069496], [79.32430267, 10.28041553], [79.32375336, 10.28042126], [79.32375336, 10.28014088], [79.32347107, 10.28014088], [79.32347107, 10.27985096], [79.32291412, 10.27985954], [79.32291412, 10.27958202], [79.32263947, 10.27958202], [79.32263947, 10.27930737], [79.32208252, 10.27931118], [79.32208252, 10.2790308], [79.3215332, 10.2790308], [79.3215332, 10.27875042], [79.32125092, 10.27875042], [79.32125092, 10.27847195], [79.32096863, 10.27847195], [79.32096863, 10.27819443], [79.32041931, 10.27819443], [79.32041931, 10.27791595], [79.31986237, 10.27792072], [79.31986237, 10.27707958], [79.31958008, 10.27708435], [79.31958008, 10.27652836], [79.31931305, 10.27653122], [79.31931305, 10.27625179], [79.31903076, 10.27625179], [79.31903076, 10.27597046], [79.31819153, 10.27597046], [79.31819153, 10.27625179], [79.31791687, 10.27625179], [79.31791687, 10.27569199], [79.31764221, 10.27569389], [79.31764221, 10.27541637], [79.31735992, 10.27542114], [79.31735992, 10.27514267], [79.31680298, 10.27514267], [79.31680298, 10.27486038], [79.31597137, 10.27486229], [79.31597137, 10.27458382], [79.31569672, 10.27458191], [79.31569672, 10.2743063], [79.3154068, 10.27431107], [79.3154068, 10.27403927], [79.31513977, 10.27403927], [79.31513977, 10.27375031], [79.31485748, 10.27375031], [79.31485748, 10.27347183], [79.31458282, 10.27347183], [79.31458282, 10.27291584], [79.31430817, 10.27291965], [79.31430817, 10.27264023], [79.31402588, 10.27264023], [79.31402588, 10.27235985], [79.31375122, 10.27235985], [79.31375122, 10.27224064], [79.31375122, 10.27208424], [79.31346893, 10.27208424], [79.31346893, 10.27180576], [79.31318665, 10.27180958], [79.31318665, 10.27153015], [79.31291962, 10.27153015], [79.31291962, 10.27124977], [79.31263733, 10.27124977], [79.31263733, 10.27096939], [79.31236267, 10.27097225], [79.31236267, 10.27069378], [79.31208038, 10.27069378], [79.31208038, 10.27041626], [79.31181335, 10.27042007], [79.31181335, 10.27013969], [79.31153107, 10.27013969], [79.31153107, 10.26958084], [79.31124878, 10.2695837], [79.31124878, 10.26902771], [79.31096649, 10.26902962], [79.31096649, 10.26875019], [79.31069183, 10.26875019], [79.31069183, 10.26819324], [79.31041718, 10.26819324], [79.31041718, 10.26764011], [79.31014252, 10.26764202], [79.31014252, 10.26736164], [79.30986023, 10.26736164], [79.30986023, 10.2668047], [79.3095932, 10.26681042], [79.3095932, 10.26625156], [79.30930328, 10.26625156], [79.30930328, 10.2656908], [79.30902863, 10.26569557], [79.30902863, 10.2654171], [79.30874634, 10.26542187], [79.30874634, 10.26486969], [79.30847168, 10.26486969], [79.30847168, 10.26431179], [79.30735779, 10.26430511], [79.30735779, 10.26458263], [79.30680847, 10.26458073], [79.30680847, 10.26486969], [79.30625153, 10.26486969], [79.30625153, 10.26513863], [79.30522156, 10.26513863], [79.30457306, 10.26513863], [79.30457306, 10.26486969], [79.30208588, 10.26486969], [79.30208588, 10.26513863], [79.30179596, 10.26513863], [79.30179596, 10.26486969], [79.30124664, 10.26486969], [79.30124664, 10.26458073], [79.30069733, 10.26458263], [79.30069733, 10.26430511], [79.30042267, 10.26431179], [79.30042267, 10.26402855], [79.30014038, 10.26402855], [79.30014038, 10.26375103], [79.29985809, 10.26375103], [79.29985809, 10.26347065], [79.29930878, 10.26347256], [79.29930878, 10.26319313], [79.29902649, 10.26319313], [79.29902649, 10.26291656], [79.29846954, 10.26292038], [79.29846954, 10.26264095], [79.29792023, 10.26264095], [79.29792023, 10.26236057], [79.29763794, 10.26236057], [79.29763794, 10.26208305], [79.29708099, 10.26208305], [79.29708099, 10.26180458], [79.29680634, 10.2618103], [79.29680634, 10.26153183], [79.29624939, 10.26153183], [79.29624939, 10.26125145], [79.29569244, 10.26125145], [79.29569244, 10.26097107], [79.29541779, 10.26097107], [79.29541779, 10.26069546], [79.29486084, 10.26069546], [79.29486084, 10.26041698], [79.29458618, 10.26041889], [79.29458618, 10.26014137], [79.29429626, 10.26014137], [79.29429626, 10.25986099], [79.29402924, 10.25986099], [79.29402924, 10.259305], [79.29374695, 10.25931168], [79.29374695, 10.2590313], [79.29347229, 10.2590313], [79.29347229, 10.25875092], [79.29319763, 10.25875092], [79.29319763, 10.25847054], [79.29291534, 10.2584734], [79.29291534, 10.25819492], [79.29264069, 10.25819492], [79.29264069, 10.2579174], [79.2923584, 10.25791931], [79.2923584, 10.25736141], [79.29180908, 10.25736141], [79.29180908, 10.25708294], [79.29152679, 10.25708294], [79.29152679, 10.25680542], [79.29125214, 10.25680923], [79.29125214, 10.25652885], [79.29096985, 10.25652885], [79.29096985, 10.25625134], [79.29069519, 10.25625134], [79.29069519, 10.25597286], [79.2904129, 10.25597286], [79.2904129, 10.25541687], [79.28958893, 10.25542068], [79.28958893, 10.25486088], [79.28930664, 10.25486088], [79.28930664, 10.25458241], [79.28902435, 10.25458241], [79.28902435, 10.25430679], [79.28874969, 10.25431061], [79.28874969, 10.25418091], [79.28874969, 10.25402641], [79.28840637, 10.25402927], [79.2876358, 10.25403118], [79.2876358, 10.2537508], [79.28708649, 10.2537508], [79.28708649, 10.25347328], [79.2868042, 10.25347328], [79.2868042, 10.25302982], [79.2868042, 10.25291634], [79.28668976, 10.25291634], [79.28652954, 10.25292969], [79.28652954, 10.2527504], [79.28652954, 10.25236034], [79.28624725, 10.25236034], [79.28624725, 10.25208473], [79.2859726, 10.25208473], [79.2859726, 10.25152779], [79.28569794, 10.25153065], [79.28569794, 10.25069046], [79.28541565, 10.25069427], [79.28541565, 10.2504158], [79.28514099, 10.25042057], [79.28514099, 10.25014019], [79.28430176, 10.25014019], [79.28430176, 10.24986935], [79.2840271, 10.24986935], [79.2840271, 10.24931145], [79.28320313, 10.24931145], [79.28320313, 10.24903011], [79.28291321, 10.24903011], [79.28291321, 10.24874973], [79.28263855, 10.24874973], [79.28263855, 10.24847031], [79.28236389, 10.24847221], [79.28236389, 10.24819374], [79.2820816, 10.24819374], [79.2820816, 10.24791622], [79.28180695, 10.24792099], [79.28180695, 10.24763966], [79.28151703, 10.24763966], [79.28151703, 10.24736023], [79.28097534, 10.24736214], [79.28097534, 10.24680614], [79.28069305, 10.24681091], [79.28069305, 10.24652958], [79.2804184, 10.24652958], [79.2804184, 10.24596977], [79.28013611, 10.24597168], [79.28013611, 10.24569416], [79.27980042, 10.24572563], [79.27986145, 10.24542046], [79.27960205, 10.24539089], [79.27958679, 10.2448616], [79.27928162, 10.2448597], [79.27902985, 10.2448597], [79.27902985, 10.24443054], [79.27902985, 10.24430561], [79.2784729, 10.24431038], [79.2784729, 10.24374104], [79.27819824, 10.24374962], [79.27819061, 10.2434721], [79.2776413, 10.2434721], [79.2776413, 10.24319363], [79.27735901, 10.24319363], [79.27735901, 10.24291801], [79.27707672, 10.24291992], [79.27707672, 10.24263954], [79.27680206, 10.24263954], [79.27680206, 10.24236202], [79.2765274, 10.24236202], [79.2765274, 10.24180603], [79.2756958, 10.24180984], [79.2756958, 10.24153042], [79.27513885, 10.24153042], [79.27513885, 10.24125195], [79.27485657, 10.24125195], [79.27485657, 10.24097061], [79.27458191, 10.24097061], [79.27458191, 10.24069309], [79.27402496, 10.24069309], [79.27402496, 10.24041843], [79.27375031, 10.24042034], [79.27375031, 10.24014187], [79.27348328, 10.24014187], [79.27348328, 10.23958111], [79.27319336, 10.23958302], [79.27319336, 10.23930454], [79.2729187, 10.23931026], [79.2729187, 10.23874855], [79.27263641, 10.23874855], [79.27263641, 10.23819542], [79.27236176, 10.23819542], [79.27236176, 10.23763943], [79.27179718, 10.23763943], [79.27179718, 10.23736095], [79.27152252, 10.23736095], [79.27152252, 10.23680973], [79.27124786, 10.23680973], [79.27124786, 10.23652935], [79.27097321, 10.23652935], [79.27097321, 10.23604202], [79.27087402, 10.23601723], [79.27069092, 10.23597336], [79.27069092, 10.23583031], [79.27069092, 10.23541737], [79.27041626, 10.23542023], [79.27041626, 10.23513889], [79.2701416, 10.23513889], [79.2701416, 10.23458099], [79.26958466, 10.2345829], [79.26958466, 10.23402691], [79.26930237, 10.23403168], [79.26930237, 10.2337513], [79.26902771, 10.2337513], [79.26902771, 10.2331953], [79.26875305, 10.2331953], [79.26875305, 10.23263931], [79.26846313, 10.23264122], [79.26846313, 10.23236084], [79.26790619, 10.23236084], [79.26790619, 10.23124886], [79.26763916, 10.23124886], [79.26763916, 10.22986126], [79.26791382, 10.22986126], [79.26791382, 10.2290287], [79.26819611, 10.22903061], [79.26819611, 10.22819042], [79.26875305, 10.22819519], [79.26875305, 10.22791672], [79.26902771, 10.22792053], [79.26902771, 10.22764111], [79.26930237, 10.22764111], [79.26930237, 10.22681141], [79.26957703, 10.22681141], [79.26957703, 10.22625065], [79.26985931, 10.22625065], [79.26985931, 10.22570133], [79.2701416, 10.22570133], [79.2701416, 10.22514057], [79.27041626, 10.22514057], [79.27041626, 10.22486019], [79.27124786, 10.22486019], [79.27124786, 10.22458363], [79.27153015, 10.22458363], [79.27153015, 10.2243042], [79.2720871, 10.22431087], [79.2720871, 10.22403145], [79.27263641, 10.22403145], [79.27263641, 10.22375011], [79.27319336, 10.22375011], [79.27319336, 10.22346973], [79.27375031, 10.22347164], [79.27375031, 10.22319412], [79.27458191, 10.22319412], [79.27458191, 10.22291565], [79.27540588, 10.22292137], [79.27540588, 10.22264004], [79.2756958, 10.22264004], [79.2756958, 10.22235966], [79.27597046, 10.22235966], [79.27597046, 10.22180557], [79.27625275, 10.22181129], [79.27625275, 10.22152996], [79.27680206, 10.22152996], [79.27680206, 10.22124958], [79.27707672, 10.22124958], [79.27707672, 10.22097015], [79.2784729, 10.22097206], [79.2784729, 10.22069359], [79.28013611, 10.22069359], [79.28013611, 10.21958447], [79.2804184, 10.21958447], [79.2804184, 10.21847153], [79.28069305, 10.21847153], [79.28069305, 10.21763992], [79.28098297, 10.21763992], [79.28098297, 10.21680069], [79.28125, 10.21680641], [79.28125, 10.21374893], [79.28098297, 10.21376133], [79.28098297, 10.21347141], [79.28069305, 10.21347141], [79.28069305, 10.21291542], [79.2804184, 10.21292019], [79.2804184, 10.21263981], [79.28013611, 10.21263981], [79.28013611, 10.21236134], [79.27986145, 10.21236134], [79.27986145, 10.21208286], [79.27958679, 10.21208286], [79.27958679, 10.21180534], [79.27902985, 10.21181011], [79.27902985, 10.21152973], [79.27874756, 10.21152973], [79.27874756, 10.21124935], [79.2784729, 10.21124935], [79.2784729, 10.21097088], [79.27791595, 10.21097088], [79.27791595, 10.21069527], [79.27764893, 10.21070004], [79.27764893, 10.21041965], [79.27735901, 10.21041965], [79.27735901, 10.21013927], [79.27680206, 10.21013927], [79.27680206, 10.20985889], [79.2765274, 10.2098608], [79.2765274, 10.20958328], [79.27597046, 10.20958328], [79.27597046, 10.20930481], [79.2756958, 10.20930958], [79.2756958, 10.2090292], [79.27540588, 10.2090292], [79.27540588, 10.20875072], [79.27485657, 10.20875072], [79.27485657, 10.2084713], [79.27458191, 10.20847321], [79.27458191, 10.20819473], [79.27430725, 10.20819473], [79.27430725, 10.20791721], [79.27375031, 10.20792198], [79.27375031, 10.20763016], [79.27347565, 10.20763874], [79.27347565, 10.20736122], [79.27319336, 10.20736122], [79.27319336, 10.20708275], [79.27263641, 10.20708275], [79.27263641, 10.20680523], [79.27236176, 10.2068119], [79.27236176, 10.20653057], [79.27179718, 10.20653057], [79.27179718, 10.20625114], [79.27152252, 10.20625114], [79.27152252, 10.20596886], [79.27097321, 10.20597267], [79.27097321, 10.20569515], [79.27069092, 10.20569515], [79.27069092, 10.20541668], [79.2701416, 10.2054224], [79.2701416, 10.20514107], [79.26985931, 10.20514107], [79.26985931, 10.20486069], [79.26930237, 10.20486069], [79.26930237, 10.20458317], [79.26902771, 10.20458317], [79.26902771, 10.2043047], [79.26875305, 10.20430946], [79.26875305, 10.20375061], [79.26846313, 10.20375061], [79.26846313, 10.20318985], [79.26819611, 10.20319462], [79.26819611, 10.20263863], [79.26790619, 10.20264053], [79.26790619, 10.20236111], [79.26763916, 10.20236111], [79.26763916, 10.20180511], [79.26735687, 10.20182037], [79.26735687, 10.20125103], [79.26708221, 10.20125103], [79.26708221, 10.20069027], [79.26680756, 10.20069504], [79.26680756, 10.20013809], [79.2665329, 10.20014095], [79.2665329, 10.19985962], [79.26625061, 10.19985962], [79.26625061, 10.19930744], [79.26597595, 10.19931126], [79.26597595, 10.19876194], [79.26568604, 10.19876194], [79.26568604, 10.19818974], [79.26541901, 10.19819355], [79.26541901, 10.19791603], [79.26513672, 10.1979208], [79.26513672, 10.19764137], [79.26486206, 10.19764137], [79.26486206, 10.19736004], [79.26457977, 10.19736004], [79.26457977, 10.19708443], [79.26430511, 10.19708443], [79.26430511, 10.19680595], [79.26374817, 10.19681072], [79.26374817, 10.1965313], [79.26346588, 10.1965313], [79.26346588, 10.19624996], [79.26319122, 10.19624996], [79.26319122, 10.19596958], [79.26291656, 10.19597244], [79.26291656, 10.19569397], [79.26264191, 10.19569397], [79.26264191, 10.19541645], [79.26235962, 10.19542122], [79.26235962, 10.19514275], [79.26209259, 10.19514275], [79.26209259, 10.19486046], [79.26180267, 10.19486237], [79.26180267, 10.19458199], [79.26125336, 10.19458199], [79.26125336, 10.19430637], [79.26097107, 10.19431114], [79.26097107, 10.19403267], [79.26069641, 10.19403267], [79.26069641, 10.19375038], [79.26040649, 10.19375038], [79.26040649, 10.19347191], [79.26013947, 10.19347191], [79.26013947, 10.19319439], [79.25958252, 10.19319439], [79.25958252, 10.19291592], [79.25930786, 10.19291973], [79.25930786, 10.19262886], [79.25902557, 10.1926403], [79.25902557, 10.19235992], [79.25846863, 10.19235992], [79.25846863, 10.19208431], [79.25819397, 10.19208431], [79.25819397, 10.19180584], [79.25791931, 10.19181061], [79.25791931, 10.19153023], [79.25736237, 10.19153023], [79.25736237, 10.19124985], [79.25708008, 10.19124985], [79.25708008, 10.19097233], [79.25653076, 10.19097233], [79.25653076, 10.19069386], [79.25624847, 10.19069386], [79.25624847, 10.19041634], [79.25596619, 10.19042015], [79.25596619, 10.19013977], [79.25541687, 10.19013977], [79.25541687, 10.18986034], [79.25514221, 10.18986225], [79.25514221, 10.18958378], [79.25485992, 10.18959141], [79.25485992, 10.18931007], [79.25430298, 10.18931007], [79.25430298, 10.18902969], [79.25402832, 10.18902969], [79.25402832, 10.18875027], [79.25319672, 10.18875027], [79.25319672, 10.18847179], [79.2529068, 10.18847179], [79.2529068, 10.18791962], [79.25235748, 10.18791962], [79.25235748, 10.18764019], [79.25208282, 10.18764019], [79.25208282, 10.18791962], [79.25125122, 10.18791962], [79.25125122, 10.18764019], [79.25068665, 10.18764019], [79.25068665, 10.18735886], [79.25041962, 10.18736172], [79.25041962, 10.18723202], [79.25041962, 10.1870842], [79.25013733, 10.1870842], [79.25013733, 10.18680573], [79.24958038, 10.18682098], [79.24958038, 10.18653202], [79.24931335, 10.18653202], [79.24931335, 10.18625164], [79.24846649, 10.18625164], [79.24846649, 10.18597126], [79.24736023, 10.18597126], [79.24736023, 10.18569565], [79.24652863, 10.18569565], [79.24652863, 10.18541527], [79.2454071, 10.18542194], [79.2454071, 10.1851387], [79.24514008, 10.1851387], [79.24514008, 10.18485928], [79.24485779, 10.18486118], [79.24485779, 10.18458271], [79.24430847, 10.18458271], [79.24430847, 10.18430519], [79.24402618, 10.18430996], [79.24402618, 10.18402958], [79.24375153, 10.18402958], [79.24375153, 10.1837492], [79.24346924, 10.1837492], [79.24346924, 10.18347263], [79.24291992, 10.18347263], [79.24291992, 10.18319321], [79.24263763, 10.18319321], [79.24263763, 10.18291664], [79.24236298, 10.18292046], [79.24236298, 10.18236065], [79.24208069, 10.18236065], [79.24208069, 10.18208313], [79.24180603, 10.18208313], [79.24180603, 10.18124866], [79.241539, 10.18125057], [79.241539, 10.18069077], [79.24124908, 10.18069458], [79.24124908, 10.1782999], [79.24124908, 10.17736053], [79.24153137, 10.17736053], [79.24153137, 10.17430687], [79.24124908, 10.17431068], [79.24124908, 10.17375088], [79.2409668, 10.17375088], [79.2409668, 10.17319012], [79.24069214, 10.17319489], [79.24069214, 10.17263794], [79.24041748, 10.1726408], [79.24041748, 10.1718111], [79.23986053, 10.1718111], [79.23986053, 10.17125034], [79.23958588, 10.17125034], [79.23958588, 10.17097187], [79.23930359, 10.17097187], [79.23930359, 10.17069435], [79.23902893, 10.17069435], [79.23902893, 10.17041588], [79.23874664, 10.17042065], [79.23874664, 10.16986179], [79.23847961, 10.16986179], [79.23847961, 10.16958046], [79.23819733, 10.16958427], [79.23819733, 10.1693058], [79.23792267, 10.16931057], [79.23792267, 10.16875267], [79.23819733, 10.16875267], [79.23819733, 10.16819191], [79.23847198, 10.16819382], [79.23847198, 10.16763783], [79.23874664, 10.16763973], [79.23874664, 10.16708183], [79.23902893, 10.16708374], [79.23902893, 10.16652775], [79.23929596, 10.16652966], [79.23929596, 10.16596985], [79.23958588, 10.16597176], [79.23958588, 10.16569424], [79.23930359, 10.16569424], [79.23930359, 10.16541576], [79.23958588, 10.16541958], [79.23958588, 10.16514015], [79.23986053, 10.16514015], [79.23986053, 10.16431046], [79.24014282, 10.16431046], [79.24014282, 10.16403008], [79.24041748, 10.16403008], [79.24041748, 10.16346931], [79.24069214, 10.16347218], [79.24069214, 10.1631937], [79.24097443, 10.1631937], [79.24097443, 10.1623621], [79.24041748, 10.1623621], [79.24041748, 10.16208363], [79.24013519, 10.16208363], [79.24013519, 10.15736103], [79.23986053, 10.15736103], [79.23986053, 10.15430546], [79.23958588, 10.15431023], [79.23958588, 10.15375137], [79.23929596, 10.15375137], [79.23929596, 10.15347958], [79.23847961, 10.15347958], [79.23847961, 10.15319061], [79.23791504, 10.15319538], [79.23791504, 10.15291691], [79.23764038, 10.15292168], [79.23764038, 10.1526413], [79.23735809, 10.1526413], [79.23735809, 10.15236092], [79.23707581, 10.15236092], [79.23707581, 10.15208054], [79.23568726, 10.15208054], [79.23569489, 10.15236092], [79.23513794, 10.15236092], [79.23513794, 10.15180492], [79.23486328, 10.1518116], [79.23486328, 10.15153122], [79.2334671, 10.15153122], [79.2334671, 10.15125084], [79.23319244, 10.15125084], [79.23319244, 10.15097141], [79.2326355, 10.15097332], [79.2326355, 10.15069485], [79.23124695, 10.15069485], [79.23124695, 10.15041733], [79.23069763, 10.15041924], [79.23069763, 10.15013885], [79.23041534, 10.15013885], [79.23041534, 10.14986134], [79.23014069, 10.14986134], [79.23014069, 10.14847279], [79.2298584, 10.14847279], [79.2298584, 10.14680672], [79.22957611, 10.14681053], [79.22957611, 10.14486027], [79.22930908, 10.14486027], [79.22930908, 10.14430428], [79.22902679, 10.14431095], [79.22902679, 10.14347172], [79.22930908, 10.14347172], [79.22930908, 10.1431942], [79.22958374, 10.1431942], [79.22958374, 10.14291573], [79.2298584, 10.14292145], [79.2298584, 10.14264011], [79.23014069, 10.14264011], [79.23014069, 10.14235973], [79.23041534, 10.14235973], [79.23041534, 10.14152813], [79.23014069, 10.14153957], [79.23014069, 10.14068985], [79.2298584, 10.14069366], [79.2298584, 10.14041615], [79.23014069, 10.14042091], [79.23014069, 10.13986015], [79.23041534, 10.13986206], [79.23041534, 10.13958359], [79.23069763, 10.13958359], [79.23069763, 10.13875008], [79.23042297, 10.13875008], [79.23042297, 10.13848114], [79.23014069, 10.13848114], [79.23014069, 10.13818932], [79.22930908, 10.13819408], [79.22930908, 10.13791561], [79.22875214, 10.13792038], [79.22875214, 10.13514042], [79.22930908, 10.13514042], [79.22930908, 10.13430977], [79.22957611, 10.13430977], [79.22957611, 10.13347054], [79.2298584, 10.13347054], [79.2298584, 10.13236237], [79.23014069, 10.13236237], [79.23014069, 10.13185978], [79.23014069, 10.13097095], [79.23041534, 10.13097095], [79.23041534, 10.13069534], [79.23069763, 10.13069534], [79.23069763, 10.13041687], [79.23152924, 10.13041973], [79.23152924, 10.13013935], [79.23208618, 10.13013935], [79.23208618, 10.12986088], [79.2326355, 10.12986088], [79.2326355, 10.12930489], [79.23291779, 10.12930965], [79.23291779, 10.12902927], [79.2334671, 10.12902927], [79.2334671, 10.12874889], [79.23707581, 10.12874889], [79.23707581, 10.12847137], [79.23680878, 10.12847328], [79.23680878, 10.12791729], [79.23652649, 10.12792015], [79.23652649, 10.12764072], [79.23596954, 10.12764072], [79.23596954, 10.1273613], [79.23569489, 10.1273613], [79.23569489, 10.12708282], [79.23542023, 10.12708282], [79.23542023, 10.12680531], [79.23513794, 10.12681198], [79.23513794, 10.12654114], [79.23486328, 10.12654114], [79.23486328, 10.12625122], [79.23430634, 10.12625122], [79.23430634, 10.12597084], [79.23401642, 10.12597084], [79.23401642, 10.12569141], [79.23374939, 10.12569523], [79.23374939, 10.12513924], [79.2334671, 10.12514114], [79.2334671, 10.12485886], [79.23319244, 10.12486076], [79.23319244, 10.12458324], [79.23291779, 10.12458324], [79.23291779, 10.12430477], [79.23235321, 10.12430859], [79.23235321, 10.12375069], [79.23208618, 10.12375069], [79.23208618, 10.12264061], [79.23179626, 10.12264061], [79.23179626, 10.12153053], [79.23152924, 10.12153053], [79.23152924, 10.12096977], [79.23124695, 10.12097263], [79.23124695, 10.1198597], [79.23097229, 10.1198597], [79.23097229, 10.11902905], [79.23069763, 10.11903095], [79.23069763, 10.11847019], [79.23041534, 10.1184721], [79.23041534, 10.11763763], [79.23014069, 10.11764145], [79.23014069, 10.11707973], [79.2298584, 10.11708355], [79.2298584, 10.11569405], [79.22930908, 10.11569405], [79.22930908, 10.11513805], [79.22902679, 10.11513996], [79.22902679, 10.11431122], [79.22875214, 10.11431122], [79.22875214, 10.11375046], [79.22846985, 10.11375046], [79.22846985, 10.11319447], [79.22819519, 10.11319447], [79.22819519, 10.11180592], [79.22846985, 10.11181068], [79.22846985, 10.11013985], [79.22875214, 10.11013985], [79.22875214, 10.10847187], [79.22902679, 10.10847187], [79.22902679, 10.1068058], [79.22930908, 10.10680962], [79.22930908, 10.10513973], [79.22957611, 10.10513973], [79.22957611, 10.10346889], [79.22930908, 10.1034708], [79.22930908, 10.10291672], [79.22875214, 10.10291958], [79.22875214, 10.1026392], [79.22820282, 10.1026392], [79.22820282, 10.10237026], [79.2279129, 10.10237026], [79.2279129, 10.1020813], [79.22763824, 10.10208321], [79.22763824, 10.10180473], [79.22735596, 10.10181046], [79.22735596, 10.10153198], [79.22680664, 10.10153198], [79.22680664, 10.10125065], [79.22651672, 10.10125065], [79.22651672, 10.09847069], [79.22680664, 10.0984726], [79.22680664, 10.09819508], [79.2270813, 10.09819508], [79.2270813, 10.09680462], [79.22735596, 10.09680939], [79.22735596, 10.09624195], [79.22763824, 10.09624863], [79.22763824, 10.09569454], [79.2279129, 10.09569454], [79.2279129, 10.09458256], [79.22819519, 10.09458256], [79.22819519, 10.09402561], [79.2279129, 10.09403133], [79.2279129, 10.09375095], [79.22820282, 10.09375095], [79.22820282, 10.09318066], [79.22846985, 10.09319496], [79.22846985, 10.09208202], [79.22875214, 10.09208202], [79.22875214, 10.09152889], [79.22902679, 10.0915308], [79.22902679, 10.09068966], [79.22930908, 10.09069443], [79.22930908, 10.09013844], [79.22957611, 10.0901413], [79.22957611, 10.08957958], [79.2298584, 10.08958435], [79.2298584, 10.08874989], [79.23014069, 10.08875275], [79.23014069, 10.08819199], [79.23041534, 10.08819389], [79.23041534, 10.08736229], [79.23069763, 10.08737087], [79.23069763, 10.08681107], [79.23097229, 10.08681107], [79.23097229, 10.08625031], [79.23124695, 10.08625031], [79.23124695, 10.08541584], [79.23152924, 10.08541965], [79.23152924, 10.08485985], [79.23180389, 10.08485985], [79.23180389, 10.08458424], [79.23208618, 10.08458424], [79.23208618, 10.08430576], [79.2326355, 10.08430576], [79.2326355, 10.08402824], [79.23319244, 10.08403015], [79.23319244, 10.08374977], [79.23264313, 10.08374977], [79.23264313, 10.08347034], [79.23291779, 10.08347225], [79.23291779, 10.08319378], [79.2326355, 10.08319378], [79.2326355, 10.08236217], [79.23291779, 10.08236217], [79.23291779, 10.08180618], [79.23319244, 10.08181], [79.23319244, 10.08152962], [79.2334671, 10.08152962], [79.2334671, 10.08069134], [79.23374939, 10.0806942], [79.23374939, 10.07986164], [79.23402405, 10.07986164], [79.23401642, 10.07846928], [79.23430634, 10.07847118], [79.23430634, 10.07819557], [79.23486328, 10.07820034], [79.23486328, 10.07791996], [79.23513794, 10.07791996], [79.23513794, 10.07708073], [79.23542023, 10.07708263], [79.23542023, 10.07624912], [79.23568726, 10.07625198], [79.23568726, 10.07543087], [79.23596954, 10.07543087], [79.23596954, 10.07486057], [79.23625183, 10.07486057], [79.23625183, 10.07458305], [79.23652649, 10.07458305], [79.23652649, 10.07402706], [79.23680878, 10.07403183], [79.23680878, 10.07375145], [79.23902893, 10.07375145], [79.23902893, 10.07347107], [79.23958588, 10.07347107], [79.23958588, 10.07319546], [79.24041748, 10.07319546], [79.24041748, 10.07347107], [79.2409668, 10.07347107], [79.2409668, 10.07375145], [79.24180603, 10.07375145], [79.24180603, 10.07319069], [79.24236298, 10.07319546], [79.24236298, 10.07347107], [79.24346924, 10.07347107], [79.24346924, 10.07319546], [79.24402618, 10.07319546], [79.24402618, 10.07291698], [79.24430847, 10.07291889], [79.24430847, 10.07264137], [79.24375153, 10.07264137], [79.24375153, 10.07291889], [79.24263763, 10.07291889], [79.24263763, 10.07264137], [79.24236298, 10.07264137], [79.24236298, 10.07236099], [79.24346924, 10.07236099], [79.24346924, 10.07208347], [79.24458313, 10.07208347], [79.24458313, 10.071805], [79.24485779, 10.07181168], [79.24485779, 10.0715313], [79.2454071, 10.0715313], [79.2454071, 10.07125092], [79.24652863, 10.07125092], [79.24652863, 10.07097054], [79.24708557, 10.0709734], [79.24708557, 10.0704174], [79.24736023, 10.07041931], [79.24736023, 10.07014084], [79.24764252, 10.07014084], [79.24764252, 10.06986141], [79.24819183, 10.06986141], [79.24819183, 10.06958294], [79.24874878, 10.06958294], [79.24874878, 10.06930542], [79.24903107, 10.06930542], [79.24903107, 10.06902885], [79.24931335, 10.06902885], [79.24931335, 10.06847095], [79.24958038, 10.06847286], [79.24958038, 10.06819534], [79.25041962, 10.06819534], [79.25041962, 10.06791687], [79.25068665, 10.06792068], [79.25068665, 10.06764126], [79.25096893, 10.06764126], [79.25096893, 10.06736088], [79.25125122, 10.06736088], [79.25125122, 10.06708336], [79.25180817, 10.06708336], [79.25180817, 10.06680679], [79.25208282, 10.06681061], [79.25208282, 10.06653118], [79.25235748, 10.06653118], [79.25235748, 10.0654211], [79.25263977, 10.0654211], [79.25263977, 10.06486034], [79.25291443, 10.06486034], [79.25291443, 10.06458473], [79.25319672, 10.06458473], [79.25319672, 10.06430435], [79.25345612, 10.06431103], [79.25345612, 10.06320095], [79.25374603, 10.06320095], [79.25374603, 10.06124973], [79.25345612, 10.06124973], [79.25345612, 10.06069183], [79.25375366, 10.06069374], [79.25375366, 10.05902767], [79.25345612, 10.05902958], [79.25345612, 10.05875015], [79.25319672, 10.05875015], [79.25319672, 10.05819416], [79.25291443, 10.05819416], [79.25291443, 10.05708408], [79.25263977, 10.05708408], [79.25263977, 10.0559721], [79.25291443, 10.0559721], [79.25291443, 10.05569363], [79.25319672, 10.05569363], [79.25319672, 10.05486202], [79.25263977, 10.05486202], [79.25263977, 10.05458355], [79.25235748, 10.05458355], [79.25235748, 10.05402756], [79.25208282, 10.05403042], [79.25208282, 10.05264187], [79.25180817, 10.05264187], [79.25180817, 10.05236244], [79.25235748, 10.05236244], [79.25235748, 10.05208397], [79.25263977, 10.05208397], [79.25263977, 10.05180454], [79.2529068, 10.05181026], [79.2529068, 10.05069065], [79.25263977, 10.05069637], [79.25263977, 10.05013943], [79.25235748, 10.05013943], [79.25235748, 10.0490303], [79.25263977, 10.0490303], [79.25263977, 10.04847145], [79.25291443, 10.04847336], [79.25291443, 10.04819489], [79.25347137, 10.04819489], [79.25347137, 10.04791737], [79.25374603, 10.04792023], [79.25374603, 10.04763889], [79.25402832, 10.04763889], [79.25402832, 10.04736137], [79.25430298, 10.04736137], [79.25430298, 10.04680538], [79.2545929, 10.04681015], [79.2545929, 10.04653168], [79.25485992, 10.04653168], [79.25485992, 10.0462513], [79.25514221, 10.0462513], [79.25514221, 10.0456953], [79.25569153, 10.0456953], [79.25569153, 10.04541683], [79.25596619, 10.0454216], [79.25596619, 10.04512978], [79.25624847, 10.04513931], [79.25624847, 10.04486084], [79.25652313, 10.04486084], [79.25652313, 10.04458141], [79.25708008, 10.04458332], [79.25708008, 10.04430485], [79.25736237, 10.04431152], [79.25736237, 10.04402924], [79.25791931, 10.04402924], [79.25791931, 10.04374886], [79.25819397, 10.04374886], [79.25819397, 10.04347324], [79.25846863, 10.04347324], [79.25846863, 10.04319477], [79.25902557, 10.04319477], [79.25902557, 10.04291725], [79.25930786, 10.04292107], [79.25930786, 10.04264069], [79.25985718, 10.04264069], [79.25985718, 10.04236126], [79.26013947, 10.04236126], [79.26013947, 10.04208279], [79.26041412, 10.04208279], [79.26041412, 10.04180527], [79.26097107, 10.04181099], [79.26097107, 10.04153061], [79.26125336, 10.04153061], [79.26125336, 10.04125118], [79.26180267, 10.04125118], [79.26180267, 10.04097271], [79.26208496, 10.04097271], [79.26208496, 10.04069519], [79.26264191, 10.04069519], [79.26264191, 10.04041672], [79.26319122, 10.04042053], [79.26319122, 10.04014111], [79.26374817, 10.04014111], [79.26374817, 10.03986073], [79.26430511, 10.03986073], [79.26430511, 10.03958225], [79.26513672, 10.03958225], [79.26513672, 10.03930664], [79.26568604, 10.03931999], [79.26568604, 10.03903103], [79.26625061, 10.03903103], [79.26625061, 10.03875065], [79.26680756, 10.03875065], [79.26680756, 10.03847027], [79.2673645, 10.03847313], [79.2673645, 10.03791618], [79.26625061, 10.03792095], [79.26625061, 10.03764057], [79.26541901, 10.03764057], [79.26541901, 10.03736019], [79.26430511, 10.03736019], [79.26430511, 10.03708458], [79.26347351, 10.03708458], [79.26347351, 10.0368042], [79.26235962, 10.03681087], [79.26235962, 10.03653145], [79.26209259, 10.03653145], [79.26209259, 10.03625011], [79.26152802, 10.03625011], [79.26152802, 10.03596973], [79.26097107, 10.03597164], [79.26097107, 10.03569412], [79.26041412, 10.03569412], [79.26041412, 10.03541565], [79.25985718, 10.03542137], [79.25985718, 10.03514004], [79.25930786, 10.03514004], [79.25930786, 10.03485966], [79.25902557, 10.03486156], [79.25902557, 10.03458214], [79.25846863, 10.03458214], [79.25846863, 10.03430557], [79.25736237, 10.03431129], [79.25736237, 10.03403091], [79.25681305, 10.03403091], [79.25681305, 10.03374958], [79.25652313, 10.03374958], [79.25652313, 10.03347015], [79.25624847, 10.03347206], [79.25624847, 10.03319359], [79.25569153, 10.03319359], [79.25569153, 10.03291607], [79.25485992, 10.03292274], [79.25485992, 10.03264046], [79.25430298, 10.03264046], [79.25430298, 10.03236008], [79.25374603, 10.03236008], [79.25374603, 10.0320797], [79.25319672, 10.03208447], [79.25319672, 10.03180599], [79.25263977, 10.03181076], [79.25263977, 10.03153038], [79.25180817, 10.03153038], [79.25180817, 10.03125], [79.25152588, 10.03125], [79.25152588, 10.03096962], [79.25125122, 10.03097153], [79.25125122, 10.03069401], [79.25096893, 10.03069401], [79.25096893, 10.03041553], [79.25068665, 10.0304203], [79.25068665, 10.03013134], [79.24986267, 10.03013992], [79.24986267, 10.0298624], [79.24930573, 10.0298624], [79.24930573, 10.02958393], [79.24903107, 10.02958393], [79.24903107, 10.02930641], [79.24846649, 10.02931023], [79.24846649, 10.02902985], [79.24791718, 10.02902985], [79.24791718, 10.02875042], [79.24736023, 10.02875042], [79.24736023, 10.02847195], [79.24680328, 10.02847195], [79.24680328, 10.02764034], [79.24652863, 10.02764034], [79.24652863, 10.02736187], [79.24597168, 10.02736187], [79.24597168, 10.02708435], [79.24569702, 10.02709103], [79.24569702, 10.02680969], [79.24514008, 10.02680969], [79.24514008, 10.02653027], [79.24485779, 10.02653027], [79.24485779, 10.02625179], [79.24430847, 10.02625179], [79.24430847, 10.02597141], [79.24402618, 10.02597141], [79.24402618, 10.02541542], [79.24318695, 10.02542019], [79.24318695, 10.02513981], [79.24263763, 10.02513981], [79.24263763, 10.02486229], [79.24236298, 10.02486229], [79.24236298, 10.02402687], [79.24208069, 10.02402973], [79.24208069, 10.02347088], [79.24153137, 10.02347088], [79.24153137, 10.02319336], [79.24124908, 10.02319336], [79.24124908, 10.02263927], [79.24069214, 10.02263927], [79.24069214, 10.02235889], [79.24041748, 10.0223608], [79.24041748, 10.02124882], [79.24014282, 10.02125072], [79.24014282, 10.02095985], [79.23986053, 10.02097321], [79.23986053, 10.02069473], [79.23958588, 10.02069473], [79.23958588, 10.02041721], [79.23929596, 10.02042198], [79.23929596, 10.02014065], [79.23874664, 10.02014065], [79.23874664, 10.01986122], [79.23819733, 10.01986122], [79.23819733, 10.01958275], [79.23791504, 10.01958275], [79.23791504, 10.01930523], [79.23764038, 10.0193119], [79.23764038, 10.01875114], [79.23735809, 10.01875114], [79.23735809, 10.01847267], [79.23708344, 10.01847267], [79.23708344, 10.01819515], [79.23680878, 10.01819515], [79.23680878, 10.01791668], [79.23625183, 10.0179224], [79.23625183, 10.01764107], [79.23596954, 10.01764107], [79.23596954, 10.01736069], [79.23568726, 10.01736069], [79.23568726, 10.01680946], [79.23513794, 10.01680946], [79.23513794, 10.01625061], [79.23486328, 10.01625061], [79.23484039, 10.01597118], [79.23430634, 10.01597309], [79.23430634, 10.01569462], [79.23374939, 10.01569462], [79.23374939, 10.0154171], [79.2334671, 10.01542091], [79.23347473, 10.01525021], [79.23347473, 10.01513863], [79.23326874, 10.01513863], [79.23319244, 10.01513863], [79.23319244, 10.01457977], [79.23291779, 10.01458263], [79.23291779, 10.01375103], [79.23264313, 10.01375103], [79.23264313, 10.0134697], [79.23208618, 10.01347256], [79.23208618, 10.01291656], [79.23152924, 10.01292133], [79.23152924, 10.01264095], [79.23124695, 10.01264095], [79.23124695, 10.01209164], [79.23069763, 10.01209164], [79.23069763, 10.01181126], [79.23042297, 10.01181126], [79.23042297, 10.01153088], [79.22957611, 10.01153088], [79.22957611, 10.01125145], [79.22930908, 10.01125145], [79.22930908, 10.01068974], [79.22902679, 10.01069355], [79.22902679, 10.01013756], [79.22875214, 10.01014137], [79.22875214, 10.00957966], [79.22846985, 10.00958538], [79.22846985, 10.00930595], [79.22820282, 10.00931072], [79.22820282, 10.00874996], [79.2279129, 10.00874996], [79.2279129, 10.00846958], [79.22763824, 10.00847244], [79.22763824, 10.00791645], [79.22735596, 10.00792122], [79.22735596, 10.00764275], [79.22680664, 10.00764275], [79.22680664, 10.00736046], [79.22651672, 10.00736046], [79.22651672, 10.00764275], [79.22597504, 10.00763798], [79.22597504, 10.00819397], [79.22569275, 10.00819397], [79.22569275, 10.00847244], [79.2251358, 10.00847244], [79.2251358, 10.00819397], [79.22486115, 10.00819397], [79.22486115, 10.00736237], [79.2251358, 10.00736237], [79.2251358, 10.00625038], [79.22486115, 10.00625038], [79.22486115, 10.00597191], [79.22458649, 10.00597191], [79.22458649, 10.00541592], [79.22429657, 10.00542068], [79.22429657, 10.0051403], [79.22402954, 10.0051403], [79.22402954, 10.00485992], [79.22374725, 10.00485992], [79.22374725, 10.00458431], [79.2234726, 10.00458431], [79.2234726, 10.00430584], [79.22319794, 10.00431061], [79.22319794, 10.00403023], [79.22292328, 10.00403023], [79.22292328, 10.00374985], [79.22264099, 10.00374985], [79.22264099, 10.00319386], [79.2223587, 10.00319386], [79.2223587, 10.00291634], [79.22180176, 10.00292015], [79.22180176, 10.00181007], [79.2215271, 10.00181007], [79.2215271, 10.00152969], [79.22125244, 10.00152969], [79.22125244, 10.00125027], [79.2206955, 10.00125027], [79.2206955, 10.00097179], [79.22041321, 10.00097179], [79.22041321, 10.00069427], [79.22013855, 10.00069427], [79.22013855, 10.00014019], [79.22013855, 9.99986172], [79.22013855, 9.9995842], [79.21986389, 9.9995842], [79.21986389, 9.99930573], [79.2195816, 9.99930954], [79.2195816, 9.99903202], [79.21930695, 9.99903202], [79.21930695, 9.99875164], [79.21901703, 9.99875164], [79.21901703, 9.99847126], [79.21875, 9.99847126], [79.21875, 9.99819565], [79.21847534, 9.99819565], [79.21847534, 9.99763966], [79.2179184, 9.99763966], [79.2179184, 9.9970789], [79.21763611, 9.99708271], [79.21763611, 9.99680519], [79.21734619, 9.99680996], [79.21734619, 9.99652958], [79.21708679, 9.99652958], [79.21708679, 9.9962492], [79.21679688, 9.9962492], [79.21679688, 9.99597073], [79.21652985, 9.99597359], [79.21652985, 9.99569321], [79.21624756, 9.99569321], [79.21624756, 9.99541664], [79.21569824, 9.99542046], [79.21569061, 9.99514198], [79.21541595, 9.99514198], [79.21541595, 9.99458122], [79.2151413, 9.99458313], [79.2151413, 9.99430466], [79.21485901, 9.99431038], [79.21485901, 9.99402046], [79.21458435, 9.99402714], [79.21458435, 9.99374866], [79.21430969, 9.99375057], [79.21430969, 9.99347115], [79.2140274, 9.99347115], [79.2140274, 9.99319458], [79.21375275, 9.99319458], [79.21375275, 9.99263859], [79.2131958, 9.99264145], [79.2131958, 9.99236107], [79.21290588, 9.99236107], [79.21290588, 9.99208069], [79.21263885, 9.9920826], [79.21263885, 9.99180508], [79.21208191, 9.99180984], [79.21208191, 9.99153137], [79.21180725, 9.99153137], [79.21180725, 9.99125099], [79.21154022, 9.99125099], [79.21154022, 9.99098015], [79.21125031, 9.99098015], [79.21125031, 9.99069023], [79.21097565, 9.990695], [79.21097565, 9.99041653], [79.21069336, 9.99041939], [79.21069336, 9.98958111], [79.2104187, 9.98958302], [79.2104187, 9.98930454], [79.21013641, 9.98930931], [79.21013641, 9.98875141], [79.20986176, 9.98875141], [79.20986176, 9.98847294], [79.20930481, 9.98847294], [79.20930481, 9.98819542], [79.20874786, 9.98819542], [79.20874786, 9.98763943], [79.20847321, 9.98764133], [79.20847321, 9.98681068], [79.20818329, 9.98681068], [79.20818329, 9.98653126], [79.2076416, 9.98653126], [79.2076416, 9.98625088], [79.20707703, 9.98625088], [79.20707703, 9.98596954], [79.20680237, 9.98597336], [79.20680237, 9.98541737], [79.20652771, 9.98542118], [79.20652771, 9.9851408], [79.20625305, 9.9851408], [79.20625305, 9.98458004], [79.20597076, 9.98458195], [79.20597076, 9.98430443], [79.20569611, 9.9843111], [79.20569611, 9.98403072], [79.20540619, 9.98403072], [79.20540619, 9.9837513], [79.20513916, 9.9837513], [79.20513916, 9.98319435], [79.20430756, 9.98319435], [79.20430756, 9.98263836], [79.2040329, 9.98264122], [79.2040329, 9.98236275], [79.20375061, 9.98236275], [79.20375061, 9.98153114], [79.20347595, 9.98153114], [79.20347595, 9.98069191], [79.20263672, 9.98069382], [79.20263672, 9.98013783], [79.20236969, 9.98013973], [79.20236969, 9.97986031], [79.20207977, 9.97986221], [79.20207977, 9.97930622], [79.20181274, 9.97931099], [79.20181274, 9.97875023], [79.20153046, 9.97875023], [79.20153046, 9.97819424], [79.20124817, 9.97819424], [79.20124817, 9.97764015], [79.20096588, 9.97764015], [79.20096588, 9.97707939], [79.20069122, 9.97708416], [79.20069122, 9.97652817], [79.20041656, 9.97653008], [79.20041656, 9.97569084], [79.20014191, 9.9756937], [79.20014191, 9.9748621], [79.19985962, 9.9748621], [79.19985962, 9.97430611], [79.19960022, 9.97430992], [79.19960022, 9.97347164], [79.19930267, 9.97347164], [79.19930267, 9.97124863], [79.19847107, 9.97124863], [79.19847107, 9.9709692], [79.19763947, 9.97097111], [79.19763947, 9.97069645], [79.19736481, 9.97069645], [79.19736481, 9.97041798], [79.19708252, 9.97042179], [79.19708252, 9.97014046], [79.1965332, 9.97014046], [79.1965332, 9.96984959], [79.19625092, 9.96986103], [79.19625092, 9.96958256], [79.19513702, 9.96958256], [79.19513702, 9.96930504], [79.19486237, 9.96930981], [79.19486237, 9.96903038], [79.19374847, 9.96903038], [79.19374847, 9.96847057], [79.19291687, 9.96847343], [79.19291687, 9.96819305], [79.19235992, 9.96819305], [79.19235992, 9.96763897], [79.1920929, 9.96764183], [79.1920929, 9.96736145], [79.19180298, 9.96736145], [79.19180298, 9.96708298], [79.19152832, 9.96708298], [79.19152832, 9.96680546], [79.19124603, 9.96681023], [79.19124603, 9.96652889], [79.19097137, 9.96652889], [79.19097137, 9.96625137], [79.19069672, 9.96625137], [79.19069672, 9.96597099], [79.19041443, 9.96597099], [79.19041443, 9.96569538], [79.19013977, 9.96569538], [79.19013977, 9.96541691], [79.18985748, 9.96542168], [79.18985748, 9.9651413], [79.18958282, 9.9651413], [79.18958282, 9.96486092], [79.18930817, 9.96486092], [79.18930817, 9.9645834], [79.18902588, 9.9645834], [79.18902588, 9.96430492], [79.18875122, 9.9643116], [79.18875122, 9.96404266], [79.18846893, 9.96404266], [79.18846893, 9.96375084], [79.18818665, 9.96375084], [79.18818665, 9.96347141], [79.18791962, 9.96347332], [79.18791962, 9.96319485], [79.18763733, 9.96319485], [79.18763733, 9.96291733], [79.1873703, 9.96291924], [79.1873703, 9.96263885], [79.18708038, 9.96263885], [79.18708038, 9.96236134], [79.18680573, 9.96236134], [79.18680573, 9.96208286], [79.18653107, 9.96208286], [79.18653107, 9.96180534], [79.18624878, 9.96181202], [79.18624878, 9.96153069], [79.18596649, 9.96153069], [79.18596649, 9.96125126], [79.18569183, 9.96125126], [79.18569183, 9.96097279], [79.18541718, 9.96097279], [79.18541718, 9.96069527], [79.18514252, 9.96069527], [79.18514252, 9.96041679], [79.18486023, 9.96042061], [79.18486023, 9.96014118], [79.1845932, 9.96014118], [79.1845932, 9.9598608], [79.18430328, 9.9598608], [79.18430328, 9.95958328], [79.18402863, 9.95958328], [79.18402863, 9.95930672], [79.18347168, 9.95931053], [79.18347168, 9.95903111], [79.18319702, 9.95903111], [79.18319702, 9.95875072], [79.1829071, 9.95875072], [79.1829071, 9.95847034], [79.18264008, 9.95847321], [79.18264008, 9.95819473], [79.18235779, 9.95819473], [79.18235779, 9.95807076], [79.18235779, 9.95791721], [79.18208313, 9.95791721], [79.18208313, 9.95763779], [79.18180847, 9.95764065], [79.18180847, 9.95736027], [79.18152618, 9.95736027], [79.18152618, 9.95708466], [79.18125153, 9.95708466], [79.18125153, 9.95680428], [79.18096924, 9.95681095], [79.18096924, 9.95653057], [79.18068695, 9.95653057], [79.18068695, 9.95625019], [79.18041992, 9.95625019], [79.18041992, 9.9556942], [79.18013763, 9.9556942], [79.18013763, 9.95541573], [79.17986298, 9.95542145], [79.17986298, 9.95514107], [79.17958069, 9.95514107], [79.17958069, 9.95486927], [79.17930603, 9.95486927], [79.17930603, 9.95458031], [79.17903137, 9.95458221], [79.17903137, 9.95430565], [79.17874908, 9.95431137], [79.17874908, 9.95403099], [79.17819977, 9.95403099], [79.17819977, 9.95374966], [79.17791748, 9.95374966], [79.17791748, 9.95347023], [79.17763519, 9.95347214], [79.17763519, 9.95319366], [79.17736053, 9.95319366], [79.17736053, 9.95291615], [79.17679596, 9.95292091], [79.17679596, 9.95263958], [79.17652893, 9.95263958], [79.17652893, 9.95236015], [79.17624664, 9.95236015], [79.17624664, 9.95208359], [79.17597198, 9.95208359], [79.17597198, 9.95180607], [79.1754303, 9.95181084], [79.1754303, 9.95153046], [79.17514038, 9.95153046], [79.17514038, 9.95125008], [79.17485809, 9.95125008], [79.17485809, 9.9509697], [79.17458344, 9.9509716], [79.17458344, 9.95069408], [79.17430878, 9.95069408], [79.17430878, 9.95041561], [79.17402649, 9.95042038], [79.17402649, 9.94985962], [79.17375183, 9.94986153], [79.17375183, 9.94958401], [79.17346954, 9.94958401], [79.17346954, 9.94930553], [79.17318726, 9.9493103], [79.17318726, 9.94902992], [79.17292023, 9.94902992], [79.17292023, 9.94874954], [79.17263794, 9.94874954], [79.17263794, 9.94819069], [79.17236328, 9.94819355], [79.17236328, 9.94791794], [79.17208099, 9.94791985], [79.17208099, 9.94736195], [79.17180634, 9.94736195], [79.17180634, 9.94708443], [79.17124939, 9.94708443], [79.17124939, 9.94680595], [79.1709671, 9.94680977], [79.1709671, 9.94625187], [79.17069244, 9.94625187], [79.17069244, 9.94567966], [79.17097473, 9.94569302], [79.17097473, 9.94541454], [79.17069244, 9.94542027], [79.17069244, 9.94514179], [79.17041779, 9.94514179], [79.17041779, 9.94485855], [79.16986084, 9.94486237], [79.16986084, 9.94458389], [79.16958618, 9.94458389], [79.16958618, 9.94430637], [79.16929626, 9.94431019], [79.16929626, 9.94402981], [79.16902924, 9.94402981], [79.16902924, 9.94374943], [79.16874695, 9.94374943], [79.16874695, 9.94347095], [79.16819763, 9.94347095], [79.16819763, 9.94319344], [79.16791534, 9.94319344], [79.16791534, 9.94291782], [79.16764069, 9.94293118], [79.16764069, 9.94263935], [79.1673584, 9.94263935], [79.1673584, 9.94250011], [79.1673584, 9.94236088], [79.167099, 9.94236088], [79.16680908, 9.94236088], [79.16680908, 9.94221115], [79.16680908, 9.94208336], [79.16652679, 9.94208336], [79.16652679, 9.94180489], [79.16625977, 9.94180965], [79.16625977, 9.94153023], [79.16596985, 9.94153023], [79.16596985, 9.94124889], [79.16569519, 9.94124889], [79.16569519, 9.94097328], [79.1654129, 9.94097328], [79.1654129, 9.94041729], [79.16513824, 9.94042015], [79.16513824, 9.94014168], [79.16485596, 9.94014168], [79.16485596, 9.93987274], [79.1645813, 9.93987274], [79.1645813, 9.93958092], [79.16430664, 9.93958282], [79.16430664, 9.93930531], [79.16401672, 9.93931198], [79.16401672, 9.9390316], [79.16374969, 9.9390316], [79.16374969, 9.93847084], [79.16347504, 9.93847084], [79.16347504, 9.93819523], [79.16319275, 9.93819523], [79.16319275, 9.93791676], [79.16291809, 9.93792152], [79.16291809, 9.93764114], [79.16236115, 9.93764114], [79.16236115, 9.93735886], [79.1618042, 9.93736076], [79.1618042, 9.93708324], [79.16124725, 9.93708324], [79.16124725, 9.93680477], [79.16042328, 9.93680859], [79.16042328, 9.93653107], [79.16013336, 9.93653107], [79.16013336, 9.93625069], [79.15957642, 9.93625069], [79.15957642, 9.93597126], [79.15930176, 9.93597317], [79.15930176, 9.93569469], [79.1590271, 9.93569469], [79.1590271, 9.93541718], [79.15875244, 9.93542099], [79.15875244, 9.93514061], [79.15847015, 9.93514061], [79.15847015, 9.93486118], [79.15791321, 9.93486118], [79.15791321, 9.93458271], [79.15763855, 9.93458271], [79.15763855, 9.93430519], [79.15735626, 9.93431091], [79.15735626, 9.93403053], [79.15706635, 9.93403053], [79.15706635, 9.93374157], [79.15680695, 9.93375111], [79.15680695, 9.93347263], [79.15652466, 9.93347263], [79.15652466, 9.93319511], [79.15597534, 9.93319511], [79.15597534, 9.93291664], [79.15569305, 9.93292141], [79.15569305, 9.93264103], [79.1554184, 9.93264103], [79.1554184, 9.93236065], [79.15513611, 9.93236065], [79.15513611, 9.93180656], [79.15486145, 9.93181133], [79.15486145, 9.93125057], [79.15458679, 9.93125057], [79.15458679, 9.93068123], [79.1543045, 9.93069458], [79.1543045, 9.93041611], [79.15402985, 9.93042088], [79.15402985, 9.92986012], [79.15374756, 9.92986012], [79.15374756, 9.92930698], [79.15319824, 9.92930889], [79.15319061, 9.92793179], [79.15291595, 9.92793179], [79.15291595, 9.92681122], [79.1526413, 9.92681122], [79.1526413, 9.92514038], [79.15291595, 9.92514038], [79.15291595, 9.92486], [79.15319061, 9.92486], [79.15319824, 9.9240284], [79.1534729, 9.9240303], [79.1534729, 9.92236042], [79.15374756, 9.92236233], [79.15374756, 9.92041779], [79.1534729, 9.92041969], [79.1534729, 9.91986179], [79.15319824, 9.91986179], [79.15319061, 9.91930962], [79.15291595, 9.91930962], [79.15291595, 9.91874027], [79.1526413, 9.91874981], [79.1526413, 9.91847229], [79.15235901, 9.91847229], [79.15235901, 9.91791534], [79.15207672, 9.91792011], [79.15207672, 9.91735935], [79.15180206, 9.91736221], [79.15180206, 9.91708374], [79.1515274, 9.91708374], [79.1515274, 9.91652679], [79.15126038, 9.91652966], [79.15126038, 9.91624928], [79.15097046, 9.91624928], [79.15097046, 9.91597366], [79.1506958, 9.9159708], [79.1506958, 9.91541672], [79.15040588, 9.91541958], [79.15040588, 9.9151392], [79.15013885, 9.9151392], [79.15013885, 9.91486073], [79.14985657, 9.91486073], [79.14985657, 9.91431046], [79.14958191, 9.91431046], [79.14958191, 9.91375065], [79.14930725, 9.91375065], [79.14930725, 9.91319084], [79.14902496, 9.91319466], [79.14902496, 9.91263866], [79.14875031, 9.91264057], [79.14875031, 9.91236115], [79.14847565, 9.91236115], [79.14847565, 9.91208267], [79.1479187, 9.91208267], [79.1479187, 9.91180515], [79.14763641, 9.91181183], [79.14763641, 9.9115324], [79.14653015, 9.9115324], [79.14653015, 9.91125107], [79.14624786, 9.91125107], [79.14624786, 9.91097069], [79.14653015, 9.9109726], [79.14653015, 9.9104166], [79.14679718, 9.91041946], [79.14679718, 9.91014099], [79.1470871, 9.91014099], [79.1470871, 9.90957069], [79.14430237, 9.90958309], [79.14430237, 9.90930462], [79.14402771, 9.90930939], [79.14402771, 9.90903091], [79.14375305, 9.90903091], [79.14375305, 9.90875053], [79.14347076, 9.90875053], [79.14347076, 9.90847111], [79.14319611, 9.90847301], [79.14319611, 9.90791702], [79.14263916, 9.90792084], [79.14263916, 9.90736103], [79.14235687, 9.90736103], [79.14235687, 9.9070797], [79.14208221, 9.90708256], [79.14208221, 9.90680695], [79.14180756, 9.90680695], [79.14180756, 9.90652657], [79.1415329, 9.90653133], [79.1415329, 9.90625095], [79.14125061, 9.90625095], [79.14125061, 9.90569019], [79.14097595, 9.90569496], [79.14097595, 9.90541744], [79.14068604, 9.90542126], [79.14068604, 9.90514088], [79.14041901, 9.90514088], [79.14041901, 9.90486145], [79.14013672, 9.90486145], [79.14013672, 9.90458202], [79.13986206, 9.90458202], [79.13986206, 9.90430355], [79.13957977, 9.90431118], [79.13957977, 9.9040308], [79.13932037, 9.9040308], [79.13932037, 9.90347004], [79.13903046, 9.9034729], [79.13903046, 9.90319443], [79.13874817, 9.90319443], [79.13874817, 9.90291595], [79.13846588, 9.90292072], [79.13846588, 9.9026413], [79.13819122, 9.9026413], [79.13819122, 9.90235996], [79.13791656, 9.90235996], [79.13791656, 9.9020853], [79.13764191, 9.9020853], [79.13764191, 9.90180588], [79.13735962, 9.90181065], [79.13735962, 9.90153122], [79.13709259, 9.90153122], [79.13709259, 9.90125275], [79.13680267, 9.90125275], [79.13680267, 9.90097046], [79.13652802, 9.90097237], [79.13652802, 9.90041637], [79.13625336, 9.90042114], [79.13625336, 9.90014267], [79.13597107, 9.90014267], [79.13597107, 9.89986038], [79.13569641, 9.89986229], [79.13569641, 9.89958382], [79.13541412, 9.89958191], [79.13541412, 9.8993063], [79.13513947, 9.89931107], [79.13513947, 9.89902973], [79.13430786, 9.89902973], [79.13430786, 9.89875031], [79.13346863, 9.89875031], [79.13346863, 9.89847183], [79.13319397, 9.89847183], [79.13319397, 9.89791584], [79.13291931, 9.89792061], [79.13291931, 9.89735985], [79.13263702, 9.89735985], [79.13263702, 9.89708424], [79.13223267, 9.89708424], [79.13153076, 9.89708424], [79.13153076, 9.89652824], [79.13069153, 9.89653015], [79.13069153, 9.89625168], [79.13041687, 9.89625168], [79.13041687, 9.89597034], [79.13014221, 9.89597225], [79.13014221, 9.89569378], [79.12985992, 9.89569378], [79.12985992, 9.89541626], [79.1295929, 9.89542007], [79.1295929, 9.89513969], [79.12930298, 9.89513969], [79.12930298, 9.89486027], [79.12902832, 9.89486217], [79.12902832, 9.8945837], [79.12847137, 9.8945837], [79.12847137, 9.89430618], [79.12819672, 9.89431], [79.12819672, 9.89402962], [79.1279068, 9.89402962], [79.1279068, 9.89346886], [79.12763977, 9.89347172], [79.12763977, 9.8931942], [79.12735748, 9.8931942], [79.12735748, 9.89264011], [79.12709045, 9.89264202], [79.12709045, 9.89236164], [79.12680817, 9.89236164], [79.12680817, 9.89208412], [79.12652588, 9.89208412], [79.12652588, 9.89106274], [79.12652588, 9.89069557], [79.12625122, 9.89069557], [79.12625122, 9.89041805], [79.12596893, 9.89041996], [79.12596893, 9.88958073], [79.12569427, 9.88958263], [79.12569427, 9.88930511], [79.12541962, 9.88931179], [79.12541962, 9.88653183], [79.12513733, 9.88653183], [79.12513733, 9.88541889], [79.12486267, 9.88541889], [79.12486267, 9.88431168], [79.12458038, 9.88431168], [79.12458038, 9.88402939], [79.12403107, 9.88402939], [79.12403107, 9.88375092], [79.12374878, 9.88375092], [79.12374878, 9.88291931], [79.12346649, 9.88291931], [79.12346649, 9.88263035], [79.12319183, 9.88263893], [79.12319183, 9.88236141], [79.12291718, 9.88236141], [79.12291718, 9.88180542], [79.12264252, 9.88180923], [79.12264252, 9.88125134], [79.12236023, 9.88125134], [79.12236023, 9.88097286], [79.12208557, 9.88097286], [79.12208557, 9.88041687], [79.12180328, 9.88042068], [79.12180328, 9.88014126], [79.12152863, 9.88014126], [79.12152863, 9.87986088], [79.12124634, 9.87986088], [79.12124634, 9.87958336], [79.12095642, 9.87959194], [79.12095642, 9.87903118], [79.12069702, 9.87903118], [79.12069702, 9.8787508], [79.1204071, 9.8787508], [79.1204071, 9.87764072], [79.11985779, 9.87764072], [79.11985779, 9.87681961], [79.11958313, 9.87681961], [79.11958313, 9.87625122], [79.11930847, 9.87625122], [79.11930847, 9.87569427], [79.11902618, 9.87569427], [79.11902618, 9.87458229], [79.11875153, 9.87458229], [79.11875153, 9.87374973], [79.11902618, 9.87374973], [79.11902618, 9.87345886], [79.11930847, 9.87347221], [79.11930847, 9.87263775], [79.11958313, 9.87263966], [79.11958313, 9.87207985], [79.11985779, 9.87208366], [79.11985779, 9.87097168], [79.11958313, 9.87097168], [79.11958313, 9.87014008], [79.11985779, 9.87014008], [79.11985779, 9.86957932], [79.12014008, 9.86958408], [79.12014008, 9.86902809], [79.1204071, 9.86903], [79.1204071, 9.86874962], [79.12095642, 9.86874962], [79.12095642, 9.86847019], [79.12152863, 9.8684721], [79.12152863, 9.86819363], [79.12180328, 9.86819363], [79.12180328, 9.86791801], [79.12236023, 9.86791992], [79.12236023, 9.86765099], [79.12291718, 9.86765099], [79.12291718, 9.86708164], [79.12319183, 9.86708355], [79.12319183, 9.86652756], [79.12346649, 9.86653042], [79.12346649, 9.86597157], [79.12374878, 9.86597157], [79.12374878, 9.86541557], [79.12403107, 9.86542034], [79.12403107, 9.86458969], [79.12431335, 9.86458969], [79.12431335, 9.86347103], [79.12458038, 9.86347103], [79.12458038, 9.8629179], [79.12486267, 9.86291981], [79.12486267, 9.86236095], [79.12458038, 9.86236095], [79.12458038, 9.86208344], [79.12430573, 9.86208344], [79.12430573, 9.86152744], [79.12403107, 9.86152744], [79.12403107, 9.86124897], [79.12431335, 9.86125183], [79.12431335, 9.86097145], [79.12374878, 9.86097336], [79.12374878, 9.86041737], [79.12403107, 9.86042023], [79.12403107, 9.85958099], [79.12430573, 9.8595829], [79.12430573, 9.85902691], [79.12403107, 9.85903168], [79.12403107, 9.8587513], [79.12374878, 9.8587513], [79.12374878, 9.85847092], [79.12347412, 9.85847092], [79.12347412, 9.8581953], [79.12319183, 9.8581953], [79.12319183, 9.85763931], [79.12291718, 9.85764122], [79.12291718, 9.85680866], [79.12264252, 9.85680866], [79.12264252, 9.85624886], [79.12236023, 9.85624886], [79.12236023, 9.85569477], [79.12208557, 9.85569477], [79.12208557, 9.85513878], [79.12180328, 9.85514069], [79.12180328, 9.85457993], [79.12152863, 9.85458279], [79.12152863, 9.85430527], [79.12095642, 9.85431194], [79.12095642, 9.85375118], [79.12069702, 9.85375118], [79.12069702, 9.85319519], [79.12041473, 9.85319519], [79.12041473, 9.85291672], [79.11985779, 9.85292053], [79.11985779, 9.85236073], [79.11958313, 9.85236073], [79.11958313, 9.85180664], [79.11930847, 9.85181141], [79.11930847, 9.85153103], [79.11875153, 9.85153103], [79.11875153, 9.85125065], [79.11846924, 9.85125065], [79.11846924, 9.85097027], [79.11819458, 9.85097313], [79.11819458, 9.85069466], [79.11791992, 9.85069466], [79.11791992, 9.85041714], [79.11736298, 9.85042095], [79.11736298, 9.85014057], [79.11708069, 9.85014057], [79.11708069, 9.8495779], [79.11680603, 9.84958458], [79.11680603, 9.8493042], [79.11653137, 9.84931087], [79.11653137, 9.84903145], [79.11624908, 9.84903145], [79.11624908, 9.84875011], [79.1159668, 9.84875011], [79.1159668, 9.84846973], [79.11569214, 9.84847164], [79.11569214, 9.84819412], [79.11541748, 9.84819412], [79.11541748, 9.84791565], [79.11515045, 9.84792137], [79.11515045, 9.84764099], [79.11486053, 9.84764099], [79.11486053, 9.84735966], [79.11458588, 9.84736156], [79.11458588, 9.84708214], [79.11430359, 9.84708214], [79.11430359, 9.84680557], [79.11374664, 9.84681129], [79.11374664, 9.84652138], [79.11347198, 9.84652805], [79.11347198, 9.84624958], [79.11319733, 9.84624958], [79.11319733, 9.84597015], [79.11291504, 9.84597206], [79.11291504, 9.84569359], [79.11235809, 9.84569359], [79.11235809, 9.84541607], [79.11209106, 9.84542274], [79.11209106, 9.84514046], [79.11180878, 9.84514046], [79.11180878, 9.84486008], [79.11152649, 9.84486008], [79.11152649, 9.84458447], [79.11125183, 9.84458447], [79.11125183, 9.84430599], [79.11068726, 9.84431076], [79.11068726, 9.84403038], [79.11042023, 9.84403038], [79.11042023, 9.84375], [79.11013794, 9.84375], [79.11013794, 9.84348106], [79.10986328, 9.84348106], [79.10986328, 9.84318924], [79.10958099, 9.84319401], [79.10958099, 9.84291553], [79.10930634, 9.8429203], [79.10930634, 9.84263992], [79.10901642, 9.84263992], [79.10901642, 9.84208202], [79.10874939, 9.84208393], [79.10874939, 9.84180641], [79.1084671, 9.84181023], [79.1084671, 9.84069061], [79.10819244, 9.84069443], [79.10819244, 9.84014034], [79.10791779, 9.84014034], [79.10791779, 9.83986187], [79.1076355, 9.83986187], [79.1076355, 9.83902836], [79.10791779, 9.83903027], [79.10791779, 9.83847237], [79.1076355, 9.83847237], [79.1076355, 9.83791542], [79.10736084, 9.83792019], [79.10736084, 9.83763981], [79.10679626, 9.83763981], [79.10679626, 9.83708096], [79.10624695, 9.83708382], [79.10624695, 9.8368063], [79.10595703, 9.83681011], [79.10595703, 9.83652973], [79.10542297, 9.83652973], [79.10542297, 9.83624935], [79.1048584, 9.83624935], [79.1048584, 9.83597088], [79.10430908, 9.83597088], [79.10430908, 9.83569336], [79.10402679, 9.83569336], [79.10402679, 9.83541775], [79.10346985, 9.83541965], [79.10346985, 9.83513927], [79.10321045, 9.83513927], [79.10321045, 9.83541965], [79.10263824, 9.83541965], [79.10263824, 9.83513927], [79.10235596, 9.83513927], [79.10235596, 9.83485889], [79.10097504, 9.8348608], [79.10097504, 9.83430481], [79.10041809, 9.83430958], [79.10041809, 9.83403015], [79.10015106, 9.83403015], [79.10015106, 9.83375072], [79.09958649, 9.83375072], [79.09958649, 9.8334713], [79.0993042, 9.8334713], [79.0993042, 9.83319473], [79.09874725, 9.83319473], [79.09874725, 9.83291721], [79.0984726, 9.83292198], [79.0984726, 9.8326416], [79.09792328, 9.8326416], [79.09792328, 9.83236122], [79.09764099, 9.83236122], [79.09764099, 9.83208275], [79.09708405, 9.83208275], [79.09708405, 9.83180523], [79.0967865, 9.8318119], [79.0967865, 9.83154106], [79.09625244, 9.83154106], [79.09622955, 9.83125114], [79.0956955, 9.83125114], [79.0956955, 9.83097267], [79.09541321, 9.83097267], [79.09541321, 9.83069515], [79.09486389, 9.83069515], [79.09486389, 9.83041668], [79.0945816, 9.83041859], [79.0945816, 9.83014107], [79.09401703, 9.83014107], [79.09401703, 9.82986069], [79.09375, 9.82986069], [79.09375, 9.82958317], [79.09347534, 9.82958317], [79.09347534, 9.8293047], [79.09319305, 9.82930946], [79.09319305, 9.82903099], [79.0929184, 9.82903099], [79.0929184, 9.82875061], [79.09263611, 9.82875061], [79.09263611, 9.82847977], [79.09208679, 9.82847977], [79.09208679, 9.82818985], [79.0918045, 9.82819462], [79.0918045, 9.8279171], [79.09152985, 9.82792091], [79.09152985, 9.82764053], [79.09124756, 9.82764053], [79.09124756, 9.82707977], [79.0909729, 9.82708263], [79.0909729, 9.82680511], [79.09069824, 9.82681179], [79.09069061, 9.82653141], [79.09041595, 9.82653141], [79.09041595, 9.82625103], [79.0901413, 9.82625103], [79.0901413, 9.82569027], [79.08985901, 9.82569504], [79.08985901, 9.82541656], [79.08957672, 9.82542133], [79.08957672, 9.82514095], [79.08930206, 9.82514095], [79.08930206, 9.82486057], [79.0890274, 9.82486057], [79.0890274, 9.82458305], [79.08875275, 9.82458305], [79.08875275, 9.82375145], [79.08847046, 9.82375145], [79.08847046, 9.82347012], [79.0881958, 9.82347298], [79.0881958, 9.82319546], [79.08791351, 9.82319546], [79.08791351, 9.82291603], [79.08763885, 9.82291889], [79.08763885, 9.82264137], [79.08735657, 9.82264137], [79.08735657, 9.82207966], [79.08708191, 9.82208538], [79.08708191, 9.82180691], [79.08680725, 9.82181072], [79.08680725, 9.8215313], [79.08653259, 9.8215313], [79.08653259, 9.82070065], [79.08625031, 9.82069016], [79.08625031, 9.82013798], [79.08598328, 9.82014275], [79.08598328, 9.81986046], [79.08569336, 9.81986237], [79.08569336, 9.81958199], [79.0854187, 9.81958199], [79.0854187, 9.8190279], [79.08513641, 9.81903267], [79.08513641, 9.81847], [79.08486176, 9.81847191], [79.08486176, 9.81791592], [79.0845871, 9.81792068], [79.0845871, 9.81735992], [79.08429718, 9.81735992], [79.08429718, 9.81681061], [79.08403015, 9.81681061], [79.08403015, 9.81624985], [79.08374786, 9.81624985], [79.08374786, 9.81569386], [79.08347321, 9.81569386], [79.08347321, 9.81513786], [79.08319092, 9.81514168], [79.08319092, 9.81486034], [79.08291626, 9.81486225], [79.08291626, 9.81430626], [79.0826416, 9.81431007], [79.0826416, 9.81375027], [79.08235931, 9.81375027], [79.08235931, 9.81319427], [79.08208466, 9.81319427], [79.08208466, 9.8120842], [79.08180237, 9.8120842], [79.08180237, 9.81152821], [79.08152771, 9.81153202], [79.08152771, 9.81124973], [79.08097076, 9.81124973], [79.08097076, 9.81013966], [79.08069611, 9.81013966], [79.08069611, 9.80985928], [79.08041382, 9.80986214], [79.08041382, 9.80847359], [79.08013916, 9.80847359], [79.08013916, 9.80708313], [79.0798645, 9.80708313], [79.0798645, 9.80541706], [79.07958221, 9.80542183], [79.07958221, 9.80375099], [79.07985687, 9.80375099], [79.07985687, 9.80264091], [79.07958221, 9.80264091], [79.07958221, 9.80180931], [79.07930756, 9.80180931], [79.07930756, 9.80125141], [79.07902527, 9.80125141], [79.07902527, 9.80069542], [79.07875061, 9.80069542], [79.07875061, 9.80041695], [79.07847595, 9.80041885], [79.07847595, 9.80014133], [79.07818604, 9.80014133], [79.07818604, 9.79957962], [79.07791901, 9.79958344], [79.07791901, 9.79902744], [79.07763672, 9.79903126], [79.07763672, 9.79875088], [79.07707977, 9.79875088], [79.07707977, 9.79846954], [79.07680511, 9.79847336], [79.07680511, 9.79819489], [79.07624817, 9.79819489], [79.07624817, 9.79791737], [79.07598114, 9.79792118], [79.07598114, 9.7976408], [79.07541656, 9.7976408], [79.07541656, 9.79736137], [79.07514191, 9.79736137], [79.07514191, 9.79708195], [79.07458496, 9.79708195], [79.07458496, 9.79680443], [79.07430267, 9.7968111], [79.07430267, 9.79653072], [79.07402802, 9.79653072], [79.07402802, 9.7962513], [79.07347107, 9.7962513], [79.07347107, 9.79597282], [79.07319641, 9.79597282], [79.07319641, 9.79569435], [79.07291412, 9.79569435], [79.07291412, 9.79541588], [79.07263947, 9.79541588], [79.07263947, 9.79513836], [79.07235718, 9.79514122], [79.07235718, 9.79486275], [79.07208252, 9.79486275], [79.07208252, 9.79458046], [79.07180786, 9.79458237], [79.07180786, 9.7943058], [79.0715332, 9.79431057], [79.0715332, 9.79403114], [79.07125092, 9.79403114], [79.07125092, 9.79375267], [79.07096863, 9.79375267], [79.07096863, 9.79347038], [79.07041931, 9.79347229], [79.07041931, 9.79319382], [79.07013702, 9.79319382], [79.07013702, 9.7929163], [79.06984711, 9.79292107], [79.06984711, 9.79263973], [79.06958008, 9.79263973], [79.06958008, 9.7923708], [79.06931305, 9.7923708], [79.06931305, 9.79207993], [79.06903076, 9.79208374], [79.06903076, 9.79152775], [79.06874847, 9.79152966], [79.06874847, 9.79125023], [79.06846619, 9.79125023], [79.06846619, 9.79068947], [79.06819153, 9.79069424], [79.06819153, 9.78985977], [79.06791687, 9.78986168], [79.06791687, 9.78958035], [79.06764221, 9.78958416], [79.06764221, 9.78902817], [79.06735992, 9.78903008], [79.06735992, 9.78847027], [79.06708527, 9.78847218], [79.06708527, 9.78791809], [79.06681061, 9.78792], [79.06681061, 9.78736019], [79.06652832, 9.7873621], [79.06652832, 9.78680611], [79.06624603, 9.78680992], [79.06624603, 9.78624058], [79.06597137, 9.78625011], [79.06597137, 9.78597164], [79.06541443, 9.78597164], [79.06541443, 9.78569412], [79.06513977, 9.78569412], [79.06513977, 9.78541565], [79.06485748, 9.78542042], [79.06485748, 9.78486156], [79.06458282, 9.78486156], [79.06458282, 9.78458405], [79.06430817, 9.78458405], [79.06430817, 9.78430557], [79.06404114, 9.78431034], [79.06404114, 9.78402996], [79.06375122, 9.78402996], [79.06375122, 9.78374958], [79.06346893, 9.78374958], [79.06346893, 9.7834692], [79.06319427, 9.78347111], [79.06319427, 9.78319263], [79.06291962, 9.78319263], [79.06291962, 9.78291798], [79.06263733, 9.78292179], [79.06263733, 9.78236198], [79.06236267, 9.78236198], [79.06236267, 9.78180504], [79.06208038, 9.78180981], [79.06208038, 9.78125191], [79.06181335, 9.78125191], [79.06181335, 9.78043079], [79.06153107, 9.78043079], [79.06153107, 9.77958107], [79.06124878, 9.77958298], [79.06124878, 9.77875137], [79.06096649, 9.77875137], [79.06096649, 9.7776413], [79.06069183, 9.7776413], [79.06069183, 9.77737045], [79.06041718, 9.77737045], [79.06041718, 9.77680969], [79.06014252, 9.77680969], [79.06014252, 9.77652931], [79.05986023, 9.77652931], [79.05986023, 9.77541924], [79.0595932, 9.77541924], [79.0595932, 9.77486134], [79.05930328, 9.77486134], [79.05930328, 9.77458286], [79.05902863, 9.77458286], [79.05902863, 9.77430534], [79.05874634, 9.77430534], [79.05874634, 9.77375126], [79.05847168, 9.77375126], [79.05847168, 9.77347279], [79.05819702, 9.77347279], [79.05819702, 9.77319527], [79.05791473, 9.77319527], [79.05791473, 9.77263927], [79.05764008, 9.77264118], [79.05764008, 9.7723608], [79.05735779, 9.7723608], [79.05735779, 9.77208328], [79.05680847, 9.77208328], [79.05680847, 9.77180672], [79.05596924, 9.77181053], [79.05596924, 9.77153111], [79.05487061, 9.77153111], [79.05487061, 9.77123928], [79.05403137, 9.77125072], [79.05403137, 9.77097321], [79.05347443, 9.77097321], [79.05347443, 9.77069473], [79.05291748, 9.77069473], [79.05291748, 9.77041721], [79.05264282, 9.77042103], [79.05264282, 9.77014065], [79.05210114, 9.77014065], [79.05210114, 9.76986027], [79.05180359, 9.76986027], [79.05180359, 9.76958466], [79.05124664, 9.76958466], [79.05124664, 9.76930428], [79.05097198, 9.76931095], [79.05097198, 9.76875114], [79.04957581, 9.76875114], [79.04957581, 9.76820087], [79.04875183, 9.76820087], [79.04875183, 9.76792145], [79.04680634, 9.76792145], [79.04680634, 9.76764107], [79.0459671, 9.76764107], [79.0459671, 9.76735973], [79.04541779, 9.76735973], [79.04541779, 9.76708221], [79.04528809, 9.76708221], [79.04486084, 9.76708221], [79.04486084, 9.76680565], [79.04429626, 9.76681137], [79.04429626, 9.76653099], [79.04347229, 9.76653099], [79.04347229, 9.76624966], [79.0429306, 9.76624966], [79.0429306, 9.76597023], [79.04180908, 9.76597023], [79.04180908, 9.76624966], [79.04152679, 9.76624966], [79.04152679, 9.76597023], [79.04125214, 9.76597214], [79.04125214, 9.76513767], [79.04096985, 9.76513958], [79.04096985, 9.76486015], [79.0404129, 9.76486015], [79.0404129, 9.76458359], [79.04013824, 9.76458359], [79.04013824, 9.76430607], [79.03987122, 9.76431084], [79.03987122, 9.76403046], [79.03930664, 9.76403046], [79.03930664, 9.76375008], [79.03901672, 9.76375008], [79.03901672, 9.7634697], [79.03874969, 9.7634716], [79.03874969, 9.76319408], [79.03847504, 9.76319408], [79.03847504, 9.76291561], [79.03819275, 9.76292038], [79.03819275, 9.76264], [79.0376358, 9.76264], [79.0376358, 9.76235962], [79.03736115, 9.76236153], [79.03736115, 9.76208401], [79.03708649, 9.76208401], [79.03708649, 9.76180553], [79.03681183, 9.76181126], [79.03681183, 9.76124954], [79.03652954, 9.76124954], [79.03652954, 9.76097202], [79.03624725, 9.76097202], [79.03624725, 9.76069355], [79.0359726, 9.76069355], [79.0359726, 9.76013756], [79.03569794, 9.76014042], [79.03569794, 9.75986195], [79.03541565, 9.75986195], [79.03541565, 9.75958443], [79.03514099, 9.75958443], [79.03514099, 9.75902843], [79.0348587, 9.75903034], [79.0348587, 9.75847244], [79.03458405, 9.75847244], [79.03458405, 9.75791645], [79.03430176, 9.75792027], [79.03430176, 9.75735855], [79.0340271, 9.75736237], [79.0340271, 9.75708389], [79.03375244, 9.75708389], [79.03375244, 9.75680637], [79.03347015, 9.75681019], [79.03347015, 9.75626087], [79.03320313, 9.75626087], [79.03320313, 9.75597095], [79.03291321, 9.75597095], [79.03291321, 9.75564957], [79.03291321, 9.75541782], [79.03263855, 9.75541973], [79.03263855, 9.7551403], [79.03235626, 9.7551403], [79.03235626, 9.75458145], [79.0320816, 9.75458336], [79.0320816, 9.75430489], [79.03180695, 9.75430965], [79.03180695, 9.75374889], [79.03151703, 9.75374889], [79.03151703, 9.75347137], [79.03125, 9.75347137], [79.03125, 9.75319481], [79.0309906, 9.75319958], [79.0309906, 9.75292015], [79.0304184, 9.75292015], [79.0304184, 9.75264168], [79.03013611, 9.75264168], [79.03013611, 9.7523613], [79.02986145, 9.7523613], [79.02986145, 9.75208282], [79.02958679, 9.75208282], [79.02958679, 9.75152683], [79.02929688, 9.7515316], [79.02929688, 9.75125122], [79.02902985, 9.75125122], [79.02902985, 9.75069523], [79.02874756, 9.75069523], [79.02874756, 9.75013924], [79.0284729, 9.75013924], [79.0284729, 9.74958324], [79.02819824, 9.74958324], [79.02819061, 9.74874878], [79.02793121, 9.74875069], [79.02793121, 9.74818993], [79.0276413, 9.74819469], [79.0276413, 9.7476387], [79.02735901, 9.74764061], [79.02735901, 9.74707127], [79.02708435, 9.74708271], [79.02708435, 9.74680519], [79.02680206, 9.74681187], [79.02680206, 9.74653053], [79.0265274, 9.74653053], [79.0265274, 9.74597073], [79.02625275, 9.74597263], [79.02625275, 9.74569511], [79.02597046, 9.74569511], [79.02597046, 9.74541664], [79.0256958, 9.74542141], [79.0256958, 9.74514103], [79.02540588, 9.74514103], [79.02540588, 9.74486065], [79.02513885, 9.74486065], [79.02513885, 9.74458313], [79.0248642, 9.74458313], [79.0248642, 9.74430466], [79.02430725, 9.74431992], [79.02430725, 9.74403095], [79.02403259, 9.74403095], [79.02403259, 9.74347019], [79.02375031, 9.74347305], [79.02375031, 9.74319458], [79.02347565, 9.74319458], [79.02347565, 9.74291706], [79.0229187, 9.74292088], [79.0229187, 9.74264145], [79.02263641, 9.74264145], [79.02263641, 9.74236012], [79.02236176, 9.74236012], [79.02236176, 9.74208546], [79.0220871, 9.74208546], [79.0220871, 9.74180698], [79.02179718, 9.74180889], [79.02179718, 9.74153137], [79.02124786, 9.74153137], [79.02124786, 9.74125957], [79.02097321, 9.74125957], [79.02097321, 9.74096966], [79.02069092, 9.74097157], [79.02069092, 9.74069405], [79.02041626, 9.74069405], [79.02041626, 9.74013805], [79.0201416, 9.74014091], [79.0201416, 9.73985958], [79.01985931, 9.73986244], [79.01985931, 9.73930645], [79.01957703, 9.73931122], [79.01957703, 9.73875046], [79.01930237, 9.73875046], [79.01930237, 9.73819447], [79.01902771, 9.73819447], [79.01902771, 9.73763847], [79.01873779, 9.73764038], [79.01873779, 9.73681068], [79.01847076, 9.73681068], [79.01847076, 9.73596954], [79.01819611, 9.7359724], [79.01819611, 9.73513794], [79.01791382, 9.73513794], [79.01791382, 9.73430634], [79.01763916, 9.7343111], [79.01763916, 9.73375034], [79.01735687, 9.73375034], [79.01735687, 9.73319054], [79.01763916, 9.73319435], [79.01763916, 9.73264027], [79.01735687, 9.73264027], [79.01735687, 9.73236179], [79.01708221, 9.73236179], [79.01708221, 9.73206997], [79.01680756, 9.73208427], [79.01680756, 9.7318058], [79.0165329, 9.73180962], [79.0165329, 9.73153019], [79.01625061, 9.73153019], [79.01625061, 9.73124981], [79.01597595, 9.73124981], [79.01597595, 9.73097229], [79.01569366, 9.73097229], [79.01569366, 9.73041534], [79.01541901, 9.73042011], [79.01541901, 9.73013973], [79.01513672, 9.73013973], [79.01513672, 9.72985935], [79.01486206, 9.72986221], [79.01486206, 9.72958374], [79.01457977, 9.72958374], [79.01457977, 9.72930622], [79.01431274, 9.72932053], [79.01431274, 9.72902966], [79.01403046, 9.72902966], [79.01403046, 9.72874928], [79.01374817, 9.72874928], [79.01374817, 9.72847366], [79.01347351, 9.7284708], [79.01347351, 9.72819328], [79.01319122, 9.72819328], [79.01319122, 9.72791767], [79.01291656, 9.72791958], [79.01291656, 9.7276392], [79.01235962, 9.7276392], [79.01235962, 9.72736073], [79.01208496, 9.72736073], [79.01208496, 9.72708321], [79.01180267, 9.72708321], [79.01180267, 9.72680473], [79.01152802, 9.72681046], [79.01152802, 9.72653198], [79.01125336, 9.72653198], [79.01125336, 9.72625065], [79.00985718, 9.72625065], [79.00985718, 9.72597122], [79.00958252, 9.72597122], [79.00958252, 9.72569466], [79.00930786, 9.72569466], [79.00930786, 9.72541714], [79.0090332, 9.72542191], [79.0090332, 9.72514153], [79.00875092, 9.72514153], [79.00875092, 9.72458076], [79.00846863, 9.72458267], [79.00846863, 9.7234726], [79.00819397, 9.7234726], [79.00819397, 9.72319508], [79.00791931, 9.72319508], [79.00791931, 9.72263908], [79.00763702, 9.72264099], [79.00763702, 9.72180939], [79.00736237, 9.72180939], [79.00736237, 9.72125053], [79.00708008, 9.72125053], [79.00708008, 9.72013187], [79.00680542, 9.72013855], [79.00680542, 9.71986103], [79.00596619, 9.71986103], [79.00596619, 9.7195797], [79.00569153, 9.71958256], [79.00569153, 9.71902657], [79.00541687, 9.71903133], [79.00541687, 9.71847057], [79.00514221, 9.71847343], [79.00514221, 9.71819496], [79.00485992, 9.71819496], [79.00485992, 9.71763897], [79.0045929, 9.71764088], [79.0045929, 9.71709156], [79.00430298, 9.71709156], [79.00430298, 9.71681118], [79.00402832, 9.71681118], [79.00402832, 9.7165308], [79.00347137, 9.7165308], [79.00347137, 9.71625137], [79.00319672, 9.71625137], [79.00319672, 9.7159729], [79.00291443, 9.7159729], [79.00291443, 9.71569538], [79.00263977, 9.71569538], [79.00263977, 9.71541595], [79.00180817, 9.71542072], [79.00180817, 9.7151413], [79.00152588, 9.7151413], [79.00152588, 9.71457958], [79.00125122, 9.71458244], [79.00125122, 9.71430683], [79.00096893, 9.71431065], [79.00096893, 9.71403122], [79.0007019, 9.71403122], [79.0007019, 9.71375275], [78.99986267, 9.71375275], [78.99986267, 9.71347046], [78.99930573, 9.71347237], [78.99930573, 9.71319389], [78.99874878, 9.71319389], [78.99874878, 9.71291637], [78.99819183, 9.71292114], [78.99819183, 9.71264267], [78.99791718, 9.71264267], [78.99791718, 9.71236038], [78.99764252, 9.71236229], [78.99764252, 9.71208382], [78.99736023, 9.71208191], [78.99736023, 9.71152782], [78.9970932, 9.71153069], [78.9970932, 9.71125031], [78.99680328, 9.71125031], [78.99680328, 9.71097183], [78.99652863, 9.71097183], [78.99652863, 9.71069431], [78.99624634, 9.71069431], [78.99624634, 9.71041584], [78.99597168, 9.71042061], [78.99597168, 9.71014023], [78.99569702, 9.71014023], [78.99569702, 9.70958042], [78.99514008, 9.70958424], [78.99514008, 9.70930576], [78.99485779, 9.70931053], [78.99485779, 9.70903015], [78.99456787, 9.70903015], [78.99456787, 9.70875168], [78.99430847, 9.70875168], [78.99430847, 9.70847034], [78.99402618, 9.70847225], [78.99402618, 9.70791626], [78.99375153, 9.70792007], [78.99375153, 9.70736027], [78.99346924, 9.70736217], [78.99346924, 9.7070837], [78.99319458, 9.7070837], [78.99319458, 9.70680618], [78.99291992, 9.70681], [78.99291992, 9.70625019], [78.99263763, 9.70625019], [78.99263763, 9.7056942], [78.99236298, 9.7056942], [78.99236298, 9.70514011], [78.99208069, 9.7051506], [78.99208069, 9.70486164], [78.99180603, 9.70486164], [78.99180603, 9.70430565], [78.99153137, 9.70431042], [78.99153137, 9.70403004], [78.99124908, 9.70403004], [78.99124908, 9.70374966], [78.9909668, 9.70374966], [78.9909668, 9.70346928], [78.99069214, 9.70347214], [78.99069214, 9.70291805], [78.99041748, 9.70291996], [78.99041748, 9.70097065], [78.99013519, 9.70097446], [78.99013519, 9.70013905], [78.98986053, 9.70014191], [78.98986053, 9.69958115], [78.98958588, 9.69958305], [78.98958588, 9.69930458], [78.98929596, 9.6993103], [78.98929596, 9.69875145], [78.98902893, 9.69875145], [78.98902893, 9.69847107], [78.98874664, 9.69847107], [78.98874664, 9.69791698], [78.98847198, 9.69791985], [78.98847198, 9.69736099], [78.98819733, 9.69736099], [78.98819733, 9.696805], [78.98792267, 9.69680977], [78.98792267, 9.69652939], [78.98764038, 9.69652939], [78.98764038, 9.69625092], [78.98735809, 9.69625092], [78.98735809, 9.69596195], [78.98708344, 9.6959734], [78.98708344, 9.69569492], [78.98680878, 9.69569492], [78.98680878, 9.6954174], [78.98652649, 9.69541931], [78.98652649, 9.69514084], [78.98596954, 9.69514084], [78.98596954, 9.69486141], [78.98569489, 9.69486141], [78.98569489, 9.69458294], [78.98542023, 9.69458294], [78.98542023, 9.69430542], [78.98513794, 9.69430923], [78.98513794, 9.69402885], [78.98458099, 9.69402885], [78.98458099, 9.69375134], [78.98430634, 9.69375134], [78.98430634, 9.69319534], [78.98402405, 9.69319534], [78.98402405, 9.69291687], [78.98374939, 9.69292068], [78.98374939, 9.69264126], [78.9834671, 9.69264126], [78.9834671, 9.69236088], [78.98319244, 9.69236088], [78.98319244, 9.69208336], [78.98291779, 9.69208336], [78.98291779, 9.69180679], [78.98262787, 9.69181061], [78.98262787, 9.69153118], [78.98236084, 9.69153118], [78.98236084, 9.69097042], [78.98208618, 9.69097328], [78.98208618, 9.69069481], [78.98180389, 9.69069481], [78.98180389, 9.69041729], [78.98152924, 9.6904211], [78.98152924, 9.6898613], [78.98124695, 9.6898613], [78.98124695, 9.68930435], [78.98097229, 9.68931103], [78.98097229, 9.68903065], [78.98069763, 9.68903065], [78.98069763, 9.68847275], [78.98041534, 9.68847275], [78.98041534, 9.68735981], [78.9798584, 9.68735981], [78.9798584, 9.68680573], [78.97959137, 9.68681145], [78.97959137, 9.68597031], [78.97930908, 9.68597221], [78.97930908, 9.68513775], [78.97902679, 9.68513966], [78.97902679, 9.68431091], [78.97875214, 9.68431091], [78.97875214, 9.68375015], [78.97846985, 9.68375015], [78.97846985, 9.68291569], [78.97820282, 9.68292141], [78.97820282, 9.68264008], [78.9779129, 9.68264008], [78.9779129, 9.68208027], [78.97763824, 9.68208408], [78.97763824, 9.68152809], [78.97735596, 9.68153], [78.97735596, 9.68124962], [78.9770813, 9.68124962], [78.9770813, 9.68068886], [78.97680664, 9.68069363], [78.97680664, 9.68013763], [78.97653198, 9.68013954], [78.97653198, 9.67958164], [78.97624969, 9.67958355], [78.97624969, 9.67902756], [78.97598267, 9.67903042], [78.97598267, 9.67847157], [78.97569275, 9.67847157], [78.97569275, 9.67763996], [78.97541809, 9.67763996], [78.97541809, 9.6770792], [78.9751358, 9.67708397], [78.9751358, 9.6754179], [78.97486115, 9.67541981], [78.97486115, 9.67458057], [78.97458649, 9.67458344], [78.97458649, 9.67319489], [78.9743042, 9.67319489], [78.9743042, 9.67263889], [78.97402954, 9.67263889], [78.97402954, 9.67208099], [78.97374725, 9.6720829], [78.97374725, 9.67180538], [78.97345734, 9.67181015], [78.97345734, 9.6712513], [78.97319794, 9.6712513], [78.97319794, 9.67041683], [78.97292328, 9.6704216], [78.97292328, 9.66958141], [78.97264099, 9.66958332], [78.97264099, 9.66930485], [78.9723587, 9.66930962], [78.9723587, 9.66875076], [78.97207642, 9.66875076], [78.97207642, 9.66847134], [78.97180176, 9.66847324], [78.97180176, 9.66763878], [78.9715271, 9.66764069], [78.9715271, 9.66653061], [78.97180176, 9.66653061], [78.97180176, 9.66625118], [78.9715271, 9.66625118], [78.9715271, 9.66486073], [78.97125244, 9.66486073], [78.97125244, 9.66402912], [78.97097015, 9.66403103], [78.97097015, 9.66291046], [78.9706955, 9.66291714], [78.9706955, 9.66152859], [78.97097015, 9.66153145], [78.97097015, 9.66069031], [78.97125244, 9.66069412], [78.97125244, 9.65902805], [78.97097015, 9.65903091], [78.97097015, 9.65847015], [78.97125244, 9.65847206], [78.97125244, 9.65597153], [78.97097015, 9.65597153], [78.97097015, 9.65541553], [78.97068787, 9.65542126], [78.97068787, 9.65513992], [78.97039795, 9.65513992], [78.97039795, 9.65431118], [78.97013855, 9.65431118], [78.97013855, 9.65319157], [78.96986389, 9.65319443], [78.96986389, 9.65236187], [78.9695816, 9.65236187], [78.9695816, 9.65208435], [78.96930695, 9.65208435], [78.96930695, 9.65152836], [78.96901703, 9.65153027], [78.96901703, 9.65125179], [78.96875, 9.65125179], [78.96875, 9.65069103], [78.96847534, 9.6506958], [78.96847534, 9.65041637], [78.96819305, 9.65042019], [78.96819305, 9.65013981], [78.9679184, 9.65013981], [78.9679184, 9.64958382], [78.96763611, 9.64958382], [78.96763611, 9.6493063], [78.96736145, 9.64931011], [78.96736145, 9.64902973], [78.96708679, 9.64902973], [78.96708679, 9.64874935], [78.96679688, 9.64874935], [78.96679688, 9.64791107], [78.96652985, 9.64791775], [78.96652985, 9.64708328], [78.96624756, 9.64708328], [78.96624756, 9.64624882], [78.9659729, 9.64625168], [78.9659729, 9.6459713], [78.96541595, 9.6459713], [78.96541595, 9.64541721], [78.96485901, 9.64542198], [78.96485901, 9.6451416], [78.96459198, 9.6451416], [78.96459198, 9.64291859], [78.96430206, 9.64291859], [78.96430206, 9.64181042], [78.9640274, 9.64181042], [78.9640274, 9.64153099], [78.96375275, 9.64153099], [78.96375275, 9.64097118], [78.96347046, 9.64097309], [78.96347046, 9.64069462], [78.9631958, 9.64069462], [78.9631958, 9.6404171], [78.96290588, 9.64042187], [78.96290588, 9.64014053], [78.96263885, 9.64014053], [78.96263885, 9.64042187], [78.9623642, 9.6404171], [78.9623642, 9.64069462], [78.96263885, 9.64068985], [78.96263885, 9.64125061], [78.96235657, 9.64125061], [78.96235657, 9.64181042], [78.96208191, 9.6418047], [78.96208191, 9.64236069], [78.96125031, 9.64236069], [78.96125031, 9.64152908], [78.96151733, 9.64153099], [78.96151733, 9.64042187], [78.96125031, 9.64042187], [78.96125031, 9.63958073], [78.96152496, 9.63958263], [78.96152496, 9.63902664], [78.96180725, 9.63903141], [78.96180725, 9.63819027], [78.96208191, 9.63819504], [78.96208191, 9.63791656], [78.96180725, 9.63792133], [78.96180725, 9.63708019], [78.96152496, 9.63708305], [78.96152496, 9.63652897], [78.96125031, 9.63653088], [78.96125031, 9.63541889], [78.96098328, 9.63541889], [78.96098328, 9.6340313], [78.96069336, 9.6340313], [78.96069336, 9.63346958], [78.9604187, 9.63347244], [78.9604187, 9.63291645], [78.96013641, 9.6329298], [78.96013641, 9.63208199], [78.95986176, 9.63208199], [78.95986176, 9.63041592], [78.9595871, 9.63042068], [78.9595871, 9.62987137], [78.95929718, 9.62987137], [78.95929718, 9.62957954], [78.95903015, 9.62958431], [78.95903015, 9.62902832], [78.95874786, 9.62903023], [78.95874786, 9.62874985], [78.95845795, 9.62874985], [78.95845795, 9.62847042], [78.95819092, 9.62847233], [78.95819092, 9.62819386], [78.95791626, 9.62819386], [78.95791626, 9.62791634], [78.95735931, 9.62792015], [78.95735931, 9.62764168], [78.95707703, 9.62764168], [78.95707703, 9.62736034], [78.95680237, 9.62736225], [78.95680237, 9.62680626], [78.95652771, 9.62681103], [78.95652771, 9.62652969], [78.95625305, 9.62652969], [78.95625305, 9.62597179], [78.95597076, 9.62597179], [78.95597076, 9.6254158], [78.95571136, 9.62541962], [78.95571136, 9.62514019], [78.95539856, 9.62514019], [78.95539856, 9.62485981], [78.9548645, 9.62486172], [78.9548645, 9.6245842], [78.95458221, 9.6245842], [78.95458221, 9.62430573], [78.9540329, 9.62430954], [78.9540329, 9.62374115], [78.95319366, 9.62374973], [78.95319366, 9.62347221], [78.95263672, 9.62347221], [78.95263672, 9.62319565], [78.95236206, 9.62319565], [78.95236206, 9.62291527], [78.95207977, 9.62292004], [78.95207977, 9.62263966], [78.95181274, 9.62263966], [78.95181274, 9.62235928], [78.95153046, 9.62236214], [78.95153046, 9.62208366], [78.95097351, 9.62208366], [78.95097351, 9.62180614], [78.95014191, 9.62180996], [78.95014191, 9.62152958], [78.94957733, 9.62152958], [78.94957733, 9.6212492], [78.94930267, 9.6212492], [78.94930267, 9.62097359], [78.94902802, 9.62097359], [78.94902802, 9.62069321], [78.94875336, 9.62069321], [78.94875336, 9.62041759], [78.94790649, 9.62042046], [78.94790649, 9.62014198], [78.94735718, 9.62014198], [78.94735718, 9.61986065], [78.94708252, 9.61986065], [78.94708252, 9.61958313], [78.94625092, 9.61958313], [78.94625092, 9.61902714], [78.94568634, 9.61903191], [78.94568634, 9.61875057], [78.94541931, 9.61875057], [78.94541931, 9.61847115], [78.94513702, 9.61847115], [78.94513702, 9.61819458], [78.94458008, 9.61819458], [78.94458008, 9.61791706], [78.94431305, 9.61793137], [78.94431305, 9.6176424], [78.94403076, 9.6176424], [78.94403076, 9.61736107], [78.94374847, 9.61736107], [78.94374847, 9.61680508], [78.94345856, 9.61680984], [78.94345856, 9.61652946], [78.94319153, 9.61652946], [78.94319153, 9.61597061], [78.94235992, 9.61597347], [78.94235992, 9.61541653], [78.9420929, 9.61541939], [78.9420929, 9.61514091], [78.94180298, 9.61514091], [78.94180298, 9.61486053], [78.94152832, 9.61486053], [78.94152832, 9.61458302], [78.94125366, 9.61458302], [78.94125366, 9.61430454], [78.94097137, 9.61430931], [78.94097137, 9.61403084], [78.94071198, 9.61403084], [78.94071198, 9.61375141], [78.94041443, 9.61375141], [78.94041443, 9.61347294], [78.94013977, 9.61347294], [78.94013977, 9.61319542], [78.93985748, 9.61319542], [78.93985748, 9.61263943], [78.93958282, 9.61264133], [78.93958282, 9.61236095], [78.93930817, 9.61236095], [78.93930817, 9.61180687], [78.93902588, 9.61180687], [78.93902588, 9.61152744], [78.93875122, 9.61153126], [78.93875122, 9.61097145], [78.93846893, 9.61097336], [78.93846893, 9.61069489], [78.93791962, 9.61069489], [78.93791962, 9.61041737], [78.93763733, 9.61042118], [78.93763733, 9.6101408], [78.93708038, 9.6101408], [78.93708038, 9.60986137], [78.93653107, 9.60986137], [78.93653107, 9.6095829], [78.93624878, 9.6095829], [78.93624878, 9.60930443], [78.93596649, 9.6093092], [78.93596649, 9.60903072], [78.93569183, 9.60903072], [78.93569183, 9.6087389], [78.93541718, 9.6087513], [78.93541718, 9.60847282], [78.93514252, 9.60847282], [78.93514252, 9.6081953], [78.93486023, 9.6081953], [78.93486023, 9.60763836], [78.93457794, 9.60764122], [78.93457794, 9.60681057], [78.93428802, 9.60681057], [78.93428802, 9.60292053], [78.93402863, 9.60292053], [78.93402863, 9.60208035], [78.93374634, 9.60208416], [78.93374634, 9.60152817], [78.93347168, 9.60153008], [78.93347168, 9.60097027], [78.93319702, 9.60097218], [78.93319702, 9.60041809], [78.9329071, 9.60042], [78.9329071, 9.59986019], [78.93264008, 9.5998621], [78.93264008, 9.59930611], [78.93235779, 9.59930992], [78.93235779, 9.59902954], [78.93208313, 9.59902954], [78.93208313, 9.59847164], [78.93180847, 9.59847164], [78.93180847, 9.59819412], [78.93152618, 9.59819412], [78.93152618, 9.59764004], [78.93125153, 9.59764004], [78.93125153, 9.59707928], [78.93096924, 9.59708405], [78.93096924, 9.59652805], [78.93068695, 9.59652996], [78.93068695, 9.5959692], [78.93041992, 9.59597206], [78.93041992, 9.59541798], [78.93013763, 9.59542179], [78.93013763, 9.59514046], [78.92986298, 9.59514046], [78.92986298, 9.59458065], [78.92958069, 9.59458447], [78.92958069, 9.59402657], [78.92930603, 9.59403038], [78.92930603, 9.59264183], [78.92903137, 9.59264183], [78.92903137, 9.59181023], [78.92930603, 9.59181023], [78.92930603, 9.59013939], [78.92903137, 9.59013939], [78.92903137, 9.58958054], [78.92874908, 9.5895834], [78.92874908, 9.5890274], [78.92848206, 9.58902931], [78.92848206, 9.58847141], [78.92819214, 9.58847332], [78.92819214, 9.58791733], [78.92791748, 9.58791924], [78.92791748, 9.58708096], [78.92763519, 9.58708286], [78.92763519, 9.58625126], [78.92736053, 9.58625126], [78.92736053, 9.58319473], [78.92763519, 9.58319473], [78.92763519, 9.58152866], [78.92791748, 9.58153057], [78.92791748, 9.5809679], [78.92819214, 9.58097267], [78.92819214, 9.58041573], [78.92764282, 9.58042145], [78.92764282, 9.57958031], [78.92736053, 9.57958221], [78.92736053, 9.57930565], [78.92764282, 9.57931137], [78.92764282, 9.57903099], [78.92736053, 9.57903099], [78.92736053, 9.57875919], [78.92708588, 9.57875919], [78.92708588, 9.57847023], [78.92680359, 9.57847214], [78.92680359, 9.57791615], [78.92652893, 9.57792091], [78.92652893, 9.57681084], [78.92624664, 9.57681084], [78.92624664, 9.57625008], [78.92597198, 9.57625008], [78.92597198, 9.57514], [78.92569733, 9.57514], [78.92569733, 9.57431126], [78.92542267, 9.57431126], [78.92542267, 9.57402992], [78.92514038, 9.57402992], [78.92514038, 9.57374954], [78.92485809, 9.57374954], [78.92485809, 9.57347202], [78.92458344, 9.57347202], [78.92458344, 9.57291794], [78.92430878, 9.57291985], [78.92430878, 9.57236195], [78.92402649, 9.57236195], [78.92402649, 9.57013988], [78.92375183, 9.57014179], [78.92375183, 9.56902981], [78.92402649, 9.56902981], [78.92402649, 9.56847095], [78.92430878, 9.56847095], [78.92430878, 9.56819344], [78.92402649, 9.56819344], [78.92402649, 9.56791782], [78.92375183, 9.56791973], [78.92375183, 9.56708145], [78.92346954, 9.56708336], [78.92346954, 9.56680489], [78.92318726, 9.56681919], [78.92318726, 9.56597137], [78.92292023, 9.56597137], [78.92292023, 9.56541729], [78.92263794, 9.56542015], [78.92263794, 9.56514168], [78.92234802, 9.56514168], [78.92234802, 9.56431198], [78.92208099, 9.56431198], [78.92208099, 9.56346035], [78.92236328, 9.56347084], [78.92236328, 9.56236076], [78.92263794, 9.56236076], [78.92263794, 9.56097126], [78.92236328, 9.56097317], [78.92236328, 9.55986118], [78.92263794, 9.55986118], [78.92263794, 9.55958271], [78.92236328, 9.55958271], [78.92236328, 9.55875111], [78.92263794, 9.55875111], [78.92263794, 9.55847263], [78.92236328, 9.55847263], [78.92236328, 9.55819511], [78.92208099, 9.55819511], [78.92208099, 9.55708313], [78.92180634, 9.55708313], [78.92180634, 9.55652905], [78.92151642, 9.55653095], [78.92151642, 9.5556879], [78.92124939, 9.55569458], [78.92124939, 9.55513859], [78.92151642, 9.55514145], [78.92151642, 9.55486012], [78.92124939, 9.55486012], [78.92124939, 9.55347157], [78.92097473, 9.55347157], [78.92097473, 9.55291557], [78.92069244, 9.5529213], [78.92069244, 9.5506897], [78.92041779, 9.55069447], [78.92041779, 9.55013847], [78.92014313, 9.55014038], [78.92014313, 9.54846096], [78.91986084, 9.5484724], [78.91986084, 9.54597187], [78.91958618, 9.54597187], [78.91958618, 9.54514027], [78.91928864, 9.54514027], [78.91928864, 9.54430962], [78.91902924, 9.54430962], [78.91902924, 9.54292011], [78.91874695, 9.54292011], [78.91874695, 9.54069138], [78.91902924, 9.54069328], [78.91902924, 9.53986073], [78.91874695, 9.53986073], [78.91874695, 9.53958321], [78.91847229, 9.53958321], [78.91847229, 9.53652668], [78.91874695, 9.53652668], [78.91874695, 9.5359726], [78.91902924, 9.5359726], [78.91902924, 9.53569508], [78.91930389, 9.53569508], [78.91930389, 9.53486061], [78.91986084, 9.53486061], [78.91986084, 9.53458309], [78.9201355, 9.53458309], [78.9201355, 9.53430462], [78.92041779, 9.53431034], [78.92041779, 9.53403091], [78.92069244, 9.53403091], [78.92069244, 9.53347969], [78.92124939, 9.53347969], [78.92124939, 9.53318977], [78.92152405, 9.53319454], [78.92152405, 9.53263855], [78.92180634, 9.53264141], [78.92180634, 9.53236103], [78.92208099, 9.53236103], [78.92208099, 9.53208256], [78.92236328, 9.53208256], [78.92236328, 9.53097343], [78.92263794, 9.53097343], [78.92263794, 9.52986145], [78.92236328, 9.52986145], [78.92236328, 9.52958298], [78.92208099, 9.52958298], [78.92208099, 9.52930546], [78.92180634, 9.52930927], [78.92180634, 9.52902889], [78.92208099, 9.52902889], [78.92208099, 9.52847004], [78.92236328, 9.5284729], [78.92236328, 9.52735996], [78.92208099, 9.52735996], [78.92208099, 9.52680683], [78.92180634, 9.52681065], [78.92180634, 9.52597046], [78.92152405, 9.52597237], [78.92152405, 9.5243063], [78.92124939, 9.52431107], [78.92124939, 9.52403069], [78.9209671, 9.52403069], [78.9209671, 9.52375031], [78.92069244, 9.52375031], [78.92069244, 9.52291584], [78.92041779, 9.52292061], [78.92041779, 9.52264023], [78.92014313, 9.52264023], [78.92014313, 9.52235985], [78.91986084, 9.52235985], [78.91986084, 9.52180576], [78.91960144, 9.52181053], [78.91960144, 9.52153969], [78.91928864, 9.52153969], [78.91928864, 9.52097034], [78.91902924, 9.52097225], [78.91902924, 9.51902771], [78.91874695, 9.51902962], [78.91874695, 9.51848125], [78.91847229, 9.51848125], [78.91847229, 9.51819134], [78.91819763, 9.5181942], [78.91819763, 9.51791573], [78.91707611, 9.51791954], [78.91707611, 9.51764202], [78.91680908, 9.51764202], [78.91680908, 9.51681042], [78.91707611, 9.51681042], [78.91707611, 9.51653004], [78.9173584, 9.51653004], [78.9173584, 9.5156889], [78.91708374, 9.51569366], [78.91708374, 9.51458359], [78.91680908, 9.51458359], [78.91680908, 9.51430607], [78.91654205, 9.51428986], [78.91652679, 9.51347446], [78.91625214, 9.51347446], [78.91625214, 9.51236057], [78.91596985, 9.51236057], [78.91596985, 9.51013947], [78.91570282, 9.51014233], [78.91570282, 9.50958061], [78.9154129, 9.50958347], [78.9154129, 9.509305], [78.91513824, 9.50930977], [78.91513824, 9.50875092], [78.91485596, 9.50875092], [78.91485596, 9.50542068], [78.91513824, 9.50542068], [78.91513824, 9.50514126], [78.91570282, 9.50514126], [78.91570282, 9.50457954], [78.9154129, 9.50458336], [78.9154129, 9.50430679], [78.91485596, 9.50431156], [78.91485596, 9.50264072], [78.9145813, 9.50264072], [78.9145813, 9.50153065], [78.91430664, 9.50153065], [78.91430664, 9.50069046], [78.9145813, 9.50069523], [78.9145813, 9.5004158], [78.91486359, 9.5004158], [78.91486359, 9.50013828], [78.91513824, 9.50014114], [78.91513824, 9.49874973], [78.91485596, 9.49874973], [78.91485596, 9.49625015], [78.9145813, 9.49625015], [78.9145813, 9.49569416], [78.91486359, 9.49569416], [78.91486359, 9.49402809], [78.9145813, 9.49403], [78.9145813, 9.49347019], [78.91430664, 9.4934721], [78.91430664, 9.49319363], [78.91402435, 9.49319363], [78.91402435, 9.49263763], [78.91374969, 9.49263954], [78.91374969, 9.49208164], [78.91347504, 9.49208355], [78.91347504, 9.49152756], [78.91179657, 9.49154186], [78.91179657, 9.49125195], [78.91124725, 9.49125195], [78.91124725, 9.49097157], [78.90847015, 9.49097157], [78.90847015, 9.49125195], [78.90763855, 9.49125195], [78.90763855, 9.49154186], [78.90680695, 9.49154186], [78.90680695, 9.49180984], [78.90625, 9.49180603], [78.90625, 9.49208355], [78.90569305, 9.49208355], [78.90569305, 9.49236202], [78.9054184, 9.49236202], [78.9054184, 9.49263954], [78.90513611, 9.49263954], [78.90513611, 9.49291992], [78.90486145, 9.49291801], [78.90486145, 9.49319363], [78.9034729, 9.49319363], [78.9034729, 9.49291801], [78.90291595, 9.49291992], [78.90291595, 9.49263954], [78.90207672, 9.49263954], [78.90207672, 9.49236202], [78.9015274, 9.49236202], [78.9015274, 9.49208355], [78.9006958, 9.49208355], [78.9006958, 9.49152756], [78.90040588, 9.49154186], [78.90040588, 9.49097157], [78.90013885, 9.49097157], [78.90013885, 9.49041557], [78.89958191, 9.49042034], [78.89958191, 9.49013996], [78.89846802, 9.49013996], [78.89846802, 9.48903179], [78.8981781, 9.48903179], [78.8981781, 9.48014069], [78.89846802, 9.48014069], [78.89846802, 9.47819042], [78.89875031, 9.47819519], [78.89875031, 9.47680473], [78.89901733, 9.47681141], [78.89901733, 9.47514057], [78.89930725, 9.47514057], [78.89930725, 9.47375107], [78.89958191, 9.47375107], [78.89958191, 9.47235966], [78.8998642, 9.47235966], [78.8998642, 9.47124958], [78.90013885, 9.47124958], [78.90013885, 9.47043037], [78.90040588, 9.47043037], [78.90040588, 9.46986008], [78.9006958, 9.46986008], [78.9006958, 9.46902847], [78.90097046, 9.46903133], [78.90097046, 9.46819019], [78.90125275, 9.46819401], [78.90125275, 9.46763802], [78.90154266, 9.46763992], [78.90154266, 9.46681118], [78.90180206, 9.46681118], [78.90180206, 9.46625042], [78.90208435, 9.46625042], [78.90207672, 9.46569157], [78.90235901, 9.46569443], [78.90235901, 9.46513844], [78.9026413, 9.46514034], [78.9026413, 9.46458244], [78.90291595, 9.46458435], [78.90291595, 9.46402836], [78.90319061, 9.46403027], [78.90319824, 9.46346855], [78.9034729, 9.46347237], [78.9034729, 9.4631958], [78.90374756, 9.4631958], [78.90374756, 9.46263981], [78.90402985, 9.46263981], [78.90402985, 9.46208382], [78.9043045, 9.46208382], [78.9043045, 9.46152782], [78.90460205, 9.46152973], [78.90460205, 9.46097088], [78.90486145, 9.46097088], [78.90486145, 9.46041775], [78.90513611, 9.46041965], [78.90513611, 9.45985889], [78.9054184, 9.45986176], [78.9054184, 9.45930481], [78.90569305, 9.45930958], [78.90569305, 9.45903015], [78.90598297, 9.45903015], [78.90598297, 9.4584713], [78.90625, 9.4584713], [78.90625, 9.45791531], [78.90651703, 9.45792198], [78.90651703, 9.45736122], [78.90680695, 9.45736122], [78.90680695, 9.45680523], [78.9070816, 9.4568119], [78.9070816, 9.45624924], [78.90736389, 9.45624924], [78.90734863, 9.45569134], [78.90763855, 9.45569515], [78.90763855, 9.45513916], [78.90791321, 9.45514107], [78.90791321, 9.45458126], [78.9081955, 9.45458317], [78.9081955, 9.4543047], [78.90847015, 9.45431042], [78.90847015, 9.45375061], [78.90875244, 9.45375061], [78.90875244, 9.4531908], [78.9090271, 9.45319462], [78.9090271, 9.45263863], [78.90930176, 9.45264053], [78.90930176, 9.45206928], [78.90958405, 9.45208263], [78.90958405, 9.45152664], [78.9098587, 9.45153141], [78.9098587, 9.45097065], [78.91014099, 9.45097256], [78.91014099, 9.45041656], [78.91040802, 9.45042133], [78.91040802, 9.45014095], [78.91069794, 9.45014095], [78.91069794, 9.44958019], [78.9109726, 9.44958305], [78.9109726, 9.44930458], [78.91124725, 9.44930458], [78.91124725, 9.44874763], [78.91152954, 9.44875145], [78.91152954, 9.44818974], [78.9118042, 9.44819546], [78.9118042, 9.44791698], [78.91208649, 9.44791889], [78.91208649, 9.44736004], [78.91236115, 9.44736004], [78.91236115, 9.44680691], [78.9126358, 9.44681072], [78.9126358, 9.44626045], [78.91291809, 9.44626045], [78.91291809, 9.44569016], [78.91319275, 9.44569397], [78.91319275, 9.44513798], [78.91348267, 9.44514275], [78.91348267, 9.44458008], [78.91374969, 9.44458199], [78.91374969, 9.44430637], [78.91401672, 9.44431114], [78.91401672, 9.44375038], [78.91430664, 9.44375038], [78.91430664, 9.44319439], [78.9145813, 9.44320107], [78.9145813, 9.44292068], [78.91485596, 9.44292068], [78.91485596, 9.44235992], [78.91513824, 9.44235992], [78.91513824, 9.44180584], [78.9154129, 9.44181061], [78.9154129, 9.44153023], [78.91570282, 9.44153023], [78.91570282, 9.44097042], [78.91596985, 9.44097233], [78.91596985, 9.44041634], [78.91625214, 9.4404211], [78.91625214, 9.44013119], [78.91652679, 9.44013786], [78.91652679, 9.43958378], [78.91680908, 9.43958378], [78.91680908, 9.43902779], [78.91707611, 9.43902969], [78.91707611, 9.43875027], [78.9173584, 9.43875027], [78.9173584, 9.43819427], [78.91764069, 9.43819427], [78.91764069, 9.4379158], [78.91792297, 9.43791962], [78.91792297, 9.43735981], [78.91819763, 9.43735981], [78.91819763, 9.43680573], [78.91847229, 9.43680954], [78.91847229, 9.43653011], [78.91874695, 9.43653011], [78.91874695, 9.43596935], [78.91902924, 9.43597221], [78.91902924, 9.43541622], [78.91928864, 9.43542004], [78.91928864, 9.43513966], [78.91960144, 9.43513966], [78.91960144, 9.4345789], [78.91986084, 9.43458366], [78.91986084, 9.43402767], [78.92014313, 9.43402958], [78.92014313, 9.4337492], [78.92041779, 9.4337492], [78.92041779, 9.43319321], [78.92069244, 9.43319321], [78.92069244, 9.43236065], [78.92124939, 9.43236065], [78.92124939, 9.43180466], [78.92151642, 9.43181038], [78.92151642, 9.43153191], [78.92180634, 9.43153191], [78.92180634, 9.43097115], [78.92208099, 9.43097115], [78.92208099, 9.43069458], [78.92236328, 9.43069458], [78.92236328, 9.43013859], [78.92263794, 9.4301424], [78.92263794, 9.42986107], [78.92292023, 9.42986107], [78.92292023, 9.42930508], [78.92318726, 9.42930984], [78.92318726, 9.42875099], [78.92346954, 9.42875099], [78.92346954, 9.42847061], [78.92375183, 9.42847347], [78.92375183, 9.42791653], [78.92402649, 9.42791939], [78.92402649, 9.42764091], [78.92430878, 9.42764091], [78.92430878, 9.42708111], [78.92458344, 9.42708302], [78.92458344, 9.42680454], [78.92485809, 9.42681026], [78.92485809, 9.42625141], [78.92514038, 9.42624855], [78.92514038, 9.4256897], [78.92541504, 9.42569542], [78.92541504, 9.42541695], [78.92569733, 9.42542171], [78.92569733, 9.42486095], [78.92597198, 9.42486095], [78.92597198, 9.42458344], [78.92624664, 9.42458344], [78.92624664, 9.42402744], [78.92652893, 9.42403126], [78.92652893, 9.42375088], [78.92679596, 9.42375088], [78.92679596, 9.42319012], [78.92708588, 9.42319489], [78.92708588, 9.42263889], [78.92736053, 9.4226408], [78.92736053, 9.42236137], [78.92763519, 9.42236137], [78.92763519, 9.42180538], [78.92791748, 9.4218092], [78.92791748, 9.42153072], [78.92819214, 9.42153072], [78.92819214, 9.42096996], [78.92847443, 9.42097282], [78.92847443, 9.4206953], [78.92874908, 9.4206953], [78.92874908, 9.42041683], [78.92903137, 9.42042065], [78.92903137, 9.41986275], [78.92930603, 9.41986275], [78.92930603, 9.41958046], [78.92958069, 9.41958237], [78.92958069, 9.41930676], [78.92986298, 9.41932011], [78.92986298, 9.4187479], [78.93013763, 9.41874981], [78.93013763, 9.41847229], [78.93041992, 9.41847229], [78.93041992, 9.41819382], [78.93069458, 9.41819382], [78.93069458, 9.41763783], [78.93096924, 9.41764069], [78.93096924, 9.41736031], [78.93125153, 9.41736031], [78.93125153, 9.41708374], [78.93152618, 9.41708374], [78.93152618, 9.41652775], [78.93180847, 9.41653061], [78.93180847, 9.41625023], [78.93208313, 9.41625023], [78.93208313, 9.41597176], [78.93235779, 9.41597176], [78.93235779, 9.41541576], [78.93264008, 9.41542053], [78.93264008, 9.41514015], [78.9329071, 9.41514015], [78.9329071, 9.41485977], [78.93319702, 9.41485977], [78.93319702, 9.41430569], [78.93347168, 9.41431141], [78.93347168, 9.41403008], [78.93374634, 9.41403008], [78.93374634, 9.41374969], [78.93402863, 9.41374969], [78.93402863, 9.4131918], [78.93430328, 9.4131937], [78.93430328, 9.41291809], [78.93457794, 9.41292], [78.93457794, 9.41263962], [78.93486023, 9.41263962], [78.93486023, 9.41207886], [78.93514252, 9.41208363], [78.93514252, 9.41180611], [78.93541718, 9.41181087], [78.93541718, 9.41125202], [78.93569183, 9.41125202], [78.93569183, 9.41097164], [78.93597412, 9.41097164], [78.93597412, 9.41069412], [78.93624878, 9.41069412], [78.93624878, 9.41041565], [78.93653107, 9.41042042], [78.93653107, 9.40985966], [78.93680573, 9.40985966], [78.93680573, 9.40958405], [78.93708038, 9.40958405], [78.93708038, 9.40930557], [78.93736267, 9.40931034], [78.93736267, 9.40902996], [78.93763733, 9.40902996], [78.93763733, 9.4084692], [78.93791962, 9.40847206], [78.93791962, 9.40819359], [78.93819427, 9.40819359], [78.93819427, 9.40791798], [78.93846893, 9.40792179], [78.93846893, 9.40736198], [78.93875122, 9.40736198], [78.93875122, 9.40708447], [78.93902588, 9.40709019], [78.93902588, 9.4068079], [78.93930817, 9.4068079], [78.93930817, 9.40625191], [78.93958282, 9.40625191], [78.93958282, 9.40597057], [78.93985748, 9.40597057], [78.93985748, 9.40569305], [78.94041443, 9.40569305], [78.94041443, 9.4054184], [78.94071198, 9.4054203], [78.94071198, 9.40514183], [78.94124603, 9.40514183], [78.94124603, 9.40486145], [78.94180298, 9.40486145], [78.94180298, 9.40458298], [78.94208527, 9.40458298], [78.94208527, 9.40402699], [78.94235992, 9.40402985], [78.94235992, 9.40347099], [78.94264221, 9.40347099], [78.94264221, 9.40291691], [78.94291687, 9.40291977], [78.94291687, 9.40236092], [78.94319153, 9.40236092], [78.94319153, 9.40180492], [78.94345856, 9.40180969], [78.94345856, 9.40152931], [78.94374847, 9.40152931], [78.94374847, 9.40125084], [78.94403076, 9.40125084], [78.94403076, 9.40096188], [78.94430542, 9.40097332], [78.94430542, 9.40069485], [78.94458008, 9.40069485], [78.94458008, 9.40041733], [78.94486237, 9.40041924], [78.94486237, 9.40014076], [78.94513702, 9.40014076], [78.94513702, 9.39986134], [78.94541931, 9.39986134], [78.94541931, 9.39958286], [78.94569397, 9.39958286], [78.94569397, 9.39902687], [78.94596863, 9.39903069], [78.94596863, 9.39875126], [78.94625092, 9.39875126], [78.94625092, 9.39847088], [78.94652557, 9.39847088], [78.94652557, 9.39819527], [78.94680786, 9.39819527], [78.94680786, 9.39791679], [78.94708252, 9.39792061], [78.94708252, 9.39764118], [78.94735718, 9.39764118], [78.94735718, 9.3973608], [78.94763947, 9.3973608], [78.94763947, 9.39708328], [78.94791412, 9.39708328], [78.94791412, 9.39680481], [78.94819641, 9.39681244], [78.94819641, 9.39653111], [78.94847107, 9.39653111], [78.94847107, 9.39625072], [78.94875336, 9.39625072], [78.94875336, 9.3959713], [78.94902802, 9.39597321], [78.94902802, 9.39569473], [78.94930267, 9.39569473], [78.94930267, 9.39541721], [78.94957733, 9.39542103], [78.94957733, 9.39515018], [78.94985962, 9.39515018], [78.94985962, 9.39457989], [78.95014191, 9.39458466], [78.95014191, 9.39430428], [78.95041656, 9.39431095], [78.95041656, 9.39403057], [78.95069122, 9.39403057], [78.95069122, 9.39375114], [78.95097351, 9.39375114], [78.95096588, 9.3934679], [78.95124817, 9.39347267], [78.95124817, 9.39319515], [78.95153046, 9.39319515], [78.95153046, 9.39291573], [78.95181274, 9.39292145], [78.95181274, 9.39264107], [78.95207977, 9.39264107], [78.95207977, 9.39235973], [78.95236206, 9.39235973], [78.95236206, 9.39208221], [78.95265198, 9.39208889], [78.95265198, 9.39181137], [78.95291901, 9.39181137], [78.95291901, 9.39153099], [78.95318604, 9.39153099], [78.95318604, 9.39124966], [78.95347595, 9.39124966], [78.95347595, 9.39097023], [78.95375061, 9.39097214], [78.95375061, 9.39069366], [78.95402527, 9.39069366], [78.95402527, 9.39013767], [78.95430756, 9.39014053], [78.95430756, 9.38986015], [78.95458221, 9.38986015], [78.95458221, 9.38958359], [78.9548645, 9.38958359], [78.9548645, 9.38930416], [78.95513916, 9.38931084], [78.95513916, 9.38902092], [78.95541382, 9.3890276], [78.95541382, 9.38875008], [78.95571136, 9.38875008], [78.95571136, 9.3884697], [78.95597076, 9.3884716], [78.95597076, 9.38819408], [78.95625305, 9.38819408], [78.95625305, 9.38791561], [78.95652771, 9.38792133], [78.95652771, 9.38764], [78.95680237, 9.38764], [78.95680237, 9.38735962], [78.95708466, 9.38736153], [78.95708466, 9.38708401], [78.95735931, 9.38708401], [78.95735931, 9.38680553], [78.9576416, 9.38681126], [78.9576416, 9.38652992], [78.95791626, 9.38652992], [78.95791626, 9.38624954], [78.95819092, 9.38624954], [78.95819092, 9.38596058], [78.95847321, 9.38597202], [78.95847321, 9.38569355], [78.95874786, 9.38569355], [78.95874786, 9.38541603], [78.95903015, 9.38541985], [78.95903015, 9.38514042], [78.95929718, 9.38514042], [78.95929718, 9.38486195], [78.9595871, 9.38486195], [78.9595871, 9.38458443], [78.95986176, 9.38458443], [78.95986176, 9.38430595], [78.96013641, 9.38431263], [78.96013641, 9.38403034], [78.9604187, 9.38403034], [78.9604187, 9.38346863], [78.96069336, 9.38347244], [78.96069336, 9.38319397], [78.96097565, 9.38319397], [78.96097565, 9.38291645], [78.96125031, 9.38292027], [78.96125031, 9.38264179], [78.96151733, 9.38264179], [78.96151733, 9.38236046], [78.96180725, 9.38236237], [78.96180725, 9.38208389], [78.96208191, 9.38208389], [78.96208191, 9.38180637], [78.96235657, 9.38181019], [78.96235657, 9.38152981], [78.96263885, 9.38152981], [78.96263885, 9.38125038], [78.96291351, 9.38125038], [78.96290588, 9.38097191], [78.9631958, 9.38097191], [78.9631958, 9.38069344], [78.96347046, 9.38069344], [78.96347046, 9.38041782], [78.96375275, 9.38041973], [78.96375275, 9.38014889], [78.9640274, 9.38014889], [78.9640274, 9.37986183], [78.96430206, 9.37986183], [78.96430206, 9.37958431], [78.96458435, 9.37958431], [78.96458435, 9.37930489], [78.96485901, 9.37930965], [78.96485901, 9.37903023], [78.9651413, 9.37903023], [78.9651413, 9.37874889], [78.96541595, 9.37874889], [78.96541595, 9.37819576], [78.96569061, 9.37819576], [78.96569824, 9.37791538], [78.9659729, 9.37792015], [78.9659729, 9.37764168], [78.96624756, 9.37764168], [78.96624756, 9.37708092], [78.96652985, 9.37708282], [78.96652985, 9.37680531], [78.96679688, 9.37681198], [78.96679688, 9.3765316], [78.96708679, 9.3765316], [78.96708679, 9.37597084], [78.96736145, 9.37597084], [78.96736145, 9.37569523], [78.96763611, 9.37569523], [78.96763611, 9.37541676], [78.9679184, 9.37541962], [78.9679184, 9.37486076], [78.96819305, 9.37486076], [78.96819305, 9.37458134], [78.96847534, 9.37458324], [78.96847534, 9.37430477], [78.96875, 9.37430954], [78.96875, 9.37401962], [78.96902466, 9.37402916], [78.96902466, 9.37374878], [78.96930695, 9.37375069], [78.96930695, 9.37347126], [78.9695816, 9.37347317], [78.9695816, 9.37319469], [78.96986389, 9.37319469], [78.96986389, 9.37291718], [78.97013855, 9.37292194], [78.97013855, 9.37264061], [78.97039795, 9.37264061], [78.97039795, 9.37236118], [78.9706955, 9.37236118], [78.9706955, 9.37208271], [78.97097015, 9.37208271], [78.97097015, 9.37180519], [78.97125244, 9.37181187], [78.97125244, 9.37153053], [78.9715271, 9.37153053], [78.9715271, 9.37125111], [78.97180176, 9.37125111], [78.97180176, 9.37097263], [78.97207642, 9.37098026], [78.97207642, 9.37069035], [78.9723587, 9.37069511], [78.9723587, 9.37041664], [78.97264099, 9.37042141], [78.97264099, 9.37014103], [78.97292328, 9.37014103], [78.97292328, 9.36986065], [78.97319794, 9.36986065], [78.97319794, 9.36958313], [78.9734726, 9.36958313], [78.9734726, 9.36930466], [78.97374725, 9.36931133], [78.97374725, 9.36903095], [78.97402954, 9.36903095], [78.97402954, 9.36875057], [78.97429657, 9.36875057], [78.97429657, 9.36847019], [78.97458649, 9.36847305], [78.97458649, 9.36819458], [78.97486115, 9.36819458], [78.97486115, 9.36791706], [78.9751358, 9.36792088], [78.9751358, 9.36764145], [78.97541809, 9.36764145], [78.97541809, 9.36736107], [78.97569275, 9.36736107], [78.97569275, 9.36708164], [78.97597504, 9.36708164], [78.97597504, 9.36680698], [78.97624969, 9.36680889], [78.97624969, 9.36653137], [78.97653198, 9.36653137], [78.97653198, 9.36625099], [78.9768219, 9.36625099], [78.9768219, 9.36596966], [78.9770813, 9.36597347], [78.9770813, 9.36569405], [78.97736359, 9.36569405], [78.97736359, 9.36541557], [78.97763824, 9.3654213], [78.97763824, 9.36514091], [78.97820282, 9.36514091], [78.97820282, 9.364851], [78.97846985, 9.3648634], [78.97846985, 9.36458206], [78.97875214, 9.36458206], [78.97875214, 9.3643074], [78.97902679, 9.36431122], [78.97902679, 9.36403084], [78.97930908, 9.36403084], [78.97930908, 9.36375046], [78.97958374, 9.36375046], [78.97959137, 9.36347008], [78.9798584, 9.36347198], [78.9798584, 9.36319447], [78.98014069, 9.36319447], [78.98014069, 9.36291599], [78.98069763, 9.36291885], [78.98069763, 9.36264038], [78.98097229, 9.36264038], [78.98097229, 9.36236], [78.98124695, 9.36236], [78.98124695, 9.36208439], [78.98152924, 9.36208439], [78.98152924, 9.36180592], [78.98179626, 9.36181068], [78.98179626, 9.36153126], [78.98208618, 9.36153126], [78.98208618, 9.36124992], [78.98236084, 9.36124992], [78.98236084, 9.36096954], [78.9826355, 9.3609724], [78.9826355, 9.36069393], [78.98319244, 9.36069393], [78.98319244, 9.36041641], [78.9834671, 9.36042118], [78.9834671, 9.36013985], [78.98374939, 9.36013985], [78.98374939, 9.35986042], [78.98402405, 9.35986233], [78.98402405, 9.35958195], [78.98430634, 9.35958195], [78.98430634, 9.35930634], [78.98458099, 9.3593111], [78.98458099, 9.35903931], [78.98486328, 9.35903931], [78.98486328, 9.35875034], [78.98513794, 9.35875034], [78.98513794, 9.35819435], [78.98542023, 9.35819435], [78.98542023, 9.35791588], [78.98568726, 9.35791969], [78.98568726, 9.35764027], [78.98596954, 9.35764027], [78.98596954, 9.35736179], [78.98625183, 9.35736179], [78.98625183, 9.35707855], [78.98652649, 9.35708427], [78.98652649, 9.3568058], [78.98680878, 9.35680962], [78.98680878, 9.35653019], [78.98707581, 9.35653019], [78.98707581, 9.35624981], [78.98735809, 9.35624981], [78.98735809, 9.35597229], [78.98764038, 9.35598087], [78.98764038, 9.35542011], [78.98792267, 9.35542011], [78.98792267, 9.35513973], [78.98819733, 9.35513973], [78.98819733, 9.35485935], [78.98847198, 9.35486221], [78.98847198, 9.35458374], [78.98874664, 9.35458374], [78.98874664, 9.35430622], [78.98902893, 9.35431004], [78.98902893, 9.35402966], [78.98929596, 9.35402966], [78.98929596, 9.35375023], [78.98986053, 9.35375023], [78.98986053, 9.3534708], [78.99013519, 9.3534708], [78.99013519, 9.35319328], [78.99041748, 9.35319328], [78.99041748, 9.35291767], [78.99069214, 9.35291767], [78.99069214, 9.35264015], [78.99124908, 9.35264015], [78.99124908, 9.35236168], [78.99153137, 9.35236168], [78.99153137, 9.35208321], [78.99180603, 9.35208321], [78.99180603, 9.35180473], [78.99208069, 9.35181046], [78.99208069, 9.35153198], [78.99263763, 9.35153198], [78.99263763, 9.3512516], [78.99291992, 9.3512516], [78.99291992, 9.35097122], [78.99319458, 9.35097122], [78.99319458, 9.35069561], [78.99346924, 9.35069561], [78.99346924, 9.35041714], [78.99402618, 9.35042191], [78.99402618, 9.35014153], [78.99430847, 9.35014153], [78.99430847, 9.3498497], [78.99458313, 9.34986115], [78.99458313, 9.34958267], [78.99485779, 9.34958267], [78.99485779, 9.34930515], [78.9954071, 9.34930992], [78.9954071, 9.34902859], [78.99597168, 9.34902859], [78.99597168, 9.34875107], [78.99624634, 9.34875107], [78.99624634, 9.34847069], [78.99652863, 9.3484726], [78.99652863, 9.3479166], [78.99680328, 9.34792042], [78.99680328, 9.34764099], [78.99736023, 9.34764099], [78.99736023, 9.34736061], [78.99764252, 9.34736061], [78.99764252, 9.34708309], [78.99791718, 9.34708309], [78.99791718, 9.34680462], [78.99819183, 9.34681034], [78.99819183, 9.34653187], [78.99846649, 9.34653187], [78.99846649, 9.34625053], [78.99874878, 9.34625053], [78.99874878, 9.34597111], [78.99930573, 9.34597301], [78.99930573, 9.34569454], [78.99958038, 9.34569454], [78.99958038, 9.34541702], [78.99986267, 9.34542179], [78.99986267, 9.34514141], [79.00125122, 9.34514141], [79.00125122, 9.34486103], [79.00152588, 9.34486103], [79.00152588, 9.34458256], [79.00180817, 9.34458256], [79.00180817, 9.34430695], [79.00208282, 9.34431171], [79.00208282, 9.34403992], [79.00263977, 9.34403992], [79.00263977, 9.34347057], [79.00291443, 9.34347343], [79.00291443, 9.34319496], [79.00319672, 9.34319496], [79.00319672, 9.34291744], [79.00347137, 9.34292126], [79.00347137, 9.34264088], [79.00376129, 9.34264088], [79.00376129, 9.34236145], [79.00402832, 9.34236145], [79.00402832, 9.34208298], [79.00430298, 9.34208298], [79.00430298, 9.34180546], [79.0045929, 9.34180927], [79.0045929, 9.34152889], [79.00514221, 9.34152889], [79.00514221, 9.34125137], [79.00541687, 9.34125137], [79.00541687, 9.3409729], [79.00597382, 9.3409729], [79.00597382, 9.34069538], [79.00624847, 9.34069538], [79.00624847, 9.34041691], [79.00708008, 9.34042072], [79.00708008, 9.3401413], [79.00736237, 9.3401413], [79.00736237, 9.33985996], [79.00763702, 9.33985996], [79.00763702, 9.33930683], [79.00818634, 9.33931065], [79.00818634, 9.33903122], [79.00846863, 9.33903122], [79.00846863, 9.33875275], [79.0090332, 9.33875275], [79.0090332, 9.33847046], [79.00930786, 9.33847332], [79.00930786, 9.33819389], [79.00958252, 9.33819389], [79.00958252, 9.33791637], [79.00986481, 9.33791637], [79.00986481, 9.3376379], [79.01041412, 9.3376379], [79.01040649, 9.33736038], [79.01069641, 9.33736038], [79.01069641, 9.33708191], [79.01097107, 9.33708191], [79.01097107, 9.3368063], [79.01152802, 9.33681107], [79.01152802, 9.33653069], [79.01180267, 9.33653069], [79.01180267, 9.33625031], [79.01235962, 9.33625031], [79.01235962, 9.33597183], [79.01264191, 9.33597183], [79.01264191, 9.33569431], [79.01291656, 9.33569431], [79.01291656, 9.33541584], [79.01319122, 9.33542061], [79.01319122, 9.33514023], [79.01346588, 9.33514023], [79.01346588, 9.33487129], [79.01374817, 9.33487129], [79.01374817, 9.33458042], [79.01403046, 9.33458424], [79.01403046, 9.33430576], [79.01431274, 9.33431053], [79.01431274, 9.33403015], [79.01457977, 9.33403015], [79.01457977, 9.33374977], [79.01486206, 9.33374977], [79.01486206, 9.33347034], [79.01513672, 9.33347225], [79.01513672, 9.33319378], [79.01541901, 9.33319378], [79.01541901, 9.33291626], [79.01599121, 9.33292103], [79.01599121, 9.33263969], [79.01625061, 9.33263969], [79.01625061, 9.33236027], [79.01652527, 9.33236217], [79.01652527, 9.3320837], [79.01680756, 9.3320837], [79.01680756, 9.33180618], [79.01735687, 9.33181095], [79.01735687, 9.33152962], [79.01763916, 9.33152962], [79.01763916, 9.33125019], [79.01791382, 9.33125019], [79.01790619, 9.33096981], [79.01847076, 9.33097172], [79.01847076, 9.3306942], [79.01875305, 9.3306942], [79.01875305, 9.33041573], [79.01902771, 9.33041954], [79.01902771, 9.33014011], [79.01957703, 9.33014011], [79.01957703, 9.32985973], [79.01930237, 9.32985973], [79.01930237, 9.32958412], [79.01902771, 9.32958412], [79.01902771, 9.32930565], [79.02041626, 9.32930565], [79.02041626, 9.32958412], [79.02097321, 9.32958412], [79.02097321, 9.32930565], [79.02124786, 9.32931042], [79.02124786, 9.32846928], [79.02153015, 9.32847214], [79.02153015, 9.32763672], [79.02179718, 9.32763958], [79.02179718, 9.3273592], [79.02236176, 9.32736206], [79.02236176, 9.32708359], [79.02263641, 9.32708359], [79.02263641, 9.32680607], [79.02319336, 9.32681179], [79.02319336, 9.32653046], [79.02348328, 9.32653046], [79.02348328, 9.32625198], [79.02401733, 9.32625198], [79.02401733, 9.32597065], [79.02430725, 9.32597065], [79.02430725, 9.32569313], [79.0248642, 9.32569313], [79.0248642, 9.32541847], [79.02513885, 9.32542038], [79.02513885, 9.32514191], [79.0256958, 9.32514191], [79.0256958, 9.32486153], [79.02597046, 9.32486153], [79.02597046, 9.32458305], [79.02625275, 9.32458305], [79.02625275, 9.32430458], [79.02680206, 9.3243103], [79.02680206, 9.32403183], [79.02707672, 9.32403183], [79.02707672, 9.3237524], [79.0276413, 9.3237524], [79.0276413, 9.32347107], [79.02791595, 9.32347107], [79.02791595, 9.32319546], [79.0284729, 9.32319546], [79.0284729, 9.32291698], [79.02874756, 9.32293129], [79.02874756, 9.32263947], [79.02929688, 9.32263947], [79.02929688, 9.32236099], [79.02958679, 9.32236099], [79.02958679, 9.32208347], [79.03013611, 9.32208347], [79.03013611, 9.321805], [79.0304184, 9.32180977], [79.0304184, 9.32152939], [79.0306778, 9.32152939], [79.0306778, 9.32125092], [79.03125, 9.32125092], [79.03125, 9.32097054], [79.03152466, 9.3209734], [79.03152466, 9.32069302], [79.03180695, 9.32069302], [79.03180695, 9.3204174], [79.0320816, 9.32041931], [79.0320816, 9.32014084], [79.03263855, 9.32014084], [79.03263855, 9.31987], [79.03291321, 9.31987], [79.03291321, 9.31958103], [79.0331955, 9.31958294], [79.0331955, 9.31930542], [79.03373718, 9.31931019], [79.03373718, 9.31903076], [79.0340271, 9.31903076], [79.0340271, 9.31875134], [79.03430176, 9.31875134], [79.03430176, 9.31847095], [79.0348587, 9.31847095], [79.0348587, 9.31819534], [79.03514099, 9.31819534], [79.03514099, 9.31791687], [79.03569794, 9.31792164], [79.03569794, 9.31764126], [79.0359726, 9.31764126], [79.0359726, 9.31736088], [79.03652954, 9.31736088], [79.03652954, 9.31708336], [79.0368042, 9.31708336], [79.0368042, 9.31680489], [79.03736115, 9.31681156], [79.03736115, 9.31653118], [79.0376358, 9.31653118], [79.0376358, 9.3162508], [79.03819275, 9.3162508], [79.03819275, 9.31597328], [79.03847504, 9.31597328], [79.03847504, 9.31569481], [79.03902435, 9.31569481], [79.03902435, 9.31541729], [79.03930664, 9.3154192], [79.03930664, 9.31514072], [79.03987122, 9.31514072], [79.03987122, 9.3148613], [79.04013824, 9.3148613], [79.04013824, 9.31458473], [79.04069519, 9.31458473], [79.04069519, 9.31430531], [79.04096985, 9.31431103], [79.04096985, 9.31403065], [79.04152679, 9.31403065], [79.04152679, 9.31374168], [79.04180908, 9.31375122], [79.04180908, 9.31347275], [79.0423584, 9.31347275], [79.0423584, 9.31319523], [79.04264069, 9.31319523], [79.04264069, 9.31291676], [79.04319763, 9.31292057], [79.04319763, 9.31264114], [79.04347229, 9.31264114], [79.04347229, 9.3123579], [79.04402924, 9.31235981], [79.04402924, 9.31208229], [79.04430389, 9.31208229], [79.04430389, 9.31180668], [79.04486084, 9.31181145], [79.04486084, 9.31153107], [79.04514313, 9.31153107], [79.04514313, 9.31125069], [79.04567719, 9.31125069], [79.04567719, 9.31097031], [79.04597473, 9.31097221], [79.04597473, 9.31069374], [79.04652405, 9.31069374], [79.04652405, 9.31041622], [79.04680634, 9.31042099], [79.04680634, 9.31014061], [79.04736328, 9.31014061], [79.04736328, 9.30957985], [79.04792023, 9.30958366], [79.04792023, 9.30930424], [79.04846954, 9.30931091], [79.04846954, 9.30903053], [79.04902649, 9.30903053], [79.04902649, 9.30875015], [79.04930878, 9.30875015], [79.04930878, 9.30847168], [79.04985809, 9.30847168], [79.04985809, 9.30819416], [79.05041504, 9.30819416], [79.05041504, 9.30791569], [79.05069733, 9.3079319], [79.05069733, 9.30764008], [79.05124664, 9.30764008], [79.05124664, 9.3073597], [79.05180359, 9.3073597], [79.05180359, 9.30708408], [79.05236053, 9.30708408], [79.05236053, 9.30680561], [79.05264282, 9.30681133], [79.05264282, 9.30653], [79.05319214, 9.30653], [79.05319214, 9.30624962], [79.05374908, 9.30624962], [79.05374908, 9.30597019], [79.05430603, 9.3059721], [79.05430603, 9.30569363], [79.05458069, 9.30569363], [79.05458069, 9.30541801], [79.05513763, 9.30541992], [79.05513763, 9.30513954], [79.05568695, 9.30513954], [79.05568695, 9.30486202], [79.05596924, 9.30486202], [79.05596924, 9.30458355], [79.05652618, 9.30458355], [79.05652618, 9.30430603], [79.05708313, 9.3043108], [79.05708313, 9.30403042], [79.05764008, 9.30403042], [79.05764008, 9.30375004], [79.0579071, 9.30375004], [79.0579071, 9.30346966], [79.05847168, 9.30347157], [79.05847168, 9.30319405], [79.05902863, 9.30319405], [79.05902863, 9.30291557], [79.0595932, 9.30292034], [79.0595932, 9.30263996], [79.05986023, 9.30263996], [79.05986023, 9.30235958], [79.06041718, 9.30236244], [79.06041718, 9.30208397], [79.06097412, 9.30208397], [79.06097412, 9.30180645], [79.06153107, 9.30180645], [79.06153107, 9.30152798], [79.06208038, 9.30153179], [79.06208038, 9.30125046], [79.06263733, 9.30125046], [79.06263733, 9.30097198], [79.06291962, 9.30097198], [79.06291962, 9.30069447], [79.06346893, 9.30069447], [79.06346893, 9.3004179], [79.06404114, 9.3004179], [79.06404114, 9.30014038], [79.06458282, 9.30014038], [79.06458282, 9.29986191], [79.06541443, 9.29986191], [79.0654068, 9.29958057], [79.06652832, 9.29958439], [79.06652832, 9.29930592], [79.06764221, 9.29930973], [79.06764221, 9.2990303], [79.06846619, 9.2990303], [79.06846619, 9.29874039], [79.06958008, 9.29874897], [79.06958008, 9.29847145], [79.07069397, 9.29847145], [79.07069397, 9.29819584], [79.07152557, 9.29819584], [79.07152557, 9.29791546], [79.07263947, 9.29792023], [79.07263947, 9.29763985], [79.07347107, 9.29763985], [79.07347107, 9.29792023], [79.07402802, 9.29791546], [79.07402802, 9.29819584], [79.07430267, 9.29819584], [79.07430267, 9.29847145], [79.07458496, 9.29847145], [79.07458496, 9.29819584], [79.07485962, 9.29819584], [79.07485962, 9.29791546], [79.07541656, 9.29792023], [79.07541656, 9.29763985], [79.07653046, 9.29763985], [79.07653046, 9.29736137], [79.07763672, 9.29736137], [79.07763672, 9.2970829], [79.07930756, 9.2970829], [79.07930756, 9.29680538], [79.08040619, 9.29681015], [79.08040619, 9.29653168], [79.08152771, 9.29653168], [79.08152771, 9.29624939], [79.0826416, 9.29624939], [79.0826416, 9.29597092], [79.08374786, 9.29597092], [79.08374786, 9.2956953], [79.0848465, 9.29570007], [79.0848465, 9.29541969], [79.08598328, 9.29541969], [79.08598328, 9.29513931], [79.08708191, 9.29513931], [79.08708191, 9.29486084], [79.08792114, 9.29486084], [79.08792114, 9.29458141], [79.08847046, 9.29458332], [79.08847046, 9.29430485], [79.08930206, 9.29430962], [79.08930206, 9.29402924], [79.0901413, 9.29402924], [79.0901413, 9.29375076], [79.09069061, 9.29375076], [79.09069824, 9.29347134], [79.09152985, 9.29347324], [79.09152985, 9.29319477], [79.09236145, 9.29319477], [79.09236145, 9.29291725], [79.09319305, 9.29292202], [79.09319305, 9.29264069], [79.09401703, 9.29264069], [79.09401703, 9.29236126], [79.09513855, 9.29236126], [79.09513855, 9.29208279], [79.09597015, 9.29208279], [79.09597015, 9.29180527], [79.0967865, 9.29181194], [79.0967865, 9.29153061], [79.09764099, 9.29153061], [79.09764099, 9.29125118], [79.0984726, 9.29125118], [79.0984726, 9.2909708], [79.09958649, 9.2909708], [79.09958649, 9.29069519], [79.10041809, 9.29069519], [79.10041809, 9.29041672], [79.10124969, 9.29042053], [79.10124969, 9.29014111], [79.10235596, 9.29014111], [79.10235596, 9.28986073], [79.10321045, 9.28986073], [79.10319519, 9.28958321], [79.10458374, 9.28958321], [79.10458374, 9.28930473], [79.10595703, 9.28931236], [79.10595703, 9.28903103], [79.10764313, 9.28903103], [79.10764313, 9.28875065], [79.10930634, 9.28875065], [79.10930634, 9.28847122], [79.11292267, 9.28847122], [79.11292267, 9.28875065], [79.11429596, 9.28875065], [79.11429596, 9.28903103], [79.11569214, 9.28903103], [79.11569214, 9.28931236], [79.11708069, 9.28930473], [79.11708069, 9.28958321], [79.12403107, 9.28958321], [79.12403107, 9.28930473], [79.12431335, 9.28931236], [79.12431335, 9.28903103], [79.12486267, 9.28903103], [79.12486267, 9.28875065], [79.12513733, 9.28875065], [79.12513733, 9.28847122], [79.12541962, 9.28847313], [79.12541962, 9.28819466], [79.12569427, 9.28819466], [79.12569427, 9.28791714], [79.12625122, 9.28792095], [79.12625122, 9.28764057], [79.1279068, 9.28764057], [79.1279068, 9.28736115], [79.12985992, 9.28736115], [79.12985992, 9.28708267], [79.13236237, 9.28708267], [79.13236237, 9.28736115], [79.13263702, 9.28736115], [79.13263702, 9.28792095], [79.13375092, 9.28791714], [79.13375092, 9.28819466], [79.13402557, 9.28819466], [79.13402557, 9.28847313], [79.13458252, 9.28847122], [79.13458252, 9.28875065], [79.13485718, 9.28875065], [79.13485718, 9.28903103], [79.13513947, 9.28903103], [79.13513947, 9.28931236], [79.13541412, 9.28930473], [79.13541412, 9.28958321], [79.13597107, 9.28958321], [79.13597107, 9.28986073], [79.13625336, 9.28986073], [79.13625336, 9.29014111], [79.13652802, 9.2901392], [79.13652802, 9.2909708], [79.13735962, 9.2909708], [79.13735962, 9.29125118], [79.13819122, 9.29125118], [79.13819122, 9.29153061], [79.13874817, 9.29153061], [79.13874817, 9.29181194], [79.13903046, 9.29180527], [79.13903046, 9.29208279], [79.13930511, 9.29208279], [79.13930511, 9.29236126], [79.14013672, 9.29236126], [79.14013672, 9.29208279], [79.14180756, 9.29208279], [79.14180756, 9.29180527], [79.14290619, 9.29181194], [79.14290619, 9.29153061], [79.14375305, 9.29153061], [79.14375305, 9.29125118], [79.14485931, 9.29125118], [79.14485931, 9.2909708], [79.14569092, 9.2909708], [79.14569092, 9.29069519], [79.14653015, 9.29069519], [79.14653015, 9.29041672], [79.1470871, 9.29042053], [79.1470871, 9.29014111], [79.1479187, 9.29014111], [79.1479187, 9.28986073], [79.14875031, 9.28986073], [79.14875031, 9.28958321], [79.14930725, 9.28958321], [79.14930725, 9.28930473], [79.15013885, 9.28931236], [79.15013885, 9.28903103], [79.1506958, 9.28903103], [79.1506958, 9.28875065], [79.15126038, 9.28875065], [79.15126038, 9.28847122], [79.15180206, 9.28847313], [79.15180206, 9.28819466], [79.15235901, 9.28819466], [79.15235901, 9.28791714], [79.1526413, 9.28792095], [79.1526413, 9.28764057], [79.15319061, 9.28764057], [79.15319824, 9.28736115], [79.15402985, 9.28736115], [79.15402985, 9.28708267], [79.15458679, 9.28708267], [79.15458679, 9.2868042], [79.15513611, 9.2868042], [79.15513611, 9.28652859], [79.15569305, 9.28653145], [79.15569305, 9.28625107], [79.15651703, 9.28625107], [79.15651703, 9.28569031], [79.15680695, 9.28569508], [79.15680695, 9.28513813], [79.15875244, 9.28514099], [79.15875244, 9.28485966], [79.1590271, 9.28485966], [79.1590271, 9.28458214], [79.16014099, 9.28458214], [79.16014099, 9.28430653], [79.16124725, 9.28431129], [79.16124725, 9.28403091], [79.1626358, 9.28403091], [79.1626358, 9.28431129], [79.16402435, 9.28430653], [79.16402435, 9.28458214], [79.1645813, 9.28458214], [79.1645813, 9.28430653], [79.16819763, 9.28430653], [79.16819763, 9.28458214], [79.17708588, 9.28458214], [79.17708588, 9.28430653], [79.17903137, 9.28431129], [79.17903137, 9.28403091], [79.17958069, 9.28403091], [79.17958069, 9.28376198], [79.18013763, 9.28376198], [79.18013763, 9.28347015], [79.18125153, 9.28347206], [79.18125153, 9.28319359], [79.19041443, 9.28319359], [79.19041443, 9.28291607], [79.19069672, 9.28292084], [79.19069672, 9.28180885], [79.1904068, 9.28180885], [79.1904068, 9.28153133], [79.18985748, 9.28153133], [79.18985748, 9.28125], [79.18791962, 9.28125], [79.18791962, 9.28153133], [79.18653107, 9.28153133], [79.18653107, 9.28125], [79.18541718, 9.28125], [79.18541718, 9.28153133], [79.18430328, 9.28153133], [79.18430328, 9.28125], [79.18319702, 9.28125], [79.18319702, 9.28096962], [79.17958069, 9.28097153], [79.17958069, 9.28069401], [79.17930603, 9.28070068], [79.17930603, 9.28042126], [79.1784668, 9.28042126], [79.1784668, 9.28070068], [79.17736053, 9.28070068], [79.17736053, 9.28042126], [79.17708588, 9.28042126], [79.17708588, 9.28013992], [79.17597198, 9.28013992], [79.17597198, 9.27985954], [79.17236328, 9.2798624], [79.17236328, 9.27958202], [79.16930389, 9.27958202], [79.16930389, 9.27930641], [79.16874695, 9.27931118], [79.16874695, 9.27902985], [79.16707611, 9.27902985], [79.16707611, 9.27875042], [79.16569519, 9.27875042], [79.16569519, 9.27847195], [79.16374969, 9.27847195], [79.16374969, 9.27819443], [79.16208649, 9.27819443], [79.16208649, 9.27791595], [79.16069794, 9.27791977], [79.16069794, 9.27763081], [79.15736389, 9.27763844], [79.15736389, 9.27736187], [79.15680695, 9.27736187], [79.15680695, 9.27680588], [79.15598297, 9.27680969], [79.15598297, 9.27653027], [79.15374756, 9.27653027], [79.15374756, 9.27680969], [79.1526413, 9.27680969], [79.1526413, 9.27653027], [79.14958191, 9.27653027], [79.14958191, 9.27625179], [79.14875031, 9.27625179], [79.14875031, 9.27653027], [79.1479187, 9.27653027], [79.1479187, 9.27625179], [79.1470871, 9.27625179], [79.1470871, 9.27596855], [79.14653015, 9.27597237], [79.14653015, 9.27569389], [79.14569092, 9.27569389], [79.14569092, 9.27541637], [79.14541626, 9.27542019], [79.14541626, 9.27486038], [79.14375305, 9.27486229], [79.14375305, 9.2743063], [79.14347076, 9.27431011], [79.14347076, 9.27415085], [79.14347076, 9.27402782], [79.14319611, 9.27402973], [79.14319611, 9.27347183], [79.14291382, 9.27347183], [79.14291382, 9.27291775], [79.14263916, 9.27291965], [79.14263916, 9.27264023], [79.1415329, 9.27264023], [79.1415329, 9.27235889], [79.13680267, 9.27236176], [79.13625336, 9.27236176], [79.13625336, 9.27208424], [79.13458252, 9.27208424], [79.13458252, 9.27180576], [79.13263702, 9.27182102], [79.13263702, 9.27153015], [79.1295929, 9.27153015], [79.1295929, 9.27125168], [79.12847137, 9.27125168], [79.12847137, 9.2709713], [79.12735748, 9.2709713], [79.12735748, 9.27069569], [79.12625122, 9.27069569], [79.12625122, 9.27041531], [79.12541962, 9.27042198], [79.12541962, 9.2701416], [79.12431335, 9.2701416], [79.12431335, 9.26986122], [79.12319183, 9.26986122], [79.12319183, 9.26958275], [79.12180328, 9.26958275], [79.12180328, 9.26930523], [79.1204071, 9.26931], [79.1204071, 9.26902962], [79.11985779, 9.26902962], [79.11985779, 9.26876068], [79.11902618, 9.26876068], [79.11902618, 9.26847076], [79.11846924, 9.26847267], [79.11846924, 9.26819324], [79.11736298, 9.26819324], [79.11736298, 9.26791668], [79.11680603, 9.26791954], [79.11680603, 9.26764202], [79.11653137, 9.26764202], [79.11653137, 9.26736069], [79.11624908, 9.26736069], [79.11624908, 9.26708317], [79.11569214, 9.26708317], [79.11569214, 9.2668047], [79.11541748, 9.26681042], [79.11541748, 9.26653194], [79.11458588, 9.26653194], [79.11458588, 9.26625061], [79.11402893, 9.26625061], [79.11402893, 9.26597118], [79.11291504, 9.26597309], [79.11291504, 9.26569462], [79.11264038, 9.26569462], [79.11264038, 9.2654171], [79.11042023, 9.26542187], [79.11042023, 9.26514053], [79.10986328, 9.26514053], [79.10986328, 9.26486111], [79.10874939, 9.26486111], [79.10874939, 9.26514053], [79.10791779, 9.26514053], [79.10791779, 9.26486111], [79.10708618, 9.26486111], [79.10708618, 9.26458263], [79.10652924, 9.26458263], [79.10652924, 9.26430511], [79.10569763, 9.26431179], [79.10569763, 9.26403141], [79.10514069, 9.26403141], [79.10514069, 9.26375103], [79.10430908, 9.26375103], [79.10430908, 9.26347065], [79.10346985, 9.26347256], [79.10346985, 9.26319504], [79.1029129, 9.26319504], [79.1029129, 9.26263905], [79.1020813, 9.26263905], [79.1020813, 9.26236057], [79.10097504, 9.26236057], [79.10097504, 9.26208305], [79.1001358, 9.26208305], [79.1001358, 9.26180458], [79.09929657, 9.26180935], [79.09929657, 9.26153088], [79.0984726, 9.26153088], [79.0984726, 9.26125145], [79.0973587, 9.26125145], [79.0973587, 9.26097012], [79.0965271, 9.26097298], [79.0965271, 9.26069546], [79.0956955, 9.26069546], [79.0956955, 9.26041698], [79.0945816, 9.26041889], [79.0945816, 9.26014137], [79.09375, 9.26014137], [79.09375, 9.25986099], [79.09098053, 9.25986099], [79.09098053, 9.26014137], [79.08930206, 9.26014137], [79.08930206, 9.26041889], [79.08569336, 9.26041698], [79.08569336, 9.26069546], [79.07541656, 9.26069546], [79.07541656, 9.26097298], [79.06903076, 9.26097012], [79.06903076, 9.26124859], [79.06819153, 9.26125145], [79.06819153, 9.26153088], [79.06764221, 9.26153088], [79.06764221, 9.26097012], [79.06735992, 9.26097298], [79.06735992, 9.26069546], [79.06541443, 9.26069546], [79.06541443, 9.26097298], [79.06404114, 9.26097012], [79.06402588, 9.26124859], [79.06375122, 9.26125145], [79.06375122, 9.26153088], [79.06346893, 9.26153088], [79.06346893, 9.26180935], [79.06319427, 9.26180458], [79.06319427, 9.26208305], [79.06291962, 9.26208305], [79.06291962, 9.26236057], [79.05819702, 9.26236057], [79.05819702, 9.26263905], [79.05625153, 9.26263905], [79.05625153, 9.26236057], [79.05403137, 9.26236057], [79.05403137, 9.26263905], [79.05319214, 9.26263046], [79.05319214, 9.26292133], [79.05097198, 9.26291656], [79.05097198, 9.26319504], [79.05041504, 9.26319504], [79.05041504, 9.26347256], [79.04985809, 9.26347065], [79.04985809, 9.26375103], [79.04957581, 9.26375103], [79.04957581, 9.26403141], [79.04902649, 9.26403141], [79.04902649, 9.26431179], [79.04875183, 9.26430511], [79.04875183, 9.26458263], [79.04319763, 9.26458263], [79.04319763, 9.26486111], [79.04207611, 9.26486111], [79.04207611, 9.26514053], [79.04013824, 9.26514053], [79.04013824, 9.26542187], [79.03819275, 9.2654171], [79.03819275, 9.26569462], [79.03652954, 9.26569462], [79.03652954, 9.26597309], [79.03569794, 9.26597118], [79.03569794, 9.26625061], [79.03514099, 9.26625061], [79.03514099, 9.26653194], [79.03430939, 9.26653194], [79.03430176, 9.26681042], [79.03375244, 9.2668047], [79.03375244, 9.26708317], [79.0304184, 9.26708317], [79.0304184, 9.26736069], [79.02929688, 9.26736069], [79.02929688, 9.26764202], [79.0284729, 9.26764202], [79.0284729, 9.26791954], [79.02735901, 9.26791668], [79.02735901, 9.26819324], [79.02541351, 9.26819324], [79.02541351, 9.26847267], [79.02375031, 9.26847076], [79.02375031, 9.26876068], [79.02179718, 9.26876068], [79.02179718, 9.26902962], [79.0201416, 9.26902962], [79.0201416, 9.26931], [79.01791382, 9.26930523], [79.01791382, 9.26958275], [79.01569366, 9.26958275], [79.01569366, 9.26986122], [79.01346588, 9.26986122], [79.01346588, 9.2701416], [79.01125336, 9.2701416], [79.01125336, 9.27042198], [79.00958252, 9.27041531], [79.00958252, 9.27069569], [79.00819397, 9.27069569], [79.00819397, 9.2709713], [79.00624847, 9.2709713], [79.00624847, 9.27125168], [79.00430298, 9.27125168], [79.00430298, 9.27153015], [79.00208282, 9.27153015], [79.00208282, 9.27182102], [79.00041962, 9.27180576], [79.00041962, 9.27236176], [79.00013733, 9.27236176], [78.99958038, 9.27235889], [78.99958038, 9.27264023], [78.99930573, 9.27264023], [78.99930573, 9.27319336], [78.99847412, 9.27319336], [78.99847412, 9.27347183], [78.99819183, 9.27347183], [78.99819183, 9.27291775], [78.99791718, 9.27291965], [78.99791718, 9.27264023], [78.99680328, 9.27264023], [78.99680328, 9.27235889], [78.99624634, 9.27235889], [78.99624634, 9.27264023], [78.99597168, 9.27264023], [78.99597168, 9.27235889], [78.9954071, 9.27235889], [78.9954071, 9.27264023], [78.99485779, 9.27264023], [78.99485779, 9.27235889], [78.99375153, 9.27235889], [78.99375153, 9.27264023], [78.99208069, 9.27264023], [78.99208069, 9.27291965], [78.99097443, 9.27291775], [78.99097443, 9.27319336], [78.98847198, 9.27319336], [78.98847198, 9.27347183], [78.98791504, 9.27347183], [78.98791504, 9.27375031], [78.98680878, 9.27375031], [78.98680878, 9.27347183], [78.98596954, 9.27347183], [78.98596954, 9.27375031], [78.98513794, 9.27375031], [78.98513794, 9.27431011], [78.98486328, 9.2743063], [78.98486328, 9.27458382], [78.98458099, 9.27458382], [78.98458099, 9.27486229], [78.98208618, 9.27486229], [78.98208618, 9.27458382], [78.98152924, 9.27458382], [78.98152924, 9.27486229], [78.98069763, 9.27486229], [78.98069763, 9.27458382], [78.98041534, 9.27458382], [78.98041534, 9.27402782], [78.98014069, 9.27402973], [78.98014069, 9.27375031], [78.97902679, 9.27375031], [78.97902679, 9.27347183], [78.97763824, 9.27347183], [78.97763824, 9.27375031], [78.97652435, 9.27375031], [78.97652435, 9.27347183], [78.9751358, 9.27347183], [78.9751358, 9.27375031], [78.97180176, 9.27375031], [78.97180176, 9.27347183], [78.9706955, 9.27347183], [78.9706955, 9.27319336], [78.97041321, 9.27319336], [78.97041321, 9.27291775], [78.96624756, 9.27291775], [78.96624756, 9.27319336], [78.96569824, 9.27319336], [78.96569061, 9.27291775], [78.96430206, 9.27291965], [78.96430206, 9.27264023], [78.96347046, 9.27264023], [78.96347046, 9.27235889], [78.96263885, 9.27236176], [78.96263885, 9.27208424], [78.96208191, 9.27208424], [78.96208191, 9.27236176], [78.96180725, 9.27235889], [78.96180725, 9.27264023], [78.9595871, 9.27264023], [78.9595871, 9.27235889], [78.95847321, 9.27236176], [78.95847321, 9.27208424], [78.95708466, 9.27208424], [78.95708466, 9.27236176], [78.95513916, 9.27236176], [78.95513916, 9.27208424], [78.95402527, 9.27208424], [78.95402527, 9.27180576], [78.95207977, 9.27182102], [78.95207977, 9.27153015], [78.95096588, 9.27153015], [78.95096588, 9.27125168], [78.94819641, 9.27125168], [78.94819641, 9.2709713], [78.94596863, 9.2709713], [78.94596863, 9.27069569], [78.94541931, 9.27069569], [78.94541931, 9.27041531], [78.94431305, 9.27042198], [78.94431305, 9.2701416], [78.94374847, 9.2701416], [78.94374847, 9.26986122], [78.94291687, 9.26986122], [78.94291687, 9.26958275], [78.94180298, 9.26958275], [78.94180298, 9.26930523], [78.93985748, 9.26931], [78.93985748, 9.26902962], [78.93930817, 9.26902962], [78.93930817, 9.26876068], [78.93653107, 9.26876068], [78.93653107, 9.26847076], [78.93486023, 9.26847267], [78.93486023, 9.26819324], [78.93430328, 9.26819324], [78.93430328, 9.26791668], [78.93374634, 9.26791954], [78.93374634, 9.26764202], [78.93208313, 9.26764202], [78.93208313, 9.26736069], [78.93096924, 9.26736069], [78.93096924, 9.26708317], [78.92986298, 9.26708317], [78.92986298, 9.2668047], [78.92874908, 9.26681042], [78.92874908, 9.26653194], [78.92764282, 9.26653194], [78.92764282, 9.26625061], [78.92708588, 9.26625061], [78.92708588, 9.26597118], [78.92569733, 9.26597309], [78.92569733, 9.26569462], [78.92514038, 9.26569462], [78.92514038, 9.2654171], [78.92457581, 9.26542187], [78.92457581, 9.26514053], [78.92430878, 9.26514053], [78.92430878, 9.26486111], [78.92402649, 9.26486111], [78.92402649, 9.26458263], [78.92346954, 9.26458263], [78.92346954, 9.26430511], [78.92318726, 9.26431179], [78.92318726, 9.26403141], [78.92263794, 9.26403141], [78.92263794, 9.26375103], [78.92234802, 9.26375103], [78.92234802, 9.26347065], [78.92208099, 9.26347256], [78.92208099, 9.26319504], [78.92180634, 9.26319504], [78.92180634, 9.26291656], [78.92151642, 9.26292133], [78.92151642, 9.26263046], [78.92097473, 9.26263905], [78.92097473, 9.26208305], [78.92069244, 9.26208305], [78.92069244, 9.26180458], [78.92041779, 9.26180935], [78.92041779, 9.26153088], [78.91986084, 9.26153088], [78.91986084, 9.26125145], [78.91960144, 9.26125145], [78.91960144, 9.26097012], [78.91930389, 9.26097298], [78.91930389, 9.26069546], [78.91902924, 9.26069546], [78.91902924, 9.26041698], [78.91874695, 9.26041889], [78.91874695, 9.26014137], [78.91847229, 9.26014137], [78.91847229, 9.2595892], [78.91819763, 9.2595892], [78.91819763, 9.25931072], [78.91792297, 9.25931072], [78.91792297, 9.2590313], [78.91764069, 9.2590313], [78.91764069, 9.25846958], [78.91708374, 9.2584734], [78.91708374, 9.25819492], [78.91680908, 9.25819492], [78.91680908, 9.25791645], [78.91625214, 9.25792122], [78.91625214, 9.25764084], [78.91596985, 9.25764084], [78.91596985, 9.25736046], [78.91569519, 9.25736046], [78.91569519, 9.25708199], [78.9154129, 9.25708199], [78.9154129, 9.2565279], [78.91513824, 9.2565279], [78.91513824, 9.25597], [78.91486359, 9.25597191], [78.91486359, 9.2551403], [78.9145813, 9.2551403], [78.9145813, 9.25468922], [78.9145813, 9.25458431], [78.91430664, 9.25458431], [78.91430664, 9.25402832], [78.91401672, 9.25403118], [78.91401672, 9.25346088], [78.91347504, 9.25347233], [78.91347504, 9.25319386], [78.91319275, 9.25319386], [78.91319275, 9.25291634], [78.91236115, 9.2529211], [78.91236115, 9.25263977], [78.91179657, 9.25263977], [78.91179657, 9.25236034], [78.91152954, 9.25236225], [78.91152954, 9.25208378], [78.91124725, 9.25208378], [78.91124725, 9.25180626], [78.9109726, 9.25181103], [78.9109726, 9.25152969], [78.91069794, 9.25152969], [78.91069794, 9.25125027], [78.91014099, 9.25125027], [78.91014099, 9.25097179], [78.9098587, 9.25097179], [78.9098587, 9.25069427], [78.90958405, 9.25069427], [78.90958405, 9.2504158], [78.90875244, 9.25041962], [78.90875244, 9.25014019], [78.90734863, 9.25014019], [78.90734863, 9.24985981], [78.90652466, 9.24985981], [78.90652466, 9.2495842], [78.90513611, 9.2495842], [78.90513611, 9.24985981], [78.90431213, 9.24985981], [78.90431213, 9.25014019], [78.90322113, 9.25014019], [78.90319824, 9.25041962], [78.90208435, 9.2504158], [78.90208435, 9.25069427], [78.90125275, 9.25069427], [78.90125275, 9.25097179], [78.90013885, 9.25097179], [78.90013885, 9.25125027], [78.89958191, 9.25125027], [78.89958191, 9.25152969], [78.89901733, 9.25152969], [78.89901733, 9.25181103], [78.89819336, 9.25180626], [78.89819336, 9.25208378], [78.89680481, 9.25208378], [78.89680481, 9.25236225], [78.89597321, 9.25236034], [78.89597321, 9.25263977], [78.8951416, 9.25263977], [78.8951416, 9.2529211], [78.89485931, 9.2529211], [78.89485931, 9.25263977], [78.89457703, 9.25263977], [78.89457703, 9.2529211], [78.89347076, 9.25291634], [78.89347076, 9.25319386], [78.89319611, 9.25319386], [78.89319611, 9.25291634], [78.89291382, 9.25291634], [78.89291382, 9.25319386], [78.8923645, 9.25319386], [78.8923645, 9.25347233], [78.89068604, 9.25346088], [78.89069366, 9.25374985], [78.89041901, 9.25374985], [78.89041901, 9.25403118], [78.88931274, 9.25403118], [78.88931274, 9.25431061], [78.88764191, 9.25430584], [78.88764191, 9.25458431], [78.88652802, 9.25458431], [78.88652802, 9.25485992], [78.88513947, 9.25485992], [78.88513947, 9.2551403], [78.88430786, 9.2551403], [78.88430786, 9.25542068], [78.88263702, 9.25541592], [78.88263702, 9.25569439], [78.88180542, 9.25569439], [78.88180542, 9.25597191], [78.88041687, 9.25597191], [78.88041687, 9.25625038], [78.87737274, 9.25625038], [78.87737274, 9.2565279], [78.87319183, 9.2565279], [78.87319183, 9.25625038], [78.87236023, 9.25625038], [78.87236023, 9.25597191], [78.87208557, 9.25597191], [78.87208557, 9.25569439], [78.87152863, 9.25569439], [78.87152863, 9.25541592], [78.87123871, 9.25542068], [78.87123871, 9.2551403], [78.87097168, 9.2551403], [78.87097168, 9.25485992], [78.8704071, 9.25485992], [78.8704071, 9.25457954], [78.87014008, 9.25458431], [78.87014008, 9.25402832], [78.86985779, 9.25403118], [78.86985779, 9.25374985], [78.86958313, 9.25374985], [78.86958313, 9.25347233], [78.86569214, 9.25347233], [78.86569214, 9.25374985], [78.86513519, 9.25374985], [78.86513519, 9.25347233], [78.86486053, 9.25347233], [78.86486053, 9.25374985], [78.86180878, 9.25374985], [78.86180878, 9.25347233], [78.86013794, 9.25347233], [78.86013794, 9.25319386], [78.85958099, 9.25319386], [78.85958099, 9.25291634], [78.85929871, 9.2529211], [78.85929871, 9.25263977], [78.85900879, 9.25263977], [78.85900879, 9.25236034], [78.85874939, 9.25236225], [78.85874939, 9.25208378], [78.85847473, 9.25208378], [78.85847473, 9.25180626], [78.85791779, 9.25181103], [78.85791779, 9.25152969], [78.85764313, 9.25152969], [78.85764313, 9.25125027], [78.85736084, 9.25125027], [78.85736084, 9.25097179], [78.85708618, 9.25097179], [78.85708618, 9.2504158], [78.85652924, 9.25041962], [78.85652924, 9.25014019], [78.85626221, 9.25014019], [78.85626221, 9.24985981], [78.85597229, 9.24985981], [78.85597229, 9.2495842], [78.85458374, 9.2495842], [78.85458374, 9.24930573], [78.85402679, 9.24930954], [78.85402679, 9.24903011], [78.85375214, 9.24903011], [78.85375214, 9.24874973], [78.85346985, 9.24874973], [78.85346985, 9.24846935], [78.85041809, 9.24847221], [78.85041809, 9.24819374], [78.84958649, 9.24819374], [78.84958649, 9.24847221], [78.84902954, 9.24847221], [78.84902954, 9.24819374], [78.8484726, 9.24819374], [78.8484726, 9.24791622], [78.84791565, 9.24791622], [78.84791565, 9.24819374], [78.84319305, 9.24819374], [78.84319305, 9.24791622], [78.84208679, 9.24792004], [78.84208679, 9.2476511], [78.8409729, 9.2476511], [78.8409729, 9.24735928], [78.8401413, 9.24736214], [78.8401413, 9.24708366], [78.83958435, 9.24708366], [78.83958435, 9.24652767], [78.83930206, 9.24652958], [78.83930206, 9.24625015], [78.83847046, 9.24625015], [78.83847046, 9.24597168], [78.83708191, 9.24597168], [78.83708191, 9.24569321], [78.83597565, 9.24569321], [78.83597565, 9.24541759], [78.83486176, 9.24542046], [78.83486176, 9.24514198], [78.83374786, 9.24514198], [78.83374786, 9.24542046], [78.83347321, 9.24541759], [78.83347321, 9.24625015], [78.83374786, 9.24625015], [78.83374786, 9.24708366], [78.83403015, 9.24708366], [78.83403015, 9.24736214], [78.83429718, 9.24735928], [78.83429718, 9.2476511], [78.8345871, 9.24763966], [78.8345871, 9.24847221], [78.83429718, 9.24846935], [78.83429718, 9.24874973], [78.83403015, 9.24874973], [78.83403015, 9.24903011], [78.83374786, 9.24902821], [78.83374786, 9.2495842], [78.83347321, 9.2495842], [78.83347321, 9.24985981], [78.83319092, 9.24985981], [78.83319092, 9.25014019], [78.83291626, 9.25014019], [78.83291626, 9.25041962], [78.8326416, 9.2504158], [78.8326416, 9.25069427], [78.83235931, 9.25069427], [78.83235931, 9.25097179], [78.8320694, 9.25097179], [78.83208466, 9.25125027], [78.83180237, 9.25125027], [78.83180237, 9.25152969], [78.83152771, 9.25152969], [78.83152771, 9.25181103], [78.83125305, 9.25180626], [78.83125305, 9.25236225], [78.83097076, 9.25236034], [78.83097076, 9.2529211], [78.83069611, 9.25291634], [78.83069611, 9.25319386], [78.83040619, 9.25319195], [78.83040619, 9.25431061], [78.83013916, 9.25430584], [78.83013916, 9.25569439], [78.83040619, 9.25568962], [78.83040619, 9.2565279], [78.83097076, 9.2565279], [78.83097076, 9.25708199], [78.83180237, 9.25708199], [78.83180237, 9.25736046], [78.83208466, 9.25736046], [78.83208466, 9.25819492], [78.83235931, 9.25819016], [78.83235931, 9.25875092], [78.8326416, 9.25875092], [78.8326416, 9.25931072], [78.83291626, 9.25931072], [78.83291626, 9.26014137], [78.83319092, 9.26013947], [78.83319092, 9.26069546], [78.83347321, 9.26068974], [78.83347321, 9.26125145], [78.83374786, 9.26124859], [78.83374786, 9.26236057], [78.83403015, 9.26236057], [78.83403015, 9.26263905], [78.83374786, 9.26263046], [78.83374786, 9.26292133], [78.83403015, 9.26291656], [78.83403015, 9.26319504], [78.83429718, 9.26319027], [78.83429718, 9.26431179], [78.8345871, 9.26430511], [78.8345871, 9.26708317], [78.83429718, 9.26708126], [78.83429718, 9.26764202], [78.83403015, 9.26764202], [78.83403015, 9.26791954], [78.83374786, 9.26791668], [78.83374786, 9.26819324], [78.83347321, 9.26819324], [78.83347321, 9.26847267], [78.83319092, 9.26847076], [78.83319092, 9.26876068], [78.8326416, 9.26876068], [78.8326416, 9.26819134], [78.83291626, 9.26819324], [78.83291626, 9.26791668], [78.83319092, 9.26791954], [78.83319092, 9.26764202], [78.83347321, 9.26764202], [78.83347321, 9.26625061], [78.83374786, 9.26625061], [78.83374786, 9.26514053], [78.83347321, 9.26514053], [78.83347321, 9.26403141], [78.83319092, 9.26403141], [78.83319092, 9.26375103], [78.83291626, 9.26375103], [78.83291626, 9.26347065], [78.8326416, 9.26347256], [78.8326416, 9.26208305], [78.83235931, 9.26208305], [78.83235931, 9.26152897], [78.8320694, 9.26153088], [78.8320694, 9.26097012], [78.83180237, 9.26097298], [78.83180237, 9.26069546], [78.83152771, 9.26069546], [78.83152771, 9.26041698], [78.83125305, 9.26041889], [78.83125305, 9.2595892], [78.83097076, 9.2595892], [78.83097076, 9.25931072], [78.83125305, 9.25931072], [78.83125305, 9.2590313], [78.83097076, 9.2590313], [78.83097076, 9.25875092], [78.83069611, 9.25875092], [78.83069611, 9.25846958], [78.83041382, 9.2584734], [78.83041382, 9.25819492], [78.83013916, 9.25819492], [78.83013916, 9.25791645], [78.82985687, 9.25792122], [78.82985687, 9.25764084], [78.83013916, 9.25764084], [78.83013916, 9.25736046], [78.8298645, 9.25736046], [78.8298645, 9.25680733], [78.82958221, 9.25681973], [78.82958221, 9.2565279], [78.8290329, 9.2565279], [78.8290329, 9.25485992], [78.82875061, 9.25485992], [78.82875061, 9.25374985], [78.82902527, 9.25374985], [78.82902527, 9.25291634], [78.82932281, 9.2529211], [78.82932281, 9.25236034], [78.82958221, 9.25236225], [78.82958221, 9.25180626], [78.82985687, 9.25181103], [78.82985687, 9.25125027], [78.83013916, 9.25125027], [78.83013916, 9.25097179], [78.83041382, 9.25097179], [78.83041382, 9.25069427], [78.83069611, 9.25069427], [78.83069611, 9.2504158], [78.83097076, 9.25041962], [78.83097076, 9.24903011], [78.83125305, 9.24903011], [78.83125305, 9.24874973], [78.83180237, 9.24874973], [78.83180237, 9.24846935], [78.83208466, 9.24847221], [78.83208466, 9.24819374], [78.83180237, 9.24819374], [78.83180237, 9.24791622], [78.8320694, 9.24792004], [78.8320694, 9.24735928], [78.83235931, 9.24736214], [78.83235931, 9.24708366], [78.8326416, 9.24708366], [78.8326416, 9.24625015], [78.83235931, 9.24625015], [78.83235931, 9.24597168], [78.8326416, 9.24597168], [78.8326416, 9.24541759], [78.83291626, 9.24542046], [78.83291626, 9.24375153], [78.8326416, 9.24375153], [78.8326416, 9.24347115], [78.83235931, 9.24347115], [78.83235931, 9.24319553], [78.83097076, 9.24319553], [78.83097076, 9.24291706], [78.82985687, 9.24291992], [78.82985687, 9.24263859], [78.82791901, 9.24263859], [78.82791901, 9.24236107], [78.82736206, 9.24236107], [78.82736206, 9.2420826], [78.82680511, 9.2420826], [78.82680511, 9.24180508], [78.82624817, 9.24180984], [78.82624817, 9.24151993], [78.82514191, 9.2415266], [78.82514191, 9.24124908], [78.82457733, 9.24125099], [78.82457733, 9.24097061], [78.82402802, 9.24097347], [78.82402802, 9.24069309], [78.82347107, 9.24069309], [78.82347107, 9.24041653], [78.82289886, 9.24042034], [78.82289886, 9.23986053], [78.82263947, 9.23986053], [78.82263947, 9.23958302], [78.82236481, 9.23958302], [78.82236481, 9.23930454], [78.82208252, 9.23931026], [78.82208252, 9.23903179], [78.82096863, 9.23903179], [78.82096863, 9.23875141], [78.81986237, 9.23875141], [78.81986237, 9.23847103], [78.81903076, 9.23847103], [78.81903076, 9.23819542], [78.81847382, 9.23819542], [78.81847382, 9.23791695], [78.81819153, 9.23792171], [78.81819153, 9.23764133], [78.81791687, 9.23764133], [78.81791687, 9.23736095], [78.81708527, 9.23736095], [78.81708527, 9.23708344], [78.81625366, 9.23708344], [78.81625366, 9.23680496], [78.81569672, 9.23680496], [78.81569672, 9.23708344], [78.81541443, 9.23708344], [78.81541443, 9.23680496], [78.81513977, 9.23680496], [78.81513977, 9.23708344], [78.81402588, 9.23708344], [78.81402588, 9.23736095], [78.81291962, 9.23736095], [78.81291962, 9.23708344], [78.81263733, 9.23708344], [78.81263733, 9.23736095], [78.81208038, 9.23736095], [78.81208038, 9.23764133], [78.81153107, 9.23764133], [78.81153107, 9.23736095], [78.81069183, 9.23736095], [78.81069183, 9.23708344], [78.80958557, 9.23708344], [78.80958557, 9.23680496], [78.80874634, 9.23681164], [78.80874634, 9.23653126], [78.80764008, 9.23653126], [78.80764008, 9.23681164], [78.80680847, 9.23681164], [78.80680847, 9.23653126], [78.80625153, 9.23653126], [78.80625153, 9.23625088], [78.80486298, 9.23625088], [78.80486298, 9.23597145], [78.80430603, 9.23597336], [78.80430603, 9.23569489], [78.80374908, 9.23569489], [78.80374908, 9.23541737], [78.8034668, 9.23541927], [78.8034668, 9.23513889], [78.80319214, 9.23513889], [78.80319214, 9.23486137], [78.80291748, 9.23486137], [78.80291748, 9.2345829], [78.80208588, 9.2345829], [78.80208588, 9.23430538], [78.80097198, 9.2343092], [78.80097198, 9.23403072], [78.80042267, 9.23403072], [78.80042267, 9.2337513], [78.79985809, 9.2337513], [78.79985809, 9.23347282], [78.79958344, 9.23347282], [78.79958344, 9.2331953], [78.79930878, 9.2331953], [78.79930878, 9.23291683], [78.79901886, 9.23292065], [78.79901886, 9.23236275], [78.79818726, 9.23236275], [78.79818726, 9.23208046], [78.79792023, 9.23208237], [78.79792023, 9.23180676], [78.79763794, 9.23181057], [78.79763794, 9.23153114], [78.79736328, 9.23153114], [78.79736328, 9.2312479], [78.79680634, 9.23125076], [78.79680634, 9.23097324], [78.79597473, 9.23097324], [78.79597473, 9.23069382], [78.79541779, 9.23069382], [78.79541779, 9.2304163], [78.79514313, 9.23042107], [78.79514313, 9.23014069], [78.79486084, 9.23014069], [78.79486084, 9.22957993], [78.79458618, 9.22958469], [78.79458618, 9.22930431], [78.79429626, 9.22931099], [78.79429626, 9.22903061], [78.79402924, 9.22903061], [78.79402924, 9.22875023], [78.79319763, 9.22875023], [78.79319763, 9.22847176], [78.79291534, 9.22847176], [78.79291534, 9.22875023], [78.79180908, 9.22875023], [78.79180908, 9.22903061], [78.78901672, 9.22903061], [78.78901672, 9.22875023], [78.78874969, 9.22875023], [78.78874969, 9.22847176], [78.7876358, 9.22847176], [78.7876358, 9.22819424], [78.78736115, 9.22819424], [78.78736115, 9.22791576], [78.78707886, 9.22792053], [78.78707886, 9.22764015], [78.78678894, 9.22764015], [78.78678894, 9.22735977], [78.78652954, 9.22735977], [78.78652954, 9.22708416], [78.7859726, 9.22708416], [78.7859726, 9.22680569], [78.78569794, 9.22681141], [78.78569794, 9.22652054], [78.78541565, 9.22652817], [78.78541565, 9.22624969], [78.78430176, 9.22624969], [78.78430176, 9.22597027], [78.7831955, 9.22597218], [78.7831955, 9.2256937], [78.78180695, 9.2256937], [78.78180695, 9.22541809], [78.78125, 9.22541809], [78.78125, 9.2256937], [78.77986145, 9.2256937], [78.77986145, 9.22541809], [78.7784729, 9.22542095], [78.7784729, 9.22513962], [78.77820587, 9.22513962], [78.77819061, 9.22486019], [78.77708435, 9.2248621], [78.77708435, 9.22458363], [78.7765274, 9.22458363], [78.7765274, 9.22430611], [78.77597046, 9.22431087], [78.77597046, 9.22402954], [78.77540588, 9.22402954], [78.77540588, 9.22348118], [78.77484894, 9.22348118], [78.77484894, 9.22318935], [78.77458191, 9.22319412], [78.77458191, 9.22291565], [78.77401733, 9.22292042], [78.77401733, 9.22264004], [78.77375031, 9.22264004], [78.77375031, 9.22235966], [78.77347565, 9.22236156], [78.77347565, 9.22208405], [78.77263641, 9.22208405], [78.77263641, 9.22180557], [78.77178955, 9.22181034], [78.77178955, 9.22152996], [78.76985931, 9.22152996], [78.76985931, 9.22124958], [78.76875305, 9.22124958], [78.76875305, 9.2209692], [78.76735687, 9.2209692], [78.76735687, 9.22124958], [78.76708221, 9.22124958], [78.76708221, 9.2209692], [78.76625061, 9.22097206], [78.76625061, 9.22069359], [78.76541901, 9.22069359], [78.76541901, 9.22041798], [78.76486206, 9.22042179], [78.76486206, 9.22014046], [78.76431274, 9.22014046], [78.76431274, 9.21986198], [78.76374817, 9.21986198], [78.76374817, 9.21958447], [78.76319122, 9.21958447], [78.76319122, 9.21930599], [78.76290894, 9.2193079], [78.76290894, 9.21903038], [78.76235962, 9.21903038], [78.76235962, 9.21875191], [78.76125336, 9.21875191], [78.76125336, 9.21847057], [78.76069641, 9.21847057], [78.76069641, 9.21819305], [78.76013947, 9.21819305], [78.76013947, 9.2179184], [78.75958252, 9.2179203], [78.75958252, 9.21764183], [78.75875092, 9.21764183], [78.75875092, 9.2173624], [78.75819397, 9.2173624], [78.75819397, 9.21708298], [78.75791931, 9.21708298], [78.75791931, 9.21680546], [78.75763702, 9.21681023], [78.75763702, 9.21652985], [78.75708008, 9.21652985], [78.75708008, 9.21624947], [78.75680542, 9.21624947], [78.75680542, 9.21597099], [78.75624847, 9.21597099], [78.75624847, 9.21569538], [78.75541687, 9.21569538], [78.75541687, 9.21541691], [78.75319672, 9.21541977], [78.75319672, 9.21513939], [78.75096893, 9.21513939], [78.75096893, 9.21486092], [78.75068665, 9.21486092], [78.75068665, 9.21513939], [78.74958038, 9.21513939], [78.74958038, 9.21486092], [78.74930573, 9.21486092], [78.74930573, 9.2145834], [78.74903107, 9.2145834], [78.74903107, 9.21430492], [78.74874878, 9.21430492], [78.74874878, 9.2145834], [78.74791718, 9.2145834], [78.74791718, 9.21430492], [78.74597168, 9.21430969], [78.74597168, 9.21402931], [78.74458313, 9.21402931], [78.74458313, 9.21375084], [78.74430847, 9.21375084], [78.74430847, 9.21347141], [78.74375153, 9.21347332], [78.74375153, 9.21319485], [78.74346924, 9.21319485], [78.74346924, 9.21291733], [78.74318695, 9.21291924], [78.74318695, 9.21264076], [78.74208069, 9.21264076], [78.74208069, 9.21236134], [78.74153137, 9.21236134], [78.74153137, 9.21208286], [78.74097443, 9.21208286], [78.74097443, 9.21180534], [78.74041748, 9.21180534], [78.74041748, 9.21208286], [78.73819733, 9.21208286], [78.73819733, 9.21180534], [78.73542023, 9.21181202], [78.73542023, 9.21154118], [78.73486328, 9.21154118], [78.73486328, 9.21125126], [78.73458099, 9.21125126], [78.73458099, 9.21097088], [78.73347473, 9.21097088], [78.73347473, 9.21069527], [78.7326355, 9.21069527], [78.7326355, 9.21041679], [78.73208618, 9.21042156], [78.73208618, 9.21014118], [78.73124695, 9.21014118], [78.73124695, 9.2098608], [78.73097229, 9.2098608], [78.73097229, 9.20958328], [78.7298584, 9.20958328], [78.7298584, 9.20930481], [78.72930908, 9.20931244], [78.72930908, 9.20903111], [78.72846985, 9.20903111], [78.72846985, 9.20875072], [78.72763824, 9.20875072], [78.72763824, 9.20848179], [78.7270813, 9.20848179], [78.7270813, 9.20818996], [78.72680664, 9.20819473], [78.72680664, 9.20763874], [78.72651672, 9.20764065], [78.72651672, 9.20707989], [78.72624969, 9.20708275], [78.72624969, 9.20680523], [78.72569275, 9.20681095], [78.72569275, 9.20653057], [78.72541809, 9.20653057], [78.72541809, 9.20625114], [78.7251358, 9.20625114], [78.7251358, 9.20597267], [78.72458649, 9.20597267], [78.72458649, 9.20569515], [78.72374725, 9.20569515], [78.72374725, 9.20541668], [78.72319794, 9.20542145], [78.72319794, 9.20514107], [78.72264099, 9.20514107], [78.72264099, 9.20485973], [78.7223587, 9.20485973], [78.7223587, 9.20458221], [78.72208405, 9.20458221], [78.72208405, 9.2043066], [78.72180176, 9.20431137], [78.72180176, 9.20403099], [78.7215271, 9.20403099], [78.7215271, 9.20375061], [78.72097015, 9.20375061], [78.72097015, 9.20347023], [78.7206955, 9.20347214], [78.7206955, 9.20319366], [78.72041321, 9.20319366], [78.72041321, 9.20291615], [78.72013855, 9.20292091], [78.72013855, 9.20264053], [78.71985626, 9.20264053], [78.71985626, 9.20235062], [78.7195816, 9.20236015], [78.7195816, 9.20180416], [78.71930695, 9.20181084], [78.71930695, 9.20153141], [78.71901703, 9.20153141], [78.71901703, 9.20125008], [78.71848297, 9.20125008], [78.71848297, 9.2009697], [78.71819305, 9.2009716], [78.71819305, 9.20069408], [78.7179184, 9.20069408], [78.7179184, 9.20013809], [78.71763611, 9.20014], [78.71763611, 9.19931126], [78.71736145, 9.19931126], [78.71736145, 9.19791985], [78.71763611, 9.19791985], [78.71763611, 9.19764042], [78.71792603, 9.19764042], [78.71792603, 9.19791985], [78.71819305, 9.19791603], [78.71819305, 9.19847202], [78.71847534, 9.19847202], [78.71847534, 9.19819355], [78.71875, 9.19819355], [78.71875, 9.19763756], [78.71930695, 9.19764042], [78.71930695, 9.19748974], [78.71930695, 9.19736195], [78.7195816, 9.19736195], [78.7195816, 9.19708443], [78.71986389, 9.19708443], [78.71986389, 9.19624996], [78.7195816, 9.19624996], [78.7195816, 9.19570065], [78.71930695, 9.1956892], [78.71930695, 9.19291782], [78.71901703, 9.19291973], [78.71901703, 9.19097137], [78.71875, 9.19097137], [78.71875, 9.19041538], [78.71847534, 9.19041538], [78.71847534, 9.19013977], [78.71679688, 9.19014168], [78.71679688, 9.1898613], [78.71486664, 9.1898613], [78.71486664, 9.19014168], [78.71347046, 9.19013977], [78.71347046, 9.19041538], [78.71180725, 9.19041538], [78.71180725, 9.19069576], [78.71097565, 9.19069576], [78.71097565, 9.19097137], [78.7076416, 9.19097137], [78.7076416, 9.19069576], [78.70430756, 9.19069576], [78.70430756, 9.19097137], [78.70375061, 9.19097137], [78.70375061, 9.19124889], [78.70347595, 9.19124889], [78.70347595, 9.19153023], [78.70236206, 9.19153023], [78.70236206, 9.19180965], [78.70202637, 9.19180584], [78.70153046, 9.19180584], [78.70153046, 9.19208431], [78.70069122, 9.19208431], [78.70069122, 9.19236183], [78.70014191, 9.19236183], [78.70014191, 9.1926403], [78.69930267, 9.1926403], [78.69930267, 9.19291973], [78.69875336, 9.19291782], [78.69875336, 9.19319439], [78.69763947, 9.19319057], [78.69763947, 9.19348145], [78.69708252, 9.19347191], [78.69708252, 9.19375038], [78.6965332, 9.19375038], [78.6965332, 9.1940279], [78.69568634, 9.1940279], [78.69568634, 9.19431019], [78.69264221, 9.19430637], [78.69264221, 9.19458389], [78.69152832, 9.19458389], [78.69152832, 9.19486237], [78.69069672, 9.19486046], [78.69069672, 9.19542027], [78.68930817, 9.19541645], [78.68930817, 9.19569397], [78.68708038, 9.19569588], [78.68708038, 9.19597244], [78.68430328, 9.19596958], [78.68430328, 9.19624996], [78.68374634, 9.19624996], [78.68374634, 9.19596958], [78.68068695, 9.19596958], [78.68068695, 9.19624996], [78.68041992, 9.19624996], [78.68041992, 9.19654179], [78.67986298, 9.19654179], [78.67986298, 9.19624996], [78.67930603, 9.19624996], [78.67930603, 9.19654179], [78.67903137, 9.19654179], [78.67903137, 9.19624996], [78.67819214, 9.19624996], [78.67819214, 9.19654179], [78.67764282, 9.19654179], [78.67764282, 9.19681072], [78.67736053, 9.19680595], [78.67736053, 9.19736195], [78.67679596, 9.19736195], [78.67679596, 9.19764042], [78.67430878, 9.19764042], [78.67430878, 9.19736195], [78.67318726, 9.19736195], [78.67318726, 9.19791985], [78.67180634, 9.19791603], [78.67180634, 9.19819355], [78.67124939, 9.19819355], [78.67124939, 9.19847202], [78.67069244, 9.19847202], [78.67069244, 9.19819355], [78.67041779, 9.19819355], [78.67041779, 9.19791603], [78.66986084, 9.19791985], [78.66986084, 9.19764042], [78.66958618, 9.19764042], [78.66958618, 9.19736195], [78.66902924, 9.19736195], [78.66902924, 9.19708443], [78.6673584, 9.19708443], [78.6673584, 9.19680595], [78.66707611, 9.19681072], [78.66707611, 9.19596958], [78.66652679, 9.19597244], [78.66652679, 9.19569588], [78.66625214, 9.19569397], [78.66625214, 9.19513988], [78.66348267, 9.19514179], [78.66348267, 9.19486046], [78.6626358, 9.19486237], [78.6626358, 9.19458389], [78.66236115, 9.19458389], [78.66236115, 9.19430637], [78.66208649, 9.19431019], [78.66208649, 9.1940279], [78.66124725, 9.1940279], [78.66124725, 9.19375038], [78.66041565, 9.19375038], [78.66041565, 9.19347191], [78.6598587, 9.19348145], [78.6598587, 9.19291973], [78.65957642, 9.19291973], [78.65957642, 9.1926403], [78.6590271, 9.1926403], [78.6590271, 9.19236183], [78.65791321, 9.19236183], [78.65791321, 9.19208431], [78.65763855, 9.19208431], [78.65763855, 9.19180584], [78.6570816, 9.19180965], [78.6570816, 9.19124889], [78.65680695, 9.19124889], [78.65680695, 9.19041538], [78.65652466, 9.19041538], [78.65652466, 9.19013977], [78.65625, 9.19014168], [78.65625, 9.1898613], [78.65569305, 9.1898613], [78.65569305, 9.18958282], [78.65513611, 9.18958282], [78.65513611, 9.18930531], [78.65486145, 9.18931007], [78.65486145, 9.18902969], [78.65429688, 9.18902969], [78.65429688, 9.18874931], [78.65402985, 9.18874931], [78.65402985, 9.18819523], [78.65319824, 9.18819523], [78.65319061, 9.18791676], [78.6526413, 9.18791962], [78.6526413, 9.18763924], [78.65235901, 9.18763924], [78.65235901, 9.18735027], [78.65180206, 9.18736076], [78.65180206, 9.18708324], [78.65125275, 9.18708324], [78.65125275, 9.18680477], [78.65097046, 9.18680954], [78.65097046, 9.18653202], [78.6506958, 9.18653202], [78.6506958, 9.18625069], [78.65013885, 9.18625069], [78.65013885, 9.18597126], [78.6498642, 9.18597317], [78.6498642, 9.18569469], [78.64902496, 9.18569469], [78.64902496, 9.18486118], [78.64875031, 9.18486118], [78.64875031, 9.18402672], [78.64848328, 9.18403053], [78.64848328, 9.18375111], [78.64763641, 9.18375111], [78.64763641, 9.18347263], [78.64736176, 9.18347263], [78.64736176, 9.18319511], [78.6470871, 9.18319511], [78.6470871, 9.18291664], [78.64653015, 9.18292141], [78.64653015, 9.18264103], [78.64624786, 9.18264103], [78.64624786, 9.18236065], [78.64597321, 9.18236065], [78.64597321, 9.18180466], [78.64569092, 9.18180943], [78.64569092, 9.18153954], [78.6451416, 9.18153954], [78.6451416, 9.18097115], [78.64485931, 9.18097305], [78.64485931, 9.18069458], [78.64458466, 9.18069458], [78.64458466, 9.1795826], [78.64430237, 9.1795826], [78.64430237, 9.17902565], [78.64402771, 9.17903137], [78.64402771, 9.17875099], [78.64375305, 9.17875099], [78.64375305, 9.17846966], [78.64347076, 9.17847347], [78.64347076, 9.178195], [78.64319611, 9.178195], [78.64319611, 9.17735958], [78.64291382, 9.17735958], [78.64291382, 9.17675018], [78.64291382, 9.17625046], [78.64263916, 9.17625046], [78.64263916, 9.17374992], [78.64235687, 9.17374992], [78.64235687, 9.17346954], [78.64263916, 9.1734724], [78.64263916, 9.17125034], [78.64291382, 9.17125034], [78.64291382, 9.17069435], [78.64319611, 9.17069435], [78.64319611, 9.1693058], [78.64402771, 9.16930962], [78.64402771, 9.16874981], [78.64430237, 9.16874981], [78.64430237, 9.16847229], [78.64458466, 9.16847229], [78.64458466, 9.16819382], [78.6451416, 9.16819382], [78.6451416, 9.1679163], [78.64541626, 9.16792011], [78.64541626, 9.16763973], [78.64569092, 9.16763973], [78.64569092, 9.16736031], [78.64597321, 9.16736221], [78.64597321, 9.16708374], [78.64624786, 9.16708374], [78.64624786, 9.16680622], [78.64679718, 9.16681004], [78.64679718, 9.16652966], [78.6470871, 9.16652966], [78.6470871, 9.16623974], [78.64763641, 9.16625023], [78.64763641, 9.16597176], [78.6479187, 9.16597176], [78.6479187, 9.16569424], [78.64819336, 9.16569424], [78.64819336, 9.16541767], [78.64848328, 9.16541958], [78.64848328, 9.16514015], [78.64875031, 9.16514015], [78.64875031, 9.16486168], [78.64902496, 9.16486168], [78.64902496, 9.16374874], [78.64930725, 9.1637516], [78.64930725, 9.16208076], [78.64958191, 9.16208267], [78.64958191, 9.16152668], [78.64985657, 9.16152954], [78.64985657, 9.16097069], [78.65013885, 9.1609726], [78.65013885, 9.16013908], [78.65040588, 9.16014194], [78.65040588, 9.15986061], [78.6506958, 9.15986061], [78.6506958, 9.15930462], [78.65097046, 9.15931034], [78.65097046, 9.15903187], [78.65180206, 9.15903187], [78.65180206, 9.15875053], [78.65486145, 9.15875053], [78.65486145, 9.15903187], [78.65513611, 9.15903187], [78.65513611, 9.15931034], [78.65764618, 9.15931034], [78.65764618, 9.15875053], [78.65791321, 9.15875053], [78.65791321, 9.15819073], [78.65763855, 9.15819454], [78.65763855, 9.15791702], [78.65735626, 9.15792179], [78.65735626, 9.15764141], [78.6554184, 9.15764141], [78.6554184, 9.15736961], [78.6534729, 9.15736961], [78.6534729, 9.15708065], [78.6515274, 9.15708256], [78.6515274, 9.15680504], [78.64958191, 9.15681171], [78.64958191, 9.15653133], [78.64679718, 9.15653133], [78.64679718, 9.15625095], [78.64402771, 9.15625095], [78.64402771, 9.15597057], [78.64097595, 9.15597343], [78.64097595, 9.15569496], [78.63819122, 9.15569496], [78.63819122, 9.15541744], [78.63540649, 9.15542126], [78.63540649, 9.15514088], [78.63430786, 9.15514088], [78.63430786, 9.15486145], [78.63346863, 9.15486145], [78.63346863, 9.15458298], [78.63236237, 9.15458298], [78.63236237, 9.15430546], [78.63124847, 9.15430546], [78.63124847, 9.15402889], [78.63014221, 9.15402889], [78.63014221, 9.15375137], [78.62930298, 9.15375137], [78.62930298, 9.1534729], [78.62819672, 9.1534729], [78.62819672, 9.15319538], [78.62679291, 9.15319538], [78.62596893, 9.15319538], [78.62596893, 9.1534729], [78.62541962, 9.1534729], [78.62541962, 9.15375137], [78.62458038, 9.15375137], [78.62458038, 9.15402889], [78.62374878, 9.15402889], [78.62374878, 9.15430546], [78.62291718, 9.15430546], [78.62291718, 9.15402889], [78.6220932, 9.15402889], [78.6220932, 9.15375137], [78.62264252, 9.15375137], [78.62264252, 9.1534729], [78.62236023, 9.1534729], [78.62236023, 9.15319538], [78.62180328, 9.15319538], [78.62180328, 9.1534729], [78.62069702, 9.1534729], [78.62069702, 9.15319538], [78.61985779, 9.15319538], [78.61985779, 9.15291691], [78.61902618, 9.15292072], [78.61902618, 9.1526413], [78.61847687, 9.1526413], [78.61847687, 9.15236092], [78.6159668, 9.15236092], [78.6159668, 9.15207958], [78.61430359, 9.1520834], [78.61430359, 9.15152645], [78.61402893, 9.15153122], [78.61402893, 9.1512394], [78.61347198, 9.15125084], [78.61347198, 9.15097332], [78.61264038, 9.15097332], [78.61264038, 9.15069485], [78.61208344, 9.15069485], [78.61208344, 9.15041637], [78.61180878, 9.15042114], [78.61180878, 9.1501379], [78.61152649, 9.1501379], [78.61152649, 9.14986038], [78.60986328, 9.14986038], [78.60986328, 9.14958477], [78.60847473, 9.14958191], [78.60847473, 9.14930439], [78.60764313, 9.14931107], [78.60764313, 9.14903069], [78.60708618, 9.14903069], [78.60708618, 9.14875031], [78.60624695, 9.14875031], [78.60624695, 9.14847183], [78.60514069, 9.14847183], [78.60514069, 9.14819431], [78.6048584, 9.14820099], [78.6048584, 9.14792061], [78.60430908, 9.14792061], [78.60430908, 9.14764023], [78.60375214, 9.14764023], [78.60375214, 9.14735985], [78.60319519, 9.14735985], [78.60319519, 9.14708424], [78.60236359, 9.14708424], [78.60236359, 9.14680576], [78.60124969, 9.14681053], [78.60124969, 9.14653111], [78.60069275, 9.14653111], [78.60069275, 9.14624977], [78.60041046, 9.14624977], [78.60041046, 9.14597034], [78.6001358, 9.14597225], [78.6001358, 9.14569378], [78.5993042, 9.14569378], [78.5993042, 9.14541626], [78.59874725, 9.14542961], [78.59874725, 9.14513969], [78.5984726, 9.14513969], [78.5984726, 9.14486027], [78.59791565, 9.14486217], [78.59791565, 9.1445837], [78.59708405, 9.1445837], [78.59708405, 9.14430618], [78.59597015, 9.14431095], [78.59597015, 9.14402962], [78.59570313, 9.14402962], [78.59570313, 9.14375019], [78.59541321, 9.14375019], [78.59541321, 9.14347172], [78.59486389, 9.14347172], [78.59486389, 9.1431942], [78.5945816, 9.1431942], [78.5945816, 9.14291573], [78.59401703, 9.14291954], [78.59401703, 9.14264011], [78.59348297, 9.14264011], [78.59348297, 9.14235973], [78.59319305, 9.14235973], [78.59319305, 9.14208412], [78.59263611, 9.14208412], [78.59263611, 9.14180565], [78.59179687, 9.14181042], [78.59179687, 9.14153004], [78.59153748, 9.14153004], [78.59153748, 9.14124966], [78.59124756, 9.14124966], [78.59124756, 9.14096928], [78.59069824, 9.14097214], [78.59069061, 9.14069366], [78.59041595, 9.14069366], [78.59041595, 9.14041805], [78.5901413, 9.14041996], [78.5901413, 9.14013958], [78.58985901, 9.14013958], [78.58985901, 9.13986015], [78.58930206, 9.13986206], [78.58930206, 9.13958359], [78.5890274, 9.13958359], [78.5890274, 9.13930607], [78.58875275, 9.13930607], [78.58875275, 9.1390276], [78.58847046, 9.13903046], [78.58847046, 9.13875198], [78.58790588, 9.13875198], [78.58790588, 9.1384716], [78.5873642, 9.1384716], [78.5873642, 9.13791847], [78.58653259, 9.13792038], [78.58653259, 9.13764191], [78.58625031, 9.13764191], [78.58625031, 9.13696003], [78.58625031, 9.13680458], [78.58598328, 9.1368103], [78.58598328, 9.13653183], [78.58513641, 9.13653183], [78.58513641, 9.13626099], [78.58486176, 9.13626099], [78.58486176, 9.13597107], [78.58403015, 9.13597107], [78.58403015, 9.13569641], [78.58319092, 9.13569641], [78.58319092, 9.13513947], [78.58291626, 9.13513947], [78.58291626, 9.13486099], [78.5826416, 9.13486099], [78.5826416, 9.13458347], [78.58235931, 9.13458347], [78.58235931, 9.13402653], [78.58207703, 9.13402939], [78.58207703, 9.13347054], [78.58180237, 9.1334734], [78.58180237, 9.13319492], [78.58069611, 9.13319969], [78.58069611, 9.13292027], [78.58040619, 9.13292027], [78.58040619, 9.13236141], [78.58013916, 9.13236141], [78.58013916, 9.13208294], [78.5798645, 9.13208294], [78.5798645, 9.13180542], [78.57875061, 9.13181019], [78.57875061, 9.13153172], [78.57818604, 9.13153172], [78.57818604, 9.13125134], [78.57736206, 9.13125134], [78.57736206, 9.13153172], [78.57569122, 9.13153172], [78.57569122, 9.13181019], [78.57514191, 9.13180542], [78.57514191, 9.13208294], [78.57491302, 9.13208294], [78.57430267, 9.13208294], [78.57430267, 9.13236141], [78.57375336, 9.13236141], [78.57375336, 9.13264084], [78.57290649, 9.13264084], [78.57290649, 9.13292027], [78.57235718, 9.13292027], [78.57235718, 9.13319969], [78.57152557, 9.13319492], [78.57152557, 9.1334734], [78.57068634, 9.13347054], [78.57068634, 9.13375092], [78.57013702, 9.13375092], [78.57013702, 9.13402939], [78.56931305, 9.13402939], [78.56931305, 9.13430977], [78.56874847, 9.134305], [78.56874847, 9.13458347], [78.56764221, 9.13458347], [78.56764221, 9.134305], [78.56652832, 9.134305], [78.56652832, 9.13458347], [78.56624603, 9.13458061], [78.56624603, 9.13513947], [78.56458282, 9.13513947], [78.56458282, 9.13541985], [78.56402588, 9.13541698], [78.56402588, 9.13569641], [78.56319427, 9.13569641], [78.56319427, 9.13597107], [78.56263733, 9.13597107], [78.56263733, 9.13626099], [78.56208038, 9.13626099], [78.56208038, 9.13653183], [78.56014252, 9.13653183], [78.56014252, 9.13626099], [78.55986023, 9.13626099], [78.55986023, 9.13653183], [78.5595932, 9.13653183], [78.5595932, 9.1368103], [78.55680847, 9.13680458], [78.55680847, 9.13708401], [78.55458069, 9.13708401], [78.55458069, 9.13736153], [78.55347443, 9.13736153], [78.55347443, 9.13708401], [78.55236053, 9.13708401], [78.55236053, 9.13736153], [78.54875183, 9.13736153], [78.54875183, 9.13764191], [78.54846954, 9.13764191], [78.54846954, 9.13736153], [78.54541779, 9.13736153], [78.54541779, 9.13708401], [78.54402924, 9.13708401], [78.54402924, 9.13736153], [78.54347229, 9.13736153], [78.54347229, 9.13708401], [78.5404129, 9.13708401], [78.5404129, 9.13736153], [78.53874969, 9.13736153], [78.53874969, 9.13708401], [78.53791809, 9.13708401], [78.53791809, 9.13680458], [78.5376358, 9.1368103], [78.5376358, 9.13653183], [78.53679657, 9.13653183], [78.53679657, 9.1368103], [78.53542328, 9.1368103], [78.53542328, 9.13653183], [78.53151703, 9.13653183], [78.53151703, 9.13626099], [78.53098297, 9.13626099], [78.53098297, 9.13653183], [78.5304184, 9.13653183], [78.5304184, 9.13626099], [78.52902985, 9.13626099], [78.52902985, 9.13597107], [78.52458191, 9.13597107], [78.52458191, 9.13626099], [78.52403259, 9.13626099], [78.52403259, 9.13653183], [78.52375031, 9.13653183], [78.52375031, 9.13626099], [78.52179718, 9.13626099], [78.52179718, 9.13653183], [78.52097321, 9.13653183], [78.52097321, 9.13626099], [78.5201416, 9.13626099], [78.5201416, 9.13597107], [78.51957703, 9.13597107], [78.51957703, 9.13626099], [78.51875305, 9.13626099], [78.51875305, 9.13597107], [78.51791382, 9.13597107], [78.51791382, 9.13569641], [78.51708221, 9.13569641], [78.51708221, 9.13597107], [78.51652527, 9.13597107], [78.51652527, 9.13569641], [78.51430511, 9.13569641], [78.51430511, 9.13541698], [78.51319122, 9.13541985], [78.51319122, 9.13513947], [78.51040649, 9.13513947], [78.51040649, 9.13486099], [78.50985718, 9.13486099], [78.50985718, 9.13458061], [78.50846863, 9.13458347], [78.50846863, 9.134305], [78.50763702, 9.13430977], [78.50763702, 9.13402939], [78.50708771, 9.13402939], [78.50708771, 9.13375092], [78.50681305, 9.13375092], [78.50681305, 9.13347054], [78.50514221, 9.1334734], [78.50514221, 9.13319492], [78.50374603, 9.13319969], [78.50374603, 9.13292027], [78.5029068, 9.13292027], [78.5029068, 9.13264084], [78.50208282, 9.13264084], [78.50208282, 9.13236141], [78.50041962, 9.13236141], [78.50041962, 9.13208294], [78.49958038, 9.13208294], [78.49958038, 9.13180542], [78.49874878, 9.13181019], [78.49874878, 9.13153172], [78.49819183, 9.13153172], [78.49819183, 9.13125134], [78.49624634, 9.13125134], [78.49624634, 9.13097095], [78.49541473, 9.13097095], [78.49541473, 9.13069534], [78.49485779, 9.13069534], [78.49485779, 9.13041687], [78.49430847, 9.13042164], [78.49430847, 9.13012981], [78.49319458, 9.13013935], [78.49319458, 9.12986088], [78.49180603, 9.12986088], [78.49180603, 9.12958336], [78.49124908, 9.12958336], [78.49124908, 9.12930489], [78.49069214, 9.12931156], [78.49069214, 9.12903118], [78.49014282, 9.12903118], [78.49014282, 9.12874889], [78.48986053, 9.12874889], [78.48986053, 9.12847328], [78.48819733, 9.12847328], [78.48819733, 9.12819481], [78.48735809, 9.12819481], [78.48735809, 9.12847328], [78.48625183, 9.12847328], [78.48625183, 9.12819481], [78.48569489, 9.12819481], [78.48569489, 9.12791729], [78.48401642, 9.1279192], [78.48401642, 9.12874889], [78.48430634, 9.12874889], [78.48430634, 9.12903118], [78.48458099, 9.12903118], [78.48458099, 9.12874889], [78.48680878, 9.12874889], [78.48680878, 9.12931156], [78.48707581, 9.12931156], [78.48707581, 9.12986088], [78.48735809, 9.12986088], [78.48735809, 9.13125134], [78.48764038, 9.13125134], [78.48764038, 9.13181019], [78.48791504, 9.13180542], [78.48791504, 9.13208294], [78.48819733, 9.13208294], [78.48819733, 9.13236141], [78.48847198, 9.13236141], [78.48847198, 9.13264084], [78.48874664, 9.13264084], [78.48874664, 9.13292027], [78.4890213, 9.13292027], [78.4890213, 9.13513947], [78.48874664, 9.13513947], [78.48874664, 9.13569641], [78.4890213, 9.13569069], [78.4890213, 9.13792038], [78.48930359, 9.13791847], [78.48930359, 9.1384716], [78.48958588, 9.1384716], [78.48958588, 9.14124966], [78.48986053, 9.14124966], [78.48986053, 9.14235973], [78.49013519, 9.14235973], [78.49013519, 9.1431942], [78.48986053, 9.1431942], [78.48986053, 9.14347172], [78.49013519, 9.14347172], [78.49013519, 9.14375019], [78.49041748, 9.14375019], [78.49041748, 9.14431095], [78.49069214, 9.14430618], [78.49069214, 9.14486217], [78.49041748, 9.14486027], [78.49041748, 9.14513969], [78.49014282, 9.14513969], [78.49014282, 9.14624977], [78.49041748, 9.14624977], [78.49041748, 9.14820099], [78.49014282, 9.14820099], [78.49014282, 9.14903069], [78.48986053, 9.14902782], [78.48986053, 9.1501379], [78.48874664, 9.1501379], [78.48874664, 9.14958477], [78.48847198, 9.14958191], [78.48847198, 9.14930439], [78.48819733, 9.14931107], [78.48819733, 9.14820099], [78.48847198, 9.14820099], [78.48847198, 9.14764023], [78.48874664, 9.14764023], [78.48874664, 9.14708042], [78.48902893, 9.14708424], [78.48902893, 9.14652824], [78.48929596, 9.14653111], [78.48929596, 9.14542961], [78.48874664, 9.14542961], [78.48874664, 9.14458179], [78.48847198, 9.1445837], [78.48847198, 9.14402771], [78.48874664, 9.14402962], [78.48874664, 9.14318943], [78.48847198, 9.1431942], [78.48847198, 9.14152813], [78.48819733, 9.14153004], [78.48819733, 9.14096928], [78.48791504, 9.14097214], [78.48791504, 9.13875008], [78.48764038, 9.13875198], [78.48764038, 9.13819122], [78.48735809, 9.13819313], [78.48735809, 9.13708401], [78.48708344, 9.13708401], [78.48708344, 9.13652706], [78.48652649, 9.13653183], [78.48652649, 9.13626099], [78.48596191, 9.13626099], [78.48596191, 9.13653183], [78.48486328, 9.13653183], [78.48486328, 9.13597107], [78.48458099, 9.13597107], [78.48458099, 9.13541698], [78.48430634, 9.13541985], [78.48430634, 9.13513947], [78.48291779, 9.13513947], [78.48291779, 9.13541985], [78.48208618, 9.13541985], [78.48208618, 9.13486099], [78.4826355, 9.13486099], [78.4826355, 9.134305], [78.48236084, 9.13430977], [78.48236084, 9.13402939], [78.48264313, 9.13402939], [78.48264313, 9.13264084], [78.48236084, 9.13264084], [78.48236084, 9.13236141], [78.48208618, 9.13236141], [78.48208618, 9.13180542], [78.48152924, 9.13181019], [78.48152924, 9.13153172], [78.48124695, 9.13153172], [78.48124695, 9.13125134], [78.48069763, 9.13125134], [78.48069763, 9.13097095], [78.48041534, 9.13097095], [78.48041534, 9.13041687], [78.48014832, 9.13042164], [78.48014832, 9.12931156], [78.48097229, 9.12930489], [78.48097229, 9.12958336], [78.48180389, 9.12958336], [78.48180389, 9.12930489], [78.48208618, 9.12931156], [78.48208618, 9.12764072], [78.48179626, 9.12764072], [78.48179626, 9.1273613], [78.48041534, 9.1273613], [78.48041534, 9.12708282], [78.4798584, 9.12708282], [78.4798584, 9.1273613], [78.47819519, 9.1273613], [78.47819519, 9.12708282], [78.4779129, 9.12708282], [78.4779129, 9.1273613], [78.47735596, 9.1273613], [78.47735596, 9.12764072], [78.47624969, 9.12764072], [78.47624969, 9.1279192], [78.47569275, 9.1279192], [78.47569275, 9.12764072], [78.47541809, 9.12764072], [78.47541809, 9.1273613], [78.4706955, 9.1273613], [78.4706955, 9.12708282], [78.46485901, 9.12708282], [78.46485901, 9.12680531], [78.46180725, 9.12680531], [78.46180725, 9.12708282], [78.46097565, 9.12708282], [78.46097565, 9.12680531], [78.4604187, 9.12681103], [78.4604187, 9.12653065], [78.4576416, 9.12653065], [78.4576416, 9.12625122], [78.45735931, 9.12625122], [78.45735931, 9.12597275], [78.45652771, 9.12597275], [78.45652771, 9.12569523], [78.45625305, 9.12569523], [78.45625305, 9.12541676], [78.45597839, 9.12542057], [78.45597839, 9.12514114], [78.45513916, 9.12514114], [78.45513916, 9.1248579], [78.4548645, 9.12486076], [78.4548645, 9.12458229], [78.45430756, 9.12458229], [78.45430756, 9.12486076], [78.4540329, 9.1248579], [78.4540329, 9.12514114], [78.45318604, 9.12514114], [78.45318604, 9.1248579], [78.45207977, 9.12486076], [78.45207977, 9.12458229], [78.45153046, 9.12458229], [78.45153046, 9.12430668], [78.45096588, 9.12432003], [78.45096588, 9.12403107], [78.45041656, 9.12403107], [78.45041656, 9.12375069], [78.44985199, 9.12375069], [78.44985199, 9.12347031], [78.44763947, 9.12347317], [78.44763947, 9.12319374], [78.44708252, 9.12319374], [78.44708252, 9.12291622], [78.44625092, 9.12292099], [78.44625092, 9.12264061], [78.44513702, 9.12264061], [78.44513702, 9.12236023], [78.44403076, 9.12236023], [78.44403076, 9.12208462], [78.44319153, 9.12208462], [78.44319153, 9.12236023], [78.44291687, 9.12236023], [78.44291687, 9.12208462], [78.44208527, 9.12208462], [78.44208527, 9.12180424], [78.44124603, 9.12181091], [78.44124603, 9.12153053], [78.44013977, 9.12153053], [78.44013977, 9.1212616], [78.43930817, 9.1212616], [78.43930817, 9.12096977], [78.43846893, 9.12097168], [78.43846893, 9.12069416], [78.43736267, 9.12069416], [78.43736267, 9.12041569], [78.43653107, 9.12042141], [78.43653107, 9.12014008], [78.43569183, 9.12014008], [78.43569183, 9.1198597], [78.43458557, 9.1198597], [78.43458557, 9.11958218], [78.43347168, 9.11958218], [78.43347168, 9.11930561], [78.43264008, 9.11931133], [78.43264008, 9.11903], [78.43180847, 9.11903], [78.43180847, 9.11874962], [78.43096924, 9.11874962], [78.43096924, 9.11847019], [78.43013763, 9.1184721], [78.43013763, 9.11819363], [78.42986298, 9.11819363], [78.42986298, 9.11791611], [78.42958069, 9.11792088], [78.42958069, 9.11763954], [78.42903137, 9.11763954], [78.42903137, 9.11736202], [78.42791748, 9.11736202], [78.42791748, 9.11763954], [78.42736053, 9.11763954], [78.42736053, 9.11736202], [78.42541504, 9.11736202], [78.42541504, 9.11708355], [78.42514038, 9.11708355], [78.42514038, 9.11652756], [78.42375183, 9.11653042], [78.42375183, 9.11625004], [78.42346954, 9.11625004], [78.42346954, 9.11596966], [78.42263794, 9.11597157], [78.42263794, 9.11569405], [78.42236328, 9.11569405], [78.42236328, 9.11541557], [78.42180634, 9.11542034], [78.42180634, 9.11513138], [78.42124939, 9.11513996], [78.42124939, 9.11486244], [78.42069244, 9.11486244], [78.42069244, 9.11458397], [78.41958618, 9.11458397], [78.41958618, 9.11430645], [78.41902924, 9.11431026], [78.41902924, 9.11403179], [78.41847229, 9.11403179], [78.41847229, 9.11375046], [78.41819763, 9.11375046], [78.41819763, 9.11347198], [78.41791534, 9.11347198], [78.41791534, 9.11319447], [78.41708374, 9.11319447], [78.41708374, 9.11347198], [78.41652679, 9.11347198], [78.41652679, 9.11319447], [78.41596985, 9.11319447], [78.41596985, 9.1129179], [78.4154129, 9.1129179], [78.4154129, 9.11264038], [78.41401672, 9.11264038], [78.41401672, 9.11236191], [78.41374207, 9.11236191], [78.41374207, 9.11180973], [78.41347504, 9.11180592], [78.41347504, 9.11208439], [78.41152954, 9.11208439], [78.41152954, 9.11180592], [78.41069794, 9.11180973], [78.41069794, 9.11125183], [78.41042328, 9.11125183], [78.41042328, 9.11097145], [78.41014099, 9.11097145], [78.41014099, 9.11069584], [78.4098587, 9.11069584], [78.4098587, 9.11041546], [78.40930176, 9.11042023], [78.40930176, 9.11013985], [78.40875244, 9.11013985], [78.40875244, 9.10986233], [78.40847015, 9.10986233], [78.40847015, 9.10902691], [78.40820313, 9.10902977], [78.40820313, 9.10847092], [78.40791321, 9.10847092], [78.40791321, 9.1081953], [78.40763855, 9.1081953], [78.40763855, 9.10791683], [78.40735626, 9.10791969], [78.40735626, 9.10763931], [78.4070816, 9.10763931], [78.4070816, 9.10791969], [78.40680695, 9.10791969], [78.40680695, 9.10763931], [78.40569305, 9.10763931], [78.40569305, 9.10736084], [78.4054184, 9.10736084], [78.4054184, 9.10708141], [78.40486145, 9.10708332], [78.40486145, 9.10680485], [78.40458679, 9.10680962], [78.40458679, 9.10652924], [78.40429688, 9.10652924], [78.40429688, 9.10625076], [78.40402985, 9.10625076], [78.40402985, 9.10597134], [78.4034729, 9.10597324], [78.4034729, 9.10569477], [78.40319824, 9.10569477], [78.40319061, 9.10541725], [78.40291595, 9.10542202], [78.40291595, 9.10514069], [78.40235901, 9.10514069], [78.40235901, 9.10486126], [78.40208435, 9.10486126], [78.40208435, 9.10458279], [78.40125275, 9.10458279], [78.40125275, 9.10430527], [78.4006958, 9.10431194], [78.4006958, 9.10403061], [78.40040588, 9.10403061], [78.40040588, 9.10375118], [78.40013885, 9.10375118], [78.40013885, 9.10347271], [78.3998642, 9.1034708], [78.3998642, 9.10319519], [78.39930725, 9.10319519], [78.39930725, 9.10291672], [78.39874268, 9.10292244], [78.39874268, 9.10264111], [78.39848328, 9.10264111], [78.39848328, 9.10236073], [78.39819336, 9.10236073], [78.39819336, 9.10180855], [78.3979187, 9.10180855], [78.3979187, 9.10153103], [78.39653015, 9.10153103], [78.39653015, 9.10125065], [78.39624786, 9.10125065], [78.39624786, 9.10097122], [78.39597321, 9.10097313], [78.39597321, 9.10069466], [78.39569092, 9.10069466], [78.39569092, 9.10041714], [78.39541626, 9.10042095], [78.39541626, 9.10013199], [78.3951416, 9.10013866], [78.3951416, 9.09986115], [78.39485931, 9.09986115], [78.39485931, 9.09958267], [78.39458466, 9.09958267], [78.39458466, 9.09930515], [78.39402771, 9.09931087], [78.39402771, 9.09903145], [78.39319611, 9.09903145], [78.39319611, 9.09846973], [78.39291382, 9.0984726], [78.39291382, 9.09819508], [78.39263916, 9.09819508], [78.39263916, 9.0979166], [78.39235687, 9.09792137], [78.39235687, 9.09764099], [78.39208221, 9.09764099], [78.39208221, 9.09735966], [78.39152527, 9.09735966], [78.39152527, 9.09708214], [78.39125061, 9.09709167], [78.39125061, 9.09681129], [78.39068604, 9.09681129], [78.39068604, 9.09625053], [78.39013672, 9.09625053], [78.39013672, 9.09597015], [78.38957977, 9.09597206], [78.38957977, 9.09569359], [78.38930511, 9.09569359], [78.38930511, 9.09541607], [78.38903046, 9.09542084], [78.38903046, 9.09514141], [78.38874817, 9.09514141], [78.38874817, 9.09486008], [78.38846588, 9.09486008], [78.38846588, 9.0945797], [78.38791656, 9.09458447], [78.38791656, 9.09430599], [78.38735962, 9.09430885], [78.38735962, 9.09403133], [78.38709259, 9.09403133], [78.38709259, 9.09375], [78.38680267, 9.09375], [78.38680267, 9.09346962], [78.38625336, 9.09347153], [78.38625336, 9.09319401], [78.38569641, 9.09319401], [78.38569641, 9.09291553], [78.38540649, 9.09292126], [78.38540649, 9.09263992], [78.38513947, 9.09263992], [78.38513947, 9.09235954], [78.38486481, 9.0923624], [78.38486481, 9.09208202], [78.38458252, 9.09208202], [78.38458252, 9.09180641], [78.3840332, 9.09181118], [78.3840332, 9.09152985], [78.38375854, 9.09152985], [78.38375854, 9.09125042], [78.38346863, 9.09125042], [78.38346863, 9.09097195], [78.38291931, 9.09097195], [78.38291931, 9.09069443], [78.38263702, 9.09069443], [78.38263702, 9.09041595], [78.38208008, 9.09041977], [78.38208008, 9.09014034], [78.38181305, 9.09014034], [78.38181305, 9.08985996], [78.38153076, 9.08985996], [78.38153076, 9.08958435], [78.38097382, 9.08958435], [78.38097382, 9.08930588], [78.38069916, 9.08931065], [78.38069916, 9.08903027], [78.38041687, 9.08903027], [78.38041687, 9.08875179], [78.38014221, 9.08875179], [78.38014221, 9.08847046], [78.37985992, 9.08847237], [78.37985992, 9.0882206], [78.37985992, 9.08791637], [78.3795929, 9.08792019], [78.3795929, 9.08763981], [78.37902832, 9.08763981], [78.37902832, 9.08736229], [78.37847137, 9.08736229], [78.37847137, 9.08708382], [78.37819672, 9.08708382], [78.37819672, 9.0868063], [78.37763214, 9.08681011], [78.37763214, 9.08652973], [78.37718964, 9.08652973], [78.37708282, 9.08652973], [78.37708282, 9.08625031], [78.37680817, 9.08625031], [78.37680817, 9.08597183], [78.37652588, 9.08597183], [78.37652588, 9.08569431], [78.37625122, 9.08569431], [78.37625122, 9.08541775], [78.37596893, 9.08541965], [78.37596893, 9.08515072], [78.37542725, 9.08515072], [78.37541962, 9.08485889], [78.37513733, 9.08486176], [78.37513733, 9.08458424], [78.3747406, 9.08458424], [78.37458038, 9.08458424], [78.37458038, 9.08446121], [78.37458038, 9.08430576], [78.37430573, 9.08430576], [78.37430573, 9.08422565], [78.37430573, 9.08402824], [78.3740387, 9.08403015], [78.37374878, 9.08403015], [78.37374878, 9.08377171], [78.37403107, 9.08375168], [78.37403107, 9.0834713], [78.37374878, 9.0834713], [78.37374878, 9.08319569], [78.37347412, 9.08319569], [78.37347412, 9.08291531], [78.37291718, 9.08292198], [78.37291718, 9.08263969], [78.37229156, 9.08263969], [78.3720932, 9.08263969], [78.37208557, 9.08248043], [78.37208557, 9.08236122], [78.37194061, 9.08236122], [78.37180328, 9.08236122], [78.37180328, 9.08224964], [78.37180328, 9.08208275], [78.37158966, 9.08209038], [78.37152863, 9.08181], [78.37124634, 9.08181], [78.37124634, 9.08152962], [78.37097168, 9.08152962], [78.37097168, 9.08097076], [78.37014008, 9.08097267], [78.37014008, 9.08124924], [78.36985779, 9.08124924], [78.36985779, 9.08152962], [78.36958313, 9.08152962], [78.36958313, 9.08209038], [78.36930847, 9.08208275], [78.36930847, 9.08236122], [78.36846924, 9.08235931], [78.36846924, 9.08263969], [78.36819458, 9.08263969], [78.36819458, 9.08319569], [78.36791992, 9.08319569], [78.36791992, 9.0834713], [78.36736298, 9.0834713], [78.36736298, 9.08375168], [78.36708069, 9.08374882], [78.36708069, 9.08415985], [78.36708069, 9.08430958], [78.36680603, 9.08430576], [78.36680603, 9.08458424], [78.36624908, 9.08458424], [78.36624908, 9.08486176], [78.36569214, 9.08485889], [78.36569214, 9.08515072], [78.36541748, 9.08515072], [78.36541748, 9.08541965], [78.36513519, 9.08541775], [78.36513519, 9.08569431], [78.36486053, 9.08569431], [78.36486053, 9.08597183], [78.36458588, 9.08597183], [78.36458588, 9.08652973], [78.36429596, 9.08652973], [78.36429596, 9.08681011], [78.36402893, 9.0868063], [78.36402893, 9.08708382], [78.36374664, 9.08708382], [78.36374664, 9.08763981], [78.36347198, 9.08763981], [78.36347198, 9.08819389], [78.36374664, 9.08819389], [78.36374664, 9.08847237], [78.36402893, 9.08847046], [78.36402893, 9.08903027], [78.36429596, 9.08903027], [78.36429596, 9.08931065], [78.36458588, 9.08930588], [78.36458588, 9.08958435], [78.36513519, 9.08958435], [78.36513519, 9.08985996], [78.36541748, 9.08985996], [78.36541748, 9.09014034], [78.36569214, 9.09014034], [78.36569214, 9.09041977], [78.36597443, 9.09041595], [78.36597443, 9.09069443], [78.36624908, 9.09069443], [78.36624908, 9.09125042], [78.36653137, 9.09125042], [78.36653137, 9.0923624], [78.36597443, 9.0923624], [78.36597443, 9.09208202], [78.36541748, 9.09208202], [78.36541748, 9.09180641], [78.36514282, 9.09181118], [78.36514282, 9.09125042], [78.36486053, 9.09125042], [78.36486053, 9.09097195], [78.36458588, 9.09097195], [78.36458588, 9.09069443], [78.36430359, 9.09069443], [78.36430359, 9.09041595], [78.36402893, 9.09041977], [78.36402893, 9.09014034], [78.36374664, 9.09014034], [78.36374664, 9.08985996], [78.36347198, 9.08985996], [78.36347198, 9.08930588], [78.36319733, 9.08931065], [78.36319733, 9.08903027], [78.36292267, 9.08903027], [78.36292267, 9.08875179], [78.36263275, 9.08875179], [78.36263275, 9.08708191], [78.36235809, 9.08708382], [78.36235809, 9.0868063], [78.36263275, 9.08681011], [78.36263275, 9.08597183], [78.36291504, 9.08597183], [78.36290741, 9.08535862], [78.36319733, 9.08541965], [78.36319733, 9.08528137], [78.36319733, 9.08514023], [78.36347198, 9.08515072], [78.36347198, 9.08458138], [78.36374664, 9.08458424], [78.36374664, 9.08430576], [78.36429596, 9.08430958], [78.36429596, 9.08375168], [78.36458588, 9.08375168], [78.36458588, 9.08319092], [78.36486053, 9.08319569], [78.36486053, 9.08291531], [78.36514282, 9.08292198], [78.36514282, 9.08235931], [78.36541748, 9.08236122], [78.36541748, 9.08180523], [78.36569214, 9.08181], [78.36569214, 9.08124924], [78.36597443, 9.08124924], [78.3659668, 9.08097076], [78.36624908, 9.08097076], [78.36624908, 9.08041668], [78.36653137, 9.08041954], [78.36653137, 9.08014202], [78.36680603, 9.08014202], [78.36680603, 9.07986069], [78.36708069, 9.07986069], [78.36708069, 9.07913017], [78.36708069, 9.07902718], [78.36736298, 9.07902718], [78.36736298, 9.07819462], [78.36763763, 9.07819462], [78.36763763, 9.0779171], [78.36736298, 9.07792187], [78.36736298, 9.07764053], [78.36708069, 9.07764053], [78.36708069, 9.07736111], [78.36680603, 9.07736111], [78.36680603, 9.07708263], [78.36653137, 9.07708263], [78.36653137, 9.07680511], [78.36624908, 9.07681179], [78.36624908, 9.07653141], [78.3659668, 9.07653141], [78.3659668, 9.07625103], [78.36541748, 9.07625103], [78.36541748, 9.07595921], [78.36513519, 9.07597256], [78.36513519, 9.07569504], [78.36486053, 9.07569504], [78.36486053, 9.07541656], [78.36458588, 9.07542133], [78.36458588, 9.07514095], [78.36429596, 9.07514095], [78.36429596, 9.07486057], [78.36402893, 9.07486057], [78.36402893, 9.07458305], [78.36374664, 9.07458305], [78.36374664, 9.07430458], [78.36347198, 9.07430935], [78.36347198, 9.07403088], [78.36319733, 9.07403088], [78.36319733, 9.07375145], [78.36263275, 9.07375145], [78.36263275, 9.07347107], [78.36235809, 9.07347298], [78.36235809, 9.07319546], [78.36208344, 9.07319546], [78.36208344, 9.07291698], [78.36180878, 9.07291889], [78.36180878, 9.07264137], [78.36152649, 9.07264137], [78.36152649, 9.07236099], [78.36125183, 9.07236099], [78.36125183, 9.07208347], [78.36096954, 9.07208347], [78.36096954, 9.07180691], [78.36068726, 9.07181072], [78.36068726, 9.0715313], [78.36042023, 9.0715313], [78.36042023, 9.07125092], [78.36013794, 9.07125092], [78.36013794, 9.07096958], [78.35986328, 9.0709734], [78.35986328, 9.07069492], [78.35958099, 9.07069492], [78.35958099, 9.0704174], [78.35901642, 9.07042122], [78.35901642, 9.07015038], [78.35874939, 9.07015038], [78.35874939, 9.06986046], [78.35847473, 9.06986046], [78.35847473, 9.06958199], [78.35819244, 9.06958199], [78.35819244, 9.06930447], [78.35791779, 9.06931114], [78.35791779, 9.06902885], [78.35764313, 9.06902885], [78.35764313, 9.06875038], [78.35708618, 9.06875038], [78.35708618, 9.06847191], [78.35680389, 9.06847191], [78.35680389, 9.06819439], [78.35652924, 9.06819439], [78.35652924, 9.0676384], [78.35624695, 9.06764126], [78.35624695, 9.06735992], [78.35597229, 9.06735992], [78.35597229, 9.06708431], [78.35541534, 9.06708431], [78.35541534, 9.06680584], [78.35514069, 9.06681061], [78.35514069, 9.06653118], [78.3548584, 9.06653118], [78.3548584, 9.06624985], [78.35430908, 9.06624985], [78.35430908, 9.06597233], [78.35402679, 9.06597233], [78.35402679, 9.06569386], [78.35375214, 9.06569386], [78.35375214, 9.06513786], [78.35346222, 9.06513977], [78.35346222, 9.06486034], [78.35319519, 9.06486225], [78.35319519, 9.06458378], [78.35263824, 9.06458378], [78.35263824, 9.06430626], [78.35235596, 9.06431103], [78.35235596, 9.06375027], [78.35180664, 9.06375027], [78.35180664, 9.06347179], [78.35152435, 9.06347179], [78.35152435, 9.06319427], [78.35124969, 9.06319427], [78.35124969, 9.0629158], [78.35098267, 9.06291962], [78.35098267, 9.06264019], [78.35069275, 9.06264019], [78.35069275, 9.06235981], [78.35041809, 9.06235981], [78.35041809, 9.0620842], [78.3501358, 9.0620842], [78.3501358, 9.06180573], [78.34958649, 9.06181145], [78.34958649, 9.06124973], [78.34929657, 9.06124973], [78.34929657, 9.0609808], [78.34902954, 9.0609808], [78.34902954, 9.06069088], [78.34874725, 9.06069374], [78.34874725, 9.06041622], [78.34819794, 9.06042004], [78.34819794, 9.06013966], [78.34792328, 9.06013966], [78.34792328, 9.05986023], [78.34764099, 9.05986214], [78.34764099, 9.05958366], [78.34708405, 9.05958366], [78.34708405, 9.05930614], [78.34680176, 9.05930996], [78.34680176, 9.05902958], [78.3465271, 9.05902958], [78.3465271, 9.05875015], [78.34625244, 9.05875015], [78.34625244, 9.05847168], [78.3456955, 9.05847168], [78.3456955, 9.05819416], [78.34541321, 9.05819416], [78.34541321, 9.05791759], [78.34513855, 9.05792046], [78.34513855, 9.05764198], [78.34458923, 9.05764198], [78.34458923, 9.0573616], [78.34430695, 9.0573616], [78.34430695, 9.05708408], [78.34402466, 9.05708408], [78.34402466, 9.05680561], [78.34348297, 9.05681038], [78.34348297, 9.05653191], [78.34319305, 9.05653191], [78.34319305, 9.05625153], [78.3429184, 9.05625153], [78.3429184, 9.05596924], [78.34236145, 9.05597115], [78.34236145, 9.05569553], [78.34208679, 9.05569553], [78.34208679, 9.05541801], [78.34152222, 9.05541992], [78.34152222, 9.05513859], [78.34124756, 9.05513859], [78.34124756, 9.05484962], [78.3409729, 9.05486107], [78.3409729, 9.0545826], [78.34041595, 9.0545826], [78.34041595, 9.05430508], [78.3401413, 9.05430984], [78.3401413, 9.05403042], [78.33957672, 9.05403042], [78.33957672, 9.05375099], [78.33930206, 9.05375099], [78.33930206, 9.05347061], [78.3390274, 9.05347347], [78.3390274, 9.05319309], [78.33847046, 9.05319309], [78.33847046, 9.05291653], [78.3381958, 9.05292034], [78.3381958, 9.05264187], [78.33763885, 9.05264187], [78.33763885, 9.05236053], [78.3373642, 9.05236053], [78.3373642, 9.05208302], [78.33680725, 9.05208302], [78.33680725, 9.05180454], [78.33651733, 9.05181026], [78.33651733, 9.05153179], [78.33625031, 9.05153179], [78.33625031, 9.05125141], [78.33569336, 9.05125141], [78.33569336, 9.05097103], [78.3354187, 9.05097103], [78.3354187, 9.05069542], [78.33486176, 9.05069542], [78.33486176, 9.05041695], [78.3345871, 9.05042171], [78.3345871, 9.05014133], [78.33429718, 9.05014133], [78.33429718, 9.04986095], [78.33374786, 9.04986095], [78.33374786, 9.04958344], [78.33347321, 9.04958344], [78.33347321, 9.04930496], [78.33319092, 9.04931164], [78.33319092, 9.0490427], [78.33264923, 9.0490427], [78.33264923, 9.04875088], [78.33235931, 9.04875088], [78.33235931, 9.04847145], [78.33180237, 9.04847336], [78.33180237, 9.04819489], [78.33152771, 9.04819489], [78.33152771, 9.04791737], [78.33125305, 9.04791927], [78.33125305, 9.04763889], [78.33069611, 9.04763889], [78.33069611, 9.04736137], [78.33041382, 9.04736137], [78.33041382, 9.0470829], [78.33013916, 9.0470829], [78.33013916, 9.04680538], [78.32958221, 9.0468092], [78.32958221, 9.04653072], [78.32930756, 9.04653072], [78.32930756, 9.0462513], [78.32875061, 9.0462513], [78.32875061, 9.04597282], [78.32847595, 9.04598045], [78.32847595, 9.04568958], [78.32819366, 9.0456953], [78.32819366, 9.04541683], [78.32763672, 9.04542065], [78.32763672, 9.04514122], [78.32736206, 9.04514122], [78.32736206, 9.04486275], [78.32681274, 9.04486275], [78.32681274, 9.04458046], [78.32653046, 9.04458332], [78.32653046, 9.04430676], [78.32624817, 9.04431057], [78.32624817, 9.04403114], [78.32569122, 9.04403114], [78.32569122, 9.0437479], [78.32541656, 9.04375076], [78.32541656, 9.04347324], [78.32485962, 9.04347324], [78.32485962, 9.04319477], [78.32458496, 9.04319477], [78.32458496, 9.0429163], [78.32402802, 9.0429163], [78.32402802, 9.04263783], [78.32375336, 9.04264069], [78.32375336, 9.04236031], [78.32319641, 9.04236031], [78.32319641, 9.04208469], [78.32291412, 9.04208469], [78.32291412, 9.04180431], [78.32235718, 9.04181099], [78.32235718, 9.04153061], [78.32208252, 9.04153061], [78.32208252, 9.04125023], [78.32152557, 9.04125023], [78.32152557, 9.04097176], [78.32125092, 9.04097176], [78.32125092, 9.04069424], [78.32069397, 9.04069424], [78.32069397, 9.04041576], [78.32041931, 9.04042053], [78.32041931, 9.04014015], [78.31986237, 9.04014015], [78.31986237, 9.03985119], [78.31958008, 9.03985977], [78.31958008, 9.03958225], [78.31903076, 9.03958225], [78.31903076, 9.03930569], [78.31874847, 9.03931141], [78.31874847, 9.03903103], [78.31819153, 9.03903103], [78.31819153, 9.03874969], [78.31791687, 9.03874969], [78.31791687, 9.03847027], [78.31735992, 9.03847218], [78.31735992, 9.0381937], [78.31708527, 9.0381937], [78.31708527, 9.03791618], [78.31652832, 9.03792095], [78.31652832, 9.03763962], [78.31624603, 9.03763962], [78.31624603, 9.03736019], [78.31569672, 9.0373621], [78.31569672, 9.03708363], [78.31541443, 9.03708363], [78.31541443, 9.03680611], [78.31485748, 9.03681087], [78.31485748, 9.03652954], [78.31458282, 9.03652954], [78.31458282, 9.03625011], [78.31430817, 9.03625011], [78.31430817, 9.03596973], [78.31402588, 9.03597164], [78.31402588, 9.03569412], [78.31375122, 9.03569412], [78.31375122, 9.03514004], [78.31346893, 9.03514004], [78.31346893, 9.03485966], [78.31319427, 9.03486156], [78.31319427, 9.03458405], [78.31291962, 9.03458405], [78.31291962, 9.03430557], [78.31263733, 9.03431034], [78.31263733, 9.03404236], [78.31236267, 9.03404236], [78.31236267, 9.03374958], [78.31208038, 9.03374958], [78.31208038, 9.03319073], [78.31180573, 9.03319359], [78.31180573, 9.03291798], [78.3115387, 9.03292179], [78.3115387, 9.03264046], [78.31124878, 9.03264046], [78.31124878, 9.03236198], [78.31069183, 9.03236198], [78.31069183, 9.03208447], [78.31041718, 9.03208447], [78.31041718, 9.03180599], [78.30986023, 9.0318079], [78.30986023, 9.03153038], [78.30930328, 9.03153038], [78.30930328, 9.03125191], [78.30874634, 9.03125191], [78.30874634, 9.03097153], [78.30847168, 9.03097153], [78.30847168, 9.03069305], [78.30791473, 9.03069305], [78.30791473, 9.03041458], [78.30735779, 9.0304203], [78.30735779, 9.03014183], [78.30680847, 9.03014183], [78.30680847, 9.0298624], [78.30652618, 9.0298624], [78.30652618, 9.02958393], [78.30596924, 9.02958393], [78.30596924, 9.02930546], [78.30541992, 9.02931023], [78.30541992, 9.02902985], [78.30486298, 9.02902985], [78.30486298, 9.02874947], [78.30458069, 9.02874947], [78.30458069, 9.02847099], [78.30403137, 9.02847099], [78.30403137, 9.02819633], [78.30374908, 9.02819633], [78.30374908, 9.02791691], [78.30319214, 9.02791691], [78.30319214, 9.02763939], [78.30291748, 9.02763939], [78.30291748, 9.02736092], [78.30263519, 9.02736092], [78.30263519, 9.0270834], [78.30208588, 9.0270834], [78.30208588, 9.02680492], [78.30179596, 9.02680969], [78.30179596, 9.02652931], [78.30152893, 9.02652931], [78.30152893, 9.02625084], [78.30124664, 9.02625084], [78.30124664, 9.02597141], [78.30069733, 9.02597332], [78.30069733, 9.02569485], [78.30041504, 9.02569485], [78.30041504, 9.02541733], [78.30014038, 9.02542019], [78.30014038, 9.02514076], [78.29957581, 9.02514076], [78.29957581, 9.02486992], [78.29930878, 9.02486992], [78.29930878, 9.02458096], [78.29902649, 9.02458286], [78.29902649, 9.02430534], [78.29846954, 9.02431202], [78.29846954, 9.02403164], [78.29818726, 9.02403164], [78.29818726, 9.02375126], [78.29846954, 9.02375126], [78.29846954, 9.02347088], [78.29819489, 9.02347088], [78.29819489, 9.02319527], [78.29763794, 9.02319527], [78.29763794, 9.02291679], [78.29736328, 9.02292156], [78.29736328, 9.02264118], [78.29680634, 9.02264118], [78.29680634, 9.0223608], [78.29652405, 9.0223608], [78.29652405, 9.02208328], [78.29597473, 9.02208328], [78.29597473, 9.02180481], [78.29569244, 9.02181244], [78.29569244, 9.0215292], [78.29514313, 9.0215292], [78.29514313, 9.02125072], [78.29486084, 9.02125072], [78.29486084, 9.0209713], [78.29430389, 9.02097321], [78.29430389, 9.02069473], [78.29402924, 9.02069473], [78.29402924, 9.02041721], [78.29347992, 9.02042103], [78.29347992, 9.02014065], [78.29319763, 9.02014065], [78.29319763, 9.01986122], [78.29264069, 9.01986122], [78.29264069, 9.01958275], [78.2923584, 9.01958275], [78.2923584, 9.01930523], [78.29180908, 9.01931095], [78.29180908, 9.01903057], [78.29125214, 9.01903057], [78.29125214, 9.01875114], [78.29096985, 9.01875114], [78.29096985, 9.01847267], [78.2904129, 9.01847267], [78.2904129, 9.01819515], [78.28986359, 9.01819515], [78.28986359, 9.01791668], [78.28930664, 9.01792145], [78.28930664, 9.01764107], [78.28901672, 9.01764107], [78.28901672, 9.01736069], [78.28847504, 9.01736069], [78.28847504, 9.01708221], [78.28791809, 9.01708221], [78.28791809, 9.0168066], [78.28819275, 9.01681137], [78.28819275, 9.01625061], [78.28848267, 9.01625061], [78.28848267, 9.01568127], [78.28819275, 9.01569366], [78.28819275, 9.01541615], [78.28791809, 9.01541615], [78.28791809, 9.01569366], [78.2876358, 9.01569366], [78.2876358, 9.01597309], [78.2868042, 9.01597309], [78.2868042, 9.01569366], [78.28652954, 9.01569366], [78.28652954, 9.01541615], [78.28624725, 9.01542091], [78.28624725, 9.01514053], [78.28569794, 9.01514053], [78.28569794, 9.01486015], [78.28541565, 9.01486015], [78.28541565, 9.01458454], [78.28514099, 9.01458454], [78.28514099, 9.01430416], [78.2848587, 9.01430416], [78.2848587, 9.01458454], [78.28430939, 9.01458454], [78.28430176, 9.01486015], [78.2831955, 9.01486015], [78.2831955, 9.01458454], [78.28263855, 9.01458454], [78.28263855, 9.01430416], [78.28180695, 9.01431084], [78.28180695, 9.01403141], [78.28125, 9.01403141], [78.28125, 9.01375008], [78.28098297, 9.01375008], [78.28098297, 9.0134697], [78.28069305, 9.0134716], [78.28069305, 9.01319408], [78.2804184, 9.01319408], [78.2804184, 9.01263809], [78.28013611, 9.01264], [78.28013611, 9.01235962], [78.27986145, 9.01236153], [78.27986145, 9.0120821], [78.27958679, 9.0120821], [78.27958679, 9.01180553], [78.27929688, 9.01181126], [78.27929688, 9.01152992], [78.27902985, 9.01152992], [78.27902985, 9.01124954], [78.27874756, 9.01124954], [78.27874756, 9.01097202], [78.2784729, 9.01097202], [78.2784729, 9.01069355], [78.27819824, 9.01069355], [78.27819061, 9.01041603], [78.27791595, 9.0104208], [78.27791595, 9.00987053], [78.2776413, 9.00987053], [78.2776413, 9.00957966], [78.27735901, 9.00958443], [78.27735901, 9.00930595], [78.27707672, 9.00931072], [78.27707672, 9.00903034], [78.27680206, 9.00903034], [78.27680206, 9.00874996], [78.2765274, 9.00874996], [78.2765274, 9.00846958], [78.27625275, 9.00847244], [78.27625275, 9.00819397], [78.27597046, 9.00819397], [78.27597046, 9.00791645], [78.2756958, 9.00792027], [78.2756958, 9.00764179], [78.27513885, 9.00764179], [78.27513885, 9.00736046], [78.2748642, 9.00736237], [78.2748642, 9.00708389], [78.27458191, 9.00708389], [78.27458191, 9.00680637], [78.27401733, 9.00681019], [78.27401733, 9.0065279], [78.27375031, 9.0065279], [78.27375031, 9.00625038], [78.27347565, 9.00625038], [78.27347565, 9.00597191], [78.2729187, 9.00597191], [78.2729187, 9.00569439], [78.27263641, 9.00569439], [78.27263641, 9.00541782], [78.27097321, 9.00541973], [78.27097321, 9.00681019], [78.27069092, 9.00680637], [78.27069092, 9.00847244], [78.27041626, 9.00846958], [78.27041626, 9.00903034], [78.2701416, 9.00902843], [78.2701416, 9.00958443], [78.26985931, 9.00957966], [78.26985931, 9.01014042], [78.26958466, 9.01013756], [78.26958466, 9.01069355], [78.26930237, 9.01069355], [78.26930237, 9.01109982], [78.26930237, 9.01124954], [78.26902771, 9.01124954], [78.26902771, 9.01181126], [78.26875305, 9.01180553], [78.26875305, 9.01236153], [78.26847076, 9.01235962], [78.26847076, 9.01292992], [78.26819611, 9.01292992], [78.26819611, 9.01431084], [78.26847076, 9.01430416], [78.26847076, 9.01569366], [78.26819611, 9.01568127], [78.26819611, 9.01625061], [78.26735687, 9.01625061], [78.26735687, 9.01653099], [78.26708221, 9.01653099], [78.26708221, 9.01681137], [78.26680756, 9.0168066], [78.26680756, 9.01736069], [78.2665329, 9.01736069], [78.2665329, 9.01764107], [78.26597595, 9.01764107], [78.26597595, 9.01792145], [78.26569366, 9.01791668], [78.26569366, 9.01819515], [78.26513672, 9.01819515], [78.26513672, 9.01847267], [78.26457977, 9.01847267], [78.26457977, 9.01875114], [78.26431274, 9.01875114], [78.26431274, 9.01903057], [78.26374817, 9.01903057], [78.26374817, 9.01931095], [78.26180267, 9.01931095], [78.26180267, 9.01903057], [78.26152802, 9.01903057], [78.26152802, 9.01875114], [78.26097107, 9.01875114], [78.26097107, 9.01791668], [78.26125336, 9.01792145], [78.26125336, 9.01708031], [78.26569366, 9.01708221], [78.26569366, 9.0168066], [78.26597595, 9.01681137], [78.26597595, 9.01653099], [78.26624298, 9.01653099], [78.26624298, 9.01625061], [78.2665329, 9.01625061], [78.2665329, 9.01542091], [78.26680756, 9.01542091], [78.26680756, 9.01403141], [78.26708221, 9.01403141], [78.26708221, 9.01264], [78.26735687, 9.01264], [78.26735687, 9.01214123], [78.2673645, 9.01152802], [78.26763916, 9.01152992], [78.26763916, 9.0104208], [78.26790619, 9.0104208], [78.26790619, 9.00846958], [78.26763916, 9.00847244], [78.26763916, 9.00680637], [78.26680756, 9.00681019], [78.26680756, 9.0065279], [78.2665329, 9.0065279], [78.2665329, 9.00625038], [78.26624298, 9.00625038], [78.26624298, 9.00458145], [78.26652527, 9.00458431], [78.26652527, 9.00402832], [78.26680756, 9.00403023], [78.26680756, 9.00347137], [78.26708221, 9.00347137], [78.26708221, 9.00319576], [78.26680756, 9.00319576], [78.26680756, 9.00291538], [78.26624298, 9.00292015], [78.26624298, 9.00264168], [78.26597595, 9.00264168], [78.26597595, 9.00235939], [78.26569366, 9.00236225], [78.26569366, 9.00208282], [78.26513672, 9.00208282], [78.26513672, 9.00180531], [78.26486206, 9.00181007], [78.26486206, 9.00152969], [78.26457977, 9.00152969], [78.26457977, 9.00124931], [78.26403046, 9.00124931], [78.26403046, 9.00097084], [78.26374817, 9.00097084], [78.26374817, 9.00069332], [78.26347351, 9.00069332], [78.26347351, 9.00041676], [78.26264191, 9.00041962], [78.26264191, 9.00013924], [78.26207733, 9.00013924], [78.26207733, 8.99986076], [78.26125336, 8.99986076], [78.26125336, 8.99958134], [78.26097107, 8.99958324], [78.26097107, 8.99930477], [78.26069641, 8.99930954], [78.26069641, 8.99903202], [78.26040649, 8.99903202], [78.26040649, 8.99875069], [78.25985718, 8.99875069], [78.25985718, 8.99847126], [78.25958252, 8.99847317], [78.25958252, 8.99819469], [78.25930786, 8.99819469], [78.25930786, 8.99791718], [78.2590332, 8.99793053], [78.2590332, 8.99764061], [78.25846863, 8.99764061], [78.25846863, 8.99736118], [78.25819397, 8.99736118], [78.25819397, 8.99708271], [78.25763702, 8.99708271], [78.25763702, 8.99680519], [78.25737, 8.99681187], [78.25737, 8.99653053], [78.25681305, 8.99653053], [78.25681305, 8.99625111], [78.25653076, 8.99625111], [78.25653076, 8.99597263], [78.25597382, 8.99597263], [78.25597382, 8.99569511], [78.25541687, 8.99569511], [78.25541687, 8.99541664], [78.25514221, 8.99542236], [78.25514221, 8.99514103], [78.2545929, 8.99514103], [78.2545929, 8.99486065], [78.25430298, 8.99486065], [78.25430298, 8.99458313], [78.25375366, 8.99458313], [78.25375366, 8.99430466], [78.25319672, 8.99430943], [78.25319672, 8.99403095], [78.2529068, 8.99403095], [78.2529068, 8.99375057], [78.25235748, 8.99375057], [78.25235748, 8.99347115], [78.25208282, 8.99347305], [78.25208282, 8.99319458], [78.25152588, 8.99319458], [78.25152588, 8.99291706], [78.25123596, 8.99292088], [78.25123596, 8.99264145], [78.25068665, 8.99264145], [78.25068665, 8.99236107], [78.25013733, 8.99236107], [78.25013733, 8.9920826], [78.24986267, 8.9920826], [78.24986267, 8.99180698], [78.24930573, 8.99180698], [78.24930573, 8.9915266], [78.24903107, 8.99153137], [78.24903107, 8.99125099], [78.24846649, 8.99125099], [78.24846649, 8.99096966], [78.24810791, 8.99097347], [78.24791718, 8.99097347], [78.24791718, 8.990695], [78.24764252, 8.990695], [78.24764252, 8.99041653], [78.2470932, 8.9904213], [78.2470932, 8.99014091], [78.24652863, 8.99014091], [78.24652863, 8.98985958], [78.24624634, 8.98985958], [78.24624634, 8.98958206], [78.24569702, 8.98958206], [78.24569702, 8.98930359], [78.24514008, 8.98931122], [78.24514008, 8.98903084], [78.24485779, 8.98903084], [78.24485779, 8.98874092], [78.24430847, 8.98875141], [78.24430847, 8.98847198], [78.24375153, 8.98847198], [78.24375153, 8.98819447], [78.24346924, 8.98819447], [78.24346924, 8.98791599], [78.24291992, 8.98791885], [78.24291992, 8.98764133], [78.24263763, 8.98764133], [78.24263763, 8.98736], [78.24208069, 8.98736], [78.24208069, 8.98708439], [78.24153137, 8.98708439], [78.24153137, 8.98680592], [78.24124908, 8.98681068], [78.24124908, 8.98653126], [78.24069214, 8.98653126], [78.24069214, 8.98624992], [78.24014282, 8.98624992], [78.24014282, 8.98596954], [78.23986053, 8.9859724], [78.23986053, 8.98569393], [78.23929596, 8.98570061], [78.23929596, 8.98542118], [78.23874664, 8.98542118], [78.23874664, 8.98513985], [78.23847198, 8.98513985], [78.23847198, 8.98486042], [78.23791504, 8.98486233], [78.23791504, 8.98458195], [78.23735809, 8.98458195], [78.23735809, 8.98430634], [78.23707581, 8.9843111], [78.23707581, 8.98402977], [78.23652649, 8.98402977], [78.23652649, 8.98375034], [78.23625183, 8.98375034], [78.23625183, 8.98347187], [78.23596954, 8.98347187], [78.23596954, 8.98319435], [78.23542023, 8.98319435], [78.23542023, 8.98291588], [78.23513794, 8.98292065], [78.23513794, 8.98264027], [78.23486328, 8.98264027], [78.23486328, 8.98235989], [78.23458099, 8.98235989], [78.23458099, 8.98208427], [78.23402405, 8.98208427], [78.23402405, 8.9818058], [78.23374939, 8.98181057], [78.23374939, 8.98153019], [78.2334671, 8.98153019], [78.2334671, 8.98124981], [78.23319244, 8.98124981], [78.23319244, 8.98097229], [78.23291779, 8.98097229], [78.23291779, 8.98069382], [78.23236084, 8.98069382], [78.23236084, 8.9804163], [78.23208618, 8.98042011], [78.23208618, 8.98013973], [78.23179626, 8.98013973], [78.23179626, 8.97986031], [78.23152924, 8.97986221], [78.23152924, 8.97958374], [78.23097229, 8.97958374], [78.23097229, 8.97930622], [78.23069763, 8.97931004], [78.23069763, 8.97902966], [78.23042297, 8.97902966], [78.23042297, 8.97875023], [78.23013306, 8.97875023], [78.23013306, 8.97846889], [78.2298584, 8.97847176], [78.2298584, 8.97819424], [78.22930908, 8.97819424], [78.22930908, 8.97791767], [78.22902679, 8.97791958], [78.22902679, 8.97764015], [78.22875214, 8.97764015], [78.22875214, 8.97736168], [78.22846985, 8.97736168], [78.22846985, 8.97708416], [78.2279129, 8.97708416], [78.2279129, 8.97680569], [78.22763824, 8.97680569], [78.22763824, 8.97652817], [78.22735596, 8.97653198], [78.22735596, 8.9762516], [78.22706604, 8.9762516], [78.22706604, 8.97596931], [78.22680664, 8.97597122], [78.22680664, 8.97569561], [78.22624969, 8.97569561], [78.22624969, 8.97541809], [78.22598267, 8.97542], [78.22598267, 8.97513962], [78.22569275, 8.97513962], [78.22569275, 8.97485924], [78.22541809, 8.97486115], [78.22541809, 8.97458267], [78.2251358, 8.97458267], [78.2251358, 8.97430515], [78.22458649, 8.97430992], [78.22458649, 8.97402954], [78.22429657, 8.97402954], [78.22429657, 8.9737606], [78.22402954, 8.9737606], [78.22402954, 8.97347069], [78.22374725, 8.9734726], [78.22374725, 8.97319317], [78.2234726, 8.97319317], [78.2234726, 8.9729166], [78.22292328, 8.97292042], [78.22292328, 8.97264194], [78.22264099, 8.97264194], [78.22264099, 8.97236061], [78.2223587, 8.97236061], [78.2223587, 8.9721899], [78.2223587, 8.97208309], [78.22208405, 8.97208309], [78.22208405, 8.97180462], [78.22180176, 8.97181034], [78.22180176, 8.97153187], [78.22126007, 8.97153187], [78.22126007, 8.97125053], [78.22097015, 8.97125053], [78.22097015, 8.97097111], [78.2206955, 8.97097111], [78.2206955, 8.97069454], [78.22041321, 8.97070026], [78.22041321, 8.97042179], [78.22013855, 8.97042179], [78.22013855, 8.97014141], [78.21985626, 8.97014141], [78.21985626, 8.96986103], [78.2195816, 8.96986103], [78.2195816, 8.96958256], [78.21930695, 8.96958256], [78.21930695, 8.96930504], [78.21901703, 8.96931171], [78.21901703, 8.96903133], [78.21875, 8.96903133], [78.21875, 8.96875095], [78.21848297, 8.96875095], [78.21848297, 8.96847057], [78.21819305, 8.96847343], [78.21819305, 8.96819496], [78.2179184, 8.96819496], [78.2179184, 8.96791744], [78.21763611, 8.96791935], [78.21763611, 8.96763039], [78.21736145, 8.96763897], [78.21736145, 8.96736145], [78.21708679, 8.96736145], [78.21708679, 8.96708298], [78.2168045, 8.96708298], [78.2168045, 8.96680546], [78.21652985, 8.96680927], [78.21652985, 8.96652889], [78.21624756, 8.96652889], [78.21624756, 8.96625137], [78.2159729, 8.96625137], [78.2159729, 8.9659729], [78.21569824, 8.9659729], [78.21569061, 8.96569538], [78.21541595, 8.96569538], [78.21541595, 8.96541691], [78.21512604, 8.96542072], [78.21512604, 8.9651413], [78.21485901, 8.9651413], [78.21485901, 8.96486092], [78.21457672, 8.96486092], [78.21457672, 8.964571], [78.21430206, 8.9645834], [78.21430206, 8.96430683], [78.2140274, 8.96431065], [78.2140274, 8.96403122], [78.21375275, 8.96403122], [78.21375275, 8.96375084], [78.21347046, 8.96375084], [78.21347046, 8.96347046], [78.2131958, 8.96347332], [78.2131958, 8.96319485], [78.21291351, 8.96319485], [78.21291351, 8.96291733], [78.21263885, 8.96292114], [78.21263885, 8.9626379], [78.21235657, 8.9626379], [78.21235657, 8.96236038], [78.21208191, 8.96236038], [78.21208191, 8.96208477], [78.21180725, 8.96208191], [78.21180725, 8.96180439], [78.21151733, 8.96181965], [78.21151733, 8.96153069], [78.21125031, 8.96153069], [78.21125031, 8.96125031], [78.21097565, 8.96125031], [78.21097565, 8.96097183], [78.21069336, 8.96097183], [78.21069336, 8.96069431], [78.2104187, 8.96069431], [78.2104187, 8.96041584], [78.21013641, 8.96042061], [78.21013641, 8.96014118], [78.20986176, 8.96014118], [78.20986176, 8.95985985], [78.2095871, 8.95985985], [78.2095871, 8.95958233], [78.20930481, 8.95958233], [78.20930481, 8.95930576], [78.20903015, 8.95931053], [78.20903015, 8.95875931], [78.20874786, 8.95875931], [78.20874786, 8.95847034], [78.20847321, 8.95847225], [78.20847321, 8.95819378], [78.20819092, 8.95819378], [78.20819092, 8.95763779], [78.20791626, 8.95763969], [78.20791626, 8.95736027], [78.2076416, 8.95736217], [78.2076416, 8.9570837], [78.20735931, 8.9570837], [78.20735931, 8.95652771], [78.20707703, 8.95652962], [78.20707703, 8.95625019], [78.20680237, 8.95625019], [78.20680237, 8.9556942], [78.20652771, 8.9556942], [78.20652771, 8.95514011], [78.20819092, 8.95514011], [78.20819092, 8.95485973], [78.20791626, 8.95485973], [78.20791626, 8.95458412], [78.2076416, 8.95458412], [78.2076416, 8.95430565], [78.20735931, 8.95431137], [78.20735931, 8.95403004], [78.20707703, 8.95403004], [78.20707703, 8.95374966], [78.20680237, 8.95374966], [78.20680237, 8.95347023], [78.20652771, 8.95347214], [78.20652771, 8.95291805], [78.20625305, 8.95291996], [78.20625305, 8.952631], [78.20597076, 8.95263767], [78.20597076, 8.95236206], [78.20569611, 8.95236206], [78.20569611, 8.95180607], [78.20540619, 8.95181274], [78.20540619, 8.95153046], [78.20513916, 8.95153046], [78.20513916, 8.95125198], [78.20485687, 8.95125198], [78.20485687, 8.95069122], [78.20458221, 8.95069408], [78.20458221, 8.95041466], [78.20430756, 8.95042038], [78.20430756, 8.95014191], [78.2040329, 8.95014191], [78.2040329, 8.94958973], [78.20375061, 8.94958973], [78.20375061, 8.9493103], [78.20347595, 8.9493103], [78.20347595, 8.94902992], [78.20318604, 8.94902992], [78.20318604, 8.94874859], [78.20263672, 8.94874859], [78.20263672, 8.94847107], [78.20236206, 8.94847107], [78.20236206, 8.94819641], [78.20207977, 8.94819641], [78.20207977, 8.94791794], [78.20181274, 8.94791985], [78.20181274, 8.94763947], [78.20153046, 8.94763947], [78.20153046, 8.94736099], [78.20096588, 8.94736099], [78.20096588, 8.94708061], [78.20069122, 8.94708347], [78.20069122, 8.946805], [78.20041656, 8.94682121], [78.20041656, 8.94653034], [78.20012665, 8.94653034], [78.20013428, 8.94636059], [78.20014191, 8.9459734], [78.19985962, 8.9459734], [78.19985962, 8.94569492], [78.19958496, 8.94569302], [78.19958496, 8.9454174], [78.19930267, 8.94542027], [78.19930267, 8.94486141], [78.19902802, 8.94486141], [78.19902802, 8.94458294], [78.19875336, 8.94458294], [78.19875336, 8.94402695], [78.19847107, 8.94403172], [78.19847107, 8.94375134], [78.19819641, 8.94375134], [78.19819641, 8.94319534], [78.19791412, 8.94319534], [78.19791412, 8.94291687], [78.19763947, 8.94292164], [78.19763947, 8.94264126], [78.19735718, 8.94264126], [78.19735718, 8.94208145], [78.19708252, 8.94208336], [78.19708252, 8.94180489], [78.19680786, 8.94181156], [78.19680786, 8.94124889], [78.19652557, 8.94124889], [78.19652557, 8.94097328], [78.19625092, 8.94097328], [78.19625092, 8.94069481], [78.19596863, 8.94069481], [78.19596863, 8.94013882], [78.19568634, 8.94014072], [78.19568634, 8.9398613], [78.19541931, 8.9398613], [78.19541931, 8.93930531], [78.19513702, 8.93931198], [78.19513702, 8.93875122], [78.19486237, 8.93875122], [78.19486237, 8.93847275], [78.19458008, 8.93847275], [78.19458008, 8.93791676], [78.19431305, 8.93792057], [78.19431305, 8.9373579], [78.19403076, 8.93736076], [78.19403076, 8.93680668], [78.19374847, 8.93681145], [78.19374847, 8.93653107], [78.19346619, 8.93653107], [78.19346619, 8.93597031], [78.19319153, 8.93597317], [78.19319153, 8.93541622], [78.19291687, 8.93542099], [78.19291687, 8.93514061], [78.19264221, 8.93514061], [78.19264221, 8.93459129], [78.19235992, 8.93459129], [78.19235992, 8.93403053], [78.1920929, 8.93403053], [78.1920929, 8.93346977], [78.19180298, 8.93347168], [78.19180298, 8.93319416], [78.19152832, 8.93319416], [78.19152832, 8.93263817], [78.19124603, 8.93264008], [78.19124603, 8.93208027], [78.19097137, 8.93208218], [78.19097137, 8.93180561], [78.19069672, 8.93181133], [78.19069672, 8.93124962], [78.1904068, 8.93124962], [78.1904068, 8.93069172], [78.19013977, 8.93069363], [78.19013977, 8.93013763], [78.18985748, 8.93013954], [78.18985748, 8.92986012], [78.18958282, 8.92986012], [78.18958282, 8.92930603], [78.18930817, 8.9293108], [78.18930817, 8.92875004], [78.18902588, 8.92875004], [78.18902588, 8.92818928], [78.18875122, 8.92819405], [78.18875122, 8.92763996], [78.18846893, 8.92763996], [78.18846893, 8.9270792], [78.18819427, 8.92708397], [78.18819427, 8.92652798], [78.18791962, 8.92653179], [78.18791962, 8.92597198], [78.18763733, 8.92597198], [78.18763733, 8.9254179], [78.18736267, 8.9254179], [78.18736267, 8.92486191], [78.18708038, 8.92486191], [78.18708038, 8.92430592], [78.18681335, 8.92430973], [78.18681335, 8.92375183], [78.18653107, 8.92375183], [78.18653107, 8.92319107], [78.18624878, 8.92319584], [78.18624878, 8.92263985], [78.18596649, 8.92265129], [78.18596649, 8.92208099], [78.18569183, 8.92208385], [78.18569183, 8.92124939], [78.18541718, 8.92124939], [78.18541718, 8.9206934], [78.18514252, 8.9206934], [78.18514252, 8.92013931], [78.18486023, 8.92013931], [78.18486023, 8.91930962], [78.1845932, 8.91930962], [78.1845932, 8.91875076], [78.18430328, 8.91875076], [78.18430328, 8.91792202], [78.18402863, 8.91792202], [78.18402863, 8.91708088], [78.18374634, 8.91708279], [78.18374634, 8.91625118], [78.18347168, 8.91625118], [78.18347168, 8.91541672], [78.18319702, 8.91542244], [78.18319702, 8.91486073], [78.1829071, 8.91486073], [78.1829071, 8.91403103], [78.18264008, 8.91403103], [78.18264008, 8.91318989], [78.18235779, 8.91319466], [78.18235779, 8.91236115], [78.18208313, 8.91236115], [78.18208313, 8.91152668], [78.18180847, 8.91153145], [78.18180847, 8.91069031], [78.18152618, 8.91069508], [78.18152618, 8.91013908], [78.18125153, 8.91014099], [78.18125153, 8.90931129], [78.18096924, 8.90931129], [78.18096924, 8.90818977], [78.18069458, 8.90819359], [78.18069458, 8.90708542], [78.18041992, 8.90708542], [78.18041992, 8.90597153], [78.18013763, 8.90597153], [78.18013763, 8.9048624], [78.17986298, 8.9048624], [78.17986298, 8.89902782], [78.18013763, 8.89902973], [78.18013763, 8.89791965], [78.18041992, 8.89791965], [78.18041992, 8.89680958], [78.18068695, 8.89680958], [78.18068695, 8.89542007], [78.18041992, 8.89542007], [78.18041992, 8.89431], [78.18013763, 8.89431], [78.18013763, 8.89319134], [78.17986298, 8.89319324], [78.17986298, 8.89263916], [78.17819214, 8.89264202], [78.17819214, 8.8923502], [78.17763519, 8.89236069], [78.17763519, 8.89208317], [78.17708588, 8.89208317], [78.17708588, 8.8918047], [78.17652893, 8.89181042], [78.17652893, 8.89153194], [78.17595673, 8.89153194], [78.17595673, 8.89125061], [78.17569733, 8.89125061], [78.17569733, 8.89097118], [78.17541504, 8.89097118], [78.17541504, 8.89069462], [78.17514038, 8.89069462], [78.17514038, 8.8904171], [78.17485809, 8.89042187], [78.17485809, 8.89014053], [78.17457581, 8.89014053], [78.17457581, 8.88986111], [78.17430878, 8.88986111], [78.17430878, 8.88958263], [78.17402649, 8.88958263], [78.17402649, 8.88930511], [78.17346954, 8.88931179], [78.17346954, 8.88903236], [78.17318726, 8.88903236], [78.17318726, 8.88875103], [78.17292023, 8.88875103], [78.17292023, 8.88847065], [78.17263794, 8.88847256], [78.17263794, 8.88819504], [78.17236328, 8.88819504], [78.17236328, 8.88791656], [78.17208099, 8.88791943], [78.17208099, 8.88764095], [78.17180634, 8.88764095], [78.17180634, 8.88736057], [78.17152405, 8.88736057], [78.17152405, 8.88708305], [78.17124939, 8.88708305], [78.17124939, 8.88652897], [78.1709671, 8.88654041], [78.1709671, 8.88597107], [78.17069244, 8.88597298], [78.17069244, 8.88541698], [78.17041779, 8.88541889], [78.17041779, 8.88486099], [78.1701355, 8.88486099], [78.1701355, 8.88430691], [78.16986084, 8.88431072], [78.16986084, 8.88375092], [78.16958618, 8.88375092], [78.16958618, 8.88320065], [78.16929626, 8.88319016], [78.16930389, 8.88263893], [78.16902924, 8.88264084], [78.16902924, 8.88208008], [78.16874695, 8.88208199], [78.16874695, 8.88097191], [78.16847229, 8.88097191], [78.16847229, 8.87902832], [78.16819763, 8.87903118], [78.16819763, 8.87708187], [78.16791534, 8.87708378], [78.16791534, 8.8754158], [78.16764069, 8.87542057], [78.16764069, 8.87347031], [78.1673584, 8.87347221], [78.1673584, 8.87152767], [78.16764069, 8.87154102], [78.16764069, 8.86931038], [78.16792297, 8.86931038], [78.16792297, 8.86791992], [78.16819763, 8.86791992], [78.16819763, 8.86708069], [78.16847229, 8.8670826], [78.16847229, 8.86624908], [78.16874695, 8.86625195], [78.16874695, 8.8654108], [78.16847229, 8.86541653], [78.16847229, 8.85986137], [78.16819763, 8.85986137], [78.16819763, 8.8595829], [78.16791534, 8.8595829], [78.16791534, 8.85930538], [78.16764069, 8.8593092], [78.16764069, 8.85903072], [78.1673584, 8.85903072], [78.1673584, 8.85847092], [78.16708374, 8.85847282], [78.16708374, 8.8581953], [78.16680908, 8.8581953], [78.16680908, 8.85791683], [78.16625214, 8.85792065], [78.16625214, 8.85708046], [78.16596985, 8.85708332], [78.16596985, 8.85597324], [78.16625214, 8.85597324], [78.16625214, 8.85486031], [78.16652679, 8.85486031], [78.16652679, 8.84958363], [78.16680908, 8.84958363], [78.16680908, 8.84736156], [78.16707611, 8.8473711], [78.16707611, 8.84403038], [78.16680908, 8.84403038], [78.16680908, 8.84319115], [78.16652679, 8.84319401], [78.16652679, 8.84263992], [78.16625214, 8.84264183], [78.16625214, 8.84235859], [78.16596985, 8.8423624], [78.16596985, 8.84180641], [78.16570282, 8.84181023], [78.16570282, 8.84152985], [78.1654129, 8.84152985], [78.1654129, 8.84123993], [78.16513824, 8.84124947], [78.16513824, 8.84069347], [78.16486359, 8.84069347], [78.16486359, 8.83986092], [78.1645813, 8.83986092], [78.1645813, 8.83874893], [78.16430664, 8.83875084], [78.16430664, 8.83792019], [78.1645813, 8.83792019], [78.1645813, 8.83708096], [78.16486359, 8.83708286], [78.16486359, 8.83569527], [78.1645813, 8.83569527], [78.1645813, 8.83443928], [78.1645813, 8.83430481], [78.16485596, 8.83430862], [78.16485596, 8.83318996], [78.16513824, 8.83319473], [78.16513824, 8.83208275], [78.1654129, 8.83208275], [78.1654129, 8.83097267], [78.16569519, 8.83097267], [78.16569519, 8.83041668], [78.16596985, 8.83042145], [78.16596985, 8.82958031], [78.16625214, 8.82958317], [78.16625214, 8.82902908], [78.16652679, 8.82903099], [78.16652679, 8.82847023], [78.16791534, 8.82847309], [78.16791534, 8.82763767], [78.16819763, 8.82764053], [78.16819763, 8.82681084], [78.16792297, 8.82681084], [78.16792297, 8.82653141], [78.16764069, 8.82653141], [78.16764069, 8.82625961], [78.1673584, 8.82625961], [78.1673584, 8.8259697], [78.16708374, 8.8259716], [78.16708374, 8.82541561], [78.16680908, 8.82542133], [78.16680908, 8.82514], [78.16652679, 8.82514], [78.16652679, 8.82485962], [78.16625214, 8.82486153], [78.16625214, 8.8245821], [78.16596985, 8.8245821], [78.16596985, 8.82402802], [78.16570282, 8.82403088], [78.16570282, 8.82347202], [78.1654129, 8.82347202], [78.1654129, 8.82291603], [78.16513824, 8.8229208], [78.16513824, 8.82236004], [78.16485596, 8.82236004], [78.16485596, 8.82181072], [78.1645813, 8.82181072], [78.1645813, 8.82124996], [78.16430664, 8.82124996], [78.16430664, 8.82070065], [78.16401672, 8.8206892], [78.16402435, 8.82013798], [78.16374969, 8.82013798], [78.16374969, 8.81958389], [78.16402435, 8.81958389], [78.16402435, 8.8176403], [78.16374969, 8.8176403], [78.16374969, 8.81680965], [78.16348267, 8.81680965], [78.16348267, 8.81374931], [78.16319275, 8.81374931], [78.16319275, 8.81291676], [78.16348267, 8.81291962], [78.16348267, 8.81236076], [78.16374969, 8.81236076], [78.16374969, 8.81208134], [78.16402435, 8.81208324], [78.16402435, 8.81180477], [78.1645813, 8.81180954], [78.1645813, 8.81153202], [78.16485596, 8.81153202], [78.16485596, 8.81126118], [78.1654129, 8.81126118], [78.1654129, 8.81069088], [78.16513824, 8.81069469], [78.16513824, 8.80986118], [78.16486359, 8.80986118], [78.16486359, 8.80930519], [78.16430664, 8.80931187], [78.16430664, 8.80903244], [78.16401672, 8.80903244], [78.16401672, 8.80875111], [78.16347504, 8.80875111], [78.16347504, 8.80847263], [78.16236115, 8.80847263], [78.16236115, 8.80791664], [78.16208649, 8.80791855], [78.16208649, 8.80736065], [78.1618042, 8.80736065], [78.1618042, 8.80708313], [78.16208649, 8.80708313], [78.16208649, 8.80624866], [78.16236115, 8.80625057], [78.16236115, 8.80597115], [78.16291809, 8.80597305], [78.16291809, 8.80541706], [78.16319275, 8.80542088], [78.16319275, 8.80430889], [78.16348267, 8.80430889], [78.16348267, 8.80319023], [78.16374969, 8.803195], [78.16374969, 8.80236053], [78.16319275, 8.80236053], [78.16319275, 8.80264091], [78.1626358, 8.80264091], [78.1626358, 8.8029213], [78.1618042, 8.80291653], [78.1618042, 8.803195], [78.16124725, 8.803195], [78.16124725, 8.80347347], [78.16069794, 8.80346966], [78.16069794, 8.80375099], [78.15930176, 8.80375099], [78.15930176, 8.80319023], [78.15958405, 8.803195], [78.15958405, 8.80263901], [78.1598587, 8.80264091], [78.1598587, 8.80236053], [78.16041565, 8.80236053], [78.16041565, 8.80125141], [78.15930176, 8.80125141], [78.15930176, 8.80013847], [78.1590271, 8.80014133], [78.1590271, 8.79819202], [78.15875244, 8.79819393], [78.15875244, 8.79680634], [78.16069794, 8.7968111], [78.16069794, 8.79568958], [78.1609726, 8.79569435], [78.1609726, 8.79402828], [78.16124725, 8.79403019], [78.16124725, 8.79347038], [78.16208649, 8.79347229], [78.16208649, 8.79319382], [78.16291809, 8.79319382], [78.16291809, 8.7929163], [78.16236115, 8.79292011], [78.16236115, 8.79236031], [78.16208649, 8.79236221], [78.16208649, 8.79208374], [78.16152954, 8.79208374], [78.16152954, 8.79180622], [78.16098022, 8.79181004], [78.16098022, 8.79125023], [78.16124725, 8.79125023], [78.16124725, 8.79069424], [78.16152954, 8.79069424], [78.16152954, 8.78986168], [78.1618042, 8.78986168], [78.16179657, 8.78931046], [78.16208649, 8.78931046], [78.16208649, 8.78846931], [78.16236115, 8.78847122], [78.16236115, 8.78791809], [78.1626358, 8.78792], [78.1626358, 8.78735924], [78.16291809, 8.7873621], [78.16291809, 8.78652668], [78.16319275, 8.78652954], [78.16319275, 8.78597069], [78.16347504, 8.78597355], [78.16347504, 8.7854166], [78.16374969, 8.78542042], [78.16374969, 8.78319073], [78.16347504, 8.78319454], [78.16347504, 8.78263855], [78.16319275, 8.78264141], [78.16319275, 8.78236103], [78.16291809, 8.78236103], [78.16291809, 8.78514194], [78.1626358, 8.78514194], [78.1626358, 8.78542042], [78.16236115, 8.7854166], [78.16236115, 8.78569317], [78.16208649, 8.78569317], [78.16208649, 8.78597355], [78.16179657, 8.78597069], [78.16179657, 8.78652954], [78.16152954, 8.78652954], [78.16152954, 8.78680992], [78.16124725, 8.78680992], [78.16124725, 8.7870903], [78.16042328, 8.7870903], [78.16042328, 8.78652954], [78.16014099, 8.78652954], [78.16014099, 8.78597069], [78.1598587, 8.78597355], [78.1598587, 8.78513908], [78.15957642, 8.78514194], [78.15957642, 8.78403187], [78.15930176, 8.78403187], [78.15930176, 8.78319073], [78.15958405, 8.78319454], [78.15958405, 8.78263855], [78.1598587, 8.78264141], [78.1598587, 8.78208065], [78.16014099, 8.78208256], [78.16014099, 8.78097343], [78.16041565, 8.78097343], [78.16041565, 8.77958298], [78.16069794, 8.77958298], [78.16069794, 8.7784729], [78.1609726, 8.7784729], [78.1609726, 8.77736092], [78.16124725, 8.77736092], [78.16124725, 8.77680683], [78.16152954, 8.77681065], [78.16152954, 8.77625084], [78.16179657, 8.77625084], [78.16179657, 8.77597046], [78.16208649, 8.77597332], [78.16208649, 8.77541733], [78.16236115, 8.77542114], [78.16236115, 8.7751503], [78.16152954, 8.7751503], [78.16152954, 8.77542114], [78.16124725, 8.77541733], [78.16124725, 8.77597332], [78.16098022, 8.77597046], [78.16098022, 8.77653122], [78.16069794, 8.7765274], [78.16069794, 8.7770834], [78.16014099, 8.7770834], [78.16014099, 8.77736092], [78.1590271, 8.77736092], [78.1590271, 8.7770834], [78.15875244, 8.7770834], [78.15875244, 8.77680683], [78.15847015, 8.77681065], [78.15847015, 8.77625084], [78.15821075, 8.77625084], [78.15821075, 8.77597046], [78.15791321, 8.77597332], [78.15791321, 8.77541733], [78.15763855, 8.77542114], [78.15763855, 8.77431107], [78.15735626, 8.77431107], [78.15735626, 8.77346992], [78.1570816, 8.77347183], [78.1570816, 8.77235985], [78.15736389, 8.77235985], [78.15736389, 8.77152824], [78.15763855, 8.77153111], [78.15763855, 8.77097034], [78.15791321, 8.77097225], [78.15791321, 8.77069378], [78.1581955, 8.77069378], [78.1581955, 8.77041626], [78.15847015, 8.77042103], [78.15847015, 8.77013969], [78.15875244, 8.77013969], [78.15875244, 8.76986027], [78.16042328, 8.76986027], [78.16042328, 8.77013969], [78.16069794, 8.77013969], [78.16069794, 8.77042103], [78.16041565, 8.77041626], [78.16041565, 8.77069378], [78.16069794, 8.77069378], [78.16069794, 8.77097225], [78.16098022, 8.77097034], [78.16098022, 8.77153111], [78.16124725, 8.77153111], [78.16124725, 8.77181053], [78.16152954, 8.77180576], [78.16152954, 8.77235985], [78.16179657, 8.77235985], [78.16179657, 8.77264118], [78.1626358, 8.77263832], [78.1626358, 8.77347183], [78.16291809, 8.77347183], [78.16291809, 8.77375126], [78.16374969, 8.77375126], [78.16374969, 8.77347183], [78.16402435, 8.77347183], [78.16402435, 8.77291584], [78.16485596, 8.77292061], [78.16485596, 8.77264118], [78.16652679, 8.77264118], [78.16652679, 8.77235985], [78.16680908, 8.77235985], [78.16680908, 8.77208233], [78.16707611, 8.77209091], [78.16707611, 8.77181053], [78.1673584, 8.77181053], [78.1673584, 8.77153111], [78.16792297, 8.77153111], [78.16792297, 8.77124977], [78.16819763, 8.77124977], [78.16819763, 8.77097034], [78.16847229, 8.77097225], [78.16847229, 8.77069378], [78.16874695, 8.77069378], [78.16874695, 8.77041626], [78.16929626, 8.77042103], [78.16929626, 8.77013969], [78.16986084, 8.77013969], [78.16986084, 8.76986027], [78.17069244, 8.76986217], [78.17069244, 8.7695837], [78.17124939, 8.7695837], [78.17124939, 8.76930618], [78.17180634, 8.76931095], [78.17180634, 8.76902103], [78.17263794, 8.76902771], [78.17263794, 8.76875019], [78.17319489, 8.76875019], [78.17318726, 8.76847172], [78.17402649, 8.76847172], [78.17402649, 8.7681942], [78.17485809, 8.7681942], [78.17485809, 8.76791573], [78.17563629, 8.76791573], [78.17624664, 8.76792145], [78.17624664, 8.76764011], [78.17791748, 8.76764011], [78.17791748, 8.76735973], [78.18013763, 8.76735973], [78.18013763, 8.76764011], [78.18041992, 8.76764011], [78.18041992, 8.76792145], [78.18068695, 8.76792145], [78.18068695, 8.77153111], [78.18096924, 8.77153111], [78.18096924, 8.77209091], [78.18125153, 8.77208233], [78.18125153, 8.77319431], [78.18180847, 8.77319431], [78.18180847, 8.77347183], [78.18208313, 8.77347183], [78.18208313, 8.77375126], [78.18264008, 8.77375126], [78.18264008, 8.77403069], [78.18319702, 8.77403069], [78.18319702, 8.77431107], [78.18347168, 8.77430439], [78.18347168, 8.77458191], [78.18402863, 8.77458191], [78.18402863, 8.77486038], [78.1845932, 8.77486038], [78.1845932, 8.7751503], [78.18486023, 8.7751503], [78.18486023, 8.77542114], [78.18541718, 8.77541733], [78.18541718, 8.77569485], [78.18569183, 8.77569485], [78.18569183, 8.77597332], [78.18624878, 8.77597046], [78.18624878, 8.77625084], [78.18653107, 8.77625084], [78.18653107, 8.77653122], [78.18708038, 8.77653122], [78.18708038, 8.77597046], [78.18680573, 8.77597332], [78.18680573, 8.77569485], [78.18624878, 8.77569485], [78.18624878, 8.77541733], [78.18569183, 8.77542114], [78.18569183, 8.7751503], [78.18541718, 8.7751503], [78.18541718, 8.77486038], [78.18486023, 8.77486038], [78.18486023, 8.77458477], [78.18430328, 8.77458191], [78.18430328, 8.77430439], [78.18374634, 8.77431107], [78.18374634, 8.77403069], [78.18347168, 8.77403069], [78.18347168, 8.77375126], [78.18319702, 8.77375126], [78.18319702, 8.77347183], [78.18291473, 8.77347183], [78.18291473, 8.77319431], [78.18264008, 8.77319431], [78.18264008, 8.77291584], [78.18235779, 8.77292061], [78.18235779, 8.77264118], [78.18209076, 8.77264118], [78.18209076, 8.77235985], [78.18180847, 8.77235985], [78.18180847, 8.77208233], [78.18152618, 8.77209091], [78.18152618, 8.77153111], [78.18180847, 8.77153111], [78.18180847, 8.77097034], [78.18208313, 8.77097225], [78.18208313, 8.77069378], [78.18270111, 8.77069378], [78.18347168, 8.77069378], [78.18347168, 8.77097225], [78.18402863, 8.77097225], [78.18402863, 8.77013779], [78.18430328, 8.77013969], [78.18430328, 8.76818943], [78.18458557, 8.7681942], [78.18458557, 8.76791573], [78.18624878, 8.76791573], [78.18624878, 8.7681942], [78.18653107, 8.7681942], [78.18653107, 8.76847172], [78.18680573, 8.76847172], [78.18680573, 8.76875019], [78.18708038, 8.76875019], [78.18708038, 8.76931095], [78.18736267, 8.76930618], [78.18736267, 8.7695837], [78.18763733, 8.7695837], [78.18763733, 8.76986217], [78.18791962, 8.76986217], [78.18791962, 8.76875019], [78.18763733, 8.76875019], [78.18763733, 8.7681942], [78.18736267, 8.7681942], [78.18736267, 8.76764011], [78.18708038, 8.76764011], [78.18708038, 8.76681137], [78.18681335, 8.76681137], [78.18681335, 8.76653004], [78.18736267, 8.76653004], [78.18736267, 8.76624966], [78.18763733, 8.76624966], [78.18763733, 8.76595974], [78.18819427, 8.76597214], [78.18819427, 8.76569366], [78.18875122, 8.76569366], [78.18875122, 8.76541805], [78.19097137, 8.76541805], [78.19097137, 8.76569366], [78.19152832, 8.76569366], [78.19152832, 8.76597214], [78.19180298, 8.76595974], [78.19180298, 8.76653004], [78.1920929, 8.76653004], [78.1920929, 8.76681137], [78.19319153, 8.76680565], [78.19319153, 8.76708412], [78.19403076, 8.76708031], [78.19403076, 8.76764011], [78.19430542, 8.76764011], [78.19430542, 8.76875019], [78.19458008, 8.76875019], [78.19458008, 8.77013969], [78.19431305, 8.77013969], [78.19431305, 8.77042103], [78.19486237, 8.77042103], [78.19486237, 8.77013969], [78.19568634, 8.77013969], [78.19568634, 8.77042103], [78.19596863, 8.77041626], [78.19596863, 8.77097225], [78.19625092, 8.77097034], [78.19625092, 8.77153111], [78.1965332, 8.77153111], [78.1965332, 8.77209091], [78.19735718, 8.77209091], [78.19735718, 8.77264118], [78.19763947, 8.77263832], [78.19763947, 8.77319431], [78.19790649, 8.77318954], [78.19790649, 8.77403069], [78.19819641, 8.77402878], [78.19819641, 8.77486038], [78.19847107, 8.77486038], [78.19847107, 8.77542114], [78.19819641, 8.77541733], [78.19819641, 8.77569485], [78.19790649, 8.77569008], [78.19790649, 8.77625084], [78.19763947, 8.77625084], [78.19763947, 8.77653122], [78.19625092, 8.77653122], [78.19625092, 8.77597046], [78.19596863, 8.77597332], [78.19596863, 8.77541733], [78.19568634, 8.77542114], [78.19568634, 8.77486038], [78.19541931, 8.77486038], [78.19541931, 8.77347183], [78.19513702, 8.77347183], [78.19513702, 8.77208233], [78.19486237, 8.77209091], [78.19486237, 8.77153111], [78.19458008, 8.77153111], [78.19458008, 8.77124977], [78.19430542, 8.77124977], [78.19430542, 8.77235985], [78.19403076, 8.77235985], [78.19403076, 8.77403069], [78.19374847, 8.77403069], [78.19374847, 8.77431107], [78.19347382, 8.77430439], [78.19347382, 8.77458191], [78.19374847, 8.77458], [78.19374847, 8.7751503], [78.19403076, 8.77513885], [78.19403076, 8.77986145], [78.19347382, 8.77986145], [78.19347382, 8.77958298], [78.19291687, 8.77958298], [78.19291687, 8.77930546], [78.19235992, 8.77930927], [78.19235992, 8.77902889], [78.19180298, 8.77902889], [78.19180298, 8.77875137], [78.19095612, 8.77875137], [78.19095612, 8.77902889], [78.19124603, 8.77902889], [78.19124603, 8.77930927], [78.19152832, 8.77930546], [78.19152832, 8.77986145], [78.19180298, 8.77986145], [78.19180298, 8.78014088], [78.1920929, 8.78014088], [78.1920929, 8.78041935], [78.19264221, 8.78041744], [78.19264221, 8.78069496], [78.19291687, 8.78069496], [78.19291687, 8.78097343], [78.19346619, 8.78096199], [78.19346619, 8.78125095], [78.19374847, 8.78125095], [78.19374847, 8.78153229], [78.19430542, 8.78152657], [78.19430542, 8.78208256], [78.19458008, 8.78208065], [78.19458008, 8.78292179], [78.19431305, 8.78292179], [78.19431305, 8.78403187], [78.19403076, 8.78403187], [78.19403076, 8.78514194], [78.19374847, 8.78513908], [78.19374847, 8.78569317], [78.19347382, 8.78569317], [78.19347382, 8.78597355], [78.19319153, 8.78597069], [78.19319153, 8.78652954], [78.19291687, 8.78652954], [78.19291687, 8.78680992], [78.19264221, 8.78680515], [78.19264221, 8.7873621], [78.19235992, 8.78735924], [78.19235992, 8.78792], [78.19208527, 8.78791809], [78.19208527, 8.78819561], [78.19180298, 8.78819561], [78.19180298, 8.78847122], [78.19152832, 8.78846931], [78.19152832, 8.78903198], [78.19180298, 8.78903198], [78.19180298, 8.78931046], [78.1920929, 8.78931046], [78.1920929, 8.78903198], [78.19291687, 8.78903198], [78.19291687, 8.78874969], [78.19319153, 8.78874969], [78.19319153, 8.78819084], [78.19347382, 8.78819561], [78.19347382, 8.78791809], [78.19374847, 8.78792], [78.19374847, 8.78763962], [78.19486237, 8.78763962], [78.19486237, 8.78792], [78.19541931, 8.78791809], [78.19541931, 8.78819561], [78.19596863, 8.78819561], [78.19596863, 8.78847122], [78.1965332, 8.78846931], [78.1965332, 8.78874969], [78.19709015, 8.78874969], [78.19709015, 8.78903198], [78.19847107, 8.78903198], [78.19847107, 8.78874969], [78.19902802, 8.78874969], [78.19902802, 8.78846931], [78.19930267, 8.78847122], [78.19930267, 8.78791809], [78.19957733, 8.78792], [78.19957733, 8.78735924], [78.19930267, 8.7873621], [78.19930267, 8.78680515], [78.19902802, 8.78680992], [78.19902802, 8.78625202], [78.19930267, 8.78625202], [78.19930267, 8.78542042], [78.19957733, 8.78542042], [78.19957733, 8.78403187], [78.19985962, 8.78403187], [78.19985962, 8.78153229], [78.19957733, 8.78153229], [78.19957733, 8.77818966], [78.19930267, 8.77819538], [78.19930267, 8.77458477], [78.19902802, 8.77458191], [78.19902802, 8.77124977], [78.19875336, 8.77124977], [78.19875336, 8.76792145], [78.19847107, 8.76792145], [78.19847107, 8.7656889], [78.19875336, 8.76569366], [78.19875336, 8.76486206], [78.19902802, 8.76486206], [78.19902802, 8.76430607], [78.19985962, 8.76431274], [78.19985962, 8.76403046], [78.20041656, 8.76403046], [78.20041656, 8.76375198], [78.20124817, 8.76375198], [78.20124817, 8.7634716], [78.20207977, 8.7634716], [78.20207977, 8.76319408], [78.20291901, 8.76319408], [78.20291901, 8.76291561], [78.20347595, 8.76292038], [78.20347595, 8.76264191], [78.20430756, 8.76264191], [78.20430756, 8.76236153], [78.20513916, 8.76236153], [78.20513916, 8.76208401], [78.20569611, 8.76208401], [78.20569611, 8.76180553], [78.20625305, 8.7618103], [78.20625305, 8.76152992], [78.20680237, 8.76152992], [78.20680237, 8.76124859], [78.20735931, 8.76124859], [78.20735931, 8.76097107], [78.20791626, 8.76097107], [78.20791626, 8.7606926], [78.20874786, 8.7606926], [78.20874786, 8.76041794], [78.20929718, 8.76041985], [78.20929718, 8.76015091], [78.20986176, 8.76015091], [78.20986176, 8.75986099], [78.2104187, 8.75986099], [78.2104187, 8.75958347], [78.21097565, 8.75958347], [78.21097565, 8.759305], [78.21151733, 8.75930977], [78.21151733, 8.75903034], [78.21235657, 8.75903034], [78.21235657, 8.75875187], [78.2131958, 8.75875187], [78.2131958, 8.75847054], [78.2140274, 8.7584734], [78.2140274, 8.75819302], [78.21485901, 8.75819302], [78.21485901, 8.7579174], [78.21569061, 8.75792027], [78.21569824, 8.75764179], [78.21652985, 8.75764179], [78.21652985, 8.75736141], [78.21763611, 8.75736141], [78.21763611, 8.75708294], [78.21875, 8.75708294], [78.21875, 8.75680542], [78.2195816, 8.75681019], [78.2195816, 8.75653172], [78.22070313, 8.75653172], [78.22070313, 8.75625134], [78.22180176, 8.75625134], [78.22180176, 8.75597095], [78.2234726, 8.75597095], [78.2234726, 8.75513935], [78.22374725, 8.75514126], [78.22374725, 8.75458145], [78.22402954, 8.75458336], [78.22402954, 8.75430489], [78.22458649, 8.75430965], [78.22458649, 8.75401974], [78.2251358, 8.75402737], [78.2251358, 8.75374889], [78.22541809, 8.75374889], [78.22541809, 8.75347328], [78.22597504, 8.75347328], [78.22597504, 8.75319481], [78.22652435, 8.75319481], [78.22652435, 8.75291729], [78.22680664, 8.7529192], [78.22680664, 8.75264072], [78.22706604, 8.75264072], [78.22706604, 8.7523613], [78.22736359, 8.7523613], [78.22736359, 8.75208282], [78.22763824, 8.75208282], [78.22763824, 8.75180531], [78.2279129, 8.75181198], [78.2279129, 8.75153065], [78.22820282, 8.75153065], [78.22820282, 8.75125122], [78.22846985, 8.75125122], [78.22846985, 8.75097275], [78.22875214, 8.75098038], [78.22875214, 8.75042057], [78.22902679, 8.75042057], [78.22902679, 8.75014114], [78.22930908, 8.75014114], [78.22930908, 8.7498579], [78.22958374, 8.74986076], [78.22958374, 8.74958324], [78.2298584, 8.74958324], [78.2298584, 8.74930668], [78.23013306, 8.74931145], [78.23013306, 8.74875069], [78.2298584, 8.74875069], [78.2298584, 8.74818993], [78.2279129, 8.74818993], [78.2279129, 8.74875069], [78.22763824, 8.74875069], [78.22763824, 8.74903107], [78.22735596, 8.74903107], [78.22735596, 8.74931145], [78.2270813, 8.74930668], [78.2270813, 8.74986076], [78.22680664, 8.7498579], [78.22680664, 8.75014114], [78.22652435, 8.75013924], [78.22652435, 8.75069523], [78.22624969, 8.75069046], [78.22624969, 8.75098038], [78.22597504, 8.75097275], [78.22597504, 8.75125122], [78.22569275, 8.75125122], [78.22569275, 8.75181198], [78.22541809, 8.75180531], [78.22541809, 8.75208282], [78.22486115, 8.75208282], [78.22486115, 8.7523613], [78.22458649, 8.7523613], [78.22458649, 8.75264072], [78.22374725, 8.75264072], [78.22374725, 8.7529192], [78.22291565, 8.75291729], [78.22291565, 8.75319481], [78.22208405, 8.75319481], [78.22208405, 8.75347328], [78.22125244, 8.75347328], [78.22125244, 8.75374889], [78.22013855, 8.75374889], [78.22013855, 8.75402737], [78.21901703, 8.75401974], [78.21901703, 8.75430965], [78.21819305, 8.75430489], [78.21819305, 8.75458336], [78.21736145, 8.75458336], [78.21736145, 8.75486088], [78.21679688, 8.75486088], [78.21679688, 8.75514126], [78.2159729, 8.75514126], [78.2159729, 8.75542164], [78.21541595, 8.75541687], [78.21541595, 8.75569534], [78.21485901, 8.75569534], [78.21485901, 8.75597095], [78.2140274, 8.75597095], [78.2140274, 8.75625134], [78.21347046, 8.75625134], [78.21347046, 8.75653172], [78.21290588, 8.75653172], [78.21290588, 8.75681019], [78.2123642, 8.75680542], [78.2123642, 8.75708294], [78.21180725, 8.75708294], [78.21180725, 8.75736141], [78.21098328, 8.75736141], [78.21098328, 8.75764179], [78.2104187, 8.75764179], [78.2104187, 8.75792027], [78.20986176, 8.7579174], [78.20986176, 8.75819302], [78.20930481, 8.75819492], [78.20930481, 8.7584734], [78.20874786, 8.75847054], [78.20874786, 8.75875187], [78.20791626, 8.75875187], [78.20791626, 8.75903034], [78.20735931, 8.75903034], [78.20735931, 8.75930977], [78.20680237, 8.759305], [78.20680237, 8.75958347], [78.20625305, 8.75958347], [78.20625305, 8.75986099], [78.20540619, 8.75986099], [78.20540619, 8.76015091], [78.20485687, 8.76015091], [78.20485687, 8.76041985], [78.20430756, 8.76041794], [78.20430756, 8.7606926], [78.20375061, 8.7606926], [78.20375061, 8.76097107], [78.20291901, 8.76097107], [78.20291901, 8.76124859], [78.20236206, 8.76124859], [78.20236206, 8.76152992], [78.20181274, 8.76152992], [78.20181274, 8.7618103], [78.20097351, 8.76180553], [78.20097351, 8.76208401], [78.20014191, 8.76208401], [78.20014191, 8.76236153], [78.19957733, 8.76236153], [78.19957733, 8.76264191], [78.19875336, 8.76264191], [78.19875336, 8.76292038], [78.19819641, 8.76291561], [78.19819641, 8.76319408], [78.19763947, 8.76319408], [78.19763947, 8.76291561], [78.19735718, 8.76292038], [78.19735718, 8.76264191], [78.19763947, 8.76264191], [78.19763947, 8.76236153], [78.19791412, 8.76236153], [78.19791412, 8.76208401], [78.19819641, 8.76208401], [78.19819641, 8.76180553], [78.19847107, 8.7618103], [78.19847107, 8.76124859], [78.19875336, 8.76124859], [78.19875336, 8.76097107], [78.19902802, 8.76097107], [78.19902802, 8.7606926], [78.19930267, 8.7606926], [78.19930267, 8.76041794], [78.19957733, 8.76041985], [78.19957733, 8.75986099], [78.19985962, 8.75986099], [78.19985962, 8.759305], [78.20041656, 8.75930977], [78.20041656, 8.75903034], [78.20069122, 8.75903034], [78.20069122, 8.75875187], [78.20124817, 8.75875187], [78.20124817, 8.75764179], [78.20096588, 8.75764179], [78.20096588, 8.75653172], [78.20069122, 8.75653172], [78.20069122, 8.75597095], [78.20041656, 8.75597095], [78.20041656, 8.75541687], [78.20012665, 8.75542164], [78.20012665, 8.75486088], [78.19985962, 8.75486088], [78.19985962, 8.75430489], [78.19957733, 8.75430965], [78.19957733, 8.75319004], [78.19985962, 8.75319481], [78.19985962, 8.75291729], [78.20041656, 8.7529192], [78.20041656, 8.75264072], [78.20069122, 8.75264072], [78.20069122, 8.7523613], [78.20097351, 8.7523613], [78.20097351, 8.75208282], [78.20153046, 8.75208282], [78.20153046, 8.75180531], [78.20181274, 8.75181198], [78.20181274, 8.75153065], [78.20263672, 8.75153065], [78.20263672, 8.75125122], [78.20319366, 8.75125122], [78.20318604, 8.75098038], [78.20485687, 8.75098038], [78.20485687, 8.75069046], [78.20569611, 8.75069523], [78.20569611, 8.75041676], [78.20625305, 8.75042057], [78.20625305, 8.75014114], [78.20680237, 8.75014114], [78.20680237, 8.7498579], [78.20735931, 8.74986076], [78.20735931, 8.74958324], [78.20819092, 8.74958324], [78.20819092, 8.74930668], [78.20847321, 8.74931145], [78.20847321, 8.74903107], [78.20874786, 8.74903107], [78.20874786, 8.74847031], [78.20903015, 8.74847317], [78.20903015, 8.74819469], [78.20930481, 8.74819469], [78.20930481, 8.74791718], [78.2095871, 8.74792099], [78.2095871, 8.74764061], [78.21206665, 8.74764061], [78.21206665, 8.74792099], [78.2123642, 8.74791718], [78.2123642, 8.74819469], [78.21291351, 8.74819469], [78.21291351, 8.74847317], [78.2131958, 8.74847031], [78.2131958, 8.75014114], [78.21347046, 8.75014114], [78.21347046, 8.75042057], [78.21375275, 8.75041676], [78.21375275, 8.75069523], [78.2140274, 8.75069046], [78.2140274, 8.75098038], [78.21430206, 8.75097275], [78.21430206, 8.75125122], [78.21457672, 8.75125122], [78.21457672, 8.75153065], [78.21624756, 8.75153065], [78.21624756, 8.75125122], [78.21652985, 8.75125122], [78.21652985, 8.75097275], [78.21679688, 8.75098038], [78.21679688, 8.75069046], [78.21708679, 8.75069523], [78.21708679, 8.74986076], [78.21736145, 8.74986076], [78.21736145, 8.74875069], [78.21763611, 8.74875069], [78.21763611, 8.74792099], [78.21736145, 8.74792099], [78.21736145, 8.74736023], [78.21708679, 8.74736023], [78.21708679, 8.74708462], [78.2159729, 8.74708462], [78.2159729, 8.74680424], [78.21569824, 8.74681091], [78.21569061, 8.74653053], [78.21541595, 8.74653053], [78.21541595, 8.74625015], [78.21512604, 8.74625015], [78.21512604, 8.74596977], [78.21485901, 8.74597168], [78.21485901, 8.74513817], [78.21763611, 8.74514103], [78.21763611, 8.74542141], [78.21819305, 8.74541569], [78.21819305, 8.74569416], [78.21847534, 8.74569416], [78.21847534, 8.74597168], [78.21901703, 8.74596977], [78.21901703, 8.74625015], [78.21930695, 8.74625015], [78.21930695, 8.74653053], [78.21985626, 8.74653053], [78.21985626, 8.74681091], [78.22013855, 8.74680424], [78.22013855, 8.74736023], [78.21985626, 8.74736023], [78.21985626, 8.74792099], [78.2206955, 8.74791718], [78.2206955, 8.74819469], [78.22208405, 8.74819469], [78.22208405, 8.74847317], [78.2234726, 8.74847317], [78.2234726, 8.74597168], [78.22291565, 8.74597168], [78.22291565, 8.74569416], [78.2223587, 8.74569416], [78.2223587, 8.74541569], [78.22180176, 8.74542141], [78.22180176, 8.74514103], [78.22126007, 8.74514103], [78.22126007, 8.74485111], [78.22041321, 8.7448597], [78.22041321, 8.74458218], [78.21986389, 8.74458218], [78.21986389, 8.74430561], [78.21930695, 8.74431133], [78.21930695, 8.74403095], [78.21875, 8.74403095], [78.21875, 8.74374962], [78.21819305, 8.74374962], [78.21819305, 8.74347019], [78.2179184, 8.7434721], [78.2179184, 8.74319363], [78.21736145, 8.74319363], [78.21736145, 8.74291611], [78.21679688, 8.74292088], [78.21679688, 8.74263954], [78.2159729, 8.74263954], [78.2159729, 8.74292088], [78.21541595, 8.74291611], [78.21541595, 8.74319363], [78.21485901, 8.74319363], [78.21485901, 8.7434721], [78.21430206, 8.74347019], [78.21430206, 8.74374962], [78.21375275, 8.74374962], [78.21375275, 8.74403095], [78.2131958, 8.74403095], [78.2131958, 8.74431133], [78.21263885, 8.74430561], [78.21263885, 8.74458218], [78.21208191, 8.74458218], [78.21208191, 8.7448597], [78.21180725, 8.74485111], [78.21180725, 8.74514103], [78.21125031, 8.74514103], [78.21125031, 8.74542141], [78.21069336, 8.74541569], [78.21069336, 8.74569416], [78.21013641, 8.74569416], [78.21013641, 8.74597168], [78.2095871, 8.74597168], [78.2095871, 8.74625015], [78.20903015, 8.74625015], [78.20903015, 8.74653053], [78.20847321, 8.74653053], [78.20847321, 8.74681091], [78.20791626, 8.74680424], [78.20791626, 8.74708462], [78.20735931, 8.74708462], [78.20735931, 8.74736023], [78.20680237, 8.74736023], [78.20680237, 8.74764061], [78.20625305, 8.74764061], [78.20625305, 8.74792099], [78.20541382, 8.74791718], [78.20541382, 8.74819469], [78.2048645, 8.74819469], [78.2048645, 8.74847317], [78.20430756, 8.74847031], [78.20430756, 8.74875069], [78.20375061, 8.74875069], [78.20375061, 8.74903107], [78.20318604, 8.74903107], [78.20318604, 8.74931145], [78.20263672, 8.74930668], [78.20263672, 8.74958324], [78.20180511, 8.74958324], [78.20180511, 8.74986076], [78.20124817, 8.7498579], [78.20124817, 8.75014114], [78.20069122, 8.75014114], [78.20069122, 8.75042057], [78.20014191, 8.75041676], [78.20014191, 8.75069523], [78.19957733, 8.75069046], [78.19957733, 8.75098038], [78.19902802, 8.75097275], [78.19902802, 8.75125122], [78.19819641, 8.75125122], [78.19819641, 8.75153065], [78.19763947, 8.75153065], [78.19763947, 8.75181198], [78.19708252, 8.75180531], [78.19708252, 8.75208282], [78.19625092, 8.75208282], [78.19625092, 8.7523613], [78.19513702, 8.7523613], [78.19513702, 8.75264072], [78.19374847, 8.75264072], [78.19374847, 8.75208092], [78.19347382, 8.75208282], [78.19347382, 8.75152683], [78.19319153, 8.75153065], [78.19319153, 8.75125122], [78.19291687, 8.75125122], [78.19291687, 8.75069523], [78.19264221, 8.75069523], [78.19264221, 8.75041676], [78.19235992, 8.75042057], [78.19235992, 8.7498579], [78.19208527, 8.74986076], [78.19208527, 8.74930668], [78.19180298, 8.74931145], [78.19180298, 8.74903107], [78.19152832, 8.74903107], [78.19152832, 8.74847031], [78.19125366, 8.74847317], [78.19125366, 8.74791718], [78.19069672, 8.74791718], [78.19069672, 8.74819469], [78.19013977, 8.74819469], [78.19013977, 8.74847317], [78.18958282, 8.74847031], [78.18958282, 8.74875069], [78.18846893, 8.74875069], [78.18846893, 8.74903107], [78.18736267, 8.74903107], [78.18736267, 8.74931145], [78.18624878, 8.74930668], [78.18624878, 8.74958324], [78.18264008, 8.74958324], [78.18264008, 8.74930668], [78.18187714, 8.74930859], [78.18125153, 8.74931145], [78.18125153, 8.74903107], [78.18041992, 8.74903107], [78.18041992, 8.74875069], [78.17958069, 8.74875069], [78.17958069, 8.74847031], [78.17874908, 8.74847317], [78.17874908, 8.74819469], [78.17763519, 8.74819469], [78.17763519, 8.74791718], [78.17679596, 8.74792099], [78.17679596, 8.74764061], [78.17595673, 8.74764061], [78.17595673, 8.74736023], [78.17514038, 8.74736023], [78.17514038, 8.74708462], [78.17458344, 8.74708462], [78.17458344, 8.74680424], [78.17402649, 8.74681091], [78.17402649, 8.74653053], [78.17346954, 8.74653053], [78.17346954, 8.74625015], [78.17263794, 8.74625015], [78.17263794, 8.74597168], [78.17208099, 8.74597168], [78.17208099, 8.74569416], [78.17152405, 8.74569416], [78.17152405, 8.74541569], [78.17124939, 8.74542141], [78.17124939, 8.74514103], [78.17069244, 8.74514103], [78.17069244, 8.74485111], [78.17041779, 8.7448597], [78.17041779, 8.74458218], [78.1701355, 8.74458218], [78.1701355, 8.74430561], [78.16986084, 8.74431133], [78.16986084, 8.74403095], [78.16929626, 8.74403095], [78.16929626, 8.74374962], [78.16902924, 8.74374962], [78.16902924, 8.74347019], [78.16874695, 8.7434721], [78.16874695, 8.74319363], [78.16847229, 8.74319363], [78.16847229, 8.74291611], [78.16792297, 8.74292088], [78.16792297, 8.74263954], [78.16764069, 8.74263954], [78.16764069, 8.74236012], [78.1673584, 8.74236012], [78.1673584, 8.74208355], [78.16708374, 8.74208355], [78.16708374, 8.74180603], [78.16652679, 8.7418108], [78.16652679, 8.74153042], [78.16625214, 8.74153042], [78.16625214, 8.74125004], [78.16596985, 8.74125004], [78.16596985, 8.74096966], [78.16569519, 8.74097157], [78.16569519, 8.74069405], [78.1654129, 8.74069405], [78.1654129, 8.74041557], [78.16513824, 8.74042034], [78.16513824, 8.74013996], [78.16485596, 8.74013996], [78.16485596, 8.73985958], [78.1645813, 8.73986244], [78.1645813, 8.73930645], [78.16430664, 8.73931122], [78.16430664, 8.73903942], [78.16401672, 8.73903942], [78.16401672, 8.73875046], [78.16374969, 8.73875046], [78.16374969, 8.73847198], [78.16347504, 8.73847198], [78.16347504, 8.73819447], [78.16319275, 8.73819447], [78.16319275, 8.7379179], [78.16291809, 8.7379179], [78.16291809, 8.73764038], [78.1626358, 8.73764038], [78.1626358, 8.73736191], [78.16236115, 8.73736191], [78.16236115, 8.73680592], [78.16208649, 8.73680973], [78.16208649, 8.73625183], [78.16179657, 8.73625183], [78.16179657, 8.73569107], [78.16152954, 8.73569584], [78.16152954, 8.73541546], [78.16124725, 8.73542023], [78.16124725, 8.73485947], [78.1609726, 8.73486233], [78.1609726, 8.73430634], [78.16069794, 8.73431015], [78.16069794, 8.73374939], [78.16041565, 8.73374939], [78.16041565, 8.7331934], [78.16014099, 8.7331934], [78.16014099, 8.73291779], [78.1598587, 8.73291779], [78.1598587, 8.73236084], [78.15957642, 8.73236084], [78.15957642, 8.73180962], [78.15930176, 8.73180962], [78.15930176, 8.73125172], [78.1590271, 8.73125172], [78.1590271, 8.73097134], [78.15875244, 8.73097134], [78.15875244, 8.73041725], [78.15847015, 8.73042202], [78.15847015, 8.72985172], [78.1581955, 8.72986126], [78.1581955, 8.72930527], [78.15792084, 8.72931194], [78.15792084, 8.7284708], [78.15763855, 8.7284708], [78.15763855, 8.72736073], [78.15735626, 8.72736073], [78.15735626, 8.72625065], [78.1570816, 8.72625065], [78.1570816, 8.72514057], [78.15680695, 8.72514057], [78.15680695, 8.72431183], [78.15651703, 8.72431183], [78.15651703, 8.72319031], [78.15625, 8.72319508], [78.15625, 8.72208309], [78.15597534, 8.72208309], [78.15597534, 8.72125053], [78.15569305, 8.72125053], [78.15569305, 8.72014141], [78.1554184, 8.72014141], [78.1554184, 8.71542072], [78.15513611, 8.71542072], [78.15513611, 8.71403027], [78.15484619, 8.71403027], [78.15484619, 8.71264172], [78.15458679, 8.71264172], [78.15458679, 8.71181011], [78.15429688, 8.71181011], [78.15429688, 8.71152973], [78.15402985, 8.71152973], [78.15402985, 8.71097183], [78.15374756, 8.71097183], [78.15374756, 8.71069431], [78.1534729, 8.71069431], [78.1534729, 8.71041775], [78.15319824, 8.71041965], [78.15319061, 8.70997334], [78.15319061, 8.70986176], [78.15291595, 8.70986176], [78.15291595, 8.70958424], [78.1526413, 8.70958424], [78.1526413, 8.70930576], [78.15235901, 8.70930958], [78.15235901, 8.70874977], [78.15207672, 8.70874977], [78.15207672, 8.70846939], [78.15180206, 8.70847225], [78.15180206, 8.70819569], [78.1515274, 8.70819569], [78.1515274, 8.70791531], [78.15125275, 8.70792007], [78.15125275, 8.70763969], [78.1506958, 8.70763969], [78.1506958, 8.70735931], [78.15041351, 8.70736217], [78.15041351, 8.7070837], [78.15013885, 8.7070837], [78.15013885, 8.70680523], [78.14985657, 8.70681], [78.14985657, 8.70652962], [78.14958191, 8.70652962], [78.14958191, 8.70624924], [78.14901733, 8.70624924], [78.14901733, 8.70596886], [78.14875031, 8.70597363], [78.14875031, 8.70569324], [78.14847565, 8.70569324], [78.14847565, 8.70541763], [78.14819336, 8.70541954], [78.14819336, 8.70514202], [78.1479187, 8.70514202], [78.1479187, 8.70486069], [78.14736176, 8.70486069], [78.14736176, 8.70458317], [78.1470871, 8.70458317], [78.1470871, 8.7043047], [78.14679718, 8.70431042], [78.14679718, 8.70403194], [78.14653015, 8.70403194], [78.14653015, 8.70390034], [78.14653015, 8.7037487], [78.14624786, 8.70375061], [78.14624786, 8.70347118], [78.14569092, 8.70347118], [78.14569092, 8.70319462], [78.14541626, 8.70319462], [78.14541626, 8.7029171], [78.1451416, 8.7029314], [78.1451416, 8.70264244], [78.14485931, 8.70264244], [78.14485931, 8.70236111], [78.14458466, 8.70236111], [78.14458466, 8.70208263], [78.14430237, 8.70208263], [78.14430237, 8.70180511], [78.14402771, 8.70181179], [78.14402771, 8.70153236], [78.14375305, 8.70153236], [78.14375305, 8.70125103], [78.14347076, 8.70125103], [78.14347076, 8.70097065], [78.14319611, 8.70097256], [78.14319611, 8.70069504], [78.14263916, 8.70069504], [78.14263916, 8.70041656], [78.14235687, 8.70041943], [78.14235687, 8.70014095], [78.14208221, 8.70014095], [78.14208221, 8.69987011], [78.14180756, 8.69987011], [78.14180756, 8.69958115], [78.14152527, 8.69958305], [78.14152527, 8.69930458], [78.14125061, 8.69930935], [78.14125061, 8.69903088], [78.14097595, 8.69903088], [78.14097595, 8.69875145], [78.14068604, 8.69875145], [78.14068604, 8.69847107], [78.14041901, 8.69847298], [78.14041901, 8.69791698], [78.14013672, 8.69791889], [78.14013672, 8.69736099], [78.1398468, 8.69736099], [78.1398468, 8.69680023], [78.13957977, 8.69680691], [78.13957977, 8.69625092], [78.13931274, 8.69625092], [78.13931274, 8.6957016], [78.13903046, 8.69569016], [78.13903046, 8.69513893], [78.13874817, 8.69514084], [78.13874817, 8.69458008], [78.13847351, 8.69458199], [78.13847351, 8.69402885], [78.13819122, 8.69402885], [78.13819122, 8.69347], [78.13791656, 8.69347286], [78.13791656, 8.69319439], [78.13764191, 8.69319439], [78.13764191, 8.6926384], [78.13735962, 8.69264126], [78.13735962, 8.69207954], [78.13708496, 8.69208241], [78.13708496, 8.69152832], [78.1368103, 8.69153118], [78.1368103, 8.69097042], [78.13652802, 8.69097233], [78.13652802, 8.69041634], [78.13625336, 8.6904211], [78.13625336, 8.68986034], [78.13597107, 8.68986225], [78.13597107, 8.68930626], [78.13569641, 8.68931103], [78.13569641, 8.68875027], [78.13540649, 8.68875027], [78.13540649, 8.68793201], [78.13513947, 8.68793201], [78.13513947, 8.68681145], [78.13485718, 8.68681145], [78.13485718, 8.68569183], [78.13458252, 8.68569374], [78.13458252, 8.68458366], [78.13430786, 8.68458366], [78.13430786, 8.68347168], [78.13402557, 8.68347168], [78.13402557, 8.68208408], [78.13375092, 8.68208408], [78.13375092, 8.68069553], [78.13346863, 8.68069553], [78.13346863, 8.67930508], [78.13318634, 8.67930984], [78.13318634, 8.67792034], [78.13291931, 8.67792034], [78.13291931, 8.67542171], [78.13263702, 8.67542171], [78.13263702, 8.67430973], [78.13236237, 8.67430973], [78.13236237, 8.67319107], [78.13208008, 8.67319489], [78.13208008, 8.67236137], [78.13180542, 8.67236137], [78.13180542, 8.6706953], [78.13208008, 8.6706953], [78.13208008, 8.66875076], [78.13236237, 8.66875076], [78.13236237, 8.66736031], [78.13208008, 8.66736031], [78.13208008, 8.6665287], [78.13181305, 8.66653061], [78.13181305, 8.66596985], [78.13153076, 8.66597176], [78.13153076, 8.66513824], [78.13124847, 8.66514111], [78.13124847, 8.66431141], [78.13096619, 8.66431141], [78.13096619, 8.66375923], [78.13069153, 8.66375923], [78.13069153, 8.66403103], [78.13041687, 8.66403103], [78.13041687, 8.66431141], [78.12958527, 8.66430569], [78.12958527, 8.66458225], [78.12819672, 8.66458225], [78.12819672, 8.66430569], [78.12708282, 8.66430569], [78.12708282, 8.66458225], [78.12652588, 8.66458225], [78.12652588, 8.66402817], [78.12625122, 8.66403103], [78.12625122, 8.66347027], [78.12652588, 8.66347218], [78.12652588, 8.6631937], [78.12680817, 8.6631937], [78.12680817, 8.66236019], [78.12652588, 8.66236019], [78.12652588, 8.66180611], [78.12625122, 8.66181087], [78.12625122, 8.66152954], [78.12596893, 8.66152954], [78.12596893, 8.66125011], [78.12568665, 8.66125011], [78.12568665, 8.66096973], [78.12541962, 8.66097164], [78.12541962, 8.66069412], [78.12625122, 8.66069412], [78.12625122, 8.66097164], [78.12680817, 8.66096973], [78.12680817, 8.66125011], [78.12708282, 8.66125011], [78.12708282, 8.66152954], [78.12735748, 8.66152954], [78.12735748, 8.66181087], [78.12763977, 8.66180611], [78.12763977, 8.66208363], [78.12819672, 8.66208363], [78.12819672, 8.66236019], [78.12847137, 8.66236019], [78.12847137, 8.66263962], [78.12985992, 8.66263962], [78.12985992, 8.66292095], [78.13069153, 8.66292095], [78.13069153, 8.66236019], [78.13041687, 8.66236019], [78.13041687, 8.66180611], [78.13014221, 8.66181087], [78.13014221, 8.66125011], [78.12985992, 8.66125011], [78.12985992, 8.6607008], [78.1295929, 8.6607008], [78.1295929, 8.66014004], [78.12930298, 8.66014004], [78.12930298, 8.65958023], [78.12902832, 8.65958405], [78.12902832, 8.65847206], [78.12875366, 8.65847206], [78.12875366, 8.6576376], [78.12847137, 8.6576376], [78.12847137, 8.65513992], [78.12819672, 8.65513992], [78.12819672, 8.65347099], [78.12791443, 8.65347099], [78.12791443, 8.65180492], [78.12763977, 8.65181923], [78.12763977, 8.65042019], [78.12735748, 8.65041733], [78.12735748, 8.65097141], [78.12680817, 8.65097141], [78.12680817, 8.65125179], [78.12625122, 8.65125179], [78.12625122, 8.65153027], [78.12568665, 8.65153027], [78.12568665, 8.65181923], [78.12541962, 8.65180492], [78.12541962, 8.6520834], [78.12486267, 8.6520834], [78.12486267, 8.65236187], [78.12431335, 8.65236187], [78.12431335, 8.65264034], [78.12374878, 8.65264034], [78.12374878, 8.65291977], [78.12264252, 8.65291786], [78.12264252, 8.65319347], [78.12152863, 8.65319061], [78.12152863, 8.65402985], [78.12124634, 8.65402794], [78.12124634, 8.65458393], [78.12208557, 8.65458393], [78.12208557, 8.6548624], [78.12264252, 8.65485859], [78.12264252, 8.65513992], [78.12291718, 8.65513992], [78.12291718, 8.65569401], [78.12319183, 8.65569401], [78.12319183, 8.65597153], [78.12346649, 8.65597153], [78.12346649, 8.65653038], [78.12374878, 8.65652847], [78.12374878, 8.65708447], [78.12403107, 8.65708447], [78.12403107, 8.65458393], [78.12430573, 8.65458393], [78.12430573, 8.65402794], [78.12458038, 8.65402985], [78.12458038, 8.65374947], [78.12541962, 8.65374947], [78.12541962, 8.65402985], [78.12596893, 8.65402985], [78.12596893, 8.65431023], [78.12625122, 8.65430641], [78.12625122, 8.6548624], [78.12596893, 8.65485859], [78.12596893, 8.65513992], [78.12568665, 8.65513992], [78.12568665, 8.6554203], [78.12541962, 8.65541553], [78.12541962, 8.65597153], [78.12568665, 8.65597153], [78.12568665, 8.65625191], [78.12596893, 8.65625191], [78.12596893, 8.6568079], [78.12625122, 8.65680599], [78.12625122, 8.65708447], [78.12652588, 8.65708447], [78.12652588, 8.65819359], [78.12625122, 8.65819168], [78.12625122, 8.65874958], [78.12596893, 8.65874958], [78.12596893, 8.65902996], [78.12568665, 8.65902996], [78.12568665, 8.65931129], [78.12541962, 8.65930557], [78.12541962, 8.65958405], [78.12403107, 8.65958405], [78.12403107, 8.65930557], [78.12319183, 8.65930557], [78.12319183, 8.65986156], [78.12236023, 8.65986156], [78.12236023, 8.65930557], [78.12210083, 8.65931129], [78.12210083, 8.65874958], [78.12069702, 8.65874958], [78.12069702, 8.65902996], [78.11958313, 8.65902996], [78.11958313, 8.6607008], [78.12319183, 8.6607008], [78.12319183, 8.66125011], [78.12291718, 8.66125011], [78.12291718, 8.66181087], [78.12264252, 8.66180611], [78.12264252, 8.66236019], [78.11902618, 8.66236019], [78.11902618, 8.66208363], [78.11736298, 8.66208363], [78.11736298, 8.66180611], [78.11708069, 8.66181087], [78.11708069, 8.66152954], [78.1167984, 8.66152763], [78.11653137, 8.66152954], [78.11653137, 8.66125011], [78.11624908, 8.66125011], [78.11624908, 8.66096973], [78.11569214, 8.66097164], [78.11569214, 8.66069412], [78.1159668, 8.6607008], [78.1159668, 8.66042137], [78.11624908, 8.66042137], [78.1162796, 8.66014004], [78.11653137, 8.66014004], [78.11653137, 8.65985966], [78.11680603, 8.65985966], [78.11680603, 8.65958405], [78.11708069, 8.65958405], [78.11708069, 8.65930557], [78.11736298, 8.65931129], [78.11736298, 8.65902996], [78.11763763, 8.65902996], [78.11763763, 8.65847015], [78.11791992, 8.65847206], [78.11791992, 8.65819359], [78.11819458, 8.65819359], [78.11819458, 8.65791798], [78.11763763, 8.65791798], [78.11763763, 8.65819359], [78.1156311, 8.65819359], [78.11541748, 8.65819359], [78.11541748, 8.65758991], [78.11541748, 8.65736198], [78.11513519, 8.65736198], [78.11513519, 8.65708447], [78.11402893, 8.65708447], [78.11402893, 8.65680599], [78.11347198, 8.6568079], [78.11347198, 8.65653038], [78.11319733, 8.65653038], [78.11319733, 8.65625191], [78.1129303, 8.65625191], [78.1129303, 8.65597153], [78.11264038, 8.65597153], [78.11264038, 8.65569401], [78.11208344, 8.65569401], [78.11208344, 8.65541553], [78.11069489, 8.65541553], [78.11069489, 8.65569401], [78.10986328, 8.65569401], [78.10986328, 8.65597153], [78.10847473, 8.65597153], [78.10847473, 8.65569401], [78.10791779, 8.65569401], [78.10791779, 8.65541553], [78.10764313, 8.6554203], [78.10764313, 8.65513992], [78.10736084, 8.65513992], [78.10736084, 8.65485859], [78.10708618, 8.6548624], [78.10708618, 8.65458393], [78.10652924, 8.65458393], [78.10652924, 8.65430641], [78.10624695, 8.65431023], [78.10624695, 8.65374947], [78.10597229, 8.65374947], [78.10597229, 8.65319347], [78.10569763, 8.65319347], [78.10569763, 8.65264034], [78.10542297, 8.65264034], [78.10542297, 8.65208054], [78.10514069, 8.6520834], [78.10514069, 8.6515274], [78.1048584, 8.65153027], [78.1048584, 8.65125179], [78.10542297, 8.65125179], [78.10542297, 8.65097141], [78.10597229, 8.65097141], [78.10597229, 8.65069485], [78.10680389, 8.65069485], [78.10680389, 8.65041733], [78.10736084, 8.65042019], [78.10736084, 8.65014172], [78.10987091, 8.65014172], [78.10987091, 8.65042019], [78.11125183, 8.65041733], [78.11125183, 8.65069485], [78.11152649, 8.65069485], [78.11152649, 8.65097141], [78.11180878, 8.65097141], [78.11180878, 8.65125179], [78.11207581, 8.65125179], [78.11207581, 8.65153027], [78.11235809, 8.65153027], [78.11235809, 8.65181923], [78.11264038, 8.65181923], [78.11264038, 8.65153027], [78.11319733, 8.65153027], [78.11319733, 8.65125179], [78.11347198, 8.65125179], [78.11347198, 8.65097141], [78.11360931, 8.65097141], [78.11402893, 8.65097141], [78.11402893, 8.65069485], [78.11430359, 8.65069485], [78.11430359, 8.65041733], [78.11402893, 8.65042019], [78.11402893, 8.65014172], [78.11374664, 8.65014172], [78.11374664, 8.64958096], [78.11347198, 8.64958286], [78.11347198, 8.64930534], [78.11319733, 8.64930534], [78.11319733, 8.64902687], [78.1129303, 8.64903164], [78.1129303, 8.6487627], [78.11264038, 8.6487627], [78.11264038, 8.64847088], [78.11235809, 8.64847088], [78.11235809, 8.64791679], [78.11207581, 8.64792156], [78.11207581, 8.64763927], [78.11180878, 8.64763927], [78.11180878, 8.64735889], [78.11208344, 8.6473608], [78.11208344, 8.64708328], [78.11235809, 8.64708328], [78.11235809, 8.64680481], [78.11260986, 8.64680958], [78.11264038, 8.6465292], [78.1129303, 8.6465292], [78.1129303, 8.64514065], [78.11319733, 8.64514065], [78.11319733, 8.6434679], [78.11347198, 8.64347076], [78.11347198, 8.64291668], [78.11319733, 8.64292145], [78.11319733, 8.64262962], [78.11291504, 8.64263916], [78.11291504, 8.64236069], [78.11264038, 8.64236069], [78.11264038, 8.6418047], [78.11235809, 8.64181137], [78.11235809, 8.64153099], [78.11207581, 8.64153099], [78.11207581, 8.64125061], [78.11180878, 8.64125061], [78.11180878, 8.64097023], [78.11152649, 8.64097309], [78.11152649, 8.64069462], [78.11125183, 8.64069462], [78.11125183, 8.64013767], [78.11096954, 8.64014053], [78.11096954, 8.63986015], [78.11069489, 8.63986015], [78.11069489, 8.63958454], [78.10986328, 8.63958454], [78.10986328, 8.63986015], [78.10930634, 8.63986015], [78.10930634, 8.64014053], [78.1084671, 8.64014053], [78.1084671, 8.64042091], [78.10791779, 8.6404171], [78.10791779, 8.64069462], [78.10708618, 8.64069462], [78.10708618, 8.64097309], [78.10652924, 8.64097023], [78.10652924, 8.64125061], [78.10597229, 8.64125061], [78.10597229, 8.64153099], [78.10569763, 8.64153099], [78.10569763, 8.64181137], [78.10531616, 8.6418047], [78.10514069, 8.6418047], [78.10514069, 8.64208317], [78.10375214, 8.64208317], [78.10375214, 8.6418047], [78.10320282, 8.64181137], [78.10320282, 8.64153099], [78.1029129, 8.64153099], [78.1029129, 8.64125061], [78.10235596, 8.64125061], [78.10235596, 8.64097023], [78.1020813, 8.64097309], [78.1020813, 8.64069462], [78.10152435, 8.64069462], [78.10152435, 8.6404171], [78.10124969, 8.64042091], [78.10124969, 8.64014053], [78.10067749, 8.64014053], [78.10068512, 8.63869953], [78.10069275, 8.63819408], [78.10124969, 8.63819408], [78.10124969, 8.63791561], [78.10151672, 8.63792133], [78.10151672, 8.63764095], [78.10180664, 8.63764095], [78.10180664, 8.63735962], [78.1020813, 8.63736343], [78.1020813, 8.6370821], [78.10236359, 8.6370821], [78.10236359, 8.63680553], [78.1029129, 8.63681984], [78.1029129, 8.63653088], [78.10320282, 8.63653088], [78.10320282, 8.63624954], [78.10346985, 8.63624954], [78.10346985, 8.63597012], [78.10375214, 8.63597202], [78.10375214, 8.63569355], [78.10430908, 8.63569355], [78.10430908, 8.63541603], [78.10708618, 8.6354208], [78.10708618, 8.63514042], [78.10736084, 8.63514042], [78.10736084, 8.63486004], [78.10791779, 8.63486004], [78.10791779, 8.63458443], [78.10819244, 8.63458443], [78.10819244, 8.63392067], [78.10819244, 8.63319397], [78.10791779, 8.63319397], [78.10791779, 8.63263798], [78.10771942, 8.63264179], [78.1076355, 8.63263798], [78.1076355, 8.63233471], [78.1076355, 8.63208389], [78.10736084, 8.63208389], [78.10736084, 8.6315279], [78.10708618, 8.63153172], [78.10708618, 8.63125038], [78.10652924, 8.63125038], [78.10652924, 8.63097191], [78.10569763, 8.63097191], [78.10569763, 8.63069439], [78.10152435, 8.63069439], [78.10152435, 8.62874985], [78.10124969, 8.62874985], [78.10124969, 8.62791538], [78.10151672, 8.62792015], [78.10151672, 8.62375164], [78.10124969, 8.62375164], [78.10124969, 8.61903095], [78.10151672, 8.61903095], [78.10151672, 8.6181879], [78.10180664, 8.61819458], [78.10180664, 8.61763859], [78.1020813, 8.61764145], [78.1020813, 8.61707973], [78.1029129, 8.6170826], [78.1029129, 8.61736107], [78.10375214, 8.61736107], [78.10373688, 8.61707973], [78.10346985, 8.6170826], [78.10346985, 8.61597347], [78.10180664, 8.61597347], [78.10180664, 8.61486053], [78.10319519, 8.61486053], [78.10319519, 8.61458302], [78.10402679, 8.61458302], [78.10402679, 8.61430359], [78.10624695, 8.61431122], [78.10624695, 8.61403084], [78.10700989, 8.61402893], [78.10708618, 8.61402893], [78.10708618, 8.61377144], [78.10597229, 8.61375141], [78.10597229, 8.61347294], [78.10514069, 8.61347294], [78.10514069, 8.61319542], [78.1048584, 8.61319542], [78.1048584, 8.61291695], [78.10457611, 8.61291885], [78.10457611, 8.61264992], [78.10430908, 8.61264992], [78.10430908, 8.61207962], [78.10263824, 8.61208153], [78.10263824, 8.61236], [78.10180664, 8.61236], [78.10180664, 8.61208153], [78.10124969, 8.61208153], [78.10124969, 8.61152935], [78.1009903, 8.61153126], [78.1009903, 8.61096954], [78.10069275, 8.6109724], [78.10069275, 8.61013794], [78.10041809, 8.6101408], [78.10041809, 8.6093111], [78.1001358, 8.6093111], [78.1001358, 8.60875034], [78.09986115, 8.60875034], [78.09986115, 8.60791588], [78.09958649, 8.60792065], [78.09958649, 8.60625172], [78.09929657, 8.60625172], [78.09929657, 8.60486031], [78.09902954, 8.60486221], [78.09902954, 8.60458374], [78.09874725, 8.60458374], [78.09874725, 8.60430622], [78.0984726, 8.60431004], [78.0984726, 8.60402966], [78.09819794, 8.60402966], [78.09819794, 8.60375023], [78.09791565, 8.60375023], [78.09791565, 8.60347176], [78.09764099, 8.60348129], [78.09764099, 8.60319138], [78.0973587, 8.60319424], [78.0973587, 8.60291576], [78.09707642, 8.60291958], [78.09707642, 8.60207939], [78.09680176, 8.60208416], [78.09680176, 8.60097218], [78.0965271, 8.60097218], [78.0965271, 8.60041809], [78.09707642, 8.60042], [78.09707642, 8.60013962], [78.09764099, 8.60013962], [78.09764099, 8.59985924], [78.09791565, 8.5998621], [78.09791565, 8.59958363], [78.0984726, 8.59958363], [78.0984726, 8.59930611], [78.09958649, 8.59930611], [78.09958649, 8.59958363], [78.09986115, 8.59958363], [78.09986115, 8.5998621], [78.1001358, 8.59985924], [78.1001358, 8.60013962], [78.10041809, 8.60013962], [78.10041809, 8.60042], [78.10069275, 8.60041809], [78.10069275, 8.60069561], [78.10097504, 8.60069561], [78.10097504, 8.60097218], [78.10180664, 8.60096931], [78.10180664, 8.60124969], [78.10263824, 8.60124969], [78.10263824, 8.60069084], [78.10236359, 8.60069561], [78.10236359, 8.60013962], [78.1020813, 8.60013962], [78.1020813, 8.59902954], [78.10180664, 8.59902954], [78.10180664, 8.59847069], [78.1020813, 8.59847355], [78.1020813, 8.59819317], [78.10180664, 8.59819317], [78.10180664, 8.59624863], [78.1009903, 8.59625053], [78.1009903, 8.59653187], [78.10041809, 8.59653187], [78.10041809, 8.59681034], [78.09986115, 8.59680462], [78.09986115, 8.59708309], [78.09902954, 8.59708309], [78.09902954, 8.59736061], [78.0984726, 8.59736061], [78.0984726, 8.59764194], [78.09793091, 8.59764194], [78.09793091, 8.59792042], [78.09513855, 8.59792042], [78.09513855, 8.59708118], [78.09541321, 8.59708309], [78.09541321, 8.59541702], [78.09570312, 8.59542179], [78.09570312, 8.59431171], [78.09597015, 8.59431171], [78.09597015, 8.59402943], [78.09625244, 8.59402943], [78.09625244, 8.59375095], [78.0965271, 8.59375095], [78.0965271, 8.59347057], [78.09680176, 8.59347343], [78.09680176, 8.59319496], [78.09708405, 8.59319496], [78.09708405, 8.59291744], [78.09764099, 8.59291935], [78.09764099, 8.59264088], [78.09793091, 8.59264088], [78.09793091, 8.59236145], [78.09819794, 8.59236145], [78.09819794, 8.59208298], [78.09791565, 8.59208298], [78.09791565, 8.59152699], [78.09764099, 8.59154034], [78.09764099, 8.59125137], [78.0973587, 8.59125137], [78.0973587, 8.5909729], [78.09708405, 8.5909729], [78.09708405, 8.59069538], [78.09680176, 8.59069538], [78.09680176, 8.59041691], [78.09625244, 8.59042072], [78.09625244, 8.5901413], [78.09597015, 8.5901413], [78.09597015, 8.58986092], [78.0956955, 8.58986092], [78.0956955, 8.5895834], [78.09541321, 8.5895834], [78.09541321, 8.58930683], [78.09513855, 8.58931065], [78.09513855, 8.58903122], [78.0945816, 8.58903122], [78.0945816, 8.58875084], [78.09430695, 8.58875084], [78.09430695, 8.5884819], [78.09401703, 8.5884819], [78.09401703, 8.58819008], [78.09430695, 8.58819485], [78.09430695, 8.58791733], [78.0945816, 8.58792114], [78.0945816, 8.58763885], [78.09513855, 8.58763885], [78.09513855, 8.58736134], [78.09541321, 8.58736134], [78.09541321, 8.58708191], [78.0956955, 8.58708191], [78.0956955, 8.58680439], [78.09597015, 8.58681107], [78.09597015, 8.58653069], [78.09625244, 8.58653069], [78.09625244, 8.58625126], [78.09680176, 8.58625126], [78.09680176, 8.58597279], [78.09708405, 8.58597279], [78.09708405, 8.58569527], [78.0973587, 8.58569527], [78.0973587, 8.58347225], [78.09708405, 8.58347225], [78.09708405, 8.58263779], [78.09680176, 8.58263969], [78.09680176, 8.58181095], [78.0965271, 8.58181095], [78.0965271, 8.58125019], [78.09680176, 8.58125019], [78.09680176, 8.58097172], [78.0973587, 8.58097172], [78.0973587, 8.5806942], [78.09764099, 8.5806942], [78.09764099, 8.58041573], [78.09793091, 8.58042145], [78.09793091, 8.58014011], [78.0984726, 8.58014011], [78.0984726, 8.57985973], [78.09874725, 8.57985973], [78.09874725, 8.57958412], [78.0993042, 8.57958412], [78.0993042, 8.57930565], [78.09958649, 8.57931137], [78.09958649, 8.57903004], [78.1001358, 8.57903004], [78.1001358, 8.57874966], [78.10263824, 8.57874966], [78.10263824, 8.57903004], [78.10430908, 8.57903004], [78.10430908, 8.57931137], [78.10569763, 8.57930565], [78.10569763, 8.57958412], [78.10736084, 8.57958412], [78.10736084, 8.57985973], [78.10791779, 8.57985973], [78.10791779, 8.58014011], [78.10819244, 8.58014011], [78.10819244, 8.58042145], [78.10847473, 8.58041573], [78.10847473, 8.5806942], [78.10874939, 8.5806942], [78.10874939, 8.58097172], [78.10930634, 8.58097172], [78.10930634, 8.58125019], [78.10958099, 8.58125019], [78.10958099, 8.58153057], [78.10987091, 8.58153057], [78.10987091, 8.58181095], [78.10958099, 8.58180618], [78.10958099, 8.58236027], [78.10930634, 8.58235073], [78.10930634, 8.58263969], [78.10902405, 8.58263779], [78.10902405, 8.58319378], [78.10874939, 8.58319187], [78.10874939, 8.58374977], [78.1084671, 8.58374977], [78.1084671, 8.58431053], [78.10819244, 8.58430672], [78.10819244, 8.58485985], [78.10986328, 8.58485985], [78.10986328, 8.58458233], [78.11180878, 8.58458233], [78.11180878, 8.58402824], [78.11207581, 8.58403111], [78.11207581, 8.58374977], [78.11235809, 8.58374977], [78.11235809, 8.58319187], [78.11264038, 8.58319378], [78.11264038, 8.58291626], [78.1129303, 8.58292103], [78.1129303, 8.58263969], [78.11319733, 8.58263969], [78.11319733, 8.58207989], [78.11347198, 8.5820837], [78.11347198, 8.58152771], [78.11374664, 8.58153057], [78.11374664, 8.58042145], [78.11402893, 8.58042145], [78.11402893, 8.57985973], [78.11486053, 8.57985973], [78.11486053, 8.58153057], [78.11458588, 8.58152771], [78.11458588, 8.58347225], [78.11486053, 8.58347225], [78.11486053, 8.58458233], [78.11513519, 8.58458233], [78.11513519, 8.58485985], [78.11541748, 8.58485985], [78.11541748, 8.58542061], [78.11569214, 8.58541584], [78.11569214, 8.58569527], [78.11597443, 8.58569527], [78.11597443, 8.58597279], [78.11680603, 8.58597279], [78.11680603, 8.58625126], [78.11708069, 8.58625126], [78.11708069, 8.58653069], [78.11736298, 8.58653069], [78.11736298, 8.58681107], [78.11791992, 8.58680439], [78.11791992, 8.58708191], [78.11819458, 8.58708191], [78.11819458, 8.58736134], [78.11846924, 8.58736134], [78.11846924, 8.58763885], [78.11875153, 8.58763885], [78.11875153, 8.58792114], [78.11930847, 8.58791733], [78.11930847, 8.58819485], [78.11958313, 8.58819008], [78.11958313, 8.5884819], [78.1204071, 8.5884819], [78.1204071, 8.58792114], [78.12069702, 8.58792114], [78.12069702, 8.58736134], [78.12208557, 8.58736134], [78.12208557, 8.58763885], [78.12236023, 8.58763885], [78.12236023, 8.58792114], [78.12291718, 8.58791733], [78.12291718, 8.58819485], [78.12319183, 8.58819008], [78.12319183, 8.5884819], [78.12346649, 8.5884819], [78.12346649, 8.58903122], [78.12374878, 8.5890274], [78.12374878, 8.5895834], [78.12430573, 8.5895834], [78.12430573, 8.58986092], [78.12458038, 8.58986092], [78.12458038, 8.5901413], [78.12513733, 8.5901413], [78.12513733, 8.59042072], [78.12569427, 8.59041691], [78.12569427, 8.59069538], [78.12625122, 8.59069538], [78.12625122, 8.5909729], [78.12680817, 8.5909729], [78.12680817, 8.59125137], [78.12763977, 8.59125137], [78.12763977, 8.59154034], [78.12819672, 8.59154034], [78.12819672, 8.59180927], [78.12875366, 8.59180546], [78.12875366, 8.59208298], [78.12930298, 8.59208298], [78.12930298, 8.59236145], [78.1295929, 8.59236145], [78.1295929, 8.59264088], [78.13014221, 8.59264088], [78.13014221, 8.59291935], [78.13041687, 8.59291744], [78.13041687, 8.59319496], [78.13124847, 8.59319496], [78.13124847, 8.59291744], [78.13318634, 8.59291935], [78.13318634, 8.59264088], [78.13375092, 8.59264088], [78.13375092, 8.59236145], [78.13458252, 8.59236145], [78.13458252, 8.59208298], [78.13597107, 8.59208107], [78.13597107, 8.59375095], [78.13569641, 8.59375095], [78.13569641, 8.59431171], [78.13541412, 8.59430504], [78.13541412, 8.59458256], [78.13485718, 8.59458065], [78.13486481, 8.59486103], [78.13458252, 8.59486103], [78.13458252, 8.59514236], [78.13404083, 8.59514236], [78.13404083, 8.59542179], [78.13375092, 8.59541702], [78.13375092, 8.59569454], [78.13346863, 8.59569454], [78.13346863, 8.59597111], [78.13291931, 8.59597111], [78.13291931, 8.59625053], [78.13263702, 8.59624863], [78.13263702, 8.59708309], [78.13236237, 8.59708309], [78.13236237, 8.59736061], [78.13208008, 8.59736061], [78.13208008, 8.59764194], [78.13181305, 8.59764194], [78.13181305, 8.59792042], [78.13153076, 8.59791756], [78.13153076, 8.59819317], [78.13097382, 8.59819317], [78.13097382, 8.59791756], [78.13124847, 8.59792042], [78.13124847, 8.59681034], [78.13153076, 8.59681034], [78.13153076, 8.59625053], [78.12819672, 8.59625053], [78.12819672, 8.59597111], [78.12763977, 8.59597111], [78.12763977, 8.59569454], [78.12735748, 8.59569454], [78.12735748, 8.59541702], [78.12680817, 8.59542179], [78.12680817, 8.59514236], [78.12625122, 8.59514236], [78.12625122, 8.59486103], [78.12568665, 8.59486103], [78.12568665, 8.59514236], [78.12596893, 8.59514236], [78.12596893, 8.59542179], [78.12625122, 8.59541702], [78.12625122, 8.59569454], [78.12652588, 8.59569454], [78.12652588, 8.59597111], [78.12680817, 8.59597111], [78.12680817, 8.59625053], [78.1279068, 8.59625053], [78.1279068, 8.59653187], [78.12847137, 8.59653187], [78.12847137, 8.59681034], [78.12902832, 8.59680462], [78.12902832, 8.59736061], [78.12930298, 8.59736061], [78.12930298, 8.60236168], [78.12874603, 8.60236168], [78.12874603, 8.60207939], [78.12819672, 8.60208416], [78.12819672, 8.60180569], [78.12763977, 8.60181046], [78.12763977, 8.60153008], [78.12708282, 8.60153008], [78.12708282, 8.60124969], [78.12680817, 8.60124969], [78.12680817, 8.60069084], [78.12652588, 8.60069561], [78.12652588, 8.60013962], [78.12680817, 8.60013962], [78.12680817, 8.59957886], [78.12708282, 8.59958363], [78.12708282, 8.59902668], [78.12735748, 8.59902954], [78.12735748, 8.59847069], [78.12763977, 8.59847355], [78.12763977, 8.59791756], [78.12680817, 8.59792042], [78.12680817, 8.59764194], [78.12568665, 8.59764194], [78.12568665, 8.59736061], [78.1248703, 8.59736061], [78.1248703, 8.59764194], [78.12431335, 8.59764194], [78.12431335, 8.59792042], [78.12346649, 8.59792042], [78.12346649, 8.59764194], [78.12319183, 8.59764194], [78.12319183, 8.59708118], [78.12374878, 8.59708309], [78.12374878, 8.59680462], [78.12431335, 8.59681034], [78.12431335, 8.59653187], [78.1248703, 8.59653187], [78.1248703, 8.59625053], [78.12541962, 8.59625053], [78.12541962, 8.59597111], [78.12513733, 8.59597111], [78.12513733, 8.59569454], [78.12458038, 8.59569454], [78.12458038, 8.59541702], [78.12431335, 8.59542179], [78.12431335, 8.59514236], [78.12374878, 8.59514236], [78.12374878, 8.59458065], [78.12403107, 8.59458256], [78.12403107, 8.59402657], [78.12431335, 8.59402943], [78.12431335, 8.59375095], [78.12458038, 8.59375095], [78.12458038, 8.59347057], [78.12430573, 8.59347343], [78.12430573, 8.59319496], [78.12403107, 8.59319496], [78.12403107, 8.59263897], [78.12374878, 8.59264088], [78.12374878, 8.59236145], [78.12319183, 8.59236145], [78.12319183, 8.59208298], [78.12264252, 8.59208298], [78.12264252, 8.59180546], [78.12210083, 8.59180927], [78.12210083, 8.59154034], [78.1204071, 8.59154034], [78.1204071, 8.59125137], [78.11846924, 8.59125137], [78.11846924, 8.5909729], [78.11819458, 8.5909729], [78.11819458, 8.59069538], [78.11791992, 8.59069538], [78.11791992, 8.59041691], [78.11763763, 8.59042072], [78.11763763, 8.5901413], [78.11736298, 8.5901413], [78.11736298, 8.58986092], [78.11707306, 8.58986092], [78.11680603, 8.58986092], [78.11680603, 8.5895834], [78.11653137, 8.5895834], [78.11653137, 8.58930683], [78.11624908, 8.58931065], [78.11624908, 8.58903122], [78.11567688, 8.58903122], [78.11567688, 8.58875084], [78.11541748, 8.58875084], [78.11541748, 8.5884819], [78.11514282, 8.5884819], [78.11514282, 8.58819008], [78.11458588, 8.58819485], [78.11458588, 8.58791733], [78.11429596, 8.58792114], [78.11429596, 8.58763885], [78.11402893, 8.58763885], [78.11402893, 8.58708477], [78.11374664, 8.58708191], [78.11374664, 8.58652878], [78.11347198, 8.58653069], [78.11347198, 8.58625126], [78.11319733, 8.58625126], [78.11319733, 8.58597279], [78.11291504, 8.58597279], [78.11291504, 8.58569527], [78.10986328, 8.58569527], [78.10986328, 8.58625126], [78.10958099, 8.58625126], [78.10958099, 8.58681107], [78.10930634, 8.58680439], [78.10930634, 8.58763885], [78.10901642, 8.58763885], [78.10901642, 8.58875084], [78.10874939, 8.58875084], [78.10874939, 8.5895834], [78.1084671, 8.58957958], [78.10847473, 8.58986092], [78.10819244, 8.58986092], [78.10819244, 8.5901413], [78.10791779, 8.5901413], [78.10791779, 8.59042072], [78.1076355, 8.59041691], [78.1076355, 8.59069538], [78.10736084, 8.59069538], [78.10736084, 8.5909729], [78.10541534, 8.5909729], [78.10541534, 8.59069538], [78.10430908, 8.59069538], [78.10430908, 8.5909729], [78.10373688, 8.59097099], [78.10375214, 8.59125137], [78.10346985, 8.59125137], [78.10346985, 8.59154034], [78.1029129, 8.59154034], [78.1029129, 8.59180927], [78.10263824, 8.59180546], [78.10263824, 8.59208298], [78.1020813, 8.59208298], [78.1020813, 8.59236145], [78.10180664, 8.59236145], [78.10180664, 8.59375095], [78.1020813, 8.59375095], [78.1020813, 8.59514236], [78.10263824, 8.59514236], [78.10263824, 8.59458065], [78.1029129, 8.59458256], [78.1029129, 8.59347343], [78.10319519, 8.59347343], [78.10319519, 8.59291744], [78.10458374, 8.59291744], [78.10458374, 8.59319496], [78.1048584, 8.59319496], [78.1048584, 8.59347343], [78.10542297, 8.59347057], [78.10542297, 8.59375095], [78.10569763, 8.59375095], [78.10569763, 8.59402943], [78.10597229, 8.59402943], [78.10597229, 8.59514236], [78.10569763, 8.59514236], [78.10569763, 8.59653187], [78.10541534, 8.5965271], [78.10541534, 8.59736061], [78.10514069, 8.59736061], [78.10514069, 8.59792042], [78.1048584, 8.59791756], [78.1048584, 8.59847355], [78.10457611, 8.59847069], [78.10457611, 8.59902954], [78.10430908, 8.59902954], [78.10430908, 8.59930992], [78.10402679, 8.59930992], [78.10402679, 8.60181046], [78.10430908, 8.60180569], [78.10430908, 8.60319424], [78.10457611, 8.60319138], [78.10457611, 8.60348129], [78.1048584, 8.60348129], [78.1048584, 8.60402966], [78.10514069, 8.60402966], [78.10514069, 8.60431004], [78.10541534, 8.60430622], [78.10541534, 8.60458374], [78.10569763, 8.60458374], [78.10569763, 8.60486221], [78.10597229, 8.60486031], [78.10597229, 8.60542011], [78.10624695, 8.6054163], [78.10624695, 8.60569382], [78.10652924, 8.60569382], [78.10652924, 8.60597229], [78.10736084, 8.60597038], [78.10736084, 8.60625172], [78.10819244, 8.60624981], [78.10819244, 8.60652828], [78.10901642, 8.60652065], [78.10901642, 8.60681057], [78.10958099, 8.6068058], [78.10958099, 8.60708427], [78.11013794, 8.60708046], [78.11013794, 8.60764027], [78.11069489, 8.60764027], [78.11069489, 8.60819435], [78.11042023, 8.60818958], [78.11042023, 8.60903072], [78.11013794, 8.60903072], [78.11013794, 8.6093111], [78.10986328, 8.60930634], [78.10986328, 8.60986233], [78.10958099, 8.60986042], [78.10958099, 8.61042118], [78.10930634, 8.61041641], [78.10930634, 8.6109724], [78.10958099, 8.61096954], [78.10958099, 8.61124992], [78.10987091, 8.61124992], [78.10987091, 8.61153126], [78.11013794, 8.61152935], [78.11013794, 8.61208153], [78.11042023, 8.61208153], [78.11042023, 8.61236], [78.11235809, 8.61236], [78.11235809, 8.61180687], [78.11264038, 8.61181068], [78.11264038, 8.61069202], [78.11291504, 8.61069393], [78.11291504, 8.61013794], [78.11319733, 8.6101408], [78.11319733, 8.60986042], [78.11347198, 8.60986233], [78.11347198, 8.60958195], [78.11374664, 8.60958195], [78.11374664, 8.60930634], [78.11402893, 8.6093111], [78.11402893, 8.60903072], [78.11429596, 8.60903072], [78.11429596, 8.60875034], [78.11458588, 8.60875034], [78.11458588, 8.60847187], [78.11513519, 8.60847187], [78.11513519, 8.60819435], [78.11569214, 8.60819435], [78.11569214, 8.60791588], [78.1159668, 8.60792065], [78.1159668, 8.60764027], [78.11653137, 8.60764027], [78.11653137, 8.60735989], [78.11567688, 8.60735989], [78.11567688, 8.60681057], [78.11541748, 8.60681057], [78.11541748, 8.60597038], [78.11513519, 8.60597229], [78.11513519, 8.60486221], [78.11486053, 8.60486221], [78.11486053, 8.60458374], [78.11458588, 8.60458374], [78.11458588, 8.60430622], [78.11429596, 8.60431004], [78.11429596, 8.60402966], [78.11402893, 8.60402966], [78.11402893, 8.60375023], [78.11374664, 8.60375023], [78.11374664, 8.60347176], [78.11347198, 8.60348129], [78.11347198, 8.60291958], [78.11319733, 8.60291958], [78.11319733, 8.60264015], [78.1129303, 8.60264015], [78.1129303, 8.60236168], [78.11264038, 8.60236168], [78.11264038, 8.60208416], [78.11235809, 8.60208416], [78.11235809, 8.60152817], [78.11207581, 8.60153008], [78.11207581, 8.60096931], [78.11180878, 8.60097218], [78.11180878, 8.60013962], [78.11235809, 8.60013962], [78.11235809, 8.59985924], [78.11271667, 8.5998621], [78.11291504, 8.5998621], [78.11291504, 8.59958363], [78.11347198, 8.59958363], [78.11347198, 8.59930611], [78.11429596, 8.59930992], [78.11429596, 8.59902954], [78.11514282, 8.59902954], [78.11514282, 8.59875202], [78.11567688, 8.59875202], [78.11567688, 8.59847069], [78.11653137, 8.59847355], [78.11653137, 8.59819317], [78.11708069, 8.59819317], [78.11708069, 8.59791756], [78.11791992, 8.59792042], [78.11791992, 8.59764194], [78.11846924, 8.59764194], [78.11846924, 8.59736061], [78.12069702, 8.59736061], [78.12069702, 8.59764194], [78.12152863, 8.59764194], [78.12152863, 8.59792042], [78.12208557, 8.59791756], [78.12208557, 8.59819317], [78.12236023, 8.59819126], [78.12236023, 8.59875202], [78.12264252, 8.59874916], [78.12264252, 8.59958363], [78.12208557, 8.59958363], [78.12208557, 8.5998621], [78.12152863, 8.59985924], [78.12152863, 8.60013962], [78.12097168, 8.60013962], [78.12097168, 8.60042], [78.12014008, 8.60041809], [78.12014008, 8.60069561], [78.11930847, 8.60069561], [78.11930847, 8.60097218], [78.11846924, 8.60096931], [78.11846924, 8.60124969], [78.11763763, 8.60124969], [78.11763763, 8.60153008], [78.11680603, 8.60153008], [78.11680603, 8.60181046], [78.11708069, 8.60180569], [78.11708069, 8.60208416], [78.11736298, 8.60208416], [78.11736298, 8.60236168], [78.11763763, 8.60236168], [78.11763763, 8.60291958], [78.11791992, 8.60291958], [78.11791992, 8.60348129], [78.11763763, 8.60348129], [78.11763763, 8.60402966], [78.11736298, 8.60402775], [78.11736298, 8.60458374], [78.11708069, 8.60458183], [78.11708069, 8.60513973], [78.11680603, 8.60513973], [78.11680603, 8.60542011], [78.11708069, 8.6054163], [78.11708069, 8.60569382], [78.11736298, 8.60569382], [78.11736298, 8.60597229], [78.11902618, 8.60597229], [78.11902618, 8.60569382], [78.12014008, 8.60569382], [78.12014008, 8.60597229], [78.12124634, 8.60597229], [78.12124634, 8.60569382], [78.12208557, 8.60569382], [78.12208557, 8.6054163], [78.12430573, 8.6054163], [78.12430573, 8.60569382], [78.12458038, 8.60569382], [78.12458038, 8.60652828], [78.12430573, 8.60652828], [78.12430573, 8.60708427], [78.12403107, 8.60708046], [78.12403107, 8.60764027], [78.12346649, 8.60764027], [78.12346649, 8.60903072], [78.12430573, 8.60902786], [78.12430573, 8.61069393], [78.12403107, 8.61069393], [78.12403107, 8.61319542], [78.12291718, 8.61319542], [78.12291718, 8.61291695], [78.12181091, 8.61291885], [78.12181091, 8.61264992], [78.12152863, 8.61264992], [78.12152863, 8.61236], [78.12124634, 8.61236], [78.12124634, 8.61208153], [78.12097168, 8.61207962], [78.12097168, 8.61291885], [78.12152863, 8.61291695], [78.12152863, 8.61347294], [78.12181091, 8.61347008], [78.12181091, 8.61431122], [78.12208557, 8.61430359], [78.12208557, 8.61486053], [78.12236023, 8.61486053], [78.12236023, 8.6154213], [78.12264252, 8.61541653], [78.12264252, 8.615695], [78.12291718, 8.61569023], [78.12291718, 8.61625099], [78.12319183, 8.61625099], [78.12319183, 8.61680889], [78.12346649, 8.61680889], [78.12346649, 8.61653137], [78.12374878, 8.61653137], [78.12374878, 8.61625099], [78.12431335, 8.61625099], [78.12431335, 8.61597061], [78.12458038, 8.61597347], [78.12458038, 8.615695], [78.12486267, 8.615695], [78.12486267, 8.61541653], [78.12569427, 8.61541653], [78.12569427, 8.615695], [78.12596893, 8.61569023], [78.12596893, 8.61625099], [78.12625122, 8.61625099], [78.12625122, 8.61680889], [78.12596893, 8.61680889], [78.12596893, 8.61875057], [78.12541962, 8.61875057], [78.12541962, 8.61903095], [78.1248703, 8.61903095], [78.1248703, 8.61930943], [78.12458038, 8.61930466], [78.12458038, 8.61958313], [78.12403107, 8.61958313], [78.12403107, 8.61986065], [78.12346649, 8.61986065], [78.12346649, 8.62014103], [78.12319183, 8.62014103], [78.12319183, 8.62041855], [78.12291718, 8.62041664], [78.12291718, 8.62069511], [78.12264252, 8.62069511], [78.12264252, 8.62097263], [78.12208557, 8.62097263], [78.12208557, 8.6212492], [78.12180328, 8.6212492], [78.12180328, 8.62152672], [78.12152863, 8.62152004], [78.12152863, 8.62181187], [78.12124634, 8.62180519], [78.12124634, 8.62208271], [78.12097168, 8.6220808], [78.12097168, 8.62292194], [78.12124634, 8.62292194], [78.12124634, 8.62403202], [78.12152863, 8.62403202], [78.12152863, 8.62458992], [78.12181091, 8.62458992], [78.12181091, 8.62541962], [78.12208557, 8.62541771], [78.12208557, 8.62597084], [78.12236023, 8.62597084], [78.12236023, 8.62624931], [78.12264252, 8.62624931], [78.12264252, 8.62681007], [78.12291718, 8.62680626], [78.12291718, 8.62708378], [78.12319183, 8.62708092], [78.12319183, 8.62765121], [78.12346649, 8.62765121], [78.12346649, 8.62792015], [78.12374878, 8.62791538], [78.12374878, 8.62819576], [78.12403107, 8.62819576], [78.12403107, 8.62874985], [78.12430573, 8.62874985], [78.12430573, 8.62958431], [78.12403107, 8.62958241], [78.12403107, 8.63153172], [78.12430573, 8.6315279], [78.12430573, 8.63347244], [78.12458038, 8.633461], [78.12458038, 8.63514042], [78.1248703, 8.63514042], [78.1248703, 8.63624954], [78.12513733, 8.63624954], [78.12513733, 8.63653088], [78.12541962, 8.63653088], [78.12541962, 8.63681984], [78.12569427, 8.63680553], [78.12569427, 8.6370821], [78.12596893, 8.6370821], [78.12596893, 8.63736343], [78.12652588, 8.63735962], [78.12652588, 8.63764095], [78.12680817, 8.63764095], [78.12680817, 8.63792133], [78.12708282, 8.63791561], [78.12708282, 8.63819408], [78.12735748, 8.63819408], [78.12735748, 8.6384716], [78.12791443, 8.6384716], [78.12791443, 8.63680553], [78.12763977, 8.63681984], [78.12763977, 8.63568974], [78.12735748, 8.63569355], [78.12735748, 8.63069439], [78.12708282, 8.63069439], [78.12708282, 8.62708378], [78.12735748, 8.62708378], [78.12735748, 8.62680626], [78.12708282, 8.62681007], [78.12708282, 8.62319088], [78.12735748, 8.62319469], [78.12735748, 8.61902905], [78.12763977, 8.61903095], [78.12763977, 8.61625099], [78.1279068, 8.61625099], [78.1279068, 8.61514091], [78.12819672, 8.61514091], [78.12819672, 8.61403084], [78.12847137, 8.61403084], [78.12847137, 8.61291885], [78.12874603, 8.61291885], [78.12874603, 8.61153126], [78.12902832, 8.61153126], [78.12902832, 8.61042118], [78.12930298, 8.61042118], [78.12930298, 8.6093111], [78.1295929, 8.6093111], [78.1295929, 8.60846996], [78.12985992, 8.60847187], [78.12985992, 8.60791588], [78.13014221, 8.60792065], [78.13014221, 8.60708046], [78.13041687, 8.60708427], [78.13041687, 8.60624981], [78.13069153, 8.60625172], [78.13069153, 8.60569191], [78.13097382, 8.60569382], [78.13097382, 8.60486221], [78.13124847, 8.60486221], [78.13124847, 8.60402775], [78.13153076, 8.60402966], [78.13153076, 8.60348129], [78.13181305, 8.60348129], [78.13181305, 8.60291958], [78.13208008, 8.60291958], [78.13208008, 8.60236168], [78.13236237, 8.60236168], [78.13236237, 8.60180569], [78.13263702, 8.60181046], [78.13263702, 8.60124969], [78.13291931, 8.60124969], [78.13291931, 8.60069084], [78.13319397, 8.60069561], [78.13319397, 8.60013962], [78.13346863, 8.60013962], [78.13346863, 8.59957886], [78.13375092, 8.59958363], [78.13375092, 8.59902668], [78.13404083, 8.59902954], [78.13404083, 8.59847069], [78.13430786, 8.59847355], [78.13430786, 8.59791756], [78.13458252, 8.59792042], [78.13458252, 8.59736061], [78.13486481, 8.59736061], [78.13486481, 8.59680462], [78.13513947, 8.59681034], [78.13513947, 8.59625053], [78.13540649, 8.59625053], [78.13540649, 8.59569073], [78.13569641, 8.59569454], [78.13569641, 8.59513855], [78.13597107, 8.59514236], [78.13597107, 8.59458065], [78.13625336, 8.59458256], [78.13625336, 8.59402657], [78.13652802, 8.59402943], [78.13652802, 8.59347057], [78.13680267, 8.59347343], [78.13680267, 8.59291744], [78.13710022, 8.59291935], [78.13710022, 8.59236145], [78.13735962, 8.59236145], [78.13735962, 8.59152699], [78.13764191, 8.59154034], [78.13764191, 8.59097099], [78.13791656, 8.5909729], [78.13791656, 8.59069538], [78.13819122, 8.59069538], [78.13819122, 8.58986092], [78.13847351, 8.58986092], [78.13846588, 8.58875084], [78.13874817, 8.58875084], [78.13874817, 8.58681107], [78.13846588, 8.58681107], [78.13846588, 8.58514118], [78.13819122, 8.58514118], [78.13819122, 8.58347034], [78.13791656, 8.58347225], [78.13791656, 8.58236027], [78.13764191, 8.58236027], [78.13764191, 8.58125019], [78.13735962, 8.58125019], [78.13735962, 8.58041573], [78.13710022, 8.58042145], [78.13710022, 8.57931137], [78.1368103, 8.57931137], [78.1368103, 8.57874966], [78.13652802, 8.57874966], [78.13652802, 8.5781889], [78.13625336, 8.57819366], [78.13625336, 8.57736206], [78.13597107, 8.57736206], [78.13597107, 8.5759716], [78.13569641, 8.5759716], [78.13569641, 8.57458401], [78.13541412, 8.57458401], [78.13541412, 8.5731926], [78.13513947, 8.5731926], [78.13513947, 8.57208443], [78.13486481, 8.57208443], [78.13486481, 8.57124901], [78.13458252, 8.57125187], [78.13458252, 8.57014179], [78.13430786, 8.57014179], [78.13430786, 8.56931019], [78.13404083, 8.56931019], [78.13404083, 8.56847095], [78.13375092, 8.56847095], [78.13375092, 8.56763935], [78.13346863, 8.56763935], [78.13346863, 8.56652927], [78.13318634, 8.56652927], [78.13318634, 8.56569099], [78.13291931, 8.56569481], [78.13291931, 8.56375122], [78.13263702, 8.56375122], [78.13263702, 8.55736256], [78.13236237, 8.5573597], [78.13236237, 8.55624962], [78.13208008, 8.55624962], [78.13208008, 8.55540943], [78.13180542, 8.55541611], [78.13180542, 8.55458355], [78.13153076, 8.55458355], [78.13153076, 8.55347157], [78.13124847, 8.55347157], [78.13124847, 8.55291557], [78.13096619, 8.5529213], [78.13096619, 8.55237103], [78.13069153, 8.55237103], [78.13069153, 8.55181122], [78.13041687, 8.55181122], [78.13041687, 8.55125046], [78.13014221, 8.55125046], [78.13014221, 8.55069447], [78.12985992, 8.55069447], [78.12985992, 8.5504179], [78.1295929, 8.55042267], [78.1295929, 8.54986191], [78.12930298, 8.54986191], [78.12930298, 8.54930592], [78.12902832, 8.54930973], [78.12902832, 8.54875183], [78.12874603, 8.54875183], [78.12874603, 8.54819107], [78.12847137, 8.54819584], [78.12847137, 8.54763985], [78.12819672, 8.54763985], [78.12819672, 8.54708099], [78.12791443, 8.54708385], [78.12791443, 8.54625034], [78.12763977, 8.54625034], [78.12763977, 8.54541779], [78.12735748, 8.54541969], [78.12735748, 8.54458141], [78.12708282, 8.54458332], [78.12708282, 8.54374886], [78.12680817, 8.54374886], [78.12680817, 8.54291725], [78.12652588, 8.54292202], [78.12652588, 8.54208088], [78.12625122, 8.54208279], [78.12625122, 8.54125118], [78.12596893, 8.54125118], [78.12596893, 8.54041672], [78.12568665, 8.54043102], [78.12568665, 8.53931046], [78.12541962, 8.53931046], [78.12541962, 8.53818989], [78.12513733, 8.53819466], [78.12513733, 8.53708267], [78.12486267, 8.53708267], [78.12486267, 8.5359726], [78.12458038, 8.5359726], [78.12458038, 8.53486061], [78.12430573, 8.53486061], [78.12430573, 8.53374767], [78.12403107, 8.53375053], [78.12403107, 8.5320797], [78.12374878, 8.5320816], [78.12374878, 8.52986336], [78.12347412, 8.52986336], [78.12347412, 8.52764034], [78.12319183, 8.52764034], [78.12319183, 8.52542973], [78.12291718, 8.52542973], [78.12291718, 8.52347183], [78.12264252, 8.52347183], [78.12264252, 8.52180576], [78.12236023, 8.52180958], [78.12236023, 8.51653194], [78.12264252, 8.51653194], [78.12264252, 8.51431179], [78.12291718, 8.51431179], [78.12291718, 8.51320171], [78.12319183, 8.51320171], [78.12319183, 8.51264095], [78.12346649, 8.51264095], [78.12346649, 8.51208115], [78.12374878, 8.51208305], [78.12374878, 8.51180458], [78.12403107, 8.51180935], [78.12403107, 8.51125145], [78.12431335, 8.51125145], [78.12431335, 8.51097107], [78.12458038, 8.51097298], [78.12458038, 8.51041698], [78.1248703, 8.51041889], [78.1248703, 8.50986099], [78.12513733, 8.50986099], [78.12513733, 8.50958347], [78.12541962, 8.50958347], [78.12541962, 8.50902653], [78.12568665, 8.5090313], [78.12568665, 8.50875092], [78.12596893, 8.50875092], [78.12596893, 8.50819016], [78.12625122, 8.50819492], [78.12625122, 8.50763893], [78.12652588, 8.50764084], [78.12652588, 8.50736141], [78.12680817, 8.50736141], [78.12680817, 8.50680542], [78.12708282, 8.50680923], [78.12708282, 8.50597], [78.12680817, 8.50597286], [78.12680817, 8.50485992], [78.12652588, 8.50485992], [78.12652588, 8.50430679], [78.12625122, 8.50432014], [78.12625122, 8.50374985], [78.12596893, 8.50374985], [78.12596893, 8.50319386], [78.12569427, 8.50319386], [78.12569427, 8.50263786], [78.12596893, 8.50264072], [78.12596893, 8.50181103], [78.12625122, 8.50181103], [78.12625122, 8.50126171], [78.12652588, 8.50126171], [78.12652588, 8.50069046], [78.12680817, 8.50069427], [78.12680817, 8.50014019], [78.12708282, 8.50014019], [78.12708282, 8.49986172], [78.12735748, 8.49986172], [78.12735748, 8.49931145], [78.12763977, 8.49931145], [78.12763977, 8.49903011], [78.12819672, 8.49903011], [78.12819672, 8.49874973], [78.12847137, 8.49874973], [78.12847137, 8.49847031], [78.12902832, 8.49847221], [78.12902832, 8.49819374], [78.12958527, 8.49819374], [78.12958527, 8.49791622], [78.12985992, 8.49792004], [78.12985992, 8.49763966], [78.13041687, 8.49763966], [78.13041687, 8.4970789], [78.13014221, 8.49708366], [78.13014221, 8.49652767], [78.12985992, 8.49652958], [78.12985992, 8.49625015], [78.12958527, 8.49625015], [78.12958527, 8.49569416], [78.12930298, 8.49569416], [78.12930298, 8.49541569], [78.12902832, 8.49542046], [78.12902832, 8.4948597], [78.12875366, 8.4948597], [78.12875366, 8.49458408], [78.12847137, 8.49458408], [78.12847137, 8.49402809], [78.12819672, 8.49403], [78.12819672, 8.49374962], [78.1279068, 8.49374962], [78.1279068, 8.49318886], [78.12763977, 8.49319363], [78.12763977, 8.49291801], [78.12735748, 8.49291992], [78.12735748, 8.49263954], [78.12708282, 8.49263954], [78.12708282, 8.49236202], [78.12680817, 8.49236202], [78.12680817, 8.49208355], [78.12652588, 8.49208355], [78.12652588, 8.49180603], [78.12625122, 8.49180984], [78.12625122, 8.49153042], [78.12596893, 8.49153042], [78.12596893, 8.49097061], [78.12569427, 8.49097443], [78.12569427, 8.49069309], [78.12541962, 8.49069309], [78.12541962, 8.49041843], [78.12513733, 8.49042034], [78.12513733, 8.48986053], [78.12486267, 8.48986053], [78.12486267, 8.48958302], [78.12458038, 8.48958302], [78.12458038, 8.48902702], [78.12431335, 8.48903179], [78.12431335, 8.48875141], [78.12403107, 8.48875141], [78.12403107, 8.48819542], [78.12374878, 8.48819542], [78.12374878, 8.48791695], [78.12346649, 8.48792171], [78.12346649, 8.48763943], [78.12319183, 8.48763943], [78.12319183, 8.48708057], [78.12291718, 8.48708344], [78.12291718, 8.48680496], [78.12264252, 8.48680973], [78.12264252, 8.48625088], [78.12236023, 8.48625088], [78.12236023, 8.48597145], [78.12208557, 8.48597336], [78.12208557, 8.48569489], [78.12180328, 8.48569489], [78.12180328, 8.48513889], [78.12152863, 8.48513889], [78.12152863, 8.48486137], [78.12124634, 8.48486137], [78.12124634, 8.4845829], [78.12097168, 8.4845829], [78.12097168, 8.48430538], [78.1204071, 8.4843092], [78.1204071, 8.48403072], [78.12014008, 8.48403072], [78.12014008, 8.4837513], [78.11985779, 8.4837513], [78.11985779, 8.48347282], [78.11958313, 8.48347282], [78.11958313, 8.4831953], [78.11930847, 8.4831953], [78.11930847, 8.48291683], [78.11875153, 8.48292065], [78.11875153, 8.48264122], [78.11846924, 8.48264122], [78.11846924, 8.48236084], [78.11818695, 8.48236084], [78.11818695, 8.48208046], [78.11791992, 8.48208332], [78.11791992, 8.48180485], [78.11763763, 8.48181152], [78.11763763, 8.48153114], [78.11736298, 8.48153114], [78.11736298, 8.48124886], [78.11708069, 8.48125076], [78.11708069, 8.48097324], [78.11680603, 8.48097324], [78.11680603, 8.48069477], [78.11653137, 8.48069477], [78.11653137, 8.48041725], [78.11624908, 8.48042107], [78.11624908, 8.48012924], [78.11597443, 8.48013878], [78.11597443, 8.47986126], [78.11569214, 8.47986126], [78.11569214, 8.47958469], [78.11541748, 8.47958469], [78.11541748, 8.47930431], [78.11514282, 8.47931099], [78.11514282, 8.47903061], [78.11486053, 8.47903061], [78.11486053, 8.47875118], [78.11458588, 8.47875118], [78.11458588, 8.47847271], [78.11430359, 8.47847271], [78.11430359, 8.47819519], [78.11402893, 8.47819519], [78.11402893, 8.47791576], [78.11374664, 8.47792053], [78.11374664, 8.47764111], [78.11347198, 8.47764111], [78.11347198, 8.47735977], [78.11319733, 8.47735977], [78.11319733, 8.47708225], [78.1129303, 8.47709084], [78.1129303, 8.47681141], [78.11235809, 8.47681141], [78.11235809, 8.47653103], [78.11207581, 8.47653103], [78.11207581, 8.47624969], [78.11180878, 8.47624969], [78.11180878, 8.47597027], [78.11152649, 8.47597218], [78.11152649, 8.4756937], [78.11125183, 8.4756937], [78.11125183, 8.47541618], [78.11096954, 8.47542095], [78.11096954, 8.47513962], [78.11068726, 8.47513962], [78.11068726, 8.47486019], [78.11042023, 8.47486019], [78.11042023, 8.4743042], [78.11013794, 8.47431087], [78.11013794, 8.47403145], [78.10987091, 8.47403145], [78.10987091, 8.47375011], [78.10958099, 8.47375011], [78.10958099, 8.47346973], [78.10930634, 8.47347164], [78.10930634, 8.47319412], [78.10902405, 8.47319412], [78.10902405, 8.47291565], [78.10874939, 8.47292137], [78.10874939, 8.47264004], [78.1084671, 8.47264004], [78.1084671, 8.47235966], [78.10819244, 8.47236156], [78.10819244, 8.47208405], [78.10791779, 8.47208405], [78.10791779, 8.47152805], [78.10764313, 8.47152996], [78.10764313, 8.47124958], [78.10736084, 8.47124958], [78.10736084, 8.47096062], [78.10708618, 8.47097206], [78.10708618, 8.47069359], [78.10680389, 8.47069359], [78.10680389, 8.47041798], [78.10652924, 8.47042274], [78.10652924, 8.47014046], [78.10624695, 8.47014046], [78.10624695, 8.46986198], [78.10597229, 8.46986198], [78.10597229, 8.46930599], [78.10569763, 8.46931267], [78.10569763, 8.46903038], [78.10542297, 8.46903038], [78.10542297, 8.46875191], [78.10514069, 8.46875191], [78.10514069, 8.46846867], [78.1048584, 8.46847153], [78.1048584, 8.46819401], [78.10458374, 8.46819401], [78.10458374, 8.46791553], [78.10402679, 8.4679203], [78.10402679, 8.46763992], [78.10373688, 8.46763992], [78.10373688, 8.46735954], [78.10346985, 8.4673624], [78.10346985, 8.46708393], [78.10319519, 8.46708393], [78.10319519, 8.46680641], [78.1029129, 8.46681023], [78.1029129, 8.46652985], [78.10263824, 8.46652985], [78.10263824, 8.46625042], [78.1020813, 8.46625042], [78.1020813, 8.46597195], [78.10180664, 8.46597195], [78.10180664, 8.46569347], [78.10152435, 8.46569347], [78.10152435, 8.46541786], [78.10124969, 8.46541977], [78.10124969, 8.46515083], [78.1009903, 8.46515083], [78.1009903, 8.46486187], [78.10067749, 8.46486187], [78.10067749, 8.46458054], [78.1001358, 8.46458435], [78.1001358, 8.46430492], [78.09986115, 8.46430969], [78.09986115, 8.46403027], [78.09958649, 8.46403027], [78.09958649, 8.46375179], [78.09929657, 8.46375179], [78.09929657, 8.46347141], [78.09902954, 8.46347141], [78.09902954, 8.4631958], [78.09874725, 8.4631958], [78.09874725, 8.46291733], [78.0984726, 8.46292019], [78.0984726, 8.46236134], [78.09819794, 8.46236134], [78.09819794, 8.46208286], [78.09793091, 8.46208954], [78.09793091, 8.46181202], [78.09764099, 8.46181202], [78.09764099, 8.46153164], [78.0973587, 8.46153164], [78.0973587, 8.46125126], [78.09707642, 8.46125126], [78.09707642, 8.46097088], [78.09680176, 8.46097088], [78.09680176, 8.46069527], [78.0965271, 8.46069527], [78.0965271, 8.46041679], [78.09625244, 8.46041965], [78.09625244, 8.45985889], [78.09597015, 8.4598608], [78.09597015, 8.45958328], [78.0956955, 8.45958328], [78.0956955, 8.45930481], [78.09541321, 8.45930958], [78.09541321, 8.45901966], [78.09513855, 8.4590292], [78.09513855, 8.45874882], [78.09485626, 8.45875072], [78.09485626, 8.4584713], [78.0945816, 8.45847321], [78.0945816, 8.45791721], [78.09430695, 8.45792198], [78.09430695, 8.45764065], [78.09401703, 8.45764065], [78.09401703, 8.45736122], [78.09375, 8.45736122], [78.09375, 8.45680523], [78.09348297, 8.4568119], [78.09348297, 8.45653057], [78.09319305, 8.45653057], [78.09319305, 8.45625114], [78.09236145, 8.45625114], [78.09236145, 8.45597267], [78.09124756, 8.45597267], [78.09124756, 8.45569515], [78.09069824, 8.45569515], [78.09069061, 8.45541668], [78.09041595, 8.45542145], [78.09041595, 8.45514107], [78.08985901, 8.45514107], [78.08985901, 8.45486069], [78.08957672, 8.45486069], [78.08957672, 8.45458031], [78.0890274, 8.45458317], [78.0890274, 8.4543047], [78.08873749, 8.45431137], [78.08873749, 8.45375061], [78.08847046, 8.45375061], [78.08847046, 8.45347023], [78.0881958, 8.45347309], [78.0881958, 8.45319462], [78.08791351, 8.45319462], [78.08791351, 8.45263863], [78.08763885, 8.45264053], [78.08763885, 8.45207977], [78.0873642, 8.45208168], [78.0873642, 8.45152855], [78.08708191, 8.45153141], [78.08708191, 8.4509697], [78.08680725, 8.45097256], [78.08680725, 8.4495821], [78.08708191, 8.4495821], [78.08708191, 8.44847202], [78.08680725, 8.44847202], [78.08680725, 8.44819355], [78.08652496, 8.44819355], [78.08652496, 8.44791603], [78.08625031, 8.4479208], [78.08625031, 8.44764042], [78.08599091, 8.44764042], [78.08599091, 8.44707966], [78.08569336, 8.44708443], [78.08569336, 8.44680595], [78.0854187, 8.44681072], [78.0854187, 8.44653034], [78.08513641, 8.44653034], [78.08513641, 8.44624996], [78.08486176, 8.44624996], [78.08486176, 8.44596958], [78.0845871, 8.44597244], [78.0845871, 8.44569397], [78.08430481, 8.44569397], [78.08430481, 8.44541645], [78.08403015, 8.44542122], [78.08403015, 8.44514179], [78.08374786, 8.44514179], [78.08374786, 8.44458199], [78.08347321, 8.44458199], [78.08347321, 8.44430637], [78.08319092, 8.44431114], [78.08319092, 8.44402122], [78.08291626, 8.4440279], [78.08291626, 8.44375038], [78.0826416, 8.44375038], [78.0826416, 8.44347191], [78.08235931, 8.44347191], [78.08235931, 8.44319439], [78.08208466, 8.44319439], [78.08208466, 8.44291592], [78.08180237, 8.44291973], [78.08180237, 8.44236183], [78.08152771, 8.44236183], [78.08152771, 8.44208431], [78.08125305, 8.44208431], [78.08125305, 8.44180584], [78.08097076, 8.44180965], [78.08097076, 8.44153023], [78.08069611, 8.44153023], [78.08069611, 8.44124985], [78.08040619, 8.44124985], [78.08040619, 8.44069099], [78.08013916, 8.44069576], [78.08013916, 8.44013977], [78.07985687, 8.44013977], [78.07985687, 8.43985939], [78.07958221, 8.43986225], [78.07958221, 8.43930626], [78.07930756, 8.43931007], [78.07930756, 8.43875027], [78.07902527, 8.43875027], [78.07902527, 8.43847084], [78.07875061, 8.43847084], [78.07875061, 8.43791771], [78.07847595, 8.43791962], [78.07847595, 8.43735886], [78.07819366, 8.43736172], [78.07819366, 8.43708324], [78.07791901, 8.43708324], [78.07791901, 8.43680477], [78.07763672, 8.43680954], [78.07763672, 8.43625164], [78.07736206, 8.43625164], [78.07736206, 8.43597126], [78.07707977, 8.43597126], [78.07707977, 8.43569469], [78.07680511, 8.43569469], [78.07680511, 8.4351387], [78.07653046, 8.43514156], [78.07653046, 8.43484974], [78.07624817, 8.43486118], [78.07624817, 8.43458271], [78.07597351, 8.43458271], [78.07597351, 8.43430519], [78.07569122, 8.43431187], [78.07569122, 8.4337492], [78.07541656, 8.4337492], [78.07541656, 8.43347263], [78.07514191, 8.43347263], [78.07514191, 8.43319511], [78.07485962, 8.43319511], [78.07485962, 8.43291664], [78.07459259, 8.43291855], [78.07459259, 8.43264103], [78.07430267, 8.43264103], [78.07430267, 8.43208122], [78.07402802, 8.43208313], [78.07402802, 8.43180466], [78.07376099, 8.43181038], [78.07376099, 8.43153095], [78.07347107, 8.43153095], [78.07347107, 8.43125057], [78.07319641, 8.43125057], [78.07319641, 8.43097115], [78.07291412, 8.43097305], [78.07291412, 8.43069458], [78.07263947, 8.43069458], [78.07263947, 8.43013859], [78.07235718, 8.43014145], [78.07235718, 8.42986107], [78.07208252, 8.42986107], [78.07208252, 8.4295826], [78.07180786, 8.4295826], [78.07180786, 8.42930698], [78.0715332, 8.42930889], [78.0715332, 8.42875099], [78.07125092, 8.42875099], [78.07125092, 8.42847061], [78.07096863, 8.42847347], [78.07096863, 8.428195], [78.07069397, 8.428195], [78.07069397, 8.42763901], [78.07041931, 8.42764091], [78.07041931, 8.42736053], [78.07013702, 8.42736053], [78.07013702, 8.42708302], [78.06986237, 8.42708302], [78.06986237, 8.42652893], [78.06958008, 8.42653084], [78.06958008, 8.42625141], [78.06930542, 8.42625141], [78.06930542, 8.42569542], [78.06903076, 8.42569542], [78.06903076, 8.42541695], [78.06874847, 8.42541885], [78.06874847, 8.42514133], [78.06846619, 8.42514133], [78.06846619, 8.42457962], [78.06819153, 8.42458153], [78.06819153, 8.42430687], [78.06791687, 8.42431068], [78.06791687, 8.42375088], [78.06762695, 8.42375088], [78.06762695, 8.42346954], [78.06735992, 8.4234724], [78.06735992, 8.42291641], [78.06708527, 8.42291641], [78.06708527, 8.42263794], [78.06680298, 8.4226408], [78.06680298, 8.42208004], [78.06652832, 8.42208195], [78.06652832, 8.42152786], [78.06624603, 8.42153072], [78.06624603, 8.42125034], [78.06597137, 8.42125034], [78.06597137, 8.42069435], [78.06569672, 8.42069435], [78.06569672, 8.42041588], [78.0654068, 8.42042065], [78.0654068, 8.4198513], [78.06513977, 8.41985989], [78.06513977, 8.41902828], [78.06485748, 8.41903019], [78.06485748, 8.41736031], [78.06458282, 8.41736221], [78.06458282, 8.41625023], [78.06430817, 8.41625023], [78.06430817, 8.41541576], [78.06402588, 8.41541958], [78.06402588, 8.41457939], [78.06375122, 8.41458416], [78.06375122, 8.41374969], [78.06346893, 8.41374969], [78.06346893, 8.41263962], [78.06318665, 8.41263962], [78.06318665, 8.41152954], [78.06291962, 8.41152954], [78.06291962, 8.41042042], [78.06263733, 8.41042042], [78.06263733, 8.40931034], [78.06236267, 8.40931034], [78.06236267, 8.4079113], [78.06208038, 8.40791702], [78.06208038, 8.40624905], [78.06182098, 8.40625095], [78.06182098, 8.40541935], [78.06153107, 8.40541935], [78.06153107, 8.40487003], [78.06124878, 8.40487003], [78.06124878, 8.40430927], [78.06096649, 8.40430927], [78.06096649, 8.40207958], [78.06069183, 8.4020834], [78.06069183, 8.40125084], [78.06041718, 8.40125084], [78.06041718, 8.39958], [78.06014252, 8.39958286], [78.06014252, 8.39847279], [78.05986023, 8.39847279], [78.05986023, 8.39791679], [78.0595932, 8.39792061], [78.0595932, 8.39764118], [78.05930328, 8.39764118], [78.05930328, 8.39708042], [78.05902863, 8.39708233], [78.05902863, 8.39680672], [78.0587616, 8.39681053], [78.0587616, 8.39653111], [78.05847168, 8.39653111], [78.05847168, 8.39597034], [78.05819702, 8.39597225], [78.05819702, 8.39541626], [78.0579071, 8.39542103], [78.0579071, 8.39457989], [78.05764008, 8.3945837], [78.05764008, 8.39375019], [78.05735779, 8.39375019], [78.05735779, 8.39263821], [78.05708313, 8.39264011], [78.05708313, 8.39181137], [78.05680847, 8.39181137], [78.05680847, 8.39097023], [78.05652618, 8.39097214], [78.05652618, 8.38986206], [78.05625153, 8.38987064], [78.05625153, 8.38903046], [78.05596924, 8.38903046], [78.05596924, 8.38792038], [78.05568695, 8.38792038], [78.05568695, 8.38652992], [78.05541992, 8.38652992], [78.05541992, 8.38514042], [78.05513763, 8.38514042], [78.05513763, 8.38374043], [78.05486298, 8.38374901], [78.05486298, 8.38291836], [78.05513763, 8.38292027], [78.05513763, 8.38236141], [78.05541992, 8.38236141], [78.05541992, 8.38180542], [78.05568695, 8.38181019], [78.05568695, 8.38125134], [78.05541992, 8.38125134], [78.05541992, 8.38152981], [78.05513763, 8.38152981], [78.05513763, 8.38181019], [78.05486298, 8.38180542], [78.05486298, 8.38208294], [78.05347443, 8.38208294], [78.05347443, 8.38180542], [78.05291748, 8.38181019], [78.05291748, 8.38152981], [78.05124664, 8.38152981], [78.05124664, 8.38181019], [78.04985809, 8.38181019], [78.04985809, 8.38152981], [78.04959106, 8.38152981], [78.04959106, 8.38041973], [78.04985809, 8.38041973], [78.04985809, 8.38013935], [78.05042267, 8.38013935], [78.05042267, 8.37986088], [78.05069733, 8.37986088], [78.05069733, 8.37958336], [78.05124664, 8.37958336], [78.05124664, 8.37930489], [78.05152893, 8.37930965], [78.05152893, 8.37902927], [78.05262756, 8.37902927], [78.05262756, 8.37874889], [78.05430603, 8.37874889], [78.05430603, 8.37902927], [78.05458069, 8.37902927], [78.05458069, 8.37930965], [78.05513763, 8.37930489], [78.05513763, 8.37958336], [78.05541992, 8.37958336], [78.05541992, 8.37986088], [78.05596924, 8.37986088], [78.05596924, 8.38013935], [78.05680847, 8.38013935], [78.05680847, 8.37986088], [78.05735779, 8.37986088], [78.05735779, 8.37958336], [78.05764008, 8.37958336], [78.05764008, 8.37930489], [78.0579071, 8.37930965], [78.0579071, 8.37902927], [78.05819702, 8.37902927], [78.05819702, 8.37874889], [78.05847168, 8.37874889], [78.05847168, 8.37819481], [78.05874634, 8.37819481], [78.05874634, 8.37791729], [78.05902863, 8.37793064], [78.05902863, 8.37764072], [78.05930328, 8.37764072], [78.05930328, 8.3773613], [78.05958557, 8.3773613], [78.05958557, 8.37708282], [78.05986023, 8.37708282], [78.05986023, 8.37680531], [78.06014252, 8.37681198], [78.06014252, 8.37653065], [78.06041718, 8.37653065], [78.06041718, 8.37597084], [78.06069183, 8.37597084], [78.06069183, 8.37569523], [78.06097412, 8.37569523], [78.06097412, 8.37541676], [78.06124878, 8.37542057], [78.06124878, 8.37514114], [78.06318665, 8.37514114], [78.06318665, 8.37542057], [78.06402588, 8.37541676], [78.06402588, 8.37569523], [78.06513977, 8.37569523], [78.06513977, 8.37541676], [78.06597137, 8.37542057], [78.06597137, 8.37514114], [78.06652832, 8.37514114], [78.06652832, 8.37485886], [78.06708527, 8.37486076], [78.06708527, 8.37458324], [78.06764221, 8.37458324], [78.06764221, 8.37402916], [78.06791687, 8.37403107], [78.06791687, 8.37347126], [78.06819153, 8.37347317], [78.06819153, 8.3726387], [78.06791687, 8.37264061], [78.06791687, 8.37236118], [78.06764221, 8.37236118], [78.06764221, 8.37180424], [78.06735992, 8.37180424], [78.06735992, 8.37125111], [78.06708527, 8.37125111], [78.06708527, 8.37069511], [78.06680298, 8.37069511], [78.06680298, 8.37041569], [78.0654068, 8.37042141], [78.0654068, 8.37014103], [78.06402588, 8.37014103], [78.06402588, 8.3698597], [78.06291962, 8.3698597], [78.06291962, 8.36958218], [78.05764008, 8.36958218], [78.05764008, 8.36930656], [78.05652618, 8.36931133], [78.05652618, 8.36903095], [78.05568695, 8.36903095], [78.05568695, 8.36874104], [78.05541992, 8.36874962], [78.05541992, 8.3684721], [78.05486298, 8.3684721], [78.05486298, 8.36819363], [78.05458069, 8.36819363], [78.05458069, 8.36791611], [78.05403137, 8.36792088], [78.05403137, 8.36763954], [78.05179596, 8.36763954], [78.05179596, 8.36736012], [78.04985809, 8.36736012], [78.04985809, 8.36708355], [78.04763794, 8.36708355], [78.04763794, 8.36680603], [78.04736328, 8.3668108], [78.04736328, 8.36653137], [78.04682159, 8.36653137], [78.04682159, 8.36625004], [78.04653168, 8.36625004], [78.04653168, 8.36596966], [78.04597473, 8.36597157], [78.04597473, 8.36569405], [78.04569244, 8.36570072], [78.04569244, 8.3654213], [78.04502869, 8.36541843], [78.04429626, 8.3654213], [78.04429626, 8.36513996], [78.04374695, 8.36513996], [78.04374695, 8.36485958], [78.04291534, 8.36486244], [78.04291534, 8.36458206], [78.0423584, 8.36458206], [78.0423584, 8.36430645], [78.04152679, 8.36431122], [78.04152679, 8.36403275], [78.04068756, 8.36403275], [78.04068756, 8.36375046], [78.03985596, 8.36375046], [78.03985596, 8.36347198], [78.03874969, 8.36347198], [78.03874969, 8.36319447], [78.03791809, 8.36319447], [78.03791809, 8.36291599], [78.03542328, 8.36292267], [78.03542328, 8.36264038], [78.03514099, 8.36264038], [78.03514099, 8.36236191], [78.03458405, 8.36236191], [78.03458405, 8.36208439], [78.03375244, 8.36208439], [78.03375244, 8.36180592], [78.03263855, 8.36180973], [78.03263855, 8.3615303], [78.03180695, 8.3615303], [78.03180695, 8.36124992], [78.02958679, 8.36124992], [78.02958679, 8.36096859], [78.02902985, 8.3609724], [78.02902985, 8.36069584], [78.0284729, 8.36069584], [78.0284729, 8.36041641], [78.02819824, 8.36042023], [78.02819061, 8.36013985], [78.0276413, 8.36013985], [78.0276413, 8.35986042], [78.02708435, 8.35986233], [78.02708435, 8.35958385], [78.0265274, 8.35958385], [78.0265274, 8.35930634], [78.02571106, 8.35931015], [78.02571106, 8.35902977], [78.0229187, 8.35902977], [78.0229187, 8.35875034], [78.02236176, 8.35875034], [78.02236176, 8.35847187], [78.0220871, 8.35847187], [78.0220871, 8.3581934], [78.02153015, 8.3581934], [78.02153015, 8.35791779], [78.02124786, 8.35791969], [78.02124786, 8.35764027], [78.02069092, 8.35764027], [78.02069092, 8.35736179], [78.02041626, 8.35736179], [78.02041626, 8.35708427], [78.01985931, 8.35708427], [78.01985931, 8.35680485], [78.01930237, 8.35680485], [78.01930237, 8.35652733], [78.01875305, 8.35653019], [78.01875305, 8.35624886], [78.01819611, 8.35624886], [78.01819611, 8.35597134], [78.01763916, 8.35597134], [78.01763916, 8.35569572], [78.01680756, 8.35569572], [78.01680756, 8.35541534], [78.01625061, 8.35542202], [78.01625061, 8.35514164], [78.01568604, 8.35514164], [78.01568604, 8.35486126], [78.01513672, 8.35486126], [78.01513672, 8.35458279], [78.01486206, 8.35458279], [78.01486206, 8.35430527], [78.01431274, 8.35431194], [78.01431274, 8.3540287], [78.01403046, 8.3540287], [78.01403046, 8.35376072], [78.01348114, 8.35376072], [78.01348114, 8.35346889], [78.01319122, 8.3534708], [78.01319122, 8.35319519], [78.01264191, 8.35319519], [78.01264191, 8.35291672], [78.01235962, 8.35291958], [78.01235962, 8.3526392], [78.01180267, 8.3526392], [78.01180267, 8.35236073], [78.01152802, 8.35236073], [78.01152802, 8.35208321], [78.01125336, 8.35208321], [78.01125336, 8.35180473], [78.01097107, 8.35181046], [78.01097107, 8.35153198], [78.01071167, 8.35153198], [78.01071167, 8.35125065], [78.01042175, 8.35125065], [78.01042175, 8.35153198], [78.00985718, 8.35153198], [78.00985718, 8.35181046], [78.00958252, 8.35180473], [78.00958252, 8.35208321], [78.00930786, 8.3520813], [78.00930786, 8.3526392], [78.00818634, 8.3526392], [78.00818634, 8.35236073], [78.00763702, 8.35236073], [78.00763702, 8.35208321], [78.00708008, 8.35208321], [78.00708008, 8.35180473], [78.00624847, 8.35181046], [78.00624847, 8.35153198], [78.00569153, 8.35153198], [78.00569153, 8.35125065], [78.00514221, 8.35125065], [78.00514221, 8.35097122], [78.00485992, 8.35097313], [78.00485992, 8.35069466], [78.00457764, 8.35070038], [78.00457764, 8.35042191], [78.00428772, 8.35042191], [78.00428772, 8.35014057], [78.00374603, 8.35014057], [78.00374603, 8.34986115], [78.00347137, 8.34986115], [78.00347137, 8.34958267], [78.00319672, 8.34958267], [78.00319672, 8.34930515], [78.00263977, 8.34930515], [78.00263977, 8.34958267], [78.00096893, 8.34958267], [78.00096893, 8.34930515], [77.99986267, 8.34931183], [77.99958038, 8.34931183], [77.99958038, 8.34875107], [77.99874878, 8.34875107], [77.99874878, 8.34847069], [77.99819183, 8.3484726], [77.99819183, 8.34819508], [77.99764252, 8.34819508], [77.99764252, 8.3479166], [77.9970932, 8.34792137], [77.9970932, 8.34762955], [77.99652863, 8.34763908], [77.99652863, 8.34736061], [77.99569702, 8.34736061], [77.99569702, 8.34708309], [77.99514008, 8.34708309], [77.99514008, 8.34680462], [77.99458313, 8.34681129], [77.99458313, 8.34653091], [77.99402618, 8.34653091], [77.99402618, 8.34625053], [77.99346924, 8.34625053], [77.99346924, 8.34597015], [77.99291992, 8.34597301], [77.99291992, 8.34569454], [77.99208069, 8.34569454], [77.99208069, 8.34541702], [77.99153137, 8.34542084], [77.99153137, 8.34514141], [77.9909668, 8.34514141], [77.9909668, 8.34486103], [77.99041748, 8.34486103], [77.99041748, 8.3445816], [77.98986053, 8.3445816], [77.98986053, 8.34430695], [77.98902893, 8.34430885], [77.98902893, 8.34403133], [77.98847198, 8.34403133], [77.98847198, 8.34375095], [77.98792267, 8.34375095], [77.98792267, 8.34346962], [77.98764038, 8.34347343], [77.98764038, 8.34319401], [77.98735809, 8.34319401], [77.98735809, 8.34292984], [77.98680878, 8.34292126], [77.98680878, 8.34264088], [77.98654175, 8.34264088], [77.98654175, 8.34235954], [77.98625183, 8.34236336], [77.98625183, 8.34208202], [77.98596954, 8.34208202], [77.98596954, 8.34180641], [77.98542023, 8.34181976], [77.98542023, 8.3415308], [77.98319244, 8.3415308], [77.98319244, 8.34125042], [77.98236084, 8.34125042], [77.98236084, 8.34097195], [77.98208618, 8.34097195], [77.98208618, 8.34069443], [77.98152924, 8.34069443], [77.98152924, 8.34041595], [77.98097229, 8.34042072], [77.98097229, 8.34014034], [77.98040771, 8.34014034], [77.98040771, 8.33985996], [77.98014069, 8.33985996], [77.98014069, 8.33958435], [77.9798584, 8.33958435], [77.9798584, 8.33930588], [77.97957611, 8.33931065], [77.97957611, 8.33903027], [77.97930908, 8.33903027], [77.97930908, 8.33875942], [77.97902679, 8.33875942], [77.97902679, 8.33847046], [77.97875214, 8.33847237], [77.97875214, 8.33819389], [77.97846985, 8.33819389], [77.97846985, 8.33791637], [77.97820282, 8.33792114], [77.97820282, 8.33764172], [77.9779129, 8.33764172], [77.9779129, 8.33736038], [77.97763824, 8.33736229], [77.97763824, 8.33708382], [77.97736359, 8.33708191], [77.97736359, 8.3368063], [77.9770813, 8.33681107], [77.9770813, 8.33652973], [77.97651672, 8.33652973], [77.97651672, 8.33625031], [77.97624969, 8.33625031], [77.97624969, 8.33597183], [77.97597504, 8.33597183], [77.97597504, 8.33569431], [77.97569275, 8.33569431], [77.97569275, 8.33541584], [77.9751358, 8.33541965], [77.9751358, 8.33514023], [77.97460175, 8.33514023], [77.97460175, 8.33485985], [77.97402954, 8.33485985], [77.97402954, 8.33458424], [77.9734726, 8.33458424], [77.9734726, 8.33430576], [77.97292328, 8.33430958], [77.97292328, 8.33403015], [77.9723587, 8.33403015], [77.9723587, 8.33374977], [77.97180176, 8.33374977], [77.97180176, 8.33346939], [77.97125244, 8.33347225], [77.97125244, 8.33319378], [77.9706955, 8.33319378], [77.9706955, 8.33291626], [77.97013855, 8.33292007], [77.97013855, 8.33263111], [77.96847534, 8.33263969], [77.96847534, 8.33236217], [77.96819305, 8.33236217], [77.96819305, 8.3320837], [77.96763611, 8.3320837], [77.96763611, 8.33180618], [77.96736145, 8.33181], [77.96736145, 8.33152962], [77.96679688, 8.33152962], [77.96679688, 8.33096886], [77.96708679, 8.33097076], [77.96708679, 8.33041763], [77.9659729, 8.33041954], [77.9659729, 8.33014202], [77.96540833, 8.33014202], [77.96540833, 8.32986164], [77.96485901, 8.32986164], [77.96485901, 8.32958317], [77.96430206, 8.32958984], [77.96430206, 8.32931042], [77.96375275, 8.32931042], [77.96375275, 8.32903194], [77.96347046, 8.32903194], [77.96347046, 8.32891083], [77.96347046, 8.3287487], [77.96318054, 8.32879257], [77.9631958, 8.32847118], [77.96260834, 8.32846928], [77.96263885, 8.3281908], [77.9623642, 8.32819462], [77.9623642, 8.3279171], [77.96208191, 8.32792187], [77.96208191, 8.32764244], [77.96180725, 8.32764244], [77.96180725, 8.3273592], [77.96152496, 8.32736111], [77.96152496, 8.32708263], [77.96125031, 8.32708263], [77.96125031, 8.32680511], [77.96098328, 8.32682133], [77.96098328, 8.32652855], [77.96069336, 8.32652855], [77.96069336, 8.32625103], [77.9604187, 8.32625103], [77.9604187, 8.32597065], [77.96013641, 8.32597256], [77.96013641, 8.32569313], [77.95986176, 8.32569313], [77.95986176, 8.32513905], [77.95960236, 8.32514095], [77.95960236, 8.32486057], [77.95903015, 8.32486057], [77.95903015, 8.32458305], [77.95819092, 8.32458305], [77.95819092, 8.32430458], [77.95791626, 8.3243103], [77.95791626, 8.32403088], [77.9576416, 8.32403088], [77.9576416, 8.32375145], [77.95735931, 8.32375145], [77.95735931, 8.32346153], [77.95680237, 8.32347298], [77.95680237, 8.32319546], [77.95652771, 8.32319546], [77.95652771, 8.32291698], [77.95623779, 8.32291889], [77.95623779, 8.32208061], [77.95597076, 8.32208347], [77.95597076, 8.32152653], [77.95569611, 8.3215313], [77.95569611, 8.32097054], [77.95541382, 8.3209734], [77.95541382, 8.32069492], [77.95513916, 8.32069492], [77.95513916, 8.32013893], [77.95485687, 8.32014084], [77.95485687, 8.31986141], [77.95458221, 8.31986141], [77.95458221, 8.31958294], [77.95430756, 8.31958294], [77.95430756, 8.31819534], [77.95458221, 8.31819534], [77.95458221, 8.31763935], [77.95430756, 8.31764984], [77.95430756, 8.31735992], [77.95402527, 8.31735992], [77.95402527, 8.31486034], [77.95375061, 8.31486034], [77.95375061, 8.31402779], [77.95291901, 8.31403065], [77.95291901, 8.31375027], [77.95236206, 8.31375027], [77.95236206, 8.31319427], [77.95207977, 8.31319427], [77.95207977, 8.3129158], [77.95181274, 8.31292057], [77.95181274, 8.31264019], [77.95096588, 8.31264019], [77.95096588, 8.31236172], [77.95014191, 8.31236172], [77.95014191, 8.31208038], [77.94985962, 8.3120842], [77.94985962, 8.31180573], [77.94930267, 8.31181145], [77.94930267, 8.31152058], [77.94875336, 8.31152821], [77.94875336, 8.31124973], [77.94790649, 8.31124973], [77.94790649, 8.31097031], [77.94736481, 8.31097221], [77.94736481, 8.31069374], [77.94680786, 8.31069374], [77.94680786, 8.31041622], [77.94625092, 8.31042004], [77.94625092, 8.31013966], [77.94541931, 8.31013966], [77.94541931, 8.30986023], [77.94486237, 8.30986214], [77.94486237, 8.30958366], [77.94458008, 8.30958366], [77.94458008, 8.30930614], [77.94403076, 8.30931091], [77.94403076, 8.30902958], [77.94319153, 8.30902958], [77.94319153, 8.30875015], [77.94291687, 8.30875015], [77.94291687, 8.30847168], [77.94264221, 8.30847168], [77.94264221, 8.30819416], [77.94235992, 8.30819416], [77.94235992, 8.30791569], [77.9420929, 8.30792046], [77.9420929, 8.30764008], [77.94180298, 8.30764008], [77.94180298, 8.3073597], [77.94152832, 8.3073597], [77.94152832, 8.30708408], [77.94097137, 8.30708408], [77.94097137, 8.30680561], [77.94069672, 8.30681038], [77.94069672, 8.30653], [77.94013977, 8.30653], [77.94013977, 8.30624962], [77.93958282, 8.30624962], [77.93958282, 8.30596924], [77.93930817, 8.3059721], [77.93930817, 8.30569363], [77.93875122, 8.30569363], [77.93875122, 8.30541801], [77.93681335, 8.30541992], [77.93681335, 8.30513954], [77.93653107, 8.30513954], [77.93653107, 8.30486202], [77.93596649, 8.30486202], [77.93596649, 8.30458069], [77.93569183, 8.30458355], [77.93569183, 8.30430603], [77.93543243, 8.30430984], [77.93543243, 8.30403042], [77.93486023, 8.30403042], [77.93486023, 8.30375195], [77.9345932, 8.30375195], [77.9345932, 8.30347061], [77.93430328, 8.30347061], [77.93430328, 8.30319309], [77.93374634, 8.30319309], [77.93374634, 8.30291843], [77.93347168, 8.30292034], [77.93347168, 8.30265141], [77.93319702, 8.30265141], [77.93319702, 8.30236053], [77.93273163, 8.30236053], [77.93235779, 8.30236053], [77.93235779, 8.30208302], [77.93208313, 8.30208302], [77.93208313, 8.30180454], [77.93180847, 8.30181026], [77.93180847, 8.30153179], [77.93152618, 8.30153179], [77.93152618, 8.30125237], [77.93096924, 8.30125237], [77.93096924, 8.30097103], [77.93013763, 8.30097103], [77.93013763, 8.30041695], [77.92986298, 8.30041981], [77.92986298, 8.29958057], [77.92958069, 8.29958344], [77.92958069, 8.29902744], [77.92949677, 8.29902744], [77.92903137, 8.29902935], [77.92903137, 8.29875088], [77.92874908, 8.29875088], [77.92874908, 8.2982502], [77.92847443, 8.29819489], [77.92847443, 8.29791737], [77.92791748, 8.29791927], [77.92791748, 8.29763889], [77.92764282, 8.29763889], [77.92764282, 8.29736137], [77.92569733, 8.29736137], [77.92569733, 8.2970829], [77.92319489, 8.2970829], [77.92319489, 8.29680538], [77.92292023, 8.29681015], [77.92292023, 8.29652023], [77.92208099, 8.29652691], [77.92208099, 8.2962513], [77.92151642, 8.2962513], [77.92151642, 8.29597092], [77.92124939, 8.29597092], [77.92124939, 8.2956953], [77.92097473, 8.2956953], [77.92097473, 8.29541683], [77.92012787, 8.2954216], [77.92012787, 8.29514122], [77.91929626, 8.29514122], [77.91929626, 8.29486084], [77.91902924, 8.29486084], [77.91902924, 8.29458332], [77.91680908, 8.29458332], [77.91680908, 8.29430485], [77.91625214, 8.29431152], [77.91625214, 8.29403114], [77.91570282, 8.29403114], [77.91570282, 8.29374886], [77.9154129, 8.29375076], [77.9154129, 8.29347324], [77.91485596, 8.29348183], [77.91485596, 8.29319], [77.91430664, 8.29319477], [77.91430664, 8.29291725], [77.91400909, 8.29292107], [77.91400909, 8.29264069], [77.91374969, 8.29264069], [77.91374969, 8.29236126], [77.91347504, 8.29236126], [77.91347504, 8.29208469], [77.91291809, 8.29208469], [77.91291809, 8.29180527], [77.9126358, 8.29181099], [77.9126358, 8.29153061], [77.91236115, 8.29153061], [77.91236115, 8.29125118], [77.91179657, 8.29125118], [77.91179657, 8.29096985], [77.91152954, 8.29097271], [77.91152954, 8.29069519], [77.9109726, 8.29069519], [77.9109726, 8.29041672], [77.91042328, 8.29042053], [77.91042328, 8.29014111], [77.91014099, 8.29014111], [77.91014099, 8.28985977], [77.90957642, 8.28985977], [77.90957642, 8.28958035], [77.90875244, 8.28958225], [77.90875244, 8.28930664], [77.90791321, 8.28931141], [77.90791321, 8.28903103], [77.90735626, 8.28903103], [77.90735626, 8.28874969], [77.90651703, 8.28874969], [77.90651703, 8.28847027], [77.90597534, 8.28847218], [77.90597534, 8.2881937], [77.9054184, 8.2881937], [77.9054184, 8.28791618], [77.90512848, 8.28792095], [77.90512848, 8.28764057], [77.90458679, 8.28764057], [77.90458679, 8.28736019], [77.9043045, 8.28736019], [77.9043045, 8.28708363], [77.90374756, 8.28708363], [77.90374756, 8.2868042], [77.90319824, 8.28681087], [77.90319061, 8.28653145], [77.90206909, 8.28653145], [77.90206909, 8.28625011], [77.9015274, 8.28625011], [77.9015274, 8.28596973], [77.90097046, 8.28597164], [77.90097046, 8.28569412], [77.9006958, 8.28569412], [77.9006958, 8.28541565], [77.90040588, 8.28542137], [77.90040588, 8.28514004], [77.90013885, 8.28514004], [77.90013885, 8.28485966], [77.8998642, 8.28486156], [77.8998642, 8.28458405], [77.89930725, 8.28458405], [77.89930725, 8.28430557], [77.89903259, 8.28431129], [77.89903259, 8.28402996], [77.89875031, 8.28402996], [77.89875031, 8.28382969], [77.89875031, 8.28374958], [77.89848328, 8.28374958], [77.89848328, 8.28347015], [77.89819336, 8.28347206], [77.89819336, 8.28291607], [77.8979187, 8.28292274], [77.8979187, 8.28264046], [77.89763641, 8.28264046], [77.89763641, 8.28236198], [77.89736176, 8.28236198], [77.89736176, 8.28208447], [77.8970871, 8.28208447], [77.8970871, 8.28180599], [77.89679718, 8.28181267], [77.89679718, 8.28154182], [77.89653015, 8.28154182], [77.89653015, 8.28125], [77.89624786, 8.28125], [77.89624786, 8.28096962], [77.89597321, 8.28097153], [77.89597321, 8.28069401], [77.89569092, 8.28069401], [77.89569092, 8.28013992], [77.89541626, 8.28013992], [77.89541626, 8.27985954], [77.8951416, 8.2798624], [77.8951416, 8.27930641], [77.89485931, 8.27931023], [77.89485931, 8.27902985], [77.8951416, 8.27902985], [77.8951416, 8.27875042], [77.89485931, 8.27875042], [77.89485931, 8.27847195], [77.89457703, 8.27848053], [77.89457703, 8.27819061], [77.89402771, 8.27819443], [77.89402771, 8.27791786], [77.89375305, 8.27791977], [77.89375305, 8.27764034], [77.89318848, 8.27764034], [77.89318848, 8.27708054], [77.89291382, 8.27708435], [77.89291382, 8.27680588], [77.89263916, 8.27680969], [77.89263916, 8.27653027], [77.89235687, 8.27653027], [77.89235687, 8.27625179], [77.89208221, 8.27625179], [77.89208221, 8.27597141], [77.89180756, 8.27597141], [77.89180756, 8.2756958], [77.89152527, 8.2756958], [77.89152527, 8.27541542], [77.89125061, 8.27542019], [77.89125061, 8.27513885], [77.89097595, 8.27513885], [77.89097595, 8.27486134], [77.89013672, 8.27486134], [77.89013672, 8.27458286], [77.88986206, 8.27458286], [77.88986206, 8.27430534], [77.88931274, 8.27431202], [77.88931274, 8.27374935], [77.88903046, 8.27374935], [77.88903046, 8.27319527], [77.88819122, 8.27319527], [77.88819122, 8.27291679], [77.88735962, 8.27291965], [77.88735962, 8.27263927], [77.8840332, 8.27263927], [77.8840332, 8.27235031], [77.88375092, 8.2723608], [77.88375092, 8.27208328], [77.88319397, 8.27208328], [77.88319397, 8.27180481], [77.88291931, 8.27180958], [77.88291931, 8.2715292], [77.88263702, 8.2715292], [77.88263702, 8.27125072], [77.88208008, 8.27125072], [77.88208008, 8.2709713], [77.88180542, 8.27097321], [77.88180542, 8.27069473], [77.88153076, 8.27069473], [77.88153076, 8.27041721], [77.88095856, 8.27042198], [77.88095856, 8.27014065], [77.88014221, 8.27014065], [77.88014221, 8.26986122], [77.87985992, 8.26986122], [77.87985992, 8.26958275], [77.87930298, 8.26958275], [77.87930298, 8.26930523], [77.87847137, 8.2693119], [77.87847137, 8.26903057], [77.87789917, 8.26903057], [77.87789917, 8.26875114], [77.87763977, 8.26875114], [77.87763977, 8.26847267], [77.87708282, 8.26847267], [77.87708282, 8.26819515], [77.87680817, 8.26819515], [77.87680817, 8.26791668], [77.87625122, 8.26792145], [77.87625122, 8.26764107], [77.87596893, 8.26764107], [77.87596893, 8.26736069], [77.87504578, 8.26736069], [77.87430573, 8.26736069], [77.87430573, 8.26708317], [77.87319183, 8.26708317], [77.87319183, 8.2668047], [77.8720932, 8.26681232], [77.8720932, 8.26653957], [77.87097168, 8.26653957], [77.87097168, 8.26625061], [77.8704071, 8.26625061], [77.8704071, 8.26597118], [77.86985779, 8.26597309], [77.86985779, 8.26569462], [77.86930847, 8.26569462], [77.86930847, 8.2654171], [77.86875153, 8.26542091], [77.86875153, 8.26514053], [77.86846924, 8.26514053], [77.86846924, 8.26486111], [77.86819458, 8.26486111], [77.86819458, 8.26458263], [77.86708069, 8.26458263], [77.86708069, 8.26486111], [77.86541748, 8.26486111], [77.86541748, 8.26458263], [77.86486053, 8.26458263], [77.86486053, 8.26430416], [77.86429596, 8.26431084], [77.86429596, 8.26403141], [77.86402893, 8.26403141], [77.86402893, 8.26375103], [77.86347198, 8.26375103], [77.86347198, 8.26347923], [77.86292267, 8.26347923], [77.86292267, 8.26319027], [77.86264038, 8.26319504], [77.86264038, 8.26291561], [77.86207581, 8.26292133], [77.86207581, 8.26264095], [77.86152649, 8.26264095], [77.86152649, 8.26235962], [77.86125183, 8.26236343], [77.86125183, 8.2620821], [77.86069489, 8.2620821], [77.86069489, 8.26180744], [77.8601532, 8.26181126], [77.8601532, 8.26153088], [77.85958099, 8.26153088], [77.85958099, 8.26124954], [77.85901642, 8.26124954], [77.85901642, 8.26097012], [77.85847473, 8.26097202], [77.85847473, 8.26069355], [77.85791779, 8.26069355], [77.85791779, 8.26041603], [77.85736084, 8.26041603], [77.85736084, 8.26013756], [77.85678864, 8.26014042], [77.85678864, 8.25986004], [77.85624695, 8.25986004], [77.85624695, 8.25958443], [77.85569763, 8.25958443], [77.85569763, 8.25930595], [77.8548584, 8.25931072], [77.8548584, 8.2590313], [77.85401917, 8.2590313], [77.85401917, 8.25874996], [77.85320282, 8.25874996], [77.85320282, 8.25846958], [77.85236359, 8.25847244], [77.85236359, 8.25819397], [77.85152435, 8.25819397], [77.85152435, 8.25791645], [77.85098267, 8.25792122], [77.85098267, 8.25764275], [77.84986115, 8.25764275], [77.84986115, 8.25735092], [77.84902954, 8.25736237], [77.84902954, 8.25708199], [77.8484726, 8.25708199], [77.8484726, 8.25680637], [77.84764099, 8.25681114], [77.84764099, 8.25653267], [77.84680176, 8.25653267], [77.84680176, 8.25625038], [77.84597015, 8.25625038], [77.84597015, 8.25597191], [77.84513855, 8.25597191], [77.84513855, 8.25569439], [77.84402466, 8.25569439], [77.84402466, 8.25541592], [77.84319305, 8.25541973], [77.84319305, 8.2551403], [77.84236145, 8.2551403], [77.84236145, 8.25486183], [77.8401413, 8.25486183], [77.8401413, 8.25458431], [77.83958435, 8.25458431], [77.83958435, 8.25430584], [77.83904266, 8.25430965], [77.83904266, 8.25403023], [77.8381958, 8.25403023], [77.8381958, 8.25374985], [77.83735657, 8.25374985], [77.83735657, 8.25346947], [77.83680725, 8.25347233], [77.83680725, 8.25319386], [77.83569336, 8.25319386], [77.83569336, 8.25291634], [77.83429718, 8.25292015], [77.83429718, 8.25263977], [77.83374786, 8.25263977], [77.83374786, 8.25236034], [77.83319092, 8.25236225], [77.83319092, 8.25208378], [77.83235931, 8.25208378], [77.83235931, 8.25180626], [77.83152771, 8.25181007], [77.83152771, 8.25154114], [77.83040619, 8.25154114], [77.83040619, 8.25125027], [77.82958221, 8.25125027], [77.82958221, 8.25097179], [77.82847595, 8.25097179], [77.82847595, 8.25069332], [77.82707977, 8.25069332], [77.82707977, 8.25041771], [77.82653046, 8.25041962], [77.82653046, 8.25014019], [77.82541656, 8.25014019], [77.82541656, 8.24985886], [77.82430267, 8.24986172], [77.82430267, 8.2495842], [77.82347107, 8.2495842], [77.82347107, 8.24930477], [77.82235718, 8.24930954], [77.82235718, 8.24903202], [77.8215332, 8.24903202], [77.8215332, 8.24875164], [77.82068634, 8.24875164], [77.82068634, 8.24847126], [77.81986237, 8.24847126], [77.81986237, 8.24819565], [77.81930542, 8.24819565], [77.81930542, 8.24791527], [77.81874847, 8.24792194], [77.81874847, 8.24764156], [77.81819153, 8.24764156], [77.81819153, 8.24735928], [77.81764221, 8.24736118], [77.81764221, 8.24708271], [77.81735992, 8.24708271], [77.81735992, 8.24680519], [77.81680298, 8.24680996], [77.81680298, 8.24652863], [77.81652832, 8.24652863], [77.81652832, 8.2462492], [77.81346893, 8.2462492], [77.81346893, 8.24597263], [77.81291962, 8.24597263], [77.81291962, 8.24569321], [77.81263733, 8.24569321], [77.81263733, 8.24541664], [77.81208038, 8.24541664], [77.81208038, 8.24513912], [77.81181335, 8.24514103], [77.81181335, 8.24486065], [77.81124878, 8.24486065], [77.81124878, 8.24458313], [77.81097412, 8.24458313], [77.81097412, 8.24430466], [77.81069183, 8.24431038], [77.81069183, 8.24403191], [77.81014252, 8.24403191], [77.81014252, 8.24375057], [77.80986023, 8.24375057], [77.80986023, 8.24347115], [77.80902863, 8.24347305], [77.80902863, 8.24319458], [77.80847168, 8.24319458], [77.80847168, 8.24291706], [77.8079071, 8.24292183], [77.8079071, 8.24264145], [77.80735779, 8.24264145], [77.80735779, 8.24236965], [77.80708313, 8.24236965], [77.80708313, 8.24208069], [77.80680847, 8.2420826], [77.80680847, 8.24180698], [77.80596924, 8.24180889], [77.80596924, 8.24153137], [77.80513763, 8.24153137], [77.80513763, 8.24125099], [77.80486298, 8.24125099], [77.80486298, 8.24097061], [77.80458069, 8.24097347], [77.80458069, 8.240695], [77.80430603, 8.240695], [77.80430603, 8.24041653], [77.8034668, 8.2404213], [77.8034668, 8.24014091], [77.80236053, 8.24014091], [77.80236053, 8.2404213], [77.80208588, 8.2404213], [77.80208588, 8.24180889], [77.80264282, 8.24180889], [77.80264282, 8.24236965], [77.80319214, 8.24236965], [77.80319214, 8.24264145], [77.8034668, 8.24264145], [77.8034668, 8.24403191], [77.80374908, 8.24402714], [77.80374908, 8.2462492], [77.80403137, 8.2462492], [77.80403137, 8.24652863], [77.80430603, 8.24652672], [77.80430603, 8.24708271], [77.80458069, 8.2470789], [77.80458069, 8.24792194], [77.80430603, 8.24791527], [77.80430603, 8.24819565], [77.80403137, 8.24819565], [77.80403137, 8.24791527], [77.80374908, 8.24792194], [77.80374908, 8.24735928], [77.80347443, 8.24736118], [77.80347443, 8.24652672], [77.80319214, 8.24652863], [77.80319214, 8.24540997], [77.80291748, 8.24541664], [77.80291748, 8.24513912], [77.80236053, 8.24514103], [77.80236053, 8.24486065], [77.80208588, 8.24486065], [77.80208588, 8.24430466], [77.80179596, 8.24431038], [77.80179596, 8.24347115], [77.80152893, 8.24347305], [77.80152893, 8.24319458], [77.80124664, 8.24319458], [77.80124664, 8.24263859], [77.80097198, 8.24264145], [77.80097198, 8.24236965], [77.80069733, 8.24236965], [77.80069733, 8.24208069], [77.80041504, 8.2420826], [77.80041504, 8.2415266], [77.80014038, 8.24153137], [77.80014038, 8.23856163], [77.80014038, 8.23791695], [77.79987335, 8.23791885], [77.79987335, 8.23764133], [77.79957581, 8.23764133], [77.79957581, 8.23653126], [77.79987335, 8.23653126], [77.79987335, 8.23596954], [77.79958344, 8.23597336], [77.79958344, 8.23541641], [77.79930878, 8.23542118], [77.79930878, 8.2343111], [77.79902649, 8.2343111], [77.79902649, 8.23403072], [77.79875183, 8.23403072], [77.79875183, 8.23375034], [77.79846954, 8.23375034], [77.79846954, 8.23347187], [77.79819489, 8.23347187], [77.79819489, 8.23319435], [77.79763794, 8.23319435], [77.79763794, 8.23291588], [77.79708099, 8.23292065], [77.79708099, 8.23264027], [77.79680634, 8.23264027], [77.79680634, 8.23235989], [77.79651642, 8.23235989], [77.79651642, 8.23181057], [77.79624939, 8.23181057], [77.79624939, 8.23153019], [77.79569244, 8.23153019], [77.79569244, 8.23125172], [77.79541779, 8.23125172], [77.79541779, 8.23097038], [77.79486084, 8.23097229], [77.79486084, 8.23069382], [77.79430389, 8.23069382], [77.79430389, 8.2304163], [77.79402924, 8.23042965], [77.79402924, 8.23013973], [77.79373932, 8.23013973], [77.79373932, 8.22986031], [77.79347229, 8.22986221], [77.79347229, 8.22958374], [77.79319763, 8.22958374], [77.79319763, 8.22902775], [77.79264069, 8.22902966], [77.79264069, 8.22875023], [77.7923584, 8.22875023], [77.7923584, 8.22847176], [77.79180908, 8.22847176], [77.79180908, 8.22819424], [77.79152679, 8.22819424], [77.79152679, 8.22791576], [77.79125214, 8.22791958], [77.79125214, 8.22764015], [77.79096985, 8.22764015], [77.79096985, 8.22737122], [77.7904129, 8.22737122], [77.7904129, 8.22707939], [77.78986359, 8.22708416], [77.78986359, 8.22680569], [77.7895813, 8.22681046], [77.7895813, 8.22653008], [77.78901672, 8.22653008], [77.78901672, 8.22624969], [77.78848267, 8.22624969], [77.78848267, 8.22596931], [77.78791809, 8.22597218], [77.78791809, 8.2256937], [77.7876358, 8.2256937], [77.7876358, 8.22541809], [77.78708649, 8.22542], [77.78708649, 8.22513962], [77.78679657, 8.22513962], [77.78679657, 8.22485924], [77.78652954, 8.2248621], [77.78652954, 8.22458363], [77.78624725, 8.22458363], [77.78624725, 8.22430611], [77.7859726, 8.22430611], [77.7859726, 8.22402763], [77.78569794, 8.22402954], [77.78569794, 8.22347069], [77.78541565, 8.22347069], [77.78541565, 8.22319317], [77.7848587, 8.22319317], [77.7848587, 8.22264004], [77.78457642, 8.22264194], [77.78457642, 8.22208118], [77.78430176, 8.22208309], [77.78430176, 8.22124863], [77.7840271, 8.22124863], [77.7840271, 8.22069454], [77.78375244, 8.22069454], [77.78375244, 8.22041702], [77.78347015, 8.22042179], [77.78347015, 8.21986103], [77.78291321, 8.21986103], [77.78291321, 8.22013855], [77.78263855, 8.22013855], [77.78263855, 8.22042179], [77.7820816, 8.22042179], [77.7820816, 8.21958065], [77.78291321, 8.21958256], [77.78291321, 8.21652699], [77.78263855, 8.21652889], [77.78263855, 8.21543121], [77.78235626, 8.21543121], [77.78235626, 8.2143116], [77.78263855, 8.2143116], [77.78263855, 8.21403122], [77.78291321, 8.21403122], [77.78291321, 8.21347141], [77.7831955, 8.21347332], [77.7831955, 8.21291733], [77.78347015, 8.21291924], [77.78347015, 8.21207142], [77.7831955, 8.21208286], [77.7831955, 8.21125126], [77.78347015, 8.21125126], [77.78347015, 8.21041679], [77.78375244, 8.21042061], [77.78375244, 8.20903111], [77.7840271, 8.20903111], [77.7840271, 8.20764065], [77.78430176, 8.20764065], [77.78430176, 8.20736027], [77.7840271, 8.20736027], [77.7840271, 8.20652771], [77.78375244, 8.20653057], [77.78375244, 8.20542145], [77.78347015, 8.20542145], [77.78347015, 8.20514011], [77.78320313, 8.20514011], [77.78320313, 8.20458031], [77.78291321, 8.20458412], [77.78291321, 8.20263767], [77.78263855, 8.20263958], [77.78263855, 8.20236015], [77.7820816, 8.20236206], [77.7820816, 8.20180607], [77.78179932, 8.20181274], [77.78179932, 8.20125008], [77.7815094, 8.20125008], [77.7815094, 8.20068932], [77.78125, 8.20069408], [77.78125, 8.20041561], [77.78069305, 8.20042038], [77.78069305, 8.20013142], [77.7804184, 8.20014], [77.7804184, 8.19958401], [77.77986145, 8.19958401], [77.77986145, 8.19930553], [77.77958679, 8.1993103], [77.77958679, 8.19902992], [77.77929688, 8.19902992], [77.77929688, 8.19874954], [77.77902985, 8.19874954], [77.77902985, 8.19847202], [77.77874756, 8.19847202], [77.77874756, 8.19819355], [77.7784729, 8.19819355], [77.7784729, 8.19791794], [77.77819824, 8.19791985], [77.77819061, 8.19764042], [77.7776413, 8.19764042], [77.7776413, 8.19736195], [77.77707672, 8.19736195], [77.77707672, 8.19707012], [77.7765274, 8.19708443], [77.7765274, 8.19680595], [77.77625275, 8.19680977], [77.77625275, 8.19653034], [77.77597046, 8.19653034], [77.77597046, 8.19625187], [77.7756958, 8.19625187], [77.7756958, 8.19597054], [77.77513885, 8.19597054], [77.77513885, 8.19569588], [77.77236176, 8.19569302], [77.77236176, 8.19541454], [77.77153015, 8.19542027], [77.77153015, 8.19514179], [77.77041626, 8.19514179], [77.77041626, 8.19486141], [77.76958466, 8.19486141], [77.76958466, 8.19458294], [77.76875305, 8.19458294], [77.76875305, 8.19430542], [77.76790619, 8.19432068], [77.76790619, 8.19402981], [77.76568604, 8.19402981], [77.76568604, 8.19374943], [77.76557159, 8.19374943], [77.76541901, 8.19374943], [77.76541901, 8.19337082], [77.76541901, 8.19319534], [77.76528931, 8.19319534], [77.76513672, 8.19319534], [77.76513672, 8.19291687], [77.76486206, 8.19291973], [77.76486206, 8.19263935], [77.76457977, 8.19263935], [77.76457977, 8.19236088], [77.76430511, 8.19236088], [77.76430511, 8.19222546], [77.76430511, 8.19180489], [77.7637558, 8.19180965], [77.7637558, 8.19152927], [77.76346588, 8.19152927], [77.76346588, 8.19126034], [77.76264191, 8.19126034], [77.76264191, 8.19097137], [77.76208496, 8.19097328], [77.76208496, 8.19069481], [77.76180267, 8.19069481], [77.76180267, 8.19041729], [77.76125336, 8.1904192], [77.76125336, 8.19014072], [77.76097107, 8.19014072], [77.76097107, 8.1898613], [77.76041412, 8.1898613], [77.76041412, 8.18958282], [77.76013947, 8.18958282], [77.76013947, 8.18930531], [77.75985718, 8.18931198], [77.75985718, 8.18903065], [77.75958252, 8.18903065], [77.75958252, 8.18875122], [77.75930786, 8.18875122], [77.75930786, 8.18847084], [77.75875092, 8.18847084], [77.75875092, 8.18819523], [77.75791931, 8.18819523], [77.75791931, 8.18791676], [77.75708008, 8.18792152], [77.75708008, 8.18764114], [77.75653076, 8.18764114], [77.75653076, 8.18708134], [77.75624847, 8.18708324], [77.75624847, 8.18680477], [77.75596619, 8.1868124], [77.75596619, 8.18653107], [77.75569153, 8.18653107], [77.75569153, 8.18625069], [77.75541687, 8.18625069], [77.75541687, 8.18597126], [77.75514221, 8.18597317], [77.75514221, 8.18569469], [77.75430298, 8.18569469], [77.75430298, 8.18597317], [77.75347137, 8.18597126], [77.75347137, 8.18625069], [77.7518158, 8.18625069], [77.7518158, 8.18542099], [77.75347137, 8.18542099], [77.75347137, 8.18513203], [77.75375366, 8.1851387], [77.75375366, 8.18486118], [77.75402832, 8.18486118], [77.75402832, 8.18458271], [77.75430298, 8.18458271], [77.75430298, 8.18430519], [77.7545929, 8.18431091], [77.7545929, 8.18406105], [77.75458527, 8.18319511], [77.75430298, 8.18319511], [77.75430298, 8.18291664], [77.75402832, 8.18292141], [77.75402832, 8.18264103], [77.75319672, 8.18264103], [77.75319672, 8.1823597], [77.75291443, 8.1823597], [77.75291443, 8.18208218], [77.75263977, 8.18208218], [77.75263977, 8.18180656], [77.75235748, 8.18181133], [77.75235748, 8.18153095], [77.75152588, 8.18153095], [77.75152588, 8.18124962], [77.75096893, 8.18124962], [77.75096893, 8.18097019], [77.75069427, 8.1809721], [77.75069427, 8.18069363], [77.75041962, 8.18069363], [77.75041962, 8.18013763], [77.74958038, 8.18014145], [77.74958038, 8.17986012], [77.74874878, 8.17986012], [77.74874878, 8.17958355], [77.74819183, 8.17958355], [77.74819183, 8.17930603], [77.74764252, 8.17932034], [77.74764252, 8.17903137], [77.74736023, 8.17903137], [77.74736023, 8.17846966], [77.74708557, 8.17847157], [77.74708557, 8.17763805], [77.74680328, 8.17763996], [77.74680328, 8.17735958], [77.74624634, 8.17736244], [77.74624634, 8.17708206], [77.74541473, 8.17708206], [77.74541473, 8.17680645], [77.74430847, 8.17681122], [77.74430847, 8.17653275], [77.74375153, 8.17653275], [77.74375153, 8.17625046], [77.74318695, 8.17625046], [77.74318695, 8.17597198], [77.74291992, 8.17597198], [77.74291992, 8.17569447], [77.74263763, 8.17569447], [77.74263763, 8.17541599], [77.74180603, 8.17542267], [77.74180603, 8.17514038], [77.74014282, 8.17514038], [77.74014282, 8.17486191], [77.73929596, 8.17486191], [77.73929596, 8.17457867], [77.73902893, 8.17458439], [77.73902893, 8.17430592], [77.73735809, 8.17431068], [77.73735809, 8.1740303], [77.73681641, 8.1740303], [77.73681641, 8.17374992], [77.73568726, 8.17374992], [77.73568726, 8.17346954], [77.73542023, 8.17346954], [77.73542023, 8.17374992], [77.73438263, 8.17374992], [77.73430634, 8.17357159], [77.73430634, 8.1734724], [77.73347473, 8.1734724], [77.73347473, 8.17319584], [77.73236084, 8.17319584], [77.73236084, 8.17291641], [77.73152924, 8.17292023], [77.73152924, 8.17263985], [77.73124695, 8.17263985], [77.73124695, 8.17208195], [77.73069763, 8.17208385], [77.73069763, 8.17236233], [77.73014069, 8.17236042], [77.73014069, 8.17263985], [77.72930908, 8.17263985], [77.72930908, 8.17236042], [77.72902679, 8.17236233], [77.72902679, 8.17208385], [77.72846985, 8.17208385], [77.72846985, 8.17236233], [77.7279129, 8.17236233], [77.7279129, 8.17208385], [77.72763824, 8.17208385], [77.72763824, 8.17236233], [77.72736359, 8.17236233], [77.72736359, 8.17208385], [77.72680664, 8.17208385], [77.72680664, 8.17180634], [77.72624969, 8.17181015], [77.72624969, 8.17152977], [77.72541809, 8.17152977], [77.72541809, 8.17125034], [77.72458649, 8.17125034], [77.72458649, 8.17097187], [77.7234726, 8.17097187], [77.7234726, 8.17069435], [77.72319794, 8.17069435], [77.72319794, 8.17041779], [77.72264099, 8.17041969], [77.72264099, 8.16958141], [77.72208405, 8.16958427], [77.72208405, 8.16902733], [77.72180176, 8.16903019], [77.72180176, 8.16874886], [77.7215271, 8.16874886], [77.7215271, 8.16819572], [77.7206955, 8.16819572], [77.7206955, 8.16791534], [77.7195816, 8.16792202], [77.7195816, 8.16764164], [77.71930695, 8.16764164], [77.71930695, 8.16736126], [77.71875, 8.16736126], [77.71875, 8.16708279], [77.7179184, 8.16709042], [77.7179184, 8.16681004], [77.71708679, 8.16681004], [77.71708679, 8.16652966], [77.71652985, 8.16652966], [77.71652985, 8.16624928], [77.71624756, 8.16624928], [77.71624756, 8.16569328], [77.7159729, 8.16569328], [77.7159729, 8.1659708], [77.71485901, 8.1659708], [77.71485901, 8.16569328], [77.7131958, 8.16569328], [77.7131958, 8.1659708], [77.71263885, 8.16597271], [77.71263885, 8.16624928], [77.71180725, 8.16624928], [77.71180725, 8.16597271], [77.71013641, 8.1659708], [77.71013641, 8.16569328], [77.70986176, 8.16569328], [77.70986176, 8.16541672], [77.70929718, 8.16541958], [77.70929718, 8.1651392], [77.70903015, 8.1651392], [77.70903015, 8.16486073], [77.70707703, 8.16486073], [77.70707703, 8.1645813], [77.70680237, 8.16458321], [77.70680237, 8.16486073], [77.70652008, 8.16486073], [77.70652008, 8.1651392], [77.70540619, 8.1651392], [77.70540619, 8.16486073], [77.70513916, 8.16486073], [77.70513916, 8.16458321], [77.7048645, 8.16458321], [77.7048645, 8.16430473], [77.7040329, 8.16431046], [77.7040329, 8.16403198], [77.70291901, 8.16403198], [77.70291901, 8.16375065], [77.70263672, 8.16375065], [77.70263672, 8.16347122], [77.69985962, 8.16347313], [77.69985962, 8.16319466], [77.69958496, 8.16319466], [77.69958496, 8.16347313], [77.69875336, 8.16347313], [77.69875336, 8.16319466], [77.69819641, 8.16319466], [77.69819641, 8.16291714], [77.69652557, 8.16291714], [77.69652557, 8.16319466], [77.69625092, 8.16319466], [77.69625092, 8.16291714], [77.69569397, 8.16291714], [77.69569397, 8.16319466], [77.69513702, 8.16319466], [77.69513702, 8.16347313], [77.69486237, 8.16347313], [77.69486237, 8.16319466], [77.69458008, 8.16319466], [77.69458008, 8.16291714], [77.69264221, 8.16292191], [77.69264221, 8.16236115], [77.68875122, 8.16236115], [77.68875122, 8.16208267], [77.68680573, 8.16208267], [77.68680573, 8.16236115], [77.68653107, 8.16236115], [77.68653107, 8.16208267], [77.68541718, 8.16208267], [77.68541718, 8.16180515], [77.68514252, 8.16181183], [77.68514252, 8.16153145], [77.68264008, 8.16153145], [77.68264008, 8.16125107], [77.68235016, 8.16125107], [77.68235016, 8.16095924], [77.68125153, 8.1609726], [77.68125153, 8.16069508], [77.68013763, 8.16069508], [77.68013763, 8.1609726], [77.67736053, 8.1609726], [77.67736053, 8.16069508], [77.67624664, 8.16069508], [77.67624664, 8.1604166], [77.67597198, 8.16042137], [77.67597198, 8.16014099], [77.67569733, 8.16014099], [77.67569733, 8.15986061], [77.67541504, 8.15986061], [77.67541504, 8.15958309], [77.67346954, 8.15958309], [77.67346954, 8.15930462], [77.67319489, 8.15930462], [77.67319489, 8.15958309], [77.67292023, 8.15958309], [77.67292023, 8.15930462], [77.67263794, 8.15930462], [77.67263794, 8.15958309], [77.67236328, 8.15958309], [77.67236328, 8.15930462], [77.67041016, 8.15930939], [77.67041016, 8.15903091], [77.67014313, 8.15903091], [77.67014313, 8.15930939], [77.66986084, 8.15930939], [77.66986084, 8.15903091], [77.66902924, 8.15903091], [77.66902924, 8.15930939], [77.66874695, 8.15930939], [77.66874695, 8.15903091], [77.66680908, 8.15903091], [77.66680908, 8.15930939], [77.66652679, 8.15930939], [77.66652679, 8.15903091], [77.66570282, 8.15903091], [77.66570282, 8.15930939], [77.66430664, 8.15930939], [77.66430664, 8.15903091], [77.66348267, 8.15903091], [77.66348267, 8.15875053], [77.66236115, 8.15875053], [77.66236115, 8.15847111], [77.66208649, 8.15847111], [77.66208649, 8.15875053], [77.66179657, 8.15875053], [77.66179657, 8.15847111], [77.66014099, 8.15847301], [77.66014099, 8.15819454], [77.65847015, 8.15819454], [77.65847015, 8.15847301], [77.65791321, 8.15847301], [77.65791321, 8.15791702], [77.65680695, 8.15791702], [77.65680695, 8.15819454], [77.65569305, 8.15819454], [77.65569305, 8.15847301], [77.65513611, 8.15847111], [77.65513611, 8.15875053], [77.65486145, 8.15875053], [77.65486145, 8.15903091], [77.6534729, 8.15903091], [77.6534729, 8.15875053], [77.65180206, 8.15875053], [77.65180206, 8.15903091], [77.65125275, 8.15902901], [77.65125275, 8.15958309], [77.65097046, 8.15958023], [77.65097046, 8.16014099], [77.65013885, 8.16014099], [77.65013885, 8.15986061], [77.64958191, 8.15986061], [77.64958191, 8.15958309], [77.64902496, 8.15958309], [77.64902496, 8.15902901], [77.64875031, 8.15903091], [77.64875031, 8.15875053], [77.64848328, 8.15875053], [77.64848328, 8.15847111], [77.6470871, 8.15847301], [77.6470871, 8.15819454], [77.64653015, 8.15819454], [77.64653015, 8.15791702], [77.64485931, 8.15792084], [77.64485931, 8.15764141], [77.64290619, 8.15764141], [77.64290619, 8.15736103], [77.64068604, 8.15736103], [77.64068604, 8.15764141], [77.64013672, 8.15764141], [77.64013672, 8.15736103], [77.63986206, 8.15736103], [77.63986206, 8.15708256], [77.63930511, 8.15708256], [77.63930511, 8.15680695], [77.63903046, 8.15680885], [77.63903046, 8.15653133], [77.63819122, 8.15653133], [77.63819122, 8.15625095], [77.63707733, 8.15625095], [77.63707733, 8.15596962], [77.63625336, 8.15597343], [77.63625336, 8.15569496], [77.63541412, 8.15569496], [77.63541412, 8.15541553], [77.63485718, 8.15542126], [77.63485718, 8.15515041], [77.63430023, 8.15515041], [77.63430023, 8.15542126], [77.63318634, 8.15542126], [77.63318634, 8.15515041], [77.63153076, 8.15515041], [77.63153076, 8.15485954], [77.63097382, 8.15485954], [77.63097382, 8.15458202], [77.63069153, 8.15458202], [77.63069153, 8.15430737], [77.62958527, 8.15430737], [77.62958527, 8.15458202], [77.62902832, 8.15458202], [77.62902832, 8.15430737], [77.62847137, 8.15431118], [77.62847137, 8.1540308], [77.62819672, 8.1540308], [77.62819672, 8.15375042], [77.62763977, 8.15375042], [77.62763977, 8.15347195], [77.62596893, 8.15347195], [77.62596893, 8.15319443], [77.62458038, 8.15319443], [77.62458038, 8.15291595], [77.62374878, 8.15292072], [77.62374878, 8.15264034], [77.62264252, 8.15264034], [77.62264252, 8.15235996], [77.62152863, 8.15235996], [77.62152863, 8.15208435], [77.62069702, 8.15209103], [77.62069702, 8.15181065], [77.61985779, 8.15181065], [77.61985779, 8.15153122], [77.61791992, 8.15153122], [77.61791992, 8.15124989], [77.61736298, 8.15124989], [77.61736298, 8.15097046], [77.61624908, 8.15097237], [77.61624908, 8.15069389], [77.61513519, 8.15069389], [77.61513519, 8.15041637], [77.61458588, 8.15042114], [77.61458588, 8.15014267], [77.61429596, 8.15014267], [77.61429596, 8.15042114], [77.61402893, 8.15042114], [77.61402893, 8.15014267], [77.61292267, 8.15014267], [77.61292267, 8.14986038], [77.61235809, 8.14986229], [77.61235809, 8.14958382], [77.61152649, 8.14958191], [77.61152649, 8.1493063], [77.61096954, 8.1493063], [77.61096954, 8.14958191], [77.61069489, 8.14958191], [77.61069489, 8.1493063], [77.61042023, 8.14931107], [77.61042023, 8.14902115], [77.60958099, 8.14902782], [77.60958099, 8.14875031], [77.60901642, 8.14875031], [77.60901642, 8.14847183], [77.60791779, 8.14847183], [77.60791779, 8.14819431], [77.60736084, 8.14819431], [77.60736084, 8.14791584], [77.60708618, 8.14791965], [77.60708618, 8.14764023], [77.60597229, 8.14764023], [77.60597229, 8.14735985], [77.6048584, 8.14735985], [77.6048584, 8.14708424], [77.60430908, 8.14708424], [77.60430908, 8.14680576], [77.60402679, 8.14680958], [77.60402679, 8.14653015], [77.60346985, 8.14653015], [77.60346985, 8.14624977], [77.6029129, 8.14624977], [77.6029129, 8.14595985], [77.60236359, 8.14597225], [77.60236359, 8.14569378], [77.60124969, 8.14569378], [77.60124969, 8.14541626], [77.60069275, 8.14542007], [77.60069275, 8.14513969], [77.59929657, 8.14513969], [77.59929657, 8.14486027], [77.59874725, 8.14486217], [77.59874725, 8.1445837], [77.59819794, 8.1445837], [77.59819794, 8.14430618], [77.5973587, 8.14431], [77.5973587, 8.14402962], [77.59625244, 8.14402962], [77.59625244, 8.14375019], [77.5956955, 8.14375019], [77.5956955, 8.14347172], [77.59541321, 8.14347172], [77.59541321, 8.14319324], [77.59430695, 8.14319324], [77.59430695, 8.14291763], [77.59263611, 8.14291954], [77.59263611, 8.14264202], [77.59179688, 8.14264202], [77.59179688, 8.14291954], [77.59152985, 8.14291954], [77.59152985, 8.14264202], [77.59124756, 8.14264202], [77.59124756, 8.14236164], [77.5901413, 8.14236164], [77.5901413, 8.14208412], [77.5890274, 8.14208412], [77.5890274, 8.1418047], [77.58875275, 8.14181042], [77.58875275, 8.14153194], [77.58847046, 8.14153194], [77.58847046, 8.14125156], [77.5881958, 8.14125156], [77.5881958, 8.14097118], [77.58763885, 8.14097118], [77.58763885, 8.14069557], [77.58680725, 8.14069557], [77.58680725, 8.1404171], [77.58625031, 8.14042187], [77.58625031, 8.14015102], [77.58598328, 8.14015102], [77.58598328, 8.1398592], [77.58569336, 8.13986111], [77.58569336, 8.13958263], [77.5854187, 8.13958263], [77.5854187, 8.13930511], [77.58486176, 8.13931179], [77.58486176, 8.13902855], [77.5845871, 8.13902855], [77.5845871, 8.13875103], [77.58347321, 8.13875103], [77.58347321, 8.13847065], [77.5826416, 8.13847256], [77.5826416, 8.13819313], [77.58180237, 8.13819313], [77.58180237, 8.13791656], [77.58125305, 8.13792038], [77.58125305, 8.13764191], [77.58040619, 8.13764191], [77.58040619, 8.13736057], [77.57958221, 8.13736057], [77.57958221, 8.13708305], [77.57902527, 8.13708305], [77.57902527, 8.13680458], [77.57847595, 8.1368103], [77.57847595, 8.13653183], [77.57763672, 8.13653183], [77.57763672, 8.13625145], [77.5770874, 8.13625145], [77.5770874, 8.13597107], [77.57653046, 8.13597107], [77.57653046, 8.13569546], [77.57569122, 8.13569546], [77.57569122, 8.13513947], [77.57541656, 8.13514137], [77.57541656, 8.13458061], [77.57514191, 8.13458347], [77.57514191, 8.13434124], [77.57514191, 8.1334734], [77.57485962, 8.1334734], [77.57485962, 8.13319492], [77.57458496, 8.13319492], [77.57458496, 8.1329174], [77.57430267, 8.13291931], [77.57430267, 8.13264084], [77.57347107, 8.13264084], [77.57347107, 8.13236141], [77.57319641, 8.13236141], [77.57319641, 8.13208294], [77.57263947, 8.13208294], [77.57263947, 8.13180542], [77.57208252, 8.13180923], [77.57208252, 8.13152885], [77.57125092, 8.13152885], [77.57125092, 8.13097954], [77.570961, 8.13097954], [77.570961, 8.13014126], [77.57068634, 8.13014126], [77.57068634, 8.12957954], [77.57041931, 8.12958241], [77.57041931, 8.12902641], [77.57013702, 8.12903118], [77.57013702, 8.12847042], [77.56986237, 8.12847328], [77.56986237, 8.12819386], [77.56958008, 8.12819386], [77.56958008, 8.12791634], [77.56874847, 8.1279211], [77.56874847, 8.12764072], [77.56846619, 8.12764072], [77.56846619, 8.12736034], [77.56791687, 8.12736034], [77.56791687, 8.12708473], [77.56735992, 8.12708473], [77.56735992, 8.12680435], [77.5670929, 8.12681103], [77.5670929, 8.12653065], [77.56680298, 8.12653065], [77.56680298, 8.12625027], [77.56652832, 8.12625027], [77.56652832, 8.12513828], [77.56624603, 8.12514019], [77.56624603, 8.12458038], [77.56569672, 8.1245842], [77.56569672, 8.12430573], [77.56485748, 8.12431145], [77.56485748, 8.12403107], [77.56458282, 8.12403107], [77.56458282, 8.12374973], [77.56430817, 8.12374973], [77.56430817, 8.12347031], [77.56402588, 8.12347221], [77.56402588, 8.12319374], [77.56375122, 8.12319374], [77.56375122, 8.12291622], [77.56346893, 8.12292099], [77.56346893, 8.12263966], [77.56318665, 8.12263966], [77.56318665, 8.12236023], [77.56291962, 8.12236214], [77.56291962, 8.12208366], [77.56236267, 8.12208366], [77.56236267, 8.12180614], [77.56181335, 8.12181091], [77.56181335, 8.12152958], [77.56153107, 8.12152958], [77.56153107, 8.12125015], [77.56124878, 8.12125015], [77.56124878, 8.12097168], [77.56097412, 8.12097168], [77.56097412, 8.12069416], [77.56069183, 8.12069416], [77.56069183, 8.12014008], [77.56014252, 8.12014008], [77.56014252, 8.1198597], [77.55958557, 8.1198597], [77.55958557, 8.11958408], [77.55930328, 8.11958408], [77.55930328, 8.1184721], [77.55958557, 8.1184721], [77.55958557, 8.11819363], [77.55986023, 8.11819363], [77.55986023, 8.11736202], [77.56014252, 8.11736202], [77.56014252, 8.11708355], [77.55986023, 8.11708355], [77.55986023, 8.11652756], [77.5595932, 8.11653042], [77.5595932, 8.11569118], [77.55930328, 8.11569309], [77.55930328, 8.11513996], [77.559021, 8.11514187], [77.559021, 8.11458111], [77.55874634, 8.11458302], [77.55874634, 8.11402702], [77.55847168, 8.11403179], [77.55847168, 8.11319065], [77.55819702, 8.11319542], [77.55819702, 8.11208344], [77.55791473, 8.11208344], [77.55791473, 8.11124897], [77.55764008, 8.11125088], [77.55764008, 8.11069107], [77.55791473, 8.11069489], [77.55791473, 8.10986137], [77.55819702, 8.10986137], [77.55819702, 8.10930538], [77.55847168, 8.10931015], [77.55847168, 8.1087513], [77.55874634, 8.1087513], [77.55874634, 8.10847092], [77.55902863, 8.10847092], [77.55902863, 8.10791683], [77.55930328, 8.1079216], [77.55930328, 8.10404015], [77.559021, 8.10404015], [77.559021, 8.10292053], [77.55874634, 8.10292053], [77.55874634, 8.10235977], [77.55847168, 8.10235977], [77.55847168, 8.10152912], [77.55874634, 8.10153103], [77.55874634, 8.10125065], [77.55847168, 8.10125065], [77.55847168, 8.09958172], [77.55874634, 8.09958363], [77.55874634, 8.0993042], [77.559021, 8.09931087], [77.559021, 8.09903145], [77.55930328, 8.09903145], [77.55930328, 8.09846973], [77.55958557, 8.09847164], [77.55958557, 8.09791565], [77.55930328, 8.09791565], [77.55930328, 8.09763813], [77.559021, 8.09764004], [77.559021, 8.09735966], [77.55874634, 8.09736156], [77.55874634, 8.09652805], [77.559021, 8.09652996], [77.559021, 8.09624958], [77.55930328, 8.09624958], [77.55930328, 8.09597015], [77.55986023, 8.09597206], [77.55986023, 8.09569359], [77.56041718, 8.09569359], [77.56041718, 8.09597206], [77.56069183, 8.09597015], [77.56069183, 8.09624958], [77.56124878, 8.09624958], [77.56124878, 8.09652996], [77.56153107, 8.09652996], [77.56153107, 8.09681129], [77.56208038, 8.09680557], [77.56208038, 8.09708214], [77.56236267, 8.09708214], [77.56236267, 8.09680557], [77.56319427, 8.09680557], [77.56319427, 8.09735966], [77.56402588, 8.09735966], [77.56402588, 8.09764004], [77.56430817, 8.09763813], [77.56430817, 8.09791565], [77.56458282, 8.09791565], [77.56458282, 8.09819412], [77.56430817, 8.09819412], [77.56430817, 8.09847164], [77.56458282, 8.09846973], [77.56458282, 8.09875011], [77.56430817, 8.09875011], [77.56430817, 8.09958363], [77.56458282, 8.09958363], [77.56458282, 8.09986019], [77.56485748, 8.09986019], [77.56485748, 8.0993042], [77.5651474, 8.09931087], [77.5651474, 8.09542274], [77.56485748, 8.09542274], [77.56485748, 8.09375], [77.5651474, 8.09375], [77.5651474, 8.09318924], [77.56541443, 8.09319401], [77.56541443, 8.09291553], [77.56569672, 8.0929203], [77.56569672, 8.09263992], [77.56597137, 8.09263992], [77.56597137, 8.09208202], [77.56513977, 8.09208393], [77.56513977, 8.09180641], [77.56458282, 8.09181023], [77.56458282, 8.09152985], [77.56346893, 8.09152985], [77.56346893, 8.09125042], [77.56318665, 8.09125042], [77.56318665, 8.09097195], [77.56291962, 8.09097195], [77.56291962, 8.09125042], [77.56236267, 8.09125042], [77.56236267, 8.09152985], [77.56181335, 8.09152985], [77.56181335, 8.09125042], [77.56153107, 8.09125042], [77.56153107, 8.09097195], [77.56124878, 8.09097195], [77.56124878, 8.09069443], [77.56097412, 8.09069443], [77.56097412, 8.09041786], [77.55986023, 8.09041977], [77.55986023, 8.09014034], [77.55930328, 8.09014034], [77.55930328, 8.08986187], [77.559021, 8.08986187], [77.559021, 8.08958054], [77.55847168, 8.08958435], [77.55847168, 8.08930588], [77.55764008, 8.08930969], [77.55764008, 8.08875179], [77.55735779, 8.08875179], [77.55735779, 8.08847141], [77.55708313, 8.08847141], [77.55708313, 8.0881958], [77.55652618, 8.0881958], [77.55652618, 8.08791542], [77.55625153, 8.08792019], [77.55625153, 8.08736134], [77.55596924, 8.08736134], [77.55596924, 8.08708286], [77.55541992, 8.08708286], [77.55541992, 8.08680534], [77.55513763, 8.08681011], [77.55513763, 8.08624935], [77.55486298, 8.08624935], [77.55486298, 8.08569527], [77.55430603, 8.08569527], [77.55430603, 8.08541679], [77.55403137, 8.08541965], [77.55403137, 8.08513927], [77.55374908, 8.08513927], [77.55374908, 8.08485889], [77.55347443, 8.0848608], [77.55347443, 8.08458328], [77.55291748, 8.08458328], [77.55291748, 8.08430481], [77.55264282, 8.08430958], [77.55264282, 8.08125114], [77.55291748, 8.08125114], [77.55291748, 8.08041668], [77.55264282, 8.0804224], [77.55264282, 8.07987022], [77.55236053, 8.07987022], [77.55236053, 8.07958126], [77.55208588, 8.07958317], [77.55208588, 8.0793047], [77.55236053, 8.07930946], [77.55236053, 8.07792091], [77.55208588, 8.07792091], [77.55208588, 8.07736111], [77.55180359, 8.07736111], [77.55180359, 8.07708263], [77.55152893, 8.07708263], [77.55152893, 8.07680511], [77.55097198, 8.07680511], [77.55097198, 8.07652569], [77.55069733, 8.07652569], [77.55069733, 8.07680511], [77.55041504, 8.07680511], [77.55041504, 8.07736111], [77.55014801, 8.07736111], [77.55014801, 8.07792091], [77.54902649, 8.07792091], [77.54902649, 8.07764053], [77.54846954, 8.07764053], [77.54846954, 8.07792091], [77.54680634, 8.07792091], [77.54680634, 8.07764053], [77.54624939, 8.07764053], [77.54624939, 8.07736111], [77.54569244, 8.07736111], [77.54569244, 8.07764053], [77.54514313, 8.07764053], [77.54514313, 8.07792091], [77.54319763, 8.0779171], [77.54319763, 8.07819462], [77.54165649, 8.07819462], [77.53902435, 8.07819462], [77.53902435, 8.07847309], [77.53874969, 8.07847309], [77.53874969, 8.07819462], [77.53847504, 8.07819462], [77.53847504, 8.07847309], [77.5376358, 8.07847309], [77.5376358, 8.07819462], [77.53624725, 8.07819462], [77.53624725, 8.0779171], [77.53542328, 8.07792091], [77.53542328, 8.07764053], [77.53485107, 8.07764053], [77.53485107, 8.07736111], [77.53291321, 8.07736111], [77.53291321, 8.07708263], [77.53125, 8.07708263], [77.53125, 8.07736111], [77.53098297, 8.07736111], [77.53098297, 8.07930946], [77.53069305, 8.07930946], [77.53069305, 8.07987022], [77.53013611, 8.07987022], [77.53013611, 8.08014107], [77.52986145, 8.08014107], [77.52986145, 8.0804224], [77.5293045, 8.08041668], [77.5293045, 8.08069515], [77.5284729, 8.08069515], [77.5284729, 8.08097267], [77.5276413, 8.08097267], [77.5276413, 8.08125114], [77.52735901, 8.08125114], [77.52735901, 8.08097267], [77.52680206, 8.08097267], [77.52680206, 8.08125114], [77.52597809, 8.08125114], [77.52597809, 8.08153057], [77.52291107, 8.08153057], [77.52291107, 8.0818119], [77.52236176, 8.0818119], [77.52236176, 8.08153057], [77.52179718, 8.08153057], [77.52179718, 8.0818119], [77.51985168, 8.0818119], [77.51985168, 8.08153057], [77.51930237, 8.08153057], [77.51930237, 8.0818119], [77.51875305, 8.08180523], [77.51875305, 8.08236122], [77.5173645, 8.08236122], [77.5173645, 8.08208275], [77.51680756, 8.08208275], [77.51680756, 8.08180523], [77.5165329, 8.0818119], [77.5165329, 8.08264065], [77.51457977, 8.08264065], [77.51457977, 8.08293056], [77.51097107, 8.08291721], [77.51097107, 8.08319473], [77.51041412, 8.08319473], [77.51041412, 8.08347321], [77.50958252, 8.0834713], [77.50958252, 8.08375072], [77.50818634, 8.08375072], [77.50818634, 8.0834713], [77.50681305, 8.0834713], [77.50681305, 8.08375072], [77.50653076, 8.08375072], [77.50653076, 8.0840292], [77.50569153, 8.0840292], [77.50569153, 8.08430958], [77.50541687, 8.08430481], [77.50541687, 8.08458328], [77.50514221, 8.08458328], [77.50514221, 8.0848608], [77.50486755, 8.08485889], [77.50486755, 8.08513927], [77.50319672, 8.08513927], [77.50319672, 8.08541965], [77.50152588, 8.08541679], [77.50152588, 8.08569527], [77.50069427, 8.08569527], [77.50069427, 8.08597088], [77.50013733, 8.08597088], [77.50013733, 8.08624935], [77.49903107, 8.08624935], [77.49903107, 8.08652973], [77.49874878, 8.08652973], [77.49874878, 8.08681011], [77.49819183, 8.08680534], [77.49819183, 8.08708286], [77.49319458, 8.08708286], [77.49319458, 8.08680534], [77.49263763, 8.08680534], [77.49263763, 8.08708286], [77.49180603, 8.08708286], [77.49180603, 8.08736134], [77.48929596, 8.08736134], [77.48930359, 8.08763981], [77.48819733, 8.08763981], [77.48819733, 8.08792019], [77.48735809, 8.08791542], [77.48735809, 8.0881958], [77.48596954, 8.0881958], [77.48596954, 8.08847141], [77.48542023, 8.08847141], [77.48542023, 8.08875179], [77.48458099, 8.08875179], [77.48458099, 8.08847141], [77.48430634, 8.08847141], [77.48430634, 8.0881958], [77.48347473, 8.0881958], [77.48347473, 8.08847141], [77.48264313, 8.08847141], [77.48264313, 8.08875179], [77.48179626, 8.08875179], [77.48179626, 8.08847141], [77.48152924, 8.08847141], [77.48152924, 8.08875179], [77.48097229, 8.08875179], [77.48097229, 8.08847141], [77.48041534, 8.08847141], [77.48041534, 8.08958435], [77.47957611, 8.08958054], [77.47958374, 8.08986187], [77.4770813, 8.08986187], [77.4770813, 8.08958435], [77.47569275, 8.08958435], [77.47569275, 8.08986187], [77.47486115, 8.08986187], [77.47486115, 8.09014034], [77.47292328, 8.09014034], [77.47292328, 8.09041977], [77.47097015, 8.09041786], [77.47097015, 8.09069443], [77.46930695, 8.09069443], [77.46930695, 8.09097195], [77.46874237, 8.09097195], [77.46875, 8.09125042], [77.46736145, 8.09125042], [77.46736145, 8.09152985], [77.46624756, 8.09152985], [77.46624756, 8.09181023], [77.46541595, 8.09180641], [77.46541595, 8.09208393], [77.46458435, 8.09208393], [77.46458435, 8.0923624], [77.46208191, 8.09235954], [77.46208191, 8.09263992], [77.46125031, 8.09263992], [77.46125031, 8.0929203], [77.45874786, 8.09291553], [77.45874786, 8.09319401], [77.4576416, 8.09319401], [77.4576416, 8.09291553], [77.45735931, 8.09291553], [77.45735931, 8.09319401], [77.45680237, 8.09319401], [77.45680237, 8.09347153], [77.45597076, 8.09347153], [77.45597076, 8.09319401], [77.45513916, 8.09319401], [77.45513916, 8.09347153], [77.45291901, 8.09346962], [77.45291901, 8.09375], [77.45124817, 8.09375], [77.45124817, 8.09403038], [77.44847107, 8.09403038], [77.44847107, 8.09431076], [77.44680786, 8.09430599], [77.44680786, 8.09458447], [77.44541931, 8.0945797], [77.44541931, 8.09487057], [77.44457245, 8.09487057], [77.44457245, 8.09514046], [77.44291687, 8.09514046], [77.44291687, 8.09542274], [77.44180298, 8.09541607], [77.44180298, 8.09569359], [77.44152832, 8.09569359], [77.44152832, 8.09597206], [77.44097137, 8.09597015], [77.44097137, 8.09624958], [77.43985748, 8.09624958], [77.43985748, 8.09652996], [77.43902588, 8.09652996], [77.43902588, 8.09681129], [77.43791962, 8.09680557], [77.43791962, 8.09708214], [77.43763733, 8.09708214], [77.43763733, 8.09736156], [77.43680573, 8.09736156], [77.43680573, 8.09708214], [77.43569183, 8.09708214], [77.43569183, 8.09736156], [77.43430328, 8.09736156], [77.43430328, 8.09708214], [77.43374634, 8.09708214], [77.43374634, 8.09736156], [77.4329071, 8.09735966], [77.4329071, 8.09764004], [77.43264008, 8.09763813], [77.43264008, 8.09791565], [77.43235779, 8.09791565], [77.43235779, 8.09819412], [77.43208313, 8.09819412], [77.43208313, 8.09847164], [77.43125153, 8.09846973], [77.43125153, 8.09875011], [77.43096924, 8.09875011], [77.43096924, 8.09903145], [77.43013763, 8.09903145], [77.43013763, 8.09931087], [77.42819214, 8.0993042], [77.42819214, 8.09958363], [77.42736053, 8.09958363], [77.42736053, 8.09986019], [77.42708588, 8.09986019], [77.42708588, 8.10014057], [77.42652893, 8.10014057], [77.42652893, 8.09986019], [77.42375183, 8.09986019], [77.42375183, 8.10014057], [77.42263794, 8.10014057], [77.42263794, 8.10042095], [77.42208099, 8.10041618], [77.42208099, 8.1006937], [77.42124939, 8.1006937], [77.42124939, 8.10097218], [77.42069244, 8.10097027], [77.42069244, 8.10125065], [77.41929626, 8.10125065], [77.41929626, 8.10153103], [77.41847229, 8.10153103], [77.41847229, 8.10181141], [77.41708374, 8.10180664], [77.41708374, 8.10208225], [77.41596985, 8.10208225], [77.41596985, 8.10235977], [77.4154129, 8.10235977], [77.4154129, 8.10264111], [77.41513824, 8.10264111], [77.41513824, 8.10292053], [77.4145813, 8.10291672], [77.4145813, 8.10319519], [77.41402435, 8.10319519], [77.41402435, 8.10291672], [77.41374969, 8.10291672], [77.41374969, 8.10319519], [77.41319275, 8.10319519], [77.41319275, 8.10347271], [77.41291809, 8.10347271], [77.41291809, 8.10375118], [77.41042328, 8.10375118], [77.41042328, 8.10404015], [77.4098587, 8.10404015], [77.4098587, 8.10431099], [77.4090271, 8.10430527], [77.4090271, 8.10458279], [77.4081955, 8.10458279], [77.4081955, 8.10486126], [77.40651703, 8.10486126], [77.40651703, 8.10514069], [77.4054184, 8.10514069], [77.4054184, 8.10542107], [77.40458679, 8.10541725], [77.40458679, 8.10569477], [77.40402985, 8.10569477], [77.40402985, 8.10597324], [77.40208435, 8.10597324], [77.40208435, 8.10624886], [77.4015274, 8.10624886], [77.4015274, 8.10653114], [77.40097046, 8.10653114], [77.40097046, 8.10681152], [77.40041351, 8.10680485], [77.40041351, 8.10708332], [77.39985657, 8.10708141], [77.3998642, 8.10736084], [77.39930725, 8.10736084], [77.39930725, 8.10764122], [77.39819336, 8.10764122], [77.39819336, 8.1079216], [77.39680481, 8.10791683], [77.39680481, 8.1081953], [77.39597321, 8.1081953], [77.39597321, 8.10847092], [77.3951416, 8.10847092], [77.3951416, 8.1087513], [77.39430237, 8.1087513], [77.39430237, 8.10903168], [77.39375305, 8.10903168], [77.39375305, 8.10931015], [77.39319611, 8.10930538], [77.39319611, 8.1095829], [77.3923645, 8.1095829], [77.3923645, 8.10986137], [77.39180756, 8.10985184], [77.39180756, 8.11013889], [77.39097595, 8.11013889], [77.39097595, 8.11042023], [77.39013672, 8.11041737], [77.39013672, 8.11069489], [77.38957977, 8.11069489], [77.38957977, 8.11097336], [77.38903046, 8.11097145], [77.38903046, 8.11125088], [77.38819122, 8.11125088], [77.38819122, 8.11152935], [77.38735962, 8.11152935], [77.38735962, 8.11180973], [77.38652802, 8.11180496], [77.38652802, 8.11208344], [77.38569641, 8.11208344], [77.38569641, 8.11236095], [77.38430786, 8.11236095], [77.38430786, 8.11263943], [77.38319397, 8.11263943], [77.38319397, 8.11291695], [77.38236237, 8.11291695], [77.38236237, 8.11319542], [77.38097382, 8.11319542], [77.38097382, 8.11347103], [77.37958527, 8.11347103], [77.37958527, 8.11374855], [77.378479, 8.11374855], [77.378479, 8.11403179], [77.3779068, 8.11403179], [77.3779068, 8.11431026], [77.37735748, 8.11431026], [77.37735748, 8.11403179], [77.37680817, 8.11403179], [77.37680817, 8.11431026], [77.37513733, 8.11430454], [77.37513733, 8.11458302], [77.37430573, 8.11458302], [77.37430573, 8.11486244], [77.37346649, 8.11486244], [77.37346649, 8.11514187], [77.37291718, 8.11514187], [77.37291718, 8.11542034], [77.37264252, 8.11541843], [77.37264252, 8.11569309], [77.3720932, 8.11569118], [77.3720932, 8.1159811], [77.37097168, 8.1159811], [77.37097168, 8.11625195], [77.37069702, 8.11625004], [77.37069702, 8.11736202], [77.3704071, 8.11736202], [77.3704071, 8.11708069], [77.36875153, 8.11708355], [77.36875153, 8.11736202], [77.36818695, 8.11736202], [77.36818695, 8.11763954], [77.36763763, 8.11763954], [77.36763763, 8.11791992], [77.36624908, 8.11791801], [77.36624908, 8.11819363], [77.36597443, 8.11819363], [77.36597443, 8.1184721], [77.36569214, 8.11846924], [77.36569214, 8.11874962], [77.36486053, 8.11874962], [77.36486053, 8.11904144], [77.36458588, 8.11904144], [77.36458588, 8.11931038], [77.36402893, 8.11930561], [77.36402893, 8.11958408], [77.36374664, 8.11958408], [77.36374664, 8.1198597], [77.36347198, 8.1198597], [77.36347198, 8.11958408], [77.36180878, 8.11958408], [77.36180878, 8.1198597], [77.36125183, 8.1198597], [77.36125183, 8.12014008], [77.35958099, 8.12014008], [77.35958099, 8.12042046], [77.35902405, 8.12041569], [77.35902405, 8.12069416], [77.35736084, 8.12069416], [77.35736084, 8.12097168], [77.35708618, 8.12097168], [77.35708618, 8.12125015], [77.35679626, 8.12125015], [77.35679626, 8.12152958], [77.35542297, 8.12152958], [77.35542297, 8.12125015], [77.35514069, 8.12125015], [77.35514069, 8.12152958], [77.35457611, 8.12152958], [77.35457611, 8.12181091], [77.35402679, 8.12180614], [77.35402679, 8.12208366], [77.3529129, 8.12208366], [77.3529129, 8.12236214], [77.3520813, 8.12236023], [77.3520813, 8.12263966], [77.35180664, 8.12263966], [77.35180664, 8.12236023], [77.35098267, 8.12236023], [77.35098267, 8.12263966], [77.35041809, 8.12263966], [77.35041809, 8.12292099], [77.34902954, 8.12291622], [77.34902954, 8.12319374], [77.34819794, 8.12319374], [77.34819794, 8.12291622], [77.34764099, 8.12292099], [77.34764099, 8.12263966], [77.3473587, 8.12263966], [77.3473587, 8.12292099], [77.34680939, 8.12291622], [77.34680176, 8.12319374], [77.34625244, 8.12319374], [77.34625244, 8.12347221], [77.34485626, 8.12347031], [77.34485626, 8.12374973], [77.34401703, 8.12374973], [77.34401703, 8.12403107], [77.34348297, 8.12403107], [77.34348297, 8.12431145], [77.34208679, 8.12431145], [77.34208679, 8.12403107], [77.3409729, 8.12403107], [77.3409729, 8.12431145], [77.34041595, 8.12430573], [77.34041595, 8.1245842], [77.33985901, 8.1245842], [77.33985901, 8.12485981], [77.33930969, 8.12485123], [77.33930969, 8.12514019], [77.33735657, 8.12514019], [77.33735657, 8.12542057], [77.33597565, 8.1254158], [77.33597565, 8.12569427], [77.33513641, 8.12569427], [77.33513641, 8.12597179], [77.33318329, 8.12596989], [77.33319092, 8.12625027], [77.3326416, 8.12625027], [77.3326416, 8.12597179], [77.33207703, 8.12596989], [77.33208466, 8.12625027], [77.33097076, 8.12625027], [77.33097076, 8.12653065], [77.33013916, 8.12653065], [77.33013916, 8.12625027], [77.32818604, 8.12625027], [77.32818604, 8.12596989], [77.32791901, 8.12597179], [77.32791901, 8.12569427], [77.32763672, 8.12569427], [77.32763672, 8.12597179], [77.32680511, 8.12597179], [77.32681274, 8.12625027], [77.32596588, 8.12625027], [77.32596588, 8.12653065], [77.32485962, 8.12653065], [77.32485962, 8.12625027], [77.32402802, 8.12625027], [77.32402802, 8.12597179], [77.32347107, 8.12597179], [77.32347107, 8.12513828], [77.32375336, 8.12514019], [77.32375336, 8.12431145], [77.32347107, 8.12431145], [77.32347107, 8.12403107], [77.32319641, 8.12403107], [77.32319641, 8.12347031], [77.32291412, 8.12347221], [77.32291412, 8.12236214], [77.32263947, 8.12236214], [77.32263947, 8.12208366], [77.32180786, 8.12208366], [77.32180786, 8.12236214], [77.3215332, 8.12236023], [77.3215332, 8.12263966], [77.32124329, 8.12263966], [77.32124329, 8.12292099], [77.32096863, 8.12291622], [77.32096863, 8.12319374], [77.32069397, 8.12319374], [77.32069397, 8.12291622], [77.32041931, 8.12292099], [77.32041931, 8.12263966], [77.31986237, 8.12263966], [77.31986237, 8.12292099], [77.31958008, 8.12291622], [77.31958008, 8.12319374], [77.31874847, 8.12319374], [77.31874847, 8.12097168], [77.31847382, 8.12097168], [77.31847382, 8.12069416], [77.31764221, 8.12069416], [77.31764221, 8.12097168], [77.31708527, 8.12097168], [77.31708527, 8.12125015], [77.31680298, 8.12125015], [77.31680298, 8.12097168], [77.31597137, 8.12097168], [77.31597137, 8.12125015], [77.31569672, 8.12125015], [77.31569672, 8.12152958], [77.3154068, 8.12152958], [77.3154068, 8.12181091], [77.31513977, 8.12180614], [77.31513977, 8.12208366], [77.31485748, 8.12208366], [77.31485748, 8.12236214], [77.31458282, 8.12236023], [77.31458282, 8.12292099], [77.31430817, 8.12291622], [77.31430817, 8.12319374], [77.31402588, 8.12319374], [77.31402588, 8.12347221], [77.31291962, 8.12347031], [77.31291962, 8.12374973], [77.31236267, 8.12374973], [77.31236267, 8.12403107], [77.31207275, 8.12403107], [77.31207275, 8.12431145], [77.31153107, 8.12430573], [77.31153107, 8.12569427], [77.31124878, 8.12569427], [77.31121826, 8.12597179], [77.31096649, 8.12596989], [77.31097412, 8.12625027], [77.31041718, 8.12625027], [77.31041718, 8.12653065], [77.31014252, 8.12653065], [77.31014252, 8.12681103], [77.30847168, 8.12680435], [77.30847168, 8.12708473], [77.30791473, 8.12708473], [77.30791473, 8.12736034], [77.30764008, 8.12736034], [77.30764008, 8.12764072], [77.30735779, 8.12764072], [77.30735779, 8.1279211], [77.30708313, 8.12791634], [77.30708313, 8.12819386], [77.30680847, 8.12819386], [77.30680847, 8.12791634], [77.30652618, 8.1279211], [77.30652618, 8.12764072], [77.30625916, 8.12764072], [77.30625916, 8.1279211], [77.30569458, 8.12791634], [77.30569458, 8.12847328], [77.30596924, 8.12847042], [77.30596924, 8.12903118], [77.30568695, 8.12903118], [77.30568695, 8.12931061], [77.30596924, 8.12931061], [77.30596924, 8.13042068], [77.30568695, 8.13042068], [77.30568695, 8.13097954], [77.30513763, 8.13097286], [77.30513763, 8.13125134], [77.30430603, 8.13125134], [77.30430603, 8.13152885], [77.3034668, 8.13152885], [77.3034668, 8.13180923], [77.30374908, 8.13180542], [77.30374908, 8.13208294], [77.30347443, 8.13208294], [77.30347443, 8.13236141], [77.30374908, 8.13236141], [77.30374908, 8.13319492], [77.30403137, 8.13319016], [77.30403137, 8.13375092], [77.30430603, 8.13375092], [77.30430603, 8.13402653], [77.30403137, 8.13401985], [77.30403137, 8.13514137], [77.30374908, 8.13514137], [77.30374908, 8.13541889], [77.30403137, 8.13541889], [77.30403137, 8.13764191], [77.30374908, 8.13763905], [77.30374908, 8.13847256], [77.3034668, 8.13847065], [77.3034668, 8.13875103], [77.30264282, 8.13875103], [77.30264282, 8.13902855], [77.30236053, 8.13902855], [77.30236053, 8.13875103], [77.30208588, 8.13875103], [77.30208588, 8.13931179], [77.30180359, 8.13930511], [77.30180359, 8.13958263], [77.30152893, 8.13958073], [77.30152893, 8.14015102], [77.30180359, 8.14013863], [77.30180359, 8.14069557], [77.30208588, 8.14069557], [77.30208588, 8.14097118], [77.30236053, 8.14097118], [77.30236053, 8.14153194], [77.30208588, 8.14152718], [77.30208588, 8.14319324], [77.30179596, 8.14319134], [77.30180359, 8.14375019], [77.30152893, 8.14375019], [77.30152893, 8.14402962], [77.30124664, 8.14402771], [77.30124664, 8.1445837], [77.30097198, 8.14458084], [77.30097198, 8.14513969], [77.30042267, 8.14513969], [77.30042267, 8.14542007], [77.30014038, 8.14541626], [77.30014038, 8.14569378], [77.29985809, 8.14569378], [77.29985809, 8.14597225], [77.29930878, 8.14595985], [77.29930878, 8.14624977], [77.29902649, 8.14624977], [77.29902649, 8.14680958], [77.29875183, 8.14680576], [77.29875183, 8.14708424], [77.29846954, 8.14708424], [77.29846954, 8.14735985], [77.29818726, 8.14735985], [77.29818726, 8.14764023], [77.29792023, 8.14764023], [77.29792023, 8.14791965], [77.29763794, 8.14791584], [77.29763794, 8.14819431], [77.29736328, 8.14819431], [77.29736328, 8.14847183], [77.29707336, 8.14847183], [77.29708099, 8.14875031], [77.29680634, 8.14875031], [77.29680634, 8.14931107], [77.29652405, 8.1493063], [77.29652405, 8.14958191], [77.29486084, 8.14958382], [77.29486084, 8.14986229], [77.29458618, 8.14986038], [77.29458618, 8.15014267], [77.29429626, 8.15014267], [77.29429626, 8.15042114], [77.29402924, 8.15041637], [77.29402924, 8.15069389], [77.29347229, 8.15069389], [77.29347229, 8.15097237], [77.29319763, 8.15097046], [77.29319763, 8.15124989], [77.29292297, 8.15124989], [77.29292297, 8.15153122], [77.29264069, 8.15153122], [77.29264069, 8.15181065], [77.2923584, 8.15181065], [77.2923584, 8.15209103], [77.29207611, 8.15209103], [77.29208374, 8.15235996], [77.29096985, 8.15235996], [77.29096985, 8.15264034], [77.29070282, 8.15264034], [77.29070282, 8.15292072], [77.29013824, 8.15291595], [77.29013824, 8.15319443], [77.28985596, 8.15318966], [77.28986359, 8.15375042], [77.28930664, 8.15375042], [77.28930664, 8.1540308], [77.28901672, 8.1540308], [77.28901672, 8.15431118], [77.28874969, 8.15430737], [77.28874969, 8.15458202], [77.28791809, 8.15458202], [77.28791809, 8.15485954], [77.28736115, 8.15485954], [77.28736115, 8.15515041], [77.28652954, 8.15513802], [77.28652954, 8.15569496], [77.28624725, 8.15569019], [77.28624725, 8.15625095], [77.2859726, 8.15625095], [77.2859726, 8.15680885], [77.2848587, 8.15680695], [77.2848587, 8.15708256], [77.2840271, 8.15708256], [77.2840271, 8.15736103], [77.28375244, 8.15736103], [77.28375244, 8.15764141], [77.28320313, 8.15764141], [77.28320313, 8.15792084], [77.28236389, 8.15791702], [77.28236389, 8.15819454], [77.2820816, 8.15819454], [77.2820816, 8.15847301], [77.28263855, 8.15847111], [77.28263855, 8.15875053], [77.28206635, 8.15875053], [77.28206635, 8.15903091], [77.28180695, 8.15903091], [77.28180695, 8.15930939], [77.28125, 8.15930462], [77.28125, 8.15958309], [77.28097534, 8.15958309], [77.28097534, 8.15986061], [77.2804184, 8.15986061], [77.2804184, 8.16014099], [77.27986145, 8.16014099], [77.27986145, 8.16042137], [77.27958679, 8.1604166], [77.27958679, 8.16069508], [77.27902985, 8.16069508], [77.27902985, 8.1609726], [77.27874756, 8.16095924], [77.27874756, 8.16125107], [77.27819824, 8.16125107], [77.27819824, 8.16153145], [77.27791595, 8.16153145], [77.27791595, 8.16181183], [77.27735901, 8.16180515], [77.27735901, 8.16208267], [77.27680206, 8.16208267], [77.27680206, 8.16236115], [77.27625275, 8.16236115], [77.27625275, 8.16264057], [77.2756958, 8.16264057], [77.2756958, 8.16292191], [77.27513885, 8.16291714], [77.27513885, 8.16319466], [77.27430725, 8.16319466], [77.27430725, 8.16347313], [77.27375031, 8.16347122], [77.27375031, 8.16375065], [77.27319336, 8.16375065], [77.27319336, 8.16403198], [77.27263641, 8.16403198], [77.27263641, 8.16431046], [77.2720871, 8.16430473], [77.2720871, 8.16458321], [77.27153015, 8.16458321], [77.27153015, 8.16486073], [77.27097321, 8.16486073], [77.27097321, 8.1651392], [77.27041626, 8.1651392], [77.27041626, 8.16541958], [77.26985931, 8.16541672], [77.26985931, 8.16569328], [77.26902771, 8.16569328], [77.26902771, 8.1659708], [77.26847076, 8.16597271], [77.26847076, 8.16624928], [77.26790619, 8.16624928], [77.26790619, 8.16652966], [77.26735687, 8.16652966], [77.26735687, 8.16681004], [77.26680756, 8.16681004], [77.26680756, 8.16709042], [77.26625061, 8.16708279], [77.26625061, 8.16736126], [77.26597595, 8.16736126], [77.26597595, 8.16764164], [77.26541901, 8.16764164], [77.26541901, 8.16792202], [77.26486206, 8.16791534], [77.26486206, 8.16819572], [77.26430511, 8.16819572], [77.26430511, 8.16847134], [77.26403046, 8.16847134], [77.26403046, 8.16874886], [77.26346588, 8.16874886], [77.26346588, 8.16903019], [77.26291656, 8.16903019], [77.26291656, 8.16930962], [77.26235962, 8.1693058], [77.26235962, 8.16958427], [77.26207733, 8.16958141], [77.26208496, 8.16986179], [77.26152802, 8.16986179], [77.26152802, 8.17014027], [77.26069641, 8.17013073], [77.26069641, 8.17041969], [77.25986481, 8.17041779], [77.25986481, 8.17069435], [77.25930786, 8.17069435], [77.25930786, 8.17097187], [77.25846863, 8.17097187], [77.25846863, 8.17125034], [77.25791931, 8.17125034], [77.25791931, 8.17152977], [77.25708008, 8.17152977], [77.25708008, 8.17181015], [77.25653076, 8.17180634], [77.25653076, 8.17208385], [77.25569153, 8.17208385], [77.25569153, 8.17236233], [77.25514984, 8.17236042], [77.25514984, 8.17263985], [77.25374603, 8.17263985], [77.25374603, 8.17292023], [77.25263977, 8.17291641], [77.25263977, 8.17319584], [77.25069427, 8.17319584], [77.25069427, 8.17291641], [77.24958038, 8.17292023], [77.24958038, 8.17263985], [77.24846649, 8.17263985], [77.24846649, 8.17236042], [77.24819183, 8.17236042], [77.24819183, 8.17263985], [77.24764252, 8.17263985], [77.24764252, 8.17292023], [77.24680328, 8.17291641], [77.24680328, 8.17319584], [77.24624634, 8.17319584], [77.24624634, 8.1734724], [77.24595642, 8.17346954], [77.24595642, 8.17374992], [77.24569702, 8.17374992], [77.24569702, 8.1740303], [77.2454071, 8.1740303], [77.2454071, 8.17431068], [77.24514008, 8.17430592], [77.24514008, 8.17458439], [77.24485779, 8.17458439], [77.24485779, 8.17486191], [77.24458313, 8.17486191], [77.24458313, 8.17514038], [77.24430847, 8.17514038], [77.24430847, 8.17542267], [77.24375153, 8.17541599], [77.24375153, 8.17569447], [77.24346924, 8.17569447], [77.24346924, 8.17597198], [77.24318695, 8.17597198], [77.24319458, 8.17625046], [77.24291992, 8.17625046], [77.24291992, 8.17653275], [77.23930359, 8.17652798], [77.23930359, 8.17736244], [77.23902893, 8.17735958], [77.23902893, 8.1779213], [77.23874664, 8.17791557], [77.23874664, 8.17819405], [77.23847198, 8.17819405], [77.23847198, 8.17847157], [77.23819733, 8.17846966], [77.23819733, 8.17875004], [77.23792267, 8.17875004], [77.23792267, 8.17903137], [77.23764038, 8.17903137], [77.23764038, 8.17932034], [77.23708344, 8.17930603], [77.23708344, 8.17958355], [77.23680878, 8.17958355], [77.23680878, 8.17986012], [77.23625183, 8.17986012], [77.23625183, 8.18014145], [77.23596954, 8.18014145], [77.23596954, 8.18042088], [77.23542023, 8.18041611], [77.23542023, 8.18069363], [77.23513794, 8.18069363], [77.23513794, 8.1809721], [77.23486328, 8.18097019], [77.23486328, 8.18124962], [77.23458099, 8.18124962], [77.23458099, 8.18181133], [77.23430634, 8.18180656], [77.23430634, 8.18208218], [77.23401642, 8.18207073], [77.23401642, 8.18264103], [77.23374939, 8.18263817], [77.23374939, 8.18319511], [77.23347473, 8.18319511], [77.23347473, 8.18347263], [77.23319244, 8.18347263], [77.23319244, 8.18375111], [77.23264313, 8.18375111], [77.23264313, 8.18403053], [77.23208618, 8.18403053], [77.23208618, 8.18431091], [77.23180389, 8.18430519], [77.23180389, 8.18458271], [77.23152924, 8.18458271], [77.23152924, 8.18486118], [77.23124695, 8.18486118], [77.23124695, 8.1851387], [77.23069763, 8.18513203], [77.23069763, 8.18542099], [77.23041534, 8.18541718], [77.23041534, 8.18736076], [77.23014069, 8.18735886], [77.23014069, 8.18792152], [77.2298584, 8.18791676], [77.2298584, 8.18847084], [77.22930908, 8.18847084], [77.22930908, 8.18875122], [77.22846985, 8.18875122], [77.22846985, 8.18903065], [77.2279129, 8.18902683], [77.2279129, 8.18958282], [77.22763824, 8.18958092], [77.22763824, 8.19014072], [77.22736359, 8.19013882], [77.22736359, 8.19069481], [77.2270813, 8.19069099], [77.2270813, 8.19126034], [77.22680664, 8.19126034], [77.22680664, 8.19180965], [77.22651672, 8.19180965], [77.22652435, 8.19236088], [77.22624969, 8.19236088], [77.22624969, 8.19291973], [77.22597504, 8.19291687], [77.22597504, 8.19374943], [77.22541809, 8.19374943], [77.22541809, 8.19402981], [77.22458649, 8.19402981], [77.22458649, 8.19432068], [77.2243042, 8.19430542], [77.2243042, 8.19486141], [77.22402954, 8.19486141], [77.22402954, 8.19569111], [77.22374725, 8.19569969], [77.22374725, 8.19625187], [77.2234726, 8.19625187], [77.2234726, 8.19653034], [77.22292328, 8.19653034], [77.22292328, 8.19680977], [77.22264099, 8.19680595], [77.22264099, 8.19694042], [77.22264099, 8.19708443], [77.2224884, 8.19708443], [77.2223587, 8.19708443], [77.2223587, 8.19736195], [77.22203827, 8.19736195], [77.22180939, 8.19736195], [77.22179413, 8.19752121], [77.2217865, 8.19764042], [77.22162628, 8.19767761], [77.2215271, 8.19770145], [77.2215271, 8.19791985], [77.22125244, 8.19791794], [77.22125244, 8.19819355], [77.2206955, 8.19819355], [77.2206955, 8.19847202], [77.22041321, 8.19847202], [77.22041321, 8.19874954], [77.22013855, 8.19874954], [77.22013855, 8.19902992], [77.2195816, 8.19902992], [77.2195816, 8.1993103], [77.21930695, 8.19930553], [77.21930695, 8.19958401], [77.21902466, 8.19958401], [77.21902466, 8.19986153], [77.21847534, 8.19986153], [77.21847534, 8.20014], [77.21819305, 8.20013142], [77.21819305, 8.20042038], [77.21763611, 8.20041561], [77.21763611, 8.20069408], [77.21736145, 8.20069408], [77.21736145, 8.2009716], [77.21679687, 8.2009697], [77.21679687, 8.20125008], [77.21652985, 8.20125008], [77.21652985, 8.20153046], [77.21598053, 8.20153046], [77.21598053, 8.20181274], [77.21569824, 8.20180607], [77.21569824, 8.20208359], [77.2151413, 8.20208359], [77.2151413, 8.20236206], [77.21485901, 8.20236015], [77.21485901, 8.20263958], [77.21430206, 8.20263958], [77.21430206, 8.20292091], [77.2140274, 8.20292091], [77.2140274, 8.20320129], [77.21347046, 8.20319366], [77.21347046, 8.20347214], [77.21290588, 8.20347023], [77.21290588, 8.20374966], [77.21235657, 8.20374966], [77.21235657, 8.20403004], [77.21180725, 8.20403004], [77.21180725, 8.20431137], [77.21125031, 8.20430565], [77.21125031, 8.20458412], [77.21069336, 8.20458412], [77.21069336, 8.20485973], [77.21013641, 8.20485973], [77.21013641, 8.20514011], [77.2095871, 8.20514011], [77.2095871, 8.20542145], [77.20903015, 8.20541573], [77.20903015, 8.2056942], [77.20847321, 8.2056942], [77.20847321, 8.20597172], [77.20819092, 8.20597172], [77.20819092, 8.20626163], [77.2076416, 8.20626163], [77.2076416, 8.20653057], [77.20707703, 8.20653057], [77.20707703, 8.20681095], [77.20680237, 8.20680428], [77.20680237, 8.2070837], [77.20625305, 8.2070837], [77.20625305, 8.20736027], [77.20597076, 8.20736027], [77.20597076, 8.20764065], [77.20540619, 8.20764065], [77.20540619, 8.20792103], [77.20513916, 8.20791626], [77.20513916, 8.20819378], [77.20458221, 8.20819378], [77.20458221, 8.20847225], [77.20430756, 8.20847034], [77.20430756, 8.20875072], [77.20375061, 8.20875072], [77.20375061, 8.20903111], [77.20347595, 8.2090292], [77.20347595, 8.20930672], [77.20291901, 8.20930672], [77.20291901, 8.20958233], [77.20263672, 8.20958233], [77.20263672, 8.20985985], [77.20207977, 8.20985985], [77.20207977, 8.21014118], [77.20181274, 8.21014118], [77.20181274, 8.21042061], [77.20124817, 8.21041679], [77.20124817, 8.21069527], [77.20069122, 8.21069527], [77.20069122, 8.21097279], [77.20041656, 8.21097279], [77.20041656, 8.21125126], [77.19985962, 8.21125126], [77.19985962, 8.21153069], [77.19930267, 8.21153069], [77.19930267, 8.21181107], [77.19875336, 8.21180534], [77.19875336, 8.21208286], [77.19847107, 8.21208477], [77.19847107, 8.21236134], [77.19790649, 8.21236134], [77.19790649, 8.21263885], [77.19735718, 8.21263885], [77.19735718, 8.21291924], [77.19680786, 8.21291733], [77.19680786, 8.21319485], [77.19625092, 8.21319485], [77.19625092, 8.21347332], [77.19568634, 8.21347141], [77.19568634, 8.21375084], [77.19513702, 8.21375084], [77.19513702, 8.21403122], [77.19458008, 8.21403122], [77.19458008, 8.2143116], [77.19403076, 8.21430492], [77.19403076, 8.2145834], [77.19346619, 8.21458054], [77.19347382, 8.21486092], [77.19291687, 8.21486092], [77.19291687, 8.2151413], [77.19181061, 8.2151413], [77.19181061, 8.21543121], [77.19125366, 8.21541691], [77.19125366, 8.21569538], [77.19041443, 8.21569538], [77.19041443, 8.21597099], [77.18985748, 8.21597099], [77.18985748, 8.21625137], [77.18930817, 8.21625137], [77.18930817, 8.21652889], [77.18875122, 8.21652889], [77.18875122, 8.21681023], [77.18846893, 8.21680546], [77.18846893, 8.21708298], [77.18791962, 8.21708298], [77.18791962, 8.21736145], [77.18736267, 8.21736145], [77.18736267, 8.21764088], [77.18681335, 8.21764088], [77.18681335, 8.21791935], [77.18653107, 8.21791935], [77.18653107, 8.21819973], [77.18597412, 8.21819305], [77.18597412, 8.21847343], [77.18567657, 8.21847057], [77.18567657, 8.21875095], [77.18541718, 8.21875095], [77.18541718, 8.21902943], [77.18514252, 8.21902943], [77.18514252, 8.21930981], [77.18458557, 8.21930504], [77.18458557, 8.21958256], [77.18430328, 8.21958256], [77.18430328, 8.21986103], [77.18402863, 8.21986103], [77.18402863, 8.22042179], [77.18374634, 8.22041702], [77.18374634, 8.22097111], [77.18347168, 8.22097111], [77.18347168, 8.22124863], [77.18319702, 8.22124004], [77.18319702, 8.22181034], [77.18291473, 8.22180462], [77.18291473, 8.22236156], [77.18264008, 8.22236156], [77.18264008, 8.22292042], [77.18235779, 8.22291756], [77.18235779, 8.22319317], [77.18208313, 8.22319126], [77.18208313, 8.22375202], [77.18180847, 8.22375011], [77.18180847, 8.22458363], [77.18152618, 8.22457886], [77.18152618, 8.22542], [77.18125153, 8.22542], [77.18125153, 8.22624969], [77.18096924, 8.22624969], [77.18096924, 8.22681046], [77.18069458, 8.22680569], [77.18069458, 8.22708416], [77.17987061, 8.22707939], [77.17987061, 8.22737122], [77.17958069, 8.22737122], [77.17958069, 8.22764015], [77.17930603, 8.22764015], [77.17930603, 8.22791958], [77.17903137, 8.22791576], [77.17903137, 8.22819424], [77.17874908, 8.22819424], [77.17874908, 8.22847176], [77.1784668, 8.22846985], [77.17847443, 8.22875023], [77.17819214, 8.22875023], [77.17819214, 8.22902966], [77.17791748, 8.22902966], [77.17791748, 8.22931099], [77.17763519, 8.22930622], [77.17763519, 8.22986221], [77.17736053, 8.22986031], [77.17736053, 8.23013973], [77.17708588, 8.23013973], [77.17708588, 8.23042965], [77.17680359, 8.2304163], [77.17680359, 8.23069382], [77.17652893, 8.23069382], [77.17652893, 8.23097229], [77.17624664, 8.23097038], [77.17624664, 8.23125172], [77.17597198, 8.23125172], [77.17597198, 8.23181057], [77.17569733, 8.2318058], [77.17569733, 8.23208427], [77.17541504, 8.23208427], [77.17541504, 8.23235989], [77.17514038, 8.23235989], [77.17514038, 8.23264027], [77.17485809, 8.23264027], [77.17485809, 8.23292065], [77.17458344, 8.23291588], [77.17458344, 8.23319435], [77.17430878, 8.23319435], [77.17430878, 8.23347187], [77.17373657, 8.23346996], [77.17375183, 8.23375034], [77.17346954, 8.23375034], [77.17346954, 8.23403072], [77.17318726, 8.23403072], [77.17318726, 8.2343111], [77.17292023, 8.23430634], [77.17292023, 8.23458195], [77.17263794, 8.23458195], [77.17263794, 8.23486042], [77.17236328, 8.23486042], [77.17236328, 8.2351408], [77.17208099, 8.2351408], [77.17208099, 8.23542118], [77.17180634, 8.23541641], [77.17180634, 8.23569393], [77.17124939, 8.23569393], [77.17124939, 8.23597336], [77.17097473, 8.23597336], [77.17097473, 8.23625088], [77.17067719, 8.23624134], [77.17067719, 8.23653126], [77.17041779, 8.23653126], [77.17041779, 8.23681068], [77.16986084, 8.23680687], [77.16986084, 8.23736095], [77.1701355, 8.23736095], [77.1701355, 8.23847294], [77.16986084, 8.23847294], [77.16986084, 8.23875141], [77.16958618, 8.23875141], [77.16958618, 8.23903084], [77.16929626, 8.23903084], [77.16929626, 8.23930931], [77.16874695, 8.23930454], [77.16874695, 8.23958302], [77.16847229, 8.23958015], [77.16847229, 8.24014091], [77.16819763, 8.24014091], [77.16819763, 8.2404213], [77.16791534, 8.24041653], [77.16791534, 8.24097347], [77.16764069, 8.24097061], [77.16764069, 8.24264145], [77.1673584, 8.24264145], [77.1673584, 8.24375057], [77.16707611, 8.24375057], [77.16707611, 8.24431038], [77.16680908, 8.24430466], [77.16680908, 8.24486065], [77.16625214, 8.24486065], [77.16625214, 8.24514103], [77.16569519, 8.24513912], [77.16569519, 8.24569321], [77.1645813, 8.24569321], [77.1645813, 8.24597263], [77.16402435, 8.24597263], [77.16402435, 8.2462492], [77.16348267, 8.2462492], [77.16348267, 8.24652863], [77.16208649, 8.24652863], [77.16208649, 8.24597073], [77.1618042, 8.24597263], [77.1618042, 8.24569321], [77.16208649, 8.24569321], [77.16208649, 8.24541664], [77.16291809, 8.24541664], [77.16291809, 8.24486065], [77.1626358, 8.24486065], [77.1626358, 8.24514103], [77.16236115, 8.24514103], [77.16236115, 8.24458122], [77.16208649, 8.24458313], [77.16208649, 8.24486065], [77.16179657, 8.24486065], [77.16179657, 8.24514103], [77.16152954, 8.24513912], [77.16152954, 8.24541664], [77.16124725, 8.24541664], [77.16124725, 8.24569321], [77.1609726, 8.24569321], [77.1609726, 8.24597263], [77.16041565, 8.24597263], [77.16041565, 8.2462492], [77.1598587, 8.2462492], [77.1598587, 8.24652863], [77.15930939, 8.24652863], [77.15930176, 8.24680996], [77.15875244, 8.24680519], [77.15875244, 8.24708271], [77.15847015, 8.24708271], [77.15847015, 8.24736118], [77.15820313, 8.24735928], [77.15820313, 8.24792194], [77.15791321, 8.24791527], [77.15791321, 8.24819565], [77.15763855, 8.24819565], [77.15763855, 8.24847126], [77.1570816, 8.24847126], [77.1570816, 8.24875164], [77.15680695, 8.24875164], [77.15680695, 8.24903202], [77.15625, 8.24903202], [77.15625, 8.24930954], [77.15597534, 8.24930477], [77.15597534, 8.24986172], [77.15570068, 8.24985886], [77.15570068, 8.25014019], [77.15513611, 8.25014019], [77.15513611, 8.25041962], [77.15486145, 8.25041771], [77.15486145, 8.25069332], [77.1543045, 8.25069332], [77.1543045, 8.25097179], [77.15402985, 8.25097179], [77.15402985, 8.25125027], [77.1534729, 8.25125027], [77.1534729, 8.25154114], [77.15319824, 8.25154114], [77.15319824, 8.25181007], [77.1526413, 8.25180626], [77.1526413, 8.25208378], [77.15235901, 8.25208378], [77.15235901, 8.25236225], [77.15207672, 8.25236034], [77.15207672, 8.25263977], [77.1515274, 8.25263977], [77.1515274, 8.25292015], [77.15125275, 8.25291634], [77.15125275, 8.25319386], [77.15097046, 8.25319386], [77.15097046, 8.25347233], [77.15040588, 8.25346947], [77.15041351, 8.25374985], [77.15013885, 8.25374985], [77.15013885, 8.25403023], [77.14956665, 8.25403023], [77.14956665, 8.25430965], [77.14930725, 8.25430584], [77.14930725, 8.25458431], [77.14902496, 8.25458431], [77.14902496, 8.25486183], [77.14848328, 8.25486183], [77.14848328, 8.2551403], [77.14819336, 8.2551403], [77.14819336, 8.25541973], [77.1479187, 8.25541592], [77.1479187, 8.25569439], [77.14736176, 8.25569439], [77.14736176, 8.25597191], [77.1470871, 8.25597191], [77.1470871, 8.25625038], [77.14653015, 8.25625038], [77.14653015, 8.25681114], [77.14624786, 8.25680637], [77.14624786, 8.25736237], [77.14597321, 8.25735092], [77.14597321, 8.25764275], [77.14541626, 8.25764275], [77.14541626, 8.25792122], [77.1451416, 8.25791645], [77.1451416, 8.25819397], [77.14458466, 8.25819397], [77.14458466, 8.25847244], [77.14402771, 8.25846958], [77.14402771, 8.25874996], [77.14376068, 8.25874996], [77.14376068, 8.2590313], [77.14319611, 8.2590313], [77.14319611, 8.25931072], [77.14291382, 8.25930595], [77.14291382, 8.25958443], [77.14235687, 8.25957966], [77.1423645, 8.25986004], [77.14125061, 8.25986004], [77.14125061, 8.26014042], [77.14041901, 8.26013756], [77.14041901, 8.26041603], [77.14013672, 8.26041603], [77.14013672, 8.26069355], [77.13986206, 8.26069355], [77.13986206, 8.26097202], [77.13957977, 8.26097012], [77.13957977, 8.26124954], [77.13903046, 8.26124954], [77.13903046, 8.26153088], [77.13874817, 8.26153088], [77.13874817, 8.26181126], [77.13847351, 8.26180744], [77.13847351, 8.2620821], [77.13791656, 8.2620821], [77.13791656, 8.26236343], [77.13762665, 8.26235962], [77.13762665, 8.26264095], [77.13735962, 8.26264095], [77.13735962, 8.26292133], [77.13708496, 8.26291561], [77.13708496, 8.26319504], [77.13680267, 8.26319027], [77.13680267, 8.26347923], [77.13652802, 8.26347923], [77.13652802, 8.26375103], [77.13625336, 8.26375103], [77.13625336, 8.26403141], [77.13597107, 8.26403141], [77.13597107, 8.26431084], [77.13541412, 8.26430416], [77.13541412, 8.26458263], [77.13513947, 8.26458263], [77.13513947, 8.26486111], [77.13456726, 8.26486111], [77.13456726, 8.26514053], [77.13430786, 8.26514053], [77.13430786, 8.26542091], [77.13375092, 8.2654171], [77.13375092, 8.26569462], [77.13346863, 8.26569462], [77.13346863, 8.26597309], [77.13291931, 8.26597118], [77.13291931, 8.26625061], [77.13263702, 8.26625061], [77.13263702, 8.26653957], [77.13153076, 8.26653957], [77.13153076, 8.26681232], [77.13124847, 8.2668047], [77.13124847, 8.26708317], [77.13096619, 8.26708031], [77.13097382, 8.26736069], [77.13069153, 8.26736069], [77.13069153, 8.26792145], [77.13041687, 8.26791668], [77.13041687, 8.26819515], [77.13014221, 8.26819515], [77.13014221, 8.26847267], [77.12985992, 8.26847267], [77.12985992, 8.26875114], [77.1295929, 8.26875114], [77.1295929, 8.26903057], [77.12847137, 8.26902676], [77.12847137, 8.26958275], [77.12819672, 8.26958275], [77.12819672, 8.26986122], [77.12763977, 8.26986122], [77.12763977, 8.27014065], [77.12735748, 8.27014065], [77.12735748, 8.27042198], [77.12708282, 8.27041721], [77.12708282, 8.27069473], [77.12652588, 8.27069473], [77.12652588, 8.27097321], [77.12625122, 8.2709713], [77.12625122, 8.27125072], [77.12596893, 8.27125072], [77.12596893, 8.2715292], [77.12541962, 8.2715292], [77.12541962, 8.27180958], [77.12513733, 8.27180481], [77.12513733, 8.27208328], [77.12458038, 8.27208328], [77.12458038, 8.2723608], [77.12403107, 8.27235031], [77.12403107, 8.27263927], [77.12346649, 8.27263927], [77.12346649, 8.27291965], [77.12291718, 8.27291679], [77.12291718, 8.27319527], [77.12264252, 8.27319527], [77.12264252, 8.27347088], [77.12236023, 8.27347088], [77.12236023, 8.27374935], [77.1220932, 8.27374935], [77.1220932, 8.27403164], [77.12152863, 8.27403164], [77.12152863, 8.27431202], [77.12124634, 8.27430534], [77.12124634, 8.27458286], [77.12097168, 8.27458286], [77.12097168, 8.27486134], [77.12069702, 8.27486134], [77.12069702, 8.27513885], [77.1204071, 8.27513885], [77.1204071, 8.27542019], [77.11985779, 8.27541542], [77.11985779, 8.2756958], [77.11958313, 8.2756958], [77.11958313, 8.27597141], [77.11930847, 8.27597141], [77.11930847, 8.27625179], [77.11902618, 8.27625179], [77.11902618, 8.27653027], [77.11846924, 8.27653027], [77.11846924, 8.27680969], [77.11819458, 8.27680588], [77.11819458, 8.27708435], [77.11791992, 8.27708435], [77.11791992, 8.27736187], [77.11736298, 8.27736187], [77.11736298, 8.27764034], [77.11708069, 8.27764034], [77.11708069, 8.27791977], [77.11680603, 8.27791786], [77.11680603, 8.27819443], [77.11624908, 8.27819061], [77.11624908, 8.27848053], [77.1159668, 8.27848053], [77.11597443, 8.27875042], [77.11569214, 8.27875042], [77.11569214, 8.27902985], [77.11514282, 8.27902985], [77.11514282, 8.27931023], [77.11486053, 8.27930641], [77.11486053, 8.27958393], [77.11458588, 8.27958393], [77.11458588, 8.2798624], [77.11429596, 8.27985954], [77.11429596, 8.28013992], [77.11402893, 8.28013992], [77.11402893, 8.2804203], [77.11374664, 8.28041553], [77.11374664, 8.28069401], [77.11319733, 8.28069401], [77.11319733, 8.28097153], [77.11292267, 8.28096962], [77.11292267, 8.28125], [77.11235809, 8.28125], [77.11235809, 8.28154182], [77.11207581, 8.28154182], [77.11207581, 8.28181267], [77.11180878, 8.28180599], [77.11180878, 8.28208447], [77.11125183, 8.28208447], [77.11125183, 8.28236198], [77.11096954, 8.28236198], [77.11096954, 8.28264046], [77.11068726, 8.28264046], [77.11068726, 8.28292274], [77.11042023, 8.28291607], [77.11042023, 8.28319359], [77.10986328, 8.28319359], [77.10986328, 8.28347206], [77.10958099, 8.28347015], [77.10958099, 8.28374958], [77.10930634, 8.28374958], [77.10930634, 8.28402996], [77.10901642, 8.28402996], [77.10901642, 8.28431129], [77.10847473, 8.28430557], [77.10847473, 8.28458405], [77.10819244, 8.28458405], [77.10819244, 8.28486156], [77.10765076, 8.28485966], [77.10765076, 8.28514004], [77.10736084, 8.28514004], [77.10736084, 8.28542137], [77.10708618, 8.28541565], [77.10708618, 8.28569412], [77.10652924, 8.28569412], [77.10652924, 8.28597164], [77.10624695, 8.28596973], [77.10624695, 8.28625011], [77.10569763, 8.28625011], [77.10569763, 8.28653145], [77.10514069, 8.28653145], [77.10514069, 8.28681087], [77.10458374, 8.2868042], [77.10458374, 8.28708363], [77.10430908, 8.28708363], [77.10430908, 8.28736019], [77.10375214, 8.28736019], [77.10375214, 8.28764057], [77.10346985, 8.28764057], [77.10346985, 8.28792095], [77.1029129, 8.28791618], [77.1029129, 8.2881937], [77.10263824, 8.2881937], [77.10263824, 8.28847218], [77.1020813, 8.28847027], [77.1020813, 8.28874969], [77.10180664, 8.28874969], [77.10180664, 8.28903103], [77.10151672, 8.28903103], [77.10151672, 8.28931141], [77.10097504, 8.28930664], [77.10097504, 8.28958225], [77.10069275, 8.28958225], [77.10069275, 8.28985977], [77.10041809, 8.28985977], [77.10041809, 8.29042053], [77.09958649, 8.29041672], [77.09958649, 8.29069519], [77.09902954, 8.29069519], [77.09902954, 8.29097271], [77.09874725, 8.29097271], [77.09874725, 8.29125118], [77.09845734, 8.29125118], [77.09845734, 8.29153061], [77.09792328, 8.29153061], [77.09792328, 8.29181099], [77.09764099, 8.29180527], [77.09764099, 8.29208469], [77.09708405, 8.29208469], [77.09708405, 8.29236126], [77.09680939, 8.29236126], [77.09680176, 8.29264069], [77.0965271, 8.29263878], [77.0965271, 8.29319477], [77.09597015, 8.29319], [77.09597015, 8.29348183], [77.09513855, 8.29347324], [77.09513855, 8.29375076], [77.09485626, 8.29374886], [77.09485626, 8.29403114], [77.0945816, 8.29403114], [77.0945816, 8.29431152], [77.09430695, 8.29430485], [77.09430695, 8.29458332], [77.09401703, 8.29458141], [77.09402466, 8.29486084], [77.09375, 8.29486084], [77.09375, 8.29514122], [77.09319305, 8.29514122], [77.09319305, 8.2954216], [77.0929184, 8.29541683], [77.0929184, 8.2956953], [77.09236145, 8.2956953], [77.09236145, 8.2962513], [77.09208679, 8.2962513], [77.09208679, 8.29652691], [77.09179688, 8.29652023], [77.09179688, 8.29681015], [77.09124756, 8.29680538], [77.09124756, 8.2970829], [77.0909729, 8.2970829], [77.0909729, 8.29736137], [77.09069824, 8.29736137], [77.09069824, 8.29747009], [77.09648895, 8.29806995], [77.09822083, 8.30150032], [77.1046524, 8.30160046], [77.10085297, 8.31165123], [77.10883331, 8.31287956], [77.11152649, 8.31649017], [77.12194824, 8.32294178], [77.13062286, 8.32423019], [77.13703156, 8.32009125], [77.14470673, 8.32022953], [77.14977264, 8.32194233], [77.15210724, 8.31946182], [77.15483093, 8.31361103], [77.15965271, 8.31250095], [77.15966797, 8.31738091], [77.15318298, 8.32566071], [77.15106201, 8.33094025], [77.15093231, 8.3354702], [77.15680695, 8.34519958], [77.15460968, 8.35139942], [77.15203857, 8.35473061], [77.14749908, 8.35458088], [77.1415329, 8.3491497], [77.13577271, 8.34566975], [77.13537598, 8.35174084], [77.14322662, 8.36227131], [77.14121246, 8.36899185], [77.13584137, 8.37251091], [77.13481903, 8.37852955], [77.14074707, 8.38280964], [77.14579773, 8.38169956], [77.14939117, 8.37543964], [77.15368652, 8.37744141], [77.16448212, 8.38784027], [77.16709137, 8.39546013], [77.17222595, 8.40170002], [77.17977905, 8.409091], [77.18039703, 8.41860199], [77.18267059, 8.4274807], [77.18868256, 8.43474102], [77.19877625, 8.43677998], [77.20951843, 8.43771935], [77.21022797, 8.44305038], [77.2090683, 8.45068073], [77.20513153, 8.45551014], [77.19877625, 8.46023941], [77.19462585, 8.4693718], [77.19091797, 8.48819065], [77.18649292, 8.49337101], [77.1920166, 8.49938107], [77.19857788, 8.50393963], [77.20639038, 8.50443172], [77.21726227, 8.49613953], [77.22255707, 8.4883213], [77.22754669, 8.49059963], [77.23240662, 8.49591923], [77.24125671, 8.49812984], [77.24754333, 8.50137997], [77.25248718, 8.51708126], [77.25817108, 8.52812958], [77.26515961, 8.53744984], [77.26508331, 8.54255962], [77.25969696, 8.54906178], [77.25152588, 8.57098961], [77.24285889, 8.58055019], [77.23761749, 8.58842945], [77.2321167, 8.59211922], [77.22840881, 8.59781265], [77.22786713, 8.60309124], [77.22827911, 8.61290073], [77.21869659, 8.61837959], [77.21237946, 8.62877941], [77.20825195, 8.63115025], [77.20523071, 8.63528156], [77.1984787, 8.64109993], [77.19523621, 8.64868069], [77.19033813, 8.65489101], [77.18710327, 8.66229153], [77.19046783, 8.67118931], [77.18975067, 8.67737961], [77.18772125, 8.68376064], [77.18296814, 8.69003105], [77.17929077, 8.69961929], [77.17234802, 8.70324993], [77.16703033, 8.70763111], [77.16172791, 8.71516132], [77.16294098, 8.720891], [77.15737915, 8.73118114], [77.15531921, 8.73756027], [77.15724182, 8.74075985], [77.16274261, 8.73518085], [77.17093658, 8.73338032], [77.1765213, 8.73502064], [77.18107605, 8.74081039], [77.18370819, 8.74814034], [77.18344116, 8.75336075], [77.18076324, 8.75756168], [77.18300629, 8.76111031], [77.19143677, 8.75839138], [77.19780731, 8.75774193], [77.20224762, 8.76088047], [77.19933319, 8.76559067], [77.19837952, 8.76949978], [77.20529175, 8.77039146], [77.20960999, 8.77371025], [77.2146759, 8.77576065], [77.21536255, 8.78666019], [77.21736145, 8.79703045], [77.22396851, 8.79833126], [77.22735596, 8.80056], [77.23159027, 8.80709171], [77.23085785, 8.81157112], [77.23195648, 8.81346035], [77.23616791, 8.81762791], [77.24704742, 8.83187962], [77.2428894, 8.84123993], [77.24595642, 8.84307957], [77.24562073, 8.84508133], [77.24040985, 8.85147095], [77.24318695, 8.85509109], [77.24298859, 8.85927105], [77.24150085, 8.86478233], [77.23986816, 8.86806107], [77.23203278, 8.86905003], [77.22712708, 8.87181854], [77.22318268, 8.87781143], [77.22389984, 8.88514996], [77.22145081, 8.88813972], [77.21473694, 8.89212036], [77.2116394, 8.89305019], [77.20625305, 8.8931818], [77.20204163, 8.90668106], [77.20736694, 8.91389179], [77.20474243, 8.91741085], [77.1980896, 8.91930962], [77.19386292, 8.92191029], [77.18976593, 8.91957188], [77.18675232, 8.91567039], [77.18966675, 8.91257], [77.18476868, 8.9101696], [77.18044281, 8.91574955], [77.18061829, 8.91845131], [77.17919159, 8.92098045], [77.18187714, 8.92883015], [77.18164825, 8.93256092], [77.17967224, 8.93749046], [77.18123627, 8.94197083], [77.18016815, 8.94701958], [77.17529297, 8.95083046], [77.17473602, 8.95685196], [77.1632309, 8.96234035], [77.15844727, 8.97819138], [77.14689636, 8.98694992], [77.1440506, 8.99184132], [77.14392853, 8.99184132], [77.14319611, 8.99788094], [77.13725281, 8.99822044], [77.13424683, 8.99997997], [77.13510895, 9.00547028], [77.13326263, 9.00825119], [77.13217926, 9.01185036], [77.13648987, 9.01310062], [77.14055634, 9.01543045], [77.14689636, 9.02156067], [77.14533234, 9.02721977], [77.14824677, 9.03298187], [77.15376282, 9.03656006], [77.16742706, 9.0385313], [77.17014313, 9.03388023], [77.18208313, 9.03650093], [77.18019104, 9.04480076], [77.18286896, 9.04710102], [77.18434906, 9.05064011], [77.1886673, 9.05648041], [77.19148254, 9.06195164], [77.19284821, 9.06503105], [77.19062042, 9.06997013], [77.18974304, 9.07518005], [77.19586182, 9.08842182], [77.2022171, 9.09138012], [77.20482635, 9.09581089], [77.20935059, 9.09757042], [77.21173096, 9.10636139], [77.21704865, 9.10809135], [77.22572327, 9.1141386], [77.23015594, 9.1148119], [77.23258209, 9.11791134], [77.23766327, 9.1299696], [77.24537659, 9.13554955], [77.24606323, 9.13924026], [77.25177765, 9.14304066], [77.24960327, 9.15603924], [77.25229645, 9.16495132], [77.2483902, 9.17578125], [77.24550629, 9.17597008], [77.24328613, 9.17612076], [77.23661804, 9.17919064], [77.23957062, 9.18656063], [77.23973083, 9.18994999], [77.24704742, 9.18925953], [77.25026703, 9.19023991], [77.2532959, 9.19336033], [77.25817871, 9.20007038], [77.26680756, 9.20881939], [77.26139069, 9.21698093], [77.2594986, 9.22441101], [77.26364899, 9.23185921], [77.26248169, 9.24090958], [77.26566315, 9.24368095], [77.26590729, 9.25529099], [77.2678299, 9.25787067], [77.26760864, 9.26239967], [77.27411652, 9.26317024], [77.26714325, 9.28168964], [77.26682281, 9.2908802], [77.27011108, 9.29177094], [77.27345276, 9.29419136], [77.27768707, 9.29526043], [77.28350067, 9.30091], [77.28423309, 9.30506039], [77.28675842, 9.30811024], [77.28681946, 9.31006145], [77.2853775, 9.31560135], [77.28230286, 9.31961918], [77.28515625, 9.32123089], [77.28414154, 9.32747078], [77.28687286, 9.32690144], [77.29055023, 9.327672], [77.30010986, 9.32495022], [77.30702972, 9.327631], [77.31134033, 9.32790184], [77.30966187, 9.33464146], [77.32061005, 9.35109043], [77.32000732, 9.35480022], [77.32303619, 9.35856056], [77.31954193, 9.36326027], [77.31980133, 9.37613106], [77.32579041, 9.37868118], [77.32608795, 9.38046074], [77.32488251, 9.38354015], [77.32762909, 9.38980961], [77.3274231, 9.39406109], [77.32137299, 9.40180111], [77.32167816, 9.40565014], [77.3241272, 9.40818024], [77.33007813, 9.41521072], [77.33185577, 9.42138958], [77.33461761, 9.42393112], [77.3342514, 9.43105125], [77.34292603, 9.4404211], [77.34542847, 9.445261], [77.35160828, 9.44970131], [77.35655212, 9.44791031], [77.3602066, 9.44367981], [77.3636322, 9.4433012], [77.36765289, 9.44390106], [77.37223816, 9.44527054], [77.37858582, 9.45075035], [77.37737274, 9.45866013], [77.38220978, 9.46118069], [77.38683319, 9.46737099], [77.38405609, 9.46977997], [77.38391876, 9.47909069], [77.38551331, 9.48619175], [77.38788605, 9.49096012], [77.3962326, 9.49654198], [77.39486694, 9.50439072], [77.39008331, 9.50463104], [77.38639832, 9.50679111], [77.3867569, 9.51673985], [77.37071991, 9.50869179], [77.36625671, 9.51479053], [77.36097717, 9.51616955], [77.35470581, 9.52390957], [77.35054779, 9.52629185], [77.35057068, 9.54026031], [77.34880829, 9.5461998], [77.34655762, 9.5485611], [77.33996582, 9.54911041], [77.33805084, 9.55027008], [77.33743286, 9.55486012], [77.33587646, 9.55683041], [77.3405304, 9.56406116], [77.34371185, 9.56384945], [77.34525299, 9.56727028], [77.34091949, 9.57763958], [77.34320068, 9.58481121], [77.34481812, 9.58760929], [77.34623718, 9.58780956], [77.34922028, 9.58649921], [77.35132599, 9.58804035], [77.35106659, 9.58930016], [77.34089661, 9.59505081], [77.32850647, 9.57322979], [77.32478333, 9.5632], [77.32100677, 9.56737137], [77.31067657, 9.57036114], [77.30976105, 9.5759697], [77.31201172, 9.57815075], [77.31078339, 9.58450127], [77.31484985, 9.58862114], [77.31371307, 9.59013939], [77.30901337, 9.58883095], [77.30430603, 9.59304142], [77.28649139, 9.58729935], [77.27954102, 9.58006954], [77.27497101, 9.58095169], [77.27529144, 9.57658958], [77.26113892, 9.56667995], [77.25785828, 9.56816196], [77.25501251, 9.564991], [77.25054932, 9.56541061], [77.24672699, 9.56866074], [77.24475861, 9.56861115], [77.24198914, 9.57154083], [77.2388916, 9.57336044], [77.22989655, 9.57592201], [77.22280884, 9.57279015], [77.21466827, 9.57880116], [77.20910645, 9.58443928], [77.20861053, 9.58883953], [77.2053833, 9.59227943], [77.20081329, 9.5923996], [77.19657898, 9.59570026], [77.19593811, 9.60419178], [77.18596649, 9.60592175], [77.18398285, 9.6024313], [77.17914581, 9.60146046], [77.17456818, 9.59716129], [77.1672821, 9.60066891], [77.15550232, 9.60150146], [77.15187073, 9.60601997], [77.15487671, 9.60838127], [77.15457916, 9.61395168], [77.1622467, 9.61981106], [77.16065216, 9.6273098], [77.16062927, 9.63024139], [77.16588593, 9.6379509], [77.16565704, 9.6482296], [77.16887665, 9.65157986], [77.17308807, 9.65184021], [77.17251587, 9.65620041], [77.17959595, 9.66038036], [77.18219757, 9.66871929], [77.18477631, 9.67147923], [77.18589783, 9.67817116], [77.19168854, 9.68618202], [77.18900299, 9.69750023], [77.19021606, 9.70615196], [77.18992615, 9.71551037], [77.19991302, 9.71728992], [77.20822906, 9.72167015], [77.20603943, 9.7374897], [77.21135712, 9.74524975], [77.2124176, 9.75539017], [77.21859741, 9.76000977], [77.21069336, 9.76638889], [77.20981598, 9.77994061], [77.22254944, 9.78177071], [77.2266922, 9.78675079], [77.2339859, 9.78851986], [77.23203278, 9.79441071], [77.23282623, 9.79728985], [77.22708893, 9.80631065], [77.21945953, 9.80884075], [77.21898651, 9.81325054], [77.21235657, 9.81293201], [77.20892334, 9.81452179], [77.21502686, 9.83087063], [77.21335602, 9.832901], [77.21383667, 9.83854008], [77.22373962, 9.84296131], [77.22366333, 9.84901047], [77.2183075, 9.8534708], [77.21325684, 9.85198021], [77.20919037, 9.85379028], [77.19911194, 9.8659811], [77.20144653, 9.869771], [77.2027359, 9.87474155], [77.20654297, 9.87776184], [77.20443726, 9.89431953], [77.21689606, 9.90576077], [77.22094727, 9.91775131], [77.2219162, 9.92282009], [77.23448181, 9.93811131], [77.23471069, 9.94283104], [77.23594666, 9.94338036], [77.23661041, 9.94138145], [77.24021149, 9.94306087], [77.24991608, 9.94253922], [77.25527954, 9.95018959], [77.25898743, 9.953372], [77.2614212, 9.96372128], [77.25952148, 9.96620083], [77.24983978, 9.97278118], [77.2487793, 9.97740078], [77.25076294, 9.98140144], [77.24672699, 9.98149014], [77.24514771, 9.98622131], [77.2478714, 9.99116039], [77.24772644, 9.99116039], [77.24768066, 9.99484062], [77.24088287, 10.00013065], [77.2407074, 10.00289059], [77.24443054, 10.00774956], [77.24893188, 10.01581097], [77.24809265, 10.02023029], [77.24556732, 10.02362156], [77.2423172, 10.02615166], [77.23707581, 10.03520203], [77.23065948, 10.03952122], [77.2244873, 10.04554939], [77.22068024, 10.05061054], [77.21817017, 10.05686092], [77.2129364, 10.0584507], [77.20443726, 10.06849098], [77.19906616, 10.07066059], [77.19519806, 10.07354164], [77.19072723, 10.08115196], [77.18979645, 10.08655071], [77.18990326, 10.09097004], [77.18779755, 10.09250164], [77.18814087, 10.09565163], [77.19460297, 10.10624886], [77.19787598, 10.10647964], [77.20330048, 10.10362244], [77.20600128, 10.10603142], [77.21234894, 10.10876083], [77.2154007, 10.10929203], [77.21872711, 10.11129093], [77.22126007, 10.11537075], [77.22511292, 10.11845016], [77.2305069, 10.12012005], [77.23483276, 10.11665058], [77.23990631, 10.11413956], [77.24608612, 10.11235142], [77.25327301, 10.11140919], [77.25498962, 10.11631203], [77.25978088, 10.11908054], [77.26101685, 10.12869167], [77.26013947, 10.13066101], [77.25756073, 10.13222027], [77.25743103, 10.13588142], [77.25961304, 10.14122963], [77.25914764, 10.15535069], [77.26441193, 10.17973995], [77.26941681, 10.18710041], [77.2713623, 10.19406033], [77.26966858, 10.19678974], [77.27297974, 10.19776058], [77.27385712, 10.20146942], [77.27620697, 10.20366192], [77.27905273, 10.20401096], [77.28044891, 10.20725155], [77.27482605, 10.22054958], [77.26996613, 10.22433186], [77.26622772, 10.22509003], [77.25875092, 10.22385979], [77.25556946, 10.22552967], [77.25418854, 10.22332191], [77.2512207, 10.22436142], [77.24915314, 10.22205925], [77.24652863, 10.22060966], [77.2455368, 10.22625065], [77.24577332, 10.23215103], [77.24482727, 10.24518967], [77.24530029, 10.24857044], [77.24755859, 10.25157166], [77.25054932, 10.2537508], [77.24652863, 10.25755024], [77.23191833, 10.27723026], [77.22093201, 10.29603958], [77.21720886, 10.29800034], [77.2144928, 10.30580139], [77.21833038, 10.32201958], [77.22251129, 10.32853127], [77.22216034, 10.34030056], [77.21444702, 10.34136963], [77.19946289, 10.34195137], [77.19274139, 10.3434], [77.1889801, 10.34617043], [77.18136597, 10.34317017], [77.17312622, 10.34401131], [77.16883087, 10.34598923], [77.16295624, 10.34628105], [77.14823151, 10.33405972], [77.13405609, 10.32371998], [77.12673187, 10.32024193], [77.11933136, 10.31551075], [77.11425781, 10.31056023], [77.10832214, 10.30717087], [77.10072327, 10.30445004], [77.09224701, 10.30426979], [77.08795929, 10.30176067], [77.08170319, 10.29965019], [77.07344055, 10.29579163], [77.06755066, 10.29022121], [77.06078339, 10.28646088], [77.05187988, 10.28548145], [77.05111694, 10.2828598], [77.05332184, 10.27989006], [77.0460968, 10.27429008], [77.03383636, 10.27217102], [77.04250336, 10.26197147], [77.03855133, 10.24816036], [77.03025818, 10.24293232], [77.01859283, 10.24183083], [77.01603699, 10.24096012], [77.01522064, 10.23759174], [77.00666809, 10.23637009], [76.99939728, 10.22979927], [76.99577332, 10.22935009], [76.99372101, 10.22772121], [76.99141693, 10.22299957], [76.98726654, 10.21994019], [76.98145294, 10.21990967], [76.97458649, 10.21393204], [76.97078705, 10.20865059], [76.96734619, 10.21257973], [76.96176147, 10.21581173], [76.95878601, 10.21873188], [76.95226288, 10.2197504], [76.94587708, 10.22279072], [76.93920898, 10.2211113], [76.92777252, 10.22958946], [76.92500305, 10.22978115], [76.92030334, 10.22544098], [76.90934753, 10.22319889], [76.90547943, 10.22475147], [76.90123749, 10.22781181], [76.89872742, 10.2325592], [76.89231873, 10.23267078], [76.89356232, 10.23744106], [76.89182281, 10.24308014], [76.8846283, 10.25507927], [76.87705994, 10.25631046], [76.87081909, 10.26408195], [76.86229706, 10.26706123], [76.86157227, 10.26962852], [76.86206818, 10.28254986], [76.86427307, 10.29004097], [76.86057281, 10.29074097], [76.85788727, 10.28926182], [76.85073853, 10.2828207], [76.84056854, 10.28361034], [76.83985901, 10.28143978], [76.83988953, 10.27754021], [76.83854675, 10.27759933], [76.83525085, 10.2816906], [76.83194733, 10.28377056], [76.83000183, 10.29111004], [76.82492065, 10.29383087], [76.81967163, 10.2952404], [76.81961823, 10.30263996], [76.82419586, 10.31231117], [76.82585907, 10.32004166], [76.82676697, 10.33026123], [76.82569122, 10.33421135], [76.82756042, 10.33758163], [76.83577728, 10.34636974], [76.83624268, 10.35296059], [76.83934784, 10.35970974], [76.83815765, 10.36264133], [76.83069611, 10.37210178], [76.82460785, 10.37524033], [76.82048798, 10.38179016], [76.8156662, 10.38653088], [76.82264709, 10.39406109], [76.82264709, 10.39893246], [76.82145691, 10.40340996], [76.81503296, 10.40178967], [76.81196594, 10.41138935], [76.80732727, 10.41491985], [76.81745148, 10.43848991], [76.82097626, 10.48023129], [76.82028961, 10.49067974], [76.82525635, 10.50298119], [76.83143616, 10.52457142], [76.83196259, 10.52916145], [76.8245163, 10.53763962], [76.82572937, 10.54298019], [76.83017731, 10.55298138], [76.82907104, 10.55706024], [76.82546234, 10.56156158], [76.82601166, 10.56751919], [76.82932281, 10.5764513], [76.82972717, 10.58506203], [76.82834625, 10.58827972], [76.82450104, 10.58956146], [76.81539917, 10.58829975], [76.80861664, 10.59448147], [76.80961609, 10.60427856], [76.80847931, 10.60727024], [76.80497742, 10.60913181], [76.80326843, 10.61408043], [76.80568695, 10.62082958], [76.80499268, 10.62634087], [76.81468964, 10.6260004], [76.8224411, 10.62738132], [76.82685089, 10.627141], [76.83129883, 10.62588978], [76.83822632, 10.62671089], [76.84471893, 10.62627125], [76.85246277, 10.62394142], [76.85952759, 10.62520027], [76.87261963, 10.62943172], [76.87460327, 10.63922977], [76.87216949, 10.65353107], [76.86947632, 10.65635967], [76.87036896, 10.66076088], [76.87016296, 10.66409969], [76.86769867, 10.66623974], [76.86326599, 10.66695976], [76.85507202, 10.67240047], [76.8555069, 10.67527199], [76.85980225, 10.67714119], [76.86190033, 10.68056202], [76.86160278, 10.68626022], [76.8651123, 10.69293976], [76.87504578, 10.70672035], [76.88101196, 10.70606136], [76.88374329, 10.70735073], [76.88128662, 10.71292973], [76.87931824, 10.72023964], [76.88040161, 10.72614002], [76.88680267, 10.73674965], [76.88765717, 10.74300957], [76.89035034, 10.74749088], [76.8931427, 10.75040245], [76.89427948, 10.75535202], [76.89385986, 10.76055145], [76.89668274, 10.76607132], [76.89750671, 10.77079964], [76.89148712, 10.79216003], [76.88829803, 10.79988194], [76.88194275, 10.80107117], [76.85999298, 10.79980183], [76.85259247, 10.80850124], [76.84041595, 10.8076601], [76.83712769, 10.81553936], [76.84342957, 10.82250023], [76.84519196, 10.82650185], [76.84266663, 10.83185101], [76.83872986, 10.83762169], [76.83407593, 10.84270191], [76.82762909, 10.84714031], [76.82459259, 10.85044193], [76.82089233, 10.85891056], [76.81755829, 10.86180115], [76.79094696, 10.87096977], [76.78527069, 10.87147236], [76.78128052, 10.87390137], [76.77773285, 10.87897015], [76.77298737, 10.88164139], [76.76669312, 10.88174057], [76.76191711, 10.87977028], [76.74910736, 10.88478184], [76.74395752, 10.88492107], [76.73943329, 10.88443089], [76.7326889, 10.88097954], [76.73079681, 10.88408184], [76.7278595, 10.88679886], [76.72283936, 10.88762188], [76.71846008, 10.88984108], [76.71142578, 10.89556026], [76.70040131, 10.90079021], [76.69300079, 10.90227032], [76.68460083, 10.90243053], [76.67487335, 10.90640163], [76.65278625, 10.91996002], [76.64916229, 10.92415237], [76.64739227, 10.92897034], [76.65558624, 10.93427086], [76.65727997, 10.93868065], [76.654953, 10.94219112], [76.65931702, 10.95048046], [76.66044617, 10.96045971], [76.67777252, 10.97970104], [76.67868805, 10.98605061], [76.68081665, 10.99265957], [76.67978668, 10.99943066], [76.6904068, 11.01749992], [76.69883728, 11.0226717], [76.70652008, 11.03135109], [76.71205139, 11.03245068], [76.73239899, 11.02897072], [76.74401855, 11.02590084], [76.75697327, 11.02459145], [76.78183746, 11.02895069], [76.78678131, 11.03225136], [76.79247284, 11.0423727], [76.79342651, 11.04701138], [76.7899704, 11.04968166], [76.7754364, 11.03428173], [76.7671814, 11.03221035], [76.76232147, 11.03426075], [76.754776, 11.03919983], [76.75112915, 11.04675961], [76.74649048, 11.04697037], [76.74022675, 11.04562855], [76.73709869, 11.04751015], [76.73600006, 11.05445194], [76.73443604, 11.05832195], [76.73449707, 11.06389046], [76.74643707, 11.07087135], [76.74803925, 11.0751009], [76.7462616, 11.07885933], [76.74572754, 11.08392143], [76.74272919, 11.08600044], [76.73858643, 11.08395958], [76.73413849, 11.0933609], [76.73500061, 11.09910011], [76.73937225, 11.10361099], [76.74060822, 11.10991001], [76.7388916, 11.11485958], [76.73871613, 11.12129021], [76.73493195, 11.12512112], [76.72930908, 11.12539005], [76.72220612, 11.12251186], [76.71536255, 11.12842083], [76.71266174, 11.13286972], [76.70983124, 11.1402998], [76.70298767, 11.14178181], [76.70269012, 11.13862038], [76.70555878, 11.13612938], [76.70361328, 11.13201141], [76.70014954, 11.1314497], [76.69667816, 11.13268089], [76.6950531, 11.14023018], [76.69117737, 11.14451027], [76.68601227, 11.15770054], [76.68902588, 11.16508961], [76.6934967, 11.16672039], [76.69676971, 11.17187977], [76.70133209, 11.17453957], [76.70643616, 11.1796217], [76.71375275, 11.17801094], [76.72115326, 11.18451118], [76.71791077, 11.19240093], [76.71795654, 11.19831085], [76.72654724, 11.20646954], [76.72557831, 11.20889091], [76.72261047, 11.20810032], [76.72054291, 11.21163273], [76.71038818, 11.21831036], [76.69696808, 11.23133087], [76.67938995, 11.2270298], [76.67784119, 11.22280025], [76.67816925, 11.21883011], [76.66819, 11.21068001], [76.65344238, 11.20429134], [76.64164734, 11.19651031], [76.62966919, 11.19080067], [76.62303925, 11.18567085], [76.60205841, 11.1954689], [76.59333801, 11.19749069], [76.57778168, 11.19684124], [76.54801178, 11.19314194], [76.53611755, 11.18931103], [76.5212326, 11.19027042], [76.51024628, 11.19528198], [76.50601196, 11.20197964], [76.50231171, 11.20286179], [76.48764801, 11.20279026], [76.474823, 11.20125961], [76.46586609, 11.19874191], [76.46653748, 11.18609047], [76.45883179, 11.18412971], [76.45272064, 11.18021011], [76.443573, 11.1908989], [76.44030762, 11.19125938], [76.43802643, 11.19454956], [76.44287872, 11.20009136], [76.44638824, 11.23046112], [76.48812866, 11.25196171], [76.51352692, 11.26196003], [76.51309204, 11.26466084], [76.51593018, 11.2724514], [76.52194977, 11.28120136], [76.53405762, 11.28796101], [76.54016876, 11.29234791], [76.5304718, 11.29574203], [76.52854156, 11.30344963], [76.53048706, 11.30963993], [76.53524017, 11.3163414], [76.53978729, 11.32095146], [76.54075623, 11.32704067], [76.53820038, 11.35159016], [76.52986145, 11.34768105], [76.51637268, 11.34897137], [76.50949097, 11.34661198], [76.50673676, 11.34766006], [76.50945282, 11.3537302], [76.51007843, 11.36115074], [76.47286987, 11.37534142], [76.44838715, 11.38141918], [76.43934631, 11.39066982], [76.41838837, 11.40526962], [76.40817261, 11.41481972], [76.41004944, 11.42520142], [76.41039276, 11.43359089], [76.39057922, 11.42796135], [76.37058258, 11.44089985], [76.36148071, 11.44796085], [76.35308075, 11.45083046], [76.33905792, 11.45417976], [76.33368683, 11.45871067], [76.32090759, 11.44469929], [76.30593872, 11.45335102], [76.297966, 11.4588604], [76.28903961, 11.4563179], [76.28407288, 11.46243954], [76.28769684, 11.46599102], [76.28578949, 11.46857071], [76.27806091, 11.47453117], [76.26608276, 11.46869183], [76.25792694, 11.47322273], [76.24726868, 11.46414948], [76.24009705, 11.45964146], [76.24089813, 11.47521019], [76.24475861, 11.49432087], [76.24288177, 11.49868965], [76.24151611, 11.50479126], [76.23320007, 11.51867962], [76.23964691, 11.52094078], [76.24295807, 11.5241909], [76.24246979, 11.52879047], [76.2383194, 11.53335953], [76.23445892, 11.54648113], [76.22693634, 11.55968189], [76.22574615, 11.56443977], [76.25969696, 11.5869379], [76.266716, 11.58932018], [76.27097321, 11.59290886], [76.27600098, 11.58995056], [76.27793884, 11.5835104], [76.28588867, 11.58295155], [76.29064178, 11.58056068], [76.29316711, 11.57176113], [76.29377747, 11.56503105], [76.29789734, 11.56433105], [76.30517578, 11.57042122], [76.30919647, 11.56960011], [76.31109619, 11.57751083], [76.32858276, 11.58855057], [76.3334198, 11.58512974], [76.33349609, 11.58065033], [76.33558655, 11.57834053], [76.34034729, 11.58056068], [76.35011292, 11.58274174], [76.3653717, 11.59171867], [76.37069702, 11.59346962], [76.37106323, 11.60069942], [76.37683868, 11.60464001], [76.37674713, 11.61474133], [76.38006592, 11.62241936], [76.39618683, 11.62531185], [76.42128754, 11.62510014], [76.42479706, 11.62329006], [76.42588806, 11.62903118], [76.43070221, 11.62963104], [76.43421936, 11.63352108], [76.43557739, 11.63770103], [76.43461609, 11.64161015], [76.4298172, 11.6450901], [76.42767334, 11.64752197], [76.42346191, 11.65932083], [76.4312973, 11.65657043], [76.45136261, 11.6551199], [76.46660614, 11.67232132], [76.47367859, 11.67813969], [76.47377777, 11.68422031], [76.47934723, 11.68240166], [76.48532104, 11.68234921], [76.48781586, 11.68545055], [76.50421143, 11.69804096], [76.51307678, 11.69419193], [76.52468872, 11.68601036], [76.53531647, 11.67704105], [76.54042053, 11.67050934], [76.5430069, 11.66296959], [76.54308319, 11.65648079], [76.54521942, 11.64825058], [76.54705811, 11.6357708], [76.54968262, 11.62697124], [76.55322266, 11.61953163], [76.55362701, 11.61291981], [76.56006622, 11.61012077], [76.5748291, 11.60571957], [76.58096313, 11.60940075], [76.58615875, 11.60799026], [76.58827972, 11.60435963], [76.59671021, 11.6033802], [76.60144043, 11.60122108], [76.60787201, 11.60044193], [76.62565613, 11.60381889], [76.63372803, 11.60352993], [76.66443634, 11.60509968], [76.67904663, 11.60414124], [76.69309998, 11.6044302], [76.70749664, 11.60593891], [76.72020721, 11.60505009], [76.73542786, 11.60523033], [76.74104309, 11.60580921], [76.74626923, 11.61054134], [76.75139618, 11.60670853], [76.77377319, 11.60342979], [76.78082275, 11.60357094], [76.79075623, 11.59970093], [76.80832672, 11.59618187], [76.81651306, 11.59720993], [76.8236084, 11.59130001], [76.82993317, 11.58982086], [76.83349609, 11.58703136], [76.83596802, 11.58403015], [76.83728027, 11.57448006], [76.84375763, 11.58603096], [76.84733582, 11.58864021], [76.85090637, 11.60182953], [76.84588623, 11.60605145], [76.84581757, 11.61164093], [76.84155273, 11.61322117], [76.83825684, 11.61584187], [76.83798218, 11.6187706], [76.83882141, 11.62341976], [76.83309174, 11.62529087], [76.82969666, 11.62934113], [76.829216, 11.63497066], [76.82775116, 11.63842964], [76.82847595, 11.64410973], [76.83003235, 11.64904022], [76.83230591, 11.65266132], [76.83566284, 11.65607071], [76.83838654, 11.66466999], [76.84137726, 11.66977119], [76.84472656, 11.67737198], [76.84617615, 11.6824789], [76.84910583, 11.68721962], [76.85572815, 11.69433975], [76.8535614, 11.69878197], [76.86457062, 11.71053123], [76.87558746, 11.71789932], [76.880867, 11.72459126], [76.88172913, 11.73009014], [76.88600922, 11.74448109], [76.88851166, 11.75043201], [76.88934326, 11.76060104], [76.88796997, 11.76589966], [76.89150238, 11.77011204], [76.89335632, 11.77730274], [76.89968872, 11.78327179], [76.90679169, 11.78123188], [76.91348267, 11.78036976], [76.92666626, 11.78089046], [76.93239594, 11.77737141], [76.93580627, 11.77674198], [76.94032288, 11.78102016], [76.94444275, 11.7813406], [76.95025635, 11.77543068], [76.95316315, 11.7712698], [76.95960236, 11.76519966], [76.96330261, 11.77079964], [76.96539307, 11.77647972], [76.97483826, 11.79102135], [76.97341156, 11.79511166], [76.97277069, 11.80106926], [76.9821167, 11.79953957], [76.99035645, 11.79931927], [77.00443268, 11.80301952], [77.00884247, 11.79696178], [77.01344299, 11.79917145], [77.01857758, 11.79732037], [77.02275848, 11.79498196], [77.02855682, 11.78911972], [77.02767944, 11.78668976], [77.03167725, 11.78395081], [77.03026581, 11.77830124], [77.02233887, 11.76470089], [77.02757263, 11.76169968], [77.04125977, 11.7775898], [77.04569244, 11.77915955], [77.05253601, 11.77923107], [77.05654144, 11.77711964], [77.0618515, 11.77206135], [77.05438995, 11.76496124], [77.05010986, 11.75774956], [77.07385254, 11.72954082], [77.07163239, 11.72500992], [77.07588959, 11.72389126], [77.0962677, 11.72312069], [77.10367584, 11.71554947], [77.10929871, 11.71280098], [77.10830688, 11.72243023], [77.10540009, 11.73158073], [77.10323334, 11.74588013], [77.10573578, 11.75064087], [77.10610962, 11.75622082], [77.1053009, 11.75948048], [77.10282898, 11.7631197], [77.11096954, 11.76314926], [77.1138916, 11.76183033], [77.11972046, 11.76338196], [77.12738037, 11.76093197], [77.13102722, 11.7623806], [77.13459015, 11.76641083], [77.13723755, 11.7719717], [77.14379883, 11.77129936], [77.15541077, 11.77427101], [77.16591644, 11.77423], [77.17230225, 11.77573013], [77.17842102, 11.77952003], [77.18966675, 11.78281975], [77.20392609, 11.78447056], [77.21642303, 11.78476048], [77.22705078, 11.78374958], [77.23707581, 11.7881918], [77.24125671, 11.79399967], [77.24173737, 11.80245972], [77.24848175, 11.8008604], [77.27227783, 11.79117966], [77.27829742, 11.78973961], [77.28235626, 11.79286003], [77.28481293, 11.79836178], [77.29045105, 11.79416084], [77.30623627, 11.77870178], [77.31356049, 11.76998043], [77.32611847, 11.75893974], [77.34565735, 11.76406956], [77.35092926, 11.76858044], [77.35515594, 11.77837181], [77.35948944, 11.77879143], [77.36223602, 11.7758007], [77.38189697, 11.77616119], [77.40145111, 11.76403141], [77.40654755, 11.76233959], [77.41246796, 11.76228142], [77.4125061, 11.75612926], [77.4134903, 11.75115204], [77.41925049, 11.75067139], [77.4207077, 11.7602911], [77.42384338, 11.76608944], [77.43105316, 11.77168179], [77.43028259, 11.77667141], [77.43209076, 11.77894115], [77.43622589, 11.78176975], [77.44087219, 11.79134178], [77.44246674, 11.80647087], [77.44650269, 11.81149197], [77.44658661, 11.81626034], [77.45159149, 11.82341194], [77.45629883, 11.83912182], [77.45536041, 11.84268188], [77.45096588, 11.84431171], [77.45252991, 11.84910011], [77.45210266, 11.85323048], [77.45387268, 11.85733891], [77.45516205, 11.8672514], [77.45329285, 11.87089062], [77.45302582, 11.87589073], [77.45385742, 11.8819418], [77.45279694, 11.88853073], [77.45392609, 11.89055061], [77.46333313, 11.88727093], [77.46743011, 11.88321018], [77.4704361, 11.88361073], [77.47367096, 11.87780094], [77.47690582, 11.87601185], [77.47721863, 11.88177967], [77.47596741, 11.88955021], [77.47733307, 11.8952713], [77.47949982, 11.9003706], [77.48219299, 11.91214085], [77.48394012, 11.9214716], [77.48282623, 11.92869186], [77.48439789, 11.93239975], [77.49043274, 11.92973995], [77.50063324, 11.92723083], [77.51095581, 11.92534161], [77.51402283, 11.92568111], [77.52365112, 11.92148113], [77.53132629, 11.92649937], [77.54799652, 11.93074989], [77.57328796, 11.92401123], [77.5789566, 11.9282999], [77.58573151, 11.92945957], [77.591362, 11.92633057], [77.59596252, 11.92928028], [77.60372162, 11.93026924], [77.61517334, 11.93414974], [77.63021851, 11.93797016], [77.63672638, 11.94026089], [77.63949585, 11.94283199], [77.64341736, 11.94417191], [77.64675903, 11.93871117], [77.6548233, 11.93735886], [77.66044617, 11.93814087], [77.664711, 11.93970013], [77.66371155, 11.95296001], [77.66705322, 11.95893192], [77.67719269, 11.98427105], [77.6810379, 11.99123096], [77.68115234, 11.99123096], [77.68945313, 12.00994968], [77.69410706, 12.01519203], [77.70155334, 12.02714062], [77.70722961, 12.03328133], [77.71264648, 12.04138184], [77.71562195, 12.04850197], [77.72036743, 12.05335236], [77.73396301, 12.06022072], [77.74610138, 12.06932068], [77.75052643, 12.08051014], [77.75634003, 12.09195995], [77.75826263, 12.09440136], [77.76280975, 12.09748173], [77.76638794, 12.1009903], [77.76844788, 12.10559177], [77.76700592, 12.1091404], [77.75282288, 12.11797047], [77.74729156, 12.12232018], [77.74421692, 12.12669182], [77.74024963, 12.12928963], [77.74046326, 12.14258194], [77.73906708, 12.14785957], [77.73195648, 12.15461063], [77.7290802, 12.15995979], [77.72635651, 12.16732025], [77.71951294, 12.17152023], [77.71077728, 12.1733408], [77.7012558, 12.17259979], [77.67282104, 12.18138885], [77.6681366, 12.18371964], [77.65544891, 12.18774986], [77.64466858, 12.18857002], [77.63301086, 12.18642139], [77.62890625, 12.18632126], [77.62561035, 12.1897192], [77.62136841, 12.19170189], [77.61582184, 12.18978119], [77.61051941, 12.19159031], [77.60411835, 12.19516182], [77.59659576, 12.19530106], [77.59113312, 12.19056034], [77.58421326, 12.18884182], [77.56955719, 12.18807125], [77.56533813, 12.19045067], [77.55583191, 12.18711185], [77.54667664, 12.19037056], [77.53852081, 12.19448853], [77.53341675, 12.19383144], [77.53102112, 12.19014072], [77.52805328, 12.19001102], [77.52445221, 12.18824005], [77.51979828, 12.18866158], [77.51130676, 12.18397141], [77.49246216, 12.18719196], [77.48248291, 12.19011974], [77.47875214, 12.19398117], [77.47493744, 12.19582939], [77.46923828, 12.19651127], [77.46566772, 12.20226097], [77.4683609, 12.21019936], [77.47229004, 12.21726036], [77.47366333, 12.22494125], [77.46676636, 12.23398018], [77.46295166, 12.23577118], [77.46350098, 12.24403954], [77.46666718, 12.24847126], [77.46723175, 12.25318241], [77.4701767, 12.26187038], [77.4752121, 12.26597023], [77.47844696, 12.26965141], [77.48423004, 12.2697897], [77.4906311, 12.27305984], [77.49318695, 12.27279091], [77.49796295, 12.2683897], [77.50208282, 12.2663002], [77.51834106, 12.2695303], [77.52352142, 12.28100109], [77.53954315, 12.28239059], [77.54270935, 12.28371143], [77.54515076, 12.29269028], [77.55609894, 12.29716015], [77.56603241, 12.31670094], [77.56859589, 12.32419014], [77.57530975, 12.32625103], [77.58616638, 12.3363018], [77.59120178, 12.3491993], [77.60024261, 12.35122108], [77.60382843, 12.35375118], [77.6063385, 12.36026001], [77.60753632, 12.36765957], [77.60987854, 12.3736496], [77.61094666, 12.38564968], [77.61329651, 12.39780045], [77.61582947, 12.40488052], [77.62008667, 12.40847969], [77.62065125, 12.41376019], [77.61712646, 12.41866112], [77.61694336, 12.42464066], [77.62010193, 12.43809032], [77.61815643, 12.4431324], [77.62169647, 12.45444965], [77.62520599, 12.47726154], [77.61728668, 12.48550987], [77.6108017, 12.4780407], [77.59664917, 12.4646101], [77.57536316, 12.46837997], [77.58249664, 12.47631073], [77.60177612, 12.49166107], [77.60473633, 12.49488163], [77.60636902, 12.49979115], [77.60520172, 12.50333023], [77.59516144, 12.50366974], [77.57850647, 12.50701141], [77.57982635, 12.51148129], [77.57763672, 12.52347088], [77.57644653, 12.5368309], [77.57235718, 12.54042053], [77.5700531, 12.5579319], [77.57119751, 12.56354141], [77.57422638, 12.56723118], [77.58145905, 12.58423138], [77.5821228, 12.60508919], [77.58539581, 12.61193085], [77.59352875, 12.6165514], [77.59781647, 12.62102032], [77.594841, 12.62710953], [77.59552002, 12.63043118], [77.59169006, 12.63275146], [77.58937073, 12.63664246], [77.58796692, 12.6426897], [77.58927917, 12.64825153], [77.59033966, 12.65754128], [77.59783936, 12.65902042], [77.60943604, 12.66335106], [77.6329422, 12.67013073], [77.63878632, 12.67014027], [77.65428925, 12.67416954], [77.67030334, 12.6712389], [77.66590881, 12.66436005], [77.66929626, 12.66193962], [77.66738129, 12.65283012], [77.66780853, 12.65063953], [77.6733017, 12.65042973], [77.67835999, 12.6490202], [77.68753052, 12.65190029], [77.69547272, 12.6512394], [77.70178986, 12.65824986], [77.70381927, 12.67374134], [77.71411133, 12.67027855], [77.71412659, 12.66539097], [77.71531677, 12.6630106], [77.71839905, 12.66198063], [77.7232132, 12.66321182], [77.73140717, 12.66397953], [77.73320007, 12.67189121], [77.730896, 12.67797089], [77.72725677, 12.68287182], [77.73355865, 12.69147968], [77.74001312, 12.68855095], [77.7470932, 12.68664074], [77.75023651, 12.68716145], [77.75598145, 12.69705009], [77.75733948, 12.70398998], [77.76152802, 12.70771027], [77.76303864, 12.71446037], [77.75557709, 12.71557045], [77.75166321, 12.71840096], [77.75306702, 12.72509861], [77.75836945, 12.72931957], [77.76695251, 12.72963047], [77.77807617, 12.73367119], [77.78292084, 12.73882198], [77.78497314, 12.74505138], [77.77829742, 12.74787045], [77.77384949, 12.75113201], [77.77163696, 12.75477791], [77.77162933, 12.75983143], [77.7815094, 12.77103138], [77.78304291, 12.77612019], [77.78793335, 12.78132057], [77.79353333, 12.78387165], [77.7979126, 12.78292084], [77.79949188, 12.78685856], [77.79650116, 12.78961945], [77.79136658, 12.79631996], [77.79441071, 12.80580997], [77.79876709, 12.80491924], [77.80066681, 12.80562973], [77.79868317, 12.8117609], [77.80101776, 12.82080936], [77.79232025, 12.82137012], [77.78803253, 12.82364178], [77.78356171, 12.82825089], [77.78488159, 12.83380985], [77.78859711, 12.83535004], [77.78948975, 12.83877087], [77.79196167, 12.83983135], [77.79981995, 12.83784103], [77.80493927, 12.84275055], [77.80902863, 12.84272957], [77.81362915, 12.84401131], [77.81704712, 12.84898186], [77.82209015, 12.8498497], [77.82224274, 12.85461998], [77.82559967, 12.85898972], [77.83094025, 12.85786057], [77.83644867, 12.85763073], [77.83963013, 12.85585117], [77.84407043, 12.85589027], [77.84944153, 12.85786057], [77.85449982, 12.85673141], [77.85884857, 12.85762024], [77.86219025, 12.85692024], [77.86689758, 12.85861969], [77.87800598, 12.85928059], [77.88226318, 12.85839939], [77.8874588, 12.86692142], [77.89427948, 12.86822891], [77.90052032, 12.86788273], [77.90219879, 12.87337112], [77.90933228, 12.87295246], [77.91436768, 12.87354183], [77.9177475, 12.87837124], [77.92428589, 12.87784004], [77.92900848, 12.87477016], [77.92871857, 12.87143135], [77.91838074, 12.86887169], [77.91967773, 12.86349964], [77.93356323, 12.86168957], [77.93444824, 12.85604], [77.93105316, 12.85621071], [77.92878723, 12.85425091], [77.92780304, 12.85046959], [77.91844177, 12.84736061], [77.91533661, 12.84427071], [77.91487885, 12.83899021], [77.91182709, 12.83243084], [77.90923309, 12.82201958], [77.91047668, 12.81971073], [77.91825104, 12.81921196], [77.92076111, 12.81621933], [77.92479706, 12.8137207], [77.93297577, 12.81292057], [77.93990326, 12.82934856], [77.93612671, 12.83380985], [77.93255615, 12.83963108], [77.93345642, 12.84478092], [77.93860626, 12.84969139], [77.94555664, 12.8493309], [77.94856262, 12.84811974], [77.94684601, 12.83808136], [77.95134735, 12.83786201], [77.95522308, 12.83870983], [77.95800018, 12.83634186], [77.95501709, 12.82516003], [77.95746613, 12.82153034], [77.97129822, 12.82264042], [77.97360229, 12.81816959], [77.97457886, 12.81444168], [77.98134613, 12.81042099], [77.98139954, 12.79564095], [77.98602295, 12.79530144], [77.98972321, 12.79719067], [78.0014801, 12.79543972], [78.00559998, 12.80326939], [78.0032959, 12.80583096], [77.99330139, 12.81367111], [77.9998703, 12.81904125], [78.00382233, 12.8179493], [78.00712585, 12.8200407], [78.00804901, 12.82296085], [78.00711823, 12.82820129], [78.00907898, 12.83370018], [78.01677704, 12.83352947], [78.01685333, 12.83836079], [78.01435852, 12.84298992], [78.0149231, 12.84592056], [78.01957703, 12.84620953], [78.02215576, 12.84122086], [78.04000854, 12.83821106], [78.04202271, 12.8421011], [78.04673004, 12.84237003], [78.05060577, 12.83858204], [78.05139923, 12.83230972], [78.06456757, 12.83016968], [78.06639862, 12.82668114], [78.06594849, 12.81893063], [78.07367706, 12.821311], [78.0761261, 12.82051086], [78.08246613, 12.80915165], [78.08647919, 12.80333996], [78.09514618, 12.80023098], [78.09765625, 12.79592991], [78.10205078, 12.7933979], [78.10946655, 12.79140186], [78.11448669, 12.78707123], [78.117836, 12.77989197], [78.1206665, 12.7700119], [78.12711334, 12.77015972], [78.13163757, 12.76966953], [78.1364975, 12.76916027], [78.14302826, 12.76664066], [78.14771271, 12.76329994], [78.15814209, 12.76022053], [78.16156006, 12.76226139], [78.16615295, 12.76500034], [78.17530823, 12.76331139], [78.17871857, 12.75992012], [78.18395996, 12.76260853], [78.19024658, 12.76107979], [78.19538116, 12.7575407], [78.1989212, 12.75509071], [78.20233917, 12.75507927], [78.21248627, 12.75506973], [78.22064972, 12.75259018], [78.2199173, 12.74962139], [78.21927643, 12.7470293], [78.22886658, 12.72020245], [78.22722626, 12.71517181], [78.22032928, 12.70328999], [78.21382141, 12.70236015], [78.20980835, 12.69926071], [78.20324707, 12.6990099], [78.19999695, 12.69622135], [78.19608307, 12.69668961], [78.19473267, 12.69526958], [78.19934082, 12.68997955], [78.19877625, 12.68871117], [78.18946075, 12.68355083], [78.18984985, 12.6813097], [78.1953125, 12.67996979], [78.19683838, 12.67859077], [78.20011139, 12.67564201], [78.21398926, 12.67475128], [78.22808075, 12.67385101], [78.22664642, 12.68014145], [78.22744751, 12.68928146], [78.23265839, 12.69376087], [78.23906708, 12.69239235], [78.26442719, 12.69184017], [78.26722717, 12.68743038], [78.28418732, 12.66761971], [78.28700256, 12.65814972], [78.28885651, 12.6565609], [78.29045868, 12.65292072], [78.29496765, 12.65424061], [78.30876923, 12.64999962], [78.32235718, 12.63720036], [78.32939911, 12.6384306], [78.33883667, 12.63190079], [78.34835815, 12.62364101], [78.36054993, 12.61511135], [78.36833954, 12.61184025], [78.37420654, 12.61309147], [78.38613892, 12.61387062], [78.3975296, 12.61359024], [78.39955902, 12.61335087], [78.39980316, 12.6133194], [78.40711212, 12.61752033], [78.41233063, 12.61831093], [78.41834259, 12.62064171], [78.42489624, 12.61490059], [78.43943787, 12.61692047], [78.44744873, 12.61650085], [78.45140076, 12.61575127], [78.45478058, 12.61201954], [78.45961761, 12.61740971], [78.46008301, 12.62045956], [78.45907593, 12.63152027], [78.4618988, 12.6322794], [78.46292877, 12.63537025], [78.45935822, 12.63876057], [78.45765686, 12.66224957], [78.47406006, 12.65917969], [78.48855591, 12.66334248], [78.49344635, 12.66959095], [78.4940567, 12.67470074], [78.49711609, 12.67648983], [78.49740601, 12.67924976], [78.49340057, 12.68103027], [78.49357605, 12.68575001], [78.48956299, 12.68660927], [78.48631287, 12.69051075], [78.48754883, 12.69262886], [78.49090576, 12.69329166], [78.49301147, 12.69369984], [78.494133, 12.69794083], [78.49340057, 12.70347023], [78.49492645, 12.70372963], [78.49788666, 12.69851112], [78.49978638, 12.69685173], [78.50389099, 12.6933012], [78.5045929, 12.69800091], [78.5098114, 12.69878006], [78.51051331, 12.70176983], [78.5090332, 12.7049017], [78.49362946, 12.71116924], [78.49146271, 12.71706963], [78.48441315, 12.72305012], [78.47966003, 12.73001957], [78.48435211, 12.73478127], [78.48886108, 12.7319603], [78.4943161, 12.73037148], [78.49710083, 12.72411919], [78.50180054, 12.72150993], [78.50315857, 12.71809959], [78.50356293, 12.71337128], [78.50740814, 12.7130909], [78.5093689, 12.71979141], [78.51094055, 12.72172165], [78.51230621, 12.70800972], [78.51474762, 12.70698929], [78.51618958, 12.70640087], [78.51616669, 12.7062397], [78.51597595, 12.70352077], [78.52641296, 12.70123005], [78.52745819, 12.69730091], [78.52561188, 12.69474983], [78.52085876, 12.6971817], [78.51853943, 12.69237995], [78.52015686, 12.6870079], [78.52436829, 12.67969036], [78.52774811, 12.67900181], [78.53127289, 12.67993164], [78.53978729, 12.68422127], [78.54135895, 12.68501186], [78.54371643, 12.68460083], [78.54467773, 12.68443966], [78.54767609, 12.68559074], [78.54773712, 12.68911171], [78.54509735, 12.6926012], [78.54801178, 12.69536972], [78.55195618, 12.69433975], [78.55224609, 12.6970911], [78.54931641, 12.70070076], [78.54550934, 12.70738125], [78.54824829, 12.71498013], [78.55224609, 12.72039127], [78.55393219, 12.72606087], [78.55088806, 12.72622967], [78.54564667, 12.72861195], [78.55030823, 12.73876095], [78.54554749, 12.74391079], [78.54663086, 12.74560928], [78.55091858, 12.74680996], [78.55406189, 12.74606991], [78.5581131, 12.7516489], [78.56157684, 12.75257015], [78.56684875, 12.75214958], [78.56572723, 12.75901127], [78.57765961, 12.76585007], [78.5800705, 12.76724052], [78.5819397, 12.77077103], [78.58290863, 12.77622032], [78.58251953, 12.78532124], [78.58976746, 12.79244995], [78.59060669, 12.7979002], [78.5881958, 12.80478001], [78.59767151, 12.81107998], [78.59562683, 12.81548977], [78.59379578, 12.83300114], [78.59229279, 12.83677006], [78.59156799, 12.83854961], [78.59900665, 12.84947014], [78.60443115, 12.8574419], [78.60462189, 12.86600018], [78.60597229, 12.87369919], [78.61222839, 12.88856125], [78.61554718, 12.89321995], [78.61965179, 12.90207195], [78.62477112, 12.91418076], [78.62570953, 12.91918182], [78.62770081, 12.91792107], [78.6307373, 12.91597939], [78.63746643, 12.91588116], [78.64671326, 12.9190197], [78.63566589, 12.93834019], [78.6289978, 12.95311069], [78.63791656, 12.9544096], [78.62024689, 12.97391033], [78.61366272, 12.97889042], [78.62049866, 12.98252106], [78.62837982, 12.9897213], [78.63733673, 12.99684143], [78.641716, 13.00161076], [78.64505005, 13.00731087], [78.6489563, 13.0163517], [78.65110779, 13.01793194], [78.66861725, 13.01105976], [78.67935944, 13.00897026], [78.6937561, 13.00439167], [78.69597626, 13.01252079], [78.7012558, 13.04426003], [78.70244598, 13.05615139], [78.72550201, 13.05278015], [78.73217773, 13.05040264], [78.73951721, 13.04549122], [78.74601746, 13.0454092], [78.7544632, 13.04698181], [78.77752686, 13.05315971], [78.7830658, 13.05637169], [78.78659058, 13.06215191], [78.79418182, 13.06975937], [78.8008728, 13.07553005], [78.80809021, 13.07793045], [78.81342316, 13.0746479], [78.83226776, 13.06959057], [78.84393311, 13.0714798], [78.85835266, 13.07106972], [78.86068726, 13.0795002], [78.86473846, 13.08468056], [78.87032318, 13.08692074], [78.8760376, 13.08615971], [78.88352203, 13.08198929], [78.88040924, 13.06960201], [78.88088989, 13.04428101], [78.87937164, 13.02550125], [78.88191986, 13.01976204], [78.8901062, 13.01982975], [78.9159317, 13.02306175], [78.92299652, 13.02176094], [78.92463684, 13.01864147], [78.9286499, 13.021451], [78.92745972, 13.02346134], [78.92043304, 13.02862072], [78.91739655, 13.03254986], [78.90439606, 13.03105068], [78.89839935, 13.0316906], [78.89346313, 13.03509235], [78.90091705, 13.05210114], [78.90867615, 13.05045986], [78.9108429, 13.05610085], [78.91204071, 13.06328201], [78.91438293, 13.06776142], [78.9300766, 13.06602192], [78.93663788, 13.06997108], [78.94584656, 13.06350994], [78.95001221, 13.06608963], [78.95509338, 13.06492996], [78.95918274, 13.06544018], [78.9629364, 13.07155991], [78.96465302, 13.07279968], [78.97167969, 13.07511997], [78.97959137, 13.07651043], [78.98174286, 13.07619953], [78.98825073, 13.07265186], [78.99523926, 13.06304073], [79.00036621, 13.05788136], [79.01142883, 13.05782986], [79.02281952, 13.05640125], [79.02588654, 13.04957962], [79.03353882, 13.04566002], [79.04389191, 13.04372025], [79.05326843, 13.03799057], [79.05397797, 13.02816105], [79.06057739, 13.02083969], [79.06906891, 13.01415062], [79.08278656, 13.0124712], [79.10437775, 13.02422047], [79.11927032, 13.02256966], [79.13114929, 13.01676273], [79.14163208, 13.00981998], [79.15270233, 13.00729275], [79.16120148, 13.01179886], [79.17059326, 13.01568031], [79.17310333, 13.01928139], [79.1743927, 13.02525043], [79.17662048, 13.0297699], [79.17697144, 13.03337955], [79.17653656, 13.03827095], [79.17227173, 13.04372025], [79.17473602, 13.04967976], [79.16942596, 13.05300999], [79.17910004, 13.060112], [79.18065643, 13.06704044], [79.1835022, 13.07294083], [79.18699646, 13.07705021], [79.18891907, 13.08461857], [79.19332123, 13.08969021], [79.20220947, 13.09029007], [79.20744324, 13.09144115], [79.2142868, 13.0968399], [79.21827698, 13.10394192], [79.21827698, 13.1103096], [79.22244263, 13.11600971], [79.21826935, 13.12043095], [79.21466064, 13.12767029], [79.21832275, 13.13555145], [79.22635651, 13.13461018], [79.23304749, 13.12769985], [79.23670197, 13.1267519], [79.24333954, 13.13335037], [79.24423981, 13.14115143], [79.2472229, 13.14808178], [79.25137329, 13.14619923], [79.25267029, 13.14129925], [79.25646973, 13.13654041], [79.26120758, 13.14074993], [79.26741028, 13.14120102], [79.27128601, 13.13806057], [79.27266693, 13.12666035], [79.27384949, 13.12090111], [79.27751923, 13.11972046], [79.28495026, 13.12285042], [79.2881012, 13.11828041], [79.29876709, 13.11483192], [79.29747009, 13.0973711], [79.30793762, 13.09691143], [79.31002808, 13.0999403], [79.30973053, 13.10690022], [79.31239319, 13.11376953], [79.31672668, 13.11936855], [79.33068848, 13.12123108], [79.33531952, 13.12751007], [79.33779144, 13.12317085], [79.34435272, 13.12356091], [79.35009766, 13.12545013], [79.35457611, 13.12977123], [79.34674835, 13.13486099], [79.34686279, 13.14015102], [79.34783936, 13.14381981], [79.34709167, 13.15395069], [79.34777069, 13.16301918], [79.35472107, 13.16133976], [79.36120605, 13.15604115], [79.36493683, 13.16037083], [79.36717224, 13.16558075], [79.37078094, 13.16858959], [79.3690033, 13.17626095], [79.37835693, 13.18243122], [79.38437653, 13.18472099], [79.39256287, 13.18446159], [79.3979187, 13.18642235], [79.41329193, 13.18584919], [79.42059326, 13.18446159], [79.42378998, 13.1874609], [79.42156982, 13.19318104], [79.42315674, 13.19891071], [79.42315674, 13.2038002], [79.42163086, 13.20853138], [79.44550323, 13.21677113], [79.4454422, 13.2217207], [79.44245911, 13.22918034], [79.43609619, 13.2298317], [79.42690277, 13.22274017], [79.41816711, 13.21846199], [79.41699982, 13.21220112], [79.4108429, 13.21216202], [79.40865326, 13.21959019], [79.40968323, 13.22815037], [79.407341, 13.23766136], [79.40866852, 13.24674129], [79.41230011, 13.25751019], [79.41902161, 13.2663393], [79.41799164, 13.26906109], [79.41837311, 13.27458954], [79.42502594, 13.2813406], [79.42177582, 13.28666019], [79.40542603, 13.28541088], [79.39897919, 13.28915119], [79.38562775, 13.29470062], [79.37460327, 13.30303955], [79.40139771, 13.31575108], [79.41732025, 13.32195854], [79.42887878, 13.32356167], [79.45464325, 13.32432079], [79.47927856, 13.32145977], [79.48722839, 13.31655121], [79.49781036, 13.31482124], [79.50953674, 13.31470013], [79.52271271, 13.31593132], [79.53578186, 13.31107044], [79.53887177, 13.30092144], [79.53922272, 13.28975964], [79.54144287, 13.27893162], [79.54634094, 13.27404976], [79.54872894, 13.26712132], [79.55478668, 13.25918102], [79.56537628, 13.24940109], [79.570961, 13.2473793], [79.58026123, 13.24537086], [79.5854187, 13.24710083], [79.58644867, 13.25348091], [79.58867645, 13.26041126], [79.59485626, 13.26304245], [79.60114288, 13.26772976], [79.60510254, 13.26736069], [79.61075592, 13.26459122], [79.61519623, 13.26045036], [79.62075806, 13.25895023], [79.62431335, 13.26202011], [79.62956238, 13.26086044], [79.63072205, 13.26815987], [79.63250732, 13.2735424], [79.63848114, 13.2761898], [79.64376831, 13.2733593], [79.64862823, 13.2733593], [79.65338135, 13.27456856], [79.65740204, 13.2684803], [79.66256714, 13.26814175], [79.66590118, 13.27327919], [79.66853333, 13.28193092], [79.67932129, 13.26933193], [79.68161011, 13.26555061], [79.68430328, 13.25667953], [79.67376709, 13.24702072], [79.67111206, 13.23584175], [79.67331696, 13.22949028], [79.68068695, 13.22837067], [79.68456268, 13.23384953], [79.69193268, 13.23852921], [79.69603729, 13.23389053], [79.69574738, 13.2237606], [79.68943787, 13.21125031], [79.68875122, 13.20740986], [79.69243622, 13.20753098], [79.69963837, 13.20268059], [79.70568848, 13.20923138], [79.71142578, 13.21047974], [79.71570587, 13.21440029], [79.71856689, 13.2225914], [79.72283173, 13.22185135], [79.72651672, 13.21738052], [79.73252869, 13.21496105], [79.73368073, 13.21023178], [79.73750305, 13.20552063], [79.73826599, 13.19825935], [79.74437714, 13.194911], [79.75183105, 13.20477962], [79.75772095, 13.20557117], [79.76333618, 13.20885086], [79.76716614, 13.21333981], [79.7735672, 13.21751976], [79.77733612, 13.2171917], [79.78325653, 13.21791935], [79.78489685, 13.22348022], [79.78325653, 13.22816181], [79.77539063, 13.23411942], [79.7527771, 13.24376011], [79.74558258, 13.24821091], [79.73938751, 13.25443077], [79.72177887, 13.26573086], [79.72129059, 13.27223969], [79.72963715, 13.27507973], [79.74149323, 13.27666187], [79.74614716, 13.28000069], [79.74975586, 13.29088116], [79.75055695, 13.29881001], [79.75405884, 13.30278969], [79.76835632, 13.28962994], [79.77422333, 13.28513145], [79.77980042, 13.28207016], [79.78727722, 13.28462029], [79.79226685, 13.29164028], [79.7950058, 13.29857063], [79.80029297, 13.30432129], [79.80848694, 13.30508041], [79.82404327, 13.30231953], [79.83059692, 13.30206013], [79.8367691, 13.30299854], [79.83905792, 13.30334091], [79.85116577, 13.3034296], [79.85568237, 13.30814075], [79.8588562, 13.31374073], [79.86519623, 13.31072998], [79.87055206, 13.31175995], [79.87496185, 13.31740093], [79.88015747, 13.32043934], [79.88607788, 13.32129192], [79.8917923, 13.32461929], [79.89736176, 13.32948971], [79.903862, 13.33327103], [79.90628815, 13.33905125], [79.91068268, 13.34370041], [79.91713715, 13.34103966], [79.92550659, 13.33594036], [79.9287262, 13.34353065], [79.93998718, 13.35811138], [79.94064331, 13.36098099], [79.93974304, 13.36910057], [79.94803619, 13.36722088], [79.95358276, 13.37411118], [79.95028687, 13.38197136], [79.93562317, 13.38484955], [79.93557739, 13.39059067], [79.93247986, 13.40437126], [79.93595123, 13.40957165], [79.94426727, 13.41078186], [79.95085144, 13.40812016], [79.95848083, 13.41285133], [79.96322632, 13.41791058], [79.96102142, 13.42766094], [79.9630661, 13.44057274], [79.96218872, 13.44413853], [79.96186066, 13.45127964], [79.96826935, 13.45643139], [79.98747253, 13.46191025], [79.99056244, 13.46205997], [79.9907608, 13.45921993], [79.99537659, 13.45945072], [80.00440216, 13.47826004], [80.00589752, 13.48777103], [80.01885223, 13.48637199], [80.02481842, 13.48670006], [80.03604126, 13.4844799], [80.0371933, 13.49282169], [80.03697968, 13.49935055], [80.03275299, 13.50183964], [80.0256424, 13.5039711], [80.01908875, 13.50166035], [80.01361847, 13.50391197], [80.00842285, 13.50830173], [80.00623322, 13.51506233], [80.00039673, 13.51237202], [79.99017334, 13.51009083], [79.98973846, 13.51300144], [79.9892807, 13.51900005], [79.98967743, 13.5267601], [79.994133, 13.52960014], [80.00771332, 13.53237247], [80.01449585, 13.52849007], [80.01754761, 13.52513123], [80.0295105, 13.52359009], [80.03409576, 13.52180099], [80.04541779, 13.52198124], [80.05098724, 13.53051186], [80.05950928, 13.5325489], [80.06561279, 13.53476048], [80.06717682, 13.53592014], [80.06944275, 13.53759098], [80.07276154, 13.53392124], [80.07582092, 13.5267601], [80.07627869, 13.52612019], [80.07943726, 13.52936077], [80.08672333, 13.52724075], [80.08766937, 13.52661037], [80.0879364, 13.52595997], [80.08866882, 13.52552986], [80.09377289, 13.5135603], [80.09565735, 13.50984001], [80.09670258, 13.50821018], [80.09942627, 13.50631046], [80.10035706, 13.50520039], [80.10504913, 13.50363159], [80.10691071, 13.50394154], [80.11687469, 13.50280857], [80.11819458, 13.5084734], [80.11819458, 13.5065279], [80.11846924, 13.50653076], [80.11846924, 13.50624084], [80.11902618, 13.50625038], [80.11902618, 13.50597191], [80.12014008, 13.50597191], [80.12014008, 13.50569439], [80.12124634, 13.50569439], [80.12124634, 13.50541592], [80.12236023, 13.50542068], [80.12236023, 13.5051403], [80.12317657, 13.5051403], [80.12317657, 13.50542068], [80.12430573, 13.50541592], [80.12430573, 13.50569439], [80.12541962, 13.50569439], [80.12541962, 13.50625038], [80.12569427, 13.50625038], [80.12569427, 13.50708199], [80.12596893, 13.50708008], [80.12596893, 13.50764084], [80.12625122, 13.50763798], [80.12625122, 13.5084734], [80.12652588, 13.50846958], [80.12652588, 13.50931072], [80.12680817, 13.50931072], [80.12680817, 13.51125145], [80.12652588, 13.51125145], [80.12652588, 13.51319504], [80.12625122, 13.51319504], [80.12625122, 13.51347256], [80.12596893, 13.51347065], [80.12596893, 13.51375103], [80.12541962, 13.51375103], [80.12541962, 13.51403141], [80.12513733, 13.51403141], [80.12513733, 13.51431179], [80.12486267, 13.51430511], [80.12486267, 13.51569462], [80.12513733, 13.51569462], [80.12513733, 13.51597309], [80.12541962, 13.51597118], [80.12541962, 13.51653194], [80.12568665, 13.51653194], [80.12568665, 13.51681042], [80.12680817, 13.5168047], [80.12680817, 13.51708317], [80.12847137, 13.51708317], [80.12847137, 13.5168047], [80.12902832, 13.51681042], [80.12902832, 13.51653194], [80.12985992, 13.51653194], [80.12985992, 13.51625061], [80.13041687, 13.51625061], [80.13041687, 13.51597118], [80.13097382, 13.51597309], [80.13097382, 13.51569462], [80.13153076, 13.51569462], [80.13153076, 13.5154171], [80.13180542, 13.5154171], [80.13180542, 13.51513863], [80.13237, 13.51514053], [80.13237, 13.51486111], [80.13291931, 13.51486111], [80.13291931, 13.51458263], [80.13319397, 13.51458263], [80.13319397, 13.51430511], [80.13375092, 13.51431179], [80.13375092, 13.51403141], [80.1340332, 13.51403141], [80.1340332, 13.51375103], [80.13430786, 13.51375103], [80.13430786, 13.51347065], [80.13486481, 13.51347256], [80.13486481, 13.51319504], [80.13513947, 13.51319504], [80.13513947, 13.51291656], [80.13569641, 13.51292133], [80.13569641, 13.51264095], [80.13597107, 13.51264095], [80.13597107, 13.51237202], [80.13817596, 13.51237202], [80.13817596, 13.51208019], [80.13847351, 13.51208305], [80.13847351, 13.51180458], [80.13874817, 13.51180935], [80.13874817, 13.51153088], [80.13903046, 13.51153088], [80.13903046, 13.51125145], [80.13931274, 13.51125145], [80.13931274, 13.51068974], [80.13957977, 13.51069546], [80.13957977, 13.51041698], [80.13986206, 13.51041889], [80.13986206, 13.51014137], [80.14013672, 13.51014137], [80.14013672, 13.50986099], [80.14041901, 13.50986099], [80.14041901, 13.50957966], [80.14069366, 13.50958157], [80.14069366, 13.50930691], [80.14097595, 13.50931072], [80.14097595, 13.5090313], [80.14125061, 13.5090313], [80.14125061, 13.50875092], [80.14154053, 13.50875092], [80.14154053, 13.50846958], [80.14180756, 13.5084734], [80.14180756, 13.50819397], [80.14208221, 13.50819397], [80.14208221, 13.50791645], [80.14235687, 13.50792122], [80.14235687, 13.50764084], [80.14263916, 13.50764084], [80.14263916, 13.50736046], [80.14291382, 13.50736046], [80.14291382, 13.50708199], [80.14319611, 13.50708199], [80.14319611, 13.5065279], [80.14347076, 13.50653076], [80.14347076, 13.50597], [80.14375305, 13.50597191], [80.14375305, 13.50541592], [80.14402771, 13.50542068], [80.14402771, 13.50457954], [80.14430237, 13.50458431], [80.14430237, 13.50402832], [80.14457703, 13.50403118], [80.14457703, 13.50347042], [80.14485931, 13.50347233], [80.14485931, 13.50291634], [80.1451416, 13.5029211], [80.1451416, 13.50208187], [80.14541626, 13.50208378], [80.14541626, 13.50152779], [80.14569092, 13.50152969], [80.14569092, 13.50097179], [80.14597321, 13.50097179], [80.14597321, 13.50043201], [80.14624786, 13.50043201], [80.14624786, 13.49985981], [80.14653015, 13.49985981], [80.14653015, 13.49930573], [80.14679718, 13.49930954], [80.14679718, 13.49874973], [80.1470871, 13.49874973], [80.1470871, 13.49819088], [80.14736176, 13.49819374], [80.14736176, 13.49791622], [80.14763641, 13.49792004], [80.14763641, 13.49737072], [80.1479187, 13.49737072], [80.1479187, 13.4970789], [80.14819336, 13.49708366], [80.14819336, 13.49680614], [80.14875031, 13.49680996], [80.14875031, 13.49652958], [80.14903259, 13.49652958], [80.14903259, 13.49625015], [80.14958191, 13.49625015], [80.14958191, 13.49597073], [80.1498642, 13.49597359], [80.1498642, 13.49569321], [80.15013885, 13.49569321], [80.15013885, 13.49541759], [80.1506958, 13.49542046], [80.1506958, 13.49514198], [80.15097046, 13.49514198], [80.15097046, 13.4948616], [80.1515274, 13.4948616], [80.1515274, 13.49458122], [80.15180206, 13.49458313], [80.15180206, 13.49430466], [80.15235901, 13.49430466], [80.15235901, 13.49402714], [80.15319061, 13.49403191], [80.15319824, 13.49375153], [80.15429687, 13.49375153], [80.15429687, 13.49347115], [80.15486145, 13.49347115], [80.15486145, 13.49319553], [80.15569305, 13.49319553], [80.15569305, 13.49291706], [80.15625, 13.49292183], [80.15625, 13.49263859], [80.1570816, 13.49263859], [80.1570816, 13.49236107], [80.15735626, 13.49236107], [80.15735626, 13.49208069], [80.15763855, 13.4920826], [80.15763855, 13.49180508], [80.15791321, 13.49181175], [80.15791321, 13.49152946], [80.15847015, 13.49152946], [80.15847015, 13.49123955], [80.15875244, 13.49124908], [80.15875244, 13.49097347], [80.1590271, 13.49097347], [80.1590271, 13.49069309], [80.15958405, 13.49069309], [80.15958405, 13.49041653], [80.16014099, 13.49042034], [80.16014099, 13.49014091], [80.1609726, 13.49014091], [80.1609726, 13.48986053], [80.16152954, 13.48986053], [80.16152954, 13.48958302], [80.1626358, 13.48958302], [80.1626358, 13.48986053], [80.16374969, 13.48986053], [80.16374969, 13.49014091], [80.1645813, 13.49014091], [80.1645813, 13.49042034], [80.16569519, 13.49041653], [80.16569519, 13.49069309], [80.16708374, 13.49069309], [80.16708374, 13.49041653], [80.1673584, 13.49042034], [80.1673584, 13.49014091], [80.16792297, 13.49014091], [80.16792297, 13.48986053], [80.16819763, 13.48986053], [80.16819763, 13.49014091], [80.16847992, 13.49014091], [80.16847992, 13.49042034], [80.16902924, 13.49041653], [80.16902924, 13.49069309], [80.16930389, 13.49069309], [80.16930389, 13.49097347], [80.16958618, 13.49097347], [80.16958618, 13.49124908], [80.16986084, 13.49123955], [80.16986084, 13.49152946], [80.17041779, 13.49152946], [80.17041779, 13.49181175], [80.17069244, 13.49180508], [80.17069244, 13.4920826], [80.1709671, 13.49208069], [80.1709671, 13.49236107], [80.17151642, 13.49236107], [80.17151642, 13.49263859], [80.17208099, 13.49263859], [80.17208099, 13.49292183], [80.17263794, 13.49291706], [80.17263794, 13.49319553], [80.17319489, 13.49319553], [80.17319489, 13.49347115], [80.17375183, 13.49347115], [80.17375183, 13.49375153], [80.17430878, 13.49375153], [80.17430878, 13.49403191], [80.17514038, 13.49402714], [80.17514038, 13.49430466], [80.17624664, 13.49430466], [80.17624664, 13.49458313], [80.17708588, 13.49458122], [80.17708588, 13.4948616], [80.17958069, 13.4948616], [80.17958069, 13.49458122], [80.18125153, 13.49458313], [80.18125153, 13.49430466], [80.18152618, 13.49430466], [80.18152618, 13.49374866], [80.18180847, 13.49375153], [80.18180847, 13.49347115], [80.18208313, 13.49347115], [80.18208313, 13.49319553], [80.18264008, 13.49319553], [80.18264008, 13.49291706], [80.18319702, 13.49292183], [80.18319702, 13.49263859], [80.18345642, 13.49263859], [80.18345642, 13.49236107], [80.18402863, 13.49236107], [80.18402863, 13.49208069], [80.18458557, 13.4920826], [80.18458557, 13.49180508], [80.18569183, 13.49181175], [80.18569183, 13.49152946], [80.18763733, 13.49152946], [80.18763733, 13.49123955], [80.18930817, 13.49124908], [80.18930817, 13.49097347], [80.19097137, 13.49097347], [80.19097137, 13.49069309], [80.19264221, 13.49069309], [80.19264221, 13.49041653], [80.19403076, 13.49042034], [80.19403076, 13.49014091], [80.19568634, 13.49014091], [80.19568634, 13.48986053], [80.19736481, 13.48986053], [80.19736481, 13.48958302], [80.19902802, 13.48958302], [80.19902802, 13.48930454], [80.20069122, 13.48931026], [80.20069122, 13.48903179], [80.20236206, 13.48903179], [80.20236206, 13.48875141], [80.2040329, 13.48875141], [80.2040329, 13.48847103], [80.2048645, 13.48847103], [80.2048645, 13.48819542], [80.20569611, 13.48820019], [80.20569611, 13.48792171], [80.20652771, 13.48792171], [80.20652771, 13.48764133], [80.20764923, 13.48764133], [80.20764923, 13.48736095], [80.20847321, 13.48736095], [80.20847321, 13.48708057], [80.20930481, 13.48708344], [80.20930481, 13.48680496], [80.21153259, 13.48681164], [80.21153259, 13.48653126], [80.2140274, 13.48653126], [80.2140274, 13.48625088], [80.21624756, 13.48625088], [80.21624756, 13.48597145], [80.22569275, 13.48597336], [80.22569275, 13.48569489], [80.22624969, 13.48569489], [80.22624969, 13.48541737], [80.2270813, 13.48542976], [80.2270813, 13.48513889], [80.2279129, 13.48513889], [80.2279129, 13.48486137], [80.22846985, 13.48486137], [80.22846985, 13.48513889], [80.2298584, 13.48513889], [80.2298584, 13.48542976], [80.23014069, 13.48542976], [80.23014069, 13.48513889], [80.23042297, 13.48513889], [80.23042297, 13.48486137], [80.23097229, 13.48486137], [80.23097229, 13.4845829], [80.23124695, 13.4845829], [80.23124695, 13.48430538], [80.23430634, 13.4843092], [80.23430634, 13.48403072], [80.23707581, 13.48403072], [80.23707581, 13.4843092], [80.23735809, 13.48430538], [80.23735809, 13.4845829], [80.23708344, 13.4845829], [80.23708344, 13.48486137], [80.23680878, 13.48486137], [80.23680878, 13.48513889], [80.23652649, 13.48513889], [80.23652649, 13.48542976], [80.23625183, 13.48541737], [80.23625183, 13.48569489], [80.23596954, 13.48569489], [80.23596954, 13.48597336], [80.23542023, 13.48597145], [80.23542023, 13.48625088], [80.23486328, 13.48625088], [80.23486328, 13.48681164], [80.23457336, 13.48681164], [80.23457336, 13.48736095], [80.23430634, 13.48736095], [80.23430634, 13.48792171], [80.23652649, 13.48792171], [80.23652649, 13.48764133], [80.23680878, 13.48764133], [80.23680878, 13.48736095], [80.23735809, 13.48736095], [80.23735809, 13.48708057], [80.23764038, 13.48708344], [80.23764038, 13.48680496], [80.23819733, 13.48681164], [80.23819733, 13.48653126], [80.23847198, 13.48653126], [80.23847198, 13.48625088], [80.23874664, 13.48625088], [80.23874664, 13.48604965], [80.23874664, 13.48597336], [80.2390213, 13.48597336], [80.23902893, 13.48541737], [80.23929596, 13.48542976], [80.23929596, 13.48513889], [80.23958588, 13.48513889], [80.23958588, 13.48486137], [80.23986053, 13.48486137], [80.23986053, 13.48430538], [80.24014282, 13.4843092], [80.24014282, 13.4837513], [80.24041748, 13.4837513], [80.24041748, 13.48318958], [80.24069214, 13.4831953], [80.24069214, 13.48263931], [80.2409668, 13.48264122], [80.2409668, 13.48208046], [80.24153137, 13.48208237], [80.24153137, 13.48180676], [80.24208069, 13.48181057], [80.24208069, 13.48153114], [80.24263763, 13.48153114], [80.24263763, 13.48125076], [80.24291992, 13.48125076], [80.24291992, 13.48097038], [80.24346924, 13.48097229], [80.24346924, 13.48069382], [80.24402618, 13.48069382], [80.24402618, 13.4804163], [80.24458313, 13.48042107], [80.24458313, 13.48014069], [80.24485779, 13.48014069], [80.24485779, 13.47986031], [80.24514008, 13.47986031], [80.24514008, 13.47958469], [80.24541473, 13.47958469], [80.24541473, 13.47930431], [80.24569702, 13.47930431], [80.24569702, 13.47902775], [80.24597168, 13.47903061], [80.24597168, 13.47846985], [80.24624634, 13.47847176], [80.24624634, 13.47819424], [80.24652863, 13.47819424], [80.24652863, 13.47791576], [80.24680328, 13.47792053], [80.24680328, 13.47764015], [80.2470932, 13.47764015], [80.2470932, 13.47735977], [80.24736023, 13.47735977], [80.24736023, 13.4756918], [80.24764252, 13.4756937], [80.24764252, 13.47541809], [80.24736023, 13.47542095], [80.24736023, 13.47431087], [80.2470932, 13.47431087], [80.2470932, 13.47346973], [80.24680328, 13.47347164], [80.24680328, 13.47319412], [80.2470932, 13.4732008], [80.2470932, 13.47292042], [80.24736023, 13.47292042], [80.24736023, 13.47264004], [80.24986267, 13.47264004], [80.24986267, 13.47235966], [80.25041962, 13.47235966], [80.25041962, 13.47207928], [80.25152588, 13.47207928], [80.25152588, 13.47235966], [80.25319672, 13.47235966], [80.25319672, 13.47264004], [80.25347137, 13.47264004], [80.25347137, 13.47292042], [80.25402832, 13.47292042], [80.25402832, 13.4732008], [80.25430298, 13.47319412], [80.25430298, 13.47347164], [80.2545929, 13.47346973], [80.2545929, 13.47375202], [80.25485992, 13.47375202], [80.25485992, 13.47402954], [80.25514221, 13.47402954], [80.25514221, 13.47431087], [80.25930786, 13.47431087], [80.25930786, 13.47402954], [80.25985718, 13.47402954], [80.25985718, 13.47375202], [80.26040649, 13.47375202], [80.26040649, 13.47346973], [80.26097107, 13.47347164], [80.26097107, 13.47319412], [80.26152802, 13.4732008], [80.26152802, 13.47292042], [80.26209259, 13.47292042], [80.26209259, 13.47264004], [80.26235962, 13.47264004], [80.26235962, 13.47207928], [80.26264191, 13.47208405], [80.26264191, 13.47180557], [80.26291656, 13.47181034], [80.26291656, 13.47152996], [80.26319122, 13.47152996], [80.26319122, 13.4709692], [80.26347351, 13.47097206], [80.26347351, 13.47069359], [80.26374817, 13.47069359], [80.26374817, 13.47041798], [80.26403046, 13.47042179], [80.26403046, 13.46986198], [80.26431274, 13.46986198], [80.26430511, 13.46958447], [80.26457977, 13.46958447], [80.26457977, 13.46902847], [80.26486969, 13.46903038], [80.26486969, 13.46847057], [80.26513672, 13.46847057], [80.26513672, 13.4679184], [80.26541901, 13.4679203], [80.26541901, 13.46764183], [80.26568604, 13.46764183], [80.26568604, 13.46736145], [80.26625061, 13.46736145], [80.26625061, 13.46708298], [80.26652527, 13.46708298], [80.26652527, 13.46680546], [80.26708221, 13.46681023], [80.26708221, 13.46291924], [80.26735687, 13.46291924], [80.26735687, 13.45931244], [80.26680756, 13.45931244], [80.26680756, 13.45875072], [80.26708221, 13.45875072], [80.26708221, 13.45819855], [80.26735687, 13.45819855], [80.26735687, 13.45792103], [80.26763916, 13.45792103], [80.26763916, 13.45764065], [80.26819611, 13.45764065], [80.26819611, 13.45736122], [80.26847076, 13.45736122], [80.26847076, 13.45708275], [80.26902771, 13.45708275], [80.26902771, 13.45485973], [80.26930237, 13.45485973], [80.26930237, 13.45431137], [80.26957703, 13.45431137], [80.26957703, 13.45374966], [80.26985931, 13.45374966], [80.26985931, 13.45318985], [80.2701416, 13.45319366], [80.2701416, 13.45263767], [80.27041626, 13.45264053], [80.27041626, 13.45207119], [80.27069092, 13.45208359], [80.27069092, 13.4515276], [80.27097321, 13.45153141], [80.27097321, 13.4509697], [80.27124786, 13.4509716], [80.27124786, 13.45041561], [80.27153015, 13.45042133], [80.27153015, 13.44985962], [80.27180481, 13.44986153], [80.27180481, 13.44902802], [80.2720871, 13.44902992], [80.2720871, 13.44847202], [80.27236176, 13.44847202], [80.27236176, 13.44763756], [80.27263641, 13.44764042], [80.27263641, 13.44708157], [80.2729187, 13.44708443], [80.2729187, 13.44652843], [80.27319336, 13.44653034], [80.27319336, 13.4456892], [80.27347565, 13.44569397], [80.27347565, 13.44513988], [80.27374268, 13.44514179], [80.27374268, 13.44458199], [80.27402496, 13.44458389], [80.27402496, 13.44430637], [80.27430725, 13.44431019], [80.27430725, 13.44402981], [80.27458191, 13.44402981], [80.27458191, 13.44375038], [80.27485657, 13.44375038], [80.27485657, 13.44347191], [80.27513885, 13.44347191], [80.27513885, 13.44319439], [80.27541351, 13.44319439], [80.27541351, 13.44291782], [80.2756958, 13.44291973], [80.2756958, 13.44236183], [80.27597046, 13.44236183], [80.27597046, 13.44208145], [80.27625275, 13.44208431], [80.27625275, 13.44180584], [80.2765274, 13.44180965], [80.2765274, 13.44153023], [80.27680969, 13.44153023], [80.27680969, 13.44124889], [80.27708435, 13.44124889], [80.27707672, 13.44097137], [80.27735901, 13.44097137], [80.27735901, 13.44069576], [80.2776413, 13.44069576], [80.2776413, 13.44041538], [80.27707672, 13.44042015], [80.27707672, 13.44013023], [80.27625275, 13.44013977], [80.27625275, 13.4398613], [80.27708435, 13.4398613], [80.27708435, 13.43958282], [80.27791595, 13.43958282], [80.27791595, 13.43930531], [80.27874756, 13.43931007], [80.27874756, 13.43902969], [80.27986908, 13.43902969], [80.27986908, 13.43874931], [80.28069305, 13.43874931], [80.28069305, 13.43819141], [80.28097534, 13.43819523], [80.28097534, 13.43763924], [80.27874756, 13.43763924], [80.27874756, 13.43791962], [80.27540588, 13.43791962], [80.27540588, 13.43736076], [80.27513885, 13.43736076], [80.27513885, 13.43514061], [80.27540588, 13.43514061], [80.27540588, 13.43153095], [80.27513885, 13.43153095], [80.27513885, 13.43096066], [80.2748642, 13.43097305], [80.2748642, 13.43069458], [80.27458191, 13.43069458], [80.27458191, 13.43041706], [80.27430725, 13.43042088], [80.27430725, 13.42986107], [80.27402496, 13.42986107], [80.27402496, 13.4295826], [80.27375031, 13.4295826], [80.27375031, 13.42902565], [80.27348328, 13.42903137], [80.27348328, 13.42875099], [80.27319336, 13.42875099], [80.27319336, 13.42846966], [80.2729187, 13.42847347], [80.2729187, 13.42791557], [80.27263641, 13.4279213], [80.27263641, 13.42764091], [80.27236176, 13.42764091], [80.27236176, 13.42735958], [80.2720871, 13.42735958], [80.2720871, 13.4268074], [80.27179718, 13.42681122], [80.27179718, 13.42625046], [80.27153015, 13.42625046], [80.27153015, 13.4256897], [80.27124786, 13.42569447], [80.27124786, 13.42513847], [80.27097321, 13.42515182], [80.27097321, 13.42457962], [80.27069092, 13.42458439], [80.27069092, 13.4240284], [80.27041626, 13.42403126], [80.27041626, 13.42346954], [80.2701416, 13.4234724], [80.2701416, 13.42291641], [80.26985931, 13.42292118], [80.26985931, 13.42209053], [80.26957703, 13.42209053], [80.26957703, 13.42097187], [80.26930237, 13.42097187], [80.26930237, 13.42014027], [80.26902771, 13.42014027], [80.26902771, 13.41930962], [80.26875305, 13.41930962], [80.26875305, 13.41819096], [80.26847076, 13.41819382], [80.26847076, 13.41736221], [80.26875305, 13.41736031], [80.26875305, 13.41763973], [80.26902771, 13.41763973], [80.26902771, 13.41819382], [80.26930237, 13.41819096], [80.26930237, 13.41874981], [80.26957703, 13.41874981], [80.26957703, 13.41930962], [80.26985931, 13.41930962], [80.26985931, 13.41986179], [80.2701416, 13.41985989], [80.2701416, 13.42069435], [80.27041626, 13.42069244], [80.27041626, 13.42125034], [80.27068329, 13.42125034], [80.27068329, 13.42209053], [80.27097321, 13.42209053], [80.27097321, 13.42263985], [80.27124786, 13.42263794], [80.27124786, 13.42319393], [80.27153015, 13.42319202], [80.27153015, 13.42431068], [80.27179718, 13.42431068], [80.27179718, 13.42542076], [80.2720871, 13.42541599], [80.2720871, 13.42597198], [80.27236176, 13.42597008], [80.27236176, 13.42625046], [80.27263641, 13.42625046], [80.27263641, 13.42653084], [80.2729187, 13.42652893], [80.2729187, 13.42708206], [80.27319336, 13.42708206], [80.27319336, 13.42735958], [80.27348328, 13.42735958], [80.27348328, 13.4279213], [80.27375031, 13.42791557], [80.27375031, 13.428195], [80.27402496, 13.428195], [80.27402496, 13.42847347], [80.27430725, 13.42846966], [80.27430725, 13.42903137], [80.27458191, 13.42903137], [80.27458191, 13.42930889], [80.27513885, 13.42930698], [80.27513885, 13.4295826], [80.27540588, 13.42957973], [80.27540588, 13.42986107], [80.2756958, 13.42986107], [80.2756958, 13.43042088], [80.27597046, 13.43041706], [80.27597046, 13.43069458], [80.27625275, 13.4306879], [80.27625275, 13.43125057], [80.2765274, 13.43125057], [80.2765274, 13.43180943], [80.27680206, 13.43180466], [80.27680206, 13.43375111], [80.27708435, 13.43375111], [80.27708435, 13.43486118], [80.27735901, 13.43486118], [80.27735901, 13.43542194], [80.2776413, 13.43541718], [80.2776413, 13.43569469], [80.27902985, 13.43569469], [80.27902985, 13.43541718], [80.28125, 13.43541718], [80.28125, 13.43569469], [80.28263855, 13.43569469], [80.28263855, 13.43541718], [80.28291321, 13.43542194], [80.28291321, 13.43514061], [80.28320313, 13.43514061], [80.28320313, 13.4345808], [80.28347015, 13.43458271], [80.28347015, 13.43430519], [80.28375244, 13.43431187], [80.28375244, 13.43403053], [80.2840271, 13.43403053], [80.2840271, 13.43375111], [80.28430176, 13.43375111], [80.28430176, 13.43347073], [80.28458405, 13.43347263], [80.28458405, 13.43319511], [80.2848587, 13.43319511], [80.2848587, 13.43291664], [80.28514099, 13.43292141], [80.28514099, 13.43264103], [80.2859726, 13.43264103], [80.2859726, 13.43292141], [80.28624725, 13.43291664], [80.28624725, 13.43319511], [80.2868042, 13.43319511], [80.2868042, 13.43347263], [80.28708649, 13.43347073], [80.28708649, 13.43375111], [80.28736115, 13.43375111], [80.28736115, 13.43403053], [80.28791809, 13.43403053], [80.28791809, 13.43431187], [80.28819275, 13.43430519], [80.28819275, 13.43458271], [80.28874969, 13.43458271], [80.28874969, 13.43486118], [80.29013824, 13.43486118], [80.29013824, 13.43458271], [80.2904129, 13.43458271], [80.2904129, 13.43430519], [80.29070282, 13.43431187], [80.29070282, 13.43375111], [80.29096985, 13.43375111], [80.29096985, 13.43347073], [80.29125214, 13.43347263], [80.29125214, 13.43319511], [80.29152679, 13.43319511], [80.29152679, 13.43291664], [80.29180908, 13.43292141], [80.29180908, 13.43264103], [80.29207611, 13.43264103], [80.29207611, 13.43236065], [80.2923584, 13.43236065], [80.2923584, 13.43180943], [80.29264069, 13.43180943], [80.29264069, 13.43153095], [80.29292297, 13.43153095], [80.29292297, 13.43125057], [80.29374695, 13.43125057], [80.29374695, 13.43096066], [80.29402924, 13.43097305], [80.29402924, 13.43069458], [80.29430389, 13.43069458], [80.29430389, 13.42930698], [80.29458618, 13.42930889], [80.29458618, 13.42875099], [80.29486847, 13.42875099], [80.29486847, 13.42735958], [80.29541779, 13.42735958], [80.29541779, 13.42708206], [80.29736328, 13.42708206], [80.29736328, 13.4268074], [80.29763794, 13.42681122], [80.29763794, 13.42653084], [80.2979126, 13.42653084], [80.2979126, 13.42681122], [80.29921722, 13.4268074], [80.30042267, 13.42681122], [80.30042267, 13.42653084], [80.30069733, 13.42653084], [80.30069733, 13.42515182], [80.30152893, 13.42515182], [80.30152893, 13.42457962], [80.30124664, 13.42458439], [80.30124664, 13.42430592], [80.30097198, 13.42431068], [80.30097198, 13.42374992], [80.30124664, 13.42374992], [80.30124664, 13.42346954], [80.30097198, 13.4234724], [80.30097198, 13.42291641], [80.30069733, 13.42292118], [80.30069733, 13.42236042], [80.30041504, 13.42236233], [80.30041504, 13.42152786], [80.30014038, 13.42153263], [80.30014038, 13.42097187], [80.29985809, 13.42097187], [80.29985809, 13.41985989], [80.29957581, 13.41986179], [80.29957581, 13.41902065], [80.29985809, 13.41902828], [80.29985809, 13.41847229], [80.30014038, 13.41847229], [80.30014038, 13.4179163], [80.30042267, 13.41792011], [80.30042267, 13.41763973], [80.30069733, 13.41763973], [80.30069733, 13.41736031], [80.30124664, 13.41736221], [80.30124664, 13.41708374], [80.30152893, 13.41708374], [80.30152893, 13.41652775], [80.30179596, 13.41652966], [80.30179596, 13.41625023], [80.30236053, 13.41625023], [80.30236053, 13.41596031], [80.30263519, 13.41597176], [80.30263519, 13.41736221], [80.30236053, 13.41736031], [80.30236053, 13.41874981], [80.30208588, 13.41874981], [80.30208588, 13.41930962], [80.30180359, 13.4193058], [80.30180359, 13.41958427], [80.30152893, 13.41957855], [80.30152893, 13.4218111], [80.30179596, 13.4218111], [80.30179596, 13.42209053], [80.30208588, 13.42209053], [80.30208588, 13.42292118], [80.30236053, 13.42291641], [80.30236053, 13.42319393], [80.30263519, 13.42319393], [80.30263519, 13.4234724], [80.30291748, 13.42346954], [80.30291748, 13.42403126], [80.30319214, 13.42403126], [80.30319214, 13.42431068], [80.3034668, 13.42431068], [80.3034668, 13.42486], [80.30374908, 13.42486], [80.30374908, 13.42515182], [80.304039, 13.42515182], [80.304039, 13.42542076], [80.30458069, 13.42541599], [80.30458069, 13.42569447], [80.30486298, 13.42569447], [80.30486298, 13.42597198], [80.30541992, 13.42597008], [80.30541992, 13.42625046], [80.30568695, 13.42625046], [80.30568695, 13.42653084], [80.30625153, 13.42653084], [80.30625153, 13.42681122], [80.30652618, 13.4268074], [80.30652618, 13.42708206], [80.30680847, 13.42708206], [80.30680847, 13.42735958], [80.30735779, 13.42735958], [80.30735779, 13.42764091], [80.30819702, 13.42764091], [80.30819702, 13.4279213], [80.30930328, 13.42791557], [80.30930328, 13.428195], [80.31041718, 13.428195], [80.31041718, 13.42791557], [80.31069183, 13.42791557], [80.31069183, 13.428195], [80.31263733, 13.428195], [80.31263733, 13.42791557], [80.31299591, 13.42791557], [80.31375122, 13.42791557], [80.31375122, 13.428195], [80.31597137, 13.428195], [80.31597137, 13.42847347], [80.31625366, 13.42847347], [80.31625366, 13.428195], [80.31652832, 13.428195], [80.31652832, 13.42735958], [80.31680298, 13.42735958], [80.31680298, 13.42708206], [80.31652832, 13.42708206], [80.31652832, 13.42625046], [80.31680298, 13.42625046], [80.31680298, 13.42597008], [80.31708527, 13.42597198], [80.31708527, 13.42569447], [80.31791687, 13.42569447], [80.31791687, 13.42513847], [80.31764221, 13.42515182], [80.31764221, 13.42457962], [80.31735992, 13.42458439], [80.31735992, 13.4234724], [80.31708527, 13.4234724], [80.31708527, 13.42291641], [80.31735992, 13.42292118], [80.31735992, 13.42263985], [80.31791687, 13.42263985], [80.31791687, 13.42236042], [80.31846619, 13.42236042], [80.31846619, 13.42263985], [80.31874847, 13.42263985], [80.31874847, 13.4218111], [80.31846619, 13.4218111], [80.31846619, 13.42125034], [80.31819153, 13.42125034], [80.31819153, 13.42069244], [80.31847382, 13.42069435], [80.31847382, 13.42014027], [80.31874847, 13.42014027], [80.31874847, 13.41957855], [80.31903076, 13.41958427], [80.31903076, 13.4193058], [80.31931305, 13.41930962], [80.31931305, 13.41902065], [80.31958008, 13.41902828], [80.31958008, 13.41847229], [80.31986237, 13.41847229], [80.31986237, 13.4179163], [80.32013702, 13.41792011], [80.32013702, 13.41736031], [80.32041931, 13.41736221], [80.32041931, 13.41652775], [80.32068634, 13.41652966], [80.32068634, 13.41486168], [80.32041931, 13.41486168], [80.32041931, 13.4145813], [80.32013702, 13.41458416], [80.32013702, 13.41430473], [80.31986237, 13.41431046], [80.31986237, 13.41403198], [80.31958008, 13.41403198], [80.31958008, 13.4137516], [80.31874847, 13.4137516], [80.31874847, 13.41347122], [80.31847382, 13.41347122], [80.31847382, 13.41319561], [80.31819153, 13.41319561], [80.31819153, 13.41291809], [80.31764221, 13.41292191], [80.31764221, 13.41263866], [80.31735992, 13.41263866], [80.31735992, 13.41208076], [80.31725311, 13.41208267], [80.31708527, 13.41208267], [80.31708527, 13.41180515], [80.31732941, 13.41180992], [80.31735992, 13.41152954], [80.31764221, 13.41152954], [80.31764221, 13.41180992], [80.31847382, 13.41180515], [80.31847382, 13.41208267], [80.31930542, 13.41208267], [80.31930542, 13.41236115], [80.31958008, 13.41235924], [80.31958008, 13.41263866], [80.31986237, 13.41263866], [80.31986237, 13.41292191], [80.32041931, 13.41291809], [80.32041931, 13.41319561], [80.32096863, 13.41319561], [80.32096863, 13.41291809], [80.3215332, 13.41292191], [80.3215332, 13.41125107], [80.32180786, 13.41125107], [80.32180786, 13.40986061], [80.32208252, 13.40986061], [80.32208252, 13.40958118], [80.32236481, 13.40958309], [80.32236481, 13.40930462], [80.32263947, 13.40931034], [80.32263947, 13.40792179], [80.32290649, 13.40792179], [80.32290649, 13.40736103], [80.32319641, 13.40736103], [80.32319641, 13.40681171], [80.32347107, 13.40681171], [80.32347107, 13.40653133], [80.32375336, 13.40653133], [80.32375336, 13.40625095], [80.32402802, 13.40625095], [80.32402802, 13.40597057], [80.32430267, 13.40597343], [80.32430267, 13.40569496], [80.32458496, 13.40569496], [80.32458496, 13.40541744], [80.32485199, 13.40542126], [80.32485199, 13.40514088], [80.32514191, 13.40514088], [80.32514191, 13.40402031], [80.32485962, 13.40402889], [80.32485962, 13.40291691], [80.32457733, 13.40292072], [80.32457733, 13.40236092], [80.32430267, 13.40236092], [80.32430267, 13.40207958], [80.32375336, 13.40208244], [80.32375336, 13.40152645], [80.32402802, 13.40153122], [80.32402802, 13.40125275], [80.32430267, 13.40125275], [80.32430267, 13.4009819], [80.32485199, 13.4009819], [80.32485199, 13.40069008], [80.32514191, 13.40069485], [80.32514191, 13.40041637], [80.32541656, 13.40042114], [80.32541656, 13.40014076], [80.32569122, 13.40014076], [80.32569122, 13.39986038], [80.32624817, 13.39986038], [80.32624817, 13.39902782], [80.32653046, 13.39903069], [80.32653046, 13.39597034], [80.32624817, 13.39597225], [80.32624817, 13.39569378], [80.32597351, 13.39569378], [80.32597351, 13.39486217], [80.32569122, 13.39486217], [80.32569122, 13.39235973], [80.32541656, 13.39235973], [80.32541656, 13.39207935], [80.32458496, 13.39208412], [80.32458496, 13.39180565], [80.32430267, 13.39181042], [80.32430267, 13.39153004], [80.32375336, 13.39153004], [80.32375336, 13.39124966], [80.32290649, 13.39124966], [80.32290649, 13.3906889], [80.32263947, 13.39069366], [80.32263947, 13.39013767], [80.32235718, 13.39013958], [80.32235718, 13.3898592], [80.32319641, 13.3898592], [80.32319641, 13.39013958], [80.32402802, 13.39013958], [80.32402802, 13.39041996], [80.32458496, 13.39041805], [80.32458496, 13.39069366], [80.32514191, 13.39069366], [80.32514191, 13.39041805], [80.32569122, 13.39041996], [80.32569122, 13.39013958], [80.32596588, 13.39013958], [80.32596588, 13.3898592], [80.32624817, 13.38986206], [80.32624817, 13.38958359], [80.32680511, 13.38958359], [80.32680511, 13.38930607], [80.32707977, 13.38931179], [80.32707977, 13.38904095], [80.32736206, 13.38904095], [80.32736206, 13.38875198], [80.32791901, 13.38875198], [80.32791901, 13.38847065], [80.32819366, 13.38847065], [80.32819366, 13.38819313], [80.32847595, 13.38819313], [80.32847595, 13.38791847], [80.32875061, 13.38792038], [80.32875061, 13.38764191], [80.32930756, 13.38764191], [80.32930756, 13.38736153], [80.32958221, 13.38736153], [80.32958221, 13.38708401], [80.3298645, 13.38708401], [80.3298645, 13.38486099], [80.33013916, 13.38486099], [80.33013916, 13.38042164], [80.33040619, 13.38042164], [80.33040619, 13.3779192], [80.33013916, 13.3779192], [80.33013916, 13.37764072], [80.32985687, 13.37764072], [80.32985687, 13.37707996], [80.32958221, 13.37708282], [80.32958221, 13.37680531], [80.32930756, 13.37681103], [80.32930756, 13.37653065], [80.3290329, 13.37653065], [80.3290329, 13.37625122], [80.32875061, 13.37625122], [80.32875061, 13.37597275], [80.32847595, 13.37597275], [80.32847595, 13.37542057], [80.32818604, 13.37542057], [80.32818604, 13.37514114], [80.32791901, 13.37514114], [80.32791901, 13.3748579], [80.32763672, 13.37485981], [80.32763672, 13.37458229], [80.32736206, 13.37458229], [80.32736206, 13.37430668], [80.32681274, 13.37431145], [80.32681274, 13.37403965], [80.32653046, 13.37403965], [80.32653046, 13.37375069], [80.32624817, 13.37375069], [80.32624817, 13.37318993], [80.32597351, 13.37319374], [80.32597351, 13.37263775], [80.32569122, 13.37264061], [80.32569122, 13.37236023], [80.32541656, 13.37236023], [80.32541656, 13.37180424], [80.32514191, 13.37181091], [80.32514191, 13.37153053], [80.32485199, 13.37153053], [80.32485199, 13.37096977], [80.32458496, 13.37097168], [80.32458496, 13.37069416], [80.32430267, 13.37069416], [80.32430267, 13.37041569], [80.32457733, 13.37042141], [80.32457733, 13.37014008], [80.32485199, 13.37014008], [80.32485199, 13.3698597], [80.32514191, 13.3698597], [80.32514191, 13.36958027], [80.32541656, 13.36958218], [80.32541656, 13.36930561], [80.32569122, 13.36931133], [80.32569122, 13.36903], [80.32596588, 13.36903], [80.32596588, 13.36874962], [80.32624817, 13.36874962], [80.32624817, 13.36847019], [80.32653046, 13.3684721], [80.32653046, 13.36819363], [80.32680511, 13.36819363], [80.32680511, 13.36791611], [80.32707977, 13.36791611], [80.32707977, 13.36763763], [80.32736206, 13.36763954], [80.32736206, 13.36736202], [80.32763672, 13.36736202], [80.32763672, 13.36708164], [80.32819366, 13.36708355], [80.32819366, 13.36680603], [80.32847595, 13.3668108], [80.32847595, 13.36653042], [80.3290329, 13.36653042], [80.3290329, 13.36763954], [80.32875061, 13.36763763], [80.32875061, 13.3684721], [80.32847595, 13.36847019], [80.32847595, 13.36874962], [80.32818604, 13.36874962], [80.32818604, 13.36903], [80.32791901, 13.36903], [80.32791901, 13.36931133], [80.32736206, 13.36930561], [80.32736206, 13.36958218], [80.32707977, 13.36958027], [80.32707977, 13.37014008], [80.32736206, 13.37013817], [80.32736206, 13.37097168], [80.32763672, 13.37096977], [80.32763672, 13.37181091], [80.32791901, 13.37181091], [80.32791901, 13.37292099], [80.32819366, 13.37291622], [80.32819366, 13.37319374], [80.32847595, 13.37319374], [80.32847595, 13.37347317], [80.32875061, 13.37347031], [80.32875061, 13.37375069], [80.3290329, 13.37375069], [80.3290329, 13.37403965], [80.32930756, 13.37403965], [80.32930756, 13.37431145], [80.32958221, 13.37430668], [80.32958221, 13.37458229], [80.3298645, 13.37458229], [80.3298645, 13.37485981], [80.33013916, 13.3748579], [80.33013916, 13.37514114], [80.33040619, 13.37514114], [80.33040619, 13.37542057], [80.33069611, 13.37541676], [80.33069611, 13.37569523], [80.33097076, 13.37569523], [80.33097076, 13.37625122], [80.33125305, 13.37625122], [80.33125305, 13.37653065], [80.33152771, 13.37652874], [80.33152771, 13.37958336], [80.33180237, 13.37958145], [80.33180237, 13.38375092], [80.33152771, 13.38375092], [80.33152771, 13.38542175], [80.33125305, 13.38542175], [80.33125305, 13.38792038], [80.33097839, 13.38792038], [80.33097839, 13.39124966], [80.33069611, 13.39124966], [80.33069611, 13.39291954], [80.33041382, 13.39291573], [80.33041382, 13.39347172], [80.33013916, 13.39346981], [80.33013916, 13.39402962], [80.3298645, 13.39402771], [80.3298645, 13.3945837], [80.32958221, 13.39458179], [80.32958221, 13.39513969], [80.32930756, 13.39513779], [80.32930756, 13.39569378], [80.3290329, 13.39569187], [80.3290329, 13.39624977], [80.32875061, 13.39624977], [80.32875061, 13.39681053], [80.32847595, 13.39680576], [80.32847595, 13.39735985], [80.32819366, 13.39735985], [80.32819366, 13.39847183], [80.32791901, 13.39846992], [80.32791901, 13.40014076], [80.32763672, 13.40014076], [80.32763672, 13.40153122], [80.32736206, 13.40152645], [80.32736206, 13.40319538], [80.32707977, 13.40319538], [80.32707977, 13.40458298], [80.32681274, 13.40458012], [80.32681274, 13.40542126], [80.32653046, 13.40541744], [80.32653046, 13.40597343], [80.32624817, 13.40597057], [80.32624817, 13.40653133], [80.32597351, 13.40652657], [80.32597351, 13.40708256], [80.32569122, 13.40708065], [80.32569122, 13.40764141], [80.32541656, 13.40764141], [80.32541656, 13.40792179], [80.32514191, 13.40791702], [80.32514191, 13.40819454], [80.32485962, 13.40819454], [80.32485962, 13.40847301], [80.32457733, 13.40847111], [80.32457733, 13.40875053], [80.32430267, 13.40875053], [80.32430267, 13.40903187], [80.32402802, 13.40903187], [80.32402802, 13.40931034], [80.32375336, 13.40930462], [80.32375336, 13.40986061], [80.32347107, 13.40986061], [80.32347107, 13.41015053], [80.32375336, 13.41015053], [80.32375336, 13.41125107], [80.32402802, 13.41124916], [80.32402802, 13.41236115], [80.32375336, 13.41236115], [80.32375336, 13.41319561], [80.32347107, 13.41319561], [80.32347107, 13.41347122], [80.32375336, 13.41347122], [80.32375336, 13.41431046], [80.32402802, 13.41430473], [80.32402802, 13.41458416], [80.32375336, 13.4145813], [80.32375336, 13.41541958], [80.32402802, 13.41541767], [80.32402802, 13.41597176], [80.32375336, 13.41596031], [80.32375336, 13.41652966], [80.32347107, 13.41652775], [80.32347107, 13.41736221], [80.32319641, 13.41736031], [80.32319641, 13.41763973], [80.32291412, 13.41763973], [80.32291412, 13.41847229], [80.32263947, 13.41847229], [80.32263947, 13.41902828], [80.32290649, 13.41902065], [80.32290649, 13.41930962], [80.32263947, 13.41930962], [80.32263947, 13.41986179], [80.32235718, 13.41986179], [80.32235718, 13.42014027], [80.32152557, 13.42014027], [80.32152557, 13.42069435], [80.32125092, 13.42069244], [80.32125092, 13.42125034], [80.32096863, 13.42125034], [80.32096863, 13.4218111], [80.32069397, 13.42180634], [80.32069397, 13.42236233], [80.32041931, 13.42236042], [80.32041931, 13.42292118], [80.32013702, 13.42291641], [80.32013702, 13.4234724], [80.31986237, 13.42346954], [80.31986237, 13.42374992], [80.31931305, 13.42374992], [80.31931305, 13.42403126], [80.31958008, 13.4240284], [80.31958008, 13.42458439], [80.31986237, 13.42457962], [80.31986237, 13.42653084], [80.32013702, 13.42653084], [80.32013702, 13.42681122], [80.32041931, 13.4268074], [80.32041931, 13.42708206], [80.32069397, 13.42708206], [80.32069397, 13.42735958], [80.3215332, 13.42735958], [80.3215332, 13.42764091], [80.32263947, 13.42764091], [80.32263947, 13.42735958], [80.32291412, 13.42735958], [80.32291412, 13.4268074], [80.32319641, 13.42681122], [80.32319641, 13.4256897], [80.32347107, 13.42569447], [80.32347107, 13.42708206], [80.32375336, 13.42708206], [80.32375336, 13.42735958], [80.32402802, 13.42735958], [80.32402802, 13.42764091], [80.32457733, 13.42764091], [80.32457733, 13.4279213], [80.32485962, 13.42791557], [80.32485962, 13.428195], [80.32514191, 13.428195], [80.32514191, 13.42847347], [80.32541656, 13.42846966], [80.32541656, 13.42903137], [80.32569122, 13.42903137], [80.32569122, 13.42930889], [80.32596588, 13.42930889], [80.32596588, 13.42986107], [80.32624817, 13.42986107], [80.32624817, 13.43125057], [80.32596588, 13.43125057], [80.32597351, 13.43236065], [80.32569122, 13.43236065], [80.32569122, 13.43458271], [80.32541656, 13.4345808], [80.32541656, 13.43625069], [80.32514191, 13.43625069], [80.32514191, 13.43791962], [80.32485199, 13.43791962], [80.32485199, 13.43902969], [80.32457733, 13.43902969], [80.32457733, 13.44236183], [80.32485199, 13.44236183], [80.32485199, 13.4426403], [80.32514191, 13.4426403], [80.32514191, 13.44319439], [80.32541656, 13.44319057], [80.32541656, 13.44375038], [80.32569122, 13.44375038], [80.32569122, 13.44319057], [80.32597351, 13.44319439], [80.32597351, 13.4426403], [80.32624817, 13.4426403], [80.32624817, 13.43958092], [80.32653046, 13.43958282], [80.32653046, 13.43791676], [80.32681274, 13.43791962], [80.32681274, 13.43625069], [80.32707977, 13.43625069], [80.32707977, 13.43431187], [80.32736206, 13.43431187], [80.32736206, 13.43264103], [80.32763672, 13.43264103], [80.32763672, 13.43125057], [80.32791901, 13.43125057], [80.32791901, 13.42986107], [80.32818604, 13.42986107], [80.32818604, 13.42681122], [80.32791901, 13.42681122], [80.32791901, 13.4256897], [80.32819366, 13.42569447], [80.32819366, 13.42513847], [80.32847595, 13.42515182], [80.32847595, 13.42209053], [80.32818604, 13.42209053], [80.32818604, 13.42153263], [80.32791901, 13.42153263], [80.32791901, 13.42097187], [80.32763672, 13.42097187], [80.32763672, 13.42041588], [80.32736206, 13.42041969], [80.32736206, 13.42014027], [80.32707977, 13.42014027], [80.32707977, 13.41986179], [80.32736206, 13.41986179], [80.32736206, 13.41930962], [80.32763672, 13.41930962], [80.32763672, 13.41902065], [80.32791901, 13.41902828], [80.32791901, 13.41847229], [80.32819366, 13.41847229], [80.32819366, 13.41680622], [80.32847595, 13.41681004], [80.32847595, 13.4145813], [80.32875061, 13.41458416], [80.32875061, 13.40847301], [80.32902527, 13.40847301], [80.32902527, 13.40708256], [80.32875061, 13.40708256], [80.32875061, 13.40680504], [80.3290329, 13.40681171], [80.3290329, 13.40486145], [80.32930756, 13.40486145], [80.32930756, 13.40458298], [80.32958221, 13.40458298], [80.32958221, 13.40430546], [80.32985687, 13.40430927], [80.32985687, 13.40375137], [80.32958221, 13.40375137], [80.32958221, 13.40236092], [80.32985687, 13.40236092], [80.32985687, 13.40125275], [80.32958221, 13.40125275], [80.32958221, 13.40014076], [80.32985687, 13.40014076], [80.32985687, 13.39986038], [80.33013916, 13.39986038], [80.33013916, 13.39847183], [80.33041382, 13.39847183], [80.33041382, 13.39763832], [80.33069611, 13.39764023], [80.33069611, 13.39653111], [80.33097839, 13.39653111], [80.33097839, 13.39513969], [80.33125305, 13.39513969], [80.33125305, 13.39485073], [80.33097076, 13.39486217], [80.33097076, 13.39430618], [80.33125305, 13.39431095], [80.33125305, 13.39346981], [80.33152771, 13.39347172], [80.33152771, 13.39235973], [80.33180237, 13.39235973], [80.33180237, 13.39124966], [80.33207703, 13.39124966], [80.33207703, 13.39013958], [80.33235931, 13.39013958], [80.33235931, 13.38904095], [80.3326416, 13.38904095], [80.3326416, 13.38792038], [80.33291626, 13.38792038], [80.33291626, 13.3868103], [80.33319092, 13.3868103], [80.33319092, 13.38569069], [80.33347321, 13.38569641], [80.33347321, 13.38458347], [80.33374786, 13.38458347], [80.33374786, 13.3834734], [80.33403015, 13.3834734], [80.33403015, 13.38236141], [80.33430481, 13.38236141], [80.33430481, 13.38125134], [80.3345871, 13.38125134], [80.3345871, 13.38014126], [80.33486176, 13.38014126], [80.33486176, 13.37903118], [80.33513641, 13.37903118], [80.33513641, 13.3779192], [80.3354187, 13.3779192], [80.3354187, 13.37681103], [80.33569336, 13.37681103], [80.33569336, 13.37597275], [80.33598328, 13.37597275], [80.33597565, 13.37485981], [80.33625031, 13.37485981], [80.33625031, 13.37375069], [80.33651733, 13.37375069], [80.33651733, 13.37264061], [80.33680725, 13.37264061], [80.33680725, 13.37181091], [80.33651733, 13.37181091], [80.33651733, 13.37069035], [80.33680725, 13.37069416], [80.33680725, 13.37097168], [80.33708191, 13.37097168], [80.33708191, 13.37069416], [80.3373642, 13.37069416], [80.3373642, 13.36958218], [80.33763885, 13.36958218], [80.33763885, 13.3684721], [80.33791351, 13.3684721], [80.33791351, 13.36736202], [80.3381958, 13.36736202], [80.3381958, 13.36653042], [80.33847046, 13.36653042], [80.33847046, 13.36542034], [80.33875275, 13.36542034], [80.33875275, 13.36431026], [80.3390274, 13.36431026], [80.3390274, 13.36375046], [80.33875275, 13.36375046], [80.33875275, 13.36347198], [80.3390274, 13.36347198], [80.3390274, 13.36236191], [80.33930206, 13.36236191], [80.33930206, 13.36208057], [80.33958435, 13.36208439], [80.33958435, 13.36097145], [80.33985901, 13.36097145], [80.33985901, 13.36041546], [80.33957672, 13.36042023], [80.33957672, 13.35986233], [80.33985901, 13.35986233], [80.33985901, 13.35763931], [80.34014893, 13.35763931], [80.34014893, 13.35708141], [80.34041595, 13.35708332], [80.34041595, 13.35624886], [80.34069061, 13.35625076], [80.34069824, 13.35568237], [80.3409729, 13.35569477], [80.3409729, 13.35513878], [80.34124756, 13.35514069], [80.34124756, 13.35293102], [80.34152985, 13.35293102], [80.34152985, 13.35236073], [80.34179687, 13.35236073], [80.34179687, 13.35097122], [80.34152985, 13.35097313], [80.34152985, 13.35013866], [80.34179687, 13.35014057], [80.34179687, 13.34986973], [80.34208679, 13.34986973], [80.34208679, 13.34903145], [80.34236145, 13.34903145], [80.34236145, 13.34735966], [80.34263611, 13.34735966], [80.34263611, 13.34514141], [80.3429184, 13.34514141], [80.3429184, 13.34431076], [80.34319305, 13.34431076], [80.34319305, 13.34263992], [80.34348297, 13.34263992], [80.34348297, 13.34208202], [80.34375, 13.34208202], [80.34375, 13.34180641], [80.34401703, 13.34181118], [80.34401703, 13.34042263], [80.34375, 13.34042263], [80.34375, 13.33985996], [80.34401703, 13.33985996], [80.34401703, 13.33903027], [80.34430695, 13.33903027], [80.34430695, 13.33793163], [80.3445816, 13.33793163], [80.3445816, 13.33763981], [80.34430695, 13.33763981], [80.34430695, 13.33625031], [80.3445816, 13.33625031], [80.3445816, 13.33569145], [80.34486389, 13.33569431], [80.34486389, 13.33541775], [80.3445816, 13.33541965], [80.3445816, 13.33430958], [80.34485626, 13.33430958], [80.34485626, 13.33180141], [80.3445816, 13.33180523], [80.3445816, 13.33152676], [80.34401703, 13.33152962], [80.34401703, 13.33124924], [80.3445816, 13.33124924], [80.3445816, 13.33097076], [80.34513855, 13.33097076], [80.34513855, 13.33014202], [80.34541321, 13.33014202], [80.34541321, 13.32764053], [80.34570313, 13.32764053], [80.34570313, 13.32597065], [80.34597015, 13.32597256], [80.34597015, 13.32541656], [80.34570313, 13.32542133], [80.34570313, 13.32181072], [80.34541321, 13.32181072], [80.34541321, 13.32069016], [80.3456955, 13.32069492], [80.3456955, 13.3204174], [80.34596252, 13.32042122], [80.34596252, 13.31986046], [80.34625244, 13.31986046], [80.34625244, 13.31958199], [80.34597015, 13.31958199], [80.34597015, 13.31902885], [80.34570313, 13.31903076], [80.34570313, 13.31764126], [80.34596252, 13.31764126], [80.34596252, 13.3154211], [80.34625244, 13.3154211], [80.34625244, 13.31347179], [80.3465271, 13.31347179], [80.3465271, 13.31318855], [80.34680176, 13.31319427], [80.34680176, 13.31180573], [80.3465271, 13.31180954], [80.3465271, 13.31124973], [80.34680176, 13.31124973], [80.34680176, 13.30847168], [80.3465271, 13.30847168], [80.3465271, 13.30764008], [80.34625244, 13.30764008], [80.34625244, 13.3073616], [80.34597015, 13.3073616], [80.34596252, 13.30513859], [80.34625244, 13.30513859], [80.34625244, 13.3045702], [80.3465271, 13.3045826], [80.3465271, 13.3040266], [80.34570313, 13.30403042], [80.34570313, 13.30375099], [80.34541321, 13.30375099], [80.34541321, 13.30264187], [80.34625244, 13.30264187], [80.34625244, 13.30182076], [80.3465271, 13.30182076], [80.3465271, 13.30014133], [80.34596252, 13.30014133], [80.34596252, 13.29931164], [80.34625244, 13.29931164], [80.34625244, 13.2968092], [80.34596252, 13.2968092], [80.34596252, 13.29596996], [80.34625244, 13.29597282], [80.34625244, 13.29486084], [80.34596252, 13.29486275], [80.34596252, 13.29347038], [80.34625244, 13.29347324], [80.34625244, 13.29236031], [80.3465271, 13.29236031], [80.3465271, 13.29152775], [80.34625244, 13.29153061], [80.34625244, 13.29125023], [80.3456955, 13.29125023], [80.3456955, 13.29069424], [80.34597015, 13.29069424], [80.34597015, 13.29041576], [80.34570313, 13.29042053], [80.34570313, 13.28985977], [80.34597015, 13.28985977], [80.34596252, 13.28931141], [80.34570313, 13.28931141], [80.34570313, 13.28847027], [80.34541321, 13.28847218], [80.34541321, 13.28791618], [80.34485626, 13.28792095], [80.34485626, 13.28763962], [80.34348297, 13.28763962], [80.34348297, 13.28652954], [80.34319305, 13.28652954], [80.34319305, 13.28431034], [80.34348297, 13.28431034], [80.34348297, 13.2804203], [80.34319305, 13.2804203], [80.34319305, 13.28014183], [80.34348297, 13.28014183], [80.34348297, 13.27958107], [80.34375, 13.27958393], [80.34375, 13.27902699], [80.3445816, 13.27903175], [80.3445816, 13.27847099], [80.34430695, 13.27847099], [80.34430695, 13.27791691], [80.34401703, 13.27791977], [80.34401703, 13.27765083], [80.34375, 13.27765083], [80.34375, 13.27736092], [80.34347534, 13.27736092], [80.34347534, 13.2770834], [80.34319305, 13.2770834], [80.34319305, 13.27597332], [80.3429184, 13.27597332], [80.3429184, 13.27569485], [80.34263611, 13.27569485], [80.34263611, 13.27541733], [80.3429184, 13.27542019], [80.3429184, 13.27514076], [80.34319305, 13.27514076], [80.34319305, 13.27486134], [80.34402466, 13.27486134], [80.34402466, 13.27458286], [80.3445816, 13.27458954], [80.3445816, 13.27431202], [80.34485626, 13.27431202], [80.34485626, 13.27319145], [80.3445816, 13.27319527], [80.3445816, 13.27291679], [80.34401703, 13.27292156], [80.34401703, 13.27264118], [80.34348297, 13.27264118], [80.34348297, 13.2723608], [80.34319305, 13.2723608], [80.34319305, 13.27208328], [80.3429184, 13.27208328], [80.3429184, 13.27180481], [80.3418045, 13.27180481], [80.3418045, 13.27208328], [80.34152985, 13.27208328], [80.34152985, 13.27319527], [80.34124756, 13.27319527], [80.34124756, 13.27291679], [80.3409729, 13.27292156], [80.3409729, 13.27264118], [80.34069824, 13.27264118], [80.34069061, 13.27181244], [80.34041595, 13.27181244], [80.34041595, 13.2709713], [80.3401413, 13.27097321], [80.3401413, 13.27041721], [80.33985901, 13.27042103], [80.33985901, 13.26986122], [80.33958435, 13.26986122], [80.33958435, 13.26930523], [80.33930206, 13.26931095], [80.33930206, 13.26792145], [80.33875275, 13.26792145], [80.33875275, 13.26764107], [80.33847046, 13.26764107], [80.33847046, 13.26708031], [80.3390274, 13.26708221], [80.3390274, 13.26652908], [80.33875275, 13.26653099], [80.33875275, 13.26568985], [80.33847046, 13.26569366], [80.33847046, 13.26541615], [80.33875275, 13.26542091], [80.33875275, 13.26514053], [80.33847046, 13.26514053], [80.33847046, 13.26457977], [80.3381958, 13.26458454], [80.3381958, 13.26375008], [80.33790588, 13.26375008], [80.33790588, 13.26292133], [80.33763885, 13.26292133], [80.33763885, 13.26235962], [80.3373642, 13.26236153], [80.3373642, 13.26124954], [80.33708191, 13.26124954], [80.33708191, 13.25403023], [80.33735657, 13.25403023], [80.33735657, 13.25264168], [80.33708191, 13.25264168], [80.33708191, 13.25208092], [80.33680725, 13.25208282], [80.33680725, 13.25097084], [80.33651733, 13.25097084], [80.33651733, 13.25013924], [80.33625031, 13.25013924], [80.33625031, 13.24930954], [80.33598328, 13.24930954], [80.33598328, 13.24875069], [80.33569336, 13.24875069], [80.33569336, 13.24792194], [80.3354187, 13.24792194], [80.3354187, 13.24653053], [80.33513641, 13.24653053], [80.33513641, 13.24542236], [80.33486176, 13.24542236], [80.33486176, 13.24486065], [80.3345871, 13.24486065], [80.3345871, 13.24430943], [80.33429718, 13.24430943], [80.33429718, 13.24403095], [80.3345871, 13.24403095], [80.3345871, 13.24375057], [80.33429718, 13.24375057], [80.33429718, 13.24207973], [80.33403015, 13.2420826], [80.33403015, 13.24180698], [80.33429718, 13.24180889], [80.33429718, 13.24152184], [80.33403015, 13.2415266], [80.33403015, 13.24041653], [80.33374786, 13.2404213], [80.33374786, 13.24014091], [80.33402252, 13.24014091], [80.33402252, 13.23985958], [80.33374786, 13.23985958], [80.33374786, 13.2393074], [80.33347321, 13.23931122], [80.33347321, 13.23875141], [80.33291626, 13.23875141], [80.33291626, 13.23848248], [80.3326416, 13.23848248], [80.3326416, 13.2381897], [80.33235931, 13.23819447], [80.33235931, 13.23791599], [80.33180237, 13.23792076], [80.33180237, 13.23681068], [80.33152771, 13.23681068], [80.33152771, 13.23624992], [80.33125305, 13.23624992], [80.33125305, 13.23596954], [80.33097076, 13.2359724], [80.33097076, 13.23569393], [80.33041382, 13.23569393], [80.33041382, 13.23541641], [80.32958221, 13.23542118], [80.32958221, 13.23513985], [80.3290329, 13.23513985], [80.3290329, 13.23542118], [80.32875061, 13.23542118], [80.32875061, 13.23513985], [80.32818604, 13.23513985], [80.32818604, 13.23542118], [80.32791901, 13.23542118], [80.32791901, 13.23513985], [80.32763672, 13.23513985], [80.32763672, 13.23486042], [80.32680511, 13.23486233], [80.32680511, 13.23458195], [80.32624817, 13.23458195], [80.32624817, 13.23430634], [80.32569122, 13.2343111], [80.32569122, 13.23402977], [80.32541656, 13.23402977], [80.32541656, 13.23375034], [80.32514191, 13.23375034], [80.32514191, 13.23347187], [80.32485962, 13.23347187], [80.32485962, 13.23319435], [80.32402802, 13.23319435], [80.32402802, 13.23291588], [80.32290649, 13.23291969], [80.32290649, 13.23264027], [80.32208252, 13.23264027], [80.32208252, 13.2323513], [80.3215332, 13.2323513], [80.3215332, 13.23264027], [80.32125092, 13.23264027], [80.32125092, 13.2323513], [80.32041931, 13.23235989], [80.32041931, 13.23208427], [80.31981659, 13.23208427], [80.31903076, 13.23208427], [80.31903076, 13.2318058], [80.31874847, 13.23181057], [80.31874847, 13.23153019], [80.31819153, 13.23153019], [80.31819153, 13.23124981], [80.31708527, 13.23124981], [80.31708527, 13.23235989], [80.31680298, 13.23235989], [80.31680298, 13.23319435], [80.31652832, 13.23318863], [80.31652832, 13.23402977], [80.31625366, 13.23402786], [80.31625366, 13.23486233], [80.315979, 13.23486042], [80.315979, 13.23624992], [80.31624603, 13.23624992], [80.31624603, 13.23848248], [80.31652832, 13.23848248], [80.31652832, 13.23931122], [80.31680298, 13.2393074], [80.31680298, 13.23985958], [80.3170929, 13.23985958], [80.3170929, 13.2404213], [80.31680298, 13.2404213], [80.31680298, 13.24125099], [80.31652832, 13.24125099], [80.31652832, 13.24292088], [80.31624603, 13.24292088], [80.31624603, 13.24430943], [80.31597137, 13.24430466], [80.31597137, 13.24458313], [80.31569672, 13.24458122], [80.31569672, 13.24486065], [80.3154068, 13.24486065], [80.3154068, 13.24514103], [80.31513977, 13.24514103], [80.31513977, 13.24542236], [80.31485748, 13.24541664], [80.31485748, 13.24569511], [80.31458282, 13.24569511], [80.31458282, 13.24597263], [80.31430817, 13.24597073], [80.31430817, 13.24653053], [80.31375122, 13.24653053], [80.31375122, 13.24514103], [80.31402588, 13.24514103], [80.31402588, 13.24430943], [80.31458282, 13.24430943], [80.31458282, 13.24403095], [80.31513977, 13.24403095], [80.31513977, 13.24236107], [80.3154068, 13.24236107], [80.3154068, 13.23931122], [80.31513977, 13.23931122], [80.31513977, 13.23875141], [80.31485748, 13.23875141], [80.31485748, 13.23624992], [80.31458282, 13.23624992], [80.31458282, 13.23542118], [80.31430817, 13.23542118], [80.31430817, 13.2343111], [80.31402588, 13.2343111], [80.31402588, 13.23318863], [80.31375122, 13.23319435], [80.31375122, 13.23264027], [80.31346893, 13.23264027], [80.31346893, 13.2323513], [80.31319427, 13.23235989], [80.31319427, 13.23152828], [80.31346893, 13.23153019], [80.31346893, 13.23124981], [80.31375122, 13.23124981], [80.31375122, 13.23097038], [80.31402588, 13.23097229], [80.31402588, 13.23069382], [80.31430817, 13.23069382], [80.31430817, 13.2304163], [80.31458282, 13.23042011], [80.31458282, 13.23013973], [80.31485748, 13.23013973], [80.31485748, 13.22958183], [80.31513977, 13.22958374], [80.31513977, 13.22930622], [80.3154068, 13.22931004], [80.3154068, 13.22902966], [80.31569672, 13.22902966], [80.31569672, 13.22846889], [80.31597137, 13.22847176], [80.31597137, 13.22819424], [80.31625366, 13.22819424], [80.31625366, 13.22764015], [80.31652832, 13.22764015], [80.31652832, 13.22736168], [80.31680298, 13.22736168], [80.31680298, 13.2270813], [80.31708527, 13.22708416], [80.31708527, 13.22680569], [80.31735992, 13.22681046], [80.31735992, 13.22654057], [80.31764221, 13.22654057], [80.31764221, 13.22597122], [80.31680298, 13.22597122], [80.31680298, 13.22569561], [80.31569672, 13.22569561], [80.31569672, 13.22541809], [80.31485748, 13.22542], [80.31485748, 13.22513962], [80.31375122, 13.22513962], [80.31375122, 13.22485924], [80.31346893, 13.22486115], [80.31346893, 13.22458267], [80.31319427, 13.22458267], [80.31319427, 13.22430515], [80.31263733, 13.22430992], [80.31263733, 13.22402954], [80.31236267, 13.22402954], [80.31236267, 13.22348022], [80.31208038, 13.22348022], [80.31208038, 13.22292042], [80.31153107, 13.22292042], [80.31153107, 13.22264194], [80.31069183, 13.22264194], [80.31069183, 13.22125053], [80.31096649, 13.22125053], [80.31096649, 13.22069073], [80.31124878, 13.22069454], [80.31124878, 13.21986103], [80.31096649, 13.21986103], [80.31096649, 13.21903133], [80.31069183, 13.21903133], [80.31069183, 13.21875095], [80.31041718, 13.21875095], [80.31041718, 13.21847057], [80.31014252, 13.21847343], [80.31014252, 13.21819496], [80.30986023, 13.21819496], [80.30986023, 13.21791744], [80.3095932, 13.21791935], [80.3095932, 13.21764088], [80.30930328, 13.21764088], [80.30930328, 13.21735191], [80.30874634, 13.21736145], [80.30874634, 13.21708298], [80.30847168, 13.21708298], [80.30847168, 13.21680546], [80.3079071, 13.21680927], [80.3079071, 13.21652889], [80.30735779, 13.21652889], [80.30735779, 13.21625137], [80.30708313, 13.21625137], [80.30708313, 13.21597099], [80.30680847, 13.2159729], [80.30680847, 13.21541691], [80.30652618, 13.21542072], [80.30652618, 13.2151413], [80.30625153, 13.2151413], [80.30625153, 13.21486092], [80.30652618, 13.21486092], [80.30652618, 13.21460056], [80.30652618, 13.21430683], [80.30680847, 13.21431065], [80.30680847, 13.21236038], [80.30708313, 13.21236038], [80.30708313, 13.21180439], [80.30735779, 13.21181107], [80.30735779, 13.21125031], [80.30819702, 13.21125031], [80.30819702, 13.21264076], [80.3079071, 13.21264076], [80.3079071, 13.21431065], [80.30764008, 13.21431065], [80.30764008, 13.21486092], [80.3079071, 13.21486092], [80.3079071, 13.2151413], [80.30819702, 13.21513939], [80.30819702, 13.21545982], [80.30819702, 13.21569538], [80.30847168, 13.21569538], [80.30847168, 13.2159729], [80.30874634, 13.21597099], [80.30874634, 13.21625137], [80.30902863, 13.21625137], [80.30902863, 13.21680927], [80.30930328, 13.21680546], [80.30930328, 13.21708298], [80.31041718, 13.21708298], [80.31041718, 13.21664143], [80.31041718, 13.21541691], [80.31097412, 13.21541691], [80.31097412, 13.21569538], [80.31124878, 13.21569538], [80.31124878, 13.2159729], [80.31153107, 13.21597099], [80.31153107, 13.21625137], [80.31181335, 13.21625137], [80.31181335, 13.21652889], [80.31208038, 13.21652889], [80.31208038, 13.21680927], [80.31236267, 13.21680546], [80.31236267, 13.21708298], [80.31263733, 13.21708298], [80.31263733, 13.21736145], [80.31291199, 13.21735191], [80.31291199, 13.21764088], [80.31319427, 13.21763897], [80.31319427, 13.21819496], [80.31291199, 13.21819019], [80.31291199, 13.21931171], [80.31319427, 13.21930504], [80.31319427, 13.22041702], [80.31346893, 13.22041702], [80.31346893, 13.22208309], [80.31402588, 13.22208118], [80.31402588, 13.22236061], [80.31430817, 13.22236061], [80.31430817, 13.22264194], [80.31485748, 13.22264194], [80.31485748, 13.22292042], [80.31541443, 13.2229166], [80.31541443, 13.22319317], [80.31569672, 13.22319126], [80.31569672, 13.22348022], [80.31624603, 13.22348022], [80.31624603, 13.22375202], [80.31652832, 13.22375202], [80.31652832, 13.22402954], [80.3170929, 13.22402954], [80.3170929, 13.22375202], [80.31746674, 13.22375202], [80.31791687, 13.22375202], [80.31791687, 13.22181034], [80.31764221, 13.22181034], [80.31764221, 13.22153187], [80.31735992, 13.22153187], [80.31735992, 13.22125053], [80.3170929, 13.22125053], [80.3170929, 13.22069073], [80.31680298, 13.22069454], [80.31680298, 13.22041702], [80.31652832, 13.22041702], [80.31652832, 13.22013855], [80.31624603, 13.22014141], [80.31624603, 13.21986103], [80.31569672, 13.21986103], [80.31569672, 13.21958065], [80.31513977, 13.21958256], [80.31513977, 13.21930504], [80.31346893, 13.21931171], [80.31346893, 13.21903133], [80.31375122, 13.21903133], [80.31375122, 13.21847057], [80.31388855, 13.21847057], [80.31402588, 13.21847343], [80.31402588, 13.21736145], [80.31375122, 13.21736145], [80.31375122, 13.21625137], [80.31346893, 13.21625137], [80.31346893, 13.21568966], [80.31319427, 13.21569538], [80.31319427, 13.21513939], [80.31291199, 13.2151413], [80.31291199, 13.21457958], [80.31263733, 13.2145834], [80.31263733, 13.21402645], [80.31236267, 13.21403122], [80.31236267, 13.21319008], [80.31208038, 13.21319485], [80.31208038, 13.21236038], [80.31180573, 13.21236038], [80.31180573, 13.21180439], [80.31153107, 13.21181107], [80.31153107, 13.21096992], [80.31124878, 13.21097183], [80.31124878, 13.21013832], [80.31096649, 13.21014118], [80.31096649, 13.20958042], [80.31069183, 13.20958424], [80.31069183, 13.20902824], [80.31153107, 13.20903111], [80.31153107, 13.20931053], [80.31180573, 13.20930576], [80.31180573, 13.20985985], [80.31208038, 13.20985985], [80.31208038, 13.21014118], [80.31236267, 13.21013832], [80.31236267, 13.21069431], [80.31263733, 13.21068954], [80.31263733, 13.21125031], [80.31291199, 13.21125031], [80.31291199, 13.21181107], [80.31318665, 13.21181107], [80.31318665, 13.21264076], [80.31346893, 13.2126379], [80.31346893, 13.21319485], [80.31375122, 13.21319008], [80.31375122, 13.21403122], [80.31402588, 13.21402645], [80.31402588, 13.2145834], [80.31430817, 13.21457958], [80.31430817, 13.2151413], [80.31458282, 13.21513939], [80.31458282, 13.21569538], [80.31485748, 13.21568966], [80.31485748, 13.21625137], [80.31513977, 13.21625137], [80.31513977, 13.21708298], [80.3154068, 13.21708012], [80.3154068, 13.21791935], [80.31569672, 13.21791744], [80.31569672, 13.21847343], [80.315979, 13.21847057], [80.315979, 13.21875095], [80.31613159, 13.21875095], [80.31624603, 13.21875095], [80.31624603, 13.21903133], [80.31652832, 13.21903133], [80.31652832, 13.21931171], [80.31680298, 13.21930504], [80.31680298, 13.21958256], [80.31708527, 13.21958256], [80.31708527, 13.21986103], [80.31735992, 13.21986103], [80.31735992, 13.22041702], [80.31764221, 13.22041702], [80.31764221, 13.22097111], [80.31791687, 13.22097111], [80.31791687, 13.22125053], [80.31874847, 13.22125053], [80.31874847, 13.22181034], [80.31903839, 13.22181034], [80.31903839, 13.22292042], [80.31931305, 13.22292042], [80.31931305, 13.22402954], [80.31958008, 13.22402954], [80.31958008, 13.22513962], [80.31986237, 13.22513962], [80.31986237, 13.22569561], [80.32013702, 13.22569561], [80.32013702, 13.22597122], [80.32041931, 13.22597122], [80.32041931, 13.22654057], [80.32096863, 13.22654057], [80.32096863, 13.22681046], [80.32125092, 13.22681046], [80.32125092, 13.22736168], [80.3215332, 13.22736168], [80.3215332, 13.22764015], [80.32180786, 13.22764015], [80.32180786, 13.22791958], [80.32208252, 13.22791767], [80.32208252, 13.22819424], [80.32263947, 13.22819424], [80.32263947, 13.22847176], [80.32319641, 13.22846889], [80.32319641, 13.22902966], [80.32430267, 13.22902966], [80.32430267, 13.22931004], [80.32458496, 13.22930622], [80.32458496, 13.22958374], [80.32514191, 13.22958374], [80.32514191, 13.22986221], [80.32569122, 13.22986031], [80.32569122, 13.23013973], [80.32736206, 13.23013973], [80.32736206, 13.23042011], [80.32763672, 13.2304163], [80.32763672, 13.23069382], [80.32791901, 13.23069382], [80.32791901, 13.23097229], [80.32818604, 13.23097038], [80.32818604, 13.23153019], [80.32875061, 13.23153019], [80.32875061, 13.23181057], [80.32902527, 13.2318058], [80.32902527, 13.23208427], [80.32958221, 13.23208427], [80.32958221, 13.23235989], [80.32985687, 13.2323513], [80.32985687, 13.23264027], [80.33040619, 13.23264027], [80.33040619, 13.23291969], [80.33069611, 13.23291588], [80.33069611, 13.23319435], [80.33097076, 13.23319435], [80.33097076, 13.23347187], [80.33125305, 13.23347187], [80.33125305, 13.23375034], [80.33097839, 13.23375034], [80.33097839, 13.23513985], [80.33180237, 13.23513985], [80.33180237, 13.23542118], [80.33347321, 13.23542118], [80.33347321, 13.23513985], [80.33374786, 13.23513985], [80.33374786, 13.23486042], [80.33347321, 13.23486233], [80.33347321, 13.23430634], [80.33319092, 13.2343111], [80.33319092, 13.23402977], [80.3326416, 13.23402977], [80.3326416, 13.23375034], [80.33207703, 13.23375034], [80.33207703, 13.23347187], [80.33152771, 13.23347187], [80.33152771, 13.2318058], [80.33125305, 13.23181057], [80.33125305, 13.23124981], [80.33097839, 13.23124981], [80.33097839, 13.23042011], [80.33069611, 13.23042011], [80.33069611, 13.22958183], [80.33041382, 13.22958374], [80.33041382, 13.22930622], [80.33013916, 13.22931004], [80.33013916, 13.22875023], [80.32985687, 13.22875023], [80.32985687, 13.22846889], [80.32958221, 13.22847176], [80.32958221, 13.22819424], [80.32930756, 13.22819424], [80.32930756, 13.22764015], [80.32958221, 13.22764015], [80.32958221, 13.22654057], [80.32985687, 13.22654057], [80.32985687, 13.2262516], [80.32958221, 13.2262516], [80.32958221, 13.22542], [80.32930756, 13.22542], [80.32930756, 13.22513962], [80.32875061, 13.22513962], [80.32875061, 13.22458076], [80.32847595, 13.22458267], [80.32847595, 13.22402668], [80.32818604, 13.22402954], [80.32818604, 13.22236061], [80.32847595, 13.22236061], [80.32847595, 13.22125053], [80.32791901, 13.22125053], [80.32791901, 13.22069073], [80.32763672, 13.22069454], [80.32763672, 13.21986103], [80.32736206, 13.21986103], [80.32736206, 13.21819019], [80.32707977, 13.21819496], [80.32707977, 13.21791744], [80.32681274, 13.21791935], [80.32681274, 13.21625137], [80.32653046, 13.21625137], [80.32653046, 13.21568966], [80.32624817, 13.21569538], [80.32624817, 13.2145834], [80.32597351, 13.2145834], [80.32597351, 13.21430683], [80.32569122, 13.21431065], [80.32569122, 13.21403122], [80.32541656, 13.21403122], [80.32541656, 13.21375084], [80.32514191, 13.21375084], [80.32514191, 13.21181107], [80.32485199, 13.21181107], [80.32485199, 13.21154022], [80.32457733, 13.21154022], [80.32457733, 13.21096992], [80.32430267, 13.21097183], [80.32430267, 13.21041584], [80.32402802, 13.21042061], [80.32402802, 13.20985985], [80.32375336, 13.20985985], [80.32375336, 13.20958424], [80.32347107, 13.20958424], [80.32347107, 13.20930576], [80.32263947, 13.20931053], [80.32263947, 13.20847034], [80.32291412, 13.20847225], [80.32291412, 13.20819378], [80.32319641, 13.20819378], [80.32319641, 13.20791626], [80.32347107, 13.20792103], [80.32347107, 13.20763969], [80.32375336, 13.20763969], [80.32375336, 13.20681095], [80.32347107, 13.20681095], [80.32347107, 13.20625019], [80.32290649, 13.20625019], [80.32290649, 13.20596981], [80.32263947, 13.20597172], [80.32263947, 13.20485973], [80.32290649, 13.20485973], [80.32290649, 13.20457935], [80.32263947, 13.20458412], [80.32263947, 13.20430565], [80.32290649, 13.20431042], [80.32290649, 13.20346928], [80.32319641, 13.20347214], [80.32319641, 13.20319366], [80.32347107, 13.20319366], [80.32347107, 13.20291805], [80.32319641, 13.20291996], [80.32319641, 13.20263958], [80.32290649, 13.20263958], [80.32290649, 13.20237064], [80.32263947, 13.20237064], [80.32263947, 13.20208168], [80.32236481, 13.20208359], [80.32236481, 13.2015276], [80.32208252, 13.20153046], [80.32208252, 13.2009716], [80.32180786, 13.2009716], [80.32180786, 13.20069408], [80.32152557, 13.20069408], [80.32152557, 13.20041466], [80.32125092, 13.20042038], [80.32125092, 13.20014191], [80.32096863, 13.20014191], [80.32096863, 13.19958115], [80.32125092, 13.19958401], [80.32125092, 13.19930553], [80.3215332, 13.1993103], [80.3215332, 13.19847107], [80.32125092, 13.19847107], [80.32125092, 13.19736099], [80.32096863, 13.19736099], [80.32096863, 13.19680977], [80.32068634, 13.19680977], [80.32068634, 13.19653034], [80.32041931, 13.19653034], [80.32041931, 13.19597054], [80.32013702, 13.1959734], [80.32013702, 13.19569492], [80.31986237, 13.19569111], [80.31986237, 13.1954174], [80.31958008, 13.19542027], [80.31958008, 13.19486141], [80.31930542, 13.19486141], [80.31930542, 13.19430542], [80.31903839, 13.19431019], [80.31903839, 13.19181156], [80.31874847, 13.19181156], [80.31874847, 13.19124889], [80.31846619, 13.19124889], [80.31846619, 13.19069004], [80.31819153, 13.19069481], [80.31819153, 13.18958282], [80.31791687, 13.18958282], [80.31791687, 13.18930531], [80.31764221, 13.18931198], [80.31764221, 13.18625069], [80.31735992, 13.18625069], [80.31735992, 13.18486023], [80.31708527, 13.18486023], [80.31708527, 13.18375015], [80.31680298, 13.18375015], [80.31680298, 13.18208027], [80.31652832, 13.18208218], [80.31652832, 13.18124962], [80.31625366, 13.18124962], [80.31625366, 13.1809721], [80.31597137, 13.1809721], [80.31597137, 13.18013763], [80.31569672, 13.18013954], [80.31569672, 13.17986012], [80.3154068, 13.17986012], [80.3154068, 13.17957973], [80.31513977, 13.17958355], [80.31513977, 13.17930603], [80.31485748, 13.1793108], [80.31485748, 13.17875004], [80.31458282, 13.17875004], [80.31458282, 13.17792034], [80.31430817, 13.17792034], [80.31430817, 13.17735958], [80.31458282, 13.17736244], [80.31458282, 13.17708397], [80.31430817, 13.17708397], [80.31430817, 13.17652798], [80.31402588, 13.17653179], [80.31402588, 13.17625046], [80.31375122, 13.17625046], [80.31375122, 13.17597198], [80.31346893, 13.17597198], [80.31346893, 13.1740284], [80.31318665, 13.1740303], [80.31318665, 13.17319107], [80.31291962, 13.17319584], [80.31291962, 13.17236233], [80.31263733, 13.17236233], [80.31263733, 13.17124939], [80.31236267, 13.17124939], [80.31236267, 13.17041969], [80.31208038, 13.17041969], [80.31208038, 13.16875076], [80.31181335, 13.16875076], [80.31181335, 13.16764069], [80.31153107, 13.16764069], [80.31153107, 13.16736126], [80.31124878, 13.16736126], [80.31124878, 13.16680527], [80.31096649, 13.16681194], [80.31096649, 13.1659708], [80.31069183, 13.1659708], [80.31069183, 13.16569519], [80.31041718, 13.16569519], [80.31041718, 13.16458321], [80.31014252, 13.16458321], [80.31014252, 13.16319466], [80.3095932, 13.16319942], [80.3095932, 13.16292095], [80.30930328, 13.16292095], [80.30930328, 13.16236115], [80.30874634, 13.16236115], [80.30874634, 13.1609726], [80.30819702, 13.1609726], [80.30819702, 13.15986061], [80.30791473, 13.15986061], [80.30791473, 13.15930653], [80.30764008, 13.15931129], [80.30764008, 13.15847015], [80.30735779, 13.15847301], [80.30735779, 13.15791607], [80.30708313, 13.15792084], [80.30708313, 13.15764141], [80.30735779, 13.15764141], [80.30735779, 13.15736008], [80.30708313, 13.15736008], [80.30708313, 13.15681076], [80.30680847, 13.15681076], [80.30680847, 13.15625], [80.30652618, 13.15625], [80.30652618, 13.15569019], [80.30625153, 13.15569401], [80.30625153, 13.15541553], [80.30596924, 13.15542126], [80.30596924, 13.15513992], [80.30568695, 13.15513992], [80.30568695, 13.15458202], [80.30541992, 13.15458202], [80.30541992, 13.15402794], [80.30513763, 13.15403271], [80.30513763, 13.15375042], [80.30486298, 13.15375042], [80.30486298, 13.15235996], [80.30513763, 13.15235996], [80.30513763, 13.15207958], [80.30486298, 13.15208435], [80.30486298, 13.15180588], [80.30458069, 13.15181065], [80.30458069, 13.15069199], [80.30430603, 13.15069389], [80.30430603, 13.15041637], [80.30374908, 13.15042019], [80.30374908, 13.15013981], [80.3034668, 13.15013981], [80.3034668, 13.14931011], [80.30319214, 13.14931011], [80.30319214, 13.14875031], [80.30291748, 13.14875031], [80.30291748, 13.14764023], [80.30264282, 13.14764023], [80.30264282, 13.14735889], [80.30236053, 13.14736176], [80.30236053, 13.14680576], [80.30208588, 13.14680958], [80.30208588, 13.14625168], [80.30179596, 13.14625168], [80.30179596, 13.1459713], [80.30152893, 13.1459713], [80.30152893, 13.14541531], [80.30124664, 13.14542007], [80.30124664, 13.14513016], [80.30097198, 13.14513969], [80.30097198, 13.14458275], [80.30069733, 13.14458275], [80.30069733, 13.14402676], [80.30042267, 13.14402962], [80.30042267, 13.14347076], [80.30014038, 13.14347363], [80.30014038, 13.14319324], [80.29985809, 13.14319324], [80.29985809, 13.14291668], [80.30014038, 13.14291954], [80.30014038, 13.14264202], [80.29985809, 13.14264202], [80.29985809, 13.14042187], [80.29957581, 13.14042187], [80.29957581, 13.14014053], [80.29930878, 13.14014053], [80.29930878, 13.13932133], [80.29902649, 13.13932133], [80.29902649, 13.13875103], [80.29985809, 13.13875103], [80.29985809, 13.13764095], [80.29957581, 13.13764095], [80.29957581, 13.13653088], [80.29930878, 13.13653088], [80.29930878, 13.13568974], [80.29875183, 13.13569546], [80.29875183, 13.13458347], [80.29930878, 13.13458347], [80.29930878, 13.13430691], [80.29985809, 13.13431072], [80.29985809, 13.13319016], [80.30014038, 13.13319492], [80.30014038, 13.1329174], [80.30042267, 13.13292122], [80.30042267, 13.13264084], [80.30069733, 13.13264084], [80.30069733, 13.13236046], [80.30041504, 13.13236046], [80.30041504, 13.13208199], [80.29763794, 13.13208199], [80.29763794, 13.13097191], [80.29792023, 13.13097191], [80.29792023, 13.13069439], [80.29819489, 13.13069439], [80.29819489, 13.13041592], [80.29846954, 13.13042068], [80.29846954, 13.13013077], [80.29875183, 13.1301384], [80.29875183, 13.12930584], [80.29846954, 13.12931061], [80.29846954, 13.12763977], [80.29818726, 13.12763977], [80.29818726, 13.12736034], [80.29792023, 13.12736225], [80.29792023, 13.12680626], [80.29763794, 13.12681103], [80.29763794, 13.12661934], [80.29763794, 13.12652779], [80.2979126, 13.12652969], [80.2979126, 13.12597179], [80.29818726, 13.12597179], [80.29818726, 13.12568855], [80.29846954, 13.12569427], [80.29846954, 13.12485981], [80.29819489, 13.12485981], [80.29819489, 13.12430573], [80.29763794, 13.12431145], [80.29763794, 13.12403011], [80.2979126, 13.12403011], [80.2979126, 13.12374973], [80.29846954, 13.12374973], [80.29846954, 13.12347031], [80.29875183, 13.12347221], [80.29875183, 13.12319374], [80.29958344, 13.12319374], [80.29958344, 13.12291622], [80.29985809, 13.12292004], [80.29985809, 13.12236023], [80.30014038, 13.12236214], [80.30014038, 13.12152767], [80.30042267, 13.12152958], [80.30042267, 13.12125015], [80.30069733, 13.12125015], [80.30069733, 13.12096024], [80.30097198, 13.12097168], [80.30097198, 13.12069416], [80.30124664, 13.12069416], [80.30124664, 13.1198616], [80.30152893, 13.1198616], [80.30152893, 13.11874866], [80.30179596, 13.11874866], [80.30179596, 13.11763954], [80.30236053, 13.11763954], [80.30236053, 13.11653042], [80.30264282, 13.11653042], [80.30264282, 13.11625195], [80.30236053, 13.11625195], [80.30236053, 13.11515141], [80.30208588, 13.11515141], [80.30208588, 13.11458111], [80.30236053, 13.11458302], [80.30236053, 13.11347103], [80.30263519, 13.11347103], [80.30263519, 13.11319542], [80.30319214, 13.11319542], [80.30319214, 13.11291695], [80.3034668, 13.11292171], [80.3034668, 13.11264133], [80.30374908, 13.11264133], [80.30374908, 13.11209202], [80.304039, 13.11209202], [80.304039, 13.11153126], [80.30458069, 13.11153126], [80.30458069, 13.11125088], [80.30486298, 13.11125088], [80.30486298, 13.11069012], [80.30458069, 13.11069489], [80.30458069, 13.1095829], [80.30486298, 13.1095829], [80.30486298, 13.10791683], [80.30458069, 13.10792065], [80.30458069, 13.10736275], [80.30513763, 13.10736275], [80.30513763, 13.10708046], [80.30486298, 13.10708332], [80.30486298, 13.10680676], [80.30430603, 13.10681057], [80.30430603, 13.10653114], [80.304039, 13.10653114], [80.304039, 13.10542107], [80.30374908, 13.10542107], [80.30374908, 13.10431099], [80.30319214, 13.10430431], [80.30319214, 13.10458469], [80.30263519, 13.10458469], [80.30263519, 13.10486031], [80.30208588, 13.10486031], [80.30208588, 13.10514069], [80.30179596, 13.10514069], [80.30179596, 13.10542107], [80.30208588, 13.10541725], [80.30208588, 13.10597324], [80.30152893, 13.10596085], [80.30152893, 13.10764122], [80.30291748, 13.10764122], [80.30291748, 13.11013889], [80.3034668, 13.11013889], [80.3034668, 13.11041927], [80.30374908, 13.11041927], [80.30374908, 13.11153126], [80.30319214, 13.11153126], [80.30319214, 13.11181164], [80.30263519, 13.11180496], [80.30264282, 13.11236095], [80.30208588, 13.11236095], [80.30208588, 13.11292171], [80.30179596, 13.11292171], [80.30179596, 13.11236095], [80.30152893, 13.11236095], [80.30152893, 13.11181164], [80.30124664, 13.11181164], [80.30124664, 13.11041927], [80.30097198, 13.11041927], [80.30097198, 13.10986137], [80.30069733, 13.10986137], [80.30069733, 13.1095829], [80.30041504, 13.1095829], [80.30041504, 13.10902882], [80.30014038, 13.10902882], [80.30014038, 13.1087513], [80.30042267, 13.1087513], [80.30041504, 13.10791683], [80.30014038, 13.10792065], [80.30014038, 13.10653114], [80.29985809, 13.10653114], [80.29985809, 13.10569], [80.29958344, 13.10569477], [80.29958344, 13.10458469], [80.29930878, 13.10458469], [80.29930878, 13.10375023], [80.29902649, 13.10375023], [80.29902649, 13.10264111], [80.29875183, 13.10264111], [80.29875183, 13.10181141], [80.29846954, 13.10181141], [80.29846954, 13.10042095], [80.29902649, 13.10042095], [80.29902649, 13.10015202], [80.29957581, 13.10015202], [80.29957581, 13.09986019], [80.30041504, 13.0998621], [80.30041504, 13.09958363], [80.30097198, 13.09958363], [80.30097198, 13.09930611], [80.30124664, 13.09931087], [80.30124664, 13.09902954], [80.30152893, 13.09902954], [80.30152893, 13.09875011], [80.30097198, 13.09875011], [80.30097198, 13.09818935], [80.30069733, 13.09819412], [80.30069733, 13.09791565], [80.30014038, 13.09792042], [80.30014038, 13.09735966], [80.29985809, 13.09736156], [80.29985809, 13.09708405], [80.29875183, 13.09708405], [80.29875183, 13.09680557], [80.29846954, 13.09680557], [80.29846954, 13.09708405], [80.29819489, 13.09708405], [80.29819489, 13.09736156], [80.29763794, 13.09736156], [80.29763794, 13.09819412], [80.29708099, 13.09819412], [80.29708099, 13.09624958], [80.29680634, 13.09624958], [80.29680634, 13.09597015], [80.29652405, 13.09597206], [80.29652405, 13.09569359], [80.29624939, 13.09569359], [80.29624939, 13.0951376], [80.2959671, 13.09514046], [80.2959671, 13.09486198], [80.29569244, 13.09486198], [80.29569244, 13.09347153], [80.29652405, 13.09347153], [80.29652405, 13.09319401], [80.29708099, 13.09319401], [80.29708099, 13.09291458], [80.2979126, 13.0929203], [80.2979126, 13.09264183], [80.29818726, 13.09264183], [80.29818726, 13.0923624], [80.29958344, 13.0923624], [80.29958344, 13.09208393], [80.30014038, 13.09208393], [80.30014038, 13.0923624], [80.30069733, 13.0923624], [80.30069733, 13.09264183], [80.30097198, 13.09264183], [80.30097198, 13.0929203], [80.30124664, 13.09291458], [80.30124664, 13.09319401], [80.30152893, 13.09319401], [80.30152893, 13.09347153], [80.30179596, 13.09347153], [80.30179596, 13.09375191], [80.30208588, 13.09375], [80.30208588, 13.09402847], [80.30236053, 13.09402084], [80.30236053, 13.09430981], [80.30264282, 13.09430981], [80.30264282, 13.09514046], [80.30291748, 13.09514046], [80.30291748, 13.09542274], [80.30319214, 13.09541798], [80.30319214, 13.09569359], [80.3034668, 13.09569073], [80.3034668, 13.09681129], [80.30291748, 13.09680557], [80.30291748, 13.09708405], [80.30263519, 13.09708405], [80.30263519, 13.09735966], [80.30291748, 13.09735966], [80.30291748, 13.09902954], [80.30319214, 13.09902763], [80.30319214, 13.09958363], [80.30347443, 13.09958363], [80.30347443, 13.1006937], [80.30374908, 13.1006918], [80.30374908, 13.10124969], [80.304039, 13.10124969], [80.304039, 13.10153103], [80.30458069, 13.10153103], [80.30458069, 13.10181141], [80.30513763, 13.10181141], [80.30513763, 13.10153103], [80.30596924, 13.10153103], [80.30596924, 13.10042095], [80.30568695, 13.10042095], [80.30568695, 13.10015202], [80.30513763, 13.10015202], [80.30513763, 13.09986019], [80.30486298, 13.0998621], [80.30486298, 13.09930611], [80.30458069, 13.09931087], [80.30458069, 13.09818935], [80.30486298, 13.09819412], [80.30486298, 13.09791565], [80.30458069, 13.09792042], [80.30458069, 13.09764004], [80.30430603, 13.09764004], [80.30430603, 13.09707928], [80.30403137, 13.09708405], [80.30403137, 13.09624958], [80.30430603, 13.09624958], [80.30430603, 13.09597015], [80.30458069, 13.09597206], [80.30458069, 13.09569359], [80.30430603, 13.09569359], [80.30430603, 13.09375], [80.304039, 13.09375191], [80.304039, 13.09264183], [80.30374908, 13.09264183], [80.30374908, 13.09208107], [80.30347443, 13.09208393], [80.30347443, 13.09097099], [80.30319214, 13.09097958], [80.30319214, 13.08958054], [80.30291748, 13.0895834], [80.30291748, 13.08930492], [80.30264282, 13.08930969], [80.30264282, 13.08903027], [80.30208588, 13.08903027], [80.30208588, 13.08875084], [80.30179596, 13.08875084], [80.30179596, 13.08847141], [80.30152893, 13.08847332], [80.30152893, 13.08819485], [80.30097198, 13.08819485], [80.30097198, 13.08791733], [80.30069733, 13.08792019], [80.30069733, 13.08708096], [80.30041504, 13.08708286], [80.30041504, 13.08680534], [80.30069733, 13.08681202], [80.30069733, 13.08542156], [80.30042267, 13.08542156], [80.30042267, 13.08485031], [80.30014038, 13.0848608], [80.30014038, 13.08458328], [80.29846954, 13.08458328], [80.29846954, 13.08430481], [80.29818726, 13.08430862], [80.29818726, 13.0840292], [80.29763794, 13.0840292], [80.29763794, 13.08318996], [80.29736328, 13.08319473], [80.29736328, 13.08291721], [80.29708099, 13.08292103], [80.29708099, 13.08236122], [80.29680634, 13.08236122], [80.29680634, 13.08208275], [80.29652405, 13.08208275], [80.29652405, 13.08180523], [80.29624939, 13.0818119], [80.29624939, 13.08125114], [80.2959671, 13.08125114], [80.2959671, 13.0809679], [80.29569244, 13.08097267], [80.29569244, 13.08041668], [80.29541779, 13.08042145], [80.29541779, 13.07986069], [80.2951355, 13.07986069], [80.2951355, 13.0793066], [80.29486847, 13.07931137], [80.29486847, 13.07903957], [80.29458618, 13.07903957], [80.29458618, 13.07847023], [80.29430389, 13.07847309], [80.29430389, 13.07763767], [80.29402924, 13.07764053], [80.29402924, 13.07736015], [80.29374695, 13.07736015], [80.29374695, 13.0765276], [80.29347229, 13.07653141], [80.29347229, 13.07597923], [80.29319763, 13.07597923], [80.29319763, 13.07569027], [80.29291534, 13.07569408], [80.29291534, 13.07541561], [80.29264069, 13.07542133], [80.29264069, 13.07458019], [80.2923584, 13.0745821], [80.2923584, 13.07402802], [80.29207611, 13.07403088], [80.29207611, 13.07374954], [80.29180908, 13.07374954], [80.29180908, 13.07319164], [80.29152679, 13.07319355], [80.29152679, 13.07291603], [80.29125214, 13.07291603], [80.29125214, 13.07152843], [80.29096985, 13.07153034], [80.29096985, 13.07096958], [80.29069519, 13.07097244], [80.29069519, 13.07069397], [80.2904129, 13.0706892], [80.2904129, 13.07013988], [80.29013824, 13.07014179], [80.29013824, 13.06958199], [80.2904129, 13.06958389], [80.2904129, 13.06930637], [80.29013824, 13.06931019], [80.29013824, 13.06847191], [80.28986359, 13.06847191], [80.28986359, 13.06819439], [80.28902435, 13.06819439], [80.28902435, 13.06791782], [80.28819275, 13.06791782], [80.28819275, 13.06819439], [80.28736115, 13.06819439], [80.28736115, 13.06847191], [80.28679657, 13.06847191], [80.2868042, 13.06875038], [80.28630829, 13.06875038], [80.2859726, 13.06875038], [80.2859726, 13.06902981], [80.28569794, 13.06902981], [80.28569794, 13.06875038], [80.28514099, 13.06875038], [80.28514099, 13.06847191], [80.28541565, 13.06847191], [80.28541565, 13.06819439], [80.28569794, 13.06819439], [80.28569794, 13.06791782], [80.28595734, 13.06791782], [80.28624725, 13.06791973], [80.28624725, 13.0676403], [80.28679657, 13.0676403], [80.28679657, 13.06736183], [80.28708649, 13.06736183], [80.28708649, 13.06708145], [80.28736115, 13.06708431], [80.28736115, 13.06624985], [80.2876358, 13.06624985], [80.2876358, 13.06569099], [80.28736115, 13.06569576], [80.28736115, 13.06513977], [80.2876358, 13.06513977], [80.2876358, 13.06374931], [80.28736115, 13.06374931], [80.28736115, 13.06347084], [80.28679657, 13.06347084], [80.28679657, 13.06319141], [80.28541565, 13.06319332], [80.28542328, 13.06347084], [80.2848587, 13.06347084], [80.2848587, 13.06319141], [80.28430176, 13.06319332], [80.28430176, 13.06263924], [80.2840271, 13.06263924], [80.2840271, 13.06153202], [80.28375244, 13.06153202], [80.28375244, 13.06097126], [80.28347015, 13.06097126], [80.28347015, 13.06041718], [80.28375244, 13.06042194], [80.28375244, 13.05847073], [80.28347015, 13.05847263], [80.28347015, 13.05819511], [80.2831955, 13.05819511], [80.2831955, 13.05763912], [80.28291321, 13.05764103], [80.28291321, 13.05736065], [80.28263855, 13.05736065], [80.28263855, 13.05680943], [80.28235626, 13.05680943], [80.28235626, 13.05653095], [80.2820816, 13.05653095], [80.2820816, 13.05486965], [80.28180695, 13.05486965], [80.28180695, 13.05264091], [80.28151703, 13.05264091], [80.28151703, 13.0506897], [80.28125, 13.05069447], [80.28125, 13.04986858], [80.28125, 13.04958534], [80.28097534, 13.04958534], [80.28097534, 13.04874992], [80.28069305, 13.04874992], [80.28069305, 13.04514027], [80.2804184, 13.04514027], [80.2804184, 13.04374981], [80.28069305, 13.04374981], [80.28069305, 13.04293156], [80.2804184, 13.04293156], [80.2804184, 13.04236031], [80.28013611, 13.04236221], [80.28013611, 13.04069424], [80.27986145, 13.04069424], [80.27986145, 13.03986168], [80.28013611, 13.03987122], [80.28013611, 13.03931046], [80.2804184, 13.03931046], [80.2804184, 13.03874969], [80.28069305, 13.03874969], [80.28069305, 13.03846931], [80.2804184, 13.03847122], [80.2804184, 13.03819561], [80.28069305, 13.03819561], [80.28069305, 13.03763962], [80.28098297, 13.03763962], [80.28098297, 13.03735924], [80.28069305, 13.0373621], [80.28069305, 13.03652668], [80.2804184, 13.03652954], [80.2804184, 13.03625202], [80.28013611, 13.03625202], [80.28013611, 13.03542042], [80.27986908, 13.03542042], [80.27986908, 13.03514194], [80.28013611, 13.03514194], [80.28013611, 13.03458118], [80.27986145, 13.03458309], [80.27986145, 13.03041744], [80.27958679, 13.03041935], [80.27958679, 13.02818966], [80.27986145, 13.02819538], [80.27986145, 13.02763939], [80.27958679, 13.0276413], [80.27958679, 13.02681065], [80.27929688, 13.02681065], [80.27929688, 13.02514076], [80.27902985, 13.02514076], [80.27902985, 13.02458], [80.27874756, 13.02458191], [80.27874756, 13.02347183], [80.2784729, 13.02347183], [80.2784729, 13.02319431], [80.27874756, 13.02319431], [80.27874756, 13.02291584], [80.2784729, 13.02292061], [80.2784729, 13.02235985], [80.27874756, 13.02235985], [80.27874756, 13.02180576], [80.2784729, 13.02180576], [80.2784729, 13.01930618], [80.27819824, 13.01931095], [80.27819061, 13.01880455], [80.27819061, 13.01846981], [80.27791595, 13.01847172], [80.27791595, 13.01735973], [80.2776413, 13.01735973], [80.2776413, 13.01624966], [80.27735901, 13.01624966], [80.27735901, 13.01570129], [80.27680969, 13.01570129], [80.27680969, 13.01541996], [80.27625275, 13.01541996], [80.27625275, 13.01513958], [80.2756958, 13.01513958], [80.2756958, 13.01486015], [80.27541351, 13.01486206], [80.27541351, 13.01458359], [80.2748642, 13.01458359], [80.2748642, 13.01430607], [80.27402496, 13.01430607], [80.27402496, 13.01458359], [80.27347565, 13.01458359], [80.27347565, 13.01486206], [80.2729187, 13.01486206], [80.2729187, 13.01458359], [80.27180481, 13.01458359], [80.27180481, 13.01486206], [80.27041626, 13.01486206], [80.27041626, 13.01458359], [80.26985931, 13.01458359], [80.26985931, 13.01430607], [80.26957703, 13.01431274], [80.26957703, 13.01403046], [80.26790619, 13.01403046], [80.26790619, 13.01375198], [80.26772308, 13.01375008], [80.26763916, 13.01375008], [80.26763916, 13.0134716], [80.26708221, 13.0134716], [80.26708221, 13.01319408], [80.26680756, 13.01319408], [80.26680756, 13.01264], [80.26735687, 13.01264191], [80.26735687, 13.01293087], [80.26747894, 13.01291561], [80.27124786, 13.01293087], [80.27124786, 13.01264191], [80.27097321, 13.01264191], [80.27097321, 13.0118103], [80.27124786, 13.0118103], [80.27124786, 13.01124859], [80.27179718, 13.01124859], [80.27179718, 13.01097107], [80.27236176, 13.01097107], [80.27236176, 13.0106926], [80.27263641, 13.0106926], [80.27263641, 13.01097107], [80.27458191, 13.01097107], [80.27458191, 13.01124859], [80.27513885, 13.01124859], [80.27513885, 13.01152992], [80.27540588, 13.01152992], [80.27540588, 13.0118103], [80.2756958, 13.01180553], [80.2756958, 13.01208401], [80.27597046, 13.01208401], [80.27597046, 13.01236153], [80.27625275, 13.01236153], [80.27625275, 13.01264191], [80.2765274, 13.01264191], [80.2765274, 13.01236153], [80.27680206, 13.01236153], [80.27680206, 13.01208401], [80.27708435, 13.01208401], [80.27708435, 13.01097107], [80.27680206, 13.01097107], [80.27680206, 13.01041794], [80.2765274, 13.01042175], [80.2765274, 13.00930977], [80.27625275, 13.00930977], [80.27625275, 13.00847054], [80.27597046, 13.0084734], [80.27597046, 13.00819492], [80.27540588, 13.00819111], [80.27541351, 13.0079174], [80.27485657, 13.00792027], [80.27485657, 13.00764179], [80.27458191, 13.00764179], [80.27458191, 13.00708103], [80.27430725, 13.00708294], [80.27430725, 13.00569534], [80.27458191, 13.00569534], [80.27458191, 13.00513935], [80.27485657, 13.00514126], [80.27485657, 13.00458145], [80.27458191, 13.00458336], [80.27458191, 13.00402737], [80.27430725, 13.00402927], [80.27430725, 13.00376034], [80.27401733, 13.00376034], [80.27401733, 13.00347137], [80.27375031, 13.00347328], [80.27375031, 13.00319481], [80.27347565, 13.00319481], [80.27347565, 13.00263882], [80.27319336, 13.00264072], [80.27319336, 13.0023613], [80.27263641, 13.0023613], [80.27263641, 13.00208282], [80.27236176, 13.00208282], [80.27236176, 13.00180531], [80.2720871, 13.00181198], [80.2720871, 13.00153065], [80.27179718, 13.00153065], [80.27179718, 13.00097275], [80.27153015, 13.00097275], [80.27153015, 13.00042057], [80.27124786, 13.00042057], [80.27124786, 13.00014114], [80.27124786, 12.9998579], [80.27153015, 12.99986076], [80.27153015, 12.99791718], [80.2720871, 12.99792099], [80.2720871, 12.99625015], [80.27179718, 12.99625015], [80.27179718, 12.99514103], [80.27153015, 12.99514103], [80.27153015, 12.99374962], [80.27124786, 12.99374962], [80.27124786, 12.99263954], [80.27097321, 12.99263954], [80.27097321, 12.99125004], [80.27068329, 12.99125004], [80.27068329, 12.99013996], [80.27041626, 12.99013996], [80.27041626, 12.98931122], [80.2701416, 12.98931122], [80.2701416, 12.98876095], [80.26985931, 12.98876095], [80.26985931, 12.98819065], [80.26958466, 12.98819447], [80.26958466, 12.98736191], [80.26930237, 12.98736191], [80.26930237, 12.98569107], [80.26902771, 12.98569584], [80.26902771, 12.98430634], [80.26875305, 12.98431015], [80.26875305, 12.98262978], [80.26847076, 12.98263931], [80.26847076, 12.98124886], [80.26819611, 12.98125076], [80.26819611, 12.97986126], [80.26791382, 12.97986126], [80.26791382, 12.97875118], [80.26763916, 12.97875118], [80.26763916, 12.97736073], [80.26735687, 12.97736073], [80.26735687, 12.97597122], [80.26708221, 12.97597313], [80.26708221, 12.97486115], [80.26680756, 12.97486115], [80.26680756, 12.97375107], [80.2665329, 12.97375107], [80.2665329, 12.97292137], [80.26625061, 12.97292137], [80.26625061, 12.97181129], [80.26597595, 12.97181129], [80.26597595, 12.97097015], [80.26569366, 12.97097301], [80.26569366, 12.9701376], [80.26541901, 12.97014141], [80.26541901, 12.96931076], [80.26513672, 12.96931076], [80.26513672, 12.96819019], [80.26486206, 12.96819401], [80.26486206, 12.96708202], [80.26457977, 12.96708202], [80.26457977, 12.96569443], [80.26430511, 12.96569443], [80.26430511, 12.96458435], [80.26403046, 12.96459103], [80.26403046, 12.96375179], [80.26374817, 12.96375179], [80.26374817, 12.96152115], [80.26347351, 12.96152782], [80.26347351, 12.95986176], [80.26319122, 12.95986176], [80.26319122, 12.95847225], [80.26291656, 12.95847225], [80.26291656, 12.95680523], [80.26264191, 12.95681], [80.26264191, 12.95541954], [80.26235962, 12.95541954], [80.26235962, 12.95446014], [80.26235962, 12.95402718], [80.26207733, 12.95403194], [80.26207733, 12.95236111], [80.26180267, 12.95236111], [80.26180267, 12.95097256], [80.26152802, 12.95097256], [80.26152802, 12.94930458], [80.26125336, 12.94930935], [80.26125336, 12.94736099], [80.26097107, 12.94736099], [80.26097107, 12.94542122], [80.26069641, 12.94542122], [80.26069641, 12.94375134], [80.26040649, 12.94375134], [80.26040649, 12.94181061], [80.26013947, 12.94181061], [80.26013947, 12.93986034], [80.25986481, 12.93986225], [80.25986481, 12.93819427], [80.25958252, 12.93819427], [80.25958252, 12.93680573], [80.25930786, 12.93681145], [80.25930786, 12.93597031], [80.25846863, 12.93597221], [80.25846863, 12.93430614], [80.25874329, 12.93430996], [80.25874329, 12.9323616], [80.25846863, 12.9323616], [80.25846863, 12.93013954], [80.25818634, 12.93013954], [80.25818634, 12.92792034], [80.25791931, 12.92792034], [80.25791931, 12.92569065], [80.25763702, 12.92569542], [80.25763702, 12.92374897], [80.25736237, 12.92375088], [80.25736237, 12.92208099], [80.25708008, 12.9220829], [80.25708008, 12.92041683], [80.25681305, 12.92042065], [80.25681305, 12.91847038], [80.25653076, 12.91847324], [80.25653076, 12.91625118], [80.25624847, 12.91625118], [80.25624847, 12.91374969], [80.25596619, 12.91374969], [80.25596619, 12.91125011], [80.25569916, 12.91125011], [80.25569916, 12.90902996], [80.25541687, 12.90902996], [80.25541687, 12.90680981], [80.25514221, 12.90680981], [80.25514221, 12.90458107], [80.25485992, 12.90458393], [80.25485992, 12.90236092], [80.25458527, 12.90236092], [80.25458527, 12.90013885], [80.25430298, 12.90014172], [80.25430298, 12.89792156], [80.25402832, 12.89792156], [80.25402832, 12.89568996], [80.25375366, 12.89569473], [80.25375366, 12.89291668], [80.25347137, 12.89292145], [80.25347137, 12.88986015], [80.25319672, 12.88986015], [80.25319672, 12.8870821], [80.25291443, 12.8870821], [80.25291443, 12.88486004], [80.25263977, 12.88486004], [80.25263977, 12.88346958], [80.25235748, 12.88347244], [80.25235748, 12.88236237], [80.25208282, 12.88236237], [80.25208282, 12.8815279], [80.25180817, 12.88152981], [80.25180817, 12.88097191], [80.25208282, 12.88097191], [80.25208282, 12.8801403], [80.25235748, 12.8801403], [80.25235748, 12.87874985], [80.25208282, 12.87874985], [80.25208282, 12.87819099], [80.25180817, 12.87819576], [80.25180817, 12.87458324], [80.25152588, 12.87458324], [80.25152588, 12.87319469], [80.25096893, 12.87319469], [80.25096893, 12.87125111], [80.25069427, 12.87125111], [80.25069427, 12.86930466], [80.25096893, 12.86930943], [80.25096893, 12.86903095], [80.25068665, 12.86903095], [80.25068665, 12.86792088], [80.25096893, 12.86792088], [80.25096893, 12.86707973], [80.25069427, 12.8670826], [80.25069427, 12.86625099], [80.25041962, 12.86625099], [80.25041962, 12.86543274], [80.25013733, 12.86543274], [80.25013733, 12.86124992], [80.24986267, 12.86124992], [80.24986267, 12.8601408], [80.24957275, 12.8601408], [80.24957275, 12.85929871], [80.24986267, 12.85930634], [80.24986267, 12.85847187], [80.24958038, 12.85847187], [80.24958038, 12.8568058], [80.24931335, 12.85681057], [80.24931335, 12.85542011], [80.24957275, 12.85542011], [80.24957275, 12.85431004], [80.24931335, 12.85431004], [80.24931335, 12.85153008], [80.24903107, 12.85153008], [80.24903107, 12.84736061], [80.24874878, 12.84736061], [80.24874878, 12.84125137], [80.24846649, 12.84125996], [80.24847412, 12.83901119], [80.24847412, 12.83708477], [80.24819183, 12.83708191], [80.24819183, 12.83319378], [80.24791718, 12.83319378], [80.24791718, 12.83291626], [80.24819183, 12.83292103], [80.24819183, 12.83236027], [80.24791718, 12.83236027], [80.24791718, 12.82680607], [80.24764252, 12.82681274], [80.24764252, 12.82569122], [80.24736023, 12.82569408], [80.24736023, 12.81680489], [80.24764252, 12.81680965], [80.24764252, 12.81096077], [80.24791718, 12.81097317], [80.24791718, 12.80930424], [80.24819183, 12.80931091], [80.24819183, 12.80542088], [80.24791718, 12.80542088], [80.24791718, 12.80515194], [80.24736023, 12.80515194], [80.24736023, 12.80542088], [80.24680328, 12.80542088], [80.24680328, 12.80624962], [80.2454071, 12.80624962], [80.2454071, 12.80597019], [80.24430847, 12.8059721], [80.24430847, 12.80569363], [80.24402618, 12.80569363], [80.24402618, 12.80541611], [80.24208069, 12.80541611], [80.24208069, 12.80569363], [80.24180603, 12.80569363], [80.24180603, 12.8059721], [80.24153137, 12.80597019], [80.24153137, 12.80624962], [80.24124908, 12.80624962], [80.24124908, 12.80708218], [80.24097443, 12.80708218], [80.24097443, 12.80847168], [80.24069214, 12.80847168], [80.24069214, 12.80875111], [80.24097443, 12.80875111], [80.24097443, 12.81236076], [80.24013519, 12.81236076], [80.24014282, 12.81347275], [80.23986053, 12.81347275], [80.23986053, 12.8148613], [80.23958588, 12.8148613], [80.23958588, 12.8154192], [80.23930359, 12.81541729], [80.23930359, 12.81569481], [80.23902893, 12.81569099], [80.23902893, 12.81652927], [80.23874664, 12.81652927], [80.23874664, 12.81736088], [80.23847198, 12.81736088], [80.23847198, 12.81819534], [80.23819733, 12.81819534], [80.23819733, 12.81986141], [80.23792267, 12.81986141], [80.23792267, 12.82292175], [80.23764038, 12.82291794], [80.23764038, 12.82347107], [80.23735809, 12.82347107], [80.23735809, 12.82402992], [80.23707581, 12.82402992], [80.23707581, 12.82514], [80.23680878, 12.82514], [80.23680878, 12.82544136], [80.23680878, 12.82681274], [80.23707581, 12.82681274], [80.23707581, 12.82874966], [80.23735809, 12.82874966], [80.23735809, 12.82985973], [80.23763275, 12.82985973], [80.23763275, 12.83181095], [80.23735809, 12.83180618], [80.23735809, 12.83347225], [80.23707581, 12.83347034], [80.23707581, 12.83403111], [80.23680878, 12.83402824], [80.23680878, 12.83597279], [80.23652649, 12.83596992], [80.23652649, 12.83653069], [80.23625183, 12.83652878], [80.23625183, 12.83708191], [80.23596954, 12.83708], [80.23596954, 12.83764076], [80.23569489, 12.83763885], [80.23569489, 12.83819485], [80.23542023, 12.83819485], [80.23542023, 12.83847332], [80.23513794, 12.83847046], [80.23513794, 12.83903122], [80.23486328, 12.83903122], [80.23486328, 12.83986092], [80.23458099, 12.83986092], [80.23458099, 12.84069538], [80.23430634, 12.84068966], [80.23430634, 12.84152889], [80.23402405, 12.84152699], [80.23402405, 12.84210968], [80.23402405, 12.84347343], [80.23374939, 12.84347057], [80.23374939, 12.84625053], [80.23264313, 12.84625053], [80.23264313, 12.84486103], [80.23291779, 12.84486103], [80.23291779, 12.84319115], [80.23319244, 12.84319496], [80.23319244, 12.84226131], [80.23319244, 12.84180546], [80.2334671, 12.84180927], [80.2334671, 12.83847046], [80.23374939, 12.83847332], [80.23374939, 12.83819485], [80.23402405, 12.83819485], [80.23402405, 12.83763885], [80.23430634, 12.83764076], [80.23430634, 12.83736134], [80.23458099, 12.83736134], [80.23458099, 12.83680439], [80.23486328, 12.83681107], [80.23486328, 12.83568954], [80.23513794, 12.83569431], [80.23513794, 12.83347225], [80.23542023, 12.83347225], [80.23542023, 12.8320837], [80.23569489, 12.8320837], [80.23569489, 12.82680607], [80.23596954, 12.82681274], [80.23596954, 12.82514], [80.23625183, 12.82514], [80.23625183, 12.82402992], [80.23652649, 12.82402992], [80.23652649, 12.82347107], [80.23680878, 12.82347107], [80.23680878, 12.8231926], [80.23652649, 12.8231926], [80.23652649, 12.82264042], [80.23680878, 12.82264042], [80.23680878, 12.81875134], [80.23707581, 12.81875134], [80.23707581, 12.81792164], [80.23735809, 12.81792164], [80.23735809, 12.81763935], [80.23707581, 12.81763935], [80.23707581, 12.81709003], [80.23680878, 12.81709003], [80.23680878, 12.81569099], [80.23708344, 12.81569481], [80.23708344, 12.81458282], [80.23735809, 12.81458282], [80.23735809, 12.81375122], [80.23763275, 12.81375122], [80.23763275, 12.81319046], [80.23791504, 12.81319523], [80.23791504, 12.81263924], [80.23819733, 12.81264114], [80.23819733, 12.8123579], [80.23847198, 12.81236076], [80.23847198, 12.81208324], [80.23874664, 12.81208324], [80.23874664, 12.81152916], [80.23902893, 12.81153107], [80.23902893, 12.81068993], [80.23930359, 12.81069469], [80.23930359, 12.8101387], [80.23902893, 12.81014061], [80.23902893, 12.80986023], [80.23874664, 12.80986023], [80.23874664, 12.80958462], [80.23819733, 12.80958462], [80.23819733, 12.80791569], [80.23792267, 12.80792141], [80.23792267, 12.80624962], [80.23819733, 12.80624962], [80.23819733, 12.80542088], [80.23763275, 12.80542088], [80.23763275, 12.80515194], [80.23735809, 12.80515194], [80.23735809, 12.80486012], [80.23680878, 12.80486012], [80.23680878, 12.80457973], [80.23625183, 12.80458355], [80.23625183, 12.80430603], [80.23596954, 12.8043108], [80.23596954, 12.80375004], [80.23542023, 12.80375004], [80.23542023, 12.80346966], [80.23513794, 12.80347157], [80.23513794, 12.80263805], [80.23486328, 12.80263996], [80.23486328, 12.80209064], [80.23457336, 12.80209064], [80.23457336, 12.80153275], [80.23445892, 12.80153275], [80.23430634, 12.80153275], [80.23430634, 12.80097198], [80.23402405, 12.80097198], [80.23402405, 12.8004179], [80.23374939, 12.80041981], [80.23374939, 12.79986191], [80.2334671, 12.79986191], [80.2334671, 12.79901886], [80.23319244, 12.7990284], [80.23319244, 12.79791641], [80.23291779, 12.79792023], [80.23291779, 12.79681015], [80.23264313, 12.79681015], [80.23264313, 12.79652977], [80.23208618, 12.79652977], [80.23208618, 12.79569054], [80.23374939, 12.7956934], [80.23374939, 12.79541779], [80.2338562, 12.79541779], [80.23401642, 12.79541969], [80.23401642, 12.79486084], [80.23430634, 12.79486084], [80.23430634, 12.79403019], [80.23457336, 12.79403019], [80.23457336, 12.79292202], [80.23486328, 12.79292202], [80.23486328, 12.79208088], [80.23458099, 12.79208279], [80.23458099, 12.79152679], [80.23430634, 12.79153156], [80.23430634, 12.79015064], [80.23401642, 12.79015064], [80.23401642, 12.78903103], [80.23374939, 12.78903103], [80.23374939, 12.78875065], [80.23401642, 12.78875065], [80.23401642, 12.78819275], [80.23430634, 12.78819466], [80.23430634, 12.78791714], [80.23401642, 12.78792191], [80.23401642, 12.78764057], [80.23310089, 12.78764057], [80.23264313, 12.78764057], [80.23264313, 12.78681183], [80.23208618, 12.78681183], [80.23208618, 12.78569031], [80.23180389, 12.78569508], [80.23180389, 12.78486061], [80.23208618, 12.78486061], [80.23208618, 12.78431129], [80.23301697, 12.78430653], [80.23374939, 12.78431129], [80.23374939, 12.78402042], [80.23457336, 12.78402042], [80.23457336, 12.78431129], [80.23513794, 12.78431129], [80.23513794, 12.78402042], [80.23596954, 12.78402901], [80.23596954, 12.78375053], [80.23680878, 12.78375053], [80.23680878, 12.78402901], [80.23792267, 12.78402042], [80.23792267, 12.78875065], [80.23819733, 12.78875065], [80.23819733, 12.78931046], [80.23847198, 12.78930473], [80.23847198, 12.78958321], [80.23874664, 12.78958321], [80.23874664, 12.78930473], [80.23986053, 12.78931046], [80.23986053, 12.78986073], [80.24014282, 12.78986073], [80.24014282, 12.79153156], [80.23986053, 12.79152679], [80.23986053, 12.79319477], [80.23958588, 12.79319096], [80.23958588, 12.79541969], [80.23930359, 12.79541779], [80.23930359, 12.79597092], [80.23902893, 12.79596043], [80.23902893, 12.79652977], [80.23874664, 12.79652786], [80.23874664, 12.80069447], [80.23930359, 12.80069447], [80.23930359, 12.80097198], [80.23958588, 12.80097198], [80.23958588, 12.80125046], [80.23986053, 12.80125046], [80.23986053, 12.80153275], [80.24014282, 12.80153275], [80.24014282, 12.80181122], [80.24041748, 12.80181122], [80.24041748, 12.80209064], [80.24069214, 12.80208397], [80.24069214, 12.80236244], [80.2409668, 12.80235958], [80.2409668, 12.80263996], [80.24375916, 12.80263996], [80.24375916, 12.80125046], [80.24346924, 12.80125046], [80.24346924, 12.80041981], [80.24375916, 12.80041981], [80.24375916, 12.80014038], [80.24485779, 12.80013847], [80.24485779, 12.80097198], [80.24514008, 12.80097198], [80.24514008, 12.80153275], [80.2454071, 12.80153275], [80.2454071, 12.80181122], [80.24569702, 12.80181122], [80.24569702, 12.80209064], [80.24597168, 12.80208397], [80.24597168, 12.80236244], [80.24624634, 12.80235958], [80.24624634, 12.80263996], [80.24819183, 12.80263996], [80.24819183, 12.80235958], [80.24847412, 12.80236244], [80.24847412, 12.80125046], [80.24874878, 12.80125046], [80.24874878, 12.8006916], [80.24903107, 12.80069447], [80.24903107, 12.8004179], [80.24931335, 12.80041981], [80.24931335, 12.79930973], [80.24957275, 12.79930973], [80.24957275, 12.79763985], [80.24931335, 12.79763985], [80.24931335, 12.79596043], [80.24958038, 12.79597092], [80.24958038, 12.79430485], [80.24931335, 12.79430962], [80.24931335, 12.79403019], [80.24957275, 12.79403019], [80.24957275, 12.79347134], [80.24986267, 12.79347134], [80.24986267, 12.79319477], [80.25013733, 12.79319477], [80.25013733, 12.79291725], [80.25041962, 12.79292202], [80.25041962, 12.79236126], [80.25069427, 12.79236126], [80.25069427, 12.79125118], [80.25096893, 12.79125118], [80.25096893, 12.79096889], [80.25152588, 12.7909708], [80.25152588, 12.79069519], [80.25208282, 12.79069519], [80.25208282, 12.79041672], [80.25402832, 12.79041862], [80.25402832, 12.79015064], [80.25430298, 12.79015064], [80.25430298, 12.78903103], [80.2545929, 12.78903103], [80.2545929, 12.78792191], [80.25485992, 12.78792191], [80.25485992, 12.78681183], [80.25514221, 12.78681183], [80.25514221, 12.78486061], [80.25485992, 12.78486061], [80.25485992, 12.78319454], [80.25458527, 12.78319454], [80.25458527, 12.78180695], [80.25430298, 12.78181076], [80.25430298, 12.78042126], [80.25402832, 12.78042126], [80.25402832, 12.7790308], [80.25374603, 12.7790308], [80.25374603, 12.77818966], [80.25347137, 12.77819443], [80.25347137, 12.77708435], [80.25319672, 12.77708435], [80.25319672, 12.77624989], [80.2529068, 12.77625179], [80.2529068, 12.77542019], [80.25263977, 12.77542019], [80.25263977, 12.77485085], [80.25235748, 12.77486229], [80.25235748, 12.77402782], [80.25208282, 12.77402973], [80.25208282, 12.77319145], [80.25180817, 12.77319431], [80.25180817, 12.77264023], [80.25152588, 12.77264023], [80.25152588, 12.77180958], [80.25125122, 12.77180958], [80.25125122, 12.77096939], [80.25096893, 12.77097225], [80.25096893, 12.76986217], [80.25069427, 12.76986217], [80.25069427, 12.76902676], [80.25041962, 12.76904106], [80.25041962, 12.76708126], [80.25013733, 12.76708317], [80.25013733, 12.7662487], [80.24986267, 12.76625156], [80.24986267, 12.7656908], [80.24958038, 12.76569462], [80.24958038, 12.76486111], [80.24930573, 12.76486111], [80.24930573, 12.76402664], [80.24903107, 12.76402855], [80.24903107, 12.76319122], [80.24874878, 12.76319504], [80.24874878, 12.76236057], [80.24847412, 12.76236057], [80.24847412, 12.76152897], [80.24819183, 12.76153088], [80.24819183, 12.76068974], [80.24791718, 12.76069546], [80.24791718, 12.75986099], [80.24764252, 12.75986099], [80.24764252, 12.75902653], [80.24736023, 12.7590313], [80.24736023, 12.7582016], [80.2470932, 12.75819016], [80.24708557, 12.75736141], [80.24680328, 12.75736141], [80.24680328, 12.75652885], [80.24652863, 12.75653076], [80.24652863, 12.75568962], [80.24597168, 12.75569534], [80.24597168, 12.7551384], [80.24624634, 12.75514126], [80.24624634, 12.75485992], [80.24597168, 12.75485992], [80.24597168, 12.75403976], [80.24569702, 12.75403976], [80.24569702, 12.75319195], [80.24541473, 12.75319386], [80.24541473, 12.75236034], [80.24514008, 12.75236034], [80.24514008, 12.75152779], [80.24485779, 12.75153065], [80.24485779, 12.75069046], [80.24458313, 12.75069427], [80.24458313, 12.74985981], [80.24430847, 12.74986172], [80.24430847, 12.74903011], [80.24402618, 12.74903011], [80.24402618, 12.74847031], [80.24375153, 12.74847221], [80.24375153, 12.74763775], [80.24346924, 12.74763966], [80.24346924, 12.74680996], [80.24318695, 12.74680996], [80.24318695, 12.74597168], [80.24291992, 12.74597168], [80.24291992, 12.74514008], [80.24263763, 12.74514198], [80.24263763, 12.74457932], [80.24236298, 12.74458408], [80.24236298, 12.74402809], [80.24208069, 12.74403], [80.24208069, 12.74374962], [80.24180603, 12.74374962], [80.24180603, 12.74208069], [80.24153137, 12.74208355], [80.24153137, 12.7415266], [80.24124908, 12.74153042], [80.24124908, 12.74069118], [80.24097443, 12.74069309], [80.24097443, 12.74013901], [80.24069977, 12.74014187], [80.24069977, 12.73986053], [80.24041748, 12.73986053], [80.24041748, 12.73847103], [80.24013519, 12.73847103], [80.24013519, 12.73763943], [80.23986053, 12.73764229], [80.23986053, 12.73680973], [80.23958588, 12.73680973], [80.23958588, 12.73597145], [80.23930359, 12.73597336], [80.23930359, 12.73541737], [80.23902893, 12.73541927], [80.23902893, 12.73458099], [80.23874664, 12.7345829], [80.23874664, 12.73402691], [80.23847198, 12.73403072], [80.23847198, 12.73318958], [80.23819733, 12.7331953], [80.23819733, 12.73236084], [80.23792267, 12.73236084], [80.23792267, 12.73153114], [80.23763275, 12.73153114], [80.23763275, 12.73097038], [80.23735809, 12.73097324], [80.23735809, 12.73013878], [80.23707581, 12.73014069], [80.23707581, 12.72903061], [80.23680878, 12.72903061], [80.23680878, 12.72819042], [80.23652649, 12.72819519], [80.23652649, 12.72763824], [80.23625183, 12.72764111], [80.23625183, 12.72681141], [80.23596954, 12.72681141], [80.23596954, 12.72597027], [80.23569489, 12.72597218], [80.23569489, 12.72513771], [80.23542023, 12.72513962], [80.23542023, 12.72458172], [80.23513794, 12.72458363], [80.23513794, 12.72375011], [80.23486328, 12.72375011], [80.23486328, 12.72291565], [80.23457336, 12.72292137], [80.23457336, 12.72235966], [80.23430634, 12.72236156], [80.23430634, 12.72152805], [80.23401642, 12.72152996], [80.23401642, 12.72068024], [80.23374939, 12.72069359], [80.23374939, 12.7201376], [80.2334671, 12.72014046], [80.2334671, 12.71930981], [80.23319244, 12.71930981], [80.23319244, 12.71875191], [80.23291779, 12.71875191], [80.23291779, 12.71793175], [80.23264313, 12.71793175], [80.23264313, 12.71708107], [80.23236084, 12.71708393], [80.23236084, 12.71652794], [80.23208618, 12.71652985], [80.23208618, 12.71569061], [80.23180389, 12.71569347], [80.23180389, 12.71486187], [80.23152924, 12.71487141], [80.23152924, 12.71430969], [80.23124695, 12.71430969], [80.23124695, 12.71347141], [80.23097229, 12.71347141], [80.23097229, 12.71263885], [80.23069763, 12.71264172], [80.23069763, 12.71208096], [80.23041534, 12.71208286], [80.23041534, 12.71125126], [80.23014069, 12.71125126], [80.23014069, 12.71041965], [80.2298584, 12.71041965], [80.2298584, 12.70985889], [80.22958374, 12.7098608], [80.22958374, 12.7090292], [80.22930908, 12.7090292], [80.22930908, 12.70819092], [80.22902679, 12.70819473], [80.22902679, 12.70736122], [80.22875214, 12.70736122], [80.22875214, 12.70680523], [80.22846985, 12.7068119], [80.22846985, 12.7059679], [80.22819519, 12.70597267], [80.22819519, 12.70513916], [80.2279129, 12.70514107], [80.2279129, 12.70431137], [80.22763824, 12.70431137], [80.22763824, 12.70347023], [80.22736359, 12.70347309], [80.22736359, 12.70263863], [80.2270813, 12.70264053], [80.2270813, 12.70153141], [80.22680664, 12.70153141], [80.22680664, 12.70014095], [80.22651672, 12.70014095], [80.22651672, 12.69957066], [80.22624969, 12.6995821], [80.22624969, 12.69902802], [80.22598267, 12.69903088], [80.22598267, 12.6979208], [80.22569275, 12.6979208], [80.22569275, 12.69679928], [80.22541809, 12.69680595], [80.22541809, 12.69652843], [80.2251358, 12.69653034], [80.2251358, 12.69570065], [80.22486115, 12.6956892], [80.22486115, 12.69486237], [80.22458649, 12.69486237], [80.22458649, 12.69430637], [80.22429657, 12.69431114], [80.22429657, 12.69347191], [80.22402954, 12.69347191], [80.22402954, 12.6926403], [80.22374725, 12.6926403], [80.22374725, 12.69180965], [80.2234726, 12.69180965], [80.2234726, 12.69069958], [80.22319794, 12.69069958], [80.22319794, 12.69013977], [80.22292328, 12.69013977], [80.22292328, 12.68931007], [80.22263336, 12.68931007], [80.22263336, 12.68847084], [80.2223587, 12.68847084], [80.2223587, 12.68791962], [80.22207642, 12.68791962], [80.22207642, 12.68708134], [80.22180176, 12.68708324], [80.22180176, 12.68624878], [80.2215271, 12.68625164], [80.2215271, 12.68542194], [80.22125244, 12.68542194], [80.22125244, 12.68457031], [80.22097015, 12.68458271], [80.22097015, 12.6837492], [80.2206955, 12.6837492], [80.2206955, 12.68291664], [80.22041321, 12.68291855], [80.22041321, 12.68208122], [80.22013855, 12.68208313], [80.22013855, 12.68124866], [80.21985626, 12.68125057], [80.21985626, 12.6806879], [80.2195816, 12.68069458], [80.2195816, 12.6790266], [80.21901703, 12.67903137], [80.21901703, 12.67819023], [80.21875, 12.678195], [80.21875, 12.67708302], [80.21847534, 12.67708302], [80.21847534, 12.67652893], [80.21819305, 12.67653084], [80.21819305, 12.67597008], [80.2179184, 12.67597294], [80.2179184, 12.67541695], [80.21763611, 12.67542076], [80.21763611, 12.67486], [80.21736145, 12.67486], [80.21736145, 12.67431068], [80.21708679, 12.67431068], [80.21708679, 12.67346954], [80.2168045, 12.6734724], [80.2168045, 12.67263794], [80.21652985, 12.67263794], [80.21652985, 12.67152786], [80.21624756, 12.67153072], [80.21624756, 12.67068958], [80.2159729, 12.67069435], [80.2159729, 12.66985989], [80.21569824, 12.66986179], [80.21569061, 12.66903019], [80.21541595, 12.66903019], [80.21541595, 12.66847038], [80.2151413, 12.66847229], [80.2151413, 12.6679163], [80.21485901, 12.66792011], [80.21485901, 12.66736031], [80.21458435, 12.66736221], [80.21458435, 12.66680622], [80.21430206, 12.66681957], [80.21430206, 12.66596985], [80.2140274, 12.66597176], [80.2140274, 12.66485977], [80.21375275, 12.66485977], [80.21375275, 12.66403008], [80.21346283, 12.66403008], [80.21346283, 12.66292], [80.2131958, 12.66292], [80.2131958, 12.66207886], [80.21291351, 12.66208363], [80.21291351, 12.66124916], [80.21263885, 12.66125202], [80.21263885, 12.66014194], [80.21235657, 12.66014194], [80.21235657, 12.65931034], [80.21208191, 12.65931034], [80.21208191, 12.65819073], [80.21180725, 12.65819454], [80.21180725, 12.65736103], [80.21151733, 12.65736103], [80.21151733, 12.65681171], [80.21125031, 12.65681171], [80.21125031, 12.65597057], [80.21097565, 12.65597343], [80.21097565, 12.65541744], [80.21069336, 12.65541935], [80.21069336, 12.65458965], [80.2104187, 12.65458965], [80.2104187, 12.65402889], [80.21013641, 12.65402889], [80.21013641, 12.65318966], [80.20986176, 12.65319538], [80.20986176, 12.65263939], [80.2095871, 12.6526413], [80.2095871, 12.6518116], [80.20929718, 12.6518116], [80.20929718, 12.65125084], [80.20903015, 12.65125084], [80.20903015, 12.65069008], [80.20874786, 12.65069485], [80.20874786, 12.65041733], [80.20847321, 12.65042114], [80.20847321, 12.64986134], [80.20819092, 12.64986134], [80.20819092, 12.64958477], [80.20791626, 12.64958286], [80.20791626, 12.64819527], [80.2076416, 12.64819527], [80.2076416, 12.64791679], [80.20735931, 12.64792061], [80.20735931, 12.64764118], [80.20707703, 12.64764118], [80.20707703, 12.64735985], [80.20680237, 12.64735985], [80.20680237, 12.64597225], [80.20652771, 12.64597225], [80.20652771, 12.64486027], [80.20625305, 12.64486027], [80.20625305, 12.64402771], [80.20597076, 12.64403057], [80.20597076, 12.64375019], [80.20569611, 12.64375019], [80.20569611, 12.64235973], [80.20540619, 12.64235973], [80.20540619, 12.64181137], [80.20513916, 12.64181137], [80.20513916, 12.64153004], [80.20485687, 12.64153004], [80.20485687, 12.64097023], [80.20458221, 12.64097214], [80.20458221, 12.64013767], [80.20430756, 12.64013958], [80.20430756, 12.63986015], [80.20402527, 12.63986206], [80.20402527, 12.63875008], [80.20375061, 12.63875198], [80.20375061, 12.63818932], [80.20347595, 12.63819408], [80.20347595, 12.63764], [80.20318604, 12.63764], [80.20318604, 12.63707924], [80.20291901, 12.63708401], [80.20291901, 12.63652802], [80.20263672, 12.63652802], [80.20263672, 12.63569355], [80.20236206, 12.63569355], [80.20236206, 12.63486195], [80.20207977, 12.63486195], [80.20207977, 12.63403034], [80.20181274, 12.63403034], [80.20181274, 12.63346004], [80.20153046, 12.63347054], [80.20153046, 12.63263893], [80.20124817, 12.63264179], [80.20124817, 12.63153172], [80.20096588, 12.63153172], [80.20096588, 12.63041973], [80.20069122, 12.63041973], [80.20069122, 12.62958145], [80.20041656, 12.62958336], [80.20041656, 12.62874889], [80.20014191, 12.62874889], [80.20014191, 12.62764072], [80.19985962, 12.62764072], [80.19985962, 12.62653065], [80.19957733, 12.62653065], [80.19957733, 12.6248579], [80.19930267, 12.62486076], [80.19930267, 12.62180424], [80.19902802, 12.62181091], [80.19902802, 12.61819172], [80.19930267, 12.61819363], [80.19930267, 12.61763763], [80.19985962, 12.61763954], [80.19985962, 12.61736012], [80.20014191, 12.61736012], [80.20014191, 12.61625004], [80.19985962, 12.61625004], [80.19985962, 12.61569023], [80.19958496, 12.61569405], [80.19958496, 12.61541557], [80.19930267, 12.6154213], [80.19930267, 12.61513996], [80.19875336, 12.61513996], [80.19875336, 12.61485958], [80.19847107, 12.61486244], [80.19847107, 12.61430645], [80.19819641, 12.61431122], [80.19819641, 12.61375046], [80.19790649, 12.61375046], [80.19790649, 12.6131916], [80.19763947, 12.61319447], [80.19763947, 12.61263847], [80.19735718, 12.61264038], [80.19735718, 12.61208153], [80.19708252, 12.61208439], [80.19708252, 12.61124992], [80.19680786, 12.61124992], [80.19680786, 12.61069107], [80.19652557, 12.61069584], [80.19652557, 12.60986233], [80.19625092, 12.60986233], [80.19625092, 12.60930634], [80.19596863, 12.60931015], [80.19596863, 12.60875034], [80.19568634, 12.60875034], [80.19568634, 12.60819054], [80.19541931, 12.6081934], [80.19541931, 12.60764027], [80.19513702, 12.60764027], [80.19513702, 12.60708141], [80.19486237, 12.60708427], [80.19486237, 12.60652733], [80.19458008, 12.60654068], [80.19458008, 12.60597134], [80.19430542, 12.60597134], [80.19430542, 12.60541534], [80.19403076, 12.60542202], [80.19403076, 12.60431194], [80.19374847, 12.60431194], [80.19374847, 12.6026392], [80.19319153, 12.6026392], [80.19319153, 12.6020813], [80.19291687, 12.60208321], [80.19291687, 12.60180473], [80.19264984, 12.60181046], [80.19264984, 12.60097122], [80.19235992, 12.60097313], [80.19235992, 12.60041714], [80.19208527, 12.60041714], [80.19208527, 12.59958267], [80.19180298, 12.59958267], [80.19180298, 12.59902668], [80.19152832, 12.59903145], [80.19152832, 12.59847069], [80.19125366, 12.5984726], [80.19125366, 12.59819508], [80.19152832, 12.59819508], [80.19152832, 12.59736061], [80.19125366, 12.59736061], [80.19125366, 12.59708309], [80.19097137, 12.59708309], [80.19097137, 12.59652901], [80.19069672, 12.59653091], [80.19069672, 12.59625053], [80.1904068, 12.59625053], [80.1904068, 12.59568977], [80.19013977, 12.59569454], [80.19013977, 12.59486103], [80.18985748, 12.59486103], [80.18985748, 12.5945797], [80.19013977, 12.5945816], [80.19013977, 12.59375095], [80.18985748, 12.59375095], [80.18985748, 12.59346962], [80.18958282, 12.59347343], [80.18958282, 12.59319401], [80.18930817, 12.59319401], [80.18930817, 12.59291553], [80.18902588, 12.59292126], [80.18902588, 12.59181118], [80.18875122, 12.59181118], [80.18875122, 12.59154034], [80.18846893, 12.59154034], [80.18846893, 12.59068966], [80.18819427, 12.59069443], [80.18819427, 12.58902836], [80.18791962, 12.58903027], [80.18791962, 12.58875179], [80.18763733, 12.58875179], [80.18763733, 12.58817959], [80.18736267, 12.58819389], [80.18736267, 12.58791637], [80.18708038, 12.58792114], [80.18708038, 12.58681107], [80.18681335, 12.58681107], [80.18681335, 12.58569241], [80.18653107, 12.58569431], [80.18653107, 12.58430576], [80.18624878, 12.58430958], [80.18624878, 12.58152962], [80.18596649, 12.58152962], [80.18596649, 12.57958126], [80.18569183, 12.57958317], [80.18569183, 12.5793047], [80.18596649, 12.57931042], [80.18596649, 12.57875156], [80.18569183, 12.57875156], [80.18569183, 12.57847118], [80.18541718, 12.57847118], [80.18541718, 12.57763863], [80.18345642, 12.57764244], [80.18345642, 12.57792187], [80.18235779, 12.57792187], [80.18235779, 12.57764244], [80.18180847, 12.57764244], [80.18180847, 12.5773592], [80.18125153, 12.57736111], [80.18125153, 12.57708263], [80.18069458, 12.57708263], [80.18069458, 12.57736111], [80.18013763, 12.5773592], [80.18013763, 12.57764244], [80.17986298, 12.57764244], [80.17986298, 12.57792187], [80.17930603, 12.5779171], [80.17930603, 12.57819462], [80.17874908, 12.57819462], [80.17874908, 12.57847118], [80.17819214, 12.57847118], [80.17819214, 12.57856655], [80.17819214, 12.57875156], [80.17764282, 12.57875156], [80.17764282, 12.57903194], [80.17708588, 12.57903194], [80.17708588, 12.57931042], [80.17680359, 12.5793047], [80.17680359, 12.57958317], [80.17624664, 12.57958126], [80.17624664, 12.57986164], [80.17569733, 12.57986164], [80.17569733, 12.58014202], [80.17542267, 12.58014202], [80.17542267, 12.58041954], [80.17514038, 12.58041763], [80.17514038, 12.58069324], [80.17458344, 12.58069324], [80.17458344, 12.58097363], [80.17402649, 12.58096886], [80.17402649, 12.58125019], [80.17375183, 12.58125019], [80.17375183, 12.58181], [80.17319489, 12.58180618], [80.17319489, 12.5820837], [80.17263794, 12.58208084], [80.17263794, 12.58237076], [80.17208099, 12.58237076], [80.17208099, 12.58263969], [80.17180634, 12.58263969], [80.17180634, 12.58319378], [80.17152405, 12.58319378], [80.17152405, 12.58347225], [80.17124939, 12.58346939], [80.17124939, 12.58403015], [80.1709671, 12.58403015], [80.1709671, 12.58514023], [80.17069244, 12.58514023], [80.17069244, 12.58652973], [80.1709671, 12.58652973], [80.1709671, 12.58681107], [80.17124939, 12.5868063], [80.17124939, 12.58708191], [80.17151642, 12.58708191], [80.17151642, 12.58764172], [80.17180634, 12.58764172], [80.17180634, 12.58792114], [80.17208099, 12.58791637], [80.17208099, 12.58819389], [80.17346954, 12.58819389], [80.17346954, 12.58847237], [80.17375183, 12.58847046], [80.17375183, 12.58875179], [80.17402649, 12.58875179], [80.17402649, 12.58903027], [80.17430878, 12.58902836], [80.17430878, 12.58958435], [80.17457581, 12.58957958], [80.17457581, 12.59014034], [80.17485809, 12.59013844], [80.17485809, 12.59069443], [80.17514038, 12.59069443], [80.17514038, 12.59347343], [80.17541504, 12.59347343], [80.17541504, 12.5945816], [80.17514038, 12.5945797], [80.17514038, 12.59514141], [80.17457581, 12.59514141], [80.17457581, 12.59431076], [80.17430878, 12.59431076], [80.17430878, 12.59346962], [80.17402649, 12.59347343], [80.17402649, 12.59291553], [80.17375183, 12.59292126], [80.17375183, 12.59235954], [80.17346954, 12.59236336], [80.17346954, 12.59180641], [80.17318726, 12.59181118], [80.17318726, 12.59154034], [80.17292023, 12.59154034], [80.17292023, 12.59125042], [80.17263794, 12.59125042], [80.17263794, 12.59097004], [80.17151642, 12.59097004], [80.17151642, 12.59154034], [80.17180634, 12.59154034], [80.17180634, 12.59292126], [80.17208099, 12.59292126], [80.17208099, 12.59403133], [80.17124939, 12.59403133], [80.17124939, 12.59431076], [80.1709671, 12.59431076], [80.1709671, 12.59486103], [80.17124939, 12.59486103], [80.17124939, 12.59514141], [80.17151642, 12.59514141], [80.17151642, 12.59542084], [80.17236328, 12.59542084], [80.17236328, 12.59625053], [80.17208099, 12.59625053], [80.17208099, 12.59653091], [80.17180634, 12.59653091], [80.17180634, 12.59681129], [80.17152405, 12.59680462], [80.17152405, 12.59708309], [80.17180634, 12.59708309], [80.17180634, 12.59736061], [80.17346954, 12.59735203], [80.17346954, 12.59764099], [80.17402649, 12.59764099], [80.17402649, 12.59792137], [80.17430878, 12.5979166], [80.17430878, 12.59819508], [80.17514038, 12.59819508], [80.17514038, 12.5984726], [80.17542267, 12.59847069], [80.17542267, 12.59875107], [80.17569733, 12.59875107], [80.17569733, 12.59903145], [80.17597198, 12.59903145], [80.17597198, 12.59931183], [80.17624664, 12.59930515], [80.17624664, 12.59986115], [80.17597198, 12.59986115], [80.17597198, 12.60014057], [80.17569733, 12.60013866], [80.17569733, 12.60041714], [80.17542267, 12.60041046], [80.17542267, 12.60153198], [80.17569733, 12.60153198], [80.17569733, 12.60236073], [80.17542267, 12.60236073], [80.17542267, 12.6026392], [80.17569733, 12.6026392], [80.17569733, 12.60319519], [80.17597198, 12.60319138], [80.17597198, 12.60348034], [80.17652893, 12.60348034], [80.17652893, 12.6026392], [80.17736053, 12.6026392], [80.17736053, 12.60319519], [80.17763519, 12.60319519], [80.17763519, 12.60374928], [80.17791748, 12.60374928], [80.17791748, 12.60403156], [80.17819214, 12.60402679], [80.17819214, 12.60458279], [80.1784668, 12.60458088], [80.1784668, 12.60514164], [80.17874908, 12.60514164], [80.17874908, 12.60542202], [80.17903137, 12.60541534], [80.17903137, 12.60624886], [80.17930603, 12.60624886], [80.17930603, 12.60680962], [80.17986298, 12.60680485], [80.17986298, 12.60708427], [80.18013763, 12.60708141], [80.18013763, 12.60764027], [80.18041992, 12.60764027], [80.18041992, 12.6081934], [80.18069458, 12.6081934], [80.18069458, 12.60847187], [80.18096924, 12.60847187], [80.18096924, 12.60875034], [80.18125153, 12.60875034], [80.18125153, 12.60902977], [80.18152618, 12.60902786], [80.18152618, 12.60986233], [80.17930603, 12.60986233], [80.17930603, 12.60902786], [80.17903137, 12.60902977], [80.17903137, 12.60819054], [80.17819214, 12.6081934], [80.17819214, 12.60764027], [80.17791748, 12.60764027], [80.17791748, 12.60486126], [80.17763519, 12.60486126], [80.17763519, 12.60430527], [80.17624664, 12.60430527], [80.17624664, 12.60458279], [80.17597198, 12.60458088], [80.17597198, 12.60514164], [80.17569733, 12.60514164], [80.17569733, 12.60542202], [80.17402649, 12.60541534], [80.17402649, 12.60569572], [80.17319489, 12.60569572], [80.17319489, 12.60597134], [80.17263794, 12.60597134], [80.17263794, 12.60624886], [80.17208099, 12.60624886], [80.17208099, 12.60654068], [80.17151642, 12.60654068], [80.17151642, 12.60680962], [80.17041779, 12.60680962], [80.17041779, 12.60654068], [80.16929626, 12.60654068], [80.16929626, 12.60624886], [80.16764069, 12.60624886], [80.16764069, 12.60597134], [80.1673584, 12.60597134], [80.1673584, 12.60569572], [80.16680908, 12.60569572], [80.16680908, 12.60597134], [80.16625214, 12.60597134], [80.16625214, 12.60541534], [80.16596985, 12.60542202], [80.16596985, 12.60514164], [80.16570282, 12.60514164], [80.16570282, 12.60486126], [80.1654129, 12.60486126], [80.1654129, 12.60430527], [80.16513824, 12.60431194], [80.16513824, 12.60374928], [80.16485596, 12.60374928], [80.16485596, 12.60291958], [80.16513824, 12.60291958], [80.16513824, 12.6026392], [80.16570282, 12.6026392], [80.16570282, 12.60236073], [80.16596985, 12.60236073], [80.16596985, 12.6020813], [80.16625214, 12.60208321], [80.16625214, 12.60180473], [80.1673584, 12.60181046], [80.1673584, 12.60153198], [80.16764069, 12.60153198], [80.16764069, 12.60125065], [80.16792297, 12.60125065], [80.16792297, 12.60041046], [80.16764069, 12.60041714], [80.16764069, 12.59986115], [80.16707611, 12.59986115], [80.16707611, 12.60014057], [80.16652679, 12.60013866], [80.16652679, 12.60041714], [80.16625214, 12.60041714], [80.16625214, 12.60069466], [80.16513824, 12.60069466], [80.16513824, 12.60013866], [80.16485596, 12.60014057], [80.16485596, 12.5995779], [80.1645813, 12.59958267], [80.1645813, 12.59875107], [80.16430664, 12.59875107], [80.16430664, 12.59819031], [80.16402435, 12.59819508], [80.16402435, 12.59763908], [80.16374969, 12.59764099], [80.16374969, 12.59735203], [80.16402435, 12.59736061], [80.16402435, 12.59680462], [80.16430664, 12.59681129], [80.16430664, 12.59653091], [80.16401672, 12.59653091], [80.16401672, 12.59568977], [80.16374969, 12.59569454], [80.16374969, 12.59541702], [80.16348267, 12.59542084], [80.16348267, 12.59403133], [80.16401672, 12.59403133], [80.16401672, 12.59375095], [80.16485596, 12.59375095], [80.16485596, 12.59403133], [80.16513824, 12.59403133], [80.16513824, 12.59431076], [80.16569519, 12.59430695], [80.16569519, 12.5945816], [80.16625214, 12.5945797], [80.16625214, 12.59514141], [80.16819763, 12.59514141], [80.16819763, 12.59486103], [80.16847992, 12.59486103], [80.16847229, 12.5945816], [80.1701355, 12.5945816], [80.1701355, 12.59402943], [80.16986084, 12.59403133], [80.16986084, 12.59375095], [80.16958618, 12.59375095], [80.16958618, 12.59346962], [80.16930389, 12.59347343], [80.16930389, 12.59319401], [80.16902924, 12.59319401], [80.16902924, 12.59347343], [80.16874695, 12.59346962], [80.16874695, 12.59375095], [80.16847992, 12.59375095], [80.16847992, 12.59403133], [80.16764069, 12.59403133], [80.16764069, 12.59375095], [80.16652679, 12.59375095], [80.16652679, 12.59346962], [80.16625214, 12.59347343], [80.16625214, 12.59319401], [80.16569519, 12.59319401], [80.16569519, 12.59291553], [80.16542053, 12.59292126], [80.16542053, 12.59264088], [80.16485596, 12.59264088], [80.16485596, 12.59235954], [80.16430664, 12.59236336], [80.16430664, 12.59180641], [80.16401672, 12.59181118], [80.16401672, 12.59125042], [80.16374969, 12.59125042], [80.16374969, 12.58957958], [80.1626358, 12.58958435], [80.1626358, 12.58930588], [80.16234589, 12.58931065], [80.16234589, 12.58903027], [80.16208649, 12.58903027], [80.16208649, 12.58847046], [80.1618042, 12.58847237], [80.1618042, 12.58736229], [80.16152954, 12.58736229], [80.16152954, 12.58625031], [80.16124725, 12.58625031], [80.16124725, 12.58541107], [80.16152954, 12.58541584], [80.16152954, 12.58514023], [80.16179657, 12.58514023], [80.16179657, 12.58485985], [80.16208649, 12.58486176], [80.16208649, 12.58458424], [80.1626358, 12.58458424], [80.1626358, 12.58430576], [80.16348267, 12.58430958], [80.16348267, 12.58403015], [80.16401672, 12.58403015], [80.16401672, 12.58374977], [80.1645813, 12.58374977], [80.1645813, 12.58346939], [80.1654129, 12.58347225], [80.1654129, 12.58319378], [80.16596985, 12.58319378], [80.16596985, 12.58291626], [80.16625214, 12.58292007], [80.16625214, 12.58263969], [80.16652679, 12.58263969], [80.16652679, 12.58237076], [80.16707611, 12.58237076], [80.16707611, 12.58208084], [80.1673584, 12.5820837], [80.1673584, 12.58180618], [80.16764069, 12.58181], [80.16764069, 12.58152962], [80.16819763, 12.58152962], [80.16819763, 12.58125019], [80.16902924, 12.58125019], [80.16902924, 12.58096886], [80.16986084, 12.58097076], [80.16986084, 12.58069324], [80.17041779, 12.58069324], [80.17041779, 12.58041763], [80.17124939, 12.58041954], [80.17124939, 12.58014202], [80.17208099, 12.58014202], [80.17208099, 12.57986164], [80.17318726, 12.57986164], [80.17318726, 12.57958126], [80.17375183, 12.57958317], [80.17375183, 12.5793047], [80.17430878, 12.57931042], [80.17430878, 12.57903194], [80.17457581, 12.57903194], [80.17457581, 12.57875156], [80.17514038, 12.57875156], [80.17514038, 12.57847118], [80.17569733, 12.57847118], [80.17569733, 12.57819462], [80.17652893, 12.57819462], [80.17652893, 12.5779171], [80.17679596, 12.57792187], [80.17679596, 12.57764244], [80.17736053, 12.57764244], [80.17736053, 12.5773592], [80.17772675, 12.57736111], [80.17791748, 12.57736111], [80.17791748, 12.57708263], [80.17819214, 12.57708263], [80.17819214, 12.57680511], [80.17874908, 12.57681179], [80.17874908, 12.57652855], [80.17903137, 12.57652855], [80.17903137, 12.57623959], [80.18013763, 12.57624912], [80.18013763, 12.57597256], [80.18235779, 12.57597256], [80.18235779, 12.57624912], [80.1829071, 12.57623959], [80.1829071, 12.57652855], [80.18402863, 12.57652855], [80.18402863, 12.57623959], [80.18458557, 12.57624912], [80.18458557, 12.57458305], [80.18430328, 12.57458305], [80.18430328, 12.57375145], [80.18402863, 12.57375145], [80.18402863, 12.57317924], [80.18374634, 12.57319546], [80.18374634, 12.57263947], [80.18345642, 12.57264137], [80.18345642, 12.5715313], [80.18319702, 12.5715313], [80.18319702, 12.57125092], [80.1829071, 12.57125092], [80.1829071, 12.57014084], [80.18264008, 12.57014084], [80.18264008, 12.56986141], [80.18235779, 12.56986141], [80.18235779, 12.56930542], [80.18208313, 12.56930923], [80.18208313, 12.56903076], [80.18180847, 12.56903076], [80.18180847, 12.56875134], [80.18152618, 12.56875134], [80.18152618, 12.56818962], [80.18125153, 12.56819534], [80.18125153, 12.56763935], [80.18096924, 12.56764126], [80.18096924, 12.56707954], [80.18069458, 12.56708241], [80.18069458, 12.56569386], [80.18041992, 12.56569386], [80.18041992, 12.56486034], [80.18013763, 12.56486034], [80.18013763, 12.56347179], [80.17986298, 12.56347179], [80.17986298, 12.56236172], [80.17958069, 12.56236172], [80.17958069, 12.56124115], [80.17930603, 12.56124973], [80.17930603, 12.56097221], [80.17903137, 12.56097221], [80.17903137, 12.56041622], [80.17874908, 12.56042004], [80.17874908, 12.56013966], [80.1784668, 12.56013966], [80.1784668, 12.55931091], [80.17819214, 12.55931091], [80.17819214, 12.55792046], [80.17791748, 12.55792046], [80.17791748, 12.55681038], [80.17764282, 12.55681038], [80.17764282, 12.55596924], [80.17736053, 12.5559721], [80.17736053, 12.55541801], [80.17708588, 12.55543137], [80.17708588, 12.55458069], [80.17680359, 12.55458355], [80.17680359, 12.55402756], [80.17652893, 12.55403042], [80.17652893, 12.55347061], [80.17624664, 12.55347061], [80.17624664, 12.55263996], [80.17597198, 12.55264187], [80.17597198, 12.55236053], [80.17569733, 12.55236053], [80.17569733, 12.55097103], [80.17541504, 12.55097103], [80.17541504, 12.55041695], [80.17514038, 12.55042171], [80.17514038, 12.54958057], [80.17485809, 12.54958344], [80.17485809, 12.54874897], [80.17457581, 12.54875088], [80.17457581, 12.54819107], [80.17430878, 12.54819489], [80.17430878, 12.54763889], [80.17402649, 12.54763889], [80.17402649, 12.54708099], [80.17375183, 12.5470829], [80.17375183, 12.5462513], [80.17346954, 12.54626179], [80.17346954, 12.54568958], [80.17319489, 12.5456953], [80.17319489, 12.54513931], [80.17292023, 12.54514122], [80.17292023, 12.54458046], [80.17263794, 12.54458332], [80.17263794, 12.54375076], [80.17236328, 12.54375076], [80.17236328, 12.54291725], [80.17208099, 12.54292107], [80.17208099, 12.54236126], [80.17180634, 12.54236126], [80.17180634, 12.5415287], [80.17151642, 12.54153061], [80.17151642, 12.54069042], [80.17124939, 12.54069519], [80.17124939, 12.53985977], [80.1709671, 12.53985977], [80.1709671, 12.53931141], [80.17069244, 12.53931141], [80.17069244, 12.53847027], [80.17041779, 12.53847218], [80.17041779, 12.53763771], [80.17014313, 12.53764057], [80.17014313, 12.53707123], [80.16986084, 12.53708363], [80.16986084, 12.53625011], [80.16958618, 12.53625011], [80.16958618, 12.53542137], [80.16929626, 12.53542137], [80.16929626, 12.53458023], [80.16902924, 12.53458405], [80.16902924, 12.53374958], [80.16874695, 12.53374958], [80.16874695, 12.53292274], [80.16847992, 12.53292274], [80.16847992, 12.53236198], [80.16819763, 12.53236198], [80.16819763, 12.53153038], [80.16792297, 12.53153038], [80.16792297, 12.53068924], [80.16764069, 12.53069401], [80.16764069, 12.52902794], [80.1673584, 12.52902985], [80.1673584, 12.52875042], [80.16707611, 12.52875042], [80.16707611, 12.52819061], [80.16680908, 12.52819443], [80.16680908, 12.52708435], [80.16652679, 12.52708435], [80.16652679, 12.52541542], [80.16625214, 12.52542019], [80.16625214, 12.52513027], [80.16596985, 12.52513885], [80.16596985, 12.52486134], [80.16569519, 12.52486134], [80.16569519, 12.52291679], [80.16542053, 12.52291965], [80.16542053, 12.52180958], [80.16513824, 12.52180958], [80.16513824, 12.52069092], [80.16486359, 12.52069473], [80.16486359, 12.51930523], [80.1645813, 12.51932144], [80.1645813, 12.5184679], [80.16430664, 12.51847267], [80.16430664, 12.51763916], [80.16401672, 12.51764107], [80.16401672, 12.51653099], [80.16430664, 12.51653099], [80.16430664, 12.51625061], [80.16401672, 12.51625061], [80.16401672, 12.51568985], [80.16374969, 12.51569462], [80.16374969, 12.51458263], [80.16347504, 12.51458263], [80.16347504, 12.51347256], [80.16319275, 12.51347256], [80.16319275, 12.5120821], [80.16291809, 12.5120821], [80.16291809, 12.51041603], [80.1626358, 12.5104208], [80.1626358, 12.50874996], [80.16234589, 12.50874996], [80.16234589, 12.50736046], [80.16208649, 12.50736237], [80.16208649, 12.50597191], [80.1618042, 12.50597191], [80.1618042, 12.50430584], [80.16152954, 12.50430965], [80.16152954, 12.50292015], [80.16124725, 12.50292015], [80.16124725, 12.50152969], [80.1609726, 12.50152969], [80.1609726, 12.49903202], [80.16069794, 12.49903202], [80.16069794, 12.49819088], [80.16041565, 12.49819565], [80.16041565, 12.49652672], [80.16014099, 12.49652863], [80.16014099, 12.49515057], [80.1598587, 12.49515057], [80.1598587, 12.49347115], [80.15958405, 12.49347305], [80.15958405, 12.4920826], [80.1592865, 12.49209023], [80.1592865, 12.49180889], [80.15957642, 12.49180889], [80.15957642, 12.49125099], [80.1592865, 12.49125099], [80.1592865, 12.4904213], [80.1590271, 12.4904213], [80.1590271, 12.48764133], [80.15875244, 12.48764133], [80.15875244, 12.4843111], [80.15847015, 12.4843111], [80.15847015, 12.48153019], [80.15820313, 12.48153019], [80.15820313, 12.47875023], [80.15791321, 12.47875023], [80.15791321, 12.47596931], [80.15763855, 12.47597218], [80.15763855, 12.47347069], [80.15736389, 12.47347069], [80.15736389, 12.47124863], [80.1570816, 12.47125244], [80.1570816, 12.46986103], [80.15680695, 12.46986103], [80.15680695, 12.46902943], [80.15651703, 12.46902943], [80.15651703, 12.46847057], [80.15625, 12.46847343], [80.15625, 12.46763897], [80.15598297, 12.46764088], [80.15598297, 12.46681023], [80.15569305, 12.46681023], [80.15569305, 12.46625137], [80.1554184, 12.46625137], [80.1554184, 12.46568966], [80.15513611, 12.46569538], [80.15513611, 12.46513939], [80.15486145, 12.4651413], [80.15486145, 12.46458054], [80.15458679, 12.4645834], [80.15458679, 12.4640274], [80.15429687, 12.46403122], [80.15429687, 12.46347141], [80.15402985, 12.46347332], [80.15402985, 12.46291733], [80.15374756, 12.46291924], [80.15374756, 12.46254063], [80.15374756, 12.46236134], [80.15345764, 12.46242046], [80.15348053, 12.46181107], [80.15319824, 12.46181107], [80.15319061, 12.46125126], [80.15291595, 12.46125126], [80.15291595, 12.46068954], [80.1526413, 12.46069527], [80.1526413, 12.46013927], [80.15235901, 12.46014118], [80.15235901, 12.45958042], [80.15208435, 12.45958233], [80.15208435, 12.4590292], [80.15180206, 12.45903969], [80.15180206, 12.45847034], [80.1515274, 12.45847225], [80.1515274, 12.45791626], [80.15125275, 12.45792103], [80.15125275, 12.45736027], [80.15097046, 12.45736027], [80.15097046, 12.45680428], [80.1506958, 12.45681095], [80.1506958, 12.45653057], [80.15040588, 12.45653057], [80.15040588, 12.45598125], [80.15013885, 12.45598125], [80.15013885, 12.45569038], [80.1498642, 12.4556942], [80.1498642, 12.45513821], [80.14958191, 12.45514011], [80.14958191, 12.45458031], [80.14930725, 12.45458412], [80.14930725, 12.45430565], [80.14901733, 12.45431137], [80.14901733, 12.45374966], [80.14875031, 12.45374966], [80.14875031, 12.45347023], [80.14847565, 12.45347214], [80.14847565, 12.45291805], [80.14819336, 12.45291805], [80.14819336, 12.45236206], [80.1479187, 12.45236206], [80.1479187, 12.45208359], [80.14763641, 12.45208359], [80.14763641, 12.4515276], [80.1473465, 12.45153046], [80.1473465, 12.45125198], [80.1470871, 12.45125198], [80.1470871, 12.45068932], [80.14680481, 12.45069408], [80.14680481, 12.45014], [80.14653015, 12.45014], [80.14653015, 12.44957924], [80.14624786, 12.44958401], [80.14624786, 12.44930553], [80.14597321, 12.4493103], [80.14597321, 12.44874954], [80.14569092, 12.44874954], [80.14569092, 12.44819069], [80.14541626, 12.44819355], [80.14541626, 12.44791794], [80.1451416, 12.44791985], [80.1451416, 12.44736195], [80.14485931, 12.44736195], [80.14485931, 12.44680977], [80.14457703, 12.44680977], [80.14457703, 12.44625187], [80.14431, 12.44625187], [80.14431, 12.44597054], [80.14402771, 12.44597054], [80.14402771, 12.44541836], [80.14375305, 12.44542027], [80.14375305, 12.44514179], [80.14347076, 12.44514179], [80.14347076, 12.44486141], [80.14319611, 12.44486141], [80.14319611, 12.44430542], [80.14290619, 12.44431019], [80.14290619, 12.44404125], [80.14263916, 12.44404125], [80.14263916, 12.44374943], [80.14235687, 12.44374943], [80.14235687, 12.44319057], [80.14208221, 12.44319534], [80.14208221, 12.44291687], [80.14180756, 12.44291973], [80.14180756, 12.44263935], [80.14154053, 12.44263935], [80.14154053, 12.44208145], [80.14125061, 12.44208336], [80.14125061, 12.44180489], [80.14097595, 12.44180965], [80.14097595, 12.44152927], [80.14068604, 12.44152927], [80.14068604, 12.44097137], [80.14041901, 12.44097328], [80.14041901, 12.44069481], [80.14013672, 12.44069481], [80.14013672, 12.44041729], [80.13986206, 12.4404192], [80.13986206, 12.4398613], [80.13957977, 12.4398613], [80.13957977, 12.43958282], [80.13930511, 12.43958282], [80.13930511, 12.43930531], [80.13903046, 12.43931198], [80.13903046, 12.43875122], [80.13874817, 12.43875122], [80.13874817, 12.43847084], [80.13846588, 12.43847084], [80.13846588, 12.43819046], [80.13819122, 12.43819523], [80.13819122, 12.43763924], [80.13791656, 12.43764114], [80.13791656, 12.43735886], [80.13764191, 12.43736076], [80.13764191, 12.43708324], [80.13735962, 12.43708324], [80.13735962, 12.43652916], [80.13707733, 12.43653107], [80.13707733, 12.43625069], [80.13680267, 12.43625069], [80.13680267, 12.43597126], [80.13652802, 12.43597317], [80.13652802, 12.43541718], [80.13625336, 12.43542099], [80.13625336, 12.43514061], [80.13597107, 12.43514061], [80.13597107, 12.43486977], [80.13569641, 12.43486977], [80.13569641, 12.43431091], [80.13540649, 12.43431091], [80.13540649, 12.43403053], [80.13513947, 12.43403053], [80.13513947, 12.43375111], [80.13485718, 12.43375111], [80.13485718, 12.43319035], [80.13458252, 12.43319511], [80.13458252, 12.43291664], [80.13430786, 12.43292141], [80.13430786, 12.43264103], [80.1340332, 12.43264103], [80.1340332, 12.43208027], [80.13375092, 12.43208218], [80.13375092, 12.43180656], [80.13346863, 12.43181133], [80.13346863, 12.43153095], [80.13318634, 12.43153095], [80.13318634, 12.43097019], [80.13291931, 12.4309721], [80.13291931, 12.43069363], [80.13263702, 12.43069363], [80.13263702, 12.43013763], [80.13237, 12.43014145], [80.13237, 12.42986012], [80.13208008, 12.42986012], [80.13208008, 12.4293108], [80.13181305, 12.4293108], [80.13181305, 12.42903137], [80.13153076, 12.42903137], [80.13153076, 12.42875004], [80.13124847, 12.42875004], [80.13124847, 12.4279213], [80.13096619, 12.4279213], [80.13096619, 12.42735958], [80.13069153, 12.42736244], [80.13069153, 12.42708206], [80.13041687, 12.42708206], [80.13041687, 12.42680645], [80.13014221, 12.42681122], [80.13014221, 12.42625046], [80.12985992, 12.42625046], [80.12985992, 12.42597198], [80.12958527, 12.42597198], [80.12958527, 12.42569447], [80.12930298, 12.42569447], [80.12930298, 12.42541599], [80.12902832, 12.42542267], [80.12902832, 12.42486191], [80.12874603, 12.42486191], [80.12874603, 12.42457867], [80.12847137, 12.42458439], [80.12847137, 12.42374992], [80.12819672, 12.42374992], [80.12819672, 12.42293167], [80.12763977, 12.42293167], [80.12763977, 12.42263985], [80.12735748, 12.42263985], [80.12735748, 12.42236042], [80.12708282, 12.42236233], [80.12708282, 12.42180634], [80.12680817, 12.42181015], [80.12680817, 12.42152977], [80.12652588, 12.42152977], [80.12652588, 12.42097187], [80.12625122, 12.42097187], [80.12625122, 12.42069435], [80.12596893, 12.42069435], [80.12596893, 12.42014027], [80.12568665, 12.42014027], [80.12568665, 12.41987133], [80.12541962, 12.41987133], [80.12541962, 12.41930962], [80.12513733, 12.41930962], [80.12513733, 12.41903019], [80.12486267, 12.41903019], [80.12486267, 12.41847134], [80.12458038, 12.41847134], [80.12458038, 12.41819572], [80.12430573, 12.41819572], [80.12430573, 12.41791534], [80.12403107, 12.41792202], [80.12403107, 12.41736126], [80.12374878, 12.41736126], [80.12374878, 12.41708279], [80.12347412, 12.41708279], [80.12347412, 12.41680527], [80.12317657, 12.41681004], [80.12317657, 12.41624928], [80.12291718, 12.41624928], [80.12291718, 12.41569138], [80.12264252, 12.41569519], [80.12264252, 12.41541672], [80.12236023, 12.41541958], [80.12236023, 12.4151392], [80.1220932, 12.4151392], [80.1220932, 12.4145813], [80.12180328, 12.41458321], [80.12180328, 12.41430473], [80.12152863, 12.41431046], [80.12152863, 12.41292191], [80.12097168, 12.41292191], [80.12097168, 12.41264057], [80.12069702, 12.41264057], [80.12069702, 12.4120779], [80.12041473, 12.41208267], [80.12041473, 12.41125107], [80.11985779, 12.41125107], [80.11985779, 12.41097069], [80.11958313, 12.4109726], [80.11958313, 12.41013908], [80.11930847, 12.41014099], [80.11930847, 12.40986061], [80.11875153, 12.40986061], [80.11875153, 12.40958309], [80.11846924, 12.40958309], [80.11846924, 12.40902901], [80.11818695, 12.40903091], [80.11818695, 12.40875053], [80.11791992, 12.40875053], [80.11791992, 12.40818977], [80.11763763, 12.40819454], [80.11763763, 12.40763855], [80.11737061, 12.40764141], [80.11737061, 12.4070797], [80.11708069, 12.40708256], [80.11708069, 12.40680695], [80.11680603, 12.40681076], [80.11680603, 12.40653133], [80.11653137, 12.40653133], [80.11653137, 12.40596962], [80.11624908, 12.40597343], [80.11624908, 12.40541553], [80.1159668, 12.40542126], [80.1159668, 12.40514088], [80.11569214, 12.40514088], [80.11569214, 12.40487194], [80.11541748, 12.40487194], [80.11541748, 12.40458012], [80.11513519, 12.40458202], [80.11513519, 12.40402794], [80.11486053, 12.4040308], [80.11486053, 12.40375042], [80.11458588, 12.40375042], [80.11458588, 12.40347004], [80.11430359, 12.40347195], [80.11430359, 12.40319443], [80.11402893, 12.40319443], [80.11402893, 12.40291595], [80.11374664, 12.40292072], [80.11374664, 12.40264034], [80.11347198, 12.40264034], [80.11347198, 12.40235996], [80.11319733, 12.40235996], [80.11319733, 12.40207958], [80.11291504, 12.40208435], [80.11291504, 12.40180588], [80.11264038, 12.40180588], [80.11264038, 12.40152836], [80.11235809, 12.40153122], [80.11235809, 12.40125179], [80.11207581, 12.40125179], [80.11207581, 12.40097046], [80.11180878, 12.40097237], [80.11180878, 12.40041637], [80.11152649, 12.40042114], [80.11152649, 12.40014267], [80.11123657, 12.40014267], [80.11123657, 12.39986038], [80.11096954, 12.39986229], [80.11096954, 12.3993063], [80.11068726, 12.39931107], [80.11068726, 12.39902973], [80.11042023, 12.39902973], [80.11042023, 12.39873886], [80.11013794, 12.39875031], [80.11013794, 12.39847183], [80.10986328, 12.39847183], [80.10986328, 12.39791584], [80.10958099, 12.39791965], [80.10958099, 12.39764023], [80.10930634, 12.39764023], [80.10930634, 12.39735985], [80.10902405, 12.39735985], [80.10902405, 12.39708424], [80.10874939, 12.39708424], [80.10874939, 12.39652824], [80.1084671, 12.39653015], [80.1084671, 12.39624977], [80.10820007, 12.39624977], [80.10820007, 12.39596939], [80.10791779, 12.39597225], [80.10791779, 12.39541626], [80.10764313, 12.39542007], [80.10764313, 12.39513969], [80.10736084, 12.39513969], [80.10736084, 12.39486027], [80.10708618, 12.39486217], [80.10708618, 12.3945837], [80.10680389, 12.3945837], [80.10680389, 12.39402771], [80.10652924, 12.39402962], [80.10652924, 12.39375019], [80.10624695, 12.39375019], [80.10624695, 12.39346886], [80.10597229, 12.39347363], [80.10597229, 12.39319324], [80.10569763, 12.39319324], [80.10569763, 12.39291763], [80.1054306, 12.39293098], [80.1054306, 12.39236164], [80.10514069, 12.39236164], [80.10514069, 12.39208126], [80.1048584, 12.39208412], [80.1048584, 12.3918047], [80.10457611, 12.39181042], [80.10457611, 12.39153194], [80.10430908, 12.39153194], [80.10430908, 12.39125156], [80.10402679, 12.39125156], [80.10402679, 12.3906908], [80.10375214, 12.39069557], [80.10375214, 12.3904171], [80.10346985, 12.39042187], [80.10346985, 12.39013863], [80.10320282, 12.39013863], [80.10320282, 12.3898592], [80.1029129, 12.38986111], [80.1029129, 12.38958263], [80.10263824, 12.38958263], [80.10263824, 12.38930511], [80.10235596, 12.38931179], [80.10235596, 12.38875103], [80.1020813, 12.38875103], [80.1020813, 12.38847065], [80.10180664, 12.38847256], [80.10180664, 12.38819313], [80.10152435, 12.38819313], [80.10152435, 12.38791656], [80.10124969, 12.38792038], [80.10124969, 12.38764095], [80.10098267, 12.38764095], [80.10098267, 12.38736057], [80.10069275, 12.38736057], [80.10069275, 12.38680458], [80.10041809, 12.38680458], [80.10041809, 12.38652706], [80.1001358, 12.38653183], [80.1001358, 12.38625145], [80.09986115, 12.38625145], [80.09986115, 12.38597107], [80.09958649, 12.38597107], [80.09958649, 12.38569546], [80.0993042, 12.38569546], [80.0993042, 12.38541698], [80.09902954, 12.38541889], [80.09902954, 12.38514137], [80.09874725, 12.38514137], [80.09874725, 12.38458061], [80.0984726, 12.38458347], [80.0984726, 12.384305], [80.09819794, 12.38431168], [80.09819794, 12.3840313], [80.09792328, 12.3840313], [80.09792328, 12.38376045], [80.09764099, 12.38376045], [80.09764099, 12.38347054], [80.0973587, 12.3834734], [80.0973587, 12.38319492], [80.09707642, 12.38319016], [80.09708405, 12.3829174], [80.09680176, 12.38292122], [80.09680176, 12.38264084], [80.0965271, 12.38264084], [80.0965271, 12.38236141], [80.09625244, 12.38236141], [80.09625244, 12.38208294], [80.09597015, 12.38208294], [80.09597015, 12.38180542], [80.09570313, 12.38180923], [80.09570313, 12.38153076], [80.09541321, 12.38153076], [80.09541321, 12.38125134], [80.09513855, 12.38125134], [80.09513855, 12.38070202], [80.09485626, 12.38070202], [80.09485626, 12.38042068], [80.0945816, 12.38042068], [80.0945816, 12.38014126], [80.09430695, 12.38014126], [80.09430695, 12.37986088], [80.09401703, 12.37986088], [80.09401703, 12.37957954], [80.09375, 12.37958241], [80.09375, 12.37930679], [80.0934906, 12.37931061], [80.0934906, 12.37903118], [80.09320068, 12.37903118], [80.09320068, 12.3787508], [80.0929184, 12.3787508], [80.0929184, 12.37847042], [80.09263611, 12.37847328], [80.09263611, 12.37819386], [80.09236145, 12.37819386], [80.09236145, 12.37791634], [80.09208679, 12.3779211], [80.09208679, 12.37762928], [80.0918045, 12.37763786], [80.0918045, 12.37736034], [80.09152985, 12.37736034], [80.09152985, 12.37708473], [80.09124756, 12.37708473], [80.09124756, 12.37680435], [80.0909729, 12.37681103], [80.0909729, 12.37653065], [80.09069824, 12.37653065], [80.09069061, 12.37597179], [80.09041595, 12.37597179], [80.09041595, 12.37569046], [80.0901413, 12.37569427], [80.0901413, 12.3754158], [80.08985901, 12.37542057], [80.08985901, 12.37514019], [80.08957672, 12.37514019], [80.08957672, 12.37486172], [80.08930206, 12.37486172], [80.08930206, 12.37457085], [80.0890274, 12.3745842], [80.0890274, 12.37402821], [80.08847046, 12.37403011], [80.08847046, 12.37374973], [80.0881958, 12.37374973], [80.0881958, 12.37347031], [80.08763885, 12.37347221], [80.08763885, 12.37337017], [80.08763885, 12.37319374], [80.08747864, 12.37319374], [80.0873642, 12.37319374], [80.0873642, 12.37307072], [80.0873642, 12.37291622], [80.08722687, 12.37291813], [80.08706665, 12.37292099], [80.08708191, 12.37275887], [80.08708191, 12.37236214], [80.08680725, 12.37236214], [80.08680725, 12.37208366], [80.08652496, 12.37208366], [80.08652496, 12.37180614], [80.08625031, 12.37182045], [80.08625031, 12.37152958], [80.08598328, 12.37152958], [80.08598328, 12.37125015], [80.08569336, 12.37125015], [80.08569336, 12.37096977], [80.0854187, 12.37097168], [80.0854187, 12.37069416], [80.08513641, 12.37069416], [80.08513641, 12.37014008], [80.08486176, 12.37014008], [80.08486176, 12.3698597], [80.0845871, 12.3698597], [80.0845871, 12.36957932], [80.08430481, 12.36958408], [80.08430481, 12.36902809], [80.08403015, 12.36903], [80.08403015, 12.36876106], [80.08374786, 12.36876106], [80.08374786, 12.36846924], [80.08347321, 12.3684721], [80.08347321, 12.36819363], [80.08319092, 12.36819363], [80.08319092, 12.36763763], [80.08291626, 12.36763954], [80.08291626, 12.36736202], [80.0826416, 12.36736202], [80.0826416, 12.36708069], [80.08235931, 12.36708355], [80.08235931, 12.36680603], [80.08207703, 12.36680984], [80.08207703, 12.36542034], [80.08180237, 12.36542034], [80.08180237, 12.36486244], [80.08152771, 12.36486244], [80.08152771, 12.36458302], [80.08097076, 12.36458302], [80.08097076, 12.36430454], [80.08069611, 12.36431026], [80.08069611, 12.36403179], [80.08040619, 12.36403179], [80.08040619, 12.36375237], [80.08013916, 12.36375237], [80.08013916, 12.36347103], [80.0798645, 12.36347103], [80.0798645, 12.36319542], [80.07958221, 12.36319542], [80.07958221, 12.36291695], [80.07930756, 12.36291981], [80.07930756, 12.36236095], [80.07902527, 12.36236095], [80.07902527, 12.36180496], [80.07875061, 12.36180973], [80.07875061, 12.36152935], [80.07847595, 12.36152935], [80.07847595, 12.36125088], [80.07818604, 12.36125088], [80.07818604, 12.36097145], [80.07791901, 12.36097336], [80.07791901, 12.36069489], [80.07763672, 12.36069489], [80.07763672, 12.36041737], [80.07736206, 12.36041927], [80.07736206, 12.35986137], [80.07707977, 12.35986137], [80.07707977, 12.3595829], [80.07681274, 12.35958958], [80.07681274, 12.35931015], [80.07653046, 12.35931015], [80.07653046, 12.35903168], [80.07624817, 12.35903168], [80.07624817, 12.3587513], [80.07596588, 12.3587513], [80.07596588, 12.35847092], [80.07569122, 12.35847092], [80.07569122, 12.3581953], [80.07541656, 12.3581953], [80.07541656, 12.35791683], [80.07512665, 12.3579216], [80.07512665, 12.35764122], [80.07488251, 12.35764122], [80.07485962, 12.35736084], [80.07470703, 12.35736084], [80.07457733, 12.35736084], [80.07458496, 12.35719013], [80.07458496, 12.35708332], [80.07430267, 12.35708332], [80.07430267, 12.35680485], [80.07402802, 12.35682106], [80.07402802, 12.35653114], [80.07375336, 12.35653114], [80.07375336, 12.35624886], [80.07347107, 12.35624886], [80.07347107, 12.35597324], [80.07319641, 12.35597324], [80.07319641, 12.35569477], [80.07291412, 12.35569477], [80.07291412, 12.35541725], [80.07263947, 12.35542107], [80.07263947, 12.35514069], [80.07235718, 12.35514069], [80.07235718, 12.35486126], [80.07208252, 12.35486126], [80.07208252, 12.35458279], [80.07180786, 12.35458279], [80.07180786, 12.35430527], [80.0715332, 12.35431099], [80.0715332, 12.35375118], [80.07125092, 12.35375118], [80.07125092, 12.35346127], [80.07096863, 12.35347271], [80.07096863, 12.35319519], [80.07069397, 12.35319519], [80.07069397, 12.35291672], [80.07041931, 12.35292053], [80.07041931, 12.35264111], [80.07013702, 12.35264111], [80.07013702, 12.35208035], [80.06986237, 12.35208225], [80.06986237, 12.35152912], [80.06958008, 12.35153103], [80.06958008, 12.35132122], [80.0694809, 12.35129356], [80.06932068, 12.35125065], [80.06931305, 12.35106087], [80.06930542, 12.3506937], [80.06903076, 12.3506937], [80.06903076, 12.35013771], [80.06874847, 12.35014057], [80.06874847, 12.34986019], [80.06847382, 12.34986019], [80.06847382, 12.3493042], [80.06819153, 12.34931087], [80.06819153, 12.34903145], [80.06791687, 12.34903145], [80.06791687, 12.34846973], [80.06764221, 12.34847164], [80.06764221, 12.34819412], [80.06735992, 12.34819412], [80.06735992, 12.34763813], [80.0670929, 12.34764862], [80.0670929, 12.34735966], [80.06680298, 12.34736156], [80.06680298, 12.34708214], [80.06652832, 12.34708214], [80.06652832, 12.34652805], [80.06624603, 12.34652996], [80.06624603, 12.34624958], [80.06597137, 12.34624958], [80.06597137, 12.34597015], [80.06569672, 12.34597206], [80.06569672, 12.34541607], [80.0654068, 12.34542274], [80.0654068, 12.34514046], [80.06513977, 12.34514046], [80.06513977, 12.34486198], [80.06485748, 12.34486198], [80.06485748, 12.34431267], [80.06458282, 12.34431267], [80.06458282, 12.34403038], [80.06430817, 12.34403038], [80.06430817, 12.34375], [80.06402588, 12.34375], [80.06402588, 12.34318924], [80.06375122, 12.34319401], [80.06375122, 12.34291553], [80.06346893, 12.3429203], [80.06346893, 12.34263992], [80.06318665, 12.34263992], [80.06318665, 12.34235954], [80.06291962, 12.3423624], [80.06291962, 12.34208393], [80.06263733, 12.34208393], [80.06263733, 12.34152794], [80.06236267, 12.34152794], [80.06236267, 12.34125042], [80.06208038, 12.34125042], [80.06208038, 12.34097195], [80.06180573, 12.34097195], [80.06180573, 12.34041786], [80.06153107, 12.34041977], [80.06153107, 12.34014034], [80.06124878, 12.34014034], [80.06124878, 12.33986187], [80.06096649, 12.33986187], [80.06096649, 12.33930969], [80.06069183, 12.33930969], [80.06069183, 12.33903027], [80.06041718, 12.33903027], [80.06041718, 12.33875179], [80.06012726, 12.33875179], [80.06012726, 12.33819103], [80.05986023, 12.3381958], [80.05986023, 12.33791542], [80.0595932, 12.33792019], [80.0595932, 12.33736134], [80.05930328, 12.33736134], [80.05930328, 12.33708286], [80.05902863, 12.33708286], [80.05902863, 12.33624935], [80.05874634, 12.33624935], [80.05874634, 12.33541965], [80.0579071, 12.33541965], [80.0579071, 12.33485889], [80.05764008, 12.3348608], [80.05764008, 12.33458328], [80.05735779, 12.33458328], [80.05735779, 12.33430481], [80.05709076, 12.33430958], [80.05709076, 12.33375072], [80.05680847, 12.33375072], [80.05680847, 12.3334713], [80.05652618, 12.33347321], [80.05652618, 12.33319473], [80.05625153, 12.33319473], [80.05625153, 12.33263874], [80.05596924, 12.33265114], [80.05596924, 12.33236122], [80.05569458, 12.33236122], [80.05569458, 12.33208275], [80.05541992, 12.33208275], [80.05541992, 12.33180523], [80.05513763, 12.3318119], [80.05513763, 12.33153057], [80.05486298, 12.33153057], [80.05486298, 12.33125114], [80.05458069, 12.33125114], [80.05458069, 12.33069038], [80.05430603, 12.33069515], [80.05430603, 12.33041668], [80.05403137, 12.3304224], [80.05403137, 12.33014107], [80.05374908, 12.33014107], [80.05374908, 12.32958126], [80.05319214, 12.32958317], [80.05319214, 12.3293047], [80.05291748, 12.32930946], [80.05291748, 12.32875061], [80.05264282, 12.32875061], [80.05264282, 12.32847118], [80.05236053, 12.32847309], [80.05236053, 12.32819462], [80.05208588, 12.32819462], [80.05208588, 12.32763863], [80.05179596, 12.32764053], [80.05179596, 12.32736111], [80.05152893, 12.32736111], [80.05152893, 12.32708263], [80.05124664, 12.32708263], [80.05124664, 12.32680511], [80.05095673, 12.32681084], [80.05095673, 12.32625103], [80.05069733, 12.32625103], [80.05069733, 12.3259697], [80.04985809, 12.3259697], [80.04985809, 12.32625103], [80.05014038, 12.32625103], [80.05014038, 12.32681084], [80.05041504, 12.32680511], [80.05041504, 12.32736111], [80.05069733, 12.32736111], [80.05069733, 12.32792091], [80.05097198, 12.3279171], [80.05097198, 12.32847309], [80.05124664, 12.32847118], [80.05124664, 12.32903099], [80.05179596, 12.32903099], [80.05179596, 12.32930946], [80.05208588, 12.3293047], [80.05208588, 12.32958317], [80.05264282, 12.32958126], [80.05264282, 12.33014107], [80.05291748, 12.33014107], [80.05291748, 12.33125114], [80.05319214, 12.33125114], [80.05319214, 12.33236122], [80.0534668, 12.33236122], [80.0534668, 12.33292198], [80.05374908, 12.33291721], [80.05374908, 12.33347321], [80.05403137, 12.3334713], [80.05403137, 12.3340292], [80.05430603, 12.3340292], [80.05430603, 12.33458328], [80.05458069, 12.33458138], [80.05458069, 12.33513927], [80.05486298, 12.33513927], [80.05486298, 12.33549023], [80.05486298, 12.33569527], [80.0550766, 12.33569145], [80.05513763, 12.33624935], [80.05541992, 12.33624935], [80.05541992, 12.33652973], [80.05569458, 12.33652687], [80.05569458, 12.33708286], [80.05596924, 12.33708096], [80.05596924, 12.33764172], [80.05625153, 12.33764172], [80.05625153, 12.33792019], [80.05652618, 12.33791542], [80.05652618, 12.33847141], [80.05680847, 12.33845997], [80.05680847, 12.33903027], [80.05708313, 12.33902836], [80.05708313, 12.33986187], [80.05735779, 12.33986187], [80.05735779, 12.34069443], [80.05764008, 12.34069443], [80.05764008, 12.34152794], [80.05791473, 12.34152794], [80.05791473, 12.3423624], [80.05819702, 12.3423624], [80.05819702, 12.34347153], [80.05847168, 12.34346962], [80.05847168, 12.34403038], [80.05874634, 12.34403038], [80.05874634, 12.34431267], [80.05902863, 12.34431267], [80.05902863, 12.34486198], [80.05930328, 12.34486198], [80.05930328, 12.34514046], [80.0595932, 12.34514046], [80.0595932, 12.34542274], [80.05986023, 12.34541607], [80.05986023, 12.34569359], [80.06012726, 12.34569168], [80.06012726, 12.34624958], [80.06041718, 12.34624958], [80.06041718, 12.34652996], [80.06069183, 12.34652996], [80.06069183, 12.34681129], [80.06124878, 12.34680557], [80.06124878, 12.34708214], [80.06180573, 12.34708214], [80.06180573, 12.34735966], [80.06208038, 12.34735966], [80.06208038, 12.34764862], [80.06236267, 12.34763813], [80.06236267, 12.34819412], [80.06263733, 12.34819412], [80.06263733, 12.34847164], [80.06291962, 12.34846973], [80.06291962, 12.34875011], [80.06346893, 12.34875011], [80.06346893, 12.34931087], [80.06375122, 12.3493042], [80.06375122, 12.34986019], [80.06402588, 12.34986019], [80.06402588, 12.35042095], [80.06375122, 12.35042095], [80.06375122, 12.35181141], [80.06402588, 12.35181141], [80.06402588, 12.35235977], [80.06375122, 12.35235977], [80.06375122, 12.35319519], [80.06346893, 12.35319042], [80.06346893, 12.35375118], [80.06318665, 12.35375118], [80.06318665, 12.35403061], [80.06291962, 12.35403061], [80.06291962, 12.35431099], [80.06236267, 12.35430527], [80.06236267, 12.35458279], [80.06153107, 12.35458279], [80.06153107, 12.35486126], [80.06096649, 12.35486126], [80.06096649, 12.35514069], [80.06041718, 12.35514069], [80.06041718, 12.35542107], [80.05958557, 12.35541725], [80.05958557, 12.35569477], [80.05874634, 12.35569477], [80.05874634, 12.35597324], [80.05764008, 12.35597324], [80.05764008, 12.35624886], [80.05680847, 12.35624886], [80.05680847, 12.35736084], [80.05708313, 12.35736084], [80.05708313, 12.3581953], [80.05735779, 12.35819054], [80.05735779, 12.35931015], [80.05764008, 12.35931015], [80.05764008, 12.36013889], [80.05791473, 12.36013889], [80.05791473, 12.36069489], [80.05819702, 12.36069107], [80.05819702, 12.36236095], [80.05791473, 12.36236095], [80.05791473, 12.36569309], [80.05819702, 12.36569118], [80.05819702, 12.36736202], [80.05680847, 12.36736202], [80.05680847, 12.36763954], [80.05596924, 12.36763954], [80.05596924, 12.36736202], [80.05568695, 12.36736202], [80.05568695, 12.36708069], [80.05541992, 12.36708355], [80.05541992, 12.36680603], [80.05513763, 12.36680984], [80.05513763, 12.36653042], [80.05486298, 12.36653042], [80.05486298, 12.36625195], [80.05458069, 12.36625195], [80.05458069, 12.36597061], [80.05430603, 12.36597061], [80.05430603, 12.36569309], [80.05403137, 12.36569309], [80.05403137, 12.36541843], [80.05374908, 12.36542034], [80.05374908, 12.36486244], [80.05347443, 12.36486244], [80.05347443, 12.36458302], [80.05319214, 12.36458302], [80.05319214, 12.36347103], [80.05291748, 12.36347103], [80.05291748, 12.36319542], [80.05180359, 12.36319542], [80.05180359, 12.36291695], [80.05124664, 12.36291981], [80.05124664, 12.36262989], [80.04957581, 12.36262989], [80.04957581, 12.36291981], [80.04930878, 12.36291695], [80.04930878, 12.36319542], [80.04792023, 12.36319542], [80.04792023, 12.36347103], [80.04763794, 12.36347103], [80.04763794, 12.36375237], [80.04708099, 12.36375237], [80.04708099, 12.36403179], [80.04651642, 12.36403179], [80.04651642, 12.36375237], [80.04429626, 12.36375237], [80.04429626, 12.36347103], [80.04402924, 12.36347103], [80.04402924, 12.36319542], [80.04347229, 12.36319542], [80.04347229, 12.36291695], [80.04319763, 12.36291981], [80.04319763, 12.36262989], [80.04291534, 12.36263943], [80.04291534, 12.36236095], [80.04264069, 12.36236095], [80.04264069, 12.36208057], [80.0423584, 12.36208344], [80.0423584, 12.36152744], [80.04264069, 12.36152935], [80.04264069, 12.36097145], [80.04291534, 12.36097336], [80.04291534, 12.36041737], [80.04319763, 12.36041927], [80.04319763, 12.35986137], [80.04347229, 12.35986137], [80.04347229, 12.35930538], [80.04374695, 12.35931015], [80.04374695, 12.35903168], [80.04402924, 12.35903168], [80.04402924, 12.35847092], [80.04430389, 12.35847092], [80.04430389, 12.3581953], [80.04402924, 12.3581953], [80.04402924, 12.35791683], [80.04374695, 12.3579216], [80.04374695, 12.35764122], [80.04319763, 12.35764122], [80.04319763, 12.35736084], [80.04292297, 12.35736084], [80.04292297, 12.35708141], [80.04264069, 12.35708332], [80.04264069, 12.35680485], [80.0423584, 12.35682106], [80.0423584, 12.35653114], [80.04209137, 12.35653114], [80.04209137, 12.35569], [80.0423584, 12.35569477], [80.0423584, 12.35541725], [80.04264069, 12.35542107], [80.04264069, 12.35486126], [80.0423584, 12.35486126], [80.0423584, 12.35458279], [80.04208374, 12.35458279], [80.04208374, 12.35430527], [80.04180908, 12.35431099], [80.04180908, 12.35403061], [80.04070282, 12.35403061], [80.04070282, 12.35375118], [80.0404129, 12.35375118], [80.0404129, 12.35319042], [80.04013824, 12.35319519], [80.04013824, 12.35291672], [80.0395813, 12.35292053], [80.0395813, 12.35264111], [80.03901672, 12.35264111], [80.03901672, 12.35292053], [80.03847504, 12.35291672], [80.03847504, 12.35319519], [80.03819275, 12.35319519], [80.03819275, 12.35347271], [80.0376358, 12.35346127], [80.0376358, 12.35375118], [80.03736115, 12.35375118], [80.03736115, 12.35319042], [80.03708649, 12.35319519], [80.03708649, 12.3526392], [80.03679657, 12.35264111], [80.03679657, 12.35208035], [80.03652954, 12.35208225], [80.03652954, 12.35180664], [80.03595734, 12.35181141], [80.03595734, 12.35153103], [80.03569794, 12.35153103], [80.03569794, 12.35125065], [80.03514099, 12.35125065], [80.03514099, 12.35097027], [80.03375244, 12.35097027], [80.03375244, 12.35125065], [80.03263855, 12.35125065], [80.03263855, 12.35097027], [80.0320816, 12.35097218], [80.0320816, 12.35041618], [80.03180695, 12.35042095], [80.03180695, 12.35014057], [80.03151703, 12.35014057], [80.03151703, 12.34986019], [80.03125, 12.34986019], [80.03125, 12.3493042], [80.03069305, 12.34931087], [80.03069305, 12.34903145], [80.03015137, 12.34903145], [80.03015137, 12.34875011], [80.02986145, 12.34875011], [80.02986145, 12.34792137], [80.02958679, 12.34792137], [80.02958679, 12.34764862], [80.02929688, 12.34764862], [80.02929688, 12.34735966], [80.02902985, 12.34736156], [80.02902985, 12.34708214], [80.0276413, 12.34708214], [80.0276413, 12.34680557], [80.0267868, 12.34681129], [80.0267868, 12.34652996], [80.02485657, 12.34652996], [80.02485657, 12.34514046], [80.02458191, 12.34514046], [80.02458191, 12.34486198], [80.02263641, 12.34486198], [80.02263641, 12.34403038], [80.0229187, 12.34403038], [80.0229187, 12.34375], [80.02319336, 12.34375], [80.02319336, 12.34318924], [80.02347565, 12.34319401], [80.02347565, 12.3423624], [80.02319336, 12.3423624], [80.02319336, 12.34208393], [80.02041626, 12.34208393], [80.02041626, 12.34180641], [80.01930237, 12.34181023], [80.01930237, 12.34152126], [80.01902771, 12.34152794], [80.01902771, 12.34097195], [80.01847076, 12.34097195], [80.01847076, 12.34069443], [80.0173645, 12.34069443], [80.0173645, 12.34041786], [80.01708221, 12.34041977], [80.01708221, 12.33958054], [80.0173645, 12.33958435], [80.0173645, 12.33930588], [80.01763916, 12.33930969], [80.01763916, 12.33903027], [80.02069092, 12.33903027], [80.02069092, 12.33875179], [80.02098083, 12.33875179], [80.02098083, 12.33845997], [80.0201416, 12.33847141], [80.0201416, 12.3381958], [80.01819611, 12.3381958], [80.01819611, 12.33791542], [80.01763916, 12.33792019], [80.01763916, 12.33708096], [80.01791382, 12.33708286], [80.01791382, 12.33680534], [80.01875305, 12.33681011], [80.01875305, 12.33652973], [80.01847076, 12.33652973], [80.01847076, 12.33597088], [80.01819611, 12.33597088], [80.01819611, 12.33569527], [80.01791382, 12.33569527], [80.01791382, 12.33458328], [80.01763916, 12.33458328], [80.01763916, 12.33374882], [80.01735687, 12.33375072], [80.01735687, 12.33319092], [80.01708221, 12.33319473], [80.01708221, 12.33291721], [80.01680756, 12.33292198], [80.01680756, 12.33208084], [80.01708221, 12.33208275], [80.01708221, 12.33180523], [80.01735687, 12.3318119], [80.01735687, 12.33096886], [80.01708221, 12.33097267], [80.01708221, 12.33069515], [80.01597595, 12.33069515], [80.01597595, 12.33041668], [80.01513672, 12.3304224], [80.01513672, 12.33014107], [80.01431274, 12.33014107], [80.01431274, 12.32986069], [80.01403046, 12.32986069], [80.01403046, 12.32958126], [80.01347351, 12.32958317], [80.01347351, 12.3293047], [80.01319122, 12.32930946], [80.01319122, 12.32903099], [80.01291656, 12.32903099], [80.01291656, 12.32875061], [80.01235962, 12.32875061], [80.01235962, 12.32847118], [80.01208496, 12.32847309], [80.01208496, 12.32819462], [80.01041412, 12.32819462], [80.01041412, 12.32708263], [80.01097107, 12.32708263], [80.01097107, 12.32736111], [80.01125336, 12.32736111], [80.01125336, 12.32764053], [80.01207733, 12.32764053], [80.01207733, 12.32736111], [80.01235962, 12.32736111], [80.01235962, 12.32708263], [80.01264191, 12.32708263], [80.01264191, 12.32680511], [80.01291656, 12.32681084], [80.01291656, 12.32625103], [80.01319122, 12.32625103], [80.01319122, 12.3259697], [80.01347351, 12.32597256], [80.01347351, 12.32291603], [80.01374817, 12.3229208], [80.01374817, 12.32264137], [80.01431274, 12.32264137], [80.01431274, 12.3229208], [80.01457977, 12.32291603], [80.01457977, 12.32319355], [80.0148468, 12.32318974], [80.0148468, 12.32403088], [80.01541901, 12.32403088], [80.01541901, 12.32431126], [80.01569366, 12.32430744], [80.01569366, 12.3245821], [80.01597595, 12.3245821], [80.01597595, 12.32485962], [80.01625061, 12.32485962], [80.01625061, 12.32514095], [80.0165329, 12.32514095], [80.0165329, 12.32542133], [80.01708221, 12.32541656], [80.01708221, 12.32569504], [80.01763916, 12.32569504], [80.01763916, 12.32597256], [80.01821136, 12.3259697], [80.01821136, 12.32625103], [80.01930237, 12.32625103], [80.01930237, 12.32652569], [80.01957703, 12.32652187], [80.01957703, 12.32681084], [80.01985931, 12.32680511], [80.01985931, 12.32708263], [80.0201416, 12.32708263], [80.0201416, 12.32736111], [80.02041626, 12.32736111], [80.02041626, 12.32764053], [80.02069092, 12.32764053], [80.02069092, 12.32792091], [80.02097321, 12.3279171], [80.02097321, 12.32847309], [80.02124786, 12.32847118], [80.02124786, 12.32875061], [80.0220871, 12.32875061], [80.0220871, 12.32903099], [80.02263641, 12.32903099], [80.02263641, 12.32930946], [80.0229187, 12.3293047], [80.0229187, 12.32958317], [80.02319336, 12.32958126], [80.02319336, 12.33014107], [80.02348328, 12.33014107], [80.02348328, 12.3304224], [80.02375031, 12.33041668], [80.02375031, 12.33069515], [80.02402496, 12.33069515], [80.02402496, 12.33097076], [80.02430725, 12.33096886], [80.02430725, 12.33125114], [80.02458191, 12.33125114], [80.02458191, 12.33153057], [80.02485657, 12.33153057], [80.02485657, 12.3318119], [80.02513885, 12.33180523], [80.02513885, 12.33208275], [80.02541351, 12.33208275], [80.02541351, 12.33236122], [80.02597046, 12.33236122], [80.02597046, 12.33265114], [80.02625275, 12.33265114], [80.02625275, 12.33292198], [80.0265274, 12.33291721], [80.0265274, 12.33319473], [80.0267868, 12.33319092], [80.0267868, 12.33375072], [80.02707672, 12.33375072], [80.02707672, 12.33430958], [80.02791595, 12.33430481], [80.02791595, 12.33458328], [80.0284729, 12.33458328], [80.0284729, 12.33430481], [80.03013611, 12.33430481], [80.03013611, 12.33458328], [80.03069305, 12.33458328], [80.03069305, 12.3348608], [80.03151703, 12.33485889], [80.03151703, 12.33513927], [80.0320816, 12.33513927], [80.0320816, 12.33541965], [80.03236389, 12.33541679], [80.03236389, 12.33569527], [80.03263855, 12.33569527], [80.03263855, 12.33597088], [80.03291321, 12.33597088], [80.03291321, 12.33624935], [80.0340271, 12.33624935], [80.0340271, 12.33652973], [80.03542328, 12.33652973], [80.03542328, 12.33681011], [80.03569794, 12.33680534], [80.03569794, 12.33708286], [80.03595734, 12.33708096], [80.03595734, 12.33764172], [80.03708649, 12.33764172], [80.03708649, 12.33792019], [80.03791809, 12.33792019], [80.03791809, 12.33764172], [80.03848267, 12.33764172], [80.03848267, 12.33792019], [80.03930664, 12.33792019], [80.03930664, 12.33764172], [80.0395813, 12.33764172], [80.0395813, 12.33736134], [80.04096985, 12.33736134], [80.04096985, 12.33708286], [80.04152679, 12.33708286], [80.04152679, 12.33680534], [80.04180908, 12.33681011], [80.04180908, 12.33652973], [80.04515076, 12.33652973], [80.04515076, 12.33681011], [80.04541779, 12.33680534], [80.04541779, 12.33708286], [80.04569244, 12.33708286], [80.04569244, 12.33736134], [80.0459671, 12.33736134], [80.0459671, 12.33792019], [80.04624939, 12.33791542], [80.04624939, 12.3381958], [80.04652405, 12.3381958], [80.04652405, 12.33847141], [80.04680634, 12.33845997], [80.04680634, 12.33875179], [80.04708099, 12.33875179], [80.04708099, 12.33930969], [80.04736328, 12.33930588], [80.04736328, 12.33958435], [80.04763794, 12.33958054], [80.04763794, 12.33986187], [80.04792023, 12.33986187], [80.04792023, 12.34041977], [80.04819489, 12.34041786], [80.04819489, 12.34069443], [80.04846954, 12.34069443], [80.04846954, 12.34097195], [80.04875183, 12.34097195], [80.04875183, 12.34125042], [80.04902649, 12.34125042], [80.04902649, 12.34181023], [80.04930878, 12.34180641], [80.04930878, 12.3423624], [80.04957581, 12.34235954], [80.04957581, 12.3429203], [80.04985809, 12.34291553], [80.04985809, 12.34319401], [80.05014038, 12.34319401], [80.05014038, 12.34347153], [80.05042267, 12.34346962], [80.05042267, 12.34375], [80.05069733, 12.34375], [80.05069733, 12.34431267], [80.05095673, 12.34431267], [80.05095673, 12.34459114], [80.05124664, 12.34459114], [80.05124664, 12.34514046], [80.05152893, 12.34514046], [80.05152893, 12.34542274], [80.05208588, 12.34541607], [80.05208588, 12.34569359], [80.05236053, 12.34569359], [80.05236053, 12.34597206], [80.05264282, 12.34597015], [80.05264282, 12.34652996], [80.05291748, 12.34652996], [80.05291748, 12.34681129], [80.05319214, 12.34680557], [80.05319214, 12.34708214], [80.0534668, 12.34708023], [80.05347443, 12.34735966], [80.05403137, 12.34735966], [80.05403137, 12.34764862], [80.05430603, 12.34764862], [80.05430603, 12.34792137], [80.05486298, 12.34791565], [80.05486298, 12.34847164], [80.05513763, 12.34846973], [80.05513763, 12.34875011], [80.05541992, 12.34875011], [80.05541992, 12.34903145], [80.05596924, 12.34903145], [80.05596924, 12.34931087], [80.05625153, 12.3493042], [80.05625153, 12.34958363], [80.05680847, 12.34958363], [80.05680847, 12.34986019], [80.05709076, 12.34986019], [80.05709076, 12.35014057], [80.05735779, 12.35014057], [80.05735779, 12.35042095], [80.05764008, 12.35041618], [80.05764008, 12.3506937], [80.05791473, 12.3506937], [80.05791473, 12.35097218], [80.0595932, 12.35097027], [80.0595932, 12.35125065], [80.05986023, 12.35125065], [80.05986023, 12.35153103], [80.06041718, 12.35153103], [80.06041718, 12.35181141], [80.06069183, 12.35180664], [80.06069183, 12.35208225], [80.06096649, 12.35208035], [80.06096649, 12.35235977], [80.06181335, 12.35235977], [80.06180573, 12.35208225], [80.06208038, 12.35208225], [80.06208038, 12.35180664], [80.06236267, 12.35181141], [80.06236267, 12.35153103], [80.06291962, 12.35153103], [80.06291962, 12.35125065], [80.06318665, 12.35125065], [80.06318665, 12.3506918], [80.06291962, 12.3506937], [80.06291962, 12.35013771], [80.06263733, 12.35014057], [80.06263733, 12.34986019], [80.06236267, 12.34986019], [80.06236267, 12.3493042], [80.06208038, 12.34931087], [80.06208038, 12.34875011], [80.06096649, 12.34875011], [80.06096649, 12.34846973], [80.06041718, 12.34847164], [80.06041718, 12.34819412], [80.06014252, 12.34819412], [80.06014252, 12.34791565], [80.05986023, 12.34792137], [80.05986023, 12.34764862], [80.05930328, 12.34764862], [80.05930328, 12.34735966], [80.05874634, 12.34736156], [80.05874634, 12.34708214], [80.05847168, 12.34708214], [80.05847168, 12.34652805], [80.05819702, 12.34652996], [80.05819702, 12.34624958], [80.0579071, 12.34624958], [80.0579071, 12.34569168], [80.05764008, 12.34569359], [80.05764008, 12.3451376], [80.05735779, 12.34514046], [80.05735779, 12.34346962], [80.05708313, 12.34347153], [80.05708313, 12.34319401], [80.05735779, 12.34319401], [80.05735779, 12.34291553], [80.05709076, 12.3429203], [80.05709076, 12.34208202], [80.05680847, 12.34208393], [80.05680847, 12.34125042], [80.05652618, 12.34125042], [80.05652618, 12.34014034], [80.05625153, 12.34014034], [80.05625153, 12.33958054], [80.05596924, 12.33958435], [80.05596924, 12.33930588], [80.05568695, 12.33930969], [80.05568695, 12.33903027], [80.05541992, 12.33903027], [80.05541992, 12.33845997], [80.05513763, 12.33847141], [80.05513763, 12.33736134], [80.05486298, 12.33736134], [80.05486298, 12.33708286], [80.05458069, 12.33708286], [80.05458069, 12.33652687], [80.05430603, 12.33652973], [80.05430603, 12.33569145], [80.05403137, 12.33569527], [80.05403137, 12.33513927], [80.05374908, 12.33513927], [80.05374908, 12.33485889], [80.05347443, 12.3348608], [80.05347443, 12.33430481], [80.05319214, 12.33430958], [80.05319214, 12.3340292], [80.05291748, 12.3340292], [80.05291748, 12.33375072], [80.05264282, 12.33375072], [80.05264282, 12.3334713], [80.05236053, 12.33347321], [80.05236053, 12.33319473], [80.05208588, 12.33319473], [80.05208588, 12.33291721], [80.05179596, 12.33292198], [80.05179596, 12.33236122], [80.05152893, 12.33236122], [80.05152893, 12.33152676], [80.05124664, 12.33153057], [80.05124664, 12.3312006], [80.05124664, 12.33097267], [80.05097198, 12.33097267], [80.05097198, 12.33084965], [80.05097198, 12.33069515], [80.05084991, 12.33069515], [80.05069733, 12.33069515], [80.05069733, 12.33041668], [80.05042267, 12.3304224], [80.05042267, 12.33014107], [80.05014038, 12.33014107], [80.05014038, 12.32978058], [80.05014038, 12.32958317], [80.04998779, 12.32958317], [80.04985809, 12.32958317], [80.04985809, 12.32942104], [80.04985809, 12.3293047], [80.04957581, 12.32930946], [80.04957581, 12.32907009], [80.04958344, 12.3287487], [80.04930878, 12.3287487], [80.04930878, 12.32847309], [80.04902649, 12.32847309], [80.04902649, 12.32835197], [80.04902649, 12.32819462], [80.04889679, 12.32819462], [80.04875183, 12.32819462], [80.0486908, 12.32792091], [80.04846954, 12.32792091], [80.04846954, 12.32764053], [80.04818726, 12.32764053], [80.04819489, 12.327281], [80.04819489, 12.32708263], [80.0480423, 12.32708263], [80.04792023, 12.32708263], [80.04792023, 12.32693005], [80.04792023, 12.32652569], [80.04819489, 12.32652569], [80.04819489, 12.32513809], [80.04736328, 12.32514095], [80.04736328, 12.32485962], [80.04708099, 12.32485962], [80.04708099, 12.32430744], [80.04680634, 12.32431126], [80.04680634, 12.32374954], [80.04651642, 12.32374954], [80.04651642, 12.32346058], [80.04624939, 12.32347202], [80.04624939, 12.32319355], [80.04569244, 12.32319355], [80.04569244, 12.32263756], [80.04541779, 12.32264137], [80.04541779, 12.32236004], [80.0451355, 12.32236004], [80.0451355, 12.32180595], [80.04486084, 12.32181072], [80.04486084, 12.32096958], [80.04458618, 12.32097244], [80.04458618, 12.32069397], [80.04402924, 12.32069016], [80.04402924, 12.32041645], [80.04374695, 12.32042122], [80.04374695, 12.32014275], [80.04347229, 12.32014275], [80.04347229, 12.31958199], [80.04319763, 12.31958199], [80.04319763, 12.31930637], [80.04292297, 12.31931114], [80.04292297, 12.31903267], [80.04264069, 12.31903267], [80.04264069, 12.31847191], [80.0423584, 12.31847191], [80.0423584, 12.31819439], [80.04208374, 12.31819439], [80.04208374, 12.3176403], [80.04180908, 12.3176403], [80.04180908, 12.31707859], [80.04152679, 12.31708431], [80.04152679, 12.31652832], [80.04125214, 12.31653023], [80.04125214, 12.31597042], [80.04096985, 12.31597233], [80.04096985, 12.31541634], [80.04070282, 12.31542015], [80.04070282, 12.31486034], [80.0404129, 12.31486225], [80.0404129, 12.31430626], [80.04013824, 12.31431007], [80.04013824, 12.31347179], [80.0404129, 12.31347179], [80.0404129, 12.31375027], [80.04070282, 12.31375027], [80.04070282, 12.31402969], [80.04096985, 12.31402969], [80.04096985, 12.31431007], [80.04125214, 12.31430626], [80.04125214, 12.31486225], [80.04152679, 12.31486034], [80.04152679, 12.31513977], [80.04180908, 12.31513977], [80.04180908, 12.31542015], [80.04208374, 12.31541634], [80.04208374, 12.31597233], [80.0423584, 12.31597042], [80.0423584, 12.31624985], [80.04264069, 12.31624985], [80.04264069, 12.31681061], [80.04291534, 12.31680584], [80.04291534, 12.31708431], [80.04319763, 12.31707859], [80.04319763, 12.3176403], [80.04347229, 12.3176403], [80.04347229, 12.31819439], [80.04374695, 12.31819439], [80.04374695, 12.31847191], [80.04402924, 12.31847191], [80.04402924, 12.31903267], [80.04429626, 12.31903267], [80.04429626, 12.31931114], [80.04458618, 12.31930637], [80.04458618, 12.31986237], [80.04486084, 12.31986046], [80.04486084, 12.32014275], [80.04515076, 12.32014275], [80.04515076, 12.32042122], [80.04541779, 12.32041645], [80.04541779, 12.32097244], [80.04569244, 12.32096958], [80.04569244, 12.32124996], [80.0459671, 12.32124996], [80.0459671, 12.3215313], [80.04624939, 12.3215313], [80.04624939, 12.32181072], [80.04651642, 12.32181072], [80.04651642, 12.32236004], [80.04680634, 12.32236004], [80.04680634, 12.32264137], [80.04708099, 12.32264137], [80.04708099, 12.3229208], [80.04736328, 12.32291603], [80.04736328, 12.32347202], [80.04763794, 12.32346058], [80.04763794, 12.32374954], [80.04792023, 12.32374954], [80.04792023, 12.32403088], [80.04819489, 12.32402897], [80.04819489, 12.3245821], [80.04846954, 12.3245821], [80.04846954, 12.32485962], [80.04875183, 12.32485962], [80.04875183, 12.32542133], [80.04957581, 12.32542133], [80.04957581, 12.32514095], [80.05014038, 12.32514095], [80.05014038, 12.32485962], [80.04985809, 12.32485962], [80.04985809, 12.32430744], [80.04957581, 12.32431126], [80.04957581, 12.32403088], [80.04930878, 12.32403088], [80.04930878, 12.32346058], [80.04902649, 12.32347202], [80.04902649, 12.32319355], [80.04875183, 12.32319355], [80.04875183, 12.32263756], [80.04846954, 12.32264137], [80.04846954, 12.32236004], [80.04818726, 12.32236004], [80.04818726, 12.32181072], [80.04792023, 12.32181072], [80.04792023, 12.3215313], [80.04763794, 12.3215313], [80.04763794, 12.32096958], [80.04736328, 12.32097244], [80.04736328, 12.32069397], [80.04708099, 12.32069016], [80.04708099, 12.32041645], [80.04680634, 12.32042122], [80.04680634, 12.31986046], [80.04652405, 12.31986237], [80.04652405, 12.31958199], [80.04624939, 12.31958199], [80.04624939, 12.31930637], [80.0459671, 12.31931114], [80.0459671, 12.31875038], [80.04569244, 12.31875038], [80.04569244, 12.31847191], [80.04541779, 12.31847191], [80.04541779, 12.31791592], [80.04515076, 12.31791973], [80.04515076, 12.3176403], [80.04486084, 12.3176403], [80.04486084, 12.31735992], [80.04458618, 12.31735992], [80.04458618, 12.31681061], [80.04429626, 12.31681061], [80.04429626, 12.31653023], [80.04402924, 12.31653023], [80.04402924, 12.31624985], [80.04374695, 12.31624985], [80.04374695, 12.31569099], [80.04347229, 12.31569386], [80.04347229, 12.31541634], [80.04319763, 12.31542015], [80.04319763, 12.31486034], [80.04291534, 12.31486225], [80.04291534, 12.31458378], [80.04264069, 12.31458378], [80.04264069, 12.31430626], [80.0423584, 12.31431007], [80.0423584, 12.31375027], [80.04208374, 12.31375027], [80.04208374, 12.31347179], [80.04180908, 12.31347179], [80.04180908, 12.31319141], [80.04152679, 12.31319427], [80.04152679, 12.31264019], [80.04125214, 12.31264019], [80.04125214, 12.31235886], [80.04096985, 12.31236172], [80.04096985, 12.31180573], [80.04070282, 12.31180954], [80.04070282, 12.31152058], [80.0404129, 12.31152725], [80.0404129, 12.31124878], [80.04013824, 12.31125164], [80.04013824, 12.31069088], [80.03986359, 12.31069565], [80.03986359, 12.31041527], [80.0395813, 12.31042194], [80.0395813, 12.30985928], [80.03930664, 12.30986118], [80.03930664, 12.30930519], [80.03901672, 12.30930996], [80.03901672, 12.30902958], [80.03874969, 12.30902958], [80.03874969, 12.3087492], [80.03847504, 12.3087492], [80.03847504, 12.30847263], [80.03819275, 12.30848026], [80.03819275, 12.3081913], [80.03791809, 12.30819321], [80.03791809, 12.30763912], [80.0376358, 12.30764198], [80.0376358, 12.30708122], [80.03736115, 12.30708313], [80.03736115, 12.30680466], [80.03708649, 12.30681038], [80.03708649, 12.30653191], [80.03679657, 12.30653191], [80.03679657, 12.30625057], [80.03652954, 12.30625057], [80.03652954, 12.30597115], [80.03624725, 12.30597305], [80.03624725, 12.30513859], [80.03569794, 12.30514145], [80.03569794, 12.30458069], [80.03541565, 12.3045826], [80.03541565, 12.30430508], [80.03514099, 12.30430889], [80.03514099, 12.30375099], [80.03457642, 12.30375099], [80.03457642, 12.30319023], [80.03430176, 12.303195], [80.03430176, 12.30291653], [80.0340271, 12.3029213], [80.0340271, 12.30264091], [80.03375244, 12.30264091], [80.03375244, 12.30208015], [80.03347015, 12.30208302], [80.03347015, 12.30152893], [80.03321075, 12.30153084], [80.03321075, 12.30097103], [80.03291321, 12.30097294], [80.03291321, 12.30069542], [80.03263855, 12.30069542], [80.03263855, 12.30013943], [80.03235626, 12.30014133], [80.03235626, 12.29957962], [80.0320816, 12.29958344], [80.0320816, 12.29902554], [80.03180695, 12.29903126], [80.03180695, 12.29846954], [80.03152466, 12.29847336], [80.03152466, 12.29819489], [80.03125, 12.29819489], [80.03125, 12.29763794], [80.03098297, 12.2976408], [80.03098297, 12.29708004], [80.03069305, 12.29708195], [80.03069305, 12.29652786], [80.0304184, 12.29654026], [80.0304184, 12.29625034], [80.03013611, 12.29625034], [80.03013611, 12.29569435], [80.02986145, 12.29569435], [80.02986145, 12.29541588], [80.02958679, 12.29542065], [80.02958679, 12.29486179], [80.02929688, 12.29486179], [80.02929688, 12.29458046], [80.02902985, 12.29458427], [80.02902985, 12.29402828], [80.02874756, 12.29403114], [80.02874756, 12.29348087], [80.0284729, 12.29348087], [80.0284729, 12.29319191], [80.02819824, 12.29319382], [80.02819061, 12.29263783], [80.02791595, 12.29263973], [80.02791595, 12.29236031], [80.0276413, 12.29236221], [80.0276413, 12.29180622], [80.02735901, 12.29181099], [80.02735901, 12.29152966], [80.02707672, 12.29152966], [80.02707672, 12.29096985], [80.02680206, 12.29097176], [80.02680206, 12.29069424], [80.0265274, 12.29069424], [80.0265274, 12.29014015], [80.02625275, 12.29014015], [80.02625275, 12.28985977], [80.02597046, 12.28985977], [80.02597046, 12.28931046], [80.0256958, 12.28931046], [80.0256958, 12.28903008], [80.02540588, 12.28903008], [80.02540588, 12.28846931], [80.02513885, 12.28847218], [80.02513885, 12.2881937], [80.0248642, 12.2881937], [80.0248642, 12.28763771], [80.02458191, 12.28763962], [80.02458191, 12.2873497], [80.02430725, 12.2873621], [80.02430725, 12.28680611], [80.02401733, 12.28680992], [80.02401733, 12.28652954], [80.02375031, 12.28652954], [80.02375031, 12.28597164], [80.02347565, 12.28597164], [80.02347565, 12.28569317], [80.02319336, 12.28569317], [80.02319336, 12.28514004], [80.0229187, 12.28514194], [80.0229187, 12.28486156], [80.02263641, 12.28486156], [80.02263641, 12.28430462], [80.02236176, 12.28431034], [80.02236176, 12.28403187], [80.0220871, 12.28403187], [80.0220871, 12.2834692], [80.02180481, 12.28347111], [80.02180481, 12.28291702], [80.02153015, 12.28292179], [80.02153015, 12.28263855], [80.02124786, 12.28263855], [80.02124786, 12.28208065], [80.02097321, 12.28208256], [80.02097321, 12.28152657], [80.02069092, 12.28154087], [80.02069092, 12.28097057], [80.02041626, 12.28097343], [80.02041626, 12.28069305], [80.0201416, 12.28069305], [80.0201416, 12.28013897], [80.01985931, 12.28014088], [80.01985931, 12.27958107], [80.01958466, 12.27958298], [80.01958466, 12.27902699], [80.01930237, 12.27902889], [80.01930237, 12.27875137], [80.01902771, 12.27875137], [80.01902771, 12.27818108], [80.01875305, 12.27819538], [80.01875305, 12.27763939], [80.01847076, 12.2776413], [80.01847076, 12.27708054], [80.01819611, 12.2770834], [80.01819611, 12.27680492], [80.01792145, 12.2768116], [80.01792145, 12.27625084], [80.01763916, 12.27625084], [80.01763916, 12.27569008], [80.0173645, 12.27569485], [80.0173645, 12.27513885], [80.01708221, 12.27514076], [80.01708221, 12.27458], [80.01680756, 12.27458286], [80.01680756, 12.27180672], [80.0165329, 12.27181053], [80.0165329, 12.27014065], [80.01597595, 12.27014065], [80.01597595, 12.26986027], [80.01569366, 12.26986027], [80.01569366, 12.26958466], [80.01541901, 12.26958466], [80.01541901, 12.26902771], [80.01513672, 12.26903057], [80.01513672, 12.26847172], [80.01486206, 12.26847172], [80.01486206, 12.26763821], [80.01457977, 12.26764011], [80.01457977, 12.26681137], [80.01431274, 12.26681137], [80.01431274, 12.26597023], [80.01403046, 12.26597214], [80.01403046, 12.26513767], [80.01374817, 12.26513958], [80.01374817, 12.26431274], [80.01346588, 12.26431274], [80.01346588, 12.2634697], [80.01319122, 12.2634716], [80.01319122, 12.26291561], [80.01291656, 12.26292038], [80.01291656, 12.26235962], [80.01264191, 12.26236153], [80.01264191, 12.26180553], [80.01235962, 12.2618103], [80.01235962, 12.26124954], [80.01207733, 12.26124954], [80.01207733, 12.26097202], [80.01180267, 12.26097202], [80.01180267, 12.26041794], [80.01152802, 12.26042938], [80.01152802, 12.26014042], [80.01125336, 12.26014042], [80.01125336, 12.25958061], [80.01097107, 12.25958443], [80.01097107, 12.25930595], [80.01069641, 12.25930977], [80.01069641, 12.25875187], [80.01040649, 12.25875187], [80.01040649, 12.25847054], [80.01013947, 12.25847054], [80.01013947, 12.25791454], [80.00985718, 12.25792027], [80.00985718, 12.25737095], [80.00958252, 12.25737095], [80.00958252, 12.25708103], [80.00930786, 12.25708294], [80.00930786, 12.25652695], [80.00904083, 12.25652981], [80.00904083, 12.25624943], [80.00763702, 12.25624943], [80.00763702, 12.25652981], [80.00791931, 12.25652695], [80.00791931, 12.25708294], [80.00818634, 12.25708103], [80.00818634, 12.25737095], [80.00846863, 12.25737095], [80.00846863, 12.25764179], [80.00875092, 12.25763988], [80.00875092, 12.25819302], [80.00902557, 12.25819302], [80.00902557, 12.25847054], [80.00930786, 12.25847054], [80.00930786, 12.25903034], [80.00958252, 12.25902843], [80.00958252, 12.25958443], [80.00985718, 12.25958061], [80.00985718, 12.26014042], [80.01013947, 12.26013756], [80.01013947, 12.26069355], [80.01040649, 12.26069069], [80.01040649, 12.26124954], [80.01069641, 12.26124954], [80.01069641, 12.26152992], [80.01097107, 12.26152802], [80.01097107, 12.26208401], [80.01125336, 12.26208401], [80.01125336, 12.26236153], [80.01152802, 12.26235962], [80.01152802, 12.26264], [80.01180267, 12.26264], [80.01180267, 12.26319408], [80.01208496, 12.26319408], [80.01208496, 12.2634716], [80.01235962, 12.2634697], [80.01235962, 12.26403046], [80.01264191, 12.2640276], [80.01264191, 12.26458359], [80.01235962, 12.26458168], [80.01235962, 12.26513958], [80.01207733, 12.26513958], [80.01207733, 12.26542091], [80.01152802, 12.26542091], [80.01152802, 12.26513958], [80.01125336, 12.26513958], [80.01125336, 12.26486015], [80.01097107, 12.26486206], [80.01097107, 12.26458359], [80.01041412, 12.26458359], [80.01041412, 12.26430607], [80.01013947, 12.26431274], [80.01013947, 12.26403046], [80.00985718, 12.26403046], [80.00985718, 12.26375008], [80.00958252, 12.26375008], [80.00958252, 12.2634697], [80.00930786, 12.2634716], [80.00930786, 12.26319408], [80.00902557, 12.26319408], [80.00902557, 12.26291561], [80.00875092, 12.26292038], [80.00875092, 12.26264], [80.00846863, 12.26264], [80.00846863, 12.26235962], [80.00819397, 12.26236153], [80.00819397, 12.26208401], [80.00791931, 12.26208401], [80.00791931, 12.26180553], [80.00763702, 12.2618103], [80.00763702, 12.26152992], [80.00736237, 12.26152992], [80.00736237, 12.26097202], [80.00708008, 12.26097202], [80.00708008, 12.26069355], [80.00680542, 12.26069355], [80.00680542, 12.26041794], [80.00653076, 12.26042938], [80.00653076, 12.25986195], [80.00624847, 12.25986195], [80.00624847, 12.25958061], [80.00569153, 12.25958443], [80.00569153, 12.25930595], [80.00485992, 12.25930595], [80.00485992, 12.25958443], [80.00458527, 12.25958443], [80.00458527, 12.26097202], [80.00485992, 12.26097202], [80.00485992, 12.26264], [80.00514221, 12.26264], [80.00514221, 12.26375008], [80.00541687, 12.26375008], [80.00541687, 12.26431274], [80.00569153, 12.26430607], [80.00569153, 12.26486206], [80.00598145, 12.26486015], [80.00598145, 12.26542091], [80.00624847, 12.26541615], [80.00624847, 12.26597214], [80.00653076, 12.26597023], [80.00653076, 12.26653099], [80.00680542, 12.26652813], [80.00680542, 12.26708221], [80.00708008, 12.26708031], [80.00708008, 12.26735973], [80.00763702, 12.26735973], [80.00763702, 12.26792145], [80.00791931, 12.26792145], [80.00791931, 12.26903057], [80.00819397, 12.26902771], [80.00819397, 12.26958466], [80.00846863, 12.26958466], [80.00846863, 12.26986027], [80.00904083, 12.26986027], [80.00904083, 12.27014065], [80.00930786, 12.27014065], [80.00930786, 12.27042103], [80.00958252, 12.27041626], [80.00958252, 12.27069378], [80.01013947, 12.27069378], [80.01013947, 12.27097321], [80.01040649, 12.27097034], [80.01040649, 12.27125072], [80.01097107, 12.27125072], [80.01097107, 12.27153111], [80.01125336, 12.2715292], [80.01125336, 12.27208233], [80.01152802, 12.27208042], [80.01152802, 12.27264118], [80.01013947, 12.27264118], [80.01013947, 12.27237034], [80.00985718, 12.27237034], [80.00985718, 12.27208042], [80.00958252, 12.27208233], [80.00958252, 12.27180672], [80.00930786, 12.27181053], [80.00930786, 12.27153111], [80.00907898, 12.27148533], [80.00902557, 12.27125072], [80.00894165, 12.27125072], [80.00846863, 12.27125072], [80.00846863, 12.27097034], [80.00819397, 12.27097321], [80.00819397, 12.27069378], [80.00791931, 12.27069378], [80.00791931, 12.27041626], [80.00763702, 12.27042103], [80.00763702, 12.27014065], [80.00736237, 12.27014065], [80.00736237, 12.26988125], [80.00736237, 12.26958466], [80.00708008, 12.26958466], [80.00708008, 12.26902771], [80.00681305, 12.26903057], [80.00681305, 12.26764011], [80.00653076, 12.26764011], [80.00653076, 12.26735973], [80.00597382, 12.26735973], [80.00597382, 12.26708221], [80.00569153, 12.26708221], [80.00569153, 12.26652813], [80.00541687, 12.26653099], [80.00541687, 12.26624107], [80.00514221, 12.26624966], [80.00514221, 12.26569366], [80.00485992, 12.26569366], [80.00485992, 12.26541615], [80.0045929, 12.26542091], [80.0045929, 12.26486015], [80.00430298, 12.26486206], [80.00430298, 12.26291561], [80.00402832, 12.26292038], [80.00402832, 12.26152992], [80.00374603, 12.26152992], [80.00374603, 12.25958061], [80.00347137, 12.25958443], [80.00347137, 12.25847054], [80.00319672, 12.25847054], [80.00319672, 12.25819588], [80.0029068, 12.25819111], [80.00291443, 12.25791454], [80.00235748, 12.25792027], [80.00235748, 12.25764179], [80.00152588, 12.25764179], [80.00152588, 12.25737095], [80.00096893, 12.25737095], [80.00096893, 12.25708103], [79.99986267, 12.25708294], [79.99877167, 12.25708294], [79.99819183, 12.25708294], [79.99819183, 12.25680542], [79.99791718, 12.25681019], [79.99791718, 12.25652981], [79.99736023, 12.25652981], [79.99736023, 12.25624943], [79.99681091, 12.25624943], [79.99681091, 12.25652981], [79.99624634, 12.25652695], [79.99624634, 12.25708294], [79.99569702, 12.25708294], [79.99569702, 12.25680542], [79.9954071, 12.25681019], [79.9954071, 12.25624943], [79.99514008, 12.25624943], [79.99514008, 12.25569057], [79.99485779, 12.25569534], [79.99485779, 12.25541687], [79.99404144, 12.25541973], [79.99404144, 12.25513935], [79.99375153, 12.25513935], [79.99375153, 12.25486088], [79.99346924, 12.25486088], [79.99346924, 12.25458145], [79.99291992, 12.25458336], [79.99291992, 12.25430489], [79.99236298, 12.25430489], [79.99236298, 12.25402737], [79.99180603, 12.25402927], [79.99180603, 12.25374889], [79.9909668, 12.25374889], [79.9909668, 12.25347137], [79.99069214, 12.25347328], [79.99069214, 12.25319481], [79.99041748, 12.25319481], [79.99041748, 12.25291729], [79.98986053, 12.25292015], [79.98986053, 12.25264072], [79.98929596, 12.25264072], [79.98929596, 12.2523613], [79.98847198, 12.2523613], [79.98847198, 12.25208282], [79.98791504, 12.25208282], [79.98791504, 12.25180531], [79.98707581, 12.25181198], [79.98707581, 12.2515316], [79.98652649, 12.2515316], [79.98652649, 12.25123978], [79.98625183, 12.25125122], [79.98625183, 12.25097084], [79.98596954, 12.25097084], [79.98596954, 12.25069141], [79.98542023, 12.25069523], [79.98542023, 12.25041676], [79.98513794, 12.25042152], [79.98513794, 12.24985886], [79.98486328, 12.24986076], [79.98486328, 12.24930477], [79.98458099, 12.2493124], [79.98458099, 12.24875069], [79.98430634, 12.24875069], [79.98430634, 12.24847126], [79.98402405, 12.24847317], [79.98402405, 12.24819469], [79.98374939, 12.24819946], [79.98374939, 12.24681091], [79.9834671, 12.24681091], [79.9834671, 12.24625111], [79.98319244, 12.24625111], [79.98319244, 12.24542999], [79.98291779, 12.24542999], [79.98291779, 12.24431133], [79.98264313, 12.24431133], [79.98264313, 12.24375057], [79.98210144, 12.24375057], [79.98210144, 12.24347019], [79.98152924, 12.2434721], [79.98152924, 12.24319363], [79.98124695, 12.24319363], [79.98124695, 12.24291611], [79.98069763, 12.24292088], [79.98069763, 12.24264145], [79.98014069, 12.24264145], [79.98014069, 12.24236012], [79.97957611, 12.24236012], [79.97957611, 12.24207973], [79.97930908, 12.24208355], [79.97930908, 12.24180603], [79.97875214, 12.2418108], [79.97875214, 12.24153137], [79.97820282, 12.24153137], [79.97820282, 12.24125004], [79.97763824, 12.24125004], [79.97763824, 12.24096966], [79.9770813, 12.24097157], [79.9770813, 12.24069405], [79.97652435, 12.24069405], [79.97652435, 12.24041557], [79.97624969, 12.2404213], [79.97624969, 12.24013996], [79.97567749, 12.24013996], [79.97567749, 12.23985958], [79.9751358, 12.23986244], [79.9751358, 12.23958206], [79.97458649, 12.23958206], [79.97458649, 12.23930645], [79.97402954, 12.23930645], [79.97402954, 12.23902798], [79.97374725, 12.23903275], [79.97374725, 12.23875046], [79.9734726, 12.23875046], [79.9734726, 12.23847198], [79.97319794, 12.23847198], [79.97319794, 12.23819447], [79.97291565, 12.23819447], [79.97291565, 12.23763847], [79.97264099, 12.23764038], [79.97264099, 12.23736], [79.9723587, 12.23736], [79.9723587, 12.23707962], [79.97208405, 12.23708439], [79.97208405, 12.23680592], [79.97180176, 12.23681068], [79.97180176, 12.2365303], [79.97097015, 12.2365303], [79.97097015, 12.23626137], [79.96930695, 12.23626137], [79.96930695, 12.23596954], [79.96902466, 12.2359724], [79.96902466, 12.23569393], [79.96819305, 12.23569393], [79.96819305, 12.23541641], [79.9679184, 12.23542023], [79.9679184, 12.23513985], [79.96763611, 12.23513985], [79.96763611, 12.23486042], [79.96736145, 12.23486233], [79.96736145, 12.23458385], [79.96708679, 12.23458385], [79.96708679, 12.23430634], [79.96681213, 12.23431015], [79.96681213, 12.23402977], [79.96652985, 12.23402977], [79.96652985, 12.23375034], [79.9659729, 12.23375034], [79.9659729, 12.23291969], [79.96541595, 12.23291969], [79.96541595, 12.23264027], [79.96485901, 12.23264027], [79.96485901, 12.23236179], [79.9640274, 12.23236179], [79.9640274, 12.23208141], [79.96347046, 12.23208427], [79.96347046, 12.2318058], [79.96290588, 12.23180962], [79.96290588, 12.23153019], [79.96208191, 12.23153019], [79.96208191, 12.23124886], [79.96180725, 12.23124886], [79.96180725, 12.23097134], [79.96125031, 12.23097134], [79.96125031, 12.23069572], [79.96097565, 12.23069572], [79.96097565, 12.23041534], [79.9604187, 12.23042202], [79.9604187, 12.22985935], [79.96013641, 12.22986126], [79.96013641, 12.22958279], [79.95986176, 12.22958279], [79.95986176, 12.22930527], [79.95929718, 12.22931004], [79.95929718, 12.22902966], [79.95874786, 12.22902966], [79.95874786, 12.22874928], [79.95819092, 12.22874928], [79.95819092, 12.22846889], [79.9576416, 12.2284708], [79.9576416, 12.22819328], [79.95708466, 12.22819328], [79.95708466, 12.22791672], [79.95652771, 12.22791958], [79.95652771, 12.22736073], [79.95540619, 12.22736073], [79.95540619, 12.22706985], [79.95513916, 12.22708321], [79.95513916, 12.22680473], [79.95487213, 12.22681046], [79.95487213, 12.22653198], [79.9540329, 12.22653198], [79.9540329, 12.22625065], [79.95375061, 12.22625065], [79.95375061, 12.22597122], [79.95319366, 12.22597313], [79.95319366, 12.22569466], [79.95263672, 12.22569466], [79.95263672, 12.22541714], [79.95207977, 12.22542191], [79.95207977, 12.22514057], [79.95124817, 12.22514057], [79.95124817, 12.22486115], [79.95097351, 12.22486115], [79.95097351, 12.22458267], [79.95041656, 12.22458267], [79.95041656, 12.22430515], [79.94985962, 12.22430515], [79.94985962, 12.22458267], [79.94958496, 12.22458267], [79.94958496, 12.22430515], [79.94930267, 12.22432137], [79.94930267, 12.22403145], [79.94902802, 12.22403145], [79.94902802, 12.22375107], [79.9487381, 12.22375107], [79.9487381, 12.22319031], [79.94847107, 12.22319508], [79.94847107, 12.2229166], [79.94790649, 12.22292233], [79.94790649, 12.22264099], [79.94735718, 12.22264099], [79.94735718, 12.22236061], [79.94680786, 12.22236061], [79.94680786, 12.22208309], [79.94625092, 12.22208309], [79.94625092, 12.22180462], [79.94596863, 12.22180939], [79.94596863, 12.22153091], [79.9457016, 12.22153091], [79.9457016, 12.22097111], [79.94541931, 12.22097301], [79.94541931, 12.22069454], [79.94513702, 12.22069454], [79.94513702, 12.22041702], [79.94486237, 12.22042084], [79.94486237, 12.22014141], [79.94458008, 12.22014141], [79.94458008, 12.21986103], [79.94486237, 12.21986103], [79.94486237, 12.21931076], [79.94569397, 12.21930695], [79.94569397, 12.21958256], [79.94625092, 12.21958256], [79.94625092, 12.21914959], [79.94625092, 12.21902561], [79.94581604, 12.21902943], [79.94513702, 12.21903133], [79.94513702, 12.21872997], [79.94513702, 12.21819496], [79.94541931, 12.21819496], [79.94541931, 12.21791744], [79.9457016, 12.21792126], [79.9457016, 12.21764088], [79.94596863, 12.21764088], [79.94596863, 12.21735954], [79.94736481, 12.21735954], [79.94736481, 12.21708202], [79.94763947, 12.21708202], [79.94763947, 12.21652889], [79.94790649, 12.2165308], [79.94790649, 12.21597004], [79.94875336, 12.21597195], [79.94875336, 12.21569443], [79.94985962, 12.21569443], [79.94985962, 12.21541595], [79.95014191, 12.21542072], [79.95014191, 12.2151289], [79.95069122, 12.21513844], [79.95069122, 12.21458435], [79.95097351, 12.21458435], [79.95097351, 12.21430588], [79.95179749, 12.21431065], [79.95179749, 12.21403122], [79.95291901, 12.21403122], [79.95291901, 12.21375275], [79.95263672, 12.21375275], [79.95263672, 12.21347046], [79.95207977, 12.21347237], [79.95207977, 12.21319389], [79.95236206, 12.21319389], [79.95236206, 12.21291637], [79.95263672, 12.21292114], [79.95263672, 12.21264267], [79.95318604, 12.21264267], [79.95318604, 12.21236038], [79.95347595, 12.21236229], [79.95347595, 12.21208191], [79.95402527, 12.21208191], [79.95402527, 12.21236229], [79.9548645, 12.21236229], [79.9548645, 12.21208191], [79.95513916, 12.21208191], [79.95513916, 12.2118063], [79.95652771, 12.2118063], [79.95652771, 12.21208191], [79.95680237, 12.21208191], [79.95680237, 12.21236229], [79.95707703, 12.21236038], [79.95707703, 12.21264267], [79.9576416, 12.21264267], [79.9576416, 12.21292114], [79.95791626, 12.21291637], [79.95791626, 12.21319389], [79.95819092, 12.21319389], [79.95819092, 12.21347237], [79.95847321, 12.21347046], [79.95847321, 12.21375275], [79.95874786, 12.21375275], [79.95874786, 12.21403122], [79.95847321, 12.21402836], [79.95847321, 12.21458435], [79.95929718, 12.21457958], [79.95929718, 12.21485996], [79.95986176, 12.21485996], [79.95986176, 12.21542072], [79.96013641, 12.21541595], [79.96013641, 12.21597195], [79.9604187, 12.21597004], [79.9604187, 12.2165308], [79.96069336, 12.21652889], [79.96069336, 12.21708202], [79.9604187, 12.21708012], [79.9604187, 12.21875095], [79.96099091, 12.21875095], [79.96099091, 12.21903133], [79.96125031, 12.21903133], [79.96125031, 12.21931076], [79.96180725, 12.21930695], [79.96180725, 12.21958256], [79.96208191, 12.2195797], [79.96208191, 12.21986103], [79.96235657, 12.21986103], [79.96235657, 12.22042084], [79.96263885, 12.22041702], [79.96263885, 12.22097301], [79.96290588, 12.22097111], [79.96290588, 12.22153091], [79.9631958, 12.22153091], [79.9631958, 12.22180939], [79.96291351, 12.22180462], [79.96291351, 12.22236061], [79.96263885, 12.22236061], [79.96263885, 12.22208309], [79.96208191, 12.22208309], [79.96208191, 12.22216034], [79.96208191, 12.22264099], [79.962883, 12.22263908], [79.9631958, 12.22263908], [79.9631958, 12.2229166], [79.96333313, 12.2229166], [79.96347046, 12.2229166], [79.96347046, 12.2234726], [79.96406555, 12.22343159], [79.9640274, 12.22375107], [79.96434021, 12.22371483], [79.96430206, 12.22432137], [79.96457672, 12.22432137], [79.96457672, 12.22403145], [79.9651413, 12.22403145], [79.9651413, 12.22432137], [79.96569061, 12.22432137], [79.96569824, 12.22403145], [79.9659729, 12.22402668], [79.9659729, 12.22486115], [79.96569824, 12.22486115], [79.96569824, 12.22511196], [79.96569824, 12.22542191], [79.9659729, 12.22541714], [79.9659729, 12.22569466], [79.96626282, 12.22569466], [79.96652985, 12.22569466], [79.96652985, 12.22597313], [79.96681213, 12.22597122], [79.96681213, 12.22625065], [79.96736145, 12.22625065], [79.96736145, 12.22653198], [79.9679184, 12.22653198], [79.9679184, 12.22681046], [79.96847534, 12.22680473], [79.96847534, 12.22708321], [79.96875, 12.22706985], [79.96875, 12.22736073], [79.96930695, 12.22736073], [79.96930695, 12.2276392], [79.9695816, 12.2276392], [79.9695816, 12.22791958], [79.97013855, 12.22791672], [79.97013855, 12.22819328], [79.97041321, 12.22819328], [79.97041321, 12.2284708], [79.9706955, 12.2284708], [79.9706955, 12.22874928], [79.97097015, 12.22874928], [79.97097015, 12.22902966], [79.97125244, 12.22902966], [79.97125244, 12.22931004], [79.9715271, 12.22930527], [79.9715271, 12.22958279], [79.97180176, 12.22958279], [79.97180939, 12.22986126], [79.97207642, 12.22985935], [79.97207642, 12.23014164], [79.9723587, 12.23013973], [79.9723587, 12.23069572], [79.97264099, 12.23069572], [79.97264099, 12.23097134], [79.97319794, 12.23097134], [79.97319794, 12.23124886], [79.9734726, 12.23124886], [79.9734726, 12.23097134], [79.9743042, 12.23097134], [79.9743042, 12.23124886], [79.97458649, 12.23124886], [79.97458649, 12.23153019], [79.9751358, 12.23153019], [79.9751358, 12.23180962], [79.97569275, 12.2318058], [79.97569275, 12.23208427], [79.97596741, 12.23208141], [79.97596741, 12.23236179], [79.97651672, 12.23236179], [79.97651672, 12.23264027], [79.9770813, 12.23264027], [79.9770813, 12.23180962], [79.97735596, 12.23180962], [79.97735596, 12.23153019], [79.9779129, 12.23152828], [79.9779129, 12.23208427], [79.97820282, 12.23208141], [79.97820282, 12.23291969], [79.97846985, 12.23291779], [79.97846985, 12.23347187], [79.97902679, 12.23347187], [79.97902679, 12.23375034], [79.97957611, 12.23375034], [79.97957611, 12.23402977], [79.98014069, 12.23402977], [79.98014069, 12.23431015], [79.98042297, 12.23431015], [79.98042297, 12.23513985], [79.98097229, 12.23513985], [79.98097229, 12.23542023], [79.98124695, 12.23541641], [79.98124695, 12.23569393], [79.98152924, 12.23569202], [79.98152924, 12.2365303], [79.98181152, 12.2365303], [79.98181152, 12.23681068], [79.98208618, 12.23680592], [79.98208618, 12.23736], [79.98236084, 12.23736], [79.98236084, 12.23764038], [79.98291779, 12.23763847], [79.98291779, 12.23847198], [79.98319244, 12.23847198], [79.98319244, 12.23903275], [79.98374939, 12.23902798], [79.98374939, 12.23930645], [79.98402405, 12.23930645], [79.98402405, 12.23958206], [79.98430634, 12.23958015], [79.98430634, 12.24013996], [79.98458099, 12.24013996], [79.98458099, 12.2404213], [79.98486328, 12.24041557], [79.98486328, 12.24097157], [79.98513794, 12.24096966], [79.98513794, 12.24125004], [79.98568726, 12.24125004], [79.98568726, 12.2418108], [79.98596954, 12.24180603], [79.98596954, 12.24208355], [79.98708344, 12.24208355], [79.98707581, 12.24223042], [79.98707581, 12.24236012], [79.98735809, 12.24236012], [79.98735809, 12.24292088], [79.98764038, 12.24291611], [79.98764038, 12.24319363], [79.98791504, 12.24319363], [79.98791504, 12.2434721], [79.98819733, 12.24347019], [79.98819733, 12.24375057], [79.98847198, 12.24375057], [79.98847198, 12.24403095], [79.98874664, 12.24402905], [79.98874664, 12.24458218], [79.98902893, 12.24458027], [79.98902893, 12.2448597], [79.98929596, 12.2448597], [79.98929596, 12.24514103], [79.98958588, 12.24514103], [79.98958588, 12.24542999], [79.98986053, 12.24541664], [79.98986053, 12.24569511], [79.99013519, 12.24569511], [79.99013519, 12.24597263], [79.99041748, 12.24596977], [79.99041748, 12.24625111], [79.99069214, 12.24625111], [79.99069214, 12.24653053], [79.9909668, 12.24653053], [79.9909668, 12.24681091], [79.99153137, 12.24680519], [79.99153137, 12.24708271], [79.99180603, 12.24708271], [79.99180603, 12.24736118], [79.99208069, 12.24736118], [79.99208069, 12.24764061], [79.99236298, 12.24764061], [79.99236298, 12.24792099], [79.99263763, 12.24792099], [79.99263763, 12.24819946], [79.99291992, 12.24819469], [79.99291992, 12.24847317], [79.99404144, 12.24847126], [79.99404144, 12.24875069], [79.99430847, 12.24875069], [79.99430847, 12.24903107], [79.99458313, 12.24903107], [79.99458313, 12.2493124], [79.99485779, 12.24930477], [79.99485779, 12.24986076], [79.99500275, 12.24986076], [79.99514008, 12.24985886], [79.99514008, 12.25014114], [79.99541473, 12.25013924], [79.99541473, 12.25069523], [79.99597168, 12.25069141], [79.99597168, 12.25097084], [79.99624634, 12.25097084], [79.99624634, 12.2515316], [79.99681091, 12.2515316], [79.99681091, 12.25181198], [79.99708557, 12.25180531], [79.99708557, 12.25208282], [79.99764252, 12.25208282], [79.99764252, 12.2523613], [79.99819183, 12.2523613], [79.99819183, 12.25264072], [79.99903107, 12.25264072], [79.99903107, 12.25292015], [79.99958038, 12.25291729], [79.99958038, 12.25319481], [80.00013733, 12.25319481], [80.00180817, 12.25319481], [80.00180817, 12.25347328], [80.00235748, 12.25347137], [80.00235748, 12.25374889], [80.00263977, 12.25374889], [80.00263977, 12.25402927], [80.00319672, 12.25402737], [80.00319672, 12.25430489], [80.00485992, 12.25430489], [80.00485992, 12.25458336], [80.00624847, 12.25458145], [80.00624847, 12.25486088], [80.00681305, 12.25486088], [80.00680542, 12.25458336], [80.00708008, 12.25458336], [80.00708008, 12.25374889], [80.00680542, 12.25374889], [80.00680542, 12.25347328], [80.00653076, 12.25347328], [80.00653076, 12.25291729], [80.00624847, 12.25292015], [80.00624847, 12.25264072], [80.00598145, 12.25264072], [80.00598145, 12.25208092], [80.00541687, 12.25208282], [80.00541687, 12.25125122], [80.00514221, 12.25125122], [80.00514221, 12.25069523], [80.00485992, 12.25069523], [80.00485992, 12.25041676], [80.0045929, 12.25042152], [80.0045929, 12.24985886], [80.00430298, 12.24986076], [80.00430298, 12.24930477], [80.00402832, 12.2493124], [80.00402832, 12.24875069], [80.00374603, 12.24875069], [80.00374603, 12.24847126], [80.00347137, 12.24847317], [80.00347137, 12.24791718], [80.00319672, 12.24792099], [80.00319672, 12.24736118], [80.00291443, 12.24736118], [80.00291443, 12.24708271], [80.00263977, 12.24708271], [80.00263977, 12.24652863], [80.00235748, 12.24653053], [80.00235748, 12.24596977], [80.00208282, 12.24597263], [80.00208282, 12.24541664], [80.00180817, 12.24542999], [80.00180817, 12.2448597], [80.00152588, 12.2448597], [80.00152588, 12.24431133], [80.00125122, 12.24431133], [80.00125122, 12.24375057], [80.00096893, 12.24375057], [80.00096893, 12.24347019], [80.00069427, 12.2434721], [80.00069427, 12.24291611], [80.00041962, 12.24292088], [80.00041962, 12.24264145], [80.00013733, 12.24264145], [80.00013733, 12.24207973], [79.99986267, 12.24208355], [79.99986267, 12.24180603], [79.99958038, 12.2418108], [79.99958038, 12.24096966], [79.99930573, 12.24097157], [79.99930573, 12.24069405], [79.99903107, 12.24069405], [79.99903107, 12.24041557], [79.99874878, 12.2404213], [79.99874878, 12.24013996], [79.99846649, 12.24013996], [79.99846649, 12.23985958], [79.99819183, 12.23986244], [79.99819183, 12.23958206], [79.99736023, 12.23958206], [79.99736023, 12.23986244], [79.99710083, 12.23985958], [79.99710083, 12.24013996], [79.99681091, 12.24013996], [79.99681091, 12.2404213], [79.99624634, 12.2404213], [79.99624634, 12.23958015], [79.99652863, 12.23958206], [79.99652863, 12.23930645], [79.99736023, 12.23930645], [79.99736023, 12.23902798], [79.99764252, 12.23903275], [79.99764252, 12.23764038], [79.99736023, 12.23764038], [79.99736023, 12.23736], [79.99708557, 12.23736], [79.99708557, 12.23680592], [79.99681091, 12.23681068], [79.99681091, 12.2365303], [79.99652863, 12.2365303], [79.99652863, 12.23596954], [79.99624634, 12.2359724], [79.99624634, 12.23569393], [79.99597168, 12.23569393], [79.99597168, 12.23513985], [79.99569702, 12.23513985], [79.99569702, 12.23458195], [79.99541473, 12.23458385], [79.99541473, 12.23402786], [79.99514008, 12.23402977], [79.99514008, 12.23375034], [79.99485779, 12.23375034], [79.99485779, 12.23347187], [79.99458313, 12.23347187], [79.99458313, 12.23319435], [79.99404144, 12.23320007], [79.99404144, 12.23291969], [79.99375153, 12.23291969], [79.99375153, 12.23180962], [79.99346924, 12.23180962], [79.99346924, 12.23097134], [79.99319458, 12.23097134], [79.99319458, 12.23041534], [79.99291992, 12.23042202], [79.99291992, 12.22985935], [79.99263763, 12.22986126], [79.99263763, 12.22930527], [79.99236298, 12.22931004], [79.99236298, 12.22902966], [79.99208069, 12.22902966], [79.99208069, 12.22874928], [79.99180603, 12.22874928], [79.99180603, 12.22846889], [79.99153137, 12.2284708], [79.99153137, 12.22819328], [79.99124908, 12.22819328], [79.99124908, 12.22736073], [79.9909668, 12.22736073], [79.9909668, 12.22681046], [79.99069214, 12.22681046], [79.99069214, 12.22625065], [79.99041748, 12.22625065], [79.99041748, 12.22569084], [79.99013519, 12.22569466], [79.99013519, 12.22541714], [79.98986053, 12.22542191], [79.98986053, 12.22486115], [79.98958588, 12.22486115], [79.98958588, 12.22430515], [79.98929596, 12.22432137], [79.98929596, 12.22403145], [79.98902893, 12.22403145], [79.98902893, 12.22375107], [79.98874664, 12.22375107], [79.98874664, 12.22347069], [79.98847198, 12.2234726], [79.98847198, 12.22319508], [79.98819733, 12.22319508], [79.98819733, 12.22263908], [79.98790741, 12.22264099], [79.98790741, 12.22236061], [79.98764038, 12.22236061], [79.98764038, 12.22208309], [79.98735809, 12.22208309], [79.98735809, 12.22152901], [79.98707581, 12.22153091], [79.98707581, 12.22097111], [79.98680878, 12.22097301], [79.98680878, 12.22069454], [79.98652649, 12.22069454], [79.98652649, 12.22013855], [79.98625183, 12.22014141], [79.98625183, 12.21986103], [79.98596954, 12.21986103], [79.98596954, 12.2195797], [79.98569489, 12.21958256], [79.98569489, 12.21930695], [79.98542023, 12.21931076], [79.98542023, 12.21903133], [79.98513794, 12.21903133], [79.98513794, 12.21875095], [79.98487091, 12.21875095], [79.98487091, 12.21846962], [79.98458099, 12.21847343], [79.98458099, 12.21819496], [79.98430634, 12.21819496], [79.98430634, 12.21791744], [79.98401642, 12.21792126], [79.98401642, 12.21764088], [79.98374939, 12.21764088], [79.98374939, 12.21597004], [79.98347473, 12.21597195], [79.98347473, 12.21569443], [79.98319244, 12.21569443], [79.98319244, 12.21485996], [79.98291779, 12.21485996], [79.98291779, 12.21431065], [79.98264313, 12.21431065], [79.98264313, 12.21375275], [79.98181152, 12.21375275], [79.98181152, 12.21347046], [79.98152924, 12.21347237], [79.98152924, 12.21291637], [79.98124695, 12.21292114], [79.98124695, 12.21236038], [79.98097229, 12.21236229], [79.98097229, 12.2118063], [79.98069763, 12.21181107], [79.98069763, 12.21152973], [79.98042297, 12.21152973], [79.98042297, 12.21097183], [79.98014069, 12.21097183], [79.98014069, 12.21041584], [79.9798584, 12.21041965], [79.9798584, 12.20985985], [79.97958374, 12.20985985], [79.97958374, 12.20930576], [79.97930908, 12.20932198], [79.97930908, 12.20874977], [79.97902679, 12.20874977], [79.97902679, 12.20819092], [79.97875214, 12.20819378], [79.97875214, 12.20791626], [79.97846985, 12.20792007], [79.97846985, 12.20736027], [79.97819519, 12.20736217], [79.97819519, 12.20680618], [79.9779129, 12.20681], [79.9779129, 12.20625019], [79.97763824, 12.20625019], [79.97763824, 12.20569134], [79.97736359, 12.2056942], [79.97736359, 12.20514011], [79.9770813, 12.20514202], [79.9770813, 12.20486164], [79.97680664, 12.20486164], [79.97680664, 12.20458126], [79.97652435, 12.20458412], [79.97652435, 12.20430565], [79.97624969, 12.20431042], [79.97624969, 12.20403194], [79.97596741, 12.20403194], [79.97596741, 12.20375156], [79.97567749, 12.20375156], [79.97567749, 12.2031889], [79.97541809, 12.20319557], [79.97541809, 12.20263863], [79.9751358, 12.20263863], [79.9751358, 12.2023592], [79.97486115, 12.20236111], [79.97486115, 12.20180511], [79.97458649, 12.20181179], [79.97458649, 12.20125103], [79.97429657, 12.20125103], [79.97429657, 12.20097065], [79.97402954, 12.20097256], [79.97402954, 12.20041656], [79.97374725, 12.20042038], [79.97374725, 12.19986057], [79.9734726, 12.19986057], [79.9734726, 12.19958305], [79.97319794, 12.19958305], [79.97319794, 12.19902706], [79.97293091, 12.19903183], [79.97293091, 12.19847107], [79.97264099, 12.19847107], [79.97264099, 12.19819546], [79.9723587, 12.19819546], [79.9723587, 12.19763947], [79.97207642, 12.19764137], [79.97207642, 12.19709015], [79.97180176, 12.19709015], [79.97180176, 12.1965313], [79.97097015, 12.1965313], [79.97097015, 12.19625092], [79.97070313, 12.19625092], [79.97070313, 12.19569969], [79.97041321, 12.19569016], [79.97041321, 12.1954174], [79.97013855, 12.19541931], [79.97013855, 12.19486141], [79.96986389, 12.19486141], [79.96986389, 12.19458294], [79.9695816, 12.19458294], [79.9695816, 12.19402885], [79.96930695, 12.19403076], [79.96930695, 12.19347095], [79.96902466, 12.19347286], [79.96902466, 12.19291687], [79.96875, 12.19292068], [79.96875, 12.19264126], [79.96848297, 12.19264126], [79.96848297, 12.19207954], [79.96819305, 12.19208336], [79.96819305, 12.19152641], [79.9679184, 12.19153118], [79.9679184, 12.1912508], [79.96763611, 12.1912508], [79.96763611, 12.19069004], [79.96736145, 12.19069481], [79.96736145, 12.19013786], [79.96708679, 12.19014072], [79.96708679, 12.18957996], [79.9668045, 12.18958473], [79.9668045, 12.18930435], [79.96652985, 12.18931103], [79.96652985, 12.18875027], [79.96624756, 12.18875027], [79.96624756, 12.18847179], [79.9659729, 12.18847179], [79.9659729, 12.18792057], [79.96569824, 12.18792057], [79.96569061, 12.18736172], [79.96541595, 12.18736172], [79.96541595, 12.18708038], [79.9651413, 12.18708229], [79.9651413, 12.18652821], [79.96485901, 12.18653107], [79.96485901, 12.18624973], [79.96457672, 12.18624973], [79.96457672, 12.18569183], [79.96430206, 12.18569374], [79.96430206, 12.18541622], [79.9640274, 12.18542099], [79.9640274, 12.18486023], [79.96375275, 12.18486214], [79.96375275, 12.18458366], [79.96347046, 12.18458366], [79.96347046, 12.18402767], [79.9631958, 12.18402958], [79.9631958, 12.18375015], [79.96290588, 12.18375015], [79.96290588, 12.18318939], [79.96263885, 12.18319416], [79.96263885, 12.18291569], [79.96235657, 12.18292046], [79.96235657, 12.18264008], [79.96208191, 12.18264008], [79.96208191, 12.18209076], [79.96180725, 12.18209076], [79.96180725, 12.18181038], [79.96151733, 12.18181038], [79.96151733, 12.18124962], [79.96125031, 12.18124962], [79.96125031, 12.18096924], [79.96097565, 12.1809721], [79.96097565, 12.18041801], [79.9606781, 12.18041992], [79.9606781, 12.18013954], [79.9604187, 12.18013954], [79.9604187, 12.17958069], [79.96013641, 12.17958355], [79.96013641, 12.17902756], [79.95986176, 12.17902756], [79.95986176, 12.17875004], [79.9595871, 12.17875195], [79.9595871, 12.17819118], [79.95930481, 12.17819309], [79.95930481, 12.17791462], [79.95903015, 12.17792034], [79.95903015, 12.17736244], [79.95874786, 12.17736244], [79.95874786, 12.17708397], [79.95847321, 12.17708397], [79.95847321, 12.17680454], [79.95819092, 12.17681026], [79.95819092, 12.17624855], [79.95791626, 12.17624855], [79.95791626, 12.17597103], [79.9576416, 12.17597103], [79.9576416, 12.17541695], [79.95735931, 12.17541981], [79.95735931, 12.17513943], [79.95707703, 12.17513943], [79.95707703, 12.17486095], [79.95680237, 12.17486095], [79.95680237, 12.17430973], [79.95652771, 12.17430973], [79.95652771, 12.1740303], [79.95625305, 12.1740303], [79.95625305, 12.17375088], [79.95597076, 12.17375088], [79.95597076, 12.17319107], [79.95569611, 12.17319489], [79.95569611, 12.17291737], [79.95540619, 12.17292023], [79.95540619, 12.17263889], [79.95513916, 12.17263889], [79.95513916, 12.17208099], [79.9548645, 12.1720829], [79.9548645, 12.17180538], [79.95458221, 12.17181015], [79.95458221, 12.17153168], [79.95430756, 12.17153168], [79.95430756, 12.17097092], [79.95402527, 12.17097092], [79.95402527, 12.1706953], [79.95375061, 12.1706953], [79.95375061, 12.17013931], [79.95347595, 12.17015266], [79.95347595, 12.16986084], [79.95318604, 12.16986084], [79.95318604, 12.16931152], [79.95291901, 12.16931152], [79.95291901, 12.16902924], [79.95263672, 12.16902924], [79.95263672, 12.16874886], [79.95236206, 12.16874886], [79.95236206, 12.16819477], [79.95207977, 12.16819477], [79.95207977, 12.16791725], [79.95179749, 12.16792107], [79.95179749, 12.16736126], [79.95153046, 12.16736126], [79.95153046, 12.16708279], [79.95124817, 12.16708279], [79.95124817, 12.1665287], [79.95096588, 12.16653061], [79.95096588, 12.16625118], [79.95069122, 12.16625118], [79.95069122, 12.16569042], [79.95041656, 12.16569519], [79.95041656, 12.16541672], [79.95014191, 12.16542053], [79.95014191, 12.16486073], [79.94985962, 12.16486073], [79.94985962, 12.16458035], [79.94958496, 12.16458225], [79.94958496, 12.16402912], [79.94930267, 12.16402912], [79.94930267, 12.16375065], [79.94902802, 12.16375065], [79.94902802, 12.1631918], [79.94875336, 12.1631937], [79.94875336, 12.16263771], [79.94847107, 12.16264057], [79.94847107, 12.16236019], [79.94819641, 12.16236019], [79.94819641, 12.1618042], [79.94790649, 12.16181087], [79.94790649, 12.16153145], [79.94763947, 12.16153145], [79.94763947, 12.16097927], [79.94735718, 12.16097927], [79.94735718, 12.16042137], [79.94708252, 12.16042137], [79.94708252, 12.16014004], [79.94680786, 12.16014004], [79.94680786, 12.15985966], [79.94652557, 12.15986156], [79.94652557, 12.15930557], [79.94625092, 12.15931129], [79.94625092, 12.15903091], [79.9457016, 12.15903091], [79.9457016, 12.15874958], [79.94541931, 12.15874958], [79.94541931, 12.15819168], [79.94513702, 12.15819359], [79.94513702, 12.15791607], [79.94486237, 12.15792274], [79.94486237, 12.15736008], [79.94458008, 12.15736008], [79.94458008, 12.1570797], [79.94430542, 12.15708447], [79.94430542, 12.15652847], [79.94403076, 12.15653038], [79.94403076, 12.15625], [79.94374847, 12.15625], [79.94374847, 12.15568924], [79.94347382, 12.15569401], [79.94347382, 12.15513992], [79.94319153, 12.15513992], [79.94319153, 12.15485096], [79.94291687, 12.1548624], [79.94291687, 12.15430641], [79.94264221, 12.15431023], [79.94264221, 12.15402985], [79.94235992, 12.15402985], [79.94235992, 12.15347195], [79.94208527, 12.15347195], [79.94208527, 12.15319443], [79.94180298, 12.15319443], [79.94180298, 12.15264034], [79.94152832, 12.15264034], [79.94152832, 12.15236187], [79.94124603, 12.15236187], [79.94124603, 12.15180969], [79.94097137, 12.15180969], [79.94097137, 12.15153027], [79.94069672, 12.15153027], [79.94069672, 12.15125179], [79.9404068, 12.15125179], [79.9404068, 12.15069103], [79.94013977, 12.1506958], [79.94013977, 12.15041542], [79.93985748, 12.15042019], [79.93985748, 12.15013981], [79.93956757, 12.15013981], [79.93956757, 12.14985943], [79.93930817, 12.14986229], [79.93930817, 12.14930534], [79.93902588, 12.14931011], [79.93902588, 12.14904118], [79.93875122, 12.14904118], [79.93875122, 12.14874935], [79.93846893, 12.14874935], [79.93846893, 12.14847088], [79.93819427, 12.14847088], [79.93819427, 12.14791679], [79.93791962, 12.14791965], [79.93791962, 12.14735889], [79.93736267, 12.1473608], [79.93736267, 12.14708328], [79.93708038, 12.14708328], [79.93708038, 12.14652729], [79.9367981, 12.1465292], [79.9367981, 12.14625072], [79.93653107, 12.14625072], [79.93653107, 12.14514065], [79.93624878, 12.14514065], [79.93624878, 12.14458084], [79.93541718, 12.14458275], [79.93541718, 12.14430523], [79.93514252, 12.1443119], [79.93514252, 12.14375114], [79.93486023, 12.14375114], [79.93486023, 12.14346886], [79.93458557, 12.14347267], [79.93458557, 12.14291668], [79.93430328, 12.14291668], [79.93430328, 12.1418047], [79.93402863, 12.14180946], [79.93402863, 12.14153099], [79.9337616, 12.14153099], [79.9337616, 12.14125061], [79.93347168, 12.14125061], [79.93347168, 12.14068985], [79.93319702, 12.14069462], [79.93319702, 12.1404171], [79.9329071, 12.14042091], [79.9329071, 12.13985157], [79.93264008, 12.13986111], [79.93264008, 12.13875103], [79.93235779, 12.13875103], [79.93235779, 12.1384697], [79.93180847, 12.13847256], [79.93180847, 12.13819504], [79.93125153, 12.13819504], [79.93125153, 12.13763905], [79.93152618, 12.13764095], [79.93152618, 12.13735962], [79.93180847, 12.13735962], [79.93180847, 12.1370821], [79.93152618, 12.1370821], [79.93152618, 12.13652897], [79.93125153, 12.13653088], [79.93125153, 12.13625145], [79.93096924, 12.13625145], [79.93096924, 12.13568974], [79.93069458, 12.13569355], [79.93069458, 12.13541603], [79.93041992, 12.1354208], [79.93041992, 12.13457966], [79.93013763, 12.13458538], [79.93013763, 12.13430595], [79.92986298, 12.13431072], [79.92986298, 12.13404179], [79.92958069, 12.13404179], [79.92958069, 12.13374996], [79.92930603, 12.13374996], [79.92930603, 12.13346958], [79.92903137, 12.13347244], [79.92903137, 12.13291645], [79.92874908, 12.13292122], [79.92874908, 12.13264275], [79.9284668, 12.13264275], [79.9284668, 12.13208199], [79.92819214, 12.13208199], [79.92819214, 12.13180637], [79.92791748, 12.13181114], [79.92791748, 12.13125038], [79.92762756, 12.13125038], [79.92762756, 12.13068867], [79.92736053, 12.13069439], [79.92736053, 12.13041592], [79.92708588, 12.13042068], [79.92708588, 12.12985992], [79.92679596, 12.12985992], [79.92679596, 12.12957954], [79.92652893, 12.12958431], [79.92652893, 12.12902832], [79.92624664, 12.12903023], [79.92624664, 12.12847042], [79.92597198, 12.12847233], [79.92597198, 12.12819386], [79.92569733, 12.12819386], [79.92569733, 12.12763786], [79.92542267, 12.12763977], [79.92542267, 12.12708187], [79.92514038, 12.12708378], [79.92514038, 12.12680626], [79.92485809, 12.12681007], [79.92485809, 12.12625027], [79.92456818, 12.12625027], [79.92456818, 12.12597179], [79.92430878, 12.12597179], [79.92430878, 12.12541962], [79.92402649, 12.12541962], [79.92402649, 12.12487125], [79.92375183, 12.12487125], [79.92375183, 12.12458134], [79.92346954, 12.1245842], [79.92346954, 12.12402821], [79.92318726, 12.12403202], [79.92318726, 12.12347126], [79.92292023, 12.12347126], [79.92292023, 12.12319565], [79.92263794, 12.12319565], [79.92263794, 12.12263966], [79.92236328, 12.12263966], [79.92236328, 12.1220789], [79.92208099, 12.12208271], [79.92208099, 12.12180519], [79.92182159, 12.12180996], [79.92182159, 12.1212492], [79.92152405, 12.1212492], [79.92152405, 12.12097359], [79.92124939, 12.12097359], [79.92124939, 12.12041664], [79.9209671, 12.12042046], [79.9209671, 12.11986065], [79.92069244, 12.11986065], [79.92069244, 12.11931038], [79.92041779, 12.11931038], [79.92041779, 12.11875057], [79.92014313, 12.11875057], [79.92014313, 12.11847115], [79.91986084, 12.11847115], [79.91986084, 12.11819458], [79.91958618, 12.11819458], [79.91958618, 12.11791706], [79.91929626, 12.11792183], [79.91929626, 12.11764145], [79.91902924, 12.11764145], [79.91902924, 12.11708069], [79.91874695, 12.1170826], [79.91874695, 12.1165266], [79.91847229, 12.11653137], [79.91847229, 12.11597061], [79.91819763, 12.11597347], [79.91819763, 12.11541653], [79.91792297, 12.11541939], [79.91792297, 12.11486053], [79.91764069, 12.11486053], [79.91764069, 12.11430454], [79.9173584, 12.11430931], [79.9173584, 12.11375141], [79.91707611, 12.11375141], [79.91707611, 12.1131897], [79.91680908, 12.11319542], [79.91680908, 12.11291695], [79.91652679, 12.1129303], [79.91652679, 12.11236095], [79.91625214, 12.11236095], [79.91625214, 12.11181068], [79.91596985, 12.11181068], [79.91596985, 12.11153126], [79.91568756, 12.11153126], [79.91568756, 12.11096954], [79.9154129, 12.11097336], [79.9154129, 12.11041737], [79.91513824, 12.11042118], [79.91513824, 12.1101408], [79.91485596, 12.1101408], [79.91485596, 12.10958004], [79.9145813, 12.10958195], [79.9145813, 12.10902882], [79.91430664, 12.10903072], [79.91430664, 12.10875034], [79.91401672, 12.10875034], [79.91401672, 12.10846996], [79.91374969, 12.10847187], [79.91374969, 12.10791588], [79.91348267, 12.10792065], [79.91348267, 12.10764122], [79.91319275, 12.10764122], [79.91319275, 12.10736275], [79.91291809, 12.10736275], [79.91291809, 12.10681057], [79.91262817, 12.10681057], [79.91262817, 12.10653114], [79.91236115, 12.10653114], [79.91236115, 12.10569191], [79.91208649, 12.10569382], [79.91208649, 12.10513783], [79.91179657, 12.10513973], [79.91179657, 12.10458183], [79.91152954, 12.10458374], [79.91152954, 12.10430622], [79.91124725, 12.10431099], [79.91124725, 12.10374069], [79.9109726, 12.10375023], [79.9109726, 12.10347176], [79.91069794, 12.10347176], [79.91069794, 12.10291576], [79.91042328, 12.10291958], [79.91042328, 12.10264015], [79.91014099, 12.10264015], [79.91014099, 12.10207939], [79.9098587, 12.10208416], [79.9098587, 12.10180569], [79.90959167, 12.10181141], [79.90959167, 12.10153008], [79.90930176, 12.10153008], [79.90930176, 12.10097027], [79.9090271, 12.10097218], [79.9090271, 12.1006937], [79.90875244, 12.1006937], [79.90875244, 12.10013771], [79.90847015, 12.10013962], [79.90847015, 12.09986019], [79.9081955, 12.0998621], [79.9081955, 12.09930611], [79.9070816, 12.09930992], [79.9070816, 12.09902954], [79.9068222, 12.09902954], [79.9068222, 12.09847164], [79.90652466, 12.09847164], [79.90652466, 12.0979147], [79.90625, 12.09793091], [79.90625, 12.09764194], [79.90598297, 12.09764194], [79.90598297, 12.09708118], [79.90569305, 12.09708405], [79.90569305, 12.09680557], [79.9054184, 12.09681034], [79.9054184, 12.09624863], [79.90513611, 12.09624863], [79.90513611, 12.0959692], [79.90486145, 12.09597111], [79.90486145, 12.09541798], [79.90458679, 12.09542179], [79.90458679, 12.09514046], [79.90429688, 12.09514046], [79.90429688, 12.09458065], [79.90402985, 12.09458256], [79.90402985, 12.09402657], [79.90374756, 12.09403038], [79.90374756, 12.09375191], [79.90345764, 12.09375191], [79.90345764, 12.09319115], [79.90319824, 12.09319305], [79.90319061, 12.09263897], [79.90291595, 12.09264183], [79.90291595, 12.09236145], [79.9026413, 12.09236145], [79.9026413, 12.09180546], [79.90235901, 12.09180546], [79.90235901, 12.09125137], [79.90207672, 12.09125137], [79.90207672, 12.09097099], [79.90180206, 12.09097099], [79.90180206, 12.09041691], [79.9015274, 12.09042168], [79.9015274, 12.0901413], [79.90125275, 12.0901413], [79.90125275, 12.08958054], [79.90097046, 12.0895834], [79.90097046, 12.0890274], [79.90068817, 12.08902931], [79.90068817, 12.08874035], [79.90041351, 12.08874893], [79.90041351, 12.08819485], [79.90013885, 12.08819485], [79.90013885, 12.08763885], [79.89985657, 12.08763885], [79.89985657, 12.08736134], [79.89958191, 12.08736134], [79.89958191, 12.08680534], [79.89930725, 12.08681202], [79.89930725, 12.08625126], [79.89901733, 12.08625126], [79.89901733, 12.08570194], [79.89875031, 12.08570194], [79.89875031, 12.08542061], [79.89848328, 12.08542061], [79.89848328, 12.0848608], [79.89819336, 12.0848608], [79.89819336, 12.08430672], [79.8979187, 12.08431053], [79.8979187, 12.08375072], [79.89765167, 12.08375072], [79.89765167, 12.08347034], [79.89736176, 12.08347321], [79.89736176, 12.08291626], [79.8970871, 12.08292103], [79.8970871, 12.08236027], [79.89680481, 12.08236027], [79.89680481, 12.08180428], [79.89653015, 12.08181095], [79.89653015, 12.08125019], [79.89624786, 12.08125019], [79.89624786, 12.08097172], [79.89597321, 12.08097172], [79.89597321, 12.08041573], [79.89569092, 12.08042145], [79.89569092, 12.07985973], [79.89541626, 12.07985973], [79.89541626, 12.07931137], [79.8951416, 12.07931137], [79.8951416, 12.07903099], [79.89485931, 12.07903099], [79.89485931, 12.07847023], [79.89458466, 12.07847214], [79.89458466, 12.07791615], [79.89430237, 12.07792091], [79.89430237, 12.07736015], [79.89402771, 12.07736206], [79.89402771, 12.07708359], [79.89375305, 12.07708359], [79.89375305, 12.0765276], [79.89347076, 12.07653046], [79.89347076, 12.07625008], [79.89319611, 12.07625008], [79.89319611, 12.07568932], [79.89291382, 12.07569408], [79.89291382, 12.07541561], [79.89263916, 12.07542038], [79.89263916, 12.07485962], [79.8923645, 12.07486153], [79.8923645, 12.07458401], [79.89208221, 12.07458401], [79.89208221, 12.07402802], [79.89180756, 12.07402992], [79.89180756, 12.07376099], [79.89151764, 12.07376099], [79.89151764, 12.07319069], [79.89125061, 12.07319355], [79.89125061, 12.07291794], [79.89097595, 12.07291985], [79.89097595, 12.07236195], [79.89068604, 12.07236195], [79.89068604, 12.07208061], [79.89041901, 12.07208443], [79.89041901, 12.07152843], [79.89013672, 12.07153034], [79.89013672, 12.07125187], [79.88986206, 12.07125187], [79.88986206, 12.07097244], [79.88957977, 12.07097244], [79.88957977, 12.07041454], [79.88931274, 12.07042027], [79.88931274, 12.07014179], [79.88903046, 12.07014179], [79.88903046, 12.06985855], [79.88874817, 12.06986237], [79.88874817, 12.06958389], [79.88847351, 12.06958389], [79.88847351, 12.06902695], [79.88819122, 12.06902981], [79.88819122, 12.06874943], [79.88791656, 12.06874943], [79.88791656, 12.06847095], [79.88764191, 12.06847095], [79.88764191, 12.06791782], [79.88735962, 12.06791973], [79.88735962, 12.06763268], [79.88708496, 12.06763935], [79.88708496, 12.06736088], [79.88680267, 12.06736088], [79.88680267, 12.06708145], [79.88652802, 12.06708336], [79.88652802, 12.06652737], [79.88625336, 12.06653023], [79.88625336, 12.06624889], [79.88597107, 12.06624889], [79.88597107, 12.06597137], [79.88569641, 12.06597328], [79.88569641, 12.06569481], [79.88541412, 12.06569481], [79.88541412, 12.06513882], [79.88513947, 12.06514168], [79.88513947, 12.0648613], [79.88486481, 12.0648613], [79.88486481, 12.06319523], [79.88458252, 12.06319523], [79.88458252, 12.06236076], [79.88430786, 12.06236076], [79.88430786, 12.06208324], [79.88346863, 12.06208324], [79.88346863, 12.06152916], [79.88318634, 12.06153107], [79.88318634, 12.06097126], [79.88291931, 12.06097317], [79.88291931, 12.06041718], [79.88265228, 12.06042099], [79.88265228, 12.05931091], [79.88236237, 12.05931091], [79.88236237, 12.05846977], [79.88208008, 12.05847263], [79.88208008, 12.05791664], [79.88181305, 12.05792141], [79.88181305, 12.05764103], [79.88153076, 12.05764103], [79.88153076, 12.05736065], [79.88124847, 12.05736065], [79.88124847, 12.05681133], [79.88096619, 12.05681133], [79.88096619, 12.05625057], [79.88069153, 12.05625057], [79.88069153, 12.05569172], [79.88041687, 12.05569363], [79.88041687, 12.05513763], [79.88014221, 12.05514145], [79.88014221, 12.05457973], [79.87985992, 12.05458546], [79.87985992, 12.05375004], [79.87957764, 12.05375004], [79.87957764, 12.05319023], [79.87930298, 12.05319405], [79.87930298, 12.05263805], [79.87902832, 12.05263805], [79.87902832, 12.05208206], [79.87875366, 12.05208206], [79.87875366, 12.05180645], [79.87930298, 12.05181122], [79.87930298, 12.05125046], [79.87902832, 12.05125046], [79.87902832, 12.05097198], [79.87847137, 12.05097198], [79.87847137, 12.05069447], [79.87819672, 12.05069447], [79.87819672, 12.05013847], [79.8779068, 12.05014038], [79.8779068, 12.04959106], [79.87763977, 12.04959106], [79.87763977, 12.0490303], [79.87735748, 12.0490303], [79.87735748, 12.04846954], [79.87708282, 12.0484724], [79.87708282, 12.04763794], [79.87680817, 12.04763985], [79.87680817, 12.04708195], [79.87652588, 12.04708385], [79.87652588, 12.04652786], [79.87625122, 12.04652977], [79.87625122, 12.04597187], [79.87596893, 12.04597187], [79.87596893, 12.04541779], [79.87568665, 12.04541969], [79.87568665, 12.04458141], [79.87541962, 12.04458427], [79.87541962, 12.04402828], [79.87513733, 12.04403019], [79.87513733, 12.04345989], [79.87486267, 12.04347134], [79.87486267, 12.04291534], [79.87458038, 12.04292011], [79.87458038, 12.04235935], [79.87430573, 12.04236221], [79.87430573, 12.04180527], [79.87403107, 12.04181004], [79.87403107, 12.04124928], [79.87374878, 12.04124928], [79.87374878, 12.04069138], [79.87347412, 12.04069328], [79.87347412, 12.0401392], [79.87319183, 12.0401392], [79.87319183, 12.0395813], [79.87291718, 12.03958321], [79.87291718, 12.03902721], [79.87264252, 12.03903198], [79.87264252, 12.03847122], [79.87236023, 12.03847122], [79.87236023, 12.03791714], [79.8720932, 12.03792191], [79.8720932, 12.03765106], [79.87180328, 12.03765106], [79.87180328, 12.03736115], [79.87152863, 12.03736115], [79.87152863, 12.03708267], [79.87124634, 12.03708267], [79.87124634, 12.03652668], [79.87097168, 12.0365324], [79.87097168, 12.03541946], [79.87071228, 12.03541946], [79.87071228, 12.03486061], [79.87041473, 12.03486061], [79.87041473, 12.03402901], [79.87014008, 12.03403091], [79.87014008, 12.03347111], [79.86985779, 12.03347301], [79.86985779, 12.03291702], [79.86958313, 12.03292084], [79.86958313, 12.03236103], [79.86930847, 12.03236103], [79.86930847, 12.03181076], [79.86902618, 12.03181076], [79.86902618, 12.03125095], [79.86875153, 12.03125095], [79.86875153, 12.03069019], [79.86846924, 12.03069496], [79.86846924, 12.02930355], [79.86818695, 12.02931118], [79.86818695, 12.0290308], [79.86791992, 12.0290308], [79.86791992, 12.02846146], [79.86763763, 12.0284729], [79.86763763, 12.02819443], [79.86736298, 12.02819443], [79.86736298, 12.02791595], [79.86708069, 12.02792072], [79.86708069, 12.02735996], [79.86680603, 12.02735996], [79.86680603, 12.02681065], [79.86653137, 12.02681065], [79.86653137, 12.02625275], [79.86624908, 12.02625275], [79.86624908, 12.02597046], [79.86597443, 12.02597237], [79.86597443, 12.0251379], [79.86569214, 12.02514267], [79.86569214, 12.02402973], [79.86541748, 12.02402973], [79.86541748, 12.02318859], [79.86513519, 12.02319431], [79.86513519, 12.02264023], [79.86486053, 12.02265167], [79.86486053, 12.02235985], [79.86458588, 12.02235985], [79.86458588, 12.02208424], [79.86430359, 12.02208424], [79.86430359, 12.02152824], [79.86402893, 12.02153015], [79.86402893, 12.02069187], [79.86374664, 12.02069378], [79.86374664, 12.01930618], [79.86347198, 12.01931], [79.86347198, 12.01846886], [79.86319733, 12.01847172], [79.86319733, 12.01791573], [79.86292267, 12.01791954], [79.86292267, 12.01736164], [79.86264038, 12.01736164], [79.86264038, 12.01708126], [79.86235809, 12.01708412], [79.86235809, 12.01680565], [79.86207581, 12.01681042], [79.86207581, 12.01596928], [79.86180878, 12.01597118], [79.86180878, 12.01569557], [79.86152649, 12.01569557], [79.86152649, 12.01541805], [79.86125183, 12.01541996], [79.86125183, 12.01513958], [79.86096954, 12.01513958], [79.86096954, 12.01458073], [79.86069489, 12.01458263], [79.86069489, 12.01402664], [79.86042023, 12.01403046], [79.86042023, 12.01375198], [79.86013794, 12.01375198], [79.86013794, 12.01292038], [79.85986328, 12.01292038], [79.85986328, 12.0118103], [79.85958099, 12.0118103], [79.85958099, 12.01153183], [79.85930634, 12.01153183], [79.85930634, 12.01069069], [79.85902405, 12.01069546], [79.85902405, 12.01013947], [79.85874939, 12.01014137], [79.85874939, 12.00986099], [79.85901642, 12.00986099], [79.85901642, 12.00958061], [79.85930634, 12.00958347], [79.85930634, 12.00902653], [79.85874939, 12.0090313], [79.85874939, 12.00847054], [79.85847473, 12.0084734], [79.85847473, 12.00763893], [79.85819244, 12.00764084], [79.85819244, 12.00680923], [79.85791779, 12.00680923], [79.85791779, 12.00597095], [79.8576355, 12.00597286], [79.8576355, 12.00541687], [79.85736084, 12.00542068], [79.85736084, 12.00486088], [79.85708618, 12.00486088], [79.85708618, 12.00457954], [79.85680389, 12.00458336], [79.85680389, 12.0037508], [79.85652924, 12.0037508], [79.85652924, 12.00347042], [79.85624695, 12.00347328], [79.85624695, 12.00291729], [79.85597229, 12.0029211], [79.85597229, 12.00264072], [79.85624695, 12.00264072], [79.85624695, 12.00207996], [79.85597229, 12.00208473], [79.85597229, 12.00180435], [79.85569763, 12.00181103], [79.85569763, 12.00014114], [79.85542297, 12.00014114], [79.85542297, 11.99986267], [79.85542297, 11.99931145], [79.85514069, 11.99931145], [79.85514069, 11.99874973], [79.8548584, 11.99874973], [79.8548584, 11.99819183], [79.85458374, 11.99819374], [79.85458374, 11.99763775], [79.85430908, 11.99763966], [79.85430908, 11.99707985], [79.85402679, 11.99708366], [79.85402679, 11.99652767], [79.85375214, 11.99652958], [79.85375214, 11.99597168], [79.85346985, 11.99597168], [79.85346985, 11.9948616], [79.85319519, 11.9948597], [79.85319519, 11.99430561], [79.8529129, 11.99431133], [79.8529129, 11.99403], [79.85320282, 11.99403], [79.85320282, 11.99374962], [79.8529129, 11.99374962], [79.8529129, 11.99347019], [79.85263824, 11.9934721], [79.85263824, 11.99263763], [79.85234833, 11.99263954], [79.85234833, 11.99208164], [79.8520813, 11.99208355], [79.8520813, 11.99097157], [79.85180664, 11.99097157], [79.85180664, 11.99069405], [79.85152435, 11.99069405], [79.85152435, 11.99041462], [79.85124969, 11.99042034], [79.85124969, 11.98931026], [79.85098267, 11.98931026], [79.85098267, 11.98903179], [79.85069275, 11.98903179], [79.85069275, 11.98874855], [79.8501358, 11.98874855], [79.8501358, 11.98847103], [79.84986115, 11.98847103], [79.84986115, 11.98819256], [79.84958649, 11.98819256], [79.84958649, 11.98764038], [79.84928894, 11.98764038], [79.84928894, 11.98654079], [79.84986115, 11.98654079], [79.84986115, 11.98569107], [79.84958649, 11.98569489], [79.84958649, 11.9845829], [79.8493042, 11.9845829], [79.8493042, 11.9837513], [79.84902954, 11.9837513], [79.84902954, 11.9829216], [79.84874725, 11.9829216], [79.84874725, 11.98208141], [79.84819794, 11.98208332], [79.84819794, 11.98124886], [79.84791565, 11.98124886], [79.84791565, 11.98069477], [79.84764099, 11.98069477], [79.84764099, 11.98041725], [79.8473587, 11.98041725], [79.8473587, 11.98013878], [79.84707642, 11.98014069], [79.84707642, 11.97819042], [79.84680176, 11.97819519], [79.84680176, 11.97708321], [79.8465271, 11.97708321], [79.8465271, 11.97680664], [79.84625244, 11.97681141], [79.84625244, 11.97625065], [79.84597015, 11.97625065], [79.84597015, 11.97403145], [79.84570313, 11.97403145], [79.84570313, 11.97375011], [79.84541321, 11.97375011], [79.84541321, 11.97346973], [79.84513855, 11.97347164], [79.84513855, 11.97208214], [79.84486389, 11.97208214], [79.84486389, 11.97069359], [79.8445816, 11.97069359], [79.8445816, 11.96930599], [79.84430695, 11.96931076], [79.84430695, 11.96875], [79.84348297, 11.96875], [79.84348297, 11.96763992], [79.84375, 11.96763992], [79.84375, 11.96735954], [79.84402466, 11.9673624], [79.84402466, 11.96708393], [79.84375, 11.96708393], [79.84375, 11.96680641], [79.84348297, 11.96681023], [79.84348297, 11.96569061], [79.84319305, 11.96569443], [79.84319305, 11.96458435], [79.84263611, 11.96458435], [79.84263611, 11.96430588], [79.84236145, 11.96430969], [79.84236145, 11.96347237], [79.84263611, 11.96347237], [79.84263611, 11.9631958], [79.84236145, 11.9631958], [79.84236145, 11.96208382], [79.84208679, 11.96208382], [79.84208679, 11.96124935], [79.84179688, 11.96124935], [79.84179688, 11.96013927], [79.84152985, 11.96013927], [79.84152985, 11.95875072], [79.84124756, 11.95875072], [79.84124756, 11.95792198], [79.8409729, 11.95792198], [79.8409729, 11.95708084], [79.84069824, 11.95708275], [79.84069061, 11.95625114], [79.84041595, 11.95625114], [79.84041595, 11.95458317], [79.8401413, 11.95458317], [79.8401413, 11.95319462], [79.83985901, 11.95319462], [79.83985901, 11.95263863], [79.8401413, 11.95264053], [79.8401413, 11.95207977], [79.83985901, 11.95208263], [79.83985901, 11.95125103], [79.83957672, 11.95125103], [79.83957672, 11.95042992], [79.83930206, 11.95042992], [79.83930206, 11.95014095], [79.8390274, 11.95014095], [79.8390274, 11.94958019], [79.83875275, 11.94958305], [79.83875275, 11.94930363], [79.8390274, 11.94931126], [79.8390274, 11.94903088], [79.83875275, 11.94903088], [79.83875275, 11.94791889], [79.83847046, 11.94791889], [79.83847046, 11.94707966], [79.8381958, 11.94708538], [79.8381958, 11.94680691], [79.83847046, 11.94681072], [79.83847046, 11.9465313], [79.8381958, 11.9465313], [79.8381958, 11.94542122], [79.83790588, 11.94542122], [79.83790588, 11.94403267], [79.83763885, 11.94403267], [79.83763885, 11.94375038], [79.83790588, 11.94375038], [79.83790588, 11.94347], [79.83763885, 11.94347191], [79.83763885, 11.9426403], [79.83790588, 11.9426403], [79.83790588, 11.94235992], [79.83763885, 11.94235992], [79.83763885, 11.94054985], [79.83069611, 11.94024944], [79.82540131, 11.94014931], [79.82540131, 11.94001007], [79.81800079, 11.94039059], [79.81420135, 11.94062138], [79.8110199, 11.94250965], [79.8081131, 11.94651031], [79.80632782, 11.95526886], [79.80602264, 11.95922089], [79.80458832, 11.96314144], [79.79972839, 11.96428967], [79.7979126, 11.96352196], [79.79527283, 11.96189022], [79.79242706, 11.95705128], [79.79165649, 11.94774055], [79.79030609, 11.94255066], [79.78756714, 11.9383707], [79.78333282, 11.94373035], [79.77879333, 11.94640064], [79.77575684, 11.94601059], [79.77272034, 11.9467907], [79.77181244, 11.94640064], [79.76937866, 11.94145107], [79.76544952, 11.93916035], [79.76420593, 11.93459034], [79.75814056, 11.93040085], [79.74784088, 11.92890167], [79.7472229, 11.91783047], [79.74751282, 11.91516113], [79.7408371, 11.90945053], [79.74053955, 11.90716076], [79.73690033, 11.9071703], [79.73658752, 11.91020966], [79.73690033, 11.92739105], [79.73356628, 11.93729973], [79.73361206, 11.94721031], [79.7144928, 11.95525074], [79.71570587, 11.9674511], [79.71790314, 11.96887112], [79.72209167, 11.96743965], [79.72692108, 11.96249199], [79.73544312, 11.96361065], [79.73816681, 11.9670496], [79.74240875, 11.96704102], [79.74513245, 11.97085094], [79.74906921, 11.97236919], [79.75244141, 11.97612953], [79.75260925, 11.97945976], [79.74964905, 11.98613071], [79.73468018, 11.99431133], [79.72899628, 11.98602104], [79.72885895, 11.98602104], [79.72711182, 11.97996998], [79.72493744, 11.97790146], [79.71985626, 11.97646046], [79.71695709, 11.97544193], [79.71259308, 11.97563076], [79.7098999, 11.97622108], [79.70584869, 11.97737026], [79.70359039, 11.98005009], [79.7016983, 11.98608971], [79.69539642, 11.99268055], [79.69075775, 11.99627972], [79.69048309, 12.00112057], [79.69242096, 12.01107121], [79.69155884, 12.0174408], [79.679039, 12.01926041], [79.67645264, 12.0128603], [79.67151642, 12.01162148], [79.66890717, 12.00729179], [79.66326141, 12.00638103], [79.65930939, 11.99689102], [79.65236664, 11.99830055], [79.64731598, 11.99722958], [79.6470108, 11.99332142], [79.64434052, 11.99267197], [79.64441681, 11.98627186], [79.64428711, 11.98627186], [79.64234161, 11.975811], [79.64420319, 11.97321033], [79.65122223, 11.97201061], [79.65960693, 11.97705078], [79.66143036, 11.97285938], [79.6653595, 11.96752167], [79.67114258, 11.97476006], [79.67344666, 11.97236919], [79.67749786, 11.97399044], [79.68113708, 11.97284126], [79.68416595, 11.97472954], [79.68689728, 11.9739809], [79.68997955, 11.9756403], [79.69480133, 11.97511101], [79.6990509, 11.97205925], [79.69921875, 11.97003078], [79.69525909, 11.96103096], [79.70192719, 11.95643139], [79.70155334, 11.95218086], [79.69315338, 11.95079041], [79.68667603, 11.94728088], [79.68543243, 11.9451704], [79.68312836, 11.94650078], [79.68148041, 11.94336033], [79.6776886, 11.93935108], [79.67819977, 11.93653202], [79.68414307, 11.92722034], [79.69023895, 11.92618275], [79.69200134, 11.92448044], [79.69277954, 11.9211998], [79.69782257, 11.91668129], [79.69608307, 11.92010021], [79.69451141, 11.92593193], [79.6946106, 11.93133068], [79.6964798, 11.93245029], [79.7060318, 11.92870998], [79.70407867, 11.91299057], [79.72489929, 11.89151001], [79.71750641, 11.88924026], [79.71601868, 11.8866806], [79.71692657, 11.87684155], [79.71537018, 11.87497044], [79.70831299, 11.87395191], [79.70437622, 11.87460136], [79.70173645, 11.87654972], [79.69153595, 11.8784008], [79.69168854, 11.89777088], [79.70250702, 11.89843178], [79.70258331, 11.90250015], [79.68286133, 11.90470886], [79.67983246, 11.89344978], [79.68229675, 11.89185047], [79.68382263, 11.88745975], [79.6799469, 11.88615036], [79.68065643, 11.8819418], [79.67987061, 11.87926197], [79.67591095, 11.87932968], [79.6687088, 11.87463093], [79.66821289, 11.87625122], [79.66036987, 11.87732029], [79.65907288, 11.87212181], [79.65907288, 11.86566925], [79.67118073, 11.86660099], [79.67090607, 11.86983109], [79.67315674, 11.86995029], [79.67838287, 11.86957073], [79.68036652, 11.87062168], [79.68205261, 11.87335014], [79.69050598, 11.87406063], [79.69573212, 11.87337971], [79.69345093, 11.85389137], [79.69766998, 11.85242081], [79.70379639, 11.83829021], [79.70668793, 11.84708977], [79.71798706, 11.84762955], [79.71817017, 11.84836197], [79.73034668, 11.84687996], [79.72776031, 11.83233929], [79.73840332, 11.83500099], [79.73944855, 11.84986115], [79.74339294, 11.85363102], [79.74363708, 11.85972118], [79.74980927, 11.8605299], [79.75099945, 11.85894966], [79.75495148, 11.85783958], [79.7557373, 11.85046959], [79.75393677, 11.84224033], [79.7515564, 11.84166145], [79.75028229, 11.83598137], [79.74871063, 11.83584023], [79.74730682, 11.83270168], [79.75213623, 11.82445145], [79.75811005, 11.82210064], [79.76043701, 11.82303143], [79.76360321, 11.83250999], [79.76539612, 11.83333111], [79.76712036, 11.84047985], [79.77849579, 11.83882999], [79.78176117, 11.840271], [79.78616333, 11.83840179], [79.78787231, 11.83508968], [79.79097748, 11.83181], [79.79402161, 11.83020973], [79.79176331, 11.82697201], [79.79281616, 11.81945992], [79.79296875, 11.81764984], [79.79397583, 11.81564045], [79.79682159, 11.81153965], [79.80041504, 11.8083992], [79.80041504, 11.80764008], [79.80069733, 11.80764008], [79.80069733, 11.80708027], [79.80041504, 11.80708408], [79.80041504, 11.80652809], [79.80014038, 11.80653], [79.80014038, 11.80568027], [79.79958344, 11.80569363], [79.79958344, 11.80513763], [79.79930878, 11.80513954], [79.79930878, 11.80263996], [79.79902649, 11.80263996], [79.79902649, 11.80181026], [79.79875183, 11.80181026], [79.79875183, 11.80125046], [79.79846954, 11.80125046], [79.79846954, 11.7990303], [79.79820251, 11.7990303], [79.79820251, 11.79875183], [79.79763794, 11.79875183], [79.79763794, 11.79653168], [79.79736328, 11.79653168], [79.79736328, 11.79347134], [79.79708099, 11.79347324], [79.79708099, 11.79263878], [79.79680634, 11.79264069], [79.79680634, 11.79181194], [79.79708099, 11.79181194], [79.79708099, 11.79014111], [79.79680634, 11.79014111], [79.79680634, 11.78903103], [79.79651642, 11.78903103], [79.79651642, 11.78875065], [79.79680634, 11.78875065], [79.79680634, 11.78736019], [79.79652405, 11.78736019], [79.79652405, 11.78625107], [79.79624939, 11.78625107], [79.79624939, 11.78514099], [79.7959671, 11.78514099], [79.7959671, 11.78431129], [79.79569244, 11.78431129], [79.79569244, 11.78374958], [79.79543304, 11.78374958], [79.79543304, 11.78318977], [79.79486084, 11.78319359], [79.79486084, 11.78291607], [79.79458618, 11.78292084], [79.79458618, 11.78236008], [79.79569244, 11.78236008], [79.79569244, 11.77874088], [79.79541779, 11.77875042], [79.79541779, 11.77764034], [79.79514313, 11.77764034], [79.79514313, 11.77596855], [79.79541779, 11.77597237], [79.79541779, 11.77513981], [79.7951355, 11.77513981], [79.7951355, 11.77486229], [79.79458618, 11.77486229], [79.79458618, 11.77319336], [79.79430389, 11.77319336], [79.79430389, 11.77152729], [79.79402924, 11.77153015], [79.79402924, 11.77042198], [79.79429626, 11.77042198], [79.79429626, 11.76986122], [79.79402924, 11.76986122], [79.79402924, 11.76930523], [79.79429626, 11.7693119], [79.79429626, 11.76903152], [79.79402924, 11.76903152], [79.79402924, 11.76791859], [79.79374695, 11.76791859], [79.79374695, 11.76764107], [79.79347229, 11.76764107], [79.79347229, 11.76679993], [79.79319763, 11.7668047], [79.79319763, 11.76569462], [79.79291534, 11.76569462], [79.79291534, 11.76375103], [79.79264069, 11.76375961], [79.79264069, 11.76347065], [79.79291534, 11.76347256], [79.79291534, 11.76291656], [79.79264069, 11.76292133], [79.79264069, 11.76264095], [79.7923584, 11.76264095], [79.7923584, 11.76208019], [79.79208374, 11.76208305], [79.79208374, 11.76180458], [79.79180908, 11.76181126], [79.79180908, 11.76069927], [79.79152679, 11.76069927], [79.79152679, 11.75957966], [79.79125214, 11.75958157], [79.79125214, 11.75791645], [79.79096985, 11.75792122], [79.79096985, 11.75681114], [79.79070282, 11.75681114], [79.79070282, 11.75597], [79.7904129, 11.75597191], [79.7904129, 11.7551403], [79.79013824, 11.7551403], [79.79013824, 11.75431061], [79.78985596, 11.75431061], [79.78985596, 11.75319195], [79.7895813, 11.75319386], [79.7895813, 11.74819565], [79.78930664, 11.74819565], [79.78930664, 11.74791527], [79.78900909, 11.74792004], [79.78900909, 11.74597073], [79.78874969, 11.74597359], [79.78874969, 11.74430466], [79.78848267, 11.74431038], [79.78848267, 11.74319077], [79.78819275, 11.74319458], [79.78819275, 11.74291706], [79.78791809, 11.74292183], [79.78791809, 11.74263], [79.7876358, 11.74263859], [79.7876358, 11.7420826], [79.78736115, 11.7420826], [79.78736115, 11.74124908], [79.7876358, 11.74125099], [79.7876358, 11.74041939], [79.78736115, 11.74041939], [79.78736115, 11.73903084], [79.78708649, 11.73903084], [79.78708649, 11.73764133], [79.78679657, 11.73764133], [79.78679657, 11.73653126], [79.78652954, 11.73653126], [79.78652954, 11.73597145], [79.78624725, 11.73597336], [79.78624725, 11.73513889], [79.7859726, 11.7351408], [79.7859726, 11.7343092], [79.78569794, 11.7343092], [79.78569794, 11.7337513], [79.78541565, 11.7337513], [79.78541565, 11.7331953], [79.78514099, 11.7331953], [79.78514099, 11.73291588], [79.78542328, 11.73292065], [79.78542328, 11.73236275], [79.78514099, 11.73236275], [79.78514099, 11.73208046], [79.7848587, 11.73208237], [79.7848587, 11.73124981], [79.78457642, 11.73125267], [79.78457642, 11.72931099], [79.78430176, 11.72931099], [79.78430176, 11.72792053], [79.7840271, 11.72792053], [79.7840271, 11.72708035], [79.78375244, 11.72708416], [79.78375244, 11.7256937], [79.78347015, 11.7256937], [79.78347015, 11.72541809], [79.78320313, 11.72542], [79.78320313, 11.72513962], [79.78291321, 11.72513962], [79.78291321, 11.72459126], [79.78263855, 11.72459126], [79.78263855, 11.72375202], [79.78291321, 11.72375202], [79.78291321, 11.72319126], [79.78263855, 11.72319412], [79.78263855, 11.72208405], [79.78236389, 11.72208405], [79.78236389, 11.72180557], [79.7820816, 11.72181034], [79.7820816, 11.72124958], [79.78180695, 11.72124958], [79.78180695, 11.7209692], [79.78152466, 11.72097206], [79.78152466, 11.72069263], [79.78069305, 11.72069263], [79.78069305, 11.72041798], [79.7804184, 11.72042179], [79.7804184, 11.71986198], [79.78069305, 11.71986198], [79.78069305, 11.71958065], [79.78097534, 11.71958447], [79.78097534, 11.71819305], [79.78069305, 11.71819305], [79.78069305, 11.71736145], [79.7804184, 11.71736145], [79.7804184, 11.71708298], [79.78013611, 11.71708298], [79.78013611, 11.71680546], [79.77986145, 11.71681023], [79.77986145, 11.71652889], [79.77958679, 11.71652889], [79.77958679, 11.71597099], [79.77902985, 11.71597099], [79.77902985, 11.71374893], [79.77874756, 11.71375084], [79.77874756, 11.71347141], [79.7784729, 11.71347332], [79.7784729, 11.71236134], [79.77819824, 11.71236134], [79.77819061, 11.71152687], [79.77791595, 11.71153069], [79.77791595, 11.71097088], [79.7776413, 11.71097279], [79.7776413, 11.71013927], [79.77735901, 11.71014118], [79.77735901, 11.7098608], [79.77708435, 11.7098608], [79.77708435, 11.70958328], [79.77625275, 11.70958328], [79.77625275, 11.7098608], [79.77597046, 11.7098608], [79.77597046, 11.71014118], [79.7756958, 11.71013927], [79.7756958, 11.71097279], [79.77540588, 11.71097088], [79.77540588, 11.71125126], [79.77513885, 11.71125126], [79.77513885, 11.71097088], [79.7748642, 11.71097279], [79.7748642, 11.71041679], [79.77458191, 11.71042061], [79.77458191, 11.70847034], [79.7748642, 11.70847321], [79.7748642, 11.70819473], [79.77513885, 11.70819473], [79.77513885, 11.70763874], [79.7756958, 11.70764065], [79.7756958, 11.70736122], [79.77625275, 11.70736122], [79.77625275, 11.70708466], [79.77680206, 11.70708466], [79.77680206, 11.70680428], [79.77735901, 11.70681095], [79.77735901, 11.7059679], [79.77708435, 11.70597267], [79.77708435, 11.7056942], [79.7765274, 11.7056942], [79.7765274, 11.70541573], [79.77680206, 11.70542145], [79.77680206, 11.70431137], [79.7765274, 11.70431137], [79.7765274, 11.70292091], [79.77625275, 11.70292091], [79.77625275, 11.70181084], [79.77597046, 11.70181084], [79.77597046, 11.70042133], [79.7756958, 11.70042133], [79.7756958, 11.69931126], [79.77540588, 11.69931126], [79.77540588, 11.69819164], [79.77513885, 11.69819355], [79.77513885, 11.69680595], [79.77485657, 11.69680977], [79.77485657, 11.69596863], [79.77458191, 11.69597244], [79.77458191, 11.69569397], [79.7748642, 11.69569397], [79.7748642, 11.69541645], [79.77513885, 11.69542027], [79.77513885, 11.69431019], [79.77485657, 11.69431019], [79.77485657, 11.69291973], [79.77458191, 11.69291973], [79.77458191, 11.6926403], [79.77432251, 11.6926403], [79.77432251, 11.69236183], [79.7740097, 11.69236183], [79.7740097, 11.69180965], [79.77432251, 11.69180965], [79.77432251, 11.69124889], [79.77458191, 11.69124889], [79.77458191, 11.69042015], [79.77485657, 11.69042015], [79.77485657, 11.68958092], [79.77458191, 11.68958282], [79.77458191, 11.68930531], [79.77432251, 11.68931198], [79.77432251, 11.6890316], [79.7740097, 11.6890316], [79.7740097, 11.68848038], [79.77375031, 11.68848038], [79.77375031, 11.68403053], [79.77348328, 11.68403053], [79.77348328, 11.68375111], [79.77319336, 11.68375111], [79.77319336, 11.68292141], [79.7729187, 11.68292141], [79.7729187, 11.68181133], [79.77263641, 11.68181133], [79.77263641, 11.68125057], [79.77236176, 11.68125057], [79.77236176, 11.68042088], [79.7720871, 11.68042088], [79.7720871, 11.67903137], [79.77179718, 11.67903137], [79.77179718, 11.67819023], [79.77153015, 11.67819405], [79.77153015, 11.6773634], [79.77124786, 11.6773634], [79.77124786, 11.67625046], [79.77097321, 11.67625046], [79.77097321, 11.67374992], [79.77069092, 11.67374992], [79.77069092, 11.67153263], [79.77041626, 11.67153263], [79.77041626, 11.67041111], [79.7701416, 11.67041588], [79.7701416, 11.6693058], [79.76985931, 11.66930962], [79.76985931, 11.66819096], [79.76958466, 11.66819572], [79.76958466, 11.66736221], [79.76930237, 11.66736221], [79.76930237, 11.66597366], [79.76902771, 11.6659708], [79.76902771, 11.66458321], [79.76875305, 11.66458321], [79.76875305, 11.66319466], [79.76847076, 11.66319466], [79.76847076, 11.66180515], [79.76818848, 11.66181183], [79.76818848, 11.66069126], [79.76791382, 11.66069508], [79.76791382, 11.65930462], [79.76763916, 11.65931034], [79.76763916, 11.65792179], [79.76735687, 11.65792179], [79.76735687, 11.65625095], [79.76708221, 11.65625095], [79.76708221, 11.65514088], [79.76680756, 11.65514088], [79.76680756, 11.65375137], [79.76652527, 11.65375137], [79.76652527, 11.65208244], [79.76625061, 11.65208244], [79.76625061, 11.65041637], [79.76597595, 11.65042114], [79.76597595, 11.64875031], [79.76568604, 11.64875031], [79.76568604, 11.64708042], [79.76541901, 11.64708424], [79.76541901, 11.64541626], [79.76512909, 11.64542007], [79.76512909, 11.64375019], [79.76486206, 11.64375019], [79.76486206, 11.64207935], [79.76457977, 11.64208412], [79.76457977, 11.64041805], [79.76431274, 11.6404314], [79.76431274, 11.63875198], [79.76403046, 11.63875198], [79.76403046, 11.63708115], [79.76374817, 11.63708305], [79.76374817, 11.63625145], [79.76346588, 11.63625145], [79.76346588, 11.63597107], [79.76319122, 11.63597107], [79.76319122, 11.63513947], [79.76291656, 11.63514233], [79.76291656, 11.63458061], [79.76264191, 11.63458347], [79.76264191, 11.63374901], [79.76235962, 11.63375092], [79.76235962, 11.63347054], [79.76264191, 11.6334734], [79.76264191, 11.63319492], [79.76235962, 11.63319111], [79.76235962, 11.6329174], [79.76180267, 11.63291931], [79.76180267, 11.63236141], [79.76152802, 11.63236141], [79.76152802, 11.63208294], [79.76125336, 11.63208294], [79.76125336, 11.63180542], [79.76097107, 11.63180923], [79.76097107, 11.6312418], [79.76125336, 11.63125134], [79.76125336, 11.63041687], [79.76152802, 11.63042068], [79.76152802, 11.62903118], [79.76125336, 11.62903118], [79.76125336, 11.62820244], [79.76097107, 11.62820244], [79.76097107, 11.6273613], [79.76069641, 11.6273613], [79.76069641, 11.62708473], [79.76041412, 11.62708473], [79.76041412, 11.62680435], [79.76013947, 11.62681103], [79.76013947, 11.62597275], [79.76040649, 11.62597275], [79.76040649, 11.62569046], [79.76069641, 11.62569523], [79.76069641, 11.6254158], [79.76040649, 11.62543011], [79.76040649, 11.62514114], [79.76069641, 11.62514114], [79.76069641, 11.62458038], [79.76097107, 11.62458229], [79.76097107, 11.62402821], [79.76069641, 11.62403107], [79.76069641, 11.62374973], [79.76040649, 11.62374973], [79.76040649, 11.62318993], [79.76069641, 11.62319374], [79.76069641, 11.62236023], [79.76097107, 11.62236023], [79.76097107, 11.62208366], [79.76125336, 11.62208366], [79.76125336, 11.62097168], [79.76097107, 11.62097168], [79.76097107, 11.62069416], [79.76069641, 11.62069416], [79.76069641, 11.62013817], [79.76040649, 11.62014008], [79.76040649, 11.61847019], [79.76013947, 11.6184721], [79.76013947, 11.61791801], [79.75985718, 11.61791992], [79.75985718, 11.61736202], [79.75958252, 11.61736202], [79.75958252, 11.61708164], [79.75930786, 11.61708355], [79.75930786, 11.61680603], [79.75902557, 11.61680603], [79.75902557, 11.61708355], [79.75818634, 11.61708164], [79.75818634, 11.61763954], [79.75791931, 11.61763954], [79.75791931, 11.61791992], [79.75763702, 11.61791801], [79.75763702, 11.6184721], [79.75708008, 11.6184721], [79.75708008, 11.61763763], [79.75681305, 11.61763954], [79.75681305, 11.61653042], [79.75763702, 11.61653042], [79.75763702, 11.61626053], [79.75818634, 11.61626053], [79.75818634, 11.61568928], [79.75902557, 11.61569405], [79.75902557, 11.61541557], [79.76040649, 11.61542034], [79.76040649, 11.61485958], [79.76013947, 11.61486244], [79.76013947, 11.61402798], [79.75985718, 11.61403179], [79.75985718, 11.61320019], [79.75958252, 11.61320019], [79.75958252, 11.61291981], [79.75932312, 11.61291981], [79.75932312, 11.61236191], [79.75902557, 11.61236191], [79.75902557, 11.61180496], [79.75875092, 11.61180973], [79.75875092, 11.6115303], [79.7590332, 11.6115303], [79.7590332, 11.61069107], [79.75930786, 11.61069584], [79.75930786, 11.61013889], [79.75958252, 11.61013889], [79.75958252, 11.60902691], [79.75932312, 11.60903168], [79.75932312, 11.6087513], [79.75958252, 11.6087513], [79.75958252, 11.60763931], [79.75932312, 11.60763931], [79.75932312, 11.60625076], [79.7590332, 11.60625076], [79.7590332, 11.6034708], [79.75875092, 11.6034708], [79.75875092, 11.60041714], [79.75846863, 11.60042095], [79.75846863, 11.59846973], [79.75819397, 11.5984726], [79.75819397, 11.5951376], [79.75791931, 11.5951376], [79.75791931, 11.59180641], [79.75763702, 11.59181118], [79.75763702, 11.58792019], [79.75736237, 11.58792019], [79.75736237, 11.58403015], [79.75708008, 11.58403015], [79.75708008, 11.5781908], [79.75736237, 11.57819462], [79.75736237, 11.56735992], [79.75708008, 11.56735992], [79.75708008, 11.56707954], [79.75736237, 11.56708431], [79.75736237, 11.56680584], [79.75763702, 11.56681061], [79.75763702, 11.56458187], [79.75736237, 11.56458378], [79.75736237, 11.56430626], [79.75708008, 11.56431103], [79.75708008, 11.56375027], [79.75736237, 11.56375027], [79.75736237, 11.56319237], [79.75763702, 11.56319427], [79.75763702, 11.56041622], [79.75791931, 11.56042004], [79.75791931, 11.5581913], [79.75819397, 11.55819321], [79.75819397, 11.55597115], [79.75846863, 11.55597115], [79.75846863, 11.55374908], [79.75875092, 11.55375099], [79.75875092, 11.55208111], [79.75902557, 11.55208302], [79.75902557, 11.55195999], [79.75902557, 11.55069542], [79.75930786, 11.55069542], [79.75930786, 11.54902744], [79.75958252, 11.54903126], [79.75958252, 11.54653072], [79.75985718, 11.54653072], [79.75985718, 11.5462513], [79.76013947, 11.5462513], [79.76013947, 11.54458046], [79.76041412, 11.54458237], [79.76041412, 11.5429163], [79.76069641, 11.54292107], [79.76069641, 11.54207993], [79.76097107, 11.54208374], [79.76097107, 11.54097176], [79.76125336, 11.54098129], [79.76125336, 11.53985977], [79.76152802, 11.53985977], [79.76152802, 11.5381918], [79.76125336, 11.5381937], [79.76125336, 11.5373621], [79.76152802, 11.5373621], [79.76152802, 11.53708363], [79.76208496, 11.53708363], [79.76208496, 11.53625011], [79.76235962, 11.53625202], [79.76235962, 11.53542042], [79.76264191, 11.53542042], [79.76264191, 11.53485012], [79.76291656, 11.53485966], [79.76291656, 11.53374958], [79.76319122, 11.53374958], [79.76319122, 11.53236198], [79.76346588, 11.53236198], [79.76346588, 11.53208065], [79.76374817, 11.53208447], [79.76374817, 11.53180599], [79.76403046, 11.53180981], [79.76403046, 11.53097057], [79.76430511, 11.53097057], [79.76430511, 11.53013897], [79.76457977, 11.53014183], [79.76457977, 11.52958107], [79.76430511, 11.52958298], [79.76430511, 11.52902699], [79.76457977, 11.52904129], [79.76457977, 11.52875137], [79.76430511, 11.52875137], [79.76430511, 11.52819538], [79.76403046, 11.52819538], [79.76403046, 11.52791691], [79.76374817, 11.52791977], [79.76374817, 11.52736092], [79.76403046, 11.52736092], [79.76403046, 11.52680969], [79.76457977, 11.52680492], [79.76457977, 11.5270834], [79.76486206, 11.5270834], [79.76486206, 11.52680492], [79.76541901, 11.52680969], [79.76541901, 11.52652931], [79.76568604, 11.52652931], [79.76568604, 11.52625084], [79.76597595, 11.52625084], [79.76597595, 11.52598], [79.76625061, 11.52598], [79.76625061, 11.52541924], [79.7665329, 11.52541924], [79.7665329, 11.52486134], [79.76680756, 11.52486134], [79.76680756, 11.52430534], [79.76708221, 11.52431202], [79.76708221, 11.52375126], [79.76735687, 11.52375126], [79.76735687, 11.52291012], [79.76763916, 11.52291679], [79.76763916, 11.52263927], [79.76790619, 11.52264118], [79.76790619, 11.52153111], [79.76818848, 11.52153111], [79.76818848, 11.5209713], [79.76847076, 11.52097321], [79.76847076, 11.52041721], [79.76875305, 11.52042103], [79.76875305, 11.51958275], [79.76902771, 11.51958466], [79.76902771, 11.51902866], [79.76930237, 11.51903057], [79.76930237, 11.51819038], [79.76958466, 11.51819515], [79.76958466, 11.51791573], [79.76930237, 11.51792145], [79.76930237, 11.51735973], [79.76957703, 11.51735973], [79.76957703, 11.51653099], [79.76985931, 11.51653099], [79.76985931, 11.51597023], [79.7701416, 11.51597214], [79.7701416, 11.51541615], [79.77041626, 11.51542091], [79.77041626, 11.51486015], [79.77069092, 11.51486015], [79.77069092, 11.51458359], [79.77097321, 11.51458359], [79.77097321, 11.51430416], [79.77126312, 11.51431084], [79.77126312, 11.51375008], [79.77153015, 11.51375008], [79.77153015, 11.51292133], [79.77126312, 11.51292133], [79.77126312, 11.51264], [79.77153015, 11.51264], [79.77153015, 11.51235962], [79.77180481, 11.51236153], [79.77180481, 11.51208401], [79.7720871, 11.51208401], [79.7720871, 11.51152802], [79.77236176, 11.51152992], [79.77236176, 11.51097202], [79.77263641, 11.51097202], [79.77263641, 11.51041603], [79.7729187, 11.51041985], [79.7729187, 11.50986195], [79.77319336, 11.50986195], [79.77319336, 11.50791073], [79.77347565, 11.50791645], [79.77347565, 11.50736237], [79.77402496, 11.50736237], [79.77402496, 11.50708389], [79.77430725, 11.50708389], [79.77430725, 11.50680637], [79.77458191, 11.50681019], [79.77458191, 11.50625038], [79.77485657, 11.50625038], [79.77485657, 11.50569057], [79.77513885, 11.50569344], [79.77513885, 11.50541782], [79.77540588, 11.50541973], [79.77540588, 11.5051403], [79.7756958, 11.5051403], [79.7756958, 11.50458145], [79.77597046, 11.50458431], [79.77597046, 11.50430489], [79.77625275, 11.50430965], [79.77625275, 11.50403023], [79.7765274, 11.50403023], [79.7765274, 11.50347137], [79.77680206, 11.50347137], [79.77680206, 11.50319576], [79.77708435, 11.50319576], [79.77708435, 11.50291538], [79.77735901, 11.50292015], [79.77735901, 11.50264168], [79.7776413, 11.50264168], [79.7776413, 11.50208092], [79.77791595, 11.50208282], [79.77791595, 11.50180531], [79.77819061, 11.50181198], [79.77819824, 11.5015316], [79.7784729, 11.5015316], [79.7784729, 11.50124931], [79.77874756, 11.50124931], [79.77874756, 11.50069141], [79.77958679, 11.50069523], [79.77958679, 11.50041676], [79.77986145, 11.50041962], [79.77986145, 11.49958134], [79.78013611, 11.49958324], [79.78013611, 11.49847317], [79.7804184, 11.49847317], [79.7804184, 11.49736118], [79.78069305, 11.49736118], [79.78069305, 11.49625111], [79.78098297, 11.49625111], [79.78097534, 11.49513912], [79.78125, 11.49514103], [79.78125, 11.49403095], [79.78151703, 11.49403095], [79.78151703, 11.4931879], [79.78180695, 11.49319458], [79.78180695, 11.49208164], [79.7820816, 11.49208164], [79.7820816, 11.49097347], [79.78236389, 11.49097347], [79.78236389, 11.49013805], [79.78263855, 11.49014091], [79.78263855, 11.48931122], [79.78291321, 11.48931122], [79.78291321, 11.48847008], [79.7831955, 11.48847198], [79.7831955, 11.48763847], [79.78347015, 11.48764038], [79.78347015, 11.48653126], [79.78375244, 11.48653126], [79.78375244, 11.48569202], [79.7840271, 11.48569393], [79.7840271, 11.48486233], [79.78430176, 11.48486233], [79.78430176, 11.48402786], [79.78457642, 11.48403263], [79.78457642, 11.48319244], [79.7848587, 11.48319435], [79.7848587, 11.48264027], [79.78514099, 11.48264027], [79.78514099, 11.48180962], [79.78542328, 11.48180962], [79.78542328, 11.48124981], [79.78569794, 11.48124981], [79.78569794, 11.48069382], [79.7859726, 11.48069382], [79.7859726, 11.47986221], [79.78624725, 11.47986221], [79.78624725, 11.47930622], [79.78652954, 11.47931004], [79.78652954, 11.47846889], [79.7868042, 11.4784708], [79.7868042, 11.47791767], [79.78708649, 11.47793102], [79.78708649, 11.47736168], [79.78736115, 11.47736168], [79.78736115, 11.47681046], [79.7876358, 11.47681046], [79.7876358, 11.4762516], [79.78791809, 11.4762516], [79.78791809, 11.47597122], [79.78819275, 11.47597122], [79.78819275, 11.47569466], [79.78847504, 11.47569466], [79.78847504, 11.47513866], [79.78874969, 11.47514153], [79.78874969, 11.47486973], [79.78900909, 11.47486973], [79.78900909, 11.47430992], [79.78929901, 11.47430992], [79.78929901, 11.47402859], [79.7895813, 11.47402859], [79.7895813, 11.47347069], [79.78986359, 11.4734726], [79.78986359, 11.47319317], [79.79013824, 11.47319317], [79.79013824, 11.4729166], [79.7904129, 11.47292042], [79.7904129, 11.47236061], [79.79069519, 11.47236061], [79.79069519, 11.47208309], [79.79096985, 11.47208309], [79.79096985, 11.4715271], [79.79125214, 11.47153187], [79.79125214, 11.47125053], [79.79152679, 11.47125053], [79.79152679, 11.47069073], [79.79180908, 11.47069454], [79.79180908, 11.47041702], [79.79207611, 11.47042179], [79.79207611, 11.46986103], [79.7923584, 11.46986103], [79.7923584, 11.46958065], [79.79264069, 11.46958256], [79.79264069, 11.46902657], [79.79292297, 11.46903133], [79.79292297, 11.46874046], [79.79319763, 11.46875095], [79.79319763, 11.46847343], [79.79347229, 11.46847343], [79.79347229, 11.46791744], [79.79374695, 11.46792126], [79.79374695, 11.46764088], [79.79402924, 11.46764088], [79.79402924, 11.46708012], [79.79430389, 11.46708298], [79.79430389, 11.46680546], [79.79458618, 11.46680927], [79.79458618, 11.46652889], [79.79486084, 11.46652889], [79.79486084, 11.46597004], [79.7951355, 11.4659729], [79.7951355, 11.46569538], [79.79543304, 11.4656992], [79.79543304, 11.4651413], [79.79569244, 11.4651413], [79.79569244, 11.46485996], [79.7959671, 11.46485996], [79.7959671, 11.46431065], [79.79624939, 11.46431065], [79.79624939, 11.46403122], [79.79651642, 11.46403122], [79.79651642, 11.46375275], [79.79680634, 11.46375275], [79.79680634, 11.46319199], [79.79708099, 11.46319389], [79.79708099, 11.46291637], [79.79736328, 11.46292114], [79.79736328, 11.46236038], [79.79763794, 11.46236038], [79.79763794, 11.46208191], [79.79792023, 11.46208191], [79.79792023, 11.4618063], [79.79820251, 11.46181107], [79.79820251, 11.46125031], [79.79846954, 11.46125031], [79.79846954, 11.46068954], [79.79875183, 11.46069431], [79.79875183, 11.46014023], [79.79902649, 11.46014023], [79.79902649, 11.45957088], [79.79930878, 11.45958424], [79.79930878, 11.45902824], [79.79957581, 11.45903015], [79.79957581, 11.45847034], [79.79985809, 11.45847225], [79.79985809, 11.45791626], [79.80014038, 11.45792103], [79.80014038, 11.45736027], [79.80041504, 11.45736217], [79.80041504, 11.45680618], [79.80069733, 11.45680618], [79.80069733, 11.45625019], [79.80097198, 11.45625019], [79.80097198, 11.45568943], [79.80124664, 11.4556942], [79.80124664, 11.45514011], [79.80152893, 11.45514011], [79.80152893, 11.45457935], [79.80180359, 11.45458412], [79.80180359, 11.45402813], [79.80208588, 11.45403004], [79.80208588, 11.45346928], [79.80236053, 11.45347214], [79.80236053, 11.45263958], [79.80264282, 11.45263958], [79.80264282, 11.45208073], [79.80291748, 11.45208359], [79.80291748, 11.4515276], [79.80319214, 11.45153046], [79.80319214, 11.45069981], [79.8034668, 11.45069981], [79.8034668, 11.45014191], [79.80374908, 11.45014191], [79.80374908, 11.44958115], [79.80403137, 11.44958305], [79.80403137, 11.44902706], [79.8042984, 11.44903183], [79.8042984, 11.4487524], [79.80458069, 11.4487524], [79.80458069, 11.44819069], [79.80486298, 11.44819546], [79.80486298, 11.44791698], [79.80513763, 11.44791985], [79.80513763, 11.44736099], [79.80541992, 11.44736099], [79.80541992, 11.44708061], [79.80569458, 11.44708347], [79.80569458, 11.44652653], [79.80596924, 11.44652939], [79.80596924, 11.44597054], [79.80625153, 11.4459734], [79.80625153, 11.44569302], [79.80652618, 11.44569302], [79.80652618, 11.44513893], [79.80680847, 11.44514084], [79.80680847, 11.44486141], [79.80708313, 11.44486141], [79.80708313, 11.44458294], [79.80735779, 11.44458294], [79.80735779, 11.44375134], [79.80708313, 11.44375134], [79.80708313, 11.44318962], [79.80735779, 11.44319534], [79.80735779, 11.44236088], [79.80764008, 11.44236088], [79.80764008, 11.4412508], [79.8079071, 11.4412508], [79.8079071, 11.44014072], [79.80819702, 11.44014072], [79.80819702, 11.43903065], [79.80847168, 11.43903065], [79.80847168, 11.43792057], [79.80874634, 11.43792057], [79.80874634, 11.43708038], [79.80902863, 11.43708229], [79.80902863, 11.43624973], [79.80930328, 11.43624973], [79.80930328, 11.43542099], [79.8095932, 11.43542099], [79.8095932, 11.43457985], [79.80986023, 11.43458366], [79.80986023, 11.43319416], [79.81014252, 11.43319416], [79.81014252, 11.43263817], [79.81041718, 11.43263817], [79.81041718, 11.43208408], [79.81069183, 11.43208408], [79.81069183, 11.43152809], [79.81096649, 11.43153], [79.81096649, 11.43068886], [79.81124878, 11.43069363], [79.81124878, 11.42958355], [79.81153107, 11.42959118], [79.81153107, 11.42818928], [79.81180573, 11.42819405], [79.81180573, 11.42708397], [79.81208038, 11.42708397], [79.81208038, 11.42597198], [79.81236267, 11.42597198], [79.81236267, 11.42486191], [79.81263733, 11.42486191], [79.81263733, 11.42375183], [79.81291962, 11.42375183], [79.81291962, 11.42292023], [79.81317902, 11.42292023], [79.81317902, 11.42181015], [79.81346893, 11.42181015], [79.81346893, 11.42097092], [79.81375122, 11.42097092], [79.81375122, 11.42013931], [79.81402588, 11.42013931], [79.81402588, 11.4191227], [79.81402588, 11.41902733], [79.81430817, 11.41902924], [79.81430817, 11.41792202], [79.81458282, 11.41792202], [79.81458282, 11.41625118], [79.81485748, 11.41625118], [79.81485748, 11.41459179], [79.81513977, 11.41459179], [79.81513977, 11.41292095], [79.8154068, 11.41292095], [79.8154068, 11.41125107], [79.81569672, 11.41125107], [79.81569672, 11.40958023], [79.81597137, 11.40958214], [79.81597137, 11.40791607], [79.8162384, 11.40792084], [79.8162384, 11.40625], [79.81652832, 11.40625], [79.81652832, 11.40458202], [79.81680298, 11.40458202], [79.81680298, 11.40236187], [79.8170929, 11.40236187], [79.81708527, 11.4006958], [79.81735992, 11.4006958], [79.81735992, 11.40013981], [79.81764221, 11.40013981], [79.81764221, 11.39931011], [79.81791687, 11.39931011], [79.81791687, 11.39875031], [79.81819153, 11.39875031], [79.81819153, 11.39764023], [79.81846619, 11.39764023], [79.81846619, 11.39652061], [79.81874847, 11.39652729], [79.81874847, 11.39513874], [79.81903076, 11.3951416], [79.81903076, 11.39374924], [79.81931305, 11.39374924], [79.81930542, 11.39263916], [79.81958008, 11.39264202], [79.81958008, 11.39125061], [79.81986237, 11.39125061], [79.81986237, 11.39014053], [79.82013702, 11.39014053], [79.82013702, 11.38875103], [79.82041931, 11.38875103], [79.82041931, 11.38736057], [79.82069397, 11.38736057], [79.82069397, 11.38624859], [79.82096863, 11.38625145], [79.82096863, 11.38514137], [79.82125092, 11.38514137], [79.82125092, 11.38431072], [79.8215332, 11.38431072], [79.8215332, 11.38375092], [79.82180786, 11.38375092], [79.82180786, 11.38292122], [79.82208252, 11.38292122], [79.82208252, 11.38236046], [79.82236481, 11.38236046], [79.82236481, 11.38180733], [79.82263947, 11.38181114], [79.82263947, 11.38125038], [79.82290649, 11.38125038], [79.82290649, 11.38097], [79.82319641, 11.38097191], [79.82319641, 11.38041592], [79.82347107, 11.38042068], [79.82347107, 11.3801403], [79.82375336, 11.3801403], [79.82375336, 11.37957954], [79.82402802, 11.37958431], [79.82402802, 11.37902832], [79.82430267, 11.37903118], [79.82430267, 11.37874985], [79.82347107, 11.37874985], [79.82347107, 11.37708187], [79.82319641, 11.37708378], [79.82319641, 11.3754158], [79.82347107, 11.37541962], [79.82347107, 11.37457943], [79.82375336, 11.3745842], [79.82375336, 11.37374973], [79.82402802, 11.37374973], [79.82402802, 11.37292004], [79.82430267, 11.37292004], [79.82430267, 11.37042046], [79.82457733, 11.37042046], [79.82457733, 11.3698616], [79.82485962, 11.3698616], [79.82485962, 11.36931038], [79.82514191, 11.36931038], [79.82514191, 11.36847115], [79.82541656, 11.36847115], [79.82541656, 11.36791706], [79.82569122, 11.36792183], [79.82569122, 11.36736107], [79.82596588, 11.36736107], [79.82596588, 11.36654091], [79.82624817, 11.36654091], [79.82624817, 11.36597061], [79.82653046, 11.36597347], [79.82653046, 11.36541653], [79.82681274, 11.36542034], [79.82681274, 11.36486053], [79.82707977, 11.36486053], [79.82707977, 11.36347103], [79.82736206, 11.36347961], [79.82736206, 11.36292171], [79.82402802, 11.36291695], [79.82402802, 11.36319542], [79.82375336, 11.36319065], [79.82375336, 11.36347961], [79.82347107, 11.36347961], [79.82347107, 11.36375141], [79.82319641, 11.36375141], [79.82319641, 11.36403179], [79.82290649, 11.36403179], [79.82290649, 11.36431026], [79.82263947, 11.36430454], [79.82263947, 11.36486053], [79.82237244, 11.36486053], [79.82237244, 11.36514091], [79.82208252, 11.36514091], [79.82208252, 11.36542034], [79.82069397, 11.36541653], [79.82069397, 11.36569309], [79.82041931, 11.36569118], [79.82041931, 11.36625099], [79.81986237, 11.36625099], [79.81986237, 11.36680984], [79.81958008, 11.36680984], [79.81958008, 11.36763859], [79.81931305, 11.36763859], [79.81931305, 11.36792183], [79.81903076, 11.36791706], [79.81903076, 11.36819553], [79.81874847, 11.36819553], [79.81874847, 11.36847115], [79.81846619, 11.36847115], [79.81846619, 11.36875153], [79.81819153, 11.36875153], [79.81819153, 11.36903191], [79.81791687, 11.36903191], [79.81791687, 11.36931038], [79.81735992, 11.36930466], [79.81735992, 11.36958408], [79.81652832, 11.36958122], [79.81652832, 11.3698616], [79.81597137, 11.3698616], [79.81597137, 11.37014198], [79.81569672, 11.37014198], [79.81569672, 11.37042046], [79.81236267, 11.37041759], [79.81236267, 11.37069321], [79.81180573, 11.37069321], [79.81180573, 11.37208366], [79.81208038, 11.3720789], [79.81208038, 11.37263966], [79.81236267, 11.37263966], [79.81236267, 11.37319374], [79.81263733, 11.37319374], [79.81263733, 11.37347221], [79.81291962, 11.37346935], [79.81291962, 11.37374973], [79.81317902, 11.37374973], [79.81317902, 11.37403011], [79.81346893, 11.37402821], [79.81346893, 11.3745842], [79.81375122, 11.37457943], [79.81375122, 11.37597179], [79.81346893, 11.37597179], [79.81346893, 11.37763977], [79.81317902, 11.37763977], [79.81317902, 11.3779211], [79.81291962, 11.3779211], [79.81291962, 11.37848091], [79.81263733, 11.37848091], [79.81263733, 11.37903118], [79.81236267, 11.37903118], [79.81236267, 11.37931061], [79.81208038, 11.37931061], [79.81208038, 11.37985992], [79.81153107, 11.37985992], [79.81153107, 11.3801403], [79.81124878, 11.3801403], [79.81124878, 11.38042068], [79.81097412, 11.38041592], [79.81097412, 11.38069439], [79.81069183, 11.38069439], [79.81069183, 11.38097191], [79.81041718, 11.38097191], [79.81043243, 11.38125038], [79.81014252, 11.38125038], [79.81014252, 11.38264084], [79.81041718, 11.38263798], [79.81041718, 11.3834734], [79.81014252, 11.38346958], [79.81014252, 11.38375092], [79.8095932, 11.38375092], [79.8095932, 11.38346958], [79.80930328, 11.3834734], [79.80930328, 11.38236046], [79.80902863, 11.38236046], [79.80902863, 11.38097191], [79.80930328, 11.38097191], [79.80930328, 11.38069439], [79.80958557, 11.38069439], [79.80958557, 11.38041592], [79.80986023, 11.38042068], [79.80986023, 11.3801403], [79.81014252, 11.3801403], [79.81014252, 11.37957954], [79.81041718, 11.37958431], [79.81041718, 11.37930584], [79.81069183, 11.37931061], [79.81069183, 11.37903118], [79.81096649, 11.37903118], [79.81096649, 11.37848091], [79.81153107, 11.37848091], [79.81153107, 11.3779211], [79.81181335, 11.3779211], [79.81181335, 11.37763977], [79.81208038, 11.37763977], [79.81208038, 11.37736034], [79.81236267, 11.37736225], [79.81236267, 11.37680626], [79.81263733, 11.37681103], [79.81263733, 11.37652969], [79.81291962, 11.37652969], [79.81291962, 11.37597179], [79.81263733, 11.37597179], [79.81263733, 11.37541962], [79.81236267, 11.37541962], [79.81236267, 11.37485981], [79.81208038, 11.37485981], [79.81208038, 11.3745842], [79.81180573, 11.3745842], [79.81180573, 11.37430573], [79.81153107, 11.37430954], [79.81153107, 11.37374973], [79.81124878, 11.37374973], [79.81124878, 11.37319088], [79.81097412, 11.37319374], [79.81097412, 11.37263966], [79.81069183, 11.37263966], [79.81069183, 11.37097073], [79.81097412, 11.37097073], [79.81097412, 11.37041759], [79.81124878, 11.37042046], [79.81124878, 11.37014198], [79.81153107, 11.37014198], [79.81153107, 11.36958122], [79.81180573, 11.36958408], [79.81180573, 11.36930466], [79.81208038, 11.36931038], [79.81208038, 11.36903191], [79.81291962, 11.36903191], [79.81291962, 11.36875153], [79.81375122, 11.36875153], [79.81375122, 11.36819077], [79.81402588, 11.36819553], [79.81402588, 11.36791706], [79.81458282, 11.36791706], [79.81458282, 11.36819553], [79.81485748, 11.36819553], [79.81485748, 11.36847115], [79.81541443, 11.36847115], [79.81541443, 11.36819553], [79.81569672, 11.36819553], [79.81569672, 11.36680508], [79.8162384, 11.36680984], [79.8162384, 11.36654091], [79.81652832, 11.36654091], [79.81652832, 11.36625099], [79.8170929, 11.36625099], [79.8170929, 11.36597061], [79.81735992, 11.36597347], [79.81735992, 11.36569309], [79.81819153, 11.36569309], [79.81819153, 11.36541653], [79.81846619, 11.36542034], [79.81846619, 11.36486053], [79.81874847, 11.36486053], [79.81874847, 11.36458302], [79.81819153, 11.36458302], [79.81819153, 11.36430454], [79.81791687, 11.36430454], [79.81791687, 11.36458302], [79.81652832, 11.36458302], [79.81652832, 11.36430454], [79.81680298, 11.36431026], [79.81680298, 11.36375141], [79.8170929, 11.36375141], [79.8170929, 11.36319065], [79.81735992, 11.36319542], [79.81735992, 11.36263943], [79.81764221, 11.36264133], [79.81764221, 11.36208057], [79.81791687, 11.36208344], [79.81791687, 11.36152744], [79.81819153, 11.36153126], [79.81819153, 11.36097145], [79.81847382, 11.36097336], [79.81847382, 11.36041737], [79.81874847, 11.36041737], [79.81874847, 11.35986137], [79.81903076, 11.35986137], [79.81903076, 11.3595829], [79.81930542, 11.3595829], [79.81930542, 11.35930538], [79.81958008, 11.3593092], [79.81958008, 11.35903072], [79.82013702, 11.35903072], [79.82013702, 11.3587513], [79.82096863, 11.3587513], [79.82096863, 11.35818958], [79.82125092, 11.3581953], [79.82125092, 11.35763931], [79.8215332, 11.35764122], [79.8215332, 11.3573513], [79.82180786, 11.35735989], [79.82180786, 11.35708237], [79.82208252, 11.35708046], [79.82208252, 11.35764122], [79.82237244, 11.35764122], [79.82237244, 11.35792065], [79.82263947, 11.35792065], [79.82263947, 11.3587513], [79.82290649, 11.3587513], [79.82290649, 11.3593092], [79.82347107, 11.35930538], [79.82347107, 11.3595829], [79.82430267, 11.3595829], [79.82430267, 11.35930538], [79.82457733, 11.3593092], [79.82457733, 11.3587513], [79.82485962, 11.3587513], [79.82485962, 11.35846996], [79.82514191, 11.35847282], [79.82514191, 11.3581953], [79.82541656, 11.3581953], [79.82541656, 11.35791683], [79.82569122, 11.35792065], [79.82569122, 11.3573513], [79.82597351, 11.35735989], [79.82597351, 11.35708237], [79.82707977, 11.35708237], [79.82707977, 11.35680676], [79.82736206, 11.35681057], [79.82736206, 11.35653114], [79.82817841, 11.35653114], [79.82817841, 11.35569], [79.82847595, 11.35569382], [79.82847595, 11.3554163], [79.82875061, 11.35542107], [79.82875061, 11.35514069], [79.8290329, 11.35514069], [79.8290329, 11.35486031], [79.82930756, 11.35486031], [79.82930756, 11.35458469], [79.83041382, 11.35458469], [79.83041382, 11.35430431], [79.83154297, 11.35431099], [79.83154297, 11.35403061], [79.83235931, 11.35403061], [79.83235931, 11.35375023], [79.8326416, 11.35375023], [79.8326416, 11.35346985], [79.83319092, 11.35346985], [79.83319092, 11.35375023], [79.83374786, 11.35375023], [79.83374786, 11.35403061], [79.83431244, 11.35403061], [79.83431244, 11.35431099], [79.8345871, 11.35430431], [79.8345871, 11.35458469], [79.83513641, 11.35458469], [79.83513641, 11.35486031], [79.8354187, 11.35486031], [79.8354187, 11.35792065], [79.83569336, 11.35791683], [79.83569336, 11.35847282], [79.83597565, 11.35847282], [79.83597565, 11.3595829], [79.83569336, 11.3595829], [79.83569336, 11.35986137], [79.83513641, 11.35986137], [79.83513641, 11.36125088], [79.83347321, 11.36125088], [79.83347321, 11.36153126], [79.83319092, 11.36153126], [79.83319092, 11.36181164], [79.83347321, 11.36180496], [79.83347321, 11.36208344], [79.83403015, 11.36208057], [79.83403015, 11.36236095], [79.83431244, 11.36236095], [79.83431244, 11.36264133], [79.83569336, 11.36264133], [79.83569336, 11.36208057], [79.83597565, 11.36208344], [79.83597565, 11.36180496], [79.83625031, 11.36181164], [79.83625031, 11.36125088], [79.83651733, 11.36125088], [79.83651733, 11.36069012], [79.83680725, 11.36069489], [79.83680725, 11.36013889], [79.83708191, 11.36013889], [79.83708191, 11.3593092], [79.83734894, 11.3593092], [79.83734894, 11.35792065], [79.83763885, 11.35792065], [79.83763885, 11.35681057], [79.83790588, 11.35681057], [79.83790588, 11.35486031], [79.8381958, 11.35486031], [79.8381958, 11.35263824], [79.83847046, 11.35264015], [79.83847046, 11.34817791], [79.83875275, 11.34819412], [79.83875275, 11.3423624], [79.83847046, 11.34237099], [79.83847046, 11.33902931], [79.8381958, 11.33902931], [79.8381958, 11.33736134], [79.83791351, 11.33736134], [79.83791351, 11.33541679], [79.8381958, 11.33542156], [79.8381958, 11.33318138], [79.83791351, 11.33319473], [79.83791351, 11.33041668], [79.83763885, 11.33043003], [79.83763885, 11.32792091], [79.83734894, 11.32792091], [79.83734894, 11.32514], [79.83708191, 11.32514], [79.83708191, 11.3220787], [79.83680725, 11.32208443], [79.83680725, 11.31847191], [79.83652496, 11.31847191], [79.83652496, 11.31541538], [79.83680725, 11.31543064], [79.83680725, 11.31291962], [79.83708191, 11.31291962], [79.83708191, 11.30986118], [79.8373642, 11.30986118], [79.8373642, 11.30402565], [79.83763885, 11.30403137], [79.83763885, 11.30013084], [79.83791351, 11.30013847], [79.83791351, 11.29652786], [79.8381958, 11.29652977], [79.8381958, 11.29319096], [79.83847046, 11.29319382], [79.83847046, 11.29041767], [79.83875275, 11.29041958], [79.83875275, 11.28763866], [79.8390274, 11.28763866], [79.8390274, 11.28486061], [79.83930206, 11.28486061], [79.83930206, 11.28292179], [79.83957672, 11.28292179], [79.83957672, 11.28153133], [79.83985901, 11.28153133], [79.83985901, 11.28014088], [79.8401413, 11.28014088], [79.8401413, 11.27847004], [79.84041595, 11.2784729], [79.84041595, 11.2770834], [79.84069061, 11.2770834], [79.84069824, 11.27569485], [79.8409729, 11.27569485], [79.8409729, 11.27375031], [79.84124756, 11.27375031], [79.84124756, 11.27124977], [79.84152985, 11.27124977], [79.84152985, 11.26902962], [79.84179688, 11.26902962], [79.84179688, 11.2670908], [79.84208679, 11.2670908], [79.84208679, 11.2656889], [79.84236145, 11.26569366], [79.84236145, 11.26458359], [79.84263611, 11.26458359], [79.84263611, 11.26375008], [79.8429184, 11.26375198], [79.8429184, 11.2618103], [79.84319305, 11.2618103], [79.84319305, 11.26069069], [79.84347534, 11.26069641], [79.84347534, 11.25958347], [79.84375, 11.25958347], [79.84375, 11.2584734], [79.84402466, 11.2584734], [79.84402466, 11.25736141], [79.84430695, 11.25736141], [79.84430695, 11.25625134], [79.8445816, 11.25625134], [79.8445816, 11.2551527], [79.84485626, 11.2551527], [79.84485626, 11.25403118], [79.84513855, 11.25403118], [79.84513855, 11.2529192], [79.84541321, 11.2529192], [79.84541321, 11.25181103], [79.84570313, 11.25181103], [79.84570313, 11.25042057], [79.84597015, 11.25042057], [79.84597015, 11.24901962], [79.84625244, 11.24902916], [79.84625244, 11.24791622], [79.84654236, 11.24792099], [79.84654236, 11.24653053], [79.84680176, 11.24653053], [79.84680176, 11.24514008], [79.84654236, 11.24514008], [79.84654236, 11.24403], [79.84625244, 11.24403], [79.84625244, 11.24347019], [79.84597015, 11.2434721], [79.84597015, 11.24291611], [79.84570313, 11.24292088], [79.84570313, 11.24236202], [79.84541321, 11.24236202], [79.84541321, 11.24153042], [79.84513855, 11.24153042], [79.84513855, 11.24042034], [79.84485626, 11.24042034], [79.84485626, 11.2395792], [79.8445816, 11.23958397], [79.8445816, 11.23930645], [79.84430695, 11.23931026], [79.84430695, 11.23903179], [79.84375, 11.23903179], [79.84375, 11.23875046], [79.84319305, 11.23875046], [79.84319305, 11.23847198], [79.8429184, 11.23847198], [79.8429184, 11.23819447], [79.8418045, 11.23819447], [79.8418045, 11.2379179], [79.8381958, 11.23791981], [79.8381958, 11.23764038], [79.83708191, 11.23764038], [79.83708191, 11.23736191], [79.83680725, 11.23736191], [79.83680725, 11.23708057], [79.83652496, 11.23708439], [79.83652496, 11.23680592], [79.83598328, 11.23680973], [79.83598328, 11.2365303], [79.8354187, 11.2365303], [79.8354187, 11.23625183], [79.83460236, 11.23625183], [79.83460236, 11.23597145], [79.83403015, 11.23597145], [79.83403015, 11.23569584], [79.83319092, 11.23569584], [79.83319092, 11.23541546], [79.83069611, 11.23542023], [79.83069611, 11.23513985], [79.83013916, 11.23513985], [79.83013916, 11.23542023], [79.82985687, 11.23542023], [79.82985687, 11.23625183], [79.83040619, 11.23625183], [79.83040619, 11.23597145], [79.83180237, 11.23597145], [79.83180237, 11.23625183], [79.83235931, 11.23625183], [79.83235931, 11.2365303], [79.83291626, 11.2365303], [79.83291626, 11.23680973], [79.83430481, 11.23680592], [79.83430481, 11.23708439], [79.8345871, 11.23708439], [79.8345871, 11.23736191], [79.83431244, 11.23736191], [79.83431244, 11.23764038], [79.83403015, 11.23764038], [79.83403015, 11.23791981], [79.83347321, 11.2379179], [79.83347321, 11.23819447], [79.83125305, 11.23819447], [79.83125305, 11.23847198], [79.83069611, 11.23847198], [79.83069611, 11.23875046], [79.83013916, 11.23875046], [79.83013916, 11.23903179], [79.82958221, 11.23903179], [79.82958221, 11.23931026], [79.82902527, 11.23930645], [79.82902527, 11.23958397], [79.82875061, 11.2395792], [79.82875061, 11.24015141], [79.82846832, 11.24015141], [79.82846832, 11.24042034], [79.82819366, 11.24041557], [79.82819366, 11.24069405], [79.82791901, 11.24069405], [79.82791901, 11.24097157], [79.82771301, 11.24097157], [79.82681274, 11.24096966], [79.82681274, 11.24125004], [79.82430267, 11.24125004], [79.82430267, 11.24096966], [79.82402802, 11.24097157], [79.82402802, 11.24069405], [79.82375336, 11.24069405], [79.82375336, 11.23958397], [79.82430267, 11.23958397], [79.82430267, 11.23986244], [79.82569122, 11.23985958], [79.82569122, 11.24015141], [79.82624817, 11.24015141], [79.82624817, 11.23985958], [79.82653046, 11.23986244], [79.82653046, 11.23958397], [79.82680511, 11.23958397], [79.82680511, 11.23902798], [79.82707977, 11.23903179], [79.82707977, 11.23875046], [79.82736206, 11.23875046], [79.82736206, 11.23819065], [79.82653046, 11.23819447], [79.82653046, 11.2379179], [79.82597351, 11.2379179], [79.82597351, 11.23819447], [79.82569122, 11.23819447], [79.82569122, 11.2379179], [79.82402802, 11.23791981], [79.82402802, 11.23764038], [79.82375336, 11.23764038], [79.82375336, 11.23736191], [79.82347107, 11.23736191], [79.82347107, 11.23708057], [79.82319641, 11.23708439], [79.82319641, 11.23680592], [79.82263947, 11.23680973], [79.82263947, 11.23625183], [79.82237244, 11.23625183], [79.82237244, 11.23597145], [79.82180786, 11.23597145], [79.82180786, 11.23569584], [79.82125092, 11.23569584], [79.82125092, 11.23541546], [79.82096863, 11.23542023], [79.82096863, 11.23513985], [79.82125092, 11.23513985], [79.82125092, 11.23486233], [79.82152557, 11.23486233], [79.82152557, 11.2345829], [79.82263947, 11.2345829], [79.82263947, 11.23486233], [79.82291412, 11.23486233], [79.82291412, 11.23430538], [79.82263947, 11.23431015], [79.82263947, 11.23402119], [79.82236481, 11.23402691], [79.82236481, 11.23347092], [79.82208252, 11.23347092], [79.82208252, 11.2331953], [79.82180786, 11.2331953], [79.82180786, 11.23291683], [79.8215332, 11.23291969], [79.8215332, 11.23263931], [79.82096863, 11.23263931], [79.82096863, 11.23236084], [79.82041931, 11.23236084], [79.82041931, 11.23208141], [79.81903076, 11.23208332], [79.81903076, 11.23180485], [79.81791687, 11.23180962], [79.81791687, 11.23152924], [79.8162384, 11.23152924], [79.8162384, 11.23180962], [79.81597137, 11.23180485], [79.81597137, 11.23208332], [79.81430817, 11.23208141], [79.81430817, 11.23236084], [79.81346893, 11.23236084], [79.81346893, 11.23291969], [79.81319427, 11.23291683], [79.81319427, 11.2331953], [79.81236267, 11.2331953], [79.81236267, 11.23347092], [79.81153107, 11.23347092], [79.81153107, 11.23374939], [79.81097412, 11.23374939], [79.81097412, 11.23402691], [79.81014252, 11.23402119], [79.81014252, 11.23431015], [79.80958557, 11.23430538], [79.80958557, 11.23486233], [79.80902863, 11.23486233], [79.80902863, 11.23513985], [79.80874634, 11.23513985], [79.80874634, 11.23542023], [79.80847168, 11.23541546], [79.80847168, 11.23569584], [79.80735779, 11.23569584], [79.80735779, 11.23597145], [79.80680847, 11.23597145], [79.80680847, 11.23625183], [79.80568695, 11.23625183], [79.80568695, 11.2365303], [79.80541992, 11.2365303], [79.80541992, 11.23680973], [79.80458069, 11.23680973], [79.80458069, 11.23625183], [79.80541992, 11.23625183], [79.80541992, 11.23597145], [79.80596924, 11.23597145], [79.80596924, 11.23569584], [79.80652618, 11.23569584], [79.80652618, 11.23541546], [79.80708313, 11.23542023], [79.80708313, 11.23513985], [79.80764008, 11.23513985], [79.80764008, 11.23486233], [79.80847168, 11.23486233], [79.80847168, 11.2345829], [79.80902863, 11.2345829], [79.80902863, 11.23430538], [79.80930328, 11.23431015], [79.80930328, 11.23402119], [79.80958557, 11.23402691], [79.80958557, 11.23374939], [79.80986023, 11.23374939], [79.80986023, 11.23347092], [79.81041718, 11.23347092], [79.81041718, 11.2331953], [79.81097412, 11.2331953], [79.81097412, 11.23291683], [79.81124878, 11.23291969], [79.81124878, 11.23263931], [79.81181335, 11.23263931], [79.81181335, 11.23236084], [79.81208038, 11.23236084], [79.81208038, 11.23208141], [79.81236267, 11.23208332], [79.81236267, 11.23180485], [79.81263733, 11.23180962], [79.81263733, 11.23152924], [79.81317902, 11.23152924], [79.81317902, 11.23125076], [79.81402588, 11.23125076], [79.81402588, 11.23069096], [79.81819153, 11.23069096], [79.81819153, 11.23097992], [79.81846619, 11.23097992], [79.81846619, 11.23125076], [79.81958008, 11.23125076], [79.81958008, 11.23152924], [79.82041931, 11.23152924], [79.82041931, 11.23180962], [79.82096863, 11.23180962], [79.82096863, 11.23152924], [79.82125092, 11.23152924], [79.82125092, 11.23180962], [79.82180786, 11.23180485], [79.82180786, 11.23208332], [79.82208252, 11.23208141], [79.82208252, 11.23236084], [79.82237244, 11.23236084], [79.82237244, 11.23263931], [79.82263947, 11.23263931], [79.82263947, 11.23291969], [79.82319641, 11.23291683], [79.82319641, 11.2331953], [79.82430267, 11.2331953], [79.82430267, 11.23347092], [79.82596588, 11.23347092], [79.82596588, 11.23374939], [79.82791901, 11.23374939], [79.82791901, 11.23347092], [79.82930756, 11.23347092], [79.82930756, 11.23374939], [79.829422, 11.23374939], [79.83013916, 11.23374939], [79.83013916, 11.23402691], [79.83097076, 11.23402119], [79.83097076, 11.23431015], [79.83403015, 11.23431015], [79.83403015, 11.23402119], [79.8354187, 11.23402691], [79.8354187, 11.2331953], [79.83513641, 11.2331953], [79.83513641, 11.23291683], [79.83486176, 11.23291969], [79.83486176, 11.23208141], [79.8345871, 11.23208332], [79.8345871, 11.23152924], [79.83431244, 11.23152924], [79.83431244, 11.23125076], [79.83403015, 11.23125076], [79.83403015, 11.23097992], [79.83374786, 11.23097992], [79.83374786, 11.23069096], [79.83347321, 11.23069477], [79.83347321, 11.23041725], [79.83319092, 11.23042202], [79.83319092, 11.23014069], [79.83291626, 11.23014069], [79.83291626, 11.22986126], [79.83319092, 11.22986126], [79.83319092, 11.22958279], [79.83403015, 11.22958279], [79.83403015, 11.22986126], [79.83431244, 11.22986126], [79.83431244, 11.23014069], [79.83460236, 11.23014069], [79.83460236, 11.23042202], [79.83486176, 11.23042202], [79.83486176, 11.23152924], [79.8354187, 11.23152924], [79.8354187, 11.23180962], [79.83597565, 11.23180485], [79.83597565, 11.23208332], [79.83763885, 11.23208332], [79.83763885, 11.23180485], [79.8381958, 11.23180485], [79.8381958, 11.23208332], [79.83958435, 11.23208332], [79.83958435, 11.23180485], [79.83985901, 11.23180962], [79.83985901, 11.23152924], [79.8401413, 11.23152924], [79.8401413, 11.23125076], [79.84040833, 11.23125076], [79.84040833, 11.23014069], [79.83985901, 11.23014069], [79.83985901, 11.22986126], [79.83930206, 11.22986126], [79.83930206, 11.22958279], [79.8390274, 11.22958279], [79.8390274, 11.22930527], [79.83930206, 11.22931194], [79.83930206, 11.22903061], [79.8401413, 11.22903061], [79.8401413, 11.22931194], [79.84041595, 11.22930527], [79.84041595, 11.22958279], [79.84069824, 11.22958279], [79.84069824, 11.22986126], [79.84152985, 11.22986126], [79.84152985, 11.23014069], [79.84208679, 11.23014069], [79.84208679, 11.23042202], [79.84263611, 11.23041725], [79.84263611, 11.23069477], [79.8429184, 11.23069096], [79.8429184, 11.23097992], [79.84319305, 11.23097992], [79.84319305, 11.23125076], [79.84375, 11.23125076], [79.84375, 11.23152924], [79.8445816, 11.23152924], [79.8445816, 11.23180962], [79.84486389, 11.23180485], [79.84486389, 11.23208332], [79.84570313, 11.23208141], [79.84570313, 11.23236084], [79.84597015, 11.23236084], [79.84597015, 11.23263931], [79.84570313, 11.23263931], [79.84570313, 11.23291969], [79.84513855, 11.23291683], [79.84513855, 11.2331953], [79.84541321, 11.23319054], [79.84541321, 11.23374939], [79.84570313, 11.23374939], [79.84570313, 11.23431015], [79.84597015, 11.23430538], [79.84597015, 11.2345829], [79.84625244, 11.23458099], [79.84625244, 11.23513985], [79.8465271, 11.23513985], [79.8465271, 11.23569584], [79.84680176, 11.23569584], [79.84680939, 11.23616982], [79.84680939, 11.2365303], [79.84707642, 11.2365303], [79.84707642, 11.23764038], [79.8473587, 11.23763657], [79.8473587, 11.23847198], [79.84707642, 11.23847198], [79.84707642, 11.23903179], [79.84680176, 11.23903179], [79.84680176, 11.23875046], [79.8465271, 11.23875046], [79.8465271, 11.23847198], [79.84625244, 11.23847198], [79.84625244, 11.2379179], [79.84597015, 11.23791981], [79.84597015, 11.23764038], [79.84570313, 11.23764038], [79.84570313, 11.23708057], [79.84430695, 11.23708439], [79.84430695, 11.23736191], [79.84375, 11.23736191], [79.84375, 11.23764038], [79.84430695, 11.23764038], [79.84430695, 11.23791981], [79.8445816, 11.2379179], [79.8445816, 11.23819447], [79.84486389, 11.23819447], [79.84486389, 11.23847198], [79.84513855, 11.23847198], [79.84513855, 11.23875046], [79.84541321, 11.23875046], [79.84541321, 11.23903179], [79.84570313, 11.23903179], [79.84570313, 11.23931026], [79.84597015, 11.23930645], [79.84597015, 11.23986244], [79.84625244, 11.23985958], [79.84625244, 11.24015141], [79.84654236, 11.24015141], [79.84654236, 11.24042034], [79.84625244, 11.24041557], [79.84625244, 11.24097157], [79.84597015, 11.24096966], [79.84597015, 11.24125004], [79.84625244, 11.24125004], [79.84625244, 11.2418108], [79.8465271, 11.24180603], [79.8465271, 11.24236202], [79.84680176, 11.24236202], [79.84680939, 11.24292088], [79.84764099, 11.24292088], [79.84764099, 11.24015141], [79.84792328, 11.24015141], [79.84792328, 11.23875046], [79.84819794, 11.23875046], [79.84819794, 11.23763657], [79.8484726, 11.23764038], [79.8484726, 11.2365303], [79.84874725, 11.2365303], [79.84874725, 11.23542023], [79.84902954, 11.23542023], [79.84902954, 11.23319054], [79.8493042, 11.2331953], [79.8493042, 11.23208332], [79.84902954, 11.23208332], [79.84902954, 11.23152733], [79.84928894, 11.23152924], [79.84928894, 11.22931194], [79.84960175, 11.22931194], [79.84960175, 11.22764111], [79.84986115, 11.22764111], [79.84986115, 11.22597122], [79.8501358, 11.22597313], [79.8501358, 11.2234726], [79.85041809, 11.2234726], [79.85041809, 11.2201376], [79.85069275, 11.22014141], [79.85069275, 11.21708202], [79.85097504, 11.21708202], [79.85097504, 11.21625042], [79.85124969, 11.21625042], [79.85124969, 11.21513844], [79.85151672, 11.21514034], [79.85151672, 11.21347046], [79.85180664, 11.21347237], [79.85180664, 11.21208382], [79.85152435, 11.21208382], [79.85152435, 11.2118063], [79.85124969, 11.21181011], [79.85124969, 11.21097183], [79.85152435, 11.21097183], [79.85152435, 11.21069431], [79.85180664, 11.21069431], [79.85180664, 11.20902824], [79.8520813, 11.20903015], [79.8520813, 11.20792198], [79.85234833, 11.20792198], [79.85234833, 11.20624924], [79.85263824, 11.20624924], [79.85263824, 11.20402718], [79.8529129, 11.20404053], [79.8529129, 11.20347118], [79.85319519, 11.20347309], [79.85319519, 11.2029171], [79.8529129, 11.20292187], [79.8529129, 11.20264053], [79.85263824, 11.20264053], [79.85263824, 11.20097065], [79.8529129, 11.20097256], [79.8529129, 11.19930458], [79.85320282, 11.19930935], [79.85320282, 11.19736099], [79.85346985, 11.19736099], [79.85346985, 11.19569492], [79.85375214, 11.19569492], [79.85375214, 11.19402885], [79.85402679, 11.19402885], [79.85402679, 11.19235992], [79.85430908, 11.19235992], [79.85430908, 11.19013786], [79.85457611, 11.19013977], [79.85457611, 11.18818855], [79.85430908, 11.18819427], [79.85430908, 11.18652821], [79.85402679, 11.18653011], [79.85402679, 11.18568039], [79.85375214, 11.18569374], [79.85375214, 11.18541622], [79.85402679, 11.18542004], [79.85402679, 11.18513966], [79.85457611, 11.18513966], [79.85457611, 11.18486023], [79.8548584, 11.18486214], [79.8548584, 11.18430614], [79.85542297, 11.18430996], [79.85542297, 11.18208122], [79.85569763, 11.18208408], [79.85569763, 11.17763901], [79.85597229, 11.17764187], [79.85597229, 11.17347145], [79.85624695, 11.17347336], [79.85624695, 11.16902637], [79.85652924, 11.16903114], [79.85652924, 11.16458035], [79.85680389, 11.16458225], [79.85680389, 11.16014004], [79.85708618, 11.16014004], [79.85708618, 11.1554203], [79.85736084, 11.1554203], [79.85736084, 11.15097141], [79.8576355, 11.15097332], [79.8576355, 11.14763927], [79.85791779, 11.14764118], [79.85791779, 11.14708138], [79.85819244, 11.14708328], [79.85819244, 11.14624882], [79.85791779, 11.14625072], [79.85791779, 11.14486122], [79.85819244, 11.14486122], [79.85819244, 11.14402866], [79.85791779, 11.14403057], [79.85791779, 11.1434679], [79.85819244, 11.14347267], [79.85819244, 11.14069366], [79.85848236, 11.14070129], [79.85848236, 11.13986015], [79.85902405, 11.13986015], [79.85902405, 11.12208271], [79.85874939, 11.12208271], [79.85874939, 11.1165266], [79.85848236, 11.11653137], [79.85848236, 11.09431171], [79.85819244, 11.09431171], [79.85819244, 11.089571], [79.85819244, 11.08930683], [79.85791779, 11.08931065], [79.85791779, 11.08568954], [79.8576355, 11.08569431], [79.8576355, 11.08236217], [79.85736084, 11.08236217], [79.85736084, 11.07680607], [79.85708618, 11.07681274], [79.85708618, 11.07625198], [79.85764313, 11.07625198], [79.85764313, 11.0759716], [79.85819244, 11.0759716], [79.85819244, 11.07569408], [79.85874939, 11.07569408], [79.85874939, 11.07541466], [79.85901642, 11.07542038], [79.85901642, 11.07319069], [79.85874939, 11.07319641], [79.85874939, 11.07291794], [79.85791779, 11.07291794], [79.85791779, 11.07319641], [79.85736084, 11.07319641], [79.85736084, 11.07347107], [79.85708618, 11.07347107], [79.85708618, 11.07124901], [79.85679626, 11.07125092], [79.85679626, 11.05542088], [79.85652924, 11.05542088], [79.85652924, 11.04819107], [79.85624695, 11.04819584], [79.85624695, 11.03736115], [79.85597229, 11.03736115], [79.85597229, 11.03097153], [79.85624695, 11.03097153], [79.85624695, 11.0298624], [79.85652924, 11.0298624], [79.85652924, 11.02958202], [79.85624695, 11.02958202], [79.85624695, 11.02875042], [79.85652924, 11.02875042], [79.85652924, 11.02680588], [79.85679626, 11.02681065], [79.85679626, 11.02597046], [79.8576355, 11.02597237], [79.8576355, 11.0251379], [79.85819244, 11.0251379], [79.85819244, 11.02458382], [79.85791779, 11.02458382], [79.85791779, 11.0243063], [79.85736084, 11.0243063], [79.85736084, 11.02458382], [79.85708618, 11.02458382], [79.85708618, 11.02375031], [79.8576355, 11.02375031], [79.8576355, 11.02347183], [79.85736084, 11.02347183], [79.85736084, 11.02319431], [79.85680389, 11.02319431], [79.85680389, 11.02347183], [79.85652924, 11.02347183], [79.85652924, 11.02013969], [79.85624695, 11.02013969], [79.85624695, 11.01625061], [79.85597229, 11.01625061], [79.85597229, 11.00986099], [79.85569763, 11.00986099], [79.85569763, 11.00430584], [79.85542297, 11.00431061], [79.85542297, 11.00152969], [79.85514069, 11.00152969], [79.85514069, 11.00068855], [79.8548584, 11.00069427], [79.8548584, 11.0004158], [79.85457611, 11.00042057], [79.85457611, 11.00014019], [79.85457611, 10.99985981], [79.85458374, 10.99791622], [79.8548584, 10.99792004], [79.8548584, 10.99514198], [79.85514069, 10.99514198], [79.85514069, 10.97764111], [79.8548584, 10.97764111], [79.8548584, 10.97604275], [79.85457611, 10.97602177], [79.85058594, 10.97579002], [79.84440613, 10.97597027], [79.83763885, 10.97643948], [79.83537292, 10.97662163], [79.83448029, 10.97671127], [79.8344574, 10.97681999], [79.82441711, 10.97949123], [79.82491302, 10.98479939], [79.82478333, 10.98662853], [79.81389618, 10.98714924], [79.81302643, 10.98485184], [79.81202698, 10.98295975], [79.80979919, 10.9820509], [79.80454254, 10.98287964], [79.80256653, 10.9848814], [79.80145264, 10.98621178], [79.79741669, 10.98490047], [79.79644775, 10.98306942], [79.79191589, 10.98092937], [79.79036713, 10.97853184], [79.78962708, 10.97338104], [79.78705597, 10.9698], [79.78341675, 10.96733189], [79.77723694, 10.96793079], [79.77392578, 10.97101116], [79.77435303, 10.97724247], [79.77227783, 10.97956181], [79.76521301, 10.97919941], [79.76051331, 10.98058128], [79.75260162, 10.97989178], [79.74823761, 10.98153114], [79.74305725, 10.98506069], [79.73721313, 10.98910046], [79.73190308, 10.98703957], [79.73017883, 10.98510933], [79.72986603, 10.9813509], [79.73163605, 10.97529125], [79.73015594, 10.97101116], [79.7381897, 10.96931934], [79.73951721, 10.9660902], [79.74381256, 10.96701145], [79.74131012, 10.96326065], [79.73914337, 10.96146107], [79.73813629, 10.95860958], [79.73992157, 10.95578098], [79.74456024, 10.95447063], [79.74572754, 10.94929028], [79.7455368, 10.9433403], [79.74009705, 10.94365025], [79.73265076, 10.94116116], [79.73169708, 10.94816017], [79.7266922, 10.95235062], [79.72093201, 10.95060062], [79.71546173, 10.95328999], [79.71150208, 10.95227146], [79.70365143, 10.95186138], [79.70391846, 10.94761086], [79.70287323, 10.94562054], [79.70323944, 10.9382906], [79.70435333, 10.93518925], [79.70934296, 10.93558121], [79.71481323, 10.93412971], [79.71555328, 10.9382906], [79.7191925, 10.94054127], [79.72122955, 10.93531036], [79.72022247, 10.93222046], [79.71585083, 10.93050957], [79.71299744, 10.9279213], [79.70847321, 10.92671108], [79.70767212, 10.92341137], [79.70848083, 10.9211607], [79.70437622, 10.92103958], [79.70423126, 10.91887093], [79.71042633, 10.91913986], [79.71034241, 10.9174099], [79.70803833, 10.91510105], [79.70863342, 10.91415501], [79.70922852, 10.91320038], [79.72083282, 10.91070175], [79.71958923, 10.90579128], [79.72119141, 10.9052], [79.72389984, 10.90802193], [79.72590637, 10.90690136], [79.72557068, 10.90358925], [79.72838593, 10.90229034], [79.72688293, 10.8974514], [79.74298096, 10.89936066], [79.74485016, 10.89674854], [79.74180603, 10.89444065], [79.74220276, 10.89054966], [79.7414093, 10.88329124], [79.74302673, 10.8819418], [79.74578094, 10.88724136], [79.74532318, 10.89307976], [79.74794769, 10.8952198], [79.74919891, 10.88941956], [79.75415802, 10.88665962], [79.75186157, 10.88085938], [79.75694275, 10.88010025], [79.76045227, 10.88315201], [79.76122284, 10.8914299], [79.77317047, 10.8895607], [79.77635956, 10.88167953], [79.77493286, 10.87890244], [79.77005768, 10.87798119], [79.76735687, 10.87555122], [79.76698303, 10.87276173], [79.7724762, 10.87325191], [79.77562714, 10.87578106], [79.78026581, 10.87131023], [79.78486633, 10.87355042], [79.78833008, 10.87292957], [79.79245758, 10.87000179], [79.80278778, 10.8711319], [79.80898285, 10.86744022], [79.81138611, 10.86443138], [79.80558014, 10.86365032], [79.79178619, 10.86394978], [79.78956604, 10.8617506], [79.79727173, 10.85809135], [79.80345917, 10.85748005], [79.80745697, 10.8526907], [79.80815887, 10.8488903], [79.80338287, 10.84731007], [79.79940796, 10.84468269], [79.79563141, 10.84381199], [79.7922821, 10.84883118], [79.79113007, 10.84570122], [79.7931366, 10.83949089], [79.79667664, 10.83589172], [79.80307007, 10.83368969], [79.80589294, 10.82804012], [79.80819702, 10.8313818], [79.81204224, 10.83282185], [79.81326294, 10.82874012], [79.81368256, 10.81837177], [79.81167603, 10.8157692], [79.81333923, 10.81408119], [79.81976318, 10.81110191], [79.8319931, 10.81137085], [79.83571625, 10.8117218], [79.84329224, 10.81225109], [79.85124969, 10.81377125], [79.85124969, 10.80097103], [79.85097504, 10.80097103], [79.85097504, 10.79930496], [79.85069275, 10.79930973], [79.85069275, 10.79736137], [79.85097504, 10.79736137], [79.85097504, 10.79597282], [79.85069275, 10.79597282], [79.85069275, 10.7956953], [79.85097504, 10.7956953], [79.85097504, 10.78402805], [79.85069275, 10.78402996], [79.85069275, 10.78347015], [79.85097504, 10.78347206], [79.85097504, 10.7798624], [79.85124969, 10.7798624], [79.85124969, 10.77597427], [79.85152435, 10.77597427], [79.85152435, 10.76930523], [79.85180664, 10.7693119], [79.85180664, 10.76486015], [79.85152435, 10.76486015], [79.85152435, 10.76319408], [79.85124969, 10.76319408], [79.85124969, 10.76291561], [79.85069275, 10.76292133], [79.85069275, 10.76068974], [79.85097504, 10.76069355], [79.85097504, 10.75541782], [79.85069275, 10.75541973], [79.85069275, 10.75458241], [79.85041809, 10.75458431], [79.85041809, 10.75347233], [79.85069275, 10.75347233], [79.85069275, 10.75291538], [79.85098267, 10.75292015], [79.85098267, 10.75013924], [79.85069275, 10.75013924], [79.85069275, 10.74958134], [79.85097504, 10.74958324], [79.85097504, 10.74902725], [79.85124969, 10.74903202], [79.85124969, 10.7462492], [79.85152435, 10.7462492], [79.85151672, 10.74514103], [79.85124969, 10.74514103], [79.85124969, 10.74403095], [79.85151672, 10.74403095], [79.85151672, 10.73958015], [79.85124969, 10.73958302], [79.85124969, 10.73930359], [79.85151672, 10.73931122], [79.85151672, 10.73791885], [79.85180664, 10.73791885], [79.85180664, 10.73596954], [79.85152435, 10.7359724], [79.85152435, 10.73569393], [79.85180664, 10.73569393], [79.85180664, 10.73513794], [79.8520813, 10.7351408], [79.8520813, 10.73042011], [79.85234833, 10.73042011], [79.85234833, 10.72596931], [79.85263824, 10.72597218], [79.85263824, 10.72347355], [79.85236359, 10.72347355], [79.85236359, 10.72291756], [79.85263824, 10.72292042], [79.85263824, 10.72153187], [79.8529129, 10.72153187], [79.8529129, 10.71263885], [79.85319519, 10.71263885], [79.85319519, 10.70180607], [79.8529129, 10.70181274], [79.8529129, 10.70069122], [79.85319519, 10.70069408], [79.85319519, 10.69986153], [79.85346985, 10.69986153], [79.85346985, 10.69375134], [79.85319519, 10.69375134], [79.85319519, 10.69347095], [79.85346985, 10.69347095], [79.85346985, 10.69236088], [79.85319519, 10.69236088], [79.85319519, 10.69097328], [79.8529129, 10.69097328], [79.8529129, 10.6898613], [79.85319519, 10.6898613], [79.85319519, 10.68930531], [79.85346985, 10.68930531], [79.85346985, 10.68902683], [79.85375214, 10.68903065], [79.85375214, 10.68764114], [79.85346985, 10.68764114], [79.85346985, 10.68708038], [79.85319519, 10.68708324], [79.85319519, 10.68625069], [79.85346985, 10.68626022], [79.85346985, 10.68542099], [79.85375214, 10.68542099], [79.85375214, 10.68514061], [79.85346985, 10.68514061], [79.85346985, 10.68431091], [79.85320282, 10.68431091], [79.85320282, 10.68375111], [79.85346985, 10.68375111], [79.85346985, 10.68208218], [79.85375214, 10.68208218], [79.85375214, 10.66819477], [79.85346985, 10.66819477], [79.85346985, 10.65513802], [79.85320282, 10.65514088], [79.85320282, 10.65375042], [79.85346985, 10.65375042], [79.85346985, 10.65319443], [79.85375214, 10.65319443], [79.85375214, 10.64764023], [79.85402679, 10.64764023], [79.85402679, 10.64208126], [79.85430908, 10.64208317], [79.85430908, 10.63652897], [79.85457611, 10.63653088], [79.85457611, 10.63097], [79.8548584, 10.63097286], [79.8548584, 10.6254158], [79.85514069, 10.62542057], [79.85514069, 10.6198597], [79.85541534, 10.6198597], [79.85541534, 10.61430454], [79.85569763, 10.61431026], [79.85569763, 10.60903072], [79.85597229, 10.60903072], [79.85597229, 10.60375118], [79.85624695, 10.60375118], [79.85624695, 10.60124969], [79.85597229, 10.60124969], [79.85597229, 10.60097027], [79.85541534, 10.60097218], [79.85541534, 10.60041618], [79.85569763, 10.60042095], [79.85569763, 10.59931087], [79.85597229, 10.59931087], [79.85597229, 10.59542274], [79.85569763, 10.59542274], [79.85569763, 10.59514046], [79.85597229, 10.59514046], [79.85597229, 10.59486198], [79.85624695, 10.59486198], [79.85624695, 10.5923624], [79.85597229, 10.5923624], [79.85597229, 10.59152794], [79.85624695, 10.59152985], [79.85624695, 10.59069061], [79.85652924, 10.59069347], [79.85652924, 10.58930492], [79.85624695, 10.58930969], [79.85624695, 10.58819103], [79.85652924, 10.5881958], [79.85652924, 10.58791733], [79.85624695, 10.58792019], [79.85624695, 10.58708096], [79.85652924, 10.58708286], [79.85652924, 10.58680534], [79.85679626, 10.58681202], [79.85679626, 10.58597088], [79.85652924, 10.58597088], [79.85652924, 10.58569527], [79.85680389, 10.58569527], [79.85680389, 10.58291721], [79.85708618, 10.58292198], [79.85708618, 10.58125114], [79.85679626, 10.58125114], [79.85679626, 10.57986069], [79.85708618, 10.57986069], [79.85708618, 10.57902908], [79.85736084, 10.57903099], [79.85736084, 10.57514095], [79.85764313, 10.57514095], [79.85764313, 10.57181072], [79.85791779, 10.57181072], [79.85791779, 10.56875038], [79.85819244, 10.56875038], [79.85819244, 10.56597233], [79.85847473, 10.56597233], [79.85847473, 10.56513977], [79.85819244, 10.56513977], [79.85819244, 10.56485939], [79.85847473, 10.56486225], [79.85847473, 10.56291771], [79.85874939, 10.56293106], [79.85874939, 10.55986977], [79.85901642, 10.55986977], [79.85901642, 10.55708122], [79.85930634, 10.55708313], [79.85930634, 10.5540266], [79.85958099, 10.55403137], [79.85958099, 10.55014133], [79.85986328, 10.55014133], [79.85986328, 10.54514027], [79.86013794, 10.54514027], [79.86013794, 10.54257202], [79.86013794, 10.54041576], [79.86042023, 10.54041958], [79.86042023, 10.53542042], [79.86068726, 10.53542042], [79.86068726, 10.52930927], [79.86096954, 10.52930927], [79.86096954, 10.52153111], [79.86125183, 10.52153111], [79.86125183, 10.51375198], [79.86154175, 10.51375198], [79.86154175, 10.50458145], [79.86125183, 10.50458336], [79.86125183, 10.50430489], [79.86154175, 10.50430965], [79.86154175, 10.50347137], [79.86208344, 10.50347328], [79.86208344, 10.50319481], [79.86264038, 10.50319481], [79.86264038, 10.50152683], [79.86235809, 10.50153065], [79.86235809, 10.50097084], [79.86207581, 10.50097084], [79.86207581, 10.50069046], [79.86152649, 10.50069523], [79.86152649, 10.50041676], [79.86180878, 10.50042057], [79.86180878, 10.4998579], [79.86208344, 10.49986076], [79.86208344, 10.49902916], [79.86180878, 10.49903107], [79.86180878, 10.49764061], [79.86207581, 10.49764061], [79.86207581, 10.49736118], [79.86235809, 10.49736118], [79.86235809, 10.4948597], [79.86264038, 10.4948597], [79.86264038, 10.49208355], [79.86291504, 10.49208355], [79.86291504, 10.48291779], [79.86264038, 10.48291969], [79.86264038, 10.48124886], [79.86291504, 10.48124886], [79.86291504, 10.48069572], [79.86319733, 10.48069572], [79.86319733, 10.47958279], [79.86291504, 10.47958279], [79.86291504, 10.47902679], [79.86319733, 10.4790287], [79.86319733, 10.47874928], [79.86347198, 10.47874928], [79.86347198, 10.47791672], [79.86374664, 10.47791958], [79.86374664, 10.4776392], [79.86319733, 10.4776392], [79.86319733, 10.47736073], [79.86291504, 10.47736073], [79.86291504, 10.47652912], [79.86319733, 10.47653198], [79.86319733, 10.47542191], [79.86292267, 10.47542191], [79.86292267, 10.47514057], [79.86347198, 10.47514057], [79.86347198, 10.4745779], [79.86319733, 10.47458267], [79.86319733, 10.47430515], [79.86292267, 10.47431183], [79.86292267, 10.47403145], [79.86319733, 10.47403145], [79.86319733, 10.46819019], [79.86347198, 10.46819401], [79.86347198, 10.46541595], [79.86319733, 10.46542072], [79.86319733, 10.46403027], [79.86347198, 10.46403027], [79.86347198, 10.46375179], [79.86374664, 10.46375179], [79.86374664, 10.45903015], [79.86402893, 10.45903015], [79.86402893, 10.45514202], [79.86374664, 10.45514202], [79.86374664, 10.45458126], [79.86402893, 10.45458317], [79.86402893, 10.45402718], [79.86428833, 10.45403194], [79.86428833, 10.45014095], [79.86457825, 10.45014095], [79.86457825, 10.44486141], [79.86486053, 10.44486141], [79.86486053, 10.44069386], [79.86458588, 10.44069386], [79.86458588, 10.44041634], [79.86486053, 10.4404211], [79.86486053, 10.43931103], [79.86514282, 10.43931103], [79.86514282, 10.43375015], [79.86541748, 10.43375015], [79.86541748, 10.42819309], [79.86569214, 10.42819309], [79.86569214, 10.42152691], [79.8659668, 10.42154121], [79.8659668, 10.41625118], [79.86624908, 10.41625118], [79.86624908, 10.41597271], [79.86653137, 10.41597271], [79.86653137, 10.41485977], [79.86680603, 10.41485977], [79.86680603, 10.4118042], [79.86708069, 10.41181087], [79.86708069, 10.40874958], [79.86680603, 10.40874958], [79.86680603, 10.40847015], [79.86708069, 10.40847206], [79.86708069, 10.40819359], [79.86736298, 10.40819359], [79.86736298, 10.40652847], [79.86763763, 10.40653038], [79.86763763, 10.40347195], [79.86791992, 10.40347195], [79.86791992, 10.40180588], [79.86763763, 10.40180969], [79.86763763, 10.40069103], [79.86791992, 10.4006958], [79.86791992, 10.40041542], [79.86818695, 10.40043068], [79.86818695, 10.39763927], [79.86846924, 10.39763927], [79.86846924, 10.39542198], [79.86818695, 10.39542198], [79.86818695, 10.39486122], [79.86846924, 10.39486122], [79.86846924, 10.39458275], [79.86875153, 10.39458275], [79.86875153, 10.3918047], [79.86902618, 10.39181232], [79.86902618, 10.38931084], [79.86930847, 10.38931084], [79.86930847, 10.38708019], [79.86958313, 10.3870821], [79.86958313, 10.38458443], [79.86985779, 10.38458443], [79.86985779, 10.38208199], [79.87014008, 10.38208199], [79.87014008, 10.37986183], [79.87041473, 10.37986183], [79.87041473, 10.37736225], [79.87069702, 10.37736225], [79.87069702, 10.37486172], [79.87097168, 10.37486172], [79.87097168, 10.3726387], [79.87124634, 10.37264156], [79.87124634, 10.37012959], [79.87152863, 10.37013912], [79.87152863, 10.36819458], [79.87180328, 10.36819458], [79.87180328, 10.3670826], [79.87208557, 10.3670826], [79.87208557, 10.365695], [79.87236023, 10.365695], [79.87236023, 10.36458302], [79.87264252, 10.36458302], [79.87264252, 10.36319542], [79.87291718, 10.36319542], [79.87291718, 10.36180687], [79.87319183, 10.36181068], [79.87319183, 10.36069202], [79.87347412, 10.36069393], [79.87347412, 10.35930634], [79.87374878, 10.3593111], [79.87374878, 10.35818958], [79.87403107, 10.35819435], [79.87403107, 10.3568058], [79.87431335, 10.35681057], [79.87431335, 10.35569191], [79.87458038, 10.35569382], [79.87458038, 10.35430622], [79.87486267, 10.35431099], [79.87486267, 10.35319233], [79.87513733, 10.35319424], [79.87513733, 10.35180569], [79.87541962, 10.35181046], [79.87541962, 10.35069084], [79.87569427, 10.3506937], [79.87569427, 10.34930611], [79.87596893, 10.34931946], [79.87596893, 10.34792042], [79.87625122, 10.34792042], [79.87625122, 10.34681034], [79.87651825, 10.34681034], [79.87651825, 10.34542179], [79.87680817, 10.34542179], [79.87680817, 10.34430981], [79.87651825, 10.34430981], [79.87651825, 10.34347057], [79.87680817, 10.34347343], [79.87680817, 10.34319305], [79.87708282, 10.34319305], [79.87708282, 10.34291744], [79.87735748, 10.34291935], [79.87735748, 10.34125137], [79.87763977, 10.34125137], [79.87763977, 10.34013939], [79.87791443, 10.34013939], [79.87791443, 10.3390274], [79.87819672, 10.33903122], [79.87819672, 10.33763885], [79.87847137, 10.33763885], [79.87847137, 10.33625126], [79.87875366, 10.33625126], [79.87874603, 10.33485985], [79.87902832, 10.33485985], [79.87902832, 10.33347225], [79.87930298, 10.33347225], [79.87930298, 10.33236027], [79.87958527, 10.33236027], [79.87958527, 10.33097172], [79.87985992, 10.33097172], [79.87985992, 10.32958412], [79.88014221, 10.32958412], [79.88014221, 10.32819366], [79.88041687, 10.32819366], [79.88041687, 10.32680607], [79.88069153, 10.32681274], [79.88069153, 10.32568932], [79.88097382, 10.32569408], [79.88097382, 10.32430553], [79.88124847, 10.3243103], [79.88124847, 10.32291985], [79.88153076, 10.32291985], [79.88153076, 10.32153034], [79.88181305, 10.32153034], [79.88181305, 10.32014179], [79.88208008, 10.32014179], [79.88208008, 10.31902027], [79.88236237, 10.31902695], [79.88236237, 10.31763935], [79.88265228, 10.31763935], [79.88265228, 10.31652927], [79.88291931, 10.31652927], [79.88291931, 10.31596184], [79.88319397, 10.31597328], [79.88319397, 10.31513882], [79.88346863, 10.31514072], [79.88346863, 10.31458092], [79.88375092, 10.31458282], [79.88375092, 10.31402683], [79.8840332, 10.31403065], [79.8840332, 10.30597019], [79.88375092, 10.3059721], [79.88375092, 10.30541611], [79.88346863, 10.30542088], [79.88346863, 10.30486012], [79.88318634, 10.30486012], [79.88318634, 10.3043108], [79.88291931, 10.3043108], [79.88291931, 10.30375004], [79.88265228, 10.30375004], [79.88265228, 10.30319023], [79.88236237, 10.30319405], [79.88236237, 10.30291557], [79.88291931, 10.3029213], [79.88291931, 10.30235958], [79.88263702, 10.30236244], [79.88263702, 10.30208206], [79.88236237, 10.30208206], [79.88236237, 10.30180645], [79.88208008, 10.30181122], [79.88208008, 10.30153275], [79.88181305, 10.30153275], [79.88181305, 10.30125046], [79.88153076, 10.30125046], [79.88153076, 10.30097198], [79.88124847, 10.30098057], [79.88124847, 10.30042267], [79.88096619, 10.30042267], [79.88096619, 10.29986191], [79.88069153, 10.29986191], [79.88069153, 10.29930592], [79.88041687, 10.29931068], [79.88041687, 10.29874992], [79.88014221, 10.29874992], [79.88014221, 10.29819107], [79.87985992, 10.29819584], [79.87985992, 10.29763985], [79.87957764, 10.29763985], [79.87957764, 10.29708195], [79.87930298, 10.29708385], [79.87930298, 10.29652786], [79.87902832, 10.29652977], [79.87902832, 10.29625034], [79.87874603, 10.29625034], [79.87874603, 10.29597187], [79.87847137, 10.29597187], [79.87847137, 10.29569435], [79.87819672, 10.29569435], [79.87819672, 10.29541779], [79.87763977, 10.29541969], [79.87763977, 10.29514027], [79.87735748, 10.29514027], [79.87735748, 10.29485035], [79.87708282, 10.29486179], [79.87708282, 10.29458427], [79.87680817, 10.29458427], [79.87680817, 10.2943058], [79.87651825, 10.29430962], [79.87651825, 10.29403019], [79.87596893, 10.29403019], [79.87596893, 10.29374886], [79.87569427, 10.29374886], [79.87569427, 10.29347134], [79.87541962, 10.29347134], [79.87541962, 10.29319572], [79.87513733, 10.29319572], [79.87513733, 10.29291534], [79.87486267, 10.29292202], [79.87486267, 10.29264164], [79.87458038, 10.29264164], [79.87458038, 10.29236126], [79.87403107, 10.29236126], [79.87403107, 10.29264164], [79.87374878, 10.29264164], [79.87374878, 10.29236126], [79.87347412, 10.29236126], [79.87347412, 10.29180527], [79.87319183, 10.29181004], [79.87319183, 10.29152966], [79.87291718, 10.29152966], [79.87291718, 10.29124928], [79.87264252, 10.29124928], [79.87264252, 10.29097271], [79.87236023, 10.2909708], [79.87236023, 10.29069328], [79.87208557, 10.29069328], [79.87208557, 10.29041672], [79.87180328, 10.29041958], [79.87180328, 10.2901392], [79.87124634, 10.2901392], [79.87124634, 10.28986073], [79.87097168, 10.28986073], [79.87097168, 10.28958321], [79.87069702, 10.28958321], [79.87069702, 10.28930473], [79.87042236, 10.28931046], [79.87042236, 10.28904057], [79.87014008, 10.28904057], [79.87014008, 10.28875065], [79.86930847, 10.28875065], [79.86930847, 10.28847122], [79.86902618, 10.28847313], [79.86902618, 10.28819466], [79.86875153, 10.28819466], [79.86875153, 10.28791714], [79.86846924, 10.28792191], [79.86846924, 10.28764057], [79.86818695, 10.28764057], [79.86818695, 10.28736115], [79.86791992, 10.28736115], [79.86791992, 10.28708267], [79.86763763, 10.28708267], [79.86763763, 10.28680515], [79.86736298, 10.28681183], [79.86736298, 10.28653145], [79.86708069, 10.28653145], [79.86708069, 10.28625107], [79.86624908, 10.28625107], [79.86624908, 10.28598022], [79.86541748, 10.28598022], [79.86541748, 10.28569031], [79.86513519, 10.28569508], [79.86513519, 10.2854166], [79.86486053, 10.28542137], [79.86486053, 10.28514099], [79.86457825, 10.28514099], [79.86457825, 10.28486061], [79.86402893, 10.28486061], [79.86402893, 10.28458309], [79.86264038, 10.28458309], [79.86264038, 10.28430462], [79.86207581, 10.28430939], [79.86207581, 10.28403091], [79.86180878, 10.28403091], [79.86180878, 10.28375053], [79.86068726, 10.28375053], [79.86068726, 10.28347111], [79.86013794, 10.28347301], [79.86013794, 10.28319454], [79.85930634, 10.28319454], [79.85930634, 10.28263855], [79.85901642, 10.28264141], [79.85901642, 10.28181076], [79.85764313, 10.28181076], [79.85764313, 10.28153133], [79.85679626, 10.28153133], [79.85679626, 10.28125095], [79.85624695, 10.28125095], [79.85624695, 10.28096962], [79.85541534, 10.28097343], [79.85541534, 10.28069496], [79.8548584, 10.28069496], [79.8548584, 10.28041553], [79.85346985, 10.28041553], [79.85346985, 10.28069496], [79.8529129, 10.28069496], [79.8529129, 10.27985954], [79.85263824, 10.27985954], [79.85263824, 10.27958202], [79.8520813, 10.27958202], [79.8520813, 10.27930737], [79.85098267, 10.27931118], [79.85098267, 10.2790308], [79.8501358, 10.2790308], [79.8501358, 10.27875042], [79.84928894, 10.27875042], [79.84928894, 10.27847004], [79.84764099, 10.27847195], [79.84764099, 10.27819443], [79.8465271, 10.27819443], [79.8465271, 10.27791595], [79.84541321, 10.27792072], [79.84541321, 10.27764034], [79.84401703, 10.27764034], [79.84401703, 10.27735996], [79.8429184, 10.27735996], [79.8429184, 10.27708435], [79.8418045, 10.27708435], [79.8418045, 10.27680588], [79.84040833, 10.27681065], [79.84040833, 10.27653122], [79.83930206, 10.27653122], [79.83930206, 10.27625179], [79.8381958, 10.27625179], [79.8381958, 10.27597046], [79.83680725, 10.27597237], [79.83680725, 10.27569389], [79.83569336, 10.27569389], [79.83569336, 10.27541637], [79.82430267, 10.27542114], [79.82430267, 10.27514267], [79.82347107, 10.27514267], [79.82347107, 10.27486038], [79.82290649, 10.27486038], [79.82290649, 10.27514267], [79.82013702, 10.27514267], [79.82013702, 10.27486038], [79.81680298, 10.27486229], [79.81680298, 10.27458382], [79.81375122, 10.27458191], [79.81375122, 10.2743063], [79.81043243, 10.27431107], [79.81043243, 10.27403927], [79.80708313, 10.27403927], [79.80708313, 10.27375031], [79.8034668, 10.27375031], [79.8034668, 10.27403927], [79.80236053, 10.27403927], [79.80236053, 10.27375031], [79.80014038, 10.27375031], [79.80014038, 10.27347183], [79.79819489, 10.27347183], [79.79819489, 10.27319431], [79.79597473, 10.27319431], [79.79597473, 10.27291584], [79.78708649, 10.27291584], [79.78708649, 10.27319431], [79.77319336, 10.27319431], [79.77319336, 10.27347183], [79.76699066, 10.27347183], [79.76568604, 10.27347183], [79.76569366, 10.27375031], [79.75846863, 10.27375031], [79.75846863, 10.27403927], [79.75485992, 10.27403927], [79.75485992, 10.27431107], [79.75125122, 10.2743063], [79.75125122, 10.27458191], [79.74791718, 10.27458382], [79.74791718, 10.27486229], [79.74430847, 10.27486038], [79.74430847, 10.27514267], [79.74291992, 10.2751379], [79.74291992, 10.27569389], [79.74263763, 10.27569199], [79.74263763, 10.27625179], [79.74236298, 10.27625179], [79.74236298, 10.27681065], [79.74208069, 10.27680588], [79.74208069, 10.27735996], [79.74180603, 10.27735996], [79.74180603, 10.27792072], [79.74153137, 10.27791595], [79.74153137, 10.27847195], [79.74291992, 10.27847195], [79.74291992, 10.27763844], [79.74318695, 10.27764034], [79.74318695, 10.27681065], [79.74624634, 10.27680588], [79.74624634, 10.27708435], [79.74597168, 10.27708435], [79.74597168, 10.27735996]]]]}}, {\\\"id\\\": \\\"29\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.32_1\\\", \\\"HASC_1\\\": \\\"IN.TG\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Telangana\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 73.6, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1621.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1135.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2755.0, \\\"geo-id\\\": 29, \\\"hpm25_child_popweighted\\\": 110.2, \\\"hpm25_female_popweighted\\\": 126.7, \\\"hpm25_male_popweighted\\\": 91.2, \\\"location\\\": \\\"Telangana\\\", \\\"mort_apm25_6cod_mean_total\\\": 19123.0, \\\"mort_hpm25_6cod_mean_total\\\": 13259.0, \\\"mort_tpm25_6cod_mean_total\\\": 32381.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[79.21147156, 16.36281013], [79.22323608, 16.35036087], [79.22785187, 16.33681107], [79.22982025, 16.30022049], [79.22505951, 16.25007057], [79.21868896, 16.23964119], [79.2075119, 16.23067093], [79.19198608, 16.22271919], [79.17658234, 16.21713066], [79.16272736, 16.2202282], [79.15117645, 16.22462082], [79.14248657, 16.22925949], [79.13317871, 16.23637962], [79.12300873, 16.23791122], [79.06859589, 16.23814011], [79.05407715, 16.24255943], [79.04252625, 16.24495125], [79.03093719, 16.2457428], [79.0201416, 16.24427032], [79.01017761, 16.24044991], [78.99243164, 16.22830009], [78.97805786, 16.22307014], [78.95900726, 16.21722031], [78.94108582, 16.20981026], [78.92549896, 16.20233917], [78.90808105, 16.19104004], [78.90545654, 16.18186951], [78.90558624, 16.16492081], [78.92086029, 16.13367081], [78.92186737, 16.12187195], [78.91726685, 16.11351967], [78.91335297, 16.10884094], [78.91047668, 16.1052227], [78.90117645, 16.09762192], [78.8890686, 16.09856033], [78.87267303, 16.11017036], [78.86942291, 16.12162971], [78.86802673, 16.13526154], [78.86633301, 16.14385986], [78.86293793, 16.15308952], [78.85645294, 16.15859985], [78.84628296, 16.15954018], [78.83783722, 16.15673828], [78.83213043, 16.15176964], [78.83049774, 16.14215088], [78.83127594, 16.13297844], [78.83394623, 16.12014008], [78.83808899, 16.11086082], [78.84028625, 16.10283089], [78.83937836, 16.09424019], [78.83650208, 16.08737755], [78.82155609, 16.06220055], [78.81376648, 16.05219078], [78.80799866, 16.04619026], [78.79001617, 16.03269958], [78.7750473, 16.02360916], [78.75393677, 16.02100945], [78.73898315, 16.02114105], [78.72596741, 16.02304077], [78.71366882, 16.02666092], [78.68656158, 16.04038048], [78.67498016, 16.0490303], [78.66837311, 16.05579948], [78.65776062, 16.07143974], [78.646698, 16.08273125], [78.63648987, 16.09144974], [78.61701202, 16.09890938], [78.60350037, 16.09643936], [78.59256744, 16.08723068], [78.57643127, 16.07034111], [78.56711578, 16.06187057], [78.55912781, 16.05637169], [78.54689789, 16.05620003], [78.5328598, 16.06232262], [78.52083588, 16.0650692], [78.49559784, 16.0730896], [78.45101166, 16.0810318], [78.42095184, 16.0828495], [78.40566254, 16.08094978], [78.38424683, 16.07183075], [78.37003326, 16.05984116], [78.35311127, 16.05451012], [78.34041595, 16.05277061], [78.33114624, 16.04709053], [78.32356262, 16.03724289], [78.31620789, 16.02915192], [78.29218292, 16.02849007], [78.28105927, 16.03209114], [78.26815796, 16.03475952], [78.25666809, 16.03129959], [78.25138092, 16.02568054], [78.25868225, 16.00508118], [78.25974274, 15.99473095], [78.25293732, 15.97844028], [78.25110626, 15.97083855], [78.24835968, 15.9683094], [78.2473526, 15.96004963], [78.24401093, 15.9469614], [78.24286652, 15.93704891], [78.23796844, 15.9290514], [78.22786713, 15.92348099], [78.20539856, 15.91706085], [78.19667053, 15.91224003], [78.18003082, 15.90044975], [78.17919159, 15.89494038], [78.18148804, 15.88765144], [78.17907715, 15.87977886], [78.17384338, 15.87252045], [78.17066193, 15.86643887], [78.16867065, 15.85317039], [78.16467285, 15.84899044], [78.15093231, 15.84904003], [78.14840698, 15.84996986], [78.13791656, 15.85024071], [78.1258316, 15.84893131], [78.12687683, 15.83492088], [78.11978912, 15.83026886], [78.10958099, 15.82718086], [78.10114288, 15.82792187], [78.0636673, 15.84456158], [78.05847168, 15.85041046], [78.04886627, 15.87075138], [78.04071808, 15.87220097], [78.03981781, 15.89810085], [78.03629303, 15.90209103], [78.02879333, 15.90269089], [78.02423859, 15.89858246], [78.01696777, 15.89514923], [78.01473236, 15.88881111], [78.00660706, 15.87197018], [78.0018692, 15.85923004], [77.99360657, 15.86098003], [77.9728775, 15.87411976], [77.96308136, 15.87590027], [77.94402313, 15.87491035], [77.92829895, 15.87650967], [77.90756226, 15.88489056], [77.88768005, 15.89592171], [77.87638092, 15.89600182], [77.86694336, 15.8923893], [77.85565186, 15.87576103], [77.85011292, 15.87382126], [77.83976746, 15.87394047], [77.83384705, 15.87551022], [77.8253479, 15.87379074], [77.81772614, 15.86949062], [77.80921936, 15.86702919], [77.79918671, 15.86532021], [77.78978729, 15.86658859], [77.77889252, 15.8693018], [77.77020264, 15.87327194], [77.76004791, 15.876791], [77.74964142, 15.87587929], [77.73883057, 15.87852097], [77.73195648, 15.88221073], [77.72486115, 15.88479137], [77.71611786, 15.88657093], [77.70730591, 15.88409996], [77.69944763, 15.88043976], [77.69249725, 15.87532139], [77.68353271, 15.87389183], [77.65894318, 15.87652016], [77.64821625, 15.87893963], [77.63960266, 15.88313103], [77.63204956, 15.89180088], [77.62570953, 15.89913082], [77.61882019, 15.90375137], [77.61384583, 15.90783024], [77.60637665, 15.91172981], [77.59868622, 15.90874195], [77.58841705, 15.90699196], [77.58010101, 15.91020966], [77.57163239, 15.91232014], [77.54884338, 15.91366863], [77.53173828, 15.91611958], [77.50945282, 15.92086029], [77.51457977, 15.94342995], [77.51589966, 15.95746136], [77.51487732, 15.96315193], [77.50901031, 15.96744061], [77.50551605, 15.97266865], [77.50549316, 15.97876167], [77.50839996, 15.99582958], [77.51010895, 16.00225067], [77.5016861, 16.00554085], [77.50028229, 16.01135063], [77.4985733, 16.01389122], [77.49881744, 16.01716042], [77.49207306, 16.02556992], [77.49072266, 16.03063011], [77.4956665, 16.04771042], [77.49447632, 16.04977989], [77.49621582, 16.05477905], [77.49952698, 16.05426025], [77.50293732, 16.07323265], [77.4930191, 16.0796299], [77.4928894, 16.08377075], [77.49788666, 16.09721947], [77.50347137, 16.10152054], [77.50939941, 16.10353088], [77.50271606, 16.10947037], [77.49543762, 16.11465073], [77.49022675, 16.11615944], [77.48667145, 16.1157608], [77.48858643, 16.12646103], [77.48809814, 16.14739037], [77.48680878, 16.15307808], [77.48362732, 16.15855026], [77.4883728, 16.17868042], [77.49491882, 16.18712044], [77.49494171, 16.19535065], [77.49369812, 16.20617104], [77.49532318, 16.21300125], [77.50232697, 16.21570015], [77.50878143, 16.21494293], [77.51116943, 16.21718979], [77.51075745, 16.22333908], [77.50222778, 16.22478104], [77.49362183, 16.22302055], [77.4887619, 16.22434998], [77.48890686, 16.24183083], [77.48755646, 16.24982071], [77.49897003, 16.25786018], [77.50020599, 16.26068115], [77.50122833, 16.26781082], [77.51309204, 16.27071953], [77.51933289, 16.27088165], [77.52442169, 16.26978111], [77.52581787, 16.26702118], [77.53378296, 16.26263046], [77.53975677, 16.28263283], [77.54321289, 16.28705978], [77.54950714, 16.29067039], [77.56498718, 16.29771042], [77.56925964, 16.29477119], [77.57434082, 16.28894043], [77.58068085, 16.28606033], [77.59030151, 16.28685188], [77.59227753, 16.29010963], [77.58835602, 16.29565048], [77.59099579, 16.30461121], [77.5908432, 16.31197929], [77.5866394, 16.32044983], [77.58438873, 16.32804108], [77.59160614, 16.33751106], [77.58644104, 16.33793068], [77.57184601, 16.33595085], [77.55452728, 16.34156036], [77.54949188, 16.34468079], [77.54432678, 16.34975815], [77.53515625, 16.35293961], [77.52863312, 16.35836029], [77.51885986, 16.37010956], [77.51014709, 16.37018013], [77.49449158, 16.37578964], [77.48137665, 16.37776947], [77.46131134, 16.3754406], [77.44896698, 16.37580109], [77.43811035, 16.3744297], [77.43519592, 16.37267113], [77.42778015, 16.36507988], [77.42220306, 16.36284256], [77.41174316, 16.36268044], [77.40112305, 16.36602974], [77.38813782, 16.37179947], [77.37319946, 16.37992096], [77.35253906, 16.3766098], [77.34294891, 16.37972069], [77.33273315, 16.38829994], [77.30696869, 16.39402008], [77.29457855, 16.39960289], [77.28466034, 16.40299988], [77.27820587, 16.41070938], [77.27475739, 16.41773987], [77.26925659, 16.42308044], [77.26438904, 16.4300518], [77.25820923, 16.44730949], [77.25245667, 16.45329094], [77.23517609, 16.46808052], [77.23886108, 16.47290993], [77.24452209, 16.47221947], [77.25151062, 16.46790123], [77.28536224, 16.47151184], [77.29199982, 16.47363853], [77.29580688, 16.48134041], [77.29688263, 16.48588943], [77.29664612, 16.49147034], [77.30909729, 16.48933983], [77.31362152, 16.48755074], [77.32440948, 16.48093033], [77.32995605, 16.48069191], [77.34365845, 16.48205948], [77.3436203, 16.48488045], [77.34790039, 16.4855175], [77.35163116, 16.48332024], [77.35816956, 16.48315048], [77.36628723, 16.48410988], [77.36717224, 16.48693085], [77.36730957, 16.4937706], [77.36908722, 16.50210953], [77.37290192, 16.50601959], [77.37908173, 16.51072121], [77.38115692, 16.51153946], [77.38871002, 16.51210976], [77.39351654, 16.51486015], [77.40061188, 16.51595116], [77.41197968, 16.51381111], [77.41532135, 16.5178299], [77.41565704, 16.54400063], [77.40157318, 16.54677963], [77.4004364, 16.55023003], [77.39705658, 16.55289268], [77.39653778, 16.55554008], [77.39480591, 16.55824089], [77.39261627, 16.55945015], [77.39029694, 16.5597496], [77.39144135, 16.56520081], [77.39753723, 16.56335068], [77.40213013, 16.56629181], [77.41728973, 16.56390953], [77.42095947, 16.56517029], [77.43672943, 16.58120918], [77.44326019, 16.58205986], [77.45639038, 16.58099937], [77.46038055, 16.58346939], [77.46417236, 16.58420944], [77.46418762, 16.58719063], [77.46134186, 16.59065819], [77.45877838, 16.59205055], [77.46034241, 16.59555054], [77.46420288, 16.59514046], [77.4646759, 16.59744072], [77.46363068, 16.60481071], [77.45388031, 16.60741997], [77.4538269, 16.61379814], [77.45556641, 16.62001038], [77.4613266, 16.62478065], [77.46247101, 16.62920952], [77.46586609, 16.63594055], [77.47133636, 16.6435318], [77.46939087, 16.64691162], [77.46141815, 16.64883041], [77.45478058, 16.64487076], [77.44851685, 16.63883018], [77.44406128, 16.63579178], [77.43836975, 16.63620186], [77.43293762, 16.63763809], [77.43622589, 16.64253044], [77.43247223, 16.64306068], [77.43026733, 16.64472961], [77.42809296, 16.65007973], [77.42119598, 16.65199089], [77.41684723, 16.65475082], [77.41657257, 16.66281128], [77.43715668, 16.6665802], [77.44642639, 16.67416], [77.46170044, 16.67235947], [77.46504211, 16.67828178], [77.46750641, 16.69680023], [77.46746063, 16.70237923], [77.46877289, 16.70870972], [77.46679688, 16.71194077], [77.46103668, 16.71316147], [77.45627594, 16.71068954], [77.44845581, 16.71357918], [77.44541168, 16.71380043], [77.4373703, 16.70754814], [77.43325806, 16.70911026], [77.43000793, 16.71170044], [77.4254303, 16.71175957], [77.42341614, 16.71453094], [77.4241333, 16.71780014], [77.42672729, 16.71837997], [77.42755127, 16.72113991], [77.42633057, 16.72274971], [77.42569733, 16.72706032], [77.42784119, 16.72948265], [77.43128967, 16.73644066], [77.43534088, 16.74954987], [77.43721008, 16.76313019], [77.43527985, 16.77762032], [77.43753815, 16.78321075], [77.44454193, 16.78004265], [77.46733856, 16.77659988], [77.471138, 16.77913094], [77.47162628, 16.78518105], [77.47175598, 16.79628944], [77.46575928, 16.80083084], [77.46272278, 16.80451965], [77.45941162, 16.81776237], [77.45662689, 16.82374954], [77.46039581, 16.84411049], [77.46031189, 16.85453033], [77.45759583, 16.87928009], [77.45223999, 16.88159943], [77.45426178, 16.88612938], [77.45581818, 16.90465927], [77.45391846, 16.90627289], [77.45339966, 16.90903282], [77.4601059, 16.91292953], [77.46537018, 16.91407967], [77.46774292, 16.91711044], [77.46787262, 16.92419815], [77.46459961, 16.92489815], [77.46354675, 16.92904091], [77.4659729, 16.93457031], [77.46430206, 16.93980026], [77.46465302, 16.94637108], [77.46407318, 16.95269012], [77.46917725, 16.95384026], [77.47374725, 16.95947075], [77.47918701, 16.96803284], [77.47998047, 16.97517014], [77.47837067, 16.99024963], [77.481987, 16.99719048], [77.48323059, 16.99867821], [77.49357605, 17.0058403], [77.49938965, 17.0073204], [77.49819946, 17.01519966], [77.49199677, 17.02165031], [77.49323273, 17.0329895], [77.49186707, 17.03884125], [77.486763, 17.04467964], [77.48306274, 17.05344009], [77.47805786, 17.06098938], [77.47543335, 17.06989098], [77.47783661, 17.07226944], [77.47692108, 17.07623291], [77.46842957, 17.08111191], [77.46386719, 17.08671188], [77.46031189, 17.09284019], [77.46263885, 17.10407066], [77.45237732, 17.1076107], [77.44841766, 17.11149979], [77.43862915, 17.11458015], [77.43376923, 17.11115074], [77.42352295, 17.11405754], [77.41178894, 17.12051964], [77.4037323, 17.12321091], [77.39890289, 17.13191986], [77.37632751, 17.13788986], [77.37541962, 17.14870071], [77.36686707, 17.15133095], [77.35999298, 17.16162109], [77.36490631, 17.16494942], [77.36354828, 17.16948128], [77.36837006, 17.17648125], [77.36753082, 17.18320084], [77.37075043, 17.19007111], [77.37671661, 17.19300079], [77.38173676, 17.1937294], [77.39148712, 17.19236946], [77.39344788, 17.2069397], [77.39881134, 17.20877838], [77.39901733, 17.21153069], [77.39318848, 17.21147919], [77.38458252, 17.2129612], [77.38128662, 17.21632195], [77.38035583, 17.21977043], [77.38401794, 17.22331047], [77.39225006, 17.22855949], [77.39585114, 17.23285103], [77.3988266, 17.23188972], [77.40545654, 17.23740959], [77.41493988, 17.22987938], [77.41776276, 17.23278999], [77.42002106, 17.24160957], [77.42047882, 17.24933052], [77.4225769, 17.25325012], [77.43736267, 17.26136971], [77.44248199, 17.26859093], [77.44967651, 17.26986122], [77.45450592, 17.27589035], [77.45279694, 17.28663063], [77.4469986, 17.2888298], [77.434021, 17.28825951], [77.43776703, 17.29668999], [77.44043732, 17.2978096], [77.44798279, 17.31345177], [77.44963837, 17.31489944], [77.45137024, 17.32723045], [77.45250702, 17.32793045], [77.45510101, 17.3379097], [77.45635223, 17.34498978], [77.45298004, 17.34880829], [77.44976807, 17.35004807], [77.44988251, 17.3630619], [77.45159912, 17.37049103], [77.47931671, 17.36961174], [77.4753418, 17.36815071], [77.47241211, 17.36317825], [77.47447205, 17.35917091], [77.48261261, 17.35445976], [77.49237823, 17.35551071], [77.49912262, 17.35407066], [77.509758, 17.3592701], [77.52081299, 17.36205101], [77.52802277, 17.37211037], [77.53018188, 17.3778801], [77.52658844, 17.37882996], [77.52133179, 17.38633156], [77.53357697, 17.39884949], [77.5355072, 17.40410042], [77.53357697, 17.40610123], [77.52671814, 17.4059906], [77.51068878, 17.41254044], [77.51014709, 17.42725945], [77.52337646, 17.43668938], [77.53347015, 17.44095039], [77.54884338, 17.43492126], [77.5577774, 17.43527031], [77.57256317, 17.42951965], [77.57195282, 17.43855095], [77.57319641, 17.45420074], [77.59041595, 17.44810295], [77.59590149, 17.44268036], [77.60447693, 17.44309044], [77.61061096, 17.44423294], [77.61144257, 17.45290947], [77.61010742, 17.46463966], [77.61094666, 17.46994019], [77.61564636, 17.47140121], [77.62657166, 17.47120094], [77.6340332, 17.47223091], [77.64042664, 17.47601128], [77.64259338, 17.48344994], [77.64422607, 17.49489975], [77.64794922, 17.49936295], [77.65276337, 17.50325012], [77.64897156, 17.49155235], [77.64808655, 17.48117828], [77.66488647, 17.47628975], [77.68401337, 17.4728508], [77.68467712, 17.48522949], [77.68696594, 17.49156952], [77.68799591, 17.49854279], [77.68562317, 17.50564957], [77.68325043, 17.50402069], [77.68202972, 17.50666809], [77.67893982, 17.50510025], [77.66606903, 17.50995064], [77.66120911, 17.51481056], [77.65661621, 17.52133942], [77.64987946, 17.52107048], [77.64531708, 17.5187912], [77.63315582, 17.52308083], [77.62121582, 17.52225113], [77.61657715, 17.52935028], [77.60797119, 17.53107262], [77.60325623, 17.53069115], [77.59925079, 17.5340004], [77.59172821, 17.53268051], [77.592453, 17.5490799], [77.59185791, 17.55505943], [77.58982849, 17.5627594], [77.5854187, 17.56204033], [77.58538818, 17.55836105], [77.56083679, 17.5535202], [77.55612946, 17.55215073], [77.55281067, 17.55000114], [77.54839325, 17.54945946], [77.54395294, 17.55459976], [77.53669739, 17.57132912], [77.5320816, 17.5730896], [77.52742004, 17.57322121], [77.51390076, 17.55724907], [77.50965881, 17.54916954], [77.50161743, 17.5408802], [77.49681854, 17.5433712], [77.49555206, 17.54652977], [77.49563599, 17.55002975], [77.48999786, 17.56627083], [77.47408295, 17.56511116], [77.47207642, 17.56913185], [77.46911621, 17.56818008], [77.46515656, 17.57465935], [77.46121979, 17.57703018], [77.43992615, 17.58147049], [77.44207001, 17.59581184], [77.44050598, 17.60409164], [77.44130707, 17.60663033], [77.44650269, 17.60724068], [77.44580078, 17.61230087], [77.44882202, 17.62278938], [77.45321655, 17.63076973], [77.45081329, 17.63236046], [77.44753265, 17.64711952], [77.44500732, 17.64842033], [77.44564819, 17.65746117], [77.44909668, 17.66611099], [77.4509964, 17.68086052], [77.45140839, 17.68774033], [77.4503479, 17.69129944], [77.45462036, 17.69409752], [77.45786285, 17.69896126], [77.47155762, 17.70401001], [77.47415161, 17.70139122], [77.47867584, 17.70302963], [77.48108673, 17.70685005], [77.48446655, 17.70364952], [77.48932648, 17.70680046], [77.49173737, 17.71286011], [77.49427795, 17.71603966], [77.50544739, 17.7145195], [77.50946808, 17.71996117], [77.52258301, 17.72402954], [77.52755737, 17.72711754], [77.53398895, 17.72520256], [77.53936005, 17.72542191], [77.54412079, 17.73339081], [77.55187988, 17.73438072], [77.55464172, 17.74113083], [77.56202698, 17.74711037], [77.56595612, 17.76411057], [77.55445099, 17.76125908], [77.53697205, 17.7704525], [77.53449249, 17.77469063], [77.52760315, 17.77666092], [77.52304077, 17.77962112], [77.50934601, 17.7800808], [77.50448608, 17.78259087], [77.50701904, 17.79295921], [77.51087952, 17.80144119], [77.51805115, 17.80772018], [77.52607727, 17.81168938], [77.52600098, 17.82681847], [77.54371643, 17.82626915], [77.54479218, 17.81701088], [77.54973602, 17.8180294], [77.55432129, 17.83049011], [77.55918884, 17.83864021], [77.56346893, 17.84200096], [77.56215668, 17.84913063], [77.56604004, 17.84955978], [77.56743622, 17.86614037], [77.57274628, 17.87281036], [77.57772827, 17.87122917], [77.58127594, 17.87574959], [77.59275818, 17.86977959], [77.59668732, 17.87045097], [77.59777832, 17.87706947], [77.59249115, 17.87949944], [77.58521271, 17.8925209], [77.58307648, 17.89838028], [77.58516693, 17.90822983], [77.59979248, 17.90367126], [77.60444641, 17.90549088], [77.61657715, 17.90286827], [77.61894989, 17.91348076], [77.6186676, 17.92180824], [77.61952972, 17.93007088], [77.6167984, 17.93810081], [77.62001038, 17.94445992], [77.62428284, 17.94369125], [77.62886047, 17.94851112], [77.62899017, 17.95384026], [77.62374115, 17.95775032], [77.6297226, 17.96297073], [77.63182068, 17.95353127], [77.63561249, 17.95051956], [77.64061737, 17.9496212], [77.64398956, 17.94637108], [77.64742279, 17.95318985], [77.6428299, 17.95729065], [77.64425659, 17.96269035], [77.6520462, 17.96430016], [77.65339661, 17.96935272], [77.64742279, 17.97043991], [77.64360809, 17.97344971], [77.64888763, 17.97841072], [77.64978027, 17.98586273], [77.64775085, 17.98732185], [77.6461792, 17.9932003], [77.64228821, 17.99590111], [77.63822174, 17.99654007], [77.63272858, 17.99514008], [77.62879944, 17.99251938], [77.62145233, 17.99834061], [77.62390137, 18.00115967], [77.62229156, 18.00465965], [77.61585236, 18.00608826], [77.61006165, 18.01048088], [77.60666656, 18.01801109], [77.5994873, 18.01573944], [77.59224701, 18.01016808], [77.58724976, 18.01333046], [77.58496857, 18.02478981], [77.57448578, 18.03074074], [77.55782318, 18.03520012], [77.55311584, 18.03466988], [77.55206299, 18.04693985], [77.54807281, 18.0479908], [77.54574585, 18.05376053], [77.54743195, 18.06363106], [77.55670929, 18.06217003], [77.56048584, 18.07113075], [77.56733704, 18.07629013], [77.57744598, 18.07686996], [77.58979797, 18.08028984], [77.59745789, 18.08428955], [77.60056305, 18.09939957], [77.59661102, 18.12103081], [77.59350586, 18.12786102], [77.59777069, 18.15184021], [77.5891571, 18.15345955], [77.57936096, 18.16212082], [77.57753754, 18.16827011], [77.57247162, 18.17894936], [77.57002258, 18.18915939], [77.5643158, 18.18997955], [77.56430817, 18.20055008], [77.5743866, 18.19992065], [77.58496094, 18.21674156], [77.58106995, 18.22273827], [77.57676697, 18.23310089], [77.57253265, 18.24056053], [77.58149719, 18.25632095], [77.59194183, 18.26177025], [77.59902954, 18.27291107], [77.60301971, 18.27799988], [77.59784698, 18.28121948], [77.58381653, 18.28308105], [77.57433319, 18.28684807], [77.57463837, 18.28931046], [77.57065582, 18.29047012], [77.56098175, 18.28310966], [77.54995728, 18.29134941], [77.55503082, 18.29831123], [77.57022858, 18.30817986], [77.56691742, 18.3179493], [77.55335999, 18.33122253], [77.54219055, 18.33390045], [77.52732849, 18.33940125], [77.51950073, 18.3492527], [77.52140045, 18.36465073], [77.53050232, 18.37577057], [77.54155731, 18.38521957], [77.54930115, 18.3877182], [77.5552063, 18.4178524], [77.54413605, 18.42041016], [77.53515625, 18.42118073], [77.53598022, 18.42345047], [77.52593994, 18.427351], [77.52848053, 18.44048119], [77.53450775, 18.44239998], [77.54644775, 18.44055939], [77.56017303, 18.43504906], [77.56693268, 18.43861008], [77.57411957, 18.4393425], [77.5826416, 18.44306946], [77.58521271, 18.44544983], [77.58328247, 18.44719124], [77.58364868, 18.45355034], [77.55908966, 18.45800018], [77.54979706, 18.45796967], [77.54888153, 18.46080971], [77.54619598, 18.46338272], [77.54651642, 18.46571922], [77.55809021, 18.465271], [77.56040192, 18.46749115], [77.57063293, 18.46685982], [77.57652283, 18.48377991], [77.59075928, 18.48110962], [77.59311676, 18.47351074], [77.60106659, 18.47421074], [77.60375214, 18.4852581], [77.60283661, 18.49138069], [77.59388733, 18.49386978], [77.58627319, 18.50292015], [77.58706665, 18.50984955], [77.59646606, 18.51499939], [77.60144806, 18.52194977], [77.60040283, 18.52497101], [77.59329224, 18.52314186], [77.59329224, 18.52802086], [77.59819031, 18.5350399], [77.59726715, 18.54754066], [77.61087036, 18.54776955], [77.61329651, 18.54239082], [77.61582184, 18.54294014], [77.61633301, 18.54866982], [77.62906647, 18.55064011], [77.63440704, 18.54518127], [77.64048004, 18.55393028], [77.64881134, 18.55261993], [77.64955139, 18.54966164], [77.65219879, 18.54963112], [77.64946747, 18.54133034], [77.64528656, 18.53630066], [77.65756989, 18.5272007], [77.66207886, 18.53325081], [77.67590332, 18.54133987], [77.68274689, 18.54080963], [77.71235657, 18.55443954], [77.72793579, 18.55154037], [77.73651123, 18.55480957], [77.73538208, 18.56318092], [77.74716187, 18.58908081], [77.74809265, 18.60531044], [77.74298859, 18.62140083], [77.73602295, 18.63089752], [77.72972107, 18.64273262], [77.72975922, 18.64558983], [77.73011017, 18.64812279], [77.73092651, 18.65532112], [77.73317719, 18.65570068], [77.73324585, 18.66212845], [77.72811127, 18.66420937], [77.73285675, 18.6760006], [77.74466705, 18.68388939], [77.74949646, 18.68978119], [77.74990845, 18.6978302], [77.75762939, 18.70709038], [77.76438141, 18.70793915], [77.76879883, 18.7016201], [77.76940155, 18.6905899], [77.78643799, 18.68412018], [77.78650665, 18.69432068], [77.80222321, 18.71611977], [77.80271912, 18.72924995], [77.81038666, 18.74024963], [77.82318115, 18.76850128], [77.8275528, 18.78601265], [77.83746338, 18.80746078], [77.85922241, 18.81406021], [77.90759277, 18.82951927], [77.92874908, 18.82172012], [77.94255066, 18.82229042], [77.94522858, 18.83210945], [77.94413757, 18.84229088], [77.92964935, 18.84649086], [77.93235779, 18.85093117], [77.92459869, 18.85414124], [77.92533875, 18.85921097], [77.90606689, 18.86731911], [77.89920044, 18.86792755], [77.89865875, 18.88373947], [77.88767242, 18.88512039], [77.88260651, 18.89637947], [77.88157654, 18.90853119], [77.8692627, 18.91032028], [77.85663605, 18.90607071], [77.84049988, 18.91130066], [77.84113312, 18.92146111], [77.84430695, 18.93032074], [77.84870148, 18.93138123], [77.85372925, 18.95227814], [77.83049774, 18.95020103], [77.82739258, 18.94572067], [77.81269073, 18.94945908], [77.81520081, 18.95923996], [77.81286621, 18.96006012], [77.81713867, 18.98237038], [77.78713226, 18.98428154], [77.7815094, 18.97632027], [77.76735687, 18.98142052], [77.76843262, 18.99938011], [77.76574707, 19.00737953], [77.76532745, 19.0153904], [77.76426697, 19.0196209], [77.76216125, 19.02050972], [77.76023865, 19.02264023], [77.75739288, 19.0285511], [77.76093292, 19.0512104], [77.75955963, 19.05930138], [77.76168823, 19.06204033], [77.77098846, 19.05615997], [77.77794647, 19.05437088], [77.78309631, 19.05483055], [77.7911377, 19.05065918], [77.79454041, 19.05019188], [77.79718018, 19.05130959], [77.79566956, 19.0610199], [77.79715729, 19.06488037], [77.79353333, 19.07121086], [77.79445648, 19.07336998], [77.79728699, 19.07459068], [77.80130768, 19.08440971], [77.79976654, 19.0945797], [77.80024719, 19.09887123], [77.80265045, 19.10196114], [77.80576324, 19.10334015], [77.81517029, 19.10366249], [77.82237244, 19.09639931], [77.8254776, 19.0916996], [77.82861328, 19.08494186], [77.8338089, 19.08653259], [77.84218597, 19.08677101], [77.84658813, 19.08851814], [77.8481369, 19.09008026], [77.84818268, 19.09259987], [77.84414673, 19.09607124], [77.84519196, 19.11421013], [77.83863831, 19.11885071], [77.83393097, 19.13273811], [77.83109283, 19.13565254], [77.837677, 19.13830948], [77.84924316, 19.15528107], [77.84874725, 19.15942955], [77.85016632, 19.16231155], [77.85035706, 19.16765022], [77.85385895, 19.16943169], [77.85423279, 19.1722908], [77.85301971, 19.17682076], [77.85839081, 19.18077278], [77.84453583, 19.18819046], [77.84654999, 19.19697952], [77.85267639, 19.20459175], [77.85233307, 19.20971107], [77.85845184, 19.21846962], [77.86152649, 19.22629166], [77.86228943, 19.23396111], [77.86540222, 19.2379303], [77.86808014, 19.24611092], [77.86738586, 19.25526047], [77.8846283, 19.26023102], [77.89187622, 19.25709915], [77.90039062, 19.25612068], [77.90570831, 19.26721954], [77.90067291, 19.27712822], [77.89305878, 19.27839279], [77.8753891, 19.27977943], [77.86192322, 19.28409958], [77.86084747, 19.28763962], [77.86264038, 19.2953701], [77.86087799, 19.30212975], [77.87111664, 19.30573082], [77.87522888, 19.30890083], [77.88804626, 19.31241035], [77.89325714, 19.32116127], [77.8995285, 19.31779099], [77.90577698, 19.31578064], [77.91227722, 19.3179512], [77.92204285, 19.32591248], [77.92632294, 19.33190918], [77.93723297, 19.33575058], [77.94062805, 19.34250069], [77.9489212, 19.34127998], [77.96270752, 19.33176994], [77.96665192, 19.3273201], [77.97690582, 19.32105064], [77.98549652, 19.30899048], [77.99588776, 19.30571747], [78.01161194, 19.30111122], [78.01824951, 19.29632759], [78.02728271, 19.2786808], [78.03288269, 19.27411079], [78.04574585, 19.27086067], [78.04944611, 19.26272964], [78.04762268, 19.25563049], [78.04804993, 19.24751282], [78.0511322, 19.24176025], [78.05755615, 19.23974991], [78.07514191, 19.24654961], [78.0822525, 19.25477028], [78.09512329, 19.24985123], [78.09938812, 19.24547958], [78.12670898, 19.24640274], [78.13926697, 19.23944092], [78.14974213, 19.23005104], [78.1700592, 19.23633003], [78.18331909, 19.24154091], [78.186409, 19.24934959], [78.18325806, 19.26116943], [78.18315125, 19.27896118], [78.19317627, 19.30294037], [78.19551086, 19.31438065], [78.19506073, 19.32496071], [78.19715118, 19.33172989], [78.18711853, 19.3386097], [78.18225098, 19.34544754], [78.17959595, 19.35301018], [78.18136597, 19.3607502], [78.18445587, 19.36821938], [78.18482208, 19.37629128], [78.18698883, 19.38454819], [78.18756866, 19.39562035], [78.18216705, 19.41176987], [78.19811249, 19.40744972], [78.20548248, 19.41435051], [78.21508026, 19.42705154], [78.22426605, 19.43403244], [78.23361969, 19.43288994], [78.24581146, 19.42898941], [78.2519989, 19.4300499], [78.26183319, 19.44009972], [78.26692963, 19.44792938], [78.27321625, 19.45384026], [78.28199005, 19.45298958], [78.29115295, 19.44879913], [78.29733276, 19.44882965], [78.3088913, 19.45640945], [78.31195831, 19.46590042], [78.31204987, 19.47925949], [78.31001282, 19.48643112], [78.30361176, 19.49376106], [78.29943085, 19.50412941], [78.29870605, 19.51356125], [78.29548645, 19.53083992], [78.29502869, 19.53728104], [78.2914505, 19.5431118], [78.28460693, 19.55039024], [78.27910614, 19.55820084], [78.28534698, 19.56034088], [78.29650879, 19.55838013], [78.29928589, 19.56129265], [78.2999115, 19.56678009], [78.30612183, 19.56744194], [78.3111496, 19.57176971], [78.31204224, 19.57856178], [78.31004333, 19.58671188], [78.31098938, 19.60417938], [78.3088913, 19.6114006], [78.29897308, 19.62341118], [78.29550171, 19.63183022], [78.29242706, 19.64416122], [78.28755951, 19.65446091], [78.2726593, 19.6601696], [78.26972198, 19.66312981], [78.27339172, 19.67015076], [78.28581238, 19.68967056], [78.3049469, 19.68843079], [78.31606293, 19.69055176], [78.32010651, 19.69671059], [78.32269287, 19.70364952], [78.33251953, 19.70850945], [78.34527588, 19.71356964], [78.34429932, 19.72433281], [78.34541321, 19.73442268], [78.35320282, 19.73775101], [78.3608017, 19.75398064], [78.36479187, 19.76733971], [78.36773682, 19.78108025], [78.36699677, 19.79454041], [78.36048889, 19.80574036], [78.35161591, 19.81035042], [78.33921051, 19.81351089], [78.33598328, 19.81866074], [78.34136963, 19.83294106], [78.33899689, 19.83917999], [78.30316925, 19.84583092], [78.29412842, 19.84955025], [78.29421234, 19.85555077], [78.29769135, 19.87329292], [78.30761719, 19.90849113], [78.31019592, 19.91274071], [78.31951141, 19.91546822], [78.32837677, 19.9160881], [78.3351059, 19.91011047], [78.3345871, 19.9043026], [78.32660675, 19.89937973], [78.32296753, 19.89497185], [78.32524109, 19.89048195], [78.33625031, 19.88319016], [78.34668732, 19.88140106], [78.36575317, 19.8828907], [78.37446594, 19.87927055], [78.38414764, 19.87922287], [78.38497162, 19.87389183], [78.38417816, 19.86362076], [78.38597107, 19.85569954], [78.38593292, 19.85270119], [78.38923645, 19.84617805], [78.3976593, 19.83640289], [78.40904236, 19.82986069], [78.42867279, 19.82311058], [78.44458771, 19.81923103], [78.46465302, 19.8162117], [78.47618866, 19.81636047], [78.48429108, 19.80718994], [78.48947144, 19.7985096], [78.49391937, 19.79314995], [78.50366974, 19.79241943], [78.50961304, 19.80118942], [78.51239014, 19.81427956], [78.51921082, 19.81990051], [78.52626801, 19.82165909], [78.55792236, 19.81561089], [78.57370758, 19.81380272], [78.58499146, 19.81168938], [78.5917511, 19.81541061], [78.59527588, 19.81735039], [78.60365295, 19.81750107], [78.61434174, 19.81326103], [78.61933899, 19.8087101], [78.63520813, 19.8037796], [78.64833832, 19.80146027], [78.68637085, 19.78993988], [78.69590759, 19.789711], [78.70178986, 19.78557968], [78.70918274, 19.7727108], [78.71644592, 19.76679993], [78.72473145, 19.76897049], [78.73184204, 19.77285004], [78.73834991, 19.77943039], [78.74308777, 19.77965927], [78.75224304, 19.77729034], [78.76322937, 19.77563095], [78.77321625, 19.77937126], [78.78486633, 19.77874947], [78.79695129, 19.76857948], [78.80317688, 19.7600708], [78.80760956, 19.75798988], [78.8171463, 19.76041985], [78.82528687, 19.76037979], [78.83830261, 19.76208115], [78.84433746, 19.75900078], [78.84562683, 19.75835037], [78.85357666, 19.73800087], [78.85691833, 19.73130035], [78.8573761, 19.71973991], [78.86167145, 19.70590019], [78.86347961, 19.69676971], [78.86398315, 19.68670082], [78.86321259, 19.67949295], [78.85912323, 19.66890907], [78.8588028, 19.65631104], [78.87793732, 19.65680122], [78.89097595, 19.65526009], [78.90379333, 19.66455841], [78.91590881, 19.66773033], [78.93498993, 19.66217995], [78.94359589, 19.66514015], [78.95419312, 19.66341019], [78.96167755, 19.65876961], [78.96895599, 19.64923286], [78.96800232, 19.63936996], [78.9646759, 19.62955284], [78.96286011, 19.61732292], [78.96562195, 19.60451126], [78.97132874, 19.59725952], [78.978302, 19.59041023], [78.98052979, 19.5850811], [78.97785187, 19.5799427], [78.96898651, 19.57345963], [78.96470642, 19.57028008], [78.95446014, 19.56272125], [78.94956207, 19.55747032], [78.9545517, 19.55183029], [78.96485138, 19.55033112], [78.97355652, 19.54990005], [78.97847748, 19.55092239], [78.98635101, 19.5570507], [78.99285889, 19.56204033], [78.99556732, 19.5610199], [79.00006104, 19.55937004], [79.01219177, 19.5437603], [79.01835632, 19.5399704], [79.03881836, 19.54499054], [79.0515213, 19.54527283], [79.060112, 19.53872108], [79.06339264, 19.53125], [79.07383728, 19.52861023], [79.09661102, 19.53047943], [79.10286713, 19.52795029], [79.10235596, 19.51935959], [79.10473633, 19.51274109], [79.11281586, 19.50978088], [79.12644958, 19.50649071], [79.14026642, 19.50111008], [79.15696716, 19.48554993], [79.1690979, 19.46776962], [79.17778778, 19.46069145], [79.18904114, 19.45870018], [79.21871185, 19.46450043], [79.22293854, 19.4677906], [79.22068787, 19.47558975], [79.20877838, 19.48479843], [79.20684814, 19.49167061], [79.20807648, 19.4986496], [79.21570587, 19.51058006], [79.22342682, 19.51700974], [79.23200226, 19.52075005], [79.2366333, 19.52679825], [79.23835754, 19.53276062], [79.23934174, 19.54204941], [79.23816681, 19.55093193], [79.23976898, 19.55948067], [79.25010681, 19.57768059], [79.24868011, 19.58686066], [79.24378204, 19.59334183], [79.23770142, 19.59954071], [79.23709106, 19.60948944], [79.24386597, 19.61255264], [79.25522614, 19.61120987], [79.26786041, 19.60666084], [79.29323578, 19.59672165], [79.30484009, 19.59015083], [79.30961609, 19.58201027], [79.31426239, 19.56552124], [79.32150269, 19.57175064], [79.3296814, 19.57368088], [79.34088898, 19.57377052], [79.36902618, 19.57123184], [79.37119293, 19.56154823], [79.38070679, 19.55585098], [79.38896942, 19.54891968], [79.40184784, 19.53983116], [79.41361237, 19.53347969], [79.42318726, 19.53284073], [79.43028259, 19.53510094], [79.44126129, 19.53351021], [79.45818329, 19.51896095], [79.46512604, 19.50901031], [79.47042084, 19.49745178], [79.48004913, 19.50381279], [79.49331665, 19.5051918], [79.51339722, 19.51806068], [79.51584625, 19.52235985], [79.51595306, 19.53680992], [79.51481628, 19.54076195], [79.51499176, 19.54195023], [79.52622223, 19.54606056], [79.53499603, 19.54807091], [79.54265594, 19.54852295], [79.5447464, 19.54271126], [79.54519653, 19.5340004], [79.54769897, 19.52608109], [79.55249786, 19.52004242], [79.56559753, 19.5109005], [79.57344055, 19.50663948], [79.58265686, 19.50305176], [79.59134674, 19.50173187], [79.59805298, 19.50377083], [79.60085297, 19.50795174], [79.60243988, 19.51452065], [79.60293579, 19.52106857], [79.60721588, 19.53946114], [79.61090851, 19.54917908], [79.61580658, 19.55862999], [79.6213913, 19.56509972], [79.6397171, 19.57500076], [79.65261841, 19.57669258], [79.66504669, 19.57716942], [79.67801666, 19.57656288], [79.68479156, 19.57916832], [79.69568634, 19.58109093], [79.70511627, 19.58122063], [79.71292877, 19.58333015], [79.7299118, 19.59656906], [79.74032593, 19.60313988], [79.7542572, 19.60233116], [79.76628876, 19.60015106], [79.77754974, 19.59767914], [79.78542328, 19.59358978], [79.78629303, 19.58965111], [79.79329681, 19.58008957], [79.8052063, 19.57675934], [79.81109619, 19.57384109], [79.81659698, 19.56900978], [79.81954956, 19.56148911], [79.82063293, 19.552351], [79.82315826, 19.54430962], [79.82821655, 19.53701019], [79.85623169, 19.51711082], [79.86379242, 19.51359749], [79.87021637, 19.50496101], [79.87822723, 19.5007019], [79.90223694, 19.49649048], [79.911026, 19.49234009], [79.91779327, 19.48554039], [79.92354584, 19.47758102], [79.93286896, 19.46912193], [79.93725586, 19.46696091], [79.94020844, 19.46450996], [79.94499969, 19.45881844], [79.94621277, 19.45093918], [79.94577026, 19.44078064], [79.95923615, 19.42591095], [79.97000122, 19.40946007], [79.97305298, 19.40102005], [79.97260284, 19.39158058], [79.9707489, 19.38212967], [79.96724701, 19.37458038], [79.96652222, 19.36088943], [79.96452332, 19.3506794], [79.95715332, 19.33456993], [79.9573822, 19.32447052], [79.96364594, 19.30653954], [79.96177673, 19.29749107], [79.94895935, 19.28886032], [79.9451828, 19.28412056], [79.93190002, 19.25932121], [79.92016602, 19.22640991], [79.91932678, 19.21501923], [79.92250824, 19.20340919], [79.93525696, 19.18385124], [79.94243622, 19.17588043], [79.94320679, 19.17060089], [79.94069672, 19.1644001], [79.92611694, 19.16094971], [79.92230988, 19.15712929], [79.90596771, 19.14178848], [79.87120819, 19.12269974], [79.86310577, 19.11582184], [79.85804749, 19.10411072], [79.8600769, 19.09095955], [79.86109924, 19.05994987], [79.85700989, 19.04220009], [79.85958862, 19.03462982], [79.87103271, 19.03554153], [79.88111115, 19.04138947], [79.89084625, 19.04545021], [79.90293884, 19.04797935], [79.91610718, 19.04735947], [79.92597961, 19.04249001], [79.93306732, 19.02968979], [79.93448639, 19.02169991], [79.93279266, 18.99570084], [79.93134308, 18.97479057], [79.93221283, 18.97158051], [79.93588257, 18.95763969], [79.94094086, 18.93766022], [79.94135284, 18.91576958], [79.94011688, 18.89673805], [79.94094849, 18.87738991], [79.93900299, 18.85889244], [79.93332672, 18.84504128], [79.92550659, 18.83754158], [79.92082214, 18.83621025], [79.90409851, 18.83488083], [79.89401245, 18.83083916], [79.90909576, 18.80669022], [79.9162674, 18.79734039], [79.93199158, 18.78442955], [79.94007111, 18.78179169], [79.95014954, 18.77990913], [79.98153687, 18.77428055], [79.99291992, 18.77351952], [80.00908661, 18.76857948], [80.01235199, 18.76675987], [80.01448822, 18.76012993], [80.0165329, 18.75702095], [80.01870728, 18.75101089], [80.02966309, 18.74869919], [80.0328598, 18.74644089], [80.0463562, 18.72092056], [80.05326843, 18.71779823], [80.06189728, 18.71651268], [80.06549072, 18.71326256], [80.06790924, 18.70870972], [80.07470703, 18.70256042], [80.0789032, 18.70133972], [80.0821228, 18.7024498], [80.08444214, 18.70084], [80.08695221, 18.6975708], [80.10054779, 18.68495941], [80.10655975, 18.67752838], [80.11081696, 18.67618942], [80.11599731, 18.67584991], [80.11841583, 18.67913246], [80.12129211, 18.68120956], [80.130867, 18.68541145], [80.13658905, 18.68680191], [80.14227295, 18.68625259], [80.14874268, 18.69324112], [80.15220642, 18.69527817], [80.15808105, 18.69594002], [80.1619873, 18.69403076], [80.16462708, 18.69029808], [80.16739655, 18.68007088], [80.1709671, 18.67733955], [80.17565155, 18.67589951], [80.18895721, 18.67558098], [80.19095612, 18.67897034], [80.19165802, 18.6836319], [80.19410706, 18.68853188], [80.20191193, 18.6974411], [80.20787811, 18.70046043], [80.2143631, 18.70112991], [80.22000885, 18.69919014], [80.22531891, 18.69614983], [80.22998047, 18.69753075], [80.23557281, 18.70042038], [80.24169159, 18.70022011], [80.24666595, 18.70132065], [80.26036835, 18.71409988], [80.26753998, 18.71796989], [80.27091217, 18.71350098], [80.27790833, 18.71096039], [80.28884125, 18.69500923], [80.29631042, 18.68564034], [80.29946136, 18.67921066], [80.30780792, 18.65228081], [80.31500244, 18.63628769], [80.31931305, 18.62173271], [80.33146667, 18.59659958], [80.33667755, 18.59052086], [80.33879089, 18.58820915], [80.34184265, 18.58644104], [80.348526, 18.58848953], [80.35289764, 18.59094048], [80.35594177, 18.59370995], [80.35749054, 18.59834099], [80.35972595, 18.60218048], [80.36251831, 18.60374069], [80.36695099, 18.6046505], [80.37052917, 18.60305977], [80.38156128, 18.59359932], [80.38558197, 18.59649086], [80.38939667, 18.59925842], [80.39325714, 18.60296059], [80.40209198, 18.60717964], [80.40703583, 18.60774994], [80.41599274, 18.60878754], [80.41755676, 18.61071968], [80.45020294, 18.6263504], [80.45524597, 18.62490273], [80.4630127, 18.6226902], [80.46774292, 18.62280083], [80.47218323, 18.62368965], [80.48005676, 18.62763977], [80.48204803, 18.62791824], [80.4834671, 18.62812042], [80.48838806, 18.62672043], [80.49812317, 18.61765289], [80.51071167, 18.61567116], [80.51383209, 18.6131382], [80.51525116, 18.6072998], [80.518013, 18.60345078], [80.52179718, 18.60075951], [80.52857208, 18.59370041], [80.52871704, 18.59284973], [80.52931976, 18.58980942], [80.53003693, 18.58879089], [80.53199768, 18.58605957], [80.54043579, 18.58295059], [80.55779266, 18.57275963], [80.56195068, 18.5695591], [80.56794739, 18.56145096], [80.58146667, 18.55745125], [80.5955658, 18.5490799], [80.60098267, 18.54503059], [80.60402679, 18.54071999], [80.61081696, 18.53353119], [80.61384583, 18.52605057], [80.62132263, 18.52312851], [80.62697601, 18.51816177], [80.6326828, 18.51884079], [80.63347626, 18.51761246], [80.63497925, 18.51531029], [80.63564301, 18.51158905], [80.63640594, 18.50723076], [80.63533783, 18.50572968], [80.63350677, 18.50315094], [80.63395691, 18.50125122], [80.63459015, 18.49863052], [80.63681793, 18.49394989], [80.64485168, 18.48351097], [80.64826202, 18.4790802], [80.65077972, 18.4722805], [80.66236115, 18.4657402], [80.66610718, 18.46264076], [80.66982269, 18.46121025], [80.67153168, 18.45973969], [80.67318726, 18.45831108], [80.67414856, 18.45631981], [80.6805191, 18.45355034], [80.68245697, 18.45001984], [80.68280029, 18.44716072], [80.68309021, 18.44462013], [80.69191742, 18.44045067], [80.69496918, 18.4407711], [80.69889069, 18.43600082], [80.69525909, 18.43457031], [80.69262695, 18.42885017], [80.69100952, 18.41934967], [80.71302795, 18.4057312], [80.71734619, 18.40908051], [80.71827698, 18.40979958], [80.72248077, 18.41032028], [80.72653961, 18.40899086], [80.72878265, 18.40380096], [80.72712708, 18.39999962], [80.72400665, 18.39524841], [80.71572876, 18.38729095], [80.71594238, 18.38552284], [80.71626282, 18.38294029], [80.71862793, 18.37924194], [80.7227478, 18.37580109], [80.72424316, 18.37198257], [80.72306824, 18.36790085], [80.72289276, 18.3642292], [80.72276306, 18.36131096], [80.72405243, 18.35737038], [80.72638702, 18.35025024], [80.73478699, 18.33868027], [80.74292755, 18.32216072], [80.74443817, 18.3168602], [80.7452774, 18.30508995], [80.74462128, 18.30218124], [80.75132751, 18.29747009], [80.7529068, 18.29127121], [80.75702667, 18.28470993], [80.75949097, 18.28256989], [80.76156616, 18.28210258], [80.76322174, 18.28172112], [80.76638031, 18.27823257], [80.77340698, 18.26493073], [80.77739716, 18.25974083], [80.78161621, 18.25958252], [80.78489685, 18.25809097], [80.78663635, 18.25591087], [80.78811646, 18.25403976], [80.78827667, 18.24978065], [80.78726959, 18.24656105], [80.7842865, 18.24327087], [80.76937866, 18.2364006], [80.75688934, 18.22949982], [80.73326874, 18.21879005], [80.73226166, 18.20545006], [80.73253632, 18.19419098], [80.73455811, 18.17171288], [80.74507141, 18.16483116], [80.75385284, 18.16389084], [80.76239777, 18.16296959], [80.78691864, 18.16418076], [80.79364014, 18.16546059], [80.79792786, 18.16629982], [80.81085205, 18.17847252], [80.81067657, 18.18325996], [80.81791687, 18.18712044], [80.81874847, 18.19202042], [80.81772614, 18.21276093], [80.81835175, 18.21903038], [80.81719208, 18.22521019], [80.81891632, 18.23098183], [80.82419586, 18.23357964], [80.82958984, 18.23411942], [80.83423615, 18.23328018], [80.8396225, 18.2280407], [80.85910034, 18.22600174], [80.86174774, 18.22167015], [80.86353302, 18.21718979], [80.86749268, 18.20725822], [80.86725616, 18.20318031], [80.86564636, 18.20099258], [80.86126709, 18.19869995], [80.85650635, 18.19842911], [80.84915924, 18.20021057], [80.84877777, 18.19919014], [80.84819794, 18.19765091], [80.84848022, 18.19594955], [80.84893799, 18.19318962], [80.85222626, 18.18348122], [80.85263062, 18.17850113], [80.85167694, 18.16835976], [80.85578918, 18.15168953], [80.8555069, 18.14915085], [80.85526276, 18.14678955], [80.85549927, 18.14501953], [80.8557663, 18.14293098], [80.85838318, 18.1391201], [80.86035156, 18.13750076], [80.86160278, 18.1364727], [80.8620224, 18.13266945], [80.88111877, 18.13253021], [80.89292908, 18.13445091], [80.90072632, 18.13467026], [80.9119873, 18.13850975], [80.93199158, 18.14941025], [80.93582153, 18.15253067], [80.93672943, 18.15480042], [80.94422913, 18.15709114], [80.94985962, 18.16422844], [80.95419312, 18.16698074], [80.96556854, 18.16835976], [80.97367859, 18.16814995], [80.97383881, 18.1583004], [80.97480011, 18.15192032], [80.97263336, 18.14355087], [80.96753693, 18.13799286], [80.94935608, 18.12318039], [80.94754791, 18.11683846], [80.94979858, 18.1036911], [80.94983673, 18.0983181], [80.94835663, 18.09127045], [80.94597626, 18.08424187], [80.94399261, 18.08102036], [80.95243835, 18.07188034], [80.96350098, 18.04977989], [80.96595764, 18.04346848], [80.96227264, 18.03153038], [80.96264648, 18.03117943], [80.96321106, 18.02816963], [80.96389771, 18.02444077], [80.96617126, 18.01859856], [80.96845245, 18.0118103], [80.9699173, 18.00305939], [80.97151947, 17.99736977], [80.97264099, 17.99317932], [80.9731369, 17.98635292], [80.97383881, 17.97681046], [80.9759903, 17.96291924], [80.97805786, 17.9496212], [80.97981262, 17.94573021], [80.98013306, 17.94326019], [80.98058319, 17.93985939], [80.98329163, 17.93495178], [80.98464966, 17.92290115], [80.99196625, 17.91937065], [80.99433899, 17.91423035], [80.99723816, 17.89516068], [81.0018692, 17.86473083], [81.00332642, 17.8491497], [81.00434875, 17.83834839], [81.01257324, 17.81666946], [81.03244781, 17.78973007], [81.03765106, 17.78623962], [81.04522705, 17.78399086], [81.05597687, 17.78283119], [81.06128693, 17.78359032], [81.06581116, 17.78424072], [81.06910706, 17.78511047], [81.07360077, 17.78629112], [81.07647705, 17.79050064], [81.07956696, 17.79497147], [81.08708191, 17.80334282], [81.08908844, 17.81087112], [81.09770203, 17.81710052], [81.10903168, 17.82312012], [81.12124634, 17.82832909], [81.15956879, 17.85263062], [81.17637634, 17.84912109], [81.18379211, 17.84926987], [81.18730164, 17.84834099], [81.1919632, 17.84710121], [81.21349335, 17.83304977], [81.22036743, 17.82935905], [81.2279129, 17.82629013], [81.25403595, 17.81212997], [81.2633667, 17.81046295], [81.29812622, 17.80985069], [81.31505585, 17.81233978], [81.32598877, 17.81241035], [81.33537292, 17.81125069], [81.3445282, 17.81158066], [81.35749817, 17.81042099], [81.36107635, 17.80961037], [81.36760712, 17.8080883], [81.3744278, 17.80532074], [81.38413239, 17.80348969], [81.38497162, 17.80659294], [81.39431, 17.80812073], [81.40276337, 17.80532074], [81.40925598, 17.80483818], [81.41445923, 17.81011009], [81.41433716, 17.81643105], [81.41941833, 17.8205986], [81.42592621, 17.82127953], [81.43387604, 17.81575966], [81.43756866, 17.81529045], [81.45942688, 17.82471085], [81.46684265, 17.82492065], [81.47012329, 17.82318115], [81.47271729, 17.81789017], [81.47457123, 17.80999947], [81.47870636, 17.80470848], [81.48117828, 17.80286026], [81.48583984, 17.8026104], [81.49632263, 17.80647087], [81.51130676, 17.80656052], [81.52572632, 17.81087112], [81.55393982, 17.8163681], [81.56459045, 17.82569122], [81.56874084, 17.82788086], [81.57486725, 17.82734108], [81.59395599, 17.81911087], [81.59973907, 17.81544113], [81.61115265, 17.81536293], [81.61569977, 17.82201004], [81.62397766, 17.82442284], [81.63143921, 17.83044052], [81.6365509, 17.83628082], [81.64279175, 17.83928108], [81.64614105, 17.84687042], [81.64601898, 17.85626984], [81.64906311, 17.86246872], [81.65270233, 17.86819077], [81.6569519, 17.8728199], [81.66306305, 17.87693024], [81.66805267, 17.87842941], [81.67774963, 17.87758064], [81.6832428, 17.87948036], [81.68828583, 17.88479996], [81.69787598, 17.87553978], [81.69927216, 17.8697319], [81.70317078, 17.86112976], [81.72631836, 17.87409973], [81.75829315, 17.89336014], [81.7634201, 17.88540077], [81.76885986, 17.87869835], [81.78144073, 17.87071991], [81.78753662, 17.86251068], [81.79277039, 17.8525219], [81.79440308, 17.84415054], [81.78784943, 17.83924103], [81.78235626, 17.83195114], [81.76393127, 17.82992935], [81.75293732, 17.81830978], [81.7388916, 17.8216095], [81.72959137, 17.8192997], [81.72342682, 17.81522179], [81.70951843, 17.80511093], [81.70398712, 17.79956055], [81.69824219, 17.78449059], [81.69138336, 17.77570152], [81.68477631, 17.77056122], [81.67469025, 17.76711082], [81.65299988, 17.76561165], [81.64189911, 17.76564026], [81.62306213, 17.76279068], [81.61859131, 17.75858116], [81.61281586, 17.74693108], [81.60919952, 17.7436409], [81.58194733, 17.73065948], [81.57662201, 17.72609138], [81.5729599, 17.71866989], [81.57198334, 17.71183014], [81.57108307, 17.70289993], [81.57116699, 17.68786812], [81.56819153, 17.68283081], [81.56018066, 17.67665291], [81.5536499, 17.66638947], [81.54608917, 17.65069962], [81.54432678, 17.64529991], [81.53414917, 17.63042259], [81.51895905, 17.61878967], [81.51187897, 17.60988045], [81.50927734, 17.60355949], [81.50926971, 17.59832954], [81.50789642, 17.59532166], [81.50292969, 17.58987999], [81.51267242, 17.58296013], [81.52089691, 17.57574081], [81.52390289, 17.57261086], [81.52371979, 17.56970978], [81.52030945, 17.56460953], [81.51374054, 17.55726051], [81.50907898, 17.54932022], [81.5014267, 17.53936005], [81.49946594, 17.53153992], [81.49803162, 17.51007271], [81.49951172, 17.50154114], [81.49816132, 17.48999977], [81.49360657, 17.47702026], [81.49373627, 17.4659996], [81.49585724, 17.46037102], [81.49536133, 17.45380974], [81.49341583, 17.44882011], [81.481987, 17.43220139], [81.47223663, 17.41953087], [81.45726013, 17.40539932], [81.45155334, 17.39833069], [81.44608307, 17.39069176], [81.44151306, 17.38171005], [81.43364716, 17.37494278], [81.42011261, 17.37218285], [81.41831207, 17.36638069], [81.41564941, 17.36162949], [81.40644836, 17.36141014], [81.38522339, 17.35513115], [81.37864685, 17.35612106], [81.37180328, 17.3571682], [81.36395264, 17.36026001], [81.34983826, 17.36852264], [81.34329987, 17.37572098], [81.34292603, 17.38541031], [81.33734894, 17.38999939], [81.33035278, 17.39209938], [81.3246994, 17.3906498], [81.32247162, 17.38915062], [81.31162262, 17.37478065], [81.30162048, 17.35972977], [81.29881287, 17.35214043], [81.28916931, 17.33754921], [81.28179932, 17.3297596], [81.26716614, 17.31999969], [81.26222229, 17.32194138], [81.25752258, 17.32266045], [81.23429108, 17.32282066], [81.21875, 17.3217392], [81.19030762, 17.32736969], [81.18154144, 17.32222939], [81.17822266, 17.31451035], [81.17195892, 17.30545044], [81.17061615, 17.29646111], [81.17114258, 17.26666069], [81.17463684, 17.26037025], [81.18055725, 17.25460052], [81.16799927, 17.24232101], [81.16278839, 17.23258018], [81.14554596, 17.23166275], [81.11817932, 17.2245903], [81.08450317, 17.21364021], [81.06221008, 17.20409966], [81.05384064, 17.21014023], [81.04654694, 17.2138176], [81.04386139, 17.20454025], [81.03996277, 17.19994164], [81.03485107, 17.1972599], [81.03145599, 17.19235039], [81.02617645, 17.1866684], [81.00540161, 17.18444824], [80.99771881, 17.18201065], [80.99125671, 17.17970276], [80.98516083, 17.17938995], [80.96633148, 17.1845417], [80.95598602, 17.18820953], [80.94773102, 17.19333076], [80.93904877, 17.20038033], [80.9306488, 17.20503044], [80.92064667, 17.20582962], [80.91384888, 17.20525932], [80.90534973, 17.20129013], [80.90763855, 17.19285965], [80.90699005, 17.18384171], [80.90847778, 17.17803955], [80.91301727, 17.17378044], [80.91487122, 17.16983986], [80.91400146, 17.16077042], [80.9121933, 17.15350914], [80.91330719, 17.14595032], [80.90939331, 17.14245033], [80.90397644, 17.14114952], [80.89615631, 17.1407795], [80.88886261, 17.14105034], [80.87676239, 17.14520073], [80.87030792, 17.14630127], [80.8667984, 17.12462044], [80.86347198, 17.11799812], [80.85504913, 17.11141014], [80.86421204, 17.09581757], [80.86239624, 17.08563042], [80.86254883, 17.08152962], [80.85646057, 17.06851959], [80.85884857, 17.05085182], [80.85489655, 17.04404068], [80.85053253, 17.0401516], [80.84487915, 17.03284073], [80.83246613, 17.02571106], [80.82930756, 17.0323391], [80.82322693, 17.03778076], [80.80322266, 17.0425396], [80.79284668, 17.04303932], [80.78528595, 17.04762268], [80.78019714, 17.04879951], [80.76609802, 17.0503006], [80.74659729, 17.05491829], [80.7257309, 17.06460953], [80.71261597, 17.06546021], [80.69516754, 17.06834984], [80.68399811, 17.06874084], [80.68139648, 17.06430054], [80.67563629, 17.0612793], [80.66777039, 17.05992126], [80.66059875, 17.05672073], [80.64919281, 17.05458069], [80.63960266, 17.05512047], [80.63392639, 17.05887985], [80.6377182, 17.06561089], [80.63775635, 17.07193947], [80.64438629, 17.07710075], [80.65541077, 17.08397102], [80.65664673, 17.08776283], [80.64626312, 17.09445953], [80.63640594, 17.09699059], [80.62523651, 17.10173988], [80.62975311, 17.11001968], [80.62391663, 17.11188126], [80.61654663, 17.11569977], [80.61292267, 17.11664009], [80.60388184, 17.11551094], [80.59510803, 17.11956024], [80.58026123, 17.13095093], [80.57348633, 17.13529015], [80.56017303, 17.1380291], [80.54907227, 17.12362289], [80.54165649, 17.12041092], [80.53542328, 17.11978912], [80.52916718, 17.11364937], [80.51941681, 17.10815048], [80.51172638, 17.10621071], [80.49611664, 17.10786057], [80.49653625, 17.10129166], [80.49240112, 17.09244156], [80.48873138, 17.08733177], [80.48678589, 17.08289909], [80.48462677, 17.06759071], [80.48465729, 17.05631065], [80.48220062, 17.05027008], [80.47506714, 17.04281044], [80.47174835, 17.0381012], [80.46422577, 17.03718185], [80.45288849, 17.03704262], [80.44624329, 17.01702118], [80.43266296, 17.02178192], [80.42053986, 17.02486038], [80.41777802, 17.02861023], [80.41429138, 17.0417881], [80.40087128, 17.05418968], [80.39890289, 17.05978966], [80.39977264, 17.0652504], [80.3973465, 17.07389069], [80.3950882, 17.07756805], [80.39319611, 17.07781029], [80.39012146, 17.07620049], [80.37905884, 17.06615067], [80.37416077, 17.06311035], [80.36699677, 17.05656815], [80.36775208, 17.05269814], [80.37162018, 17.04752922], [80.37838745, 17.03412056], [80.37722015, 17.02787018], [80.37789154, 17.02334023], [80.38376617, 17.01975822], [80.38871765, 17.01406097], [80.38790894, 17.00729942], [80.3864975, 17.00294113], [80.38197327, 17.00004005], [80.37119293, 16.99584007], [80.37120056, 16.99315071], [80.37161255, 16.98711967], [80.36972046, 16.98295021], [80.36106873, 16.9744606], [80.35824585, 16.97063065], [80.36042023, 16.97050095], [80.38080597, 16.96251106], [80.39762115, 16.95701027], [80.41234589, 16.95417023], [80.44254303, 16.94494057], [80.45308685, 16.9383297], [80.46324921, 16.93021011], [80.46985626, 16.92651176], [80.47688293, 16.92117119], [80.48781586, 16.91744041], [80.48558807, 16.92703819], [80.48693848, 16.93685913], [80.49130249, 16.94818115], [80.509758, 16.94243813], [80.52069092, 16.93639946], [80.53173828, 16.95017815], [80.56948853, 16.92688942], [80.58419037, 16.92651939], [80.58914185, 16.91666985], [80.59030914, 16.91163063], [80.5893631, 16.9071312], [80.58587646, 16.90432167], [80.5821228, 16.90310287], [80.58123779, 16.89677811], [80.58335876, 16.89060974], [80.58577728, 16.88716125], [80.58674622, 16.87393951], [80.57650757, 16.87310028], [80.56497192, 16.86903954], [80.56482697, 16.84991074], [80.56400299, 16.84256172], [80.56243134, 16.83632088], [80.55458069, 16.82478905], [80.55602264, 16.81841087], [80.56124878, 16.81712914], [80.56700897, 16.81710052], [80.57176971, 16.81209946], [80.58584595, 16.8066597], [80.59364319, 16.79791832], [80.59777832, 16.79203033], [80.60410309, 16.78775978], [80.59751892, 16.78508949], [80.56933594, 16.77075005], [80.56281281, 16.76283073], [80.54650879, 16.76765823], [80.53005981, 16.77005959], [80.51806641, 16.76876831], [80.51098633, 16.76993752], [80.48953247, 16.77585983], [80.48464966, 16.78131104], [80.47905731, 16.78495026], [80.47101593, 16.78832054], [80.45639801, 16.79002953], [80.45507813, 16.80648041], [80.4526062, 16.81529045], [80.44476318, 16.81939125], [80.43183136, 16.82385063], [80.43210602, 16.82718086], [80.4228363, 16.82930946], [80.42140961, 16.83712006], [80.41867065, 16.84231949], [80.39971161, 16.84973907], [80.400177, 16.83704948], [80.39914703, 16.83158112], [80.39422607, 16.82516289], [80.3793869, 16.81953049], [80.37784576, 16.81248093], [80.37587738, 16.8106308], [80.37293243, 16.81110001], [80.36711121, 16.82676125], [80.36472321, 16.83890152], [80.36120605, 16.85038185], [80.35862732, 16.8549099], [80.35090637, 16.85330009], [80.33495331, 16.85573959], [80.33731079, 16.86708069], [80.32731628, 16.87101936], [80.3192215, 16.87094116], [80.3184433, 16.87743759], [80.31600189, 16.88400078], [80.31613159, 16.89466286], [80.31328583, 16.91200256], [80.31537628, 16.91238976], [80.30784607, 16.92381287], [80.30396271, 16.93947029], [80.30137634, 16.95586014], [80.28898621, 16.97680283], [80.27617645, 16.99324989], [80.26217651, 17.01062965], [80.25026703, 17.00737953], [80.2411499, 17.00280952], [80.23574829, 17.00233078], [80.23223877, 17.0049305], [80.2178421, 17.0196209], [80.21321869, 17.0191803], [80.2012558, 17.01313972], [80.19554901, 17.01804161], [80.19610596, 17.02568817], [80.19426727, 17.04251289], [80.18212891, 17.04494095], [80.17053223, 17.03041267], [80.16718292, 17.02362061], [80.14911652, 17.00805092], [80.14247131, 17.0014801], [80.14057159, 16.99328995], [80.13385773, 16.98535919], [80.12689972, 16.98533058], [80.12014771, 16.98681068], [80.11467743, 16.98587036], [80.11279297, 16.98232079], [80.10578918, 16.98131943], [80.09947205, 16.98280144], [80.08769226, 16.98744011], [80.08394623, 16.9776783], [80.08423615, 16.96319008], [80.04588318, 16.96529961], [80.03705597, 16.93647003], [80.02849579, 16.92741013], [80.01860046, 16.91880989], [80.009552, 16.90726089], [80.0027771, 16.89146805], [79.99505615, 16.87731171], [79.99167633, 16.86325073], [79.994133, 16.86218071], [80.01383209, 16.85293961], [80.03309631, 16.85244942], [80.03436279, 16.84776115], [80.03439331, 16.83912277], [80.03666687, 16.83238983], [80.0418396, 16.82606125], [80.06967163, 16.81360817], [80.06492615, 16.80251122], [80.05767059, 16.78187943], [80.05158997, 16.77128983], [80.04789734, 16.74515152], [80.04335022, 16.73970032], [80.03276062, 16.73178101], [80.0233078, 16.71847916], [80.01667786, 16.71183014], [80.002388, 16.70294952], [79.99368286, 16.69444084], [79.99151611, 16.69255066], [79.97302246, 16.6595211], [79.95815277, 16.64204979], [79.94256592, 16.63262939], [79.92366791, 16.63073921], [79.91382599, 16.63313103], [79.90207672, 16.63784981], [79.89092255, 16.64956093], [79.88065338, 16.67617035], [79.87330627, 16.68869972], [79.86183929, 16.69822121], [79.84456635, 16.69646072], [79.8259201, 16.69146919], [79.81025696, 16.69049072], [79.7833786, 16.72484016], [79.77490234, 16.7295208], [79.76309204, 16.7271328], [79.75048065, 16.72011948], [79.7338028, 16.69802094], [79.72274017, 16.69260979], [79.6830368, 16.6903801], [79.66864014, 16.68400955], [79.65550232, 16.67408943], [79.64803314, 16.66200066], [79.63329315, 16.6608696], [79.61680603, 16.66464043], [79.59990692, 16.66327095], [79.58558655, 16.65135002], [79.57402039, 16.64359093], [79.56359863, 16.63806915], [79.55399323, 16.63459015], [79.53671265, 16.63156128], [79.51212311, 16.63365173], [79.49717712, 16.63051033], [79.47009277, 16.61874962], [79.45059204, 16.60914993], [79.44315338, 16.59370041], [79.43450165, 16.58566093], [79.42658997, 16.58252144], [79.40270996, 16.58044052], [79.34552765, 16.57956123], [79.33333588, 16.57852173], [79.31977844, 16.57587051], [79.29512024, 16.56735039], [79.28237915, 16.56544113], [79.26611328, 16.56147003], [79.26077271, 16.54642105], [79.23044586, 16.51929092], [79.22527313, 16.50822067], [79.22410583, 16.49213982], [79.23091125, 16.48167038], [79.23513031, 16.47068977], [79.23618317, 16.45853996], [79.22635651, 16.45253944], [79.21906281, 16.43816948], [79.21501923, 16.41576195], [79.21260071, 16.39376068], [79.21330261, 16.37438965], [79.21147156, 16.36281013]]]}}, {\\\"id\\\": \\\"30\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.33_1\\\", \\\"HASC_1\\\": \\\"IN.TR\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Tripura\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": null, \\\"apm25_popweighted\\\": 33.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 754.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 2038.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2792.0, \\\"geo-id\\\": 30, \\\"hpm25_child_popweighted\\\": 173.1, \\\"hpm25_female_popweighted\\\": 199.0, \\\"hpm25_male_popweighted\\\": 143.3, \\\"location\\\": \\\"Tripura\\\", \\\"mort_apm25_6cod_mean_total\\\": 1172.0, \\\"mort_hpm25_6cod_mean_total\\\": 3099.0, \\\"mort_tpm25_6cod_mean_total\\\": 4270.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[91.38983154, 23.17717171], [91.38968658, 23.17726326], [91.38961792, 23.17733574], [91.38951874, 23.17742538], [91.38946533, 23.17752838], [91.38930511, 23.17773056], [91.38920593, 23.17787743], [91.38913727, 23.17794991], [91.38907623, 23.17809677], [91.38897705, 23.1782856], [91.3888855, 23.17844582], [91.38885498, 23.17857742], [91.3888092, 23.17868042], [91.38871765, 23.17886925], [91.38867188, 23.17901421], [91.3886261, 23.17911911], [91.38864136, 23.17930794], [91.38877106, 23.17939377], [91.38885498, 23.17943001], [91.38983154, 23.17717171]]], [[[91.41801453, 23.25741768], [91.41793823, 23.25728226], [91.41781616, 23.2571888], [91.41768646, 23.25718689], [91.41764832, 23.25725174], [91.41779327, 23.2573452], [91.41801453, 23.25741768]]], [[[92.03777313, 24.37796402], [92.03799438, 24.37792587], [92.03791809, 24.37782097], [92.03777313, 24.37796402]]], [[[91.71310425, 22.98869514], [91.71295929, 22.98880577], [91.71283722, 22.9889164], [91.71266174, 22.98898888], [91.71246338, 22.98899269], [91.7122879, 22.98898888], [91.71205139, 22.98907471], [91.71180725, 22.98895454], [91.71189117, 22.98889542], [91.71147919, 22.98868752], [91.71131897, 22.98848915], [91.71115112, 22.98822594], [91.71101379, 22.98796654], [91.71108246, 22.98776245], [91.71123505, 22.98749924], [91.71130371, 22.98731422], [91.71131897, 22.9871788], [91.71128082, 22.98686218], [91.71128845, 22.9866333], [91.71131897, 22.98617172], [91.71137238, 22.98588371], [91.71134949, 22.98570061], [91.71146393, 22.98517227], [91.71152496, 22.98477364], [91.71154022, 22.9845314], [91.71155548, 22.98442841], [91.71160889, 22.98410034], [91.71160126, 22.98391914], [91.71157837, 22.98371124], [91.71142578, 22.98364639], [91.71131897, 22.98344994], [91.71115112, 22.98308372], [91.71115875, 22.98298645], [91.71099091, 22.98266983], [91.71081543, 22.98253059], [91.71055603, 22.9823761], [91.70991516, 22.98211288], [91.7097702, 22.98209], [91.70934296, 22.98201561], [91.70901489, 22.98201752], [91.70891571, 22.9820118], [91.70874786, 22.98198509], [91.70856476, 22.98200226], [91.70840454, 22.98205757], [91.70815277, 22.98215675], [91.70798492, 22.98234749], [91.70782471, 22.98242569], [91.7076416, 22.98247528], [91.70758057, 22.98254776], [91.70735168, 22.98269272], [91.70716095, 22.98278046], [91.70693207, 22.98304749], [91.70664978, 22.9833374], [91.70652771, 22.98364639], [91.70617676, 22.98404694], [91.70587158, 22.98445892], [91.70581055, 22.98460007], [91.70543671, 22.98502541], [91.70522308, 22.98531723], [91.70513916, 22.98541641], [91.70504761, 22.98555756], [91.70481873, 22.98593521], [91.70471191, 22.98594284], [91.70459747, 22.98616982], [91.70445251, 22.98649788], [91.70428467, 22.98673439], [91.70420074, 22.98676682], [91.70397186, 22.98699188], [91.70376587, 22.98723984], [91.7036972, 22.98739624], [91.70361328, 22.9877243], [91.70350647, 22.9879818], [91.70343018, 22.98817825], [91.70333862, 22.98827744], [91.70317078, 22.98838806], [91.70298767, 22.98845673], [91.70278931, 22.98854637], [91.70253754, 22.98863983], [91.70223999, 22.98880386], [91.70192719, 22.98891258], [91.70162964, 22.989048], [91.70148468, 22.989048], [91.70111847, 22.98910332], [91.70090485, 22.989151], [91.70068359, 22.9891758], [91.70013428, 22.98905373], [91.69994354, 22.98901176], [91.69957733, 22.98892975], [91.69924164, 22.98883057], [91.6990509, 22.98879242], [91.69873047, 22.98879433], [91.69828033, 22.98874855], [91.69793701, 22.98873901], [91.69772339, 22.98866653], [91.69705963, 22.98842239], [91.6966629, 22.98836708], [91.69625092, 22.98834801], [91.69608307, 22.9883194], [91.69590759, 22.98836136], [91.69566345, 22.98843956], [91.69529724, 22.98849487], [91.69506073, 22.98844719], [91.69483185, 22.98844719], [91.69436646, 22.98848915], [91.69385529, 22.98841858], [91.69361115, 22.98844719], [91.69329834, 22.98828125], [91.69290924, 22.98813057], [91.69264221, 22.98800278], [91.69242859, 22.98781967], [91.69216156, 22.98751068], [91.69192505, 22.98719215], [91.69180298, 22.98707199], [91.69164276, 22.98682022], [91.69158173, 22.98663902], [91.69152832, 22.98633194], [91.69140625, 22.98575783], [91.69145203, 22.98542976], [91.69145203, 22.98530769], [91.69145203, 22.98497009], [91.69142914, 22.98458672], [91.6913147, 22.98420143], [91.69113922, 22.98397255], [91.69100952, 22.98374176], [91.69091034, 22.98341179], [91.69089508, 22.98314285], [91.69059753, 22.98288727], [91.69029999, 22.98266602], [91.68974304, 22.98228645], [91.6893158, 22.98210526], [91.68922424, 22.98206902], [91.68882751, 22.9818058], [91.68856812, 22.9818058], [91.68823242, 22.98180389], [91.68804932, 22.98174095], [91.68785095, 22.98163414], [91.68768311, 22.98157883], [91.68750763, 22.98148918], [91.68719482, 22.9813385], [91.68674469, 22.98111725], [91.68658447, 22.98106575], [91.68643188, 22.98102188], [91.68626404, 22.9810009], [91.68609619, 22.98106003], [91.68583679, 22.98095512], [91.6856308, 22.98084068], [91.68545532, 22.98068619], [91.68530273, 22.98058128], [91.68505859, 22.98043251], [91.6849823, 22.9803772], [91.68489838, 22.98029709], [91.68466949, 22.98001862], [91.68460846, 22.97992325], [91.68450928, 22.9797554], [91.68434906, 22.97958755], [91.68416595, 22.97932053], [91.68367767, 22.97854424], [91.68360901, 22.97844315], [91.68350983, 22.97830582], [91.68336487, 22.9781971], [91.68312836, 22.97797012], [91.68299103, 22.97789764], [91.68268585, 22.97769165], [91.68243408, 22.97756958], [91.68215942, 22.97750664], [91.68190765, 22.97743416], [91.6816864, 22.97738838], [91.68135071, 22.97743416], [91.68102264, 22.97749329], [91.68094635, 22.9775238], [91.68078613, 22.97758865], [91.68066406, 22.97774315], [91.6805191, 22.97797012], [91.68031311, 22.97816086], [91.68025208, 22.97823715], [91.68012238, 22.97839737], [91.68001556, 22.97848511], [91.67987823, 22.97856903], [91.67980194, 22.97867775], [91.67972565, 22.97880363], [91.67967224, 22.97894859], [91.67961884, 22.97909546], [91.67950439, 22.97939301], [91.67946625, 22.97952652], [91.67938995, 22.97968483], [91.67926788, 22.97992706], [91.67919159, 22.98010254], [91.67903137, 22.98029327], [91.67888641, 22.98041344], [91.6787796, 22.98050308], [91.67855072, 22.9806385], [91.67835236, 22.98074722], [91.67827606, 22.98078537], [91.67809296, 22.98087502], [91.67795563, 22.98089218], [91.6774826, 22.98095512], [91.67705536, 22.98094749], [91.67683411, 22.98095512], [91.67671967, 22.98092842], [91.67642212, 22.98081017], [91.67616272, 22.98073578], [91.67591858, 22.98063469], [91.67569733, 22.98054695], [91.67547607, 22.98044014], [91.6751709, 22.98038292], [91.67476654, 22.98029518], [91.67459869, 22.98025513], [91.67444611, 22.98007393], [91.67427826, 22.97987366], [91.67419434, 22.9797554], [91.67391205, 22.97951889], [91.67377472, 22.97940826], [91.6734848, 22.97919846], [91.67316437, 22.97891045], [91.67301941, 22.97871971], [91.67287445, 22.97856522], [91.67266083, 22.97834396], [91.67256165, 22.97821999], [91.67247772, 22.97805977], [91.67222595, 22.97779274], [91.67203522, 22.97761154], [91.6717453, 22.97748947], [91.67153168, 22.97740173], [91.67129517, 22.97731781], [91.67110443, 22.97725677], [91.67092133, 22.97719193], [91.67077637, 22.9771843], [91.67067719, 22.97723961], [91.67050171, 22.97726822], [91.6703949, 22.97725296], [91.67022705, 22.97729301], [91.67007446, 22.97737694], [91.66991425, 22.97748375], [91.66975403, 22.97758293], [91.66947174, 22.97768402], [91.66934204, 22.97696877], [91.66920471, 22.97799683], [91.66905212, 22.97808266], [91.66877747, 22.97833633], [91.66864014, 22.97842407], [91.66845703, 22.97848892], [91.66838074, 22.97852707], [91.66825104, 22.97860146], [91.66805267, 22.97861481], [91.66791534, 22.97870827], [91.66781616, 22.97874641], [91.66762543, 22.97882462], [91.66726685, 22.97894669], [91.6672821, 22.97910309], [91.66706085, 22.97931099], [91.66690063, 22.97949219], [91.66674042, 22.97967148], [91.66649628, 22.97988892], [91.66635132, 22.98008728], [91.66623688, 22.98026848], [91.66612244, 22.98044014], [91.66603851, 22.98058128], [91.66589355, 22.98072624], [91.665802, 22.98084641], [91.66564178, 22.98101044], [91.66544342, 22.98115349], [91.66523743, 22.98131752], [91.66498566, 22.9815464], [91.66478729, 22.98172188], [91.66465759, 22.98177528], [91.664505, 22.98179245], [91.66429901, 22.98181152], [91.66418457, 22.9817791], [91.66407013, 22.98167419], [91.6639328, 22.98146439], [91.66383362, 22.98128319], [91.66375732, 22.98104668], [91.66366577, 22.98091698], [91.66363525, 22.98077583], [91.66357422, 22.98062134], [91.66349792, 22.98049164], [91.66336823, 22.98034096], [91.66323853, 22.98018646], [91.66312408, 22.98000908], [91.6629715, 22.97973824], [91.66278839, 22.97955704], [91.66261292, 22.97944832], [91.66249084, 22.97942924], [91.66229248, 22.97937584], [91.66204834, 22.9793396], [91.66176605, 22.97932625], [91.66160583, 22.97936821], [91.66140747, 22.97944641], [91.66119385, 22.97961998], [91.66109467, 22.9796772], [91.66085052, 22.9798851], [91.66064453, 22.98005104], [91.66056824, 22.98012161], [91.66047668, 22.980299], [91.66039276, 22.9804287], [91.66014862, 22.98070908], [91.65986633, 22.98098564], [91.65982056, 22.98117638], [91.65965271, 22.98128319], [91.65953064, 22.98132706], [91.65938568, 22.98139191], [91.65918732, 22.98153877], [91.65900421, 22.98160934], [91.65883636, 22.98166084], [91.65854645, 22.98179436], [91.65831757, 22.98183632], [91.65804291, 22.98188591], [91.65786743, 22.98188019], [91.65766144, 22.98189926], [91.65729523, 22.98188591], [91.65711975, 22.98180008], [91.65701294, 22.98176003], [91.65684509, 22.98168182], [91.65668488, 22.98159218], [91.65660095, 22.98150063], [91.65647888, 22.98130226], [91.65636444, 22.98113823], [91.65629578, 22.98096085], [91.65625763, 22.98077774], [91.65628052, 22.98060799], [91.65638733, 22.98045158], [91.65645599, 22.98036194], [91.65651703, 22.98027611], [91.65662384, 22.9801445], [91.6566925, 22.98011971], [91.65678406, 22.98010826], [91.6569519, 22.98008347], [91.65710449, 22.98003387], [91.6572113, 22.97998619], [91.65729523, 22.97989655], [91.65756989, 22.9797039], [91.65770721, 22.97957802], [91.65782166, 22.97948265], [91.65790558, 22.9793663], [91.65794373, 22.97924995], [91.65800476, 22.97900963], [91.65800476, 22.97885323], [91.65800476, 22.97837448], [91.65802765, 22.97826576], [91.65794373, 22.97822762], [91.65785217, 22.97821236], [91.65765381, 22.97807884], [91.65750885, 22.97802734], [91.65739441, 22.97795677], [91.65724182, 22.97781563], [91.65705872, 22.97766876], [91.65686035, 22.97754097], [91.65677643, 22.97737122], [91.65666962, 22.97730827], [91.65661621, 22.97721672], [91.65651703, 22.97714043], [91.65640259, 22.97709465], [91.65610504, 22.97688484], [91.65600586, 22.97683144], [91.65544891, 22.97670364], [91.65509033, 22.97664261], [91.65493011, 22.97664833], [91.65474701, 22.97667503], [91.65426636, 22.97670364], [91.65368652, 22.97677231], [91.65349579, 22.97680855], [91.65332031, 22.97681999], [91.65310669, 22.97686577], [91.65291595, 22.97689247], [91.65280151, 22.97688675], [91.65262604, 22.97686195], [91.65236664, 22.9768219], [91.65213013, 22.97680473], [91.65194702, 22.97681046], [91.65181732, 22.97681808], [91.65168762, 22.97682762], [91.65150452, 22.97684288], [91.65129852, 22.97688103], [91.65115356, 22.97697258], [91.65106201, 22.97703552], [91.65090179, 22.97713661], [91.65084076, 22.97727966], [91.65080261, 22.97755051], [91.65074921, 22.97773743], [91.65068054, 22.97790146], [91.65058899, 22.97821426], [91.6505661, 22.9783783], [91.65060425, 22.97857475], [91.65060425, 22.9786911], [91.65059662, 22.97897339], [91.65059662, 22.97909927], [91.65058899, 22.97937584], [91.6505661, 22.97962761], [91.65055847, 22.97988892], [91.65054321, 22.98011208], [91.6505661, 22.98043251], [91.65057373, 22.98060608], [91.65058136, 22.98093605], [91.65058899, 22.98117065], [91.65060425, 22.98135185], [91.65060425, 22.98150444], [91.65055084, 22.98168564], [91.6505127, 22.98178482], [91.65035248, 22.9820137], [91.65021515, 22.9822197], [91.65011597, 22.98228073], [91.65001678, 22.98243141], [91.64994049, 22.98252106], [91.64995575, 22.98265648], [91.64984131, 22.98277473], [91.64965057, 22.98301697], [91.64951324, 22.98319054], [91.6493988, 22.98335648], [91.64927673, 22.98348999], [91.64905548, 22.98361969], [91.64878082, 22.98377609], [91.64858246, 22.98394585], [91.64829254, 22.98412704], [91.64807892, 22.98431206], [91.64783478, 22.98456001], [91.64772034, 22.98464775], [91.64751434, 22.98473549], [91.64736938, 22.98483086], [91.6470108, 22.98503304], [91.64668274, 22.98516273], [91.64641571, 22.98524475], [91.64630127, 22.98526382], [91.64611816, 22.98529816], [91.64584351, 22.98530769], [91.64571381, 22.98528671], [91.64559937, 22.98525238], [91.64546204, 22.98519707], [91.64532471, 22.9851265], [91.64520264, 22.98501587], [91.64521027, 22.98480797], [91.64514923, 22.98468971], [91.64515686, 22.9844265], [91.64511871, 22.9840641], [91.6451416, 22.9839592], [91.64517212, 22.98369217], [91.64520264, 22.98328209], [91.6452179, 22.98305511], [91.64524841, 22.98293114], [91.64528656, 22.98263741], [91.64531708, 22.9825573], [91.64537048, 22.98243713], [91.64544678, 22.98192978], [91.64546967, 22.98155403], [91.64550781, 22.98124504], [91.64559937, 22.98088646], [91.64559937, 22.98064041], [91.64562988, 22.98051643], [91.64573669, 22.98036194], [91.64575958, 22.98027039], [91.64574432, 22.98013878], [91.64573669, 22.98000717], [91.64570618, 22.97981453], [91.64567566, 22.97955132], [91.64565277, 22.97945786], [91.64566803, 22.97934532], [91.64570618, 22.97903442], [91.64572144, 22.97877693], [91.64580536, 22.97847748], [91.64575958, 22.97826767], [91.6457901, 22.97808075], [91.64572906, 22.97802162], [91.64568329, 22.97779655], [91.64569855, 22.97757149], [91.64569855, 22.97748184], [91.64572144, 22.97717285], [91.64573669, 22.97704124], [91.64566803, 22.97675133], [91.64546967, 22.976408], [91.64536285, 22.97635078], [91.64519501, 22.97620583], [91.64501953, 22.97613144], [91.64494324, 22.97609138], [91.64485168, 22.97605705], [91.64478302, 22.97601891], [91.64458466, 22.9759903], [91.6443634, 22.97599792], [91.64415741, 22.97604179], [91.64388275, 22.97608566], [91.64375305, 22.97608757], [91.64336395, 22.97609138], [91.64324951, 22.97608566], [91.64287567, 22.97605705], [91.64234924, 22.97601891], [91.64218903, 22.97596931], [91.64205933, 22.97590256], [91.64186859, 22.97587013], [91.641716, 22.97584724], [91.64144135, 22.97571754], [91.64131165, 22.97563934], [91.64120483, 22.97554207], [91.64092255, 22.97520638], [91.64080048, 22.97509575], [91.64074707, 22.97501755], [91.64073181, 22.97479439], [91.64071655, 22.97449684], [91.64069366, 22.9743042], [91.64070129, 22.97420692], [91.64073181, 22.9736824], [91.64073181, 22.97344398], [91.64070892, 22.97315216], [91.64071655, 22.97302437], [91.64070892, 22.97280884], [91.64070129, 22.97250557], [91.64071655, 22.9721508], [91.640625, 22.9716835], [91.64060211, 22.97138977], [91.64058685, 22.97120667], [91.64053345, 22.97075462], [91.64045715, 22.97047615], [91.64041138, 22.97040939], [91.64033508, 22.97034645], [91.64025879, 22.97032928], [91.64015961, 22.97025108], [91.64022827, 22.97013855], [91.64019775, 22.97006798], [91.64012146, 22.96992111], [91.63999939, 22.96965981], [91.63990784, 22.9695015], [91.63980103, 22.96933556], [91.6397171, 22.96920967], [91.63961792, 22.96904945], [91.63951111, 22.96889687], [91.63937378, 22.96868324], [91.63928223, 22.96860886], [91.63920593, 22.96856689], [91.63912201, 22.9685688], [91.63905334, 22.96845436], [91.63899231, 22.96835709], [91.63890839, 22.96832085], [91.63871002, 22.96799088], [91.63861084, 22.96783066], [91.63845825, 22.96767998], [91.63832855, 22.96747971], [91.63819885, 22.96728516], [91.63803864, 22.9671154], [91.63793182, 22.96699333], [91.63763428, 22.96658707], [91.63757324, 22.96652412], [91.63746643, 22.9664135], [91.63741302, 22.96626663], [91.63733673, 22.96615982], [91.63722992, 22.96604919], [91.63711548, 22.96589851], [91.63710022, 22.9657383], [91.6370163, 22.96550369], [91.63695526, 22.96534157], [91.6370697, 22.96498489], [91.63710022, 22.96477699], [91.63712311, 22.9645195], [91.63716125, 22.96440697], [91.63719177, 22.96419716], [91.63722229, 22.96412086], [91.63722229, 22.96390533], [91.63721466, 22.96370125], [91.63708496, 22.96339417], [91.63706207, 22.96325684], [91.63706207, 22.96316719], [91.63690948, 22.96307182], [91.63681793, 22.96293068], [91.63673401, 22.96277428], [91.63661957, 22.96254921], [91.63650513, 22.96243477], [91.63640594, 22.96221352], [91.63625336, 22.96201515], [91.63595581, 22.96171761], [91.63586426, 22.96162796], [91.63569641, 22.96143532], [91.63565063, 22.96133995], [91.63560486, 22.96125412], [91.63550568, 22.96116829], [91.63538361, 22.96105385], [91.63529968, 22.96106911], [91.63523865, 22.96102524], [91.63516998, 22.96097946], [91.6348877, 22.96073914], [91.63467407, 22.96060562], [91.63454437, 22.96057129], [91.63442993, 22.96058655], [91.63419342, 22.96045876], [91.63404846, 22.96035576], [91.6339035, 22.96030426], [91.63375854, 22.96026421], [91.63356781, 22.96016693], [91.63311768, 22.95995331], [91.63275146, 22.95981598], [91.63259888, 22.95976257], [91.63240814, 22.95968819], [91.63215637, 22.95956993], [91.63181305, 22.95941734], [91.63167572, 22.95939445], [91.63147736, 22.95929909], [91.63115692, 22.95923996], [91.63082123, 22.95920753], [91.63069916, 22.95921135], [91.63034058, 22.95929909], [91.62973022, 22.95962524], [91.62955475, 22.95970535], [91.62931824, 22.95985031], [91.62910461, 22.95993996], [91.62882996, 22.96011734], [91.62865448, 22.96027374], [91.62854767, 22.96037483], [91.6284256, 22.96045685], [91.62817383, 22.96071434], [91.62805176, 22.96083832], [91.62741852, 22.96016121], [91.62734222, 22.95955849], [91.62732697, 22.95940971], [91.62792969, 22.95788574], [91.62908936, 22.95690918], [91.62767792, 22.95508575], [91.62755585, 22.95495415], [91.62557983, 22.95281029], [91.62537384, 22.95258713], [91.62533569, 22.9525013], [91.62506104, 22.95217133], [91.62493896, 22.95202446], [91.6248703, 22.95180702], [91.62462616, 22.95149994], [91.62438202, 22.9511013], [91.62420654, 22.95084953], [91.62399292, 22.95053482], [91.62380981, 22.95027161], [91.62372589, 22.95011711], [91.62364197, 22.95002556], [91.6235733, 22.9498539], [91.62350464, 22.9496994], [91.6234436, 22.94954109], [91.62345123, 22.94937325], [91.62346649, 22.94921875], [91.62350464, 22.94911957], [91.62345123, 22.94897079], [91.62350464, 22.94866943], [91.62358856, 22.94853783], [91.62356567, 22.94846344], [91.62380981, 22.948246], [91.62391663, 22.94813347], [91.62397766, 22.94798279], [91.62407684, 22.94788551], [91.62416077, 22.94777679], [91.62428284, 22.94761658], [91.62436676, 22.94748306], [91.62439728, 22.94737816], [91.62456512, 22.94717216], [91.62467957, 22.94711113], [91.62481689, 22.94696236], [91.62488556, 22.94684029], [91.62515259, 22.94647408], [91.62516022, 22.9462204], [91.62533569, 22.94585037], [91.62546539, 22.94549751], [91.62554169, 22.9451313], [91.62554932, 22.94474983], [91.62553406, 22.94445992], [91.62547302, 22.94418144], [91.62532043, 22.94394493], [91.62518311, 22.94376183], [91.62496185, 22.94372559], [91.62492371, 22.94363594], [91.62477112, 22.94338608], [91.62452698, 22.94319344], [91.62438202, 22.94312096], [91.62422943, 22.94301796], [91.62411499, 22.94284821], [91.62372589, 22.94266701], [91.6233139, 22.94233322], [91.62282562, 22.94187546], [91.62236023, 22.94142151], [91.62212372, 22.94114494], [91.62195587, 22.94089317], [91.62174988, 22.9406414], [91.62149811, 22.94029427], [91.62140656, 22.94014168], [91.621315, 22.94005585], [91.62120819, 22.94000435], [91.62120819, 22.93988228], [91.6211319, 22.93981934], [91.62071228, 22.93928909], [91.62054443, 22.93907166], [91.62042236, 22.93888664], [91.620224, 22.93867493], [91.62000275, 22.93858719], [91.61988068, 22.93854523], [91.61972046, 22.93853951], [91.61934662, 22.93851089], [91.61902618, 22.93848991], [91.61878967, 22.93852615], [91.61849976, 22.9385643], [91.61823273, 22.93857956], [91.61793518, 22.93865395], [91.6175766, 22.93880272], [91.61728668, 22.93900108], [91.61717987, 22.93912506], [91.61701202, 22.93935013], [91.61682129, 22.93969345], [91.61669159, 22.94009018], [91.61662292, 22.94046974], [91.6166153, 22.94102287], [91.61668396, 22.94159508], [91.61678314, 22.94226265], [91.61690521, 22.94276237], [91.61695862, 22.94319725], [91.61699677, 22.94346428], [91.61698151, 22.94371796], [91.61694336, 22.94393921], [91.61688995, 22.94417953], [91.61682129, 22.94422531], [91.61660004, 22.94424057], [91.61607361, 22.94437981], [91.61585999, 22.9444809], [91.61560822, 22.94466591], [91.61528015, 22.94484329], [91.6146698, 22.94513702], [91.61411285, 22.94539261], [91.61389923, 22.94555092], [91.61371613, 22.94564247], [91.61340332, 22.94597626], [91.61320496, 22.94607544], [91.6129837, 22.94628525], [91.61289215, 22.9466629], [91.6126709, 22.94719315], [91.61267853, 22.94731712], [91.61268616, 22.94749641], [91.61261749, 22.94760704], [91.61260223, 22.94767952], [91.61260223, 22.947752], [91.61254883, 22.94799614], [91.61248779, 22.94831085], [91.6125412, 22.94861794], [91.61253357, 22.94890594], [91.61260986, 22.94933319], [91.61270142, 22.94942284], [91.61277008, 22.94953537], [91.61292267, 22.94972038], [91.61309052, 22.94977188], [91.61339569, 22.94982147], [91.61376953, 22.94973373], [91.61408997, 22.94967079], [91.61447144, 22.94963646], [91.61465454, 22.949543], [91.6149826, 22.94938278], [91.615242, 22.94935226], [91.61560822, 22.94924736], [91.61574554, 22.94923782], [91.61585236, 22.94922829], [91.61612701, 22.9491539], [91.61629486, 22.94919968], [91.61640167, 22.94926262], [91.6163559, 22.94961357], [91.61651611, 22.94982719], [91.61663818, 22.94996262], [91.61663055, 22.95016289], [91.61653137, 22.95040703], [91.6164093, 22.95064545], [91.61634064, 22.95083427], [91.61626434, 22.95092201], [91.61621094, 22.95097351], [91.61611938, 22.9511528], [91.61600494, 22.95129776], [91.61578369, 22.95158768], [91.61538696, 22.95189667], [91.61526489, 22.95199013], [91.61502075, 22.95212746], [91.61476898, 22.9522953], [91.61432648, 22.95249367], [91.6137619, 22.95256424], [91.61360168, 22.95254898], [91.61333466, 22.95247459], [91.6132431, 22.95236206], [91.61319733, 22.95226479], [91.61304474, 22.95219994], [91.61294556, 22.95213509], [91.61277771, 22.95213699], [91.61228943, 22.95202065], [91.61190033, 22.95196342], [91.61170959, 22.95188713], [91.61149597, 22.95178223], [91.61133575, 22.9516964], [91.61121368, 22.95160294], [91.6109848, 22.95148849], [91.61058807, 22.95127487], [91.61006927, 22.95108986], [91.60979462, 22.95089531], [91.60948944, 22.95067596], [91.60807037, 22.95047188], [91.60861206, 22.95028687], [91.60814667, 22.95018196], [91.60783386, 22.95010948], [91.6074295, 22.9500885], [91.60716248, 22.95014572], [91.60705566, 22.95016289], [91.60694885, 22.95027161], [91.60688782, 22.95040321], [91.60671997, 22.95067596], [91.60661316, 22.9509449], [91.6067276, 22.95120811], [91.60676575, 22.95148087], [91.60678864, 22.95172501], [91.60688019, 22.95198059], [91.60690308, 22.9521389], [91.60700989, 22.95229721], [91.60707092, 22.95247459], [91.60712433, 22.9525795], [91.60717773, 22.95271683], [91.60734558, 22.95305252], [91.60762787, 22.95353699], [91.60784912, 22.95381546], [91.60800934, 22.95410538], [91.608284, 22.95439339], [91.60860443, 22.95477867], [91.60879517, 22.95502472], [91.60894775, 22.95516968], [91.60932159, 22.95570946], [91.60944366, 22.95587921], [91.60947418, 22.95602036], [91.60931396, 22.95611572], [91.60888672, 22.95648193], [91.60668945, 22.95611572], [91.60581207, 22.95612144], [91.6055069, 22.95589638], [91.60535431, 22.95575714], [91.60501862, 22.95551109], [91.60490417, 22.95540619], [91.60445404, 22.95503235], [91.60437012, 22.95493889], [91.60429382, 22.95484543], [91.60401154, 22.95464706], [91.60386658, 22.9545517], [91.60349274, 22.95417595], [91.60308075, 22.95381927], [91.60273743, 22.95354652], [91.60254669, 22.95346451], [91.60236359, 22.95338249], [91.60216522, 22.95345688], [91.60198212, 22.95341492], [91.60190582, 22.95335388], [91.60179901, 22.95334625], [91.60153961, 22.95343781], [91.60142517, 22.95344543], [91.60131073, 22.95346451], [91.60127258, 22.95353889], [91.60088348, 22.95382881], [91.60077667, 22.95393181], [91.6005249, 22.95413971], [91.60037994, 22.95422935], [91.60025024, 22.95445251], [91.6002121, 22.9546299], [91.60012054, 22.95484161], [91.60002136, 22.95508003], [91.60004425, 22.9552803], [91.60001373, 22.95542336], [91.60002899, 22.956007], [91.60005951, 22.95615005], [91.6001358, 22.95624161], [91.60017395, 22.9563446], [91.60031891, 22.95649147], [91.60032654, 22.95668221], [91.60034943, 22.95676804], [91.60050964, 22.95701408], [91.60079193, 22.95749855], [91.60105133, 22.95791054], [91.6013031, 22.95824242], [91.60152435, 22.95851135], [91.60179138, 22.95894814], [91.60186005, 22.95911407], [91.60207367, 22.95933151], [91.60218048, 22.95948029], [91.60240173, 22.95965958], [91.60256195, 22.95978737], [91.60263824, 22.95990562], [91.6027832, 22.96003914], [91.60295105, 22.96031189], [91.6030426, 22.96047592], [91.60330963, 22.96075058], [91.60342407, 22.96092987], [91.60361481, 22.96114922], [91.60387421, 22.96139526], [91.60424805, 22.96175385], [91.60469055, 22.96221352], [91.60478973, 22.96231079], [91.60492706, 22.96237755], [91.60505676, 22.96239471], [91.60520935, 22.96243668], [91.60536194, 22.96245193], [91.60547638, 22.96251488], [91.60572815, 22.96244621], [91.60599518, 22.96235657], [91.60620117, 22.96231079], [91.60641479, 22.96227646], [91.60667419, 22.96218681], [91.60679626, 22.96214867], [91.6072998, 22.96331787], [91.60800934, 22.96423531], [91.60786438, 22.9642868], [91.60669708, 22.96468544], [91.60631561, 22.96486092], [91.60595703, 22.96505737], [91.60561371, 22.96530342], [91.60532379, 22.96580887], [91.60519409, 22.96615791], [91.60516357, 22.96643829], [91.60518646, 22.96676445], [91.60526276, 22.96731949], [91.60536194, 22.96784973], [91.60553741, 22.96850014], [91.60577393, 22.96932602], [91.60612488, 22.97023964], [91.60620117, 22.97047234], [91.60623932, 22.97077751], [91.60629272, 22.97112846], [91.6062851, 22.97143745], [91.60623169, 22.97166061], [91.60611725, 22.97190666], [91.60603333, 22.97203827], [91.60584259, 22.9721241], [91.6055603, 22.97216988], [91.60482025, 22.97203064], [91.60388184, 22.97191238], [91.60365295, 22.97182465], [91.60327148, 22.97167969], [91.59967041, 22.96972656], [91.59729004, 22.97052002], [91.59747314, 22.97247314], [91.59828186, 22.97514153], [91.59767914, 22.97571373], [91.59745026, 22.97561264], [91.59727478, 22.97541237], [91.59684753, 22.97516441], [91.59638214, 22.97482872], [91.59589386, 22.97443962], [91.59532928, 22.97400284], [91.59479523, 22.97362137], [91.59453583, 22.97340584], [91.59436798, 22.9732933], [91.59402466, 22.97306633], [91.59367371, 22.97294807], [91.5934906, 22.97278404], [91.59336853, 22.97271538], [91.59319305, 22.97269058], [91.59284973, 22.97276497], [91.59264374, 22.97296524], [91.59242249, 22.97313118], [91.59233093, 22.97340202], [91.59223175, 22.97359085], [91.59209442, 22.97398376], [91.5920105, 22.97445488], [91.59187317, 22.97509003], [91.59172821, 22.97568512], [91.59166718, 22.97605705], [91.59159851, 22.97628593], [91.59145355, 22.97660065], [91.59133911, 22.97671509], [91.59106445, 22.97691154], [91.59082794, 22.97701836], [91.59060669, 22.97705269], [91.59038544, 22.97705841], [91.59017944, 22.9769783], [91.58998871, 22.97687531], [91.58985138, 22.97676849], [91.58979034, 22.97644997], [91.5894928, 22.97598076], [91.58882904, 22.97527313], [91.58861542, 22.97504616], [91.58848572, 22.97479248], [91.58766937, 22.97406006], [91.58692932, 22.9734211], [91.58638763, 22.97300529], [91.58550262, 22.97229958], [91.58498383, 22.9718895], [91.58448792, 22.97154999], [91.58362579, 22.97088814], [91.58244324, 22.96992683], [91.58085632, 22.96865082], [91.5796814, 22.96770287], [91.57888031, 22.9671154], [91.57866669, 22.96693993], [91.57823944, 22.96658325], [91.57778931, 22.96629333], [91.57736206, 22.96595573], [91.57695007, 22.96559143], [91.57675934, 22.96537399], [91.57635498, 22.96563721], [91.57624054, 22.96589851], [91.57553864, 22.96749306], [91.57500458, 22.9688282], [91.57456207, 22.9690361], [91.56768799, 22.97229004], [91.56729126, 22.97278595], [91.5663147, 22.97333145], [91.56607056, 22.97347069], [91.56563568, 22.97372246], [91.5640564, 22.97460365], [91.56231689, 22.97561836], [91.56092834, 22.97637367], [91.55990601, 22.97698212], [91.55843353, 22.97785759], [91.55717468, 22.97860336], [91.55712128, 22.97987747], [91.5570755, 22.98105431], [91.55705261, 22.98163795], [91.55701447, 22.98324776], [91.55696106, 22.98574448], [91.55692291, 22.98769379], [91.55695343, 22.98999596], [91.55696869, 22.99114418], [91.55696869, 22.99139595], [91.55700684, 22.99212074], [91.55699921, 22.99283791], [91.55291748, 22.99267578], [91.54901886, 22.99475479], [91.54746246, 22.99436188], [91.54698181, 22.99485207], [91.54684448, 22.99499893], [91.54595184, 22.99592018], [91.54566956, 22.99622154], [91.54485321, 22.99709129], [91.54362488, 22.99839211], [91.54314423, 22.99890518], [91.54244995, 22.99965286], [91.54270172, 23.0005722], [91.54272461, 23.00064659], [91.54319, 23.00222588], [91.54358673, 23.00358582], [91.54397583, 23.00494957], [91.5443573, 23.00625038], [91.54465485, 23.00727844], [91.54534149, 23.00960922], [91.54568481, 23.01083755], [91.54647064, 23.01356888], [91.54665375, 23.01420403], [91.54689026, 23.01504135], [91.54548645, 23.01488113], [91.54560089, 23.01519585], [91.54638672, 23.01730347], [91.54412842, 23.0178833], [91.54512787, 23.01937675], [91.54341125, 23.01937294], [91.54092407, 23.01936531], [91.53964996, 23.01935768], [91.53834534, 23.01935577], [91.53863525, 23.01977539], [91.53910828, 23.02045822], [91.53926849, 23.02074814], [91.53948212, 23.02112198], [91.54045105, 23.02247238], [91.5406189, 23.02269936], [91.54121399, 23.02356339], [91.54173279, 23.02431679], [91.5422821, 23.02511978], [91.54290771, 23.02604103], [91.5440979, 23.0281601], [91.54521179, 23.03012848], [91.54607391, 23.03155708], [91.54681396, 23.0327816], [91.54750061, 23.03392601], [91.54761505, 23.03412628], [91.5480957, 23.03493309], [91.54850006, 23.03560829], [91.54878235, 23.03608131], [91.54933929, 23.03700829], [91.55028534, 23.03854752], [91.55011749, 23.03854752], [91.54865265, 23.03855515], [91.5464325, 23.0385685], [91.54451752, 23.03857994], [91.54255676, 23.03858948], [91.5417099, 23.0385952], [91.54137421, 23.03859711], [91.54088593, 23.03855515], [91.54063416, 23.03853607], [91.53997803, 23.03852081], [91.53859711, 23.03849602], [91.53608704, 23.03847885], [91.53587341, 23.03847694], [91.53390503, 23.03846359], [91.53156281, 23.03844452], [91.53070068, 23.0384388], [91.53043365, 23.03843689], [91.53090668, 23.04018211], [91.53141022, 23.04203606], [91.53144073, 23.04213905], [91.53156281, 23.04258919], [91.53210449, 23.04390144], [91.53274536, 23.04545784], [91.53336334, 23.04694557], [91.53372955, 23.04790497], [91.53427887, 23.0494175], [91.53468323, 23.05060577], [91.53505707, 23.05158997], [91.53526306, 23.052145], [91.53529358, 23.05222893], [91.5322876, 23.05310059], [91.53131104, 23.05328369], [91.53117371, 23.05330658], [91.53011322, 23.05348015], [91.52999878, 23.05343246], [91.52857971, 23.05364037], [91.52951813, 23.05548668], [91.52913666, 23.05548859], [91.52839661, 23.05548859], [91.52757263, 23.05548859], [91.52523804, 23.05549622], [91.52490997, 23.05549812], [91.52511597, 23.05671883], [91.525177, 23.05710602], [91.52532196, 23.05780792], [91.52559662, 23.0591259], [91.52577209, 23.06013107], [91.52754974, 23.06075859], [91.52902222, 23.0612812], [91.52973175, 23.06153297], [91.53321838, 23.06276321], [91.53525543, 23.06348038], [91.53520966, 23.06357002], [91.5348587, 23.06422043], [91.53397369, 23.0658741], [91.53382874, 23.06614876], [91.53327179, 23.06719017], [91.53259277, 23.06846809], [91.53247833, 23.06869125], [91.53199768, 23.06963921], [91.53124237, 23.07113457], [91.53017426, 23.07318306], [91.52952576, 23.0744133], [91.52858734, 23.07621193], [91.52801514, 23.0772438], [91.52725983, 23.07867622], [91.5267334, 23.07969284], [91.52613831, 23.08083916], [91.5250473, 23.08296585], [91.52713013, 23.08424377], [91.52842712, 23.08502007], [91.52881622, 23.08525276], [91.52988434, 23.08590889], [91.52983856, 23.08818436], [91.52980804, 23.08934975], [91.52978516, 23.09049606], [91.5297699, 23.09117889], [91.52976227, 23.0915966], [91.52919769, 23.09170151], [91.52841949, 23.09168434], [91.5266037, 23.09219933], [91.52635956, 23.09224701], [91.52468109, 23.09269905], [91.5240097, 23.09288025], [91.52294159, 23.09316444], [91.52157593, 23.09352684], [91.52010345, 23.09391975], [91.51886749, 23.09428406], [91.51929474, 23.095438], [91.51973724, 23.09665108], [91.52047729, 23.09883118], [91.52101135, 23.10039139], [91.52152252, 23.1019001], [91.52158356, 23.10208321], [91.52133179, 23.10237122], [91.51902008, 23.10254288], [91.51756287, 23.10316277], [91.51662445, 23.10425186], [91.51564789, 23.10427284], [91.51318359, 23.10430717], [91.51293945, 23.1043129], [91.51124573, 23.10434341], [91.51148224, 23.10658073], [91.51165009, 23.10821533], [91.51168823, 23.10853386], [91.51171112, 23.10874748], [91.51194763, 23.11082649], [91.51211548, 23.11229324], [91.51223755, 23.11336708], [91.51477814, 23.11375046], [91.51620483, 23.1139679], [91.51779938, 23.11421585], [91.51844788, 23.11431503], [91.52033234, 23.11459351], [91.52023315, 23.11486435], [91.52014923, 23.1151104], [91.51944733, 23.11710739], [91.51925659, 23.11764526], [91.51917267, 23.1178894], [91.51714325, 23.11784172], [91.5162735, 23.11782074], [91.51534271, 23.11779785], [91.51530457, 23.11797523], [91.51512909, 23.11874771], [91.51507568, 23.11897087], [91.51495361, 23.11944199], [91.51464081, 23.12078094], [91.51442719, 23.1216507], [91.51419067, 23.12269211], [91.51589203, 23.12401581], [91.51486206, 23.1249218], [91.51373291, 23.12537003], [91.51174927, 23.12545013], [91.51011658, 23.12623978], [91.50971222, 23.1264801], [91.509552, 23.12662888], [91.5091629, 23.12668037], [91.50782776, 23.12685394], [91.50571442, 23.12713623], [91.50374603, 23.12739372], [91.50360107, 23.12814331], [91.50350189, 23.1286087], [91.50320435, 23.13010979], [91.50308228, 23.13063431], [91.50439453, 23.13153648], [91.5063324, 23.13287544], [91.50762939, 23.13376236], [91.50901794, 23.13472939], [91.51168823, 23.13657188], [91.51261902, 23.13720131], [91.51210022, 23.13731003], [91.50904083, 23.13796043], [91.50745392, 23.1398735], [91.50722504, 23.1398983], [91.50711823, 23.13995171], [91.5070343, 23.14003563], [91.50695801, 23.1401825], [91.50692749, 23.14033127], [91.50688171, 23.14039803], [91.50680542, 23.14043617], [91.50668335, 23.14042282], [91.50648499, 23.14033508], [91.50636292, 23.1402607], [91.50627136, 23.14023209], [91.50615692, 23.14022636], [91.50605011, 23.1402359], [91.50592041, 23.14031601], [91.50576019, 23.14039612], [91.50550079, 23.14049149], [91.50521851, 23.14056778], [91.50510406, 23.14060974], [91.50498199, 23.14061165], [91.5049057, 23.14061165], [91.50478363, 23.1405735], [91.5046463, 23.14049149], [91.50444794, 23.14045906], [91.50443268, 23.14057732], [91.50442505, 23.14066505], [91.50447083, 23.14075089], [91.50444031, 23.14084244], [91.50435638, 23.14083862], [91.50419617, 23.14073944], [91.5041275, 23.14077759], [91.50413513, 23.14088821], [91.50409698, 23.14103889], [91.50403595, 23.14118576], [91.50392151, 23.14134789], [91.50382233, 23.14144516], [91.50367737, 23.14157867], [91.50362396, 23.14166832], [91.50357056, 23.14179039], [91.50350189, 23.14188766], [91.50338745, 23.14193153], [91.50318909, 23.14201927], [91.50312042, 23.14207268], [91.50296783, 23.14217186], [91.50284576, 23.14225006], [91.50273132, 23.1423378], [91.50259399, 23.14242744], [91.5025177, 23.1424942], [91.50243378, 23.14253044], [91.50234985, 23.14256477], [91.50228119, 23.14263725], [91.50222015, 23.14273643], [91.50205231, 23.14280701], [91.50189972, 23.14289474], [91.50182343, 23.1429882], [91.50174713, 23.14307976], [91.50167084, 23.14314461], [91.50157928, 23.14320564], [91.50149536, 23.14321709], [91.5014267, 23.14315033], [91.50138855, 23.1430645], [91.501297, 23.14299011], [91.50128937, 23.14311981], [91.50125122, 23.14325142], [91.50115967, 23.14326286], [91.50107574, 23.1432457], [91.50106812, 23.14315987], [91.50105286, 23.14305878], [91.50099945, 23.14297295], [91.50089264, 23.14290237], [91.50072479, 23.14293289], [91.50050354, 23.14298248], [91.50037384, 23.14293861], [91.50026703, 23.1429081], [91.50020599, 23.14286804], [91.50011444, 23.14273834], [91.50011444, 23.14264679], [91.50010681, 23.14255333], [91.50014496, 23.14240837], [91.50016022, 23.14231682], [91.50016022, 23.14222717], [91.50010681, 23.14217377], [91.50003052, 23.14211273], [91.49987793, 23.14216805], [91.49966431, 23.14235497], [91.49945831, 23.14256096], [91.49936676, 23.14266586], [91.49926758, 23.14274979], [91.4991684, 23.14280319], [91.49894714, 23.14283943], [91.49887085, 23.1428051], [91.49879456, 23.14273643], [91.49866486, 23.14267921], [91.49869537, 23.14285088], [91.49871826, 23.14293098], [91.49874115, 23.14300346], [91.498703, 23.14311409], [91.49861908, 23.1431694], [91.4985199, 23.14330101], [91.49855042, 23.14339256], [91.4986496, 23.14346695], [91.49880219, 23.14353943], [91.49886322, 23.14361191], [91.49889374, 23.14371109], [91.49893951, 23.14382935], [91.49892426, 23.14391899], [91.49886322, 23.14397812], [91.49879456, 23.14403534], [91.498703, 23.14403725], [91.49862671, 23.14404106], [91.49852753, 23.14401627], [91.4984436, 23.14400864], [91.49833679, 23.14395905], [91.49825287, 23.14400864], [91.4982605, 23.14409447], [91.49821472, 23.14416885], [91.4981308, 23.14422417], [91.49810028, 23.14430428], [91.49804688, 23.1443882], [91.49797821, 23.14448357], [91.49795532, 23.14455414], [91.49790955, 23.14462471], [91.49782562, 23.14462852], [91.4977417, 23.14464951], [91.49767303, 23.144701], [91.49760437, 23.14478683], [91.49756622, 23.14486885], [91.49754333, 23.14496994], [91.4974823, 23.14513206], [91.49738312, 23.14526749], [91.49724579, 23.14535332], [91.4970932, 23.14544487], [91.49698639, 23.14544868], [91.49690247, 23.14542961], [91.49678802, 23.14541054], [91.49671173, 23.14541817], [91.49662781, 23.14544106], [91.49656677, 23.14548874], [91.49653625, 23.1455574], [91.496521, 23.14564133], [91.4964447, 23.14574814], [91.49634552, 23.14575005], [91.49624634, 23.14578438], [91.49626923, 23.14586258], [91.49634552, 23.14603043], [91.49637604, 23.14626694], [91.49632263, 23.14635468], [91.49627686, 23.14641571], [91.49629974, 23.14652252], [91.4963913, 23.14657974], [91.49648285, 23.14666748], [91.49642944, 23.14673996], [91.49628448, 23.14681053], [91.49610138, 23.14686775], [91.49595642, 23.1469059], [91.49580383, 23.14688683], [91.49557495, 23.14685059], [91.49538422, 23.14685822], [91.49523163, 23.14687157], [91.49516296, 23.14691162], [91.49510956, 23.14699936], [91.49503326, 23.14709854], [91.49489594, 23.14714622], [91.49468231, 23.14722252], [91.49682617, 23.14821243], [91.49838257, 23.14892769], [91.501091, 23.15017128], [91.50170898, 23.15045929], [91.50286865, 23.15100098], [91.50406647, 23.15169144], [91.50653076, 23.15312004], [91.50683594, 23.15329742], [91.50728607, 23.15356064], [91.50717926, 23.15426445], [91.507164, 23.15440559], [91.50528717, 23.15411186], [91.50384521, 23.15387154], [91.50193787, 23.15356255], [91.50121307, 23.1534462], [91.50087738, 23.1533947], [91.49991608, 23.15324211], [91.49757385, 23.15287399], [91.49628448, 23.15267181], [91.49428558, 23.15236282], [91.49398804, 23.15284538], [91.49383545, 23.15308762], [91.49324036, 23.15404129], [91.49273682, 23.15485001], [91.49227142, 23.15558243], [91.49143219, 23.15691376], [91.49088287, 23.15776253], [91.49193573, 23.15915298], [91.49256897, 23.15999603], [91.49297333, 23.16053772], [91.49324799, 23.16057396], [91.49333191, 23.16065025], [91.49333191, 23.16150093], [91.49337006, 23.16162872], [91.49349976, 23.16169548], [91.49357605, 23.16155052], [91.49370575, 23.16150475], [91.49476624, 23.16210747], [91.49503326, 23.16286278], [91.49528503, 23.16357803], [91.49620819, 23.16620636], [91.49664307, 23.16744804], [91.49697113, 23.16838264], [91.49749756, 23.16988564], [91.49812317, 23.17178726], [91.49634552, 23.17189789], [91.49611664, 23.17191315], [91.49559784, 23.17193031], [91.49398804, 23.17201233], [91.49228668, 23.17209244], [91.4921875, 23.17295074], [91.49217224, 23.17312622], [91.49208069, 23.17396927], [91.49189758, 23.17555237], [91.49180603, 23.17640686], [91.49172211, 23.17721748], [91.4916687, 23.17771149], [91.49328613, 23.17834854], [91.49462128, 23.17887115], [91.49633789, 23.17955208], [91.49687195, 23.17976379], [91.49729919, 23.17993546], [91.49846649, 23.18001938], [91.49966431, 23.18010139], [91.50081635, 23.18018341], [91.50108337, 23.18020439], [91.50130463, 23.18021965], [91.50209045, 23.18027306], [91.5029068, 23.18032646], [91.50334167, 23.18035316], [91.50346375, 23.18034363], [91.50367737, 23.18032646], [91.50408173, 23.18029404], [91.50483704, 23.180233], [91.50666809, 23.18008423], [91.50673676, 23.18041039], [91.50682831, 23.18085289], [91.50701904, 23.18182564], [91.50706482, 23.18202019], [91.50720215, 23.18265915], [91.50730896, 23.18314552], [91.50735474, 23.18334389], [91.50689697, 23.18350029], [91.50629425, 23.18414307], [91.50604248, 23.18420601], [91.50596619, 23.18422699], [91.50517273, 23.18441772], [91.50411224, 23.18467903], [91.50323486, 23.18489838], [91.50286865, 23.18498421], [91.50156403, 23.1852951], [91.50102997, 23.18541908], [91.50198364, 23.18662071], [91.50215912, 23.18683815], [91.50074768, 23.18691063], [91.49562073, 23.18731117], [91.49192047, 23.18765259], [91.49054718, 23.18700027], [91.4887085, 23.1872406], [91.48712158, 23.18760109], [91.4838562, 23.18805122], [91.48149872, 23.18587112], [91.47891235, 23.18630981], [91.47477722, 23.18839836], [91.47424316, 23.18883705], [91.47615814, 23.19251442], [91.47649384, 23.19315529], [91.47579193, 23.19356346], [91.47506714, 23.19399071], [91.47422791, 23.1944809], [91.47330475, 23.19502831], [91.47251892, 23.19548416], [91.47163391, 23.19600677], [91.4706955, 23.19655991], [91.47180939, 23.19676018], [91.47325897, 23.19701385], [91.4744873, 23.19721985], [91.47499084, 23.19730759], [91.47592163, 23.1974659], [91.4765625, 23.19757462], [91.47735596, 23.19771004], [91.47831726, 23.19787598], [91.47924805, 23.19803429], [91.48058319, 23.19826317], [91.48162079, 23.19843292], [91.4823761, 23.19856644], [91.48249817, 23.19920921], [91.48267365, 23.20017433], [91.4828949, 23.20137215], [91.48313904, 23.20269012], [91.4833374, 23.20374489], [91.48361969, 23.20530128], [91.48384857, 23.20650291], [91.48395538, 23.20708275], [91.48408508, 23.20775986], [91.48423004, 23.20851326], [91.48436737, 23.20933533], [91.48370361, 23.21012688], [91.48343658, 23.21045494], [91.4829483, 23.2110672], [91.48215485, 23.21204948], [91.4815979, 23.21273994], [91.48125458, 23.21317101], [91.48077393, 23.2137661], [91.48009491, 23.21461487], [91.47980499, 23.21497726], [91.47924805, 23.21565819], [91.47896576, 23.21600533], [91.47857666, 23.21598053], [91.47371674, 23.2143116], [91.46714783, 23.21245193], [91.46559906, 23.21239281], [91.4642868, 23.2122097], [91.46380615, 23.2128582], [91.4621582, 23.21306038], [91.46177673, 23.21405983], [91.46081543, 23.21438408], [91.46007538, 23.21407509], [91.45924377, 23.21372795], [91.45856476, 23.21344757], [91.45849609, 23.21357155], [91.45838165, 23.21367455], [91.45822906, 23.21376228], [91.45809174, 23.21386528], [91.45806122, 23.21399117], [91.45804596, 23.21417046], [91.45806122, 23.21437836], [91.45809174, 23.21459389], [91.45806122, 23.21474648], [91.45804596, 23.21490288], [91.45812988, 23.21515656], [91.45822144, 23.21536446], [91.45827484, 23.21556854], [91.45827484, 23.21567154], [91.45824432, 23.21575356], [91.45809937, 23.21584511], [91.45788574, 23.21593475], [91.45756531, 23.21601486], [91.4572525, 23.21618652], [91.45675659, 23.21644783], [91.4564209, 23.21661568], [91.45618439, 23.21673203], [91.45582581, 23.21693802], [91.45550537, 23.21708107], [91.45531464, 23.21713638], [91.4551239, 23.21724701], [91.45503235, 23.21730614], [91.45497894, 23.21736526], [91.45482635, 23.21746254], [91.45448303, 23.21749687], [91.45420074, 23.21763802], [91.45407867, 23.2176609], [91.45401001, 23.21769905], [91.45391083, 23.21772766], [91.45384216, 23.21784019], [91.45378113, 23.21797752], [91.45373535, 23.2181263], [91.4539032, 23.21821785], [91.45407104, 23.21829987], [91.45414734, 23.21840858], [91.45413208, 23.21848869], [91.45399475, 23.21853447], [91.45383453, 23.21853256], [91.45359802, 23.21850204], [91.45336914, 23.21844482], [91.45314789, 23.21841431], [91.45294952, 23.21846771], [91.45269775, 23.21852112], [91.45251465, 23.21855164], [91.45236206, 23.21862793], [91.45219421, 23.21874237], [91.45210266, 23.21885681], [91.45201874, 23.21898079], [91.45188904, 23.21907043], [91.45167542, 23.21913719], [91.45157623, 23.21917152], [91.45142365, 23.21925545], [91.45126343, 23.21931839], [91.45110321, 23.21930695], [91.45101166, 23.21926308], [91.45088196, 23.21923637], [91.45079041, 23.21928596], [91.45074463, 23.21942139], [91.45066071, 23.21949005], [91.45050049, 23.21959877], [91.45062256, 23.21985245], [91.45067596, 23.22006035], [91.45069885, 23.22028542], [91.45072174, 23.22041702], [91.45079803, 23.22045898], [91.45097351, 23.22047234], [91.45101166, 23.22060394], [91.45109558, 23.2207489], [91.4513092, 23.22087097], [91.4515152, 23.22099304], [91.45155334, 23.22110367], [91.45161438, 23.22121048], [91.4516983, 23.2212429], [91.45179749, 23.22124863], [91.45201874, 23.22120857], [91.45214844, 23.22119522], [91.45223236, 23.22114944], [91.45236969, 23.22112846], [91.45243835, 23.22115517], [91.4524765, 23.22122192], [91.45248413, 23.22130203], [91.45248413, 23.22138405], [91.45243835, 23.22146034], [91.45236969, 23.2215519], [91.45238495, 23.22162628], [91.45243835, 23.22171021], [91.45279694, 23.22167397], [91.45281219, 23.22186279], [91.45289612, 23.22204399], [91.45294952, 23.22216415], [91.45303345, 23.22220993], [91.45314026, 23.22222328], [91.45324707, 23.22226143], [91.45333099, 23.22234917], [91.45336151, 23.22258949], [91.45327759, 23.22269058], [91.45304108, 23.22265244], [91.45294189, 23.22268867], [91.45294189, 23.22279167], [91.45304108, 23.22301483], [91.453125, 23.2231884], [91.45320129, 23.2232914], [91.45339966, 23.22336197], [91.45357513, 23.22340202], [91.45383453, 23.22344589], [91.45393372, 23.22350502], [91.45400238, 23.2235775], [91.45418549, 23.22350883], [91.45426941, 23.22365952], [91.45510101, 23.22387314], [91.45635986, 23.2242012], [91.45857239, 23.22477341], [91.46041107, 23.22525024], [91.46279144, 23.22586823], [91.46372223, 23.22610283], [91.46564484, 23.22659683], [91.46794128, 23.2271862], [91.47024536, 23.22777748], [91.46952057, 23.22891045], [91.46820831, 23.23095894], [91.46721649, 23.23252106], [91.46589661, 23.23458481], [91.46473694, 23.23639679], [91.46338654, 23.23851204], [91.46247864, 23.23999977], [91.46193695, 23.23999214], [91.46115112, 23.24117088], [91.46045685, 23.24220848], [91.46031952, 23.24241447], [91.45825958, 23.24258995], [91.45670319, 23.24200821], [91.45574951, 23.24165916], [91.45372009, 23.24197006], [91.45168304, 23.2434597], [91.45184326, 23.24463654], [91.45137787, 23.244524], [91.45069885, 23.24429512], [91.45011139, 23.24418449], [91.44911194, 23.24399567], [91.44853973, 23.24388695], [91.44885254, 23.24459839], [91.45362091, 23.25566864], [91.45393372, 23.25640106], [91.45204926, 23.25665092], [91.4434433, 23.25810051], [91.43660736, 23.25842094], [91.43260956, 23.2583847], [91.42917633, 23.25835419], [91.42861176, 23.25834846], [91.4263382, 23.25832939], [91.42504883, 23.25700951], [91.42368317, 23.25502014], [91.42177582, 23.2572403], [91.42201233, 23.25972939], [91.42201996, 23.26138115], [91.42113495, 23.26192856], [91.42095184, 23.26152229], [91.42062378, 23.26079559], [91.41982269, 23.25902557], [91.41941833, 23.25806236], [91.41877747, 23.25654602], [91.41837311, 23.25558662], [91.41825104, 23.25561142], [91.41834259, 23.25580978], [91.41842651, 23.25593948], [91.41849518, 23.25606346], [91.41844177, 23.25624657], [91.41825104, 23.25641632], [91.41821289, 23.25650978], [91.41825867, 23.25662613], [91.41833496, 23.25679398], [91.418396, 23.25697899], [91.41838074, 23.25713348], [91.41831207, 23.25728989], [91.41825104, 23.25732803], [91.41814423, 23.25735474], [91.41801453, 23.25741768], [91.41832733, 23.25759125], [91.41838837, 23.25766945], [91.41851044, 23.25792122], [91.41867828, 23.25837517], [91.41863251, 23.25849724], [91.41849518, 23.25862503], [91.418396, 23.25862312], [91.41832733, 23.25859261], [91.41816711, 23.25846863], [91.41809082, 23.25842857], [91.41798401, 23.25843811], [91.41798401, 23.25855064], [91.41809082, 23.25857162], [91.41816711, 23.25862694], [91.41822815, 23.25882912], [91.41808319, 23.25888062], [91.41797638, 23.25893211], [91.41797638, 23.25906563], [91.41808319, 23.25916672], [91.41796875, 23.25926399], [91.41796875, 23.2593441], [91.41782379, 23.25949669], [91.41772461, 23.2596283], [91.4176712, 23.25970459], [91.41765594, 23.25991631], [91.41756439, 23.26008415], [91.41732025, 23.26005936], [91.4169693, 23.25994682], [91.41685486, 23.2599144], [91.41677094, 23.25993919], [91.41673279, 23.26015282], [91.41670227, 23.26049805], [91.41664124, 23.26075363], [91.41655731, 23.26080322], [91.41639709, 23.26080322], [91.41632843, 23.26082993], [91.41628265, 23.26088905], [91.41624451, 23.26102066], [91.41624451, 23.26132393], [91.41621399, 23.26153564], [91.41616821, 23.26161194], [91.41607666, 23.26167107], [91.41597748, 23.26167297], [91.41569519, 23.26173019], [91.41566467, 23.26183701], [91.41578674, 23.26198959], [91.41581726, 23.26206017], [91.41576385, 23.26227379], [91.4158783, 23.26235008], [91.41609955, 23.26229477], [91.41622925, 23.26231194], [91.41635132, 23.26238441], [91.41640472, 23.26247787], [91.41623688, 23.26270294], [91.41600037, 23.26275444], [91.41584015, 23.2626915], [91.41567993, 23.26263046], [91.41557312, 23.26271057], [91.41564178, 23.26302528], [91.41580963, 23.26311493], [91.4158783, 23.26319885], [91.41582489, 23.26334572], [91.41565704, 23.26343727], [91.41557312, 23.26346016], [91.41535187, 23.26348495], [91.41543579, 23.2635746], [91.41592407, 23.2637558], [91.4162674, 23.26395798], [91.41636658, 23.26405525], [91.41639709, 23.26413727], [91.41629791, 23.26428413], [91.41629028, 23.264431], [91.41638947, 23.26453972], [91.41638947, 23.26462746], [91.41635132, 23.26477051], [91.41635895, 23.26490211], [91.41638947, 23.26498413], [91.41648102, 23.26506805], [91.41659546, 23.26480293], [91.41662598, 23.26471901], [91.41675568, 23.26464081], [91.41717529, 23.26452637], [91.41737366, 23.26462364], [91.41735077, 23.26471901], [91.41723633, 23.26485252], [91.41725922, 23.26494789], [91.41720581, 23.26502037], [91.41713715, 23.26504707], [91.41693115, 23.26498795], [91.41685486, 23.26505852], [91.4168396, 23.26513672], [91.41690063, 23.26561737], [91.41687012, 23.26581192], [91.41682434, 23.26599884], [91.4167099, 23.26616478], [91.4165802, 23.2662735], [91.41649628, 23.26641273], [91.41649628, 23.26654434], [91.41632843, 23.26691246], [91.41673279, 23.26664734], [91.41684723, 23.26658249], [91.41706848, 23.26655388], [91.41710663, 23.26667595], [91.41710663, 23.26680183], [91.41702271, 23.26700783], [91.41693878, 23.26712608], [91.41684723, 23.26721954], [91.41690063, 23.26744461], [91.41692352, 23.2677803], [91.41690826, 23.26800728], [91.41686249, 23.2682724], [91.41678619, 23.26835632], [91.41653442, 23.2685585], [91.4164505, 23.26872826], [91.41652679, 23.26886749], [91.41647339, 23.26893997], [91.41629791, 23.26911354], [91.41590118, 23.26949692], [91.41589355, 23.26962471], [91.41599274, 23.26966286], [91.41646576, 23.26927567], [91.41656494, 23.26923943], [91.41668701, 23.2692585], [91.41674805, 23.26938057], [91.41684723, 23.26952171], [91.41698456, 23.2695694], [91.41740417, 23.26963425], [91.4176712, 23.26964378], [91.41783142, 23.26965332], [91.4179306, 23.26965904], [91.41808319, 23.2697258], [91.41815948, 23.26980972], [91.41818237, 23.26998711], [91.41814423, 23.27024078], [91.41815948, 23.27056885], [91.41821289, 23.27067566], [91.41843414, 23.27095604], [91.41864777, 23.27127457], [91.41867065, 23.27136993], [91.41867065, 23.27147865], [91.41864014, 23.27166557], [91.41860199, 23.27182007], [91.41863251, 23.27200508], [91.41867828, 23.27215767], [91.41872406, 23.27230453], [91.41876984, 23.27237511], [91.41893005, 23.27235413], [91.41915131, 23.27235031], [91.41934204, 23.27252007], [91.41951752, 23.27274704], [91.41954041, 23.27289009], [91.41954803, 23.27305222], [91.41951752, 23.27342987], [91.41928101, 23.27363968], [91.41919708, 23.27367592], [91.41910553, 23.27374649], [91.41900635, 23.27380562], [91.41889191, 23.27380753], [91.41882324, 23.27383041], [91.41875458, 23.27394295], [91.41873932, 23.27407837], [91.41869354, 23.27425766], [91.4185791, 23.27427292], [91.4184494, 23.27429008], [91.41835785, 23.27431488], [91.41837311, 23.27442932], [91.41841125, 23.27474976], [91.41841888, 23.27483368], [91.41820526, 23.27487946], [91.41810608, 23.27487564], [91.41799164, 23.2748642], [91.41782379, 23.27482796], [91.41766357, 23.27485657], [91.4176712, 23.2749691], [91.41770172, 23.27505875], [91.41775513, 23.27523804], [91.4177475, 23.27534294], [91.41742706, 23.27530479], [91.41732788, 23.27537155], [91.41732025, 23.27546501], [91.41733551, 23.27560234], [91.41739655, 23.27569199], [91.41746521, 23.27581978], [91.41753387, 23.27586937], [91.41759491, 23.27592659], [91.4176712, 23.27598763], [91.4178009, 23.27611351], [91.41782379, 23.27619934], [91.4178009, 23.27627373], [91.4177475, 23.27632904], [91.41764069, 23.27632141], [91.41741943, 23.27627182], [91.41730499, 23.27622986], [91.41721344, 23.27620125], [91.41707611, 23.27614784], [91.41700745, 23.2761116], [91.41693115, 23.27599525], [91.41687012, 23.2759285], [91.41682434, 23.27584267], [91.41670227, 23.27578735], [91.41655731, 23.27579117], [91.41670227, 23.27590752], [91.41675568, 23.27607918], [91.41679382, 23.27624893], [91.41682434, 23.27646255], [91.41683197, 23.27661705], [91.41687775, 23.27683258], [91.41697693, 23.27684975], [91.4172287, 23.2768364], [91.41728973, 23.27689362], [91.41734314, 23.27713203], [91.41733551, 23.27723694], [91.41761017, 23.27731705], [91.4176712, 23.27736092], [91.41755676, 23.27752304], [91.41728973, 23.2776432], [91.41706848, 23.27774811], [91.41713715, 23.27788734], [91.41717529, 23.27811813], [91.41710663, 23.27832603], [91.41699982, 23.27851295], [91.41693878, 23.27857971], [91.41665649, 23.27864647], [91.4165802, 23.27872276], [91.4165802, 23.27882576], [91.41661835, 23.27893066], [91.41671753, 23.27913094], [91.4167099, 23.27924538], [91.41665649, 23.27931786], [91.4165802, 23.27933311], [91.41638947, 23.27925682], [91.4163208, 23.27931023], [91.41636658, 23.27941132], [91.41635895, 23.27952766], [91.41630554, 23.27963829], [91.41624451, 23.27972221], [91.41611481, 23.27975273], [91.416008, 23.27970123], [91.41595459, 23.2796402], [91.41599274, 23.27951622], [91.41600037, 23.27943039], [91.41594696, 23.27932549], [91.41578674, 23.27930069], [91.41561127, 23.27937508], [91.41553497, 23.27943993], [91.41548157, 23.27961731], [91.41543579, 23.27975273], [91.41544342, 23.27986336], [91.41546631, 23.27993965], [91.41547394, 23.28002357], [91.41546631, 23.28011513], [91.4154129, 23.28022766], [91.41536713, 23.28038216], [91.41534424, 23.2804966], [91.41534424, 23.28059387], [91.41537476, 23.28073502], [91.41545868, 23.28103065], [91.41558838, 23.28147316], [91.41552734, 23.28162193], [91.41542816, 23.28169823], [91.41535187, 23.2817955], [91.41530609, 23.28190804], [91.41523743, 23.28205109], [91.41526031, 23.28212929], [91.41532135, 23.28218842], [91.41545105, 23.28227806], [91.41558838, 23.28236198], [91.41560364, 23.28243256], [91.41559601, 23.28251457], [91.41556549, 23.28263664], [91.41556549, 23.28273582], [91.41559601, 23.28281403], [91.41559601, 23.28289986], [91.41552734, 23.28292465], [91.41531372, 23.28283119], [91.41522217, 23.28274345], [91.41510773, 23.28264236], [91.4149704, 23.28255463], [91.4145813, 23.28247833], [91.41448975, 23.28242874], [91.41428375, 23.28224564], [91.41416931, 23.28212166], [91.41398621, 23.28186798], [91.4139328, 23.28175926], [91.41399384, 23.28165245], [91.41409302, 23.28156281], [91.41410828, 23.28146553], [91.41402435, 23.2814312], [91.41390991, 23.28142738], [91.41370392, 23.28149033], [91.4134903, 23.28157997], [91.4133606, 23.28162575], [91.41330719, 23.28170776], [91.41329193, 23.28185272], [91.41327667, 23.28201103], [91.41320801, 23.28217888], [91.41313171, 23.28230858], [91.41308594, 23.28248787], [91.41307831, 23.28262711], [91.41304016, 23.28285408], [91.41294098, 23.28286934], [91.41283417, 23.28285027], [91.41273499, 23.28296661], [91.41264343, 23.28307343], [91.41254425, 23.28312302], [91.41246033, 23.28308868], [91.41236877, 23.28300095], [91.412323, 23.28287888], [91.41226196, 23.28268623], [91.41213989, 23.28265572], [91.41208649, 23.28271484], [91.41203308, 23.28289413], [91.4119339, 23.28310013], [91.41182709, 23.28329849], [91.41170502, 23.2834568], [91.41159058, 23.28360176], [91.41155243, 23.28368378], [91.41156769, 23.28377342], [91.41158295, 23.28396606], [91.41149902, 23.2841053], [91.41138458, 23.28420258], [91.41129303, 23.28424644], [91.41106415, 23.2842083], [91.41098022, 23.28420639], [91.41075134, 23.28424072], [91.4106369, 23.28419685], [91.41049957, 23.28413963], [91.4103775, 23.28412247], [91.41026306, 23.28415298], [91.4102478, 23.28425407], [91.41018677, 23.28441238], [91.41001892, 23.28460693], [91.40992737, 23.28463173], [91.40983582, 23.28460312], [91.40973663, 23.2845211], [91.40963745, 23.2844162], [91.40953827, 23.28437042], [91.40933228, 23.28434753], [91.40927124, 23.28438568], [91.40925598, 23.28452873], [91.4092865, 23.28464127], [91.40929413, 23.28473663], [91.4092865, 23.28483772], [91.40924835, 23.28491402], [91.40917206, 23.28507805], [91.40908051, 23.28518677], [91.40896606, 23.28528023], [91.40883636, 23.28532219], [91.40885162, 23.28505516], [91.40885925, 23.28475952], [91.40890503, 23.28373909], [91.40897369, 23.28247452], [91.40908051, 23.28048897], [91.40911102, 23.27989197], [91.40914154, 23.2793026], [91.40920258, 23.27812576], [91.40924835, 23.27714729], [91.40930939, 23.275877], [91.40934753, 23.27500725], [91.40938568, 23.27428436], [91.40940857, 23.27386665], [91.40946198, 23.27289391], [91.40956116, 23.27149582], [91.40962219, 23.27085304], [91.40975952, 23.26953888], [91.4098587, 23.26857948], [91.40994263, 23.26774216], [91.41009521, 23.26638222], [91.41021729, 23.26526642], [91.41026306, 23.26483154], [91.41033936, 23.26412392], [91.41046143, 23.26298904], [91.41047668, 23.26285362], [91.41055298, 23.26213837], [91.4105835, 23.26184273], [91.41069031, 23.26086044], [91.41077423, 23.26007462], [91.41087341, 23.25945282], [91.4109726, 23.25856972], [91.41107941, 23.25751495], [91.41118622, 23.25644302], [91.41123199, 23.25581551], [91.4101181, 23.25597954], [91.40969086, 23.25597191], [91.40849304, 23.25609589], [91.4077301, 23.25617409], [91.40770721, 23.25398064], [91.40770721, 23.25356293], [91.40849304, 23.25276947], [91.40908813, 23.25217247], [91.41104889, 23.25020981], [91.41316223, 23.24880981], [91.4156723, 23.24488258], [91.41485596, 23.24458885], [91.40725708, 23.24283028], [91.40303802, 23.23771095], [91.4061203, 23.23182106], [91.40647125, 23.23115921], [91.40400696, 23.22616005], [91.39582062, 23.22344017], [91.39697266, 23.2186203], [91.39691925, 23.21813202], [91.39678955, 23.21810913], [91.39658356, 23.21805191], [91.39641571, 23.21805382], [91.39630127, 23.21805573], [91.39617157, 23.21805763], [91.39602661, 23.21804428], [91.39585114, 23.21804619], [91.39569092, 23.2180481], [91.39555359, 23.21800613], [91.39539337, 23.21796608], [91.39527893, 23.21793747], [91.39514923, 23.21786499], [91.39501953, 23.21779442], [91.39488983, 23.21772194], [91.39479828, 23.21764946], [91.3946991, 23.21757889], [91.39461517, 23.21751976], [91.39456177, 23.21744728], [91.39450836, 23.21736145], [91.39443207, 23.21730232], [91.39437103, 23.21721649], [91.39428711, 23.21712875], [91.39415741, 23.21713829], [91.39412689, 23.2170639], [91.39380646, 23.21706581], [91.39341736, 23.21704674], [91.39331818, 23.21693039], [91.39292908, 23.21698189], [91.39272308, 23.21680641], [91.39257813, 23.21679497], [91.39233398, 23.21684837], [91.39212799, 23.2169323], [91.39192963, 23.21701813], [91.39176941, 23.21708298], [91.39146423, 23.21718597], [91.39110565, 23.21730614], [91.39072418, 23.21747017], [91.39026642, 23.21767044], [91.38962555, 23.21679115], [91.38894653, 23.21582222], [91.38851929, 23.21522903], [91.38822937, 23.21481895], [91.38742828, 23.21419907], [91.38668823, 23.21359253], [91.38542175, 23.2125206], [91.38452148, 23.2117672], [91.38386536, 23.21121788], [91.38301849, 23.21051407], [91.38227844, 23.20989227], [91.38134003, 23.20910835], [91.38069916, 23.20856667], [91.38204956, 23.20846176], [91.38341522, 23.20835686], [91.38462067, 23.2082653], [91.38503265, 23.20823479], [91.38587189, 23.20816803], [91.38645172, 23.20812416], [91.38768005, 23.20802307], [91.38761902, 23.20740891], [91.38755798, 23.20685005], [91.38748169, 23.20633125], [91.38742065, 23.20591927], [91.38726044, 23.204813], [91.38718414, 23.20423889], [91.38702393, 23.20310974], [91.38690948, 23.20223427], [91.38671875, 23.20100212], [91.38657379, 23.19998169], [91.38648987, 23.19936371], [91.3862915, 23.19791031], [91.3861618, 23.19721603], [91.38602448, 23.19626236], [91.38587189, 23.19507599], [91.38582611, 23.19470596], [91.38570404, 23.19360352], [91.38562012, 23.19303513], [91.38547516, 23.19198227], [91.38497162, 23.19195175], [91.38399506, 23.19189644], [91.38291931, 23.1918354], [91.38202667, 23.19178581], [91.38156128, 23.19176292], [91.38092041, 23.19173622], [91.3808136, 23.19111443], [91.38064575, 23.19005394], [91.38040924, 23.18859863], [91.38030243, 23.1879406], [91.38014984, 23.18673515], [91.38001251, 23.18569946], [91.37989044, 23.18476295], [91.37986755, 23.18461227], [91.38063049, 23.18470764], [91.38082886, 23.18473625], [91.38116455, 23.18478584], [91.38150787, 23.18479156], [91.38225555, 23.18471146], [91.38295746, 23.18462944], [91.38282776, 23.18379021], [91.38265228, 23.18239784], [91.38252258, 23.18141937], [91.38237762, 23.18045235], [91.3822403, 23.17939758], [91.3821106, 23.17815018], [91.38202667, 23.17731094], [91.38191223, 23.17602921], [91.3818512, 23.17536736], [91.38183594, 23.17515182], [91.38265991, 23.17520714], [91.38362122, 23.17525864], [91.38385773, 23.17527008], [91.38454437, 23.17530823], [91.38516998, 23.17534065], [91.38515472, 23.17517662], [91.38541412, 23.17514038], [91.38576508, 23.17507172], [91.38595581, 23.17505455], [91.38608551, 23.1751194], [91.38631439, 23.17513275], [91.38658905, 23.1751442], [91.38676453, 23.17513275], [91.38690186, 23.17515373], [91.38723755, 23.1751461], [91.38739777, 23.17515373], [91.38762665, 23.17516708], [91.38777161, 23.17525482], [91.38793182, 23.1752243], [91.38803101, 23.1752243], [91.38825989, 23.17526817], [91.38841248, 23.17529678], [91.38857269, 23.17529678], [91.38869476, 23.17532539], [91.38884735, 23.175354], [91.38918304, 23.17542839], [91.389328, 23.17548561], [91.38945007, 23.17555809], [91.38956451, 23.17557144], [91.3897171, 23.17564583], [91.3898468, 23.17570114], [91.38999939, 23.17577553], [91.39012909, 23.17584801], [91.39030457, 23.17596436], [91.39035797, 23.17510986], [91.39293671, 23.16765022], [91.39084625, 23.15761948], [91.39089203, 23.15728951], [91.39147186, 23.15258026], [91.39157104, 23.15246201], [91.39319611, 23.15057945], [91.39435577, 23.14998055], [91.39583588, 23.14752007], [91.39595032, 23.1471653], [91.39599609, 23.14702988], [91.39597321, 23.14686012], [91.39595032, 23.14674187], [91.39595795, 23.14654922], [91.39595032, 23.14635468], [91.39593506, 23.1462059], [91.39593506, 23.14602852], [91.39592743, 23.14581871], [91.39593506, 23.1457119], [91.39592743, 23.14553452], [91.39592743, 23.14542961], [91.39593506, 23.14532471], [91.39592743, 23.14515877], [91.39590454, 23.14495277], [91.39591217, 23.14484024], [91.39594269, 23.14470291], [91.39598846, 23.1445694], [91.39605713, 23.14440918], [91.39612579, 23.14424706], [91.39617157, 23.14409256], [91.3962326, 23.14386177], [91.39627838, 23.143713], [91.3963089, 23.14341545], [91.39631653, 23.14320564], [91.39631653, 23.14304352], [91.3963089, 23.14289474], [91.39628601, 23.14274597], [91.39628601, 23.14258194], [91.3962326, 23.14246559], [91.39611053, 23.14221764], [91.3960495, 23.14208794], [91.39600372, 23.14198494], [91.39595032, 23.1418972], [91.39588928, 23.14178085], [91.39584351, 23.14165115], [91.39579773, 23.14151955], [91.39576721, 23.14137268], [91.39576721, 23.14125443], [91.39576721, 23.14112091], [91.39577484, 23.14101791], [91.39577484, 23.14091492], [91.39577484, 23.14081192], [91.39582062, 23.14069176], [91.39585876, 23.14058685], [91.39591217, 23.14049721], [91.39595795, 23.14036369], [91.39600372, 23.14024353], [91.3960495, 23.14015388], [91.39610291, 23.14002037], [91.39619446, 23.13995743], [91.39632416, 23.13990974], [91.396492, 23.13985825], [91.39659882, 23.13982391], [91.39678955, 23.13976097], [91.39690399, 23.13977432], [91.39707184, 23.1397953], [91.39723206, 23.13978767], [91.39733887, 23.13978386], [91.39746094, 23.13978004], [91.39759064, 23.13979149], [91.39771271, 23.13980103], [91.39783478, 23.1397953], [91.39794159, 23.13982201], [91.3980484, 23.13984871], [91.39820862, 23.13988686], [91.39839935, 23.139925], [91.39861298, 23.1399765], [91.40119171, 23.13519096], [91.40310669, 23.12914276], [91.40325928, 23.12522125], [91.40349579, 23.11904144], [91.40380859, 23.11798096], [91.40503693, 23.11590004], [91.40541077, 23.11528969], [91.40666962, 23.11401939], [91.40748596, 23.11318016], [91.4088974, 23.11007118], [91.40999603, 23.10680962], [91.4090271, 23.10445976], [91.40930176, 23.10386276], [91.40805817, 23.09511948], [91.40801239, 23.09473038], [91.40821075, 23.09469032], [91.40943909, 23.09449959], [91.41240692, 23.09477806], [91.41297913, 23.09357071], [91.41216278, 23.09166908], [91.41284943, 23.09115982], [91.4125061, 23.08657074], [91.41226196, 23.08337021], [91.41283417, 23.08284187], [91.41291809, 23.08282852], [91.41326904, 23.08277512], [91.41339111, 23.08275604], [91.41426849, 23.08262062], [91.41439056, 23.08256912], [91.41477966, 23.08260918], [91.41497803, 23.08265495], [91.41523743, 23.08278084], [91.41532135, 23.08288956], [91.41539764, 23.08309174], [91.41545105, 23.08314705], [91.41558838, 23.0831852], [91.41637421, 23.08308792], [91.41652679, 23.08288383], [91.41659546, 23.08284378], [91.4168396, 23.08305359], [91.41725159, 23.0830307], [91.41741943, 23.08299255], [91.41748047, 23.08275986], [91.41744995, 23.0826683], [91.41752625, 23.08252144], [91.4171524, 23.08213234], [91.41648865, 23.08161545], [91.41630554, 23.08114243], [91.41625977, 23.08067703], [91.4162674, 23.08058548], [91.41629028, 23.0802803], [91.41635895, 23.07938576], [91.41633606, 23.07913971], [91.41624451, 23.07879448], [91.41608429, 23.07854843], [91.41592407, 23.07831192], [91.41584015, 23.07788658], [91.41592407, 23.0776844], [91.41606903, 23.07754326], [91.41612244, 23.07738876], [91.41616058, 23.07715225], [91.41615295, 23.07702446], [91.41610718, 23.07678604], [91.41604614, 23.07665634], [91.41477966, 23.07643509], [91.41370392, 23.07619095], [91.41349792, 23.07601929], [91.41332245, 23.07559586], [91.41332245, 23.07529449], [91.41344452, 23.07504845], [91.41364288, 23.07497215], [91.41363525, 23.07483101], [91.4134903, 23.07344627], [91.41339111, 23.07249451], [91.41324615, 23.0710392], [91.41312408, 23.06988525], [91.41313171, 23.06966019], [91.4127655, 23.06951523], [91.41265106, 23.06907845], [91.41259003, 23.06863213], [91.41229248, 23.06818008], [91.41186523, 23.06770325], [91.41130829, 23.06706238], [91.41114807, 23.06692505], [91.41101074, 23.06673431], [91.41082001, 23.06642723], [91.41079712, 23.06617928], [91.4108429, 23.06607819], [91.41108704, 23.06588364], [91.41196442, 23.06558037], [91.41282654, 23.06557655], [91.41290283, 23.06556129], [91.41372681, 23.06539154], [91.41421509, 23.06527138], [91.41467285, 23.06516075], [91.4152832, 23.06505585], [91.41578674, 23.06515312], [91.41639709, 23.06527138], [91.41687012, 23.06523895], [91.41716766, 23.06515694], [91.41731262, 23.06499672], [91.41716003, 23.06470108], [91.41681671, 23.06440544], [91.41657257, 23.06409264], [91.41674805, 23.06395912], [91.41689301, 23.0638752], [91.41699982, 23.06380081], [91.41707611, 23.06372452], [91.41727448, 23.06363487], [91.41738892, 23.06356621], [91.41754913, 23.06347847], [91.41773987, 23.0633812], [91.41783905, 23.06332779], [91.41796875, 23.06326866], [91.41807556, 23.0632], [91.41822815, 23.06317139], [91.418396, 23.06308937], [91.41848755, 23.06310844], [91.41866302, 23.06310081], [91.41876984, 23.063097], [91.41893768, 23.0631237], [91.41909027, 23.06310654], [91.41989136, 23.0614109], [91.42199707, 23.05924988], [91.41765594, 23.05561066], [91.41246796, 23.05408287], [91.41255951, 23.05440903], [91.41262817, 23.0545845], [91.41268158, 23.05473328], [91.41270447, 23.05483246], [91.41273499, 23.05498505], [91.4127121, 23.05508614], [91.41270447, 23.05537415], [91.41272736, 23.0555439], [91.41262054, 23.05565643], [91.41259003, 23.05574036], [91.41259766, 23.05593681], [91.41262817, 23.05611801], [91.41260529, 23.0562706], [91.4125824, 23.05639648], [91.41256714, 23.05650711], [91.41255188, 23.056633], [91.41253662, 23.05677032], [91.4125061, 23.05687904], [91.41255188, 23.05706406], [91.41246033, 23.05714607], [91.41235352, 23.05714607], [91.41197205, 23.05723381], [91.4118042, 23.05729294], [91.41171265, 23.05731392], [91.41156769, 23.0573597], [91.41146088, 23.05740929], [91.41134644, 23.05745506], [91.41121674, 23.0575161], [91.41111755, 23.05761909], [91.41103363, 23.0577507], [91.41099548, 23.05788612], [91.41091919, 23.05810547], [91.41087341, 23.05825043], [91.41085052, 23.05841827], [91.41085052, 23.05853844], [91.41085815, 23.05865669], [91.41086578, 23.05879784], [91.41086578, 23.05887985], [91.41086578, 23.05906868], [91.41087341, 23.05924225], [91.41088104, 23.05933571], [91.41088867, 23.05951309], [91.41092682, 23.05962563], [91.41095734, 23.05978394], [91.41098022, 23.05985832], [91.41101837, 23.0600071], [91.41107178, 23.06012535], [91.41110992, 23.06024551], [91.41114044, 23.06038094], [91.41116333, 23.06046104], [91.4111557, 23.06055832], [91.41120911, 23.06072807], [91.41123199, 23.06098557], [91.41125488, 23.06110764], [91.41127014, 23.06122589], [91.41127777, 23.06133842], [91.41130066, 23.06149483], [91.41127014, 23.06168365], [91.41077423, 23.06125259], [91.41059113, 23.06119728], [91.41055298, 23.06095695], [91.4098053, 23.06072617], [91.40930939, 23.06044006], [91.40908813, 23.06035423], [91.40883636, 23.0603447], [91.40864563, 23.06018066], [91.40853882, 23.06011772], [91.40837097, 23.06010246], [91.4074707, 23.06008911], [91.40699005, 23.06008148], [91.40686798, 23.05998611], [91.40677643, 23.05984497], [91.40673065, 23.05978394], [91.40652466, 23.05947113], [91.40628052, 23.05936241], [91.40626526, 23.0591259], [91.40557098, 23.05913353], [91.40501404, 23.05908775], [91.4046936, 23.05880547], [91.40459442, 23.05875397], [91.4036026, 23.05924606], [91.40306091, 23.05916023], [91.40260315, 23.05870247], [91.40229797, 23.05848312], [91.40196228, 23.05846596], [91.40170288, 23.05841255], [91.40110779, 23.05831146], [91.40093231, 23.05857849], [91.40068817, 23.05853081], [91.40059662, 23.05854607], [91.40049744, 23.05852699], [91.40024567, 23.05854797], [91.40006256, 23.0585537], [91.39961243, 23.05856323], [91.39918518, 23.05857086], [91.39899445, 23.0575428], [91.39867401, 23.05664635], [91.39855194, 23.05661774], [91.39833832, 23.05665779], [91.39811707, 23.05654716], [91.39779663, 23.05646133], [91.39772034, 23.05640984], [91.39712524, 23.05637169], [91.3970108, 23.05626869], [91.39664459, 23.05614281], [91.39651489, 23.05625916], [91.39581299, 23.05620384], [91.39573669, 23.0562973], [91.39559174, 23.05638885], [91.39508057, 23.05673027], [91.39429474, 23.05724716], [91.3931427, 23.05800819], [91.39152527, 23.05918312], [91.3903656, 23.06002045], [91.38977051, 23.06005669], [91.38909912, 23.06044579], [91.3878479, 23.06116486], [91.38764191, 23.06128502], [91.38695526, 23.06167984], [91.38613129, 23.06215858], [91.38491821, 23.0628624], [91.38414001, 23.06328583], [91.38341522, 23.06367493], [91.38249207, 23.06416321], [91.38154602, 23.06466484], [91.3809433, 23.06498528], [91.38027954, 23.06533432], [91.3793335, 23.06583023], [91.37911987, 23.06594467], [91.37856293, 23.06624222], [91.37840271, 23.06636429], [91.3781662, 23.0665493], [91.37786102, 23.06674576], [91.37750244, 23.06678581], [91.37671661, 23.06687355], [91.37604523, 23.06720734], [91.37535095, 23.06757164], [91.37485504, 23.06782341], [91.37425995, 23.06813049], [91.37362671, 23.06845665], [91.37307739, 23.06877518], [91.37272644, 23.06895447], [91.37232971, 23.06916237], [91.3719635, 23.06935692], [91.37189484, 23.06939507], [91.37168121, 23.06951141], [91.37146759, 23.06965446], [91.37078094, 23.07004166], [91.37032318, 23.07027245], [91.36972046, 23.07052231], [91.36936188, 23.07107735], [91.36858368, 23.07226563], [91.36804962, 23.07308006], [91.36773682, 23.07355118], [91.36668396, 23.07509613], [91.36601257, 23.0761013], [91.36497498, 23.07761574], [91.36450195, 23.07831192], [91.36391449, 23.07917976], [91.3634491, 23.07986259], [91.36281586, 23.08077812], [91.3620224, 23.08194351], [91.36058044, 23.0840435], [91.35929871, 23.08591652], [91.35835266, 23.08731651], [91.35810852, 23.08778381], [91.35749817, 23.08868027], [91.35696411, 23.08946228], [91.35626221, 23.09055138], [91.35532379, 23.09192467], [91.35460663, 23.09298515], [91.35398865, 23.09391403], [91.35346222, 23.09469032], [91.35284424, 23.09561348], [91.35233307, 23.09636688], [91.3514328, 23.09770203], [91.35009766, 23.09912491], [91.34885406, 23.10045052], [91.34838867, 23.10094833], [91.34731293, 23.10207939], [91.3471756, 23.10221291], [91.3469162, 23.10245895], [91.3469696, 23.10420799], [91.34700012, 23.10530663], [91.34703827, 23.10671616], [91.34707642, 23.10786629], [91.3470993, 23.10853958], [91.34711456, 23.10906982], [91.34712982, 23.10949707], [91.34716034, 23.11022568], [91.34718323, 23.11117744], [91.34716797, 23.11185646], [91.34719086, 23.11287308], [91.34725952, 23.11418343], [91.34729767, 23.11555099], [91.347435, 23.11674309], [91.34745026, 23.11688232], [91.34742737, 23.11714935], [91.3475647, 23.11893082], [91.34729004, 23.11888695], [91.3467865, 23.11880875], [91.34558105, 23.11860085], [91.34410095, 23.11834335], [91.34277344, 23.11811829], [91.3418045, 23.11795807], [91.34168243, 23.11849022], [91.34169006, 23.1195488], [91.34169006, 23.12037659], [91.34169769, 23.12183952], [91.34170532, 23.12355614], [91.34172821, 23.12494278], [91.34171295, 23.12590599], [91.34168243, 23.12764168], [91.34165955, 23.12889481], [91.34081268, 23.12931442], [91.33933258, 23.13004684], [91.33823395, 23.13059235], [91.33701324, 23.13120079], [91.33681488, 23.13220978], [91.33647919, 23.13388443], [91.33613586, 23.13586807], [91.33575439, 23.13801765], [91.33551788, 23.13934135], [91.33506012, 23.14149857], [91.33477783, 23.14352226], [91.3345108, 23.1449852], [91.33428955, 23.14617538], [91.33424377, 23.14640617], [91.33409882, 23.14713669], [91.33383179, 23.14866638], [91.33363342, 23.14978409], [91.33348083, 23.15061188], [91.33329773, 23.15166473], [91.33305359, 23.15301704], [91.33158875, 23.15387535], [91.33041382, 23.15450287], [91.32901001, 23.15525055], [91.32810974, 23.15572357], [91.32720184, 23.15619278], [91.32609558, 23.15682411], [91.32492065, 23.15741348], [91.32331848, 23.15822029], [91.32413483, 23.16007042], [91.32419586, 23.16139984], [91.32426453, 23.16266441], [91.3243103, 23.16339302], [91.32432556, 23.16363907], [91.32437134, 23.16434669], [91.32445526, 23.1656456], [91.32453918, 23.16688156], [91.32459259, 23.16766739], [91.32466888, 23.16877556], [91.32463074, 23.16971779], [91.32459259, 23.17136383], [91.32456207, 23.17237473], [91.32452393, 23.17372131], [91.32443237, 23.17609978], [91.32436371, 23.17799187], [91.32433319, 23.17885208], [91.32427216, 23.18103409], [91.32418823, 23.18336868], [91.32411957, 23.18516541], [91.32406616, 23.18669128], [91.32400513, 23.1883297], [91.32394409, 23.19017601], [91.32385254, 23.192379], [91.32383728, 23.19462776], [91.32381439, 23.19637871], [91.32380676, 23.19702339], [91.32376862, 23.1985569], [91.32374573, 23.1993351], [91.32372284, 23.20096397], [91.32371521, 23.20172882], [91.3237381, 23.20336533], [91.32374573, 23.20471764], [91.32370758, 23.20562935], [91.32373047, 23.207407], [91.32373047, 23.208498], [91.3237381, 23.21001625], [91.32374573, 23.21119118], [91.32375336, 23.21164703], [91.32375336, 23.2118721], [91.32375336, 23.21331406], [91.32373047, 23.21467781], [91.32371521, 23.21579361], [91.32369995, 23.21719742], [91.32368469, 23.21814346], [91.3236618, 23.21953583], [91.3236618, 23.22026825], [91.32365417, 23.22178078], [91.32364655, 23.22315788], [91.32361603, 23.22510719], [91.32361603, 23.22608185], [91.3236084, 23.22686386], [91.3236084, 23.22817421], [91.32361603, 23.22853661], [91.3236084, 23.23001671], [91.32360077, 23.23129272], [91.32359314, 23.23302078], [91.32359314, 23.23474121], [91.32358551, 23.23660088], [91.32358551, 23.23701096], [91.32358551, 23.23760605], [91.32228851, 23.23826599], [91.32009888, 23.23937607], [91.31886292, 23.24000931], [91.31881714, 23.24097633], [91.31874847, 23.24273682], [91.31867218, 23.2444458], [91.31864929, 23.24514961], [91.3186264, 23.24562073], [91.3203125, 23.24603653], [91.32223511, 23.2464962], [91.32391357, 23.24691772], [91.32409668, 23.2469635], [91.32456207, 23.24707985], [91.32542419, 23.24728584], [91.32559967, 23.24810791], [91.32575226, 23.2487812], [91.32595062, 23.24967575], [91.32623291, 23.25100136], [91.32654572, 23.25243759], [91.3249054, 23.25255966], [91.3234787, 23.25264931], [91.32275391, 23.25270653], [91.32152557, 23.2528019], [91.32109833, 23.25283051], [91.32060242, 23.25286484], [91.31989288, 23.25291634], [91.31795502, 23.25304794], [91.31781006, 23.25346565], [91.31757355, 23.25414467], [91.3168335, 23.25630951], [91.31674194, 23.25654602], [91.31648254, 23.25720596], [91.31613922, 23.25828171], [91.31568146, 23.25951958], [91.31532288, 23.26054001], [91.31490326, 23.26179504], [91.31479645, 23.26210403], [91.31459045, 23.2626915], [91.3140564, 23.26419258], [91.31352997, 23.26568222], [91.31309509, 23.26695633], [91.3126297, 23.26826096], [91.31250763, 23.26860237], [91.31214142, 23.26961708], [91.31188965, 23.27037048], [91.31135559, 23.27193069], [91.31092072, 23.27317047], [91.31076813, 23.27362251], [91.31032562, 23.27483749], [91.3097229, 23.27651024], [91.31103516, 23.27719688], [91.31193542, 23.27767181], [91.31215668, 23.27778435], [91.31296539, 23.27819824], [91.31363678, 23.27856255], [91.3145752, 23.27902603], [91.31516266, 23.27931786], [91.31568909, 23.27957344], [91.31581116, 23.27979088], [91.31628418, 23.28063965], [91.31667328, 23.28133202], [91.31671906, 23.28141403], [91.31661987, 23.28201866], [91.31575012, 23.28228951], [91.31413269, 23.28279114], [91.31260681, 23.28326416], [91.31157684, 23.28358459], [91.31032562, 23.28397751], [91.30895233, 23.28441048], [91.30823517, 23.28456116], [91.30814362, 23.28459167], [91.30714417, 23.28491783], [91.3068161, 23.28502464], [91.30394745, 23.28594971], [91.30228424, 23.28649521], [91.30172729, 23.28814697], [91.30144501, 23.28894043], [91.30101776, 23.29013824], [91.30079651, 23.29075623], [91.30019379, 23.29242134], [91.30015564, 23.29257584], [91.30030823, 23.29273415], [91.30114746, 23.29361153], [91.30220795, 23.29468536], [91.30357361, 23.2961483], [91.30451202, 23.29712677], [91.30471802, 23.29734039], [91.30543518, 23.29810333], [91.30601501, 23.29873848], [91.30686951, 23.29962158], [91.3069458, 23.29970169], [91.30715179, 23.29991341], [91.30809784, 23.29949188], [91.30874634, 23.29922485], [91.30928802, 23.29899788], [91.31004333, 23.29870033], [91.31118011, 23.29825974], [91.3125, 23.29949951], [91.31441498, 23.29958344], [91.3139801, 23.30179596], [91.31390381, 23.30216789], [91.31362915, 23.30357552], [91.31329346, 23.30538368], [91.31319427, 23.30588913], [91.31307983, 23.30648041], [91.31237793, 23.30793953], [91.31194305, 23.30883789], [91.31173706, 23.30928802], [91.31162262, 23.30955124], [91.31105804, 23.31079292], [91.31044769, 23.31196976], [91.30947113, 23.31400108], [91.3092041, 23.31399536], [91.30744171, 23.31395721], [91.30523682, 23.31390762], [91.3039093, 23.31385422], [91.30365753, 23.31384468], [91.30226898, 23.31378937], [91.30206299, 23.31378365], [91.30145264, 23.31376839], [91.30123138, 23.31375694], [91.30075836, 23.31373596], [91.29995728, 23.31369781], [91.29959869, 23.31368065], [91.29883575, 23.31364822], [91.29646301, 23.31356239], [91.29612732, 23.31357384], [91.29547119, 23.31411552], [91.29347229, 23.31572151], [91.29306793, 23.31604576], [91.29256439, 23.31645393], [91.29073334, 23.31794357], [91.28979492, 23.31865883], [91.2898941, 23.31889153], [91.29008484, 23.31935883], [91.29068756, 23.32084846], [91.29140472, 23.32260704], [91.29166412, 23.32324791], [91.29183197, 23.32366753], [91.29229736, 23.32479858], [91.29255676, 23.32598877], [91.29278564, 23.32695007], [91.2930069, 23.32790756], [91.29356384, 23.33023643], [91.29399872, 23.33207512], [91.29425049, 23.33315086], [91.29468536, 23.33509445], [91.29493713, 23.33613777], [91.2951355, 23.33695793], [91.29541016, 23.3380909], [91.29573822, 23.33944893], [91.29611206, 23.34099579], [91.29691315, 23.34103775], [91.29978943, 23.3419342], [91.30317688, 23.34298134], [91.30505371, 23.34354591], [91.30547333, 23.34347343], [91.30782318, 23.34306717], [91.31049347, 23.3426075], [91.31072998, 23.34256554], [91.31043243, 23.34407425], [91.31031036, 23.34466553], [91.31005096, 23.34594917], [91.31045532, 23.34884453], [91.31077576, 23.35121727], [91.31093597, 23.35241699], [91.31096649, 23.35262108], [91.31100464, 23.35282516], [91.31121826, 23.35287285], [91.31134796, 23.35290337], [91.3115387, 23.35311508], [91.31150818, 23.35330009], [91.31149292, 23.3533802], [91.31151581, 23.35349655], [91.31163788, 23.35357857], [91.31178284, 23.35360718], [91.31201935, 23.35363579], [91.31214905, 23.35377312], [91.31227112, 23.35400009], [91.31251526, 23.3540535], [91.31280518, 23.35404778], [91.31311035, 23.35398293], [91.3133316, 23.3537159], [91.31355286, 23.35321617], [91.31383514, 23.35299301], [91.31421661, 23.35279465], [91.31436157, 23.35277939], [91.31472778, 23.35274506], [91.31507874, 23.35286713], [91.31543732, 23.35299492], [91.31578064, 23.35326958], [91.31588745, 23.35324669], [91.31617737, 23.35339546], [91.31660461, 23.35320091], [91.31710052, 23.35301018], [91.31738281, 23.35295486], [91.31763458, 23.35300827], [91.31790161, 23.35310364], [91.31815338, 23.35334206], [91.31816864, 23.35344887], [91.31819916, 23.3536396], [91.31863403, 23.35520554], [91.31904602, 23.35669899], [91.31919861, 23.35725021], [91.319664, 23.35894203], [91.32002258, 23.36023712], [91.31837463, 23.36050034], [91.31813049, 23.36054039], [91.31663513, 23.35996628], [91.31654358, 23.35990524], [91.316185, 23.35970116], [91.31232452, 23.35747337], [91.31224823, 23.35743141], [91.30932617, 23.35528564], [91.3069458, 23.35469055], [91.30471802, 23.35424995], [91.30425262, 23.35393333], [91.30405426, 23.35380173], [91.30311584, 23.35316658], [91.3009491, 23.35169792], [91.30084991, 23.35169029], [91.29995728, 23.35161591], [91.29886627, 23.35151482], [91.29761505, 23.35139084], [91.29620361, 23.35128593], [91.29572296, 23.35124779], [91.29505157, 23.35119438], [91.29457092, 23.35115433], [91.29337311, 23.35102654], [91.29225922, 23.3509407], [91.29162598, 23.35089111], [91.29099274, 23.35079002], [91.29115295, 23.35133362], [91.29125977, 23.35153198], [91.29156494, 23.35237312], [91.29225922, 23.35430145], [91.29238892, 23.35466576], [91.29256439, 23.35518837], [91.29290771, 23.35620689], [91.29348755, 23.35784531], [91.29450989, 23.36074638], [91.29483795, 23.36133575], [91.29293823, 23.36177635], [91.2908783, 23.36223221], [91.28996277, 23.36242485], [91.28848267, 23.36275673], [91.28792572, 23.36288071], [91.28692627, 23.36310387], [91.28655243, 23.36318588], [91.28611755, 23.36328125], [91.28583527, 23.36437225], [91.28535461, 23.36654472], [91.28490448, 23.36839867], [91.2844696, 23.37019348], [91.28442383, 23.37038422], [91.28436279, 23.3706398], [91.28420258, 23.37129974], [91.28516388, 23.37130928], [91.28620148, 23.37131882], [91.28798676, 23.37135315], [91.29111481, 23.37138748], [91.29092407, 23.37181282], [91.29381561, 23.37216187], [91.29393005, 23.37289429], [91.29430389, 23.37484741], [91.2937088, 23.37534714], [91.29347229, 23.37561798], [91.29335022, 23.37582588], [91.29331207, 23.3761692], [91.29323578, 23.37643814], [91.29320526, 23.37683487], [91.29322052, 23.37723923], [91.29325867, 23.37745285], [91.2913208, 23.37689209], [91.29047394, 23.37708855], [91.29013062, 23.37655067], [91.28973389, 23.37611198], [91.28965759, 23.37602043], [91.2894516, 23.37595749], [91.28908539, 23.37590218], [91.28877258, 23.37571144], [91.28858185, 23.375597], [91.28848267, 23.37554359], [91.28836823, 23.37554932], [91.28819275, 23.37561226], [91.28810883, 23.37571144], [91.28783417, 23.37592888], [91.28762817, 23.37609673], [91.28748322, 23.37622833], [91.28726959, 23.37622833], [91.28713226, 23.37618637], [91.28694916, 23.37606239], [91.2864151, 23.37626839], [91.28578949, 23.3764801], [91.28569794, 23.37652016], [91.28543091, 23.37677193], [91.28511047, 23.37717247], [91.28407288, 23.37708092], [91.2837677, 23.37691307], [91.28278351, 23.37665939], [91.28263092, 23.37650871], [91.2821579, 23.37603951], [91.28205109, 23.37599945], [91.28192902, 23.37604332], [91.28171539, 23.3761158], [91.28105164, 23.37638855], [91.28086853, 23.37658691], [91.28066254, 23.37674141], [91.28049469, 23.37674713], [91.28045654, 23.37658119], [91.28028107, 23.37678528], [91.28009796, 23.37672043], [91.2796936, 23.37677765], [91.27961731, 23.37781143], [91.27954102, 23.37878418], [91.27950287, 23.37922287], [91.27939606, 23.38071632], [91.27936554, 23.38111115], [91.27933502, 23.38143921], [91.27923584, 23.38256264], [91.27920532, 23.38290977], [91.27914429, 23.38380623], [91.27905273, 23.38499832], [91.27893829, 23.3864212], [91.27882385, 23.38791466], [91.27864838, 23.3899498], [91.27861023, 23.39042091], [91.27851868, 23.39149857], [91.27848816, 23.39182281], [91.27842712, 23.39249229], [91.27835083, 23.39379311], [91.27831268, 23.39422417], [91.27824402, 23.39505005], [91.27812195, 23.39649582], [91.27803802, 23.39761162], [91.27801514, 23.39785767], [91.27794647, 23.39876366], [91.2779007, 23.39945602], [91.27776337, 23.40062714], [91.27759552, 23.40240288], [91.27745819, 23.40373039], [91.27738953, 23.40450478], [91.2772522, 23.40571404], [91.27715302, 23.40685272], [91.27706146, 23.40784645], [91.27696991, 23.40873718], [91.27685547, 23.40984344], [91.27671814, 23.41117477], [91.27663422, 23.41197968], [91.27646637, 23.41386414], [91.27637482, 23.41482735], [91.2749176, 23.41579437], [91.27440643, 23.4161377], [91.27349091, 23.41676331], [91.27278137, 23.41724205], [91.27165222, 23.41804314], [91.27111816, 23.41842461], [91.27070618, 23.41871071], [91.26969147, 23.41941643], [91.26925659, 23.41971588], [91.26895905, 23.41994858], [91.26811218, 23.42054558], [91.2676239, 23.42088699], [91.26659393, 23.42160034], [91.26611328, 23.42193794], [91.26560974, 23.42229462], [91.26522827, 23.42255783], [91.26448822, 23.42306328], [91.26403809, 23.42337608], [91.26395416, 23.4234333], [91.26338959, 23.42385101], [91.26423645, 23.42451477], [91.26480865, 23.42500305], [91.26592255, 23.42594528], [91.26687622, 23.42676163], [91.26737213, 23.42718124], [91.26779175, 23.42753983], [91.26851654, 23.42815208], [91.26908112, 23.42863464], [91.26953888, 23.42903137], [91.26993561, 23.42937279], [91.27060699, 23.42993546], [91.26912689, 23.43120956], [91.26894379, 23.43136978], [91.26854706, 23.43171883], [91.26828003, 23.43195915], [91.2678833, 23.4323101], [91.26780701, 23.43238449], [91.26676178, 23.43333244], [91.26636505, 23.43364716], [91.26615143, 23.433815], [91.26544189, 23.43437958], [91.26454163, 23.43514061], [91.26346588, 23.43608665], [91.26262665, 23.43679428], [91.26208496, 23.43722916], [91.26164246, 23.43759727], [91.26092529, 23.43820953], [91.25947571, 23.43916512], [91.25941467, 23.43920517], [91.25872803, 23.43965149], [91.25780487, 23.44043159], [91.25701141, 23.44114304], [91.2565918, 23.44151688], [91.25640106, 23.44169426], [91.25637054, 23.44237709], [91.25628662, 23.44408989], [91.25627136, 23.4442749], [91.25624084, 23.44495583], [91.25592041, 23.44659615], [91.25572205, 23.44751358], [91.25536346, 23.44797897], [91.25474548, 23.44881058], [91.2545166, 23.44910049], [91.25410461, 23.44967842], [91.25371552, 23.45021057], [91.25326538, 23.45092773], [91.25293732, 23.45144081], [91.25270844, 23.45180511], [91.25167847, 23.45344734], [91.2514801, 23.45377731], [91.25196838, 23.45484924], [91.25200653, 23.45493698], [91.25279999, 23.45671463], [91.25341797, 23.45814514], [91.25337982, 23.45933342], [91.25335693, 23.46060562], [91.2533493, 23.46154213], [91.2525177, 23.46189117], [91.2517395, 23.46229172], [91.25112152, 23.46282768], [91.25102997, 23.46290779], [91.25095367, 23.46340752], [91.25082397, 23.46387291], [91.25075531, 23.46448326], [91.25105286, 23.46500969], [91.25138092, 23.46552658], [91.25153351, 23.46613312], [91.25158691, 23.46681023], [91.2515564, 23.46723938], [91.25160217, 23.46780968], [91.25160217, 23.46788216], [91.25157928, 23.46814346], [91.25144958, 23.468647], [91.25135803, 23.46901703], [91.25131989, 23.46907806], [91.25112915, 23.46942711], [91.25072479, 23.46976852], [91.25094604, 23.47058296], [91.2510376, 23.47099113], [91.25115967, 23.47152519], [91.2514801, 23.47289276], [91.25158691, 23.4740696], [91.25163269, 23.4746151], [91.2518158, 23.47690773], [91.25183868, 23.47719574], [91.25193024, 23.478302], [91.25196838, 23.47877121], [91.25202942, 23.47948647], [91.25205994, 23.47982788], [91.25215149, 23.48090935], [91.25217438, 23.48114586], [91.25190735, 23.48180389], [91.2515564, 23.48267365], [91.25119781, 23.48357391], [91.25100708, 23.48407364], [91.25050354, 23.48538399], [91.25009918, 23.48639107], [91.24981689, 23.48765373], [91.24951935, 23.48908043], [91.24936676, 23.48979568], [91.24925995, 23.49031258], [91.24365997, 23.49035454], [91.24121857, 23.490448], [91.24069214, 23.49038887], [91.23965454, 23.4901104], [91.2387619, 23.48985481], [91.23630524, 23.48914528], [91.23659515, 23.4912281], [91.23678589, 23.49263763], [91.2371521, 23.4952774], [91.23620605, 23.49562263], [91.23573303, 23.49579048], [91.2347641, 23.4961319], [91.23435974, 23.49627304], [91.23439789, 23.49643898], [91.23448181, 23.49682236], [91.23480988, 23.49843407], [91.23490906, 23.49893761], [91.23516083, 23.5001297], [91.23551178, 23.50191879], [91.2354126, 23.50187302], [91.23235321, 23.50048256], [91.23208618, 23.50036049], [91.2307663, 23.49975777], [91.23015594, 23.49947357], [91.22962952, 23.49922752], [91.22901154, 23.49904251], [91.2279129, 23.49872971], [91.22757721, 23.49863052], [91.22605896, 23.49818611], [91.22515106, 23.49793434], [91.22354889, 23.49750137], [91.22335815, 23.49744797], [91.22296906, 23.49743271], [91.2226181, 23.49742508], [91.22148132, 23.49796295], [91.21994019, 23.49869728], [91.21923828, 23.49902725], [91.21836853, 23.49943924], [91.21792603, 23.49964714], [91.21831512, 23.50060463], [91.21860504, 23.50137138], [91.21893311, 23.50227547], [91.21930695, 23.50327682], [91.21975708, 23.50446892], [91.22071075, 23.50698853], [91.22116852, 23.50822449], [91.22170258, 23.50952721], [91.22189331, 23.51002121], [91.22222137, 23.51086807], [91.22259521, 23.51181984], [91.22341156, 23.51392746], [91.22290039, 23.51391602], [91.21808624, 23.51342392], [91.21796417, 23.51338196], [91.21551514, 23.51251221], [91.21235657, 23.51349449], [91.21202087, 23.51340294], [91.21125793, 23.51318741], [91.20992279, 23.51281548], [91.20775604, 23.51221275], [91.20601654, 23.51417732], [91.20521545, 23.51508141], [91.20503998, 23.51527405], [91.20479584, 23.51555252], [91.20400238, 23.51644707], [91.2039032, 23.5165596], [91.20347595, 23.51703453], [91.2024231, 23.51822853], [91.20111084, 23.519701], [91.20070648, 23.52016258], [91.20070648, 23.52026176], [91.20069122, 23.52087212], [91.20068359, 23.52108192], [91.20065308, 23.52217484], [91.20063019, 23.52314568], [91.20124817, 23.52461052], [91.20199585, 23.526371], [91.20307922, 23.52896309], [91.20368958, 23.53041077], [91.20391846, 23.53096771], [91.20424652, 23.53170967], [91.20451355, 23.53236389], [91.20480347, 23.53305817], [91.20519257, 23.53398705], [91.20558929, 23.53520966], [91.20578003, 23.53582001], [91.20631409, 23.53756142], [91.20674896, 23.53894615], [91.20689392, 23.53936577], [91.20746613, 23.54123306], [91.20787811, 23.54251671], [91.2080307, 23.54297066], [91.20809937, 23.5431881], [91.21035767, 23.54416084], [91.21231079, 23.54501152], [91.21296692, 23.54528236], [91.21295929, 23.54568863], [91.2129364, 23.54802704], [91.2129364, 23.54814529], [91.21284485, 23.54811287], [91.21230316, 23.54782104], [91.21089935, 23.54689407], [91.21032715, 23.54689407], [91.2104187, 23.54665947], [91.20964813, 23.54649925], [91.20939636, 23.54613686], [91.20909119, 23.54602051], [91.20861816, 23.54587364], [91.20827484, 23.54579163], [91.20806122, 23.54594803], [91.20779419, 23.54603577], [91.20742798, 23.54550362], [91.20713043, 23.54546928], [91.20664978, 23.54567909], [91.20636749, 23.54569817], [91.20574951, 23.54553223], [91.20527649, 23.54540443], [91.2041626, 23.54699898], [91.20362091, 23.54776573], [91.20227814, 23.54744911], [91.20219421, 23.54746819], [91.19952393, 23.5480957], [91.19924927, 23.5483551], [91.19890594, 23.54806328], [91.19897461, 23.547472], [91.19801331, 23.54743576], [91.19586182, 23.547369], [91.19438171, 23.54732323], [91.1944046, 23.54768562], [91.19441986, 23.54802322], [91.19462585, 23.55164528], [91.19483185, 23.55528259], [91.19502258, 23.55861092], [91.19507599, 23.55960464], [91.19515991, 23.56114197], [91.19520569, 23.5619297], [91.19522095, 23.56213951], [91.19509888, 23.56261063], [91.19502258, 23.56271553], [91.19484711, 23.56294632], [91.19394684, 23.56414986], [91.19294739, 23.56549072], [91.1917038, 23.567173], [91.19047546, 23.5688343], [91.18940735, 23.57028961], [91.18904877, 23.57078934], [91.18844604, 23.57159996], [91.18739319, 23.57302475], [91.18721008, 23.57326698], [91.18721771, 23.57339287], [91.18709564, 23.5735321], [91.1871109, 23.57363319], [91.18711853, 23.57387352], [91.18713379, 23.57440948], [91.1872406, 23.57765961], [91.18671417, 23.57767487], [91.18591309, 23.57769775], [91.18408966, 23.57942581], [91.18397522, 23.57953644], [91.18231201, 23.58065224], [91.18136597, 23.58127975], [91.18112946, 23.58143806], [91.18036652, 23.58218575], [91.18019867, 23.58235359], [91.18006134, 23.58252716], [91.1780014, 23.58410263], [91.17681122, 23.58416176], [91.17572021, 23.58514023], [91.17517853, 23.58562851], [91.17514801, 23.58580589], [91.17507935, 23.58630371], [91.17533112, 23.58671951], [91.17648315, 23.58782387], [91.17622375, 23.58870888], [91.17607117, 23.58893776], [91.17638397, 23.58946228], [91.17694855, 23.5900135], [91.17801666, 23.59188461], [91.17704773, 23.59332657], [91.17668152, 23.59334564], [91.17491913, 23.59344864], [91.17424774, 23.59347916], [91.17224121, 23.59329605], [91.17168427, 23.59326172], [91.16914368, 23.5930233], [91.16866302, 23.59273338], [91.1673584, 23.59327126], [91.16357422, 23.59486389], [91.16272736, 23.59520912], [91.16243744, 23.59519577], [91.16249847, 23.59592247], [91.16251373, 23.59617996], [91.16251373, 23.59698105], [91.16248322, 23.59752655], [91.16240692, 23.59753036], [91.16207886, 23.59755135], [91.16208649, 23.5979538], [91.16210175, 23.59881973], [91.16329956, 23.60060883], [91.16368103, 23.60117149], [91.16207886, 23.60489273], [91.16110229, 23.6075592], [91.16047668, 23.6091671], [91.15960693, 23.61144257], [91.1604538, 23.61309624], [91.16094208, 23.61406326], [91.1606369, 23.61454773], [91.16077423, 23.61460304], [91.1607666, 23.61509705], [91.16036224, 23.61593437], [91.15934753, 23.6170826], [91.15922546, 23.61705971], [91.15907288, 23.61733818], [91.15882111, 23.61945724], [91.15847778, 23.61945152], [91.15855408, 23.62029457], [91.15844727, 23.62098885], [91.15804291, 23.62192154], [91.1580658, 23.62421799], [91.15814972, 23.62485886], [91.15830994, 23.62608719], [91.15914154, 23.62613678], [91.15865326, 23.62905312], [91.16094971, 23.63135529], [91.1596756, 23.63480568], [91.15962219, 23.63602066], [91.15913391, 23.63707733], [91.15893555, 23.64004517], [91.15897369, 23.64096642], [91.15885925, 23.64146233], [91.158638, 23.64149284], [91.15895844, 23.64200401], [91.15931702, 23.64233208], [91.15970612, 23.64337349], [91.1598587, 23.64556694], [91.15962982, 23.64570618], [91.15998077, 23.64634705], [91.16039276, 23.64759064], [91.16056824, 23.64819908], [91.16077423, 23.64816666], [91.16095734, 23.64891052], [91.1609726, 23.64990425], [91.16096497, 23.65184402], [91.16077423, 23.65181923], [91.1607666, 23.65218163], [91.16075897, 23.65246773], [91.16095734, 23.65249443], [91.16121674, 23.6540451], [91.16131592, 23.65445709], [91.16101837, 23.65506935], [91.15995026, 23.65723419], [91.15990448, 23.65743637], [91.15975189, 23.65739822], [91.15971375, 23.6584816], [91.1595459, 23.65938187], [91.15859222, 23.66256142], [91.15851593, 23.66279793], [91.15761566, 23.66523743], [91.15694427, 23.66704369], [91.15697479, 23.66712379], [91.15676117, 23.66851616], [91.15643311, 23.66930008], [91.15627289, 23.6696701], [91.15634155, 23.6704998], [91.15625763, 23.67084503], [91.157341, 23.6701889], [91.15742493, 23.67013359], [91.15748596, 23.67009354], [91.15854645, 23.66933632], [91.15943146, 23.66846085], [91.15966034, 23.66788292], [91.15992737, 23.66758919], [91.1603241, 23.66745758], [91.16052246, 23.66742325], [91.16036224, 23.66808128], [91.16127014, 23.6706028], [91.16131592, 23.67071533], [91.16330719, 23.66825676], [91.16338348, 23.66817284], [91.16491699, 23.6652832], [91.16812134, 23.66403961], [91.17163849, 23.6623497], [91.17221069, 23.66179657], [91.17230988, 23.66168785], [91.17392731, 23.65987968], [91.17543793, 23.65806007], [91.17560577, 23.65830421], [91.1756897, 23.65848541], [91.17573547, 23.65855408], [91.17578888, 23.65876007], [91.17584229, 23.65897942], [91.17583466, 23.6591568], [91.17585754, 23.65956497], [91.17601776, 23.65973473], [91.17608643, 23.65963554], [91.1761322, 23.65949631], [91.17606354, 23.65915298], [91.1760025, 23.65889549], [91.17598724, 23.65872955], [91.17597961, 23.65861511], [91.17601013, 23.6583786], [91.17604828, 23.65812302], [91.17616272, 23.65796661], [91.17626953, 23.65789795], [91.17644501, 23.65780067], [91.17657471, 23.65778732], [91.17667389, 23.65782738], [91.17701721, 23.65801811], [91.17714691, 23.65813255], [91.17725372, 23.65826607], [91.17725372, 23.65839005], [91.17731476, 23.65859413], [91.17738342, 23.65867424], [91.17770386, 23.65868568], [91.17778778, 23.65861893], [91.17786407, 23.65849113], [91.17806244, 23.65815544], [91.17816925, 23.65798187], [91.17832184, 23.65785217], [91.17845917, 23.65774727], [91.1787796, 23.65759468], [91.17925262, 23.65745735], [91.17943573, 23.65739441], [91.17971039, 23.65731049], [91.1798172, 23.65725899], [91.17996216, 23.65716553], [91.18016815, 23.65702248], [91.18035126, 23.65693283], [91.18066406, 23.65677452], [91.18083954, 23.65666962], [91.18101501, 23.65656281], [91.18125153, 23.65651131], [91.18154144, 23.65649223], [91.18173981, 23.65649986], [91.18228912, 23.65664101], [91.18264771, 23.65675545], [91.18273926, 23.65688896], [91.18278503, 23.65707779], [91.18273926, 23.65724373], [91.18260193, 23.6572876], [91.18239594, 23.65728378], [91.18217468, 23.65724945], [91.18202972, 23.65725517], [91.18193817, 23.65730667], [91.18195343, 23.65743446], [91.18205261, 23.65768814], [91.18235779, 23.6583786], [91.18244934, 23.65882301], [91.18249512, 23.65916252], [91.18247223, 23.65939331], [91.18237305, 23.65966034], [91.18239594, 23.65976715], [91.18247986, 23.65983009], [91.18276978, 23.65979576], [91.18294525, 23.65960693], [91.18300629, 23.6593914], [91.18322754, 23.65888214], [91.18326569, 23.65868568], [91.18338013, 23.65858459], [91.18367767, 23.65831947], [91.1836853, 23.65823174], [91.18382263, 23.65815926], [91.1839447, 23.65802383], [91.18408203, 23.65794563], [91.1842041, 23.65784836], [91.18427277, 23.65774727], [91.18441772, 23.65753746], [91.18451691, 23.65731812], [91.18460846, 23.65717506], [91.18490601, 23.65682983], [91.18502808, 23.65676689], [91.18512726, 23.65670395], [91.18572235, 23.65654755], [91.1868515, 23.65623665], [91.18724823, 23.65612793], [91.18825531, 23.65584946], [91.18960571, 23.65547562], [91.19117737, 23.65504456], [91.19248962, 23.65467644], [91.19288635, 23.654562], [91.19224548, 23.65237617], [91.19155884, 23.65002632], [91.19094849, 23.64791107], [91.19070435, 23.64709282], [91.19190979, 23.64673424], [91.19324493, 23.64633751], [91.19377899, 23.6461792], [91.19643402, 23.64645004], [91.1969223, 23.64649773], [91.19797516, 23.64660263], [91.19935608, 23.64674187], [91.19940186, 23.64728355], [91.19947815, 23.64816093], [91.19963837, 23.64981842], [91.20140076, 23.65006828], [91.20165253, 23.65010834], [91.20272827, 23.65026283], [91.20453644, 23.65052795], [91.20366669, 23.65200996], [91.20289612, 23.65333366], [91.20246124, 23.65405846], [91.20298767, 23.65404892], [91.2050705, 23.65405273], [91.20494843, 23.65512657], [91.20423126, 23.65530586], [91.20350647, 23.65549088], [91.20140076, 23.65609169], [91.20150757, 23.65620232], [91.20259857, 23.6573391], [91.20362854, 23.65841103], [91.20297241, 23.66077995], [91.2024765, 23.66254044], [91.20232391, 23.66303444], [91.20252991, 23.66445351], [91.20258331, 23.66487503], [91.20288849, 23.66687202], [91.20313263, 23.66850853], [91.2033844, 23.67017365], [91.20352173, 23.6710186], [91.20381927, 23.67294312], [91.20404053, 23.67439842], [91.20441437, 23.67683411], [91.20458221, 23.67784119], [91.20491028, 23.67991447], [91.20428467, 23.68003654], [91.20394135, 23.6801033], [91.20320129, 23.68024254], [91.20328522, 23.6803875], [91.20339966, 23.6805954], [91.2035141, 23.68094635], [91.20350647, 23.68103981], [91.20353699, 23.68112755], [91.20359802, 23.68128395], [91.20368195, 23.68136215], [91.20388794, 23.68153763], [91.20402527, 23.6817627], [91.20417786, 23.68188095], [91.20428467, 23.68193054], [91.20439148, 23.68208313], [91.20443726, 23.68225098], [91.20445251, 23.68234253], [91.20452881, 23.68247414], [91.20479584, 23.68251228], [91.20491028, 23.68254089], [91.20494843, 23.68264771], [91.20505524, 23.68268967], [91.20550537, 23.68261528], [91.20581818, 23.68263054], [91.20592499, 23.68270493], [91.20607758, 23.68313408], [91.20611572, 23.68322945], [91.20620728, 23.68346024], [91.20630646, 23.68366051], [91.20632172, 23.68384171], [91.2064209, 23.68419456], [91.20632935, 23.68431282], [91.20627594, 23.68445206], [91.20635223, 23.68485832], [91.20643616, 23.6849556], [91.20658112, 23.68498421], [91.20690155, 23.68496132], [91.20726776, 23.68497849], [91.20761871, 23.68502235], [91.20785522, 23.68549538], [91.20798492, 23.68582344], [91.20790863, 23.68588066], [91.20792389, 23.68606567], [91.20837402, 23.68639946], [91.20846558, 23.68657303], [91.20697784, 23.68626022], [91.20482635, 23.68582153], [91.20404053, 23.6856575], [91.20361328, 23.68556023], [91.20340729, 23.68582726], [91.2024231, 23.68711853], [91.20202637, 23.68765259], [91.19963837, 23.68933105], [91.19889832, 23.68985367], [91.19800568, 23.69048691], [91.19637299, 23.69164658], [91.1960907, 23.69184875], [91.19548035, 23.69228172], [91.19522858, 23.69195366], [91.19476318, 23.69134521], [91.19445801, 23.69093895], [91.19376373, 23.6900444], [91.19204712, 23.69000626], [91.1907196, 23.68997192], [91.18894958, 23.68993378], [91.18699646, 23.689888], [91.18521118, 23.68984604], [91.18400574, 23.68981934], [91.18237305, 23.68978119], [91.18029785, 23.68973541], [91.17951202, 23.68971634], [91.17784882, 23.68968201], [91.17733765, 23.68966484], [91.17682648, 23.68964386], [91.17610168, 23.68961334], [91.17526245, 23.68958664], [91.17463684, 23.68956947], [91.1733017, 23.68953896], [91.1726532, 23.6895256], [91.17152405, 23.6894989], [91.17034912, 23.6894722], [91.16843414, 23.68943214], [91.16611481, 23.68930054], [91.16349792, 23.68914413], [91.16100311, 23.68899727], [91.15827179, 23.68883133], [91.15689087, 23.68873405], [91.15589142, 23.68866158], [91.15507507, 23.68860054], [91.15418243, 23.6885376], [91.1539917, 23.68875122], [91.15346527, 23.68935585], [91.15344238, 23.68959618], [91.15325165, 23.69158745], [91.15312958, 23.69257927], [91.15306854, 23.69309998], [91.1529007, 23.69487953], [91.15233612, 23.69714165], [91.15209961, 23.69807243], [91.15209198, 23.6991024], [91.15206909, 23.69960785], [91.15209198, 23.70030975], [91.15209198, 23.70082474], [91.15211487, 23.70166016], [91.15196228, 23.70204163], [91.15184021, 23.70238304], [91.15180969, 23.70283699], [91.15162659, 23.70409203], [91.1516037, 23.70446777], [91.15149689, 23.70479965], [91.15156555, 23.70510483], [91.15155029, 23.70557976], [91.15071106, 23.70593262], [91.15048218, 23.7069912], [91.15026855, 23.70793343], [91.14995575, 23.70937729], [91.1498642, 23.70983124], [91.15007019, 23.71045876], [91.14963531, 23.710989], [91.14912415, 23.71166801], [91.14970398, 23.71290588], [91.15013885, 23.7138176], [91.15026093, 23.7143383], [91.15045166, 23.71514893], [91.15065765, 23.71608734], [91.15093231, 23.71735001], [91.15112305, 23.71770287], [91.1518631, 23.71907234], [91.15279388, 23.72122002], [91.15296173, 23.72296143], [91.15287018, 23.72418022], [91.1528244, 23.72471046], [91.15323639, 23.72574997], [91.15381622, 23.727211], [91.15406036, 23.72781754], [91.15483093, 23.72977638], [91.15518188, 23.73064613], [91.15499115, 23.73186493], [91.15509033, 23.73260689], [91.1559906, 23.7348156], [91.15621185, 23.73555565], [91.15615845, 23.73595238], [91.15614319, 23.73610497], [91.15628052, 23.73649406], [91.15725708, 23.73811531], [91.15729523, 23.73817825], [91.15802002, 23.7393856], [91.1574173, 23.73957825], [91.1563797, 23.73991013], [91.15665436, 23.74091148], [91.1570282, 23.74215317], [91.15847015, 23.74185181], [91.15878296, 23.74178505], [91.16014862, 23.7432766], [91.16059113, 23.74374771], [91.16085052, 23.74402046], [91.16160583, 23.74481964], [91.16175079, 23.74500465], [91.16239929, 23.74570656], [91.16285706, 23.74620247], [91.16332245, 23.74668312], [91.16358948, 23.74697685], [91.16421509, 23.74767876], [91.16500854, 23.74830246], [91.16577148, 23.74890137], [91.1661377, 23.74910927], [91.167099, 23.7495327], [91.16759491, 23.74978256], [91.16819763, 23.74979782], [91.16874695, 23.74985123], [91.16901398, 23.74983406], [91.16999817, 23.7497673], [91.17009735, 23.75004959], [91.17019653, 23.75016212], [91.17032623, 23.75024605], [91.17043304, 23.75031471], [91.17051697, 23.75036621], [91.17062378, 23.75044823], [91.17075348, 23.75050545], [91.17086029, 23.7505722], [91.17108154, 23.75068283], [91.17115784, 23.75074768], [91.17121124, 23.75082016], [91.17115021, 23.75092125], [91.17110443, 23.75099564], [91.17105865, 23.75115395], [91.17118073, 23.75123215], [91.17128754, 23.7512989], [91.17138672, 23.75136185], [91.1723938, 23.75201416], [91.17247772, 23.75200653], [91.17810059, 23.75170898], [91.18310547, 23.75128174], [91.18768311, 23.75128174], [91.18927002, 23.75170898], [91.19487, 23.75316048], [91.19549561, 23.7532959], [91.19936371, 23.7531414], [91.20007324, 23.75311279], [91.20546722, 23.75222969], [91.21038818, 23.75162125], [91.21092987, 23.75160599], [91.21429443, 23.75012207], [91.21496582, 23.74867058], [91.21583557, 23.74699402], [91.21587372, 23.7468853], [91.21708679, 23.74368095], [91.21996307, 23.74118996], [91.22052765, 23.74092484], [91.22117615, 23.74263191], [91.22183228, 23.7443409], [91.22241211, 23.74585724], [91.22323608, 23.74700165], [91.22423553, 23.74839973], [91.2253952, 23.74999809], [91.22561646, 23.75030136], [91.22599792, 23.75084496], [91.22629547, 23.75126266], [91.22625732, 23.75143433], [91.22605133, 23.75244713], [91.22595215, 23.75293159], [91.22589111, 23.75323677], [91.22579956, 23.7536602], [91.22541809, 23.75548553], [91.22516632, 23.75666809], [91.22599792, 23.75794601], [91.22637939, 23.75852966], [91.22698975, 23.75946617], [91.22763062, 23.76044846], [91.22801208, 23.76103592], [91.22834015, 23.76153564], [91.22938538, 23.76316452], [91.22990417, 23.76396179], [91.23051453, 23.76486397], [91.23064423, 23.76506042], [91.2306366, 23.76587296], [91.23062134, 23.76679993], [91.23058319, 23.76901245], [91.23053741, 23.77147293], [91.23049927, 23.77351379], [91.23046112, 23.77606201], [91.23028564, 23.77760124], [91.23006439, 23.77938271], [91.23027802, 23.78206444], [91.23044586, 23.78410721], [91.23047638, 23.78453445], [91.23029327, 23.78464317], [91.22991943, 23.78482437], [91.22888947, 23.78539467], [91.22832489, 23.78570747], [91.22865295, 23.78719139], [91.2286911, 23.7873497], [91.2286377, 23.78770256], [91.2285614, 23.78825378], [91.22846985, 23.78893471], [91.2280426, 23.78941727], [91.22709656, 23.79021263], [91.22693634, 23.79034615], [91.22679138, 23.79046822], [91.22660065, 23.79073143], [91.22637939, 23.79110336], [91.22663116, 23.79183388], [91.22711182, 23.79322624], [91.227211, 23.79334068], [91.22720337, 23.79348564], [91.22830963, 23.7952919], [91.22879028, 23.79575157], [91.22914124, 23.79609108], [91.22969818, 23.79655075], [91.23008728, 23.79686928], [91.23046112, 23.79718018], [91.23080444, 23.79744339], [91.23110962, 23.79768753], [91.23100281, 23.79822159], [91.23127747, 23.79827118], [91.23153687, 23.79831886], [91.23134613, 23.79907036], [91.23132324, 23.79917336], [91.23137665, 23.79936409], [91.23171997, 23.80057526], [91.23249054, 23.80252647], [91.2326889, 23.80317879], [91.23314667, 23.80464554], [91.23335266, 23.80533028], [91.23366547, 23.80633163], [91.2338028, 23.8067894], [91.23390961, 23.80705261], [91.23377991, 23.80725288], [91.23368835, 23.80742264], [91.23365784, 23.80759048], [91.23374939, 23.80777931], [91.23376465, 23.80788803], [91.23365784, 23.80814743], [91.23365021, 23.80832291], [91.23358154, 23.80844879], [91.23353577, 23.80864334], [91.23355103, 23.80939674], [91.23353577, 23.81004143], [91.23368835, 23.8109684], [91.23397064, 23.81097794], [91.23403931, 23.81128311], [91.23409271, 23.81154633], [91.23435974, 23.81166267], [91.23445892, 23.81172562], [91.23441315, 23.81186104], [91.23451233, 23.81193161], [91.23473358, 23.8119297], [91.23479462, 23.81205177], [91.23484802, 23.81211472], [91.23503876, 23.81227303], [91.2352829, 23.81241035], [91.23526001, 23.81248093], [91.23548126, 23.81251717], [91.23564911, 23.81251907], [91.23582458, 23.81256294], [91.23591614, 23.81263351], [91.23617554, 23.81268883], [91.23642731, 23.81295967], [91.23651886, 23.81308746], [91.23667908, 23.8131485], [91.23683167, 23.81320763], [91.23707581, 23.8135376], [91.23733521, 23.81374168], [91.23748016, 23.81373787], [91.23756409, 23.81391907], [91.23860168, 23.81573677], [91.23971558, 23.81769562], [91.24009705, 23.81835556], [91.24063873, 23.81927681], [91.24069214, 23.81937599], [91.24113464, 23.82014275], [91.24221039, 23.8219986], [91.24285889, 23.82311058], [91.24371338, 23.82427406], [91.24384308, 23.8244648], [91.2448349, 23.82582283], [91.24593353, 23.82733154], [91.24750519, 23.82949448], [91.24933624, 23.83198738], [91.25061035, 23.833395], [91.25171661, 23.83462715], [91.25260162, 23.83561516], [91.2534256, 23.83652687], [91.25399017, 23.83715439], [91.25404358, 23.83812904], [91.25325012, 23.8398056], [91.25301361, 23.84030151], [91.25289917, 23.84055328], [91.25282288, 23.84072113], [91.25266266, 23.84105301], [91.25193787, 23.84259224], [91.25135803, 23.84382057], [91.25065613, 23.84529495], [91.24985504, 23.84698868], [91.24958801, 23.84801483], [91.24932861, 23.84899902], [91.24880981, 23.85095406], [91.24834442, 23.8515892], [91.24806213, 23.85197067], [91.24710846, 23.85326576], [91.24611664, 23.85461807], [91.24520874, 23.85585785], [91.24436951, 23.85699844], [91.24339294, 23.85832405], [91.24201965, 23.86019897], [91.24129486, 23.86117935], [91.24080658, 23.86184311], [91.24049377, 23.86268616], [91.24007416, 23.8638134], [91.23918152, 23.86620522], [91.23882294, 23.86715317], [91.23851013, 23.86798096], [91.23855591, 23.8680706], [91.23847198, 23.86812973], [91.23827362, 23.87022781], [91.23819733, 23.87109375], [91.23814392, 23.87165833], [91.23808289, 23.87233734], [91.2379837, 23.87257385], [91.23784637, 23.87287521], [91.23744965, 23.87376595], [91.2366333, 23.87558365], [91.23652649, 23.87581825], [91.23571014, 23.87766075], [91.23442078, 23.87784386], [91.23377228, 23.87794113], [91.23175812, 23.87823486], [91.23133087, 23.8787117], [91.23067474, 23.8794632], [91.22970581, 23.88055611], [91.22954559, 23.88073921], [91.22943115, 23.88254166], [91.22934723, 23.88386917], [91.22924805, 23.8854599], [91.22915649, 23.88692093], [91.22905731, 23.88847542], [91.22897339, 23.8897686], [91.22885132, 23.89190292], [91.22875214, 23.89370346], [91.22866821, 23.89525986], [91.22855377, 23.89684486], [91.22849274, 23.89767075], [91.2284317, 23.89877892], [91.22881317, 23.89876938], [91.22982788, 23.89916992], [91.23000336, 23.89923859], [91.23032379, 23.89936638], [91.23100281, 23.89963341], [91.23325348, 23.90052032], [91.23530579, 23.90133286], [91.23655701, 23.90209198], [91.23738098, 23.90259361], [91.23825073, 23.90312386], [91.23986053, 23.90410614], [91.24227905, 23.90557861], [91.24459076, 23.90698051], [91.24481201, 23.90711594], [91.24490356, 23.90779877], [91.24501038, 23.90854454], [91.24515533, 23.90886497], [91.24551392, 23.91048622], [91.24594879, 23.91243935], [91.24612427, 23.91322517], [91.24613953, 23.91384697], [91.24506378, 23.9158783], [91.24406433, 23.91777992], [91.24330902, 23.9192009], [91.24137878, 23.92284584], [91.23969269, 23.9236908], [91.23779297, 23.92464638], [91.23723602, 23.92492485], [91.23628998, 23.9254055], [91.23518372, 23.92596817], [91.23391724, 23.92661095], [91.23295593, 23.92709541], [91.23387146, 23.9279995], [91.23460388, 23.92792892], [91.23472595, 23.92791748], [91.23503113, 23.92788696], [91.23560333, 23.92783165], [91.23531342, 23.92868042], [91.23651123, 23.9296875], [91.23920441, 23.92952347], [91.23950195, 23.92950439], [91.24684906, 23.92837906], [91.25183868, 23.9289875], [91.25443268, 23.92753983], [91.25708008, 23.92730713], [91.2623291, 23.92651367], [91.26727295, 23.92712402], [91.27205658, 23.92698097], [91.2724762, 23.92697334], [91.27261353, 23.92691612], [91.27270508, 23.92689896], [91.2753067, 23.9264183], [91.27467346, 23.92933273], [91.27417755, 23.93162346], [91.27371216, 23.93378639], [91.2733078, 23.9356308], [91.27293396, 23.93733025], [91.27282715, 23.93778419], [91.27188873, 23.938591], [91.27178955, 23.9386673], [91.27082825, 23.9393959], [91.26961517, 23.94030952], [91.26855469, 23.94110298], [91.2681427, 23.94140244], [91.26691437, 23.94230843], [91.26613617, 23.94288254], [91.26393127, 23.94437027], [91.26430511, 23.94515991], [91.26474762, 23.94610214], [91.26503754, 23.94671631], [91.26572418, 23.94848633], [91.26646423, 23.95039177], [91.26741791, 23.95281029], [91.26773071, 23.9535923], [91.26851654, 23.95558167], [91.2696228, 23.95833015], [91.2702179, 23.95981026], [91.27072906, 23.96114731], [91.27145386, 23.96304703], [91.27184296, 23.9636116], [91.27189636, 23.9636879], [91.27331543, 23.9666748], [91.27593231, 23.97005463], [91.27868652, 23.97387695], [91.27987671, 23.97680855], [91.27992249, 23.97692108], [91.28157806, 23.98017883], [91.28164673, 23.98030663], [91.28367615, 23.9831028], [91.28557587, 23.98309326], [91.28570557, 23.98309326], [91.28541565, 23.98196793], [91.28553772, 23.98205185], [91.28562164, 23.98205948], [91.28572083, 23.98198509], [91.28588867, 23.98195076], [91.28595734, 23.98200607], [91.28606415, 23.98215485], [91.28617096, 23.98207664], [91.28599548, 23.98184967], [91.28593445, 23.98173141], [91.28590393, 23.98153877], [91.28583527, 23.98122025], [91.28578186, 23.9809494], [91.28572845, 23.98060608], [91.28569794, 23.98045731], [91.28562164, 23.9804039], [91.28536987, 23.98035812], [91.28522491, 23.98029327], [91.28505707, 23.98009872], [91.284935, 23.97998047], [91.28488159, 23.97973824], [91.2849884, 23.97961235], [91.28510284, 23.97945404], [91.28517914, 23.97938728], [91.2852478, 23.97920609], [91.28520203, 23.97903824], [91.28507996, 23.97875786], [91.28491974, 23.97839546], [91.28479004, 23.97808075], [91.28478241, 23.97800636], [91.28462982, 23.97763062], [91.28460693, 23.97739601], [91.28469086, 23.9772892], [91.2846756, 23.97715187], [91.28477478, 23.97700691], [91.28487396, 23.97689247], [91.2851944, 23.97664452], [91.28541565, 23.9765892], [91.28554535, 23.9765625], [91.28569031, 23.97651291], [91.28581238, 23.97632217], [91.28588867, 23.97622871], [91.28598785, 23.97614098], [91.28619385, 23.97606087], [91.28636169, 23.97605515], [91.28657532, 23.9761219], [91.28662109, 23.97606468], [91.28665924, 23.97587395], [91.28656769, 23.97552872], [91.28652954, 23.97525406], [91.28650665, 23.97499466], [91.28652191, 23.97489357], [91.28656006, 23.97479439], [91.28665161, 23.97468567], [91.28676605, 23.97461891], [91.28697968, 23.97445107], [91.28701019, 23.97436714], [91.28701019, 23.97422791], [91.28700256, 23.97402], [91.287117, 23.97388268], [91.28722382, 23.97380257], [91.28739166, 23.97397232], [91.28751373, 23.97410965], [91.28751373, 23.97418404], [91.28759003, 23.97417068], [91.28765106, 23.97411728], [91.28767395, 23.97404099], [91.28761292, 23.97386551], [91.28748322, 23.97363663], [91.28739929, 23.97346497], [91.28736115, 23.97333145], [91.28731537, 23.97308159], [91.28723145, 23.97285461], [91.28707123, 23.97277451], [91.28690338, 23.97269058], [91.28672791, 23.97257042], [91.28668976, 23.97243881], [91.28672791, 23.97234344], [91.28682709, 23.97218704], [91.2869873, 23.97202682], [91.28707123, 23.97190475], [91.28712463, 23.97178268], [91.28712463, 23.9715519], [91.28717041, 23.9713192], [91.28733826, 23.9710083], [91.2875061, 23.97083855], [91.2877121, 23.97070313], [91.28791809, 23.97045517], [91.2878418, 23.97037315], [91.28765869, 23.9703083], [91.28756714, 23.97022057], [91.28751373, 23.9701252], [91.28746033, 23.96993446], [91.28734589, 23.96971703], [91.28702545, 23.96945572], [91.28699493, 23.96937752], [91.28697205, 23.96926689], [91.28697968, 23.9691906], [91.28704071, 23.96903229], [91.28716278, 23.96885681], [91.28733826, 23.96863556], [91.28736115, 23.96851921], [91.28742981, 23.96831322], [91.28760529, 23.96817207], [91.28770447, 23.96814537], [91.28778839, 23.96818161], [91.28784943, 23.96825218], [91.28790283, 23.96834564], [91.28801727, 23.96853447], [91.28817749, 23.96858788], [91.28833008, 23.96861458], [91.28857422, 23.96858978], [91.28878021, 23.96858788], [91.28897858, 23.96854782], [91.28907013, 23.96846771], [91.2893219, 23.96843338], [91.28939056, 23.96835518], [91.28948212, 23.96820068], [91.28948975, 23.96807861], [91.29057312, 23.96850204], [91.29309082, 23.96948242], [91.2942276, 23.97022057], [91.29430389, 23.9702816], [91.29594421, 23.97157097], [91.2960968, 23.97161865], [91.29946899, 23.97265053], [91.2983551, 23.97450256], [91.29810333, 23.97491837], [91.2975769, 23.97578621], [91.2974472, 23.97599792], [91.29721069, 23.97638702], [91.29801941, 23.9778614], [91.29819489, 23.97818375], [91.29849243, 23.97873497], [91.29898834, 23.97964096], [91.29973602, 23.98103333], [91.30072784, 23.9828701], [91.30075836, 23.98327446], [91.30076599, 23.98334694], [91.30101776, 23.98374176], [91.30192566, 23.98501968], [91.30230713, 23.98583984], [91.3026886, 23.98657417], [91.30342102, 23.987957], [91.30330658, 23.98801994], [91.30316162, 23.9881134], [91.30295563, 23.98883247], [91.30281067, 23.98913956], [91.3026886, 23.98924065], [91.30259705, 23.98923111], [91.30250549, 23.98922157], [91.30237579, 23.98924637], [91.30223083, 23.98936081], [91.30228424, 23.9895668], [91.30229187, 23.98970795], [91.30217743, 23.98995018], [91.30219269, 23.99023438], [91.30219269, 23.99030685], [91.30204773, 23.99064445], [91.30217743, 23.99074936], [91.30224609, 23.99082756], [91.30213928, 23.99092293], [91.30200195, 23.99096107], [91.30194855, 23.99103737], [91.30188751, 23.99114799], [91.30188751, 23.99123764], [91.30194855, 23.99141121], [91.30197906, 23.99159813], [91.30206299, 23.99176407], [91.30219269, 23.99183273], [91.30223846, 23.99196625], [91.30221558, 23.99217987], [91.30211639, 23.9924736], [91.30210876, 23.99259377], [91.30201721, 23.9928112], [91.30186462, 23.99319077], [91.30168915, 23.99330902], [91.3015976, 23.99337959], [91.30157471, 23.99348259], [91.30152893, 23.99367332], [91.30137634, 23.99377632], [91.3013382, 23.99385071], [91.30138397, 23.99394035], [91.3014679, 23.99396896], [91.30151367, 23.99412537], [91.30156708, 23.99428558], [91.30162048, 23.99445343], [91.30175018, 23.99455643], [91.30179596, 23.99462318], [91.30181885, 23.99476814], [91.30194855, 23.99489403], [91.30198669, 23.99497604], [91.30200958, 23.99508095], [91.30202484, 23.99535751], [91.30207825, 23.99551773], [91.3024826, 23.99568176], [91.3025589, 23.99575615], [91.30251312, 23.99599457], [91.30258179, 23.99604988], [91.30265808, 23.99611473], [91.30275726, 23.99614525], [91.30290222, 23.99619293], [91.30297089, 23.99629593], [91.30290985, 23.99642754], [91.302948, 23.9965744], [91.30322266, 23.99662209], [91.30342865, 23.99672127], [91.30352783, 23.9967308], [91.30358124, 23.99682808], [91.30364227, 23.99700928], [91.3034668, 23.99705315], [91.3033371, 23.99698257], [91.3032608, 23.99694443], [91.30318451, 23.99690056], [91.30304718, 23.99690247], [91.30305481, 23.99700928], [91.3031311, 23.99706841], [91.30328369, 23.99721336], [91.30325317, 23.99729729], [91.30313873, 23.99733353], [91.30337524, 23.99761009], [91.30349731, 23.99791718], [91.30357361, 23.99803734], [91.30382538, 23.99805641], [91.30394745, 23.99814034], [91.30405426, 23.99799347], [91.30399323, 23.99750519], [91.30414581, 23.99733543], [91.30420685, 23.99725342], [91.30434418, 23.99712944], [91.30458832, 23.99677086], [91.30432892, 23.99647331], [91.30445862, 23.99601173], [91.30480194, 23.9960022], [91.30492401, 23.99584007], [91.30501556, 23.995718], [91.30511475, 23.99565125], [91.30513763, 23.99539566], [91.3052597, 23.99535942], [91.30545807, 23.99555779], [91.30558014, 23.99554634], [91.30567169, 23.99541092], [91.30575562, 23.99535942], [91.30593109, 23.99526024], [91.30605316, 23.99517441], [91.30636597, 23.9952755], [91.30691528, 23.99509811], [91.30705261, 23.9949913], [91.30755615, 23.99489212], [91.30763245, 23.99484825], [91.3075943, 23.99461365], [91.30775452, 23.99457169], [91.30786133, 23.99451065], [91.30792236, 23.99428749], [91.30799866, 23.9942379], [91.30819702, 23.99421692], [91.30839539, 23.99420547], [91.30858612, 23.99415016], [91.30866241, 23.99409294], [91.308815, 23.99394035], [91.30895233, 23.99387741], [91.30909729, 23.99378777], [91.30912781, 23.99359322], [91.30921173, 23.99350929], [91.30934906, 23.99344254], [91.30945587, 23.99333382], [91.30963135, 23.99327469], [91.30970764, 23.99309731], [91.31002808, 23.99313164], [91.31022644, 23.99330711], [91.31032562, 23.99329567], [91.31025696, 23.99306107], [91.31008148, 23.992836], [91.31015015, 23.99278069], [91.31026459, 23.99279213], [91.31040192, 23.99279594], [91.31053162, 23.99271202], [91.3106308, 23.99258804], [91.3108902, 23.99250031], [91.31095123, 23.9924469], [91.31085205, 23.99231529], [91.3109436, 23.99224663], [91.31106567, 23.99217033], [91.31098938, 23.99193001], [91.31106567, 23.99185371], [91.31127167, 23.9919529], [91.31147003, 23.99192238], [91.31175232, 23.99173164], [91.31202698, 23.99179077], [91.31217194, 23.99160767], [91.31237793, 23.9915905], [91.31257629, 23.99145889], [91.31322479, 23.99128914], [91.3134079, 23.99128151], [91.31354523, 23.99121857], [91.31386566, 23.99121284], [91.31407166, 23.99127007], [91.31415558, 23.99113083], [91.31424713, 23.99120903], [91.31434631, 23.99126244], [91.31446075, 23.99114037], [91.31454468, 23.99090195], [91.31474304, 23.99068832], [91.31488037, 23.99057198], [91.31515503, 23.99064064], [91.31534576, 23.99070168], [91.31575012, 23.99069023], [91.3159256, 23.99067116], [91.31600952, 23.99067879], [91.31616974, 23.99088097], [91.31637573, 23.99076843], [91.31651306, 23.99068069], [91.31673431, 23.99069786], [91.31680298, 23.99079323], [91.3168869, 23.99085236], [91.31699371, 23.99101448], [91.31721497, 23.99143219], [91.31764221, 23.99170303], [91.31778717, 23.99193382], [91.31803131, 23.99210358], [91.31816101, 23.99221802], [91.31826019, 23.99225616], [91.31838989, 23.99235916], [91.31850433, 23.99240494], [91.31868744, 23.99254799], [91.31908417, 23.99261284], [91.31923676, 23.99283981], [91.31952667, 23.99301529], [91.31974792, 23.99311256], [91.31996918, 23.99309921], [91.32022858, 23.99326706], [91.32038116, 23.99336624], [91.32051849, 23.99368477], [91.32079315, 23.99374008], [91.32082367, 23.99391747], [91.32150269, 23.99376488], [91.3217392, 23.99380684], [91.32219696, 23.99412155], [91.32283783, 23.99431038], [91.32305908, 23.99445343], [91.32325745, 23.99446106], [91.32346344, 23.99463463], [91.32363892, 23.99461555], [91.32385254, 23.99427986], [91.32392883, 23.9942112], [91.32437897, 23.99424362], [91.32444763, 23.99412346], [91.3243866, 23.99398804], [91.324646, 23.99377251], [91.32472992, 23.99354172], [91.32520294, 23.99353218], [91.32566833, 23.99262047], [91.32574463, 23.99247551], [91.32604218, 23.99250984], [91.32616425, 23.9922123], [91.32666016, 23.99213982], [91.32682037, 23.99170494], [91.32744598, 23.99187851], [91.3279953, 23.99165535], [91.32798004, 23.99176598], [91.32820129, 23.9919796], [91.32839203, 23.99189758], [91.32859802, 23.99190903], [91.32884979, 23.99197197], [91.32904053, 23.9922123], [91.32915497, 23.99225616], [91.32931519, 23.99238777], [91.32984161, 23.99239731], [91.32998657, 23.99261665], [91.33022308, 23.99233627], [91.33036804, 23.99235916], [91.33032227, 23.99202919], [91.33073425, 23.99195671], [91.33097839, 23.99201393], [91.33119202, 23.99209595], [91.33132172, 23.99202156], [91.33135223, 23.99190712], [91.33141327, 23.99181747], [91.33135223, 23.99160767], [91.33145142, 23.99147224], [91.33153534, 23.99135208], [91.33182526, 23.99150848], [91.33191681, 23.99146461], [91.33197784, 23.99128151], [91.33224487, 23.9910717], [91.33267212, 23.99126625], [91.33275604, 23.99103928], [91.33305359, 23.99111176], [91.33334351, 23.9907074], [91.33371735, 23.99079323], [91.33374023, 23.9905777], [91.33377075, 23.99040413], [91.33388519, 23.99038506], [91.33406067, 23.99041367], [91.33413696, 23.9903717], [91.33412933, 23.99001884], [91.33395386, 23.99000168], [91.33392334, 23.98962593], [91.33426666, 23.98963737], [91.33425903, 23.98955917], [91.33424377, 23.98904419], [91.3345108, 23.9889164], [91.33475494, 23.98871803], [91.33499146, 23.98871803], [91.33503723, 23.98877716], [91.33509827, 23.98887062], [91.33521271, 23.98893356], [91.33555603, 23.98879051], [91.33557129, 23.98858643], [91.33570862, 23.98855019], [91.33578491, 23.98848534], [91.33570862, 23.9883194], [91.33560944, 23.9881649], [91.33567047, 23.98798943], [91.33579254, 23.98793221], [91.3359375, 23.98770714], [91.33609009, 23.98767471], [91.33623505, 23.98724365], [91.33640289, 23.98711586], [91.33644867, 23.98701286], [91.33628845, 23.98674965], [91.3363266, 23.98651695], [91.33653259, 23.98657417], [91.33669281, 23.98650169], [91.33705902, 23.98638153], [91.33692169, 23.98615265], [91.33686829, 23.98607063], [91.33687592, 23.98587418], [91.33689117, 23.98563957], [91.33705139, 23.98527527], [91.33721924, 23.9847374], [91.33734894, 23.98456955], [91.33757782, 23.98452759], [91.33778381, 23.98458481], [91.33791351, 23.98441315], [91.33816528, 23.98443794], [91.33837891, 23.98431778], [91.33855438, 23.98441124], [91.33879089, 23.98436546], [91.33896637, 23.984375], [91.33912659, 23.98433495], [91.33937836, 23.98408699], [91.33934021, 23.98384666], [91.33940887, 23.98378181], [91.33959198, 23.98373985], [91.33957672, 23.98348427], [91.33956146, 23.98329544], [91.33970642, 23.98311615], [91.33988953, 23.9829464], [91.34008026, 23.98284531], [91.34028625, 23.98273277], [91.34043884, 23.98260117], [91.34050751, 23.98241997], [91.34056854, 23.9822464], [91.34082031, 23.98219681], [91.34116364, 23.98212624], [91.34140778, 23.98225403], [91.34159088, 23.98229408], [91.34174347, 23.98229599], [91.34211731, 23.98241234], [91.34226227, 23.98267174], [91.3423996, 23.9827404], [91.34266663, 23.98275566], [91.34281921, 23.98313332], [91.34290314, 23.98318863], [91.34315491, 23.9831295], [91.34377289, 23.98300934], [91.34413147, 23.98292923], [91.34446716, 23.9828701], [91.34455872, 23.98289108], [91.34498596, 23.98332405], [91.34555054, 23.9831562], [91.34567261, 23.98333359], [91.34599304, 23.98378754], [91.34630585, 23.98377037], [91.3465271, 23.98397446], [91.34687042, 23.98410797], [91.34720612, 23.98433304], [91.34746552, 23.98434258], [91.34777069, 23.98409081], [91.34803009, 23.98410225], [91.34873962, 23.98396492], [91.34914398, 23.9838047], [91.34940338, 23.98374557], [91.3496933, 23.98357964], [91.34994507, 23.98337555], [91.34985352, 23.98316574], [91.34992981, 23.98307991], [91.35009003, 23.98310471], [91.35017395, 23.98306656], [91.35025787, 23.98299217], [91.35025787, 23.98277473], [91.35050201, 23.98281288], [91.35064697, 23.98265839], [91.35080719, 23.98264694], [91.35084534, 23.98270798], [91.35152435, 23.98264122], [91.35169983, 23.98269272], [91.35189819, 23.98258781], [91.35194397, 23.98246765], [91.352211, 23.98241425], [91.35250092, 23.98233032], [91.35266113, 23.9822197], [91.3527298, 23.98186684], [91.35300446, 23.98200607], [91.35321045, 23.98209], [91.35335541, 23.98221207], [91.35355377, 23.9822731], [91.35373688, 23.9823761], [91.35404205, 23.982584], [91.3540802, 23.98283386], [91.35428619, 23.9829216], [91.35424042, 23.98316002], [91.3543396, 23.98329163], [91.35494232, 23.98357773], [91.35502625, 23.9837265], [91.35590363, 23.98408127], [91.35636139, 23.98415565], [91.35726929, 23.98407745], [91.35873413, 23.98441696], [91.35905457, 23.98548508], [91.36022949, 23.986063], [91.36100006, 23.98625565], [91.3615799, 23.9863987], [91.36245728, 23.98551559], [91.36276245, 23.98529053], [91.36380768, 23.98469925], [91.36412811, 23.98451614], [91.36580658, 23.98356819], [91.36975098, 23.98079109], [91.3704834, 23.98028564], [91.37310791, 23.97851563], [91.37548828, 23.97747803], [91.37823486, 23.97695732], [91.37902832, 23.9786911], [91.3789978, 23.97885704], [91.37892914, 23.9792347], [91.37944794, 23.97909927], [91.3795929, 23.97915649], [91.37944794, 23.97939301], [91.3793335, 23.97948837], [91.37911224, 23.97966957], [91.37900543, 23.97975922], [91.37905121, 23.98018456], [91.37876892, 23.9801178], [91.37859344, 23.97991562], [91.37836456, 23.97986603], [91.37830353, 23.97998238], [91.37831116, 23.98021698], [91.37826538, 23.98028374], [91.37789917, 23.98006821], [91.37767792, 23.98005676], [91.37768555, 23.98026466], [91.37846375, 23.98097038], [91.37862396, 23.98088646], [91.37830353, 23.98263741], [91.37815094, 23.98274231], [91.37798309, 23.98285294], [91.3779068, 23.98287964], [91.37776947, 23.98288345], [91.3775177, 23.98288536], [91.37732697, 23.9827919], [91.37727356, 23.98297882], [91.37736511, 23.98311043], [91.37745667, 23.98324585], [91.3775177, 23.98346519], [91.37723541, 23.98354721], [91.37715149, 23.98357201], [91.37718201, 23.98369408], [91.37727356, 23.98403168], [91.37717438, 23.98420525], [91.37710571, 23.98432732], [91.37726593, 23.9845829], [91.37766266, 23.98467255], [91.3777771, 23.98477554], [91.37785339, 23.98495293], [91.37776947, 23.98525047], [91.37767792, 23.98553467], [91.37743378, 23.98544502], [91.37739563, 23.98534775], [91.37747192, 23.98504066], [91.37741089, 23.98496056], [91.37725067, 23.98498726], [91.37714386, 23.98509598], [91.37709045, 23.98524284], [91.37706757, 23.98568535], [91.37696075, 23.9857502], [91.37673187, 23.98584366], [91.37661743, 23.98598099], [91.37657928, 23.98622704], [91.3765564, 23.98661613], [91.37613678, 23.98680878], [91.37617493, 23.98693848], [91.37619019, 23.98701096], [91.37640381, 23.98728943], [91.37664795, 23.98745728], [91.37676239, 23.98753548], [91.37683868, 23.9876461], [91.37665558, 23.98796272], [91.37647247, 23.98827362], [91.37651062, 23.98844337], [91.37660217, 23.98843002], [91.37703705, 23.98814774], [91.37689209, 23.9901123], [91.37690735, 23.99027634], [91.37660217, 23.99018288], [91.37664795, 23.99047661], [91.37666321, 23.99059105], [91.37670898, 23.99072266], [91.37695312, 23.99086761], [91.37714386, 23.99332047], [91.37705231, 23.99332809], [91.37691498, 23.99325371], [91.37684631, 23.99315834], [91.37657928, 23.99279404], [91.37638855, 23.99292564], [91.37625122, 23.99315262], [91.3762207, 23.9934082], [91.37627411, 23.99349213], [91.37646484, 23.99375534], [91.37639618, 23.99383926], [91.37612152, 23.99390411], [91.37562561, 23.99383354], [91.37523651, 23.9937706], [91.37506866, 23.9938755], [91.37494659, 23.9939537], [91.37502289, 23.99411392], [91.37504578, 23.99431992], [91.37503815, 23.99447441], [91.37493896, 23.99472427], [91.37461853, 23.99489403], [91.37438965, 23.99501228], [91.37417603, 23.99510384], [91.37418365, 23.99531746], [91.37428284, 23.99543381], [91.37453461, 23.99552345], [91.37526703, 23.99558067], [91.37542725, 23.99551392], [91.37585449, 23.99519348], [91.3761673, 23.99529076], [91.37622833, 23.99543381], [91.37611389, 23.99565506], [91.37605286, 23.99576569], [91.37599182, 23.99595261], [91.37508392, 23.99669456], [91.37506866, 23.99654388], [91.37520599, 23.99645042], [91.37527466, 23.99640083], [91.37532043, 23.99624825], [91.37537384, 23.9961586], [91.37521362, 23.99611092], [91.3751297, 23.99609566], [91.37495422, 23.99606133], [91.37471771, 23.99622345], [91.37465668, 23.99650574], [91.37463379, 23.99660873], [91.3748703, 23.99687195], [91.37432861, 23.99731445], [91.37418365, 23.99732208], [91.37387848, 23.99747086], [91.37369537, 23.99776649], [91.37373352, 23.99825478], [91.37375641, 23.99855042], [91.37376404, 23.9987011], [91.37413788, 23.99894142], [91.37451172, 23.99920273], [91.37464905, 23.99918175], [91.37493896, 23.99900818], [91.37503052, 23.99892807], [91.37512207, 23.99925232], [91.37516785, 23.99941063], [91.37509155, 23.99971962], [91.37483978, 24.00003624], [91.37454224, 24.00029182], [91.37427521, 24.0004921], [91.37393188, 24.00075722], [91.373909, 24.00092888], [91.37388611, 24.00109863], [91.37391663, 24.00151253], [91.37413025, 24.00181198], [91.3742981, 24.00189209], [91.3744812, 24.00197983], [91.37475586, 24.0020237], [91.37492371, 24.00214386], [91.37490082, 24.00231743], [91.37467957, 24.00246048], [91.37428284, 24.00253868], [91.37397766, 24.00244904], [91.3733902, 24.00228119], [91.37329102, 24.00237465], [91.37326813, 24.00257111], [91.37325287, 24.0028038], [91.37358093, 24.0032692], [91.37404633, 24.00354385], [91.37421417, 24.00364304], [91.37435913, 24.00384521], [91.37432098, 24.00393677], [91.37409973, 24.00438118], [91.3742218, 24.00445366], [91.37590027, 24.00663376], [91.37771606, 24.0089817], [91.37949371, 24.01128578], [91.38126373, 24.01356697], [91.38306427, 24.01589203], [91.38485718, 24.01820946], [91.38618469, 24.01993179], [91.38686371, 24.02080917], [91.38729858, 24.02138138], [91.38756561, 24.02171707], [91.38923645, 24.02388382], [91.39080811, 24.02591133], [91.39074707, 24.02791405], [91.39109039, 24.02878761], [91.39148712, 24.02981949], [91.3941803, 24.03678894], [91.3948822, 24.03858566], [91.39567566, 24.04064178], [91.39638519, 24.04247093], [91.39639282, 24.04301453], [91.3964386, 24.04532242], [91.396492, 24.04785919], [91.39649963, 24.04833794], [91.39653778, 24.04975319], [91.39628601, 24.05014229], [91.39488983, 24.05231094], [91.39321136, 24.05491257], [91.39207458, 24.05669403], [91.39060211, 24.05897713], [91.389534, 24.06064034], [91.3883667, 24.06245232], [91.38722229, 24.06423187], [91.38552856, 24.06685638], [91.38471985, 24.0681076], [91.38350677, 24.06999969], [91.3822937, 24.07187843], [91.38137817, 24.07330894], [91.38098907, 24.07391357], [91.37966156, 24.07596397], [91.37849426, 24.0778923], [91.37841797, 24.07802391], [91.37759399, 24.07918167], [91.37723541, 24.07974052], [91.3770752, 24.07999229], [91.3769455, 24.08118629], [91.37683105, 24.08232117], [91.37656403, 24.08484077], [91.37631226, 24.08721542], [91.37605286, 24.08971977], [91.37593079, 24.0908432], [91.37591553, 24.09101677], [91.37590027, 24.09112358], [91.37587738, 24.09134674], [91.37582397, 24.09189034], [91.37581635, 24.09197617], [91.37578583, 24.09220314], [91.3757782, 24.09231186], [91.3755188, 24.09478188], [91.37532043, 24.09667778], [91.37500763, 24.09964943], [91.3747406, 24.10218811], [91.37452698, 24.10417938], [91.37439728, 24.10538101], [91.37434387, 24.10593414], [91.37432098, 24.10613632], [91.3744812, 24.10743523], [91.37453461, 24.10789871], [91.37481689, 24.10760307], [91.37490082, 24.10752678], [91.37528992, 24.10728264], [91.37547302, 24.10724258], [91.37548828, 24.10748291], [91.37802124, 24.10950089], [91.38356018, 24.1089592], [91.3844986, 24.10888672], [91.3862915, 24.10888672], [91.38769531, 24.10931396], [91.38941193, 24.10988617], [91.38952637, 24.10988426], [91.39161682, 24.10985947], [91.39170837, 24.10985565], [91.39489746, 24.10931396], [91.39618683, 24.10923576], [91.39665985, 24.10935593], [91.39694977, 24.109478], [91.39750671, 24.10970879], [91.39772034, 24.10967064], [91.3980484, 24.10961342], [91.39819336, 24.10968399], [91.39850616, 24.10984039], [91.39910889, 24.11035347], [91.39930725, 24.11052513], [91.39989471, 24.11125183], [91.40013123, 24.1114769], [91.40111542, 24.11156845], [91.40146637, 24.11160278], [91.40109253, 24.11100388], [91.40106201, 24.1108532], [91.40106964, 24.11076736], [91.40131378, 24.10976219], [91.40200043, 24.10952377], [91.40226746, 24.10957718], [91.40287781, 24.10953712], [91.40294647, 24.10949516], [91.40306854, 24.10942078], [91.40373993, 24.10920715], [91.4043808, 24.1092453], [91.40493011, 24.10928726], [91.40565491, 24.10934448], [91.40650177, 24.10940552], [91.40670776, 24.10941887], [91.40745544, 24.1094017], [91.40843201, 24.10932732], [91.40894318, 24.10936546], [91.40974426, 24.10938835], [91.41007996, 24.10951996], [91.41030884, 24.10970879], [91.41067505, 24.11000633], [91.41085815, 24.11010361], [91.411026, 24.11013985], [91.41249847, 24.11008453], [91.41372681, 24.10986328], [91.41437531, 24.10968018], [91.41521454, 24.10928535], [91.41624451, 24.10880852], [91.41668701, 24.10857391], [91.41677856, 24.10852242], [91.41714478, 24.10831451], [91.41770172, 24.10844231], [91.41822815, 24.10856438], [91.41848755, 24.1086216], [91.41883087, 24.10864639], [91.41914368, 24.10866928], [91.41975403, 24.10860062], [91.42015076, 24.10855865], [91.420578, 24.10845947], [91.42094421, 24.10837555], [91.42223358, 24.10796547], [91.42354584, 24.10755157], [91.42511749, 24.10738373], [91.42557526, 24.10703087], [91.42571259, 24.10795021], [91.42645264, 24.10796356], [91.42654419, 24.10796547], [91.42694092, 24.10814095], [91.42717743, 24.10824394], [91.42749786, 24.10844231], [91.42778778, 24.10853958], [91.42805481, 24.10858727], [91.42835999, 24.10848236], [91.42856598, 24.10835266], [91.4286499, 24.10817337], [91.42858124, 24.10797501], [91.4288559, 24.10792732], [91.42894745, 24.10790062], [91.42905426, 24.10787964], [91.43049622, 24.10758591], [91.43083954, 24.10424042], [91.43187714, 24.10210991], [91.4319458, 24.10208702], [91.43370056, 24.10148048], [91.4337616, 24.10159492], [91.43424225, 24.10156631], [91.4343338, 24.10126114], [91.43440247, 24.10103226], [91.43444061, 24.10095596], [91.43453979, 24.10093117], [91.43477631, 24.10095024], [91.43506622, 24.10096931], [91.43539429, 24.10111809], [91.43572998, 24.10131264], [91.436409, 24.10193825], [91.43677521, 24.10245132], [91.43694305, 24.10266304], [91.43711853, 24.10283089], [91.4372406, 24.10287094], [91.43779755, 24.10281372], [91.43796539, 24.10272217], [91.43873596, 24.10314941], [91.4405365, 24.10309219], [91.44067383, 24.10308838], [91.44207764, 24.10089111], [91.44412231, 24.09796906], [91.44425964, 24.09800529], [91.44432831, 24.0983429], [91.44445038, 24.09853363], [91.44483185, 24.0987339], [91.44506073, 24.09888458], [91.44541168, 24.09913254], [91.44585419, 24.09911346], [91.44642639, 24.09941483], [91.44662476, 24.0993309], [91.44680023, 24.09939957], [91.44660187, 24.09965897], [91.44681549, 24.09976387], [91.44691467, 24.09974861], [91.44701385, 24.09960365], [91.44706726, 24.09949684], [91.44750214, 24.09944916], [91.4477005, 24.09955978], [91.44779205, 24.09953499], [91.4479599, 24.09968376], [91.44760132, 24.09976768], [91.44762421, 24.09991264], [91.44749451, 24.10003853], [91.44744873, 24.10013199], [91.44781494, 24.10023689], [91.44816589, 24.10042381], [91.44815063, 24.10076141], [91.44832611, 24.1008625], [91.44848633, 24.10046577], [91.44856262, 24.10057068], [91.4486618, 24.1008358], [91.44878387, 24.10087204], [91.44883728, 24.1007328], [91.44895172, 24.10074615], [91.44904327, 24.10085106], [91.44918823, 24.10070229], [91.44924927, 24.10085869], [91.44950867, 24.10105324], [91.44934082, 24.10110283], [91.44944, 24.10156441], [91.44953918, 24.10159492], [91.44978333, 24.10129738], [91.4496994, 24.10120583], [91.44985962, 24.10099411], [91.4499054, 24.1012001], [91.45019531, 24.10114288], [91.45027924, 24.10132027], [91.45036316, 24.10130882], [91.45043182, 24.10121536], [91.45083618, 24.10123253], [91.45072937, 24.10097885], [91.45095062, 24.10097694], [91.4509201, 24.10082436], [91.45087433, 24.1006794], [91.45111847, 24.10064697], [91.45114899, 24.10046768], [91.45088959, 24.100317], [91.45089722, 24.10024071], [91.45118713, 24.10006332], [91.4512558, 24.09994698], [91.45120239, 24.09983063], [91.45110321, 24.09962082], [91.45155334, 24.09970474], [91.45197296, 24.09945297], [91.45191193, 24.09931183], [91.45189667, 24.09920502], [91.45178986, 24.09898376], [91.45211029, 24.09869766], [91.45199585, 24.09840584], [91.45240021, 24.09826469], [91.4525528, 24.09820557], [91.4528656, 24.09831047], [91.45315552, 24.09845161], [91.4532547, 24.09838486], [91.45322418, 24.09814644], [91.45343781, 24.09814262], [91.45363617, 24.09803772], [91.45346832, 24.09850121], [91.45346832, 24.09863091], [91.45360565, 24.09870338], [91.45379639, 24.09868813], [91.45388794, 24.09871292], [91.45399475, 24.09876251], [91.45420074, 24.09878922], [91.4552002, 24.09803009], [91.45532227, 24.09803009], [91.45794678, 24.09804916], [91.46125793, 24.09810066], [91.46383667, 24.0975914], [91.46387482, 24.09765434], [91.46394348, 24.09770012], [91.46412659, 24.09799576], [91.4642868, 24.09810257], [91.4648056, 24.09845352], [91.46540833, 24.09877205], [91.46579742, 24.09883308], [91.46594238, 24.09889603], [91.46726227, 24.09921837], [91.46798706, 24.09935379], [91.46833038, 24.09938622], [91.46846008, 24.09935188], [91.46881104, 24.09926033], [91.46923828, 24.09912682], [91.46970367, 24.09897423], [91.46993256, 24.09889984], [91.47055817, 24.09878922], [91.47065735, 24.09880829], [91.47084808, 24.09884453], [91.47122955, 24.09892464], [91.47163391, 24.09916878], [91.47187042, 24.09979057], [91.47195435, 24.09993935], [91.47262573, 24.10108757], [91.47310638, 24.10190773], [91.47315979, 24.10185051], [91.47335815, 24.10171318], [91.47364807, 24.1016655], [91.4731369, 24.10084534], [91.4730835, 24.10060692], [91.47304535, 24.10046387], [91.47335815, 24.10007477], [91.47351074, 24.10008621], [91.47364044, 24.10008621], [91.47375488, 24.10008621], [91.47389221, 24.10008812], [91.47396851, 24.10008812], [91.47441101, 24.10009193], [91.47451019, 24.10022926], [91.47486115, 24.10034561], [91.4750061, 24.10024071], [91.47515106, 24.10051918], [91.47544098, 24.1004467], [91.47575378, 24.10065842], [91.47580719, 24.10050583], [91.47606659, 24.10051346], [91.47612762, 24.10005569], [91.47618103, 24.09978294], [91.47634888, 24.09982109], [91.47628784, 24.0995636], [91.47670746, 24.09926796], [91.47678375, 24.09921265], [91.47789001, 24.09843445], [91.47807312, 24.09830856], [91.47814178, 24.0982151], [91.47821045, 24.09817314], [91.47870636, 24.09807777], [91.47935486, 24.09816933], [91.47962952, 24.09820557], [91.48021698, 24.09828186], [91.48047638, 24.09830666], [91.48060608, 24.09832573], [91.48087311, 24.09824371], [91.48120117, 24.09810066], [91.48149872, 24.09805298], [91.48175812, 24.0981617], [91.48195648, 24.0979805], [91.48280334, 24.09796906], [91.48284149, 24.09783363], [91.48307037, 24.09765434], [91.48348999, 24.09759903], [91.48329926, 24.09716606], [91.4834137, 24.09686661], [91.4835968, 24.09665871], [91.48368835, 24.09653282], [91.48421478, 24.09658051], [91.48491669, 24.09655762], [91.48511505, 24.09647751], [91.48592377, 24.09614563], [91.48671722, 24.09600639], [91.48730469, 24.09583473], [91.48727417, 24.09546471], [91.4872818, 24.09539223], [91.48735809, 24.09539032], [91.48755646, 24.09560585], [91.48789215, 24.09556007], [91.48847198, 24.09583664], [91.48884583, 24.09559059], [91.48903656, 24.09557724], [91.48919678, 24.09566116], [91.48900604, 24.09586906], [91.48934937, 24.09611893], [91.48973846, 24.09629631], [91.49048615, 24.09634399], [91.49137115, 24.09652519], [91.49127197, 24.09679985], [91.49155426, 24.09708786], [91.49168396, 24.09722137], [91.49211121, 24.09718513], [91.49267578, 24.09684753], [91.49329376, 24.09650993], [91.49356079, 24.09636688], [91.49493408, 24.09564972], [91.49462128, 24.0950489], [91.49443817, 24.09467888], [91.49375916, 24.09353065], [91.49328613, 24.09262466], [91.49308777, 24.09224319], [91.49339294, 24.09057808], [91.49407196, 24.09026337], [91.49460602, 24.09001541], [91.49542999, 24.08951187], [91.49588013, 24.0891819], [91.49647522, 24.08873749], [91.4966507, 24.08860397], [91.49757385, 24.08743477], [91.50019836, 24.08726501], [91.50205231, 24.08703232], [91.50289154, 24.08717537], [91.5040741, 24.08712769], [91.50465393, 24.0871067], [91.50582123, 24.08707047], [91.50636292, 24.08700752], [91.50740814, 24.08667946], [91.50856781, 24.08657837], [91.50982666, 24.08618546], [91.51236725, 24.08539581], [91.51315308, 24.08516312], [91.51462555, 24.08475876], [91.51557159, 24.08444977], [91.51642609, 24.08412552], [91.51754761, 24.08370018], [91.51821899, 24.08348465], [91.52057648, 24.08273315], [91.52337646, 24.08181], [91.5253067, 24.08126068], [91.52758026, 24.08054161], [91.52881622, 24.08010101], [91.5297699, 24.07988358], [91.53079224, 24.0795536], [91.53369904, 24.07878494], [91.53488159, 24.07836533], [91.53659821, 24.07785416], [91.53879547, 24.07680321], [91.54039001, 24.07627678], [91.54087067, 24.0762043], [91.54167938, 24.07608986], [91.54283142, 24.07612038], [91.54332733, 24.07613182], [91.54415894, 24.07607651], [91.54473114, 24.07579231], [91.54503632, 24.07486916], [91.54521179, 24.07434464], [91.54563904, 24.07444], [91.54817963, 24.07499695], [91.5484848, 24.07506371], [91.54844666, 24.07520485], [91.54869843, 24.07550049], [91.54896545, 24.07584381], [91.54908752, 24.07601738], [91.54919434, 24.07612991], [91.54922485, 24.07625198], [91.54914093, 24.07635689], [91.54904938, 24.07647133], [91.54891205, 24.07659149], [91.54884338, 24.07666397], [91.54872894, 24.07684517], [91.54870605, 24.07696724], [91.54872894, 24.07707787], [91.5488205, 24.07720184], [91.54888916, 24.07733345], [91.5489502, 24.07747269], [91.54898071, 24.07759666], [91.54901886, 24.07769394], [91.54908752, 24.07782745], [91.54917908, 24.07795334], [91.55072021, 24.07786751], [91.55310059, 24.07657242], [91.55508423, 24.07650948], [91.55518341, 24.07653046], [91.55713654, 24.07849121], [91.55977631, 24.07891083], [91.56352234, 24.0785408], [91.56764221, 24.07834053], [91.57126617, 24.07837105], [91.57198334, 24.07864952], [91.57280731, 24.07897377], [91.57291412, 24.07924652], [91.57324219, 24.07923889], [91.57339478, 24.07920456], [91.57369232, 24.07932091], [91.57377625, 24.07935905], [91.57398987, 24.07937241], [91.57378387, 24.0798378], [91.57403564, 24.0799675], [91.57414246, 24.08009148], [91.57440186, 24.08014679], [91.57524109, 24.07958984], [91.57640076, 24.07979012], [91.57872009, 24.07977295], [91.58103943, 24.07853127], [91.58460999, 24.07611084], [91.58747864, 24.07695007], [91.58841705, 24.07723045], [91.59220123, 24.07883263], [91.59251404, 24.07914162], [91.59287262, 24.07956505], [91.59311676, 24.08001518], [91.59334564, 24.08065605], [91.59340668, 24.08115387], [91.59362793, 24.08225441], [91.59384155, 24.08279419], [91.59400177, 24.08300018], [91.59431458, 24.08314514], [91.59487152, 24.08328629], [91.5954895, 24.08332825], [91.5957489, 24.08330917], [91.59620667, 24.08332634], [91.59649658, 24.08333588], [91.59732056, 24.0834198], [91.59777832, 24.08368492], [91.59807587, 24.08402634], [91.59843445, 24.08460617], [91.59856415, 24.08541298], [91.59860992, 24.08572006], [91.59863281, 24.08617783], [91.59864044, 24.08635521], [91.59848022, 24.08664131], [91.59838104, 24.08677673], [91.59806061, 24.08699989], [91.59751129, 24.08724403], [91.59658813, 24.08751106], [91.59609985, 24.08774376], [91.59539032, 24.08826828], [91.59474182, 24.08867645], [91.5940094, 24.08891106], [91.59355164, 24.08906174], [91.59296417, 24.08933258], [91.59281921, 24.08960533], [91.5925293, 24.09039116], [91.59239197, 24.09070206], [91.59223938, 24.09125328], [91.59194183, 24.09165573], [91.59121704, 24.09275818], [91.59108734, 24.09313774], [91.59121704, 24.09340858], [91.59169006, 24.09368134], [91.59228516, 24.09360504], [91.59276581, 24.09329033], [91.59337616, 24.0929966], [91.59365845, 24.09293556], [91.59382629, 24.09288788], [91.59438324, 24.09296227], [91.59451294, 24.09300804], [91.59474182, 24.09309387], [91.5942688, 24.09469032], [91.59564972, 24.09558678], [91.59535217, 24.09598351], [91.5944519, 24.09665298], [91.59484863, 24.09676361], [91.59512329, 24.09684753], [91.59562683, 24.0970974], [91.59584808, 24.09712601], [91.59617615, 24.09662056], [91.59660339, 24.09648323], [91.59679413, 24.09632683], [91.59709167, 24.09608078], [91.59727478, 24.09599113], [91.59799957, 24.09616852], [91.59835052, 24.09630203], [91.59802246, 24.09658623], [91.5980072, 24.09675026], [91.59812164, 24.09682655], [91.59845734, 24.09693146], [91.59872437, 24.09712601], [91.5991745, 24.09724426], [91.59915924, 24.09686089], [91.5993042, 24.09672928], [91.59928131, 24.09640121], [91.59971619, 24.09646416], [91.59992981, 24.09636307], [91.60014343, 24.09620285], [91.60060883, 24.09606934], [91.60012054, 24.09570503], [91.6000824, 24.09555244], [91.60028076, 24.09544754], [91.60055542, 24.09551811], [91.60095215, 24.09568787], [91.6018219, 24.09576035], [91.60198975, 24.09608078], [91.60169983, 24.09642601], [91.60186768, 24.096632], [91.6020813, 24.09680367], [91.60253143, 24.09674454], [91.60303497, 24.09648514], [91.60276794, 24.09646606], [91.60246277, 24.09632492], [91.6023941, 24.09604073], [91.60250854, 24.095644], [91.60266876, 24.09552574], [91.60282135, 24.09547424], [91.60302734, 24.09560585], [91.60330963, 24.09559631], [91.60352325, 24.09565544], [91.60390472, 24.09614372], [91.60404205, 24.09621811], [91.60422516, 24.09618378], [91.60446167, 24.09591866], [91.60453796, 24.09564018], [91.60396576, 24.09524345], [91.60389709, 24.09513283], [91.60375214, 24.09489059], [91.60357666, 24.09465981], [91.60346985, 24.09455109], [91.60342407, 24.09432411], [91.603508, 24.0942173], [91.60371399, 24.09420395], [91.60392761, 24.09425926], [91.60431671, 24.09404564], [91.6044693, 24.09404564], [91.60463715, 24.09429932], [91.60479736, 24.09453583], [91.60497284, 24.09452248], [91.60508728, 24.09448051], [91.60525513, 24.09444618], [91.60547638, 24.09439659], [91.60564423, 24.09426498], [91.60552979, 24.0939827], [91.6055603, 24.09387398], [91.60552216, 24.09374046], [91.60543823, 24.09347916], [91.60547638, 24.09341621], [91.60562134, 24.09343147], [91.60584259, 24.09348297], [91.60579681, 24.09339523], [91.60581207, 24.09329224], [91.60590363, 24.0932579], [91.60607147, 24.09326363], [91.6062088, 24.09348869], [91.60638428, 24.09345245], [91.60646057, 24.093256], [91.60643768, 24.0929718], [91.60648346, 24.09288406], [91.60669708, 24.09298706], [91.60694885, 24.09313583], [91.60726929, 24.09331703], [91.60732269, 24.09347534], [91.60728455, 24.09368896], [91.60752869, 24.09378433], [91.60803223, 24.09342384], [91.60835266, 24.09311104], [91.60858154, 24.09288597], [91.60865784, 24.09275246], [91.60868073, 24.09248734], [91.6087265, 24.09227371], [91.60879517, 24.09220123], [91.60884857, 24.09214783], [91.6089859, 24.09216118], [91.60903168, 24.09231186], [91.60917664, 24.09280205], [91.60931396, 24.09299088], [91.60943604, 24.09291077], [91.60966492, 24.09280968], [91.6100769, 24.09273148], [91.61051178, 24.09267235], [91.61116791, 24.09246635], [91.61126709, 24.09230232], [91.61122894, 24.09206581], [91.61086273, 24.09197235], [91.6105957, 24.09189415], [91.61057281, 24.09181213], [91.61096191, 24.09179878], [91.61119843, 24.09181595], [91.61146545, 24.09196472], [91.61148071, 24.0921402], [91.61138153, 24.09268379], [91.61174774, 24.09316635], [91.61190033, 24.09328842], [91.61220551, 24.09316826], [91.61251068, 24.09319305], [91.61277008, 24.09314537], [91.61315155, 24.09309006], [91.61356354, 24.09297752], [91.61375427, 24.09292603], [91.61392975, 24.09302521], [91.61411285, 24.0933075], [91.61408234, 24.09366608], [91.61392975, 24.09404564], [91.61390686, 24.0943737], [91.61396027, 24.09459496], [91.61403656, 24.09458923], [91.61429596, 24.09462357], [91.61444092, 24.09472847], [91.61463165, 24.09487152], [91.61480713, 24.09430313], [91.61496735, 24.0941925], [91.61510468, 24.09432602], [91.61518097, 24.09459496], [91.61516571, 24.0951004], [91.615242, 24.09527779], [91.61566925, 24.09557724], [91.61582184, 24.09556198], [91.61579132, 24.09547234], [91.61567688, 24.09515953], [91.61569214, 24.09501457], [91.61608124, 24.09468651], [91.61660004, 24.09451103], [91.61693573, 24.09439468], [91.61714935, 24.0944519], [91.61722565, 24.09462357], [91.61725616, 24.09487724], [91.61701965, 24.09488106], [91.61681366, 24.09498978], [91.61678314, 24.09526062], [91.61710358, 24.09549713], [91.61762238, 24.09564209], [91.61785126, 24.09575272], [91.61811829, 24.09536552], [91.61843872, 24.09511185], [91.61857605, 24.09512329], [91.61855316, 24.09538651], [91.6186676, 24.09568024], [91.61860657, 24.09598923], [91.61865997, 24.09611893], [91.61888885, 24.09615707], [91.61915588, 24.0960865], [91.61935425, 24.09600449], [91.61949921, 24.09600067], [91.61955261, 24.09606361], [91.61927795, 24.09625626], [91.6193161, 24.09645653], [91.61949921, 24.09659004], [91.61972809, 24.09683037], [91.61985779, 24.0967865], [91.62005615, 24.09667969], [91.62049103, 24.09645844], [91.62084198, 24.09654617], [91.62091064, 24.09658432], [91.62094879, 24.09649467], [91.62093353, 24.09610176], [91.62116241, 24.09576225], [91.62137604, 24.09539413], [91.62146759, 24.09541512], [91.62162781, 24.09562874], [91.62189484, 24.09587669], [91.62191772, 24.09594917], [91.62195587, 24.09614372], [91.62177277, 24.09634399], [91.62186432, 24.09656715], [91.62237549, 24.09664726], [91.62277985, 24.09673309], [91.62271118, 24.09691048], [91.62254333, 24.09710312], [91.62252808, 24.09729195], [91.62256622, 24.09737015], [91.62271881, 24.09744263], [91.62516022, 24.09859467], [91.6257019, 24.09880066], [91.62579346, 24.09883308], [91.62561035, 24.09904671], [91.62554932, 24.09916878], [91.62570953, 24.09943199], [91.62587738, 24.09955215], [91.62611389, 24.09955215], [91.62622833, 24.09937096], [91.62632751, 24.09902573], [91.62698364, 24.09926224], [91.62702179, 24.0994854], [91.62705994, 24.09956932], [91.62744904, 24.09943008], [91.62760925, 24.0994873], [91.62765503, 24.09960747], [91.62763977, 24.09991837], [91.62757874, 24.10040283], [91.62773132, 24.10055923], [91.62787628, 24.1006279], [91.62819672, 24.10029793], [91.62856293, 24.10091972], [91.62880707, 24.10123634], [91.62897491, 24.10146713], [91.62917328, 24.10160637], [91.62936401, 24.10154533], [91.62947083, 24.10146332], [91.62940216, 24.10130119], [91.6291275, 24.10087585], [91.6290741, 24.1007309], [91.62919617, 24.10068893], [91.62934875, 24.1007061], [91.62932587, 24.10083961], [91.62937164, 24.1009407], [91.62949371, 24.10104942], [91.62968445, 24.10099983], [91.62984467, 24.10079193], [91.63015747, 24.10068893], [91.63026428, 24.1005497], [91.63407898, 24.10256958], [91.63776398, 24.1053257], [91.63671875, 24.10669708], [91.63703918, 24.10692215], [91.63832855, 24.10783386], [91.63946533, 24.10864067], [91.63970184, 24.10928917], [91.64054108, 24.1116333], [91.64110565, 24.11322403], [91.64061737, 24.11573982], [91.64022827, 24.11773682], [91.63986969, 24.11955261], [91.63983154, 24.11983299], [91.63946533, 24.12244606], [91.63920593, 24.12430954], [91.63905334, 24.12535667], [91.63877869, 24.12736511], [91.63851166, 24.12924576], [91.63844299, 24.12973595], [91.63708496, 24.13253593], [91.63596344, 24.1348362], [91.63545227, 24.13589287], [91.63472748, 24.13738441], [91.63436127, 24.13817787], [91.634758, 24.13881493], [91.63601685, 24.14073563], [91.6365509, 24.14155006], [91.63732147, 24.14272308], [91.63949585, 24.14603424], [91.64089966, 24.14818001], [91.64231873, 24.15033531], [91.64309692, 24.15152359], [91.64472198, 24.15400124], [91.64551544, 24.15521622], [91.64599609, 24.15594482], [91.64656067, 24.15674973], [91.64634705, 24.1578331], [91.64621735, 24.15859795], [91.64598846, 24.15995789], [91.64576721, 24.16125679], [91.64551544, 24.16274643], [91.64539337, 24.16346741], [91.6452713, 24.16419792], [91.64507294, 24.1653614], [91.64479065, 24.16700745], [91.64452362, 24.16858864], [91.64430237, 24.16988945], [91.64415741, 24.17072868], [91.64425659, 24.17101669], [91.64439392, 24.17145538], [91.64466095, 24.17230797], [91.64518738, 24.17399597], [91.64563751, 24.17544365], [91.64609528, 24.17689133], [91.64645386, 24.17801094], [91.64668274, 24.17875671], [91.6472702, 24.17854881], [91.64949799, 24.17776108], [91.65164185, 24.17700958], [91.65390015, 24.17620659], [91.65493011, 24.17584229], [91.65501404, 24.17586327], [91.65587616, 24.1760788], [91.65622711, 24.17628288], [91.65616608, 24.176548], [91.65608978, 24.17697906], [91.65594482, 24.17744446], [91.65590668, 24.17772675], [91.65610504, 24.17785263], [91.65621185, 24.17796707], [91.65628052, 24.1780529], [91.65641022, 24.17800331], [91.65670013, 24.17811203], [91.65685272, 24.17821503], [91.65707397, 24.17832375], [91.65717316, 24.17867088], [91.65740967, 24.17970276], [91.65727234, 24.17972946], [91.65710449, 24.17990494], [91.65727997, 24.1801033], [91.65721893, 24.18019676], [91.65701294, 24.18024254], [91.65706635, 24.18040848], [91.65689087, 24.18030167], [91.65679169, 24.18036079], [91.65704346, 24.18068123], [91.65723419, 24.18077087], [91.65731049, 24.18075562], [91.65739441, 24.18082619], [91.65760803, 24.18096352], [91.65769196, 24.18094254], [91.65791321, 24.1818428], [91.65818024, 24.18293953], [91.65835571, 24.18340683], [91.6582489, 24.18351936], [91.65846252, 24.18390656], [91.65857697, 24.18398094], [91.6584549, 24.18400002], [91.65817261, 24.18396378], [91.65811157, 24.18403435], [91.65822601, 24.18415833], [91.6584549, 24.18439674], [91.65849304, 24.18452454], [91.65846252, 24.18460846], [91.65825653, 24.18450737], [91.65808868, 24.18446159], [91.6574173, 24.1848278], [91.65744019, 24.1849308], [91.65788269, 24.18507957], [91.65808105, 24.18520164], [91.65834045, 24.1851387], [91.6583786, 24.1854229], [91.65857697, 24.18561172], [91.65852356, 24.18612099], [91.65847015, 24.18632698], [91.65840149, 24.18646622], [91.65830231, 24.18653679], [91.65830994, 24.18673134], [91.65841675, 24.18670845], [91.65860748, 24.18656731], [91.65871429, 24.18648529], [91.65877533, 24.18660355], [91.65888977, 24.18682289], [91.65882874, 24.18691635], [91.65849304, 24.18688393], [91.65827942, 24.18717766], [91.65816498, 24.18742752], [91.65831757, 24.18751335], [91.65856171, 24.18738174], [91.65868378, 24.18746948], [91.65871429, 24.187603], [91.65866852, 24.18786049], [91.65866852, 24.18798065], [91.65885925, 24.18810463], [91.65911865, 24.18814087], [91.65917206, 24.18829155], [91.65910339, 24.18835258], [91.65884399, 24.18837738], [91.65888977, 24.18853188], [91.65917206, 24.18859863], [91.65920258, 24.18870926], [91.65913391, 24.18884277], [91.65922546, 24.18906403], [91.65962219, 24.18935204], [91.6595993, 24.18945122], [91.65940857, 24.18951416], [91.65939331, 24.1896534], [91.65969086, 24.1896553], [91.65927887, 24.19122124], [91.65924835, 24.19136238], [91.65904999, 24.19140434], [91.65885162, 24.19145966], [91.65870667, 24.19130516], [91.65859222, 24.19141388], [91.65842438, 24.19152641], [91.65836334, 24.19160652], [91.65881348, 24.19176865], [91.65872955, 24.1918602], [91.65821075, 24.19188499], [91.65816498, 24.19198227], [91.65841675, 24.19220161], [91.65843964, 24.19241333], [91.65816498, 24.19295883], [91.6581192, 24.19305229], [91.65792847, 24.19314957], [91.657547, 24.19327545], [91.65750122, 24.19338226], [91.65769196, 24.19347], [91.6579361, 24.19345284], [91.65817261, 24.19340324], [91.65830231, 24.19338989], [91.65839386, 24.19350052], [91.65465546, 24.19523048], [91.65454102, 24.19514847], [91.65442657, 24.19523048], [91.6544342, 24.19533539], [91.65327454, 24.19587326], [91.65309906, 24.19595528], [91.65280914, 24.19589806], [91.65267181, 24.1959362], [91.65253448, 24.19602585], [91.6525116, 24.19630623], [91.65264893, 24.19652939], [91.65289307, 24.19667816], [91.65319824, 24.19647217], [91.65351105, 24.19657707], [91.65337372, 24.19678497], [91.65335846, 24.19709778], [91.65313721, 24.19729805], [91.65301514, 24.1972084], [91.65283203, 24.19704247], [91.65279388, 24.19730759], [91.6526947, 24.19751549], [91.65265656, 24.19758987], [91.65284729, 24.19762039], [91.65286255, 24.19771004], [91.65266418, 24.19777679], [91.65258789, 24.19788551], [91.65311432, 24.19802856], [91.65309906, 24.19814301], [91.65263367, 24.19818878], [91.65264893, 24.19832611], [91.65280151, 24.19849586], [91.65306091, 24.19868088], [91.6532135, 24.19905663], [91.65345001, 24.19908524], [91.65354919, 24.19909859], [91.65372467, 24.1989727], [91.65395355, 24.19858932], [91.65403748, 24.19861984], [91.65393829, 24.19896126], [91.65385437, 24.19923401], [91.653862, 24.19956398], [91.65395355, 24.20007324], [91.65393066, 24.20025063], [91.65390015, 24.20044518], [91.65367126, 24.20067406], [91.65368652, 24.20082474], [91.65369415, 24.20090103], [91.65377808, 24.20111465], [91.65345764, 24.2011795], [91.65333557, 24.20133209], [91.65345764, 24.20166779], [91.65339661, 24.20178413], [91.65299988, 24.20183182], [91.65312195, 24.20201111], [91.65350342, 24.20215416], [91.65357208, 24.20217896], [91.65385437, 24.20237923], [91.65377045, 24.2025795], [91.65361023, 24.20252037], [91.65345001, 24.2025547], [91.65350342, 24.20273781], [91.65362549, 24.20292664], [91.65351105, 24.20320511], [91.65335083, 24.20322227], [91.6532135, 24.20322418], [91.65319824, 24.20337486], [91.65338135, 24.20351601], [91.65331268, 24.20367813], [91.65316772, 24.20367432], [91.65306854, 24.20360374], [91.65280151, 24.20347214], [91.65268707, 24.20353317], [91.65254974, 24.20371628], [91.65259552, 24.20399857], [91.65271759, 24.20416451], [91.65290833, 24.20429039], [91.65302277, 24.20438004], [91.6529541, 24.20454025], [91.65292358, 24.20461655], [91.65287781, 24.20472908], [91.65260315, 24.20472527], [91.65235138, 24.20477486], [91.65223694, 24.20487595], [91.6523819, 24.20499229], [91.65276337, 24.20500565], [91.65273285, 24.20507813], [91.65266418, 24.20524216], [91.65232086, 24.20529938], [91.65222931, 24.20542717], [91.65232849, 24.20554161], [91.65248871, 24.20571899], [91.65242767, 24.20592117], [91.6519165, 24.2075119], [91.65179443, 24.207901], [91.65175629, 24.20804214], [91.65169525, 24.20814896], [91.65168762, 24.20840263], [91.65150452, 24.20863914], [91.65132904, 24.20896721], [91.6512146, 24.20896339], [91.65106201, 24.20895958], [91.65101624, 24.20902634], [91.65110016, 24.20916176], [91.65003967, 24.21096039], [91.64925385, 24.21232414], [91.64916229, 24.21248627], [91.64919281, 24.21265221], [91.64922333, 24.21273804], [91.64949036, 24.21294403], [91.64955139, 24.2131176], [91.6493988, 24.2132473], [91.64930725, 24.2131443], [91.64907837, 24.21319771], [91.64887238, 24.21335983], [91.64878845, 24.21356392], [91.64875793, 24.21371269], [91.64901733, 24.21372414], [91.6492691, 24.21373177], [91.64930725, 24.21399307], [91.64888763, 24.21430206], [91.64868927, 24.21457672], [91.64866638, 24.21479225], [91.64854431, 24.2148838], [91.64820862, 24.21465683], [91.64796448, 24.21474838], [91.64787292, 24.21478271], [91.64762878, 24.21506119], [91.6473465, 24.21520996], [91.64715576, 24.21532249], [91.64722443, 24.21552277], [91.64765167, 24.21558189], [91.64789581, 24.21566772], [91.64818573, 24.21570969], [91.64837646, 24.21577835], [91.64845276, 24.21590805], [91.64842987, 24.21617889], [91.64837646, 24.21637535], [91.64849854, 24.216465], [91.64871979, 24.21659088], [91.64868927, 24.2166748], [91.64848328, 24.21665573], [91.64825439, 24.21651268], [91.64809418, 24.2166481], [91.64826202, 24.21683693], [91.64860535, 24.21704674], [91.6488266, 24.2171917], [91.64884186, 24.21731949], [91.64849854, 24.21731186], [91.64839935, 24.21735764], [91.64834595, 24.21744728], [91.64859772, 24.21783638], [91.64852905, 24.21794701], [91.64823914, 24.21805763], [91.64817047, 24.21829605], [91.64801788, 24.21839714], [91.64774323, 24.21848297], [91.64766693, 24.21862602], [91.64775085, 24.21871948], [91.64794922, 24.218853], [91.64808655, 24.21901512], [91.64804077, 24.21930122], [91.64820099, 24.21949387], [91.64848328, 24.21959686], [91.64865112, 24.21969414], [91.64875793, 24.21982193], [91.64887238, 24.22024918], [91.64904022, 24.22026253], [91.64955139, 24.21999168], [91.64959717, 24.22006798], [91.64959717, 24.22044182], [91.64968109, 24.22059059], [91.64985657, 24.22039795], [91.64992523, 24.22006416], [91.65016937, 24.21984482], [91.64997101, 24.21966743], [91.64962006, 24.21966553], [91.6495285, 24.21945572], [91.64963531, 24.21926689], [91.64969635, 24.21921158], [91.65019989, 24.21910095], [91.65029907, 24.21907425], [91.65039063, 24.21904945], [91.65047455, 24.21888542], [91.65059662, 24.21868134], [91.65070343, 24.2185154], [91.65084839, 24.21850204], [91.65089417, 24.21869278], [91.65072632, 24.21892548], [91.65058899, 24.2191925], [91.65105438, 24.21945], [91.65162659, 24.21973228], [91.65195465, 24.21982193], [91.65198517, 24.21996307], [91.65192413, 24.22012138], [91.6519165, 24.2202549], [91.65198517, 24.22032547], [91.6521759, 24.22032738], [91.65219879, 24.22022247], [91.6521759, 24.21984291], [91.65229797, 24.21973991], [91.65244293, 24.21997833], [91.65245819, 24.22018242], [91.65233612, 24.22029686], [91.6522522, 24.22042084], [91.65224457, 24.22051048], [91.65233612, 24.22046852], [91.65267944, 24.22033882], [91.65279388, 24.22035408], [91.65296173, 24.22049522], [91.65296173, 24.2208252], [91.65305328, 24.22098541], [91.65348816, 24.22132683], [91.65361786, 24.22146797], [91.65366364, 24.22163773], [91.65381622, 24.22161102], [91.65412903, 24.22149467], [91.65423584, 24.22164917], [91.65427399, 24.22206116], [91.6542511, 24.22231674], [91.65406799, 24.22298813], [91.65407562, 24.22315788], [91.65423584, 24.22335052], [91.65460205, 24.22326469], [91.65459442, 24.22304726], [91.65522766, 24.22315788], [91.65538788, 24.22330856], [91.65547943, 24.22352409], [91.65571594, 24.22406197], [91.65576172, 24.22435188], [91.65588379, 24.22443962], [91.65598297, 24.22466278], [91.65592194, 24.2247448], [91.65590668, 24.22496414], [91.65595245, 24.22507286], [91.65607452, 24.2251606], [91.65633392, 24.22515106], [91.65663147, 24.22540283], [91.65645599, 24.22551918], [91.65634155, 24.22577286], [91.65621185, 24.22598076], [91.65616608, 24.22615242], [91.65620422, 24.22622871], [91.65653992, 24.2261219], [91.65692902, 24.2259922], [91.65706635, 24.22607613], [91.6569519, 24.22631836], [91.65683746, 24.22656822], [91.65676117, 24.22678185], [91.65673828, 24.22691536], [91.65699768, 24.22696114], [91.65731049, 24.22704887], [91.65744019, 24.22719002], [91.6574707, 24.22738457], [91.65739441, 24.22751999], [91.6576767, 24.22769928], [91.6577301, 24.22783661], [91.65786743, 24.22794914], [91.65802765, 24.22795677], [91.65826416, 24.22794342], [91.65840912, 24.22803116], [91.65843201, 24.22819519], [91.65848541, 24.22837448], [91.65864563, 24.22833061], [91.65911865, 24.22818756], [91.65937805, 24.22842026], [91.6595993, 24.228405], [91.65966797, 24.22846985], [91.65958405, 24.22873306], [91.65961456, 24.22891617], [91.66014099, 24.22877502], [91.66042328, 24.22885132], [91.66055298, 24.22883224], [91.66069794, 24.22873878], [91.66077423, 24.22875214], [91.66098785, 24.22894478], [91.66099548, 24.22909355], [91.66078949, 24.22917175], [91.66068268, 24.22930908], [91.66110229, 24.22960472], [91.66140747, 24.22943878], [91.66188049, 24.22947121], [91.66196442, 24.22959518], [91.66195679, 24.22974968], [91.66203308, 24.2299614], [91.6622467, 24.23011398], [91.6627121, 24.23022842], [91.66271973, 24.22964668], [91.66300201, 24.229599], [91.66319275, 24.22949409], [91.66324615, 24.22935486], [91.66329193, 24.2292366], [91.66355133, 24.22936249], [91.66364288, 24.22940254], [91.66374969, 24.22926331], [91.66385651, 24.22912407], [91.66395569, 24.22916031], [91.66414642, 24.22922707], [91.66424561, 24.22950363], [91.66405487, 24.22985458], [91.66425323, 24.23026657], [91.66413116, 24.23054123], [91.66384888, 24.23107529], [91.66381836, 24.23148727], [91.66421509, 24.23187447], [91.66410828, 24.23203468], [91.66412354, 24.23225784], [91.66444397, 24.23259735], [91.66468811, 24.23272324], [91.66481781, 24.23286819], [91.66517639, 24.23298454], [91.66517639, 24.23314285], [91.6649704, 24.23326683], [91.6648941, 24.23348236], [91.66508484, 24.23365211], [91.66534424, 24.23365593], [91.66556549, 24.23344803], [91.66571808, 24.23318863], [91.66587067, 24.23316765], [91.66599274, 24.2331295], [91.66622162, 24.23318291], [91.66638184, 24.23306274], [91.66629028, 24.23286629], [91.66630554, 24.23276901], [91.6663208, 24.23268509], [91.66650391, 24.23246765], [91.66665649, 24.23226166], [91.66674042, 24.23198318], [91.66685486, 24.23181725], [91.66708374, 24.2317543], [91.66737366, 24.23181343], [91.66755676, 24.23176575], [91.66783142, 24.23153496], [91.66793823, 24.23141289], [91.66799164, 24.23119736], [91.66790009, 24.23099709], [91.66764069, 24.23105049], [91.66742706, 24.23103142], [91.66729736, 24.23094559], [91.66714478, 24.23062706], [91.66731262, 24.23046684], [91.66738129, 24.23034859], [91.66752625, 24.23040009], [91.66874695, 24.22719955], [91.66872406, 24.22559166], [91.66867065, 24.22156906], [91.66909027, 24.21875191], [91.66763306, 24.21579742], [91.66746521, 24.21569252], [91.66712952, 24.21559525], [91.6672287, 24.21523476], [91.66718292, 24.21498299], [91.66684723, 24.21490669], [91.6668396, 24.2147789], [91.66699982, 24.21457481], [91.6668396, 24.21451569], [91.6667099, 24.21437836], [91.66692352, 24.21427345], [91.66705322, 24.21419144], [91.66728973, 24.21412277], [91.66735077, 24.21399307], [91.66710663, 24.21371651], [91.66719818, 24.2131424], [91.66686249, 24.21321106], [91.66679382, 24.21303177], [91.66679382, 24.21269035], [91.66660309, 24.21232414], [91.66659546, 24.21202278], [91.66673279, 24.21202469], [91.66718292, 24.21249771], [91.6673584, 24.21235657], [91.66714478, 24.21218109], [91.667099, 24.21174049], [91.66721344, 24.21137238], [91.66709137, 24.21103859], [91.6669693, 24.210886], [91.66690826, 24.21066093], [91.66755676, 24.21056175], [91.66777802, 24.21046066], [91.66791534, 24.21039581], [91.66802979, 24.21020889], [91.66806793, 24.20999336], [91.66809845, 24.20977592], [91.66811371, 24.209692], [91.66835022, 24.20990944], [91.66846466, 24.20989799], [91.66841125, 24.20969391], [91.66885376, 24.20929718], [91.66906738, 24.20939064], [91.66905975, 24.20911598], [91.66901398, 24.20895195], [91.66916656, 24.20891571], [91.66923523, 24.20895386], [91.66960144, 24.20915031], [91.6696167, 24.20901108], [91.66950989, 24.20884323], [91.66941833, 24.20878792], [91.66933441, 24.2087326], [91.66923523, 24.2086525], [91.66931915, 24.20843887], [91.66945648, 24.20837212], [91.66957092, 24.2083683], [91.66983032, 24.20848083], [91.66994476, 24.20837212], [91.67073059, 24.20761108], [91.67363739, 24.20421982], [91.67379761, 24.20275688], [91.67404175, 24.20252037], [91.67409515, 24.20232964], [91.67405701, 24.20213699], [91.67390442, 24.2017498], [91.67420959, 24.20175171], [91.67441559, 24.20200348], [91.67459106, 24.20223618], [91.67470551, 24.20219803], [91.67456818, 24.20174217], [91.67457581, 24.20145988], [91.67446136, 24.20143318], [91.67408752, 24.20148468], [91.6739502, 24.20133972], [91.67385864, 24.20124626], [91.67396545, 24.20115662], [91.67458344, 24.20106506], [91.67475891, 24.2010498], [91.67500305, 24.20127487], [91.67527771, 24.20145416], [91.67604065, 24.20129967], [91.67632294, 24.20116806], [91.67649078, 24.20103073], [91.67662048, 24.20075798], [91.67665863, 24.20043182], [91.67636108, 24.20020103], [91.67596436, 24.20022964], [91.67571259, 24.20012665], [91.67562103, 24.19998932], [91.67563629, 24.1998024], [91.67550659, 24.19962311], [91.67549133, 24.19947815], [91.67568207, 24.19932175], [91.67578125, 24.19944572], [91.67597198, 24.1997261], [91.67619324, 24.19983101], [91.67635345, 24.19965363], [91.67634583, 24.19929504], [91.67626953, 24.19912529], [91.67698669, 24.19865036], [91.67709351, 24.19748688], [91.6771698, 24.19663811], [91.67729187, 24.19688416], [91.67736053, 24.19693947], [91.6776123, 24.19690514], [91.67788696, 24.19686699], [91.67778015, 24.19640541], [91.67776489, 24.1963253], [91.67762756, 24.19605827], [91.67723846, 24.19585991], [91.67713165, 24.19580269], [91.67694092, 24.19561577], [91.67694855, 24.19540977], [91.67711639, 24.19522285], [91.67723083, 24.19510078], [91.67722321, 24.19443703], [91.6774826, 24.19447136], [91.67745972, 24.19466591], [91.6775589, 24.19483757], [91.6776123, 24.1949501], [91.6780014, 24.19467926], [91.67831421, 24.19460297], [91.6784668, 24.19452477], [91.67831421, 24.19425774], [91.67835236, 24.19412422], [91.67897797, 24.19399643], [91.67913818, 24.19392967], [91.67935181, 24.19384193], [91.67953491, 24.19362259], [91.67960358, 24.19327545], [91.6795578, 24.19244003], [91.67952728, 24.19223595], [91.67955017, 24.19203758], [91.67948151, 24.19174957], [91.67959595, 24.1916256], [91.68004608, 24.19161034], [91.68019867, 24.19153976], [91.68009186, 24.19127083], [91.68006134, 24.19109726], [91.68002319, 24.19079971], [91.67983246, 24.19026756], [91.68000031, 24.18981743], [91.68041229, 24.18941498], [91.68052673, 24.18919373], [91.68051147, 24.18893623], [91.68036652, 24.18880844], [91.68010712, 24.18868256], [91.67990875, 24.18884277], [91.68010712, 24.18704033], [91.68231964, 24.18214989], [91.68257141, 24.17714119], [91.68422699, 24.17146111], [91.68493652, 24.16937065], [91.68836975, 24.16527939], [91.69043732, 24.16274071], [91.69159698, 24.16072273], [91.69182587, 24.16083336], [91.69195557, 24.16060829], [91.69228363, 24.16041183], [91.69233704, 24.16031456], [91.6924057, 24.1601181], [91.6922226, 24.16002655], [91.69195557, 24.16005325], [91.69203186, 24.15992355], [91.69210815, 24.15980148], [91.69230652, 24.15978241], [91.69258881, 24.15991402], [91.69277954, 24.15991211], [91.69282532, 24.16007042], [91.69303894, 24.1600666], [91.69320679, 24.16001511], [91.69325256, 24.16033745], [91.69337463, 24.16034126], [91.69345856, 24.16022301], [91.69360352, 24.1600399], [91.69366455, 24.15995789], [91.69385529, 24.15991974], [91.69410706, 24.15986061], [91.6943512, 24.15982246], [91.69456482, 24.15976906], [91.69490051, 24.15966988], [91.69507599, 24.15971184], [91.69502258, 24.15981865], [91.69488525, 24.15999413], [91.69502258, 24.16021729], [91.69528198, 24.16013908], [91.69527435, 24.16044235], [91.69538116, 24.16049957], [91.69564056, 24.16045761], [91.69577789, 24.16055107], [91.6958313, 24.16072083], [91.69574738, 24.16085052], [91.69569397, 24.16096878], [91.69557953, 24.16110611], [91.69544983, 24.16123962], [91.69551086, 24.16139221], [91.69563293, 24.16131973], [91.69577026, 24.16124344], [91.69580078, 24.16134644], [91.69579315, 24.16164589], [91.69599152, 24.16164017], [91.69641876, 24.16154671], [91.69657898, 24.16152191], [91.6966629, 24.16161919], [91.6966629, 24.16186714], [91.69692993, 24.16204643], [91.69702148, 24.1621685], [91.69690704, 24.16224861], [91.69656372, 24.16230011], [91.69658661, 24.16249084], [91.6967392, 24.16267204], [91.69687653, 24.16264153], [91.69689941, 24.16247368], [91.69696808, 24.1623745], [91.6971283, 24.16232872], [91.69735718, 24.16251564], [91.69749451, 24.16265297], [91.6975708, 24.1627636], [91.69748688, 24.16282463], [91.69723511, 24.16293526], [91.6971283, 24.16304779], [91.69706726, 24.16341972], [91.69725037, 24.16362572], [91.69736481, 24.16379929], [91.69762421, 24.16388893], [91.69769287, 24.16370964], [91.69761658, 24.16348457], [91.69764709, 24.1633873], [91.69797516, 24.16351891], [91.6982193, 24.16352272], [91.69854736, 24.16337585], [91.69870758, 24.16332245], [91.69887543, 24.16339302], [91.69904327, 24.16341209], [91.69923401, 24.16343117], [91.69944, 24.1635952], [91.69931793, 24.16376114], [91.69927979, 24.16400337], [91.69943237, 24.1640625], [91.6995697, 24.16395569], [91.69966888, 24.16385841], [91.69979095, 24.16365433], [91.69991302, 24.16352463], [91.70000458, 24.163517], [91.70018768, 24.16350937], [91.70066071, 24.16402626], [91.70075989, 24.16403198], [91.70083618, 24.16384506], [91.70090485, 24.1636734], [91.70102692, 24.1634922], [91.70106506, 24.16342735], [91.70114899, 24.16327095], [91.70122528, 24.16327286], [91.70130157, 24.16327286], [91.70152283, 24.16323662], [91.70160675, 24.16348648], [91.70185852, 24.16360283], [91.70198822, 24.16381836], [91.70213318, 24.16402245], [91.70227814, 24.16405678], [91.70230865, 24.16388512], [91.70222473, 24.1635685], [91.70233154, 24.16348457], [91.70249176, 24.1634655], [91.7027359, 24.16362762], [91.70304108, 24.16376114], [91.70328522, 24.16367912], [91.70342255, 24.16357422], [91.7035675, 24.16330528], [91.70341492, 24.16331482], [91.70324707, 24.16348457], [91.70306396, 24.16342926], [91.70304871, 24.1632843], [91.70303345, 24.16312599], [91.70322418, 24.16300201], [91.70323944, 24.16290474], [91.70328522, 24.16275024], [91.70336914, 24.16270065], [91.70355988, 24.16283989], [91.70368195, 24.16277695], [91.70379639, 24.16263008], [91.70378113, 24.16254616], [91.70371246, 24.16248322], [91.70349121, 24.16256905], [91.70348358, 24.16240692], [91.70349121, 24.16224098], [91.70365143, 24.16221237], [91.70393372, 24.16230965], [91.70400238, 24.16226768], [91.70407867, 24.16221809], [91.70405579, 24.16211128], [91.70401001, 24.16199112], [91.70394135, 24.16189575], [91.70385742, 24.1618042], [91.70368958, 24.16162682], [91.70388794, 24.16141701], [91.70404816, 24.16141319], [91.7040329, 24.16150475], [91.704216, 24.16161728], [91.70427704, 24.16167259], [91.70450592, 24.16174507], [91.70463562, 24.16172791], [91.7045517, 24.16157341], [91.70436096, 24.16143036], [91.7043457, 24.1613369], [91.70442963, 24.16116333], [91.70468903, 24.16124153], [91.70484161, 24.16121674], [91.70472717, 24.16101456], [91.70468903, 24.16088867], [91.70455933, 24.16070747], [91.70487976, 24.16036797], [91.70498657, 24.16025352], [91.70568085, 24.1595211], [91.70575714, 24.1583519], [91.70576477, 24.1582756], [91.70615387, 24.15801811], [91.70633698, 24.15788269], [91.70631409, 24.15777588], [91.70611572, 24.15764999], [91.70600891, 24.15755272], [91.70631409, 24.15698624], [91.70630646, 24.15673256], [91.70627594, 24.15643311], [91.70626831, 24.15631676], [91.70633698, 24.1561451], [91.7063446, 24.15606689], [91.70636749, 24.15593719], [91.70631409, 24.15548706], [91.70613861, 24.15500069], [91.70610046, 24.15480614], [91.70593262, 24.15455627], [91.70600891, 24.15441322], [91.7061615, 24.15441322], [91.70644379, 24.15449333], [91.70690918, 24.15462875], [91.70760345, 24.15486145], [91.70772552, 24.15489578], [91.70796967, 24.15488434], [91.70818329, 24.15480042], [91.70868683, 24.15445709], [91.70915222, 24.15411568], [91.70941162, 24.15424347], [91.70983124, 24.15431786], [91.71017456, 24.15424538], [91.71083069, 24.15417862], [91.71118927, 24.15409088], [91.71156311, 24.15391922], [91.71188354, 24.15376854], [91.71208954, 24.1536274], [91.71208954, 24.15349007], [91.71214294, 24.15335464], [91.71218109, 24.15323639], [91.71230316, 24.15322685], [91.7125473, 24.15323257], [91.71281433, 24.15323257], [91.7131424, 24.15315247], [91.71331024, 24.15301704], [91.71348572, 24.15306854], [91.71374512, 24.15343666], [91.7140274, 24.15380096], [91.71417236, 24.15385056], [91.71434784, 24.15390587], [91.71461487, 24.15382195], [91.71479797, 24.15358543], [91.71490479, 24.15343285], [91.71501923, 24.15327263], [91.71530151, 24.15310097], [91.71551514, 24.15309525], [91.71564484, 24.15324974], [91.71570587, 24.15332413], [91.71630859, 24.15321541], [91.71658325, 24.1531086], [91.71649933, 24.15301132], [91.71640778, 24.15297127], [91.71619415, 24.15287399], [91.71603394, 24.15269089], [91.71609497, 24.1525898], [91.71637726, 24.1523056], [91.71652985, 24.15217018], [91.71672058, 24.15212822], [91.71692657, 24.15220833], [91.7171402, 24.1522789], [91.71726227, 24.15233421], [91.71741486, 24.15240288], [91.71736145, 24.15257645], [91.71737671, 24.15273285], [91.71751404, 24.15275192], [91.71781921, 24.15254784], [91.71789551, 24.15239906], [91.71794128, 24.1523056], [91.71809387, 24.15239716], [91.71829987, 24.15251541], [91.71851349, 24.15240479], [91.71869659, 24.15224457], [91.71897125, 24.15211105], [91.71904755, 24.15209198], [91.71920013, 24.15205574], [91.7193222, 24.15220451], [91.71923828, 24.15237236], [91.71918488, 24.15246964], [91.71932983, 24.15261841], [91.71945953, 24.15261078], [91.71964264, 24.15237999], [91.71981812, 24.15225792], [91.72013855, 24.15229607], [91.72035217, 24.15218925], [91.72099304, 24.15268326], [91.72109985, 24.15287399], [91.72122192, 24.15278816], [91.7212677, 24.15262413], [91.72148132, 24.15261841], [91.72169495, 24.15261841], [91.72179413, 24.1524868], [91.72174072, 24.1523838], [91.72158051, 24.15227318], [91.72163391, 24.15220642], [91.72197723, 24.15212059], [91.72216797, 24.15185165], [91.72209167, 24.15158653], [91.72225952, 24.15148544], [91.72232056, 24.15136909], [91.7220993, 24.15122414], [91.72235107, 24.15077591], [91.72254944, 24.15074539], [91.72280121, 24.1507988], [91.72293091, 24.150774], [91.72290802, 24.15069008], [91.72286224, 24.15051651], [91.72298431, 24.15009117], [91.72293854, 24.14991951], [91.72296906, 24.14971924], [91.72332001, 24.14920807], [91.72337341, 24.14907265], [91.72323608, 24.14888191], [91.72317505, 24.14873123], [91.72325897, 24.14847755], [91.72356415, 24.14807701], [91.72390747, 24.14774895], [91.72428131, 24.14761734], [91.724617, 24.14743042], [91.72460175, 24.14733124], [91.72454834, 24.14710426], [91.72465515, 24.1469593], [91.7247467, 24.14690781], [91.72496796, 24.14683533], [91.72536469, 24.1467762], [91.72554779, 24.146698], [91.7256546, 24.14665031], [91.72593689, 24.14673615], [91.72612762, 24.14674759], [91.72636414, 24.14683151], [91.72660828, 24.1467495], [91.72678375, 24.1465683], [91.72676086, 24.14618111], [91.72680664, 24.14604568], [91.72693634, 24.14596748], [91.72720337, 24.14591789], [91.72737885, 24.14584732], [91.72759247, 24.14547157], [91.72777557, 24.14517784], [91.72810364, 24.14505005], [91.72833252, 24.1449604], [91.72844696, 24.14485168], [91.72847748, 24.1447773], [91.72838593, 24.14460182], [91.72818756, 24.14440155], [91.72774506, 24.14434052], [91.72750092, 24.14434624], [91.72737885, 24.14434814], [91.727211, 24.14430237], [91.7273407, 24.14416313], [91.72743225, 24.14406586], [91.72763062, 24.14390564], [91.72774506, 24.14383316], [91.72792053, 24.14372253], [91.72833252, 24.14340782], [91.72883606, 24.14367485], [91.72904968, 24.14373779], [91.72927856, 24.1437912], [91.72949982, 24.1438427], [91.72982788, 24.14397812], [91.73040009, 24.1438179], [91.73067474, 24.14373779], [91.73098755, 24.14376068], [91.73122406, 24.14391708], [91.7313385, 24.14437866], [91.73146057, 24.14459419], [91.73142242, 24.1449337], [91.73165131, 24.1454792], [91.73212433, 24.14581299], [91.73236847, 24.14589882], [91.73253632, 24.14561081], [91.73268127, 24.14533997], [91.7328949, 24.14497375], [91.73310089, 24.14468002], [91.73345184, 24.14439011], [91.73378754, 24.14415359], [91.73403931, 24.14386368], [91.73418427, 24.14383125], [91.73433685, 24.14394951], [91.73445129, 24.14422798], [91.73458099, 24.14451599], [91.73466492, 24.14473915], [91.73477936, 24.14488602], [91.73484039, 24.14496231], [91.73506927, 24.14514732], [91.73530579, 24.14525414], [91.73554993, 24.14533806], [91.73612213, 24.14572716], [91.73633575, 24.14585686], [91.7366333, 24.14603806], [91.73716736, 24.14529991], [91.73749542, 24.14513016], [91.73802185, 24.1447258], [91.73804474, 24.14465332], [91.7379303, 24.14434052], [91.73792267, 24.14424706], [91.73822784, 24.14396477], [91.73816681, 24.14360809], [91.73801422, 24.14339828], [91.73795319, 24.1432476], [91.73844147, 24.14342117], [91.7385788, 24.14325905], [91.73866272, 24.14329529], [91.73873138, 24.14321136], [91.73867798, 24.14314461], [91.73889923, 24.14288712], [91.73981476, 24.14181137], [91.73991394, 24.1420536], [91.73988342, 24.14212227], [91.7397995, 24.14230537], [91.7399292, 24.142519], [91.74017334, 24.14260864], [91.74051666, 24.14265633], [91.74072266, 24.14286995], [91.74082947, 24.14293098], [91.74121857, 24.14293289], [91.74152374, 24.14280891], [91.74176025, 24.14264679], [91.74187469, 24.14250946], [91.74181366, 24.14208603], [91.74179077, 24.14172173], [91.74188232, 24.14153862], [91.74201965, 24.14145088], [91.74230957, 24.1414814], [91.7425766, 24.1415596], [91.74275208, 24.14161491], [91.74298096, 24.14160919], [91.74305725, 24.14152718], [91.74310303, 24.14146423], [91.74317169, 24.14135742], [91.74328613, 24.14118576], [91.74351501, 24.14117622], [91.74360657, 24.14124298], [91.74385071, 24.1414299], [91.74407959, 24.14158249], [91.74420929, 24.14161491], [91.74459839, 24.14213753], [91.7443924, 24.14256477], [91.7444458, 24.14264107], [91.7445755, 24.14282417], [91.74463654, 24.14299202], [91.74472809, 24.14317322], [91.74507904, 24.14316177], [91.74538422, 24.1430912], [91.74562073, 24.14307785], [91.74575043, 24.14311981], [91.7458725, 24.14298439], [91.74549103, 24.14237595], [91.74555206, 24.14216423], [91.74578857, 24.14203453], [91.74597931, 24.14185333], [91.74608612, 24.14169502], [91.74616241, 24.14140511], [91.74621582, 24.14126968], [91.74633026, 24.14132118], [91.7464447, 24.14147758], [91.74642181, 24.14168549], [91.74634552, 24.14185905], [91.74627686, 24.14194298], [91.7464447, 24.14202309], [91.74672699, 24.14196205], [91.74694824, 24.14192963], [91.74765015, 24.14216614], [91.74774933, 24.14212418], [91.7478714, 24.14181709], [91.74790192, 24.14160728], [91.74807739, 24.14159393], [91.74828339, 24.14163208], [91.74849701, 24.14167023], [91.74871063, 24.14160156], [91.74923706, 24.14178467], [91.7492981, 24.14189911], [91.74938965, 24.14201927], [91.74947357, 24.14213181], [91.74983215, 24.14209938], [91.75007629, 24.1420784], [91.75041199, 24.14219475], [91.75053406, 24.14223671], [91.75055695, 24.14237595], [91.75057983, 24.14248085], [91.75067902, 24.14251137], [91.75100708, 24.14240074], [91.75110626, 24.14243317], [91.75165558, 24.14272308], [91.75173187, 24.14265251], [91.75180054, 24.14258385], [91.75189209, 24.14230728], [91.7519989, 24.14214706], [91.7525177, 24.14201927], [91.75305176, 24.14188766], [91.75320435, 24.14190483], [91.75336456, 24.14197731], [91.7535553, 24.14203262], [91.75382996, 24.14205551], [91.7539444, 24.14206505], [91.75417328, 24.14208031], [91.75428772, 24.14213371], [91.75447845, 24.14232445], [91.75460815, 24.14245415], [91.754776, 24.14239502], [91.75488281, 24.142313], [91.75505066, 24.14215851], [91.75517273, 24.14203072], [91.75533295, 24.14211082], [91.75547791, 24.14227104], [91.7555542, 24.14230347], [91.75582886, 24.14212608], [91.75614166, 24.14190674], [91.75637817, 24.14178848], [91.7565918, 24.14167213], [91.75680542, 24.14156914], [91.75701904, 24.14153099], [91.7572937, 24.14146614], [91.75737, 24.14138412], [91.75743103, 24.14134026], [91.75775909, 24.14136696], [91.75798798, 24.14141273], [91.75617218, 24.14270782], [91.75951385, 24.14196014], [91.75963593, 24.14217567], [91.75973511, 24.14232063], [91.75971985, 24.14245033], [91.7596817, 24.14261436], [91.75960541, 24.14274597], [91.75949097, 24.14305687], [91.75948334, 24.1432209], [91.75946808, 24.1434269], [91.75949097, 24.14356232], [91.75953674, 24.14369202], [91.75957489, 24.14379692], [91.75962067, 24.14389038], [91.75964355, 24.14398766], [91.75964355, 24.14409828], [91.75965881, 24.14421463], [91.75967407, 24.1443615], [91.75964355, 24.14459229], [91.75967407, 24.14472389], [91.75969696, 24.14483643], [91.75975037, 24.14552116], [91.759552, 24.14611626], [91.75938416, 24.14658356], [91.75902557, 24.14737892], [91.75875854, 24.1492939], [91.75847626, 24.15127754], [91.75844574, 24.15151024], [91.75807953, 24.15409279], [91.75794983, 24.15503502], [91.75772095, 24.15664101], [91.75744629, 24.15865135], [91.75737, 24.15918922], [91.75675201, 24.16350555], [91.75637054, 24.1662178], [91.7559967, 24.16887665], [91.75585938, 24.1698761], [91.75576782, 24.17052078], [91.75543213, 24.17289543], [91.7552948, 24.17385864], [91.75489807, 24.17670631], [91.75452423, 24.17936707], [91.75402069, 24.18295479], [91.75352478, 24.18648338], [91.75305939, 24.18976593], [91.75273895, 24.19206619], [91.75261688, 24.1929245], [91.7522583, 24.19545937], [91.75212097, 24.19639969], [91.7516861, 24.19950676], [91.75125885, 24.20251083], [91.751091, 24.20373917], [91.75078583, 24.20586777], [91.75042725, 24.20845604], [91.75003815, 24.21116066], [91.74988556, 24.21224022], [91.74948883, 24.21504593], [91.74932861, 24.2162056], [91.74903107, 24.21832657], [91.74871063, 24.22049522], [91.74829865, 24.22349167], [91.74782562, 24.22682953], [91.74760437, 24.22844696], [91.74729156, 24.23061371], [91.74673462, 24.23458672], [91.74630737, 24.23764229], [91.74608612, 24.23921204], [91.74586487, 24.2407608], [91.74560547, 24.24261856], [91.74507141, 24.24641228], [91.74497223, 24.24708557], [91.74537659, 24.24685478], [91.74615479, 24.24640846], [91.74908447, 24.24472427], [91.75215149, 24.2429657], [91.75360107, 24.24213028], [91.75706482, 24.24013901], [91.75949097, 24.23874474], [91.76094818, 24.2379055], [91.76377106, 24.23621559], [91.7645874, 24.23575401], [91.7664032, 24.23472214], [91.76941681, 24.23301506], [91.77276611, 24.23111534], [91.774086, 24.23036766], [91.77600098, 24.22928429], [91.7780838, 24.22810555], [91.78094482, 24.22648239], [91.78334045, 24.22512245], [91.78457642, 24.22442055], [91.78756714, 24.22274017], [91.78784943, 24.22258377], [91.78797913, 24.2225132], [91.78862762, 24.22214699], [91.78869629, 24.22211266], [91.79110718, 24.22096252], [91.79296875, 24.22083473], [91.79295349, 24.22092819], [91.79312134, 24.22092247], [91.79330444, 24.22096634], [91.7934494, 24.22080994], [91.79356384, 24.22090149], [91.79360199, 24.22096443], [91.79370117, 24.22103882], [91.79388428, 24.22098732], [91.79398346, 24.22079086], [91.79376221, 24.22051048], [91.79369354, 24.22038269], [91.79399109, 24.2202282], [91.79404449, 24.22009468], [91.79400635, 24.21993446], [91.79405212, 24.21977234], [91.79424286, 24.21964836], [91.79444885, 24.21965218], [91.794487, 24.21974564], [91.79450226, 24.21985054], [91.79463196, 24.21993637], [91.79479218, 24.22002792], [91.79503632, 24.2201004], [91.79530334, 24.22023582], [91.79521942, 24.2204628], [91.79547119, 24.22054291], [91.79553986, 24.2205658], [91.79568481, 24.2206192], [91.79584503, 24.22046661], [91.79582977, 24.22039604], [91.79579926, 24.22025871], [91.7958374, 24.22008514], [91.79593658, 24.21991348], [91.79615021, 24.21980286], [91.79623413, 24.21978951], [91.79641724, 24.21990204], [91.79654694, 24.21986771], [91.79657745, 24.21978951], [91.79666901, 24.21973991], [91.79684448, 24.21969032], [91.79698181, 24.21967125], [91.79725647, 24.21977043], [91.79733276, 24.21988106], [91.79743958, 24.21992111], [91.79759979, 24.21978188], [91.79782104, 24.21967888], [91.79797363, 24.21973419], [91.79806519, 24.21977997], [91.798172, 24.21982384], [91.79824066, 24.2200737], [91.79833221, 24.2201786], [91.79837799, 24.22023773], [91.79847717, 24.22036362], [91.79843903, 24.22055054], [91.79851532, 24.22063446], [91.79871368, 24.22059631], [91.79875946, 24.22065735], [91.79872131, 24.22087669], [91.7988739, 24.22089005], [91.79898834, 24.22060394], [91.79910278, 24.22046661], [91.79924011, 24.22034264], [91.79964447, 24.22032738], [91.79980469, 24.22032166], [91.79985046, 24.22041893], [91.8000412, 24.22043419], [91.80012512, 24.22029305], [91.80017853, 24.22005272], [91.80032349, 24.22008514], [91.80060577, 24.22022057], [91.80066681, 24.22015572], [91.80078888, 24.21997643], [91.80091095, 24.21989632], [91.80104065, 24.2197094], [91.80114746, 24.21972466], [91.8013916, 24.21966934], [91.80166626, 24.21970749], [91.8017807, 24.21982956], [91.80192566, 24.21974945], [91.80208588, 24.21955299], [91.80226898, 24.21947479], [91.80238342, 24.2195816], [91.80240631, 24.21973228], [91.80226898, 24.21988869], [91.80231476, 24.21997261], [91.80252838, 24.21996498], [91.80266571, 24.21985626], [91.80278015, 24.21992111], [91.802948, 24.22013283], [91.80305481, 24.22023392], [91.80319214, 24.22036171], [91.80329895, 24.22041702], [91.80353546, 24.22034454], [91.80369568, 24.2203331], [91.80393219, 24.22037315], [91.80401611, 24.22048378], [91.80392456, 24.2205658], [91.80408478, 24.2206459], [91.80422974, 24.22052956], [91.80428314, 24.22035599], [91.80443573, 24.22031403], [91.80461884, 24.22014427], [91.80477905, 24.22025871], [91.80492401, 24.22035599], [91.80510712, 24.22035217], [91.8052597, 24.22039223], [91.80529785, 24.22055244], [91.80530548, 24.22068405], [91.80551147, 24.220644], [91.80577087, 24.2206459], [91.80588531, 24.22073746], [91.80601501, 24.22084427], [91.8061676, 24.22082329], [91.80640411, 24.22065353], [91.80662537, 24.22052956], [91.80669403, 24.22038651], [91.806633, 24.22027397], [91.80662537, 24.2201767], [91.80673981, 24.22010231], [91.80678558, 24.21995735], [91.80686951, 24.21979141], [91.80677032, 24.21956253], [91.80672455, 24.2194519], [91.80683899, 24.21940994], [91.80704498, 24.21935844], [91.80699921, 24.21907043], [91.80651093, 24.21919632], [91.80648804, 24.21903038], [91.80639648, 24.2189045], [91.80632782, 24.21882057], [91.80622101, 24.21884727], [91.80606842, 24.21899223], [91.80584717, 24.21883774], [91.80620575, 24.21870995], [91.80630493, 24.2185421], [91.80698395, 24.2184639], [91.80713654, 24.21834373], [91.8073349, 24.21825218], [91.80757904, 24.21822929], [91.80757904, 24.218153], [91.80731964, 24.21809578], [91.80751038, 24.2179451], [91.80828857, 24.21791649], [91.80866241, 24.21799469], [91.8087616, 24.21800995], [91.80886078, 24.21802521], [91.80879974, 24.21809959], [91.80913544, 24.21816826], [91.80931854, 24.21789551], [91.80937958, 24.21803665], [91.80943298, 24.2182045], [91.80957031, 24.21837997], [91.80969238, 24.21822357], [91.80976868, 24.21792603], [91.80982971, 24.21788788], [91.80990601, 24.21757889], [91.81001282, 24.21755981], [91.81005096, 24.21776199], [91.81040192, 24.21771622], [91.81021881, 24.21748352], [91.81011963, 24.21735382], [91.81031036, 24.21733093], [91.81036377, 24.21718407], [91.81044006, 24.21721649], [91.81061554, 24.21729469], [91.81069946, 24.21720314], [91.81077576, 24.21705437], [91.81069183, 24.21689034], [91.81035614, 24.21677971], [91.8104248, 24.21666145], [91.81079102, 24.216465], [91.81095123, 24.2165432], [91.81091309, 24.21673203], [91.81106567, 24.2168293], [91.81111145, 24.21673584], [91.81118011, 24.21618271], [91.81118011, 24.21596527], [91.81125641, 24.21579933], [91.81141663, 24.21567917], [91.81144714, 24.21553993], [91.8115387, 24.21547508], [91.81155396, 24.2154026], [91.81130981, 24.21530533], [91.81175995, 24.21504974], [91.81192017, 24.21497917], [91.8116684, 24.21484375], [91.81163025, 24.21478271], [91.81172943, 24.21469879], [91.81182098, 24.21464729], [91.81216431, 24.21464348], [91.81233978, 24.21452141], [91.81220245, 24.21427917], [91.8123703, 24.21413422], [91.81243896, 24.21394157], [91.8126297, 24.21383286], [91.81258392, 24.21370506], [91.81269073, 24.21363068], [91.81278229, 24.21377373], [91.81291962, 24.21369553], [91.81287384, 24.21316147], [91.81272125, 24.21295357], [91.81267548, 24.21261597], [91.81253052, 24.21248245], [91.81251526, 24.21237564], [91.81264496, 24.21223068], [91.81299591, 24.21257019], [91.81317139, 24.21269798], [91.81315613, 24.21245956], [91.81362152, 24.2123394], [91.81376648, 24.21235466], [91.81389618, 24.21233559], [91.8140564, 24.21241379], [91.81414795, 24.21242142], [91.81434631, 24.21218491], [91.81452179, 24.2121048], [91.81460571, 24.21219635], [91.81469727, 24.21203232], [91.81477356, 24.21195221], [91.81491089, 24.21186638], [91.81499481, 24.21189499], [91.81503296, 24.21207237], [91.81520081, 24.21218681], [91.81529999, 24.21214104], [91.81536865, 24.2118988], [91.81544495, 24.21185493], [91.81550598, 24.21190453], [91.8156662, 24.21175385], [91.81569672, 24.21162224], [91.81576538, 24.21156883], [91.81582642, 24.21146393], [91.81588745, 24.21140099], [91.815979, 24.21133995], [91.81606293, 24.21130943], [91.81611633, 24.21125412], [91.81625366, 24.2109623], [91.81612396, 24.21062851], [91.81604767, 24.21051216], [91.81606293, 24.21035957], [91.81613922, 24.21020889], [91.81619263, 24.21011353], [91.81629944, 24.21008301], [91.81646729, 24.21007919], [91.81658936, 24.21012497], [91.81666565, 24.21046448], [91.81682587, 24.21051216], [91.81697845, 24.2105484], [91.81694031, 24.21035767], [91.81700897, 24.21031952], [91.81710815, 24.21021271], [91.81726837, 24.21020699], [91.81738281, 24.21002197], [91.81747437, 24.20993233], [91.81768036, 24.21004486], [91.81748962, 24.21021843], [91.81747437, 24.21031761], [91.81745911, 24.21047783], [91.81760406, 24.21066666], [91.81784058, 24.21069908], [91.81801605, 24.21074867], [91.81806183, 24.21052361], [91.81826019, 24.21060181], [91.81835938, 24.21064186], [91.81848145, 24.21062088], [91.81850433, 24.210495], [91.8187027, 24.21046066], [91.81873322, 24.21076393], [91.81879425, 24.21080971], [91.8189621, 24.21080017], [91.81902313, 24.21076202], [91.8190918, 24.21067619], [91.81909943, 24.21049309], [91.81902313, 24.21031952], [91.81919861, 24.21018219], [91.81909943, 24.2099514], [91.81916809, 24.20983315], [91.81936646, 24.20979691], [91.81954956, 24.20988274], [91.8194046, 24.20996094], [91.81948853, 24.21014977], [91.81943512, 24.2102356], [91.81941223, 24.21038437], [91.81950378, 24.21030807], [91.81960297, 24.21025848], [91.81980896, 24.21009445], [91.81984711, 24.21002197], [91.82136536, 24.21073532], [91.82132721, 24.21095276], [91.82151794, 24.21101189], [91.82176208, 24.2110424], [91.82184601, 24.21096039], [91.82185364, 24.21068954], [91.82202148, 24.21063995], [91.82218933, 24.21056557], [91.82254791, 24.21072006], [91.82260895, 24.21064758], [91.82234192, 24.21035957], [91.82250214, 24.21039009], [91.82276154, 24.21052933], [91.82279968, 24.21042633], [91.82279205, 24.2102375], [91.82279205, 24.21013069], [91.82290649, 24.21017838], [91.8230896, 24.21024132], [91.82363892, 24.21016121], [91.82378387, 24.2102375], [91.82373047, 24.21040154], [91.82348633, 24.21053696], [91.82335663, 24.21060562], [91.82334137, 24.21071243], [91.82339478, 24.21088028], [91.82350159, 24.21102905], [91.82363129, 24.21113396], [91.82379913, 24.21123695], [91.82382965, 24.21142387], [91.8239212, 24.21150589], [91.82406616, 24.21146202], [91.82422638, 24.21137238], [91.82444763, 24.21113396], [91.82462311, 24.21110725], [91.82475281, 24.21121979], [91.82482147, 24.21143532], [91.82473755, 24.2115612], [91.82468414, 24.21167374], [91.8246994, 24.21179008], [91.82472229, 24.2119236], [91.82476044, 24.21198654], [91.82492828, 24.21211052], [91.82498932, 24.21224594], [91.82493591, 24.21234894], [91.82492828, 24.21248436], [91.82502747, 24.2126503], [91.82530212, 24.21273613], [91.82545471, 24.21283722], [91.82550812, 24.21293449], [91.8256073, 24.21302986], [91.82566071, 24.21310616], [91.82580566, 24.21315765], [91.82595825, 24.21316338], [91.82604218, 24.21324158], [91.82607269, 24.21333313], [91.82611847, 24.21343422], [91.82618713, 24.21356392], [91.82630157, 24.21369171], [91.82640839, 24.21376801], [91.82666779, 24.21377754], [91.8267746, 24.21370316], [91.82695007, 24.21352005], [91.82704926, 24.21346664], [91.82717896, 24.21350479], [91.82733154, 24.21353722], [91.82740784, 24.2135582], [91.82754517, 24.21352768], [91.82770538, 24.21342087], [91.82788849, 24.21331978], [91.82805634, 24.21327591], [91.82904053, 24.21323204], [91.82915497, 24.21327972], [91.82918549, 24.21336937], [91.82904053, 24.21346855], [91.82889557, 24.21367455], [91.82888794, 24.21383858], [91.82897949, 24.213871], [91.82897186, 24.21400833], [91.8289566, 24.21409607], [91.82894897, 24.21418381], [91.82904053, 24.21429062], [91.829216, 24.21429634], [91.82930756, 24.21441078], [91.82944489, 24.21471596], [91.82950592, 24.21485329], [91.82959747, 24.21492386], [91.82974243, 24.21497917], [91.82988739, 24.21515656], [91.83003998, 24.21562195], [91.83013153, 24.21563339], [91.83026123, 24.21562195], [91.83035278, 24.21571922], [91.83052063, 24.21590805], [91.83066559, 24.21590424], [91.83093262, 24.21589851], [91.83107758, 24.21605682], [91.83109283, 24.21616554], [91.83106232, 24.21634674], [91.83097076, 24.21658134], [91.83103943, 24.21666336], [91.83114624, 24.21674538], [91.83130646, 24.21684265], [91.83142853, 24.21703529], [91.83148193, 24.21713257], [91.83145905, 24.21723557], [91.8314209, 24.21733093], [91.83148193, 24.21747589], [91.83148193, 24.21759033], [91.8314743, 24.21776581], [91.83152008, 24.21796227], [91.83141327, 24.21810341], [91.83125305, 24.21813965], [91.83115387, 24.21815109], [91.8312149, 24.21834373], [91.8313446, 24.21832848], [91.83163452, 24.21824646], [91.83189392, 24.21816254], [91.83195496, 24.21836281], [91.83213043, 24.21832466], [91.83222198, 24.21822739], [91.83235168, 24.21816635], [91.83250427, 24.21823502], [91.83265686, 24.21822166], [91.83274841, 24.2183609], [91.83292389, 24.2183094], [91.83302307, 24.21821404], [91.83303833, 24.21805954], [91.83313751, 24.21802711], [91.83332062, 24.21805], [91.83326721, 24.21834755], [91.83335114, 24.21829605], [91.83342743, 24.21825218], [91.83353424, 24.2182827], [91.83361053, 24.21842194], [91.83372498, 24.2185154], [91.83377075, 24.21837044], [91.83387756, 24.21834946], [91.83407593, 24.21835327], [91.83415985, 24.21833801], [91.83433533, 24.21824646], [91.83444977, 24.21829987], [91.83454132, 24.21834183], [91.83466339, 24.21839905], [91.8374176, 24.21968079], [91.83753204, 24.2212925], [91.8375473, 24.22145653], [91.83759308, 24.22204208], [91.83744812, 24.22211647], [91.83731842, 24.22233772], [91.83711243, 24.22273064], [91.83708954, 24.22285461], [91.83712006, 24.22298813], [91.83707428, 24.22306824], [91.83708954, 24.22315788], [91.83746338, 24.22325897], [91.83743286, 24.22343826], [91.83726501, 24.2235775], [91.83705139, 24.22382355], [91.83721924, 24.22388458], [91.83773041, 24.22395706], [91.83785248, 24.22397614], [91.83798218, 24.22403145], [91.83802795, 24.22412491], [91.83779907, 24.22429848], [91.83773041, 24.22442245], [91.83752441, 24.22458076], [91.83745575, 24.22471428], [91.83747101, 24.22478676], [91.83763123, 24.22476196], [91.8377533, 24.22489738], [91.83758545, 24.22506714], [91.83733368, 24.22524261], [91.83720398, 24.22502327], [91.83711243, 24.22491646], [91.83680725, 24.22496796], [91.83677673, 24.22513771], [91.83679199, 24.22523117], [91.83686066, 24.22552681], [91.83695221, 24.2257061], [91.83735657, 24.22567177], [91.837677, 24.22561264], [91.837883, 24.22583389], [91.83798218, 24.22612572], [91.83818054, 24.22637749], [91.83848572, 24.22653961], [91.83869171, 24.22652435], [91.83904266, 24.22640038], [91.83925629, 24.22632027], [91.83991241, 24.22722816], [91.84389496, 24.22907639], [91.8447876, 24.22890854], [91.84747314, 24.22827148], [91.84471893, 24.22584534], [91.84490967, 24.22571754], [91.84572601, 24.22505379], [91.84593964, 24.22472191], [91.84603119, 24.22439384], [91.84597015, 24.22418022], [91.84594727, 24.22410774], [91.84563446, 24.22386932], [91.84529114, 24.22366905], [91.84472656, 24.22348022], [91.84365845, 24.22340584], [91.84339142, 24.22335434], [91.8432312, 24.22332382], [91.84317017, 24.22327423], [91.84291077, 24.22306633], [91.842659, 24.22274971], [91.84257507, 24.22236252], [91.8425827, 24.22208023], [91.84262848, 24.22174835], [91.84264374, 24.22163963], [91.8427124, 24.22118568], [91.84291077, 24.22064972], [91.84297943, 24.22037506], [91.84325409, 24.22025299], [91.84358978, 24.22022438], [91.84393311, 24.22038651], [91.84431458, 24.22067261], [91.84465027, 24.22092247], [91.84508514, 24.22122383], [91.84555817, 24.22143364], [91.84591675, 24.22145653], [91.84636688, 24.22145844], [91.84683228, 24.22145653], [91.84761047, 24.22144318], [91.84812164, 24.2215786], [91.84856415, 24.22153854], [91.84896088, 24.22143936], [91.84925079, 24.22133636], [91.84954834, 24.22110176], [91.85140991, 24.22147751], [91.85150146, 24.22149658], [91.85263062, 24.21879196], [91.85268402, 24.21865463], [91.85491943, 24.2164917], [91.85687256, 24.21429443], [91.85674286, 24.21430016], [91.85327148, 24.21447754], [91.85231781, 24.21457672], [91.85331726, 24.21414566], [91.85422516, 24.21382904], [91.85457611, 24.21366692], [91.85488892, 24.21343422], [91.85508728, 24.21320534], [91.85509491, 24.21253204], [91.85507202, 24.21220779], [91.85505676, 24.21201515], [91.85469818, 24.21182442], [91.85440826, 24.21178055], [91.85351563, 24.21198845], [91.85305786, 24.21207428], [91.85274506, 24.21220016], [91.85249329, 24.21238136], [91.85197449, 24.2130127], [91.85168457, 24.21326256], [91.85137939, 24.21332359], [91.8509903, 24.21335411], [91.85083008, 24.21336555], [91.85038757, 24.21328354], [91.8500824, 24.21307755], [91.84976196, 24.21289063], [91.84960175, 24.21254921], [91.84957886, 24.21219444], [91.84964752, 24.21181679], [91.84979248, 24.21151543], [91.85023499, 24.21088982], [91.85055542, 24.21038818], [91.85103607, 24.20993042], [91.85147858, 24.20952988], [91.85178375, 24.20925713], [91.85198975, 24.20900726], [91.85206604, 24.20874405], [91.85204315, 24.2085762], [91.85202789, 24.20843315], [91.8518219, 24.20795059], [91.85155487, 24.20780182], [91.85131836, 24.20779991], [91.85105896, 24.20794106], [91.85060883, 24.20840263], [91.8503418, 24.20870972], [91.85018158, 24.20886803], [91.84966278, 24.20892334], [91.84934235, 24.20876312], [91.84928894, 24.20868683], [91.8491745, 24.20852852], [91.84902954, 24.20810509], [91.84880829, 24.20701408], [91.85043335, 24.20709229], [91.85018921, 24.2044487], [91.84991455, 24.20227051], [91.84962463, 24.20200729], [91.84750366, 24.20004082], [91.84742737, 24.20004082], [91.84662628, 24.20004272], [91.84614563, 24.20094299], [91.84600067, 24.20072556], [91.84580231, 24.20078278], [91.84521484, 24.20120239], [91.84455109, 24.20182228], [91.84409332, 24.20204353], [91.84392548, 24.20212555], [91.84342957, 24.20215988], [91.84283447, 24.20210266], [91.84226227, 24.20183754], [91.84190369, 24.20148087], [91.84194183, 24.2011013], [91.84211731, 24.20078659], [91.84244537, 24.20063972], [91.84277344, 24.2005806], [91.84326172, 24.20044327], [91.84371185, 24.20026207], [91.84391785, 24.20009041], [91.84413147, 24.19987488], [91.84429932, 24.19956779], [91.84436035, 24.19911575], [91.84363556, 24.19763374], [91.84379578, 24.19744873], [91.84383392, 24.19734001], [91.84388733, 24.19706154], [91.84391785, 24.19687653], [91.84404755, 24.19669533], [91.84420013, 24.19669533], [91.84427643, 24.19673538], [91.84423828, 24.1968708], [91.84422302, 24.19700813], [91.84415436, 24.19717979], [91.84422302, 24.19727325], [91.84434509, 24.19742966], [91.84456635, 24.19753265], [91.84474945, 24.19756317], [91.84484863, 24.19758034], [91.84508514, 24.19757271], [91.84518433, 24.1974926], [91.84526062, 24.19736862], [91.84519958, 24.19709587], [91.84506989, 24.1968441], [91.84487915, 24.1965332], [91.8447876, 24.19628525], [91.84474182, 24.19605064], [91.84470367, 24.19584274], [91.84474945, 24.19569016], [91.844841, 24.19562721], [91.84497833, 24.19553566], [91.84515381, 24.19557571], [91.84518433, 24.19571114], [91.84524536, 24.19581985], [91.84532166, 24.19607544], [91.84539032, 24.19614983], [91.84549713, 24.19614983], [91.84560394, 24.1961174], [91.84563446, 24.19589615], [91.84560394, 24.19563675], [91.84555817, 24.19542503], [91.84550476, 24.19517899], [91.84560394, 24.19511414], [91.84581757, 24.19536209], [91.84599304, 24.1955471], [91.846138, 24.19543076], [91.84619141, 24.19534302], [91.84615326, 24.19519615], [91.84615326, 24.19503021], [91.84615326, 24.1947403], [91.84611511, 24.19446373], [91.846138, 24.19436836], [91.84608459, 24.19408226], [91.84603882, 24.19380188], [91.84606171, 24.19370079], [91.84631348, 24.19363403], [91.84647369, 24.19368362], [91.84667969, 24.1936245], [91.84690094, 24.19353676], [91.84700775, 24.1934433], [91.84711456, 24.19324684], [91.84713745, 24.19314575], [91.84703064, 24.1930542], [91.8469162, 24.19298744], [91.84672546, 24.19296455], [91.84645081, 24.19302559], [91.84623718, 24.19313049], [91.84609222, 24.19304848], [91.84610748, 24.19297218], [91.84633636, 24.19270134], [91.84648132, 24.19252396], [91.84658813, 24.1923542], [91.84661102, 24.19228363], [91.84666443, 24.1920948], [91.84662628, 24.19194984], [91.84656525, 24.19188118], [91.84616089, 24.19187164], [91.84580994, 24.19186783], [91.84552002, 24.19181442], [91.84538269, 24.19169617], [91.84535217, 24.19151115], [91.84537506, 24.19137955], [91.84567261, 24.19119263], [91.8456955, 24.19111824], [91.84562683, 24.19100571], [91.84548187, 24.19087601], [91.84546661, 24.19078636], [91.84545898, 24.19059944], [91.84531403, 24.19045639], [91.84529877, 24.19029045], [91.84523773, 24.19018364], [91.84501648, 24.19013786], [91.84499359, 24.1900692], [91.84480286, 24.18992996], [91.84494781, 24.18989372], [91.84514618, 24.18962288], [91.84536743, 24.18956947], [91.84540558, 24.18938065], [91.84549713, 24.18934441], [91.84558868, 24.18935204], [91.84576416, 24.18938828], [91.84585571, 24.18935394], [91.84600067, 24.1892662], [91.84616852, 24.18924141], [91.84625244, 24.18922997], [91.84630585, 24.18917465], [91.84638977, 24.18902397], [91.84650421, 24.18906403], [91.8466568, 24.18912125], [91.84676361, 24.18915176], [91.84677887, 24.18905067], [91.84677124, 24.18897057], [91.84676361, 24.18886566], [91.8467865, 24.18873978], [91.84692383, 24.18860626], [91.8469696, 24.18850708], [91.84707642, 24.18846703], [91.84714508, 24.18838501], [91.8471756, 24.18830109], [91.84711456, 24.18823242], [91.84719086, 24.18809319], [91.847229, 24.18802834], [91.84736633, 24.18800735], [91.84734344, 24.18790817], [91.84724426, 24.18788338], [91.8470993, 24.18772316], [91.84713745, 24.18754959], [91.84721375, 24.18747711], [91.84728241, 24.18745422], [91.84732056, 24.18737411], [91.84729004, 24.18721199], [91.84726715, 24.18713951], [91.847229, 24.18698883], [91.84727478, 24.18691635], [91.84740448, 24.18677902], [91.84751892, 24.1866951], [91.84767151, 24.18664169], [91.84779358, 24.18660164], [91.84796906, 24.18654442], [91.84793091, 24.18647385], [91.84772491, 24.18639755], [91.84747314, 24.1862812], [91.84749603, 24.18620872], [91.84761047, 24.18596649], [91.84766388, 24.18589401], [91.84789276, 24.1858902], [91.84806824, 24.18588448], [91.8480835, 24.18572998], [91.84790039, 24.18552589], [91.84786224, 24.18542671], [91.84793854, 24.18531799], [91.84793091, 24.18522835], [91.84796906, 24.18507385], [91.84797668, 24.1849556], [91.84807587, 24.18491554], [91.84816742, 24.18491364], [91.84825134, 24.18500519], [91.84832764, 24.18502998], [91.84846497, 24.18512154], [91.84867096, 24.18515968], [91.84877014, 24.18526459], [91.84886932, 24.18532944], [91.84899902, 24.18539238], [91.84925079, 24.18541336], [91.84923553, 24.18520546], [91.84919739, 24.18506241], [91.84921265, 24.18492889], [91.84934998, 24.18486404], [91.84923553, 24.18460846], [91.8493576, 24.18448639], [91.84949493, 24.18441582], [91.84958649, 24.18429375], [91.84967041, 24.18420792], [91.84976959, 24.18411636], [91.84989166, 24.18401718], [91.84992218, 24.18390846], [91.84978485, 24.18374825], [91.84976959, 24.18361282], [91.84979248, 24.18347549], [91.84985352, 24.18340302], [91.84996796, 24.18334579], [91.85019684, 24.18336678], [91.85030365, 24.18313217], [91.85019684, 24.18308067], [91.85018921, 24.18286705], [91.85041809, 24.18273926], [91.85049438, 24.18268776], [91.85055542, 24.18250275], [91.85110474, 24.18247223], [91.85119629, 24.18245697], [91.85114288, 24.18228912], [91.85101318, 24.18221855], [91.85098267, 24.18210793], [91.85105133, 24.18198967], [91.8511734, 24.1819458], [91.85126495, 24.18197632], [91.85144806, 24.18194771], [91.85160065, 24.18201828], [91.85173035, 24.18209457], [91.85185242, 24.18206596], [91.85186768, 24.18198013], [91.85198212, 24.18185043], [91.8521347, 24.1817627], [91.8522644, 24.18170738], [91.85234833, 24.18177032], [91.85237122, 24.18188858], [91.85227966, 24.18202972], [91.85225677, 24.18223953], [91.85246277, 24.18235207], [91.85253143, 24.18240166], [91.85275269, 24.18246841], [91.85286713, 24.18254471], [91.85283661, 24.18270302], [91.85287476, 24.18281174], [91.85301208, 24.18286896], [91.85306549, 24.18280792], [91.85312653, 24.18271637], [91.85320282, 24.18269348], [91.85325623, 24.18275261], [91.85340118, 24.18285561], [91.85354614, 24.18281555], [91.85362244, 24.18278122], [91.85383606, 24.18287659], [91.85391998, 24.18291092], [91.85387421, 24.18305397], [91.85391235, 24.18314934], [91.85411072, 24.18330383], [91.85413361, 24.18343925], [91.85415649, 24.18359184], [91.85424042, 24.18352509], [91.85434723, 24.18343925], [91.85442352, 24.18338013], [91.854599, 24.18325806], [91.85466003, 24.18317604], [91.85475159, 24.18305397], [91.85487366, 24.18299294], [91.85503387, 24.18294334], [91.85520935, 24.18308449], [91.8553009, 24.18317223], [91.85535431, 24.18322372], [91.85547638, 24.18329811], [91.85566711, 24.18328285], [91.85572815, 24.1831913], [91.85574341, 24.18310738], [91.85562897, 24.18302917], [91.85548401, 24.18294334], [91.85522461, 24.18286705], [91.85526276, 24.18274117], [91.85535431, 24.18262863], [91.8556366, 24.1825676], [91.85583496, 24.18255615], [91.85592651, 24.1824894], [91.85592651, 24.18241501], [91.85579681, 24.1822834], [91.85570526, 24.1822319], [91.85559082, 24.18217659], [91.85535431, 24.18205833], [91.85540009, 24.18196487], [91.85544586, 24.18188286], [91.85545349, 24.18177223], [91.85553741, 24.18159294], [91.85565186, 24.1816082], [91.85577393, 24.18173027], [91.85596466, 24.18168449], [91.85607147, 24.1817646], [91.85618591, 24.18177414], [91.85637665, 24.1817894], [91.85646057, 24.18183708], [91.85652161, 24.1819191], [91.85662079, 24.18204689], [91.85666656, 24.18216133], [91.85663605, 24.18235016], [91.85673523, 24.18241501], [91.85689545, 24.18238068], [91.85699463, 24.18230057], [91.85710144, 24.18194199], [91.85719299, 24.18194771], [91.8574295, 24.18206978], [91.85758972, 24.18210793], [91.85784912, 24.1819191], [91.85788727, 24.18173599], [91.85796356, 24.18151855], [91.85809326, 24.18148422], [91.85927582, 24.18155479], [91.85939789, 24.18177414], [91.85949707, 24.18182182], [91.85974121, 24.18194008], [91.85997009, 24.18197632], [91.86018372, 24.18177795], [91.86029816, 24.18161583], [91.8604126, 24.18162155], [91.86044312, 24.18172646], [91.86051178, 24.18205643], [91.86054993, 24.1821785], [91.86061859, 24.18222809], [91.86081696, 24.18232727], [91.86074066, 24.1825161], [91.86071014, 24.18261147], [91.86064911, 24.18283272], [91.86063385, 24.18290329], [91.86071014, 24.18294907], [91.86083984, 24.18300819], [91.86112976, 24.18289375], [91.86136627, 24.18273544], [91.86146545, 24.18265152], [91.86157227, 24.18252754], [91.86138153, 24.18234253], [91.86136627, 24.18225288], [91.86136627, 24.18207741], [91.86121368, 24.18195343], [91.86109161, 24.18181419], [91.86099243, 24.18165588], [91.86128235, 24.18165398], [91.8613739, 24.18180084], [91.86151123, 24.18196869], [91.86165619, 24.18196106], [91.86177826, 24.1818924], [91.86185455, 24.18175888], [91.86199188, 24.18172264], [91.86206818, 24.18195343], [91.86212158, 24.182024], [91.86221313, 24.18200684], [91.86232758, 24.18194962], [91.86244965, 24.18188667], [91.86244965, 24.18164635], [91.86256409, 24.1816349], [91.86270905, 24.18150139], [91.86282349, 24.18161392], [91.86318207, 24.18140602], [91.86338806, 24.18135071], [91.86374664, 24.18123627], [91.86378479, 24.18112755], [91.86373138, 24.18107796], [91.86360168, 24.18101883], [91.8635025, 24.18089294], [91.86345673, 24.18081093], [91.86385345, 24.18041039], [91.86399078, 24.18031502], [91.86418152, 24.18013954], [91.86437225, 24.1802063], [91.86453247, 24.18021965], [91.86457062, 24.18029022], [91.86474609, 24.18033409], [91.86485291, 24.18032265], [91.8650589, 24.18016434], [91.86508942, 24.17995644], [91.86512756, 24.17975235], [91.86504364, 24.17957497], [91.86493683, 24.17943954], [91.86486053, 24.17930603], [91.86479187, 24.17907333], [91.86478424, 24.17889214], [91.86491394, 24.1787281], [91.86500549, 24.17864418], [91.86511993, 24.17851257], [91.86517334, 24.17835999], [91.86527252, 24.17821312], [91.86542511, 24.17810822], [91.86575317, 24.1780014], [91.86582184, 24.17795563], [91.86598206, 24.17782974], [91.86611938, 24.17774963], [91.86617279, 24.17767334], [91.86599731, 24.17752075], [91.86595154, 24.17734718], [91.86606598, 24.17735291], [91.86631012, 24.17737198], [91.86647034, 24.17727661], [91.86643219, 24.17719078], [91.86634064, 24.1771431], [91.8662796, 24.17704964], [91.86613464, 24.17692184], [91.86602783, 24.17686462], [91.86601257, 24.17676353], [91.86603546, 24.17666626], [91.86612701, 24.17661285], [91.86639404, 24.17657852], [91.86655426, 24.17657661], [91.86677551, 24.1765976], [91.86706543, 24.17675018], [91.86713409, 24.17687988], [91.86721802, 24.17707062], [91.8673172, 24.177248], [91.86738586, 24.17737007], [91.86745453, 24.17747688], [91.86764526, 24.17762375], [91.86774445, 24.17756081], [91.86772919, 24.17719841], [91.86775208, 24.1769619], [91.86785889, 24.17689323], [91.8678894, 24.17676926], [91.86833191, 24.17656326], [91.86855316, 24.17658234], [91.86863708, 24.17663383], [91.86853027, 24.17671204], [91.8684082, 24.17677689], [91.86844635, 24.17690086], [91.86858368, 24.17695618], [91.86872864, 24.17696381], [91.86901855, 24.1771965], [91.86919403, 24.17733002], [91.86927795, 24.17733574], [91.86941528, 24.177248], [91.86888123, 24.17695808], [91.86880493, 24.17691803], [91.86891174, 24.17685318], [91.86909485, 24.17686653], [91.86919403, 24.17698288], [91.86927032, 24.17690277], [91.86933899, 24.17676353], [91.86943817, 24.17660713], [91.86974335, 24.17648506], [91.86989594, 24.17654228], [91.87011719, 24.17661858], [91.87029266, 24.17663383], [91.87033081, 24.17643547], [91.87026215, 24.17619324], [91.87029266, 24.17612076], [91.87030792, 24.1759491], [91.87030792, 24.17584801], [91.87029266, 24.17570496], [91.87083435, 24.17520523], [91.87088776, 24.17515564], [91.87099457, 24.17519188], [91.87111664, 24.1751461], [91.87127686, 24.17506218], [91.87133026, 24.174963], [91.87138367, 24.1747036], [91.87145996, 24.17463303], [91.8715744, 24.17468071], [91.87166595, 24.1746254], [91.8718338, 24.17463875], [91.87201691, 24.17471695], [91.87207794, 24.17496872], [91.87213135, 24.17504501], [91.87220764, 24.17511368], [91.87226868, 24.17522621], [91.87233734, 24.17534447], [91.8724823, 24.17546844], [91.87255096, 24.17530823], [91.87260437, 24.17524147], [91.87277222, 24.17505646], [91.87293243, 24.17487717], [91.8731308, 24.17468834], [91.87322998, 24.17459106], [91.87335968, 24.17457008], [91.8734436, 24.17461205], [91.87369537, 24.17461967], [91.87381744, 24.17464638], [91.87391663, 24.17461777], [91.87388611, 24.17446899], [91.87380219, 24.17447662], [91.87371826, 24.17448425], [91.87354279, 24.17451668], [91.87352753, 24.1744442], [91.87358856, 24.17438126], [91.87376404, 24.17422485], [91.87397003, 24.1740036], [91.87380981, 24.17373276], [91.87377167, 24.17366791], [91.87385559, 24.17363358], [91.87397003, 24.17353058], [91.87378693, 24.17335892], [91.87369537, 24.17303848], [91.87361145, 24.1728611], [91.87364197, 24.17271996], [91.87345886, 24.17268753], [91.87332153, 24.17277908], [91.87322235, 24.17284393], [91.87306213, 24.17292213], [91.8730011, 24.17269707], [91.87306213, 24.17259979], [91.87316132, 24.17246819], [91.87321472, 24.17240334], [91.87336731, 24.17239571], [91.87359619, 24.17232704], [91.87368011, 24.1723156], [91.87388611, 24.17228699], [91.87410736, 24.17235947], [91.87418365, 24.17229652], [91.87423706, 24.1721096], [91.87419891, 24.17200089], [91.87403107, 24.17194557], [91.87389374, 24.17188835], [91.87381744, 24.17185211], [91.87373352, 24.17198753], [91.87350464, 24.17206955], [91.87336731, 24.17191696], [91.8733902, 24.17177963], [91.87361145, 24.17171669], [91.87362671, 24.17162895], [91.87358856, 24.17149734], [91.87343597, 24.17119789], [91.8734436, 24.17111969], [91.87362671, 24.17106438], [91.87384033, 24.17096901], [91.87397003, 24.17097855], [91.87406921, 24.17103767], [91.87387848, 24.17118454], [91.87379456, 24.17124939], [91.873703, 24.17137718], [91.87393188, 24.17158508], [91.87400055, 24.17155266], [91.87401581, 24.17137909], [91.87406158, 24.1713047], [91.87432098, 24.17124748], [91.87441254, 24.1713028], [91.87450409, 24.17148209], [91.87460327, 24.17154694], [91.87481689, 24.17152214], [91.875, 24.17148018], [91.87516785, 24.17144203], [91.87541962, 24.17141342], [91.87549591, 24.17127609], [91.87545013, 24.17115593], [91.87535858, 24.1710453], [91.87521362, 24.17099762], [91.87505341, 24.1709404], [91.87510681, 24.17055511], [91.87507629, 24.17032814], [91.87515259, 24.17030144], [91.87533569, 24.1703167], [91.87538147, 24.17043877], [91.87539673, 24.17050934], [91.8754425, 24.17058182], [91.87559509, 24.17056084], [91.87583923, 24.1705246], [91.87595367, 24.17043304], [91.87601471, 24.17038155], [91.87609863, 24.17037201], [91.87608337, 24.17027664], [91.87588501, 24.17022896], [91.87586975, 24.16992188], [91.87595367, 24.16991615], [91.87620544, 24.1699543], [91.87625122, 24.16989708], [91.87599182, 24.16968536], [91.87585449, 24.16961479], [91.87571716, 24.16958046], [91.87550354, 24.16952515], [91.87526703, 24.16938782], [91.87509155, 24.16937637], [91.87491608, 24.16941643], [91.87483215, 24.16945839], [91.87477875, 24.16957092], [91.87471771, 24.1696682], [91.87463379, 24.16970253], [91.87454224, 24.16969109], [91.87439728, 24.16962242], [91.87432098, 24.16963577], [91.8742218, 24.16965294], [91.87405396, 24.16968536], [91.87402344, 24.16946983], [91.87412262, 24.16936493], [91.87402344, 24.16913795], [91.87393951, 24.16912079], [91.87382507, 24.16909409], [91.87371063, 24.16900253], [91.87369537, 24.1688633], [91.87373352, 24.16870499], [91.87391663, 24.16847801], [91.87397766, 24.16832352], [91.87386322, 24.16824341], [91.87366486, 24.1682415], [91.87345886, 24.16830254], [91.87339783, 24.16822052], [91.87329865, 24.16802025], [91.87329865, 24.16788483], [91.87337494, 24.16780472], [91.87348175, 24.16785812], [91.87369537, 24.16808891], [91.87380981, 24.16806984], [91.87395477, 24.16801071], [91.87418365, 24.16784096], [91.87428284, 24.16778564], [91.87442017, 24.16775703], [91.87450409, 24.16780472], [91.87468719, 24.16781044], [91.87470245, 24.16773415], [91.87474823, 24.16763878], [91.87463379, 24.16759682], [91.87449646, 24.16748428], [91.87438965, 24.16733932], [91.87428284, 24.16711998], [91.87417603, 24.16702271], [91.87405396, 24.16697121], [91.8739624, 24.16701317], [91.87397003, 24.16720772], [91.87391663, 24.16749382], [91.8737793, 24.16747093], [91.87372589, 24.16739464], [91.87374115, 24.16719437], [91.87368774, 24.1671257], [91.87355804, 24.16699219], [91.87355042, 24.16679001], [91.87367249, 24.16669464], [91.87374878, 24.16672134], [91.87389374, 24.16658592], [91.87400055, 24.1664753], [91.87426758, 24.16653633], [91.8745575, 24.16652679], [91.87471771, 24.1665287], [91.87484741, 24.1664505], [91.87479401, 24.16620827], [91.87472534, 24.16614151], [91.87456512, 24.16612053], [91.8744812, 24.16602325], [91.87464905, 24.16594124], [91.87476349, 24.16577721], [91.87483215, 24.16547394], [91.87490082, 24.16526413], [91.87483215, 24.165205], [91.87461853, 24.16520309], [91.87459564, 24.16501808], [91.87454224, 24.164814], [91.87449646, 24.16459465], [91.87443542, 24.16433144], [91.87434387, 24.16418266], [91.87426758, 24.16391182], [91.87419128, 24.16413879], [91.87408447, 24.16412926], [91.87394714, 24.16404724], [91.87406158, 24.16372871], [91.87419128, 24.16370201], [91.87427521, 24.16367912], [91.8746109, 24.16340065], [91.8745575, 24.16333008], [91.8742218, 24.16328049], [91.87413788, 24.16326904], [91.87393951, 24.16350555], [91.8738327, 24.16351891], [91.87374115, 24.16350365], [91.873703, 24.16342545], [91.87369537, 24.16332626], [91.87379456, 24.16308594], [91.87413788, 24.16294479], [91.87422943, 24.16282845], [91.87427521, 24.1626358], [91.87438965, 24.16252136], [91.8744812, 24.16254425], [91.87457275, 24.16256714], [91.87470245, 24.16272545], [91.87477875, 24.16279793], [91.87491608, 24.16286659], [91.87499237, 24.16287041], [91.87511444, 24.16282463], [91.87493134, 24.16269684], [91.87487793, 24.16261292], [91.87482452, 24.16253281], [91.87470245, 24.16222191], [91.8746109, 24.16216087], [91.87466431, 24.16201019], [91.87475586, 24.16205978], [91.87502289, 24.16215515], [91.87507629, 24.16202736], [91.87522888, 24.16187477], [91.87538147, 24.16178513], [91.87556458, 24.16169357], [91.87579346, 24.16155434], [91.87588501, 24.16147041], [91.87599182, 24.16140175], [91.87613678, 24.16142654], [91.87633514, 24.16158104], [91.87639618, 24.16164398], [91.87657928, 24.16157532], [91.87657928, 24.16144371], [91.87654114, 24.16134453], [91.87652588, 24.16119194], [91.87651062, 24.1610508], [91.87643433, 24.16086197], [91.87644196, 24.16073418], [91.87670898, 24.16080093], [91.8768158, 24.16066551], [91.87683105, 24.16055489], [91.87680817, 24.16042709], [91.87662506, 24.16041565], [91.87657166, 24.16049004], [91.87644196, 24.16054916], [91.87631989, 24.16044617], [91.87633514, 24.16034698], [91.87646484, 24.16009331], [91.87636566, 24.16001701], [91.87617493, 24.16006088], [91.87612915, 24.15998268], [91.87624359, 24.15993118], [91.87618256, 24.15983772], [91.87606812, 24.15974617], [91.87595367, 24.15968704], [91.87596893, 24.15957832], [91.87607574, 24.15950584], [91.87619019, 24.15939522], [91.8764267, 24.15931129], [91.87644958, 24.15916634], [91.87625885, 24.15919685], [91.8761673, 24.15907478], [91.87634277, 24.15896034], [91.87649536, 24.15888405], [91.87679291, 24.15895653], [91.87689972, 24.1588974], [91.8767395, 24.1587162], [91.87683105, 24.15853691], [91.87680817, 24.15841103], [91.87656403, 24.15840149], [91.87637329, 24.15845299], [91.87634277, 24.15837288], [91.8764267, 24.15831947], [91.8766098, 24.15820313], [91.87669373, 24.15811729], [91.87686157, 24.1580677], [91.87692261, 24.15781212], [91.8771286, 24.15787315], [91.87719727, 24.15784454], [91.87723541, 24.15769386], [91.8769989, 24.15763664], [91.87693024, 24.15745354], [91.87661743, 24.15739441], [91.87660217, 24.15727615], [91.87666321, 24.15707397], [91.87663269, 24.15695953], [91.87638855, 24.1569252], [91.87617493, 24.1567173], [91.87623596, 24.15654564], [91.87599182, 24.15649223], [91.87599182, 24.15641403], [91.8759079, 24.15637589], [91.87730408, 24.15428543], [91.87734222, 24.15422249], [91.87740326, 24.15397835], [91.87744904, 24.15410233], [91.87758636, 24.15397072], [91.87758636, 24.15368271], [91.87757874, 24.15325165], [91.87760162, 24.15316963], [91.87762451, 24.15307999], [91.87772369, 24.15306091], [91.87792206, 24.15300179], [91.87779236, 24.15288925], [91.87788391, 24.1528492], [91.87808228, 24.15280724], [91.8780899, 24.15267754], [91.87807465, 24.15234947], [91.87804413, 24.15217781], [91.87809753, 24.1521244], [91.87824249, 24.1522274], [91.87836456, 24.15237617], [91.8784256, 24.15230942], [91.87836456, 24.15218163], [91.87831879, 24.15210342], [91.87831116, 24.1520195], [91.87853241, 24.15187645], [91.87856293, 24.15180588], [91.878479, 24.15178108], [91.87839508, 24.1517868], [91.87836456, 24.15151024], [91.8786087, 24.1516304], [91.87876129, 24.15175438], [91.87885284, 24.15182304], [91.87901306, 24.15163803], [91.87890625, 24.15151787], [91.87869263, 24.15141678], [91.87867737, 24.15134621], [91.87888336, 24.15119362], [91.87901306, 24.15104294], [91.87898254, 24.15096664], [91.87885284, 24.1510067], [91.87873077, 24.15106773], [91.87847137, 24.1512661], [91.87839508, 24.15119362], [91.87837982, 24.15112305], [91.87844849, 24.15084076], [91.87847137, 24.15069199], [91.87834167, 24.15071106], [91.8781662, 24.1509304], [91.87822723, 24.15056038], [91.87825775, 24.15030861], [91.87809753, 24.15016937], [91.87796783, 24.15011978], [91.87799072, 24.15003777], [91.87812042, 24.15005684], [91.87828064, 24.15015793], [91.87843323, 24.15005302], [91.87831116, 24.14988899], [91.87822723, 24.14972687], [91.87812042, 24.14964676], [91.8783493, 24.14950752], [91.87828064, 24.14943314], [91.87825775, 24.14912796], [91.87838745, 24.14915657], [91.87850189, 24.14918137], [91.87879944, 24.14916611], [91.87883759, 24.14897919], [91.87874603, 24.14894676], [91.8785553, 24.14889526], [91.87841797, 24.14878654], [91.87844086, 24.14846802], [91.87837219, 24.14838219], [91.87846375, 24.14812469], [91.87836456, 24.14805984], [91.87817383, 24.14811134], [91.87797546, 24.14805222], [91.8779068, 24.14799881], [91.87783813, 24.1479454], [91.87787628, 24.14785576], [91.8780365, 24.14779472], [91.87815094, 24.14772987], [91.87827301, 24.14770889], [91.87844849, 24.14766312], [91.87848663, 24.14758682], [91.87837219, 24.14749908], [91.87828827, 24.14743233], [91.87828827, 24.14731026], [91.87837982, 24.14728737], [91.8786087, 24.14733315], [91.87882233, 24.14735413], [91.87883759, 24.14745903], [91.87882996, 24.14761543], [91.87897491, 24.1476593], [91.87911224, 24.14739227], [91.87910461, 24.14722443], [91.87909698, 24.14691925], [91.87897491, 24.1468792], [91.87865448, 24.1468544], [91.87853241, 24.14683533], [91.87847137, 24.1467762], [91.87850952, 24.14666939], [91.87849426, 24.14655876], [91.87857819, 24.14643669], [91.87862396, 24.14634895], [91.87875366, 24.14622307], [91.87905121, 24.1462326], [91.87910461, 24.14612579], [91.87917328, 24.14603424], [91.87918854, 24.14595795], [91.87939453, 24.14582443], [91.87947083, 24.14572144], [91.87969208, 24.14540291], [91.87973022, 24.14534187], [91.87983704, 24.14532852], [91.88009644, 24.14563751], [91.88018036, 24.14575958], [91.88022614, 24.14582443], [91.88035583, 24.14596367], [91.88058472, 24.14587593], [91.88082886, 24.14592552], [91.88095093, 24.14595795], [91.88109589, 24.14599419], [91.88118744, 24.14595032], [91.8811264, 24.14582062], [91.88153076, 24.14550781], [91.8818512, 24.14486122], [91.88199615, 24.14487839], [91.88195801, 24.14464569], [91.88234711, 24.14385796], [91.88253784, 24.14396858], [91.88260651, 24.14404678], [91.88282013, 24.14391136], [91.88301849, 24.14370728], [91.8832016, 24.14347076], [91.8833847, 24.14333725], [91.88354492, 24.14326668], [91.8835907, 24.14320374], [91.88362122, 24.1431179], [91.88365173, 24.14286804], [91.88365936, 24.1427536], [91.88368988, 24.14262581], [91.88392639, 24.14272118], [91.88414764, 24.14289093], [91.88430023, 24.14277077], [91.88437653, 24.14271355], [91.8844223, 24.14251518], [91.88420868, 24.14238167], [91.88405609, 24.14228249], [91.88394165, 24.14215088], [91.88389587, 24.14176559], [91.88396454, 24.1416626], [91.8841629, 24.14157486], [91.88431549, 24.14147186], [91.88439178, 24.14134026], [91.88441467, 24.14125633], [91.88435364, 24.14113998], [91.88430023, 24.1410141], [91.88667297, 24.13868904], [91.88681793, 24.13870239], [91.88696289, 24.13872147], [91.88728333, 24.13872719], [91.88782501, 24.13856125], [91.8879776, 24.13855362], [91.88807678, 24.13857269], [91.88816071, 24.13866615], [91.88820648, 24.13872337], [91.88835907, 24.13899994], [91.88871002, 24.13900185], [91.88894653, 24.13898277], [91.88903046, 24.13891411], [91.88909149, 24.13882828], [91.88913727, 24.13876152], [91.88923645, 24.13859177], [91.88931274, 24.13838577], [91.88925171, 24.13831329], [91.88910675, 24.13821602], [91.88898468, 24.1381588], [91.88900757, 24.13807678], [91.88916779, 24.13799095], [91.88954926, 24.13793755], [91.88964081, 24.13792038], [91.88977051, 24.13781929], [91.88977051, 24.13756371], [91.88980103, 24.13741302], [91.89190674, 24.13787842], [91.89302063, 24.13878059], [91.89315033, 24.1388855], [91.89447021, 24.13994026], [91.89569092, 24.14007568], [91.8972168, 24.13948822], [91.89730072, 24.1394558], [91.89753723, 24.13936234], [91.89775085, 24.13956833], [91.89782715, 24.13960838], [91.8980484, 24.13955307], [91.89815521, 24.13947678], [91.89822388, 24.13943672], [91.89839935, 24.13935471], [91.89846039, 24.1392746], [91.89945221, 24.13866615], [91.90192413, 24.13714409], [91.90216064, 24.13710213], [91.90228271, 24.13788986], [91.90254974, 24.13783836], [91.90273285, 24.13799286], [91.90349579, 24.13851166], [91.90364838, 24.13861465], [91.90436554, 24.13856506], [91.90488434, 24.13864517], [91.90502167, 24.13876534], [91.90527344, 24.13891411], [91.90570068, 24.13881493], [91.90591431, 24.13934708], [91.90579224, 24.13951492], [91.90589905, 24.13975906], [91.90586853, 24.14001083], [91.90583801, 24.14010811], [91.90581512, 24.14020157], [91.90544128, 24.14091873], [91.90568542, 24.14127541], [91.90588379, 24.14161301], [91.9056778, 24.14178467], [91.9056778, 24.14196205], [91.90605927, 24.14193535], [91.90616608, 24.14202499], [91.90596771, 24.14229965], [91.90582275, 24.14250183], [91.90553284, 24.14255524], [91.90544891, 24.14270401], [91.90576935, 24.14289665], [91.90605164, 24.14295387], [91.90612793, 24.14296722], [91.90608215, 24.14307785], [91.90605927, 24.14321709], [91.90592957, 24.14321899], [91.9058609, 24.14349556], [91.90603638, 24.14367867], [91.90609741, 24.14374161], [91.90616608, 24.14382553], [91.90604401, 24.14391708], [91.90585327, 24.14405823], [91.90592957, 24.14439964], [91.90576935, 24.1445446], [91.90593719, 24.14484215], [91.90600586, 24.1449604], [91.90638733, 24.14507675], [91.90670013, 24.14545059], [91.90726471, 24.14571953], [91.90763855, 24.14575768], [91.90774536, 24.14592361], [91.90764618, 24.14612389], [91.90789795, 24.14625168], [91.90828705, 24.14608574], [91.90859222, 24.1460743], [91.90869904, 24.14608574], [91.90877533, 24.14609146], [91.90890503, 24.14608002], [91.90899658, 24.14618683], [91.90971375, 24.14645004], [91.9099884, 24.14648056], [91.91012573, 24.14646912], [91.9101944, 24.14661598], [91.91020203, 24.14673042], [91.90984344, 24.14673233], [91.90979767, 24.14689255], [91.90974426, 24.1470108], [91.90976715, 24.14717293], [91.91009521, 24.14718819], [91.91011047, 24.14731979], [91.90996552, 24.14748192], [91.90981293, 24.14776039], [91.90996552, 24.14809418], [91.91039276, 24.14824867], [91.91087341, 24.14843559], [91.91106415, 24.14851189], [91.91103363, 24.14872742], [91.91095734, 24.14886284], [91.91090393, 24.14897156], [91.91101074, 24.14904213], [91.91114807, 24.14910507], [91.91121674, 24.14917564], [91.91120148, 24.1492672], [91.91088867, 24.14936066], [91.91069031, 24.14941978], [91.91051483, 24.14975357], [91.91044617, 24.14989471], [91.91036987, 24.14999008], [91.91034698, 24.15006065], [91.91027832, 24.15042686], [91.91014099, 24.1503849], [91.91000366, 24.15037918], [91.90985107, 24.15037346], [91.9095993, 24.15066147], [91.90962219, 24.15076065], [91.90974426, 24.15091896], [91.90994263, 24.1510601], [91.9103241, 24.15133667], [91.9106369, 24.15145111], [91.91110229, 24.15224648], [91.91093445, 24.15226555], [91.91104126, 24.15255356], [91.91105652, 24.15268517], [91.91110229, 24.15315819], [91.91133118, 24.15371895], [91.91145325, 24.15373802], [91.91160583, 24.15373993], [91.91171265, 24.15370178], [91.91177368, 24.15363312], [91.9118576, 24.15355873], [91.91202545, 24.15341568], [91.91225433, 24.15329933], [91.91259766, 24.15337944], [91.91321564, 24.15339088], [91.91348267, 24.15340996], [91.91365051, 24.15344048], [91.91383362, 24.15351677], [91.91392517, 24.15354347], [91.91417694, 24.15360832], [91.91437531, 24.15363121], [91.91443634, 24.15368462], [91.91447449, 24.15376854], [91.91443634, 24.15386772], [91.91432953, 24.15397072], [91.9141922, 24.15401459], [91.91410065, 24.15407562], [91.91395569, 24.15408516], [91.91382599, 24.15403366], [91.91370392, 24.15398407], [91.91355133, 24.15392685], [91.913414, 24.15394592], [91.91314697, 24.15392494], [91.91299438, 24.15393639], [91.91293335, 24.15402412], [91.91288757, 24.15413094], [91.91280365, 24.15433121], [91.9127655, 24.15457153], [91.91274261, 24.15467453], [91.91278076, 24.15476036], [91.91287231, 24.15480995], [91.91300201, 24.15488434], [91.91319275, 24.15498924], [91.91326904, 24.15502357], [91.91345215, 24.15505791], [91.91359711, 24.15506935], [91.9136734, 24.1550808], [91.91378021, 24.15508461], [91.91391754, 24.15507698], [91.91402435, 24.1550808], [91.91410828, 24.15515327], [91.91416168, 24.1552906], [91.91408539, 24.15542793], [91.91400909, 24.15546608], [91.91390228, 24.15546989], [91.91369629, 24.15543556], [91.91347504, 24.15534782], [91.91322327, 24.15543175], [91.91300201, 24.15575218], [91.91312408, 24.15587425], [91.91326141, 24.1559906], [91.91357422, 24.15610504], [91.91365051, 24.15613365], [91.91381836, 24.15622902], [91.91371155, 24.15642166], [91.91348267, 24.15666008], [91.91339874, 24.15683556], [91.91334534, 24.15699196], [91.91321564, 24.15731812], [91.91314697, 24.15751266], [91.91321564, 24.15769196], [91.91344452, 24.15769768], [91.91372681, 24.15770912], [91.91390228, 24.15771675], [91.91404724, 24.1577549], [91.91414642, 24.15776634], [91.91429901, 24.15789604], [91.91434479, 24.15803146], [91.91418457, 24.15812874], [91.91392517, 24.15811539], [91.91365051, 24.15820313], [91.9136734, 24.15829086], [91.91373444, 24.15842819], [91.91373444, 24.15858841], [91.91370392, 24.15878105], [91.91378784, 24.15893745], [91.91374207, 24.15907478], [91.91369629, 24.15929985], [91.9138031, 24.15934753], [91.91395569, 24.15941048], [91.91411591, 24.15947533], [91.91414642, 24.1595459], [91.91392517, 24.15972519], [91.91379547, 24.159832], [91.91370392, 24.1598835], [91.91320801, 24.16003418], [91.91333771, 24.16011429], [91.91349792, 24.16023636], [91.913414, 24.16034126], [91.91320801, 24.16028023], [91.91311646, 24.16022873], [91.91303253, 24.16020966], [91.91298676, 24.16030121], [91.91296387, 24.16049576], [91.91285706, 24.16067505], [91.91278076, 24.16079903], [91.91269684, 24.16083336], [91.91260529, 24.16086197], [91.91247559, 24.16094971], [91.91259003, 24.1610527], [91.91279602, 24.16119385], [91.91278076, 24.16156197], [91.91282654, 24.16165161], [91.9130249, 24.16166496], [91.91329193, 24.16168022], [91.91352081, 24.16164017], [91.91363525, 24.16166687], [91.91358185, 24.16174889], [91.91352081, 24.16179848], [91.913414, 24.16181946], [91.9132309, 24.16186333], [91.91313171, 24.16189194], [91.91309357, 24.16195869], [91.91307068, 24.16203117], [91.91318512, 24.16214561], [91.91331482, 24.16223717], [91.91350555, 24.16230965], [91.91362762, 24.16230774], [91.91374969, 24.1622982], [91.91386414, 24.16233253], [91.91381073, 24.16247177], [91.91368866, 24.16251183], [91.9135437, 24.16257668], [91.91344452, 24.16255188], [91.91335297, 24.16258621], [91.91336823, 24.16271019], [91.91343689, 24.16275597], [91.91339874, 24.16287613], [91.91330719, 24.16293716], [91.91319275, 24.16297913], [91.9131012, 24.16300774], [91.91296387, 24.16313934], [91.91288757, 24.16323853], [91.91285706, 24.16333199], [91.91278839, 24.16339684], [91.91270447, 24.16341209], [91.91261292, 24.16337776], [91.91253662, 24.16334915], [91.91236877, 24.16337013], [91.91230774, 24.16345978], [91.9122467, 24.16350365], [91.91212463, 24.16347313], [91.91184998, 24.16349792], [91.91182709, 24.1635952], [91.91170502, 24.16371155], [91.91162109, 24.1638546], [91.91147614, 24.16400719], [91.91133881, 24.16413307], [91.91137695, 24.16423798], [91.91156769, 24.16426659], [91.91172028, 24.16430473], [91.9118042, 24.1642952], [91.91199493, 24.16439438], [91.91217041, 24.16444397], [91.91226959, 24.16443062], [91.91248322, 24.16446686], [91.91271973, 24.16463661], [91.91287231, 24.16475105], [91.91281128, 24.16491508], [91.91275787, 24.16507339], [91.91267395, 24.16520882], [91.91274261, 24.16534042], [91.91273499, 24.16544724], [91.91281128, 24.16551208], [91.91303253, 24.16562653], [91.91319275, 24.16570473], [91.91330719, 24.16574287], [91.91358948, 24.16581154], [91.91382599, 24.16583633], [91.91407776, 24.16587257], [91.9140625, 24.16608429], [91.9140625, 24.16621017], [91.91416168, 24.16634178], [91.91421509, 24.16642952], [91.91431427, 24.16646004], [91.91446686, 24.16638184], [91.91453552, 24.16634941], [91.91468811, 24.16628265], [91.9148407, 24.16623116], [91.91487122, 24.16674805], [91.91469574, 24.1668396], [91.9145813, 24.16693497], [91.91446686, 24.16689873], [91.91432953, 24.16681099], [91.91425323, 24.16683197], [91.91411591, 24.16695213], [91.91405487, 24.16705894], [91.91399384, 24.16716385], [91.91401672, 24.16724586], [91.91400909, 24.16735649], [91.91399384, 24.16750145], [91.91395569, 24.16760445], [91.91385651, 24.1675663], [91.91366577, 24.16757011], [91.91353607, 24.16767502], [91.91347504, 24.16773033], [91.9133606, 24.16782188], [91.9131012, 24.16781616], [91.91293335, 24.16786194], [91.91269684, 24.16794586], [91.91255951, 24.16806793], [91.9123764, 24.16810608], [91.91214752, 24.16817284], [91.91207123, 24.1683445], [91.91200256, 24.16849518], [91.9119339, 24.16853523], [91.91184998, 24.16854477], [91.91177368, 24.1684742], [91.91171265, 24.16836929], [91.91165161, 24.16825485], [91.91158295, 24.16817665], [91.91149139, 24.1681118], [91.91137695, 24.16804314], [91.91127777, 24.16804314], [91.91132355, 24.16831589], [91.91159821, 24.16926765], [91.91188049, 24.17021561], [91.91201782, 24.17066956], [91.91218567, 24.17124176], [91.91259003, 24.17263222], [91.9132309, 24.17481232], [91.91397858, 24.17733955], [91.91466522, 24.17966461], [91.91563416, 24.18297768], [91.91623688, 24.1850071], [91.9168396, 24.18720818], [91.91796112, 24.19073677], [91.91915894, 24.19494057], [91.91938019, 24.19570541], [91.92011261, 24.19819069], [91.92071533, 24.20023346], [91.92165375, 24.20340157], [91.92241669, 24.20600319], [91.9235611, 24.20989418], [91.92453003, 24.21319389], [91.92533112, 24.21590424], [91.92583466, 24.21762466], [91.92589569, 24.21782303], [91.9259491, 24.21799278], [91.9260025, 24.21818161], [91.92605591, 24.21837044], [91.92635345, 24.2193737], [91.92682648, 24.22097588], [91.92787933, 24.22455025], [91.92867279, 24.22724342], [91.92923737, 24.22917366], [91.9296875, 24.2306881], [91.93061066, 24.23383522], [91.93105316, 24.23534012], [91.931633, 24.23730278], [91.93202972, 24.23853683], [91.93228149, 24.23950958], [91.93299866, 24.24194145], [91.93354034, 24.24377823], [91.93403625, 24.24547958], [91.93464661, 24.24755287], [91.93508148, 24.24902534], [91.93601227, 24.25217438], [91.93638611, 24.25344276], [91.93695068, 24.255373], [91.93788147, 24.25851822], [91.93860626, 24.2610054], [91.93910217, 24.26266289], [91.93990326, 24.26538658], [91.94074249, 24.26823807], [91.93998718, 24.27076149], [91.93972778, 24.27161407], [91.93942261, 24.27262688], [91.9391098, 24.27366638], [91.93849182, 24.27575111], [91.93758392, 24.278759], [91.93671417, 24.28166199], [91.93588257, 24.2844162], [91.93516541, 24.28680992], [91.93476868, 24.28814507], [91.93427277, 24.28977776], [91.93361664, 24.29197693], [91.93326569, 24.29313469], [91.93254089, 24.29554176], [91.93199921, 24.29734802], [91.93119049, 24.30004311], [91.93074799, 24.30151367], [91.93027496, 24.30307579], [91.93002319, 24.30392075], [91.92990875, 24.30431557], [91.92894745, 24.30748749], [91.92867279, 24.308424], [91.92803192, 24.31056023], [91.92768097, 24.31170464], [91.92741394, 24.31261253], [91.92671204, 24.3149395], [91.92604065, 24.31718636], [91.92545319, 24.31925964], [91.92498779, 24.32067108], [91.92493439, 24.32083321], [91.9249115, 24.32091713], [91.92436981, 24.3226757], [91.92382813, 24.32448387], [91.92312622, 24.32683182], [91.92284393, 24.32777596], [91.92189026, 24.33095741], [91.92160797, 24.33190918], [91.92076111, 24.33473587], [91.92045593, 24.3357563], [91.91992188, 24.3375206], [91.92028046, 24.33709335], [91.92049408, 24.33667755], [91.92070007, 24.33657455], [91.92088318, 24.33654976], [91.92098999, 24.33658791], [91.92105865, 24.336483], [91.92114258, 24.33631325], [91.92134094, 24.33621788], [91.92140961, 24.33601379], [91.92156982, 24.33586311], [91.92166901, 24.33582497], [91.921875, 24.33573532], [91.92201996, 24.33581352], [91.92211914, 24.33579826], [91.92221069, 24.33582497], [91.92227173, 24.33576584], [91.92237091, 24.33582497], [91.92254639, 24.33584785], [91.92264557, 24.33583641], [91.92279816, 24.33594131], [91.92284393, 24.33587456], [91.92295837, 24.33596992], [91.92312622, 24.33597565], [91.92312622, 24.33605957], [91.9233017, 24.33605385], [91.92343903, 24.33616066], [91.92351532, 24.33611298], [91.92360687, 24.3361187], [91.92379761, 24.33615112], [91.92385864, 24.33620071], [91.92393494, 24.33613586], [91.92407227, 24.33611679], [91.92411804, 24.33618164], [91.92409515, 24.33629799], [91.92409515, 24.33639145], [91.92423248, 24.33642197], [91.92433167, 24.33637428], [91.92434692, 24.33649063], [91.92446136, 24.33646011], [91.92453003, 24.33636093], [91.92462158, 24.3363781], [91.92464447, 24.33627129], [91.92472839, 24.33629799], [91.92469788, 24.33636665], [91.92487335, 24.33649063], [91.92504883, 24.336483], [91.92498779, 24.33639908], [91.92508698, 24.33639908], [91.92524719, 24.33653259], [91.92532349, 24.33666229], [91.92540741, 24.33660889], [91.9254837, 24.33661842], [91.92546082, 24.3367157], [91.92557526, 24.33664894], [91.9256897, 24.33670425], [91.92572784, 24.33663177], [91.92568207, 24.33655357], [91.9258728, 24.33657265], [91.92597961, 24.33656693], [91.92594147, 24.33666229], [91.9259491, 24.33687401], [91.92603302, 24.33691978], [91.92613983, 24.33716393], [91.92617035, 24.33723259], [91.92627716, 24.33728981], [91.92636108, 24.33729172], [91.92646027, 24.3374176], [91.92640686, 24.33750534], [91.92643738, 24.33771133], [91.92645264, 24.33788872], [91.92640686, 24.33798409], [91.92653656, 24.33796692], [91.92664337, 24.33805275], [91.92662048, 24.33826828], [91.92671204, 24.33832741], [91.92675781, 24.3385582], [91.92689514, 24.33840561], [91.92697144, 24.33838272], [91.92707825, 24.33845901], [91.92704773, 24.33857918], [91.92714691, 24.33864212], [91.92719269, 24.33871841], [91.92701721, 24.33889198], [91.92704773, 24.33896065], [91.92714691, 24.33894539], [91.92722321, 24.3390522], [91.92712402, 24.33917809], [91.92733765, 24.33915901], [91.92752075, 24.33918381], [91.92760468, 24.33922386], [91.92770386, 24.3393631], [91.92779541, 24.33936501], [91.92787933, 24.33943367], [91.92791748, 24.33951759], [91.92808533, 24.33951569], [91.92809296, 24.33959007], [91.92816162, 24.33964348], [91.92823029, 24.3396759], [91.92832184, 24.33971977], [91.92830658, 24.33980179], [91.92838287, 24.33979034], [91.92848969, 24.33972168], [91.92869568, 24.33971596], [91.9288559, 24.3397274], [91.929039, 24.33972931], [91.92912292, 24.33970451], [91.92933655, 24.33967018], [91.92951202, 24.33976364], [91.92959595, 24.33989525], [91.92959595, 24.33997345], [91.92967987, 24.34000969], [91.92977905, 24.33992767], [91.92990112, 24.33998108], [91.92990112, 24.33989143], [91.93002319, 24.33981895], [91.9305954, 24.34018517], [91.9307251, 24.34026909], [91.93161011, 24.34060097], [91.9316864, 24.34062958], [91.93196106, 24.34069061], [91.93203735, 24.34084129], [91.93190002, 24.34090805], [91.9320755, 24.34099388], [91.93218231, 24.34114838], [91.93206024, 24.34119225], [91.93202209, 24.34127998], [91.93216705, 24.34125519], [91.93222046, 24.34141541], [91.93235016, 24.34132957], [91.93247986, 24.34118271], [91.93270874, 24.34116364], [91.93278503, 24.34118271], [91.93297577, 24.34120178], [91.93302155, 24.3413887], [91.93309784, 24.3413887], [91.93312073, 24.34117889], [91.93312073, 24.34108543], [91.9331131, 24.3409729], [91.9331665, 24.34075165], [91.93338776, 24.34096146], [91.93344879, 24.34091568], [91.93347931, 24.34070778], [91.9335022, 24.34056473], [91.93352509, 24.34045982], [91.93358612, 24.3403511], [91.93364716, 24.34039116], [91.93367767, 24.34049606], [91.93365479, 24.34070206], [91.93372345, 24.34075737], [91.93383026, 24.34060287], [91.93408203, 24.34052849], [91.93434906, 24.34050751], [91.93440247, 24.3404541], [91.93428802, 24.34034157], [91.93437195, 24.34025383], [91.9344635, 24.34019661], [91.93445587, 24.34004784], [91.93467712, 24.34005928], [91.93480682, 24.34004593], [91.93478394, 24.33994293], [91.93481445, 24.33983994], [91.93495178, 24.33990669], [91.93516541, 24.34013748], [91.93508911, 24.3402195], [91.93500519, 24.34026527], [91.93500519, 24.34036064], [91.93507385, 24.34044647], [91.93516541, 24.34053993], [91.93517303, 24.34076118], [91.93526459, 24.34098434], [91.93543243, 24.34111786], [91.93561554, 24.3412838], [91.93569183, 24.34147263], [91.93574524, 24.34140205], [91.93582153, 24.34130669], [91.93589783, 24.34128952], [91.93595123, 24.34133911], [91.93603516, 24.34142494], [91.93619537, 24.34136391], [91.93628693, 24.3413868], [91.93653107, 24.34141731], [91.93658447, 24.34149361], [91.93637848, 24.3415947], [91.93636322, 24.34172058], [91.93649292, 24.34178543], [91.93688202, 24.34169579], [91.93681335, 24.34190941], [91.93684387, 24.34198761], [91.93704987, 24.34193039], [91.93699646, 24.34205055], [91.93713379, 24.34211731], [91.93714142, 24.3421936], [91.93709564, 24.34225845], [91.93710327, 24.34243774], [91.93743896, 24.34255028], [91.93764496, 24.34261894], [91.93753052, 24.34277534], [91.93786621, 24.34288406], [91.93796539, 24.34280777], [91.93802643, 24.34294319], [91.93805695, 24.34311485], [91.93814087, 24.34306908], [91.93825531, 24.34304619], [91.93841553, 24.34323502], [91.93833923, 24.34337807], [91.93845367, 24.34339714], [91.93859863, 24.34323883], [91.9387207, 24.34321404], [91.93888092, 24.34327507], [91.93891144, 24.34320068], [91.938797, 24.34300232], [91.94030762, 24.34350586], [91.94156647, 24.34538841], [91.94167328, 24.34554672], [91.9418335, 24.34577942], [91.94174957, 24.34598732], [91.94176483, 24.34615898], [91.94180298, 24.346241], [91.94200134, 24.34625435], [91.94213867, 24.34621811], [91.94219208, 24.34629059], [91.9420929, 24.34641647], [91.94206238, 24.34652328], [91.94218445, 24.34649277], [91.94229889, 24.3464489], [91.94234467, 24.34650993], [91.94239807, 24.34659195], [91.94223022, 24.34667206], [91.94200134, 24.3469944], [91.9420929, 24.34729958], [91.94215393, 24.34734917], [91.94251251, 24.34731674], [91.94241333, 24.34758186], [91.94251251, 24.34763145], [91.94291687, 24.34766006], [91.94306946, 24.3477478], [91.94326019, 24.34799767], [91.9431839, 24.34805107], [91.94309235, 24.34805298], [91.94301605, 24.34815025], [91.94321442, 24.34872627], [91.94332123, 24.34890938], [91.94328308, 24.34906387], [91.94346619, 24.34900284], [91.94351959, 24.34891319], [91.94364166, 24.3487072], [91.94372559, 24.34865761], [91.94385529, 24.34888268], [91.94417572, 24.3487072], [91.94438934, 24.34864998], [91.94443512, 24.34871101], [91.94459534, 24.3488903], [91.94477081, 24.34887123], [91.94506073, 24.34897614], [91.94521332, 24.34915924], [91.94618225, 24.34956741], [91.94639587, 24.34984779], [91.94641113, 24.34998512], [91.94641113, 24.35015678], [91.94632721, 24.35033417], [91.94618988, 24.35044861], [91.94619751, 24.3505249], [91.94617462, 24.3507061], [91.94618225, 24.35081291], [91.94643402, 24.35084152], [91.9466629, 24.3510437], [91.94675446, 24.35105705], [91.94680786, 24.35099602], [91.94698334, 24.35081291], [91.94719696, 24.35090446], [91.94728851, 24.35092545], [91.94755554, 24.35083199], [91.94765472, 24.35088348], [91.94762421, 24.3509903], [91.94763184, 24.35115433], [91.94771576, 24.35110474], [91.94789124, 24.35104179], [91.94813538, 24.35104942], [91.94834137, 24.35107231], [91.948349, 24.35098648], [91.94837189, 24.35087013], [91.94856262, 24.35066032], [91.9490509, 24.35102463], [91.94915009, 24.35109711], [91.94924164, 24.35116768], [91.9495163, 24.35137749], [91.94960022, 24.35134125], [91.94976044, 24.35112381], [91.94992065, 24.35091972], [91.95008087, 24.35094643], [91.95010376, 24.35110664], [91.9502182, 24.35126686], [91.95031738, 24.35147476], [91.95057678, 24.35147858], [91.95078278, 24.35150146], [91.95085144, 24.35164833], [91.95108032, 24.35192108], [91.95109558, 24.3520298], [91.95090485, 24.35201263], [91.95081329, 24.35223389], [91.95082855, 24.35236168], [91.95079803, 24.35246277], [91.95107269, 24.35254669], [91.95134735, 24.35275459], [91.95162201, 24.35296059], [91.95172119, 24.35303307], [91.95185089, 24.35313225], [91.95222473, 24.35341072], [91.95259094, 24.35365105], [91.9526825, 24.35371971], [91.95606995, 24.35572052], [91.95610046, 24.35585976], [91.9562149, 24.35600662], [91.95622253, 24.35612869], [91.95633698, 24.35634041], [91.95640564, 24.35662842], [91.95666504, 24.35681725], [91.95710754, 24.35658073], [91.95747375, 24.35645103], [91.95774841, 24.35619926], [91.95788574, 24.35604095], [91.95805359, 24.35583878], [91.95838928, 24.3554287], [91.95887756, 24.35484314], [91.95922852, 24.35445786], [91.95956421, 24.35428047], [91.95995331, 24.35416603], [91.96066284, 24.35404396], [91.96078491, 24.35396004], [91.96125031, 24.35389519], [91.96160126, 24.35379028], [91.9619751, 24.35353088], [91.96224213, 24.35330009], [91.96238708, 24.35310173], [91.96251678, 24.35276413], [91.96303558, 24.35181046], [91.96337891, 24.35115433], [91.96350098, 24.35103607], [91.96392822, 24.35063362], [91.96429443, 24.35043144], [91.96459198, 24.35033798], [91.96490479, 24.350317], [91.96535492, 24.35032463], [91.96593475, 24.35041428], [91.96633148, 24.35047531], [91.96708679, 24.35052681], [91.967453, 24.35060883], [91.96773529, 24.35067177], [91.96828461, 24.3506031], [91.96858215, 24.35046387], [91.96891785, 24.35027695], [91.96904755, 24.35006332], [91.96913147, 24.34985161], [91.96909332, 24.34958458], [91.96899414, 24.34939575], [91.96891785, 24.34925652], [91.96873474, 24.34906197], [91.96855164, 24.34890556], [91.96833038, 24.34882927], [91.96727753, 24.34851265], [91.96631622, 24.34809494], [91.9659729, 24.34777641], [91.96583557, 24.34749222], [91.96573639, 24.34719276], [91.96577454, 24.34707832], [91.9658432, 24.34684944], [91.96607208, 24.34661484], [91.96642303, 24.34637833], [91.96794891, 24.34582901], [91.96873474, 24.34539032], [91.96925354, 24.34498215], [91.96983337, 24.34452629], [91.97034454, 24.34388161], [91.97088623, 24.3432045], [91.97117615, 24.34268379], [91.97142029, 24.34220505], [91.97157288, 24.34145737], [91.97154999, 24.34065056], [91.97147369, 24.33958817], [91.97147369, 24.33942795], [91.97146606, 24.33922195], [91.97150421, 24.33865929], [91.97175598, 24.33751106], [91.97205353, 24.33654022], [91.97219849, 24.33625031], [91.97248077, 24.33530426], [91.97284698, 24.3343029], [91.97316742, 24.33339882], [91.97344971, 24.33288002], [91.97377014, 24.33267212], [91.97406006, 24.33238029], [91.97438049, 24.33206558], [91.9748764, 24.33155632], [91.97910309, 24.33179283], [91.98291016, 24.33111572], [91.98607635, 24.3260498], [91.99007416, 24.3239727], [91.99015045, 24.32402611], [91.99029541, 24.32406044], [91.99047089, 24.32402992], [91.99098969, 24.32380486], [91.99126434, 24.32365036], [91.99156189, 24.32343102], [91.99217224, 24.32291031], [91.99228668, 24.322855], [91.99330902, 24.32235527], [91.99356842, 24.32222939], [91.99459076, 24.3222332], [91.99585724, 24.32217979], [91.99584961, 24.32320786], [91.99584198, 24.32332993], [91.99584198, 24.32342529], [91.99582672, 24.32376289], [91.99588776, 24.32405472], [91.99593353, 24.3243103], [91.99597931, 24.32437515], [91.99611664, 24.32439041], [91.99617767, 24.32497787], [91.99626923, 24.32557869], [91.99629211, 24.32591057], [91.9963913, 24.3265667], [91.99639893, 24.32673073], [91.99619293, 24.32674789], [91.99597168, 24.32675743], [91.99572754, 24.326828], [91.99572754, 24.32692719], [91.99571991, 24.32712364], [91.99568939, 24.32745552], [91.99567413, 24.32761955], [91.99567413, 24.32772446], [91.99531555, 24.32778931], [91.99530792, 24.32798004], [91.9952774, 24.32844353], [91.99524689, 24.32890701], [91.99521637, 24.32912827], [91.99501801, 24.32921219], [91.99501038, 24.32932854], [91.99499512, 24.32943726], [91.99495697, 24.32978249], [91.99490356, 24.33036423], [91.99489594, 24.33049202], [91.99488831, 24.33099747], [91.99491882, 24.33156967], [91.99565887, 24.33186722], [91.99565125, 24.33272743], [91.99562836, 24.33420563], [91.99582672, 24.33420753], [91.99586487, 24.33465004], [91.99608612, 24.33465004], [91.99610138, 24.33525085], [91.99625397, 24.33525276], [91.99627686, 24.33564949], [91.99667358, 24.33563805], [91.9967804, 24.33694458], [91.99651337, 24.33689117], [91.9963913, 24.33709908], [91.99629211, 24.33810997], [91.9956131, 24.3392086], [91.993927, 24.33993912], [91.99302673, 24.33996964], [91.99291992, 24.34160805], [91.99291229, 24.34170723], [91.99290466, 24.34184837], [91.99282837, 24.3424511], [91.99204254, 24.34350395], [91.98920441, 24.34375], [91.98840332, 24.34647942], [91.98835754, 24.346632], [91.98828125, 24.3468914], [91.98815918, 24.34690475], [91.98795319, 24.34691811], [91.98786926, 24.34713745], [91.98777771, 24.34737015], [91.98770142, 24.34760094], [91.98754883, 24.34778595], [91.98739624, 24.34788704], [91.98735046, 24.34803772], [91.98727417, 24.34817123], [91.98715973, 24.34817505], [91.98696899, 24.34819603], [91.98683929, 24.34823608], [91.98667145, 24.34835815], [91.98653412, 24.34840012], [91.98638916, 24.34842873], [91.98627472, 24.3484726], [91.9862442, 24.34856033], [91.98626709, 24.34866905], [91.98623657, 24.34889412], [91.98626709, 24.34905434], [91.98632813, 24.34920502], [91.98627472, 24.34931183], [91.98628235, 24.34945297], [91.98604584, 24.3495121], [91.98588562, 24.34955978], [91.98587799, 24.34967422], [91.9859314, 24.34979057], [91.98592377, 24.35003281], [91.98581696, 24.35016441], [91.985672, 24.35023308], [91.98553467, 24.35027504], [91.98543549, 24.35037231], [91.98535156, 24.35042572], [91.9851532, 24.35048676], [91.98497009, 24.3505497], [91.98480225, 24.35062408], [91.98468018, 24.35069084], [91.98459625, 24.35088921], [91.98453522, 24.35106087], [91.98442841, 24.35120964], [91.98428345, 24.35130882], [91.98413849, 24.35142136], [91.98386383, 24.35157776], [91.9836731, 24.35170937], [91.98361206, 24.35181999], [91.98344421, 24.35196686], [91.98335266, 24.35207748], [91.98319244, 24.35213661], [91.98292542, 24.35219193], [91.98279572, 24.35232925], [91.98275757, 24.35252953], [91.98271179, 24.35266876], [91.9826355, 24.3529129], [91.98253632, 24.35302544], [91.98238373, 24.35318375], [91.98230743, 24.35330391], [91.98220825, 24.35345268], [91.98220062, 24.35362244], [91.98226166, 24.3539257], [91.98220062, 24.35404205], [91.9821167, 24.35416412], [91.98197937, 24.35439301], [91.98187256, 24.35444069], [91.98156738, 24.35447502], [91.98132324, 24.35449219], [91.98117065, 24.35455132], [91.9810791, 24.35452843], [91.98091888, 24.35448265], [91.98078156, 24.35456085], [91.98087311, 24.35462952], [91.98105621, 24.35476303], [91.9811554, 24.3548851], [91.98129272, 24.3550148], [91.98146057, 24.35516739], [91.98143768, 24.35526657], [91.98137665, 24.35545921], [91.98124695, 24.3555088], [91.9810791, 24.35546684], [91.98091125, 24.35535622], [91.98070526, 24.3552475], [91.98054504, 24.35520172], [91.9804306, 24.3552494], [91.98018646, 24.35540199], [91.97994232, 24.35566711], [91.97982025, 24.35582352], [91.97963715, 24.35605049], [91.97950745, 24.35620117], [91.9794693, 24.35636139], [91.97959137, 24.35647011], [91.97967529, 24.35655594], [91.97969055, 24.35671806], [91.97962952, 24.35676956], [91.97948456, 24.35682869], [91.97937012, 24.35685349], [91.97916412, 24.35689735], [91.97872162, 24.3569355], [91.97846222, 24.35708237], [91.97830963, 24.35722542], [91.97821045, 24.35735512], [91.97807312, 24.35751152], [91.97803497, 24.35761261], [91.97808075, 24.35774994], [91.97814941, 24.35780716], [91.97830963, 24.35786819], [91.97851563, 24.35795021], [91.97878265, 24.3579731], [91.97886658, 24.35800934], [91.97895813, 24.35808372], [91.97904205, 24.35817337], [91.97903442, 24.35835457], [91.9790802, 24.35844994], [91.97920227, 24.35851479], [91.97917175, 24.35873032], [91.97908783, 24.35874176], [91.97893524, 24.35871696], [91.97880554, 24.35876274], [91.97881317, 24.35887146], [91.97884369, 24.35900497], [91.97885895, 24.3591404], [91.97894287, 24.35923958], [91.97904968, 24.3592968], [91.97911835, 24.35941696], [91.97917175, 24.35953903], [91.97923279, 24.35969543], [91.97928619, 24.35980797], [91.97938538, 24.35981178], [91.97950745, 24.35974121], [91.97960663, 24.35967064], [91.97974396, 24.35968971], [91.97971344, 24.35983086], [91.97964478, 24.36002541], [91.97951508, 24.3603096], [91.97950745, 24.36052322], [91.97957611, 24.36058426], [91.9797287, 24.36053276], [91.97980499, 24.36046791], [91.97992706, 24.36032677], [91.98004913, 24.36022758], [91.98014069, 24.36006927], [91.98023224, 24.35997963], [91.98033905, 24.35998917], [91.98065948, 24.36006355], [91.98085785, 24.36008263], [91.98097229, 24.36003304], [91.98110199, 24.35997772], [91.98124695, 24.35996819], [91.98134613, 24.35995102], [91.98152924, 24.36021042], [91.98431396, 24.36066818], [91.98445129, 24.36069107], [91.98451233, 24.36078072], [91.98457336, 24.3608551], [91.98457336, 24.36101151], [91.98458099, 24.36118698], [91.98448944, 24.36129189], [91.98435974, 24.36143684], [91.98423767, 24.36157417], [91.98413849, 24.36169243], [91.98400116, 24.36169815], [91.98379517, 24.36196327], [91.98369598, 24.36208344], [91.98353577, 24.36222649], [91.9834137, 24.36226845], [91.98324585, 24.36228943], [91.98308563, 24.36221123], [91.98292542, 24.36219978], [91.98267365, 24.36243248], [91.98254395, 24.3624897], [91.98234558, 24.36256599], [91.98205566, 24.36256981], [91.98187256, 24.36250687], [91.98175049, 24.36252594], [91.98160553, 24.3625164], [91.98152924, 24.36271286], [91.98146057, 24.36293602], [91.98152924, 24.36303711], [91.98140717, 24.36318779], [91.98132324, 24.36318588], [91.98119354, 24.36328506], [91.98106384, 24.36325455], [91.98094177, 24.36329842], [91.98081207, 24.363451], [91.98065948, 24.36360931], [91.98052979, 24.36371422], [91.98027802, 24.36384583], [91.98014832, 24.36393356], [91.98010254, 24.36405182], [91.98011017, 24.36414337], [91.98009491, 24.36427879], [91.98011017, 24.36439705], [91.98011017, 24.36458397], [91.98009491, 24.36476326], [91.98006439, 24.36492538], [91.9800415, 24.36508751], [91.97999573, 24.36530113], [91.97996521, 24.36541748], [91.9799118, 24.36551285], [91.97983551, 24.3656311], [91.97972107, 24.36581039], [91.97966766, 24.3659687], [91.97944641, 24.36589432], [91.97924042, 24.36591721], [91.97898865, 24.36602211], [91.97875214, 24.36623192], [91.97851563, 24.36646461], [91.97839355, 24.36663818], [91.97827911, 24.36677551], [91.97821808, 24.3668766], [91.97814941, 24.36704445], [91.97814178, 24.36724663], [91.97821045, 24.36751366], [91.97827148, 24.36774445], [91.97844696, 24.36812973], [91.97855377, 24.36850548], [91.97862244, 24.36887741], [91.97866821, 24.36907005], [91.97875977, 24.36944199], [91.97889709, 24.36970329], [91.97884369, 24.36990929], [91.97872162, 24.370224], [91.97844696, 24.37059212], [91.97833252, 24.37067032], [91.97806549, 24.37086678], [91.97777557, 24.37123489], [91.97768402, 24.37132072], [91.9776535, 24.37140656], [91.97761536, 24.371521], [91.97759247, 24.37159729], [91.97745514, 24.3717289], [91.97731018, 24.3717556], [91.97721863, 24.37177277], [91.97703552, 24.37200165], [91.97701263, 24.37207222], [91.977211, 24.37235641], [91.9773407, 24.37242126], [91.97750854, 24.37261581], [91.97747803, 24.37279129], [91.97745514, 24.37288666], [91.97736359, 24.37299919], [91.97714996, 24.37308502], [91.97701263, 24.37299728], [91.97689056, 24.37267494], [91.97673035, 24.37239838], [91.97650909, 24.37210655], [91.97622681, 24.3718586], [91.97585297, 24.37172508], [91.97546387, 24.37132263], [91.97510529, 24.37110138], [91.97467041, 24.37083626], [91.97425079, 24.37071609], [91.97400665, 24.37069893], [91.97380829, 24.37080574], [91.97361755, 24.37095451], [91.97357178, 24.37106323], [91.97356415, 24.37134361], [91.97361755, 24.37141609], [91.97357941, 24.37148476], [91.97354126, 24.37154961], [91.97319794, 24.37217903], [91.97285461, 24.37257004], [91.97266388, 24.3727684], [91.97251129, 24.37290573], [91.97220612, 24.37307358], [91.97194672, 24.37320709], [91.97180176, 24.3732872], [91.97168732, 24.37339211], [91.97148132, 24.3735981], [91.97132111, 24.37364388], [91.97121429, 24.373703], [91.97103882, 24.37387085], [91.97080994, 24.37401581], [91.97060394, 24.37424278], [91.97057343, 24.37432861], [91.97048187, 24.37433434], [91.9703064, 24.37438774], [91.97011566, 24.37447357], [91.970047, 24.3745575], [91.96988678, 24.37488747], [91.97007751, 24.3750248], [91.97044373, 24.37518501], [91.97070312, 24.37532043], [91.97105408, 24.37555695], [91.97128296, 24.37570572], [91.97143555, 24.37580872], [91.97187805, 24.37618065], [91.97245789, 24.3768158], [91.97265625, 24.37716293], [91.97273254, 24.3774395], [91.97280121, 24.37770844], [91.97280121, 24.37817574], [91.97272491, 24.37869072], [91.97248077, 24.37919426], [91.97215271, 24.37965775], [91.9719696, 24.37976074], [91.97167206, 24.37992668], [91.97132874, 24.38007164], [91.9710083, 24.38016319], [91.97064209, 24.38016891], [91.97022247, 24.38005257], [91.96992493, 24.37995338], [91.96945953, 24.37965965], [91.96907043, 24.37944412], [91.96862793, 24.37914085], [91.96831512, 24.37896919], [91.96788025, 24.37884521], [91.9675827, 24.37882233], [91.96738434, 24.37893105], [91.96711731, 24.37904167], [91.96703339, 24.37916183], [91.96695709, 24.37938881], [91.96690369, 24.37950134], [91.96685028, 24.37981415], [91.96686554, 24.38015938], [91.96691132, 24.38052177], [91.9670639, 24.38098717], [91.96721649, 24.38128662], [91.96741486, 24.38155937], [91.96776581, 24.38196373], [91.96819305, 24.38245201], [91.96856689, 24.38280106], [91.9688797, 24.38313293], [91.96931458, 24.38353729], [91.96958923, 24.38390541], [91.96975708, 24.38407707], [91.97003174, 24.38439751], [91.9701004, 24.38445091], [91.97035217, 24.38465691], [91.97045898, 24.38468933], [91.97073364, 24.38477516], [91.97107697, 24.38484383], [91.97151184, 24.38489914], [91.9719162, 24.38488007], [91.97221375, 24.38482094], [91.97267151, 24.38468933], [91.97309113, 24.38446045], [91.97332001, 24.38433075], [91.97361755, 24.38409233], [91.97393799, 24.38380432], [91.97445679, 24.38333511], [91.9750061, 24.38284111], [91.9754715, 24.38253212], [91.97585297, 24.38233948], [91.97628784, 24.38220024], [91.97671509, 24.38207436], [91.97725677, 24.38196754], [91.97780609, 24.38186073], [91.97839355, 24.3817997], [91.97899628, 24.38168526], [91.97946167, 24.38166237], [91.98002625, 24.3816185], [91.98040771, 24.38154411], [91.98078156, 24.38144493], [91.98109436, 24.38134193], [91.98162842, 24.38115501], [91.98197937, 24.38085556], [91.98232269, 24.38062286], [91.98257446, 24.38035202], [91.98274994, 24.37995338], [91.98287964, 24.37952995], [91.98307037, 24.37890053], [91.98316193, 24.37832069], [91.98326874, 24.37789536], [91.98336029, 24.37763023], [91.98350525, 24.37737083], [91.98366547, 24.37723923], [91.98379517, 24.37710571], [91.98440552, 24.3768692], [91.98467255, 24.37674713], [91.98508453, 24.37679672], [91.98544312, 24.37693787], [91.98568726, 24.37700462], [91.98587799, 24.37724113], [91.98609924, 24.37753677], [91.9853363, 24.38170815], [91.98590088, 24.38427734], [91.98591614, 24.38435364], [91.98609924, 24.38546181], [91.98703766, 24.386343], [91.9899292, 24.38897514], [91.99209595, 24.38817596], [91.99203491, 24.38883781], [91.99199677, 24.38903427], [91.99189758, 24.38927841], [91.99143982, 24.38962173], [91.99079895, 24.38984299], [91.99054718, 24.3898735], [91.99016571, 24.38991737], [91.98950958, 24.38994789], [91.98955536, 24.39030647], [91.98977661, 24.39042091], [91.98997498, 24.39047623], [91.99003601, 24.39053154], [91.99034882, 24.39071083], [91.99048615, 24.39070511], [91.9907608, 24.39050102], [91.99086761, 24.39048004], [91.99120331, 24.39041328], [91.99146271, 24.39021301], [91.99185181, 24.39023781], [91.99210358, 24.38995743], [91.99233246, 24.38980103], [91.99267578, 24.3895607], [91.99295044, 24.38914299], [91.9931488, 24.38888359], [91.99334717, 24.38869095], [91.99332428, 24.38853455], [91.99333191, 24.38840866], [91.99337769, 24.38834572], [91.99350739, 24.38831711], [91.9936676, 24.38830566], [91.99423981, 24.38823891], [91.99465179, 24.38817787], [91.99481201, 24.38819504], [91.99489594, 24.38825989], [91.99546814, 24.38868904], [91.99559021, 24.38877678], [91.99571228, 24.38916969], [91.99584961, 24.38953018], [91.99595642, 24.3897438], [91.99611664, 24.3905983], [91.99617004, 24.39073372], [91.99611664, 24.39091873], [91.9960556, 24.3911171], [91.99591064, 24.39139748], [91.9957428, 24.39143753], [91.99539948, 24.3917141], [91.99530792, 24.39172173], [91.99525452, 24.39178467], [91.99513245, 24.39192009], [91.99499512, 24.39200592], [91.99475861, 24.39215088], [91.9947052, 24.39227104], [91.99482727, 24.39236832], [91.9949646, 24.39238358], [91.99528503, 24.39220619], [91.99568176, 24.39213562], [91.99586487, 24.39225197], [91.99607086, 24.39247322], [91.99617767, 24.39261436], [91.99620819, 24.39270401], [91.99620056, 24.39283752], [91.99620819, 24.39335823], [91.99620819, 24.39351654], [91.99620056, 24.39359856], [91.99628448, 24.39374352], [91.99642181, 24.39382744], [91.99649811, 24.39387512], [91.99669647, 24.39378929], [91.99694061, 24.39369011], [91.99707031, 24.3935585], [91.99716949, 24.39342499], [91.99723816, 24.39325714], [91.99730682, 24.39280128], [91.99729919, 24.39255333], [91.99736786, 24.3924942], [91.99751282, 24.39243507], [91.99769592, 24.39247131], [91.99804688, 24.39246178], [91.99845123, 24.3922863], [91.99852753, 24.39226151], [91.99863434, 24.39225769], [91.99876404, 24.39235115], [91.99884796, 24.39237213], [91.99918365, 24.39240456], [91.99925232, 24.39233398], [91.99945068, 24.39213943], [91.99964142, 24.39192772], [91.99974823, 24.39183044], [91.99996185, 24.39197731], [92.00004578, 24.39203453], [92.00012207, 24.39208984], [92.00091553, 24.39068604], [92.00390625, 24.38891602], [92.00671387, 24.38690186], [92.00671387, 24.38677025], [92.00668335, 24.38311768], [92.00668335, 24.38303185], [92.01013184, 24.3819809], [92.0102005, 24.38202286], [92.0100174, 24.38223076], [92.01006317, 24.38232422], [92.01016235, 24.38231277], [92.01031494, 24.38253975], [92.0105896, 24.38276291], [92.01078796, 24.38291168], [92.01103973, 24.3828392], [92.01115417, 24.38298607], [92.01132965, 24.38289452], [92.01147461, 24.38298988], [92.01160431, 24.38286591], [92.01291656, 24.38365173], [92.0134964, 24.38377762], [92.01342773, 24.38391304], [92.01358032, 24.38409805], [92.01370239, 24.38420486], [92.01385498, 24.38385391], [92.01407623, 24.38392258], [92.01422119, 24.38396835], [92.01437378, 24.38401794], [92.01454163, 24.38407135], [92.01499176, 24.38409996], [92.01516724, 24.38413811], [92.01532745, 24.38417244], [92.01543427, 24.38419533], [92.01553345, 24.38421631], [92.01594543, 24.38430595], [92.01581573, 24.38437271], [92.01576233, 24.38449097], [92.01602173, 24.38452911], [92.01613617, 24.384758], [92.01628113, 24.38475227], [92.01652527, 24.38472939], [92.01672363, 24.38478661], [92.01689148, 24.38476372], [92.0171814, 24.38472748], [92.01730347, 24.38459778], [92.0174408, 24.38476181], [92.01753235, 24.38472748], [92.01764679, 24.38467216], [92.01769257, 24.38486671], [92.01783752, 24.38504219], [92.01802826, 24.38508415], [92.01811981, 24.38521194], [92.01818085, 24.38525391], [92.01832581, 24.38537979], [92.01838684, 24.3854866], [92.0185318, 24.38551331], [92.01861572, 24.38562393], [92.01872253, 24.38573837], [92.01894379, 24.385849], [92.01909637, 24.38601685], [92.01922607, 24.38604736], [92.01926422, 24.38619995], [92.01937866, 24.38632774], [92.01950836, 24.38648033], [92.01972198, 24.38639069], [92.01977539, 24.38655853], [92.01986694, 24.38666534], [92.01998901, 24.38669205], [92.0201416, 24.38653946], [92.02028656, 24.38652802], [92.02046967, 24.38641548], [92.02069855, 24.38628006], [92.02093506, 24.3862381], [92.02111053, 24.38613701], [92.02137756, 24.38605499], [92.02155304, 24.38602448], [92.02193451, 24.3861599], [92.02237701, 24.38619041], [92.02264404, 24.38612747], [92.02275848, 24.38609695], [92.02288055, 24.38609695], [92.02307129, 24.38607407], [92.02329254, 24.38587952], [92.02346802, 24.38580132], [92.02354431, 24.38576889], [92.02362823, 24.3856926], [92.02372742, 24.38557816], [92.0236969, 24.38549423], [92.02361298, 24.38531113], [92.0235672, 24.38522148], [92.02347565, 24.38510513], [92.02335358, 24.38490486], [92.02339935, 24.38483238], [92.02333832, 24.38474464], [92.02313232, 24.38478279], [92.02294922, 24.38483047], [92.02294159, 24.38455009], [92.02287292, 24.38444328], [92.02271271, 24.38440323], [92.0226059, 24.38438988], [92.02255249, 24.38420296], [92.0223465, 24.38403511], [92.02224731, 24.38395691], [92.02210236, 24.38393402], [92.02193451, 24.38384056], [92.02178955, 24.38378906], [92.0216217, 24.38394737], [92.021492, 24.38394547], [92.0214386, 24.38386917], [92.02147675, 24.38366508], [92.02144623, 24.38353729], [92.02146149, 24.38344193], [92.0215683, 24.3833828], [92.02173615, 24.38317108], [92.02181244, 24.38306808], [92.02199554, 24.38299942], [92.02216339, 24.38289261], [92.02241516, 24.3829422], [92.02269745, 24.38299751], [92.02296448, 24.38303566], [92.02318573, 24.383255], [92.02349854, 24.38340569], [92.02373505, 24.38353157], [92.02384949, 24.3835144], [92.02407837, 24.38341904], [92.02425385, 24.38369179], [92.02438354, 24.38371658], [92.02469635, 24.38363457], [92.02464294, 24.38346672], [92.02474976, 24.38337517], [92.02490234, 24.3834095], [92.02487183, 24.38319016], [92.02488708, 24.38310814], [92.02494049, 24.38290596], [92.02487183, 24.38272476], [92.02507019, 24.38265228], [92.02502441, 24.38255119], [92.02494812, 24.38249016], [92.02522278, 24.38228798], [92.02540588, 24.38232803], [92.02558136, 24.38229561], [92.02600098, 24.38221359], [92.02624512, 24.38220596], [92.02645111, 24.38221931], [92.02663422, 24.38195038], [92.02666473, 24.38150215], [92.02680206, 24.38143349], [92.02681732, 24.38121605], [92.02677155, 24.38084412], [92.02675629, 24.38071251], [92.02680969, 24.38062859], [92.02696228, 24.38057709], [92.02692413, 24.38035202], [92.02676392, 24.38021088], [92.0266571, 24.37995911], [92.02674866, 24.37975502], [92.02697754, 24.37990761], [92.02711487, 24.37988663], [92.0272522, 24.37967873], [92.02758789, 24.37962723], [92.02783966, 24.37981796], [92.02794647, 24.37966728], [92.02812195, 24.3796463], [92.02824402, 24.37971115], [92.02828979, 24.37985611], [92.02855682, 24.3800602], [92.02869415, 24.38002205], [92.02893829, 24.37986946], [92.02902985, 24.3800869], [92.02928162, 24.38023186], [92.02948761, 24.38019943], [92.02957153, 24.37999344], [92.02957916, 24.37984276], [92.03062439, 24.3801136], [92.03199768, 24.38046646], [92.0320816, 24.38043213], [92.0343399, 24.37947083], [92.03455353, 24.37950706], [92.03462982, 24.37981224], [92.03483582, 24.38002396], [92.03491211, 24.3799839], [92.03505707, 24.37997627], [92.03530884, 24.37981033], [92.03538513, 24.37981606], [92.03555298, 24.3798008], [92.03549957, 24.37995148], [92.03555298, 24.38010025], [92.03565216, 24.38022232], [92.03578949, 24.38025665], [92.03581238, 24.38018799], [92.03569794, 24.38013268], [92.03577423, 24.38001823], [92.03605652, 24.37982559], [92.03604889, 24.37973785], [92.036026, 24.37954521], [92.03630066, 24.37927628], [92.03624725, 24.37903214], [92.03635406, 24.3790226], [92.03666687, 24.37917709], [92.03675842, 24.37921143], [92.03675079, 24.37912369], [92.03674316, 24.37904739], [92.03691864, 24.37901306], [92.03697968, 24.37893867], [92.03689575, 24.37888908], [92.03704071, 24.37878799], [92.03714752, 24.37874222], [92.03723907, 24.37853432], [92.03733063, 24.37858009], [92.03736877, 24.37864494], [92.03743744, 24.37860489], [92.03762054, 24.37837601], [92.03775787, 24.37841034], [92.03778839, 24.3782177], [92.0375824, 24.3780117], [92.03777313, 24.37796402], [92.03778839, 24.37775612], [92.03778839, 24.37765503], [92.03803253, 24.3775425], [92.03820038, 24.37753296], [92.03826904, 24.37745667], [92.03824615, 24.37732697], [92.03839111, 24.37717628], [92.03847504, 24.3771801], [92.03868866, 24.37731934], [92.03907013, 24.37701225], [92.03917694, 24.37691116], [92.03933716, 24.37690163], [92.03946686, 24.37689018], [92.03959656, 24.37693405], [92.03969574, 24.37693596], [92.03968811, 24.37679672], [92.04008484, 24.37683487], [92.04007721, 24.37690926], [92.03988647, 24.37693596], [92.03987122, 24.37711906], [92.04001617, 24.37707329], [92.04006958, 24.3769989], [92.04018402, 24.37701416], [92.0403595, 24.3771019], [92.04043579, 24.37706184], [92.04055023, 24.37701797], [92.04061127, 24.37714195], [92.04064178, 24.3772583], [92.04078674, 24.37722206], [92.04093933, 24.37725258], [92.04115295, 24.3772583], [92.04128265, 24.37734032], [92.04137421, 24.37737274], [92.04149628, 24.37732124], [92.04167938, 24.377388], [92.04192352, 24.37746239], [92.04206848, 24.37747574], [92.04237366, 24.37742615], [92.04256439, 24.37738609], [92.04263306, 24.37745857], [92.04286957, 24.37770653], [92.04299164, 24.37764931], [92.04312897, 24.37754059], [92.04320526, 24.37733459], [92.04318237, 24.3772049], [92.04303741, 24.37705421], [92.0429306, 24.3769474], [92.04281616, 24.37679863], [92.04267883, 24.3767128], [92.04283905, 24.37658501], [92.04298401, 24.37663078], [92.04310608, 24.37661171], [92.04312897, 24.3768177], [92.04327393, 24.37688637], [92.04333496, 24.37684059], [92.04457855, 24.3759594], [92.0453949, 24.37614441], [92.04533386, 24.37624931], [92.04527283, 24.37636566], [92.04532623, 24.37644958], [92.04551697, 24.3764534], [92.04562378, 24.37648392], [92.04571533, 24.37659073], [92.04579163, 24.37650871], [92.04587555, 24.37651253], [92.04602051, 24.37661743], [92.04605103, 24.37629509], [92.04636383, 24.37636566], [92.04646301, 24.37638855], [92.04660034, 24.37641907], [92.04654694, 24.37631989], [92.04679108, 24.37627029], [92.04676819, 24.37638092], [92.04680634, 24.37646484], [92.04690552, 24.37668228], [92.04682159, 24.37699127], [92.04705048, 24.37694359], [92.04724884, 24.37709999], [92.04759216, 24.37694931], [92.04766083, 24.37710762], [92.04788208, 24.37723732], [92.04798126, 24.37742043], [92.04815674, 24.37747955], [92.04808807, 24.37762451], [92.04813385, 24.3776989], [92.04825592, 24.37770653], [92.04834747, 24.37762451], [92.0484848, 24.37757111], [92.04864502, 24.37755966], [92.04873657, 24.37771034], [92.0488739, 24.37770271], [92.0489502, 24.37766075], [92.0490036, 24.37717247], [92.04894257, 24.37706375], [92.04903412, 24.37698555], [92.04914856, 24.37680435], [92.05627441, 24.37609863], [92.0605545, 24.37586975], [92.06427002, 24.37567139], [92.07189941, 24.37527657], [92.07680511, 24.37521935], [92.07691956, 24.37525558], [92.07723999, 24.3752327], [92.07743835, 24.37523842], [92.0776825, 24.37530518], [92.07776642, 24.37548065], [92.07797241, 24.3754406], [92.07842255, 24.37534142], [92.0786438, 24.37515259], [92.07900238, 24.37508965], [92.07935333, 24.37509537], [92.07954407, 24.37503624], [92.07987976, 24.3749218], [92.0801239, 24.37477303], [92.08026886, 24.37490845], [92.08059692, 24.37491608], [92.08089447, 24.37483025], [92.08098602, 24.37488556], [92.08131409, 24.37498474], [92.08164978, 24.37499237], [92.08200836, 24.37500381], [92.0821991, 24.37501335], [92.08247375, 24.37508583], [92.08269501, 24.37517738], [92.08309174, 24.37512207], [92.08319092, 24.37524414], [92.08338165, 24.37537956], [92.08357239, 24.37541389], [92.08393097, 24.37548637], [92.08411407, 24.37547493], [92.08432007, 24.3755722], [92.0845108, 24.37547684], [92.08469391, 24.37557602], [92.08494568, 24.37546539], [92.08514404, 24.37574577], [92.08541107, 24.37561226], [92.08574677, 24.37528992], [92.08904266, 24.37342072], [92.09368896, 24.37432861], [92.09656525, 24.37544441], [92.09664917, 24.37552071], [92.09729767, 24.3761158], [92.09724426, 24.37623787], [92.09731293, 24.37635612], [92.09741211, 24.37640953], [92.09754944, 24.37634659], [92.09990692, 24.37852287], [92.10002136, 24.37862778], [92.10011292, 24.37871361], [92.10114288, 24.38011742], [92.10105133, 24.38021088], [92.10089874, 24.38052559], [92.10085297, 24.38061523], [92.10054016, 24.38069725], [92.10018921, 24.38058472], [92.09997559, 24.38064766], [92.10009766, 24.38080406], [92.10023499, 24.38092804], [92.10046387, 24.38098907], [92.10083771, 24.38101959], [92.10094452, 24.38104248], [92.10111237, 24.38107681], [92.10126495, 24.38133049], [92.10132599, 24.38144684], [92.10148621, 24.38160706], [92.10163116, 24.38172913], [92.10194397, 24.38192749], [92.10194397, 24.38218117], [92.10179138, 24.38241959], [92.10162354, 24.38251686], [92.10168457, 24.38267517], [92.10186768, 24.38287354], [92.10196686, 24.38293457], [92.10232544, 24.38305664], [92.10256195, 24.38301277], [92.10289764, 24.38298225], [92.10333252, 24.38287735], [92.1036911, 24.38263512], [92.10382843, 24.38243484], [92.10394287, 24.38229179], [92.10407257, 24.38207436], [92.10404968, 24.38182449], [92.10405731, 24.38141251], [92.1040802, 24.38117599], [92.10437012, 24.38114166], [92.10544586, 24.38211441], [92.10571289, 24.38222504], [92.10562897, 24.38285446], [92.10561371, 24.38302422], [92.10559845, 24.38323784], [92.10559845, 24.38337898], [92.10826874, 24.38212776], [92.11187744, 24.38287354], [92.11594391, 24.38446426], [92.11608887, 24.38452148], [92.11933136, 24.3839035], [92.12200928, 24.38599777], [92.12192535, 24.38607407], [92.12168121, 24.38625526], [92.12171936, 24.38641357], [92.12187958, 24.3865757], [92.12182617, 24.38677788], [92.12145996, 24.38682938], [92.1213913, 24.38707161], [92.1217041, 24.38706398], [92.12181091, 24.38706207], [92.12190247, 24.3871479], [92.1217041, 24.3874054], [92.12159729, 24.3873806], [92.12121582, 24.38729477], [92.1209259, 24.38732147], [92.12046814, 24.38790321], [92.12002563, 24.38757515], [92.11985779, 24.38779449], [92.11986542, 24.38813019], [92.12012482, 24.38870239], [92.11966705, 24.38856888], [92.11933136, 24.38851929], [92.1191864, 24.38858795], [92.11907959, 24.38874245], [92.11962128, 24.38899803], [92.11968231, 24.38912201], [92.11973572, 24.38923836], [92.11985779, 24.38954544], [92.12017822, 24.38965607], [92.12031555, 24.38958359], [92.12049103, 24.38929558], [92.12069702, 24.38944054], [92.12068176, 24.38966751], [92.12031555, 24.38988304], [92.12008667, 24.38999176], [92.11951447, 24.38961411], [92.11940002, 24.38980484], [92.11929321, 24.38985062], [92.11897278, 24.38998413], [92.11882019, 24.39003181], [92.11883545, 24.3901577], [92.11902618, 24.39024353], [92.11916351, 24.39055824], [92.11975098, 24.39063644], [92.11971283, 24.39076042], [92.11963654, 24.39099884], [92.11981964, 24.39129639], [92.11962128, 24.3915081], [92.12023163, 24.39187813], [92.11980438, 24.39201927], [92.11978912, 24.39213753], [92.11982727, 24.39228249], [92.12008667, 24.39246559], [92.12039948, 24.39245796], [92.12080383, 24.39236641], [92.1210556, 24.39247131], [92.12168121, 24.39319992], [92.12172699, 24.39325905], [92.12162018, 24.39367867], [92.12173462, 24.3938961], [92.12202454, 24.39396858], [92.12206268, 24.39410973], [92.12204742, 24.39430237], [92.12220764, 24.39460373], [92.12224579, 24.39476013], [92.12226105, 24.39499855], [92.12232208, 24.39515305], [92.12246704, 24.39538574], [92.12245178, 24.39562988], [92.12241364, 24.39587784], [92.12248993, 24.39606667], [92.12290955, 24.39616394], [92.1231308, 24.39624786], [92.12322235, 24.39646149], [92.12362671, 24.39678001], [92.12373352, 24.39678001], [92.12409973, 24.39627647], [92.12421417, 24.3962059], [92.12441254, 24.39621544], [92.12547302, 24.39711571], [92.12736511, 24.39875031], [92.12736511, 24.3988781], [92.1269989, 24.39915848], [92.12683868, 24.39978027], [92.12689209, 24.39989662], [92.12751007, 24.40005875], [92.12817383, 24.39970589], [92.12825775, 24.39988327], [92.12840271, 24.40019035], [92.1282196, 24.40067101], [92.12797546, 24.40069389], [92.12787628, 24.40070343], [92.12770844, 24.40099716], [92.12738037, 24.40118027], [92.12729645, 24.40138054], [92.12728119, 24.40177345], [92.12734985, 24.40182304], [92.12760925, 24.40183449], [92.12788391, 24.4020462], [92.12807465, 24.40225601], [92.12837219, 24.40258789], [92.12875366, 24.40266991], [92.1292038, 24.40323067], [92.12953186, 24.40350342], [92.1295166, 24.40387344], [92.1295929, 24.40425682], [92.13005066, 24.40403557], [92.13036346, 24.40404892], [92.13033295, 24.40419197], [92.13008118, 24.40434837], [92.13008881, 24.40451431], [92.13014221, 24.40476799], [92.13040161, 24.40508842], [92.13084412, 24.40561485], [92.13101959, 24.40590858], [92.13122559, 24.40626335], [92.13161469, 24.40629959], [92.13174438, 24.40657043], [92.13144684, 24.40675926], [92.13175964, 24.40706825], [92.13182068, 24.40701866], [92.13204193, 24.40693474], [92.1321106, 24.40678406], [92.13195801, 24.40657806], [92.13201141, 24.40628052], [92.132164, 24.4060688], [92.13231659, 24.4060936], [92.1324234, 24.40618324], [92.13249207, 24.40668869], [92.13264465, 24.4068737], [92.13288879, 24.40678406], [92.13312531, 24.40674973], [92.13314819, 24.40691185], [92.13308716, 24.40716743], [92.13298798, 24.40747261], [92.13316345, 24.40751648], [92.13327789, 24.40723991], [92.13339996, 24.40695572], [92.13369751, 24.40677643], [92.13388062, 24.40675354], [92.13398743, 24.40696716], [92.13407898, 24.40715027], [92.13427734, 24.40728378], [92.13435364, 24.40720749], [92.13499451, 24.40763092], [92.13491058, 24.40803337], [92.13467407, 24.40828323], [92.13470459, 24.40838432], [92.13474274, 24.40849495], [92.13464355, 24.40885353], [92.13471222, 24.40924644], [92.13467407, 24.40954018], [92.13439178, 24.40958977], [92.13420105, 24.40960693], [92.13417816, 24.409729], [92.13433838, 24.41000557], [92.13438416, 24.41008759], [92.13442993, 24.41020584], [92.1342392, 24.41028595], [92.13393402, 24.41028976], [92.13381958, 24.4106636], [92.13380432, 24.41089821], [92.13372803, 24.41098022], [92.13359833, 24.41100502], [92.13322449, 24.41088295], [92.13296509, 24.41077995], [92.13254547, 24.41110802], [92.13249207, 24.41127205], [92.13261414, 24.41147804], [92.13277435, 24.41149712], [92.13309479, 24.41137505], [92.13328552, 24.41142464], [92.13334656, 24.4118576], [92.13342285, 24.41224289], [92.13362122, 24.41267395], [92.13356781, 24.41277313], [92.13343811, 24.41293716], [92.1332016, 24.41311073], [92.13314056, 24.41331291], [92.13331604, 24.41363716], [92.13331604, 24.4137516], [92.13298798, 24.4140358], [92.13288116, 24.41430092], [92.13278961, 24.41451836], [92.13298798, 24.41483498], [92.13309479, 24.41522217], [92.13317108, 24.41575623], [92.13342285, 24.41603279], [92.1332016, 24.41630936], [92.13317108, 24.41643524], [92.13344574, 24.41673088], [92.13323975, 24.41706467], [92.133461, 24.41720009], [92.13370514, 24.41753197], [92.13402557, 24.41774559], [92.13440704, 24.41789627], [92.13454437, 24.41813278], [92.13468933, 24.41836548], [92.13493347, 24.41851616], [92.13505554, 24.41861916], [92.13502502, 24.41888237], [92.13529968, 24.41906357], [92.13567352, 24.41918564], [92.135849, 24.41947746], [92.13605499, 24.41945457], [92.13619995, 24.41956902], [92.1363678, 24.41982841], [92.13651276, 24.42004967], [92.13660431, 24.42016792], [92.13648224, 24.42040634], [92.13644409, 24.42064095], [92.13659668, 24.42103767], [92.13626862, 24.42128181], [92.13621521, 24.42139435], [92.13629913, 24.42164993], [92.13645172, 24.42188263], [92.13647461, 24.4220562], [92.13625336, 24.42218018], [92.13608551, 24.42227364], [92.13613129, 24.42282104], [92.13601685, 24.423069], [92.13599396, 24.42333221], [92.13622284, 24.42362595], [92.13647461, 24.42386627], [92.13671875, 24.42406654], [92.13680267, 24.42413139], [92.13687134, 24.42418671], [92.13686371, 24.424263], [92.13676453, 24.42439842], [92.13670349, 24.42461777], [92.1366272, 24.42480278], [92.13658142, 24.42489433], [92.13669586, 24.42509842], [92.13681793, 24.4251194], [92.13706207, 24.42505646], [92.13726044, 24.42505264], [92.13759613, 24.42505455], [92.13793182, 24.42505836], [92.13821411, 24.42513275], [92.13838196, 24.42523766], [92.13848114, 24.42528725], [92.13863373, 24.42525673], [92.13882446, 24.4250164], [92.13891602, 24.42486382], [92.13904572, 24.42465973], [92.13909912, 24.42449951], [92.14051056, 24.42461395], [92.14277649, 24.42486], [92.14287567, 24.42486763], [92.14795685, 24.42420959], [92.15216064, 24.42518044], [92.15228271, 24.42529297], [92.15311432, 24.42557526], [92.15322876, 24.42561531], [92.15337372, 24.42566299], [92.15361786, 24.42574692], [92.15571594, 24.42645836], [92.15599823, 24.42637062], [92.15979767, 24.42486954], [92.16377258, 24.42172241], [92.16622162, 24.42207336], [92.16584015, 24.42238045], [92.16571045, 24.4225769], [92.16573334, 24.42266846], [92.16579437, 24.4227066], [92.16624451, 24.42273712], [92.16654968, 24.4227562], [92.16662598, 24.42286682], [92.16666412, 24.42295456], [92.16663361, 24.42310715], [92.16658783, 24.4234314], [92.16661835, 24.42358398], [92.16680908, 24.42376328], [92.16707611, 24.42404938], [92.16732788, 24.42423248], [92.16747284, 24.42453194], [92.16764069, 24.42492867], [92.16775513, 24.42525673], [92.16779327, 24.42546654], [92.16770935, 24.42593193], [92.16754913, 24.42638016], [92.16752625, 24.42646408], [92.16746521, 24.4266758], [92.16738129, 24.4270134], [92.16740417, 24.42714119], [92.16744995, 24.42723465], [92.16772461, 24.42739296], [92.16809845, 24.42746735], [92.1684494, 24.42752647], [92.16881561, 24.42763519], [92.16894531, 24.42776871], [92.16904449, 24.42791176], [92.16895294, 24.42805481], [92.16882324, 24.42817688], [92.16862488, 24.42823792], [92.16844177, 24.42829132], [92.16817474, 24.42835426], [92.16765594, 24.42841339], [92.16752625, 24.42839432], [92.16719818, 24.42834091], [92.16664124, 24.42819023], [92.1661911, 24.42807388], [92.16601562, 24.42813301], [92.16591644, 24.4282589], [92.16596985, 24.42849731], [92.16613007, 24.42886925], [92.16631317, 24.42935371], [92.16636658, 24.42974281], [92.16637421, 24.42986298], [92.16638947, 24.43005371], [92.16640472, 24.43029976], [92.16648865, 24.43058014], [92.16655731, 24.4307003], [92.16659546, 24.43077469], [92.16669464, 24.4308567], [92.16694641, 24.43126488], [92.16697693, 24.43155098], [92.16680908, 24.43187523], [92.16648865, 24.43242455], [92.16625977, 24.43267632], [92.16608429, 24.43292618], [92.16595459, 24.43322563], [92.16590881, 24.43343544], [92.16607666, 24.43362808], [92.16617584, 24.43371391], [92.16661835, 24.43374062], [92.16687012, 24.43373489], [92.1671524, 24.43378258], [92.16737366, 24.43394661], [92.16743469, 24.43416023], [92.16736603, 24.43443871], [92.16734314, 24.43469048], [92.16724396, 24.43490791], [92.16705322, 24.43518066], [92.16688538, 24.43539047], [92.16673279, 24.43558311], [92.16664124, 24.43578911], [92.16654968, 24.43619537], [92.16651917, 24.43632507], [92.16602325, 24.43679047], [92.16592407, 24.4368763], [92.16560364, 24.43663597], [92.16539764, 24.43654823], [92.16500854, 24.43643379], [92.16455078, 24.43639183], [92.16414642, 24.4364624], [92.16396332, 24.43658257], [92.16379547, 24.43675804], [92.16368103, 24.43696022], [92.16368103, 24.43720818], [92.16368103, 24.43742943], [92.16377258, 24.43766403], [92.16386414, 24.43796349], [92.16410065, 24.43829346], [92.16416931, 24.43838501], [92.16429138, 24.43855667], [92.16435242, 24.43873978], [92.16434479, 24.43895531], [92.16422272, 24.43906784], [92.16416168, 24.43917465], [92.16408539, 24.43931389], [92.16377258, 24.43948936], [92.16342163, 24.43954086], [92.16313934, 24.43959808], [92.16288757, 24.43964958], [92.16271973, 24.43976212], [92.16252136, 24.44003487], [92.16260529, 24.44018364], [92.16275024, 24.44035339], [92.16291809, 24.44043159], [92.16305542, 24.44049072], [92.16303253, 24.44073296], [92.16291809, 24.4438858], [92.16426849, 24.44491577], [92.16422272, 24.44497871], [92.16386414, 24.44522476], [92.16357422, 24.44547844], [92.16345215, 24.44560623], [92.16334534, 24.44586182], [92.16316986, 24.44615746], [92.16291809, 24.44641685], [92.1627655, 24.44654083], [92.16252899, 24.44677734], [92.16213226, 24.44705772], [92.16201019, 24.4472065], [92.16199493, 24.44731903], [92.16207886, 24.44767952], [92.16210938, 24.4479351], [92.16210938, 24.44820404], [92.16197205, 24.4484539], [92.16175079, 24.44862938], [92.16149139, 24.44870567], [92.16104126, 24.4487648], [92.16091156, 24.44886017], [92.16085815, 24.44915962], [92.16082001, 24.44951057], [92.16085815, 24.44972229], [92.16109467, 24.45004272], [92.16130066, 24.45020103], [92.16179657, 24.45044708], [92.16213226, 24.45067215], [92.1622467, 24.45085907], [92.16230011, 24.45107841], [92.16226196, 24.45125771], [92.16214752, 24.45146179], [92.16196442, 24.45182037], [92.16186523, 24.45207787], [92.16182709, 24.45216942], [92.16172791, 24.45245552], [92.16158295, 24.45277977], [92.16133118, 24.45299911], [92.16096497, 24.45312881], [92.16059875, 24.4531765], [92.16024017, 24.45312691], [92.15984344, 24.45311928], [92.1595993, 24.45320511], [92.15949249, 24.45339394], [92.1595459, 24.45365715], [92.15976715, 24.4539566], [92.16001129, 24.45429802], [92.16013336, 24.45447159], [92.16022491, 24.45465088], [92.16027832, 24.4548111], [92.16034698, 24.45510101], [92.16036987, 24.45546532], [92.16042328, 24.45561981], [92.1608963, 24.45586205], [92.16107941, 24.45596123], [92.16116333, 24.45615768], [92.16120148, 24.45639801], [92.16106415, 24.45667648], [92.16098785, 24.45683289], [92.16085052, 24.45713043], [92.16070557, 24.45727539], [92.1601181, 24.45908356], [92.15981293, 24.45904732], [92.15935516, 24.45893288], [92.15881348, 24.45878983], [92.15848541, 24.45885277], [92.1583252, 24.45896149], [92.15820312, 24.45921898], [92.15811157, 24.45946121], [92.15799713, 24.45979118], [92.15804291, 24.46020889], [92.15816498, 24.46037102], [92.15840149, 24.46044731], [92.15789795, 24.46069336], [92.15787506, 24.46278], [92.15787506, 24.46290207], [92.1585083, 24.46390724], [92.15834808, 24.46392441], [92.1583252, 24.46406174], [92.15837097, 24.46436119], [92.15855408, 24.46477318], [92.15862274, 24.46516609], [92.15860748, 24.4653244], [92.15858459, 24.46545982], [92.15850067, 24.46566391], [92.15837097, 24.46598053], [92.15816498, 24.4662075], [92.15790558, 24.46642685], [92.15757751, 24.46644402], [92.15737915, 24.46643448], [92.15718079, 24.4663372], [92.15686798, 24.46600533], [92.15659332, 24.46573639], [92.1563797, 24.46549606], [92.15624237, 24.46543694], [92.15607452, 24.46543884], [92.15597534, 24.46548653], [92.15582275, 24.4655571], [92.15550995, 24.46578217], [92.15545654, 24.46594048], [92.15546417, 24.46617699], [92.1556015, 24.46661568], [92.15574646, 24.46704483], [92.15582275, 24.46756744], [92.15584564, 24.46774483], [92.15585327, 24.46781731], [92.15589142, 24.46801758], [92.15617371, 24.46844292], [92.15641785, 24.46873474], [92.15665436, 24.46885872], [92.15693665, 24.46899223], [92.15718079, 24.46886444], [92.15736389, 24.46865273], [92.15744781, 24.46845627], [92.15750122, 24.46808052], [92.15756226, 24.46775818], [92.15763092, 24.46757317], [92.15776825, 24.46749115], [92.15795898, 24.46753883], [92.15811157, 24.46763229], [92.15813446, 24.46780968], [92.15815735, 24.46806717], [92.15805054, 24.46854019], [92.15805817, 24.46884727], [92.15805054, 24.46930122], [92.15809631, 24.46971893], [92.15796661, 24.47014236], [92.15782166, 24.47021484], [92.15751648, 24.47025299], [92.1570282, 24.47018051], [92.15670776, 24.47001839], [92.15641785, 24.46990776], [92.15627289, 24.46976852], [92.15597534, 24.46961784], [92.15578461, 24.46962166], [92.15553284, 24.46970177], [92.15533447, 24.46980858], [92.15518951, 24.46995354], [92.15515137, 24.47020912], [92.1552124, 24.47041893], [92.15538025, 24.47073364], [92.15548706, 24.47092819], [92.15559387, 24.47109985], [92.15557861, 24.47123718], [92.15544891, 24.47134399], [92.15530396, 24.47137451], [92.15502167, 24.47151566], [92.15483093, 24.47158623], [92.15459442, 24.47175407], [92.15428925, 24.47204399], [92.15419006, 24.47220993], [92.15419769, 24.47245789], [92.15422821, 24.47255135], [92.15431976, 24.47282028], [92.15450287, 24.47318649], [92.15475464, 24.4734726], [92.15497589, 24.47377205], [92.15531158, 24.47400665], [92.15542603, 24.47407341], [92.15567017, 24.47402763], [92.15578461, 24.47389221], [92.15581512, 24.47377777], [92.15575409, 24.47342873], [92.1555481, 24.47301483], [92.15561676, 24.47283936], [92.15573883, 24.47259712], [92.15592957, 24.47251701], [92.15614319, 24.47274017], [92.15634155, 24.47282982], [92.15670776, 24.472929], [92.15699005, 24.47305679], [92.15710449, 24.47311783], [92.15717316, 24.47329903], [92.15716553, 24.47363472], [92.15717316, 24.47410011], [92.15713501, 24.47426796], [92.1570282, 24.47438622], [92.1567688, 24.47462082], [92.15631104, 24.47488594], [92.15606689, 24.47506523], [92.1558075, 24.47529411], [92.15578461, 24.47547722], [92.15584564, 24.47570419], [92.15592957, 24.47595978], [92.15601349, 24.4762249], [92.15613556, 24.47661591], [92.15614319, 24.47675323], [92.15614319, 24.47686195], [92.15609741, 24.47706413], [92.15599823, 24.47725677], [92.15586853, 24.47739792], [92.15564728, 24.47751617], [92.15509796, 24.47785759], [92.1545639, 24.47816086], [92.15408325, 24.4784832], [92.15380096, 24.47868347], [92.15366364, 24.47882271], [92.15366364, 24.47903824], [92.15366364, 24.47912407], [92.15367889, 24.47967529], [92.15374756, 24.4802475], [92.15367126, 24.48049545], [92.15356445, 24.48062134], [92.15315247, 24.48108673], [92.15267944, 24.48151016], [92.15258026, 24.48163414], [92.152565, 24.48200417], [92.15259552, 24.4822216], [92.1526947, 24.48246956], [92.15284729, 24.48265648], [92.15310669, 24.48285675], [92.15320587, 24.48303032], [92.1531601, 24.48329926], [92.15307617, 24.48366928], [92.15304565, 24.48386002], [92.15309906, 24.48404503], [92.1532135, 24.48421097], [92.15349579, 24.48442268], [92.15374756, 24.48461723], [92.15383148, 24.48468018], [92.15370178, 24.48485374], [92.15365601, 24.4851017], [92.15345764, 24.48526192], [92.1530304, 24.48564148], [92.15296936, 24.48587227], [92.15286255, 24.48610878], [92.15288544, 24.48626709], [92.15293121, 24.48642921], [92.15301514, 24.48658752], [92.15330505, 24.4869194], [92.15319061, 24.48749352], [92.15294647, 24.48737907], [92.15267944, 24.48721695], [92.1524353, 24.48713493], [92.15219116, 24.48715973], [92.15192413, 24.48728371], [92.15180206, 24.48750114], [92.15196228, 24.4881134], [92.15197754, 24.48836136], [92.15198517, 24.48851013], [92.15189362, 24.48886681], [92.15164948, 24.48947906], [92.15166473, 24.489851], [92.15176392, 24.48999596], [92.15210724, 24.49020195], [92.1521759, 24.49041939], [92.15219116, 24.4906044], [92.1519165, 24.49072647], [92.1516571, 24.49084282], [92.15150452, 24.49086952], [92.15129089, 24.49098396], [92.15119171, 24.49114609], [92.1512146, 24.49136162], [92.15136719, 24.49153137], [92.15155029, 24.49158859], [92.15184784, 24.49157906], [92.1525116, 24.49147415], [92.15283966, 24.49144745], [92.15309143, 24.49150848], [92.15320587, 24.4915638], [92.1534729, 24.49169922], [92.15356445, 24.49177361], [92.15342712, 24.49210739], [92.15328217, 24.49226379], [92.15297699, 24.49266434], [92.15248871, 24.49318504], [92.15226746, 24.49349976], [92.15218353, 24.49369049], [92.15216064, 24.49381828], [92.15216064, 24.49408722], [92.1521759, 24.49453354], [92.15206146, 24.49481964], [92.15193176, 24.49487114], [92.15146637, 24.49505615], [92.15136719, 24.49509621], [92.15111542, 24.49520302], [92.15093231, 24.49525261], [92.15052795, 24.49529839], [92.15039825, 24.49536705], [92.15042114, 24.49559402], [92.15048218, 24.49565506], [92.15074158, 24.49580193], [92.15107727, 24.49600029], [92.15133667, 24.49614716], [92.15136719, 24.49625206], [92.15141296, 24.49651146], [92.15143585, 24.49684525], [92.15143585, 24.49731827], [92.15142059, 24.49772072], [92.15144348, 24.49792862], [92.1515274, 24.49818611], [92.15156555, 24.49852562], [92.15148926, 24.49890137], [92.15151978, 24.49913597], [92.1516037, 24.49938011], [92.15174866, 24.49960518], [92.15197754, 24.49980545], [92.15222168, 24.50007057], [92.15252686, 24.50030518], [92.15293121, 24.50131607], [92.15262604, 24.50156593], [92.15236664, 24.50189018], [92.15218353, 24.50225258], [92.15221405, 24.5024147], [92.15245056, 24.50269508], [92.15258026, 24.50280952], [92.1526947, 24.50291824], [92.15291595, 24.50297928], [92.15309906, 24.50300789], [92.15351868, 24.50300598], [92.15361786, 24.50300789], [92.15409851, 24.50419617], [92.15412903, 24.50426674], [92.1541748, 24.50436974], [92.15447998, 24.50488281], [92.15612793, 24.50769043], [92.15883636, 24.50772095], [92.15831757, 24.50825119], [92.15801239, 24.50855446], [92.15763092, 24.50885773], [92.157341, 24.50907135], [92.15703583, 24.50934601], [92.15667725, 24.50965118], [92.15638733, 24.50990295], [92.15592194, 24.51010513], [92.15567017, 24.51024818], [92.15531921, 24.51041031], [92.15490723, 24.51062012], [92.15470886, 24.51081848], [92.15465546, 24.5110321], [92.15466309, 24.51146889], [92.15468597, 24.51178932], [92.1546936, 24.51189423], [92.15454865, 24.51207733], [92.15435791, 24.51209831], [92.15411377, 24.51199532], [92.15382385, 24.51186943], [92.15365601, 24.51181984], [92.1534729, 24.51197243], [92.15344238, 24.51205635], [92.15339661, 24.51218414], [92.15343475, 24.51234436], [92.15361786, 24.51255226], [92.15390015, 24.51267242], [92.15423584, 24.51270294], [92.15458679, 24.51269341], [92.15494537, 24.51275063], [92.15524292, 24.51291656], [92.15537262, 24.51328659], [92.15556335, 24.51335716], [92.15571594, 24.51361465], [92.15586853, 24.51374245], [92.15602875, 24.51377106], [92.15615082, 24.51363945], [92.15621948, 24.51345253], [92.15629578, 24.51314545], [92.15634155, 24.51297379], [92.15644836, 24.51272202], [92.15654755, 24.51262665], [92.15682983, 24.51260757], [92.15697479, 24.51268196], [92.15694427, 24.51282692], [92.15687561, 24.51321602], [92.15679169, 24.51352692], [92.15677643, 24.51367569], [92.15675354, 24.51382637], [92.15677643, 24.51410103], [92.15692902, 24.5143528], [92.15710449, 24.51454163], [92.1571579, 24.51460266], [92.15737915, 24.51477814], [92.15776062, 24.51497459], [92.15802765, 24.51518059], [92.15813446, 24.51533508], [92.1580658, 24.5154686], [92.15801239, 24.51554108], [92.15756989, 24.5155983], [92.15717316, 24.51567078], [92.15680695, 24.51573753], [92.15648651, 24.51592445], [92.15625763, 24.51612663], [92.15608978, 24.51643372], [92.15601349, 24.51669312], [92.15596008, 24.51699257], [92.15585327, 24.51720238], [92.15578461, 24.51739883], [92.15568542, 24.51752663], [92.15554047, 24.51768112], [92.15543365, 24.51803207], [92.15537262, 24.5182457], [92.15509033, 24.51928711], [92.15561676, 24.522686], [92.155159, 24.522686], [92.15500641, 24.52275276], [92.15487671, 24.52290535], [92.15486145, 24.52311897], [92.1550293, 24.52323151], [92.15530396, 24.52328873], [92.1554718, 24.52327728], [92.15571594, 24.5232563], [92.15588379, 24.52429199], [92.15782928, 24.52485275], [92.15790558, 24.52487564], [92.16005707, 24.52566147], [92.15999603, 24.5258522], [92.1598053, 24.52607918], [92.15943909, 24.52638435], [92.15921021, 24.52670479], [92.15890503, 24.52710915], [92.15877533, 24.52744865], [92.15872955, 24.52760124], [92.15886688, 24.52775764], [92.15890503, 24.52782059], [92.15898895, 24.52799416], [92.15904236, 24.52825928], [92.15914154, 24.5285244], [92.15921021, 24.52866936], [92.15933228, 24.52882576], [92.15939331, 24.52890587], [92.15940094, 24.52904892], [92.15959167, 24.52929306], [92.15968323, 24.52943993], [92.15982819, 24.52951241], [92.15986633, 24.52928734], [92.15990448, 24.5290451], [92.1600647, 24.52902603], [92.16031647, 24.52901268], [92.16059875, 24.52900887], [92.16099548, 24.52893066], [92.16126251, 24.52890396], [92.16137695, 24.52878952], [92.16143036, 24.52868462], [92.16143036, 24.52842522], [92.16143036, 24.52799606], [92.16144562, 24.52777481], [92.16146851, 24.52767372], [92.16159058, 24.52762413], [92.16177368, 24.52762222], [92.16202545, 24.52782249], [92.16226196, 24.52817917], [92.16226196, 24.52832413], [92.16257477, 24.5284996], [92.16271973, 24.52856827], [92.16294098, 24.52845001], [92.16325378, 24.52840424], [92.16353607, 24.52829742], [92.16359711, 24.52836037], [92.16375732, 24.528368], [92.16410065, 24.52867508], [92.16433716, 24.52893257], [92.16452789, 24.52906609], [92.16464996, 24.52923965], [92.16512299, 24.52916145], [92.16532898, 24.52919388], [92.16560364, 24.52923584], [92.16565704, 24.5293541], [92.16572571, 24.52950096], [92.16576385, 24.52980804], [92.16569519, 24.530056], [92.1656723, 24.53047943], [92.16551971, 24.53090286], [92.16540527, 24.5310955], [92.16542816, 24.53135681], [92.16549683, 24.5314064], [92.16561127, 24.53153801], [92.16588593, 24.53158569], [92.16598511, 24.53161049], [92.1662674, 24.53168106], [92.16651154, 24.53176689], [92.16668701, 24.53183174], [92.16697693, 24.53193474], [92.16718292, 24.53201485], [92.16729736, 24.53193855], [92.16733551, 24.53182983], [92.16731262, 24.53162575], [92.16729736, 24.53154564], [92.16725922, 24.53137589], [92.16724396, 24.5311718], [92.16723633, 24.53102875], [92.16736603, 24.53098297], [92.16763306, 24.53092766], [92.16778564, 24.53090096], [92.16802216, 24.53093147], [92.16831207, 24.53114891], [92.16853333, 24.53136635], [92.16875458, 24.53155327], [92.16902161, 24.53180504], [92.16918182, 24.53187943], [92.16939545, 24.53187752], [92.16957855, 24.53177834], [92.16983795, 24.53160858], [92.16989899, 24.53155518], [92.17340088, 24.53402138], [92.17767334, 24.53070068], [92.1796875, 24.52868652], [92.17932129, 24.52667236], [92.17877197, 24.5237999], [92.17897797, 24.52387619], [92.17910767, 24.52399635], [92.17934418, 24.52409172], [92.17953491, 24.52423668], [92.17969513, 24.52420807], [92.17987823, 24.52407074], [92.17999268, 24.52395058], [92.18019867, 24.52373695], [92.18025208, 24.52355766], [92.18026733, 24.52346039], [92.18022156, 24.52322197], [92.1802063, 24.52313042], [92.18014526, 24.52293015], [92.18012238, 24.52278519], [92.18005371, 24.52256966], [92.18031311, 24.52241898], [92.18045044, 24.5225296], [92.18043518, 24.52270317], [92.18057251, 24.52299881], [92.18070221, 24.52314568], [92.18082428, 24.52329063], [92.18097687, 24.52342415], [92.18112183, 24.52352333], [92.18122101, 24.52357674], [92.18133545, 24.52363968], [92.18151093, 24.52375031], [92.18180847, 24.52387619], [92.18206787, 24.5239563], [92.18218231, 24.52393532], [92.18231201, 24.52386093], [92.18237305, 24.52372932], [92.18236542, 24.52362633], [92.18230438, 24.52355576], [92.18225098, 24.5232811], [92.18231964, 24.52314949], [92.1824646, 24.52298737], [92.18386078, 24.52293777], [92.18395996, 24.52301216], [92.18419647, 24.52312851], [92.18431854, 24.52319336], [92.18437958, 24.52327347], [92.18454742, 24.52335358], [92.18471527, 24.52338219], [92.18489075, 24.52334976], [92.18506622, 24.52323723], [92.18528748, 24.52314949], [92.18540192, 24.52306175], [92.18556976, 24.52290535], [92.18572998, 24.52270889], [92.18591309, 24.52252579], [92.18595886, 24.52234077], [92.18746948, 24.52125549], [92.18764496, 24.52129364], [92.18779755, 24.52132416], [92.18789673, 24.52122498], [92.18791962, 24.52108955], [92.18798828, 24.52098274], [92.18807983, 24.52082062], [92.18895721, 24.52019119], [92.19126129, 24.52098083], [92.19268799, 24.52148438], [92.1942749, 24.51971436], [92.19708252, 24.51672363], [92.19989014, 24.51531982], [92.19983673, 24.5112915], [92.19989014, 24.51123238], [92.2000351, 24.51105881], [92.20007324, 24.51087952], [92.20009613, 24.51075172], [92.20010376, 24.51044083], [92.20020294, 24.51023293], [92.20024872, 24.51015091], [92.20045471, 24.51002312], [92.20053864, 24.50989151], [92.20063019, 24.50964165], [92.20067596, 24.50934219], [92.20066071, 24.50895119], [92.20074463, 24.50883293], [92.20083618, 24.50873375], [92.20108032, 24.50868416], [92.20136261, 24.50863075], [92.20158386, 24.50852966], [92.20172882, 24.50835228], [92.20172119, 24.50820541], [92.20155334, 24.50800514], [92.2014389, 24.50784683], [92.20145416, 24.5077095], [92.20147705, 24.50759697], [92.20167542, 24.50746918], [92.20194244, 24.50748062], [92.20201874, 24.50748062], [92.20214844, 24.50748062], [92.20264435, 24.50754166], [92.20293427, 24.50749207], [92.20311737, 24.50743294], [92.20341492, 24.50736809], [92.20375824, 24.50730324], [92.20409393, 24.50725174], [92.20440674, 24.50719643], [92.20477295, 24.5070858], [92.20505524, 24.50704575], [92.2053833, 24.50699425], [92.20561981, 24.50693703], [92.20573425, 24.50692177], [92.20588684, 24.50683403], [92.20600891, 24.50677681], [92.20607758, 24.50656509], [92.20607758, 24.50640869], [92.20615387, 24.50629234], [92.20628357, 24.50623703], [92.20644379, 24.50620461], [92.20670319, 24.50622177], [92.20683289, 24.50623322], [92.20710754, 24.50629425], [92.20738983, 24.50624847], [92.20753479, 24.50625229], [92.20760345, 24.50619316], [92.20771027, 24.50602722], [92.20782471, 24.50591469], [92.20796204, 24.50566101], [92.20806885, 24.50547981], [92.20811462, 24.5053196], [92.20821381, 24.5051918], [92.20832825, 24.50491905], [92.20839691, 24.50469589], [92.20846558, 24.50447464], [92.2086792, 24.50432587], [92.20878601, 24.50426483], [92.20891571, 24.50424194], [92.20920563, 24.50427246], [92.20939636, 24.50436592], [92.20967102, 24.50440407], [92.20993042, 24.50447655], [92.21015167, 24.50449181], [92.21038818, 24.50451469], [92.21060944, 24.50452805], [92.21075439, 24.50450897], [92.21091461, 24.50443268], [92.2110672, 24.5043602], [92.21122742, 24.50426674], [92.21147919, 24.50416946], [92.21164703, 24.50411034], [92.21182251, 24.5040493], [92.21191406, 24.50401878], [92.21212006, 24.50393677], [92.21231842, 24.50385475], [92.21244049, 24.50381088], [92.21253204, 24.50376892], [92.21316528, 24.50477982], [92.21450043, 24.50564766], [92.21514893, 24.50669479], [92.21572876, 24.50774193], [92.21714783, 24.50720024], [92.22027588, 24.50628662], [92.22113037, 24.50292969], [92.22148132, 24.50151062], [92.230896, 24.49969482], [92.23094177, 24.50222969], [92.23099518, 24.50409126], [92.23426819, 24.5004406], [92.23468018, 24.49932861], [92.23510742, 24.49829102], [92.23547363, 24.49688721], [92.23615265, 24.49484444], [92.23632813, 24.49432373], [92.23660278, 24.49282265], [92.23950195, 24.4899292], [92.23384094, 24.48471069], [92.23029327, 24.4800396], [92.22891998, 24.47210121], [92.22895813, 24.47200203], [92.23117065, 24.46544075], [92.23109436, 24.46081352], [92.23108673, 24.46051025], [92.23114777, 24.46041489], [92.2322998, 24.45849609], [92.23506927, 24.45643234], [92.23593903, 24.45378113], [92.23606873, 24.45027161], [92.23931885, 24.44732666], [92.25632477, 24.4364109], [92.25653076, 24.4362793], [92.25747681, 24.43251991], [92.25595856, 24.41897964], [92.25863647, 24.41464615], [92.25927734, 24.41351318], [92.26268005, 24.40981102], [92.26330566, 24.40808105], [92.26264954, 24.40491676], [92.26267242, 24.40482903], [92.26428223, 24.39770508], [92.26989746, 24.39489746], [92.27050781, 24.39093018], [92.27308655, 24.38845062], [92.27270508, 24.3862915], [92.2726593, 24.38622284], [92.26994324, 24.38228989], [92.2698822, 24.38219833], [92.27187347, 24.38003349], [92.27246857, 24.37928009], [92.27225494, 24.37768936], [92.26830292, 24.3747921], [92.2677002, 24.37329102], [92.26812744, 24.36730957], [92.26415253, 24.36226082], [92.26409912, 24.36214828], [92.21289063, 24.24932861], [92.24047852, 24.25067139], [92.25958252, 24.25049019], [92.25970459, 24.25048828], [92.28478241, 24.25206757], [92.28491211, 24.25205231], [92.29187012, 24.25128174], [92.29660797, 24.25172997], [92.29668427, 24.25174141], [92.29709625, 24.24954033], [92.2953186, 24.24806976], [92.29412842, 24.24432373], [92.29492188, 24.24072266], [92.296875, 24.23809814], [92.29632568, 24.23608398], [92.29632568, 24.23388672], [92.29946899, 24.23162079], [92.29931641, 24.22949219], [92.29920959, 24.22934151], [92.29769897, 24.22731781], [92.30105591, 24.22553444], [92.30187988, 24.22509766], [92.30113983, 24.22448158], [92.30088043, 24.22204018], [92.30342102, 24.22165298], [92.30353546, 24.22163582], [92.31083679, 24.2225399], [92.31375122, 24.22288322], [92.31359863, 24.22113037], [92.30966949, 24.21612167], [92.30974579, 24.21479988], [92.31265259, 24.21109772], [92.31610107, 24.21331787], [92.3190918, 24.20910645], [92.32470703, 24.20587158], [92.32489014, 24.20471191], [92.32480621, 24.20470428], [92.3203125, 24.20430946], [92.3203125, 24.20269775], [92.32506561, 24.19908333], [92.32510376, 24.1989994], [92.32557678, 24.19753647], [92.32470703, 24.19628906], [92.32476044, 24.19476128], [92.32949066, 24.19114113], [92.32891083, 24.18911171], [92.32971191, 24.18829346], [92.32958221, 24.18818855], [92.3270874, 24.18609619], [92.33040619, 24.18483162], [92.33087158, 24.18212891], [92.33002472, 24.18013763], [92.33002472, 24.1800499], [92.32993317, 24.17465019], [92.32855988, 24.1661129], [92.32946777, 24.16452026], [92.33190918, 24.16369629], [92.33447266, 24.15087891], [92.33691406, 24.14691162], [92.33688354, 24.14677811], [92.33627319, 24.14432335], [92.33532715, 24.14367676], [92.3336792, 24.14428711], [92.33353424, 24.14426804], [92.33296967, 24.14419365], [92.33227539, 24.14402962], [92.33227539, 24.14050293], [92.32928467, 24.13989258], [92.32830048, 24.13862038], [92.32816315, 24.13516998], [92.329216, 24.13162613], [92.32878113, 24.12972069], [92.32888031, 24.1296463], [92.33111572, 24.12811279], [92.33101654, 24.12799072], [92.32832336, 24.12468338], [92.32867432, 24.11590576], [92.33174133, 24.11314583], [92.33187103, 24.11187363], [92.33188629, 24.11176109], [92.32937622, 24.11036682], [92.33229065, 24.10688782], [92.33229065, 24.10680962], [92.33227539, 24.10528564], [92.32950592, 24.10293007], [92.3296814, 24.10132408], [92.32967377, 24.10109329], [92.32834625, 24.09859848], [92.33142853, 24.09874535], [92.33068085, 24.09697342], [92.33027649, 24.09615326], [92.33014679, 24.09602356], [92.32794952, 24.09370232], [92.32878113, 24.08912086], [92.32814026, 24.08515549], [92.32811737, 24.08502007], [92.32904816, 24.08225632], [92.32814026, 24.08068085], [92.32805634, 24.08062744], [92.32282257, 24.07748032], [92.32284546, 24.07726669], [92.32287598, 24.07695961], [92.3270874, 24.07647705], [92.32727051, 24.07452393], [92.32369232, 24.07326317], [92.32292175, 24.07187462], [92.32293701, 24.07180023], [92.32330322, 24.06970215], [92.32128906, 24.06848145], [92.3192749, 24.06951904], [92.31828308, 24.06912422], [92.3182373, 24.06904411], [92.3168869, 24.06689835], [92.31880188, 24.06202126], [92.3190918, 24.0612793], [92.32176971, 24.05866051], [92.31871033, 24.05735016], [92.31999969, 24.05231667], [92.32028961, 24.05116272], [92.31904602, 24.0501194], [92.31682587, 24.05135155], [92.31526947, 24.0486908], [92.31549072, 24.04492188], [92.31754303, 24.03952026], [92.31719971, 24.03750038], [92.31506348, 24.0355587], [92.31413269, 24.03471184], [92.3192749, 24.03131104], [92.3192749, 24.03027344], [92.3167572, 24.02802467], [92.31669617, 24.02797127], [92.3190918, 24.0255127], [92.31848145, 24.02270508], [92.32171631, 24.0189209], [92.32165527, 24.0188446], [92.32092285, 24.0178833], [92.31890869, 24.01928711], [92.31750488, 24.0189209], [92.31713867, 24.01761246], [92.32470703, 24.00653076], [92.32746124, 24.00420952], [92.32727051, 24.00189209], [92.32905579, 23.98965073], [92.32589722, 23.98753548], [92.32579803, 23.98747063], [92.32736969, 23.98604584], [92.32769775, 23.98571777], [92.32778931, 23.98470116], [92.32614899, 23.98365974], [92.32552338, 23.98326111], [92.32409668, 23.97949219], [92.32285309, 23.97978592], [92.32274628, 23.97981071], [92.32208252, 23.97528076], [92.31964111, 23.97532082], [92.31768036, 23.97210121], [92.31513977, 23.97216606], [92.31530762, 23.97088623], [92.31360626, 23.97049141], [92.31269836, 23.9702301], [92.3133316, 23.96108818], [92.31333923, 23.96096992], [92.31155396, 23.96060562], [92.31144714, 23.96058273], [92.31265259, 23.95750618], [92.31123352, 23.94568443], [92.31347656, 23.94329834], [92.31268311, 23.94128418], [92.31347656, 23.93450928], [92.31807709, 23.93035126], [92.32116699, 23.92611122], [92.32128906, 23.92607498], [92.3278656, 23.92401695], [92.32971191, 23.9230957], [92.33065796, 23.92144966], [92.32939148, 23.91885948], [92.33114624, 23.91180229], [92.33052826, 23.90783119], [92.330513, 23.90771484], [92.33048248, 23.90759659], [92.32989502, 23.90551758], [92.32778168, 23.90621948], [92.32592773, 23.90447998], [92.32579041, 23.90449524], [92.32372284, 23.90466881], [92.32360077, 23.90467834], [92.32331085, 23.90441322], [92.32315063, 23.90426636], [92.32171631, 23.89147949], [92.32157898, 23.8914547], [92.32067871, 23.89129639], [92.31988525, 23.88989258], [92.3192749, 23.89068604], [92.31919861, 23.89066887], [92.31863403, 23.89053917], [92.3184967, 23.89048958], [92.31902313, 23.88915443], [92.31832886, 23.88793182], [92.31952667, 23.88610077], [92.31932831, 23.88372421], [92.31713104, 23.88408852], [92.31642151, 23.88343811], [92.31628418, 23.88330078], [92.31671143, 23.88171387], [92.31750488, 23.88153076], [92.31747437, 23.8813858], [92.31712341, 23.87926483], [92.31710815, 23.87918091], [92.3190918, 23.87768555], [92.32041168, 23.8780098], [92.32198334, 23.87415886], [92.32209015, 23.87390327], [92.32209015, 23.87379074], [92.32208252, 23.86987305], [92.32198334, 23.86982536], [92.31845856, 23.86799431], [92.31824493, 23.86713982], [92.3203125, 23.86590576], [92.32022095, 23.86581039], [92.31968689, 23.86530876], [92.31954956, 23.86524773], [92.3156662, 23.86354637], [92.31552887, 23.86352539], [92.30987549, 23.8626709], [92.30731201, 23.8638916], [92.30432129, 23.86382294], [92.30426025, 23.8638649], [92.30068207, 23.8664608], [92.29510498, 23.86547852], [92.29514313, 23.87010956], [92.29388428, 23.87127686], [92.29338074, 23.87134743], [92.29201508, 23.87140846], [92.28790283, 23.86688232], [92.28790283, 23.86309814], [92.28592682, 23.85886574], [92.28530121, 23.85747147], [92.2765274, 23.8528862], [92.27474976, 23.84905815], [92.2741394, 23.84361076], [92.27393341, 23.84169769], [92.27587891, 23.83990479], [92.2770462, 23.83670998], [92.27713013, 23.8366127], [92.28210449, 23.83087158], [92.28160858, 23.82630157], [92.28159332, 23.82616043], [92.28366852, 23.82418633], [92.28346252, 23.82349968], [92.28568268, 23.82263184], [92.28681183, 23.81676102], [92.28588867, 23.81567383], [92.28374481, 23.81623459], [92.28084564, 23.81515884], [92.27911377, 23.81671143], [92.2766571, 23.81520844], [92.26947784, 23.81777954], [92.25953674, 23.81502914], [92.25939941, 23.814991], [92.26068115, 23.80712891], [92.2623291, 23.80487061], [92.26348877, 23.79968262], [92.26374054, 23.79168892], [92.26779938, 23.76997185], [92.26802826, 23.7665081], [92.26728058, 23.76273346], [92.26711273, 23.76189995], [92.26824951, 23.75651741], [92.26824188, 23.75640488], [92.26647949, 23.7387085], [92.26848602, 23.72869682], [92.26850128, 23.72861099], [92.2691803, 23.72811127], [92.27626038, 23.72187042], [92.27670288, 23.72106171], [92.27965546, 23.71568108], [92.27905273, 23.71653175], [92.27820587, 23.71752167], [92.27739716, 23.71825027], [92.27587891, 23.71954536], [92.27468872, 23.7204113], [92.27297974, 23.72093201], [92.27111816, 23.72144699], [92.26811981, 23.722332], [92.26641846, 23.72335815], [92.26610565, 23.72435188], [92.26599121, 23.72472572], [92.26488495, 23.72476959], [92.26437378, 23.72479057], [92.26421356, 23.72459221], [92.26340485, 23.72358322], [92.2616272, 23.72344208], [92.26023865, 23.72465324], [92.25985718, 23.72498894], [92.25784302, 23.72524643], [92.25717926, 23.72506523], [92.25636292, 23.72484016], [92.25502014, 23.72499275], [92.25398254, 23.72439957], [92.25192261, 23.72431755], [92.25113678, 23.72408295], [92.25081635, 23.72423935], [92.25074005, 23.7242775], [92.24941254, 23.72430611], [92.24875641, 23.72342873], [92.24822235, 23.72270775], [92.24720001, 23.72267342], [92.24681854, 23.72266006], [92.24571228, 23.7202816], [92.24562836, 23.72016144], [92.24324799, 23.71670151], [92.24317169, 23.71656418], [92.24151611, 23.71368408], [92.24115753, 23.71068573], [92.24113464, 23.71060562], [92.24053192, 23.70848083], [92.24085236, 23.70614815], [92.24085999, 23.70606995], [92.24250793, 23.70428467], [92.24273682, 23.70377922], [92.24446106, 23.69992256], [92.24477386, 23.69890785], [92.24487305, 23.69848633], [92.24613953, 23.69592285], [92.24622345, 23.6958065], [92.24707031, 23.69470215], [92.24691772, 23.69189262], [92.24434662, 23.69009399], [92.2441864, 23.689991], [92.24245453, 23.68896484], [92.24236298, 23.68890953], [92.24217987, 23.68650055], [92.24205017, 23.68590164], [92.24191284, 23.6854763], [92.24188232, 23.68538094], [92.241745, 23.68455887], [92.24030304, 23.68309593], [92.24021912, 23.68301201], [92.23965454, 23.68252754], [92.23950195, 23.6809082], [92.23954773, 23.68028069], [92.23921204, 23.67968178], [92.23910522, 23.67948914], [92.23904419, 23.67936707], [92.23896027, 23.67920494], [92.23867798, 23.6787281], [92.2386322, 23.67866135], [92.23753357, 23.67685318], [92.23748779, 23.67678261], [92.23748779, 23.67547607], [92.23803711, 23.67247391], [92.23805237, 23.67235756], [92.23813629, 23.67027092], [92.23496246, 23.66749954], [92.2336731, 23.66540718], [92.23248291, 23.66369629], [92.2305069, 23.66146278], [92.22963715, 23.66055489], [92.22953033, 23.66043854], [92.22853088, 23.65929222], [92.22841644, 23.65924072], [92.22629547, 23.65830612], [92.2260437, 23.65769005], [92.22596741, 23.65718842], [92.22612762, 23.65617561], [92.22569275, 23.65524483], [92.22420502, 23.65484238], [92.22329712, 23.65455246], [92.22323608, 23.65429878], [92.22270203, 23.65300941], [92.22175598, 23.65324783], [92.22077942, 23.65267944], [92.22008514, 23.6523056], [92.2195282, 23.65210915], [92.21930695, 23.65203476], [92.21916962, 23.65205383], [92.21781158, 23.65224457], [92.21759796, 23.65222359], [92.21643829, 23.65211105], [92.21629333, 23.65272903], [92.2151947, 23.65279198], [92.21447754, 23.65283203], [92.21250916, 23.65288734], [92.21189117, 23.65304375], [92.21146393, 23.65315247], [92.21048737, 23.65393448], [92.21063995, 23.65527344], [92.21138, 23.65571404], [92.21087646, 23.65700531], [92.21118164, 23.65761185], [92.21100616, 23.65888405], [92.20954132, 23.65976715], [92.20847321, 23.66034889], [92.20672607, 23.66109657], [92.20672607, 23.66268539], [92.20693207, 23.66486549], [92.20677948, 23.66638947], [92.20741272, 23.66697693], [92.20748138, 23.66704178], [92.20766449, 23.66720581], [92.20722198, 23.6680336], [92.20687103, 23.66868782], [92.20622253, 23.6696167], [92.20639038, 23.67085457], [92.20648956, 23.67162704], [92.20611572, 23.67202377], [92.20581055, 23.67234039], [92.20603943, 23.6726799], [92.20623779, 23.67298126], [92.20625305, 23.67420578], [92.20638275, 23.67486191], [92.20643616, 23.67516327], [92.20664215, 23.67558479], [92.20703888, 23.67642784], [92.20721436, 23.67697525], [92.20742798, 23.6776619], [92.20834351, 23.67728806], [92.20868683, 23.67798424], [92.21021271, 23.67871094], [92.21039581, 23.67898178], [92.21072388, 23.67946815], [92.21137238, 23.67994499], [92.2124939, 23.68123627], [92.21239471, 23.6816597], [92.21270752, 23.68205833], [92.21272278, 23.68226433], [92.21279144, 23.68309402], [92.21308899, 23.68461037], [92.21378326, 23.68513489], [92.21338654, 23.68589973], [92.21305084, 23.686409], [92.2124939, 23.68652153], [92.21229553, 23.68729401], [92.21208954, 23.68746758], [92.21162415, 23.68759537], [92.21138, 23.68790245], [92.21086884, 23.6887722], [92.21084595, 23.69007111], [92.21130371, 23.69067764], [92.2104187, 23.69140625], [92.21018219, 23.69115257], [92.20976257, 23.69157982], [92.20994568, 23.69247818], [92.20969391, 23.69282913], [92.20925903, 23.69348717], [92.20918274, 23.69441414], [92.20913696, 23.69511414], [92.20911407, 23.69542313], [92.2088089, 23.69636536], [92.20864105, 23.69660378], [92.20825958, 23.69745255], [92.20769501, 23.69825554], [92.2072525, 23.69891167], [92.20733643, 23.6991024], [92.20710754, 23.70001221], [92.2068634, 23.70003891], [92.20697021, 23.70065117], [92.20646667, 23.70088387], [92.20559692, 23.70186806], [92.20491791, 23.70157051], [92.20481873, 23.70152664], [92.20439911, 23.70177269], [92.20401001, 23.70201111], [92.20375824, 23.70259476], [92.20391846, 23.70379448], [92.20375061, 23.70407486], [92.20352936, 23.70433617], [92.20341492, 23.70456696], [92.2029953, 23.70471954], [92.20281219, 23.70591927], [92.20237732, 23.70591164], [92.20202637, 23.7057972], [92.20180511, 23.70572281], [92.20102692, 23.70599556], [92.20004272, 23.70680428], [92.19827271, 23.70700836], [92.19789886, 23.70729828], [92.19711304, 23.70716667], [92.19682312, 23.70711708], [92.19676208, 23.70704651], [92.19651794, 23.70677185], [92.19610596, 23.70681572], [92.19563293, 23.70686531], [92.1953125, 23.70664787], [92.19422913, 23.70694923], [92.1934967, 23.70685005], [92.19296265, 23.70709419], [92.19278717, 23.70750427], [92.19165802, 23.70757294], [92.19097137, 23.70798683], [92.19084167, 23.70832443], [92.19002533, 23.70849991], [92.18940735, 23.7092247], [92.1886673, 23.71007347], [92.18854523, 23.71007729], [92.18829346, 23.71008301], [92.18682861, 23.71042824], [92.18661499, 23.71037102], [92.18651581, 23.71050262], [92.18608093, 23.71106911], [92.18558502, 23.71061516], [92.18539429, 23.70982552], [92.18536377, 23.709692], [92.18516541, 23.7096386], [92.18440247, 23.70943451], [92.18477631, 23.70929146], [92.18486023, 23.70925713], [92.18467712, 23.70824051], [92.18331909, 23.7080574], [92.18320465, 23.70804024], [92.1831131, 23.7079258], [92.18288422, 23.70764351], [92.18273163, 23.70767784], [92.1812439, 23.70801544], [92.18030548, 23.70808792], [92.17987061, 23.70797348], [92.17848969, 23.70813942], [92.17819977, 23.70788574], [92.177948, 23.70767021], [92.17768097, 23.70767021], [92.17762756, 23.7078743], [92.17739868, 23.70874977], [92.17697144, 23.70937538], [92.17750549, 23.70969391], [92.17750549, 23.7103653], [92.17677307, 23.71084595], [92.17681885, 23.71111107], [92.17658997, 23.71179008], [92.17634583, 23.71252823], [92.17679596, 23.71344757], [92.17656708, 23.71364403], [92.17656708, 23.71500778], [92.17649078, 23.71654129], [92.1751709, 23.71736908], [92.17373657, 23.71779442], [92.17351532, 23.71786308], [92.17342377, 23.71784973], [92.17304993, 23.71779823], [92.17288971, 23.7180748], [92.17249298, 23.71876335], [92.17205048, 23.71951485], [92.17140961, 23.72065353], [92.17089844, 23.72167397], [92.1708374, 23.72180557], [92.1707077, 23.7226963], [92.16985321, 23.72321129], [92.16959381, 23.7233696], [92.16950226, 23.72477722], [92.17005157, 23.72476768], [92.17067719, 23.72508812], [92.17140961, 23.72631836], [92.17131805, 23.72783661], [92.17093658, 23.72920799], [92.17108917, 23.7299099], [92.17108154, 23.73004532], [92.17102814, 23.73067856], [92.1709137, 23.73138046], [92.17076111, 23.73230362], [92.17076874, 23.7328968], [92.1720047, 23.73377609], [92.17224884, 23.73462868], [92.17250824, 23.73490906], [92.17269897, 23.73537445], [92.17287445, 23.73580933], [92.1727066, 23.73608971], [92.17245483, 23.73651695], [92.17259216, 23.73680878], [92.17254639, 23.7368679], [92.17227173, 23.73723221], [92.17176056, 23.73744392], [92.17191315, 23.73780441], [92.17206573, 23.73817825], [92.17179108, 23.73870659], [92.17105103, 23.73902512], [92.16971588, 23.73976326], [92.16854095, 23.73991776], [92.16748047, 23.73999214], [92.16665649, 23.74027443], [92.16616058, 23.74011612], [92.16543579, 23.73932648], [92.16487885, 23.73899651], [92.16379547, 23.73916054], [92.16346741, 23.73958397], [92.16307831, 23.73962784], [92.16235352, 23.73971176], [92.16110992, 23.73920631], [92.16106415, 23.73913383], [92.16077423, 23.73868179], [92.15984344, 23.73831177], [92.15901184, 23.7382412], [92.15834808, 23.73818588], [92.1574173, 23.73771477], [92.15700531, 23.7371521], [92.15603638, 23.73686218], [92.15576172, 23.73648453], [92.15581512, 23.73605347], [92.15590668, 23.73538971], [92.15545654, 23.73500061], [92.15480804, 23.73444366], [92.15419769, 23.73464775], [92.15380096, 23.73477936], [92.15370178, 23.73481178], [92.15291595, 23.73448563], [92.15198517, 23.73410034], [92.15096283, 23.7345047], [92.15052795, 23.73575401], [92.14948273, 23.73541451], [92.1493988, 23.73552895], [92.14928436, 23.73568726], [92.14855957, 23.73570633], [92.14780426, 23.73529053], [92.14766693, 23.73495293], [92.14713287, 23.73481941], [92.14654541, 23.73474503], [92.14553833, 23.73405647], [92.14492798, 23.73376274], [92.14419556, 23.73321724], [92.14375305, 23.73214722], [92.14349365, 23.73130417], [92.1434021, 23.73008919], [92.14296722, 23.7295723], [92.14239502, 23.72946358], [92.14253235, 23.72855568], [92.14234161, 23.72711372], [92.14221191, 23.72621155], [92.14208984, 23.7253952], [92.14179993, 23.72526932], [92.14148712, 23.72430611], [92.14100647, 23.72419739], [92.14048767, 23.72338676], [92.14057159, 23.72272682], [92.13935852, 23.72181129], [92.13930511, 23.72152138], [92.13890076, 23.72141647], [92.1388855, 23.721632], [92.13838196, 23.72100449], [92.13922882, 23.72032166], [92.13819122, 23.72000504], [92.13825226, 23.71953201], [92.1367569, 23.71904373], [92.13648224, 23.71808052], [92.13601685, 23.71799088], [92.13594818, 23.71772003], [92.1353302, 23.71752167], [92.13550568, 23.71715546], [92.13474274, 23.71661186], [92.13450623, 23.71603012], [92.13404083, 23.71591759], [92.13375854, 23.71584892], [92.13379669, 23.71555328], [92.13391113, 23.71470451], [92.13234711, 23.71374321], [92.13140106, 23.71238708], [92.13178253, 23.71170998], [92.13150787, 23.71120071], [92.13111115, 23.7109108], [92.1308136, 23.71071243], [92.1306076, 23.71074486], [92.13037872, 23.70985794], [92.12954712, 23.70926666], [92.12929535, 23.70918846], [92.12900543, 23.70909691], [92.12900543, 23.70898438], [92.12900543, 23.70798874], [92.12799835, 23.70745277], [92.12744904, 23.70768166], [92.1266098, 23.70670128], [92.1262207, 23.70691872], [92.12522888, 23.70656586], [92.12522888, 23.70561218], [92.12493134, 23.70554924], [92.12514496, 23.70520401], [92.12447357, 23.70415878], [92.12406921, 23.70303726], [92.12478638, 23.70216179], [92.12431335, 23.70171738], [92.12474823, 23.70090866], [92.12371826, 23.70040131], [92.12356567, 23.69995308], [92.12289429, 23.69960213], [92.12350464, 23.69907379], [92.12330627, 23.69814873], [92.12416077, 23.6974659], [92.12321472, 23.69683075], [92.12353516, 23.6960125], [92.1237793, 23.69575119], [92.12271881, 23.69509697], [92.12132263, 23.69352913], [92.1207962, 23.69304848], [92.12075806, 23.69279289], [92.12028503, 23.69257927], [92.1180954, 23.69058228], [92.11712646, 23.68969727], [92.11453247, 23.6870594], [92.11359406, 23.68588448], [92.11273956, 23.68481064], [92.11080933, 23.68239594], [92.11026764, 23.68171883], [92.11019897, 23.68158913], [92.10945892, 23.68032074], [92.10935974, 23.68014908], [92.10852051, 23.67871094], [92.105896, 23.67651367], [92.10467529, 23.67608643], [92.10391235, 23.67609024], [92.10308075, 23.67595291], [92.10299683, 23.67593956], [92.10107422, 23.67669678], [92.10009003, 23.67707825], [92.0998764, 23.67720985], [92.09970093, 23.67678642], [92.09929657, 23.67687607], [92.09887695, 23.67696953], [92.09798431, 23.67675209], [92.0969162, 23.67729759], [92.09636688, 23.67709732], [92.09537506, 23.67786407], [92.09384155, 23.67782593], [92.09322357, 23.67850113], [92.09235382, 23.67802238], [92.09195709, 23.67777824], [92.09171295, 23.67765427], [92.0917511, 23.67713928], [92.09130859, 23.67745399], [92.0899353, 23.67843819], [92.08878326, 23.679142], [92.08789825, 23.67944145], [92.08753204, 23.68070221], [92.08660889, 23.68048286], [92.08660126, 23.68033409], [92.086586, 23.67955589], [92.08560181, 23.68021393], [92.0854187, 23.68033791], [92.08506775, 23.68089104], [92.08459473, 23.68012047], [92.08441162, 23.68012047], [92.08306885, 23.68012619], [92.08278656, 23.67892265], [92.08312988, 23.67712402], [92.08188629, 23.6760273], [92.08166504, 23.67583466], [92.081604, 23.67473602], [92.08110046, 23.67308235], [92.08057404, 23.67135811], [92.0798111, 23.67127228], [92.0783844, 23.67111397], [92.07744598, 23.66958809], [92.07630157, 23.66804504], [92.07659912, 23.66786385], [92.07697296, 23.66735458], [92.07706451, 23.66731262], [92.07801819, 23.66687202], [92.07826233, 23.66577911], [92.0783844, 23.66522026], [92.07894135, 23.6649971], [92.07952881, 23.6647644], [92.07946014, 23.66427803], [92.07941437, 23.66397476], [92.08001709, 23.66232109], [92.07949066, 23.65997314], [92.07901764, 23.65881157], [92.07872009, 23.65787315], [92.07923126, 23.65611076], [92.07928467, 23.65591621], [92.07884979, 23.65551376], [92.07775116, 23.6544857], [92.07834625, 23.65405846], [92.07850647, 23.65394974], [92.07837677, 23.65363121], [92.07785034, 23.65231514], [92.07844543, 23.65192795], [92.07827759, 23.65120697], [92.07879639, 23.64980698], [92.07925415, 23.64869881], [92.07833099, 23.64845276], [92.07649994, 23.64888191], [92.07569122, 23.64854813], [92.07476044, 23.64751244], [92.07411194, 23.64774895], [92.0737915, 23.64758682], [92.07244873, 23.64690399], [92.07099152, 23.64741135], [92.07002258, 23.64772224], [92.06907654, 23.64827728], [92.06795502, 23.64797401], [92.06713104, 23.64699745], [92.06614685, 23.64670944], [92.06596375, 23.64612389], [92.06506348, 23.64623642], [92.06358337, 23.64583778], [92.06343079, 23.6453495], [92.06335449, 23.64511108], [92.06169891, 23.64551163], [92.0614624, 23.64620972], [92.06114197, 23.64716339], [92.05973053, 23.64748383], [92.05936432, 23.64787292], [92.05815125, 23.64811325], [92.05763245, 23.64855385], [92.05678558, 23.64849854], [92.05615234, 23.64845467], [92.05551147, 23.6487999], [92.05368042, 23.6486969], [92.05290222, 23.64883995], [92.05263519, 23.64888382], [92.05218506, 23.64896011], [92.05150604, 23.64923859], [92.05120087, 23.64905357], [92.05064392, 23.64945602], [92.04976654, 23.64936447], [92.04946136, 23.64834404], [92.04823303, 23.64787483], [92.048172, 23.64816666], [92.0477829, 23.64726448], [92.04764557, 23.6469326], [92.04602814, 23.64683342], [92.04496002, 23.64814949], [92.04426575, 23.64832497], [92.04395294, 23.64840508], [92.0430069, 23.6487484], [92.04199982, 23.6480999], [92.04029846, 23.64878654], [92.03887177, 23.6505127], [92.03926086, 23.65134811], [92.03799438, 23.65198517], [92.03742981, 23.65226364], [92.03699493, 23.65192413], [92.03691101, 23.65185738], [92.03688812, 23.65194702], [92.03675079, 23.65267563], [92.03561401, 23.65325737], [92.03528595, 23.65325928], [92.034729, 23.653265], [92.03427887, 23.65350533], [92.03408051, 23.65361214], [92.03311157, 23.65472603], [92.03314972, 23.65530014], [92.03234863, 23.65538406], [92.03210449, 23.65541077], [92.03211975, 23.65556145], [92.03215027, 23.65590858], [92.03147888, 23.65592194], [92.03124237, 23.65592766], [92.03127289, 23.65610695], [92.03145599, 23.65699959], [92.03083038, 23.65710068], [92.03043365, 23.65716362], [92.03053284, 23.65794373], [92.02999878, 23.65790749], [92.02960205, 23.65846252], [92.02851868, 23.65798569], [92.02799988, 23.65825844], [92.02790833, 23.65834045], [92.02767944, 23.6587429], [92.02722931, 23.65850449], [92.02703857, 23.6584816], [92.02706146, 23.65879822], [92.02635193, 23.65874481], [92.02609253, 23.65815353], [92.02478027, 23.65784454], [92.02470398, 23.65764618], [92.02458954, 23.65737343], [92.0243454, 23.65750122], [92.02397919, 23.65769577], [92.02368164, 23.65771484], [92.02314758, 23.65799332], [92.02304077, 23.6580162], [92.02259827, 23.65811539], [92.0221405, 23.65821838], [92.02233124, 23.65880775], [92.0223999, 23.65902519], [92.02250671, 23.65933418], [92.02265167, 23.65977097], [92.02366638, 23.66053009], [92.02420044, 23.66134262], [92.02390289, 23.66166496], [92.02418518, 23.66235924], [92.02336121, 23.66286278], [92.0231781, 23.66297722], [92.02313232, 23.66288567], [92.02285767, 23.6622982], [92.02224731, 23.66244125], [92.02213287, 23.66246796], [92.02225494, 23.66263771], [92.02226257, 23.6627903], [92.02207184, 23.66277885], [92.02111816, 23.66272926], [92.02050781, 23.66217804], [92.02016449, 23.66259003], [92.01987457, 23.66293716], [92.01842499, 23.66223335], [92.0173645, 23.66163445], [92.0165863, 23.66119766], [92.01589966, 23.65990829], [92.01469421, 23.66026306], [92.01457977, 23.6602993], [92.01397705, 23.66137886], [92.01361084, 23.66301346], [92.01321411, 23.66336823], [92.01292419, 23.66363144], [92.01207733, 23.66348648], [92.01147461, 23.66308403], [92.01046753, 23.66351318], [92.01006317, 23.66368294], [92.00953674, 23.66358757], [92.00892639, 23.66347694], [92.00842285, 23.66373062], [92.00771332, 23.66475868], [92.00691223, 23.66690636], [92.0066452, 23.66781044], [92.00719452, 23.66879272], [92.00659943, 23.66941261], [92.00632477, 23.67088509], [92.00517273, 23.67171478], [92.00328064, 23.67189598], [92.00166321, 23.67078781], [92.00123596, 23.67074776], [92.00053406, 23.670681], [91.99995422, 23.67133331], [92.00009918, 23.6733036], [92.00063324, 23.67353058], [91.99970245, 23.67436981], [91.99945068, 23.67459488], [91.99936676, 23.67518425], [91.9992981, 23.6756897], [91.99913788, 23.67816353], [91.9990387, 23.67777252], [91.99795532, 23.67920685], [91.99707794, 23.67969322], [91.99668884, 23.67990685], [91.99673462, 23.680233], [91.99610138, 23.68303108], [91.9953537, 23.68401146], [91.99545288, 23.68505669], [91.9948349, 23.6860466], [91.99458313, 23.68666458], [91.99503326, 23.68749428], [91.99383545, 23.6877346], [91.99356842, 23.68960571], [91.994133, 23.69129944], [91.99389648, 23.69293022], [91.99349976, 23.69327545], [91.99313354, 23.69482613], [91.99169922, 23.69608116], [91.99072266, 23.6979084], [91.98984528, 23.6999054], [91.9887619, 23.7011795], [91.98870087, 23.70206642], [91.98907471, 23.70257378], [91.9887619, 23.7030468], [91.98892212, 23.7048912], [91.9881897, 23.70605278], [91.98721313, 23.70838737], [91.98735809, 23.70983315], [91.98705292, 23.71133614], [91.98701477, 23.71153259], [91.98600769, 23.71310997], [91.98623657, 23.71369934], [91.98606873, 23.71510696], [91.98616028, 23.71557617], [91.98513031, 23.71650505], [91.98544312, 23.71919441], [91.98602295, 23.7200985], [91.98536682, 23.7218647], [91.98513794, 23.72304153], [91.98434448, 23.72309875], [91.98401642, 23.72409821], [91.98331451, 23.72369003], [91.98260498, 23.72327995], [91.980896, 23.72312737], [91.9804306, 23.7236557], [91.98013306, 23.72496223], [91.97963715, 23.72632027], [91.97976685, 23.7273674], [91.97917175, 23.72853851], [91.97802734, 23.73133278], [91.97802734, 23.73146439], [91.97805786, 23.73334122], [91.97684479, 23.73306847], [91.97729492, 23.73150635], [91.977211, 23.73149109], [91.97088623, 23.73028564], [91.96892548, 23.73002434], [91.96847534, 23.72963524], [91.96713257, 23.72963524], [91.96694946, 23.72982025], [91.96617889, 23.72974968], [91.96427155, 23.72913933], [91.96211243, 23.72770119], [91.95932007, 23.72340965], [91.95761108, 23.72062874], [91.95668793, 23.71913719], [91.95672607, 23.71789551], [91.95727539, 23.71588135], [91.95831299, 23.71307373], [91.95835114, 23.71007156], [91.95665741, 23.70795059], [91.95657349, 23.70714951], [91.95652771, 23.70676041], [91.95743561, 23.70386124], [91.95755005, 23.70341682], [91.95756531, 23.70328712], [91.95774078, 23.70160103], [91.95759583, 23.70074844], [91.95755005, 23.70049477], [91.95752716, 23.70036125], [91.95727539, 23.69909668], [91.95619965, 23.6975956], [91.95663452, 23.69755173], [91.95713806, 23.69750214], [91.9571991, 23.69622421], [91.95729065, 23.6943512], [91.95730591, 23.69398308], [91.95545197, 23.69397545], [91.95373535, 23.69338989], [91.95250702, 23.69181633], [91.9520874, 23.69128418], [91.95167542, 23.69097519], [91.95160675, 23.69091988], [91.94953918, 23.68925095], [91.94892883, 23.68887711], [91.94881439, 23.68880653], [91.94846344, 23.68850136], [91.94836426, 23.68843079], [91.94534302, 23.68624306], [91.94521332, 23.68612671], [91.94423676, 23.6853466], [91.94415283, 23.68523026], [91.94256592, 23.68329048], [91.94230652, 23.68180847], [91.94242096, 23.6814003], [91.94371033, 23.67669106], [91.94374084, 23.67660332], [91.94684601, 23.66825485], [91.94687653, 23.66816902], [91.95007324, 23.65808105], [91.95185089, 23.64694023], [91.95147705, 23.63928223], [91.95134735, 23.63695145], [91.95095825, 23.63286972], [91.95193481, 23.62936783], [91.95211029, 23.62873077], [91.95214844, 23.62866783], [91.95489502, 23.62371826], [91.95672607, 23.61791992], [91.95658112, 23.61429024], [91.95648193, 23.60809326], [91.95471191, 23.59588623], [91.95375824, 23.5932312], [91.95404816, 23.59184265], [91.95542145, 23.58995438], [91.95407867, 23.58693123], [91.95425415, 23.58652878], [91.95475769, 23.58675575], [91.95567322, 23.58717155], [91.95681763, 23.58734512], [91.95691681, 23.58729935], [91.95901489, 23.58634567], [91.95906067, 23.5862751], [91.96234131, 23.58133698], [91.96388245, 23.57888985], [91.96392059, 23.5788269], [91.96368408, 23.57507324], [91.96221161, 23.57174301], [91.96212769, 23.57160187], [91.96146393, 23.57050896], [91.96143341, 23.57042503], [91.96115112, 23.56950951], [91.96113586, 23.56943893], [91.96051025, 23.56707764], [91.96054077, 23.56655121], [91.96087646, 23.56591797], [91.96127319, 23.56510925], [91.96135712, 23.56503105], [91.96215057, 23.56401062], [91.96252441, 23.56373787], [91.96252441, 23.56263924], [91.96252441, 23.5625], [91.96255493, 23.56228447], [91.96279907, 23.56009293], [91.96287537, 23.55908012], [91.96290588, 23.55899811], [91.96368408, 23.55670166], [91.96389008, 23.55606651], [91.96398163, 23.55599213], [91.96429443, 23.5557251], [91.96569824, 23.55407715], [91.96508789, 23.55133057], [91.96490479, 23.55047607], [91.96448517, 23.54776382], [91.9644165, 23.54760933], [91.96335602, 23.54554939], [91.9629364, 23.54421806], [91.96276855, 23.5436821], [91.9627533, 23.54354858], [91.96252441, 23.54187012], [91.9620285, 23.54115295], [91.96251678, 23.54025841], [91.96278381, 23.53883171], [91.96308899, 23.5372448], [91.96450806, 23.53537369], [91.96437836, 23.5351181], [91.96347809, 23.53332138], [91.96163177, 23.53301048], [91.95885468, 23.53237534], [91.95793152, 23.53047562], [91.95788574, 23.53037643], [91.95678711, 23.52917671], [91.95623779, 23.52583504], [91.95782471, 23.52232552], [91.95962524, 23.51991463], [91.96006775, 23.51855087], [91.96034241, 23.51857567], [91.96443176, 23.51893425], [91.9631958, 23.51746368], [91.96421814, 23.51588058], [91.96522522, 23.51552391], [91.96616364, 23.51519394], [91.96607208, 23.51504898], [91.96813202, 23.51379776], [91.9686203, 23.51248741], [91.9686203, 23.5124073], [91.96871185, 23.5109272], [91.96871185, 23.51077271], [91.96858978, 23.50970078], [91.96898651, 23.50896072], [91.97027588, 23.50830078], [91.97187805, 23.50699043], [91.9730835, 23.50592041], [91.97423553, 23.50436592], [91.9743042, 23.50427246], [91.97406006, 23.50362015], [91.97394562, 23.50309753], [91.9724884, 23.50177956], [91.97210693, 23.50067139], [91.97169495, 23.49937057], [91.97223663, 23.49789047], [91.97271729, 23.49688721], [91.97515869, 23.49616814], [91.97607422, 23.49596024], [91.97603607, 23.49511909], [91.97598267, 23.49500465], [91.9755249, 23.49407959], [91.97363281, 23.49275017], [91.97323608, 23.49253845], [91.97305298, 23.49244118], [91.9727478, 23.49061012], [91.97374725, 23.48859978], [91.97384644, 23.48835182], [91.97387695, 23.48828125], [91.97451019, 23.48670387], [91.97453308, 23.4865551], [91.97458649, 23.48557091], [91.97518921, 23.48241043], [91.97332764, 23.480896], [91.97192383, 23.4810791], [91.97052002, 23.4814949], [91.97039795, 23.48153305], [91.96968079, 23.4815712], [91.96944427, 23.4815979], [91.96970367, 23.47862816], [91.96910858, 23.47650146], [91.96712494, 23.4772377], [91.96726227, 23.47809982], [91.96624756, 23.47836113], [91.96542358, 23.47857285], [91.96229553, 23.47831726], [91.96142578, 23.47824669], [91.95819092, 23.47966194], [91.95852661, 23.47763634], [91.95869446, 23.47661209], [91.95867157, 23.4730587], [91.95700836, 23.47413826], [91.95640564, 23.47588348], [91.95511627, 23.47553635], [91.95449066, 23.47491264], [91.95428467, 23.47467041], [91.95350647, 23.47392845], [91.95288086, 23.47332764], [91.95223236, 23.47248077], [91.95185852, 23.47052956], [91.94946289, 23.47035027], [91.94848633, 23.47027588], [91.94821167, 23.47026443], [91.94764709, 23.46970558], [91.94776917, 23.46678352], [91.94557953, 23.46596336], [91.94463348, 23.46777916], [91.94242096, 23.46665764], [91.94246674, 23.46648216], [91.94245148, 23.4663868], [91.94205475, 23.46411514], [91.94203186, 23.46401215], [91.94152832, 23.46148682], [91.94152832, 23.46087646], [91.94287109, 23.45770264], [91.94390869, 23.45587158], [91.94451904, 23.45471191], [91.94470215, 23.45391846], [91.94592285, 23.45050049], [91.94625092, 23.44951057], [91.94628143, 23.4494381], [91.94695282, 23.44768143], [91.94708252, 23.44653893], [91.94708252, 23.44628906], [91.94732666, 23.4440918], [91.94686127, 23.44350433], [91.94680023, 23.44340134], [91.94650269, 23.44286728], [91.94631958, 23.4417305], [91.94488525, 23.43988037], [91.94287109, 23.43847656], [91.94269562, 23.43832779], [91.94313049, 23.43710899], [91.94273376, 23.43524742], [91.94210815, 23.43494034], [91.94113922, 23.43522835], [91.94052124, 23.4354763], [91.94021606, 23.43494034], [91.93854523, 23.43423462], [91.9373703, 23.43252373], [91.93632507, 23.43288231], [91.93518829, 23.43323708], [91.93419647, 23.43368912], [91.93480682, 23.4352951], [91.9340744, 23.43563461], [91.93308258, 23.43602371], [91.93289185, 23.43530273], [91.93125153, 23.43455315], [91.93041992, 23.43535805], [91.92989349, 23.43465042], [91.92893982, 23.43455505], [91.92835236, 23.43413162], [91.92672729, 23.43391037], [91.92626953, 23.43447876], [91.92501831, 23.43432045], [91.92399597, 23.43375587], [91.92346954, 23.43488312], [91.9229126, 23.43542671], [91.92216492, 23.43644524], [91.92169189, 23.43694115], [91.92176056, 23.43808937], [91.92108154, 23.43827057], [91.92025757, 23.4388504], [91.91931915, 23.43841553], [91.91894531, 23.43957901], [91.91841125, 23.43973923], [91.91746521, 23.43851852], [91.9169693, 23.43899536], [91.91642761, 23.43874359], [91.91614532, 23.43830872], [91.91550446, 23.43810463], [91.91497803, 23.43759727], [91.91435242, 23.43711472], [91.91352081, 23.43751526], [91.91337585, 23.43688011], [91.91199493, 23.43684578], [91.91056824, 23.4370594], [91.91009521, 23.4368248], [91.90932465, 23.43670654], [91.90869141, 23.43702507], [91.90802765, 23.4371357], [91.90730286, 23.43746376], [91.90646362, 23.43703079], [91.90570831, 23.43790627], [91.90488434, 23.43767738], [91.90419769, 23.43860626], [91.90400696, 23.43863297], [91.9029541, 23.43877792], [91.90277863, 23.43948174], [91.90244293, 23.43962097], [91.90048218, 23.44042587], [91.89964294, 23.44072151], [91.899086, 23.44040871], [91.8993454, 23.43953514], [91.89975739, 23.43941307], [91.8997879, 23.43909264], [91.89969635, 23.43875885], [91.89958191, 23.43837357], [91.89971924, 23.43829346], [91.90106201, 23.43711281], [91.90046692, 23.43593788], [91.89836884, 23.43515778], [91.89782715, 23.4349556], [91.8976593, 23.43504906], [91.8973999, 23.4348278], [91.89694214, 23.43400764], [91.89646912, 23.43375969], [91.89567566, 23.43353081], [91.89601135, 23.43259048], [91.89519501, 23.43152428], [91.8940506, 23.4315815], [91.89363098, 23.43247986], [91.89334869, 23.43252373], [91.89278412, 23.43261147], [91.89230347, 23.43328857], [91.89186859, 23.43347359], [91.89138031, 23.4336834], [91.89057159, 23.43378258], [91.88993835, 23.43351936], [91.88897705, 23.43343925], [91.88832092, 23.43316269], [91.88735199, 23.43311119], [91.88773346, 23.43206596], [91.88777161, 23.43153381], [91.88814545, 23.43083763], [91.88851929, 23.43026161], [91.88864899, 23.42945671], [91.88807678, 23.42912674], [91.88781738, 23.42849541], [91.88707733, 23.42783356], [91.88687134, 23.42698288], [91.8855896, 23.42634964], [91.88508606, 23.42596054], [91.8841629, 23.4255867], [91.88339233, 23.42564011], [91.88304138, 23.42539597], [91.88231659, 23.42532921], [91.88186646, 23.42399597], [91.88046265, 23.42397308], [91.87996674, 23.42367744], [91.87975311, 23.42309189], [91.87866974, 23.42302132], [91.87825775, 23.42230988], [91.87638092, 23.4224205], [91.87584686, 23.42056084], [91.87477875, 23.4200325], [91.87401581, 23.41926575], [91.8735199, 23.41662216], [91.87316132, 23.41538811], [91.87309265, 23.41514587], [91.87316132, 23.4149971], [91.87355042, 23.4141922], [91.87296295, 23.41433525], [91.87231445, 23.41411018], [91.87185669, 23.4141407], [91.87153625, 23.41415977], [91.87145233, 23.414114], [91.87104797, 23.41369438], [91.87052155, 23.41303444], [91.87000275, 23.41313362], [91.86971283, 23.41318893], [91.86933136, 23.41326332], [91.86871338, 23.41265678], [91.86846924, 23.41241837], [91.86830902, 23.41244125], [91.86688232, 23.41168213], [91.86639404, 23.41119576], [91.86629486, 23.41109848], [91.86557007, 23.40982628], [91.8655014, 23.4097538], [91.86495209, 23.40984154], [91.86399841, 23.40916443], [91.86392212, 23.40866852], [91.86307526, 23.40784264], [91.86190033, 23.40760422], [91.86032867, 23.40626717], [91.86038971, 23.40598679], [91.8605423, 23.4053154], [91.85852814, 23.40513611], [91.85843658, 23.40521622], [91.85758972, 23.40593147], [91.85679626, 23.40528679], [91.85660553, 23.40550423], [91.85617828, 23.40599823], [91.85540771, 23.40594101], [91.85535431, 23.4066658], [91.85474396, 23.40681076], [91.85385895, 23.40649796], [91.85284424, 23.4063797], [91.8528595, 23.40557671], [91.85194397, 23.40506935], [91.85165405, 23.40448952], [91.85085297, 23.40421295], [91.85041046, 23.40489197], [91.84841919, 23.40529251], [91.84503937, 23.4047699], [91.84533691, 23.40287399], [91.84529114, 23.4007225], [91.8430481, 23.40031242], [91.84307098, 23.39932823], [91.84192657, 23.39976501], [91.84104156, 23.39985466], [91.8407135, 23.39897346], [91.84091949, 23.39791107], [91.84150696, 23.39692307], [91.84150696, 23.39427376], [91.84144592, 23.39154625], [91.84185791, 23.39097404], [91.84205627, 23.38939476], [91.84185791, 23.38847923], [91.83853149, 23.38715553], [91.83685303, 23.38742638], [91.8369751, 23.38699722], [91.8361969, 23.38660622], [91.83635712, 23.38554764], [91.8365097, 23.38329124], [91.8369751, 23.38127708], [91.83779907, 23.37875557], [91.83750916, 23.37717056], [91.83707428, 23.37535477], [91.83758545, 23.37508965], [91.83777618, 23.37410355], [91.8379364, 23.37314415], [91.83789825, 23.37287331], [91.83761597, 23.37090683], [91.83589172, 23.37021446], [91.83548737, 23.37013245], [91.83283234, 23.36959457], [91.83242798, 23.3699131], [91.83187866, 23.36845779], [91.83219147, 23.36722374], [91.83177948, 23.36591148], [91.83156586, 23.36523628], [91.83047485, 23.36421776], [91.83003235, 23.36467171], [91.82847595, 23.36626434], [91.82823944, 23.36527252], [91.82714844, 23.36506462], [91.82627106, 23.36355209], [91.82556152, 23.36329269], [91.8258667, 23.36279297], [91.82538605, 23.35972977], [91.82532501, 23.35931969], [91.82556915, 23.35864258], [91.82556152, 23.35802841], [91.82523346, 23.35726929], [91.82511902, 23.35634232], [91.8248291, 23.35612297], [91.82518005, 23.35599709], [91.82521057, 23.35550499], [91.82548523, 23.35512352], [91.82515717, 23.35489655], [91.8249588, 23.35420799], [91.82530212, 23.35352516], [91.82505035, 23.35245323], [91.82471466, 23.35249138], [91.82423401, 23.35205269], [91.82299042, 23.35193253], [91.82246399, 23.35156441], [91.82208252, 23.35151672], [91.82161713, 23.3514576], [91.82143402, 23.35143471], [91.82115936, 23.35176659], [91.82021332, 23.35134697], [91.81964874, 23.35110664], [91.81920624, 23.35122871], [91.8189621, 23.3507843], [91.81851196, 23.35051155], [91.81855011, 23.34954262], [91.818367, 23.3490963], [91.81851959, 23.34883881], [91.81771088, 23.34874916], [91.81742096, 23.34807777], [91.81744385, 23.34771538], [91.81731415, 23.34755135], [91.81789398, 23.3474617], [91.817276, 23.34715271], [91.81772614, 23.34711647], [91.81761169, 23.34698105], [91.81752014, 23.34668922], [91.81803131, 23.346735], [91.81796265, 23.34649849], [91.81717682, 23.34608078], [91.81716156, 23.345644], [91.81684113, 23.34567261], [91.81629181, 23.34515381], [91.8164444, 23.34489059], [91.81585693, 23.34472847], [91.81520844, 23.34436417], [91.81538391, 23.34410095], [91.81491852, 23.34393883], [91.81497192, 23.34423828], [91.81462097, 23.34415627], [91.81448364, 23.3443203], [91.8144455, 23.34439278], [91.81349945, 23.34366226], [91.81343079, 23.34361458], [91.81053925, 23.34155083], [91.80882263, 23.33940697], [91.80825806, 23.33870697], [91.80751801, 23.33725739], [91.80774689, 23.3373642], [91.80764771, 23.33711052], [91.80818939, 23.33721161], [91.80712891, 23.33648872], [91.80718231, 23.33585739], [91.80704498, 23.33592224], [91.80714417, 23.33569717], [91.80686188, 23.33538246], [91.80651855, 23.33530045], [91.80651855, 23.33485031], [91.80628204, 23.33498192], [91.8059845, 23.33436394], [91.80644226, 23.33407784], [91.80582428, 23.33343315], [91.80532837, 23.33298302], [91.80527496, 23.3328743], [91.80516052, 23.33263969], [91.80263519, 23.32894516], [91.80253601, 23.32876968], [91.79888916, 23.32232666], [91.79608154, 23.31750488], [91.79533386, 23.31635475], [91.79528809, 23.31628418], [91.79174042, 23.31072617], [91.79208374, 23.31235504], [91.7902832, 23.30908203], [91.78990936, 23.30810738], [91.78987885, 23.30801964], [91.78937531, 23.30649757], [91.7893219, 23.30637169], [91.78845978, 23.30434608], [91.78839111, 23.30419159], [91.78808594, 23.30352783], [91.78676605, 23.30063057], [91.78631592, 23.29968262], [91.78533936, 23.29862976], [91.78520966, 23.29855919], [91.78309631, 23.29412079], [91.78305817, 23.29401588], [91.7822876, 23.29187012], [91.7817688, 23.2907505], [91.78112793, 23.28851318], [91.78030396, 23.28786278], [91.78025055, 23.28776741], [91.77988434, 23.28712273], [91.77983856, 23.28704071], [91.77947998, 23.28668213], [91.77830505, 23.28529167], [91.7782135, 23.28511238], [91.7769165, 23.2824707], [91.77614594, 23.28007126], [91.77575684, 23.27947998], [91.77484894, 23.27806091], [91.77490234, 23.27612305], [91.77481842, 23.27288818], [91.77288818, 23.27008057], [91.77294159, 23.26990509], [91.77313995, 23.26991081], [91.77329254, 23.26988602], [91.77339172, 23.269907], [91.77349854, 23.26996613], [91.77359772, 23.27015877], [91.77378845, 23.2701664], [91.77387238, 23.27009773], [91.77394104, 23.27005005], [91.77398682, 23.26994705], [91.77392578, 23.26984024], [91.77390289, 23.2697525], [91.77391815, 23.26965714], [91.77399445, 23.26952934], [91.774086, 23.26943016], [91.77416992, 23.26937485], [91.77426147, 23.26936531], [91.7744751, 23.26938438], [91.77458954, 23.26940346], [91.77472687, 23.26936531], [91.77500916, 23.26943207], [91.77510834, 23.2696476], [91.77513123, 23.2697258], [91.77534485, 23.26990318], [91.77552795, 23.27008438], [91.7756424, 23.2701664], [91.77584839, 23.27018356], [91.77594757, 23.27012253], [91.77602386, 23.2700386], [91.77610016, 23.26993942], [91.77622986, 23.26986504], [91.77641296, 23.2697773], [91.77659607, 23.26973343], [91.77666473, 23.26969337], [91.77667999, 23.26958084], [91.77674866, 23.26950836], [91.7769165, 23.26943779], [91.7769928, 23.26936531], [91.77695465, 23.26923943], [91.77696991, 23.26916885], [91.77694702, 23.26909065], [91.77687073, 23.26901627], [91.77674866, 23.26887703], [91.77661896, 23.26865768], [91.77655792, 23.26855469], [91.77655792, 23.26848221], [91.77651978, 23.26841736], [91.77645874, 23.26827049], [91.77639771, 23.26819038], [91.77629852, 23.26807594], [91.77624512, 23.26796722], [91.77622223, 23.26788521], [91.77619171, 23.26778221], [91.77613831, 23.26763344], [91.77618408, 23.26751709], [91.77620697, 23.2674408], [91.77619934, 23.26734352], [91.7760849, 23.26720428], [91.77602386, 23.26707077], [91.77600098, 23.26696777], [91.77601624, 23.26682281], [91.77606964, 23.266716], [91.77613831, 23.26666832], [91.77629089, 23.26663208], [91.77645874, 23.26660919], [91.77654266, 23.2665863], [91.77659607, 23.26646614], [91.77659607, 23.26634979], [91.77648926, 23.2660141], [91.77639771, 23.26580238], [91.77632141, 23.26569557], [91.77627563, 23.26560974], [91.77623749, 23.26550102], [91.77616119, 23.26544189], [91.77610016, 23.26537895], [91.77604675, 23.2652607], [91.77612305, 23.26498795], [91.77610779, 23.26488876], [91.77610016, 23.26478195], [91.77616882, 23.26451874], [91.77620697, 23.26444054], [91.77630615, 23.26424599], [91.77642059, 23.26406097], [91.77655029, 23.26388931], [91.77661896, 23.26381111], [91.77663422, 23.2637043], [91.77669525, 23.26357651], [91.77667999, 23.2634964], [91.77659607, 23.26342201], [91.77643585, 23.26345062], [91.77632904, 23.26343346], [91.77615356, 23.26329803], [91.77605438, 23.26322746], [91.77586365, 23.26311684], [91.77574158, 23.26300812], [91.77572632, 23.26293755], [91.77575684, 23.26282692], [91.77588654, 23.26275826], [91.77600098, 23.26271629], [91.77610779, 23.26262283], [91.77614594, 23.26249886], [91.77614594, 23.26237106], [91.77606201, 23.26226807], [91.77587128, 23.26219559], [91.77561188, 23.26216698], [91.77544403, 23.26218796], [91.77529907, 23.26212883], [91.77535248, 23.26196671], [91.77535248, 23.26185989], [91.77536011, 23.26167297], [91.775383, 23.26158905], [91.7754364, 23.26151466], [91.77553558, 23.26140976], [91.7756958, 23.26127434], [91.77577209, 23.26122856], [91.77594757, 23.26115608], [91.77614594, 23.26104736], [91.77628326, 23.26095963], [91.77639771, 23.2609005], [91.7765274, 23.26088905], [91.77670288, 23.26088524], [91.77683258, 23.26088524], [91.77696228, 23.26086044], [91.77703094, 23.26078415], [91.77706146, 23.26069832], [91.77711487, 23.26057434], [91.77722931, 23.26045609], [91.7773819, 23.26019287], [91.77745819, 23.26006126], [91.77741241, 23.25984764], [91.7773056, 23.25969315], [91.77722931, 23.25958443], [91.77700806, 23.25959587], [91.7769165, 23.25965118], [91.77675629, 23.25975227], [91.7766571, 23.25978279], [91.77658081, 23.25973892], [91.77658081, 23.25965881], [91.77653503, 23.25960159], [91.77651215, 23.25952148], [91.77646637, 23.25941467], [91.77643585, 23.25934029], [91.77639771, 23.25913239], [91.77631378, 23.2589798], [91.77627563, 23.2588768], [91.77623749, 23.25871658], [91.77624512, 23.25855446], [91.77624512, 23.25843811], [91.77628326, 23.25835228], [91.77637482, 23.25825691], [91.776474, 23.25808525], [91.77661896, 23.25792122], [91.7768631, 23.25762558], [91.77689362, 23.25752258], [91.77675629, 23.2574501], [91.77663422, 23.25738525], [91.77656555, 23.25734138], [91.77645111, 23.25728607], [91.77629852, 23.25730515], [91.77609253, 23.25738144], [91.77597809, 23.25754547], [91.77587128, 23.25761414], [91.77577209, 23.25766754], [91.7756424, 23.25753975], [91.77555084, 23.25743675], [91.77541351, 23.25735855], [91.77532196, 23.25734138], [91.77516937, 23.25728607], [91.77502441, 23.25719643], [91.7749176, 23.2570591], [91.77487946, 23.25695038], [91.7749176, 23.25680542], [91.77503204, 23.25659943], [91.77510071, 23.25642395], [91.77513885, 23.25625038], [91.77515411, 23.25607681], [91.77510071, 23.25592422], [91.77510071, 23.25583267], [91.7751236, 23.25574303], [91.77522278, 23.25567055], [91.77539062, 23.25568008], [91.77561951, 23.25563812], [91.77578735, 23.25561523], [91.77597046, 23.25554276], [91.77611542, 23.25547028], [91.77633667, 23.25535202], [91.77642822, 23.25532341], [91.77653503, 23.25532532], [91.77661133, 23.25529861], [91.77679443, 23.25521469], [91.77690887, 23.25518799], [91.7769928, 23.25518227], [91.77710724, 23.25528526], [91.77720642, 23.25543976], [91.77722168, 23.25563622], [91.77723694, 23.25574684], [91.77734375, 23.25592041], [91.7774353, 23.25606918], [91.77751923, 23.25623131], [91.77762604, 23.25632668], [91.77771759, 23.25642586], [91.77797699, 23.25657463], [91.7780838, 23.25659561], [91.77815247, 23.25653267], [91.77819061, 23.25644684], [91.77819061, 23.25628662], [91.77820587, 23.25616646], [91.77824402, 23.25607872], [91.77824402, 23.25597382], [91.77819824, 23.25581169], [91.77816772, 23.25568771], [91.77812195, 23.25559616], [91.77809143, 23.25549698], [91.77809143, 23.2553463], [91.77812958, 23.25518799], [91.77819824, 23.25505829], [91.77822876, 23.25492477], [91.77828979, 23.25481606], [91.77842712, 23.25470924], [91.77858734, 23.25455856], [91.77867889, 23.25452805], [91.77879333, 23.25447655], [91.77886963, 23.25449181], [91.77896881, 23.25441742], [91.77913666, 23.25435829], [91.77926636, 23.25428009], [91.77934265, 23.25423622], [91.77951813, 23.25406647], [91.7796936, 23.25389671], [91.77970123, 23.2537899], [91.77941895, 23.25350761], [91.77933502, 23.2534523], [91.77919769, 23.25332642], [91.77909088, 23.25321388], [91.77896881, 23.25304985], [91.77886963, 23.25289726], [91.77864075, 23.25262642], [91.77856445, 23.25247192], [91.77850342, 23.25240326], [91.77845764, 23.25231171], [91.77841187, 23.25216484], [91.77839661, 23.25205421], [91.77840424, 23.2519207], [91.77845001, 23.25180244], [91.77851868, 23.25174522], [91.77864075, 23.25177765], [91.77872467, 23.25180817], [91.77883911, 23.25184822], [91.77901459, 23.25184631], [91.77914429, 23.25184631], [91.77926636, 23.25180054], [91.77935028, 23.25175476], [91.77936554, 23.25168228], [91.77932739, 23.25155449], [91.77931213, 23.25143623], [91.77932739, 23.2513485], [91.77936554, 23.2512188], [91.77938843, 23.25105095], [91.77939606, 23.25082016], [91.77938843, 23.25069427], [91.77944946, 23.25051308], [91.77944183, 23.2504406], [91.77950287, 23.25029182], [91.77944946, 23.25018692], [91.77940369, 23.2501297], [91.7793045, 23.25006866], [91.77919006, 23.24998093], [91.77905273, 23.24987602], [91.77901459, 23.24981308], [91.77901459, 23.24971581], [91.77910614, 23.24955368], [91.7792511, 23.24945068], [91.77933502, 23.24935722], [91.77935791, 23.24928856], [91.77931976, 23.24881172], [91.77934265, 23.2486496], [91.77936554, 23.24848557], [91.77936554, 23.24834251], [91.77938843, 23.24819756], [91.7793808, 23.24799538], [91.77944946, 23.24794769], [91.7795639, 23.24787521], [91.77963257, 23.24777603], [91.77968597, 23.24764252], [91.77977753, 23.247509], [91.77985382, 23.24747086], [91.77993774, 23.24744225], [91.78007507, 23.2474308], [91.78022003, 23.24734879], [91.78030396, 23.24720573], [91.7803421, 23.24712181], [91.78031158, 23.24698639], [91.78029633, 23.246912], [91.7802124, 23.24682426], [91.78005219, 23.24684334], [91.7800293, 23.24674034], [91.77991486, 23.24671555], [91.77980804, 23.24668884], [91.77973175, 23.24678802], [91.77959442, 23.24678612], [91.7795105, 23.24688148], [91.77926636, 23.24692535], [91.7791748, 23.24691391], [91.77909851, 23.24692917], [91.77898407, 23.24692917], [91.77889252, 23.24689674], [91.77875519, 23.24682426], [91.77867889, 23.24674988], [91.7786026, 23.24664307], [91.77853394, 23.24654198], [91.77842712, 23.24640465], [91.77836609, 23.24626923], [91.77826691, 23.24596596], [91.77824402, 23.24570465], [91.77817535, 23.24560547], [91.77809143, 23.24551582], [91.77797699, 23.24546242], [91.77776337, 23.2454071], [91.77770996, 23.24535561], [91.77768707, 23.24522591], [91.77770233, 23.24506378], [91.77783203, 23.24503326], [91.77783203, 23.24489975], [91.77785492, 23.24481583], [91.77787018, 23.24470711], [91.77785492, 23.24460793], [91.77780914, 23.24453545], [91.77774811, 23.24447441], [91.77765656, 23.24441147], [91.77735138, 23.24438667], [91.77721405, 23.24436188], [91.77709198, 23.24433517], [91.77700806, 23.2443428], [91.77687073, 23.24434471], [91.77680206, 23.24431419], [91.7765274, 23.2442627], [91.7763443, 23.24419212], [91.77728271, 23.24291992], [91.77830505, 23.24123764], [91.77841187, 23.24121094], [91.77851105, 23.24118614], [91.77864075, 23.24114037], [91.77877045, 23.2411232], [91.77888489, 23.24105072], [91.77898407, 23.24093819], [91.77902985, 23.24084282], [91.77905273, 23.24070168], [91.77908325, 23.24049377], [91.7791748, 23.24043083], [91.77935028, 23.24030876], [91.77957916, 23.24032211], [91.77967834, 23.24028587], [91.77970886, 23.24015808], [91.77967072, 23.24008179], [91.77990723, 23.23991394], [91.77993774, 23.24008751], [91.77997589, 23.24017525], [91.78007507, 23.24032021], [91.78012848, 23.24045181], [91.78025818, 23.24060631], [91.78040314, 23.24077415], [91.78047943, 23.24090576], [91.78062439, 23.24099159], [91.7807312, 23.24105072], [91.78083801, 23.24107742], [91.78096008, 23.24116516], [91.78100586, 23.24123192], [91.78108978, 23.24131584], [91.78115082, 23.24148369], [91.78121185, 23.2415638], [91.78122711, 23.24165916], [91.78123474, 23.24173737], [91.78121948, 23.24183655], [91.78113556, 23.24190903], [91.78108215, 23.24200058], [91.78096771, 23.24199295], [91.78089905, 23.24204063], [91.78073883, 23.24197197], [91.78051758, 23.24205208], [91.78038788, 23.24215508], [91.78031921, 23.24219131], [91.78020477, 23.24222755], [91.78012848, 23.24233627], [91.78014374, 23.24247932], [91.78011322, 23.24264526], [91.78011322, 23.2427845], [91.78012848, 23.24286652], [91.78028107, 23.24306679], [91.78032684, 23.24318886], [91.7803421, 23.24329948], [91.78048706, 23.24344444], [91.78063965, 23.24353409], [91.7807312, 23.24349785], [91.78089905, 23.24357986], [91.78097534, 23.24360847], [91.78115082, 23.24362564], [91.78131104, 23.24360847], [91.78139496, 23.24352837], [91.78148651, 23.2434082], [91.78156281, 23.24333382], [91.7816925, 23.24332047], [91.7817688, 23.24337959], [91.78186035, 23.24354362], [91.78183746, 23.24367142], [91.7818985, 23.24378014], [91.78197479, 23.24377441], [91.78207397, 23.24377823], [91.78213501, 23.24370766], [91.78227234, 23.2435627], [91.78227234, 23.24343491], [91.78227234, 23.24333572], [91.78230286, 23.24326134], [91.78239441, 23.24324417], [91.78250885, 23.24331284], [91.78263855, 23.24340439], [91.78277588, 23.24344826], [91.78295135, 23.24348259], [91.78314972, 23.24348068], [91.78329468, 23.24349976], [91.7833786, 23.24350739], [91.78348541, 23.24342728], [91.78353119, 23.24336243], [91.78340912, 23.24318886], [91.78331757, 23.24306488], [91.78320313, 23.24295235], [91.78305054, 23.24280739], [91.78302002, 23.24273872], [91.78307343, 23.24262619], [91.78321838, 23.24245644], [91.7833252, 23.2423172], [91.78343201, 23.24220848], [91.78350067, 23.2421627], [91.78363037, 23.24213028], [91.78372955, 23.24206543], [91.78382111, 23.24197769], [91.78383636, 23.24189568], [91.78383636, 23.24180031], [91.78383636, 23.24158478], [91.78386688, 23.24150276], [91.78394318, 23.24148941], [91.78421021, 23.24148178], [91.78433228, 23.24140358], [91.78445435, 23.24133301], [91.78448486, 23.24118233], [91.78442383, 23.24105453], [91.7842865, 23.24096489], [91.78416443, 23.24084091], [91.7841568, 23.24070168], [91.78411865, 23.24051094], [91.78411865, 23.24041748], [91.7841568, 23.24029732], [91.78424835, 23.24019623], [91.78436279, 23.24013329], [91.78451538, 23.24004936], [91.78468323, 23.23989677], [91.78482819, 23.23976517], [91.7850647, 23.23963737], [91.78517914, 23.23948288], [91.78526306, 23.23935699], [91.78531647, 23.23925781], [91.78533936, 23.23917389], [91.78533936, 23.23897552], [91.78527832, 23.23892403], [91.78521729, 23.2388649], [91.78514099, 23.23882103], [91.7850647, 23.23881531], [91.78497314, 23.2388382], [91.78490448, 23.23889732], [91.78487396, 23.23896599], [91.78474426, 23.23910141], [91.78466797, 23.23915672], [91.78451538, 23.2392292], [91.78440094, 23.23921967], [91.78426361, 23.23915291], [91.78421021, 23.23906898], [91.78417969, 23.23899269], [91.78417206, 23.23877907], [91.78417969, 23.23870277], [91.78423309, 23.2384758], [91.78425598, 23.23832512], [91.78432465, 23.23819351], [91.78438568, 23.23804855], [91.78439331, 23.23790359], [91.7844162, 23.23773956], [91.78443909, 23.23753357], [91.78448486, 23.2373333], [91.78456116, 23.23719406], [91.7845459, 23.23698616], [91.78451538, 23.23690414], [91.7844162, 23.23683357], [91.78426361, 23.23673439], [91.78414154, 23.23662567], [91.78422546, 23.23653984], [91.78432465, 23.23644257], [91.78729248, 23.23352051], [91.7888031, 23.23214149], [91.79206848, 23.22916794], [91.79203796, 23.22909355], [91.79187012, 23.22887039], [91.79158783, 23.22871017], [91.79102325, 23.22694016], [91.79096222, 23.22675514], [91.7909317, 23.226614], [91.7907486, 23.22552681], [91.79090118, 23.22570419], [91.79100037, 23.22582245], [91.79111481, 23.22578621], [91.79116058, 23.22569656], [91.79118347, 23.22556686], [91.79114532, 23.22545624], [91.7911377, 23.22537994], [91.79113007, 23.22523499], [91.79113007, 23.22480202], [91.79111481, 23.22462845], [91.79111481, 23.22444153], [91.79111481, 23.22432137], [91.79108429, 23.22424507], [91.79084015, 23.22392464], [91.79083252, 23.22381401], [91.79091644, 23.22374153], [91.79105377, 23.22374535], [91.79137421, 23.2237606], [91.79149628, 23.22372627], [91.79161835, 23.2236805], [91.79162598, 23.22360611], [91.79161835, 23.22352982], [91.79158783, 23.2233429], [91.79151917, 23.22322464], [91.79136658, 23.22311592], [91.79132843, 23.2230072], [91.79116821, 23.22297096], [91.79107666, 23.22293472], [91.79087067, 23.22295189], [91.79034424, 23.22281647], [91.79030609, 23.22273064], [91.7903595, 23.22255516], [91.79042816, 23.22242546], [91.79051208, 23.22231293], [91.7905426, 23.22220993], [91.79050446, 23.22211647], [91.79046631, 23.22195244], [91.79029083, 23.22179794], [91.79019928, 23.22168922], [91.7901535, 23.22157097], [91.7901535, 23.22139168], [91.79017639, 23.22118187], [91.79022217, 23.22102356], [91.79032898, 23.22088242], [91.79046631, 23.22079086], [91.79058838, 23.22073555], [91.79073334, 23.22062683], [91.79084015, 23.22055435], [91.79105377, 23.22028542], [91.79113007, 23.22013664], [91.79130554, 23.21984863], [91.79132843, 23.21975708], [91.79138184, 23.21964836], [91.79151917, 23.2195015], [91.79164124, 23.21934128], [91.79172516, 23.21911812], [91.79179382, 23.21866989], [91.79184723, 23.21841049], [91.79184723, 23.2182827], [91.79171753, 23.2181015], [91.79156494, 23.21799278], [91.79144287, 23.21794701], [91.79125214, 23.21783829], [91.79101563, 23.21770287], [91.79088593, 23.21765709], [91.79071808, 23.2176342], [91.7903595, 23.21752167], [91.78995514, 23.21742058], [91.78977966, 23.21737289], [91.78949738, 23.21731949], [91.78929901, 23.21725845], [91.78904724, 23.2171936], [91.78879547, 23.21708488], [91.78845215, 23.216959], [91.78833008, 23.21690369], [91.78823853, 23.21679688], [91.7881546, 23.21666718], [91.78810883, 23.21650887], [91.78810883, 23.21635246], [91.78813171, 23.21596146], [91.78804016, 23.21573257], [91.78794098, 23.21556664], [91.78822327, 23.21493721], [91.78847504, 23.21479607], [91.7886734, 23.21470642], [91.78878784, 23.21465111], [91.78897858, 23.21456146], [91.7891922, 23.21445084], [91.78931427, 23.21439743], [91.78942108, 23.21434212], [91.78970337, 23.21429062], [91.78987885, 23.21425247], [91.79003143, 23.21421432], [91.79018402, 23.21410751], [91.79026031, 23.2140522], [91.79031372, 23.21397591], [91.79038239, 23.21380234], [91.7904129, 23.21362686], [91.79051971, 23.21347237], [91.79058838, 23.21336365], [91.7906723, 23.21324921], [91.79084778, 23.21291542], [91.79095459, 23.21281242], [91.7910614, 23.21274376], [91.79129791, 23.21267128], [91.79140472, 23.2126255], [91.79154968, 23.21253395], [91.79160309, 23.21245193], [91.79160309, 23.21236229], [91.79155731, 23.21227264], [91.79146576, 23.21215248], [91.79138947, 23.21207237], [91.79130554, 23.21202469], [91.79108429, 23.21194458], [91.79090881, 23.21191025], [91.79076385, 23.21183586], [91.79071808, 23.21174812], [91.79074097, 23.21163559], [91.79083252, 23.21155357], [91.79096985, 23.21145439], [91.79109192, 23.21141815], [91.79118347, 23.21138382], [91.79128265, 23.21137238], [91.79140472, 23.2113266], [91.79151154, 23.21128082], [91.79170227, 23.21114349], [91.79177856, 23.21107292], [91.79192352, 23.21087265], [91.79189301, 23.21074867], [91.79187012, 23.21061897], [91.7918396, 23.21052933], [91.79176331, 23.21035957], [91.79164124, 23.21017075], [91.79180145, 23.21002007], [91.79186249, 23.21013641], [91.7919693, 23.21016502], [91.79205322, 23.21014595], [91.79216003, 23.21004105], [91.79227448, 23.2099247], [91.79239655, 23.20971107], [91.79252625, 23.20954704], [91.79256439, 23.20942116], [91.79255676, 23.20927048], [91.79272461, 23.20910645], [91.79290771, 23.20849609], [91.79299164, 23.20779991], [91.79351807, 23.20568848], [91.79389191, 23.20147705], [91.79394531, 23.2014122], [91.79501343, 23.20017815], [91.79512787, 23.20010757], [91.79607391, 23.19950867], [91.79612732, 23.19944], [91.79651642, 23.19893837], [91.79683685, 23.19853592], [91.79721069, 23.19794846], [91.79727936, 23.19783783], [91.79940796, 23.19667816], [91.8000946, 23.19268608], [91.80006409, 23.19257545], [91.79992676, 23.19207764], [91.79933167, 23.1903038], [91.79929352, 23.19022179], [91.79897308, 23.18922043], [91.79872894, 23.18706894], [91.80029297, 23.18548584], [91.80056763, 23.18413162], [91.80076599, 23.18406487], [91.80085754, 23.18402481], [91.80097198, 23.18391228], [91.80104065, 23.18381691], [91.80110931, 23.18363762], [91.80112457, 23.18354988], [91.80105591, 23.18343735], [91.80097961, 23.18333244], [91.80096436, 23.18325996], [91.80092621, 23.18313217], [91.80098724, 23.18302917], [91.80120087, 23.18289566], [91.8013382, 23.18282318], [91.80146027, 23.18273544], [91.80153656, 23.18264961], [91.8015976, 23.18254089], [91.80173492, 23.18245125], [91.80191803, 23.18234062], [91.80200195, 23.18230438], [91.80213165, 23.18220901], [91.80239868, 23.18203354], [91.80259705, 23.18193245], [91.80283356, 23.18185234], [91.80307007, 23.18183899], [91.80318451, 23.18182373], [91.80334473, 23.18179703], [91.80354309, 23.18174744], [91.80369568, 23.18165588], [91.80375671, 23.18156624], [91.80379486, 23.18142509], [91.80383301, 23.18128586], [91.80393982, 23.18114281], [91.80399323, 23.18108368], [91.80412292, 23.18105316], [91.80429077, 23.18100548], [91.80445099, 23.18095207], [91.80455017, 23.18091202], [91.80476379, 23.18086052], [91.80492401, 23.18082237], [91.80505371, 23.1807518], [91.80516815, 23.18068123], [91.80528259, 23.18047523], [91.805336, 23.18033409], [91.8053894, 23.18020439], [91.80539703, 23.18007088], [91.80535126, 23.17986298], [91.80545044, 23.17967033], [91.80558014, 23.179533], [91.80571747, 23.1794281], [91.80588531, 23.1793766], [91.80605316, 23.17934227], [91.80618286, 23.17926407], [91.80620575, 23.17918777], [91.80603027, 23.17903328], [91.80584717, 23.17891312], [91.80574036, 23.17882156], [91.80558014, 23.17861748], [91.80547333, 23.17854309], [91.80535126, 23.17848778], [91.8052063, 23.17851257], [91.80503082, 23.17853737], [91.80483246, 23.17848778], [91.80474854, 23.17848015], [91.80465698, 23.17842102], [91.80455017, 23.17835426], [91.80451965, 23.17827797], [91.80445862, 23.17815781], [91.80437469, 23.1780014], [91.80430603, 23.17788124], [91.80426788, 23.17763329], [91.80427551, 23.17751122], [91.80434418, 23.17720985], [91.80431366, 23.17706299], [91.80425262, 23.17694664], [91.80414581, 23.17688751], [91.80405426, 23.17690849], [91.80386353, 23.17694092], [91.80360413, 23.17697716], [91.80352783, 23.17701149], [91.80331421, 23.17705536], [91.80318451, 23.17704391], [91.80311584, 23.17698669], [91.80312347, 23.1768074], [91.80318451, 23.17669106], [91.80336761, 23.17653656], [91.80345154, 23.17644691], [91.80356598, 23.17628479], [91.80370331, 23.17606544], [91.80393982, 23.17595291], [91.80406189, 23.17595673], [91.80422211, 23.17591095], [91.80430603, 23.17583275], [91.80437469, 23.17573738], [91.80439758, 23.17555618], [91.80442047, 23.17539597], [91.80444336, 23.17526817], [91.80435944, 23.17510223], [91.80419922, 23.17492676], [91.80406952, 23.17477608], [91.80405426, 23.17468834], [91.80410767, 23.17460442], [91.80423737, 23.17460442], [91.80437469, 23.17462921], [91.80446625, 23.17465973], [91.80459595, 23.17465973], [91.8046875, 23.1746788], [91.80484009, 23.17474937], [91.80495453, 23.17485619], [91.80500793, 23.1749382], [91.80501556, 23.17507935], [91.80502319, 23.17515564], [91.80500793, 23.17531967], [91.80493164, 23.17560959], [91.80496216, 23.17572021], [91.80500793, 23.17580795], [91.8050766, 23.17585564], [91.80523682, 23.17586708], [91.80534363, 23.17589188], [91.8054657, 23.17583084], [91.80555725, 23.17577744], [91.80560303, 23.17572021], [91.80566406, 23.17557716], [91.80574036, 23.17544174], [91.80583191, 23.17538071], [91.80596924, 23.17539215], [91.80609894, 23.17546463], [91.80622864, 23.17549324], [91.80643463, 23.17551613], [91.80654144, 23.17550278], [91.806633, 23.17544556], [91.80667114, 23.17535591], [91.80667114, 23.17526436], [91.80667114, 23.17518234], [91.80664825, 23.17509651], [91.80645752, 23.17487907], [91.80636597, 23.17482567], [91.80632782, 23.17476463], [91.80619049, 23.17462921], [91.80595398, 23.1746273], [91.80578613, 23.17456055], [91.80555725, 23.17452621], [91.80532837, 23.17442513], [91.80510712, 23.17434883], [91.80503082, 23.17428398], [91.80505371, 23.1742115], [91.8050766, 23.17414284], [91.8052597, 23.17394257], [91.80538177, 23.17386627], [91.80548096, 23.17384911], [91.80558014, 23.17383003], [91.80573273, 23.1738987], [91.8058548, 23.17396164], [91.80595398, 23.17393684], [91.80603027, 23.17388535], [91.80607605, 23.17381096], [91.80610657, 23.17370224], [91.80610657, 23.17361259], [91.80607605, 23.1734581], [91.80602264, 23.17331696], [91.80599213, 23.17312241], [91.8059845, 23.17294884], [91.80599213, 23.17278099], [91.80600739, 23.1727047], [91.80604553, 23.17263603], [91.80614471, 23.17261314], [91.80625153, 23.17261314], [91.806427, 23.17266655], [91.806633, 23.17269897], [91.80677795, 23.17271233], [91.80686951, 23.17265892], [91.8068924, 23.1725769], [91.80686188, 23.17234993], [91.8068924, 23.17216301], [91.8068924, 23.17202759], [91.8068924, 23.1719017], [91.80680847, 23.17181396], [91.80670166, 23.17178535], [91.80653381, 23.17186737], [91.8061142, 23.17214012], [91.80599976, 23.17224884], [91.80590057, 23.17231369], [91.80576324, 23.17235947], [91.80568695, 23.17231941], [91.80564117, 23.17223167], [91.8055954, 23.1721344], [91.80556488, 23.17201805], [91.80555725, 23.17190933], [91.80557251, 23.17183113], [91.80566406, 23.17175102], [91.80573273, 23.17163277], [91.80581665, 23.17154503], [91.80586243, 23.17140579], [91.80593872, 23.1713047], [91.80605316, 23.17119598], [91.80612946, 23.17106056], [91.8061676, 23.17092896], [91.80619049, 23.17081451], [91.80622101, 23.1706543], [91.8062439, 23.17042351], [91.80613708, 23.17029762], [91.80596161, 23.17021179], [91.80703735, 23.16898918], [91.80735016, 23.16666985], [91.80735016, 23.16638565], [91.80757141, 23.16625404], [91.80771637, 23.16618156], [91.80786133, 23.1661129], [91.80802917, 23.16605759], [91.80818176, 23.16605377], [91.80831909, 23.16601944], [91.80844879, 23.16600037], [91.80857086, 23.16595459], [91.80867004, 23.16591835], [91.80875397, 23.16588211], [91.80884552, 23.16587639], [91.80903625, 23.16581726], [91.80921936, 23.16572762], [91.80940247, 23.16566277], [91.80960846, 23.1655426], [91.80970001, 23.16552925], [91.80982971, 23.16552544], [91.80992889, 23.16539383], [91.81000519, 23.16521835], [91.81002045, 23.16509438], [91.81000519, 23.16501427], [91.80993652, 23.16492081], [91.80989838, 23.16483879], [91.80988312, 23.16457367], [91.80983734, 23.16449547], [91.80956268, 23.16421127], [91.8094101, 23.16403961], [91.80924225, 23.16354752], [91.80905151, 23.16351318], [91.80897522, 23.1634922], [91.80885315, 23.16344261], [91.80851746, 23.16334152], [91.80840302, 23.16333961], [91.80831909, 23.16329384], [91.80805969, 23.16320419], [91.80789948, 23.16316986], [91.80765533, 23.16312981], [91.80754852, 23.1631012], [91.80737305, 23.16304016], [91.80716705, 23.16287613], [91.8070755, 23.16280174], [91.80700684, 23.16273308], [91.80690765, 23.16264343], [91.80686188, 23.16255569], [91.80687714, 23.16244125], [91.8069458, 23.16241074], [91.80704498, 23.16240692], [91.80712891, 23.16238403], [91.80722046, 23.16233444], [91.80730438, 23.16230965], [91.80741882, 23.16221237], [91.80751038, 23.16212273], [91.80757904, 23.16203499], [91.80762482, 23.16193962], [91.80761719, 23.16182899], [91.8075943, 23.16171646], [91.80757141, 23.161623], [91.80754089, 23.16144943], [91.80751038, 23.1613121], [91.80741119, 23.16097641], [91.80718994, 23.16055107], [91.80701447, 23.16022491], [91.80677795, 23.15984726], [91.80675507, 23.15971565], [91.80664825, 23.15945816], [91.8065567, 23.15923882], [91.80649567, 23.15904427], [91.80631256, 23.15863991], [91.8062973, 23.158535], [91.8062439, 23.15833855], [91.80622864, 23.15820694], [91.80621338, 23.15809631], [91.80613708, 23.15783882], [91.80603027, 23.15758133], [91.80603027, 23.15744972], [91.80606079, 23.15736961], [91.80612946, 23.15729141], [91.80620575, 23.15721703], [91.80632019, 23.15716553], [91.806633, 23.1570282], [91.80706787, 23.15680885], [91.80719757, 23.15672112], [91.80728149, 23.15662384], [91.80749512, 23.15649605], [91.80760956, 23.15642357], [91.80770874, 23.15633202], [91.80780029, 23.15624809], [91.8081131, 23.15606499], [91.80820465, 23.15600967], [91.80831909, 23.15592766], [91.80840302, 23.15577126], [91.80845642, 23.15570068], [91.80851746, 23.15558052], [91.80861664, 23.15543747], [91.80877686, 23.15524673], [91.80895996, 23.15504456], [91.80905151, 23.15493584], [91.80918884, 23.15476608], [91.80931091, 23.15460777], [91.8094635, 23.15445518], [91.80960083, 23.15431595], [91.80976868, 23.15409279], [91.80995178, 23.15401077], [91.81015015, 23.15393448], [91.81026459, 23.15391159], [91.81034088, 23.15385056], [91.81048584, 23.15372086], [91.8105545, 23.1536026], [91.81069946, 23.15326118], [91.81070709, 23.15310669], [91.81077576, 23.15279388], [91.8107605, 23.15269279], [91.81053925, 23.15260315], [91.81044006, 23.15258217], [91.81034851, 23.15250397], [91.81026459, 23.15247536], [91.81019592, 23.15243149], [91.81012726, 23.15235329], [91.810112, 23.15226173], [91.810112, 23.1521759], [91.81014252, 23.15204811], [91.81018066, 23.15197372], [91.81023407, 23.15189171], [91.81047821, 23.15179253], [91.81061554, 23.15177536], [91.81089783, 23.15220261], [91.81118011, 23.15256882], [91.81138611, 23.15287399], [91.8116684, 23.15330124], [91.81201172, 23.15372849], [91.81215668, 23.15385628], [91.8134079, 23.15088844], [91.81337738, 23.14998055], [91.81404114, 23.14750481], [91.81408691, 23.14727783], [91.81417084, 23.14549255], [91.81417847, 23.14528847], [91.81411743, 23.1450119], [91.81401062, 23.14483643], [91.8137207, 23.14452744], [91.81365967, 23.14447212], [91.813591, 23.14442253], [91.81352234, 23.14434242], [91.81335449, 23.14429092], [91.81320953, 23.14414024], [91.81302643, 23.14383698], [91.81288147, 23.14389992], [91.81268311, 23.14402962], [91.81259155, 23.14418602], [91.81256104, 23.14426041], [91.81250763, 23.14434052], [91.81230164, 23.14453506], [91.81222534, 23.14459038], [91.81204224, 23.14464188], [91.81187439, 23.14467239], [91.81142426, 23.14474678], [91.81118774, 23.14476395], [91.81098938, 23.14474297], [91.81095886, 23.14464188], [91.81098938, 23.14451027], [91.81098938, 23.14438248], [91.81095123, 23.14403725], [91.8108902, 23.14374542], [91.81082153, 23.14364815], [91.81072235, 23.14358139], [91.81065369, 23.14349747], [91.81060791, 23.14341736], [91.81053925, 23.14327049], [91.81049347, 23.14314842], [91.81047058, 23.14306259], [91.81035614, 23.14274597], [91.81031036, 23.14263916], [91.81022644, 23.14247322], [91.81014252, 23.14234924], [91.81006622, 23.14220428], [91.80989838, 23.14202118], [91.8097229, 23.14169884], [91.80949402, 23.1413765], [91.80918121, 23.14106941], [91.80882263, 23.14061546], [91.80876923, 23.14047813], [91.80870819, 23.14035988], [91.80870819, 23.14020538], [91.80875397, 23.13996887], [91.80870819, 23.13979912], [91.80870819, 23.13971519], [91.8086853, 23.13962364], [91.80858612, 23.13944626], [91.80844879, 23.13941574], [91.80825806, 23.13932419], [91.80810547, 23.13917923], [91.80825806, 23.13877487], [91.80834198, 23.13855171], [91.80841064, 23.13823128], [91.80844879, 23.13796234], [91.80853271, 23.13784409], [91.80860138, 23.13770866], [91.80880737, 23.13752174], [91.80886078, 23.13737488], [91.80892944, 23.13726616], [91.80905914, 23.13688087], [91.80911255, 23.13679123], [91.80918884, 23.13667297], [91.80919647, 23.13656807], [91.80908966, 23.13648224], [91.80898285, 23.13633919], [91.809021, 23.13623428], [91.80892944, 23.13615227], [91.80878448, 23.13610649], [91.80861664, 23.13603783], [91.8085022, 23.13596535], [91.80821228, 23.13591957], [91.8080368, 23.13578796], [91.80805969, 23.13566399], [91.80814362, 23.13543701], [91.8082428, 23.13515472], [91.80825043, 23.13501167], [91.80835724, 23.13484573], [91.80848694, 23.13466644], [91.80859375, 23.13453674], [91.80870056, 23.13432121], [91.80892944, 23.13405228], [91.80905151, 23.13399696], [91.80921936, 23.13394737], [91.8093338, 23.13394737], [91.80944824, 23.13399315], [91.80953979, 23.13400078], [91.80964661, 23.13401222], [91.8098526, 23.1339016], [91.81002045, 23.13382721], [91.81019592, 23.13380814], [91.81033325, 23.13382149], [91.81054688, 23.13393974], [91.81079865, 23.13418388], [91.81085968, 23.13435364], [91.81088257, 23.13455009], [91.8108139, 23.13467598], [91.8107605, 23.13503647], [91.81079102, 23.1356411], [91.81080627, 23.13573456], [91.81079102, 23.13587952], [91.81083679, 23.13602638], [91.81083679, 23.13614464], [91.8108139, 23.13633537], [91.81076813, 23.13643837], [91.8107605, 23.13656044], [91.8108139, 23.13665199], [91.81080627, 23.13686943], [91.81086731, 23.13702393], [91.8110199, 23.13707161], [91.81112671, 23.13702583], [91.81119537, 23.13677979], [91.81124878, 23.1359539], [91.81124878, 23.13579941], [91.81131744, 23.13558197], [91.81132507, 23.13532829], [91.81132507, 23.13489914], [91.81139374, 23.13479042], [91.81143188, 23.13458252], [91.8115387, 23.13435555], [91.81165314, 23.13424301], [91.8118515, 23.13424683], [91.8120575, 23.13426399], [91.81240082, 23.13427544], [91.81253815, 23.13430023], [91.81261444, 23.13433647], [91.81298065, 23.13435555], [91.81317902, 23.13430214], [91.81343842, 23.13424683], [91.81358337, 23.13420868], [91.81375122, 23.1341362], [91.81388855, 23.13409996], [91.81402588, 23.13401413], [91.81413269, 23.13391876], [91.81429291, 23.13381195], [91.8145752, 23.13368225], [91.81463623, 23.13358879], [91.81469727, 23.13342476], [91.81471252, 23.13327408], [91.81469727, 23.13308334], [91.81469727, 23.13289833], [91.8147583, 23.13267899], [91.81477356, 23.13244629], [91.81481171, 23.13231087], [91.81479645, 23.13220787], [91.81486511, 23.13197327], [91.81486511, 23.13183022], [91.81472778, 23.13158417], [91.8146286, 23.13150215], [91.81443787, 23.13140297], [91.81429291, 23.13137627], [91.81398773, 23.13126373], [91.81381226, 23.13122177], [91.81357574, 23.13123894], [91.81345367, 23.13122177], [91.81336212, 23.13123131], [91.8131485, 23.13118744], [91.81280518, 23.13111115], [91.81252289, 23.1309948], [91.81235504, 23.13093185], [91.81229401, 23.13085365], [91.81225586, 23.13075256], [91.81231689, 23.13066864], [91.81248474, 23.13057518], [91.81252289, 23.13040352], [91.81274414, 23.1302681], [91.81282806, 23.13021851], [91.81313324, 23.13002777], [91.8136673, 23.12969971], [91.813797, 23.12960815], [91.81501007, 23.12938118], [91.81555939, 23.12938118], [91.81674957, 23.1289711], [91.81671143, 23.1282959], [91.81787109, 23.12768555], [91.81732178, 23.12609863], [91.81633759, 23.12483406], [91.81628418, 23.12371826], [91.81616974, 23.12361908], [91.81504822, 23.12273026], [91.81420135, 23.12203217], [91.81349945, 23.12153625], [91.813797, 23.11907196], [91.81394196, 23.1190052], [91.81410217, 23.11902428], [91.81435394, 23.11909676], [91.81468964, 23.11920547], [91.81502533, 23.11933136], [91.8152771, 23.11932182], [91.81536865, 23.11932182], [91.81549835, 23.11926079], [91.81556702, 23.11919212], [91.81561279, 23.11902046], [91.8159256, 23.11907578], [91.815979, 23.11914635], [91.81741333, 23.12061882], [91.81751251, 23.12072372], [91.81756592, 23.12080574], [91.81829834, 23.1217041], [91.81850433, 23.12199593], [91.81872559, 23.12231445], [91.81988525, 23.12310791], [91.81996155, 23.12306213], [91.82086182, 23.1225338], [91.82086945, 23.12240028], [91.82087708, 23.12221909], [91.82092285, 23.12091064], [91.82067871, 23.11828613], [91.8194809, 23.11593056], [91.81887054, 23.11468124], [91.81848907, 23.11388779], [91.81845856, 23.11375237], [91.81798553, 23.11231613], [91.81848145, 23.11187744], [91.81986237, 23.11179161], [91.82116699, 23.11174011], [91.82269287, 23.11169434], [91.82292938, 23.11066818], [91.82315826, 23.1101532], [91.82319641, 23.10890007], [91.82330322, 23.10888672], [91.82452393, 23.10748291], [91.82460022, 23.10736847], [91.82507324, 23.10668945], [91.8245697, 23.1056881], [91.82404327, 23.10451698], [91.82400513, 23.10443497], [91.82315063, 23.10383797], [91.82308197, 23.10379028], [91.82269287, 23.10351563], [91.82236481, 23.1028862], [91.82287598, 23.10211182], [91.82312012, 23.10150146], [91.82330322, 23.10089111], [91.82427979, 23.10028076], [91.82514954, 23.09993935], [91.82692719, 23.10015106], [91.82952881, 23.10070801], [91.83167267, 23.10011292], [91.83270264, 23.09887695], [91.83443451, 23.09664536], [91.83449554, 23.09658432], [91.83551025, 23.09552002], [91.83551025, 23.09387207], [91.83546448, 23.09378052], [91.83556366, 23.09366035], [91.83563995, 23.09356499], [91.83571625, 23.09342575], [91.83572388, 23.09331894], [91.83573914, 23.09318542], [91.83569336, 23.09303856], [91.83556366, 23.09285736], [91.83548737, 23.09281731], [91.83550262, 23.09274101], [91.83531952, 23.09261703], [91.83522797, 23.09254837], [91.8351059, 23.09249496], [91.8350296, 23.09249496], [91.83482361, 23.09249496], [91.83460236, 23.09249306], [91.83429718, 23.09251213], [91.83407593, 23.09254456], [91.83383179, 23.0925827], [91.83366394, 23.0926342], [91.83343506, 23.09269905], [91.83327484, 23.09270287], [91.83300018, 23.09269142], [91.83293915, 23.09256744], [91.83290863, 23.09244156], [91.83293152, 23.09234428], [91.83293915, 23.09220505], [91.83298492, 23.09212685], [91.83306122, 23.09201813], [91.83312225, 23.09187508], [91.83320618, 23.09171867], [91.83331299, 23.09156799], [91.83338928, 23.09144592], [91.83345032, 23.09128571], [91.83340454, 23.09111786], [91.83329773, 23.09103775], [91.83323669, 23.09098434], [91.83314514, 23.0909977], [91.8330307, 23.09105682], [91.83293915, 23.09113121], [91.83285522, 23.09115028], [91.83268738, 23.09119606], [91.83255768, 23.09119034], [91.83216858, 23.09118271], [91.83195496, 23.09121895], [91.83181, 23.09119034], [91.83172607, 23.09116936], [91.83161926, 23.09114075], [91.83152771, 23.09109306], [91.83136749, 23.09087563], [91.83133698, 23.09073448], [91.83137512, 23.09055519], [91.83148193, 23.09037018], [91.83148193, 23.09024239], [91.83144379, 23.09004974], [91.83139038, 23.08995056], [91.83132172, 23.08989334], [91.83120728, 23.0899353], [91.83110809, 23.09003448], [91.83110809, 23.09016228], [91.83109283, 23.09024239], [91.83097839, 23.09026909], [91.83094025, 23.09038734], [91.83081818, 23.0905056], [91.83059692, 23.0907135], [91.83052063, 23.09088516], [91.83039093, 23.09103775], [91.8302536, 23.09120941], [91.83013153, 23.09140778], [91.82995605, 23.09161377], [91.82985687, 23.09171486], [91.82967377, 23.09179115], [91.82962036, 23.09172058], [91.82952118, 23.09167862], [91.82936096, 23.0915966], [91.82924652, 23.09169579], [91.82917786, 23.09141731], [91.82914734, 23.09119987], [91.8291626, 23.09101105], [91.8291626, 23.09086227], [91.82917023, 23.09077835], [91.8290329, 23.09054756], [91.83227539, 23.08947754], [91.83193207, 23.08947754], [91.83061981, 23.08933067], [91.82990265, 23.08922005], [91.82963562, 23.08860397], [91.8289032, 23.08840942], [91.82831573, 23.0883522], [91.82765198, 23.08817101], [91.82706451, 23.08798981], [91.82633972, 23.08787346], [91.82542419, 23.0877552], [91.82530212, 23.08774567], [91.8252182, 23.08773994], [91.82505798, 23.08760262], [91.82468414, 23.08744812], [91.82465363, 23.08731461], [91.82442474, 23.08717537], [91.8243103, 23.08712387], [91.82407379, 23.08707428], [91.82367706, 23.08703232], [91.82350922, 23.08701706], [91.82331085, 23.08701897], [91.82308197, 23.08697701], [91.8229599, 23.08687592], [91.82286835, 23.08683586], [91.82279968, 23.08675957], [91.8227005, 23.08674049], [91.8225708, 23.08654404], [91.82249451, 23.08641624], [91.8223877, 23.08627319], [91.82236481, 23.0861969], [91.82219696, 23.08584976], [91.82219696, 23.08571434], [91.82228851, 23.08557892], [91.82234955, 23.08548355], [91.82252502, 23.08533287], [91.82266998, 23.0851841], [91.8229599, 23.08498192], [91.82315826, 23.08490753], [91.82331848, 23.08479691], [91.8234787, 23.08472252], [91.82362366, 23.08461189], [91.82370758, 23.08452988], [91.8239212, 23.08436203], [91.82402039, 23.08427048], [91.82418823, 23.08412361], [91.82426453, 23.08396721], [91.82437134, 23.08382416], [91.82427216, 23.08358002], [91.82415009, 23.0834198], [91.82405853, 23.08330345], [91.82395935, 23.08325005], [91.82369995, 23.08311081], [91.82344818, 23.08303261], [91.82309723, 23.08288193], [91.82293701, 23.08282089], [91.82260132, 23.08260345], [91.82250214, 23.08250618], [91.82236481, 23.08237267], [91.82215881, 23.08223724], [91.82198334, 23.08207321], [91.82191467, 23.08201599], [91.82178497, 23.08190918], [91.82167053, 23.08180428], [91.8214798, 23.08170319], [91.82117462, 23.08139992], [91.82108307, 23.08132935], [91.82087708, 23.08114624], [91.82060242, 23.08094215], [91.82052612, 23.08086205], [91.82043457, 23.08075905], [91.8203125, 23.08065033], [91.82015228, 23.08048439], [91.82009888, 23.08034897], [91.81998444, 23.08023643], [91.81990814, 23.08014679], [91.8197403, 23.07997894], [91.81954193, 23.07990074], [91.81943512, 23.07991219], [91.8193512, 23.07994843], [91.8192749, 23.08005714], [91.81920624, 23.08025742], [91.8192215, 23.08045006], [91.81923676, 23.08057022], [91.81918335, 23.08078766], [91.81912231, 23.08090591], [91.81903839, 23.08114243], [91.81895447, 23.08138275], [91.81893158, 23.08146477], [91.81887817, 23.08179474], [91.8188858, 23.08187103], [91.81881714, 23.08209419], [91.81879425, 23.08226395], [91.8187027, 23.08243752], [91.81863403, 23.08254814], [91.81854248, 23.08271599], [91.8184433, 23.08299637], [91.81835175, 23.0831089], [91.81820679, 23.08314323], [91.81812286, 23.08314514], [91.81803131, 23.08315849], [91.8179245, 23.08315849], [91.81780243, 23.08313751], [91.81765747, 23.08314514], [91.81742096, 23.08309555], [91.81726074, 23.0830555], [91.81719971, 23.08298492], [91.81712341, 23.08293343], [91.81702423, 23.08278656], [91.81699371, 23.08267593], [91.81694794, 23.08255196], [91.81684875, 23.08241653], [91.81684113, 23.08226585], [91.81687927, 23.08205605], [91.81678772, 23.08171463], [91.81676483, 23.08154869], [91.81671143, 23.08131981], [91.81665039, 23.08119202], [91.8164444, 23.08092117], [91.81632233, 23.08091164], [91.81616211, 23.08094788], [91.81606293, 23.08102417], [91.81591797, 23.08101273], [91.81563568, 23.08100319], [91.81525421, 23.08093452], [91.81508636, 23.08090973], [91.81486511, 23.08085632], [91.81468964, 23.08071518], [91.81461334, 23.08058548], [91.81463623, 23.08051109], [91.81466675, 23.08041573], [91.81471252, 23.0803318], [91.81483459, 23.08023262], [91.81505585, 23.08014679], [91.81518555, 23.08010864], [91.8152771, 23.08008003], [91.81538391, 23.08004951], [91.81602478, 23.07971382], [91.81621552, 23.07961655], [91.81652832, 23.07953262], [91.81665802, 23.07949448], [91.81684875, 23.07944679], [91.81698608, 23.07937241], [91.81706238, 23.07931709], [91.81716156, 23.07920456], [91.81721497, 23.07910156], [91.81726837, 23.0789032], [91.81734467, 23.07857704], [91.81737518, 23.07844162], [91.81745911, 23.07814407], [91.81757355, 23.07790184], [91.81764221, 23.07763863], [91.81769562, 23.07747841], [91.81777191, 23.0772419], [91.81782532, 23.07689095], [91.81781769, 23.07667351], [91.81781006, 23.07656288], [91.81784821, 23.0764389], [91.81783295, 23.07628441], [91.81781006, 23.07595253], [91.81775665, 23.07582474], [91.81764221, 23.0757122], [91.81752014, 23.07563972], [91.81741333, 23.07567787], [91.81733704, 23.07566261], [91.8172226, 23.07567596], [91.81707764, 23.07561111], [91.81681824, 23.07552147], [91.81650543, 23.07539177], [91.81637573, 23.07532883], [91.81620026, 23.07526207], [91.81606293, 23.07513237], [91.81595612, 23.07504845], [91.81584167, 23.07492065], [91.81584167, 23.07481003], [91.81591034, 23.07468033], [91.81602478, 23.07457352], [91.81611633, 23.07441902], [91.81621552, 23.07431602], [91.81637573, 23.07417297], [91.81655884, 23.07406235], [91.81686401, 23.07394218], [91.81697845, 23.07388687], [91.81730652, 23.07385063], [91.81777954, 23.07385063], [91.81791687, 23.07383347], [91.8181076, 23.07381248], [91.81825256, 23.07366371], [91.81833649, 23.07345963], [91.81838226, 23.07326508], [91.81832886, 23.07294846], [91.81822205, 23.0727787], [91.81806183, 23.07262421], [91.81800842, 23.07254219], [91.81790161, 23.07242966], [91.81783295, 23.07234001], [91.81773376, 23.07229424], [91.81745911, 23.07216835], [91.81734467, 23.07213783], [91.81706238, 23.07208443], [91.81682587, 23.07203102], [91.81658936, 23.07201195], [91.81638336, 23.07198334], [91.81621552, 23.07199478], [91.81594849, 23.0720005], [91.81585693, 23.07204819], [91.81569672, 23.07208443], [91.81547546, 23.072155], [91.81533051, 23.07221603], [91.81522369, 23.07229996], [91.81507874, 23.07243919], [91.81491089, 23.07266235], [91.81479645, 23.07288361], [91.81471252, 23.07299232], [91.81465912, 23.07310104], [91.81454468, 23.07322693], [91.81443024, 23.07331848], [91.81422424, 23.07346535], [91.81414795, 23.07356071], [91.81394958, 23.07367516], [91.81372833, 23.07377243], [91.81354523, 23.07378769], [91.81339264, 23.07377052], [91.81326294, 23.07375336], [91.81319427, 23.07370186], [91.81311035, 23.07364845], [91.81302643, 23.07353783], [91.81292725, 23.07336998], [91.81290436, 23.07326508], [91.81285095, 23.07315826], [91.81275177, 23.07299042], [91.81260681, 23.07274055], [91.81253815, 23.07267952], [91.81243134, 23.07237244], [91.81241608, 23.07226753], [91.81246948, 23.07220268], [91.81250763, 23.07209587], [91.81261444, 23.07201195], [91.81270599, 23.07193375], [91.81278229, 23.07188988], [91.8128891, 23.07182884], [91.81298828, 23.07174683], [91.81313324, 23.071661], [91.81334686, 23.07144356], [91.81348419, 23.07128525], [91.81357574, 23.07121086], [91.81364441, 23.07110786], [91.81370544, 23.07098198], [91.81375885, 23.07083321], [91.81378174, 23.0707283], [91.8137207, 23.07064629], [91.81359863, 23.07055092], [91.81346893, 23.07048416], [91.81330109, 23.07050133], [91.8130722, 23.07056046], [91.81291199, 23.07057762], [91.81278229, 23.07056236], [91.81250763, 23.07055855], [91.81233978, 23.07053185], [91.81208801, 23.07042503], [91.81201172, 23.07036781], [91.81193542, 23.07032776], [91.81188202, 23.07026863], [91.81181335, 23.07016182], [91.8117218, 23.07010078], [91.8115921, 23.06997871], [91.81153107, 23.06981277], [91.81150818, 23.06965065], [91.81153107, 23.06954384], [91.81156921, 23.06918335], [91.81156921, 23.06906509], [91.81158447, 23.06896782], [91.81165314, 23.06886482], [91.81166077, 23.06878281], [91.81170654, 23.0687027], [91.81191254, 23.06847382], [91.81202698, 23.0683136], [91.81210327, 23.0681324], [91.81221771, 23.06803131], [91.8122406, 23.06793404], [91.81229401, 23.06783485], [91.81234741, 23.06774712], [91.81238556, 23.06757927], [91.81242371, 23.06740379], [91.81243134, 23.06716728], [91.81245422, 23.06707954], [91.81240845, 23.06700325], [91.81240845, 23.06668663], [91.81232452, 23.06642723], [91.81224823, 23.06634331], [91.81204987, 23.06624031], [91.8117981, 23.06613541], [91.81147003, 23.0662384], [91.81109619, 23.06632805], [91.81098175, 23.06640053], [91.81076813, 23.06650925], [91.81062317, 23.06655502], [91.81045532, 23.06667328], [91.81032562, 23.06669998], [91.81020355, 23.06670952], [91.80998993, 23.066782], [91.80987549, 23.06679153], [91.80970764, 23.06681824], [91.80957031, 23.06680489], [91.80924225, 23.06675529], [91.80883026, 23.06669235], [91.8086319, 23.06667137], [91.80838776, 23.06660271], [91.80817413, 23.0666008], [91.80809021, 23.06659889], [91.80783081, 23.06667328], [91.80747223, 23.06671906], [91.80728149, 23.06681442], [91.80708313, 23.06692696], [91.80702209, 23.06698227], [91.80693817, 23.06705093], [91.80680084, 23.06710625], [91.80670929, 23.06710815], [91.80656433, 23.06714439], [91.80635071, 23.06698799], [91.80615997, 23.06713104], [91.80593109, 23.06711388], [91.80584717, 23.0670414], [91.80567932, 23.06683922], [91.80562592, 23.06671715], [91.80561066, 23.0666008], [91.80566406, 23.06643867], [91.80580902, 23.0662365], [91.80593109, 23.06603622], [91.80607605, 23.06606674], [91.80630493, 23.06568336], [91.80648041, 23.06553078], [91.80659485, 23.06524086], [91.80669403, 23.06509781], [91.80673981, 23.06497955], [91.80679321, 23.06486702], [91.80680847, 23.06459808], [91.80682373, 23.06404495], [91.80677032, 23.06393623], [91.80672455, 23.06376648], [91.80664825, 23.0636692], [91.80662537, 23.06356812], [91.80657196, 23.06345558], [91.80638885, 23.06332779], [91.80620575, 23.06327438], [91.80610657, 23.06323624], [91.80597687, 23.06316185], [91.80580902, 23.06320381], [91.80556488, 23.06324196], [91.80505371, 23.06326866], [91.80469513, 23.06329727], [91.80460358, 23.06329346], [91.80423737, 23.06339264], [91.80413055, 23.06341934], [91.80393982, 23.06345749], [91.80381775, 23.06348991], [91.80373383, 23.06351852], [91.80362701, 23.06353378], [91.80339813, 23.06369591], [91.80304718, 23.06395721], [91.80284119, 23.0640583], [91.8026123, 23.06419945], [91.8024292, 23.06427574], [91.8022995, 23.06435204], [91.80207825, 23.06440353], [91.80184937, 23.06451416], [91.80147552, 23.06462479], [91.80135345, 23.06469727], [91.80112457, 23.06476402], [91.80082703, 23.06487465], [91.80057526, 23.06490898], [91.80028534, 23.06502342], [91.79984283, 23.06510735], [91.79953003, 23.06509018], [91.79909515, 23.06510162], [91.79865265, 23.06502724], [91.79823303, 23.06495285], [91.79797363, 23.06479263], [91.79785919, 23.06475067], [91.79773712, 23.06464386], [91.7975769, 23.06443787], [91.79750061, 23.0643692], [91.79741669, 23.06425667], [91.7972641, 23.06416893], [91.7971344, 23.06404114], [91.79707336, 23.06395149], [91.79666138, 23.06357002], [91.79654694, 23.06346512], [91.79637146, 23.06324959], [91.79608917, 23.06300926], [91.79584503, 23.06276894], [91.79576874, 23.06271744], [91.79541016, 23.06241989], [91.79528809, 23.0623455], [91.7951355, 23.0622673], [91.79497528, 23.06224632], [91.79463959, 23.06226158], [91.79429626, 23.06231499], [91.79417419, 23.06239128], [91.79400635, 23.06242752], [91.79385376, 23.06255722], [91.79373932, 23.06275177], [91.79364014, 23.06292343], [91.79348755, 23.06332397], [91.79342651, 23.06368256], [91.79338074, 23.06391716], [91.79338837, 23.06423759], [91.79344177, 23.06471443], [91.79351807, 23.06501389], [91.79363251, 23.06522369], [91.79364014, 23.06534386], [91.79373169, 23.06551933], [91.79389191, 23.06577873], [91.79408264, 23.06597137], [91.7943573, 23.06620598], [91.79446411, 23.06625938], [91.79455566, 23.06629753], [91.79467773, 23.06630707], [91.7948761, 23.06633186], [91.79457092, 23.06664276], [91.79367828, 23.06768036], [91.79405212, 23.0690136], [91.79396057, 23.06905365], [91.79366302, 23.06917572], [91.79355621, 23.06917], [91.79345703, 23.06918526], [91.79328156, 23.06917], [91.79315186, 23.06912994], [91.79291534, 23.06906891], [91.7926178, 23.06899834], [91.79246521, 23.0689888], [91.79228973, 23.06894493], [91.792099, 23.06891823], [91.7918396, 23.06887817], [91.79154968, 23.06882668], [91.79124451, 23.06881332], [91.79093933, 23.06876183], [91.79072571, 23.06876755], [91.79032135, 23.06874847], [91.79017639, 23.06877327], [91.78997803, 23.06876564], [91.7897644, 23.06887054], [91.78967285, 23.06896973], [91.7896347, 23.06907654], [91.78953552, 23.06930733], [91.78951263, 23.06944656], [91.789505, 23.06981659], [91.78949738, 23.06998253], [91.78949738, 23.07024574], [91.78957367, 23.07072258], [91.7896347, 23.07089806], [91.78972626, 23.07104111], [91.78974152, 23.07118797], [91.78972626, 23.07144737], [91.78968048, 23.07165909], [91.78953552, 23.07180214], [91.78938293, 23.0718174], [91.78928375, 23.07179832], [91.78908539, 23.07167244], [91.7889328, 23.07150841], [91.78877258, 23.07134438], [91.78849792, 23.07118607], [91.78838348, 23.07107544], [91.78827667, 23.07091331], [91.78816223, 23.07058716], [91.78807068, 23.07027626], [91.78803253, 23.07003975], [91.78806305, 23.06982613], [91.7881012, 23.06963539], [91.78813934, 23.06951904], [91.78826904, 23.06936455], [91.78834534, 23.06924057], [91.78848267, 23.06905174], [91.78855133, 23.06889915], [91.78865051, 23.06876183], [91.78877258, 23.06863022], [91.78891754, 23.06841087], [91.78903961, 23.06823349], [91.78907013, 23.0681591], [91.78919983, 23.06785774], [91.78919983, 23.06774521], [91.78917694, 23.06762886], [91.78903198, 23.0674057], [91.78889465, 23.06734848], [91.78878784, 23.067379], [91.78862, 23.06746483], [91.78845978, 23.06748772], [91.78817749, 23.06753349], [91.78788757, 23.06762505], [91.78768921, 23.06771851], [91.78752899, 23.06781197], [91.78742218, 23.06782722], [91.78730774, 23.06787491], [91.78720093, 23.06789398], [91.78702545, 23.06796837], [91.78686523, 23.06805801], [91.78636169, 23.0681839], [91.78627777, 23.06817436], [91.78618622, 23.06824112], [91.78600311, 23.068367], [91.78594208, 23.06845665], [91.78585815, 23.0684967], [91.78578949, 23.06871414], [91.78574371, 23.06900597], [91.78579712, 23.06945419], [91.78585815, 23.07010269], [91.78586578, 23.07026482], [91.78586578, 23.07053185], [91.7858429, 23.07066154], [91.78582764, 23.07073402], [91.78574371, 23.07096863], [91.78560638, 23.07118607], [91.7855072, 23.07134056], [91.78541565, 23.07138443], [91.78533173, 23.07140923], [91.78513336, 23.07145691], [91.7849884, 23.07152748], [91.78474426, 23.07162476], [91.78450775, 23.07158661], [91.78437042, 23.07158661], [91.78397369, 23.0716362], [91.78382111, 23.07165909], [91.78358459, 23.07165527], [91.78282928, 23.07157516], [91.78240967, 23.07152367], [91.78204346, 23.07143021], [91.78179169, 23.07137489], [91.78153992, 23.07139015], [91.78125763, 23.07136726], [91.78075409, 23.07131767], [91.7804718, 23.07131195], [91.78015137, 23.07126617], [91.78002167, 23.07126427], [91.7797699, 23.07122803], [91.77914429, 23.07115173], [91.77881622, 23.07108879], [91.77872467, 23.07104111], [91.77861786, 23.07103348], [91.7781601, 23.07091904], [91.77794647, 23.07077026], [91.77787018, 23.07076836], [91.77731323, 23.07061577], [91.77700806, 23.07053947], [91.77670288, 23.07050514], [91.77645874, 23.07050323], [91.77632904, 23.07045746], [91.77619934, 23.07039833], [91.77601624, 23.07039452], [91.77565765, 23.07027626], [91.77502441, 23.06999016], [91.77468109, 23.06982231], [91.77445984, 23.06971741], [91.77422333, 23.06945419], [91.77402496, 23.06921196], [91.77394104, 23.06909943], [91.77387238, 23.06891823], [91.77374268, 23.06867218], [91.77367401, 23.06853867], [91.77359009, 23.06836891], [91.77351379, 23.06797791], [91.77346802, 23.0676651], [91.77339935, 23.06741142], [91.77334595, 23.06711006], [91.77340698, 23.06674767], [91.77352905, 23.0664444], [91.77376556, 23.0660305], [91.77392578, 23.06577873], [91.77416992, 23.06552505], [91.77428436, 23.06540489], [91.77449799, 23.0651741], [91.77482605, 23.06488419], [91.77490997, 23.0648632], [91.77534485, 23.06443787], [91.77552795, 23.0643177], [91.77563477, 23.06418991], [91.77573395, 23.06411934], [91.77579498, 23.06403923], [91.77587128, 23.06392097], [91.77610016, 23.06372643], [91.77633667, 23.06356812], [91.77654266, 23.06336021], [91.77667236, 23.06328392], [91.77689362, 23.0631218], [91.77710724, 23.06298065], [91.77722168, 23.06284142], [91.77747345, 23.06261444], [91.77757263, 23.06248665], [91.77768707, 23.06241417], [91.7778244, 23.06227684], [91.77806091, 23.06204033], [91.77826691, 23.06187057], [91.77835083, 23.06177521], [91.77843475, 23.06173325], [91.77855682, 23.06161499], [91.77864838, 23.06144333], [91.77880096, 23.06123352], [91.7789917, 23.06097031], [91.77906036, 23.06085396], [91.77908325, 23.06074333], [91.77918243, 23.06048775], [91.77922821, 23.06025505], [91.77935791, 23.0600872], [91.77941132, 23.05987358], [91.77941895, 23.05969048], [91.77944183, 23.05956268], [91.77944183, 23.05937958], [91.77960968, 23.05925941], [91.77935791, 23.05903625], [91.77935028, 23.05896187], [91.77928162, 23.05879402], [91.77921295, 23.05841446], [91.77919769, 23.0581913], [91.77913666, 23.05789566], [91.77906036, 23.05772781], [91.77896881, 23.05759621], [91.77889252, 23.05751801], [91.7787323, 23.0573597], [91.77858734, 23.0573101], [91.77802277, 23.05711365], [91.77761078, 23.05696869], [91.78109741, 23.05555725], [91.7824707, 23.05328369], [91.78295898, 23.05282974], [91.78471375, 23.05131721], [91.78479767, 23.05124664], [91.78668213, 23.04888916], [91.78692627, 23.04797554], [91.787323, 23.04576111], [91.78747559, 23.04211426], [91.78697968, 23.04027748], [91.78703308, 23.0366497], [91.78588867, 23.0335083], [91.78509521, 23.03167725], [91.78378296, 23.03154945], [91.7833252, 23.03149414], [91.78051758, 23.03112793], [91.78037262, 23.03139305], [91.78033447, 23.03100586], [91.7804184, 23.03071594], [91.78050995, 23.03046036], [91.78054047, 23.03011513], [91.78059387, 23.02968788], [91.78055573, 23.02935028], [91.78050232, 23.02921867], [91.78043365, 23.02919006], [91.78035736, 23.02913475], [91.78028107, 23.02897263], [91.78012085, 23.02878761], [91.77999878, 23.02867126], [91.77971649, 23.02853775], [91.77961731, 23.02847099], [91.7794342, 23.02839088], [91.77911377, 23.02820587], [91.77898407, 23.0281353], [91.77884674, 23.02809525], [91.77843475, 23.02791786], [91.77739716, 23.02748299], [91.77714539, 23.02737427], [91.77700043, 23.02731895], [91.77689362, 23.02730942], [91.77661133, 23.02721024], [91.77637482, 23.02706718], [91.77618408, 23.02703667], [91.77584076, 23.02700043], [91.775383, 23.02701187], [91.77468109, 23.02700996], [91.77423859, 23.02725029], [91.7738266, 23.02767372], [91.77365875, 23.02795792], [91.77353668, 23.02821922], [91.77337646, 23.02897644], [91.77313995, 23.02933884], [91.77302551, 23.02966499], [91.77297211, 23.02982903], [91.77296448, 23.03003502], [91.77287292, 23.03041077], [91.77282715, 23.03088951], [91.77289581, 23.03104782], [91.77294159, 23.03148079], [91.772789, 23.03186035], [91.77278137, 23.03224945], [91.77285004, 23.03273201], [91.77282715, 23.03308105], [91.77297974, 23.03349113], [91.77308655, 23.03383064], [91.77310181, 23.03400803], [91.77325439, 23.03453445], [91.77333069, 23.03469467], [91.77326202, 23.03483582], [91.77333832, 23.03493881], [91.77331543, 23.03504372], [91.77336121, 23.03520966], [91.77361298, 23.03604317], [91.77393341, 23.03678703], [91.77410889, 23.0369606], [91.77407837, 23.03712845], [91.77412415, 23.0372448], [91.77121735, 23.03679466], [91.77078247, 23.03613281], [91.77096558, 23.03587151], [91.77111816, 23.03559303], [91.77159882, 23.03480148], [91.77184296, 23.034235], [91.77191925, 23.03398705], [91.77200317, 23.03347397], [91.77197266, 23.03336143], [91.77185822, 23.03320122], [91.77165222, 23.03309631], [91.77149963, 23.03299904], [91.77085114, 23.03301048], [91.77030945, 23.03299713], [91.76996613, 23.0330925], [91.76969147, 23.03324318], [91.76947021, 23.03354073], [91.76921082, 23.03373337], [91.76908112, 23.03382683], [91.76874542, 23.03404427], [91.76835632, 23.03433228], [91.7681427, 23.03440094], [91.76804352, 23.0343132], [91.76789856, 23.03416061], [91.76766968, 23.03389549], [91.76750183, 23.03381348], [91.76738739, 23.03373337], [91.76722717, 23.0335865], [91.76698303, 23.03340721], [91.7668457, 23.03320885], [91.76662445, 23.03303719], [91.76641083, 23.03280449], [91.76609039, 23.03248215], [91.76571655, 23.03205872], [91.76557922, 23.03191566], [91.7654953, 23.03187943], [91.76539612, 23.031847], [91.7647934, 23.03133583], [91.76439667, 23.03107071], [91.76408386, 23.03091812], [91.76354218, 23.0308342], [91.76314545, 23.03074074], [91.76271057, 23.03068352], [91.76168823, 23.03046417], [91.76102448, 23.02999115], [91.76093292, 23.02973747], [91.76092529, 23.02952194], [91.76099396, 23.02941322], [91.76099396, 23.0292244], [91.7613678, 23.02764702], [91.76143646, 23.02740479], [91.76146698, 23.02677536], [91.76147461, 23.02653122], [91.76141357, 23.02634811], [91.76098633, 23.02582169], [91.76028442, 23.02503204], [91.75994873, 23.02482605], [91.75938416, 23.02461624], [91.7591095, 23.02461433], [91.75774384, 23.02457809], [91.75748444, 23.02454185], [91.75782013, 23.02117348], [91.75799561, 23.02068138], [91.75804138, 23.02031326], [91.75811005, 23.01990318], [91.75608826, 23.01569366], [91.75603485, 23.01563263], [91.75109863, 23.0100708], [91.74627686, 23.00671387], [91.74572754, 23.00628662], [91.74169159, 23.00514412], [91.74156952, 23.00512123], [91.73931885, 23.00466919], [91.73924255, 23.00463676], [91.73896027, 23.00446701], [91.73370361, 23.00128174], [91.72894287, 22.99755096], [91.72808838, 22.99688721], [91.72747803, 22.99487305], [91.72737122, 22.99454117], [91.72711182, 22.99371338], [91.72690582, 22.99263191], [91.72607422, 22.9899292], [91.7258606, 22.98957825], [91.72570801, 22.98940849], [91.72559357, 22.98927689], [91.72403717, 22.9887104], [91.72342682, 22.98965645], [91.72241974, 22.98929024], [91.72145081, 22.98884583], [91.72132111, 22.98835754], [91.72123718, 22.98820877], [91.721138, 22.98806381], [91.72083282, 22.98778152], [91.72052765, 22.98755074], [91.7203064, 22.98746109], [91.720047, 22.9873867], [91.71977997, 22.98727989], [91.71931458, 22.98713684], [91.71878052, 22.98690605], [91.71845245, 22.98680878], [91.71831512, 22.9867363], [91.71810913, 22.98671913], [91.7175293, 22.98674583], [91.71697235, 22.9867878], [91.71656799, 22.98686218], [91.71624756, 22.98697472], [91.71560669, 22.98726463], [91.71476746, 22.98766708], [91.71440887, 22.98785973], [91.71414948, 22.98808098], [91.71360779, 22.98840714], [91.71337891, 22.988554], [91.71321106, 22.98861504], [91.71310425, 22.98869514]], [[91.81077576, 24.21705437], [91.81054688, 24.21708298], [91.81060791, 24.21698761], [91.81077576, 24.21705437]], [[91.7907486, 23.22552681], [91.79064941, 23.22492409], [91.79076385, 23.22495079], [91.79089355, 23.22505379], [91.79090118, 23.22515869], [91.7908783, 23.22524452], [91.79083252, 23.22538567], [91.7907486, 23.22552681]], [[91.16204834, 23.66392899], [91.16113281, 23.66510391], [91.16120148, 23.66400528], [91.16162109, 23.66396713], [91.16204834, 23.66392899]], [[91.16082764, 23.66613579], [91.16074371, 23.66648483], [91.16066742, 23.66646576], [91.16074371, 23.66613197], [91.16082764, 23.66613579]], [[91.87788391, 24.15058136], [91.8777771, 24.15035439], [91.87781525, 24.15028954], [91.87789917, 24.15027237], [91.87791443, 24.150383], [91.87788391, 24.15058136]], [[91.57254791, 24.07493782], [91.57284546, 24.07489777], [91.57288361, 24.07507896], [91.57254791, 24.07493782]]], [[[91.74414063, 24.24369812], [91.74346924, 24.24712753], [91.74507141, 24.24641228], [91.74497986, 24.24634171], [91.74488068, 24.24621201], [91.7448349, 24.24607849], [91.74471283, 24.24596405], [91.74469757, 24.24586296], [91.74469757, 24.24570656], [91.74472046, 24.24559402], [91.7447052, 24.2454834], [91.74468994, 24.24539948], [91.74466705, 24.24531746], [91.74467468, 24.24522018], [91.74464417, 24.24511147], [91.74462891, 24.24501419], [91.7445755, 24.2447567], [91.74449921, 24.24452591], [91.7443924, 24.2442379], [91.74424744, 24.24390221], [91.74414063, 24.24369812]]]]}}, {\\\"id\\\": \\\"31\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.34_1\\\", \\\"HASC_1\\\": \\\"IN.UP\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Uttar Pradesh\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"United Provinces\\\", \\\"apm25_popweighted\\\": 87.7, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1130.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 2092.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3222.0, \\\"geo-id\\\": 31, \\\"hpm25_child_popweighted\\\": 288.8, \\\"hpm25_female_popweighted\\\": 332.0, \\\"hpm25_male_popweighted\\\": 239.0, \\\"location\\\": \\\"Uttar Pradesh\\\", \\\"mort_apm25_6cod_mean_total\\\": 77890.0, \\\"mort_hpm25_6cod_mean_total\\\": 144881.0, \\\"mort_tpm25_6cod_mean_total\\\": 222771.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[77.70540619, 26.88027954], [77.69773102, 26.8800106], [77.69637299, 26.87659073], [77.69371796, 26.87289047], [77.68937683, 26.87347031], [77.68636322, 26.87832069], [77.68235016, 26.87916946], [77.67835236, 26.87832069], [77.67468262, 26.87462997], [77.67166901, 26.87407112], [77.66697693, 26.86238289], [77.66462708, 26.85984039], [77.65730286, 26.85641098], [77.62487793, 26.84674835], [77.61620331, 26.84847069], [77.61319733, 26.84446907], [77.61186218, 26.83964157], [77.60853577, 26.8345108], [77.60450745, 26.83280182], [77.60083771, 26.83423042], [77.60016632, 26.84250069], [77.59615326, 26.84165192], [77.5881424, 26.83337975], [77.57746887, 26.83310127], [77.57211304, 26.83196068], [77.5687561, 26.82741165], [77.56476593, 26.82456017], [77.55641937, 26.82199097], [77.54740906, 26.82172012], [77.5357132, 26.82542992], [77.52838135, 26.8245697], [77.52069092, 26.82200813], [77.51435852, 26.8245697], [77.5120163, 26.82798958], [77.51233673, 26.83826065], [77.51535034, 26.84140015], [77.51367188, 26.84510231], [77.50666809, 26.84738159], [77.50197601, 26.84653091], [77.49797821, 26.84794998], [77.49698639, 26.83797073], [77.48932648, 26.80861092], [77.48664856, 26.80120087], [77.48232269, 26.7940712], [77.48098755, 26.78779984], [77.48432159, 26.78239059], [77.48932648, 26.77724838], [77.49668884, 26.77411079], [77.49334717, 26.76699066], [77.48635864, 26.76101112], [77.48036194, 26.75387955], [77.44831085, 26.74674988], [77.45730591, 26.76214027], [77.46166992, 26.76584816], [77.46431732, 26.76955032], [77.45597076, 26.78038025], [77.45095062, 26.78067017], [77.44528198, 26.77753067], [77.43894196, 26.77581024], [77.43428802, 26.77239037], [77.4285965, 26.77011108], [77.42726898, 26.77609253], [77.42858887, 26.78578949], [77.43192291, 26.79235077], [77.43824005, 26.80887985], [77.43921661, 26.81915092], [77.43421173, 26.82541084], [77.42719269, 26.8316803], [77.42584991, 26.83567047], [77.4228363, 26.83680916], [77.4174881, 26.8427906], [77.4214859, 26.84877968], [77.42616272, 26.85305977], [77.42347717, 26.85762024], [77.42247009, 26.86701965], [77.42648315, 26.8670311], [77.4318161, 26.8658905], [77.43650818, 26.8678875], [77.44182587, 26.87759018], [77.45052338, 26.87501144], [77.45417786, 26.8767395], [77.455513, 26.88043976], [77.45517731, 26.8895607], [77.46478271, 26.89266014], [77.47377777, 26.89978981], [77.48246765, 26.90377998], [77.49584198, 26.90578079], [77.51856995, 26.91547966], [77.5453186, 26.92204094], [77.55735779, 26.92603111], [77.57975006, 26.93087006], [77.5847702, 26.94227028], [77.58744812, 26.94454956], [77.59176636, 26.94398117], [77.59379578, 26.93770981], [77.59812927, 26.94026947], [77.60482788, 26.94595909], [77.64227295, 26.96730042], [77.64894104, 26.9738102], [77.65260315, 26.97494125], [77.65660858, 26.97406006], [77.65960693, 26.96808052], [77.66529846, 26.96692085], [77.66861725, 26.96917915], [77.67028046, 26.97710991], [77.69191742, 26.97899246], [77.70123291, 26.98431969], [77.70992279, 26.98769951], [77.71459198, 26.99166107], [77.72328186, 26.98823929], [77.73634338, 26.98822021], [77.73900604, 26.99106026], [77.73969269, 26.9979496], [77.74336243, 26.99765968], [77.74771118, 26.99850082], [77.74607849, 27.00294113], [77.74246216, 27.00570107], [77.74254608, 27.00634956], [77.74546051, 27.00868988], [77.74616241, 27.01086044], [77.74529266, 27.01336098], [77.74768066, 27.01762962], [77.75501251, 27.02276039], [77.75311279, 27.02363014], [77.74389648, 27.02374077], [77.74085236, 27.02552032], [77.73935699, 27.0275898], [77.73840332, 27.03268051], [77.7355423, 27.033741], [77.72648621, 27.03153992], [77.72216034, 27.02614021], [77.7201767, 27.01404953], [77.72104645, 27.00570107], [77.72336578, 27.00390816], [77.72231293, 27.00033951], [77.71761322, 27.00002098], [77.71392059, 26.99796104], [77.70858002, 27.00110245], [77.70358276, 27.0003109], [77.69896698, 27.0057106], [77.69661713, 27.00695038], [77.69567108, 27.01605034], [77.69374084, 27.01951981], [77.68202209, 27.03294182], [77.68486023, 27.0398407], [77.68430328, 27.04491997], [77.67816925, 27.05052948], [77.67331696, 27.05155945], [77.67076874, 27.0489006], [77.66329956, 27.03030968], [77.6598587, 27.02503967], [77.6570282, 27.02273178], [77.65196991, 27.02257919], [77.64334106, 27.02719116], [77.63426208, 27.02701187], [77.63092041, 27.0234108], [77.62740326, 27.01550102], [77.62425232, 27.01689911], [77.62201691, 27.02186966], [77.61949921, 27.02490807], [77.61559296, 27.02739906], [77.6034317, 27.02909279], [77.59881592, 27.02882957], [77.5943222, 27.03119087], [77.59059143, 27.03166008], [77.58875275, 27.03705978], [77.58392334, 27.03931999], [77.57509613, 27.04157066], [77.56820679, 27.03932953], [77.56067657, 27.03565025], [77.55739594, 27.03689957], [77.55893707, 27.04878998], [77.56112671, 27.05157089], [77.56523895, 27.05397987], [77.56680298, 27.06026077], [77.56694031, 27.06632042], [77.56572723, 27.06903076], [77.5684433, 27.07248116], [77.56568146, 27.07801056], [77.56324005, 27.07862282], [77.55422974, 27.07722092], [77.54631805, 27.08073044], [77.54139709, 27.07739067], [77.53366089, 27.06981087], [77.52915955, 27.06711006], [77.52654266, 27.06650925], [77.52136993, 27.0672226], [77.51429749, 27.07042122], [77.51468658, 27.07406044], [77.51773834, 27.0797596], [77.51822662, 27.0880928], [77.51738739, 27.08949089], [77.51377869, 27.09137917], [77.51474762, 27.09189987], [77.51100159, 27.09391975], [77.49938965, 27.09398079], [77.49841309, 27.09519005], [77.49903107, 27.09584045], [77.50231934, 27.09922028], [77.50821686, 27.1028595], [77.51383972, 27.10808945], [77.52082062, 27.1058197], [77.52937317, 27.10414124], [77.53209686, 27.10968971], [77.53948212, 27.11125946], [77.54444885, 27.11560059], [77.54576874, 27.11512947], [77.55612183, 27.11581993], [77.57466888, 27.1221199], [77.58342743, 27.12068176], [77.58587646, 27.12424088], [77.59078217, 27.12308121], [77.59567261, 27.12615967], [77.59726715, 27.12905121], [77.59455109, 27.13368034], [77.59591675, 27.13721085], [77.59239197, 27.14011955], [77.59210968, 27.14476967], [77.59365845, 27.14795113], [77.59807587, 27.14800072], [77.60653687, 27.15414047], [77.6059494, 27.15890121], [77.60407257, 27.16431999], [77.6051178, 27.16847992], [77.61480713, 27.17478943], [77.62252045, 27.1749897], [77.6254425, 27.17436028], [77.6282959, 27.17312241], [77.63079834, 27.17020988], [77.63591766, 27.17012978], [77.64334106, 27.17440033], [77.65461731, 27.17558098], [77.66124725, 27.18278122], [77.6654129, 27.1861496], [77.67199707, 27.19506073], [77.67299652, 27.20036125], [77.66719055, 27.20709991], [77.65664673, 27.21302032], [77.65500641, 27.21178055], [77.64778137, 27.21454811], [77.64202881, 27.21476936], [77.63951874, 27.2172718], [77.6394577, 27.22323036], [77.64318085, 27.23180962], [77.64420319, 27.23887825], [77.63839722, 27.24065018], [77.63800812, 27.24253845], [77.63913727, 27.24712944], [77.63890839, 27.24714088], [77.6342392, 27.25368118], [77.62957764, 27.25549126], [77.62581635, 27.26234055], [77.62329865, 27.26382065], [77.61284637, 27.26030159], [77.60900116, 27.2650795], [77.60661316, 27.2727108], [77.61125183, 27.27433968], [77.61414337, 27.27916145], [77.60935211, 27.28166962], [77.60909271, 27.28799057], [77.60307312, 27.29487991], [77.59832764, 27.29635048], [77.59166718, 27.30055809], [77.59172821, 27.30273056], [77.59702301, 27.30470085], [77.6000824, 27.30470085], [77.603302, 27.30992126], [77.60887909, 27.3119297], [77.6135025, 27.31476021], [77.61553192, 27.32541084], [77.61559296, 27.33453941], [77.61634064, 27.33831024], [77.61411285, 27.34338951], [77.61036682, 27.34439278], [77.60753632, 27.34215927], [77.60481262, 27.33794975], [77.5929718, 27.3379612], [77.58661652, 27.33527184], [77.58229828, 27.33163071], [77.58043671, 27.32845116], [77.57454681, 27.32673073], [77.57273865, 27.33008957], [77.56777191, 27.33323097], [77.56671906, 27.33361053], [77.56173706, 27.33543968], [77.5427475, 27.34242821], [77.5404129, 27.34758949], [77.53909302, 27.35307121], [77.53539276, 27.35293961], [77.53074646, 27.35276985], [77.52200317, 27.35763931], [77.51567841, 27.36273003], [77.50936127, 27.36782074], [77.50802612, 27.37278175], [77.50385284, 27.37405968], [77.50219727, 27.37735939], [77.49724579, 27.38136292], [77.48696136, 27.38562965], [77.47586823, 27.38772964], [77.46660614, 27.3842907], [77.461586, 27.38759041], [77.44326019, 27.39332962], [77.43578339, 27.39678955], [77.4318924, 27.39915848], [77.4295578, 27.4043808], [77.42999268, 27.4050293], [77.42677307, 27.41661072], [77.42508698, 27.41887283], [77.41517639, 27.42537117], [77.41703033, 27.43824005], [77.41828156, 27.4421711], [77.42073059, 27.44729042], [77.42295074, 27.44943047], [77.42727661, 27.45100975], [77.42878723, 27.45545959], [77.42959595, 27.46204948], [77.42543793, 27.46480942], [77.41545105, 27.46614075], [77.41136932, 27.47269058], [77.40738678, 27.47636986], [77.39642334, 27.47780991], [77.39359283, 27.48194122], [77.39234924, 27.48610115], [77.39155579, 27.49356079], [77.39202881, 27.50204277], [77.38955688, 27.50542259], [77.38326263, 27.51148987], [77.38241577, 27.51655006], [77.37619019, 27.51860046], [77.36122894, 27.51851082], [77.35816956, 27.51947975], [77.35222626, 27.51997948], [77.34026337, 27.52477264], [77.33513641, 27.53002167], [77.33252716, 27.53854942], [77.33545685, 27.54170036], [77.34015656, 27.54673958], [77.33843994, 27.54964256], [77.33357239, 27.55459023], [77.33067322, 27.56375122], [77.33120728, 27.56862831], [77.33039856, 27.57110977], [77.33109283, 27.57344055], [77.33306122, 27.57604027], [77.33838654, 27.57660294], [77.3434906, 27.58550262], [77.3483963, 27.59012032], [77.35011292, 27.59340096], [77.33516693, 27.60153008], [77.32811737, 27.59604073], [77.32578278, 27.59687805], [77.31121063, 27.61169052], [77.31321716, 27.61732101], [77.33233643, 27.6377697], [77.3423233, 27.6530304], [77.34276581, 27.65720177], [77.33934784, 27.66242027], [77.33716583, 27.6696701], [77.33746338, 27.67580986], [77.33500671, 27.68142128], [77.33679199, 27.68546295], [77.33654785, 27.69618034], [77.33444214, 27.69948959], [77.3339386, 27.70792007], [77.33053589, 27.71113968], [77.32447815, 27.71319008], [77.32034302, 27.71268272], [77.31725311, 27.71124077], [77.30845642, 27.71390915], [77.30235291, 27.71321106], [77.29760742, 27.71868134], [77.29634094, 27.72982979], [77.31067657, 27.73686981], [77.31233215, 27.73867989], [77.31210327, 27.74017143], [77.30966949, 27.74278831], [77.30599976, 27.74469948], [77.305336, 27.74922943], [77.30134583, 27.75645828], [77.30169678, 27.76006126], [77.30280304, 27.76119041], [77.30296326, 27.76465034], [77.30152893, 27.76896095], [77.3014679, 27.77170944], [77.30368805, 27.77598], [77.30414581, 27.78800964], [77.30110931, 27.79368019], [77.29794312, 27.79785919], [77.29538727, 27.79984093], [77.29064178, 27.80170059], [77.27932739, 27.80280113], [77.27577972, 27.80654907], [77.27707672, 27.80673981], [77.27934265, 27.8119812], [77.28347778, 27.81591988], [77.28970337, 27.81783295], [77.29062653, 27.81970978], [77.28888702, 27.82913971], [77.29915619, 27.83138275], [77.3048172, 27.83123016], [77.30632019, 27.83200073], [77.31292725, 27.83005142], [77.31719208, 27.83324051], [77.32211304, 27.83472061], [77.32733154, 27.83772087], [77.32406616, 27.8408699], [77.32924652, 27.85198975], [77.33120728, 27.85268021], [77.33265686, 27.85489082], [77.33933258, 27.85959053], [77.34406281, 27.85898972], [77.35264587, 27.8564415], [77.36483002, 27.86059189], [77.37001038, 27.86313057], [77.37388611, 27.86370277], [77.38208008, 27.86309052], [77.39282227, 27.85894966], [77.40377808, 27.85824013], [77.41239166, 27.85907173], [77.41442108, 27.86069107], [77.41369629, 27.86260033], [77.40629578, 27.86967087], [77.40512848, 27.87174988], [77.40453339, 27.8758297], [77.40155029, 27.88190079], [77.40409088, 27.88661003], [77.40709686, 27.88912964], [77.41104126, 27.89501953], [77.41229248, 27.89615822], [77.41423035, 27.89652061], [77.42220306, 27.89447975], [77.430336, 27.88884163], [77.44219971, 27.87848091], [77.44584656, 27.87840843], [77.45848846, 27.88529968], [77.46981812, 27.89472961], [77.4724884, 27.90120125], [77.474617, 27.91206169], [77.47245026, 27.9192009], [77.47086334, 27.92061043], [77.47059631, 27.92789268], [77.46845245, 27.93188095], [77.46872711, 27.93291092], [77.47766113, 27.94021034], [77.48474884, 27.94391251], [77.48796082, 27.94145012], [77.49060059, 27.93394852], [77.49225616, 27.93180847], [77.49537659, 27.93077087], [77.49777985, 27.93141174], [77.50585938, 27.93614006], [77.51116943, 27.9374218], [77.5137558, 27.93634033], [77.51921082, 27.93188095], [77.53137207, 27.94181824], [77.53613281, 27.94930267], [77.53733826, 27.95776939], [77.53591919, 27.96554947], [77.52900696, 27.96624947], [77.51502991, 27.9654808], [77.51059723, 27.96820831], [77.50958252, 27.97333145], [77.51344299, 27.97743988], [77.52667999, 27.98402023], [77.53215027, 27.98884964], [77.53521729, 27.99333], [77.52011108, 28.00654984], [77.5118866, 28.01025009], [77.50937653, 28.01772118], [77.50652313, 28.02234077], [77.50177002, 28.02737999], [77.49743652, 28.03063965], [77.49517059, 28.03429985], [77.48970795, 28.0393219], [77.47911072, 28.04416275], [77.47763824, 28.04910088], [77.48284912, 28.05764961], [77.48287201, 28.0589447], [77.48290253, 28.06071091], [77.47683716, 28.07331276], [77.47173309, 28.07875061], [77.47001648, 28.0837307], [77.46887207, 28.08601189], [77.47306824, 28.10371971], [77.47479248, 28.10428047], [77.47823334, 28.10797119], [77.48278046, 28.10785294], [77.48602295, 28.09739113], [77.49014282, 28.09529114], [77.49230957, 28.09801102], [77.49373627, 28.10227013], [77.49324036, 28.10817909], [77.49137115, 28.11271095], [77.49939728, 28.12259102], [77.49964142, 28.12735939], [77.49846649, 28.1356926], [77.48796082, 28.13878059], [77.48725128, 28.14143181], [77.48986816, 28.14438057], [77.49529266, 28.14581108], [77.49636841, 28.15987015], [77.498909, 28.16300964], [77.51159668, 28.16489029], [77.5317688, 28.17025948], [77.54236603, 28.1816597], [77.53794861, 28.19089127], [77.53018951, 28.1929493], [77.52082062, 28.19174004], [77.50566101, 28.19547081], [77.50151825, 28.18719101], [77.49211884, 28.18510056], [77.49061584, 28.19305992], [77.48912048, 28.21199036], [77.49759674, 28.21302032], [77.51056671, 28.20633125], [77.51281738, 28.20168114], [77.51911926, 28.20178032], [77.52327728, 28.20717049], [77.52157593, 28.21739006], [77.51703644, 28.22138977], [77.51557922, 28.22976112], [77.53562164, 28.24052048], [77.54120636, 28.2477417], [77.53878021, 28.25440979], [77.52501678, 28.25342941], [77.51225281, 28.25432968], [77.51159668, 28.25455093], [77.51062012, 28.25489044], [77.50206757, 28.25784111], [77.48707581, 28.26176071], [77.46730042, 28.26972008], [77.46481323, 28.27742958], [77.47225189, 28.28120995], [77.48808289, 28.27911949], [77.49273682, 28.28063011], [77.49476624, 28.29261017], [77.49417114, 28.30026054], [77.49578857, 28.30704117], [77.4818573, 28.32361984], [77.47355652, 28.32788086], [77.46592712, 28.33394051], [77.46375275, 28.33801079], [77.46640778, 28.34120941], [77.48517609, 28.35021019], [77.49423981, 28.35826111], [77.4920578, 28.36952019], [77.48589325, 28.37970161], [77.46953583, 28.39430046], [77.46684265, 28.39968109], [77.47386169, 28.40381241], [77.47455597, 28.41351128], [77.46869659, 28.41753006], [77.45610046, 28.42098808], [77.45147705, 28.42485809], [77.44399261, 28.42897034], [77.43599701, 28.43161011], [77.42829895, 28.44406128], [77.42578125, 28.45454025], [77.4181366, 28.45578957], [77.40828705, 28.45560074], [77.39779663, 28.45864105], [77.39483643, 28.46279907], [77.40003204, 28.4666996], [77.39789581, 28.47117043], [77.38816833, 28.47281837], [77.37600708, 28.47616005], [77.36936188, 28.4806881], [77.36412048, 28.48565102], [77.36396027, 28.49290085], [77.36048126, 28.49785995], [77.34319305, 28.50361061], [77.33773804, 28.50897026], [77.33682251, 28.51568031], [77.33396912, 28.52070236], [77.330513, 28.52410126], [77.32151031, 28.53585052], [77.314888, 28.54149055], [77.31069946, 28.54368973], [77.30306244, 28.55045128], [77.2951889, 28.5612011], [77.29380035, 28.5667305], [77.29364777, 28.57971954], [77.29490662, 28.58242989], [77.30713654, 28.59691048], [77.30992126, 28.59896088], [77.31694031, 28.59996033], [77.32784271, 28.60488129], [77.33315277, 28.60671234], [77.33618164, 28.60886955], [77.33753204, 28.61749268], [77.33708191, 28.62190056], [77.33422089, 28.62699127], [77.33045959, 28.6314106], [77.32095337, 28.63602066], [77.31358337, 28.64320183], [77.31121063, 28.64464188], [77.31307983, 28.64666939], [77.31533051, 28.651371], [77.31542969, 28.66327095], [77.31756592, 28.67161942], [77.31791687, 28.67934036], [77.32538605, 28.68250275], [77.32713318, 28.68515968], [77.32758331, 28.69184113], [77.32092285, 28.69967079], [77.31983948, 28.70364189], [77.32167816, 28.71183014], [77.32348633, 28.71587181], [77.31716156, 28.71722031], [77.30622101, 28.71767044], [77.30146027, 28.71673012], [77.29563141, 28.7130394], [77.29294586, 28.7097702], [77.28489685, 28.71245956], [77.28365326, 28.7189827], [77.2844162, 28.72393036], [77.28069305, 28.73002052], [77.2768631, 28.7343998], [77.27111816, 28.7381897], [77.26637268, 28.7392807], [77.25991821, 28.73812294], [77.25617218, 28.73991966], [77.25187683, 28.74550056], [77.25319672, 28.75279045], [77.24846649, 28.75753021], [77.24585724, 28.75735092], [77.23799133, 28.75922012], [77.22904205, 28.77243805], [77.22090912, 28.7779007], [77.21710205, 28.78168106], [77.22206879, 28.783741], [77.22467804, 28.78762817], [77.21826935, 28.78762817], [77.21305084, 28.7864399], [77.20845032, 28.78718948], [77.20269012, 28.78940964], [77.1969223, 28.79528046], [77.19444275, 28.80229187], [77.1946106, 28.81536293], [77.21364594, 28.81349945], [77.2173233, 28.83527946], [77.21061707, 28.84529114], [77.21147156, 28.85493088], [77.20783234, 28.86021996], [77.20479584, 28.86291122], [77.199646, 28.86494064], [77.19348907, 28.86535072], [77.18686676, 28.86681938], [77.18318939, 28.87177086], [77.17829132, 28.88004112], [77.17803955, 28.8855629], [77.18177032, 28.88980103], [77.19909668, 28.89268112], [77.20530701, 28.89460945], [77.21687317, 28.90034294], [77.22119141, 28.90413284], [77.22149658, 28.90813065], [77.21602631, 28.91143036], [77.20204926, 28.91555977], [77.19676971, 28.92093086], [77.20536804, 28.93646049], [77.204422, 28.93997955], [77.19078827, 28.94686127], [77.19013977, 28.95566177], [77.19095612, 28.96165085], [77.20375061, 28.9822998], [77.20790863, 28.99106026], [77.21418762, 29.00596046], [77.21404266, 29.00669098], [77.21113586, 29.01138115], [77.20379639, 29.01671982], [77.19159698, 29.02129173], [77.1765213, 29.03647041], [77.1626358, 29.04857063], [77.16163635, 29.05244064], [77.162323, 29.06537247], [77.15718842, 29.07753181], [77.14929962, 29.08324051], [77.14160156, 29.08681107], [77.13176727, 29.09464836], [77.12438202, 29.10148811], [77.12204742, 29.1057682], [77.12441254, 29.11346054], [77.13620758, 29.12784004], [77.13858032, 29.13476944], [77.12661743, 29.15402031], [77.12734222, 29.16291046], [77.13240814, 29.17181015], [77.13999176, 29.18208122], [77.13813782, 29.20106125], [77.1361618, 29.20745087], [77.13262939, 29.21311951], [77.12770081, 29.21842003], [77.12522125, 29.22487068], [77.12722015, 29.22814178], [77.14279938, 29.23779106], [77.14402008, 29.24333191], [77.14247894, 29.25160027], [77.13498688, 29.26649284], [77.12948608, 29.27279091], [77.13761902, 29.28746986], [77.14437103, 29.2961998], [77.1423111, 29.30151176], [77.15421295, 29.31692123], [77.1536026, 29.3222599], [77.15104675, 29.32551956], [77.15001678, 29.33169174], [77.15394592, 29.33547974], [77.1518631, 29.33929062], [77.14644623, 29.34506035], [77.12757874, 29.34433937], [77.12368774, 29.34498978], [77.12003326, 29.34979057], [77.11752319, 29.35715103], [77.11884308, 29.36195946], [77.11669922, 29.37257957], [77.11694336, 29.37668037], [77.12046814, 29.37877083], [77.13105011, 29.38070107], [77.13864899, 29.38390923], [77.14679718, 29.38977051], [77.14597321, 29.39248085], [77.14006805, 29.39472008], [77.133461, 29.39843941], [77.12908936, 29.40249062], [77.12586975, 29.41064072], [77.12487793, 29.42217064], [77.13577271, 29.43222046], [77.13845062, 29.43686295], [77.13938904, 29.44210052], [77.13774872, 29.44659042], [77.1319809, 29.45049095], [77.12413788, 29.45294189], [77.117836, 29.45646095], [77.11429596, 29.46186066], [77.1140213, 29.47029114], [77.115448, 29.47540283], [77.12039185, 29.48006058], [77.12332153, 29.4860611], [77.11989594, 29.49732971], [77.11451721, 29.50315857], [77.10340881, 29.50954056], [77.09761047, 29.51201248], [77.08648682, 29.52826118], [77.08490753, 29.53359032], [77.08622742, 29.53949928], [77.0894165, 29.54469109], [77.09529877, 29.54764938], [77.10443115, 29.54891014], [77.10971832, 29.55298996], [77.10675812, 29.56636047], [77.10198212, 29.57699966], [77.09378052, 29.5872097], [77.08989716, 29.59043121], [77.08680725, 29.59646988], [77.08561707, 29.60079956], [77.09218597, 29.60867119], [77.09388733, 29.61297035], [77.0945282, 29.61776924], [77.10047913, 29.62227249], [77.10160065, 29.62491989], [77.10106659, 29.63307953], [77.10489655, 29.63557816], [77.10782623, 29.63996124], [77.10970306, 29.64723969], [77.12180328, 29.65353966], [77.12941742, 29.65859032], [77.13130188, 29.66299057], [77.13114166, 29.66634941], [77.11997986, 29.6802597], [77.11917114, 29.68584061], [77.12110138, 29.69156075], [77.12552643, 29.69691086], [77.13218689, 29.69948006], [77.13987732, 29.70022964], [77.14260101, 29.70163918], [77.14332581, 29.70597076], [77.14021301, 29.7172718], [77.12255859, 29.73603821], [77.12256622, 29.74282074], [77.11515808, 29.74496078], [77.11295319, 29.74860001], [77.11421967, 29.75429153], [77.11785889, 29.76043129], [77.11889648, 29.76422119], [77.11704254, 29.77090073], [77.11828613, 29.77555084], [77.12349701, 29.7778492], [77.13199615, 29.77898026], [77.13743591, 29.78220177], [77.14222717, 29.78757095], [77.1523819, 29.79327965], [77.15400696, 29.79768944], [77.15171814, 29.80347061], [77.15209961, 29.80766106], [77.15396881, 29.81378174], [77.15564728, 29.81678963], [77.16526794, 29.82448959], [77.16903687, 29.82958031], [77.16703796, 29.84370995], [77.16758728, 29.84638977], [77.17810822, 29.86215973], [77.18006134, 29.86914063], [77.18245697, 29.87327957], [77.18229675, 29.88158989], [77.18496704, 29.89030838], [77.1848526, 29.89490128], [77.1795578, 29.90226936], [77.18016815, 29.90621185], [77.18591309, 29.91305161], [77.18689728, 29.91748047], [77.18913269, 29.92204285], [77.1955719, 29.92727089], [77.20256805, 29.9310894], [77.21112823, 29.94071007], [77.22373962, 29.95475006], [77.22489929, 29.95858955], [77.22957611, 29.96190262], [77.23194885, 29.96632195], [77.23310852, 29.97363091], [77.23548126, 29.98117256], [77.25047302, 29.988451], [77.25476074, 29.99316025], [77.25512695, 29.99596977], [77.26316071, 30.00214958], [77.26154327, 30.00561905], [77.26191711, 30.0073204], [77.26434326, 30.01305962], [77.26544189, 30.01803017], [77.26759338, 30.02210999], [77.26969147, 30.02746964], [77.27313995, 30.03404045], [77.27176666, 30.03991127], [77.2698822, 30.04422951], [77.27040863, 30.04833984], [77.27625275, 30.05047035], [77.2804184, 30.05251122], [77.28610992, 30.0574894], [77.29184723, 30.05849075], [77.29759216, 30.0603199], [77.30290985, 30.06058121], [77.31291199, 30.06053925], [77.32480621, 30.06180191], [77.33174133, 30.06445122], [77.33716583, 30.06824112], [77.34842682, 30.0766983], [77.35697937, 30.08415031], [77.36849976, 30.09155846], [77.37342834, 30.09301949], [77.38034058, 30.09304047], [77.39245605, 30.09441185], [77.39673615, 30.09576035], [77.40857697, 30.10255241], [77.41442871, 30.10713005], [77.4141922, 30.11111069], [77.41008759, 30.11108971], [77.40603638, 30.11130905], [77.40061188, 30.11326027], [77.39800262, 30.11872292], [77.40326691, 30.12105942], [77.40865326, 30.12320137], [77.41261292, 30.12771034], [77.41552734, 30.13349915], [77.41783905, 30.14118195], [77.41490173, 30.1434803], [77.41082764, 30.14587975], [77.41142273, 30.14969063], [77.41532135, 30.1566906], [77.42354584, 30.16847992], [77.43061066, 30.16642952], [77.43517303, 30.16995811], [77.44033813, 30.16920853], [77.44684601, 30.16860962], [77.45153809, 30.17362976], [77.45598602, 30.18096161], [77.46021271, 30.1837883], [77.4732666, 30.188591], [77.47677612, 30.19501114], [77.47997284, 30.20215988], [77.48390198, 30.2100811], [77.48853302, 30.21874046], [77.49372101, 30.2274704], [77.49598694, 30.23363113], [77.50550842, 30.24224091], [77.51983643, 30.26013184], [77.52250671, 30.26619911], [77.52468109, 30.2779808], [77.52677917, 30.28231239], [77.53218079, 30.2868576], [77.54042053, 30.29096985], [77.5453186, 30.29413986], [77.55577087, 30.30257034], [77.56355286, 30.30608177], [77.57035065, 30.31122971], [77.5738678, 30.3189106], [77.57501221, 30.32607079], [77.57009888, 30.3315506], [77.56989288, 30.33711052], [77.57463074, 30.34695053], [77.58278656, 30.35843849], [77.59201813, 30.37086105], [77.59012604, 30.37726021], [77.58444214, 30.38136101], [77.57489014, 30.38451958], [77.57615662, 30.38989067], [77.57292175, 30.3930912], [77.56785583, 30.39875984], [77.56305695, 30.40448952], [77.56710815, 30.40484047], [77.56858826, 30.40682983], [77.56958008, 30.40789986], [77.57112122, 30.40863991], [77.5728302, 30.41033173], [77.5749588, 30.41174126], [77.57753754, 30.41245842], [77.57971191, 30.41192055], [77.58436584, 30.40998077], [77.58467865, 30.40878105], [77.58638763, 30.40801048], [77.58699036, 30.40806007], [77.58777618, 30.40846252], [77.59107208, 30.40904999], [77.59246063, 30.40949059], [77.59778595, 30.4088707], [77.59896851, 30.40891075], [77.60273743, 30.40841293], [77.60411072, 30.40875053], [77.60597229, 30.40948105], [77.60707092, 30.40963173], [77.60822296, 30.41019249], [77.60916138, 30.41040993], [77.61122894, 30.40757179], [77.61450958, 30.40582085], [77.61694336, 30.4052906], [77.61818695, 30.40533066], [77.62207031, 30.4047699], [77.62354279, 30.40516281], [77.62552643, 30.4070816], [77.63053131, 30.4108696], [77.63288116, 30.41117287], [77.63421631, 30.41087914], [77.63569641, 30.41012192], [77.63661957, 30.40920067], [77.63941193, 30.40710068], [77.63986969, 30.40640068], [77.64138031, 30.40536118], [77.643013, 30.40454292], [77.64450836, 30.40257835], [77.64569092, 30.40199089], [77.64762115, 30.39807129], [77.65193176, 30.39550018], [77.65529633, 30.39477921], [77.65805817, 30.39401054], [77.65969086, 30.39393806], [77.66034698, 30.39374161], [77.66126251, 30.39323044], [77.66153717, 30.3926506], [77.66243744, 30.39167023], [77.66300964, 30.39057159], [77.66369629, 30.38751984], [77.66348267, 30.38557816], [77.66320801, 30.38473129], [77.66410828, 30.3839798], [77.66581726, 30.38343811], [77.66687775, 30.38365936], [77.66880035, 30.38352966], [77.67183685, 30.38394165], [77.6733017, 30.38565063], [77.67386627, 30.38459969], [77.67700195, 30.38080025], [77.67751312, 30.37912941], [77.67977142, 30.37560081], [77.6802597, 30.37434006], [77.68273926, 30.37138939], [77.68390656, 30.3696003], [77.68434143, 30.36816025], [77.68596649, 30.36688042], [77.68707275, 30.36457825], [77.69064331, 30.35972977], [77.69126892, 30.35824013], [77.69277954, 30.35724068], [77.69341278, 30.35569191], [77.69425201, 30.35534286], [77.6971283, 30.3516407], [77.6977005, 30.35031128], [77.70108032, 30.34747124], [77.70491791, 30.34387016], [77.70773315, 30.34132195], [77.70993805, 30.33991051], [77.71077728, 30.33876038], [77.71308899, 30.33793259], [77.71537781, 30.33687973], [77.71766663, 30.33609962], [77.72088623, 30.33542824], [77.72265625, 30.33415031], [77.72553253, 30.33291054], [77.7297287, 30.33147812], [77.73239136, 30.32991028], [77.73581696, 30.32925034], [77.73771667, 30.32819176], [77.74017334, 30.3283329], [77.7425766, 30.32760811], [77.74828339, 30.32537079], [77.751297, 30.32464981], [77.75705719, 30.320961], [77.75866699, 30.3200798], [77.76069641, 30.31913948], [77.76268005, 30.31849098], [77.76496124, 30.31736946], [77.77301025, 30.3130703], [77.7772522, 30.30987167], [77.77848053, 30.30929947], [77.78320313, 30.30641937], [77.78430939, 30.30549049], [77.7889328, 30.30365944], [77.79930878, 30.29763031], [77.80179596, 30.2959919], [77.80737305, 30.29362106], [77.80905151, 30.29217911], [77.81240845, 30.2907505], [77.8186264, 30.28918076], [77.82405853, 30.28635979], [77.8286972, 30.28467941], [77.83277893, 30.28378105], [77.83629608, 30.28228951], [77.84030151, 30.28121185], [77.84246826, 30.28033066], [77.84755707, 30.27877045], [77.85189056, 30.27658272], [77.85587311, 30.27393913], [77.85788727, 30.27237129], [77.86103058, 30.27135086], [77.86554718, 30.27048111], [77.86714172, 30.271101], [77.868927, 30.27210045], [77.87148285, 30.27441978], [77.87397003, 30.27415085], [77.87985992, 30.27193069], [77.88220978, 30.27046967], [77.89021301, 30.26823997], [77.89164734, 30.26735115], [77.89636993, 30.26601028], [77.90029907, 30.26440811], [77.90363312, 30.26267815], [77.90795135, 30.26073074], [77.91030121, 30.25931168], [77.91362762, 30.25761032], [77.91684723, 30.25617027], [77.91996765, 30.2540493], [77.92189026, 30.2517395], [77.92386627, 30.24981117], [77.92539978, 30.24871063], [77.92823792, 30.24775124], [77.93148041, 30.24695969], [77.93026733, 30.24300194], [77.92977142, 30.24180984], [77.92932129, 30.23999023], [77.92713165, 30.23641968], [77.923172, 30.23179817], [77.92182159, 30.22970009], [77.9180603, 30.22479057], [77.91454315, 30.22180939], [77.91139221, 30.21877289], [77.90762329, 30.21698952], [77.90439606, 30.21520805], [77.90312958, 30.21306038], [77.90229797, 30.20976067], [77.90039825, 30.20578003], [77.89990997, 30.20401001], [77.8989563, 30.19487953], [77.89833069, 30.19226074], [77.89707184, 30.18822289], [77.89599609, 30.18629265], [77.89280701, 30.18342972], [77.89012146, 30.18037987], [77.88793945, 30.17874908], [77.8793869, 30.16967964], [77.87798309, 30.16860008], [77.87664032, 30.16695976], [77.87332916, 30.16393089], [77.87204742, 30.16303062], [77.86871338, 30.15880013], [77.86548615, 30.15507126], [77.86499786, 30.15209961], [77.86444092, 30.14993858], [77.8613205, 30.1440506], [77.85990143, 30.1415596], [77.85909271, 30.14048195], [77.8579483, 30.13809967], [77.85527039, 30.13362122], [77.85233307, 30.13092995], [77.85051727, 30.12865829], [77.84809875, 30.1245327], [77.84723663, 30.12346077], [77.84468842, 30.11950111], [77.84361267, 30.11831284], [77.84274292, 30.11677933], [77.83853149, 30.11227036], [77.83747864, 30.11143112], [77.8360672, 30.10995293], [77.83283234, 30.10800934], [77.83058167, 30.10724068], [77.82842255, 30.10612106], [77.82656097, 30.10552025], [77.82530975, 30.10473061], [77.82395172, 30.10127068], [77.82189178, 30.09888077], [77.82186127, 30.09694862], [77.81996918, 30.09363937], [77.81790924, 30.09157944], [77.81519318, 30.09016991], [77.81307983, 30.08963013], [77.81070709, 30.08954811], [77.80806732, 30.09020996], [77.80548096, 30.09196091], [77.80413055, 30.09363937], [77.80278015, 30.09456062], [77.80101776, 30.09617805], [77.79873657, 30.09786034], [77.7977066, 30.09885979], [77.79503632, 30.10061073], [77.79392242, 30.10108757], [77.79186249, 30.10185051], [77.78956604, 30.10153008], [77.78643799, 30.09996986], [77.78595734, 30.09910965], [77.78513336, 30.09678078], [77.78276062, 30.09325981], [77.78174591, 30.09086037], [77.78005219, 30.08916283], [77.77868652, 30.08543968], [77.77729797, 30.08240128], [77.77585602, 30.07765007], [77.77523041, 30.07631111], [77.77337646, 30.07386017], [77.77189636, 30.07249069], [77.76978302, 30.06838036], [77.7690506, 30.06809998], [77.76793671, 30.06694031], [77.76531982, 30.06306076], [77.76442719, 30.06088066], [77.76148987, 30.05544281], [77.75833893, 30.05050087], [77.75757599, 30.04823112], [77.75820923, 30.04654121], [77.75982666, 30.0449295], [77.7620163, 30.04318047], [77.76389313, 30.04216957], [77.76570129, 30.0396595], [77.7700882, 30.03688049], [77.77255249, 30.03370094], [77.77326202, 30.03303909], [77.77388763, 30.03210068], [77.77353668, 30.02956963], [77.7722702, 30.0262928], [77.76944733, 30.02384758], [77.76779938, 30.02293968], [77.76288605, 30.02163124], [77.75974274, 30.02042961], [77.75756073, 30.01951981], [77.75325012, 30.01736069], [77.74912262, 30.01410103], [77.74642944, 30.01134109], [77.74462128, 30.00880241], [77.74323273, 30.00596046], [77.74080658, 29.99411964], [77.736763, 29.99072075], [77.73007965, 29.98745155], [77.73100281, 29.98433113], [77.744133, 29.97186089], [77.74495697, 29.96759987], [77.74347687, 29.96377945], [77.74014282, 29.95890045], [77.7326889, 29.95498085], [77.72946167, 29.9518795], [77.72898102, 29.94561958], [77.72541809, 29.94351959], [77.72067261, 29.93902969], [77.71768188, 29.93495178], [77.71894073, 29.93284035], [77.72416687, 29.9300518], [77.72879791, 29.92856026], [77.72956085, 29.92280006], [77.73301697, 29.91348076], [77.73111725, 29.91129112], [77.727211, 29.90904236], [77.72483063, 29.90590096], [77.72009277, 29.90279007], [77.71752167, 29.89463043], [77.71302032, 29.89157295], [77.71105194, 29.88812065], [77.70301819, 29.88975906], [77.70250702, 29.88570023], [77.70316315, 29.87845039], [77.70201874, 29.8717804], [77.70326233, 29.86767006], [77.7060318, 29.86374092], [77.70957947, 29.8594799], [77.71334839, 29.85647964], [77.73005676, 29.85308075], [77.73092651, 29.84190178], [77.72918701, 29.83756065], [77.73203278, 29.83455086], [77.73895264, 29.83027077], [77.74234009, 29.82463264], [77.74398804, 29.81628036], [77.74128723, 29.81141853], [77.74214935, 29.80952072], [77.74932861, 29.80435944], [77.75296021, 29.79743958], [77.76470184, 29.78545952], [77.76053619, 29.78128052], [77.7607193, 29.77877998], [77.76539612, 29.77573013], [77.76352692, 29.77036095], [77.76571655, 29.76371002], [77.76165009, 29.75576019], [77.76085663, 29.75270081], [77.76187134, 29.74382019], [77.76735687, 29.73781013], [77.76925659, 29.73464966], [77.76792145, 29.73056984], [77.7637558, 29.72610092], [77.75771332, 29.71591949], [77.75891113, 29.71342087], [77.76203918, 29.71178818], [77.76980591, 29.70992088], [77.78269196, 29.70832062], [77.79492188, 29.70046043], [77.7974472, 29.6978302], [77.78916931, 29.68588066], [77.79251862, 29.68192101], [77.80448914, 29.67690086], [77.81108093, 29.67248917], [77.82129669, 29.66899109], [77.82897186, 29.6693306], [77.83426666, 29.67188263], [77.83843994, 29.67551994], [77.8406601, 29.67935944], [77.84294128, 29.68130112], [77.84706879, 29.68062973], [77.84863281, 29.68418121], [77.85405731, 29.68890953], [77.85851288, 29.68806076], [77.8662262, 29.69341087], [77.86991119, 29.69400978], [77.87003326, 29.69878006], [77.87387848, 29.70197105], [77.87722778, 29.70038986], [77.88218689, 29.70000267], [77.88683319, 29.70070076], [77.89994049, 29.69782066], [77.91020966, 29.69893837], [77.90483856, 29.7025528], [77.90634918, 29.70409966], [77.9083786, 29.70286942], [77.9095459, 29.70384026], [77.90804291, 29.70528984], [77.90962982, 29.7063694], [77.91072845, 29.70549011], [77.91622925, 29.71165085], [77.92015839, 29.71385956], [77.92491913, 29.71265984], [77.92722321, 29.71458054], [77.93049622, 29.71305275], [77.93665314, 29.71391106], [77.93895721, 29.71475983], [77.94081879, 29.71459961], [77.94245148, 29.71240044], [77.94943237, 29.70766258], [77.95198059, 29.70536995], [77.9462204, 29.70376968], [77.94229126, 29.70203018], [77.94114685, 29.70004082], [77.94359589, 29.69672966], [77.94628143, 29.69546127], [77.94328308, 29.69363976], [77.94306946, 29.69157982], [77.94491577, 29.69143295], [77.94377899, 29.68943024], [77.94470215, 29.68935966], [77.94539642, 29.68723106], [77.94727325, 29.68707085], [77.95176697, 29.68567085], [77.95411682, 29.68133163], [77.95668793, 29.67904091], [77.95831299, 29.67683029], [77.96156311, 29.67240906], [77.96228027, 29.67027092], [77.9631958, 29.67020035], [77.9691925, 29.67385101], [77.97126007, 29.67576981], [77.97218323, 29.6756897], [77.97207642, 29.67465973], [77.97277069, 29.67253113], [77.97162628, 29.67053986], [77.9704895, 29.66856956], [77.96936035, 29.66657066], [77.96913147, 29.66451073], [77.96891785, 29.66246033], [77.96788025, 29.66151047], [77.96673584, 29.6595211], [77.96537781, 29.65547943], [77.96750641, 29.64907074], [77.97168732, 29.64456749], [77.97445679, 29.64435005], [77.97537994, 29.64426994], [77.97702026, 29.64206123], [77.97471619, 29.63809967], [77.97312927, 29.63199043], [77.97351837, 29.62676239], [77.97493744, 29.62249947], [77.97541809, 29.61831093], [77.97683716, 29.61403847], [77.97464752, 29.61108971], [77.97025299, 29.61351967], [77.96633148, 29.61174965], [77.96240234, 29.60999107], [77.95986176, 29.61227989], [77.95822144, 29.61449051], [77.95568848, 29.61679077], [77.95186615, 29.61603928], [77.9496994, 29.61310959], [77.95040131, 29.61096954], [77.95101166, 29.60778999], [77.95240784, 29.60351944], [77.95323181, 29.60241127], [77.95092773, 29.59844017], [77.94876862, 29.5954895], [77.94854736, 29.59342957], [77.94832611, 29.59136963], [77.94728851, 29.59043121], [77.94822693, 29.5903492], [77.9498291, 29.58813095], [77.95157623, 29.58694077], [77.95320892, 29.58472061], [77.95598602, 29.58444977], [77.95987701, 29.58621025], [77.96174622, 29.5860405], [77.96337128, 29.58382988], [77.96631622, 29.5845108], [77.96736145, 29.58572006], [77.96955109, 29.58518982], [77.97268677, 29.58315086], [77.97299957, 29.58333969], [77.97704315, 29.58333015], [77.97881317, 29.58536911], [77.98101044, 29.58781052], [77.98232269, 29.58901024], [77.98375702, 29.58805084], [77.98457336, 29.58455276], [77.98404694, 29.57986069], [77.9807663, 29.56875992], [77.97881317, 29.5681591], [77.97675323, 29.56384087], [77.97705841, 29.55811119], [77.97885895, 29.55413055], [77.98802185, 29.54586029], [77.99415588, 29.55509949], [78.00351715, 29.5560894], [78.01661682, 29.55462074], [78.01927185, 29.55405045], [78.03256226, 29.55170059], [78.03688049, 29.55262947], [78.03826141, 29.56143951], [78.03721619, 29.5652504], [78.04264069, 29.57191277], [78.0407486, 29.5753212], [78.03730011, 29.57776833], [78.03650665, 29.58086014], [78.03975677, 29.58798027], [78.04393005, 29.59307098], [78.0506897, 29.59805107], [78.05924988, 29.60161018], [78.06826019, 29.60141182], [78.07315826, 29.59991074], [78.07850647, 29.59954262], [78.08206177, 29.60181046], [78.08867645, 29.61330032], [78.09062195, 29.62477112], [78.09423828, 29.62803078], [78.09683228, 29.63059998], [78.09751129, 29.63078117], [78.10697937, 29.63318062], [78.10913849, 29.63669968], [78.11482239, 29.64516068], [78.13400269, 29.65851021], [78.13912201, 29.67609978], [78.1659317, 29.67952919], [78.18222046, 29.69155121], [78.19229889, 29.70659065], [78.19352722, 29.71005821], [78.22126007, 29.71762276], [78.23139954, 29.70409012], [78.26476288, 29.72679138], [78.28193665, 29.74234009], [78.30293274, 29.75759125], [78.33174133, 29.79618073], [78.33193207, 29.79611969], [78.33853912, 29.7925396], [78.35125732, 29.78625107], [78.38598633, 29.77386093], [78.39842224, 29.77213287], [78.40838623, 29.77343941], [78.41256714, 29.77242088], [78.42431641, 29.76165009], [78.43212891, 29.75811958], [78.45215607, 29.75213814], [78.46473694, 29.75101089], [78.47357941, 29.74847031], [78.48757935, 29.7413826], [78.49021149, 29.72491837], [78.5002594, 29.71533966], [78.50184631, 29.71170807], [78.50601959, 29.69388962], [78.50744629, 29.69083023], [78.50724792, 29.67696953], [78.50763702, 29.6729126], [78.50961304, 29.66847992], [78.50921631, 29.65965271], [78.51151276, 29.65069008], [78.51774597, 29.63915062], [78.52546692, 29.62977028], [78.52735901, 29.62436295], [78.53054047, 29.62393188], [78.56121063, 29.59373093], [78.57647705, 29.58057022], [78.6052475, 29.5617981], [78.61515808, 29.55787086], [78.62149811, 29.55289078], [78.63957214, 29.54777908], [78.65039063, 29.54068947], [78.67655945, 29.52135086], [78.68540955, 29.5135498], [78.69335938, 29.50887108], [78.70826721, 29.50942039], [78.72660828, 29.50871086], [78.73152161, 29.50574112], [78.73905945, 29.50498009], [78.74225616, 29.5012207], [78.76577759, 29.48378944], [78.77474976, 29.48093987], [78.7855072, 29.47603035], [78.79695129, 29.47595024], [78.81138611, 29.46982956], [78.81669617, 29.46857071], [78.82376862, 29.46969032], [78.83006287, 29.46850967], [78.84612274, 29.46365166], [78.86575317, 29.45960045], [78.87542725, 29.4599781], [78.8826828, 29.45784187], [78.8901062, 29.45754051], [78.89601898, 29.45618057], [78.90033722, 29.45618057], [78.91979218, 29.46014977], [78.92292786, 29.45618057], [78.90714264, 29.45183182], [78.90040588, 29.44668961], [78.89647675, 29.42358017], [78.89061737, 29.41642952], [78.88719177, 29.40899086], [78.88279724, 29.40480042], [78.87275696, 29.39856911], [78.87018585, 29.39236259], [78.86599731, 29.39311981], [78.86258698, 29.39460945], [78.8602066, 29.39388275], [78.85888672, 29.39147949], [78.86003113, 29.38931084], [78.85975647, 29.38767052], [78.85679626, 29.3855896], [78.84039307, 29.3799305], [78.83631134, 29.38143158], [78.8325119, 29.38134956], [78.83185577, 29.37658119], [78.8347168, 29.37434959], [78.83580017, 29.37228775], [78.83625793, 29.37140846], [78.83436584, 29.36967087], [78.82881927, 29.36818123], [78.8239212, 29.36844063], [78.81417847, 29.3700428], [78.81176758, 29.37231064], [78.81095886, 29.38027954], [78.81500244, 29.38533974], [78.81160736, 29.38470078], [78.80898285, 29.38287926], [78.80776978, 29.38027191], [78.80684662, 29.37315178], [78.79720306, 29.35563087], [78.79014587, 29.35211945], [78.79012299, 29.35040092], [78.79167175, 29.34787941], [78.79270172, 29.34342766], [78.7979126, 29.33831978], [78.79738617, 29.33697128], [78.79133606, 29.33499908], [78.78884125, 29.32928276], [78.78132629, 29.33196068], [78.78444672, 29.34292984], [78.78246307, 29.34644127], [78.78089142, 29.34352112], [78.77905273, 29.3422718], [78.7696228, 29.34065056], [78.76593018, 29.3410511], [78.76384735, 29.34320068], [78.76532745, 29.34572983], [78.76352692, 29.34739113], [78.75740814, 29.34976006], [78.74704742, 29.34333992], [78.74608612, 29.34091949], [78.74164581, 29.33588028], [78.74150085, 29.33262062], [78.73478699, 29.3317585], [78.7315979, 29.33431053], [78.72834778, 29.33415985], [78.7277298, 29.33138084], [78.72570801, 29.32998276], [78.72592163, 29.32512093], [78.72860718, 29.31896019], [78.7273407, 29.31748962], [78.72110748, 29.31945992], [78.71975708, 29.31842041], [78.71412659, 29.31933022], [78.71385956, 29.31735039], [78.72080231, 29.31228065], [78.72756195, 29.31278992], [78.73139191, 29.31101036], [78.73889923, 29.30631065], [78.74675751, 29.30270958], [78.76107788, 29.29333115], [78.76552582, 29.28992081], [78.76683044, 29.28590965], [78.75863647, 29.28667068], [78.78153992, 29.2712307], [78.78600311, 29.27301979], [78.78736877, 29.26533127], [78.78994751, 29.26299095], [78.79286957, 29.26260948], [78.79988098, 29.25785255], [78.81378174, 29.25229073], [78.81611633, 29.25382805], [78.82289886, 29.25579071], [78.82756042, 29.25793076], [78.83125305, 29.26073837], [78.83319092, 29.25942039], [78.83405304, 29.25619125], [78.84233093, 29.25428009], [78.84519196, 29.25814056], [78.84668732, 29.25824928], [78.8506012, 29.26222992], [78.85262299, 29.26131058], [78.85383606, 29.25921059], [78.85437775, 29.25542068], [78.85787201, 29.25220108], [78.86406708, 29.24949265], [78.87097931, 29.24073029], [78.87359619, 29.23525238], [78.87303925, 29.23225975], [78.86958313, 29.22953987], [78.87014771, 29.22853088], [78.88286591, 29.22532082], [78.88445282, 29.21951294], [78.88687897, 29.21783066], [78.89103699, 29.21647263], [78.89214325, 29.21487236], [78.89225769, 29.21285057], [78.88774872, 29.21033287], [78.89356232, 29.20483971], [78.89916229, 29.20259285], [78.89720917, 29.19869041], [78.89434814, 29.19589996], [78.89911652, 29.19063187], [78.90130615, 29.18273926], [78.90570068, 29.18033981], [78.9057312, 29.17748833], [78.90239716, 29.17449951], [78.9045105, 29.17057037], [78.90332031, 29.16768074], [78.90571594, 29.16521072], [78.90479279, 29.16316986], [78.89961243, 29.16142082], [78.89504242, 29.15681076], [78.89589691, 29.15579033], [78.89834595, 29.15488815], [78.90040588, 29.15061951], [78.9144516, 29.14898109], [78.92077637, 29.15286064], [78.92363739, 29.1571312], [78.93371582, 29.15420914], [78.94438934, 29.14958954], [78.94888306, 29.15278053], [78.95146942, 29.15970993], [78.95610809, 29.16037178], [78.9608078, 29.16159821], [78.96127319, 29.16317749], [78.96035004, 29.16460037], [78.96057892, 29.16587067], [78.96232605, 29.16681099], [78.96662903, 29.16555023], [78.97319794, 29.16082001], [78.97901154, 29.15475082], [78.98262787, 29.1469593], [78.98353577, 29.13734818], [78.98809814, 29.13512039], [78.99262238, 29.13363266], [78.9954071, 29.12927055], [78.99465942, 29.12537003], [78.99838257, 29.12294006], [79.0005722, 29.11655045], [79.00657654, 29.12051964], [79.01700592, 29.11786079], [79.02185059, 29.11892128], [79.02606964, 29.12154961], [79.02970123, 29.12543106], [79.03096771, 29.13022995], [79.02768707, 29.13296127], [79.02352142, 29.13312912], [79.01899719, 29.13508987], [79.01187134, 29.13471031], [79.00875854, 29.13622093], [79.00859833, 29.13936234], [79.01203918, 29.14487076], [79.01278687, 29.14912987], [79.01048279, 29.15302849], [79.01095581, 29.15722084], [79.01335144, 29.15769005], [79.01696777, 29.15397072], [79.02147675, 29.1508007], [79.02639771, 29.14986038], [79.02867889, 29.15239906], [79.02742004, 29.15588188], [79.0275116, 29.16074944], [79.02388, 29.16338921], [79.02175903, 29.16730118], [79.02307129, 29.17079163], [79.02614594, 29.17196083], [79.02696228, 29.17226982], [79.03378296, 29.17110062], [79.0382309, 29.16629028], [79.04612732, 29.15472984], [79.05438232, 29.15518188], [79.05947876, 29.15626907], [79.07286072, 29.15199089], [79.09223938, 29.13674164], [79.10074615, 29.13167953], [79.10853577, 29.13043976], [79.11361694, 29.13066292], [79.11779022, 29.13388062], [79.13080597, 29.1293602], [79.13384247, 29.12416077], [79.14221954, 29.11972809], [79.14398193, 29.1066227], [79.14319611, 29.09894943], [79.1370163, 29.09090805], [79.13471985, 29.08191109], [79.13698578, 29.06933975], [79.14369965, 29.06009102], [79.15345764, 29.05476952], [79.1654129, 29.05125809], [79.16015625, 29.0433197], [79.15866852, 29.03421021], [79.15421295, 29.03292084], [79.15451813, 29.02741051], [79.15827942, 29.02287865], [79.16410065, 29.02058983], [79.16562653, 29.01729965], [79.16858673, 29.0158596], [79.17759705, 29.0196209], [79.18493652, 29.01801109], [79.18296051, 29.02420998], [79.19758606, 29.02209091], [79.19911194, 29.02527809], [79.2040329, 29.02910042], [79.21116638, 29.02370071], [79.22154236, 29.01729012], [79.23774719, 29.00683975], [79.23937225, 28.99990082], [79.24389648, 28.99648094], [79.24996948, 28.99217987], [79.25801849, 28.98694992], [79.26434326, 28.98213959], [79.26846313, 28.97739983], [79.27052307, 28.97542953], [79.27365112, 28.97287178], [79.27887726, 28.96483994], [79.28600311, 28.96050262], [79.29547882, 28.95429993], [79.29892731, 28.95311165], [79.30150604, 28.95285034], [79.30467987, 28.95393944], [79.30718994, 28.95846939], [79.31215668, 28.95806122], [79.31658936, 28.95679092], [79.32095337, 28.9567585], [79.32881165, 28.95540047], [79.33368683, 28.95498276], [79.33763885, 28.95453072], [79.34390259, 28.95313072], [79.349617, 28.95210075], [79.35189056, 28.95243073], [79.35476685, 28.9534111], [79.35389709, 28.95681953], [79.35275269, 28.95882034], [79.35285187, 28.96123123], [79.35507965, 28.96528053], [79.3571167, 28.96797943], [79.35967255, 28.97047997], [79.36338806, 28.96665955], [79.36506653, 28.96199036], [79.36743164, 28.95994949], [79.36897278, 28.95767975], [79.3707428, 28.95458031], [79.37224579, 28.9511795], [79.37252045, 28.94762993], [79.37336731, 28.9418602], [79.37490082, 28.93939018], [79.37702942, 28.93704987], [79.37934113, 28.93629074], [79.38497925, 28.93731117], [79.38942719, 28.93830109], [79.39556122, 28.93675041], [79.3983078, 28.93515968], [79.40143585, 28.93226051], [79.40261841, 28.92904091], [79.40139771, 28.92136955], [79.39900208, 28.9169693], [79.40007782, 28.91101074], [79.40123749, 28.90186119], [79.40114594, 28.89977074], [79.400383, 28.89558983], [79.39565277, 28.88544083], [79.3979187, 28.88104057], [79.40187836, 28.87728119], [79.40429688, 28.87490082], [79.4048233, 28.87112999], [79.40493774, 28.86745262], [79.40621948, 28.86225128], [79.4087677, 28.85801125], [79.41121674, 28.85588074], [79.41712189, 28.85584259], [79.41963196, 28.8553009], [79.42388916, 28.85523987], [79.42752838, 28.85725021], [79.43031311, 28.8597908], [79.43345642, 28.86164284], [79.43976593, 28.86104965], [79.44777679, 28.86005974], [79.45510864, 28.86005974], [79.4597168, 28.85915947], [79.46338654, 28.86053085], [79.46470642, 28.86275291], [79.46776581, 28.86491013], [79.47663116, 28.86717033], [79.48262787, 28.86622047], [79.48654938, 28.86459923], [79.49137115, 28.86259842], [79.49691772, 28.86239052], [79.50248718, 28.86276054], [79.5072403, 28.86330032], [79.51013184, 28.86470032], [79.51406097, 28.86759186], [79.51732635, 28.87058067], [79.51996613, 28.87329102], [79.52259827, 28.87632942], [79.52591705, 28.88199806], [79.52989197, 28.88689041], [79.53308868, 28.89031029], [79.53645325, 28.89253998], [79.53866577, 28.89241028], [79.54332733, 28.89066124], [79.55049896, 28.88418007], [79.55253601, 28.88153076], [79.55397034, 28.87852097], [79.55374146, 28.87481117], [79.55166626, 28.86824989], [79.5512619, 28.86610985], [79.55120087, 28.86320114], [79.54991913, 28.86016083], [79.54767609, 28.85429955], [79.54821777, 28.85004997], [79.55092621, 28.84589195], [79.5535965, 28.84505081], [79.55716705, 28.84568977], [79.5594101, 28.84670067], [79.56233978, 28.84790993], [79.56347656, 28.8487606], [79.56578827, 28.84946823], [79.57189941, 28.84902], [79.57427979, 28.84930038], [79.57655334, 28.85028076], [79.57878876, 28.85238266], [79.58197021, 28.85584259], [79.59226227, 28.86655045], [79.59805298, 28.86491966], [79.60360718, 28.86470032], [79.60868073, 28.86671066], [79.61354828, 28.86873055], [79.61904144, 28.86758041], [79.62399292, 28.86268997], [79.63075256, 28.85885811], [79.634552, 28.8584404], [79.64109802, 28.85646248], [79.6432724, 28.85322952], [79.64393616, 28.852911], [79.65405273, 28.84873962], [79.6594696, 28.84773064], [79.66619873, 28.84832954], [79.6672821, 28.8500309], [79.66709137, 28.85409927], [79.67285919, 28.8576107], [79.68434143, 28.8573494], [79.68643951, 28.86700058], [79.68814087, 28.86819077], [79.69233704, 28.86832047], [79.69705963, 28.87028122], [79.70189667, 28.86989975], [79.70517731, 28.87022018], [79.7056427, 28.8723526], [79.70672607, 28.87523842], [79.70961761, 28.87920952], [79.71218872, 28.88068008], [79.71555328, 28.88178062], [79.71813202, 28.88275909], [79.72836304, 28.88507271], [79.73282623, 28.88309097], [79.73726654, 28.88259125], [79.74044037, 28.88318062], [79.74128723, 28.88535118], [79.74487305, 28.88978004], [79.748703, 28.89154053], [79.74996948, 28.89335251], [79.75977325, 28.88953018], [79.76197052, 28.8896904], [79.77446747, 28.89183044], [79.79064178, 28.87742996], [79.79125214, 28.87380981], [79.79161835, 28.87039757], [79.79485321, 28.86987114], [79.79696655, 28.87045097], [79.80280304, 28.87182045], [79.80574036, 28.86905098], [79.80693817, 28.86631012], [79.8086319, 28.86283112], [79.80901337, 28.85890961], [79.80812073, 28.85629082], [79.79991913, 28.85427094], [79.7946167, 28.8528595], [79.79669952, 28.84955025], [79.79815674, 28.84803963], [79.798172, 28.84604073], [79.79431152, 28.84303093], [79.79367065, 28.8392601], [79.79920197, 28.83623123], [79.80146027, 28.8332901], [79.80119324, 28.82963753], [79.79988098, 28.82468987], [79.79782104, 28.82081032], [79.79704285, 28.81649017], [79.79479218, 28.8147316], [79.79189301, 28.81517029], [79.78940582, 28.81970024], [79.78617096, 28.82093048], [79.78214264, 28.81319046], [79.78336334, 28.80541992], [79.78544617, 28.80620956], [79.79203033, 28.80303955], [79.7947464, 28.80380058], [79.8012619, 28.80454063], [79.80303955, 28.80558968], [79.80419922, 28.80706024], [79.80503845, 28.80873108], [79.80905151, 28.81075096], [79.81128693, 28.81138039], [79.81407166, 28.81060982], [79.81591034, 28.81225967], [79.81503296, 28.81458092], [79.81465149, 28.81912041], [79.81620789, 28.8217411], [79.8157196, 28.82468033], [79.81282806, 28.83018112], [79.813797, 28.83171082], [79.82234955, 28.8417511], [79.82446289, 28.84478951], [79.82965088, 28.84667969], [79.83383942, 28.84439087], [79.84171295, 28.84260941], [79.8441391, 28.84354019], [79.8494873, 28.84538078], [79.85404968, 28.84428978], [79.85468292, 28.84140968], [79.85560608, 28.83905983], [79.86061096, 28.83413124], [79.87101746, 28.83065033], [79.87532043, 28.83024025], [79.87547302, 28.82128906], [79.87563324, 28.8183403], [79.87123871, 28.81641006], [79.86042023, 28.81791115], [79.85423279, 28.82082939], [79.84971619, 28.8217411], [79.84620667, 28.82130051], [79.84332275, 28.81504059], [79.8405304, 28.80866051], [79.84648895, 28.80496025], [79.85336304, 28.80080032], [79.85965729, 28.79845047], [79.86728668, 28.79644966], [79.87307739, 28.79646111], [79.88012695, 28.79681969], [79.88604736, 28.79881096], [79.89480591, 28.80145073], [79.90129089, 28.80212021], [79.9005661, 28.79940033], [79.89813232, 28.79488754], [79.8934021, 28.79186249], [79.8889389, 28.78577042], [79.89209747, 28.78125954], [79.89450836, 28.77900124], [79.8992691, 28.77386093], [79.90571594, 28.77209854], [79.91204834, 28.76496124], [79.91014099, 28.76333046], [79.91172791, 28.75928116], [79.91808319, 28.75219917], [79.92150879, 28.74500084], [79.92233276, 28.73829079], [79.92237854, 28.73270988], [79.92951965, 28.72651291], [79.94087219, 28.72145844], [79.95288849, 28.71752167], [79.96782684, 28.71562004], [79.97483063, 28.7167511], [79.98825836, 28.71701813], [79.99958038, 28.72564125], [80.00286865, 28.72694969], [80.00565338, 28.72949982], [80.0136261, 28.73736954], [80.02297211, 28.74867058], [80.02906799, 28.75806046], [80.03124237, 28.76055908], [80.03344727, 28.76138115], [80.03476715, 28.76323128], [80.03398132, 28.76638031], [80.0345459, 28.76904106], [80.03816223, 28.77511978], [80.04045868, 28.78310966], [80.03623962, 28.79071999], [80.0326767, 28.79417992], [80.02736664, 28.79737854], [80.02568817, 28.79985046], [80.03198242, 28.80348969], [80.03360748, 28.80546951], [80.03408813, 28.80982971], [80.0584259, 28.83526039], [80.06381226, 28.83189964], [80.0696106, 28.8298912], [80.07013702, 28.8296833], [80.07025146, 28.82963943], [80.07238007, 28.82974434], [80.07671356, 28.82438278], [80.10886383, 28.82771873], [80.11964417, 28.82871437], [80.11980438, 28.82872963], [80.11997223, 28.82860565], [80.12274933, 28.82657433], [80.12705994, 28.82342148], [80.13316345, 28.81895256], [80.14019775, 28.81383514], [80.15667725, 28.79784012], [80.16027069, 28.79434776], [80.16233826, 28.79234123], [80.16316223, 28.79154015], [80.16493225, 28.78982162], [80.17298889, 28.7820015], [80.18338013, 28.77579498], [80.20236206, 28.76446152], [80.21772766, 28.75528336], [80.22679901, 28.75714684], [80.23535919, 28.75914192], [80.23592377, 28.75922012], [80.23698425, 28.75836945], [80.23831177, 28.75730705], [80.24319458, 28.75612068], [80.24704742, 28.75592613], [80.25228882, 28.75782204], [80.25449371, 28.75608826], [80.26358795, 28.74894142], [80.26679993, 28.74350548], [80.26622772, 28.73775864], [80.2634201, 28.73271561], [80.25946045, 28.73026848], [80.25790405, 28.72933578], [80.2622757, 28.72587013], [80.26802063, 28.72131538], [80.27370453, 28.71471977], [80.27651215, 28.71141434], [80.27922058, 28.70991516], [80.2926712, 28.71107864], [80.29541779, 28.71131516], [80.29850769, 28.70967484], [80.29953766, 28.70803642], [80.30062103, 28.70631981], [80.30558777, 28.70535278], [80.30961609, 28.70461464], [80.31851959, 28.7001152], [80.32236481, 28.69488716], [80.3236618, 28.68937492], [80.32369232, 28.68923187], [80.32423401, 28.68693352], [80.32299042, 28.68121719], [80.32758331, 28.66978264], [80.32758331, 28.66829681], [80.32758331, 28.66630363], [80.33892059, 28.6607151], [80.35031891, 28.65324593], [80.35501862, 28.65011597], [80.35691833, 28.64704132], [80.36238098, 28.64492989], [80.35890198, 28.64144897], [80.35968018, 28.63969994], [80.36091614, 28.63701439], [80.36371613, 28.63501358], [80.36991882, 28.63481522], [80.37236786, 28.63245773], [80.37258148, 28.63225555], [80.37332153, 28.62902069], [80.3769455, 28.62911415], [80.37804413, 28.62827492], [80.3846283, 28.63063622], [80.38786316, 28.62962914], [80.40626526, 28.63483238], [80.41641998, 28.63911438], [80.4256134, 28.63711548], [80.4280014, 28.63759613], [80.43412018, 28.63721466], [80.43930817, 28.63523483], [80.44102478, 28.63287926], [80.44430542, 28.62841988], [80.45067596, 28.62867928], [80.45281982, 28.6288147], [80.45820618, 28.62332535], [80.46281433, 28.62071609], [80.46401978, 28.61781502], [80.46446991, 28.61698723], [80.46466064, 28.61696625], [80.46590424, 28.61510277], [80.46573639, 28.61470604], [80.4655304, 28.61423302], [80.46479034, 28.61464691], [80.46270752, 28.61451912], [80.46411133, 28.61252213], [80.46632385, 28.60565567], [80.46788788, 28.6007061], [80.47316742, 28.59085083], [80.4733429, 28.59052658], [80.4726181, 28.58453178], [80.47170258, 28.5843029], [80.47013092, 28.58390999], [80.47025299, 28.58291626], [80.47708893, 28.58304024], [80.48031616, 28.58527756], [80.48154449, 28.58527756], [80.48162079, 28.5853157], [80.48280334, 28.58527756], [80.48542023, 28.58201599], [80.49659729, 28.57521057], [80.50141907, 28.56961441], [80.50814056, 28.56798744], [80.51172638, 28.56365776], [80.51698303, 28.55731583], [80.51934052, 28.55172348], [80.52161407, 28.55421448], [80.52441406, 28.5527153], [80.53199005, 28.57342529], [80.53195953, 28.57351112], [80.52729797, 28.57322311], [80.52331543, 28.5768261], [80.51650238, 28.61585808], [80.51299286, 28.62371063], [80.51288605, 28.62429428], [80.50792694, 28.64631081], [80.50518799, 28.66522598], [80.50780487, 28.67089081], [80.54161835, 28.69053841], [80.55177307, 28.69153023], [80.55587769, 28.69066048], [80.56707764, 28.6884594], [80.57041931, 28.68780327], [80.57919312, 28.68452454], [80.59204102, 28.67972565], [80.58259583, 28.66256332], [80.58184814, 28.66120911], [80.58379364, 28.6606102], [80.59925079, 28.65586472], [80.5970459, 28.65355873], [80.59145355, 28.64762497], [80.60011292, 28.65006828], [80.6079483, 28.65225983], [80.61064148, 28.64566994], [80.61328888, 28.63921165], [80.63491821, 28.63721466], [80.64321899, 28.64321518], [80.65031433, 28.63621521], [80.6529007, 28.63389969], [80.6583786, 28.63654518], [80.66934204, 28.64182091], [80.67246246, 28.6282959], [80.68127441, 28.62045479], [80.67970276, 28.60910416], [80.67962646, 28.6085434], [80.67903137, 28.60429192], [80.68694305, 28.60386467], [80.69742584, 28.60329628], [80.69192505, 28.5870285], [80.70562744, 28.57869148], [80.70782471, 28.57646942], [80.71630096, 28.5678978], [80.7233429, 28.57273865], [80.72621918, 28.57471466], [80.72809601, 28.5735302], [80.74030304, 28.56581497], [80.74005127, 28.57421684], [80.75148773, 28.57072449], [80.76065063, 28.56809425], [80.76963043, 28.56551743], [80.77101898, 28.55176163], [80.77124023, 28.54961014], [80.77375793, 28.54906464], [80.7844162, 28.54671478], [80.79181671, 28.54351616], [80.79161072, 28.54297638], [80.78627777, 28.52923012], [80.7880249, 28.52729034], [80.79075623, 28.52425957], [80.80144501, 28.52102852], [80.81014252, 28.5208168], [80.81356049, 28.52071953], [80.81373596, 28.52071571], [80.8172226, 28.52065468], [80.83172607, 28.51173019], [80.84379578, 28.50100136], [80.84529877, 28.49963188], [80.84605408, 28.49542046], [80.85699463, 28.49704361], [80.86728668, 28.48943901], [80.86332703, 28.5041256], [80.87762451, 28.50971794], [80.88355255, 28.50851822], [80.89789581, 28.50559998], [80.90151978, 28.5004158], [80.90702057, 28.49941444], [80.90856171, 28.49846458], [80.90960693, 28.4977932], [80.91030884, 28.49753952], [80.90873718, 28.48979568], [80.90869904, 28.4896183], [80.90311432, 28.48561478], [80.90692139, 28.46814919], [80.90744781, 28.46572685], [80.90969086, 28.46387863], [80.91459656, 28.45982933], [80.91738892, 28.45752335], [80.91706848, 28.46009064], [80.91611481, 28.46771622], [80.92121887, 28.4637146], [80.9210968, 28.46343994], [80.91938019, 28.45963669], [80.92718506, 28.45887184], [80.93258667, 28.45835495], [80.93399811, 28.46250534], [80.93416595, 28.46299171], [80.94422913, 28.46833611], [80.94692993, 28.46613121], [80.93404388, 28.45851898], [80.9450531, 28.45510674], [80.94651794, 28.45471573], [80.95262909, 28.45545006], [80.95330811, 28.45553589], [80.95341492, 28.44745827], [80.9550705, 28.44774055], [80.95903015, 28.44841194], [80.96582031, 28.44961548], [80.96881866, 28.4569149], [80.98151398, 28.45516205], [80.96794128, 28.44555092], [80.96659851, 28.44459915], [80.96839142, 28.44363594], [80.96983337, 28.44285965], [80.96697235, 28.43776512], [80.98088837, 28.43431091], [80.97961426, 28.44251442], [80.99093628, 28.44163895], [80.99754333, 28.44944382], [81.00139618, 28.45392036], [81.01779938, 28.45178413], [81.01831818, 28.45170021], [81.01917267, 28.45155907], [81.01483154, 28.43855476], [81.01469421, 28.43813705], [81.02091217, 28.43167496], [81.02729797, 28.43585205], [81.03121948, 28.43841553], [81.03560638, 28.42783356], [81.01854706, 28.41563988], [81.02051544, 28.4131546], [81.02281952, 28.41031456], [81.02639008, 28.40660095], [81.03411865, 28.39871597], [81.03661346, 28.41331482], [81.04428101, 28.41096878], [81.04451752, 28.41089821], [81.04772186, 28.4099369], [81.06912994, 28.39439201], [81.07267761, 28.39166069], [81.074646, 28.39014626], [81.07508087, 28.38981056], [81.08153534, 28.3848381], [81.09111786, 28.38201523], [81.15041351, 28.371315], [81.19491577, 28.36381531], [81.20446014, 28.36198807], [81.2124176, 28.36051559], [81.21394348, 28.3592186], [81.21511841, 28.35821533], [81.22136688, 28.34480858], [81.23203278, 28.33031273], [81.23628998, 28.32456017], [81.23590088, 28.31572723], [81.23453522, 28.28888512], [81.2352066, 28.28821182], [81.23565674, 28.2877655], [81.28221893, 28.23471451], [81.29164886, 28.2249527], [81.29371643, 28.22281456], [81.29380035, 28.22278404], [81.30141449, 28.21981621], [81.32241058, 28.19716835], [81.32015991, 28.18225861], [81.32601929, 28.17547989], [81.32649994, 28.17492485], [81.32302094, 28.16871262], [81.3160553, 28.16762161], [81.30620575, 28.1684494], [81.30400848, 28.16771698], [81.30384064, 28.16692924], [81.30410004, 28.16589737], [81.30491638, 28.16291618], [81.30600739, 28.16252899], [81.30893707, 28.1614933], [81.31047821, 28.16097069], [81.31142426, 28.16062737], [81.31245422, 28.15553474], [81.31635284, 28.15743637], [81.32189941, 28.16013718], [81.32972717, 28.14820671], [81.32014465, 28.14510345], [81.31945038, 28.14317894], [81.31718445, 28.13692474], [81.31978607, 28.13341904], [81.33618927, 28.14012909], [81.34389496, 28.13950729], [81.37311554, 28.14221573], [81.37503815, 28.14489746], [81.37841797, 28.14961624], [81.38018799, 28.15541458], [81.37966919, 28.15675735], [81.3789444, 28.15864563], [81.37847137, 28.15876389], [81.37049103, 28.16075897], [81.36959839, 28.1617775], [81.36875153, 28.16274643], [81.36873627, 28.16586113], [81.37111664, 28.1699543], [81.37580872, 28.17305565], [81.37521362, 28.17542267], [81.37693787, 28.17689323], [81.3797226, 28.17630768], [81.39170837, 28.17368889], [81.41249847, 28.17455292], [81.42827606, 28.1705761], [81.44570923, 28.16213989], [81.44876862, 28.16024208], [81.44779205, 28.1559124], [81.4522934, 28.15143967], [81.45188904, 28.15056801], [81.45178223, 28.14198685], [81.45176697, 28.14075089], [81.46398163, 28.13128662], [81.46941376, 28.12708092], [81.47451019, 28.12546539], [81.48581696, 28.11813164], [81.48160553, 28.11004639], [81.48022461, 28.08251572], [81.50752258, 28.06981277], [81.52885437, 28.0589447], [81.53952026, 28.05351448], [81.54907227, 28.04903603], [81.58120728, 28.02941704], [81.58841705, 28.02501488], [81.5887146, 28.02488327], [81.58883667, 28.02442932], [81.59888458, 28.02041054], [81.60002136, 28.01995659], [81.61891174, 28.01026344], [81.61977386, 28.00916862], [81.62591553, 28.00145149], [81.6286087, 28.00156403], [81.63793182, 27.99733925], [81.64110565, 27.99697876], [81.64523315, 27.99373436], [81.6500473, 27.9932766], [81.67645264, 27.99087715], [81.69463348, 27.98942184], [81.69476318, 27.98941994], [81.69509125, 27.98941612], [81.70018005, 27.98812485], [81.70354462, 27.98540878], [81.70400238, 27.98652077], [81.75705719, 27.94296265], [81.7588501, 27.94153976], [81.7640686, 27.93743896], [81.80397034, 27.90544701], [81.80670929, 27.90324974], [81.81541443, 27.90441513], [81.82310486, 27.90288544], [81.8249588, 27.90251732], [81.82732391, 27.90040588], [81.8354187, 27.89741516], [81.84185791, 27.89096069], [81.84944153, 27.88710785], [81.86231995, 27.87781906], [81.87541962, 27.8693161], [81.88209534, 27.86221695], [81.88684845, 27.85715866], [81.89902496, 27.85479736], [81.90402222, 27.85368347], [81.92801666, 27.85964584], [81.92711639, 27.87531471], [81.9319458, 27.88253403], [81.93990326, 27.88784218], [81.94004059, 27.89359283], [81.94961548, 27.90341568], [81.95281982, 27.9101162], [81.96112061, 27.91631508], [81.96364594, 27.92302322], [81.97011566, 27.92881584], [81.99311829, 27.9291153], [82.02742004, 27.9250145], [82.04701996, 27.92441559], [82.06441498, 27.92151451], [82.06928253, 27.92215347], [82.06965637, 27.92339325], [82.07288361, 27.92252541], [82.08242798, 27.90902138], [82.09201813, 27.89931488], [82.09329987, 27.8945713], [82.10283661, 27.88599014], [82.11611938, 27.8774147], [82.12311554, 27.86775398], [82.12522125, 27.86483955], [82.14131165, 27.85978317], [82.15193939, 27.85780525], [82.15591431, 27.86611557], [82.1632309, 27.86244011], [82.16376495, 27.86217308], [82.16970062, 27.85920715], [82.17901611, 27.8545475], [82.18349457, 27.85288811], [82.19798279, 27.84752083], [82.20195007, 27.84604836], [82.21020508, 27.84299088], [82.23104858, 27.82191467], [82.23233032, 27.82062149], [82.25344849, 27.81053352], [82.25469971, 27.80993462], [82.30499268, 27.77297783], [82.30579376, 27.77242851], [82.31711578, 27.76631546], [82.33841705, 27.75461578], [82.3530426, 27.748806], [82.36901855, 27.74241447], [82.38407898, 27.72046852], [82.40332031, 27.70290947], [82.40368652, 27.70254517], [82.40471649, 27.70213127], [82.41471863, 27.69810677], [82.42572784, 27.69052124], [82.42917633, 27.68814468], [82.43899536, 27.68491364], [82.45071411, 27.67861557], [82.46733093, 27.67683601], [82.47515869, 27.67634201], [82.48381805, 27.68271446], [82.48596954, 27.68056297], [82.49192047, 27.68104935], [82.49441528, 27.68401527], [82.50224304, 27.68482208], [82.51811218, 27.69024277], [82.53247833, 27.68652725], [82.53294373, 27.68640518], [82.54064941, 27.6875248], [82.5431366, 27.68553543], [82.5514679, 27.6886425], [82.55350494, 27.68848991], [82.55643463, 27.68827057], [82.56388855, 27.6916256], [82.58688354, 27.69845963], [82.59559631, 27.69673538], [82.60205078, 27.70402718], [82.60527039, 27.70518494], [82.60591888, 27.70541573], [82.60701752, 27.70579338], [82.62081146, 27.70206451], [82.62123871, 27.70240784], [82.62950897, 27.70902443], [82.62961578, 27.71021461], [82.62975311, 27.71138573], [82.64044189, 27.70889854], [82.65721893, 27.71312523], [82.66616821, 27.72194862], [82.66656494, 27.72079468], [82.66840363, 27.71548653], [82.68271637, 27.71361542], [82.69111633, 27.71501541], [82.70088196, 27.72159386], [82.70121765, 27.72182465], [82.70394897, 27.71610641], [82.70703888, 27.71636391], [82.70974731, 27.72137833], [82.70991516, 27.72169876], [82.70751953, 27.7110157], [82.70781708, 27.70271492], [82.71191406, 27.69521523], [82.71762085, 27.6916256], [82.72020721, 27.68731117], [82.71856689, 27.68432426], [82.71691895, 27.68131447], [82.71721649, 27.67621613], [82.71723938, 27.67611313], [82.71811676, 27.67547035], [82.71798706, 27.6724472], [82.71800232, 27.6723671], [82.71513367, 27.67074776], [82.71786499, 27.66788864], [82.71739197, 27.66705513], [82.71734619, 27.66697693], [82.71687317, 27.66614914], [82.71375275, 27.66493607], [82.71621704, 27.66241455], [82.72234344, 27.66155052], [82.72097015, 27.65881729], [82.72234344, 27.65720177], [82.72458649, 27.65836716], [82.72569275, 27.65894127], [82.72653961, 27.65860558], [82.72668457, 27.65854645], [82.72756195, 27.6581955], [82.7322464, 27.65279007], [82.73241425, 27.65261459], [82.73339844, 27.64887428], [82.73309326, 27.64832687], [82.73278046, 27.64775658], [82.7321701, 27.64775658], [82.7303772, 27.64665413], [82.73004913, 27.64539528], [82.73551178, 27.64601707], [82.73526764, 27.64252472], [82.73812103, 27.64303398], [82.73961639, 27.64054871], [82.73948669, 27.63681984], [82.73700714, 27.63545418], [82.7401123, 27.63184929], [82.73564148, 27.62837219], [82.73861694, 27.62576103], [82.73770905, 27.62503242], [82.73675537, 27.62426949], [82.73281097, 27.62388229], [82.73861694, 27.62151527], [82.73503113, 27.61853027], [82.73712921, 27.61606598], [82.73683167, 27.61534119], [82.7371521, 27.61334229], [82.73825073, 27.61121941], [82.73761749, 27.61041641], [82.73687744, 27.6094799], [82.74051666, 27.60651588], [82.74421692, 27.60451508], [82.74729919, 27.60014153], [82.74681854, 27.59518814], [82.75170135, 27.59370232], [82.75198364, 27.59344292], [82.75738525, 27.58835411], [82.75758362, 27.58764458], [82.75764465, 27.5874424], [82.75788116, 27.58661461], [82.75415802, 27.58387947], [82.75291443, 27.57681465], [82.75080109, 27.57605171], [82.75099945, 27.57501221], [82.75117493, 27.57406235], [82.74978638, 27.57198143], [82.74971771, 27.57181549], [82.75341034, 27.56548691], [82.74991608, 27.56261444], [82.74597931, 27.56123543], [82.74885559, 27.55524635], [82.74906158, 27.55492401], [82.74371338, 27.55393028], [82.74197388, 27.55144501], [82.7401123, 27.55194092], [82.74048615, 27.55032539], [82.74162292, 27.55009842], [82.74297333, 27.54982948], [82.73962402, 27.54673195], [82.74171448, 27.54532051], [82.74396515, 27.54597664], [82.74272156, 27.54460907], [82.74458313, 27.54324341], [82.74344635, 27.54282951], [82.74321747, 27.54274559], [82.74371338, 27.54125404], [82.743927, 27.5412159], [82.74507904, 27.54100609], [82.74376678, 27.53999138], [82.74346924, 27.5397625], [82.74357605, 27.53856277], [82.74371338, 27.53702927], [82.74336243, 27.53695869], [82.74331665, 27.53661537], [82.7444458, 27.5355854], [82.74582672, 27.5356617], [82.7465744, 27.5339222], [82.745224, 27.53372955], [82.7448349, 27.53367424], [82.74404144, 27.53208542], [82.74394226, 27.53194809], [82.74707031, 27.53205872], [82.74700165, 27.53177261], [82.74821472, 27.53171539], [82.74736786, 27.53019524], [82.74918365, 27.53143692], [82.74712372, 27.52889442], [82.74707031, 27.52882767], [82.74734497, 27.52865982], [82.74893188, 27.52770805], [82.74879456, 27.52715302], [82.74843597, 27.5257206], [82.74946594, 27.52616882], [82.75042725, 27.52659035], [82.751297, 27.52447701], [82.75053406, 27.52382088], [82.75071716, 27.52341461], [82.75033569, 27.52283096], [82.75141907, 27.52261353], [82.74906158, 27.51938248], [82.74861908, 27.52021599], [82.74819183, 27.52087402], [82.74423981, 27.52099419], [82.74411774, 27.52101517], [82.74511719, 27.51653099], [82.73971558, 27.51821518], [82.73911285, 27.50900841], [82.73961639, 27.50856972], [82.73711395, 27.50821495], [82.73703766, 27.50453568], [82.73700714, 27.50310135], [82.76049042, 27.50111771], [82.77727509, 27.50051689], [82.78731537, 27.50001526], [82.80361176, 27.4963913], [82.83705139, 27.50150871], [82.85021973, 27.49941444], [82.87231445, 27.49841499], [82.89451599, 27.50061607], [82.92307281, 27.50112915], [82.92788696, 27.50123787], [82.93161774, 27.50086594], [82.94068146, 27.49202728], [82.94152069, 27.49121284], [82.94689941, 27.47675705], [82.95134735, 27.47249031], [82.95622253, 27.46780777], [82.9628067, 27.46582031], [82.99996948, 27.45836449], [83.01813507, 27.45408821], [83.02532196, 27.4523983], [83.03611755, 27.44871521], [83.07141876, 27.45141602], [83.07691956, 27.45264816], [83.09571075, 27.4536171], [83.11310577, 27.45451546], [83.1346817, 27.45562935], [83.14788055, 27.45640182], [83.1661911, 27.45749664], [83.16651917, 27.45751572], [83.16725159, 27.45737076], [83.17606354, 27.45562935], [83.17546844, 27.45603943], [83.19021606, 27.45401573], [83.19805908, 27.4459362], [83.20550537, 27.43470573], [83.21247864, 27.42418861], [83.2159729, 27.42075539], [83.21906281, 27.41772652], [83.22776031, 27.41176033], [83.23985291, 27.40727997], [83.2421875, 27.40642929], [83.25920105, 27.39398956], [83.2742157, 27.38341522], [83.26889801, 27.36851311], [83.26765442, 27.36540604], [83.27462006, 27.35261536], [83.2947464, 27.33595467], [83.29430389, 27.33551407], [83.29441833, 27.33541489], [83.29541016, 27.33475494], [83.29636383, 27.33471107], [83.29653168, 27.33401871], [83.29866028, 27.334198], [83.30121613, 27.33441544], [83.30179596, 27.33408356], [83.30257416, 27.33421516], [83.30680084, 27.33123207], [83.31015778, 27.33334351], [83.31528473, 27.33152199], [83.31960297, 27.32998848], [83.31755829, 27.3326664], [83.32059479, 27.3357048], [83.32026672, 27.33649635], [83.31996918, 27.33719635], [83.32605743, 27.33662224], [83.3265152, 27.33657837], [83.32691956, 27.33631516], [83.3299942, 27.33403206], [83.33090973, 27.33421516], [83.33364868, 27.33254433], [83.33370972, 27.33250618], [83.33398438, 27.33254242], [83.33699799, 27.33346939], [83.33813477, 27.33308983], [83.33831787, 27.33311462], [83.34521484, 27.33487892], [83.34606934, 27.3380661], [83.35451508, 27.33981514], [83.35444641, 27.33992386], [83.35292053, 27.34221458], [83.35762024, 27.34441566], [83.36121368, 27.34301567], [83.3605423, 27.34913826], [83.35986328, 27.35024643], [83.36658478, 27.35558319], [83.37001801, 27.35561562], [83.37179565, 27.35795021], [83.3757782, 27.35712242], [83.37612152, 27.36005592], [83.37442017, 27.36481476], [83.37602234, 27.36876297], [83.37676239, 27.3697567], [83.38481903, 27.37073898], [83.39019012, 27.37572098], [83.38845062, 27.3803196], [83.39006042, 27.38355064], [83.38838959, 27.38480377], [83.38707733, 27.38578796], [83.38681793, 27.39011574], [83.39031982, 27.39151573], [83.39463806, 27.39549446], [83.39803314, 27.39562988], [83.39950562, 27.39784241], [83.40071869, 27.39809799], [83.40758514, 27.40529823], [83.4079361, 27.40789795], [83.40851593, 27.41177559], [83.41168976, 27.4125061], [83.41156006, 27.41364861], [83.41143799, 27.41474342], [83.40921783, 27.41511536], [83.40761566, 27.41861534], [83.40187073, 27.4189682], [83.40253448, 27.4199028], [83.39789581, 27.42232513], [83.39493561, 27.42503548], [83.39381409, 27.42951584], [83.38683319, 27.43512535], [83.3866806, 27.43566132], [83.38665009, 27.43577194], [83.38633728, 27.43686485], [83.38829041, 27.43893242], [83.38839722, 27.43913841], [83.38608551, 27.4407177], [83.38601685, 27.44151688], [83.38596344, 27.44220734], [83.39170837, 27.44455147], [83.39201355, 27.4447155], [83.39366913, 27.446558], [83.39611053, 27.44640923], [83.39776611, 27.44634056], [83.40071869, 27.44891548], [83.40398407, 27.45749283], [83.40201569, 27.45971489], [83.4019928, 27.45983887], [83.40187073, 27.46345901], [83.40460205, 27.46606827], [83.40335846, 27.467062], [83.40000153, 27.46532249], [83.39791107, 27.46637154], [83.39752197, 27.46661568], [83.39761353, 27.46951485], [83.39740753, 27.46958351], [83.39068604, 27.47054291], [83.39105988, 27.47290421], [83.39439392, 27.47624016], [83.39093018, 27.47949028], [83.40857697, 27.47886848], [83.48214722, 27.47538948], [83.49269867, 27.47491455], [83.50961304, 27.47414589], [83.55323029, 27.47228241], [83.60956573, 27.46974564], [83.61673737, 27.46942329], [83.64095306, 27.45854187], [83.66812897, 27.4469986], [83.68692017, 27.43779182], [83.69441986, 27.43411446], [83.6951828, 27.43373871], [83.70932007, 27.42679787], [83.7109375, 27.42605209], [83.7473526, 27.4090271], [83.76187897, 27.40243149], [83.79705811, 27.3861599], [83.79775238, 27.38584137], [83.79941559, 27.38521576], [83.81408691, 27.37833214], [83.83322144, 27.36950874], [83.85471344, 27.3537159], [83.85850525, 27.35096169], [83.85640717, 27.34821129], [83.85624695, 27.3477211], [83.8549881, 27.34033012], [83.84934235, 27.33560944], [83.82933807, 27.32747078], [83.82833099, 27.3259182], [83.82849121, 27.32467079], [83.8289566, 27.32275963], [83.83058929, 27.32135963], [83.83625793, 27.3194809], [83.8425293, 27.32131195], [83.84523773, 27.31965256], [83.84741974, 27.3168602], [83.84797668, 27.31397057], [83.85051727, 27.31209946], [83.85463715, 27.31122971], [83.85907745, 27.3116703], [83.87240601, 27.31620979], [83.88794708, 27.32646942], [83.89356232, 27.32905006], [83.89758301, 27.33012962], [83.90804291, 27.33039093], [83.91668701, 27.32533073], [83.92359924, 27.31643105], [83.92534637, 27.30952072], [83.92565155, 27.30418968], [83.92188263, 27.29635811], [83.91883087, 27.29265976], [83.9105072, 27.28563118], [83.90406799, 27.2811718], [83.89804077, 27.27898979], [83.89615631, 27.277071], [83.89549255, 27.26815033], [83.89795685, 27.25942993], [83.90190125, 27.25213051], [83.90762329, 27.24802971], [83.91175842, 27.24650192], [83.92531586, 27.24253082], [83.94814301, 27.23833084], [83.95448303, 27.23504066], [83.95585632, 27.23352051], [83.95501709, 27.23106956], [83.96153259, 27.22795105], [83.96376038, 27.22526932], [83.96411896, 27.22319031], [83.96328735, 27.22108078], [83.96031189, 27.21665955], [83.96167755, 27.21376038], [83.96457672, 27.21100998], [83.97660828, 27.20342064], [83.97878265, 27.20043945], [83.98512268, 27.1817627], [83.98419952, 27.17871094], [83.97972107, 27.17340279], [83.9683075, 27.16559982], [83.96658325, 27.1608429], [83.95864868, 27.1486702], [83.95091248, 27.14088058], [83.95079803, 27.13908005], [83.95363617, 27.13194084], [83.9524765, 27.12898254], [83.95081329, 27.12634087], [83.94766235, 27.12362099], [83.94143677, 27.11983109], [83.93955994, 27.11667061], [83.93839264, 27.11102295], [83.93856812, 27.10732079], [83.94034576, 27.10230064], [83.93942261, 27.09299278], [83.94082642, 27.08962059], [83.94409943, 27.08725166], [83.94777679, 27.08620071], [83.9549408, 27.08612061], [83.97120667, 27.09194183], [83.97786713, 27.09262085], [83.98123169, 27.09382057], [83.99017334, 27.09884071], [83.99265289, 27.10014915], [83.99751282, 27.09848022], [84.00251007, 27.10028076], [84.00531769, 27.10403061], [84.0116272, 27.10488129], [84.01422119, 27.10008049], [84.02072144, 27.09548187], [84.01892853, 27.09344101], [84.01609802, 27.09176064], [84.01831818, 27.08723831], [84.01689148, 27.08376122], [84.01194, 27.08127975], [84.00559235, 27.07193947], [83.9910965, 27.07129288], [83.9907608, 27.06859016], [83.99489594, 27.06125069], [84.01217651, 27.05379105], [84.0242691, 27.0447197], [84.03125763, 27.04646111], [84.0356369, 27.0465107], [84.04081726, 27.04467964], [84.04030609, 27.03530121], [84.03595734, 27.02901268], [84.03572845, 27.01931953], [84.03044891, 27.01181984], [84.03993225, 27.00587273], [84.04270172, 27.00312042], [84.04516602, 26.99973106], [84.04432678, 26.99768066], [84.0495224, 26.99081039], [84.0459671, 26.98715973], [84.03901672, 26.98801994], [84.03643036, 26.98403168], [84.04250336, 26.9815712], [84.04345703, 26.98039055], [84.04125977, 26.96801186], [84.04599762, 26.96809006], [84.04666138, 26.96194077], [84.04415894, 26.96087074], [84.04086304, 26.95745277], [84.03862, 26.95775986], [84.03909302, 26.95430946], [84.03514862, 26.94872093], [84.0316925, 26.94933128], [84.02636719, 26.94896126], [84.02490234, 26.94272041], [84.02880859, 26.94120026], [84.02980804, 26.93956947], [84.03630829, 26.94113159], [84.03866577, 26.93828964], [84.03655243, 26.93301964], [84.03846741, 26.93087959], [84.04521942, 26.93042183], [84.04766846, 26.93182945], [84.04924011, 26.91459084], [84.04408264, 26.90979958], [84.04239655, 26.90912819], [84.04514313, 26.90474129], [84.04737854, 26.90621948], [84.05079651, 26.90164948], [84.04898071, 26.89994049], [84.05200195, 26.89170074], [84.05905151, 26.8907795], [84.06008911, 26.88646126], [84.07155609, 26.88187027], [84.0762558, 26.87878036], [84.08550262, 26.88524246], [84.08789063, 26.88235283], [84.08651733, 26.8789196], [84.09002686, 26.87715149], [84.09262085, 26.87783051], [84.09683228, 26.88633919], [84.09986877, 26.88799095], [84.10106659, 26.89383125], [84.09922028, 26.89521027], [84.10063171, 26.90084076], [84.10640717, 26.8950901], [84.10941315, 26.89443016], [84.11164093, 26.89188957], [84.12201691, 26.8926506], [84.12301636, 26.88902092], [84.13024902, 26.88527107], [84.14083862, 26.88758087], [84.14073944, 26.88391113], [84.13861847, 26.88306999], [84.13752747, 26.87630081], [84.13929749, 26.8740406], [84.13183594, 26.87055969], [84.13165283, 26.85569], [84.15054321, 26.83946991], [84.15727997, 26.83636093], [84.16892242, 26.83451843], [84.17471313, 26.8357811], [84.17740631, 26.8426609], [84.17533112, 26.84593964], [84.17694855, 26.84937859], [84.1764679, 26.85334015], [84.18080902, 26.85737991], [84.18531799, 26.86009026], [84.18955994, 26.85981941], [84.19655609, 26.86118126], [84.20922089, 26.87099075], [84.22109985, 26.87223816], [84.22196198, 26.87018013], [84.2286377, 26.8698101], [84.23538208, 26.86433983], [84.2410965, 26.86243057], [84.24563599, 26.85872269], [84.25211334, 26.84492111], [84.25041962, 26.83782005], [84.25102997, 26.83069992], [84.24646759, 26.8275795], [84.242836, 26.82181931], [84.2485199, 26.82089806], [84.24680328, 26.81454086], [84.25229645, 26.80867958], [84.2493515, 26.8022728], [84.24848938, 26.79268074], [84.24112701, 26.77543068], [84.23548889, 26.76698112], [84.22460938, 26.75710106], [84.2332077, 26.74510956], [84.2339859, 26.73953056], [84.24227905, 26.73077011], [84.24738312, 26.72929001], [84.25234222, 26.73147011], [84.25448608, 26.73426819], [84.25528717, 26.73896027], [84.25936127, 26.74081993], [84.26677704, 26.74207115], [84.27130127, 26.74454117], [84.27861023, 26.75123978], [84.28675079, 26.75144005], [84.29802704, 26.7532711], [84.30664825, 26.73957062], [84.30561829, 26.73768044], [84.3110199, 26.73360252], [84.31851196, 26.71623039], [84.32334137, 26.68847847], [84.32566071, 26.68425751], [84.33706665, 26.68144035], [84.34480286, 26.68042946], [84.35012054, 26.6814003], [84.35484314, 26.67888069], [84.36675262, 26.67881012], [84.40223694, 26.67122269], [84.40479279, 26.64275169], [84.40737152, 26.63805962], [84.41439819, 26.62717056], [84.4005661, 26.62413025], [84.39499664, 26.62573814], [84.38343811, 26.62150955], [84.37885284, 26.62183952], [84.37059021, 26.61539078], [84.35093689, 26.62042809], [84.3300705, 26.61832047], [84.32549286, 26.61532021], [84.3107605, 26.61457253], [84.30651855, 26.6170311], [84.30267334, 26.61747169], [84.29702759, 26.61569977], [84.29502106, 26.60663033], [84.2931366, 26.60551071], [84.28919983, 26.60699081], [84.28679657, 26.60392189], [84.27934265, 26.60658073], [84.27741241, 26.60073853], [84.27346802, 26.60135078], [84.2722168, 26.59936142], [84.26291656, 26.60302162], [84.25888824, 26.60732269], [84.25063324, 26.60794067], [84.24009705, 26.61004066], [84.2309494, 26.6097908], [84.22866821, 26.61321068], [84.22305298, 26.61309052], [84.22199249, 26.61568069], [84.21569824, 26.61868095], [84.20681763, 26.6209507], [84.20388031, 26.62053108], [84.20198822, 26.62434006], [84.18467712, 26.62585068], [84.17698669, 26.62454033], [84.16779327, 26.62629128], [84.16725159, 26.6241703], [84.14853668, 26.62774849], [84.15345764, 26.63367081], [84.15203094, 26.63850021], [84.13951111, 26.63903046], [84.13742065, 26.63648033], [84.12906647, 26.63850021], [84.12413025, 26.63741112], [84.12098694, 26.63755035], [84.12146759, 26.63462067], [84.1156311, 26.63743019], [84.1060791, 26.63723183], [84.10431671, 26.63266182], [84.09934998, 26.63396835], [84.09934998, 26.63557053], [84.09493256, 26.63648033], [84.09407806, 26.63832092], [84.08448792, 26.6401329], [84.08177948, 26.64286041], [84.08042145, 26.64075279], [84.08138275, 26.63677979], [84.08059692, 26.63392067], [84.08383942, 26.6314106], [84.08213806, 26.62655067], [84.07962036, 26.6237011], [84.08352661, 26.61825943], [84.08280182, 26.61505127], [84.08476257, 26.61055946], [84.08178711, 26.60311127], [84.08252716, 26.59959984], [84.07914734, 26.59435081], [84.07028961, 26.58925819], [84.0712204, 26.58448029], [84.06772614, 26.58130074], [84.06285095, 26.57969284], [84.05690765, 26.57341003], [84.05474854, 26.5676899], [84.04931641, 26.56159019], [84.04814148, 26.55751991], [84.04878235, 26.55033112], [84.04776001, 26.54348946], [84.0430069, 26.54096031], [84.03082275, 26.53555107], [84.02004242, 26.5320797], [84.01448059, 26.53202057], [84.00068665, 26.52501106], [83.9986496, 26.52503014], [83.99835205, 26.5273819], [83.99030304, 26.53014183], [83.9835968, 26.53146172], [83.97418976, 26.53194046], [83.97054291, 26.52943993], [83.96810913, 26.52584076], [83.96655273, 26.52095032], [83.96541595, 26.51173973], [83.9625473, 26.50860023], [83.95616913, 26.50819969], [83.94565582, 26.5102005], [83.94271851, 26.51347923], [83.94352722, 26.51589966], [83.94584656, 26.51842117], [83.9392395, 26.52128029], [83.93499756, 26.52444077], [83.93048859, 26.52478027], [83.91467285, 26.52024078], [83.90220642, 26.51807976], [83.90084076, 26.51371193], [83.90175629, 26.51044083], [83.90679169, 26.50675964], [83.90746307, 26.50037956], [83.90496826, 26.49434853], [83.90323639, 26.47227097], [83.90154266, 26.46730995], [83.90302277, 26.4610405], [83.90228271, 26.45025063], [83.9081192, 26.44950104], [83.91902161, 26.44552994], [83.9360733, 26.44168091], [83.94626617, 26.43810844], [83.96129608, 26.43714905], [83.98195648, 26.4346199], [83.9834671, 26.43490028], [83.990448, 26.44762993], [83.99263, 26.44761086], [84.00170135, 26.44359016], [84.0090332, 26.44498062], [84.01098633, 26.44845963], [84.01611328, 26.44197083], [84.01494598, 26.43947029], [84.0164032, 26.43192291], [84.02052307, 26.42884064], [84.02178192, 26.4250412], [84.03318024, 26.41378021], [84.03056335, 26.41300964], [84.03618622, 26.40784073], [84.03826141, 26.41040039], [84.04087067, 26.40849113], [84.0412674, 26.40555], [84.04498291, 26.4052906], [84.04509735, 26.40407181], [84.05497742, 26.40204811], [84.0550766, 26.40024757], [84.06181335, 26.39427948], [84.06151581, 26.39009094], [84.07061768, 26.38689041], [84.07200623, 26.38446999], [84.0772171, 26.38396263], [84.07884216, 26.38572121], [84.08055878, 26.38622093], [84.08116913, 26.38966942], [84.087677, 26.39011955], [84.08970642, 26.38751984], [84.09230042, 26.39043045], [84.09654236, 26.38791084], [84.11519623, 26.38756943], [84.11675262, 26.38524818], [84.12844086, 26.38421059], [84.13078308, 26.3821907], [84.15402985, 26.37615967], [84.15634155, 26.37825966], [84.1713562, 26.37397957], [84.1696167, 26.36256027], [84.16723633, 26.36022949], [84.16720581, 26.33810997], [84.17681885, 26.32249069], [84.18173981, 26.31703949], [84.17944336, 26.31178093], [84.17150879, 26.30369186], [84.16874695, 26.29286957], [84.1709671, 26.28664017], [84.16964722, 26.27723122], [84.16815948, 26.27367973], [84.17099762, 26.27050018], [84.1713562, 26.26773071], [84.1676178, 26.26402092], [84.16365051, 26.26136971], [84.15740204, 26.26091957], [84.15512848, 26.25772095], [84.15570831, 26.25254059], [84.15934753, 26.24590111], [84.15730286, 26.24413109], [84.1534729, 26.24526978], [84.14533997, 26.26165962], [84.1414032, 26.25774956], [84.12594604, 26.26144981], [84.12375641, 26.25881958], [84.11295319, 26.26192093], [84.11234283, 26.25657272], [84.1099472, 26.25309753], [84.11270142, 26.24967957], [84.11045837, 26.24183083], [84.10135651, 26.2430706], [84.10035706, 26.2392807], [84.09229279, 26.24022102], [84.09137726, 26.23402977], [84.08738708, 26.23653984], [84.07952118, 26.23184013], [84.08190155, 26.22710037], [84.08014679, 26.22442055], [84.07936859, 26.22121048], [84.07367706, 26.22103119], [84.07357788, 26.22488022], [84.05835724, 26.22674942], [84.05726624, 26.22521019], [84.04943848, 26.22557068], [84.04680634, 26.23019028], [84.03363037, 26.23208809], [84.03115845, 26.23567009], [84.03132629, 26.23907089], [84.02400208, 26.23958969], [84.02050018, 26.24163055], [84.01838684, 26.23878098], [84.01412201, 26.24058914], [84.01152039, 26.2406826], [84.01048279, 26.23879051], [84.01091003, 26.23581123], [84.00551605, 26.23406982], [84.0082016, 26.22531128], [84.00946045, 26.22392082], [84.01676941, 26.22161293], [84.02047729, 26.22364998], [84.0242691, 26.21976089], [84.02091217, 26.21422005], [84.01902008, 26.20928955], [84.01950073, 26.20601082], [84.02323914, 26.20449066], [84.02359009, 26.2009201], [84.02044678, 26.19755936], [84.01499939, 26.19742966], [84.00901031, 26.19955826], [84.00211334, 26.19013977], [84.00406647, 26.18069077], [84.00302124, 26.17823029], [84.01381683, 26.16698074], [84.01970673, 26.1640625], [84.02289581, 26.16534805], [84.02784729, 26.16296005], [84.02841187, 26.15962029], [84.02731323, 26.1530304], [84.02363586, 26.15414047], [84.0181427, 26.14512062], [84.03362274, 26.13747978], [84.04239655, 26.13154984], [84.04524231, 26.12042046], [84.04187775, 26.12050056], [84.04361725, 26.11717033], [84.04223633, 26.11162186], [84.04514313, 26.10631943], [84.04824829, 26.10383034], [84.04905701, 26.09970093], [84.06923676, 26.09912109], [84.08113861, 26.09976959], [84.09104156, 26.09654045], [84.1071701, 26.08171272], [84.11605072, 26.0748806], [84.12792206, 26.05553055], [84.13667297, 26.04701042], [84.1590271, 26.03224182], [84.16726685, 26.02547073], [84.166008, 26.00270081], [84.16622925, 25.99150085], [84.17024231, 25.99166107], [84.17243958, 25.99879074], [84.17640686, 25.99775124], [84.192276, 25.98953819], [84.19474792, 25.99130058], [84.20181274, 26.00056076], [84.21412659, 25.99620056], [84.22344208, 25.99117088], [84.23522949, 25.98600006], [84.24048615, 25.98275948], [84.24455261, 25.97681808], [84.25466919, 25.97108841], [84.2645874, 25.96726036], [84.27536774, 25.96129036], [84.28366089, 25.95560074], [84.29155731, 25.94828033], [84.29633331, 25.94698906], [84.30310822, 25.94639015], [84.30927277, 25.94688988], [84.3138504, 25.94796944], [84.34371185, 25.9587307], [84.34880066, 25.95998192], [84.35138702, 25.95934105], [84.36501312, 25.95053291], [84.3862915, 25.93818092], [84.40830231, 25.93135071], [84.4092865, 25.92438126], [84.4175415, 25.9114399], [84.42151642, 25.90220833], [84.42417145, 25.89833832], [84.42331696, 25.89242172], [84.4276886, 25.89118958], [84.43118286, 25.89266968], [84.44371796, 25.88966942], [84.45066071, 25.89022064], [84.46105194, 25.888731], [84.46655273, 25.88368988], [84.47867584, 25.88836098], [84.4852829, 25.8892498], [84.50652313, 25.8723793], [84.52864075, 25.87774086], [84.53164673, 25.87272072], [84.54055023, 25.86211967], [84.53990936, 25.8603611], [84.52825928, 25.86473083], [84.51999664, 25.86115074], [84.52625275, 25.85540962], [84.52697754, 25.83432961], [84.53292084, 25.83222961], [84.54425049, 25.82998085], [84.54685211, 25.84132004], [84.55654907, 25.83751106], [84.57141876, 25.82983971], [84.5871582, 25.81960106], [84.59819794, 25.80965042], [84.61089325, 25.80065918], [84.61682892, 25.79554939], [84.62021637, 25.79409027], [84.62111664, 25.79236031], [84.6190567, 25.78897095], [84.62075043, 25.77238083], [84.6146698, 25.77242279], [84.61013794, 25.77728081], [84.60289001, 25.77243996], [84.60053253, 25.76062965], [84.60318756, 25.75757027], [84.61487579, 25.75283813], [84.62232971, 25.74731827], [84.62628174, 25.74160194], [84.62989807, 25.73311043], [84.63059998, 25.72834015], [84.62419128, 25.72790909], [84.61306, 25.73073959], [84.59552002, 25.73911095], [84.55562592, 25.73640823], [84.55896759, 25.72165108], [84.55860901, 25.70098114], [84.55639648, 25.68857002], [84.55233002, 25.68403053], [84.53138733, 25.69283295], [84.53586578, 25.72649002], [84.5304718, 25.72462082], [84.52794647, 25.71537018], [84.52458954, 25.68435097], [84.51638031, 25.67770958], [84.50576782, 25.68226051], [84.49903107, 25.67739105], [84.48838806, 25.67785072], [84.48934174, 25.69108963], [84.46650696, 25.68551064], [84.46031952, 25.69071007], [84.46276093, 25.6958828], [84.4631958, 25.69864273], [84.45877838, 25.69843292], [84.45865631, 25.70321083], [84.45516968, 25.71031189], [84.44901276, 25.71138], [84.44877625, 25.71449089], [84.43855286, 25.71068001], [84.43247223, 25.71207809], [84.42417145, 25.71171951], [84.42360687, 25.6950798], [84.4108963, 25.69847107], [84.40187836, 25.69950104], [84.39710999, 25.70907021], [84.4004364, 25.71689034], [84.39546967, 25.72439957], [84.39311981, 25.72602081], [84.39364624, 25.72890282], [84.38117218, 25.73425102], [84.38448334, 25.73768044], [84.38852692, 25.74427986], [84.38001251, 25.74868965], [84.37296295, 25.74226952], [84.36953735, 25.74373055], [84.3675766, 25.74170113], [84.37168884, 25.73830032], [84.36950684, 25.7360096], [84.36617279, 25.73843956], [84.35440826, 25.74361992], [84.33748627, 25.74513054], [84.3312912, 25.74457169], [84.32562256, 25.7371006], [84.32443237, 25.73327065], [84.32318878, 25.72313118], [84.32356262, 25.70400047], [84.32071686, 25.68208122], [84.31858826, 25.67193985], [84.31339264, 25.66890907], [84.31212616, 25.67242813], [84.29876709, 25.67179108], [84.29477692, 25.6741581], [84.29212952, 25.67704964], [84.28777313, 25.67632294], [84.28357697, 25.67713928], [84.28218842, 25.67461014], [84.2928009, 25.66852951], [84.29013062, 25.66283035], [84.28557587, 25.66152954], [84.2729187, 25.66168976], [84.26843262, 25.66325951], [84.24759674, 25.66281128], [84.23322296, 25.6639595], [84.21707916, 25.66406059], [84.20291138, 25.66963959], [84.19950867, 25.67234993], [84.19719696, 25.69223022], [84.19431305, 25.70342064], [84.17398071, 25.7157402], [84.16750336, 25.72175026], [84.15550995, 25.7259407], [84.14823151, 25.73096085], [84.14524841, 25.72860909], [84.14834595, 25.72601128], [84.14453125, 25.72060966], [84.13572693, 25.71688271], [84.12930298, 25.71735954], [84.12654877, 25.71851921], [84.13150024, 25.72393036], [84.1367569, 25.72375107], [84.13669586, 25.72754097], [84.13511658, 25.73163033], [84.12309265, 25.72394943], [84.10787201, 25.72364044], [84.09439087, 25.72038078], [84.08289337, 25.71269035], [84.06964874, 25.69561005], [84.07356262, 25.68357277], [84.07402802, 25.67250061], [84.07969666, 25.65273094], [84.07650757, 25.63753128], [84.05683136, 25.63222122], [84.02822113, 25.62273979], [84.01423645, 25.61613083], [84.00004578, 25.60771942], [83.99156952, 25.60102272], [83.95587921, 25.57542992], [83.94432068, 25.56734085], [83.93966675, 25.56543159], [83.9253006, 25.56315231], [83.92098236, 25.56172943], [83.91705322, 25.55849075], [83.91356659, 25.55434036], [83.89942169, 25.53177071], [83.89626312, 25.52827263], [83.89280701, 25.5254612], [83.8881073, 25.52321053], [83.88247681, 25.52145958], [83.87692261, 25.52140808], [83.87296295, 25.52040291], [83.86820984, 25.51163292], [83.8712616, 25.5031929], [83.86672974, 25.49349976], [83.86443329, 25.49061966], [83.85977936, 25.48920059], [83.85491943, 25.48485947], [83.85112, 25.47372055], [83.8478775, 25.47100258], [83.83378601, 25.4629612], [83.82935333, 25.46149063], [83.82467651, 25.46124077], [83.82256317, 25.46202278], [83.81474304, 25.46832085], [83.81233978, 25.46790123], [83.81022644, 25.46591949], [83.80671692, 25.45850945], [83.80555725, 25.45370102], [83.80793762, 25.45325279], [83.8103714, 25.45425034], [83.81381989, 25.45389938], [83.81858826, 25.45294762], [83.82150269, 25.45158005], [83.83043671, 25.45108032], [83.83338165, 25.45014954], [83.83751678, 25.44622993], [83.83943939, 25.44211006], [83.83937073, 25.43877983], [83.83837128, 25.43688965], [83.8302002, 25.43358994], [83.82408142, 25.43324089], [83.82064819, 25.43761063], [83.81762695, 25.43732071], [83.80294037, 25.43285942], [83.79670715, 25.43279266], [83.7943573, 25.43161964], [83.79270172, 25.43015862], [83.80319214, 25.42692947], [83.80522156, 25.42453003], [83.80327606, 25.41810989], [83.79936981, 25.41098022], [83.79660797, 25.40827942], [83.78227234, 25.39872932], [83.77068329, 25.40019989], [83.7651825, 25.39966011], [83.76346588, 25.39861107], [83.76225281, 25.39114189], [83.76193237, 25.38791084], [83.74973297, 25.39206123], [83.74971771, 25.39677048], [83.75195313, 25.39839172], [83.75887299, 25.40051079], [83.75805664, 25.40121078], [83.75332642, 25.40416908], [83.7507019, 25.40497017], [83.74809265, 25.40434074], [83.74198151, 25.4005909], [83.74060059, 25.40020943], [83.73784637, 25.40089035], [83.7349472, 25.40933037], [83.7325058, 25.41060066], [83.72944641, 25.40621948], [83.72717285, 25.39850044], [83.72531128, 25.39767075], [83.71806335, 25.39981079], [83.7154007, 25.39923286], [83.70947266, 25.39525032], [83.70400238, 25.38614845], [83.70140839, 25.38585091], [83.69893646, 25.38819122], [83.69628143, 25.39635086], [83.69458008, 25.39609909], [83.69277954, 25.39377022], [83.68940735, 25.38585091], [83.67626953, 25.38170052], [83.67520142, 25.37839127], [83.67681885, 25.37675095], [83.68784332, 25.37414169], [83.68897247, 25.3712883], [83.68628693, 25.36944962], [83.67899323, 25.36658096], [83.67221832, 25.36458969], [83.66908264, 25.3644619], [83.66477966, 25.36689949], [83.66020966, 25.37100029], [83.65791321, 25.3692112], [83.66020203, 25.36387062], [83.65879822, 25.36302948], [83.65616608, 25.36366081], [83.65020752, 25.36795998], [83.6496582, 25.36544037], [83.65059662, 25.36157036], [83.65022278, 25.35910034], [83.64540863, 25.35764122], [83.64351654, 25.35444069], [83.64657593, 25.34720039], [83.64440155, 25.34500122], [83.64250183, 25.34111977], [83.63877106, 25.34015274], [83.63182831, 25.34205055], [83.62996674, 25.34324074], [83.628479, 25.34113121], [83.62898254, 25.3379097], [83.62835693, 25.33625031], [83.62477112, 25.33493805], [83.62238312, 25.32952118], [83.62005615, 25.32858086], [83.61464691, 25.33166122], [83.61065674, 25.3325901], [83.60721588, 25.33230972], [83.60320282, 25.33156967], [83.58805847, 25.32644081], [83.58389282, 25.32489014], [83.58081818, 25.32234955], [83.5788269, 25.31726837], [83.57788086, 25.31664848], [83.57224274, 25.31761932], [83.56938171, 25.31013107], [83.56417084, 25.30814934], [83.56289673, 25.30965805], [83.56426239, 25.31585121], [83.56088257, 25.31608009], [83.55430603, 25.31406975], [83.55123138, 25.31389236], [83.54747772, 25.31585121], [83.53946686, 25.31764984], [83.53465271, 25.31520081], [83.53314972, 25.31287193], [83.5443573, 25.31314278], [83.54664612, 25.31160927], [83.54531097, 25.30985069], [83.54257965, 25.30932045], [83.53118134, 25.30451012], [83.52879333, 25.30144119], [83.52561188, 25.29953957], [83.52310181, 25.30045128], [83.52002716, 25.30332184], [83.51806641, 25.3024807], [83.51693726, 25.30060959], [83.51690674, 25.29846954], [83.51795197, 25.29323959], [83.51117706, 25.28782082], [83.5080719, 25.28619957], [83.50260162, 25.28957176], [83.49820709, 25.28297043], [83.49688721, 25.28300095], [83.49572754, 25.28440285], [83.49476624, 25.28729057], [83.4912796, 25.28659058], [83.48961639, 25.28116989], [83.48619843, 25.27950287], [83.48206329, 25.28289032], [83.48026276, 25.28240967], [83.47101593, 25.27214813], [83.470047, 25.26922989], [83.4719162, 25.26545906], [83.4704361, 25.26267815], [83.46325684, 25.25640869], [83.46028137, 25.25197029], [83.45729065, 25.25041008], [83.45355225, 25.25127983], [83.44294739, 25.25926018], [83.43979645, 25.25920105], [83.43321991, 25.25356102], [83.43115234, 25.25008011], [83.43136597, 25.24450111], [83.4287262, 25.24448967], [83.42251587, 25.25224113], [83.41934204, 25.25332069], [83.41854858, 25.25206947], [83.41934204, 25.24636078], [83.41706848, 25.24611092], [83.40927124, 25.24928093], [83.40690613, 25.2472496], [83.40416718, 25.24241066], [83.40233612, 25.23755074], [83.40151215, 25.23003006], [83.39727783, 25.22521019], [83.39597321, 25.22252083], [83.39505005, 25.21690941], [83.39113617, 25.21558952], [83.38990021, 25.21412086], [83.38999176, 25.2116394], [83.38822174, 25.20700836], [83.38535309, 25.20602989], [83.38173676, 25.21079826], [83.37957764, 25.21175003], [83.37770844, 25.20965958], [83.3745575, 25.20251083], [83.37210083, 25.20111084], [83.36662292, 25.20033073], [83.36026001, 25.1963501], [83.35597229, 25.1986618], [83.34960938, 25.19894028], [83.34739685, 25.19304085], [83.34394836, 25.18740273], [83.34121704, 25.18555069], [83.33586121, 25.18357086], [83.33535767, 25.18139267], [83.3380127, 25.17991066], [83.34224701, 25.17885971], [83.3481369, 25.17860031], [83.34673309, 25.16959953], [83.34509277, 25.16669083], [83.34320831, 25.15867043], [83.35080719, 25.15339088], [83.3524704, 25.15182114], [83.35343933, 25.14916039], [83.35399628, 25.14017105], [83.35212708, 25.13121986], [83.35762787, 25.12792015], [83.35736084, 25.12419128], [83.35375977, 25.11037254], [83.34783936, 25.11079979], [83.34288788, 25.11248016], [83.34012604, 25.11240005], [83.34031677, 25.09864998], [83.33802795, 25.08806038], [83.33669281, 25.08634949], [83.33351135, 25.08479118], [83.33222198, 25.0824604], [83.33120728, 25.07335281], [83.32778168, 25.06100082], [83.33123779, 25.05982971], [83.33360291, 25.05803108], [83.3338089, 25.05099106], [83.33210754, 25.05050087], [83.33016968, 25.05097961], [83.32711792, 25.0533905], [83.32624054, 25.0553894], [83.32495117, 25.05597115], [83.3219223, 25.05583], [83.32145691, 25.05243111], [83.32345581, 25.04805183], [83.31784058, 25.04165077], [83.3164978, 25.03838158], [83.31607056, 25.02733994], [83.31817627, 25.01732063], [83.31965637, 25.01554108], [83.32765198, 25.01632118], [83.33909607, 25.01189041], [83.34208679, 25.01146126], [83.34387207, 25.01048279], [83.34487915, 25.0026207], [83.34619904, 24.99596024], [83.34593201, 24.99209023], [83.34040833, 24.97921944], [83.34052277, 24.97481918], [83.33846283, 24.96355057], [83.34393311, 24.96388054], [83.34629822, 24.96294975], [83.34938049, 24.95952988], [83.35701752, 24.95535278], [83.35790253, 24.95162964], [83.35761261, 24.94598961], [83.35852051, 24.93740082], [83.35735321, 24.91924095], [83.35803223, 24.91399002], [83.35730743, 24.91140175], [83.35598755, 24.90983963], [83.35202789, 24.90784073], [83.35121155, 24.90623283], [83.35138702, 24.90306091], [83.36001587, 24.89184952], [83.35962677, 24.89018059], [83.35617828, 24.88921928], [83.35505676, 24.88747978], [83.35489655, 24.8855381], [83.35623169, 24.88430977], [83.36180115, 24.88233948], [83.36386871, 24.88043976], [83.36424255, 24.87858009], [83.36316681, 24.87697029], [83.3572464, 24.87352753], [83.35399628, 24.87061119], [83.35575104, 24.86865044], [83.36827087, 24.86318016], [83.37864685, 24.84613991], [83.38101959, 24.84445953], [83.38076019, 24.84303093], [83.38250732, 24.84025955], [83.38527679, 24.84007072], [83.38915253, 24.83607101], [83.39038849, 24.83308029], [83.38963318, 24.82715034], [83.39131165, 24.82315826], [83.39492798, 24.8202095], [83.39566803, 24.81559944], [83.39559937, 24.81099129], [83.39006042, 24.80442047], [83.38990021, 24.80185127], [83.39254761, 24.7971096], [83.3884964, 24.79154015], [83.38633728, 24.78659058], [83.38680267, 24.78421974], [83.39409637, 24.77947044], [83.40344238, 24.77667046], [83.41129303, 24.77532005], [83.41941833, 24.76987076], [83.42542267, 24.76311111], [83.43424225, 24.75684929], [83.44146729, 24.74403], [83.44467163, 24.74044991], [83.45308685, 24.73332024], [83.46243286, 24.73513031], [83.46695709, 24.73452759], [83.47174835, 24.73567009], [83.47532654, 24.73801994], [83.47984314, 24.73783112], [83.48245239, 24.73493958], [83.48332214, 24.73106956], [83.48327637, 24.72277069], [83.48036957, 24.71620941], [83.47997284, 24.70993805], [83.48071289, 24.70573235], [83.48335266, 24.70295906], [83.48589325, 24.70271111], [83.48960876, 24.70585823], [83.49205017, 24.70516014], [83.49498749, 24.70268059], [83.49571228, 24.6962204], [83.49990082, 24.69453049], [83.50917053, 24.6847496], [83.51264954, 24.68341064], [83.51370239, 24.68115044], [83.51319122, 24.67892075], [83.50218201, 24.67158127], [83.4994812, 24.66847992], [83.49704742, 24.65921974], [83.49752045, 24.65166092], [83.49971771, 24.64941025], [83.50251007, 24.64871025], [83.50717163, 24.64937019], [83.51590729, 24.64282036], [83.52169037, 24.64453125], [83.52394104, 24.64435005], [83.52419281, 24.64209938], [83.52068329, 24.6300106], [83.53890991, 24.62774277], [83.54141235, 24.62618065], [83.54171753, 24.6245594], [83.53843689, 24.62162971], [83.53453064, 24.61560059], [83.52555847, 24.61368942], [83.51743317, 24.60322952], [83.51721954, 24.59873009], [83.51999664, 24.59101105], [83.52350616, 24.58782005], [83.52498627, 24.58503914], [83.52514648, 24.58019829], [83.52400208, 24.57502174], [83.52458954, 24.5673008], [83.51793671, 24.55494118], [83.5171814, 24.54916954], [83.50495911, 24.54438972], [83.49341583, 24.54207039], [83.49320221, 24.53607941], [83.49761963, 24.52897072], [83.49816895, 24.52705956], [83.48671722, 24.52435112], [83.48139191, 24.52391052], [83.46186829, 24.51787758], [83.45308685, 24.51711082], [83.43563843, 24.5135994], [83.42636108, 24.51278114], [83.39997864, 24.50605965], [83.39546967, 24.50377083], [83.393013, 24.50119019], [83.39212799, 24.49711037], [83.39160156, 24.49283981], [83.39360809, 24.48891068], [83.39346313, 24.48476982], [83.39256287, 24.48027992], [83.38816833, 24.47326279], [83.38820648, 24.4681282], [83.38713074, 24.46457291], [83.3842392, 24.46140099], [83.38140869, 24.45565033], [83.38978577, 24.43758965], [83.39248657, 24.43642044], [83.40067291, 24.43713951], [83.3989563, 24.41208076], [83.40013885, 24.40867996], [83.41197205, 24.41025162], [83.41652679, 24.40947914], [83.4262085, 24.40604973], [83.42988586, 24.40378952], [83.43048859, 24.39600754], [83.43292999, 24.39404106], [83.43470764, 24.39063072], [83.43884277, 24.38899994], [83.43995667, 24.38698006], [83.4397583, 24.38013077], [83.44278717, 24.37764168], [83.44320679, 24.37278938], [83.44763947, 24.36844826], [83.45144653, 24.36700058], [83.45139313, 24.36474991], [83.44567108, 24.36327171], [83.44104767, 24.3608799], [83.43431091, 24.34747124], [83.43004608, 24.34495926], [83.42661285, 24.3399601], [83.42352295, 24.33870125], [83.41118622, 24.33955002], [83.40689087, 24.33899117], [83.40332794, 24.3373909], [83.3914032, 24.32677078], [83.38530731, 24.32034111], [83.37861633, 24.31552124], [83.37593842, 24.31454086], [83.37561035, 24.31344986], [83.38027191, 24.3047905], [83.38063812, 24.30046844], [83.38182831, 24.29988098], [83.38656616, 24.29756927], [83.39050293, 24.29652023], [83.39615631, 24.29339027], [83.4005127, 24.28524017], [83.40291595, 24.27613068], [83.40188599, 24.26600075], [83.39338684, 24.25266075], [83.39343262, 24.2471199], [83.39111328, 24.24464989], [83.38085938, 24.24002075], [83.37734222, 24.23566055], [83.37689972, 24.23093033], [83.37930298, 24.22019958], [83.37840271, 24.21685982], [83.37602997, 24.213871], [83.37621307, 24.21013069], [83.37822723, 24.2052803], [83.37834167, 24.20079041], [83.37049866, 24.18675041], [83.36936188, 24.18058968], [83.36560059, 24.17196083], [83.35735321, 24.15683937], [83.35607147, 24.14773941], [83.35250092, 24.14030075], [83.34992218, 24.13709259], [83.34900665, 24.12643814], [83.34355164, 24.11878967], [83.34279633, 24.11425018], [83.33904266, 24.11045074], [83.32356262, 24.1013298], [83.31894684, 24.10645103], [83.31491089, 24.10698128], [83.31352234, 24.10140038], [83.31344604, 24.09742928], [83.3110733, 24.09276009], [83.29242706, 24.07720947], [83.28900909, 24.07290077], [83.28417206, 24.06464958], [83.28040314, 24.05507088], [83.27748871, 24.04995918], [83.27680206, 24.04566956], [83.279953, 24.03476906], [83.27646637, 24.02730942], [83.27607727, 24.0232811], [83.2738266, 24.02115059], [83.27052307, 24.02026939], [83.26574707, 24.01725006], [83.26239777, 24.01366043], [83.25894928, 24.0116291], [83.25306702, 24.01213074], [83.24703217, 24.01519966], [83.24182129, 24.013731], [83.23697662, 24.00995827], [83.23535919, 24.00715065], [83.23692322, 24.00139046], [83.23352051, 23.99831009], [83.22677612, 23.99631119], [83.22252655, 23.99205971], [83.21602631, 23.98940277], [83.21476746, 23.9862709], [83.21562958, 23.98077965], [83.21057129, 23.97725105], [83.20835114, 23.9727993], [83.21063995, 23.96541023], [83.21121216, 23.96035767], [83.20587158, 23.95379066], [83.20323181, 23.94753265], [83.20176697, 23.94054031], [83.19135284, 23.93263054], [83.19313049, 23.92690086], [83.18956757, 23.92110062], [83.18312836, 23.91948128], [83.17756653, 23.91951942], [83.17260742, 23.91765976], [83.1678772, 23.91786957], [83.16433716, 23.91510963], [83.15785217, 23.91303062], [83.15557098, 23.91130829], [83.1452179, 23.90994263], [83.13878632, 23.90437126], [83.13526154, 23.8985405], [83.13437653, 23.89455032], [83.12741089, 23.89002037], [83.08660126, 23.87817192], [83.06104279, 23.87524033], [83.04345703, 23.87939072], [83.03643799, 23.88305092], [83.02546692, 23.88162994], [83.02052307, 23.88269806], [82.99227905, 23.87850952], [82.98396301, 23.87955284], [82.95359039, 23.87277031], [82.94950104, 23.87298965], [82.93881989, 23.87586975], [82.93308258, 23.87940025], [82.93058777, 23.88196945], [82.9251709, 23.89071083], [82.92251587, 23.89269066], [82.91747284, 23.895401], [82.90608215, 23.89789963], [82.89034271, 23.90456009], [82.88118744, 23.91028023], [82.87529755, 23.91641045], [82.86569214, 23.92266273], [82.86296082, 23.92552948], [82.85515594, 23.93877983], [82.84889984, 23.94683266], [82.84133911, 23.95014954], [82.82071686, 23.9649601], [82.8077774, 23.96305847], [82.80046844, 23.96748161], [82.79888153, 23.97089005], [82.79872131, 23.97661972], [82.80050659, 23.98533058], [82.80065155, 23.99655914], [82.8014679, 24.00106239], [82.79727173, 24.0051403], [82.78990173, 24.00677109], [82.78266907, 24.00695992], [82.76628876, 24.00605011], [82.75235748, 24.00843048], [82.74588776, 24.01311111], [82.74199677, 24.02140045], [82.73992157, 24.03104973], [82.74314117, 24.03487968], [82.75576782, 24.04359818], [82.76220703, 24.05988121], [82.76625824, 24.07786751], [82.76055145, 24.07967949], [82.75492096, 24.07324028], [82.75174713, 24.07959747], [82.74803925, 24.08053017], [82.74146271, 24.07509041], [82.73768616, 24.07872963], [82.72628021, 24.08256912], [82.70839691, 24.08076096], [82.70522308, 24.0857296], [82.70136261, 24.09707069], [82.66352844, 24.12392998], [82.65738678, 24.13479805], [82.66587067, 24.14278984], [82.66519928, 24.15112114], [82.67085266, 24.15847015], [82.6794281, 24.15673065], [82.68836212, 24.14422989], [82.72036743, 24.1389904], [82.72132111, 24.1498127], [82.72307587, 24.15681076], [82.73613739, 24.16835022], [82.73478699, 24.1830101], [82.73190308, 24.20107269], [82.72699738, 24.22326088], [82.73223114, 24.22797012], [82.73706055, 24.23031044], [82.74331665, 24.23161125], [82.74991608, 24.23612976], [82.75157166, 24.24586105], [82.74938965, 24.25662041], [82.75058746, 24.26813126], [82.75460815, 24.2716198], [82.75705719, 24.27569962], [82.76413727, 24.29243088], [82.76603699, 24.31220818], [82.75981903, 24.31908035], [82.76045227, 24.32310104], [82.76299286, 24.32982826], [82.76326752, 24.34243011], [82.76449585, 24.34754944], [82.75981903, 24.35838127], [82.75892639, 24.36314964], [82.75875854, 24.36931038], [82.76058197, 24.37304115], [82.75688934, 24.37594032], [82.7544632, 24.37951088], [82.74677277, 24.37252045], [82.73478699, 24.37117958], [82.71849823, 24.37122154], [82.71286011, 24.37520981], [82.70716095, 24.38517952], [82.70758057, 24.38937759], [82.71496582, 24.41617012], [82.71936798, 24.42163086], [82.72019196, 24.42967987], [82.72572327, 24.42625809], [82.73271179, 24.43274117], [82.72730255, 24.43414116], [82.72503662, 24.44473267], [82.72602081, 24.46084023], [82.73060608, 24.47033119], [82.72377014, 24.4763298], [82.73377991, 24.48723984], [82.73654938, 24.49977112], [82.71563721, 24.51329994], [82.71414948, 24.53619957], [82.7150116, 24.54811096], [82.71253204, 24.5562191], [82.71611023, 24.55714035], [82.73352814, 24.55162048], [82.74120331, 24.55459023], [82.74536133, 24.55251122], [82.74601746, 24.54152107], [82.78093719, 24.54606819], [82.80076599, 24.55268097], [82.79644012, 24.58749962], [82.79637146, 24.59976006], [82.78542328, 24.59951019], [82.76825714, 24.59754181], [82.76007843, 24.59981918], [82.7629776, 24.60481071], [82.76789093, 24.61061287], [82.76716614, 24.62943077], [82.76580048, 24.64163017], [82.76278687, 24.64566994], [82.74312592, 24.64406967], [82.72746277, 24.64647293], [82.71460724, 24.6421299], [82.70921326, 24.64371109], [82.70207214, 24.64211273], [82.6951828, 24.64425278], [82.69169617, 24.64863968], [82.69345856, 24.66157913], [82.69586945, 24.66871262], [82.69595337, 24.67572021], [82.69230652, 24.68022919], [82.68543243, 24.68652153], [82.66555023, 24.69986153], [82.65792847, 24.70039749], [82.64569855, 24.69454956], [82.63643646, 24.68783951], [82.62996674, 24.68670082], [82.60299683, 24.67945099], [82.58764648, 24.67373085], [82.57396698, 24.66300011], [82.54425812, 24.65487862], [82.52926636, 24.65196037], [82.52398682, 24.65714073], [82.51843262, 24.67834091], [82.50905609, 24.6790905], [82.501297, 24.67840958], [82.486763, 24.67550087], [82.47667694, 24.6835804], [82.4640274, 24.68007088], [82.44885254, 24.67790031], [82.44480896, 24.68008995], [82.44838715, 24.69062042], [82.44484711, 24.69637108], [82.43231201, 24.70628166], [82.42015076, 24.70525169], [82.40738678, 24.69514084], [82.40159607, 24.68379974], [82.40679932, 24.6744194], [82.4054718, 24.66682053], [82.41178894, 24.65784836], [82.40896606, 24.64956093], [82.40904999, 24.64306068], [82.40352631, 24.6361618], [82.40364838, 24.63097954], [82.40789032, 24.62281036], [82.40567017, 24.61751175], [82.41456604, 24.60639191], [82.40917206, 24.59782982], [82.40081787, 24.59869957], [82.39359283, 24.59749985], [82.38564301, 24.59737968], [82.36084747, 24.60200119], [82.35391998, 24.60447121], [82.35051727, 24.60820961], [82.34596252, 24.61880112], [82.33506012, 24.6229496], [82.32977295, 24.62375069], [82.32373047, 24.62254906], [82.31915283, 24.6202507], [82.31530762, 24.61535072], [82.30940247, 24.61293983], [82.29833984, 24.61242104], [82.29393005, 24.61374092], [82.29302979, 24.61689949], [82.29841614, 24.6280117], [82.29579926, 24.63624191], [82.29611206, 24.64332008], [82.29469299, 24.65385246], [82.29808807, 24.65654945], [82.29189301, 24.66477966], [82.29641724, 24.67001152], [82.29107666, 24.67086983], [82.28520966, 24.67001152], [82.28173828, 24.67174149], [82.27851105, 24.68087959], [82.2694931, 24.68186951], [82.2633667, 24.6864109], [82.25834656, 24.68209076], [82.26674652, 24.67840958], [82.25305176, 24.66609192], [82.24952698, 24.66833115], [82.24797821, 24.67556953], [82.23551941, 24.67638969], [82.23420715, 24.67193985], [82.23509979, 24.66591072], [82.22992706, 24.66963959], [82.22885132, 24.67459106], [82.2286911, 24.69075966], [82.23400116, 24.69656944], [82.24304962, 24.70176125], [82.24046326, 24.71055984], [82.24394989, 24.71638107], [82.24101257, 24.7269001], [82.24143982, 24.73846054], [82.24590302, 24.74065971], [82.24962616, 24.75636864], [82.24659729, 24.75976181], [82.24365997, 24.77575111], [82.24031067, 24.77547073], [82.24108887, 24.76827049], [82.2383728, 24.75440979], [82.2323761, 24.75814819], [82.22773743, 24.76556015], [82.22338867, 24.76417923], [82.22091675, 24.76704979], [82.21853638, 24.76498032], [82.22157288, 24.75991058], [82.22280884, 24.7517395], [82.20918274, 24.75951004], [82.19948578, 24.75206947], [82.2022171, 24.74817085], [82.21340179, 24.74420929], [82.21604919, 24.73615074], [82.21375275, 24.72866058], [82.20841217, 24.7389698], [82.2026062, 24.74078941], [82.19512939, 24.73994064], [82.18873596, 24.74377823], [82.17288208, 24.73957062], [82.1914978, 24.75316048], [82.19567108, 24.76374817], [82.19061279, 24.76955986], [82.19129181, 24.77486038], [82.18936157, 24.78228188], [82.19403839, 24.78326035], [82.20179749, 24.7806797], [82.20947266, 24.78149033], [82.20493317, 24.78550911], [82.20545959, 24.79144096], [82.20871735, 24.79776955], [82.20136261, 24.80065155], [82.19491577, 24.79694939], [82.18855286, 24.79821968], [82.1812973, 24.80084991], [82.17900848, 24.80465126], [82.18090057, 24.80821991], [82.19126892, 24.81772041], [82.19596863, 24.82452965], [82.18791962, 24.82071114], [82.18244171, 24.81678963], [82.17373657, 24.81418991], [82.17176056, 24.8088398], [82.16281128, 24.80498123], [82.17336273, 24.80096054], [82.16323853, 24.79577065], [82.15939331, 24.79226112], [82.14657593, 24.79730988], [82.13224792, 24.8044796], [82.12892151, 24.79976273], [82.12637329, 24.79394913], [82.11219025, 24.79226112], [82.10778809, 24.79368019], [82.10769653, 24.8008194], [82.10475922, 24.80560112], [82.1000061, 24.80994987], [82.0946579, 24.81036949], [82.08972931, 24.8159008], [82.08187103, 24.82211113], [82.07084656, 24.82493973], [82.06520081, 24.82344055], [82.05648804, 24.82807922], [82.04232788, 24.83424187], [82.03720093, 24.83296013], [82.02427673, 24.8446312], [82.00489044, 24.85069084], [81.99793243, 24.84744072], [81.99154663, 24.8465004], [81.97544861, 24.84246063], [81.96806335, 24.84386063], [81.96498108, 24.84142113], [81.96156311, 24.83172989], [81.95915222, 24.83061028], [81.95717621, 24.83213043], [81.95488739, 24.83924103], [81.94772339, 24.84259033], [81.94615173, 24.84671021], [81.93718719, 24.85005951], [81.93466949, 24.85144997], [81.93177032, 24.85649109], [81.92672729, 24.86079025], [81.92838287, 24.87306023], [81.92366791, 24.87627029], [81.91513062, 24.87779045], [81.91339111, 24.88041115], [81.91010284, 24.88043976], [81.90628815, 24.88354111], [81.90265656, 24.88413048], [81.89644623, 24.89250946], [81.89879608, 24.8993206], [81.89846039, 24.90518188], [81.90242004, 24.91150093], [81.91030884, 24.9204998], [81.91204071, 24.93091965], [81.90962219, 24.93714905], [81.90410614, 24.94226837], [81.90096283, 24.97305107], [81.89834595, 24.97532082], [81.89845276, 24.97686958], [81.90164185, 24.98282051], [81.90052032, 24.98483086], [81.89450073, 24.98740005], [81.89483643, 24.99109077], [81.89922333, 24.99924088], [81.89994812, 25.00344086], [81.89997101, 25.0072403], [81.89846802, 25.00962067], [81.89142609, 25.0134697], [81.889328, 25.01311111], [81.88822937, 25.01098061], [81.88861084, 25.00954819], [81.89160919, 25.00505066], [81.89402008, 25.00345993], [81.89309692, 24.99982071], [81.89058685, 24.99636841], [81.88772583, 24.99340057], [81.88613129, 24.99282074], [81.88331604, 24.99365044], [81.8813858, 24.99949265], [81.8735199, 25.00214005], [81.86837006, 25.00222969], [81.86683655, 25.00015068], [81.86454773, 25.00039291], [81.86371613, 25.00357056], [81.84938049, 25.00601006], [81.84629822, 25.00712013], [81.84002686, 25.01497269], [81.8349762, 25.01828194], [81.82936859, 25.01933289], [81.79165649, 25.01000977], [81.78922272, 25.01013947], [81.78011322, 25.01519012], [81.77871704, 25.01762009], [81.77139282, 25.02323914], [81.74977112, 25.03162193], [81.74740601, 25.03362274], [81.74646759, 25.0357399], [81.74150085, 25.03697014], [81.73821259, 25.03907013], [81.73723602, 25.04194069], [81.73446655, 25.0431385], [81.7350769, 25.04452133], [81.73239136, 25.04870987], [81.71640778, 25.05297279], [81.71382141, 25.04725075], [81.71338654, 25.04006004], [81.71012115, 25.03912926], [81.70536041, 25.03790283], [81.68553925, 25.04218292], [81.6818924, 25.04377174], [81.68371582, 25.05079079], [81.68306732, 25.0567627], [81.67780304, 25.06467819], [81.67582703, 25.06598091], [81.67137909, 25.06624985], [81.66398621, 25.06394958], [81.66221619, 25.06513977], [81.66040802, 25.07146072], [81.65989685, 25.07818031], [81.65869141, 25.07973099], [81.65650177, 25.07862091], [81.65307617, 25.07503128], [81.64684296, 25.07504082], [81.64598083, 25.07055092], [81.64418793, 25.06835937], [81.63559723, 25.06179047], [81.63201141, 25.06147957], [81.62525177, 25.06245995], [81.62190247, 25.05692101], [81.61725616, 25.05712128], [81.60852051, 25.05887985], [81.60434723, 25.06074905], [81.60272217, 25.06304169], [81.6032486, 25.06435966], [81.60558319, 25.0645504], [81.60855103, 25.06331062], [81.60971069, 25.06469917], [81.60811615, 25.06682014], [81.6039505, 25.06954193], [81.60280609, 25.07183075], [81.59446716, 25.07693291], [81.59379578, 25.07979965], [81.59591675, 25.08182907], [81.60443878, 25.08299065], [81.60949707, 25.08515167], [81.61486816, 25.09404755], [81.62088776, 25.09507942], [81.62153625, 25.09836006], [81.62583923, 25.09988976], [81.62930298, 25.09972954], [81.63166046, 25.10148048], [81.63195038, 25.10326958], [81.62265015, 25.11124039], [81.62534332, 25.1178112], [81.62506104, 25.12044907], [81.62329102, 25.12193108], [81.61675262, 25.12261963], [81.61483002, 25.1198597], [81.61302948, 25.11322975], [81.6100769, 25.11170959], [81.60639191, 25.10594177], [81.60426331, 25.09966278], [81.60122681, 25.10021019], [81.60280609, 25.11244965], [81.60180664, 25.1160183], [81.60230255, 25.11750984], [81.59102631, 25.12298965], [81.59146881, 25.12735939], [81.59414673, 25.12951279], [81.59211731, 25.13638115], [81.59417725, 25.13801193], [81.59918213, 25.13982964], [81.60430145, 25.14281082], [81.61001587, 25.14717102], [81.61223602, 25.14660072], [81.61506653, 25.14393044], [81.61763763, 25.14624977], [81.618927, 25.14908981], [81.61965942, 25.15563965], [81.61898804, 25.1596508], [81.61737061, 25.16389847], [81.61441803, 25.16506958], [81.61347198, 25.17052078], [81.61000061, 25.17365265], [81.60810852, 25.17276955], [81.60675812, 25.17057037], [81.60703278, 25.16805077], [81.60549164, 25.16562843], [81.6029129, 25.16588974], [81.60114288, 25.16736984], [81.599823, 25.16603088], [81.59657288, 25.16553116], [81.58177948, 25.16827011], [81.58194733, 25.17033005], [81.58799744, 25.1837883], [81.58560944, 25.18662071], [81.57718658, 25.19129944], [81.5716629, 25.1929512], [81.56639862, 25.19574928], [81.55844116, 25.18919182], [81.54902649, 25.18658066], [81.54876709, 25.18865013], [81.53991699, 25.18765831], [81.53401184, 25.18826103], [81.53333282, 25.18756104], [81.53253937, 25.18542099], [81.52321625, 25.1857605], [81.52007294, 25.1872406], [81.5128479, 25.18790054], [81.50956726, 25.18703079], [81.50778961, 25.18497086], [81.50711823, 25.17854118], [81.5078125, 25.17625046], [81.51074219, 25.17368126], [81.52728271, 25.16662025], [81.53000641, 25.16333961], [81.52884674, 25.16133118], [81.5199585, 25.15365982], [81.51873779, 25.15183067], [81.525177, 25.14753151], [81.52465057, 25.14364052], [81.51846313, 25.14254761], [81.51566315, 25.14533997], [81.51091003, 25.14840126], [81.50496674, 25.15122032], [81.50063324, 25.1528492], [81.4954071, 25.15234947], [81.49199677, 25.14875984], [81.48995972, 25.14191818], [81.49054718, 25.13504028], [81.48960876, 25.13422012], [81.48452759, 25.13434982], [81.4801712, 25.13770103], [81.47743225, 25.13842964], [81.4746933, 25.13812065], [81.4728775, 25.1371212], [81.47175598, 25.13499069], [81.4720459, 25.13303947], [81.47812653, 25.12792015], [81.47772217, 25.12108994], [81.48171997, 25.11732101], [81.48562622, 25.11586952], [81.49314117, 25.11065292], [81.50319672, 25.11051941], [81.50757599, 25.10680962], [81.50701904, 25.10532188], [81.50286865, 25.10172081], [81.50054932, 25.10083008], [81.4942627, 25.10169983], [81.49740601, 25.09604073], [81.49462128, 25.08210945], [81.49224091, 25.08192062], [81.4864502, 25.08410072], [81.4851532, 25.0775795], [81.4837265, 25.07493973], [81.48118591, 25.07590294], [81.47740173, 25.07925034], [81.47305298, 25.08093071], [81.46539307, 25.08184052], [81.45829773, 25.08677101], [81.45781708, 25.08934975], [81.4588623, 25.09299088], [81.436409, 25.09616089], [81.42479706, 25.09943962], [81.42082977, 25.1015892], [81.41314697, 25.10399055], [81.40306854, 25.10640907], [81.40084839, 25.10777092], [81.400383, 25.10914993], [81.40300751, 25.1115799], [81.40689087, 25.11201859], [81.41147614, 25.11230087], [81.42717743, 25.1106205], [81.43546295, 25.11103821], [81.43833923, 25.11044121], [81.43910217, 25.11198997], [81.43856812, 25.11400032], [81.43437195, 25.12194061], [81.42913818, 25.12953949], [81.43022156, 25.13363075], [81.42778015, 25.13360977], [81.41970062, 25.13560295], [81.41783905, 25.13517189], [81.41604614, 25.13228035], [81.41326904, 25.13169098], [81.40020752, 25.13380051], [81.40181732, 25.13082123], [81.40667725, 25.1251297], [81.40624237, 25.12339973], [81.40431976, 25.12216759], [81.4005661, 25.1217308], [81.39753723, 25.12170029], [81.39122009, 25.1231308], [81.38903046, 25.12426186], [81.38722992, 25.12895012], [81.38500214, 25.1301403], [81.38652039, 25.13393021], [81.3843689, 25.13508034], [81.37898254, 25.13445091], [81.37428284, 25.13877106], [81.36688232, 25.13743973], [81.36450958, 25.13785934], [81.36453247, 25.13929749], [81.36643982, 25.14172935], [81.36560822, 25.14425087], [81.36251068, 25.14571953], [81.35720825, 25.15232086], [81.35549927, 25.15764999], [81.3533783, 25.16147995], [81.35089874, 25.16391945], [81.34941101, 25.16735077], [81.34459686, 25.16547012], [81.33603668, 25.16634941], [81.33103943, 25.16955757], [81.32995605, 25.17249107], [81.31964111, 25.1680603], [81.31297302, 25.16354752], [81.31073761, 25.15263939], [81.31096649, 25.14896011], [81.31225586, 25.14621925], [81.31680298, 25.14066124], [81.31598663, 25.1350708], [81.31678009, 25.12808037], [81.32026672, 25.1224308], [81.32221222, 25.12072945], [81.32301331, 25.11839294], [81.31852722, 25.11869049], [81.31830597, 25.11684036], [81.31700897, 25.1160183], [81.31466675, 25.11629105], [81.31302643, 25.11741066], [81.31195068, 25.12343025], [81.31005096, 25.12402916], [81.30838776, 25.12583923], [81.30880737, 25.13158989], [81.30696869, 25.13339043], [81.30657959, 25.13517189], [81.30802155, 25.1388607], [81.30490112, 25.14307022], [81.30429077, 25.14529037], [81.30699921, 25.15966988], [81.30638885, 25.16599274], [81.30487061, 25.16745949], [81.29254913, 25.16798019], [81.29133606, 25.16679764], [81.28468323, 25.16530991], [81.28147888, 25.1654892], [81.27522278, 25.16899109], [81.27143097, 25.16893959], [81.26911926, 25.16773987], [81.26864624, 25.16518974], [81.27390289, 25.15836906], [81.27477264, 25.15341949], [81.27059174, 25.14843941], [81.26558685, 25.14487076], [81.26146698, 25.14434814], [81.26122284, 25.1439209], [81.25974274, 25.14118195], [81.262146, 25.13108063], [81.25683594, 25.12862968], [81.25817871, 25.12363243], [81.25795746, 25.1168499], [81.25617981, 25.11454964], [81.24812317, 25.1117382], [81.24569702, 25.10554123], [81.24648285, 25.10326958], [81.24878693, 25.10071945], [81.25206757, 25.09857941], [81.25443268, 25.09270096], [81.25911713, 25.08730125], [81.25302887, 25.07904816], [81.25997925, 25.07562256], [81.26222229, 25.0728302], [81.26158905, 25.06846046], [81.25527191, 25.06082916], [81.25602722, 25.05571938], [81.25338745, 25.05443001], [81.25229645, 25.05257988], [81.24756622, 25.04149246], [81.2425766, 25.03630066], [81.23921204, 25.03136063], [81.23600769, 25.02930069], [81.23069, 25.0180912], [81.22309875, 25.01132965], [81.22023773, 25.0072403], [81.21656799, 25.00444984], [81.2113266, 25.00169182], [81.21070099, 25.00165939], [81.21016693, 25.00181961], [81.20974731, 25.0021801], [81.20900726, 25.00291824], [81.20854187, 25.00312042], [81.20735931, 25.0035305], [81.20641327, 25.00374031], [81.20581055, 25.00342941], [81.20511627, 25.00311089], [81.20482635, 25.00280952], [81.20381927, 24.99755287], [81.2016983, 24.99572945], [81.20733643, 24.9912796], [81.21129608, 24.98680115], [81.21273041, 24.98166275], [81.21230316, 24.97774124], [81.20127869, 24.97026253], [81.20001221, 24.96685028], [81.20407867, 24.96284103], [81.20600891, 24.95808983], [81.20639038, 24.95408058], [81.20437622, 24.95047951], [81.20600128, 24.9392395], [81.20749664, 24.93725014], [81.21148682, 24.93622971], [81.21260834, 24.93452072], [81.21098328, 24.93259048], [81.20729828, 24.93110275], [81.20249939, 24.92780113], [81.19948578, 24.92694092], [81.19579315, 24.92900848], [81.18441772, 24.9292202], [81.19303894, 24.93461037], [81.19828033, 24.93404961], [81.19895935, 24.93473816], [81.1884079, 24.94505119], [81.18062592, 24.94945908], [81.17658997, 24.95496941], [81.17212677, 24.95350075], [81.16967773, 24.95675087], [81.16419983, 24.95976257], [81.16143036, 24.95851135], [81.15956116, 24.95473289], [81.1568985, 24.94571114], [81.15779877, 24.94267082], [81.15602112, 24.93982124], [81.15548706, 24.9319706], [81.15233612, 24.92937279], [81.15116119, 24.92720985], [81.15090179, 24.92374039], [81.15249634, 24.91962242], [81.15231323, 24.91628075], [81.14813995, 24.91768074], [81.14272308, 24.91736984], [81.14008331, 24.91643906], [81.13331604, 24.90557098], [81.13289642, 24.90050125], [81.1342392, 24.89384079], [81.13244629, 24.89207077], [81.1281662, 24.89361954], [81.12265015, 24.89870071], [81.11678314, 24.90182114], [81.11292267, 24.90552139], [81.11073303, 24.91068077], [81.10748291, 24.91214752], [81.10381317, 24.91270065], [81.09871674, 24.91843033], [81.09654236, 24.92253113], [81.09449768, 24.92378044], [81.08950043, 24.92448044], [81.08487701, 24.93435287], [81.08156586, 24.93575096], [81.08049774, 24.9383812], [81.08246613, 24.94769096], [81.08120728, 24.95021057], [81.07641602, 24.95226097], [81.05741882, 24.95311928], [81.0508194, 24.95527267], [81.04715729, 24.9552002], [81.04312134, 24.95263863], [81.02667236, 24.95496941], [81.02320099, 24.95235062], [81.01991272, 24.95198059], [81.02139282, 24.94839096], [81.0207901, 24.94607925], [81.01924896, 24.94499969], [81.01698303, 24.94643974], [81.00952911, 24.95432091], [81.00715637, 24.95262909], [81.01258087, 24.94371986], [81.01531219, 24.94005966], [81.02114105, 24.93825912], [81.02128601, 24.93712044], [81.01799011, 24.93554115], [81.01677704, 24.93246078], [81.01467133, 24.93160057], [81.0118866, 24.9332428], [81.0087204, 24.93246078], [81.00002289, 24.94021034], [80.99672699, 24.93959045], [80.99124146, 24.93712044], [80.98448944, 24.93258095], [80.98101044, 24.9296608], [80.97792816, 24.93315125], [80.97928619, 24.93807983], [80.97225952, 24.9396019], [80.96566772, 24.93861961], [80.95838928, 24.93224907], [80.95523071, 24.92571068], [80.95111084, 24.92702293], [80.95287323, 24.93943977], [80.9522171, 24.94288063], [80.9498291, 24.94638062], [80.94481659, 24.94713974], [80.94386292, 24.95070076], [80.94668579, 24.95691109], [80.9467392, 24.96114159], [80.94484711, 24.96800995], [80.94249725, 24.97113991], [80.93682098, 24.97249985], [80.93374634, 24.97010994], [80.9284668, 24.96769905], [80.92162323, 24.96657944], [80.91596222, 24.96479034], [80.91152191, 24.96228027], [80.89730072, 24.95672035], [80.89431763, 24.95389938], [80.89331818, 24.95046043], [80.90119934, 24.94334984], [80.90278625, 24.94016075], [80.9000473, 24.93958092], [80.89795685, 24.94169044], [80.8948288, 24.94244003], [80.88870239, 24.9474411], [80.88482666, 24.94889069], [80.88123322, 24.94820023], [80.87684631, 24.94506073], [80.87500763, 24.94071007], [80.85661316, 24.93595123], [80.84091949, 24.93556023], [80.83490753, 24.93452835], [80.82901001, 24.93844986], [80.82081604, 24.93659019], [80.81542969, 24.93790817], [80.80220032, 24.94445992], [80.80290985, 24.9569397], [80.79164124, 24.96391106], [80.78994751, 24.96718025], [80.78999329, 24.97178268], [80.79360962, 24.97365189], [80.79879761, 24.97489166], [80.8065033, 24.97500992], [80.81257629, 24.97367096], [80.81864166, 24.97363091], [80.82109833, 24.98250008], [80.82470703, 24.9860611], [80.83640289, 24.98608971], [80.845047, 24.99349976], [80.84818268, 24.99814034], [80.85025024, 25.0031414], [80.84192657, 25.0125103], [80.84005737, 25.02021027], [80.82911682, 25.02997971], [80.82668304, 25.03919029], [80.83522034, 25.03968048], [80.84113312, 25.05127907], [80.84687042, 25.05327988], [80.8557663, 25.06244087], [80.87065125, 25.07105064], [80.87507629, 25.07953835], [80.86480713, 25.08434105], [80.86425018, 25.08815956], [80.86730957, 25.09402084], [80.87121582, 25.09824944], [80.87298584, 25.10256958], [80.87224579, 25.10930061], [80.86650848, 25.11943054], [80.8649826, 25.1236496], [80.86585236, 25.12552071], [80.8690033, 25.12791061], [80.87275696, 25.13389015], [80.87541962, 25.14443016], [80.88526917, 25.14001274], [80.8884201, 25.14123917], [80.89029694, 25.14635086], [80.90157318, 25.15797997], [80.90492249, 25.16031075], [80.90556335, 25.16448021], [80.89597321, 25.17126083], [80.88902283, 25.17469025], [80.8861618, 25.17717171], [80.8780365, 25.19560051], [80.86953735, 25.18865967], [80.86416626, 25.18786049], [80.86315155, 25.18921089], [80.86036682, 25.1905899], [80.84858704, 25.19003105], [80.84108734, 25.19347954], [80.83628082, 25.19268036], [80.83515167, 25.19046974], [80.83589172, 25.18540955], [80.84111023, 25.17525291], [80.84230042, 25.1711998], [80.84188843, 25.16794014], [80.83744049, 25.16031075], [80.83384705, 25.14561272], [80.83209991, 25.14141083], [80.83479309, 25.13252068], [80.8377533, 25.12751007], [80.83344269, 25.11327171], [80.82769775, 25.1103096], [80.82393646, 25.11465263], [80.82315826, 25.11777115], [80.82151794, 25.1200428], [80.82168579, 25.12285042], [80.82139587, 25.12560081], [80.81864166, 25.13055038], [80.80961609, 25.13070107], [80.80771637, 25.13310051], [80.80828094, 25.14081955], [80.8032074, 25.1435318], [80.79957581, 25.14641762], [80.79786682, 25.14624023], [80.79367065, 25.14232063], [80.7906723, 25.14273071], [80.78613281, 25.13796043], [80.78369904, 25.13836288], [80.78214264, 25.13708115], [80.7766571, 25.14484024], [80.77403259, 25.1466198], [80.76605988, 25.14088821], [80.75956726, 25.14059067], [80.75086212, 25.14170074], [80.74043274, 25.13741112], [80.73809814, 25.13459969], [80.73545837, 25.13521957], [80.73206329, 25.14052963], [80.73227692, 25.14236259], [80.72865295, 25.14289856], [80.7277298, 25.14740181], [80.72305298, 25.14878273], [80.71763611, 25.14660072], [80.71530914, 25.14665985], [80.71478271, 25.14328003], [80.71061707, 25.13844109], [80.70092773, 25.1380806], [80.69963837, 25.13714981], [80.69847107, 25.13137245], [80.7008667, 25.12803841], [80.70746613, 25.12743187], [80.71730042, 25.1289196], [80.72244263, 25.12599182], [80.72537231, 25.12288284], [80.7199173, 25.11725807], [80.7190094, 25.10402107], [80.72049713, 25.10139275], [80.72524261, 25.09795952], [80.72931671, 25.09729767], [80.73343658, 25.1013298], [80.74577332, 25.09939957], [80.74931335, 25.09777069], [80.75205231, 25.09540939], [80.75100708, 25.09428978], [80.75112152, 25.09111977], [80.76703644, 25.08559036], [80.77597809, 25.08430099], [80.77961731, 25.07786942], [80.7813797, 25.069561], [80.77825928, 25.06386948], [80.77593994, 25.06169128], [80.76595306, 25.06114006], [80.75566864, 25.06257057], [80.7514267, 25.06399918], [80.74410248, 25.06233025], [80.7335968, 25.06244087], [80.72921753, 25.06553268], [80.72720337, 25.07182121], [80.7144165, 25.06775284], [80.71096039, 25.06726265], [80.70948792, 25.06632042], [80.70831299, 25.06492996], [80.70533752, 25.06142044], [80.69801331, 25.06155014], [80.68688965, 25.05879021], [80.67829895, 25.05457115], [80.67356873, 25.05417061], [80.67465973, 25.06019974], [80.67507935, 25.06253052], [80.67192078, 25.06456947], [80.67180634, 25.06732941], [80.67421722, 25.0680809], [80.67788696, 25.07310104], [80.67896271, 25.07578087], [80.67926025, 25.08181953], [80.66828918, 25.08675194], [80.66670227, 25.08426285], [80.66610718, 25.08053017], [80.66580963, 25.08019066], [80.66422272, 25.07839012], [80.65629578, 25.07444191], [80.65373993, 25.07645988], [80.65052795, 25.08753014], [80.64554596, 25.0906105], [80.6414566, 25.09314919], [80.63645172, 25.09395981], [80.63574982, 25.09605026], [80.63523865, 25.09756088], [80.63434601, 25.09717941], [80.63391876, 25.09379959], [80.62861633, 25.09328842], [80.62516785, 25.09555817], [80.62354279, 25.09519958], [80.62195587, 25.09338951], [80.62230682, 25.08929062], [80.62004089, 25.08958054], [80.617836, 25.09366035], [80.6084671, 25.09860039], [80.60655212, 25.10157967], [80.60135651, 25.10440826], [80.60682678, 25.1065197], [80.61329651, 25.10654068], [80.61506653, 25.11120987], [80.61476898, 25.11386108], [80.61823273, 25.11580086], [80.61875153, 25.11808014], [80.61923218, 25.12021065], [80.62229919, 25.12202072], [80.63123322, 25.11980057], [80.63239288, 25.12328148], [80.62802124, 25.13029099], [80.62496185, 25.13767052], [80.62245178, 25.13606071], [80.6159668, 25.13812065], [80.6083374, 25.13294983], [80.60547638, 25.13635063], [80.6056366, 25.14278984], [80.60578918, 25.14928055], [80.60269928, 25.1523819], [80.59960938, 25.15546989], [80.59458923, 25.15524101], [80.59105682, 25.14129066], [80.59011078, 25.13482094], [80.59075928, 25.13158035], [80.59757233, 25.1281395], [80.60037994, 25.1253109], [80.60144806, 25.12281036], [80.59642029, 25.12202072], [80.59137726, 25.11799049], [80.58777618, 25.10910034], [80.59188843, 25.09600258], [80.59333801, 25.09420967], [80.59435272, 25.09295082], [80.60002136, 25.09075165], [80.60675812, 25.07620049], [80.60730743, 25.07308006], [80.60710144, 25.07273293], [80.60678101, 25.07217979], [80.60452271, 25.07262993], [80.59594727, 25.07818031], [80.5932312, 25.08152962], [80.58872223, 25.08434105], [80.58757782, 25.08587074], [80.58011627, 25.08695984], [80.57866669, 25.08826256], [80.57263947, 25.08580017], [80.56804657, 25.08528137], [80.56562805, 25.08718109], [80.56243896, 25.0914402], [80.56109619, 25.08876991], [80.56117249, 25.07928276], [80.55999756, 25.07498932], [80.55766296, 25.07292175], [80.55536652, 25.07089806], [80.55245209, 25.06928062], [80.54862213, 25.06931114], [80.54676819, 25.06797028], [80.54341888, 25.06766129], [80.53882599, 25.06965828], [80.53203583, 25.07591057], [80.52812958, 25.07705116], [80.51899719, 25.08193016], [80.51731873, 25.08479118], [80.51515961, 25.08846092], [80.51425934, 25.09577751], [80.51288605, 25.0982399], [80.50950623, 25.10102081], [80.50190735, 25.10413933], [80.49471283, 25.10494041], [80.49212646, 25.10223007], [80.48391724, 25.10281944], [80.48030853, 25.10157967], [80.47612762, 25.10225105], [80.47447968, 25.10182953], [80.47471619, 25.09906006], [80.47759247, 25.09641266], [80.48729706, 25.09180069], [80.49433136, 25.09205055], [80.49777222, 25.09139061], [80.49997711, 25.08955956], [80.49842834, 25.08257103], [80.49453735, 25.07956123], [80.49059296, 25.07821083], [80.50007629, 25.07097054], [80.5021286, 25.06735039], [80.50231934, 25.06286049], [80.50019836, 25.05877113], [80.49724579, 25.0560112], [80.49317169, 25.05431938], [80.49420929, 25.04532051], [80.48583221, 25.04730988], [80.48314667, 25.04725075], [80.47901154, 25.04434967], [80.47693634, 25.04388809], [80.47331238, 25.04358292], [80.4701767, 25.04469109], [80.46142578, 25.05798912], [80.45996857, 25.06970024], [80.45593262, 25.07382011], [80.45297241, 25.06878281], [80.445961, 25.06583023], [80.44420624, 25.06817055], [80.44464111, 25.07081032], [80.44225311, 25.07328033], [80.44164276, 25.07600021], [80.44342041, 25.07733917], [80.44513702, 25.08017159], [80.44428253, 25.0812912], [80.4417572, 25.08101273], [80.44071198, 25.0820694], [80.43509674, 25.0809803], [80.43292236, 25.07839012], [80.4311676, 25.07394028], [80.42951202, 25.07254028], [80.42450714, 25.07150078], [80.42272949, 25.07131958], [80.40991974, 25.07671928], [80.40677643, 25.06344986], [80.40525055, 25.06085014], [80.40268707, 25.06095123], [80.39746857, 25.06562042], [80.39807892, 25.06928062], [80.39412689, 25.07202148], [80.38944244, 25.0682106], [80.38640594, 25.0673008], [80.38414764, 25.06534004], [80.38347626, 25.0616703], [80.3792572, 25.05595016], [80.36724854, 25.05886078], [80.3657608, 25.05776024], [80.36627197, 25.05307961], [80.36406708, 25.04771996], [80.36750793, 25.04609108], [80.37520599, 25.0456295], [80.37906647, 25.04440117], [80.38020325, 25.04160118], [80.38043213, 25.03890038], [80.37831116, 25.03680992], [80.3747406, 25.03660011], [80.37287903, 25.03470039], [80.37177277, 25.03276062], [80.3723526, 25.02918053], [80.37612915, 25.02799988], [80.38088226, 25.02765846], [80.38304138, 25.01869011], [80.38915253, 25.01490974], [80.38739014, 25.01242065], [80.38218689, 25.00974083], [80.37283325, 25.00832939], [80.36921692, 25.01888084], [80.36885834, 25.02383995], [80.36782074, 25.02543068], [80.35884857, 25.02607918], [80.35507202, 25.02449036], [80.35257721, 25.01988029], [80.34793854, 25.01646805], [80.34456635, 25.01947021], [80.33798218, 25.02094078], [80.3289566, 25.00543022], [80.32739258, 25.00434113], [80.32594299, 25.00311089], [80.32491302, 25.00307083], [80.3243866, 25.00303078], [80.32388306, 25.00298119], [80.323349, 25.00296021], [80.32285309, 25.00294113], [80.32231903, 25.00291061], [80.3217926, 25.00291061], [80.32128143, 25.00290108], [80.32079315, 25.00291061], [80.32025909, 25.00291061], [80.31973267, 25.00291824], [80.31922913, 25.00294113], [80.31871033, 25.00296974], [80.31819916, 25.0030117], [80.31768036, 25.00303078], [80.31716919, 25.0030899], [80.31665039, 25.0031414], [80.31614685, 25.00320053], [80.31564331, 25.0032692], [80.31511688, 25.0033493], [80.31462097, 25.00342178], [80.31410217, 25.00350952], [80.31278229, 25.00432014], [80.31236267, 25.00629807], [80.29897308, 25.01603127], [80.28919983, 25.02114105], [80.27849579, 25.02164841], [80.26693726, 25.03024292], [80.26727295, 25.0316124], [80.26876831, 25.03269958], [80.27078247, 25.03417969], [80.27327728, 25.0371418], [80.27487946, 25.03903961], [80.2771759, 25.04294014], [80.27780151, 25.04397964], [80.27941132, 25.05267906], [80.28115845, 25.05673981], [80.28157043, 25.06005096], [80.28195953, 25.06322098], [80.2876358, 25.06689072], [80.2947464, 25.06909943], [80.30478668, 25.07551003], [80.31051636, 25.08195114], [80.3132019, 25.0892601], [80.31472015, 25.0940609], [80.31327057, 25.10117149], [80.32283783, 25.1066494], [80.33835602, 25.12125015], [80.34411621, 25.12491989], [80.34752655, 25.13002014], [80.34861755, 25.14069176], [80.35128784, 25.14490128], [80.35614777, 25.14841843], [80.36245728, 25.14973068], [80.37343597, 25.15517807], [80.38066864, 25.16077995], [80.3867569, 25.16288185], [80.40358734, 25.16505051], [80.41548157, 25.16529274], [80.42256927, 25.17221069], [80.42369843, 25.17414284], [80.42237854, 25.18136024], [80.41812897, 25.19192123], [80.41162872, 25.19943047], [80.4095459, 25.20586014], [80.40423584, 25.21404076], [80.4016571, 25.22095108], [80.39906311, 25.24296951], [80.39070129, 25.24568748], [80.3829422, 25.24195099], [80.3813324, 25.23829842], [80.37802887, 25.23751068], [80.36289215, 25.24682999], [80.35771179, 25.25113106], [80.35359192, 25.25638962], [80.35173798, 25.26024055], [80.35041046, 25.2652626], [80.34926605, 25.26955032], [80.3409729, 25.27860069], [80.33766174, 25.27941132], [80.31983948, 25.28049088], [80.31201172, 25.28215027], [80.30404663, 25.28889275], [80.30307007, 25.2911396], [80.30267334, 25.29696083], [80.30912018, 25.30585098], [80.31069183, 25.31065178], [80.31173706, 25.33420944], [80.30980682, 25.34127045], [80.30358887, 25.35251236], [80.30262756, 25.35828018], [80.30536652, 25.36207962], [80.30861664, 25.36372948], [80.31324768, 25.37225914], [80.31121063, 25.3810997], [80.31075287, 25.38731766], [80.30905151, 25.39183998], [80.30857849, 25.39233017], [80.29532623, 25.40776062], [80.28964233, 25.41271973], [80.28431702, 25.41588974], [80.27372742, 25.42503929], [80.26123047, 25.42617989], [80.255867, 25.42871094], [80.253479, 25.42346954], [80.25241089, 25.41877174], [80.24730682, 25.41146088], [80.24739838, 25.40738106], [80.24518585, 25.40489006], [80.22956085, 25.4109211], [80.22657776, 25.41064072], [80.2140274, 25.40423012], [80.21137238, 25.40394974], [80.20244598, 25.40673065], [80.19786835, 25.41056061], [80.19832611, 25.41269112], [80.19724274, 25.4149704], [80.19391632, 25.41623116], [80.19143677, 25.41271019], [80.19093323, 25.40904045], [80.18882751, 25.4064312], [80.18916321, 25.38922119], [80.18789673, 25.38364983], [80.18261719, 25.38151932], [80.17201233, 25.38069153], [80.16668701, 25.37895012], [80.15917969, 25.37764931], [80.15828705, 25.37265968], [80.15912628, 25.36619949], [80.15315247, 25.3628006], [80.14496613, 25.36010933], [80.13712311, 25.35573006], [80.13273621, 25.35032082], [80.12708282, 25.34061813], [80.12329865, 25.3384304], [80.119133, 25.34269905], [80.106987, 25.34418106], [80.09609222, 25.35157967], [80.09337616, 25.35383034], [80.08329773, 25.35583115], [80.07839966, 25.35344124], [80.07234192, 25.34509087], [80.07002258, 25.34309959], [80.06150055, 25.34204102], [80.05486298, 25.34129906], [80.04444122, 25.34185028], [80.0371933, 25.34096909], [80.02419281, 25.34459114], [80.02073669, 25.34316063], [80.01449585, 25.33111], [80.01265717, 25.33011055], [80.00991058, 25.32475281], [80.01264954, 25.30171967], [80.0083313, 25.30067825], [79.998703, 25.29376984], [79.99385834, 25.28884125], [79.99220276, 25.28524971], [79.99125671, 25.28316116], [79.9921875, 25.28098106], [79.99559784, 25.27672958], [79.99534607, 25.27466011], [79.99733734, 25.27013016], [79.99672699, 25.26865005], [79.99221039, 25.26930046], [79.97727966, 25.26494026], [79.96951294, 25.26816177], [79.96717072, 25.26847076], [79.96304321, 25.26824951], [79.94921875, 25.26530075], [79.94256592, 25.2718792], [79.94095612, 25.26971054], [79.93437958, 25.26486969], [79.93332672, 25.26301956], [79.93196106, 25.25985909], [79.93257141, 25.25032043], [79.92410278, 25.25155067], [79.92099762, 25.25070953], [79.91345215, 25.2334404], [79.91220856, 25.23376274], [79.91062927, 25.23604965], [79.91056061, 25.24497986], [79.90629578, 25.25418091], [79.90532684, 25.25547028], [79.90239716, 25.25691986], [79.89962006, 25.25657082], [79.89834595, 25.25510025], [79.8972702, 25.24959946], [79.89615631, 25.24753952], [79.89360046, 25.2462101], [79.8866272, 25.24641037], [79.87500763, 25.25299072], [79.87245941, 25.25379181], [79.86595917, 25.24682045], [79.86097717, 25.24299049], [79.85755157, 25.2419014], [79.8509903, 25.24156952], [79.84713745, 25.24020004], [79.84572601, 25.23838234], [79.8452301, 25.23655128], [79.84716034, 25.23241043], [79.85285187, 25.2250309], [79.86136627, 25.22095108], [79.86303711, 25.2191906], [79.85618591, 25.2136097], [79.85411835, 25.21042061], [79.85185242, 25.20347977], [79.8547821, 25.19909286], [79.85878754, 25.19022942], [79.85810852, 25.18185806], [79.86154175, 25.17906952], [79.86260223, 25.17696953], [79.85965729, 25.16205025], [79.86058807, 25.15606117], [79.86300659, 25.15390968], [79.87210083, 25.15030289], [79.87217712, 25.14851189], [79.86483002, 25.14499283], [79.85740662, 25.14281082], [79.85161591, 25.13977814], [79.84767151, 25.13339043], [79.84796906, 25.12823105], [79.84657288, 25.12227058], [79.84268188, 25.1163311], [79.84580994, 25.11046982], [79.85309601, 25.10275078], [79.855896, 25.09850121], [79.84921265, 25.09698105], [79.84085846, 25.09639931], [79.8312912, 25.0981102], [79.8272171, 25.10012054], [79.82434082, 25.10370064], [79.82327271, 25.10640907], [79.8187027, 25.11015129], [79.81640625, 25.11086273], [79.80516815, 25.11097908], [79.79325104, 25.11837959], [79.78833771, 25.12039185], [79.76921844, 25.1252594], [79.76274872, 25.12982941], [79.75772095, 25.13452911], [79.75110626, 25.14066124], [79.74781799, 25.14260101], [79.74563599, 25.14388275], [79.73957825, 25.14295959], [79.72603607, 25.13573265], [79.72455597, 25.13540077], [79.71776581, 25.13381958], [79.70728302, 25.13331985], [79.68698883, 25.13686943], [79.6765976, 25.13698959], [79.67418671, 25.13577843], [79.67079163, 25.13208961], [79.66616821, 25.12712097], [79.66053772, 25.12796021], [79.65659332, 25.12951279], [79.65419006, 25.1304512], [79.64302826, 25.13236046], [79.64070129, 25.13239861], [79.6378479, 25.13108063], [79.63285065, 25.13282967], [79.62003326, 25.14266968], [79.60608673, 25.13249969], [79.60514832, 25.13223076], [79.60209656, 25.1313591], [79.5978775, 25.13143158], [79.59516907, 25.13413239], [79.59541321, 25.13562012], [79.59748077, 25.13955116], [79.59854889, 25.1453495], [79.60276794, 25.15310097], [79.60279083, 25.15384293], [79.60280609, 25.1547699], [79.60003662, 25.15497971], [79.59326935, 25.14635086], [79.59233856, 25.14631081], [79.59144592, 25.14627075], [79.59052277, 25.14680099], [79.58969879, 25.14727974], [79.58573914, 25.15286255], [79.5762558, 25.15705109], [79.57396698, 25.15945053], [79.56893921, 25.17552185], [79.56552124, 25.17755127], [79.5595932, 25.17597008], [79.55033875, 25.16940117], [79.5427475, 25.16055107], [79.53795624, 25.15262985], [79.53494263, 25.14762115], [79.53363037, 25.14644051], [79.52864838, 25.14497948], [79.52731323, 25.14310074], [79.52857971, 25.13801193], [79.52868652, 25.13738251], [79.52658844, 25.13563919], [79.51795959, 25.1312294], [79.51377106, 25.12572289], [79.51394653, 25.12210083], [79.51815796, 25.10770035], [79.51828766, 25.10443115], [79.51722717, 25.10178757], [79.51535797, 25.10104179], [79.5133667, 25.10025024], [79.50527191, 25.10130119], [79.50016022, 25.0992012], [79.4937973, 25.0920105], [79.49118042, 25.08612251], [79.49112701, 25.08488274], [79.49106598, 25.08329964], [79.48987579, 25.08275032], [79.48243713, 25.08510971], [79.4715271, 25.08719063], [79.46053314, 25.09633064], [79.4701767, 25.13068008], [79.4701767, 25.13380051], [79.46951294, 25.13404083], [79.46837616, 25.13445091], [79.45656586, 25.12499046], [79.45022583, 25.11783028], [79.44478607, 25.11309052], [79.43637085, 25.10782051], [79.43106842, 25.10750961], [79.43067169, 25.10806084], [79.42990875, 25.10913277], [79.42951965, 25.11148262], [79.42945862, 25.1117897], [79.43115997, 25.11594963], [79.43344879, 25.12000084], [79.4344101, 25.12170029], [79.43525696, 25.1265316], [79.43297577, 25.13141823], [79.43113708, 25.13540077], [79.42590332, 25.13839912], [79.41760254, 25.1384697], [79.41512299, 25.13909912], [79.41477203, 25.13736916], [79.4178009, 25.1350708], [79.418396, 25.13352013], [79.41710663, 25.12726974], [79.41496277, 25.12299919], [79.40918732, 25.11565971], [79.40196991, 25.11335945], [79.39914703, 25.11346054], [79.39317322, 25.1161499], [79.39080811, 25.11790276], [79.38928986, 25.12058067], [79.38873291, 25.13162994], [79.38704681, 25.13614273], [79.38389587, 25.14003944], [79.38212585, 25.14593124], [79.38022614, 25.14912033], [79.38006592, 25.15372086], [79.38387299, 25.17028046], [79.39150238, 25.17964935], [79.40389252, 25.18958092], [79.40421295, 25.19441032], [79.40455627, 25.19947052], [79.40809631, 25.20751953], [79.40957642, 25.20876122], [79.41734314, 25.20392036], [79.42125702, 25.20323944], [79.42460632, 25.20264816], [79.42617798, 25.20305824], [79.42800903, 25.20353127], [79.43213654, 25.20277977], [79.43578339, 25.20465851], [79.44270325, 25.21256065], [79.44239807, 25.22095108], [79.43231201, 25.22180176], [79.42701721, 25.22503853], [79.43297577, 25.23600006], [79.43418121, 25.24178123], [79.43855286, 25.24827194], [79.4417572, 25.25172043], [79.44358826, 25.2486496], [79.44490814, 25.24811935], [79.44834137, 25.25081062], [79.45285034, 25.25650024], [79.45522308, 25.26521111], [79.45919037, 25.26945114], [79.46070099, 25.26960945], [79.46401215, 25.26799965], [79.47453308, 25.26657295], [79.47911835, 25.26516914], [79.48396301, 25.26498032], [79.48973846, 25.26564026], [79.49082947, 25.26901054], [79.49040222, 25.2703495], [79.48446655, 25.27273941], [79.47772217, 25.27238274], [79.4763031, 25.27316093], [79.47532654, 25.27487946], [79.47527313, 25.27671051], [79.47525024, 25.27749062], [79.4752121, 25.27917099], [79.47312164, 25.2821312], [79.45741272, 25.2838707], [79.45307159, 25.28256035], [79.4527359, 25.27526855], [79.45157623, 25.27360916], [79.43121338, 25.25955009], [79.42665863, 25.25842285], [79.41530609, 25.25922012], [79.40122223, 25.26235962], [79.40188599, 25.2792511], [79.39229584, 25.28486061], [79.38861084, 25.28624916], [79.38600159, 25.28415108], [79.38353729, 25.28360939], [79.37931061, 25.28672028], [79.37561798, 25.29109955], [79.37256622, 25.2933197], [79.36975098, 25.29409981], [79.36741638, 25.29432106], [79.36444855, 25.29252052], [79.36717224, 25.27557945], [79.36724091, 25.27242088], [79.36573792, 25.26807022], [79.36168671, 25.26427078], [79.35829926, 25.26351929], [79.35296631, 25.26538086], [79.35109711, 25.26995087], [79.35161591, 25.27799034], [79.34970856, 25.28841972], [79.34308624, 25.29042053], [79.33249664, 25.29230118], [79.33164978, 25.29257965], [79.33104706, 25.29277992], [79.33075714, 25.29404831], [79.34187317, 25.30458069], [79.3414917, 25.30768967], [79.33769989, 25.31090927], [79.33448029, 25.31739807], [79.33837891, 25.32492828], [79.34588623, 25.33304024], [79.34458923, 25.33444977], [79.3337326, 25.33258057], [79.33023071, 25.3337307], [79.32512665, 25.33724976], [79.30930328, 25.33856964], [79.30422211, 25.33984947], [79.29473114, 25.3402195], [79.29408264, 25.33937073], [79.29371643, 25.33236122], [79.2913208, 25.32928848], [79.28341675, 25.33008957], [79.27760315, 25.32805061], [79.27651978, 25.32703018], [79.26760101, 25.31875038], [79.26013947, 25.31023979], [79.25798798, 25.29837036], [79.25601196, 25.29171944], [79.25683594, 25.28499031], [79.25627899, 25.28211975], [79.25650787, 25.27947044], [79.25901031, 25.27420998], [79.25945282, 25.27144051], [79.26196289, 25.26773071], [79.26566315, 25.26639938], [79.26877594, 25.26646042], [79.27111053, 25.26650238], [79.27529907, 25.26929092], [79.27787018, 25.27100182], [79.28646088, 25.28107071], [79.28775024, 25.29024124], [79.29830933, 25.27577019], [79.30391693, 25.26540184], [79.31004333, 25.26192093], [79.31468964, 25.26139259], [79.31873322, 25.26307106], [79.32338715, 25.26684952], [79.33190155, 25.27626991], [79.33454132, 25.27571106], [79.33789825, 25.27318764], [79.34008789, 25.27276039], [79.3445282, 25.26429939], [79.34129333, 25.25864983], [79.34086609, 25.25607109], [79.34028625, 25.24308014], [79.34127808, 25.2390995], [79.34111786, 25.23048973], [79.33953094, 25.22809029], [79.33197784, 25.23200035], [79.33078003, 25.23207092], [79.32911682, 25.22990036], [79.33490753, 25.22286987], [79.34696198, 25.21424103], [79.34337616, 25.20998955], [79.3325882, 25.20083046], [79.32656097, 25.20850945], [79.32578278, 25.21081161], [79.32508087, 25.21387291], [79.32534027, 25.22244072], [79.32433319, 25.22257042], [79.3229599, 25.22274971], [79.31491089, 25.21960068], [79.31339264, 25.21955109], [79.31078339, 25.21948051], [79.30858612, 25.22319031], [79.30047607, 25.22744942], [79.29782104, 25.23444939], [79.29332733, 25.24020004], [79.28401184, 25.24650002], [79.27855682, 25.24782944], [79.27359772, 25.24811935], [79.27391052, 25.24650002], [79.27416992, 25.24518967], [79.27822876, 25.23829079], [79.28148651, 25.22714043], [79.28106689, 25.22434044], [79.27963257, 25.22171021], [79.27802277, 25.21063995], [79.27777863, 25.20351028], [79.27880096, 25.19739914], [79.28351593, 25.18946075], [79.28872681, 25.18626976], [79.29077911, 25.18390083], [79.30188751, 25.17534065], [79.30874634, 25.16512108], [79.31060028, 25.16090012], [79.31453705, 25.15187836], [79.31388855, 25.15096092], [79.30570984, 25.13990021], [79.30322266, 25.13332939], [79.30098724, 25.13083076], [79.29110718, 25.13125992], [79.28218079, 25.13352013], [79.27654266, 25.12026024], [79.27381897, 25.12168121], [79.26999664, 25.12615013], [79.26875305, 25.12623024], [79.2600708, 25.12210083], [79.25807953, 25.12401962], [79.25454712, 25.13046074], [79.26207733, 25.14115906], [79.26194763, 25.14191055], [79.25836182, 25.14390945], [79.25934601, 25.14694023], [79.25920105, 25.15327263], [79.2559967, 25.15728188], [79.25060272, 25.16120911], [79.24584198, 25.1619606], [79.23583984, 25.16096115], [79.22518158, 25.1581707], [79.21965027, 25.15456963], [79.21391296, 25.14838028], [79.22252655, 25.14562035], [79.22399139, 25.14318085], [79.22408295, 25.14082909], [79.2248764, 25.14023018], [79.2375412, 25.1428299], [79.23980713, 25.14273071], [79.24151611, 25.14092064], [79.24353027, 25.14079094], [79.23767853, 25.13133049], [79.23810577, 25.12672043], [79.24014282, 25.12018967], [79.2396698, 25.11783981], [79.23838043, 25.11636925], [79.23488617, 25.11746025], [79.22598267, 25.12240982], [79.22278595, 25.12325096], [79.22010803, 25.12099075], [79.21843719, 25.11819077], [79.21369934, 25.11647987], [79.21067047, 25.11445045], [79.20638275, 25.1137619], [79.20709991, 25.12439156], [79.19793701, 25.12818909], [79.19616699, 25.13167], [79.19632721, 25.13804817], [79.19671631, 25.14293098], [79.19373322, 25.1436615], [79.19010925, 25.14565086], [79.1889801, 25.14935112], [79.18768311, 25.15092278], [79.1848526, 25.15113258], [79.18110657, 25.14762115], [79.17730713, 25.14595032], [79.16837311, 25.14530754], [79.16677856, 25.14234924], [79.16652679, 25.13953018], [79.16879272, 25.13157082], [79.17987823, 25.12882996], [79.17930603, 25.11769295], [79.17411804, 25.11903], [79.17236328, 25.11847115], [79.16887665, 25.11186028], [79.15661621, 25.11190033], [79.14480591, 25.1165905], [79.13820648, 25.11841011], [79.13337708, 25.1110611], [79.12917328, 25.11076927], [79.12433624, 25.11186981], [79.12084961, 25.11340141], [79.11482239, 25.11779976], [79.12510681, 25.12921906], [79.1247406, 25.12957954], [79.10781097, 25.14369965], [79.11859131, 25.15839195], [79.12042236, 25.16418076], [79.11920929, 25.1634407], [79.10710907, 25.16814041], [79.10256195, 25.17119026], [79.09057617, 25.17622948], [79.08872986, 25.17832947], [79.08841705, 25.18372917], [79.08722687, 25.18783951], [79.08429718, 25.19252968], [79.07025909, 25.17776108], [79.06407928, 25.17249107], [79.06285858, 25.16274261], [79.05805206, 25.15081978], [79.0545578, 25.14887047], [79.04889679, 25.14751053], [79.04305267, 25.13817024], [79.03888702, 25.13722992], [79.0355072, 25.13784027], [79.02823639, 25.13993073], [79.02176666, 25.14319038], [79.02162933, 25.14693069], [79.02523804, 25.15579033], [79.03578186, 25.1739006], [79.03144836, 25.17850113], [79.02796173, 25.1803112], [79.02572632, 25.18259048], [79.02459717, 25.18657112], [79.04277802, 25.21014023], [79.04847717, 25.20979118], [79.05513, 25.21722031], [79.05673981, 25.21922112], [79.05644226, 25.22570992], [79.05232239, 25.22813034], [79.04506683, 25.23063087], [79.02648163, 25.23467064], [79.0283432, 25.24102974], [79.03103638, 25.24628067], [79.02937317, 25.24934006], [79.01474762, 25.24775124], [79.01212311, 25.24824905], [79.01161957, 25.24933052], [79.01167297, 25.25284958], [79.01599121, 25.26515007], [79.01431274, 25.27103043], [79.01235962, 25.27404022], [79.00496674, 25.27696991], [78.99265289, 25.27773094], [78.98677063, 25.27495956], [78.97722626, 25.2616806], [78.97331238, 25.25368118], [78.97116852, 25.24492073], [78.97231293, 25.24283028], [78.98741913, 25.23592949], [78.99269867, 25.23500252], [78.99466705, 25.23374939], [78.99500275, 25.23228073], [78.99453735, 25.22545052], [78.99330902, 25.22221947], [79.00035858, 25.2160511], [78.99749756, 25.2075901], [78.99733734, 25.19828987], [78.99581146, 25.19593811], [78.99275208, 25.19652176], [78.98774719, 25.19677925], [78.98240662, 25.19915009], [78.97767639, 25.20420074], [78.96920776, 25.21663284], [78.96392059, 25.21943092], [78.95284271, 25.22069168], [78.94834137, 25.22018051], [78.94235992, 25.21836281], [78.92423248, 25.2105999], [78.91916656, 25.2062397], [78.91529083, 25.20259094], [78.90804291, 25.19352913], [78.90159607, 25.18326187], [78.9006424, 25.18053818], [78.89340973, 25.17322922], [78.87713623, 25.16218185], [78.87393188, 25.16327095], [78.87184143, 25.16600037], [78.87325287, 25.17200279], [78.86921692, 25.17811966], [78.86979675, 25.18291283], [78.86759949, 25.18634033], [78.86738586, 25.18996048], [78.87104797, 25.19616127], [78.8757019, 25.20014954], [78.88011932, 25.20589828], [78.88241577, 25.21105957], [78.88162231, 25.21547127], [78.87325287, 25.22608185], [78.86707306, 25.23254013], [78.86725616, 25.23769188], [78.87217712, 25.25078964], [78.87587738, 25.25576973], [78.88022614, 25.25362015], [78.88456726, 25.24723053], [78.89169312, 25.24546051], [78.89644623, 25.24994087], [78.90859985, 25.27436066], [78.91520691, 25.27569008], [78.91828918, 25.27517128], [78.92276764, 25.27148056], [78.92581177, 25.26782036], [78.93348694, 25.26354027], [78.93643951, 25.26267815], [78.94061279, 25.26268959], [78.94618225, 25.26377106], [78.94838715, 25.2659111], [78.94799042, 25.2717495], [78.94447327, 25.27544975], [78.94378662, 25.28007126], [78.94754028, 25.28370094], [78.95384979, 25.28562927], [78.96469879, 25.2838707], [78.970047, 25.28520966], [78.97027588, 25.29109192], [78.95279694, 25.3118782], [78.95202637, 25.31738091], [78.9557724, 25.34776115], [78.95285797, 25.34987068], [78.94999695, 25.34827995], [78.94581604, 25.34725952], [78.94277954, 25.34511948], [78.93547058, 25.33620071], [78.93122864, 25.33241272], [78.9276123, 25.33171082], [78.92537689, 25.33457947], [78.92546082, 25.33843994], [78.92453003, 25.34192848], [78.91886902, 25.34599113], [78.91467285, 25.34644127], [78.91121674, 25.34213066], [78.90788269, 25.33940125], [78.9034729, 25.3400898], [78.89552307, 25.34351921], [78.88524628, 25.34669113], [78.87895966, 25.34687996], [78.87651825, 25.34445953], [78.87679291, 25.33921051], [78.87560272, 25.33401108], [78.87306976, 25.33082962], [78.86245728, 25.32460976], [78.85823822, 25.3208828], [78.85643768, 25.31695938], [78.85954285, 25.31455994], [78.86686707, 25.31098938], [78.86763763, 25.30134964], [78.87185669, 25.29179955], [78.87242889, 25.28820992], [78.87059021, 25.28486824], [78.86228943, 25.28313065], [78.85791779, 25.26624107], [78.85288239, 25.2588501], [78.85028839, 25.25342751], [78.84594727, 25.23378944], [78.84462738, 25.23110962], [78.8417511, 25.22916031], [78.83505249, 25.23320007], [78.82367706, 25.25107956], [78.81128693, 25.26600075], [78.80562592, 25.27093124], [78.80635071, 25.27946091], [78.81215668, 25.29409981], [78.81272125, 25.29776001], [78.81167603, 25.29984093], [78.80699158, 25.30297089], [78.80367279, 25.30199814], [78.79328918, 25.29310036], [78.79120636, 25.29301071], [78.78692627, 25.29494095], [78.7832489, 25.29761124], [78.78328705, 25.30318069], [78.78674316, 25.30972099], [78.79193878, 25.31479263], [78.79802704, 25.31452179], [78.81022644, 25.31085968], [78.81456757, 25.31096077], [78.81667328, 25.31657028], [78.8216629, 25.31874275], [78.82659912, 25.31985283], [78.8332901, 25.33134079], [78.83566284, 25.33298111], [78.84026337, 25.33185005], [78.84350586, 25.33236122], [78.84567261, 25.33518982], [78.84541321, 25.33867073], [78.8431778, 25.34208107], [78.83586121, 25.34703064], [78.83773804, 25.35217285], [78.8453598, 25.36091042], [78.86142731, 25.37702942], [78.87474823, 25.38765907], [78.88301849, 25.38951111], [78.89055634, 25.38883018], [78.90107727, 25.38925934], [78.90830994, 25.39237022], [78.91201019, 25.39699936], [78.9154129, 25.39962959], [78.92266846, 25.4004612], [78.9310379, 25.4031601], [78.94341278, 25.40312004], [78.94935608, 25.40015984], [78.95123291, 25.39645958], [78.94725037, 25.39318085], [78.93885803, 25.38907051], [78.93113708, 25.37712288], [78.92636871, 25.37734032], [78.90912628, 25.38056183], [78.89539337, 25.38079071], [78.89245605, 25.37529755], [78.89322662, 25.36901093], [78.8969574, 25.36520958], [78.90638733, 25.36338043], [78.9171524, 25.35999107], [78.92862701, 25.35180092], [78.93871307, 25.35283089], [78.94844055, 25.37000275], [78.95527649, 25.37308121], [78.97447205, 25.3725605], [78.978508, 25.3760128], [78.97840881, 25.38286018], [78.97580719, 25.38869095], [78.97106171, 25.39184952], [78.96817017, 25.39655113], [78.9655304, 25.41147995], [78.97022247, 25.42045975], [78.96891022, 25.42513275], [78.96248627, 25.43635941], [78.96012878, 25.43889046], [78.94696808, 25.44254112], [78.94258881, 25.44170189], [78.93782043, 25.43753815], [78.93415833, 25.4318924], [78.92913055, 25.42832947], [78.91259003, 25.43867111], [78.90322876, 25.44693756], [78.90631104, 25.4504509], [78.91340637, 25.4520607], [78.9197464, 25.46216011], [78.92745972, 25.46569061], [78.93003845, 25.46858978], [78.93563843, 25.48002052], [78.93612671, 25.48778152], [78.93518066, 25.49430084], [78.93315125, 25.4982605], [78.92617798, 25.50761032], [78.91918182, 25.51355171], [78.91668701, 25.51675034], [78.91638184, 25.52075005], [78.91726685, 25.52547073], [78.9196167, 25.52744293], [78.93224335, 25.52435112], [78.93844604, 25.52753067], [78.9418869, 25.53115082], [78.94381714, 25.54092026], [78.94168854, 25.55144119], [78.93566132, 25.55709076], [78.93074036, 25.55972099], [78.92568207, 25.5599575], [78.92263794, 25.55682945], [78.9204483, 25.54957008], [78.9185791, 25.54332161], [78.9168396, 25.54129028], [78.91332245, 25.54552078], [78.91036987, 25.55933952], [78.90595245, 25.56060028], [78.89678955, 25.55939102], [78.88553619, 25.56077003], [78.88276672, 25.56040955], [78.88109589, 25.5601902], [78.87435913, 25.55701256], [78.8690033, 25.55116081], [78.8684082, 25.54417992], [78.87757111, 25.53318977], [78.87837219, 25.52865982], [78.87600708, 25.5243206], [78.85128784, 25.51889038], [78.84706879, 25.51853943], [78.84120178, 25.51807022], [78.83673096, 25.51678848], [78.83394623, 25.51600075], [78.82832336, 25.50998116], [78.82699585, 25.50370026], [78.83071899, 25.49837112], [78.84603882, 25.4913826], [78.84880066, 25.48757172], [78.85164642, 25.47779083], [78.8571701, 25.4671402], [78.8572464, 25.46215248], [78.85369873, 25.45230103], [78.84533691, 25.44497108], [78.83660126, 25.43424988], [78.83426666, 25.43246078], [78.83097839, 25.43203163], [78.81973267, 25.43778038], [78.81569672, 25.44175911], [78.81387329, 25.44630814], [78.81645966, 25.44890976], [78.83036041, 25.44748116], [78.83268738, 25.44765282], [78.83718872, 25.44798088], [78.84200287, 25.45000267], [78.8457489, 25.45438957], [78.84211731, 25.45714951], [78.83764648, 25.45885086], [78.83590698, 25.45998955], [78.83339691, 25.46165085], [78.82985687, 25.46569061], [78.82549286, 25.46837044], [78.81526184, 25.47241974], [78.81019592, 25.47544098], [78.78952789, 25.48351288], [78.78172302, 25.48414993], [78.77677155, 25.48339081], [78.77297211, 25.48283005], [78.76432037, 25.4766407], [78.76051331, 25.47575951], [78.75654602, 25.47615051], [78.7494812, 25.48221016], [78.74359131, 25.48489189], [78.74154663, 25.48993111], [78.73931885, 25.49987984], [78.7360611, 25.50432968], [78.73175049, 25.50065041], [78.72631836, 25.49007034], [78.72464752, 25.46330833], [78.72766876, 25.4587307], [78.7323761, 25.45566177], [78.7436676, 25.45210075], [78.74812317, 25.44844055], [78.75180817, 25.43843079], [78.75506592, 25.43385124], [78.75997162, 25.43056107], [78.76537323, 25.43003273], [78.77207947, 25.4329319], [78.77629089, 25.43696976], [78.78218079, 25.43992043], [78.7894516, 25.44202042], [78.79528809, 25.44132805], [78.80345154, 25.43819046], [78.8117981, 25.43308067], [78.81291199, 25.43042755], [78.81138611, 25.42735291], [78.80766296, 25.42523956], [78.79464722, 25.4265995], [78.79046631, 25.42568016], [78.78823853, 25.42358017], [78.77604675, 25.42119026], [78.7562027, 25.41929817], [78.74938202, 25.41756058], [78.7454071, 25.4155407], [78.74314117, 25.41270065], [78.7405014, 25.40654182], [78.74030304, 25.40307045], [78.74156189, 25.39858055], [78.74349976, 25.39767075], [78.74754333, 25.4005394], [78.75115967, 25.40526962], [78.7546463, 25.40621948], [78.75863647, 25.40409088], [78.75962067, 25.402071], [78.75988007, 25.39775085], [78.75888824, 25.39352036], [78.75726318, 25.39252281], [78.75437164, 25.39307022], [78.75302887, 25.39195061], [78.75286102, 25.39034081], [78.75482178, 25.38619041], [78.76122284, 25.38216019], [78.76216125, 25.37437057], [78.76574707, 25.36477089], [78.76532745, 25.36044121], [78.76438141, 25.35840034], [78.75628662, 25.35750961], [78.74978638, 25.35211945], [78.735672, 25.34919167], [78.72524261, 25.35398293], [78.72112274, 25.3538208], [78.71794891, 25.35280991], [78.71362305, 25.3529892], [78.70944214, 25.35432053], [78.70384979, 25.3586483], [78.70361328, 25.36170006], [78.70455933, 25.36559105], [78.70976257, 25.37626839], [78.70903015, 25.37874985], [78.69982147, 25.38170052], [78.69711304, 25.38329124], [78.69610596, 25.38552856], [78.69275665, 25.38773918], [78.6905899, 25.38673973], [78.68914032, 25.3830204], [78.68717957, 25.3806324], [78.68386078, 25.38047981], [78.67156219, 25.38456154], [78.67352295, 25.38799095], [78.67376709, 25.39116096], [78.66940308, 25.39290047], [78.66493225, 25.38800049], [78.66117096, 25.38656044], [78.65789032, 25.38797951], [78.65592957, 25.39217186], [78.65688324, 25.39599037], [78.65666962, 25.4005394], [78.6520462, 25.41314125], [78.65367889, 25.41681099], [78.65651703, 25.42012978], [78.65930176, 25.4183712], [78.66493988, 25.40446091], [78.66909027, 25.40388107], [78.68448639, 25.41601181], [78.70024109, 25.42612076], [78.70140076, 25.42885971], [78.69983673, 25.43230057], [78.69332123, 25.43922043], [78.68924713, 25.44535065], [78.6857605, 25.44779015], [78.6816864, 25.44740105], [78.67893219, 25.44389915], [78.67751312, 25.43972969], [78.67488861, 25.43814087], [78.67041016, 25.43889046], [78.65796661, 25.44383049], [78.65271759, 25.44400024], [78.64901733, 25.44239235], [78.64541626, 25.43785095], [78.63883972, 25.44042969], [78.63365936, 25.43806076], [78.63250732, 25.4330101], [78.63749695, 25.41978836], [78.63680267, 25.41411018], [78.63379669, 25.4095211], [78.62858582, 25.40646172], [78.62362671, 25.4059906], [78.61921692, 25.40703964], [78.61692047, 25.41007042], [78.61435699, 25.41633034], [78.60349274, 25.41707039], [78.59895325, 25.41522026], [78.59461212, 25.40911293], [78.59163666, 25.39653969], [78.58834076, 25.39211273], [78.58409882, 25.3902607], [78.5789032, 25.39009094], [78.5761261, 25.39109039], [78.5686264, 25.39619064], [78.56344604, 25.39792061], [78.56112671, 25.39569283], [78.55690002, 25.38414955], [78.56009674, 25.38204956], [78.56463623, 25.38396072], [78.57034302, 25.38478279], [78.57440186, 25.38223076], [78.57775879, 25.37714005], [78.57950592, 25.36057091], [78.5789032, 25.35531807], [78.57621765, 25.35193062], [78.56204987, 25.34795189], [78.55602264, 25.34860992], [78.54473114, 25.3586998], [78.53505707, 25.36400986], [78.52806091, 25.36588097], [78.52514648, 25.36301231], [78.52336884, 25.3583107], [78.52480316, 25.35474968], [78.53044891, 25.35205078], [78.53108978, 25.34859085], [78.53069305, 25.33916855], [78.53150177, 25.33485031], [78.53359222, 25.33089256], [78.53768921, 25.32949829], [78.54145813, 25.32659912], [78.54083252, 25.3224411], [78.5389328, 25.32039261], [78.53356171, 25.31870079], [78.53098297, 25.31706047], [78.52507782, 25.30653], [78.51872253, 25.30581284], [78.51586151, 25.30433083], [78.50511169, 25.30211067], [78.50025177, 25.30413055], [78.49581146, 25.3101902], [78.49492645, 25.32069016], [78.49217224, 25.32382965], [78.4875412, 25.32019043], [78.48324585, 25.31418991], [78.47792053, 25.30869102], [78.47175598, 25.30583954], [78.46926117, 25.30332184], [78.46705627, 25.29301071], [78.45928955, 25.29665947], [78.45680237, 25.2993412], [78.44851685, 25.30328941], [78.44059753, 25.30416107], [78.43517303, 25.30252075], [78.4298172, 25.29701042], [78.42736053, 25.28867149], [78.42871094, 25.28083038], [78.43575287, 25.27324104], [78.44445038, 25.26995087], [78.4540329, 25.27060127], [78.48932648, 25.29208946], [78.49668121, 25.29385948], [78.50080872, 25.28824806], [78.50257874, 25.28342056], [78.50531769, 25.28154755], [78.52085114, 25.28803825], [78.52516937, 25.28549957], [78.52555847, 25.27817154], [78.52849579, 25.27450943], [78.53601837, 25.27194977], [78.54226685, 25.27203941], [78.55237579, 25.27087975], [78.55702209, 25.26932907], [78.56437683, 25.26521111], [78.56858063, 25.25860977], [78.56816864, 25.25405121], [78.5657959, 25.24945068], [78.56254578, 25.23867035], [78.56149292, 25.22744942], [78.56259155, 25.22602272], [78.56456757, 25.22096062], [78.56976318, 25.20195961], [78.59371185, 25.15739059], [78.59597778, 25.14858055], [78.59816742, 25.12708092], [78.59829712, 25.10808945], [78.59667969, 25.10345078], [78.59716797, 25.09787178], [78.60555267, 25.09422112], [78.61760712, 25.09271049], [78.62032318, 25.09159279], [78.6247406, 25.08641052], [78.62948608, 25.08242989], [78.63482666, 25.07419014], [78.6355896, 25.07101059], [78.63941193, 25.06637192], [78.64192963, 25.06149101], [78.64418793, 25.03524971], [78.6371994, 25.02555084], [78.6361618, 25.02136993], [78.6361618, 25.01089287], [78.63510895, 25.00432968], [78.63201904, 24.98372078], [78.62290192, 24.9677906], [78.62204742, 24.96490097], [78.62491608, 24.96194077], [78.64243317, 24.95265007], [78.64251709, 24.95029068], [78.6400528, 24.94532967], [78.64050293, 24.94036293], [78.6421814, 24.93976974], [78.65371704, 24.94421959], [78.65709686, 24.92506027], [78.65947723, 24.91752052], [78.66301727, 24.9092617], [78.668396, 24.90239906], [78.6754303, 24.8985405], [78.67965698, 24.89719009], [78.69171906, 24.89590073], [78.69634247, 24.89466095], [78.70056915, 24.88648033], [78.70289612, 24.88402748], [78.7128067, 24.88379097], [78.71887207, 24.88266182], [78.72254181, 24.88071823], [78.73163605, 24.87234116], [78.73441315, 24.87099266], [78.73838043, 24.86963081], [78.74668121, 24.87084961], [78.75061035, 24.86886024], [78.75343323, 24.86496925], [78.76135254, 24.86295128], [78.76448059, 24.86136818], [78.76716614, 24.85567093], [78.76740265, 24.84891129], [78.76888275, 24.84374809], [78.77256775, 24.83048058], [78.78054047, 24.81497192], [78.78109741, 24.81051064], [78.78011322, 24.80698967], [78.77781677, 24.80487251], [78.76722717, 24.79851151], [78.76454926, 24.79499245], [78.76319885, 24.76675987], [78.76862335, 24.7548008], [78.76895142, 24.75110054], [78.76748657, 24.74341011], [78.76912689, 24.72354126], [78.76980591, 24.71884918], [78.77308655, 24.71165085], [78.77297974, 24.70691109], [78.77239227, 24.70414162], [78.76760101, 24.69692993], [78.76534271, 24.69532967], [78.75998688, 24.69356918], [78.75878143, 24.68217087], [78.75753784, 24.67715073], [78.75498962, 24.67357063], [78.74487305, 24.66930962], [78.74427032, 24.66682053], [78.74006653, 24.65995979], [78.7405777, 24.65607071], [78.74208069, 24.65063095], [78.74635315, 24.64319038], [78.74797821, 24.63705063], [78.7485733, 24.62471008], [78.74803162, 24.61152077], [78.74946594, 24.60498047], [78.75199127, 24.60246277], [78.76661682, 24.59756279], [78.77690125, 24.59309006], [78.79382324, 24.59822845], [78.79788208, 24.60531998], [78.80182648, 24.60782814], [78.80667877, 24.6071701], [78.81112671, 24.60533905], [78.8140564, 24.60560036], [78.82039642, 24.6078701], [78.82878113, 24.60781097], [78.83084869, 24.60889053], [78.83345032, 24.62079048], [78.83599854, 24.62557983], [78.83905792, 24.6282196], [78.84436798, 24.62899017], [78.84916687, 24.62166023], [78.85240173, 24.62094116], [78.85579681, 24.62298965], [78.85919189, 24.62817955], [78.86280823, 24.64112091], [78.866539, 24.64549255], [78.87306976, 24.64694977], [78.8817215, 24.63969994], [78.89144135, 24.62207031], [78.89186859, 24.61680031], [78.89295197, 24.6138382], [78.90438843, 24.60430908], [78.90561676, 24.602211], [78.90850067, 24.58880997], [78.91314697, 24.58130074], [78.93038177, 24.56439018], [78.94299316, 24.55787849], [78.94465637, 24.55620956], [78.94550323, 24.55331039], [78.94036865, 24.54314995], [78.94001007, 24.53408051], [78.94042206, 24.53120995], [78.94393921, 24.52664757], [78.94477081, 24.52363014], [78.943367, 24.51662064], [78.94416809, 24.50950813], [78.94708252, 24.50598907], [78.95018768, 24.50447845], [78.96340942, 24.50204086], [78.96549225, 24.50028038], [78.96639252, 24.49694824], [78.96391296, 24.49378014], [78.95455933, 24.48855972], [78.94856262, 24.4861927], [78.94313812, 24.48488045], [78.93071747, 24.48454094], [78.92517853, 24.48599052], [78.92334747, 24.48839951], [78.92569733, 24.49183083], [78.92607117, 24.49638748], [78.92436218, 24.49908066], [78.92182922, 24.50107956], [78.91757965, 24.50251007], [78.91381073, 24.50084114], [78.90808105, 24.49316025], [78.90093994, 24.4883709], [78.90088654, 24.48357964], [78.9026413, 24.47837067], [78.90859222, 24.46677017], [78.91279602, 24.46351051], [78.92724609, 24.4621315], [78.93107605, 24.4599781], [78.94065857, 24.44598007], [78.94439697, 24.44325829], [78.94713593, 24.44313049], [78.95552826, 24.44512749], [78.96203613, 24.44407082], [78.97183228, 24.44473267], [78.981987, 24.44724083], [78.98438263, 24.44136047], [78.98651123, 24.43403053], [78.98777771, 24.42797089], [78.9868927, 24.42324066], [78.98087311, 24.41782951], [78.97621155, 24.40289116], [78.97422028, 24.39863968], [78.97097778, 24.38472939], [78.96717072, 24.37358284], [78.96692657, 24.37034988], [78.96833801, 24.36024284], [78.96813965, 24.35695076], [78.96687317, 24.35366058], [78.9648819, 24.35044289], [78.96099091, 24.34716988], [78.95493317, 24.34392929], [78.95088959, 24.34041023], [78.94536591, 24.33130074], [78.93245697, 24.31888962], [78.92874146, 24.31620979], [78.9241333, 24.31421852], [78.90776062, 24.30123138], [78.9070816, 24.29643059], [78.9077301, 24.29487038], [78.91284943, 24.28944969], [78.91322327, 24.28590965], [78.91172028, 24.2765007], [78.90985107, 24.27292061], [78.88558197, 24.25928116], [78.87909698, 24.25401115], [78.87827301, 24.24868965], [78.87982178, 24.24411964], [78.88105011, 24.22888947], [78.87886047, 24.22305107], [78.87368011, 24.2189312], [78.86283112, 24.21404076], [78.8582077, 24.21354103], [78.84654236, 24.21693039], [78.83876801, 24.21467972], [78.83277893, 24.20928192], [78.82772064, 24.20318985], [78.8242569, 24.20129967], [78.82007599, 24.20121956], [78.81886292, 24.20243835], [78.81638336, 24.20865059], [78.81352234, 24.21027946], [78.8105011, 24.20852089], [78.80908203, 24.20465088], [78.80795288, 24.19331932], [78.80570984, 24.18429947], [78.80224609, 24.18190002], [78.79168701, 24.18024063], [78.78848267, 24.18135834], [78.7845993, 24.18514061], [78.78205872, 24.19152069], [78.77831268, 24.2010498], [78.77625275, 24.21002007], [78.77488708, 24.21228981], [78.76983643, 24.215271], [78.76774597, 24.21777916], [78.76053619, 24.23385048], [78.76000977, 24.23651123], [78.7607193, 24.2390995], [78.76642609, 24.25057983], [78.76027679, 24.25848961], [78.75668335, 24.25972939], [78.75428772, 24.2472496], [78.75255585, 24.24367905], [78.74977112, 24.24073982], [78.74588776, 24.23927116], [78.74371338, 24.23945045], [78.74085236, 24.24016953], [78.73751831, 24.24210167], [78.73610687, 24.24510956], [78.73526001, 24.25177956], [78.73221588, 24.25382042], [78.72653961, 24.25270081], [78.72110748, 24.24122047], [78.71858215, 24.239151], [78.71111298, 24.23944092], [78.7071228, 24.23876953], [78.69886017, 24.2344799], [78.69258118, 24.23701096], [78.68113708, 24.24407005], [78.67809296, 24.24489975], [78.67311096, 24.24435043], [78.66912079, 24.24501991], [78.66535187, 24.24844933], [78.66316223, 24.25263023], [78.65779877, 24.26805115], [78.65444946, 24.27374077], [78.64363861, 24.28149986], [78.63923645, 24.28619957], [78.6341629, 24.28936958], [78.6313858, 24.29018974], [78.62602234, 24.28646278], [78.62171936, 24.2862606], [78.61940002, 24.28944969], [78.61734009, 24.2961216], [78.61788177, 24.2992897], [78.62351227, 24.30690193], [78.62281036, 24.30985069], [78.61962891, 24.31184006], [78.61492157, 24.31257248], [78.6047821, 24.31574059], [78.6020813, 24.31830025], [78.59900665, 24.32318115], [78.59364319, 24.33936119], [78.58777618, 24.34135056], [78.58470154, 24.3434391], [78.58071899, 24.34983063], [78.57888031, 24.35396194], [78.57843781, 24.35708046], [78.57489777, 24.3593502], [78.56651306, 24.35732079], [78.56265259, 24.35935974], [78.5568924, 24.3611908], [78.55258179, 24.36062813], [78.52762604, 24.37447166], [78.52511597, 24.37713814], [78.52207184, 24.38414955], [78.51922607, 24.38735008], [78.51455688, 24.39055824], [78.50537109, 24.39394951], [78.49993896, 24.39433098], [78.49819183, 24.3927803], [78.48977661, 24.38605118], [78.48430634, 24.37762833], [78.47532654, 24.36742973], [78.47280121, 24.36235046], [78.47167969, 24.35709], [78.47077179, 24.34338188], [78.46779633, 24.33934021], [78.45892334, 24.33568954], [78.45459747, 24.33322144], [78.45082855, 24.32987976], [78.44029236, 24.32553101], [78.4335022, 24.31340981], [78.43332672, 24.30900955], [78.43477631, 24.29766083], [78.42648315, 24.29018021], [78.42315674, 24.28915024], [78.41861725, 24.28946114], [78.41448975, 24.28884125], [78.41130829, 24.28758049], [78.4069519, 24.27700996], [78.40326691, 24.27547264], [78.39296722, 24.2747612], [78.38566589, 24.27305031], [78.38237, 24.2739296], [78.37963867, 24.27556038], [78.37742615, 24.27806091], [78.3730011, 24.28635979], [78.36989594, 24.28908157], [78.36624908, 24.29030991], [78.3639679, 24.29235077], [78.36168671, 24.29610062], [78.35141754, 24.29927063], [78.34453583, 24.30328941], [78.34243774, 24.30538177], [78.34140015, 24.30780983], [78.34130859, 24.31151962], [78.33943176, 24.31735992], [78.33551788, 24.31917953], [78.33181, 24.32249069], [78.32852173, 24.32550049], [78.3259964, 24.32961845], [78.32543182, 24.33436966], [78.32657623, 24.33846855], [78.33112335, 24.34255028], [78.33544922, 24.3450985], [78.34092712, 24.35242081], [78.34651947, 24.36269951], [78.36257172, 24.37815094], [78.36292267, 24.38161087], [78.36094666, 24.38578987], [78.3588562, 24.38718987], [78.35040283, 24.38953018], [78.3449173, 24.39204025], [78.33673096, 24.40386963], [78.33244324, 24.40597153], [78.31830597, 24.4103508], [78.31520081, 24.41284943], [78.31150055, 24.41744041], [78.29985046, 24.42654991], [78.28985596, 24.43312073], [78.28121185, 24.43721008], [78.26687622, 24.44737053], [78.26074982, 24.45393944], [78.26030731, 24.46001053], [78.26966095, 24.47310829], [78.2696228, 24.47618294], [78.26682281, 24.47999954], [78.263237, 24.48308182], [78.2545929, 24.4858284], [78.24621582, 24.48671913], [78.23963165, 24.48945999], [78.23789978, 24.49358177], [78.23768616, 24.49617958], [78.24150848, 24.50484276], [78.24017334, 24.50958061], [78.23806, 24.5116806], [78.2281723, 24.51645279], [78.21971893, 24.52277946], [78.21653748, 24.53164291], [78.21839905, 24.53569031], [78.22418213, 24.54133987], [78.23654938, 24.5463295], [78.24610901, 24.5486908], [78.25531769, 24.5522995], [78.25888824, 24.55818939], [78.26035309, 24.56923294], [78.2637558, 24.57872009], [78.26808167, 24.59697914], [78.26940155, 24.60502052], [78.26985168, 24.61538124], [78.26753235, 24.62191963], [78.26339722, 24.62812042], [78.25847626, 24.63780022], [78.25669098, 24.64862061], [78.25834656, 24.65283966], [78.26789856, 24.66352081], [78.26847839, 24.66710091], [78.26799774, 24.66959953], [78.25699615, 24.68593025], [78.25460815, 24.69248962], [78.25280762, 24.70094109], [78.25078583, 24.70557022], [78.23654938, 24.72463989], [78.22631836, 24.73624992], [78.22039032, 24.74736977], [78.21888733, 24.75379944], [78.21987152, 24.75819016], [78.22428894, 24.76403046], [78.22518921, 24.76639175], [78.22582245, 24.77657127], [78.22387695, 24.78300095], [78.21836853, 24.79191971], [78.20896912, 24.8130703], [78.19587708, 24.82859039], [78.19403076, 24.83156013], [78.19158173, 24.83967018], [78.18689728, 24.84280968], [78.17357635, 24.8461895], [78.1700058, 24.84647942], [78.16532898, 24.84817123], [78.1638031, 24.85709953], [78.16355133, 24.8642807], [78.16332245, 24.87099266], [78.16470337, 24.87829971], [78.1653595, 24.88174057], [78.1704483, 24.88526917], [78.17704773, 24.88733101], [78.18917084, 24.89280128], [78.19973755, 24.8962307], [78.2039566, 24.90050125], [78.21070862, 24.91234016], [78.21391296, 24.91557121], [78.22878265, 24.9240799], [78.24936676, 24.93848038], [78.25244904, 24.93950081], [78.25604248, 24.94203949], [78.25991821, 24.94924927], [78.26271057, 24.95260048], [78.2822876, 24.96320915], [78.28959656, 24.96813965], [78.30256653, 24.98397064], [78.3066864, 24.98899269], [78.30961609, 24.99124908], [78.32753754, 24.9995594], [78.33020782, 25.00374031], [78.33460999, 25.01073837], [78.33751678, 25.0207901], [78.3380661, 25.02733994], [78.33078003, 25.0453701], [78.32717896, 25.06791115], [78.32498932, 25.07249832], [78.32524872, 25.08406067], [78.32675934, 25.08688164], [78.32776642, 25.08876991], [78.33090973, 25.09163094], [78.33265686, 25.09324265], [78.34781647, 25.09996986], [78.35784149, 25.10235023], [78.36699677, 25.1045208], [78.37441254, 25.10853958], [78.37869263, 25.11269951], [78.38968658, 25.12699127], [78.39531708, 25.1305275], [78.40226746, 25.13097], [78.41072845, 25.1292305], [78.41765594, 25.12697029], [78.42468262, 25.12469101], [78.43097687, 25.1244812], [78.44291687, 25.12877083], [78.43235779, 25.13754082], [78.42294312, 25.14537048], [78.41882324, 25.15109062], [78.41829681, 25.1534996], [78.42089844, 25.15764046], [78.42870331, 25.15833092], [78.44198608, 25.15735054], [78.44284821, 25.15788078], [78.44631195, 25.1667099], [78.44645691, 25.16902161], [78.44394684, 25.17255974], [78.43913269, 25.17214966], [78.43746185, 25.17140961], [78.435112, 25.17036057], [78.42823029, 25.16964149], [78.41726685, 25.17278099], [78.4090271, 25.18202972], [78.40725708, 25.1857605], [78.40355682, 25.18894005], [78.3913269, 25.19120026], [78.38889313, 25.1928196], [78.38536072, 25.19515991], [78.38427734, 25.19933128], [78.3835907, 25.20195007], [78.3838501, 25.20486069], [78.38394928, 25.20600128], [78.38577271, 25.20868111], [78.39450073, 25.21463966], [78.39775848, 25.21775055], [78.39553833, 25.22118187], [78.39215088, 25.22234917], [78.38108826, 25.2238102], [78.37516785, 25.22575188], [78.37075806, 25.23336029], [78.36888885, 25.24166107], [78.3645401, 25.24391174], [78.35708618, 25.24417114], [78.35453033, 25.2460804], [78.35521698, 25.24996948], [78.36029816, 25.25856972], [78.36222076, 25.26543045], [78.35526276, 25.2757206], [78.34506989, 25.28297043], [78.34516144, 25.29794121], [78.34130859, 25.29927063], [78.33007813, 25.30038071], [78.31645203, 25.30458069], [78.31163788, 25.3075695], [78.30802917, 25.31098938], [78.31057739, 25.31615829], [78.31543732, 25.32073021], [78.32710266, 25.32720947], [78.32782745, 25.32761002], [78.33078003, 25.33128929], [78.3312912, 25.33671951], [78.32756042, 25.34645081], [78.32657623, 25.34902], [78.32319641, 25.35526848], [78.31626892, 25.35961914], [78.30162048, 25.36437988], [78.2962265, 25.36499023], [78.2942276, 25.36762047], [78.29551697, 25.37479973], [78.29972076, 25.38375282], [78.30340576, 25.38479042], [78.30716705, 25.3841629], [78.31067657, 25.3850708], [78.31690979, 25.39090919], [78.32151031, 25.3952198], [78.33027649, 25.40099907], [78.33248901, 25.40455055], [78.33407593, 25.41815186], [78.33518982, 25.43105125], [78.33656311, 25.43498993], [78.34378815, 25.44617844], [78.34758759, 25.45483971], [78.34925842, 25.45579147], [78.35266876, 25.45531273], [78.36097717, 25.44660187], [78.36614227, 25.44631767], [78.37077332, 25.44717026], [78.37738037, 25.44837952], [78.38088989, 25.4504509], [78.38340759, 25.45193291], [78.38568878, 25.45416069], [78.39189911, 25.46884918], [78.39309692, 25.47042084], [78.39375305, 25.47125053], [78.3960495, 25.47177124], [78.40142822, 25.47297096], [78.40672302, 25.47921944], [78.41646576, 25.47750282], [78.42072296, 25.47761917], [78.42156982, 25.47970963], [78.41947937, 25.49054146], [78.412323, 25.49766159], [78.40940857, 25.50427055], [78.408638, 25.50799942], [78.40956879, 25.51864815], [78.41124725, 25.51902008], [78.41433716, 25.51531029], [78.41628265, 25.51573944], [78.41674805, 25.51777267], [78.41529846, 25.52139091], [78.411026, 25.52738953], [78.40866089, 25.53290176], [78.40997314, 25.53771973], [78.41230774, 25.54224968], [78.4261322, 25.56145096], [78.42933655, 25.56385994], [78.43353271, 25.56524086], [78.43707275, 25.56435013], [78.43974304, 25.55895996], [78.44303894, 25.5570507], [78.44496918, 25.55499077], [78.44915009, 25.5527401], [78.45519257, 25.55195045], [78.45733643, 25.55540085], [78.46003723, 25.56455994], [78.46212006, 25.56747055], [78.46894073, 25.57298088], [78.48108673, 25.58043289], [78.48626709, 25.58222961], [78.49149323, 25.58188057], [78.51143646, 25.57296181], [78.52751923, 25.57292938], [78.53240204, 25.57028961], [78.53604889, 25.56686974], [78.54178619, 25.56513977], [78.54714966, 25.56470108], [78.55974579, 25.56780052], [78.56548309, 25.56787109], [78.57096863, 25.56735992], [78.57608032, 25.56528854], [78.58119202, 25.56430817], [78.583992, 25.56554985], [78.58706665, 25.57294083], [78.59027863, 25.57522011], [78.59525299, 25.57493019], [78.59799194, 25.57561111], [78.60015106, 25.57835007], [78.6042099, 25.58728981], [78.60573578, 25.58887291], [78.60862732, 25.58908081], [78.6181488, 25.58699036], [78.62133026, 25.58218002], [78.62020874, 25.57356071], [78.62341309, 25.57100105], [78.62883759, 25.56900024], [78.64434052, 25.56541824], [78.64862061, 25.5656395], [78.66535187, 25.58484077], [78.672966, 25.59180069], [78.67701721, 25.59410095], [78.68798828, 25.59515953], [78.69570923, 25.59984016], [78.7003479, 25.60131073], [78.70658875, 25.60327911], [78.71116638, 25.60659027], [78.72431946, 25.60844994], [78.73284149, 25.60305977], [78.74095154, 25.60387993], [78.7489624, 25.60834122], [78.75541687, 25.60959053], [78.76597595, 25.61314964], [78.78485107, 25.61548996], [78.79454803, 25.6175499], [78.79815674, 25.61922073], [78.80519104, 25.6245575], [78.806427, 25.63302994], [78.80979156, 25.63836098], [78.81124878, 25.64545059], [78.81060791, 25.66506195], [78.8113327, 25.67448044], [78.80938721, 25.67807007], [78.79576111, 25.69614029], [78.78940582, 25.69983101], [78.79070282, 25.70285034], [78.79255676, 25.70717049], [78.79123688, 25.71054077], [78.77752686, 25.71370125], [78.76074982, 25.72079086], [78.75240326, 25.72741127], [78.74803925, 25.73265076], [78.7457962, 25.73801994], [78.74550629, 25.74411964], [78.74681854, 25.74909019], [78.75128174, 25.75270081], [78.75567627, 25.75299072], [78.76241302, 25.75226021], [78.76582336, 25.75891113], [78.77578735, 25.7614994], [78.77996826, 25.77511978], [78.79062653, 25.7882309], [78.79360199, 25.7935009], [78.79606628, 25.79593086], [78.79955292, 25.79936028], [78.80413055, 25.80033112], [78.80497742, 25.80019188], [78.81169891, 25.79914093], [78.8167572, 25.7992897], [78.82050323, 25.79940033], [78.82408142, 25.80760956], [78.82376862, 25.81082153], [78.82363892, 25.81236076], [78.82227325, 25.81522751], [78.81623077, 25.81758118], [78.813797, 25.81681061], [78.80766296, 25.81151962], [78.80401611, 25.81022072], [78.80046082, 25.81287956], [78.79885864, 25.8182106], [78.80198669, 25.82220078], [78.81124878, 25.83012009], [78.81582642, 25.83114052], [78.83512878, 25.82409286], [78.84098053, 25.82064056], [78.84179688, 25.81680107], [78.84073639, 25.81208038], [78.84129333, 25.80520058], [78.8436203, 25.80130959], [78.8496933, 25.79586029], [78.8559494, 25.79443932], [78.86192322, 25.79919815], [78.8633194, 25.80208015], [78.86396027, 25.81627083], [78.86646271, 25.8296299], [78.86575317, 25.83435059], [78.85293579, 25.84361076], [78.84622192, 25.83876038], [78.84397888, 25.84531021], [78.84662628, 25.86050034], [78.85051727, 25.86561012], [78.85782623, 25.87201118], [78.86071777, 25.87332916], [78.86358643, 25.87467194], [78.86606598, 25.87485123], [78.86798096, 25.87498093], [78.87268829, 25.87302017], [78.87689209, 25.8698597], [78.8826828, 25.87026978], [78.88345337, 25.87491989], [78.88371277, 25.87647057], [78.88134003, 25.8884201], [78.88511658, 25.89286041], [78.88719177, 25.89897156], [78.8829422, 25.90635109], [78.88034821, 25.90955162], [78.87741852, 25.91316986], [78.8768692, 25.91448021], [78.87638092, 25.91566086], [78.89427185, 25.92585182], [78.89808655, 25.93087006], [78.90125275, 25.9375], [78.90394592, 25.94110107], [78.90978241, 25.94608116], [78.91532898, 25.94936943], [78.92384338, 25.95275116], [78.92112732, 25.95084763], [78.92215729, 25.95012093], [78.92484283, 25.9487114], [78.92735291, 25.94832039], [78.92952728, 25.94935989], [78.93009949, 25.95158005], [78.92742157, 25.95549965], [78.92582703, 25.95889282], [78.92547607, 25.96541977], [78.92951965, 25.9716301], [78.93113708, 25.97631073], [78.9261322, 25.97776985], [78.92362213, 25.9808712], [78.92459106, 25.98431015], [78.92720032, 25.98651123], [78.93102264, 25.98553085], [78.93621826, 25.98531914], [78.93947601, 25.98637009], [78.94316864, 25.99069023], [78.9438858, 25.99324036], [78.94330597, 25.99822807], [78.94610596, 26.00155067], [78.94658661, 26.00506973], [78.94613647, 26.00616074], [78.94441986, 26.00889015], [78.94534302, 26.01390076], [78.95040131, 26.01986122], [78.95050049, 26.02582169], [78.94618988, 26.03107262], [78.94432831, 26.03695107], [78.94863129, 26.03881264], [78.95266724, 26.04203033], [78.96144867, 26.0508194], [78.9681778, 26.05916023], [78.97579956, 26.05988121], [78.9786911, 26.0646801], [78.98248291, 26.07375908], [78.98602295, 26.07608032], [78.99188232, 26.07464027], [78.99711609, 26.07393074], [78.99915314, 26.07709122], [79.00113678, 26.0783596], [79.00315094, 26.08179283], [79.00219727, 26.08660126], [79.00437927, 26.09008026], [79.00350952, 26.09431076], [79.00049591, 26.09671021], [78.99185181, 26.09526062], [78.99011993, 26.09589958], [78.9718399, 26.1086998], [78.96977997, 26.11230087], [78.97049713, 26.12028122], [78.96922302, 26.1234417], [78.96652985, 26.12565041], [78.95810699, 26.12990952], [78.95464325, 26.13286018], [78.94438934, 26.13751984], [78.94267273, 26.13914108], [78.94576263, 26.14106178], [78.95230103, 26.14260101], [78.96032715, 26.15427017], [78.96533966, 26.15578079], [78.97064209, 26.15540123], [78.98623657, 26.1505394], [78.98966217, 26.15070915], [78.99179077, 26.15205956], [78.99459839, 26.15278053], [79.00071716, 26.15497971], [79.00092316, 26.16026115], [79.002388, 26.16472816], [79.00340271, 26.17295837], [78.99598694, 26.17551041], [78.99178314, 26.17728043], [78.97574615, 26.19281006], [78.97737885, 26.19549942], [78.98091888, 26.19841003], [78.98403931, 26.20067024], [78.99175262, 26.20396805], [78.9944458, 26.2004509], [78.99655151, 26.19898033], [79.00232697, 26.19676971], [79.0129776, 26.19686127], [79.01494598, 26.19746971], [79.01502991, 26.19815063], [79.01257324, 26.20140076], [79.01039124, 26.20277977], [79.00990295, 26.2049408], [79.02062225, 26.20857048], [79.02070618, 26.20967293], [79.01819611, 26.2125206], [79.01872253, 26.21582985], [79.01729584, 26.22369194], [79.01761627, 26.22340012], [79.01690674, 26.22800064], [79.01714325, 26.2321682], [79.02039337, 26.23425293], [79.02466583, 26.23425293], [79.02684784, 26.23336029], [79.02960968, 26.23207092], [79.03425598, 26.23154068], [79.04055023, 26.22928047], [79.04603577, 26.23354912], [79.0521698, 26.23211288], [79.05526733, 26.23238945], [79.05705261, 26.23289108], [79.05555725, 26.23964119], [79.05652618, 26.24188995], [79.06112671, 26.24369049], [79.06266785, 26.24693108], [79.05844116, 26.25391006], [79.05551147, 26.25415039], [79.05191803, 26.25324059], [79.04892731, 26.25369072], [79.04692078, 26.25539017], [79.04535675, 26.26029968], [79.04219818, 26.25996017], [79.03793335, 26.26287079], [79.03703308, 26.26699066], [79.04677582, 26.26531982], [79.04853058, 26.26597023], [79.04679871, 26.27059174], [79.05327606, 26.27960014], [79.05789185, 26.28380013], [79.0640564, 26.28263092], [79.06726837, 26.28762054], [79.06865692, 26.28777122], [79.07206726, 26.28523064], [79.07553101, 26.28713036], [79.07769012, 26.28721809], [79.0786972, 26.28448105], [79.07872772, 26.28034019], [79.07657623, 26.27882195], [79.07610321, 26.27519035], [79.07720184, 26.27359962], [79.07964325, 26.27260971], [79.08357239, 26.27240944], [79.08635712, 26.28367043], [79.08309937, 26.29389954], [79.083992, 26.29708099], [79.08769226, 26.2990303], [79.09178925, 26.30404282], [79.09147644, 26.30845261], [79.09384918, 26.31194115], [79.09797668, 26.31464958], [79.10154724, 26.3138504], [79.10875702, 26.30862045], [79.11457825, 26.31314087], [79.11911774, 26.31492805], [79.12658691, 26.3160305], [79.12724304, 26.32138062], [79.11798859, 26.32634163], [79.11573029, 26.32849121], [79.11569214, 26.33130074], [79.11564636, 26.33509064], [79.12423706, 26.33114052], [79.12586212, 26.33143806], [79.12703705, 26.33165932], [79.12731171, 26.33349037], [79.12499237, 26.33793068], [79.12680054, 26.33992004], [79.13257599, 26.34276009], [79.13374329, 26.3449707], [79.13137817, 26.34589958], [79.12320709, 26.34473038], [79.11952209, 26.35103989], [79.11662292, 26.35357285], [79.10858154, 26.35449028], [79.10526276, 26.35598946], [79.10340118, 26.35951042], [79.10038757, 26.35509109], [79.09644318, 26.35560989], [79.09673309, 26.35956955], [79.0951767, 26.35981941], [79.0930481, 26.36013985], [79.08857727, 26.3599205], [79.08421326, 26.3597126], [79.07679749, 26.36269188], [79.07675934, 26.3660202], [79.07924652, 26.37288094], [79.08911896, 26.37713051], [79.09047699, 26.37939072], [79.08849335, 26.38313293], [79.08959198, 26.38820076], [79.08699799, 26.39108276], [79.08072662, 26.40550041], [79.08682251, 26.41782188], [79.09192657, 26.41674042], [79.09268951, 26.41614914], [79.09703827, 26.41259956], [79.10067749, 26.41173172], [79.11489868, 26.41558838], [79.11723328, 26.41712189], [79.11682129, 26.42421913], [79.11911011, 26.4328804], [79.12328339, 26.4406395], [79.12676239, 26.44481087], [79.12400818, 26.4455204], [79.12098694, 26.44789124], [79.11030579, 26.45301056], [79.10515594, 26.45360184], [79.09989166, 26.45602989], [79.0949173, 26.45709991], [79.09287262, 26.45730019], [79.09118652, 26.45527077], [79.09113312, 26.45240021], [79.08943176, 26.45092964], [79.08329773, 26.4530201], [79.08274841, 26.45231056], [79.08304596, 26.44973946], [79.08094025, 26.44390106], [79.07769775, 26.44723129], [79.07417297, 26.44556808], [79.07279205, 26.44779015], [79.06906891, 26.44651985], [79.06710052, 26.44700813], [79.06684875, 26.44940948], [79.06355286, 26.44895935], [79.06130219, 26.44943047], [79.06062317, 26.45182991], [79.05802917, 26.45128059], [79.05748749, 26.45614052], [79.05323029, 26.45561028], [79.04846191, 26.45605087], [79.04676056, 26.45786095], [79.04707336, 26.46142006], [79.0634613, 26.48476028], [79.06433868, 26.4868412], [79.06230927, 26.48987961], [79.06114197, 26.49095917], [79.06093597, 26.50329971], [79.0565567, 26.50316048], [79.05335999, 26.50121117], [79.05088043, 26.50077057], [79.04971313, 26.50276947], [79.04975128, 26.50666046], [79.04374695, 26.51046944], [79.03930664, 26.5157299], [79.03959656, 26.5196991], [79.04102325, 26.52276039], [79.03946686, 26.5233593], [79.03325653, 26.52262115], [79.03129578, 26.52477074], [79.03366852, 26.53341103], [79.03309631, 26.53598976], [79.01963043, 26.54144096], [79.01863098, 26.5433197], [79.02054596, 26.55166054], [79.01724243, 26.55212975], [79.01278687, 26.54871941], [79.00804138, 26.54778099], [79.00598907, 26.55142021], [79.00284576, 26.54993057], [78.99798584, 26.55093956], [78.99575043, 26.55411148], [78.99768829, 26.55586052], [79.00518799, 26.55623055], [79.00673676, 26.55780029], [79.00437927, 26.55862045], [78.99797058, 26.56401062], [78.99912262, 26.5667305], [78.99785614, 26.57215118], [78.99820709, 26.57422256], [78.9935379, 26.5788002], [78.99134064, 26.58230972], [78.97962189, 26.57407951], [78.97952271, 26.58156967], [78.98100281, 26.58600807], [78.97802734, 26.59243011], [78.9821167, 26.59417915], [78.99133301, 26.60464096], [79.00372314, 26.60637093], [79.00566101, 26.61046982], [79.00520325, 26.61413765], [79.00311279, 26.61923027], [79.0030899, 26.62665939], [79.00084686, 26.63041115], [78.99530029, 26.63596916], [78.99130249, 26.64143944], [78.98722076, 26.6441803], [78.98686981, 26.64736748], [78.98899078, 26.65142059], [78.9912796, 26.65456963], [78.99572754, 26.66356277], [78.99814606, 26.66662025], [79.0011673, 26.6739006], [79.00041199, 26.67671013], [78.99732208, 26.68099022], [78.99317932, 26.68457031], [78.99124908, 26.68444061], [78.98728943, 26.68604088], [78.98388672, 26.68571091], [78.97387695, 26.68254089], [78.9696579, 26.6805706], [78.96393585, 26.67651749], [78.94789124, 26.66262817], [78.9437027, 26.6610508], [78.93791199, 26.66269112], [78.9360733, 26.66488075], [78.93579102, 26.6679306], [78.93698883, 26.67228127], [78.94991302, 26.69194031], [78.95015717, 26.6940403], [78.94814301, 26.6967411], [78.93076324, 26.70426941], [78.91278839, 26.71038055], [78.90792084, 26.71294022], [78.90394592, 26.71338081], [78.88288879, 26.70440102], [78.87708282, 26.7035408], [78.87123871, 26.70360947], [78.8649292, 26.70466995], [78.85431671, 26.71232033], [78.85114288, 26.71642113], [78.84068298, 26.7260704], [78.81138611, 26.7654705], [78.80610657, 26.7687912], [78.79868317, 26.76911163], [78.77414703, 26.76606941], [78.77070618, 26.76419067], [78.76638031, 26.76453972], [78.762146, 26.76683044], [78.75447845, 26.77571106], [78.74904633, 26.78440094], [78.74479675, 26.78940964], [78.74108124, 26.79252052], [78.73596954, 26.78898048], [78.73145294, 26.78310966], [78.72586823, 26.77962112], [78.72293854, 26.77934265], [78.71837616, 26.78170013], [78.7178421, 26.78717995], [78.72033691, 26.79274178], [78.72142792, 26.79771042], [78.71534729, 26.80021286], [78.69007111, 26.79602814], [78.6834259, 26.79461288], [78.67736053, 26.79238129], [78.67282867, 26.78774834], [78.66750336, 26.77424049], [78.65901947, 26.76922989], [78.65036774, 26.76972961], [78.62857056, 26.77539063], [78.62043762, 26.77519989], [78.61569214, 26.77190018], [78.61178589, 26.76711273], [78.60938263, 26.76102066], [78.60646057, 26.75752068], [78.60196686, 26.75605965], [78.57521057, 26.75599289], [78.5658493, 26.75769043], [78.56009674, 26.76221275], [78.55490112, 26.76482964], [78.53504944, 26.77166176], [78.53427124, 26.77200127], [78.52632904, 26.77853966], [78.51557159, 26.78511047], [78.49199677, 26.78795052], [78.47632599, 26.79225159], [78.46631622, 26.79341125], [78.45813751, 26.79523277], [78.45078278, 26.79805183], [78.44557953, 26.80343056], [78.43427277, 26.82411194], [78.430336, 26.82887268], [78.4258728, 26.83231926], [78.41337585, 26.83043098], [78.40032196, 26.82600975], [78.38973999, 26.82489967], [78.38559723, 26.82793999], [78.38065338, 26.83609009], [78.37480927, 26.84683037], [78.37010956, 26.85758972], [78.36688232, 26.8625927], [78.36464691, 26.86884117], [78.36250305, 26.87133026], [78.35135651, 26.87437057], [78.34120178, 26.87395096], [78.32375336, 26.8686409], [78.315979, 26.86936188], [78.30200958, 26.86911964], [78.29470062, 26.86828995], [78.28206635, 26.86408806], [78.27623749, 26.86048126], [78.27075195, 26.85559082], [78.26779175, 26.84966087], [78.2664566, 26.8409996], [78.26677704, 26.8328228], [78.26531219, 26.82467079], [78.26088715, 26.82094955], [78.2556076, 26.82028961], [78.24754333, 26.82387924], [78.23680115, 26.83169937], [78.22299194, 26.8372097], [78.21700287, 26.83767128], [78.20979309, 26.83609009], [78.21164703, 26.83846092], [78.21395111, 26.84852028], [78.20755768, 26.85233116], [78.20448303, 26.85555077], [78.20075226, 26.86240005], [78.19689178, 26.87212181], [78.19017792, 26.88346291], [78.19113922, 26.88861084], [78.19352722, 26.88952065], [78.20053864, 26.87858009], [78.20485687, 26.87738991], [78.22657013, 26.88262939], [78.22978973, 26.89389992], [78.23249817, 26.89545822], [78.24817657, 26.90063095], [78.25267029, 26.90460968], [78.25432587, 26.90974808], [78.25953674, 26.91621971], [78.26223755, 26.92351151], [78.2617569, 26.93017006], [78.26122284, 26.93177986], [78.25831604, 26.9340229], [78.25219727, 26.9349823], [78.24733734, 26.93074989], [78.24024963, 26.93363953], [78.23274231, 26.93369293], [78.23060608, 26.93678284], [78.22940063, 26.94131088], [78.22731781, 26.94358063], [78.2233963, 26.9450798], [78.22052765, 26.94767952], [78.21589661, 26.95395088], [78.21219635, 26.94961929], [78.20826721, 26.93975258], [78.20524597, 26.93889046], [78.2012558, 26.94032288], [78.19049835, 26.94676971], [78.17373657, 26.94869041], [78.16314697, 26.95269012], [78.15265656, 26.95214081], [78.14608002, 26.95305061], [78.13947296, 26.95713043], [78.13407135, 26.95700836], [78.12706757, 26.9554882], [78.11489868, 26.95486069], [78.11134338, 26.95323181], [78.10804749, 26.9500103], [78.1079483, 26.94831085], [78.10943604, 26.94487953], [78.11305237, 26.94194984], [78.11522675, 26.93819046], [78.11431122, 26.93058014], [78.11270905, 26.92749023], [78.10630798, 26.93001175], [78.10214233, 26.93085289], [78.09866333, 26.93061066], [78.09535217, 26.92905045], [78.09662628, 26.92304039], [78.09908295, 26.92061234], [78.10276031, 26.90993118], [78.10147095, 26.90498924], [78.09861755, 26.90397263], [78.09346008, 26.91008949], [78.09104919, 26.9116497], [78.08830261, 26.90993118], [78.08992004, 26.90574837], [78.0894165, 26.90286255], [78.08682251, 26.90200806], [78.07280731, 26.90755081], [78.06788635, 26.91028023], [78.06291962, 26.91485023], [78.06053925, 26.91590118], [78.05712128, 26.91329956], [78.0524826, 26.91488266], [78.04862976, 26.91377068], [78.04223633, 26.91542053], [78.04522705, 26.90286255], [78.04429626, 26.88453102], [78.04482269, 26.88211823], [78.04772949, 26.8777504], [78.04780579, 26.87480927], [78.04589081, 26.87488174], [78.03965759, 26.87734985], [78.03755951, 26.87696266], [78.03540039, 26.8745594], [78.03114319, 26.86548233], [78.02722168, 26.86218071], [78.02202606, 26.86087036], [78.01761627, 26.86164093], [78.01635742, 26.86381912], [78.02731323, 26.87347984], [78.02793121, 26.87615013], [78.02009583, 26.87961006], [78.01756287, 26.88203049], [78.02207184, 26.89019012], [78.02171326, 26.89479065], [78.01911926, 26.89743996], [78.01629639, 26.90497971], [78.01406097, 26.90839195], [78.00666046, 26.9106617], [77.99838257, 26.90985107], [77.99188995, 26.91090012], [77.98501587, 26.90138054], [77.98027802, 26.89770126], [77.9751358, 26.89752769], [77.97062683, 26.89970016], [77.96675873, 26.90302086], [77.96481323, 26.90724945], [77.96579742, 26.91098022], [77.96295929, 26.91257095], [77.94197083, 26.89978981], [77.93769836, 26.90205002], [77.93474579, 26.9051609], [77.93212891, 26.90999985], [77.92884064, 26.91283989], [77.92189026, 26.91455078], [77.90956879, 26.9142704], [77.9082489, 26.91683006], [77.90925598, 26.92082977], [77.90661621, 26.92395973], [77.89994049, 26.9245491], [77.89692688, 26.92000008], [77.89858246, 26.91542053], [77.90090179, 26.91171265], [77.90284729, 26.90114021], [77.90083313, 26.89513969], [77.89612579, 26.88972092], [77.8901062, 26.88945961], [77.88479614, 26.89232063], [77.88214111, 26.89603996], [77.87677765, 26.89920998], [77.87146759, 26.90550041], [77.84940338, 26.91242027], [77.84104156, 26.91644096], [77.83637238, 26.9195919], [77.82633209, 26.92103958], [77.82132721, 26.92620087], [77.8146286, 26.92279053], [77.80860901, 26.92566109], [77.8052597, 26.9285202], [77.79923248, 26.92825127], [77.79588318, 26.92340088], [77.78885651, 26.92228127], [77.78148651, 26.92770958], [77.77313995, 26.9325695], [77.77348328, 26.93626976], [77.76509857, 26.93799019], [77.75337982, 26.93773842], [77.748703, 26.9269104], [77.74433136, 26.92321014], [77.74064636, 26.92691994], [77.72895813, 26.92580032], [77.72392273, 26.92295074], [77.71891022, 26.91641045], [77.71083832, 26.90302086], [77.71788025, 26.89958954], [77.71987915, 26.89673042], [77.72054291, 26.89301109], [77.719841, 26.88673973], [77.7158432, 26.88133049], [77.70540619, 26.88027954]]]}}, {\\\"id\\\": \\\"32\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.35_1\\\", \\\"HASC_1\\\": \\\"IN.UT\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"Uttarakhand\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Uttarakhand\\\", \\\"apm25_popweighted\\\": 30.1, \\\"dalys_apm25_rate_6cod_mean_total\\\": 681.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 1912.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 2593.0, \\\"geo-id\\\": 32, \\\"hpm25_child_popweighted\\\": 260.0, \\\"hpm25_female_popweighted\\\": 299.0, \\\"hpm25_male_popweighted\\\": 215.0, \\\"location\\\": \\\"Uttarakhand\\\", \\\"mort_apm25_6cod_mean_total\\\": 2770.0, \\\"mort_hpm25_6cod_mean_total\\\": 6237.0, \\\"mort_tpm25_6cod_mean_total\\\": 9007.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"Polygon\\\", \\\"coordinates\\\": [[[80.06291199, 28.88316345], [80.06633759, 28.837286], [80.07238007, 28.82974434], [80.07025146, 28.82963943], [80.07013702, 28.8296833], [80.0696106, 28.8298912], [80.06381226, 28.83189964], [80.0584259, 28.83526039], [80.03408813, 28.80982971], [80.03360748, 28.80546951], [80.03198242, 28.80348969], [80.02568817, 28.79985046], [80.02736664, 28.79737854], [80.0326767, 28.79417992], [80.03623962, 28.79071999], [80.04045868, 28.78310966], [80.03816223, 28.77511978], [80.0345459, 28.76904106], [80.03398132, 28.76638031], [80.03476715, 28.76323128], [80.03344727, 28.76138115], [80.03124237, 28.76055908], [80.02906799, 28.75806046], [80.02297211, 28.74867058], [80.0136261, 28.73736954], [80.00565338, 28.72949982], [80.00286865, 28.72694969], [79.99958038, 28.72564125], [79.98825836, 28.71701813], [79.97483063, 28.7167511], [79.96782684, 28.71562004], [79.95288849, 28.71752167], [79.94087219, 28.72145844], [79.92951965, 28.72651291], [79.92237854, 28.73270988], [79.92233276, 28.73829079], [79.92150879, 28.74500084], [79.91808319, 28.75219917], [79.91172791, 28.75928116], [79.91014099, 28.76333046], [79.91204834, 28.76496124], [79.90571594, 28.77209854], [79.8992691, 28.77386093], [79.89450836, 28.77900124], [79.89209747, 28.78125954], [79.8889389, 28.78577042], [79.8934021, 28.79186249], [79.89813232, 28.79488754], [79.9005661, 28.79940033], [79.90129089, 28.80212021], [79.89480591, 28.80145073], [79.88604736, 28.79881096], [79.88012695, 28.79681969], [79.87307739, 28.79646111], [79.86728668, 28.79644966], [79.85965729, 28.79845047], [79.85336304, 28.80080032], [79.84648895, 28.80496025], [79.8405304, 28.80866051], [79.84332275, 28.81504059], [79.84620667, 28.82130051], [79.84971619, 28.8217411], [79.85423279, 28.82082939], [79.86042023, 28.81791115], [79.87123871, 28.81641006], [79.87563324, 28.8183403], [79.87547302, 28.82128906], [79.87532043, 28.83024025], [79.87101746, 28.83065033], [79.86061096, 28.83413124], [79.85560608, 28.83905983], [79.85468292, 28.84140968], [79.85404968, 28.84428978], [79.8494873, 28.84538078], [79.8441391, 28.84354019], [79.84171295, 28.84260941], [79.83383942, 28.84439087], [79.82965088, 28.84667969], [79.82446289, 28.84478951], [79.82234955, 28.8417511], [79.813797, 28.83171082], [79.81282806, 28.83018112], [79.8157196, 28.82468033], [79.81620789, 28.8217411], [79.81465149, 28.81912041], [79.81503296, 28.81458092], [79.81591034, 28.81225967], [79.81407166, 28.81060982], [79.81128693, 28.81138039], [79.80905151, 28.81075096], [79.80503845, 28.80873108], [79.80419922, 28.80706024], [79.80303955, 28.80558968], [79.8012619, 28.80454063], [79.7947464, 28.80380058], [79.79203033, 28.80303955], [79.78544617, 28.80620956], [79.78336334, 28.80541992], [79.78214264, 28.81319046], [79.78617096, 28.82093048], [79.78940582, 28.81970024], [79.79189301, 28.81517029], [79.79479218, 28.8147316], [79.79704285, 28.81649017], [79.79782104, 28.82081032], [79.79988098, 28.82468987], [79.80119324, 28.82963753], [79.80146027, 28.8332901], [79.79920197, 28.83623123], [79.79367065, 28.8392601], [79.79431152, 28.84303093], [79.798172, 28.84604073], [79.79815674, 28.84803963], [79.79669952, 28.84955025], [79.7946167, 28.8528595], [79.79991913, 28.85427094], [79.80812073, 28.85629082], [79.80901337, 28.85890961], [79.8086319, 28.86283112], [79.80693817, 28.86631012], [79.80574036, 28.86905098], [79.80280304, 28.87182045], [79.79696655, 28.87045097], [79.79485321, 28.86987114], [79.79161835, 28.87039757], [79.79125214, 28.87380981], [79.79064178, 28.87742996], [79.77446747, 28.89183044], [79.76197052, 28.8896904], [79.75977325, 28.88953018], [79.74996948, 28.89335251], [79.748703, 28.89154053], [79.74487305, 28.88978004], [79.74128723, 28.88535118], [79.74044037, 28.88318062], [79.73726654, 28.88259125], [79.73282623, 28.88309097], [79.72836304, 28.88507271], [79.71813202, 28.88275909], [79.71555328, 28.88178062], [79.71218872, 28.88068008], [79.70961761, 28.87920952], [79.70672607, 28.87523842], [79.7056427, 28.8723526], [79.70517731, 28.87022018], [79.70189667, 28.86989975], [79.69705963, 28.87028122], [79.69233704, 28.86832047], [79.68814087, 28.86819077], [79.68643951, 28.86700058], [79.68434143, 28.8573494], [79.67285919, 28.8576107], [79.66709137, 28.85409927], [79.6672821, 28.8500309], [79.66619873, 28.84832954], [79.6594696, 28.84773064], [79.65405273, 28.84873962], [79.64393616, 28.852911], [79.6432724, 28.85322952], [79.64109802, 28.85646248], [79.634552, 28.8584404], [79.63075256, 28.85885811], [79.62399292, 28.86268997], [79.61904144, 28.86758041], [79.61354828, 28.86873055], [79.60868073, 28.86671066], [79.60360718, 28.86470032], [79.59805298, 28.86491966], [79.59226227, 28.86655045], [79.58197021, 28.85584259], [79.57878876, 28.85238266], [79.57655334, 28.85028076], [79.57427979, 28.84930038], [79.57189941, 28.84902], [79.56578827, 28.84946823], [79.56347656, 28.8487606], [79.56233978, 28.84790993], [79.5594101, 28.84670067], [79.55716705, 28.84568977], [79.5535965, 28.84505081], [79.55092621, 28.84589195], [79.54821777, 28.85004997], [79.54767609, 28.85429955], [79.54991913, 28.86016083], [79.55120087, 28.86320114], [79.5512619, 28.86610985], [79.55166626, 28.86824989], [79.55374146, 28.87481117], [79.55397034, 28.87852097], [79.55253601, 28.88153076], [79.55049896, 28.88418007], [79.54332733, 28.89066124], [79.53866577, 28.89241028], [79.53645325, 28.89253998], [79.53308868, 28.89031029], [79.52989197, 28.88689041], [79.52591705, 28.88199806], [79.52259827, 28.87632942], [79.51996613, 28.87329102], [79.51732635, 28.87058067], [79.51406097, 28.86759186], [79.51013184, 28.86470032], [79.5072403, 28.86330032], [79.50248718, 28.86276054], [79.49691772, 28.86239052], [79.49137115, 28.86259842], [79.48654938, 28.86459923], [79.48262787, 28.86622047], [79.47663116, 28.86717033], [79.46776581, 28.86491013], [79.46470642, 28.86275291], [79.46338654, 28.86053085], [79.4597168, 28.85915947], [79.45510864, 28.86005974], [79.44777679, 28.86005974], [79.43976593, 28.86104965], [79.43345642, 28.86164284], [79.43031311, 28.8597908], [79.42752838, 28.85725021], [79.42388916, 28.85523987], [79.41963196, 28.8553009], [79.41712189, 28.85584259], [79.41121674, 28.85588074], [79.4087677, 28.85801125], [79.40621948, 28.86225128], [79.40493774, 28.86745262], [79.4048233, 28.87112999], [79.40429688, 28.87490082], [79.40187836, 28.87728119], [79.3979187, 28.88104057], [79.39565277, 28.88544083], [79.400383, 28.89558983], [79.40114594, 28.89977074], [79.40123749, 28.90186119], [79.40007782, 28.91101074], [79.39900208, 28.9169693], [79.40139771, 28.92136955], [79.40261841, 28.92904091], [79.40143585, 28.93226051], [79.3983078, 28.93515968], [79.39556122, 28.93675041], [79.38942719, 28.93830109], [79.38497925, 28.93731117], [79.37934113, 28.93629074], [79.37702942, 28.93704987], [79.37490082, 28.93939018], [79.37336731, 28.9418602], [79.37252045, 28.94762993], [79.37224579, 28.9511795], [79.3707428, 28.95458031], [79.36897278, 28.95767975], [79.36743164, 28.95994949], [79.36506653, 28.96199036], [79.36338806, 28.96665955], [79.35967255, 28.97047997], [79.3571167, 28.96797943], [79.35507965, 28.96528053], [79.35285187, 28.96123123], [79.35275269, 28.95882034], [79.35389709, 28.95681953], [79.35476685, 28.9534111], [79.35189056, 28.95243073], [79.349617, 28.95210075], [79.34390259, 28.95313072], [79.33763885, 28.95453072], [79.33368683, 28.95498276], [79.32881165, 28.95540047], [79.32095337, 28.9567585], [79.31658936, 28.95679092], [79.31215668, 28.95806122], [79.30718994, 28.95846939], [79.30467987, 28.95393944], [79.30150604, 28.95285034], [79.29892731, 28.95311165], [79.29547882, 28.95429993], [79.28600311, 28.96050262], [79.27887726, 28.96483994], [79.27365112, 28.97287178], [79.27052307, 28.97542953], [79.26846313, 28.97739983], [79.26434326, 28.98213959], [79.25801849, 28.98694992], [79.24996948, 28.99217987], [79.24389648, 28.99648094], [79.23937225, 28.99990082], [79.23774719, 29.00683975], [79.22154236, 29.01729012], [79.21116638, 29.02370071], [79.2040329, 29.02910042], [79.19911194, 29.02527809], [79.19758606, 29.02209091], [79.18296051, 29.02420998], [79.18493652, 29.01801109], [79.17759705, 29.0196209], [79.16858673, 29.0158596], [79.16562653, 29.01729965], [79.16410065, 29.02058983], [79.15827942, 29.02287865], [79.15451813, 29.02741051], [79.15421295, 29.03292084], [79.15866852, 29.03421021], [79.16015625, 29.0433197], [79.1654129, 29.05125809], [79.15345764, 29.05476952], [79.14369965, 29.06009102], [79.13698578, 29.06933975], [79.13471985, 29.08191109], [79.1370163, 29.09090805], [79.14319611, 29.09894943], [79.14398193, 29.1066227], [79.14221954, 29.11972809], [79.13384247, 29.12416077], [79.13080597, 29.1293602], [79.11779022, 29.13388062], [79.11361694, 29.13066292], [79.10853577, 29.13043976], [79.10074615, 29.13167953], [79.09223938, 29.13674164], [79.07286072, 29.15199089], [79.05947876, 29.15626907], [79.05438232, 29.15518188], [79.04612732, 29.15472984], [79.0382309, 29.16629028], [79.03378296, 29.17110062], [79.02696228, 29.17226982], [79.02614594, 29.17196083], [79.02307129, 29.17079163], [79.02175903, 29.16730118], [79.02388, 29.16338921], [79.0275116, 29.16074944], [79.02742004, 29.15588188], [79.02867889, 29.15239906], [79.02639771, 29.14986038], [79.02147675, 29.1508007], [79.01696777, 29.15397072], [79.01335144, 29.15769005], [79.01095581, 29.15722084], [79.01048279, 29.15302849], [79.01278687, 29.14912987], [79.01203918, 29.14487076], [79.00859833, 29.13936234], [79.00875854, 29.13622093], [79.01187134, 29.13471031], [79.01899719, 29.13508987], [79.02352142, 29.13312912], [79.02768707, 29.13296127], [79.03096771, 29.13022995], [79.02970123, 29.12543106], [79.02606964, 29.12154961], [79.02185059, 29.11892128], [79.01700592, 29.11786079], [79.00657654, 29.12051964], [79.0005722, 29.11655045], [78.99838257, 29.12294006], [78.99465942, 29.12537003], [78.9954071, 29.12927055], [78.99262238, 29.13363266], [78.98809814, 29.13512039], [78.98353577, 29.13734818], [78.98262787, 29.1469593], [78.97901154, 29.15475082], [78.97319794, 29.16082001], [78.96662903, 29.16555023], [78.96232605, 29.16681099], [78.96057892, 29.16587067], [78.96035004, 29.16460037], [78.96127319, 29.16317749], [78.9608078, 29.16159821], [78.95610809, 29.16037178], [78.95146942, 29.15970993], [78.94888306, 29.15278053], [78.94438934, 29.14958954], [78.93371582, 29.15420914], [78.92363739, 29.1571312], [78.92077637, 29.15286064], [78.9144516, 29.14898109], [78.90040588, 29.15061951], [78.89834595, 29.15488815], [78.89589691, 29.15579033], [78.89504242, 29.15681076], [78.89961243, 29.16142082], [78.90479279, 29.16316986], [78.90571594, 29.16521072], [78.90332031, 29.16768074], [78.9045105, 29.17057037], [78.90239716, 29.17449951], [78.9057312, 29.17748833], [78.90570068, 29.18033981], [78.90130615, 29.18273926], [78.89911652, 29.19063187], [78.89434814, 29.19589996], [78.89720917, 29.19869041], [78.89916229, 29.20259285], [78.89356232, 29.20483971], [78.88774872, 29.21033287], [78.89225769, 29.21285057], [78.89214325, 29.21487236], [78.89103699, 29.21647263], [78.88687897, 29.21783066], [78.88445282, 29.21951294], [78.88286591, 29.22532082], [78.87014771, 29.22853088], [78.86958313, 29.22953987], [78.87303925, 29.23225975], [78.87359619, 29.23525238], [78.87097931, 29.24073029], [78.86406708, 29.24949265], [78.85787201, 29.25220108], [78.85437775, 29.25542068], [78.85383606, 29.25921059], [78.85262299, 29.26131058], [78.8506012, 29.26222992], [78.84668732, 29.25824928], [78.84519196, 29.25814056], [78.84233093, 29.25428009], [78.83405304, 29.25619125], [78.83319092, 29.25942039], [78.83125305, 29.26073837], [78.82756042, 29.25793076], [78.82289886, 29.25579071], [78.81611633, 29.25382805], [78.81378174, 29.25229073], [78.79988098, 29.25785255], [78.79286957, 29.26260948], [78.78994751, 29.26299095], [78.78736877, 29.26533127], [78.78600311, 29.27301979], [78.78153992, 29.2712307], [78.75863647, 29.28667068], [78.76683044, 29.28590965], [78.76552582, 29.28992081], [78.76107788, 29.29333115], [78.74675751, 29.30270958], [78.73889923, 29.30631065], [78.73139191, 29.31101036], [78.72756195, 29.31278992], [78.72080231, 29.31228065], [78.71385956, 29.31735039], [78.71412659, 29.31933022], [78.71975708, 29.31842041], [78.72110748, 29.31945992], [78.7273407, 29.31748962], [78.72860718, 29.31896019], [78.72592163, 29.32512093], [78.72570801, 29.32998276], [78.7277298, 29.33138084], [78.72834778, 29.33415985], [78.7315979, 29.33431053], [78.73478699, 29.3317585], [78.74150085, 29.33262062], [78.74164581, 29.33588028], [78.74608612, 29.34091949], [78.74704742, 29.34333992], [78.75740814, 29.34976006], [78.76352692, 29.34739113], [78.76532745, 29.34572983], [78.76384735, 29.34320068], [78.76593018, 29.3410511], [78.7696228, 29.34065056], [78.77905273, 29.3422718], [78.78089142, 29.34352112], [78.78246307, 29.34644127], [78.78444672, 29.34292984], [78.78132629, 29.33196068], [78.78884125, 29.32928276], [78.79133606, 29.33499908], [78.79738617, 29.33697128], [78.7979126, 29.33831978], [78.79270172, 29.34342766], [78.79167175, 29.34787941], [78.79012299, 29.35040092], [78.79014587, 29.35211945], [78.79720306, 29.35563087], [78.80684662, 29.37315178], [78.80776978, 29.38027191], [78.80898285, 29.38287926], [78.81160736, 29.38470078], [78.81500244, 29.38533974], [78.81095886, 29.38027954], [78.81176758, 29.37231064], [78.81417847, 29.3700428], [78.8239212, 29.36844063], [78.82881927, 29.36818123], [78.83436584, 29.36967087], [78.83625793, 29.37140846], [78.83580017, 29.37228775], [78.8347168, 29.37434959], [78.83185577, 29.37658119], [78.8325119, 29.38134956], [78.83631134, 29.38143158], [78.84039307, 29.3799305], [78.85679626, 29.3855896], [78.85975647, 29.38767052], [78.86003113, 29.38931084], [78.85888672, 29.39147949], [78.8602066, 29.39388275], [78.86258698, 29.39460945], [78.86599731, 29.39311981], [78.87018585, 29.39236259], [78.87275696, 29.39856911], [78.88279724, 29.40480042], [78.88719177, 29.40899086], [78.89061737, 29.41642952], [78.89647675, 29.42358017], [78.90040588, 29.44668961], [78.90714264, 29.45183182], [78.92292786, 29.45618057], [78.91979218, 29.46014977], [78.90033722, 29.45618057], [78.89601898, 29.45618057], [78.8901062, 29.45754051], [78.8826828, 29.45784187], [78.87542725, 29.4599781], [78.86575317, 29.45960045], [78.84612274, 29.46365166], [78.83006287, 29.46850967], [78.82376862, 29.46969032], [78.81669617, 29.46857071], [78.81138611, 29.46982956], [78.79695129, 29.47595024], [78.7855072, 29.47603035], [78.77474976, 29.48093987], [78.76577759, 29.48378944], [78.74225616, 29.5012207], [78.73905945, 29.50498009], [78.73152161, 29.50574112], [78.72660828, 29.50871086], [78.70826721, 29.50942039], [78.69335938, 29.50887108], [78.68540955, 29.5135498], [78.67655945, 29.52135086], [78.65039063, 29.54068947], [78.63957214, 29.54777908], [78.62149811, 29.55289078], [78.61515808, 29.55787086], [78.6052475, 29.5617981], [78.57647705, 29.58057022], [78.56121063, 29.59373093], [78.53054047, 29.62393188], [78.52735901, 29.62436295], [78.52546692, 29.62977028], [78.51774597, 29.63915062], [78.51151276, 29.65069008], [78.50921631, 29.65965271], [78.50961304, 29.66847992], [78.50763702, 29.6729126], [78.50724792, 29.67696953], [78.50744629, 29.69083023], [78.50601959, 29.69388962], [78.50184631, 29.71170807], [78.5002594, 29.71533966], [78.49021149, 29.72491837], [78.48757935, 29.7413826], [78.47357941, 29.74847031], [78.46473694, 29.75101089], [78.45215607, 29.75213814], [78.43212891, 29.75811958], [78.42431641, 29.76165009], [78.41256714, 29.77242088], [78.40838623, 29.77343941], [78.39842224, 29.77213287], [78.38598633, 29.77386093], [78.35125732, 29.78625107], [78.33853912, 29.7925396], [78.33193207, 29.79611969], [78.33174133, 29.79618073], [78.30293274, 29.75759125], [78.28193665, 29.74234009], [78.26476288, 29.72679138], [78.23139954, 29.70409012], [78.22126007, 29.71762276], [78.19352722, 29.71005821], [78.19229889, 29.70659065], [78.18222046, 29.69155121], [78.1659317, 29.67952919], [78.13912201, 29.67609978], [78.13400269, 29.65851021], [78.11482239, 29.64516068], [78.10913849, 29.63669968], [78.10697937, 29.63318062], [78.09751129, 29.63078117], [78.09683228, 29.63059998], [78.09423828, 29.62803078], [78.09062195, 29.62477112], [78.08867645, 29.61330032], [78.08206177, 29.60181046], [78.07850647, 29.59954262], [78.07315826, 29.59991074], [78.06826019, 29.60141182], [78.05924988, 29.60161018], [78.0506897, 29.59805107], [78.04393005, 29.59307098], [78.03975677, 29.58798027], [78.03650665, 29.58086014], [78.03730011, 29.57776833], [78.0407486, 29.5753212], [78.04264069, 29.57191277], [78.03721619, 29.5652504], [78.03826141, 29.56143951], [78.03688049, 29.55262947], [78.03256226, 29.55170059], [78.01927185, 29.55405045], [78.01661682, 29.55462074], [78.00351715, 29.5560894], [77.99415588, 29.55509949], [77.98802185, 29.54586029], [77.97885895, 29.55413055], [77.97705841, 29.55811119], [77.97675323, 29.56384087], [77.97881317, 29.5681591], [77.9807663, 29.56875992], [77.98404694, 29.57986069], [77.98457336, 29.58455276], [77.98375702, 29.58805084], [77.98232269, 29.58901024], [77.98101044, 29.58781052], [77.97881317, 29.58536911], [77.97704315, 29.58333015], [77.97299957, 29.58333969], [77.97268677, 29.58315086], [77.96955109, 29.58518982], [77.96736145, 29.58572006], [77.96631622, 29.5845108], [77.96337128, 29.58382988], [77.96174622, 29.5860405], [77.95987701, 29.58621025], [77.95598602, 29.58444977], [77.95320892, 29.58472061], [77.95157623, 29.58694077], [77.9498291, 29.58813095], [77.94822693, 29.5903492], [77.94728851, 29.59043121], [77.94832611, 29.59136963], [77.94854736, 29.59342957], [77.94876862, 29.5954895], [77.95092773, 29.59844017], [77.95323181, 29.60241127], [77.95240784, 29.60351944], [77.95101166, 29.60778999], [77.95040131, 29.61096954], [77.9496994, 29.61310959], [77.95186615, 29.61603928], [77.95568848, 29.61679077], [77.95822144, 29.61449051], [77.95986176, 29.61227989], [77.96240234, 29.60999107], [77.96633148, 29.61174965], [77.97025299, 29.61351967], [77.97464752, 29.61108971], [77.97683716, 29.61403847], [77.97541809, 29.61831093], [77.97493744, 29.62249947], [77.97351837, 29.62676239], [77.97312927, 29.63199043], [77.97471619, 29.63809967], [77.97702026, 29.64206123], [77.97537994, 29.64426994], [77.97445679, 29.64435005], [77.97168732, 29.64456749], [77.96750641, 29.64907074], [77.96537781, 29.65547943], [77.96673584, 29.6595211], [77.96788025, 29.66151047], [77.96891785, 29.66246033], [77.96913147, 29.66451073], [77.96936035, 29.66657066], [77.9704895, 29.66856956], [77.97162628, 29.67053986], [77.97277069, 29.67253113], [77.97207642, 29.67465973], [77.97218323, 29.6756897], [77.97126007, 29.67576981], [77.9691925, 29.67385101], [77.9631958, 29.67020035], [77.96228027, 29.67027092], [77.96156311, 29.67240906], [77.95831299, 29.67683029], [77.95668793, 29.67904091], [77.95411682, 29.68133163], [77.95176697, 29.68567085], [77.94727325, 29.68707085], [77.94539642, 29.68723106], [77.94470215, 29.68935966], [77.94377899, 29.68943024], [77.94491577, 29.69143295], [77.94306946, 29.69157982], [77.94328308, 29.69363976], [77.94628143, 29.69546127], [77.94359589, 29.69672966], [77.94114685, 29.70004082], [77.94229126, 29.70203018], [77.9462204, 29.70376968], [77.95198059, 29.70536995], [77.94943237, 29.70766258], [77.94245148, 29.71240044], [77.94081879, 29.71459961], [77.93895721, 29.71475983], [77.93665314, 29.71391106], [77.93049622, 29.71305275], [77.92722321, 29.71458054], [77.92491913, 29.71265984], [77.92015839, 29.71385956], [77.91622925, 29.71165085], [77.91072845, 29.70549011], [77.90962982, 29.7063694], [77.90804291, 29.70528984], [77.9095459, 29.70384026], [77.9083786, 29.70286942], [77.90634918, 29.70409966], [77.90483856, 29.7025528], [77.91020966, 29.69893837], [77.89994049, 29.69782066], [77.88683319, 29.70070076], [77.88218689, 29.70000267], [77.87722778, 29.70038986], [77.87387848, 29.70197105], [77.87003326, 29.69878006], [77.86991119, 29.69400978], [77.8662262, 29.69341087], [77.85851288, 29.68806076], [77.85405731, 29.68890953], [77.84863281, 29.68418121], [77.84706879, 29.68062973], [77.84294128, 29.68130112], [77.8406601, 29.67935944], [77.83843994, 29.67551994], [77.83426666, 29.67188263], [77.82897186, 29.6693306], [77.82129669, 29.66899109], [77.81108093, 29.67248917], [77.80448914, 29.67690086], [77.79251862, 29.68192101], [77.78916931, 29.68588066], [77.7974472, 29.6978302], [77.79492188, 29.70046043], [77.78269196, 29.70832062], [77.76980591, 29.70992088], [77.76203918, 29.71178818], [77.75891113, 29.71342087], [77.75771332, 29.71591949], [77.7637558, 29.72610092], [77.76792145, 29.73056984], [77.76925659, 29.73464966], [77.76735687, 29.73781013], [77.76187134, 29.74382019], [77.76085663, 29.75270081], [77.76165009, 29.75576019], [77.76571655, 29.76371002], [77.76352692, 29.77036095], [77.76539612, 29.77573013], [77.7607193, 29.77877998], [77.76053619, 29.78128052], [77.76470184, 29.78545952], [77.75296021, 29.79743958], [77.74932861, 29.80435944], [77.74214935, 29.80952072], [77.74128723, 29.81141853], [77.74398804, 29.81628036], [77.74234009, 29.82463264], [77.73895264, 29.83027077], [77.73203278, 29.83455086], [77.72918701, 29.83756065], [77.73092651, 29.84190178], [77.73005676, 29.85308075], [77.71334839, 29.85647964], [77.70957947, 29.8594799], [77.7060318, 29.86374092], [77.70326233, 29.86767006], [77.70201874, 29.8717804], [77.70316315, 29.87845039], [77.70250702, 29.88570023], [77.70301819, 29.88975906], [77.71105194, 29.88812065], [77.71302032, 29.89157295], [77.71752167, 29.89463043], [77.72009277, 29.90279007], [77.72483063, 29.90590096], [77.727211, 29.90904236], [77.73111725, 29.91129112], [77.73301697, 29.91348076], [77.72956085, 29.92280006], [77.72879791, 29.92856026], [77.72416687, 29.9300518], [77.71894073, 29.93284035], [77.71768188, 29.93495178], [77.72067261, 29.93902969], [77.72541809, 29.94351959], [77.72898102, 29.94561958], [77.72946167, 29.9518795], [77.7326889, 29.95498085], [77.74014282, 29.95890045], [77.74347687, 29.96377945], [77.74495697, 29.96759987], [77.744133, 29.97186089], [77.73100281, 29.98433113], [77.73007965, 29.98745155], [77.736763, 29.99072075], [77.74080658, 29.99411964], [77.74323273, 30.00596046], [77.74462128, 30.00880241], [77.74642944, 30.01134109], [77.74912262, 30.01410103], [77.75325012, 30.01736069], [77.75756073, 30.01951981], [77.75974274, 30.02042961], [77.76288605, 30.02163124], [77.76779938, 30.02293968], [77.76944733, 30.02384758], [77.7722702, 30.0262928], [77.77353668, 30.02956963], [77.77388763, 30.03210068], [77.77326202, 30.03303909], [77.77255249, 30.03370094], [77.7700882, 30.03688049], [77.76570129, 30.0396595], [77.76389313, 30.04216957], [77.7620163, 30.04318047], [77.75982666, 30.0449295], [77.75820923, 30.04654121], [77.75757599, 30.04823112], [77.75833893, 30.05050087], [77.76148987, 30.05544281], [77.76442719, 30.06088066], [77.76531982, 30.06306076], [77.76793671, 30.06694031], [77.7690506, 30.06809998], [77.76978302, 30.06838036], [77.77189636, 30.07249069], [77.77337646, 30.07386017], [77.77523041, 30.07631111], [77.77585602, 30.07765007], [77.77729797, 30.08240128], [77.77868652, 30.08543968], [77.78005219, 30.08916283], [77.78174591, 30.09086037], [77.78276062, 30.09325981], [77.78513336, 30.09678078], [77.78595734, 30.09910965], [77.78643799, 30.09996986], [77.78956604, 30.10153008], [77.79186249, 30.10185051], [77.79392242, 30.10108757], [77.79503632, 30.10061073], [77.7977066, 30.09885979], [77.79873657, 30.09786034], [77.80101776, 30.09617805], [77.80278015, 30.09456062], [77.80413055, 30.09363937], [77.80548096, 30.09196091], [77.80806732, 30.09020996], [77.81070709, 30.08954811], [77.81307983, 30.08963013], [77.81519318, 30.09016991], [77.81790924, 30.09157944], [77.81996918, 30.09363937], [77.82186127, 30.09694862], [77.82189178, 30.09888077], [77.82395172, 30.10127068], [77.82530975, 30.10473061], [77.82656097, 30.10552025], [77.82842255, 30.10612106], [77.83058167, 30.10724068], [77.83283234, 30.10800934], [77.8360672, 30.10995293], [77.83747864, 30.11143112], [77.83853149, 30.11227036], [77.84274292, 30.11677933], [77.84361267, 30.11831284], [77.84468842, 30.11950111], [77.84723663, 30.12346077], [77.84809875, 30.1245327], [77.85051727, 30.12865829], [77.85233307, 30.13092995], [77.85527039, 30.13362122], [77.8579483, 30.13809967], [77.85909271, 30.14048195], [77.85990143, 30.1415596], [77.8613205, 30.1440506], [77.86444092, 30.14993858], [77.86499786, 30.15209961], [77.86548615, 30.15507126], [77.86871338, 30.15880013], [77.87204742, 30.16303062], [77.87332916, 30.16393089], [77.87664032, 30.16695976], [77.87798309, 30.16860008], [77.8793869, 30.16967964], [77.88793945, 30.17874908], [77.89012146, 30.18037987], [77.89280701, 30.18342972], [77.89599609, 30.18629265], [77.89707184, 30.18822289], [77.89833069, 30.19226074], [77.8989563, 30.19487953], [77.89990997, 30.20401001], [77.90039825, 30.20578003], [77.90229797, 30.20976067], [77.90312958, 30.21306038], [77.90439606, 30.21520805], [77.90762329, 30.21698952], [77.91139221, 30.21877289], [77.91454315, 30.22180939], [77.9180603, 30.22479057], [77.92182159, 30.22970009], [77.923172, 30.23179817], [77.92713165, 30.23641968], [77.92932129, 30.23999023], [77.92977142, 30.24180984], [77.93026733, 30.24300194], [77.93148041, 30.24695969], [77.92823792, 30.24775124], [77.92539978, 30.24871063], [77.92386627, 30.24981117], [77.92189026, 30.2517395], [77.91996765, 30.2540493], [77.91684723, 30.25617027], [77.91362762, 30.25761032], [77.91030121, 30.25931168], [77.90795135, 30.26073074], [77.90363312, 30.26267815], [77.90029907, 30.26440811], [77.89636993, 30.26601028], [77.89164734, 30.26735115], [77.89021301, 30.26823997], [77.88220978, 30.27046967], [77.87985992, 30.27193069], [77.87397003, 30.27415085], [77.87148285, 30.27441978], [77.868927, 30.27210045], [77.86714172, 30.271101], [77.86554718, 30.27048111], [77.86103058, 30.27135086], [77.85788727, 30.27237129], [77.85587311, 30.27393913], [77.85189056, 30.27658272], [77.84755707, 30.27877045], [77.84246826, 30.28033066], [77.84030151, 30.28121185], [77.83629608, 30.28228951], [77.83277893, 30.28378105], [77.8286972, 30.28467941], [77.82405853, 30.28635979], [77.8186264, 30.28918076], [77.81240845, 30.2907505], [77.80905151, 30.29217911], [77.80737305, 30.29362106], [77.80179596, 30.2959919], [77.79930878, 30.29763031], [77.7889328, 30.30365944], [77.78430939, 30.30549049], [77.78320313, 30.30641937], [77.77848053, 30.30929947], [77.7772522, 30.30987167], [77.77301025, 30.3130703], [77.76496124, 30.31736946], [77.76268005, 30.31849098], [77.76069641, 30.31913948], [77.75866699, 30.3200798], [77.75705719, 30.320961], [77.751297, 30.32464981], [77.74828339, 30.32537079], [77.7425766, 30.32760811], [77.74017334, 30.3283329], [77.73771667, 30.32819176], [77.73581696, 30.32925034], [77.73239136, 30.32991028], [77.7297287, 30.33147812], [77.72553253, 30.33291054], [77.72265625, 30.33415031], [77.72088623, 30.33542824], [77.71766663, 30.33609962], [77.71537781, 30.33687973], [77.71308899, 30.33793259], [77.71077728, 30.33876038], [77.70993805, 30.33991051], [77.70773315, 30.34132195], [77.70491791, 30.34387016], [77.70108032, 30.34747124], [77.6977005, 30.35031128], [77.6971283, 30.3516407], [77.69425201, 30.35534286], [77.69341278, 30.35569191], [77.69277954, 30.35724068], [77.69126892, 30.35824013], [77.69064331, 30.35972977], [77.68707275, 30.36457825], [77.68596649, 30.36688042], [77.68434143, 30.36816025], [77.68390656, 30.3696003], [77.68273926, 30.37138939], [77.6802597, 30.37434006], [77.67977142, 30.37560081], [77.67751312, 30.37912941], [77.67700195, 30.38080025], [77.67386627, 30.38459969], [77.6733017, 30.38565063], [77.67183685, 30.38394165], [77.66880035, 30.38352966], [77.66687775, 30.38365936], [77.66581726, 30.38343811], [77.66410828, 30.3839798], [77.66320801, 30.38473129], [77.66348267, 30.38557816], [77.66369629, 30.38751984], [77.66300964, 30.39057159], [77.66243744, 30.39167023], [77.66153717, 30.3926506], [77.66126251, 30.39323044], [77.66034698, 30.39374161], [77.65969086, 30.39393806], [77.65805817, 30.39401054], [77.65529633, 30.39477921], [77.65193176, 30.39550018], [77.64762115, 30.39807129], [77.64569092, 30.40199089], [77.64450836, 30.40257835], [77.643013, 30.40454292], [77.64138031, 30.40536118], [77.63986969, 30.40640068], [77.63941193, 30.40710068], [77.63661957, 30.40920067], [77.63569641, 30.41012192], [77.63421631, 30.41087914], [77.63288116, 30.41117287], [77.63053131, 30.4108696], [77.62552643, 30.4070816], [77.62354279, 30.40516281], [77.62207031, 30.4047699], [77.61818695, 30.40533066], [77.61694336, 30.4052906], [77.61450958, 30.40582085], [77.61122894, 30.40757179], [77.60916138, 30.41040993], [77.60822296, 30.41019249], [77.60707092, 30.40963173], [77.60597229, 30.40948105], [77.60411072, 30.40875053], [77.60273743, 30.40841293], [77.59896851, 30.40891075], [77.59778595, 30.4088707], [77.59246063, 30.40949059], [77.59107208, 30.40904999], [77.58777618, 30.40846252], [77.58699036, 30.40806007], [77.58638763, 30.40801048], [77.58467865, 30.40878105], [77.58436584, 30.40998077], [77.57971191, 30.41192055], [77.57753754, 30.41245842], [77.5749588, 30.41174126], [77.5728302, 30.41033173], [77.57112122, 30.40863991], [77.56958008, 30.40789986], [77.56858826, 30.40682983], [77.56710815, 30.40484047], [77.56305695, 30.40448952], [77.5622406, 30.41006279], [77.56288147, 30.41707993], [77.56790161, 30.4217186], [77.57463074, 30.42651939], [77.58106995, 30.43029976], [77.59041595, 30.43378067], [77.60375214, 30.43744087], [77.61200714, 30.43840027], [77.61672211, 30.43623161], [77.63054657, 30.43615913], [77.63333893, 30.43976974], [77.63568115, 30.44433975], [77.63783264, 30.44948769], [77.6402359, 30.45235062], [77.64665222, 30.45245934], [77.65320587, 30.44954109], [77.66160583, 30.44878006], [77.67906952, 30.45173073], [77.68219757, 30.45769119], [77.69008636, 30.46294022], [77.69918823, 30.4686985], [77.70466614, 30.47340012], [77.71122742, 30.47727013], [77.72144318, 30.47776985], [77.72927856, 30.48233986], [77.73658752, 30.48725128], [77.74752808, 30.49404907], [77.75504303, 30.49832916], [77.76344299, 30.50024986], [77.76761627, 30.5043602], [77.78819275, 30.5060997], [77.79389954, 30.50860023], [77.79917908, 30.51139069], [77.80056, 30.51316071], [77.80197144, 30.51538086], [77.80412292, 30.52037048], [77.80502319, 30.52478027], [77.81064606, 30.53318024], [77.81220245, 30.5380497], [77.80995941, 30.5440197], [77.80680847, 30.5493412], [77.80687714, 30.55426025], [77.80586243, 30.56073952], [77.80323792, 30.56377983], [77.79827118, 30.56413078], [77.7951889, 30.5611496], [77.79058838, 30.56025124], [77.78637695, 30.56139946], [77.77826691, 30.5573597], [77.77459717, 30.55890083], [77.77091217, 30.56240082], [77.7665329, 30.56349945], [77.76184845, 30.56298828], [77.75727081, 30.56558037], [77.75353241, 30.57023048], [77.75187683, 30.57458115], [77.74948883, 30.57996941], [77.74619293, 30.5844326], [77.74362946, 30.58975983], [77.73863983, 30.59287071], [77.73192596, 30.5961895], [77.72952271, 30.59838295], [77.73126984, 30.60152054], [77.73159027, 30.6047802], [77.73210907, 30.60712814], [77.73478699, 30.60816002], [77.73832703, 30.60808945], [77.74246979, 30.6071701], [77.74971008, 30.60136986], [77.75444031, 30.60074997], [77.7572403, 30.60479927], [77.75563049, 30.61619949], [77.75660706, 30.62032127], [77.76132965, 30.61944962], [77.76711273, 30.61818123], [77.7722168, 30.61783028], [77.77864838, 30.61787987], [77.78199005, 30.61935806], [77.77960968, 30.62268066], [77.77645874, 30.62613106], [77.77127838, 30.62848091], [77.77231598, 30.63237953], [77.77545166, 30.63746834], [77.77497864, 30.64112091], [77.77217102, 30.64496994], [77.76830292, 30.65147972], [77.77025604, 30.65514946], [77.7749176, 30.65845108], [77.77905273, 30.66377068], [77.77706146, 30.66558838], [77.77423096, 30.66566086], [77.77220917, 30.66539192], [77.76950073, 30.66419029], [77.76590729, 30.66527939], [77.76294708, 30.66843033], [77.75881195, 30.67238998], [77.75419617, 30.67605972], [77.74788666, 30.67814064], [77.74275208, 30.68056107], [77.7365799, 30.68284988], [77.73340607, 30.68582916], [77.73339844, 30.69350052], [77.73358154, 30.69745255], [77.73574066, 30.70157814], [77.73690033, 30.70500946], [77.74038696, 30.7071228], [77.7410965, 30.71066093], [77.7372818, 30.71346855], [77.73432922, 30.71669006], [77.73227692, 30.72070122], [77.73068237, 30.72447968], [77.7252121, 30.72734833], [77.72219086, 30.73061943], [77.72249603, 30.73335838], [77.72171021, 30.73635292], [77.72033691, 30.7382412], [77.71765137, 30.73886108], [77.71533966, 30.73826027], [77.71289062, 30.73945236], [77.71163177, 30.7420826], [77.70928192, 30.74415016], [77.70723724, 30.74552917], [77.70435333, 30.74570084], [77.700737, 30.74496841], [77.69770813, 30.74496841], [77.69394684, 30.74617004], [77.69158936, 30.74831009], [77.6904068, 30.75132942], [77.6917572, 30.75505066], [77.69300842, 30.75785065], [77.69148254, 30.76025963], [77.68828583, 30.76866913], [77.69265747, 30.77141953], [77.69843292, 30.77342033], [77.70452881, 30.77902031], [77.70864868, 30.78450966], [77.71539307, 30.79421806], [77.71710205, 30.79949951], [77.71806335, 30.80509949], [77.71942139, 30.80830956], [77.72408295, 30.81104088], [77.7265625, 30.8144207], [77.73088837, 30.81939125], [77.73403168, 30.82406807], [77.73744965, 30.82629967], [77.74038696, 30.82766914], [77.74440765, 30.82985115], [77.74407196, 30.83624268], [77.74089813, 30.84015083], [77.73338318, 30.8474884], [77.73146057, 30.85077095], [77.73336792, 30.85420036], [77.73573303, 30.85704994], [77.73958588, 30.86018944], [77.74167633, 30.86420059], [77.74101257, 30.86992073], [77.74085236, 30.87433052], [77.74178314, 30.87828064], [77.74452209, 30.88119125], [77.74774933, 30.88227081], [77.75105286, 30.88272095], [77.75454712, 30.88244057], [77.75820923, 30.88047981], [77.76026917, 30.87784195], [77.76177979, 30.87508965], [77.76278687, 30.86816025], [77.76516724, 30.86517906], [77.76899719, 30.86295128], [77.77359772, 30.86103058], [77.77852631, 30.86000061], [77.78936768, 30.85854912], [77.7889328, 30.86495972], [77.78705597, 30.86812019], [77.78350067, 30.87206078], [77.78362274, 30.87865067], [77.78412628, 30.88215065], [77.78443909, 30.88837051], [77.78543854, 30.89335823], [77.78639984, 30.8960495], [77.79088593, 30.90067101], [77.79463196, 30.90348053], [77.7989502, 30.90879059], [77.80084991, 30.91274071], [77.79741669, 30.91674995], [77.79498291, 30.92043114], [77.79561615, 30.92379951], [77.79337311, 30.92598152], [77.79102325, 30.92613029], [77.78874207, 30.92628098], [77.78185272, 30.92621994], [77.77449036, 30.92533112], [77.7716217, 30.92419052], [77.76725769, 30.92048073], [77.76317596, 30.92015076], [77.75824738, 30.92038155], [77.75219727, 30.92095947], [77.74559784, 30.92230988], [77.74736786, 30.92872047], [77.74649811, 30.9339695], [77.74357605, 30.93522835], [77.73924255, 30.93667984], [77.73665619, 30.9396019], [77.73568726, 30.94202042], [77.73487854, 30.94401169], [77.73327637, 30.94950104], [77.73457336, 30.95956993], [77.73634338, 30.96359062], [77.74196625, 30.96764183], [77.75392151, 30.97684288], [77.76387787, 30.97698975], [77.77094269, 30.97566032], [77.77838135, 30.97232056], [77.78761292, 30.96572113], [77.79659271, 30.95843124], [77.80227661, 30.95510101], [77.80754089, 30.95371056], [77.81260681, 30.95279121], [77.8171463, 30.95356941], [77.81932068, 30.95684052], [77.81891632, 30.96009064], [77.81639099, 30.96198273], [77.81324768, 30.96244812], [77.80462646, 30.96099091], [77.80158234, 30.96356964], [77.79740143, 30.96775818], [77.79641724, 30.96982002], [77.79728699, 30.97295952], [77.79872131, 30.97611809], [77.80319214, 30.97970963], [77.80523682, 30.98163986], [77.80621338, 30.98348045], [77.80648041, 30.98503113], [77.80621338, 30.98806], [77.80754089, 30.99384117], [77.81091309, 30.9953804], [77.81360626, 30.99892044], [77.81028748, 31.00213051], [77.81005096, 31.00521088], [77.82470703, 31.0051899], [77.82533264, 31.00813293], [77.82270813, 31.01180077], [77.81884766, 31.01579094], [77.82106018, 31.02108002], [77.82160187, 31.02992058], [77.81880951, 31.03230095], [77.81511688, 31.03392982], [77.81067657, 31.04359055], [77.80502319, 31.05406952], [77.80491638, 31.05877113], [77.80060577, 31.06208038], [77.8068924, 31.06233025], [77.80960846, 31.06137085], [77.80947876, 31.05973244], [77.81469727, 31.06090164], [77.81954956, 31.06491089], [77.82472992, 31.07443047], [77.8310318, 31.07703972], [77.83746338, 31.07751083], [77.84282684, 31.0812912], [77.85037994, 31.09516907], [77.8501358, 31.10420036], [77.85153198, 31.11096954], [77.85787201, 31.11623955], [77.87275696, 31.12321091], [77.87872314, 31.12467194], [77.87905884, 31.13158989], [77.88040161, 31.13743019], [77.88575745, 31.14307022], [77.88970947, 31.14896965], [77.88748932, 31.15470123], [77.89279175, 31.15726852], [77.9021759, 31.15882111], [77.9094162, 31.15550041], [77.91468811, 31.15657806], [77.93443298, 31.16729164], [77.93921661, 31.16730118], [77.9412384, 31.17116165], [77.94602203, 31.17617035], [77.95475769, 31.1787796], [77.96938324, 31.1651516], [77.97896576, 31.16644096], [77.98522949, 31.16802025], [77.9925766, 31.16703033], [78.00772095, 31.1570797], [78.01423645, 31.15493965], [78.01654816, 31.15850067], [78.01528168, 31.16615105], [78.01622009, 31.1715126], [78.02688599, 31.18019104], [78.029953, 31.18531036], [78.03874969, 31.18715096], [78.03967285, 31.18750954], [78.05383301, 31.19293022], [78.05915833, 31.19236946], [78.07110596, 31.19276047], [78.07549286, 31.19291115], [78.08007813, 31.19070816], [78.08773804, 31.19079971], [78.09237671, 31.19283104], [78.10079193, 31.19979095], [78.10688019, 31.20248985], [78.10984802, 31.2056694], [78.11380005, 31.20623016], [78.11915588, 31.21404076], [78.13490295, 31.21611977], [78.137146, 31.22242165], [78.14360809, 31.22407913], [78.14583588, 31.22688103], [78.14782715, 31.2315712], [78.15313721, 31.23068047], [78.15542603, 31.23028755], [78.16044617, 31.23192024], [78.16308594, 31.23150063], [78.16581726, 31.23106194], [78.17141724, 31.23180962], [78.17648315, 31.23003006], [78.18492126, 31.22332954], [78.18756104, 31.22221947], [78.19284058, 31.22291183], [78.20027161, 31.22571945], [78.20398712, 31.23409081], [78.20681763, 31.2372303], [78.21209717, 31.23855019], [78.21843719, 31.23871994], [78.23258972, 31.23501968], [78.23764801, 31.2397995], [78.23751068, 31.24394035], [78.24263, 31.24336243], [78.24820709, 31.24665833], [78.2497406, 31.25055122], [78.25324249, 31.25287056], [78.25495911, 31.25659943], [78.25814056, 31.26036263], [78.26902008, 31.2713604], [78.27815247, 31.26666069], [78.28845978, 31.26420021], [78.29341888, 31.2660408], [78.29551697, 31.27285957], [78.29680634, 31.2844696], [78.29836273, 31.28820992], [78.30632782, 31.28623962], [78.31693268, 31.28507805], [78.32663727, 31.28824043], [78.33609009, 31.2874794], [78.34247589, 31.28897285], [78.3474884, 31.29011917], [78.35632324, 31.29087067], [78.36335754, 31.2901001], [78.3692627, 31.28790092], [78.37346649, 31.27920914], [78.38136292, 31.28147125], [78.38327026, 31.2743206], [78.38619232, 31.26963043], [78.39308167, 31.2622776], [78.39134979, 31.25299072], [78.3975296, 31.24779129], [78.4050827, 31.24867058], [78.41438293, 31.25090981], [78.41945648, 31.25988007], [78.42706299, 31.25597954], [78.4316864, 31.24959946], [78.44413757, 31.24419975], [78.45722198, 31.22781181], [78.46656799, 31.22093964], [78.46721649, 31.21184921], [78.47010803, 31.20375061], [78.47698212, 31.20510292], [78.48657227, 31.20417023], [78.51413727, 31.20392036], [78.537117, 31.20671082], [78.55024719, 31.21849251], [78.55632782, 31.22738075], [78.56189728, 31.22960091], [78.56658173, 31.23373985], [78.57939911, 31.23500252], [78.58392334, 31.23430061], [78.59536743, 31.23639107], [78.6006012, 31.23585129], [78.61004639, 31.23105049], [78.61329651, 31.22743988], [78.61711121, 31.22524834], [78.62831879, 31.22191811], [78.63445282, 31.2218895], [78.63600159, 31.2195797], [78.63800812, 31.20838928], [78.64549255, 31.20251846], [78.64769745, 31.19466972], [78.65067291, 31.19785118], [78.65983582, 31.20325089], [78.66575623, 31.20247269], [78.67608643, 31.20318985], [78.6955719, 31.19629097], [78.70069885, 31.19639015], [78.70746613, 31.19497108], [78.71302795, 31.1966629], [78.72038269, 31.19701958], [78.74945068, 31.1943512], [78.75759125, 31.1946907], [78.76460266, 31.1959095], [78.77088928, 31.19729996], [78.78881073, 31.20445061], [78.79503632, 31.20503998], [78.8001709, 31.20237923], [78.80316925, 31.19923019], [78.80111694, 31.1939106], [78.7980423, 31.18894958], [78.7975769, 31.18250275], [78.80050659, 31.1782608], [78.81170654, 31.16941071], [78.81021881, 31.16386032], [78.81587219, 31.15393066], [78.81873322, 31.14721107], [78.82472229, 31.14355087], [78.82897949, 31.13633919], [78.83777618, 31.13068962], [78.84432983, 31.12804031], [78.85202026, 31.12621117], [78.86225128, 31.11240959], [78.87139893, 31.10732079], [78.88004303, 31.10383987], [78.88417816, 31.10423279], [78.89074707, 31.1060791], [78.89679718, 31.10563087], [78.89942932, 31.10759926], [78.90058136, 31.11206055], [78.90379333, 31.11547089], [78.90779114, 31.11631966], [78.91265869, 31.11618042], [78.92047119, 31.10758972], [78.93257141, 31.10697937], [78.93752289, 31.10534286], [78.94211578, 31.10502815], [78.95243073, 31.10840988], [78.95582581, 31.1108799], [78.96565247, 31.1153698], [78.98486328, 31.11647034], [78.99079895, 31.11709023], [78.99658203, 31.11533928], [78.99669647, 31.11618042], [78.99669647, 31.11758995], [78.99077606, 31.13087845], [78.98919678, 31.13735962], [78.98706055, 31.14060974], [78.98480988, 31.14093971], [78.97808838, 31.1456604], [78.97579956, 31.15070915], [78.97767639, 31.15483093], [78.97747803, 31.17016029], [78.97466278, 31.17810059], [78.97187042, 31.18237114], [78.96845245, 31.18346977], [78.96615601, 31.18599129], [78.96092224, 31.18643188], [78.95284271, 31.1898098], [78.94621277, 31.19355965], [78.94486237, 31.19693947], [78.94168091, 31.20080185], [78.93585205, 31.20568085], [78.9332428, 31.21455193], [78.93506622, 31.2191906], [78.93512726, 31.22236252], [78.9196167, 31.22309113], [78.91564941, 31.2251606], [78.90991211, 31.23388863], [78.90585327, 31.2501812], [78.90688324, 31.25918961], [78.90891266, 31.25885963], [78.91308594, 31.26072121], [78.91409302, 31.26163101], [78.91459656, 31.26231956], [78.91664886, 31.26662827], [78.91686249, 31.26797295], [78.91673279, 31.27500153], [78.91619873, 31.27655983], [78.91599274, 31.28717041], [78.92354584, 31.30145073], [78.92479706, 31.30668068], [78.92518616, 31.3143692], [78.92310333, 31.32538986], [78.92537689, 31.33176041], [78.92626953, 31.33242989], [78.9302063, 31.33788109], [78.93696594, 31.34247971], [78.95223999, 31.34823036], [78.95366669, 31.34880066], [78.96124268, 31.35203171], [78.96331024, 31.35238647], [78.96827698, 31.35324097], [78.96879578, 31.35301971], [78.9805603, 31.35698128], [78.98967743, 31.36183929], [78.99160767, 31.36403084], [78.99337006, 31.36751175], [78.99310303, 31.37428284], [78.99456787, 31.37927055], [79.00682831, 31.40061951], [79.01183319, 31.40654945], [79.01374817, 31.40859985], [79.01478577, 31.40904999], [79.01544189, 31.41019058], [79.01580811, 31.41109085], [79.02150726, 31.41455078], [79.02720642, 31.4202919], [79.02823639, 31.42073059], [79.02897644, 31.42274094], [79.02964783, 31.42297935], [79.0305481, 31.42399979], [79.0322113, 31.42700195], [79.03314209, 31.42736053], [79.03417206, 31.42801094], [79.03396606, 31.44458008], [79.0355072, 31.45318031], [79.0369873, 31.45737076], [79.03823853, 31.45875931], [79.0405426, 31.46214867], [79.04519653, 31.46812057], [79.04785919, 31.47038269], [79.05210114, 31.47162247], [79.05336761, 31.4720192], [79.05677795, 31.47225952], [79.06028748, 31.46865273], [79.06211853, 31.46759987], [79.06214905, 31.4666996], [79.0634613, 31.46603966], [79.06452179, 31.46513939], [79.06558228, 31.46424294], [79.06611633, 31.46379089], [79.07621002, 31.45825005], [79.08917236, 31.45523834], [79.08966827, 31.4548111], [79.09075165, 31.45438004], [79.09127045, 31.45347023], [79.09394836, 31.45238113], [79.09423065, 31.45170975], [79.10009003, 31.44793129], [79.12255859, 31.44151115], [79.12648773, 31.43978119], [79.12666321, 31.43925095], [79.12886047, 31.43873024], [79.1296463, 31.43807983], [79.13288879, 31.43471909], [79.13345337, 31.43359947], [79.135849, 31.43025017], [79.13640594, 31.43003273], [79.14189148, 31.42002106], [79.14266968, 31.41945076], [79.14370728, 31.41722107], [79.1447525, 31.41609955], [79.14594269, 31.41473961], [79.14692688, 31.41341972], [79.14862061, 31.41114807], [79.15788269, 31.4040699], [79.1582489, 31.40336037], [79.16345215, 31.39891815], [79.17005157, 31.38646126], [79.17092896, 31.38480949], [79.17160034, 31.38418007], [79.17228699, 31.38213921], [79.17418671, 31.37737083], [79.17495728, 31.37693024], [79.17511749, 31.37647057], [79.17565918, 31.37581062], [79.17619324, 31.3751297], [79.17671967, 31.37492943], [79.17756653, 31.37220955], [79.17887878, 31.37133026], [79.17993164, 31.37087822], [79.18183899, 31.3674984], [79.18608093, 31.36374092], [79.18818665, 31.36001015], [79.18968201, 31.35894012], [79.19107056, 31.35796928], [79.19193268, 31.35653114], [79.19312286, 31.35571289], [79.1942215, 31.35495949], [79.19477844, 31.35362244], [79.19816589, 31.35195923], [79.2073822, 31.34632111], [79.21055603, 31.34501076], [79.21128082, 31.34482002], [79.21214294, 31.34456062], [79.21504974, 31.34267807], [79.22164154, 31.33730125], [79.22265625, 31.33484268], [79.22271729, 31.33157921], [79.22142792, 31.3298912], [79.22099304, 31.32925034], [79.22088623, 31.32843971], [79.22054291, 31.32793999], [79.22115326, 31.32586288], [79.22062683, 31.32450104], [79.22083282, 31.32286072], [79.22104645, 31.32028008], [79.22146606, 31.31939125], [79.22306824, 31.31736183], [79.22358704, 31.31692123], [79.2259903, 31.3151207], [79.22601318, 31.31422806], [79.23847961, 31.30421066], [79.24008942, 31.30299187], [79.24063873, 31.30185127], [79.24809265, 31.29661942], [79.24845123, 31.29500008], [79.24901581, 31.29454041], [79.24951935, 31.28961945], [79.24772644, 31.28534126], [79.24642944, 31.283741], [79.24578094, 31.28321075], [79.23710632, 31.27574921], [79.2338028, 31.2691803], [79.23342133, 31.26618958], [79.23287201, 31.26194191], [79.23388672, 31.25403976], [79.23734283, 31.25068092], [79.24333954, 31.24693108], [79.24563599, 31.2466507], [79.24743652, 31.24690056], [79.25147247, 31.24654961], [79.25280762, 31.24609947], [79.2546463, 31.24635124], [79.25518799, 31.24658012], [79.26277924, 31.24529076], [79.26445007, 31.24394035], [79.2651825, 31.24259949], [79.26628876, 31.23945999], [79.26683044, 31.23924065], [79.26737976, 31.23743057], [79.2678833, 31.23720932], [79.26863098, 31.23661041], [79.27111053, 31.23181915], [79.27217102, 31.23159981], [79.27229309, 31.23093987], [79.27281952, 31.23073959], [79.27664948, 31.22282982], [79.27719116, 31.22261047], [79.27877808, 31.21749115], [79.28629303, 31.19990158], [79.28843689, 31.19563293], [79.28814697, 31.18952751], [79.28778076, 31.18840027], [79.28494263, 31.18567085], [79.28304291, 31.18157959], [79.28211975, 31.18091011], [79.28212738, 31.17930984], [79.28270721, 31.17548943], [79.28318024, 31.17436028], [79.28489685, 31.17010117], [79.28569031, 31.16966057], [79.28676605, 31.1687603], [79.28942871, 31.16426277], [79.2918396, 31.16249084], [79.29374695, 31.15909958], [79.29611206, 31.15710068], [79.29728699, 31.15418053], [79.29780579, 31.15395927], [79.29962158, 31.14924049], [79.30761719, 31.14210129], [79.30869293, 31.1405201], [79.30869293, 31.14006042], [79.31156158, 31.13918114], [79.31275177, 31.13915062], [79.3143158, 31.13894081], [79.31790161, 31.13879013], [79.31891632, 31.13902092], [79.32132721, 31.13747025], [79.32184601, 31.13589096], [79.32263947, 31.13544083], [79.32316589, 31.13521004], [79.32509613, 31.12981033], [79.32614899, 31.12939072], [79.33059692, 31.12873077], [79.3379364, 31.12927055], [79.34082031, 31.12882996], [79.34187317, 31.12861252], [79.3447876, 31.12749863], [79.34635925, 31.1264019], [79.34996796, 31.12405014], [79.35038757, 31.1237812], [79.35389709, 31.12177277], [79.35559845, 31.12129021], [79.36061859, 31.12018013], [79.36192322, 31.12066078], [79.36994934, 31.12041092], [79.37709808, 31.12079048], [79.37889099, 31.12041473], [79.37918854, 31.12034988], [79.3818512, 31.11835098], [79.38408661, 31.11231041], [79.38511658, 31.11000061], [79.38588715, 31.10958099], [79.38639832, 31.1093502], [79.38709259, 31.10754013], [79.38967896, 31.0987606], [79.39124298, 31.08243942], [79.39169312, 31.08118057], [79.39235687, 31.0798111], [79.39469147, 31.07963181], [79.39966583, 31.0803299], [79.40042114, 31.08009911], [79.40174103, 31.0798912], [79.40624237, 31.07698822], [79.40734863, 31.07338905], [79.40788269, 31.07316971], [79.40840912, 31.07295036], [79.40842438, 31.07254219], [79.40846252, 31.07134247], [79.40888214, 31.05649185], [79.40975952, 31.05236053], [79.41136169, 31.04730988], [79.41308594, 31.03755188], [79.42175293, 31.03582954], [79.42471313, 31.0363121], [79.43322754, 31.03771019], [79.45729828, 31.03950119], [79.46109772, 31.0403595], [79.46589661, 31.04137039], [79.47200012, 31.04026031], [79.47981262, 31.03807068], [79.48735809, 31.04105949], [79.4936676, 31.04087257], [79.49706268, 31.04136276], [79.50125885, 31.0391407], [79.50209045, 31.03800011], [79.50287628, 31.03757286], [79.50279236, 31.03051758], [79.50276184, 31.02763939], [79.50403595, 31.02584076], [79.50457764, 31.02561188], [79.5045929, 31.02491951], [79.50488281, 31.0238018], [79.50538635, 31.02357101], [79.50540161, 31.02312279], [79.50775909, 31.02179909], [79.50776672, 31.02135086], [79.50830841, 31.02089119], [79.50895691, 31.02081108], [79.50940704, 31.02053642], [79.51098633, 31.01958084], [79.51463318, 31.01721954], [79.51631927, 31.01622963], [79.51709747, 31.01486969], [79.51779175, 31.014431], [79.51860809, 31.01398087], [79.51860809, 31.01351166], [79.52033997, 31.0105896], [79.52137756, 31.00992966], [79.52192688, 31.00835037], [79.52246857, 31.00812149], [79.52266693, 31.00452042], [79.52078247, 30.99901581], [79.5194931, 30.99524117], [79.51938629, 30.99344063], [79.52307129, 30.99255943], [79.52753448, 30.99214554], [79.53134155, 30.99179077], [79.53613281, 30.99218941], [79.5377121, 30.99130058], [79.53752136, 30.98703957], [79.53546143, 30.98540688], [79.53520203, 30.98520279], [79.53325653, 30.98338127], [79.53131866, 30.97789001], [79.53096008, 30.97591019], [79.5311203, 30.97410011], [79.53298187, 30.97322083], [79.5329895, 30.97276115], [79.53430939, 30.97187042], [79.53431702, 30.97141075], [79.53536224, 30.9698391], [79.5358963, 30.96985245], [79.54062653, 30.96717072], [79.54141998, 30.96652031], [79.54142761, 30.96604919], [79.54168701, 30.96536255], [79.54338837, 30.96442986], [79.54393005, 30.96443939], [79.54738617, 30.96260262], [79.5484314, 30.96203041], [79.5501709, 30.96108055], [79.55045319, 30.96042061], [79.55123138, 30.96043015], [79.55361176, 30.95885849], [79.55957794, 30.95671844], [79.57572937, 30.95438957], [79.57688904, 30.95363998], [79.58058929, 30.95029068], [79.58059692, 30.94983292], [79.58139801, 30.94940186], [79.58139801, 30.94894028], [79.58244324, 30.94828033], [79.58285522, 30.94724655], [79.58352661, 30.94556046], [79.58481598, 30.94399071], [79.58724213, 30.94309044], [79.58957672, 30.94288826], [79.59031677, 30.94324493], [79.59243011, 30.94425964], [79.59384918, 30.94631004], [79.5943222, 30.94790077], [79.59654999, 30.94918633], [79.59895325, 30.95056915], [79.60360718, 30.95268059], [79.60591888, 30.95451164], [79.60617828, 30.95543289], [79.60679626, 30.95656013], [79.6078186, 30.95679092], [79.61575317, 30.96179962], [79.62423706, 30.96533012], [79.63033295, 30.96636963], [79.64261627, 30.96760941], [79.64940643, 30.97059059], [79.65003967, 30.97171974], [79.64982605, 30.97985077], [79.65045929, 30.98054123], [79.65159607, 30.98436165], [79.65394592, 30.9857502], [79.66256714, 30.98693085], [79.67124176, 30.98425102], [79.6932373, 30.98167992], [79.69373322, 30.98191071], [79.69638062, 30.98168945], [79.69687653, 30.98180962], [79.70477295, 30.98339081], [79.71411133, 30.98565102], [79.72479248, 30.99088097], [79.72609711, 30.99204063], [79.72646332, 30.99362946], [79.72695923, 30.99521255], [79.72775269, 30.99545097], [79.72918701, 30.9963398], [79.72930145, 30.99724007], [79.73221588, 31.00156975], [79.7325058, 31.00199127], [79.73420715, 31.00291061], [79.73459625, 31.00358009], [79.73808289, 31.0060997], [79.74214935, 31.00679016], [79.74559021, 31.0061512], [79.7505722, 31.00119019], [79.75139618, 30.99893188], [79.76032257, 30.99311829], [79.77855682, 30.98826027], [79.78452301, 30.98666954], [79.78553009, 30.98641014], [79.7923584, 30.98423958], [79.80499268, 30.97776985], [79.80941772, 30.97733116], [79.81072998, 30.97756004], [79.81606293, 30.97929001], [79.81807709, 30.9801712], [79.8216095, 30.98204613], [79.8234787, 30.98304176], [79.83030701, 30.98398018], [79.84104919, 30.9808712], [79.8467865, 30.98135948], [79.85202789, 30.98023987], [79.85492706, 30.97891045], [79.85597229, 30.97735023], [79.85626221, 30.97665024], [79.85756683, 30.97575951], [79.85864258, 30.97507095], [79.85968781, 30.97125053], [79.86075592, 30.97037125], [79.86155701, 30.96990967], [79.86157227, 30.96920967], [79.86206818, 30.96899033], [79.86380005, 30.96606064], [79.8645401, 30.96439171], [79.86532593, 30.96178055], [79.8659668, 30.96120071], [79.86688995, 30.95838165], [79.86875153, 30.95275116], [79.86929321, 30.95253944], [79.87007904, 30.94983292], [79.87065887, 30.94942093], [79.87120056, 30.94919014], [79.87358856, 30.9410305], [79.87464142, 30.93879128], [79.87471008, 30.9304409], [79.87525177, 30.93021011], [79.8765564, 30.92930031], [79.87761688, 30.9263916], [79.87998962, 30.92527962], [79.8809967, 30.92510986], [79.88154602, 30.9250927], [79.89253235, 30.9235096], [79.89411163, 30.92329979], [79.89753723, 30.92174911], [79.89937592, 30.91809845], [79.90203094, 30.91566086], [79.90310669, 30.91180992], [79.90603638, 30.90957069], [79.90677643, 30.90727997], [79.90812683, 30.90325165], [79.91078186, 30.90056038], [79.91131592, 30.89920998], [79.91159058, 30.89874077], [79.91504669, 30.89221954], [79.92108917, 30.89086914], [79.93435669, 30.89298058], [79.93965912, 30.89190102], [79.94164276, 30.8920002], [79.94348145, 30.89159012], [79.94403839, 30.89142036], [79.94642639, 30.89030075], [79.95980835, 30.88558006], [79.96749878, 30.88231468], [79.96757507, 30.88228226], [79.96764374, 30.88223839], [79.98065948, 30.87394905], [79.980896, 30.87335014], [79.98757935, 30.87000084], [79.99153137, 30.86878014], [79.99471283, 30.86737823], [79.99649811, 30.86631966], [79.99916077, 30.86431122], [80.00123596, 30.86250114], [80.00152588, 30.86182022], [80.00279236, 30.86117935], [80.00332642, 30.86071968], [80.00361633, 30.86004066], [80.00836182, 30.85618973], [80.00945282, 30.8539505], [80.01782227, 30.84787941], [80.01808167, 30.84651756], [80.02490997, 30.8438282], [80.02777863, 30.84338951], [80.02906799, 30.84361076], [80.0297699, 30.84381104], [80.03824615, 30.84296036], [80.04265594, 30.84389114], [80.04411316, 30.84399986], [80.04660797, 30.84073257], [80.0477066, 30.83940125], [80.04823303, 30.83895111], [80.04846954, 30.83839035], [80.05033112, 30.83283043], [80.06420898, 30.82454109], [80.06420898, 30.82407951], [80.06463623, 30.82369041], [80.06465912, 30.82323074], [80.06648254, 30.82211113], [80.06948853, 30.81933975], [80.06965637, 30.81792068], [80.07038116, 30.81228065], [80.07161713, 30.80904007], [80.0740509, 30.79972076], [80.08306122, 30.79528999], [80.08331299, 30.79459953], [80.08487701, 30.7933197], [80.086586, 30.79186058], [80.0879364, 30.79071236], [80.08795929, 30.79026031], [80.10108185, 30.78150749], [80.10135651, 30.7808876], [80.10314941, 30.77967072], [80.10787201, 30.77901077], [80.11308289, 30.78084946], [80.11869812, 30.78633118], [80.12036133, 30.78742027], [80.12243652, 30.79101944], [80.12526703, 30.79351044], [80.1260376, 30.79394913], [80.13751984, 30.79603958], [80.13831329, 30.79670906], [80.13870239, 30.79804993], [80.1377182, 30.80552101], [80.1386261, 30.81002808], [80.13951111, 30.81115913], [80.14472198, 30.81319046], [80.14784241, 30.81342125], [80.15673828, 30.81254005], [80.15727234, 30.81275177], [80.15937042, 30.81208992], [80.16353607, 30.80997086], [80.1674881, 30.80715942], [80.16829681, 30.80554962], [80.16855621, 30.80512047], [80.16958618, 30.80330086], [80.17090607, 30.80241013], [80.17089844, 30.80195808], [80.17221069, 30.80105019], [80.17301941, 30.80060005], [80.17405701, 30.79836082], [80.17457581, 30.7981205], [80.17617798, 30.79541969], [80.17700195, 30.79481125], [80.1783371, 30.79352951], [80.18115234, 30.78932953], [80.18405914, 30.7870903], [80.1848526, 30.78663063], [80.18524933, 30.78549957], [80.18540955, 30.78032112], [80.18492126, 30.77465057], [80.18595886, 30.77036095], [80.18647003, 30.77015114], [80.18860626, 30.76675987], [80.18942261, 30.76630974], [80.19011688, 30.76490974], [80.19045258, 30.76381111], [80.19542694, 30.76111031], [80.19727325, 30.76000023], [80.20720673, 30.75753021], [80.20797729, 30.75776291], [80.21079254, 30.76408005], [80.2127533, 30.76566124], [80.21476746, 30.76645088], [80.21726227, 30.76699066], [80.2178421, 30.76704979], [80.22097778, 30.76593018], [80.22177887, 30.76501083], [80.22281647, 30.76523018], [80.22306824, 30.76455116], [80.22383881, 30.76409912], [80.22543335, 30.76095009], [80.22616577, 30.76036072], [80.22699738, 30.75844955], [80.22753143, 30.7582283], [80.22807312, 30.7580204], [80.22834778, 30.75663757], [80.22953033, 30.75370979], [80.23002625, 30.75349998], [80.23223877, 30.7487812], [80.23298645, 30.74819946], [80.23426056, 30.74558067], [80.23500061, 30.7449894], [80.23726654, 30.74065971], [80.23729706, 30.73769951], [80.2368927, 30.73656273], [80.23264313, 30.72956085], [80.23085785, 30.72257042], [80.22538757, 30.71759033], [80.22357178, 30.71465111], [80.2212677, 30.70453072], [80.22090149, 30.70113945], [80.22006989, 30.70055008], [80.21977234, 30.69725037], [80.21717834, 30.6952095], [80.20987701, 30.69135857], [80.20909119, 30.69155121], [80.19896698, 30.69013023], [80.19715118, 30.68949127], [80.19335938, 30.68772125], [80.19333649, 30.68684959], [80.19285583, 30.68638039], [80.19271851, 30.68592072], [80.18554688, 30.6823082], [80.18284607, 30.67959976], [80.18210602, 30.67811012], [80.18121338, 30.67481995], [80.18049622, 30.66986084], [80.1831665, 30.66534996], [80.1884079, 30.66220093], [80.1884079, 30.66130066], [80.19732666, 30.65675163], [80.20041656, 30.65546036], [80.20095062, 30.65500069], [80.20095062, 30.65388107], [80.20316315, 30.65221024], [80.20316315, 30.65176964], [80.20643616, 30.64891052], [80.20844269, 30.64530945], [80.20896149, 30.64508247], [80.2093811, 30.64145088], [80.20781708, 30.63673019], [80.20568848, 30.63455009], [80.20292664, 30.63061905], [80.19921875, 30.62754059], [80.19869232, 30.62663078], [80.19851685, 30.62314034], [80.19905853, 30.61932945], [80.19956207, 30.61886978], [80.20585632, 30.61639977], [80.20925903, 30.6157093], [80.2106781, 30.61557961], [80.21131897, 30.61548805], [80.21131897, 30.61503029], [80.21209717, 30.61457062], [80.21253204, 30.61345291], [80.21228027, 30.60893822], [80.21189117, 30.60782814], [80.20643616, 30.60238075], [80.20594025, 30.60124969], [80.20597076, 30.59740067], [80.20922852, 30.58753777], [80.21096039, 30.58230019], [80.21476746, 30.5798912], [80.21573639, 30.57904053], [80.22123718, 30.57632828], [80.22144318, 30.57578087], [80.22437286, 30.57496262], [80.22982025, 30.57261276], [80.23214722, 30.57102966], [80.23242188, 30.56945038], [80.2339859, 30.56855011], [80.23425293, 30.56787109], [80.23709106, 30.5662384], [80.23864746, 30.56566048], [80.24022675, 30.56540108], [80.2440567, 30.56677055], [80.24606323, 30.56749153], [80.24780273, 30.56858063], [80.24977112, 30.57252121], [80.25076294, 30.5734539], [80.25112152, 30.5737896], [80.25222015, 30.57492065], [80.25318146, 30.57515907], [80.25467682, 30.57518005], [80.25537109, 30.57518005], [80.25644684, 30.57481956], [80.25701141, 30.57422066], [80.25662231, 30.57106018], [80.25663757, 30.57093048], [80.25689697, 30.56836128], [80.25784302, 30.56796837], [80.25802612, 30.56740952], [80.26055145, 30.56653976], [80.26106262, 30.56744957], [80.26209259, 30.56792068], [80.26235199, 30.56880951], [80.26242065, 30.56964111], [80.26246643, 30.57016945], [80.26355743, 30.57112122], [80.26761627, 30.57376099], [80.2722168, 30.57406044], [80.27799988, 30.57448006], [80.2806015, 30.57390022], [80.28125, 30.57368088], [80.28199005, 30.57333946], [80.28356934, 30.57245064], [80.28412628, 30.57201958], [80.28591919, 30.57181931], [80.28672791, 30.57172966], [80.2893219, 30.57100105], [80.29242706, 30.56998062], [80.29367065, 30.5694809], [80.29456329, 30.56933975], [80.29524231, 30.56962967], [80.29676056, 30.56978035], [80.2977829, 30.56971169], [80.29885101, 30.56974983], [80.29885101, 30.56884956], [80.30145264, 30.56839943], [80.30220795, 30.5680809], [80.30560303, 30.56750107], [80.30716705, 30.56682014], [80.30761719, 30.56602097], [80.30735016, 30.56488037], [80.30895233, 30.5633297], [80.30895996, 30.56287193], [80.30918884, 30.5625782], [80.31137848, 30.55981827], [80.31191254, 30.55960846], [80.31269073, 30.55735016], [80.31347656, 30.55689049], [80.31424713, 30.5564518], [80.31558228, 30.55397034], [80.31996918, 30.55120277], [80.32833862, 30.54675102], [80.33348846, 30.54477119], [80.3377533, 30.54313087], [80.34059143, 30.54134941], [80.34140778, 30.54029274], [80.3455658, 30.53786278], [80.36517334, 30.52869034], [80.36663055, 30.52783775], [80.36828613, 30.52687073], [80.38131714, 30.52350998], [80.38195038, 30.52396774], [80.38370514, 30.52523041], [80.38754272, 30.52799034], [80.39142609, 30.52981949], [80.40055084, 30.53116989], [80.40222931, 30.53045845], [80.40273285, 30.52933121], [80.40629578, 30.5264492], [80.40805817, 30.52216148], [80.40946198, 30.5187397], [80.41256714, 30.51581955], [80.41335297, 30.5151329], [80.41559601, 30.51131058], [80.41623688, 30.51062965], [80.41676331, 30.51016998], [80.42354584, 30.5056591], [80.44805908, 30.49637032], [80.45688629, 30.49389076], [80.465065, 30.49303627], [80.47164154, 30.49234962], [80.47354889, 30.49204063], [80.4751358, 30.49185944], [80.48529816, 30.49048042], [80.48646545, 30.49012566], [80.48970795, 30.48913956], [80.49297333, 30.48679543], [80.49415588, 30.48595047], [80.49415588, 30.48483086], [80.49494934, 30.48460007], [80.49546051, 30.48347092], [80.49701691, 30.48188972], [80.49781799, 30.48143005], [80.49832916, 30.47986984], [80.49884796, 30.47964096], [80.50432587, 30.47036171], [80.50511169, 30.46992111], [80.50565338, 30.46876907], [80.50955963, 30.4654007], [80.5116806, 30.46330833], [80.51216888, 30.46292114], [80.51358795, 30.46133041], [80.51425934, 30.46063995], [80.51970673, 30.45749092], [80.5199585, 30.45658112], [80.52398682, 30.45542908], [80.52648926, 30.45430946], [80.52803802, 30.45521927], [80.52919769, 30.45929909], [80.5298233, 30.46006966], [80.53058624, 30.46108818], [80.53317261, 30.46251869], [80.53505707, 30.4635601], [80.53505707, 30.46401978], [80.53949738, 30.46467972], [80.5423584, 30.46385765], [80.54315948, 30.46362686], [80.54415131, 30.46334076], [80.55171967, 30.46465111], [80.55560303, 30.46716118], [80.55766296, 30.47033119], [80.56005859, 30.47402191], [80.56117249, 30.4757309], [80.5641861, 30.48321152], [80.56636047, 30.48860168], [80.56873322, 30.48929024], [80.56960297, 30.48940086], [80.57666016, 30.48971176], [80.579422, 30.48879814], [80.58419037, 30.48722267], [80.59355927, 30.48223114], [80.5951767, 30.48119926], [80.62306976, 30.4634285], [80.62873077, 30.45981979], [80.63105774, 30.45756912], [80.63368225, 30.4554882], [80.63366699, 30.4546299], [80.63683319, 30.45235062], [80.63681793, 30.45189095], [80.63743591, 30.45103073], [80.63820648, 30.45041275], [80.64350128, 30.44750977], [80.64473724, 30.44706917], [80.64663696, 30.44625092], [80.6472168, 30.44601059], [80.64904022, 30.44532013], [80.65059662, 30.4457798], [80.65345001, 30.44531059], [80.66073608, 30.44576073], [80.66594696, 30.44338989], [80.66638184, 30.44311714], [80.6672287, 30.44259262], [80.66728973, 30.4424305], [80.66777039, 30.44119835], [80.66932678, 30.44053078], [80.67012787, 30.43984032], [80.67514038, 30.43630409], [80.67690277, 30.43506241], [80.67690277, 30.43463326], [80.67690277, 30.43420029], [80.67860413, 30.43302155], [80.68000031, 30.43205452], [80.69980621, 30.41834259], [80.70294952, 30.4166851], [80.70717621, 30.41445732], [80.71962738, 30.40789986], [80.73129272, 30.40221977], [80.73451233, 30.40010071], [80.73748779, 30.39813995], [80.74532318, 30.39157104], [80.74556732, 30.39089012], [80.74919891, 30.38793945], [80.74919891, 30.38747025], [80.75154114, 30.38546181], [80.75231934, 30.38408279], [80.75576782, 30.37996101], [80.7567215, 30.37931252], [80.75737762, 30.37701035], [80.75846863, 30.37590981], [80.75936127, 30.37527084], [80.76403809, 30.36552048], [80.76451874, 30.36530113], [80.76635742, 30.36121941], [80.76685333, 30.36100006], [80.76711273, 30.35987091], [80.76817322, 30.35897064], [80.76869965, 30.35874939], [80.77243805, 30.3481102], [80.77387238, 30.34562111], [80.7743988, 30.34542084], [80.77600098, 30.34316063], [80.78221893, 30.33839035], [80.7824707, 30.33774948], [80.79374695, 30.3302803], [80.81128693, 30.31998062], [80.81804657, 30.31678963], [80.82073975, 30.31574059], [80.82688904, 30.31348038], [80.84580231, 30.30722809], [80.85354614, 30.30597115], [80.86499023, 30.30412102], [80.86580658, 30.30397987], [80.87049103, 30.30284119], [80.88349152, 30.29961967], [80.89646912, 30.29393005], [80.90542603, 30.29112053], [80.91673279, 30.2879715], [80.92058563, 30.28730583], [80.9299469, 30.2856884], [80.93063354, 30.28561974], [80.93424988, 30.28524971], [80.93447876, 30.28523636], [80.93640137, 30.28512955], [80.94059753, 30.2844696], [80.94225311, 30.28403091], [80.947258, 30.28256035], [80.96734619, 30.27577019], [80.97252655, 30.27440071], [80.97608185, 30.27360153], [80.97831726, 30.2730999], [80.9940567, 30.27046013], [80.99829102, 30.26854134], [81.00790405, 30.26418686], [81.0109787, 30.26279068], [81.0120697, 30.26197815], [81.01509094, 30.25962067], [81.01586151, 30.25906944], [81.01714325, 30.25747108], [81.01906586, 30.25317955], [81.01960754, 30.25295258], [81.01999664, 30.25068283], [81.01994324, 30.25014114], [81.01887512, 30.23683739], [81.01421356, 30.2395153], [81.00721741, 30.24061584], [81.00003052, 30.24507523], [80.99046326, 30.24681664], [80.98391724, 30.24391556], [80.97888184, 30.23896027], [80.9779129, 30.23799324], [80.96125793, 30.23761559], [80.93740082, 30.23476219], [80.92921448, 30.23591614], [80.92298126, 30.23165512], [80.92191315, 30.22928047], [80.92134094, 30.22806168], [80.91742706, 30.22460556], [80.91191864, 30.2232151], [80.90931702, 30.22111511], [80.90598297, 30.21673775], [80.90411377, 30.21421623], [80.90120697, 30.21313095], [80.89901733, 30.21225548], [80.89591217, 30.20622063], [80.88572693, 30.19440842], [80.88721466, 30.18831444], [80.88182068, 30.18131447], [80.87303925, 30.17583084], [80.86991882, 30.17573166], [80.86457062, 30.16889572], [80.86531067, 30.16790962], [80.86856842, 30.16666985], [80.8686676, 30.16663361], [80.87311554, 30.16091537], [80.87261963, 30.1532402], [80.87522888, 30.14432144], [80.87787628, 30.1410656], [80.87791443, 30.13661575], [80.88048553, 30.13249779], [80.87921906, 30.12851524], [80.87575531, 30.12627029], [80.86972046, 30.12540817], [80.86431885, 30.12091446], [80.85674286, 30.12030602], [80.85639954, 30.11962318], [80.85599518, 30.11881447], [80.84671021, 30.11606216], [80.84359741, 30.11052895], [80.84658813, 30.10782242], [80.84791565, 30.10661507], [80.84705353, 30.10228539], [80.83921814, 30.09771538], [80.83176422, 30.09719086], [80.83071136, 30.09749985], [80.82965088, 30.09781265], [80.82803345, 30.10004807], [80.82499695, 30.09988403], [80.82344055, 30.09980011], [80.82123566, 30.09710312], [80.81721497, 30.09631538], [80.81574249, 30.09296417], [80.81175232, 30.09142113], [80.80802917, 30.08998299], [80.80341339, 30.08561516], [80.80119324, 30.08090973], [80.79671478, 30.07781601], [80.79348755, 30.07357788], [80.79258728, 30.07333755], [80.79091644, 30.06931496], [80.78226471, 30.05801964], [80.78143311, 30.05692673], [80.77783203, 30.05431557], [80.76731873, 30.05191612], [80.76467896, 30.05047607], [80.76293182, 30.04949188], [80.76060486, 30.04440689], [80.76105499, 30.04350471], [80.75741577, 30.03941536], [80.75733948, 30.03108978], [80.75991821, 30.02761459], [80.75930023, 30.02388763], [80.75611877, 30.02061462], [80.75323486, 30.01255798], [80.74939728, 30.00662994], [80.73981476, 29.99951553], [80.72129059, 30.00037766], [80.71411896, 29.9902153], [80.7062149, 29.98571587], [80.70226288, 29.98002815], [80.69881439, 29.97951508], [80.69184875, 29.97413826], [80.6853714, 29.96695137], [80.6838913, 29.96252251], [80.67791748, 29.95811462], [80.67311859, 29.95739174], [80.65815735, 29.95512199], [80.65032196, 29.95589066], [80.64138031, 29.96124077], [80.63802338, 29.96359634], [80.63332367, 29.96476555], [80.6315155, 29.96521568], [80.62994385, 29.96499062], [80.62310791, 29.96396828], [80.61595154, 29.96061325], [80.61305237, 29.95923233], [80.60533905, 29.95871735], [80.59215546, 29.94844437], [80.58097839, 29.93252754], [80.5799942, 29.92822075], [80.57603455, 29.92343712], [80.57281494, 29.91511536], [80.57141113, 29.90904045], [80.57314301, 29.90112114], [80.57402039, 29.89450073], [80.57431793, 29.89442635], [80.56768036, 29.87921524], [80.55860901, 29.8706398], [80.55891418, 29.86961555], [80.55923462, 29.86852646], [80.5632782, 29.86644173], [80.5610199, 29.86470985], [80.55649567, 29.86206436], [80.55631256, 29.86081696], [80.55612946, 29.85957909], [80.55313873, 29.85635185], [80.55522919, 29.85299683], [80.55401611, 29.85000992], [80.55451202, 29.84923744], [80.55028534, 29.8501339], [80.54541779, 29.84631538], [80.54062653, 29.84714699], [80.53761292, 29.83870125], [80.53291321, 29.83821487], [80.52991486, 29.83361626], [80.52555084, 29.83212662], [80.52571869, 29.82911491], [80.52415466, 29.82768631], [80.52344513, 29.82701874], [80.50902557, 29.82304192], [80.50679016, 29.81931496], [80.50294495, 29.8174305], [80.49921417, 29.81101608], [80.50170898, 29.8088913], [80.5019455, 29.80875206], [80.49723816, 29.80478859], [80.49659729, 29.80216408], [80.49562073, 29.80210686], [80.49720001, 29.79746628], [80.49411774, 29.79531479], [80.48451996, 29.79641533], [80.48131561, 29.79570198], [80.47821808, 29.79791451], [80.46561432, 29.80231476], [80.45596313, 29.80241585], [80.44957733, 29.79910278], [80.44921875, 29.79891586], [80.44303894, 29.80042458], [80.43959045, 29.80384254], [80.43771362, 29.80571556], [80.4365921, 29.80449295], [80.43061829, 29.79801559], [80.41947937, 29.79603004], [80.41768646, 29.79570198], [80.41482544, 29.79185104], [80.41375732, 29.79185104], [80.41365051, 29.79185104], [80.41259003, 29.79185104], [80.408638, 29.79444504], [80.40936279, 29.79160118], [80.40848541, 29.78977394], [80.40789032, 29.78849792], [80.40885925, 29.78402138], [80.4054184, 29.78181076], [80.40641785, 29.77841568], [80.40163422, 29.77380943], [80.39792633, 29.76314354], [80.39929199, 29.7592907], [80.39811707, 29.75861549], [80.39755249, 29.75829697], [80.39271545, 29.76041603], [80.39126587, 29.75994873], [80.38687134, 29.75853157], [80.38725281, 29.75358963], [80.38748932, 29.75051308], [80.37401581, 29.7491188], [80.36972046, 29.75061607], [80.36933899, 29.75001526], [80.36701202, 29.746418], [80.36585999, 29.74015236], [80.37133026, 29.73443604], [80.36785126, 29.72995949], [80.36772919, 29.72491455], [80.37021637, 29.72161484], [80.37480927, 29.72163582], [80.37704468, 29.72026825], [80.37704468, 29.71921539], [80.37704468, 29.71815491], [80.37372589, 29.7153244], [80.37382507, 29.71516991], [80.37617493, 29.71281242], [80.37606049, 29.71159935], [80.37611389, 29.71151543], [80.3788147, 29.70251465], [80.38161469, 29.70101547], [80.38215637, 29.68860435], [80.38621521, 29.68581581], [80.38587189, 29.68161964], [80.38500214, 29.67901039], [80.38601685, 29.6750145], [80.39183807, 29.67105675], [80.39118958, 29.66792488], [80.39112091, 29.66744804], [80.39221954, 29.66450119], [80.40041351, 29.66260529], [80.4006958, 29.66220093], [80.40103149, 29.66173553], [80.40039825, 29.66095734], [80.39990234, 29.65920258], [80.40041351, 29.65862846], [80.40824127, 29.65962219], [80.41170502, 29.65364647], [80.41594696, 29.65415573], [80.41698456, 29.65276527], [80.41819, 29.65116692], [80.4163208, 29.64831543], [80.41571808, 29.64431572], [80.41757202, 29.64161491], [80.42192078, 29.63911438], [80.42116547, 29.63402176], [80.42195892, 29.63212967], [80.42281342, 29.63021469], [80.41991425, 29.62641525], [80.4127121, 29.62532425], [80.41024017, 29.62150192], [80.40982819, 29.61513519], [80.4074173, 29.61281586], [80.40971375, 29.6098156], [80.41061401, 29.60491562], [80.40949249, 29.5949192], [80.40937042, 29.59477234], [80.40488434, 29.58953285], [80.39322662, 29.58157349], [80.39191437, 29.57461548], [80.38999176, 29.57203484], [80.3808136, 29.57151413], [80.38059998, 29.56420708], [80.38051605, 29.56131554], [80.36536407, 29.5640564], [80.36469269, 29.56282806], [80.36399841, 29.56157112], [80.36569977, 29.5567112], [80.36571503, 29.55661583], [80.35891724, 29.55511475], [80.35057831, 29.55535698], [80.34759521, 29.55416489], [80.34435272, 29.55286407], [80.34734344, 29.54864693], [80.34341431, 29.54161453], [80.34775543, 29.54097557], [80.3483429, 29.54106522], [80.34913635, 29.54077148], [80.34965515, 29.54058075], [80.35070038, 29.54019547], [80.35391998, 29.53631592], [80.35903168, 29.53373337], [80.35939789, 29.5328083], [80.35977173, 29.53186989], [80.3584137, 29.52952766], [80.35012817, 29.52352524], [80.3509903, 29.52019882], [80.35132599, 29.51894569], [80.34423828, 29.51099205], [80.34212494, 29.50987244], [80.33842468, 29.51189423], [80.33666229, 29.51285553], [80.335289, 29.5127964], [80.33258057, 29.50822449], [80.33253479, 29.50814438], [80.33044434, 29.50527573], [80.32966614, 29.50495148], [80.31503296, 29.49782372], [80.31453705, 29.49657631], [80.31608582, 29.49277496], [80.31614685, 29.49262619], [80.31516266, 29.48476982], [80.31143188, 29.48526764], [80.30583954, 29.48613739], [80.3028183, 29.48925209], [80.30156708, 29.49055672], [80.30141449, 29.49054718], [80.29793549, 29.48816681], [80.29776001, 29.48800087], [80.2977829, 29.48762894], [80.29801178, 29.48340225], [80.29477692, 29.47892952], [80.28843689, 29.47722054], [80.28968048, 29.4719696], [80.29534912, 29.46432877], [80.29824066, 29.46043205], [80.30285645, 29.45705605], [80.30447388, 29.45444679], [80.30437469, 29.45390701], [80.30435181, 29.4537735], [80.30422211, 29.45307922], [80.29976654, 29.45102692], [80.2993927, 29.45085335], [80.29751587, 29.45361519], [80.29451752, 29.45321465], [80.29005432, 29.45009804], [80.28890228, 29.45088959], [80.28248596, 29.45100212], [80.28220367, 29.45100784], [80.28063202, 29.45394135], [80.28168488, 29.4563446], [80.2822113, 29.45751762], [80.27713013, 29.45842361], [80.27096558, 29.45509338], [80.27571869, 29.45260811], [80.27663422, 29.45096779], [80.27601624, 29.44947624], [80.27141571, 29.45071983], [80.26855469, 29.44848251], [80.26599121, 29.44947243], [80.25983429, 29.45180321], [80.25868225, 29.45001793], [80.25740051, 29.44802666], [80.25225067, 29.44732857], [80.24771118, 29.44674683], [80.24481964, 29.44450569], [80.24473572, 29.44113159], [80.24745941, 29.43839264], [80.24904633, 29.4368], [80.24900055, 29.43241882], [80.24568939, 29.42350388], [80.24769592, 29.41603851], [80.24334717, 29.41158676], [80.24609375, 29.40890121], [80.24768066, 29.40735054], [80.24778748, 29.40730667], [80.25563049, 29.4039917], [80.25687408, 29.4031601], [80.26582336, 29.39715767], [80.27053833, 29.39565659], [80.27129364, 29.39541626], [80.27402496, 29.39492035], [80.2769165, 29.39221573], [80.27462006, 29.38621521], [80.28060913, 29.37888908], [80.27427673, 29.37503624], [80.27281952, 29.37321663], [80.27336121, 29.37122345], [80.27340698, 29.37105942], [80.27290344, 29.36372757], [80.2808075, 29.35989952], [80.28104401, 29.35048485], [80.28110504, 29.3476162], [80.28508759, 29.34185791], [80.29217529, 29.33661079], [80.2929306, 29.33018875], [80.2930603, 29.33003998], [80.29862976, 29.3237114], [80.30404663, 29.32302094], [80.31130981, 29.32209587], [80.31813812, 29.3156395], [80.31864166, 29.31339645], [80.31764984, 29.30821037], [80.32012939, 29.30382729], [80.31989288, 29.3027668], [80.31963348, 29.30158997], [80.3130188, 29.29151535], [80.30783081, 29.28891373], [80.30596161, 29.28531075], [80.30571747, 29.2729454], [80.30571747, 29.27275848], [80.30332947, 29.26456451], [80.30111694, 29.26171494], [80.30175781, 29.25556946], [80.30186462, 29.25498772], [80.3002243, 29.24964905], [80.30198669, 29.24541855], [80.30199432, 29.24203873], [80.29241943, 29.23187256], [80.2925415, 29.22976112], [80.29728699, 29.22219467], [80.29776001, 29.22143364], [80.29679108, 29.21764183], [80.29639435, 29.21609116], [80.29580688, 29.21074295], [80.2990036, 29.20503044], [80.29529572, 29.19762421], [80.2913208, 29.19521523], [80.28620148, 29.19682693], [80.28337097, 29.2007618], [80.28269958, 29.2016964], [80.27663422, 29.2070179], [80.27490997, 29.20697403], [80.26248932, 29.20666122], [80.25950623, 29.21075058], [80.25906372, 29.2141552], [80.25861359, 29.21783066], [80.2543869, 29.22143364], [80.25036621, 29.2206955], [80.24991608, 29.22061539], [80.24881744, 29.21531487], [80.2461853, 29.21236229], [80.24436188, 29.2079277], [80.24259186, 29.20372391], [80.24241638, 29.20331573], [80.24359894, 29.20044327], [80.24930573, 29.197052], [80.2518158, 29.19561577], [80.25962067, 29.18741608], [80.26231384, 29.17471504], [80.26011658, 29.17051506], [80.26000977, 29.16576004], [80.26729584, 29.1534481], [80.27440643, 29.1447506], [80.27340698, 29.14202309], [80.27079773, 29.14053154], [80.26098633, 29.1398983], [80.25574493, 29.1378994], [80.25054932, 29.1289978], [80.2480545, 29.12698555], [80.24694061, 29.12705421], [80.23970032, 29.12121964], [80.23931885, 29.12091446], [80.23501587, 29.11841583], [80.21138763, 29.12176704], [80.20754242, 29.12499809], [80.20738983, 29.12527275], [80.20518494, 29.12929726], [80.19715881, 29.13140678], [80.19598389, 29.13170815], [80.18927765, 29.1354847], [80.1860199, 29.13731575], [80.18519592, 29.13671112], [80.18320465, 29.13533211], [80.17984009, 29.12850571], [80.17662048, 29.12671471], [80.16950989, 29.12574387], [80.16553497, 29.11692047], [80.15992737, 29.11291885], [80.14602661, 29.10300064], [80.13143158, 29.06446266], [80.13011932, 29.06099701], [80.13040161, 29.06092262], [80.13821411, 29.05891609], [80.12814331, 29.03170776], [80.13297272, 29.03042603], [80.12936401, 29.02106667], [80.1277771, 29.01695633], [80.12625885, 29.0130024], [80.13794708, 29.00954819], [80.13762665, 29.00841141], [80.13732147, 29.00731087], [80.12877655, 29.00598526], [80.12851715, 29.00591469], [80.11955261, 28.98171043], [80.10973358, 28.98431969], [80.10190582, 28.98643303], [80.09771729, 28.97521591], [80.06713867, 28.92731667], [80.06014252, 28.91631699], [80.06291199, 28.88316345]]]}}, {\\\"id\\\": \\\"33\\\", \\\"type\\\": \\\"Feature\\\", \\\"properties\\\": {\\\"CC_1\\\": null, \\\"ENGTYPE_1\\\": \\\"State\\\", \\\"GID_0\\\": \\\"IND\\\", \\\"GID_1\\\": \\\"IND.36_1\\\", \\\"HASC_1\\\": \\\"IN.WB\\\", \\\"NAME_0\\\": \\\"India\\\", \\\"NAME_1\\\": \\\"West Bengal\\\", \\\"NL_NAME_1\\\": null, \\\"TYPE_1\\\": \\\"State\\\", \\\"VARNAME_1\\\": \\\"Bangla|Bengala Occidentale|Bengala Ocidental|Bengale occidental\\\", \\\"apm25_popweighted\\\": 63.4, \\\"dalys_apm25_rate_6cod_mean_total\\\": 1044.0, \\\"dalys_hpm25_rate_6cod_mean_total\\\": 2032.0, \\\"dalys_tpm25_rate_6cod_mean_total\\\": 3076.0, \\\"geo-id\\\": 33, \\\"hpm25_child_popweighted\\\": 258.1, \\\"hpm25_female_popweighted\\\": 296.8, \\\"hpm25_male_popweighted\\\": 213.4, \\\"location\\\": \\\"West Bengal\\\", \\\"mort_apm25_6cod_mean_total\\\": 28523.0, \\\"mort_hpm25_6cod_mean_total\\\": 58389.0, \\\"mort_tpm25_6cod_mean_total\\\": 86912.0, \\\"scenario\\\": \\\"BASELINE\\\"}, \\\"geometry\\\": {\\\"type\\\": \\\"MultiPolygon\\\", \\\"coordinates\\\": [[[[88.01860809, 21.5727787], [88.01889038, 21.57250023], [88.01944733, 21.57250023], [88.01972198, 21.5722084], [88.02055359, 21.57222176], [88.02138519, 21.57138824], [88.02139282, 21.57110977], [88.02111053, 21.57083321], [88.02111053, 21.57055473], [88.02138519, 21.57027817], [88.02139282, 21.56944084], [88.02166748, 21.56916618], [88.02166748, 21.56888962], [88.02139282, 21.56861115], [88.02138519, 21.56833267], [88.02166748, 21.56805611], [88.02166748, 21.56777954], [88.02054596, 21.56666946], [88.02027893, 21.56666756], [88.01972198, 21.56722069], [88.01972198, 21.56750107], [88.01944733, 21.56777954], [88.01944733, 21.56805611], [88.01916504, 21.56833267], [88.01917267, 21.56861115], [88.01860809, 21.56916618], [88.01860809, 21.56944466], [88.01832581, 21.56972122], [88.01833344, 21.57027817], [88.01777649, 21.57083321], [88.01777649, 21.57111168], [88.01667023, 21.5722084], [88.01693726, 21.57250023], [88.01693726, 21.57278252], [88.01721954, 21.57305527], [88.01693726, 21.57333183], [88.01693726, 21.57361031], [88.01638794, 21.57417107], [88.01638794, 21.5755558], [88.01611328, 21.57583046], [88.01611328, 21.57639122], [88.01583099, 21.57666588], [88.01583099, 21.57694244], [88.01555634, 21.57722092], [88.01555634, 21.57749939], [88.01521301, 21.57784462], [88.01499939, 21.57806015], [88.01499939, 21.57833481], [88.01470947, 21.57860947], [88.01470947, 21.57999992], [88.01499939, 21.5802784], [88.01499939, 21.58083344], [88.01565552, 21.58149147], [88.01583099, 21.58167076], [88.01638794, 21.58111], [88.01638794, 21.58083344], [88.01638794, 21.58055687], [88.01667023, 21.5802803], [88.01667023, 21.57888985], [88.01693726, 21.57860947], [88.01694489, 21.57722473], [88.01721954, 21.57694244], [88.01721954, 21.57666588], [88.01776886, 21.57611084], [88.01776886, 21.57557106], [88.01805878, 21.57528114], [88.01805878, 21.57444191], [88.01833344, 21.57416725], [88.01832581, 21.57361031], [88.01860809, 21.57333183], [88.01860809, 21.5727787]]], [[[88.17778015, 21.60111046], [88.17778015, 21.60083008], [88.17805481, 21.60083389], [88.1783371, 21.60055542], [88.1783371, 21.59972191], [88.17778015, 21.59916687], [88.17778015, 21.59804916], [88.1783371, 21.59749985], [88.1783371, 21.59721756], [88.17888641, 21.59666634], [88.1783371, 21.59610939], [88.17805481, 21.5961113], [88.17749786, 21.59555626], [88.17749786, 21.59527969], [88.17778015, 21.59500122], [88.17778015, 21.59444046], [88.17805481, 21.59416771], [88.17804718, 21.59305954], [88.17778015, 21.59278107], [88.17778015, 21.59222031], [88.1783371, 21.59166527], [88.1783371, 21.59139061], [88.17973328, 21.59000015], [88.17972565, 21.58916664], [88.17944336, 21.58889008], [88.17973328, 21.58889008], [88.18055725, 21.58805275], [88.18055725, 21.58749962], [88.18222046, 21.58583069], [88.18222046, 21.58555603], [88.18360901, 21.58416939], [88.18499756, 21.58416748], [88.18527985, 21.58444405], [88.18583679, 21.58444405], [88.18611145, 21.58416748], [88.18640137, 21.58416939], [88.18694305, 21.58361053], [88.1875, 21.58361053], [88.18776703, 21.58332825], [88.18777466, 21.5830555], [88.18888855, 21.5819397], [88.18888855, 21.58166885], [88.18888855, 21.58138084], [88.18861389, 21.58111191], [88.1883316, 21.58111191], [88.18805695, 21.58083344], [88.18805695, 21.58055687], [88.18776703, 21.5802803], [88.18776703, 21.57971954], [88.18722534, 21.57916451], [88.18611145, 21.57917023], [88.18694305, 21.57834053], [88.18694305, 21.57806015], [88.1866684, 21.57777977], [88.1866684, 21.57722092], [88.18638611, 21.57694244], [88.18638611, 21.57479286], [88.18638611, 21.57305527], [88.18611145, 21.57278252], [88.18611145, 21.57110977], [88.18583679, 21.57083321], [88.18583679, 21.56805611], [88.1866684, 21.56722069], [88.1866684, 21.56694412], [88.18694305, 21.56666756], [88.18694305, 21.56583023], [88.1866684, 21.56555748], [88.1866684, 21.56500053], [88.18723297, 21.56443977], [88.18722534, 21.56416512], [88.1875, 21.56389046], [88.18805695, 21.56389046], [88.1883316, 21.56417084], [88.18861389, 21.56416512], [88.18888855, 21.56444359], [88.18888855, 21.56416512], [88.18860626, 21.56389046], [88.18860626, 21.56334114], [88.18888855, 21.56306076], [88.18860626, 21.56278038], [88.18805695, 21.56278038], [88.18777466, 21.56249809], [88.1875, 21.56222153], [88.1875, 21.56083107], [88.1866684, 21.55999947], [88.18416595, 21.55999947], [88.1838913, 21.5597229], [88.18360901, 21.5597229], [88.18334198, 21.55999947], [88.1827774, 21.55999947], [88.18250275, 21.56027794], [88.18222046, 21.56027031], [88.1819458, 21.56056023], [88.18026733, 21.56056023], [88.17888641, 21.56194305], [88.17888641, 21.56221962], [88.1783371, 21.56278038], [88.1783371, 21.56306076], [88.17720795, 21.56417084], [88.17694092, 21.56416512], [88.17666626, 21.56444359], [88.17666626, 21.56472206], [88.17610931, 21.56472206], [88.17500305, 21.56583023], [88.17500305, 21.56611061], [88.17444611, 21.56666756], [88.17446136, 21.56722069], [88.17414856, 21.56750107], [88.17414856, 21.56777954], [88.17388916, 21.56805611], [88.17388916, 21.56833076], [88.17360687, 21.56861115], [88.17360687, 21.56888962], [88.17388916, 21.56916618], [88.17388916, 21.56944466], [88.17414856, 21.56972122], [88.17414856, 21.57027817], [88.17305756, 21.57139015], [88.17305756, 21.57167244], [88.1727829, 21.57195282], [88.17277527, 21.5727787], [88.17222595, 21.57333183], [88.17222595, 21.57361031], [88.17193604, 21.57389069], [88.17193604, 21.57500076], [88.17166901, 21.57527733], [88.17166901, 21.57583237], [88.17138672, 21.57611084], [88.17140198, 21.57860947], [88.17111206, 21.57888985], [88.17111206, 21.58166885], [88.17082977, 21.5819397], [88.17082977, 21.5830555], [88.17111206, 21.58332825], [88.17111206, 21.58527946], [88.17140198, 21.58556175], [88.17082977, 21.58556175], [88.16971588, 21.58667183], [88.16972351, 21.58777809], [88.16889191, 21.5886097], [88.16889191, 21.58889008], [88.16916656, 21.58917046], [88.16916656, 21.58944321], [88.16889191, 21.58971977], [88.16889191, 21.59057045], [88.16860962, 21.59057045], [88.16805267, 21.59111023], [88.16805267, 21.59139061], [88.16777802, 21.59166527], [88.16777802, 21.59181023], [88.16777802, 21.59250069], [88.16805267, 21.59278107], [88.16805267, 21.59389114], [88.16777802, 21.59416771], [88.16777802, 21.5961113], [88.16805267, 21.59638977], [88.16805267, 21.59694481], [88.16832733, 21.59721756], [88.16833496, 21.59749985], [88.16889191, 21.59805489], [88.16889191, 21.59833145], [88.16944122, 21.5988903], [88.16944122, 21.59945107], [88.16999817, 21.60000038], [88.17028046, 21.60000038], [88.17056274, 21.60028267], [88.17082977, 21.60028267], [88.17111206, 21.60056114], [88.17138672, 21.60055542], [88.17166901, 21.60083389], [88.17250061, 21.60083389], [88.17277527, 21.60111046], [88.17333221, 21.60111046], [88.17360687, 21.60083008], [88.17472076, 21.60083389], [88.17500305, 21.60055542], [88.17610931, 21.60055542], [88.1763916, 21.60083389], [88.17694092, 21.60083008], [88.17720795, 21.60111046], [88.17778015, 21.60111046]]], [[[88.83472443, 21.6072216], [88.83499908, 21.60694695], [88.83528137, 21.60695076], [88.83638, 21.60583115], [88.83750153, 21.60583305], [88.83777618, 21.60555649], [88.83805847, 21.60555649], [88.83833313, 21.60527611], [88.83833313, 21.60472107], [88.83889008, 21.60416412], [88.8391571, 21.60416985], [88.83944702, 21.60388947], [88.83999634, 21.60388947], [88.84055328, 21.60333061], [88.84055328, 21.60305405], [88.8408432, 21.60277939], [88.8408432, 21.60222054], [88.84111023, 21.60194206], [88.84111023, 21.6016674], [88.84139252, 21.60167122], [88.84194183, 21.60111046], [88.84306335, 21.60111046], [88.84333038, 21.60083389], [88.84416962, 21.60083389], [88.84471893, 21.60027695], [88.84527588, 21.60028267], [88.84583282, 21.59972191], [88.84610748, 21.59972191], [88.84638977, 21.59944534], [88.84666443, 21.59944534], [88.84694672, 21.59972191], [88.84777832, 21.59972191], [88.84805298, 21.59944534], [88.84860992, 21.59945107], [88.84889221, 21.59917259], [88.85083008, 21.59917259], [88.85111237, 21.5988903], [88.85333252, 21.5988903], [88.85360718, 21.59861183], [88.85500336, 21.59861183], [88.85527802, 21.59833336], [88.85639191, 21.59833336], [88.85666656, 21.59861183], [88.85694122, 21.59861183], [88.85722351, 21.59833336], [88.85832977, 21.59833336], [88.85916901, 21.59749985], [88.85943604, 21.59749985], [88.86000061, 21.59693909], [88.86027527, 21.59694481], [88.86055756, 21.59666634], [88.86110687, 21.59666824], [88.86138916, 21.59638023], [88.86277771, 21.59638977], [88.86305237, 21.5961113], [88.86528015, 21.5961113], [88.8658371, 21.59555626], [88.86611176, 21.59555817], [88.86638641, 21.59527969], [88.86667633, 21.59527969], [88.86694336, 21.59500122], [88.86776733, 21.59500122], [88.86805725, 21.59472084], [88.86893463, 21.59476662], [88.86915588, 21.59500122], [88.8694458, 21.59500122], [88.86972046, 21.59527969], [88.87000275, 21.59527969], [88.8702774, 21.59555817], [88.87055206, 21.59527969], [88.87055206, 21.59500122], [88.87082672, 21.59472084], [88.8713913, 21.59472275], [88.87166595, 21.59444427], [88.87194824, 21.59444427], [88.8722229, 21.59416771], [88.87277985, 21.59416962], [88.87304688, 21.59389114], [88.87333679, 21.59389114], [88.87388611, 21.59332085], [88.8741684, 21.5933342], [88.87444305, 21.59305763], [88.87473297, 21.59305954], [88.875, 21.59278107], [88.87526703, 21.59278107], [88.8758316, 21.59222031], [88.87611389, 21.59222221], [88.87722015, 21.59111023], [88.87722015, 21.59028053], [88.8777771, 21.58971977], [88.8777771, 21.58944321], [88.87832642, 21.58889008], [88.87832642, 21.58805275], [88.87944794, 21.58694458], [88.87999725, 21.58638954], [88.88054657, 21.58667183], [88.88083649, 21.58638954], [88.8813858, 21.58638954], [88.88194275, 21.58583069], [88.88277435, 21.5858326], [88.88277435, 21.58527756], [88.88360596, 21.58443832], [88.88361359, 21.58416748], [88.88388824, 21.58389091], [88.88388824, 21.58361053], [88.8841629, 21.58332825], [88.8841629, 21.5830555], [88.88471985, 21.58305931], [88.88555908, 21.58221817], [88.88583374, 21.58222198], [88.8861084, 21.58194351], [88.88694763, 21.58194351], [88.88722229, 21.58166885], [88.88833618, 21.58167076], [88.88833618, 21.58138084], [88.89027405, 21.58111191], [88.89027405, 21.57916451], [88.89055634, 21.57888985], [88.89111328, 21.57888794], [88.89167023, 21.57944679], [88.89250183, 21.57944679], [88.89360809, 21.57833481], [88.89362335, 21.57806015], [88.89417267, 21.57749939], [88.89416504, 21.57722473], [88.89444733, 21.57694244], [88.89444733, 21.57638931], [88.89472198, 21.57611084], [88.89472198, 21.57583046], [88.89527893, 21.57527733], [88.89527893, 21.57500076], [88.89639282, 21.57389069], [88.89665985, 21.57389069], [88.89665985, 21.57333183], [88.89694214, 21.57305527], [88.89694214, 21.57123947], [88.89694214, 21.57111168], [88.89778137, 21.57027817], [88.89778137, 21.56999969], [88.89816284, 21.56961823], [88.89916992, 21.56861115], [88.89916992, 21.56833076], [88.90000153, 21.56749916], [88.90000153, 21.56722069], [88.90055847, 21.56666756], [88.90055847, 21.5664196], [88.90083313, 21.56611061], [88.90083313, 21.56555939], [88.90110779, 21.56528091], [88.90110779, 21.56472015], [88.90166473, 21.56416512], [88.9016571, 21.56361008], [88.90249634, 21.56277847], [88.90249634, 21.5625], [88.90270233, 21.5622921], [88.90305328, 21.56194305], [88.90305328, 21.5616703], [88.9033432, 21.56138992], [88.9033432, 21.56083107], [88.90361023, 21.56055641], [88.90361023, 21.56027031], [88.90389252, 21.55999947], [88.90389252, 21.55943871], [88.90416718, 21.55916595], [88.90416718, 21.55855179], [88.90416718, 21.55805588], [88.90389252, 21.55777931], [88.90389252, 21.55750084], [88.90361023, 21.55721092], [88.90361023, 21.55583382], [88.90000153, 21.5522213], [88.89916992, 21.5522213], [88.89888763, 21.55194664], [88.89861298, 21.55194664], [88.89833069, 21.55166435], [88.89805603, 21.55167007], [88.89778137, 21.55140114], [88.89749908, 21.55140114], [88.8972168, 21.55111122], [88.89694214, 21.55111122], [88.89665985, 21.55083084], [88.89638519, 21.55083275], [88.89611053, 21.55055428], [88.89554596, 21.55056], [88.89527893, 21.55027962], [88.89389038, 21.55027962], [88.89362335, 21.55000114], [88.89250183, 21.55000114], [88.89221954, 21.54972076], [88.88999939, 21.54972076], [88.8897171, 21.55000114], [88.88944244, 21.55000114], [88.88916779, 21.55027962], [88.88749695, 21.55027962], [88.88722229, 21.55000114], [88.88694763, 21.55000114], [88.88667297, 21.54972076], [88.88471985, 21.54972458], [88.88444519, 21.54944229], [88.88305664, 21.54944229], [88.88277435, 21.54972458], [88.88168335, 21.54972076], [88.8813858, 21.55000114], [88.8797226, 21.55000114], [88.87958527, 21.54986382], [88.87944794, 21.54972076], [88.87805176, 21.54972458], [88.8777771, 21.54944229], [88.8769455, 21.54944229], [88.87666321, 21.54916573], [88.87555695, 21.54916954], [88.87526703, 21.54889107], [88.87444305, 21.54889107], [88.8741684, 21.54916954], [88.8722229, 21.54916573], [88.87194824, 21.54944229], [88.8686142, 21.54944229], [88.86833191, 21.54972458], [88.86805725, 21.54972458], [88.86777496, 21.54944229], [88.86694336, 21.54944229], [88.8666687, 21.54972458], [88.86638641, 21.54972076], [88.86611176, 21.55000114], [88.8638916, 21.55000114], [88.86361694, 21.54972076], [88.86305237, 21.54972076], [88.86277771, 21.55000114], [88.86250305, 21.55000114], [88.86222076, 21.55027962], [88.86083221, 21.55027962], [88.86054993, 21.55000114], [88.86000061, 21.55000114], [88.86000061, 21.55111122], [88.85943604, 21.55167007], [88.85888672, 21.55167007], [88.85778046, 21.55056], [88.85610962, 21.55056], [88.85582733, 21.55027962], [88.85527802, 21.55027962], [88.85500336, 21.55000114], [88.85388947, 21.55000114], [88.85360718, 21.55027962], [88.8527832, 21.55027962], [88.85250092, 21.55056], [88.85221863, 21.55055428], [88.85055542, 21.5522213], [88.84999847, 21.5522213], [88.84972382, 21.55194664], [88.84860992, 21.55194664], [88.84833527, 21.5522213], [88.84694672, 21.55221939], [88.84694672, 21.55249977], [88.84638977, 21.55305672], [88.84527588, 21.55305672], [88.84500122, 21.55333328], [88.84388733, 21.55332947], [88.84333038, 21.55389023], [88.84278107, 21.55388832], [88.84194183, 21.55471992], [88.84194183, 21.55500031], [88.84139252, 21.55555534], [88.84139252, 21.55582809], [88.84111023, 21.55611038], [88.84111023, 21.55639076], [88.8408432, 21.55666924], [88.84055328, 21.55666733], [88.83999634, 21.55722237], [88.83972168, 21.55721092], [88.83944702, 21.55750084], [88.8391571, 21.55750084], [88.83889008, 21.55777931], [88.83860779, 21.55777931], [88.83833313, 21.5580616], [88.83805847, 21.5580616], [88.83750153, 21.55861092], [88.83750153, 21.55888939], [88.83694458, 21.55944443], [88.83666992, 21.55944443], [88.83638763, 21.5597229], [88.83611298, 21.5597229], [88.83583069, 21.55999947], [88.83583069, 21.56055641], [88.83555603, 21.56083107], [88.83555603, 21.56110954], [88.83528137, 21.56138992], [88.83528137, 21.5616703], [88.83416748, 21.56277847], [88.83416748, 21.56361008], [88.83528137, 21.56389046], [88.83528137, 21.56416512], [88.83555603, 21.56444359], [88.83555603, 21.56472015], [88.83583069, 21.56500053], [88.83528137, 21.56555939], [88.83444214, 21.56555748], [88.83389282, 21.56611061], [88.83361053, 21.56611061], [88.83333588, 21.56640053], [88.83277893, 21.56640053], [88.83249664, 21.56611061], [88.83222198, 21.56611061], [88.83222198, 21.56640053], [88.83194733, 21.56666756], [88.83194733, 21.56722069], [88.83166504, 21.56749916], [88.83167267, 21.56861115], [88.83139038, 21.56888962], [88.83139038, 21.56916618], [88.83110809, 21.56944466], [88.83110809, 21.57055473], [88.83082581, 21.57082748], [88.83082581, 21.57195282], [88.83027649, 21.57250023], [88.83027649, 21.57278252], [88.83000183, 21.57305527], [88.83000183, 21.57333183], [88.82971954, 21.57361031], [88.82971954, 21.57416725], [88.82917786, 21.57471275], [88.82917023, 21.57527733], [88.82861328, 21.57583046], [88.82861328, 21.57666588], [88.82833099, 21.57694244], [88.82833099, 21.57860947], [88.82861328, 21.57888985], [88.82861328, 21.57916451], [88.82888794, 21.57944679], [88.82888794, 21.57971954], [88.82917023, 21.57999992], [88.82944489, 21.57999992], [88.83027649, 21.58083344], [88.83027649, 21.58222198], [88.83056641, 21.58250046], [88.83056641, 21.58305931], [88.83110809, 21.58361053], [88.83082581, 21.58389091], [88.83082581, 21.58499908], [88.83055878, 21.58527756], [88.83056641, 21.58638954], [88.83082581, 21.58667183], [88.83082581, 21.58751106], [88.83110809, 21.58777809], [88.83110809, 21.58805466], [88.83139038, 21.58833122], [88.83139038, 21.58945084], [88.83194733, 21.59000015], [88.83194733, 21.59111023], [88.83166504, 21.5913887], [88.83167267, 21.59250069], [88.83139038, 21.59278107], [88.83139038, 21.59305763], [88.83166504, 21.5933342], [88.83167267, 21.59361076], [88.83139038, 21.59389114], [88.83139038, 21.59500122], [88.83110809, 21.59527969], [88.83110809, 21.5961113], [88.83083344, 21.59638977], [88.83083344, 21.59694481], [88.83056641, 21.59721756], [88.83055878, 21.60055542], [88.83082581, 21.60083008], [88.83082581, 21.60111046], [88.83056641, 21.60139275], [88.83055878, 21.6016674], [88.83082581, 21.60194016], [88.83082581, 21.60361099], [88.83110809, 21.60388947], [88.83083344, 21.60416412], [88.83139038, 21.60472107], [88.83139038, 21.60527992], [88.83277893, 21.60667038], [88.83361053, 21.60666466], [88.83398438, 21.6070385], [88.83416748, 21.6072216], [88.83472443, 21.6072216]]], [[[88.49771118, 21.59975433], [88.49829865, 21.59942818], [88.49888611, 21.59916687], [88.49888611, 21.59861183], [88.49972534, 21.59777832], [88.49973297, 21.59749985], [88.50222015, 21.59499931], [88.50250244, 21.59472084], [88.50250244, 21.59444427], [88.50333405, 21.59361076], [88.50389099, 21.59416962], [88.50417328, 21.59416962], [88.50499725, 21.59332085], [88.50527954, 21.5933342], [88.5055542, 21.59305763], [88.5063858, 21.59305954], [88.50666809, 21.59278107], [88.50723267, 21.59278107], [88.50763702, 21.59263039], [88.50784302, 21.59250069], [88.50833893, 21.59233284], [88.50887299, 21.5921402], [88.50938416, 21.59187508], [88.50987244, 21.59152031], [88.51039124, 21.59115028], [88.51095581, 21.59083939], [88.51154327, 21.59054947], [88.51207733, 21.59024048], [88.51248932, 21.58987045], [88.5128479, 21.58953094], [88.51319122, 21.58928871], [88.51352692, 21.58909988], [88.51381683, 21.58889389], [88.51409912, 21.58869362], [88.51444244, 21.58858109], [88.51477051, 21.5883503], [88.5151825, 21.58818245], [88.51563263, 21.58802032], [88.51609802, 21.58778572], [88.51657867, 21.58757019], [88.51676941, 21.58740807], [88.51694489, 21.58722115], [88.51750183, 21.58722115], [88.51777649, 21.58694458], [88.51777649, 21.58666611], [88.51805878, 21.58638954], [88.51832581, 21.58667183], [88.51860809, 21.58666611], [88.51875305, 21.58680725], [88.51889038, 21.58694458], [88.51944733, 21.58638954], [88.51972198, 21.58638954], [88.51999664, 21.58610916], [88.52047729, 21.58608055], [88.52102661, 21.58586121], [88.52162933, 21.5857296], [88.52218628, 21.5855484], [88.52272797, 21.58535194], [88.52326202, 21.58527946], [88.52500153, 21.58527756], [88.52555847, 21.58472061], [88.52583313, 21.58472252], [88.52639008, 21.58416748], [88.52722168, 21.58416939], [88.52749634, 21.58389091], [88.5283432, 21.58389091], [88.52861023, 21.58416939], [88.52889252, 21.58389091], [88.52889252, 21.58361053], [88.52944946, 21.58305931], [88.52971649, 21.58305931], [88.53221893, 21.58056068], [88.53221893, 21.5802803], [88.53277588, 21.57971954], [88.53277588, 21.57916451], [88.53388977, 21.57806015], [88.53388977, 21.57666969], [88.53360748, 21.57639122], [88.53360748, 21.57417107], [88.53388977, 21.57389069], [88.53388977, 21.57361031], [88.53360748, 21.57361031], [88.53341675, 21.57341766], [88.53305817, 21.57305527], [88.53221893, 21.5730629], [88.53193665, 21.57278252], [88.53166962, 21.57278252], [88.53083038, 21.57195282], [88.53056335, 21.57195282], [88.53028107, 21.57167244], [88.53028107, 21.57110977], [88.53083038, 21.57055473], [88.53083038, 21.57027817], [88.53056335, 21.56999969], [88.53055573, 21.56944466], [88.53028107, 21.56916618], [88.53028107, 21.56805992], [88.53083038, 21.56750107], [88.53083038, 21.56694031], [88.53111267, 21.56666756], [88.53111267, 21.56640053], [88.53166962, 21.56583023], [88.53111267, 21.56555748], [88.53083038, 21.56528091], [88.53083038, 21.56443977], [88.53166962, 21.56361389], [88.53193665, 21.56361008], [88.53221893, 21.56388855], [88.53221893, 21.56444359], [88.53250885, 21.56472015], [88.53250122, 21.56555748], [88.53356171, 21.56661415], [88.53388977, 21.56694412], [88.53388977, 21.5672226], [88.53444672, 21.56666756], [88.53444672, 21.56611061], [88.5341568, 21.56583023], [88.53416443, 21.56555748], [88.53407288, 21.56508827], [88.53395081, 21.56454849], [88.53382874, 21.56402016], [88.53360748, 21.56389046], [88.53360748, 21.56334114], [88.53333282, 21.56306076], [88.53333282, 21.56278038], [88.53305817, 21.5625], [88.53305817, 21.56195068], [88.53277588, 21.5616703], [88.53277588, 21.56110954], [88.53167725, 21.56001282], [88.53111267, 21.55944443], [88.53111267, 21.55916595], [88.52971649, 21.55777931], [88.52971649, 21.55639076], [88.52944946, 21.55611038], [88.52944183, 21.55555534], [88.52889252, 21.55500031], [88.52889252, 21.55471992], [88.52916718, 21.55444527], [88.52916718, 21.55389023], [88.52971649, 21.55332947], [88.52972412, 21.55277824], [88.52944946, 21.55249977], [88.52944183, 21.5522213], [88.52999878, 21.55166435], [88.52999878, 21.55111122], [88.52971649, 21.55083084], [88.52972412, 21.54999924], [88.52999878, 21.54972076], [88.52999878, 21.54944229], [88.53028107, 21.54916573], [88.53028107, 21.54805946], [88.53221893, 21.54611015], [88.53221893, 21.5447216], [88.53250122, 21.54444504], [88.53250885, 21.54388809], [88.53221893, 21.54360962], [88.53221893, 21.54333305], [88.53138733, 21.54249954], [88.53111267, 21.54249954], [88.53083038, 21.54220963], [88.52805328, 21.54222298], [88.52722168, 21.54138947], [88.52638245, 21.54138947], [88.52610779, 21.54111099], [88.52500153, 21.54111099], [88.52471924, 21.54138947], [88.52332306, 21.54138947], [88.52305603, 21.54166985], [88.5222168, 21.54083061], [88.52055359, 21.54083252], [88.52027893, 21.54055786], [88.51999664, 21.54055977], [88.51972198, 21.54027939], [88.51917267, 21.54027939], [88.51889038, 21.54000092], [88.51777649, 21.54000092], [88.51750946, 21.53972054], [88.51721954, 21.53972054], [88.51664734, 21.53985023], [88.51638794, 21.53985023], [88.51611328, 21.53972054], [88.51583099, 21.53972244], [88.51555634, 21.53944588], [88.51527405, 21.53972244], [88.5147171, 21.53972054], [88.51444244, 21.54000092], [88.51389313, 21.54000092], [88.51361084, 21.54027939], [88.51333618, 21.54027939], [88.51304626, 21.54055977], [88.51082611, 21.54055977], [88.51027679, 21.54000092], [88.51000214, 21.54000092], [88.50945282, 21.54055977], [88.5091629, 21.54055786], [88.50888824, 21.54083252], [88.50749969, 21.54083252], [88.50723267, 21.54111099], [88.50611115, 21.54111099], [88.50527954, 21.54194069], [88.50527954, 21.54277992], [88.5055542, 21.54305649], [88.5055542, 21.54333305], [88.5057373, 21.54381371], [88.50583649, 21.54418373], [88.50595093, 21.54457092], [88.50606537, 21.54499626], [88.50611115, 21.54527092], [88.50611115, 21.54545975], [88.50611115, 21.54639053], [88.5063858, 21.54667282], [88.5063858, 21.54916573], [88.50666809, 21.54944038], [88.50666809, 21.55055428], [88.50694275, 21.55083084], [88.50694275, 21.55111122], [88.50777435, 21.55194664], [88.50777435, 21.5522213], [88.51027679, 21.55471992], [88.51027679, 21.55500031], [88.5111084, 21.55583382], [88.5111084, 21.55694389], [88.51138306, 21.55721092], [88.51138306, 21.55750084], [88.51167297, 21.55777931], [88.51167297, 21.5580616], [88.5111084, 21.55861092], [88.5111084, 21.55916595], [88.51083374, 21.55944443], [88.51082611, 21.5597229], [88.51055908, 21.55999947], [88.51055908, 21.56027794], [88.50971985, 21.56111145], [88.5091629, 21.56110954], [88.50888824, 21.56138992], [88.50805664, 21.56138992], [88.50776672, 21.5616703], [88.5063858, 21.5616703], [88.50611115, 21.56195068], [88.50527954, 21.56194305], [88.50499725, 21.56222153], [88.5047226, 21.56221962], [88.50444794, 21.5625], [88.50444794, 21.56306076], [88.50416565, 21.56333542], [88.50417328, 21.56472015], [88.50389099, 21.56500053], [88.50305176, 21.56500053], [88.50305176, 21.56528091], [88.5027771, 21.56500053], [88.5027771, 21.56472015], [88.50305176, 21.56444359], [88.50305176, 21.56388855], [88.5027771, 21.56361008], [88.5027771, 21.56305313], [88.50305176, 21.56278038], [88.50305176, 21.5625], [88.5036087, 21.56195068], [88.5036087, 21.5616703], [88.50389099, 21.56138992], [88.50389099, 21.56110954], [88.50416565, 21.56083107], [88.50444794, 21.56083107], [88.5047226, 21.56055641], [88.50554657, 21.56056023], [88.50591278, 21.56048012], [88.50630951, 21.56038094], [88.5067215, 21.56031036], [88.50715637, 21.56027031], [88.50757599, 21.56026459], [88.50796509, 21.56021118], [88.50830841, 21.56008339], [88.50863647, 21.55997086], [88.50892639, 21.55982208], [88.5091629, 21.55963135], [88.50936127, 21.55937767], [88.50953674, 21.55903244], [88.50965881, 21.55855179], [88.50969696, 21.55793953], [88.50966644, 21.55725288], [88.50956726, 21.55653954], [88.50938416, 21.55586433], [88.50909424, 21.55526924], [88.50871277, 21.55478096], [88.50827789, 21.55431175], [88.50782013, 21.55388069], [88.50734711, 21.55344963], [88.50692749, 21.55300713], [88.5065918, 21.55254173], [88.50630951, 21.55212212], [88.50609589, 21.55174065], [88.50591278, 21.55143356], [88.50579071, 21.55111885], [88.50549316, 21.55113029], [88.50534821, 21.55091095], [88.50527954, 21.55055428], [88.50527954, 21.54972076], [88.50499725, 21.54944229], [88.50499725, 21.54611015], [88.5047226, 21.54583359], [88.5047226, 21.54500008], [88.50417328, 21.54445267], [88.50389099, 21.54444504], [88.5036087, 21.54445267], [88.503479, 21.54445267], [88.50332642, 21.54416847], [88.50305176, 21.54416847], [88.5027771, 21.54388809], [88.50250244, 21.54416847], [88.50026703, 21.54416847], [88.5, 21.54445267], [88.49965668, 21.54446983], [88.49919891, 21.54464912], [88.49865723, 21.54475975], [88.4981308, 21.544981], [88.49763489, 21.54517937], [88.49723816, 21.5454731], [88.49691772, 21.54578972], [88.4966507, 21.5460968], [88.49646759, 21.54641342], [88.49649048, 21.54684258], [88.49648285, 21.54730988], [88.49620819, 21.54775429], [88.49581909, 21.54821968], [88.49555206, 21.54861069], [88.49388885, 21.55027771], [88.49333954, 21.5503006], [88.49276733, 21.55056], [88.4916687, 21.55055428], [88.49138641, 21.55083275], [88.49111176, 21.55083275], [88.49055481, 21.55027771], [88.49027252, 21.55027962], [88.48999786, 21.55056], [88.48916626, 21.55055428], [88.4888916, 21.55083275], [88.48860931, 21.55083084], [88.48832703, 21.55111122], [88.48777771, 21.55111122], [88.48750305, 21.55140114], [88.48750305, 21.55249977], [88.48721313, 21.55278015], [88.48694611, 21.55277824], [88.48638916, 21.55333328], [88.4861145, 21.55333328], [88.48583221, 21.55361176], [88.48527527, 21.55361176], [88.48510742, 21.5537796], [88.48500061, 21.55389023], [88.48306274, 21.55389023], [88.48278046, 21.55417061], [88.48222351, 21.5541687], [88.48190308, 21.55450058], [88.48170471, 21.55472565], [88.48159027, 21.55504227], [88.48143768, 21.55537987], [88.48142242, 21.55581093], [88.48152161, 21.55631065], [88.48145294, 21.55689049], [88.48134613, 21.55750084], [88.48136139, 21.55811882], [88.48118591, 21.55880928], [88.48130798, 21.55923843], [88.48136902, 21.55966187], [88.4810791, 21.56009102], [88.48110962, 21.5604496], [88.48104095, 21.56087112], [88.48108673, 21.56129837], [88.48110962, 21.56174088], [88.48105621, 21.56212807], [88.48108673, 21.56250954], [88.48097229, 21.56287003], [88.48097229, 21.5637455], [88.48103333, 21.56483078], [88.48092651, 21.56562042], [88.48108673, 21.56587029], [88.48110962, 21.56619835], [88.48110962, 21.56657982], [88.48110962, 21.56701088], [88.48113251, 21.56742096], [88.48123169, 21.56776047], [88.48146057, 21.5682106], [88.48189545, 21.56894875], [88.48217773, 21.56987953], [88.48271179, 21.57117081], [88.48280334, 21.57146072], [88.48287201, 21.57175827], [88.48300934, 21.57204247], [88.48308563, 21.57238007], [88.48306274, 21.57279015], [88.48306274, 21.57324028], [88.48309326, 21.57370186], [88.48313904, 21.57420349], [88.48322296, 21.5748291], [88.48353577, 21.57551765], [88.4835968, 21.57575035], [88.48356628, 21.57611084], [88.48368835, 21.57632065], [88.48383331, 21.5765667], [88.48388672, 21.57691956], [88.48388672, 21.57735062], [88.48388672, 21.57783127], [88.48394775, 21.5783596], [88.48412323, 21.57889557], [88.48412323, 21.57949066], [88.48429871, 21.58008766], [88.48434448, 21.58054733], [88.48441315, 21.58105087], [88.48430634, 21.58146667], [88.48438263, 21.58165359], [88.48445892, 21.582201], [88.48480988, 21.58255959], [88.48500061, 21.58305931], [88.48527527, 21.5830555], [88.48555756, 21.58332825], [88.48555756, 21.58527946], [88.48527527, 21.58555603], [88.4852829, 21.58583069], [88.48583221, 21.58638954], [88.48583221, 21.58722115], [88.4861145, 21.58749962], [88.48610687, 21.58833122], [88.48665619, 21.58889008], [88.48721313, 21.58889008], [88.48777771, 21.58945084], [88.48777771, 21.59000015], [88.48805237, 21.59028053], [88.48805237, 21.59167099], [88.4888916, 21.59250069], [88.4888916, 21.59277534], [88.49055481, 21.59444427], [88.49054718, 21.59472084], [88.4908371, 21.59500122], [88.4908371, 21.59527969], [88.4916687, 21.5961113], [88.4916687, 21.59638023], [88.49276733, 21.59749985], [88.49277496, 21.59777832], [88.49333191, 21.59833336], [88.4936142, 21.59833336], [88.4937973, 21.59851837], [88.49388885, 21.59861183], [88.49415588, 21.59861183], [88.4944458, 21.5988903], [88.49472046, 21.5988903], [88.4952774, 21.59945107], [88.49555206, 21.59944534], [88.49583435, 21.59972191], [88.49610901, 21.59972191], [88.4963913, 21.60000038], [88.49649811, 21.60008049], [88.49659729, 21.6001606], [88.49714661, 21.60009003], [88.49771118, 21.59975433]]], [[[88.96576691, 21.64153481], [88.96607971, 21.64129829], [88.96637726, 21.64102936], [88.96675873, 21.6408329], [88.96723938, 21.64067078], [88.96772766, 21.64058113], [88.9681778, 21.6405201], [88.96862793, 21.64043045], [88.96904755, 21.64031792], [88.96948242, 21.64029121], [88.96990204, 21.64034081], [88.97035217, 21.64048195], [88.97080994, 21.64059448], [88.97128296, 21.64073944], [88.97171783, 21.64089966], [88.97215271, 21.64108086], [88.97259521, 21.64123344], [88.97303009, 21.64139938], [88.97346497, 21.64157677], [88.9739151, 21.64172173], [88.9743576, 21.64189339], [88.97481537, 21.64204216], [88.97527313, 21.64221954], [88.97572327, 21.6424408], [88.97618103, 21.64267921], [88.97627258, 21.64273262], [88.97662354, 21.64293671], [88.97708893, 21.64311981], [88.97753906, 21.6432724], [88.9779892, 21.64340019], [88.9784317, 21.64358521], [88.97891235, 21.64377975], [88.97949219, 21.6439209], [88.98009491, 21.64408112], [88.98071289, 21.64419174], [88.98133087, 21.64431953], [88.98197937, 21.64439964], [88.98264313, 21.64443016], [88.98330688, 21.64448166], [88.9839859, 21.64453125], [88.98468018, 21.64446831], [88.98538971, 21.64459038], [88.98600769, 21.64476013], [88.98654938, 21.64484024], [88.9870224, 21.64485931], [88.9874649, 21.64486313], [88.98789215, 21.64486313], [88.98835754, 21.6448307], [88.98889923, 21.64471054], [88.98956299, 21.6445961], [88.990242, 21.64438057], [88.99085999, 21.64404106], [88.99138641, 21.64356995], [88.99185181, 21.64299965], [88.99221802, 21.6423912], [88.99250031, 21.64178085], [88.9927063, 21.64118958], [88.99288177, 21.64064026], [88.99302673, 21.64015007], [88.99311066, 21.63965034], [88.99326324, 21.63918114], [88.99331665, 21.63869286], [88.99333191, 21.63818741], [88.99333954, 21.63768005], [88.99339294, 21.63718033], [88.9935379, 21.63669968], [88.99360657, 21.63620949], [88.9936676, 21.63571167], [88.99384308, 21.63519096], [88.99388885, 21.6346302], [88.99394226, 21.63406181], [88.99407196, 21.63351059], [88.99419403, 21.6329174], [88.99434662, 21.63229942], [88.99443054, 21.63165283], [88.99446106, 21.63101006], [88.99452972, 21.63042068], [88.99467468, 21.62994194], [88.99473572, 21.62946129], [88.99481201, 21.62901878], [88.99495697, 21.62862968], [88.99500275, 21.62820053], [88.99478149, 21.6277504], [88.9950943, 21.62731361], [88.99485016, 21.62685966], [88.99513245, 21.62639999], [88.99485016, 21.62592125], [88.99485016, 21.62540817], [88.99485016, 21.62513542], [88.9944458, 21.62486076], [88.99432373, 21.62418938], [88.99416351, 21.62333298], [88.9938736, 21.62318993], [88.99376678, 21.62275124], [88.99307251, 21.62194061], [88.99305725, 21.62138939], [88.99250031, 21.62083244], [88.99250031, 21.62050056], [88.99250031, 21.61916733], [88.99223328, 21.61889076], [88.99223328, 21.61778069], [88.99250031, 21.61749077], [88.99250031, 21.61666679], [88.9908371, 21.61499977], [88.99060059, 21.61499977], [88.99028015, 21.61499977], [88.98972321, 21.61445045], [88.98944092, 21.61445045], [88.98916626, 21.61417007], [88.9888916, 21.61417007], [88.98832703, 21.61361122], [88.98805237, 21.61361122], [88.98805237, 21.61333275], [88.98777771, 21.61305618], [88.98722076, 21.61305618], [88.98694611, 21.61333275], [88.98583221, 21.61333275], [88.98583221, 21.61361122], [88.98555756, 21.61388969], [88.98500061, 21.61388969], [88.98443604, 21.61333275], [88.98388672, 21.61333275], [88.98361206, 21.61305618], [88.983078, 21.61305618], [88.98166656, 21.61305618], [88.98139191, 21.61333275], [88.98000336, 21.61333275], [88.97957611, 21.6131916], [88.97571564, 21.6131916], [88.97472382, 21.61333275], [88.97389221, 21.61333275], [88.97360992, 21.61334038], [88.97305298, 21.61347961], [88.97286987, 21.61338234], [88.97277832, 21.61333275], [88.97071075, 21.61333275], [88.97000122, 21.61361122], [88.96835327, 21.61361122], [88.96749878, 21.61388969], [88.96721649, 21.61388969], [88.96694183, 21.61417007], [88.96639252, 21.61417007], [88.96611023, 21.61445045], [88.96583557, 21.61444473], [88.96555328, 21.6147213], [88.96527863, 21.61471939], [88.96499634, 21.61499977], [88.96360779, 21.61499977], [88.96333313, 21.61528015], [88.96277618, 21.61527824], [88.96250153, 21.61555481], [88.96221924, 21.61555481], [88.96166992, 21.61611176], [88.96028137, 21.61610985], [88.95970917, 21.61667061], [88.95833588, 21.61667061], [88.95804596, 21.61695099], [88.95777893, 21.61694336], [88.95749664, 21.61722183], [88.95641327, 21.6174202], [88.95591736, 21.61756706], [88.95612335, 21.61770248], [88.95612335, 21.61777687], [88.95610809, 21.61833572], [88.95639038, 21.61833], [88.95639038, 21.61889076], [88.95666504, 21.61916733], [88.95667267, 21.61972046], [88.9569397, 21.62000084], [88.95722198, 21.62000084], [88.95777893, 21.62055779], [88.95777893, 21.62083054], [88.95805359, 21.62111092], [88.95841217, 21.62147331], [88.9585495, 21.62169266], [88.95876312, 21.62202072], [88.95861053, 21.62222099], [88.95861053, 21.62249947], [88.95816803, 21.62249947], [88.95804596, 21.62249947], [88.95777893, 21.62277985], [88.95777893, 21.62305832], [88.95722198, 21.62361908], [88.95722198, 21.62388992], [88.95667267, 21.62445068], [88.95639038, 21.62445068], [88.95555878, 21.62528038], [88.95527649, 21.62528038], [88.95276642, 21.62778282], [88.95276642, 21.62805939], [88.9522171, 21.62861061], [88.9522171, 21.6288929], [88.95166779, 21.62944221], [88.95166779, 21.62972069], [88.95083618, 21.6305542], [88.95083618, 21.63083076], [88.95054626, 21.63111115], [88.95055389, 21.63138962], [88.94999695, 21.63194656], [88.94999695, 21.63305092], [88.94917297, 21.63389015], [88.9486084, 21.63388634], [88.94776917, 21.63471985], [88.94776917, 21.63500023], [88.94750214, 21.63528061], [88.94750214, 21.63555527], [88.94721985, 21.63582993], [88.94721985, 21.63611031], [88.9466629, 21.63666725], [88.94694519, 21.63694382], [88.9466629, 21.63722038], [88.9466629, 21.63750076], [88.9458313, 21.63833427], [88.94555664, 21.63832855], [88.94526672, 21.63862038], [88.94361115, 21.63861084], [88.94301605, 21.63920784], [88.94277954, 21.63944435], [88.94267273, 21.63939667], [88.94238281, 21.63974953], [88.94207001, 21.64015007], [88.9420929, 21.64055634], [88.94225311, 21.6408329], [88.94168091, 21.6415329], [88.94140625, 21.64152336], [88.94113159, 21.64180183], [88.94098663, 21.64249992], [88.94083405, 21.6427784], [88.94082642, 21.64361], [88.9402771, 21.64417076], [88.94023895, 21.64587021], [88.94000244, 21.64611053], [88.94000244, 21.64639091], [88.93972015, 21.64666748], [88.93972015, 21.64694595], [88.94000244, 21.64722061], [88.94024658, 21.64729118], [88.94058228, 21.64770126], [88.94085693, 21.6480999], [88.9411087, 21.64861107], [88.94135284, 21.64885139], [88.94166565, 21.64916611], [88.94152069, 21.64931488], [88.94139099, 21.64944458], [88.94139099, 21.64972305], [88.94185638, 21.65018845], [88.94194794, 21.65027809], [88.94194794, 21.65041924], [88.94194794, 21.65083313], [88.94220734, 21.6511097], [88.94217682, 21.65129089], [88.94229889, 21.6518116], [88.94248199, 21.65229034], [88.94262695, 21.65276909], [88.94274902, 21.65323067], [88.94281006, 21.65366936], [88.94293213, 21.65402985], [88.94309998, 21.65432358], [88.94330597, 21.65458107], [88.94346619, 21.65487099], [88.94355774, 21.65523529], [88.9438324, 21.65544319], [88.9438324, 21.65592957], [88.94420624, 21.65642929], [88.94445038, 21.65688324], [88.94468689, 21.65730095], [88.94484711, 21.65796089], [88.94494629, 21.65867996], [88.94532776, 21.6592598], [88.94554138, 21.65987968], [88.9457016, 21.66050911], [88.94586182, 21.66115952], [88.94612885, 21.66176987], [88.94645691, 21.66231918], [88.94668579, 21.66291809], [88.94696045, 21.66349983], [88.94724274, 21.66398048], [88.94753265, 21.66436958], [88.94779968, 21.66467285], [88.94805145, 21.66494942], [88.94825745, 21.66524124], [88.94837952, 21.66563988], [88.94857025, 21.66605186], [88.9487381, 21.66655922], [88.94904327, 21.66695023], [88.94937897, 21.66732788], [88.94970703, 21.66769409], [88.94986725, 21.66790962], [88.94999695, 21.66808128], [88.95025635, 21.6684761], [88.95044708, 21.6689415], [88.95059204, 21.66946793], [88.95083618, 21.66995049], [88.95111084, 21.67043114], [88.95137787, 21.67087936], [88.95159912, 21.6713295], [88.95178986, 21.67178726], [88.95197296, 21.67220116], [88.9522171, 21.67253113], [88.95243835, 21.67287445], [88.9526062, 21.67328262], [88.95282745, 21.67366028], [88.95307159, 21.67406273], [88.95332336, 21.67447853], [88.95355225, 21.67495346], [88.95365143, 21.67554092], [88.9539032, 21.6760807], [88.95423126, 21.676548], [88.95468903, 21.6769104], [88.95520782, 21.6770916], [88.95587921, 21.67682266], [88.95654297, 21.67628288], [88.95705414, 21.67577744], [88.95742035, 21.67528915], [88.95765686, 21.6748085], [88.95780945, 21.67433167], [88.95793152, 21.67385483], [88.95807648, 21.67337036], [88.95826721, 21.67290306], [88.95848083, 21.67244911], [88.95865631, 21.67198181], [88.95884705, 21.6715107], [88.95903778, 21.67110825], [88.95922089, 21.67068291], [88.95940399, 21.67024612], [88.9595871, 21.66979027], [88.95974731, 21.66932106], [88.95995331, 21.66889], [88.96013641, 21.66847038], [88.960289, 21.66798973], [88.9604187, 21.66749763], [88.96057892, 21.66699028], [88.96077728, 21.66646194], [88.96095276, 21.66595078], [88.96105194, 21.66547203], [88.96123505, 21.66501999], [88.9614563, 21.66459465], [88.96161652, 21.6641922], [88.96173096, 21.66379929], [88.96185303, 21.66335106], [88.96198273, 21.66283607], [88.96211243, 21.66228104], [88.96222687, 21.66169167], [88.9622879, 21.66102982], [88.9623642, 21.66035461], [88.96244812, 21.65963554], [88.96248627, 21.65888977], [88.96245575, 21.65814972], [88.96238708, 21.65743065], [88.96232605, 21.65674019], [88.96222687, 21.6561203], [88.9621582, 21.65555954], [88.96211243, 21.65506172], [88.96208954, 21.65459061], [88.96203613, 21.65413094], [88.96193695, 21.65365028], [88.96186066, 21.6531105], [88.96179962, 21.65254021], [88.96177673, 21.65195274], [88.9617691, 21.65137482], [88.96179199, 21.65076828], [88.96186066, 21.65011024], [88.96191406, 21.6493969], [88.96202087, 21.64867973], [88.96217346, 21.64801788], [88.96232605, 21.64743805], [88.96248627, 21.64698029], [88.96264648, 21.64657974], [88.96285248, 21.6462307], [88.96309662, 21.64590073], [88.96333313, 21.64550018], [88.96347809, 21.64504433], [88.96357727, 21.64454079], [88.96370697, 21.64408112], [88.96389008, 21.64369965], [88.96412659, 21.64339638], [88.96440125, 21.64311028], [88.96469116, 21.64280128], [88.96496582, 21.64245987], [88.96520233, 21.64209938], [88.96547699, 21.6417923], [88.96576691, 21.64153481]]], [[[88.53721619, 21.63862038], [88.53749847, 21.63806152], [88.53778076, 21.63806152], [88.53832245, 21.63750076], [88.53943634, 21.63750076], [88.54055786, 21.63639069], [88.54083252, 21.63639069], [88.54138947, 21.63582993], [88.54138947, 21.63555527], [88.54165649, 21.63528061], [88.54193115, 21.63511086], [88.54232788, 21.63490105], [88.5427475, 21.63471031], [88.54315948, 21.63449097], [88.54360962, 21.63431931], [88.54360962, 21.63417053], [88.54444885, 21.63417053], [88.54471588, 21.63389015], [88.54528046, 21.63389015], [88.54556274, 21.63360977], [88.54666901, 21.63361168], [88.54777527, 21.63249969], [88.55000305, 21.63249016], [88.55027771, 21.63278008], [88.55166626, 21.63278008], [88.55249786, 21.63194084], [88.55278015, 21.63222313], [88.55388641, 21.63222313], [88.5541687, 21.63194656], [88.55444336, 21.63222313], [88.55500031, 21.63222313], [88.55527496, 21.63194656], [88.5561142, 21.63194656], [88.55638885, 21.63166428], [88.55750275, 21.63167], [88.5577774, 21.63138962], [88.55805206, 21.63138962], [88.55832672, 21.63111115], [88.55860901, 21.63111115], [88.55944824, 21.63027954], [88.5597229, 21.63027954], [88.55999756, 21.63000107], [88.56027985, 21.63000107], [88.56083679, 21.62943268], [88.56111145, 21.62944221], [88.56138611, 21.62916756], [88.5616684, 21.62916946], [88.56223297, 21.62861061], [88.5625, 21.62861061], [88.5633316, 21.62778282], [88.56360626, 21.62778282], [88.56388855, 21.62750053], [88.56445313, 21.62750053], [88.56472015, 21.62722015], [88.56500244, 21.62722015], [88.56555176, 21.62666702], [88.56582642, 21.62668037], [88.56639099, 21.62611008], [88.56639099, 21.62555504], [88.56777954, 21.62556267], [88.56833649, 21.62500191], [88.56861877, 21.62500191], [88.56916809, 21.62444496], [88.56944275, 21.62445068], [88.57026672, 21.62361908], [88.57055664, 21.62361908], [88.57110596, 21.62305832], [88.5716629, 21.62305832], [88.5736084, 21.62111092], [88.5736084, 21.62028122], [88.57389069, 21.62000084], [88.57472229, 21.62000084], [88.57527924, 21.61944008], [88.57499695, 21.61916733], [88.57583618, 21.61833], [88.5763855, 21.61833572], [88.58027649, 21.61444473], [88.58027649, 21.61388969], [88.58139038, 21.61277962], [88.58167267, 21.61277962], [88.58304596, 21.61138916], [88.58333588, 21.61138916], [88.58389282, 21.6108284], [88.58388519, 21.60888863], [88.58416748, 21.60861015], [88.58416748, 21.60833359], [88.58499908, 21.60750008], [88.58528137, 21.60750008], [88.58583069, 21.60695076], [88.58583069, 21.60750008], [88.58638763, 21.60695076], [88.58638763, 21.60639], [88.58611298, 21.60610962], [88.58611298, 21.60583305], [88.58666992, 21.60527611], [88.58666229, 21.60416985], [88.58693695, 21.60388947], [88.58693695, 21.60333061], [88.58721924, 21.60305405], [88.58721924, 21.60222054], [88.58750153, 21.60194206], [88.58750153, 21.60138893], [88.58721924, 21.60111046], [88.58721924, 21.60056114], [88.58693695, 21.60028267], [88.58693695, 21.59972191], [88.58666992, 21.59944534], [88.58666229, 21.59917259], [88.58693695, 21.5988903], [88.58693695, 21.59833145], [88.58666992, 21.59805489], [88.58666992, 21.59749985], [88.58638763, 21.59721756], [88.58638763, 21.59638977], [88.58611298, 21.5961113], [88.58611298, 21.59527969], [88.58638763, 21.59500122], [88.58638763, 21.59444046], [88.58721924, 21.59361076], [88.58666229, 21.59305954], [88.58666229, 21.59250069], [88.58638763, 21.59222031], [88.58638763, 21.59166527], [88.58583069, 21.59111023], [88.58583069, 21.59082985], [88.58638763, 21.59027863], [88.58638763, 21.59000015], [88.58666229, 21.58971977], [88.58666229, 21.58902359], [88.58654785, 21.5884037], [88.58634949, 21.58785248], [88.58610535, 21.58739471], [88.58583832, 21.5870266], [88.58560944, 21.58670807], [88.58547974, 21.58633041], [88.585289, 21.58600616], [88.58509827, 21.58566093], [88.58487701, 21.58530998], [88.58460236, 21.58497047], [88.58435822, 21.58462524], [88.58413696, 21.58430862], [88.5839386, 21.58399963], [88.58378601, 21.58365059], [88.58359528, 21.58334923], [88.58338165, 21.58308029], [88.58319092, 21.58279228], [88.58300018, 21.58251953], [88.58280182, 21.58226967], [88.58265686, 21.58197975], [88.58246613, 21.58172035], [88.5822525, 21.58150291], [88.58206177, 21.5812397], [88.58181763, 21.58096123], [88.58158112, 21.58058167], [88.58130646, 21.58018875], [88.5810318, 21.57978058], [88.58070374, 21.57945633], [88.58035278, 21.57917023], [88.57997894, 21.57888985], [88.57958984, 21.57858276], [88.57920837, 21.57819939], [88.57888031, 21.57776642], [88.57858276, 21.57734108], [88.57826996, 21.57697105], [88.57791901, 21.57665634], [88.57756805, 21.57633972], [88.57724762, 21.57600784], [88.57695007, 21.57566833], [88.57662964, 21.57531738], [88.57554626, 21.57417107], [88.57527924, 21.57417107], [88.57472229, 21.57361031], [88.57444763, 21.57361031], [88.57417297, 21.57333183], [88.57389069, 21.57333374], [88.57333374, 21.57305527], [88.57277679, 21.57250023], [88.57250214, 21.57250023], [88.57195282, 21.57195282], [88.5716629, 21.57195282], [88.57110596, 21.57139015], [88.5708313, 21.57139015], [88.57069397, 21.57125092], [88.57055664, 21.57111168], [88.56999969, 21.57111168], [88.56972504, 21.57083321], [88.56916809, 21.57083321], [88.5680542, 21.56972313], [88.56777954, 21.56972313], [88.56749725, 21.56944466], [88.5672226, 21.56944466], [88.56694794, 21.56916618], [88.56667328, 21.56916809], [88.56639099, 21.56888962], [88.56555939, 21.56888962], [88.5652771, 21.56916618], [88.5652771, 21.56944466], [88.56555939, 21.56972122], [88.56555939, 21.57027817], [88.5652771, 21.57027817], [88.56500244, 21.56999969], [88.56428528, 21.57034111], [88.56399536, 21.56999016], [88.56365967, 21.56960106], [88.56333923, 21.5691967], [88.56305695, 21.56944466], [88.56298065, 21.56937027], [88.56277466, 21.56916618], [88.56194305, 21.56916618], [88.5616684, 21.56944466], [88.56111145, 21.56944466], [88.56097412, 21.56930542], [88.56083679, 21.56916618], [88.55832672, 21.56916809], [88.55805206, 21.56888962], [88.5577774, 21.56888962], [88.55750275, 21.56861115], [88.55665588, 21.56861115], [88.55555725, 21.56750107], [88.55526733, 21.56750107], [88.55504608, 21.56726646], [88.55472565, 21.5672226], [88.55444336, 21.56694412], [88.5541687, 21.56694412], [88.55397797, 21.56675911], [88.55388641, 21.56666756], [88.55361938, 21.56666946], [88.55194092, 21.56500053], [88.5513916, 21.56500053], [88.5513916, 21.56472015], [88.55083466, 21.56416512], [88.55055237, 21.56417084], [88.55000305, 21.56361008], [88.54972076, 21.56361008], [88.54944611, 21.56389046], [88.54915619, 21.56389046], [88.54888916, 21.56417084], [88.54833221, 21.56417084], [88.54722595, 21.56528091], [88.54694366, 21.56527519], [88.54673004, 21.56549072], [88.54611206, 21.56611061], [88.54528046, 21.56611061], [88.54499817, 21.56640053], [88.54471588, 21.56640053], [88.54444885, 21.56666946], [88.54360962, 21.56666946], [88.54360962, 21.56750107], [88.54389191, 21.56777954], [88.54389191, 21.56805611], [88.54360962, 21.56833076], [88.54360962, 21.56861115], [88.54333496, 21.56888962], [88.54332733, 21.56972122], [88.54360962, 21.56999969], [88.54360962, 21.57055473], [88.54333496, 21.57083321], [88.54333496, 21.57170105], [88.54333496, 21.57305527], [88.54305267, 21.57333183], [88.54305267, 21.57500076], [88.54277802, 21.57500076], [88.54277802, 21.5755558], [88.54250336, 21.57583046], [88.54250336, 21.57633972], [88.54250336, 21.57676125], [88.54248047, 21.57720184], [88.54236603, 21.57761955], [88.54220581, 21.57801056], [88.54202271, 21.57839966], [88.54187012, 21.5788517], [88.54165649, 21.57929039], [88.54139709, 21.57972717], [88.54116821, 21.5802021], [88.54108429, 21.58034134], [88.54089355, 21.58064651], [88.54068756, 21.58114052], [88.54052734, 21.58166885], [88.54025269, 21.58213997], [88.53996277, 21.58255959], [88.53970337, 21.58295059], [88.53944397, 21.58332443], [88.53916931, 21.58369255], [88.53888702, 21.58407211], [88.53878021, 21.58420563], [88.53858948, 21.58443832], [88.53824615, 21.58481026], [88.53787231, 21.58518791], [88.53752899, 21.58562279], [88.5372467, 21.58608818], [88.53704834, 21.58655739], [88.53694916, 21.5869503], [88.53701019, 21.5872612], [88.5375061, 21.5875206], [88.53807068, 21.58773613], [88.53869629, 21.58788109], [88.53929901, 21.58806038], [88.53991699, 21.58819962], [88.54056549, 21.58819771], [88.54112244, 21.58836174], [88.54159546, 21.58856583], [88.54205322, 21.58873367], [88.54247284, 21.58892059], [88.54286194, 21.58916283], [88.54324341, 21.58943176], [88.54360962, 21.58972549], [88.54397583, 21.59003258], [88.54438019, 21.59032059], [88.54476929, 21.59062958], [88.5451355, 21.59095192], [88.54551697, 21.59124947], [88.54589844, 21.59154892], [88.5463028, 21.59184074], [88.54669189, 21.59221077], [88.54707336, 21.59260941], [88.54747772, 21.59299088], [88.54789734, 21.5933094], [88.54831696, 21.59361076], [88.54878235, 21.59390068], [88.54928589, 21.59421539], [88.54980469, 21.59458351], [88.55032349, 21.59501457], [88.55084229, 21.59546089], [88.55137634, 21.59589958], [88.55191803, 21.59630966], [88.55249786, 21.59662819], [88.5530777, 21.59687805], [88.55362701, 21.59712029], [88.55409241, 21.59741783], [88.55448151, 21.5977211], [88.55484772, 21.59801483], [88.55521393, 21.5982933], [88.55560303, 21.59856033], [88.5559845, 21.59882736], [88.55635834, 21.59911156], [88.5566864, 21.5994606], [88.55698395, 21.5998764], [88.55724335, 21.6003418], [88.55745697, 21.60085106], [88.55760956, 21.60140991], [88.55750275, 21.6016674], [88.5577774, 21.60194206], [88.5577774, 21.60333252], [88.55666351, 21.60444641], [88.5561142, 21.60388947], [88.55610657, 21.60277939], [88.55638885, 21.60251045], [88.55639648, 21.60214996], [88.55639648, 21.60161972], [88.55630493, 21.6010704], [88.55607605, 21.60056114], [88.55574036, 21.60009956], [88.55532074, 21.59971619], [88.55486298, 21.59939003], [88.55436707, 21.59910011], [88.5539093, 21.59883118], [88.55345154, 21.5985527], [88.55298615, 21.59826088], [88.55251312, 21.59798431], [88.55204773, 21.59771347], [88.55160522, 21.59745979], [88.55119324, 21.59722519], [88.55084229, 21.59698105], [88.55052185, 21.59675026], [88.55020905, 21.59653664], [88.54988861, 21.59633064], [88.54955292, 21.59610176], [88.54917908, 21.59585953], [88.54876709, 21.59560013], [88.54836273, 21.59526443], [88.54795837, 21.59493446], [88.54754639, 21.59464073], [88.54715729, 21.59433365], [88.54677582, 21.59399986], [88.54641724, 21.59365273], [88.54607391, 21.59332657], [88.54573059, 21.59302902], [88.54537964, 21.59273911], [88.5450058, 21.59246063], [88.54464722, 21.59213066], [88.54431152, 21.59179115], [88.5439682, 21.59145546], [88.54364777, 21.59112549], [88.54335022, 21.59082985], [88.54304504, 21.59059715], [88.54271698, 21.59044075], [88.5424118, 21.59025192], [88.54212189, 21.59006119], [88.54177856, 21.58989906], [88.54144287, 21.58971977], [88.54104614, 21.58954811], [88.54055023, 21.58945847], [88.5399704, 21.58943176], [88.53933716, 21.58941078], [88.53874969, 21.5893383], [88.53826141, 21.58915901], [88.5378418, 21.58897018], [88.53740692, 21.58876991], [88.5369339, 21.58839798], [88.53659821, 21.58839417], [88.53633118, 21.58859062], [88.53604126, 21.58879852], [88.53569794, 21.58892822], [88.53544617, 21.5891304], [88.53517151, 21.58927917], [88.5348587, 21.58945084], [88.53450012, 21.58966446], [88.53411102, 21.58992195], [88.53362274, 21.59013939], [88.53312683, 21.59038925], [88.53273773, 21.59073067], [88.53231812, 21.59099007], [88.53186035, 21.59119987], [88.53141785, 21.59140015], [88.53102112, 21.59161949], [88.53056335, 21.59184647], [88.53015137, 21.59206963], [88.52974701, 21.5922966], [88.52955627, 21.59242058], [88.52937317, 21.59254265], [88.5289917, 21.59278107], [88.52858734, 21.59300995], [88.5281601, 21.59320831], [88.52765656, 21.59337044], [88.52749634, 21.59361076], [88.52722168, 21.59361076], [88.5266571, 21.59416962], [88.52639008, 21.59416771], [88.52610779, 21.59444427], [88.52583313, 21.59444046], [88.52527618, 21.59500122], [88.52500153, 21.59500122], [88.52443695, 21.59555817], [88.52388763, 21.59555626], [88.52361298, 21.59583282], [88.52333069, 21.59583282], [88.5228653, 21.59583282], [88.52242279, 21.59583282], [88.5220108, 21.59583092], [88.52163696, 21.59587097], [88.5213089, 21.59601974], [88.52091217, 21.59609985], [88.52044678, 21.59614944], [88.5200119, 21.59634018], [88.51947784, 21.59642982], [88.51899719, 21.59666061], [88.51853943, 21.59686089], [88.51805115, 21.59698105], [88.51763153, 21.59716034], [88.5171814, 21.59724998], [88.51676178, 21.59739113], [88.51633453, 21.59748459], [88.51590729, 21.59753036], [88.51551056, 21.59767723], [88.51508331, 21.59779358], [88.5146637, 21.59795189], [88.51418304, 21.5980854], [88.51370239, 21.59833145], [88.51321411, 21.59860611], [88.51271057, 21.59888458], [88.51223755, 21.59918022], [88.51187897, 21.59956551], [88.51148987, 21.59982109], [88.51125336, 21.60013962], [88.51107025, 21.60042763], [88.51085663, 21.60064125], [88.51066589, 21.60087013], [88.51053619, 21.60115051], [88.51027679, 21.60138893], [88.51027679, 21.60194206], [88.51000214, 21.60222054], [88.51027679, 21.60250092], [88.51027679, 21.60333061], [88.51055908, 21.60361099], [88.51055908, 21.60388947], [88.51083374, 21.60416412], [88.51083374, 21.60444641], [88.5111084, 21.60472107], [88.5111084, 21.60527611], [88.51139069, 21.60555649], [88.51139069, 21.60583305], [88.51167297, 21.60610962], [88.51167297, 21.60778046], [88.51194763, 21.60806084], [88.51194763, 21.6091671], [88.51167297, 21.60943985], [88.51250458, 21.61027908], [88.51277924, 21.61056137], [88.51333618, 21.61055565], [88.51361084, 21.61083412], [88.51389313, 21.61056137], [88.51472473, 21.61055565], [88.51499939, 21.61083412], [88.51526642, 21.6108284], [88.51555634, 21.61111069], [88.51555634, 21.61166573], [88.51526642, 21.61193848], [88.51526642, 21.61277962], [88.51555634, 21.6130619], [88.51555634, 21.61444473], [88.51526642, 21.61471939], [88.51526642, 21.61528015], [88.51777649, 21.61777687], [88.51777649, 21.61833], [88.51805878, 21.61861038], [88.51803589, 21.61876106], [88.51824188, 21.6192112], [88.51843262, 21.61971092], [88.51870728, 21.62020111], [88.51908875, 21.62063026], [88.51938629, 21.62111092], [88.51972198, 21.62166977], [88.52027893, 21.62166786], [88.52055359, 21.62194443], [88.52083588, 21.62194443], [88.52138519, 21.62249947], [88.52166748, 21.62249947], [88.52278137, 21.62361908], [88.52278137, 21.62388992], [88.52305603, 21.62416649], [88.52305603, 21.62471771], [88.52332306, 21.62500191], [88.52333069, 21.62527847], [88.52416992, 21.62611008], [88.52416992, 21.62666702], [88.52361298, 21.62722015], [88.52361298, 21.62778282], [88.52332306, 21.62778282], [88.52305603, 21.62805939], [88.5222168, 21.62805939], [88.52194214, 21.62778282], [88.52083588, 21.62888908], [88.52105713, 21.62906075], [88.52127838, 21.62952042], [88.52144623, 21.63005257], [88.52167511, 21.63054657], [88.52186584, 21.63100052], [88.521698, 21.63136482], [88.52150726, 21.63169861], [88.52137756, 21.63207054], [88.52122498, 21.63240623], [88.52111816, 21.63278008], [88.5210495, 21.63318062], [88.52088928, 21.63349152], [88.52083588, 21.63382912], [88.52078247, 21.63417816], [88.52059937, 21.63451004], [88.52054596, 21.63498116], [88.52050781, 21.63552284], [88.52037048, 21.63607025], [88.52050781, 21.63668251], [88.52060699, 21.63731194], [88.52085114, 21.63779831], [88.52106476, 21.6382618], [88.52115631, 21.63875008], [88.52133179, 21.6392498], [88.52127838, 21.63967514], [88.52112579, 21.64005089], [88.52104187, 21.64043999], [88.52086639, 21.64076996], [88.52079773, 21.64113998], [88.52065277, 21.64145279], [88.52056885, 21.64183044], [88.52050018, 21.64230728], [88.52031708, 21.64283943], [88.52028656, 21.64352989], [88.52039337, 21.64426994], [88.52059174, 21.64492989], [88.52083588, 21.64549637], [88.52111053, 21.6459713], [88.52118683, 21.64608192], [88.52139282, 21.64637947], [88.52163696, 21.64678192], [88.52185059, 21.64721107], [88.5220108, 21.64768028], [88.52223206, 21.6482296], [88.52249908, 21.64874077], [88.52272797, 21.64923096], [88.52278137, 21.64977074], [88.52281952, 21.65028954], [88.52297211, 21.65079117], [88.52308655, 21.65132141], [88.52333832, 21.6517601], [88.52360535, 21.65216637], [88.52384949, 21.65254021], [88.52407074, 21.65288925], [88.52437592, 21.65320015], [88.52469635, 21.65328026], [88.52501678, 21.65304947], [88.52539063, 21.65265274], [88.52572632, 21.65212059], [88.52613831, 21.65166473], [88.52653503, 21.65120125], [88.52685547, 21.65067863], [88.5271225, 21.65014076], [88.52745056, 21.64965057], [88.52777863, 21.64915466], [88.52812958, 21.6486702], [88.52861023, 21.6483326], [88.52861023, 21.64777756], [88.52916718, 21.64722061], [88.52916718, 21.64694595], [88.52944183, 21.64666748], [88.52944946, 21.64639091], [88.53028107, 21.64556122], [88.53028107, 21.64528084], [88.53083038, 21.64472008], [88.53349304, 21.64205933], [88.53359222, 21.64192772], [88.53383636, 21.64160919], [88.53425598, 21.64115906], [88.53472137, 21.64071083], [88.53521729, 21.64025116], [88.53570557, 21.63978958], [88.53623199, 21.63936043], [88.53671265, 21.63888931], [88.53721619, 21.63862038]]], [[[88.72885132, 21.63708115], [88.72886658, 21.63659096], [88.72889709, 21.63612938], [88.7289505, 21.63572693], [88.72905731, 21.63533974], [88.72914124, 21.63493347], [88.72922516, 21.63451004], [88.72936249, 21.63409615], [88.72943878, 21.63366318], [88.72952271, 21.63321114], [88.72966766, 21.63279533], [88.72981262, 21.63236046], [88.72995758, 21.63190079], [88.73007202, 21.63143539], [88.7302475, 21.63097], [88.73040771, 21.63049507], [88.73060608, 21.63009071], [88.73084259, 21.62973213], [88.73105621, 21.62938118], [88.7312088, 21.62898064], [88.73137665, 21.62859535], [88.73153687, 21.6282196], [88.73174286, 21.6279335], [88.73200226, 21.62771034], [88.73226929, 21.62745094], [88.7325592, 21.62712097], [88.73287201, 21.62673378], [88.7332077, 21.62633133], [88.73352051, 21.6258831], [88.73377228, 21.62535858], [88.73396301, 21.62477112], [88.73413086, 21.62413979], [88.73421478, 21.62347221], [88.73416138, 21.62280846], [88.73407745, 21.62219048], [88.73394775, 21.6216507], [88.73387146, 21.62112808], [88.73381805, 21.62065887], [88.73369598, 21.62024117], [88.73362732, 21.61982155], [88.73361206, 21.61942673], [88.7335968, 21.61901283], [88.73355103, 21.61856842], [88.73345184, 21.61810112], [88.73340607, 21.61758041], [88.7334671, 21.6170311], [88.73358154, 21.61648941], [88.7336731, 21.61592102], [88.73381042, 21.61538124], [88.7339325, 21.61486053], [88.73407745, 21.61442566], [88.73413849, 21.61400986], [88.73416138, 21.61363029], [88.73419952, 21.61330032], [88.73439026, 21.6129818], [88.73454285, 21.61266327], [88.73470306, 21.61239052], [88.73485565, 21.61212349], [88.73501587, 21.61188126], [88.73519135, 21.61164284], [88.73537445, 21.61137199], [88.73558044, 21.61105156], [88.73587036, 21.61067963], [88.73623657, 21.61026955], [88.73670197, 21.60984039], [88.73726654, 21.60943985], [88.73789978, 21.60910606], [88.73853302, 21.60874939], [88.73914337, 21.60836983], [88.73977661, 21.60800934], [88.74040985, 21.60767174], [88.74106598, 21.6074028], [88.7416687, 21.6071682], [88.74217224, 21.60694122], [88.74262238, 21.60674095], [88.74305725, 21.60659981], [88.74343109, 21.60642242], [88.74382019, 21.60627747], [88.7441864, 21.60612106], [88.74458313, 21.60597992], [88.74500275, 21.60586548], [88.74543762, 21.60578918], [88.74585724, 21.60567284], [88.74626923, 21.60556984], [88.74669647, 21.60547066], [88.74707031, 21.60531616], [88.74746704, 21.60518265], [88.7478714, 21.60505295], [88.74830627, 21.60494041], [88.74874115, 21.60474968], [88.74921417, 21.60458183], [88.74975586, 21.60440636], [88.75035095, 21.60421944], [88.75096893, 21.60405922], [88.75151825, 21.60378265], [88.75200653, 21.60342407], [88.75251007, 21.60310173], [88.75299835, 21.60282516], [88.75345612, 21.60259056], [88.75392914, 21.60240936], [88.75432587, 21.60214996], [88.75469208, 21.60181046], [88.75510406, 21.60145378], [88.75556183, 21.60111809], [88.75602722, 21.60079002], [88.75647736, 21.60044098], [88.7568512, 21.60005379], [88.75709534, 21.59957504], [88.75718689, 21.59897995], [88.75711823, 21.5983429], [88.75683594, 21.59779167], [88.75636292, 21.59745026], [88.755867, 21.59716034], [88.75540924, 21.59691048], [88.75497437, 21.59667778], [88.75453186, 21.59645271], [88.75408936, 21.59619141], [88.75360107, 21.59593964], [88.75311279, 21.59568024], [88.75263977, 21.59539413], [88.75222778, 21.59506989], [88.75182343, 21.59475517], [88.75138855, 21.59447289], [88.75093842, 21.59422493], [88.75056458, 21.59390259], [88.75022125, 21.59354019], [88.74991608, 21.59314919], [88.74957275, 21.5927906], [88.7492218, 21.59244537], [88.748909, 21.59206963], [88.74861908, 21.59168816], [88.74835205, 21.59132957], [88.74813843, 21.59095192], [88.74799347, 21.5905304], [88.74780273, 21.59013939], [88.74762726, 21.58973122], [88.74746704, 21.58930969], [88.74729156, 21.58884811], [88.74723053, 21.58827972], [88.7472229, 21.58764267], [88.74723053, 21.58698082], [88.74727631, 21.58634949], [88.74742126, 21.58580971], [88.74740601, 21.58530998], [88.74727631, 21.58486176], [88.74724579, 21.58443832], [88.74729156, 21.58399963], [88.74738312, 21.5835762], [88.74729919, 21.58310127], [88.74723816, 21.58255959], [88.7472229, 21.5819397], [88.7472229, 21.58134079], [88.7472229, 21.58078957], [88.7472229, 21.58029938], [88.7472229, 21.57985115], [88.7472229, 21.57971954], [88.7472229, 21.57833481], [88.74694824, 21.57806015], [88.74694824, 21.57749939], [88.74666595, 21.57749939], [88.74555206, 21.57639122], [88.74500275, 21.57639122], [88.74472046, 21.57611084], [88.74415588, 21.57611084], [88.74388885, 21.57583046], [88.74305725, 21.57583046], [88.74276733, 21.57611084], [88.7416687, 21.57611084], [88.74138641, 21.57583046], [88.7408371, 21.57583237], [88.74028015, 21.57527733], [88.74028778, 21.57500076], [88.7408371, 21.57444382], [88.7408371, 21.57388878], [88.74111176, 21.57361031], [88.74054718, 21.5730629], [88.74028015, 21.57333374], [88.73999786, 21.57333374], [88.73972321, 21.57305527], [88.7388916, 21.5730629], [88.73860931, 21.57278252], [88.73832703, 21.57278252], [88.73805237, 21.5730629], [88.73722076, 21.5730629], [88.73583221, 21.57167244], [88.73555756, 21.57167244], [88.7352829, 21.57195282], [88.73472595, 21.57195282], [88.73388672, 21.57278252], [88.73221588, 21.57278252], [88.73194122, 21.5730629], [88.73139191, 21.5730629], [88.73111725, 21.57278252], [88.73027802, 21.57278252], [88.73000336, 21.5730629], [88.72833252, 21.57305527], [88.72805786, 21.57333374], [88.72638702, 21.57333183], [88.72611237, 21.57361031], [88.72583008, 21.57361031], [88.72556305, 21.57389069], [88.72499084, 21.57389069], [88.72471619, 21.57417107], [88.72389221, 21.57417107], [88.7233429, 21.57361031], [88.72305298, 21.57361031], [88.72222137, 21.57444382], [88.72166443, 21.57444382], [88.72138977, 21.57472229], [88.72083282, 21.57472038], [88.72055817, 21.57500076], [88.72027588, 21.57500076], [88.72000122, 21.57528114], [88.71943665, 21.57528114], [88.71833038, 21.57639122], [88.71806335, 21.57639122], [88.71778107, 21.57666969], [88.71722412, 21.57666588], [88.71694183, 21.57694244], [88.71666718, 21.57694244], [88.71639252, 21.57722473], [88.71611786, 21.57722092], [88.71499634, 21.57834053], [88.71444702, 21.57833481], [88.7141571, 21.57860947], [88.7141571, 21.57888985], [88.71389008, 21.57916451], [88.71389008, 21.57971954], [88.71333313, 21.5802803], [88.71333313, 21.58055687], [88.71305847, 21.58083344], [88.71333313, 21.58111191], [88.71305084, 21.58138084], [88.71305084, 21.58167076], [88.71221924, 21.58250046], [88.71221924, 21.58278084], [88.71194458, 21.58277893], [88.71138763, 21.58332825], [88.71138763, 21.58361053], [88.71111298, 21.58389091], [88.71111298, 21.58416748], [88.71083069, 21.58444405], [88.71083069, 21.58472061], [88.71055603, 21.58499908], [88.71055603, 21.58527756], [88.70999146, 21.58583069], [88.70999146, 21.58610916], [88.70944214, 21.58667183], [88.70948029, 21.5869503], [88.70940399, 21.58732605], [88.70928192, 21.58765411], [88.70913696, 21.58797264], [88.70892334, 21.58828163], [88.70865631, 21.58860016], [88.70849609, 21.58898544], [88.70832825, 21.5893383], [88.70818329, 21.5897007], [88.70802307, 21.59007072], [88.70793915, 21.59044647], [88.707901, 21.59082985], [88.7078476, 21.5912075], [88.70774078, 21.5915947], [88.70770264, 21.5920105], [88.70767212, 21.59245491], [88.70761108, 21.59287071], [88.70748901, 21.59324074], [88.70735931, 21.59355927], [88.70726013, 21.59387016], [88.70720673, 21.59422112], [88.70720673, 21.59459114], [88.70720673, 21.59495926], [88.70723724, 21.59530258], [88.70730591, 21.59562111], [88.70752716, 21.59589005], [88.70781708, 21.59613037], [88.70809937, 21.59638023], [88.70841217, 21.59662056], [88.70871735, 21.59683037], [88.70889282, 21.59709167], [88.70904541, 21.59734535], [88.70917511, 21.59749222], [88.70916748, 21.59972191], [88.70944214, 21.60000038], [88.70944214, 21.60055542], [88.7097168, 21.60083008], [88.7097168, 21.60111046], [88.70999908, 21.60138893], [88.70999146, 21.6047802], [88.70999146, 21.60639], [88.71028137, 21.60667038], [88.71028137, 21.60694695], [88.71055603, 21.6072197], [88.71055603, 21.61000061], [88.71111298, 21.61055565], [88.71111298, 21.6108284], [88.71138763, 21.61111069], [88.71138763, 21.61166573], [88.71166992, 21.6119442], [88.71166992, 21.61222076], [88.71138763, 21.61249924], [88.71138763, 21.61277962], [88.71111298, 21.6130619], [88.71111298, 21.61388969], [88.71138763, 21.61417007], [88.71138763, 21.61444473], [88.71134186, 21.61497116], [88.71166992, 21.61527824], [88.71166992, 21.61611176], [88.71185303, 21.61629677], [88.71221924, 21.61667061], [88.71277618, 21.61666679], [88.71277618, 21.61722183], [88.71305084, 21.61749077], [88.71305084, 21.61889076], [88.71277618, 21.61916733], [88.71277618, 21.61972046], [88.71250153, 21.62000084], [88.71250153, 21.6202755], [88.71193695, 21.62083054], [88.71193695, 21.62111092], [88.71250153, 21.62166977], [88.71277618, 21.62166786], [88.71305847, 21.62194443], [88.71333313, 21.62194443], [88.71360779, 21.62222099], [88.71360779, 21.62249947], [88.71333313, 21.62277985], [88.71333313, 21.62305641], [88.71305084, 21.62333107], [88.71305084, 21.62388992], [88.71277618, 21.62416649], [88.71277618, 21.62471771], [88.71305084, 21.62500191], [88.71305084, 21.62528038], [88.71333313, 21.62555504], [88.71333313, 21.6258316], [88.71389008, 21.62639046], [88.71389008, 21.62668037], [88.71499634, 21.6277771], [88.71499634, 21.62833214], [88.71527863, 21.62833023], [88.71527863, 21.62916756], [88.71555328, 21.62944221], [88.71555328, 21.62972069], [88.7158432, 21.63000107], [88.7158432, 21.63027954], [88.71611023, 21.6305542], [88.71611786, 21.63083076], [88.71639252, 21.63111115], [88.71639252, 21.63138962], [88.71666718, 21.63166428], [88.71666718, 21.63194656], [88.71694183, 21.63222313], [88.71694183, 21.63249969], [88.71778107, 21.63333321], [88.71916962, 21.63333321], [88.71943665, 21.63305092], [88.71943665, 21.63417053], [88.71971893, 21.63444519], [88.71971893, 21.63471985], [88.72000122, 21.63500023], [88.72000122, 21.63555527], [88.72027588, 21.63582993], [88.72027588, 21.63777733], [88.72083282, 21.63833427], [88.72194672, 21.63833427], [88.7223587, 21.63824654], [88.72281647, 21.63801003], [88.72319031, 21.63764191], [88.72357941, 21.63737106], [88.72399902, 21.63718796], [88.72445679, 21.63705063], [88.72501373, 21.63704491], [88.72554779, 21.63714981], [88.72606659, 21.63728905], [88.72655487, 21.63751602], [88.72704315, 21.63780022], [88.72749329, 21.63812065], [88.72795105, 21.63836098], [88.72836304, 21.63834953], [88.72860718, 21.63801956], [88.72879028, 21.63758278], [88.72885132, 21.63708115]]], [[[88.77194214, 21.65306282], [88.77249908, 21.65250015], [88.77278137, 21.65250015], [88.77278137, 21.65222168], [88.77222443, 21.65166664], [88.7722168, 21.65138817], [88.77388763, 21.64972115], [88.77388763, 21.64916611], [88.77416992, 21.64888954], [88.77416992, 21.64833069], [88.77333069, 21.64749718], [88.77471924, 21.64750099], [88.77555847, 21.64666939], [88.77555847, 21.64528084], [88.77527618, 21.64500046], [88.77500153, 21.64500046], [88.77500153, 21.64472008], [88.77555847, 21.64416695], [88.77555847, 21.64361], [88.77500153, 21.64305305], [88.77497864, 21.64275932], [88.77471924, 21.64249992], [88.77333069, 21.64249992], [88.77333069, 21.64221954], [88.77249908, 21.64222145], [88.77194214, 21.64166641], [88.77194214, 21.64138985], [88.77278137, 21.64056015], [88.77278137, 21.64027977], [88.77305603, 21.63999939], [88.77278137, 21.63972282], [88.77278137, 21.63666725], [88.7722168, 21.63611031], [88.77166748, 21.63611031], [88.77139282, 21.63582993], [88.77111053, 21.63583374], [88.77111053, 21.63555527], [88.77083588, 21.63528061], [88.77083588, 21.63500023], [88.77054596, 21.63471985], [88.77055359, 21.63138962], [88.77111053, 21.63083076], [88.77111053, 21.62805557], [88.77166748, 21.62750053], [88.77166748, 21.62722015], [88.77249908, 21.62638855], [88.77249908, 21.62556267], [88.7722168, 21.62528038], [88.7722168, 21.62471771], [88.77249908, 21.62444496], [88.77249908, 21.6241684], [88.77278137, 21.62388992], [88.77278137, 21.62333107], [88.77305603, 21.62305641], [88.77305603, 21.62249947], [88.77333069, 21.62222099], [88.77333069, 21.62194443], [88.77361298, 21.62166786], [88.77361298, 21.62138939], [88.77388763, 21.62111092], [88.77388763, 21.61972046], [88.77462006, 21.61899185], [88.77583313, 21.61777687], [88.77639008, 21.61778069], [88.77694702, 21.61721992], [88.77694702, 21.61666679], [88.77722168, 21.61639023], [88.77694702, 21.61610985], [88.77694702, 21.61583138], [88.77639008, 21.61527824], [88.77639008, 21.61510086], [88.77639008, 21.61499977], [88.77749634, 21.61499977], [88.77777863, 21.61471939], [88.77805328, 21.6147213], [88.77861023, 21.61416626], [88.77889252, 21.61417007], [88.77916718, 21.61388969], [88.77944183, 21.61388969], [88.78028107, 21.6130619], [88.78083038, 21.6130619], [88.78115082, 21.61252975], [88.7815094, 21.61211967], [88.78192139, 21.61172104], [88.782341, 21.61130905], [88.78250122, 21.61111069], [88.78333282, 21.61027908], [88.78333282, 21.61000061], [88.7841568, 21.60917091], [88.78472137, 21.60917091], [88.78491211, 21.60868835], [88.78524017, 21.60834122], [88.78557587, 21.60795021], [88.78591919, 21.60757065], [88.78627777, 21.60724068], [88.78663635, 21.60691261], [88.78694916, 21.6065197], [88.7872467, 21.60611725], [88.78756714, 21.60573959], [88.78795624, 21.60536957], [88.78842926, 21.6049633], [88.78890228, 21.60449982], [88.78936005, 21.60408974], [88.78943634, 21.60388947], [88.79055786, 21.60277939], [88.79055786, 21.60222054], [88.79083252, 21.60194206], [88.79083252, 21.6016674], [88.79065704, 21.60145187], [88.79042053, 21.6012001], [88.79021454, 21.60095215], [88.78992462, 21.60072708], [88.78965759, 21.60050011], [88.78933716, 21.60029984], [88.78896332, 21.60013962], [88.78855896, 21.59997749], [88.78843689, 21.5999279], [88.78813934, 21.59980392], [88.7877121, 21.5996151], [88.78730774, 21.59939957], [88.78691864, 21.59915924], [88.78652191, 21.5989399], [88.78607941, 21.59877205], [88.78566742, 21.59855843], [88.7852478, 21.59833145], [88.78481293, 21.59811974], [88.78449249, 21.59794235], [88.78444672, 21.59805489], [88.78434753, 21.59795761], [88.78416443, 21.59777832], [88.78360748, 21.59777832], [88.78333282, 21.59749985], [88.78305817, 21.59749985], [88.78277588, 21.59721756], [88.78250122, 21.59722137], [88.78221893, 21.59694481], [88.78221893, 21.5961113], [88.78283691, 21.59628105], [88.78340912, 21.59641266], [88.78388214, 21.59657097], [88.78430176, 21.59669113], [88.78468323, 21.59684944], [88.78508759, 21.59701538], [88.78553772, 21.59720993], [88.786026, 21.59744263], [88.78658295, 21.59765053], [88.78713226, 21.5978508], [88.78764343, 21.59804726], [88.78813171, 21.5982399], [88.78859711, 21.59842873], [88.78896332, 21.59869194], [88.78930664, 21.59897804], [88.78951263, 21.59910774], [88.78972626, 21.59924126], [88.79019928, 21.59950638], [88.79071808, 21.59976959], [88.79123688, 21.59979248], [88.79178619, 21.59959984], [88.79239655, 21.59947968], [88.79309845, 21.59954453], [88.79373169, 21.59972954], [88.79425049, 21.59977913], [88.7947464, 21.59935951], [88.79510498, 21.5987587], [88.79519653, 21.59813499], [88.79528046, 21.59804916], [88.79528046, 21.59777832], [88.79556274, 21.59749985], [88.79555511, 21.59722137], [88.79582977, 21.59694481], [88.79582977, 21.59666634], [88.79638672, 21.59610939], [88.79638672, 21.59555626], [88.79666901, 21.59527969], [88.79666901, 21.59472084], [88.79694366, 21.59444427], [88.79722595, 21.59444427], [88.79722595, 21.59416771], [88.7977829, 21.59361076], [88.79777527, 21.59222221], [88.79805756, 21.59194565], [88.79805756, 21.59166527], [88.7977829, 21.59139061], [88.7977829, 21.59111023], [88.79750061, 21.59083557], [88.79750061, 21.59055328], [88.79722595, 21.59028053], [88.79722595, 21.59000015], [88.79638672, 21.58917046], [88.79638672, 21.58889008], [88.79611206, 21.5886097], [88.79611206, 21.58805466], [88.79555511, 21.58749962], [88.79556274, 21.58722115], [88.79416656, 21.5858326], [88.79389191, 21.5858326], [88.79292297, 21.58486366], [88.79194641, 21.58389091], [88.79165649, 21.58389091], [88.79089355, 21.58311653], [88.79027557, 21.58250046], [88.79027557, 21.58222198], [88.79000092, 21.58194351], [88.78916931, 21.58194351], [88.78833008, 21.58111191], [88.78833008, 21.58083344], [88.78805542, 21.58083344], [88.78778076, 21.58055687], [88.78666687, 21.58056068], [88.78639221, 21.5802803], [88.78527069, 21.5802803], [88.78499603, 21.57999992], [88.78472137, 21.57999992], [88.78444672, 21.5802803], [88.78360748, 21.5802803], [88.78333282, 21.57999992], [88.7822113, 21.57999992], [88.78193665, 21.5802803], [88.78056335, 21.5802803], [88.78028107, 21.57999992], [88.77971649, 21.57999992], [88.77944183, 21.5802803], [88.77861023, 21.5802803], [88.77855682, 21.58022499], [88.7783432, 21.57999992], [88.77777863, 21.57999992], [88.77749634, 21.57971954], [88.77722168, 21.57972145], [88.77694702, 21.57944679], [88.77666473, 21.57944679], [88.77639008, 21.57972145], [88.77555847, 21.57972145], [88.77500153, 21.57916451], [88.77471924, 21.57917023], [88.77443695, 21.57888985], [88.77388763, 21.57888985], [88.77361298, 21.57860947], [88.77333069, 21.57861137], [88.77305603, 21.57833481], [88.77249908, 21.57834053], [88.7722168, 21.57806015], [88.77054596, 21.57806015], [88.7702713, 21.57777977], [88.76999664, 21.57777977], [88.76972198, 21.57749939], [88.76944733, 21.57749939], [88.76917267, 21.57722092], [88.76860809, 21.57722473], [88.76833344, 21.57694244], [88.76721954, 21.57694244], [88.76694489, 21.57666588], [88.76638794, 21.57666969], [88.76611328, 21.57639122], [88.76583099, 21.57639122], [88.76555634, 21.57611084], [88.7638855, 21.57611084], [88.76361084, 21.57583237], [88.76194763, 21.57583237], [88.76167297, 21.57611084], [88.75805664, 21.57611084], [88.75776672, 21.57583046], [88.75611115, 21.57583046], [88.75583649, 21.57611084], [88.75499725, 21.57611084], [88.75444794, 21.57666969], [88.7519455, 21.57666588], [88.75166321, 21.57694244], [88.75110626, 21.57694054], [88.75055695, 21.57749939], [88.75026703, 21.57749939], [88.74944305, 21.57833481], [88.74944305, 21.57860947], [88.74916077, 21.57888985], [88.7491684, 21.57916451], [88.74888611, 21.57944107], [88.74888611, 21.5802803], [88.74861145, 21.58055687], [88.74888611, 21.58082962], [88.74888611, 21.58166885], [88.74861145, 21.5819397], [88.74861908, 21.58267021], [88.74861145, 21.58331108], [88.74861145, 21.58396149], [88.74861145, 21.58460045], [88.74861908, 21.58523941], [88.74864197, 21.58587646], [88.74869537, 21.58650398], [88.748703, 21.58711052], [88.74868011, 21.58768845], [88.74876404, 21.58821678], [88.74887085, 21.5887146], [88.74894714, 21.58918953], [88.74909973, 21.58963013], [88.7492218, 21.59010506], [88.74944305, 21.59059334], [88.74971008, 21.59111595], [88.75002289, 21.59165192], [88.75040436, 21.59214973], [88.75086975, 21.59259415], [88.75137329, 21.59299469], [88.75195313, 21.59332085], [88.75248718, 21.59362984], [88.75300598, 21.59395981], [88.753479, 21.59431839], [88.75395203, 21.59468651], [88.75449371, 21.59501266], [88.75508118, 21.59527969], [88.75565338, 21.595541], [88.75613403, 21.59579468], [88.75621033, 21.59580421], [88.7563858, 21.59583282], [88.75666809, 21.5961113], [88.75694275, 21.5961113], [88.75805664, 21.59721756], [88.75805664, 21.59749985], [88.75836182, 21.5981102], [88.75850677, 21.59867859], [88.75847626, 21.59922028], [88.75836182, 21.59966278], [88.75823975, 21.60003853], [88.75805664, 21.6003437], [88.75782776, 21.60067177], [88.75756836, 21.60104561], [88.75717926, 21.60141182], [88.75669861, 21.60182953], [88.75617981, 21.60229874], [88.75565338, 21.60277367], [88.75512695, 21.60321045], [88.7546463, 21.60362053], [88.75417328, 21.60400009], [88.75366974, 21.60434723], [88.75306702, 21.60464287], [88.75238037, 21.60487938], [88.75167847, 21.60514069], [88.75096893, 21.60542107], [88.75025177, 21.60565948], [88.74952698, 21.60589027], [88.74884033, 21.60612869], [88.74820709, 21.60638428], [88.747612, 21.60663033], [88.74700165, 21.60684013], [88.74635315, 21.60695076], [88.74568176, 21.60705948], [88.74505615, 21.60725021], [88.7444458, 21.60749054], [88.74384308, 21.60771751], [88.74317932, 21.60787773], [88.7425766, 21.60808182], [88.74204254, 21.60832024], [88.74151611, 21.60859108], [88.7410202, 21.60881805], [88.7405014, 21.6089859], [88.74002075, 21.60920334], [88.7395401, 21.60945129], [88.73903656, 21.60972023], [88.73851776, 21.61001968], [88.73796844, 21.61037827], [88.73744965, 21.61084938], [88.73693085, 21.61137009], [88.7364502, 21.6118927], [88.73607635, 21.61240959], [88.73575592, 21.61288071], [88.73555756, 21.61333847], [88.73539734, 21.61376953], [88.73529053, 21.61419106], [88.73517609, 21.61461067], [88.73506927, 21.61501312], [88.73501587, 21.6154747], [88.73500824, 21.61595154], [88.73500824, 21.61642838], [88.73501587, 21.61688042], [88.73500824, 21.61730003], [88.73500824, 21.61770058], [88.73500824, 21.61809158], [88.73500824, 21.61847115], [88.73500824, 21.61888123], [88.73501587, 21.61931992], [88.73501587, 21.61977959], [88.73505402, 21.62023735], [88.73512268, 21.62068939], [88.73523712, 21.62114716], [88.73529816, 21.62162018], [88.73539734, 21.62207985], [88.73555756, 21.62222099], [88.73555756, 21.62277985], [88.73610687, 21.62333107], [88.73610687, 21.62361908], [88.73555756, 21.6241684], [88.73555756, 21.62445068], [88.73527527, 21.62488937], [88.7350769, 21.6252346], [88.73493958, 21.62556267], [88.73475647, 21.6258316], [88.73460388, 21.62612915], [88.73442841, 21.6264801], [88.73419189, 21.62689972], [88.7338562, 21.62733078], [88.7334671, 21.62778854], [88.73306274, 21.62825012], [88.73264313, 21.62869644], [88.7322998, 21.62914085], [88.73205566, 21.62964821], [88.7318573, 21.63015938], [88.73162079, 21.63070107], [88.73132324, 21.63124657], [88.73108673, 21.63188171], [88.73086548, 21.63251114], [88.73068237, 21.63310051], [88.73052216, 21.63367081], [88.73039246, 21.63414764], [88.73036957, 21.63466072], [88.73031616, 21.63516045], [88.73029327, 21.63569069], [88.73027039, 21.63624954], [88.73020935, 21.63680267], [88.73007202, 21.63731384], [88.72998047, 21.63783455], [88.7298584, 21.63834953], [88.72970581, 21.63887978], [88.72955322, 21.63941002], [88.72956848, 21.6399498], [88.72982025, 21.64040947], [88.7301712, 21.64079094], [88.73058319, 21.64115906], [88.73104095, 21.64154053], [88.7315979, 21.64189529], [88.73206329, 21.64218712], [88.73219299, 21.64226913], [88.73277283, 21.64269829], [88.7333374, 21.64314079], [88.73390961, 21.64357758], [88.73448944, 21.64396858], [88.73503113, 21.64432907], [88.73558044, 21.64463615], [88.73618317, 21.6448307], [88.73686981, 21.64491272], [88.73757172, 21.64492989], [88.73826599, 21.64492035], [88.73895264, 21.64488029], [88.73961639, 21.64481926], [88.74028015, 21.64481354], [88.74092865, 21.64480972], [88.74158478, 21.64481735], [88.74230194, 21.64483261], [88.74301147, 21.6448307], [88.74371338, 21.6448307], [88.7443924, 21.64485741], [88.74505615, 21.64492989], [88.74565125, 21.64505959], [88.74620056, 21.64517784], [88.74672699, 21.64528275], [88.74721527, 21.64541054], [88.74769592, 21.64550972], [88.74819946, 21.64562035], [88.74871826, 21.64575958], [88.74928284, 21.64596939], [88.74978638, 21.64624977], [88.75022125, 21.64657021], [88.75060272, 21.64688873], [88.75097656, 21.64719009], [88.75135803, 21.64750099], [88.75173187, 21.64783859], [88.75211334, 21.64807129], [88.75251007, 21.64833832], [88.7529068, 21.64861107], [88.75334167, 21.64888954], [88.75379944, 21.64916611], [88.75430298, 21.64944077], [88.75483704, 21.64972115], [88.75540161, 21.64998245], [88.75598907, 21.65019035], [88.75656128, 21.65048981], [88.75723267, 21.65060043], [88.75784302, 21.65083694], [88.75844574, 21.6511097], [88.75904083, 21.65135956], [88.75966644, 21.65152931], [88.76022339, 21.6518116], [88.76074982, 21.65216255], [88.76126862, 21.65254974], [88.76177216, 21.65301514], [88.76242828, 21.65333176], [88.7631073, 21.65357018], [88.76380157, 21.65365982], [88.76438141, 21.65390968], [88.76490021, 21.65421104], [88.76539612, 21.65455055], [88.76608276, 21.65470123], [88.76679993, 21.65478897], [88.76743317, 21.65501022], [88.76805115, 21.65528107], [88.76867676, 21.65552139], [88.76931763, 21.65559196], [88.76985931, 21.65556717], [88.77033234, 21.65500069], [88.77073669, 21.65455055], [88.77110291, 21.65428925], [88.77142334, 21.65402985], [88.77171326, 21.65369987], [88.77201843, 21.65334702], [88.77194214, 21.65306282]]], [[[88.89235687, 21.65209007], [88.89261627, 21.65167236], [88.89290619, 21.65138817], [88.89375305, 21.65055847], [88.89389038, 21.65027809], [88.89444733, 21.64972115], [88.89389038, 21.64916611], [88.89333344, 21.64916611], [88.89305878, 21.64944458], [88.89277649, 21.64944458], [88.89250183, 21.64972115], [88.89250183, 21.64999962], [88.89138794, 21.6511116], [88.89111328, 21.6511097], [88.89083099, 21.65138817], [88.89083099, 21.65167236], [88.89055634, 21.65195274], [88.89027405, 21.65194511], [88.89027405, 21.65222168], [88.88916779, 21.65333176], [88.88916779, 21.65361977], [88.88889313, 21.65389061], [88.88887024, 21.6541729], [88.88900757, 21.65457344], [88.88944244, 21.65457344], [88.88999939, 21.65447044], [88.89150238, 21.65306282], [88.89164734, 21.65278053], [88.89192963, 21.65250015], [88.89235687, 21.65209007]]], [[[89.01072693, 21.65061951], [89.01094055, 21.65076065], [89.01129913, 21.65102959], [89.01158142, 21.65122986], [89.01180267, 21.65122795], [89.01208496, 21.65129471], [89.01222992, 21.65136147], [89.01265717, 21.65142822], [89.01280212, 21.65149689], [89.01307678, 21.65155983], [89.01330566, 21.65169716], [89.01402283, 21.65209961], [89.01436615, 21.65244293], [89.01465607, 21.65263939], [89.01487732, 21.65290833], [89.01509094, 21.6531105], [89.01538086, 21.65331078], [89.01558685, 21.65337944], [89.01587677, 21.65337944], [89.01602173, 21.65357971], [89.01631165, 21.65392113], [89.0165863, 21.65411949], [89.01673889, 21.65431976], [89.01702881, 21.65452385], [89.01740265, 21.65493011], [89.01760864, 21.65499878], [89.01798248, 21.65511513], [89.01825714, 21.65520287], [89.0189743, 21.65526772], [89.01940155, 21.65533447], [89.01993561, 21.65525436], [89.02031708, 21.65503311], [89.02073669, 21.65492249], [89.02114868, 21.65476036], [89.02159119, 21.65471077], [89.02204895, 21.65460014], [89.02243805, 21.65436172], [89.02275848, 21.65402603], [89.0230484, 21.65359116], [89.02333832, 21.65314293], [89.02361298, 21.65273094], [89.02349091, 21.65236092], [89.02313232, 21.65209007], [89.0229187, 21.65122032], [89.02276611, 21.65081024], [89.02277374, 21.64933205], [89.02220154, 21.64852524], [89.02220154, 21.6473217], [89.02213287, 21.64692116], [89.02198029, 21.64624023], [89.02191162, 21.64583969], [89.02175903, 21.64526939], [89.021698, 21.64476013], [89.02162933, 21.64416122], [89.02133942, 21.64355087], [89.02127075, 21.64307976], [89.02118683, 21.64226913], [89.02127075, 21.64159966], [89.02133942, 21.64113045], [89.02133942, 21.64079094], [89.02140808, 21.63985062], [89.02140808, 21.63953018], [89.02140808, 21.63906097], [89.02176666, 21.63832855], [89.02194214, 21.63798332], [89.02204895, 21.63777924], [89.02218628, 21.6371727], [89.02226257, 21.63650131], [89.02233887, 21.63609505], [89.02269745, 21.63562965], [89.02276611, 21.63521767], [89.02297974, 21.63482094], [89.02311707, 21.63462067], [89.02340698, 21.63414955], [89.02355194, 21.63388062], [89.0236969, 21.6334095], [89.02423096, 21.63240051], [89.02439117, 21.6319809], [89.02458954, 21.63153076], [89.02484894, 21.63111115], [89.02513885, 21.63070679], [89.02549744, 21.6303215], [89.02583313, 21.62988853], [89.02617645, 21.62947083], [89.02654266, 21.62911987], [89.0266571, 21.62897491], [89.02681732, 21.62876892], [89.02715302, 21.62854958], [89.02742767, 21.62830925], [89.02765656, 21.62808228], [89.02792358, 21.62791252], [89.02818298, 21.62779045], [89.02840424, 21.62772751], [89.02857208, 21.62759972], [89.02879333, 21.62751007], [89.02910614, 21.62746811], [89.02953339, 21.62733078], [89.03003693, 21.62724113], [89.03061676, 21.62718964], [89.03116608, 21.62702942], [89.03166962, 21.62691689], [89.03206635, 21.6267128], [89.03245544, 21.62656784], [89.03279877, 21.62636948], [89.0331192, 21.62616158], [89.03350067, 21.62594795], [89.03392792, 21.62570953], [89.03444672, 21.62549019], [89.03501129, 21.6252594], [89.03575897, 21.62464905], [89.03604889, 21.62424088], [89.03626251, 21.62384033], [89.03633118, 21.62350082], [89.03640747, 21.62317085], [89.03647614, 21.62282944], [89.03647614, 21.62148094], [89.03642273, 21.62120438], [89.03636932, 21.62097168], [89.03614807, 21.6207695], [89.03601074, 21.6206398], [89.03585815, 21.62029839], [89.03585815, 21.62015915], [89.03614807, 21.61996269], [89.03629303, 21.61982918], [89.03665161, 21.61976051], [89.03679657, 21.61951065], [89.03707886, 21.61901283], [89.03734589, 21.61856842], [89.03749084, 21.61812973], [89.03753662, 21.61761093], [89.03753662, 21.61660004], [89.03748322, 21.61613083], [89.03739929, 21.61552048], [89.0372467, 21.61485291], [89.0372467, 21.61458015], [89.03660583, 21.61355972], [89.03638458, 21.61330986], [89.03601074, 21.61281013], [89.0356369, 21.61235046], [89.03533936, 21.61190987], [89.03509521, 21.61158371], [89.03503418, 21.6115036], [89.03472137, 21.61109161], [89.03439331, 21.61065292], [89.03399658, 21.61024094], [89.033638, 21.60983086], [89.03327942, 21.60941124], [89.03292847, 21.60902405], [89.03258514, 21.60866737], [89.03141022, 21.60798073], [89.03105164, 21.60764503], [89.03048706, 21.60718155], [89.03003693, 21.60684013], [89.02976227, 21.60650063], [89.02947998, 21.60609818], [89.02905273, 21.60509109], [89.02876282, 21.60482216], [89.02832031, 21.60486412], [89.02760315, 21.60493279], [89.02703094, 21.60493279], [89.02610016, 21.60453033], [89.02574158, 21.60425949], [89.02545166, 21.60399246], [89.02502441, 21.60385895], [89.02437592, 21.60353279], [89.02394867, 21.60332108], [89.02345276, 21.6031208], [89.02274323, 21.60292053], [89.02237701, 21.60277939], [89.02159119, 21.60264778], [89.02130127, 21.60264778], [89.02101135, 21.60251236], [89.02072906, 21.60251236], [89.02060699, 21.60251045], [89.02032471, 21.60263634], [89.02015686, 21.60267448], [89.02003479, 21.60270119], [89.019104, 21.60270119], [89.0185318, 21.60256958], [89.01817322, 21.60251045], [89.01766205, 21.60237122], [89.01716614, 21.60223007], [89.01695251, 21.60223007], [89.0165863, 21.60230064], [89.01631165, 21.60230064], [89.01595306, 21.60243034], [89.01573944, 21.60264015], [89.0152359, 21.6030426], [89.01494598, 21.60331154], [89.01465607, 21.60331154], [89.01409149, 21.60316849], [89.01402283, 21.60297012], [89.01380157, 21.60283852], [89.01344299, 21.60223007], [89.01287079, 21.60203171], [89.01222992, 21.6020298], [89.01187134, 21.60209846], [89.01158142, 21.60223579], [89.01129913, 21.60223579], [89.01087189, 21.60209846], [89.01065063, 21.60197067], [89.01022339, 21.60182953], [89.00979614, 21.60182953], [89.00958252, 21.60189438], [89.00936127, 21.60203171], [89.00901031, 21.60223579], [89.00850677, 21.60223579], [89.00821686, 21.60216331], [89.00746918, 21.60217094], [89.00704956, 21.60214615], [89.00647736, 21.60244179], [89.00650024, 21.60330391], [89.00641632, 21.60337067], [89.00602722, 21.60331154], [89.00563049, 21.60296059], [89.00520325, 21.60284996], [89.00488281, 21.60248184], [89.00445557, 21.6020298], [89.00392151, 21.60188293], [89.00359344, 21.60206795], [89.00295258, 21.60223579], [89.00244141, 21.60231209], [89.00199127, 21.60216522], [89.0014801, 21.60204124], [89.00086975, 21.60207176], [89.00026703, 21.60209084], [89.0, 21.60167122], [88.99972534, 21.60207176], [88.99967194, 21.60242271], [88.99888611, 21.60251045], [88.99868011, 21.60309601], [88.99850464, 21.60324287], [88.99836731, 21.60370827], [88.99806976, 21.60474014], [88.99852753, 21.60639954], [88.99867249, 21.6066761], [88.99860382, 21.60680199], [88.99868011, 21.6072197], [88.99888611, 21.60833359], [88.99861145, 21.60861206], [88.99861145, 21.60944366], [88.9985733, 21.60996056], [88.99861145, 21.61027718], [88.99841309, 21.61083412], [88.99855804, 21.61124992], [88.99833679, 21.61168289], [88.99833679, 21.61361122], [88.9983902, 21.61420822], [88.99835968, 21.61468124], [88.99833679, 21.61515045], [88.99833679, 21.61562729], [88.99833679, 21.61611176], [88.99833679, 21.6165905], [88.99833679, 21.61707115], [88.99833679, 21.6175251], [88.99832916, 21.61796188], [88.99830627, 21.61839294], [88.99820709, 21.61882973], [88.99809265, 21.61930084], [88.9980545, 21.61984253], [88.99804688, 21.62044144], [88.99804688, 21.62107277], [88.99804688, 21.62166977], [88.99803162, 21.62220955], [88.99794769, 21.62265968], [88.99781036, 21.62304115], [88.99777222, 21.6233902], [88.9977417, 21.62369919], [88.99762726, 21.62397957], [88.99752045, 21.62435532], [88.99746704, 21.62477112], [88.99732971, 21.6251812], [88.99723053, 21.62560081], [88.99713135, 21.62602806], [88.99697876, 21.62642097], [88.99690247, 21.62686539], [88.99671173, 21.62725067], [88.99637604, 21.62776756], [88.99664307, 21.62829971], [88.99658966, 21.62884521], [88.99642944, 21.62935448], [88.9963913, 21.62991333], [88.99636841, 21.63047218], [88.99632263, 21.63100243], [88.99614716, 21.63152122], [88.99603271, 21.63210106], [88.99585724, 21.6326828], [88.99581909, 21.63330841], [88.9957428, 21.63390923], [88.99558258, 21.63445663], [88.99549103, 21.63500023], [88.99531555, 21.6355381], [88.99524689, 21.63612938], [88.99513245, 21.63669586], [88.99500275, 21.6371994], [88.99484253, 21.63765526], [88.99474335, 21.63807106], [88.99446869, 21.63839912], [88.9942627, 21.63879013], [88.9941864, 21.63935089], [88.994133, 21.63993263], [88.99402618, 21.64042664], [88.993927, 21.64087486], [88.99384308, 21.64129066], [88.99369049, 21.64163017], [88.99356079, 21.64195061], [88.99340057, 21.6422596], [88.9932785, 21.64262009], [88.9930954, 21.64298248], [88.99289703, 21.64336014], [88.99264526, 21.64374924], [88.99236298, 21.64414024], [88.99201202, 21.64451981], [88.99163055, 21.64488029], [88.99120331, 21.6451683], [88.99072266, 21.64536667], [88.99019623, 21.64551926], [88.98961639, 21.64565086], [88.9890213, 21.64583015], [88.98835754, 21.64599991], [88.98758698, 21.64606857], [88.98678589, 21.64608955], [88.98597717, 21.64609146], [88.98516846, 21.64608192], [88.984375, 21.64603424], [88.98361969, 21.64593315], [88.9828949, 21.64591217], [88.98222351, 21.64580154], [88.98159027, 21.6456604], [88.9809494, 21.64557076], [88.98029327, 21.64552879], [88.97962189, 21.64545059], [88.97895813, 21.64530563], [88.97827148, 21.6451683], [88.97762299, 21.64495087], [88.97702026, 21.64470291], [88.97641754, 21.6444397], [88.97583008, 21.64418411], [88.97523499, 21.64396667], [88.97464752, 21.64377975], [88.97410583, 21.64356995], [88.97360992, 21.64332008], [88.97312927, 21.6430397], [88.97266388, 21.64276695], [88.97220612, 21.64250946], [88.9717865, 21.6423111], [88.97142029, 21.64213943], [88.97109985, 21.64199066], [88.97071838, 21.64191818], [88.97027588, 21.64185905], [88.96981812, 21.64173126], [88.9696579, 21.6417141], [88.96933746, 21.64167976], [88.96885681, 21.64167976], [88.96839905, 21.64169884], [88.96798706, 21.64178085], [88.96762848, 21.64196014], [88.9673233, 21.64215279], [88.96689606, 21.6424408], [88.96649933, 21.64270592], [88.96613312, 21.64302063], [88.96575165, 21.64334106], [88.96535492, 21.64364815], [88.96518707, 21.64383125], [88.96499634, 21.64403915], [88.96470642, 21.64450073], [88.96444702, 21.64495087], [88.96421051, 21.6453495], [88.96401978, 21.64574051], [88.96385956, 21.64612961], [88.96370697, 21.64651108], [88.96360016, 21.64694977], [88.96347809, 21.64743042], [88.96338654, 21.64796638], [88.96330261, 21.64854813], [88.96318054, 21.6491394], [88.96311951, 21.64971733], [88.96311188, 21.65027809], [88.96312714, 21.65087128], [88.9631958, 21.65150642], [88.96325684, 21.65220261], [88.9631958, 21.65295982], [88.96321869, 21.65377998], [88.96331787, 21.65459061], [88.96341705, 21.65537071], [88.96355438, 21.65607834], [88.96361542, 21.65654182], [88.96363831, 21.65674973], [88.96372986, 21.65735054], [88.9638443, 21.65787506], [88.96389771, 21.65836143], [88.96391296, 21.65881348], [88.96390533, 21.65924263], [88.96385193, 21.65966225], [88.96372986, 21.66007233], [88.96366119, 21.66055107], [88.96360016, 21.66104889], [88.96350861, 21.66152954], [88.96340179, 21.66201019], [88.96334076, 21.66250038], [88.96325684, 21.66299057], [88.96308899, 21.66345024], [88.96291351, 21.66392326], [88.9627533, 21.66440964], [88.9625473, 21.66488075], [88.96240234, 21.66534805], [88.96221924, 21.6657505], [88.9620285, 21.66609764], [88.96189117, 21.66642952], [88.96173859, 21.66671753], [88.96160126, 21.66702271], [88.96147919, 21.66732788], [88.96135712, 21.6676712], [88.96121216, 21.66803932], [88.9610672, 21.66847038], [88.96089935, 21.66895294], [88.96074677, 21.66949081], [88.96059418, 21.66995811], [88.96044922, 21.67037964], [88.96032715, 21.67073822], [88.96022797, 21.67106247], [88.96009064, 21.67136192], [88.95996094, 21.6717205], [88.95980072, 21.67213821], [88.9596405, 21.67262077], [88.95944214, 21.67310524], [88.95923615, 21.67354965], [88.95907593, 21.67395782], [88.95890808, 21.67428207], [88.95876312, 21.67457008], [88.95861816, 21.67487907], [88.95848846, 21.67517281], [88.95836639, 21.67547035], [88.95825195, 21.67576981], [88.95806885, 21.67604828], [88.95783997, 21.67636108], [88.95757294, 21.67671967], [88.95722961, 21.6770916], [88.95664978, 21.67739105], [88.95582581, 21.67749977], [88.95555878, 21.67777824], [88.95555878, 21.67805481], [88.95500183, 21.67861176], [88.95500183, 21.67889023], [88.95444489, 21.67944527], [88.95443726, 21.68083191], [88.95471954, 21.68111038], [88.95471954, 21.68139076], [88.95444489, 21.68166733], [88.95443726, 21.68222046], [88.95471954, 21.68250084], [88.95471954, 21.68278122], [88.95443726, 21.68305969], [88.95443726, 21.68638992], [88.95417023, 21.68666458], [88.95417023, 21.68753052], [88.9541626, 21.68806076], [88.95417023, 21.68849945], [88.95417023, 21.68889046], [88.95414734, 21.68927002], [88.95405579, 21.6897068], [88.9539032, 21.69020844], [88.95372009, 21.6907692], [88.9536972, 21.69135094], [88.95370483, 21.69189644], [88.95357513, 21.69247055], [88.95334625, 21.69293022], [88.95317078, 21.69331932], [88.95298767, 21.69366837], [88.95285797, 21.69400978], [88.95276642, 21.69433975], [88.9526825, 21.69465065], [88.95249176, 21.69489861], [88.95230103, 21.69514275], [88.95220947, 21.69543076], [88.95213318, 21.69571114], [88.95207977, 21.69605064], [88.95198822, 21.6964283], [88.95191193, 21.69688034], [88.95166779, 21.69734192], [88.95140076, 21.69785118], [88.95118713, 21.6984005], [88.95111847, 21.69896126], [88.95108032, 21.69945908], [88.95094299, 21.69992065], [88.95083618, 21.70036125], [88.95084381, 21.70072174], [88.95096588, 21.70100975], [88.9513092, 21.70123863], [88.95173645, 21.70143127], [88.95244598, 21.7014904], [88.95324707, 21.70142174], [88.95397186, 21.70137978], [88.95462036, 21.70137024], [88.95523834, 21.70135117], [88.95583344, 21.70129967], [88.95638275, 21.70116997], [88.95694733, 21.7010994], [88.95748901, 21.70103073], [88.95797729, 21.70088959], [88.95847321, 21.70080185], [88.95893097, 21.7007122], [88.95933533, 21.70056915], [88.95972443, 21.70048332], [88.96009827, 21.70041275], [88.96047211, 21.70031929], [88.96086121, 21.70022964], [88.96127319, 21.70014954], [88.96166992, 21.70009995], [88.96203613, 21.70015907], [88.96237946, 21.7002697], [88.96272278, 21.7003994], [88.96312714, 21.70047951], [88.96363068, 21.70051193], [88.9641571, 21.70051956], [88.96470642, 21.70051956], [88.96526337, 21.70051956], [88.9658432, 21.70051193], [88.96641541, 21.70049667], [88.9670105, 21.70041847], [88.96756744, 21.70021057], [88.96810913, 21.69991493], [88.96861267, 21.69955254], [88.96911621, 21.69918442], [88.96962738, 21.69883347], [88.97012329, 21.69848442], [88.9706192, 21.69813919], [88.97112274, 21.6978302], [88.9716568, 21.69760323], [88.97220612, 21.6974659], [88.97270203, 21.69736099], [88.97315979, 21.6973896], [88.97357941, 21.69761658], [88.97399902, 21.69782257], [88.97438812, 21.69809151], [88.97475433, 21.69841194], [88.97511292, 21.69874001], [88.97541046, 21.69909096], [88.97570038, 21.69940758], [88.97595978, 21.69971085], [88.97618866, 21.70002937], [88.97644806, 21.70033073], [88.97672272, 21.70064926], [88.97696686, 21.70096016], [88.97724152, 21.70131111], [88.9776001, 21.70169258], [88.97808075, 21.70216942], [88.97838593, 21.70247078], [88.97869873, 21.70275688], [88.97917938, 21.70301056], [88.97944641, 21.70308113], [88.97968292, 21.7031498], [88.97994995, 21.70326042], [88.98030853, 21.7033596], [88.98072052, 21.70349503], [88.98116302, 21.70365143], [88.98162079, 21.70386124], [88.9821167, 21.7041111], [88.98265839, 21.70438957], [88.98323059, 21.70477104], [88.98384094, 21.70532036], [88.98448944, 21.70568848], [88.98509216, 21.70554924], [88.9852829, 21.70556259], [88.98555756, 21.7052803], [88.98583221, 21.7052803], [88.98680878, 21.70430183], [88.98944092, 21.70166779], [88.98944092, 21.70140076], [88.98944092, 21.70111084], [88.98972321, 21.70083046], [88.98972321, 21.70000076], [88.99001312, 21.69972038], [88.98999786, 21.69805336], [88.99028015, 21.69778061], [88.99028015, 21.69750023], [88.99001312, 21.69721985], [88.98999786, 21.69555473], [88.99028015, 21.69527817], [88.99001312, 21.69499969], [88.98999786, 21.69444466], [88.98972321, 21.69416618], [88.98972321, 21.69361115], [88.98944092, 21.69333267], [88.98944092, 21.69305611], [88.98972321, 21.6927681], [88.98944092, 21.69249916], [88.98950195, 21.69225121], [88.98989105, 21.69212151], [88.99017334, 21.69181252], [88.99038696, 21.6913662], [88.99060059, 21.69087982], [88.99084473, 21.69042778], [88.99106598, 21.69003105], [88.99127197, 21.68969727], [88.99143219, 21.68939018], [88.99160767, 21.68908882], [88.99172211, 21.6887207], [88.99185181, 21.68834114], [88.99198151, 21.68792915], [88.99217224, 21.6875], [88.99194336, 21.68722153], [88.99250031, 21.68666458], [88.99250031, 21.68638992], [88.99223328, 21.68610954], [88.99222565, 21.68472481], [88.99194336, 21.68444633], [88.99194336, 21.68361092], [88.99138641, 21.68305588], [88.99138641, 21.68250084], [88.9916687, 21.68222046], [88.9916687, 21.68000031], [88.99194336, 21.67972183], [88.99194336, 21.67888832], [88.99223328, 21.67861176], [88.99222565, 21.67833328], [88.99250031, 21.67805481], [88.99250031, 21.67777824], [88.99333191, 21.67694092], [88.99333191, 21.67611122], [88.99307251, 21.67583084], [88.9936142, 21.67527962], [88.99333191, 21.67500114], [88.99333191, 21.6747303], [88.99360657, 21.67444038], [88.9936142, 21.67388916], [88.99388885, 21.67361069], [88.99388885, 21.67305946], [88.99360657, 21.67278099], [88.99360657, 21.67193985], [88.99333191, 21.67111206], [88.99250031, 21.67027855], [88.99092102, 21.66966057], [88.99063873, 21.66938972], [88.98934937, 21.66845131], [88.9888916, 21.66722107], [88.98790741, 21.66629982], [88.98734283, 21.66483116], [88.98705292, 21.6610508], [88.98690033, 21.65782738], [88.98719025, 21.65592957], [88.98761749, 21.6543293], [88.98790741, 21.6529808], [88.98833466, 21.65217781], [88.98860168, 21.65188026], [88.990448, 21.65032959], [88.9908371, 21.64999962], [88.9931488, 21.64925194], [88.99430084, 21.64898109], [88.99544525, 21.64903259], [88.99598694, 21.64908981], [88.99610901, 21.64916992], [88.9963913, 21.64903831], [88.99861145, 21.64944458], [88.99888611, 21.64945412], [89.0, 21.64944077], [89.00039673, 21.64969063], [89.00080872, 21.64970016], [89.00123596, 21.64972115], [89.00166321, 21.64972115], [89.00208282, 21.64972115], [89.00248718, 21.64973068], [89.00280762, 21.64964104], [89.00327301, 21.64966965], [89.00389862, 21.64973068], [89.00431824, 21.64979935], [89.0045929, 21.64992905], [89.00537872, 21.64999962], [89.00579834, 21.64999962], [89.00621796, 21.64999962], [89.00662231, 21.65003967], [89.00707245, 21.65001678], [89.00721741, 21.65008354], [89.00772095, 21.65008354], [89.00788116, 21.65016365], [89.00800323, 21.65022087], [89.00836182, 21.65028954], [89.00858307, 21.65028954], [89.00901031, 21.65041924], [89.0092926, 21.65041924], [89.00938416, 21.65044785], [89.00952148, 21.65048981], [89.00979614, 21.65044975], [89.01014709, 21.65055847], [89.01036835, 21.65055466], [89.01072693, 21.65061951]]], [[[88.23166656, 21.64110947], [88.23138428, 21.64067841], [88.23110199, 21.64018822], [88.23078156, 21.63965607], [88.23043823, 21.63907814], [88.22997284, 21.63859749], [88.2294693, 21.63820267], [88.22899628, 21.6378212], [88.22852325, 21.6375103], [88.22807312, 21.63723183], [88.22766113, 21.63696289], [88.22724915, 21.63671112], [88.22680664, 21.63649559], [88.22644043, 21.63620949], [88.22611237, 21.63583374], [88.22595978, 21.63555527], [88.22583771, 21.63554764], [88.22569275, 21.6355381], [88.22512817, 21.63486099], [88.22496796, 21.63484955], [88.22499084, 21.63458061], [88.22444153, 21.63360977], [88.22416687, 21.63361168], [88.22389221, 21.63333321], [88.22360992, 21.63333321], [88.22333527, 21.63305664], [88.22305298, 21.63305664], [88.22270203, 21.63270569], [88.22166443, 21.63166428], [88.22138977, 21.63167], [88.22122192, 21.63150024], [88.22111511, 21.63143158], [88.22114563, 21.63157082], [88.22076416, 21.63118935], [88.22032166, 21.63082123], [88.21987152, 21.63041115], [88.21942139, 21.6299305], [88.21893311, 21.62944984], [88.21840668, 21.62899017], [88.21790314, 21.62861061], [88.21743011, 21.62825966], [88.21700287, 21.62793922], [88.21665192, 21.62758064], [88.21630859, 21.62723923], [88.21592712, 21.62689972], [88.21556091, 21.62653542], [88.21517944, 21.62615967], [88.21476746, 21.62582779], [88.21438599, 21.62547112], [88.21409607, 21.62500954], [88.2138443, 21.62456894], [88.21357727, 21.62419128], [88.21334839, 21.62388992], [88.21317291, 21.6235981], [88.2130127, 21.62333107], [88.21283722, 21.62308121], [88.21272278, 21.62277031], [88.21251678, 21.62249947], [88.21234131, 21.62214088], [88.21218872, 21.62169838], [88.21193695, 21.62111092], [88.21166992, 21.62083054], [88.21166992, 21.62000084], [88.21138763, 21.61972046], [88.21060181, 21.61810493], [88.21073914, 21.61695099], [88.21055603, 21.61611176], [88.21055603, 21.61583138], [88.21083069, 21.61555481], [88.21083069, 21.61527824], [88.21111298, 21.61499977], [88.21111298, 21.61417007], [88.21083069, 21.61388969], [88.21083069, 21.61361122], [88.21028137, 21.6130619], [88.21028137, 21.61249924], [88.21057129, 21.61222076], [88.21055603, 21.6119442], [88.21083069, 21.61166573], [88.21083069, 21.61111069], [88.21111298, 21.6108284], [88.21111298, 21.60944366], [88.21138763, 21.6091671], [88.21138763, 21.60861015], [88.21166992, 21.60833359], [88.21166992, 21.60806084], [88.21221924, 21.60750008], [88.21221924, 21.60695076], [88.21250153, 21.60695076], [88.21305847, 21.60639], [88.21277618, 21.60610962], [88.21277618, 21.60555649], [88.21305847, 21.60527611], [88.21305847, 21.60499954], [88.21331787, 21.60472107], [88.21333313, 21.60361099], [88.21360779, 21.60333061], [88.21360779, 21.60277748], [88.21389008, 21.60251045], [88.21389008, 21.60194016], [88.21279907, 21.60194206], [88.21221924, 21.60194206], [88.21194458, 21.6016674], [88.21166992, 21.60194206], [88.2097168, 21.60194016], [88.20889282, 21.60277939], [88.20888519, 21.60305405], [88.20861053, 21.60333061], [88.20861053, 21.60361099], [88.20833588, 21.60388947], [88.20804596, 21.60388947], [88.20777893, 21.60416412], [88.20833588, 21.60472488], [88.20861053, 21.60472107], [88.20916748, 21.60527611], [88.20916748, 21.60555649], [88.20888519, 21.60583305], [88.20888519, 21.60611153], [88.20861053, 21.60611153], [88.20610809, 21.60861015], [88.20610809, 21.60889053], [88.20582581, 21.60917091], [88.20555878, 21.6091671], [88.20500183, 21.60972023], [88.20500183, 21.61000061], [88.20471954, 21.61027908], [88.20471954, 21.61111069], [88.20417023, 21.61166573], [88.20417023, 21.6119442], [88.20388794, 21.61222076], [88.20388794, 21.61249924], [88.20361328, 21.61277962], [88.20361328, 21.61361122], [88.20305634, 21.61417007], [88.20305634, 21.61499977], [88.20277405, 21.61527824], [88.20276642, 21.61610985], [88.2022171, 21.61667061], [88.2022171, 21.61778069], [88.20194244, 21.61805344], [88.20194244, 21.61833], [88.2013855, 21.61888885], [88.20137787, 21.61944008], [88.20083618, 21.62000084], [88.20111084, 21.6202755], [88.20111084, 21.62055779], [88.20083618, 21.62083054], [88.20057678, 21.62121964], [88.20054626, 21.62138939], [88.20027924, 21.62166786], [88.20027924, 21.62222099], [88.19999695, 21.62249947], [88.19999695, 21.62305641], [88.19972229, 21.62333107], [88.19972229, 21.62388992], [88.19944763, 21.62416649], [88.19922638, 21.62464905], [88.19904327, 21.62486076], [88.19889069, 21.62500191], [88.19880676, 21.62528038], [88.1987381, 21.62549019], [88.19874573, 21.62569809], [88.1986084, 21.62583351], [88.19834137, 21.62615013], [88.19809723, 21.62662888], [88.19787598, 21.62713051], [88.19773865, 21.62765121], [88.1975174, 21.62807655], [88.19733429, 21.62851334], [88.1971817, 21.62897682], [88.19695282, 21.6293602], [88.19668579, 21.62973976], [88.19650269, 21.63015938], [88.1963501, 21.63062096], [88.19610596, 21.63099098], [88.19583893, 21.63132095], [88.19557953, 21.63163757], [88.19532776, 21.6319294], [88.19507599, 21.63219261], [88.19481659, 21.63241005], [88.19469452, 21.63269806], [88.19489288, 21.63338089], [88.19495392, 21.63402557], [88.19485474, 21.63467407], [88.19447327, 21.63531113], [88.1938324, 21.63582611], [88.19384003, 21.63636971], [88.19387817, 21.63696289], [88.19384766, 21.63750076], [88.19365692, 21.63790894], [88.19351959, 21.63826942], [88.19332886, 21.63857079], [88.19311523, 21.63884926], [88.19294739, 21.63916016], [88.19281006, 21.63948059], [88.19277954, 21.63986969], [88.19277954, 21.64025116], [88.19283295, 21.64066124], [88.19300079, 21.64110947], [88.19304657, 21.64162064], [88.1930542, 21.64215851], [88.19304657, 21.6427002], [88.1930542, 21.64325714], [88.19301605, 21.64381027], [88.19285583, 21.64434052], [88.19258118, 21.64479065], [88.19241333, 21.64523125], [88.19225311, 21.64561081], [88.19219208, 21.64596558], [88.19206238, 21.64626122], [88.19193268, 21.64657021], [88.19174957, 21.64689064], [88.1916275, 21.64728928], [88.19139862, 21.64764977], [88.19115448, 21.64800644], [88.19091034, 21.64835167], [88.1906662, 21.64875031], [88.1905899, 21.64929008], [88.19058228, 21.64990044], [88.1904068, 21.65041924], [88.19009399, 21.65080833], [88.18977356, 21.6511116], [88.18952179, 21.65135956], [88.1893158, 21.65159035], [88.18930817, 21.65196991], [88.18927765, 21.65234756], [88.18914795, 21.65265274], [88.18904877, 21.65297127], [88.18901825, 21.65340042], [88.18889618, 21.65382957], [88.18870544, 21.65424538], [88.18855286, 21.65473938], [88.18831635, 21.65526009], [88.1880722, 21.65582275], [88.18788147, 21.65642929], [88.18778229, 21.65703773], [88.18772888, 21.65757942], [88.18762207, 21.65799522], [88.18747711, 21.65831184], [88.18730164, 21.65856934], [88.18719482, 21.65882683], [88.18707275, 21.65906143], [88.18694305, 21.65929985], [88.18682861, 21.65958595], [88.18672943, 21.65998077], [88.18669128, 21.66053009], [88.1865387, 21.66114616], [88.186203, 21.66178131], [88.18615723, 21.66242027], [88.18630981, 21.66300964], [88.18622589, 21.66348076], [88.18608856, 21.66386986], [88.18595886, 21.66418266], [88.18582916, 21.6644516], [88.18569183, 21.66469955], [88.18548584, 21.66491127], [88.18521881, 21.66514015], [88.18515778, 21.6656208], [88.18538666, 21.66630554], [88.18545532, 21.66695213], [88.18528748, 21.66749382], [88.18512726, 21.66800117], [88.18514252, 21.66860008], [88.18499756, 21.66916275], [88.18480682, 21.66978264], [88.18457031, 21.6703701], [88.18416595, 21.67080688], [88.18369293, 21.67120361], [88.18335724, 21.67159081], [88.18354797, 21.67208099], [88.18356323, 21.67258072], [88.18347931, 21.67313957], [88.18327332, 21.67368126], [88.18310547, 21.67425728], [88.18305206, 21.67485809], [88.18302917, 21.67542648], [88.18295288, 21.67588425], [88.18282318, 21.67625809], [88.1827774, 21.67666817], [88.18276215, 21.67712975], [88.18250275, 21.67749977], [88.1827774, 21.67778969], [88.1827774, 21.68111038], [88.18250275, 21.68138885], [88.18250275, 21.68181038], [88.18250275, 21.68194389], [88.18222046, 21.68222046], [88.18226624, 21.68305016], [88.18235016, 21.6842308], [88.18205261, 21.6847496], [88.18147278, 21.68576431], [88.18138885, 21.68610954], [88.18138885, 21.6866703], [88.18139648, 21.68694687], [88.18133545, 21.68753433], [88.18138123, 21.68811226], [88.18138885, 21.68830109], [88.18139648, 21.68868065], [88.18148804, 21.68921852], [88.18167114, 21.68967438], [88.18184662, 21.69009972], [88.18199158, 21.69054985], [88.18218231, 21.6909256], [88.18232727, 21.69133186], [88.18251038, 21.69170952], [88.18270874, 21.69207573], [88.18286133, 21.69246674], [88.1830368, 21.69283485], [88.18319702, 21.6932106], [88.18335724, 21.69366074], [88.18353271, 21.69411087], [88.18362427, 21.69466782], [88.18374634, 21.69520187], [88.1840744, 21.69547081], [88.18418884, 21.69582176], [88.18416595, 21.69667053], [88.18444824, 21.69695091], [88.18444824, 21.69805336], [88.1847229, 21.69832993], [88.1847229, 21.69916534], [88.18499756, 21.69944], [88.18519592, 21.69992828], [88.18528748, 21.70006943], [88.18527985, 21.70027542], [88.18583679, 21.70083046], [88.18583679, 21.70111084], [88.18611145, 21.70138931], [88.18611145, 21.70194435], [88.18638611, 21.70222282], [88.18640137, 21.70249939], [88.1866684, 21.70277977], [88.1866684, 21.7033329], [88.18694305, 21.70360756], [88.18694305, 21.70416641], [88.18722534, 21.70444489], [88.18723297, 21.70500183], [88.1875, 21.7052784], [88.1875, 21.70611191], [88.18777466, 21.70638847], [88.18778229, 21.70648956], [88.18778992, 21.70667267], [88.18782806, 21.70675468], [88.18795776, 21.70704079], [88.18810272, 21.70746613], [88.1883316, 21.70776939], [88.1883316, 21.70806122], [88.1911087, 21.71084023], [88.19139099, 21.7108326], [88.19166565, 21.71111107], [88.19194794, 21.71111107], [88.1938858, 21.71305656], [88.19416809, 21.71305084], [88.19437408, 21.71326256], [88.19499969, 21.71389961], [88.19528198, 21.71389961], [88.19722748, 21.71584129], [88.19917297, 21.71777916], [88.19944763, 21.71777916], [88.19972229, 21.71805573], [88.19972229, 21.7183342], [88.20083618, 21.71944427], [88.20083618, 21.71970749], [88.20111084, 21.72000122], [88.20111084, 21.72027779], [88.20152283, 21.72069359], [88.20194244, 21.7211113], [88.2022171, 21.72110939], [88.20240021, 21.72138596], [88.20275879, 21.72166252], [88.20317841, 21.72187996], [88.20358276, 21.72191048], [88.20387268, 21.7217598], [88.20405579, 21.72166252], [88.20424652, 21.72146988], [88.20450592, 21.72118187], [88.20465851, 21.72064018], [88.20504761, 21.71970749], [88.20583344, 21.71888924], [88.20610809, 21.71894836], [88.20639038, 21.71861076], [88.20667267, 21.71832848], [88.20666504, 21.71777725], [88.20694733, 21.71750069], [88.20694733, 21.7172184], [88.20749664, 21.71666718], [88.2075119, 21.71639061], [88.20777893, 21.71611023], [88.20777893, 21.71582985], [88.20833588, 21.71527863], [88.20833588, 21.71500015], [88.20861053, 21.71471977], [88.20861053, 21.71444511], [88.20868683, 21.71417046], [88.20999908, 21.71249962], [88.21028137, 21.71249962], [88.21083069, 21.71194077], [88.21131897, 21.71160889], [88.21193695, 21.71138954], [88.21353149, 21.70944023], [88.21389008, 21.70916748], [88.2141571, 21.70889282], [88.2141571, 21.70861053], [88.21470642, 21.70763969], [88.21527863, 21.7069416], [88.215271, 21.70646477], [88.21536255, 21.7062664], [88.21555328, 21.70583344], [88.21583557, 21.70555496], [88.21586609, 21.70500183], [88.21606445, 21.70439529], [88.21611023, 21.70375061], [88.21615601, 21.70310974], [88.21634674, 21.70248985], [88.21643829, 21.701828], [88.2166214, 21.7011795], [88.21659088, 21.70054054], [88.21624756, 21.7000103], [88.21580505, 21.69957352], [88.21530914, 21.69925499], [88.21482086, 21.69902039], [88.21431732, 21.69894981], [88.21379852, 21.6989193], [88.21327209, 21.69890022], [88.21273804, 21.69885063], [88.21226501, 21.69868088], [88.21175385, 21.6985817], [88.21128082, 21.69841003], [88.21073914, 21.69833946], [88.21013641, 21.69833565], [88.2095108, 21.69833183], [88.20887756, 21.69828606], [88.20826721, 21.69809151], [88.2076416, 21.69799614], [88.20701599, 21.69782257], [88.20639038, 21.69777107], [88.20578003, 21.69769287], [88.20521545, 21.69752884], [88.2046814, 21.69742012], [88.20425415, 21.69722748], [88.20384979, 21.69704056], [88.20361328, 21.69695091], [88.20333099, 21.69666672], [88.20305634, 21.69667053], [88.20276642, 21.69639015], [88.20249939, 21.69639015], [88.2022171, 21.69610977], [88.2013855, 21.69611168], [88.20111084, 21.6958313], [88.20055389, 21.6958313], [88.19999695, 21.69527817], [88.19972229, 21.69528008], [88.19917297, 21.69472122], [88.19889069, 21.69472122], [88.1986084, 21.69444466], [88.19833374, 21.69444466], [88.19638824, 21.69249916], [88.19638824, 21.69222069], [88.19555664, 21.69138908], [88.19525909, 21.69111061], [88.19528198, 21.69055939], [88.19528198, 21.69028091], [88.19499969, 21.69000053], [88.19499969, 21.68972969], [88.19473267, 21.68943977], [88.19472504, 21.68916893], [88.19416809, 21.68861008], [88.19416809, 21.68805695], [88.19444275, 21.68778038], [88.19444275, 21.6875], [88.19473267, 21.68721962], [88.19472504, 21.6855545], [88.19499969, 21.68527985], [88.19499969, 21.68473053], [88.1955719, 21.68416977], [88.1955719, 21.68333054], [88.19527435, 21.68305588], [88.19528198, 21.68278122], [88.1955719, 21.68250084], [88.19555664, 21.68194389], [88.1958313, 21.68166733], [88.1958313, 21.68139076], [88.19610596, 21.68111038], [88.19610596, 21.68083191], [88.19638824, 21.68055534], [88.1966629, 21.68056107], [88.19695282, 21.68028259], [88.19695282, 21.68000031], [88.19721985, 21.67972183], [88.19721985, 21.67888832], [88.19750214, 21.67861176], [88.19750214, 21.67833328], [88.19777679, 21.67805481], [88.19777679, 21.67749977], [88.19805908, 21.67721748], [88.19805908, 21.67694473], [88.1986084, 21.67638969], [88.19904327, 21.67584038], [88.19950867, 21.67537117], [88.20008087, 21.67501068], [88.20067596, 21.67469025], [88.20124817, 21.67431068], [88.20179749, 21.67393112], [88.20237732, 21.6736393], [88.20294952, 21.67340088], [88.20337677, 21.67307854], [88.20376587, 21.67278862], [88.20413971, 21.67252922], [88.2045517, 21.67238808], [88.20498657, 21.67224121], [88.20545197, 21.67220879], [88.20571136, 21.67198181], [88.20617676, 21.67177582], [88.20670319, 21.67160988], [88.20717621, 21.67155838], [88.20780182, 21.67150688], [88.20845795, 21.67135048], [88.20892334, 21.67110062], [88.20957184, 21.67093086], [88.20999908, 21.6707077], [88.21054077, 21.67057991], [88.2109375, 21.67042351], [88.2116394, 21.67046165], [88.21213531, 21.67030716], [88.21264648, 21.67028046], [88.21315765, 21.67025185], [88.21360779, 21.67013359], [88.21403503, 21.67002106], [88.21450806, 21.66999817], [88.2150116, 21.66995811], [88.21553802, 21.66981506], [88.21605682, 21.66995049], [88.21659851, 21.67003822], [88.21711731, 21.67021942], [88.2177124, 21.67027283], [88.21836853, 21.67028046], [88.21907043, 21.67032242], [88.21926117, 21.67037392], [88.21977234, 21.67051125], [88.22046661, 21.67052078], [88.22115326, 21.67037964], [88.22186279, 21.67041969], [88.22251129, 21.67050171], [88.22309875, 21.67058754], [88.22362518, 21.67079163], [88.22421265, 21.67083549], [88.22450256, 21.67081642], [88.22481537, 21.67079735], [88.22537231, 21.67061043], [88.22590637, 21.67046165], [88.22632599, 21.67021179], [88.22665405, 21.66985703], [88.22693634, 21.66941833], [88.227211, 21.66889], [88.22740173, 21.6682663], [88.22750092, 21.6675396], [88.22757721, 21.66675949], [88.22772217, 21.6659584], [88.2277832, 21.66583061], [88.22777557, 21.66527748], [88.22750092, 21.66500092], [88.22750092, 21.66278839], [88.22693634, 21.66221809], [88.22721863, 21.66194534], [88.22693634, 21.66167068], [88.22721863, 21.6613903], [88.22721863, 21.66110992], [88.22694397, 21.66083336], [88.22694397, 21.66027832], [88.22721863, 21.65999985], [88.22721863, 21.65971947], [88.22750092, 21.65944672], [88.22750092, 21.65805435], [88.2277832, 21.65722084], [88.22805786, 21.65638924], [88.22805786, 21.65444183], [88.22833252, 21.65416718], [88.22831726, 21.65250015], [88.22853088, 21.6516819], [88.22859955, 21.65146065], [88.22888184, 21.65132141], [88.22916412, 21.6511116], [88.22923279, 21.65076637], [88.22923279, 21.65055847], [88.22914124, 21.64992905], [88.22914124, 21.64958763], [88.22984314, 21.64903069], [88.23005676, 21.64840126], [88.23026276, 21.64810944], [88.23060608, 21.64749718], [88.23082733, 21.64722061], [88.23083496, 21.64666748], [88.23110962, 21.64639091], [88.23110962, 21.64528084], [88.23139191, 21.64500046], [88.23139191, 21.64389038], [88.23166656, 21.64361], [88.23166656, 21.64333344], [88.23139191, 21.64305305], [88.23139191, 21.64167976], [88.23166656, 21.64138985], [88.23166656, 21.64110947]]], [[[88.57688141, 21.69173431], [88.57701874, 21.69137192], [88.57717896, 21.69111061], [88.5772934, 21.69081116], [88.57744598, 21.6905098], [88.57756042, 21.6901226], [88.57769775, 21.68970108], [88.57769775, 21.68917847], [88.57758331, 21.68861961], [88.57756042, 21.68811035], [88.57756805, 21.68803406], [88.57765198, 21.68746185], [88.57781219, 21.68696213], [88.57801056, 21.68656349], [88.57815552, 21.68615913], [88.57829285, 21.6857605], [88.57836151, 21.68530083], [88.57849121, 21.68481827], [88.57859039, 21.68433762], [88.57866669, 21.68382072], [88.57884979, 21.68328094], [88.57901001, 21.68269157], [88.57920074, 21.68210983], [88.57943726, 21.68153191], [88.57966614, 21.68091393], [88.57980347, 21.68023109], [88.58001709, 21.67958069], [88.58027649, 21.67896271], [88.58055878, 21.67839813], [88.58081818, 21.67790413], [88.58107758, 21.67745209], [88.58131409, 21.67702484], [88.58153534, 21.67661095], [88.58170319, 21.67617035], [88.58192444, 21.67579651], [88.5821228, 21.67539978], [88.58233643, 21.67503357], [88.58261871, 21.67468834], [88.58289337, 21.67431068], [88.58311462, 21.67389297], [88.58334351, 21.67346954], [88.58355713, 21.67305946], [88.58361053, 21.67291069], [88.58370972, 21.67260742], [88.58390808, 21.67217827], [88.58411407, 21.6717453], [88.58428955, 21.67122078], [88.58436584, 21.67085075], [88.58441162, 21.67063522], [88.58450317, 21.67000008], [88.58467102, 21.66941071], [88.58479309, 21.66879845], [88.58499146, 21.66824532], [88.58516693, 21.66771126], [88.58525848, 21.66719246], [88.58530426, 21.66670418], [88.58535767, 21.66624451], [88.58530426, 21.66579437], [88.58528137, 21.66531944], [88.58527374, 21.66482162], [88.585289, 21.66430855], [88.58532715, 21.66381073], [88.58551025, 21.66332054], [88.5855484, 21.66283035], [88.58555603, 21.66234589], [88.5855484, 21.66186333], [88.58528137, 21.66166878], [88.58555603, 21.6613903], [88.58555603, 21.65999985], [88.58583069, 21.65971947], [88.58583069, 21.65805435], [88.58611298, 21.65777969], [88.58611298, 21.65750122], [88.58666229, 21.65694046], [88.58666992, 21.6566658], [88.58694458, 21.6566658], [88.58721924, 21.65638924], [88.58750153, 21.65639114], [88.58777618, 21.65611076], [88.58805847, 21.65611076], [88.58860779, 21.65555954], [88.58889008, 21.65555954], [88.5891571, 21.65528107], [88.58944702, 21.65528107], [88.58972168, 21.65500069], [88.59027863, 21.65500069], [88.59055328, 21.65472031], [88.5911026, 21.65472031], [88.59166718, 21.65472221], [88.59194183, 21.65444374], [88.59249878, 21.65444374], [88.59305573, 21.65423965], [88.59343719, 21.65390015], [88.59377289, 21.6535511], [88.59384155, 21.65324974], [88.59388733, 21.65305519], [88.59361267, 21.65306282], [88.59333038, 21.65278053], [88.59333038, 21.65195274], [88.59361267, 21.65167236], [88.59361267, 21.65083122], [88.59388733, 21.65055466], [88.59388733, 21.65027809], [88.59471893, 21.64944077], [88.59471893, 21.64916611], [88.59500122, 21.64888954], [88.59527588, 21.64888954], [88.59638977, 21.64777946], [88.59638977, 21.64750099], [88.5966568, 21.64722061], [88.59666443, 21.64638901], [88.59694672, 21.64611053], [88.59694672, 21.64556122], [88.59722137, 21.64528084], [88.59722137, 21.64443016], [88.59750366, 21.64416695], [88.59749603, 21.64361], [88.59777832, 21.64333344], [88.59777832, 21.64305305], [88.59860229, 21.64221954], [88.59860992, 21.64194489], [88.59889221, 21.64166641], [88.59889221, 21.64138985], [88.59916687, 21.64110947], [88.59916687, 21.63999939], [88.59944153, 21.63972282], [88.59944153, 21.63916588], [88.59971619, 21.63888931], [88.59971619, 21.63862038], [88.59916687, 21.63806152], [88.59916687, 21.63722038], [88.59972382, 21.63666725], [88.59971619, 21.63611031], [88.59918213, 21.63556862], [88.59916687, 21.63500023], [88.59967804, 21.63448906], [88.59999847, 21.63416862], [88.60028076, 21.63417053], [88.60056305, 21.63389015], [88.60083008, 21.63389015], [88.60138702, 21.63332939], [88.60138702, 21.63194656], [88.60166931, 21.63166428], [88.60166168, 21.63138962], [88.60193634, 21.63111115], [88.60193634, 21.63000107], [88.60221863, 21.62972069], [88.60221863, 21.62916756], [88.60250092, 21.6288929], [88.60294342, 21.62902451], [88.60309601, 21.62851524], [88.60334778, 21.62802124], [88.60361481, 21.62750053], [88.60305786, 21.62750053], [88.60305786, 21.62668037], [88.60415649, 21.62556267], [88.60457611, 21.62590408], [88.60496521, 21.62565041], [88.60526276, 21.62537956], [88.60546112, 21.62507629], [88.60558319, 21.62473106], [88.60571289, 21.62440109], [88.60559082, 21.62411118], [88.60555267, 21.62388992], [88.60527802, 21.62361908], [88.60527802, 21.62333107], [88.60472107, 21.62277985], [88.6047287, 21.62249947], [88.60419464, 21.62196732], [88.60333252, 21.62111092], [88.60305786, 21.62111092], [88.6027832, 21.62083054], [88.60250092, 21.62083244], [88.60221863, 21.62055779], [88.60166931, 21.62055779], [88.60138702, 21.6202755], [88.60028076, 21.62028122], [88.59999847, 21.62000084], [88.59971619, 21.62000084], [88.59944153, 21.61972046], [88.59805298, 21.61972046], [88.59777832, 21.62000084], [88.59694672, 21.62000084], [88.5966568, 21.62028122], [88.59583282, 21.6202755], [88.59527588, 21.62083244], [88.59500122, 21.62083244], [88.59500122, 21.62000084], [88.59388733, 21.61889076], [88.59388733, 21.61861038], [88.59305573, 21.61861038], [88.59249878, 21.61805344], [88.59194183, 21.61805344], [88.59166718, 21.61833572], [88.59111023, 21.61833572], [88.58889008, 21.62055779], [88.58860779, 21.62055016], [88.58805847, 21.62111092], [88.58777618, 21.62111092], [88.58750153, 21.62138939], [88.58694458, 21.62138939], [88.58638763, 21.62194061], [88.58599091, 21.62208748], [88.58565521, 21.62236595], [88.58524323, 21.6225605], [88.5848465, 21.62279892], [88.58450317, 21.62308121], [88.584198, 21.62339973], [88.58389282, 21.62375069], [88.58355713, 21.62411118], [88.58318329, 21.62446976], [88.58273315, 21.62485123], [88.58220673, 21.62521172], [88.58164978, 21.62554741], [88.58108521, 21.62586021], [88.58052826, 21.62615204], [88.58001709, 21.6264801], [88.57953644, 21.62684059], [88.57905579, 21.62717056], [88.57849121, 21.62741089], [88.57808685, 21.62773514], [88.57772827, 21.62804413], [88.57736969, 21.62833023], [88.57701874, 21.6286087], [88.57665253, 21.62887192], [88.57627869, 21.62912941], [88.57589722, 21.62936592], [88.57544708, 21.62953949], [88.5750351, 21.62974548], [88.574646, 21.63005257], [88.57415771, 21.63035011], [88.57360077, 21.63068008], [88.57299805, 21.63105011], [88.57231903, 21.63138008], [88.57161713, 21.63167], [88.57095337, 21.63194656], [88.57036591, 21.63222122], [88.56985474, 21.63247108], [88.5693512, 21.63261032], [88.56916809, 21.63222122], [88.56861877, 21.63278008], [88.56833649, 21.63277817], [88.56777954, 21.63333321], [88.56749725, 21.63333321], [88.5672226, 21.63361168], [88.56639099, 21.63360977], [88.56625366, 21.63375092], [88.5661087, 21.63389015], [88.56555939, 21.63367081], [88.56510162, 21.63367081], [88.5647049, 21.63384056], [88.56427765, 21.63393211], [88.56388092, 21.63412285], [88.56341553, 21.63417053], [88.56291962, 21.63423347], [88.56246185, 21.63443947], [88.5619812, 21.63463974], [88.56143188, 21.63461113], [88.56085968, 21.63457108], [88.5606308, 21.63461876], [88.56027985, 21.63469124], [88.55967712, 21.63472748], [88.55909729, 21.63479805], [88.55856323, 21.63499069], [88.55832672, 21.63500023], [88.55805206, 21.63528061], [88.5577774, 21.63528061], [88.55750275, 21.63500023], [88.55722046, 21.63528061], [88.5569458, 21.6352787], [88.55638885, 21.63583374], [88.55584717, 21.63612938], [88.55549622, 21.63657951], [88.55513, 21.63697052], [88.55486298, 21.6373806], [88.55470276, 21.63777924], [88.55452728, 21.63811111], [88.55444336, 21.63845634], [88.55435944, 21.6388092], [88.5541687, 21.63915062], [88.55397797, 21.63953018], [88.55387115, 21.63999748], [88.55371094, 21.64046478], [88.55362701, 21.64096069], [88.55361176, 21.6415081], [88.55361938, 21.64208984], [88.55361176, 21.6427269], [88.55361176, 21.64338112], [88.55363464, 21.6440239], [88.55373383, 21.64456367], [88.55384064, 21.64500427], [88.55387115, 21.64515114], [88.55391693, 21.64538193], [88.55403137, 21.64570618], [88.55414581, 21.64604378], [88.55422974, 21.6464119], [88.55429077, 21.64651108], [88.5544281, 21.64673042], [88.55459595, 21.64709091], [88.55477142, 21.64743042], [88.55502319, 21.64770126], [88.55528259, 21.64794159], [88.55555725, 21.64816284], [88.55583191, 21.64843941], [88.55610657, 21.64878273], [88.55640411, 21.64915848], [88.55678558, 21.64948463], [88.55709839, 21.64987946], [88.55744171, 21.65027809], [88.55776215, 21.65068817], [88.55805969, 21.65114021], [88.55838776, 21.65158081], [88.55877686, 21.65196991], [88.55916595, 21.65237999], [88.55957031, 21.65276718], [88.5599823, 21.6531105], [88.56039429, 21.6534462], [88.56080627, 21.65374947], [88.56117249, 21.65411949], [88.56154633, 21.65446091], [88.5619278, 21.65483093], [88.56227875, 21.65522003], [88.56266785, 21.65557098], [88.56304169, 21.65594864], [88.5634079, 21.65633965], [88.563797, 21.65671158], [88.56417847, 21.65711021], [88.56458282, 21.6574707], [88.56501007, 21.65777969], [88.56541443, 21.65807724], [88.5657196, 21.65844154], [88.56587982, 21.65893555], [88.56611633, 21.65941048], [88.56639099, 21.6599102], [88.56667328, 21.66041756], [88.56698608, 21.6608696], [88.56742859, 21.66115952], [88.56780243, 21.66146088], [88.56808472, 21.66178513], [88.56837463, 21.66210175], [88.5686264, 21.66246223], [88.56887817, 21.66283035], [88.56905365, 21.66322136], [88.56919861, 21.66358948], [88.56939697, 21.66385078], [88.5696106, 21.66409492], [88.56977081, 21.6643219], [88.56999969, 21.66451073], [88.57022095, 21.66473961], [88.57040405, 21.66501045], [88.57054901, 21.66531944], [88.57065582, 21.66566086], [88.57080841, 21.66600037], [88.57086182, 21.66641045], [88.57099915, 21.66684723], [88.57109833, 21.66734123], [88.57113647, 21.66789055], [88.57129669, 21.66841125], [88.57137299, 21.66895294], [88.57139587, 21.66949081], [88.57144165, 21.6700058], [88.57152557, 21.67022324], [88.57162476, 21.67048454], [88.5716629, 21.67098045], [88.57167816, 21.67148972], [88.57167053, 21.67198753], [88.57167053, 21.67248154], [88.57167053, 21.67297173], [88.57167816, 21.67346954], [88.5716629, 21.67398071], [88.57159424, 21.67447853], [88.57142639, 21.67493057], [88.57138824, 21.67535973], [88.57138824, 21.67575073], [88.57138824, 21.6760807], [88.57138824, 21.67644119], [88.5713501, 21.67684555], [88.57115173, 21.67727089], [88.57108307, 21.67780113], [88.57090759, 21.67827988], [88.57077026, 21.6787796], [88.57072449, 21.67889023], [88.5705719, 21.67923355], [88.57042694, 21.67972183], [88.57026672, 21.68023109], [88.57010651, 21.68074036], [88.57000732, 21.68123055], [88.56994629, 21.68166733], [88.56976318, 21.68198967], [88.56972504, 21.68233681], [88.56969452, 21.68266296], [88.56955719, 21.68294907], [88.56942749, 21.68332291], [88.56923676, 21.68370819], [88.56912994, 21.68422127], [88.56891632, 21.68470955], [88.56876373, 21.68525696], [88.56861877, 21.68577957], [88.5684433, 21.68628883], [88.56832123, 21.68679428], [88.56815338, 21.68725967], [88.56803894, 21.68771744], [88.56787109, 21.68810463], [88.56775665, 21.68847084], [88.56759644, 21.68880081], [88.56751251, 21.68917847], [88.56749725, 21.68961143], [88.56748962, 21.69005394], [88.56752777, 21.69046974], [88.56770325, 21.69081879], [88.56800079, 21.69110298], [88.56841278, 21.69133186], [88.56900024, 21.6914196], [88.56958771, 21.69153976], [88.57012939, 21.69164085], [88.57064056, 21.69164467], [88.57110596, 21.69155884], [88.57154083, 21.69148064], [88.57196808, 21.69146156], [88.57235718, 21.69164085], [88.57276917, 21.69177818], [88.57319641, 21.69190025], [88.57366943, 21.69199944], [88.57408905, 21.69219017], [88.57459259, 21.69236565], [88.57514954, 21.69252968], [88.57572174, 21.6926899], [88.57627869, 21.69252968], [88.57663727, 21.6921196], [88.57688141, 21.69173431]]], [[[88.30931091, 21.69219017], [88.30893707, 21.69258118], [88.30860901, 21.69296837], [88.30831909, 21.69331169], [88.30805206, 21.6936245], [88.30778503, 21.69393349], [88.30751038, 21.69427109], [88.30722809, 21.69468117], [88.30693817, 21.69511986], [88.306633, 21.69560051], [88.30627441, 21.69607735], [88.30584717, 21.69651031], [88.30542755, 21.69693947], [88.30503845, 21.69734192], [88.30472565, 21.69775772], [88.30444336, 21.69815445], [88.3041687, 21.69852066], [88.30389404, 21.69887161], [88.3035965, 21.6991806], [88.30332947, 21.69953728], [88.30304718, 21.69987106], [88.30275726, 21.70021057], [88.30243683, 21.70048523], [88.30208588, 21.70070076], [88.30182648, 21.70095062], [88.30158997, 21.70119095], [88.30134583, 21.70144081], [88.30110931, 21.70175934], [88.3008728, 21.70211029], [88.30065155, 21.70242882], [88.30051422, 21.70285416], [88.3004303, 21.70344162], [88.30036926, 21.70402908], [88.30042267, 21.70455933], [88.30057526, 21.70498466], [88.30084991, 21.70536995], [88.3012085, 21.70578957], [88.30163574, 21.70625687], [88.30207825, 21.70675468], [88.3026123, 21.70705986], [88.30316925, 21.70732117], [88.30371857, 21.70748329], [88.30428314, 21.70756149], [88.30480957, 21.70773125], [88.30512238, 21.70770073], [88.30537415, 21.70767403], [88.30593872, 21.70752144], [88.30651093, 21.70744133], [88.30708313, 21.70743561], [88.30751801, 21.70730019], [88.30791473, 21.7071743], [88.3082962, 21.70697021], [88.30871582, 21.70683098], [88.30911255, 21.70664978], [88.30948639, 21.70643044], [88.30996704, 21.70639038], [88.31041718, 21.70638657], [88.31051636, 21.70638084], [88.31108093, 21.70635033], [88.3116684, 21.70611191], [88.3152771, 21.70611191], [88.31555176, 21.70583344], [88.31639099, 21.70583344], [88.31666565, 21.70555496], [88.31833649, 21.70555496], [88.31861115, 21.70583344], [88.32305908, 21.70583344], [88.32333374, 21.70611191], [88.32389069, 21.70611191], [88.32416534, 21.70583344], [88.32444763, 21.70583344], [88.32472229, 21.70555496], [88.32639313, 21.70556259], [88.32666779, 21.7052803], [88.32713318, 21.7052803], [88.32861328, 21.7052803], [88.32917023, 21.7047081], [88.32944489, 21.70472145], [88.33027649, 21.70388985], [88.33055878, 21.70388985], [88.33110809, 21.70332909], [88.33139038, 21.7033329], [88.33249664, 21.70222282], [88.33277893, 21.70222282], [88.33333588, 21.70166779], [88.33390045, 21.70166969], [88.33499908, 21.70055962], [88.33499908, 21.70028114], [88.33555603, 21.69972038], [88.33555603, 21.69944572], [88.33583069, 21.69916534], [88.33721924, 21.69778061], [88.33805847, 21.69778061], [88.33860779, 21.69721985], [88.33833313, 21.69694328], [88.33860779, 21.69667053], [88.33860779, 21.69639015], [88.34055328, 21.69444275], [88.34059906, 21.69474983], [88.34089661, 21.69444275], [88.34122467, 21.69413948], [88.34150696, 21.69379044], [88.34187317, 21.69354439], [88.34220123, 21.69324875], [88.34249115, 21.69290924], [88.34275055, 21.69254112], [88.3430481, 21.69222069], [88.34333038, 21.69187927], [88.34361267, 21.69153976], [88.34388733, 21.69121552], [88.34416962, 21.69087982], [88.34444427, 21.69054985], [88.34471893, 21.69019127], [88.345047, 21.68976212], [88.34610748, 21.68861008], [88.34583282, 21.68833351], [88.34583282, 21.68805695], [88.34610748, 21.68778038], [88.34610748, 21.68695831], [88.34638977, 21.6866703], [88.34638977, 21.68638992], [88.3466568, 21.68610954], [88.34694672, 21.68611145], [88.34693146, 21.68564987], [88.34732056, 21.68526077], [88.34789276, 21.6849308], [88.34805298, 21.68447113], [88.34812927, 21.68405151], [88.34828186, 21.68369675], [88.34835052, 21.68336105], [88.34845734, 21.68305969], [88.34864044, 21.68275452], [88.34888458, 21.68240929], [88.34912872, 21.68198967], [88.34942627, 21.68155098], [88.34976959, 21.68110085], [88.35020447, 21.68075562], [88.35056305, 21.68028259], [88.35028076, 21.68000031], [88.35028076, 21.67972183], [88.35055542, 21.67944527], [88.35056305, 21.67889023], [88.35083008, 21.67861176], [88.35083008, 21.67833328], [88.35111237, 21.67805481], [88.35111237, 21.67555618], [88.35083008, 21.67527962], [88.35083008, 21.67444038], [88.34999847, 21.67361069], [88.34971619, 21.67361069], [88.34916687, 21.67305946], [88.35056305, 21.67165947], [88.35028076, 21.67138863], [88.35028076, 21.67111015], [88.34944153, 21.67027855], [88.34944153, 21.67000008], [88.34916687, 21.6697197], [88.34916687, 21.66944313], [88.34944153, 21.66917038], [88.34916687, 21.66889], [88.34916687, 21.66833115], [88.34999847, 21.66749954], [88.34999847, 21.66638947], [88.34944153, 21.66583061], [88.34944153, 21.66555595], [88.34887695, 21.66500092], [88.34887695, 21.66443825], [88.34860992, 21.6641674], [88.34860992, 21.66332817], [88.34805298, 21.66277885], [88.34777832, 21.66278839], [88.34729004, 21.66229057], [88.34722137, 21.66221809], [88.34694672, 21.66222191], [88.34666443, 21.66194534], [88.34638977, 21.66194916], [88.34610748, 21.66167068], [88.34610748, 21.6613903], [88.34638977, 21.66110992], [88.34638977, 21.66055679], [88.34693146, 21.66001129], [88.34722137, 21.65972137], [88.34750366, 21.65972137], [88.34833527, 21.65888977], [88.34833527, 21.6586113], [88.34860992, 21.65833282], [88.34860992, 21.65638924], [88.34887695, 21.65611076], [88.34887695, 21.65583038], [88.34777832, 21.65472221], [88.34750366, 21.65472221], [88.34666443, 21.6538887], [88.34638977, 21.65389061], [88.34638977, 21.65333176], [88.34750366, 21.65222168], [88.34777832, 21.65222168], [88.34805298, 21.65250015], [88.34805298, 21.65278053], [88.34860992, 21.65278053], [88.34887695, 21.65306282], [88.34916687, 21.65305519], [88.34944153, 21.65333366], [88.34999847, 21.65333176], [88.3500824, 21.65341377], [88.35028076, 21.65361977], [88.35111237, 21.65361977], [88.35138702, 21.65333176], [88.35138702, 21.65305519], [88.35221863, 21.65222168], [88.35221863, 21.65194511], [88.35250092, 21.65167236], [88.35250092, 21.6511097], [88.35305786, 21.65055466], [88.35305786, 21.65027809], [88.35388947, 21.64944077], [88.35416412, 21.64944458], [88.35472107, 21.64888954], [88.35527802, 21.64888954], [88.35555267, 21.64861107], [88.35694122, 21.64861107], [88.35807037, 21.64750099], [88.35807037, 21.64722061], [88.35778046, 21.64694595], [88.35778046, 21.64666748], [88.35666656, 21.64556122], [88.35639191, 21.6455574], [88.35610962, 21.64583588], [88.35500336, 21.64583588], [88.35472107, 21.6455574], [88.35444641, 21.64556122], [88.35388947, 21.64500046], [88.35360718, 21.64500046], [88.35332489, 21.64476776], [88.35305786, 21.64472198], [88.35277557, 21.64444351], [88.35250092, 21.64444351], [88.35194397, 21.64388847], [88.35166931, 21.64389038], [88.35138702, 21.64417076], [88.35083008, 21.64417076], [88.35028076, 21.64361], [88.34999847, 21.64333344], [88.34999847, 21.6427784], [88.34971619, 21.64249992], [88.34971619, 21.64138985], [88.34944153, 21.64110947], [88.34944153, 21.6408329], [88.34916687, 21.6408329], [88.34889221, 21.64055634], [88.34887695, 21.64027977], [88.34860992, 21.63999939], [88.34860992, 21.63943863], [88.34860992, 21.63926506], [88.34838104, 21.63894844], [88.34817505, 21.63866806], [88.3481369, 21.63835526], [88.3482666, 21.63800049], [88.34829712, 21.63764954], [88.34822083, 21.63731956], [88.34805298, 21.6370182], [88.34784698, 21.63673019], [88.34763336, 21.6364212], [88.34734344, 21.63616943], [88.34694672, 21.63611031], [88.3466568, 21.63582993], [88.34583282, 21.63583374], [88.34555817, 21.63555527], [88.34416962, 21.63555908], [88.34388733, 21.63528061], [88.34416962, 21.63500023], [88.34416962, 21.63389015], [88.34443665, 21.63360977], [88.34444427, 21.63333321], [88.34471893, 21.63305664], [88.34444427, 21.63277817], [88.34443665, 21.63249016], [88.34416962, 21.63222313], [88.34416962, 21.63194656], [88.34444427, 21.63166428], [88.34416962, 21.63138962], [88.34381866, 21.63138962], [88.34361267, 21.63138962], [88.34278107, 21.63055992], [88.34278107, 21.63027954], [88.34221649, 21.62972069], [88.34222412, 21.62944221], [88.34194183, 21.62916756], [88.34194183, 21.62805939], [88.34139252, 21.62750053], [88.34139252, 21.62722015], [88.34083557, 21.62666702], [88.3408432, 21.62611008], [88.34111023, 21.62583351], [88.34111023, 21.62500191], [88.3408432, 21.62471771], [88.33999634, 21.62472153], [88.33853149, 21.62353706], [88.33838654, 21.62259293], [88.33838654, 21.62179184], [88.33724213, 21.62111664], [88.33553314, 21.62083817], [88.33337402, 21.62071609], [88.33138275, 21.61977005], [88.33094025, 21.61896515], [88.330513, 21.61815834], [88.32950592, 21.61762047], [88.32807922, 21.61721802], [88.32749939, 21.61636925], [88.3272171, 21.61610985], [88.3263855, 21.61611176], [88.32570648, 21.61722183], [88.32527924, 21.61750031], [88.32472229, 21.61694336], [88.32470703, 21.61639023], [88.32444763, 21.61610985], [88.32444763, 21.61583138], [88.3236084, 21.61583138], [88.32333374, 21.61555481], [88.32305908, 21.61555481], [88.32277679, 21.61583138], [88.32250214, 21.61583138], [88.32250214, 21.61499977], [88.32196045, 21.61445045], [88.32196045, 21.61388969], [88.32138824, 21.61333275], [88.32138824, 21.61318207], [88.32098389, 21.61284256], [88.32070923, 21.61250877], [88.32045746, 21.61214828], [88.32015991, 21.61175156], [88.31983185, 21.61129761], [88.31938171, 21.61090088], [88.31887054, 21.61058044], [88.31837463, 21.61030579], [88.31788635, 21.61008072], [88.31739807, 21.61001015], [88.31691742, 21.60997963], [88.31645966, 21.60988426], [88.31614685, 21.60960007], [88.31595612, 21.60923958], [88.31582642, 21.60889053], [88.31582642, 21.60861015], [88.3152771, 21.60805511], [88.31500244, 21.60805511], [88.31472015, 21.60833359], [88.31277466, 21.60833359], [88.3125, 21.60861206], [88.31222534, 21.60833359], [88.31194305, 21.60833359], [88.3116684, 21.60861206], [88.31138611, 21.60861015], [88.31111145, 21.60889053], [88.31083679, 21.60889053], [88.31054688, 21.60917091], [88.31027985, 21.6091671], [88.3097229, 21.60972214], [88.30944824, 21.60972023], [88.30805206, 21.61111069], [88.30792236, 21.61148453], [88.30776215, 21.61186028], [88.30755615, 21.61222076], [88.30750275, 21.61265945], [88.30744171, 21.61314011], [88.30723572, 21.61360741], [88.30702972, 21.61413002], [88.30695343, 21.61472321], [88.3069458, 21.61531639], [88.30691528, 21.61584473], [88.30678558, 21.61627197], [88.3066864, 21.61667252], [88.30667114, 21.61709023], [88.30664063, 21.61757088], [88.30651093, 21.61809158], [88.30641174, 21.61862946], [88.30640411, 21.61912537], [88.30644226, 21.61952209], [88.30632782, 21.61984253], [88.30621338, 21.62034035], [88.30632019, 21.62093163], [88.30625153, 21.62140083], [88.3061676, 21.6218605], [88.30618286, 21.62238693], [88.30612946, 21.62288284], [88.30610657, 21.62342262], [88.30605316, 21.62394524], [88.30589294, 21.62446976], [88.30583954, 21.62500954], [88.30583191, 21.62556267], [88.30583191, 21.62611008], [88.30583191, 21.62664413], [88.30583191, 21.62714958], [88.30583191, 21.62763023], [88.30583191, 21.6280899], [88.30581665, 21.62855911], [88.30575562, 21.62906075], [88.30583954, 21.62959671], [88.30597687, 21.6301403], [88.30609131, 21.6307106], [88.3061142, 21.63129807], [88.30615234, 21.63189316], [88.30636597, 21.6324482], [88.30654907, 21.63305092], [88.30673981, 21.63368034], [88.30690765, 21.63428688], [88.30696106, 21.6348896], [88.30696106, 21.6354866], [88.30705261, 21.63603973], [88.30724335, 21.63656044], [88.30750275, 21.63705063], [88.30776978, 21.63754082], [88.3080368, 21.6380291], [88.30831909, 21.63850021], [88.30854797, 21.63898087], [88.30869293, 21.63948059], [88.30887604, 21.63987541], [88.30902863, 21.6402607], [88.30917358, 21.64066887], [88.30932617, 21.64110947], [88.30948639, 21.64159966], [88.30973053, 21.64205933], [88.30993652, 21.6425209], [88.31011963, 21.64297867], [88.31034851, 21.64340019], [88.31056213, 21.64382935], [88.3107605, 21.64427948], [88.31083679, 21.64472008], [88.31111145, 21.64500046], [88.31111145, 21.64528084], [88.31138611, 21.6455574], [88.31138611, 21.64583015], [88.3116684, 21.64611053], [88.3116684, 21.64666748], [88.31194305, 21.64694595], [88.31194305, 21.64722061], [88.31223297, 21.64750099], [88.31223297, 21.64777946], [88.3125, 21.64805984], [88.3125, 21.64888954], [88.31305695, 21.64944458], [88.31305695, 21.64972115], [88.3133316, 21.64999962], [88.3133316, 21.65055466], [88.31305695, 21.65083122], [88.31305695, 21.65138817], [88.31361389, 21.65194511], [88.31360626, 21.65333176], [88.31416321, 21.6538887], [88.31416321, 21.65444374], [88.31445313, 21.65472031], [88.31445313, 21.65528107], [88.31472015, 21.65555573], [88.31472015, 21.65722466], [88.31495667, 21.65750694], [88.31500244, 21.65777969], [88.3152771, 21.65805435], [88.3152771, 21.65833092], [88.3152771, 21.65888023], [88.31532288, 21.6593895], [88.31550598, 21.65985107], [88.31561279, 21.66036987], [88.31582642, 21.66082954], [88.31606293, 21.6613102], [88.3161087, 21.66188812], [88.31611633, 21.66251945], [88.3162384, 21.66318893], [88.31636047, 21.66387939], [88.31642914, 21.66460991], [88.31659698, 21.66535187], [88.31665802, 21.66607094], [88.31665802, 21.66676521], [88.31656647, 21.6674099], [88.31620789, 21.6679554], [88.31601715, 21.66847038], [88.31613922, 21.66905785], [88.31633759, 21.66971016], [88.31639099, 21.67041779], [88.31633759, 21.6711216], [88.31608582, 21.67176819], [88.31583405, 21.67237854], [88.31597137, 21.67307091], [88.31590271, 21.67368126], [88.31585693, 21.67424011], [88.31591797, 21.67476082], [88.31601715, 21.67527962], [88.31587982, 21.67575073], [88.31582642, 21.67620277], [88.31583405, 21.67664909], [88.31583405, 21.67711449], [88.3157959, 21.67759132], [88.31561279, 21.67804909], [88.31552887, 21.67856979], [88.31539154, 21.67910194], [88.31523895, 21.67959976], [88.31501007, 21.68014717], [88.31481171, 21.68075943], [88.31468964, 21.68139076], [88.3144989, 21.6819191], [88.31442261, 21.68239975], [88.31429291, 21.6827774], [88.31416321, 21.68310165], [88.31398773, 21.68338966], [88.31389618, 21.68370247], [88.31382751, 21.68400955], [88.3136673, 21.68425941], [88.31352234, 21.68452072], [88.31333923, 21.68475914], [88.31317139, 21.68502808], [88.31302643, 21.68534088], [88.31286621, 21.68562889], [88.31278992, 21.68592834], [88.31275177, 21.68626785], [88.31263733, 21.6865406], [88.31250763, 21.68684959], [88.31239319, 21.68719292], [88.31221771, 21.68753052], [88.31202698, 21.68788147], [88.31189728, 21.68828964], [88.31167603, 21.68862534], [88.3114624, 21.68897057], [88.31130219, 21.68937111], [88.31108093, 21.68970108], [88.31082916, 21.68999863], [88.31056213, 21.69029427], [88.31034851, 21.69062805], [88.31018829, 21.69103622], [88.30993652, 21.69138908], [88.30963135, 21.69177055], [88.30931091, 21.69219017]]], [[[88.4540329, 21.70934105], [88.45444489, 21.70916748], [88.45500183, 21.70861053], [88.45500183, 21.70833015], [88.45555878, 21.70777702], [88.45527649, 21.70777702], [88.45583344, 21.70722008], [88.45583344, 21.70694351], [88.45639038, 21.70638847], [88.45639038, 21.70611191], [88.45718384, 21.70549393], [88.45719147, 21.70514488], [88.45724487, 21.70474815], [88.45735931, 21.70430946], [88.4575119, 21.70385551], [88.45770264, 21.70336151], [88.45783234, 21.70284462], [88.45805359, 21.70239067], [88.45826721, 21.70197105], [88.4584198, 21.70153046], [88.45861053, 21.7011528], [88.45879364, 21.70079041], [88.45895386, 21.70041084], [88.45915985, 21.70004272], [88.45936584, 21.69964981], [88.45952606, 21.69923019], [88.45973969, 21.69883537], [88.45996857, 21.69843864], [88.4601593, 21.69800949], [88.46031189, 21.69756317], [88.46048737, 21.69713974], [88.46065521, 21.69671059], [88.46086884, 21.69628906], [88.46110535, 21.69588852], [88.4613266, 21.69544983], [88.46140289, 21.69492722], [88.46150208, 21.69439125], [88.46173096, 21.6939106], [88.46198273, 21.69342041], [88.46222687, 21.69293022], [88.46247864, 21.69244957], [88.462677, 21.69197083], [88.46290588, 21.69152641], [88.46311188, 21.69108009], [88.46333313, 21.69067001], [88.46360016, 21.69029617], [88.46388245, 21.68992805], [88.4641571, 21.68952942], [88.46444702, 21.68909073], [88.46473694, 21.68861961], [88.46505737, 21.68816185], [88.46538544, 21.68773079], [88.46567535, 21.68725967], [88.46595001, 21.68677521], [88.46613312, 21.68621063], [88.46633148, 21.68560982], [88.46644592, 21.68497849], [88.46660614, 21.68439102], [88.46669769, 21.68387985], [88.46684265, 21.68343925], [88.46694183, 21.68302917], [88.46701813, 21.68260956], [88.4671402, 21.68221283], [88.46702576, 21.68173027], [88.46722412, 21.68128204], [88.46748352, 21.68081856], [88.46769714, 21.68032074], [88.46803284, 21.67988014], [88.4683075, 21.67942429], [88.46845245, 21.6788559], [88.46850586, 21.67823029], [88.46853638, 21.67811012], [88.46865845, 21.67767906], [88.46885681, 21.67720985], [88.4690094, 21.67673111], [88.46918488, 21.67642021], [88.46925354, 21.67629242], [88.46955872, 21.67578888], [88.46994019, 21.67528915], [88.47026062, 21.67476082], [88.47055054, 21.6742878], [88.47073364, 21.67384529], [88.4706955, 21.67341423], [88.47068787, 21.6729908], [88.47027588, 21.67277527], [88.46971893, 21.67222023], [88.46971893, 21.67164993], [88.46971893, 21.67083549], [88.46950531, 21.67029762], [88.46922302, 21.66990089], [88.46916962, 21.6697216], [88.46888733, 21.66944313], [88.46888733, 21.66917038], [88.46721649, 21.66749954], [88.46611023, 21.66749954], [88.46607971, 21.66776276], [88.46594238, 21.66797256], [88.4658432, 21.66825485], [88.46573639, 21.66860962], [88.46563721, 21.66901016], [88.4656601, 21.6694603], [88.46576691, 21.66990089], [88.46582031, 21.67036247], [88.4658432, 21.67084122], [88.46585846, 21.6713562], [88.46591187, 21.67189026], [88.46605682, 21.67243767], [88.46617126, 21.67304039], [88.46639252, 21.67361069], [88.46639252, 21.67368889], [88.46639252, 21.67444038], [88.46666718, 21.6747303], [88.46666718, 21.67555809], [88.46611023, 21.67611122], [88.46583557, 21.67611122], [88.46555328, 21.67583275], [88.46555328, 21.67499924], [88.46527863, 21.6747303], [88.46527863, 21.67416954], [88.46512604, 21.6738205], [88.46498108, 21.67345619], [88.46479797, 21.67307091], [88.46475983, 21.67263985], [88.46475983, 21.67220116], [88.46475983, 21.67176819], [88.46473694, 21.67135048], [88.46466064, 21.67093086], [88.46461487, 21.67046928], [88.4646225, 21.66995811], [88.46463776, 21.66949081], [88.46463013, 21.66908264], [88.46460724, 21.66868973], [88.4646225, 21.66823959], [88.46466827, 21.66770744], [88.46478271, 21.66718102], [88.46489716, 21.66672134], [88.46496582, 21.66628838], [88.46491241, 21.66584969], [88.46479034, 21.6654129], [88.46472931, 21.6649437], [88.46466064, 21.66449356], [88.46444702, 21.6641674], [88.46444702, 21.66389084], [88.46472168, 21.66361046], [88.46469879, 21.65942192], [88.46452332, 21.65897751], [88.46446228, 21.65855026], [88.46443939, 21.65813065], [88.46438599, 21.65772057], [88.46422577, 21.65733147], [88.46409607, 21.6568985], [88.46389008, 21.65647125], [88.46366882, 21.65603256], [88.46350861, 21.65551949], [88.46337128, 21.65501976], [88.46325684, 21.65457153], [88.4630661, 21.65423965], [88.46286011, 21.65398979], [88.46260071, 21.65378952], [88.46235657, 21.65354538], [88.46212769, 21.65324974], [88.46195984, 21.6529007], [88.46194458, 21.65250015], [88.46138763, 21.65195274], [88.46138763, 21.65083122], [88.46166992, 21.65055466], [88.46138763, 21.65027809], [88.46111298, 21.65027809], [88.46083069, 21.64999962], [88.46028137, 21.64999962], [88.46006012, 21.64971161], [88.45967865, 21.6497612], [88.45928955, 21.64978981], [88.45892334, 21.64960289], [88.45861053, 21.64944077], [88.45888519, 21.64944458], [88.45888519, 21.64916611], [88.45916748, 21.64888954], [88.45916748, 21.64861107], [88.45999908, 21.64777946], [88.45999908, 21.64500046], [88.4597168, 21.64472008], [88.45972443, 21.64388847], [88.45916748, 21.64332962], [88.45916748, 21.6427784], [88.45944214, 21.64249992], [88.45944214, 21.64221954], [88.45916748, 21.64194489], [88.45916748, 21.64166641], [88.45833588, 21.6408329], [88.45861053, 21.64055634], [88.45861053, 21.63943863], [88.45833588, 21.63916588], [88.45833588, 21.63862038], [88.45777893, 21.63806152], [88.45777893, 21.63777924], [88.45749664, 21.63750076], [88.45749664, 21.6369381], [88.45722198, 21.63666725], [88.45722961, 21.63639069], [88.45694733, 21.63611031], [88.45694733, 21.63582993], [88.45666504, 21.63555527], [88.45667267, 21.63528061], [88.45610809, 21.63471985], [88.45610809, 21.63444519], [88.45582581, 21.63417053], [88.45582581, 21.63360977], [88.45527649, 21.63305664], [88.45527649, 21.63277817], [88.45500183, 21.63249016], [88.45500183, 21.63166428], [88.45527649, 21.63138962], [88.45500183, 21.63111115], [88.45471954, 21.63111115], [88.45417023, 21.63055992], [88.45388794, 21.63055992], [88.45388794, 21.63027954], [88.45361328, 21.63000107], [88.45361328, 21.62916946], [88.45333099, 21.6288929], [88.45333099, 21.62861061], [88.45305634, 21.62833023], [88.45305634, 21.6277771], [88.45276642, 21.62750053], [88.45276642, 21.62694168], [88.45249939, 21.62666702], [88.45305634, 21.62611008], [88.45305634, 21.62583351], [88.45388794, 21.62500191], [88.45400238, 21.62477112], [88.45388794, 21.62445068], [88.45388794, 21.6241684], [88.45361328, 21.62388992], [88.45361328, 21.62361908], [88.45333099, 21.62333107], [88.45333099, 21.62305641], [88.45276642, 21.62249947], [88.45276642, 21.62222099], [88.45111084, 21.62055779], [88.45055389, 21.62055779], [88.45027924, 21.6202755], [88.44999695, 21.62028122], [88.44972229, 21.62000084], [88.44889069, 21.62000084], [88.4486084, 21.61972046], [88.44805908, 21.61972237], [88.44750214, 21.61916733], [88.44695282, 21.61917114], [88.44676208, 21.61898613], [88.4466629, 21.61888885], [88.44610596, 21.61889076], [88.4458313, 21.61861038], [88.44555664, 21.61861038], [88.44526672, 21.61833], [88.44527435, 21.61805344], [88.44416809, 21.61695099], [88.44416809, 21.61667061], [88.44249725, 21.61499977], [88.44223022, 21.61499977], [88.44194794, 21.61528015], [88.4411087, 21.61527824], [88.44055176, 21.61582947], [88.44055176, 21.61639023], [88.4411087, 21.61694336], [88.4411087, 21.61722183], [88.44139099, 21.61749077], [88.44139099, 21.61861038], [88.44167328, 21.61889076], [88.44139099, 21.61917114], [88.44139099, 21.62000084], [88.4411087, 21.6202755], [88.4411087, 21.62144279], [88.44137573, 21.62200356], [88.44153595, 21.62264061], [88.44152069, 21.62335587], [88.44112396, 21.62396431], [88.44068909, 21.62451935], [88.44030762, 21.62508965], [88.43992615, 21.62560081], [88.44005585, 21.62593079], [88.44013977, 21.62630081], [88.43998718, 21.62673759], [88.43976593, 21.62722015], [88.43976593, 21.62775993], [88.43991852, 21.6282692], [88.4397583, 21.62866402], [88.43965912, 21.62903023], [88.4394989, 21.62932014], [88.43942261, 21.6296463], [88.43927002, 21.62990952], [88.43914795, 21.63021088], [88.43898773, 21.63047791], [88.43887329, 21.63079071], [88.43875885, 21.6310997], [88.43859863, 21.63137054], [88.4384079, 21.63161087], [88.43827057, 21.63187027], [88.43809509, 21.6321373], [88.43801117, 21.63253975], [88.43776703, 21.63298988], [88.4375, 21.63347816], [88.43721008, 21.63396645], [88.43688202, 21.63439178], [88.43651581, 21.6347599], [88.436203, 21.63517761], [88.43585968, 21.6355896], [88.43551636, 21.63602066], [88.43517303, 21.63640022], [88.43488312, 21.63679123], [88.43464661, 21.63712692], [88.43435669, 21.63733101], [88.43415833, 21.63758278], [88.43395996, 21.63780594], [88.43376923, 21.63804817], [88.43357849, 21.63831711], [88.43332672, 21.63859749], [88.4330368, 21.63891029], [88.432724, 21.63921547], [88.43241119, 21.63954353], [88.43214417, 21.63993454], [88.43180847, 21.64027023], [88.43144226, 21.64060974], [88.43112183, 21.64097977], [88.43080902, 21.64137077], [88.43044281, 21.64167976], [88.43005371, 21.64199829], [88.42971802, 21.64236069], [88.42938995, 21.64273071], [88.42901611, 21.64306068], [88.42865753, 21.64339066], [88.42832947, 21.64376068], [88.42797089, 21.64410973], [88.42753601, 21.64439011], [88.42707062, 21.6446209], [88.42669678, 21.6449604], [88.42635345, 21.64530945], [88.4260025, 21.64567375], [88.42567444, 21.64608383], [88.42527771, 21.64645004], [88.42487335, 21.64684105], [88.42447662, 21.64725685], [88.42414856, 21.6477623], [88.42373657, 21.6482048], [88.42328644, 21.64859962], [88.42281342, 21.64897537], [88.42240143, 21.64938354], [88.42214203, 21.64978027], [88.42178345, 21.65003586], [88.4214859, 21.65032005], [88.42124939, 21.65066528], [88.42089844, 21.65094948], [88.42064667, 21.65135002], [88.42050934, 21.65192032], [88.42027283, 21.65246964], [88.4200592, 21.65307045], [88.42011261, 21.65372086], [88.42028809, 21.65437126], [88.42050171, 21.65496826], [88.42059326, 21.65554237], [88.42076874, 21.65595818], [88.42082977, 21.65637016], [88.4208374, 21.65677834], [88.4208374, 21.65717316], [88.4208374, 21.65757942], [88.42082214, 21.65800858], [88.42072296, 21.6584301], [88.42059326, 21.65883064], [88.42055511, 21.65926552], [88.42055511, 21.6597023], [88.42056274, 21.66012955], [88.42056274, 21.66056824], [88.42054749, 21.66100883], [88.42047119, 21.66145325], [88.42034912, 21.66188049], [88.42047119, 21.66236115], [88.4203186, 21.66283035], [88.42028046, 21.66332054], [88.42028809, 21.66385078], [88.42038727, 21.66442108], [88.42048645, 21.66504097], [88.4203186, 21.66568756], [88.42028046, 21.66638184], [88.42027283, 21.66708183], [88.42028046, 21.6677494], [88.42034149, 21.66835976], [88.42049408, 21.66887856], [88.42043304, 21.66941833], [88.42050171, 21.66995049], [88.42054749, 21.67038918], [88.42056274, 21.67076111], [88.42055511, 21.67107773], [88.42057037, 21.67346954], [88.42042542, 21.67481804], [88.42037964, 21.67501831], [88.41999817, 21.67656708], [88.41942596, 21.6777401], [88.41932678, 21.67817116], [88.41919708, 21.67866135], [88.41916656, 21.67925072], [88.41912842, 21.67988014], [88.41894531, 21.68051147], [88.41887665, 21.68115807], [88.41876984, 21.68184662], [88.41855621, 21.6825695], [88.41886139, 21.68316078], [88.41913605, 21.68369102], [88.41918182, 21.68394279], [88.41931152, 21.68404007], [88.41944122, 21.68472481], [88.41944122, 21.68610954], [88.41945648, 21.6866703], [88.41945648, 21.68806076], [88.41937256, 21.68841934], [88.41941071, 21.68917847], [88.41960907, 21.6896801], [88.41959381, 21.68982887], [88.42020416, 21.69026375], [88.42061615, 21.69053078], [88.4210434, 21.69074059], [88.42141724, 21.6909523], [88.42176819, 21.69117355], [88.42218018, 21.69136047], [88.42253113, 21.69164085], [88.42286682, 21.69159126], [88.42321777, 21.69178963], [88.42373657, 21.69181252], [88.42428589, 21.6923027], [88.42462158, 21.69272041], [88.42481995, 21.69306183], [88.42511749, 21.69333267], [88.42558289, 21.69346619], [88.42608643, 21.69358826], [88.42649078, 21.69388008], [88.42712402, 21.69442558], [88.42734528, 21.69457245], [88.42767334, 21.69499969], [88.42806244, 21.69528961], [88.42842102, 21.69557953], [88.42871094, 21.6959095], [88.42904663, 21.69617271], [88.42928314, 21.69650078], [88.42946625, 21.69680977], [88.42971039, 21.69704819], [88.42991638, 21.69728279], [88.4300766, 21.6975708], [88.43026733, 21.69779968], [88.43041229, 21.69804955], [88.43054962, 21.69832039], [88.43067169, 21.69859123], [88.43081665, 21.69888115], [88.4309082, 21.69921875], [88.43109131, 21.69951057], [88.43144226, 21.69986534], [88.43193054, 21.70090294], [88.43200684, 21.70107269], [88.43244171, 21.70215034], [88.4332962, 21.70309067], [88.43443298, 21.70400047], [88.43467712, 21.70446014], [88.43518066, 21.7048111], [88.4356308, 21.70518684], [88.43605042, 21.7055645], [88.43645477, 21.70594215], [88.43687439, 21.70627594], [88.43730927, 21.7065506], [88.43775177, 21.70680237], [88.43817902, 21.70705986], [88.43859863, 21.7073307], [88.43902588, 21.70759964], [88.43945313, 21.70784187], [88.43991852, 21.70806122], [88.44037628, 21.70827293], [88.44087982, 21.70846939], [88.44140625, 21.70863533], [88.44194794, 21.70878983], [88.4425354, 21.70890427], [88.44316864, 21.70900154], [88.44385529, 21.70903206], [88.44451904, 21.70902061], [88.44512939, 21.70898056], [88.44573212, 21.70903969], [88.44634247, 21.70909309], [88.44696808, 21.70915031], [88.44757843, 21.70922279], [88.44815063, 21.70919991], [88.44872284, 21.70923996], [88.4492569, 21.70933533], [88.44983673, 21.70936966], [88.4504776, 21.70940018], [88.45111847, 21.70941925], [88.45183563, 21.70944595], [88.45227814, 21.70947266], [88.45257568, 21.70949173], [88.45332336, 21.70942497], [88.4540329, 21.70934105]]], [[[88.63444519, 21.6566658], [88.6341629, 21.65638924], [88.63388824, 21.65639114], [88.63381195, 21.65631294], [88.63370514, 21.65620422], [88.6333313, 21.65583229], [88.6333313, 21.65527725], [88.63305664, 21.65500069], [88.63305664, 21.65444183], [88.63361359, 21.6538887], [88.63360596, 21.65306282], [88.63388824, 21.65278053], [88.63388824, 21.65195274], [88.63445282, 21.65138817], [88.63360596, 21.65055847], [88.63305664, 21.65055847], [88.63276672, 21.65027809], [88.63276672, 21.64999962], [88.63194275, 21.64916992], [88.63166809, 21.64916992], [88.6313858, 21.64888954], [88.63111115, 21.64916992], [88.63027954, 21.64916611], [88.62832642, 21.6511097], [88.62832642, 21.65138817], [88.6277771, 21.65194511], [88.6277771, 21.65222168], [88.62750244, 21.65250015], [88.62750244, 21.6543808], [88.62750244, 21.65806007], [88.62832642, 21.65888977], [88.62833405, 21.65916443], [88.6286087, 21.65944672], [88.6286087, 21.66055679], [88.62889862, 21.66082954], [88.62889099, 21.66194534], [88.62916565, 21.66222191], [88.62917328, 21.66332817], [88.62944794, 21.66361046], [88.62944794, 21.6641674], [88.6297226, 21.66443825], [88.6297226, 21.66527748], [88.63027954, 21.66583252], [88.63166809, 21.66722107], [88.63166809, 21.66749954], [88.63194275, 21.66777802], [88.6313858, 21.66833115], [88.6313858, 21.66889], [88.63249969, 21.67000008], [88.63249969, 21.67028046], [88.63276672, 21.67056084], [88.63277435, 21.67138863], [88.63360596, 21.67222023], [88.63361359, 21.67250061], [88.63391113, 21.67278099], [88.63417053, 21.67316818], [88.6344223, 21.67360306], [88.63462067, 21.67413139], [88.63491058, 21.67461967], [88.63526154, 21.67505074], [88.63560486, 21.67547035], [88.63595581, 21.6758194], [88.63630676, 21.67612648], [88.63661957, 21.67642212], [88.63691711, 21.67671967], [88.63719177, 21.6770153], [88.63744354, 21.67729378], [88.63766479, 21.67754364], [88.63788605, 21.67774963], [88.63817596, 21.67785072], [88.63855743, 21.67803955], [88.6390686, 21.67815971], [88.63955688, 21.67836952], [88.63999939, 21.67856979], [88.64039612, 21.67857361], [88.64065552, 21.6783886], [88.64082336, 21.67809105], [88.64090729, 21.67781067], [88.64108276, 21.6774807], [88.64112091, 21.67703056], [88.64112091, 21.67651558], [88.64111328, 21.67598915], [88.64111328, 21.67550087], [88.64111328, 21.6750412], [88.64109039, 21.67460251], [88.64097595, 21.67414856], [88.64079285, 21.67365265], [88.64055634, 21.67313004], [88.64041138, 21.67282295], [88.64029694, 21.67258072], [88.64009857, 21.67201042], [88.64006042, 21.6713829], [88.64009857, 21.67076111], [88.63993835, 21.67028999], [88.63977051, 21.66987991], [88.6397171, 21.66945648], [88.63964844, 21.66906929], [88.63948059, 21.66876984], [88.63944244, 21.66860008], [88.63944244, 21.66805649], [88.63916779, 21.66777992], [88.63916779, 21.66749954], [88.63889313, 21.66722107], [88.6388855, 21.6669445], [88.63833618, 21.66638947], [88.63833618, 21.66610909], [88.63777161, 21.66556168], [88.63777161, 21.66527939], [88.63749695, 21.66500092], [88.63749695, 21.66472054], [88.63639069, 21.66361046], [88.63639069, 21.66332817], [88.6361084, 21.66305542], [88.6361084, 21.66278839], [88.63582611, 21.66250038], [88.63582611, 21.66221809], [88.63471985, 21.66111183], [88.63444519, 21.66111183], [88.63444519, 21.66055679], [88.6341629, 21.66027832], [88.6341629, 21.65971947], [88.63388824, 21.65944672], [88.63388824, 21.6586113], [88.6341629, 21.65833282], [88.6341629, 21.65694237], [88.63444519, 21.6566658]]], [[[88.19560242, 21.72447968], [88.19499969, 21.72417068], [88.19473267, 21.72445107], [88.19473267, 21.72556114], [88.19499969, 21.72583961], [88.19499969, 21.72611046], [88.19528198, 21.72639084], [88.19527435, 21.7266674], [88.19555664, 21.72694588], [88.1955719, 21.72722054], [88.1958313, 21.72750092], [88.1958313, 21.72833252], [88.19555664, 21.72861099], [88.19559479, 21.72942162], [88.19579315, 21.72972107], [88.19586945, 21.73006821], [88.19600677, 21.73032951], [88.19613647, 21.73057938], [88.19633484, 21.73080444], [88.19655609, 21.73102951], [88.1967392, 21.73137093], [88.19695282, 21.7316494], [88.19721222, 21.73191833], [88.19747925, 21.73220253], [88.19776154, 21.73249245], [88.19802856, 21.73278046], [88.19824982, 21.73308945], [88.19847107, 21.73338509], [88.19868469, 21.73373413], [88.1989212, 21.73411942], [88.19918823, 21.73449516], [88.19944763, 21.73485184], [88.1996994, 21.73520279], [88.19991302, 21.73554039], [88.20013428, 21.7358284], [88.20034027, 21.73607063], [88.20056152, 21.73624992], [88.20077515, 21.73636436], [88.20101166, 21.73641396], [88.20105743, 21.73654175], [88.20111084, 21.73666954], [88.20137787, 21.73666954], [88.20137787, 21.73639107], [88.20194244, 21.73583031], [88.20194244, 21.73500061], [88.20166779, 21.73472023], [88.20166779, 21.73361015], [88.2013855, 21.73333359], [88.2013855, 21.73305511], [88.20111084, 21.73278046], [88.20111084, 21.73138809], [88.20054626, 21.73082924], [88.20055389, 21.73055649], [88.20027924, 21.73027992], [88.20027924, 21.72972107], [88.19999695, 21.7294445], [88.19999695, 21.72888947], [88.19972229, 21.72861099], [88.19972229, 21.72833061], [88.19944763, 21.72805786], [88.19944763, 21.72777939], [88.19889069, 21.72722054], [88.19895172, 21.72698021], [88.19864655, 21.72678947], [88.19834137, 21.72661972], [88.19802856, 21.72636986], [88.19773865, 21.7260685], [88.19747925, 21.72576904], [88.19719696, 21.72553253], [88.19696808, 21.72532272], [88.19671631, 21.7251606], [88.19650269, 21.7250042], [88.19626617, 21.72485733], [88.19600677, 21.72467995], [88.19560242, 21.72447968]]], [[[88.38195038, 21.66722107], [88.38194275, 21.66805649], [88.38166809, 21.6697197], [88.38166809, 21.67000008], [88.38195038, 21.67028046], [88.38194275, 21.67055321], [88.38166809, 21.67083549], [88.38195038, 21.67111015], [88.38166809, 21.67138863], [88.38166809, 21.67166519], [88.3813858, 21.67194366], [88.3805542, 21.67194366], [88.38027954, 21.67222214], [88.37999725, 21.67222023], [88.3797226, 21.67250061], [88.3797226, 21.67333031], [88.37999725, 21.67361069], [88.37999725, 21.67416954], [88.38011932, 21.67456055], [88.38023376, 21.67504692], [88.38026428, 21.67559624], [88.38025665, 21.67617035], [88.38021088, 21.67675018], [88.38004303, 21.67720985], [88.37983704, 21.67760086], [88.37999725, 21.67778969], [88.37999725, 21.67944527], [88.3797226, 21.67972183], [88.3797226, 21.68028259], [88.37999725, 21.68055534], [88.3797226, 21.68083191], [88.38027954, 21.68139076], [88.38027954, 21.68166733], [88.3805542, 21.68194389], [88.3805542, 21.68222237], [88.38078308, 21.68268394], [88.38109589, 21.68316078], [88.38141632, 21.68366241], [88.38176727, 21.6841526], [88.38215637, 21.68468094], [88.38253021, 21.68524742], [88.38297272, 21.68580246], [88.38345337, 21.68632507], [88.38400269, 21.68679047], [88.38451385, 21.68728828], [88.38500977, 21.68779182], [88.38574982, 21.68830109], [88.3859024, 21.68862915], [88.38632202, 21.68900108], [88.38703156, 21.68926048], [88.38719177, 21.68949127], [88.3875351, 21.68969727], [88.38788605, 21.68985748], [88.38819122, 21.69013786], [88.38848877, 21.69044113], [88.38883209, 21.69078255], [88.3891983, 21.69112778], [88.38963318, 21.6914196], [88.39006805, 21.69171715], [88.39054108, 21.69195175], [88.39096832, 21.69221687], [88.39135742, 21.69249344], [88.39196014, 21.69287109], [88.39244843, 21.69313049], [88.39274597, 21.69360161], [88.39309692, 21.69372749], [88.39348602, 21.69401932], [88.3939743, 21.69419861], [88.39437866, 21.69449043], [88.39490509, 21.69488907], [88.39520264, 21.69519234], [88.39595032, 21.69571495], [88.39643097, 21.69612122], [88.3969574, 21.69659615], [88.39749908, 21.69721985], [88.39768219, 21.69752884], [88.39807129, 21.69783211], [88.39844513, 21.69810295], [88.39874268, 21.6984539], [88.39904022, 21.6987896], [88.39923859, 21.69922829], [88.39946747, 21.69965363], [88.39972687, 21.70005226], [88.39998627, 21.70041084], [88.40021515, 21.70077515], [88.40028381, 21.70124435], [88.40054321, 21.70163155], [88.4006958, 21.70197105], [88.40100861, 21.70214081], [88.40106201, 21.70232964], [88.40136719, 21.70260048], [88.40156555, 21.70292664], [88.40167999, 21.70330429], [88.4019928, 21.70374107], [88.40209198, 21.70421028], [88.40245056, 21.70478058], [88.402771, 21.70540047], [88.4029541, 21.70584679], [88.4030304, 21.70603561], [88.40317535, 21.70664215], [88.40322113, 21.70713806], [88.4033432, 21.70750046], [88.40348053, 21.70779037], [88.40358734, 21.70808029], [88.40368652, 21.70838928], [88.40387726, 21.70866966], [88.40406799, 21.70899963], [88.40415955, 21.70941925], [88.40421295, 21.70988083], [88.40439606, 21.71030807], [88.40439606, 21.71075058], [88.40418243, 21.71116257], [88.4039917, 21.71158028], [88.40390778, 21.71199036], [88.40388489, 21.71241379], [88.40383911, 21.71285057], [88.40378571, 21.71344566], [88.40381622, 21.71385193], [88.40382385, 21.71453857], [88.40387726, 21.71519089], [88.4037323, 21.7157402], [88.40362549, 21.71623611], [88.40354156, 21.7166729], [88.40335846, 21.71700096], [88.40319824, 21.71731567], [88.40296936, 21.71759987], [88.402771, 21.71793556], [88.40257263, 21.71829987], [88.40245819, 21.71878052], [88.40222931, 21.71927071], [88.40197754, 21.71983528], [88.40174103, 21.72044945], [88.40135193, 21.72097969], [88.40085602, 21.72142982], [88.40036011, 21.72184753], [88.39982605, 21.72219849], [88.39927673, 21.72244072], [88.39898682, 21.72254944], [88.39826202, 21.72278976], [88.39814758, 21.72334862], [88.3975296, 21.72340965], [88.3972168, 21.72375107], [88.39689636, 21.7240715], [88.39650726, 21.72432709], [88.39609528, 21.72454834], [88.39563751, 21.72472954], [88.39514923, 21.72492981], [88.39457703, 21.72504044], [88.39402771, 21.7252655], [88.39341736, 21.7254715], [88.3927536, 21.72567368], [88.39205933, 21.72585487], [88.3914032, 21.72610092], [88.39080048, 21.72629929], [88.39028931, 21.72636223], [88.38988495, 21.72624779], [88.38935852, 21.72590065], [88.38916779, 21.72611046], [88.38833618, 21.72611046], [88.38804626, 21.72639084], [88.38582611, 21.72639084], [88.38555908, 21.72611046], [88.38471985, 21.72611046], [88.38445282, 21.72583961], [88.38276672, 21.72583961], [88.38249969, 21.72556114], [88.38195038, 21.72556114], [88.38166809, 21.72583961], [88.3813858, 21.72556114], [88.37999725, 21.72556114], [88.3797226, 21.72528076], [88.37832642, 21.72528076], [88.3777771, 21.72472], [88.37722015, 21.72472191], [88.37695313, 21.72500038], [88.37666321, 21.72500038], [88.37631989, 21.72495079], [88.3759613, 21.72478485], [88.37554169, 21.72467422], [88.37516022, 21.72448349], [88.37472534, 21.72439957], [88.37433624, 21.72421074], [88.37391663, 21.7241497], [88.37352753, 21.72405815], [88.37317657, 21.72392082], [88.37280273, 21.7238884], [88.37239838, 21.72386169], [88.37201691, 21.72373962], [88.3716507, 21.72363091], [88.37126923, 21.72364426], [88.37107849, 21.72373009], [88.37090302, 21.7238102], [88.37047577, 21.72397041], [88.37008667, 21.72418976], [88.36974335, 21.7244606], [88.3694458, 21.72478294], [88.36917114, 21.7251358], [88.36894989, 21.72553253], [88.36885071, 21.72602654], [88.36868286, 21.72648048], [88.36862183, 21.72693062], [88.36863708, 21.7273407], [88.3687973, 21.72768784], [88.3690033, 21.72802353], [88.36929321, 21.72832108], [88.36964417, 21.72861099], [88.37006378, 21.72888565], [88.3705368, 21.72911072], [88.37110138, 21.7292099], [88.37155914, 21.72943115], [88.37200165, 21.7296257], [88.37249756, 21.72972107], [88.37277985, 21.72999954], [88.37333679, 21.72999954], [88.37361145, 21.73027992], [88.37388611, 21.73027992], [88.375, 21.73083305], [88.37527466, 21.73083305], [88.37555695, 21.73055649], [88.37611389, 21.73027992], [88.37652588, 21.73069191], [88.3769455, 21.73111153], [88.3777771, 21.73110962], [88.37805176, 21.73138809], [88.37999725, 21.73138809], [88.38041687, 21.73162079], [88.38095856, 21.73171043], [88.38145447, 21.73190689], [88.38198853, 21.73200035], [88.38240814, 21.73217964], [88.38288879, 21.73227501], [88.38334656, 21.73250008], [88.38382721, 21.73282814], [88.38427734, 21.73295975], [88.38461304, 21.73310089], [88.38508606, 21.73311234], [88.38523102, 21.73315048], [88.38562012, 21.73321342], [88.38651276, 21.73365974], [88.38674164, 21.73385048], [88.38718414, 21.73451614], [88.38751221, 21.73483086], [88.38771057, 21.73507118], [88.38774872, 21.73538971], [88.38801575, 21.73560524], [88.388237, 21.73587036], [88.38845825, 21.7362175], [88.38877106, 21.73656082], [88.38909912, 21.73693848], [88.38942719, 21.73731995], [88.38975525, 21.73770905], [88.39006805, 21.73808289], [88.39044952, 21.73838043], [88.39070129, 21.73868942], [88.39097595, 21.73913193], [88.3911972, 21.73958015], [88.39161682, 21.74006081], [88.3916626, 21.74073029], [88.39167023, 21.7408371], [88.39193726, 21.74134064], [88.39203644, 21.7414608], [88.391922, 21.74221039], [88.3920517, 21.74259758], [88.39219666, 21.74298096], [88.39221954, 21.74341583], [88.39221954, 21.74385071], [88.39221954, 21.74430084], [88.39222717, 21.74477005], [88.39225006, 21.74522972], [88.39228821, 21.74570084], [88.39245605, 21.74611092], [88.39250183, 21.74653053], [88.39256287, 21.74695969], [88.39274597, 21.74734116], [88.39290619, 21.74775505], [88.39308167, 21.74814415], [88.3932724, 21.74850082], [88.39334106, 21.74894142], [88.39344025, 21.74940109], [88.39363098, 21.7498703], [88.3938446, 21.75035477], [88.39393616, 21.75087166], [88.3940506, 21.75141335], [88.39389038, 21.75194359], [88.39389038, 21.75234985], [88.39389038, 21.75277519], [88.39444733, 21.75333595], [88.39444733, 21.75444031], [88.39499664, 21.75500107], [88.3951416, 21.75485992], [88.39527893, 21.7547226], [88.39585876, 21.75447464], [88.39627838, 21.75417519], [88.39672089, 21.75389099], [88.39722443, 21.75363922], [88.39779663, 21.75345993], [88.39842224, 21.75328827], [88.39898682, 21.75304985], [88.3995285, 21.75275993], [88.40000916, 21.75241661], [88.40035248, 21.75193024], [88.40062714, 21.75138092], [88.40085602, 21.75082016], [88.40104675, 21.75024033], [88.40110016, 21.74962044], [88.40106201, 21.74901009], [88.40090942, 21.74844933], [88.40084839, 21.74786949], [88.4008255, 21.7473278], [88.40075684, 21.74685097], [88.4005661, 21.74644089], [88.400383, 21.74604034], [88.40019989, 21.74561882], [88.39998627, 21.74518967], [88.39981842, 21.74477196], [88.39974213, 21.74431801], [88.39971924, 21.74388123], [88.39972687, 21.74347115], [88.39980316, 21.74310112], [88.39994812, 21.74278069], [88.40009308, 21.74241066], [88.40022278, 21.7420063], [88.40032959, 21.74154091], [88.40048218, 21.7410984], [88.40055847, 21.74067116], [88.40062714, 21.74026108], [88.40077209, 21.73991966], [88.40087891, 21.73956108], [88.40100861, 21.73925209], [88.40113831, 21.73894882], [88.40129852, 21.73867035], [88.40142059, 21.73838997], [88.40158081, 21.73812103], [88.40177155, 21.73782539], [88.40206146, 21.73752022], [88.40248108, 21.73720169], [88.40294647, 21.73685074], [88.40341187, 21.73649979], [88.40391541, 21.73625565], [88.40441895, 21.73612022], [88.40492249, 21.73603058], [88.4054184, 21.73587036], [88.40593719, 21.73580742], [88.40647125, 21.73574066], [88.40698242, 21.73558044], [88.40748596, 21.73545837], [88.40792084, 21.73521996], [88.40834045, 21.73493958], [88.40880585, 21.73464966], [88.4092865, 21.73434639], [88.40970612, 21.73398018], [88.41009521, 21.7336216], [88.41047668, 21.73329735], [88.4108429, 21.73298073], [88.41120148, 21.73265266], [88.41153717, 21.73223114], [88.41192627, 21.73176956], [88.41233826, 21.7312603], [88.41271973, 21.7306881], [88.41306305, 21.73009872], [88.41342926, 21.72954178], [88.41384888, 21.72906113], [88.41427612, 21.72859001], [88.41468811, 21.7281189], [88.41514587, 21.72770119], [88.41552734, 21.72722054], [88.41583252, 21.72670364], [88.41610718, 21.7262249], [88.41636658, 21.72579193], [88.4165802, 21.72538185], [88.41682434, 21.72503281], [88.41710663, 21.72472954], [88.41741943, 21.72443008], [88.4177475, 21.72409821], [88.4180603, 21.72365952], [88.41833496, 21.72314835], [88.41864777, 21.72257042], [88.41900635, 21.72198105], [88.41944122, 21.72142029], [88.41956329, 21.7212925], [88.41992188, 21.72092247], [88.42041016, 21.72048187], [88.42085266, 21.72002029], [88.42127991, 21.71956062], [88.42170715, 21.7191124], [88.42195129, 21.71861076], [88.42214966, 21.71813011], [88.42232513, 21.71768188], [88.42248535, 21.71722603], [88.42259216, 21.71672821], [88.42276764, 21.71623039], [88.42292023, 21.71569061], [88.42307281, 21.7151413], [88.42326355, 21.71459579], [88.42337036, 21.7140007], [88.42340851, 21.71366119], [88.42354584, 21.71137047], [88.42455292, 21.70935631], [88.42556, 21.7071991], [88.42655945, 21.7055912], [88.42713165, 21.70478058], [88.42784882, 21.70357323], [88.42856598, 21.70255852], [88.42856598, 21.70201111], [88.42832184, 21.70154953], [88.42797852, 21.7011528], [88.42758942, 21.70078087], [88.42723846, 21.70040512], [88.42691803, 21.7000103], [88.4265213, 21.69971085], [88.42613983, 21.69944572], [88.4257431, 21.69922256], [88.42527771, 21.69916534], [88.42444611, 21.69917107], [88.42415619, 21.69890022], [88.42360687, 21.69890022], [88.42333221, 21.69861031], [88.42305756, 21.69861031], [88.4227829, 21.69832993], [88.42250061, 21.69833565], [88.4223938, 21.69822502], [88.42222595, 21.69805336], [88.42193604, 21.69806099], [88.42159271, 21.69787025], [88.42115021, 21.69775009], [88.42048645, 21.69779015], [88.42022705, 21.69761086], [88.41993713, 21.69750977], [88.41979218, 21.69745827], [88.41954041, 21.69721031], [88.41816711, 21.69658279], [88.41716766, 21.69551086], [88.41487885, 21.69334984], [88.41330719, 21.69106674], [88.41282654, 21.68864059], [88.41279602, 21.6884861], [88.41274261, 21.68811035], [88.41253662, 21.68750954], [88.41239929, 21.68686104], [88.41191864, 21.68624115], [88.41183472, 21.68610573], [88.41156006, 21.68567276], [88.41152191, 21.68512917], [88.41151428, 21.68495369], [88.41151428, 21.68421936], [88.41136932, 21.68391037], [88.41136932, 21.68351936], [88.41165924, 21.68318176], [88.4118042, 21.68134689], [88.41152191, 21.68000031], [88.41179657, 21.67865944], [88.4122467, 21.67756081], [88.41238403, 21.67732239], [88.41226196, 21.67675209], [88.41233826, 21.67638969], [88.41265869, 21.67592239], [88.41261292, 21.67548943], [88.41305542, 21.67507553], [88.41308594, 21.67461014], [88.4132309, 21.67424965], [88.41331482, 21.6738987], [88.41333771, 21.67349052], [88.41338348, 21.67303276], [88.41356659, 21.67252922], [88.41365814, 21.67194939], [88.41368103, 21.67119026], [88.41323853, 21.67064095], [88.41268158, 21.66930389], [88.41225433, 21.66849518], [88.41196442, 21.66782379], [88.41182709, 21.66741943], [88.41226196, 21.66655159], [88.4121933, 21.66609383], [88.4120636, 21.66566467], [88.41195679, 21.66524124], [88.41194153, 21.6647892], [88.41192627, 21.66432953], [88.41182709, 21.66389084], [88.41174316, 21.66345978], [88.41168976, 21.66302109], [88.41166687, 21.66257095], [88.41162872, 21.66210175], [88.41150665, 21.66161728], [88.41140747, 21.66108131], [88.41131592, 21.66051292], [88.41114807, 21.66000175], [88.41110992, 21.65951538], [88.41110992, 21.65908051], [88.41116333, 21.6586628], [88.41133881, 21.6582737], [88.41137695, 21.65784073], [88.41143036, 21.65736961], [88.41161346, 21.65696144], [88.41169739, 21.65650177], [88.41186523, 21.65607452], [88.41204071, 21.65564156], [88.41203308, 21.65513802], [88.41221619, 21.65458107], [88.41240692, 21.65418053], [88.41253662, 21.65359116], [88.41279602, 21.65302086], [88.41305542, 21.65249062], [88.41333008, 21.65196991], [88.41361237, 21.65147018], [88.41387177, 21.6509819], [88.41409302, 21.6505146], [88.41424561, 21.65006065], [88.41442108, 21.6496582], [88.41454315, 21.64923096], [88.41473389, 21.64885139], [88.41498566, 21.64848518], [88.41523743, 21.6480999], [88.41555023, 21.64774895], [88.41584015, 21.64736938], [88.41616821, 21.64699554], [88.41654968, 21.64661407], [88.41692352, 21.64614868], [88.4173584, 21.64569092], [88.4178009, 21.64524078], [88.41797638, 21.64488029], [88.41822052, 21.64437103], [88.41842651, 21.64405823], [88.41882324, 21.64380264], [88.41934204, 21.64354324], [88.41999817, 21.64315987], [88.42069244, 21.64278412], [88.42095184, 21.64249992], [88.42121887, 21.64223099], [88.42151642, 21.64198112], [88.42191315, 21.64176941], [88.42228699, 21.64146042], [88.42272186, 21.64117241], [88.42307281, 21.64084053], [88.42339325, 21.64056778], [88.42368317, 21.64034081], [88.42397308, 21.64017868], [88.42421722, 21.63996124], [88.42450714, 21.63972282], [88.42482758, 21.63943863], [88.42518616, 21.63913536], [88.42552948, 21.63877106], [88.42582703, 21.63834572], [88.42610931, 21.63788986], [88.4263916, 21.63742065], [88.42666626, 21.63695145], [88.42693329, 21.63648987], [88.42722321, 21.63603973], [88.42755127, 21.63563919], [88.42790222, 21.63528824], [88.42822266, 21.63498116], [88.42843628, 21.63463974], [88.42867279, 21.63438034], [88.42887878, 21.63414001], [88.429039, 21.63388062], [88.42917633, 21.63362122], [88.42935181, 21.63339996], [88.42945099, 21.63311005], [88.42954254, 21.6328373], [88.42967224, 21.63260078], [88.42974854, 21.6323185], [88.42988586, 21.63203049], [88.43001556, 21.63170815], [88.43016815, 21.63133812], [88.43031311, 21.63090134], [88.43056488, 21.63049316], [88.43086243, 21.63007927], [88.43119049, 21.62965965], [88.43154907, 21.62924957], [88.43179321, 21.62875938], [88.43192291, 21.62827682], [88.4319458, 21.62780952], [88.43193817, 21.62735939], [88.43187714, 21.62692833], [88.43174744, 21.62656975], [88.4311142, 21.62555504], [88.43110657, 21.62528038], [88.43083191, 21.62500191], [88.43055725, 21.6241684], [88.43055725, 21.62388992], [88.43026733, 21.62361908], [88.43026733, 21.62333107], [88.42973328, 21.62278938], [88.4291687, 21.6222229], [88.4291687, 21.62194443], [88.42888641, 21.62166786], [88.42861176, 21.62166977], [88.42804718, 21.62111092], [88.42722321, 21.62111092], [88.42693329, 21.62083054], [88.42666626, 21.62083244], [88.42610931, 21.6202755], [88.42582703, 21.62028122], [88.42555237, 21.62000084], [88.42527771, 21.62000084], [88.42472076, 21.61944008], [88.42444611, 21.61944008], [88.42388916, 21.62000084], [88.42360687, 21.62000084], [88.42333221, 21.62028122], [88.42305756, 21.62028122], [88.42222595, 21.61944008], [88.42138672, 21.6194458], [88.42111206, 21.61972237], [88.42028046, 21.61972046], [88.41999817, 21.62000084], [88.41889191, 21.62000084], [88.41860962, 21.61972046], [88.41833496, 21.61972237], [88.4180603, 21.62000084], [88.41777802, 21.62000084], [88.41750336, 21.61972046], [88.41666412, 21.61972237], [88.41638947, 21.6194458], [88.41610718, 21.61972046], [88.41610718, 21.62000084], [88.41583252, 21.6202755], [88.41583252, 21.62055779], [88.41555786, 21.62083244], [88.41499329, 21.62083054], [88.41471863, 21.62111092], [88.41443634, 21.62111092], [88.41416931, 21.62138939], [88.41416931, 21.62249947], [88.41388702, 21.62249947], [88.41361237, 21.62277985], [88.41333008, 21.62277985], [88.41305542, 21.62250137], [88.41278076, 21.62222099], [88.41278076, 21.62055779], [88.41166687, 21.6194458], [88.41139221, 21.6194458], [88.41110992, 21.61916733], [88.41055298, 21.61917114], [88.41027832, 21.61889076], [88.40999603, 21.61889076], [88.40777588, 21.61667061], [88.40777588, 21.61639023], [88.40750122, 21.61610985], [88.40750122, 21.61583138], [88.40721893, 21.61555481], [88.40721893, 21.61444473], [88.40805817, 21.61361122], [88.40833282, 21.61361122], [88.40860748, 21.61333275], [88.40860748, 21.61322594], [88.40836334, 21.61297035], [88.40810394, 21.61271286], [88.40789032, 21.61240959], [88.40773773, 21.61202049], [88.40777588, 21.6119442], [88.40750122, 21.61166573], [88.40750122, 21.61138916], [88.40721893, 21.61111069], [88.40721893, 21.6108284], [88.40694427, 21.61055565], [88.40693665, 21.60972023], [88.40721893, 21.60944366], [88.40721893, 21.60888863], [88.40693665, 21.60861015], [88.40666962, 21.60861206], [88.40638733, 21.60833359], [88.40555573, 21.60833359], [88.40555573, 21.6072216], [88.40611267, 21.60666466], [88.4061203, 21.60610962], [88.40555573, 21.60555649], [88.40555573, 21.60444641], [88.40583038, 21.60416412], [88.40583038, 21.60388947], [88.4061203, 21.60361099], [88.40611267, 21.60333252], [88.40638733, 21.60305405], [88.40638733, 21.60222054], [88.40648651, 21.60212326], [88.40666962, 21.60194206], [88.40666962, 21.60138893], [88.40692902, 21.60110092], [88.40701294, 21.60087013], [88.40718842, 21.60069084], [88.40740204, 21.60046768], [88.40751648, 21.60001945], [88.40748596, 21.59951401], [88.40721893, 21.59916687], [88.40638733, 21.59833145], [88.40583038, 21.59833336], [88.40496063, 21.59745979], [88.40472412, 21.59722137], [88.40444183, 21.59722137], [88.40361023, 21.59805489], [88.40333557, 21.59805489], [88.40309143, 21.59782028], [88.40305328, 21.59749985], [88.40277863, 21.59721756], [88.40277863, 21.59694481], [88.40194702, 21.5961113], [88.40194702, 21.59555626], [88.40055847, 21.59555626], [88.40027618, 21.59583282], [88.39916992, 21.59583282], [88.39888763, 21.59555626], [88.39861298, 21.59555626], [88.39833069, 21.59583092], [88.39826965, 21.59589005], [88.3980484, 21.59609795], [88.39782715, 21.59638023], [88.39774323, 21.59679031], [88.39758301, 21.59717178], [88.39750671, 21.59757614], [88.39749908, 21.59804916], [88.39749908, 21.59916687], [88.39694214, 21.59972191], [88.39694214, 21.60000038], [88.39499664, 21.60194206], [88.39499664, 21.60222244], [88.39389038, 21.60222244], [88.39277649, 21.60333061], [88.39277649, 21.60361099], [88.39250183, 21.60388947], [88.39250183, 21.60472107], [88.39221954, 21.60499954], [88.39221954, 21.60639], [88.39193726, 21.60667038], [88.39194489, 21.60694695], [88.39167023, 21.6072216], [88.39027405, 21.6072216], [88.38916779, 21.60832024], [88.38916779, 21.60888863], [88.38819122, 21.60994148], [88.38774872, 21.61041451], [88.38736725, 21.61148071], [88.38745117, 21.61190987], [88.38736725, 21.61235046], [88.38725281, 21.61283112], [88.38726044, 21.61334801], [88.38743591, 21.61375046], [88.38768005, 21.61404991], [88.3878479, 21.61446953], [88.38800812, 21.61495972], [88.38804626, 21.61548996], [88.38807678, 21.61593819], [88.38825226, 21.61628914], [88.38848877, 21.61658478], [88.38864899, 21.61693954], [88.3888855, 21.61727905], [88.38916016, 21.61766052], [88.38916779, 21.61778069], [88.38999939, 21.61861038], [88.38999939, 21.61889076], [88.39027405, 21.61916733], [88.39027405, 21.61991119], [88.39027405, 21.62055779], [88.39055634, 21.62083244], [88.39055634, 21.62194061], [88.38999939, 21.62249947], [88.38999939, 21.62277985], [88.38972473, 21.62305641], [88.3897171, 21.62333107], [88.38944244, 21.62361908], [88.38944244, 21.62416649], [88.3888855, 21.62472153], [88.3888855, 21.62500191], [88.38805389, 21.62583351], [88.38777924, 21.6258316], [88.38722229, 21.62639046], [88.38667297, 21.62639046], [88.38639069, 21.62668037], [88.38608551, 21.62666893], [88.38576508, 21.6267643], [88.38557434, 21.62689018], [88.38545227, 21.62697029], [88.38510895, 21.62724113], [88.38474274, 21.62759972], [88.38444519, 21.62808228], [88.38417816, 21.62860107], [88.38394165, 21.62909126], [88.38368225, 21.62945938], [88.38348389, 21.62979317], [88.38339233, 21.63027954], [88.3833313, 21.63104439], [88.38331604, 21.63150978], [88.38331604, 21.6319809], [88.38342285, 21.63258743], [88.38358307, 21.63303185], [88.38361359, 21.63348961], [88.38360596, 21.63393974], [88.38359833, 21.63436127], [88.38350677, 21.63472748], [88.38339233, 21.6350708], [88.38337708, 21.63555908], [88.38343811, 21.63624001], [88.38367462, 21.63691902], [88.38405609, 21.63739014], [88.38440704, 21.63777924], [88.38468933, 21.63813972], [88.38490295, 21.63856125], [88.38498688, 21.63912964], [88.3850174, 21.6397953], [88.38512421, 21.64051628], [88.38529968, 21.64113998], [88.38555145, 21.64175034], [88.38581848, 21.64232063], [88.3860321, 21.64284706], [88.3861618, 21.6433506], [88.38637543, 21.64376831], [88.38654327, 21.64420128], [88.3866806, 21.64468765], [88.38683319, 21.64518166], [88.38696289, 21.64568138], [88.38713074, 21.64613152], [88.3871994, 21.6465416], [88.38777924, 21.64694023], [88.38722229, 21.64750099], [88.38722229, 21.64916611], [88.38694763, 21.64944458], [88.38694763, 21.64972305], [88.38667297, 21.64999962], [88.38666534, 21.65055466], [88.38646698, 21.65081215], [88.3862381, 21.65109062], [88.38595581, 21.65133095], [88.38581085, 21.65164185], [88.38562012, 21.65191269], [88.38547516, 21.65229607], [88.38531494, 21.6527729], [88.38527679, 21.65336037], [88.38529968, 21.65398979], [88.38536835, 21.65459061], [88.38526154, 21.65513039], [88.38507843, 21.65559959], [88.38491821, 21.65603256], [88.38469696, 21.65639114], [88.38448334, 21.65674019], [88.38426208, 21.65713501], [88.38404846, 21.65757942], [88.38379669, 21.65802765], [88.38349915, 21.65841103], [88.38313293, 21.65872192], [88.38285828, 21.65908051], [88.38259888, 21.65944099], [88.38233185, 21.65979004], [88.3821106, 21.6602211], [88.38187408, 21.66057777], [88.38166046, 21.66096115], [88.3814621, 21.66131973], [88.38127899, 21.66167641], [88.38114166, 21.66208076], [88.3811264, 21.66258812], [88.38121796, 21.66315269], [88.38140869, 21.66373062], [88.38166046, 21.66427994], [88.38195038, 21.66443825], [88.38194275, 21.66527748], [88.38208008, 21.66541672], [88.38277435, 21.66610909], [88.38208771, 21.66703415], [88.38195038, 21.66722107]]], [[[89.05430603, 21.61780357], [89.05337524, 21.61793709], [89.05309296, 21.61834145], [89.05258942, 21.61834145], [89.05208588, 21.61793709], [89.05194855, 21.61780357], [89.05187225, 21.61753464], [89.05158997, 21.61753082], [89.05143738, 21.61774063], [89.05130768, 21.61774063], [89.05108643, 21.61814117], [89.05094147, 21.61833954], [89.05072784, 21.61848068], [89.05045319, 21.61868095], [89.05016327, 21.61888123], [89.04979706, 21.61921692], [89.04972839, 21.61955261], [89.04950714, 21.61989021], [89.04943848, 21.62022591], [89.04892731, 21.62055016], [89.04836273, 21.62089539], [89.04794312, 21.62123108], [89.04750824, 21.62157059], [89.04707336, 21.62217522], [89.04664612, 21.62243843], [89.04638672, 21.62276077], [89.04541779, 21.62333107], [89.04431915, 21.62436104], [89.04411316, 21.62463951], [89.04396057, 21.62483025], [89.04353333, 21.6252346], [89.0433197, 21.62543106], [89.04316711, 21.62564278], [89.0426712, 21.62610817], [89.04238892, 21.62643814], [89.04217529, 21.62664795], [89.04189301, 21.62697983], [89.04123688, 21.62738991], [89.04102325, 21.62759018], [89.0406723, 21.62778854], [89.0402298, 21.6281929], [89.03987885, 21.62859535], [89.03952026, 21.62892914], [89.03923798, 21.62927055], [89.03887939, 21.6296711], [89.03866577, 21.62986946], [89.03837585, 21.63020897], [89.03830719, 21.63034058], [89.0382309, 21.63047981], [89.03805542, 21.6305542], [89.03778076, 21.63083267], [89.03749847, 21.63083076], [89.03694153, 21.63138962], [89.03666687, 21.63138962], [89.03639221, 21.63167], [89.03610992, 21.63166428], [89.03555298, 21.63222313], [89.03504944, 21.6328907], [89.03475952, 21.63310051], [89.03469086, 21.63330269], [89.03447723, 21.63357162], [89.03418732, 21.6341095], [89.03418732, 21.63471031], [89.03425598, 21.63517952], [89.03440094, 21.63552284], [89.03469086, 21.63605499], [89.03497314, 21.63631821], [89.0351181, 21.63672638], [89.03526306, 21.63706017], [89.03547668, 21.63754082], [89.03590393, 21.63820648], [89.03626251, 21.63874054], [89.03655243, 21.63921547], [89.03705597, 21.63974953], [89.03740692, 21.6398201], [89.03769684, 21.64009094], [89.03769684, 21.64029121], [89.03762817, 21.64056015], [89.03733826, 21.64069939], [89.03697968, 21.64056015], [89.03647614, 21.64022064], [89.03604889, 21.63988876], [89.03569031, 21.63941956], [89.03518677, 21.63894844], [89.03504944, 21.63853836], [89.03475952, 21.6380043], [89.0345459, 21.63766861], [89.03425598, 21.63726997], [89.03404236, 21.63680077], [89.03391266, 21.63659096], [89.03382874, 21.63618851], [89.03368378, 21.63605499], [89.03362274, 21.63558006], [89.03347015, 21.63518143], [89.03333282, 21.63471031], [89.03318787, 21.63451004], [89.03296661, 21.63425064], [89.03275299, 21.63397026], [89.03253937, 21.63375092], [89.03090668, 21.63380051], [89.02999878, 21.63417053], [89.02979279, 21.63430023], [89.02944183, 21.63445091], [89.0289917, 21.63478088], [89.02884674, 21.63504982], [89.02848816, 21.63531876], [89.02841949, 21.63565254], [89.02841949, 21.63699722], [89.02855682, 21.63713074], [89.02856445, 21.6375351], [89.02863312, 21.63772964], [89.02848816, 21.63801003], [89.02848816, 21.63874817], [89.02841949, 21.63908386], [89.02820587, 21.63948631], [89.02806091, 21.63982582], [89.02798462, 21.64009476], [89.02797699, 21.64035034], [89.02791595, 21.64076614], [89.02755737, 21.64110184], [89.02741241, 21.64143753], [89.02726746, 21.64176941], [89.02713776, 21.64217949], [89.0269165, 21.64258003], [89.02662659, 21.64285088], [89.02648163, 21.64332008], [89.02612305, 21.64365959], [89.02605438, 21.64392662], [89.02619934, 21.64500237], [89.02648163, 21.64526939], [89.02677155, 21.64574051], [89.02705383, 21.64634705], [89.02707672, 21.64672089], [89.0273056, 21.64798737], [89.02735138, 21.64818954], [89.02749634, 21.64888954], [89.02777863, 21.64944077], [89.02784729, 21.64979935], [89.02805328, 21.65027809], [89.02862549, 21.65062332], [89.02868652, 21.6511097], [89.02861023, 21.65166664], [89.02805328, 21.65333176], [89.02778625, 21.65389061], [89.02749634, 21.6541996], [89.0275116, 21.65457916], [89.02722168, 21.65472221], [89.02694702, 21.65506172], [89.02639008, 21.65611076], [89.02610779, 21.65638924], [89.02610779, 21.65694237], [89.02619171, 21.65742493], [89.02640533, 21.65813255], [89.02719879, 21.65854454], [89.02806091, 21.65848541], [89.02913666, 21.65815926], [89.02966309, 21.65776062], [89.03015137, 21.65721321], [89.0307312, 21.65671158], [89.03131866, 21.65617943], [89.03151703, 21.6558094], [89.03188324, 21.65519333], [89.03240204, 21.6547451], [89.03273773, 21.65452957], [89.03304291, 21.65467453], [89.03283691, 21.65528107], [89.03244781, 21.65579414], [89.03208923, 21.65620995], [89.03160858, 21.65687943], [89.03108215, 21.65729523], [89.03044891, 21.6578083], [89.03000641, 21.65823174], [89.0296936, 21.65852547], [89.02908325, 21.65896988], [89.02806091, 21.65937614], [89.02725983, 21.65945816], [89.02571106, 21.6595974], [89.02542877, 21.65965462], [89.02500916, 21.65991974], [89.02459717, 21.66047859], [89.02424622, 21.6606102], [89.0238266, 21.66075516], [89.02348328, 21.66082001], [89.022995, 21.66096687], [89.02235413, 21.66104317], [89.02166748, 21.66110992], [89.02126312, 21.66167068], [89.02111053, 21.66194916], [89.02090454, 21.66235733], [89.02089691, 21.66290092], [89.02106476, 21.66325951], [89.02160645, 21.66374969], [89.02175903, 21.66396523], [89.02196503, 21.66451263], [89.02189636, 21.66535187], [89.02194977, 21.66589928], [89.02217102, 21.66651917], [89.02236176, 21.6668129], [89.02258301, 21.66708946], [89.022995, 21.66750908], [89.0230484, 21.66785049], [89.02341461, 21.66819954], [89.02340698, 21.66854286], [89.02368927, 21.66888809], [89.02376556, 21.66965485], [89.02390289, 21.67074013], [89.02375793, 21.67187691], [89.02368927, 21.67268944], [89.02362061, 21.67362976], [89.02355957, 21.67424011], [89.02348328, 21.6747303], [89.02355194, 21.67534447], [89.02362061, 21.67604065], [89.02368164, 21.67638969], [89.02390289, 21.67715073], [89.02388763, 21.67749977], [89.02403259, 21.68001747], [89.02416992, 21.68083191], [89.02430725, 21.68097687], [89.02437592, 21.68132019], [89.02458954, 21.68187714], [89.02471924, 21.68222237], [89.02500916, 21.6826458], [89.02527618, 21.68333244], [89.02548981, 21.68354034], [89.02555847, 21.68388939], [89.02583313, 21.68443108], [89.02604675, 21.68507957], [89.02610779, 21.6855545], [89.02619171, 21.68610191], [89.02633667, 21.68743324], [89.02641296, 21.68791008], [89.02632904, 21.68847084], [89.02597809, 21.68908119], [89.02575684, 21.69000053], [89.0256958, 21.69034767], [89.02555847, 21.69055557], [89.02548981, 21.69110107], [89.02506256, 21.69236565], [89.02500153, 21.6927681], [89.02500153, 21.69361115], [89.02472687, 21.69486046], [89.02452087, 21.69514275], [89.02410126, 21.69624519], [89.02396393, 21.69652367], [89.02355194, 21.69742393], [89.02348328, 21.6977005], [89.02320862, 21.69819069], [89.02313232, 21.69868088], [89.02285767, 21.69896126], [89.02200317, 21.70038033], [89.01999664, 21.70166779], [89.01979065, 21.70173454], [89.01944733, 21.70194054], [89.01895905, 21.70207977], [89.01860809, 21.70222092], [89.01832581, 21.70228958], [89.01805878, 21.70249939], [89.0174408, 21.70283508], [89.01694489, 21.70284462], [89.01625061, 21.70290947], [89.01583099, 21.70305824], [89.01438904, 21.70325851], [89.01361084, 21.7033329], [89.01311493, 21.70325851], [89.01212311, 21.70330429], [89.01174927, 21.70332527], [89.0111084, 21.70332909], [89.01062775, 21.70346642], [89.01027679, 21.70361137], [89.01000214, 21.70374107], [89.00979614, 21.70487022], [89.00995636, 21.7052784], [89.01016235, 21.70589066], [89.01051331, 21.7064476], [89.01036835, 21.70705986], [89.01049805, 21.70754051], [89.01076508, 21.70791245], [89.01154327, 21.70776939], [89.01194763, 21.70792961], [89.01222229, 21.70833206], [89.01259613, 21.70852661], [89.01277924, 21.70862007], [89.0135498, 21.70862007], [89.01390076, 21.70833969], [89.01499939, 21.70827484], [89.01555634, 21.7080555], [89.01750183, 21.70806122], [89.01848602, 21.70820808], [89.01917267, 21.70854378], [89.01951599, 21.70874977], [89.01998901, 21.70889282], [89.0203476, 21.70910072], [89.02098846, 21.70923233], [89.02201843, 21.71008682], [89.02237701, 21.71063232], [89.02250671, 21.7110405], [89.02265167, 21.71159935], [89.02300262, 21.71275139], [89.02292633, 21.71403122], [89.02229309, 21.71484947], [89.0222168, 21.71528053], [89.02289581, 21.7161293], [89.02360535, 21.71653175], [89.02409363, 21.71674347], [89.02444458, 21.7166748], [89.02471924, 21.71666718], [89.02555847, 21.71666908], [89.02590179, 21.71687889], [89.02612305, 21.71693993], [89.02667236, 21.71708679], [89.02722168, 21.7172184], [89.02755737, 21.71730232], [89.02805328, 21.71736526], [89.02861786, 21.71744156], [89.02999878, 21.71777916], [89.03028107, 21.71805954], [89.03083038, 21.71805573], [89.03111267, 21.7183342], [89.03138733, 21.71832848], [89.03166962, 21.71861076], [89.03221893, 21.71861076], [89.03277588, 21.71916962], [89.03305817, 21.7191658], [89.0331955, 21.71930504], [89.03333282, 21.71944427], [89.03360748, 21.71944427], [89.03388977, 21.71972275], [89.03444672, 21.71970749], [89.03472137, 21.72000122], [89.0358429, 21.72000122], [89.03610992, 21.72027969], [89.03694153, 21.72027969], [89.03721619, 21.72056007], [89.03861237, 21.72055626], [89.03879547, 21.72074127], [89.03888702, 21.72083282], [89.03916931, 21.72055626], [89.03971863, 21.72055626], [89.04000092, 21.72083282], [89.04083252, 21.72083282], [89.04135895, 21.72085953], [89.04279327, 21.72085953], [89.0431366, 21.7209301], [89.0435791, 21.72113037], [89.04371643, 21.72113037], [89.04415131, 21.72119713], [89.04437256, 21.72126007], [89.04450989, 21.72133064], [89.04486847, 21.72146606], [89.04515839, 21.72153282], [89.04544067, 21.72159958], [89.04593658, 21.72167015], [89.04715729, 21.72167015], [89.04773712, 21.72174072], [89.04830933, 21.72174072], [89.04973602, 21.72159958], [89.05002594, 21.72159958], [89.05045319, 21.72174072], [89.05088806, 21.72187042], [89.0513382, 21.72186852], [89.05483246, 21.72187042], [89.05548096, 21.72180176], [89.056633, 21.72180176], [89.05699158, 21.72187042], [89.05741119, 21.72187042], [89.05848694, 21.7220726], [89.05885315, 21.7220726], [89.05905914, 21.72200394], [89.0592041, 21.72180367], [89.05941772, 21.72173309], [89.05978394, 21.7218132], [89.05983734, 21.7219429], [89.06041718, 21.7219429], [89.06070709, 21.72174072], [89.06092072, 21.72146988], [89.06112671, 21.7210598], [89.06099701, 21.72043991], [89.06128693, 21.7201004], [89.06164551, 21.71990204], [89.06193542, 21.71949959], [89.06214905, 21.71923065], [89.06223297, 21.71883011], [89.06228638, 21.71856117], [89.06236267, 21.71821976], [89.06250763, 21.71788406], [89.06278992, 21.71734619], [89.06299591, 21.7171402], [89.06321716, 21.71707726], [89.06343842, 21.71693993], [89.0637207, 21.7166748], [89.06401062, 21.7163372], [89.06414795, 21.7159996], [89.06443787, 21.71566582], [89.06450653, 21.71545982], [89.06465149, 21.71526146], [89.06494141, 21.71506119], [89.06522369, 21.71452332], [89.06522369, 21.71391678], [89.06529999, 21.71351051], [89.06536865, 21.71317673], [89.06536865, 21.71257019], [89.06543732, 21.71236992], [89.06550598, 21.71210098], [89.06558228, 21.71162987], [89.06565857, 21.71122742], [89.0657959, 21.71103287], [89.0657959, 21.71068192], [89.06594086, 21.71035576], [89.06594086, 21.70994949], [89.06608582, 21.70955086], [89.06623077, 21.70920753], [89.06643677, 21.70874023], [89.06665802, 21.70833969], [89.06681824, 21.7080822], [89.0668869, 21.70801353], [89.06715393, 21.7077446], [89.06729889, 21.70759583], [89.06758881, 21.70740128], [89.06777954, 21.70722008], [89.0680542, 21.70694351], [89.06821442, 21.7063942], [89.06829071, 21.70625877], [89.06829071, 21.70578957], [89.0684967, 21.70539093], [89.06871796, 21.70518112], [89.0687561, 21.70510101], [89.06886292, 21.70484734], [89.06893158, 21.7047081], [89.0691452, 21.70451164], [89.06929016, 21.70424271], [89.06958008, 21.70390511], [89.06965637, 21.70363998], [89.06971741, 21.70343018], [89.06986237, 21.70330048], [89.07015228, 21.7027607], [89.07028961, 21.70229149], [89.07036591, 21.70202255], [89.07057953, 21.70175362], [89.07057953, 21.70108223], [89.07064819, 21.70094681], [89.07064819, 21.69973946], [89.07071686, 21.69953918], [89.07071686, 21.69779015], [89.07079315, 21.69745064], [89.07086182, 21.69725037], [89.07086182, 21.69663811], [89.07079315, 21.69637489], [89.07064819, 21.69597054], [89.07057953, 21.69582939], [89.07051086, 21.69563484], [89.07022095, 21.69529915], [89.06954956, 21.69485283], [89.0694046, 21.69451714], [89.06925964, 21.69417953], [89.06925964, 21.69296837], [89.06921387, 21.69284248], [89.06912231, 21.69256592], [89.06890106, 21.69215965], [89.06861877, 21.69169235], [89.06840515, 21.69128609], [89.06826019, 21.69108963], [89.06826019, 21.69087982], [89.06811523, 21.69061661], [89.06797028, 21.69041061], [89.06768799, 21.69014549], [89.06739807, 21.68988037], [89.06726074, 21.68974113], [89.06690216, 21.68967247], [89.06604004, 21.68967247], [89.06568146, 21.68974113], [89.06546783, 21.68981171], [89.06510925, 21.69028091], [89.06496429, 21.69034767], [89.064888, 21.69035912], [89.06453705, 21.69041443], [89.06453705, 21.69021225], [89.06460571, 21.69001007], [89.06475067, 21.68974113], [89.06481934, 21.68954277], [89.06490326, 21.68941116], [89.06490326, 21.68927002], [89.06504059, 21.6890049], [89.06517792, 21.68886757], [89.06532288, 21.68873024], [89.06546783, 21.68866539], [89.06768799, 21.68867111], [89.06783295, 21.68860054], [89.06826019, 21.68847084], [89.06861877, 21.68840027], [89.06897736, 21.68840027], [89.06919098, 21.6883297], [89.06939697, 21.6883297], [89.06961823, 21.68840027], [89.06990814, 21.68860054], [89.07026672, 21.68880081], [89.07048035, 21.6890049], [89.07063293, 21.68919945], [89.07112122, 21.68940544], [89.07141113, 21.68967438], [89.07206726, 21.68989372], [89.07265472, 21.6897316], [89.07333374, 21.68916893], [89.07389069, 21.68861008], [89.07402039, 21.68861198], [89.07430267, 21.68833351], [89.07444763, 21.68805695], [89.07485962, 21.6875], [89.07499695, 21.68721962], [89.07540894, 21.68659973], [89.07554626, 21.68638992], [89.07583618, 21.68610954], [89.07597351, 21.68583488], [89.07805634, 21.68361092], [89.07833099, 21.6834774], [89.07936096, 21.68215942], [89.07956696, 21.68194962], [89.07985687, 21.68146324], [89.08082581, 21.68083191], [89.08110809, 21.68083382], [89.08153534, 21.68082428], [89.08189392, 21.68054581], [89.08195496, 21.68020248], [89.08181, 21.67965508], [89.08172607, 21.67951965], [89.08185577, 21.67891121], [89.08235931, 21.67870331], [89.0828476, 21.67896271], [89.08312988, 21.67937088], [89.0836792, 21.67949104], [89.08390045, 21.67887115], [89.08338928, 21.6782608], [89.0830307, 21.67798042], [89.08303833, 21.67752266], [89.08338165, 21.67742729], [89.08403015, 21.67802238], [89.08441162, 21.67792702], [89.08489227, 21.67782784], [89.0851059, 21.67725945], [89.08506012, 21.67683983], [89.08480072, 21.67637062], [89.08499908, 21.67572021], [89.08570099, 21.67465019], [89.08608246, 21.67416], [89.08617401, 21.67403221], [89.08644867, 21.6738224], [89.08666992, 21.67361069], [89.08679962, 21.67333031], [89.08694458, 21.67305756], [89.08701324, 21.67284966], [89.08693695, 21.6722908], [89.08693695, 21.67193985], [89.08694458, 21.67138863], [89.08809662, 21.67023087], [89.08824921, 21.67003059], [89.08838654, 21.66962051], [89.08875275, 21.66922188], [89.08889771, 21.66908646], [89.08924866, 21.66868019], [89.08939362, 21.66854858], [89.0896759, 21.66842079], [89.08996582, 21.66814995], [89.09011078, 21.66794014], [89.09017944, 21.66774178], [89.09053802, 21.66740608], [89.09053802, 21.66727066], [89.09068298, 21.66706848], [89.0909729, 21.66699982], [89.09111023, 21.66700172], [89.0915451, 21.66693497], [89.09175873, 21.66679955], [89.09189606, 21.66667175], [89.09197235, 21.66653252], [89.09204865, 21.66633034], [89.09211731, 21.66605949], [89.09233093, 21.66572571], [89.09233093, 21.6649189], [89.09226227, 21.66472054], [89.09211731, 21.6644516], [89.09218597, 21.66418266], [89.09233093, 21.66411018], [89.09247589, 21.66398048], [89.09262085, 21.66377068], [89.09268951, 21.66357231], [89.09262085, 21.66337013], [89.09254456, 21.66303444], [89.09247589, 21.66283226], [89.09233093, 21.66263199], [89.0923996, 21.66229439], [89.09254456, 21.66222954], [89.09275818, 21.66208839], [89.09283447, 21.6619606], [89.09297943, 21.66142273], [89.09290314, 21.66094971], [89.09275818, 21.66074944], [89.09275818, 21.6603508], [89.09290314, 21.66007805], [89.0930481, 21.66000938], [89.09333038, 21.65971947], [89.09377289, 21.65897369], [89.09377289, 21.65870476], [89.09370422, 21.65829849], [89.09355927, 21.6579628], [89.09342194, 21.65769577], [89.09342194, 21.65715981], [89.09364319, 21.65702057], [89.09377289, 21.65695572], [89.09391785, 21.65688705], [89.09420776, 21.65654945], [89.09435272, 21.65568161], [89.09420776, 21.65534019], [89.09413147, 21.65500641], [89.09435272, 21.65454102], [89.09468842, 21.6541996], [89.09477997, 21.65406036], [89.09492493, 21.65366173], [89.09492493, 21.65312386], [89.09484863, 21.65298843], [89.09468842, 21.65265274], [89.09470367, 21.65218163], [89.09484863, 21.65198135], [89.09492493, 21.65184784], [89.09497833, 21.65130806], [89.09506226, 21.65103912], [89.09513855, 21.65063095], [89.09513855, 21.64969635], [89.09518433, 21.64887238], [89.09518433, 21.64658546], [89.09510803, 21.64619064], [89.09510803, 21.64565086], [89.09503937, 21.64511108], [89.09503937, 21.64396095], [89.09489441, 21.6434269], [89.09482574, 21.64302254], [89.09468079, 21.64221573], [89.09468079, 21.64195061], [89.09453583, 21.64147949], [89.09440613, 21.64113998], [89.09425354, 21.64073563], [89.09411621, 21.64039993], [89.09396362, 21.64012909], [89.09375, 21.63966179], [89.09361267, 21.63945961], [89.09353638, 21.63920021], [89.09332275, 21.63871956], [89.09329224, 21.63841248], [89.09314728, 21.63773918], [89.09300995, 21.63726616], [89.09285736, 21.63693047], [89.09250641, 21.63652992], [89.09221649, 21.63619232], [89.0919342, 21.63592339], [89.09150696, 21.63585663], [89.09121704, 21.63565254], [89.09107208, 21.63538551], [89.09085846, 21.63504982], [89.09063721, 21.63465118], [89.09063721, 21.63438034], [89.09070587, 21.63417816], [89.09063721, 21.63390923], [89.09043121, 21.63376808], [89.09007263, 21.63357162], [89.08985901, 21.63349915], [89.08956909, 21.63336945], [89.0894165, 21.63323021], [89.0887146, 21.63310051], [89.08856964, 21.63297081], [89.08827972, 21.63262939], [89.08792114, 21.63223076], [89.08757019, 21.63182068], [89.08728027, 21.63162041], [89.08699036, 21.63134956], [89.08663177, 21.63108253], [89.08649445, 21.63094711], [89.0861969, 21.63068008], [89.08584595, 21.63041115], [89.0854187, 21.63021088], [89.08512878, 21.6301403], [89.08455658, 21.6300106], [89.08393097, 21.6300106], [89.08355713, 21.63027954], [89.08326721, 21.63094711], [89.08312225, 21.6312809], [89.08319855, 21.63148499], [89.08348083, 21.63175392], [89.08377075, 21.63209152], [89.08393097, 21.63228989], [89.08397675, 21.63262939], [89.084198, 21.63290024], [89.08455658, 21.63310051], [89.08470154, 21.63317108], [89.08492279, 21.63344193], [89.08506012, 21.63371277], [89.0849762, 21.63384056], [89.08463287, 21.63384056], [89.08398438, 21.63397408], [89.08383942, 21.63397408], [89.08312225, 21.6337719], [89.0827713, 21.63350105], [89.08269501, 21.63323212], [89.08255005, 21.63303375], [89.08241272, 21.63262939], [89.08226776, 21.63228989], [89.08226776, 21.63202286], [89.08219147, 21.63188934], [89.0821228, 21.63168907], [89.08197784, 21.63141823], [89.08170319, 21.63114929], [89.0815506, 21.63095284], [89.0815506, 21.63054276], [89.08161926, 21.63034248], [89.08183289, 21.63020897], [89.08190918, 21.6301403], [89.08190918, 21.6300106], [89.08197784, 21.62953949], [89.08197784, 21.62820053], [89.08221436, 21.62816811], [89.08220673, 21.6278801], [89.08196259, 21.62786484], [89.08193207, 21.62759018], [89.08168793, 21.6275959], [89.08168793, 21.62736702], [89.08075714, 21.62734032], [89.08055115, 21.62709999], [89.08040619, 21.62683105], [89.07997131, 21.62648964], [89.07975769, 21.62635612], [89.07939911, 21.6262207], [89.0788269, 21.62608719], [89.07875061, 21.6260376], [89.07839966, 21.62581825], [89.07804108, 21.62548065], [89.07775879, 21.62521362], [89.0776825, 21.62501335], [89.07746887, 21.62494469], [89.07725525, 21.62474442], [89.076828, 21.62474442], [89.07624817, 21.62460899], [89.07602692, 21.62454033], [89.07567596, 21.62447548], [89.07524872, 21.62413788], [89.07502747, 21.62400055], [89.07474518, 21.62386894], [89.07453156, 21.62387085], [89.07424927, 21.62372971], [89.07381439, 21.6235981], [89.0735321, 21.62339973], [89.07331848, 21.62339973], [89.07280731, 21.62333107], [89.07253265, 21.6232605], [89.07224274, 21.62306213], [89.07202911, 21.62265778], [89.07195282, 21.62252045], [89.07152557, 21.62225533], [89.07138824, 21.62222099], [89.07090759, 21.62228966], [89.06970215, 21.62215042], [89.06920624, 21.62228012], [89.06892395, 21.62220573], [89.06867218, 21.62105942], [89.06835938, 21.62061119], [89.06797028, 21.62037086], [89.06680298, 21.62014008], [89.06607819, 21.62013054], [89.06500244, 21.62020111], [89.06450653, 21.62013054], [89.06401825, 21.61965942], [89.06326294, 21.61880112], [89.06261444, 21.61854362], [89.06233215, 21.61841011], [89.06196594, 21.61833954], [89.0615387, 21.61827469], [89.06104279, 21.61814117], [89.06060791, 21.6180706], [89.060112, 21.6180706], [89.05944824, 21.61814117], [89.05924988, 21.61847687], [89.05903625, 21.61854362], [89.05853271, 21.61841011], [89.05844879, 21.61834526], [89.05817413, 21.61814117], [89.05774689, 21.61787033], [89.05745697, 21.61780357], [89.05702972, 21.61773872], [89.05638885, 21.61766815], [89.05545044, 21.61753082], [89.05459595, 21.6176033], [89.05430603, 21.61780357]]], [[[88.69712067, 21.71287918], [88.69734192, 21.71264076], [88.69750214, 21.71228027], [88.69766998, 21.71192169], [88.69777679, 21.71157265], [88.69792175, 21.71125031], [88.69802856, 21.71093941], [88.69805145, 21.71060944], [88.69806671, 21.71027946], [88.69813538, 21.70998955], [88.69829559, 21.70972061], [88.69834137, 21.70939445], [88.69837952, 21.70903778], [88.69848633, 21.70866966], [88.69851685, 21.70830917], [88.6985321, 21.70800018], [88.6986084, 21.70771027], [88.69869232, 21.70735168], [88.69886017, 21.70686913], [88.69888306, 21.7062397], [88.69884491, 21.7055397], [88.69869232, 21.70483017], [88.69877625, 21.70415115], [88.6988678, 21.70353127], [88.69883728, 21.70297813], [88.69875336, 21.70248985], [88.69886017, 21.70203972], [88.69888306, 21.70158005], [88.69882965, 21.70112038], [88.69886017, 21.70062065], [88.69888306, 21.7001152], [88.69889832, 21.69961166], [88.69895935, 21.69911957], [88.6991272, 21.69866371], [88.6991806, 21.6981678], [88.69929504, 21.69766426], [88.69950104, 21.69715309], [88.69968414, 21.69657707], [88.69975281, 21.69589996], [88.69983673, 21.6952095], [88.69979858, 21.69452286], [88.69998169, 21.69396782], [88.70012665, 21.69349098], [88.70024872, 21.69310951], [88.70028687, 21.69277954], [88.7003479, 21.69248199], [88.70052338, 21.69223213], [88.70061493, 21.69193649], [88.70079803, 21.69162941], [88.70088959, 21.69124985], [88.70108795, 21.69087982], [88.70132446, 21.69051743], [88.70156097, 21.6901207], [88.70185089, 21.68971634], [88.70213318, 21.689291], [88.70226288, 21.68875122], [88.7024231, 21.6882782], [88.70258331, 21.68782043], [88.70277405, 21.68741989], [88.70300293, 21.68702126], [88.70329285, 21.68663979], [88.70359039, 21.68626022], [88.70388794, 21.68586349], [88.7041626, 21.68548584], [88.70444489, 21.68512154], [88.70471954, 21.68475914], [88.70500946, 21.6843605], [88.70536041, 21.68394279], [88.70578766, 21.68350983], [88.70614624, 21.68300056], [88.70642853, 21.68247223], [88.70674896, 21.68200684], [88.7071228, 21.68161964], [88.70742798, 21.68119049], [88.70779419, 21.68081093], [88.70822906, 21.68046761], [88.70856476, 21.6800518], [88.708992, 21.67973137], [88.70942688, 21.67944717], [88.70981598, 21.67913055], [88.71029663, 21.6788311], [88.71079254, 21.67850113], [88.71109009, 21.67790794], [88.71153259, 21.67758942], [88.71206665, 21.677351], [88.71231842, 21.67682266], [88.71277618, 21.67638969], [88.71330261, 21.67598915], [88.71379089, 21.67559052], [88.71424866, 21.6752739], [88.71465302, 21.67497635], [88.71498871, 21.67468262], [88.71531677, 21.67440987], [88.71566772, 21.67416], [88.71602631, 21.67389107], [88.71643066, 21.67362022], [88.71689606, 21.67337036], [88.7173996, 21.67305946], [88.71793365, 21.67275047], [88.71842194, 21.67241478], [88.71889496, 21.67212677], [88.71935272, 21.6718998], [88.71974182, 21.6716404], [88.72011566, 21.67138481], [88.72048187, 21.6711216], [88.72087097, 21.67087936], [88.72128296, 21.67064095], [88.72164154, 21.6703186], [88.72202301, 21.67002106], [88.72245026, 21.66975021], [88.72286224, 21.66945076], [88.72329712, 21.6691494], [88.72371674, 21.66879082], [88.72418213, 21.66844749], [88.72467041, 21.66809082], [88.72512054, 21.66765976], [88.72556305, 21.66723251], [88.72602844, 21.6668644], [88.7264328, 21.66646194], [88.72686005, 21.66606903], [88.72731018, 21.66564941], [88.72785187, 21.66526985], [88.72842407, 21.66489029], [88.7289505, 21.6644516], [88.72947693, 21.664011], [88.73002625, 21.66360092], [88.73056793, 21.66319084], [88.73110199, 21.66281891], [88.73158264, 21.66242981], [88.73200226, 21.66202736], [88.7324295, 21.66169167], [88.73284912, 21.66140938], [88.73329163, 21.66117096], [88.73381805, 21.66094971], [88.73426056, 21.66062927], [88.73468781, 21.66028976], [88.73500061, 21.65986061], [88.7352829, 21.65944672], [88.73557281, 21.65904808], [88.73587036, 21.65869713], [88.73618317, 21.65836906], [88.73649597, 21.65807343], [88.73682404, 21.65778351], [88.7371521, 21.6574955], [88.73748016, 21.65720177], [88.7378006, 21.65689087], [88.73815155, 21.65660095], [88.73846436, 21.65629959], [88.7387619, 21.65600204], [88.73906708, 21.65570068], [88.73941803, 21.6554203], [88.73972321, 21.65512085], [88.74000549, 21.6548233], [88.74029541, 21.65453529], [88.74061584, 21.65426064], [88.74099731, 21.65401268], [88.74136353, 21.65370941], [88.74183655, 21.65352821], [88.74227905, 21.65331078], [88.74273682, 21.65313148], [88.74321747, 21.6529808], [88.74371338, 21.65276909], [88.7443161, 21.65264893], [88.74488831, 21.65241051], [88.74547577, 21.65223885], [88.74608612, 21.65209007], [88.74668884, 21.65192413], [88.74728394, 21.65173721], [88.74790192, 21.6516304], [88.74842834, 21.65141106], [88.74893951, 21.65117073], [88.74942017, 21.65093994], [88.74981689, 21.65081024], [88.75016022, 21.65048409], [88.75051117, 21.65017319], [88.75083923, 21.64979935], [88.7511673, 21.64946175], [88.75148773, 21.64925957], [88.75159454, 21.64906883], [88.75137329, 21.64871979], [88.75079346, 21.64826965], [88.7502594, 21.64791107], [88.74983978, 21.64756012], [88.74946594, 21.64724922], [88.74913025, 21.64700127], [88.74875641, 21.64680099], [88.74834442, 21.64663124], [88.74790192, 21.64645958], [88.74745178, 21.64629173], [88.74698639, 21.64616013], [88.74646759, 21.6460495], [88.74591064, 21.64595222], [88.74529266, 21.64588928], [88.74463654, 21.64587021], [88.74395752, 21.64586067], [88.74328613, 21.64585686], [88.74262238, 21.64583969], [88.74192047, 21.64580536], [88.74124146, 21.64574051], [88.74055481, 21.64572906], [88.73987579, 21.64571762], [88.73922729, 21.64570045], [88.73856354, 21.64571381], [88.73786163, 21.64570427], [88.73719025, 21.64566803], [88.73655701, 21.64561081], [88.73597717, 21.64546967], [88.73549652, 21.64528847], [88.73504639, 21.64507103], [88.73457336, 21.64481926], [88.73403931, 21.64454842], [88.7334671, 21.64423943], [88.73292542, 21.64393616], [88.7324295, 21.64365959], [88.73194885, 21.6433506], [88.73147583, 21.64307022], [88.73104095, 21.64277267], [88.73059082, 21.6424408], [88.73015594, 21.64207268], [88.72972107, 21.64167976], [88.72927094, 21.64128113], [88.72895813, 21.6409893], [88.72884369, 21.64088058], [88.72838593, 21.64050293], [88.72808838, 21.64029312], [88.72790527, 21.64016914], [88.72738647, 21.63986969], [88.72686768, 21.63955307], [88.72639465, 21.63914871], [88.72589111, 21.638731], [88.72563934, 21.63855362], [88.72536469, 21.63836479], [88.72511292, 21.63820267], [88.72483826, 21.63813019], [88.72446442, 21.63804054], [88.72402191, 21.63804817], [88.72357941, 21.63812065], [88.72315216, 21.63832855], [88.72289276, 21.63862038], [88.72281647, 21.63887978], [88.72277832, 21.63916588], [88.72305298, 21.63944435], [88.72305298, 21.63972282], [88.72305298, 21.63999939], [88.72333527, 21.64027786], [88.72333527, 21.64111137], [88.72250366, 21.64194489], [88.72249603, 21.64221954], [88.72222137, 21.64249992], [88.72222137, 21.6427784], [88.72166443, 21.64333344], [88.72138977, 21.64333344], [88.72138977, 21.64361], [88.72083282, 21.64417076], [88.72055817, 21.64416695], [88.72027588, 21.64444351], [88.72001648, 21.64438248], [88.71956635, 21.64460945], [88.71903229, 21.64473724], [88.71835327, 21.6448307], [88.71817017, 21.6451683], [88.7179184, 21.64559746], [88.71756744, 21.64605141], [88.7172699, 21.64647102], [88.71710968, 21.64689827], [88.7169342, 21.64722252], [88.71685028, 21.6473217], [88.71671295, 21.64748001], [88.71649933, 21.64776993], [88.71621704, 21.64804077], [88.71585846, 21.64827919], [88.71554565, 21.64857864], [88.71525574, 21.64888191], [88.7150116, 21.64919281], [88.71490479, 21.64958763], [88.71478271, 21.64999008], [88.71459198, 21.65038872], [88.71425629, 21.65075302], [88.71373749, 21.6510601], [88.71336365, 21.65146065], [88.7130661, 21.65192032], [88.71282959, 21.65246964], [88.71270752, 21.65312958], [88.71244812, 21.65370941], [88.71205139, 21.65418053], [88.71169281, 21.65460968], [88.71138, 21.65500832], [88.71111298, 21.65534973], [88.71087646, 21.65571022], [88.71070862, 21.65610313], [88.71053314, 21.6565094], [88.71027374, 21.65689087], [88.7100296, 21.65728378], [88.70986938, 21.6577282], [88.70960999, 21.65809059], [88.70941162, 21.65845108], [88.70916748, 21.65875053], [88.7089386, 21.65903091], [88.7088089, 21.65937042], [88.70861053, 21.6596489], [88.70841217, 21.65993118], [88.7082901, 21.66029549], [88.70805359, 21.66055679], [88.70804596, 21.66082954], [88.70916748, 21.66194916], [88.70972443, 21.66194534], [88.70999146, 21.66221809], [88.70999146, 21.66250038], [88.7097168, 21.66278839], [88.70972443, 21.66305542], [88.70944214, 21.66333389], [88.70861053, 21.66332817], [88.70833588, 21.66361046], [88.70777893, 21.66361046], [88.70722198, 21.6641674], [88.70722198, 21.66472244], [88.70694733, 21.66472054], [88.70639038, 21.66527939], [88.70471954, 21.66527939], [88.70417786, 21.66472054], [88.70361328, 21.66472244], [88.70333862, 21.66500092], [88.70305634, 21.66527748], [88.70321655, 21.66496086], [88.70270538, 21.66509247], [88.70220947, 21.6652832], [88.70173645, 21.66547966], [88.70131683, 21.66569138], [88.70104218, 21.66603088], [88.70078278, 21.66648102], [88.70037842, 21.6668911], [88.69999695, 21.66731071], [88.69962311, 21.66773987], [88.69921112, 21.66813087], [88.69882202, 21.66855049], [88.69841766, 21.66892052], [88.69806671, 21.6692791], [88.69777679, 21.6696167], [88.69753265, 21.66991043], [88.69737244, 21.67025948], [88.69716644, 21.67060089], [88.69696045, 21.67095566], [88.69680023, 21.67134094], [88.69664764, 21.67175102], [88.69644928, 21.67223358], [88.69610596, 21.67288971], [88.69593048, 21.67354965], [88.69610596, 21.67361069], [88.69555664, 21.67416763], [88.69555664, 21.67444038], [88.69444275, 21.67555618], [88.69444275, 21.67583084], [88.69361115, 21.67666626], [88.69361115, 21.67694473], [88.6922226, 21.67833328], [88.6922226, 21.67861176], [88.69194794, 21.67861176], [88.68805695, 21.68250084], [88.68769073, 21.68282127], [88.68728638, 21.68305016], [88.68704224, 21.68333054], [88.68712616, 21.68362045], [88.6873703, 21.68396759], [88.68762207, 21.68437576], [88.68782806, 21.68475914], [88.68810272, 21.68507004], [88.68833923, 21.68538094], [88.68859863, 21.68571091], [88.68884277, 21.68609047], [88.68913269, 21.68647957], [88.68940735, 21.68689919], [88.68971252, 21.68733025], [88.69000244, 21.68778992], [88.6902771, 21.68828011], [88.69055176, 21.68882179], [88.69078064, 21.68942261], [88.69090271, 21.69011116], [88.69111633, 21.69075012], [88.69138336, 21.69133759], [88.69165802, 21.69195175], [88.69186401, 21.69260216], [88.69194794, 21.69324303], [88.69203186, 21.69380951], [88.69218445, 21.69428062], [88.69226837, 21.69471359], [88.69245148, 21.69506454], [88.69250488, 21.69542313], [88.69258118, 21.69576073], [88.69274139, 21.6960907], [88.69283295, 21.69650459], [88.69300842, 21.69692421], [88.69307709, 21.69742966], [88.69319916, 21.69791985], [88.69333649, 21.69778061], [88.69361115, 21.69805336], [88.69361115, 21.69832993], [88.6938858, 21.69861031], [88.6938858, 21.69916534], [88.69416809, 21.69944], [88.69416809, 21.70055962], [88.69416046, 21.70112991], [88.69416046, 21.70167351], [88.69410706, 21.70220947], [88.69394684, 21.70272827], [88.69400024, 21.70319748], [88.69407654, 21.70373535], [88.69422913, 21.70429993], [88.69444275, 21.7048111], [88.69465637, 21.70531082], [88.6947403, 21.70580864], [88.69489288, 21.70627022], [88.69507599, 21.70668983], [88.69541931, 21.70705986], [88.69574738, 21.70747757], [88.69587708, 21.70800018], [88.69606781, 21.70843124], [88.69617462, 21.70892715], [88.69629669, 21.70947075], [88.69624329, 21.7100811], [88.69631958, 21.71069336], [88.69619751, 21.71125031], [88.6958313, 21.71166992], [88.6958313, 21.71278], [88.69611359, 21.71277618], [88.69638824, 21.71305656], [88.69638824, 21.71333313], [88.69675446, 21.71320534], [88.69692993, 21.7130394], [88.69712067, 21.71287918]]], [[[88.59194183, 21.69416618], [88.59306335, 21.69306183], [88.59333038, 21.69306183], [88.59388733, 21.69249916], [88.59388733, 21.69222069], [88.59500122, 21.69111061], [88.59500122, 21.69082832], [88.59610748, 21.68972206], [88.59638977, 21.68972969], [88.5966568, 21.68943977], [88.59750366, 21.68944359], [88.59777832, 21.68916893], [88.59790802, 21.68913078], [88.59848785, 21.68872643], [88.59906769, 21.68828964], [88.59958649, 21.68783951], [88.60011292, 21.68750572], [88.60058594, 21.68721962], [88.60102844, 21.68694115], [88.60146332, 21.68665695], [88.60192871, 21.68632126], [88.60241699, 21.68591118], [88.6029129, 21.68540001], [88.60336304, 21.68478012], [88.60386658, 21.68416023], [88.60434723, 21.68354034], [88.60471344, 21.68289948], [88.60500336, 21.6823082], [88.60534668, 21.68188095], [88.60561371, 21.68142891], [88.60585785, 21.68102074], [88.60604095, 21.68062973], [88.60619354, 21.68029213], [88.6063385, 21.67997742], [88.60621643, 21.6796627], [88.60582733, 21.6794529], [88.60527802, 21.67889023], [88.60527802, 21.67861176], [88.60472107, 21.67805481], [88.60416412, 21.67805481], [88.60360718, 21.67749596], [88.60333252, 21.6772213], [88.60361481, 21.67694473], [88.60361481, 21.67638969], [88.60527802, 21.6747303], [88.60556793, 21.67445755], [88.60549164, 21.67386246], [88.60526276, 21.67333221], [88.60500336, 21.67277527], [88.6047287, 21.67250061], [88.60472107, 21.67194366], [88.60444641, 21.67166519], [88.60444641, 21.67111206], [88.60166931, 21.66833115], [88.60166931, 21.66805649], [88.60028076, 21.66667175], [88.60028076, 21.66638947], [88.59999847, 21.66610909], [88.59999847, 21.66583061], [88.59972382, 21.66555595], [88.59971619, 21.66527939], [88.59860229, 21.66416931], [88.59860229, 21.66389084], [88.59749603, 21.66278839], [88.59694672, 21.66278839], [88.5966568, 21.66250038], [88.59610748, 21.66250038], [88.59471893, 21.66110992], [88.59444427, 21.66111183], [88.59388733, 21.66055679], [88.59361267, 21.66055679], [88.59305573, 21.65999985], [88.59278107, 21.65999985], [88.59240723, 21.65962601], [88.59222412, 21.65944672], [88.59194183, 21.65944672], [88.59111023, 21.6586113], [88.59083557, 21.6586113], [88.59055328, 21.65833282], [88.59027863, 21.65833282], [88.58999634, 21.65805435], [88.58972168, 21.65806007], [88.58944702, 21.65777969], [88.58889008, 21.65777969], [88.5887146, 21.65755272], [88.58854675, 21.65733147], [88.58830261, 21.6576004], [88.58805847, 21.65776062], [88.5878067, 21.65789032], [88.58759308, 21.65807915], [88.58745575, 21.6583786], [88.58721924, 21.65860939], [88.58721924, 21.65888977], [88.58693695, 21.65917015], [88.58693695, 21.66500092], [88.58721924, 21.66527939], [88.58721924, 21.66556168], [88.58708191, 21.6659584], [88.58698273, 21.66648102], [88.58695221, 21.66699982], [88.58693695, 21.66748047], [88.58693695, 21.66789818], [88.58689117, 21.66826057], [88.58676147, 21.66855431], [88.58669281, 21.66884041], [88.58663177, 21.66916275], [88.58653259, 21.66949081], [88.58638763, 21.66987991], [88.58624268, 21.6703186], [88.58610535, 21.67078972], [88.58596802, 21.67124557], [88.58582306, 21.6716404], [88.58566284, 21.67200089], [88.58550262, 21.67233849], [88.58531189, 21.67263222], [88.58513641, 21.67295456], [88.58499146, 21.67334175], [88.5848465, 21.67374039], [88.58466339, 21.67410088], [88.58448029, 21.67443085], [88.58435059, 21.67477989], [88.58416748, 21.67513084], [88.58396149, 21.67551041], [88.58377838, 21.67593193], [88.58355713, 21.67636108], [88.58331299, 21.67680931], [88.58304596, 21.67728806], [88.58278656, 21.67778969], [88.58255768, 21.6782608], [88.58242798, 21.67872047], [88.58228302, 21.67910194], [88.58216858, 21.67944908], [88.58198547, 21.67970467], [88.58183289, 21.67996979], [88.58167267, 21.68021965], [88.58148956, 21.68046761], [88.58133698, 21.68074226], [88.58117676, 21.68101311], [88.58106995, 21.68132019], [88.58092499, 21.68158722], [88.58078003, 21.68185043], [88.58061218, 21.68213081], [88.58048248, 21.6825161], [88.58039093, 21.68299484], [88.58052063, 21.68354034], [88.58082581, 21.68405914], [88.58133698, 21.68444061], [88.58187103, 21.68481064], [88.58232117, 21.68516731], [88.5827713, 21.68551254], [88.58322906, 21.68581009], [88.58367157, 21.68609047], [88.5841217, 21.68635941], [88.58457947, 21.6866703], [88.58508301, 21.6869812], [88.58565521, 21.6872654], [88.58626556, 21.68749428], [88.58688354, 21.68769646], [88.58750916, 21.68782043], [88.58811188, 21.68798065], [88.58870697, 21.6880722], [88.58925629, 21.68818092], [88.58973694, 21.68834114], [88.59017181, 21.68852997], [88.59055328, 21.68871117], [88.59086609, 21.68892288], [88.59108734, 21.68917084], [88.59123993, 21.68946075], [88.59139252, 21.68972969], [88.59166718, 21.69000053], [88.59166718, 21.69028091], [88.59194183, 21.69055939], [88.59194183, 21.69138908], [88.59166718, 21.69166946], [88.59166718, 21.69249916], [88.59111023, 21.69305611], [88.59111023, 21.69333267], [88.5908432, 21.69361115], [88.59064484, 21.69400024], [88.59046173, 21.69432068], [88.59021759, 21.69468117], [88.58994293, 21.69506836], [88.58963776, 21.69549561], [88.58934021, 21.69593239], [88.58903503, 21.69634819], [88.58875275, 21.69672966], [88.58848572, 21.69709778], [88.58825684, 21.69745827], [88.5880661, 21.69783592], [88.58789063, 21.69824982], [88.5877533, 21.69874001], [88.58759308, 21.69923973], [88.58751678, 21.69976044], [88.58751678, 21.70029831], [88.58758545, 21.70088577], [88.58779144, 21.70144081], [88.5880661, 21.70158958], [88.58835602, 21.70150948], [88.58860779, 21.70138931], [88.58889008, 21.70111084], [88.58889008, 21.70055962], [88.5891571, 21.70028114], [88.5891571, 21.69944], [88.58944702, 21.69916534], [88.58944702, 21.69890022], [88.58972168, 21.69861031], [88.58972168, 21.69750023], [88.59139252, 21.69582939], [88.59139252, 21.69555473], [88.59166718, 21.69527817], [88.59166718, 21.69499969], [88.59194183, 21.69472122], [88.59194183, 21.69416618]]], [[[88.80665588, 21.70667267], [88.80722046, 21.70611191], [88.80750275, 21.70611191], [88.80805206, 21.70555496], [88.80860901, 21.70556259], [88.8088913, 21.7052803], [88.80916595, 21.7052803], [88.8097229, 21.7047081], [88.8097229, 21.70444489], [88.80999756, 21.70416641], [88.80999756, 21.69917107], [88.8097229, 21.69890022], [88.8097229, 21.69528008], [88.80999756, 21.69499969], [88.80999756, 21.69388962], [88.81027985, 21.69361115], [88.81027985, 21.69281006], [88.81014252, 21.69146156], [88.81014252, 21.69011688], [88.81028748, 21.68864059], [88.80999756, 21.68721962], [88.80999756, 21.68527794], [88.8097229, 21.68499947], [88.8097229, 21.68333054], [88.80916595, 21.6827774], [88.80916595, 21.68222046], [88.8088913, 21.68194389], [88.8088913, 21.68027687], [88.80860901, 21.68000031], [88.80860901, 21.67972183], [88.80805206, 21.67916679], [88.80805206, 21.67861176], [88.8077774, 21.67833328], [88.8077774, 21.67694473], [88.80750275, 21.67666626], [88.80750275, 21.67583084], [88.80722046, 21.67555618], [88.80722046, 21.67525101], [88.80722046, 21.67499924], [88.80639648, 21.67416954], [88.80610657, 21.67416954], [88.80639648, 21.67389107], [88.80639648, 21.67361069], [88.8069458, 21.67305756], [88.8069458, 21.6697197], [88.80722046, 21.66944313], [88.80722046, 21.66583061], [88.8069458, 21.66555595], [88.8069458, 21.66472054], [88.80666351, 21.66444397], [88.80666351, 21.66389084], [88.80610657, 21.66332817], [88.8061142, 21.66305542], [88.80555725, 21.66250038], [88.80555725, 21.66221809], [88.80472565, 21.6613884], [88.80473328, 21.66110992], [88.8041687, 21.66055679], [88.8041687, 21.66027832], [88.80304718, 21.65917015], [88.80304718, 21.65888977], [88.80222321, 21.65806007], [88.80194092, 21.65806007], [88.80166626, 21.65777969], [88.8013916, 21.65777969], [88.80110931, 21.65750122], [88.80027008, 21.65750122], [88.80000305, 21.65722084], [88.79944611, 21.65722466], [88.79833221, 21.65611076], [88.79805756, 21.65611076], [88.7977829, 21.65583038], [88.79750061, 21.65583229], [88.79694366, 21.65527725], [88.79666901, 21.65555954], [88.79444122, 21.65555573], [88.79416656, 21.65583229], [88.79305267, 21.65583038], [88.79277802, 21.65611076], [88.79250336, 21.65611076], [88.79222107, 21.65639114], [88.79166412, 21.65638924], [88.79146576, 21.6565876], [88.79138947, 21.6566658], [88.79083252, 21.6566658], [88.79055786, 21.65694237], [88.79000092, 21.65694046], [88.78943634, 21.65750122], [88.78888702, 21.65750122], [88.78833008, 21.65806007], [88.78805542, 21.65805435], [88.78778076, 21.65833282], [88.78778076, 21.65860939], [88.78722382, 21.65916443], [88.78721619, 21.65944099], [88.78778076, 21.65999985], [88.78805542, 21.65999985], [88.78833008, 21.66028023], [88.78888702, 21.66027832], [88.78916931, 21.66055679], [88.78971863, 21.66055679], [88.79000092, 21.66083336], [88.79055786, 21.66083336], [88.79083252, 21.66111183], [88.79165649, 21.66110992], [88.79194641, 21.6613903], [88.79250336, 21.6613903], [88.79277802, 21.66167068], [88.79305267, 21.66167068], [88.79389191, 21.66250038], [88.79389191, 21.66278839], [88.79416656, 21.66305542], [88.79416656, 21.66332817], [88.79444122, 21.66361046], [88.79444122, 21.6641674], [88.79416656, 21.66444397], [88.79305267, 21.66333389], [88.79305267, 21.66305542], [88.79250336, 21.66250038], [88.79083252, 21.66250038], [88.79055786, 21.66221809], [88.79000092, 21.66222191], [88.78971863, 21.66194534], [88.78888702, 21.66194916], [88.78861237, 21.66167068], [88.78749847, 21.66167068], [88.78694153, 21.66110992], [88.78666687, 21.66111183], [88.78583527, 21.66027832], [88.78499603, 21.66028023], [88.78472137, 21.65999985], [88.78388977, 21.65999985], [88.78360748, 21.66028023], [88.78333282, 21.66027832], [88.78305817, 21.66055679], [88.78277588, 21.66055679], [88.78250122, 21.66083336], [88.78250122, 21.66110992], [88.7822113, 21.6613903], [88.78193665, 21.66110992], [88.78166962, 21.6613903], [88.78138733, 21.6613903], [88.78111267, 21.66167068], [88.78083038, 21.66167068], [88.78056335, 21.66194916], [88.77999878, 21.66194534], [88.77972412, 21.66222191], [88.77944183, 21.66221809], [88.77889252, 21.66278839], [88.77889252, 21.66305542], [88.77916718, 21.66333389], [88.77861023, 21.66332817], [88.77805328, 21.66389084], [88.77777863, 21.66389084], [88.77749634, 21.66416931], [88.77583313, 21.66416931], [88.77555847, 21.66389084], [88.77471924, 21.66389084], [88.77443695, 21.66416931], [88.77416992, 21.6641674], [88.77388763, 21.66444397], [88.77333069, 21.66444397], [88.77305603, 21.66472244], [88.77278137, 21.66472054], [88.77249908, 21.66500092], [88.77166748, 21.66500092], [88.77139282, 21.66527939], [88.77083588, 21.66527939], [88.77054596, 21.66556168], [88.76832581, 21.66556168], [88.76805878, 21.66527939], [88.76777649, 21.66527939], [88.76768494, 21.66518784], [88.76721954, 21.66472244], [88.76638794, 21.66472244], [88.76620483, 21.66453934], [88.76583099, 21.6641674], [88.76526642, 21.66416931], [88.76499939, 21.66389084], [88.76333618, 21.66389084], [88.76304626, 21.66361046], [88.76139069, 21.66361046], [88.76110077, 21.66332817], [88.76083374, 21.66333389], [88.76055908, 21.66305542], [88.76027679, 21.66333389], [88.76000214, 21.66333389], [88.75971985, 21.66305542], [88.75944519, 21.66305542], [88.7591629, 21.66333389], [88.75888824, 21.66332817], [88.75805664, 21.6641674], [88.75805664, 21.66444397], [88.75666809, 21.66583061], [88.75666809, 21.66610909], [88.7555542, 21.66722107], [88.75527954, 21.66722107], [88.7491684, 21.67333412], [88.74888611, 21.67333031], [88.74804687, 21.67416954], [88.74777985, 21.67416954], [88.7472229, 21.6747303], [88.74694824, 21.6747303], [88.74666595, 21.67500114], [88.7463913, 21.67500114], [88.74610138, 21.67527962], [88.74582672, 21.67527962], [88.74555206, 21.67555809], [88.7452774, 21.67555618], [88.74500275, 21.67583275], [88.74472046, 21.67583084], [88.7444458, 21.67611122], [88.74415588, 21.67611122], [88.74360657, 21.67666817], [88.74333191, 21.67666626], [88.74305725, 21.67694473], [88.74277496, 21.67694473], [88.74223328, 21.67749977], [88.74194336, 21.67749977], [88.7408371, 21.67861176], [88.74054718, 21.67861176], [88.73972321, 21.6794529], [88.73944092, 21.6794529], [88.7388916, 21.68000031], [88.73860931, 21.68000031], [88.73832703, 21.68028259], [88.73805237, 21.68028259], [88.73777771, 21.68056107], [88.73750305, 21.68055534], [88.73722076, 21.68083382], [88.73694611, 21.68083191], [88.73665619, 21.68111038], [88.73638916, 21.68111038], [88.73610687, 21.68139076], [88.73583221, 21.68139076], [88.73555756, 21.68167114], [88.73500061, 21.68166733], [88.73472595, 21.68194389], [88.73416901, 21.68194389], [88.73388672, 21.68222237], [88.73361206, 21.68222046], [88.73332977, 21.68250084], [88.73306274, 21.68250084], [88.73278046, 21.68278122], [88.73249817, 21.68278122], [88.73221588, 21.68305969], [88.73194122, 21.68305969], [88.73083496, 21.68416405], [88.73083496, 21.68444633], [88.73055267, 21.68472099], [88.73055267, 21.68638611], [88.73139191, 21.68722153], [88.73194122, 21.68721962], [88.73199463, 21.68727684], [88.73221588, 21.6875], [88.73665619, 21.6875], [88.73722076, 21.68806076], [88.73805237, 21.68805695], [88.73833466, 21.68833351], [88.73860931, 21.68833351], [88.7388916, 21.68861198], [88.73916626, 21.68861008], [88.73944092, 21.68889046], [88.73972321, 21.68889046], [88.73999786, 21.68917084], [88.74028015, 21.68916893], [88.74041748, 21.68930435], [88.74055481, 21.68944359], [88.74111176, 21.68944359], [88.74138641, 21.68916893], [88.74194336, 21.68917084], [88.74250031, 21.68861008], [88.74250031, 21.68833351], [88.74277496, 21.68805695], [88.74276733, 21.68721962], [88.74305725, 21.68694687], [88.74276733, 21.6866703], [88.74276733, 21.68638992], [88.74250031, 21.68610954], [88.74250031, 21.68527794], [88.74276733, 21.68499947], [88.74276733, 21.68444061], [88.74333191, 21.68388939], [88.74333191, 21.68359947], [88.7444458, 21.68250084], [88.74472046, 21.68250084], [88.74500275, 21.68222046], [88.74583435, 21.68222237], [88.74610901, 21.68194389], [88.74749756, 21.68194389], [88.74777985, 21.68222237], [88.74833679, 21.68222046], [88.74861145, 21.68250084], [88.74916077, 21.68250084], [88.74944305, 21.68278122], [88.74973297, 21.68278122], [88.75, 21.68305969], [88.75027466, 21.68305588], [88.75055695, 21.68333244], [88.75250244, 21.68333244], [88.7527771, 21.68305588], [88.75305176, 21.68305969], [88.75332642, 21.68278122], [88.75417328, 21.68278122], [88.75444794, 21.68250084], [88.75499725, 21.68250084], [88.75528717, 21.68222046], [88.75749969, 21.68227577], [88.75776672, 21.68250084], [88.7583313, 21.68250084], [88.75860596, 21.68278122], [88.7591629, 21.68278122], [88.75945282, 21.68305969], [88.75971985, 21.68305588], [88.76000214, 21.68333244], [88.76027679, 21.68333244], [88.76087189, 21.68392944], [88.76166534, 21.68472481], [88.76167297, 21.68499947], [88.76222229, 21.6855545], [88.76222229, 21.68583488], [88.76249695, 21.68610954], [88.76249695, 21.68638992], [88.76277924, 21.6866703], [88.76277924, 21.68916893], [88.76305389, 21.68944359], [88.76304626, 21.69082832], [88.76333618, 21.69111061], [88.76333618, 21.69138908], [88.76389313, 21.6919384], [88.76444244, 21.69249916], [88.76444244, 21.6927681], [88.76454926, 21.69288635], [88.7647171, 21.69306183], [88.76499939, 21.69306183], [88.76526642, 21.6927681], [88.76583099, 21.69277763], [88.76611328, 21.69249916], [88.76667023, 21.69249916], [88.76694489, 21.69277763], [88.76889038, 21.6927681], [88.76917267, 21.69306183], [88.76972198, 21.69305611], [88.76990509, 21.69324112], [88.76999664, 21.69333267], [88.77083588, 21.69333267], [88.77111053, 21.69361115], [88.7722168, 21.69361115], [88.77249908, 21.69388962], [88.77416992, 21.69388962], [88.77443695, 21.69417191], [88.77471924, 21.69416618], [88.77500153, 21.69444466], [88.77527618, 21.69444466], [88.77555847, 21.69472122], [88.77610779, 21.69472122], [88.7766571, 21.69528008], [88.77694702, 21.69527817], [88.77722168, 21.69555473], [88.77749634, 21.69555473], [88.77777863, 21.6958313], [88.77889252, 21.6958313], [88.77925873, 21.69620323], [88.77944183, 21.69639015], [88.77971649, 21.69639015], [88.78028107, 21.69695091], [88.78083038, 21.69695091], [88.78138733, 21.69750023], [88.78166962, 21.69750023], [88.78193665, 21.69778061], [88.78221893, 21.6977787], [88.78277588, 21.69833565], [88.78305817, 21.69832993], [88.78360748, 21.69890022], [88.78388977, 21.69890022], [88.7841568, 21.69917107], [88.78472137, 21.69916534], [88.78500366, 21.69944572], [88.78555298, 21.69944], [88.78610992, 21.70000076], [88.78639221, 21.70000076], [88.78666687, 21.70028114], [88.78694153, 21.70028114], [88.78721619, 21.70055962], [88.78749847, 21.70055771], [88.78778076, 21.70083427], [88.78806305, 21.70083046], [88.78833008, 21.70111084], [88.78861237, 21.70111084], [88.78916931, 21.70166969], [88.78944397, 21.70166779], [88.78971863, 21.70194435], [88.79000092, 21.70194435], [88.79027557, 21.70222282], [88.79055786, 21.70222092], [88.79110718, 21.70277977], [88.79139709, 21.70277977], [88.79148102, 21.70287132], [88.79165649, 21.70305824], [88.79222107, 21.70305634], [88.79250336, 21.7033329], [88.79305267, 21.70332909], [88.79333496, 21.70360756], [88.79360962, 21.70388985], [88.79444122, 21.70388985], [88.79471588, 21.70416832], [88.79528046, 21.70416641], [88.79555511, 21.70444489], [88.79638672, 21.70444489], [88.79666901, 21.70472145], [88.79722595, 21.7047081], [88.79750061, 21.70500183], [88.7977829, 21.70500183], [88.79833221, 21.70556259], [88.79972076, 21.70555496], [88.79988861, 21.7057209], [88.80000305, 21.70583344], [88.80027771, 21.70583344], [88.80055237, 21.70611191], [88.80110931, 21.70611191], [88.80125427, 21.70625114], [88.8013916, 21.70639038], [88.80304718, 21.70639038], [88.8033371, 21.70667267], [88.80361176, 21.70667267], [88.80388641, 21.70639038], [88.8041687, 21.70639038], [88.80473328, 21.70583153], [88.80527496, 21.70583344], [88.80555725, 21.70555496], [88.80583191, 21.70583153], [88.80583191, 21.70639038], [88.80610657, 21.70667267], [88.80665588, 21.70667267]]], [[[88.56243134, 21.70505905], [88.56301117, 21.70483589], [88.563591, 21.70450592], [88.56414032, 21.70407104], [88.56463623, 21.7035408], [88.56505585, 21.70294189], [88.56532288, 21.70228004], [88.5655899, 21.70169258], [88.56587219, 21.70119858], [88.56585693, 21.70063019], [88.56584167, 21.70008469], [88.56584167, 21.69955254], [88.56585693, 21.69902039], [88.56594849, 21.69849968], [88.56600952, 21.69799423], [88.56588745, 21.69747353], [88.56584167, 21.69694901], [88.56582642, 21.69641113], [88.56581116, 21.69588852], [88.56574249, 21.69536018], [88.56564331, 21.69482994], [88.56583405, 21.69416618], [88.56583405, 21.69363976], [88.56583405, 21.69305611], [88.5661087, 21.6927681], [88.5661087, 21.6922226], [88.56583405, 21.69194412], [88.56583405, 21.69138908], [88.56555939, 21.69111061], [88.56555176, 21.69055557], [88.5652771, 21.69028091], [88.5652771, 21.68972969], [88.56555939, 21.68943977], [88.56555176, 21.68916893], [88.5652771, 21.68889046], [88.5652771, 21.68695831], [88.56555939, 21.6866703], [88.56555939, 21.68556023], [88.56582642, 21.68527985], [88.56582642, 21.68499947], [88.5661087, 21.68472099], [88.5661087, 21.68416405], [88.56639099, 21.68388939], [88.56639099, 21.68333054], [88.56666565, 21.68305588], [88.56667328, 21.68250084], [88.56694794, 21.68222237], [88.56694794, 21.68166733], [88.5672226, 21.68139076], [88.5672226, 21.68111038], [88.56749725, 21.68083191], [88.56749725, 21.68027687], [88.56777954, 21.68000031], [88.56777954, 21.6794529], [88.56804657, 21.67917252], [88.56804657, 21.67861176], [88.56833649, 21.67833328], [88.56833649, 21.67805481], [88.56861115, 21.67777824], [88.56861877, 21.67749977], [88.5688858, 21.6772213], [88.5688858, 21.67527962], [88.56861877, 21.67500114], [88.56861877, 21.67278099], [88.5688858, 21.67250061], [88.56861877, 21.67222023], [88.56861115, 21.67055321], [88.5688858, 21.67028046], [88.5688858, 21.6697197], [88.56916809, 21.66944313], [88.5688858, 21.66917038], [88.5688858, 21.66889], [88.56861877, 21.66860008], [88.56861115, 21.66833115], [88.56833649, 21.66805649], [88.56833649, 21.66722107], [88.5680542, 21.6669445], [88.5680542, 21.66610909], [88.56777954, 21.66583061], [88.56777954, 21.66527748], [88.56694794, 21.66443825], [88.56694794, 21.6641674], [88.56667328, 21.66389084], [88.56667328, 21.66361046], [88.56555176, 21.66250038], [88.5652771, 21.66250038], [88.5644455, 21.66166878], [88.56445313, 21.6613903], [88.56416321, 21.66110992], [88.56360626, 21.66110992], [88.5633316, 21.6613903], [88.5633316, 21.66082954], [88.56277466, 21.66027832], [88.56276703, 21.65999985], [88.56249237, 21.65999985], [88.56266022, 21.65974045], [88.56210327, 21.65942764], [88.5616684, 21.65888977], [88.56111145, 21.65833092], [88.56111145, 21.65749931], [88.56083679, 21.65722084], [88.5605545, 21.65722466], [88.5588913, 21.65555573], [88.55860901, 21.65555954], [88.55722809, 21.6541748], [88.5567627, 21.65370941], [88.55638885, 21.65333366], [88.55626678, 21.65333366], [88.55596161, 21.6530571], [88.55568695, 21.65279961], [88.55544281, 21.65254021], [88.55516815, 21.65209007], [88.55480194, 21.65179062], [88.55458069, 21.65146065], [88.55439758, 21.65114021], [88.55417633, 21.65089035], [88.55399323, 21.65064049], [88.55384064, 21.65036964], [88.5536499, 21.65010071], [88.5535202, 21.64976311], [88.55330658, 21.64941978], [88.55305481, 21.64904404], [88.55278015, 21.64861107], [88.55278015, 21.64833069], [88.55249786, 21.64805794], [88.55249786, 21.64777946], [88.55222321, 21.64750099], [88.55222321, 21.64639091], [88.55194092, 21.64611053], [88.55194092, 21.64556122], [88.55166626, 21.64528084], [88.55194092, 21.64500046], [88.55194092, 21.64443016], [88.5513916, 21.64388847], [88.5513916, 21.6408329], [88.55166626, 21.64055634], [88.55166626, 21.63943863], [88.55194092, 21.63916588], [88.55194092, 21.63777733], [88.55190277, 21.63713074], [88.55156708, 21.63665962], [88.55091858, 21.63648987], [88.55052948, 21.63659096], [88.55017853, 21.63659096], [88.54972076, 21.6364994], [88.54920197, 21.63656044], [88.54859161, 21.63640022], [88.54833221, 21.63666916], [88.54777527, 21.63666725], [88.54750061, 21.63694382], [88.54694366, 21.63694382], [88.54666901, 21.63666725], [88.54638672, 21.63666725], [88.54556274, 21.63750076], [88.54528046, 21.63750076], [88.54499817, 21.63777733], [88.54462433, 21.63796234], [88.54411316, 21.63813019], [88.54368591, 21.63842964], [88.54325104, 21.63869286], [88.54283142, 21.63891983], [88.5424118, 21.63916969], [88.5419693, 21.63939667], [88.54145813, 21.63952446], [88.54099274, 21.63974953], [88.54058075, 21.64010048], [88.54019165, 21.64051437], [88.53974915, 21.6409111], [88.53929138, 21.64131927], [88.53872681, 21.64159012], [88.53827667, 21.64198494], [88.53778839, 21.6423912], [88.53733063, 21.64286041], [88.53692627, 21.64337921], [88.53655243, 21.64386177], [88.53616333, 21.64430046], [88.53582001, 21.64474106], [88.53546906, 21.64519882], [88.53505707, 21.64562988], [88.53468323, 21.64608955], [88.53430939, 21.64653015], [88.53392792, 21.64697456], [88.53354645, 21.64742279], [88.53312683, 21.64784813], [88.53273773, 21.6483078], [88.53237152, 21.64874268], [88.53203583, 21.64915466], [88.53172302, 21.64954185], [88.53143311, 21.64993286], [88.5311203, 21.65027809], [88.53083801, 21.65065956], [88.53056335, 21.65105247], [88.53031158, 21.6514492], [88.5300827, 21.65187073], [88.52981567, 21.65224648], [88.52957916, 21.65265274], [88.52947235, 21.65307999], [88.52944946, 21.6534729], [88.52944946, 21.65379906], [88.52942657, 21.65407562], [88.52934265, 21.65433311], [88.52925873, 21.65457344], [88.52915955, 21.65479279], [88.52899933, 21.6550312], [88.52881622, 21.65531921], [88.52856445, 21.65558815], [88.52832031, 21.65596962], [88.52809906, 21.65642929], [88.52805328, 21.65699005], [88.52805328, 21.65755272], [88.52805328, 21.65806961], [88.52805328, 21.6585331], [88.52805328, 21.65896034], [88.52809143, 21.65934944], [88.52826691, 21.65968323], [88.52836609, 21.66006088], [88.52855682, 21.66040993], [88.52871704, 21.66081429], [88.52890778, 21.66120338], [88.52901459, 21.66135216], [88.52913666, 21.66153145], [88.52931976, 21.66181183], [88.5295105, 21.66201401], [88.52971649, 21.66222191], [88.52997589, 21.66250038], [88.53024292, 21.66287994], [88.53053284, 21.66329956], [88.53082275, 21.66374969], [88.53110504, 21.66422653], [88.53141785, 21.66472435], [88.5318222, 21.66517067], [88.53222656, 21.66571999], [88.53263092, 21.6662693], [88.53277588, 21.6669445], [88.53305817, 21.66722107], [88.53305817, 21.66749954], [88.53333282, 21.66777802], [88.53333282, 21.66860008], [88.53305817, 21.66889], [88.53194427, 21.67000008], [88.53193665, 21.67111015], [88.53166962, 21.67138863], [88.53166962, 21.67166519], [88.53111267, 21.67222023], [88.53111267, 21.67416954], [88.53085327, 21.67435074], [88.53076935, 21.67440796], [88.53063202, 21.67465973], [88.5306778, 21.67510986], [88.53083801, 21.67564964], [88.53100586, 21.67624474], [88.53102875, 21.67690468], [88.53083801, 21.67747116], [88.53058624, 21.67791939], [88.53037262, 21.67833138], [88.530159, 21.67874908], [88.53002167, 21.67929077], [88.529953, 21.67991066], [88.52970886, 21.68053818], [88.52941132, 21.6811409], [88.52912903, 21.68169022], [88.52890778, 21.68223953], [88.52881622, 21.68280792], [88.52861023, 21.68321991], [88.52837372, 21.68357086], [88.52812958, 21.68388367], [88.52789307, 21.68416023], [88.52767944, 21.68445015], [88.5275116, 21.68476677], [88.52736664, 21.68513107], [88.52722168, 21.68558121], [88.52706909, 21.68606186], [88.52696991, 21.68656349], [88.52693939, 21.6870594], [88.52694702, 21.68751907], [88.5269928, 21.68792915], [88.52713013, 21.68827057], [88.52739716, 21.6885128], [88.52752686, 21.68889046], [88.52770233, 21.6892662], [88.527771, 21.68972969], [88.52777863, 21.6902504], [88.52773285, 21.6907692], [88.52754211, 21.69128036], [88.5274353, 21.69176865], [88.52723694, 21.69219017], [88.52702332, 21.69260025], [88.52675629, 21.6929512], [88.52646637, 21.69319725], [88.52614594, 21.69342041], [88.52581787, 21.69375038], [88.5255661, 21.69440079], [88.52513885, 21.69479561], [88.52453613, 21.69490814], [88.52414703, 21.69555664], [88.52380371, 21.69564247], [88.52349854, 21.69596481], [88.52329254, 21.69628906], [88.52310944, 21.69657707], [88.52302551, 21.69689941], [88.52287292, 21.69712067], [88.52269745, 21.69729996], [88.52258301, 21.69747162], [88.52259064, 21.6977005], [88.52250671, 21.69802094], [88.52233887, 21.69832039], [88.5222168, 21.69861031], [88.5221405, 21.69889069], [88.52197266, 21.69917107], [88.52185059, 21.69948769], [88.52172089, 21.69985008], [88.52156067, 21.70028114], [88.52131653, 21.70070076], [88.52150726, 21.70111084], [88.52196503, 21.70124626], [88.52222443, 21.70194435], [88.5222168, 21.70222092], [88.52054596, 21.70388985], [88.52055359, 21.70416641], [88.52083588, 21.70443916], [88.52027893, 21.70500183], [88.52027893, 21.7052803], [88.51999664, 21.70555496], [88.51999664, 21.70583344], [88.51983643, 21.70585251], [88.51889801, 21.70596695], [88.51860809, 21.70611191], [88.51833344, 21.70638847], [88.51832581, 21.7069416], [88.51819611, 21.70708847], [88.51819611, 21.70722008], [88.51789093, 21.70778847], [88.51777649, 21.7082901], [88.51763153, 21.70874977], [88.51756287, 21.70915031], [88.51751709, 21.70952988], [88.51747894, 21.70992279], [88.51734924, 21.7103405], [88.51724243, 21.71084023], [88.51721954, 21.71140099], [88.51727295, 21.71195984], [88.51747131, 21.71242905], [88.51761627, 21.71284485], [88.51773834, 21.7131958], [88.51781464, 21.71354294], [88.51798248, 21.7138195], [88.51815033, 21.71410751], [88.51832581, 21.71439934], [88.51847076, 21.71473122], [88.51863861, 21.71507835], [88.51889038, 21.71538925], [88.51916504, 21.71570396], [88.51944733, 21.7160244], [88.51973724, 21.71633148], [88.52009583, 21.71661186], [88.52058411, 21.71679115], [88.52115631, 21.71691322], [88.52180481, 21.71694183], [88.52245331, 21.71694374], [88.52307129, 21.71694374], [88.52366638, 21.71694374], [88.52420807, 21.71694374], [88.52471924, 21.71694374], [88.52638245, 21.71693993], [88.5283432, 21.71888924], [88.52879333, 21.71931267], [88.52921295, 21.71977806], [88.52953339, 21.72021294], [88.5297699, 21.72058105], [88.52996826, 21.72087097], [88.53010559, 21.72115707], [88.53025818, 21.72141075], [88.53038025, 21.72170067], [88.5305481, 21.7219429], [88.53070831, 21.72217941], [88.53085327, 21.72243118], [88.53096771, 21.72269249], [88.53111267, 21.72294807], [88.53122711, 21.72323036], [88.53138733, 21.72350311], [88.53151703, 21.7238121], [88.53166199, 21.7241497], [88.53179932, 21.72456169], [88.53195953, 21.72501945], [88.53213501, 21.72550964], [88.53225708, 21.72606087], [88.53238678, 21.72662926], [88.53253174, 21.72719193], [88.53268433, 21.72774124], [88.53283691, 21.7282505], [88.53302765, 21.72865105], [88.53318024, 21.72900009], [88.5333252, 21.72931862], [88.53347015, 21.72961044], [88.53365326, 21.72987175], [88.53382111, 21.73010826], [88.53395844, 21.73038483], [88.53411865, 21.73063087], [88.53425598, 21.73090935], [88.53444672, 21.73116875], [88.53464508, 21.73145294], [88.53483582, 21.73181152], [88.53509521, 21.73225784], [88.53547668, 21.73271179], [88.53596497, 21.73313904], [88.53650665, 21.73351097], [88.53710175, 21.73386955], [88.53768921, 21.7342205], [88.53824615, 21.73460007], [88.5388031, 21.73493195], [88.53936768, 21.73521996], [88.53990936, 21.7354908], [88.54046631, 21.73574066], [88.54107666, 21.73592949], [88.54174042, 21.73604012], [88.54235077, 21.73611641], [88.5428772, 21.73620033], [88.54335022, 21.7362709], [88.54379272, 21.73628807], [88.54425049, 21.73628044], [88.54473877, 21.73624992], [88.54520416, 21.73619652], [88.54566956, 21.73612976], [88.54611206, 21.73612022], [88.54656219, 21.7361412], [88.54701233, 21.73612976], [88.54746246, 21.73612022], [88.5479126, 21.73611069], [88.54836273, 21.73611069], [88.54882813, 21.73610115], [88.54930878, 21.7360611], [88.54981232, 21.73598099], [88.55039215, 21.73588943], [88.55102539, 21.7357769], [88.55165863, 21.73563957], [88.55230713, 21.73554039], [88.55292511, 21.73542976], [88.5535202, 21.73526382], [88.55407715, 21.73506737], [88.55458832, 21.73483849], [88.55506134, 21.73455811], [88.55550385, 21.73425674], [88.55591583, 21.73392105], [88.55631256, 21.73353958], [88.55666351, 21.73315048], [88.55697632, 21.73269081], [88.55730438, 21.73220062], [88.55761719, 21.73167038], [88.55795288, 21.73110962], [88.55828094, 21.73057938], [88.5586319, 21.73015976], [88.55896759, 21.72982979], [88.55930328, 21.72961235], [88.55966187, 21.72945786], [88.56004333, 21.72936058], [88.56041718, 21.72930717], [88.56079865, 21.72936058], [88.56115723, 21.72951126], [88.56151581, 21.72972107], [88.56192017, 21.72995186], [88.56237793, 21.73022079], [88.56289673, 21.73050117], [88.56347656, 21.73076057], [88.56407166, 21.73108101], [88.56463623, 21.73140526], [88.56520081, 21.7317009], [88.56577301, 21.7319603], [88.56632233, 21.73218727], [88.56659698, 21.73226929], [88.56687927, 21.73235321], [88.56745148, 21.7324028], [88.56802368, 21.73237038], [88.56859589, 21.73230362], [88.56920624, 21.73230171], [88.56989288, 21.7324295], [88.57055664, 21.73250008], [88.5708313, 21.73250008], [88.57110596, 21.7322216], [88.57111359, 21.73194504], [88.5716629, 21.73138809], [88.5716629, 21.73110962], [88.57138824, 21.73111153], [88.57120514, 21.73092842], [88.5708313, 21.73055649], [88.57055664, 21.7305584], [88.5716629, 21.72944069], [88.5716629, 21.72833252], [88.57194519, 21.72805786], [88.57195282, 21.72777939], [88.57250214, 21.72722054], [88.57254028, 21.72636604], [88.57253265, 21.72602272], [88.57264709, 21.72568893], [88.5728302, 21.72533798], [88.57306671, 21.72497177], [88.57332611, 21.72456169], [88.5736084, 21.72410011], [88.57389832, 21.72360039], [88.57417297, 21.72309113], [88.57444763, 21.72260094], [88.57470703, 21.72215271], [88.57495117, 21.72170067], [88.57513428, 21.7212677], [88.57533264, 21.72091293], [88.57556152, 21.72065353], [88.57581329, 21.72044754], [88.5760498, 21.72020149], [88.5762558, 21.71985054], [88.57646942, 21.71943855], [88.5766983, 21.71902084], [88.57698059, 21.71865082], [88.57730103, 21.71834183], [88.57762909, 21.71805954], [88.57795715, 21.71780014], [88.57832336, 21.71755981], [88.57867432, 21.71728706], [88.5790863, 21.71698952], [88.57949829, 21.71654892], [88.57994843, 21.71611023], [88.58035278, 21.71554947], [88.58084106, 21.71512413], [88.58135986, 21.71477509], [88.58191681, 21.71449089], [88.58247375, 21.71417618], [88.58297729, 21.71380997], [88.58344269, 21.71340942], [88.58388519, 21.7130661], [88.5843277, 21.71276283], [88.58473206, 21.71243095], [88.58513641, 21.71207047], [88.58554077, 21.71170235], [88.58596039, 21.71133041], [88.5863266, 21.71088982], [88.58667755, 21.71043968], [88.58696747, 21.71002007], [88.5872345, 21.70965958], [88.58744049, 21.70927811], [88.58751678, 21.70881271], [88.58759308, 21.70829964], [88.58773041, 21.70776939], [88.58779144, 21.70721245], [88.5878067, 21.70661545], [88.58779144, 21.70600128], [88.58771515, 21.70543289], [88.58751678, 21.7049408], [88.58744049, 21.70478821], [88.58728027, 21.7044754], [88.58703613, 21.70395851], [88.58677673, 21.70339012], [88.58663177, 21.7027607], [88.58670044, 21.70220947], [88.58664703, 21.70171165], [88.58643341, 21.70119476], [88.58622742, 21.700634], [88.58612061, 21.70002174], [88.5860672, 21.69942856], [88.58616638, 21.69893265], [88.58634949, 21.69856453], [88.58650208, 21.69823265], [88.58665466, 21.69791412], [88.58679962, 21.69753838], [88.58700562, 21.69711876], [88.58728027, 21.69663811], [88.58761597, 21.69614029], [88.58796692, 21.69561958], [88.58833313, 21.6950798], [88.58869934, 21.6945591], [88.58908081, 21.69407845], [88.58943176, 21.69360161], [88.58974457, 21.69309235], [88.59002686, 21.69256783], [88.59030151, 21.69206047], [88.59055328, 21.69153976], [88.59067535, 21.69103813], [88.59069824, 21.69062805], [88.59052277, 21.69028091], [88.59020233, 21.69001389], [88.58981323, 21.68982124], [88.5893631, 21.68970299], [88.58888245, 21.6896019], [88.58840942, 21.68943977], [88.58790588, 21.689291], [88.58744812, 21.68912125], [88.58701324, 21.68895912], [88.58657837, 21.68882751], [88.58612061, 21.68868065], [88.58563995, 21.68852043], [88.58519745, 21.68832016], [88.58474731, 21.68814087], [88.5843277, 21.68798065], [88.58390808, 21.68777084], [88.58347321, 21.68755341], [88.58305359, 21.68725014], [88.58261108, 21.68693352], [88.58214569, 21.68662262], [88.5816803, 21.68629646], [88.58126068, 21.68585968], [88.58088684, 21.68533707], [88.58055878, 21.68486977], [88.58024597, 21.68468094], [88.57997894, 21.68490982], [88.57971191, 21.68511581], [88.57953644, 21.68548965], [88.57946014, 21.68597794], [88.57942963, 21.68613815], [88.57937622, 21.68646049], [88.57925415, 21.68690681], [88.57918549, 21.68737221], [88.5791626, 21.68786049], [88.57910919, 21.68836975], [88.57897186, 21.68886948], [88.5789032, 21.68939972], [88.5788269, 21.68995285], [88.57868195, 21.69046021], [88.5785675, 21.69097519], [88.57837677, 21.6914711], [88.57819366, 21.69201469], [88.57788849, 21.69247818], [88.57752991, 21.69296837], [88.5771637, 21.69346428], [88.57670593, 21.69390488], [88.57623291, 21.69432068], [88.575737, 21.69474983], [88.57530212, 21.69518852], [88.57489777, 21.69563293], [88.57448578, 21.69597626], [88.57411194, 21.69631958], [88.5737381, 21.6966629], [88.57337952, 21.69698906], [88.57304382, 21.69734383], [88.57272339, 21.69769287], [88.57241058, 21.69803047], [88.57213593, 21.69831276], [88.57189178, 21.6985817], [88.57167053, 21.69883728], [88.5714798, 21.69912338], [88.57132721, 21.69947243], [88.57111359, 21.69983292], [88.57086945, 21.70024109], [88.57064056, 21.70070076], [88.57047272, 21.70121193], [88.57032776, 21.7017498], [88.57022095, 21.70232964], [88.57009888, 21.70294189], [88.57009125, 21.70360756], [88.57021332, 21.70427895], [88.57026672, 21.70496941], [88.57028198, 21.70563698], [88.5703125, 21.7062645], [88.57039642, 21.70685959], [88.57050323, 21.70743942], [88.57054901, 21.70802116], [88.57055664, 21.70855331], [88.57052612, 21.70902061], [88.57042694, 21.70940018], [88.5703125, 21.70973015], [88.57022858, 21.71003914], [88.57009125, 21.71032715], [88.56993866, 21.71062088], [88.56967926, 21.71086121], [88.56935883, 21.71105003], [88.56896973, 21.71113396], [88.56859589, 21.71124458], [88.5682373, 21.71136093], [88.56788635, 21.71149063], [88.56742096, 21.71158981], [88.56690216, 21.71167755], [88.56639862, 21.71178055], [88.56591034, 21.71173668], [88.56543732, 21.7116909], [88.56497955, 21.71169853], [88.56455231, 21.7118206], [88.56412506, 21.71191597], [88.56369019, 21.71199799], [88.56328583, 21.71212959], [88.56282806, 21.71220016], [88.56234741, 21.7122364], [88.56188965, 21.71231461], [88.56143951, 21.71244812], [88.56098938, 21.71259117], [88.56059265, 21.71277618], [88.56021118, 21.71301079], [88.55982971, 21.71327019], [88.55950165, 21.7135582], [88.55927277, 21.71390915], [88.55912018, 21.71431923], [88.55899048, 21.71475983], [88.55893707, 21.715271], [88.55892944, 21.71575928], [88.55890656, 21.71620941], [88.55888367, 21.71660614], [88.55880737, 21.71695137], [88.55869293, 21.71725082], [88.55858612, 21.71755791], [88.55845642, 21.71786118], [88.55823517, 21.7181263], [88.55796051, 21.71837997], [88.55767059, 21.71866989], [88.55738831, 21.71898079], [88.55708313, 21.71929932], [88.55677032, 21.71961594], [88.55646515, 21.71993446], [88.55619049, 21.72027016], [88.55596924, 21.72067833], [88.5557785, 21.72113037], [88.55554962, 21.72157669], [88.55526733, 21.72203064], [88.5549469, 21.72249031], [88.55455017, 21.72290039], [88.55410767, 21.72326088], [88.55365753, 21.72356987], [88.55321503, 21.72383308], [88.55280304, 21.72404099], [88.55236053, 21.72419739], [88.55187988, 21.72431183], [88.55138397, 21.72442436], [88.55085754, 21.72454453], [88.55033875, 21.72466087], [88.54982758, 21.72476006], [88.54930878, 21.72483063], [88.54875946, 21.72486687], [88.54816437, 21.72488403], [88.54750061, 21.72492218], [88.54676819, 21.72492027], [88.5460434, 21.72485161], [88.54537964, 21.72472191], [88.54476166, 21.72459221], [88.54417419, 21.72447205], [88.54364014, 21.72434616], [88.54322052, 21.72417068], [88.54301453, 21.72391319], [88.54305267, 21.72367287], [88.54329681, 21.72356224], [88.54367065, 21.7235527], [88.5440979, 21.72351074], [88.544487, 21.72330093], [88.54479218, 21.72287941], [88.54493713, 21.72229958], [88.54499054, 21.72164917], [88.54503632, 21.72103119], [88.54515076, 21.72055244], [88.54534149, 21.72032738], [88.545578, 21.72041512], [88.54577637, 21.72076416], [88.54586029, 21.72121811], [88.54582977, 21.72166252], [88.54576111, 21.72211075], [88.54573059, 21.72258568], [88.54576874, 21.72305489], [88.54590607, 21.72341347], [88.54615021, 21.72362328], [88.5464859, 21.72375488], [88.54688263, 21.72383308], [88.5473175, 21.72387123], [88.5477829, 21.72388458], [88.54824829, 21.72386932], [88.54870605, 21.72381973], [88.54915619, 21.72372055], [88.54963684, 21.72367287], [88.55008698, 21.72364044], [88.55053711, 21.72360992], [88.55095673, 21.7235508], [88.55136871, 21.7234211], [88.55178833, 21.72332573], [88.55220795, 21.72319984], [88.55264282, 21.72301102], [88.55309296, 21.72270012], [88.55354309, 21.7222805], [88.55400085, 21.72178078], [88.55448914, 21.72131157], [88.55444336, 21.72110939], [88.55500031, 21.72055626], [88.55500031, 21.72027969], [88.55610657, 21.71916962], [88.55631256, 21.71857071], [88.55658722, 21.71819496], [88.55690002, 21.71783066], [88.55721283, 21.71742058], [88.55747223, 21.7169342], [88.55764771, 21.71636581], [88.55776215, 21.71580505], [88.55780029, 21.71524048], [88.55782318, 21.71468163], [88.55796051, 21.71419334], [88.55815887, 21.71373177], [88.55839539, 21.71331024], [88.55866241, 21.71293831], [88.55896759, 21.71261978], [88.55930328, 21.7123394], [88.55969238, 21.71211243], [88.56011963, 21.71187592], [88.56054688, 21.71158981], [88.5610199, 21.7113018], [88.56163025, 21.71108055], [88.56227112, 21.71088982], [88.5629425, 21.71073914], [88.56358337, 21.71055031], [88.5641861, 21.71037102], [88.56478119, 21.71030045], [88.56532288, 21.71027946], [88.5657959, 21.71027946], [88.56624603, 21.71027946], [88.56668854, 21.71026993], [88.56713104, 21.71025848], [88.56755829, 21.71019173], [88.56793213, 21.71000671], [88.56829834, 21.70976067], [88.56859589, 21.70941925], [88.56880951, 21.70900345], [88.56893158, 21.70849228], [88.56900024, 21.70796585], [88.56893921, 21.70743942], [88.56890869, 21.70689011], [88.56887054, 21.70633125], [88.56878662, 21.70578957], [88.56868744, 21.70522118], [88.56864929, 21.70460701], [88.5686264, 21.70400047], [88.56864166, 21.70339966], [88.56868744, 21.70284081], [88.56884003, 21.70232964], [88.56894684, 21.70177269], [88.56915283, 21.70119095], [88.56936646, 21.7005806], [88.56958771, 21.6999855], [88.56978607, 21.69942284], [88.57002258, 21.69896317], [88.57028198, 21.69858932], [88.57052612, 21.69823074], [88.57077789, 21.69785118], [88.57106018, 21.69748116], [88.57135773, 21.69712067], [88.57167816, 21.6967411], [88.572052, 21.69638443], [88.57247162, 21.69600487], [88.5729599, 21.69558144], [88.5735321, 21.69511223], [88.57406616, 21.69452667], [88.57420349, 21.69402695], [88.5739212, 21.69379044], [88.5735321, 21.69364548], [88.5730896, 21.69358063], [88.57267761, 21.69341278], [88.57224274, 21.69316101], [88.57162476, 21.69313622], [88.57095337, 21.69326973], [88.57023621, 21.69330978], [88.56952667, 21.69326019], [88.56885529, 21.69307709], [88.56820679, 21.69293022], [88.56781006, 21.69286728], [88.56762695, 21.69284058], [88.56743622, 21.69300842], [88.567276, 21.69314957], [88.56720734, 21.6937809], [88.56720734, 21.69440079], [88.56723022, 21.69494629], [88.56729126, 21.69546127], [88.56743622, 21.69598961], [88.56749725, 21.6965847], [88.56752014, 21.69722939], [88.56755829, 21.69791031], [88.56764221, 21.69859123], [88.56755829, 21.69927979], [88.56751251, 21.69993973], [88.56748962, 21.70055962], [88.56743622, 21.70110512], [88.56730652, 21.70153809], [88.56719208, 21.70196152], [88.56704712, 21.70230865], [88.56693268, 21.70264816], [88.5667572, 21.70297623], [88.56656647, 21.70331955], [88.56630707, 21.70369148], [88.56600189, 21.70412064], [88.56558228, 21.70454979], [88.56512451, 21.70500183], [88.56459045, 21.70544052], [88.5639801, 21.70580101], [88.56333923, 21.70609665], [88.56272125, 21.70636368], [88.56212616, 21.70657921], [88.56150818, 21.70671082], [88.56091309, 21.70685959], [88.56027985, 21.70691109], [88.55963898, 21.70691109], [88.559021, 21.70685959], [88.5585022, 21.70671082], [88.55799103, 21.70660019], [88.5577774, 21.70639038], [88.5569458, 21.70639038], [88.55583191, 21.7052803], [88.55555725, 21.7052803], [88.55488586, 21.70460701], [88.55472565, 21.70444489], [88.55421448, 21.70418167], [88.55371857, 21.70369148], [88.5533371, 21.70361137], [88.5533371, 21.7033329], [88.55278015, 21.70277977], [88.5533371, 21.70222092], [88.55377197, 21.70249939], [88.55420685, 21.70281029], [88.55464935, 21.7031002], [88.5550766, 21.70339966], [88.5555191, 21.70369148], [88.55594635, 21.70400047], [88.55638123, 21.70428848], [88.55658722, 21.704422], [88.55683136, 21.7045784], [88.55732727, 21.70482063], [88.55786133, 21.70501709], [88.55838013, 21.70519829], [88.55890656, 21.70527077], [88.55940247, 21.70531082], [88.5598526, 21.70540047], [88.56030273, 21.70547104], [88.5607605, 21.70537949], [88.56128693, 21.70531082], [88.56185913, 21.70523071], [88.56243134, 21.70505905]]], [[[88.88305664, 21.74527931], [88.88276672, 21.74500084], [88.88360596, 21.74500084], [88.88388824, 21.74472046], [88.88444519, 21.74472237], [88.88471985, 21.74444389], [88.88500214, 21.74416733], [88.88555908, 21.74416924], [88.88639069, 21.74332809], [88.88666534, 21.74333382], [88.88722229, 21.74277878], [88.88749695, 21.74278069], [88.88777924, 21.74250031], [88.88804626, 21.74250031], [88.88833618, 21.74221992], [88.88861084, 21.74222183], [88.8888855, 21.74194527], [88.88916779, 21.74194908], [88.88944244, 21.74167061], [88.8897171, 21.74167061], [88.89055634, 21.74081993], [88.89111328, 21.74083328], [88.89138794, 21.74055672], [88.89167023, 21.74055672], [88.89194489, 21.74027824], [88.89221954, 21.74028015], [88.89332581, 21.73917007], [88.89362335, 21.73917007], [88.89389038, 21.73888969], [88.89417267, 21.73888969], [88.89444733, 21.73861122], [88.89472198, 21.73861122], [88.89583588, 21.73750114], [88.89611053, 21.73750114], [88.89639282, 21.73722076], [88.89666748, 21.73722267], [88.89694214, 21.73694229], [88.89722443, 21.73694229], [88.89749908, 21.73666573], [88.89778137, 21.73666954], [88.89778137, 21.73639107], [88.89805603, 21.73639107], [88.90083313, 21.73361015], [88.90110779, 21.73361015], [88.90139008, 21.73333359], [88.90166473, 21.73333359], [88.90528107, 21.72972298], [88.90555573, 21.72972298], [88.90583038, 21.7294445], [88.90638733, 21.7294445], [88.90666962, 21.72916794], [88.90693665, 21.72916985], [88.90750122, 21.72861099], [88.90859985, 21.72861099], [88.90888977, 21.72833061], [88.90916443, 21.72833252], [88.90944672, 21.72805786], [88.91027832, 21.72805977], [88.91055298, 21.72777939], [88.91110992, 21.72777939], [88.91139221, 21.72750092], [88.91221619, 21.72750092], [88.91388702, 21.72583961], [88.91388702, 21.72556114], [88.91416931, 21.72528076], [88.91416931, 21.72500038], [88.91388702, 21.72472], [88.91388702, 21.72305489], [88.91416931, 21.72277832], [88.91416931, 21.72167015], [88.91443634, 21.72138977], [88.91443634, 21.72110939], [88.91471863, 21.72083282], [88.91471863, 21.72055626], [88.91500092, 21.72027969], [88.91500092, 21.72000122], [88.9152832, 21.71970749], [88.91500092, 21.71944427], [88.91500092, 21.71888924], [88.9152832, 21.71861076], [88.91527557, 21.71805573], [88.91583252, 21.71750069], [88.91583252, 21.71693993], [88.91611481, 21.71666718], [88.91610718, 21.71639061], [88.91638947, 21.71611023], [88.91638947, 21.71582985], [88.91666412, 21.71555519], [88.91665649, 21.71528053], [88.91694641, 21.71500015], [88.91694641, 21.71471977], [88.91722107, 21.71444511], [88.91722107, 21.71389961], [88.91750336, 21.7136097], [88.91750336, 21.71333313], [88.91805267, 21.71277618], [88.91805267, 21.71249962], [88.91944122, 21.71111107], [88.91944122, 21.71084023], [88.92028046, 21.71000099], [88.92056274, 21.71000099], [88.92333221, 21.70722008], [88.9236145, 21.70722008], [88.92416382, 21.70666695], [88.92472076, 21.70667267], [88.92527771, 21.70611191], [88.92555237, 21.70611191], [88.92583466, 21.70583344], [88.9263916, 21.70583344], [88.92694092, 21.7052784], [88.92749786, 21.7052803], [88.92778015, 21.70500183], [88.9283371, 21.70500183], [88.92861176, 21.7047081], [88.92888641, 21.70472145], [88.9291687, 21.70444489], [88.92944336, 21.70444489], [88.92972565, 21.70416641], [88.93000031, 21.70416832], [88.93026733, 21.70388985], [88.93110657, 21.70388985], [88.93138885, 21.70360756], [88.93166351, 21.70361137], [88.9319458, 21.7033329], [88.9327774, 21.7033329], [88.93305206, 21.70305634], [88.93332672, 21.70305824], [88.93360901, 21.70277977], [88.9338913, 21.70277977], [88.93416595, 21.70249939], [88.93444824, 21.70249939], [88.9347229, 21.70222092], [88.93527985, 21.70222282], [88.93583679, 21.70166779], [88.93611145, 21.70166969], [88.9375, 21.70028114], [88.9375, 21.70000076], [88.93860626, 21.69890022], [88.93860626, 21.69861031], [88.93916321, 21.69806099], [88.93916321, 21.69778061], [88.93945313, 21.69750023], [88.9394455, 21.69666672], [88.93972015, 21.69639015], [88.93972015, 21.69610977], [88.94000244, 21.6958313], [88.94000244, 21.69555473], [88.9402771, 21.69527817], [88.94000244, 21.69499969], [88.94000244, 21.69472122], [88.9402771, 21.69444466], [88.9402771, 21.69416618], [88.94055176, 21.69388962], [88.94055176, 21.69333267], [88.94083405, 21.69305611], [88.94082642, 21.6919384], [88.9411087, 21.69166756], [88.9411087, 21.69111061], [88.94167328, 21.69055939], [88.94167328, 21.69000053], [88.94194794, 21.68972206], [88.94139099, 21.68917084], [88.94139099, 21.68778038], [88.94075775, 21.68624115], [88.94062042, 21.6850338], [88.93990326, 21.68382263], [88.93939972, 21.68254471], [88.93898773, 21.68182945], [88.93889618, 21.68167114], [88.93868256, 21.68066025], [88.93854523, 21.6794529], [88.93854523, 21.67864418], [88.9383316, 21.67804909], [88.9383316, 21.67638969], [88.93776703, 21.67583084], [88.93777466, 21.67555618], [88.9375, 21.67527962], [88.9375, 21.67500114], [88.93776703, 21.6747303], [88.9375, 21.67444038], [88.9375, 21.67416763], [88.93723297, 21.67389107], [88.93723297, 21.67305946], [88.93694305, 21.67278099], [88.93694305, 21.67193985], [88.93722534, 21.67166519], [88.93694305, 21.67138863], [88.93694305, 21.67111015], [88.93722534, 21.67111206], [88.93722534, 21.67083549], [88.93694305, 21.67055321], [88.93694305, 21.67028046], [88.93638611, 21.6697197], [88.93638611, 21.66944313], [88.93582916, 21.66889], [88.93582916, 21.66777992], [88.93611145, 21.66777992], [88.93611145, 21.66722107], [88.93583679, 21.66722107], [88.93583679, 21.66666603], [88.93553925, 21.66638947], [88.93553925, 21.66610909], [88.93527985, 21.66583061], [88.93527985, 21.66555595], [88.9347229, 21.66500092], [88.9347229, 21.66389084], [88.93444824, 21.66361046], [88.93444824, 21.66332817], [88.93360901, 21.66250038], [88.93360901, 21.66194916], [88.93305206, 21.6613903], [88.93305206, 21.66082954], [88.9327774, 21.66055679], [88.9327774, 21.66027832], [88.93250275, 21.65999985], [88.93250275, 21.65971947], [88.93222046, 21.65944672], [88.9315033, 21.65834236], [88.93083191, 21.65722466], [88.93083191, 21.65694237], [88.93027496, 21.65638924], [88.93026733, 21.65528107], [88.93000031, 21.65500069], [88.93000031, 21.65472031], [88.92944336, 21.65416718], [88.92944336, 21.65389061], [88.9291687, 21.65361977], [88.9291687, 21.65333176], [88.92805481, 21.65222168], [88.92805481, 21.65138817], [88.92749786, 21.65083122], [88.92749786, 21.65027809], [88.92722321, 21.64999962], [88.92722321, 21.64972115], [88.92610931, 21.64861107], [88.92610931, 21.64750099], [88.92555237, 21.64694023], [88.92555237, 21.64527512], [88.92527771, 21.64500046], [88.92527771, 21.64439964], [88.92527771, 21.64333344], [88.92500305, 21.64305305], [88.92500305, 21.64221954], [88.92472076, 21.64194489], [88.92472076, 21.64138794], [88.92444611, 21.64110947], [88.92444611, 21.63972282], [88.92416382, 21.63944435], [88.92416382, 21.63861084], [88.92388916, 21.63832855], [88.92388916, 21.63694382], [88.9236145, 21.63666725], [88.92359924, 21.63582993], [88.92305756, 21.6352787], [88.92305756, 21.63500023], [88.9227829, 21.63471985], [88.92277527, 21.63416862], [88.92233276, 21.63372993], [88.92194366, 21.63291168], [88.92138672, 21.63277817], [88.92082977, 21.63222122], [88.92055511, 21.63222313], [88.9201355, 21.63207817], [88.91945648, 21.63220024], [88.91887665, 21.63237], [88.91859436, 21.63264275], [88.91776276, 21.63306808], [88.91776276, 21.63362122], [88.91779327, 21.63445091], [88.91779327, 21.63528061], [88.91750336, 21.63555908], [88.91750336, 21.63611031], [88.91722107, 21.63639069], [88.91694641, 21.63639069], [88.91665649, 21.63666916], [88.91638947, 21.63666916], [88.91610718, 21.63639069], [88.91555786, 21.63638878], [88.91500092, 21.63694382], [88.91471863, 21.63694382], [88.91443634, 21.63722038], [88.91443634, 21.63750076], [88.91416931, 21.63777924], [88.91387939, 21.63779259], [88.91332245, 21.63861084], [88.91319275, 21.63862038], [88.91319275, 21.63916588], [88.91333008, 21.63972282], [88.91222382, 21.6408329], [88.91194153, 21.6408329], [88.91166687, 21.64111137], [88.91106415, 21.64115524], [88.91083527, 21.64138794], [88.91055298, 21.64110947], [88.91027832, 21.64111137], [88.90944672, 21.64194107], [88.90859985, 21.6427803], [88.90860748, 21.64305305], [88.90833282, 21.64333344], [88.90833282, 21.64361382], [88.90721893, 21.64472008], [88.90721893, 21.64500046], [88.90611267, 21.64611053], [88.90611267, 21.64639091], [88.90583038, 21.64666748], [88.90583038, 21.64694595], [88.90556335, 21.64722061], [88.90556335, 21.64750099], [88.90528107, 21.64777946], [88.90528107, 21.64805984], [88.90459442, 21.64957047], [88.90374756, 21.64995956], [88.90027618, 21.65278053], [88.89971924, 21.65278053], [88.89943695, 21.65306282], [88.89916992, 21.65278053], [88.89888763, 21.65278053], [88.89861298, 21.65250015], [88.89833069, 21.65250015], [88.89805603, 21.65222168], [88.89611053, 21.65222168], [88.89583588, 21.65250015], [88.89499664, 21.65250015], [88.89472198, 21.65278053], [88.89444733, 21.65278053], [88.89342499, 21.65420723], [88.89277649, 21.65444183], [88.89221191, 21.65512085], [88.89083099, 21.65611076], [88.89026642, 21.65611076], [88.88999939, 21.65639114], [88.88972473, 21.65638924], [88.88916779, 21.65694237], [88.88889313, 21.65694046], [88.88777924, 21.65805435], [88.88777924, 21.65833282], [88.88749695, 21.65860939], [88.88749695, 21.65888977], [88.88722229, 21.65916443], [88.88722229, 21.65944672], [88.88667297, 21.65999985], [88.88666534, 21.66027832], [88.88582611, 21.66110992], [88.88582611, 21.6613903], [88.88555908, 21.66166878], [88.88555908, 21.66221809], [88.88527679, 21.66250038], [88.88527679, 21.66278839], [88.88500214, 21.66305923], [88.88500214, 21.66389084], [88.88471985, 21.6641674], [88.88471985, 21.66444397], [88.88445282, 21.66472054], [88.88471985, 21.66500092], [88.88500214, 21.66500092], [88.88527679, 21.66527748], [88.88527679, 21.66583061], [88.88555908, 21.66610909], [88.88555908, 21.6669445], [88.88582611, 21.66722107], [88.88582611, 21.66777992], [88.88555908, 21.66805649], [88.88555908, 21.66833115], [88.88583374, 21.66861153], [88.88582611, 21.6697197], [88.8861084, 21.67000008], [88.88527679, 21.67083549], [88.88527679, 21.67222023], [88.88471985, 21.67278099], [88.88471985, 21.67389107], [88.88500214, 21.67416954], [88.88500214, 21.6747303], [88.88471985, 21.67500114], [88.88471985, 21.67555618], [88.88444519, 21.67583275], [88.88445282, 21.67638969], [88.8841629, 21.67666817], [88.8841629, 21.67749977], [88.88388824, 21.67777824], [88.88388824, 21.67804909], [88.88305664, 21.67889023], [88.88305664, 21.67917252], [88.8833313, 21.6794529], [88.8833313, 21.68028259], [88.88305664, 21.68055534], [88.88305664, 21.68083191], [88.88277435, 21.68111038], [88.88277435, 21.68194389], [88.88249969, 21.68222046], [88.88249969, 21.68250084], [88.88223267, 21.68278122], [88.88222504, 21.68305588], [88.88194275, 21.68333244], [88.88194275, 21.68361092], [88.88111115, 21.68444633], [88.88083649, 21.68444633], [88.88054657, 21.68472099], [88.8805542, 21.6855545], [88.88027954, 21.68583107], [88.88027954, 21.68638992], [88.8797226, 21.68695831], [88.8797226, 21.6875], [88.87916565, 21.68805695], [88.87916565, 21.68833351], [88.87889099, 21.68861198], [88.87889099, 21.68944359], [88.8786087, 21.68916893], [88.87832642, 21.68917084], [88.87750244, 21.6883297], [88.87610626, 21.68972969], [88.87610626, 21.69055939], [88.87555695, 21.69111061], [88.87555695, 21.69138908], [88.875, 21.69194412], [88.875, 21.69222069], [88.87472534, 21.69249916], [88.87472534, 21.69277763], [88.8730545, 21.69444466], [88.8730545, 21.6958313], [88.87277985, 21.69610977], [88.87277985, 21.69750023], [88.87249756, 21.6977787], [88.87248993, 21.69832993], [88.8722229, 21.69861031], [88.8722229, 21.69916534], [88.87194824, 21.69944], [88.87194824, 21.70249939], [88.87166595, 21.70277977], [88.87166595, 21.7047081], [88.8713913, 21.70500183], [88.8713913, 21.70694351], [88.87166595, 21.70722008], [88.87166595, 21.70776939], [88.8713913, 21.7080555], [88.8713913, 21.70944214], [88.87166595, 21.70972061], [88.87166595, 21.71027946], [88.87194824, 21.71055412], [88.87194824, 21.71194649], [88.87166595, 21.71222115], [88.87166595, 21.71249962], [88.87185669, 21.71268845], [88.87194824, 21.71277618], [88.87194824, 21.71287918], [88.87194824, 21.7136097], [88.8722229, 21.71388626], [88.8722229, 21.71471977], [88.87248993, 21.71500015], [88.8722229, 21.71528053], [88.8722229, 21.71639061], [88.87248993, 21.71639061], [88.87277985, 21.71666718], [88.87277985, 21.71694374], [88.87248993, 21.7172184], [88.87248993, 21.71777916], [88.87277985, 21.71805954], [88.87277985, 21.7191658], [88.87248993, 21.71943855], [88.87249756, 21.72055626], [88.87277985, 21.72083282], [88.87277985, 21.72110939], [88.87304688, 21.72138977], [88.8730545, 21.72166634], [88.87361145, 21.72221947], [88.87361145, 21.72249985], [88.87388611, 21.72277832], [88.87388611, 21.72333336], [88.8741684, 21.72360992], [88.8741684, 21.7238903], [88.87472534, 21.72444344], [88.87473297, 21.72472], [88.87526703, 21.72528076], [88.87526703, 21.72583961], [88.87555695, 21.72611046], [88.87555695, 21.72638893], [88.87638855, 21.72722054], [88.87638855, 21.72805786], [88.87666321, 21.72833061], [88.87666321, 21.72861099], [88.87695313, 21.72887993], [88.8769455, 21.72916794], [88.87722015, 21.72944069], [88.87722015, 21.72999954], [88.87750244, 21.73027992], [88.87750244, 21.73110962], [88.87805176, 21.73167038], [88.87805176, 21.73250008], [88.8777771, 21.73278046], [88.87805176, 21.73305511], [88.87805176, 21.73333359], [88.87833405, 21.73361015], [88.87833405, 21.73444366], [88.87861633, 21.73472023], [88.87861633, 21.7352829], [88.87889099, 21.73555946], [88.87889099, 21.73611069], [88.87944794, 21.73666573], [88.87944794, 21.73694229], [88.8797226, 21.73722076], [88.8797226, 21.73777962], [88.87999725, 21.73805428], [88.87999725, 21.73833084], [88.88027954, 21.73861122], [88.87999725, 21.73888969], [88.87999725, 21.73971939], [88.88027954, 21.73999977], [88.88027954, 21.74194527], [88.88054657, 21.74221992], [88.88054657, 21.74278069], [88.88083649, 21.74305534], [88.88083649, 21.74332809], [88.88111115, 21.74361038], [88.88111115, 21.74389076], [88.8813858, 21.74389076], [88.8813858, 21.74443817], [88.88223267, 21.74527931], [88.88305664, 21.74527931]]], [[[88.97799683, 21.72687531], [88.97860718, 21.72665024], [88.97914124, 21.72639084], [88.97966003, 21.72617912], [88.98020935, 21.72608185], [88.98073578, 21.72594261], [88.98123932, 21.72579956], [88.98171234, 21.72561073], [88.98216248, 21.72551346], [88.98256683, 21.72537613], [88.98298645, 21.72529984], [88.98343658, 21.72527122], [88.98387909, 21.72521973], [88.98427582, 21.72505951], [88.98471069, 21.72500038], [88.9851532, 21.72494125], [88.98552704, 21.72479057], [88.98596191, 21.72473335], [88.98639679, 21.72470284], [88.98683167, 21.72462845], [88.98726654, 21.72449112], [88.98771667, 21.72442245], [88.98816681, 21.72431946], [88.98860168, 21.72418976], [88.9887619, 21.7241497], [88.98904419, 21.72407913], [88.98944092, 21.72390938], [88.98985291, 21.7237606], [88.99026489, 21.72359657], [88.99069977, 21.72340965], [88.99118805, 21.72324181], [88.99169922, 21.72302055], [88.99221802, 21.72278023], [88.99272156, 21.72249985], [88.99318695, 21.72221947], [88.99359131, 21.72191048], [88.99394226, 21.72154999], [88.99423218, 21.72121429], [88.99452972, 21.72089767], [88.99479675, 21.72058105], [88.99505615, 21.72023773], [88.99532318, 21.71985054], [88.99559784, 21.71941948], [88.99591064, 21.71894073], [88.99628448, 21.71847916], [88.99672699, 21.71804047], [88.99721527, 21.71760559], [88.99775696, 21.71721077], [88.99832916, 21.71677589], [88.99888611, 21.71630096], [88.99944305, 21.71587944], [88.99972534, 21.71527863], [88.99973297, 21.71582985], [89.0, 21.71611023], [89.00026703, 21.71582985], [89.00128937, 21.71546555], [89.00189972, 21.71536064], [89.00245667, 21.715271], [89.00298309, 21.71517944], [89.00348663, 21.71517944], [89.00415802, 21.7151432], [89.00460815, 21.71519279], [89.00508881, 21.71517181], [89.00559235, 21.71525574], [89.00585938, 21.71534348], [89.00627899, 21.71550941], [89.00672913, 21.71566963], [89.00717163, 21.71583748], [89.00760651, 21.7159996], [89.00804901, 21.71613121], [89.00852203, 21.71627045], [89.00900269, 21.71638107], [89.00949097, 21.71648979], [89.00995636, 21.71665001], [89.01040649, 21.71680832], [89.010849, 21.71707726], [89.01123047, 21.71731377], [89.01154327, 21.71731186], [89.01185608, 21.71730804], [89.01229095, 21.7171402], [89.01275635, 21.71715546], [89.01328278, 21.7172184], [89.01383972, 21.71731949], [89.0144577, 21.71751976], [89.01509857, 21.71769905], [89.01557159, 21.71751976], [89.01604462, 21.71726608], [89.01651001, 21.71690941], [89.01698303, 21.71647453], [89.0174942, 21.71603012], [89.01802826, 21.71558952], [89.01863098, 21.71522331], [89.01927948, 21.71489716], [89.01988983, 21.71455956], [89.0202713, 21.71408653], [89.02052307, 21.71355057], [89.02051544, 21.71297646], [89.02027893, 21.71243095], [89.02001953, 21.71196175], [89.01972198, 21.7115593], [89.01943207, 21.71122169], [89.01911926, 21.71095848], [89.01873779, 21.7107811], [89.01838684, 21.7105484], [89.01802826, 21.71033287], [89.01753235, 21.7103157], [89.01696777, 21.71041489], [89.0164032, 21.71032333], [89.01586914, 21.71028519], [89.01539612, 21.71030807], [89.01499176, 21.71043968], [89.01461792, 21.71055031], [89.01422882, 21.71055984], [89.01381683, 21.71055984], [89.01338959, 21.71055984], [89.01293945, 21.71055984], [89.01248932, 21.71055031], [89.01204681, 21.71047974], [89.01161194, 21.7103157], [89.0111084, 21.71026039], [89.01095581, 21.71020699], [89.01063538, 21.71009636], [89.0100708, 21.70993996], [89.00950623, 21.70968819], [89.00898743, 21.70935249], [89.00863647, 21.70889473], [89.00833893, 21.70846558], [89.00811768, 21.70808983], [89.00801849, 21.70773125], [89.00786591, 21.70743942], [89.00778961, 21.70713043], [89.00777435, 21.70677567], [89.00775146, 21.70638084], [89.00762939, 21.70594978], [89.00752258, 21.70549965], [89.00751495, 21.7053299], [89.00749969, 21.70503998], [89.00753021, 21.70459938], [89.00762939, 21.70421028], [89.00773621, 21.70392036], [89.00782013, 21.70363045], [89.00799561, 21.70335579], [89.00814056, 21.70297813], [89.00818634, 21.70286942], [89.00834656, 21.70250893], [89.00865936, 21.70202065], [89.0091629, 21.70166969], [89.00971222, 21.7013607], [89.01025391, 21.70111465], [89.01078796, 21.70090485], [89.01134491, 21.70080185], [89.0117569, 21.70067024], [89.01190948, 21.70062256], [89.0125351, 21.70056152], [89.01321411, 21.70059586], [89.01390076, 21.7007885], [89.01460266, 21.70083237], [89.01526642, 21.70079041], [89.01586914, 21.70059776], [89.0164566, 21.70051193], [89.0169754, 21.70031738], [89.01753235, 21.7002182], [89.01802063, 21.7000103], [89.01854706, 21.69980812], [89.01913452, 21.69967842], [89.01965332, 21.69935036], [89.02005005, 21.69872665], [89.02046204, 21.69815063], [89.02076721, 21.69758987], [89.02083588, 21.69701958], [89.02083588, 21.6964798], [89.02084351, 21.69598007], [89.02091217, 21.69549942], [89.02108765, 21.69503021], [89.02120209, 21.69450951], [89.02140045, 21.69400024], [89.02165222, 21.69352913], [89.02184296, 21.6930294], [89.02197266, 21.69255257], [89.02220917, 21.69216728], [89.02239227, 21.69177055], [89.02259827, 21.69137383], [89.02281952, 21.69093132], [89.02311707, 21.69048119], [89.02339935, 21.68997955], [89.02363586, 21.68942451], [89.02389526, 21.6888752], [89.02411652, 21.6883297], [89.02416229, 21.6877327], [89.02412415, 21.68714523], [89.02391052, 21.68665123], [89.02368164, 21.68618011], [89.02349854, 21.68571091], [89.02333069, 21.68556023], [89.02333069, 21.68499947], [89.0230484, 21.68472099], [89.02305603, 21.68444633], [89.02278137, 21.68416405], [89.02278137, 21.68388939], [89.02249908, 21.68359947], [89.02249908, 21.68305588], [89.0222168, 21.68278122], [89.0222168, 21.68250084], [89.02194214, 21.68222046], [89.02194214, 21.68194389], [89.02166748, 21.68166733], [89.02166748, 21.68083191], [89.02138519, 21.68055534], [89.02139282, 21.67972183], [89.02131653, 21.67964554], [89.02111053, 21.67944527], [89.02111053, 21.67745018], [89.02111053, 21.67472267], [89.02083588, 21.67444038], [89.02083588, 21.67361069], [89.02111053, 21.67333031], [89.02111053, 21.67111206], [89.02083588, 21.67083549], [89.02083588, 21.67055321], [89.02082825, 21.66995811], [89.02076721, 21.66930962], [89.02056122, 21.66878128], [89.02036285, 21.66826057], [89.02020264, 21.66772079], [89.01994324, 21.66722107], [89.01963806, 21.66674042], [89.01924896, 21.66633224], [89.01889801, 21.66585922], [89.01860809, 21.66533089], [89.01829529, 21.66512871], [89.01798248, 21.66447067], [89.01796722, 21.66395569], [89.018013, 21.66347122], [89.01789093, 21.66305923], [89.01795197, 21.66237068], [89.01795959, 21.66172409], [89.01783752, 21.66118622], [89.01740265, 21.66085052], [89.01689911, 21.66064644], [89.01667023, 21.66055107], [89.01527405, 21.65944672], [89.01499176, 21.65923309], [89.01413727, 21.65882111], [89.01384735, 21.65854073], [89.01385498, 21.65810585], [89.01402283, 21.65740967], [89.01389313, 21.65707016], [89.01361084, 21.65686035], [89.0131073, 21.65666008], [89.01299286, 21.65645027], [89.01277924, 21.65611076], [89.01249695, 21.65583038], [89.01222229, 21.65583229], [89.01194763, 21.65555573], [89.01167297, 21.65555954], [89.0109787, 21.65482712], [89.01035309, 21.65416718], [89.01013184, 21.65396118], [89.00930023, 21.65325928], [89.00888824, 21.65306282], [89.0083313, 21.65262985], [89.00805664, 21.65250015], [89.00775909, 21.65222168], [89.00734711, 21.65222168], [89.00694275, 21.65222168], [89.00637817, 21.65208054], [89.00395966, 21.65201187], [89.00318146, 21.65242386], [89.00235748, 21.6523571], [89.00197601, 21.65223122], [89.0014267, 21.65223122], [89.00077057, 21.65216255], [89.0, 21.65222168], [88.99954987, 21.65219116], [88.99899292, 21.65209961], [88.99871063, 21.65195274], [88.99833679, 21.65192032], [88.99801636, 21.65176964], [88.99765015, 21.65167809], [88.99724579, 21.65166092], [88.9968338, 21.65166473], [88.99641418, 21.65166473], [88.99598694, 21.65163422], [88.99556732, 21.65151978], [88.99514008, 21.65141106], [88.99471283, 21.65138817], [88.99427032, 21.65138817], [88.99384308, 21.65138817], [88.99341583, 21.65138817], [88.99299622, 21.65142059], [88.99263, 21.65160942], [88.99223328, 21.65167618], [88.99183655, 21.65178108], [88.99147797, 21.65198708], [88.99114227, 21.65229607], [88.9908371, 21.65265274], [88.99060059, 21.65302086], [88.99040222, 21.65335846], [88.99025726, 21.65373421], [88.99007416, 21.6541214], [88.98996735, 21.65462112], [88.98980713, 21.65513992], [88.9897995, 21.65565872], [88.98995209, 21.65625954], [88.99001312, 21.6568203], [88.98999786, 21.65733719], [88.9899826, 21.65784073], [88.98992157, 21.65833092], [88.98983765, 21.65877914], [88.98973846, 21.65924072], [88.98972321, 21.65969276], [88.98971558, 21.66013527], [88.98964691, 21.66059113], [88.98947906, 21.66105843], [88.98944092, 21.66161919], [88.98944092, 21.66223145], [88.98944855, 21.66286469], [88.98950195, 21.66348267], [88.98964691, 21.66403961], [88.98978424, 21.66460037], [88.99001312, 21.66505814], [88.99024963, 21.66546059], [88.99045563, 21.66586685], [88.99060822, 21.66627121], [88.99085999, 21.66664124], [88.99118805, 21.66699982], [88.99164581, 21.66732025], [88.99212646, 21.66770554], [88.99256134, 21.66812134], [88.99305725, 21.66859055], [88.99365234, 21.66905022], [88.99417877, 21.66950798], [88.99436951, 21.66978264], [88.99472046, 21.67027855], [88.99472046, 21.67083549], [88.99500275, 21.67111015], [88.99500275, 21.67138863], [88.99555206, 21.67194366], [88.99555206, 21.67222023], [88.99581909, 21.67250061], [88.99581909, 21.67278099], [88.99577332, 21.67325974], [88.99560547, 21.67375565], [88.99552917, 21.67423058], [88.99545288, 21.67468262], [88.99550629, 21.67517281], [88.99551392, 21.67564583], [88.9954071, 21.67609978], [88.99525452, 21.67655182], [88.99507141, 21.67698097], [88.99492645, 21.67741966], [88.99474335, 21.67782021], [88.99463654, 21.6782608], [88.99443817, 21.67867088], [88.9942627, 21.67904282], [88.99421692, 21.67914009], [88.9940567, 21.67970848], [88.99386597, 21.68028259], [88.9936142, 21.68166733], [88.99333191, 21.68194389], [88.99333191, 21.68222237], [88.99307251, 21.68250084], [88.99305725, 21.6827774], [88.99360657, 21.68333054], [88.9936142, 21.68416405], [88.99388885, 21.68444061], [88.99388885, 21.68499947], [88.99415588, 21.68527985], [88.99415588, 21.6875], [88.99388885, 21.68777847], [88.99388885, 21.68833351], [88.99360657, 21.68861008], [88.9936142, 21.68916893], [88.99333191, 21.68943977], [88.99333191, 21.68972206], [88.99307251, 21.69000053], [88.99307251, 21.69028091], [88.99277496, 21.69055557], [88.99277496, 21.69083405], [88.99266052, 21.69095039], [88.99250031, 21.69111061], [88.99250031, 21.69166756], [88.99223328, 21.6919384], [88.99222565, 21.69249916], [88.99194336, 21.69277763], [88.99194336, 21.69439125], [88.99194336, 21.69472122], [88.99185181, 21.69481659], [88.9916687, 21.69499969], [88.9916687, 21.69555473], [88.99194336, 21.6958313], [88.99194336, 21.69610977], [88.99223328, 21.69639015], [88.99223328, 21.69778061], [88.99250031, 21.69806099], [88.99250031, 21.69890022], [88.9927597, 21.69917107], [88.9927597, 21.70000076], [88.99250031, 21.70028114], [88.99250031, 21.70139122], [88.99222565, 21.70166779], [88.99222565, 21.70194435], [88.99194336, 21.70222092], [88.99194336, 21.70249939], [88.9916687, 21.70277977], [88.9916687, 21.70305634], [88.99138641, 21.7033329], [88.99138641, 21.70360756], [88.9908371, 21.70416641], [88.9908371, 21.70443916], [88.99001312, 21.7052803], [88.99001312, 21.70556259], [88.98916626, 21.70639038], [88.9888916, 21.70639038], [88.98472595, 21.71055984], [88.98443604, 21.71055984], [88.98332977, 21.71166992], [88.98305511, 21.7116642], [88.98249817, 21.71222305], [88.98221588, 21.71222115], [88.98166656, 21.71278], [88.98139191, 21.71277618], [88.98110962, 21.71305656], [88.98083496, 21.71305656], [88.98055267, 21.71333313], [88.98027802, 21.71333313], [88.98000336, 21.7136116], [88.97972107, 21.7136097], [88.97944641, 21.71389961], [88.97915649, 21.71389961], [88.97860718, 21.71445084], [88.97833252, 21.71444511], [88.9777832, 21.71500015], [88.97750092, 21.71500015], [88.97693634, 21.71556091], [88.97666931, 21.71556091], [88.97611237, 21.71611023], [88.97583008, 21.71611023], [88.97528076, 21.71666908], [88.97499847, 21.71666718], [88.97467041, 21.71699524], [88.97333527, 21.7183342], [88.97305298, 21.71832848], [88.97249603, 21.71888924], [88.97222137, 21.71888924], [88.97110748, 21.72000122], [88.97110748, 21.72027779], [88.97055817, 21.72083282], [88.97055817, 21.72110939], [88.97110748, 21.72166634], [88.97110748, 21.7219429], [88.97164917, 21.72249985], [88.97193909, 21.72249985], [88.97194672, 21.72277832], [88.97389221, 21.72472], [88.97389221, 21.72500038], [88.97416687, 21.72528076], [88.97416687, 21.72556114], [88.97528076, 21.72667122], [88.97555542, 21.7266674], [88.97583008, 21.72694588], [88.97611237, 21.72694588], [88.97638702, 21.72722244], [88.97666931, 21.72722244], [88.97729492, 21.72712135], [88.97775269, 21.72696114], [88.97799683, 21.72687531]]], [[[87.91194153, 22.43222046], [87.91194153, 22.43194389], [87.91278076, 22.43111038], [87.91306305, 22.43139076], [87.91305542, 22.43166733], [87.91361237, 22.43222237], [87.91388702, 22.43222237], [87.91444397, 22.43166733], [87.9152832, 22.43167114], [87.91555023, 22.43139076], [87.91610718, 22.43139076], [87.91638947, 22.43111038], [87.91665649, 22.43111038], [87.91694641, 22.43083191], [87.91750336, 22.43083382], [87.91777802, 22.43055534], [87.91805267, 22.43056107], [87.9183197, 22.43029022], [87.9183197, 22.43000031], [87.91777802, 22.4294529], [87.91694641, 22.42944527], [87.91666412, 22.42972374], [87.91638947, 22.42944527], [87.91583252, 22.4294529], [87.9152832, 22.42889023], [87.91443634, 22.42889023], [87.91416931, 22.42861176], [87.91388702, 22.42889023], [87.91278076, 22.42889023], [87.9125061, 22.42917061], [87.91166687, 22.42917061], [87.91139221, 22.4294529], [87.91083527, 22.42944527], [87.91055298, 22.42972374], [87.90999603, 22.42972183], [87.90972137, 22.43000031], [87.90888977, 22.43000031], [87.90805817, 22.43083191], [87.90805817, 22.43167114], [87.90888977, 22.43250084], [87.9091568, 22.43222046], [87.90944672, 22.43222046], [87.90972137, 22.43250084], [87.90999603, 22.43250084], [87.91055298, 22.43305969], [87.91110992, 22.43305969], [87.91194153, 22.43222046]]], [[[88.85916901, 22.46944427], [88.85916901, 22.46666908], [88.85888672, 22.46639061], [88.85888672, 22.4636097], [88.85861206, 22.46333313], [88.85861206, 22.46222687], [88.85805511, 22.46166611], [88.85806274, 22.46138954], [88.85778046, 22.46111107], [88.85778046, 22.4608326], [88.85749817, 22.46055794], [88.85749054, 22.46000099], [88.85721588, 22.45972252], [88.85722351, 22.45944595], [88.85666656, 22.45889091], [88.85610962, 22.45889091], [88.85610962, 22.45916939], [88.85555267, 22.45972252], [88.85555267, 22.45999908], [88.85527802, 22.46027184], [88.85527802, 22.46055794], [88.85555267, 22.4608326], [88.85555267, 22.46111107], [88.85610962, 22.46138954], [88.85639191, 22.46138954], [88.85721588, 22.46222115], [88.85721588, 22.46389198], [88.85749054, 22.46417046], [88.85749817, 22.46555519], [88.85722351, 22.46583366], [88.85721588, 22.46693993], [88.85778046, 22.46750069], [88.85778046, 22.46805573], [88.85806274, 22.46833038], [88.85749054, 22.46889114], [88.85639191, 22.46889114], [88.85610962, 22.46916771], [88.85639191, 22.46944427], [88.85639191, 22.46972275], [88.85610962, 22.47000122], [88.85610962, 22.47055626], [88.85639191, 22.47083282], [88.85639191, 22.47139168], [88.85666656, 22.47166634], [88.85666656, 22.47221375], [88.85694122, 22.47250175], [88.85721588, 22.47250175], [88.85832977, 22.47139168], [88.85832977, 22.47083282], [88.85861206, 22.47055626], [88.85861206, 22.4702816], [88.85888672, 22.47000122], [88.85888672, 22.46972275], [88.85916901, 22.46944427]]], [[[87.93805695, 22.39666939], [87.93776703, 22.39666939], [87.9375, 22.39694977], [87.9375, 22.39749908], [87.93722534, 22.39777946], [87.93723297, 22.39833069], [87.93694305, 22.39860916], [87.93694305, 22.39888763], [87.9366684, 22.39916611], [87.9366684, 22.39944458], [87.93638611, 22.39972305], [87.93638611, 22.39998817], [87.93611145, 22.40027809], [87.93611145, 22.40083313], [87.93583679, 22.4011116], [87.93583679, 22.40250015], [87.93554688, 22.40278053], [87.93554688, 22.40361023], [87.93527985, 22.40389061], [87.93527985, 22.40500069], [87.93499756, 22.40527725], [87.93499756, 22.40583038], [87.9347229, 22.4061203], [87.9347229, 22.40639114], [87.93444824, 22.4066658], [87.93444824, 22.40694046], [87.9338913, 22.40750122], [87.9338913, 22.40777969], [87.9327774, 22.40888977], [87.9327774, 22.40916634], [87.93333435, 22.40972137], [87.93499756, 22.40805435], [87.93499756, 22.40777969], [87.93583679, 22.40694046], [87.93583679, 22.4066658], [87.93611145, 22.40639114], [87.93611145, 22.40583038], [87.93638611, 22.40555573], [87.93638611, 22.40500069], [87.93667603, 22.40472031], [87.9366684, 22.40444374], [87.93694305, 22.40416718], [87.93694305, 22.40389061], [87.93723297, 22.40361023], [87.93722534, 22.40305519], [87.9375, 22.40277863], [87.9375, 22.40195274], [87.93776703, 22.40167046], [87.93776703, 22.40055084], [87.93805695, 22.40027809], [87.93805695, 22.39971924], [87.9383316, 22.39944458], [87.9383316, 22.39805794], [87.93860626, 22.39777946], [87.93860626, 22.39722061], [87.93805695, 22.39666939]]], [[[88.86777496, 22.41083336], [88.86805725, 22.41055489], [88.86888885, 22.41055489], [88.8694458, 22.41000175], [88.86972046, 22.41000175], [88.8713913, 22.40833092], [88.87166595, 22.40833473], [88.87277985, 22.40722656], [88.8730545, 22.40722656], [88.87361145, 22.40666771], [88.87388611, 22.40667152], [88.8741684, 22.40639305], [88.8741684, 22.40612221], [88.87444305, 22.40583229], [88.87444305, 22.40555573], [88.8741684, 22.40528488], [88.87304688, 22.40528488], [88.87277985, 22.40500069], [88.87248993, 22.40528488], [88.87194824, 22.40527725], [88.8713913, 22.40583229], [88.8713913, 22.40639305], [88.87110901, 22.40666771], [88.87110901, 22.40694427], [88.87082672, 22.40722084], [88.87083435, 22.40749931], [88.87000275, 22.40833473], [88.86888885, 22.40833092], [88.86805725, 22.40918159], [88.86777496, 22.40916634], [88.86750031, 22.40944481], [88.86722565, 22.40944481], [88.86667633, 22.41000175], [88.86638641, 22.41000175], [88.86611176, 22.41028023], [88.86611176, 22.41083336], [88.86777496, 22.41083336]]], [[[88.91889954, 22.42653275], [88.91889191, 22.42527962], [88.91860962, 22.42500114], [88.91860962, 22.42472267], [88.91777802, 22.42389107], [88.91750336, 22.42389107], [88.91722107, 22.42361259], [88.91638947, 22.42361259], [88.91622925, 22.42334938], [88.91584778, 22.42333031], [88.91542053, 22.42329025], [88.91501617, 22.42311287], [88.91448975, 22.42305946], [88.91394043, 22.42302132], [88.91343689, 22.42284203], [88.91320801, 22.42278099], [88.91295624, 22.42280006], [88.91262054, 22.42292213], [88.91230011, 22.42305183], [88.91195679, 22.42318535], [88.91163635, 22.4233799], [88.91143036, 22.42369652], [88.91139221, 22.42416954], [88.91145325, 22.42472267], [88.91168213, 22.42521095], [88.91200256, 22.42558289], [88.91240692, 22.42580223], [88.9128418, 22.42591286], [88.91313171, 22.42616081], [88.91330719, 22.42648125], [88.91353607, 22.42667961], [88.91420746, 22.42646027], [88.91490173, 22.42630196], [88.91557312, 22.42646027], [88.91599274, 22.42672157], [88.91607666, 22.42710495], [88.91607666, 22.42753029], [88.91649628, 22.42802811], [88.91678619, 22.4287014], [88.91719055, 22.42902946], [88.91732025, 22.42892456], [88.91738129, 22.42886925], [88.91765594, 22.42862892], [88.9180069, 22.42834282], [88.91835022, 22.4278965], [88.91867065, 22.42741966], [88.91889954, 22.42653275]]], [[[87.92568207, 22.42482948], [87.92539215, 22.42469406], [87.92395782, 22.42561913], [87.92266083, 22.42657089], [87.92194366, 22.42764282], [87.92064667, 22.42831421], [87.91978455, 22.42871666], [87.91921234, 22.42910957], [87.9193573, 22.42951965], [87.91979218, 22.4297905], [87.92076874, 22.42923927], [87.9212265, 22.42897987], [87.92223358, 22.42831421], [87.92337799, 22.42791176], [87.92395782, 22.42737579], [87.92481995, 22.42683983], [87.92539215, 22.42617035], [87.92568207, 22.42482948]]], [[[88.89389038, 22.37055969], [88.89360809, 22.37083244], [88.89305878, 22.37083244], [88.89277649, 22.37111092], [88.89250183, 22.37111092], [88.89221954, 22.37138748], [88.89138794, 22.37138748], [88.89111328, 22.37167168], [88.88964844, 22.37166595], [88.88964844, 22.37260246], [88.88993835, 22.37301064], [88.89022064, 22.37314034], [88.89022064, 22.37354088], [88.89051056, 22.37448311], [88.89051056, 22.37488556], [88.89065552, 22.37542152], [88.8897934, 22.37622261], [88.88949585, 22.37622261], [88.88893127, 22.37635994], [88.88792419, 22.37635612], [88.88735199, 22.37649345], [88.88576508, 22.37649345], [88.88562775, 22.37595558], [88.88548279, 22.37554932], [88.88548279, 22.37528229], [88.88576508, 22.37448311], [88.88591003, 22.37421227], [88.88634491, 22.37367821], [88.8866272, 22.37341118], [88.8867569, 22.37260246], [88.88639069, 22.37249756], [88.8861084, 22.37277985], [88.88569641, 22.37332916], [88.88540649, 22.37376976], [88.88516998, 22.37419319], [88.88496399, 22.37459755], [88.884758, 22.37500191], [88.88459015, 22.37550163], [88.88439178, 22.37608147], [88.88414001, 22.37655067], [88.88388062, 22.37695122], [88.88361359, 22.37731552], [88.88336182, 22.3776722], [88.88316345, 22.37808418], [88.88298035, 22.3785305], [88.88272095, 22.37894058], [88.88246918, 22.37933922], [88.88217163, 22.37968254], [88.88184357, 22.37999916], [88.88153076, 22.38033485], [88.88131714, 22.38076973], [88.88104248, 22.38120079], [88.88074493, 22.38164711], [88.88034058, 22.38203621], [88.87999725, 22.3824501], [88.87968445, 22.38282585], [88.87943268, 22.3831501], [88.87919617, 22.38339043], [88.8789978, 22.38363075], [88.87879944, 22.38386917], [88.87856293, 22.38408089], [88.87825775, 22.38428307], [88.87804413, 22.38451958], [88.87785339, 22.38475609], [88.87768555, 22.38498688], [88.87751007, 22.38520241], [88.87731171, 22.38547707], [88.87709045, 22.38589287], [88.87684631, 22.38639259], [88.87660217, 22.38691711], [88.87666321, 22.38750267], [88.8767395, 22.38816261], [88.87696075, 22.38876152], [88.87719727, 22.38924217], [88.87737274, 22.38970947], [88.87753296, 22.39018059], [88.8777771, 22.39065552], [88.8780365, 22.39119148], [88.87821198, 22.39180374], [88.87847137, 22.39234543], [88.87879944, 22.39282036], [88.87909698, 22.39331055], [88.87930298, 22.39367294], [88.87944031, 22.39392281], [88.87957764, 22.39418221], [88.8797226, 22.3944416], [88.87985992, 22.39472771], [88.87999725, 22.39504051], [88.88011932, 22.39536858], [88.88026428, 22.39565468], [88.88034821, 22.39598846], [88.88044739, 22.39653206], [88.88058472, 22.39707756], [88.88065338, 22.39764214], [88.88084412, 22.3981514], [88.88108063, 22.39863205], [88.8812561, 22.39917183], [88.88141632, 22.39972496], [88.88165283, 22.40023232], [88.88183594, 22.40073967], [88.88197327, 22.40125275], [88.88217926, 22.40171814], [88.88222504, 22.40222359], [88.88224792, 22.40272331], [88.8822937, 22.40319061], [88.88218689, 22.40363693], [88.88189697, 22.40400124], [88.88150787, 22.40432167], [88.8811264, 22.40463066], [88.88079071, 22.40499115], [88.88044739, 22.40533257], [88.87993622, 22.40563011], [88.87943268, 22.40594673], [88.87888336, 22.40624046], [88.87828064, 22.4065609], [88.87761688, 22.4068203], [88.87692261, 22.40710258], [88.87621307, 22.40731812], [88.87558746, 22.40754128], [88.87504578, 22.40779305], [88.87452698, 22.40806007], [88.87403107, 22.40834808], [88.87356567, 22.40865707], [88.87312317, 22.40897942], [88.87272644, 22.40937233], [88.87232971, 22.40973091], [88.87194061, 22.41007042], [88.87155151, 22.41037941], [88.87113953, 22.41061974], [88.87075806, 22.41085243], [88.87039948, 22.41106987], [88.87003326, 22.41123009], [88.86965179, 22.4113903], [88.8692627, 22.41155052], [88.86880493, 22.41169548], [88.86833191, 22.41189194], [88.86782837, 22.41193199], [88.86730957, 22.41194916], [88.8667984, 22.41194916], [88.86628723, 22.41194916], [88.86582947, 22.41193199], [88.86541748, 22.41194916], [88.86505127, 22.41196632], [88.86470032, 22.41205406], [88.86430359, 22.41202736], [88.86386871, 22.4120121], [88.86341095, 22.41220284], [88.86292267, 22.41238213], [88.86237335, 22.41254997], [88.8618927, 22.41283989], [88.86148071, 22.41321182], [88.86116028, 22.41356277], [88.86086273, 22.41391373], [88.860672, 22.41431999], [88.86045074, 22.41469002], [88.86018372, 22.41501236], [88.85991669, 22.41535378], [88.85964203, 22.41568184], [88.85942841, 22.41612053], [88.85920715, 22.41657066], [88.85890961, 22.41698837], [88.8586731, 22.41743469], [88.85848236, 22.41790009], [88.85816956, 22.41827011], [88.85793304, 22.41873169], [88.85767365, 22.41918945], [88.85748291, 22.41965485], [88.85726929, 22.42006111], [88.85719299, 22.42049217], [88.85700989, 22.42081451], [88.85695648, 22.42119789], [88.85668182, 22.4216404], [88.85639191, 22.42218971], [88.85612488, 22.42278099], [88.85597992, 22.42339134], [88.8560791, 22.42400169], [88.85610962, 22.42457008], [88.85608673, 22.42511177], [88.85595703, 22.42564011], [88.85581207, 22.42621803], [88.85559845, 22.42679024], [88.85558319, 22.42745018], [88.85565948, 22.42810249], [88.85558319, 22.42852211], [88.8555603, 22.42891121], [88.85555267, 22.42928505], [88.85555267, 22.42966461], [88.8555603, 22.43005943], [88.85555267, 22.43049049], [88.85552979, 22.43098259], [88.8553772, 22.43153381], [88.85530853, 22.43219185], [88.85527039, 22.43281937], [88.85517883, 22.43340111], [88.85492706, 22.43401146], [88.85482788, 22.43473244], [88.8547821, 22.4354229], [88.85473633, 22.43597984], [88.85472107, 22.43646049], [88.85472107, 22.43692207], [88.8547287, 22.43740654], [88.8547821, 22.43792152], [88.85500336, 22.43840981], [88.85529327, 22.43885422], [88.85566711, 22.4391613], [88.85607147, 22.43943977], [88.85649109, 22.43970299], [88.85690308, 22.43997002], [88.85728455, 22.44025612], [88.85768127, 22.44053078], [88.85810852, 22.44074821], [88.8585434, 22.44091988], [88.85890961, 22.44115257], [88.85919952, 22.44143867], [88.85944366, 22.44179344], [88.85970306, 22.44219017], [88.85999298, 22.44262123], [88.86027527, 22.44308281], [88.86051178, 22.44356155], [88.86064911, 22.44407082], [88.8608017, 22.44454575], [88.86090088, 22.44502068], [88.86104584, 22.44548225], [88.86103821, 22.44593811], [88.86089325, 22.44637108], [88.86083984, 22.4467907], [88.86080933, 22.44717216], [88.86071014, 22.44748116], [88.86057281, 22.44777107], [88.86044312, 22.44807053], [88.86030579, 22.4484005], [88.8602066, 22.4487896], [88.86003876, 22.4491539], [88.85988617, 22.44955444], [88.85971069, 22.44995689], [88.85948944, 22.45038033], [88.85927582, 22.45081139], [88.85904694, 22.45119286], [88.8588028, 22.45150948], [88.85856628, 22.45184135], [88.85830688, 22.45218086], [88.85797119, 22.45255089], [88.8575592, 22.45293999], [88.85719299, 22.45345116], [88.85697937, 22.45412827], [88.8568573, 22.45482063], [88.85675812, 22.45548248], [88.85683441, 22.45608711], [88.856987, 22.45667076], [88.85720062, 22.45718956], [88.85739899, 22.45763969], [88.85761261, 22.45799065], [88.85783386, 22.4582653], [88.85805511, 22.45854568], [88.85830688, 22.45888138], [88.8585968, 22.45927238], [88.8588562, 22.45971107], [88.85906219, 22.46014214], [88.85916901, 22.46129036], [88.85974121, 22.46323586], [88.86013031, 22.46608162], [88.86022949, 22.46661186], [88.8602829, 22.46710014], [88.86029053, 22.4675827], [88.86034393, 22.46805191], [88.86044312, 22.46851158], [88.86031342, 22.46895027], [88.86019897, 22.46936226], [88.86003876, 22.46973228], [88.85995483, 22.47014236], [88.85978699, 22.47051048], [88.85968018, 22.47091675], [88.85949707, 22.4712925], [88.85941315, 22.47168159], [88.85926056, 22.47197723], [88.85912323, 22.47224808], [88.85894012, 22.4724884], [88.85884094, 22.47278023], [88.8586731, 22.47303009], [88.85856628, 22.47337151], [88.85842133, 22.47370911], [88.85834503, 22.47410965], [88.85832977, 22.4745636], [88.8583374, 22.47504997], [88.85837555, 22.4755497], [88.85848999, 22.47603226], [88.85838318, 22.47652245], [88.85823822, 22.47701073], [88.85814667, 22.47751045], [88.85823822, 22.47800255], [88.85830688, 22.47844124], [88.8583374, 22.47884941], [88.8583374, 22.47927475], [88.8583374, 22.4797802], [88.85832977, 22.48040199], [88.8583374, 22.48111153], [88.85839081, 22.48184013], [88.85858154, 22.48252869], [88.8588028, 22.48312187], [88.85923767, 22.48344231], [88.85971069, 22.48354912], [88.86009979, 22.48357964], [88.86038971, 22.48361015], [88.86064148, 22.48381042], [88.86092377, 22.48396873], [88.86125183, 22.4840641], [88.86161804, 22.48404121], [88.86196899, 22.48397255], [88.86226654, 22.48393059], [88.86252594, 22.48404121], [88.86274719, 22.48426819], [88.86299133, 22.48440742], [88.86328888, 22.48452568], [88.86364746, 22.48466682], [88.86408234, 22.48472214], [88.86455536, 22.48479462], [88.86499786, 22.48500252], [88.86543274, 22.48526955], [88.8658905, 22.48552513], [88.86638641, 22.48568344], [88.86683655, 22.48586082], [88.86721802, 22.48613167], [88.86753082, 22.4864521], [88.86773682, 22.48687172], [88.86776733, 22.48737144], [88.86773682, 22.48786736], [88.86752319, 22.48829079], [88.86717987, 22.48862267], [88.86670685, 22.48885155], [88.8662262, 22.48901176], [88.86588287, 22.48918915], [88.8655014, 22.48943138], [88.86507416, 22.48967743], [88.86460114, 22.48999977], [88.864151, 22.4903717], [88.86380768, 22.49081993], [88.86351776, 22.49124718], [88.86332703, 22.49140167], [88.86300659, 22.49175262], [88.86280823, 22.4920311], [88.86250305, 22.49240494], [88.86213684, 22.49294281], [88.86210632, 22.49329376], [88.86186981, 22.49378014], [88.86171722, 22.49440193], [88.86159515, 22.49505424], [88.86161804, 22.49567795], [88.8615799, 22.49626541], [88.86146545, 22.49682426], [88.86144257, 22.49736977], [88.86143494, 22.49785805], [88.86142731, 22.49827003], [88.86139679, 22.49863815], [88.86132813, 22.49903107], [88.86110687, 22.49941063], [88.86073303, 22.49981117], [88.86023712, 22.50025749], [88.85965729, 22.50064468], [88.85912323, 22.50103951], [88.85858917, 22.50138283], [88.85804749, 22.50160027], [88.85746002, 22.50173759], [88.85688782, 22.50187111], [88.85629272, 22.50193977], [88.85569763, 22.50201225], [88.8551178, 22.50213051], [88.85453796, 22.5022049], [88.85266113, 22.50217247], [88.85223389, 22.50217247], [88.85144043, 22.50210762], [88.85108185, 22.50196838], [88.85072327, 22.50190544], [88.85029602, 22.50177193], [88.84964752, 22.50156975], [88.84921265, 22.50150108], [88.84871674, 22.50143623], [88.84763336, 22.50143623], [88.84720612, 22.50150108], [88.84570312, 22.50169945], [88.84526062, 22.50191116], [88.84513092, 22.50204277], [88.84497833, 22.5023098], [88.84461975, 22.50284004], [88.84446716, 22.50317955], [88.84403992, 22.50411797], [88.84390259, 22.50465202], [88.84390259, 22.50512123], [88.84382629, 22.50552177], [88.84368134, 22.50633049], [88.84361267, 22.5067997], [88.84361267, 22.50739861], [88.84403992, 22.50766945], [88.84429169, 22.50794029], [88.84467316, 22.50816154], [88.84481049, 22.50830269], [88.84516907, 22.50850105], [88.84545898, 22.50863075], [88.84624481, 22.50876808], [88.84804535, 22.50876808], [88.8483963, 22.50883484], [88.84928894, 22.50901222], [88.84972382, 22.50900841], [88.85001373, 22.50914192], [88.85037231, 22.50914192], [88.85108948, 22.50907707], [88.85217285, 22.50893974], [88.85256958, 22.50897026], [88.85364532, 22.50896645], [88.85436249, 22.5090313], [88.85486603, 22.50910187], [88.85521698, 22.50923157], [88.85559082, 22.50937271], [88.85630798, 22.50977135], [88.85666656, 22.50997353], [88.85709381, 22.51077461], [88.85795593, 22.51197815], [88.8585968, 22.51387215], [88.85869598, 22.51445961], [88.85881805, 22.51498413], [88.85890198, 22.51546478], [88.8589859, 22.51589012], [88.85912323, 22.51625824], [88.85922241, 22.51662254], [88.85943604, 22.51694298], [88.85943604, 22.51751137], [88.85972595, 22.51777649], [88.85972595, 22.51833344], [88.86000061, 22.51860809], [88.86000061, 22.51889229], [88.8602829, 22.51889229], [88.86054993, 22.51917076], [88.86138916, 22.51916885], [88.86166382, 22.51944542], [88.86187744, 22.51942253], [88.86235809, 22.51955223], [88.8628006, 22.5197506], [88.86325073, 22.51999092], [88.86373901, 22.52020073], [88.8642807, 22.52034187], [88.86478424, 22.52056122], [88.86527252, 22.52079582], [88.86580658, 22.52095222], [88.86633301, 22.52115059], [88.86681366, 22.52139282], [88.86724091, 22.52166939], [88.86759186, 22.52197075], [88.86785126, 22.52229118], [88.86806488, 22.52260017], [88.8682785, 22.52293968], [88.86840057, 22.52339172], [88.86855316, 22.5239315], [88.86859894, 22.52458191], [88.86855316, 22.52524185], [88.86839294, 22.52581978], [88.86766052, 22.52815056], [88.86715698, 22.53049278], [88.86730194, 22.5322361], [88.86730194, 22.53451157], [88.86781311, 22.53738976], [88.86830902, 22.5392704], [88.86895752, 22.54047394], [88.86923981, 22.54068375], [88.86966705, 22.5408802], [88.87024689, 22.54115105], [88.87068176, 22.54128075], [88.87125397, 22.5413456], [88.87182617, 22.54141426], [88.87166595, 22.5411129], [88.8713913, 22.54083061], [88.87110901, 22.54083443], [88.87083435, 22.54055405], [88.87055206, 22.54055977], [88.8702774, 22.5402813], [88.87000275, 22.5402813], [88.86972046, 22.54000282], [88.86972046, 22.53972054], [88.8694458, 22.53944588], [88.8694458, 22.53805733], [88.8702774, 22.53722382], [88.8702774, 22.53666878], [88.8694458, 22.53582954], [88.8694458, 22.53555489], [88.86805725, 22.53416634], [88.86805725, 22.53306007], [88.86833191, 22.5327816], [88.86833191, 22.53251076], [88.86888885, 22.53194237], [88.86888885, 22.5316658], [88.86915588, 22.53139305], [88.86915588, 22.53083229], [88.8694458, 22.53055573], [88.87000275, 22.53056145], [88.87082672, 22.53139305], [88.8713913, 22.53139305], [88.87166595, 22.53111076], [88.87194824, 22.53111076], [88.8722229, 22.53138733], [88.8722229, 22.53194618], [88.87277985, 22.53194427], [88.87288666, 22.5320549], [88.8730545, 22.53222466], [88.87333679, 22.53222084], [88.87333679, 22.5327816], [88.87361145, 22.53305626], [88.87361145, 22.53360939], [88.87388611, 22.53389168], [88.87388611, 22.53471947], [88.8741684, 22.53500175], [88.8741684, 22.53527832], [88.87458801, 22.53569794], [88.875, 22.53611374], [88.87555695, 22.53611374], [88.87695313, 22.53750038], [88.8769455, 22.53777695], [88.87750244, 22.53832054], [88.87750244, 22.53861046], [88.87610626, 22.54000282], [88.87610626, 22.53972054], [88.87555695, 22.5402813], [88.8758316, 22.54055405], [88.87587738, 22.54082489], [88.87610626, 22.5411129], [88.87750244, 22.5411129], [88.87800598, 22.54155159], [88.87880707, 22.54306984], [88.87908173, 22.54332542], [88.87922668, 22.54346275], [88.87970734, 22.54384041], [88.88022614, 22.54416084], [88.88072205, 22.5444603], [88.88105011, 22.54491234], [88.88126373, 22.54541397], [88.8814621, 22.54588127], [88.88173676, 22.54627037], [88.88204956, 22.54661179], [88.88239288, 22.54692078], [88.88273621, 22.54721832], [88.8830719, 22.54754066], [88.88334656, 22.54790306], [88.88362122, 22.54828072], [88.88388824, 22.54869461], [88.8841629, 22.54911232], [88.88449097, 22.54945374], [88.88487244, 22.54972267], [88.88523865, 22.54999161], [88.88552856, 22.55033112], [88.88572693, 22.55072212], [88.88594818, 22.55105782], [88.88617706, 22.55133247], [88.88640594, 22.55156136], [88.8866272, 22.55179024], [88.88678741, 22.55207062], [88.88696289, 22.55240059], [88.88722229, 22.55278206], [88.88804626, 22.55362129], [88.88833618, 22.55389214], [88.88861084, 22.55389214], [88.88889313, 22.55417061], [88.88944244, 22.55417061], [88.88999939, 22.55362129], [88.89026642, 22.55333138], [88.89027405, 22.55305481], [88.88944244, 22.5522213], [88.88944244, 22.55194664], [88.88916779, 22.55166817], [88.88889313, 22.55167389], [88.88861084, 22.55138969], [88.88861084, 22.55027962], [88.88889313, 22.55000114], [88.88861084, 22.54972267], [88.88916779, 22.54916573], [88.88916779, 22.54889107], [88.8897171, 22.54833031], [88.88999939, 22.54833412], [88.89055634, 22.54777718], [88.89083099, 22.5477829], [88.89167023, 22.54861259], [88.89167023, 22.54889107], [88.89193726, 22.54916954], [88.89250183, 22.54916954], [88.89277649, 22.54889107], [88.89305878, 22.54889107], [88.89332581, 22.54861259], [88.89389038, 22.54916573], [88.89389038, 22.5494442], [88.89417267, 22.54972267], [88.89416504, 22.55027962], [88.89444733, 22.55055809], [88.89444733, 22.55083466], [88.89472198, 22.55111122], [88.89472198, 22.55167389], [88.89554596, 22.55249977], [88.89554596, 22.55278206], [88.89472198, 22.55362129], [88.89488983, 22.55418968], [88.89546204, 22.55417061], [88.89588928, 22.55389977], [88.89620209, 22.55356026], [88.89640045, 22.55314064], [88.89654541, 22.55275726], [88.89663696, 22.55239296], [88.89665985, 22.55204201], [88.89669037, 22.55175209], [88.89682007, 22.55153084], [88.89691162, 22.55131149], [88.8969574, 22.55104637], [88.89704895, 22.55076027], [88.89717102, 22.55045128], [88.89726257, 22.55014801], [88.89769745, 22.54886055], [88.89797211, 22.54811859], [88.89878082, 22.54745865], [88.89906311, 22.54754066], [88.89925385, 22.54747391], [88.89938354, 22.54743195], [88.89975739, 22.5471611], [88.90011597, 22.54678154], [88.90035248, 22.54632759], [88.90048218, 22.54585266], [88.90049744, 22.54537964], [88.9004364, 22.54490089], [88.90026093, 22.54442406], [88.89985657, 22.54401207], [88.89981079, 22.54374123], [88.89993286, 22.54347038], [88.8999939, 22.54307938], [88.9000473, 22.54260254], [88.90022278, 22.54207039], [88.90027618, 22.54146004], [88.90033722, 22.5408535], [88.90055847, 22.54034996], [88.90083313, 22.53987312], [88.90106964, 22.53938103], [88.90126801, 22.53890038], [88.901474, 22.53849792], [88.90177155, 22.53820229], [88.90211487, 22.53777695], [88.90248108, 22.53725815], [88.90273285, 22.53673172], [88.90278625, 22.53614807], [88.90278625, 22.53557014], [88.90277863, 22.53502655], [88.90267944, 22.53451157], [88.90248108, 22.53406143], [88.90222168, 22.53365517], [88.90194702, 22.53324318], [88.90171814, 22.53276253], [88.9016571, 22.53211021], [88.90167999, 22.53138161], [88.90176392, 22.5306263], [88.90195465, 22.52989006], [88.9021759, 22.5291729], [88.90228271, 22.52845955], [88.90237427, 22.52782822], [88.90232086, 22.52728081], [88.90235138, 22.52685928], [88.90249634, 22.52652168], [88.90273285, 22.52615547], [88.90296173, 22.52564621], [88.90322876, 22.52513123], [88.90358734, 22.52474785], [88.90393829, 22.5243206], [88.90441895, 22.52392006], [88.90489197, 22.52349281], [88.90525055, 22.52296829], [88.90553284, 22.52240753], [88.9057312, 22.5218029], [88.90577698, 22.52113342], [88.90569305, 22.52052116], [88.90548706, 22.52010155], [88.9052124, 22.51976967], [88.90487671, 22.5194416], [88.90454865, 22.51905441], [88.90425873, 22.51852989], [88.9039917, 22.51792908], [88.90364838, 22.51740074], [88.90368652, 22.51696968], [88.90383148, 22.51650238], [88.90388489, 22.51589775], [88.90387726, 22.51521111], [88.90387726, 22.5144825], [88.90386963, 22.51376724], [88.90390015, 22.51305962], [88.90395355, 22.5123539], [88.903862, 22.51156807], [88.90364838, 22.51080132], [88.90357208, 22.51000595], [88.90335083, 22.50930023], [88.90318298, 22.50863075], [88.90305328, 22.50834274], [88.90305328, 22.50722313], [88.90277863, 22.50694466], [88.90305328, 22.50666618], [88.90305328, 22.50556946], [88.9033432, 22.50528145], [88.9033432, 22.50444221], [88.90277863, 22.50388718], [88.90194702, 22.5038929], [88.90083313, 22.50500298], [88.90083313, 22.50528145], [88.9016571, 22.50611305], [88.90166473, 22.50666618], [88.90110779, 22.50722313], [88.90083313, 22.50722313], [88.90055847, 22.5075016], [88.90027618, 22.5075016], [88.89916992, 22.50861168], [88.89833069, 22.50861168], [88.89694214, 22.50722313], [88.89694214, 22.50694466], [88.89638519, 22.50639153], [88.89638519, 22.50527954], [88.89554596, 22.50444221], [88.89555359, 22.50388718], [88.89527893, 22.50361061], [88.89527893, 22.50333214], [88.89527893, 22.50194359], [88.89499664, 22.50166893], [88.89499664, 22.5008297], [88.89638519, 22.49944305], [88.89666748, 22.49944305], [88.89698029, 22.49913216], [88.89778137, 22.49833488], [88.89778137, 22.49805641], [88.89805603, 22.49778175], [88.89861298, 22.49778175], [88.89916992, 22.4972229], [88.89971924, 22.49722481], [88.90000153, 22.49694633], [88.90055847, 22.49694443], [88.90222168, 22.49860954], [88.90222168, 22.49889183], [88.90249634, 22.49916649], [88.90249634, 22.49944305], [88.90277863, 22.49972343], [88.90305328, 22.49972343], [88.90333557, 22.50000191], [88.90510559, 22.5004406], [88.90525818, 22.49971962], [88.90529633, 22.49903488], [88.9052887, 22.49839211], [88.90523529, 22.49778938], [88.90499878, 22.49728966], [88.90471649, 22.49682045], [88.90442657, 22.49638176], [88.90405273, 22.4960041], [88.90361023, 22.49565315], [88.90315247, 22.49529839], [88.90265656, 22.49497032], [88.90220642, 22.49459267], [88.90172577, 22.49425125], [88.90120697, 22.49395943], [88.90080261, 22.49364662], [88.90040588, 22.49333954], [88.8999939, 22.49305534], [88.89955902, 22.49278069], [88.89913177, 22.49250221], [88.89874268, 22.49221992], [88.89861298, 22.49222374], [88.89833069, 22.49194527], [88.89778137, 22.4919529], [88.89737701, 22.49154663], [88.89715576, 22.49132156], [88.89694214, 22.49111176], [88.89694214, 22.49083328], [88.89416504, 22.48805618], [88.89417267, 22.48777962], [88.89305878, 22.48666954], [88.89305878, 22.48639107], [88.89277649, 22.48611259], [88.89277649, 22.48528099], [88.89250183, 22.48500252], [88.89232635, 22.48441124], [88.89227295, 22.48389244], [88.89225769, 22.48337746], [88.89231873, 22.48289299], [88.89244843, 22.48243523], [88.89261627, 22.48199272], [88.89290619, 22.4816227], [88.89331055, 22.48129082], [88.89372253, 22.48095131], [88.89398193, 22.4805603], [88.89420319, 22.48018837], [88.89441681, 22.47985268], [88.89457703, 22.47948265], [88.89476013, 22.4791317], [88.89505005, 22.47881126], [88.89531708, 22.47837257], [88.8956604, 22.47795486], [88.89593506, 22.47746658], [88.89610291, 22.47697258], [88.89624023, 22.476511], [88.89634705, 22.47600174], [88.89652252, 22.47548294], [88.8966217, 22.47493172], [88.89659119, 22.47442436], [88.89637756, 22.47402573], [88.8961792, 22.4736805], [88.89617157, 22.47336388], [88.89633179, 22.47302055], [88.89636993, 22.47246933], [88.89630127, 22.47184944], [88.89608002, 22.47133064], [88.89588165, 22.47087288], [88.89570618, 22.47048187], [88.89551544, 22.47023964], [88.89503479, 22.46975517], [88.89476776, 22.46946335], [88.89447021, 22.46916389], [88.89414978, 22.46881294], [88.89377594, 22.46839905], [88.89338684, 22.46797943], [88.89305878, 22.46751595], [88.89277649, 22.46701241], [88.89250183, 22.46647263], [88.89228821, 22.46593475], [88.89232635, 22.46535301], [88.89252472, 22.4648571], [88.89277649, 22.46446037], [88.89306641, 22.46411705], [88.89343262, 22.46380043], [88.89388275, 22.4634304], [88.89430237, 22.46306229], [88.89472198, 22.46271324], [88.89514923, 22.46237373], [88.89556885, 22.46209145], [88.89599609, 22.46173286], [88.89633179, 22.46119118], [88.89665985, 22.46063042], [88.89698792, 22.46012115], [88.89732361, 22.45967865], [88.89749908, 22.45919228], [88.89762115, 22.45872307], [88.89772034, 22.45827675], [88.897789, 22.45782089], [88.89789581, 22.45739174], [88.89798737, 22.45696259], [88.8980484, 22.45652008], [88.89808655, 22.45607185], [88.89818573, 22.45564079], [88.89808655, 22.45520973], [88.89813995, 22.45479965], [88.89829254, 22.45440102], [88.89837646, 22.45393944], [88.8985672, 22.45353127], [88.89862823, 22.45306969], [88.89872742, 22.45265007], [88.89890289, 22.45229149], [88.89910126, 22.45197105], [88.89916229, 22.45158958], [88.89916992, 22.45121956], [88.89920807, 22.45088005], [88.89936829, 22.4505825], [88.89939117, 22.4502182], [88.89924622, 22.44979286], [88.89918518, 22.44937706], [88.89924622, 22.44894981], [88.89940643, 22.44854164], [88.89948273, 22.44810295], [88.89962769, 22.44772148], [88.89971161, 22.4472847], [88.8997879, 22.4467907], [88.90000153, 22.44632149], [88.90023041, 22.44585228], [88.90031433, 22.44539452], [88.90046692, 22.4450779], [88.90055847, 22.44483948], [88.90065765, 22.44461823], [88.9008255, 22.44440079], [88.90104675, 22.44413567], [88.90132904, 22.44389153], [88.90161133, 22.44366264], [88.90184784, 22.44341087], [88.90200806, 22.44309044], [88.90220642, 22.44282722], [88.90238953, 22.44252968], [88.90263367, 22.44225693], [88.90297699, 22.44201279], [88.90331268, 22.44167137], [88.90361023, 22.44125557], [88.90388489, 22.44080162], [88.90413666, 22.44032097], [88.9043045, 22.43981361], [88.90460205, 22.43941689], [88.9048996, 22.43901253], [88.90527344, 22.43865585], [88.90565491, 22.43824196], [88.90602875, 22.43779182], [88.90636444, 22.43736649], [88.90661621, 22.43697166], [88.90685272, 22.43662834], [88.90703583, 22.43627167], [88.90722656, 22.43589973], [88.90744781, 22.43550301], [88.90762329, 22.43506622], [88.90779877, 22.43460846], [88.90801239, 22.43415642], [88.90805817, 22.43364143], [88.90805054, 22.43310165], [88.90799713, 22.4325695], [88.90792084, 22.43204308], [88.90783691, 22.43152046], [88.90776825, 22.43102074], [88.9076767, 22.43058777], [88.90756989, 22.43019295], [88.9074707, 22.42979431], [88.90731049, 22.42939186], [88.90714264, 22.42892647], [88.90688324, 22.42844963], [88.90648651, 22.4279995], [88.90611267, 22.4274807], [88.90578461, 22.42689896], [88.90545654, 22.42631912], [88.90512085, 22.42579079], [88.90478516, 22.42528915], [88.90445709, 22.42482567], [88.90416718, 22.42435265], [88.90387726, 22.42386055], [88.90361023, 22.42336464], [88.90332794, 22.42287254], [88.9030838, 22.42247963], [88.90305328, 22.42222595], [88.90277863, 22.42194557], [88.90277863, 22.4197216], [88.90249634, 22.41944695], [88.90249634, 22.41777992], [88.90278625, 22.41750145], [88.90277863, 22.41472435], [88.90303802, 22.41444588], [88.90315247, 22.41407967], [88.90332031, 22.41373444], [88.90345001, 22.41335869], [88.90363312, 22.41301155], [88.90387726, 22.41269112], [88.90413666, 22.41233253], [88.90434265, 22.41192055], [88.9045105, 22.41167259], [88.90473938, 22.4114666], [88.90502167, 22.41125298], [88.90535736, 22.41104317], [88.9057312, 22.41082191], [88.90611267, 22.4105835], [88.90654755, 22.41039848], [88.90699768, 22.41021156], [88.90751648, 22.40998268], [88.90804291, 22.40971184], [88.90854645, 22.40944862], [88.90905762, 22.40921974], [88.90960693, 22.40912628], [88.91010284, 22.40892029], [88.91062164, 22.40880013], [88.91107178, 22.40865135], [88.9115448, 22.40858269], [88.91197968, 22.40844917], [88.91243744, 22.40829277], [88.91291046, 22.40808487], [88.91345978, 22.40793419], [88.91407013, 22.40775871], [88.91464996, 22.40753174], [88.9152298, 22.40736961], [88.91573334, 22.40718269], [88.91612244, 22.40694237], [88.91647339, 22.40670013], [88.91685486, 22.40647888], [88.91726685, 22.40623283], [88.91779327, 22.4059639], [88.91833496, 22.40564728], [88.91887665, 22.40525246], [88.91931152, 22.40474129], [88.91944122, 22.40472221], [88.92111206, 22.40305519], [88.92111206, 22.40278053], [88.92138672, 22.40250206], [88.92138672, 22.40167046], [88.92166901, 22.40139008], [88.92166901, 22.40055275], [88.92138672, 22.40027809], [88.92138672, 22.39971924], [88.92111206, 22.39944458], [88.92111206, 22.39916992], [88.91779327, 22.39583015], [88.91722107, 22.39583397], [88.91702271, 22.39550209], [88.91670227, 22.39511108], [88.91615295, 22.39487648], [88.91558838, 22.39458275], [88.91507721, 22.39419937], [88.91452026, 22.3938942], [88.91398621, 22.39363289], [88.91348267, 22.39346123], [88.91304016, 22.39331055], [88.9126358, 22.39312172], [88.91220093, 22.39306068], [88.91175842, 22.39305115], [88.91131592, 22.39302254], [88.91091919, 22.39288139], [88.91047668, 22.39279556], [88.90997314, 22.39277077], [88.90942383, 22.39273262], [88.90892029, 22.39260864], [88.90843964, 22.39246941], [88.9079895, 22.39231491], [88.90751648, 22.39221382], [88.90705109, 22.39208794], [88.90657806, 22.39192009], [88.90614319, 22.39167213], [88.90567017, 22.39138222], [88.9052124, 22.39105034], [88.90471649, 22.39074326], [88.90419006, 22.39043427], [88.90368652, 22.39008141], [88.90320587, 22.38971519], [88.90274048, 22.38932991], [88.90229797, 22.3889637], [88.90182495, 22.38866234], [88.90139008, 22.38837242], [88.90099335, 22.38809013], [88.90055847, 22.38785934], [88.90013885, 22.38763237], [88.89971924, 22.38739204], [88.89933777, 22.38715172], [88.89894104, 22.38692284], [88.89855194, 22.38670349], [88.89816284, 22.3864994], [88.89779663, 22.38625145], [88.89749146, 22.38591957], [88.89720154, 22.38554955], [88.89691162, 22.3851738], [88.89655304, 22.38486862], [88.89624023, 22.38457298], [88.89599609, 22.38422203], [88.89581299, 22.38396454], [88.89566803, 22.38372993], [88.89552307, 22.38352013], [88.89533997, 22.38328171], [88.89521027, 22.38298607], [88.89502716, 22.38269234], [88.89490509, 22.38233376], [88.89466095, 22.3819828], [88.89444733, 22.38156128], [88.89416504, 22.38111305], [88.89416504, 22.3797245], [88.89444733, 22.37944412], [88.89444733, 22.37888908], [88.89472198, 22.37861061], [88.89472198, 22.37806129], [88.89444733, 22.37778473], [88.89417267, 22.37806129], [88.89389038, 22.37806129], [88.89277649, 22.37917137], [88.89250183, 22.37916756], [88.89221954, 22.37944412], [88.89083099, 22.37944412], [88.89055634, 22.37916756], [88.8897171, 22.37917137], [88.88944244, 22.37889481], [88.88889313, 22.37889481], [88.88861084, 22.37861061], [88.88833618, 22.37861061], [88.88804626, 22.37833214], [88.88805389, 22.3777771], [88.88861084, 22.37722206], [88.88916779, 22.37722206], [88.88944244, 22.37694359], [88.88972473, 22.37694359], [88.88990784, 22.37713051], [88.88999939, 22.37722206], [88.89027405, 22.37722206], [88.89055634, 22.37694359], [88.89138794, 22.37694359], [88.89167023, 22.37666893], [88.89167023, 22.37639046], [88.89193726, 22.37611389], [88.89194489, 22.37500191], [88.89305878, 22.37389183], [88.89305878, 22.37307358], [88.89277649, 22.37278175], [88.89389038, 22.37167168], [88.89472198, 22.37166595], [88.89499664, 22.37194252], [88.89499664, 22.37277985], [88.89555359, 22.37333298], [88.89527893, 22.37361145], [88.89583588, 22.3741703], [88.89639282, 22.37361145], [88.89611053, 22.37333298], [88.89611053, 22.37305641], [88.89665985, 22.37167168], [88.89665985, 22.37111092], [88.89694214, 22.37083244], [88.89694214, 22.3702774], [88.89833069, 22.36889076], [88.89833069, 22.36861229], [88.89861298, 22.36833], [88.89861298, 22.36722183], [88.89805603, 22.36666679], [88.89778137, 22.36667061], [88.89694214, 22.36750221], [88.89665985, 22.36750221], [88.89611053, 22.36805534], [88.89611053, 22.36833], [88.89527893, 22.36916924], [88.89527893, 22.36944389], [88.89499664, 22.36972237], [88.89472198, 22.36972237], [88.89417267, 22.37028313], [88.89417267, 22.3705616], [88.89389038, 22.37055969]]], [[[88.93419647, 22.5640316], [88.93483734, 22.56388855], [88.93553925, 22.56369972], [88.93596649, 22.56343269], [88.93609619, 22.5631237], [88.93615723, 22.56279945], [88.93625641, 22.56245995], [88.93630219, 22.56208038], [88.93621063, 22.56169319], [88.93627167, 22.56133461], [88.93609619, 22.5612011], [88.93547058, 22.56139183], [88.93496704, 22.56163979], [88.93452454, 22.56189919], [88.93400574, 22.56211281], [88.93339539, 22.56214333], [88.93280792, 22.56192207], [88.93235779, 22.56162643], [88.93222046, 22.5616703], [88.93222046, 22.56139183], [88.93250275, 22.56110954], [88.93250275, 22.56083107], [88.9327774, 22.56055641], [88.93276978, 22.56028175], [88.93444824, 22.55861092], [88.93444824, 22.55833244], [88.93416595, 22.55805969], [88.9338913, 22.5580616], [88.93360901, 22.55778313], [88.93332672, 22.5580616], [88.93305206, 22.55805969], [88.9327774, 22.55833244], [88.93250275, 22.55833244], [88.9319458, 22.55888748], [88.9319458, 22.55916977], [88.93166351, 22.55944443], [88.93165588, 22.55971909], [88.93110657, 22.56028175], [88.93096924, 22.5605526], [88.93070984, 22.56087303], [88.9305191, 22.56125069], [88.93032074, 22.56163216], [88.9302063, 22.5620594], [88.93005371, 22.56241417], [88.93002319, 22.56278038], [88.93000793, 22.56312752], [88.93009186, 22.56342506], [88.93035889, 22.56361389], [88.93078613, 22.56367111], [88.9313736, 22.56372643], [88.93196869, 22.56394386], [88.93250275, 22.56403542], [88.93302917, 22.56396484], [88.93360138, 22.56406212], [88.93389893, 22.56404686], [88.93419647, 22.5640316]]], [[[88.93650818, 22.61913681], [88.93535614, 22.61982155], [88.93486023, 22.6206913], [88.93457031, 22.62149239], [88.93605042, 22.62157059], [88.93650818, 22.61913681]]], [[[88.78138733, 22.50056267], [88.78193665, 22.50000191], [88.78277588, 22.50000191], [88.78305817, 22.50028038], [88.78333282, 22.50028038], [88.78398132, 22.50008965], [88.78449249, 22.49976158], [88.78500366, 22.49950218], [88.7855835, 22.49934578], [88.78614044, 22.49919319], [88.78668976, 22.49910927], [88.7871933, 22.49892807], [88.78775024, 22.49889565], [88.78832245, 22.49894333], [88.78887177, 22.49912071], [88.78943634, 22.49921036], [88.79001617, 22.49932289], [88.7906189, 22.49919319], [88.7911911, 22.49905968], [88.79167175, 22.49885941], [88.79208374, 22.49861336], [88.79248047, 22.49835014], [88.79292297, 22.4980545], [88.793396, 22.4976902], [88.79384613, 22.49727058], [88.79429626, 22.49681473], [88.79479218, 22.49638176], [88.79522705, 22.49592018], [88.79554749, 22.49543381], [88.79582214, 22.49501228], [88.7960434, 22.49463081], [88.79618835, 22.49422264], [88.79638672, 22.49376106], [88.79659271, 22.49318123], [88.79669189, 22.49249268], [88.79684448, 22.49181557], [88.79691315, 22.49115944], [88.79693604, 22.49063301], [88.79701233, 22.49025154], [88.79718018, 22.48997307], [88.79727936, 22.48962212], [88.79746246, 22.48927116], [88.79766083, 22.4888382], [88.7978363, 22.48835182], [88.79810333, 22.48790169], [88.79841614, 22.48751831], [88.79881287, 22.48719978], [88.79919434, 22.48690414], [88.79953003, 22.48660088], [88.79988861, 22.48636246], [88.80023193, 22.48615074], [88.80062866, 22.48601151], [88.80101013, 22.48581886], [88.80145264, 22.48559952], [88.8020401, 22.48545265], [88.80270386, 22.4853096], [88.80338287, 22.4852314], [88.80396271, 22.48500252], [88.80451202, 22.48477745], [88.80519867, 22.48468208], [88.80587006, 22.48444366], [88.80648041, 22.48410988], [88.80693054, 22.48363495], [88.80728149, 22.48310852], [88.80767822, 22.48263168], [88.80821991, 22.48226547], [88.808815, 22.48193932], [88.80983734, 22.48119354], [88.80998993, 22.48099136], [88.81020355, 22.48059273], [88.81048584, 22.48011971], [88.81092072, 22.47958565], [88.81121063, 22.47891045], [88.8112793, 22.47831154], [88.81121063, 22.47690392], [88.81121063, 22.47596931], [88.81162262, 22.47416115], [88.81166077, 22.47369957], [88.81169891, 22.47320938], [88.81182098, 22.47275162], [88.8119278, 22.47240257], [88.81202698, 22.47205162], [88.81223297, 22.47177315], [88.81244659, 22.47147179], [88.81256866, 22.4710598], [88.81272125, 22.47058296], [88.81273651, 22.47002983], [88.81266785, 22.46953392], [88.81253815, 22.46908379], [88.8125, 22.46861458], [88.81249237, 22.46813011], [88.81246185, 22.46764946], [88.81233215, 22.46720314], [88.8122406, 22.4667511], [88.81221771, 22.46631813], [88.81223297, 22.46587944], [88.81224823, 22.4654026], [88.81233215, 22.46489143], [88.81224823, 22.46441078], [88.81217957, 22.46395302], [88.81194305, 22.46389198], [88.81194305, 22.46222115], [88.81222534, 22.46194458], [88.81208038, 22.46010399], [88.81194305, 22.45944595], [88.81199646, 22.45788383], [88.81228638, 22.45452118], [88.81234741, 22.45417976], [88.81276703, 22.45361137], [88.81291199, 22.4533329], [88.81305695, 22.45305824], [88.8133316, 22.45278168], [88.8133316, 22.4525013], [88.81360626, 22.4521122], [88.81387329, 22.45178032], [88.81407928, 22.45145226], [88.81427765, 22.45106125], [88.81458282, 22.4507103], [88.81492615, 22.45039177], [88.81536865, 22.45018959], [88.81582642, 22.45003128], [88.81630707, 22.44994545], [88.81671906, 22.44978142], [88.8171463, 22.44971275], [88.81754303, 22.44964027], [88.81790924, 22.4494915], [88.81835175, 22.44944763], [88.81884003, 22.44943619], [88.81935883, 22.44944191], [88.81984711, 22.44944191], [88.82029724, 22.44943047], [88.82073212, 22.44941139], [88.82117462, 22.44937325], [88.82164764, 22.44935036], [88.82206726, 22.44945908], [88.82256317, 22.44966316], [88.82316589, 22.44976234], [88.82382965, 22.44987297], [88.82446289, 22.44968987], [88.82499695, 22.44941139], [88.82539368, 22.44906425], [88.82576752, 22.44876289], [88.82608032, 22.44841957], [88.82644653, 22.44804382], [88.82685089, 22.4474144], [88.82730103, 22.44676971], [88.82743073, 22.44618034], [88.8273468, 22.44567108], [88.82718658, 22.4451313], [88.82694244, 22.44461823], [88.8266983, 22.44413185], [88.82653809, 22.44368553], [88.82633209, 22.44336128], [88.82613373, 22.44309616], [88.8259964, 22.44280624], [88.82582855, 22.44255257], [88.82564545, 22.4423008], [88.82549286, 22.44201851], [88.82528687, 22.44175148], [88.82505798, 22.44144821], [88.82480621, 22.44114113], [88.82448578, 22.44087029], [88.82415009, 22.44057465], [88.82382965, 22.44026375], [88.82354736, 22.43992043], [88.82328796, 22.43954468], [88.82298279, 22.43919945], [88.82264709, 22.43889046], [88.82229614, 22.43859291], [88.82198334, 22.43824959], [88.82167816, 22.4378891], [88.82144928, 22.43747139], [88.82138824, 22.43692017], [88.82138062, 22.4363308], [88.8214035, 22.43574905], [88.82148743, 22.43521309], [88.82168579, 22.43478966], [88.82194519, 22.43445206], [88.82225037, 22.43414116], [88.82260895, 22.43388176], [88.82298279, 22.43361092], [88.82337189, 22.43335152], [88.82390594, 22.43317032], [88.82454681, 22.43313789], [88.82512665, 22.43319893], [88.82555389, 22.43321419], [88.82692719, 22.43313026], [88.82843781, 22.4331913], [88.829216, 22.43333244], [88.82987213, 22.43346977], [88.83045197, 22.43359947], [88.83109283, 22.43373108], [88.83203125, 22.43400192], [88.83296204, 22.43427086], [88.83346558, 22.43440437], [88.83454132, 22.43460655], [88.8348999, 22.43460655], [88.83518982, 22.43453979], [88.83526611, 22.43433952], [88.83512115, 22.43408012], [88.83483124, 22.43380356], [88.83447266, 22.43367386], [88.83410645, 22.43340111], [88.83361053, 22.43325996], [88.83289337, 22.43319511], [88.83253479, 22.43306541], [88.83217621, 22.43306541], [88.83102417, 22.43272972], [88.829216, 22.43253136], [88.82699585, 22.43238831], [88.82423401, 22.43205452], [88.82367706, 22.43211174], [88.82320404, 22.43218994], [88.82273102, 22.43221474], [88.82224274, 22.43220329], [88.82173157, 22.43211746], [88.82121277, 22.43199158], [88.820961, 22.43195152], [88.82067871, 22.43194389], [88.82026672, 22.4319706], [88.81978607, 22.432127], [88.81922913, 22.43225288], [88.81874847, 22.43248177], [88.81832886, 22.43266106], [88.81793976, 22.43279266], [88.81758881, 22.43294907], [88.81719208, 22.43307304], [88.81674957, 22.43323708], [88.81624603, 22.43341637], [88.81584167, 22.4337635], [88.81548309, 22.43413353], [88.81513977, 22.43444252], [88.81481934, 22.43470955], [88.8144989, 22.43494987], [88.81417847, 22.43519592], [88.81388092, 22.43548012], [88.81355286, 22.43580055], [88.81314087, 22.43611908], [88.81269073, 22.43647575], [88.81223297, 22.43687248], [88.81175995, 22.43730545], [88.81136322, 22.43781281], [88.81096649, 22.43833542], [88.81059265, 22.43885994], [88.81022644, 22.43941307], [88.8098526, 22.43992043], [88.80937195, 22.44032097], [88.80887604, 22.44059181], [88.80850983, 22.44087029], [88.80821991, 22.44113731], [88.80765533, 22.44136238], [88.80686951, 22.44155312], [88.80623627, 22.44188118], [88.80584717, 22.44234276], [88.80551147, 22.4426899], [88.80515289, 22.44299126], [88.80487061, 22.44336128], [88.80458832, 22.44373512], [88.80427551, 22.44408607], [88.80397034, 22.44445229], [88.80371094, 22.44487953], [88.80351257, 22.4453373], [88.8033371, 22.44579124], [88.80316925, 22.44621086], [88.8030777, 22.44662285], [88.80304718, 22.44701958], [88.80300903, 22.44742012], [88.80290222, 22.44779968], [88.80280304, 22.44820213], [88.80278015, 22.44865036], [88.80278015, 22.44910812], [88.80278015, 22.44959068], [88.80278778, 22.45008278], [88.80282593, 22.45055199], [88.80296326, 22.45092964], [88.80307007, 22.45127106], [88.8030014, 22.45182037], [88.80288696, 22.45235252], [88.8028183, 22.45284081], [88.80278015, 22.45335388], [88.80272675, 22.45392036], [88.80262756, 22.45456123], [88.80258179, 22.45526314], [88.80256653, 22.45594978], [88.80241394, 22.45641708], [88.80210114, 22.45672226], [88.80179596, 22.45714188], [88.80162811, 22.45774841], [88.80142212, 22.45838356], [88.80131531, 22.45900154], [88.80116272, 22.45951271], [88.8010788, 22.46003151], [88.80093384, 22.46046257], [88.80084991, 22.46080017], [88.80080414, 22.4611187], [88.8006897, 22.46140099], [88.80053711, 22.46172142], [88.80030823, 22.46207237], [88.80008698, 22.46249962], [88.79981995, 22.46297264], [88.79953766, 22.46350288], [88.79920197, 22.46398163], [88.79888153, 22.46445274], [88.79857635, 22.4648819], [88.79830933, 22.4652195], [88.79806519, 22.46549797], [88.79785156, 22.4657917], [88.79767609, 22.46617317], [88.79746246, 22.46656227], [88.79740143, 22.46723175], [88.79734039, 22.46783829], [88.79701233, 22.46813583], [88.79670715, 22.46846962], [88.79641724, 22.46885109], [88.79611969, 22.4691906], [88.79586029, 22.46955299], [88.79566193, 22.46992111], [88.79553223, 22.47029495], [88.79537964, 22.47061157], [88.79524994, 22.47092247], [88.79508209, 22.47125053], [88.79494476, 22.4717083], [88.79471588, 22.47221375], [88.79442596, 22.4727726], [88.79413605, 22.47334099], [88.79386139, 22.47391891], [88.79363251, 22.47448349], [88.79350281, 22.47504997], [88.79354095, 22.4756794], [88.79341125, 22.47632027], [88.79325867, 22.47693634], [88.79310608, 22.47754097], [88.7930603, 22.47817039], [88.79299927, 22.47875786], [88.79283905, 22.47929192], [88.79271698, 22.47982216], [88.7925415, 22.48028183], [88.79234314, 22.48075294], [88.79216003, 22.48130226], [88.79194641, 22.48181343], [88.79171753, 22.48228455], [88.79148102, 22.48272133], [88.79115295, 22.48306084], [88.790802, 22.48338127], [88.79046631, 22.48370171], [88.79016113, 22.48402023], [88.78987885, 22.4842968], [88.78960419, 22.48454475], [88.78926849, 22.48477364], [88.7889328, 22.4850502], [88.78859711, 22.48537827], [88.78830719, 22.4857502], [88.78798676, 22.48621178], [88.78756714, 22.48669243], [88.78710938, 22.4869175], [88.78665161, 22.48712349], [88.78620148, 22.48739433], [88.78582001, 22.48780441], [88.78543854, 22.48823166], [88.78501129, 22.48859978], [88.78459167, 22.48892021], [88.78425598, 22.48925209], [88.78401947, 22.4895916], [88.78382874, 22.48989105], [88.78362274, 22.49012184], [88.78341675, 22.49036217], [88.78325653, 22.49062157], [88.78305054, 22.49089241], [88.7828064, 22.49121475], [88.78246307, 22.49160767], [88.7820816, 22.49205971], [88.78172302, 22.49262047], [88.78142548, 22.49319649], [88.78120422, 22.49371338], [88.78111267, 22.49361229], [88.78055573, 22.49416733], [88.78056335, 22.49500275], [88.78028107, 22.49528122], [88.78055573, 22.49555779], [88.78055573, 22.49694443], [88.78028107, 22.4972229], [88.78028107, 22.49916649], [88.78055573, 22.49944305], [88.78056335, 22.49971962], [88.78083038, 22.50000191], [88.78083038, 22.50028038], [88.78111267, 22.50056267], [88.78138733, 22.50056267]]], [[[89.65219879, 26.0621624], [89.65222931, 26.06225777], [89.65227509, 26.06243515], [89.65228271, 26.06256676], [89.65229797, 26.06265068], [89.65229797, 26.06279564], [89.65228271, 26.06288147], [89.65227509, 26.06295776], [89.6522522, 26.06305313], [89.65224457, 26.06314278], [89.65216064, 26.06351852], [89.6521225, 26.06380081], [89.65209961, 26.0641098], [89.65206909, 26.06440163], [89.65205383, 26.06458664], [89.65201569, 26.06481934], [89.65200806, 26.0650425], [89.6519928, 26.06529427], [89.65202332, 26.06554222], [89.65268707, 26.0635891], [89.65235138, 26.06223106], [89.65219879, 26.0621624]]], [[[88.88509369, 26.24045753], [88.88491058, 26.24035645], [88.88476563, 26.24032974], [88.88461304, 26.24033356], [88.88446045, 26.24035263], [88.88427734, 26.24050713], [88.88407898, 26.24067688], [88.88388824, 26.24094963], [88.88368225, 26.24123955], [88.88352966, 26.24142265], [88.88336182, 26.24160576], [88.88321686, 26.24180222], [88.88306427, 26.24201393], [88.88294983, 26.24221039], [88.88285828, 26.24238968], [88.88279724, 26.24250984], [88.88272858, 26.24269104], [88.88265228, 26.24285507], [88.88253021, 26.24304962], [88.88244629, 26.24324226], [88.88226318, 26.24355698], [88.88217163, 26.2437191], [88.88204956, 26.24388313], [88.88192749, 26.24403572], [88.88256836, 26.24439049], [88.88389587, 26.24529076], [88.88497162, 26.24414063], [88.88507843, 26.2420311], [88.88509369, 26.24045753]]], [[[89.02344513, 26.242733], [89.02387238, 26.24292374], [89.02420807, 26.24292183], [89.02462006, 26.24283981], [89.02500916, 26.24282074], [89.02526093, 26.24280167], [89.02557373, 26.24275589], [89.02576447, 26.24274635], [89.02587128, 26.24268532], [89.02592468, 26.24249268], [89.0259552, 26.24216652], [89.02585602, 26.24173164], [89.02568817, 26.24116898], [89.02555847, 26.24082375], [89.025383, 26.24058723], [89.02520752, 26.24062157], [89.02489471, 26.24069405], [89.02445221, 26.2407608], [89.02401733, 26.24075699], [89.02362061, 26.2407856], [89.02332306, 26.24083328], [89.0230484, 26.24098778], [89.02298737, 26.24106216], [89.02293396, 26.24115372], [89.02280426, 26.24128532], [89.0226593, 26.24155617], [89.02248383, 26.2416153], [89.02201843, 26.24267006], [89.02223969, 26.24267006], [89.0225296, 26.24266243], [89.02288055, 26.24266815], [89.02313995, 26.24256706], [89.02344513, 26.242733]]], [[[87.75389099, 21.69639015], [87.75389099, 21.69610977], [87.7536087, 21.6958313], [87.7536087, 21.69555473], [87.75333405, 21.69527817], [87.75332642, 21.69444275], [87.7536087, 21.69416618], [87.7536087, 21.69361115], [87.75305176, 21.69306183], [87.75250244, 21.69361115], [87.75222015, 21.69361115], [87.75195313, 21.69388962], [87.75166321, 21.69388962], [87.75138855, 21.69417191], [87.7508316, 21.69417191], [87.75055695, 21.69388962], [87.75, 21.69388962], [87.74972534, 21.69361115], [87.74972534, 21.69305611], [87.74944305, 21.6927681], [87.74944305, 21.6922226], [87.7491684, 21.69194412], [87.7491684, 21.69138908], [87.74944305, 21.69111061], [87.74944305, 21.69082832], [87.75, 21.6902771], [87.75, 21.69011116], [87.75, 21.69000053], [87.75027466, 21.68972206], [87.75026703, 21.68889046], [87.75000763, 21.68861008], [87.75, 21.68833351], [87.74973297, 21.68777847], [87.75000763, 21.68721962], [87.75027466, 21.68722153], [87.75027466, 21.68666458], [87.74888611, 21.68527985], [87.74888611, 21.68472099], [87.7480545, 21.68388939], [87.74777985, 21.68388939], [87.7472229, 21.68333054], [87.74666595, 21.68333244], [87.7463913, 21.68361092], [87.74583435, 21.68361092], [87.74555206, 21.68333244], [87.7452774, 21.68333244], [87.7450943, 21.68314934], [87.74472046, 21.6827774], [87.7444458, 21.68278122], [87.74415588, 21.68250084], [87.74388123, 21.68250084], [87.74351501, 21.68213081], [87.74333191, 21.68194389], [87.74333191, 21.68138885], [87.74250031, 21.68056107], [87.74223328, 21.68056107], [87.7416687, 21.68000031], [87.74138641, 21.68000031], [87.74054718, 21.67917252], [87.74028015, 21.67917252], [87.73999786, 21.67889023], [87.73999786, 21.67861176], [87.73972321, 21.67833328], [87.73916626, 21.67833328], [87.7388916, 21.67805481], [87.73860931, 21.67805481], [87.73833466, 21.67777824], [87.73805237, 21.67778969], [87.73777771, 21.67749977], [87.73750305, 21.67749977], [87.73722076, 21.67721748], [87.73694611, 21.6772213], [87.73666382, 21.67694473], [87.73638916, 21.67694473], [87.73583221, 21.67638969], [87.73555756, 21.67638969], [87.7352829, 21.67611122], [87.73500061, 21.67611122], [87.73361206, 21.67506027], [87.73249817, 21.6747303], [87.73221588, 21.67444038], [87.73166656, 21.6744442], [87.73139191, 21.67416763], [87.73110962, 21.67416954], [87.73055267, 21.67361069], [87.73027802, 21.67361069], [87.73000336, 21.67333031], [87.72972107, 21.67333412], [87.72916412, 21.67277527], [87.72888184, 21.67278099], [87.72860718, 21.67250061], [87.72805786, 21.67250061], [87.7277832, 21.67222023], [87.72750092, 21.67222214], [87.72721863, 21.67194366], [87.72694397, 21.67194366], [87.72666931, 21.67166519], [87.72583008, 21.67166519], [87.72555542, 21.67138863], [87.72528076, 21.67139053], [87.72514343, 21.67124939], [87.72499847, 21.67111015], [87.72472382, 21.67111206], [87.72455597, 21.67094421], [87.72444153, 21.67083549], [87.72416687, 21.67083549], [87.72389221, 21.67055321], [87.72305298, 21.67056084], [87.72277832, 21.67028046], [87.72249603, 21.67028046], [87.72222137, 21.67000008], [87.72194672, 21.67000008], [87.7216568, 21.6697197], [87.72138977, 21.6697216], [87.72110748, 21.66944313], [87.72083282, 21.66945076], [87.72055817, 21.66917038], [87.72027588, 21.66917038], [87.72000122, 21.66889], [87.7197113, 21.66889], [87.71942139, 21.66866302], [87.71916962, 21.66861153], [87.71888733, 21.66833115], [87.71861267, 21.66833115], [87.71798706, 21.66790962], [87.71778107, 21.66777802], [87.71749878, 21.66784286], [87.71707916, 21.66764069], [87.71694183, 21.66756248], [87.71666718, 21.66749191], [87.71611023, 21.66740608], [87.71562958, 21.66719818], [87.71527863, 21.6669445], [87.71472168, 21.6669445], [87.71458435, 21.66680527], [87.71444702, 21.66666603], [87.71389771, 21.66667175], [87.71360779, 21.66638947], [87.71333313, 21.66638947], [87.71305847, 21.66610909], [87.71277618, 21.66610909], [87.71250153, 21.66583061], [87.71221924, 21.66583252], [87.71194458, 21.66555405], [87.71166992, 21.66527748], [87.71138763, 21.66527939], [87.71111298, 21.66500092], [87.71083069, 21.66500092], [87.7103653, 21.66475487], [87.70982361, 21.66470528], [87.70928955, 21.66469002], [87.70889282, 21.66452026], [87.70847321, 21.66436005], [87.70810699, 21.66415024], [87.7077179, 21.66394615], [87.7072525, 21.66386414], [87.70677948, 21.6637764], [87.70639038, 21.66360092], [87.70601654, 21.66340828], [87.70561981, 21.66327095], [87.70523834, 21.66308975], [87.70481873, 21.66294289], [87.70439911, 21.66280365], [87.70396423, 21.66270065], [87.70355988, 21.66255951], [87.70314789, 21.66246033], [87.70305634, 21.6622982], [87.70276642, 21.66221809], [87.70166779, 21.66201973], [87.70111084, 21.66167068], [87.70027924, 21.66167068], [87.69999695, 21.6613903], [87.69972229, 21.6613903], [87.69944763, 21.66110992], [87.69889069, 21.66111183], [87.6986084, 21.66083336], [87.69833374, 21.66083336], [87.69805908, 21.66055679], [87.69750214, 21.66055679], [87.69721985, 21.66027832], [87.6966629, 21.66028023], [87.69638824, 21.65999985], [87.69555664, 21.65999985], [87.69526672, 21.65971947], [87.69499969, 21.65972137], [87.69472504, 21.65944672], [87.69416809, 21.65944672], [87.6938858, 21.65916443], [87.69333649, 21.65917015], [87.69304657, 21.65888977], [87.69277191, 21.65888977], [87.69255066, 21.65866661], [87.69249725, 21.65860939], [87.69166565, 21.6586113], [87.69139099, 21.65833282], [87.69083405, 21.65833282], [87.69055176, 21.65805435], [87.6902771, 21.65806007], [87.68972778, 21.65750122], [87.68860626, 21.65750122], [87.6883316, 21.65722084], [87.6875, 21.65722466], [87.68722534, 21.65694237], [87.6866684, 21.65694237], [87.68638611, 21.6566658], [87.68583679, 21.6566658], [87.6855545, 21.65638924], [87.68527985, 21.65639114], [87.68499756, 21.65611076], [87.68416595, 21.65611076], [87.6838913, 21.65583038], [87.68333435, 21.65583229], [87.68305206, 21.65555573], [87.68257141, 21.6552906], [87.68222046, 21.65528107], [87.68145752, 21.65513992], [87.6811142, 21.65500069], [87.68055725, 21.65500069], [87.68028259, 21.65472031], [87.67972565, 21.65472221], [87.67944336, 21.65444374], [87.67888641, 21.65444374], [87.67861176, 21.65416718], [87.67804718, 21.6541729], [87.67778778, 21.65389061], [87.67648315, 21.65374947], [87.67583466, 21.65361023], [87.67555237, 21.65361977], [87.67527771, 21.65333176], [87.67472076, 21.65333366], [87.67453766, 21.65314865], [87.67444611, 21.65305519], [87.67388916, 21.65306282], [87.67360687, 21.65278053], [87.6727829, 21.65278053], [87.67250061, 21.65250015], [87.67118073, 21.65236092], [87.67082977, 21.65222168], [87.67007446, 21.65202332], [87.66972351, 21.65194511], [87.66916656, 21.6518116], [87.66889191, 21.65167236], [87.66709137, 21.65146065], [87.66666412, 21.65138817], [87.66438293, 21.65105247], [87.66388702, 21.6511116], [87.66305542, 21.6511116], [87.66278076, 21.65083313], [87.66222382, 21.65083313], [87.66194153, 21.65055466], [87.66139221, 21.65055847], [87.66110992, 21.65027809], [87.65888977, 21.65027809], [87.65860748, 21.64999962], [87.65805817, 21.64999962], [87.65777588, 21.64972115], [87.65721893, 21.64972305], [87.65712738, 21.64962959], [87.65694427, 21.64944458], [87.65583038, 21.64944458], [87.65555573, 21.64916611], [87.65471649, 21.64916992], [87.65444183, 21.64888954], [87.65361023, 21.64888954], [87.65333557, 21.64861107], [87.65000153, 21.64861107], [87.64971924, 21.64888954], [87.64888763, 21.64888954], [87.64861298, 21.64916992], [87.64778137, 21.64916611], [87.64749908, 21.64944458], [87.64722443, 21.64944458], [87.64694214, 21.64972305], [87.64611053, 21.64972115], [87.64583588, 21.64999962], [87.64554596, 21.64999962], [87.6452713, 21.64977837], [87.64472198, 21.64972115], [87.64444733, 21.64999962], [87.64347076, 21.65063095], [87.64332581, 21.65083122], [87.64250183, 21.65166664], [87.64214325, 21.65263939], [87.64215088, 21.65305519], [87.64209747, 21.65410995], [87.64208221, 21.65444183], [87.64193726, 21.65466118], [87.64193726, 21.65500069], [87.64173126, 21.65555573], [87.64167023, 21.65583229], [87.64167786, 21.65611076], [87.64194489, 21.65638924], [87.64221954, 21.65679359], [87.64277649, 21.65694046], [87.64299011, 21.65715027], [87.64437103, 21.65846825], [87.64444733, 21.65860939], [87.64472198, 21.65888977], [87.64472198, 21.65917015], [87.64487457, 21.65964508], [87.64437866, 21.65998077], [87.64360809, 21.65999985], [87.64305878, 21.65944099], [87.64277649, 21.65944672], [87.64138794, 21.65805435], [87.64105988, 21.65776062], [87.64063263, 21.65756035], [87.64026642, 21.65750122], [87.63987732, 21.65730095], [87.63941193, 21.65695], [87.63893127, 21.65659904], [87.63865662, 21.65638924], [87.63846588, 21.65624428], [87.63800812, 21.65591049], [87.63755798, 21.65559959], [87.637146, 21.65524101], [87.63679504, 21.65484238], [87.63648987, 21.65441132], [87.63625336, 21.65396118], [87.63613129, 21.6534996], [87.6359787, 21.65304947], [87.63574982, 21.65269089], [87.63550568, 21.6524086], [87.63527679, 21.65205956], [87.63504791, 21.65164566], [87.63481903, 21.65114021], [87.63469696, 21.6505909], [87.63454437, 21.65018272], [87.63444519, 21.64983749], [87.63430023, 21.64954948], [87.63408661, 21.64921951], [87.63381958, 21.64889908], [87.63342285, 21.64860725], [87.6329422, 21.64830017], [87.63248444, 21.64800072], [87.63204193, 21.64767265], [87.63160706, 21.64734077], [87.63111877, 21.64712143], [87.63061523, 21.64692879], [87.63011932, 21.64673042], [87.6295929, 21.64665222], [87.62906647, 21.6465435], [87.62854004, 21.64636803], [87.62799835, 21.64616013], [87.627388, 21.646101], [87.6267395, 21.64603043], [87.62608337, 21.64586258], [87.62540436, 21.64576149], [87.62475586, 21.64559364], [87.62406921, 21.64550972], [87.62341309, 21.6453228], [87.62274933, 21.64518166], [87.62208557, 21.64499474], [87.6214447, 21.64480782], [87.62078857, 21.64471054], [87.6202774, 21.64472198], [87.62000275, 21.64444351], [87.61833191, 21.64444351], [87.61804962, 21.64422226], [87.61749268, 21.64417076], [87.61723328, 21.64389038], [87.61694336, 21.64417076], [87.61528015, 21.64417076], [87.61499786, 21.64389038], [87.61277771, 21.64389038], [87.6125946, 21.64370537], [87.61222076, 21.64333344], [87.61194611, 21.64333344], [87.61166382, 21.64305305], [87.60978699, 21.64285088], [87.60906982, 21.64271927], [87.60835266, 21.6426506], [87.60799408, 21.64251518], [87.60706329, 21.64232063], [87.60634613, 21.64204979], [87.60549927, 21.64216995], [87.60527802, 21.64194107], [87.60472107, 21.64194489], [87.60407257, 21.64189148], [87.60341644, 21.64176559], [87.60286713, 21.64162064], [87.60238647, 21.6414299], [87.60188293, 21.64138985], [87.60135651, 21.64137077], [87.60083771, 21.64126015], [87.60028076, 21.64108086], [87.59970093, 21.64088058], [87.59908295, 21.6408329], [87.59849548, 21.64080811], [87.59798431, 21.64069176], [87.59751129, 21.64053917], [87.5970459, 21.64038086], [87.59648132, 21.64030075], [87.59584045, 21.64033127], [87.59541321, 21.64029694], [87.59519958, 21.64028358], [87.59455109, 21.64023018], [87.59395599, 21.64012909], [87.59346008, 21.63999939], [87.59300232, 21.63989449], [87.59256744, 21.6397686], [87.59208679, 21.63955116], [87.59147644, 21.63937187], [87.5908432, 21.63920021], [87.59017181, 21.63915825], [87.58956909, 21.63914108], [87.58904266, 21.63911057], [87.58857727, 21.63896942], [87.5881424, 21.6388607], [87.58773041, 21.638731], [87.58732605, 21.63862038], [87.58692932, 21.63853073], [87.58653259, 21.63838959], [87.58609009, 21.63829994], [87.58566284, 21.63817024], [87.58522034, 21.63804054], [87.58476257, 21.63786125], [87.58428192, 21.63772774], [87.58377075, 21.63757133], [87.58320618, 21.63750076], [87.58266449, 21.63744736], [87.58223724, 21.63728142], [87.58178711, 21.63721657], [87.58135223, 21.63714027], [87.58097076, 21.63699341], [87.58052063, 21.63693047], [87.58004761, 21.63684082], [87.57953644, 21.63669968], [87.57901764, 21.63662529], [87.57850647, 21.63646126], [87.57800293, 21.63639069], [87.57752228, 21.63631821], [87.57707977, 21.63620186], [87.57665253, 21.63612175], [87.57621765, 21.63589478], [87.57592773, 21.63574791], [87.57533264, 21.63576126], [87.57485962, 21.63563919], [87.57435608, 21.63562012], [87.57382965, 21.63533974], [87.57330322, 21.63513947], [87.57279205, 21.63507652], [87.57226563, 21.63521385], [87.5716629, 21.63517189], [87.57147217, 21.6350708], [87.57100677, 21.63502693], [87.57058716, 21.63495064], [87.57019806, 21.63476944], [87.56977844, 21.63469124], [87.56941986, 21.63455009], [87.56906128, 21.63446045], [87.56873322, 21.63439941], [87.56838989, 21.63425064], [87.56803131, 21.63414955], [87.56763458, 21.63402939], [87.56716919, 21.63392258], [87.56667328, 21.63396072], [87.56629944, 21.63393974], [87.56604767, 21.63389969], [87.56575775, 21.63389015], [87.56539917, 21.63388062], [87.56498718, 21.63381958], [87.56461334, 21.63365364], [87.56421661, 21.63353348], [87.56381989, 21.63344383], [87.56330872, 21.63349342], [87.56291199, 21.6333847], [87.56277466, 21.63333321], [87.56118011, 21.63306427], [87.56083679, 21.63305664], [87.56027985, 21.63300514], [87.55937195, 21.63327026], [87.559021, 21.63348961], [87.55805206, 21.63388634], [87.55770874, 21.63396454], [87.55750275, 21.63409042], [87.55715179, 21.63425064], [87.5569458, 21.63445091], [87.55583191, 21.63555908], [87.55444336, 21.63555908], [87.55388641, 21.63611031], [87.55304718, 21.63611031], [87.55166626, 21.63471985], [87.5513916, 21.63472176], [87.55110931, 21.63444519], [87.55000305, 21.63445091], [87.54944611, 21.63389015], [87.54944611, 21.63360977], [87.54916382, 21.63333321], [87.54916382, 21.63222313], [87.54833221, 21.63138962], [87.54833221, 21.63083076], [87.54805756, 21.63083267], [87.54777527, 21.6305542], [87.54722595, 21.63055992], [87.54693604, 21.63027954], [87.54666901, 21.63027954], [87.54638672, 21.63000107], [87.54611206, 21.62972069], [87.54611206, 21.62944221], [87.54582977, 21.62916756], [87.54556274, 21.62916946], [87.54545593, 21.62906647], [87.54528046, 21.62888908], [87.54444122, 21.6288929], [87.54416656, 21.62861061], [87.54389191, 21.62861061], [87.54360962, 21.62833023], [87.54166412, 21.62833214], [87.54138947, 21.62805557], [87.54110718, 21.62805939], [87.54083252, 21.62778282], [87.54055786, 21.62778282], [87.5402832, 21.62750053], [87.53943634, 21.62750053], [87.53916931, 21.62722015], [87.53749847, 21.62722015], [87.5368042, 21.62680244], [87.53499603, 21.62668037], [87.53472137, 21.62639046], [87.53444672, 21.62639046], [87.5341568, 21.62611008], [87.53360748, 21.62597656], [87.53257751, 21.62505913], [87.53221893, 21.62480164], [87.53166962, 21.62445068], [87.53083038, 21.62444496], [87.53055573, 21.62472153], [87.53028107, 21.62472153], [87.52973175, 21.62417221], [87.52916718, 21.62361145], [87.52889252, 21.62361908], [87.52861023, 21.62333107], [87.52805328, 21.62333298], [87.52777863, 21.62305641], [87.52749634, 21.62305832], [87.52738953, 21.6229496], [87.52722931, 21.62277985], [87.52587891, 21.62224007], [87.52487946, 21.62216949], [87.52444458, 21.62217331], [87.52351379, 21.62176895], [87.52250671, 21.62177277], [87.52186584, 21.62170029], [87.52166748, 21.62138939], [87.5212326, 21.62125969], [87.52068329, 21.62124062], [87.52011871, 21.62129974], [87.5196228, 21.62118912], [87.51912689, 21.62109947], [87.51864624, 21.62100029], [87.51819611, 21.62085915], [87.51771545, 21.62078667], [87.51727295, 21.6206398], [87.51679993, 21.62055588], [87.5163269, 21.6204586], [87.51589203, 21.62029839], [87.51544952, 21.62015915], [87.51502991, 21.6199894], [87.51463318, 21.6198082], [87.51419067, 21.61969185], [87.51306915, 21.61961174], [87.51249695, 21.61944008], [87.51194763, 21.6194458], [87.51166534, 21.61916733], [87.51139069, 21.61917114], [87.51082611, 21.61861038], [87.51055908, 21.61861038], [87.50988007, 21.6185894], [87.50937653, 21.61850929], [87.50892639, 21.61837006], [87.50843048, 21.61828995], [87.50791931, 21.61812973], [87.50737762, 21.61800957], [87.50686646, 21.61785126], [87.50636292, 21.61771965], [87.50585938, 21.61755371], [87.50527954, 21.61750031], [87.50499725, 21.61750031], [87.5047226, 21.61722183], [87.5036087, 21.61722183], [87.50333405, 21.61694336], [87.50305939, 21.61695099], [87.50296021, 21.61685181], [87.5027771, 21.61666679], [87.50195313, 21.61667061], [87.50176239, 21.6164856], [87.50166321, 21.61638832], [87.50110626, 21.61639023], [87.49989319, 21.61572075], [87.49938965, 21.61572075], [87.498703, 21.61560059], [87.49860382, 21.61558151], [87.49760437, 21.61517715], [87.4972229, 21.61499977], [87.49694824, 21.61471939], [87.4963913, 21.6147213], [87.49610901, 21.61444473], [87.49555206, 21.61445045], [87.4952774, 21.61417007], [87.49500275, 21.61417007], [87.49415588, 21.61333275], [87.49285126, 21.61352921], [87.49227142, 21.61292267], [87.49098969, 21.61272049], [87.49027252, 21.61252022], [87.48976898, 21.61225128], [87.48890686, 21.61211967], [87.48806, 21.61164093], [87.48777771, 21.61138916], [87.48750305, 21.61111069], [87.48694611, 21.61111069], [87.48665619, 21.6108284], [87.48638916, 21.61083412], [87.4861145, 21.61055565], [87.48583221, 21.61056137], [87.48458862, 21.61018944], [87.48401642, 21.61005974], [87.48323059, 21.60957909], [87.48278046, 21.6091671], [87.48249817, 21.60889053], [87.48221588, 21.60889053], [87.48203278, 21.60870361], [87.48175812, 21.60946274], [87.48171234, 21.61383057], [87.48265839, 21.61803246], [87.48208618, 21.62586975], [87.4785614, 21.62794113], [87.47751617, 21.63175964], [87.47074127, 21.64307022], [87.46776581, 21.64565086], [87.46090698, 21.64445114], [87.45864868, 21.64493942], [87.4604187, 21.65712929], [87.46491241, 21.65855026], [87.46349335, 21.66876984], [87.46507263, 21.67110062], [87.46520233, 21.67513084], [87.46826172, 21.67727089], [87.46839142, 21.68378067], [87.46969604, 21.6916008], [87.4675293, 21.69565964], [87.46929169, 21.69845009], [87.47083282, 21.70718002], [87.46264648, 21.71706009], [87.46083069, 21.72050095], [87.46231842, 21.72224998], [87.46573639, 21.7235775], [87.46605682, 21.72519112], [87.46517944, 21.72636032], [87.46276855, 21.72640038], [87.45419312, 21.72943115], [87.44293213, 21.72904968], [87.44441986, 21.732481], [87.45137024, 21.73241043], [87.45111084, 21.7354126], [87.44563293, 21.7379303], [87.44330597, 21.74212074], [87.44245911, 21.75533104], [87.44367218, 21.76088905], [87.43930817, 21.76436043], [87.43139648, 21.76440048], [87.42481995, 21.76565933], [87.41208649, 21.76375008], [87.40283203, 21.7655201], [87.40101624, 21.76486015], [87.39993286, 21.76256943], [87.39524078, 21.76242256], [87.39377594, 21.76377106], [87.39315796, 21.76613808], [87.38990021, 21.76654053], [87.39240265, 21.76898193], [87.39096069, 21.77044106], [87.38330078, 21.77086067], [87.37542725, 21.76799965], [87.37348938, 21.76641083], [87.37306213, 21.76204109], [87.37166595, 21.76039124], [87.37011719, 21.76007271], [87.36873627, 21.76263046], [87.37045288, 21.76802063], [87.36779785, 21.77463913], [87.35736084, 21.77724075], [87.35504913, 21.77927971], [87.3520813, 21.78573036], [87.34449768, 21.78596115], [87.34046173, 21.78395844], [87.33922577, 21.7808094], [87.33666992, 21.77918053], [87.33500671, 21.78013039], [87.33573151, 21.78121185], [87.33534241, 21.78363037], [87.33270264, 21.78720093], [87.33011627, 21.78770256], [87.32618713, 21.78564072], [87.32427216, 21.78537941], [87.32286072, 21.78596115], [87.31730652, 21.78572083], [87.31685638, 21.78854942], [87.31796265, 21.79055023], [87.30916595, 21.78890991], [87.30755615, 21.79268265], [87.30605316, 21.79385948], [87.29872131, 21.79444122], [87.29656982, 21.79533005], [87.294487, 21.79842186], [87.29480743, 21.80389023], [87.29281616, 21.80546951], [87.2869873, 21.80384827], [87.28060913, 21.7991581], [87.27350616, 21.8020401], [87.27333832, 21.80360031], [87.27156067, 21.80340004], [87.27165222, 21.80471992], [87.27314758, 21.80579948], [87.27379608, 21.81171989], [87.27147675, 21.81307983], [87.26542664, 21.81289101], [87.26242065, 21.81385994], [87.26326752, 21.81604195], [87.26780701, 21.81970978], [87.26756287, 21.82149124], [87.26346588, 21.82501984], [87.26357269, 21.82719994], [87.26226044, 21.82982826], [87.26169586, 21.83329964], [87.25888824, 21.83501053], [87.25714874, 21.84137917], [87.25527191, 21.8438797], [87.24762726, 21.84820747], [87.24475098, 21.85637093], [87.24900055, 21.86380005], [87.24897766, 21.86651993], [87.24732971, 21.87172127], [87.23480988, 21.89560127], [87.23651886, 21.90272141], [87.23937225, 21.90682983], [87.25054932, 21.91518021], [87.25240326, 21.91780281], [87.25208282, 21.92097282], [87.23542786, 21.93374062], [87.23223114, 21.94036102], [87.23232269, 21.94646263], [87.23500061, 21.95298958], [87.23484802, 21.95438004], [87.22873688, 21.95607948], [87.22561646, 21.9571209], [87.22440338, 21.95401955], [87.22323608, 21.95323181], [87.22119141, 21.95321083], [87.20957184, 21.95737076], [87.20291138, 21.95643997], [87.19510651, 21.95356941], [87.18837738, 21.95701027], [87.17497253, 21.96619987], [87.17085266, 21.97261047], [87.16744232, 21.97340965], [87.16520691, 21.96751022], [87.16056061, 21.96244049], [87.16127777, 21.95389938], [87.15976715, 21.94908142], [87.15989685, 21.93392944], [87.15828705, 21.93054962], [87.15641785, 21.9289093], [87.15168762, 21.9279995], [87.14782715, 21.92592812], [87.14112854, 21.91969109], [87.1367569, 21.91797066], [87.13091278, 21.91801071], [87.12351227, 21.92024994], [87.11618042, 21.92064095], [87.11424255, 21.92217064], [87.11255646, 21.92115021], [87.1103363, 21.91802025], [87.10785675, 21.91741943], [87.10468292, 21.91781998], [87.10180664, 21.91608047], [87.09955597, 21.91098022], [87.09353638, 21.90789986], [87.09101868, 21.89923096], [87.08876801, 21.89812088], [87.08853912, 21.89507294], [87.0894165, 21.89240074], [87.09314728, 21.88986969], [87.09612274, 21.88624954], [87.09626007, 21.88210106], [87.0929184, 21.87420273], [87.09464264, 21.86034012], [87.0777359, 21.85980034], [87.06210327, 21.86018944], [87.05377197, 21.86094284], [87.03024292, 21.86531067], [87.02511597, 21.87034988], [87.01996613, 21.88574982], [87.0167923, 21.88722992], [87.01478577, 21.88968277], [87.00483704, 21.8955307], [87.00125885, 21.90584183], [86.99793243, 21.90750122], [87.00061035, 21.91438103], [86.99939728, 21.91814041], [87.0025177, 21.92235947], [87.00408173, 21.9354229], [87.00554657, 21.94065094], [87.01490021, 21.95326042], [87.02030945, 21.96836281], [87.03085327, 21.97883987], [87.03224182, 21.98610115], [87.03431702, 21.98919106], [87.0319519, 21.99567032], [87.02796936, 21.99842262], [87.02500916, 22.00395012], [87.02226257, 22.0120697], [87.02350616, 22.02102089], [87.02604675, 22.02874947], [87.02469635, 22.03269005], [87.01761627, 22.04128075], [87.0094223, 22.04148102], [87.00470734, 22.04278946], [87.00093079, 22.04500008], [86.99517822, 22.04579926], [86.99048615, 22.04938126], [86.98754883, 22.05507278], [86.97190857, 22.06627083], [86.97046661, 22.07399178], [86.96705627, 22.07775116], [86.95723724, 22.0833683], [86.95197296, 22.08134079], [86.94426727, 22.08197975], [86.93203735, 22.08584976], [86.92901611, 22.08453941], [86.92225647, 22.08576012], [86.90876007, 22.08638], [86.84790039, 22.09835052], [86.84603119, 22.09514999], [86.84169006, 22.09180069], [86.83200836, 22.09510994], [86.83132935, 22.10069084], [86.82540131, 22.10863113], [86.82331085, 22.11292076], [86.8208313, 22.11362076], [86.81484985, 22.11244011], [86.81217194, 22.11367035], [86.80621338, 22.11416054], [86.80438232, 22.11707115], [86.80796814, 22.12382126], [86.806633, 22.12536049], [86.80396271, 22.12613106], [86.79785919, 22.12528038], [86.79709625, 22.12613106], [86.79984283, 22.12848091], [86.80047607, 22.1304512], [86.799263, 22.13908958], [86.80045319, 22.1459198], [86.79032135, 22.1539402], [86.78681183, 22.15372276], [86.78283691, 22.15014076], [86.77694702, 22.1490097], [86.77153778, 22.14678001], [86.75670624, 22.14519119], [86.75222015, 22.14396095], [86.73953247, 22.14508247], [86.73233795, 22.14491081], [86.72280884, 22.14274025], [86.71544647, 22.14349174], [86.71520996, 22.15872002], [86.71689606, 22.16376114], [86.71534729, 22.17440987], [86.71277618, 22.17828941], [86.71335602, 22.18135262], [86.71721649, 22.18556976], [86.71607208, 22.19379997], [86.71766663, 22.19792938], [86.71996307, 22.21018982], [86.72278595, 22.21524811], [86.72534943, 22.21350098], [86.73375702, 22.21121979], [86.74106598, 22.21080971], [86.74780273, 22.20798111], [86.75509644, 22.20798111], [86.76703644, 22.21134186], [86.76992035, 22.21455002], [86.77522278, 22.21462822], [86.77455902, 22.2233696], [86.77207184, 22.22768021], [86.77275085, 22.23034286], [86.77588654, 22.23154068], [86.77996826, 22.23172188], [86.78681946, 22.2293396], [86.79220581, 22.22384262], [86.79115295, 22.22030067], [86.78250122, 22.22536278], [86.77892303, 22.22171974], [86.77601624, 22.21377945], [86.77906036, 22.21152115], [86.78356934, 22.21165085], [86.78594208, 22.21405029], [86.79136658, 22.21754074], [86.80011749, 22.21363068], [86.8091507, 22.2331028], [86.80986786, 22.23800278], [86.80137634, 22.23863029], [86.7995224, 22.23518944], [86.79756165, 22.23394966], [86.79283142, 22.23872948], [86.79316711, 22.24398994], [86.79068756, 22.25323105], [86.79026794, 22.26280022], [86.80062866, 22.26192284], [86.79641724, 22.24991035], [86.79846191, 22.24544907], [86.79650879, 22.24508095], [86.79691315, 22.24306107], [86.79960632, 22.24097252], [86.80242157, 22.24180984], [86.80394745, 22.24397087], [86.80660248, 22.24378014], [86.80744171, 22.24582291], [86.80895233, 22.2464695], [86.80996704, 22.24954987], [86.80919647, 22.25379944], [86.8113327, 22.25948143], [86.81186676, 22.26393127], [86.81256104, 22.25928116], [86.81382751, 22.2580204], [86.81633759, 22.2493], [86.81912231, 22.25354958], [86.82034302, 22.26061058], [86.82280731, 22.26132965], [86.82842255, 22.25922966], [86.83371735, 22.25959969], [86.83605194, 22.26078987], [86.84127045, 22.2571106], [86.85015106, 22.25926971], [86.85069275, 22.26049042], [86.85423279, 22.25678062], [86.85835266, 22.25443077], [86.86460876, 22.25348282], [86.86904907, 22.25464058], [86.87313843, 22.25447083], [86.88568115, 22.25212097], [86.88667297, 22.25900078], [86.88555908, 22.26342964], [86.88562775, 22.26890945], [86.88796234, 22.26958275], [86.88860321, 22.27569962], [86.88845062, 22.28141022], [86.88684845, 22.28668976], [86.88623047, 22.29412079], [86.88511658, 22.29670906], [86.88080597, 22.29640961], [86.87258911, 22.2987709], [86.87121582, 22.30266953], [86.86808014, 22.30458069], [86.86295319, 22.30381966], [86.84719086, 22.31315041], [86.84066772, 22.31381035], [86.8368988, 22.31675148], [86.82919312, 22.32459068], [86.82853699, 22.32949066], [86.83006287, 22.33839989], [86.82894135, 22.34150124], [86.83634186, 22.36087036], [86.84094238, 22.36902046], [86.83822632, 22.37861061], [86.84047699, 22.3842392], [86.84359741, 22.38764191], [86.8449173, 22.39232826], [86.84393311, 22.39606094], [86.83875275, 22.40135956], [86.83090973, 22.40637016], [86.81841278, 22.41230011], [86.8052597, 22.41649055], [86.78897858, 22.41825294], [86.77867889, 22.42149162], [86.76925659, 22.42158127], [86.76389313, 22.42288971], [86.76226044, 22.42523193], [86.75794983, 22.43565941], [86.75707245, 22.44244957], [86.75744629, 22.44638062], [86.7514801, 22.45067978], [86.74900055, 22.46033287], [86.74513245, 22.47053909], [86.7454071, 22.4756794], [86.74826813, 22.47866058], [86.75332642, 22.48011971], [86.76066589, 22.47891045], [86.76953125, 22.4759407], [86.77571106, 22.47730064], [86.78251648, 22.47735023], [86.7855072, 22.47665024], [86.78922272, 22.47451019], [86.79556274, 22.47968292], [86.79801178, 22.48398972], [86.797966, 22.48699188], [86.79701233, 22.48875809], [86.79296112, 22.49060059], [86.79096222, 22.49362946], [86.79860687, 22.49882126], [86.78962708, 22.50757027], [86.78930664, 22.50965118], [86.79177856, 22.51343918], [86.79139709, 22.51666069], [86.789711, 22.52038002], [86.7828064, 22.52437019], [86.78520966, 22.52931023], [86.78531647, 22.53244019], [86.78279114, 22.5357399], [86.78617096, 22.53741074], [86.78407288, 22.54424095], [86.77789307, 22.54541016], [86.77630615, 22.54700851], [86.77137756, 22.54583931], [86.77126312, 22.54831123], [86.76451874, 22.55063057], [86.76348114, 22.55252075], [86.76696014, 22.55603027], [86.76741791, 22.56088829], [86.76344299, 22.5646286], [86.7599411, 22.57242966], [86.75598907, 22.57427025], [86.72767639, 22.57463837], [86.70601654, 22.58036041], [86.68340302, 22.57676125], [86.67388916, 22.57349014], [86.67279816, 22.57238007], [86.66139984, 22.57443047], [86.65727997, 22.57270813], [86.65170288, 22.57579041], [86.64932251, 22.58204079], [86.65109253, 22.58426285], [86.64827728, 22.59160995], [86.63897705, 22.59375], [86.63432312, 22.59725952], [86.63400269, 22.60401154], [86.63239288, 22.60997963], [86.63510132, 22.62265968], [86.6367569, 22.63081932], [86.63548279, 22.64719963], [86.63668823, 22.65512085], [86.63037872, 22.66250992], [86.62236786, 22.66631126], [86.61786652, 22.67338943], [86.61016083, 22.67741966], [86.6029129, 22.67983055], [86.59670258, 22.68544006], [86.59121704, 22.68864059], [86.58078003, 22.68899155], [86.57401276, 22.69463921], [86.55510712, 22.70788002], [86.5495224, 22.7109108], [86.54634857, 22.71528816], [86.53925323, 22.72064972], [86.53369904, 22.71657944], [86.52017975, 22.71790123], [86.51644897, 22.71478081], [86.50995636, 22.71606064], [86.50805664, 22.70816994], [86.50955963, 22.70226288], [86.5065918, 22.70152092], [86.50035858, 22.7110405], [86.49653625, 22.7154808], [86.48993683, 22.71981049], [86.48774719, 22.72328949], [86.48162079, 22.72474098], [86.47898102, 22.72239113], [86.47001648, 22.73740768], [86.46666718, 22.74023056], [86.46604156, 22.74645042], [86.45401001, 22.75963974], [86.4438858, 22.7585907], [86.43982697, 22.76268005], [86.42887115, 22.76843071], [86.42198944, 22.7741909], [86.41615295, 22.77650833], [86.4126358, 22.78643036], [86.41796875, 22.78981972], [86.42159271, 22.80882072], [86.43390656, 22.82859039], [86.43300629, 22.83533287], [86.43321991, 22.84058952], [86.43126678, 22.84638023], [86.43283844, 22.8604908], [86.44687653, 22.85877991], [86.44769287, 22.86173058], [86.44667053, 22.86944962], [86.44928741, 22.87705994], [86.44696045, 22.8834095], [86.45101929, 22.88297081], [86.46304321, 22.89663124], [86.46234894, 22.89898109], [86.44845581, 22.90192032], [86.43241882, 22.91576958], [86.43113708, 22.92013931], [86.43282318, 22.92340279], [86.43708801, 22.92728996], [86.45104218, 22.93046951], [86.45820618, 22.93296051], [86.4580307, 22.93879128], [86.46206665, 22.94423103], [86.47012329, 22.94662285], [86.47042084, 22.94944954], [86.4743576, 22.94882965], [86.47344971, 22.94408035], [86.47872162, 22.9405899], [86.4838028, 22.93824959], [86.48452759, 22.9342804], [86.48680115, 22.93554115], [86.48943329, 22.94406128], [86.49246979, 22.94423103], [86.49401093, 22.94148827], [86.49577332, 22.94129181], [86.49772644, 22.94512939], [86.49662018, 22.94754028], [86.49868774, 22.94774055], [86.50757599, 22.94535828], [86.51272583, 22.94619179], [86.51835632, 22.94433022], [86.52339172, 22.94868088], [86.52757263, 22.95792961], [86.52662659, 22.96087074], [86.53244781, 22.96223259], [86.53851318, 22.96186829], [86.53774261, 22.96583939], [86.54203033, 22.97434044], [86.5402832, 22.9872303], [86.5341568, 22.98135948], [86.52076721, 22.97282982], [86.52271271, 22.97215843], [86.51876068, 22.96811295], [86.51223755, 22.96626091], [86.49991608, 22.96854019], [86.50762177, 22.97277069], [86.50401306, 22.97801971], [86.49730682, 22.98314857], [86.4973526, 22.98990822], [86.47936249, 22.98884964], [86.4749527, 22.98566055], [86.46618652, 22.98863029], [86.46308899, 22.98521805], [86.45108795, 22.98760986], [86.44779205, 22.9871006], [86.44522858, 22.98509026], [86.44168854, 22.98732948], [86.44056702, 22.99007988], [86.43170166, 22.99032974], [86.41628265, 22.99479103], [86.41052246, 22.98701859], [86.4003067, 22.98314095], [86.3968811, 22.97781944], [86.39303589, 22.97423935], [86.38730621, 22.97673035], [86.38360596, 22.98013115], [86.38096619, 22.98441124], [86.38044739, 22.99074936], [86.36949921, 22.99431038], [86.3632431, 22.99274826], [86.35997772, 22.99668121], [86.35160828, 22.99491119], [86.35048676, 22.98917961], [86.34648895, 22.9930191], [86.34133148, 22.99328041], [86.3347168, 22.98935127], [86.33215332, 22.98890114], [86.32585907, 22.9924202], [86.31529236, 22.99555969], [86.31217957, 22.99521065], [86.30989075, 22.9981308], [86.30992889, 23.00065041], [86.3059082, 23.00248909], [86.30211639, 23.00335121], [86.30020142, 23.00630188], [86.30042267, 23.00831985], [86.30069733, 23.01035118], [86.30030823, 23.01234055], [86.29825592, 23.01328278], [86.29751587, 23.01325989], [86.29638672, 23.0102005], [86.29482269, 23.00914192], [86.29400635, 23.00811005], [86.29191589, 23.00905037], [86.29199219, 23.0100708], [86.28475952, 23.01086044], [86.27937317, 23.0107193], [86.27552032, 23.00860023], [86.27350616, 23.00653076], [86.26972198, 23.00443077], [86.26500702, 23.00040054], [86.26328278, 22.99936104], [86.26378632, 22.99802971], [86.2612915, 22.99553108], [86.25086212, 22.99497986], [86.24508667, 22.99546051], [86.2386322, 22.99488831], [86.23448181, 22.99336815], [86.23095703, 22.99214172], [86.22706604, 22.99287033], [86.21697235, 22.99160957], [86.21247864, 22.9918499], [86.20642853, 22.99407005], [86.20381165, 22.99785805], [86.20024109, 23.00974846], [86.20436096, 23.0132103], [86.2008667, 23.01514244], [86.18118286, 23.01296043], [86.17838287, 23.01172066], [86.17562866, 23.01299095], [86.17249298, 23.02305031], [86.1667099, 23.02695084], [86.162323, 23.03380966], [86.16015625, 23.03906059], [86.15365601, 23.03722954], [86.15001678, 23.04089928], [86.14833069, 23.05266953], [86.14604187, 23.05572128], [86.1381073, 23.05932999], [86.13456726, 23.0629406], [86.13363647, 23.06990051], [86.13803864, 23.08048058], [86.13656616, 23.08310127], [86.12864685, 23.0857296], [86.12735748, 23.08908081], [86.11569214, 23.09363174], [86.11418152, 23.09196091], [86.10640717, 23.09028816], [86.10476685, 23.08889961], [86.09710693, 23.09166908], [86.09179688, 23.09077072], [86.08358765, 23.09859085], [86.08322144, 23.10093117], [86.08096313, 23.10429955], [86.07000732, 23.1014328], [86.05928802, 23.1055603], [86.047966, 23.10868073], [86.04424286, 23.11186028], [86.04653931, 23.12068748], [86.04897308, 23.12484932], [86.04839325, 23.12916946], [86.04199219, 23.13596916], [86.03692627, 23.14361], [86.03227234, 23.1450901], [86.02835846, 23.1457119], [86.0247879, 23.14319992], [86.01799774, 23.14048958], [86.01389313, 23.14164162], [86.00971985, 23.14497948], [86.00609589, 23.14490128], [86.00258636, 23.14616966], [85.99555969, 23.14442062], [85.99006653, 23.14628029], [85.98194122, 23.14590073], [85.97048187, 23.14002991], [85.9593277, 23.13977242], [85.95629883, 23.13947105], [85.95155334, 23.13816071], [85.94790649, 23.13396072], [85.9467392, 23.13088036], [85.94380951, 23.12947083], [85.93628693, 23.1296711], [85.92581177, 23.13065147], [85.92202759, 23.12939835], [85.92147064, 23.12593079], [85.91957092, 23.12695122], [85.91781616, 23.1311512], [85.91499329, 23.12952995], [85.91160583, 23.13358116], [85.90673828, 23.14207077], [85.900383, 23.1480999], [85.88916016, 23.1517601], [85.88640594, 23.15335083], [85.87731171, 23.15866089], [85.87657928, 23.16127968], [85.87780762, 23.17101288], [85.87721252, 23.17296028], [85.85984802, 23.19239044], [85.85752106, 23.19436264], [85.85192108, 23.19255066], [85.84391022, 23.19412994], [85.83500671, 23.19210052], [85.83241272, 23.1926403], [85.83155823, 23.19511986], [85.83371735, 23.20190048], [85.83281708, 23.20614052], [85.83072662, 23.21063995], [85.83068848, 23.21397018], [85.83184052, 23.21783066], [85.83067322, 23.24323082], [85.82636261, 23.26312065], [85.83365631, 23.2806797], [85.83912659, 23.2820797], [85.84173584, 23.28432083], [85.84446716, 23.28956985], [85.85240936, 23.2944603], [85.85785675, 23.3010807], [85.86149597, 23.30332947], [85.86077118, 23.31497955], [85.86830139, 23.31587982], [85.87523651, 23.32067108], [85.87798309, 23.32370949], [85.87751007, 23.32625961], [85.87535095, 23.32874107], [85.87159729, 23.33015823], [85.8708725, 23.35251999], [85.87277985, 23.35527992], [85.87301636, 23.35689926], [85.8666687, 23.36148071], [85.86625671, 23.36484909], [85.87503052, 23.36828041], [85.88527679, 23.37375832], [85.89337921, 23.36953926], [85.89569092, 23.37059021], [85.89585876, 23.37697983], [85.89434814, 23.37968063], [85.89057922, 23.38103294], [85.88247681, 23.3810997], [85.88212585, 23.38371086], [85.88478088, 23.38734055], [85.87731171, 23.40043068], [85.8782959, 23.4021492], [85.8817215, 23.40372086], [85.87845612, 23.40802956], [85.87419891, 23.41050911], [85.8722229, 23.40853119], [85.86287689, 23.40997124], [85.86089325, 23.42818069], [85.85975647, 23.44161987], [85.85954285, 23.45095062], [85.86206055, 23.45496941], [85.86354828, 23.45948982], [85.86602783, 23.4702301], [85.87007904, 23.47480011], [85.87412262, 23.47623062], [85.87757874, 23.4758606], [85.89125061, 23.47598076], [85.90637207, 23.47175026], [85.91269684, 23.46729851], [85.91752625, 23.46235085], [85.9379425, 23.45513916], [85.94390869, 23.45462036], [85.94979858, 23.45545006], [85.95289612, 23.45962906], [85.95717621, 23.46193123], [85.96781921, 23.46537018], [85.97566223, 23.47072983], [85.99037933, 23.47637939], [85.99475098, 23.47553253], [86.00137329, 23.47879982], [86.00557709, 23.48269081], [86.01023102, 23.48315048], [86.01545715, 23.48516083], [86.02037048, 23.48791122], [86.02559662, 23.48808098], [86.02906799, 23.48715973], [86.03575134, 23.49032021], [86.04136658, 23.49024963], [86.04722595, 23.49364281], [86.05150604, 23.49900055], [86.0508728, 23.50155067], [86.04860687, 23.5026207], [86.03276825, 23.50484085], [86.03269196, 23.51802254], [86.03156281, 23.52096748], [86.02703857, 23.52425003], [86.02506256, 23.53174973], [86.01854706, 23.54243088], [86.02110291, 23.54549026], [86.01077271, 23.55164909], [86.01100922, 23.56124115], [86.01760864, 23.56361008], [86.02511597, 23.57229805], [86.03009796, 23.57476044], [86.03533936, 23.57509041], [86.0373764, 23.58345985], [86.04686737, 23.58386993], [86.05133057, 23.57889938], [86.06530762, 23.58073044], [86.07144165, 23.57847977], [86.07276917, 23.56822014], [86.08268738, 23.56857109], [86.08795929, 23.5676403], [86.09358215, 23.57001114], [86.09835815, 23.570961], [86.10154724, 23.57389832], [86.10485077, 23.57196045], [86.1102066, 23.57073021], [86.11943817, 23.57391167], [86.1266861, 23.56674957], [86.13172913, 23.56623077], [86.13607025, 23.56926918], [86.13861084, 23.57002068], [86.14476776, 23.56777191], [86.14819336, 23.56542015], [86.14842987, 23.56393051], [86.14628601, 23.55866051], [86.14846802, 23.55550957], [86.15326691, 23.55159187], [86.15273285, 23.5482502], [86.14969635, 23.54117966], [86.14427948, 23.53524017], [86.14292908, 23.52734184], [86.15455627, 23.51914978], [86.15328979, 23.50975037], [86.15511322, 23.5042305], [86.14517975, 23.49398994], [86.14585876, 23.48612976], [86.14331055, 23.4812603], [86.14267731, 23.47733116], [86.1455307, 23.47307014], [86.15296173, 23.47698975], [86.16792297, 23.47608948], [86.17233276, 23.47854042], [86.17914581, 23.47512054], [86.1787796, 23.46772957], [86.18102264, 23.46692085], [86.18676758, 23.46837044], [86.19180298, 23.46442032], [86.19536591, 23.46347046], [86.19956207, 23.46404839], [86.20326233, 23.45868111], [86.20970917, 23.45923042], [86.22097778, 23.4559803], [86.22406006, 23.4572506], [86.22319794, 23.46480751], [86.22532654, 23.46988106], [86.23226929, 23.47072029], [86.23874664, 23.46969032], [86.23517609, 23.45598984], [86.22735596, 23.44960976], [86.22502136, 23.4428196], [86.22466278, 23.43568039], [86.23110962, 23.42951965], [86.23954773, 23.43168068], [86.2390976, 23.42571068], [86.23989105, 23.42258072], [86.24317932, 23.41958046], [86.24646759, 23.41918945], [86.25083923, 23.42221069], [86.25305176, 23.42485046], [86.24794769, 23.43083954], [86.2466507, 23.4341526], [86.25006104, 23.43559074], [86.25244141, 23.43749046], [86.25784302, 23.43821907], [86.26374817, 23.43657112], [86.26629639, 23.43795967], [86.26719666, 23.44000053], [86.27348328, 23.43894958], [86.2784729, 23.44112015], [86.2806778, 23.43960953], [86.28115082, 23.43544769], [86.28237152, 23.42745972], [86.28967285, 23.42287064], [86.30000305, 23.42006111], [86.3133316, 23.42606163], [86.3142395, 23.42828941], [86.31286621, 23.43143082], [86.31227875, 23.43732071], [86.30998993, 23.43761063], [86.30578613, 23.43618011], [86.30034637, 23.4406395], [86.30014801, 23.44371033], [86.30647278, 23.44820976], [86.31208801, 23.44860077], [86.31511688, 23.45267105], [86.3212204, 23.45448112], [86.32621002, 23.45756149], [86.32863617, 23.45498085], [86.32926941, 23.44824028], [86.33135986, 23.44724083], [86.34041595, 23.45239258], [86.33834076, 23.45697975], [86.33789825, 23.46109009], [86.34703827, 23.46116257], [86.35183716, 23.46363068], [86.35222626, 23.46819115], [86.34897614, 23.47249985], [86.35549927, 23.48155975], [86.36440277, 23.48214912], [86.36850739, 23.48396111], [86.37052155, 23.48163986], [86.37194824, 23.48266029], [86.37214661, 23.48607826], [86.37059784, 23.49026108], [86.36205292, 23.49188995], [86.3585968, 23.48958969], [86.35370636, 23.49641991], [86.35706329, 23.51025009], [86.35690308, 23.51288986], [86.36503601, 23.51543808], [86.36701202, 23.51885986], [86.36765289, 23.52255821], [86.36495209, 23.52548981], [86.36383057, 23.52807045], [86.35965729, 23.53067017], [86.3587265, 23.53363991], [86.36048126, 23.53848076], [86.35797119, 23.5430603], [86.36048126, 23.54612923], [86.36160278, 23.54966164], [86.36422729, 23.55134964], [86.36480713, 23.55705261], [86.36789703, 23.55920982], [86.37304688, 23.5613308], [86.37486267, 23.56851959], [86.37812042, 23.56883812], [86.38288116, 23.57201958], [86.38176727, 23.57550049], [86.38220215, 23.5789299], [86.38092804, 23.58436012], [86.38697052, 23.58535957], [86.38941956, 23.58877945], [86.40019226, 23.58945274], [86.40622711, 23.58798027], [86.41036987, 23.59802246], [86.41356659, 23.60133171], [86.41821289, 23.60341263], [86.42466736, 23.60491943], [86.42727661, 23.61033058], [86.43045807, 23.61111069], [86.43456268, 23.60845184], [86.43963623, 23.60910034], [86.43959808, 23.61667252], [86.43791962, 23.62417984], [86.43847656, 23.62779236], [86.43988037, 23.62961006], [86.44490814, 23.63153267], [86.46642303, 23.6296196], [86.47162628, 23.6312809], [86.48129272, 23.63503838], [86.50171661, 23.63157845], [86.51187897, 23.62906075], [86.5236969, 23.62836075], [86.52865601, 23.62898064], [86.53743744, 23.63462067], [86.55201721, 23.64009285], [86.56524658, 23.64627075], [86.58310699, 23.65884018], [86.59062195, 23.66224098], [86.58850861, 23.66544151], [86.58796692, 23.66908073], [86.59160614, 23.67115021], [86.61580658, 23.6716404], [86.62444305, 23.67276955], [86.63334656, 23.6757412], [86.64884949, 23.68287086], [86.66873169, 23.68605042], [86.68334961, 23.68974113], [86.69384766, 23.69452095], [86.71100616, 23.69722939], [86.73169708, 23.69379044], [86.73654938, 23.68876076], [86.73591614, 23.6790905], [86.73812866, 23.6776104], [86.75850677, 23.67848015], [86.77269745, 23.68188095], [86.79203796, 23.6873703], [86.79567719, 23.69347954], [86.79305267, 23.69502258], [86.79093933, 23.69849968], [86.79351044, 23.70601273], [86.79837036, 23.71634102], [86.80451202, 23.73985291], [86.80800629, 23.74381065], [86.81163025, 23.74480057], [86.81610107, 23.74483109], [86.81933594, 23.75226974], [86.81977081, 23.76107025], [86.81671906, 23.77614975], [86.80841064, 23.78827095], [86.79769135, 23.79771805], [86.80097198, 23.8133297], [86.79747009, 23.82403946], [86.79220581, 23.82726288], [86.79283905, 23.83138084], [86.79738617, 23.83186913], [86.80018616, 23.83263016], [86.80367279, 23.83068085], [86.80647278, 23.8281002], [86.80786896, 23.82455254], [86.80702209, 23.81814957], [86.80930328, 23.81413078], [86.813797, 23.81216049], [86.82077026, 23.81130981], [86.82591248, 23.81319809], [86.83500671, 23.81925964], [86.84442902, 23.82185173], [86.8544693, 23.83247757], [86.85704803, 23.83950043], [86.86084747, 23.84217262], [86.87121582, 23.84418106], [86.87309265, 23.83448029], [86.87329102, 23.82723045], [86.87693024, 23.82133102], [86.87693024, 23.81344986], [86.88226318, 23.81447983], [86.88437653, 23.81920052], [86.88768768, 23.82216072], [86.88690948, 23.82732964], [86.88474274, 23.83049011], [86.88478851, 23.83436966], [86.88017273, 23.84220123], [86.88226318, 23.85661125], [86.8753891, 23.85745049], [86.87526703, 23.86238098], [86.88008881, 23.86650085], [86.88461304, 23.87335014], [86.89138031, 23.87639046], [86.8950119, 23.87995148], [86.90365601, 23.8789711], [86.90688324, 23.87951088], [86.92415619, 23.86588097], [86.92540741, 23.85384178], [86.92813873, 23.84995842], [86.93637848, 23.84486008], [86.94319916, 23.84286118], [86.95123291, 23.84587097], [86.95575714, 23.84961128], [86.95771027, 23.85913086], [86.95957184, 23.86231041], [86.96304321, 23.8647728], [86.96691132, 23.86529922], [86.97187805, 23.86283112], [86.98013306, 23.85638046], [86.99455261, 23.85353088], [87.00205994, 23.85248947], [87.01345825, 23.8469429], [87.02243042, 23.84052277], [87.03440857, 23.83682823], [87.0569458, 23.81625938], [87.06423187, 23.81349945], [87.07276917, 23.81233978], [87.07660675, 23.80911064], [87.0845108, 23.80526924], [87.08840179, 23.80780983], [87.09130096, 23.80961037], [87.09572601, 23.80948067], [87.10592651, 23.79952049], [87.10771179, 23.80187035], [87.11258698, 23.80553818], [87.1160965, 23.80480194], [87.11633301, 23.80196953], [87.1146698, 23.80008125], [87.11025238, 23.79906273], [87.11299896, 23.79681015], [87.12416077, 23.79503822], [87.13362885, 23.79634094], [87.13920593, 23.80006027], [87.14354706, 23.79636192], [87.14874268, 23.79437065], [87.15364838, 23.79845047], [87.15592957, 23.80372047], [87.16644287, 23.81958961], [87.16220856, 23.82761955], [87.15912628, 23.82830048], [87.15399933, 23.82574081], [87.14581299, 23.83661079], [87.13772583, 23.84580994], [87.13033295, 23.85091019], [87.12944031, 23.85490036], [87.12963104, 23.8581295], [87.12786102, 23.86244011], [87.13092804, 23.86696053], [87.13581848, 23.86813927], [87.13860321, 23.86740112], [87.14076996, 23.86510086], [87.14750671, 23.86268234], [87.1529007, 23.86559105], [87.1566925, 23.86488914], [87.16668701, 23.8604908], [87.16911316, 23.8577919], [87.17295074, 23.85622025], [87.17662048, 23.85246277], [87.18060303, 23.85153008], [87.18427277, 23.852911], [87.18736267, 23.85717964], [87.19565582, 23.85425949], [87.19541931, 23.8508606], [87.18869781, 23.84631157], [87.18856812, 23.84083748], [87.19164276, 23.84044266], [87.19433594, 23.84212112], [87.19944763, 23.84749985], [87.20302582, 23.84617233], [87.2073288, 23.85301018], [87.21282196, 23.85027122], [87.21675873, 23.85094261], [87.22248077, 23.85763931], [87.22782898, 23.85530281], [87.23623657, 23.85306931], [87.23513794, 23.84824181], [87.23174286, 23.84456062], [87.22796631, 23.84290123], [87.22410583, 23.84268951], [87.22235107, 23.83483124], [87.21855927, 23.83080101], [87.21975708, 23.82720947], [87.22912598, 23.82300949], [87.23375702, 23.82534981], [87.23880005, 23.82485008], [87.24272919, 23.82616043], [87.24572754, 23.82807159], [87.25521851, 23.83930016], [87.25270081, 23.84286118], [87.25152588, 23.84766006], [87.24742889, 23.85131073], [87.24608612, 23.85658073], [87.24904633, 23.86582947], [87.24487305, 23.86840057], [87.24442291, 23.87807846], [87.24530029, 23.88060951], [87.24311066, 23.8848629], [87.24608612, 23.89493942], [87.2443161, 23.90039063], [87.24822235, 23.90701103], [87.25242615, 23.91011047], [87.25666046, 23.90759277], [87.25920105, 23.90420151], [87.25987244, 23.90211105], [87.25630951, 23.89814949], [87.26088715, 23.89217949], [87.26412964, 23.87997055], [87.26174927, 23.87817192], [87.26493073, 23.87482834], [87.27041626, 23.87294006], [87.27832031, 23.88194847], [87.28129578, 23.88420105], [87.28552246, 23.88361168], [87.29258728, 23.89014053], [87.2906723, 23.89870071], [87.29454803, 23.89857101], [87.28768921, 23.92023087], [87.28782654, 23.9259491], [87.28513336, 23.93388939], [87.29193115, 23.93875122], [87.2904892, 23.94745255], [87.29181671, 23.95569992], [87.28666687, 23.95749092], [87.27805328, 23.95755959], [87.26925659, 23.96532059], [87.26452637, 23.9634819], [87.26154327, 23.96616936], [87.25953674, 23.96992111], [87.26072693, 23.97809029], [87.26602173, 23.9818306], [87.26802826, 23.98463058], [87.26692963, 23.98777962], [87.26206207, 23.99509048], [87.26271057, 23.99912071], [87.26081848, 24.00290108], [87.25718689, 23.99978065], [87.25640869, 23.99909019], [87.25621033, 23.99827003], [87.25595856, 23.99788094], [87.25565338, 23.99751091], [87.25531006, 23.99716949], [87.25493622, 23.99689102], [87.2545166, 23.99661064], [87.25408936, 23.99636078], [87.25363159, 23.99614906], [87.25311279, 23.99599075], [87.25260162, 23.99587059], [87.25208282, 23.99578094], [87.25157928, 23.99572754], [87.251091, 23.99571037], [87.25060272, 23.99572754], [87.25009918, 23.99578094], [87.24960327, 23.99587059], [87.24909973, 23.99599075], [87.24862671, 23.99612999], [87.24816132, 23.99632072], [87.24769592, 23.99653053], [87.24727631, 23.99677086], [87.24687195, 23.99702072], [87.24616241, 23.99765015], [87.24581146, 23.99802017], [87.24539948, 23.99855042], [87.24356842, 24.00101089], [87.24059296, 24.00572014], [87.24034882, 24.01066017], [87.23922729, 24.01478004], [87.23536682, 24.01754951], [87.23265076, 24.02459908], [87.23348236, 24.03268814], [87.23480225, 24.03731918], [87.23797607, 24.04121971], [87.24359894, 24.04211998], [87.2490387, 24.04012108], [87.25345612, 24.03734016], [87.2578125, 24.0354805], [87.26387024, 24.03469086], [87.26918793, 24.03301048], [87.27427673, 24.03184128], [87.27915955, 24.02935982], [87.28264618, 24.02692986], [87.28621674, 24.02717972], [87.28956604, 24.03030968], [87.29654694, 24.03016281], [87.30368042, 24.02937126], [87.30877686, 24.0319519], [87.31373596, 24.03239059], [87.31997681, 24.03144073], [87.32628632, 24.03013039], [87.33235931, 24.03100967], [87.33550262, 24.02386284], [87.33319092, 24.0222702], [87.3323288, 24.01753998], [87.32743073, 24.01662064], [87.32417297, 24.01748085], [87.32225037, 24.01316261], [87.32054138, 24.00927925], [87.31828308, 24.00687027], [87.31581116, 24.00708961], [87.31539154, 24.00442123], [87.31788635, 24.00152016], [87.31989288, 23.99917984], [87.32395935, 23.99706268], [87.32787323, 23.99599075], [87.3372879, 23.99495125], [87.34810638, 23.99579048], [87.3502121, 23.99697113], [87.35098267, 23.99920273], [87.35334778, 24.00225067], [87.35484314, 24.00559807], [87.35663605, 24.00918961], [87.36038971, 24.00734138], [87.36479187, 24.00677109], [87.37400818, 24.00657845], [87.37687683, 24.00317001], [87.38234711, 24.00270081], [87.38976288, 24.00196266], [87.39389038, 23.99924088], [87.39427185, 23.99653053], [87.4003067, 23.99392128], [87.41452789, 23.99084282], [87.4185791, 23.98935127], [87.42212677, 23.99080086], [87.42637634, 23.99032021], [87.42735291, 23.98792839], [87.42758942, 23.98397064], [87.4292984, 23.98186111], [87.43398285, 23.98168945], [87.43656158, 23.97915077], [87.43910217, 23.97813034], [87.44547272, 23.98146057], [87.44898224, 23.98429108], [87.45359802, 23.98339081], [87.45796967, 23.98142052], [87.45980072, 23.98483276], [87.45835876, 23.99349976], [87.45487976, 23.99689102], [87.45067596, 23.99924088], [87.45018768, 23.99999046], [87.44676971, 24.00062943], [87.44330597, 24.00094032], [87.44139862, 24.00323105], [87.44246674, 24.00530052], [87.44487762, 24.00576019], [87.44610596, 24.00696945], [87.44676971, 24.00835037], [87.44423676, 24.00909996], [87.44087219, 24.00946045], [87.43844604, 24.00904083], [87.43678284, 24.00781059], [87.43464661, 24.00686073], [87.43383026, 24.00832176], [87.43650055, 24.01094246], [87.43872833, 24.01251984], [87.44316101, 24.01375961], [87.44625092, 24.01428986], [87.44851685, 24.01634026], [87.45226288, 24.01506042], [87.45490265, 24.01496124], [87.45691681, 24.01406288], [87.45926666, 24.01297951], [87.46209717, 24.01311111], [87.46393585, 24.01262093], [87.46733856, 24.01217842], [87.46924591, 24.01156235], [87.4713974, 24.01089096], [87.47345734, 24.01143265], [87.47619629, 24.01301193], [87.47915649, 24.0141201], [87.48275757, 24.0136528], [87.48642731, 24.01595116], [87.48847961, 24.01933098], [87.4912262, 24.02337074], [87.49476624, 24.02435112], [87.49649048, 24.02316093], [87.5013504, 24.02232933], [87.50131226, 24.02609062], [87.50196075, 24.02815056], [87.50393677, 24.03009033], [87.50670624, 24.03199959], [87.5090332, 24.03467941], [87.51055145, 24.03983116], [87.50845337, 24.0425396], [87.50784302, 24.04566956], [87.5042572, 24.04618263], [87.50137329, 24.04751015], [87.49539185, 24.04997063], [87.4912262, 24.05202103], [87.49185181, 24.05553055], [87.49331665, 24.05924988], [87.49423218, 24.06265068], [87.49252319, 24.06470108], [87.49075317, 24.06657028], [87.48890686, 24.06966019], [87.48973083, 24.07323074], [87.49318695, 24.07473946], [87.49685669, 24.07369041], [87.49978638, 24.07254028], [87.50123596, 24.07331848], [87.50260162, 24.07526016], [87.50357056, 24.07766914], [87.50535583, 24.07942963], [87.50578308, 24.08208084], [87.50216675, 24.0832901], [87.4980011, 24.08435059], [87.49324036, 24.08460045], [87.49001312, 24.08546829], [87.48892212, 24.08819962], [87.48964691, 24.09004021], [87.49353027, 24.09309006], [87.49281311, 24.09547043], [87.49365234, 24.09724045], [87.49584961, 24.0971508], [87.49694824, 24.0993309], [87.49656677, 24.1026783], [87.49536896, 24.10547066], [87.49384308, 24.10815048], [87.49310303, 24.11193085], [87.49359894, 24.11520958], [87.49659729, 24.11580086], [87.49951172, 24.11458015], [87.50293732, 24.1128006], [87.50717926, 24.11128044], [87.51052856, 24.1103611], [87.51367188, 24.11082077], [87.516922, 24.11100006], [87.51889038, 24.10872078], [87.51991272, 24.1058712], [87.52130127, 24.10423088], [87.52406311, 24.10370827], [87.52693939, 24.10378075], [87.52986145, 24.10240936], [87.53069305, 24.09921074], [87.53096771, 24.09486961], [87.53449249, 24.09140968], [87.53916931, 24.08780098], [87.54419708, 24.0865612], [87.54825592, 24.08546066], [87.55261993, 24.0845108], [87.55628204, 24.08230972], [87.5597229, 24.08288956], [87.56344604, 24.08450127], [87.56672668, 24.08641052], [87.57021332, 24.08762169], [87.57316589, 24.0862999], [87.57615662, 24.08526039], [87.57644653, 24.08710098], [87.5743103, 24.09015083], [87.57064819, 24.09547043], [87.56949615, 24.10098076], [87.5692215, 24.10675049], [87.57211304, 24.10971069], [87.5748291, 24.1089592], [87.57779694, 24.11042023], [87.57965088, 24.11501122], [87.57952118, 24.11951065], [87.58172607, 24.12339973], [87.59262085, 24.12424088], [87.59541321, 24.12487984], [87.60041046, 24.12537003], [87.60481262, 24.12656975], [87.60761261, 24.12894249], [87.6049118, 24.1321106], [87.60119629, 24.13517952], [87.59794617, 24.1379509], [87.59391785, 24.14147949], [87.59004211, 24.14410019], [87.58602142, 24.14752007], [87.58087158, 24.15044022], [87.57646942, 24.15275955], [87.57142639, 24.15440941], [87.56938171, 24.15565109], [87.5766983, 24.15888023], [87.57975006, 24.16153908], [87.58407593, 24.16146088], [87.59037781, 24.1600914], [87.5955658, 24.15980911], [87.59957886, 24.16050911], [87.60415649, 24.16399956], [87.6104126, 24.16488075], [87.61605835, 24.1646595], [87.62166595, 24.16386986], [87.62754059, 24.16313171], [87.63162994, 24.16028976], [87.63632965, 24.15738106], [87.64067078, 24.15493011], [87.6457901, 24.15379906], [87.65054321, 24.15452957], [87.6569519, 24.15591049], [87.66361237, 24.15427971], [87.66777802, 24.15143967], [87.67353058, 24.15134048], [87.68016815, 24.14797974], [87.68435669, 24.14916992], [87.68956757, 24.1498394], [87.69248199, 24.15447044], [87.69364166, 24.15917015], [87.6932373, 24.16434097], [87.69645691, 24.16721153], [87.69641113, 24.17131042], [87.69667816, 24.17534828], [87.69378662, 24.1784687], [87.69399261, 24.18197823], [87.69255829, 24.18618011], [87.68891144, 24.18514061], [87.68353271, 24.18905258], [87.67830658, 24.19111061], [87.67460632, 24.1952095], [87.67378998, 24.20049095], [87.67095184, 24.20573807], [87.6661377, 24.20611191], [87.65901947, 24.20740128], [87.65278625, 24.20618248], [87.64509583, 24.20799065], [87.63772583, 24.21158028], [87.63844299, 24.21614075], [87.64151001, 24.21960068], [87.64315796, 24.22459984], [87.643013, 24.23010063], [87.63951874, 24.23472023], [87.63658142, 24.23818016], [87.63571167, 24.24253082], [87.64002991, 24.24603081], [87.64173126, 24.24986076], [87.64714813, 24.24855995], [87.64929962, 24.24662018], [87.64985657, 24.24365997], [87.6519165, 24.24015045], [87.65429688, 24.23658943], [87.65703583, 24.23539925], [87.6590271, 24.23835754], [87.66028595, 24.2419796], [87.66190338, 24.24495125], [87.6654129, 24.24349022], [87.66876984, 24.24274063], [87.67067719, 24.24427986], [87.67384338, 24.24670029], [87.67791748, 24.24645233], [87.68135834, 24.24644089], [87.68309784, 24.24855042], [87.68496704, 24.25284958], [87.6886673, 24.25560951], [87.69301605, 24.25739098], [87.69740295, 24.25972939], [87.70263672, 24.25992012], [87.70452881, 24.26375961], [87.70598602, 24.2678299], [87.70543671, 24.27170944], [87.70461273, 24.2745018], [87.70617676, 24.2781105], [87.70833588, 24.28038979], [87.7094574, 24.28290939], [87.71008301, 24.28657913], [87.71031952, 24.29207039], [87.71573639, 24.29001045], [87.71977234, 24.28803062], [87.72395325, 24.28749275], [87.72718811, 24.28622055], [87.73015594, 24.2876091], [87.73304749, 24.28791046], [87.73638153, 24.28894043], [87.73620605, 24.29199982], [87.74046326, 24.29272842], [87.74312592, 24.29772186], [87.7457428, 24.29980278], [87.74819946, 24.30148125], [87.75209808, 24.30465126], [87.75627899, 24.30359268], [87.75849915, 24.30783081], [87.76035309, 24.31303978], [87.75946045, 24.31688118], [87.76007843, 24.31952095], [87.76248169, 24.32068062], [87.76448059, 24.32279015], [87.76420593, 24.32522011], [87.76055908, 24.32817078], [87.7612381, 24.33331108], [87.76451874, 24.3385601], [87.7678833, 24.34045982], [87.76941681, 24.34539986], [87.77262878, 24.34938049], [87.77658844, 24.35341072], [87.77922821, 24.35705948], [87.78235626, 24.3602314], [87.78494263, 24.36763191], [87.78765106, 24.37166977], [87.78994751, 24.37701035], [87.79376984, 24.38076019], [87.79750824, 24.38218117], [87.7975769, 24.38606071], [87.79811096, 24.3907795], [87.7973175, 24.39229965], [87.79469299, 24.39217949], [87.79263306, 24.3930912], [87.79257965, 24.39644051], [87.79476929, 24.40007973], [87.79821014, 24.39973068], [87.8015213, 24.40192032], [87.80425262, 24.40354919], [87.80745697, 24.40435982], [87.81002045, 24.40662003], [87.80899048, 24.40923119], [87.80847931, 24.41213036], [87.80639648, 24.41472054], [87.80522156, 24.41814041], [87.80134583, 24.41341972], [87.79862976, 24.41122246], [87.79297638, 24.41063118], [87.78790283, 24.41152954], [87.78475189, 24.41454124], [87.78620911, 24.41862106], [87.79003143, 24.42167091], [87.79220581, 24.4238205], [87.79226685, 24.42687035], [87.79038239, 24.42939949], [87.7881012, 24.43209267], [87.78978729, 24.43465996], [87.79103851, 24.4377594], [87.79290009, 24.43980026], [87.79595184, 24.43939972], [87.79688263, 24.44186974], [87.79988098, 24.44371986], [87.79972076, 24.44544983], [87.80094147, 24.4473896], [87.80251312, 24.45014], [87.80687714, 24.45259857], [87.81125641, 24.4518795], [87.81494904, 24.45134926], [87.81524658, 24.45359993], [87.81614685, 24.45531273], [87.81735992, 24.4589901], [87.81772614, 24.46232033], [87.81659698, 24.46547127], [87.81784821, 24.46845055], [87.81478882, 24.47006035], [87.8137207, 24.47274017], [87.81138611, 24.47480965], [87.80909729, 24.47659111], [87.81035614, 24.48037148], [87.8130188, 24.48512077], [87.81685638, 24.48608017], [87.82025909, 24.48584938], [87.82099152, 24.48843002], [87.82145691, 24.49008942], [87.82244873, 24.49234009], [87.82287598, 24.49440956], [87.82190704, 24.49644089], [87.8197403, 24.49591064], [87.82022095, 24.49347115], [87.81867981, 24.49205971], [87.81555939, 24.4928093], [87.81225586, 24.4915905], [87.81021118, 24.49209023], [87.81001282, 24.49452972], [87.81111145, 24.49641991], [87.81178284, 24.49900055], [87.81021881, 24.50204086], [87.80831146, 24.50456047], [87.80734253, 24.50619125], [87.80758667, 24.5093708], [87.80667114, 24.51060104], [87.80526733, 24.50963974], [87.80391693, 24.50723076], [87.80374146, 24.50476074], [87.80342865, 24.50164032], [87.80298615, 24.49864006], [87.80101776, 24.49481964], [87.79853058, 24.49185944], [87.79515076, 24.49105072], [87.79380035, 24.49426079], [87.79260254, 24.49722862], [87.7939682, 24.50032043], [87.79823303, 24.50242996], [87.79994202, 24.50424957], [87.79850769, 24.50699997], [87.79850006, 24.50942993], [87.79972076, 24.51172066], [87.80116272, 24.51463127], [87.80121613, 24.51769066], [87.79901886, 24.52091026], [87.79756927, 24.52462959], [87.79712677, 24.53001022], [87.79798126, 24.53535843], [87.79749298, 24.53866959], [87.79985046, 24.54116058], [87.8035965, 24.54010963], [87.8057785, 24.54244041], [87.80634308, 24.54520035], [87.8048172, 24.54922104], [87.80261993, 24.55428123], [87.79936981, 24.55890083], [87.7961731, 24.56238174], [87.79158783, 24.56568909], [87.78572845, 24.56858063], [87.77774811, 24.57138062], [87.77317047, 24.57188034], [87.76757813, 24.57156944], [87.76792145, 24.57602119], [87.76940918, 24.58176041], [87.77966309, 24.58209038], [87.78536224, 24.5823307], [87.79067993, 24.58107948], [87.79505157, 24.57966995], [87.79889679, 24.57781029], [87.80224609, 24.57802963], [87.80500793, 24.57752037], [87.80899811, 24.576231], [87.81166077, 24.57444], [87.81420898, 24.57261276], [87.81685638, 24.57007027], [87.82015228, 24.5683918], [87.82327271, 24.56655121], [87.82388306, 24.56335258], [87.82450867, 24.55948257], [87.82698822, 24.55816078], [87.83480072, 24.55632973], [87.84111023, 24.55441093], [87.84497833, 24.55278015], [87.8482132, 24.55105019], [87.84996033, 24.5537281], [87.84921265, 24.5569191], [87.85047913, 24.55783272], [87.85378265, 24.55603027], [87.85632324, 24.55459023], [87.860466, 24.55526161], [87.86389923, 24.55657959], [87.86443329, 24.55870819], [87.86585999, 24.56083107], [87.86863708, 24.5612812], [87.87661743, 24.56108284], [87.8807373, 24.56295967], [87.88732147, 24.56270981], [87.88989258, 24.57191086], [87.89025879, 24.57472992], [87.89148712, 24.57962036], [87.89608765, 24.58062172], [87.89737701, 24.58245087], [87.89940643, 24.58357048], [87.90326691, 24.58238983], [87.90544891, 24.58380127], [87.90683746, 24.58735085], [87.90873718, 24.5911808], [87.90997314, 24.59386826], [87.90912628, 24.5963726], [87.90762329, 24.59939766], [87.90773773, 24.60436821], [87.9081192, 24.60817909], [87.90290833, 24.60804176], [87.8986969, 24.60807037], [87.89348602, 24.60834122], [87.88871002, 24.60820961], [87.88802338, 24.60532951], [87.88613129, 24.60514069], [87.88118744, 24.60696983], [87.87799835, 24.60944939], [87.87596893, 24.60885811], [87.87528992, 24.60990906], [87.87354279, 24.60931969], [87.8727417, 24.61071968], [87.87346649, 24.61347008], [87.87483215, 24.61552048], [87.87700653, 24.61629105], [87.87911224, 24.61475182], [87.88215637, 24.61359024], [87.88552094, 24.61178017], [87.88828278, 24.61133003], [87.89118195, 24.61219978], [87.89383698, 24.61296272], [87.89631653, 24.61186981], [87.89948273, 24.6114006], [87.90161133, 24.61258125], [87.90213013, 24.61650085], [87.90139008, 24.62002945], [87.90180206, 24.62257004], [87.90225983, 24.62592125], [87.89885712, 24.62574005], [87.89539337, 24.62449265], [87.89177704, 24.62368011], [87.887146, 24.62446976], [87.88461304, 24.62664986], [87.8868103, 24.62949944], [87.88886261, 24.63142014], [87.89227295, 24.63204956], [87.8968811, 24.6303997], [87.90000153, 24.62942123], [87.90200806, 24.62943077], [87.90428925, 24.63042068], [87.90629578, 24.63264275], [87.9076767, 24.63678169], [87.90796661, 24.64208984], [87.90785217, 24.64682961], [87.90886688, 24.65130997], [87.91013336, 24.65493011], [87.91340637, 24.6585598], [87.91159821, 24.66229057], [87.90647888, 24.66436005], [87.90319824, 24.66695976], [87.89990997, 24.6693306], [87.89507294, 24.66850281], [87.89038086, 24.67033005], [87.88661957, 24.67410278], [87.88625336, 24.67808914], [87.88941193, 24.68177986], [87.89274597, 24.68574905], [87.89656067, 24.69066048], [87.897789, 24.69497108], [87.8990097, 24.69968033], [87.8961792, 24.7024498], [87.89750671, 24.70647049], [87.89884949, 24.7098999], [87.90091705, 24.71050262], [87.90291595, 24.70993805], [87.90313721, 24.71190071], [87.9033432, 24.71455956], [87.90215302, 24.71849823], [87.90083313, 24.72159958], [87.89565277, 24.72302055], [87.89077759, 24.72258949], [87.8871994, 24.72544289], [87.88545227, 24.72929955], [87.88423157, 24.73347092], [87.88244629, 24.73627281], [87.8777771, 24.73908043], [87.87493896, 24.73508835], [87.87088013, 24.73002815], [87.86738586, 24.72940063], [87.86103821, 24.73125076], [87.85234833, 24.73493958], [87.83970642, 24.7381897], [87.82533264, 24.75221062], [87.82050323, 24.75206947], [87.81607819, 24.75204086], [87.81389618, 24.75336075], [87.81603241, 24.75960922], [87.81806183, 24.76598167], [87.82209015, 24.76671982], [87.82565308, 24.76931], [87.82785034, 24.77192116], [87.82836914, 24.77670288], [87.83001709, 24.78297043], [87.83368683, 24.78786087], [87.83753204, 24.78780174], [87.83847046, 24.78470993], [87.83899689, 24.78014183], [87.83687592, 24.77734947], [87.833992, 24.77464104], [87.83378601, 24.76968002], [87.83376312, 24.7658596], [87.83524323, 24.76323128], [87.83885956, 24.76536179], [87.84246826, 24.76285934], [87.84677887, 24.7610302], [87.85022736, 24.76127052], [87.85453796, 24.76431084], [87.8584671, 24.76781082], [87.85999298, 24.77200127], [87.86538696, 24.7743206], [87.86650848, 24.77614975], [87.86486053, 24.7785511], [87.86654663, 24.78244972], [87.86810303, 24.7870903], [87.87005615, 24.79087067], [87.87233734, 24.79193115], [87.87291718, 24.78977013], [87.87475586, 24.78980064], [87.87666321, 24.79368973], [87.87751007, 24.79800034], [87.87760925, 24.80101013], [87.87583923, 24.80311012], [87.87284851, 24.8052597], [87.87271881, 24.8075695], [87.87210846, 24.81186295], [87.87029266, 24.81524277], [87.8681488, 24.81811905], [87.86631012, 24.82074928], [87.86766815, 24.82298279], [87.86924744, 24.8234005], [87.87471771, 24.82271957], [87.88170624, 24.8203907], [87.88655853, 24.81966019], [87.89070892, 24.82287979], [87.8961792, 24.82259941], [87.89842224, 24.82452965], [87.89591217, 24.82756996], [87.89391327, 24.82917023], [87.8949585, 24.83389282], [87.89569092, 24.83959007], [87.89724731, 24.84174919], [87.89776611, 24.84278107], [87.89466858, 24.84775925], [87.89135742, 24.84815979], [87.88897705, 24.85293961], [87.89701843, 24.85435295], [87.91124725, 24.85593987], [87.92154694, 24.86024094], [87.92874146, 24.86588287], [87.93644714, 24.86961174], [87.94464111, 24.87267113], [87.9523468, 24.87685966], [87.96124268, 24.87905121], [87.96650696, 24.88129997], [87.96936798, 24.88512039], [87.97220612, 24.89142036], [87.9733429, 24.89648247], [87.97228241, 24.9033699], [87.97123718, 24.91003036], [87.97041321, 24.91607094], [87.9699707, 24.92358017], [87.9664917, 24.92959976], [87.96169281, 24.93593025], [87.95627594, 24.94141006], [87.9502182, 24.94534111], [87.94621277, 24.94889069], [87.93904877, 24.95573044], [87.930336, 24.96179962], [87.92444611, 24.96718025], [87.91851044, 24.9728508], [87.91352844, 24.97890282], [87.90648651, 24.98581123], [87.90336609, 24.99839973], [87.90242004, 24.99945068], [87.89292145, 25.00894928], [87.88082123, 25.02053833], [87.88117981, 25.02150917], [87.87697601, 25.02803993], [87.86434174, 25.03985023], [87.8550415, 25.04623985], [87.84262085, 25.05220032], [87.83493805, 25.05701828], [87.8201828, 25.06150055], [87.79989624, 25.07123947], [87.7928772, 25.07573128], [87.77986145, 25.08735085], [87.7765274, 25.09127045], [87.77266693, 25.09909821], [87.76983643, 25.11470985], [87.76928711, 25.12700081], [87.77120972, 25.138731], [87.77104187, 25.15227127], [87.77275085, 25.15961838], [87.77900696, 25.17692947], [87.7804718, 25.18527031], [87.78466797, 25.19960022], [87.78518677, 25.20907974], [87.7875824, 25.2204895], [87.80134583, 25.21824074], [87.81004333, 25.21173286], [87.82119751, 25.20808983], [87.82965851, 25.20405006], [87.83230591, 25.20078087], [87.83664703, 25.19926071], [87.83683777, 25.20310974], [87.83380127, 25.21336937], [87.82277679, 25.23434067], [87.82493591, 25.23655128], [87.83024597, 25.23966026], [87.83228302, 25.24464989], [87.83553314, 25.24981117], [87.84158325, 25.25358009], [87.84555054, 25.2522583], [87.84729004, 25.25225067], [87.84925079, 25.25342751], [87.85103607, 25.25796127], [87.8497467, 25.26148033], [87.84996796, 25.26728058], [87.85137939, 25.26906967], [87.85428619, 25.26791], [87.85652161, 25.2777729], [87.85616302, 25.28297043], [87.85501099, 25.2895298], [87.853302, 25.28936958], [87.85137939, 25.29249954], [87.85041046, 25.29743767], [87.84037018, 25.2983799], [87.83114624, 25.30216026], [87.82892609, 25.30342102], [87.82035065, 25.31282043], [87.8110733, 25.31916046], [87.80162811, 25.3234005], [87.79728699, 25.32208061], [87.79144287, 25.32233047], [87.78398132, 25.33242989], [87.78159332, 25.33839989], [87.78486633, 25.34460068], [87.78736115, 25.35486031], [87.78882599, 25.3722496], [87.77671814, 25.37084961], [87.77379608, 25.37195015], [87.76570129, 25.37799072], [87.76268768, 25.38623047], [87.76255798, 25.38899994], [87.76306915, 25.39561081], [87.76644897, 25.40353012], [87.76381683, 25.4048996], [87.75910187, 25.40504074], [87.75975037, 25.41008949], [87.76213837, 25.41206169], [87.76413727, 25.40897942], [87.76798248, 25.40876961], [87.76998138, 25.40983009], [87.77127075, 25.41155815], [87.77242279, 25.41491127], [87.77120209, 25.41852951], [87.76586151, 25.42429161], [87.77011108, 25.42876816], [87.77651215, 25.42897034], [87.7796402, 25.43659973], [87.78132629, 25.44465065], [87.78652191, 25.44869995], [87.79260254, 25.44561958], [87.7933197, 25.44219971], [87.79830933, 25.44186974], [87.80680084, 25.43477821], [87.80864716, 25.43419075], [87.81922913, 25.43753815], [87.82092285, 25.43977165], [87.82171631, 25.44302177], [87.82578278, 25.445261], [87.82496643, 25.44939041], [87.8273468, 25.45158958], [87.82559967, 25.45754051], [87.82769012, 25.45883179], [87.8338089, 25.45881081], [87.83381653, 25.46457291], [87.84955597, 25.46499062], [87.85067749, 25.46834946], [87.86347198, 25.46538925], [87.86428833, 25.46788979], [87.86390686, 25.47031975], [87.86052704, 25.47783089], [87.86086273, 25.48605156], [87.86348724, 25.49342918], [87.86872864, 25.49718285], [87.86988068, 25.50300026], [87.88136292, 25.50556946], [87.88047791, 25.51332092], [87.87921906, 25.51597023], [87.88532257, 25.51708984], [87.88815308, 25.5127697], [87.89501953, 25.5099411], [87.89585114, 25.50472069], [87.89898682, 25.50430107], [87.9005127, 25.50723076], [87.90480804, 25.50733948], [87.90271759, 25.51122093], [87.90631866, 25.51366806], [87.9030304, 25.5190506], [87.90815735, 25.52412033], [87.91374969, 25.52376938], [87.91456604, 25.52523041], [87.91440582, 25.5309391], [87.91609955, 25.53190994], [87.91963196, 25.53083992], [87.92411041, 25.53564835], [87.92604828, 25.53621292], [87.93354797, 25.5349617], [87.93804932, 25.53528976], [87.94287872, 25.53467751], [87.95239258, 25.53646088], [87.95561218, 25.5380497], [87.96408844, 25.53308105], [87.96914673, 25.52606964], [87.97225952, 25.5232296], [87.98603821, 25.52482986], [87.98764801, 25.52394104], [87.98819733, 25.52260017], [87.98780823, 25.52071953], [87.98055267, 25.51585007], [87.98496246, 25.50811005], [87.9866333, 25.50263023], [87.99276733, 25.49785042], [87.99835205, 25.49539948], [88.00424194, 25.49403954], [88.00300598, 25.49969101], [88.00377655, 25.50481987], [88.00747681, 25.51039124], [88.01167297, 25.50756073], [88.00792694, 25.50283051], [88.00994873, 25.50097084], [88.01573181, 25.50049973], [88.02028656, 25.4953804], [88.02868652, 25.4889698], [88.02754974, 25.4861412], [88.03122711, 25.48599052], [88.03450775, 25.49273109], [88.03862762, 25.49155807], [88.03660583, 25.48654175], [88.04213715, 25.48538971], [88.04633331, 25.4826107], [88.04933929, 25.48271942], [88.04947662, 25.48615074], [88.05296326, 25.48662949], [88.05580139, 25.483881], [88.06167603, 25.48558998], [88.06593323, 25.48115158], [88.07041168, 25.48050117], [88.06815338, 25.48984909], [88.06812286, 25.49679947], [88.06981659, 25.50188255], [88.07285309, 25.50390053], [88.07125854, 25.50488091], [88.06642914, 25.50503922], [88.0638504, 25.50617027], [88.06491089, 25.5085125], [88.06886292, 25.51304817], [88.06687927, 25.51642036], [88.05748749, 25.52567101], [88.05812073, 25.52870941], [88.05597687, 25.52993011], [88.0507431, 25.53051949], [88.04884338, 25.53333092], [88.04605103, 25.53433037], [88.04247284, 25.53206062], [88.03909302, 25.53318977], [88.0357132, 25.53672981], [88.03787994, 25.54618073], [88.0298233, 25.55039024], [88.0270462, 25.55327034], [88.03042603, 25.55754852], [88.02961731, 25.55948067], [88.03343964, 25.56145096], [88.03547668, 25.56038094], [88.03824615, 25.56388092], [88.03392792, 25.5659008], [88.02818298, 25.56631088], [88.02526855, 25.5690918], [88.03002167, 25.57434082], [88.02194214, 25.58292007], [88.02102661, 25.58692169], [88.02649689, 25.58590126], [88.03138733, 25.58749962], [88.03121948, 25.59101105], [88.03858948, 25.59504128], [88.03983307, 25.59736061], [88.03565216, 25.59698105], [88.03131104, 25.59826279], [88.02970123, 25.60003853], [88.03605652, 25.60240173], [88.04139709, 25.60549927], [88.03930664, 25.60848999], [88.04042816, 25.61046028], [88.0372467, 25.6155777], [88.03502655, 25.61705017], [88.03694153, 25.62200928], [88.03942871, 25.62730026], [88.04376984, 25.62822914], [88.04749298, 25.6276207], [88.0542984, 25.63286018], [88.04347992, 25.63207054], [88.04081726, 25.63611984], [88.03555298, 25.63683128], [88.03582001, 25.64097977], [88.04016113, 25.64191246], [88.04294586, 25.63899994], [88.04438782, 25.63965988], [88.044487, 25.64287949], [88.04614258, 25.64441109], [88.0473175, 25.64302254], [88.04853821, 25.64390945], [88.04537201, 25.64810944], [88.04397583, 25.65258026], [88.04876709, 25.65542984], [88.04888153, 25.6579895], [88.04538727, 25.65980148], [88.0431366, 25.67388916], [88.04467773, 25.67696953], [88.04910278, 25.68147087], [88.0508194, 25.68580055], [88.04862976, 25.69057083], [88.0451889, 25.69000053], [88.04332733, 25.69469261], [88.03985596, 25.69813919], [88.03475189, 25.69403076], [88.03219604, 25.69647026], [88.03016663, 25.69881058], [88.02677917, 25.6989212], [88.02239227, 25.6915226], [88.01615906, 25.69171906], [88.01434326, 25.6943512], [88.01431274, 25.69748116], [88.01751709, 25.70249939], [88.01667023, 25.70471191], [88.00676727, 25.70651054], [88.00196838, 25.70910072], [87.99717712, 25.71191025], [87.99256134, 25.71912956], [87.98770905, 25.72002029], [87.98779297, 25.72367096], [87.98184204, 25.72170067], [87.97966766, 25.71846008], [87.9716568, 25.72006989], [87.96099854, 25.72468185], [87.96199799, 25.72969818], [87.96047974, 25.73212051], [87.95665741, 25.73544121], [87.95102692, 25.73862076], [87.94415283, 25.74381256], [87.94386292, 25.74814034], [87.93862915, 25.74854088], [87.9420166, 25.75323105], [87.94164276, 25.75595093], [87.93752289, 25.75830078], [87.93734741, 25.76794052], [87.93239594, 25.77132034], [87.92919922, 25.77209091], [87.92862701, 25.76785088], [87.91866302, 25.77404022], [87.90497589, 25.77196121], [87.90125275, 25.76923943], [87.89846802, 25.76976013], [87.89774323, 25.77181053], [87.90094757, 25.78030968], [87.89800262, 25.79927063], [87.89919281, 25.8002491], [87.90159607, 25.80050087], [87.90305328, 25.80187035], [87.90188599, 25.80398941], [87.89907074, 25.80550194], [87.89501953, 25.80468941], [87.89672852, 25.81105995], [87.89927673, 25.81159019], [87.90119171, 25.81069946], [87.90203857, 25.81101036], [87.90200806, 25.81314087], [87.90313721, 25.81413078], [87.9076004, 25.80939293], [87.90947723, 25.81069183], [87.9105072, 25.8148098], [87.90445709, 25.81892014], [87.89874268, 25.82014084], [87.89385223, 25.8250618], [87.89795685, 25.82765007], [87.8964386, 25.82909012], [87.89379883, 25.82916069], [87.89096832, 25.82650948], [87.88433838, 25.82731056], [87.88339996, 25.82860947], [87.88764954, 25.83287048], [87.88935852, 25.83280182], [87.89261627, 25.8350811], [87.89530945, 25.83317947], [87.89742279, 25.83452034], [87.8973465, 25.83959961], [87.91091156, 25.85174942], [87.90483093, 25.85308838], [87.90138245, 25.85624123], [87.89945221, 25.85983086], [87.88481903, 25.86465263], [87.88121796, 25.85840988], [87.87874603, 25.85845947], [87.87223816, 25.85965919], [87.87068939, 25.86600113], [87.86766052, 25.86445045], [87.86528015, 25.8675518], [87.855896, 25.86473083], [87.85043335, 25.86707115], [87.84314728, 25.86871147], [87.83454132, 25.86874008], [87.82283783, 25.87146759], [87.81986237, 25.88097954], [87.81828308, 25.88148117], [87.81706238, 25.88334084], [87.81550598, 25.88554001], [87.81552124, 25.88796043], [87.81796265, 25.88845062], [87.82026672, 25.89376068], [87.81891632, 25.89715958], [87.81459045, 25.89884186], [87.81365967, 25.89995193], [87.81680298, 25.90487099], [87.81726074, 25.90918922], [87.81646729, 25.91270828], [87.81186676, 25.9131794], [87.81066132, 25.91399956], [87.80780029, 25.90899086], [87.80375671, 25.91214943], [87.80355835, 25.91394806], [87.80747986, 25.91583061], [87.80745697, 25.91827011], [87.80358124, 25.92072105], [87.80573273, 25.92843056], [87.80696106, 25.92991829], [87.81787109, 25.93301964], [87.82350922, 25.93135071], [87.82681274, 25.93185043], [87.82993317, 25.93545151], [87.82711029, 25.93778038], [87.82830811, 25.94111061], [87.82480621, 25.94366074], [87.82390594, 25.94645119], [87.82657623, 25.95004272], [87.82704926, 25.95358086], [87.82538605, 25.95872116], [87.83097839, 25.96223068], [87.83126068, 25.96409988], [87.82987976, 25.97187996], [87.82618713, 25.98368263], [87.82604218, 25.98831177], [87.82720184, 25.99234009], [87.83075714, 25.9921608], [87.83333588, 26.00109291], [87.84062195, 26.01976967], [87.83892822, 26.02287102], [87.84165192, 26.03230095], [87.84126282, 26.04120827], [87.84211731, 26.04448128], [87.84915161, 26.04496956], [87.86325073, 26.05610085], [87.87520599, 26.05557823], [87.87769318, 26.05791092], [87.87606049, 26.06619072], [87.88471985, 26.07151985], [87.88826752, 26.07193947], [87.88928223, 26.07509995], [87.89256287, 26.08035088], [87.89572906, 26.07987022], [87.91293335, 26.0909729], [87.91750336, 26.08801079], [87.91652679, 26.07969856], [87.92185974, 26.07687187], [87.92253876, 26.07180977], [87.93112946, 26.06895065], [87.93470001, 26.0705204], [87.93820953, 26.07676125], [87.93694305, 26.07975006], [87.93788147, 26.08446121], [87.94300842, 26.08469009], [87.95052338, 26.08304024], [87.9598465, 26.08403969], [87.96401215, 26.08325005], [87.96813202, 26.08136177], [87.97219086, 26.08485031], [87.97025299, 26.08735085], [87.96948242, 26.0916481], [87.96570587, 26.09192085], [87.96273041, 26.09472084], [87.95765686, 26.09708977], [87.95812988, 26.10085106], [87.95440674, 26.10279274], [87.95494843, 26.10568237], [87.95823669, 26.1088295], [87.96935272, 26.10931015], [87.97563171, 26.12162971], [87.96740723, 26.12537193], [87.95868683, 26.12569809], [87.95713043, 26.12886047], [87.9678421, 26.13183022], [87.97097015, 26.13714027], [87.96877289, 26.13935089], [87.96869659, 26.14787102], [87.96334076, 26.14888954], [87.96405792, 26.15197945], [87.96953583, 26.15440941], [87.97479248, 26.15286064], [87.98210907, 26.15917969], [87.98840332, 26.14861107], [87.99603271, 26.14179039], [87.99910736, 26.1403904], [88.00681305, 26.14328957], [88.01306915, 26.14087105], [88.01509094, 26.1429081], [88.01078033, 26.14929008], [88.01174164, 26.15479088], [88.01751709, 26.15555954], [88.02662659, 26.16279984], [88.02852631, 26.16728973], [88.03363037, 26.17028999], [88.03233337, 26.17351913], [88.03743744, 26.17770004], [88.04046631, 26.17681122], [88.04618073, 26.17788124], [88.04836273, 26.17464066], [88.05233002, 26.17167282], [88.05864716, 26.17375946], [88.06343079, 26.17667007], [88.06710052, 26.17762947], [88.06983185, 26.17571831], [88.07141876, 26.17879295], [88.0748291, 26.18128014], [88.07298279, 26.18539047], [88.08162689, 26.19235039], [88.08724213, 26.19444084], [88.08759308, 26.19797134], [88.08969116, 26.20323181], [88.09359741, 26.20653915], [88.09718323, 26.20643044], [88.10246277, 26.21224976], [88.10572815, 26.21640015], [88.10838318, 26.21705055], [88.11601257, 26.2229805], [88.11390686, 26.22397995], [88.11187744, 26.22620964], [88.11995697, 26.22794914], [88.12560272, 26.22789955], [88.12612915, 26.22691917], [88.13105011, 26.22681046], [88.13582611, 26.22821045], [88.13880157, 26.2308197], [88.13593292, 26.23715019], [88.13741302, 26.2437706], [88.14063263, 26.24572945], [88.14064789, 26.24963951], [88.14444733, 26.25279999], [88.15882874, 26.25691032], [88.16311646, 26.25753021], [88.16706085, 26.25720024], [88.17690277, 26.26172829], [88.1833725, 26.27468109], [88.1893692, 26.27510071], [88.19448853, 26.27412987], [88.20410156, 26.27959061], [88.21115875, 26.28000069], [88.21425629, 26.28168106], [88.21498108, 26.28493118], [88.21900177, 26.28567123], [88.22101593, 26.28821945], [88.22458649, 26.2894001], [88.22677612, 26.29664993], [88.22690582, 26.30397034], [88.23177338, 26.31035805], [88.23416138, 26.30668068], [88.2364502, 26.30540085], [88.23912811, 26.31319809], [88.24469757, 26.3162899], [88.24819946, 26.32653809], [88.25370789, 26.3277607], [88.25630951, 26.33011818], [88.25801086, 26.33423996], [88.26113129, 26.33785057], [88.26526642, 26.33649063], [88.26859283, 26.33700943], [88.26976013, 26.33268929], [88.27243805, 26.3305397], [88.27626038, 26.33249283], [88.27955627, 26.33553123], [88.28170013, 26.33980942], [88.27935028, 26.34634972], [88.28336334, 26.34930992], [88.28913879, 26.35113907], [88.29191589, 26.35391045], [88.28990173, 26.35691071], [88.2818985, 26.36013031], [88.27397919, 26.37728119], [88.26994324, 26.37887955], [88.26759338, 26.38116074], [88.26164246, 26.38002968], [88.25489807, 26.37446976], [88.25126648, 26.37585831], [88.24511719, 26.37599754], [88.24312592, 26.37409019], [88.23760986, 26.37537766], [88.23171234, 26.38490105], [88.22924805, 26.38985062], [88.23044586, 26.39396095], [88.23581696, 26.39616966], [88.25538635, 26.4158802], [88.26315308, 26.41501045], [88.26834869, 26.41792107], [88.26790619, 26.42175293], [88.26560974, 26.4233799], [88.26275635, 26.42808914], [88.25963593, 26.43066978], [88.25219727, 26.43379021], [88.24835205, 26.43880081], [88.24340057, 26.44930077], [88.23664856, 26.4493103], [88.23388672, 26.44625092], [88.22897339, 26.44715118], [88.22460175, 26.45574951], [88.21533966, 26.46573067], [88.22112274, 26.46684837], [88.22595978, 26.4720211], [88.22622681, 26.4762516], [88.21315765, 26.47777939], [88.21264648, 26.47458076], [88.21694183, 26.47265053], [88.21479034, 26.46973038], [88.1937561, 26.4720211], [88.19164276, 26.48307991], [88.18295288, 26.48526001], [88.18340302, 26.48839951], [88.179039, 26.49057961], [88.17920685, 26.49398041], [88.18634033, 26.50007057], [88.19386292, 26.50801086], [88.1998291, 26.51065063], [88.20635986, 26.51006126], [88.20665741, 26.51498032], [88.21865082, 26.52370071], [88.22582245, 26.52663994], [88.23336029, 26.53236961], [88.23114777, 26.53921127], [88.23120117, 26.55198288], [88.22180939, 26.55323029], [88.21539307, 26.55726814], [88.21389008, 26.55076981], [88.21922302, 26.54859161], [88.22080231, 26.54627991], [88.21689606, 26.54156113], [88.21235657, 26.54166985], [88.20966339, 26.54072189], [88.21109009, 26.53869057], [88.21534729, 26.53791046], [88.21456146, 26.53558922], [88.20742035, 26.5352211], [88.2049408, 26.53725052], [88.20405579, 26.53955078], [88.20149231, 26.53860092], [88.19924164, 26.53872108], [88.19898987, 26.54175186], [88.19668579, 26.54356003], [88.19050598, 26.54430962], [88.18573761, 26.54413986], [88.18242645, 26.5429306], [88.17913055, 26.53699112], [88.17962646, 26.53449059], [88.17868042, 26.53087044], [88.17382813, 26.53282928], [88.17063141, 26.53650284], [88.1682663, 26.53736115], [88.16602325, 26.53446007], [88.16538239, 26.52164078], [88.15744019, 26.51874161], [88.15506744, 26.51577187], [88.15090179, 26.51692009], [88.14769745, 26.51663971], [88.14539337, 26.51097107], [88.14129639, 26.51179123], [88.13765717, 26.51419258], [88.13217926, 26.51258087], [88.12354279, 26.52013969], [88.11514282, 26.53018951], [88.11030579, 26.53024101], [88.10819244, 26.5352211], [88.10614777, 26.53562355], [88.10621643, 26.53601456], [88.10504913, 26.53584862], [88.10547638, 26.53903961], [88.1054306, 26.53940773], [88.10649872, 26.53948402], [88.10860443, 26.54097176], [88.11408997, 26.54484558], [88.1139679, 26.54496765], [88.11009979, 26.5501709], [88.10871887, 26.55033493], [88.10798645, 26.55042076], [88.10797119, 26.55428696], [88.10798645, 26.56060982], [88.11032104, 26.56010056], [88.11185455, 26.55673218], [88.11594391, 26.55787659], [88.11608124, 26.55872154], [88.11618805, 26.55936813], [88.11320496, 26.56172943], [88.11326599, 26.56178093], [88.11768341, 26.5654583], [88.11681366, 26.56645203], [88.11569214, 26.56458664], [88.11531067, 26.56461906], [88.11420441, 26.56471252], [88.11517334, 26.5661869], [88.1139679, 26.56798553], [88.11594391, 26.57229233], [88.11660767, 26.57120895], [88.11730957, 26.57005501], [88.12151337, 26.56781578], [88.12016296, 26.57428169], [88.12339783, 26.5753994], [88.12551117, 26.57192039], [88.12774658, 26.57415581], [88.12559509, 26.57631302], [88.12551117, 26.57639313], [88.12799835, 26.57726288], [88.12805176, 26.57716942], [88.13098145, 26.57229233], [88.13191986, 26.5728302], [88.13272095, 26.57328606], [88.13248444, 26.57888985], [88.13246918, 26.57925415], [88.12985992, 26.58161354], [88.13272095, 26.58459473], [88.13239288, 26.58590889], [88.13209534, 26.58708191], [88.13431549, 26.59255791], [88.13446045, 26.59292221], [88.13431549, 26.5976162], [88.13365173, 26.5988636], [88.13250732, 26.60102844], [88.13821411, 26.60561562], [88.14179993, 26.60651779], [88.14464569, 26.62548256], [88.14663696, 26.62647629], [88.14677429, 26.62727547], [88.14688873, 26.62796783], [88.147995, 26.62835884], [88.15074158, 26.6293335], [88.15720367, 26.63020325], [88.15994263, 26.63255882], [88.16080475, 26.63567162], [88.16192627, 26.63598442], [88.16304016, 26.63629341], [88.16053009, 26.63976479], [88.1656189, 26.64574051], [88.16751099, 26.67001534], [88.16664124, 26.67819595], [88.17049408, 26.68364143], [88.16999817, 26.69892693], [88.17559052, 26.70775032], [88.17991638, 26.71071625], [88.18466187, 26.71918488], [88.18491364, 26.72713661], [88.18741608, 26.73061562], [88.18714142, 26.73400497], [88.18901062, 26.73819733], [88.18912506, 26.74006653], [88.1897583, 26.75062561], [88.18852997, 26.75650978], [88.18988037, 26.76019478], [88.19049835, 26.7714119], [88.18752289, 26.78281212], [88.18019104, 26.80331802], [88.18071747, 26.80846596], [88.18151855, 26.81621552], [88.1750946, 26.82568741], [88.17434692, 26.82902145], [88.17683411, 26.83314323], [88.17021942, 26.83711624], [88.17114258, 26.84150124], [88.17321777, 26.84481621], [88.17316437, 26.84487534], [88.17037201, 26.84693718], [88.1701889, 26.8481102], [88.16999817, 26.84929848], [88.17339325, 26.85099411], [88.17667389, 26.85397148], [88.17608643, 26.85513878], [88.17636108, 26.85625648], [88.17708588, 26.85923958], [88.1758194, 26.85960197], [88.17447662, 26.85998535], [88.17608643, 26.86520576], [88.17448425, 26.86890221], [88.17346954, 26.86917496], [88.16923523, 26.87022209], [88.16431427, 26.88061523], [88.16017914, 26.88272858], [88.15982056, 26.88381577], [88.15943909, 26.8849659], [88.15446472, 26.88521385], [88.15371704, 26.8842144], [88.1496582, 26.88819504], [88.14825439, 26.8890667], [88.14800262, 26.8898201], [88.14539337, 26.89093018], [88.14438629, 26.89365005], [88.14425659, 26.8937912], [88.13893127, 26.898386], [88.13911438, 26.8993187], [88.13930511, 26.90025139], [88.14181519, 26.90151596], [88.14143372, 26.9050045], [88.14685822, 26.91579628], [88.14711761, 26.91631508], [88.14663696, 26.91727638], [88.14862061, 26.92041588], [88.14849854, 26.92056656], [88.14001465, 26.93100357], [88.14129639, 26.93069839], [88.13980103, 26.93350792], [88.1348114, 26.93778992], [88.13345337, 26.93832207], [88.13134766, 26.93914795], [88.12301636, 26.9501152], [88.12574768, 26.9598217], [88.12451935, 26.96501541], [88.12590027, 26.96959114], [88.13321686, 26.98031616], [88.13748169, 26.98526764], [88.13742828, 26.98533058], [88.13669586, 26.98624802], [88.12650299, 26.98724174], [88.12581635, 26.98722649], [88.12078857, 26.98711777], [88.11813354, 26.98828697], [88.11768341, 26.98848534], [88.11283112, 26.99134254], [88.11147308, 26.99484062], [88.10699463, 26.99718475], [88.10179138, 27.0033989], [88.09503937, 27.00403976], [88.09111023, 27.00789452], [88.09111786, 27.01531601], [88.08624268, 27.02241135], [88.08561707, 27.02861595], [88.07950592, 27.03508186], [88.07827759, 27.03444672], [88.07244873, 27.0313015], [88.07191467, 27.0310154], [88.07006836, 27.0309391], [88.06697845, 27.03086281], [88.06221771, 27.02871513], [88.06051636, 27.0314827], [88.05847931, 27.03217125], [88.05243683, 27.03421783], [88.04792023, 27.0364151], [88.04292297, 27.03637314], [88.04026031, 27.03631783], [88.03752136, 27.04291725], [88.03672028, 27.04320526], [88.03578186, 27.04353905], [88.03023529, 27.05072594], [88.02959442, 27.05304718], [88.02841949, 27.05741501], [88.02522278, 27.06280136], [88.02459717, 27.06702614], [88.01900482, 27.07324028], [88.01863861, 27.07671928], [88.02349091, 27.08203697], [88.02372742, 27.08740616], [88.01850128, 27.0881443], [88.01531219, 27.093256], [88.01441956, 27.09711456], [88.01167297, 27.09797096], [88.01119995, 27.09939384], [88.00518036, 27.1034584], [88.00434113, 27.10468102], [88.00391388, 27.1043148], [88.00297546, 27.10343742], [87.99788666, 27.10320663], [87.99417114, 27.10520744], [87.99190521, 27.11637306], [87.99005127, 27.11897278], [87.99093628, 27.11979294], [87.99141693, 27.12331581], [87.9934082, 27.12568283], [87.99381256, 27.13054085], [88.0012207, 27.13341522], [88.0032196, 27.14001465], [88.00669098, 27.14151764], [88.00992584, 27.14295959], [88.01291656, 27.15441513], [88.01217651, 27.15737343], [88.01291656, 27.15811539], [88.01366425, 27.15886497], [88.0135498, 27.16542625], [88.01692963, 27.16659737], [88.02198792, 27.17066956], [88.02147675, 27.17195511], [88.02124786, 27.17253494], [88.02017975, 27.17334557], [88.01561737, 27.17823601], [88.01615143, 27.17912102], [88.01651764, 27.19041443], [88.01861572, 27.19291496], [88.01802063, 27.19951439], [88.01430511, 27.20352364], [88.01435089, 27.20360565], [88.01826477, 27.21056175], [88.0173111, 27.21151161], [88.01513672, 27.21654129], [88.01696777, 27.21887207], [88.02398682, 27.22066116], [88.03292847, 27.22103119], [88.04676056, 27.21611023], [88.05819702, 27.21389008], [88.06173706, 27.2112999], [88.06433868, 27.20783043], [88.0682373, 27.20473099], [88.07495117, 27.20084], [88.07540894, 27.19880104], [88.0688324, 27.1943512], [88.06745148, 27.19026947], [88.06926727, 27.18494987], [88.07232666, 27.17934036], [88.07309723, 27.1744175], [88.0786972, 27.16792107], [88.08325958, 27.16504288], [88.08390808, 27.16106987], [88.08299255, 27.14893913], [88.08383179, 27.14501953], [88.08584595, 27.14151001], [88.08863831, 27.13875008], [88.09266663, 27.13627815], [88.09593964, 27.13550949], [88.12329102, 27.12379074], [88.12690735, 27.12308121], [88.1366272, 27.11687851], [88.14377594, 27.11707115], [88.15231323, 27.11170959], [88.15544128, 27.1121006], [88.15843964, 27.11435127], [88.17260742, 27.1303196], [88.17899323, 27.13471031], [88.18367767, 27.1352005], [88.18850708, 27.13442039], [88.19561768, 27.13623047], [88.20986938, 27.13340187], [88.21383667, 27.1351223], [88.22151184, 27.12527084], [88.22690582, 27.12138939], [88.2325058, 27.11976814], [88.24006653, 27.12037086], [88.25154877, 27.12536049], [88.26345825, 27.12737083], [88.27088928, 27.13013077], [88.27735138, 27.13119125], [88.27813721, 27.13083076], [88.29490662, 27.12477112], [88.29988861, 27.12799835], [88.30449677, 27.12860107], [88.31127167, 27.12535095], [88.31881714, 27.1193409], [88.32048798, 27.11664009], [88.32007599, 27.10732079], [88.32383728, 27.10490036], [88.33174133, 27.10816765], [88.34079742, 27.11067009], [88.34516144, 27.10690117], [88.34793854, 27.10332108], [88.35230255, 27.1010704], [88.36387634, 27.0984211], [88.37065125, 27.09941292], [88.38751984, 27.09840965], [88.3976593, 27.09443092], [88.41100311, 27.09070015], [88.42914581, 27.08362007], [88.4319458, 27.08160973], [88.43962097, 27.08416939], [88.44628143, 27.08539963], [88.45449829, 27.0896492], [88.46018219, 27.09584999], [88.46479797, 27.10479164], [88.46672058, 27.11394119], [88.46907806, 27.11730194], [88.47377777, 27.12070084], [88.48127747, 27.12285042], [88.48668671, 27.12677956], [88.49185181, 27.1248703], [88.4956131, 27.12536049], [88.49640656, 27.12815285], [88.49890137, 27.13121986], [88.50295258, 27.13405037], [88.50750732, 27.13599014], [88.51222992, 27.14103127], [88.51596069, 27.1437397], [88.51870728, 27.14780045], [88.52171326, 27.15034294], [88.52674103, 27.14977264], [88.52993011, 27.1501503], [88.5320282, 27.1543293], [88.52672577, 27.1602726], [88.52980804, 27.16579056], [88.52047729, 27.17502975], [88.52075195, 27.17818069], [88.52899933, 27.17776108], [88.54084015, 27.1837101], [88.55899048, 27.18875122], [88.56629181, 27.18786049], [88.58509064, 27.19283295], [88.58702087, 27.19053268], [88.59147644, 27.19445992], [88.59400177, 27.19118118], [88.59751892, 27.19271088], [88.59810638, 27.19137192], [88.60352325, 27.19115257], [88.60678864, 27.18966103], [88.61901855, 27.18785286], [88.63327789, 27.17453003], [88.6387558, 27.16772079], [88.64248657, 27.16715813], [88.65645599, 27.1624012], [88.6595993, 27.16221046], [88.66806793, 27.17198944], [88.67350006, 27.17661095], [88.68036652, 27.17951012], [88.6844101, 27.18022919], [88.6914978, 27.17869949], [88.70197296, 27.17411041], [88.71180725, 27.16514969], [88.71496582, 27.15023994], [88.71779633, 27.14397049], [88.72454071, 27.13852119], [88.73253632, 27.13735008], [88.73718262, 27.13952065], [88.74694061, 27.14536476], [88.74604034, 27.14429665], [88.7483902, 27.1421051], [88.74949646, 27.14170265], [88.75088501, 27.141222], [88.75208282, 27.14065742], [88.75318909, 27.14041901], [88.75466156, 27.1401844], [88.75622559, 27.13970566], [88.75715637, 27.13905525], [88.75844574, 27.13857269], [88.75927734, 27.13816833], [88.76074982, 27.13768768], [88.76148987, 27.13728333], [88.76250458, 27.13712692], [88.76397705, 27.13681221], [88.76602936, 27.13624382], [88.76730347, 27.1361351], [88.76869965, 27.13650513], [88.7695694, 27.1363945], [88.77043915, 27.13646126], [88.77137756, 27.13646889], [88.77193451, 27.13673592], [88.77418518, 27.13612747], [88.77671051, 27.13552284], [88.77867126, 27.13535118], [88.78120422, 27.13505745], [88.78400421, 27.13508224], [88.7858963, 27.1350975], [88.78820801, 27.13536835], [88.79030609, 27.13569832], [88.79226685, 27.13596535], [88.7951355, 27.13642883], [88.79737091, 27.13713646], [88.79777527, 27.13721466], [88.79940033, 27.13752937], [88.80141449, 27.13892555], [88.8039093, 27.13908958], [88.80397034, 27.13784027], [88.80475616, 27.1361599], [88.80587769, 27.13486862], [88.80711365, 27.13305283], [88.80787659, 27.13160133], [88.80902863, 27.13031006], [88.80999756, 27.12915039], [88.81126404, 27.12834549], [88.81246948, 27.12716484], [88.81408691, 27.12617493], [88.81522369, 27.12474251], [88.81628418, 27.12374687], [88.81846619, 27.12288666], [88.82169342, 27.12266159], [88.82324219, 27.12179565], [88.82437897, 27.12086487], [88.82648468, 27.11981583], [88.82866669, 27.11901855], [88.83050537, 27.11784172], [88.83275604, 27.11629295], [88.83293915, 27.11622238], [88.83501434, 27.11543274], [88.83634186, 27.11506653], [88.83824158, 27.11508179], [88.83985138, 27.11465645], [88.84075928, 27.11358452], [88.84143066, 27.11222267], [88.84359741, 27.11154938], [88.84577179, 27.11162949], [88.84759521, 27.11101723], [88.84957123, 27.10965347], [88.85167694, 27.10941887], [88.85218048, 27.10946655], [88.85314941, 27.1095562], [88.85462189, 27.10944366], [88.85636902, 27.10951996], [88.85832977, 27.11009789], [88.86022186, 27.1100502], [88.861763, 27.10974884], [88.8635788, 27.11026573], [88.86540222, 27.11027145], [88.86713409, 27.11151314], [88.86764526, 27.11255646], [88.86834717, 27.11101913], [88.86884308, 27.11051559], [88.86998749, 27.10914612], [88.87007904, 27.10827637], [88.87001801, 27.10748672], [88.87000275, 27.10726166], [88.87007904, 27.10674477], [88.87026978, 27.10552216], [88.8702774, 27.10441208], [88.87028503, 27.10392761], [88.87033844, 27.10373306], [88.87088013, 27.10170555], [88.87179565, 27.09999084], [88.87232208, 27.09750366], [88.87283325, 27.09566498], [88.87326813, 27.09384918], [88.87356567, 27.09253311], [88.87326813, 27.09059334], [88.87402344, 27.08833694], [88.87340546, 27.0866394], [88.8737793, 27.08469772], [88.8736496, 27.0833168], [88.87373352, 27.08212662], [88.87374115, 27.0807476], [88.87320709, 27.07946968], [88.87377167, 27.07792664], [88.87483215, 27.07674217], [88.87574768, 27.07551003], [88.8760376, 27.07512283], [88.87619781, 27.07349205], [88.87479401, 27.07092094], [88.87553406, 27.06882668], [88.87684631, 27.06748009], [88.8782959, 27.06661034], [88.8788681, 27.06523514], [88.87800598, 27.06334496], [88.87799072, 27.06152916], [88.87774658, 27.06036949], [88.87759399, 27.0596447], [88.87746429, 27.05795097], [88.87726593, 27.056633], [88.87704468, 27.05514145], [88.87745667, 27.05282593], [88.87737274, 27.0510025], [88.87737274, 27.04915428], [88.87722015, 27.04799461], [88.87718201, 27.04719543], [88.87715149, 27.04647064], [88.87717438, 27.04480171], [88.87702179, 27.04364014], [88.8775177, 27.04233932], [88.87796783, 27.04104996], [88.87871552, 27.04020119], [88.87897491, 27.03990746], [88.87873077, 27.03861237], [88.878685, 27.03839302], [88.87772369, 27.03693199], [88.87688446, 27.0354023], [88.87615204, 27.03366661], [88.87562561, 27.03210449], [88.87519073, 27.0304966], [88.87509918, 27.03016472], [88.87463379, 27.02853394], [88.87451935, 27.02812576], [88.8742218, 27.02701759], [88.87382507, 27.02536392], [88.87371826, 27.02423859], [88.87368774, 27.02394104], [88.873703, 27.02200317], [88.8738327, 27.01953888], [88.87447357, 27.01721382], [88.87438202, 27.01531982], [88.87374115, 27.01334381], [88.87310791, 27.01185036], [88.87307739, 27.0104847], [88.87297058, 27.00845528], [88.87205505, 27.00629425], [88.87133026, 27.00474167], [88.87112427, 27.00275803], [88.87070465, 27.00171661], [88.86965179, 26.99906921], [88.86894989, 26.99613571], [88.86875916, 26.99455833], [88.86904144, 26.99226379], [88.86980438, 26.99064636], [88.87068939, 26.98896027], [88.87101746, 26.98840523], [88.87156677, 26.98746872], [88.87195587, 26.9857502], [88.87189484, 26.98323822], [88.87137604, 26.98069572], [88.87122345, 26.97949791], [88.87091827, 26.97707939], [88.87101746, 26.97545433], [88.87145996, 26.97374725], [88.87159729, 26.97250366], [88.87171936, 26.97142982], [88.8717041, 26.97108269], [88.87164307, 26.97001266], [88.87127686, 26.96803284], [88.87067413, 26.96636581], [88.86994934, 26.96475792], [88.86981201, 26.96397591], [88.86963654, 26.96298409], [88.87018585, 26.9611721], [88.87145996, 26.9603138], [88.87289429, 26.95476341], [88.87328339, 26.95316124], [88.87477875, 26.95180702], [88.87532043, 26.94843102], [88.87615967, 26.94587898], [88.87699127, 26.94433403], [88.87830353, 26.94507408], [88.87961578, 26.94618034], [88.88051605, 26.9474411], [88.88188934, 26.94913864], [88.88774109, 26.95759392], [88.89090729, 26.96132278], [88.89302826, 26.96277428], [88.89434052, 26.96481514], [88.89512634, 26.96649551], [88.89559174, 26.9673481], [88.89651489, 26.96917534], [88.897995, 26.97160912], [88.89989471, 26.97347641], [88.90200806, 26.97522736], [88.90348053, 26.97737312], [88.90467072, 26.97879601], [88.90808105, 26.97938156], [88.91007996, 26.97939682], [88.91192627, 26.98204041], [88.91150665, 26.9838295], [88.91268921, 26.98563194], [88.91351318, 26.98678398], [88.91439819, 26.9880352], [88.91638947, 26.98984337], [88.91785431, 26.98985291], [88.92077637, 26.99118996], [88.92090607, 26.9916687], [88.92116547, 26.99226952], [88.92150879, 26.99381638], [88.92253876, 26.99268341], [88.92327118, 26.99188232], [88.92521667, 26.99045372], [88.92654419, 26.9892292], [88.92707062, 26.98874283], [88.92736816, 26.98847008], [88.92887878, 26.98727417], [88.9315567, 26.98507118], [88.9343338, 26.98286629], [88.9369812, 26.98071861], [88.93704987, 26.98065376], [88.93878937, 26.97904968], [88.94119263, 26.97737694], [88.94287109, 26.97568321], [88.94413757, 26.97469711], [88.9458313, 26.97368431], [88.94855499, 26.97146416], [88.94998169, 26.97030258], [88.95081329, 26.9686985], [88.9514389, 26.96528816], [88.95157623, 26.96404266], [88.95150757, 26.9613781], [88.95291138, 26.96004868], [88.95270538, 26.95664024], [88.95238495, 26.95485497], [88.95275116, 26.95186043], [88.95271301, 26.95137405], [88.95250702, 26.94886971], [88.95211792, 26.94755173], [88.95172882, 26.94623566], [88.95094299, 26.94491386], [88.94989014, 26.94335365], [88.94857025, 26.94226837], [88.9475174, 26.94022751], [88.94727325, 26.93819427], [88.94728851, 26.93652153], [88.94611359, 26.9355278], [88.9460144, 26.9353447], [88.94589996, 26.93512535], [88.94483948, 26.93496895], [88.94368744, 26.93431091], [88.94475555, 26.93388939], [88.94587708, 26.93342018], [88.94646454, 26.93309212], [88.9473114, 26.93276405], [88.94828033, 26.93210411], [88.9500885, 26.93100548], [88.95365906, 26.92918968], [88.95638275, 26.92789459], [88.95860291, 26.92672539], [88.96086121, 26.92565536], [88.96150208, 26.92533112], [88.96305084, 26.9245472], [88.96646118, 26.92294884], [88.97064209, 26.92103386], [88.97142029, 26.92072105], [88.9755249, 26.91906929], [88.98036957, 26.91724968], [88.98297119, 26.91890526], [88.98416138, 26.91962624], [88.98455048, 26.91985703], [88.98486328, 26.92004013], [88.98615265, 26.92080116], [88.98779297, 26.92161942], [88.99021912, 26.92263794], [88.99090576, 26.92292595], [88.99249268, 26.92374611], [88.9940033, 26.92494583], [88.99575043, 26.92640305], [89.0109787, 26.93500328], [89.01587677, 26.93776512], [89.02124786, 26.94079971], [89.02182007, 26.93928337], [89.022995, 26.93615723], [89.02352905, 26.9351387], [89.02988434, 26.92305756], [89.041008, 26.92288017], [89.04640961, 26.91889191], [89.04802704, 26.91769791], [89.05024719, 26.91605568], [89.04911804, 26.90265846], [89.04881287, 26.89905167], [89.06747437, 26.90327263], [89.06950378, 26.9037323], [89.07466888, 26.90035248], [89.0796051, 26.89711952], [89.09033966, 26.89353752], [89.0956192, 26.89177704], [89.0949173, 26.88756943], [89.09403992, 26.8822937], [89.09244537, 26.87271309], [89.09810638, 26.86764145], [89.10076141, 26.86526108], [89.10586548, 26.86069107], [89.10612488, 26.86045837], [89.10095978, 26.84406471], [89.1005249, 26.84268761], [89.10128021, 26.84174538], [89.108284, 26.83299637], [89.10901642, 26.83208084], [89.11525726, 26.82428551], [89.1240921, 26.82222748], [89.13427734, 26.80783653], [89.14907837, 26.81188202], [89.17632294, 26.81932831], [89.17910004, 26.81797028], [89.19359589, 26.81088257], [89.19677734, 26.81158257], [89.22727203, 26.81829643], [89.23929596, 26.81889915], [89.26225281, 26.8139019], [89.26429749, 26.81833076], [89.26515961, 26.81914902], [89.26573944, 26.81971741], [89.26607513, 26.82000351], [89.26631165, 26.82026482], [89.26655579, 26.82050514], [89.26705933, 26.82096481], [89.26759338, 26.82148933], [89.26809692, 26.82199287], [89.26867676, 26.82249641], [89.26947021, 26.82330513], [89.27005005, 26.82383156], [89.27043915, 26.82424736], [89.27127838, 26.82505608], [89.27178955, 26.82551575], [89.2719574, 26.82566833], [89.27246094, 26.82621574], [89.2729187, 26.82658768], [89.27359772, 26.8272438], [89.2743454, 26.82798767], [89.2749939, 26.82862282], [89.27532959, 26.82890701], [89.27561951, 26.82870483], [89.27637482, 26.82811928], [89.27835083, 26.82659531], [89.28038788, 26.83036232], [89.28082275, 26.83116722], [89.28869629, 26.83485413], [89.295784, 26.84022141], [89.29821014, 26.84065437], [89.30069733, 26.84249115], [89.30282593, 26.84241486], [89.30567932, 26.84466743], [89.30723572, 26.84494019], [89.31005096, 26.84543419], [89.31832123, 26.85152626], [89.32087708, 26.85162354], [89.32186127, 26.85147476], [89.32305908, 26.85129356], [89.32376099, 26.84976578], [89.32430267, 26.84858513], [89.32670593, 26.84331894], [89.33386993, 26.84593964], [89.3651123, 26.85737228], [89.36740875, 26.85821342], [89.36975861, 26.85907364], [89.37892914, 26.86242485], [89.3835907, 26.85912895], [89.3894577, 26.84226036], [89.38954926, 26.84199333], [89.40517426, 26.84112358], [89.41113281, 26.8407917], [89.41356659, 26.84065628], [89.41480255, 26.84003639], [89.41487885, 26.83999825], [89.41650391, 26.83918381], [89.42250061, 26.83617973], [89.42527771, 26.83696365], [89.43871307, 26.84075546], [89.44438171, 26.83591843], [89.4499588, 26.83115959], [89.44883728, 26.82602882], [89.4504776, 26.81803513], [89.4516983, 26.81664658], [89.46105194, 26.80597496], [89.46316528, 26.80518532], [89.46974945, 26.80272675], [89.47431946, 26.802742], [89.47609711, 26.80317688], [89.5044632, 26.81011963], [89.50723267, 26.81079674], [89.50785065, 26.81156349], [89.50880432, 26.81151772], [89.50965118, 26.81237984], [89.51076508, 26.81243134], [89.52294159, 26.81367493], [89.52391815, 26.81373978], [89.52532196, 26.81292915], [89.52700043, 26.81274605], [89.52923584, 26.8133812], [89.53132629, 26.81401443], [89.53272247, 26.81402016], [89.53377533, 26.81396103], [89.53475189, 26.81365013], [89.53601074, 26.8132782], [89.53769684, 26.81246758], [89.53831482, 26.81231117], [89.53964996, 26.81197166], [89.54147339, 26.8115387], [89.5430069, 26.81116676], [89.54486084, 26.81085777], [89.54689026, 26.81170464], [89.54831696, 26.81243706], [89.55046844, 26.81324959], [89.55249786, 26.81395721], [89.5552597, 26.81428146], [89.55743408, 26.81422806], [89.55995941, 26.81322861], [89.55950928, 26.81143188], [89.56023407, 26.80952835], [89.56121063, 26.80714989], [89.56291962, 26.80547333], [89.56391144, 26.80428314], [89.56404114, 26.80284119], [89.56404877, 26.80121613], [89.56516266, 26.80022049], [89.56751251, 26.79985619], [89.56916046, 26.79950333], [89.5712204, 26.79897881], [89.5727005, 26.79838562], [89.57433319, 26.79776955], [89.57588196, 26.79709435], [89.57759857, 26.79678917], [89.5794754, 26.79631042], [89.58095551, 26.79552078], [89.58259583, 26.7948246], [89.58435059, 26.79430008], [89.58605957, 26.79323578], [89.58857727, 26.79192734], [89.5912323, 26.79249763], [89.5930481, 26.79212761], [89.59451294, 26.79175377], [89.59550476, 26.79148102], [89.59674835, 26.79055595], [89.59796906, 26.78938675], [89.59951019, 26.78853989], [89.60138702, 26.7885437], [89.60396576, 26.7878933], [89.60549927, 26.78764534], [89.6072464, 26.78765106], [89.60836792, 26.7870903], [89.60978699, 26.78666878], [89.61297607, 26.78666306], [89.6155014, 26.78629303], [89.61654663, 26.78479195], [89.6180954, 26.78354073], [89.6190033, 26.78235245], [89.61961365, 26.78125], [89.62090302, 26.77815437], [89.62184143, 26.77855873], [89.62397766, 26.77947998], [89.62634277, 26.78074074], [89.6292038, 26.78212738], [89.63046265, 26.78281975], [89.63192749, 26.78338814], [89.63318634, 26.78307915], [89.63486481, 26.78276825], [89.63567352, 26.7824688], [89.63654327, 26.78214645], [89.63831329, 26.78211212], [89.63996887, 26.78090096], [89.64105988, 26.77974892], [89.64251709, 26.77844238], [89.64318848, 26.77789879], [89.64536285, 26.77794647], [89.64640808, 26.77796936], [89.64884949, 26.77759933], [89.65090942, 26.77643013], [89.65048218, 26.77430153], [89.65020752, 26.77295876], [89.65132141, 26.7701416], [89.65258789, 26.76795006], [89.65338135, 26.76706886], [89.6499939, 26.76693916], [89.64878082, 26.76535606], [89.64769745, 26.7640152], [89.64756775, 26.76182556], [89.64377594, 26.76059914], [89.64455414, 26.75864792], [89.64524078, 26.75709343], [89.64530945, 26.75625992], [89.64549255, 26.75548363], [89.64562225, 26.75476074], [89.64537811, 26.75259399], [89.64377594, 26.75008965], [89.64063263, 26.74741554], [89.63852692, 26.74707794], [89.63685608, 26.74685097], [89.6346283, 26.74614525], [89.63246155, 26.7451992], [89.63142395, 26.74431801], [89.63009644, 26.74331093], [89.62821198, 26.7429924], [89.62654114, 26.74242401], [89.62535095, 26.74154282], [89.6240387, 26.74062347], [89.6230545, 26.73948479], [89.62229156, 26.73783493], [89.62200928, 26.73725128], [89.62159729, 26.73639107], [89.62062073, 26.73513412], [89.62007141, 26.73281288], [89.61923981, 26.73161888], [89.61903381, 26.73067856], [89.61761475, 26.72885895], [89.61785126, 26.72779083], [89.61904144, 26.72653961], [89.62121582, 26.72579193], [89.62306976, 26.72353935], [89.6229248, 26.72276497], [89.62276459, 26.72187233], [89.6232605, 26.72002792], [89.62376404, 26.71867561], [89.62473297, 26.71870422], [89.62748718, 26.71766281], [89.6290741, 26.71926117], [89.63103485, 26.71901703], [89.63143921, 26.71953392], [89.63180542, 26.72000694], [89.63254547, 26.72167397], [89.63383484, 26.72445488], [89.63531494, 26.72495842], [89.63720703, 26.7246418], [89.64021301, 26.72339439], [89.64200592, 26.72283554], [89.64209747, 26.72280693], [89.643013, 26.72252274], [89.64504242, 26.72233963], [89.64657593, 26.72159195], [89.64860535, 26.72009087], [89.64868164, 26.71962357], [89.64896393, 26.71783447], [89.65315247, 26.71796989], [89.65330505, 26.71797752], [89.65594482, 26.7181015], [89.65818024, 26.7189846], [89.65985107, 26.71939087], [89.66027069, 26.71949196], [89.66122437, 26.72082138], [89.6618042, 26.72162819], [89.66360474, 26.72489357], [89.66390991, 26.725214], [89.66486359, 26.72621346], [89.66539764, 26.72714996], [89.66576385, 26.7277832], [89.66638947, 26.72853661], [89.6672287, 26.729496], [89.66743469, 26.72973061], [89.66861725, 26.73073578], [89.66938019, 26.73243141], [89.66944885, 26.73387337], [89.66944122, 26.73563004], [89.66918945, 26.73609924], [89.66936493, 26.73798561], [89.6696167, 26.73848534], [89.67076874, 26.73965454], [89.67453003, 26.73971748], [89.67586517, 26.73963737], [89.67753601, 26.73953629], [89.67997742, 26.73834991], [89.68132019, 26.73722649], [89.68222046, 26.73647308], [89.68453217, 26.73560143], [89.68613434, 26.73466301], [89.68844604, 26.73347664], [89.68979645, 26.73325157], [89.69200134, 26.73467636], [89.69298553, 26.7348671], [89.69367981, 26.73524475], [89.69514465, 26.73549843], [89.69605255, 26.73600197], [89.69674683, 26.73625374], [89.697052, 26.7364769], [89.69752502, 26.73682404], [89.69786835, 26.73689651], [89.69839478, 26.73701859], [89.69874573, 26.73707581], [89.6992569, 26.73718262], [89.69973755, 26.73730469], [89.70022583, 26.73726845], [89.7009964, 26.73688507], [89.70198822, 26.73639107], [89.70259094, 26.73605537], [89.70321655, 26.73535919], [89.70446014, 26.73480415], [89.70571136, 26.73313141], [89.70773315, 26.73188019], [89.70928955, 26.73090744], [89.71161652, 26.73049164], [89.71456909, 26.73035812], [89.71674347, 26.7302227], [89.71798706, 26.72994614], [89.7178421, 26.72799301], [89.72001648, 26.72632408], [89.72173309, 26.72534943], [89.7220993, 26.72493744], [89.72223663, 26.72478104], [89.72235107, 26.72465324], [89.72288513, 26.72427368], [89.72390747, 26.72354126], [89.72499847, 26.72354317], [89.72763824, 26.72438431], [89.73104858, 26.72606468], [89.73280334, 26.72662544], [89.73368835, 26.72690773], [89.73554993, 26.72774696], [89.73628998, 26.72794724], [89.73865509, 26.72859001], [89.74192047, 26.72943306], [89.74456024, 26.7302742], [89.74472046, 26.73037148], [89.74720764, 26.73187637], [89.74777222, 26.7322197], [89.74906921, 26.73292923], [89.75098419, 26.73465157], [89.75244141, 26.73556137], [89.75473022, 26.73418045], [89.75626373, 26.73279572], [89.75777435, 26.73054504], [89.75789642, 26.72857285], [89.7570343, 26.72590256], [89.75613403, 26.72403908], [89.75461578, 26.72116661], [89.75418854, 26.71979141], [89.75553894, 26.71772385], [89.75621796, 26.71759796], [89.7578125, 26.71730042], [89.75972748, 26.7166214], [89.76128387, 26.71538544], [89.76374817, 26.71183777], [89.7644577, 26.71052742], [89.7645874, 26.71012306], [89.76564026, 26.70686722], [89.76680756, 26.70453262], [89.76839447, 26.70336723], [89.77022552, 26.7026062], [89.7705307, 26.70254898], [89.77223969, 26.70222855], [89.79200745, 26.70697784], [89.79485321, 26.70766068], [89.79834747, 26.70845032], [89.80813599, 26.71019173], [89.81214905, 26.71098137], [89.84100342, 26.70583534], [89.8600769, 26.70137405], [89.86141205, 26.70034981], [89.87142944, 26.68353081], [89.87148285, 26.67921829], [89.86946869, 26.67381096], [89.86933899, 26.67094994], [89.87052155, 26.66621971], [89.86987305, 26.66267014], [89.86828613, 26.66076088], [89.86805725, 26.65661812], [89.87275696, 26.65185928], [89.87637329, 26.64949989], [89.87583923, 26.64630127], [89.87367249, 26.64351082], [89.86126709, 26.63555908], [89.85729218, 26.63208961], [89.85704041, 26.62341118], [89.85900116, 26.61721039], [89.86183167, 26.61515045], [89.87161255, 26.61495972], [89.87722778, 26.61305046], [89.87663269, 26.60634232], [89.87522125, 26.60116959], [89.87254333, 26.59757042], [89.87211609, 26.5947094], [89.8742218, 26.58921242], [89.87754822, 26.58424187], [89.86987305, 26.57950974], [89.86200714, 26.57788277], [89.86152649, 26.57456017], [89.86499786, 26.57027054], [89.86548615, 26.56583977], [89.86432648, 26.56077957], [89.86461639, 26.54829025], [89.86141968, 26.5431881], [89.86226654, 26.53729057], [89.86183929, 26.53046036], [89.85443115, 26.52107811], [89.85350037, 26.51723289], [89.85560608, 26.5051403], [89.85497284, 26.49430275], [89.85269165, 26.48777962], [89.86102295, 26.47478104], [89.86237335, 26.46607018], [89.86709595, 26.46581078], [89.87020874, 26.46397972], [89.87062073, 26.45989037], [89.86943054, 26.45728111], [89.86949921, 26.44841957], [89.86112976, 26.44042015], [89.8576889, 26.4381218], [89.85520172, 26.43404961], [89.85299683, 26.42456055], [89.84976196, 26.42225075], [89.84778595, 26.42175293], [89.84764862, 26.41982269], [89.84980774, 26.41420937], [89.84484863, 26.4102211], [89.83634186, 26.41127014], [89.8332901, 26.41229057], [89.82946777, 26.40328026], [89.82727814, 26.39647293], [89.82797241, 26.39347839], [89.83058929, 26.39019966], [89.84039307, 26.39081955], [89.84449768, 26.39435005], [89.84606171, 26.39779282], [89.84681702, 26.40274048], [89.85032654, 26.3982811], [89.85315704, 26.39599037], [89.85729218, 26.38446045], [89.85507202, 26.38203049], [89.85125732, 26.38405037], [89.84549713, 26.38402939], [89.84092712, 26.37775993], [89.83402252, 26.38126183], [89.83098602, 26.38203049], [89.82787323, 26.38112068], [89.82559204, 26.37931824], [89.82440948, 26.37689018], [89.8274231, 26.36981964], [89.82705688, 26.36664963], [89.82106018, 26.35906982], [89.82341003, 26.3552494], [89.82118988, 26.35113907], [89.82009888, 26.35038185], [89.81556702, 26.3514595], [89.81362915, 26.35317039], [89.81149292, 26.35802078], [89.81154633, 26.36071014], [89.81266785, 26.36240005], [89.81723022, 26.36610031], [89.82041931, 26.37062073], [89.81256104, 26.36700058], [89.8098526, 26.36650085], [89.80400085, 26.36234283], [89.79032135, 26.35806274], [89.78201294, 26.35327911], [89.78089142, 26.35217094], [89.77906036, 26.3474102], [89.77921295, 26.34320259], [89.78103638, 26.33584023], [89.7808609, 26.33088112], [89.77774811, 26.3277607], [89.7685318, 26.32380295], [89.76196289, 26.3170681], [89.75364685, 26.32180023], [89.75166321, 26.32216072], [89.75054169, 26.32146072], [89.75089264, 26.30624008], [89.75914001, 26.29259109], [89.75865936, 26.28932953], [89.75710297, 26.28853035], [89.74888611, 26.2894001], [89.74606323, 26.29076195], [89.74234772, 26.29520988], [89.73179626, 26.29290009], [89.72344971, 26.29475021], [89.72088623, 26.29628944], [89.71980286, 26.29863167], [89.72276306, 26.30755043], [89.72025299, 26.30813026], [89.71782684, 26.3057003], [89.71568298, 26.30198097], [89.71544647, 26.2970295], [89.71705627, 26.29305267], [89.72109222, 26.28816986], [89.72918701, 26.28293991], [89.73745728, 26.271101], [89.7336731, 26.26646042], [89.73345184, 26.26250076], [89.73227692, 26.26033974], [89.72521973, 26.2584095], [89.71734619, 26.259161], [89.71142578, 26.26326942], [89.71084595, 26.2645607], [89.71154022, 26.26958084], [89.70894623, 26.27082062], [89.7048111, 26.26990128], [89.70067596, 26.26084137], [89.7009964, 26.25918961], [89.70362091, 26.25697136], [89.71138763, 26.25803947], [89.71537018, 26.25649071], [89.71642303, 26.25526047], [89.71652222, 26.25233841], [89.71502686, 26.24897194], [89.71572113, 26.24637985], [89.72357178, 26.24353981], [89.7287674, 26.23820114], [89.72332001, 26.23292923], [89.7181778, 26.23162079], [89.7128067, 26.22896957], [89.71170807, 26.22774124], [89.71022797, 26.21914101], [89.70555878, 26.21706009], [89.70310211, 26.21730995], [89.6995697, 26.21890068], [89.69722748, 26.21722984], [89.69754791, 26.21594238], [89.70024872, 26.21376038], [89.70307922, 26.21329117], [89.71549988, 26.21478081], [89.72438049, 26.21729088], [89.73127747, 26.21491051], [89.73203278, 26.21228981], [89.73132324, 26.21076965], [89.72566223, 26.20607948], [89.7232132, 26.2053299], [89.72062683, 26.20617104], [89.7172699, 26.20561028], [89.71421814, 26.20597839], [89.71163177, 26.20319939], [89.71556091, 26.20265007], [89.71747589, 26.20012093], [89.7181015, 26.19679832], [89.71613312, 26.19132805], [89.71405029, 26.18935966], [89.71073914, 26.18856049], [89.70822144, 26.18683815], [89.70536804, 26.1880703], [89.70184326, 26.18815041], [89.69757843, 26.19086075], [89.69483948, 26.18907166], [89.70020294, 26.18482971], [89.70061493, 26.18346405], [89.70253754, 26.17712021], [89.70427704, 26.1745491], [89.70652008, 26.17313004], [89.71161652, 26.1735096], [89.71705627, 26.17720985], [89.71980286, 26.17793846], [89.73023987, 26.17700005], [89.73314667, 26.1758709], [89.73417664, 26.1749897], [89.73375702, 26.17337036], [89.73293304, 26.17297173], [89.72705078, 26.17387962], [89.72509766, 26.17160988], [89.72509766, 26.16963005], [89.71930695, 26.16640663], [89.71875763, 26.16604805], [89.71869659, 26.1661377], [89.71812439, 26.16588593], [89.7178421, 26.16576004], [89.71696472, 26.16537285], [89.7164917, 26.1660099], [89.7168045, 26.16649246], [89.71695709, 26.16711044], [89.71687317, 26.1674366], [89.71664429, 26.16836357], [89.71447754, 26.16885757], [89.71318054, 26.16833496], [89.71263885, 26.16811371], [89.71199799, 26.16681099], [89.71115112, 26.16480827], [89.71042633, 26.16270065], [89.71086884, 26.16059113], [89.71054077, 26.15848923], [89.70989227, 26.15630913], [89.70899963, 26.15533447], [89.70828247, 26.15454674], [89.70661163, 26.15372467], [89.70539093, 26.15316391], [89.70501709, 26.15299034], [89.70306396, 26.15216827], [89.7013092, 26.15185738], [89.70115662, 26.15367317], [89.70011139, 26.15561295], [89.6988678, 26.15689468], [89.69718933, 26.15855789], [89.69496155, 26.15962601], [89.69284821, 26.16038322], [89.68365479, 26.16367912], [89.68087769, 26.16467476], [89.67963409, 26.16511917], [89.67425537, 26.16704559], [89.67514038, 26.16728783], [89.68414307, 26.16973495], [89.68487549, 26.16996193], [89.68547821, 26.17014885], [89.68858337, 26.17024612], [89.69106293, 26.16979599], [89.6934433, 26.16930962], [89.69451904, 26.16944122], [89.69633484, 26.16972542], [89.69780731, 26.17001152], [89.69979858, 26.17140388], [89.70114899, 26.17231369], [89.70148468, 26.17293358], [89.70158386, 26.17315102], [89.70198822, 26.17406273], [89.69828796, 26.17501068], [89.69564056, 26.17539215], [89.69396973, 26.17563248], [89.69174194, 26.17763519], [89.68441772, 26.18786049], [89.68350983, 26.1894722], [89.68210602, 26.1925354], [89.6819458, 26.19349289], [89.6812973, 26.19733238], [89.68125916, 26.19756317], [89.68120575, 26.19787598], [89.68053436, 26.1978302], [89.67806244, 26.19766235], [89.67349243, 26.20569992], [89.67344666, 26.20578384], [89.67380524, 26.20626068], [89.67586517, 26.20900726], [89.6759491, 26.20904922], [89.67838287, 26.21027946], [89.67897034, 26.21030617], [89.68032837, 26.21036911], [89.68178558, 26.20957756], [89.68193054, 26.20929718], [89.68314362, 26.20853424], [89.68338013, 26.20838547], [89.68558502, 26.20700264], [89.68683624, 26.2093811], [89.68708038, 26.20979691], [89.68821716, 26.21035957], [89.69124603, 26.21168709], [89.69142151, 26.21176147], [89.69164276, 26.21357155], [89.68969727, 26.21297836], [89.68912506, 26.21240425], [89.68836975, 26.21165085], [89.68809509, 26.21149063], [89.68669128, 26.21068764], [89.6858902, 26.20974731], [89.68503571, 26.20874405], [89.6832962, 26.20921516], [89.68313599, 26.21039009], [89.68276215, 26.21060753], [89.68182373, 26.21212387], [89.67971802, 26.2140274], [89.67965698, 26.21408844], [89.67961884, 26.21421814], [89.67906952, 26.21648979], [89.67862701, 26.21953011], [89.67865753, 26.2217865], [89.67888641, 26.22351837], [89.67897797, 26.22418976], [89.68032837, 26.22382736], [89.6815567, 26.22130775], [89.68419647, 26.2202034], [89.68690491, 26.21998215], [89.6891098, 26.2212162], [89.68938446, 26.22136879], [89.68920898, 26.22183037], [89.68907928, 26.22215843], [89.68792725, 26.22170067], [89.68570709, 26.22128105], [89.68419647, 26.22125053], [89.68229675, 26.22128105], [89.68187714, 26.22184944], [89.68276978, 26.22286034], [89.68416595, 26.2232933], [89.68371582, 26.22375298], [89.68360901, 26.22386169], [89.68621063, 26.22571373], [89.68595886, 26.22604942], [89.68622589, 26.22628593], [89.68659973, 26.22598076], [89.68711853, 26.22636604], [89.68746185, 26.22661591], [89.68567657, 26.22665405], [89.68570709, 26.22674751], [89.68577576, 26.22695351], [89.68595123, 26.22746849], [89.68486023, 26.22709084], [89.68379974, 26.22782898], [89.68348694, 26.22747231], [89.68278503, 26.22759056], [89.68195343, 26.2277317], [89.68179321, 26.22775841], [89.68073273, 26.23051071], [89.6802597, 26.23232079], [89.68009186, 26.2330513], [89.67980957, 26.234272], [89.67971802, 26.23449898], [89.67755127, 26.23112106], [89.67584991, 26.22948074], [89.67556, 26.22921944], [89.67420197, 26.22718811], [89.67427826, 26.2236824], [89.67436981, 26.22174072], [89.67449951, 26.21906281], [89.67324829, 26.21867943], [89.67047882, 26.21889114], [89.66670227, 26.21946144], [89.66320801, 26.21809006], [89.66086578, 26.21767044], [89.65717316, 26.21846962], [89.6556015, 26.21912766], [89.65549469, 26.21917343], [89.65512085, 26.22025299], [89.65502167, 26.22052956], [89.65288544, 26.22058296], [89.65093994, 26.22097206], [89.65066528, 26.22102547], [89.65040588, 26.22107697], [89.65032959, 26.22115326], [89.6481781, 26.22324371], [89.6472702, 26.22410393], [89.64624023, 26.22508812], [89.64563751, 26.22569847], [89.64326477, 26.22610855], [89.64102936, 26.2261219], [89.63871002, 26.22796822], [89.63846588, 26.22816467], [89.63835144, 26.22825813], [89.63809967, 26.22886276], [89.63772583, 26.22918701], [89.63769531, 26.2293663], [89.63751221, 26.23040962], [89.63536072, 26.23097229], [89.63379669, 26.23034668], [89.63361359, 26.22829628], [89.63379669, 26.22751045], [89.6341095, 26.22616577], [89.6346283, 26.22421265], [89.63481903, 26.22348976], [89.63394928, 26.22201157], [89.63733673, 26.22237015], [89.63759613, 26.22234917], [89.63725281, 26.21886063], [89.63739777, 26.21665001], [89.63685608, 26.2133007], [89.63683319, 26.21307945], [89.63666534, 26.21105385], [89.63833618, 26.21108818], [89.63890839, 26.20879173], [89.64054108, 26.20783043], [89.64096832, 26.20756912], [89.64102936, 26.20738983], [89.64192963, 26.20425034], [89.64305115, 26.20020294], [89.64370728, 26.19746971], [89.64639282, 26.19512558], [89.6475296, 26.19306946], [89.64820099, 26.19323921], [89.64838409, 26.19179153], [89.64980316, 26.19146156], [89.64994049, 26.19029808], [89.64980316, 26.19026566], [89.64832306, 26.18992996], [89.64762115, 26.18935204], [89.64743805, 26.18777847], [89.64589691, 26.1890049], [89.64553833, 26.18862915], [89.64737701, 26.18528938], [89.64710236, 26.18523407], [89.64496613, 26.1848526], [89.64450073, 26.18497086], [89.64367676, 26.18528366], [89.64235687, 26.18538094], [89.64211273, 26.18579292], [89.64150238, 26.18599129], [89.64138031, 26.1860199], [89.64089203, 26.18606186], [89.64016724, 26.18672371], [89.63798523, 26.18686485], [89.63796234, 26.18817139], [89.63716888, 26.18802071], [89.637146, 26.18833733], [89.63713074, 26.18857193], [89.63764191, 26.18862152], [89.63790131, 26.18864441], [89.63786316, 26.18979645], [89.63548279, 26.19022179], [89.63645172, 26.18904114], [89.63430023, 26.18856049], [89.63212585, 26.18806076], [89.63131714, 26.18786812], [89.62983704, 26.18618965], [89.63076019, 26.18412971], [89.63181305, 26.18263054], [89.63224792, 26.18239594], [89.6322403, 26.1826973], [89.6322403, 26.18280029], [89.63301086, 26.18278885], [89.63296509, 26.18200874], [89.63343048, 26.18176079], [89.63475037, 26.18180084], [89.63736725, 26.18062019], [89.6391983, 26.17951012], [89.63928986, 26.1794796], [89.6402359, 26.18234444], [89.64318085, 26.18270302], [89.64364624, 26.18289185], [89.64597321, 26.18161583], [89.6476059, 26.18131828], [89.65014648, 26.18053436], [89.65048218, 26.18092918], [89.6528244, 26.18097878], [89.65315247, 26.18157005], [89.65544128, 26.18152618], [89.65577698, 26.18023872], [89.65622711, 26.18023872], [89.65904236, 26.17893028], [89.66057587, 26.17681122], [89.66062164, 26.17563057], [89.65952301, 26.17336082], [89.65753937, 26.17201996], [89.65745544, 26.17193413], [89.65612793, 26.17051125], [89.65582275, 26.17006493], [89.65567017, 26.17008591], [89.65528107, 26.17002487], [89.654953, 26.17020226], [89.65471649, 26.17028236], [89.6545105, 26.17032433], [89.65454102, 26.17040443], [89.6530838, 26.17019272], [89.65126038, 26.17100334], [89.650383, 26.17012596], [89.65018463, 26.1699276], [89.65072632, 26.16864204], [89.6502533, 26.16820526], [89.64981079, 26.1678009], [89.64982605, 26.16712189], [89.64982605, 26.16686821], [89.64983368, 26.1662674], [89.64954376, 26.16625404], [89.64933014, 26.16624451], [89.64931488, 26.16591835], [89.64927673, 26.1652317], [89.64923859, 26.16453171], [89.64603424, 26.16455269], [89.64551544, 26.16556358], [89.64412689, 26.16575813], [89.64225769, 26.16555977], [89.64141083, 26.16604996], [89.64011383, 26.16680145], [89.63864899, 26.16693878], [89.63837433, 26.16696548], [89.6383667, 26.16727257], [89.63835907, 26.16804695], [89.63778687, 26.16898727], [89.63779449, 26.17063904], [89.63784027, 26.17107582], [89.63792419, 26.17185593], [89.63781738, 26.17222214], [89.63513184, 26.17204094], [89.63386536, 26.17201805], [89.63208008, 26.17198563], [89.63189697, 26.17335892], [89.6318512, 26.17371941], [89.63290405, 26.173563], [89.63334656, 26.17349815], [89.63359833, 26.17454147], [89.6337204, 26.17506981], [89.6353302, 26.17505836], [89.63581848, 26.17523766], [89.6360321, 26.17531586], [89.6361618, 26.17605209], [89.63624573, 26.17652893], [89.6370697, 26.17634964], [89.63729858, 26.17629814], [89.63731384, 26.177248], [89.63707733, 26.17737961], [89.63469696, 26.1782093], [89.63318634, 26.17818069], [89.63076782, 26.17674065], [89.62935638, 26.17534065], [89.62805176, 26.17308044], [89.62689972, 26.17145157], [89.6247406, 26.17140579], [89.62471771, 26.17133331], [89.62451172, 26.17130089], [89.62391663, 26.17120934], [89.62281799, 26.17129517], [89.62275696, 26.17189026], [89.6219635, 26.17186928], [89.62195587, 26.17238045], [89.62194824, 26.1728611], [89.62245178, 26.17282677], [89.62277222, 26.17280388], [89.62277222, 26.17343521], [89.62165833, 26.17352295], [89.62184143, 26.17384529], [89.62200165, 26.17414093], [89.62294769, 26.17432022], [89.62327576, 26.17438316], [89.62314606, 26.17519569], [89.62332153, 26.17531013], [89.62319946, 26.17715836], [89.62303925, 26.1774559], [89.62380219, 26.17768478], [89.62380981, 26.17804337], [89.62384033, 26.17921638], [89.62111664, 26.17939377], [89.61808777, 26.1793499], [89.61476135, 26.17866898], [89.61480713, 26.17846298], [89.6151886, 26.176548], [89.61487579, 26.1765728], [89.61326599, 26.17670631], [89.61260986, 26.17704773], [89.61277771, 26.17798996], [89.61183929, 26.17809296], [89.61180878, 26.17828178], [89.60926056, 26.17865944], [89.60938263, 26.17891884], [89.6098938, 26.17992973], [89.61013031, 26.18041039], [89.60871124, 26.18068504], [89.60855865, 26.18033981], [89.60835266, 26.17987442], [89.60796356, 26.17961693], [89.60738373, 26.17923737], [89.60746765, 26.17897797], [89.60764313, 26.17841911], [89.60804749, 26.17856026], [89.60849762, 26.17671013], [89.60816193, 26.176651], [89.60823059, 26.17644119], [89.61242676, 26.17637444], [89.61239624, 26.17582703], [89.61402893, 26.17546844], [89.61411285, 26.17545128], [89.614151, 26.17562103], [89.61424255, 26.17607498], [89.61508942, 26.17597771], [89.61522675, 26.1742878], [89.6153183, 26.17311859], [89.61355591, 26.17328072], [89.6136322, 26.17351723], [89.61330414, 26.1735878], [89.61320496, 26.17361069], [89.61325073, 26.17375946], [89.61346436, 26.17455864], [89.6116333, 26.17510986], [89.61164856, 26.17467308], [89.61166382, 26.17442131], [89.61144257, 26.17442894], [89.61091614, 26.17444801], [89.61094666, 26.17402267], [89.61115265, 26.17118454], [89.6115036, 26.17113495], [89.61142731, 26.17055321], [89.61138916, 26.17030907], [89.61156464, 26.17027283], [89.61174774, 26.17023468], [89.61164856, 26.16995239], [89.61116791, 26.16870308], [89.61122894, 26.1686573], [89.61277771, 26.16746902], [89.61470795, 26.16817474], [89.61491394, 26.16825104], [89.61524963, 26.1683712], [89.61769867, 26.16915321], [89.61800385, 26.16925049], [89.61823273, 26.16849709], [89.61915588, 26.16866112], [89.61837769, 26.16818619], [89.6197052, 26.1681881], [89.61875153, 26.16770363], [89.61856842, 26.16761017], [89.61865234, 26.16739464], [89.61895752, 26.16745949], [89.62129211, 26.1677227], [89.62197113, 26.16680908], [89.61992645, 26.16553116], [89.61738586, 26.16436958], [89.61676025, 26.16344261], [89.6163559, 26.16284943], [89.61598206, 26.16172028], [89.61450958, 26.16146088], [89.61267853, 26.16102982], [89.611763, 26.15922165], [89.61181641, 26.15837097], [89.61344147, 26.15755081], [89.61435699, 26.15571976], [89.61348724, 26.15335274], [89.61152649, 26.15200996], [89.60970306, 26.15215111], [89.60945892, 26.15300179], [89.60932159, 26.15376282], [89.60901642, 26.15370369], [89.60848999, 26.15360069], [89.60693359, 26.15449715], [89.60757446, 26.15669823], [89.60790253, 26.15820122], [89.60797882, 26.15843201], [89.60741425, 26.15849304], [89.60738373, 26.15767479], [89.60720825, 26.15812683], [89.60652161, 26.158041], [89.60597992, 26.15777397], [89.6053772, 26.15914726], [89.60431671, 26.1585331], [89.60440826, 26.15837288], [89.6053009, 26.15690613], [89.60455322, 26.15639687], [89.60446167, 26.15641975], [89.60411072, 26.15650368], [89.60375977, 26.1565876], [89.60121155, 26.15788269], [89.6001358, 26.1602726], [89.599617, 26.16047287], [89.59689331, 26.15949059], [89.59469604, 26.15703964], [89.59458923, 26.15690994], [89.59498596, 26.15653419], [89.59599304, 26.15646362], [89.59706116, 26.15505028], [89.59741211, 26.15458298], [89.5974884, 26.15452766], [89.59785461, 26.15400696], [89.59788513, 26.15376663], [89.5983429, 26.15052986], [89.59658051, 26.1499939], [89.59754944, 26.14851379], [89.59777069, 26.14818001], [89.59771729, 26.14762688], [89.59738159, 26.14429665], [89.59554291, 26.1400013], [89.59568787, 26.13996887], [89.59706879, 26.13965225], [89.59818268, 26.1390934], [89.59810638, 26.13734627], [89.59764099, 26.13642502], [89.59741211, 26.13597107], [89.59649658, 26.13530159], [89.5966568, 26.13517189], [89.5978775, 26.13415909], [89.59825134, 26.13278008], [89.59790802, 26.13255119], [89.59967804, 26.13131142], [89.60074615, 26.13021469], [89.60235596, 26.12680626], [89.60276031, 26.12674332], [89.60305023, 26.12672615], [89.6033783, 26.12833214], [89.60345459, 26.12836838], [89.60418701, 26.12870979], [89.60671234, 26.12602997], [89.60745239, 26.12569046], [89.60840607, 26.1259594], [89.60927582, 26.12515068], [89.60943604, 26.12452507], [89.61035156, 26.12626648], [89.61201477, 26.12759018], [89.61234283, 26.1278553], [89.61339569, 26.12667084], [89.61351776, 26.12557983], [89.61353302, 26.12546921], [89.61547089, 26.12338066], [89.61710358, 26.12056541], [89.62036133, 26.11985207], [89.62043762, 26.1198349], [89.62049103, 26.11992645], [89.62132263, 26.12141037], [89.62190247, 26.12244797], [89.62251282, 26.12613678], [89.62371826, 26.12786102], [89.62566376, 26.12835884], [89.62630463, 26.12852287], [89.62738037, 26.12750435], [89.62776184, 26.12714195], [89.62847137, 26.12783051], [89.63121033, 26.12620163], [89.63188171, 26.12370872], [89.63215637, 26.12265968], [89.63298798, 26.1189003], [89.63297272, 26.11758995], [89.63160706, 26.11544991], [89.62676239, 26.11211967], [89.62651062, 26.11194992], [89.62420654, 26.1100502], [89.62217712, 26.10860062], [89.62045288, 26.10696983], [89.6187973, 26.10642815], [89.61702728, 26.10623169], [89.61598206, 26.10663986], [89.61516571, 26.10718918], [89.61405945, 26.10689735], [89.61196136, 26.10795021], [89.61061859, 26.1086235], [89.60877991, 26.10831833], [89.60733032, 26.10756683], [89.60543823, 26.10658073], [89.60519409, 26.10645294], [89.60513306, 26.10666084], [89.60440063, 26.10911942], [89.6029892, 26.10930443], [89.60292053, 26.1093483], [89.60260773, 26.10905075], [89.60212708, 26.10860062], [89.60044861, 26.10885048], [89.59979248, 26.10876656], [89.59848785, 26.10860062], [89.59832764, 26.10818291], [89.59811401, 26.10762215], [89.59903717, 26.10744476], [89.59932709, 26.10778999], [89.60071564, 26.10758591], [89.60047913, 26.10627747], [89.59999084, 26.10354805], [89.59971619, 26.10362625], [89.59684753, 26.1044445], [89.59423065, 26.10344505], [89.59416199, 26.10321808], [89.59384918, 26.10224152], [89.59532166, 26.10030746], [89.59671021, 26.09802246], [89.59868622, 26.0969162], [89.60147858, 26.09580803], [89.6042099, 26.09481621], [89.60579681, 26.09341812], [89.60704041, 26.09045792], [89.60825348, 26.08850479], [89.60971069, 26.0897007], [89.61001587, 26.08994675], [89.61016846, 26.09007454], [89.60912323, 26.09308434], [89.60943604, 26.09547997], [89.6113205, 26.09649086], [89.61222839, 26.09627914], [89.61277771, 26.09615326], [89.61383057, 26.09527588], [89.61492157, 26.09608269], [89.61713409, 26.0950985], [89.61604309, 26.09803581], [89.61360168, 26.1009388], [89.61386871, 26.10342789], [89.61389923, 26.10370064], [89.61608124, 26.10426712], [89.61759949, 26.10326767], [89.61849976, 26.10353088], [89.62001038, 26.10317039], [89.62097931, 26.10225105], [89.62214661, 26.10113525], [89.6227417, 26.10174942], [89.62337494, 26.1030159], [89.62364197, 26.10567474], [89.62355804, 26.10750389], [89.62385559, 26.10782623], [89.6240387, 26.10801506], [89.62526703, 26.10836601], [89.62748718, 26.10821724], [89.62791443, 26.10801315], [89.62856293, 26.10831261], [89.62872314, 26.10839081], [89.63169098, 26.10732079], [89.63266754, 26.10696983], [89.63455963, 26.10482979], [89.63471222, 26.10466003], [89.63529968, 26.10244179], [89.6362915, 26.10116959], [89.63935089, 26.09958839], [89.63977814, 26.09890938], [89.63748169, 26.09661102], [89.63555908, 26.09465027], [89.63780212, 26.09308052], [89.63928223, 26.09235191], [89.63922119, 26.09209824], [89.63917542, 26.09191132], [89.63912964, 26.09172821], [89.63908386, 26.09150314], [89.63903046, 26.09126854], [89.63898468, 26.09112167], [89.63934326, 26.09096909], [89.63919067, 26.08973312], [89.63838959, 26.08974266], [89.63733673, 26.0897541], [89.63716888, 26.08934212], [89.63641357, 26.08747673], [89.63657379, 26.08574295], [89.63591766, 26.08619881], [89.63562775, 26.08640289], [89.63475037, 26.08525658], [89.63414001, 26.08444977], [89.63340759, 26.08262825], [89.63398743, 26.08010674], [89.63529205, 26.07834435], [89.63562775, 26.0777607], [89.63671875, 26.07540512], [89.6392746, 26.07413483], [89.64155579, 26.07324028], [89.6442337, 26.07150841], [89.64588928, 26.07024002], [89.64825439, 26.06848717], [89.64965057, 26.06640053], [89.65000153, 26.06448364], [89.64953613, 26.06303596], [89.64920807, 26.06201363], [89.64902496, 26.06145287], [89.64790344, 26.06197739], [89.6470871, 26.06235886], [89.64428711, 26.06212044], [89.64099121, 26.06068993], [89.63896942, 26.06026077], [89.6375885, 26.06034088], [89.63636017, 26.06121445], [89.63478851, 26.06105614], [89.63321686, 26.06206703], [89.6317215, 26.06302834], [89.63048553, 26.062397], [89.62802124, 26.06113625], [89.62741852, 26.05755997], [89.62657166, 26.05745506], [89.62504578, 26.05726433], [89.62440491, 26.056633], [89.62225342, 26.05450821], [89.62162018, 26.05429268], [89.62068939, 26.05397415], [89.61934662, 26.0535183], [89.61719513, 26.05437851], [89.61611176, 26.05692673], [89.61753845, 26.05983734], [89.61772919, 26.06022453], [89.61682892, 26.06002235], [89.61620331, 26.05988121], [89.61598206, 26.05982971], [89.61540985, 26.05974579], [89.61309814, 26.05940819], [89.6101532, 26.0600605], [89.6096344, 26.06219673], [89.60870361, 26.06382942], [89.60836029, 26.06361008], [89.60788727, 26.06157112], [89.60891724, 26.05940056], [89.61065674, 26.05817986], [89.61273193, 26.05768967], [89.61345673, 26.05729103], [89.61441803, 26.05676079], [89.61614227, 26.05435181], [89.61667633, 26.05297279], [89.61559296, 26.05140114], [89.61260986, 26.04997063], [89.60975647, 26.0486412], [89.60832214, 26.04815292], [89.60690308, 26.04766273], [89.60678864, 26.04758263], [89.60391235, 26.04548073], [89.60201263, 26.04459763], [89.60037231, 26.04422951], [89.59941864, 26.0440197], [89.59790802, 26.04409027], [89.59596252, 26.04424095], [89.59564972, 26.0439682], [89.59506989, 26.0434494], [89.59555054, 26.04296112], [89.59630585, 26.04217911], [89.59841919, 26.04055977], [89.60053253, 26.03944969], [89.60172272, 26.03803062], [89.59938049, 26.0365696], [89.59606934, 26.03508186], [89.59449005, 26.0346508], [89.5934906, 26.03523064], [89.59329224, 26.03550529], [89.59140015, 26.03570366], [89.59104156, 26.03658676], [89.59005737, 26.03647995], [89.58934784, 26.03558922], [89.5892868, 26.03575897], [89.58914948, 26.03604126], [89.58911896, 26.03619957], [89.58901215, 26.0363369], [89.58909607, 26.03684044], [89.5892868, 26.03830338], [89.58904266, 26.03847122], [89.58874512, 26.03862953], [89.58849335, 26.03872871], [89.5880661, 26.0388031], [89.58773804, 26.03884888], [89.5876236, 26.03879547], [89.58681488, 26.03842163], [89.58657837, 26.03505898], [89.58579254, 26.03464317], [89.58365631, 26.0335083], [89.58364105, 26.03340149], [89.58315277, 26.03033829], [89.58423615, 26.02907753], [89.58527374, 26.02636528], [89.58428192, 26.02524948], [89.58356476, 26.02445221], [89.58348846, 26.02444267], [89.58148193, 26.02420807], [89.58106995, 26.02205086], [89.58270264, 26.01777077], [89.5841217, 26.01172066], [89.58364105, 26.00946045], [89.58248901, 26.00786972], [89.58409119, 26.00513077], [89.58367157, 26.00320053], [89.58602905, 26.00095177], [89.58899689, 25.99829102], [89.59176636, 25.99398994], [89.59136963, 25.99207115], [89.58847809, 25.9889183], [89.58930969, 25.98538971], [89.59059143, 25.98299026], [89.59118652, 25.9808712], [89.59120941, 25.97847748], [89.5907135, 25.97591591], [89.59051514, 25.97598457], [89.59038544, 25.97600746], [89.590271, 25.97600174], [89.59008026, 25.9759388], [89.58987427, 25.97583008], [89.58953094, 25.97560501], [89.58942413, 25.97553635], [89.58769989, 25.97615051], [89.58740234, 25.97649193], [89.58545685, 25.97774506], [89.58509064, 25.97766495], [89.58511353, 25.97600174], [89.58431244, 25.97600555], [89.58423615, 25.97600555], [89.58374023, 25.97774506], [89.58366394, 25.97800636], [89.5835495, 25.97840691], [89.58342743, 25.97884941], [89.5814209, 25.97904778], [89.58052826, 25.97913551], [89.57989502, 25.97919846], [89.5779953, 25.97861481], [89.57795715, 25.97661972], [89.57795715, 25.97623062], [89.57853699, 25.97578812], [89.57920837, 25.97529984], [89.58113098, 25.9736805], [89.58127594, 25.9719429], [89.58133698, 25.97123909], [89.58040619, 25.9681797], [89.57692719, 25.96685982], [89.5735321, 25.9674511], [89.573349, 25.96770859], [89.57311249, 25.96821213], [89.57068634, 25.96778679], [89.56884003, 25.96785927], [89.56735229, 25.9704895], [89.56739807, 25.97178268], [89.5654068, 25.9701004], [89.56260681, 25.96799088], [89.56144714, 25.96606255], [89.55799103, 25.96461868], [89.55792999, 25.96472359], [89.55786896, 25.9648571], [89.55779266, 25.9650631], [89.55758667, 25.96545982], [89.55430603, 25.96553802], [89.55177307, 25.96602821], [89.55006409, 25.96636581], [89.54990387, 25.96639633], [89.54974365, 25.966465], [89.5495224, 25.96661568], [89.54729462, 25.96814537], [89.54695892, 25.96813965], [89.54498291, 25.96810913], [89.5408783, 25.9696312], [89.53874969, 25.9722023], [89.53852844, 25.97337723], [89.5381546, 25.9753685], [89.5381012, 25.97567558], [89.53937531, 25.97816658], [89.54019928, 25.98037148], [89.5415802, 25.98319817], [89.54161835, 25.98328018], [89.54151154, 25.98343849], [89.53755951, 25.98481369], [89.53671265, 25.98505211], [89.53623962, 25.98548317], [89.53601074, 25.98569489], [89.5361557, 25.98701096], [89.53621674, 25.98770714], [89.53618622, 25.988451], [89.53617096, 25.98875046], [89.53569031, 25.98885536], [89.53509521, 25.98898888], [89.53572083, 25.99067688], [89.53639984, 25.99009132], [89.53715515, 25.99060059], [89.53787231, 25.99089622], [89.53784943, 25.99149704], [89.53728485, 25.99178123], [89.53772736, 25.99430656], [89.54098511, 25.99556732], [89.5421524, 25.9960289], [89.54285431, 25.99708557], [89.54543304, 25.99729919], [89.54537964, 25.99806213], [89.54798126, 25.9981041], [89.54812622, 26.00006104], [89.548172, 26.00069809], [89.54734039, 26.00115776], [89.54663086, 26.00048637], [89.54651642, 26.00037766], [89.54560089, 26.00039101], [89.54499817, 26.00039864], [89.5447464, 26.00270081], [89.54288483, 26.00270844], [89.54283142, 26.00367737], [89.54231262, 26.00444794], [89.54128265, 26.00448418], [89.53968048, 26.0031395], [89.53762817, 26.00281525], [89.53740692, 26.00223541], [89.53665161, 26.00252724], [89.53635406, 26.00261307], [89.53567505, 26.00312233], [89.53424072, 26.00353813], [89.5318985, 26.00393105], [89.53044891, 26.00521469], [89.5297699, 26.00583649], [89.52921295, 26.00562668], [89.52844238, 26.00534058], [89.52793884, 26.00515175], [89.52606201, 26.00485229], [89.52549744, 26.00590515], [89.52521515, 26.00608063], [89.52485657, 26.00613976], [89.52363586, 26.00624275], [89.52200317, 26.00527], [89.52126312, 26.0082798], [89.51706696, 26.00670052], [89.51634216, 26.00597763], [89.5136261, 26.00328064], [89.51164246, 26.00131989], [89.50829315, 26.00033951], [89.50434113, 26.00159073], [89.50152588, 26.00271034], [89.50045776, 26.00325966], [89.49944305, 26.00357056], [89.49759674, 26.00344086], [89.4968338, 26.00295639], [89.49601746, 26.00318718], [89.49698639, 26.003479], [89.49661255, 26.0039196], [89.49640656, 26.00416756], [89.49523926, 26.00413513], [89.4941864, 26.00406265], [89.49433899, 26.00465584], [89.49273682, 26.00512505], [89.49247742, 26.0057106], [89.49136353, 26.00601006], [89.49120331, 26.00605392], [89.49077606, 26.00430679], [89.4882431, 26.00278091], [89.48805237, 26.00182724], [89.48685455, 26.00028229], [89.48575592, 25.99991417], [89.48403931, 25.99933815], [89.48180389, 25.99752617], [89.48124695, 25.99754524], [89.48094177, 25.99734306], [89.48047638, 25.99714279], [89.48036194, 25.99712563], [89.48040009, 25.99698639], [89.47834015, 25.99670982], [89.47725677, 25.99690056], [89.47519684, 25.99727058], [89.47312164, 25.99706841], [89.46948242, 25.99768066], [89.46734619, 25.99803352], [89.46578979, 25.99809456], [89.461586, 25.99846077], [89.4610672, 25.99895477], [89.46100616, 25.99901009], [89.45985413, 25.9998436], [89.4597702, 25.99990463], [89.45932007, 26.00022888], [89.45891571, 26.0003643], [89.45864105, 26.00045776], [89.45807648, 26.00064659], [89.45798492, 26.00067902], [89.45485687, 26.00302696], [89.45243835, 26.00495911], [89.44991302, 26.00644875], [89.449646, 26.00647163], [89.44621277, 26.0068512], [89.44507599, 26.0069809], [89.43850708, 26.00859833], [89.43732452, 26.00936127], [89.43634796, 26.00949669], [89.43341064, 26.01021385], [89.43096161, 26.01114464], [89.42741394, 26.01324081], [89.42669678, 26.01532364], [89.42716217, 26.01527786], [89.42789459, 26.01520729], [89.42784119, 26.01470947], [89.42858887, 26.01459694], [89.42816925, 26.01616669], [89.42734528, 26.01925087], [89.42878723, 26.02244186], [89.43038177, 26.02516747], [89.43179321, 26.02773476], [89.43389893, 26.03053474], [89.43268585, 26.03854752], [89.43263245, 26.038908], [89.4315033, 26.0405674], [89.4295578, 26.04344749], [89.42950439, 26.04351997], [89.42938995, 26.04354477], [89.4282074, 26.04380608], [89.42582703, 26.0443306], [89.42378235, 26.04701042], [89.42306519, 26.04696465], [89.42267609, 26.04693985], [89.42428589, 26.04442787], [89.42437744, 26.04428482], [89.42329407, 26.04360771], [89.42123413, 26.04367447], [89.41891479, 26.04198456], [89.41783905, 26.04188347], [89.41519165, 26.0416584], [89.41339874, 26.04133415], [89.41184235, 26.04105186], [89.41049957, 26.04080963], [89.40739441, 26.04161263], [89.40679932, 26.04115486], [89.40626526, 26.04074669], [89.40720367, 26.04015541], [89.40750885, 26.0394783], [89.407547, 26.03939056], [89.40745544, 26.03939247], [89.40694427, 26.03940201], [89.40644836, 26.03787231], [89.40740967, 26.03624344], [89.40590668, 26.0352478], [89.40567017, 26.03498268], [89.40480804, 26.03401566], [89.40662384, 26.03305435], [89.40657043, 26.031744], [89.40656281, 26.03161812], [89.4052124, 26.03133011], [89.40427399, 26.03112793], [89.4039917, 26.0302639], [89.40361023, 26.02911377], [89.40317535, 26.02779579], [89.40312958, 26.027668], [89.40100098, 26.02630424], [89.3985672, 26.02603912], [89.39635468, 26.02462578], [89.3952179, 26.02396774], [89.39401245, 26.02327347], [89.39351654, 26.02298737], [89.39117432, 26.02303314], [89.39080811, 26.02304077], [89.39051819, 26.01926041], [89.39160156, 26.01857567], [89.39182281, 26.01843643], [89.39160156, 26.01794434], [89.39109039, 26.01681709], [89.39347076, 26.01527596], [89.39344025, 26.01385117], [89.39443207, 26.01325035], [89.39369965, 26.01202393], [89.39392853, 26.01064301], [89.39379883, 26.00918007], [89.39376068, 26.00872803], [89.39324951, 26.00814438], [89.3924408, 26.00723076], [89.39199066, 26.00933456], [89.3915863, 26.00943375], [89.39110565, 26.00955391], [89.39022827, 26.00860977], [89.39013672, 26.0085125], [89.38933563, 26.00844574], [89.38973999, 26.0091629], [89.38787079, 26.00997925], [89.3864975, 26.00969124], [89.383461, 26.00955009], [89.38072205, 26.00942993], [89.37911224, 26.01053047], [89.37783813, 26.01007652], [89.37773895, 26.00980949], [89.37757111, 26.00935173], [89.37702942, 26.00977898], [89.37535095, 26.00910187], [89.37338257, 26.00905991], [89.37162018, 26.00925064], [89.37126923, 26.00919533], [89.37117767, 26.00909042], [89.37052917, 26.00912476], [89.3692627, 26.00888062], [89.3677063, 26.00851822], [89.36593628, 26.00810814], [89.36312866, 26.00761986], [89.36078644, 26.00889015], [89.36039734, 26.00928879], [89.36005402, 26.00868225], [89.35964203, 26.00793839], [89.35951233, 26.00909424], [89.35949707, 26.0092411], [89.35822296, 26.00857544], [89.35710907, 26.00799179], [89.35666656, 26.00902939], [89.35626984, 26.00996971], [89.35588074, 26.00935555], [89.3553009, 26.00843239], [89.35536194, 26.00889778], [89.35441589, 26.01010895], [89.35428619, 26.01008987], [89.35243988, 26.01051903], [89.35225677, 26.01016426], [89.35171509, 26.00995255], [89.35113525, 26.01014137], [89.35105133, 26.01104355], [89.35099792, 26.01156616], [89.35055542, 26.01137543], [89.35037231, 26.01129913], [89.35022736, 26.0112381], [89.35017395, 26.01117897], [89.34959412, 26.01058197], [89.34913635, 26.01039314], [89.34848785, 26.01048088], [89.34875488, 26.01110649], [89.34902954, 26.01174736], [89.3482666, 26.01223946], [89.34708405, 26.01183128], [89.34643555, 26.01160622], [89.34420776, 26.01329803], [89.34559631, 26.01323318], [89.34689331, 26.0136013], [89.34692383, 26.01384735], [89.34703827, 26.01489449], [89.34664917, 26.01475906], [89.34606934, 26.01547813], [89.34576416, 26.0150528], [89.3453598, 26.01448822], [89.34361267, 26.01599884], [89.34368134, 26.01713562], [89.34298706, 26.01671028], [89.3433075, 26.01587296], [89.34349823, 26.01586151], [89.34358978, 26.01585579], [89.34342957, 26.01468658], [89.34313965, 26.01536942], [89.34217072, 26.01493645], [89.34003448, 26.01534653], [89.34098816, 26.01550484], [89.33995819, 26.01747704], [89.33892822, 26.01714706], [89.33971405, 26.01787376], [89.33727264, 26.01807594], [89.33847046, 26.01821518], [89.33903503, 26.01828003], [89.33861542, 26.01843834], [89.33728027, 26.0189476], [89.33718109, 26.02007484], [89.33827972, 26.01962662], [89.33869171, 26.01946068], [89.33865356, 26.02009392], [89.3385849, 26.02110291], [89.33719635, 26.020504], [89.3372879, 26.02180099], [89.33731842, 26.02223778], [89.33624268, 26.02039337], [89.33563232, 26.02027512], [89.33447266, 26.0200882], [89.33469391, 26.0209465], [89.33512115, 26.02086067], [89.3353653, 26.02080917], [89.33740997, 26.02300835], [89.3385849, 26.02340698], [89.33774567, 26.02344131], [89.33633423, 26.02350044], [89.33706665, 26.02477646], [89.33670807, 26.02556038], [89.33667755, 26.02589607], [89.33661652, 26.0265274], [89.33625031, 26.02636528], [89.33480835, 26.0257206], [89.33419037, 26.02747345], [89.33415222, 26.02757645], [89.33350372, 26.02726555], [89.33286285, 26.02696037], [89.33319092, 26.02828979], [89.33184052, 26.0293541], [89.33159637, 26.02954483], [89.33073425, 26.02913094], [89.33095551, 26.02774429], [89.3309021, 26.02762604], [89.33073425, 26.0272789], [89.32884979, 26.02834129], [89.3293457, 26.02860069], [89.33002472, 26.02895927], [89.32977295, 26.02956581], [89.32959747, 26.02996445], [89.32945251, 26.03031349], [89.32804108, 26.03036499], [89.32758331, 26.03038216], [89.32894897, 26.03153419], [89.32644653, 26.03187943], [89.32597351, 26.0325489], [89.32662964, 26.03274345], [89.32733154, 26.03294945], [89.32789612, 26.03331757], [89.32778931, 26.03410149], [89.32698059, 26.03437233], [89.32550812, 26.03486633], [89.32588959, 26.03524399], [89.32644653, 26.03597832], [89.32585907, 26.03663445], [89.32542419, 26.03631783], [89.32507324, 26.03606224], [89.32427979, 26.03604889], [89.32446289, 26.03671837], [89.32291412, 26.03772545], [89.32027435, 26.03814125], [89.31917572, 26.03926086], [89.3190918, 26.03845406], [89.31789398, 26.03797531], [89.31690979, 26.03758049], [89.31586456, 26.03734589], [89.31550598, 26.03726387], [89.31510925, 26.03756142], [89.31571198, 26.0381031], [89.31654358, 26.03832626], [89.31719971, 26.03849983], [89.3168869, 26.03902245], [89.31632996, 26.0390377], [89.31475067, 26.03908157], [89.31422424, 26.03936005], [89.31318665, 26.03991318], [89.31089783, 26.04099846], [89.308815, 26.04269791], [89.30731964, 26.04535675], [89.30724335, 26.04527092], [89.30641174, 26.04440308], [89.30615234, 26.04660797], [89.3057251, 26.04611778], [89.30509949, 26.04540825], [89.30480957, 26.04594994], [89.30371094, 26.04566574], [89.30406952, 26.04623413], [89.30459595, 26.04706955], [89.30257416, 26.04666519], [89.30266571, 26.04685783], [89.30185699, 26.04634285], [89.30123138, 26.04593277], [89.29928589, 26.04566956], [89.29719543, 26.0466156], [89.29657745, 26.04541969], [89.29519653, 26.04618645], [89.29355621, 26.04601479], [89.2919693, 26.04643059], [89.29161835, 26.04652023], [89.2911911, 26.04581642], [89.29090881, 26.04536438], [89.29080963, 26.0466938], [89.28913116, 26.04684639], [89.2891922, 26.0482502], [89.28407288, 26.04848099], [89.27877045, 26.0486393], [89.27850342, 26.04864693], [89.27566528, 26.04917526], [89.2767868, 26.0514946], [89.27706909, 26.05140114], [89.27895355, 26.05078506], [89.27911377, 26.05150986], [89.27949524, 26.05316544], [89.28000641, 26.05432892], [89.28010559, 26.05431557], [89.28074646, 26.05422211], [89.28087616, 26.05451965], [89.28161621, 26.05618858], [89.28162384, 26.05626869], [89.28157806, 26.05783653], [89.28067017, 26.05780411], [89.28100586, 26.0586071], [89.28096008, 26.06081963], [89.28124237, 26.0620594], [89.28120422, 26.06240845], [89.28113556, 26.06306648], [89.28166199, 26.0635376], [89.28179169, 26.06365585], [89.28244781, 26.06424522], [89.28099823, 26.06476021], [89.28097534, 26.06569481], [89.27839661, 26.06652641], [89.27823639, 26.06657791], [89.27809143, 26.06554794], [89.27800751, 26.06500816], [89.27667999, 26.06476784], [89.27642822, 26.06454277], [89.27587891, 26.06404495], [89.27588654, 26.06307983], [89.27588654, 26.06279755], [89.2762146, 26.06219101], [89.27579498, 26.0622654], [89.2752533, 26.06236267], [89.27519989, 26.0616169], [89.27612305, 26.06128502], [89.27574158, 26.06120872], [89.27409363, 26.06088257], [89.27379608, 26.06178093], [89.27241516, 26.06071854], [89.27186584, 26.06170845], [89.27079773, 26.06190681], [89.27043915, 26.06197166], [89.27007294, 26.06092262], [89.27085114, 26.0608654], [89.27083588, 26.06049728], [89.27082062, 26.06002045], [89.26935577, 26.06012344], [89.26908112, 26.06091118], [89.26696014, 26.06089592], [89.26542664, 26.06152725], [89.26430511, 26.06173515], [89.2644577, 26.06245804], [89.26383209, 26.06212616], [89.26043701, 26.06263542], [89.25937653, 26.06232834], [89.25824738, 26.06295013], [89.25802612, 26.06343079], [89.25759888, 26.06293106], [89.25722504, 26.06292534], [89.25704193, 26.06413841], [89.25602722, 26.06422234], [89.25598145, 26.06365013], [89.25434875, 26.06421471], [89.25489807, 26.06573677], [89.25431061, 26.06584549], [89.25437164, 26.06744385], [89.25463104, 26.06797409], [89.2549057, 26.06854057], [89.25514984, 26.06905556], [89.25601196, 26.07182121], [89.25520325, 26.07303047], [89.25505066, 26.07425308], [89.25465393, 26.07476044], [89.25522614, 26.0754509], [89.25571442, 26.07604408], [89.25601196, 26.07653618], [89.25630188, 26.07701683], [89.25634766, 26.07731819], [89.25680542, 26.08016014], [89.25712585, 26.08000374], [89.25772095, 26.07972336], [89.25791931, 26.08037186], [89.25803375, 26.08073997], [89.25836182, 26.0806942], [89.2587738, 26.08063698], [89.25904083, 26.08119965], [89.25946045, 26.08208275], [89.25966644, 26.08221436], [89.26081085, 26.08296204], [89.26042938, 26.08429909], [89.26134491, 26.08588028], [89.26580048, 26.08791161], [89.26550293, 26.09086609], [89.26630402, 26.09127235], [89.26644135, 26.09134293], [89.26638031, 26.09142494], [89.26563263, 26.0923996], [89.26675415, 26.09247971], [89.26644135, 26.09272766], [89.26584625, 26.0932045], [89.26546478, 26.09350586], [89.26559448, 26.09316635], [89.26580048, 26.09260941], [89.26421356, 26.09315872], [89.2639389, 26.09327316], [89.26373291, 26.09287834], [89.26333618, 26.0921936], [89.26114655, 26.09222031], [89.26025391, 26.09209061], [89.25972748, 26.09184456], [89.25974274, 26.09201622], [89.25888062, 26.09189034], [89.25743103, 26.09221268], [89.25734711, 26.09247398], [89.25567627, 26.09212494], [89.25669098, 26.09266281], [89.25521088, 26.09341621], [89.25304413, 26.09260368], [89.25296783, 26.09257507], [89.2529068, 26.09233093], [89.25275421, 26.09165764], [89.2515564, 26.09145737], [89.25112152, 26.09285545], [89.25148773, 26.09285545], [89.25230408, 26.09285545], [89.25214386, 26.09308434], [89.25136566, 26.09418106], [89.2502594, 26.09454918], [89.25049591, 26.09481812], [89.25141144, 26.09588623], [89.25143433, 26.0965519], [89.2514801, 26.0979538], [89.25232697, 26.097929], [89.2522583, 26.09863281], [89.25160217, 26.09860802], [89.2509613, 26.10027313], [89.25171661, 26.10131645], [89.25050354, 26.10107613], [89.24923706, 26.10081863], [89.24936676, 26.10115051], [89.24972534, 26.10207748], [89.24982452, 26.10231781], [89.24766541, 26.10181618], [89.2484436, 26.10370064], [89.24725342, 26.10453796], [89.24704742, 26.10468292], [89.24488068, 26.10667038], [89.24369812, 26.10497093], [89.24414825, 26.10610008], [89.24256897, 26.10594368], [89.24194336, 26.10588074], [89.24150085, 26.10583687], [89.24274445, 26.10727882], [89.241539, 26.1060276], [89.24101257, 26.10680389], [89.24214935, 26.10915184], [89.24039459, 26.10771561], [89.23986816, 26.1086235], [89.23947906, 26.10930634], [89.24008942, 26.10962486], [89.24128723, 26.11024666], [89.23999786, 26.11035919], [89.23921204, 26.11042786], [89.23955536, 26.11155891], [89.23787689, 26.11277771], [89.2377243, 26.11262894], [89.23745728, 26.11283302], [89.23635864, 26.11365891], [89.23548889, 26.11481476], [89.23352814, 26.11341095], [89.23304749, 26.11307144], [89.23329926, 26.11371613], [89.23348236, 26.11417198], [89.23300934, 26.11513138], [89.23168945, 26.11723709], [89.23055267, 26.11618996], [89.22971344, 26.11648941], [89.22917938, 26.11668205], [89.2303772, 26.11738586], [89.23066711, 26.11755753], [89.23007965, 26.11845398], [89.22879791, 26.12005997], [89.2284317, 26.12051582], [89.22911835, 26.120924], [89.22941589, 26.12110329], [89.22937775, 26.12289047], [89.22847748, 26.12317276], [89.22814941, 26.12313271], [89.22822571, 26.12291336], [89.22756958, 26.12244225], [89.22716522, 26.12215042], [89.22687531, 26.12298012], [89.22679901, 26.12318802], [89.22544098, 26.12433052], [89.22463226, 26.12377167], [89.22348785, 26.12511826], [89.22177887, 26.12566185], [89.22029877, 26.12565422], [89.21968842, 26.12461662], [89.21906281, 26.1245327], [89.21911621, 26.12472916], [89.21931458, 26.12542915], [89.2196579, 26.12663078], [89.21837616, 26.12673759], [89.21704102, 26.12563705], [89.21703339, 26.12636757], [89.21382904, 26.12697411], [89.21465302, 26.12635994], [89.21450806, 26.12602997], [89.21430206, 26.12553024], [89.21420288, 26.12529182], [89.21352386, 26.12585068], [89.21310425, 26.12546921], [89.21278381, 26.12517929], [89.21161652, 26.12449455], [89.2113266, 26.1243248], [89.21091461, 26.1252327], [89.21060944, 26.12589836], [89.20999908, 26.12665939], [89.20899963, 26.12678909], [89.20890045, 26.12666702], [89.20851135, 26.12685204], [89.20838928, 26.12691116], [89.20752716, 26.12664986], [89.20691681, 26.12648964], [89.20500946, 26.12453079], [89.20362091, 26.12431908], [89.20330811, 26.12437248], [89.20331573, 26.12452507], [89.20332336, 26.12462425], [89.20336151, 26.12477493], [89.2033844, 26.1248951], [89.2033844, 26.12504196], [89.20336914, 26.12524223], [89.20333099, 26.12538528], [89.20333862, 26.12548256], [89.20333862, 26.12565231], [89.20331573, 26.12583923], [89.20331573, 26.12600136], [89.20332336, 26.12609291], [89.20336151, 26.12619781], [89.20339966, 26.12630272], [89.20346069, 26.12636948], [89.20352173, 26.12644005], [89.20362854, 26.12637329], [89.20371246, 26.12631989], [89.20379639, 26.12627983], [89.20391846, 26.12629318], [89.20404816, 26.12635422], [89.20419312, 26.12642288], [89.20491028, 26.12731934], [89.20284271, 26.12935829], [89.20220947, 26.12876511], [89.20187378, 26.12908745], [89.20148468, 26.12854195], [89.2011795, 26.12899399], [89.20011902, 26.12860107], [89.19966125, 26.12751579], [89.19963074, 26.12744331], [89.19945526, 26.12744141], [89.19862366, 26.12743187], [89.1986084, 26.12720871], [89.19855499, 26.12637329], [89.19812775, 26.12575912], [89.19830322, 26.12680244], [89.19813538, 26.12645149], [89.1971817, 26.12670708], [89.1950531, 26.12727928], [89.19550323, 26.1267643], [89.19634247, 26.12581253], [89.19540405, 26.12592316], [89.19468689, 26.12600899], [89.1945343, 26.12532616], [89.19441986, 26.12481499], [89.19329071, 26.12478256], [89.19291687, 26.12387466], [89.19101715, 26.12519836], [89.18978119, 26.12453842], [89.18966675, 26.12647057], [89.18942261, 26.12682724], [89.18898773, 26.12688065], [89.18670654, 26.12662125], [89.18508148, 26.12675095], [89.18343353, 26.12851906], [89.18319702, 26.12813187], [89.18232727, 26.12938499], [89.18132019, 26.1281662], [89.18064117, 26.12928581], [89.18015289, 26.12817764], [89.18010712, 26.12808418], [89.17986298, 26.12829208], [89.17852783, 26.12941742], [89.17845917, 26.13035202], [89.17756653, 26.13012314], [89.17726898, 26.13029861], [89.17590332, 26.13110542], [89.17664337, 26.13157463], [89.17650604, 26.13207626], [89.17520905, 26.13185501], [89.17491913, 26.13111305], [89.17487335, 26.13100433], [89.17474365, 26.13098717], [89.17248535, 26.13068199], [89.17240906, 26.13083267], [89.17066956, 26.13062668], [89.17002869, 26.13055038], [89.17004395, 26.13124466], [89.17005157, 26.13140869], [89.16985321, 26.13142395], [89.16797638, 26.131567], [89.16687775, 26.13027], [89.16649628, 26.13235664], [89.16439819, 26.13174438], [89.16368866, 26.13353539], [89.16291046, 26.13324165], [89.16240692, 26.13305473], [89.16184998, 26.13433075], [89.16220093, 26.13524437], [89.16233063, 26.13557625], [89.16210175, 26.13553429], [89.16049957, 26.13524437], [89.16040039, 26.13545227], [89.16022491, 26.13581467], [89.16104889, 26.13735199], [89.16003418, 26.13672066], [89.15914917, 26.13686562], [89.15992737, 26.13711166], [89.15973663, 26.13737679], [89.1594162, 26.13783264], [89.16025543, 26.13829422], [89.1605835, 26.13847542], [89.16002655, 26.13920403], [89.15953064, 26.13985252], [89.15823364, 26.13837242], [89.15795135, 26.13909721], [89.15699005, 26.14006233], [89.15672302, 26.13939667], [89.15666962, 26.13925171], [89.15615845, 26.13904381], [89.15532684, 26.13870811], [89.15488434, 26.13960266], [89.15523529, 26.14072418], [89.15468597, 26.1414814], [89.15435028, 26.14189339], [89.153862, 26.14248657], [89.15418243, 26.14284515], [89.15353394, 26.14322853], [89.15353394, 26.14356995], [89.15353394, 26.14388847], [89.15335083, 26.14366722], [89.15312958, 26.14453506], [89.15345764, 26.14427948], [89.15363312, 26.14495087], [89.15343475, 26.14490509], [89.15309906, 26.14486122], [89.15301514, 26.1453476], [89.15213776, 26.14568138], [89.15211487, 26.14582825], [89.1520462, 26.14628792], [89.15222931, 26.14650917], [89.15280151, 26.14720345], [89.1517868, 26.14682579], [89.15222931, 26.14747047], [89.15227509, 26.14766502], [89.15242767, 26.14826202], [89.15241241, 26.1484623], [89.15148163, 26.14806366], [89.1512146, 26.14840126], [89.15093231, 26.14876366], [89.15136719, 26.14935493], [89.15175629, 26.14988899], [89.15169525, 26.15167809], [89.1498642, 26.15305138], [89.15024567, 26.15487289], [89.14931488, 26.15493202], [89.14922333, 26.15493774], [89.14926147, 26.15604591], [89.14926147, 26.15613747], [89.14845276, 26.15819359], [89.14862823, 26.15872574], [89.14887238, 26.15948296], [89.15139771, 26.15977859], [89.15532684, 26.15963936], [89.15549469, 26.15995407], [89.15607452, 26.16107368], [89.15677643, 26.1624279], [89.15722656, 26.16328812], [89.15435791, 26.16389656], [89.15323639, 26.16399956], [89.15300751, 26.16456032], [89.15235138, 26.16526222], [89.1521225, 26.16529274], [89.15185547, 26.16532898], [89.15187073, 26.16629028], [89.15188599, 26.16696739], [89.15136719, 26.16776657], [89.15071869, 26.16871071], [89.15049744, 26.16908455], [89.15003204, 26.16900444], [89.15036774, 26.16930008], [89.14905548, 26.16941643], [89.14910889, 26.17013359], [89.14754486, 26.17019844], [89.14643097, 26.17024422], [89.14543152, 26.17009544], [89.14543915, 26.16973114], [89.14473724, 26.1697197], [89.14474487, 26.16950417], [89.14474487, 26.16934204], [89.14440918, 26.16934776], [89.14250946, 26.16938782], [89.14096069, 26.16939545], [89.14020538, 26.17244148], [89.14015961, 26.17338371], [89.14015198, 26.17355728], [89.14040375, 26.17381287], [89.14105988, 26.17447662], [89.1411438, 26.17589951], [89.14025879, 26.1759491], [89.13965607, 26.17549515], [89.13965607, 26.17609596], [89.13842773, 26.17605591], [89.13841248, 26.17637634], [89.13748169, 26.17636299], [89.13690948, 26.17839241], [89.13713074, 26.17917061], [89.13685608, 26.18003654], [89.13522339, 26.18007851], [89.13511658, 26.18026543], [89.13455963, 26.18127823], [89.13499451, 26.18161964], [89.13553619, 26.18166351], [89.13568115, 26.18173981], [89.13608551, 26.18194389], [89.13605499, 26.18357658], [89.13657379, 26.18362427], [89.13648987, 26.18504333], [89.13539124, 26.18555069], [89.13542175, 26.18621254], [89.13548279, 26.18738747], [89.13619995, 26.18770409], [89.13711548, 26.18766022], [89.13707733, 26.18806267], [89.13704681, 26.18837547], [89.13802338, 26.18846512], [89.13818359, 26.18863678], [89.13830566, 26.18876648], [89.13845062, 26.18942451], [89.13864136, 26.1903553], [89.13869476, 26.19130325], [89.13922119, 26.19224358], [89.13886261, 26.19354248], [89.13912201, 26.19444466], [89.13916016, 26.19456673], [89.13926697, 26.19464111], [89.13990784, 26.1950779], [89.13999939, 26.19513702], [89.13980865, 26.19716644], [89.1397934, 26.19729805], [89.1394577, 26.19803238], [89.13928223, 26.19840622], [89.13986969, 26.19853401], [89.14028168, 26.19862175], [89.14019012, 26.19916916], [89.14009857, 26.19972992], [89.14207458, 26.199646], [89.14248657, 26.20077515], [89.14352417, 26.20047951], [89.14385223, 26.20038605], [89.14399719, 26.20269585], [89.1440506, 26.20350266], [89.14710999, 26.20490646], [89.147995, 26.20651817], [89.1484375, 26.20645332], [89.14852905, 26.20643997], [89.14880371, 26.20742416], [89.14820099, 26.20760345], [89.14825439, 26.20798874], [89.14837646, 26.20885849], [89.14929199, 26.20896149], [89.14925385, 26.20912552], [89.14897919, 26.21035004], [89.14787292, 26.21041298], [89.14749908, 26.21028137], [89.14741516, 26.21113586], [89.14685822, 26.21176529], [89.14667511, 26.21116829], [89.14570618, 26.21128082], [89.14459991, 26.21263313], [89.14369202, 26.21311378], [89.14373016, 26.21360397], [89.1428299, 26.21360779], [89.1426239, 26.21470261], [89.14207458, 26.21464157], [89.14174652, 26.21630478], [89.14154816, 26.21734238], [89.14178467, 26.21739388], [89.1421051, 26.21746063], [89.14170837, 26.21871376], [89.14217377, 26.21886063], [89.14215088, 26.21993637], [89.14211273, 26.22049141], [89.14206696, 26.2210865], [89.1431427, 26.22126007], [89.1437912, 26.22136307], [89.14091492, 26.22505569], [89.1410141, 26.22541428], [89.14030457, 26.22590828], [89.14054108, 26.22653008], [89.14065552, 26.2268486], [89.14082336, 26.22729111], [89.13972473, 26.22922516], [89.13951111, 26.22961426], [89.14073181, 26.23114204], [89.14125061, 26.23178864], [89.14093781, 26.23476601], [89.14087677, 26.23587418], [89.13935089, 26.2381382], [89.13764954, 26.23677635], [89.13695526, 26.23665047], [89.13396454, 26.23757744], [89.1336441, 26.23828316], [89.13357544, 26.23843384], [89.13593292, 26.23989296], [89.13596344, 26.24006462], [89.13607025, 26.24067879], [89.13533783, 26.2412281], [89.13182831, 26.23963547], [89.13248444, 26.24196815], [89.13091278, 26.24274826], [89.13174438, 26.24492264], [89.13187408, 26.2452507], [89.13211823, 26.24587631], [89.13109589, 26.24733925], [89.13064575, 26.24798012], [89.13001251, 26.24889374], [89.12693024, 26.24892998], [89.12674713, 26.24934769], [89.12670135, 26.24945641], [89.12612152, 26.25081253], [89.12513733, 26.25070763], [89.1242981, 26.25061989], [89.12417603, 26.25060654], [89.12412262, 26.25047493], [89.12390137, 26.24985123], [89.12368011, 26.25000191], [89.11985016, 26.25268364], [89.11978912, 26.25272942], [89.12002563, 26.25290489], [89.12036896, 26.25316238], [89.12029266, 26.25331497], [89.12007141, 26.25377464], [89.11987305, 26.25420189], [89.12090302, 26.25458336], [89.12088776, 26.2551403], [89.12221527, 26.25564384], [89.12203979, 26.25642967], [89.12136078, 26.25832748], [89.12329102, 26.25876236], [89.12324524, 26.25997925], [89.12329865, 26.26007652], [89.12358856, 26.26062202], [89.12386322, 26.26114845], [89.12532806, 26.26132584], [89.1252594, 26.26154518], [89.12496948, 26.26247215], [89.12516022, 26.26356316], [89.12310028, 26.26514626], [89.1200943, 26.26674271], [89.11976624, 26.26696777], [89.11787415, 26.26828575], [89.11700439, 26.26889229], [89.11505127, 26.26988983], [89.11437988, 26.27090836], [89.11381531, 26.27111435], [89.11235809, 26.27164078], [89.11159515, 26.27275658], [89.10996246, 26.2723465], [89.10933685, 26.27219009], [89.10861206, 26.27368355], [89.10903931, 26.27535629], [89.10887146, 26.27540207], [89.10784149, 26.27567482], [89.10633087, 26.27424812], [89.10601807, 26.27396011], [89.10527039, 26.27467155], [89.1050415, 26.27524185], [89.10494995, 26.27548409], [89.1049118, 26.27556801], [89.10496521, 26.27602386], [89.10501862, 26.2765007], [89.10513306, 26.27757454], [89.10515594, 26.27777481], [89.10544586, 26.27791786], [89.10591888, 26.27815437], [89.10600281, 26.27941322], [89.10597229, 26.28118515], [89.10582733, 26.28117561], [89.1056366, 26.28116608], [89.10552979, 26.28116035], [89.10436249, 26.2810955], [89.10393524, 26.28107071], [89.1033783, 26.28111839], [89.10337067, 26.28086853], [89.10328674, 26.27869225], [89.10300446, 26.27857971], [89.10198975, 26.27816963], [89.10017395, 26.27947998], [89.10005188, 26.27956581], [89.10015106, 26.27967262], [89.10120392, 26.28085518], [89.10127258, 26.28093147], [89.10183716, 26.28130913], [89.10237122, 26.28166962], [89.10258484, 26.28180885], [89.10231781, 26.28189278], [89.10186768, 26.28203201], [89.10168457, 26.28310966], [89.10198212, 26.28423882], [89.10234833, 26.28615189], [89.10237122, 26.2863121], [89.10253906, 26.28871346], [89.10347748, 26.28928566], [89.10449219, 26.28928375], [89.10430908, 26.28998184], [89.10641479, 26.29043961], [89.10696411, 26.29152489], [89.10707855, 26.29174995], [89.10497284, 26.29252052], [89.10433197, 26.2929306], [89.10326385, 26.29360962], [89.10346222, 26.29537773], [89.10365295, 26.29703712], [89.10494232, 26.29784584], [89.10731506, 26.29932785], [89.10417938, 26.30172729], [89.10377502, 26.30203629], [89.10295105, 26.30216789], [89.09973907, 26.30268097], [89.09919739, 26.30412102], [89.09959412, 26.30459595], [89.10053253, 26.30569267], [89.10155487, 26.30689812], [89.10287476, 26.30839729], [89.10287476, 26.30854034], [89.10269928, 26.31189156], [89.10268402, 26.31225014], [89.10347748, 26.31279182], [89.10335541, 26.31334114], [89.10482788, 26.31320763], [89.10466766, 26.3139267], [89.10463715, 26.31492615], [89.10469055, 26.3159256], [89.10495758, 26.31591034], [89.10603333, 26.3158474], [89.1060791, 26.31539536], [89.10503387, 26.31530571], [89.10497284, 26.31399155], [89.10501862, 26.31390953], [89.105896, 26.31377983], [89.10601044, 26.31376266], [89.10635376, 26.31371117], [89.1062851, 26.31337929], [89.10654449, 26.31334686], [89.10824585, 26.31312752], [89.10823059, 26.31297874], [89.10791016, 26.30932045], [89.10887909, 26.30937195], [89.10887146, 26.30837822], [89.10886383, 26.30735779], [89.10906219, 26.30731201], [89.10961914, 26.30845261], [89.11051941, 26.31100082], [89.11071777, 26.31270027], [89.11110687, 26.31456947], [89.11155701, 26.31568909], [89.11251831, 26.3169899], [89.11371613, 26.31687164], [89.11553192, 26.3139019], [89.11634064, 26.31100082], [89.11708832, 26.30861092], [89.11859894, 26.30705833], [89.12062073, 26.30629921], [89.12224579, 26.30277061], [89.12319183, 26.2994194], [89.1233902, 26.29796982], [89.12361908, 26.29623985], [89.1243515, 26.29369164], [89.12451172, 26.29411697], [89.1267395, 26.29577827], [89.12725067, 26.29615784], [89.12835693, 26.29619408], [89.12845612, 26.29619789], [89.12839508, 26.29669189], [89.12822723, 26.297966], [89.13053894, 26.29806519], [89.13134766, 26.29755402], [89.13156891, 26.29741478], [89.13131714, 26.29813576], [89.13111115, 26.29872131], [89.13230133, 26.29881477], [89.13240814, 26.2988224], [89.13235474, 26.30031967], [89.12995148, 26.30045128], [89.13012695, 26.29985046], [89.13034058, 26.2991333], [89.13038635, 26.29897499], [89.12862396, 26.29889107], [89.12809753, 26.30125237], [89.12797546, 26.30132675], [89.12785339, 26.30139923], [89.12739563, 26.30167007], [89.12743378, 26.30256271], [89.12746429, 26.30313683], [89.1288681, 26.30321121], [89.1288147, 26.30261993], [89.12877655, 26.30218697], [89.12872314, 26.30163956], [89.1288147, 26.30161858], [89.13127899, 26.30101013], [89.13080597, 26.30213928], [89.13067627, 26.30244255], [89.13010406, 26.30339813], [89.12999725, 26.30356979], [89.13077545, 26.30365181], [89.13057709, 26.30487823], [89.13051605, 26.3052845], [89.12989044, 26.30488205], [89.12837219, 26.3042717], [89.1282959, 26.30424118], [89.12822723, 26.30429268], [89.12747955, 26.30487061], [89.1271286, 26.30514145], [89.12564087, 26.30425072], [89.12516022, 26.30544853], [89.12718201, 26.30607414], [89.12765503, 26.3062191], [89.12901306, 26.30585861], [89.129776, 26.30593109], [89.13143158, 26.30608368], [89.13169861, 26.30610847], [89.13319397, 26.30596733], [89.13368988, 26.30592155], [89.1340332, 26.30685806], [89.13420105, 26.30732155], [89.13425446, 26.30747032], [89.13454437, 26.30747795], [89.13477325, 26.30779076], [89.13605499, 26.30790138], [89.1361618, 26.30828476], [89.13634491, 26.30891418], [89.13532257, 26.30887032], [89.13513947, 26.30955887], [89.13488007, 26.31135368], [89.13289642, 26.31128883], [89.13276672, 26.31197166], [89.13381195, 26.31206322], [89.13477325, 26.31214523], [89.13486481, 26.31215477], [89.13476563, 26.31324768], [89.1296463, 26.31259155], [89.12953186, 26.3125782], [89.12950134, 26.31313705], [89.12974548, 26.31316376], [89.13034058, 26.31322479], [89.1339035, 26.31377411], [89.13446045, 26.31385803], [89.13515472, 26.31466675], [89.13536072, 26.31467819], [89.1359787, 26.31471252], [89.13596344, 26.31700134], [89.13619232, 26.31962776], [89.13624573, 26.32021713], [89.13565063, 26.32032585], [89.13524628, 26.32040215], [89.13535309, 26.32059097], [89.13565826, 26.32112312], [89.13578033, 26.32133102], [89.13468933, 26.32144165], [89.13456726, 26.32145309], [89.13450623, 26.32136345], [89.13395691, 26.32062912], [89.13237, 26.32062149], [89.13093567, 26.32061386], [89.13076782, 26.31991959], [89.13053894, 26.31900406], [89.13027954, 26.31899071], [89.12825012, 26.3188858], [89.12820435, 26.31968498], [89.12604523, 26.31949997], [89.12529755, 26.32008362], [89.12522125, 26.32014084], [89.12509918, 26.32009125], [89.12371063, 26.3194294], [89.12226868, 26.31925964], [89.12201691, 26.31922913], [89.12043762, 26.31972122], [89.12030029, 26.31974983], [89.11985016, 26.32103729], [89.11932373, 26.32094002], [89.11937714, 26.3203392], [89.1193161, 26.32022858], [89.11736298, 26.32036018], [89.11701202, 26.3202877], [89.1164856, 26.32019615], [89.11632538, 26.32016754], [89.11544037, 26.32001305], [89.11636353, 26.31870079], [89.11642456, 26.31861496], [89.1162796, 26.31859589], [89.1149292, 26.31842041], [89.1145401, 26.31868172], [89.1126709, 26.31851006], [89.11148071, 26.32011414], [89.1115036, 26.3206768], [89.11073303, 26.3217411], [89.11045074, 26.32212257], [89.11184692, 26.32238388], [89.11177826, 26.3230381], [89.11139679, 26.32376671], [89.11019897, 26.32454872], [89.11010742, 26.32486725], [89.10996246, 26.32536125], [89.10871887, 26.32557106], [89.10826874, 26.32546616], [89.10781097, 26.32669258], [89.10726929, 26.32685852], [89.10692596, 26.32671928], [89.1065979, 26.32658577], [89.10564423, 26.32661057], [89.10566711, 26.32651711], [89.10580444, 26.3259182], [89.10567474, 26.32548714], [89.10549164, 26.32489777], [89.10466766, 26.325037], [89.10463715, 26.32489777], [89.10428619, 26.32338715], [89.10409546, 26.32338333], [89.10335541, 26.32336998], [89.10360718, 26.32301712], [89.10308075, 26.32308388], [89.10044861, 26.32341385], [89.1004715, 26.32354164], [89.10055542, 26.32402611], [89.09864807, 26.32417107], [89.09860229, 26.32468605], [89.09856415, 26.32502174], [89.09857941, 26.32514], [89.09864044, 26.32586098], [89.09934235, 26.32837677], [89.09915161, 26.32847023], [89.09892273, 26.32858086], [89.0982666, 26.32890129], [89.09816742, 26.32892799], [89.09673309, 26.32932281], [89.09642792, 26.32773399], [89.09551239, 26.32686996], [89.09550476, 26.32678413], [89.09545898, 26.32636261], [89.09537506, 26.32567596], [89.09527588, 26.32568932], [89.09355927, 26.32590866], [89.09352112, 26.32574463], [89.09316254, 26.32419586], [89.09290314, 26.32431412], [89.09277344, 26.32436943], [89.09275055, 26.32427216], [89.0921936, 26.32189178], [89.09185028, 26.3204155], [89.0916214, 26.32041359], [89.09145355, 26.32040977], [89.08979034, 26.3224678], [89.08925629, 26.32226563], [89.08744049, 26.32158852], [89.08742523, 26.32172585], [89.08721924, 26.3231163], [89.08720398, 26.32322884], [89.08686829, 26.3230896], [89.08439636, 26.32205009], [89.0837326, 26.32229805], [89.08364105, 26.32322693], [89.08454132, 26.32366943], [89.08579254, 26.32427979], [89.08879089, 26.32547188], [89.08950043, 26.32726479], [89.09120178, 26.32801056], [89.09157562, 26.3281765], [89.0911026, 26.32916451], [89.09088898, 26.32959557], [89.09142303, 26.32984161], [89.09274292, 26.32972717], [89.09306335, 26.32969856], [89.09320068, 26.32995796], [89.09527588, 26.32988167], [89.09544373, 26.33126068], [89.09546661, 26.33143425], [89.09558868, 26.33139992], [89.09619141, 26.3312397], [89.09642029, 26.33356857], [89.09646606, 26.33403397], [89.09708405, 26.33393288], [89.09734344, 26.33389091], [89.09809113, 26.33433342], [89.0982132, 26.33543587], [89.09828186, 26.33602905], [89.10016632, 26.33655167], [89.10087585, 26.33660316], [89.10128784, 26.33663368], [89.10126495, 26.33716011], [89.10071564, 26.33723068], [89.10015869, 26.33730316], [89.10015869, 26.33741188], [89.10022736, 26.33904266], [89.09931946, 26.33904457], [89.09899902, 26.33921242], [89.09771729, 26.33986855], [89.09779358, 26.34029388], [89.09809113, 26.34184265], [89.09873962, 26.34189415], [89.09848785, 26.34316254], [89.09807587, 26.34521294], [89.09809875, 26.34532738], [89.09851837, 26.34786415], [89.09815979, 26.34860802], [89.09789276, 26.34987259], [89.09599304, 26.35025215], [89.09590912, 26.35032272], [89.09577942, 26.35062218], [89.09545898, 26.35137749], [89.09515381, 26.35208893], [89.09535217, 26.35255814], [89.09580994, 26.3536396], [89.09590912, 26.35387611], [89.09506226, 26.35405731], [89.09443665, 26.35254669], [89.0940094, 26.3527317], [89.0933075, 26.3530407], [89.09386444, 26.35471535], [89.0958252, 26.35427475], [89.09584808, 26.35441971], [89.09637451, 26.35728073], [89.0981369, 26.35814857], [89.09822083, 26.35819054], [89.09825897, 26.35868073], [89.09828186, 26.35902786], [89.09632111, 26.35928154], [89.09630585, 26.35960197], [89.09627533, 26.36018562], [89.09461975, 26.36019135], [89.09397125, 26.36019325], [89.09377289, 26.36056709], [89.09370422, 26.3598175], [89.09268188, 26.35980415], [89.09265137, 26.35994339], [89.09249115, 26.3608036], [89.09203339, 26.36077309], [89.09141541, 26.36073303], [89.09011841, 26.36064529], [89.08982086, 26.36062622], [89.08972168, 26.36174774], [89.08969879, 26.36207962], [89.08921051, 26.36217499], [89.08691406, 26.36263084], [89.08575439, 26.36285973], [89.08575439, 26.36362648], [89.08576202, 26.3639698], [89.08441925, 26.36413574], [89.0841217, 26.36417198], [89.08325958, 26.36340141], [89.0831604, 26.36309052], [89.08289337, 26.36222458], [89.08273315, 26.36226082], [89.07965851, 26.36293793], [89.07966614, 26.36304665], [89.07985687, 26.36632538], [89.07988739, 26.36677551], [89.08617401, 26.36605263], [89.08694458, 26.36595917], [89.08685303, 26.36611748], [89.08718872, 26.36764908], [89.08795166, 26.36821175], [89.08898926, 26.36834717], [89.08898926, 26.37088203], [89.08898926, 26.37132835], [89.08989716, 26.37130165], [89.09038544, 26.37408829], [89.0904541, 26.37444115], [89.0905838, 26.37518501], [89.08901978, 26.37580109], [89.08887482, 26.3758564], [89.08889008, 26.37629318], [89.08894348, 26.37866974], [89.08896637, 26.37973404], [89.08899689, 26.38085175], [89.08899689, 26.38101768], [89.08943939, 26.38099861], [89.09034729, 26.38095665], [89.09046936, 26.38167], [89.09049225, 26.38181686], [89.09176636, 26.38258934], [89.09172821, 26.38319778], [89.09161377, 26.38538551], [89.08997345, 26.38547897], [89.09004211, 26.38567734], [89.09082794, 26.3881588], [89.09249878, 26.38968468], [89.09365082, 26.38946724], [89.0942688, 26.3893528], [89.09431458, 26.38950157], [89.09461212, 26.3904705], [89.09568024, 26.39154053], [89.0955658, 26.39159775], [89.09339142, 26.39267731], [89.09339905, 26.39280891], [89.09269714, 26.39256096], [89.0923233, 26.3924408], [89.09092712, 26.39210129], [89.09069061, 26.39221382], [89.09062195, 26.39212608], [89.0904007, 26.3918457], [89.08892059, 26.39204597], [89.08641052, 26.39238548], [89.0859375, 26.39245033], [89.08582306, 26.39192009], [89.08576965, 26.39170265], [89.08531952, 26.39163589], [89.08339691, 26.39134979], [89.08335114, 26.39044571], [89.08334351, 26.39037132], [89.08298492, 26.39035606], [89.08126831, 26.39028358], [89.08125305, 26.3903656], [89.08116913, 26.39110184], [89.08105469, 26.39114761], [89.08084106, 26.39123154], [89.08003235, 26.39155197], [89.07991791, 26.39159393], [89.08003998, 26.39180565], [89.08055115, 26.39270401], [89.08072662, 26.39302254], [89.081604, 26.39270401], [89.08206177, 26.39253807], [89.08216858, 26.39258194], [89.08380127, 26.3932724], [89.08478546, 26.39368629], [89.08517456, 26.39385033], [89.08668518, 26.39535141], [89.08721924, 26.39757156], [89.08727264, 26.39776421], [89.08616638, 26.39775467], [89.08537292, 26.39751053], [89.08396912, 26.39542007], [89.08326721, 26.39474106], [89.08168793, 26.39499092], [89.08132935, 26.39687157], [89.08101654, 26.39712143], [89.07530212, 26.39608002], [89.07524872, 26.39574051], [89.07484436, 26.39335632], [89.07453156, 26.39145279], [89.07447815, 26.39112473], [89.07374573, 26.39126968], [89.07379913, 26.39153099], [89.0747757, 26.3960743], [89.07118225, 26.39850235], [89.0708847, 26.39841461], [89.06943512, 26.39798164], [89.0693512, 26.39795685], [89.06848145, 26.39769936], [89.06841278, 26.39783859], [89.0675354, 26.39950562], [89.06633759, 26.39867973], [89.06437683, 26.39822578], [89.06438446, 26.39689064], [89.06439209, 26.39673424], [89.06424713, 26.39679718], [89.06302643, 26.39735031], [89.06180573, 26.39790344], [89.06266785, 26.39938354], [89.06227112, 26.39965057], [89.06143188, 26.39828491], [89.06124115, 26.39833641], [89.06053162, 26.39852333], [89.05911255, 26.39889717], [89.05896759, 26.39893532], [89.05893707, 26.39872932], [89.05852509, 26.39591408], [89.05843353, 26.39585304], [89.05789185, 26.39551544], [89.05780029, 26.39545441], [89.05567932, 26.39594269], [89.05535126, 26.39683151], [89.05531311, 26.39692497], [89.05509949, 26.39751434], [89.05440521, 26.39841652], [89.05414581, 26.39875031], [89.054039, 26.39875221], [89.05045319, 26.39885902], [89.0497818, 26.3988781], [89.04964447, 26.39893913], [89.04889679, 26.39927292], [89.04821777, 26.39957237], [89.04624939, 26.39993095], [89.04582214, 26.39793968], [89.04471588, 26.39723015], [89.04132843, 26.39799118], [89.04103851, 26.39792061], [89.04096222, 26.39799118], [89.04065704, 26.39931107], [89.04076385, 26.39999008], [89.03939056, 26.40029144], [89.03921509, 26.40023804], [89.03840637, 26.39997292], [89.0377655, 26.39976501], [89.03781128, 26.39858818], [89.03784943, 26.39746284], [89.03785706, 26.39731979], [89.03746033, 26.3968544], [89.0381012, 26.39666367], [89.03804016, 26.39653969], [89.03746796, 26.39539909], [89.03739929, 26.39526558], [89.03713226, 26.39530563], [89.03666687, 26.3953743], [89.03664398, 26.39496422], [89.0335083, 26.39553261], [89.0343399, 26.39956284], [89.03289795, 26.40003395], [89.0318222, 26.39966393], [89.03174591, 26.39968681], [89.03177643, 26.40052223], [89.03181458, 26.40166664], [89.0318222, 26.40184784], [89.03166199, 26.40186501], [89.03128815, 26.40190506], [89.03129578, 26.40202904], [89.03136444, 26.40392685], [89.03048706, 26.40384674], [89.02998352, 26.40380096], [89.02934265, 26.404953], [89.02992249, 26.40694809], [89.02996826, 26.4071064], [89.02977753, 26.40717888], [89.02864075, 26.40759659], [89.02798462, 26.40783691], [89.02667236, 26.40751457], [89.02584839, 26.40731049], [89.02439117, 26.40782356], [89.02426147, 26.4068737], [89.02310944, 26.40608215], [89.02212524, 26.40589714], [89.02197266, 26.40586853], [89.02200317, 26.40578461], [89.02211761, 26.40547371], [89.02259064, 26.40415001], [89.02264404, 26.40401077], [89.02136993, 26.40402985], [89.02032471, 26.40413284], [89.01935577, 26.40422821], [89.01891327, 26.40616035], [89.02040863, 26.40688324], [89.0205307, 26.4069519], [89.02155304, 26.40839386], [89.02277374, 26.40833282], [89.02302551, 26.40831947], [89.02240753, 26.41210747], [89.02173615, 26.41408348], [89.02170563, 26.41417122], [89.02140808, 26.41423035], [89.02003479, 26.41450882], [89.01799011, 26.41519356], [89.01787567, 26.41523361], [89.01750183, 26.41497231], [89.01725769, 26.41480446], [89.01444244, 26.41422462], [89.01219177, 26.41338348], [89.00994873, 26.41313934], [89.00814819, 26.41294289], [89.007164, 26.41283417], [89.00720215, 26.41312408], [89.00733185, 26.41430092], [89.007164, 26.41430664], [89.00667572, 26.41432571], [89.00619507, 26.41572762], [89.00582123, 26.4167881], [89.00565338, 26.41679764], [89.00502777, 26.41683006], [89.00508881, 26.4171772], [89.00489807, 26.41712952], [89.00348663, 26.41788292], [89.00335693, 26.41996193], [89.00049591, 26.41996193], [88.99913025, 26.42134285], [88.99906921, 26.42139816], [88.99875641, 26.42044449], [88.99832916, 26.42049217], [88.99568176, 26.42078972], [88.99568939, 26.42089462], [88.99573517, 26.42142677], [88.99585724, 26.42268944], [88.99474335, 26.42288399], [88.99367523, 26.42307091], [88.99346161, 26.42228317], [88.99295807, 26.4203968], [88.99311829, 26.42036438], [88.9956665, 26.4198246], [88.99595642, 26.41976357], [88.99590302, 26.41953468], [88.99559021, 26.41818428], [88.99524689, 26.41675377], [88.99578857, 26.41667938], [88.99790192, 26.41553307], [88.99819946, 26.41417885], [88.99822998, 26.41404724], [88.99835968, 26.41344833], [88.99839783, 26.41327477], [88.9963913, 26.41254044], [88.99397278, 26.41289711], [88.99411011, 26.41394424], [88.99423981, 26.41494942], [88.99422455, 26.41525078], [88.99414063, 26.41685677], [88.99220276, 26.41709709], [88.99211121, 26.41710854], [88.99226379, 26.417593], [88.9927063, 26.4189949], [88.99136353, 26.42023468], [88.98838806, 26.4204483], [88.98547363, 26.42022705], [88.98308563, 26.42109489], [88.9829483, 26.42114639], [88.98340607, 26.42359543], [88.98357391, 26.42448997], [88.98159027, 26.42508507], [88.98069, 26.42535591], [88.98108673, 26.42577171], [88.98151398, 26.42621994], [88.98143005, 26.42628098], [88.98085022, 26.42669868], [88.98279572, 26.4285202], [88.98384094, 26.42949867], [88.98297882, 26.43097687], [88.98140717, 26.43041039], [88.98036957, 26.43168831], [88.97976685, 26.43384552], [88.97884369, 26.43393517], [88.97854614, 26.43396378], [88.97872162, 26.4360981], [88.98120117, 26.43664551], [88.9828186, 26.43808365], [88.98311615, 26.44012833], [88.9832077, 26.44079208], [88.98423004, 26.44169044], [88.98317719, 26.44212151], [88.98290253, 26.44161034], [88.98087311, 26.44184875], [88.98091125, 26.4430027], [88.9809494, 26.44425201], [88.9824295, 26.4440136], [88.98285675, 26.44542885], [88.9832077, 26.44659424], [88.98088837, 26.44689178], [88.97871399, 26.44633102], [88.97846985, 26.44626999], [88.97847748, 26.44800758], [88.97847748, 26.4481926], [88.97927094, 26.44822884], [88.97935486, 26.44973183], [88.97724915, 26.44921112], [88.97669983, 26.44630814], [88.97640991, 26.44637108], [88.97576141, 26.44651413], [88.97592926, 26.44706917], [88.97612, 26.44771385], [88.97499084, 26.44874001], [88.97498322, 26.44995308], [88.97138214, 26.45031357], [88.97103119, 26.45143509], [88.96728516, 26.45136261], [88.96624756, 26.45134163], [88.96632385, 26.45176315], [88.96639252, 26.45217514], [88.9665451, 26.45298576], [88.96613312, 26.45298958], [88.96559143, 26.4529953], [88.96560669, 26.45445251], [88.96562958, 26.45598221], [88.96565247, 26.45765114], [88.9646759, 26.45741081], [88.95877838, 26.45910263], [88.95713806, 26.45953178], [88.95579529, 26.46029663], [88.95545959, 26.45991135], [88.95720673, 26.45915222], [88.9572525, 26.4548645], [88.95796204, 26.45464516], [88.95908356, 26.45429039], [88.95933533, 26.45318031], [88.95941925, 26.45300674], [88.9597168, 26.45240021], [88.95996094, 26.45241928], [88.9628067, 26.4526329], [88.96521759, 26.4519825], [88.96398163, 26.45116806], [88.96277618, 26.45013428], [88.96144104, 26.44913101], [88.96054077, 26.44837189], [88.95821381, 26.44959831], [88.95365906, 26.45186234], [88.95344543, 26.45196724], [88.95108795, 26.45211983], [88.95181274, 26.44849777], [88.94992065, 26.44812775], [88.94612885, 26.44803619], [88.94599915, 26.44498444], [88.94660187, 26.4448719], [88.94704437, 26.44478989], [88.9468689, 26.44413757], [88.94669342, 26.44349098], [88.94737244, 26.44342041], [88.94902039, 26.44324684], [88.9489975, 26.44207382], [88.94895935, 26.43999672], [88.94684601, 26.43942261], [88.94777679, 26.4389534], [88.9491272, 26.43826675], [88.95042419, 26.4358654], [88.9512558, 26.43510628], [88.95124054, 26.43486977], [88.95114136, 26.43371582], [88.95050049, 26.4335289], [88.94786072, 26.43317032], [88.9454422, 26.43281937], [88.94497681, 26.43166924], [88.94475555, 26.43111038], [88.94457245, 26.43065643], [88.94548798, 26.43044281], [88.94549561, 26.42969513], [88.94549561, 26.42910004], [88.94429779, 26.42916298], [88.9443512, 26.4284935], [88.94275665, 26.42828178], [88.94290161, 26.4273243], [88.94322968, 26.42702866], [88.9439621, 26.42636871], [88.94471741, 26.42568398], [88.9418335, 26.42539406], [88.93831635, 26.42570114], [88.93800354, 26.42572784], [88.93804169, 26.42734528], [88.93806458, 26.42821884], [88.93728638, 26.42918968], [88.93630981, 26.43039894], [88.93388367, 26.43167114], [88.92809296, 26.4330368], [88.9281311, 26.43206596], [88.92614746, 26.43216324], [88.92543793, 26.42912292], [88.92588806, 26.42772675], [88.92601013, 26.42767525], [88.92751312, 26.42700958], [88.93148041, 26.42743492], [88.93271637, 26.42756653], [88.93360901, 26.42662239], [88.93309784, 26.42622375], [88.932724, 26.42593575], [88.93171692, 26.42506409], [88.9319458, 26.42288971], [88.93369293, 26.42110825], [88.9363327, 26.41988945], [88.93701172, 26.41851997], [88.93662262, 26.41682053], [88.93525696, 26.41370964], [88.93373871, 26.41218948], [88.93094635, 26.41044998], [88.92854309, 26.41052818], [88.92749023, 26.40884399], [88.92697906, 26.40782356], [88.92650604, 26.40689278], [88.92424011, 26.40698624], [88.92363739, 26.4070797], [88.91970062, 26.40751076], [88.91815186, 26.40773773], [88.9156189, 26.40828896], [88.91461945, 26.40859413], [88.91382599, 26.408638], [88.91253662, 26.40870857], [88.9125824, 26.4081459], [88.91010284, 26.4076767], [88.90670776, 26.406744], [88.90473175, 26.40856552], [88.90393829, 26.40813446], [88.90543365, 26.40610123], [88.90563965, 26.40582848], [88.90557098, 26.40559387], [88.90518951, 26.40432358], [88.90611267, 26.40361786], [88.90621185, 26.40362549], [88.90866852, 26.40380669], [88.90872192, 26.4030304], [88.90882111, 26.40153503], [88.90971375, 26.40098572], [88.90989685, 26.40087128], [88.91155243, 26.40103722], [88.91251373, 26.40146446], [88.91290283, 26.40317154], [88.91576385, 26.40366364], [88.91719818, 26.40327072], [88.91746521, 26.40249252], [88.91757965, 26.40216064], [88.91802216, 26.40088463], [88.91809082, 26.40000534], [88.91817474, 26.39905357], [88.91830444, 26.39756775], [88.91876984, 26.39504433], [88.91868591, 26.39404297], [88.91859436, 26.39302635], [88.9185791, 26.3927803], [88.91840363, 26.39023018], [88.91830444, 26.39024162], [88.91727448, 26.3903389], [88.91638947, 26.3893013], [88.91683197, 26.38791275], [88.91613007, 26.38665962], [88.91622925, 26.38615417], [88.9164505, 26.38496017], [88.91629028, 26.38488388], [88.91416168, 26.38389397], [88.91207886, 26.38372612], [88.91208649, 26.38258934], [88.90969849, 26.3823185], [88.90943909, 26.38146019], [88.90904236, 26.38013649], [88.91229248, 26.38038445], [88.9136734, 26.37801743], [88.91481018, 26.37841034], [88.9153595, 26.378088], [88.91782379, 26.37833214], [88.92054749, 26.37864876], [88.92114258, 26.37763977], [88.92134094, 26.37730408], [88.92123413, 26.377285], [88.91963196, 26.37698555], [88.91952515, 26.37687111], [88.91968536, 26.37617302], [88.91983032, 26.37553024], [88.92002106, 26.3746891], [88.91777039, 26.37465096], [88.918396, 26.37319183], [88.91989136, 26.3699398], [88.92214203, 26.36865997], [88.92455292, 26.3686924], [88.92662811, 26.36828041], [88.92685699, 26.36663055], [88.92648315, 26.36540985], [88.92627716, 26.36474228], [88.92697906, 26.36450386], [88.92788696, 26.3642025], [88.92892456, 26.36385345], [88.92900848, 26.36358643], [88.9291687, 26.36365128], [88.92930603, 26.36385155], [88.93032074, 26.36534119], [88.93139648, 26.36621284], [88.93254089, 26.36713982], [88.93519592, 26.36762047], [88.93547821, 26.36688042], [88.93593597, 26.36568069], [88.93768311, 26.36293983], [88.94052124, 26.36165047], [88.94111633, 26.36137009], [88.94539642, 26.36018944], [88.94732666, 26.36005402], [88.94731903, 26.36070061], [88.94839478, 26.36083603], [88.94846344, 26.36139488], [88.94860077, 26.36245155], [88.94866943, 26.36301804], [88.9491806, 26.36465454], [88.95042419, 26.36632156], [88.95330048, 26.36606598], [88.95397186, 26.36392975], [88.9543457, 26.36287689], [88.95469666, 26.36190605], [88.9548111, 26.361866], [88.95481873, 26.36226082], [88.95568085, 26.36610985], [88.95677185, 26.36803055], [88.96086884, 26.36770058], [88.96250153, 26.36655045], [88.96362305, 26.36580276], [88.96450806, 26.36503029], [88.96549988, 26.36418915], [88.96460724, 26.36234474], [88.96450806, 26.36213112], [88.96432495, 26.36173439], [88.96414948, 26.36136055], [88.96286774, 26.36081696], [88.96258545, 26.36069679], [88.96226501, 26.36067009], [88.96194458, 26.36042213], [88.96156311, 26.36026192], [88.96126556, 26.3599987], [88.96120453, 26.35994148], [88.95887756, 26.35789108], [88.95620728, 26.35626984], [88.95549774, 26.35371971], [88.95448303, 26.35152054], [88.95362091, 26.34897041], [88.9540329, 26.34699059], [88.95625305, 26.34673119], [88.95884705, 26.34737968], [88.95985413, 26.3475647], [88.95920563, 26.34799004], [88.95911407, 26.34804916], [88.95928955, 26.34818077], [88.95955658, 26.34837914], [88.96044922, 26.3490448], [88.96066284, 26.34920692], [88.96056366, 26.35087204], [88.96052551, 26.35153198], [88.96134949, 26.35240364], [88.96305847, 26.35191727], [88.96318817, 26.35019112], [88.96486664, 26.34968185], [88.9645462, 26.34897232], [88.96590424, 26.34964752], [88.96668243, 26.35193443], [88.96778107, 26.35034943], [88.96839905, 26.3501873], [88.96996307, 26.34977722], [88.97121429, 26.3499794], [88.97144318, 26.35001755], [88.97148132, 26.35056496], [88.97155762, 26.35149574], [88.97264099, 26.35180283], [88.9732666, 26.3510704], [88.97494507, 26.35089111], [88.97550964, 26.34944153], [88.97657776, 26.34905624], [88.97801971, 26.34745598], [88.97737122, 26.34709549], [88.97966766, 26.34661102], [88.9803009, 26.34799004], [88.9825058, 26.34810829], [88.98252869, 26.34824371], [88.98268127, 26.34910965], [88.98445129, 26.34916496], [88.98529053, 26.34850121], [88.98461914, 26.34928513], [88.98415375, 26.349823], [88.98508453, 26.35004425], [88.98719788, 26.34805679], [88.98666382, 26.34823799], [88.98768616, 26.34721375], [88.98671722, 26.34726715], [88.9861145, 26.34729958], [88.98610687, 26.34657097], [88.98674011, 26.34654427], [88.98711395, 26.34252167], [88.98871613, 26.34126091], [88.9899826, 26.33857727], [88.98905182, 26.33840561], [88.98722839, 26.33808708], [88.98783112, 26.33867264], [88.98857117, 26.3393898], [88.9885788, 26.33946609], [88.98592377, 26.3399086], [88.98609161, 26.34030533], [88.98659515, 26.3414669], [88.98455048, 26.34082985], [88.98348236, 26.34166527], [88.98174286, 26.34110451], [88.98182678, 26.34078979], [88.98228455, 26.33911324], [88.98453522, 26.33657074], [88.98479462, 26.33403015], [88.98646545, 26.33249283], [88.98686218, 26.3321228], [88.9890976, 26.3324852], [88.9899826, 26.33437157], [88.99002838, 26.33548164], [88.99259949, 26.33491516], [88.99214172, 26.33404541], [88.99179077, 26.33338928], [88.99190521, 26.33333969], [88.99368286, 26.33252716], [88.99626923, 26.33196259], [88.99877167, 26.33189011], [88.99940491, 26.33015823], [89.00090027, 26.32985687], [89.00080109, 26.32948112], [89.00095367, 26.32948494], [89.00119781, 26.32952118], [89.00153351, 26.32959747], [89.00191498, 26.32972145], [89.0022583, 26.32986069], [89.00263977, 26.33000183], [89.00300598, 26.33020782], [89.00340271, 26.33046341], [89.0037384, 26.33070946], [89.00397491, 26.3309021], [89.0041275, 26.33106804], [89.00424957, 26.33136368], [89.0043335, 26.33169937], [89.00445557, 26.33202553], [89.00457764, 26.33220482], [89.00465393, 26.33230591], [89.00485229, 26.33237267], [89.00508118, 26.33245659], [89.00531006, 26.33250999], [89.00538635, 26.33261108], [89.00530243, 26.33282089], [89.00519562, 26.33315659], [89.00507355, 26.3334465], [89.00499725, 26.33358383], [89.00489044, 26.33372307], [89.00491333, 26.3338871], [89.00665283, 26.33279991], [89.00726318, 26.33131027], [89.00762939, 26.32863998], [89.0065918, 26.32661057], [89.00405121, 26.32471085], [89.00271606, 26.32448959], [89.00002289, 26.3247509], [88.99944305, 26.32310295], [89.00094604, 26.32152939], [89.00232697, 26.32009125], [89.00269318, 26.31972122], [89.00328827, 26.31817818], [89.00337219, 26.31796074], [89.00228882, 26.31660271], [89.00032806, 26.31661987], [88.997612, 26.31785011], [88.99642181, 26.3183918], [88.99585724, 26.31866074], [88.99397278, 26.32003403], [88.99425507, 26.317276], [88.99705505, 26.31653404], [88.99632263, 26.31545448], [88.99488068, 26.31334305], [88.99331665, 26.3150425], [88.99191284, 26.3151207], [88.9905014, 26.31240082], [88.99047089, 26.30864906], [88.99076843, 26.30723], [88.99114227, 26.30607986], [88.99188995, 26.30477905], [88.99352264, 26.30391121], [88.99610901, 26.30291939], [88.9988327, 26.30216026], [89.00154877, 26.30201912], [89.00331879, 26.30183029], [89.00348663, 26.30001068], [89.00321198, 26.29926109], [89.00213623, 26.29639053], [89.0021286, 26.29549026], [89.00232697, 26.29557419], [89.00340271, 26.2960186], [89.00358582, 26.29644585], [89.00450134, 26.2986145], [89.00415039, 26.30215836], [89.00418091, 26.30243683], [89.0043335, 26.30377388], [89.00578308, 26.30274773], [89.00587463, 26.3029213], [89.0065918, 26.30428696], [89.00666809, 26.30443382], [89.00754547, 26.30424309], [89.00763702, 26.30422211], [89.00805664, 26.30231476], [89.00812531, 26.30199051], [89.00839233, 26.30198288], [89.00948334, 26.30195808], [89.00995636, 26.30194664], [89.01021576, 26.30194092], [89.01036072, 26.30119896], [89.01040649, 26.30095673], [89.01051331, 26.29881096], [89.01078033, 26.29870415], [89.01299286, 26.29807472], [89.01282501, 26.29783249], [89.01236725, 26.29716873], [89.0120697, 26.29373169], [89.01235962, 26.29340553], [89.01423645, 26.29133606], [89.01490784, 26.29086113], [89.01683044, 26.28949356], [89.0169754, 26.28970909], [89.01850128, 26.29200363], [89.01869202, 26.29246712], [89.01890564, 26.29296875], [89.01920319, 26.29367256], [89.01985931, 26.29371834], [89.0200119, 26.29372787], [89.01992798, 26.29395294], [89.01965332, 26.29468155], [89.01956177, 26.29509354], [89.01818848, 26.29554176], [89.01720428, 26.29663277], [89.01718903, 26.29674339], [89.0169754, 26.29824829], [89.01589966, 26.29968834], [89.01470184, 26.29901886], [89.01452637, 26.29892349], [89.01443481, 26.29942894], [89.01433563, 26.29994583], [89.01426697, 26.30033684], [89.01545715, 26.30034637], [89.01557922, 26.30034828], [89.01608276, 26.30112839], [89.01631927, 26.30149651], [89.01555634, 26.3022213], [89.01638031, 26.30345726], [89.0164566, 26.30356979], [89.01674652, 26.30341721], [89.01725769, 26.30314827], [89.01740265, 26.30371666], [89.01766205, 26.30475235], [89.01977539, 26.30506897], [89.02005768, 26.30511093], [89.01893616, 26.30539322], [89.01878357, 26.30543327], [89.01867676, 26.30720901], [89.02020264, 26.30713463], [89.02035522, 26.307127], [89.02086639, 26.30850792], [89.02111053, 26.30917549], [89.02122498, 26.30886841], [89.02172089, 26.30752373], [89.02189636, 26.30766678], [89.02259827, 26.30825996], [89.0243454, 26.30774689], [89.02523041, 26.30708694], [89.02561951, 26.30870056], [89.02688599, 26.30965996], [89.0322876, 26.30784035], [89.03322601, 26.30624008], [89.03189087, 26.3037529], [89.03018188, 26.30167961], [89.02928162, 26.29947281], [89.02947235, 26.2976017], [89.02942657, 26.29527092], [89.02865601, 26.29335022], [89.02813721, 26.29222107], [89.02836609, 26.29033852], [89.03061676, 26.28918266], [89.03201294, 26.28865051], [89.03279877, 26.28693008], [89.03308105, 26.28623009], [89.03334808, 26.28556061], [89.03527069, 26.28544235], [89.03560638, 26.28541946], [89.03894806, 26.28640938], [89.04083252, 26.28610039], [89.04270172, 26.28504944], [89.04447174, 26.28498077], [89.04485321, 26.28533173], [89.0453186, 26.28675842], [89.04554749, 26.28746033], [89.04550171, 26.28867531], [89.04548645, 26.28925133], [89.04605865, 26.28911591], [89.04495239, 26.28964996], [89.04421997, 26.29000854], [89.04232025, 26.29009819], [89.04206085, 26.29010963], [89.04315186, 26.29115295], [89.04527283, 26.29112244], [89.04560089, 26.29323769], [89.04585266, 26.29491234], [89.04621124, 26.2954998], [89.04634857, 26.29573441], [89.04947662, 26.29614639], [89.05058289, 26.29555893], [89.05228424, 26.29614258], [89.05240631, 26.29548264], [89.05245209, 26.29522324], [89.05348206, 26.29657173], [89.05593872, 26.29718399], [89.05597687, 26.29705429], [89.05634308, 26.29678726], [89.05664825, 26.29650307], [89.05687714, 26.29632759], [89.05715179, 26.29612923], [89.05756378, 26.29584122], [89.05807495, 26.29546928], [89.05836487, 26.29522705], [89.05856323, 26.29505157], [89.05869293, 26.29487038], [89.05879974, 26.29470825], [89.05895233, 26.29447174], [89.05901337, 26.29428864], [89.05905914, 26.29403305], [89.05906677, 26.29380226], [89.05890656, 26.29351997], [89.05876923, 26.29332733], [89.05867004, 26.29317665], [89.05948639, 26.29138374], [89.06025696, 26.28969574], [89.05818939, 26.28728294], [89.05760956, 26.28627205], [89.05747223, 26.28603554], [89.05831146, 26.28508377], [89.06053925, 26.28340721], [89.0610199, 26.28304672], [89.06213379, 26.28167343], [89.06227112, 26.27921867], [89.06223297, 26.27897453], [89.06241608, 26.27891541], [89.06217957, 26.27864456], [89.06215668, 26.2784977], [89.06208801, 26.27807045], [89.06192017, 26.27802849], [89.06574249, 26.27621078], [89.06729889, 26.27403069], [89.06788635, 26.27073288], [89.06785583, 26.26691055], [89.06846619, 26.26266289], [89.06838226, 26.26027107], [89.06855774, 26.25880051], [89.06922913, 26.25657272], [89.06970215, 26.25533295], [89.06745148, 26.25530815], [89.06622314, 26.25626945], [89.063591, 26.25795174], [89.0610733, 26.25819969], [89.06025696, 26.25729752], [89.06012726, 26.25692368], [89.06287384, 26.255867], [89.06267548, 26.25510597], [89.06232452, 26.25373268], [89.05988312, 26.25465393], [89.05905151, 26.25408745], [89.05841064, 26.25491905], [89.05754089, 26.25349045], [89.0569458, 26.25251961], [89.05654144, 26.2497406], [89.05715942, 26.24690056], [89.05745697, 26.24502182], [89.05567932, 26.24366951], [89.054039, 26.24358177], [89.05182648, 26.24382973], [89.04984283, 26.24438095], [89.04973602, 26.2444706], [89.0496521, 26.24410057], [89.04945374, 26.2432251], [89.04964447, 26.24314499], [89.05101776, 26.24258232], [89.05062103, 26.24176979], [89.04895782, 26.24211121], [89.04769897, 26.24153137], [89.04598236, 26.24076462], [89.04222107, 26.24292183], [89.04006958, 26.24422836], [89.03729248, 26.24583244], [89.03707123, 26.24464989], [89.03666687, 26.24247551], [89.03656006, 26.2424984], [89.03407288, 26.24301147], [89.03377533, 26.24594498], [89.03285217, 26.24607658], [89.03296661, 26.24679565], [89.03015137, 26.24727249], [89.02764893, 26.24686813], [89.02742004, 26.24677467], [89.02739716, 26.2464447], [89.02726746, 26.24416161], [89.0270462, 26.24416542], [89.02444458, 26.24421501], [89.02442169, 26.24501038], [89.02140808, 26.24508476], [89.02063751, 26.24465179], [89.02042389, 26.2439785], [89.01997375, 26.24254417], [89.01913452, 26.24229431], [89.01896667, 26.24224472], [89.01820374, 26.24201965], [89.01818848, 26.24266434], [89.01815033, 26.24374771], [89.01646423, 26.24364281], [89.01583862, 26.24472046], [89.01293945, 26.24467468], [89.00921631, 26.24461174], [89.00257111, 26.24451065], [88.9987793, 26.244524], [88.99790955, 26.24471474], [88.99723053, 26.2448864], [88.99511719, 26.24529839], [88.99373627, 26.24556923], [88.99010468, 26.2454052], [88.98801422, 26.24519539], [88.98580933, 26.24497223], [88.98330688, 26.24488068], [88.98300171, 26.24488831], [88.98277283, 26.24485207], [88.98036957, 26.24490929], [88.97982025, 26.24464989], [88.97882843, 26.24411392], [88.97880554, 26.24378014], [88.97875214, 26.24308205], [88.97861481, 26.24278069], [88.97849274, 26.24278069], [88.9768219, 26.24278831], [88.97669983, 26.24245834], [88.97570038, 26.24250603], [88.97501373, 26.24220848], [88.97501373, 26.24196434], [88.97501373, 26.24171066], [88.97475433, 26.24167633], [88.97420502, 26.24160385], [88.97419739, 26.24185371], [88.97418976, 26.24195671], [88.97370911, 26.242033], [88.97364807, 26.2416172], [88.97361755, 26.24141312], [88.97329712, 26.24143028], [88.97299194, 26.24144554], [88.97280884, 26.24147606], [88.97275543, 26.24165535], [88.97248077, 26.24164391], [88.9719696, 26.24172592], [88.97193909, 26.24162102], [88.97173309, 26.24083328], [88.97163391, 26.24050903], [88.97163391, 26.2403183], [88.97158051, 26.24026299], [88.97140503, 26.24024582], [88.97131348, 26.24015427], [88.97088623, 26.24015427], [88.9706955, 26.23984528], [88.9703064, 26.23976135], [88.97028351, 26.23967934], [88.96982574, 26.23975182], [88.96973419, 26.23970032], [88.96945953, 26.24002457], [88.96952057, 26.24032021], [88.96913147, 26.24023247], [88.96867371, 26.23988914], [88.96831512, 26.2398262], [88.96831512, 26.23965263], [88.967453, 26.2393837], [88.9670105, 26.23930168], [88.96699524, 26.23915291], [88.96619415, 26.23899841], [88.96537781, 26.23884392], [88.96530914, 26.23878479], [88.96490479, 26.23893929], [88.96457672, 26.23906517], [88.96411896, 26.23915863], [88.96339417, 26.23917961], [88.96321106, 26.23918533], [88.96192169, 26.23963928], [88.95896912, 26.24021149], [88.95820618, 26.24035835], [88.95804596, 26.24039078], [88.95703125, 26.24058723], [88.95677948, 26.24065971], [88.95698547, 26.24267387], [88.95661163, 26.24266624], [88.9548645, 26.24263], [88.9546051, 26.24201775], [88.95360565, 26.24206352], [88.95308685, 26.24208832], [88.95304871, 26.24219322], [88.95237732, 26.24393082], [88.95227051, 26.24422264], [88.95246124, 26.24427414], [88.95278168, 26.2444191], [88.95157623, 26.24615288], [88.95133209, 26.24663162], [88.95066071, 26.24780464], [88.94986725, 26.24781609], [88.94982147, 26.24796677], [88.94960022, 26.24872208], [88.94918823, 26.24951744], [88.94902802, 26.24977684], [88.94844055, 26.2507267], [88.94830322, 26.25095749], [88.94792938, 26.25142479], [88.94773865, 26.25166512], [88.94721222, 26.25232506], [88.94731903, 26.25241089], [88.9471817, 26.25254822], [88.94690704, 26.25246429], [88.94604492, 26.25326347], [88.94592285, 26.25321579], [88.94439697, 26.25459862], [88.9442749, 26.25457573], [88.94394684, 26.25550079], [88.94374084, 26.25608063], [88.94359589, 26.25642586], [88.94355011, 26.25655174], [88.94337463, 26.25653267], [88.94334412, 26.25665665], [88.94350433, 26.25671577], [88.9430542, 26.25793648], [88.94295502, 26.25796318], [88.94247437, 26.25882912], [88.94231415, 26.25896645], [88.94224548, 26.25904846], [88.94195557, 26.25949287], [88.94190979, 26.25958633], [88.94203186, 26.25969124], [88.9410553, 26.26124191], [88.94065094, 26.26226997], [88.94054413, 26.26298141], [88.94018555, 26.26360893], [88.93998718, 26.26365852], [88.93950653, 26.26409531], [88.93832397, 26.2647171], [88.93811035, 26.26471329], [88.93725586, 26.26530457], [88.93647766, 26.26585197], [88.93627167, 26.26605797], [88.9360199, 26.26630592], [88.9356842, 26.26714134], [88.93553925, 26.2671299], [88.93511963, 26.2671032], [88.93505096, 26.26730919], [88.93482208, 26.26798248], [88.93421173, 26.26977921], [88.93421936, 26.27014923], [88.93412781, 26.27024078], [88.93399048, 26.27072144], [88.93405151, 26.27091789], [88.93341827, 26.27218437], [88.93288422, 26.27321053], [88.93258667, 26.27374649], [88.93245697, 26.27376366], [88.93156433, 26.27444267], [88.93131256, 26.27521896], [88.93139648, 26.27526855], [88.93140411, 26.27634239], [88.93138885, 26.27665138], [88.93127441, 26.27666664], [88.93108368, 26.27752876], [88.93041992, 26.27838326], [88.92977142, 26.27897644], [88.92858887, 26.28003883], [88.92749786, 26.28186417], [88.92622375, 26.28389359], [88.92469788, 26.28416634], [88.92453766, 26.28395844], [88.92449188, 26.28389359], [88.92406464, 26.28380394], [88.92379761, 26.28384781], [88.92366028, 26.28414154], [88.92243958, 26.28417206], [88.92227936, 26.28503418], [88.92048645, 26.28493309], [88.92037964, 26.28445435], [88.91983795, 26.28457832], [88.9197998, 26.28472519], [88.91937256, 26.28523254], [88.91960144, 26.28531456], [88.91939545, 26.28634453], [88.91831207, 26.28627777], [88.91809082, 26.28788948], [88.91807556, 26.28802872], [88.9178772, 26.28801918], [88.91721344, 26.28798485], [88.91692352, 26.28796959], [88.91678619, 26.28796196], [88.91519165, 26.28787994], [88.91386414, 26.28760529], [88.91343689, 26.28754234], [88.91333008, 26.28776932], [88.90982056, 26.2875309], [88.90918732, 26.28760529], [88.90843964, 26.28768921], [88.90842438, 26.28819466], [88.90791321, 26.28810501], [88.90687561, 26.28811264], [88.90641785, 26.28811646], [88.90381622, 26.28820229], [88.90089417, 26.28839493], [88.90052032, 26.28844261], [88.89820099, 26.28874397], [88.89691162, 26.2885437], [88.89586639, 26.28838348], [88.89344025, 26.28804398], [88.89099884, 26.28789139], [88.88993073, 26.28785133], [88.88835907, 26.2877903], [88.888237, 26.28778648], [88.88708496, 26.28760338], [88.88476563, 26.28735733], [88.88062286, 26.28700447], [88.87744141, 26.28673744], [88.87670135, 26.28669739], [88.87600708, 26.28632927], [88.8755722, 26.28580284], [88.87480164, 26.28491974], [88.87306976, 26.28243065], [88.87281036, 26.28107071], [88.87146759, 26.27966118], [88.86942291, 26.27865028], [88.86820984, 26.27746964], [88.86876678, 26.27565956], [88.86963654, 26.27030945], [88.86804962, 26.26749039], [88.86785889, 26.2653904], [88.86776733, 26.26090813], [88.86802673, 26.25785065], [88.87010193, 26.25460052], [88.87262726, 26.25316048], [88.87471771, 26.25132942], [88.87703705, 26.24875069], [88.8781662, 26.24777985], [88.87886047, 26.24600983], [88.87872314, 26.24356842], [88.87913513, 26.24353027], [88.87914276, 26.2432785], [88.87903595, 26.24310875], [88.87854767, 26.2422905], [88.87866974, 26.24227905], [88.87875366, 26.24224854], [88.87898254, 26.24204826], [88.87947845, 26.24199295], [88.8795166, 26.24163437], [88.8796463, 26.24146271], [88.87976074, 26.24133682], [88.87985992, 26.24127388], [88.87997437, 26.24118042], [88.88004303, 26.24110031], [88.88014221, 26.24100685], [88.88025665, 26.24091339], [88.88031769, 26.24085045], [88.88051605, 26.24080086], [88.88070679, 26.24089622], [88.88095856, 26.24091911], [88.88119507, 26.24095726], [88.88130188, 26.24088669], [88.88141632, 26.2407856], [88.8814621, 26.24067307], [88.88154602, 26.24059868], [88.88163757, 26.24040794], [88.88179016, 26.24027824], [88.88188171, 26.24024391], [88.88195801, 26.24019051], [88.88208008, 26.24010468], [88.88212585, 26.24003601], [88.88220978, 26.23991013], [88.88233185, 26.23975182], [88.88243103, 26.23962784], [88.88252258, 26.23944092], [88.88259125, 26.23928642], [88.88266754, 26.23908615], [88.88272858, 26.23886871], [88.88278961, 26.23860741], [88.88285065, 26.2384243], [88.88293457, 26.23822403], [88.88298035, 26.23799706], [88.88298035, 26.2378788], [88.88306427, 26.2378006], [88.88317108, 26.2377243], [88.88337708, 26.23767853], [88.88356018, 26.23768997], [88.8836441, 26.23770142], [88.88374329, 26.23772621], [88.88386536, 26.23767662], [88.88392639, 26.23762703], [88.88394165, 26.23752213], [88.88393402, 26.23737335], [88.88394165, 26.23725128], [88.88381958, 26.23708534], [88.88350677, 26.23665047], [88.88173676, 26.23655128], [88.87667847, 26.23644066], [88.87670135, 26.23625183], [88.87698364, 26.23555183], [88.87781525, 26.23349571], [88.8776474, 26.23348236], [88.87245941, 26.23311234], [88.87203217, 26.23363113], [88.87160492, 26.23414993], [88.86872864, 26.23350525], [88.86509705, 26.23242569], [88.86301422, 26.23257446], [88.86012268, 26.23239136], [88.86000061, 26.23223877], [88.85973358, 26.23154068], [88.85962677, 26.23155212], [88.85865784, 26.23166084], [88.85862732, 26.23225975], [88.85665131, 26.23383522], [88.85556793, 26.23399544], [88.85546875, 26.23402214], [88.85533142, 26.23405838], [88.85422516, 26.23515511], [88.85395813, 26.23516273], [88.85295105, 26.23518944], [88.85192871, 26.23521805], [88.85122681, 26.2343502], [88.84913635, 26.23373985], [88.84809875, 26.23397446], [88.84809113, 26.23388672], [88.8480835, 26.2335968], [88.84624481, 26.2333622], [88.84379578, 26.2325058], [88.84376526, 26.23224831], [88.84389496, 26.23067284], [88.84026337, 26.23140907], [88.83847046, 26.23219681], [88.83837128, 26.23442459], [88.83846283, 26.2367363], [88.83833313, 26.23723221], [88.83807373, 26.23823929], [88.83423615, 26.23775482], [88.83365631, 26.23837471], [88.83352661, 26.23851585], [88.83310699, 26.23846626], [88.83189392, 26.23832512], [88.83101654, 26.24015808], [88.83096313, 26.24027061], [88.83033752, 26.24017143], [88.82757568, 26.23972702], [88.82753754, 26.24001312], [88.82720947, 26.242239], [88.82711029, 26.24291039], [88.82688904, 26.24482536], [88.82707214, 26.24487495], [88.82859039, 26.24529457], [88.82857513, 26.24544907], [88.82847595, 26.24648857], [88.82881165, 26.24728394], [88.82909393, 26.24980545], [88.82775879, 26.25006676], [88.8276062, 26.24971199], [88.82741547, 26.24929428], [88.82731628, 26.24927711], [88.8234024, 26.24862671], [88.82361603, 26.2495079], [88.8234024, 26.25056267], [88.82331085, 26.25098038], [88.82347107, 26.25101089], [88.82411194, 26.25113297], [88.82396698, 26.25150108], [88.82360077, 26.25238991], [88.82314301, 26.25344658], [88.82151031, 26.25384712], [88.81951904, 26.25385094], [88.81903076, 26.2552948], [88.81489563, 26.25524902], [88.81475067, 26.25501442], [88.81464386, 26.25484467], [88.81430054, 26.25428391], [88.81391907, 26.25447845], [88.81365204, 26.25461006], [88.81352234, 26.25467491], [88.81282043, 26.25693512], [88.81288147, 26.25704956], [88.81372833, 26.25877762], [88.81355286, 26.25884819], [88.8131485, 26.25901413], [88.81313324, 26.26014328], [88.81309509, 26.26175499], [88.81299591, 26.26195335], [88.81295776, 26.26202011], [88.81210327, 26.26363945], [88.8121109, 26.26409912], [88.81212616, 26.2647171], [88.81217957, 26.26487541], [88.81464386, 26.26526451], [88.81478119, 26.26599503], [88.81503296, 26.26732254], [88.81494904, 26.26910973], [88.81409454, 26.2696476], [88.81417847, 26.27164841], [88.81410217, 26.27198029], [88.81380463, 26.27321625], [88.81373596, 26.27348518], [88.81229401, 26.27361679], [88.8102951, 26.2743454], [88.81034088, 26.27536392], [88.80996704, 26.27702141], [88.81034851, 26.27699852], [88.81093597, 26.27696228], [88.81112671, 26.27777672], [88.81169128, 26.28015137], [88.81206512, 26.28167915], [88.81230927, 26.28292656], [88.81246948, 26.28377533], [88.8125, 26.28396988], [88.81287384, 26.28634453], [88.81314087, 26.28807259], [88.81320953, 26.28852654], [88.81343842, 26.28875732], [88.81568909, 26.29102898], [88.8170166, 26.29242897], [88.81824493, 26.29372406], [88.81906891, 26.29459], [88.81510162, 26.29633331], [88.81310272, 26.29721451], [88.81219482, 26.2983799], [88.81059265, 26.29918289], [88.80947113, 26.30083275], [88.80802155, 26.30166054], [88.80715942, 26.30166435], [88.80437469, 26.30437088], [88.80175781, 26.30641556], [88.79890442, 26.30760002], [88.79597473, 26.30814171], [88.79347229, 26.31007385], [88.79064178, 26.30755997], [88.78746796, 26.30589676], [88.78708649, 26.30577278], [88.78688049, 26.30559349], [88.78487396, 26.30421829], [88.78180695, 26.30310059], [88.77937317, 26.30325317], [88.77754211, 26.3035965], [88.77619934, 26.30374908], [88.77591705, 26.30335617], [88.77505493, 26.30268288], [88.77416229, 26.30215836], [88.77329254, 26.30167007], [88.77302551, 26.3013401], [88.77180481, 26.30064011], [88.77172852, 26.30065346], [88.77072906, 26.30035973], [88.76993561, 26.3001461], [88.76966095, 26.30002022], [88.76820374, 26.29984093], [88.76654816, 26.29974937], [88.76570129, 26.29954338], [88.76515198, 26.29940987], [88.76478577, 26.29926872], [88.76403046, 26.29898071], [88.76381683, 26.29900932], [88.7634964, 26.29906273], [88.76346588, 26.29898453], [88.76259613, 26.29924965], [88.76178741, 26.29954147], [88.76069641, 26.29998589], [88.75970459, 26.30033493], [88.75968933, 26.30088997], [88.75946045, 26.30093956], [88.75941467, 26.30199051], [88.75954437, 26.30218315], [88.75961304, 26.30315971], [88.75952148, 26.30319786], [88.75925446, 26.30414391], [88.75923157, 26.30422401], [88.75894928, 26.30496979], [88.75868225, 26.30489922], [88.7583313, 26.3059597], [88.75702667, 26.30758286], [88.75655365, 26.30901718], [88.75656128, 26.31057549], [88.75349426, 26.31042862], [88.75314331, 26.31025696], [88.75222015, 26.3102417], [88.75158691, 26.31064987], [88.75039673, 26.31030846], [88.75024414, 26.31093216], [88.7497406, 26.31087303], [88.74953461, 26.31056213], [88.74784851, 26.31087303], [88.74766541, 26.31105042], [88.74662781, 26.31111145], [88.74550629, 26.30895042], [88.74530029, 26.30858231], [88.74536133, 26.30820656], [88.74494171, 26.30591202], [88.74456024, 26.30592155], [88.74430847, 26.30368042], [88.74412537, 26.30365181], [88.744133, 26.30306816], [88.74414063, 26.30291367], [88.7440567, 26.3026104], [88.74364471, 26.30111885], [88.74321747, 26.29932404], [88.74253082, 26.29934502], [88.74256897, 26.29884148], [88.74234772, 26.29850197], [88.74168396, 26.2974987], [88.74130249, 26.29767799], [88.74077606, 26.29568672], [88.74234772, 26.2953167], [88.74253845, 26.29446602], [88.74343109, 26.29444695], [88.74333954, 26.29387283], [88.74330902, 26.29368401], [88.74391937, 26.2936058], [88.74394226, 26.29369926], [88.74492645, 26.29361153], [88.74536896, 26.29357147], [88.74530792, 26.29297256], [88.74565125, 26.29286766], [88.74562836, 26.2926178], [88.74546051, 26.29110146], [88.74508667, 26.29104996], [88.74505615, 26.29074478], [88.74498749, 26.29072189], [88.74411774, 26.29077911], [88.74411011, 26.29107666], [88.74362946, 26.29112434], [88.74353027, 26.29113579], [88.74350739, 26.2915802], [88.74288177, 26.29158974], [88.74276733, 26.29112053], [88.74152374, 26.29137421], [88.73962402, 26.29147148], [88.73847198, 26.29136848], [88.73731995, 26.29156494], [88.73782349, 26.29250145], [88.73736572, 26.29274178], [88.73725891, 26.29350853], [88.7368927, 26.29356384], [88.73691559, 26.29371071], [88.73620605, 26.29375839], [88.73395538, 26.29444504], [88.73244476, 26.29444695], [88.73064423, 26.29475975], [88.73028564, 26.29471588], [88.72994995, 26.29470253], [88.72966003, 26.29469109], [88.72969055, 26.29354668], [88.7305069, 26.29129982], [88.72962189, 26.29121399], [88.72953796, 26.29084206], [88.72906494, 26.29084206], [88.72902679, 26.29030228], [88.72938538, 26.29018402], [88.72917175, 26.2894001], [88.72840118, 26.28951645], [88.72833252, 26.28934288], [88.72743988, 26.28953362], [88.72746277, 26.2896595], [88.727211, 26.2897625], [88.72725677, 26.28987885], [88.72647095, 26.29024315], [88.72710419, 26.29179001], [88.72756958, 26.29292488], [88.72659302, 26.29321671], [88.72645569, 26.29322243], [88.7246933, 26.29330444], [88.72315979, 26.29311562], [88.72309875, 26.29281807], [88.72219086, 26.2928009], [88.72142792, 26.29325867], [88.71987152, 26.29310989], [88.71974945, 26.29309845], [88.71992493, 26.29203033], [88.72013092, 26.29202843], [88.72029877, 26.29202843], [88.72029877, 26.29140091], [88.72029877, 26.29115295], [88.72045135, 26.29114342], [88.72083282, 26.29112053], [88.72100067, 26.28992271], [88.72105408, 26.28985405], [88.72168732, 26.28985214], [88.72163391, 26.28900719], [88.72133636, 26.2889843], [88.72126007, 26.28855133], [88.72102356, 26.28853226], [88.72105408, 26.28777885], [88.72129059, 26.28776932], [88.72210693, 26.28773689], [88.72213745, 26.28673172], [88.72369385, 26.28624725], [88.72283936, 26.28451157], [88.72194672, 26.28292656], [88.72033691, 26.28293991], [88.7191925, 26.28277397], [88.71820068, 26.2824707], [88.71647644, 26.28231621], [88.71385193, 26.28236961], [88.71364594, 26.2822094], [88.71446228, 26.28183937], [88.71446991, 26.28166199], [88.71219635, 26.28170013], [88.71006775, 26.28180313], [88.70906067, 26.28179932], [88.70722961, 26.28161049], [88.70506287, 26.28150558], [88.70503235, 26.28186035], [88.7045517, 26.28186417], [88.70452881, 26.28149223], [88.70250702, 26.28122902], [88.70250702, 26.28056145], [88.69579315, 26.27953911], [88.69609833, 26.27737427], [88.69178772, 26.27155685], [88.69194031, 26.27142334], [88.69199371, 26.27051735], [88.69223022, 26.27037811], [88.69232178, 26.2696228], [88.69252777, 26.26961899], [88.69242859, 26.26913071], [88.69203949, 26.26905632], [88.69181824, 26.26867485], [88.69008636, 26.26861191], [88.69003296, 26.26673317], [88.68795013, 26.26672554], [88.68804169, 26.26635361], [88.68739319, 26.26626968], [88.68683624, 26.26769829], [88.68596649, 26.26766205], [88.68598938, 26.26735115], [88.68563843, 26.26729393], [88.68579865, 26.2668705], [88.68540192, 26.26683044], [88.68560028, 26.2662735], [88.68504333, 26.26619339], [88.68511963, 26.26585197], [88.68458557, 26.26574707], [88.68625641, 26.26316833], [88.68370056, 26.26159668], [88.68352509, 26.26184845], [88.68296814, 26.26171303], [88.6831665, 26.26092339], [88.68198395, 26.2604599], [88.68083954, 26.25966263], [88.6794281, 26.25901031], [88.67907715, 26.25999451], [88.6785202, 26.26156235], [88.67823792, 26.26282883], [88.67805481, 26.2642498], [88.67790985, 26.26422882], [88.67782593, 26.26461792], [88.67678833, 26.26449013], [88.67674255, 26.26476669], [88.67540741, 26.26446915], [88.67570496, 26.26369095], [88.67465973, 26.26344681], [88.67352295, 26.26337242], [88.67198181, 26.2631321], [88.67197418, 26.26395226], [88.67007446, 26.26403618], [88.6701355, 26.26322937], [88.66888428, 26.26334381], [88.66734314, 26.26347351], [88.66742706, 26.26264381], [88.66674805, 26.26269722], [88.66620636, 26.26273918], [88.66615295, 26.26335716], [88.66629028, 26.2635231], [88.66645813, 26.26486206], [88.66685486, 26.26492119], [88.66688538, 26.2657795], [88.66729736, 26.26578331], [88.66728973, 26.26625443], [88.66745758, 26.26639366], [88.66744995, 26.26663017], [88.66817474, 26.26674271], [88.66837311, 26.26677513], [88.66838837, 26.26695824], [88.66843414, 26.2673912], [88.66880035, 26.26747704], [88.6688385, 26.26733017], [88.67180634, 26.2669735], [88.67179108, 26.26777077], [88.67177582, 26.26856804], [88.67214203, 26.26856613], [88.67215729, 26.27048492], [88.67204285, 26.27232933], [88.66950989, 26.27205276], [88.66760254, 26.27204323], [88.6675415, 26.27227592], [88.66743469, 26.27258873], [88.6672287, 26.27290535], [88.66701508, 26.27290916], [88.66680145, 26.27387047], [88.66767883, 26.2739296], [88.66763306, 26.27453423], [88.66733551, 26.2745266], [88.6673584, 26.27562523], [88.66700745, 26.27558899], [88.66703033, 26.27610397], [88.6674118, 26.27615166], [88.66727448, 26.27693558], [88.66725159, 26.27757454], [88.66735077, 26.27816582], [88.6681366, 26.27820778], [88.66811371, 26.27889824], [88.66854858, 26.27890396], [88.66857147, 26.27966881], [88.66903687, 26.27967072], [88.66944122, 26.27967262], [88.66954041, 26.28037453], [88.6696167, 26.28085899], [88.66829681, 26.28203201], [88.6668396, 26.2835598], [88.66566467, 26.2848587], [88.66568756, 26.28495598], [88.66643524, 26.28512001], [88.66637421, 26.28618622], [88.6661911, 26.28630447], [88.66620636, 26.28713417], [88.66643524, 26.28714371], [88.66644287, 26.28783798], [88.66617584, 26.28932381], [88.66727448, 26.28930664], [88.66860962, 26.28928757], [88.66860199, 26.28959274], [88.66963959, 26.28964996], [88.66900635, 26.29076004], [88.66822815, 26.29212952], [88.66893005, 26.29229736], [88.66873169, 26.29353142], [88.66841888, 26.29354668], [88.66821289, 26.29441643], [88.66921234, 26.29459572], [88.66798401, 26.29726601], [88.66877747, 26.29759216], [88.66972351, 26.29771805], [88.6706543, 26.29784203], [88.67062378, 26.29828835], [88.67391205, 26.29859543], [88.67472839, 26.29852676], [88.6747818, 26.29734993], [88.67649841, 26.29737473], [88.67654419, 26.29669762], [88.67747498, 26.29670525], [88.67749786, 26.2962513], [88.67865753, 26.29604912], [88.67869568, 26.29554939], [88.6789093, 26.29516029], [88.67945862, 26.29500008], [88.67948151, 26.29515076], [88.68067169, 26.29528046], [88.68086243, 26.29426003], [88.6803894, 26.29248619], [88.68106079, 26.29252243], [88.68424988, 26.29226112], [88.68434906, 26.29086685], [88.68487549, 26.2908783], [88.685112, 26.29028511], [88.68560028, 26.2903595], [88.68579102, 26.29039001], [88.68580627, 26.29000664], [88.6858139, 26.28956223], [88.68563843, 26.28857231], [88.68643951, 26.28852463], [88.68681335, 26.28841972], [88.68717957, 26.28831863], [88.68717194, 26.2881546], [88.68713379, 26.28775978], [88.68539429, 26.28746605], [88.68434143, 26.28742599], [88.68427277, 26.2880249], [88.68338013, 26.28794479], [88.68336487, 26.28733063], [88.68153381, 26.28716087], [88.68178558, 26.28530693], [88.68234253, 26.28535271], [88.68270111, 26.28353119], [88.68424225, 26.28367996], [88.68399048, 26.28275681], [88.68518066, 26.28293228], [88.6852417, 26.28246307], [88.68572998, 26.28252411], [88.68619537, 26.28211975], [88.68704987, 26.28214836], [88.68803406, 26.28217888], [88.68782806, 26.28370476], [88.68778992, 26.28518867], [88.69034576, 26.2857151], [88.69036102, 26.28488159], [88.69107819, 26.28489685], [88.69116211, 26.28437042], [88.6904068, 26.28424454], [88.69043732, 26.28371239], [88.69109344, 26.28377151], [88.69298553, 26.28393936], [88.69312286, 26.28285217], [88.69542694, 26.28277779], [88.69530487, 26.28407288], [88.69600677, 26.2844162], [88.69683075, 26.28491974], [88.69889069, 26.28554726], [88.69931793, 26.28534889], [88.69944763, 26.28427124], [88.70139313, 26.28437233], [88.70145416, 26.2844429], [88.7013092, 26.28582573], [88.70431519, 26.28580475], [88.7046051, 26.28580284], [88.70452881, 26.28625679], [88.70446777, 26.28662491], [88.70536804, 26.28818893], [88.70552063, 26.28846169], [88.7062149, 26.28862762], [88.70700073, 26.28861427], [88.70700073, 26.28851509], [88.70772552, 26.28853798], [88.70775604, 26.28873825], [88.70832825, 26.28878212], [88.70832062, 26.28886223], [88.70903778, 26.28890991], [88.70938873, 26.28886604], [88.70920563, 26.2890377], [88.70846558, 26.28906631], [88.70803833, 26.2892189], [88.70687103, 26.28911972], [88.70578003, 26.28909302], [88.70648193, 26.29148865], [88.70352173, 26.29144859], [88.70352936, 26.29182243], [88.70277405, 26.29179955], [88.70263672, 26.29257584], [88.69978333, 26.29237175], [88.69980621, 26.2914238], [88.70266724, 26.29176521], [88.70272827, 26.29104614], [88.70262909, 26.2910347], [88.70178223, 26.29093742], [88.70143127, 26.29089737], [88.70144653, 26.29064941], [88.70149994, 26.28988647], [88.70038605, 26.2898407], [88.70041656, 26.28948212], [88.69813538, 26.28933907], [88.69799805, 26.29017067], [88.69483948, 26.29026985], [88.69482422, 26.29090309], [88.69232941, 26.2906208], [88.69217682, 26.29060364], [88.69207001, 26.29124832], [88.6942749, 26.29141045], [88.69481659, 26.2914505], [88.69481659, 26.29219627], [88.6950531, 26.29265022], [88.69413757, 26.29266739], [88.69398499, 26.29342461], [88.69314575, 26.29339981], [88.6931076, 26.29361725], [88.69345856, 26.29367828], [88.69325256, 26.29554749], [88.69261932, 26.29546356], [88.69272614, 26.29479218], [88.69246674, 26.29475403], [88.6910553, 26.29454613], [88.68968201, 26.29434204], [88.68967438, 26.2948513], [88.68858337, 26.29486656], [88.68861389, 26.29448318], [88.68738556, 26.2945385], [88.68739319, 26.29487991], [88.68596649, 26.29483032], [88.68583679, 26.29542732], [88.68474579, 26.29520226], [88.68457031, 26.29576492], [88.68508911, 26.29597473], [88.6841507, 26.29769135], [88.68338776, 26.29751396], [88.68319702, 26.29853821], [88.68244171, 26.29850578], [88.68278503, 26.29916573], [88.68353271, 26.29982948], [88.68460083, 26.30150986], [88.68313599, 26.3017025], [88.68314362, 26.30203056], [88.68190002, 26.30206108], [88.68187714, 26.30252838], [88.68160248, 26.30253601], [88.68149567, 26.30203056], [88.68012238, 26.30153465], [88.67980957, 26.30289459], [88.67823792, 26.30437279], [88.67792511, 26.30706406], [88.67844391, 26.30719376], [88.6787262, 26.30792999], [88.6806488, 26.30813217], [88.68302155, 26.30856133], [88.68301392, 26.31028366], [88.68250275, 26.31260872], [88.68097687, 26.31241035], [88.6811142, 26.31165123], [88.68077087, 26.31162643], [88.68066406, 26.31203461], [88.68049622, 26.31203079], [88.6800766, 26.31348801], [88.67928314, 26.31341553], [88.67904663, 26.31476784], [88.67790222, 26.31464577], [88.67795563, 26.31384087], [88.67840576, 26.31383324], [88.6784668, 26.3134346], [88.67740631, 26.31337929], [88.67735291, 26.31309509], [88.67694092, 26.31306648], [88.6770401, 26.31176376], [88.67637634, 26.31175804], [88.67639923, 26.3115139], [88.67523956, 26.31144905], [88.67506409, 26.31294441], [88.67594147, 26.31303024], [88.67591095, 26.31348801], [88.67468262, 26.31339645], [88.67454529, 26.31435013], [88.67580414, 26.31446075], [88.67557526, 26.31641769], [88.67614746, 26.31651497], [88.67604065, 26.31754494], [88.67514801, 26.31750298], [88.67501068, 26.31811333], [88.67550659, 26.3182106], [88.67507172, 26.32017136], [88.67822266, 26.320261], [88.67810822, 26.32150841], [88.67934418, 26.3215313], [88.67926788, 26.32224846], [88.68193054, 26.32237434], [88.68592834, 26.32285309], [88.68819427, 26.32296944], [88.6897049, 26.32312584], [88.68956757, 26.32348824], [88.68976593, 26.323843], [88.69024658, 26.3242321], [88.69048309, 26.3254509], [88.69078064, 26.32599258], [88.6909256, 26.32789612], [88.69094849, 26.32897568], [88.69197083, 26.32899094], [88.69229126, 26.32872391], [88.69346619, 26.3286705], [88.69568634, 26.32882118], [88.69578552, 26.32775879], [88.69644165, 26.32783508], [88.69646454, 26.32704735], [88.69620514, 26.32701683], [88.6962204, 26.32654572], [88.69659424, 26.32655907], [88.69674683, 26.32585144], [88.69405365, 26.32579231], [88.69223022, 26.32569504], [88.69139862, 26.32444572], [88.690979, 26.32418251], [88.68984985, 26.32344055], [88.69020844, 26.32280159], [88.69186401, 26.32256508], [88.6917572, 26.32219505], [88.69236755, 26.3216877], [88.69223022, 26.32098961], [88.69211578, 26.3201313], [88.69139862, 26.3198185], [88.69160461, 26.31953049], [88.69150543, 26.31939697], [88.69104767, 26.31939507], [88.69087982, 26.31850624], [88.69185638, 26.31755447], [88.69186401, 26.31710815], [88.69252014, 26.31708527], [88.69258118, 26.31575012], [88.69290924, 26.31572342], [88.69320679, 26.3140831], [88.6944809, 26.31409073], [88.69513702, 26.31452179], [88.69639587, 26.31442642], [88.69697571, 26.31365013], [88.69615936, 26.3126297], [88.69718933, 26.31221771], [88.6978302, 26.31264305], [88.69882202, 26.31286812], [88.6991806, 26.3137188], [88.69885254, 26.31446457], [88.70022583, 26.31484604], [88.70349884, 26.31484604], [88.70629883, 26.31477547], [88.7062149, 26.31570435], [88.70816803, 26.31539726], [88.70806122, 26.31637764], [88.70990753, 26.3169632], [88.71227264, 26.31734657], [88.71498108, 26.31805611], [88.7172699, 26.31716728], [88.71904755, 26.3157692], [88.71842194, 26.31231689], [88.71918488, 26.31225014], [88.7208252, 26.31438828], [88.72223663, 26.31487465], [88.72439575, 26.31475449], [88.7259903, 26.3156414], [88.72626495, 26.31762123], [88.72865295, 26.3181572], [88.7311554, 26.31847572], [88.73153687, 26.31930351], [88.73114014, 26.32202911], [88.73066711, 26.32193184], [88.73058319, 26.32374954], [88.73259735, 26.32375717], [88.73525238, 26.3235836], [88.73848724, 26.32369041], [88.73914337, 26.32380486], [88.74004364, 26.32273865], [88.74307251, 26.32264519], [88.74645233, 26.32247543], [88.74684143, 26.32495689], [88.74747467, 26.32698059], [88.74793243, 26.32879448], [88.74842834, 26.33060646], [88.74868011, 26.33202362], [88.74571228, 26.33253288], [88.74422455, 26.33184814], [88.74310303, 26.33179855], [88.74265289, 26.33077812], [88.73993683, 26.32945824], [88.73749542, 26.32919693], [88.73727417, 26.32878113], [88.73382568, 26.32858467], [88.73427582, 26.3308773], [88.73504639, 26.33180428], [88.73594666, 26.33406258], [88.73732758, 26.33513832], [88.73862457, 26.33513641], [88.74088287, 26.33669281], [88.74272919, 26.33679008], [88.74398804, 26.33857918], [88.74427795, 26.34091759], [88.74298859, 26.34196663], [88.74254608, 26.34419823], [88.74423981, 26.34470177], [88.74443817, 26.34346581], [88.74515533, 26.34467316], [88.74559021, 26.3447094], [88.74581909, 26.34717369], [88.74524689, 26.3479557], [88.74391937, 26.34883118], [88.73960876, 26.34882927], [88.73881531, 26.34938431], [88.73629761, 26.34955215], [88.73596191, 26.35209656], [88.73724365, 26.35194397], [88.73753357, 26.35338783], [88.73425293, 26.35379601], [88.73416138, 26.35367012], [88.73413849, 26.35330009], [88.73410797, 26.35276031], [88.73504639, 26.35036087], [88.73479462, 26.35016251], [88.73516083, 26.3501091], [88.73550415, 26.34917068], [88.73581696, 26.34918404], [88.73586273, 26.34808159], [88.73286438, 26.34812164], [88.73210144, 26.34812355], [88.72937775, 26.34625244], [88.72927094, 26.34472084], [88.72684479, 26.34466934], [88.72631073, 26.34423065], [88.72608185, 26.34136772], [88.72425842, 26.34122849], [88.72429657, 26.34210587], [88.72377777, 26.34302902], [88.72205353, 26.3433094], [88.72200012, 26.34293747], [88.72129059, 26.34294319], [88.71883392, 26.34294128], [88.71883392, 26.34343529], [88.71757507, 26.34354591], [88.71752167, 26.34388542], [88.71569061, 26.34389496], [88.71401215, 26.34381866], [88.7135849, 26.34379959], [88.71278381, 26.34372902], [88.71273804, 26.34259033], [88.71238708, 26.33817863], [88.71235657, 26.3378315], [88.71227264, 26.33784103], [88.71173859, 26.33628082], [88.71050262, 26.33389091], [88.70855713, 26.33279991], [88.70672607, 26.33279991], [88.70652008, 26.33293343], [88.70601654, 26.33282471], [88.70490265, 26.33262825], [88.70463562, 26.33258057], [88.70449066, 26.33278084], [88.70431519, 26.33301735], [88.70401764, 26.33333206], [88.70375061, 26.33420944], [88.70324707, 26.33434296], [88.70316315, 26.33428192], [88.70291901, 26.33430099], [88.70271301, 26.33449364], [88.70265198, 26.33470917], [88.70258331, 26.33479309], [88.70246887, 26.33488083], [88.70226288, 26.33543968], [88.70218658, 26.33545685], [88.70214081, 26.33620071], [88.70201874, 26.33620262], [88.70200348, 26.33644295], [88.70223999, 26.33648682], [88.70235443, 26.33647537], [88.70288086, 26.33642197], [88.70291138, 26.33688354], [88.70317078, 26.33688545], [88.70317078, 26.33723831], [88.70317841, 26.3377552], [88.70303345, 26.33776474], [88.70275879, 26.33778572], [88.70274353, 26.33808327], [88.7027359, 26.33825111], [88.70250702, 26.33823776], [88.70161438, 26.33818817], [88.70159149, 26.33888817], [88.70209503, 26.3389225], [88.70307159, 26.33898735], [88.70303345, 26.33946991], [88.70301819, 26.33970261], [88.70314789, 26.33971405], [88.70317078, 26.33991623], [88.70357513, 26.33992958], [88.70376587, 26.3399353], [88.70376587, 26.3409996], [88.70237732, 26.34218979], [88.7022934, 26.34219933], [88.70226288, 26.34188461], [88.7002182, 26.34177399], [88.70012665, 26.34172821], [88.69960785, 26.34172058], [88.69952393, 26.34127808], [88.69894409, 26.34125519], [88.6985321, 26.34123802], [88.69843292, 26.34202194], [88.69815826, 26.34202194], [88.69807434, 26.34236717], [88.6980896, 26.34272003], [88.69816589, 26.34300995], [88.69809723, 26.34326744], [88.69805908, 26.3434391], [88.69761658, 26.34370613], [88.69754028, 26.34375191], [88.6973877, 26.34368324], [88.69667816, 26.34369469], [88.69664001, 26.34399223], [88.69657135, 26.34434128], [88.69613647, 26.34429741], [88.69561005, 26.34423447], [88.69506073, 26.344244], [88.69499207, 26.34449387], [88.69487762, 26.34473801], [88.69493866, 26.34515953], [88.69495392, 26.34528542], [88.69503021, 26.34548187], [88.6950531, 26.34571266], [88.69452667, 26.34577942], [88.69441223, 26.34579468], [88.69443512, 26.34604454], [88.69435883, 26.34625816], [88.69422913, 26.34628296], [88.69420624, 26.34667778], [88.69415283, 26.34684372], [88.69404602, 26.34686661], [88.69404602, 26.34695244], [88.69467926, 26.34700966], [88.69513702, 26.34701538], [88.69536591, 26.34705544], [88.69548035, 26.34704781], [88.69593048, 26.34701729], [88.69667816, 26.34701347], [88.69660187, 26.34719849], [88.69661713, 26.34807777], [88.69711304, 26.34807205], [88.69715118, 26.34882545], [88.69719696, 26.34889984], [88.69742584, 26.34890938], [88.69741821, 26.34922409], [88.69737244, 26.34949684], [88.69736481, 26.34961891], [88.69762421, 26.34963608], [88.69779205, 26.34964752], [88.69773865, 26.34986305], [88.69771576, 26.34995461], [88.69761658, 26.35072708], [88.69758606, 26.35104179], [88.69760895, 26.35157013], [88.69792175, 26.35161209], [88.69779205, 26.35257339], [88.69784546, 26.35264587], [88.69788361, 26.35366249], [88.6979599, 26.35368156], [88.69792175, 26.35430145], [88.69788361, 26.35507774], [88.69785309, 26.35538483], [88.69776154, 26.35567093], [88.69795227, 26.35570717], [88.69801331, 26.35593033], [88.69847107, 26.35591125], [88.69844818, 26.35604668], [88.69838715, 26.35644913], [88.69661713, 26.35711479], [88.69577789, 26.3572216], [88.69507599, 26.35731125], [88.69387817, 26.35656548], [88.69378662, 26.35650635], [88.69254303, 26.35778999], [88.69244385, 26.35798454], [88.69145203, 26.36004639], [88.69178009, 26.36014748], [88.69364929, 26.3607254], [88.69403076, 26.36092186], [88.69456482, 26.3611927], [88.69613647, 26.36198997], [88.69623566, 26.36203957], [88.69592285, 26.36242676], [88.69491577, 26.36366081], [88.694664, 26.36366653], [88.69438934, 26.36367035], [88.69074249, 26.36373138], [88.68914795, 26.36375999], [88.6885376, 26.3667984], [88.68831635, 26.36789894], [88.68797302, 26.37024307], [88.68787384, 26.370224], [88.68769073, 26.37084961], [88.68764496, 26.37142944], [88.68760681, 26.37162018], [88.68749237, 26.37162399], [88.68733215, 26.37221336], [88.68721008, 26.37220764], [88.6869812, 26.37306023], [88.68675232, 26.37387466], [88.68621826, 26.37378693], [88.68573761, 26.37370682], [88.68530273, 26.37476921], [88.68527985, 26.37563324], [88.68552399, 26.37569237], [88.68601227, 26.37581062], [88.68604279, 26.37667847], [88.68667603, 26.37689972], [88.6865921, 26.37848663], [88.68609619, 26.37866974], [88.68476105, 26.3785553], [88.68403625, 26.37841797], [88.68126678, 26.37799644], [88.68122864, 26.37831306], [88.68108368, 26.3797226], [88.68103027, 26.38022041], [88.68187714, 26.38040352], [88.68278503, 26.38185883], [88.68286133, 26.38238907], [88.68331909, 26.38241196], [88.68527985, 26.38317108], [88.6890564, 26.38339424], [88.68912506, 26.38342094], [88.690979, 26.38409996], [88.69504547, 26.38523293], [88.69721985, 26.3854332], [88.69881439, 26.38557816], [88.69940948, 26.38562775], [88.69954681, 26.38563919], [88.69976044, 26.38565636], [88.70081329, 26.38574409], [88.70137024, 26.3861599], [88.70220184, 26.38762474], [88.70224762, 26.38855362], [88.70175171, 26.38879013], [88.69960785, 26.38981438], [88.69815063, 26.38928032], [88.69644928, 26.38866997], [88.69439697, 26.38801956], [88.69408417, 26.38792038], [88.69408417, 26.38766479], [88.69300842, 26.38753128], [88.69242859, 26.3874073], [88.69142914, 26.38733673], [88.69110107, 26.38729668], [88.69017029, 26.38720322], [88.68737793, 26.38692665], [88.68730164, 26.38917732], [88.68746948, 26.39018631], [88.68748474, 26.39028358], [88.68771362, 26.39165306], [88.68652344, 26.39069557], [88.68593597, 26.39022064], [88.68587494, 26.39060593], [88.68573761, 26.39151573], [88.6860199, 26.39167023], [88.68760681, 26.39253235], [88.68773651, 26.39320374], [88.68801117, 26.39463234], [88.68802643, 26.39470863], [88.68813324, 26.39472771], [88.68941498, 26.39494514], [88.68938446, 26.39519882], [88.68901825, 26.39553261], [88.68561554, 26.39525414], [88.68476868, 26.39455223], [88.6836319, 26.39361], [88.68060303, 26.3942337], [88.68044281, 26.39421272], [88.68014526, 26.39417458], [88.67933655, 26.39391327], [88.67812347, 26.39352608], [88.67810822, 26.39406013], [88.67701721, 26.39451981], [88.67638397, 26.39485741], [88.67417145, 26.39541245], [88.67343903, 26.39606094], [88.67193604, 26.39754868], [88.67029572, 26.39779282], [88.67074585, 26.39877892], [88.67163086, 26.39860725], [88.67233276, 26.39847183], [88.67198181, 26.39893913], [88.67279816, 26.39940071], [88.67487335, 26.3999691], [88.67596436, 26.40073967], [88.6757431, 26.40113831], [88.67710114, 26.40153885], [88.67932892, 26.40275955], [88.68205261, 26.40261269], [88.68328857, 26.40261269], [88.6838913, 26.4025898], [88.68461609, 26.40256119], [88.68582153, 26.40175819], [88.68599701, 26.40164948], [88.68733978, 26.40133476], [88.68726349, 26.40237999], [88.68729401, 26.40274239], [88.68692017, 26.40273285], [88.68689728, 26.4032135], [88.6867981, 26.40323448], [88.68635559, 26.40332794], [88.68645477, 26.40395927], [88.68648529, 26.40411186], [88.68628693, 26.4041481], [88.68616486, 26.4041729], [88.68617249, 26.40425491], [88.68621063, 26.40454102], [88.6858139, 26.40460968], [88.6857605, 26.40484428], [88.68559265, 26.40553474], [88.68592072, 26.40557289], [88.68676758, 26.40566826], [88.68668365, 26.4061203], [88.68612671, 26.40605927], [88.68571472, 26.4060154], [88.68573761, 26.40585136], [88.6852951, 26.40583611], [88.68421936, 26.40577698], [88.68424225, 26.40600204], [88.68431091, 26.40675545], [88.68362427, 26.40681458], [88.6835022, 26.40759087], [88.68379211, 26.40773582], [88.68380737, 26.40811348], [88.68450165, 26.40806007], [88.68451691, 26.40770531], [88.68524933, 26.40775681], [88.68561554, 26.40838814], [88.6855011, 26.40861702], [88.68560028, 26.40914536], [88.68496704, 26.40919304], [88.68492889, 26.40870094], [88.68393707, 26.40878677], [88.68405914, 26.40908623], [88.68419647, 26.40967941], [88.68440247, 26.41049385], [88.68486786, 26.41065407], [88.68501282, 26.41083336], [88.685112, 26.41108704], [88.68579865, 26.41099739], [88.68584442, 26.4112606], [88.68499756, 26.41155052], [88.68465424, 26.41152763], [88.6834259, 26.41156197], [88.68331146, 26.41254044], [88.68302155, 26.41271019], [88.68157959, 26.41247749], [88.68151855, 26.41088104], [88.68138123, 26.41070938], [88.68141937, 26.41043663], [88.68132782, 26.41033936], [88.68144989, 26.40923119], [88.68154144, 26.40846634], [88.68167114, 26.40843201], [88.68170166, 26.40803528], [88.68069458, 26.40800285], [88.68065643, 26.40854836], [88.67987061, 26.40855789], [88.67987061, 26.40872383], [88.67947388, 26.40869331], [88.67945099, 26.40886307], [88.67819214, 26.40858841], [88.67787933, 26.40781784], [88.67630768, 26.4077301], [88.67475891, 26.4077816], [88.67474365, 26.40801811], [88.6740799, 26.40791512], [88.67408752, 26.40769005], [88.67284393, 26.40770149], [88.67236328, 26.40771866], [88.67191315, 26.40767288], [88.67127991, 26.40760803], [88.67004395, 26.40761375], [88.67003632, 26.40740967], [88.66773987, 26.40730667], [88.66766357, 26.40784264], [88.66763306, 26.40804291], [88.66772461, 26.40900993], [88.66764069, 26.40903664], [88.66764832, 26.40930557], [88.66766357, 26.40964317], [88.66733551, 26.4096756], [88.6671524, 26.4097023], [88.66639709, 26.40981293], [88.66628265, 26.40978622], [88.66548157, 26.40959167], [88.66454315, 26.40984344], [88.66383362, 26.40896606], [88.66382599, 26.40971947], [88.66321564, 26.40994644], [88.66322327, 26.40979767], [88.6627655, 26.40995789], [88.66299438, 26.41068077], [88.66301727, 26.41075134], [88.66291046, 26.41077423], [88.66227722, 26.41091537], [88.66194916, 26.41167068], [88.66171265, 26.41178131], [88.66165924, 26.41259003], [88.66192627, 26.4125843], [88.66205597, 26.4125824], [88.66204071, 26.41354942], [88.66220856, 26.41357231], [88.66220856, 26.41399765], [88.66107941, 26.4140873], [88.66105652, 26.41470337], [88.6608429, 26.4147625], [88.66082764, 26.41558456], [88.66052246, 26.41565895], [88.66046906, 26.41605377], [88.66039276, 26.41640854], [88.65981293, 26.41656494], [88.65923309, 26.41658592], [88.65918732, 26.41639709], [88.65706635, 26.4164772], [88.6570282, 26.41662025], [88.65632629, 26.41665649], [88.65541077, 26.4164505], [88.65515137, 26.41628647], [88.65492249, 26.4161396], [88.65442657, 26.41607094], [88.65435028, 26.4160347], [88.65433502, 26.4157238], [88.65364838, 26.41571045], [88.65275574, 26.41569328], [88.65137482, 26.41566467], [88.65048981, 26.41562271], [88.65044403, 26.41629601], [88.65044403, 26.41663551], [88.65032196, 26.41751289], [88.64848328, 26.41754341], [88.64855194, 26.4171257], [88.64804077, 26.41710281], [88.64802551, 26.41699409], [88.64677429, 26.41704178], [88.64714813, 26.41743279], [88.64727783, 26.41757011], [88.64714813, 26.4176693], [88.6470108, 26.41762924], [88.64681244, 26.41775322], [88.64685059, 26.4179039], [88.64673615, 26.41801262], [88.6467514, 26.41820717], [88.64645386, 26.41839027], [88.64652252, 26.41867065], [88.64633179, 26.41849327], [88.64620972, 26.41838264], [88.64611816, 26.41840553], [88.64440155, 26.41883278], [88.64444733, 26.41924858], [88.64497375, 26.41994286], [88.6462326, 26.42009735], [88.64689636, 26.42009735], [88.64785004, 26.42017365], [88.64906311, 26.42027092], [88.64971924, 26.42077255], [88.65057373, 26.42142868], [88.65100861, 26.42176437], [88.65130615, 26.42457008], [88.65110016, 26.42521286], [88.65091705, 26.42580986], [88.65058136, 26.42674065], [88.65028381, 26.42754745], [88.64975739, 26.4296875], [88.64962769, 26.42965698], [88.64661407, 26.42898178], [88.64649963, 26.42901802], [88.64284515, 26.43008995], [88.64218903, 26.43001556], [88.64110565, 26.42989159], [88.64034271, 26.42980385], [88.63983917, 26.42974663], [88.63831329, 26.42957306], [88.638237, 26.42956352], [88.63814545, 26.42959023], [88.63805389, 26.42961693], [88.63598633, 26.43026543], [88.63512421, 26.43206406], [88.63478851, 26.43202019], [88.63365936, 26.43187714], [88.63200378, 26.43166542], [88.63105774, 26.43154335], [88.63093567, 26.43152618], [88.63076782, 26.43156242], [88.63063812, 26.43281937], [88.63043213, 26.43473625], [88.62945557, 26.43470573], [88.6280899, 26.43466568], [88.62789917, 26.43371391], [88.62787628, 26.43357849], [88.62768555, 26.43377304], [88.62752533, 26.43381691], [88.62587738, 26.43435097], [88.625, 26.43506622], [88.62372589, 26.43486214], [88.62371063, 26.43494415], [88.62316895, 26.43841743], [88.62471771, 26.44024277], [88.62484741, 26.44039345], [88.62491608, 26.44048119], [88.62600708, 26.44026375], [88.62650299, 26.44016457], [88.62663269, 26.44013786], [88.62824249, 26.44112587], [88.62782288, 26.44376373], [88.62746429, 26.44602013], [88.62708282, 26.44879341], [88.62703705, 26.44913483], [88.62678528, 26.45093536], [88.62648773, 26.45093155], [88.6255722, 26.4509201], [88.625, 26.4550972], [88.62469482, 26.45748138], [88.62454987, 26.45853424], [88.62364197, 26.46495819], [88.62319183, 26.46846771], [88.62201691, 26.46998978], [88.62069702, 26.47106934], [88.61843109, 26.47071838], [88.61434174, 26.47047043], [88.61155701, 26.47025108], [88.60791779, 26.47087288], [88.60608673, 26.4710331], [88.60561371, 26.47102356], [88.60502625, 26.47094154], [88.6043396, 26.47099495], [88.603508, 26.47113037], [88.60347748, 26.4707222], [88.60346222, 26.4705143], [88.60344696, 26.47033501], [88.60269928, 26.47024536], [88.60125732, 26.47045708], [88.60069275, 26.47101974], [88.60058594, 26.47105598], [88.60032654, 26.47129059], [88.5999527, 26.47127151], [88.59577179, 26.47106743], [88.59473419, 26.47093582], [88.5942688, 26.47009087], [88.59432983, 26.46939659], [88.59508514, 26.46932411], [88.59584808, 26.46927643], [88.5954361, 26.46656418], [88.59520721, 26.46286964], [88.59505463, 26.46021271], [88.595047, 26.46011162], [88.59555817, 26.4589119], [88.596138, 26.45594978], [88.596138, 26.45503044], [88.596138, 26.45321083], [88.59690094, 26.45001984], [88.59702301, 26.44939041], [88.59513855, 26.44921112], [88.59291077, 26.44917107], [88.59254456, 26.44874191], [88.59030914, 26.44890976], [88.59030914, 26.44926643], [88.58883667, 26.44948006], [88.58672333, 26.45094681], [88.58428192, 26.45038986], [88.58430481, 26.45077705], [88.5844574, 26.45326042], [88.58435059, 26.45339966], [88.58374023, 26.45420074], [88.58027649, 26.45527077], [88.57637024, 26.45625114], [88.57441711, 26.45673943], [88.57202148, 26.4568615], [88.57098389, 26.45680809], [88.5682373, 26.45716667], [88.56297302, 26.45763969], [88.56182861, 26.45675087], [88.56018829, 26.45706749], [88.55995941, 26.45711136], [88.55841064, 26.45811462], [88.55783081, 26.45895767], [88.55804443, 26.45960999], [88.55986786, 26.45940208], [88.56191254, 26.45880127], [88.56284332, 26.45916176], [88.5631485, 26.45989609], [88.56272125, 26.46046257], [88.55986786, 26.46123505], [88.55961609, 26.46174622], [88.55944061, 26.46209908], [88.55930328, 26.46421051], [88.55934143, 26.4643116], [88.5594101, 26.4643631], [88.56092072, 26.46771622], [88.55888367, 26.46669197], [88.55776215, 26.46672058], [88.55758667, 26.46746826], [88.55802155, 26.4679184], [88.55832672, 26.46823502], [88.557724, 26.46982384], [88.55768585, 26.47003365], [88.55805206, 26.47101212], [88.5586853, 26.47176552], [88.56011963, 26.47256088], [88.55966949, 26.47252274], [88.55787659, 26.47236443], [88.55626678, 26.47180748], [88.55545807, 26.47182465], [88.55430603, 26.47184944], [88.5539856, 26.47185516], [88.55389404, 26.47211456], [88.5537796, 26.47245026], [88.55640411, 26.47316933], [88.55675507, 26.47459221], [88.55682373, 26.47488213], [88.55638123, 26.47512817], [88.5557785, 26.47545815], [88.55383301, 26.47474098], [88.55328369, 26.4745388], [88.55231476, 26.47555733], [88.55226898, 26.47716522], [88.55257416, 26.47733307], [88.55345154, 26.47781944], [88.55471039, 26.47851563], [88.55493164, 26.48058128], [88.55501556, 26.48137474], [88.55651855, 26.48344612], [88.55645752, 26.48487282], [88.5561676, 26.48486328], [88.55496216, 26.48482513], [88.5525589, 26.48456764], [88.55175781, 26.48421288], [88.54936981, 26.48329926], [88.54483795, 26.48265076], [88.54189301, 26.4822998], [88.53981018, 26.48200989], [88.53929901, 26.48190117], [88.53659821, 26.48130989], [88.53295135, 26.4810791], [88.53050232, 26.48089027], [88.52848053, 26.4810009], [88.52738953, 26.48144341], [88.52645111, 26.48148918], [88.52667236, 26.48205757], [88.52671814, 26.4831028], [88.52658081, 26.48442078], [88.52513123, 26.48478317], [88.52415466, 26.4848671], [88.52514648, 26.48520851], [88.52793121, 26.486166], [88.52732849, 26.48624039], [88.52519226, 26.48650551], [88.52282715, 26.48679924], [88.52294159, 26.48696899], [88.52455139, 26.48938942], [88.52467346, 26.49167061], [88.52420807, 26.49238205], [88.52385712, 26.49291992], [88.52340698, 26.49361992], [88.52307892, 26.49412346], [88.52298737, 26.49426079], [88.52259827, 26.49520493], [88.52174377, 26.49726868], [88.52135468, 26.49820709], [88.51862335, 26.50132942], [88.52143097, 26.50357628], [88.52281952, 26.50629807], [88.52202606, 26.50805855], [88.52191925, 26.50847054], [88.51996613, 26.50862122], [88.51876831, 26.50835037], [88.51682281, 26.50799942], [88.51531219, 26.50798988], [88.51405334, 26.50815964], [88.51322174, 26.50906944], [88.5125885, 26.51021004], [88.51246643, 26.51054955], [88.51216125, 26.51154327], [88.51003265, 26.51272011], [88.50983429, 26.51307487], [88.509758, 26.5132122], [88.50932312, 26.51361084], [88.50779724, 26.51449966], [88.50102997, 26.51333046], [88.50073242, 26.51320839], [88.49996185, 26.5125103], [88.49906921, 26.51222229], [88.49754333, 26.51173019], [88.49692535, 26.51213455], [88.49511719, 26.51180077], [88.49285126, 26.51192665], [88.49240875, 26.51195145], [88.49228668, 26.51180077], [88.49151611, 26.510849], [88.49104309, 26.51074219], [88.48981476, 26.51046562], [88.48970032, 26.51044083], [88.48973083, 26.51053238], [88.49029541, 26.51230431], [88.49022675, 26.51244926], [88.48938751, 26.51424217], [88.48914337, 26.51665497], [88.48914337, 26.51761627], [88.489151, 26.51931953], [88.48914337, 26.52223396], [88.48838806, 26.52464867], [88.48786926, 26.52589798], [88.48757935, 26.52660561], [88.4879837, 26.52735329], [88.48860168, 26.52852058], [88.4886322, 26.53062248], [88.48729706, 26.53098869], [88.48720551, 26.53097916], [88.48484802, 26.53073692], [88.48298645, 26.53054619], [88.4825058, 26.53112793], [88.48239136, 26.53284454], [88.48236084, 26.53304291], [88.48215485, 26.53437614], [88.48217773, 26.53504753], [88.48223114, 26.53664207], [88.48431396, 26.5398922], [88.48352814, 26.54106903], [88.48047638, 26.54109383], [88.4781189, 26.54200554], [88.47786713, 26.54259872], [88.47754669, 26.54333878], [88.477005, 26.54351234], [88.47399139, 26.54446983], [88.47390747, 26.54447365], [88.4693985, 26.54417038], [88.46817017, 26.54422951], [88.46746063, 26.54418945], [88.46627808, 26.54416084], [88.46604919, 26.5443325], [88.46482849, 26.54439163], [88.46459961, 26.54440308], [88.46302795, 26.54399872], [88.46252441, 26.54387283], [88.46164703, 26.54691124], [88.46155548, 26.54721642], [88.45915222, 26.54722595], [88.45883179, 26.54722786], [88.45735931, 26.54494286], [88.45800018, 26.54325294], [88.45806885, 26.54272079], [88.45814514, 26.54212379], [88.45825195, 26.54129601], [88.45833588, 26.54068184], [88.45838165, 26.54032707], [88.45689392, 26.53975868], [88.45661163, 26.53965187], [88.45691681, 26.53845978], [88.45723724, 26.53721046], [88.45691681, 26.53692055], [88.45658112, 26.53660965], [88.4564209, 26.53647041], [88.45454407, 26.53634834], [88.45379639, 26.53609276], [88.4525528, 26.53593445], [88.44816589, 26.5353775], [88.44628143, 26.53692818], [88.44386292, 26.53891945], [88.44329834, 26.53938484], [88.44303894, 26.54374313], [88.44302368, 26.54407692], [88.44194794, 26.54408836], [88.43725586, 26.54414177], [88.43569946, 26.54549217], [88.43426514, 26.54673958], [88.43393707, 26.54702377], [88.43123627, 26.55015755], [88.42929077, 26.55442047], [88.42919922, 26.55463982], [88.42745972, 26.55861282], [88.42690277, 26.55985832], [88.42577362, 26.56236458], [88.42442322, 26.56524086], [88.42342377, 26.56576157], [88.42271423, 26.56612778], [88.42266083, 26.56630707], [88.42137909, 26.57028198], [88.42111969, 26.57109451], [88.42141724, 26.57114601], [88.42166138, 26.57403946], [88.42169952, 26.57444382], [88.42235565, 26.57834625], [88.42242432, 26.58028412], [88.42243195, 26.58055115], [88.42253113, 26.58286285], [88.42169952, 26.58532143], [88.42126465, 26.58651352], [88.420784, 26.58784485], [88.42068481, 26.58811378], [88.42025757, 26.58928871], [88.41944122, 26.59184074], [88.41938019, 26.59204483], [88.41988373, 26.59657669], [88.4197998, 26.5991993], [88.41902924, 26.60309029], [88.41780853, 26.60788536], [88.41690826, 26.61218834], [88.41678619, 26.61363602], [88.41677094, 26.61459923], [88.41689301, 26.61490631], [88.41692352, 26.61530685], [88.41728973, 26.61740875], [88.41733551, 26.617836], [88.41739655, 26.61836624], [88.41766357, 26.61972237], [88.41796875, 26.6215744], [88.41798401, 26.6216507], [88.41455078, 26.6225071], [88.41524506, 26.62454033], [88.41550446, 26.62557411], [88.41613007, 26.62809181], [88.41603088, 26.63170242], [88.41564178, 26.63177681], [88.41516876, 26.63186646], [88.41478729, 26.63193703], [88.41512299, 26.63326263], [88.41422272, 26.63343811], [88.41396332, 26.6334877], [88.41385651, 26.63350868], [88.41200256, 26.63407326], [88.41131592, 26.63381004], [88.41044617, 26.63313103], [88.4095993, 26.63257027], [88.40907288, 26.63376617], [88.407547, 26.63150978], [88.40446472, 26.62985802], [88.40113068, 26.62812996], [88.40078735, 26.62795448], [88.39842224, 26.62598801], [88.39836121, 26.62593651], [88.39820862, 26.62548256], [88.39785767, 26.62444305], [88.39686584, 26.62152672], [88.39626312, 26.61998367], [88.3943634, 26.61824608], [88.39050293, 26.61629105], [88.38765717, 26.61204338], [88.38792419, 26.61119461], [88.38852692, 26.6092701], [88.38859558, 26.60890579], [88.39022827, 26.60768509], [88.39048767, 26.60756493], [88.39271545, 26.60654449], [88.39328003, 26.60653687], [88.39555359, 26.60712624], [88.39601898, 26.60706711], [88.39782715, 26.60633087], [88.39827728, 26.60617828], [88.39842224, 26.60435295], [88.39846802, 26.60372543], [88.39469147, 26.60281372], [88.39420319, 26.60261917], [88.39413452, 26.60264397], [88.39079285, 26.60124588], [88.388237, 26.60025978], [88.38650513, 26.5997715], [88.38507843, 26.59936905], [88.38479614, 26.59928894], [88.38453674, 26.59921455], [88.38316345, 26.59882736], [88.38239288, 26.59860992], [88.38169861, 26.59852028], [88.37963104, 26.59825134], [88.37732697, 26.5965786], [88.37591553, 26.59426689], [88.37586975, 26.59247208], [88.37506866, 26.5875206], [88.37467957, 26.58687592], [88.373909, 26.58558083], [88.37387085, 26.58551598], [88.37458038, 26.58405876], [88.37466431, 26.58389091], [88.37464142, 26.5827446], [88.37464142, 26.58226967], [88.37456512, 26.58175659], [88.37434387, 26.5808754], [88.37421417, 26.58030891], [88.37413025, 26.57994652], [88.3739624, 26.57918739], [88.3738327, 26.57862091], [88.37275696, 26.57747269], [88.37106323, 26.57609177], [88.3706665, 26.57542992], [88.37018585, 26.57460976], [88.37018585, 26.57372856], [88.37034607, 26.5732708], [88.3705368, 26.57271957], [88.37068939, 26.57215309], [88.3707962, 26.57193375], [88.37083435, 26.57174492], [88.37096405, 26.57107353], [88.37108612, 26.57065964], [88.37126923, 26.56998825], [88.37143707, 26.56950951], [88.37156677, 26.56764793], [88.37158203, 26.5668354], [88.37136841, 26.56506157], [88.37123871, 26.56329918], [88.37120819, 26.56192589], [88.37083435, 26.56066513], [88.37041473, 26.55965424], [88.36978912, 26.55952072], [88.36927032, 26.55921745], [88.36833191, 26.55867004], [88.36722565, 26.55786133], [88.36698914, 26.55769157], [88.36681366, 26.55736923], [88.36650085, 26.55679512], [88.3664093, 26.55672836], [88.36586761, 26.55633926], [88.36531067, 26.55540848], [88.3651886, 26.55421448], [88.365242, 26.55323029], [88.36530304, 26.55293846], [88.36540222, 26.55249023], [88.36527252, 26.55212212], [88.36461639, 26.55158234], [88.36392212, 26.55103683], [88.36325073, 26.55049133], [88.36268616, 26.54980278], [88.36186981, 26.54894066], [88.36138916, 26.54800034], [88.36131287, 26.54781914], [88.36061859, 26.54553032], [88.35912323, 26.5422802], [88.35830688, 26.5401001], [88.35786438, 26.53802681], [88.35811615, 26.53731155], [88.35823059, 26.53673172], [88.3584137, 26.53613853], [88.35908508, 26.5355587], [88.35916138, 26.53549004], [88.35913086, 26.5353775], [88.35884094, 26.53434753], [88.359375, 26.53380966], [88.35961151, 26.53357506], [88.35939026, 26.53347969], [88.35926056, 26.53342247], [88.35919952, 26.53279114], [88.35916138, 26.53237915], [88.35926056, 26.53209305], [88.35930634, 26.53142357], [88.35931396, 26.53129768], [88.359375, 26.53028679], [88.35907745, 26.52964783], [88.35852051, 26.52903748], [88.35798645, 26.52848053], [88.35747528, 26.52792549], [88.35679626, 26.52752304], [88.355896, 26.52727699], [88.35544586, 26.52708435], [88.35402679, 26.5261097], [88.35368347, 26.52586174], [88.35257721, 26.52457047], [88.35185242, 26.52327347], [88.35166931, 26.52242851], [88.35161591, 26.52176666], [88.35158539, 26.52144623], [88.35162354, 26.5209446], [88.35173035, 26.52021217], [88.35187531, 26.51943398], [88.35207367, 26.51852608], [88.3522644, 26.51810455], [88.35264587, 26.51721001], [88.35269928, 26.51708412], [88.35283661, 26.51672935], [88.35302734, 26.51603699], [88.35269165, 26.51538277], [88.35261536, 26.51517677], [88.35276794, 26.51412964], [88.35257721, 26.51202011], [88.35089874, 26.50989914], [88.34970856, 26.50869942], [88.34879303, 26.50792885], [88.34873199, 26.50758743], [88.34844208, 26.50763512], [88.34770966, 26.50775337], [88.3474884, 26.50735283], [88.34715271, 26.50687027], [88.34690094, 26.50650597], [88.34632874, 26.50599289], [88.34593201, 26.50534248], [88.34472656, 26.50437737], [88.34464264, 26.50418472], [88.34436798, 26.50413513], [88.34345245, 26.50335503], [88.34249115, 26.50280571], [88.34187317, 26.5021019], [88.34037018, 26.50066948], [88.33885956, 26.49940109], [88.33760834, 26.4976902], [88.33715057, 26.49714088], [88.33489227, 26.49660683], [88.33464813, 26.49628067], [88.33415222, 26.4956646], [88.33379364, 26.49544334], [88.33351898, 26.4951725], [88.33290863, 26.49448776], [88.33237457, 26.49365807], [88.33206177, 26.4932003], [88.33184814, 26.49215317], [88.33177948, 26.49177933], [88.33165741, 26.49120522], [88.33152771, 26.48886299], [88.3314743, 26.4865284], [88.3311615, 26.48463249], [88.3313446, 26.48459244], [88.33201599, 26.48444557], [88.33346558, 26.4827404], [88.33439636, 26.48164368], [88.33435822, 26.4814949], [88.33402252, 26.48008537], [88.33371735, 26.47880745], [88.33383179, 26.47874641], [88.33457947, 26.47834969], [88.33501434, 26.47811508], [88.33562469, 26.47798347], [88.33728027, 26.47877502], [88.33760071, 26.47876358], [88.33932495, 26.47870827], [88.34068298, 26.47843742], [88.34068298, 26.47769547], [88.3411026, 26.47780037], [88.34211731, 26.47644043], [88.34200287, 26.47369957], [88.34163666, 26.47106934], [88.34202576, 26.46913338], [88.34479523, 26.46884346], [88.34625244, 26.46870041], [88.34648132, 26.46861458], [88.34703064, 26.46840477], [88.34700775, 26.46763229], [88.34646606, 26.46604347], [88.34666443, 26.46602631], [88.3482132, 26.46589279], [88.34815216, 26.46554947], [88.34777832, 26.46327209], [88.3478241, 26.46291924], [88.34820557, 26.46022606], [88.34825897, 26.46001244], [88.34954071, 26.4594593], [88.34970856, 26.45922279], [88.34977722, 26.45898628], [88.34989929, 26.45871353], [88.34979248, 26.45837402], [88.34973907, 26.45817947], [88.34973907, 26.45757675], [88.3500824, 26.45746613], [88.35028076, 26.45716858], [88.35037231, 26.45703125], [88.35036469, 26.4569416], [88.35023499, 26.45594597], [88.35045624, 26.45582771], [88.35097504, 26.45426559], [88.35160828, 26.45350075], [88.35178375, 26.4532814], [88.35201263, 26.45298195], [88.35224152, 26.4525032], [88.35279846, 26.45210266], [88.35322571, 26.45144081], [88.35334778, 26.44987488], [88.3529129, 26.44904137], [88.35243225, 26.44872665], [88.35221863, 26.44857788], [88.3520813, 26.44814873], [88.35270691, 26.44786453], [88.35334778, 26.44757652], [88.35387421, 26.44736099], [88.35477448, 26.44714165], [88.35488892, 26.44711304], [88.35523224, 26.44722557], [88.35551453, 26.44732094], [88.35578156, 26.44763184], [88.35549164, 26.44824028], [88.35539246, 26.44873047], [88.35533142, 26.45006752], [88.35622406, 26.45116997], [88.35646057, 26.45185661], [88.35662842, 26.45202637], [88.35691071, 26.45243454], [88.35720062, 26.45238686], [88.3575058, 26.45289612], [88.35787201, 26.45332336], [88.35897827, 26.45357323], [88.35980988, 26.45372772], [88.36030579, 26.45391273], [88.36062622, 26.45410156], [88.3611908, 26.45469475], [88.36148834, 26.45516777], [88.36149597, 26.45533752], [88.36144257, 26.45566368], [88.36134338, 26.45581245], [88.36101532, 26.45605278], [88.36086273, 26.45616531], [88.36053467, 26.45633698], [88.36044312, 26.45638847], [88.35978699, 26.45646858], [88.3589859, 26.45680428], [88.35894012, 26.4575634], [88.35925293, 26.4579792], [88.35946655, 26.45841408], [88.35984802, 26.45926476], [88.36001587, 26.45950699], [88.36019135, 26.4597683], [88.36036682, 26.46025658], [88.36097717, 26.46146393], [88.36071777, 26.46166229], [88.36039734, 26.46191978], [88.36008453, 26.4623909], [88.36001587, 26.46251869], [88.36004639, 26.4628849], [88.36036682, 26.46342087], [88.360466, 26.46359062], [88.36058807, 26.46414185], [88.36039734, 26.46423912], [88.36035156, 26.46440125], [88.36063385, 26.46534538], [88.36107635, 26.46605301], [88.36143494, 26.46631432], [88.36206818, 26.46678162], [88.36277008, 26.46720123], [88.36319733, 26.46730042], [88.36344147, 26.46735764], [88.3637619, 26.46774292], [88.36400604, 26.46833801], [88.36404419, 26.46843529], [88.36436462, 26.46926117], [88.36451721, 26.46982765], [88.36472321, 26.46998215], [88.36510468, 26.47027206], [88.36603546, 26.47085381], [88.36531067, 26.4715023], [88.36560822, 26.47186852], [88.36559296, 26.47236061], [88.36473083, 26.47284698], [88.36413574, 26.47299576], [88.36395264, 26.47301292], [88.36380768, 26.47302628], [88.36339569, 26.47289658], [88.36255646, 26.47300339], [88.36222839, 26.47350121], [88.36201477, 26.47409821], [88.36190033, 26.47432327], [88.36214447, 26.4745121], [88.36252594, 26.47481728], [88.36264801, 26.47524834], [88.36235046, 26.47543526], [88.36210632, 26.47559547], [88.36241913, 26.47634697], [88.36233521, 26.47682381], [88.36231995, 26.47691727], [88.36229706, 26.47720337], [88.36225891, 26.4773922], [88.36242676, 26.47760963], [88.36251068, 26.47766113], [88.3625946, 26.47771454], [88.36268616, 26.47789383], [88.36248779, 26.47799873], [88.36220551, 26.47815514], [88.36199188, 26.47835732], [88.36197662, 26.47855377], [88.36207581, 26.47917747], [88.36183167, 26.47941017], [88.36170959, 26.47968102], [88.36181641, 26.48003006], [88.36188507, 26.48011398], [88.36204529, 26.48031998], [88.36182404, 26.4806366], [88.3613205, 26.48081589], [88.36122131, 26.48079872], [88.36103821, 26.48077202], [88.36054993, 26.48067093], [88.36048126, 26.48074913], [88.36048126, 26.48095512], [88.3602066, 26.48171616], [88.3602829, 26.48196983], [88.36049652, 26.48264503], [88.36027527, 26.48280716], [88.36006927, 26.48282051], [88.35999298, 26.48291779], [88.36026001, 26.48309708], [88.36022949, 26.48355675], [88.3605957, 26.48382378], [88.36077118, 26.48402977], [88.36075592, 26.48416519], [88.36052704, 26.48430634], [88.36048889, 26.48458672], [88.36053467, 26.4847393], [88.36066437, 26.48484993], [88.36139679, 26.48497772], [88.3618927, 26.48506355], [88.36226654, 26.48531151], [88.36260986, 26.48547363], [88.36269379, 26.48604774], [88.36273193, 26.48630905], [88.36289215, 26.48638725], [88.36325836, 26.48636246], [88.36341095, 26.48644257], [88.36331177, 26.48700905], [88.36709595, 26.4876194], [88.37113953, 26.48826408], [88.37234497, 26.48840714], [88.37265015, 26.48838234], [88.37374878, 26.48846817], [88.37440491, 26.48851776], [88.3744278, 26.48786354], [88.37445831, 26.48716927], [88.37446594, 26.48692322], [88.37494659, 26.48627853], [88.37508392, 26.48591805], [88.37529755, 26.48533821], [88.37537384, 26.48500252], [88.3755722, 26.48407936], [88.37615204, 26.48414803], [88.3772583, 26.48427963], [88.37755585, 26.48431396], [88.37918854, 26.48365974], [88.38137054, 26.48371887], [88.38259125, 26.48320389], [88.38455963, 26.48319244], [88.38596344, 26.48274612], [88.38619995, 26.48293304], [88.3866806, 26.48174477], [88.38728333, 26.48148918], [88.38841248, 26.48035049], [88.3899765, 26.4793911], [88.39086914, 26.47919464], [88.39109802, 26.47924805], [88.39186859, 26.47970581], [88.39349365, 26.48066521], [88.39557648, 26.48134995], [88.39781189, 26.48206139], [88.40080261, 26.483078], [88.40123749, 26.48322678], [88.40146637, 26.48413086], [88.40233612, 26.48543739], [88.40398407, 26.48606491], [88.40415192, 26.48612785], [88.40491486, 26.48589325], [88.40552521, 26.48514748], [88.40539551, 26.48475647], [88.40627289, 26.48408127], [88.40659332, 26.48203087], [88.40747833, 26.48055077], [88.40811157, 26.47971535], [88.40860748, 26.47956848], [88.40859985, 26.47908211], [88.40886688, 26.47872925], [88.40988159, 26.4770546], [88.41040802, 26.47699165], [88.41027069, 26.47634506], [88.41014099, 26.47504044], [88.41072083, 26.47484016], [88.41210938, 26.47435951], [88.41249084, 26.47422791], [88.41251373, 26.47380066], [88.41366577, 26.47195816], [88.41394806, 26.47171211], [88.41445923, 26.47146988], [88.4145813, 26.47115326], [88.41651917, 26.46945], [88.41665649, 26.46934891], [88.41863251, 26.46940041], [88.41860962, 26.46901512], [88.41854095, 26.4679718], [88.41890717, 26.46770287], [88.41969299, 26.46708107], [88.42074585, 26.46622849], [88.42105865, 26.46600151], [88.42243958, 26.46608925], [88.42193604, 26.4669857], [88.4216156, 26.46756363], [88.42133331, 26.46865654], [88.42167664, 26.46892357], [88.42238617, 26.46949005], [88.42292786, 26.4699192], [88.42276764, 26.47278023], [88.42559814, 26.47294426], [88.42838287, 26.47302246], [88.42901611, 26.47192383], [88.42916107, 26.47177505], [88.42995453, 26.47094536], [88.43029785, 26.47071075], [88.43062592, 26.4706955], [88.4313736, 26.47159576], [88.43183136, 26.47172928], [88.43331146, 26.47216034], [88.43373108, 26.47228241], [88.43379211, 26.47178841], [88.43390656, 26.47082138], [88.43408203, 26.47084808], [88.43538666, 26.47022057], [88.4361496, 26.46903038], [88.43659973, 26.46686172], [88.4372406, 26.46606445], [88.43785095, 26.46599388], [88.44106293, 26.46572685], [88.44338989, 26.46614456], [88.44607544, 26.46676254], [88.45055389, 26.46673203], [88.45491028, 26.46678352], [88.45814514, 26.46673203], [88.4624939, 26.46618652], [88.46598053, 26.46496964], [88.46923828, 26.46432686], [88.47224426, 26.46326065], [88.47712708, 26.46208572], [88.47843933, 26.4616642], [88.47955322, 26.46130562], [88.48091888, 26.46086502], [88.48413849, 26.46052742], [88.48470306, 26.46046829], [88.48519897, 26.46035004], [88.48484039, 26.45936012], [88.4848175, 26.45920753], [88.48465729, 26.45828629], [88.48423767, 26.45669174], [88.48355103, 26.45604515], [88.48236084, 26.45568466], [88.48126984, 26.4554882], [88.48074341, 26.45539284], [88.48035431, 26.4552536], [88.48006439, 26.45516396], [88.47951508, 26.45458984], [88.47937012, 26.45379066], [88.47950745, 26.45253944], [88.48113251, 26.45209122], [88.48277283, 26.4508419], [88.48355865, 26.45058441], [88.48368073, 26.45054626], [88.48536682, 26.45074081], [88.48644257, 26.45066643], [88.48656464, 26.45025253], [88.48656464, 26.45011711], [88.48686981, 26.45005989], [88.48799896, 26.44971848], [88.48781586, 26.44761086], [88.48764038, 26.44538116], [88.48776245, 26.44472313], [88.48820496, 26.44447136], [88.48969269, 26.44431686], [88.49077606, 26.44408226], [88.49108887, 26.44348145], [88.4913559, 26.44346046], [88.49254608, 26.44305992], [88.49267578, 26.44209099], [88.49199677, 26.44031906], [88.49234772, 26.43950844], [88.49280548, 26.4391613], [88.49422455, 26.43831635], [88.49564362, 26.4374752], [88.49616241, 26.43719482], [88.49620819, 26.4369812], [88.49678802, 26.43675041], [88.49755096, 26.43567085], [88.49812317, 26.43435097], [88.4980011, 26.43276978], [88.49655914, 26.43116951], [88.49227905, 26.43050957], [88.49140167, 26.42999077], [88.49147034, 26.42902946], [88.49234772, 26.42855835], [88.49347687, 26.42852211], [88.49507904, 26.42835999], [88.49571228, 26.4281044], [88.49609375, 26.42794228], [88.49673462, 26.42755127], [88.49728394, 26.42686272], [88.49753571, 26.42655945], [88.49760437, 26.42649841], [88.49839783, 26.42580032], [88.49833679, 26.42472267], [88.49816895, 26.42446136], [88.49816895, 26.42427635], [88.49800873, 26.42420959], [88.49771118, 26.42375183], [88.496521, 26.42230988], [88.49508667, 26.42053986], [88.49420166, 26.41922951], [88.49411011, 26.41869545], [88.49478912, 26.41805458], [88.49606323, 26.41711998], [88.49697876, 26.41716003], [88.49820709, 26.41740608], [88.49958038, 26.41763115], [88.50222015, 26.41810799], [88.50265503, 26.41758919], [88.50251007, 26.41728973], [88.50237274, 26.41700172], [88.50184631, 26.41616249], [88.50074768, 26.41482162], [88.49953461, 26.41356468], [88.49876404, 26.41303825], [88.49793243, 26.41218758], [88.49690247, 26.41190529], [88.49610138, 26.4115963], [88.49533081, 26.41039467], [88.49559784, 26.40953255], [88.49650574, 26.40873146], [88.4973526, 26.40857887], [88.49784851, 26.40863228], [88.49977112, 26.40821457], [88.50032806, 26.40782928], [88.50048828, 26.4076519], [88.5010376, 26.40756035], [88.50211334, 26.40744972], [88.50361633, 26.40453911], [88.50370026, 26.40414047], [88.50383759, 26.40353203], [88.50414276, 26.40369606], [88.50523376, 26.40447617], [88.50561523, 26.4053936], [88.50627899, 26.40665436], [88.50662231, 26.40698433], [88.50714874, 26.40699005], [88.50723267, 26.40695763], [88.50776672, 26.40704155], [88.50835419, 26.40704918], [88.50874329, 26.40696144], [88.50888062, 26.40729904], [88.50952148, 26.40660095], [88.50963593, 26.4064045], [88.5099411, 26.40590858], [88.51052856, 26.40588951], [88.51072693, 26.40587997], [88.51180267, 26.40389061], [88.51225281, 26.40143967], [88.5118103, 26.40047264], [88.51111603, 26.40001106], [88.50892639, 26.39966011], [88.50772858, 26.39931107], [88.50653839, 26.39857101], [88.5075531, 26.39731979], [88.50968933, 26.39520836], [88.51190186, 26.39270973], [88.51278687, 26.3902607], [88.51294708, 26.38881111], [88.51300049, 26.38843918], [88.51300049, 26.38762474], [88.51319885, 26.38741684], [88.5134964, 26.38741493], [88.51402283, 26.38731766], [88.51457977, 26.38760185], [88.51515961, 26.38865471], [88.51565552, 26.38955688], [88.51670074, 26.39028549], [88.51678467, 26.39027977], [88.51883698, 26.39011955], [88.51909637, 26.39009857], [88.51906586, 26.38991165], [88.51920319, 26.38994026], [88.51937866, 26.38980103], [88.5202179, 26.38914108], [88.52072144, 26.38789177], [88.52015686, 26.38640976], [88.51883698, 26.38594818], [88.51763916, 26.38474083], [88.51715088, 26.38252068], [88.51564789, 26.37989044], [88.51558685, 26.37817955], [88.51515961, 26.37681007], [88.51528931, 26.37458038], [88.51611328, 26.37252998], [88.51628113, 26.37231064], [88.51750183, 26.37071991], [88.51914978, 26.37114906], [88.52040863, 26.37246704], [88.5218811, 26.37459755], [88.52347565, 26.3756218], [88.5242691, 26.37539673], [88.52478027, 26.37466621], [88.52468109, 26.37447929], [88.52461243, 26.37434578], [88.52409363, 26.37338829], [88.52340698, 26.37211037], [88.52212524, 26.37045479], [88.52202606, 26.37031937], [88.52204895, 26.370121], [88.52233887, 26.36812592], [88.52217102, 26.36723328], [88.52111816, 26.36679268], [88.51995087, 26.3663044], [88.51898193, 26.36632538], [88.51881409, 26.36632919], [88.5175705, 26.36647034], [88.51570129, 26.36597824], [88.51528168, 26.36511421], [88.51532745, 26.36423302], [88.51534271, 26.36406708], [88.51654053, 26.36253738], [88.51719666, 26.36240196], [88.51829529, 26.36217499], [88.51973724, 26.36279488], [88.5212326, 26.36327744], [88.52244568, 26.36259651], [88.52274323, 26.36220169], [88.5235672, 26.36194992], [88.52477264, 26.36092949], [88.52480316, 26.36048126], [88.52482605, 26.35983849], [88.52375793, 26.35790062], [88.52282715, 26.35658836], [88.5220108, 26.3555603], [88.52139282, 26.35447121], [88.52088928, 26.35360909], [88.51988983, 26.35218048], [88.51837158, 26.35132027], [88.51725006, 26.35124016], [88.51541901, 26.3517704], [88.5151825, 26.35188103], [88.51476288, 26.35197639], [88.51477051, 26.35210228], [88.51477814, 26.35224533], [88.5147934, 26.35237503], [88.51478577, 26.35248947], [88.51477814, 26.35259056], [88.51475525, 26.35270691], [88.51459503, 26.35272026], [88.51332855, 26.35281944], [88.51004028, 26.35285378], [88.50991058, 26.35285568], [88.50926971, 26.3527298], [88.50996399, 26.35051918], [88.50937653, 26.35077477], [88.50836182, 26.35121727], [88.50833893, 26.35113144], [88.50753021, 26.35119438], [88.50713348, 26.34885025], [88.5056076, 26.34866333], [88.50492859, 26.34873581], [88.50463104, 26.34876633], [88.5045166, 26.34877777], [88.5038147, 26.349617], [88.50474548, 26.35019684], [88.50565338, 26.3518219], [88.50549316, 26.35492325], [88.50545502, 26.35618019], [88.50543976, 26.35643196], [88.50608063, 26.35647964], [88.50700378, 26.35655022], [88.50632477, 26.35856056], [88.50731659, 26.3591938], [88.50754547, 26.35934258], [88.50770569, 26.360672], [88.50795746, 26.36094284], [88.50741577, 26.3613205], [88.50678253, 26.36091995], [88.50527954, 26.35995102], [88.50314331, 26.35845947], [88.50138855, 26.35782051], [88.49944305, 26.3578701], [88.49680328, 26.35877991], [88.49569702, 26.35907936], [88.49505615, 26.35926056], [88.49303436, 26.35950279], [88.49267578, 26.35974693], [88.49260712, 26.35979271], [88.49025726, 26.35983849], [88.48956299, 26.35920906], [88.48957062, 26.35810852], [88.48957062, 26.35784149], [88.49002838, 26.35700035], [88.49072266, 26.35573006], [88.49166107, 26.35391045], [88.49202728, 26.35213089], [88.49215698, 26.3514595], [88.49104309, 26.35042953], [88.48985291, 26.34992027], [88.48854828, 26.34950256], [88.48838043, 26.34892845], [88.48773956, 26.34909248], [88.48703766, 26.34927177], [88.4857254, 26.34960747], [88.48537445, 26.34971237], [88.48503876, 26.34969521], [88.4835434, 26.34967232], [88.483284, 26.34986305], [88.48238373, 26.35050964], [88.48184967, 26.35056496], [88.48171997, 26.35057831], [88.48023224, 26.3507328], [88.48083496, 26.35165977], [88.48016357, 26.35329628], [88.48000336, 26.35325241], [88.47889709, 26.3529377], [88.47727203, 26.35397148], [88.47724915, 26.35410881], [88.47701263, 26.35581589], [88.47705078, 26.35589218], [88.47737122, 26.35660553], [88.4764328, 26.35671043], [88.47302246, 26.35674667], [88.47291565, 26.35658264], [88.47286224, 26.35649872], [88.47229767, 26.35679817], [88.47209167, 26.35690498], [88.4719162, 26.35699463], [88.47042084, 26.35700989], [88.4692688, 26.35713959], [88.46826172, 26.35765076], [88.46685791, 26.35773087], [88.46643829, 26.35774994], [88.46629333, 26.35780716], [88.46315765, 26.35735893], [88.46318817, 26.35772133], [88.46333313, 26.35913086], [88.46326447, 26.35916901], [88.46209717, 26.3597908], [88.46131897, 26.36117744], [88.45982361, 26.36166573], [88.45856476, 26.36221504], [88.45940399, 26.36403465], [88.45788574, 26.36437416], [88.45767975, 26.36441994], [88.45729828, 26.36450577], [88.45731354, 26.36663055], [88.45797729, 26.36678505], [88.45847321, 26.3669014], [88.45863342, 26.36717987], [88.45953369, 26.36879349], [88.46002197, 26.36966896], [88.4598999, 26.37113762], [88.45745087, 26.37146378], [88.45787811, 26.37273407], [88.45814514, 26.37271309], [88.45890045, 26.37265396], [88.45906067, 26.37391472], [88.45789337, 26.37375069], [88.4573822, 26.37318039], [88.45628357, 26.37201309], [88.45413208, 26.37121964], [88.45162964, 26.37047768], [88.45154572, 26.36794662], [88.45078278, 26.36680412], [88.45035553, 26.36649132], [88.44901276, 26.36550331], [88.4486084, 26.36520195], [88.44790649, 26.36468697], [88.44664001, 26.36498833], [88.44645691, 26.3650341], [88.44548035, 26.3617897], [88.44464874, 26.36113548], [88.44420624, 26.35922813], [88.44402313, 26.3586216], [88.44392395, 26.35828781], [88.44333649, 26.3571167], [88.44298553, 26.35642433], [88.44286346, 26.35617256], [88.44273376, 26.35546112], [88.44250488, 26.35496521], [88.44275665, 26.35396194], [88.44258881, 26.35293388], [88.44094086, 26.35179901], [88.43973541, 26.35074234], [88.43915558, 26.35023499], [88.44017029, 26.34980011], [88.44074249, 26.34955597], [88.44026184, 26.3482151], [88.4380722, 26.34633636], [88.43811035, 26.34598541], [88.43829346, 26.34412193], [88.43842316, 26.34277725], [88.43793488, 26.34292603], [88.43707275, 26.34318733], [88.43702698, 26.34286118], [88.43688965, 26.34202194], [88.43684387, 26.34170341], [88.43809509, 26.34145546], [88.43864441, 26.34134674], [88.43830109, 26.33864975], [88.43810272, 26.33704948], [88.4367218, 26.33612823], [88.43493652, 26.33549118], [88.43450165, 26.33522797], [88.43366241, 26.33531952], [88.43151093, 26.3350296], [88.42984009, 26.33505058], [88.42591095, 26.33512115], [88.42451477, 26.33522987], [88.42308807, 26.3353405], [88.42114258, 26.33543968], [88.41861725, 26.33595276], [88.41736603, 26.33611107], [88.41485596, 26.33673096], [88.41308594, 26.33580971], [88.41248322, 26.33392906], [88.411026, 26.33266068], [88.40846252, 26.33163071], [88.40695953, 26.33041954], [88.40627289, 26.32933998], [88.40702057, 26.32788467], [88.40721893, 26.32786369], [88.40790558, 26.32779503], [88.40775299, 26.32711029], [88.40701294, 26.32387543], [88.40698242, 26.32374954], [88.40852356, 26.32322693], [88.40975952, 26.32322121], [88.41152191, 26.32321358], [88.41226959, 26.32399559], [88.41342163, 26.32380867], [88.41518402, 26.32431602], [88.41561127, 26.32444], [88.41574097, 26.32280159], [88.41652679, 26.32176208], [88.41641998, 26.32139206], [88.41513062, 26.3169632], [88.41526794, 26.31600761], [88.41511536, 26.31561089], [88.41495514, 26.31518555], [88.41454315, 26.3154068], [88.41423798, 26.31557465], [88.41334534, 26.31605339], [88.41293335, 26.31627846], [88.41235352, 26.31585884], [88.41207123, 26.31565666], [88.41152954, 26.31588936], [88.41051483, 26.3163166], [88.41038513, 26.31637192], [88.40963745, 26.31594276], [88.40849304, 26.31657219], [88.40646362, 26.31661415], [88.40546417, 26.31645584], [88.40532684, 26.31647301], [88.40512848, 26.31649971], [88.40399933, 26.31661797], [88.40293121, 26.31677055], [88.40148163, 26.31682014], [88.40027618, 26.31614113], [88.39929199, 26.31509972], [88.39840698, 26.31430054], [88.39740753, 26.31355095], [88.39527893, 26.3126297], [88.39325714, 26.31319809], [88.39212799, 26.31336021], [88.39058685, 26.31373787], [88.38998413, 26.31289864], [88.38987732, 26.31371689], [88.38942719, 26.31368828], [88.38906097, 26.31249809], [88.38812256, 26.31270027], [88.38780212, 26.31277084], [88.3864212, 26.31197166], [88.38581085, 26.30846977], [88.38581085, 26.30785942], [88.38360596, 26.30756187], [88.38134766, 26.3074398], [88.38072968, 26.30653], [88.38047791, 26.30521965], [88.37966919, 26.3043499], [88.37872314, 26.30429077], [88.37705994, 26.3050251], [88.37594604, 26.30483437], [88.37581635, 26.30496216], [88.37583923, 26.30467987], [88.37583923, 26.30307961], [88.37528229, 26.30239105], [88.37452698, 26.30188179], [88.3736496, 26.30227089], [88.3734436, 26.30322838], [88.37306213, 26.30289268], [88.3728714, 26.30342865], [88.37263489, 26.30407143], [88.37239075, 26.30475235], [88.37249756, 26.30488396], [88.37280273, 26.30526924], [88.3731308, 26.30568314], [88.37268066, 26.30576706], [88.37150574, 26.30599022], [88.37084198, 26.3051548], [88.37034607, 26.30508232], [88.36920929, 26.30311394], [88.36902618, 26.3019352], [88.36912537, 26.30073929], [88.369133, 26.30058479], [88.36821747, 26.29949188], [88.36781311, 26.29952431], [88.36620331, 26.29916], [88.36592102, 26.29908943], [88.36580658, 26.29886055], [88.36543274, 26.29807091], [88.36493683, 26.29652977], [88.36514282, 26.29430962], [88.36444855, 26.29241943], [88.36313629, 26.29076195], [88.36145782, 26.28853035], [88.36045837, 26.28738022], [88.35926819, 26.28629112], [88.358078, 26.28583908], [88.35700226, 26.28610992], [88.35606384, 26.28652], [88.35588074, 26.28603935], [88.35518646, 26.28539658], [88.35475159, 26.28561974], [88.35449982, 26.28502083], [88.35437775, 26.28370857], [88.35414124, 26.28285027], [88.35271454, 26.28227043], [88.35262299, 26.28223228], [88.35190582, 26.28262138], [88.35121155, 26.28289413], [88.34960175, 26.28230858], [88.34944916, 26.28152275], [88.3494339, 26.28144836], [88.34967041, 26.28121567], [88.35022736, 26.28065872], [88.35057831, 26.27954292], [88.34976959, 26.27892494], [88.34931946, 26.27825546], [88.34923553, 26.27787971], [88.35017395, 26.27698898], [88.35009003, 26.27667427], [88.35144043, 26.27650833], [88.3518219, 26.27596092], [88.35011292, 26.2752285], [88.34886169, 26.27410889], [88.34857178, 26.27348328], [88.34866333, 26.27336693], [88.34989929, 26.2726841], [88.35011292, 26.27165604], [88.34902191, 26.271101], [88.34889221, 26.26976204], [88.34812164, 26.26890564], [88.34815979, 26.26847076], [88.3495636, 26.26784515], [88.3499527, 26.26767349], [88.35015106, 26.26789856], [88.3506546, 26.26847649], [88.35076904, 26.26860619], [88.35189819, 26.26760674], [88.3518219, 26.26713943], [88.35280609, 26.26726913], [88.35382843, 26.26646996], [88.35389709, 26.26551056], [88.35352325, 26.26499176], [88.35251617, 26.26447105], [88.35176849, 26.26383972], [88.35270691, 26.26264954], [88.35309601, 26.26190948], [88.35228729, 26.26071167], [88.35183716, 26.25962067], [88.35209656, 26.25849152], [88.35217285, 26.25712013], [88.35124207, 26.25534058], [88.35035706, 26.25431061], [88.35018158, 26.25316811], [88.35050201, 26.25209045], [88.35108185, 26.2513504], [88.35125732, 26.25054932], [88.35121155, 26.25041771], [88.35148621, 26.25020218], [88.35299683, 26.24901581], [88.35362244, 26.24835777], [88.35404205, 26.24791145], [88.35382843, 26.24697304], [88.35338593, 26.24692345], [88.35140991, 26.24743462], [88.35129547, 26.24746323], [88.35114288, 26.24773216], [88.35072327, 26.24845314], [88.34976959, 26.24768448], [88.35012817, 26.24738503], [88.35076904, 26.24685287], [88.35160065, 26.24562645], [88.35162354, 26.24572372], [88.35228729, 26.24576378], [88.35238647, 26.2457695], [88.35365295, 26.24584389], [88.35492706, 26.24540901], [88.35693359, 26.24425125], [88.35775757, 26.24377823], [88.35922241, 26.242939], [88.35919952, 26.24259567], [88.35913849, 26.24150085], [88.35877228, 26.23998451], [88.3587265, 26.23980141], [88.35827637, 26.239748], [88.35557556, 26.23943329], [88.35435486, 26.23829079], [88.35431671, 26.23757362], [88.35429382, 26.23717117], [88.35489655, 26.23604965], [88.3557663, 26.23540878], [88.3559494, 26.23391914], [88.35573578, 26.23251534], [88.35397339, 26.23240471], [88.35338593, 26.23117638], [88.35334778, 26.23108864], [88.35165405, 26.2305851], [88.35115051, 26.23043633], [88.35095978, 26.22834206], [88.35105896, 26.22828102], [88.35324097, 26.22688103], [88.35118866, 26.22556877], [88.35102844, 26.22546959], [88.35062408, 26.2257843], [88.35009003, 26.2262001], [88.34934998, 26.22591782], [88.34999084, 26.22477341], [88.3505249, 26.22381401], [88.3506546, 26.22347069], [88.35101318, 26.22250557], [88.35127258, 26.22181702], [88.35102081, 26.22149467], [88.35012817, 26.22034645], [88.34925079, 26.2209568], [88.34859467, 26.22142601], [88.34781647, 26.22198486], [88.34375763, 26.22013474], [88.34301758, 26.21985817], [88.34111786, 26.21914864], [88.3407135, 26.21899605], [88.3398819, 26.21782112], [88.33976746, 26.2176609], [88.33930206, 26.21763229], [88.336586, 26.21747208], [88.33334351, 26.21604729], [88.3314209, 26.21700668], [88.3311615, 26.21714211], [88.33115387, 26.21684456], [88.33112335, 26.21462822], [88.33110046, 26.21282196], [88.32997131, 26.21318436], [88.32889557, 26.21352959], [88.32868195, 26.21359825], [88.32814026, 26.212883], [88.3265152, 26.21074104], [88.32449341, 26.21055031], [88.32447052, 26.21073151], [88.32305908, 26.21034431], [88.32315826, 26.21007729], [88.32408905, 26.20750427], [88.3245697, 26.20715141], [88.32572937, 26.20630264], [88.32549286, 26.20582771], [88.32444, 26.20482826], [88.32433319, 26.20472717], [88.32376862, 26.20474243], [88.3218689, 26.20479012], [88.32150269, 26.20446587], [88.32139587, 26.20437431], [88.32238007, 26.20241928], [88.32190704, 26.20204926], [88.32028961, 26.20124054], [88.31933594, 26.20238113], [88.31788635, 26.20345116], [88.31664276, 26.20271111], [88.31607819, 26.20111084], [88.31407166, 26.20172119], [88.31305695, 26.20245934], [88.31167603, 26.2029705], [88.30992126, 26.2025528], [88.30860901, 26.2017498], [88.30797577, 26.20049095], [88.30780792, 26.1982708], [88.30674744, 26.19735146], [88.30561066, 26.19791985], [88.30504608, 26.19878006], [88.30479431, 26.19911957], [88.3045578, 26.19898224], [88.3032608, 26.19916916], [88.30301666, 26.19970131], [88.30255127, 26.200737], [88.30273438, 26.20186806], [88.30197144, 26.20197105], [88.3012619, 26.20206451], [88.30124664, 26.20082664], [88.30122375, 26.19953918], [88.30101776, 26.19928169], [88.29989624, 26.19788551], [88.29979706, 26.19775963], [88.29973602, 26.19787979], [88.29962921, 26.19735527], [88.29931641, 26.19729614], [88.29823303, 26.19709587], [88.29764557, 26.19772911], [88.29753876, 26.19813919], [88.29719543, 26.19942856], [88.29516602, 26.19951439], [88.29419708, 26.19869423], [88.29393005, 26.1986618], [88.29251862, 26.19848442], [88.29185486, 26.19867134], [88.29193115, 26.19964027], [88.29165649, 26.19944954], [88.29073334, 26.19812965], [88.2902298, 26.19733047], [88.28916931, 26.19670105], [88.28835297, 26.19742966], [88.28803253, 26.19783401], [88.28813934, 26.19803429], [88.28818512, 26.19815254], [88.28825378, 26.19843674], [88.28790283, 26.19799614], [88.28756714, 26.19757462], [88.28749847, 26.19748497], [88.28747559, 26.19758606], [88.28742218, 26.19788551], [88.28725433, 26.19883156], [88.28717041, 26.1993103], [88.28643036, 26.20030212], [88.28596497, 26.20027161], [88.28557587, 26.20024681], [88.28347015, 26.19852066], [88.28341675, 26.19743538], [88.28284454, 26.1970253], [88.28386688, 26.19502831], [88.28270721, 26.19486809], [88.28263092, 26.1942749], [88.28231049, 26.19423676], [88.2811203, 26.1940937], [88.28077698, 26.19516945], [88.28069305, 26.19544601], [88.28029633, 26.19514275], [88.27967834, 26.194664], [88.27906036, 26.19419289], [88.27897644, 26.19272995], [88.27896118, 26.19240761], [88.27848816, 26.19221306], [88.27807617, 26.1920414], [88.27667236, 26.19037819], [88.27632904, 26.18888474], [88.27626801, 26.18860817], [88.27580261, 26.18853188], [88.27371216, 26.18818474], [88.27371216, 26.188097], [88.27371216, 26.18791008], [88.27281952, 26.18813515], [88.27147675, 26.18820381], [88.27039337, 26.18825722], [88.26976776, 26.18749619], [88.26928711, 26.18659973], [88.26630402, 26.18778419], [88.2660141, 26.18790054], [88.26412964, 26.18878937], [88.26364899, 26.19019318], [88.26317596, 26.18961525], [88.26267242, 26.18899727], [88.2625351, 26.18882179], [88.26215363, 26.18875122], [88.26056671, 26.18845558], [88.25991058, 26.18683434], [88.25953674, 26.18671989], [88.25943756, 26.18668938], [88.25920868, 26.18662071], [88.25876617, 26.18678474], [88.25833893, 26.18732262], [88.2562027, 26.18688965], [88.25621033, 26.18574905], [88.25557709, 26.18465996], [88.25421143, 26.18407822], [88.25287628, 26.18493271], [88.25235748, 26.18560028], [88.25180817, 26.18569946], [88.25084686, 26.18587494], [88.25067139, 26.18713188], [88.25031281, 26.18861389], [88.24989319, 26.18927574], [88.24943542, 26.19000816], [88.24807739, 26.19044495], [88.24747467, 26.1903286], [88.24569702, 26.18997955], [88.24492645, 26.18943214], [88.2455368, 26.18740463], [88.244133, 26.18772316], [88.24393463, 26.18797302], [88.2434845, 26.18852997], [88.24368286, 26.18859673], [88.24420929, 26.18877411], [88.24482727, 26.18955421], [88.2440033, 26.18965912], [88.24343872, 26.18899536], [88.24176788, 26.18917847], [88.24123383, 26.18742561], [88.24155426, 26.18638611], [88.24022675, 26.18573189], [88.23851776, 26.18536949], [88.23796844, 26.18376923], [88.23653412, 26.18267632], [88.23558044, 26.18249893], [88.23485565, 26.18358803], [88.23445892, 26.18487167], [88.23416138, 26.18498611], [88.23275757, 26.184021], [88.2329483, 26.18262863], [88.23317719, 26.18111801], [88.23350525, 26.18083763], [88.23459625, 26.17991257], [88.23480225, 26.17982483], [88.23626709, 26.17919731], [88.23719788, 26.1782341], [88.2371521, 26.17800903], [88.23706055, 26.17760086], [88.23748779, 26.17743111], [88.23882294, 26.17509842], [88.23800659, 26.17401123], [88.2360611, 26.17400169], [88.23455811, 26.17262077], [88.23351288, 26.17097282], [88.23206329, 26.17090034], [88.2299881, 26.17134094], [88.22866821, 26.17168045], [88.22753906, 26.17122078], [88.22762299, 26.17014122], [88.22912598, 26.16905975], [88.22956848, 26.16855049], [88.22944641, 26.16728973], [88.22750092, 26.16718292], [88.22648621, 26.16715813], [88.22518158, 26.16600037], [88.22363281, 26.16497993], [88.22199249, 26.1649704], [88.21980286, 26.16467094], [88.21866608, 26.1636982], [88.21785736, 26.16221046], [88.21698761, 26.16108894], [88.21691895, 26.16127777], [88.21687317, 26.16137886], [88.21675873, 26.16147804], [88.21665192, 26.16150284], [88.21645355, 26.16155434], [88.216362, 26.16157913], [88.21642303, 26.16172981], [88.21641541, 26.16184807], [88.21619415, 26.16191101], [88.21616364, 26.16201401], [88.2162323, 26.1620903], [88.21632385, 26.16221237], [88.21628571, 26.16234398], [88.21621704, 26.16239929], [88.21606445, 26.16255188], [88.21598053, 26.16264915], [88.21583557, 26.16308022], [88.21620178, 26.16377831], [88.21626282, 26.16390419], [88.21599579, 26.16483307], [88.21559143, 26.16496086], [88.21559906, 26.16432762], [88.21517944, 26.16308594], [88.21263123, 26.1616745], [88.20770264, 26.16108513], [88.20399475, 26.15917969], [88.20213318, 26.15928841], [88.20124054, 26.1593399], [88.20080566, 26.16020012], [88.19986725, 26.16051102], [88.19866943, 26.16085052], [88.19724274, 26.15903282], [88.19580841, 26.1569519], [88.19512177, 26.15524101], [88.19497681, 26.15478516], [88.19585419, 26.15473938], [88.19576263, 26.15455818], [88.19544983, 26.15393448], [88.19700623, 26.1539402], [88.19827271, 26.15319061], [88.19834137, 26.15212059], [88.19741058, 26.15086174], [88.19438934, 26.15113068], [88.19238281, 26.15175056], [88.18987274, 26.15236092], [88.18786621, 26.15205956], [88.18579865, 26.15125084], [88.18473816, 26.14999962], [88.18406677, 26.14850044], [88.18268585, 26.14683914], [88.18044281, 26.14569283], [88.17957306, 26.14277077], [88.17891693, 26.14031219], [88.17992401, 26.13993263], [88.17971039, 26.13951492], [88.17942047, 26.13895607], [88.17991638, 26.13804054], [88.18087006, 26.13592911], [88.18055725, 26.13388062], [88.17975616, 26.1315918], [88.17801666, 26.12935829], [88.1764679, 26.12724113], [88.17624664, 26.1261158], [88.17824554, 26.12500572], [88.17819977, 26.12480545], [88.17974854, 26.12434959], [88.18094635, 26.12350082], [88.1803894, 26.12178993], [88.17870331, 26.12012291], [88.17682648, 26.11828041], [88.17621613, 26.11737061], [88.17630005, 26.11319923], [88.17611694, 26.1112709], [88.17563629, 26.10891914], [88.1739502, 26.10760117], [88.17207336, 26.10674095], [88.16900635, 26.10569191], [88.16681671, 26.10522079], [88.16549683, 26.10338974], [88.16607666, 26.10161972], [88.16622162, 26.09974289], [88.16433716, 26.09841919], [88.16240692, 26.09640121], [88.16155243, 26.09464073], [88.16124725, 26.09246826], [88.16320801, 26.08963013], [88.16348267, 26.08911896], [88.16485596, 26.08970451], [88.16454315, 26.08745956], [88.16448212, 26.08701134], [88.16429901, 26.08570671], [88.16187286, 26.08516121], [88.15962219, 26.08372307], [88.1594696, 26.08336067], [88.15895081, 26.0820961], [88.15840912, 26.08078575], [88.15927887, 26.07804871], [88.15996552, 26.07793427], [88.16034698, 26.07787323], [88.16123199, 26.07847214], [88.16551208, 26.08136368], [88.16590881, 26.08163071], [88.1676178, 26.08286476], [88.16757202, 26.08308792], [88.16751862, 26.08334541], [88.16727448, 26.08454323], [88.16748047, 26.08437347], [88.16909027, 26.08305931], [88.16890717, 26.08207512], [88.16881561, 26.08066559], [88.16905975, 26.08033371], [88.1693573, 26.08098984], [88.16977692, 26.08183861], [88.17072296, 26.08293915], [88.17183685, 26.08288956], [88.17304993, 26.08044052], [88.17405701, 26.0782795], [88.17469788, 26.07676125], [88.17489624, 26.07629013], [88.1762619, 26.07561111], [88.17714691, 26.07516289], [88.18055725, 26.07341957], [88.18339539, 26.07169724], [88.18338013, 26.07159805], [88.18333435, 26.07151031], [88.18315125, 26.07117462], [88.18291473, 26.07096291], [88.1827774, 26.07083321], [88.1824646, 26.07052612], [88.18213654, 26.0700798], [88.18196106, 26.06982613], [88.18180084, 26.06960106], [88.18158722, 26.06931114], [88.18143463, 26.06871605], [88.18167877, 26.0671196], [88.18498993, 26.065382], [88.185112, 26.06487656], [88.18546295, 26.06343651], [88.18401337, 26.06201935], [88.18055725, 26.05865669], [88.18019104, 26.05829811], [88.1782074, 26.05931282], [88.17776489, 26.0595417], [88.1771698, 26.05984497], [88.17690277, 26.05945206], [88.17601013, 26.05812836], [88.17772675, 26.05269814], [88.17771149, 26.05222321], [88.17762756, 26.04977798], [88.17760468, 26.04901123], [88.17925262, 26.04659843], [88.17880249, 26.04680252], [88.17738342, 26.04744911], [88.17398834, 26.04899597], [88.17192078, 26.04876518], [88.1710434, 26.04866982], [88.17058563, 26.04795074], [88.16983032, 26.04677963], [88.16949463, 26.04533195], [88.17172241, 26.0431633], [88.17412567, 26.04163551], [88.17536163, 26.03979492], [88.17497253, 26.03945541], [88.17266083, 26.03743935], [88.1725769, 26.03736115], [88.17115784, 26.03654861], [88.17269897, 26.03160858], [88.17414856, 26.03116798], [88.17626953, 26.0305233], [88.17910004, 26.03008652], [88.18050385, 26.02987099], [88.18382263, 26.02980042], [88.18521118, 26.02923965], [88.18608856, 26.02827072], [88.18666077, 26.0270195], [88.18717194, 26.02582169], [88.18712616, 26.0245285], [88.1871109, 26.0240612], [88.18624115, 26.02313995], [88.1836319, 26.02198029], [88.1816864, 26.0206604], [88.17923737, 26.01944923], [88.17681122, 26.01857948], [88.17466736, 26.01890945], [88.17247772, 26.01981163], [88.17059326, 26.02013969], [88.168396, 26.0200119], [88.16501617, 26.01976013], [88.16266632, 26.01974487], [88.16164398, 26.01920891], [88.16072845, 26.01872826], [88.15899658, 26.01922798], [88.15872955, 26.01928139], [88.15756989, 26.01920128], [88.15582275, 26.01861954], [88.15374756, 26.01781273], [88.15168762, 26.01666069], [88.15000153, 26.01575089], [88.1496582, 26.01550102], [88.1484375, 26.01459122], [88.14662933, 26.01332283], [88.14525604, 26.0125103], [88.14399719, 26.01181984], [88.14319611, 26.01021957], [88.14302063, 26.00901985], [88.14496613, 26.0069809], [88.14636993, 26.00515938], [88.14662933, 26.00282288], [88.14676666, 26.00071907], [88.14583588, 25.99911118], [88.14360046, 25.99687958], [88.14276123, 25.9962101], [88.14234924, 25.9958992], [88.14080048, 25.99406052], [88.14028168, 25.9936924], [88.14019775, 25.99380875], [88.1401062, 25.99390793], [88.14004517, 25.99398994], [88.1399231, 25.99407387], [88.13983154, 25.99416161], [88.13975525, 25.99421501], [88.13967896, 25.99426842], [88.1395874, 25.99430656], [88.13951874, 25.99433517], [88.13478088, 25.99821281], [88.13475037, 25.9981308], [88.13246918, 25.9988327], [88.13148499, 25.99700737], [88.13075256, 25.99701881], [88.12963867, 25.99703789], [88.12953949, 25.9966526], [88.1288147, 25.99373245], [88.1301651, 25.9906292], [88.13014221, 25.99023247], [88.12995148, 25.98666382], [88.12994385, 25.98655319], [88.12960815, 25.98552704], [88.1293335, 25.98535728], [88.12804413, 25.98455048], [88.12802124, 25.98446655], [88.12706757, 25.98056412], [88.12700653, 25.98032188], [88.12899017, 25.98033714], [88.12863922, 25.9799366], [88.1280365, 25.97925377], [88.12799072, 25.97871208], [88.12788391, 25.97740555], [88.12782288, 25.97683907], [88.12780762, 25.97671127], [88.12457275, 25.97567749], [88.12475586, 25.97383118], [88.12557983, 25.97280121], [88.12602234, 25.97224045], [88.12732697, 25.97141075], [88.12798309, 25.97100067], [88.1280899, 25.97080994], [88.12886047, 25.96940994], [88.12874603, 25.96689034], [88.12793732, 25.96569061], [88.12594604, 25.96396828], [88.12420654, 25.96293068], [88.121521, 25.96154976], [88.12007141, 25.96071815], [88.11952209, 25.96039009], [88.11833954, 25.95862007], [88.11934662, 25.9571991], [88.12033844, 25.95630074], [88.12062073, 25.95532036], [88.11955261, 25.95420265], [88.11950684, 25.95407104], [88.11920929, 25.95377159], [88.12015533, 25.95316315], [88.12219238, 25.95001793], [88.12231445, 25.94846344], [88.12221527, 25.94838715], [88.12037659, 25.94699097], [88.11975098, 25.945961], [88.11961365, 25.94581413], [88.11764526, 25.94371986], [88.1158905, 25.94373322], [88.11290741, 25.94375801], [88.11290741, 25.93953323], [88.11191559, 25.93803406], [88.11315155, 25.93710518], [88.11322021, 25.93701172], [88.11334991, 25.93688011], [88.11344147, 25.93673325], [88.11353302, 25.93660545], [88.11363983, 25.93647194], [88.1137085, 25.93638039], [88.11347961, 25.93577003], [88.1126709, 25.93451118], [88.11186981, 25.93313026], [88.11080933, 25.93239021], [88.10912323, 25.9319191], [88.10839081, 25.93227959], [88.10623169, 25.93338013], [88.1052475, 25.93394852], [88.10485077, 25.93320084], [88.1030426, 25.93432045], [88.10254669, 25.93464279], [88.10032654, 25.93403053], [88.0982666, 25.9328804], [88.09571838, 25.93132019], [88.09372711, 25.92959976], [88.09143066, 25.92621994], [88.09026337, 25.92279053], [88.08914948, 25.92056084], [88.08834839, 25.91924095], [88.08912659, 25.91594124], [88.0879364, 25.91443825], [88.08705902, 25.91368294], [88.08927155, 25.91314125], [88.09054565, 25.9146595], [88.09072113, 25.91487312], [88.09176636, 25.91419029], [88.09194183, 25.91236115], [88.09364319, 25.91117668], [88.09352875, 25.91086578], [88.09326935, 25.91014862], [88.09403992, 25.9078083], [88.09138489, 25.90669632], [88.09144592, 25.90573883], [88.09146881, 25.90538025], [88.0912323, 25.90350914], [88.09129333, 25.90188026], [88.09133148, 25.90083885], [88.09122467, 25.90054703], [88.09046173, 25.89849854], [88.0903244, 25.89646912], [88.09311676, 25.89515114], [88.09411621, 25.89467812], [88.09920502, 25.89398766], [88.10047913, 25.89177513], [88.10268402, 25.88956261], [88.10293579, 25.88931274], [88.10274506, 25.88904762], [88.10140991, 25.88716316], [88.1006012, 25.88602448], [88.10069275, 25.88583946], [88.10118103, 25.88492966], [88.10102844, 25.88484383], [88.09828186, 25.88330841], [88.09699249, 25.88051224], [88.09685516, 25.88022041], [88.09819031, 25.87976456], [88.09888458, 25.87861633], [88.09851074, 25.87848091], [88.09657288, 25.87778282], [88.09636688, 25.87751579], [88.09494781, 25.87568283], [88.09405518, 25.8746357], [88.09385681, 25.87440109], [88.09663391, 25.87125587], [88.10003662, 25.8732357], [88.10031891, 25.87272453], [88.10240173, 25.86886978], [88.10096741, 25.86327934], [88.1014328, 25.86300659], [88.1028595, 25.86183357], [88.10482025, 25.86375427], [88.10650635, 25.86884308], [88.10891724, 25.8691349], [88.10919189, 25.86846161], [88.10998535, 25.86653519], [88.11100769, 25.86406517], [88.11090851, 25.8637886], [88.11032104, 25.86214638], [88.10970306, 25.86041451], [88.11005402, 25.85972214], [88.1109848, 25.85791779], [88.11108398, 25.85780334], [88.11120605, 25.85765648], [88.11214447, 25.8565464], [88.1128006, 25.85625076], [88.11355591, 25.85591125], [88.11431885, 25.85494041], [88.11534119, 25.85243988], [88.11530304, 25.84976006], [88.11399078, 25.84793282], [88.11087036, 25.84620285], [88.10662842, 25.8438282], [88.10449982, 25.84387016], [88.10356903, 25.8431797], [88.10289001, 25.84140968], [88.10310364, 25.84054375], [88.10350037, 25.84031677], [88.10707092, 25.8413887], [88.10746002, 25.83980179], [88.10755157, 25.83943558], [88.1088562, 25.83922005], [88.11112213, 25.83811188], [88.1116333, 25.83627129], [88.11151123, 25.83428001], [88.11147308, 25.83419037], [88.11128998, 25.8343029], [88.11109161, 25.83442879], [88.11086273, 25.83457756], [88.11066437, 25.83473015], [88.110466, 25.83487892], [88.11027527, 25.83503914], [88.11013031, 25.83515739], [88.10993195, 25.83529663], [88.1096344, 25.83550072], [88.10935211, 25.83572388], [88.10897064, 25.835989], [88.10860443, 25.83625793], [88.1081543, 25.83661079], [88.10742188, 25.83708], [88.10694885, 25.83431816], [88.10690308, 25.83407593], [88.10650635, 25.83371925], [88.10476685, 25.83215141], [88.10417938, 25.83162308], [88.10302734, 25.83166504], [88.10205078, 25.83170128], [88.10129547, 25.82964516], [88.10788727, 25.8296051], [88.10573578, 25.82801819], [88.10492706, 25.82640266], [88.10502625, 25.82639503], [88.10567474, 25.82635307], [88.10559082, 25.82595062], [88.10551453, 25.82555771], [88.10547638, 25.82538414], [88.10599518, 25.82432747], [88.10619354, 25.8239193], [88.10630035, 25.82375526], [88.10710144, 25.82251549], [88.10728455, 25.8222332], [88.10749817, 25.82206917], [88.10758209, 25.82200432], [88.10801697, 25.82187462], [88.10879517, 25.82309532], [88.10927582, 25.82285309], [88.11152649, 25.82173157], [88.11125183, 25.82154274], [88.11022186, 25.82085228], [88.11009979, 25.82063484], [88.10983276, 25.82017517], [88.10862732, 25.81808472], [88.10785675, 25.81671906], [88.10729218, 25.81571388], [88.10706329, 25.81531906], [88.106987, 25.81517982], [88.10708618, 25.81513977], [88.10783386, 25.81482506], [88.10799408, 25.8147583], [88.108284, 25.81522751], [88.10853577, 25.8156395], [88.11155701, 25.8151722], [88.11215973, 25.81507874], [88.11231995, 25.81507492], [88.11519623, 25.81499672], [88.12007141, 25.81257629], [88.11994934, 25.81229019], [88.11934662, 25.81084442], [88.11876678, 25.80945969], [88.11856842, 25.80924416], [88.11795807, 25.80857277], [88.11748505, 25.80805397], [88.11738586, 25.80794334], [88.11708069, 25.80741119], [88.116539, 25.8064537], [88.1164856, 25.80637169], [88.11535645, 25.80339622], [88.1149292, 25.79964638], [88.11466217, 25.79880524], [88.11441803, 25.79802322], [88.11477661, 25.79812622], [88.11551666, 25.79833603], [88.11572266, 25.79828835], [88.11689758, 25.79801178], [88.11917114, 25.79747581], [88.12444305, 25.79637718], [88.12488556, 25.79628563], [88.12515259, 25.79705811], [88.12519073, 25.79716492], [88.12579346, 25.79710388], [88.12708282, 25.79697227], [88.12769318, 25.79808998], [88.13072205, 25.79730797], [88.13092041, 25.79773712], [88.131073, 25.79805756], [88.13117981, 25.79802895], [88.13248444, 25.79767227], [88.13289642, 25.79755783], [88.13414764, 25.79721642], [88.13595581, 25.79722214], [88.13864136, 25.79674911], [88.13840485, 25.79590988], [88.13885498, 25.79576874], [88.13937378, 25.79560852], [88.14155579, 25.79493713], [88.14168549, 25.79487419], [88.1437912, 25.79390717], [88.1441803, 25.79372787], [88.14444733, 25.79135513], [88.14448547, 25.79103088], [88.1444931, 25.79093361], [88.1446991, 25.78817749], [88.14473724, 25.78769493], [88.14457703, 25.78740311], [88.14337921, 25.78521347], [88.14333344, 25.78511047], [88.14233398, 25.78311539], [88.1420517, 25.7825489], [88.14190674, 25.78226089], [88.14174652, 25.78106117], [88.14165497, 25.78044701], [88.14163208, 25.78023148], [88.14432526, 25.77978516], [88.14517975, 25.77964401], [88.14691925, 25.78009605], [88.14844513, 25.78107452], [88.14858246, 25.78116035], [88.14744568, 25.777668], [88.14703369, 25.77638817], [88.14743805, 25.77634048], [88.14974213, 25.7760582], [88.15214539, 25.77576447], [88.15340424, 25.77739525], [88.15405273, 25.77727509], [88.15458679, 25.7771759], [88.1548233, 25.77713203], [88.15699005, 25.77953529], [88.15671539, 25.7818718], [88.15768433, 25.78223991], [88.1593399, 25.78289413], [88.15911102, 25.78338242], [88.15878296, 25.78409386], [88.15837097, 25.78497505], [88.15849304, 25.78505898], [88.15963745, 25.78589249], [88.15959167, 25.78612709], [88.15931702, 25.78759384], [88.15961456, 25.7876606], [88.16271973, 25.78835487], [88.16443634, 25.78951263], [88.16746521, 25.78831291], [88.17235565, 25.78673363], [88.17250061, 25.78706932], [88.17319489, 25.78861618], [88.17333221, 25.78892899], [88.17359161, 25.78938866], [88.17441559, 25.79087067], [88.17461395, 25.79121971], [88.1756897, 25.7910862], [88.17565155, 25.79136086], [88.17541504, 25.79323006], [88.17565918, 25.79334641], [88.17614746, 25.79358864], [88.17649078, 25.79375648], [88.17713928, 25.79407692], [88.18027496, 25.7933445], [88.18045807, 25.79377556], [88.18102264, 25.79513359], [88.18088531, 25.7953186], [88.17985535, 25.79669762], [88.18180084, 25.79624748], [88.18160248, 25.79661369], [88.18097687, 25.7977562], [88.18097687, 25.79803658], [88.18096161, 25.79917145], [88.18293762, 25.80018425], [88.18332672, 25.80100632], [88.18370056, 25.80178452], [88.18418121, 25.80148697], [88.18482208, 25.80108452], [88.18499756, 25.80097771], [88.18771362, 25.80083084], [88.18855286, 25.80078506], [88.18868256, 25.80077744], [88.18888855, 25.80202103], [88.18919373, 25.80223274], [88.18939972, 25.80237579], [88.1897049, 25.8025856], [88.19341278, 25.80164337], [88.19334412, 25.80105782], [88.1932373, 25.80005455], [88.19428253, 25.79940414], [88.19455719, 25.79923058], [88.19477081, 25.79910278], [88.19457245, 25.79874229], [88.19477081, 25.79867172], [88.19524384, 25.79752159], [88.19703674, 25.79640007], [88.19933319, 25.7940731], [88.19926453, 25.79378891], [88.20094299, 25.79294014], [88.20194244, 25.79117966], [88.2023468, 25.78908157], [88.20705414, 25.78749657], [88.20909119, 25.78720665], [88.20960999, 25.78783607], [88.2093277, 25.78917885], [88.20908356, 25.790308], [88.20950317, 25.79162788], [88.20999908, 25.79172325], [88.21028137, 25.79285431], [88.21063232, 25.79314804], [88.21191406, 25.79421234], [88.21149445, 25.79355431], [88.21076202, 25.79240036], [88.21188354, 25.79228973], [88.21222687, 25.7922554], [88.2130127, 25.79525757], [88.21305084, 25.79659081], [88.21193695, 25.79578209], [88.21086884, 25.79502869], [88.21051788, 25.79504585], [88.2104187, 25.79504967], [88.21030426, 25.79615021], [88.21116638, 25.79680252], [88.21127319, 25.79688644], [88.21329498, 25.79828453], [88.21341705, 25.79823494], [88.21448517, 25.79780006], [88.2142868, 25.80044174], [88.21490479, 25.80091095], [88.215065, 25.80085373], [88.21561432, 25.80065918], [88.2171402, 25.8001194], [88.21954346, 25.79927063], [88.22242737, 25.79760742], [88.22266388, 25.79779434], [88.2249527, 25.79958916], [88.22560883, 25.79939842], [88.22605896, 25.79926872], [88.2271347, 25.7980175], [88.22744751, 25.79765511], [88.22825623, 25.79671288], [88.22859192, 25.79691124], [88.23028564, 25.79789925], [88.23175049, 25.79786491], [88.23219299, 25.79785538], [88.2332077, 25.79823303], [88.23345947, 25.79999924], [88.23308563, 25.80047417], [88.23070526, 25.80239296], [88.23049164, 25.80256271], [88.23171997, 25.80328369], [88.23310852, 25.80459404], [88.23425293, 25.80566788], [88.23561859, 25.8066597], [88.23538971, 25.80831528], [88.23535919, 25.80854416], [88.23563385, 25.80853271], [88.23781586, 25.80843925], [88.2387085, 25.80881882], [88.24036407, 25.80951691], [88.24053955, 25.80959129], [88.24131012, 25.80991745], [88.24178314, 25.80983734], [88.24447632, 25.80938721], [88.2468338, 25.80607986], [88.24692535, 25.80617332], [88.24758911, 25.80726814], [88.2477417, 25.80752754], [88.24799347, 25.80854607], [88.24806213, 25.80879784], [88.24771118, 25.81138802], [88.24853516, 25.81341362], [88.24893951, 25.81232643], [88.24898529, 25.81218719], [88.25327301, 25.81200218], [88.25346375, 25.81199265], [88.25395203, 25.81191826], [88.25698853, 25.81146049], [88.25866699, 25.81131172], [88.25957489, 25.81392479], [88.25998688, 25.81369209], [88.26107788, 25.81307793], [88.26303101, 25.81194878], [88.26426697, 25.81182098], [88.26548004, 25.81053925], [88.26569366, 25.81038094], [88.26593018, 25.81020355], [88.26731873, 25.8094902], [88.26992798, 25.8081398], [88.27017212, 25.80789566], [88.26998138, 25.80792046], [88.26984406, 25.8079586], [88.26966858, 25.80798531], [88.26952362, 25.80797958], [88.26954651, 25.80752563], [88.26959229, 25.80655479], [88.26960754, 25.8061161], [88.27085876, 25.80503845], [88.27097321, 25.80327988], [88.27119446, 25.79998589], [88.27120209, 25.79983902], [88.27141571, 25.79690552], [88.27147675, 25.79605865], [88.271492, 25.79585838], [88.27157593, 25.7946434], [88.27164459, 25.79360008], [88.27177429, 25.79176331], [88.27159119, 25.79134178], [88.27138519, 25.79084587], [88.27145386, 25.79034805], [88.27153778, 25.78977776], [88.27156067, 25.78962135], [88.27012634, 25.78882027], [88.26997375, 25.78873253], [88.26979065, 25.78472328], [88.26808929, 25.78398323], [88.26651764, 25.78329468], [88.26760101, 25.78190231], [88.26831818, 25.78097725], [88.26846313, 25.78079796], [88.2701416, 25.78094673], [88.27050781, 25.78075218], [88.27182007, 25.78006172], [88.27251434, 25.77969933], [88.27370453, 25.77907944], [88.27388763, 25.778759], [88.27445984, 25.77845001], [88.27746582, 25.7762928], [88.27932739, 25.77447891], [88.28188324, 25.77568817], [88.28219604, 25.77555847], [88.28464508, 25.77450371], [88.28645325, 25.77456474], [88.28659821, 25.77453995], [88.28762817, 25.77436829], [88.29074097, 25.77385139], [88.29042053, 25.77283859], [88.29251099, 25.77158165], [88.29376984, 25.76993179], [88.29328156, 25.76644707], [88.29349518, 25.76630783], [88.29637909, 25.76531219], [88.29782104, 25.76490402], [88.29967499, 25.76437569], [88.29885101, 25.76373672], [88.29969025, 25.7629528], [88.30014038, 25.76281929], [88.30002594, 25.76263618], [88.29901886, 25.76097107], [88.30200958, 25.75952721], [88.30327606, 25.75910378], [88.30667877, 25.757967], [88.31182861, 25.75568199], [88.31240082, 25.75527763], [88.3132782, 25.75466156], [88.3136673, 25.75438881], [88.31633759, 25.75318718], [88.31634521, 25.75290871], [88.31635284, 25.75216866], [88.31693268, 25.75196075], [88.31925201, 25.75072289], [88.32007599, 25.74867058], [88.31990051, 25.74644279], [88.31970215, 25.74551201], [88.32071686, 25.74526596], [88.32051086, 25.74459648], [88.32032013, 25.74395943], [88.31958771, 25.74401093], [88.3186264, 25.74407768], [88.31826019, 25.74280357], [88.31987762, 25.74092674], [88.32007599, 25.74075317], [88.32087708, 25.74004936], [88.3208847, 25.73817253], [88.32089233, 25.73757935], [88.32406616, 25.73753738], [88.32501221, 25.73752594], [88.32509613, 25.73760414], [88.32802582, 25.74017143], [88.32810974, 25.74014664], [88.3320694, 25.73903084], [88.33752441, 25.73770905], [88.33750153, 25.7373085], [88.33747101, 25.7366848], [88.3374176, 25.73539543], [88.33792114, 25.73532104], [88.33856964, 25.73522758], [88.34088135, 25.73488998], [88.34124756, 25.73423576], [88.34215546, 25.73259926], [88.34256744, 25.73184967], [88.34308624, 25.73091698], [88.34406281, 25.72954369], [88.34514618, 25.72973061], [88.34776306, 25.73017693], [88.34814453, 25.73017502], [88.34883118, 25.7301712], [88.35057068, 25.73016357], [88.35144806, 25.72827721], [88.35441589, 25.72751808], [88.35539246, 25.72727013], [88.35616302, 25.72932053], [88.35643768, 25.72919846], [88.35878754, 25.72817039], [88.35807037, 25.72531509], [88.36001587, 25.72569847], [88.36134338, 25.72404861], [88.36160278, 25.7213707], [88.36122131, 25.72054482], [88.36204529, 25.7203846], [88.36280823, 25.72023773], [88.36468506, 25.71987152], [88.36499786, 25.7182827], [88.3651123, 25.71769142], [88.365242, 25.71765327], [88.36546326, 25.71764183], [88.36698914, 25.71757126], [88.36752319, 25.71694946], [88.37193298, 25.71559334], [88.37237549, 25.71597099], [88.37308502, 25.71657944], [88.37393188, 25.71730804], [88.37402344, 25.71701622], [88.37462616, 25.71504021], [88.37463379, 25.71403503], [88.37638855, 25.71408081], [88.37857819, 25.71255112], [88.37860107, 25.71162987], [88.37697601, 25.70792007], [88.37449646, 25.70306015], [88.37413025, 25.70043182], [88.37388611, 25.69821167], [88.373909, 25.69775963], [88.37391663, 25.69754791], [88.3761673, 25.69767189], [88.37660217, 25.69759369], [88.37714386, 25.69749641], [88.37736511, 25.69745445], [88.37812042, 25.69731712], [88.37919617, 25.69712257], [88.381073, 25.697258], [88.38135529, 25.69727898], [88.38206482, 25.69733047], [88.38320923, 25.69552803], [88.38529968, 25.69576454], [88.38517761, 25.69449425], [88.38674927, 25.69426727], [88.39055634, 25.69371986], [88.3914566, 25.69359016], [88.39093781, 25.69216347], [88.39079285, 25.69176102], [88.39222717, 25.69115829], [88.39337158, 25.68962097], [88.39375305, 25.68717194], [88.39376068, 25.68557167], [88.39362335, 25.68429375], [88.39564514, 25.68528366], [88.39924622, 25.68558502], [88.40177155, 25.68605995], [88.4019165, 25.68599892], [88.40403748, 25.68510437], [88.40510559, 25.68309593], [88.4050293, 25.68293381], [88.40645599, 25.6824894], [88.40740204, 25.68078041], [88.40804291, 25.67815971], [88.40730286, 25.67655945], [88.40586853, 25.67507172], [88.40505981, 25.67318916], [88.40534973, 25.67147064], [88.40866852, 25.67071152], [88.40918732, 25.67061615], [88.41165924, 25.67016792], [88.41526794, 25.66954041], [88.41858673, 25.66776085], [88.41867828, 25.66790771], [88.42029572, 25.67037582], [88.42085266, 25.67038918], [88.42430115, 25.67046928], [88.42449188, 25.67041588], [88.42711639, 25.66970253], [88.42757416, 25.66957664], [88.42967224, 25.6687355], [88.4332428, 25.66857338], [88.43650818, 25.66799736], [88.43983459, 25.66719055], [88.44008636, 25.66712952], [88.44306183, 25.66606522], [88.44393921, 25.66508484], [88.4454422, 25.66557312], [88.4460907, 25.66545486], [88.44683838, 25.66531754], [88.44692993, 25.66530037], [88.45085907, 25.66457558], [88.45091248, 25.66484451], [88.45104218, 25.66553879], [88.45262909, 25.6652317], [88.45359039, 25.66504478], [88.45376587, 25.66501045], [88.45407867, 25.66425896], [88.45436859, 25.66355324], [88.45433807, 25.66317177], [88.45428467, 25.66243172], [88.45672607, 25.66049957], [88.45767975, 25.65640068], [88.45807648, 25.65071106], [88.45809174, 25.64614105], [88.45748901, 25.64162064], [88.45762634, 25.6371212], [88.45726776, 25.63382149], [88.45783234, 25.63120079], [88.4581604, 25.62787819], [88.45754242, 25.62543106], [88.45461273, 25.6236496], [88.45192719, 25.62267113], [88.45050049, 25.62054825], [88.45044708, 25.61798096], [88.45021057, 25.61569977], [88.44986725, 25.61526108], [88.44896698, 25.6140995], [88.448349, 25.61312294], [88.44873047, 25.61045074], [88.4492569, 25.60896111], [88.44954681, 25.60811043], [88.45024872, 25.60462952], [88.45056915, 25.60251808], [88.44908142, 25.6002903], [88.44783783, 25.59957123], [88.44702148, 25.59909058], [88.44644165, 25.59714699], [88.4480896, 25.59723854], [88.4535141, 25.59812927], [88.45704651, 25.59897804], [88.45720673, 25.596138], [88.45732117, 25.59599876], [88.45847321, 25.59628105], [88.45979309, 25.59528732], [88.45778656, 25.59544373], [88.45936584, 25.59356117], [88.46134949, 25.59324646], [88.46276855, 25.59302139], [88.46299744, 25.59298515], [88.46325684, 25.5923233], [88.46463013, 25.59209824], [88.46575165, 25.5919323], [88.4661026, 25.59065437], [88.46556854, 25.58953857], [88.46717072, 25.58877945], [88.47012329, 25.58646011], [88.47036743, 25.58509064], [88.47044373, 25.58461761], [88.47110748, 25.58519173], [88.4725647, 25.58480072], [88.47330475, 25.58460236], [88.47740173, 25.58538437], [88.4802475, 25.58539772], [88.48106384, 25.58568001], [88.48103333, 25.58242798], [88.4810257, 25.58210182], [88.48226166, 25.58228683], [88.48257446, 25.58233452], [88.48361206, 25.58660316], [88.48677063, 25.58582687], [88.49147797, 25.58458328], [88.49140167, 25.58336639], [88.49138641, 25.5830555], [88.49153137, 25.58304214], [88.49320984, 25.58287621], [88.49395752, 25.58280373], [88.49320221, 25.58427429], [88.49420166, 25.58442879], [88.49447632, 25.58441162], [88.4966507, 25.58464813], [88.49989319, 25.58405495], [88.4998703, 25.58388329], [88.49954987, 25.58135033], [88.49919128, 25.57855606], [88.49900818, 25.57468605], [88.49899292, 25.57444572], [88.49893951, 25.57323265], [88.49780273, 25.57008934], [88.49888611, 25.56821251], [88.49901581, 25.56798744], [88.5009079, 25.56406593], [88.50102997, 25.56103134], [88.501297, 25.5588932], [88.49893951, 25.55875206], [88.49796295, 25.55669594], [88.49901581, 25.55587006], [88.50019836, 25.55359077], [88.5007019, 25.55109024], [88.50100708, 25.55062866], [88.50325012, 25.5499115], [88.50537109, 25.5485878], [88.50788116, 25.54718018], [88.50865936, 25.54532814], [88.5092926, 25.54431725], [88.50939178, 25.54415894], [88.50945282, 25.54438972], [88.50984192, 25.54586411], [88.51093292, 25.54565048], [88.51148987, 25.54554176], [88.51157379, 25.5455246], [88.51242065, 25.54634476], [88.51280975, 25.54672813], [88.51374817, 25.54763603], [88.51423645, 25.54746246], [88.51720428, 25.54641342], [88.51741791, 25.54633904], [88.51901245, 25.54519081], [88.51902771, 25.5450058], [88.51912689, 25.54388428], [88.51926422, 25.54239273], [88.51935577, 25.54132652], [88.51866913, 25.53840828], [88.52086639, 25.53705788], [88.52112579, 25.53688049], [88.52342987, 25.53530884], [88.52352142, 25.5353756], [88.52424622, 25.53625107], [88.52539063, 25.53764534], [88.52648163, 25.54026031], [88.52761078, 25.54324722], [88.52767181, 25.54340744], [88.53307343, 25.54220009], [88.53304291, 25.54045486], [88.53303528, 25.53993416], [88.53318787, 25.53655815], [88.53276825, 25.53229904], [88.53374481, 25.53223991], [88.5342865, 25.53220749], [88.53445435, 25.53219795], [88.53437805, 25.5337925], [88.53445435, 25.53380775], [88.53746033, 25.53443146], [88.53909302, 25.53476906], [88.53936005, 25.53482437], [88.53944397, 25.53448868], [88.53975677, 25.53326225], [88.5403595, 25.5308342], [88.54090881, 25.5308609], [88.54078674, 25.52807045], [88.54075623, 25.52622414], [88.54050446, 25.52626419], [88.53946686, 25.52642632], [88.53798676, 25.52534676], [88.53796387, 25.52523613], [88.5377655, 25.52392578], [88.53739929, 25.52153587], [88.53733063, 25.52108765], [88.53990173, 25.52013397], [88.54036713, 25.5199604], [88.54003143, 25.51844788], [88.53959656, 25.5165062], [88.53970337, 25.51407814], [88.5401535, 25.51332092], [88.5405426, 25.51265717], [88.54117584, 25.51158714], [88.54065704, 25.51126099], [88.53968048, 25.51065254], [88.5398941, 25.50838661], [88.54153442, 25.5086422], [88.54177856, 25.50868034], [88.54349518, 25.50894737], [88.54392242, 25.50901222], [88.5463028, 25.50842667], [88.54649353, 25.50910759], [88.54695129, 25.51070023], [88.54821014, 25.51511002], [88.54826355, 25.51529312], [88.54795837, 25.51824951], [88.54878998, 25.5184021], [88.55019379, 25.51865959], [88.55154419, 25.52052307], [88.55450439, 25.52094841], [88.55485535, 25.52099991], [88.55464935, 25.51813316], [88.55434418, 25.51762772], [88.55504608, 25.51756287], [88.5566864, 25.51567841], [88.55708313, 25.51399612], [88.55958557, 25.5135746], [88.55988312, 25.51280594], [88.5599823, 25.51255608], [88.56362152, 25.51324081], [88.56612396, 25.51365089], [88.56797791, 25.51399612], [88.56825256, 25.51404762], [88.5682373, 25.51392365], [88.56822205, 25.51384735], [88.56778717, 25.51135445], [88.5708313, 25.51084518], [88.57094574, 25.51078796], [88.5719223, 25.51029778], [88.57221985, 25.51014519], [88.57282257, 25.50984573], [88.57273102, 25.50905418], [88.57526398, 25.50872993], [88.57765198, 25.50842476], [88.57976532, 25.50975609], [88.58008575, 25.50979614], [88.58577728, 25.51047707], [88.58609772, 25.50939369], [88.58670807, 25.50728989], [88.58961487, 25.50823021], [88.59027863, 25.50889587], [88.59083557, 25.50945854], [88.59144592, 25.50896072], [88.59371185, 25.50709915], [88.59394836, 25.50701523], [88.59588623, 25.50633049], [88.59606171, 25.50626945], [88.59632874, 25.50618172], [88.59859467, 25.50853729], [88.59960175, 25.50958633], [88.59951782, 25.51132584], [88.59950256, 25.51166916], [88.60031891, 25.51170731], [88.60086823, 25.5117321], [88.60103607, 25.51198578], [88.60151672, 25.5127182], [88.60259247, 25.5143528], [88.60268402, 25.51535416], [88.60274506, 25.51596642], [88.60478973, 25.51588631], [88.60525513, 25.51586723], [88.60906219, 25.51643372], [88.60907745, 25.51578712], [88.60913086, 25.51361847], [88.60929871, 25.51317787], [88.60942841, 25.51316071], [88.60999298, 25.51185036], [88.61023712, 25.50992966], [88.61264038, 25.50998878], [88.6129303, 25.50999641], [88.61300659, 25.50999832], [88.61306763, 25.50993156], [88.61392975, 25.50897217], [88.61477661, 25.50803757], [88.61487579, 25.50792885], [88.61507416, 25.50713539], [88.61515808, 25.50680733], [88.61551666, 25.50539589], [88.61607361, 25.50496483], [88.61632538, 25.50476265], [88.61760712, 25.5037632], [88.61865234, 25.50382233], [88.61965179, 25.50387955], [88.61988831, 25.50334167], [88.62030029, 25.50236702], [88.62068176, 25.50147629], [88.62130737, 25.4998951], [88.62264252, 25.49882126], [88.62290955, 25.49777031], [88.62309265, 25.4971447], [88.62696075, 25.49787521], [88.62919617, 25.4982605], [88.63330078, 25.4987545], [88.63491821, 25.49894714], [88.63973999, 25.49955368], [88.64086914, 25.49936867], [88.64363861, 25.49891663], [88.64468384, 25.49874496], [88.64480591, 25.498312], [88.64517975, 25.49698257], [88.64699554, 25.49734688], [88.6472702, 25.49715233], [88.64845276, 25.49630737], [88.6484375, 25.49444389], [88.64953613, 25.49328995], [88.65072632, 25.49154091], [88.64948273, 25.49034119], [88.6474762, 25.49033165], [88.64560699, 25.49003983], [88.64511871, 25.48924065], [88.64550018, 25.48610115], [88.64639282, 25.48073959], [88.64644623, 25.48035049], [88.64761353, 25.47856712], [88.64794922, 25.47857857], [88.65029144, 25.48027039], [88.65297699, 25.48153114], [88.65429688, 25.48152542], [88.65688324, 25.48226166], [88.66007996, 25.4818573], [88.66023254, 25.48183823], [88.66088104, 25.47927475], [88.66092682, 25.4790802], [88.66111755, 25.47917557], [88.66126251, 25.47924423], [88.66197205, 25.47959709], [88.66200256, 25.47945786], [88.66217804, 25.47851372], [88.66243744, 25.4770813], [88.6625061, 25.47671318], [88.66252899, 25.47659683], [88.6629715, 25.47376823], [88.66317749, 25.47380257], [88.66412354, 25.47396278], [88.66457367, 25.47403908], [88.66926575, 25.47482491], [88.67029572, 25.47439384], [88.67419434, 25.47464561], [88.67483521, 25.47468948], [88.67519379, 25.47471428], [88.67823029, 25.47414398], [88.67842865, 25.47410583], [88.67977905, 25.47454453], [88.68170929, 25.47517395], [88.68257141, 25.4753418], [88.68448639, 25.47571182], [88.68729401, 25.47561646], [88.68823242, 25.47558403], [88.68976593, 25.47462463], [88.69043732, 25.47420883], [88.69407654, 25.4736805], [88.69580841, 25.47342873], [88.69916534, 25.47150612], [88.69950867, 25.47130966], [88.7000885, 25.47303963], [88.70036316, 25.47593689], [88.70037842, 25.47607422], [88.70278931, 25.47617531], [88.70329285, 25.47619629], [88.7039566, 25.4762249], [88.70616913, 25.47675133], [88.70710754, 25.47697449], [88.70746613, 25.47705841], [88.70653534, 25.47953415], [88.70638275, 25.47993469], [88.70769501, 25.48007011], [88.70804596, 25.48015404], [88.70973969, 25.48056602], [88.70985413, 25.48059464], [88.71012115, 25.48065948], [88.71014404, 25.48161697], [88.70972443, 25.48363876], [88.70931244, 25.48634148], [88.7080307, 25.49237633], [88.70907593, 25.49568748], [88.70923615, 25.49618149], [88.70768738, 25.49955368], [88.70750427, 25.49994469], [88.70812988, 25.49989891], [88.7088623, 25.4998455], [88.70980072, 25.49977493], [88.71012878, 25.49975014], [88.71134949, 25.49988174], [88.71292877, 25.5000515], [88.71327209, 25.50008774], [88.71324158, 25.49821091], [88.71255493, 25.49770927], [88.71191406, 25.49724197], [88.71203613, 25.49701691], [88.71212006, 25.49685669], [88.7122345, 25.49664116], [88.7128067, 25.49555016], [88.71379852, 25.49565506], [88.71334839, 25.49817657], [88.71517944, 25.49885368], [88.71543884, 25.49894714], [88.71466827, 25.49937248], [88.71434021, 25.49955177], [88.7145462, 25.4995594], [88.71500397, 25.49957657], [88.72116089, 25.49980736], [88.72148895, 25.5016613], [88.72570801, 25.50202751], [88.72640228, 25.50232697], [88.72632599, 25.50336266], [88.72988129, 25.50371742], [88.73137665, 25.50375557], [88.7318573, 25.50376701], [88.73670197, 25.50419426], [88.73730469, 25.50429726], [88.74088287, 25.50490761], [88.74184418, 25.50507164], [88.74213409, 25.50511932], [88.74211884, 25.50434875], [88.74209595, 25.50331497], [88.74206543, 25.50185394], [88.74384308, 25.49685669], [88.74385071, 25.49648476], [88.74389648, 25.49487877], [88.74333191, 25.49510002], [88.74254608, 25.4954052], [88.74243164, 25.49514198], [88.74098969, 25.49185753], [88.74002838, 25.48941612], [88.74240112, 25.48880386], [88.74280548, 25.48869896], [88.74475861, 25.48884773], [88.74501801, 25.48886681], [88.7462616, 25.4923172], [88.7485733, 25.49370193], [88.7492218, 25.49383354], [88.75000763, 25.49399185], [88.7505722, 25.49410629], [88.75295258, 25.49416351], [88.7541275, 25.49419022], [88.75534821, 25.49385834], [88.75685883, 25.49344826], [88.76087189, 25.49337769], [88.76477814, 25.49495506], [88.76554871, 25.495718], [88.76893616, 25.4990406], [88.76944733, 25.50037193], [88.77007294, 25.5019989], [88.76927948, 25.50263023], [88.76703644, 25.50446892], [88.76567078, 25.50478363], [88.76553345, 25.50481415], [88.7645874, 25.50623703], [88.76322937, 25.50827599], [88.76303101, 25.50856781], [88.76271057, 25.50866127], [88.76194, 25.50888634], [88.75913239, 25.5097065], [88.7589035, 25.51192856], [88.76039124, 25.51858711], [88.75952911, 25.52248001], [88.75917816, 25.52403069], [88.760849, 25.52534676], [88.7616272, 25.52595901], [88.76331329, 25.52543259], [88.76436615, 25.52510262], [88.7645874, 25.52503204], [88.76708984, 25.52523804], [88.76741028, 25.52526283], [88.76744843, 25.52490425], [88.76778412, 25.5219326], [88.77027893, 25.52055168], [88.77130127, 25.51998329], [88.77289581, 25.51922989], [88.77403259, 25.51869011], [88.77565765, 25.5186882], [88.77618408, 25.51868629], [88.77614594, 25.5182476], [88.77599335, 25.51652527], [88.77628326, 25.51648521], [88.77792358, 25.51624489], [88.77896118, 25.51609421], [88.78061676, 25.51544571], [88.78207397, 25.51618195], [88.78262329, 25.51520538], [88.78277588, 25.51538467], [88.78361511, 25.51636314], [88.78370667, 25.51646996], [88.78634644, 25.51652145], [88.78636932, 25.51704025], [88.78637695, 25.51721764], [88.78639221, 25.51768112], [88.78623199, 25.51774979], [88.78496552, 25.5182991], [88.78523254, 25.51839447], [88.78959656, 25.5199852], [88.7924881, 25.52097893], [88.79232788, 25.52280617], [88.79570007, 25.52310753], [88.79896545, 25.52389336], [88.79930115, 25.5239563], [88.79975128, 25.52403641], [88.80231476, 25.52432632], [88.8032608, 25.52443504], [88.80488586, 25.52330589], [88.80615997, 25.52353287], [88.80861664, 25.52396965], [88.81019592, 25.52335739], [88.81059265, 25.5232029], [88.80944824, 25.52019119], [88.80870819, 25.51822853], [88.80808258, 25.51340675], [88.80799866, 25.51280022], [88.80963135, 25.51082993], [88.81008911, 25.51027489], [88.81003571, 25.5100193], [88.81064606, 25.50879288], [88.8111496, 25.50714111], [88.81153107, 25.50297928], [88.81147003, 25.4981308], [88.8118515, 25.49545288], [88.81297302, 25.49265099], [88.8138504, 25.48986053], [88.8143158, 25.48804283], [88.81542969, 25.48814201], [88.81630707, 25.48822021], [88.82141876, 25.48900032], [88.82620239, 25.48981476], [88.8293457, 25.49030685], [88.82965088, 25.49035454], [88.82958984, 25.48942375], [88.82958221, 25.489254], [88.82963562, 25.48918152], [88.83174896, 25.48636818], [88.83220673, 25.48494339], [88.83307648, 25.48225403], [88.83312225, 25.48200035], [88.83347321, 25.47990799], [88.83352661, 25.47958565], [88.83518982, 25.47554207], [88.83611298, 25.47435188], [88.83727264, 25.47285652], [88.83726501, 25.47262955], [88.83731842, 25.47255707], [88.837883, 25.47180748], [88.83907318, 25.46959114], [88.83937836, 25.46690941], [88.83903503, 25.46604538], [88.83850861, 25.46474075], [88.83732605, 25.46305466], [88.83825684, 25.46191406], [88.83927917, 25.45867538], [88.83919525, 25.45832062], [88.83956909, 25.45795059], [88.84156799, 25.45584106], [88.84211731, 25.45339012], [88.84099579, 25.45145035], [88.83895111, 25.44927979], [88.83563995, 25.44870949], [88.83246613, 25.44728088], [88.83120728, 25.44527817], [88.8295517, 25.44294167], [88.82872009, 25.44089127], [88.8295517, 25.43774986], [88.8296051, 25.4368], [88.83207703, 25.43704224], [88.83226013, 25.43684959], [88.83287811, 25.43621063], [88.83286285, 25.43605232], [88.83272552, 25.43442154], [88.8326416, 25.4336071], [88.83244324, 25.431633], [88.83279419, 25.43166161], [88.83377838, 25.43173981], [88.83426666, 25.43177986], [88.83441925, 25.42753029], [88.8298111, 25.42769241], [88.82854462, 25.42613411], [88.82896423, 25.4242897], [88.83071899, 25.42330551], [88.83034515, 25.42004395], [88.82995605, 25.41711426], [88.8297348, 25.41706276], [88.82668304, 25.41724586], [88.82646942, 25.41576958], [88.81977844, 25.41548347], [88.81961823, 25.41717148], [88.82019043, 25.41804695], [88.81884766, 25.4181366], [88.81827545, 25.41817474], [88.81801605, 25.41719055], [88.81748199, 25.41441727], [88.81237793, 25.41051102], [88.81447601, 25.40996552], [88.81806183, 25.4098568], [88.81930542, 25.40981865], [88.81990814, 25.40978813], [88.82318878, 25.40962791], [88.82321167, 25.40934944], [88.82343292, 25.40611267], [88.82361603, 25.40608978], [88.82594299, 25.40402985], [88.82624817, 25.40345001], [88.82637024, 25.40124321], [88.82860565, 25.40133476], [88.83454132, 25.40151596], [88.83714294, 25.4018898], [88.8378067, 25.39814949], [88.83878326, 25.3982296], [88.8395462, 25.39758682], [88.84079742, 25.39773178], [88.84080505, 25.39762878], [88.84101105, 25.39559937], [88.84117126, 25.39403343], [88.84122467, 25.39347839], [88.84017944, 25.3916893], [88.83878326, 25.39135742], [88.83779144, 25.39112091], [88.83694458, 25.39091873], [88.83733368, 25.38819695], [88.83675385, 25.38462257], [88.83758545, 25.38448524], [88.84022522, 25.38404846], [88.84026337, 25.38398743], [88.84165192, 25.3817215], [88.83842468, 25.38150024], [88.83856201, 25.37846756], [88.83840942, 25.37428474], [88.83939362, 25.37385368], [88.83779144, 25.36813927], [88.83859253, 25.36815643], [88.84008789, 25.36818695], [88.84008789, 25.36798096], [88.84010315, 25.36387062], [88.84328461, 25.36368561], [88.84568024, 25.36354637], [88.8455658, 25.36219406], [88.84635925, 25.36232758], [88.84764099, 25.36254501], [88.8547821, 25.36351395], [88.85481262, 25.36291695], [88.8548584, 25.36225319], [88.8549118, 25.36138153], [88.8549881, 25.36002922], [88.85498047, 25.35946083], [88.85518646, 25.35951042], [88.85681152, 25.35911942], [88.85874939, 25.35758018], [88.85912323, 25.35535049], [88.85923004, 25.35474586], [88.86194611, 25.35508156], [88.86251831, 25.35515213], [88.86361694, 25.35427856], [88.86369324, 25.35177231], [88.86431885, 25.35183716], [88.86538696, 25.35194778], [88.86888123, 25.35230827], [88.86920929, 25.3495121], [88.86907959, 25.34942245], [88.87033844, 25.34914017], [88.87175751, 25.34806824], [88.87158966, 25.34595108], [88.87103271, 25.34299278], [88.87103271, 25.34058952], [88.87135315, 25.33996391], [88.87187958, 25.33963966], [88.87290955, 25.33840752], [88.87339783, 25.33736992], [88.8736496, 25.33682823], [88.87399292, 25.33692551], [88.87423706, 25.33699608], [88.87565613, 25.33740425], [88.87570953, 25.33712387], [88.87609863, 25.33517838], [88.87863159, 25.33273125], [88.88018799, 25.33020973], [88.88127136, 25.32880783], [88.88380432, 25.32641029], [88.88418579, 25.32647705], [88.88509369, 25.32572937], [88.88555145, 25.32579041], [88.88851166, 25.3261795], [88.88802338, 25.32971382], [88.88786316, 25.3300724], [88.88645935, 25.3331337], [88.88574219, 25.33469391], [88.88691711, 25.33518791], [88.88762665, 25.33721161], [88.89083099, 25.33729172], [88.89099121, 25.33729744], [88.89298248, 25.33707619], [88.89352417, 25.33701515], [88.89611816, 25.33697891], [88.89831543, 25.33684731], [88.89913177, 25.33695984], [88.90244293, 25.33742142], [88.90267944, 25.33751106], [88.90514374, 25.33844376], [88.90630341, 25.33796501], [88.90638733, 25.33795166], [88.90630341, 25.33670998], [88.90622711, 25.33562279], [88.90648651, 25.33555031], [88.90818024, 25.33371925], [88.90936279, 25.33098984], [88.9095993, 25.32864952], [88.90979004, 25.3243103], [88.91026306, 25.32344627], [88.91001129, 25.32243347], [88.90965271, 25.32122612], [88.91087341, 25.32089806], [88.91121674, 25.31982994], [88.91259766, 25.31712341], [88.91264343, 25.31703568], [88.91353607, 25.31527901], [88.91505432, 25.31259918], [88.91581726, 25.31177711], [88.9159317, 25.31209755], [88.91641235, 25.31211281], [88.91692352, 25.31215096], [88.91764832, 25.31224823], [88.91847229, 25.31224632], [88.91889954, 25.31224442], [88.91967773, 25.31225395], [88.92093658, 25.3121109], [88.92188263, 25.3120842], [88.92227173, 25.31207466], [88.9236145, 25.31216049], [88.92366791, 25.31210709], [88.92395782, 25.31209373], [88.92401123, 25.31223679], [88.92404938, 25.31234932], [88.92436981, 25.31301689], [88.92444611, 25.3134346], [88.92459869, 25.31371689], [88.92475891, 25.31500626], [88.92597961, 25.3150425], [88.9259491, 25.31540489], [88.92689514, 25.31527328], [88.92794037, 25.31529617], [88.92790985, 25.31570816], [88.927742, 25.31573868], [88.92776489, 25.31729317], [88.92809296, 25.31707573], [88.92825317, 25.31697083], [88.92871857, 25.31652069], [88.92878723, 25.31628227], [88.92855072, 25.31626892], [88.92852783, 25.31546593], [88.92874146, 25.31533241], [88.92865753, 25.31520271], [88.9285965, 25.313797], [88.92874908, 25.3137989], [88.92903137, 25.31380272], [88.92900085, 25.31335068], [88.92899323, 25.31327629], [88.92894745, 25.31246948], [88.92881012, 25.31196976], [88.92855072, 25.31197548], [88.92836761, 25.31060982], [88.92864227, 25.3105526], [88.92861938, 25.31019783], [88.9288559, 25.31017494], [88.92880249, 25.30983734], [88.92900085, 25.30977821], [88.929039, 25.30911255], [88.92869568, 25.30785942], [88.92871857, 25.30687332], [88.92868042, 25.30608559], [88.92875671, 25.30598831], [88.92893219, 25.30576324], [88.92918396, 25.30471611], [88.92927551, 25.30454445], [88.92943573, 25.30421257], [88.92997742, 25.30418396], [88.9305191, 25.30415726], [88.9309082, 25.30435944], [88.93228149, 25.30562019], [88.93268585, 25.30638123], [88.93408203, 25.30898094], [88.93476868, 25.3101387], [88.93489838, 25.31035042], [88.93701172, 25.3111496], [88.93917847, 25.30973053], [88.93933868, 25.30948639], [88.94111633, 25.30676079], [88.94174957, 25.30520058], [88.94243622, 25.30351067], [88.94480133, 25.30180168], [88.94496918, 25.30183029], [88.94500732, 25.3020916], [88.94504547, 25.30231476], [88.94526672, 25.30286026], [88.94596863, 25.30283737], [88.94674683, 25.30242157], [88.94702148, 25.30236053], [88.94750214, 25.30240822], [88.94789886, 25.30256271], [88.9485321, 25.30297661], [88.9496994, 25.30383492], [88.9499054, 25.30387306], [88.95140839, 25.30337524], [88.95184326, 25.30363083], [88.95210266, 25.30391121], [88.95401764, 25.30597115], [88.95620728, 25.30779839], [88.95950317, 25.30797005], [88.96243286, 25.30779839], [88.96498871, 25.30729103], [88.96797943, 25.30711937], [88.97078705, 25.30562973], [88.97177124, 25.30519295], [88.97245789, 25.30488968], [88.97465515, 25.3025589], [88.97468567, 25.30303192], [88.9750061, 25.30306625], [88.97502136, 25.3034153], [88.9751358, 25.30343246], [88.97523499, 25.30443764], [88.97540283, 25.30443954], [88.97549438, 25.30508995], [88.97557831, 25.30590439], [88.97566223, 25.30604935], [88.97586823, 25.30629349], [88.97687531, 25.30620956], [88.97737885, 25.30620193], [88.9794693, 25.30609894], [88.97946167, 25.30595016], [88.9808197, 25.30589104], [88.98246002, 25.30602455], [88.98299408, 25.30591583], [88.98312378, 25.30589104], [88.98377991, 25.30595398], [88.98390198, 25.30570602], [88.98527527, 25.30600929], [88.98493958, 25.30553246], [88.98477936, 25.30530548], [88.98433685, 25.30468178], [88.98420715, 25.30472565], [88.98377228, 25.30420113], [88.98300171, 25.3041172], [88.98286438, 25.30348969], [88.98265076, 25.30320358], [88.98274231, 25.30275536], [88.98285675, 25.30213547], [88.98307037, 25.30178642], [88.98332214, 25.30136871], [88.98387146, 25.30080414], [88.98407745, 25.30091286], [88.98426819, 25.30163765], [88.98446655, 25.30162048], [88.98451996, 25.30171394], [88.98503113, 25.30207253], [88.98529053, 25.302145], [88.98597717, 25.30215263], [88.98638916, 25.30200768], [88.98651123, 25.30184746], [88.98660278, 25.30173492], [88.98641205, 25.3016243], [88.98638153, 25.30155563], [88.98617554, 25.30148697], [88.98621368, 25.30118752], [88.98627472, 25.30082893], [88.98635101, 25.30034065], [88.98646545, 25.29959679], [88.98672485, 25.29969597], [88.98679352, 25.29956627], [88.98711395, 25.29929161], [88.98840332, 25.29932404], [88.98848724, 25.29924202], [88.9887619, 25.29917526], [88.98985291, 25.29941177], [88.99082947, 25.29782295], [88.99101257, 25.29781342], [88.99143219, 25.29732132], [88.99176025, 25.29730034], [88.99252319, 25.29629898], [88.99352264, 25.29664993], [88.99359894, 25.29646492], [88.99518585, 25.29714012], [88.99573517, 25.29616356], [88.99611664, 25.29591179], [88.99698639, 25.29593277], [88.99765778, 25.29604149], [88.99770355, 25.29614639], [88.99795532, 25.29623032], [88.99793243, 25.29668236], [88.99864197, 25.29675865], [88.9988327, 25.29609489], [89.00164795, 25.29660988], [89.00193024, 25.29666138], [89.00216675, 25.29672623], [89.00221252, 25.29704666], [89.00257111, 25.29748344], [89.0026474, 25.29792213], [89.00328064, 25.29787827], [89.00331879, 25.29811478], [89.00299835, 25.29820824], [89.00318146, 25.29882431], [89.00331879, 25.29947281], [89.00363922, 25.29943657], [89.00387573, 25.29945755], [89.00431061, 25.2994957], [89.00534821, 25.29933548], [89.00541687, 25.29951096], [89.00593567, 25.29960823], [89.0059433, 25.29987144], [89.0059433, 25.29999542], [89.00616455, 25.29998779], [89.00628662, 25.29998398], [89.00628662, 25.30008698], [89.00624084, 25.30128479], [89.00611115, 25.30223274], [89.00611115, 25.30235481], [89.00598907, 25.30239296], [89.00583649, 25.30280495], [89.00578308, 25.30297089], [89.00706482, 25.30294609], [89.00722504, 25.3029232], [89.00850677, 25.30311203], [89.00861359, 25.3030777], [89.00887299, 25.30314064], [89.00895691, 25.30257988], [89.00904083, 25.3019104], [89.00917053, 25.30098724], [89.00933838, 25.29973984], [89.0093689, 25.29919624], [89.0093689, 25.2983551], [89.00932312, 25.29749298], [89.0092392, 25.29673004], [89.00914001, 25.29600716], [89.00902557, 25.29522324], [89.00897217, 25.29454613], [89.00891113, 25.29379654], [89.00886536, 25.29335976], [89.00876617, 25.29262924], [89.00869751, 25.2920723], [89.00865173, 25.29176712], [89.00862122, 25.29141617], [89.00857544, 25.29106331], [89.00846863, 25.29022408], [89.0083847, 25.28968811], [89.0083313, 25.28941154], [89.00827026, 25.28884888], [89.0082016, 25.28819466], [89.00799561, 25.28631783], [89.00787354, 25.28577614], [89.00780487, 25.28536797], [89.00773621, 25.28464699], [89.00763702, 25.2840519], [89.00749969, 25.28308105], [89.00737762, 25.28264809], [89.00727081, 25.28211212], [89.00727081, 25.28169441], [89.00724792, 25.28117561], [89.00717926, 25.28081131], [89.00712585, 25.28040695], [89.00714111, 25.2802906], [89.00760651, 25.27659988], [89.00724792, 25.2758007], [89.00702667, 25.27532959], [89.00671387, 25.27547646], [89.00670624, 25.27523232], [89.00671387, 25.27480125], [89.00650787, 25.27475357], [89.00645447, 25.27451515], [89.00645447, 25.27433777], [89.00675964, 25.27426338], [89.00680542, 25.27400398], [89.00666809, 25.27398682], [89.00667572, 25.27388], [89.00681305, 25.27387047], [89.00691223, 25.27307892], [89.00702667, 25.2724514], [89.00713348, 25.27180481], [89.00720978, 25.27133942], [89.00730133, 25.27070808], [89.00746155, 25.26980019], [89.00758362, 25.26907349], [89.00769043, 25.26841927], [89.00779724, 25.26789665], [89.00783539, 25.26765823], [89.00786591, 25.26746941], [89.00790405, 25.2671299], [89.00798798, 25.26637459], [89.0079422, 25.26566315], [89.00785828, 25.26503944], [89.00747681, 25.26513481], [89.00736237, 25.26513672], [89.00731659, 25.26489067], [89.00749207, 25.26484489], [89.00770569, 25.26478958], [89.00759125, 25.26374435], [89.00744629, 25.26371574], [89.00702667, 25.26370811], [89.00696564, 25.26353073], [89.00640869, 25.26358795], [89.00640869, 25.26375198], [89.00605011, 25.26383781], [89.00600433, 25.26376152], [89.0054245, 25.26387405], [89.00514984, 25.26398849], [89.00492859, 25.26407814], [89.00495911, 25.2642498], [89.00501251, 25.26455307], [89.00489807, 25.26459312], [89.00497437, 25.26486778], [89.00475311, 25.26493454], [89.00460815, 25.26497841], [89.00424194, 25.26538658], [89.00437927, 25.26601219], [89.00471497, 25.26625061], [89.00483704, 25.26634026], [89.00522614, 25.26753426], [89.00550842, 25.2688427], [89.00523376, 25.2691288], [89.00348663, 25.26901054], [89.00223541, 25.26905441], [89.00195313, 25.26928711], [89.00106049, 25.26941681], [89.00106049, 25.2694931], [89.00024414, 25.26945114], [89.00020599, 25.26933098], [88.99942017, 25.26934242], [88.9989624, 25.26923943], [88.99856567, 25.26930237], [88.99762726, 25.26917648], [88.99681091, 25.26919365], [88.99654388, 25.269701], [88.99643707, 25.26965141], [88.99586487, 25.27031326], [88.99569702, 25.27033997], [88.99493408, 25.27018547], [88.99473572, 25.27005196], [88.99442291, 25.27033234], [88.99420166, 25.27029228], [88.99410248, 25.27036858], [88.99395752, 25.27033424], [88.99391174, 25.27048874], [88.99347687, 25.27034378], [88.99312592, 25.27027702], [88.99310303, 25.27092934], [88.99317932, 25.27110481], [88.99295807, 25.27167892], [88.99278259, 25.27210999], [88.99303436, 25.27216148], [88.99289703, 25.27284241], [88.99247742, 25.27337646], [88.9923172, 25.27378845], [88.99213409, 25.27379227], [88.99183655, 25.27386856], [88.99175262, 25.2736969], [88.99150085, 25.27380562], [88.99140167, 25.27366066], [88.99060822, 25.27392006], [88.99041748, 25.2739315], [88.98989105, 25.274086], [88.98946381, 25.27416229], [88.9894104, 25.274086], [88.98882294, 25.27415085], [88.9887619, 25.274086], [88.98847961, 25.27413559], [88.98838806, 25.27401352], [88.9871521, 25.27457809], [88.986763, 25.27456665], [88.98627472, 25.27435493], [88.98631287, 25.27422523], [88.98664093, 25.27419281], [88.98649597, 25.27337265], [88.98634338, 25.27259254], [88.98592377, 25.27265167], [88.98566437, 25.27200127], [88.98508453, 25.2722683], [88.98500824, 25.271698], [88.98486328, 25.27108002], [88.98480225, 25.27083397], [88.98478699, 25.27066994], [88.98468781, 25.27058411], [88.98467255, 25.2703743], [88.98458862, 25.27036858], [88.98443604, 25.27036095], [88.98448181, 25.26991653], [88.98439026, 25.26983833], [88.98443604, 25.2696476], [88.98449707, 25.26943207], [88.98436737, 25.26937294], [88.9838562, 25.26915359], [88.9838562, 25.268713], [88.98387909, 25.26838303], [88.9832077, 25.26839066], [88.9831543, 25.26828957], [88.98254395, 25.26829147], [88.98253632, 25.268713], [88.98222351, 25.26869392], [88.9821167, 25.26844788], [88.98210907, 25.26794624], [88.98239899, 25.26789665], [88.98242188, 25.26774979], [88.9825592, 25.26771736], [88.98257446, 25.26760292], [88.98260498, 25.26740456], [88.98246765, 25.26729774], [88.98169708, 25.26730537], [88.98162079, 25.26718903], [88.98140717, 25.26725197], [88.98132324, 25.26680565], [88.98104095, 25.26589775], [88.98135376, 25.26581573], [88.98213196, 25.26560783], [88.98213959, 25.26529503], [88.98226929, 25.2652092], [88.98222351, 25.26499176], [88.98204041, 25.26495552], [88.9818573, 25.26482201], [88.98169708, 25.2648201], [88.9815979, 25.26481819], [88.98158264, 25.26489258], [88.98149109, 25.26494026], [88.98154449, 25.26507759], [88.98163605, 25.26530075], [88.98154449, 25.26538849], [88.98150635, 25.26558495], [88.98135376, 25.26559067], [88.98120117, 25.26532936], [88.98097992, 25.26531601], [88.98091888, 25.26486588], [88.98090363, 25.26478958], [88.98072052, 25.26475716], [88.98062897, 25.26459885], [88.98048401, 25.2645874], [88.98039246, 25.26428604], [88.98032379, 25.26425171], [88.98029327, 25.26410866], [88.98021698, 25.2640667], [88.97986603, 25.26409721], [88.97979736, 25.26374054], [88.97780609, 25.26403809], [88.97745514, 25.26349831], [88.97719574, 25.26358795], [88.97734833, 25.2639904], [88.97696686, 25.26412392], [88.97672272, 25.26420593], [88.97610474, 25.26418686], [88.97582245, 25.26415825], [88.97590637, 25.26349449], [88.9756546, 25.26343346], [88.97567749, 25.26267052], [88.97537231, 25.26263428], [88.97524261, 25.2615509], [88.97499084, 25.26078415], [88.97489929, 25.26065636], [88.97457886, 25.26022339], [88.9740448, 25.26031876], [88.97354126, 25.26030731], [88.97302246, 25.26028061], [88.97286987, 25.26026917], [88.97257996, 25.26020241], [88.97247314, 25.26029587], [88.97218323, 25.26035118], [88.97070313, 25.26047707], [88.97055817, 25.26012993], [88.97025299, 25.25919342], [88.97000122, 25.25867081], [88.96973419, 25.25799561], [88.9688797, 25.25802803], [88.96828461, 25.25793648], [88.96726227, 25.25796509], [88.96675873, 25.25741577], [88.96578217, 25.25680923], [88.96500397, 25.25646973], [88.96300507, 25.25565338], [88.96299744, 25.25557709], [88.96250153, 25.25543976], [88.96219635, 25.25548172], [88.96148682, 25.25557899], [88.96042633, 25.25555992], [88.95972443, 25.25541878], [88.95964813, 25.25534058], [88.95948029, 25.25527954], [88.95896912, 25.25444984], [88.95860291, 25.25454903], [88.95850372, 25.25451279], [88.95710754, 25.25488663], [88.95663452, 25.25497437], [88.95624542, 25.25515556], [88.95574951, 25.25446701], [88.95528412, 25.25397491], [88.9552002, 25.25376129], [88.95500946, 25.25359535], [88.95498657, 25.25348282], [88.95489502, 25.25342941], [88.95501709, 25.25271606], [88.95475769, 25.25263405], [88.9552002, 25.25191498], [88.95523071, 25.25085258], [88.95498657, 25.25031662], [88.95484161, 25.25000954], [88.95414734, 25.24963188], [88.95324707, 25.24902725], [88.95265961, 25.24835777], [88.95201111, 25.24748039], [88.95184326, 25.24657822], [88.95175934, 25.24615097], [88.95169067, 25.24558067], [88.95143127, 25.24374008], [88.95143127, 25.24329948], [88.95131683, 25.24230385], [88.95173645, 25.24146271], [88.95250702, 25.24018478], [88.95291138, 25.23968697], [88.95357513, 25.23886871], [88.95387268, 25.23835564], [88.95393372, 25.23784256], [88.95410156, 25.2377758], [88.95431519, 25.2371769], [88.95418549, 25.23695755], [88.95352936, 25.23609352], [88.95294189, 25.2358532], [88.95279694, 25.23549271], [88.95304871, 25.23536873], [88.95281219, 25.23502159], [88.95310974, 25.23463821], [88.95633698, 25.23046112], [88.9571228, 25.22657967], [88.95735931, 25.2234726], [88.95773315, 25.22324371], [88.95776367, 25.22250557], [88.95767975, 25.22198105], [88.95794678, 25.22104263], [88.95887756, 25.21960068], [88.9580307, 25.21871948], [88.95801544, 25.21834946], [88.95777893, 25.21713638], [88.95796204, 25.21676254], [88.95833588, 25.21696663], [88.95849609, 25.21660614], [88.95792389, 25.21549606], [88.95799255, 25.21450615], [88.95864105, 25.21305847], [88.95875549, 25.21298027], [88.95884705, 25.21282005], [88.9594574, 25.21299934], [88.95963287, 25.21221733], [88.95969391, 25.21195412], [88.9596405, 25.21150589], [88.96038818, 25.21107292], [88.96051788, 25.21118736], [88.96069336, 25.21096039], [88.96136475, 25.21059799], [88.96162415, 25.20919991], [88.96170807, 25.20916557], [88.96151733, 25.20867538], [88.96128845, 25.20866585], [88.96122742, 25.20837593], [88.96104431, 25.20827484], [88.96071625, 25.20837021], [88.9600296, 25.20837212], [88.95954132, 25.20855522], [88.95942688, 25.20843887], [88.95936584, 25.20813942], [88.95850372, 25.20895576], [88.95839691, 25.20891953], [88.95783234, 25.20919418], [88.95690155, 25.20837784], [88.95641327, 25.2082653], [88.95632935, 25.20829201], [88.95624542, 25.20820618], [88.95578003, 25.20826149], [88.95561218, 25.20791817], [88.95556641, 25.20723343], [88.95513153, 25.20695496], [88.95503998, 25.20681953], [88.95458221, 25.20671844], [88.95397949, 25.20679092], [88.95392609, 25.20685959], [88.95347595, 25.20693398], [88.9533844, 25.20687675], [88.95323181, 25.20688438], [88.95285034, 25.20715523], [88.95217133, 25.20715523], [88.95219421, 25.20755959], [88.95195007, 25.20779228], [88.95147705, 25.20672798], [88.95106506, 25.20678902], [88.95110321, 25.20718575], [88.95081329, 25.20720673], [88.95067596, 25.20641708], [88.95004272, 25.20645142], [88.95000458, 25.2066288], [88.94934845, 25.20664787], [88.94928741, 25.20672989], [88.94902039, 25.20677185], [88.94892883, 25.20683098], [88.94845581, 25.20686913], [88.94838715, 25.20700836], [88.94803619, 25.20698929], [88.94741821, 25.20676422], [88.94629669, 25.20677567], [88.94626617, 25.20668793], [88.94532013, 25.20660591], [88.9443512, 25.20622444], [88.94358063, 25.20648956], [88.94355774, 25.20676994], [88.94347382, 25.20682335], [88.94353485, 25.20731354], [88.94326782, 25.20745087], [88.94326019, 25.20800972], [88.94332123, 25.2084713], [88.94335937, 25.2088089], [88.94269562, 25.20947266], [88.94194794, 25.20886803], [88.94184113, 25.20895767], [88.94161224, 25.20898628], [88.94160461, 25.20938873], [88.94142914, 25.2094841], [88.94148254, 25.21004295], [88.9412384, 25.21009254], [88.94125366, 25.21033478], [88.94064331, 25.21043205], [88.94055939, 25.2104435], [88.94055939, 25.21026802], [88.94036102, 25.21024323], [88.94012451, 25.21028709], [88.93923187, 25.21019554], [88.93929291, 25.2109623], [88.93886566, 25.21100044], [88.93885803, 25.21164513], [88.93797302, 25.21184921], [88.93790436, 25.21146965], [88.93751526, 25.21149254], [88.93745422, 25.21105194], [88.93699646, 25.21100616], [88.93697357, 25.2107048], [88.93640137, 25.21063423], [88.93671417, 25.20993233], [88.93663788, 25.20956993], [88.93656158, 25.20897865], [88.93638611, 25.20852089], [88.93631744, 25.20820808], [88.93630981, 25.20729637], [88.93626404, 25.20689392], [88.9360199, 25.20565605], [88.93621063, 25.20495605], [88.93665314, 25.20454025], [88.93672943, 25.20419312], [88.93704987, 25.20369911], [88.93698883, 25.20332909], [88.93689728, 25.20270538], [88.93637085, 25.20248985], [88.93604279, 25.20222092], [88.93589783, 25.20210266], [88.93543243, 25.20172882], [88.93501282, 25.20147514], [88.93468475, 25.2012825], [88.93383026, 25.19990158], [88.9340744, 25.19969559], [88.93413544, 25.19951439], [88.93457031, 25.19821167], [88.93500519, 25.19732666], [88.93515015, 25.19702339], [88.93569183, 25.19666862], [88.93588257, 25.19654083], [88.9360733, 25.19629288], [88.93692017, 25.19508934], [88.93706512, 25.19532585], [88.93789673, 25.19451332], [88.93787384, 25.19428253], [88.93781281, 25.19361496], [88.93830872, 25.19354439], [88.93901062, 25.19343376], [88.94011688, 25.19331741], [88.94021606, 25.19322014], [88.94055176, 25.19312668], [88.94368744, 25.19318771], [88.9438858, 25.19325638], [88.94583893, 25.19395828], [88.94618225, 25.19408035], [88.94700623, 25.19437599], [88.94727325, 25.19447327], [88.94750214, 25.19455338], [88.94746399, 25.19443893], [88.94717407, 25.19341087], [88.94696045, 25.19266129], [88.94676971, 25.19201088], [88.94680786, 25.18953514], [88.94711304, 25.18888664], [88.94772339, 25.18757248], [88.94776917, 25.18747139], [88.94680023, 25.18658829], [88.94619751, 25.18603325], [88.94387817, 25.18429375], [88.94384766, 25.18420219], [88.94351959, 25.18320084], [88.94359589, 25.18310547], [88.9440918, 25.1829567], [88.945755, 25.18245506], [88.94845581, 25.18163681], [88.94959259, 25.18129158], [88.94862366, 25.17962074], [88.94847107, 25.17935181], [88.94845581, 25.17879677], [88.94842529, 25.17725754], [88.94841766, 25.17687416], [88.94841766, 25.17660713], [88.94841003, 25.17643166], [88.94623566, 25.17676926], [88.9458313, 25.1768322], [88.94522095, 25.17617416], [88.94415283, 25.17502213], [88.94322205, 25.17358208], [88.94174194, 25.17360115], [88.94126129, 25.17360878], [88.94102478, 25.17361069], [88.94104004, 25.17378044], [88.9412384, 25.17601776], [88.94109344, 25.17604637], [88.93926239, 25.1764431], [88.9392395, 25.1770649], [88.93922424, 25.1775341], [88.9389267, 25.17929268], [88.9369812, 25.18041229], [88.93427277, 25.18148613], [88.93417358, 25.18152809], [88.93328094, 25.1813488], [88.93050385, 25.17861176], [88.93040466, 25.17852974], [88.929039, 25.17744637], [88.9280014, 25.17648506], [88.9276886, 25.17620087], [88.9287262, 25.17498016], [88.92899323, 25.17466545], [88.92804718, 25.17466927], [88.92711639, 25.17467499], [88.92671204, 25.17430115], [88.92664337, 25.17424202], [88.92498779, 25.17270851], [88.92444611, 25.17221451], [88.92418671, 25.17197227], [88.92411041, 25.17166519], [88.92405701, 25.17142677], [88.92389679, 25.16937447], [88.92378998, 25.16897964], [88.92351532, 25.16801071], [88.92314911, 25.16672897], [88.92301941, 25.16500664], [88.92105865, 25.16567993], [88.92088318, 25.16578865], [88.91861725, 25.16723633], [88.91835022, 25.16740608], [88.91635132, 25.16723442], [88.91400909, 25.16703224], [88.91233063, 25.16806412], [88.91233826, 25.16856956], [88.91236877, 25.17043304], [88.91265869, 25.17335129], [88.91234589, 25.17422867], [88.91241455, 25.17517662], [88.91256714, 25.17737007], [88.91261292, 25.17802048], [88.91179657, 25.17827034], [88.91124725, 25.17843819], [88.9112854, 25.1787529], [88.9114151, 25.17987633], [88.91127014, 25.18003273], [88.91010284, 25.1801796], [88.90931702, 25.17995262], [88.90885925, 25.17981911], [88.90648651, 25.17965317], [88.90632629, 25.17887115], [88.90630341, 25.17874527], [88.90617371, 25.17877769], [88.90503693, 25.17907143], [88.90444183, 25.17922592], [88.90351868, 25.17946625], [88.90093994, 25.18006134], [88.90081024, 25.18013763], [88.90062714, 25.18024635], [88.89889526, 25.18127441], [88.89891815, 25.18151855], [88.89899445, 25.1825428], [88.89694214, 25.18282318], [88.89320374, 25.18332863], [88.89268494, 25.18440628], [88.89073944, 25.18461227], [88.89067078, 25.18418121], [88.89084625, 25.18264008], [88.89086151, 25.18251038], [88.89096069, 25.18122101], [88.88989258, 25.18010712], [88.88981628, 25.1784687], [88.88952637, 25.17852402], [88.88844299, 25.17873383], [88.8865509, 25.17909813], [88.88641357, 25.17910957], [88.88509369, 25.17921257], [88.88439178, 25.17926598], [88.88119507, 25.17926407], [88.8783493, 25.17910957], [88.87582397, 25.17897224], [88.87521362, 25.17946243], [88.87522125, 25.1795578], [88.87533569, 25.18131447], [88.87532043, 25.18210602], [88.87532043, 25.18257523], [88.87528229, 25.18524933], [88.87434387, 25.18753624], [88.87319183, 25.18870926], [88.87284088, 25.18906975], [88.87281036, 25.18918228], [88.8735733, 25.19087982], [88.87388611, 25.19157219], [88.87379456, 25.19174194], [88.87320709, 25.19277954], [88.87302399, 25.1931076], [88.87291718, 25.19329643], [88.87302399, 25.1933136], [88.87355804, 25.19340515], [88.87368011, 25.19342613], [88.87486267, 25.19362831], [88.87486267, 25.19374275], [88.87486267, 25.19511032], [88.8748703, 25.19632721], [88.87465668, 25.19631577], [88.87404633, 25.19627762], [88.87394714, 25.1962719], [88.87397766, 25.19526863], [88.87399292, 25.19492531], [88.87178802, 25.19487381], [88.87149811, 25.19486809], [88.87146759, 25.19263268], [88.8714447, 25.19152832], [88.868927, 25.19108963], [88.86873627, 25.19106865], [88.86828613, 25.19051361], [88.86778259, 25.18989563], [88.86764526, 25.18987656], [88.86724091, 25.18982506], [88.86546326, 25.18959999], [88.86407471, 25.19023895], [88.86421204, 25.19082832], [88.86447144, 25.19190407], [88.8645401, 25.19261742], [88.86467743, 25.19393539], [88.86496735, 25.19543648], [88.8651123, 25.19619179], [88.86471558, 25.19827843], [88.86487579, 25.20070267], [88.86388397, 25.20078659], [88.86357117, 25.2008152], [88.86356354, 25.20141792], [88.85942841, 25.20175934], [88.85749817, 25.20148277], [88.85726166, 25.20124054], [88.85651398, 25.20084381], [88.85477448, 25.19992638], [88.85317993, 25.20067215], [88.85303497, 25.20067024], [88.85176849, 25.20064163], [88.85155487, 25.20063591], [88.85150909, 25.20102882], [88.85147095, 25.20139503], [88.85135651, 25.20142555], [88.84967804, 25.20185661], [88.84925079, 25.20423126], [88.84858704, 25.20646095], [88.84864807, 25.20711136], [88.84879303, 25.20849991], [88.84906769, 25.20887566], [88.84783936, 25.21014023], [88.84490967, 25.21120071], [88.84246063, 25.2111702], [88.84218597, 25.21103859], [88.84230804, 25.21072197], [88.84159088, 25.2107563], [88.8400116, 25.21001053], [88.83786011, 25.20903969], [88.83670044, 25.20852852], [88.83669281, 25.20694351], [88.83669281, 25.20627785], [88.8321991, 25.20662689], [88.83172607, 25.20666313], [88.83041382, 25.20545387], [88.82949829, 25.2017498], [88.82905579, 25.20023727], [88.82832336, 25.19774246], [88.82830048, 25.19766426], [88.8272171, 25.19366264], [88.82707977, 25.19316864], [88.82691956, 25.19259071], [88.82667542, 25.19226265], [88.82578278, 25.19104767], [88.82305145, 25.19109535], [88.82278442, 25.19110107], [88.82272339, 25.19031906], [88.82266998, 25.1896019], [88.82139587, 25.19026184], [88.82087708, 25.1898613], [88.82077789, 25.18860054], [88.81946564, 25.18877602], [88.81785583, 25.18899155], [88.81743622, 25.18717766], [88.81719208, 25.18583298], [88.81492615, 25.18507195], [88.81482697, 25.18503761], [88.81479645, 25.18482971], [88.81462097, 25.18367958], [88.8142395, 25.18082047], [88.81371307, 25.17702675], [88.81344604, 25.17508316], [88.81343079, 25.1749649], [88.81333923, 25.17436218], [88.8106842, 25.1742897], [88.80999756, 25.17427063], [88.80924988, 25.17405891], [88.80912781, 25.17349434], [88.80908203, 25.17325783], [88.80723572, 25.17340851], [88.80605316, 25.1728096], [88.80590057, 25.17277527], [88.8058548, 25.17121506], [88.80583954, 25.17054939], [88.80115509, 25.17089272], [88.79954529, 25.17111778], [88.79836273, 25.17128181], [88.79522705, 25.17241096], [88.79302216, 25.1727314], [88.79089355, 25.17386055], [88.78903198, 25.17460442], [88.78591919, 25.17581177], [88.7828064, 25.1764946], [88.77896881, 25.17786598], [88.77548981, 25.17891693], [88.77360535, 25.17946434], [88.77392578, 25.18135071], [88.7740097, 25.18185806], [88.77398682, 25.182127], [88.77388763, 25.18350983], [88.77409363, 25.18546104], [88.77215576, 25.1856575], [88.77216339, 25.1873951], [88.77275848, 25.18949318], [88.77121735, 25.1896801], [88.7706604, 25.18925095], [88.7702713, 25.1875], [88.77017975, 25.18741035], [88.76837158, 25.18733788], [88.76809692, 25.18596458], [88.76803589, 25.18567657], [88.76696014, 25.18325615], [88.76344299, 25.18410301], [88.76055908, 25.18541527], [88.75909424, 25.18579674], [88.75894928, 25.18607521], [88.75734711, 25.18424034], [88.75672913, 25.18297005], [88.75563049, 25.1805706], [88.75430298, 25.17821121], [88.75254059, 25.17791748], [88.75203705, 25.17782974], [88.75170898, 25.17817688], [88.75110626, 25.17778587], [88.75000763, 25.17705727], [88.74871063, 25.17708397], [88.74880981, 25.17764854], [88.74894714, 25.17852211], [88.74918365, 25.17995453], [88.74945831, 25.18176842], [88.74921417, 25.18227768], [88.74893951, 25.18205452], [88.74533844, 25.18288803], [88.74512482, 25.18357277], [88.74465942, 25.18507385], [88.74279785, 25.18663216], [88.74238586, 25.18662834], [88.74016571, 25.18514252], [88.73453522, 25.1846981], [88.73458099, 25.18493652], [88.73512268, 25.18788338], [88.7352066, 25.18831062], [88.73525238, 25.18854713], [88.73538971, 25.18927193], [88.73519897, 25.18982887], [88.73497009, 25.19048309], [88.7334671, 25.19115448], [88.73355865, 25.191576], [88.73417664, 25.19445038], [88.73419952, 25.19454384], [88.7342453, 25.19490242], [88.73277283, 25.19599533], [88.73308563, 25.19711304], [88.73327637, 25.19781494], [88.73332214, 25.19955826], [88.7333374, 25.20001793], [88.73284149, 25.20010376], [88.73071289, 25.20047379], [88.73008728, 25.20017052], [88.72882843, 25.19956398], [88.72528839, 25.19900894], [88.72425079, 25.19964218], [88.72419739, 25.20172501], [88.72395325, 25.20241165], [88.72367859, 25.20258522], [88.72316742, 25.20262146], [88.72067261, 25.20246315], [88.71907043, 25.20219421], [88.71791077, 25.20199776], [88.71781158, 25.20217705], [88.71721649, 25.20328331], [88.71692657, 25.20355225], [88.71536255, 25.20499992], [88.71494293, 25.20708275], [88.71138763, 25.20745468], [88.70787048, 25.2079525], [88.70448303, 25.20828819], [88.70227814, 25.20738983], [88.6989212, 25.20801735], [88.69459534, 25.20776939], [88.68945313, 25.20793915], [88.68824768, 25.20734406], [88.68756866, 25.20755386], [88.68759918, 25.20770836], [88.68773651, 25.20842934], [88.68788147, 25.20920563], [88.68732452, 25.20949364], [88.68441772, 25.20923615], [88.6807785, 25.20905876], [88.67999268, 25.20902061], [88.67913055, 25.20738029], [88.67834473, 25.20670509], [88.67823792, 25.20661545], [88.67801666, 25.20556259], [88.67796326, 25.20532799], [88.67848969, 25.2052021], [88.67925262, 25.2050209], [88.67873383, 25.20457458], [88.67832184, 25.20328331], [88.67667389, 25.20281982], [88.67588043, 25.20215034], [88.67433167, 25.19975281], [88.67266846, 25.19852829], [88.66969299, 25.19829941], [88.66934967, 25.19834137], [88.66818237, 25.19848442], [88.6672821, 25.19859314], [88.66701508, 25.19960403], [88.66688538, 25.20010185], [88.66680908, 25.20039177], [88.6667099, 25.2007885], [88.66668701, 25.20088768], [88.6665802, 25.20088387], [88.66523743, 25.20082092], [88.66547394, 25.20199203], [88.66544342, 25.2020874], [88.66381073, 25.20281982], [88.65927124, 25.20266533], [88.6546936, 25.20370102], [88.65460968, 25.20370674], [88.65388489, 25.20376396], [88.65132141, 25.20396423], [88.64703369, 25.20437622], [88.64685059, 25.20491791], [88.64603424, 25.20502663], [88.64539337, 25.20511055], [88.64459229, 25.20521545], [88.64281464, 25.20642853], [88.641716, 25.20584106], [88.64155579, 25.20575714], [88.63851929, 25.20475578], [88.63847351, 25.20465851], [88.63801575, 25.20355034], [88.63650513, 25.20361328], [88.6353302, 25.2033329], [88.63407135, 25.20275497], [88.63279724, 25.20217896], [88.63178253, 25.20219231], [88.63098907, 25.20176697], [88.63036346, 25.20195198], [88.62979889, 25.20225906], [88.62931061, 25.20215607], [88.62902069, 25.20176697], [88.62814331, 25.20185471], [88.62749481, 25.20242119], [88.62697601, 25.20287514], [88.62662506, 25.20375061], [88.62612152, 25.20428085], [88.62471008, 25.20455551], [88.62288666, 25.20419502], [88.62212372, 25.20430183], [88.62098694, 25.20505524], [88.62020111, 25.20525932], [88.61920166, 25.20512962], [88.61875916, 25.2050724], [88.61865997, 25.20497322], [88.61814117, 25.20444489], [88.61746216, 25.20401764], [88.61696625, 25.20385551], [88.61610413, 25.20357704], [88.61530304, 25.20383644], [88.61448669, 25.20380974], [88.61299133, 25.2042923], [88.61264038, 25.20395088], [88.61222839, 25.20360947], [88.61186218, 25.20281792], [88.6115799, 25.20227432], [88.61147308, 25.20200729], [88.61121368, 25.20135307], [88.61126709, 25.20047379], [88.61096191, 25.19964981], [88.61082458, 25.19943047], [88.61034393, 25.1986866], [88.61006165, 25.19861031], [88.60926056, 25.19838905], [88.60856628, 25.19796371], [88.60835266, 25.19774818], [88.60751343, 25.19688988], [88.60564423, 25.19597435], [88.60515594, 25.19586372], [88.60464478, 25.19536591], [88.60469818, 25.19513321], [88.60399628, 25.19442177], [88.6036911, 25.19446754], [88.60177612, 25.19360161], [88.60024261, 25.1927433], [88.59832764, 25.19165611], [88.59772491, 25.19099998], [88.59675598, 25.19118118], [88.59468079, 25.19205093], [88.59342194, 25.19256401], [88.59288788, 25.19321251], [88.59265137, 25.19350243], [88.59170532, 25.19409561], [88.59144592, 25.19395065], [88.59118652, 25.19009018], [88.59111786, 25.18950272], [88.59107208, 25.18909836], [88.59118652, 25.18771553], [88.59148407, 25.18754196], [88.59190369, 25.18729401], [88.59144592, 25.18690491], [88.59113312, 25.18519402], [88.58972168, 25.18539238], [88.58959198, 25.18527985], [88.58869171, 25.18494415], [88.58824158, 25.18389511], [88.58818054, 25.18374062], [88.58691406, 25.18234253], [88.58635712, 25.18230247], [88.58370972, 25.18211746], [88.58304596, 25.18206978], [88.58268738, 25.18210602], [88.58242798, 25.18194962], [88.5814209, 25.18053818], [88.58100891, 25.1802063], [88.58096313, 25.17996979], [88.57990265, 25.17912483], [88.57980347, 25.1784153], [88.57965851, 25.17748451], [88.5796051, 25.17711258], [88.57957458, 25.17690659], [88.57597351, 25.17724419], [88.57568359, 25.17727089], [88.57556152, 25.17707443], [88.57499695, 25.17617989], [88.57422638, 25.17640114], [88.57354736, 25.17657089], [88.57254791, 25.17681885], [88.57208252, 25.17693329], [88.57161713, 25.17704773], [88.57146454, 25.17738152], [88.5711441, 25.17746162], [88.57078552, 25.17588806], [88.56636047, 25.17600441], [88.56480408, 25.17461586], [88.55989838, 25.17658043], [88.55764008, 25.17774963], [88.55556488, 25.1790657], [88.5556488, 25.18033981], [88.55580902, 25.18050957], [88.55711365, 25.18187904], [88.55800629, 25.18281937], [88.55882263, 25.18367958], [88.55908966, 25.18395996], [88.55970001, 25.18460464], [88.55963898, 25.18555832], [88.55949402, 25.18773842], [88.55968475, 25.18914795], [88.55989075, 25.19073677], [88.55992889, 25.19098473], [88.55983734, 25.19104958], [88.55757141, 25.1927166], [88.55552673, 25.19332123], [88.55371094, 25.19295883], [88.55266571, 25.19343185], [88.55195618, 25.19366455], [88.55094147, 25.19399643], [88.55068207, 25.19408035], [88.54821014, 25.19523239], [88.54802704, 25.19531631], [88.54776001, 25.19497681], [88.54692841, 25.19393921], [88.54658508, 25.19350624], [88.5456543, 25.19371033], [88.54432678, 25.19400215], [88.5442276, 25.19402313], [88.54304504, 25.19402313], [88.54243469, 25.19402313], [88.54216003, 25.19371033], [88.54160309, 25.19302368], [88.54123688, 25.19207573], [88.54108429, 25.19116402], [88.54073334, 25.18910789], [88.5388031, 25.18936157], [88.53862762, 25.18938446], [88.53833008, 25.18917656], [88.5377121, 25.18874741], [88.53754425, 25.18862915], [88.53761292, 25.18722343], [88.53694153, 25.18737984], [88.53610992, 25.18757248], [88.53504944, 25.18781853], [88.53408813, 25.18804169], [88.53392029, 25.18807983], [88.53374481, 25.18834305], [88.53359222, 25.18856049], [88.53351593, 25.18867302], [88.53354645, 25.1887722], [88.53414154, 25.19117928], [88.53384399, 25.19174194], [88.5335083, 25.19235992], [88.53292084, 25.1934433], [88.53292084, 25.1945076], [88.53384399, 25.19500542], [88.53424072, 25.19556999], [88.53450012, 25.19668961], [88.53553772, 25.19763947], [88.5361557, 25.19801331], [88.5343399, 25.19811821], [88.53421021, 25.19812584], [88.53234863, 25.19845772], [88.53065491, 25.19876099], [88.5302887, 25.19884491], [88.52945709, 25.19903564], [88.52568054, 25.19990158], [88.51997375, 25.2006588], [88.51818848, 25.20124245], [88.51543427, 25.20186615], [88.50817108, 25.20314598], [88.50788116, 25.20319748], [88.5051651, 25.20313835], [88.50447845, 25.203125], [88.50059509, 25.20340729], [88.50017548, 25.20363617], [88.49974823, 25.20386505], [88.49990082, 25.20697975], [88.49995422, 25.20803642], [88.49967957, 25.20883751], [88.49915314, 25.21032906], [88.49909973, 25.21049309], [88.49866486, 25.21050644], [88.49723816, 25.2105484], [88.49691772, 25.21055794], [88.49568939, 25.2105484], [88.49466705, 25.21054077], [88.49131012, 25.21076775], [88.48838043, 25.21113586], [88.48616028, 25.21170044], [88.48377228, 25.21195793], [88.48304749, 25.21197701], [88.48294067, 25.21198082], [88.48291016, 25.21149063], [88.48288727, 25.21101952], [88.47995758, 25.21151161], [88.47982788, 25.21172714], [88.47907257, 25.21297836], [88.47893524, 25.2132206], [88.47773743, 25.21331024], [88.47609711, 25.21219063], [88.47502899, 25.2102108], [88.47439575, 25.20885277], [88.47433472, 25.2087307], [88.47422028, 25.20848465], [88.47406006, 25.20762253], [88.47349548, 25.2069664], [88.47344971, 25.20687485], [88.47276306, 25.20545959], [88.47155762, 25.20366096], [88.47149658, 25.20160103], [88.47148132, 25.20116043], [88.47260284, 25.20018005], [88.47292328, 25.19898987], [88.47203827, 25.19828224], [88.47202301, 25.19809723], [88.47198486, 25.19762993], [88.47045898, 25.19760895], [88.4691925, 25.19759178], [88.46893311, 25.19758797], [88.46920013, 25.19730186], [88.46963501, 25.19683838], [88.46852875, 25.19713783], [88.46757507, 25.19739342], [88.46604156, 25.1965313], [88.46337128, 25.19502449], [88.46094513, 25.19570351], [88.45843506, 25.19572449], [88.45574188, 25.19617081], [88.45137787, 25.1968956], [88.44896698, 25.19727707], [88.44709015, 25.19757271], [88.44692993, 25.1975975], [88.44690704, 25.19732857], [88.44684601, 25.19672585], [88.44460297, 25.19695854], [88.444664, 25.19729233], [88.44364166, 25.19739151], [88.44425201, 25.19618988], [88.44554901, 25.19608116], [88.44384003, 25.19489098], [88.44394684, 25.19279289], [88.44436646, 25.18949127], [88.44442749, 25.18677139], [88.4446106, 25.18556976], [88.44641113, 25.18175125], [88.44677734, 25.18066978], [88.44671631, 25.17982101], [88.44476318, 25.17683029], [88.44568634, 25.1753006], [88.45025635, 25.17263031], [88.45149994, 25.17057991], [88.4526825, 25.16789818], [88.45404816, 25.16646194], [88.45656586, 25.16560555], [88.45687866, 25.16565514], [88.4569931, 25.16541672], [88.45842743, 25.16477966], [88.45935822, 25.16267014], [88.46084595, 25.15929985], [88.46109009, 25.15788078], [88.46044922, 25.15545082], [88.46157074, 25.1540699], [88.46299744, 25.15122032], [88.46218109, 25.14719963], [88.46264648, 25.14203072], [88.46238708, 25.14010048], [88.45923615, 25.1350708], [88.45530701, 25.13276291], [88.45144653, 25.13049126], [88.44757843, 25.12881088], [88.4473877, 25.12819672], [88.44594574, 25.12810326], [88.4458313, 25.12803841], [88.44468689, 25.12802315], [88.44199371, 25.12771606], [88.44135284, 25.12764359], [88.44152832, 25.12661552], [88.44178772, 25.12514687], [88.44191742, 25.12438583], [88.44261932, 25.12052917], [88.44295502, 25.1186924], [88.44299316, 25.11848831], [88.44210052, 25.11524582], [88.44205475, 25.11507034], [88.44271088, 25.11475945], [88.44364166, 25.11432457], [88.44541931, 25.11348534], [88.44555664, 25.11317635], [88.44705963, 25.10802078], [88.44708252, 25.10794258], [88.44657898, 25.10652161], [88.44618988, 25.10543633], [88.44597626, 25.1048336], [88.44472504, 25.10312271], [88.44445801, 25.10275459], [88.44437408, 25.10244179], [88.44386292, 25.10050201], [88.44405365, 25.09980774], [88.44509125, 25.09758186], [88.44517517, 25.09739494], [88.44553375, 25.09585953], [88.4461441, 25.09449387], [88.44645691, 25.09378624], [88.44638062, 25.09262848], [88.44702148, 25.09059143], [88.44718933, 25.09006882], [88.44711304, 25.08869171], [88.44710541, 25.08860016], [88.44631958, 25.08785057], [88.44632721, 25.08731079], [88.44655609, 25.08733368], [88.44768524, 25.08739853], [88.44790649, 25.08742905], [88.44795227, 25.08550262], [88.44832611, 25.08378983], [88.44893646, 25.08197021], [88.45030975, 25.08077049], [88.45199585, 25.07978058], [88.45240021, 25.07954407], [88.45285797, 25.079422], [88.45281219, 25.07930565], [88.45240784, 25.07825661], [88.45214844, 25.0775795], [88.45096588, 25.07451248], [88.4478302, 25.0705719], [88.44706726, 25.06962013], [88.4454422, 25.06758118], [88.44536591, 25.06742096], [88.44449615, 25.06531906], [88.44435883, 25.06344986], [88.44365692, 25.06118011], [88.44114685, 25.05836105], [88.4382019, 25.05630112], [88.4370575, 25.05387115], [88.4365387, 25.05018044], [88.43710327, 25.0467701], [88.43914795, 25.04368019], [88.44145203, 25.0424614], [88.44294739, 25.04259491], [88.44406891, 25.04230309], [88.44495392, 25.0420742], [88.44808197, 25.04195023], [88.45133209, 25.04141045], [88.45289612, 25.04090118], [88.45381927, 25.03866005], [88.45381165, 25.03560066], [88.45173645, 25.03373909], [88.4486084, 25.03309059], [88.44724274, 25.0326519], [88.44680786, 25.03131104], [88.44647217, 25.03021812], [88.44626617, 25.02783012], [88.44621277, 25.02709961], [88.44564819, 25.02634048], [88.44457245, 25.0248394], [88.44256592, 25.02275848], [88.44149017, 25.02094078], [88.44142151, 25.02074623], [88.44154358, 25.02028275], [88.44139862, 25.01961136], [88.44104767, 25.01900482], [88.44083405, 25.01900673], [88.4407959, 25.01890182], [88.44056702, 25.01795959], [88.44123077, 25.01802254], [88.4412384, 25.01731682], [88.44030762, 25.0168972], [88.44009399, 25.01679993], [88.43867493, 25.01666832], [88.43793488, 25.01655579], [88.4373703, 25.01647377], [88.43713379, 25.01583862], [88.43770599, 25.01550102], [88.4380722, 25.01553917], [88.43857574, 25.01558876], [88.43902588, 25.01563263], [88.43998718, 25.01556778], [88.4401474, 25.01556396], [88.44061279, 25.01485634], [88.4406662, 25.01477814], [88.44132233, 25.01383209], [88.4417038, 25.01349068], [88.44193268, 25.0132885], [88.44161987, 25.01225662], [88.44043732, 25.01144981], [88.44016266, 25.01154518], [88.43988037, 25.01148033], [88.43978119, 25.01229668], [88.43983459, 25.01251602], [88.44000244, 25.01325798], [88.43981171, 25.01342773], [88.43947601, 25.01335907], [88.43930054, 25.01332283], [88.43889618, 25.01211929], [88.43824768, 25.01017952], [88.43788147, 25.00912094], [88.43656158, 25.00658417], [88.43645477, 25.00650597], [88.43608856, 25.00622177], [88.435112, 25.00589371], [88.43474579, 25.00577164], [88.43384552, 25.00551033], [88.43323517, 25.00590324], [88.4330368, 25.00609779], [88.43017578, 25.0073204], [88.42724609, 25.00762939], [88.42549896, 25.007164], [88.42540741, 25.00670052], [88.4250946, 25.00654411], [88.42427063, 25.00676155], [88.42416382, 25.00678825], [88.42201996, 25.00704002], [88.42167664, 25.00656128], [88.42149353, 25.00631142], [88.42124939, 25.00549698], [88.4212265, 25.00474739], [88.4212265, 25.00448418], [88.4209137, 25.00413132], [88.42036438, 25.00397491], [88.42032623, 25.00374222], [88.42055511, 25.00353432], [88.4203186, 25.0032444], [88.41989899, 25.00272179], [88.41924286, 25.00190544], [88.41954041, 25.00160789], [88.420578, 25.00053406], [88.42046356, 24.99967384], [88.41808319, 24.99871063], [88.41577148, 24.99843025], [88.41527557, 24.99836922], [88.4123764, 24.99904442], [88.41236877, 24.99894524], [88.41230774, 24.99708748], [88.41204834, 24.99629402], [88.41199493, 24.99614334], [88.41343689, 24.99691963], [88.41360474, 24.99700928], [88.41378784, 24.99669838], [88.4144516, 24.99555016], [88.41461182, 24.99526978], [88.41445923, 24.99459267], [88.41307068, 24.99185181], [88.41290283, 24.9909935], [88.41277313, 24.99032974], [88.41259766, 24.9896965], [88.41249847, 24.9893322], [88.41238403, 24.98890877], [88.41197205, 24.98656654], [88.4118576, 24.98590279], [88.41177368, 24.98542213], [88.41207123, 24.9851017], [88.41365051, 24.98526001], [88.41427612, 24.98532104], [88.41641235, 24.98523331], [88.41660309, 24.98522568], [88.41656494, 24.98513603], [88.41632843, 24.98455811], [88.41667938, 24.98407555], [88.41790009, 24.98389816], [88.41860962, 24.98340607], [88.41874695, 24.98331451], [88.41864777, 24.98306656], [88.41854095, 24.98279572], [88.41796112, 24.9824276], [88.41738129, 24.98242188], [88.41701508, 24.98241806], [88.41600037, 24.9829216], [88.41530609, 24.98327827], [88.41415405, 24.98324585], [88.41304779, 24.983078], [88.41246033, 24.98253441], [88.41230011, 24.98237801], [88.41249847, 24.98199654], [88.41377258, 24.98126221], [88.41435242, 24.98092842], [88.41501617, 24.98100471], [88.41531372, 24.98086357], [88.41505432, 24.98052597], [88.41549683, 24.98018837], [88.416008, 24.98045349], [88.41621399, 24.98054886], [88.41629791, 24.98032761], [88.41694641, 24.97715378], [88.41683197, 24.97665024], [88.41667938, 24.97599792], [88.41699982, 24.97553825], [88.41738892, 24.97498131], [88.4173584, 24.97398949], [88.41616821, 24.97270012], [88.41410065, 24.97232056], [88.41210175, 24.97318077], [88.41186523, 24.97343826], [88.41086578, 24.97358131], [88.41069794, 24.97439766], [88.41053009, 24.97486305], [88.41017151, 24.97525024], [88.40849304, 24.97578049], [88.4072876, 24.97517967], [88.40579224, 24.97443962], [88.40472412, 24.97334671], [88.40572357, 24.97302246], [88.40588379, 24.97343636], [88.40628052, 24.9732914], [88.40620422, 24.97282219], [88.40604401, 24.97257805], [88.40567017, 24.97204781], [88.40530396, 24.97216225], [88.40531158, 24.97247696], [88.40463257, 24.97291756], [88.40415955, 24.97215652], [88.40415955, 24.97125435], [88.40398407, 24.97102737], [88.40315247, 24.97099876], [88.4028244, 24.97118759], [88.4030838, 24.97191811], [88.40387726, 24.97239876], [88.40383148, 24.97253609], [88.40203094, 24.97197914], [88.39997101, 24.97159958], [88.39834595, 24.96999168], [88.39797974, 24.96961975], [88.39746094, 24.96912003], [88.39663696, 24.96730995], [88.39612579, 24.96572113], [88.39604187, 24.96558571], [88.39626312, 24.96532249], [88.39620972, 24.96497917], [88.39600372, 24.96483994], [88.39589691, 24.96476555], [88.39559937, 24.96472359], [88.39548492, 24.96472931], [88.39525604, 24.96438026], [88.39515686, 24.96460724], [88.39511108, 24.96470833], [88.39492798, 24.96467781], [88.39464569, 24.96434975], [88.39418793, 24.96410561], [88.39388275, 24.96417046], [88.39360046, 24.96502876], [88.39352417, 24.96527672], [88.39287567, 24.96492386], [88.39292145, 24.96478653], [88.39323425, 24.96388245], [88.39299774, 24.96328163], [88.39290619, 24.96268845], [88.39293671, 24.96177101], [88.39315796, 24.96100807], [88.39343262, 24.96038055], [88.39388275, 24.96004295], [88.39457703, 24.95968628], [88.39512634, 24.95946312], [88.39560699, 24.95943069], [88.39583588, 24.95960426], [88.39594269, 24.95973015], [88.39608765, 24.95989418], [88.39639282, 24.9601841], [88.39687347, 24.96032333], [88.39752197, 24.96025276], [88.39796448, 24.9601059], [88.39855957, 24.95984459], [88.39900208, 24.95954323], [88.39910889, 24.95921898], [88.39903259, 24.9589119], [88.39880371, 24.95871925], [88.39851379, 24.95869637], [88.39835358, 24.95868683], [88.39810944, 24.95867348], [88.39756775, 24.95854187], [88.3973999, 24.95841789], [88.39737701, 24.95832253], [88.39730072, 24.95801544], [88.39735413, 24.95757675], [88.39743805, 24.9573288], [88.39813995, 24.95666695], [88.39865112, 24.95588875], [88.39907837, 24.95522499], [88.39941406, 24.95505714], [88.39951324, 24.95506859], [88.39979553, 24.95509911], [88.4002533, 24.95506477], [88.40044403, 24.95479965], [88.4003067, 24.9544735], [88.40010071, 24.95418358], [88.40010071, 24.95378304], [88.40039825, 24.95363426], [88.40084076, 24.953619], [88.40119934, 24.95331764], [88.40122223, 24.95293617], [88.40112305, 24.95264816], [88.40148926, 24.95221138], [88.40164185, 24.9517746], [88.40179443, 24.95085907], [88.4017868, 24.9503994], [88.40207672, 24.94966125], [88.40149689, 24.94569016], [88.39898682, 24.94299126], [88.3973465, 24.94210052], [88.39541626, 24.94104195], [88.39303589, 24.94111252], [88.39092255, 24.94112968], [88.38765717, 24.93849945], [88.38446808, 24.93777847], [88.38153839, 24.93882942], [88.38058472, 24.93979836], [88.37917328, 24.9412384], [88.37654877, 24.94263268], [88.3744278, 24.94185066], [88.37186432, 24.94242287], [88.37158203, 24.94227409], [88.37116241, 24.94227028], [88.37098694, 24.94239616], [88.37071228, 24.94259644], [88.37049866, 24.94316101], [88.37039185, 24.94335175], [88.37034607, 24.94388199], [88.37029266, 24.94445801], [88.37028503, 24.94479752], [88.37025452, 24.94568062], [88.37001801, 24.94594574], [88.36951447, 24.94594002], [88.36901855, 24.94564819], [88.36852264, 24.94537544], [88.36763, 24.9450531], [88.36753845, 24.94502068], [88.36734009, 24.94501305], [88.36720276, 24.94500923], [88.36671448, 24.94499207], [88.36636353, 24.94518089], [88.36628723, 24.94524193], [88.3658371, 24.94559479], [88.36511993, 24.94617844], [88.36505127, 24.94623566], [88.36483002, 24.94684601], [88.36501312, 24.94734383], [88.36568451, 24.94758034], [88.36598969, 24.9476757], [88.36582184, 24.94806099], [88.36581421, 24.94854736], [88.36472321, 24.94843102], [88.36412048, 24.94853783], [88.36388397, 24.94889832], [88.36393738, 24.94933891], [88.36443329, 24.95001221], [88.36525726, 24.95086288], [88.36572266, 24.95140648], [88.36606598, 24.95180893], [88.36620331, 24.95234489], [88.36618042, 24.95282173], [88.36598969, 24.95308685], [88.3658371, 24.95329666], [88.36539459, 24.95342636], [88.36462402, 24.95318794], [88.36360168, 24.95264053], [88.36287689, 24.95226097], [88.36274719, 24.95219231], [88.36265564, 24.95219421], [88.36201477, 24.95220375], [88.36138153, 24.95231056], [88.36064911, 24.95260811], [88.36006927, 24.95321465], [88.35952759, 24.95347595], [88.3587265, 24.95342827], [88.35826874, 24.95315552], [88.35796356, 24.95265579], [88.35803223, 24.95204544], [88.35842133, 24.95122719], [88.35901642, 24.95054626], [88.35986328, 24.95013428], [88.3600235, 24.95004654], [88.36043549, 24.94981575], [88.36032867, 24.94952774], [88.36013794, 24.94943047], [88.35991669, 24.94931412], [88.35945892, 24.94898415], [88.35806274, 24.94812775], [88.35732269, 24.94745064], [88.35669708, 24.94681358], [88.35614014, 24.9462719], [88.3558197, 24.94544601], [88.35543823, 24.94412422], [88.35507202, 24.94320297], [88.3549118, 24.94279289], [88.3547287, 24.94231987], [88.35428619, 24.94204712], [88.35369873, 24.94213104], [88.35306549, 24.94256783], [88.35243225, 24.94294357], [88.35177612, 24.94368172], [88.35088348, 24.94420624], [88.3507309, 24.94433784], [88.35037994, 24.94464111], [88.3497467, 24.94499779], [88.34911346, 24.94479942], [88.34861755, 24.94444847], [88.34851837, 24.94424248], [88.34837341, 24.94395065], [88.34798431, 24.94331551], [88.34754944, 24.94300461], [88.34709167, 24.94292259], [88.34610748, 24.94283485], [88.34510803, 24.94287109], [88.34490967, 24.94287872], [88.34429932, 24.94279671], [88.34390259, 24.9426384], [88.34320068, 24.94222832], [88.3425293, 24.94183922], [88.34099579, 24.94088554], [88.34020996, 24.94028473], [88.3397522, 24.93966866], [88.33974457, 24.93958855], [88.33963776, 24.93890381], [88.33977509, 24.9381218], [88.34028625, 24.93728638], [88.34078217, 24.93647003], [88.34085846, 24.93635941], [88.34120941, 24.93586349], [88.34125519, 24.93554306], [88.34130096, 24.93521309], [88.34122467, 24.93488884], [88.34098816, 24.93471527], [88.34015656, 24.93453217], [88.33957672, 24.93431473], [88.33942413, 24.93410683], [88.33924103, 24.93385315], [88.33914948, 24.93310738], [88.33913422, 24.93280029], [88.33909607, 24.93228531], [88.33874512, 24.93180275], [88.33831024, 24.93158722], [88.33761597, 24.93157959], [88.33726501, 24.93153763], [88.3369751, 24.93126678], [88.3368988, 24.93050194], [88.33691406, 24.92935562], [88.33700562, 24.92885971], [88.33734894, 24.9281559], [88.33805084, 24.92726517], [88.33811951, 24.92695999], [88.33798218, 24.92642403], [88.33744049, 24.92624664], [88.33668518, 24.92617989], [88.33628845, 24.92638588], [88.33605194, 24.92670822], [88.33576202, 24.92731285], [88.33551788, 24.92756271], [88.33507538, 24.92767143], [88.3345108, 24.92732239], [88.3342514, 24.92668915], [88.33428192, 24.92577171], [88.33452606, 24.92498589], [88.33465576, 24.92459106], [88.33467865, 24.9244175], [88.33476257, 24.92383575], [88.33483887, 24.92367744], [88.33547974, 24.92234993], [88.33592224, 24.92146111], [88.3365097, 24.91936874], [88.33660889, 24.91903114], [88.33653259, 24.91859245], [88.33638763, 24.91844749], [88.33633423, 24.91829681], [88.33615875, 24.91782951], [88.33303833, 24.91785049], [88.33159637, 24.91809082], [88.33059692, 24.91657066], [88.32965851, 24.91617966], [88.32862091, 24.91638947], [88.32759857, 24.91660118], [88.32628632, 24.91587067], [88.32583618, 24.91456985], [88.32630157, 24.91094971], [88.32636261, 24.91070747], [88.32775879, 24.90722084], [88.32937622, 24.90439796], [88.33087158, 24.90499306], [88.33187866, 24.90530777], [88.33194733, 24.90533066], [88.33358765, 24.90501595], [88.33397675, 24.90494156], [88.33425903, 24.90423012], [88.33447266, 24.90367889], [88.33449554, 24.90073967], [88.33276367, 24.89735985], [88.3327179, 24.89727592], [88.33309174, 24.89707375], [88.33453369, 24.89829254], [88.33577728, 24.89854622], [88.3365097, 24.8986969], [88.33725739, 24.89959335], [88.33743286, 24.89979935], [88.34052277, 24.90014458], [88.34158325, 24.8990345], [88.34255981, 24.90000343], [88.34358215, 24.89974785], [88.34383392, 24.89968491], [88.34392548, 24.89958382], [88.34429932, 24.89864349], [88.3445282, 24.89807701], [88.34434509, 24.89793396], [88.34615326, 24.89542389], [88.34644318, 24.89412498], [88.34653473, 24.89374161], [88.34680939, 24.89251328], [88.34477997, 24.89161873], [88.34456635, 24.89152527], [88.34461975, 24.8914566], [88.34535217, 24.89043427], [88.34500122, 24.88985825], [88.34442139, 24.88892365], [88.34437561, 24.88885689], [88.34261322, 24.8884182], [88.34320068, 24.88711929], [88.34297943, 24.88518524], [88.34293365, 24.88510513], [88.34192657, 24.88344955], [88.3418808, 24.88336754], [88.34043121, 24.8817997], [88.34024048, 24.88159561], [88.33921051, 24.88048172], [88.33893585, 24.87903214], [88.3388443, 24.87853432], [88.33881378, 24.87843704], [88.33416748, 24.87757874], [88.3342514, 24.87731934], [88.33520508, 24.87433815], [88.33423615, 24.87356186], [88.33409882, 24.87344933], [88.33254242, 24.87254715], [88.33296204, 24.87152672], [88.33295441, 24.87091255], [88.33300781, 24.87067986], [88.33306885, 24.87055016], [88.33312225, 24.87044525], [88.33145142, 24.86967087], [88.33112335, 24.8694725], [88.33098602, 24.8693924], [88.3262558, 24.86655235], [88.32608795, 24.86645317], [88.3259201, 24.86635017], [88.32579803, 24.86627579], [88.32514954, 24.8658905], [88.32820129, 24.86953163], [88.32781982, 24.86989021], [88.32735443, 24.87032509], [88.32679749, 24.87048149], [88.3263092, 24.87076187], [88.32598877, 24.8711853], [88.32579803, 24.87142563], [88.32471466, 24.87288857], [88.32463074, 24.87297821], [88.32402039, 24.87362862], [88.32267761, 24.87463951], [88.32132721, 24.87563705], [88.32106018, 24.87634087], [88.32118225, 24.87692833], [88.3212204, 24.87712669], [88.32169342, 24.87781906], [88.32193756, 24.87841415], [88.32192993, 24.87898445], [88.3219223, 24.87923622], [88.32171631, 24.88057137], [88.32128143, 24.88217354], [88.32118988, 24.88249588], [88.32107544, 24.88295937], [88.32096863, 24.88341141], [88.32058716, 24.88360023], [88.32051086, 24.88360214], [88.31983185, 24.8836174], [88.3184967, 24.88364601], [88.31822968, 24.88348961], [88.31803894, 24.88337708], [88.31751251, 24.88338089], [88.31734467, 24.8833828], [88.31707764, 24.88301468], [88.3167572, 24.88258553], [88.31671143, 24.88252258], [88.31665802, 24.88092041], [88.31665039, 24.8807621], [88.31639862, 24.88088989], [88.31530762, 24.88076019], [88.31424713, 24.87973022], [88.31292725, 24.87845039], [88.31060791, 24.87643051], [88.3081665, 24.87407112], [88.30573273, 24.87124825], [88.30428314, 24.87041092], [88.3034668, 24.8719368], [88.30319977, 24.87184525], [88.30125427, 24.87346077], [88.30169678, 24.87524414], [88.30044556, 24.8757267], [88.30013275, 24.87703323], [88.29957581, 24.87896538], [88.29808044, 24.88083458], [88.29833221, 24.88224792], [88.29838562, 24.88254547], [88.30037689, 24.8820858], [88.30056, 24.8820858], [88.30081177, 24.8827858], [88.30104828, 24.88341522], [88.30088806, 24.8841877], [88.3008194, 24.88450432], [88.30114746, 24.88479805], [88.30155182, 24.88516808], [88.3017807, 24.88557243], [88.30197906, 24.88593674], [88.30011749, 24.88583183], [88.29985809, 24.88574409], [88.29971313, 24.8856945], [88.29921722, 24.88552666], [88.29816437, 24.88517189], [88.29845428, 24.8860817], [88.29737091, 24.88759613], [88.29682922, 24.88834572], [88.29441071, 24.88839531], [88.29392242, 24.8893795], [88.29143524, 24.88951111], [88.29006195, 24.88926315], [88.28915405, 24.88878059], [88.28857422, 24.88847542], [88.28804779, 24.88814163], [88.28678131, 24.88732719], [88.28645325, 24.88711548], [88.28631592, 24.88645744], [88.2856369, 24.88652611], [88.28497314, 24.88697052], [88.28523254, 24.88793182], [88.2853775, 24.8884697], [88.2845993, 24.8886795], [88.28157806, 24.88780022], [88.27939606, 24.88731003], [88.27918243, 24.8882637], [88.27806854, 24.88815308], [88.27755737, 24.89178658], [88.27572632, 24.89189911], [88.27624512, 24.89327049], [88.27613831, 24.89338493], [88.27602386, 24.89350891], [88.2770462, 24.89571953], [88.27587128, 24.89567947], [88.27423859, 24.89450073], [88.27226257, 24.8913002], [88.2713089, 24.88975906], [88.27104187, 24.88931084], [88.27053833, 24.88766098], [88.27027893, 24.88566971], [88.26946259, 24.88182068], [88.26937866, 24.87972069], [88.2689209, 24.87776947], [88.26876068, 24.87706184], [88.26782227, 24.87587929], [88.26687622, 24.8749218], [88.26538086, 24.87482071], [88.26381683, 24.87545967], [88.26357269, 24.87576294], [88.26187134, 24.87779045], [88.26144409, 24.87777328], [88.2614212, 24.87759018], [88.26018524, 24.87761307], [88.25902557, 24.8781414], [88.25999451, 24.87947845], [88.2627182, 24.88395309], [88.26419067, 24.88794708], [88.26491547, 24.89279366], [88.26456451, 24.89676857], [88.26411438, 24.90115738], [88.26394653, 24.90277863], [88.26406097, 24.904562], [88.26428223, 24.908041], [88.26413727, 24.91456985], [88.26333618, 24.91839409], [88.26311493, 24.91905212], [88.25945282, 24.92534065], [88.25788879, 24.92707825], [88.25683594, 24.927742], [88.25351715, 24.92928123], [88.25280762, 24.92994499], [88.24964142, 24.93291283], [88.24731445, 24.93509293], [88.24298096, 24.93789864], [88.23982239, 24.94088936], [88.23683929, 24.94426155], [88.23587036, 24.94535828], [88.23547363, 24.94592476], [88.23455811, 24.9472599], [88.23290253, 24.95097733], [88.23197937, 24.95305252], [88.23148346, 24.95397377], [88.2299881, 24.95676994], [88.22929382, 24.95806694], [88.22814178, 24.95893669], [88.22759247, 24.95916748], [88.22621918, 24.95979118], [88.22497559, 24.96004677], [88.22483826, 24.96007347], [88.22360992, 24.96008301], [88.21986389, 24.95974541], [88.21983337, 24.95949936], [88.21767426, 24.95931435], [88.21587372, 24.95910645], [88.21585846, 24.95900154], [88.21338654, 24.95866966], [88.21336365, 24.95877457], [88.21108246, 24.95866585], [88.21017456, 24.95868111], [88.20989227, 24.958601], [88.20864868, 24.95851135], [88.20723724, 24.95834541], [88.20554352, 24.95807266], [88.20493317, 24.95790863], [88.20342255, 24.95765686], [88.20183563, 24.95731354], [88.19802856, 24.95580101], [88.19328308, 24.95345116], [88.19160461, 24.95324516], [88.19017792, 24.95238304], [88.18960571, 24.95219612], [88.18806458, 24.95169067], [88.18662262, 24.95181465], [88.1855545, 24.95313835], [88.18283844, 24.95350838], [88.18280029, 24.95339394], [88.18270111, 24.95307922], [88.18112946, 24.95121384], [88.17948151, 24.94988251], [88.17932892, 24.94901085], [88.17720032, 24.94737816], [88.1767807, 24.94755936], [88.1756897, 24.94655991], [88.17544556, 24.94633675], [88.1751709, 24.94646835], [88.1736145, 24.94721031], [88.17463684, 24.94848251], [88.17450714, 24.94853973], [88.1735611, 24.94931221], [88.17208099, 24.94982338], [88.17015076, 24.95049095], [88.16882324, 24.94834709], [88.16867065, 24.9481945], [88.16713715, 24.94666862], [88.16690826, 24.94643974], [88.16603851, 24.94639206], [88.16495514, 24.94633484], [88.16494751, 24.9462471], [88.16480255, 24.94390297], [88.16465759, 24.94237518], [88.16456604, 24.94142914], [88.16437531, 24.9413681], [88.16347504, 24.94108582], [88.16330719, 24.94090271], [88.16281891, 24.94088173], [88.16273499, 24.94087219], [88.16236115, 24.94073868], [88.16204834, 24.94079781], [88.16056061, 24.93984985], [88.15957642, 24.93828964], [88.15964508, 24.93810844], [88.15944672, 24.93810272], [88.1587677, 24.9370842], [88.15753937, 24.93377495], [88.15746307, 24.93358421], [88.15306091, 24.93289948], [88.1528244, 24.93283272], [88.15145874, 24.9327774], [88.15081024, 24.93274689], [88.14958191, 24.93268585], [88.14585114, 24.93496513], [88.14578247, 24.9352951], [88.14559937, 24.93615913], [88.14546204, 24.93682289], [88.14477539, 24.93676758], [88.14422607, 24.93672562], [88.14396667, 24.93670464], [88.1414566, 24.93650818], [88.14015961, 24.93641281], [88.13968658, 24.93612862], [88.13893127, 24.93194008], [88.13926697, 24.92996979], [88.1399231, 24.92624855], [88.14008331, 24.92366982], [88.14028168, 24.92074013], [88.14058685, 24.91733932], [88.14240265, 24.91494942], [88.14376831, 24.91434669], [88.14389801, 24.91428185], [88.14575958, 24.91337967], [88.14611816, 24.9130764], [88.14649963, 24.9128685], [88.14885712, 24.9112606], [88.15093994, 24.90913391], [88.15132904, 24.90866089], [88.15148163, 24.90852928], [88.15169525, 24.90833092], [88.1531601, 24.90695381], [88.15362549, 24.90649605], [88.15357208, 24.90585136], [88.15431976, 24.90485954], [88.15544128, 24.9017601], [88.15561676, 24.90126991], [88.15711975, 24.89844704], [88.15924072, 24.89806938], [88.16079712, 24.89817047], [88.16248322, 24.89780998], [88.16290283, 24.8972683], [88.16294861, 24.89720535], [88.1638031, 24.896101], [88.16481781, 24.89526558], [88.16524506, 24.89551735], [88.16680908, 24.89455414], [88.16682434, 24.89413261], [88.16685486, 24.89334869], [88.1680603, 24.8931942], [88.16888428, 24.89308739], [88.16897583, 24.89307594], [88.16921234, 24.89211845], [88.16913605, 24.8919239], [88.16898346, 24.89151573], [88.16909027, 24.89088631], [88.16864014, 24.89012146], [88.16799164, 24.89008713], [88.16748047, 24.88946152], [88.1684494, 24.88897705], [88.16866302, 24.88832474], [88.16809082, 24.88838959], [88.16623688, 24.88859749], [88.16643524, 24.88995171], [88.16579437, 24.890028], [88.16560364, 24.89005089], [88.1633606, 24.88961029], [88.16291809, 24.88898087], [88.16230774, 24.88952827], [88.16168213, 24.88938332], [88.16065979, 24.88914299], [88.16009521, 24.89027214], [88.1595993, 24.89034081], [88.15942383, 24.89071274], [88.15898895, 24.89043045], [88.15709686, 24.88918114], [88.15496826, 24.88656998], [88.15486145, 24.88514137], [88.15477753, 24.88418961], [88.15535736, 24.88379288], [88.15533447, 24.88368607], [88.15537262, 24.88169479], [88.15638733, 24.8815136], [88.15653229, 24.8814888], [88.1595993, 24.88094521], [88.16013336, 24.88085175], [88.16035461, 24.88066101], [88.16066742, 24.88038635], [88.16159058, 24.87990189], [88.16252136, 24.8794117], [88.16260529, 24.87874413], [88.16366577, 24.87807846], [88.16336823, 24.87651253], [88.16331482, 24.87624168], [88.16281128, 24.87629318], [88.1612854, 24.87532043], [88.16028595, 24.87468147], [88.15927887, 24.87217522], [88.15949249, 24.87190056], [88.16110229, 24.86986351], [88.16210937, 24.86858368], [88.16311646, 24.86730576], [88.16338348, 24.86696815], [88.16458893, 24.86530113], [88.16724396, 24.86356735], [88.17188263, 24.86380005], [88.17356873, 24.86288452], [88.17369843, 24.86281395], [88.17415619, 24.86258507], [88.17430115, 24.86250687], [88.17544556, 24.86193466], [88.1750946, 24.86064529], [88.17498779, 24.86025047], [88.1745224, 24.86026764], [88.17323303, 24.85941124], [88.17192078, 24.85950851], [88.1696701, 24.85967064], [88.16765594, 24.85906029], [88.16551971, 24.85720062], [88.16422272, 24.85606956], [88.16422272, 24.85357094], [88.16440582, 24.85045052], [88.16353607, 24.84910011], [88.16253662, 24.84851074], [88.16225433, 24.84858322], [88.16112518, 24.84886932], [88.16042328, 24.84858131], [88.1599884, 24.849226], [88.15937042, 24.85015297], [88.15929413, 24.85026169], [88.15619659, 24.85017395], [88.15564728, 24.85015869], [88.15515137, 24.85043144], [88.15506744, 24.85047531], [88.15501404, 24.85042191], [88.15455627, 24.84994888], [88.15306091, 24.85010719], [88.15224457, 24.849823], [88.15088654, 24.84934998], [88.15080261, 24.84992218], [88.15071869, 24.85050201], [88.15063477, 24.85111809], [88.15033722, 24.85343361], [88.15007782, 24.85336494], [88.14995575, 24.85333252], [88.15027618, 24.85067368], [88.15035248, 24.85006332], [88.14879608, 24.850214], [88.14762115, 24.85023499], [88.14685822, 24.85024834], [88.14685059, 24.85050011], [88.14681244, 24.85202408], [88.14638519, 24.85183907], [88.14490509, 24.8512001], [88.14547729, 24.84973145], [88.1444931, 24.84978485], [88.14442444, 24.84878731], [88.14438629, 24.84827805], [88.14468384, 24.84840012], [88.14504242, 24.8485508], [88.14487457, 24.84703064], [88.14477539, 24.84608078], [88.14476776, 24.8459301], [88.14472198, 24.84504509], [88.1446991, 24.84467316], [88.14483643, 24.84365273], [88.14550781, 24.84383583], [88.14678955, 24.84418869], [88.14692688, 24.84422684], [88.14707184, 24.84373474], [88.14513397, 24.84307671], [88.14502716, 24.84285927], [88.1435318, 24.8411293], [88.14141083, 24.83984947], [88.14109039, 24.83967018], [88.14099121, 24.83933067], [88.14015198, 24.83666039], [88.14017487, 24.83577156], [88.14102173, 24.835289], [88.14089203, 24.83447647], [88.14020538, 24.83442497], [88.14021301, 24.83427048], [88.13973999, 24.83403969], [88.13907623, 24.83372116], [88.13645935, 24.8327198], [88.13503265, 24.83176041], [88.13500977, 24.83162117], [88.13463593, 24.82847023], [88.13468933, 24.82364082], [88.13453674, 24.8207798], [88.13450623, 24.82018089], [88.13506317, 24.81608963], [88.13543701, 24.81458092], [88.13574219, 24.81335831], [88.13685608, 24.8097229], [88.13742065, 24.80648041], [88.13624573, 24.80543709], [88.1361084, 24.8053112], [88.13552856, 24.80503082], [88.13317108, 24.80390167], [88.13192749, 24.8050766], [88.13134766, 24.8050766], [88.13071442, 24.8050766], [88.1301651, 24.80599213], [88.12979889, 24.80679512], [88.12849426, 24.80961037], [88.12791443, 24.81086922], [88.12768555, 24.81136894], [88.12565613, 24.81668854], [88.1235733, 24.81942177], [88.12355042, 24.82144356], [88.12353516, 24.82316589], [88.12337494, 24.82306671], [88.1217041, 24.82203293], [88.12115479, 24.82169342], [88.12076569, 24.82140923], [88.11798859, 24.81936836], [88.11522675, 24.81716728], [88.11400604, 24.8158474], [88.11342621, 24.81526756], [88.11229706, 24.81415367], [88.11190033, 24.81351089], [88.11064911, 24.81148529], [88.11003113, 24.81047821], [88.10800934, 24.80605125], [88.10657501, 24.80323601], [88.1058197, 24.80155182], [88.1049881, 24.79966927], [88.1051178, 24.79750824], [88.10549164, 24.79526329], [88.10558319, 24.79406738], [88.10549927, 24.79403114], [88.10549164, 24.79380608], [88.1051712, 24.79374695], [88.10493469, 24.79351997], [88.10520935, 24.79195595], [88.10504913, 24.78919411], [88.10501099, 24.78679466], [88.10631561, 24.7869873], [88.10616302, 24.78534508], [88.10605621, 24.78419685], [88.10607147, 24.78080177], [88.1060791, 24.77968407], [88.10005951, 24.7799511], [88.09719086, 24.78018951], [88.09594727, 24.78032112], [88.09244537, 24.78148651], [88.09020996, 24.78247452], [88.08982849, 24.78252029], [88.08695221, 24.77895927], [88.08364105, 24.77342033], [88.08277893, 24.77256966], [88.08094788, 24.77077103], [88.08022308, 24.77058983], [88.0786438, 24.77019119], [88.07783508, 24.76920891], [88.07717896, 24.7695446], [88.0754776, 24.77043724], [88.07457733, 24.77090836], [88.07448578, 24.77095985], [88.07372284, 24.77139091], [88.07215118, 24.77093124], [88.07076263, 24.76959038], [88.07058716, 24.76942062], [88.07032776, 24.76826477], [88.07045746, 24.76819992], [88.0710907, 24.76789284], [88.07064056, 24.76706505], [88.07019043, 24.76622581], [88.07021332, 24.76551056], [88.07021332, 24.76414108], [88.07112122, 24.76265907], [88.07254791, 24.76190376], [88.07388306, 24.76119614], [88.07441711, 24.76091576], [88.07450867, 24.76086617], [88.0743866, 24.76071358], [88.07273865, 24.75870132], [88.07228088, 24.75814629], [88.07151794, 24.75720406], [88.07003021, 24.75537682], [88.06969452, 24.75489426], [88.06826019, 24.75283813], [88.06790161, 24.75260162], [88.06664276, 24.75177765], [88.06571198, 24.75081444], [88.06620789, 24.75033951], [88.06720734, 24.74939156], [88.06755829, 24.74906921], [88.07009125, 24.74673653], [88.07032776, 24.746521], [88.0710907, 24.74553108], [88.07144165, 24.74534988], [88.07312012, 24.74369049], [88.07380676, 24.74118042], [88.07142639, 24.73662186], [88.06931305, 24.73258972], [88.06761932, 24.72822952], [88.06606293, 24.72437859], [88.06474304, 24.72138023], [88.0626297, 24.71787071], [88.05986786, 24.71504974], [88.05506134, 24.71110916], [88.05056763, 24.70728111], [88.04625702, 24.70362091], [88.04232788, 24.70046806], [88.04084015, 24.69944954], [88.03814697, 24.69759941], [88.03410339, 24.6936512], [88.03206635, 24.69129944], [88.03009796, 24.68902016], [88.02585602, 24.68399048], [88.02179718, 24.67999077], [88.01837158, 24.67642975], [88.01474762, 24.67305183], [88.01281738, 24.67113113], [88.01132202, 24.66904068], [88.0112381, 24.66879082], [88.01056671, 24.66666031], [88.01127625, 24.6655407], [88.01223755, 24.66469383], [88.01530457, 24.66225052], [88.01756287, 24.6604538], [88.02075195, 24.65787125], [88.02357483, 24.65545654], [88.02662659, 24.65152359], [88.02851105, 24.64991951], [88.02941132, 24.64918709], [88.03364563, 24.64718246], [88.03687286, 24.64596176], [88.03839874, 24.64531517], [88.03939056, 24.64489746], [88.04115295, 24.64342499], [88.04216003, 24.64130402], [88.04292297, 24.64073944], [88.04615021, 24.63742065], [88.04788971, 24.63297844], [88.05018616, 24.62939072], [88.05293274, 24.62585068], [88.05517578, 24.62232018], [88.05583954, 24.62067413], [88.05593872, 24.62030411], [88.05835724, 24.61737251], [88.06078339, 24.61483955], [88.06195068, 24.61345863], [88.06469727, 24.61021996], [88.06955719, 24.60485077], [88.07279205, 24.60000038], [88.07583618, 24.59515953], [88.07876587, 24.58934975], [88.08100128, 24.58535957], [88.08654022, 24.57753944], [88.08878326, 24.57375717], [88.08938599, 24.57275009], [88.09200287, 24.56496048], [88.09387207, 24.56216049], [88.09655762, 24.55931091], [88.09841156, 24.55668068], [88.10115051, 24.55234909], [88.10375977, 24.54893112], [88.1071167, 24.54544067], [88.10926819, 24.54357529], [88.11048126, 24.54252052], [88.11493683, 24.53885078], [88.1177597, 24.53650093], [88.1220932, 24.53259087], [88.12306213, 24.53170967], [88.12565613, 24.52867126], [88.12895203, 24.52478981], [88.12976074, 24.52397537], [88.13027191, 24.52346039], [88.13156128, 24.52215958], [88.13449097, 24.51913071], [88.13722229, 24.5160408], [88.14144897, 24.51221085], [88.14369202, 24.51048851], [88.14494324, 24.50895119], [88.14614868, 24.50757599], [88.14707184, 24.50693512], [88.14835358, 24.50533104], [88.15084076, 24.50385666], [88.15364838, 24.50379753], [88.15615082, 24.50296211], [88.15821075, 24.5022049], [88.16099548, 24.50062561], [88.16152954, 24.50032043], [88.16285706, 24.49956894], [88.16482544, 24.49873543], [88.16664886, 24.49796486], [88.16943359, 24.49598503], [88.16989899, 24.49565506], [88.17170715, 24.4943676], [88.17342377, 24.49314308], [88.17404175, 24.49238777], [88.17498779, 24.49123001], [88.17543793, 24.49060249], [88.17559052, 24.49047852], [88.17577362, 24.49032021], [88.17774963, 24.48859596], [88.17796326, 24.48840904], [88.17884827, 24.48763084], [88.1802597, 24.48639107], [88.1815033, 24.48513222], [88.18397522, 24.48261833], [88.1849823, 24.48159027], [88.18595123, 24.48016167], [88.18689728, 24.47929001], [88.19007874, 24.4762001], [88.19174957, 24.47318077], [88.19274139, 24.4701004], [88.1937027, 24.46619797], [88.19838715, 24.46258163], [88.19942474, 24.4622345], [88.20014954, 24.46199226], [88.20441437, 24.45946693], [88.20478821, 24.45942307], [88.2059021, 24.45929527], [88.20700073, 24.45894241], [88.21011353, 24.45794106], [88.21044922, 24.45783424], [88.21120453, 24.45765495], [88.21369171, 24.4570694], [88.21459198, 24.45685959], [88.21627045, 24.45664215], [88.21768951, 24.45665932], [88.22014618, 24.45666504], [88.22034454, 24.45664215], [88.22052002, 24.45661545], [88.22306824, 24.45624352], [88.22354889, 24.45617294], [88.22446442, 24.45611], [88.22745514, 24.45559883], [88.2330246, 24.45377541], [88.23404694, 24.45358467], [88.23717499, 24.45300102], [88.24329376, 24.45023727], [88.2455368, 24.44971275], [88.24997711, 24.44823837], [88.25536346, 24.44778824], [88.2588501, 24.44725227], [88.26205444, 24.44634438], [88.26330566, 24.44599342], [88.2634201, 24.44590378], [88.26459503, 24.44498825], [88.2646637, 24.44493294], [88.26756287, 24.44322968], [88.27085114, 24.44144058], [88.27519226, 24.43868065], [88.28009796, 24.43518066], [88.28246307, 24.43117905], [88.28386688, 24.42799759], [88.28585815, 24.42418098], [88.28988647, 24.42039108], [88.29285431, 24.41727638], [88.29572296, 24.4142704], [88.29944611, 24.41106033], [88.3038559, 24.40768051], [88.31186676, 24.4017601], [88.3168869, 24.39712143], [88.32327271, 24.39088058], [88.3277359, 24.38675117], [88.33300781, 24.38319016], [88.33786011, 24.38076019], [88.34282684, 24.37856293], [88.34818268, 24.37647247], [88.35444641, 24.37489128], [88.36091614, 24.37375069], [88.3629837, 24.37344933], [88.36424255, 24.37340546], [88.36659241, 24.3730526], [88.36972046, 24.37320328], [88.37429047, 24.37390709], [88.38006592, 24.37430382], [88.38247681, 24.37354851], [88.38306427, 24.3733654], [88.38486481, 24.37280083], [88.38676453, 24.37220764], [88.38938904, 24.37191391], [88.39144897, 24.37220955], [88.39273071, 24.37239265], [88.39489746, 24.37270355], [88.39897156, 24.37421989], [88.40161133, 24.37455559], [88.41230011, 24.37698364], [88.41239929, 24.37700272], [88.41300201, 24.37754059], [88.41962433, 24.38149071], [88.42134094, 24.38196373], [88.42482758, 24.38326645], [88.42677307, 24.38344574], [88.430336, 24.3837738], [88.43232727, 24.38292694], [88.43325043, 24.38285446], [88.43360901, 24.38282585], [88.43588257, 24.38216591], [88.44171143, 24.3801136], [88.44632721, 24.37866783], [88.45169067, 24.37566185], [88.4538269, 24.37424088], [88.45389557, 24.37419319], [88.45923615, 24.37137032], [88.46321106, 24.36849022], [88.46975708, 24.36433792], [88.47007751, 24.36413574], [88.47125244, 24.36332512], [88.47148895, 24.36318207], [88.47806549, 24.35997391], [88.48112488, 24.3583889], [88.48307037, 24.35769272], [88.48735046, 24.35583115], [88.48920441, 24.35521698], [88.49594116, 24.35448647], [88.49649811, 24.35356712], [88.49829102, 24.35305977], [88.5003891, 24.35161972], [88.50324249, 24.34885979], [88.50718689, 24.34468079], [88.51434326, 24.34346962], [88.52667236, 24.34436798], [88.52710724, 24.34446716], [88.52713776, 24.34432602], [88.52870941, 24.34418106], [88.53050232, 24.34205818], [88.53856659, 24.32716942], [88.54165649, 24.32146072], [88.54503632, 24.31478119], [88.54849243, 24.3078804], [88.55137634, 24.30269241], [88.55500031, 24.29648972], [88.55594635, 24.29640961], [88.55696869, 24.29894257], [88.55775452, 24.30121231], [88.56151581, 24.31215668], [88.5621109, 24.31388092], [88.56220245, 24.31410408], [88.56313324, 24.31637764], [88.56336212, 24.31688881], [88.56364441, 24.31749916], [88.56399536, 24.31803131], [88.56504822, 24.31961823], [88.56526947, 24.31995201], [88.56650543, 24.3228569], [88.56700134, 24.3246212], [88.56758118, 24.32670975], [88.56816101, 24.32666779], [88.57346344, 24.32586861], [88.58158875, 24.32479286], [88.58708954, 24.32420158], [88.58724213, 24.3219471], [88.58770752, 24.31464005], [88.58804321, 24.31197739], [88.59526062, 24.31218719], [88.59548187, 24.31212997], [88.59978485, 24.31103325], [88.60308838, 24.31032562], [88.60340118, 24.31025887], [88.60347748, 24.31026077], [88.60559845, 24.31033516], [88.60605621, 24.31035042], [88.60609436, 24.31065559], [88.60657501, 24.31457138], [88.60666656, 24.31531334], [88.60736847, 24.31526756], [88.60778809, 24.3166275], [88.61859894, 24.31583977], [88.62325287, 24.31555939], [88.62367249, 24.31560326], [88.62376404, 24.31540298], [88.62464905, 24.31349754], [88.62556458, 24.31152153], [88.62850189, 24.30518913], [88.62866974, 24.30529594], [88.62978363, 24.30603027], [88.62993622, 24.30612946], [88.63284302, 24.30804825], [88.63304138, 24.30787468], [88.63385773, 24.3071537], [88.63421631, 24.30683136], [88.63431549, 24.30685234], [88.63818359, 24.30772781], [88.63822937, 24.3079319], [88.63825989, 24.30807495], [88.6416626, 24.30869484], [88.64723969, 24.31093788], [88.64889526, 24.31105995], [88.64891815, 24.31088448], [88.64898682, 24.31046104], [88.64931488, 24.30837822], [88.64977264, 24.30773926], [88.64984131, 24.30570793], [88.65014648, 24.3056469], [88.65254974, 24.30518723], [88.65493011, 24.30869484], [88.6574173, 24.31234741], [88.6588974, 24.31451797], [88.65981293, 24.31434059], [88.66110229, 24.31409264], [88.66130066, 24.31414032], [88.66415405, 24.31484032], [88.66879272, 24.31454086], [88.67012787, 24.31471252], [88.67346954, 24.31516075], [88.67346954, 24.31492233], [88.67501068, 24.31512451], [88.67510223, 24.31537819], [88.67536926, 24.31541634], [88.67597198, 24.31550026], [88.67560577, 24.31520462], [88.68131256, 24.31595039], [88.69426727, 24.3156395], [88.69617462, 24.31546021], [88.69652557, 24.31542778], [88.70023346, 24.31396484], [88.70154572, 24.31344986], [88.70456696, 24.31278229], [88.70558167, 24.31225204], [88.70588684, 24.31209183], [88.70628357, 24.31188202], [88.70833588, 24.30997849], [88.71065521, 24.30783081], [88.71221161, 24.30677414], [88.71243286, 24.30662537], [88.71442413, 24.30462646], [88.71710968, 24.30280876], [88.72001648, 24.30118561], [88.7205658, 24.30088425], [88.72241974, 24.29984856], [88.72283936, 24.29949188], [88.7237854, 24.2986908], [88.72473907, 24.29787827], [88.72549438, 24.29637337], [88.72632599, 24.2947197], [88.72673798, 24.29321861], [88.72922516, 24.28987122], [88.73154449, 24.2850914], [88.73396301, 24.27914619], [88.73540497, 24.27656555], [88.73580933, 24.27310753], [88.73736572, 24.27012253], [88.73813629, 24.265625], [88.73779297, 24.26176262], [88.73782349, 24.26099968], [88.73903656, 24.25958633], [88.74031067, 24.2563324], [88.74089813, 24.25402451], [88.74054718, 24.25133705], [88.74040985, 24.25094795], [88.74036407, 24.25081062], [88.73901367, 24.24698639], [88.73699188, 24.23575592], [88.73612976, 24.22865105], [88.73536682, 24.22570801], [88.73449707, 24.2223568], [88.73477936, 24.22054482], [88.73500061, 24.21908188], [88.73486328, 24.21809196], [88.7347641, 24.21740341], [88.73477936, 24.21596527], [88.73478699, 24.21569824], [88.73480225, 24.21377563], [88.73485565, 24.2135067], [88.73523712, 24.21160698], [88.73420715, 24.20644188], [88.73405457, 24.19978142], [88.73362732, 24.19724274], [88.73336029, 24.19561195], [88.73342133, 24.19392014], [88.73344421, 24.19332314], [88.7328949, 24.18832779], [88.73297882, 24.18637085], [88.73261261, 24.18517303], [88.7324295, 24.18456459], [88.73143768, 24.17763329], [88.73143005, 24.17642021], [88.73141479, 24.17346954], [88.73153687, 24.1717186], [88.73352051, 24.16911697], [88.73654175, 24.16686249], [88.74032593, 24.16339302], [88.74071503, 24.16236305], [88.74139404, 24.1605854], [88.74395752, 24.15060425], [88.74623108, 24.14739799], [88.7463913, 24.14717102], [88.73858643, 24.14159203], [88.73014832, 24.13556099], [88.72164154, 24.12948036], [88.71272278, 24.1231041], [88.70953369, 24.12082291], [88.71019745, 24.11891937], [88.70695496, 24.11925888], [88.7046051, 24.11950493], [88.70379639, 24.11959076], [88.70101166, 24.11894989], [88.69763184, 24.11816978], [88.69603729, 24.11728287], [88.69538116, 24.11672974], [88.69525909, 24.11662865], [88.69468689, 24.11569214], [88.69391632, 24.11442947], [88.69303894, 24.11132431], [88.69345856, 24.11007118], [88.69454193, 24.10972595], [88.69465637, 24.10974884], [88.6966095, 24.11015892], [88.69800568, 24.11045265], [88.69988251, 24.10970879], [88.70078278, 24.10825539], [88.7013092, 24.10408783], [88.70121765, 24.10325813], [88.70026398, 24.09478378], [88.70186615, 24.09433556], [88.70362091, 24.09421349], [88.70381165, 24.09438133], [88.70521545, 24.09561729], [88.70811462, 24.09772682], [88.71258545, 24.10074997], [88.71487427, 24.10229492], [88.71643829, 24.10320854], [88.71717072, 24.10349846], [88.71864319, 24.10361862], [88.72350311, 24.10401344], [88.72363281, 24.10402298], [88.72370911, 24.10396576], [88.72770691, 24.10092354], [88.72846222, 24.09233665], [88.72846222, 24.09049606], [88.72679901, 24.08539772], [88.72595978, 24.08299065], [88.72494507, 24.07995796], [88.72492218, 24.07986069], [88.72451019, 24.07770348], [88.72441101, 24.07718277], [88.72428131, 24.07638931], [88.72381592, 24.07344818], [88.72367859, 24.07329559], [88.72341156, 24.07191849], [88.72344208, 24.07114601], [88.72354889, 24.06873894], [88.72492218, 24.06639481], [88.72541046, 24.06555367], [88.72631836, 24.06523705], [88.72781372, 24.06471062], [88.72846222, 24.06448174], [88.72944641, 24.06472588], [88.73156738, 24.0652504], [88.73358154, 24.06633568], [88.73374176, 24.06616783], [88.73504639, 24.06478882], [88.73716736, 24.06255722], [88.73741913, 24.06203461], [88.73697662, 24.0616188], [88.73680878, 24.06146622], [88.7368927, 24.06126976], [88.73763275, 24.05942917], [88.73738098, 24.05663109], [88.73734283, 24.05633163], [88.73660278, 24.05562973], [88.73143005, 24.05458069], [88.72775269, 24.05380058], [88.72684479, 24.05346489], [88.72683716, 24.05324173], [88.72682953, 24.05305862], [88.72693634, 24.05295372], [88.72971344, 24.05016899], [88.73042297, 24.04997826], [88.73147583, 24.04969788], [88.73157501, 24.04971886], [88.73238373, 24.04989243], [88.73323059, 24.0510006], [88.73379517, 24.05124855], [88.73394012, 24.05114937], [88.73517609, 24.04973412], [88.73599243, 24.04915237], [88.73763275, 24.04798889], [88.73939514, 24.04590416], [88.73953247, 24.04573631], [88.73841095, 24.0402832], [88.73825073, 24.0388813], [88.73817444, 24.03819847], [88.73799896, 24.03823471], [88.73865509, 24.03617859], [88.74143219, 24.03547668], [88.74152374, 24.03545189], [88.74180603, 24.03538132], [88.74216461, 24.03342628], [88.74027252, 24.03045654], [88.73841858, 24.02789879], [88.73808289, 24.02737999], [88.73745728, 24.02325058], [88.73773193, 24.01557159], [88.73777008, 24.01375008], [88.73764038, 24.0135994], [88.73506165, 24.01078987], [88.7332077, 24.00976944], [88.73175812, 24.00896072], [88.73085785, 24.00746155], [88.73049927, 24.00470924], [88.7303772, 24.0036068], [88.72930908, 24.00076485], [88.72890472, 23.99969482], [88.72845459, 23.99887276], [88.72880554, 23.99666023], [88.72934723, 23.99606323], [88.72991943, 23.99542046], [88.7312851, 23.99537468], [88.73168182, 23.99536133], [88.73461914, 23.99526024], [88.73537445, 23.99523354], [88.73736572, 23.99648285], [88.73775482, 23.99715042], [88.73886871, 23.99905777], [88.7394104, 23.99997711], [88.73951721, 24.00010872], [88.74152374, 24.00270271], [88.74253845, 24.00401497], [88.74594879, 24.00579643], [88.74598694, 24.00568199], [88.746315, 24.00456619], [88.74957275, 24.00604439], [88.75274658, 24.00671577], [88.75410461, 24.00670242], [88.75874329, 24.00818253], [88.76241302, 24.00525093], [88.76332855, 24.001894], [88.76304626, 24.00187111], [88.76229095, 24.00182343], [88.76233673, 23.99886131], [88.76235199, 23.99877739], [88.76279449, 23.99587822], [88.76636505, 23.98923302], [88.76898193, 23.98424721], [88.76940918, 23.98254967], [88.7695694, 23.98190689], [88.76934052, 23.98149872], [88.76830292, 23.98117828], [88.76695251, 23.98104858], [88.7652359, 23.98120308], [88.76276398, 23.98225975], [88.75894928, 23.98337364], [88.75613403, 23.98430634], [88.75395203, 23.98480225], [88.75024414, 23.9853344], [88.74640656, 23.98547363], [88.74485779, 23.98552895], [88.74173737, 23.98516846], [88.73963928, 23.98462677], [88.73853302, 23.98377991], [88.73744965, 23.98267174], [88.73655701, 23.98111153], [88.7364502, 23.98043442], [88.73615265, 23.97854614], [88.73562622, 23.97754478], [88.73590088, 23.9757061], [88.73633575, 23.97387123], [88.73705292, 23.9711628], [88.7365036, 23.96785355], [88.73582458, 23.9643116], [88.73567963, 23.96355438], [88.73471832, 23.96309853], [88.73460388, 23.96304512], [88.73447418, 23.96298599], [88.73467255, 23.96295738], [88.73439789, 23.96212006], [88.73378754, 23.96167946], [88.73381805, 23.96009064], [88.73404694, 23.95957375], [88.73477173, 23.95962906], [88.73499298, 23.95858002], [88.73423767, 23.95910072], [88.73379517, 23.95828819], [88.73355103, 23.95783043], [88.73335266, 23.95746803], [88.73590851, 23.95536041], [88.7374115, 23.95350647], [88.73894501, 23.95285225], [88.73902893, 23.95309067], [88.73925781, 23.95378304], [88.73992157, 23.95397949], [88.7401886, 23.95404434], [88.74241638, 23.95114899], [88.74179077, 23.95075798], [88.74170685, 23.95077133], [88.74118805, 23.9510994], [88.74093628, 23.95125771], [88.74065399, 23.95105743], [88.74085999, 23.94901085], [88.74035645, 23.94831085], [88.73974609, 23.94742012], [88.73977661, 23.94470024], [88.74028778, 23.9434433], [88.74066925, 23.94334793], [88.74063873, 23.94281769], [88.74057007, 23.94275284], [88.73974609, 23.94195747], [88.74045563, 23.9400425], [88.74145508, 23.93907547], [88.74151611, 23.93901443], [88.74137115, 23.93895912], [88.74028015, 23.93852615], [88.74006653, 23.93844414], [88.73996735, 23.93840408], [88.74015808, 23.93730354], [88.74068451, 23.93629074], [88.7409668, 23.93574715], [88.74103546, 23.93560791], [88.74180603, 23.93391609], [88.74206543, 23.93334579], [88.74311829, 23.92974854], [88.7423172, 23.92950058], [88.74184418, 23.93053627], [88.74182129, 23.93126488], [88.74144745, 23.93104935], [88.74035645, 23.93042183], [88.74022675, 23.93034363], [88.73947144, 23.93198776], [88.73930359, 23.93234825], [88.73873901, 23.93267632], [88.73587799, 23.93223953], [88.73488617, 23.9317894], [88.73475647, 23.93167877], [88.73471832, 23.93131638], [88.7350769, 23.9310112], [88.73519135, 23.9309082], [88.73529053, 23.93081856], [88.73696136, 23.92928505], [88.7371521, 23.92910576], [88.73704529, 23.92905235], [88.73591614, 23.92848206], [88.73467255, 23.92837906], [88.73420715, 23.92812347], [88.735466, 23.92319107], [88.73549652, 23.92307472], [88.7334137, 23.92289543], [88.73374176, 23.92159081], [88.73363495, 23.92004395], [88.7341156, 23.9183712], [88.73540497, 23.91474724], [88.73504639, 23.91429901], [88.73344421, 23.91399956], [88.73314667, 23.91328812], [88.73338318, 23.91111755], [88.73247528, 23.91087914], [88.73207092, 23.91078568], [88.73104858, 23.91080666], [88.73019409, 23.91082573], [88.72978973, 23.911026], [88.72947693, 23.9112339], [88.7296524, 23.9123745], [88.73029327, 23.91292191], [88.72827148, 23.91332626], [88.72763062, 23.91328812], [88.72651672, 23.91315651], [88.72509766, 23.91299057], [88.72483826, 23.91296005], [88.72497559, 23.91366577], [88.7250061, 23.91380692], [88.72402954, 23.91506386], [88.7233429, 23.9153595], [88.72117615, 23.91543961], [88.72097015, 23.91567039], [88.71419525, 23.91425323], [88.71331024, 23.91308594], [88.71295166, 23.91261292], [88.7095871, 23.91441727], [88.70614624, 23.91413116], [88.70537567, 23.91406631], [88.70336914, 23.91207504], [88.70321655, 23.91192245], [88.70154572, 23.91226768], [88.70102692, 23.91171837], [88.70066071, 23.90967178], [88.70236206, 23.9076004], [88.70296478, 23.90703773], [88.70372009, 23.90730476], [88.70389557, 23.90706062], [88.7041626, 23.90667915], [88.70346832, 23.9065609], [88.70376587, 23.90628052], [88.70449829, 23.90562057], [88.70478821, 23.9043808], [88.70491028, 23.90386963], [88.7053299, 23.90246201], [88.7053833, 23.90227127], [88.70535278, 23.90102196], [88.70534515, 23.90072823], [88.70510864, 23.90043831], [88.70493317, 23.90003014], [88.70435333, 23.89942741], [88.70418549, 23.89925003], [88.70359802, 23.8996563], [88.70326996, 23.89987755], [88.70264435, 23.89974022], [88.70187378, 23.89957047], [88.70120239, 23.90055847], [88.70106506, 23.90071487], [88.70063019, 23.90120888], [88.70000458, 23.90057564], [88.70011139, 23.8999424], [88.70024109, 23.89916801], [88.70027161, 23.89897156], [88.69890594, 23.89940643], [88.69793701, 23.89971733], [88.69533539, 23.9002037], [88.69353485, 23.90036201], [88.69287872, 23.90042114], [88.69252777, 23.90051079], [88.68837738, 23.90157127], [88.68822479, 23.90118408], [88.68814087, 23.9009819], [88.68719482, 23.89856339], [88.68621063, 23.89547348], [88.68541718, 23.8932209], [88.68418884, 23.89027214], [88.68270874, 23.88879967], [88.68077087, 23.88738441], [88.67797852, 23.88630104], [88.67787933, 23.88619995], [88.67627716, 23.88459015], [88.67194366, 23.88394165], [88.66947937, 23.88414001], [88.66761017, 23.88305092], [88.66670227, 23.88251686], [88.66564941, 23.88250923], [88.66423798, 23.88249779], [88.66363525, 23.87949753], [88.66359711, 23.87930679], [88.66352844, 23.87895584], [88.66370392, 23.87831688], [88.66389465, 23.8776226], [88.66407776, 23.87694359], [88.6646347, 23.87561607], [88.66498566, 23.87479401], [88.6668396, 23.87218094], [88.66751099, 23.86969566], [88.6675415, 23.86959457], [88.66744232, 23.86963272], [88.6652298, 23.87046432], [88.66409302, 23.87008286], [88.66369629, 23.87018013], [88.66355896, 23.86992073], [88.66062927, 23.86881447], [88.65838623, 23.86893272], [88.65715027, 23.86935234], [88.65455627, 23.86888885], [88.65435028, 23.86840439], [88.65428925, 23.86825562], [88.65418243, 23.8680172], [88.65395355, 23.86748123], [88.65403748, 23.86736298], [88.65466309, 23.86650085], [88.65414429, 23.86557198], [88.65380096, 23.86575508], [88.65341949, 23.8659668], [88.65296173, 23.86621475], [88.65205383, 23.8665123], [88.65146637, 23.86670303], [88.65087128, 23.86717606], [88.65062714, 23.8673687], [88.6496582, 23.86741447], [88.64963531, 23.86817932], [88.64963531, 23.86831474], [88.64962769, 23.8684864], [88.64916229, 23.86856461], [88.64730835, 23.8688736], [88.64601898, 23.8696537], [88.64576721, 23.8698082], [88.6439743, 23.86919594], [88.64215088, 23.86880493], [88.64241791, 23.8684082], [88.64251709, 23.86831474], [88.64260101, 23.86826897], [88.64266205, 23.86822891], [88.64279938, 23.86812782], [88.64298248, 23.86802673], [88.64307404, 23.86796379], [88.64318848, 23.86789703], [88.64328766, 23.86782265], [88.64334869, 23.86776924], [88.64347839, 23.86764145], [88.64356995, 23.86754608], [88.64366913, 23.86744118], [88.64141083, 23.86664963], [88.63796997, 23.86323166], [88.63379669, 23.86161995], [88.63307953, 23.86136055], [88.62937927, 23.86181068], [88.62741089, 23.86272049], [88.62592316, 23.86363983], [88.6245575, 23.86655235], [88.62407684, 23.86678123], [88.62325287, 23.87021065], [88.62242889, 23.87355995], [88.62119293, 23.87446976], [88.61798096, 23.87557983], [88.6166687, 23.8752594], [88.61221313, 23.87419128], [88.61136627, 23.87350082], [88.61049652, 23.87203026], [88.60993195, 23.87107086], [88.60907745, 23.86963272], [88.60948944, 23.86747551], [88.60987854, 23.86540031], [88.60930634, 23.864048], [88.6088028, 23.86346626], [88.6084671, 23.86308289], [88.60823822, 23.86305618], [88.60736847, 23.86295509], [88.60585022, 23.86343384], [88.60439301, 23.86483765], [88.60375977, 23.8644104], [88.60253143, 23.86418915], [88.60009003, 23.86483955], [88.6000824, 23.86529922], [88.5929718, 23.86994934], [88.59237671, 23.87023544], [88.59207916, 23.87031555], [88.59178925, 23.87039375], [88.59085846, 23.87018394], [88.59020996, 23.8702774], [88.58969879, 23.87034225], [88.58727264, 23.86976051], [88.58479309, 23.86794281], [88.58470917, 23.86774063], [88.58462524, 23.86752129], [88.58473206, 23.86740494], [88.58501434, 23.86707687], [88.58487701, 23.86675072], [88.58474731, 23.86643028], [88.58467102, 23.86625671], [88.58450317, 23.86636353], [88.58425903, 23.86651993], [88.58336639, 23.8640995], [88.58241272, 23.86321831], [88.58243561, 23.86294937], [88.5824585, 23.8626194], [88.58192444, 23.86231613], [88.58139038, 23.86226463], [88.58125305, 23.86225128], [88.57910156, 23.8620472], [88.57627106, 23.86209869], [88.57615662, 23.8621006], [88.57601929, 23.86215782], [88.57534027, 23.86243629], [88.57528687, 23.86172295], [88.57614899, 23.86058044], [88.57646942, 23.86016083], [88.57658386, 23.86001587], [88.57776642, 23.85825539], [88.57795715, 23.85779572], [88.57778168, 23.85761833], [88.57697296, 23.85678101], [88.57641602, 23.85502815], [88.57662964, 23.85476303], [88.57725525, 23.85399628], [88.57754517, 23.85364914], [88.57749176, 23.85352135], [88.58086395, 23.85211372], [88.58164215, 23.8528614], [88.58276367, 23.85455894], [88.5828476, 23.85467148], [88.58405304, 23.85506248], [88.58540344, 23.85515022], [88.58660126, 23.85513878], [88.58809662, 23.85481262], [88.58866119, 23.8545742], [88.58944702, 23.85432816], [88.58935547, 23.85418129], [88.59007263, 23.85391045], [88.59020996, 23.85394669], [88.59120941, 23.85285759], [88.5915451, 23.85159683], [88.59053802, 23.85018349], [88.58929443, 23.84937859], [88.58911133, 23.84914398], [88.58853912, 23.84840393], [88.58816528, 23.84713745], [88.58791351, 23.84659004], [88.58759308, 23.84567261], [88.58718872, 23.84404564], [88.58706665, 23.84296989], [88.58706665, 23.84244347], [88.58706665, 23.84160995], [88.58721161, 23.83944893], [88.58707428, 23.83944511], [88.58739471, 23.83834457], [88.58748627, 23.83835793], [88.58747864, 23.83823967], [88.58757019, 23.83571053], [88.58766937, 23.83444023], [88.59144592, 23.8263607], [88.59294891, 23.82550812], [88.59384155, 23.82489777], [88.59460449, 23.82456589], [88.59668732, 23.82365799], [88.59885406, 23.82238579], [88.5993042, 23.82193565], [88.59951019, 23.82182121], [88.600914, 23.82062149], [88.60127258, 23.81995964], [88.60150909, 23.81951904], [88.60204315, 23.81816292], [88.60203552, 23.81651306], [88.60109711, 23.81460953], [88.60101318, 23.81444931], [88.60035706, 23.81396294], [88.59921265, 23.81311989], [88.59857178, 23.81232452], [88.59833527, 23.81062126], [88.59739685, 23.81045532], [88.59664154, 23.81140518], [88.59611511, 23.81120872], [88.59503174, 23.81080246], [88.59506226, 23.81004143], [88.59490967, 23.80987358], [88.59417725, 23.8090477], [88.59384918, 23.80931854], [88.59385681, 23.809412], [88.59399414, 23.81127548], [88.59380341, 23.81125641], [88.59044647, 23.81095314], [88.59007263, 23.81096077], [88.58933258, 23.81277847], [88.58940887, 23.81341362], [88.58927917, 23.81340027], [88.58772278, 23.8127079], [88.58757782, 23.81060028], [88.59013367, 23.80869102], [88.59130859, 23.80781555], [88.5931015, 23.80807495], [88.59308624, 23.80772972], [88.59303284, 23.8066349], [88.59354401, 23.80632401], [88.59458923, 23.80637741], [88.59549713, 23.80642319], [88.59563446, 23.80624199], [88.59612274, 23.80556107], [88.59571075, 23.80508995], [88.59559631, 23.80495644], [88.59326935, 23.80491638], [88.59285736, 23.80490875], [88.59222412, 23.80430984], [88.59205627, 23.80374718], [88.5920639, 23.80359268], [88.59217072, 23.80300522], [88.59262085, 23.80144119], [88.59272766, 23.80106735], [88.5928421, 23.80068588], [88.5930481, 23.79998016], [88.59285736, 23.79908371], [88.59233856, 23.79854584], [88.59227753, 23.79847717], [88.59215546, 23.79835129], [88.59156036, 23.79763794], [88.59024048, 23.79712486], [88.58824158, 23.7966938], [88.58756256, 23.79674911], [88.58662415, 23.79674339], [88.58511353, 23.79719543], [88.58379364, 23.79758835], [88.58369446, 23.79761887], [88.58312225, 23.79772758], [88.58213043, 23.79779434], [88.58128357, 23.7971611], [88.58100891, 23.79662895], [88.58070374, 23.79598618], [88.58084106, 23.79524612], [88.58139801, 23.79384041], [88.58157349, 23.7935524], [88.58189392, 23.79303169], [88.58211517, 23.79267693], [88.5825119, 23.791605], [88.58220673, 23.79083824], [88.5814209, 23.79018784], [88.58133698, 23.79011345], [88.58101654, 23.78995132], [88.58042908, 23.78965187], [88.57987213, 23.7888813], [88.57894135, 23.78759766], [88.57886505, 23.78757477], [88.57748413, 23.78640938], [88.57585907, 23.78539848], [88.57397461, 23.78431129], [88.57350922, 23.78400612], [88.57276154, 23.78351212], [88.57135773, 23.78328323], [88.57110596, 23.78332329], [88.57008362, 23.78348732], [88.56943512, 23.78369522], [88.56828308, 23.78435326], [88.56708527, 23.78479767], [88.56591797, 23.78495789], [88.56529236, 23.78504372], [88.56333923, 23.78533554], [88.56217194, 23.78580284], [88.5615387, 23.78591537], [88.55969238, 23.78624344], [88.55935669, 23.78630257], [88.55819702, 23.78628349], [88.55717468, 23.78580475], [88.55626678, 23.78508377], [88.55577087, 23.78445244], [88.55599976, 23.78434944], [88.55836487, 23.78368568], [88.55858612, 23.7837925], [88.5592804, 23.78413391], [88.55947113, 23.78422737], [88.55970001, 23.784338], [88.56044006, 23.78421402], [88.56069183, 23.78417015], [88.56039429, 23.78357887], [88.55969238, 23.78228378], [88.55970001, 23.78178024], [88.56019592, 23.7815609], [88.56019592, 23.7811203], [88.56020355, 23.78087044], [88.56207275, 23.78014755], [88.56237793, 23.7800293], [88.56248474, 23.77998924], [88.56257629, 23.77995491], [88.56279755, 23.77986908], [88.56304932, 23.77874947], [88.56322479, 23.7786293], [88.56499481, 23.77744293], [88.566185, 23.77704239], [88.568367, 23.77692604], [88.56903076, 23.77614784], [88.56908417, 23.77608109], [88.56929779, 23.77604103], [88.56956482, 23.77599144], [88.5703125, 23.77591133], [88.57159424, 23.77521515], [88.57180786, 23.77524948], [88.57271576, 23.77540207], [88.57375336, 23.775177], [88.57423401, 23.77526093], [88.57448578, 23.77530479], [88.57507324, 23.77540588], [88.57518005, 23.77542496], [88.57598877, 23.77475357], [88.57875061, 23.77529716], [88.5791626, 23.77512169], [88.57950592, 23.77384377], [88.57962036, 23.77338219], [88.57969666, 23.77309036], [88.57962036, 23.7725811], [88.57940674, 23.77098083], [88.57923889, 23.76974487], [88.57996368, 23.76810455], [88.58042145, 23.7661438], [88.58055115, 23.76519775], [88.58021545, 23.76327705], [88.58037567, 23.76217079], [88.58058929, 23.76067352], [88.58065796, 23.75996208], [88.58071899, 23.75933647], [88.58072662, 23.75925636], [88.580513, 23.7585144], [88.58037567, 23.75803566], [88.57975769, 23.75792694], [88.57865906, 23.75794792], [88.57863617, 23.75673103], [88.57804871, 23.7551403], [88.57582092, 23.75287056], [88.57466125, 23.75029182], [88.57389832, 23.74856186], [88.57377625, 23.74355125], [88.57421112, 23.7401619], [88.5742569, 23.73978615], [88.57239532, 23.73958588], [88.57215118, 23.73955917], [88.57159424, 23.73688698], [88.57199097, 23.73386765], [88.57333374, 23.73368454], [88.57373047, 23.73374176], [88.5742569, 23.73381805], [88.57426453, 23.73451424], [88.57427979, 23.73521042], [88.57430267, 23.73626328], [88.57365417, 23.73822975], [88.57427216, 23.73829079], [88.57444763, 23.73830795], [88.57526398, 23.73838806], [88.57627106, 23.73729134], [88.5764389, 23.73711014], [88.57682037, 23.73499107], [88.57666016, 23.73374367], [88.57659912, 23.73328018], [88.57657623, 23.73308563], [88.57417297, 23.73324966], [88.57398224, 23.73318481], [88.57366943, 23.733078], [88.57398224, 23.73257065], [88.57473755, 23.73134995], [88.57498169, 23.73044968], [88.57421875, 23.72899628], [88.5723114, 23.72903824], [88.5712204, 23.72906113], [88.57106781, 23.72906494], [88.57040405, 23.72885323], [88.57004547, 23.72873688], [88.56962585, 23.72860336], [88.56916046, 23.72766113], [88.56867981, 23.72667503], [88.56845856, 23.7262249], [88.56852722, 23.72566795], [88.56874084, 23.72410393], [88.56898499, 23.72414398], [88.5691452, 23.72418213], [88.5692749, 23.72421646], [88.56937408, 23.7242527], [88.56949615, 23.72425461], [88.56962585, 23.72427368], [88.56978607, 23.72427559], [88.56993103, 23.72427559], [88.57009125, 23.72427177], [88.57025909, 23.72424698], [88.57047272, 23.72423172], [88.57066345, 23.7241993], [88.57080078, 23.72418785], [88.57099915, 23.72413635], [88.56859589, 23.72102356], [88.56850433, 23.71982574], [88.5684433, 23.71896362], [88.56782532, 23.71912003], [88.56724548, 23.71927261], [88.56716919, 23.71878242], [88.56785583, 23.71717262], [88.56781769, 23.71548271], [88.56780243, 23.71485329], [88.5660553, 23.71417809], [88.56513977, 23.71382332], [88.56471252, 23.71317101], [88.56501007, 23.71133423], [88.5660553, 23.70829964], [88.56638336, 23.70510292], [88.56767273, 23.70241356], [88.56707001, 23.6998806], [88.56817627, 23.69836235], [88.56826782, 23.69568825], [88.56952667, 23.69125938], [88.57077789, 23.68832016], [88.5711441, 23.68531227], [88.57288361, 23.68514061], [88.57291412, 23.68502808], [88.57299042, 23.68471718], [88.5734787, 23.6827507], [88.57369995, 23.68185425], [88.5741272, 23.67904663], [88.57450867, 23.6781311], [88.57482147, 23.67724037], [88.5749054, 23.6769886], [88.57481384, 23.67675781], [88.57472992, 23.67653275], [88.57427216, 23.67595482], [88.57431793, 23.67576408], [88.57443237, 23.67535973], [88.5741272, 23.67475891], [88.57307434, 23.67445183], [88.57393646, 23.67000008], [88.5737381, 23.66769028], [88.5738678, 23.66742134], [88.57382202, 23.66675186], [88.57240295, 23.66698074], [88.56894684, 23.6658802], [88.56931305, 23.66459084], [88.57028961, 23.66131783], [88.56879425, 23.66012764], [88.56812286, 23.65969658], [88.56822968, 23.65896988], [88.56829834, 23.6584301], [88.56838226, 23.65796089], [88.56752014, 23.65703964], [88.56344604, 23.64962959], [88.56192017, 23.64624405], [88.56319427, 23.64557838], [88.56263733, 23.64274597], [88.56240845, 23.64014053], [88.56240082, 23.6400547], [88.56215668, 23.63718414], [88.56652832, 23.63647461], [88.56895447, 23.63656807], [88.57102203, 23.63613892], [88.57244873, 23.63699722], [88.57407379, 23.63797379], [88.57608032, 23.63879204], [88.57797241, 23.63860321], [88.57966614, 23.63900375], [88.58106232, 23.63893127], [88.58235168, 23.6391468], [88.58559418, 23.63921928], [88.58821869, 23.63990211], [88.58880615, 23.64046669], [88.58892822, 23.64058876], [88.58978271, 23.6410141], [88.59044647, 23.64134216], [88.59353638, 23.64093781], [88.59371185, 23.64091301], [88.59355164, 23.64039612], [88.59304047, 23.63877678], [88.59313202, 23.63834953], [88.59342194, 23.63705063], [88.59347534, 23.63684082], [88.59333038, 23.63591003], [88.59313202, 23.63461304], [88.59305573, 23.63411713], [88.59305573, 23.63394928], [88.59408569, 23.63164902], [88.59418488, 23.63142967], [88.59314728, 23.62989044], [88.59316254, 23.62914658], [88.59493256, 23.62840843], [88.59375, 23.62796974], [88.59319305, 23.62776566], [88.5932312, 23.62638092], [88.59281921, 23.62495613], [88.59282684, 23.62468338], [88.59273529, 23.6222744], [88.59272766, 23.62190628], [88.59280396, 23.62173271], [88.59371185, 23.6198082], [88.59378052, 23.61698914], [88.59060669, 23.61624718], [88.59034729, 23.6147995], [88.59018707, 23.61470032], [88.58473969, 23.61095047], [88.58283234, 23.60822105], [88.58180237, 23.60663033], [88.58168793, 23.60300064], [88.58261108, 23.60296822], [88.5869751, 23.60270691], [88.5894928, 23.60308838], [88.58986664, 23.60314369], [88.590065, 23.60315323], [88.59150696, 23.60321236], [88.59243774, 23.60325241], [88.59268188, 23.60319138], [88.59316254, 23.60307121], [88.59405518, 23.60284805], [88.5953064, 23.6030407], [88.59720612, 23.60329628], [88.59721375, 23.60345078], [88.59686279, 23.6051693], [88.59680939, 23.60541725], [88.59785461, 23.60640144], [88.59941864, 23.606493], [88.59990692, 23.60677719], [88.60266876, 23.60840416], [88.60608673, 23.6104126], [88.60623169, 23.61050034], [88.60657501, 23.61009598], [88.60145569, 23.60697937], [88.6043396, 23.60581207], [88.60475922, 23.60564232], [88.60718536, 23.60470581], [88.60765839, 23.60486794], [88.60816956, 23.6050415], [88.60835266, 23.60510445], [88.60861206, 23.6040802], [88.60881042, 23.60329247], [88.60884857, 23.60316467], [88.6085434, 23.60243416], [88.60847473, 23.60227394], [88.60835266, 23.60197258], [88.60733795, 23.60300636], [88.60726166, 23.60308266], [88.60613251, 23.60292435], [88.60609436, 23.6028347], [88.60597992, 23.60260773], [88.60541534, 23.60143852], [88.6051712, 23.60094643], [88.60490417, 23.6003952], [88.6051712, 23.60038185], [88.60639191, 23.60033035], [88.6071167, 23.60087013], [88.6102066, 23.60137367], [88.6113739, 23.60245895], [88.61376953, 23.60347557], [88.61667633, 23.60239983], [88.62034607, 23.60295105], [88.62084961, 23.60272789], [88.62102509, 23.60279655], [88.62242889, 23.60499382], [88.62260437, 23.60526466], [88.62509155, 23.60702324], [88.62705231, 23.6067524], [88.62767792, 23.60666656], [88.62963104, 23.60884094], [88.62984467, 23.60908127], [88.6301651, 23.60895729], [88.63027954, 23.60891533], [88.63160706, 23.60839844], [88.63176727, 23.6083374], [88.63275909, 23.60910034], [88.63311005, 23.60936737], [88.63560486, 23.60774422], [88.63575745, 23.60764694], [88.63663483, 23.60708046], [88.63678741, 23.60700607], [88.63705444, 23.60687637], [88.63717651, 23.60731506], [88.63806915, 23.61041069], [88.63819885, 23.61086273], [88.63980865, 23.61130333], [88.63983917, 23.61123657], [88.64050293, 23.60956764], [88.64064789, 23.60922432], [88.64303589, 23.60874939], [88.64516449, 23.60830498], [88.64599609, 23.60813141], [88.64492035, 23.60767937], [88.64494324, 23.60760689], [88.64541626, 23.60738945], [88.64538574, 23.60686111], [88.64537811, 23.60671616], [88.645401, 23.60664177], [88.64539337, 23.60643959], [88.64538574, 23.60627365], [88.64530945, 23.60309982], [88.64494324, 23.60217285], [88.63931274, 23.59716034], [88.63908386, 23.59569359], [88.63922119, 23.59538269], [88.63924408, 23.59437943], [88.63925171, 23.59366035], [88.63923645, 23.59284973], [88.6397171, 23.59242249], [88.64044189, 23.59109497], [88.64160156, 23.59122658], [88.64250946, 23.59138489], [88.64381409, 23.59161377], [88.64408112, 23.59165955], [88.64508057, 23.59123421], [88.64559937, 23.59052467], [88.64567566, 23.58955002], [88.64492798, 23.58955383], [88.64367676, 23.58955956], [88.64532471, 23.58811188], [88.64556885, 23.5879631], [88.64775085, 23.58665085], [88.6501236, 23.58547783], [88.65067291, 23.58464622], [88.65068054, 23.58402443], [88.65054321, 23.58384514], [88.65037537, 23.58361626], [88.64902496, 23.58255577], [88.64837646, 23.58154297], [88.64812469, 23.580513], [88.64849854, 23.57977676], [88.64920807, 23.57873154], [88.64981079, 23.57756615], [88.65026855, 23.57599258], [88.65036774, 23.57535362], [88.65049744, 23.5744648], [88.65093231, 23.57346153], [88.65123749, 23.572752], [88.65198517, 23.57060623], [88.65203857, 23.57021332], [88.65229034, 23.5683403], [88.65372467, 23.56553268], [88.65488434, 23.5632], [88.65476227, 23.56231499], [88.6540451, 23.56132889], [88.65545654, 23.55760956], [88.65596771, 23.55738068], [88.65670013, 23.55694962], [88.65670013, 23.55649948], [88.65744019, 23.55603027], [88.65888977, 23.55350876], [88.65975952, 23.55284882], [88.66015625, 23.55215836], [88.66015625, 23.55183983], [88.66160583, 23.55061913], [88.66162109, 23.55018806], [88.66162109, 23.5497303], [88.66455078, 23.54858971], [88.66945648, 23.54725838], [88.67087555, 23.54758453], [88.67280579, 23.54819489], [88.67390442, 23.54829216], [88.67469025, 23.54780769], [88.67552185, 23.54729652], [88.67708588, 23.54623413], [88.6782074, 23.54559898], [88.67912292, 23.54477119], [88.68017578, 23.54351234], [88.681427, 23.5427227], [88.68165588, 23.54255867], [88.68286133, 23.54169655], [88.68315125, 23.54121971], [88.68363953, 23.54021454], [88.6837616, 23.53995895], [88.68508911, 23.5390625], [88.68566895, 23.53839874], [88.68591309, 23.53759575], [88.6860199, 23.5364151], [88.68603516, 23.53559494], [88.68606567, 23.5339489], [88.68585205, 23.53278542], [88.6854248, 23.53192139], [88.68474579, 23.53130913], [88.68441772, 23.53031158], [88.68437958, 23.52985764], [88.68474579, 23.52947807], [88.68528748, 23.5294342], [88.68585968, 23.5298214], [88.68611908, 23.5300827], [88.68664551, 23.53063965], [88.68765259, 23.53160477], [88.68878937, 23.53182983], [88.69016266, 23.53155136], [88.69037628, 23.53150749], [88.69122314, 23.53085899], [88.69160461, 23.53022575], [88.69149017, 23.52879333], [88.6913147, 23.5263195], [88.69128418, 23.52594757], [88.69161224, 23.52451706], [88.69231415, 23.52411652], [88.69295502, 23.52415466], [88.69322205, 23.52417183], [88.6942749, 23.52511406], [88.69491577, 23.52571678], [88.69556427, 23.52577019], [88.69615936, 23.5254879], [88.6964035, 23.52489281], [88.69622803, 23.52391052], [88.69554901, 23.52192116], [88.69520569, 23.52022171], [88.69522095, 23.51869392], [88.69572449, 23.51750374], [88.69655609, 23.51698494], [88.69822693, 23.51594734], [88.69952393, 23.5155983], [88.70029449, 23.51580238], [88.70267487, 23.51672554], [88.70399475, 23.51709366], [88.70510864, 23.51719856], [88.70596313, 23.51696777], [88.70698547, 23.51616287], [88.70863342, 23.51431274], [88.70915222, 23.51369858], [88.70941925, 23.51337624], [88.71062469, 23.51194], [88.7119751, 23.510149], [88.71216583, 23.50989723], [88.71508026, 23.50855064], [88.71560669, 23.50861168], [88.71607208, 23.5089016], [88.71645355, 23.50940704], [88.71696472, 23.51024818], [88.71783447, 23.51113892], [88.71855927, 23.51179123], [88.71930695, 23.51198769], [88.72106934, 23.51209831], [88.72176361, 23.51236725], [88.72284698, 23.51290131], [88.72351837, 23.51285934], [88.72387695, 23.51268768], [88.72406769, 23.51259995], [88.72527313, 23.51151085], [88.7265625, 23.50987434], [88.72724152, 23.50865936], [88.7282486, 23.50714874], [88.72847748, 23.50680542], [88.72982025, 23.50423622], [88.73053741, 23.50264168], [88.73065186, 23.50123215], [88.73077393, 23.49917793], [88.73036957, 23.49838066], [88.73085022, 23.49678993], [88.73618317, 23.49345016], [88.73864746, 23.4918499], [88.73896027, 23.49164009], [88.73993683, 23.49073029], [88.74041748, 23.48913574], [88.74264526, 23.48674202], [88.7428894, 23.48497772], [88.74291992, 23.48477936], [88.74318695, 23.48447037], [88.74435425, 23.48313713], [88.74402618, 23.48301506], [88.7430191, 23.48263741], [88.74252319, 23.48211479], [88.74285889, 23.48098946], [88.74314117, 23.48127937], [88.74356079, 23.48137283], [88.74372101, 23.48093987], [88.74342346, 23.48056984], [88.74440765, 23.48015594], [88.74465179, 23.48044586], [88.74494171, 23.48078156], [88.74465179, 23.4817276], [88.74484253, 23.48297119], [88.74512482, 23.48337936], [88.74590302, 23.4836731], [88.7466507, 23.48370361], [88.74745941, 23.48325539], [88.74868011, 23.48245239], [88.75002289, 23.48134613], [88.75074768, 23.48074913], [88.75379181, 23.47914886], [88.75571442, 23.47866631], [88.75621033, 23.47903061], [88.75641632, 23.48345757], [88.7567215, 23.48490906], [88.75632477, 23.48540497], [88.75597382, 23.48654938], [88.75604248, 23.48762512], [88.75668335, 23.48868179], [88.7579422, 23.4896946], [88.75912476, 23.49037361], [88.76059723, 23.49081612], [88.76168823, 23.49084854], [88.76239014, 23.49047089], [88.76328278, 23.48925972], [88.76363373, 23.48816299], [88.76369476, 23.48792839], [88.7640686, 23.48648071], [88.7647934, 23.48496056], [88.76622009, 23.48253822], [88.76706696, 23.48170471], [88.76836395, 23.48091125], [88.76902771, 23.4807148], [88.77085876, 23.4801712], [88.77201843, 23.48130989], [88.77213287, 23.48427963], [88.77177429, 23.48517418], [88.77114868, 23.48674011], [88.76967621, 23.4869442], [88.76845551, 23.48727036], [88.76806641, 23.48760033], [88.76777649, 23.48812485], [88.76763916, 23.48896027], [88.76799011, 23.48999023], [88.76857758, 23.49101448], [88.76888275, 23.49155045], [88.76967621, 23.49301529], [88.76968384, 23.49319267], [88.76981354, 23.49495125], [88.76990509, 23.49569321], [88.77049255, 23.49713135], [88.77113342, 23.49790001], [88.77185059, 23.49840736], [88.77291107, 23.49882317], [88.7742691, 23.49917793], [88.77600861, 23.49974823], [88.7773819, 23.50019646], [88.77973175, 23.50102615], [88.7819519, 23.50185585], [88.78329468, 23.50253677], [88.78347778, 23.50268173], [88.78450012, 23.50350189], [88.78566742, 23.50489998], [88.78601074, 23.50561523], [88.78614807, 23.50589752], [88.786026, 23.5069313], [88.78655243, 23.50739098], [88.78675079, 23.50731087], [88.78686523, 23.50666046], [88.78677368, 23.50582504], [88.78668976, 23.50562859], [88.78647614, 23.50515938], [88.78642273, 23.50503922], [88.78636932, 23.50492859], [88.7862854, 23.50473213], [88.78598022, 23.50391197], [88.78475952, 23.50260735], [88.78408813, 23.50171661], [88.78357697, 23.50079155], [88.78336334, 23.50039291], [88.7833252, 23.50033188], [88.78333282, 23.50022888], [88.78337097, 23.49931717], [88.78340912, 23.49845123], [88.7844696, 23.4973011], [88.78594208, 23.4971714], [88.78704834, 23.49756432], [88.78765869, 23.49807549], [88.78800964, 23.49836922], [88.78842163, 23.49946594], [88.78869629, 23.50002098], [88.78874969, 23.50013161], [88.78968048, 23.5020256], [88.79055023, 23.50205231], [88.79185486, 23.50286102], [88.79361725, 23.50269699], [88.79426575, 23.5024662], [88.79470062, 23.50231361], [88.79528046, 23.50122452], [88.79801178, 23.49953079], [88.79868317, 23.4991188], [88.79969788, 23.49825096], [88.80042267, 23.4976368], [88.80040741, 23.49715805], [88.79974365, 23.4966526], [88.79898071, 23.49623108], [88.7979126, 23.49563599], [88.79794312, 23.49541473], [88.79827881, 23.49285316], [88.79920959, 23.49209785], [88.79934692, 23.49156189], [88.79927063, 23.49121475], [88.79872894, 23.48879242], [88.79547119, 23.48545456], [88.79743958, 23.48540115], [88.79821014, 23.48627472], [88.79949188, 23.48648643], [88.79984283, 23.48654556], [88.79997253, 23.4865284], [88.80138397, 23.48635674], [88.80088043, 23.48563576], [88.79964447, 23.48557281], [88.79947662, 23.48527336], [88.79962158, 23.48282051], [88.79797363, 23.48255348], [88.79655457, 23.4823246], [88.79608917, 23.48210144], [88.79518127, 23.48166847], [88.79454041, 23.4813652], [88.79443359, 23.4813118], [88.79406738, 23.48114014], [88.79379272, 23.47987556], [88.79376221, 23.47971535], [88.7927475, 23.47749519], [88.79247284, 23.47688293], [88.79152679, 23.47541618], [88.78984833, 23.472826], [88.78974915, 23.47266769], [88.78971863, 23.47175789], [88.78768158, 23.46996117], [88.78725433, 23.4695797], [88.78729248, 23.46920395], [88.78807068, 23.4688549], [88.78823853, 23.46856308], [88.78820038, 23.46846581], [88.78756714, 23.46743011], [88.78791809, 23.46712685], [88.7882309, 23.46685219], [88.78900146, 23.46681976], [88.78954315, 23.46679688], [88.78948975, 23.46662521], [88.78938293, 23.46629143], [88.78870392, 23.46604538], [88.78839874, 23.46593475], [88.7882843, 23.46558189], [88.78855133, 23.46545219], [88.7889328, 23.46526718], [88.78986359, 23.46585846], [88.78994751, 23.46574402], [88.7901001, 23.4655571], [88.78948975, 23.46495247], [88.78939819, 23.46478462], [88.78918457, 23.46440887], [88.78996277, 23.46422768], [88.79100037, 23.46474266], [88.79178619, 23.46323013], [88.79185486, 23.46308517], [88.79086304, 23.46298981], [88.7907486, 23.46298027], [88.79045868, 23.46030617], [88.7928009, 23.46115494], [88.79301453, 23.46103477], [88.79315186, 23.46095657], [88.79297638, 23.46044922], [88.79224396, 23.46027374], [88.78940582, 23.45959854], [88.78951263, 23.45924187], [88.79013062, 23.45881844], [88.79034424, 23.45802498], [88.79011536, 23.45679092], [88.79141998, 23.45598984], [88.79149628, 23.45594025], [88.79238129, 23.45580101], [88.79279327, 23.45548058], [88.79268646, 23.45509148], [88.79084015, 23.45374298], [88.79039764, 23.45342064], [88.79046631, 23.45287323], [88.79151154, 23.45230865], [88.79150391, 23.45116234], [88.79057312, 23.45098305], [88.79036713, 23.45058441], [88.7907486, 23.4485817], [88.79149628, 23.44799995], [88.79177856, 23.44778061], [88.79210663, 23.44787598], [88.79290009, 23.44810104], [88.79309082, 23.44803619], [88.79367828, 23.44783401], [88.79442596, 23.44757462], [88.79457092, 23.44699287], [88.79491425, 23.44560051], [88.79530334, 23.4440155], [88.79541016, 23.44360352], [88.79328156, 23.44426346], [88.79299164, 23.4423542], [88.79290771, 23.4423542], [88.7928009, 23.44241142], [88.79224396, 23.44271088], [88.79251862, 23.44394684], [88.79222107, 23.44413185], [88.79139709, 23.44461441], [88.79101563, 23.44455528], [88.79066467, 23.44371414], [88.79058838, 23.44309235], [88.79039001, 23.44157982], [88.79037476, 23.44150925], [88.78988647, 23.44139481], [88.7889328, 23.44162178], [88.7874527, 23.44177437], [88.78681183, 23.44233322], [88.78705597, 23.44260597], [88.7881012, 23.44287109], [88.78896332, 23.44281006], [88.78934479, 23.44278336], [88.78933716, 23.44298363], [88.78929901, 23.44435883], [88.78892517, 23.44457245], [88.78868103, 23.44470978], [88.78755188, 23.44475174], [88.78728485, 23.44447327], [88.78675079, 23.44463158], [88.78656769, 23.44468689], [88.78639984, 23.44473648], [88.78504944, 23.44491577], [88.78314972, 23.44195747], [88.78322601, 23.44037628], [88.78430939, 23.43990707], [88.78434753, 23.43982315], [88.78474426, 23.43900681], [88.78458405, 23.43883324], [88.78427124, 23.43849373], [88.78361511, 23.43869209], [88.78317261, 23.43942642], [88.78292847, 23.43983459], [88.78256226, 23.44020462], [88.78227997, 23.440485], [88.78148651, 23.43974876], [88.78144836, 23.43961525], [88.78138733, 23.43938065], [88.7811203, 23.43837357], [88.78192902, 23.43820381], [88.78265381, 23.43805122], [88.78297424, 23.43769264], [88.78276825, 23.43730545], [88.78168488, 23.43740273], [88.7815094, 23.43743515], [88.78089905, 23.43630028], [88.78018951, 23.43585014], [88.77797699, 23.43586922], [88.77513123, 23.43778992], [88.77350616, 23.43922997], [88.77350616, 23.43966866], [88.77304077, 23.43965912], [88.77304077, 23.44013023], [88.7700882, 23.44325829], [88.76985931, 23.44351959], [88.76883698, 23.44374084], [88.76529694, 23.44281006], [88.76442719, 23.44211006], [88.76299286, 23.43781281], [88.76265717, 23.43598366], [88.76194, 23.43425751], [88.76107788, 23.43347359], [88.76160431, 23.43285561], [88.76187897, 23.4325428], [88.76199341, 23.43240547], [88.76231384, 23.43203163], [88.76222992, 23.43157196], [88.76216125, 23.43119812], [88.7617569, 23.43110657], [88.76036072, 23.4235611], [88.75740814, 23.41900826], [88.75834656, 23.41326714], [88.75844574, 23.41324043], [88.75846863, 23.41292381], [88.75924683, 23.41069603], [88.75997162, 23.4100132], [88.76042938, 23.40973091], [88.76041412, 23.4095974], [88.76114655, 23.40891457], [88.7605896, 23.40758705], [88.76017761, 23.40721893], [88.75881195, 23.40599442], [88.75704193, 23.40464783], [88.75330353, 23.40352249], [88.75112152, 23.40286636], [88.75074005, 23.40174866], [88.75029755, 23.40048027], [88.75016785, 23.40011978], [88.74876404, 23.39814949], [88.74993134, 23.39686203], [88.75268555, 23.39582062], [88.75401306, 23.39531708], [88.75432587, 23.39519691], [88.75424957, 23.39503479], [88.75278473, 23.39221191], [88.75289917, 23.38956642], [88.75297546, 23.38927841], [88.7539978, 23.38886452], [88.75636292, 23.3885498], [88.75669861, 23.38819885], [88.75676727, 23.38812828], [88.75702667, 23.38785934], [88.75687408, 23.38633347], [88.7582016, 23.38592148], [88.75956726, 23.3847065], [88.75967407, 23.38503647], [88.76023865, 23.3868618], [88.76139069, 23.38671112], [88.76194, 23.38695526], [88.76284027, 23.38735199], [88.76187897, 23.38676834], [88.76127625, 23.38640404], [88.76113892, 23.38520241], [88.7618103, 23.38484383], [88.7624054, 23.38452721], [88.76182556, 23.38453865], [88.76130676, 23.38455009], [88.76084137, 23.38094139], [88.76081085, 23.38074303], [88.75943756, 23.38070488], [88.75914001, 23.38069725], [88.75871277, 23.37943459], [88.75869751, 23.37859917], [88.7589798, 23.37687874], [88.75924683, 23.37669563], [88.76030731, 23.37595558], [88.76007843, 23.37584114], [88.75946808, 23.37554169], [88.75911713, 23.37536812], [88.75932312, 23.37496185], [88.75953674, 23.37455368], [88.75971222, 23.37432861], [88.75987244, 23.37354851], [88.76074982, 23.37346458], [88.76197052, 23.37311554], [88.76290894, 23.37238121], [88.763237, 23.37207222], [88.76408386, 23.37126923], [88.76481628, 23.37042809], [88.76525879, 23.36991501], [88.76565552, 23.36915398], [88.76571655, 23.36831856], [88.76548767, 23.36767197], [88.76464844, 23.36642265], [88.7644577, 23.36618233], [88.7636795, 23.36517143], [88.76361847, 23.36509895], [88.76287842, 23.36406517], [88.76245117, 23.36353683], [88.76230621, 23.36174965], [88.7593689, 23.35900116], [88.75791168, 23.35832024], [88.75569916, 23.35852051], [88.75486755, 23.35881805], [88.75354767, 23.35924911], [88.75299835, 23.35943031], [88.75019836, 23.35806084], [88.74970245, 23.35806084], [88.74957275, 23.35762978], [88.74920654, 23.3564415], [88.74740601, 23.35057068], [88.74691772, 23.35011101], [88.74674988, 23.35008049], [88.74666595, 23.34961128], [88.74604034, 23.34897232], [88.74503326, 23.34872627], [88.7440033, 23.34867096], [88.74277496, 23.34897423], [88.74268341, 23.34900665], [88.74256134, 23.34904671], [88.7408905, 23.34962463], [88.73982239, 23.35019493], [88.73943329, 23.35040092], [88.73719025, 23.35174561], [88.73547363, 23.352808], [88.73438263, 23.35332489], [88.73373413, 23.35343742], [88.73316193, 23.35333824], [88.73272705, 23.3531189], [88.73218536, 23.35263634], [88.73214722, 23.35250473], [88.73194122, 23.35177422], [88.73207855, 23.35089111], [88.73240662, 23.34900665], [88.73285675, 23.34760094], [88.73327637, 23.34705353], [88.73387909, 23.34665298], [88.73397827, 23.34663391], [88.73449707, 23.34653854], [88.73535156, 23.34666443], [88.73592377, 23.34664536], [88.73698425, 23.34622383], [88.73738098, 23.34595108], [88.73786926, 23.34560966], [88.73860168, 23.34475517], [88.73894501, 23.34392166], [88.73908234, 23.34327698], [88.73898315, 23.34267998], [88.73855591, 23.34193611], [88.73773193, 23.341259], [88.73688507, 23.34055901], [88.73622131, 23.33983803], [88.73614502, 23.33971214], [88.73764038, 23.33854294], [88.73777008, 23.3380909], [88.73789215, 23.33761978], [88.73803711, 23.33151054], [88.73699188, 23.32925987], [88.73658752, 23.32835007], [88.73664856, 23.32753563], [88.73715973, 23.32761002], [88.74049377, 23.32818604], [88.74185181, 23.3282299], [88.74251556, 23.32825089], [88.74372864, 23.32809258], [88.74437714, 23.32771683], [88.74492645, 23.32707596], [88.74517059, 23.32650375], [88.74536133, 23.32521439], [88.74555969, 23.32460403], [88.74559784, 23.32447624], [88.74599457, 23.32390594], [88.74651337, 23.32343292], [88.74703979, 23.32315254], [88.74752808, 23.32289124], [88.74906158, 23.32216263], [88.7496109, 23.32176018], [88.74982452, 23.32135582], [88.74987793, 23.32090187], [88.74967194, 23.32056618], [88.74936676, 23.32020569], [88.74862671, 23.31943512], [88.74783325, 23.31830406], [88.74716949, 23.31715202], [88.74704742, 23.31690025], [88.74607849, 23.31494522], [88.74580383, 23.313797], [88.74580383, 23.31350327], [88.74597168, 23.31352425], [88.7461319, 23.31355667], [88.74623108, 23.31354904], [88.746315, 23.31349564], [88.74638367, 23.31344223], [88.74658203, 23.31326675], [88.74658966, 23.31318283], [88.74655914, 23.31309509], [88.74655914, 23.31297493], [88.74671936, 23.31277466], [88.74687195, 23.31274605], [88.74607849, 23.3098011], [88.74589539, 23.30956268], [88.7459259, 23.30892181], [88.74559784, 23.30784416], [88.74501038, 23.30712318], [88.74352264, 23.30605888], [88.74176788, 23.30520821], [88.74074554, 23.30496788], [88.74040222, 23.30488777], [88.73905945, 23.30485344], [88.73752594, 23.30507851], [88.73589325, 23.30563927], [88.73430634, 23.30645943], [88.73407745, 23.3065815], [88.7321701, 23.30787277], [88.73201752, 23.30797386], [88.73008728, 23.30963135], [88.72945404, 23.31053352], [88.72895813, 23.31165314], [88.72893524, 23.31172752], [88.7286911, 23.31258392], [88.72868347, 23.31332397], [88.72885895, 23.31382751], [88.72926331, 23.31457138], [88.72998047, 23.31546021], [88.73079681, 23.31642342], [88.73094177, 23.31672668], [88.73146057, 23.31779099], [88.73173523, 23.318964], [88.73157501, 23.31948853], [88.73117828, 23.3198204], [88.73087311, 23.31984138], [88.7305603, 23.31986237], [88.72957611, 23.319664], [88.72727966, 23.3191185], [88.72640991, 23.31885338], [88.7256012, 23.31860352], [88.72532654, 23.31837654], [88.72501373, 23.31812096], [88.72493744, 23.31766701], [88.72512054, 23.31726074], [88.72583008, 23.31681252], [88.72631073, 23.3162365], [88.72642517, 23.31610107], [88.72685242, 23.31531525], [88.72708893, 23.31436157], [88.72712708, 23.31359863], [88.7271347, 23.31252289], [88.72684479, 23.3103466], [88.72683716, 23.31010056], [88.72772217, 23.3092804], [88.72749329, 23.30632973], [88.72705078, 23.30538368], [88.727211, 23.30451775], [88.72756195, 23.30284882], [88.72742462, 23.30131721], [88.72727966, 23.30043221], [88.72694397, 23.29983139], [88.72589111, 23.29886818], [88.72494507, 23.29833412], [88.72328949, 23.29784393], [88.72112274, 23.29753876], [88.72028351, 23.29759216], [88.72013855, 23.2976017], [88.71920013, 23.29790497], [88.71888733, 23.29830933], [88.71881104, 23.29871368], [88.71898651, 23.29926491], [88.71906281, 23.29942894], [88.71671295, 23.2999897], [88.71644592, 23.30067062], [88.71523285, 23.3004303], [88.7144928, 23.30067062], [88.71324921, 23.3022728], [88.71209717, 23.30376053], [88.71113586, 23.30570412], [88.71069336, 23.30543518], [88.71038818, 23.30508041], [88.70995331, 23.30459213], [88.70910645, 23.30389214], [88.70802307, 23.30361938], [88.70787048, 23.30364037], [88.70714569, 23.30373192], [88.70644379, 23.30413246], [88.70625305, 23.30465698], [88.70616913, 23.30515862], [88.70639801, 23.30606842], [88.70655823, 23.30661011], [88.70682526, 23.30750465], [88.70713043, 23.30803108], [88.7075119, 23.30868149], [88.70825195, 23.30938148], [88.70933533, 23.30979538], [88.71073151, 23.31002235], [88.71165466, 23.31025505], [88.71191406, 23.3103199], [88.71279144, 23.31089973], [88.71299744, 23.3113327], [88.71291351, 23.31180954], [88.71260071, 23.31228447], [88.71194458, 23.31270981], [88.71072388, 23.31300926], [88.70940399, 23.31304741], [88.70875549, 23.31285858], [88.70855713, 23.31280136], [88.70796967, 23.31219864], [88.70677185, 23.31032562], [88.70541382, 23.3090229], [88.70361328, 23.30778885], [88.70222473, 23.30670357], [88.70160675, 23.3063736], [88.70011139, 23.30558586], [88.69823456, 23.30430412], [88.69685364, 23.30316925], [88.69624329, 23.30223274], [88.69625092, 23.30134773], [88.69652557, 23.29965401], [88.6968689, 23.29877281], [88.69716644, 23.29712105], [88.69719696, 23.29695892], [88.69719696, 23.29685974], [88.69716644, 23.29512405], [88.69713593, 23.29495811], [88.6969986, 23.29368401], [88.69713593, 23.29256248], [88.69763184, 23.29177666], [88.69812775, 23.29147148], [88.69875336, 23.29133224], [88.69983673, 23.29150963], [88.70159149, 23.29188156], [88.70373535, 23.29209137], [88.70534515, 23.29193687], [88.70640564, 23.2916584], [88.70760345, 23.29095268], [88.70916748, 23.28974533], [88.70948792, 23.28948593], [88.71047211, 23.28868103], [88.71115112, 23.28744507], [88.71179199, 23.2855854], [88.71192932, 23.28491783], [88.71195221, 23.28281593], [88.71154022, 23.2815609], [88.71277618, 23.27865982], [88.7140274, 23.27686119], [88.71486664, 23.27527046], [88.71537781, 23.27527046], [88.71537781, 23.27485847], [88.71704865, 23.27411079], [88.71971893, 23.27372742], [88.72173309, 23.27374268], [88.7231369, 23.27349091], [88.72331238, 23.27336502], [88.72381592, 23.272995], [88.72444153, 23.27190208], [88.72429657, 23.27106285], [88.72389221, 23.27000809], [88.72373199, 23.2696228], [88.72303009, 23.26789856], [88.72161102, 23.26506805], [88.721138, 23.26365471], [88.72081757, 23.26203156], [88.72064209, 23.26116562], [88.72033691, 23.2599411], [88.72009277, 23.25897789], [88.72003937, 23.25876999], [88.71943665, 23.25757027], [88.71885681, 23.25639534], [88.71880341, 23.25628853], [88.71949005, 23.25468826], [88.71987915, 23.25458717], [88.72246552, 23.25429726], [88.72467041, 23.25371742], [88.72677612, 23.25266075], [88.72875214, 23.25109863], [88.7294693, 23.2505455], [88.72998047, 23.25015259], [88.73291779, 23.24840736], [88.7352829, 23.24747086], [88.73636627, 23.24716949], [88.73773956, 23.24696541], [88.73864746, 23.24702072], [88.73923492, 23.24682617], [88.73994446, 23.24659348], [88.74233246, 23.24580765], [88.74294281, 23.24560928], [88.74513245, 23.24489784], [88.74739075, 23.24400711], [88.74861145, 23.24322891], [88.75035858, 23.24173737], [88.75097656, 23.24165535], [88.75227356, 23.2414856], [88.75347137, 23.24058342], [88.75390625, 23.24026108], [88.75904846, 23.24192238], [88.75998688, 23.2436161], [88.75977325, 23.24494171], [88.75962067, 23.24586487], [88.76050568, 23.24635124], [88.76241302, 23.24598503], [88.76291656, 23.24588966], [88.76434326, 23.24603653], [88.7651825, 23.24612427], [88.76594543, 23.24602318], [88.76739502, 23.24583244], [88.76799774, 23.24558067], [88.76888275, 23.24520683], [88.76947021, 23.24496269], [88.77033234, 23.24347115], [88.77127075, 23.24149895], [88.77268982, 23.24187279], [88.77285004, 23.24191475], [88.77361298, 23.24128532], [88.77424622, 23.24066353], [88.77383423, 23.23975372], [88.77296448, 23.23935127], [88.77323151, 23.2390461], [88.77451324, 23.23898697], [88.77555847, 23.23865128], [88.77590179, 23.23843384], [88.77622986, 23.23822021], [88.77618408, 23.23762703], [88.77609253, 23.23641014], [88.77796936, 23.23518372], [88.77700806, 23.23495674], [88.77571869, 23.23464966], [88.77548981, 23.23459625], [88.77469635, 23.23446274], [88.77680206, 23.2327404], [88.77802277, 23.22977829], [88.77803802, 23.22343063], [88.77900696, 23.22252846], [88.78079224, 23.2211628], [88.782341, 23.22121048], [88.78277588, 23.22196007], [88.7833252, 23.2229023], [88.78373718, 23.22278976], [88.78530121, 23.22236443], [88.78580475, 23.2222805], [88.78701019, 23.22208023], [88.7877655, 23.22195625], [88.78853607, 23.22021866], [88.78973389, 23.21848679], [88.79105377, 23.21829033], [88.79111481, 23.21878815], [88.7914505, 23.22168159], [88.79444122, 23.22003937], [88.79766846, 23.2191925], [88.80419922, 23.21879768], [88.80747223, 23.21945763], [88.8085556, 23.22006798], [88.81129456, 23.22161484], [88.81140137, 23.22167397], [88.81111145, 23.22200394], [88.80847931, 23.22497368], [88.80854034, 23.22529411], [88.8086319, 23.22571754], [88.80901337, 23.22762489], [88.80921936, 23.22865105], [88.80725861, 23.2307682], [88.8065033, 23.23159027], [88.80679321, 23.23388481], [88.80690002, 23.23501396], [88.80589294, 23.23809814], [88.80603027, 23.23853302], [88.80619049, 23.23901558], [88.8075943, 23.24333572], [88.80810547, 23.24401093], [88.80821228, 23.2440815], [88.80900574, 23.24503326], [88.80828857, 23.2455883], [88.80818939, 23.24566269], [88.80831146, 23.24581146], [88.80867004, 23.2489109], [88.80886078, 23.24937439], [88.80863953, 23.24951553], [88.80910492, 23.2513752], [88.80947113, 23.25312614], [88.80953979, 23.25335503], [88.81002045, 23.25499916], [88.81090546, 23.25476837], [88.81095123, 23.25620651], [88.81130219, 23.25624275], [88.81221771, 23.25634003], [88.81246185, 23.25597954], [88.81278229, 23.25551796], [88.81329346, 23.25379181], [88.81338501, 23.25347519], [88.81350708, 23.25271225], [88.81354523, 23.25248337], [88.81359863, 23.25216675], [88.81595612, 23.25082207], [88.81613159, 23.25074959], [88.81829834, 23.24987411], [88.81970978, 23.24907875], [88.82063293, 23.24855804], [88.82393646, 23.24729919], [88.82756042, 23.24551964], [88.82798767, 23.24530983], [88.82822418, 23.24519539], [88.82818604, 23.24498367], [88.82827759, 23.24497032], [88.83093262, 23.24468994], [88.82804108, 23.24057961], [88.82367706, 23.23742104], [88.82304382, 23.23603249], [88.82302856, 23.23548889], [88.82355499, 23.23415375], [88.82423401, 23.2337532], [88.82511139, 23.23390198], [88.82611084, 23.23438835], [88.82691193, 23.23513412], [88.82834625, 23.23617363], [88.83040619, 23.23759842], [88.83315277, 23.23948288], [88.8342514, 23.24114037], [88.83544922, 23.2429657], [88.83609009, 23.24373436], [88.83681488, 23.24381065], [88.83702087, 23.24372292], [88.83731079, 23.24359703], [88.837883, 23.24283981], [88.83867645, 23.24112511], [88.83925629, 23.23929214], [88.83930969, 23.2390976], [88.84010315, 23.23721695], [88.84030914, 23.23697472], [88.84112549, 23.23600578], [88.842659, 23.23496437], [88.84408569, 23.2341156], [88.84436798, 23.23371696], [88.84466553, 23.23328209], [88.84466553, 23.23278809], [88.84467316, 23.23270988], [88.84449768, 23.23257828], [88.84400177, 23.23221016], [88.84484863, 23.2306881], [88.84650421, 23.23057938], [88.85005188, 23.23053551], [88.85056305, 23.2311306], [88.85092926, 23.23155785], [88.85132599, 23.23408508], [88.85146332, 23.23409462], [88.8520813, 23.2341404], [88.85224152, 23.23415184], [88.8536377, 23.23425484], [88.85366058, 23.23467064], [88.85373688, 23.23646355], [88.85422516, 23.23624229], [88.85630035, 23.23530769], [88.85668945, 23.23527908], [88.85912323, 23.23508644], [88.85929871, 23.23453331], [88.85996246, 23.23243332], [88.86009979, 23.23239326], [88.86080933, 23.23218918], [88.86122131, 23.23207092], [88.86188507, 23.23381615], [88.86210632, 23.23438454], [88.86795807, 23.23393059], [88.86927032, 23.2338295], [88.87319946, 23.23420715], [88.87336731, 23.23421669], [88.87411499, 23.23425484], [88.87464905, 23.23428345], [88.87472534, 23.23408699], [88.87509155, 23.23323631], [88.87535858, 23.23259735], [88.87548828, 23.23229408], [88.87569427, 23.23230934], [88.87709045, 23.23241615], [88.87908936, 23.23139763], [88.88357544, 23.229599], [88.88475037, 23.22951317], [88.88572693, 23.22870827], [88.88572693, 23.22683907], [88.88572693, 23.22664452], [88.8857193, 23.22624016], [88.885849, 23.22620773], [88.88594818, 23.22618484], [88.88627625, 23.22610283], [88.88689423, 23.22649002], [88.88698578, 23.22696877], [88.88712311, 23.22773361], [88.88690186, 23.22977638], [88.88676453, 23.23112297], [88.88673401, 23.23142242], [88.88795471, 23.23132324], [88.88813019, 23.23130798], [88.8883667, 23.231287], [88.88925934, 23.23120499], [88.89037323, 23.2311039], [88.89086151, 23.23105812], [88.89183807, 23.2317543], [88.89225769, 23.2322979], [88.89239502, 23.23247337], [88.89256287, 23.23232841], [88.89367676, 23.23134041], [88.89488983, 23.23104286], [88.89507294, 23.23246765], [88.89588165, 23.23286247], [88.89614868, 23.23299217], [88.8962326, 23.23298836], [88.89717102, 23.23294258], [88.89784241, 23.23291016], [88.89862061, 23.23189545], [88.89876556, 23.23195267], [88.9000473, 23.23243141], [88.90032959, 23.23316193], [88.90060425, 23.23387527], [88.90132141, 23.2332077], [88.90316772, 23.23475456], [88.90391541, 23.23581886], [88.90484619, 23.23613358], [88.90498352, 23.23607445], [88.90589905, 23.235672], [88.905159, 23.23433113], [88.90640259, 23.23493385], [88.90674591, 23.23597336], [88.90678406, 23.23609734], [88.90744781, 23.23558426], [88.90803528, 23.23513222], [88.91052246, 23.23469734], [88.91091919, 23.23462868], [88.91217804, 23.23402786], [88.91207886, 23.23153496], [88.91207886, 23.2313633], [88.91256714, 23.2309494], [88.91334534, 23.23029518], [88.91407013, 23.22968102], [88.91492462, 23.22895813], [88.91487885, 23.22665215], [88.9148407, 23.22532463], [88.91479492, 23.22377586], [88.9157486, 23.22324181], [88.91660309, 23.22276306], [88.91612244, 23.21948051], [88.9147644, 23.21676064], [88.91435242, 23.21624756], [88.91387177, 23.21498108], [88.91388702, 23.2146492], [88.91390991, 23.21429825], [88.91469574, 23.21334076], [88.91478729, 23.21322441], [88.91503906, 23.21311951], [88.91610718, 23.21266747], [88.9163208, 23.21257782], [88.91753387, 23.21247482], [88.91848755, 23.21344948], [88.91851044, 23.2137928], [88.91854858, 23.21465111], [88.92001343, 23.21490669], [88.92008972, 23.21492004], [88.92093658, 23.21614647], [88.92111206, 23.21752167], [88.92118073, 23.21810913], [88.91925812, 23.2186985], [88.9188385, 23.21874428], [88.91678619, 23.21897507], [88.91661072, 23.21899414], [88.91664124, 23.21931648], [88.91664886, 23.21946907], [88.91667175, 23.21967888], [88.91899872, 23.21925926], [88.91957855, 23.21915436], [88.92025757, 23.21903229], [88.92280579, 23.21824074], [88.92302704, 23.21817207], [88.92286682, 23.21713638], [88.92275238, 23.21636581], [88.92272949, 23.21618271], [88.92295074, 23.21614456], [88.92401886, 23.21596527], [88.92478943, 23.21583748], [88.92499542, 23.21685982], [88.92519379, 23.21790123], [88.92636871, 23.21803665], [88.92646027, 23.21784401], [88.92694855, 23.21681023], [88.92706299, 23.21694756], [88.92767334, 23.21763992], [88.93023682, 23.21691704], [88.92980957, 23.21571541], [88.92856598, 23.21505356], [88.92887115, 23.21462822], [88.92897034, 23.21449089], [88.92936707, 23.21429443], [88.92961121, 23.21417236], [88.92940521, 23.21241951], [88.92939758, 23.21234512], [88.92929077, 23.21146393], [88.93315887, 23.20995712], [88.93392181, 23.20966148], [88.93455505, 23.20939827], [88.93933868, 23.20742798], [88.94215393, 23.20638275], [88.9422226, 23.20635796], [88.94746399, 23.20659065], [88.94944, 23.20932579], [88.95202637, 23.210989], [88.95241547, 23.21128273], [88.95256805, 23.21133614], [88.95270538, 23.21058083], [88.95458221, 23.21113968], [88.95482635, 23.21121979], [88.95600891, 23.21161079], [88.95650482, 23.21220779], [88.95716858, 23.21253204], [88.95762634, 23.2127533], [88.95836639, 23.21291351], [88.95936584, 23.21312904], [88.95936584, 23.21380806], [88.95937347, 23.21393394], [88.96059418, 23.2141552], [88.96399689, 23.21476936], [88.96466827, 23.21739769], [88.96540833, 23.21815491], [88.96627045, 23.21905518], [88.96643829, 23.21918678], [88.96734619, 23.21938324], [88.9675827, 23.21943283], [88.9682312, 23.21957397], [88.96871185, 23.22056961], [88.96878052, 23.22071838], [88.96886444, 23.22068024], [88.96949005, 23.22040558], [88.97026825, 23.22152328], [88.97058868, 23.22256851], [88.9706192, 23.22267532], [88.97138977, 23.22257042], [88.9716568, 23.22253418], [88.97218323, 23.2224617], [88.97317505, 23.22252083], [88.97415924, 23.22111893], [88.97422791, 23.22102356], [88.97496033, 23.2197094], [88.97530365, 23.21909523], [88.97705841, 23.21616745], [88.9776535, 23.21498299], [88.97782898, 23.21461868], [88.97893524, 23.21573639], [88.97798157, 23.21665192], [88.97639465, 23.21843338], [88.97568512, 23.21967125], [88.97542572, 23.22012901], [88.97427368, 23.22219467], [88.97418213, 23.22338867], [88.97477722, 23.22418594], [88.97494507, 23.22427177], [88.97554779, 23.22456932], [88.97678375, 23.22452927], [88.97834015, 23.22410965], [88.97943115, 23.22352219], [88.98030853, 23.22333336], [88.98110962, 23.2226181], [88.98149109, 23.22174072], [88.98141479, 23.22126198], [88.98300171, 23.22055817], [88.98257446, 23.22138977], [88.98262024, 23.22151947], [88.98274231, 23.22191048], [88.98311615, 23.2219429], [88.98350525, 23.22166634], [88.98412323, 23.22123718], [88.98445129, 23.22100258], [88.98442841, 23.22120857], [88.98435211, 23.22178459], [88.98471832, 23.22161865], [88.98493195, 23.22111702], [88.9850769, 23.22081566], [88.98566437, 23.21959305], [88.98591614, 23.21925926], [88.98893738, 23.21788979], [88.99015808, 23.21734047], [88.99207306, 23.21559525], [88.9925766, 23.21562195], [88.99269867, 23.21563148], [88.99407196, 23.21572685], [88.99500275, 23.21570969], [88.99583435, 23.21518898], [88.99599457, 23.21449661], [88.99563599, 23.21399307], [88.99506378, 23.21361542], [88.99494171, 23.21353531], [88.99398804, 23.21308517], [88.99375916, 23.21297646], [88.99272919, 23.21265984], [88.99151611, 23.21248436], [88.99093628, 23.21254158], [88.99060822, 23.21257401], [88.9897995, 23.21299934], [88.98963928, 23.21318626], [88.98886108, 23.21406937], [88.98761749, 23.21511269], [88.98626709, 23.21553421], [88.98484039, 23.21571541], [88.98461151, 23.21567345], [88.98336792, 23.21544266], [88.98236847, 23.21479225], [88.98116302, 23.21387672], [88.98044586, 23.21328545], [88.97966766, 23.21264648], [88.97940063, 23.21141624], [88.97955322, 23.21121788], [88.9801712, 23.21041679], [88.98038483, 23.21014214], [88.98139954, 23.20981407], [88.98280334, 23.20977211], [88.98314667, 23.20976067], [88.98403168, 23.20936775], [88.98426056, 23.20926857], [88.984375, 23.20921707], [88.9855957, 23.20876694], [88.98627472, 23.20793533], [88.98679352, 23.20705414], [88.98712921, 23.20576096], [88.98609161, 23.20475578], [88.98674774, 23.20395088], [88.98748779, 23.20304489], [88.98768616, 23.20279121], [88.98725891, 23.20277023], [88.986763, 23.20274734], [88.98583984, 23.20270348], [88.98561096, 23.20269203], [88.9847641, 23.20164871], [88.98442841, 23.20030975], [88.98530579, 23.19996643], [88.98404694, 23.19906998], [88.98306274, 23.1978302], [88.98273468, 23.19663239], [88.98193359, 23.19576645], [88.98176575, 23.19558144], [88.98188019, 23.19506264], [88.98196411, 23.19469452], [88.98004913, 23.19385529], [88.98144531, 23.19262695], [88.98064423, 23.19193268], [88.98025513, 23.19159889], [88.97989655, 23.1912899], [88.97977448, 23.18964386], [88.97932434, 23.18935776], [88.97819519, 23.18864822], [88.97821045, 23.18845367], [88.97827911, 23.1871376], [88.97827911, 23.18702316], [88.97888947, 23.18704605], [88.97956085, 23.18707085], [88.97871399, 23.18670273], [88.97853851, 23.18523407], [88.97867584, 23.18389893], [88.97871399, 23.18348885], [88.97962952, 23.18302727], [88.98036194, 23.18265724], [88.97950745, 23.18286705], [88.97860718, 23.18309212], [88.97820282, 23.18391991], [88.97796631, 23.18342972], [88.97746277, 23.18237305], [88.9769516, 23.18201637], [88.97644043, 23.1818943], [88.97602081, 23.18197632], [88.97598267, 23.18222237], [88.97566223, 23.18427467], [88.9756012, 23.18570137], [88.9752655, 23.18671799], [88.97514343, 23.18707466], [88.97542572, 23.18710899], [88.9757843, 23.18715096], [88.97587585, 23.1871624], [88.97586823, 23.18737602], [88.9758606, 23.18750191], [88.9757843, 23.18893242], [88.97537231, 23.1895504], [88.97499847, 23.19011688], [88.97483063, 23.19037819], [88.97467804, 23.19150734], [88.97472382, 23.19158745], [88.9748764, 23.19182396], [88.97530365, 23.19249153], [88.9743576, 23.19295883], [88.97067261, 23.19336128], [88.9664917, 23.19382477], [88.96438599, 23.19348335], [88.96224213, 23.19326782], [88.96179962, 23.19322205], [88.9617157, 23.19294357], [88.96153259, 23.19233131], [88.96122742, 23.19129372], [88.9609375, 23.1911602], [88.96063232, 23.19101906], [88.9597702, 23.19061852], [88.95941162, 23.19041634], [88.95862579, 23.18996239], [88.95826721, 23.18975639], [88.95825195, 23.18962097], [88.95792389, 23.1866684], [88.95783997, 23.18640327], [88.95738983, 23.18495941], [88.95743561, 23.18471146], [88.95770264, 23.18338776], [88.95781708, 23.1827755], [88.95715332, 23.18217278], [88.95617676, 23.18200684], [88.95462799, 23.18208313], [88.95426941, 23.1821022], [88.95419312, 23.18210602], [88.95275879, 23.18217468], [88.95095062, 23.18226051], [88.95095062, 23.1811924], [88.94787598, 23.18087769], [88.94617462, 23.18070412], [88.94606781, 23.18059349], [88.94585419, 23.18037224], [88.9434967, 23.17795944], [88.94391632, 23.17686844], [88.94412994, 23.17632294], [88.93929291, 23.1768837], [88.93901062, 23.17691803], [88.9389267, 23.17665291], [88.93815613, 23.17428207], [88.93806458, 23.1740036], [88.93795776, 23.17362976], [88.93771362, 23.17276192], [88.93649292, 23.1726284], [88.93527985, 23.1724968], [88.93526459, 23.17230415], [88.93506622, 23.1705265], [88.93424988, 23.16996956], [88.93388367, 23.16941071], [88.93345642, 23.16876602], [88.93333435, 23.16828537], [88.93269348, 23.16573906], [88.93265533, 23.16556549], [88.93344879, 23.16508293], [88.93409729, 23.16469002], [88.93428802, 23.16330147], [88.93401337, 23.16191483], [88.93340302, 23.16194725], [88.93318939, 23.1619606], [88.93250275, 23.16199684], [88.93157959, 23.16204643], [88.93156433, 23.16263962], [88.93082428, 23.16282654], [88.92819977, 23.16348648], [88.92803192, 23.16352844], [88.92783356, 23.16317749], [88.92802429, 23.16311646], [88.93013, 23.16242981], [88.93009186, 23.16219139], [88.92805481, 23.16275406], [88.92782593, 23.16101265], [88.92781067, 23.16086006], [88.92789459, 23.16086769], [88.92978668, 23.16100883], [88.93114471, 23.16008759], [88.93054962, 23.15782738], [88.93062592, 23.15768623], [88.93127441, 23.15641785], [88.93151093, 23.15637016], [88.93219757, 23.15623665], [88.93227386, 23.15622139], [88.93209076, 23.15487099], [88.93202972, 23.15440369], [88.93216705, 23.15436935], [88.93241119, 23.15430641], [88.93224335, 23.15170479], [88.93202209, 23.14969826], [88.93198395, 23.14911652], [88.93187714, 23.14715958], [88.93185425, 23.14666176], [88.93160248, 23.14561272], [88.9315033, 23.14598846], [88.93127441, 23.14685059], [88.93118286, 23.14685631], [88.9307251, 23.14688873], [88.93054199, 23.14690018], [88.93061829, 23.14551544], [88.93062592, 23.14536285], [88.93070984, 23.14483833], [88.93145752, 23.14040947], [88.93135071, 23.13858032], [88.93061829, 23.13815117], [88.92867279, 23.13857079], [88.92571259, 23.14015007], [88.92513275, 23.13992119], [88.92463684, 23.13983917], [88.92269135, 23.13948059], [88.92196655, 23.13508034], [88.92154694, 23.13252258], [88.92147064, 23.12745094], [88.92086792, 23.12610054], [88.91821289, 23.12451172], [88.91133118, 23.12355995], [88.90851593, 23.12152863], [88.90804291, 23.12152863], [88.90499878, 23.11540031], [88.90357208, 23.11383057], [88.90184021, 23.11180115], [88.89745331, 23.10608101], [88.89131927, 23.102911], [88.88787079, 23.10499001], [88.88723755, 23.10476112], [88.88580322, 23.10560036], [88.88421631, 23.10470009], [88.88179779, 23.09902954], [88.881073, 23.09832954], [88.88056946, 23.0981102], [88.87982178, 23.0977726], [88.87909698, 23.09744072], [88.87420654, 23.09765053], [88.87187195, 23.09674644], [88.87176514, 23.09580612], [88.8734436, 23.09566498], [88.8735733, 23.09465408], [88.87386322, 23.09245491], [88.873909, 23.09210587], [88.87399292, 23.0920887], [88.87482452, 23.09191513], [88.87408447, 23.09184265], [88.87400818, 23.09183502], [88.87454224, 23.09006691], [88.87458801, 23.08992004], [88.87376404, 23.08950615], [88.87364197, 23.08944511], [88.87310028, 23.08917618], [88.87281799, 23.08903313], [88.87217712, 23.08911514], [88.87107849, 23.08925629], [88.8708725, 23.08913612], [88.87091827, 23.08889008], [88.87106323, 23.08806229], [88.87108612, 23.08793449], [88.87155151, 23.08692741], [88.8712616, 23.08695602], [88.87038422, 23.08704376], [88.87036896, 23.08690262], [88.87024689, 23.08611298], [88.86819458, 23.08639526], [88.86804199, 23.08638191], [88.86698914, 23.08629417], [88.86644745, 23.0862484], [88.86616516, 23.0862236], [88.86614227, 23.08589172], [88.8660965, 23.0853157], [88.86599731, 23.08413506], [88.8659668, 23.08190918], [88.86484528, 23.08068275], [88.86467743, 23.08052254], [88.86398315, 23.07990646], [88.8636322, 23.07959366], [88.86447144, 23.07896042], [88.86514282, 23.07845879], [88.86547852, 23.07796478], [88.86553955, 23.07788086], [88.86528778, 23.07753563], [88.86487579, 23.07766151], [88.8636322, 23.07804108], [88.86253357, 23.07885551], [88.86129761, 23.0788784], [88.8611145, 23.07801437], [88.86099243, 23.07744598], [88.86327362, 23.0769825], [88.86296082, 23.07604408], [88.86603546, 23.07429504], [88.86687469, 23.07376289], [88.86755371, 23.07340622], [88.86766815, 23.07334709], [88.86817169, 23.07261848], [88.86816406, 23.07183838], [88.86786652, 23.07184029], [88.86735535, 23.07289886], [88.86722565, 23.07292366], [88.86693573, 23.07297897], [88.86673737, 23.0715847], [88.86733246, 23.0714283], [88.86753845, 23.07063484], [88.86828613, 23.06909943], [88.86859894, 23.06874657], [88.86941528, 23.06782532], [88.86959076, 23.06772614], [88.87014771, 23.06753159], [88.8703537, 23.0674572], [88.87097931, 23.06734657], [88.8724823, 23.06660461], [88.87280273, 23.06651878], [88.87378693, 23.06625557], [88.87366486, 23.06548119], [88.87324524, 23.06280136], [88.87322998, 23.06219482], [88.87363434, 23.06202126], [88.87413788, 23.06191254], [88.87452698, 23.06183052], [88.87471008, 23.06179237], [88.87503052, 23.06172562], [88.87499237, 23.06149864], [88.87468719, 23.05952454], [88.87454987, 23.05864906], [88.87431335, 23.05822754], [88.87406158, 23.05695152], [88.87451935, 23.05566406], [88.87485504, 23.05557823], [88.87478638, 23.05482101], [88.87454224, 23.05334282], [88.87435913, 23.0520668], [88.8742981, 23.05165291], [88.87416077, 23.05077934], [88.87444305, 23.05066681], [88.87499237, 23.05049515], [88.87513733, 23.05045128], [88.87481689, 23.04949951], [88.8745575, 23.04885101], [88.87467957, 23.04675293], [88.87503815, 23.04665565], [88.87497711, 23.04567528], [88.87490845, 23.0446434], [88.87494659, 23.04442406], [88.87602234, 23.04408264], [88.87698364, 23.0435257], [88.87767029, 23.04289818], [88.87850952, 23.04200935], [88.87992096, 23.04115677], [88.8816452, 23.04060936], [88.88274384, 23.04047966], [88.88318634, 23.04042625], [88.88408661, 23.04055214], [88.88407898, 23.04045105], [88.88394928, 23.03907967], [88.88421631, 23.03882408], [88.88420868, 23.03874397], [88.88368225, 23.03751183], [88.8844223, 23.0371666], [88.88420868, 23.03661346], [88.88368988, 23.03686333], [88.88343048, 23.03704453], [88.88311768, 23.03725243], [88.88267517, 23.03728294], [88.88214111, 23.03712273], [88.88208008, 23.03601646], [88.88185883, 23.0344677], [88.88173676, 23.03360748], [88.88150787, 23.03366661], [88.88076782, 23.03385735], [88.88004303, 23.03198814], [88.88054657, 23.03030586], [88.88049316, 23.02832031], [88.87989044, 23.02644348], [88.88095093, 23.02596283], [88.88090515, 23.02556038], [88.88026428, 23.02496338], [88.87968445, 23.02505875], [88.8799057, 23.02584839], [88.87900543, 23.02603722], [88.8789444, 23.0247612], [88.87963104, 23.02463341], [88.87887573, 23.02445984], [88.87806702, 23.02427101], [88.87834167, 23.02543831], [88.8784256, 23.02584648], [88.87848663, 23.02611542], [88.8776474, 23.02621078], [88.87721252, 23.0261898], [88.87704468, 23.02494812], [88.87687683, 23.02290916], [88.87567902, 23.02272987], [88.8747406, 23.02207565], [88.87374115, 23.02074242], [88.87275696, 23.01922798], [88.87252045, 23.01874542], [88.87223053, 23.01769066], [88.87217712, 23.01674843], [88.87296295, 23.01607323], [88.87355042, 23.01531601], [88.87380219, 23.01510048], [88.87407684, 23.01486206], [88.87451172, 23.01442719], [88.87462616, 23.01379776], [88.87450409, 23.01234818], [88.87440491, 23.01110649], [88.87439728, 23.01101303], [88.8742981, 23.0101738], [88.87638855, 23.0101738], [88.8784256, 23.01005554], [88.87979126, 23.00936699], [88.88017273, 23.00847435], [88.88011169, 23.00790596], [88.87973785, 23.00629044], [88.87906647, 23.00468826], [88.87847137, 23.00386047], [88.87841797, 23.00378418], [88.87786102, 23.00340271], [88.87722778, 23.00324821], [88.87661743, 23.00330162], [88.87342072, 23.00444794], [88.87341309, 23.00434113], [88.87304688, 23.00342941], [88.87082672, 23.00183105], [88.87034607, 23.00162125], [88.87021637, 23.00164032], [88.86496735, 23.00271988], [88.85787964, 23.0053196], [88.85323334, 23.00699043], [88.84868622, 23.00605965], [88.84777832, 23.00549316], [88.84777069, 23.00535774], [88.85010529, 23.00306702], [88.85205078, 23.00209236], [88.85287476, 23.00203323], [88.85431671, 23.00236702], [88.85617828, 23.00269508], [88.85803986, 23.00282288], [88.85837555, 23.00283051], [88.86050415, 23.00287056], [88.86222076, 23.00256729], [88.86377716, 23.00199127], [88.86483765, 23.00120163], [88.86558533, 23.00038338], [88.86566925, 22.99960136], [88.8653717, 22.99889755], [88.86512756, 22.99830818], [88.86437225, 22.99615097], [88.86395264, 22.99480057], [88.86389923, 22.9933567], [88.86387634, 22.99273109], [88.86385345, 22.99191856], [88.86434174, 22.98886108], [88.86488342, 22.98647308], [88.86579895, 22.98381615], [88.86656952, 22.98257446], [88.86727905, 22.98150444], [88.8673172, 22.98143959], [88.86777496, 22.98116493], [88.86903381, 22.98175621], [88.86920166, 22.98053169], [88.86919403, 22.98029518], [88.87068176, 22.97936249], [88.87107849, 22.97874641], [88.87098694, 22.9785347], [88.87062073, 22.97763443], [88.86952209, 22.97667503], [88.86904144, 22.9763813], [88.86633301, 22.97474289], [88.86499023, 22.97414589], [88.86368561, 22.9737072], [88.86038971, 22.97253609], [88.85954285, 22.97223663], [88.85845947, 22.97148514], [88.85758209, 22.97004128], [88.85697937, 22.96884155], [88.85617828, 22.96635437], [88.85557556, 22.96424294], [88.85508728, 22.96120644], [88.85498047, 22.95913315], [88.85516357, 22.95760727], [88.85585785, 22.95425797], [88.85721588, 22.95056725], [88.85820007, 22.94754219], [88.85848236, 22.94564247], [88.85889435, 22.9437542], [88.85958862, 22.94245529], [88.8599472, 22.94222069], [88.86045074, 22.94220924], [88.86075592, 22.94239807], [88.86080933, 22.94249535], [88.86102295, 22.94290924], [88.86135864, 22.94419289], [88.86206055, 22.94556236], [88.86358643, 22.9472065], [88.86468506, 22.94823456], [88.86707306, 22.95033646], [88.86828613, 22.95137405], [88.86885834, 22.95158386], [88.86917877, 22.95156479], [88.87114716, 22.95058823], [88.87210083, 22.94988632], [88.8735199, 22.94869804], [88.87411499, 22.94832993], [88.87464905, 22.94824791], [88.87537384, 22.94838905], [88.87584686, 22.94853592], [88.87615204, 22.94870567], [88.87650299, 22.94889832], [88.87733459, 22.94990921], [88.87773895, 22.95075417], [88.87779999, 22.95088577], [88.87786102, 22.95126343], [88.8780899, 22.952631], [88.8782959, 22.95350647], [88.87869263, 22.95406151], [88.8795166, 22.9542675], [88.88109589, 22.95412254], [88.88467407, 22.95380974], [88.88693237, 22.95357513], [88.8913269, 22.95306015], [88.89315796, 22.95282936], [88.89350128, 22.95269966], [88.89363098, 22.95265198], [88.89405823, 22.95248413], [88.89433289, 22.95223045], [88.89434052, 22.9519577], [88.89435577, 22.95149994], [88.89411163, 22.95108795], [88.89396667, 22.9508419], [88.89331055, 22.94963264], [88.89283752, 22.94818306], [88.89251709, 22.94708252], [88.89241028, 22.94607925], [88.89237976, 22.94427872], [88.89260864, 22.94280243], [88.89266205, 22.9419651], [88.89287567, 22.94005585], [88.89303589, 22.93868446], [88.89289856, 22.93796539], [88.89268494, 22.93767548], [88.89420319, 22.93766403], [88.8943634, 22.93766594], [88.89455414, 22.93769264], [88.89472961, 22.93772507], [88.8948822, 22.93775368], [88.89510345, 22.93779373], [88.89518738, 22.93785858], [88.89537811, 22.93790054], [88.89547729, 22.93795013], [88.89559174, 22.93799973], [88.89572144, 22.93807602], [88.89587402, 22.93816376], [88.89595795, 22.93825531], [88.89602661, 22.93836403], [88.8961792, 22.93849373], [88.89622498, 22.93862152], [88.89624786, 22.9387455], [88.89635468, 22.93886566], [88.89641571, 22.93901825], [88.89653778, 22.93918419], [88.8966217, 22.93932343], [88.89672852, 22.93946838], [88.89696503, 22.93949509], [88.89717102, 22.93939972], [88.89727783, 22.93922806], [88.89725494, 22.9391098], [88.89723206, 22.93895912], [88.8972168, 22.93885422], [88.89720154, 22.93876076], [88.89718628, 22.9386692], [88.89717102, 22.93855667], [88.89715576, 22.93844795], [88.89713287, 22.9383297], [88.89710236, 22.93814278], [88.89706421, 22.93793869], [88.89704895, 22.93783188], [88.8969574, 22.9372921], [88.89665222, 22.93547821], [88.89624786, 22.93305969], [88.89698792, 22.92674065], [88.90174866, 22.92406654], [88.90414429, 22.92303848], [88.90575409, 22.92243195], [88.90591431, 22.92231941], [88.90873718, 22.92197037], [88.91018677, 22.92179108], [88.91177368, 22.92042732], [88.91172028, 22.92037582], [88.91159058, 22.92027664], [88.91142273, 22.92012405], [88.91129303, 22.92002678], [88.91112518, 22.9199295], [88.91099548, 22.9199028], [88.91086578, 22.91990471], [88.9107132, 22.9199295], [88.9104538, 22.91992569], [88.91020966, 22.91984367], [88.91007233, 22.91975784], [88.90998077, 22.91969299], [88.90968323, 22.91953468], [88.90956116, 22.91944122], [88.90919495, 22.91926765], [88.90858459, 22.91915894], [88.90853119, 22.91867447], [88.90840149, 22.91829872], [88.90817261, 22.91762352], [88.90758514, 22.91638565], [88.90742493, 22.9160347], [88.90656281, 22.91504669], [88.90606689, 22.91479683], [88.90537262, 22.91444397], [88.90406036, 22.91416931], [88.90332794, 22.91414261], [88.89952087, 22.91426659], [88.89852142, 22.91430283], [88.8968811, 22.91454887], [88.89598846, 22.91458702], [88.89559174, 22.91443253], [88.89537811, 22.913908], [88.89532471, 22.91324806], [88.895401, 22.91285515], [88.8955307, 22.91218185], [88.8959198, 22.91139603], [88.89646912, 22.91068268], [88.89762878, 22.90971565], [88.89865112, 22.90886879], [88.90028381, 22.90760422], [88.90084839, 22.90709305], [88.90112305, 22.90672874], [88.90123749, 22.90638542], [88.90123749, 22.90598297], [88.90111542, 22.90419769], [88.90100098, 22.90331459], [88.9005661, 22.90201378], [88.90037537, 22.90166664], [88.8992157, 22.89961433], [88.89822388, 22.89782333], [88.89855194, 22.89768028], [88.89927673, 22.89736557], [88.90138245, 22.89653397], [88.90226746, 22.89577866], [88.90274048, 22.89537239], [88.9040451, 22.89574432], [88.90445709, 22.89586258], [88.90487671, 22.89522552], [88.90524292, 22.89413071], [88.90586853, 22.89407158], [88.90634155, 22.89399529], [88.90779114, 22.893713], [88.90736389, 22.89340591], [88.90632629, 22.89266586], [88.90538025, 22.89254761], [88.90534973, 22.89229393], [88.90505981, 22.88989258], [88.90518951, 22.88950729], [88.90540314, 22.88884926], [88.9056015, 22.88805771], [88.90573883, 22.88791847], [88.90584564, 22.88780975], [88.90615845, 22.88745499], [88.90705872, 22.88715363], [88.90769958, 22.88715744], [88.90808105, 22.88715363], [88.9077301, 22.8869915], [88.90801239, 22.88532066], [88.90884399, 22.88513184], [88.90982056, 22.88482666], [88.90921021, 22.88157082], [88.91191864, 22.88182449], [88.91268158, 22.88160706], [88.91252899, 22.88113976], [88.91227722, 22.88114166], [88.91194153, 22.88056183], [88.91149139, 22.88050842], [88.91096497, 22.88072205], [88.91065216, 22.88084793], [88.90962219, 22.88101768], [88.90951538, 22.88030434], [88.90982819, 22.88018608], [88.90979004, 22.8798027], [88.91203308, 22.87870789], [88.91249847, 22.87856483], [88.91307068, 22.87839127], [88.91329956, 22.87909508], [88.91352844, 22.8798008], [88.91490173, 22.8794117], [88.91537476, 22.87927818], [88.91654205, 22.87894821], [88.91799927, 22.87857437], [88.91785431, 22.87739754], [88.91880798, 22.877388], [88.91917419, 22.87766838], [88.92108154, 22.87913895], [88.92251587, 22.8802433], [88.92272186, 22.8797245], [88.92355347, 22.87761497], [88.92394257, 22.87661362], [88.92633057, 22.87530136], [88.92793274, 22.87264824], [88.93057251, 22.87363625], [88.93336487, 22.87438774], [88.93717957, 22.874403], [88.93987274, 22.87494278], [88.94030762, 22.87579918], [88.9405899, 22.87635231], [88.94115448, 22.87727928], [88.94152069, 22.877882], [88.94163513, 22.87840271], [88.9419632, 22.87987518], [88.94303894, 22.88032722], [88.94465637, 22.88062477], [88.94498444, 22.88054466], [88.94608307, 22.88008118], [88.94624329, 22.87993431], [88.9468689, 22.87892342], [88.94776154, 22.87800217], [88.94879913, 22.8777771], [88.94944763, 22.87742233], [88.94976044, 22.87639427], [88.9495697, 22.87486839], [88.94956207, 22.87478638], [88.94948578, 22.87363625], [88.94967651, 22.8730545], [88.95011902, 22.87238312], [88.95040131, 22.87230301], [88.95104218, 22.872118], [88.95154572, 22.87185287], [88.95194244, 22.87065506], [88.95227051, 22.87008286], [88.95284271, 22.86932755], [88.95332336, 22.86841965], [88.95337677, 22.8679924], [88.95346069, 22.86771584], [88.95378113, 22.86672401], [88.95368195, 22.86618614], [88.95339966, 22.86572647], [88.95300293, 22.86524963], [88.95288086, 22.86484528], [88.95296478, 22.86442757], [88.95334625, 22.86400986], [88.95344543, 22.8639946], [88.95407867, 22.86390495], [88.95483398, 22.86409378], [88.95542145, 22.86401939], [88.95595551, 22.86372566], [88.95735931, 22.86268044], [88.95789337, 22.86184692], [88.95850372, 22.86065674], [88.95874786, 22.85991669], [88.95868683, 22.85940552], [88.95821381, 22.85803604], [88.9580307, 22.85748863], [88.95795441, 22.85696602], [88.957901, 22.85663795], [88.9580307, 22.85631371], [88.95849609, 22.85594368], [88.96052551, 22.85513496], [88.96111298, 22.85468864], [88.96392822, 22.85131264], [88.96613312, 22.84826851], [88.96813965, 22.84517479], [88.96850586, 22.84414482], [88.96852875, 22.84347534], [88.9679718, 22.84131241], [88.96774292, 22.84044075], [88.96718597, 22.8383007], [88.96714783, 22.83790588], [88.96705627, 22.83685112], [88.96642303, 22.82889175], [88.96324921, 22.81937981], [88.96201324, 22.8168602], [88.96157074, 22.8135376], [88.96108246, 22.80984116], [88.96045685, 22.80938148], [88.96035004, 22.80912018], [88.95910645, 22.80599022], [88.9588089, 22.80336952], [88.95863342, 22.80184174], [88.95851898, 22.80085754], [88.95852661, 22.80068207], [88.95851898, 22.8002491], [88.95851898, 22.80007553], [88.95887756, 22.79794502], [88.95867157, 22.79763031], [88.95847321, 22.79733276], [88.95847321, 22.79715919], [88.95813751, 22.79638863], [88.95783234, 22.79600334], [88.95720673, 22.79622459], [88.95710754, 22.79625893], [88.9571991, 22.79599571], [88.95731354, 22.79595947], [88.95746613, 22.79594421], [88.95761871, 22.79592323], [88.95808411, 22.7959156], [88.95834351, 22.79593468], [88.95845795, 22.79593468], [88.95844269, 22.79421043], [88.95774078, 22.79355049], [88.95065308, 22.79214287], [88.9477005, 22.79100227], [88.94158936, 22.78806114], [88.94141388, 22.78795624], [88.94046783, 22.78741264], [88.93917084, 22.78667259], [88.93894958, 22.78651237], [88.93834686, 22.78600121], [88.9365921, 22.78457069], [88.93584442, 22.78394508], [88.93623352, 22.78306198], [88.93611908, 22.78302765], [88.93590546, 22.78243828], [88.93577576, 22.78244209], [88.9356308, 22.78198051], [88.93544769, 22.78201675], [88.93436432, 22.78223801], [88.93392181, 22.78233719], [88.9329834, 22.78155136], [88.93258667, 22.78121948], [88.93006134, 22.7748909], [88.9296875, 22.77396965], [88.92708588, 22.77189064], [88.92682648, 22.77158165], [88.9259491, 22.77061653], [88.92576599, 22.77000999], [88.92560577, 22.77003098], [88.9254303, 22.77005005], [88.92520905, 22.76980782], [88.9251709, 22.77008057], [88.92237854, 22.77040863], [88.91938782, 22.77096939], [88.91892242, 22.77105331], [88.9186554, 22.77082253], [88.91841888, 22.77061462], [88.91704559, 22.76942635], [88.91675568, 22.76910782], [88.91599274, 22.76792717], [88.91535187, 22.76675415], [88.91468048, 22.76552391], [88.91452789, 22.76522064], [88.91396332, 22.76399231], [88.91364288, 22.76364708], [88.91356659, 22.76355362], [88.91368103, 22.76351166], [88.9131012, 22.76253319], [88.91396332, 22.76224899], [88.91384888, 22.76186371], [88.91348267, 22.76067543], [88.91308594, 22.76072311], [88.91311646, 22.76019478], [88.9130249, 22.7600956], [88.91287231, 22.76009369], [88.9125824, 22.76006317], [88.91231537, 22.75994873], [88.91221619, 22.75971985], [88.91220093, 22.75951004], [88.91189575, 22.7595005], [88.91178894, 22.75941658], [88.91146851, 22.75889778], [88.91121674, 22.75824547], [88.91098022, 22.75786209], [88.91104889, 22.75765038], [88.91123962, 22.75754929], [88.91139221, 22.7574482], [88.91153717, 22.75721931], [88.91170502, 22.75696754], [88.91194153, 22.75664711], [88.91229248, 22.75628471], [88.91249084, 22.75605392], [88.9125061, 22.75587845], [88.91249847, 22.75576019], [88.91244507, 22.75555801], [88.91223145, 22.75500298], [88.91217804, 22.75483894], [88.91223145, 22.75471878], [88.91239166, 22.75471115], [88.9128952, 22.75465202], [88.91301727, 22.75463295], [88.91337585, 22.75457764], [88.91382599, 22.75432777], [88.9141922, 22.75418854], [88.91447449, 22.75407791], [88.91484833, 22.75427818], [88.91512299, 22.75463295], [88.91529846, 22.754776], [88.91519928, 22.75487328], [88.91537476, 22.75500488], [88.91545868, 22.75492668], [88.91659546, 22.75542641], [88.91760254, 22.75533867], [88.91838837, 22.75475121], [88.91921234, 22.75435448], [88.91980743, 22.75406837], [88.92017365, 22.75406456], [88.9209137, 22.75279999], [88.92073822, 22.75278091], [88.92028046, 22.75273514], [88.92063904, 22.75168228], [88.92069244, 22.75153542], [88.92110443, 22.75025558], [88.92108154, 22.74983025], [88.92066956, 22.74925804], [88.92044067, 22.74898148], [88.92028809, 22.74879074], [88.91954041, 22.7486496], [88.91941071, 22.74852753], [88.91889191, 22.74846649], [88.91843414, 22.74814415], [88.91812897, 22.74784851], [88.91762543, 22.74668694], [88.91751099, 22.74608994], [88.91738129, 22.74547386], [88.91695404, 22.7449131], [88.91661835, 22.74419785], [88.91651154, 22.74304771], [88.91681671, 22.74188995], [88.91657257, 22.74150848], [88.91619873, 22.7408123], [88.91609192, 22.74045944], [88.91586304, 22.73985863], [88.91579437, 22.73915863], [88.91581726, 22.73895836], [88.91596222, 22.73869514], [88.91565704, 22.73718834], [88.91565704, 22.73694801], [88.91566467, 22.73666954], [88.91579437, 22.73659706], [88.91579437, 22.73624229], [88.91583252, 22.73588181], [88.91598511, 22.73545456], [88.91608429, 22.73524284], [88.91612244, 22.73516273], [88.91621399, 22.73496437], [88.91636658, 22.73463631], [88.91644287, 22.73435974], [88.91651154, 22.73410034], [88.91664124, 22.73409653], [88.91672516, 22.73396873], [88.91686249, 22.73397064], [88.91734314, 22.73320389], [88.91757965, 22.73266029], [88.9177475, 22.73196602], [88.9178009, 22.73166466], [88.91808319, 22.73156357], [88.91816711, 22.73049164], [88.91817474, 22.73038292], [88.91861725, 22.73031998], [88.9186554, 22.73053741], [88.91867828, 22.73068619], [88.91905975, 22.73062515], [88.91973877, 22.73051834], [88.92089081, 22.73030663], [88.92084503, 22.73005486], [88.92080688, 22.72985077], [88.92120361, 22.72979164], [88.92198944, 22.7296772], [88.92300415, 22.72957611], [88.92320251, 22.72895813], [88.92325592, 22.72878838], [88.92329407, 22.72844887], [88.92434692, 22.72818756], [88.92517853, 22.72803688], [88.92588806, 22.72607422], [88.92596436, 22.72478294], [88.92598724, 22.72362137], [88.92632294, 22.72286415], [88.92681885, 22.72176552], [88.92731476, 22.72090149], [88.92761993, 22.72038651], [88.9276886, 22.72027779], [88.92771912, 22.72010994], [88.92781067, 22.71931076], [88.92788696, 22.71853447], [88.92791748, 22.71816444], [88.92829895, 22.71808815], [88.92848969, 22.71807098], [88.92881012, 22.71794319], [88.92915344, 22.7177887], [88.93054199, 22.7174263], [88.93170929, 22.71673393], [88.93264771, 22.71590042], [88.93448639, 22.71453857], [88.9347229, 22.71440887], [88.93517303, 22.71416092], [88.93534088, 22.71406746], [88.9362793, 22.71355438], [88.93806458, 22.71277237], [88.94070435, 22.71138763], [88.94238281, 22.70998955], [88.94411469, 22.70874023], [88.94702911, 22.70739174], [88.94760895, 22.70670891], [88.94773102, 22.70674324], [88.94827271, 22.70569801], [88.94836426, 22.70552444], [88.94858551, 22.70552063], [88.94889069, 22.70569992], [88.94988251, 22.70629501], [88.95034027, 22.70659447], [88.95111847, 22.70710564], [88.95278168, 22.70598221], [88.9539032, 22.70516205], [88.95607758, 22.70412636], [88.95697784, 22.70289612], [88.95682526, 22.70277786], [88.95785522, 22.70149422], [88.95813751, 22.70095062], [88.95830536, 22.70036888], [88.95790863, 22.700037], [88.96059418, 22.69815826], [88.96039581, 22.69788742], [88.96039581, 22.69699097], [88.96151733, 22.69590378], [88.96180725, 22.69561768], [88.96231842, 22.69510841], [88.9621582, 22.69504166], [88.96230316, 22.69458961], [88.96232605, 22.69400406], [88.9622345, 22.69329071], [88.9619751, 22.69267845], [88.96175385, 22.69199562], [88.96173096, 22.69167328], [88.96176147, 22.69119644], [88.96179199, 22.69064522], [88.96173859, 22.6902523], [88.96172333, 22.68998909], [88.9616394, 22.68965912], [88.9615097, 22.68919182], [88.96105194, 22.68832397], [88.9605484, 22.68735123], [88.9610672, 22.68680573], [88.96178436, 22.68610764], [88.96195984, 22.68593407], [88.96160889, 22.68535042], [88.96079254, 22.68530655], [88.96061707, 22.68529701], [88.9602356, 22.68527603], [88.95841217, 22.68533325], [88.95774841, 22.68542099], [88.95419312, 22.6809597], [88.95326233, 22.6801815], [88.95308685, 22.68003464], [88.94875336, 22.67028236], [88.94747162, 22.66119003], [88.94728088, 22.65985107], [88.94667816, 22.65920067], [88.94551849, 22.65793037], [88.93878937, 22.65055275], [88.9341507, 22.64796257], [88.93308258, 22.64735985], [88.9319458, 22.64554977], [88.93174744, 22.64594078], [88.93160248, 22.64641953], [88.93136597, 22.64683914], [88.93108368, 22.64723778], [88.93076324, 22.64759827], [88.93050385, 22.64805031], [88.9302597, 22.6485157], [88.93002319, 22.64899254], [88.92978668, 22.64948273], [88.92937469, 22.64980888], [88.92936707, 22.64990807], [88.92926788, 22.65007401], [88.92919922, 22.65018654], [88.92916107, 22.65025139], [88.92891693, 22.65073395], [88.9287262, 22.6512394], [88.92844391, 22.65158272], [88.9282074, 22.6519413], [88.92797852, 22.65230751], [88.92775726, 22.65268135], [88.92755127, 22.65302849], [88.92740631, 22.6534214], [88.92726898, 22.65382195], [88.92708588, 22.65415764], [88.92693329, 22.65451241], [88.92672729, 22.65487289], [88.92664337, 22.65528107], [88.92588043, 22.65709686], [88.92536163, 22.6585083], [88.92521667, 22.65891075], [88.9250412, 22.65916634], [88.92493439, 22.65947914], [88.92475891, 22.65974617], [88.92465973, 22.66011238], [88.92445374, 22.6604557], [88.92424011, 22.66083527], [88.92403412, 22.66124153], [88.9238205, 22.66166878], [88.92351532, 22.66200829], [88.92328644, 22.66241455], [88.92305756, 22.6627903], [88.92285156, 22.66316223], [88.92259979, 22.66348457], [88.92243958, 22.66386223], [88.92220306, 22.66418266], [88.92196655, 22.66445923], [88.92178345, 22.66475105], [88.92164612, 22.66504669], [88.92147827, 22.66529274], [88.9213028, 22.66555214], [88.9210968, 22.66583061], [88.92082977, 22.66612816], [88.92055511, 22.66650963], [88.92025757, 22.66694832], [88.91986847, 22.66736412], [88.91944122, 22.66778374], [88.91902161, 22.6682148], [88.91860962, 22.66861916], [88.91819763, 22.66902733], [88.91778564, 22.66944122], [88.91736603, 22.66985893], [88.91693115, 22.67026711], [88.91644287, 22.67060852], [88.91596985, 22.67098427], [88.91555786, 22.67141151], [88.91521454, 22.67193031], [88.91485596, 22.67243767], [88.91447449, 22.67282677], [88.91416931, 22.67326355], [88.91388702, 22.67370033], [88.91361237, 22.67413139], [88.91333771, 22.6746006], [88.91304779, 22.67512703], [88.9127121, 22.67567635], [88.9122467, 22.67613792], [88.91175842, 22.67656136], [88.91126251, 22.67692566], [88.91081238, 22.67721367], [88.91043091, 22.67743111], [88.91008759, 22.67752266], [88.90986633, 22.67765236], [88.90969849, 22.67778969], [88.90949249, 22.67783546], [88.90927887, 22.67794037], [88.90901947, 22.67804146], [88.90871429, 22.67813301], [88.90840912, 22.6783123], [88.90805817, 22.67846107], [88.90766144, 22.67860794], [88.90722656, 22.67873764], [88.90674591, 22.67886162], [88.90620422, 22.67892647], [88.90563202, 22.67906761], [88.9050293, 22.67910576], [88.90441895, 22.67895317], [88.90379333, 22.67900276], [88.90318298, 22.67913628], [88.90254211, 22.67916679], [88.90190125, 22.67914581], [88.90126038, 22.67902565], [88.90067291, 22.67885208], [88.9001236, 22.67863274], [88.89957428, 22.6784687], [88.89903259, 22.6783123], [88.89849854, 22.67811775], [88.89796448, 22.67797279], [88.89756012, 22.67780495], [88.89666748, 22.67694855], [88.89638519, 22.67694855], [88.89611053, 22.67666626], [88.89583588, 22.67666626], [88.89555359, 22.67638969], [88.89555359, 22.67611122], [88.89528656, 22.6760025], [88.8950119, 22.67580986], [88.89481354, 22.67560387], [88.89458466, 22.67547035], [88.89428711, 22.67533684], [88.89399719, 22.67506218], [88.89363861, 22.67487144], [88.89329529, 22.67467308], [88.89297485, 22.67445946], [88.8926239, 22.67429161], [88.89224243, 22.67410851], [88.89183044, 22.67387581], [88.89136505, 22.67359352], [88.89085388, 22.67330742], [88.89032745, 22.67298508], [88.88983917, 22.67261696], [88.88938141, 22.67224312], [88.8888855, 22.67193794], [88.88841248, 22.67163849], [88.88798523, 22.67133141], [88.88755035, 22.67105675], [88.88713837, 22.67076111], [88.88671875, 22.67046928], [88.88630676, 22.67015266], [88.88581848, 22.66991234], [88.88529968, 22.66970634], [88.884758, 22.66948891], [88.88420868, 22.66918564], [88.88362885, 22.66889381], [88.88301086, 22.66866112], [88.88236237, 22.66858101], [88.88175201, 22.66843224], [88.8811264, 22.66830635], [88.88052368, 22.66810036], [88.87994385, 22.66797829], [88.87940979, 22.66781616], [88.87885284, 22.6677475], [88.8783493, 22.66760826], [88.87786865, 22.66745377], [88.87741089, 22.66724968], [88.87692261, 22.66707993], [88.87639618, 22.66696358], [88.87585449, 22.66689873], [88.87539673, 22.66666603], [88.87498474, 22.66641235], [88.87458801, 22.66623878], [88.87425232, 22.66602707], [88.87400055, 22.66577148], [88.87335968, 22.66562462], [88.87267303, 22.6655407], [88.87223053, 22.66561317], [88.87179565, 22.66563225], [88.87132263, 22.6654892], [88.87082672, 22.66533089], [88.87030029, 22.66527748], [88.86979675, 22.66523361], [88.86935425, 22.66508675], [88.86891174, 22.66501427], [88.86846161, 22.66500282], [88.86797333, 22.66500282], [88.86746216, 22.66499138], [88.8669281, 22.66493416], [88.86640167, 22.66477585], [88.86586761, 22.66472816], [88.86535645, 22.66474724], [88.86485291, 22.66486931], [88.86436462, 22.66508293], [88.86402893, 22.66547775], [88.86383057, 22.6659584], [88.86377716, 22.66644478], [88.86364746, 22.66680717], [88.86361694, 22.66716194], [88.86360931, 22.66753197], [88.86360931, 22.66791344], [88.86360931, 22.66828728], [88.86360931, 22.66863251], [88.86360931, 22.66894341], [88.86360931, 22.66922951], [88.86360931, 22.66951561], [88.86361694, 22.66981506], [88.86363983, 22.67011833], [88.86367035, 22.67041969], [88.86363983, 22.67073631], [88.86360931, 22.67111206], [88.8638916, 22.67138863], [88.8638916, 22.67361259], [88.86360931, 22.67389107], [88.86361694, 22.67417526], [88.86361694, 22.6744442], [88.86360931, 22.67480659], [88.86360931, 22.67543983], [88.86360931, 22.67602539], [88.86360931, 22.67654037], [88.86360931, 22.67701721], [88.86358643, 22.67751122], [88.86346436, 22.67803764], [88.86334991, 22.67857361], [88.86319733, 22.67906761], [88.86297607, 22.67954826], [88.86278534, 22.68009758], [88.86262512, 22.68071938], [88.86247253, 22.68139267], [88.86232758, 22.68204308], [88.86245728, 22.6825943], [88.86249542, 22.68309975], [88.86245728, 22.68357277], [88.86228943, 22.68404388], [88.86216736, 22.68457031], [88.8620224, 22.68512535], [88.86210632, 22.68567467], [88.86234283, 22.68617058], [88.86252594, 22.68656921], [88.8627243, 22.68696022], [88.86279297, 22.68745232], [88.86286926, 22.68795967], [88.86301422, 22.68844795], [88.86309814, 22.68895531], [88.86328125, 22.68943214], [88.86334991, 22.68995094], [88.86346436, 22.6904068], [88.86359406, 22.69072914], [88.86369324, 22.69102669], [88.86384583, 22.69127846], [88.86390686, 22.69157982], [88.86395264, 22.69186974], [88.86403656, 22.69213295], [88.86414337, 22.6924572], [88.86417389, 22.69286537], [88.86415863, 22.69327736], [88.86411285, 22.6936512], [88.86396027, 22.69401741], [88.86370087, 22.69437218], [88.86345673, 22.6947422], [88.86319733, 22.695158], [88.86292267, 22.69564247], [88.86256409, 22.69605064], [88.8621521, 22.69642639], [88.86158752, 22.69668007], [88.86094666, 22.69690132], [88.86022949, 22.69696236], [88.85953522, 22.69700813], [88.8589325, 22.69696236], [88.85836792, 22.69692039], [88.85784149, 22.69679451], [88.85733795, 22.69664192], [88.85686493, 22.69639015], [88.85638428, 22.69611168], [88.85591888, 22.6958065], [88.85549164, 22.69545937], [88.85515594, 22.69506264], [88.85480499, 22.69473839], [88.85442352, 22.69448662], [88.85395813, 22.69433784], [88.85352325, 22.69416046], [88.85309601, 22.69396019], [88.85264587, 22.6938343], [88.85219574, 22.69365692], [88.85173798, 22.69359398], [88.85128784, 22.69351006], [88.85084534, 22.69340324], [88.85042572, 22.69330025], [88.85004425, 22.69315529], [88.84963226, 22.69304657], [88.84925842, 22.69317627], [88.84895325, 22.69353294], [88.84876251, 22.69394875], [88.84877777, 22.69449425], [88.84895325, 22.69498634], [88.8491745, 22.69547081], [88.84939575, 22.69597816], [88.84952545, 22.6965332], [88.84954834, 22.69713402], [88.84964752, 22.69771385], [88.84971619, 22.69830132], [88.84978485, 22.69891167], [88.84996033, 22.6995182], [88.84996033, 22.70015144], [88.84983063, 22.7008152], [88.84993744, 22.70150566], [88.84988403, 22.70213127], [88.84976196, 22.70260429], [88.84970856, 22.70306206], [88.84960938, 22.70348549], [88.84945679, 22.70388222], [88.84931946, 22.70427895], [88.84919739, 22.70471001], [88.84916687, 22.70516777], [88.84915924, 22.70560455], [88.84912109, 22.70602608], [88.84890747, 22.70702171], [88.84883881, 22.70742226], [88.84883881, 22.70815849], [88.84869385, 22.70842934], [88.84812164, 22.70889854], [88.84797668, 22.70903015], [88.84603119, 22.70903015], [88.8447876, 22.70889473], [88.84416199, 22.70889282], [88.84353638, 22.70884895], [88.84297943, 22.70866203], [88.84243774, 22.70861626], [88.84194946, 22.70861244], [88.84150696, 22.70860863], [88.84108734, 22.70857048], [88.84070587, 22.7084446], [88.84031677, 22.70835495], [88.83992767, 22.70833397], [88.83952332, 22.70833397], [88.83908844, 22.70833397], [88.83860779, 22.70833397], [88.83808899, 22.70833397], [88.8375473, 22.70837212], [88.83700562, 22.70853043], [88.83642578, 22.70865059], [88.83586121, 22.70889282], [88.83525085, 22.7091198], [88.8345871, 22.70919418], [88.83396149, 22.70932579], [88.83338928, 22.70947075], [88.83288574, 22.70964241], [88.83232117, 22.7096386], [88.83171082, 22.70970726], [88.83111572, 22.7097683], [88.83058929, 22.70995522], [88.83001709, 22.71007729], [88.82951355, 22.71037865], [88.82897949, 22.71048546], [88.82841492, 22.71054649], [88.82776642, 22.71060753], [88.82709503, 22.71079063], [88.82634735, 22.71083069], [88.82556915, 22.71083641], [88.82479858, 22.71083641], [88.82404327, 22.71083069], [88.82330322, 22.71083069], [88.82257843, 22.71083069], [88.82040405, 22.71083069], [88.819664, 22.71083069], [88.81893158, 22.71083641], [88.81822205, 22.71083641], [88.81752777, 22.71083069], [88.8168869, 22.71078682], [88.81632233, 22.71060371], [88.8157959, 22.71055794], [88.81532288, 22.71055794], [88.81489563, 22.71055222], [88.8144989, 22.71052742], [88.81411743, 22.71039391], [88.81367493, 22.71029854], [88.81315613, 22.71024513], [88.81259918, 22.71012306], [88.81202698, 22.71006966], [88.81143951, 22.71019554], [88.81090546, 22.71025848], [88.81041718, 22.71030617], [88.80998993, 22.71043587], [88.8095932, 22.71067047], [88.80925751, 22.71108437], [88.80905151, 22.71166801], [88.80913544, 22.71227074], [88.80926514, 22.71286964], [88.80944061, 22.71335983], [88.8095932, 22.7137661], [88.80970001, 22.71410751], [88.80973053, 22.71443748], [88.80978394, 22.71474648], [88.80994415, 22.71500206], [88.81002045, 22.71534157], [88.81015778, 22.71569633], [88.81036377, 22.71608353], [88.8104248, 22.71652031], [88.81049347, 22.71695137], [88.81057739, 22.71743965], [88.81072235, 22.71795464], [88.81084442, 22.71849251], [88.81095886, 22.71904564], [88.81098938, 22.7196331], [88.81098175, 22.72035408], [88.81091309, 22.7210331], [88.81082153, 22.72165489], [88.81069183, 22.72223473], [88.81058502, 22.72283936], [88.81054688, 22.72345161], [88.81049347, 22.72402191], [88.81033325, 22.72449303], [88.8102417, 22.72498894], [88.81010437, 22.72547722], [88.81002045, 22.72602081], [88.80996704, 22.72658348], [88.80982971, 22.72710228], [88.80966187, 22.72752762], [88.80937195, 22.72783852], [88.80899811, 22.72813988], [88.80865479, 22.72852325], [88.8083725, 22.72900963], [88.80813599, 22.72959328], [88.80799866, 22.7302494], [88.80801392, 22.73091888], [88.80789948, 22.73151207], [88.80764771, 22.73211288], [88.80745697, 22.73277092], [88.80755615, 22.73348236], [88.80771637, 22.73412323], [88.80789948, 22.73468208], [88.80819702, 22.73516464], [88.80854797, 22.73558426], [88.80887604, 22.7360096], [88.80918121, 22.73643303], [88.80950165, 22.73683548], [88.80982971, 22.73719788], [88.81014252, 22.73753548], [88.81038666, 22.73789787], [88.81058502, 22.73827171], [88.8108139, 22.73860741], [88.81100464, 22.73897743], [88.81112671, 22.73941612], [88.81125641, 22.73987579], [88.81138611, 22.74036217], [88.81150818, 22.74087715], [88.8115921, 22.74144363], [88.81158447, 22.74206161], [88.8115387, 22.74269485], [88.81145477, 22.74327278], [88.81139374, 22.74381638], [88.81131744, 22.74432182], [88.8111496, 22.74476051], [88.81100464, 22.74518776], [88.8108139, 22.74555397], [88.81059265, 22.74589729], [88.81040955, 22.74628639], [88.81025696, 22.74671555], [88.81008148, 22.7471714], [88.80992126, 22.74766541], [88.8097229, 22.7481308], [88.80952454, 22.74855614], [88.80934906, 22.74894524], [88.80915833, 22.74926186], [88.8089447, 22.74955177], [88.80875397, 22.74987411], [88.80866241, 22.75027084], [88.80871582, 22.75067711], [88.80908203, 22.75113678], [88.80960846, 22.7515049], [88.81021881, 22.75171852], [88.81087494, 22.7517662], [88.81150055, 22.75164223], [88.81203461, 22.75136948], [88.81256104, 22.75110435], [88.81314087, 22.75090218], [88.81375885, 22.75076294], [88.81436157, 22.75055885], [88.81495667, 22.7503643], [88.81557465, 22.75022507], [88.81619263, 22.75006676], [88.81686401, 22.74998665], [88.81752014, 22.74987411], [88.81804657, 22.74958038], [88.81832886, 22.7490139], [88.81829071, 22.74820137], [88.81802368, 22.74761772], [88.81755066, 22.74728203], [88.81702423, 22.74700928], [88.81651306, 22.7467556], [88.81608582, 22.74648476], [88.81568146, 22.74623871], [88.81528473, 22.74598885], [88.81488037, 22.745718], [88.81438446, 22.74549294], [88.81389618, 22.74523735], [88.81345367, 22.74489784], [88.81309509, 22.74448586], [88.81284332, 22.74403763], [88.81271362, 22.74358559], [88.81263733, 22.74317551], [88.81270599, 22.74279213], [88.81284332, 22.74242592], [88.81305695, 22.74209976], [88.81331635, 22.74173927], [88.81360626, 22.74132347], [88.81396484, 22.74090767], [88.81446075, 22.74057961], [88.81502533, 22.74032211], [88.81563568, 22.74014854], [88.81623077, 22.73991966], [88.81689453, 22.73974419], [88.81758881, 22.7396183], [88.8183136, 22.7394886], [88.81905365, 22.73942757], [88.81978607, 22.73934364], [88.82049561, 22.73921394], [88.82118225, 22.73912811], [88.82180023, 22.73900414], [88.82235718, 22.7388401], [88.82286072, 22.73866081], [88.82335663, 22.73853493], [88.82379913, 22.73836708], [88.82422638, 22.73823929], [88.82461548, 22.73809624], [88.82500458, 22.73798561], [88.82536316, 22.73779678], [88.82574463, 22.73763275], [88.82618713, 22.73753548], [88.82666016, 22.73749733], [88.82713318, 22.73745537], [88.8276062, 22.73737907], [88.82810211, 22.7373867], [88.82860565, 22.73756027], [88.82897186, 22.73777008], [88.82918549, 22.73796082], [88.82936859, 22.73820305], [88.82959747, 22.73853493], [88.82983398, 22.73895073], [88.83003998, 22.7393589], [88.83021545, 22.7396946], [88.83034515, 22.73999977], [88.83050537, 22.7402668], [88.83065796, 22.74054527], [88.83082581, 22.74083519], [88.83100891, 22.74115562], [88.83119202, 22.74150276], [88.83141327, 22.74184608], [88.83164215, 22.74219131], [88.83189392, 22.74253654], [88.83215332, 22.74289894], [88.83242035, 22.74331474], [88.83254242, 22.74379921], [88.83271027, 22.74428558], [88.83296204, 22.74471092], [88.83321381, 22.74508858], [88.83349609, 22.74535942], [88.83383942, 22.74550247], [88.83422852, 22.74545288], [88.83457184, 22.7451992], [88.83481598, 22.74479485], [88.83492279, 22.74431992], [88.83491516, 22.74382973], [88.83486938, 22.7433567], [88.83493805, 22.74291039], [88.83499908, 22.74246407], [88.83507538, 22.74202156], [88.83518219, 22.74158478], [88.83526611, 22.74113655], [88.83533478, 22.74068642], [88.83538818, 22.7402153], [88.83546448, 22.73969078], [88.83562469, 22.73919868], [88.83579254, 22.73877144], [88.83592224, 22.7383709], [88.83608246, 22.73800659], [88.83620453, 22.7376461], [88.83633423, 22.73731613], [88.83647919, 22.73701668], [88.83665466, 22.73673248], [88.83686829, 22.73644829], [88.83712769, 22.73615074], [88.8374176, 22.73583031], [88.83782196, 22.7355442], [88.83833313, 22.73530006], [88.83886719, 22.73507881], [88.8394165, 22.73494148], [88.83999634, 22.73497772], [88.84054565, 22.73508644], [88.84101105, 22.73529243], [88.84138489, 22.73554993], [88.84169769, 22.73582268], [88.84199524, 22.73612785], [88.84230042, 22.73646736], [88.84255219, 22.73689651], [88.84280396, 22.73735237], [88.84305573, 22.73780632], [88.84329224, 22.73824883], [88.8434906, 22.73869705], [88.84365082, 22.73918343], [88.84382629, 22.73968315], [88.84396362, 22.74022865], [88.84416199, 22.74074745], [88.84437561, 22.74123383], [88.84468079, 22.74164009], [88.84497833, 22.74200439], [88.84524536, 22.74236679], [88.84546661, 22.74274635], [88.84563446, 22.74319649], [88.84575653, 22.74369621], [88.84600067, 22.74400902], [88.84642792, 22.74409294], [88.84684753, 22.74399185], [88.84712982, 22.74404907], [88.84685516, 22.74447441], [88.84663391, 22.74508858], [88.84664154, 22.74564934], [88.84684753, 22.74607468], [88.84705353, 22.74650764], [88.84725952, 22.74693489], [88.84749603, 22.74733162], [88.84774017, 22.7477169], [88.8479538, 22.74811363], [88.8481369, 22.74851418], [88.84833527, 22.74890137], [88.848526, 22.74933624], [88.84861755, 22.74988747], [88.84851074, 22.75048256], [88.84822845, 22.75098991], [88.84780121, 22.75138664], [88.8473053, 22.75174141], [88.84666443, 22.75198936], [88.84599304, 22.75225639], [88.8453064, 22.7525177], [88.84459686, 22.75252342], [88.8438797, 22.75252724], [88.84317017, 22.75258827], [88.84252167, 22.75274849], [88.84192657, 22.75291252], [88.84146881, 22.75314713], [88.84102631, 22.7532711], [88.8405304, 22.75326729], [88.84001923, 22.75327873], [88.83948517, 22.75332451], [88.83895111, 22.75341988], [88.83846283, 22.75353813], [88.83802032, 22.75363731], [88.83760071, 22.75375938], [88.83715057, 22.75388336], [88.83670044, 22.75396538], [88.83624268, 22.75392342], [88.83578491, 22.75391197], [88.83528137, 22.75388908], [88.83499908, 22.75416756], [88.83416748, 22.75416756], [88.83388519, 22.75444412], [88.83305359, 22.75444412], [88.83249664, 22.75388908], [88.83305359, 22.75333595], [88.83333588, 22.75333595], [88.83378601, 22.75312996], [88.83424377, 22.75302315], [88.8347168, 22.75290871], [88.83519745, 22.75279617], [88.8356781, 22.7526989], [88.83614349, 22.7525692], [88.83663177, 22.75251961], [88.83711243, 22.7524929], [88.83758545, 22.75243568], [88.83802032, 22.75226784], [88.83849335, 22.75206566], [88.8390274, 22.75187111], [88.83963013, 22.75167465], [88.8403244, 22.75149918], [88.84101868, 22.75141525], [88.84169769, 22.75132561], [88.84236145, 22.75119591], [88.84303284, 22.75112343], [88.84372711, 22.75106621], [88.8444519, 22.75102806], [88.8451767, 22.75097466], [88.84585571, 22.75084877], [88.84643555, 22.75057411], [88.84680939, 22.75013924], [88.84690857, 22.74961662], [88.84681702, 22.74913979], [88.84664154, 22.74874687], [88.84645844, 22.74841118], [88.84629822, 22.74810791], [88.84613037, 22.7478466], [88.84594727, 22.74761009], [88.84573364, 22.74737358], [88.84548187, 22.74709892], [88.84522247, 22.7467556], [88.84498596, 22.74632454], [88.84474945, 22.74585915], [88.84449005, 22.74539757], [88.84423065, 22.74494362], [88.8440094, 22.74450111], [88.84382629, 22.74407578], [88.84365082, 22.74368477], [88.84350586, 22.74329948], [88.84333801, 22.74294472], [88.8431778, 22.74262047], [88.8431015, 22.74230957], [88.84303284, 22.74202538], [88.84291077, 22.7417717], [88.84278107, 22.74150276], [88.84262848, 22.74118996], [88.84248352, 22.74077415], [88.8423233, 22.74030495], [88.8421936, 22.7397728], [88.84202576, 22.73925209], [88.84178162, 22.7387867], [88.84151459, 22.7383976], [88.84133148, 22.73793221], [88.84119415, 22.73747063], [88.84107971, 22.73705482], [88.84094238, 22.73670959], [88.84081268, 22.73640251], [88.84066772, 22.73613167], [88.84052277, 22.73589516], [88.84031677, 22.73571968], [88.83999634, 22.73564339], [88.83965302, 22.73573685], [88.8392868, 22.73599052], [88.83888245, 22.73635864], [88.83841705, 22.73679543], [88.83797455, 22.73729897], [88.83763885, 22.73784828], [88.83739471, 22.7384243], [88.83717346, 22.73901176], [88.8369751, 22.73963737], [88.83680725, 22.74027252], [88.83675385, 22.74094582], [88.8367691, 22.74156189], [88.83683777, 22.74208832], [88.83681488, 22.74259949], [88.83670807, 22.74310112], [88.8366394, 22.74361229], [88.83670807, 22.74414635], [88.83666229, 22.74461365], [88.83650208, 22.74500465], [88.83633423, 22.74538994], [88.83613586, 22.74578285], [88.83592987, 22.74620056], [88.83560181, 22.74654007], [88.83515167, 22.74677849], [88.83457947, 22.74690247], [88.83393097, 22.74696541], [88.83345032, 22.74686813], [88.83304596, 22.74672127], [88.83264923, 22.74657249], [88.83227539, 22.74630928], [88.83195496, 22.74594307], [88.83168793, 22.74555397], [88.83142853, 22.74522018], [88.83113861, 22.7449398], [88.83084869, 22.74463081], [88.83060455, 22.74417305], [88.83036804, 22.74377251], [88.83017731, 22.74343109], [88.83005524, 22.74311256], [88.82996368, 22.74279213], [88.82984924, 22.74246025], [88.82971954, 22.74209023], [88.82958221, 22.74168205], [88.82939148, 22.74131393], [88.82920074, 22.74091148], [88.8290329, 22.74045944], [88.82878113, 22.73996925], [88.8283844, 22.73943901], [88.82791138, 22.73893929], [88.82750702, 22.73872185], [88.82713318, 22.73870277], [88.8266449, 22.73871994], [88.82617188, 22.73885536], [88.82569122, 22.73903084], [88.82514191, 22.7392025], [88.8245697, 22.73945045], [88.82395935, 22.73976135], [88.82336426, 22.74010658], [88.82274628, 22.7402935], [88.82217407, 22.74045753], [88.82164764, 22.74059868], [88.82115173, 22.74074745], [88.82064056, 22.74081612], [88.82012177, 22.74085045], [88.8196106, 22.74090767], [88.81911469, 22.74103546], [88.81861877, 22.74113655], [88.81812286, 22.74124718], [88.81762695, 22.74136925], [88.81711578, 22.74146461], [88.81661987, 22.74162865], [88.81610107, 22.74175835], [88.81565094, 22.74196053], [88.81523895, 22.7421627], [88.81488037, 22.74233818], [88.8146286, 22.74260521], [88.81453705, 22.7430687], [88.81472015, 22.74375343], [88.8151474, 22.74425697], [88.81567383, 22.74456215], [88.81620789, 22.7447834], [88.81671906, 22.74490166], [88.8172226, 22.74492455], [88.81769562, 22.74516869], [88.81816864, 22.74545479], [88.81858826, 22.74580574], [88.81895447, 22.74619484], [88.81928253, 22.74658966], [88.81960297, 22.74693108], [88.81987762, 22.7472477], [88.82009125, 22.7475605], [88.82029724, 22.74786377], [88.82043457, 22.74827385], [88.82045746, 22.74881554], [88.82028198, 22.74937248], [88.81993103, 22.74986458], [88.8194809, 22.75029182], [88.81899261, 22.75065613], [88.8184433, 22.75089264], [88.81793976, 22.7511158], [88.81747437, 22.75131226], [88.81698608, 22.75141525], [88.81652069, 22.75153923], [88.8160553, 22.75169182], [88.81559753, 22.75187492], [88.81511688, 22.75204659], [88.81465912, 22.75226784], [88.8141861, 22.75248528], [88.8136673, 22.75267601], [88.81311035, 22.75283051], [88.81256866, 22.75305748], [88.81202698, 22.75331116], [88.81143188, 22.75354195], [88.81078339, 22.75367928], [88.81014252, 22.7536335], [88.80951691, 22.75356483], [88.80891418, 22.75343132], [88.80838013, 22.75314713], [88.80806732, 22.75283051], [88.80784607, 22.75244522], [88.80760956, 22.75199318], [88.80744171, 22.7516861], [88.80730438, 22.75140572], [88.80715942, 22.75103569], [88.80702209, 22.75067329], [88.80699921, 22.75024605], [88.80708313, 22.74978065], [88.80725098, 22.7493248], [88.80744171, 22.74887276], [88.80753326, 22.74838448], [88.80765533, 22.74790382], [88.80779266, 22.7474308], [88.80796814, 22.74697685], [88.80819702, 22.74658394], [88.8085022, 22.74632072], [88.80876923, 22.74605751], [88.80901337, 22.74578667], [88.80923462, 22.74549294], [88.80941772, 22.74518776], [88.80957794, 22.74489021], [88.80970001, 22.7446003], [88.80982208, 22.74432945], [88.80993652, 22.74404907], [88.81001282, 22.74369621], [88.80999756, 22.74316597], [88.80995178, 22.74253654], [88.81001282, 22.74188614], [88.81000519, 22.74125862], [88.80988312, 22.74074173], [88.80969238, 22.74034691], [88.80948639, 22.74004173], [88.80930328, 22.73974609], [88.80912018, 22.73945618], [88.8088913, 22.73917961], [88.80867004, 22.73888206], [88.80852509, 22.7385273], [88.80825806, 22.73835182], [88.80801392, 22.73817062], [88.80779266, 22.73797417], [88.80760193, 22.73775291], [88.80744171, 22.73750114], [88.80722809, 22.73725891], [88.80702972, 22.73695946], [88.8068924, 22.7365818], [88.80684662, 22.73634529], [88.80671692, 22.73606682], [88.80660248, 22.73568916], [88.80641937, 22.73533821], [88.80622864, 22.73502541], [88.80609131, 22.7347126], [88.80599213, 22.73438454], [88.80586243, 22.7340374], [88.80580139, 22.73363686], [88.80577087, 22.73320007], [88.8057785, 22.73275948], [88.80578613, 22.73234367], [88.80580139, 22.73194885], [88.80583954, 22.73151207], [88.80594635, 22.73101234], [88.80609894, 22.73045921], [88.8062439, 22.72988701], [88.80638885, 22.7293644], [88.80654144, 22.72891045], [88.80670929, 22.72852325], [88.80693054, 22.72819328], [88.80716705, 22.72782135], [88.80741882, 22.72740364], [88.80764771, 22.72689629], [88.8080368, 22.72638321], [88.80882263, 22.72538185], [88.80918121, 22.72444153], [88.80882263, 22.72310066], [88.80875397, 22.72089195], [88.80839539, 22.71867943], [88.80776215, 22.71636391], [88.80771637, 22.71594429], [88.80760193, 22.71551704], [88.80751801, 22.71502113], [88.80750275, 22.7144413], [88.80749512, 22.71379089], [88.80750275, 22.71309471], [88.80753326, 22.71238518], [88.80765533, 22.71170807], [88.80778503, 22.71114731], [88.80799103, 22.71072197], [88.80821991, 22.71035385], [88.80845642, 22.70998192], [88.80873108, 22.709692], [88.80901337, 22.70946312], [88.80934143, 22.70929146], [88.80973053, 22.7091465], [88.810112, 22.7089901], [88.81056213, 22.70890617], [88.8110199, 22.70884895], [88.81142426, 22.70869637], [88.81184387, 22.70855141], [88.81224823, 22.70837784], [88.81268311, 22.70833397], [88.81311798, 22.70833015], [88.8135376, 22.70833397], [88.81394958, 22.7083683], [88.81435394, 22.70849037], [88.81479645, 22.70852089], [88.81526184, 22.70838737], [88.81572723, 22.7083683], [88.81617737, 22.70850754], [88.81667328, 22.70859718], [88.81723022, 22.70865631], [88.81778717, 22.70884323], [88.81835938, 22.7088871], [88.81894684, 22.70889282], [88.81952667, 22.70889282], [88.82010651, 22.70889282], [88.82069397, 22.70889282], [88.82128143, 22.70889282], [88.82186127, 22.70887566], [88.82243347, 22.70879173], [88.82299042, 22.70864487], [88.82354736, 22.70861244], [88.82411194, 22.70863152], [88.8246994, 22.7087307], [88.82536316, 22.70877266], [88.8259964, 22.70863152], [88.82662964, 22.70850754], [88.82724762, 22.70833778], [88.8278656, 22.70818138], [88.82848358, 22.70804977], [88.82910156, 22.70791435], [88.82974243, 22.7078228], [88.83040619, 22.70776176], [88.83106995, 22.7076664], [88.83171082, 22.70752335], [88.83235168, 22.70743179], [88.83291626, 22.70720863], [88.83345032, 22.70697212], [88.83403778, 22.70682144], [88.83469391, 22.70665741], [88.83531189, 22.70648193], [88.83587646, 22.70635414], [88.83634186, 22.70620537], [88.83674622, 22.70613289], [88.83711243, 22.70617104], [88.83747101, 22.70631218], [88.83776855, 22.70623779], [88.83808136, 22.70612907], [88.8384552, 22.70607376], [88.83885956, 22.70599556], [88.83927917, 22.70599556], [88.83969116, 22.70611763], [88.84009552, 22.70628166], [88.8405304, 22.70620918], [88.84094238, 22.70614243], [88.84133148, 22.70621681], [88.84175873, 22.70635033], [88.84222412, 22.70638847], [88.84270477, 22.70642471], [88.84317017, 22.70654488], [88.84358978, 22.70664406], [88.84400177, 22.70667076], [88.8443985, 22.70666695], [88.8454361, 22.70675278], [88.84593964, 22.70675278], [88.84651947, 22.70668602], [88.84701538, 22.70668602], [88.84723663, 22.70654869], [88.84759521, 22.70567894], [88.84780884, 22.70420647], [88.84736633, 22.70208168], [88.84724426, 22.7015667], [88.84716034, 22.70105934], [88.84698486, 22.70062828], [88.84688568, 22.70017052], [88.84670258, 22.69975853], [88.84661102, 22.69928932], [88.84648132, 22.69885063], [88.84638977, 22.6984024], [88.84631348, 22.6979599], [88.84622192, 22.69752312], [88.84613037, 22.69708061], [88.84611511, 22.69659042], [88.84610748, 22.69608116], [88.84609222, 22.69556618], [88.84607697, 22.69507408], [88.84605408, 22.69462585], [88.84605408, 22.69422722], [88.84608459, 22.69386101], [88.84614563, 22.69350433], [88.84628296, 22.69317627], [88.84644318, 22.69285965], [88.84663391, 22.6925869], [88.8467865, 22.69229317], [88.8469696, 22.69203377], [88.84720612, 22.69182205], [88.847435, 22.69161415], [88.84767914, 22.69137383], [88.8479538, 22.6911087], [88.84828186, 22.69083214], [88.84866333, 22.69056129], [88.84906769, 22.69032478], [88.84950256, 22.69019508], [88.8498764, 22.69003868], [88.85024261, 22.68995476], [88.85054016, 22.6897831], [88.85085297, 22.68972778], [88.85119629, 22.68971825], [88.85154724, 22.68971443], [88.85189819, 22.6896801], [88.85225677, 22.68958473], [88.85262299, 22.6895504], [88.8529892, 22.6896801], [88.85341644, 22.68981743], [88.85386658, 22.68997192], [88.85438538, 22.69009972], [88.8549118, 22.69030952], [88.85542297, 22.69061089], [88.85591125, 22.69101334], [88.85643768, 22.69136238], [88.85695648, 22.69167519], [88.85743713, 22.69195938], [88.85787201, 22.69223022], [88.85823059, 22.69251442], [88.85853577, 22.69280815], [88.8588028, 22.6931324], [88.85906219, 22.6934948], [88.85944366, 22.69376183], [88.85985565, 22.69400787], [88.8603363, 22.69421959], [88.86082458, 22.69434929], [88.86128235, 22.69419479], [88.8615799, 22.69374275], [88.86162567, 22.6931076], [88.86153412, 22.69243431], [88.86135864, 22.69179535], [88.86112976, 22.69124794], [88.86090088, 22.69075775], [88.86071777, 22.69028282], [88.86051941, 22.68982506], [88.86027527, 22.68936729], [88.86001587, 22.68887901], [88.8598175, 22.68834686], [88.8596344, 22.68782043], [88.85943604, 22.6873455], [88.85923767, 22.68688011], [88.85913086, 22.68626785], [88.85897827, 22.68561172], [88.85890198, 22.68489647], [88.85884094, 22.68416214], [88.85868835, 22.68351555], [88.85858154, 22.68295479], [88.85861206, 22.68277931], [88.85805511, 22.68222046], [88.85805511, 22.68166924], [88.85778046, 22.68139267], [88.85778046, 22.68027687], [88.85749817, 22.68000221], [88.85757446, 22.67948723], [88.85749817, 22.67944527], [88.85749817, 22.67833519], [88.85722351, 22.67805862], [88.85722351, 22.67749977], [88.85749817, 22.6772213], [88.85749817, 22.67611122], [88.85805511, 22.67555618], [88.85805511, 22.67527962], [88.85861206, 22.67472267], [88.85861206, 22.6744442], [88.85916901, 22.67389107], [88.85916901, 22.67361259], [88.85944366, 22.67333412], [88.85972595, 22.67333412], [88.86006927, 22.67283058], [88.86045074, 22.67232323], [88.8608017, 22.67179108], [88.86105347, 22.67120171], [88.86109161, 22.67054176], [88.86101532, 22.66991615], [88.86094666, 22.66935158], [88.86103058, 22.66880226], [88.86095428, 22.66830254], [88.86089325, 22.66781616], [88.8609848, 22.66732979], [88.86108398, 22.66686058], [88.86112976, 22.6663723], [88.8612442, 22.66592026], [88.86151123, 22.66559792], [88.86186981, 22.66533852], [88.86222076, 22.66501808], [88.86256409, 22.66465759], [88.86293793, 22.66430092], [88.86334991, 22.66399384], [88.86378479, 22.66374779], [88.86426544, 22.66359329], [88.86473083, 22.66344452], [88.86521149, 22.66329765], [88.86567688, 22.66311073], [88.86620331, 22.66307259], [88.86673737, 22.66314125], [88.86727905, 22.66328239], [88.86785889, 22.66332626], [88.86841583, 22.66333771], [88.86894226, 22.66333199], [88.86946106, 22.66333199], [88.87001801, 22.66334724], [88.87062836, 22.66342735], [88.8712616, 22.6636219], [88.87187958, 22.66385841], [88.87245178, 22.66403961], [88.87295532, 22.66425514], [88.87368011, 22.66448212], [88.8743515, 22.66480064], [88.87480164, 22.66470528], [88.87538147, 22.6646862], [88.87595367, 22.66465759], [88.8764267, 22.66475487], [88.87683105, 22.66493416], [88.87728119, 22.66499519], [88.87773132, 22.66500282], [88.87817383, 22.66500854], [88.87858582, 22.66506004], [88.87898254, 22.66514778], [88.87937164, 22.66525078], [88.87980652, 22.66527748], [88.88024139, 22.66527748], [88.8806839, 22.6652813], [88.8811264, 22.66531563], [88.88153076, 22.66545486], [88.88191986, 22.6655674], [88.88232422, 22.66571617], [88.8828125, 22.66586113], [88.88331604, 22.66607285], [88.88388062, 22.66622734], [88.88444519, 22.66636086], [88.88500214, 22.6664238], [88.88549042, 22.66657829], [88.88594818, 22.66669655], [88.88635254, 22.66689491], [88.88674927, 22.66705513], [88.88704681, 22.66723824], [88.88729095, 22.66743279], [88.88757324, 22.66759491], [88.88795471, 22.66781425], [88.88840485, 22.6681118], [88.88896942, 22.66841125], [88.88957977, 22.6687336], [88.89021301, 22.66900063], [88.89071655, 22.66929436], [88.89111328, 22.66944695], [88.89138794, 22.66944695], [88.89167023, 22.66972351], [88.89194489, 22.66972351], [88.89221954, 22.67000008], [88.89250183, 22.67000008], [88.89389038, 22.67138863], [88.89416504, 22.67138863], [88.89527893, 22.67250252], [88.89555359, 22.67250252], [88.89611053, 22.67305565], [88.89613342, 22.67328644], [88.896492, 22.67357826], [88.89691162, 22.67386818], [88.89730072, 22.67418098], [88.8976059, 22.67450905], [88.89794922, 22.67468452], [88.89820862, 22.67490578], [88.89855957, 22.67504692], [88.89894104, 22.67527199], [88.89937592, 22.67554665], [88.89984131, 22.67581367], [88.90032959, 22.67604256], [88.90083313, 22.67622375], [88.90133667, 22.67639351], [88.90184784, 22.67655373], [88.90236664, 22.67664146], [88.90287018, 22.67666054], [88.90330505, 22.67673302], [88.90381622, 22.67669868], [88.90432739, 22.6768856], [88.9048233, 22.67712975], [88.90535736, 22.67720985], [88.90592957, 22.6772213], [88.90654755, 22.67718124], [88.90717316, 22.67701721], [88.90781403, 22.67683983], [88.9083252, 22.6764431], [88.90888977, 22.67611122], [88.91000366, 22.67500114], [88.91027832, 22.67500114], [88.91110992, 22.67416573], [88.91110992, 22.67389107], [88.91139221, 22.67361259], [88.91139221, 22.67277718], [88.91222382, 22.67194557], [88.91222382, 22.6716671], [88.91249847, 22.67138863], [88.91249847, 22.67111206], [88.91278076, 22.67083549], [88.91278076, 22.67055702], [88.91305542, 22.67027855], [88.91336823, 22.66973305], [88.91375732, 22.66929436], [88.91411591, 22.66883469], [88.91442108, 22.6683445], [88.91467285, 22.66786766], [88.91498566, 22.66752815], [88.91527557, 22.66722679], [88.91555023, 22.66693878], [88.91582489, 22.66662025], [88.91610718, 22.66626549], [88.91638947, 22.66588783], [88.91666412, 22.66552544], [88.91691589, 22.6651783], [88.91714478, 22.66481018], [88.91740417, 22.6644249], [88.91768646, 22.66399384], [88.91801453, 22.66353607], [88.91833496, 22.66302681], [88.91867065, 22.66249657], [88.91898346, 22.66195107], [88.91928101, 22.66141319], [88.91956329, 22.66090202], [88.91976929, 22.66039467], [88.9200058, 22.65996742], [88.9202652, 22.65961647], [88.92047882, 22.65928841], [88.92059326, 22.6588726], [88.92071533, 22.65843964], [88.92090607, 22.65798378], [88.92113495, 22.65747833], [88.92138672, 22.65694618], [88.92149353, 22.65683937], [88.92166901, 22.6566658], [88.92166901, 22.65639114], [88.92193604, 22.65611267], [88.92193604, 22.65556145], [88.92250061, 22.65500259], [88.92250061, 22.65472031], [88.92277527, 22.65444374], [88.92277527, 22.65389061], [88.92305756, 22.65361023], [88.92305756, 22.65332985], [88.92333221, 22.65305519], [88.92336273, 22.65273285], [88.92359924, 22.65225029], [88.92386627, 22.65174484], [88.92410278, 22.65123177], [88.92440033, 22.65081215], [88.92459106, 22.65041161], [88.92472076, 22.65028191], [88.92472076, 22.64999962], [88.92582703, 22.64888954], [88.92582703, 22.64861107], [88.92610931, 22.6483326], [88.92610931, 22.64805794], [88.9263916, 22.64777946], [88.9263916, 22.64750099], [88.92666626, 22.64722252], [88.92666626, 22.64666939], [88.92694092, 22.64639091], [88.92694092, 22.64611244], [88.9283371, 22.64472008], [88.9283371, 22.64444351], [88.92861176, 22.64416695], [88.92861176, 22.64333344], [88.92889404, 22.64292526], [88.9291687, 22.64245033], [88.92947388, 22.64199448], [88.92977142, 22.64161873], [88.9298172, 22.6415329], [88.93010712, 22.64099312], [88.93025208, 22.64038277], [88.92997742, 22.63967133], [88.92979431, 22.6389904], [88.92977142, 22.63832283], [88.92985535, 22.63767052], [88.9299469, 22.63702202], [88.92999268, 22.63634109], [88.93002319, 22.63567162], [88.9300766, 22.63504028], [88.9302063, 22.63447952], [88.93026733, 22.63393974], [88.93035126, 22.63342094], [88.93050385, 22.63290215], [88.93054962, 22.6323185], [88.93055725, 22.63169289], [88.93054962, 22.63105392], [88.93054962, 22.63043022], [88.93055725, 22.62979126], [88.93060303, 22.62911034], [88.93070221, 22.62841034], [88.93078613, 22.6277523], [88.9307785, 22.62713623], [88.93081665, 22.62654114], [88.93083191, 22.6260128], [88.93083954, 22.62553978], [88.93087769, 22.62508965], [88.93106079, 22.62466431], [88.93110657, 22.62421417], [88.9311142, 22.62376213], [88.93110657, 22.6233139], [88.9311142, 22.62288475], [88.93110657, 22.62248421], [88.9311142, 22.62210655], [88.93113708, 22.62174034], [88.93122864, 22.62138176], [88.93138123, 22.62088394], [88.93156433, 22.62034988], [88.93190002, 22.61985207], [88.93222809, 22.6192894], [88.93255615, 22.6187439], [88.93299103, 22.61833], [88.93338013, 22.61800957], [88.93372345, 22.61779022], [88.93401337, 22.61765099], [88.93424225, 22.61752129], [88.93447113, 22.61744118], [88.93470001, 22.61728287], [88.93499756, 22.61718178], [88.93525696, 22.61700249], [88.93559265, 22.61691093], [88.93591309, 22.61676216], [88.93630219, 22.61663818], [88.93673706, 22.61644173], [88.93730164, 22.6162529], [88.93791962, 22.61613274], [88.93858337, 22.6160717], [88.93917847, 22.61593056], [88.93975067, 22.61606789], [88.94011688, 22.61609459], [88.94030762, 22.61611176], [88.9408493, 22.61611366], [88.94139099, 22.61611366], [88.94193268, 22.61611366], [88.94245148, 22.61611176], [88.94291687, 22.61611176], [88.94332886, 22.61613274], [88.94368744, 22.61621284], [88.94406891, 22.61636162], [88.94451141, 22.61643028], [88.94496918, 22.61660385], [88.94551086, 22.61667061], [88.9460907, 22.61665154], [88.9466629, 22.61668205], [88.94718933, 22.61678886], [88.94770813, 22.61693192], [88.94819641, 22.61709023], [88.94867706, 22.61728287], [88.94915009, 22.61744118], [88.94967651, 22.61744118], [88.95018005, 22.61761284], [88.950737, 22.61763191], [88.95128632, 22.61770058], [88.95282745, 22.61795235], [88.95476532, 22.61795044], [88.95498657, 22.61796951], [88.95627594, 22.61808777], [88.95728302, 22.61788368], [88.95777893, 22.61741447], [88.95792389, 22.61694527], [88.95800018, 22.61647987], [88.95804596, 22.61597252], [88.95806122, 22.61539268], [88.95804596, 22.61478233], [88.95802307, 22.61412239], [88.95800018, 22.61351204], [88.95797729, 22.61288261], [88.95788574, 22.61221886], [88.95778656, 22.61150169], [88.95771027, 22.61078072], [88.9574585, 22.61020088], [88.95709229, 22.60976982], [88.95664978, 22.60944939], [88.95623016, 22.60917091], [88.95578766, 22.60889244], [88.95533752, 22.60861015], [88.95504761, 22.60841942], [88.95490265, 22.60832024], [88.95448303, 22.6079998], [88.95404816, 22.60767174], [88.95359039, 22.60739326], [88.95310211, 22.60714149], [88.95263672, 22.60684967], [88.9522171, 22.60655022], [88.95181274, 22.60625267], [88.95139313, 22.60597038], [88.95101929, 22.60575294], [88.95070648, 22.60556221], [88.95044708, 22.60546112], [88.95027924, 22.60527992], [88.94999695, 22.60527992], [88.94972229, 22.60500145], [88.94944763, 22.60500145], [88.94917297, 22.60473061], [88.94889069, 22.60473061], [88.94869995, 22.60453606], [88.9486084, 22.6044445], [88.9484024, 22.60416031], [88.94800568, 22.60386848], [88.94760895, 22.60349083], [88.94719696, 22.6031208], [88.9467926, 22.6027813], [88.94642639, 22.60247231], [88.94613647, 22.60217094], [88.94591522, 22.60186386], [88.945755, 22.60149956], [88.94547272, 22.60121346], [88.94507599, 22.60099411], [88.94473267, 22.60064125], [88.94439697, 22.6002636], [88.94393921, 22.59999275], [88.94346619, 22.59973335], [88.94300079, 22.59949303], [88.94252777, 22.59929085], [88.9420929, 22.59905052], [88.94165802, 22.59885979], [88.94126129, 22.59861565], [88.94087982, 22.59837151], [88.94052887, 22.59807014], [88.94020844, 22.59774208], [88.93995667, 22.59732056], [88.93966675, 22.59690285], [88.93930817, 22.59652138], [88.93894958, 22.59614182], [88.93855286, 22.59583092], [88.93817902, 22.595541], [88.93782806, 22.5952301], [88.93751526, 22.59490776], [88.9372406, 22.59457207], [88.93701935, 22.59422493], [88.93687439, 22.59383965], [88.93667603, 22.59348106], [88.9365387, 22.59308052], [88.93636322, 22.59267235], [88.93611908, 22.59225273], [88.93593597, 22.59175301], [88.93579865, 22.59116173], [88.93560791, 22.59055138], [88.93553925, 22.58987999], [88.93553925, 22.58922958], [88.93553925, 22.58865166], [88.93556213, 22.58818436], [88.93561554, 22.58778954], [88.93570709, 22.58741188], [88.93580627, 22.58698845], [88.93582153, 22.58648109], [88.93578339, 22.58588219], [88.93569183, 22.58524323], [88.9356308, 22.58458138], [88.93569946, 22.58392525], [88.9357605, 22.5832901], [88.93578339, 22.58270073], [88.93579102, 22.58217621], [88.93579865, 22.58171272], [88.93582153, 22.58125114], [88.93582916, 22.58076286], [88.93586731, 22.58024216], [88.93601227, 22.57974434], [88.93617249, 22.57925606], [88.93634033, 22.57884026], [88.93637085, 22.57845688], [88.93637085, 22.5781498], [88.93657684, 22.57782555], [88.93663788, 22.57759285], [88.9366684, 22.57727051], [88.9367218, 22.57692146], [88.93683624, 22.57655144], [88.9369278, 22.57612038], [88.93694305, 22.57569122], [88.93694305, 22.57526207], [88.93696594, 22.57484245], [88.9370575, 22.57443047], [88.93717194, 22.57403374], [88.93723297, 22.57359505], [88.93731689, 22.57316017], [88.93741608, 22.57270813], [88.93747711, 22.57222176], [88.93754578, 22.57170486], [88.93770599, 22.57122993], [88.93775177, 22.57078171], [88.93768311, 22.57038116], [88.93760681, 22.56993294], [88.9370575, 22.56965637], [88.9362793, 22.56969452], [88.93559265, 22.56964493], [88.93495178, 22.56950188], [88.93431854, 22.56939125], [88.93370056, 22.56921959], [88.93312073, 22.56917953], [88.93257904, 22.56921959], [88.93209076, 22.56941032], [88.93158722, 22.56957054], [88.93106842, 22.56959915], [88.93057251, 22.5694294], [88.93013763, 22.56921959], [88.92973328, 22.56906128], [88.92935944, 22.56894112], [88.92900848, 22.56886292], [88.92868042, 22.56871033], [88.92832947, 22.56866455], [88.92796326, 22.56873322], [88.92761993, 22.56864738], [88.92730713, 22.56862068], [88.92701721, 22.56859016], [88.92671204, 22.56850243], [88.92639923, 22.56837463], [88.92605591, 22.56833839], [88.92569733, 22.56833076], [88.92533875, 22.56833458], [88.92495728, 22.56833458], [88.92458344, 22.56833458], [88.92424011, 22.56833076], [88.92395782, 22.56833839], [88.9236908, 22.56834793], [88.92339325, 22.56835365], [88.92305756, 22.56833076], [88.92269897, 22.56841087], [88.92229462, 22.56854439], [88.92194366, 22.56833458], [88.92082977, 22.56833458], [88.92055511, 22.5680542], [88.91999054, 22.5680027], [88.91951752, 22.56807137], [88.91916656, 22.56805992], [88.91860962, 22.56802177], [88.91831207, 22.56796265], [88.91802216, 22.5678196], [88.91771698, 22.56770134], [88.91747284, 22.56749916], [88.91720581, 22.5672493], [88.91689301, 22.56698227], [88.91655731, 22.56673431], [88.91616821, 22.56657028], [88.91581726, 22.5664196], [88.91542053, 22.56633949], [88.91506195, 22.56621361], [88.91467285, 22.56620216], [88.91426849, 22.5663147], [88.91382599, 22.56629181], [88.91342163, 22.56617165], [88.91333008, 22.56611061], [88.91221619, 22.56611061], [88.91194153, 22.56583214], [88.91166687, 22.56583595], [88.91139221, 22.56555748], [88.91110992, 22.56556129], [88.91091156, 22.56535339], [88.9108429, 22.56528473], [88.90972137, 22.56528473], [88.90944672, 22.56556129], [88.90859985, 22.56556129], [88.90833282, 22.56528473], [88.90805054, 22.56516075], [88.90766907, 22.5652523], [88.90719604, 22.56522942], [88.90670013, 22.56507111], [88.90614319, 22.56496239], [88.90559387, 22.56479836], [88.90500641, 22.56472969], [88.90441895, 22.56469727], [88.90383148, 22.56456947], [88.90320587, 22.56434631], [88.90252686, 22.56419945], [88.90184021, 22.5641613], [88.90118408, 22.56412315], [88.90061188, 22.56397057], [88.90009308, 22.5639019], [88.89958954, 22.56388855], [88.89911652, 22.56389046], [88.89868164, 22.56385994], [88.89823914, 22.56376648], [88.89775848, 22.56366539], [88.89726257, 22.56357002], [88.89683533, 22.56340218], [88.89666748, 22.56333351], [88.89638519, 22.56333351], [88.89620209, 22.5631485], [88.89611053, 22.56305504], [88.89583588, 22.56306458], [88.89554596, 22.56278038], [88.89527893, 22.56278038], [88.89472198, 22.56221962], [88.89444733, 22.56222343], [88.89416504, 22.56194496], [88.89389038, 22.56194496], [88.89333344, 22.56138992], [88.89305878, 22.56139183], [88.89289093, 22.5612011], [88.89260101, 22.56093025], [88.89225769, 22.56064987], [88.89198303, 22.5603199], [88.89176178, 22.55994987], [88.89160919, 22.55956078], [88.89141083, 22.55923843], [88.89125061, 22.55891228], [88.89111328, 22.55888748], [88.89111328, 22.5580616], [88.88916779, 22.55611229], [88.8888855, 22.55611229], [88.88871002, 22.55594063], [88.88857269, 22.55580521], [88.88822937, 22.55553246], [88.88786316, 22.55525017], [88.88754272, 22.55495262], [88.88722229, 22.55462265], [88.88690948, 22.5543232], [88.88656616, 22.55404663], [88.88626862, 22.55373955], [88.8860321, 22.55339241], [88.88582611, 22.55307198], [88.88565063, 22.55278206], [88.88546753, 22.55252647], [88.88524628, 22.55228996], [88.88500977, 22.55204201], [88.88474274, 22.55175209], [88.88445282, 22.55138969], [88.88417053, 22.5510006], [88.88388824, 22.55055046], [88.88359833, 22.55013657], [88.88330841, 22.54974174], [88.88298798, 22.54940987], [88.88263702, 22.54911995], [88.88230133, 22.54883194], [88.88199615, 22.54849052], [88.88172913, 22.54811859], [88.88146973, 22.54776192], [88.88118744, 22.54743195], [88.88088989, 22.54713058], [88.88057709, 22.54686165], [88.88024902, 22.54662323], [88.87992859, 22.54637337], [88.8796463, 22.54600334], [88.87942505, 22.54562187], [88.87923431, 22.54528236], [88.87870026, 22.54473686], [88.87854767, 22.5446434], [88.878479, 22.54460526], [88.87834167, 22.54453087], [88.87798309, 22.54453468], [88.8777771, 22.5447216], [88.8769455, 22.5447216], [88.87638855, 22.54416656], [88.87555695, 22.54417229], [88.87526703, 22.54445076], [88.875, 22.54444885], [88.87472534, 22.5447216], [88.87473297, 22.54499817], [88.87444305, 22.54528236], [88.87444305, 22.54555893], [88.87388611, 22.54611397], [88.8730545, 22.54611397], [88.87277985, 22.54583549], [88.87249756, 22.54583549], [88.8722229, 22.54555511], [88.87180328, 22.54597473], [88.87166595, 22.54611397], [88.8713913, 22.54583549], [88.8713913, 22.5447216], [88.87083435, 22.54416656], [88.87055206, 22.54416656], [88.87000275, 22.5447216], [88.87000275, 22.54499817], [88.86916351, 22.54583549], [88.86888885, 22.54583549], [88.86759186, 22.54453659], [88.86694336, 22.54388618], [88.86667633, 22.54388809], [88.8658371, 22.54306221], [88.8658371, 22.54194069], [88.86694336, 22.54083252], [88.86722565, 22.54083443], [88.86750031, 22.54055405], [88.86750031, 22.5402813], [88.86734772, 22.54018021], [88.86720276, 22.53979492], [88.86712646, 22.53931236], [88.86712646, 22.53884315], [88.8670578, 22.53804016], [88.86663055, 22.53709984], [88.86634064, 22.53562164], [88.86598206, 22.5339489], [88.86612701, 22.5334816], [88.86612701, 22.53254128], [88.86598206, 22.53167152], [88.86569214, 22.53046417], [88.86598206, 22.52859306], [88.86669922, 22.5261097], [88.86698914, 22.52510262], [88.8670578, 22.52342987], [88.86659241, 22.52303123], [88.86614227, 22.52274132], [88.86569977, 22.52252579], [88.86524963, 22.52235222], [88.8647995, 22.52222252], [88.86435699, 22.52211189], [88.86395264, 22.52198219], [88.86353302, 22.52190208], [88.86315155, 22.52176857], [88.86279297, 22.52163124], [88.86245728, 22.52140999], [88.86206818, 22.52124596], [88.86167145, 22.52111244], [88.86128235, 22.52099037], [88.8609314, 22.52086067], [88.86057281, 22.52073097], [88.86023712, 22.52055168], [88.85991669, 22.52033043], [88.85958099, 22.52011299], [88.85929108, 22.51982307], [88.85904694, 22.51950264], [88.8588028, 22.51920128], [88.85855103, 22.51890182], [88.85832977, 22.51855278], [88.85813141, 22.51814842], [88.85803986, 22.51766014], [88.85795593, 22.51716614], [88.85780334, 22.51672173], [88.85766602, 22.51628685], [88.85752869, 22.51587105], [88.85740662, 22.51547432], [88.85727692, 22.51508522], [88.85720062, 22.5146904], [88.85710144, 22.51433945], [88.85697937, 22.51403618], [88.85688019, 22.51371193], [88.85674286, 22.51342583], [88.85662079, 22.51309395], [88.85639191, 22.51277733], [88.85639191, 22.51166725], [88.85527802, 22.5105629], [88.85500336, 22.5105629], [88.85472107, 22.51028252], [88.85415649, 22.51028252], [88.85388947, 22.51000023], [88.85360718, 22.51000023], [88.85333252, 22.51028252], [88.85292816, 22.51020622], [88.85260773, 22.51031113], [88.85244751, 22.51036263], [88.85196686, 22.51031303], [88.85146332, 22.51029015], [88.85096741, 22.51028252], [88.85045624, 22.51027107], [88.84996033, 22.51023293], [88.84947968, 22.51007462], [88.84900665, 22.50994492], [88.84860229, 22.5097599], [88.84818268, 22.5096035], [88.84771729, 22.50946999], [88.84728241, 22.50936317], [88.84686279, 22.50927162], [88.84644318, 22.50938225], [88.84610748, 22.50962257], [88.8458252, 22.50979805], [88.84551239, 22.5098362], [88.84522247, 22.50975609], [88.84492493, 22.50956154], [88.84456635, 22.50930977], [88.84417725, 22.50904655], [88.84381866, 22.50875282], [88.84347534, 22.50850677], [88.84316254, 22.50834465], [88.84281158, 22.50787354], [88.84259796, 22.50720406], [88.84266663, 22.50639915], [88.84295654, 22.50486183], [88.84323883, 22.50339317], [88.84365845, 22.50204277], [88.84460449, 22.50090408], [88.84648132, 22.50040245], [88.84689331, 22.50028038], [88.84725189, 22.50016975], [88.84752655, 22.50002289], [88.84777832, 22.4999485], [88.84803772, 22.49996948], [88.84829712, 22.50004005], [88.84855652, 22.50016975], [88.84884644, 22.50025177], [88.84915924, 22.5003109], [88.84942627, 22.50041008], [88.84976959, 22.50040627], [88.85019684, 22.50045967], [88.85073853, 22.50052071], [88.85138702, 22.50053978], [88.8520813, 22.50055122], [88.85273743, 22.50055122], [88.85330963, 22.50055122], [88.85381317, 22.50055122], [88.85428619, 22.50053024], [88.85484314, 22.50045967], [88.85546875, 22.50042152], [88.85614777, 22.50048447], [88.85652161, 22.50045395], [88.85683441, 22.50042534], [88.85749054, 22.50013161], [88.85782623, 22.49988174], [88.85816193, 22.49963188], [88.85884857, 22.49915123], [88.85929108, 22.49872017], [88.85948181, 22.49823189], [88.85965729, 22.49775124], [88.85977173, 22.49722862], [88.85993958, 22.49673271], [88.86003876, 22.49616051], [88.8602066, 22.49558067], [88.86032867, 22.4949398], [88.86053467, 22.49432564], [88.86075592, 22.49370193], [88.86102295, 22.49316025], [88.86129761, 22.49269295], [88.86152649, 22.49218941], [88.861763, 22.49166298], [88.86199188, 22.49114227], [88.86226654, 22.49067879], [88.86258698, 22.49029922], [88.86295319, 22.48999214], [88.86329651, 22.48965263], [88.86364746, 22.48929024], [88.86408234, 22.48893356], [88.86460876, 22.48858643], [88.86508179, 22.48814201], [88.86524963, 22.4875164], [88.86519623, 22.48687172], [88.86483002, 22.48635292], [88.86421204, 22.48613548], [88.86360168, 22.48602486], [88.86310577, 22.48590469], [88.8625946, 22.48587227], [88.86203766, 22.48591423], [88.86143494, 22.48585892], [88.86083221, 22.48577309], [88.86029816, 22.48555374], [88.85980225, 22.48533249], [88.85931396, 22.48516273], [88.85889435, 22.48489761], [88.85848999, 22.48459053], [88.85810852, 22.48428345], [88.85777283, 22.48393822], [88.85749054, 22.48358917], [88.85726166, 22.4832325], [88.85713196, 22.48278999], [88.85710144, 22.48229599], [88.85704803, 22.48180008], [88.85695648, 22.48130226], [88.85687256, 22.48076439], [88.85671997, 22.48020363], [88.85667419, 22.47961426], [88.85666656, 22.47904778], [88.85666656, 22.47853279], [88.85666656, 22.47805977], [88.85666656, 22.47762108], [88.85666656, 22.4771595], [88.85668945, 22.47665977], [88.8567276, 22.47614288], [88.85681152, 22.47564125], [88.85666656, 22.47500038], [88.85639191, 22.47500038], [88.85610962, 22.47472191], [88.85582733, 22.47472191], [88.85555267, 22.47500038], [88.85527802, 22.47500038], [88.85500336, 22.47527885], [88.85444641, 22.47527885], [88.85432434, 22.47515488], [88.85416412, 22.47500038], [88.85333252, 22.47500038], [88.85305786, 22.47527885], [88.8527832, 22.47527122], [88.85250092, 22.47556114], [88.85166931, 22.47556114], [88.85111237, 22.47500038], [88.8527832, 22.47332954], [88.85277557, 22.47305489], [88.85333252, 22.47250175], [88.85333252, 22.4719429], [88.85361481, 22.47166634], [88.85360718, 22.47139168], [88.85388947, 22.47110939], [88.85388947, 22.47083473], [88.85444641, 22.47027779], [88.85444641, 22.47000122], [88.85472107, 22.46972275], [88.85472107, 22.4691658], [88.85500336, 22.46889114], [88.85500336, 22.46833038], [88.85472107, 22.46805573], [88.85472107, 22.46778107], [88.85444641, 22.46750069], [88.85444641, 22.46500206], [88.85472107, 22.46471977], [88.85472107, 22.46333313], [88.85444641, 22.46305847], [88.85444641, 22.46277618], [88.85388947, 22.46222115], [88.85388947, 22.46194458], [88.85333252, 22.46138954], [88.85333252, 22.46027184], [88.85305786, 22.45999908], [88.85305786, 22.45944023], [88.85277557, 22.45916748], [88.8527832, 22.45889091], [88.85250092, 22.45861244], [88.85250092, 22.45833015], [88.85277557, 22.4580555], [88.8527832, 22.45694351], [88.85194397, 22.45611382], [88.85194397, 22.45583534], [88.85221863, 22.45583534], [88.85277557, 22.4552784], [88.8527832, 22.45417023], [88.85305786, 22.45389175], [88.85333252, 22.45389175], [88.85360718, 22.45417023], [88.85444641, 22.45500183], [88.85472107, 22.45500183], [88.85500336, 22.45471954], [88.85527802, 22.45471954], [88.85555267, 22.45444679], [88.85555267, 22.45416832], [88.85582733, 22.45389175], [88.85582733, 22.45361137], [88.85610962, 22.4533329], [88.85610962, 22.45278168], [88.85582733, 22.4525013], [88.85740662, 22.45121384], [88.85775757, 22.45080566], [88.85807037, 22.45037079], [88.85838318, 22.44992256], [88.85864258, 22.44942474], [88.85887146, 22.44891167], [88.85904694, 22.44841194], [88.85914612, 22.44790459], [88.85920715, 22.44746017], [88.85933685, 22.44708061], [88.85942078, 22.44667244], [88.85948944, 22.44617462], [88.85961914, 22.44557381], [88.85961151, 22.44482994], [88.85939789, 22.44413185], [88.85904694, 22.44354057], [88.85862732, 22.4430275], [88.85817719, 22.4425602], [88.85772705, 22.44215393], [88.85729218, 22.44176483], [88.85681152, 22.44144249], [88.85629272, 22.44119072], [88.85575867, 22.44101143], [88.85527802, 22.44081116], [88.85486603, 22.44054985], [88.85452271, 22.44025993], [88.85423279, 22.43993187], [88.85398865, 22.4395504], [88.8537674, 22.43914986], [88.8535614, 22.43872261], [88.85334015, 22.4383049], [88.85314941, 22.43784142], [88.85307312, 22.43735313], [88.85305023, 22.43690109], [88.8530426, 22.43653297], [88.8530426, 22.43622017], [88.8530426, 22.4359436], [88.85305023, 22.43567467], [88.85305023, 22.43540001], [88.8530426, 22.43510246], [88.85299683, 22.43477058], [88.85298157, 22.43425179], [88.85312653, 22.43360329], [88.85306549, 22.43326759], [88.85292816, 22.43303108], [88.8527298, 22.43289185], [88.85244751, 22.43283272], [88.8520813, 22.43287086], [88.8516922, 22.4329319], [88.85131073, 22.43303108], [88.85093689, 22.4331913], [88.8505249, 22.43333435], [88.8500824, 22.43349838], [88.84962463, 22.4336586], [88.84916687, 22.43386269], [88.84872437, 22.4340744], [88.84828949, 22.43432045], [88.84792328, 22.43456078], [88.84752655, 22.43473816], [88.84711456, 22.4348774], [88.84672546, 22.43499947], [88.84632111, 22.43510437], [88.84591675, 22.43528938], [88.84552002, 22.43550301], [88.84509277, 22.43562126], [88.84464264, 22.43570137], [88.84428406, 22.43583298], [88.84393311, 22.43595314], [88.84348297, 22.43597221], [88.84291077, 22.43591118], [88.84218597, 22.43600273], [88.8414917, 22.43617058], [88.84088898, 22.4364109], [88.84039307, 22.43660164], [88.83985901, 22.43671989], [88.83934784, 22.43694878], [88.83880615, 22.43717194], [88.83821869, 22.43722916], [88.83760834, 22.43725014], [88.83699799, 22.43732262], [88.8363266, 22.43725014], [88.83571625, 22.43722916], [88.8351593, 22.43721962], [88.83463287, 22.43717194], [88.83409119, 22.43699074], [88.83347321, 22.43690872], [88.83281708, 22.4367485], [88.8321991, 22.4366703], [88.83162689, 22.43660927], [88.83114624, 22.43647194], [88.83067322, 22.4364109], [88.8302002, 22.43621254], [88.82964325, 22.43613243], [88.82901001, 22.43602943], [88.82836151, 22.43588257], [88.82766724, 22.43573952], [88.82692719, 22.43560982], [88.8261795, 22.4356041], [88.82550049, 22.4356823], [88.82496643, 22.43586159], [88.82453156, 22.43611908], [88.8241272, 22.43659019], [88.82411194, 22.43728065], [88.82444763, 22.43782425], [88.82485962, 22.43827248], [88.82533264, 22.43861198], [88.82585144, 22.43885422], [88.82637024, 22.43921471], [88.82686615, 22.43965912], [88.82733154, 22.4401226], [88.82775879, 22.44054222], [88.82816315, 22.44095039], [88.82853699, 22.44138145], [88.82884979, 22.441782], [88.8290863, 22.44215012], [88.82935333, 22.44247246], [88.82946777, 22.44286156], [88.82962036, 22.44325066], [88.82969666, 22.44369316], [88.82971954, 22.44409752], [88.82971954, 22.44445229], [88.82971954, 22.44474983], [88.82971954, 22.44503212], [88.82971954, 22.44530296], [88.82971954, 22.44559288], [88.82972717, 22.44592094], [88.82971954, 22.44630623], [88.8296814, 22.44675255], [88.8295517, 22.44720268], [88.82930756, 22.44762802], [88.82900238, 22.44807243], [88.82866669, 22.44854927], [88.82828522, 22.44902229], [88.82782745, 22.44944191], [88.8273468, 22.44984245], [88.82688141, 22.45021248], [88.82639313, 22.45049286], [88.82594299, 22.45070076], [88.82553101, 22.45088005], [88.82520294, 22.45104027], [88.82480621, 22.45111847], [88.82434082, 22.45119286], [88.82382202, 22.45136833], [88.8232193, 22.45153618], [88.82264709, 22.45178413], [88.82203674, 22.45202255], [88.82145691, 22.45229149], [88.82092285, 22.45245552], [88.82035828, 22.45253181], [88.81987, 22.45267487], [88.81943512, 22.45287323], [88.81894684, 22.45299149], [88.81847382, 22.45314217], [88.81803894, 22.4533329], [88.81758881, 22.45355034], [88.81716156, 22.45389175], [88.81672668, 22.45423508], [88.81639099, 22.45444107], [88.81582642, 22.45500183], [88.8152771, 22.4552002], [88.81472015, 22.45555496], [88.81472015, 22.45583344], [88.81416321, 22.45639229], [88.81416321, 22.45666695], [88.81417847, 22.45694351], [88.81416321, 22.45723152], [88.81416321, 22.4580555], [88.8144455, 22.45833206], [88.8144455, 22.46138954], [88.81455231, 22.46160316], [88.81445313, 22.46199226], [88.8143692, 22.46233749], [88.81429291, 22.46273232], [88.81417847, 22.46317101], [88.81404877, 22.46368217], [88.81385803, 22.46418953], [88.81368256, 22.46471977], [88.81362152, 22.46531105], [88.81360626, 22.46587181], [88.81360626, 22.46638298], [88.81360626, 22.46689034], [88.81362915, 22.46746445], [88.81369781, 22.46812439], [88.81387329, 22.46882057], [88.8139801, 22.46956825], [88.8141098, 22.4702549], [88.81421661, 22.47089958], [88.81437683, 22.47147942], [88.81435394, 22.47197723], [88.81417084, 22.47235489], [88.81397247, 22.47267914], [88.81378174, 22.47310257], [88.81359863, 22.47354507], [88.81336975, 22.47401237], [88.81317902, 22.47453117], [88.81302643, 22.47508049], [88.81284332, 22.4755764], [88.81278229, 22.47604942], [88.81273651, 22.47647667], [88.81262207, 22.47686195], [88.81253815, 22.47731018], [88.81252289, 22.47784233], [88.81251526, 22.47838593], [88.8125, 22.47890282], [88.81244659, 22.47936058], [88.81228638, 22.47969246], [88.81218719, 22.48003387], [88.8120575, 22.48032951], [88.81194305, 22.48066139], [88.81176758, 22.48101234], [88.81156158, 22.48137856], [88.81128693, 22.4817524], [88.81093597, 22.48209953], [88.81051636, 22.48240662], [88.81000519, 22.48271179], [88.80945587, 22.48304939], [88.80887604, 22.48341942], [88.80840302, 22.48383141], [88.80800629, 22.48425102], [88.80770874, 22.48466492], [88.80739594, 22.48499107], [88.8070755, 22.48526573], [88.80671692, 22.48550987], [88.80639648, 22.48579979], [88.80605316, 22.48608971], [88.80562592, 22.48633003], [88.80523682, 22.48661232], [88.80484009, 22.48682976], [88.80446625, 22.4870491], [88.80403137, 22.48721123], [88.80353546, 22.48732567], [88.80304718, 22.48747253], [88.80258179, 22.48759842], [88.80216217, 22.48774147], [88.80171967, 22.48783493], [88.80130768, 22.48800087], [88.80082703, 22.48812294], [88.80039215, 22.48833275], [88.79995728, 22.48857117], [88.79956055, 22.48880386], [88.79923248, 22.4890995], [88.79889679, 22.48942757], [88.79857635, 22.48978233], [88.79833221, 22.49020195], [88.79812622, 22.49063301], [88.79806519, 22.49110794], [88.79802704, 22.49157143], [88.797966, 22.4920311], [88.79788208, 22.49245262], [88.79782867, 22.49289131], [88.79775238, 22.49331093], [88.79759979, 22.49363899], [88.79751587, 22.49394035], [88.79741669, 22.49422836], [88.79725647, 22.4944973], [88.79710388, 22.49484253], [88.79691315, 22.49521255], [88.79666138, 22.49559212], [88.79640198, 22.49602318], [88.79612732, 22.49645042], [88.7958374, 22.49684906], [88.79550171, 22.49723244], [88.79508209, 22.49762154], [88.79462433, 22.49804497], [88.79411316, 22.4984417], [88.79363251, 22.49885941], [88.79318237, 22.4992218], [88.79272461, 22.49955177], [88.79231262, 22.49989128], [88.79194641, 22.50020409], [88.79160309, 22.5004406], [88.79125214, 22.50065994], [88.79081726, 22.50085831], [88.79027557, 22.50109673], [88.78967285, 22.50129509], [88.78902435, 22.50143623], [88.78839874, 22.50159264], [88.78777313, 22.50164223], [88.78716278, 22.50167274], [88.78662872, 22.50175285], [88.7861557, 22.50192833], [88.78569031, 22.50208092], [88.7852478, 22.50225258], [88.78485107, 22.50247192], [88.78443909, 22.50266075], [88.78409576, 22.50281715], [88.78381348, 22.50306129], [88.78353882, 22.50333977], [88.7832489, 22.5036602], [88.78302765, 22.50405121], [88.78277588, 22.50444984], [88.78255463, 22.50488091], [88.78238678, 22.50538063], [88.78211212, 22.50579643], [88.78173828, 22.50618172], [88.78132629, 22.50661278], [88.78088379, 22.50702286], [88.78042603, 22.50743294], [88.77993774, 22.50777054], [88.77947998, 22.50805473], [88.77906799, 22.50831032], [88.77868652, 22.50855064], [88.77838135, 22.50883484], [88.77806091, 22.50909233], [88.77771759, 22.50937271], [88.77732849, 22.50965118], [88.77693939, 22.5099926], [88.77648926, 22.5103302], [88.77605438, 22.51071167], [88.7755661, 22.5110302], [88.77513123, 22.51137161], [88.77468872, 22.51166534], [88.77427673, 22.51194382], [88.77389526, 22.51219749], [88.77346039, 22.51237297], [88.77300262, 22.51255989], [88.77253723, 22.51279259], [88.77207947, 22.51305771], [88.77166748, 22.51338005], [88.77144623, 22.51387215], [88.77139282, 22.51443481], [88.77144623, 22.51498985], [88.77168274, 22.51548195], [88.77196503, 22.51592827], [88.7722702, 22.51633835], [88.77259827, 22.5167408], [88.77295685, 22.51712227], [88.77332306, 22.51746941], [88.77366638, 22.51777077], [88.77405548, 22.51802826], [88.77445221, 22.51830101], [88.77487946, 22.51857376], [88.77527618, 22.51889229], [88.77583313, 22.51889229], [88.77610779, 22.51917076], [88.77639008, 22.51916885], [88.77694702, 22.51972389], [88.77777863, 22.51971817], [88.77805328, 22.52000237], [88.77889252, 22.52000237], [88.77916718, 22.52028084], [88.78056335, 22.52028084], [88.78083038, 22.52057266], [88.78138733, 22.52057266], [88.78150177, 22.52057266], [88.78198242, 22.52065086], [88.7824173, 22.52086067], [88.78282166, 22.52115059], [88.78314209, 22.5214901], [88.78341675, 22.52182388], [88.78366852, 22.52211952], [88.78388214, 22.52239037], [88.78404999, 22.52264595], [88.78417206, 22.5229435], [88.78423309, 22.52329063], [88.78424835, 22.52367973], [88.78425598, 22.52404022], [88.78423309, 22.52437019], [88.78417206, 22.52470016], [88.78416443, 22.52499962], [88.78304291, 22.52616692], [88.78266907, 22.52631569], [88.78227234, 22.52643394], [88.78188324, 22.52660179], [88.78145599, 22.52667046], [88.78105164, 22.52674294], [88.77945709, 22.52663612], [88.77895355, 22.5265007], [88.7784729, 22.52649498], [88.77801514, 22.52658653], [88.77758026, 22.5265522], [88.77716827, 22.52643013], [88.77674866, 22.5263195], [88.77632141, 22.52620125], [88.77583313, 22.52617073], [88.77534485, 22.52625656], [88.77488708, 22.52643013], [88.77445221, 22.52668953], [88.77404022, 22.52700996], [88.77368164, 22.52742386], [88.77346802, 22.52791023], [88.77346039, 22.52844048], [88.77327728, 22.52905083], [88.77300262, 22.5296936], [88.77265167, 22.53024292], [88.77224731, 22.53067207], [88.77186584, 22.53105545], [88.77147675, 22.53137016], [88.77110291, 22.53162384], [88.77070618, 22.53175163], [88.7703476, 22.53195953], [88.76998138, 22.53219032], [88.76953125, 22.53237152], [88.76893616, 22.53249168], [88.76828766, 22.5325985], [88.76763916, 22.53281212], [88.76702881, 22.53307533], [88.76647949, 22.53337288], [88.76602173, 22.53374863], [88.76568604, 22.53424263], [88.76550293, 22.53484154], [88.76541138, 22.53541183], [88.76538086, 22.53590012], [88.76537323, 22.53627968], [88.76537323, 22.5365696], [88.76531982, 22.53683281], [88.7652359, 22.53711128], [88.76519012, 22.53745842], [88.76519012, 22.53790474], [88.76522064, 22.53842354], [88.76527405, 22.53899193], [88.76528931, 22.53957939], [88.76527405, 22.54017067], [88.76524353, 22.54074478], [88.76519012, 22.54129982], [88.76513672, 22.54185486], [88.76512146, 22.54239273], [88.76513672, 22.54291534], [88.76519775, 22.54343987], [88.76522827, 22.54395103], [88.76529694, 22.54440117], [88.76531219, 22.54482269], [88.76519012, 22.54525185], [88.76493073, 22.54568291], [88.76464844, 22.54607391], [88.76436615, 22.54643059], [88.7641449, 22.54682922], [88.76391602, 22.54723167], [88.76365662, 22.54763222], [88.76321411, 22.54801559], [88.76280212, 22.5484581], [88.76250458, 22.54886055], [88.7623291, 22.54924393], [88.76222992, 22.54964638], [88.76220703, 22.55005455], [88.7620697, 22.55051994], [88.76242828, 22.55139732], [88.76271057, 22.55186272], [88.76293182, 22.55213165], [88.76329803, 22.55240059], [88.76364899, 22.55266953], [88.76461792, 22.55389977], [88.76493073, 22.55457115], [88.76527405, 22.55515671], [88.76557922, 22.5557003], [88.76579285, 22.5561924], [88.76593781, 22.55657768], [88.76605225, 22.55692482], [88.76621246, 22.55727196], [88.76635742, 22.55768013], [88.76642609, 22.55816841], [88.76641083, 22.55874062], [88.7664032, 22.55931664], [88.76644897, 22.55972481], [88.76651001, 22.56007195], [88.76660919, 22.56041145], [88.76667023, 22.56055641], [88.76638794, 22.56083488], [88.76611328, 22.56083488], [88.76580811, 22.56061745], [88.76563263, 22.56033134], [88.76551056, 22.56003189], [88.76540375, 22.55960274], [88.76534271, 22.55910683], [88.76529694, 22.55856133], [88.76528168, 22.55799294], [88.76522064, 22.55748177], [88.76512146, 22.5570507], [88.7649765, 22.55669975], [88.76477814, 22.5564003], [88.76452637, 22.55610085], [88.76428223, 22.55529213], [88.7634201, 22.55441093], [88.76216125, 22.55289841], [88.76184082, 22.55241013], [88.76146698, 22.55194473], [88.76118469, 22.55138206], [88.76101685, 22.55076027], [88.7609787, 22.55014992], [88.76110077, 22.54967308], [88.76126099, 22.54930115], [88.76140594, 22.54897118], [88.76161957, 22.54864311], [88.7618866, 22.54827118], [88.76216888, 22.54787254], [88.76239777, 22.54746819], [88.76345062, 22.54589272], [88.7638092, 22.54455757], [88.76360321, 22.54297066], [88.7636795, 22.54247284], [88.76369476, 22.54190636], [88.76371002, 22.54129028], [88.7637558, 22.54065132], [88.76378632, 22.5400486], [88.76378632, 22.53947258], [88.76374054, 22.53894043], [88.7636261, 22.53843117], [88.76348877, 22.53794289], [88.76352692, 22.53746223], [88.76371002, 22.53700066], [88.76383209, 22.53655052], [88.76389313, 22.53613091], [88.76394653, 22.53572273], [88.76404572, 22.5352993], [88.76418304, 22.53484154], [88.76434326, 22.53434181], [88.76457214, 22.53389168], [88.76490021, 22.53355026], [88.76531982, 22.53325081], [88.76574707, 22.53294373], [88.76617432, 22.53257561], [88.76660919, 22.53219414], [88.76715088, 22.53188515], [88.7677536, 22.53164101], [88.76843262, 22.5314312], [88.76913452, 22.53120041], [88.76984406, 22.53091621], [88.7702713, 22.53056145], [88.7702713, 22.53000069], [88.76972198, 22.53000069], [88.76944733, 22.52972221], [88.76889038, 22.53028297], [88.76805878, 22.53028297], [88.76777649, 22.53056145], [88.76693726, 22.53056145], [88.76638794, 22.53111076], [88.76555634, 22.53111076], [88.76526642, 22.53083229], [88.76527405, 22.53055573], [88.7647171, 22.53000069], [88.7647171, 22.52972221], [88.76499939, 22.52972221], [88.76527405, 22.52944374], [88.76526642, 22.5291729], [88.7647171, 22.52861214], [88.7647171, 22.52832985], [88.76444244, 22.52805519], [88.76444244, 22.52778053], [88.76499939, 22.52721977], [88.76526642, 22.52721977], [88.76555634, 22.52750206], [88.76583099, 22.52750206], [88.76667023, 22.52833366], [88.76694489, 22.52833366], [88.76721954, 22.52861214], [88.76741028, 22.52842522], [88.76750183, 22.52833366], [88.76777649, 22.52833366], [88.76805878, 22.52805519], [88.76860809, 22.52806282], [88.76944733, 22.52889061], [88.7702713, 22.52889061], [88.77054596, 22.52861214], [88.77111053, 22.52861214], [88.7711792, 22.5286808], [88.77139282, 22.52889061], [88.77187347, 22.52846527], [88.77199554, 22.52835655], [88.77217865, 22.52798271], [88.77246094, 22.52744865], [88.77281189, 22.52695274], [88.77323914, 22.52650261], [88.77374268, 22.52604103], [88.77430725, 22.5255909], [88.77490997, 22.52518272], [88.77561188, 22.5249157], [88.77623749, 22.5249939], [88.77693176, 22.52513123], [88.77777863, 22.52528191], [88.77805328, 22.52528191], [88.7783432, 22.52499962], [88.77889252, 22.52499962], [88.78138733, 22.52528191], [88.78166962, 22.52499962], [88.78250122, 22.52499962], [88.78277588, 22.52472115], [88.78277588, 22.52277756], [88.7822113, 22.52222252], [88.78194427, 22.52222252], [88.78166962, 22.52194405], [88.78111267, 22.52194405], [88.78083038, 22.52166939], [88.78056335, 22.52166939], [88.77997589, 22.52164268], [88.77950287, 22.52145958], [88.77902222, 22.52131844], [88.77857208, 22.5211792], [88.77815247, 22.52109909], [88.77770233, 22.52104187], [88.77731323, 22.52094078], [88.77697754, 22.52091217], [88.77694702, 22.52083397], [88.77610779, 22.52083397], [88.77583313, 22.5205555], [88.77555847, 22.52057266], [88.77527618, 22.52028084], [88.77500153, 22.52028084], [88.77471924, 22.52000237], [88.7743988, 22.51976204], [88.77397919, 22.51950836], [88.7735672, 22.5192318], [88.77313995, 22.51893425], [88.77262115, 22.51864052], [88.77205658, 22.51833153], [88.77169037, 22.51789474], [88.77139282, 22.51743507], [88.77111816, 22.51701164], [88.77086639, 22.51659966], [88.77062988, 22.51617241], [88.77043152, 22.51569939], [88.77024078, 22.51519966], [88.77000427, 22.5147419], [88.76970673, 22.51428795], [88.76935577, 22.51385307], [88.76888275, 22.51359177], [88.76837921, 22.51343918], [88.76793671, 22.5135479], [88.76751709, 22.5136013], [88.76709747, 22.51361275], [88.76668549, 22.51361084], [88.76626587, 22.51361275], [88.76582336, 22.51363754], [88.76534271, 22.51369286], [88.76473999, 22.51366234], [88.76416779, 22.51370049], [88.7636261, 22.51384163], [88.76316071, 22.51389122], [88.76270294, 22.51390266], [88.76220703, 22.51391029], [88.76171112, 22.51395988], [88.76126099, 22.51411247], [88.76082611, 22.51419258], [88.76048279, 22.51429176], [88.76019287, 22.51443481], [88.75981903, 22.51453209], [88.75937653, 22.51466942], [88.75891113, 22.51479149], [88.75847626, 22.51488304], [88.75811005, 22.51502037], [88.7576828, 22.51518059], [88.75726318, 22.51531029], [88.7568512, 22.51553154], [88.75642395, 22.51568031], [88.75601196, 22.51584435], [88.75562286, 22.51601601], [88.75520325, 22.51614189], [88.75478363, 22.5163002], [88.75434875, 22.51642036], [88.75393677, 22.51659966], [88.75348663, 22.51675224], [88.75305176, 22.51690292], [88.75245667, 22.51693153], [88.7518692, 22.5168972], [88.7507782, 22.51696587], [88.75041962, 22.51696587], [88.7501297, 22.5168972], [88.7495575, 22.51664162], [88.74897766, 22.51629066], [88.74783325, 22.51609421], [88.74674988, 22.51602745], [88.74495697, 22.51575279], [88.74372101, 22.51543617], [88.74323273, 22.51534081], [88.74276733, 22.51530266], [88.74233246, 22.5152607], [88.74185944, 22.51519966], [88.74139404, 22.51504707], [88.74092865, 22.51485252], [88.74044037, 22.51466179], [88.73994446, 22.51450157], [88.73944855, 22.51433754], [88.73898315, 22.51418114], [88.73854828, 22.51400185], [88.73812103, 22.51384544], [88.73776245, 22.51366234], [88.73744965, 22.51346016], [88.73716736, 22.51322937], [88.73687744, 22.51297379], [88.73659515, 22.51268005], [88.73629761, 22.5123806], [88.73602295, 22.51205254], [88.73571014, 22.51173973], [88.73539734, 22.51146126], [88.7350769, 22.51125145], [88.73477936, 22.51106071], [88.73446655, 22.51095963], [88.73414612, 22.51091957], [88.73382568, 22.51094818], [88.73352051, 22.51106071], [88.73322296, 22.51128197], [88.73290253, 22.51156807], [88.73259735, 22.51192474], [88.73226929, 22.51230049], [88.73197937, 22.51272964], [88.73169708, 22.51316261], [88.73139191, 22.51357841], [88.73103333, 22.51395226], [88.73059845, 22.51431084], [88.73012543, 22.51470757], [88.72963715, 22.51511383], [88.72917938, 22.51553154], [88.72880554, 22.51592827], [88.72858429, 22.51633835], [88.72835541, 22.51670647], [88.72812653, 22.51707077], [88.72776794, 22.51735115], [88.72737885, 22.51764107], [88.72721863, 22.51806068], [88.72666931, 22.51805878], [88.72638702, 22.51833534], [88.72611237, 22.51833153], [88.72556305, 22.51889229], [88.72528076, 22.51889229], [88.72532654, 22.51903915], [88.7249527, 22.51892471], [88.72454071, 22.51893997], [88.72410583, 22.51907158], [88.72364807, 22.51933289], [88.72315979, 22.51958275], [88.72261047, 22.51971245], [88.72196198, 22.51979637], [88.7212677, 22.51989174], [88.72055054, 22.52003479], [88.71990967, 22.52029037], [88.71936035, 22.52066612], [88.71884155, 22.52119637], [88.71810913, 22.52138329], [88.71723938, 22.52234459], [88.71655273, 22.52272224], [88.71627045, 22.52372169], [88.71572876, 22.52418518], [88.71533203, 22.52471352], [88.71494293, 22.52523994], [88.7144928, 22.52571297], [88.71401215, 22.52610207], [88.7135849, 22.52642059], [88.71317291, 22.52670479], [88.7127533, 22.52695274], [88.71234131, 22.52715683], [88.71195221, 22.52728081], [88.71159363, 22.52745819], [88.71124268, 22.52767372], [88.71095276, 22.52803993], [88.71057129, 22.52850533], [88.7099762, 22.52885246], [88.70925903, 22.52907753], [88.70848846, 22.5290947], [88.70778656, 22.5289402], [88.70716095, 22.52882957], [88.70664215, 22.52867317], [88.7061615, 22.52858353], [88.70571136, 22.52844048], [88.70526886, 22.52831078], [88.70484924, 22.52817535], [88.70446014, 22.52802086], [88.70410919, 22.52783394], [88.70378113, 22.52765083], [88.70352173, 22.52740288], [88.70330811, 22.52710152], [88.70307159, 22.52676201], [88.70269012, 22.52638054], [88.7022934, 22.52601051], [88.70187378, 22.52577591], [88.7013855, 22.52555656], [88.70111084, 22.52555656], [88.70083618, 22.52583313], [88.70083618, 22.5261097], [88.70166779, 22.52694321], [88.70166779, 22.52721977], [88.70194244, 22.52750206], [88.70194244, 22.52778053], [88.70276642, 22.52861214], [88.70305634, 22.52861214], [88.70361328, 22.5291729], [88.70249939, 22.53028297], [88.7022171, 22.53028297], [88.70194244, 22.53056145], [88.70083618, 22.53056145], [88.70054626, 22.53028297], [88.69999695, 22.53028297], [88.69944763, 22.52972221], [88.6986084, 22.52972221], [88.69819641, 22.52930641], [88.69777679, 22.5288887], [88.69750214, 22.52889061], [88.69721985, 22.52861214], [88.6958313, 22.52861214], [88.69555664, 22.52889061], [88.69526672, 22.52889061], [88.69502258, 22.52863503], [88.69472504, 22.52833366], [88.69444275, 22.52833366], [88.69249725, 22.52638817], [88.6922226, 22.52638817], [88.69194794, 22.52611351], [88.69194794, 22.52555656], [88.69249725, 22.52499962], [88.69444275, 22.52499962], [88.69499969, 22.52555656], [88.69527435, 22.52555656], [88.6958313, 22.52611351], [88.6966629, 22.52611351], [88.69721985, 22.52555656], [88.69721985, 22.52499962], [88.69695282, 22.52472115], [88.69667053, 22.52463531], [88.69599152, 22.52451134], [88.69532776, 22.52441978], [88.69471741, 22.52431488], [88.69419861, 22.52419281], [88.69371796, 22.52406502], [88.69315338, 22.52396393], [88.69249725, 22.52392578], [88.69185638, 22.52394295], [88.69130707, 22.52402115], [88.69093323, 22.5241909], [88.6906662, 22.52441216], [88.69050598, 22.52474022], [88.69036865, 22.52510262], [88.69029999, 22.52552032], [88.69029236, 22.52594185], [88.69035339, 22.52636147], [88.69050598, 22.52672005], [88.69065094, 22.52711868], [88.6908493, 22.52745819], [88.69106293, 22.52779961], [88.69113922, 22.52825737], [88.69126129, 22.52877235], [88.69138336, 22.52931023], [88.6914978, 22.52987289], [88.6916275, 22.5304203], [88.69168091, 22.53098679], [88.69172668, 22.53156281], [88.69181824, 22.53212166], [88.69184113, 22.53264809], [88.69168091, 22.53309059], [88.69149017, 22.53350258], [88.69135284, 22.53383255], [88.69132996, 22.53405952], [88.69078064, 22.53458977], [88.69054413, 22.53461647], [88.69030762, 22.53470039], [88.69000244, 22.53481293], [88.68963623, 22.53495979], [88.68920898, 22.53508949], [88.6887207, 22.53526115], [88.68819427, 22.53544044], [88.68768311, 22.53565025], [88.68714905, 22.53586006], [88.68667603, 22.53604126], [88.686203, 22.53609848], [88.68578339, 22.53611374], [88.68544769, 22.53614807], [88.68427277, 22.53660774], [88.68312073, 22.53685951], [88.68234253, 22.53744316], [88.68214417, 22.53784561], [88.68202209, 22.53822136], [88.68205261, 22.5385685], [88.68218231, 22.53891945], [88.68234253, 22.53936386], [88.68254852, 22.53985023], [88.68283844, 22.54031944], [88.68309021, 22.54144287], [88.68314362, 22.54212189], [88.68300629, 22.54248238], [88.68279266, 22.54283333], [88.68255615, 22.54327202], [88.68226624, 22.54378128], [88.68192291, 22.54421043], [88.68154144, 22.54462242], [88.68110657, 22.54495049], [88.6805954, 22.54519272], [88.68003845, 22.54540062], [88.67948151, 22.54562569], [88.67887115, 22.54589272], [88.67823792, 22.54618263], [88.67758942, 22.54651642], [88.67698669, 22.54691124], [88.6763916, 22.54741096], [88.67592621, 22.54789162], [88.67553711, 22.54824829], [88.67517853, 22.54856491], [88.6738739, 22.54961967], [88.67359161, 22.55002213], [88.67359161, 22.55062294], [88.67366028, 22.55096245], [88.67405701, 22.55181313], [88.67408752, 22.55237007], [88.67410278, 22.55295944], [88.67403412, 22.55356026], [88.67389679, 22.55416489], [88.6736908, 22.55476952], [88.67346954, 22.55534172], [88.67325592, 22.55589104], [88.67311859, 22.55635262], [88.67308807, 22.55672264], [88.67311859, 22.55701828], [88.67325592, 22.55726051], [88.67353058, 22.55746269], [88.67388153, 22.55762672], [88.67424011, 22.55779076], [88.67459869, 22.55799294], [88.67494965, 22.55824661], [88.6753006, 22.55856895], [88.67565155, 22.55895042], [88.67595673, 22.55936813], [88.6762085, 22.55982018], [88.67639923, 22.5603199], [88.67646027, 22.56082916], [88.67640686, 22.56136131], [88.67625427, 22.56189156], [88.67597961, 22.56240463], [88.67565155, 22.56295967], [88.67529297, 22.56359291], [88.67495728, 22.56420326], [88.67469025, 22.5647583], [88.67450714, 22.56525993], [88.6743927, 22.56567955], [88.67429352, 22.56606102], [88.67423248, 22.5664196], [88.674263, 22.56674004], [88.67468262, 22.56750298], [88.67538452, 22.5683403], [88.67619324, 22.56945992], [88.67636871, 22.56994057], [88.67662811, 22.5703907], [88.67684937, 22.57085228], [88.67698669, 22.57127953], [88.67710876, 22.57162285], [88.67717743, 22.57196808], [88.67726135, 22.57235146], [88.67736053, 22.57288551], [88.67739105, 22.57338142], [88.67735291, 22.57386208], [88.67743683, 22.57430077], [88.67763519, 22.5746212], [88.6778717, 22.57480431], [88.67812347, 22.57480431], [88.67840576, 22.57459259], [88.6787262, 22.57442284], [88.67893219, 22.57438278], [88.67912292, 22.57459259], [88.67914581, 22.57505989], [88.67912292, 22.57573128], [88.67920685, 22.5763092], [88.67943573, 22.57672882], [88.67975616, 22.57702065], [88.68016052, 22.57717705], [88.68064117, 22.57722282], [88.68087006, 22.57738495], [88.68074036, 22.57775307], [88.68044281, 22.5782032], [88.68016052, 22.57864761], [88.67997742, 22.57917976], [88.67975616, 22.57969093], [88.67948914, 22.5802021], [88.67913055, 22.58071518], [88.67871857, 22.58123207], [88.67832947, 22.58177185], [88.67797089, 22.58226395], [88.67772675, 22.58272934], [88.67772675, 22.58326149], [88.67778015, 22.58361816], [88.67778015, 22.58389091], [88.67790985, 22.58423424], [88.67805481, 22.58444405], [88.67819214, 22.58472252], [88.6783371, 22.58499908], [88.67854309, 22.58527756], [88.67861176, 22.58556175], [88.67867279, 22.58577156], [88.67881775, 22.58592033], [88.67893982, 22.58640862], [88.67893219, 22.58700371], [88.67893219, 22.58764267], [88.67887115, 22.58820343], [88.67875671, 22.58867073], [88.67863464, 22.5891037], [88.67854309, 22.58961678], [88.67850494, 22.58994484], [88.67780304, 22.59082985], [88.67773438, 22.59134865], [88.677948, 22.59213066], [88.67824554, 22.59220505], [88.67841339, 22.59259224], [88.67822266, 22.59303093], [88.6783371, 22.59361076], [88.67749786, 22.59361076], [88.67740631, 22.59349823], [88.67716217, 22.5928936], [88.67696381, 22.59220695], [88.67681122, 22.59155083], [88.67677307, 22.59095955], [88.6767807, 22.5905056], [88.67688751, 22.59010124], [88.67700958, 22.58974266], [88.67713928, 22.5894413], [88.67729187, 22.58915138], [88.67749023, 22.58887672], [88.67772675, 22.58857155], [88.67797852, 22.58815956], [88.67813873, 22.58770943], [88.67811584, 22.58730125], [88.67798615, 22.58688164], [88.67780304, 22.58644295], [88.67758179, 22.58599281], [88.67740631, 22.58551979], [88.67723083, 22.58509254], [88.67706299, 22.58472252], [88.67692566, 22.58433342], [88.67678833, 22.5839901], [88.67662811, 22.58364105], [88.67642212, 22.58328056], [88.67617035, 22.58284187], [88.67666626, 22.58222198], [88.67666626, 22.58194542], [88.67722321, 22.58138847], [88.67722321, 22.58083153], [88.67762756, 22.58069038], [88.677948, 22.58040047], [88.6782608, 22.58008766], [88.67854309, 22.57976151], [88.67878723, 22.57938194], [88.67891693, 22.57891655], [88.67899323, 22.57840157], [88.67894745, 22.57790947], [88.67878723, 22.57748222], [88.67854309, 22.57716179], [88.67822266, 22.57685852], [88.6778717, 22.57657051], [88.67753601, 22.57625008], [88.67723083, 22.5759201], [88.67693329, 22.57557106], [88.67663574, 22.57523346], [88.67636871, 22.57492256], [88.67608643, 22.57472038], [88.67581177, 22.57472038], [88.67582703, 22.57443047], [88.67583466, 22.57111168], [88.67555237, 22.57073784], [88.67520905, 22.57060051], [88.6743927, 22.56944847], [88.67366791, 22.56884956], [88.6730423, 22.56791115], [88.67279816, 22.56733894], [88.6727066, 22.56677055], [88.67256927, 22.56626129], [88.67251587, 22.56576347], [88.67253113, 22.56530952], [88.67260742, 22.56490135], [88.67272186, 22.56453514], [88.67284393, 22.56419563], [88.67304993, 22.56387138], [88.67331696, 22.56348991], [88.67362213, 22.56303978], [88.67398834, 22.56257629], [88.67437744, 22.56212044], [88.67469788, 22.56163979], [88.67488861, 22.56113243], [88.67487335, 22.56060982], [88.67463684, 22.5601902], [88.67427063, 22.55987167], [88.67385101, 22.55962563], [88.67350006, 22.5593338], [88.67315674, 22.55906487], [88.6727829, 22.55888748], [88.67243958, 22.55867195], [88.67216492, 22.55817223], [88.67192078, 22.55765343], [88.6717453, 22.55716515], [88.67169952, 22.55668449], [88.67178345, 22.5562191], [88.67195129, 22.55573273], [88.67218781, 22.55521202], [88.67243958, 22.5546875], [88.6726532, 22.5540905], [88.67301941, 22.55363464], [88.67308807, 22.55323601], [88.67308807, 22.55290031], [88.67301941, 22.55236244], [88.67258453, 22.55169487], [88.67215729, 22.55068779], [88.67222595, 22.54944038], [88.67250061, 22.5494442], [88.67388916, 22.54805565], [88.67415619, 22.54805946], [88.67444611, 22.5477829], [88.67459106, 22.54735947], [88.6751709, 22.54693031], [88.67572021, 22.54650307], [88.67620087, 22.54612541], [88.67655182, 22.54578972], [88.67746735, 22.54509735], [88.67804718, 22.54483223], [88.67854309, 22.54463005], [88.67919159, 22.54443169], [88.67970276, 22.54429054], [88.68034363, 22.54416084], [88.68077087, 22.54396248], [88.68112946, 22.54369164], [88.68112946, 22.54302025], [88.68106079, 22.54289055], [88.68091583, 22.5425396], [88.68084717, 22.54221535], [88.68070221, 22.54141045], [88.68055725, 22.54074287], [88.68055725, 22.53947258], [88.68026733, 22.53806114], [88.68091583, 22.5363884], [88.68196869, 22.53563118], [88.68263245, 22.53536034], [88.68341064, 22.53516006], [88.68419647, 22.53503227], [88.68463135, 22.53489113], [88.68563843, 22.5346241], [88.68606567, 22.53442574], [88.68678284, 22.53442574], [88.6881485, 22.53429222], [88.68908691, 22.53402138], [88.68951416, 22.53388977], [88.68994904, 22.5333519], [88.69023132, 22.53294945], [88.69052124, 22.53241158], [88.69073486, 22.53181076], [88.69072723, 22.53094482], [88.6906662, 22.53059959], [88.69052124, 22.53046989], [88.69016266, 22.53046989], [88.68994904, 22.53087044], [88.68987274, 22.53101158], [88.68987274, 22.5320797], [88.68979645, 22.53222084], [88.68930054, 22.53222084], [88.68913269, 22.53156281], [88.68897247, 22.53102493], [88.68876648, 22.53046989], [88.68875122, 22.5301609], [88.68889618, 22.52997017], [88.68908691, 22.52972221], [88.68916321, 22.52935219], [88.68917084, 22.52892685], [88.68917084, 22.52847099], [88.68916321, 22.52800179], [88.68913269, 22.52753258], [88.68903351, 22.52708435], [88.68894958, 22.52666664], [88.68881989, 22.52532387], [88.68925476, 22.52404976], [88.69019318, 22.52298164], [88.69148254, 22.52238274], [88.69306183, 22.52257729], [88.6950531, 22.52317238], [88.69565582, 22.52327156], [88.69628143, 22.52331924], [88.69687653, 22.52340126], [88.69745636, 22.52351761], [88.69792175, 22.52341461], [88.69824982, 22.52318764], [88.69859314, 22.52312088], [88.69892883, 22.52324486], [88.6993866, 22.52331924], [88.69989014, 22.52347755], [88.70044708, 22.52364159], [88.70102692, 22.52388954], [88.7016449, 22.52417946], [88.70224762, 22.5245533], [88.70272827, 22.52508163], [88.70316315, 22.52564049], [88.70359802, 22.52609825], [88.70402527, 22.52647209], [88.7044754, 22.52675438], [88.70491028, 22.52705956], [88.7053833, 22.52731133], [88.70593262, 22.52752113], [88.70655823, 22.52766228], [88.70720673, 22.52773094], [88.70748901, 22.52771378], [88.70780182, 22.5276947], [88.70830536, 22.52756882], [88.70877075, 22.52744102], [88.709198, 22.52728081], [88.7096405, 22.52713776], [88.71008301, 22.52696037], [88.71051025, 22.52679062], [88.71092224, 22.52660179], [88.71137238, 22.52642822], [88.71185303, 22.52626991], [88.71230316, 22.52607346], [88.71272278, 22.52581596], [88.71305847, 22.52544212], [88.71327209, 22.5248394], [88.71341705, 22.52425194], [88.71360779, 22.5238018], [88.713974, 22.52350235], [88.71450806, 22.52321434], [88.71495819, 22.52284241], [88.71531677, 22.52243996], [88.71565247, 22.52204895], [88.71601868, 22.52169228], [88.71643066, 22.5213604], [88.71685028, 22.52099037], [88.7171936, 22.52052879], [88.71747589, 22.5200901], [88.71776581, 22.51973152], [88.7181015, 22.51945496], [88.7184906, 22.51926231], [88.71894836, 22.51913261], [88.71942902, 22.51902199], [88.71985626, 22.5188694], [88.72026825, 22.51873207], [88.72070313, 22.51855659], [88.72114563, 22.51839256], [88.72161865, 22.51830482], [88.72210693, 22.51832008], [88.72258759, 22.51841164], [88.72299194, 22.51836967], [88.72336578, 22.51826286], [88.72371674, 22.51807022], [88.72409821, 22.51787186], [88.72452545, 22.51768494], [88.72496033, 22.51745415], [88.72535706, 22.51714516], [88.72575378, 22.51679611], [88.72611237, 22.51641273], [88.72652435, 22.51606369], [88.7269516, 22.51570892], [88.72740173, 22.51535988], [88.72786713, 22.51498222], [88.72835541, 22.51458168], [88.72886658, 22.51418114], [88.72934723, 22.51377296], [88.72975922, 22.51333046], [88.73011017, 22.51291084], [88.73039246, 22.51250267], [88.73064423, 22.51211739], [88.73092651, 22.51173592], [88.73126984, 22.51140594], [88.73165131, 22.51111031], [88.73203278, 22.51082039], [88.73239899, 22.5105648], [88.73279572, 22.51033974], [88.73321533, 22.51016426], [88.73357391, 22.5099926], [88.7339325, 22.5098896], [88.73432922, 22.50987053], [88.73477936, 22.5098629], [88.73521423, 22.50983238], [88.73554993, 22.50975609], [88.7358017, 22.5097599], [88.73600006, 22.50989342], [88.73622894, 22.51024437], [88.73647308, 22.51070213], [88.73681641, 22.51115227], [88.73718262, 22.51161766], [88.73761749, 22.5120945], [88.73812103, 22.51252174], [88.73867035, 22.51286125], [88.73921204, 22.51309776], [88.73973846, 22.5132618], [88.74022675, 22.51338005], [88.74069214, 22.51353455], [88.7411499, 22.5136013], [88.74163055, 22.5136776], [88.74206543, 22.51383018], [88.74253082, 22.51395226], [88.74297333, 22.51410103], [88.74347687, 22.5142231], [88.7440033, 22.51440048], [88.74462128, 22.5146122], [88.74526215, 22.51493263], [88.7459259, 22.51493263], [88.74656677, 22.51494026], [88.74720764, 22.5148716], [88.74780273, 22.51481056], [88.74833679, 22.5148983], [88.7488327, 22.51493263], [88.74925995, 22.5150013], [88.74968719, 22.51514816], [88.75013733, 22.51534081], [88.75063324, 22.51549721], [88.7511673, 22.5155468], [88.7517395, 22.51555443], [88.75232697, 22.51555443], [88.75291443, 22.51552391], [88.75348663, 22.51540565], [88.75408173, 22.51529121], [88.75463867, 22.51518059], [88.75512695, 22.51497269], [88.75554657, 22.51472282], [88.7559433, 22.51444054], [88.75634003, 22.51418495], [88.75676727, 22.51398277], [88.75726318, 22.51385307], [88.75773621, 22.51363182], [88.75823975, 22.51342201], [88.75874329, 22.51319313], [88.75917816, 22.5129509], [88.75961304, 22.512743], [88.75998688, 22.51254082], [88.76040649, 22.51247025], [88.76077271, 22.51236153], [88.76111603, 22.51222038], [88.7614975, 22.51210213], [88.76190186, 22.51197815], [88.7623291, 22.51189995], [88.76275635, 22.51176834], [88.76321411, 22.51181412], [88.76361084, 22.51194572], [88.7638855, 22.51166725], [88.76499939, 22.51166725], [88.76526642, 22.51194382], [88.7654953, 22.51194382], [88.76596832, 22.51194954], [88.76611328, 22.51194954], [88.7665329, 22.51194954], [88.76715088, 22.51194382], [88.7678299, 22.5119133], [88.76850128, 22.51176834], [88.76911163, 22.5116024], [88.76965332, 22.51142311], [88.76999664, 22.51138878], [88.77027893, 22.51111031], [88.77054596, 22.51111031], [88.77083588, 22.51083374], [88.77111053, 22.51083565], [88.77138519, 22.51055717], [88.77159882, 22.51052284], [88.77210236, 22.51013184], [88.77271271, 22.50972366], [88.77334595, 22.50930977], [88.7740097, 22.50892067], [88.77468872, 22.50858116], [88.77527618, 22.50819016], [88.77585602, 22.50780487], [88.77645874, 22.50748825], [88.77703857, 22.50719261], [88.77754974, 22.50688171], [88.77799225, 22.50650215], [88.77842712, 22.50608444], [88.77883148, 22.50566483], [88.77916718, 22.50523949], [88.77941895, 22.50481987], [88.77958679, 22.50444984], [88.7797699, 22.50412178], [88.77990723, 22.50374794], [88.77999115, 22.50325203], [88.78011322, 22.50282288], [88.78009796, 22.50234413], [88.78000641, 22.50182152], [88.77988434, 22.50129509], [88.77971649, 22.50081062], [88.77955627, 22.50034332], [88.77945709, 22.4998436], [88.77939606, 22.49931145], [88.77931976, 22.49876976], [88.77922058, 22.49821281], [88.77916718, 22.49764061], [88.77916718, 22.49711609], [88.77916718, 22.49664116], [88.77916718, 22.49620247], [88.77916718, 22.49577141], [88.77916718, 22.49533272], [88.77916718, 22.49490738], [88.77921295, 22.49451256], [88.77935028, 22.49417114], [88.77944183, 22.49374199], [88.77953339, 22.49315071], [88.77973938, 22.49263763], [88.7800293, 22.492342], [88.78041077, 22.49206352], [88.78072357, 22.49177742], [88.78102112, 22.49148178], [88.78132629, 22.49115944], [88.78161621, 22.4908123], [88.78186035, 22.49046135], [88.78205109, 22.49014091], [88.78218079, 22.48986626], [88.78227997, 22.48962212], [88.78240967, 22.48934174], [88.78259277, 22.48901176], [88.78286743, 22.48870468], [88.78314972, 22.4883213], [88.78344727, 22.48796272], [88.78370667, 22.48759842], [88.78391266, 22.48718071], [88.7841568, 22.48681068], [88.78444672, 22.48645973], [88.78470612, 22.48616028], [88.78472137, 22.48639107], [88.78666687, 22.48444366], [88.78694153, 22.48444557], [88.78722382, 22.4841671], [88.78769684, 22.48407173], [88.78822327, 22.4837513], [88.78869629, 22.48327065], [88.78913116, 22.48274612], [88.7894516, 22.48223305], [88.78980255, 22.48179054], [88.79016113, 22.48140144], [88.79032898, 22.48082161], [88.79046631, 22.48026085], [88.79055023, 22.47976112], [88.79057312, 22.47932434], [88.79058838, 22.4789238], [88.79071808, 22.47855949], [88.79104614, 22.47821045], [88.79131317, 22.47779274], [88.79136658, 22.47727203], [88.79136658, 22.47674751], [88.79142761, 22.47624016], [88.79157257, 22.47571945], [88.7917099, 22.47514153], [88.79193878, 22.47458076], [88.79219055, 22.47401237], [88.79241943, 22.47343636], [88.79265594, 22.4729023], [88.79288483, 22.47240257], [88.79312134, 22.47197723], [88.79335022, 22.47158051], [88.79358673, 22.4711895], [88.79379272, 22.47074318], [88.79393768, 22.47021484], [88.79413605, 22.4697094], [88.79429626, 22.46920204], [88.79449463, 22.46874619], [88.79471588, 22.46833038], [88.79496002, 22.46791267], [88.7951889, 22.46743011], [88.79538727, 22.4669323], [88.795578, 22.46643257], [88.79582214, 22.46601486], [88.79605865, 22.46558952], [88.79624939, 22.46515083], [88.7964859, 22.46474457], [88.79675293, 22.46436119], [88.79702759, 22.46398735], [88.79733276, 22.46361923], [88.79766846, 22.46326637], [88.79795837, 22.46287155], [88.79821014, 22.46247292], [88.79840851, 22.46210289], [88.79860687, 22.46182632], [88.79888916, 22.46167183], [88.79915619, 22.46138954], [88.79915619, 22.4608326], [88.79944611, 22.46055794], [88.79944611, 22.46000099], [88.79972076, 22.45972252], [88.79972076, 22.45916939], [88.80000305, 22.45889091], [88.80000305, 22.45861244], [88.80007172, 22.45852089], [88.80026245, 22.45802116], [88.8004303, 22.45755959], [88.80050659, 22.45714188], [88.80060577, 22.45674706], [88.80065918, 22.45628166], [88.80071259, 22.45578575], [88.8007431, 22.45527077], [88.80075073, 22.45473289], [88.80079651, 22.45418739], [88.8008728, 22.45356941], [88.80096436, 22.45299149], [88.80107117, 22.45235825], [88.80117035, 22.45167923], [88.80111694, 22.45105171], [88.8010788, 22.45044518], [88.80103302, 22.44987297], [88.80110931, 22.44972038], [88.80110931, 22.44861031], [88.80082703, 22.44833183], [88.80083466, 22.44750023], [88.80110931, 22.44722176], [88.80110931, 22.44666862], [88.8013916, 22.44639015], [88.8013916, 22.44611168], [88.80166626, 22.44583321], [88.80166626, 22.44555473], [88.80198669, 22.44511604], [88.80214691, 22.4444828], [88.80233765, 22.44384956], [88.80252075, 22.44342232], [88.80280304, 22.44322014], [88.80304718, 22.44302177], [88.8033371, 22.44277191], [88.80360413, 22.44246674], [88.80388641, 22.44211769], [88.80414581, 22.441782], [88.80439758, 22.44147491], [88.80470276, 22.4412384], [88.80499268, 22.44099236], [88.80531311, 22.44070053], [88.80570984, 22.44040108], [88.80618286, 22.44006157], [88.80671692, 22.4397316], [88.80726624, 22.43939018], [88.80776978, 22.43898964], [88.80821991, 22.43859291], [88.80863953, 22.43819237], [88.8090744, 22.43783951], [88.80944061, 22.43741035], [88.80982971, 22.43699074], [88.81024933, 22.43662262], [88.81062317, 22.43618202], [88.81102753, 22.43578148], [88.81141663, 22.43536186], [88.81183624, 22.43497849], [88.81224823, 22.43460274], [88.81269836, 22.43424034], [88.81317139, 22.43389893], [88.81362915, 22.43354988], [88.81400299, 22.43313026], [88.81439972, 22.43275833], [88.81482697, 22.43240929], [88.8152771, 22.43209267], [88.81571198, 22.43178558], [88.81616211, 22.43150139], [88.81664276, 22.43128014], [88.81711578, 22.43107033], [88.81755829, 22.43086052], [88.81801605, 22.43071175], [88.81848145, 22.43057251], [88.81894684, 22.43046761], [88.81941986, 22.43033028], [88.81991577, 22.43037224], [88.82041931, 22.43050957], [88.82098389, 22.43055534], [88.82156372, 22.43055534], [88.8221283, 22.43051338], [88.82261658, 22.43035507], [88.8230896, 22.43029213], [88.82350159, 22.43027115], [88.82385254, 22.43026161], [88.82417297, 22.43024826], [88.82447815, 22.43020248], [88.82483673, 22.43007278], [88.82527161, 22.43000221], [88.825737, 22.43000984], [88.82624054, 22.43008995], [88.82674408, 22.43027687], [88.82861328, 22.43029213], [88.82888794, 22.43000221], [88.83000183, 22.43000221], [88.83027649, 22.43029213], [88.83110809, 22.43029213], [88.83139038, 22.43056488], [88.83167267, 22.43029213], [88.83249664, 22.43029213], [88.83277893, 22.43056488], [88.83305359, 22.43055534], [88.83333588, 22.43083382], [88.83361053, 22.43083382], [88.83388519, 22.43111229], [88.8347168, 22.43111229], [88.83499908, 22.43139076], [88.83528137, 22.43139076], [88.83555603, 22.43167305], [88.83611298, 22.43166924], [88.83638763, 22.43194389], [88.83666992, 22.43194389], [88.83694458, 22.43222237], [88.83999634, 22.43222237], [88.84027863, 22.43250084], [88.84194183, 22.43250084], [88.84221649, 22.43222237], [88.84555817, 22.43222237], [88.84583282, 22.43194389], [88.84638977, 22.43194389], [88.84666443, 22.43166924], [88.84722137, 22.43167305], [88.8483429, 22.43056488], [88.8483429, 22.43000221], [88.84860992, 22.42972374], [88.84860992, 22.42916679], [88.84889221, 22.42889023], [88.84893036, 22.42823982], [88.84910583, 22.42776299], [88.84928131, 22.42732048], [88.84945679, 22.42691994], [88.849617, 22.42653084], [88.84968567, 22.42609787], [88.84971619, 22.42564964], [88.84976959, 22.42523384], [88.84985352, 22.42486763], [88.84996033, 22.42453957], [88.84999847, 22.42419052], [88.85003662, 22.42381096], [88.85017395, 22.42342186], [88.85029602, 22.42295265], [88.8504715, 22.42245293], [88.85063934, 22.42192459], [88.85082245, 22.421381], [88.85096741, 22.42083168], [88.85109711, 22.42025948], [88.85118866, 22.41968918], [88.85140228, 22.41916084], [88.85163879, 22.41863823], [88.85180664, 22.41807365], [88.85198975, 22.41751671], [88.85218811, 22.41697884], [88.85233307, 22.41640472], [88.85251617, 22.41584015], [88.85275269, 22.41531181], [88.85293579, 22.41481972], [88.85322571, 22.41446686], [88.85334778, 22.41410255], [88.85353851, 22.41378975], [88.85371399, 22.41347694], [88.85385132, 22.41311073], [88.85401154, 22.41273308], [88.85417175, 22.41234779], [88.85439301, 22.41199303], [88.85455322, 22.41155052], [88.85475922, 22.41113281], [88.85500336, 22.41074944], [88.85522461, 22.4104023], [88.85538483, 22.41003609], [88.85555267, 22.40969467], [88.85567474, 22.40932655], [88.85582733, 22.40892982], [88.85595703, 22.40848351], [88.85607147, 22.40801048], [88.85604858, 22.4075222], [88.85588837, 22.40705109], [88.855896, 22.40651894], [88.85600281, 22.40594292], [88.85581207, 22.40541458], [88.85552979, 22.40492058], [88.85525513, 22.40445137], [88.85502625, 22.40399361], [88.85485077, 22.40352058], [88.85472107, 22.4030323], [88.85460663, 22.40253258], [88.85452271, 22.40202141], [88.85438538, 22.40156174], [88.85420227, 22.40114784], [88.85401154, 22.4007206], [88.85381317, 22.40027618], [88.85366058, 22.39980125], [88.85360718, 22.39923859], [88.85357666, 22.39870262], [88.85353088, 22.39822388], [88.85337067, 22.39780998], [88.85328674, 22.39735222], [88.85322571, 22.39687157], [88.85302734, 22.39643478], [88.85279083, 22.3959713], [88.85259247, 22.39546013], [88.85250854, 22.39489555], [88.85250092, 22.39437294], [88.85250092, 22.39392662], [88.85250092, 22.39352608], [88.85250092, 22.39313316], [88.85250854, 22.39272881], [88.85250092, 22.39222145], [88.85221863, 22.39194679], [88.85194397, 22.39194679], [88.85166931, 22.39166832], [88.85138702, 22.39194679], [88.85083008, 22.39194679], [88.85055542, 22.39222145], [88.84750366, 22.39222145], [88.84694672, 22.39166832], [88.84694672, 22.39083481], [88.84722137, 22.39055824], [88.84722137, 22.39027977], [88.84749603, 22.3900013], [88.84638977, 22.38889122], [88.84638977, 22.38861275], [88.84610748, 22.38833237], [88.84638977, 22.3880558], [88.84638977, 22.38777733], [88.8466568, 22.38750267], [88.8466568, 22.38721848], [88.84889221, 22.38499832], [88.84889221, 22.38472176], [88.84944153, 22.38417244], [88.85028076, 22.38501167], [88.85028076, 22.38528061], [88.85083008, 22.38583565], [88.85111237, 22.38583183], [88.85166931, 22.38639259], [88.85166931, 22.38666725], [88.85194397, 22.38694572], [88.85250092, 22.38694572], [88.85277557, 22.38666725], [88.8527832, 22.38501167], [88.85299683, 22.38470268], [88.8530426, 22.38433266], [88.85305786, 22.38387108], [88.85307312, 22.38331032], [88.85314178, 22.38272285], [88.85333252, 22.38223076], [88.8535614, 22.38177109], [88.85380554, 22.38135719], [88.85401917, 22.38097191], [88.85420227, 22.38060379], [88.85443115, 22.38029289], [88.8546524, 22.37997246], [88.85475922, 22.37952995], [88.85488892, 22.37917137], [88.85501862, 22.37890625], [88.85515594, 22.37868309], [88.85528564, 22.3783741], [88.85540771, 22.37806892], [88.85558319, 22.3778019], [88.8557663, 22.37756348], [88.85597229, 22.37732124], [88.85610199, 22.37698746], [88.85617828, 22.37662315], [88.8563385, 22.37626839], [88.85637665, 22.37584114], [88.85637665, 22.37540245], [88.85637665, 22.3749218], [88.85645294, 22.37442207], [88.85663605, 22.3739109], [88.85679626, 22.373312], [88.85697937, 22.37267113], [88.85723114, 22.37207985], [88.85749054, 22.37154961], [88.85774231, 22.37105942], [88.85793304, 22.37059975], [88.85806274, 22.37028313], [88.85832977, 22.37001228], [88.85832977, 22.36972237], [88.85861206, 22.36944389], [88.85888672, 22.36944389], [88.85916901, 22.36916924], [88.85916901, 22.36889076], [88.85943604, 22.36861229], [88.85943604, 22.36806297], [88.85972595, 22.36778069], [88.85972595, 22.36750221], [88.86000061, 22.36721992], [88.86000061, 22.36694527], [88.8602829, 22.36667061], [88.86023712, 22.36638069], [88.86038208, 22.36598015], [88.8605957, 22.36562347], [88.86084747, 22.3653183], [88.86110687, 22.36502266], [88.86140442, 22.36471176], [88.86173248, 22.36438942], [88.86206055, 22.36409187], [88.86252594, 22.36392021], [88.86305237, 22.36383247], [88.86358643, 22.36367035], [88.86416626, 22.36355019], [88.8647995, 22.36343002], [88.8653183, 22.36312294], [88.8658371, 22.36284256], [88.86638641, 22.36261749], [88.86688232, 22.36240959], [88.86734009, 22.36217308], [88.86772156, 22.3618679], [88.86808777, 22.36155128], [88.86850739, 22.36128044], [88.86901855, 22.36104012], [88.86953735, 22.36069107], [88.87011719, 22.36034012], [88.87077332, 22.36004066], [88.87137604, 22.35973358], [88.87191772, 22.35944939], [88.87240601, 22.35920143], [88.8728714, 22.3590107], [88.8733139, 22.35883331], [88.87375641, 22.35862541], [88.87425232, 22.35840034], [88.87474823, 22.35811806], [88.87528229, 22.35775948], [88.87577057, 22.35728455], [88.87610626, 22.35665321], [88.87632751, 22.35598183], [88.87628937, 22.35531044], [88.8759079, 22.35492134], [88.8754425, 22.35501671], [88.87503052, 22.35527229], [88.87468719, 22.35557938], [88.87438965, 22.35586739], [88.87409973, 22.35616684], [88.8738327, 22.35648155], [88.87361145, 22.35667229], [88.8713913, 22.35889244], [88.87082672, 22.35889244], [88.87055206, 22.35917091], [88.86972046, 22.3591671], [88.86958313, 22.35930824], [88.8694458, 22.35944557], [88.86916351, 22.3591671], [88.86888885, 22.3591404], [88.86833191, 22.35904121], [88.86791229, 22.35892868], [88.86753082, 22.35886192], [88.86717987, 22.35881805], [88.86683655, 22.35878754], [88.86649323, 22.35878372], [88.86612701, 22.35877037], [88.86582184, 22.35868263], [88.8655014, 22.35851097], [88.86515808, 22.3583622], [88.86482239, 22.35828018], [88.86437225, 22.35822105], [88.86383057, 22.35819244], [88.86327362, 22.35820389], [88.8628006, 22.35828018], [88.86251831, 22.35847282], [88.8622818, 22.35871315], [88.86203003, 22.35899925], [88.86168671, 22.35923195], [88.86132813, 22.35946465], [88.86096191, 22.35970116], [88.86058044, 22.35992241], [88.86011505, 22.360075], [88.85961914, 22.3602314], [88.85906219, 22.3603611], [88.85848999, 22.36050987], [88.85785675, 22.36063957], [88.85720062, 22.36079979], [88.85652924, 22.36095238], [88.85587311, 22.36114311], [88.85523987, 22.36133766], [88.85468292, 22.36156273], [88.8542099, 22.36177254], [88.85379791, 22.36198235], [88.85337067, 22.36219215], [88.85293579, 22.36240196], [88.85250854, 22.36264229], [88.85211182, 22.36287117], [88.85166931, 22.36318398], [88.85118103, 22.36359024], [88.85068512, 22.36392975], [88.85020447, 22.36415672], [88.84971619, 22.36436653], [88.84923553, 22.36454201], [88.84908295, 22.36450195], [88.84884644, 22.3644352], [88.84845734, 22.36427116], [88.8480072, 22.36417389], [88.8475647, 22.36407661], [88.84713745, 22.36394119], [88.84668732, 22.36383247], [88.84622955, 22.36362267], [88.84570312, 22.36339188], [88.84513855, 22.36317253], [88.84456635, 22.36296844], [88.84394836, 22.36282539], [88.84329987, 22.36269188], [88.8427124, 22.36248207], [88.84213257, 22.3622551], [88.84150696, 22.36206818], [88.84088898, 22.36190224], [88.84034729, 22.36169243], [88.83982086, 22.36150169], [88.83933258, 22.36134338], [88.83886719, 22.36115074], [88.83838654, 22.36100006], [88.83789062, 22.36082268], [88.83737946, 22.36063194], [88.83683777, 22.36048698], [88.83625031, 22.36026192], [88.83557892, 22.36008644], [88.83503723, 22.35988045], [88.83460999, 22.35963821], [88.83425903, 22.35945702], [88.83389282, 22.3593502], [88.83351135, 22.35928154], [88.83308411, 22.3592186], [88.83262634, 22.35920143], [88.83218384, 22.3592186], [88.83175659, 22.35926247], [88.83138275, 22.35929298], [88.83103943, 22.35933113], [88.83074188, 22.35940933], [88.83046722, 22.35951042], [88.83013153, 22.35962105], [88.82969666, 22.35970116], [88.82920074, 22.35983276], [88.82859039, 22.36009026], [88.8279953, 22.36034775], [88.82774353, 22.36040306], [88.82746887, 22.3604641], [88.82697296, 22.36045456], [88.82647705, 22.36035728], [88.82595825, 22.36037254], [88.82544708, 22.36053467], [88.82489777, 22.36073112], [88.82431793, 22.36091042], [88.82409668, 22.36088562], [88.8238678, 22.36086082], [88.82344818, 22.36078835], [88.82303619, 22.36069107], [88.82254791, 22.36078835], [88.82195282, 22.36089134], [88.82138062, 22.36111259], [88.82138062, 22.36139107], [88.8216629, 22.36166573], [88.8216629, 22.3619442], [88.82051849, 22.36309433], [88.81972504, 22.36388969], [88.81916809, 22.36388969], [88.8188858, 22.36361122], [88.8188858, 22.36333275], [88.81861115, 22.36305618], [88.81861115, 22.36166954], [88.81833649, 22.36139107], [88.81817627, 22.36112976], [88.81797791, 22.36074066], [88.81774902, 22.36035156], [88.81748962, 22.35995865], [88.81720734, 22.35956764], [88.81693268, 22.35918045], [88.81665039, 22.3588295], [88.81639862, 22.35853004], [88.81616974, 22.35824966], [88.81593323, 22.35798073], [88.8157959, 22.35775948], [88.81564331, 22.3574295], [88.81535339, 22.35680962], [88.81508636, 22.35604095], [88.81488037, 22.35535049], [88.81466675, 22.3547802], [88.81476593, 22.35414124], [88.81498718, 22.35349083], [88.81511688, 22.35289192], [88.81503296, 22.35239029], [88.81487274, 22.35197067], [88.81466675, 22.35161972], [88.81443024, 22.35132027], [88.81416321, 22.35104942], [88.8138504, 22.35079002], [88.81355286, 22.35050964], [88.81326294, 22.35026169], [88.81300354, 22.35002518], [88.81276703, 22.34980011], [88.81254578, 22.34956932], [88.81234741, 22.3492794], [88.81215668, 22.34894943], [88.81194305, 22.34863091], [88.81170654, 22.3483429], [88.81153107, 22.34803009], [88.8116684, 22.34777832], [88.81138611, 22.34750175], [88.81138611, 22.34555817], [88.81111145, 22.34527969], [88.81111145, 22.34472084], [88.81083679, 22.34444427], [88.81083679, 22.34361076], [88.81054688, 22.34333038], [88.8105545, 22.34277534], [88.81027985, 22.34250069], [88.81027985, 22.34193993], [88.80999756, 22.34166527], [88.80944061, 22.34167099], [88.80944061, 22.34136009], [88.80938721, 22.3410511], [88.80927277, 22.34070969], [88.80914307, 22.34033012], [88.80898285, 22.33992958], [88.80882263, 22.33948326], [88.80860138, 22.33906364], [88.80834198, 22.33863449], [88.80805206, 22.33820534], [88.80776215, 22.33778], [88.80750275, 22.33737183], [88.80728149, 22.3369751], [88.80710602, 22.33657074], [88.80693054, 22.33619308], [88.80674744, 22.33580017], [88.80665588, 22.33528137], [88.80654907, 22.33469009], [88.80628967, 22.33411026], [88.80596924, 22.33362007], [88.80568695, 22.33324051], [88.80555725, 22.33305931], [88.80528259, 22.33278084], [88.80528259, 22.33250046], [88.80500031, 22.33222008], [88.80500031, 22.33194351], [88.80472565, 22.33166885], [88.80444336, 22.33167076], [88.80406952, 22.33129692], [88.80388641, 22.33110809], [88.80388641, 22.33083344], [88.80379486, 22.33106995], [88.80358887, 22.33082008], [88.8033371, 22.33053017], [88.8030777, 22.3302002], [88.80284882, 22.32983017], [88.80271912, 22.32941055], [88.80261993, 22.32898331], [88.80275726, 22.3285408], [88.80291748, 22.32809258], [88.80302429, 22.32787323], [88.8031311, 22.32764626], [88.80339813, 22.32726288], [88.8036499, 22.32685471], [88.80391693, 22.32644653], [88.80408478, 22.32616615], [88.80417633, 22.32601357], [88.80445099, 22.32553864], [88.80473328, 22.32500076], [88.80528259, 22.32440948], [88.80683899, 22.32273674], [88.80921173, 22.31993294], [88.80950928, 22.31963158], [88.80974579, 22.31922913], [88.80999756, 22.31881142], [88.81019592, 22.31836128], [88.81025696, 22.31781387], [88.81032562, 22.31721306], [88.8104248, 22.31682968], [88.81048584, 22.31660461], [88.81047058, 22.31595039], [88.81033325, 22.31532288], [88.81027985, 22.31470108], [88.81021881, 22.31414986], [88.81001282, 22.31370926], [88.80977631, 22.31327057], [88.80953979, 22.31278992], [88.80924988, 22.31232834], [88.80887604, 22.31190109], [88.80853271, 22.31146431], [88.80818176, 22.3110733], [88.8079071, 22.31068039], [88.80768585, 22.31032944], [88.80745697, 22.31003952], [88.80725098, 22.30978012], [88.80710602, 22.30948067], [88.80697632, 22.30918121], [88.80683899, 22.30879974], [88.80664063, 22.30841446], [88.806427, 22.30798149], [88.80634308, 22.30745125], [88.80635071, 22.30685806], [88.80626678, 22.30630112], [88.80618286, 22.30578041], [88.8061142, 22.30532837], [88.80605316, 22.30491066], [88.80595398, 22.30451393], [88.80586243, 22.30410767], [88.80581665, 22.30367088], [88.80571747, 22.30323982], [88.80555725, 22.30281067], [88.80544281, 22.30233192], [88.80529785, 22.30182457], [88.80522156, 22.30130386], [88.80503845, 22.3008728], [88.80493164, 22.30042076], [88.80475616, 22.30003929], [88.80462646, 22.29964066], [88.80444336, 22.29927063], [88.80420685, 22.2989006], [88.80399323, 22.29846954], [88.80356598, 22.29813004], [88.8034668, 22.29758072], [88.8033371, 22.29705811], [88.80321503, 22.29654312], [88.80310822, 22.29602051], [88.80306244, 22.29545975], [88.80305481, 22.29488754], [88.80304718, 22.29430962], [88.80304718, 22.2937603], [88.80304718, 22.29326057], [88.80304718, 22.29283905], [88.80304718, 22.29247093], [88.80304718, 22.29212952], [88.80306244, 22.29180717], [88.8030777, 22.29150963], [88.8031311, 22.29124069], [88.80326843, 22.29092407], [88.80348206, 22.29063225], [88.80358887, 22.29022408], [88.80365753, 22.28977394], [88.80383301, 22.28935051], [88.80392456, 22.28887939], [88.80407715, 22.28837013], [88.80415344, 22.28775597], [88.80416107, 22.28707123], [88.8041687, 22.28634834], [88.80419922, 22.28564072], [88.80436707, 22.28499031], [88.80455017, 22.28436279], [88.80473328, 22.28380966], [88.80467224, 22.28324127], [88.8044281, 22.2827301], [88.80409241, 22.28228188], [88.80370331, 22.2818718], [88.80332184, 22.28141022], [88.80290985, 22.28097343], [88.80251312, 22.28051949], [88.80210114, 22.2800827], [88.80162811, 22.27973938], [88.8011322, 22.27946281], [88.80066681, 22.2791996], [88.80023956, 22.27900505], [88.79985046, 22.27880096], [88.79953766, 22.27846909], [88.79918671, 22.27821159], [88.79879761, 22.27797127], [88.79833221, 22.2779541], [88.79786682, 22.27795982], [88.79749298, 22.27782059], [88.79705811, 22.27779007], [88.79663086, 22.27783966], [88.79621124, 22.27798843], [88.79576874, 22.27804947], [88.79538727, 22.27801514], [88.79482269, 22.27779007], [88.79429626, 22.27757072], [88.79377747, 22.27738953], [88.79335785, 22.27707481], [88.79299927, 22.2766552], [88.79270935, 22.2761898], [88.79271698, 22.27569389], [88.79292297, 22.27524948], [88.79309845, 22.27485085], [88.79321289, 22.27449989], [88.79310608, 22.27415085], [88.79302216, 22.2737999], [88.79283905, 22.27345276], [88.7925415, 22.27310944], [88.79225922, 22.27269363], [88.79209137, 22.27219963], [88.79217529, 22.27170944], [88.79231262, 22.2712841], [88.79251099, 22.27096176], [88.79271698, 22.27062607], [88.7928772, 22.27017975], [88.7930069, 22.26968956], [88.79306793, 22.26917839], [88.79308319, 22.26868057], [88.79304504, 22.26821327], [88.79294586, 22.26777077], [88.79281616, 22.26732063], [88.79271698, 22.26685905], [88.79256439, 22.26645088], [88.79245758, 22.26601028], [88.79231262, 22.26559067], [88.79223633, 22.26515388], [88.79219818, 22.26472664], [88.79214478, 22.26431084], [88.79216003, 22.26381111], [88.7921524, 22.26328087], [88.79207611, 22.26271057], [88.79176331, 22.26222992], [88.79151917, 22.26171112], [88.79141235, 22.26122284], [88.79135132, 22.26081467], [88.79122925, 22.26050377], [88.79110718, 22.26022339], [88.79096222, 22.25996399], [88.79079437, 22.25970268], [88.7905426, 22.25948143], [88.79017639, 22.25937653], [88.7897644, 22.25936127], [88.78930664, 22.25945091], [88.78881836, 22.2595768], [88.78831482, 22.25961304], [88.78783417, 22.25943947], [88.78733063, 22.25922966], [88.78674316, 22.25909996], [88.78616333, 22.25887108], [88.78553009, 22.25858879], [88.78491974, 22.25826073], [88.78436279, 22.25786018], [88.7837677, 22.25751877], [88.78317261, 22.25722122], [88.7826004, 22.25694275], [88.7820816, 22.25666046], [88.78161621, 22.25640106], [88.78121185, 22.25616074], [88.78087616, 22.25587654], [88.78056335, 22.25559044], [88.78014374, 22.25535393], [88.77962494, 22.25516129], [88.77910614, 22.25491905], [88.77861023, 22.25464058], [88.77812195, 22.25438118], [88.77764893, 22.25414658], [88.7771759, 22.2538929], [88.77670288, 22.25365639], [88.77620697, 22.25344086], [88.77571106, 22.25323105], [88.775177, 22.25300026], [88.7746582, 22.25272179], [88.77415466, 22.25238037], [88.77362061, 22.25206947], [88.77307892, 22.25176048], [88.77255249, 22.25151634], [88.7720871, 22.25127983], [88.77176666, 22.25101089], [88.77155304, 22.25070953], [88.77136993, 22.25042152], [88.77119446, 22.25013733], [88.77102661, 22.24978065], [88.77082062, 22.24940109], [88.77059937, 22.24893951], [88.77040863, 22.24840546], [88.77025604, 22.24781036], [88.77011108, 22.24723816], [88.7700119, 22.24669456], [88.76985931, 22.2461853], [88.76966095, 22.24566078], [88.76941681, 22.24517822], [88.76921082, 22.24464035], [88.76904297, 22.24406815], [88.76889801, 22.2435112], [88.76875305, 22.24315071], [88.76859283, 22.24287033], [88.76837158, 22.24268913], [88.76802063, 22.24264908], [88.76767731, 22.24262047], [88.76729584, 22.24263191], [88.76699066, 22.24274826], [88.76669312, 22.24285316], [88.76629639, 22.24290466], [88.76592255, 22.24306107], [88.76544952, 22.24326515], [88.76490021, 22.24343109], [88.76432037, 22.24357986], [88.76371765, 22.24360275], [88.76317596, 22.24353981], [88.76272583, 22.24335098], [88.76230621, 22.24316025], [88.76194763, 22.24302101], [88.76167297, 22.2428112], [88.76139069, 22.24265099], [88.76111603, 22.24250031], [88.76085663, 22.24238014], [88.76061249, 22.24224091], [88.76034546, 22.24212074], [88.76011658, 22.24189758], [88.75990295, 22.24155998], [88.75968933, 22.24115944], [88.75943756, 22.24073029], [88.7591629, 22.24030495], [88.75885773, 22.23989105], [88.75850677, 22.23951912], [88.75810242, 22.23919106], [88.75772858, 22.23883629], [88.75736237, 22.23846817], [88.75701904, 22.23809052], [88.75665283, 22.23773956], [88.75631714, 22.23732948], [88.75595856, 22.23694992], [88.75557709, 22.2365799], [88.75522614, 22.23620033], [88.75482178, 22.23587608], [88.75435638, 22.23564911], [88.75386047, 22.23550034], [88.75341034, 22.23530579], [88.75296021, 22.23516083], [88.75254822, 22.23501587], [88.75211334, 22.23489189], [88.75166321, 22.23470116], [88.75123596, 22.23444939], [88.7508316, 22.23419952], [88.75039673, 22.2340107], [88.75002289, 22.23376083], [88.74965668, 22.23348808], [88.74922943, 22.23327065], [88.74882507, 22.23306274], [88.74842072, 22.23287582], [88.74800873, 22.23271942], [88.74752045, 22.23248291], [88.74704742, 22.23214912], [88.74662781, 22.23174095], [88.74620819, 22.23139763], [88.74582672, 22.23110962], [88.74555206, 22.23111153], [88.7436142, 22.22916603], [88.74360657, 22.22888947], [88.74333191, 22.2286129], [88.74333191, 22.22831917], [88.7436142, 22.22805595], [88.74360657, 22.22777939], [88.74333191, 22.22750282], [88.74333191, 22.22721863], [88.7436142, 22.22694397], [88.7436142, 22.2266674], [88.74500275, 22.22528076], [88.74500275, 22.22500038], [88.7463913, 22.22360992], [88.7463913, 22.22339249], [88.74647522, 22.22343445], [88.74682617, 22.22306633], [88.74717712, 22.22270966], [88.74751282, 22.22234344], [88.74784851, 22.22199059], [88.74821472, 22.22168159], [88.74861145, 22.22139168], [88.74903107, 22.22110176], [88.74936676, 22.22073174], [88.74958801, 22.22024345], [88.74938965, 22.21965218], [88.74897003, 22.2191143], [88.74867249, 22.21869087], [88.7485733, 22.21854973], [88.74823761, 22.21803093], [88.74798584, 22.21751976], [88.74776459, 22.21703529], [88.74752045, 22.21656036], [88.74732971, 22.21603584], [88.74720764, 22.21544075], [88.74706268, 22.21486282], [88.74681091, 22.21440506], [88.74659729, 22.21392059], [88.74636078, 22.21345711], [88.7461319, 22.21299171], [88.74595642, 22.21250725], [88.74581146, 22.21203041], [88.74568176, 22.21158981], [88.74558258, 22.21116066], [88.74555206, 22.21069908], [88.74551392, 22.21028519], [88.7454071, 22.20993805], [88.74532318, 22.20959091], [88.74534607, 22.20920944], [88.74546814, 22.20878983], [88.74547577, 22.20833969], [88.74536896, 22.20792389], [88.74531555, 22.20750618], [88.74536133, 22.20709991], [88.7454834, 22.20669556], [88.7456131, 22.20619965], [88.74573517, 22.20572853], [88.74588776, 22.20528984], [88.74610901, 22.20499992], [88.74611664, 22.20471191], [88.7463913, 22.20444489], [88.7463913, 22.20305824], [88.74623871, 22.20290756], [88.74610901, 22.20277786], [88.74610138, 22.20222282], [88.74583435, 22.20194435], [88.74583435, 22.20138931], [88.7452774, 22.20083427], [88.74416351, 22.20194435], [88.74415588, 22.20360947], [88.7444458, 22.20388794], [88.7444458, 22.20471954], [88.74472046, 22.20499992], [88.74472046, 22.2052784], [88.74416351, 22.20583344], [88.74415588, 22.20722008], [88.7444458, 22.20750809], [88.74416351, 22.20777512], [88.74415588, 22.20833015], [88.7436142, 22.2088871], [88.7436142, 22.20944405], [88.74388885, 22.20972061], [88.74388885, 22.21055794], [88.74360657, 22.21083069], [88.74360657, 22.21110916], [88.74333191, 22.21138954], [88.74333191, 22.21166611], [88.74305725, 22.21194458], [88.74277496, 22.21194458], [88.74250031, 22.21221924], [88.74250031, 22.21250153], [88.74222565, 22.21277809], [88.74223328, 22.2136116], [88.7416687, 22.21417046], [88.74138641, 22.21417046], [88.74111176, 22.21445274], [88.7408371, 22.21444511], [88.74055481, 22.21472168], [88.73999786, 22.21472168], [88.73944092, 22.21416664], [88.73916626, 22.21417046], [88.7388916, 22.21389008], [88.7388916, 22.21166992], [88.73860931, 22.21138954], [88.73860931, 22.21056938], [88.7388916, 22.21027946], [88.7388916, 22.21000099], [88.73916626, 22.21000099], [88.73972321, 22.20944023], [88.73999786, 22.20944405], [88.74111176, 22.20833397], [88.74111176, 22.20694351], [88.7408371, 22.20666695], [88.7408371, 22.20639038], [88.74111176, 22.20611], [88.74111176, 22.20583344], [88.74138641, 22.20555305], [88.74138641, 22.2052803], [88.74111176, 22.20499992], [88.74111176, 22.20471954], [88.7408371, 22.20444489], [88.7408371, 22.20416641], [88.74028778, 22.20360947], [88.74028015, 22.20305634], [88.74250031, 22.20083237], [88.74250031, 22.2005558], [88.74278259, 22.20027924], [88.74278259, 22.20000076], [88.74250031, 22.19972229], [88.74194336, 22.19972229], [88.74194336, 22.19944382], [88.74138641, 22.19889069], [88.74138641, 22.1986084], [88.74111176, 22.1986084], [88.74057007, 22.19860077], [88.73989105, 22.19855118], [88.73922729, 22.19835091], [88.73860168, 22.19803047], [88.73797607, 22.1977005], [88.73738098, 22.19740105], [88.73666382, 22.1971283], [88.73609161, 22.19683838], [88.7361145, 22.19694519], [88.73583221, 22.19695091], [88.73555756, 22.19667244], [88.73527527, 22.19638634], [88.73500061, 22.19639015], [88.73486328, 22.19625092], [88.73472595, 22.19610977], [88.73416901, 22.19611168], [88.73361206, 22.19555473], [88.73194122, 22.19555473], [88.73161316, 22.19559288], [88.73118591, 22.19573021], [88.7307663, 22.19582939], [88.73034668, 22.19593048], [88.72992706, 22.1960907], [88.72947693, 22.1962204], [88.72902679, 22.19635963], [88.72852325, 22.19649124], [88.72797394, 22.19662666], [88.72735596, 22.19672012], [88.72675323, 22.19692993], [88.72609711, 22.1971302], [88.72544098, 22.19733047], [88.72473907, 22.19752502], [88.72408295, 22.19774055], [88.72341919, 22.19795036], [88.72277069, 22.19811058], [88.72219086, 22.19833946], [88.7216568, 22.19854927], [88.72112274, 22.19866943], [88.72064209, 22.19886017], [88.7201767, 22.19905281], [88.71974182, 22.19927788], [88.71930695, 22.19954109], [88.71882629, 22.1997509], [88.71835327, 22.19997978], [88.71787262, 22.20016289], [88.71733856, 22.20027733], [88.71684265, 22.20040321], [88.71640015, 22.2005825], [88.71598816, 22.20081329], [88.71556854, 22.20104027], [88.71511841, 22.20125008], [88.71469116, 22.20155525], [88.71422577, 22.20194244], [88.71369934, 22.20238686], [88.71311188, 22.20282936], [88.71253204, 22.20329094], [88.71198273, 22.20371056], [88.7114563, 22.20409966], [88.7109375, 22.20438004], [88.71051788, 22.20463943], [88.71012878, 22.20485115], [88.70973206, 22.20502663], [88.70938873, 22.20526123], [88.70905304, 22.2055397], [88.7086792, 22.2058506], [88.70832825, 22.20622253], [88.70795441, 22.20659828], [88.7075119, 22.20693016], [88.70701599, 22.20722008], [88.70654297, 22.20745087], [88.70605469, 22.20758629], [88.70565796, 22.20778465], [88.70532227, 22.20797348], [88.70498657, 22.2080307], [88.70466614, 22.20809555], [88.70429993, 22.20826149], [88.70394135, 22.2085495], [88.70355988, 22.20885277], [88.70313263, 22.20903015], [88.70274353, 22.20916939], [88.70236206, 22.2093029], [88.7019577, 22.20944214], [88.70153809, 22.20956993], [88.70110321, 22.20969772], [88.70064545, 22.20977211], [88.70022583, 22.20994949], [88.69975281, 22.2100296], [88.69927979, 22.2101326], [88.6987381, 22.21010017], [88.69821167, 22.21014023], [88.69772339, 22.21026611], [88.69724274, 22.21038055], [88.69673157, 22.21051598], [88.69615173, 22.21055031], [88.69551849, 22.21056938], [88.69503021, 22.21055984], [88.69487, 22.21055412], [88.69421387, 22.21050835], [88.69361877, 22.21033096], [88.69301605, 22.21023178], [88.69252014, 22.21004295], [88.69204712, 22.20994949], [88.69161224, 22.20984077], [88.69114685, 22.20976067], [88.69064331, 22.20972061], [88.69011688, 22.20966911], [88.68962097, 22.20955276], [88.68906403, 22.20946884], [88.68843842, 22.20944977], [88.68781281, 22.20944023], [88.6871109, 22.20944023], [88.68638611, 22.20944977], [88.68569183, 22.20950127], [88.68500519, 22.20966721], [88.6843338, 22.2097168], [88.68369293, 22.20969009], [88.68313599, 22.20954895], [88.68267059, 22.20940971], [88.68229675, 22.20922089], [88.68193817, 22.20915985], [88.68157196, 22.20915985], [88.68121338, 22.209198], [88.68089294, 22.20931816], [88.68057251, 22.20952988], [88.68028259, 22.20984077], [88.67998505, 22.21022606], [88.67961884, 22.2106514], [88.67917633, 22.21107292], [88.67871857, 22.21149063], [88.67815399, 22.21174049], [88.67759705, 22.21196365], [88.67707062, 22.21217346], [88.67650604, 22.21224213], [88.67597961, 22.21237183], [88.67550659, 22.21256828], [88.67505646, 22.21280289], [88.67460632, 22.21305847], [88.6741333, 22.2133503], [88.67365265, 22.21372032], [88.67320251, 22.21411324], [88.67274475, 22.21445274], [88.67250061, 22.21472168], [88.67222595, 22.21472168], [88.67111206, 22.21583366], [88.67082977, 22.21583366], [88.67074585, 22.21584892], [88.67015076, 22.21596336], [88.66963196, 22.21614456], [88.66918945, 22.21636391], [88.66873932, 22.21652031], [88.66829681, 22.21669006], [88.66786957, 22.21689034], [88.66736603, 22.2170105], [88.66684723, 22.21718979], [88.66625977, 22.21729088], [88.66562653, 22.2174511], [88.66494751, 22.2175293], [88.66426849, 22.21763992], [88.66353607, 22.21773911], [88.66279602, 22.21773911], [88.66205597, 22.21772957], [88.66131592, 22.21771049], [88.66059875, 22.21759987], [88.65989685, 22.21749115], [88.65923309, 22.21737099], [88.65862274, 22.21719933], [88.65808105, 22.21697807], [88.65756989, 22.21679688], [88.65709686, 22.2165699], [88.65665436, 22.21625137], [88.65625, 22.21575165], [88.65572357, 22.21520233], [88.65529633, 22.21462822], [88.65506744, 22.21398926], [88.654953, 22.21334267], [88.65468597, 22.21277046], [88.65432739, 22.21228981], [88.65388489, 22.21194077], [88.65342712, 22.21165085], [88.65297699, 22.21138954], [88.65249634, 22.21121025], [88.65198517, 22.21133804], [88.65142059, 22.2113781], [88.65087891, 22.21139526], [88.65040588, 22.21145058], [88.65000153, 22.21162987], [88.64958191, 22.21166611], [88.64916229, 22.21169472], [88.64873505, 22.21181107], [88.64828491, 22.2119236], [88.647789, 22.21194267], [88.64722443, 22.21192932], [88.64659882, 22.21191978], [88.64595795, 22.21206093], [88.64525604, 22.21216965], [88.64453125, 22.21221542], [88.64377594, 22.21224976], [88.64305878, 22.21237564], [88.64237213, 22.21250153], [88.64174652, 22.21263123], [88.64113617, 22.21276093], [88.64055634, 22.21281815], [88.64002991, 22.21299171], [88.63949585, 22.21309853], [88.63905334, 22.21331024], [88.63856506, 22.21356773], [88.63806152, 22.21380043], [88.63757324, 22.21410942], [88.63703918, 22.21445274], [88.63651276, 22.21482086], [88.63609314, 22.21529007], [88.63568878, 22.21570587], [88.63535309, 22.21607971], [88.63504028, 22.21640015], [88.63488007, 22.2168808], [88.63470459, 22.21746635], [88.634552, 22.21813965], [88.6346817, 22.21886635], [88.63479614, 22.2195797], [88.63503265, 22.22018051], [88.63526917, 22.22068024], [88.63549042, 22.22120094], [88.63564301, 22.22173119], [88.63584137, 22.22225189], [88.63606262, 22.22273636], [88.63626862, 22.22320366], [88.63645935, 22.22361755], [88.6366806, 22.22403908], [88.63691711, 22.22442055], [88.63717651, 22.22479057], [88.63739777, 22.22514915], [88.63765717, 22.22544289], [88.63794708, 22.22571945], [88.63829803, 22.22594833], [88.63861084, 22.22622108], [88.6388855, 22.22639084], [88.63944244, 22.22694397], [88.6397171, 22.22693825], [88.64167023, 22.22888947], [88.64193726, 22.22888947], [88.64221954, 22.22916985], [88.64250183, 22.22916603], [88.64277649, 22.2294445], [88.64333344, 22.2294445], [88.64360809, 22.22972107], [88.64389038, 22.22972107], [88.64416504, 22.22999954], [88.64444733, 22.22999954], [88.64472198, 22.23027992], [88.64499664, 22.23027992], [88.64527893, 22.2305603], [88.64555359, 22.23055649], [88.64583588, 22.23083305], [88.64611053, 22.23083305], [88.64638519, 22.23111153], [88.64698792, 22.2311573], [88.6472168, 22.23139], [88.64749908, 22.23139], [88.64805603, 22.23195076], [88.64861298, 22.23194313], [88.64888763, 22.2322216], [88.64916992, 22.2322197], [88.64943695, 22.23250008], [88.64971161, 22.23250008], [88.65027618, 22.23306084], [88.65055847, 22.23306084], [88.65139008, 22.23389053], [88.6516571, 22.23389053], [88.65222168, 22.23444939], [88.65249634, 22.23444939], [88.6533432, 22.23528099], [88.65361023, 22.23528099], [88.65444183, 22.23611069], [88.65471649, 22.23611069], [88.65777588, 22.23916626], [88.65777588, 22.23944473], [88.6580658, 22.23936081], [88.65809631, 22.23966026], [88.65818024, 22.23991966], [88.65833282, 22.24014091], [88.65847778, 22.24041939], [88.65866089, 22.24071121], [88.65887451, 22.24098015], [88.65904999, 22.24126244], [88.65918732, 22.24155998], [88.65936279, 22.24188995], [88.65947723, 22.24225807], [88.65970612, 22.24265099], [88.65989685, 22.24309921], [88.66002655, 22.2435894], [88.66024017, 22.24399757], [88.66036987, 22.2444191], [88.66047668, 22.24482918], [88.66054535, 22.24522972], [88.66057587, 22.24562073], [88.66065979, 22.24602699], [88.66066742, 22.24654961], [88.66065979, 22.24703979], [88.6605835, 22.24742889], [88.66057587, 22.24780083], [88.66062927, 22.24821854], [88.66062164, 22.2487812], [88.66073608, 22.24934006], [88.66083527, 22.24983788], [88.66091919, 22.25032997], [88.66108704, 22.25078964], [88.66118622, 22.25125122], [88.66137695, 22.25163078], [88.66155243, 22.25199509], [88.66168976, 22.2524395], [88.66187286, 22.2528801], [88.66201019, 22.25336075], [88.66223145, 22.2538414], [88.66249847, 22.25431442], [88.66274261, 22.25479126], [88.66285706, 22.25531006], [88.66306305, 22.25579071], [88.66324615, 22.25624275], [88.66340637, 22.25673294], [88.66358185, 22.25720787], [88.66371918, 22.25769424], [88.66394043, 22.25811386], [88.66417694, 22.25852966], [88.66445923, 22.25892067], [88.66464233, 22.25933838], [88.66477966, 22.25974083], [88.66496277, 22.26008987], [88.66503143, 22.2604866], [88.66516113, 22.26085091], [88.6652832, 22.26124001], [88.66539764, 22.26163292], [88.66557312, 22.26200104], [88.665802, 22.26235962], [88.66597748, 22.26280022], [88.66614532, 22.26328087], [88.66638184, 22.26370239], [88.66661072, 22.26409721], [88.66680145, 22.26443481], [88.66696167, 22.2647438], [88.66712189, 22.26503372], [88.66722107, 22.26534843], [88.66726685, 22.26568985], [88.66731262, 22.26596832], [88.66735077, 22.26623917], [88.66751862, 22.2664299], [88.66752625, 22.26671028], [88.66763306, 22.26701927], [88.66797638, 22.26729965], [88.6682663, 22.26769066], [88.66847229, 22.26820946], [88.66889191, 22.26861191], [88.66889191, 22.26889038], [88.66916656, 22.26916695], [88.66916656, 22.2694397], [88.66971588, 22.27000046], [88.66971588, 22.27028084], [88.66999817, 22.2705555], [88.66999817, 22.27083015], [88.67055511, 22.27138901], [88.67055511, 22.27194595], [88.67082214, 22.27222061], [88.67082214, 22.27250099], [88.67138672, 22.27305412], [88.67138672, 22.27333069], [88.67166901, 22.27362061], [88.67166901, 22.27388954], [88.67194366, 22.27388954], [88.67230988, 22.27425575], [88.67250061, 22.27444458], [88.67277527, 22.27444458], [88.67444611, 22.2761097], [88.67444611, 22.27638817], [88.67437744, 22.27645302], [88.67469788, 22.27700043], [88.67494202, 22.27765083], [88.67533875, 22.27821159], [88.6757431, 22.27867126], [88.67616272, 22.27897263], [88.6764679, 22.27939987], [88.67675018, 22.27991104], [88.67719269, 22.2803154], [88.6775589, 22.28072357], [88.67786407, 22.28105354], [88.67807007, 22.28133965], [88.67832947, 22.28162956], [88.67867279, 22.28201294], [88.67903137, 22.28252029], [88.67944336, 22.28308105], [88.6799469, 22.28360176], [88.68052673, 22.28406906], [88.6809845, 22.28448296], [88.68132782, 22.28489113], [88.68158722, 22.28540993], [88.6818161, 22.28601837], [88.68196869, 22.28664207], [88.68218231, 22.28714561], [88.68238831, 22.28765106], [88.68260956, 22.2881279], [88.68278503, 22.28853226], [88.68296814, 22.28883934], [88.6831131, 22.28917122], [88.68325043, 22.28948975], [88.68333435, 22.28990746], [88.68357849, 22.29032135], [88.68376923, 22.2907505], [88.68385315, 22.29118919], [88.68387604, 22.2916317], [88.68398285, 22.29203033], [88.68415833, 22.2923584], [88.68434906, 22.29268456], [88.68453217, 22.29305458], [88.68467712, 22.29343987], [88.68476105, 22.29387093], [88.68492126, 22.29427528], [88.68498993, 22.29470825], [88.68499756, 22.29515076], [88.68496704, 22.29556274], [88.68488312, 22.29597282], [88.68486786, 22.29649734], [88.68486786, 22.29714012], [88.68493652, 22.29776955], [88.68482971, 22.29838943], [88.68469238, 22.29906082], [88.68445587, 22.29971123], [88.68417358, 22.30033684], [88.68389893, 22.3009758], [88.68369293, 22.30161476], [88.68357086, 22.30220985], [88.68335724, 22.3026619], [88.68318176, 22.30306625], [88.68302155, 22.30347061], [88.68286133, 22.30387115], [88.68292999, 22.30436707], [88.6827774, 22.30491066], [88.68255615, 22.30548859], [88.68226624, 22.30604935], [88.68196106, 22.30651093], [88.68170929, 22.30697441], [88.68157959, 22.30752945], [88.68138123, 22.30805016], [88.68115234, 22.30854988], [88.68103027, 22.30911064], [88.68087006, 22.30964088], [88.68083191, 22.31013107], [88.6807785, 22.31055069], [88.68061066, 22.31081963], [88.68052673, 22.31105042], [88.68045044, 22.31126022], [88.68051147, 22.31151009], [88.68089294, 22.31183815], [88.68109894, 22.31213188], [88.68115234, 22.3123951], [88.68125916, 22.31265259], [88.68135834, 22.31294823], [88.68133545, 22.31333923], [88.68110657, 22.31373978], [88.68084717, 22.31418991], [88.68064117, 22.3146801], [88.68055725, 22.31516647], [88.68048096, 22.31562424], [88.680336, 22.31600189], [88.68016815, 22.31632805], [88.68016052, 22.31678009], [88.68022156, 22.31724739], [88.68016815, 22.31765175], [88.68000031, 22.31805611], [88.67973328, 22.31833076], [88.67973328, 22.31890106], [88.67944336, 22.31916618], [88.67944336, 22.31971931], [88.6791687, 22.3200016], [88.6791687, 22.32278061], [88.67888641, 22.3230629], [88.67972565, 22.32388878], [88.67972565, 22.32472229], [88.68000793, 22.32500076], [88.68000793, 22.32528114], [88.68028259, 22.32555962], [88.68083191, 22.3255558], [88.6811142, 22.32583427], [88.68165588, 22.32583046], [88.6819458, 22.32611084], [88.68499756, 22.32611084], [88.68517303, 22.32599068], [88.68560791, 22.32587624], [88.6860733, 22.32578087], [88.68650818, 22.32566643], [88.68696594, 22.32561111], [88.68743896, 22.32559586], [88.68791199, 22.3256321], [88.6884079, 22.32573318], [88.68888855, 22.32583427], [88.68916321, 22.3255558], [88.68972015, 22.3255558], [88.68986511, 22.32569695], [88.69000244, 22.32583427], [88.6902771, 22.32583046], [88.69055176, 22.32611084], [88.69055176, 22.32666588], [88.6902771, 22.32694435], [88.6883316, 22.32694435], [88.68805695, 22.32722282], [88.68694305, 22.32722282], [88.68638611, 22.32777786], [88.68583679, 22.32777023], [88.68554688, 22.32806015], [88.68527985, 22.32805443], [88.68499756, 22.3283329], [88.6847229, 22.3283329], [88.68444824, 22.32861137], [88.6838913, 22.32860947], [88.68360901, 22.32888985], [88.68165588, 22.32888985], [88.68138885, 22.32917023], [88.68083191, 22.32917023], [88.68055725, 22.32888985], [88.68028259, 22.32888985], [88.67977905, 22.32839012], [88.67944336, 22.32805443], [88.6791687, 22.32806015], [88.67888641, 22.32777023], [88.67861176, 22.32777023], [88.6783371, 22.32806015], [88.67749786, 22.32806015], [88.67666626, 22.32722092], [88.6763916, 22.32722282], [88.67610931, 22.32694435], [88.67583466, 22.32694435], [88.67555237, 22.32666588], [88.67500305, 22.32666969], [88.67415619, 22.32583046], [88.67388916, 22.32583427], [88.6736145, 22.3255558], [88.67333221, 22.3255558], [88.67305756, 22.32583427], [88.6727829, 22.32583046], [88.67222595, 22.32639122], [88.67193604, 22.32639122], [88.67154694, 22.32599449], [88.67138672, 22.32583427], [88.67111206, 22.32583046], [88.67056274, 22.32639122], [88.67055511, 22.32666588], [88.67028046, 22.32694435], [88.67028046, 22.3283329], [88.66999817, 22.32860947], [88.66999817, 22.32916641], [88.66972351, 22.32944489], [88.66971588, 22.32971954], [88.66944122, 22.32999992], [88.66944122, 22.3302803], [88.66889191, 22.33083344], [88.66889191, 22.33221817], [88.66860962, 22.33250046], [88.66860962, 22.33416748], [88.66832733, 22.33444023], [88.66832733, 22.3350029], [88.66860962, 22.33527946], [88.66860962, 22.33555603], [88.66832733, 22.3358326], [88.66832733, 22.33611107], [88.66777802, 22.33666611], [88.66777802, 22.33694458], [88.66750336, 22.33722115], [88.66750336, 22.33749962], [88.66722107, 22.33777809], [88.66722107, 22.33805466], [88.66694641, 22.33833122], [88.66677094, 22.33871078], [88.66662598, 22.33884811], [88.66648102, 22.33910751], [88.66633606, 22.33917427], [88.66612244, 22.33904076], [88.66597748, 22.33876991], [88.6656189, 22.33823776], [88.66583252, 22.33749962], [88.66665649, 22.33666992], [88.66665649, 22.33638954], [88.66694641, 22.33611107], [88.66694641, 22.3358326], [88.66722107, 22.33555603], [88.66722107, 22.3350029], [88.66694641, 22.33472252], [88.66722107, 22.33444405], [88.66722107, 22.33389091], [88.66694641, 22.33360863], [88.66694641, 22.33305931], [88.66722107, 22.33278084], [88.66722107, 22.33167076], [88.66777802, 22.33110809], [88.66777802, 22.33083344], [88.66750336, 22.33056068], [88.66781616, 22.33014107], [88.66806793, 22.32974815], [88.66829681, 22.32936096], [88.66846466, 22.32897568], [88.66858673, 22.32860947], [88.66864777, 22.32818222], [88.66873932, 22.32770538], [88.66889954, 22.32723808], [88.66909027, 22.3267498], [88.66944122, 22.32583427], [88.66972351, 22.3255558], [88.66971588, 22.32528114], [88.67056274, 22.32444], [88.67082977, 22.32444382], [88.67250061, 22.3227787], [88.67250061, 22.32250023], [88.67333221, 22.32167053], [88.67333221, 22.32139015], [88.67366028, 22.32118034], [88.67395782, 22.32095909], [88.674263, 22.32069969], [88.67453766, 22.32040977], [88.67471313, 22.32006645], [88.67485809, 22.31970978], [88.67502594, 22.31933975], [88.67523956, 22.31895065], [88.67539978, 22.31850052], [88.67557526, 22.31805038], [88.67581177, 22.31762314], [88.67597961, 22.3171463], [88.67583466, 22.31646729], [88.67562103, 22.31583023], [88.67559052, 22.3152771], [88.67569733, 22.31479073], [88.67579651, 22.31431007], [88.67584229, 22.3138485], [88.67591858, 22.31348038], [88.67611694, 22.3132], [88.67626953, 22.31287766], [88.67636871, 22.31246948], [88.67658997, 22.31199265], [88.67699432, 22.31139946], [88.67711639, 22.31071091], [88.67697906, 22.31007957], [88.67690277, 22.30950165], [88.67678833, 22.30899811], [88.67682648, 22.30860138], [88.67695618, 22.30828094], [88.67711639, 22.30799294], [88.67720032, 22.30764961], [88.67723846, 22.30724335], [88.67735291, 22.30681419], [88.67753601, 22.30634308], [88.6776886, 22.30579948], [88.67782593, 22.30527115], [88.6780014, 22.30482292], [88.67803955, 22.30442047], [88.67801666, 22.30405998], [88.67798615, 22.30371284], [88.67803192, 22.30337334], [88.6780777, 22.30297852], [88.67816925, 22.30257034], [88.67829895, 22.30214119], [88.67832947, 22.30166435], [88.67832947, 22.30138969], [88.67832947, 22.30117035], [88.6783371, 22.30027962], [88.67861176, 22.30000114], [88.67861176, 22.29916954], [88.6783371, 22.29889107], [88.6783371, 22.29722023], [88.67805481, 22.29694366], [88.67805481, 22.2966671], [88.6783371, 22.29639053], [88.6783371, 22.29500008], [88.6791687, 22.29417038], [88.6791687, 22.29389191], [88.6783371, 22.2930603], [88.6783371, 22.29249763], [88.67804718, 22.29221916], [88.67805481, 22.2919445], [88.67778015, 22.29166794], [88.67778015, 22.29138756], [88.67749786, 22.29110909], [88.67749786, 22.29083061], [88.67725372, 22.2905674], [88.67707825, 22.29014015], [88.67688751, 22.28951073], [88.6765976, 22.28886032], [88.67620087, 22.28831291], [88.67582703, 22.287817], [88.67543793, 22.28739166], [88.67508698, 22.2869606], [88.67476654, 22.28655052], [88.67451477, 22.28614044], [88.67427063, 22.28580093], [88.67408752, 22.28547287], [88.67391205, 22.28515053], [88.67372131, 22.28482819], [88.67341614, 22.28455925], [88.67314911, 22.28415108], [88.6728363, 22.28367043], [88.67247772, 22.28321075], [88.67207336, 22.28272057], [88.67170715, 22.28215027], [88.67140198, 22.28156853], [88.67112732, 22.28103065], [88.6709137, 22.28059006], [88.67063904, 22.28027916], [88.67032623, 22.28001022], [88.66995239, 22.2798233], [88.66954041, 22.27963066], [88.66921234, 22.27931976], [88.66895294, 22.27896309], [88.66869354, 22.27861214], [88.66843414, 22.27825356], [88.66822815, 22.2778244], [88.66798401, 22.27742386], [88.66775513, 22.2770462], [88.66750336, 22.27672005], [88.6672287, 22.27642059], [88.66697693, 22.27610016], [88.66669464, 22.27577019], [88.66639709, 22.27539063], [88.66607666, 22.27498245], [88.66570282, 22.27459335], [88.66532135, 22.27419281], [88.66499329, 22.27374077], [88.66467285, 22.2732811], [88.66439819, 22.27276993], [88.66413879, 22.27224731], [88.66387177, 22.27173042], [88.66359711, 22.2712326], [88.66335297, 22.27075958], [88.66310883, 22.27029419], [88.66290283, 22.26983833], [88.66265869, 22.26941299], [88.6624527, 22.26894188], [88.66220856, 22.26848221], [88.6619339, 22.26805687], [88.66160583, 22.26768112], [88.66133881, 22.26732826], [88.66107941, 22.26696014], [88.66082764, 22.26658821], [88.66057587, 22.26622009], [88.66042328, 22.26585388], [88.66030121, 22.26550865], [88.66023254, 22.26517105], [88.6601181, 22.26485825], [88.65999603, 22.26389122], [88.65947723, 22.26296997], [88.6581192, 22.26055908], [88.65783691, 22.25976181], [88.65776062, 22.25922012], [88.65783691, 22.25875092], [88.65805054, 22.25842094], [88.65820313, 22.25801086], [88.65840912, 22.25747681], [88.65847778, 22.25640106], [88.65847778, 22.25486374], [88.65833282, 22.25439453], [88.6581192, 22.25385857], [88.65783691, 22.25345993], [88.65769196, 22.25245285], [88.657547, 22.25151443], [88.65725708, 22.25097847], [88.65711212, 22.25064087], [88.65675354, 22.25010681], [88.65638733, 22.24970055], [88.65582275, 22.24916649], [88.65453339, 22.24810028], [88.65380859, 22.24641991], [88.65179443, 22.24447823], [88.65141296, 22.24395561], [88.65055847, 22.24277687], [88.65055847, 22.24250031], [88.65000153, 22.2419529], [88.65000153, 22.24167061], [88.64694214, 22.23861122], [88.64666748, 22.23861122], [88.64527893, 22.23722076], [88.64499664, 22.23749733], [88.64477539, 22.23700142], [88.64442444, 22.23650742], [88.64406586, 22.23608017], [88.64376831, 22.23562813], [88.64338684, 22.23521805], [88.64305878, 22.2347908], [88.64274597, 22.23437119], [88.64238739, 22.23406792], [88.64199066, 22.23384094], [88.64162445, 22.23360252], [88.64128876, 22.23333931], [88.64093781, 22.23307991], [88.64057922, 22.23285103], [88.64026642, 22.23257065], [88.63996887, 22.23229027], [88.63965607, 22.23200989], [88.63937378, 22.23170662], [88.63925171, 22.23159981], [88.63902283, 22.23140335], [88.63859558, 22.23113632], [88.63806152, 22.23097992], [88.63755035, 22.23080826], [88.63710022, 22.2305603], [88.63665009, 22.23031807], [88.63619232, 22.23007965], [88.63577271, 22.22977066], [88.63534546, 22.22948837], [88.63498688, 22.22916031], [88.63466644, 22.22883224], [88.63433838, 22.22852325], [88.63396454, 22.22825813], [88.63363647, 22.22792053], [88.63337708, 22.22752953], [88.63323212, 22.22704124], [88.63302612, 22.22661972], [88.63278198, 22.22623825], [88.6325531, 22.2258606], [88.63230896, 22.22547531], [88.63212585, 22.2250309], [88.63191986, 22.22461128], [88.63168335, 22.22421074], [88.63145447, 22.22380447], [88.63124847, 22.2233696], [88.63104248, 22.22293091], [88.6309433, 22.22249794], [88.63091278, 22.22204971], [88.63098145, 22.22160912], [88.631073, 22.22116089], [88.63109589, 22.22070122], [88.63111115, 22.22024918], [88.63109589, 22.21981049], [88.63108826, 22.21939087], [88.63110352, 22.21900368], [88.6311264, 22.21862411], [88.63121033, 22.21825218], [88.63134766, 22.21787643], [88.6313858, 22.21746063], [88.6313858, 22.2170105], [88.6313858, 22.21655464], [88.63140869, 22.21607208], [88.63150787, 22.21557045], [88.63166809, 22.21504974], [88.63188171, 22.21451187], [88.63212585, 22.21399117], [88.63227844, 22.21376228], [88.63246155, 22.21349907], [88.63279724, 22.21297073], [88.63318634, 22.21248055], [88.63357544, 22.21201515], [88.6340332, 22.21167564], [88.63448334, 22.21138954], [88.63491058, 22.21109962], [88.63530731, 22.21080971], [88.63574982, 22.21054077], [88.63617706, 22.21023178], [88.6366806, 22.20997047], [88.637146, 22.20965004], [88.63755798, 22.20928764], [88.63794708, 22.20895004], [88.63832092, 22.20868874], [88.63865662, 22.20846939], [88.63900757, 22.20829964], [88.63934326, 22.20812035], [88.63973999, 22.2080307], [88.64012909, 22.20788956], [88.64048004, 22.20766068], [88.64086151, 22.20755386], [88.64124298, 22.20747948], [88.64161682, 22.20738029], [88.64200592, 22.20734978], [88.64237213, 22.20734978], [88.64272308, 22.20738029], [88.6431427, 22.20744705], [88.64359283, 22.20749283], [88.64404297, 22.20749283], [88.64444733, 22.2074585], [88.64480591, 22.20742035], [88.64520264, 22.20737267], [88.64565277, 22.20740128], [88.64608765, 22.20747948], [88.64655304, 22.20750809], [88.6470871, 22.20755005], [88.6476593, 22.20772743], [88.64827728, 22.20773315], [88.64883423, 22.20754051], [88.6493454, 22.20744133], [88.64974213, 22.20726585], [88.65011597, 22.20722008], [88.65049744, 22.20722198], [88.65088654, 22.2072506], [88.65130615, 22.20740128], [88.65174866, 22.20747757], [88.65215302, 22.20754051], [88.65249634, 22.20773125], [88.65289307, 22.20776939], [88.65328979, 22.20776558], [88.65370178, 22.20779037], [88.65413666, 22.20788956], [88.65461731, 22.20801163], [88.65518188, 22.20807838], [88.65576935, 22.20824814], [88.65638733, 22.2083149], [88.65698242, 22.20825958], [88.65750885, 22.20810127], [88.6579895, 22.20806122], [88.65841675, 22.20804977], [88.65881348, 22.20805359], [88.65920258, 22.20807076], [88.65960693, 22.20814514], [88.66005707, 22.20826149], [88.66056061, 22.20824051], [88.66108704, 22.20845985], [88.66176605, 22.20850945], [88.6624527, 22.20836067], [88.66311646, 22.20828056], [88.66378021, 22.20804977], [88.6644516, 22.20783043], [88.66513062, 22.2078228], [88.665802, 22.20796967], [88.66641235, 22.20798111], [88.66702271, 22.20779037], [88.6676178, 22.20763969], [88.6681366, 22.20748138], [88.66860199, 22.20726776], [88.66903687, 22.20701981], [88.669487, 22.20677185], [88.66995239, 22.20655441], [88.67040253, 22.20627403], [88.67089844, 22.20598793], [88.6714859, 22.20574188], [88.67210388, 22.2054348], [88.67259216, 22.20505905], [88.67254639, 22.20467949], [88.67253876, 22.20420456], [88.67262268, 22.20365143], [88.67267609, 22.20303535], [88.67267609, 22.20240021], [88.67253876, 22.20179939], [88.67246246, 22.20119858], [88.67230988, 22.20063019], [88.67218018, 22.20013428], [88.67198181, 22.19964218], [88.67180634, 22.19911957], [88.67165375, 22.19857788], [88.67150116, 22.19803047], [88.6713562, 22.19749641], [88.67115784, 22.19702911], [88.67097473, 22.19658661], [88.67080688, 22.19614029], [88.67061615, 22.19572258], [88.67044067, 22.19529915], [88.67024231, 22.19488907], [88.66999054, 22.19452095], [88.66973114, 22.19409943], [88.66950226, 22.19363976], [88.66938782, 22.19304085], [88.66915894, 22.19254875], [88.66886902, 22.19210815], [88.66861725, 22.19177437], [88.66838837, 22.19142532], [88.66822815, 22.19101906], [88.66803741, 22.19060135], [88.66778564, 22.1901989], [88.6675415, 22.18975067], [88.66731262, 22.18926048], [88.66707611, 22.18874168], [88.66682434, 22.18823814], [88.66647339, 22.18786049], [88.6661377, 22.18753052], [88.66584778, 22.1872406], [88.66564178, 22.18695259], [88.66545868, 22.1866951], [88.66529083, 22.18643951], [88.66513062, 22.1861496], [88.66493225, 22.18581963], [88.66467285, 22.18540955], [88.66426849, 22.18498039], [88.6638031, 22.18451118], [88.66326904, 22.18408012], [88.66278839, 22.18363762], [88.66233826, 22.1832695], [88.66201019, 22.18287277], [88.66166687, 22.18262672], [88.66136932, 22.18240166], [88.66110229, 22.18217278], [88.66083527, 22.18193436], [88.66055298, 22.18167114], [88.66018677, 22.18138123], [88.65981293, 22.18106079], [88.65944672, 22.18066978], [88.65911102, 22.18027687], [88.6587677, 22.17990685], [88.65836334, 22.1796608], [88.65795898, 22.17942429], [88.65757751, 22.17914009], [88.6572113, 22.17881012], [88.65679932, 22.17847061], [88.65637207, 22.17811966], [88.65592957, 22.17779541], [88.65549469, 22.17753029], [88.65511322, 22.17731094], [88.65478516, 22.17708778], [88.65453339, 22.17687988], [88.65434265, 22.17667961], [88.65413666, 22.1764698], [88.65390778, 22.17623138], [88.65365601, 22.17589188], [88.65335083, 22.17550087], [88.6530304, 22.17510605], [88.65267181, 22.17477036], [88.65231323, 22.1744976], [88.6520462, 22.17421532], [88.6516571, 22.17389107], [88.65139008, 22.17361069], [88.65139008, 22.1733284], [88.65110779, 22.17305565], [88.65083313, 22.17305946], [88.65027618, 22.17250061], [88.65000153, 22.17222214], [88.65000153, 22.17194366], [88.64916992, 22.17111206], [88.64888763, 22.17073822], [88.64865112, 22.17050171], [88.64839935, 22.17020988], [88.64816284, 22.16983986], [88.64787292, 22.16945839], [88.64753723, 22.16908073], [88.64722443, 22.16867828], [88.64689636, 22.16827965], [88.646492, 22.16794968], [88.64619446, 22.16749191], [88.64602661, 22.16682816], [88.64552307, 22.16642952], [88.6453476, 22.16571236], [88.64498138, 22.16520119], [88.64456177, 22.16477966], [88.64409637, 22.16447067], [88.6436615, 22.16423988], [88.64333344, 22.16394043], [88.64305878, 22.16361046], [88.6428299, 22.1632309], [88.64265442, 22.16278839], [88.64245605, 22.16233063], [88.64239502, 22.16224098], [88.64218903, 22.16192436], [88.64190674, 22.16156769], [88.64170074, 22.16114998], [88.6415329, 22.16074371], [88.64139557, 22.16042519], [88.64128113, 22.16011047], [88.64111328, 22.15981293], [88.64098358, 22.15949631], [88.64084625, 22.15920067], [88.64076233, 22.15891457], [88.64055634, 22.15867615], [88.64025879, 22.15850067], [88.64008331, 22.15827179], [88.63995361, 22.15802574], [88.63967896, 22.15777969], [88.63948059, 22.1574707], [88.63933563, 22.15710831], [88.63916779, 22.15666962], [88.63889313, 22.15639114], [88.63889313, 22.15611076], [88.63861084, 22.1558342], [88.63861084, 22.15555763], [88.63833618, 22.15528107], [88.63833618, 22.15417099], [88.63861084, 22.15389061], [88.63861084, 22.15361023], [88.63889313, 22.15332985], [88.6388855, 22.15250015], [88.63916779, 22.15222168], [88.63916779, 22.15166664], [88.63944244, 22.15139008], [88.63944244, 22.1511097], [88.63972473, 22.15083313], [88.63972473, 22.15027809], [88.63999939, 22.14999962], [88.63999939, 22.14944267], [88.64027405, 22.14916611], [88.64026642, 22.14723015], [88.64055634, 22.14693832], [88.64055634, 22.14500046], [88.64083862, 22.14471817], [88.64064026, 22.14400673], [88.64037323, 22.14344978], [88.64002228, 22.14298058], [88.63965607, 22.1425705], [88.63931274, 22.14221954], [88.63894653, 22.14188194], [88.63858032, 22.14150238], [88.63816071, 22.1411171], [88.63768768, 22.14073181], [88.63723755, 22.14029121], [88.6368103, 22.13986969], [88.63643646, 22.13949013], [88.63613892, 22.13917923], [88.63587189, 22.13894272], [88.63559723, 22.13877106], [88.6353302, 22.13857079], [88.6350708, 22.13833046], [88.63479614, 22.13807106], [88.6344986, 22.13781929], [88.63421631, 22.13751984], [88.63394165, 22.13722992], [88.63365173, 22.13697815], [88.6333313, 22.13678932], [88.63300323, 22.13665962], [88.63269043, 22.13660049], [88.6324234, 22.1366806], [88.63226318, 22.13697815], [88.63214874, 22.13749886], [88.63200378, 22.13797379], [88.63195801, 22.13848114], [88.63194275, 22.13861084], [88.63194275, 22.13972092], [88.63166809, 22.13999939], [88.63166809, 22.1408329], [88.6313858, 22.14111137], [88.6313858, 22.14221954], [88.63111115, 22.14249992], [88.63111115, 22.14471817], [88.63054657, 22.14528084], [88.6297226, 22.14528084], [88.6297226, 22.14360809], [88.62999725, 22.14333344], [88.62999725, 22.14277649], [88.63027954, 22.14249992], [88.63027954, 22.14083099], [88.6305542, 22.14055443], [88.63054657, 22.13972092], [88.63083649, 22.13944435], [88.63083649, 22.13888931], [88.63082123, 22.13845253], [88.63087463, 22.13797188], [88.6309967, 22.13746071], [88.63121796, 22.13692856], [88.63150787, 22.13637161], [88.63140106, 22.13583374], [88.63122559, 22.13526154], [88.63102722, 22.13469124], [88.63067627, 22.1342907], [88.63034058, 22.13391113], [88.62996674, 22.13359642], [88.62966156, 22.13326073], [88.6293869, 22.13294029], [88.62914276, 22.13265038], [88.62888336, 22.13240623], [88.62858582, 22.13216972], [88.62827301, 22.13191032], [88.62796783, 22.13158417], [88.62761688, 22.13121414], [88.62728119, 22.13080978], [88.62696075, 22.13041115], [88.62667084, 22.13005066], [88.62641144, 22.12972832], [88.62622833, 22.12943077], [88.626091, 22.12912941], [88.62593842, 22.12885284], [88.62581635, 22.12857246], [88.62567139, 22.12829971], [88.62553406, 22.12801361], [88.62537384, 22.12772179], [88.62523651, 22.12737083], [88.62504578, 22.12699127], [88.62491608, 22.12650108], [88.62471008, 22.12603951], [88.62445068, 22.12560272], [88.62423706, 22.12515068], [88.62407684, 22.12466049], [88.62388611, 22.12424088], [88.62371063, 22.1238575], [88.6235733, 22.12347984], [88.6233902, 22.12319183], [88.62326813, 22.12288094], [88.62310791, 22.12262154], [88.62301636, 22.12228966], [88.62290955, 22.12195778], [88.62278748, 22.12157822], [88.62265015, 22.12112045], [88.62246704, 22.12061501], [88.62224579, 22.12008286], [88.62210083, 22.11953354], [88.62197876, 22.11904335], [88.6219101, 22.1186142], [88.6218338, 22.11825752], [88.62169647, 22.11797905], [88.62161255, 22.11764908], [88.62148285, 22.1172905], [88.62138367, 22.11684036], [88.6212616, 22.11635971], [88.62111664, 22.1158905], [88.62094879, 22.11540985], [88.62077332, 22.11488914], [88.62064362, 22.11427879], [88.62050629, 22.11364174], [88.62030792, 22.11302948], [88.62017059, 22.11243057], [88.62000275, 22.11186981], [88.6198349, 22.11134911], [88.61974335, 22.11079979], [88.61967468, 22.11017036], [88.61962891, 22.10943031], [88.61928558, 22.10884094], [88.61864471, 22.10864449], [88.61795807, 22.10863686], [88.6173172, 22.10864258], [88.61683655, 22.10843468], [88.6162796, 22.10828972], [88.61572266, 22.10810089], [88.6151123, 22.10806274], [88.61448669, 22.10806274], [88.6138916, 22.10803032], [88.61333466, 22.10791969], [88.61279297, 22.10779953], [88.61225128, 22.10773087], [88.61178589, 22.1075592], [88.61126709, 22.10750008], [88.61075592, 22.10750008], [88.61023712, 22.10758018], [88.60979462, 22.10786629], [88.60955811, 22.10840034], [88.60954285, 22.10908699], [88.60968018, 22.10972023], [88.60980225, 22.1102829], [88.61000061, 22.11067963], [88.61016846, 22.1110611], [88.6103363, 22.11145782], [88.61052704, 22.11190224], [88.61071777, 22.11240005], [88.61087036, 22.11292839], [88.61094666, 22.11349106], [88.61091614, 22.1140995], [88.61087036, 22.11468697], [88.61082458, 22.11520195], [88.61074066, 22.11562538], [88.61061859, 22.11596107], [88.61055756, 22.11629295], [88.610466, 22.1165905], [88.61032867, 22.11686516], [88.61016846, 22.11718369], [88.6099472, 22.11750031], [88.60968018, 22.11785126], [88.60943604, 22.11826134], [88.60916901, 22.11867142], [88.60889435, 22.11907387], [88.60861969, 22.11946487], [88.6083374, 22.11985207], [88.60804749, 22.12023163], [88.60774994, 22.12061119], [88.60748291, 22.12103081], [88.60722351, 22.12144089], [88.60694122, 22.12182999], [88.60664368, 22.12220573], [88.6063385, 22.12257195], [88.60608673, 22.12298965], [88.60584259, 22.12338066], [88.60559082, 22.12374115], [88.60534668, 22.12409019], [88.60510254, 22.1244297], [88.60481262, 22.1247406], [88.60450745, 22.12504959], [88.60420227, 22.1253891], [88.60391235, 22.12571907], [88.60365295, 22.12607956], [88.60340881, 22.12643814], [88.60320282, 22.12677193], [88.60299683, 22.1270504], [88.60281372, 22.12736511], [88.60263062, 22.12779236], [88.6023941, 22.12817383], [88.60214996, 22.12855339], [88.60196686, 22.12898254], [88.60166168, 22.12944031], [88.60166168, 22.13000107], [88.60111237, 22.13055992], [88.60111237, 22.13138962], [88.60083008, 22.13166809], [88.60056305, 22.13138962], [88.60055542, 22.13027954], [88.60028076, 22.13000107], [88.60028076, 22.12972069], [88.60083008, 22.12916565], [88.60083008, 22.12861061], [88.60111237, 22.12833023], [88.60111237, 22.12805557], [88.60138702, 22.12778091], [88.60138702, 22.12750053], [88.60193634, 22.12693977], [88.60083008, 22.12693977], [88.59999847, 22.12778091], [88.59999847, 22.12805557], [88.59971619, 22.12833023], [88.59972382, 22.12861061], [88.59916687, 22.12916565], [88.59916687, 22.12944412], [88.59889221, 22.1297226], [88.59889221, 22.13083076], [88.59860992, 22.13111115], [88.59860992, 22.13305473], [88.59916687, 22.13361168], [88.59889221, 22.13389015], [88.59889221, 22.1352787], [88.59921265, 22.13547134], [88.59938049, 22.13607025], [88.59947968, 22.13679504], [88.599617, 22.13751984], [88.59976196, 22.13821983], [88.59999847, 22.13880348], [88.60025787, 22.13931465], [88.60054016, 22.13978958], [88.60085297, 22.14024162], [88.60119629, 22.14043808], [88.60148621, 22.14030075], [88.60157013, 22.13983154], [88.60144806, 22.13928986], [88.60134888, 22.13879013], [88.60124207, 22.13838959], [88.60137939, 22.13805962], [88.60153198, 22.13775063], [88.60172272, 22.13746834], [88.60196686, 22.13727379], [88.60224152, 22.1373291], [88.60250854, 22.13771057], [88.60273743, 22.13817024], [88.60288239, 22.13870049], [88.60301971, 22.13926125], [88.60305023, 22.13982582], [88.60307312, 22.1403904], [88.60315704, 22.14093971], [88.60328674, 22.14149284], [88.60333252, 22.14206123], [88.60333252, 22.14262962], [88.60334015, 22.14319992], [88.6033783, 22.1437645], [88.60353088, 22.14429092], [88.60364532, 22.14482689], [88.60379028, 22.14535141], [88.60386658, 22.14593124], [88.60388947, 22.14651108], [88.60394287, 22.14705086], [88.60404968, 22.1475029], [88.60414886, 22.14789009], [88.60415649, 22.14825058], [88.60418701, 22.14857101], [88.60430145, 22.14888191], [88.60440826, 22.14928055], [88.60446167, 22.14974976], [88.60455322, 22.15023041], [88.60468292, 22.15069008], [88.60473633, 22.15114594], [88.60480499, 22.15154076], [88.60494232, 22.15185356], [88.60500336, 22.15219307], [88.60507202, 22.15254021], [88.60525513, 22.15289497], [88.60539246, 22.15332985], [88.60552216, 22.15388107], [88.60555267, 22.15453911], [88.6055603, 22.15526772], [88.60555267, 22.15600014], [88.60547638, 22.15670013], [88.60531616, 22.15730095], [88.60521698, 22.15787125], [88.60505676, 22.1583519], [88.6049881, 22.15880013], [88.60491943, 22.15919113], [88.60475922, 22.15946388], [88.60462952, 22.15977478], [88.60443878, 22.1600399], [88.60418701, 22.16032028], [88.60389709, 22.16068077], [88.60359955, 22.16106987], [88.60324097, 22.1614418], [88.60281372, 22.16174126], [88.60237885, 22.16202164], [88.60188293, 22.16225052], [88.60137939, 22.16251945], [88.60087585, 22.16277122], [88.60034943, 22.16302109], [88.59980011, 22.16321945], [88.59924316, 22.1633606], [88.59868622, 22.16351128], [88.59812927, 22.16364098], [88.59760284, 22.1638298], [88.59705353, 22.16393661], [88.59655762, 22.16410065], [88.59606934, 22.16415977], [88.5956192, 22.16418457], [88.59520721, 22.16424942], [88.59481812, 22.1644001], [88.59442139, 22.1644516], [88.59403229, 22.16451454], [88.59366608, 22.16464043], [88.59323883, 22.16471291], [88.59274292, 22.16477776], [88.59223175, 22.16493988], [88.59165955, 22.16504669], [88.59106445, 22.16521263], [88.59041595, 22.16526985], [88.58978271, 22.16534042], [88.58921051, 22.16551971], [88.58863068, 22.16567039], [88.58809662, 22.16584969], [88.58763885, 22.16611099], [88.58721161, 22.16637039], [88.5867691, 22.16661072], [88.58629608, 22.16679955], [88.58585358, 22.16704941], [88.58544922, 22.1673317], [88.58503723, 22.16765022], [88.58466339, 22.16801643], [88.5842514, 22.16839981], [88.58383942, 22.16882706], [88.58344269, 22.16925049], [88.58307648, 22.1697197], [88.58277893, 22.17020035], [88.5825119, 22.17066002], [88.58229828, 22.17112732], [88.58222198, 22.17167091], [88.58215332, 22.17223549], [88.58202362, 22.17279434], [88.58201599, 22.17334175], [88.58213806, 22.17385101], [88.58221436, 22.17433739], [88.58226776, 22.17477989], [88.5823822, 22.17518806], [88.58249664, 22.17564011], [88.58261108, 22.17615891], [88.58272552, 22.17673111], [88.5827713, 22.17735291], [88.58282471, 22.17798805], [88.582901, 22.17861557], [88.58281708, 22.17918015], [88.58274078, 22.17970276], [88.58261871, 22.18013954], [88.58246613, 22.1805191], [88.58229065, 22.18086815], [88.58213043, 22.18122292], [88.58194733, 22.18152618], [88.5817337, 22.18187141], [88.58148193, 22.18226242], [88.5811615, 22.18272209], [88.5807724, 22.1831646], [88.58035278, 22.18354988], [88.57991791, 22.18387032], [88.57950592, 22.18414116], [88.57911682, 22.18438911], [88.57872772, 22.1846199], [88.57829285, 22.18482018], [88.57784271, 22.18499756], [88.57744598, 22.1852169], [88.57704163, 22.18547249], [88.57658386, 22.18579483], [88.57602692, 22.18616104], [88.57544708, 22.18661118], [88.57492065, 22.18709946], [88.57443237, 22.18758965], [88.57406616, 22.18806267], [88.57386017, 22.18851089], [88.57377625, 22.18892097], [88.57377625, 22.18931007], [88.57386017, 22.18969917], [88.57396698, 22.19009018], [88.57414246, 22.19049072], [88.57434845, 22.19091988], [88.57453918, 22.19142914], [88.57476807, 22.1919651], [88.57504272, 22.19248962], [88.57532501, 22.19297791], [88.57563019, 22.19338989], [88.57590485, 22.1937561], [88.57611084, 22.19413948], [88.57628632, 22.19449997], [88.57642365, 22.19484901], [88.57657623, 22.19514275], [88.57673645, 22.19540977], [88.57691956, 22.19573784], [88.57710266, 22.19615364], [88.57730103, 22.19656372], [88.57750702, 22.19695854], [88.5777359, 22.19734955], [88.57785797, 22.19777107], [88.57775879, 22.19819832], [88.57749939, 22.19846916], [88.57718658, 22.19843292], [88.57691956, 22.19816017], [88.57666779, 22.19776535], [88.57641602, 22.19738007], [88.57621765, 22.19697952], [88.57602692, 22.19659042], [88.57588196, 22.19618988], [88.57572937, 22.19584846], [88.57563782, 22.19548035], [88.57556915, 22.19503975], [88.57541656, 22.19458961], [88.57518768, 22.19415092], [88.57495117, 22.19370079], [88.57466125, 22.19324112], [88.57435608, 22.19272995], [88.57408905, 22.19218826], [88.57386017, 22.19165039], [88.5736618, 22.19114113], [88.57344818, 22.19065094], [88.57319641, 22.19013977], [88.57292938, 22.18960953], [88.57274628, 22.18910027], [88.57277679, 22.18873215], [88.57283783, 22.1883316], [88.5729599, 22.18791008], [88.57316589, 22.18749046], [88.57343292, 22.18702126], [88.57373047, 22.18655014], [88.5741272, 22.18616104], [88.57454681, 22.18584251], [88.5749588, 22.18555069], [88.5753479, 22.18527603], [88.575737, 22.18499756], [88.57611847, 22.18473816], [88.57652283, 22.1844902], [88.57694244, 22.18430519], [88.57736206, 22.18411064], [88.57776642, 22.18388748], [88.57817078, 22.18366432], [88.57859802, 22.18344116], [88.57904053, 22.18317032], [88.57949066, 22.18280029], [88.57995605, 22.18235016], [88.58039856, 22.18181992], [88.58080292, 22.18126106], [88.58110809, 22.18071747], [88.58130646, 22.18019295], [88.58141327, 22.1796608], [88.58148193, 22.17914963], [88.581604, 22.17869949], [88.58164215, 22.17822838], [88.58158875, 22.17776108], [88.58144379, 22.1773262], [88.58130646, 22.17683029], [88.58117676, 22.17629814], [88.58106995, 22.17579079], [88.58091736, 22.17535019], [88.58080292, 22.17488098], [88.58067322, 22.17445374], [88.5806427, 22.17396164], [88.58065796, 22.17344093], [88.58071136, 22.17292023], [88.58081818, 22.17250061], [88.58086395, 22.17209244], [88.58088684, 22.1716404], [88.58094788, 22.17114067], [88.58112335, 22.17064095], [88.58135223, 22.17007065], [88.58167267, 22.16950989], [88.58205414, 22.16905975], [88.58244324, 22.16864967], [88.5827713, 22.16819954], [88.58309937, 22.16771126], [88.58348083, 22.16723061], [88.58390808, 22.16675758], [88.58436584, 22.16633606], [88.58483124, 22.16592979], [88.5853653, 22.16560364], [88.58595276, 22.16530037], [88.586586, 22.16501045], [88.58725739, 22.16472054], [88.58789063, 22.16444778], [88.58849335, 22.16419029], [88.58909607, 22.1639595], [88.58972931, 22.16379929], [88.59034729, 22.16366005], [88.59095764, 22.16356087], [88.59147644, 22.1633606], [88.59197235, 22.16320038], [88.592453, 22.16309929], [88.59294891, 22.16303062], [88.59346008, 22.16292953], [88.59398651, 22.16281891], [88.59453583, 22.16274071], [88.59503937, 22.16262817], [88.59552765, 22.16254044], [88.59603119, 22.16250038], [88.59654236, 22.16244125], [88.59706116, 22.16230965], [88.59758759, 22.16220284], [88.5980835, 22.16206932], [88.59855652, 22.16193962], [88.5990448, 22.16181374], [88.59958649, 22.16170883], [88.60016632, 22.16163063], [88.6007843, 22.16147995], [88.60137939, 22.16119194], [88.60196686, 22.16078949], [88.60250092, 22.16029549], [88.60299683, 22.15974998], [88.60337067, 22.15908813], [88.60360718, 22.15839577], [88.60373688, 22.15769958], [88.60365295, 22.15707397], [88.6035614, 22.15640831], [88.60336304, 22.15577126], [88.60318756, 22.15511894], [88.60308075, 22.15446854], [88.60305786, 22.15385818], [88.60305023, 22.15328026], [88.60300446, 22.15274239], [88.60282898, 22.15224075], [88.6027298, 22.15168381], [88.60254669, 22.15111923], [88.60250092, 22.15044022], [88.60249329, 22.14969635], [88.60244751, 22.14894676], [88.60227203, 22.14830017], [88.60214996, 22.14771652], [88.60199738, 22.14715958], [88.60193634, 22.14656067], [88.60188293, 22.14598274], [88.60173798, 22.14544106], [88.60166931, 22.14490509], [88.60159302, 22.14439011], [88.6014328, 22.14388084], [88.60134125, 22.14336014], [88.60116577, 22.14290047], [88.60105133, 22.14238548], [88.60082245, 22.14194107], [88.60056305, 22.14154816], [88.60027313, 22.14118004], [88.59998322, 22.14084816], [88.59966278, 22.14053154], [88.59938049, 22.14017105], [88.59914398, 22.13971138], [88.59890747, 22.1391983], [88.59868622, 22.13863945], [88.59851074, 22.13799095], [88.59844971, 22.13725471], [88.59829712, 22.1365509], [88.5981369, 22.13594055], [88.59809113, 22.1354599], [88.5980835, 22.13503075], [88.59790039, 22.1345005], [88.59764099, 22.13401985], [88.59745026, 22.1335392], [88.59735107, 22.13307953], [88.59733582, 22.13262749], [88.59739685, 22.13212013], [88.59745026, 22.13158989], [88.59749603, 22.13108253], [88.59757233, 22.13062096], [88.59771729, 22.13017273], [88.59790039, 22.12965965], [88.59812164, 22.12914085], [88.59831238, 22.1286602], [88.598526, 22.12828255], [88.59874725, 22.12798691], [88.59897614, 22.12772751], [88.59921265, 22.12747955], [88.59944916, 22.12722015], [88.59971619, 22.12695694], [88.60003662, 22.12667084], [88.60045624, 22.12638664], [88.60098267, 22.12614059], [88.60157013, 22.12597084], [88.60211182, 22.12578201], [88.60250854, 22.12552071], [88.60282135, 22.12520027], [88.60308075, 22.12482834], [88.60336304, 22.1244812], [88.60365295, 22.12415123], [88.60392761, 22.12382317], [88.60417938, 22.12346649], [88.60443878, 22.12312126], [88.60468292, 22.12277031], [88.60494232, 22.12240982], [88.60520935, 22.12203789], [88.60549164, 22.12168121], [88.60571289, 22.12125969], [88.60591125, 22.12088966], [88.60611725, 22.12057114], [88.60633087, 22.12030411], [88.60649109, 22.12005043], [88.60666656, 22.11983109], [88.60688782, 22.11962128], [88.60712433, 22.1193676], [88.60739136, 22.11905289], [88.60765839, 22.1186409], [88.60797882, 22.11823082], [88.60826874, 22.11780548], [88.60848999, 22.11735725], [88.60869598, 22.1169796], [88.60890961, 22.11665154], [88.60910797, 22.11633301], [88.60923767, 22.11594963], [88.60939026, 22.11553955], [88.60942841, 22.11502457], [88.60944366, 22.11441612], [88.60943604, 22.11374092], [88.60936737, 22.11304283], [88.60914612, 22.11234283], [88.60887909, 22.11168098], [88.60857391, 22.11109924], [88.60826111, 22.1106205], [88.60800934, 22.11032867], [88.60749817, 22.10972023], [88.60749817, 22.10944366], [88.60722351, 22.1091671], [88.60721588, 22.10889053], [88.60666656, 22.10833168], [88.60666656, 22.10777855], [88.60721588, 22.1072216], [88.60744476, 22.1070118], [88.60769653, 22.10704994], [88.6079483, 22.10700035], [88.60820007, 22.10695267], [88.60868835, 22.10684013], [88.60910034, 22.10666084], [88.60943604, 22.10639191], [88.61000061, 22.10639191], [88.6102829, 22.10611153], [88.61055756, 22.10611153], [88.6108017, 22.10605621], [88.61126709, 22.10611153], [88.61174774, 22.10616875], [88.61222076, 22.10630035], [88.61281586, 22.10633278], [88.61347961, 22.10637093], [88.614151, 22.10638046], [88.61480713, 22.10634995], [88.61546326, 22.10624123], [88.61608124, 22.10614777], [88.6166687, 22.10606956], [88.61717224, 22.10589027], [88.61772919, 22.10580063], [88.6180191, 22.10571289], [88.61828613, 22.10563087], [88.61886597, 22.10551071], [88.61936951, 22.10532951], [88.61971283, 22.1049881], [88.6199646, 22.10454941], [88.62018585, 22.10400009], [88.62043762, 22.1033802], [88.62049103, 22.10264969], [88.62034607, 22.10198021], [88.62032318, 22.10135269], [88.62037659, 22.10081482], [88.62047577, 22.10034752], [88.6205368, 22.09992027], [88.62055969, 22.09953499], [88.62058258, 22.09918022], [88.62070465, 22.09885406], [88.62081146, 22.09848022], [88.62082672, 22.09803009], [88.6208725, 22.09754944], [88.62104034, 22.0970726], [88.62119293, 22.09658241], [88.62133789, 22.09605408], [88.62138367, 22.09547234], [88.62142944, 22.0948925], [88.6215744, 22.09435272], [88.62179565, 22.09383965], [88.62203979, 22.09331322], [88.62199402, 22.09260941], [88.62203217, 22.09189987], [88.62217712, 22.09120941], [88.62224579, 22.09048843], [88.62243652, 22.08980942], [88.62280273, 22.08917809], [88.62325287, 22.08856964], [88.6233902, 22.08811951], [88.62346649, 22.08788109], [88.62340546, 22.08736992], [88.62338257, 22.08714867], [88.62335205, 22.08645058], [88.62354279, 22.08587074], [88.62358093, 22.08531952], [88.62360382, 22.08485222], [88.62362671, 22.08443832], [88.62371826, 22.0840683], [88.62397003, 22.08376694], [88.62420654, 22.0834198], [88.62419128, 22.08299255], [88.62419891, 22.08247375], [88.62431335, 22.08188629], [88.6244278, 22.08122826], [88.62451935, 22.08051109], [88.62467957, 22.07983208], [88.6247406, 22.07915497], [88.62480927, 22.07853127], [88.62497711, 22.0779705], [88.62509155, 22.07743835], [88.62523651, 22.07698059], [88.62528992, 22.07653809], [88.62532806, 22.07613945], [88.6253891, 22.07575035], [88.62547302, 22.07536125], [88.62555695, 22.07496262], [88.6257019, 22.07455254], [88.62580109, 22.07413673], [88.6258316, 22.0736599], [88.6258316, 22.07315826], [88.6258316, 22.07262993], [88.62588501, 22.07210159], [88.62605286, 22.07160187], [88.62610626, 22.07107735], [88.6261673, 22.07056999], [88.62638855, 22.07014847], [88.62661743, 22.06969833], [88.62671661, 22.06915092], [88.62689209, 22.06858063], [88.62693024, 22.06793976], [88.62689972, 22.06728935], [88.62679291, 22.06665993], [88.62692261, 22.06607437], [88.62705994, 22.06545067], [88.62700653, 22.06468964], [88.62703705, 22.06394005], [88.62690735, 22.06336021], [88.62671661, 22.06282043], [88.62666321, 22.06225014], [88.62665558, 22.06165123], [88.62665558, 22.06104279], [88.62665558, 22.06045723], [88.62666321, 22.05992126], [88.62666321, 22.0594101], [88.62665558, 22.05892372], [88.62666321, 22.05842972], [88.62667847, 22.05791283], [88.62674713, 22.05739975], [88.62687683, 22.0569191], [88.62697601, 22.05643082], [88.62708282, 22.05599022], [88.62718201, 22.05559921], [88.62722778, 22.05518913], [88.62729645, 22.05480957], [88.62742615, 22.0544529], [88.62752533, 22.05406761], [88.62763977, 22.05368042], [88.62780762, 22.05331039], [88.62802887, 22.05293274], [88.62824249, 22.05250931], [88.62848663, 22.05207825], [88.6287384, 22.05166054], [88.62902069, 22.05126762], [88.62927246, 22.05091286], [88.62953949, 22.0506115], [88.62984467, 22.05033875], [88.63021088, 22.05006981], [88.63067627, 22.04977989], [88.63119507, 22.0494442], [88.63172913, 22.0490551], [88.63228607, 22.04866982], [88.63288116, 22.04834747], [88.63339996, 22.04804993], [88.63386536, 22.04777527], [88.63426208, 22.04750061], [88.6346283, 22.04722977], [88.63497925, 22.04696846], [88.6353302, 22.04673004], [88.63569641, 22.04654121], [88.63610077, 22.04636192], [88.63638306, 22.04606819], [88.63658142, 22.04574013], [88.63665771, 22.04528999], [88.6366272, 22.04478073], [88.63645172, 22.04424095], [88.63617706, 22.04370117], [88.63609314, 22.04356384], [88.63584137, 22.04315186], [88.63547516, 22.04261398], [88.63504028, 22.04215813], [88.63463593, 22.04174995], [88.63425446, 22.04145241], [88.63395691, 22.04116058], [88.63374329, 22.04084969], [88.63349152, 22.04055595], [88.6332016, 22.04026985], [88.63288116, 22.03998756], [88.63257599, 22.03970909], [88.63227844, 22.03942108], [88.63199615, 22.03911972], [88.63170624, 22.03878021], [88.63141632, 22.03837967], [88.63108063, 22.0380249], [88.6307373, 22.03769875], [88.63038635, 22.03742027], [88.63012695, 22.03707123], [88.62989044, 22.03670692], [88.62958527, 22.03635216], [88.62928009, 22.03596306], [88.62895203, 22.03561592], [88.62865448, 22.03527451], [88.62838745, 22.03497124], [88.62812805, 22.03469276], [88.62786865, 22.03442383], [88.62758636, 22.03414536], [88.62729645, 22.03385162], [88.62698364, 22.03355217], [88.62669373, 22.03325462], [88.62644196, 22.03294945], [88.62623596, 22.03261948], [88.62602997, 22.03227997], [88.6257782, 22.03195953], [88.62546539, 22.03166389], [88.62511444, 22.0313549], [88.62477875, 22.03100395], [88.6244812, 22.03061295], [88.62417603, 22.03028679], [88.62387848, 22.02999115], [88.62359619, 22.02968979], [88.62329102, 22.02937126], [88.62303925, 22.02898026], [88.62278748, 22.02860641], [88.62256622, 22.02823067], [88.62239838, 22.02782822], [88.62217712, 22.02745056], [88.62194061, 22.02703285], [88.62166595, 22.02656746], [88.6213913, 22.02602959], [88.62111664, 22.02545166], [88.62086487, 22.02485657], [88.6206665, 22.02429008], [88.6203537, 22.02390289], [88.62005615, 22.02359962], [88.61981964, 22.02333069], [88.61962128, 22.02305984], [88.61940765, 22.02281189], [88.61917114, 22.02259254], [88.618927, 22.02235985], [88.61873627, 22.02206993], [88.61855316, 22.02176094], [88.61830139, 22.02151108], [88.6180191, 22.02132988], [88.61775208, 22.02113914], [88.61743927, 22.0210247], [88.61711884, 22.02087784], [88.616745, 22.02088547], [88.61633301, 22.02106094], [88.6158371, 22.02116013], [88.6153717, 22.02133751], [88.61489105, 22.02140808], [88.61444092, 22.02153015], [88.61400604, 22.02165031], [88.61354828, 22.02174759], [88.61305237, 22.02190971], [88.61248016, 22.02205849], [88.61186981, 22.02222061], [88.61123657, 22.02238083], [88.6105957, 22.02241135], [88.61016083, 22.02232361], [88.60997009, 22.02228165], [88.60935974, 22.02226067], [88.60875702, 22.02235031], [88.60816193, 22.02246857], [88.60753632, 22.0225296], [88.60692596, 22.02264977], [88.60632324, 22.02275085], [88.60571289, 22.02277946], [88.60507965, 22.02282906], [88.60450745, 22.02304077], [88.60394287, 22.02329063], [88.60340118, 22.02355957], [88.60292053, 22.02387047], [88.6024704, 22.02416992], [88.6020813, 22.02446175], [88.60176849, 22.02478981], [88.60155487, 22.02518272], [88.60141754, 22.02541733], [88.60132599, 22.02557182], [88.60110474, 22.0259552], [88.60089111, 22.02635956], [88.60087585, 22.0268898], [88.60105133, 22.02742958], [88.60111237, 22.02793121], [88.60115814, 22.02839661], [88.6013031, 22.02882957], [88.60142517, 22.02931595], [88.60158539, 22.02979279], [88.60171509, 22.03027153], [88.60189056, 22.03069115], [88.60196686, 22.03115082], [88.60206604, 22.03159332], [88.60218048, 22.03202057], [88.60221863, 22.03248024], [88.60222626, 22.03294182], [88.60222626, 22.03339005], [88.60222626, 22.03383064], [88.602211, 22.0342598], [88.60214233, 22.03467941], [88.60201263, 22.03511047], [88.60196686, 22.03561783], [88.6019516, 22.03614044], [88.6019516, 22.03666115], [88.60195923, 22.03713608], [88.60199738, 22.03757095], [88.60211945, 22.03796768], [88.60220337, 22.03833389], [88.60222626, 22.03869247], [88.60224915, 22.03904724], [88.60233307, 22.03938484], [88.60249329, 22.03973007], [88.6026535, 22.04014969], [88.60287476, 22.04062462], [88.6031723, 22.0410881], [88.60352325, 22.04157829], [88.60387421, 22.04208374], [88.6042099, 22.04257965], [88.60455322, 22.04301071], [88.60488892, 22.04337502], [88.60514832, 22.0437603], [88.60536957, 22.04416275], [88.60555267, 22.0445385], [88.60572052, 22.04489326], [88.60585785, 22.04525375], [88.60601044, 22.04561043], [88.60610962, 22.0460186], [88.60620117, 22.0464325], [88.60632324, 22.04682922], [88.60637665, 22.04726791], [88.60635376, 22.04772186], [88.60626221, 22.04815483], [88.60614014, 22.04853249], [88.60603333, 22.04892349], [88.60588837, 22.04929161], [88.60575104, 22.04972076], [88.60551453, 22.05012894], [88.60522461, 22.0505352], [88.6049118, 22.05095673], [88.60464478, 22.05138397], [88.60438538, 22.05180931], [88.60412598, 22.05221748], [88.60386658, 22.05261993], [88.60363007, 22.05303001], [88.6034317, 22.05345917], [88.60321808, 22.05382919], [88.60296631, 22.05414963], [88.60273743, 22.05447769], [88.60251617, 22.05482101], [88.60231781, 22.05518913], [88.60217285, 22.05558968], [88.60193634, 22.05594063], [88.60167694, 22.05628014], [88.60138702, 22.056633], [88.60108948, 22.05699158], [88.60079956, 22.05737114], [88.60044098, 22.05772972], [88.6000061, 22.05805969], [88.59957886, 22.05842972], [88.59915924, 22.05885124], [88.59873962, 22.0592804], [88.59836578, 22.05973816], [88.59807587, 22.06019974], [88.59781647, 22.06060028], [88.59763336, 22.06097031], [88.59748077, 22.06130028], [88.59733582, 22.06157684], [88.59722137, 22.06188202], [88.59710693, 22.06217957], [88.59696198, 22.06251907], [88.5968399, 22.06289101], [88.59673309, 22.06329727], [88.59671783, 22.06377029], [88.59673309, 22.0642662], [88.59680176, 22.0647316], [88.59693146, 22.06513023], [88.59707642, 22.06554985], [88.59726715, 22.06594086], [88.59749603, 22.0663681], [88.59771729, 22.06684113], [88.59797668, 22.06729698], [88.59829712, 22.06768036], [88.59863281, 22.06804085], [88.59896851, 22.06837654], [88.59931946, 22.06872749], [88.59970856, 22.06911087], [88.60011292, 22.06950188], [88.6004715, 22.06989098], [88.60077667, 22.07023811], [88.60101318, 22.07055283], [88.60121155, 22.07084084], [88.60140228, 22.07110977], [88.60160065, 22.07139015], [88.60173798, 22.0717411], [88.60186005, 22.07214737], [88.60190582, 22.07263947], [88.60183716, 22.07316017], [88.60166168, 22.07361031], [88.60111237, 22.07306099], [88.60111237, 22.07250023], [88.60083008, 22.07221985], [88.60067749, 22.07198334], [88.60050964, 22.07166481], [88.60028076, 22.07139587], [88.6000061, 22.07110977], [88.59967804, 22.07078934], [88.59931183, 22.07042122], [88.59890747, 22.07004547], [88.59851837, 22.06966019], [88.59818268, 22.06925964], [88.59785461, 22.06886292], [88.59754181, 22.06848145], [88.597229, 22.06810188], [88.59690094, 22.06771469], [88.59658051, 22.06726646], [88.59636688, 22.06668282], [88.59617615, 22.06611061], [88.59603882, 22.06559372], [88.59599304, 22.06505203], [88.59598541, 22.06453705], [88.59597015, 22.06402016], [88.59596252, 22.06349945], [88.59596252, 22.062994], [88.5959549, 22.06250381], [88.59601593, 22.06204033], [88.59610748, 22.06157112], [88.59622955, 22.06104088], [88.59645081, 22.06054115], [88.59675598, 22.06008911], [88.59707642, 22.05969238], [88.59738159, 22.0592804], [88.59764862, 22.05883026], [88.59790039, 22.05836678], [88.5982132, 22.05791283], [88.59860229, 22.05751038], [88.59901428, 22.05712318], [88.59938049, 22.05667305], [88.59976959, 22.05620384], [88.60017395, 22.05573654], [88.60054016, 22.0552597], [88.60083771, 22.05481911], [88.60108948, 22.05446053], [88.6013031, 22.05415916], [88.60150146, 22.05388069], [88.60171509, 22.05361176], [88.6019516, 22.05332375], [88.60219574, 22.05302429], [88.60240936, 22.05273056], [88.6026001, 22.05241013], [88.6027832, 22.05212021], [88.60299683, 22.05182266], [88.60322571, 22.05147934], [88.60349274, 22.05109024], [88.60379028, 22.05064964], [88.60411835, 22.05018044], [88.60446167, 22.04966354], [88.60475159, 22.04904938], [88.60491943, 22.0483284], [88.60497284, 22.04755974], [88.60488892, 22.04684258], [88.60468292, 22.04626083], [88.60443878, 22.04577065], [88.60417938, 22.04533005], [88.60394287, 22.04490089], [88.60372925, 22.0444603], [88.60348511, 22.04404259], [88.60322571, 22.0436306], [88.60295105, 22.04322624], [88.60262299, 22.04278946], [88.60222626, 22.04232025], [88.6018219, 22.04179382], [88.60144043, 22.04121971], [88.60113525, 22.04065895], [88.60090637, 22.04016113], [88.60076904, 22.03969955], [88.6006012, 22.0392704], [88.60049438, 22.03876495], [88.6003418, 22.03819084], [88.60028839, 22.0375061], [88.60027313, 22.03681946], [88.60027313, 22.03619957], [88.60027313, 22.03569984], [88.60028076, 22.0352993], [88.60031891, 22.03494072], [88.60043335, 22.03458023], [88.60051727, 22.03417969], [88.60054779, 22.03372955], [88.60055542, 22.03326225], [88.60055542, 22.03277779], [88.60056305, 22.03228951], [88.60054779, 22.03181458], [88.60049438, 22.03136826], [88.60037231, 22.03098106], [88.60029602, 22.03059196], [88.60024261, 22.03020859], [88.6001358, 22.02985191], [88.60003662, 22.02946091], [88.59997559, 22.02904129], [88.5998764, 22.02860832], [88.59977722, 22.02808952], [88.59967041, 22.02749252], [88.5994873, 22.02694511], [88.59934998, 22.02640533], [88.59932709, 22.02588081], [88.59945679, 22.02542114], [88.59965515, 22.02503967], [88.59971619, 22.02466774], [88.59971619, 22.02430916], [88.59977722, 22.02395058], [88.59990692, 22.02359581], [88.60015106, 22.02321625], [88.60051727, 22.0228405], [88.60092926, 22.02247047], [88.60134125, 22.02207947], [88.60162354, 22.02183342], [88.60173035, 22.02173615], [88.60212708, 22.0214901], [88.60256958, 22.02131081], [88.60299683, 22.021101], [88.60341644, 22.02087975], [88.60388947, 22.02083969], [88.60415649, 22.02111053], [88.6047287, 22.02111053], [88.60500336, 22.02139091], [88.60749817, 22.02139091], [88.60778809, 22.02111053], [88.60861206, 22.02111053], [88.60888672, 22.02083969], [88.60916901, 22.02083969], [88.60943604, 22.02111053], [88.61138916, 22.02111053], [88.61165619, 22.02083969], [88.61205292, 22.02083778], [88.61332703, 22.02083969], [88.61444092, 22.01972008], [88.61444092, 22.01944351], [88.61434937, 22.01935005], [88.61416626, 22.01916695], [88.61416626, 22.01861], [88.6138916, 22.01833344], [88.6138916, 22.01764488], [88.61412048, 22.0171814], [88.61415863, 22.01672554], [88.61411285, 22.01626968], [88.61393738, 22.01578903], [88.61387634, 22.01518822], [88.6138382, 22.01453018], [88.61367035, 22.01391029], [88.61361694, 22.01330376], [88.61358643, 22.01279068], [88.61348724, 22.01241112], [88.61334991, 22.0121212], [88.61323547, 22.01186371], [88.61315918, 22.01176643], [88.61306763, 22.01164436], [88.61292267, 22.01138306], [88.61277008, 22.01108932], [88.61255646, 22.01078033], [88.61235046, 22.01042938], [88.61205292, 22.01009941], [88.61174774, 22.00976563], [88.61151123, 22.00933266], [88.6111908, 22.00895119], [88.61089325, 22.00851059], [88.61062622, 22.0079689], [88.61038208, 22.00733948], [88.61009979, 22.00671959], [88.60972595, 22.00616074], [88.60939789, 22.0056591], [88.60906982, 22.00523758], [88.6088562, 22.00486565], [88.60865784, 22.00455475], [88.60852814, 22.00425529], [88.60836792, 22.00401115], [88.6082077, 22.00375938], [88.60804749, 22.00350952], [88.60786438, 22.0032177], [88.6076889, 22.00281143], [88.60744476, 22.00236893], [88.6071167, 22.00194168], [88.60682678, 22.00152969], [88.60668182, 22.0011692], [88.60677338, 22.00094986], [88.60639191, 22.00000191], [88.60669708, 21.99967957], [88.60653687, 21.99953079], [88.60639191, 21.99929047], [88.60626221, 21.99904633], [88.60611725, 21.99879074], [88.60600281, 21.99852943], [88.60579681, 21.99829483], [88.60559845, 21.99805069], [88.60547638, 21.99775124], [88.60529327, 21.99747086], [88.60511017, 21.99714088], [88.60497284, 21.99677467], [88.60478973, 21.99641418], [88.60466766, 21.99602509], [88.60452271, 21.99567986], [88.60441589, 21.99532127], [88.60430145, 21.99496269], [88.60415649, 21.99452019], [88.60399628, 21.99403381], [88.6037674, 21.99355888], [88.60356903, 21.99304962], [88.60333252, 21.99250031], [88.60305786, 21.99221992], [88.60305786, 21.99194336], [88.6027832, 21.99167061], [88.6027832, 21.99053955], [88.60250092, 21.99055481], [88.60208893, 21.99035072], [88.60194397, 21.99027824], [88.6027832, 21.98944283], [88.60277557, 21.98916626], [88.60250092, 21.98888969], [88.60250092, 21.98861122], [88.60193634, 21.9880619], [88.60111237, 21.98722267], [88.60194397, 21.98638916], [88.60193634, 21.98611069], [88.60138702, 21.98555946], [88.60138702, 21.98524094], [88.60138702, 21.9841671], [88.60111237, 21.98389053], [88.60111237, 21.98360825], [88.60083008, 21.98333359], [88.60028076, 21.98333359], [88.60028076, 21.98249817], [88.59988403, 21.98210335], [88.59972382, 21.98194695], [88.59980011, 21.98186874], [88.59999847, 21.98166847], [88.60055542, 21.98166847], [88.60055542, 21.98055458], [88.60028076, 21.98027992], [88.60028076, 21.97999954], [88.59999847, 21.97972107], [88.59999847, 21.9794445], [88.59999084, 21.97916985], [88.5997467, 21.97862053], [88.59957886, 21.97805023], [88.59944153, 21.97746086], [88.59931183, 21.97685051], [88.59915161, 21.97626686], [88.59896088, 21.97570992], [88.59884644, 21.97518921], [88.59870148, 21.97470093], [88.59879303, 21.97417259], [88.59908295, 21.97363091], [88.59903717, 21.97321129], [88.59886932, 21.97278976], [88.59866333, 21.97237968], [88.59860992, 21.97192955], [88.59860229, 21.97145844], [88.59860229, 21.97099113], [88.59860992, 21.97055626], [88.59860229, 21.97000122], [88.59881592, 21.96979523], [88.59889221, 21.96972275], [88.59889221, 21.96944427], [88.59833527, 21.96888733], [88.5983429, 21.96833038], [88.59860992, 21.96805763], [88.59860229, 21.96778107], [88.59889221, 21.96750069], [88.59889221, 21.96528053], [88.59887695, 21.96489906], [88.59889221, 21.96454811], [88.59895325, 21.9642086], [88.59906006, 21.96390533], [88.59916687, 21.96363068], [88.59928131, 21.96339226], [88.59937286, 21.96312714], [88.59916687, 21.96278], [88.59944153, 21.96249962], [88.59944153, 21.96222115], [88.59972382, 21.96194458], [88.59972382, 21.96166611], [88.59983063, 21.9615612], [88.60028076, 21.96111107], [88.60056305, 21.96111107], [88.60086823, 21.96047783], [88.60119629, 21.95988083], [88.60138702, 21.95972252], [88.60138702, 21.95916748], [88.60166168, 21.95889091], [88.60166168, 21.95832825], [88.60194397, 21.9580555], [88.60221863, 21.95833397], [88.60233307, 21.95822144], [88.60250092, 21.9580555], [88.60250092, 21.9569397], [88.60253143, 21.95669174], [88.60276031, 21.95630074], [88.60293579, 21.95582962], [88.60317993, 21.95534515], [88.60352325, 21.9549408], [88.60360718, 21.95471954], [88.60388947, 21.95444679], [88.60388947, 21.95416451], [88.60415649, 21.95388985], [88.60415649, 21.95360947], [88.60444641, 21.9533329], [88.60472107, 21.9533329], [88.60500336, 21.95305443], [88.60500336, 21.95222092], [88.60583496, 21.95138931], [88.60555267, 21.95111084], [88.60582733, 21.95083046], [88.60583496, 21.95027733], [88.60639191, 21.94972038], [88.60639191, 21.94944382], [88.60666656, 21.94916725], [88.60666656, 21.94861984], [88.60721588, 21.9480629], [88.60721588, 21.94750023], [88.60778809, 21.94695282], [88.60778809, 21.94611168], [88.60944366, 21.94444466], [88.60972595, 21.94444466], [88.60993958, 21.94408989], [88.6102829, 21.94367981], [88.61062622, 21.94320869], [88.61104584, 21.94275093], [88.61147308, 21.94227028], [88.61190796, 21.94180107], [88.61231232, 21.94129944], [88.61270905, 21.94079018], [88.61306763, 21.9402504], [88.61339569, 21.93968964], [88.61376953, 21.93915939], [88.61414337, 21.93863106], [88.61446381, 21.93809128], [88.61473846, 21.93753815], [88.61493683, 21.93699265], [88.61496735, 21.93640137], [88.61485291, 21.93582153], [88.61467743, 21.93526077], [88.61444092, 21.93476105], [88.61417389, 21.93432045], [88.6138916, 21.93391991], [88.61362457, 21.93355751], [88.61334991, 21.93321037], [88.61307526, 21.93288422], [88.61282349, 21.93255806], [88.6125412, 21.93228912], [88.61221313, 21.93209267], [88.6118927, 21.9319725], [88.61153412, 21.9318943], [88.61110687, 21.93169022], [88.61061096, 21.93172836], [88.61017609, 21.93172836], [88.60988617, 21.93185043], [88.60935211, 21.93189049], [88.60877991, 21.93239975], [88.60816956, 21.93276024], [88.6076355, 21.93304825], [88.60718536, 21.93331337], [88.60677338, 21.93355942], [88.6063385, 21.93379021], [88.60593414, 21.93394852], [88.60558319, 21.93417358], [88.60529327, 21.93439484], [88.60486603, 21.93467331], [88.60458374, 21.93440437], [88.60394287, 21.93440056], [88.60286713, 21.93480682], [88.60201263, 21.93540955], [88.60164642, 21.9355526], [88.60138702, 21.93527985], [88.60250092, 21.93416977], [88.60305786, 21.93416977], [88.60369873, 21.93352318], [88.60388947, 21.93333244], [88.60475159, 21.93245888], [88.60539246, 21.93185043], [88.605896, 21.93138313], [88.60675049, 21.93071175], [88.60746765, 21.9301033], [88.60824585, 21.92943001], [88.60947418, 21.92855835], [88.61019135, 21.92761993], [88.6103363, 21.92661095], [88.61083221, 21.92580032], [88.61083984, 21.92472649], [88.61089325, 21.9230957], [88.61067963, 21.92135048], [88.61023712, 21.92019844], [88.60988617, 21.91885948], [88.60945892, 21.91778946], [88.60916901, 21.91749954], [88.60916901, 21.91721916], [88.60861206, 21.91666794], [88.60861206, 21.91611099], [88.60806274, 21.91555023], [88.60805511, 21.91527557], [88.60749817, 21.91472054], [88.60749817, 21.91444588], [88.60694122, 21.91388893], [88.60694122, 21.91361046], [88.60666656, 21.91333008], [88.60666656, 21.91305733], [88.60611725, 21.91250992], [88.60610962, 21.91222], [88.60587311, 21.91198349], [88.60527802, 21.9113884], [88.60527802, 21.91110992], [88.60277557, 21.9086113], [88.60277557, 21.90833282], [88.60250092, 21.90805626], [88.60250092, 21.90777969], [88.60221863, 21.90750122], [88.60221863, 21.90666962], [88.60138702, 21.90582848], [88.60111237, 21.9058342], [88.60028076, 21.90500069], [88.59999847, 21.90500069], [88.59944153, 21.90443993], [88.59916687, 21.90444374], [88.59889221, 21.90416718], [88.59860229, 21.90416908], [88.59805298, 21.90360832], [88.59777832, 21.90360832], [88.59610748, 21.90195084], [88.59583282, 21.90195084], [88.59333038, 21.89944077], [88.59305573, 21.89944649], [88.59278107, 21.8991642], [88.59221649, 21.89916992], [88.59194183, 21.89888954], [88.59166718, 21.89888954], [88.59111023, 21.89833069], [88.59083557, 21.8983326], [88.59063721, 21.89813614], [88.59055328, 21.89805412], [88.59027863, 21.89805984], [88.58972168, 21.89751053], [88.58944702, 21.89751053], [88.5890274, 21.89708328], [88.58889008, 21.89694023], [88.58860779, 21.89694214], [88.58611298, 21.89444351], [88.58583069, 21.89444351], [88.58527374, 21.89388466], [88.58472443, 21.89333344], [88.58444214, 21.89333344], [88.58416748, 21.89305496], [88.58389282, 21.89306259], [88.58361816, 21.8927803], [88.58333588, 21.8927803], [88.58304596, 21.89250183], [88.58277893, 21.89250183], [88.58222198, 21.89193916], [88.58166504, 21.89194489], [88.58110809, 21.89138985], [88.58083344, 21.89138985], [88.58055878, 21.89111137], [88.58027649, 21.89111137], [88.57944489, 21.89027977], [88.57917023, 21.89027977], [88.57888794, 21.88999748], [88.57888794, 21.88972092], [88.57861328, 21.88944435], [88.57843781, 21.88944435], [88.57833099, 21.88944435], [88.57805634, 21.88972092], [88.57805634, 21.88999748], [88.57777405, 21.89027977], [88.57777405, 21.8908329], [88.5772171, 21.89138031], [88.57722473, 21.89166641], [88.57694244, 21.89194489], [88.57694244, 21.89222145], [88.57666779, 21.89250183], [88.57666779, 21.8927803], [88.5763855, 21.89305496], [88.5763855, 21.89333344], [88.57611084, 21.89361191], [88.57611084, 21.89389038], [88.57583618, 21.89417267], [88.57583618, 21.89500046], [88.57554626, 21.89528275], [88.57554626, 21.89639091], [88.57527924, 21.89666748], [88.57527924, 21.89722061], [88.57499695, 21.89751053], [88.57499695, 21.89861107], [88.57472229, 21.89888954], [88.57472229, 21.8991642], [88.57444763, 21.89944649], [88.57444763, 21.89972305], [88.57417297, 21.89999962], [88.57416534, 21.90027618], [88.57389069, 21.90055466], [88.57389069, 21.9011097], [88.5736084, 21.90139008], [88.5736084, 21.90194511], [88.57332611, 21.90221977], [88.57332611, 21.90250015], [88.57277679, 21.90305519], [88.57277679, 21.90444374], [88.57305908, 21.9047184], [88.57277679, 21.90501022], [88.57277679, 21.90555573], [88.57305908, 21.90582848], [88.57305908, 21.9066658], [88.57499695, 21.90860939], [88.57499695, 21.90888977], [88.57666779, 21.91055489], [88.57666779, 21.91083336], [88.58027649, 21.91444588], [88.58027649, 21.91472054], [88.58083344, 21.91527557], [88.58083344, 21.91555786], [88.58110809, 21.91583061], [88.58110809, 21.91611099], [88.58139038, 21.91638947], [88.58139038, 21.91805649], [88.58110809, 21.9183197], [88.58110809, 21.91917038], [88.58083344, 21.91944504], [88.58082581, 21.9197216], [88.58055878, 21.92000008], [88.58055878, 21.92028046], [88.58027649, 21.92055511], [88.58027649, 21.92111015], [88.58000183, 21.92138863], [88.58000183, 21.92333031], [88.58027649, 21.92361069], [88.58027649, 21.92389107], [88.58083344, 21.92444229], [88.58082581, 21.92472076], [88.58110809, 21.92500114], [88.58167267, 21.92500114], [88.58194733, 21.92527962], [88.58277893, 21.92527771], [88.58333588, 21.92583275], [88.58416748, 21.92583084], [88.58444214, 21.92611122], [88.58499908, 21.92611122], [88.58528137, 21.92638969], [88.58555603, 21.92638969], [88.58583069, 21.92666435], [88.58583069, 21.92694664], [88.58611298, 21.92694664], [88.58611298, 21.92749023], [88.58638763, 21.92777634], [88.58638763, 21.92805099], [88.58555603, 21.92889023], [88.5847168, 21.92805099], [88.58472443, 21.92777634], [88.58416748, 21.92721939], [88.58333588, 21.9272213], [88.58305359, 21.92694664], [88.58249664, 21.92694664], [88.58222198, 21.92666435], [88.58194733, 21.92667007], [88.58167267, 21.92638969], [88.58139038, 21.92638969], [88.58110809, 21.92611122], [88.58082581, 21.92611122], [88.58055878, 21.92583084], [88.58027649, 21.92583275], [88.57917023, 21.92472267], [88.57917023, 21.92361069], [88.57888794, 21.92333031], [88.57888794, 21.92277718], [88.57861328, 21.92250061], [88.57861328, 21.92083168], [88.57888794, 21.92055511], [88.57888794, 21.92028046], [88.57917023, 21.92000008], [88.57917023, 21.9197216], [88.57944489, 21.91944504], [88.57943726, 21.91917038], [88.57971954, 21.91889191], [88.57971954, 21.91860771], [88.58000183, 21.91833305], [88.58000183, 21.91666794], [88.57943726, 21.91611099], [88.57943726, 21.91583061], [88.57777405, 21.9141655], [88.57776642, 21.91389084], [88.57639313, 21.91250992], [88.57639313, 21.91222], [88.57611084, 21.91194344], [88.57583618, 21.91195107], [88.57499695, 21.91110992], [88.57499695, 21.91083336], [88.57472229, 21.91055489], [88.57472229, 21.91027832], [88.57277679, 21.90833282], [88.57277679, 21.90805626], [88.57250214, 21.90777969], [88.57250214, 21.90722275], [88.57221985, 21.90722275], [88.57195282, 21.90750122], [88.5716629, 21.90749931], [88.5708313, 21.90833282], [88.5708313, 21.90860939], [88.57055664, 21.90888977], [88.57055664, 21.90917015], [88.56944275, 21.91028023], [88.56916809, 21.91027832], [88.5688858, 21.91055489], [88.5688858, 21.91083336], [88.56861115, 21.91111183], [88.56833649, 21.91110992], [88.56777954, 21.91167068], [88.56777954, 21.91195107], [88.56694794, 21.91278076], [88.56666565, 21.91277695], [88.5661087, 21.9133358], [88.56582642, 21.91333008], [88.5652771, 21.91389084], [88.56500244, 21.91389084], [88.56472015, 21.91417122], [88.56361389, 21.9141655], [88.5633316, 21.91444588], [88.5633316, 21.91472054], [88.56305695, 21.91500092], [88.56276703, 21.91472054], [88.56138611, 21.91611099], [88.56083679, 21.91611099], [88.56027985, 21.91666985], [88.5597229, 21.91666794], [88.55944824, 21.9169445], [88.55805206, 21.91694069], [88.55750275, 21.91749954], [88.55665588, 21.91749954], [88.55638885, 21.91777992], [88.55555725, 21.91777992], [88.55528259, 21.9180584], [88.55472565, 21.91805649], [88.5541687, 21.91861153], [88.55388641, 21.91860771], [88.5533371, 21.91917038], [88.55305481, 21.91916656], [88.55249786, 21.9197216], [88.55222321, 21.9197216], [88.55166626, 21.92028046], [88.5513916, 21.92028046], [88.55027771, 21.92139053], [88.55055237, 21.92168045], [88.55027771, 21.9216671], [88.55027771, 21.92194366], [88.55000305, 21.92222023], [88.55000305, 21.92527962], [88.55027771, 21.92556], [88.55027771, 21.92611122], [88.55055237, 21.92638969], [88.55055237, 21.92777634], [88.55082703, 21.92805099], [88.55082703, 21.92889023], [88.55110931, 21.9291687], [88.55110931, 21.92971992], [88.5513916, 21.93000031], [88.5513916, 21.93250084], [88.55110931, 21.93277931], [88.55110931, 21.93305588], [88.5513916, 21.93333244], [88.5513916, 21.9347229], [88.55110931, 21.93499947], [88.55110931, 21.93583107], [88.55082703, 21.93610954], [88.55083466, 21.93694305], [88.55055237, 21.93721962], [88.55055237, 21.93805313], [88.55027771, 21.9383297], [88.55027771, 21.93916512], [88.55000305, 21.93943024], [88.55000305, 21.94000053], [88.54972076, 21.94028091], [88.54972076, 21.94055748], [88.54944611, 21.94083023], [88.54944611, 21.94111061], [88.54833221, 21.9422226], [88.54833221, 21.94248962], [88.54805756, 21.94277954], [88.54805756, 21.94305611], [88.54777527, 21.94333267], [88.5477829, 21.94388962], [88.54750061, 21.94416618], [88.54750061, 21.94444466], [88.54722595, 21.94472122], [88.54722595, 21.94528008], [88.54694366, 21.94555473], [88.54693604, 21.94582939], [88.54638672, 21.94639015], [88.54638672, 21.94667053], [88.54611206, 21.94695282], [88.54611206, 21.94750023], [88.54582977, 21.94778061], [88.54582977, 21.9480629], [88.54528046, 21.94861984], [88.54528046, 21.94889069], [88.54499817, 21.94916725], [88.54499817, 21.94972038], [88.54471588, 21.95000076], [88.54472351, 21.9505558], [88.54444122, 21.95083237], [88.54444885, 21.95111084], [88.54416656, 21.95138931], [88.54416656, 21.95222092], [88.54389191, 21.95249939], [88.54389191, 21.95277977], [88.54360962, 21.95305443], [88.54360962, 21.95360947], [88.54332733, 21.95388985], [88.54332733, 21.95499992], [88.54305267, 21.95527649], [88.54305267, 21.95694351], [88.54277802, 21.95721817], [88.54277802, 21.95750046], [88.54250336, 21.95778084], [88.54250336, 21.96528053], [88.54277802, 21.96556091], [88.54277802, 21.96778107], [88.54305267, 21.96805763], [88.54305267, 21.96833038], [88.54332733, 21.96861076], [88.54332733, 21.96889114], [88.54360962, 21.96916962], [88.54360962, 21.97000122], [88.54389191, 21.97027969], [88.54389191, 21.97055817], [88.54499817, 21.97166824], [88.54528046, 21.97166634], [88.54582977, 21.97222137], [88.54638672, 21.97222137], [88.54666901, 21.97250175], [88.54777527, 21.97250175], [88.54788971, 21.9726162], [88.54805756, 21.97278976], [88.54916382, 21.97277832], [88.54944611, 21.97305489], [88.55166626, 21.97305489], [88.55194092, 21.97277832], [88.55222321, 21.97305489], [88.55555725, 21.97305489], [88.55583191, 21.97277832], [88.55638885, 21.97278976], [88.55665588, 21.97250175], [88.5569458, 21.97250175], [88.55722046, 21.97222137], [88.55750275, 21.97222137], [88.55916595, 21.97055626], [88.55916595, 21.97027969], [88.55944824, 21.97000122], [88.55944824, 21.96916962], [88.55999756, 21.96861076], [88.55999756, 21.96805954], [88.56027985, 21.96778107], [88.56027985, 21.96750069], [88.56054688, 21.96722031], [88.5605545, 21.96666527], [88.56083679, 21.9663887], [88.56083679, 21.96582985], [88.56111145, 21.96555328], [88.56111145, 21.96528053], [88.56138611, 21.96500015], [88.56138611, 21.96445084], [88.5616684, 21.96417046], [88.5616684, 21.96362114], [88.56223297, 21.96305275], [88.56222534, 21.96277809], [88.56276703, 21.96222115], [88.56277466, 21.96194458], [88.56305695, 21.96166611], [88.56305695, 21.96111107], [88.5633316, 21.9608326], [88.5633316, 21.96055603], [88.56360626, 21.96027946], [88.56388855, 21.96027946], [88.56388855, 21.95999908], [88.56416321, 21.95972061], [88.5644455, 21.95972252], [88.56472015, 21.95944405], [88.56500244, 21.95944405], [88.56583405, 21.95861053], [88.5661087, 21.95861053], [88.56667328, 21.95805931], [88.56749725, 21.9580555], [88.56777954, 21.95832825], [88.56777954, 21.95889091], [88.56716919, 21.95916939], [88.5667038, 21.95952034], [88.566185, 21.9598999], [88.56562042, 21.96030426], [88.56508636, 21.96072006], [88.56468964, 21.96116066], [88.56439972, 21.96157837], [88.56414795, 21.9619503], [88.56389618, 21.96232986], [88.56365204, 21.96274948], [88.56343842, 21.96322823], [88.56327057, 21.96375084], [88.56305695, 21.96424103], [88.56285095, 21.96469879], [88.56269836, 21.96516037], [88.56253815, 21.96559715], [88.56240082, 21.96601486], [88.56223297, 21.96639442], [88.56204987, 21.96677017], [88.56186676, 21.96719551], [88.56165314, 21.96763992], [88.56138611, 21.96811104], [88.56111908, 21.96860123], [88.56088257, 21.96907997], [88.56070709, 21.96955109], [88.56050873, 21.96998978], [88.56025696, 21.97041512], [88.55995178, 21.97088051], [88.5595932, 21.97139931], [88.55914307, 21.97193718], [88.55866241, 21.97245216], [88.5581665, 21.97289467], [88.55767059, 21.9732399], [88.55721283, 21.97352028], [88.55679321, 21.97372818], [88.55634308, 21.97392082], [88.55586243, 21.97407913], [88.55531311, 21.97418594], [88.55476379, 21.97431374], [88.55417633, 21.97439957], [88.55362701, 21.97451019], [88.55309296, 21.97454071], [88.55251312, 21.97450066], [88.55198669, 21.97434807], [88.55145264, 21.9742012], [88.55090332, 21.97407913], [88.550354, 21.97399712], [88.54981232, 21.9739399], [88.54928589, 21.97385979], [88.54875946, 21.97384071], [88.54825592, 21.97382164], [88.54776001, 21.97382164], [88.54725647, 21.97377968], [88.54676056, 21.97363091], [88.54624939, 21.97348976], [88.54579163, 21.97331047], [88.54535675, 21.97310066], [88.54495239, 21.97285271], [88.54454041, 21.97258186], [88.54412842, 21.97229958], [88.54370117, 21.97200012], [88.54331207, 21.97161293], [88.54296112, 21.97113037], [88.54263306, 21.97063065], [88.54241943, 21.97005081], [88.54223633, 21.96953011], [88.54209137, 21.96904945], [88.54192352, 21.96863365], [88.54171753, 21.96823883], [88.54155731, 21.96778107], [88.54138947, 21.96730042], [88.54119873, 21.96683311], [88.54109192, 21.96633911], [88.54109192, 21.96585655], [88.54110718, 21.9654007], [88.54110718, 21.96494102], [88.54108429, 21.96445656], [88.54097748, 21.96391869], [88.5409317, 21.9633503], [88.54100037, 21.96276474], [88.54105377, 21.96214485], [88.54104614, 21.96150589], [88.54096222, 21.96086121], [88.54088593, 21.96021271], [88.54095459, 21.95957375], [88.54103851, 21.9589386], [88.54107666, 21.95829964], [88.54112244, 21.95766068], [88.54117584, 21.95702934], [88.54128265, 21.95640945], [88.54137421, 21.95580482], [88.54138947, 21.95520782], [88.54138947, 21.95465088], [88.54141235, 21.95416069], [88.54155731, 21.95372963], [88.54176331, 21.95334435], [88.54200745, 21.95295906], [88.54218292, 21.95248985], [88.54227448, 21.95196724], [88.5424118, 21.9514904], [88.54245758, 21.95100021], [88.54255676, 21.95054626], [88.54270172, 21.95009041], [88.54286194, 21.94959068], [88.54307556, 21.94909286], [88.54333496, 21.94860649], [88.54360199, 21.9481411], [88.54386902, 21.94767952], [88.54412079, 21.94721603], [88.54431152, 21.94670105], [88.54456329, 21.94621086], [88.5448761, 21.94581223], [88.5451355, 21.94540977], [88.54537201, 21.94503784], [88.54560089, 21.94470024], [88.54582977, 21.94436646], [88.54605103, 21.94400978], [88.54621887, 21.94360161], [88.54641724, 21.9431839], [88.54666138, 21.94278717], [88.54690552, 21.94241333], [88.54711151, 21.9420433], [88.54730225, 21.94171333], [88.54749298, 21.94143295], [88.54769135, 21.94117355], [88.54784393, 21.94090462], [88.54800415, 21.9406414], [88.54808807, 21.94035721], [88.54821777, 21.94010162], [88.54839325, 21.93980026], [88.5485611, 21.93949318], [88.54866791, 21.93909073], [88.54882813, 21.93868446], [88.54891205, 21.93817329], [88.54904175, 21.93761635], [88.5491333, 21.93700981], [88.54911041, 21.93634033], [88.54911041, 21.93567467], [88.54916382, 21.93501663], [88.54924011, 21.93434906], [88.54940796, 21.9336071], [88.54940033, 21.93283844], [88.54916382, 21.93216515], [88.54892731, 21.93152046], [88.54888916, 21.93086243], [88.54892731, 21.93019104], [88.54905701, 21.92950058], [88.54907227, 21.92880058], [88.54891205, 21.92813301], [88.54875183, 21.9274559], [88.54854584, 21.92687988], [88.54837799, 21.92629051], [88.54838562, 21.92572975], [88.54853058, 21.92521095], [88.54844666, 21.92463112], [88.54857635, 21.92414093], [88.54860687, 21.92366982], [88.54860687, 21.92321014], [88.54862213, 21.92274094], [88.54866791, 21.92227936], [88.54884338, 21.9218483], [88.54902649, 21.92142296], [88.549263, 21.92098999], [88.54947662, 21.92054939], [88.54972839, 21.9201107], [88.55000305, 21.91966057], [88.55024719, 21.91918945], [88.55046082, 21.9187336], [88.55079651, 21.9184761], [88.5511322, 21.91820145], [88.55150604, 21.91794014], [88.55195618, 21.91770744], [88.55243683, 21.91747093], [88.55293274, 21.91720581], [88.55342102, 21.91691589], [88.55391693, 21.91664124], [88.55444336, 21.91637993], [88.55493164, 21.91610336], [88.55541229, 21.9158287], [88.55584717, 21.91555023], [88.55625916, 21.91530418], [88.55667877, 21.9151268], [88.55709076, 21.9149704], [88.55745697, 21.91479111], [88.55789185, 21.91468239], [88.55828094, 21.91447067], [88.55871582, 21.91433144], [88.55912018, 21.91415977], [88.55953979, 21.91401482], [88.56007385, 21.91402435], [88.56069946, 21.91387177], [88.56128693, 21.91361237], [88.5618515, 21.91331482], [88.56234741, 21.91294289], [88.56273651, 21.91253853], [88.56299591, 21.91204834], [88.56338501, 21.9117527], [88.5638504, 21.91153526], [88.56429291, 21.9112606], [88.56472015, 21.91097069], [88.56513977, 21.91068268], [88.56550598, 21.91036987], [88.56604767, 21.91026115], [88.56661224, 21.91008949], [88.5671463, 21.90975571], [88.56761169, 21.90928078], [88.56815338, 21.90884018], [88.56856537, 21.90837288], [88.56887817, 21.90786552], [88.56916809, 21.90731239], [88.56948853, 21.90676308], [88.56983185, 21.90626144], [88.57009125, 21.90574265], [88.5703125, 21.90525627], [88.57052612, 21.90483093], [88.57058716, 21.90442085], [88.57064819, 21.90401459], [88.57054138, 21.90360832], [88.57032776, 21.90324974], [88.57008362, 21.90290833], [88.56968689, 21.90262032], [88.56922913, 21.90228081], [88.56878662, 21.90183258], [88.56815338, 21.90146065], [88.56756592, 21.90109634], [88.56703949, 21.90069962], [88.56659698, 21.9003315], [88.56613159, 21.8999958], [88.56565857, 21.89968872], [88.56519318, 21.89940643], [88.56475067, 21.89919853], [88.5643158, 21.89908028], [88.56391144, 21.89895058], [88.56343842, 21.89888954], [88.56291962, 21.89888], [88.56239319, 21.89888], [88.56186676, 21.89891052], [88.56139374, 21.89898682], [88.56095886, 21.89910126], [88.56048584, 21.89921951], [88.56004333, 21.89938927], [88.55954742, 21.89953041], [88.55908966, 21.8997364], [88.55863953, 21.89995193], [88.55814362, 21.90011215], [88.55773163, 21.90032005], [88.55737305, 21.90056992], [88.55702209, 21.90083885], [88.5566864, 21.9011116], [88.55635071, 21.90138054], [88.55597687, 21.9016304], [88.55555725, 21.90180969], [88.55510712, 21.90199089], [88.55472565, 21.90222549], [88.55435181, 21.90248108], [88.55394745, 21.90270805], [88.55350494, 21.90288544], [88.55304718, 21.90304947], [88.5526123, 21.90321541], [88.55218506, 21.90340233], [88.55178833, 21.90360832], [88.55140686, 21.9038372], [88.55097198, 21.90395164], [88.55055237, 21.90413094], [88.55010223, 21.90424728], [88.54966736, 21.90445328], [88.54925537, 21.90468979], [88.54882813, 21.90486908], [88.54838562, 21.90500069], [88.54795837, 21.90512466], [88.54754639, 21.9052906], [88.54714203, 21.90549088], [88.54665375, 21.90560722], [88.54615021, 21.90577126], [88.54560089, 21.90588951], [88.54504395, 21.90604019], [88.54445648, 21.90608215], [88.54386902, 21.90602875], [88.54335785, 21.90584183], [88.54286957, 21.90561104], [88.54244232, 21.90533066], [88.54201508, 21.90506172], [88.54163361, 21.90474129], [88.54125214, 21.90445328], [88.5408783, 21.90418625], [88.54055786, 21.90386963], [88.54027557, 21.90348625], [88.54000092, 21.90304947], [88.53972626, 21.90257835], [88.53949738, 21.90211105], [88.5393219, 21.90163994], [88.53920746, 21.90117073], [88.5391922, 21.90068054], [88.53926849, 21.90021515], [88.53939819, 21.89978027], [88.53949738, 21.89935112], [88.53968811, 21.8989296], [88.53992462, 21.89852142], [88.54019165, 21.89813995], [88.54048157, 21.89777946], [88.54078674, 21.89743996], [88.54107666, 21.89709091], [88.54139709, 21.89675331], [88.54174805, 21.8964138], [88.54216003, 21.89608383], [88.54264832, 21.89577866], [88.54332733, 21.8956604], [88.54363251, 21.89529991], [88.54392242, 21.8948822], [88.54431915, 21.89447975], [88.54480743, 21.89415169], [88.54534149, 21.89385033], [88.54582977, 21.89350128], [88.54615021, 21.89286041], [88.54650116, 21.89228821], [88.54683685, 21.89179039], [88.54714203, 21.89136124], [88.54737854, 21.89096069], [88.54756165, 21.89049911], [88.54772186, 21.89001083], [88.54775238, 21.88940048], [88.54772949, 21.888731], [88.54776001, 21.88803291], [88.54777527, 21.88735771], [88.5477829, 21.88670158], [88.5477829, 21.8860817], [88.54777527, 21.88552094], [88.54780579, 21.88500595], [88.54792023, 21.88454819], [88.54802704, 21.88405991], [88.54807281, 21.88348007], [88.54806519, 21.88286591], [88.5480423, 21.88224983], [88.54792786, 21.88169098], [88.54776764, 21.88119125], [88.54753876, 21.88075066], [88.54745483, 21.88056183], [88.54733276, 21.8802948], [88.54708099, 21.87986183], [88.54682922, 21.87943077], [88.54659271, 21.8789711], [88.5462265, 21.87860107], [88.54585266, 21.87821007], [88.5454483, 21.87778282], [88.54499817, 21.8773613], [88.54452515, 21.87697029], [88.54402161, 21.87665939], [88.5435791, 21.87631989], [88.54327393, 21.87587738], [88.54289246, 21.87559128], [88.5424881, 21.87533951], [88.54206085, 21.87509155], [88.54154205, 21.87494087], [88.54110718, 21.87471962], [88.54111481, 21.87444687], [88.5402832, 21.87360954], [88.54027557, 21.87333298], [88.54000092, 21.87306023], [88.54000092, 21.87277985], [88.53943634, 21.87222099], [88.53944397, 21.87194443], [88.53916931, 21.87166405], [88.53916931, 21.87138939], [88.53888702, 21.87111092], [88.53888702, 21.87055969], [88.53861237, 21.87026978], [88.53888702, 21.87000084], [88.53888702, 21.86972046], [88.53861237, 21.86944389], [88.53861237, 21.86833382], [88.53833008, 21.86805534], [88.53832245, 21.86639023], [88.53888702, 21.86583138], [88.53888702, 21.86361122], [88.53909302, 21.86361122], [88.53916931, 21.86361122], [88.53916931, 21.86333084], [88.5390625, 21.86322594], [88.53887939, 21.86299515], [88.53868103, 21.8614502], [88.53810883, 21.85943031], [88.53781891, 21.85802078], [88.53710938, 21.85775948], [88.53694153, 21.85695076], [88.53666687, 21.85667038], [88.53610992, 21.85667038], [88.53569794, 21.85639], [88.53526306, 21.85623169], [88.53483582, 21.8561306], [88.53440094, 21.85610008], [88.53395081, 21.85605431], [88.53351593, 21.85594749], [88.5330658, 21.85584068], [88.53262329, 21.85576439], [88.53223419, 21.85557365], [88.53181458, 21.85542488], [88.53166962, 21.85527039], [88.53138733, 21.85527802], [88.53111267, 21.85499954], [88.53083038, 21.85499954], [88.53056335, 21.85472107], [88.53028107, 21.85472107], [88.52944183, 21.85388947], [88.52916718, 21.85388947], [88.52861023, 21.8533287], [88.52833557, 21.85333252], [88.52805328, 21.85305595], [88.52749634, 21.85305595], [88.52713013, 21.85326958], [88.5266571, 21.8535099], [88.52600098, 21.85345268], [88.52548981, 21.85362244], [88.52507019, 21.85387039], [88.52466583, 21.85414124], [88.52424622, 21.85441971], [88.52379608, 21.85469055], [88.52333069, 21.85496712], [88.52287292, 21.85526085], [88.52240753, 21.85555267], [88.52194977, 21.85583115], [88.52147675, 21.85611916], [88.52102661, 21.85642815], [88.52069092, 21.8568306], [88.52046204, 21.85731125], [88.52024078, 21.85780144], [88.5199585, 21.85823059], [88.51959991, 21.85859108], [88.51918793, 21.85890007], [88.51882172, 21.85923958], [88.51836395, 21.85951424], [88.51793671, 21.85981941], [88.51751709, 21.86014366], [88.51709747, 21.86049461], [88.51659393, 21.86078453], [88.51599884, 21.8610096], [88.51551056, 21.86139107], [88.5150528, 21.86181831], [88.51461029, 21.86232185], [88.51410675, 21.86276054], [88.51354218, 21.86314774], [88.51304626, 21.86359215], [88.51243591, 21.86397171], [88.51189423, 21.86442947], [88.51132965, 21.86487007], [88.51071167, 21.86524963], [88.51009369, 21.86558914], [88.50971985, 21.86606979], [88.50935364, 21.86657524], [88.50886536, 21.86701012], [88.50831604, 21.86746025], [88.50775909, 21.86791039], [88.507164, 21.86828423], [88.50655365, 21.86856651], [88.50592041, 21.86874008], [88.50533295, 21.86893272], [88.50489044, 21.86925125], [88.50450134, 21.86953545], [88.50411224, 21.8697834], [88.50373077, 21.87000084], [88.50337219, 21.8702507], [88.50306702, 21.87055016], [88.5027771, 21.87088966], [88.50244904, 21.87122536], [88.50201416, 21.87149239], [88.50160217, 21.87185478], [88.50112915, 21.87215996], [88.50067902, 21.87248039], [88.50022888, 21.87276077], [88.49980927, 21.87298965], [88.4994278, 21.87324524], [88.4990387, 21.87350273], [88.49858093, 21.87371063], [88.49830627, 21.87404823], [88.4980545, 21.87438965], [88.49781799, 21.87471008], [88.49759674, 21.875], [88.49740601, 21.87525558], [88.49719238, 21.87547112], [88.49694824, 21.87567902], [88.49669647, 21.87594032], [88.49645996, 21.87631035], [88.49616241, 21.8766861], [88.49607086, 21.87680054], [88.49584961, 21.87708092], [88.49555206, 21.87747955], [88.49520111, 21.8778019], [88.49487305, 21.87817001], [88.49452209, 21.87858009], [88.4942627, 21.87909126], [88.4941864, 21.87973022], [88.49419403, 21.88037872], [88.4942627, 21.88100433], [88.49441528, 21.88158417], [88.49447632, 21.88215065], [88.49466705, 21.88270187], [88.49475861, 21.88326073], [88.49497986, 21.88371086], [88.49514008, 21.88415909], [88.49525452, 21.88458633], [88.49529266, 21.88500977], [88.49533844, 21.88539124], [88.49549866, 21.88572311], [88.49559784, 21.8860817], [88.49581909, 21.88639069], [88.4961319, 21.88668823], [88.49648285, 21.88701057], [88.49684906, 21.88726997], [88.49714661, 21.88756943], [88.49738312, 21.88793945], [88.49762726, 21.88833809], [88.49788666, 21.888731], [88.49814606, 21.8891201], [88.49842072, 21.88948059], [88.49859619, 21.88990974], [88.49872589, 21.89036179], [88.49897766, 21.89068985], [88.49919891, 21.89104462], [88.49945068, 21.89141464], [88.49971771, 21.89179993], [88.50001526, 21.89219856], [88.50042725, 21.89249039], [88.50089264, 21.89274979], [88.50132751, 21.89301109], [88.50164795, 21.89333153], [88.50189972, 21.89363098], [88.50211334, 21.89390945], [88.50226593, 21.89418983], [88.50250244, 21.89444351], [88.5027771, 21.89472008], [88.50305176, 21.89472008], [88.50305176, 21.89500046], [88.50332642, 21.89528275], [88.50332642, 21.89556122], [88.50389099, 21.89611053], [88.50389099, 21.89638901], [88.5047226, 21.89722061], [88.5047226, 21.89751053], [88.50499725, 21.89777946], [88.50499725, 21.89805412], [88.50527954, 21.89833069], [88.50527954, 21.89861107], [88.50554657, 21.89894295], [88.50572968, 21.89936066], [88.505867, 21.89978981], [88.50605774, 21.90016937], [88.50614166, 21.90063095], [88.5063324, 21.90109634], [88.50641632, 21.90167046], [88.50666809, 21.90221977], [88.50695038, 21.90275955], [88.50728607, 21.90324974], [88.50769043, 21.90366364], [88.50806427, 21.90410233], [88.50846863, 21.9045105], [88.50887299, 21.9049511], [88.50924683, 21.9054451], [88.50975037, 21.90586472], [88.51026917, 21.90625954], [88.51079559, 21.90660858], [88.51138306, 21.90681267], [88.51190948, 21.90700912], [88.51239777, 21.90723991], [88.51287079, 21.90752029], [88.51329041, 21.90788078], [88.51361847, 21.90835953], [88.51418304, 21.90858078], [88.51483917, 21.90858841], [88.51530457, 21.90879822], [88.51571655, 21.9090004], [88.51612091, 21.90923691], [88.51652527, 21.90946007], [88.51690674, 21.90973091], [88.51727295, 21.91007042], [88.5176239, 21.91040802], [88.51802826, 21.91073036], [88.51859283, 21.91085052], [88.51909637, 21.91100121], [88.51951599, 21.9113102], [88.51998138, 21.91158676], [88.520401, 21.91193962], [88.52081299, 21.91234016], [88.52115631, 21.91279984], [88.52146149, 21.91327858], [88.52177429, 21.91374207], [88.52197266, 21.91426086], [88.5222168, 21.91472816], [88.52246857, 21.91518021], [88.52262878, 21.91567993], [88.52281952, 21.91614151], [88.52305603, 21.91657257], [88.52328491, 21.91700363], [88.52335358, 21.9174633], [88.52349854, 21.91791916], [88.52366638, 21.91843033], [88.52384186, 21.91894913], [88.52391815, 21.91955948], [88.52390289, 21.92025948], [88.52411652, 21.92084122], [88.52426147, 21.92139816], [88.52436066, 21.92192078], [88.5243988, 21.92243958], [88.5243454, 21.92297745], [88.52411652, 21.92361069], [88.52429199, 21.92412567], [88.52451324, 21.92468071], [88.52465057, 21.92526054], [88.52474213, 21.92584038], [88.52489471, 21.92637825], [88.5250473, 21.92688942], [88.52524567, 21.92746544], [88.52529907, 21.92809486], [88.52542114, 21.92875481], [88.52553558, 21.92944145], [88.5255127, 21.9301548], [88.52532196, 21.93082809], [88.52527618, 21.93152809], [88.52527618, 21.93218994], [88.52527618, 21.93280029], [88.5252533, 21.93334961], [88.52509308, 21.933815], [88.52497101, 21.93427277], [88.5247879, 21.93468666], [88.52472687, 21.93512917], [88.52466583, 21.93558121], [88.52448273, 21.93596268], [88.52440643, 21.9364109], [88.52420807, 21.93678093], [88.52404785, 21.93717003], [88.52390289, 21.93756866], [88.52381897, 21.93799019], [88.52362823, 21.93837929], [88.52349854, 21.93884087], [88.52333832, 21.93934822], [88.52319336, 21.93987274], [88.52310181, 21.9403801], [88.52280426, 21.94076538], [88.52256012, 21.94118118], [88.52236938, 21.94166946], [88.52211761, 21.94218254], [88.52172089, 21.94268036], [88.52124786, 21.94319916], [88.52065277, 21.94369698], [88.52005005, 21.94421005], [88.51946259, 21.9447403], [88.51889801, 21.94527054], [88.51834106, 21.94569588], [88.51784515, 21.94605446], [88.51748657, 21.94637108], [88.51716614, 21.94660187], [88.51685333, 21.94674683], [88.51660156, 21.94692039], [88.51628876, 21.94704056], [88.5160675, 21.94723892], [88.51584625, 21.9474411], [88.51557159, 21.94759941], [88.51526642, 21.94776917], [88.51486969, 21.9479599], [88.514328, 21.94812584], [88.51374817, 21.94837189], [88.51317596, 21.94872093], [88.51275635, 21.94922066], [88.51228333, 21.94964027], [88.51171875, 21.94981956], [88.51122284, 21.95003128], [88.51077271, 21.95028114], [88.51036072, 21.95055008], [88.50993347, 21.9508152], [88.50970459, 21.95094299], [88.50949097, 21.95106125], [88.50907898, 21.95133972], [88.50860596, 21.95153618], [88.50813293, 21.95173073], [88.50771332, 21.95199966], [88.50727081, 21.95223045], [88.50683594, 21.95248985], [88.50637817, 21.95267677], [88.50588989, 21.95284271], [88.50543976, 21.95306396], [88.50499725, 21.95330048], [88.50448608, 21.95344162], [88.5039978, 21.95363045], [88.50351715, 21.95386124], [88.50295258, 21.95387077], [88.50234985, 21.95381737], [88.50179291, 21.95396042], [88.50128937, 21.9542408], [88.50077057, 21.95447159], [88.50028992, 21.95474052], [88.49984741, 21.95505333], [88.49938202, 21.95534325], [88.49887848, 21.9555912], [88.49833679, 21.95583534], [88.49777985, 21.95611382], [88.49723053, 21.95643997], [88.49668884, 21.95680618], [88.4961853, 21.95719337], [88.49564362, 21.95748329], [88.49510193, 21.95770836], [88.49465179, 21.95804024], [88.49423981, 21.958395], [88.49398804, 21.95870972], [88.49389648, 21.95882607], [88.49360657, 21.95929909], [88.49334717, 21.95981026], [88.49318695, 21.96038628], [88.4930191, 21.96100044], [88.49281311, 21.96162033], [88.49278259, 21.96228981], [88.49277496, 21.96299744], [88.49279785, 21.96368217], [88.49290466, 21.96431351], [88.49301147, 21.96487808], [88.49320221, 21.96530914], [88.49334717, 21.96569252], [88.49349213, 21.96602058], [88.49359894, 21.96635056], [88.49364471, 21.96668816], [88.49369812, 21.96705246], [88.4938736, 21.96740532], [88.49404144, 21.96778488], [88.49420166, 21.96817017], [88.49442291, 21.9684906], [88.49461365, 21.96879959], [88.49478149, 21.96912193], [88.49499512, 21.96943855], [88.49520874, 21.96977997], [88.49539948, 21.97018814], [88.49559784, 21.97063255], [88.49585724, 21.97108078], [88.49614716, 21.97150993], [88.49649811, 21.97185516], [88.49677277, 21.97223282], [88.49701691, 21.97260094], [88.49731445, 21.97288895], [88.49754333, 21.97323036], [88.49778748, 21.9735775], [88.49804688, 21.9739399], [88.49832916, 21.97434616], [88.49861145, 21.97474098], [88.498909, 21.97512054], [88.49925232, 21.97541046], [88.49960327, 21.97574043], [88.49995422, 21.97606087], [88.50038147, 21.97637177], [88.50086975, 21.97668457], [88.50138092, 21.97707367], [88.50188446, 21.97753334], [88.50239563, 21.97804451], [88.50296021, 21.97850037], [88.50354004, 21.97887993], [88.50408936, 21.97919464], [88.50453949, 21.97956467], [88.50501251, 21.9799099], [88.50550842, 21.98021889], [88.50603485, 21.98046112], [88.50623322, 21.98052788], [88.50656891, 21.98064041], [88.50702667, 21.9808712], [88.50744629, 21.98112106], [88.50785065, 21.98139], [88.50824738, 21.98166084], [88.50868225, 21.98188591], [88.50915527, 21.98206139], [88.50965118, 21.98225975], [88.51008606, 21.98250961], [88.51053619, 21.98278046], [88.51097107, 21.98303986], [88.51142883, 21.98326111], [88.51190948, 21.9834404], [88.51235199, 21.98366547], [88.51278687, 21.98393059], [88.51325226, 21.98420715], [88.5136261, 21.98448753], [88.51370239, 21.98454475], [88.51415253, 21.98488998], [88.51456451, 21.98525047], [88.51495361, 21.98555183], [88.51528931, 21.98579216], [88.51563263, 21.9858799], [88.51584625, 21.98610115], [88.51608276, 21.98630905], [88.5164566, 21.98648834], [88.51674652, 21.98678207], [88.5170517, 21.9870739], [88.51746368, 21.98729324], [88.51772308, 21.98743248], [88.5178833, 21.98752022], [88.51824951, 21.98779106], [88.51863861, 21.98804092], [88.51911926, 21.9882431], [88.51976013, 21.98830032], [88.52043152, 21.98830986], [88.52108765, 21.98830986], [88.52175903, 21.98830986], [88.52246094, 21.98830032], [88.52312469, 21.9882679], [88.5236969, 21.98817825], [88.52420807, 21.98801041], [88.5246582, 21.98776054], [88.52511597, 21.98749352], [88.52557373, 21.98721695], [88.52604675, 21.98693085], [88.52651215, 21.98660278], [88.5269165, 21.98616982], [88.52732086, 21.98570251], [88.52771759, 21.98522186], [88.52809143, 21.98474121], [88.5284729, 21.98430061], [88.52868652, 21.98407173], [88.52884674, 21.98390007], [88.52926636, 21.98352242], [88.52973938, 21.98315048], [88.53023529, 21.98278618], [88.53073883, 21.98241997], [88.53119659, 21.98200035], [88.53167725, 21.98158073], [88.53217316, 21.98117065], [88.53266907, 21.98079681], [88.53315735, 21.98043823], [88.53366852, 21.98020935], [88.53416443, 21.97998047], [88.53463745, 21.97974968], [88.53508759, 21.97956276], [88.53551483, 21.97941399], [88.5358963, 21.97925949], [88.53627014, 21.97911072], [88.53662109, 21.97894287], [88.53702545, 21.97880554], [88.5375061, 21.9786911], [88.53806305, 21.97864914], [88.53861237, 21.97870827], [88.53910828, 21.97887039], [88.53957367, 21.97905731], [88.53999329, 21.97929382], [88.54043579, 21.97954941], [88.54091644, 21.97980118], [88.54138947, 21.98007011], [88.54177856, 21.98035049], [88.54210663, 21.98066521], [88.54239655, 21.98100281], [88.54270172, 21.98133087], [88.54299927, 21.98165512], [88.5433197, 21.98199463], [88.54360199, 21.98236465], [88.54384613, 21.98275566], [88.54403687, 21.98314095], [88.54426575, 21.98348808], [88.54450226, 21.98381042], [88.54473877, 21.98414993], [88.54496002, 21.98448563], [88.54515839, 21.98487282], [88.54537201, 21.98529053], [88.54561615, 21.98576927], [88.54585266, 21.98636818], [88.54608917, 21.98699951], [88.54629517, 21.98761749], [88.54651642, 21.98818016], [88.54672241, 21.98866081], [88.54691315, 21.98907852], [88.54702759, 21.98945045], [88.54717255, 21.98977089], [88.54727936, 21.99010277], [88.54740906, 21.99043274], [88.5475769, 21.99077988], [88.54779816, 21.99115753], [88.54799652, 21.99158287], [88.54818726, 21.99204063], [88.54840088, 21.99251938], [88.54862976, 21.99303055], [88.54885101, 21.99355888], [88.5490799, 21.99407959], [88.54933167, 21.99459839], [88.54959106, 21.995121], [88.54979706, 21.99566269], [88.54998016, 21.99620628], [88.55013275, 21.9967308], [88.55029297, 21.99724007], [88.55045319, 21.99777031], [88.55056763, 21.99840546], [88.55062103, 21.99913025], [88.55083466, 22.00000191], [88.5509491, 22.00146294], [88.5509491, 22.00341606], [88.55108643, 22.00642967], [88.55108643, 22.00851059], [88.55195618, 22.01145935], [88.55317688, 22.01407051], [88.55412292, 22.01641083], [88.55548096, 22.01930046], [88.5559845, 22.02083778], [88.556633, 22.02318001], [88.556633, 22.02713966], [88.5565567, 22.02820969], [88.55612946, 22.03022003], [88.55548096, 22.03230095], [88.55504608, 22.03396988], [88.55490112, 22.03470993], [88.55476379, 22.03517532], [88.55476379, 22.03544426], [88.55461884, 22.03570938], [88.55440521, 22.03531265], [88.55440521, 22.03396988], [88.55447388, 22.03323364], [88.55461884, 22.03256226], [88.55483246, 22.03182793], [88.55504608, 22.03136063], [88.55526733, 22.03075027], [88.555336, 22.03021812], [88.55548096, 22.02927017], [88.55562592, 22.02807426], [88.55576324, 22.02747154], [88.55583954, 22.02713585], [88.55583954, 22.02652931], [88.55548096, 22.02559662], [88.555336, 22.02445602], [88.555336, 22.02379036], [88.55526733, 22.02284813], [88.55490112, 22.02178001], [88.55446625, 22.02043915], [88.55432892, 22.01976967], [88.554039, 22.01883125], [88.55377197, 22.01828957], [88.55361176, 22.01782227], [88.55303955, 22.01675034], [88.55268097, 22.01614952], [88.55224609, 22.01540947], [88.55181122, 22.01480675], [88.55137634, 22.01412964], [88.55117035, 22.01366806], [88.55103302, 22.01300049], [88.5507431, 22.01226044], [88.55045319, 22.01158905], [88.55023193, 22.01106262], [88.55016327, 22.00978088], [88.54987335, 22.00890923], [88.54959106, 22.00811005], [88.54936981, 22.00743103], [88.54936981, 22.0057621], [88.54944611, 22.00368309], [88.54944611, 22.00000191], [88.54943848, 21.99940109], [88.54930115, 21.99881935], [88.5491333, 21.99825096], [88.5489502, 21.99769974], [88.54876709, 21.99712944], [88.54858398, 21.9965744], [88.54838562, 21.99603271], [88.5482254, 21.99550629], [88.54805756, 21.99502945], [88.54788971, 21.99457169], [88.54769135, 21.99410439], [88.54745483, 21.9936409], [88.54720306, 21.99316025], [88.54697418, 21.99267387], [88.54675293, 21.99218178], [88.54654694, 21.99171829], [88.54634094, 21.99128914], [88.54613495, 21.99086571], [88.54595947, 21.99044037], [88.54579926, 21.99001694], [88.54561615, 21.98957253], [88.54547119, 21.98910332], [88.5452652, 21.98865509], [88.54503632, 21.98821068], [88.54483032, 21.98779106], [88.54467773, 21.98732948], [88.54450989, 21.98689079], [88.5443573, 21.98644829], [88.54416656, 21.98603821], [88.54395294, 21.98558998], [88.54371643, 21.98513985], [88.54342651, 21.98471069], [88.54318237, 21.98427963], [88.54297638, 21.98387146], [88.54277802, 21.98351669], [88.54260254, 21.98319817], [88.5424118, 21.98291969], [88.54218292, 21.98265076], [88.54194641, 21.98236084], [88.54170227, 21.98203087], [88.54141998, 21.98171043], [88.54110718, 21.98139954], [88.54078674, 21.98109055], [88.54043579, 21.98077965], [88.54006958, 21.98053551], [88.53970337, 21.9803009], [88.53933716, 21.98011017], [88.53894043, 21.98000336], [88.53851318, 21.9799614], [88.53805542, 21.97995186], [88.53761292, 21.97997284], [88.53717804, 21.98003006], [88.53678131, 21.98015022], [88.53636169, 21.98031235], [88.53586578, 21.98047638], [88.53536224, 21.98069], [88.53489685, 21.98092079], [88.53442383, 21.98116493], [88.53395081, 21.98142052], [88.53350067, 21.9817028], [88.53305054, 21.98199081], [88.53266907, 21.98233032], [88.53233337, 21.98269081], [88.53199768, 21.98306847], [88.53170776, 21.9834404], [88.53141785, 21.98384285], [88.53106689, 21.98421288], [88.53068542, 21.98458862], [88.53031158, 21.98497963], [88.52996826, 21.98541069], [88.52959442, 21.98582458], [88.52916718, 21.98621941], [88.52869415, 21.98661041], [88.52813721, 21.98696327], [88.527565, 21.98732948], [88.52702332, 21.98773956], [88.52646637, 21.98813057], [88.52593994, 21.9885273], [88.525383, 21.9888401], [88.52481079, 21.9890995], [88.52424622, 21.98929024], [88.52363586, 21.98938942], [88.52301788, 21.98939705], [88.52243042, 21.98941994], [88.52178955, 21.98947525], [88.52133942, 21.98947906], [88.52104187, 21.98948479], [88.52035522, 21.98944283], [88.51983643, 21.98924255], [88.51946259, 21.98887062], [88.51925659, 21.98858833], [88.51876068, 21.98858833], [88.51812744, 21.98874283], [88.5175705, 21.98872757], [88.51721954, 21.98861122], [88.51714325, 21.98856926], [88.5167923, 21.9883709], [88.51641083, 21.98816109], [88.51599121, 21.98789978], [88.51545715, 21.98764992], [88.51480103, 21.98725128], [88.51410675, 21.98688126], [88.51348114, 21.98655128], [88.51287842, 21.98633957], [88.51239014, 21.98610115], [88.51198578, 21.98584175], [88.51159668, 21.98558998], [88.51122284, 21.98541069], [88.51082611, 21.98530006], [88.51048279, 21.98514938], [88.51026154, 21.98475075], [88.50991058, 21.98441124], [88.50937653, 21.98415947], [88.50884247, 21.98392105], [88.50831604, 21.98368835], [88.50784302, 21.98343849], [88.50731659, 21.98324013], [88.50679016, 21.98303032], [88.50627136, 21.98277092], [88.5057373, 21.98248672], [88.50518799, 21.98215103], [88.50460052, 21.98181915], [88.50401306, 21.98149109], [88.50350189, 21.98109055], [88.50302887, 21.98068047], [88.50247955, 21.98032951], [88.50189972, 21.9799614], [88.50135803, 21.97947311], [88.50076294, 21.97902489], [88.50016022, 21.97857285], [88.49964142, 21.97803116], [88.49913025, 21.97748184], [88.49859619, 21.97696114], [88.49807739, 21.9764595], [88.49763489, 21.97597313], [88.4972229, 21.97556114], [88.49681854, 21.97520256], [88.49651337, 21.97480965], [88.49616241, 21.9744606], [88.49584198, 21.9740696], [88.49555206, 21.97364998], [88.49525452, 21.9732666], [88.49489594, 21.97291946], [88.49471283, 21.97242928], [88.49446869, 21.97198486], [88.49419403, 21.97156906], [88.49391174, 21.97116089], [88.49359131, 21.97079277], [88.49331665, 21.97034073], [88.49305725, 21.96988106], [88.49281311, 21.96940994], [88.49262238, 21.96891022], [88.49241638, 21.96841049], [88.49217987, 21.9679203], [88.49186707, 21.96742058], [88.49156952, 21.96689034], [88.4914093, 21.96623993], [88.49138641, 21.96556091], [88.49138641, 21.96492958], [88.49138641, 21.96433067], [88.49138641, 21.96379089], [88.49132538, 21.96329308], [88.49111176, 21.96283913], [88.49089813, 21.96232986], [88.49086761, 21.9617424], [88.49100494, 21.96110916], [88.49118805, 21.96046066], [88.49144745, 21.9598484], [88.49179077, 21.95934105], [88.49217987, 21.95890999], [88.49250031, 21.95848274], [88.49278259, 21.95810509], [88.49305725, 21.95775986], [88.49333191, 21.95741272], [88.49360657, 21.95702934], [88.49388885, 21.95661163], [88.4941864, 21.95617104], [88.49458313, 21.95582199], [88.49497223, 21.9554615], [88.49534607, 21.95508385], [88.49578094, 21.95478058], [88.49621582, 21.95445824], [88.49666595, 21.95417023], [88.4970932, 21.95388985], [88.49750519, 21.95363235], [88.49791718, 21.95340538], [88.49835205, 21.95323181], [88.49880219, 21.95309258], [88.49931335, 21.95298958], [88.49977875, 21.95274734], [88.50029755, 21.9525528], [88.50084686, 21.95239067], [88.5012207, 21.95213127], [88.50150299, 21.95186043], [88.5018158, 21.95163918], [88.50213623, 21.95137024], [88.50250244, 21.95112991], [88.50292969, 21.95096016], [88.50335693, 21.95080948], [88.50376892, 21.95059776], [88.5042572, 21.9504509], [88.50476074, 21.95029068], [88.50527954, 21.95016098], [88.50576782, 21.95004272], [88.50624084, 21.94984436], [88.50679016, 21.94970512], [88.50737, 21.94959068], [88.50778961, 21.94930267], [88.50817871, 21.94898987], [88.50853729, 21.94869041], [88.50892639, 21.94846153], [88.50933838, 21.94828987], [88.50971985, 21.9480629], [88.51010132, 21.94782829], [88.51053619, 21.94772148], [88.51095581, 21.94763947], [88.5113678, 21.94753075], [88.5118103, 21.94748116], [88.51222229, 21.9473381], [88.51261902, 21.94717979], [88.51296234, 21.94695282], [88.51326752, 21.94671059], [88.51354218, 21.94642067], [88.51386261, 21.94617271], [88.51434326, 21.94607353], [88.51486206, 21.94593048], [88.51538849, 21.94573021], [88.51577759, 21.94536018], [88.51616669, 21.94492912], [88.5165863, 21.94449043], [88.51714325, 21.94413948], [88.51767731, 21.94373131], [88.51828766, 21.94334221], [88.51888275, 21.94284248], [88.51946259, 21.94230461], [88.52000427, 21.94177055], [88.52046204, 21.94127083], [88.52062988, 21.94069099], [88.52083588, 21.94026947], [88.52104187, 21.93995667], [88.52120209, 21.93967056], [88.52137756, 21.93942261], [88.52159119, 21.93919945], [88.5218277, 21.93901062], [88.52197266, 21.93868065], [88.5221405, 21.93835068], [88.52220154, 21.9379406], [88.5222168, 21.93750954], [88.52229309, 21.93707275], [88.52249908, 21.9366703], [88.52271271, 21.93626022], [88.52275085, 21.93580818], [88.52274323, 21.93534279], [88.52276611, 21.93482971], [88.52275085, 21.9343071], [88.52268219, 21.93379021], [88.52274323, 21.93344116], [88.52281952, 21.93309975], [88.52301025, 21.9327507], [88.52305603, 21.93228912], [88.52303314, 21.93180084], [88.52295685, 21.93131828], [88.52281189, 21.93089104], [88.52276611, 21.93046951], [88.52277374, 21.93004608], [88.52276611, 21.92962074], [88.52274323, 21.92920113], [88.52258301, 21.92879295], [88.52250671, 21.92835045], [88.52246857, 21.92789078], [88.52231598, 21.92744064], [88.52223206, 21.92695045], [88.5222168, 21.9264183], [88.5222168, 21.92588806], [88.5222168, 21.92537117], [88.5222702, 21.92486191], [88.52240753, 21.92432976], [88.52224731, 21.92375946], [88.5220871, 21.92316055], [88.52194977, 21.92256737], [88.52184296, 21.92200089], [88.52173615, 21.92152977], [88.52186584, 21.92110825], [88.5218811, 21.92072105], [88.52181244, 21.92034149], [88.52170563, 21.91996574], [88.52168274, 21.91955757], [88.52173615, 21.91904259], [88.52185822, 21.91841888], [88.5217514, 21.91783905], [88.52159882, 21.91720963], [88.52124786, 21.91661072], [88.52091217, 21.91601563], [88.5206604, 21.91539574], [88.5202179, 21.91501045], [88.51973724, 21.91473961], [88.51928711, 21.91448975], [88.51882935, 21.91436195], [88.51843262, 21.9141655], [88.51808167, 21.9139328], [88.51779938, 21.91363144], [88.5174942, 21.91335678], [88.51711273, 21.91320038], [88.51661682, 21.91314888], [88.5164566, 21.9132061], [88.51610565, 21.91333961], [88.51557922, 21.91358948], [88.51506805, 21.91384125], [88.514534, 21.91388512], [88.51399994, 21.91389084], [88.51352692, 21.91394043], [88.5131073, 21.91410828], [88.51264191, 21.91410828], [88.51213837, 21.91415024], [88.51155853, 21.91410828], [88.51091003, 21.91399956], [88.51026917, 21.91412926], [88.50965118, 21.91415977], [88.50904083, 21.91417122], [88.50849915, 21.91417122], [88.50801086, 21.91421127], [88.50757599, 21.91439438], [88.50711823, 21.91444206], [88.50665283, 21.91448021], [88.50623322, 21.91466522], [88.50583649, 21.91472244], [88.50222015, 21.91472244], [88.5019455, 21.91444588], [88.50147247, 21.91439819], [88.50108337, 21.91415024], [88.50064087, 21.91394043], [88.50012207, 21.91389275], [88.49960327, 21.91386795], [88.49942017, 21.91383362], [88.4990921, 21.91377068], [88.49855042, 21.91353035], [88.4981308, 21.91353035], [88.49781036, 21.91360092], [88.49745941, 21.91361809], [88.49720001, 21.91361427], [88.49705505, 21.91361237], [88.49661255, 21.91358185], [88.4961853, 21.91342735], [88.49569702, 21.91335106], [88.49520111, 21.91333008], [88.49466705, 21.91333008], [88.494133, 21.91333961], [88.49357605, 21.91333961], [88.49304962, 21.91328812], [88.49260712, 21.91306686], [88.49221039, 21.91282272], [88.49183655, 21.91257095], [88.49143982, 21.91240883], [88.4910202, 21.91228294], [88.490448, 21.91233253], [88.48999023, 21.91228485], [88.48956299, 21.91220284], [88.48915863, 21.91208076], [88.4887619, 21.91196823], [88.4883728, 21.91191292], [88.48799896, 21.91177177], [88.48748779, 21.91162109], [88.48703766, 21.9114151], [88.4865799, 21.91128922], [88.48615265, 21.91110039], [88.48571014, 21.91090012], [88.4852066, 21.91078949], [88.48475647, 21.91055107], [88.48430634, 21.91029549], [88.48377991, 21.91012192], [88.48323822, 21.90995979], [88.48280334, 21.90966034], [88.48236847, 21.90932083], [88.48194122, 21.9090004], [88.48149872, 21.90870667], [88.4810791, 21.90840912], [88.4806366, 21.90814018], [88.48026276, 21.90777969], [88.47986603, 21.90738106], [88.47944641, 21.90693092], [88.47902679, 21.90640068], [88.47857666, 21.90587044], [88.4781189, 21.90536118], [88.47762299, 21.9048996], [88.47727203, 21.9043808], [88.47702789, 21.90383148], [88.47685242, 21.90327072], [88.47664642, 21.90272141], [88.47638702, 21.90219688], [88.47612, 21.90167046], [88.47586823, 21.90113449], [88.4756546, 21.90056229], [88.4754715, 21.90001106], [88.47535706, 21.89948082], [88.47537231, 21.89937973], [88.47541809, 21.89894676], [88.47551727, 21.89842033], [88.47556305, 21.89793015], [88.47553253, 21.89744377], [88.47537994, 21.89696693], [88.4751358, 21.89653015], [88.47489166, 21.89624977], [88.47463226, 21.89602089], [88.47438812, 21.89583015], [88.47414398, 21.89566422], [88.47386932, 21.89551544], [88.47355652, 21.89534187], [88.47316742, 21.89542961], [88.4726944, 21.89553833], [88.47219086, 21.89555359], [88.47167969, 21.89551353], [88.47113037, 21.89542961], [88.4704895, 21.89578438], [88.47023773, 21.89584351], [88.46977234, 21.89596176], [88.46895599, 21.89586067], [88.46823883, 21.89591026], [88.46762848, 21.89607048], [88.46708679, 21.89618111], [88.4666214, 21.89635086], [88.46613312, 21.89638901], [88.46563721, 21.89639473], [88.46513367, 21.89638901], [88.46460724, 21.89639091], [88.46409607, 21.89639664], [88.46357727, 21.89645195], [88.46313477, 21.89667892], [88.4628067, 21.89687157], [88.46269226, 21.89694023], [88.46224976, 21.8971653], [88.46173096, 21.89723969], [88.46124268, 21.89736938], [88.46075439, 21.8974781], [88.46047211, 21.89749527], [88.46021271, 21.89751053], [88.4596405, 21.89751625], [88.4590683, 21.89760399], [88.45855713, 21.8977375], [88.45806122, 21.89783287], [88.4576416, 21.89808846], [88.4572525, 21.89834976], [88.45683289, 21.89861107], [88.45643616, 21.89884567], [88.45612335, 21.89916039], [88.45582581, 21.89953041], [88.45561218, 21.89994812], [88.45555878, 21.90043831], [88.45555115, 21.90090942], [88.45559692, 21.9014225], [88.45575714, 21.90183258], [88.45582581, 21.90228081], [88.45583344, 21.90273094], [88.45587158, 21.90316963], [88.45604706, 21.90359116], [88.45610809, 21.90405273], [88.4561615, 21.90452194], [88.45635223, 21.90491867], [88.45648193, 21.90535164], [88.45667267, 21.90576553], [88.45687103, 21.90620041], [88.45701599, 21.90672112], [88.45722961, 21.90723038], [88.45749664, 21.9077301], [88.45777893, 21.90821075], [88.45804596, 21.90864944], [88.4582901, 21.90905762], [88.45841217, 21.90950012], [88.45862579, 21.90989113], [88.45889282, 21.91023064], [88.45915222, 21.91058922], [88.45934296, 21.91101646], [88.45952606, 21.91146088], [88.45969391, 21.91186714], [88.45976257, 21.91226959], [88.45992279, 21.91258049], [88.45999908, 21.91290855], [88.46005249, 21.91324043], [88.46018982, 21.91354942], [88.46035004, 21.91390038], [88.46052551, 21.91431618], [88.46068573, 21.91479301], [88.46083832, 21.9152813], [88.46099854, 21.91572189], [88.46111298, 21.91613007], [88.46121979, 21.91648293], [88.46136475, 21.91675949], [88.46144867, 21.91707039], [88.46160126, 21.91734123], [88.46170044, 21.91769028], [88.46188354, 21.91802979], [88.46194458, 21.91848183], [88.46193695, 21.91898537], [88.46200562, 21.91950226], [88.46209717, 21.91994286], [88.46201324, 21.92045021], [88.46216583, 21.92080879], [88.46224213, 21.92110062], [88.46221924, 21.92160988], [88.46222687, 21.92188072], [88.46222687, 21.9221611], [88.46221924, 21.92246056], [88.46219635, 21.92277718], [88.46211243, 21.92311287], [88.46196747, 21.92350006], [88.46187592, 21.92398262], [88.46164703, 21.9244709], [88.46135712, 21.9249897], [88.46099854, 21.92550087], [88.46060944, 21.92597961], [88.46029663, 21.92645073], [88.46006775, 21.92686844], [88.45985413, 21.92720413], [88.45964813, 21.9274826], [88.45947266, 21.9277401], [88.4593277, 21.92805099], [88.45915222, 21.92838097], [88.45889282, 21.92873955], [88.45858765, 21.92915916], [88.45818329, 21.92957115], [88.45775604, 21.93000031], [88.45733643, 21.93041611], [88.45684814, 21.93084145], [88.45639038, 21.93133163], [88.45597076, 21.93181229], [88.45561218, 21.93227959], [88.45532227, 21.93270683], [88.45524597, 21.93278503], [88.45501709, 21.93302345], [88.4547348, 21.93326187], [88.45452118, 21.9335041], [88.45443726, 21.9338398], [88.45432281, 21.93418121], [88.45413208, 21.93447876], [88.4540329, 21.93490028], [88.45391846, 21.93514061], [88.45375061, 21.9354496], [88.45372009, 21.93574715], [88.45361328, 21.93596268], [88.45352936, 21.93594742], [88.45345306, 21.93643951], [88.45333099, 21.93695068], [88.45324707, 21.93729973], [88.45305634, 21.93805313], [88.45310211, 21.93834305], [88.45304871, 21.93881989], [88.45289612, 21.93953705], [88.45289612, 21.94005394], [88.4529953, 21.9404583], [88.45307922, 21.94091034], [88.45323181, 21.94139099], [88.45340729, 21.94186974], [88.45365906, 21.94226646], [88.4539032, 21.94267273], [88.45417023, 21.94309998], [88.45449066, 21.94355965], [88.45487976, 21.94404984], [88.45529938, 21.94457817], [88.45573425, 21.94514656], [88.45613098, 21.94577026], [88.45677948, 21.94625092], [88.45735931, 21.9466095], [88.45799255, 21.94705963], [88.45845032, 21.94735146], [88.45906067, 21.94763947], [88.45935822, 21.9480629], [88.45981598, 21.94833183], [88.46026611, 21.94855309], [88.46066284, 21.94879341], [88.46102905, 21.94903946], [88.46144104, 21.94922829], [88.46185303, 21.94943237], [88.46227264, 21.94967079], [88.4627533, 21.94989014], [88.46347046, 21.95000648], [88.46389008, 21.95018005], [88.46406555, 21.95030403], [88.46433258, 21.95049095], [88.46481323, 21.95082283], [88.46530914, 21.9510994], [88.4658432, 21.95139122], [88.46642303, 21.9516983], [88.46704865, 21.95204735], [88.46767426, 21.95243454], [88.46823883, 21.95283127], [88.46865082, 21.95331192], [88.46897125, 21.95375061], [88.46918488, 21.95415878], [88.46944427, 21.95447159], [88.4697113, 21.95471954], [88.4699707, 21.95498085], [88.47019196, 21.9552803], [88.47032166, 21.95573044], [88.47051239, 21.95621109], [88.47062683, 21.95672989], [88.4705658, 21.95725632], [88.47048187, 21.95778084], [88.47032928, 21.95832825], [88.47020721, 21.95890045], [88.46998596, 21.95940971], [88.4697113, 21.95986938], [88.46942902, 21.96029472], [88.46912384, 21.96069717], [88.46876526, 21.96107292], [88.46835327, 21.9614296], [88.4679184, 21.96178818], [88.46746063, 21.96213913], [88.46696472, 21.96243286], [88.46641541, 21.9626236], [88.46589661, 21.96280098], [88.46542358, 21.96300125], [88.46495056, 21.96313095], [88.46450806, 21.96327972], [88.46405792, 21.96338081], [88.46368408, 21.96352005], [88.46326447, 21.96359253], [88.46276855, 21.96363258], [88.46204376, 21.96346283], [88.46128082, 21.9633503], [88.46099091, 21.96348953], [88.46080017, 21.96373177], [88.46034241, 21.96387291], [88.4597168, 21.96401024], [88.45900726, 21.96414185], [88.45826721, 21.96417046], [88.45752716, 21.96416283], [88.45681, 21.96410942], [88.45607758, 21.96397018], [88.45536041, 21.96408272], [88.45465851, 21.96392822], [88.45391846, 21.96389008], [88.45317078, 21.96389008], [88.45243073, 21.96389008], [88.45168304, 21.96389008], [88.45096588, 21.96389008], [88.45024109, 21.96389008], [88.44953156, 21.96388626], [88.44885254, 21.9638958], [88.4485321, 21.96392441], [88.4482193, 21.96395493], [88.44766998, 21.96416283], [88.44716644, 21.96438026], [88.44667816, 21.96454239], [88.44631958, 21.96487045], [88.44608307, 21.96537971], [88.44593048, 21.96595955], [88.44591522, 21.96655655], [88.445961, 21.96717453], [88.44606018, 21.9675808], [88.44609833, 21.96774292], [88.44628906, 21.96825981], [88.44642639, 21.96887016], [88.4466629, 21.96941948], [88.44689941, 21.96996117], [88.44706726, 21.97046089], [88.44718933, 21.97089958], [88.44727325, 21.97129059], [88.44742584, 21.9716301], [88.44754028, 21.97204971], [88.44774628, 21.97250175], [88.44793701, 21.97301102], [88.44812012, 21.97356987], [88.44828033, 21.97413063], [88.44837952, 21.97468758], [88.44856262, 21.97521019], [88.44861603, 21.97580719], [88.4486618, 21.97616959], [88.44869995, 21.97645187], [88.44889832, 21.97710991], [88.44909668, 21.97777939], [88.44915771, 21.97851181], [88.4491806, 21.97919846], [88.44924164, 21.97983932], [88.44939423, 21.98043442], [88.44944, 21.98101997], [88.44944763, 21.98162651], [88.44944763, 21.98224258], [88.44944763, 21.98285484], [88.44944763, 21.9834404], [88.44943237, 21.98398972], [88.44934845, 21.98447609], [88.44917297, 21.98488998], [88.44893646, 21.98533821], [88.44876862, 21.98591042], [88.44854736, 21.98648071], [88.44824219, 21.98698807], [88.44786835, 21.98743248], [88.44743347, 21.98778343], [88.44694519, 21.98806381], [88.44647217, 21.98833275], [88.44602203, 21.98860168], [88.44554901, 21.98886108], [88.4450531, 21.9890995], [88.44451904, 21.9892807], [88.44404602, 21.98949051], [88.44367981, 21.98971558], [88.4434433, 21.98991013], [88.44335938, 21.99012184], [88.44348907, 21.99051094], [88.4437027, 21.99115944], [88.44396973, 21.99180984], [88.4443512, 21.99234009], [88.44482422, 21.99274063], [88.44529724, 21.99306107], [88.44573212, 21.99336052], [88.44611359, 21.99367905], [88.44644928, 21.99400139], [88.44680786, 21.99427986], [88.44717407, 21.99453926], [88.44750977, 21.99482346], [88.44782257, 21.99510956], [88.44814301, 21.9953804], [88.44843292, 21.99567986], [88.44866943, 21.99604034], [88.4489212, 21.99643517], [88.4491806, 21.99690056], [88.44945526, 21.99741554], [88.44972992, 21.99799347], [88.44999695, 21.99862289], [88.45015717, 21.99926949], [88.45027924, 22.00000191], [88.45027924, 22.00055504], [88.45055389, 22.00083351], [88.45054626, 22.00472069], [88.45027924, 22.00500107], [88.45027924, 22.00611115], [88.45055389, 22.00638962], [88.45054626, 22.00722122], [88.4516983, 22.00830269], [88.45240784, 22.00863075], [88.45284271, 22.00869942], [88.45327759, 22.00869942], [88.4536972, 22.00882912], [88.45464325, 22.00882912], [88.45556641, 22.00876045], [88.4575882, 22.00876427], [88.45830536, 22.00896454], [88.45902252, 22.00923347], [88.45967102, 22.0096302], [88.46017456, 22.00996971], [88.46060181, 22.01057243], [88.46089172, 22.01097488], [88.46111298, 22.0112381], [88.46111298, 22.01138115], [88.46089172, 22.01157951], [88.46076965, 22.01153374], [88.46053314, 22.01144409], [88.46009827, 22.01097488], [88.45967102, 22.01057243], [88.45902252, 22.01023865], [88.45809174, 22.01004028], [88.45744324, 22.00996971], [88.45622253, 22.00996971], [88.45456696, 22.01004028], [88.45233917, 22.01004028], [88.45133972, 22.00984001], [88.45089722, 22.0095005], [88.45040131, 22.009161], [88.4498291, 22.00829506], [88.44967651, 22.00782967], [88.44933319, 22.00702095], [88.44911194, 22.00668716], [88.44889069, 22.00562096], [88.44889069, 22.00222015], [88.44916534, 22.00194359], [88.44916534, 22.00083351], [88.44889069, 22.00055504], [88.44889069, 22.00000191], [88.44892883, 21.99930954], [88.44873047, 21.99875069], [88.44850922, 21.99822617], [88.44819641, 21.99780273], [88.44787598, 21.99742126], [88.4475708, 21.99703026], [88.44724274, 21.9966507], [88.44691467, 21.99627113], [88.44656372, 21.99591827], [88.44616699, 21.99559975], [88.44577789, 21.99529266], [88.44537354, 21.99500275], [88.44496918, 21.99472237], [88.44458771, 21.99445152], [88.44421387, 21.9941864], [88.44387817, 21.99389267], [88.44353485, 21.99359894], [88.44319153, 21.99329948], [88.44285583, 21.99298096], [88.44254303, 21.99263], [88.44226837, 21.99226761], [88.4420166, 21.99188995], [88.44179535, 21.99149895], [88.4416275, 21.99106026], [88.44168854, 21.99060822], [88.44182587, 21.99020958], [88.44197083, 21.9899292], [88.44211578, 21.98968124], [88.442276, 21.98942947], [88.44245911, 21.98920822], [88.4426651, 21.98901367], [88.44289398, 21.98882484], [88.44313049, 21.98860359], [88.44341278, 21.98838425], [88.44374847, 21.98819542], [88.44410706, 21.98801994], [88.44443512, 21.98784828], [88.44477844, 21.98771286], [88.44514465, 21.98755646], [88.44555664, 21.98736191], [88.44596863, 21.98711777], [88.44641113, 21.98687172], [88.44683075, 21.98661041], [88.44719696, 21.98630905], [88.44747925, 21.9859333], [88.4477005, 21.98551559], [88.4478302, 21.98503113], [88.44798279, 21.98451805], [88.44803619, 21.98393059], [88.44805908, 21.98330116], [88.44805908, 21.98265076], [88.44803619, 21.98200035], [88.44799805, 21.98138046], [88.44783783, 21.98081017], [88.44777679, 21.98019981], [88.44777679, 21.97960663], [88.44774628, 21.97903061], [88.44764709, 21.97847939], [88.44753265, 21.97794342], [88.4474411, 21.97740364], [88.44727325, 21.97689629], [88.44718933, 21.9763298], [88.44703674, 21.97577095], [88.44690704, 21.97518921], [88.44668579, 21.97464943], [88.44650269, 21.9740696], [88.44633484, 21.97346687], [88.44610596, 21.97289085], [88.44589233, 21.97233772], [88.44576263, 21.97177124], [88.44556427, 21.97126961], [88.44538879, 21.97079277], [88.44525146, 21.97030258], [88.44507599, 21.96983719], [88.44499969, 21.96931839], [88.44490814, 21.96883583], [88.44477081, 21.96841049], [88.44472504, 21.96804237], [88.44472504, 21.96767807], [88.44471741, 21.96727943], [88.44468689, 21.96680069], [88.44464874, 21.96623993], [88.44468689, 21.96562958], [88.44481659, 21.96502113], [88.44506836, 21.96455383], [88.44532776, 21.9641552], [88.44565582, 21.96384048], [88.44607544, 21.96362114], [88.4465332, 21.96343613], [88.44703674, 21.96329117], [88.44745636, 21.96308708], [88.44780731, 21.96285057], [88.44822693, 21.96267128], [88.44867706, 21.96249962], [88.44915009, 21.96232033], [88.44963074, 21.96224022], [88.45009613, 21.96219826], [88.45053101, 21.96213913], [88.45096588, 21.96213913], [88.45144653, 21.96219826], [88.45202637, 21.96219826], [88.45264435, 21.96221161], [88.45324707, 21.96219826], [88.45379639, 21.96222115], [88.45432281, 21.96222115], [88.45478821, 21.96222115], [88.45529175, 21.96222115], [88.45584106, 21.96222115], [88.45642853, 21.96223068], [88.45703125, 21.9622612], [88.4572525, 21.96228981], [88.45761871, 21.96234131], [88.45820618, 21.96245956], [88.45883179, 21.96249962], [88.45942688, 21.96249962], [88.4599762, 21.96251106], [88.46048737, 21.96256256], [88.46096802, 21.96264076], [88.46156311, 21.96253967], [88.46224213, 21.96231079], [88.4629364, 21.96222115], [88.46362305, 21.96216011], [88.46424866, 21.96199036], [88.46484375, 21.96187592], [88.46534729, 21.96167946], [88.46582031, 21.96149635], [88.46626282, 21.96132278], [88.46666718, 21.96108818], [88.46703339, 21.96080971], [88.46737671, 21.96051788], [88.46769714, 21.96019936], [88.46801758, 21.95986176], [88.46827698, 21.95948029], [88.46852875, 21.95906067], [88.46871948, 21.95856285], [88.46892548, 21.95796967], [88.46905518, 21.95725822], [88.46900177, 21.95650101], [88.46882629, 21.95583916], [88.46855164, 21.95540047], [88.46822357, 21.95513725], [88.46791077, 21.95482254], [88.46761322, 21.95449066], [88.46725464, 21.95424652], [88.46679688, 21.9541111], [88.46642303, 21.95387077], [88.46606445, 21.95358086], [88.46562958, 21.95331955], [88.46517944, 21.95305443], [88.46485138, 21.9528656], [88.46471405, 21.95278549], [88.46422577, 21.9525528], [88.46380615, 21.95225525], [88.46338654, 21.95195007], [88.46295166, 21.95166779], [88.46248627, 21.95141029], [88.46198273, 21.95119095], [88.46143341, 21.9509964], [88.46087646, 21.95076942], [88.46032715, 21.9505291], [88.45976257, 21.9502697], [88.45921326, 21.94997406], [88.45874786, 21.94958115], [88.45819092, 21.94931984], [88.45775604, 21.94904137], [88.45722961, 21.94860268], [88.45674133, 21.94826126], [88.45613861, 21.9480381], [88.45559692, 21.94775009], [88.45519257, 21.9473629], [88.45477295, 21.94709969], [88.45445251, 21.94676781], [88.45417023, 21.94639969], [88.45383453, 21.94605827], [88.45350647, 21.94573021], [88.45320129, 21.94536972], [88.45287323, 21.94498825], [88.45253754, 21.94454956], [88.45230103, 21.94395828], [88.45211029, 21.94325066], [88.451828, 21.94259453], [88.45148468, 21.94202614], [88.45133972, 21.94146919], [88.45131683, 21.9410305], [88.45134735, 21.9409523], [88.45139313, 21.94083023], [88.4513855, 21.93944359], [88.45111084, 21.93916512], [88.45131683, 21.93856049], [88.45115662, 21.93812943], [88.45107269, 21.9376297], [88.45110321, 21.93702126], [88.45110321, 21.93667984], [88.45105743, 21.9363575], [88.45105743, 21.93540573], [88.45149231, 21.93460083], [88.4515686, 21.93334007], [88.45243073, 21.93179321], [88.45365143, 21.9300251], [88.45466614, 21.92916107], [88.45529938, 21.92828941], [88.45581818, 21.9280262], [88.45643616, 21.92723083], [88.45735931, 21.92560005], [88.45828247, 21.92435074], [88.45867157, 21.92361069], [88.45869446, 21.92318535], [88.45864868, 21.92212105], [88.45886993, 21.9217205], [88.45889282, 21.92114067], [88.45890808, 21.92046165], [88.45881653, 21.91989517], [88.45857239, 21.91940117], [88.45848083, 21.91884041], [88.45822144, 21.91852951], [88.4580307, 21.91820145], [88.457901, 21.91777039], [88.45759583, 21.91755104], [88.45730591, 21.91732025], [88.45698547, 21.91714287], [88.45665741, 21.91690636], [88.45627594, 21.91665077], [88.4559021, 21.91636658], [88.45553589, 21.91604042], [88.45526123, 21.91565704], [88.45487976, 21.91533089], [88.45412445, 21.91518211], [88.45345306, 21.91496849], [88.45284271, 21.91468239], [88.45224762, 21.91436577], [88.45168304, 21.914011], [88.4511261, 21.91365051], [88.45057678, 21.91335106], [88.4500351, 21.91313171], [88.44946289, 21.91300201], [88.44894409, 21.91283417], [88.44841766, 21.91271973], [88.44790649, 21.91256142], [88.44735718, 21.91244125], [88.44683075, 21.91228294], [88.44626617, 21.91220284], [88.44573975, 21.91212082], [88.44526672, 21.91200066], [88.44474792, 21.9119091], [88.44444275, 21.91195107], [88.44387817, 21.91194916], [88.44361115, 21.91195107], [88.44333649, 21.91167068], [88.44277954, 21.91167068], [88.44249725, 21.9113903], [88.44167328, 21.9113903], [88.44083405, 21.9105587], [88.44055176, 21.91028023], [88.44039917, 21.91011047], [88.44023132, 21.90992737], [88.43991852, 21.90954018], [88.43952179, 21.90925026], [88.43906403, 21.9090519], [88.4386673, 21.90881729], [88.43834686, 21.90849113], [88.43805695, 21.90806007], [88.43772888, 21.90760231], [88.43730927, 21.90716362], [88.43695068, 21.90664101], [88.43662262, 21.90610123], [88.4361496, 21.9056778], [88.43575287, 21.90519905], [88.43533325, 21.90475464], [88.4349823, 21.90435028], [88.43466187, 21.90397835], [88.43430328, 21.90363121], [88.43385315, 21.90330124], [88.43338776, 21.9030304], [88.43299866, 21.90281105], [88.43264008, 21.90277481], [88.43234253, 21.90275383], [88.43205261, 21.90266037], [88.43172455, 21.90275574], [88.43141174, 21.90299034], [88.43107605, 21.90313911], [88.43078613, 21.9033699], [88.43044281, 21.90363121], [88.43000793, 21.9039402], [88.42962646, 21.90439606], [88.42935944, 21.90464973], [88.42913818, 21.90485764], [88.42856598, 21.9052906], [88.4280014, 21.90575027], [88.42739868, 21.90615082], [88.42687225, 21.90659142], [88.42629242, 21.90693092], [88.42565155, 21.90722275], [88.42494965, 21.90747833], [88.42418671, 21.90771294], [88.42344666, 21.90775108], [88.42273712, 21.90764046], [88.42209625, 21.90752029], [88.42156982, 21.90744209], [88.42121124, 21.90725327], [88.42086029, 21.90711212], [88.42056274, 21.9069519], [88.42027283, 21.90679932], [88.41996765, 21.90667343], [88.41972351, 21.90655136], [88.41951752, 21.90637589], [88.41929626, 21.90614128], [88.41898346, 21.90590858], [88.41870117, 21.90558052], [88.41835022, 21.9052906], [88.41802216, 21.90501022], [88.41773987, 21.90473938], [88.4174881, 21.90449715], [88.41725159, 21.9042511], [88.41707611, 21.90390015], [88.41687012, 21.90335846], [88.41670227, 21.90278816], [88.41661835, 21.9022274], [88.41639709, 21.9017601], [88.4163208, 21.90153122], [88.41622925, 21.90127182], [88.41619873, 21.90079117], [88.41634369, 21.90029907], [88.41638184, 21.89981079], [88.41638947, 21.8993206], [88.41638947, 21.8988266], [88.41638184, 21.89829063], [88.41636658, 21.89767075], [88.41638184, 21.89700127], [88.41638947, 21.89628983], [88.41638947, 21.89556122], [88.41633606, 21.89483833], [88.4161377, 21.89420319], [88.41586304, 21.89364433], [88.41567993, 21.89307594], [88.41549683, 21.8925209], [88.41532898, 21.89199066], [88.41525269, 21.89151955], [88.41506958, 21.89115906], [88.41496277, 21.89081955], [88.41475677, 21.89055634], [88.41468048, 21.89023018], [88.41448975, 21.88993835], [88.41429901, 21.88957024], [88.41405487, 21.88917351], [88.41374207, 21.88874626], [88.41333771, 21.88830948], [88.41291809, 21.8878479], [88.4123764, 21.88744926], [88.41157532, 21.88729286], [88.4111557, 21.88687515], [88.41073608, 21.88638115], [88.41021729, 21.88606834], [88.40970612, 21.88581276], [88.40919495, 21.88555908], [88.40866852, 21.8853302], [88.40818787, 21.88519287], [88.40779114, 21.88503075], [88.40738678, 21.88495064], [88.40705872, 21.8848114], [88.40694427, 21.88472176], [88.40444183, 21.88471985], [88.40416718, 21.88500023], [88.4033432, 21.88500023], [88.40320587, 21.88500977], [88.40305328, 21.88500023], [88.40270996, 21.88486099], [88.40249634, 21.88472176], [88.40139008, 21.88583565], [88.40139008, 21.88652039], [88.40139008, 21.88666534], [88.40110779, 21.88694382], [88.40110779, 21.88722038], [88.40110016, 21.88760948], [88.40103912, 21.88799095], [88.40090942, 21.88834763], [88.40072632, 21.88872337], [88.40048218, 21.88910103], [88.40011597, 21.889431], [88.39968872, 21.88972092], [88.39923096, 21.88999748], [88.39878082, 21.89027977], [88.39834595, 21.89055824], [88.3979187, 21.89087105], [88.39745331, 21.89113998], [88.39694977, 21.89133835], [88.39638519, 21.89142227], [88.39586639, 21.8915844], [88.39539337, 21.89183044], [88.39501953, 21.89213943], [88.39459991, 21.89228821], [88.3941803, 21.89245987], [88.39369965, 21.89254761], [88.39322662, 21.89269066], [88.39273071, 21.89280319], [88.39225769, 21.89299965], [88.39183044, 21.89328957], [88.39138031, 21.8934803], [88.39089203, 21.89361954], [88.39039612, 21.89376068], [88.38996124, 21.89395142], [88.38954926, 21.89426041], [88.38912964, 21.89454079], [88.38867188, 21.89472961], [88.38819122, 21.89487076], [88.38777161, 21.89504433], [88.3874588, 21.89533424], [88.38719177, 21.89570045], [88.38690186, 21.89606094], [88.38656616, 21.89635086], [88.38620758, 21.89657211], [88.38585663, 21.89677048], [88.38555908, 21.89705086], [88.38527679, 21.89742279], [88.38504028, 21.89791107], [88.38488007, 21.89853287], [88.38474274, 21.89915276], [88.38466644, 21.89980507], [88.38463593, 21.90048027], [88.38482666, 21.90108109], [88.38504028, 21.90170288], [88.38527679, 21.90229988], [88.38556671, 21.90287018], [88.38587952, 21.90341949], [88.38621521, 21.90395164], [88.38667297, 21.9043808], [88.38712311, 21.90479088], [88.38749695, 21.90525055], [88.38796234, 21.90565109], [88.38838196, 21.90615082], [88.38887787, 21.90662956], [88.38946533, 21.90698624], [88.39002991, 21.90730286], [88.39058685, 21.90754128], [88.39113617, 21.90775108], [88.3916626, 21.90793037], [88.39212799, 21.90814018], [88.39260864, 21.90837097], [88.39303589, 21.90867043], [88.39346313, 21.90898514], [88.39391327, 21.90917015], [88.39431, 21.9093399], [88.39473724, 21.90949059], [88.39515686, 21.90966988], [88.39565277, 21.90973091], [88.39612579, 21.90986824], [88.39658356, 21.91002274], [88.39700317, 21.91024971], [88.39742279, 21.91040993], [88.39788818, 21.91057968], [88.39832306, 21.91082954], [88.39875793, 21.91107941], [88.39923859, 21.91127968], [88.39976501, 21.91142082], [88.40023804, 21.91162491], [88.40052032, 21.9116993], [88.40071106, 21.91175079], [88.40113068, 21.91195107], [88.4015274, 21.91220284], [88.40194702, 21.91244125], [88.40238953, 21.91271973], [88.40288544, 21.91293716], [88.40341187, 21.9131012], [88.40391541, 21.91327095], [88.40433502, 21.91355324], [88.40468597, 21.91387939], [88.4050293, 21.91421127], [88.40537262, 21.91455269], [88.40570831, 21.91491127], [88.4059906, 21.91530037], [88.40627289, 21.91570854], [88.40660858, 21.91607285], [88.40691376, 21.91645813], [88.4071579, 21.91690445], [88.40725708, 21.91744423], [88.40744781, 21.91797829], [88.40753937, 21.91852951], [88.40770721, 21.91899109], [88.40777588, 21.91949272], [88.40777588, 21.92000008], [88.40777588, 21.92052078], [88.40776062, 21.92102814], [88.40769958, 21.92152023], [88.40753174, 21.92195892], [88.40743256, 21.92246056], [88.40721893, 21.92294121], [88.40696716, 21.92346191], [88.40672302, 21.92401123], [88.40638733, 21.9244709], [88.40602112, 21.92490005], [88.40557861, 21.9253006], [88.40525055, 21.92576027], [88.4048996, 21.92620087], [88.40455627, 21.92658043], [88.40432739, 21.92703056], [88.40397644, 21.92741013], [88.40361023, 21.92778015], [88.40322876, 21.92815971], [88.40284729, 21.92853546], [88.40242767, 21.92888069], [88.40197754, 21.9292202], [88.40154266, 21.92958069], [88.40107727, 21.92993927], [88.40061951, 21.93029976], [88.40023041, 21.93071175], [88.39980316, 21.93103981], [88.39940643, 21.93136024], [88.39907074, 21.9316597], [88.39872742, 21.93193054], [88.39836121, 21.93219948], [88.39798737, 21.93249893], [88.39756775, 21.93283844], [88.39716339, 21.93328285], [88.39672089, 21.93369293], [88.3963089, 21.93412971], [88.39588928, 21.934515], [88.39550781, 21.93491936], [88.39509583, 21.93531036], [88.39472961, 21.93572044], [88.39441681, 21.93618011], [88.39424896, 21.93676949], [88.39418793, 21.93731117], [88.39414978, 21.9377594], [88.39406586, 21.93821907], [88.39403534, 21.93872833], [88.3941803, 21.9392128], [88.3943634, 21.93970108], [88.39454651, 21.9401207], [88.39479065, 21.94052124], [88.39504242, 21.94087982], [88.39527893, 21.9412899], [88.3955307, 21.9417305], [88.39573669, 21.94222832], [88.39592743, 21.94273949], [88.39613342, 21.94319725], [88.39639282, 21.94359016], [88.39657593, 21.94399071], [88.396698, 21.9444294], [88.39693451, 21.94479561], [88.3971405, 21.94519043], [88.39736938, 21.94560051], [88.3976059, 21.94606972], [88.39790344, 21.94651604], [88.39820862, 21.94698143], [88.39842987, 21.94748306], [88.39861298, 21.9479599], [88.39879608, 21.94841957], [88.39897156, 21.94886971], [88.39913177, 21.94933128], [88.39919281, 21.94987106], [88.39929199, 21.95045853], [88.39933014, 21.9511261], [88.39920807, 21.95182419], [88.39906311, 21.95249557], [88.39881134, 21.95309258], [88.39846802, 21.95353889], [88.39803314, 21.95387459], [88.39755249, 21.95416451], [88.39705658, 21.95442963], [88.39659882, 21.95467949], [88.39614105, 21.9548912], [88.39572906, 21.95510292], [88.39533234, 21.95529938], [88.39496613, 21.95550919], [88.39451599, 21.9555912], [88.39409637, 21.95573997], [88.3936615, 21.95582962], [88.39323425, 21.95589638], [88.39283752, 21.95605469], [88.39239502, 21.95610809], [88.39196014, 21.95615959], [88.3915863, 21.95633698], [88.39115906, 21.95639992], [88.39073944, 21.95650101], [88.39032745, 21.95664024], [88.38989258, 21.95672989], [88.38949585, 21.95689964], [88.38905334, 21.9570446], [88.38858032, 21.95717049], [88.38809204, 21.95732117], [88.38763428, 21.95750046], [88.38718414, 21.95767975], [88.38674164, 21.95783806], [88.38632202, 21.95804977], [88.38588715, 21.95823097], [88.38542938, 21.95841026], [88.38499451, 21.95861816], [88.384552, 21.95883179], [88.38411713, 21.95897484], [88.38397217, 21.95921135], [88.38388824, 21.95916748], [88.38361359, 21.95944405], [88.3833313, 21.95944405], [88.38305664, 21.95972252], [88.38276672, 21.95972061], [88.38249969, 21.95999908], [88.3822403, 21.95999908], [88.38195038, 21.96027946], [88.38166809, 21.96027946], [88.3813858, 21.96056175], [88.38111115, 21.96055603], [88.38083649, 21.9608326], [88.38054657, 21.9608326], [88.38027954, 21.96111107], [88.37997437, 21.96117401], [88.3796463, 21.96136093], [88.37922668, 21.96157837], [88.37874603, 21.96175575], [88.37831116, 21.96198082], [88.37786865, 21.96220779], [88.37744904, 21.9623909], [88.37702942, 21.96254921], [88.37666321, 21.96278], [88.37630463, 21.96301651], [88.37593079, 21.96325111], [88.3755722, 21.96352005], [88.37522125, 21.96380615], [88.37498474, 21.96398354], [88.37473297, 21.96417046], [88.37444305, 21.96445084], [88.37388611, 21.96527863], [88.37388611, 21.96665955], [88.37462616, 21.96740723], [88.375, 21.96778107], [88.37527466, 21.96777534], [88.3758316, 21.9683342], [88.37610626, 21.96833038], [88.37638855, 21.96861076], [88.37666321, 21.96861076], [88.37722015, 21.96889114], [88.37760925, 21.96906281], [88.37819672, 21.96916962], [88.37877655, 21.96927071], [88.37930298, 21.96936035], [88.37980652, 21.96941376], [88.38031006, 21.96948051], [88.38079834, 21.96957779], [88.38130188, 21.96962166], [88.38179779, 21.96964264], [88.3822937, 21.96965408], [88.38278961, 21.96965981], [88.38327789, 21.96966934], [88.38376617, 21.96966934], [88.38424683, 21.96968269], [88.38471985, 21.96969986], [88.3852005, 21.96975899], [88.38567352, 21.96985435], [88.3861618, 21.96989441], [88.38664246, 21.96987343], [88.38710022, 21.96980095], [88.38755035, 21.96976089], [88.38800812, 21.96975517], [88.38846588, 21.96977425], [88.38865662, 21.96979332], [88.3889389, 21.96982193], [88.38939667, 21.96989059], [88.38990784, 21.96988106], [88.39045715, 21.969841], [88.39109039, 21.96988106], [88.39175415, 21.97000885], [88.39243317, 21.9701519], [88.39306641, 21.97034073], [88.39367676, 21.97052956], [88.39431, 21.97066116], [88.39389038, 21.97138977], [88.39331055, 21.97170067], [88.39267731, 21.97166061], [88.39080048, 21.97145844], [88.39020538, 21.97140503], [88.3895874, 21.9713707], [88.38896179, 21.97130966], [88.38834381, 21.97121239], [88.38772583, 21.97121048], [88.38710785, 21.97129822], [88.38647461, 21.97133446], [88.38582611, 21.97131729], [88.38519287, 21.97126007], [88.38459778, 21.97120285], [88.3840332, 21.97126961], [88.38347626, 21.97128105], [88.38330078, 21.9712677], [88.3829422, 21.971241], [88.38243103, 21.97117805], [88.38195038, 21.97108078], [88.38150787, 21.97099876], [88.38105774, 21.97095108], [88.38059998, 21.97090912], [88.38011932, 21.97083092], [88.37944794, 21.97083282], [88.37722015, 21.97027969], [88.37638855, 21.97000122], [88.37581635, 21.96972084], [88.375, 21.96916771], [88.37444305, 21.96889114], [88.37277985, 21.96665955], [88.37277985, 21.96500015], [88.37304688, 21.96471977], [88.3730545, 21.96444321], [88.37333679, 21.96445084], [88.37332153, 21.96395111], [88.37360382, 21.96359062], [88.3739624, 21.96319962], [88.37444305, 21.96281815], [88.375, 21.96246338], [88.37556458, 21.9620533], [88.37612915, 21.96164131], [88.37667847, 21.96125031], [88.37722015, 21.9609375], [88.37773895, 21.96068954], [88.37819672, 21.96046829], [88.37860107, 21.96021271], [88.37895203, 21.95994949], [88.37934875, 21.95973206], [88.379776, 21.95954895], [88.38024139, 21.9593811], [88.38071442, 21.95917511], [88.38124847, 21.95896149], [88.38183594, 21.95877075], [88.38217163, 21.95863152], [88.38237, 21.9585495], [88.38279724, 21.95829964], [88.38315582, 21.95804024], [88.38345337, 21.95778084], [88.3837738, 21.95758247], [88.38414764, 21.95740128], [88.38453674, 21.95721054], [88.38491821, 21.9569397], [88.38530731, 21.95667076], [88.38574219, 21.95643044], [88.38619995, 21.95623016], [88.3866806, 21.95606613], [88.38712311, 21.95586014], [88.38757324, 21.95568085], [88.38803864, 21.95554161], [88.38851166, 21.95538712], [88.38900757, 21.95526123], [88.38948059, 21.95512581], [88.38990784, 21.9550209], [88.39027405, 21.95494461], [88.39052582, 21.9547863], [88.39083099, 21.95471954], [88.39120483, 21.95466995], [88.39161682, 21.95452118], [88.39205933, 21.95442581], [88.39247894, 21.95430946], [88.39290619, 21.95420265], [88.39335632, 21.9541111], [88.39379883, 21.95393181], [88.39430237, 21.95384216], [88.39476013, 21.95366859], [88.39523315, 21.95360947], [88.39555359, 21.95361137], [88.39611053, 21.95361137], [88.39638519, 21.9533329], [88.39666748, 21.9533329], [88.39694214, 21.95305443], [88.3972168, 21.95306015], [88.39805603, 21.95222092], [88.39805603, 21.95194435], [88.39833069, 21.95166588], [88.39833069, 21.95111084], [88.39749908, 21.95028114], [88.39749908, 21.95000076], [88.3972168, 21.94972038], [88.39722443, 21.94916725], [88.39694977, 21.94889069], [88.39694977, 21.94861984], [88.39666748, 21.94833183], [88.39666748, 21.94805527], [88.39554596, 21.94695282], [88.39560699, 21.94676018], [88.39549255, 21.94635582], [88.39527893, 21.94595337], [88.39503479, 21.94552612], [88.39480591, 21.94506073], [88.39464569, 21.94450951], [88.39441681, 21.94397163], [88.39418793, 21.94343948], [88.39398193, 21.94289589], [88.39383698, 21.94232941], [88.39362335, 21.94178009], [88.39346313, 21.94123077], [88.39331055, 21.94067955], [88.39321899, 21.94042206], [88.39312744, 21.94014549], [88.39299774, 21.93961906], [88.39283752, 21.93912125], [88.39277649, 21.93859291], [88.39277649, 21.93803978], [88.39277649, 21.93745995], [88.39284515, 21.93687057], [88.39303589, 21.93628502], [88.39322662, 21.93569183], [88.39347839, 21.93510056], [88.3936615, 21.9344635], [88.39402008, 21.93388939], [88.39437866, 21.93335342], [88.39459991, 21.93272781], [88.39479828, 21.93246078], [88.39497375, 21.93221855], [88.39530182, 21.93172836], [88.39570618, 21.93134117], [88.39610291, 21.93097115], [88.39647675, 21.93061066], [88.39691162, 21.93029022], [88.39729309, 21.92995262], [88.39769745, 21.92969322], [88.39809418, 21.92941284], [88.39850616, 21.92913055], [88.39891052, 21.92880058], [88.39933777, 21.92851448], [88.3996582, 21.92812538], [88.40011597, 21.92789078], [88.40047455, 21.92753029], [88.40090942, 21.92723083], [88.40141296, 21.92692947], [88.40189362, 21.9265728], [88.40234375, 21.92612648], [88.40283966, 21.92570114], [88.40335846, 21.92529106], [88.40387726, 21.92490005], [88.4043808, 21.92451096], [88.40471649, 21.92405128], [88.40497589, 21.92362976], [88.40518951, 21.92324066], [88.40534973, 21.92287064], [88.40554047, 21.92257118], [88.40572357, 21.92230415], [88.40584564, 21.92201042], [88.40597534, 21.92172241], [88.40597534, 21.92134094], [88.40601349, 21.92097092], [88.4061203, 21.92061043], [88.40624237, 21.92021179], [88.40636444, 21.91978455], [88.40635681, 21.91929817], [88.40625, 21.91883659], [88.40609741, 21.91839027], [88.40590668, 21.91797066], [88.40560913, 21.91763115], [88.40525055, 21.91728973], [88.40483856, 21.91694832], [88.40441132, 21.91660118], [88.40400696, 21.91618919], [88.40354919, 21.91580009], [88.40299988, 21.91549492], [88.40242004, 21.91521072], [88.40182495, 21.91498756], [88.40123749, 21.91477013], [88.4006958, 21.91469765], [88.40059662, 21.9146843], [88.40007019, 21.91445923], [88.39956665, 21.91423988], [88.39912415, 21.91402054], [88.39868164, 21.91366386], [88.39817047, 21.91344833], [88.39758301, 21.91333008], [88.3970108, 21.9132061], [88.39653015, 21.91299057], [88.3960495, 21.91289139], [88.39575958, 21.91254044], [88.39543915, 21.91225052], [88.39508057, 21.91201973], [88.39460754, 21.9118309], [88.39411926, 21.91164017], [88.39365387, 21.9113884], [88.39318085, 21.91110992], [88.39266205, 21.91083336], [88.3921051, 21.91055679], [88.39151001, 21.91028023], [88.39087677, 21.90999031], [88.39026642, 21.90966415], [88.38970947, 21.90925026], [88.38916779, 21.90880966], [88.38861847, 21.90838051], [88.38813019, 21.90809631], [88.38803101, 21.90803719], [88.38751984, 21.90767097], [88.38703918, 21.90742874], [88.38664246, 21.90715027], [88.38619232, 21.90691948], [88.38574982, 21.90665054], [88.3853302, 21.90627289], [88.38500214, 21.90579605], [88.38471985, 21.90530014], [88.3844223, 21.90484428], [88.3841095, 21.90442848], [88.38382721, 21.90398026], [88.3835144, 21.90356255], [88.38330841, 21.90303993], [88.38309479, 21.90249443], [88.38303375, 21.90188026], [88.3829422, 21.90143013], [88.38291168, 21.90127563], [88.38279724, 21.90068054], [88.38278198, 21.90007973], [88.38280487, 21.89948845], [88.38289642, 21.89891815], [88.38304138, 21.89838982], [88.38313293, 21.89792824], [88.38329315, 21.89755249], [88.38343048, 21.89718819], [88.38362122, 21.89683914], [88.38388062, 21.89648819], [88.3841629, 21.89610291], [88.38445282, 21.8956604], [88.38474274, 21.89520264], [88.38508606, 21.89476013], [88.38546753, 21.89434814], [88.38583374, 21.89392471], [88.3862915, 21.89359665], [88.38672638, 21.89324951], [88.38719177, 21.89285278], [88.38768768, 21.89246941], [88.38944244, 21.8908329], [88.39047241, 21.89002609], [88.3914032, 21.8895607], [88.39244843, 21.88941956], [88.39252472, 21.8893013], [88.3926239, 21.88915253], [88.39312744, 21.8890152], [88.39362335, 21.88875008], [88.39491272, 21.88781166], [88.39657593, 21.88638878], [88.39722443, 21.88583565], [88.39722443, 21.88555336], [88.39749908, 21.88528061], [88.3972168, 21.88389015], [88.39666748, 21.88278008], [88.39666748, 21.88249969], [88.39639282, 21.88221169], [88.39611053, 21.88138962], [88.39592743, 21.88019943], [88.39557648, 21.87971497], [88.39531708, 21.87916946], [88.39520264, 21.87853813], [88.39506531, 21.87791252], [88.39511871, 21.87723732], [88.39454651, 21.87650108], [88.39440155, 21.87535095], [88.39440155, 21.87434578], [88.39404297, 21.8730011], [88.39404297, 21.8703804], [88.39375305, 21.86870003], [88.39382935, 21.86727905], [88.39347076, 21.86358643], [88.39375305, 21.86305046], [88.39389038, 21.86277962], [88.39360809, 21.86250114], [88.39360809, 21.86166954], [88.39347076, 21.86025047], [88.39353943, 21.85951424], [88.39360809, 21.85823631], [88.39353943, 21.85568237], [88.39396667, 21.85413551], [88.39382935, 21.85231972], [88.3934021, 21.85144806], [88.39311981, 21.85117912], [88.39299011, 21.85078049], [88.39276123, 21.85039902], [88.39250183, 21.85004997], [88.39222717, 21.84972763], [88.39195251, 21.84941292], [88.39169312, 21.84906006], [88.39144135, 21.84866905], [88.39121246, 21.84826088], [88.39105988, 21.84784317], [88.39086151, 21.84755135], [88.39060211, 21.84736633], [88.39037323, 21.84716034], [88.39017487, 21.84691811], [88.38955688, 21.84613037], [88.38920593, 21.8454628], [88.38813019, 21.84445], [88.38704681, 21.84283257], [88.38577271, 21.83940315], [88.38562775, 21.83503342], [88.38634491, 21.82938576], [88.38749695, 21.82694435], [88.38748932, 21.82659912], [88.38777924, 21.82500076], [88.38804626, 21.82471848], [88.38805389, 21.82444382], [88.38833618, 21.82416725], [88.38833618, 21.82389069], [88.38861084, 21.82361031], [88.38861084, 21.82332993], [88.3888855, 21.82305527], [88.38889313, 21.82278061], [88.38916779, 21.82250023], [88.38916779, 21.82222748], [88.38944244, 21.82195091], [88.38944244, 21.82167053], [88.3897171, 21.82139015], [88.3897171, 21.82110977], [88.38999939, 21.82083321], [88.38999939, 21.82055664], [88.38999176, 21.82027626], [88.3897171, 21.81972122], [88.38972473, 21.81944656], [88.3904953, 21.81926155], [88.39038086, 21.81869125], [88.39051819, 21.81825066], [88.39076233, 21.81785011], [88.3910675, 21.81747055], [88.39126587, 21.81701088], [88.39118958, 21.81648636], [88.39129639, 21.81598091], [88.3914032, 21.81542969], [88.39160156, 21.81496811], [88.39169312, 21.81454086], [88.39192963, 21.81417274], [88.39216614, 21.81374168], [88.39225006, 21.81318092], [88.39205933, 21.81278992], [88.39186859, 21.81240463], [88.39185333, 21.8116684], [88.39221954, 21.81098175], [88.39231873, 21.81047821], [88.39257813, 21.81001091], [88.39256287, 21.80933762], [88.39250946, 21.80863953], [88.39250183, 21.80800629], [88.39250183, 21.8074398], [88.39250183, 21.80694962], [88.39248657, 21.80653954], [88.39241791, 21.80620384], [88.39226532, 21.80591011], [88.39226532, 21.80554581], [88.3924408, 21.80507088], [88.3924942, 21.804533], [88.3924942, 21.80394173], [88.39241028, 21.80333328], [88.39209747, 21.8028698], [88.39193726, 21.80278015], [88.39182281, 21.80235291], [88.3915329, 21.80126953], [88.39083099, 21.80005836], [88.39067078, 21.79898071], [88.38980103, 21.79797363], [88.38948822, 21.79774666], [88.38920593, 21.79751968], [88.38890839, 21.79734993], [88.3886261, 21.79713058], [88.3883667, 21.79685974], [88.38819122, 21.79652023], [88.38800049, 21.79617119], [88.38775635, 21.7958107], [88.38749695, 21.79541969], [88.38723755, 21.79502487], [88.38690948, 21.79467964], [88.3864975, 21.79446983], [88.3860321, 21.79432869], [88.38564301, 21.79409027], [88.38530731, 21.79372978], [88.38500977, 21.79334068], [88.38465881, 21.79299164], [88.38431549, 21.79267311], [88.38394165, 21.79244614], [88.38362885, 21.79227066], [88.38318634, 21.79207039], [88.38270569, 21.79196548], [88.38224792, 21.79190063], [88.38197327, 21.79169846], [88.38163757, 21.79158783], [88.38109589, 21.79216003], [88.38043213, 21.79231071], [88.37967682, 21.79220009], [88.37928009, 21.79249573], [88.37892151, 21.7928524], [88.37857819, 21.79319954], [88.37819672, 21.79346657], [88.37782288, 21.79371262], [88.37745667, 21.79400063], [88.3769989, 21.79421043], [88.37652588, 21.79445076], [88.37602234, 21.7947216], [88.37547302, 21.79499054], [88.37489319, 21.79528046], [88.37429047, 21.79554939], [88.37365723, 21.79576111], [88.3730011, 21.79586029], [88.37239838, 21.79603958], [88.37174225, 21.79610825], [88.37108612, 21.79616928], [88.37045288, 21.79635048], [88.36976624, 21.79639053], [88.3690567, 21.79642105], [88.36837006, 21.79653931], [88.36767578, 21.79668236], [88.36697388, 21.79685974], [88.36629486, 21.79698181], [88.36567688, 21.79717255], [88.36509705, 21.7972908], [88.36464691, 21.79749107], [88.3642807, 21.79767036], [88.36400604, 21.79783058], [88.36386871, 21.79805946], [88.3637085, 21.79825592], [88.36361694, 21.79857063], [88.3635788, 21.79896927], [88.36351776, 21.79940033], [88.36351013, 21.79988098], [88.36345673, 21.80039024], [88.36368561, 21.80075073], [88.36354828, 21.80132294], [88.36374664, 21.80170059], [88.36386871, 21.80205727], [88.36387634, 21.80238152], [88.36380005, 21.80265999], [88.36369324, 21.80296516], [88.36373138, 21.8032608], [88.3634491, 21.80365562], [88.36380768, 21.8039608], [88.36347961, 21.80476952], [88.36342621, 21.80540276], [88.36331177, 21.80602074], [88.36340332, 21.80659103], [88.36357117, 21.80713081], [88.36361694, 21.80764961], [88.36361694, 21.80814934], [88.36355591, 21.8086319], [88.3632431, 21.80903625], [88.36292267, 21.80955887], [88.36257172, 21.81018066], [88.36225128, 21.81085777], [88.36201477, 21.81153107], [88.36167908, 21.81198311], [88.36136627, 21.81241035], [88.36100769, 21.81277084], [88.36061096, 21.81306267], [88.36040497, 21.81334114], [88.36026001, 21.81377029], [88.36001587, 21.81407166], [88.35997772, 21.81423187], [88.35943604, 21.8145504], [88.35930634, 21.81483841], [88.35914612, 21.81511116], [88.35897064, 21.81537056], [88.35884094, 21.81567955], [88.35862732, 21.81596947], [88.35842133, 21.8162899], [88.35817719, 21.81666946], [88.35790253, 21.81706619], [88.35756683, 21.81742287], [88.35723877, 21.81776047], [88.35697937, 21.81808853], [88.35677338, 21.81838036], [88.35663605, 21.81868744], [88.35645294, 21.81892967], [88.35626221, 21.81918907], [88.35610962, 21.81947327], [88.3559494, 21.8197403], [88.35582733, 21.82005119], [88.35573578, 21.82036018], [88.35558319, 21.82072067], [88.35549164, 21.82115364], [88.35531616, 21.82162094], [88.35514069, 21.82212639], [88.35488129, 21.82279968], [88.35473633, 21.82347107], [88.35459137, 21.82509041], [88.35459137, 21.82683945], [88.35444641, 21.82817841], [88.35416412, 21.82925415], [88.35453033, 21.83011055], [88.35473633, 21.83060074], [88.35501862, 21.83262062], [88.35534668, 21.8350296], [88.35552979, 21.83554077], [88.35565948, 21.83607292], [88.35579681, 21.83661079], [88.35582733, 21.83719063], [88.35582733, 21.83781052], [88.35583496, 21.83842659], [88.35585785, 21.83905029], [88.35597992, 21.83966637], [88.35604858, 21.84030151], [88.35609436, 21.84099388], [88.35609436, 21.84151077], [88.35609436, 21.84172058], [88.35598755, 21.84242439], [88.35571289, 21.84303093], [88.35573578, 21.84361076], [88.35581207, 21.84412956], [88.355896, 21.8447094], [88.35561371, 21.84511757], [88.35562134, 21.84547043], [88.35557556, 21.84579659], [88.35562134, 21.84621239], [88.35578156, 21.84667969], [88.35582733, 21.84723663], [88.35577393, 21.84782219], [88.35559845, 21.84841347], [88.3555603, 21.84899139], [88.35555267, 21.84954453], [88.35555267, 21.85007477], [88.35556793, 21.8506031], [88.35562134, 21.85115242], [88.35569, 21.85174179], [88.35566711, 21.85236549], [88.3556366, 21.85294151], [88.35546875, 21.8534317], [88.35528564, 21.85386467], [88.35514069, 21.85429955], [88.35500336, 21.85474014], [88.35494232, 21.85518837], [88.35492706, 21.85565567], [88.35531616, 21.85612106], [88.35573578, 21.85663986], [88.35607147, 21.85717964], [88.35639954, 21.85762024], [88.35669708, 21.85804939], [88.35706329, 21.85838127], [88.35736847, 21.85869026], [88.35761261, 21.85900116], [88.35780334, 21.85932732], [88.35803986, 21.85963058], [88.35820007, 21.85995865], [88.35836029, 21.86027527], [88.35857391, 21.86051941], [88.35877228, 21.86077118], [88.35894775, 21.86104012], [88.35914612, 21.86125946], [88.35934448, 21.86149025], [88.35951996, 21.86174202], [88.35971832, 21.86204338], [88.35993195, 21.86242294], [88.36022949, 21.86284065], [88.36052704, 21.86338043], [88.36086273, 21.86399078], [88.36123657, 21.86456108], [88.36161804, 21.86498642], [88.36181641, 21.86540222], [88.36199951, 21.86570358], [88.36218262, 21.86592484], [88.36228943, 21.86619377], [88.36250305, 21.86642075], [88.36270905, 21.86671066], [88.36286926, 21.86704826], [88.36313629, 21.86732101], [88.36334229, 21.86761093], [88.36348724, 21.86790085], [88.36369324, 21.86815834], [88.36389923, 21.86844826], [88.36410522, 21.86880875], [88.36428833, 21.86925125], [88.36445618, 21.86977959], [88.36471558, 21.87028313], [88.36489105, 21.87072754], [88.36504364, 21.87124634], [88.3651886, 21.87158012], [88.36527252, 21.87190056], [88.36534882, 21.87219238], [88.36547852, 21.8724308], [88.36567688, 21.87268257], [88.36582947, 21.87298012], [88.36593628, 21.87337112], [88.36605072, 21.8738308], [88.36616516, 21.87434959], [88.36633301, 21.87483978], [88.3664093, 21.87532043], [88.366539, 21.87569046], [88.36666107, 21.87601089], [88.36675262, 21.87631989], [88.36691284, 21.87664032], [88.36694336, 21.87706947], [88.36699677, 21.8775692], [88.36714935, 21.87808037], [88.36725616, 21.87862015], [88.3674469, 21.87915039], [88.36752319, 21.87973022], [88.36765289, 21.88029289], [88.36775208, 21.88086891], [88.36779785, 21.88148117], [88.36789703, 21.88212967], [88.36807251, 21.88274956], [88.36828613, 21.88335037], [88.36833191, 21.88397026], [88.36834717, 21.88453102], [88.36846161, 21.88500977], [88.3685379, 21.88546944], [88.36859131, 21.88594818], [88.3686142, 21.88647461], [88.36862946, 21.8868103], [88.36864471, 21.88704872], [88.36876678, 21.88763428], [88.36891174, 21.88824081], [88.36909485, 21.88884926], [88.36915588, 21.88949013], [88.36917877, 21.89011002], [88.36924744, 21.89067078], [88.36943054, 21.89112091], [88.36956024, 21.89157104], [88.36972046, 21.89203072], [88.36984253, 21.89248085], [88.36995697, 21.89293289], [88.37001038, 21.89342117], [88.37008667, 21.89396286], [88.37025452, 21.89451981], [88.37039185, 21.8950901], [88.37052155, 21.89562035], [88.37055206, 21.89609146], [88.37055969, 21.89653015], [88.37055969, 21.89694595], [88.37055969, 21.89736176], [88.37054443, 21.89779854], [88.37051392, 21.89827156], [88.3704071, 21.8988018], [88.37033081, 21.89938927], [88.37024689, 21.89999008], [88.37013245, 21.90056229], [88.36997223, 21.90108109], [88.36977386, 21.90157127], [88.36960602, 21.902071], [88.36947632, 21.90257835], [88.36937714, 21.90306664], [88.36920929, 21.90349007], [88.3690567, 21.90393066], [88.36891937, 21.90437126], [88.3687973, 21.90478134], [88.3686676, 21.90512085], [88.36857605, 21.90544128], [88.36846161, 21.90570259], [88.36831665, 21.90594101], [88.36815643, 21.90619659], [88.36798096, 21.90646362], [88.36781311, 21.90673065], [88.36767578, 21.90705109], [88.36749268, 21.90739059], [88.36724854, 21.90780067], [88.36701202, 21.90833282], [88.36679077, 21.90895271], [88.36649323, 21.90949631], [88.36618805, 21.91001129], [88.36592102, 21.91049004], [88.36571503, 21.91095734], [88.36555481, 21.91139221], [88.36540222, 21.91179276], [88.36522675, 21.91213989], [88.36501312, 21.91245842], [88.36477661, 21.91279984], [88.36451721, 21.9131794], [88.36426544, 21.91361427], [88.36399078, 21.91407013], [88.36374664, 21.91455269], [88.36351776, 21.91503525], [88.36326599, 21.91550064], [88.36297607, 21.91597748], [88.36264801, 21.91645813], [88.3622818, 21.91697121], [88.36193848, 21.91755867], [88.36160278, 21.91817093], [88.3612442, 21.91871834], [88.36090088, 21.91918945], [88.36061096, 21.91964912], [88.36032104, 21.92008018], [88.36003876, 21.92045975], [88.3597641, 21.92084312], [88.35951233, 21.92122841], [88.35928345, 21.92162514], [88.35900116, 21.9219799], [88.35868073, 21.92233849], [88.35832214, 21.92270279], [88.35791016, 21.92307091], [88.35745239, 21.92346954], [88.35695648, 21.92389107], [88.35645294, 21.92431068], [88.35592651, 21.92465973], [88.35544586, 21.92497063], [88.35502625, 21.9252491], [88.35466003, 21.92550087], [88.35430908, 21.92571831], [88.35391998, 21.92592812], [88.35344696, 21.92613983], [88.35295868, 21.9263382], [88.35249329, 21.92654037], [88.35202026, 21.92673874], [88.35176086, 21.92685127], [88.35069275, 21.92738914], [88.35032654, 21.92746162], [88.34998322, 21.92738914], [88.34997559, 21.92718887], [88.35032654, 21.9267025], [88.35074615, 21.92638969], [88.35116577, 21.92611122], [88.35160065, 21.92585754], [88.35205841, 21.92563248], [88.35250854, 21.92538071], [88.35295868, 21.92514038], [88.35346222, 21.92490768], [88.35394287, 21.92465973], [88.35443115, 21.92440033], [88.35489655, 21.92413139], [88.3553772, 21.92383957], [88.35582733, 21.9235096], [88.35623169, 21.92313957], [88.35663605, 21.92274094], [88.35706329, 21.92233276], [88.35749054, 21.92193031], [88.35790253, 21.9215107], [88.35827637, 21.92105293], [88.35861206, 21.92053986], [88.3589325, 21.91999054], [88.35927582, 21.91942978], [88.35965729, 21.91893387], [88.36001587, 21.91845131], [88.36035156, 21.91798592], [88.360672, 21.91752052], [88.3609848, 21.91705513], [88.36128998, 21.91657066], [88.36157227, 21.91610527], [88.36183929, 21.91566277], [88.36211395, 21.91525459], [88.36236572, 21.91484833], [88.36258698, 21.91440964], [88.36280823, 21.91399956], [88.36302948, 21.91360855], [88.36322784, 21.91320992], [88.36342621, 21.91283989], [88.36364746, 21.91248131], [88.3638916, 21.91212082], [88.36414337, 21.91172981], [88.36437225, 21.91130257], [88.36457062, 21.91084099], [88.36477661, 21.91039085], [88.36500549, 21.91000175], [88.36521912, 21.90962982], [88.36538696, 21.90922165], [88.3655777, 21.90880775], [88.36579132, 21.90837097], [88.36598206, 21.90790749], [88.36618805, 21.90744972], [88.3664093, 21.90703011], [88.36663055, 21.90662956], [88.36679077, 21.90624046], [88.36695862, 21.90592194], [88.36712646, 21.90563011], [88.36727142, 21.90530968], [88.3674469, 21.90497971], [88.36754608, 21.90460014], [88.36769867, 21.90423965], [88.36781311, 21.90388107], [88.3679657, 21.90356827], [88.36808777, 21.90322113], [88.3682251, 21.90286255], [88.36831665, 21.90246964], [88.36837769, 21.90205956], [88.36847687, 21.9017067], [88.36857605, 21.901371], [88.36863708, 21.90096092], [88.36876678, 21.90048027], [88.36885834, 21.8998909], [88.36891937, 21.89921188], [88.3690033, 21.89852142], [88.36911774, 21.89788055], [88.36915588, 21.89725113], [88.36915588, 21.89661026], [88.36911011, 21.89596176], [88.36897278, 21.89530945], [88.36889648, 21.89466286], [88.36885834, 21.89406967], [88.36873627, 21.89359093], [88.36862946, 21.89315033], [88.36852264, 21.89272118], [88.36836243, 21.89233017], [88.36824799, 21.89190292], [88.36808777, 21.89151573], [88.36798859, 21.89106941], [88.367836, 21.89060974], [88.36776733, 21.89007759], [88.36767578, 21.889534], [88.36753845, 21.88898087], [88.3674469, 21.88840103], [88.36733246, 21.8878479], [88.36720276, 21.88730049], [88.36704254, 21.88680267], [88.36696625, 21.88626289], [88.36694336, 21.88570023], [88.36691284, 21.88512039], [88.36675262, 21.88457489], [88.36668396, 21.88400269], [88.36666107, 21.88344383], [88.36660767, 21.88292122], [88.36646271, 21.88245964], [88.36638641, 21.88195038], [88.36637115, 21.88146019], [88.36625671, 21.88097954], [88.36613464, 21.8805542], [88.36603546, 21.88015366], [88.36590576, 21.87978745], [88.36579132, 21.87945938], [88.36567688, 21.87914085], [88.36561584, 21.87881088], [88.3655777, 21.87841988], [88.36554718, 21.8780098], [88.36547852, 21.87759018], [88.36535645, 21.87721062], [88.36523438, 21.87685966], [88.36508942, 21.87650108], [88.36501312, 21.876091], [88.36495209, 21.87574005], [88.36480713, 21.87547112], [88.36472321, 21.87515068], [88.36463928, 21.87478065], [88.36446381, 21.87444687], [88.36429596, 21.87403107], [88.36414337, 21.87355042], [88.36390686, 21.8730793], [88.3637619, 21.87252808], [88.3636322, 21.87195015], [88.36353302, 21.87136078], [88.36330414, 21.87087822], [88.36303711, 21.87044907], [88.36281586, 21.87002945], [88.36264038, 21.86960983], [88.36244202, 21.86925125], [88.36221313, 21.8689003], [88.36199951, 21.86856079], [88.36180878, 21.86814117], [88.36151886, 21.86780739], [88.36116791, 21.86748123], [88.3609314, 21.86705208], [88.36060333, 21.86670303], [88.36029816, 21.86633873], [88.36006165, 21.8658905], [88.35983276, 21.86541939], [88.35949707, 21.86504745], [88.35917664, 21.86471748], [88.35888672, 21.86442947], [88.35861206, 21.864151], [88.35834503, 21.86389923], [88.35808563, 21.86362076], [88.35792542, 21.86322784], [88.35771942, 21.86284065], [88.3575058, 21.86248589], [88.35726929, 21.86214638], [88.35706329, 21.86181068], [88.35673523, 21.86159325], [88.35643768, 21.8613224], [88.35611725, 21.86099052], [88.35573578, 21.86066055], [88.35529327, 21.86032677], [88.3549118, 21.8599205], [88.3546524, 21.85942459], [88.3543396, 21.85900116], [88.35424805, 21.85845947], [88.35411835, 21.8579483], [88.35388184, 21.85750961], [88.35357666, 21.85715485], [88.35317993, 21.85692406], [88.35274506, 21.85674858], [88.35225677, 21.85687065], [88.35176086, 21.8569603], [88.35124969, 21.85708046], [88.3507309, 21.85716057], [88.3502121, 21.85699081], [88.34967041, 21.85695076], [88.34913635, 21.85694122], [88.34858704, 21.85694122], [88.34807587, 21.85695076], [88.34755707, 21.85695076], [88.34706116, 21.85695076], [88.34657288, 21.85695076], [88.34622192, 21.85694313], [88.34609985, 21.85694313], [88.34564972, 21.85694313], [88.34523773, 21.8569603], [88.34487915, 21.85707283], [88.3445282, 21.8572197], [88.34414673, 21.85737038], [88.34372711, 21.85752106], [88.34335327, 21.85775948], [88.34300232, 21.85804939], [88.34265137, 21.85832024], [88.34229279, 21.85859108], [88.34191132, 21.85886955], [88.34152222, 21.85916328], [88.34121704, 21.85943222], [88.34115601, 21.85949135], [88.34081268, 21.85984993], [88.34046173, 21.8602066], [88.34007263, 21.86050987], [88.33963013, 21.86078072], [88.33913422, 21.86098671], [88.33859253, 21.86112976], [88.3380661, 21.86131096], [88.33753967, 21.8614254], [88.3370285, 21.86161041], [88.33647919, 21.86166954], [88.33592224, 21.86172104], [88.3353653, 21.86187935], [88.3347168, 21.86198235], [88.33405304, 21.86211395], [88.33338928, 21.8619957], [88.3327179, 21.86197281], [88.3320694, 21.86203957], [88.33146667, 21.86214638], [88.33087921, 21.86218452], [88.33027649, 21.86218262], [88.32964325, 21.86216927], [88.32897186, 21.86215973], [88.32828522, 21.86216164], [88.32759857, 21.86215973], [88.32692719, 21.86215973], [88.32628632, 21.86215973], [88.32565308, 21.86215019], [88.32499695, 21.86207962], [88.32446289, 21.86190987], [88.32393646, 21.86174965], [88.3234024, 21.86164093], [88.32283783, 21.86156273], [88.32229614, 21.8614502], [88.32177734, 21.86135292], [88.32126617, 21.86123085], [88.32077789, 21.86107254], [88.32032013, 21.86090851], [88.31991577, 21.8607502], [88.31952667, 21.86059189], [88.3191452, 21.86048508], [88.3187561, 21.86034012], [88.31833649, 21.86024094], [88.31791687, 21.86012077], [88.31754303, 21.85997009], [88.31713867, 21.85980988], [88.31671906, 21.85969162], [88.31627655, 21.85954094], [88.31586456, 21.85932732], [88.31545258, 21.85910034], [88.31504059, 21.85885429], [88.31460571, 21.85858154], [88.31414032, 21.85829544], [88.31369019, 21.85798073], [88.31325531, 21.85765839], [88.31285858, 21.85726929], [88.31247711, 21.85680962], [88.31208038, 21.8563385], [88.31165314, 21.85584068], [88.31118774, 21.85544014], [88.31080627, 21.85553932], [88.31046295, 21.85572815], [88.31021118, 21.85596275], [88.30988312, 21.85610008], [88.30941772, 21.85621071], [88.30893707, 21.85639954], [88.30856323, 21.8568058], [88.3081131, 21.85716057], [88.30764008, 21.85749054], [88.30718231, 21.85778046], [88.30673981, 21.85805511], [88.30632019, 21.85833359], [88.3059082, 21.85860062], [88.30547333, 21.85884094], [88.30499268, 21.85902405], [88.30447388, 21.85922241], [88.30422974, 21.85935593], [88.30395508, 21.8595047], [88.30344391, 21.85987282], [88.30290985, 21.86021042], [88.30239868, 21.8605442], [88.30195618, 21.86082077], [88.30158997, 21.86103058], [88.30130005, 21.8611393], [88.30130005, 21.86136055], [88.30171204, 21.86206818], [88.30219269, 21.86268997], [88.30262756, 21.86314964], [88.30303192, 21.86348915], [88.30341339, 21.86381912], [88.30377197, 21.864151], [88.30413818, 21.86448669], [88.30449677, 21.86483192], [88.30486298, 21.86515999], [88.30519867, 21.8654995], [88.30555725, 21.86583138], [88.30590057, 21.86615944], [88.30623627, 21.86647987], [88.3065567, 21.86684608], [88.30680084, 21.86726952], [88.30699158, 21.86778831], [88.30718994, 21.86831474], [88.30737305, 21.86885071], [88.30753326, 21.86940956], [88.30770111, 21.86991882], [88.3078537, 21.87041473], [88.30800629, 21.87088013], [88.30812836, 21.87138367], [88.30825043, 21.87191963], [88.3083725, 21.87249947], [88.30853271, 21.87306023], [88.30867767, 21.87359047], [88.30883789, 21.8740406], [88.30901337, 21.87441826], [88.30915833, 21.8747406], [88.30928802, 21.87504959], [88.30942535, 21.87532806], [88.30956268, 21.87561035], [88.30973053, 21.87589073], [88.3098526, 21.87618065], [88.30999756, 21.87648773], [88.31009674, 21.87684059], [88.31011963, 21.87726974], [88.31001282, 21.87734795], [88.30979919, 21.87768364], [88.30944061, 21.87768364], [88.30918884, 21.87738991], [88.3088913, 21.87687302], [88.30882263, 21.87641716], [88.30864716, 21.87598038], [88.3084259, 21.87555122], [88.30815887, 21.87512016], [88.30789185, 21.87465096], [88.30767059, 21.87409019], [88.30745697, 21.87347031], [88.30725861, 21.87283325], [88.30706787, 21.87217522], [88.30690765, 21.87150192], [88.30680084, 21.87079811], [88.30673218, 21.87014961], [88.306633, 21.86961555], [88.30651093, 21.86917114], [88.30638123, 21.86881256], [88.30622101, 21.86847115], [88.30612946, 21.86829758], [88.30606079, 21.86816216], [88.30592346, 21.86784744], [88.30574799, 21.8675499], [88.30554962, 21.86722946], [88.30528259, 21.86692047], [88.30495453, 21.8666153], [88.30457306, 21.86630821], [88.30414581, 21.86600876], [88.30374146, 21.86567116], [88.30338287, 21.86530113], [88.30298615, 21.8649292], [88.30256653, 21.8645401], [88.3021698, 21.864151], [88.3017807, 21.86378288], [88.30145264, 21.8633709], [88.30117798, 21.86284828], [88.30109406, 21.86242676], [88.3010025, 21.86200142], [88.30059052, 21.86132622], [88.3003006, 21.8612709], [88.29982758, 21.86130905], [88.29928589, 21.86137009], [88.29872894, 21.8614006], [88.29812622, 21.8614006], [88.29751587, 21.86137962], [88.29686737, 21.86131096], [88.29615021, 21.86119843], [88.29544067, 21.86112976], [88.29477692, 21.86107254], [88.29420471, 21.86096573], [88.29367828, 21.86086845], [88.29315948, 21.86079025], [88.29265594, 21.8606987], [88.29213715, 21.86059189], [88.29161072, 21.8604908], [88.29106903, 21.86032677], [88.29051208, 21.86021805], [88.2899704, 21.86005592], [88.28942871, 21.85988045], [88.28884125, 21.85972786], [88.28820801, 21.85955238], [88.28759766, 21.8592701], [88.28694916, 21.85911179], [88.28629303, 21.85888863], [88.28559113, 21.85865021], [88.28486633, 21.85840988], [88.28409576, 21.85823822], [88.2833786, 21.85804939], [88.28269958, 21.85788727], [88.2820816, 21.85775948], [88.28156281, 21.85762978], [88.28109741, 21.85753822], [88.28066254, 21.85750771], [88.28024292, 21.85749054], [88.27983856, 21.85745621], [88.27945709, 21.85736084], [88.27908325, 21.85725975], [88.27867126, 21.85723114], [88.27820587, 21.8572197], [88.27765656, 21.8572197], [88.27703857, 21.8572197], [88.27632904, 21.8572197], [88.27558136, 21.85722733], [88.27481842, 21.85726357], [88.27407837, 21.85730171], [88.27341461, 21.85728836], [88.27281952, 21.85728073], [88.27224731, 21.85740089], [88.2718277, 21.8573513], [88.27162933, 21.85732841], [88.27106476, 21.85744858], [88.27048492, 21.85754395], [88.26990509, 21.85761452], [88.26935577, 21.85759735], [88.26883698, 21.85757065], [88.26835632, 21.85758018], [88.26782227, 21.85769272], [88.26729584, 21.85775948], [88.26677704, 21.85778999], [88.26628113, 21.85783958], [88.26580811, 21.8579483], [88.26532745, 21.85804939], [88.2648468, 21.85814476], [88.26438904, 21.85828018], [88.26390076, 21.85839081], [88.2634201, 21.85853767], [88.26293182, 21.85859489], [88.26244354, 21.85862541], [88.26197815, 21.85869026], [88.26154327, 21.85886192], [88.26111603, 21.85902977], [88.26068878, 21.85921288], [88.26026154, 21.85942268], [88.25979614, 21.85964012], [88.25933075, 21.85993004], [88.25892639, 21.86033058], [88.25858307, 21.86078072], [88.25823212, 21.86116982], [88.25795746, 21.86156273], [88.25776672, 21.86198997], [88.25760651, 21.86237907], [88.25747681, 21.86273193], [88.25733948, 21.86305618], [88.25726318, 21.86342049], [88.25721741, 21.86380959], [88.25712585, 21.86421967], [88.25701904, 21.86464119], [88.25694275, 21.86514091], [88.25685883, 21.86567116], [88.25673676, 21.86616707], [88.25665283, 21.86664963], [88.25653076, 21.86706924], [88.25643158, 21.86744308], [88.25637817, 21.86782074], [88.25630951, 21.86822128], [88.25615692, 21.8686409], [88.256073, 21.86914063], [88.25596619, 21.86970139], [88.25600433, 21.87030792], [88.25604248, 21.87043953], [88.25615692, 21.87088966], [88.25639343, 21.87143517], [88.25668335, 21.87194061], [88.25697327, 21.8724308], [88.25728607, 21.87293053], [88.25760651, 21.87338638], [88.25799561, 21.87380981], [88.25839996, 21.87420273], [88.25879669, 21.8746109], [88.25921631, 21.87498093], [88.25964355, 21.87532425], [88.26002502, 21.87572289], [88.26037598, 21.87615967], [88.26077271, 21.87659073], [88.26117706, 21.8769989], [88.26159668, 21.87739944], [88.26200104, 21.87778091], [88.26235199, 21.87817764], [88.26268005, 21.87861443], [88.26299286, 21.8791008], [88.26332855, 21.8795948], [88.26377869, 21.88000488], [88.26425171, 21.88042259], [88.2647171, 21.8808403], [88.26517487, 21.88127327], [88.26563263, 21.88170242], [88.26609802, 21.88208389], [88.2665329, 21.88243294], [88.26693726, 21.88273811], [88.26734924, 21.88299561], [88.26774597, 21.88322067], [88.26821136, 21.88339043], [88.26863098, 21.88360023], [88.26902008, 21.88383675], [88.26940155, 21.88409233], [88.26979065, 21.88435173], [88.27009583, 21.88499069], [88.2698822, 21.88512039], [88.26973724, 21.88519287], [88.26959991, 21.88519287], [88.26924896, 21.88486099], [88.26866913, 21.88459015], [88.26832581, 21.88436127], [88.26777649, 21.88418961], [88.26729584, 21.88397026], [88.26683044, 21.88373184], [88.26667023, 21.88360977], [88.26638794, 21.88361168], [88.26611328, 21.88333321], [88.26576233, 21.88293076], [88.26442719, 21.88194275], [88.26416779, 21.88194466], [88.2638855, 21.88166618], [88.2636795, 21.88159943], [88.26286316, 21.88061905], [88.26278687, 21.88021278], [88.26243591, 21.8799324], [88.26222229, 21.8797226], [88.26194763, 21.87944412], [88.26194763, 21.87916756], [88.26139069, 21.87861061], [88.26094818, 21.87825966], [88.26038361, 21.87779427], [88.25984192, 21.877285], [88.25933075, 21.87675095], [88.25884247, 21.87619781], [88.25830841, 21.87569809], [88.25779724, 21.87519073], [88.25734711, 21.87471008], [88.25700378, 21.87423515], [88.25666046, 21.87375069], [88.2563324, 21.87330246], [88.25602722, 21.87293816], [88.25576019, 21.87261009], [88.25549316, 21.8722496], [88.25527954, 21.87194061], [88.25489807, 21.8713398], [88.25469208, 21.87060165], [88.25475311, 21.8698597], [88.25481415, 21.86893082], [88.25483704, 21.86853027], [88.25495148, 21.86822319], [88.25502014, 21.86785126], [88.25507355, 21.86743927], [88.25518036, 21.8670311], [88.25524902, 21.86660194], [88.25527954, 21.86614037], [88.25528717, 21.86566925], [88.25530243, 21.86516953], [88.25535583, 21.86468315], [88.25548553, 21.86420631], [88.25559235, 21.86375237], [88.25571442, 21.86335182], [88.25584412, 21.8629837], [88.25598145, 21.86263275], [88.25611877, 21.86228561], [88.2562561, 21.86194038], [88.25641632, 21.86157036], [88.2565918, 21.86120224], [88.25682068, 21.86082649], [88.25708771, 21.86045265], [88.25740051, 21.8601017], [88.25772858, 21.85975075], [88.25811005, 21.85944366], [88.25850677, 21.85913277], [88.2589035, 21.85880661], [88.25932312, 21.85849953], [88.25977325, 21.85827065], [88.2602005, 21.85806084], [88.26059723, 21.85786057], [88.26106262, 21.85771942], [88.26154327, 21.85758018], [88.26209259, 21.85747147], [88.26268768, 21.85733223], [88.26335144, 21.85717201], [88.26400757, 21.85694122], [88.26467896, 21.85671616], [88.26537323, 21.85655975], [88.2660675, 21.85642815], [88.26674652, 21.85639572], [88.26741028, 21.85639954], [88.26805878, 21.85645294], [88.26869965, 21.8565197], [88.26918793, 21.85639954], [88.26965332, 21.85625076], [88.27005768, 21.85613632], [88.27046967, 21.85606003], [88.27085876, 21.85596275], [88.27121735, 21.85591507], [88.27155304, 21.85596275], [88.27188873, 21.85605049], [88.27227783, 21.8560009], [88.27275085, 21.85587502], [88.27327728, 21.85584068], [88.27381897, 21.85583115], [88.27436066, 21.85583115], [88.27490234, 21.85583115], [88.27545166, 21.85583115], [88.27558899, 21.85583305], [88.27601624, 21.85584068], [88.27644348, 21.85583115], [88.27658081, 21.85583115], [88.27713776, 21.85581017], [88.27765656, 21.85570335], [88.27816772, 21.8556118], [88.27867126, 21.85557365], [88.27915192, 21.8556118], [88.27955627, 21.85569572], [88.27993011, 21.85581017], [88.28029633, 21.85589027], [88.28064728, 21.85603523], [88.28107452, 21.85610008], [88.28156281, 21.8561306], [88.28203583, 21.85619926], [88.2824707, 21.85634995], [88.2829361, 21.85641098], [88.28340149, 21.85649109], [88.28385925, 21.85662079], [88.28430939, 21.8567791], [88.28475189, 21.85689545], [88.28521729, 21.85693169], [88.28568268, 21.85699081], [88.28608704, 21.85711098], [88.28650665, 21.85726929], [88.28690338, 21.85747147], [88.28734589, 21.85757065], [88.28775024, 21.85775757], [88.28816223, 21.85791969], [88.28865051, 21.85803604], [88.28917694, 21.85811043], [88.28965759, 21.85828972], [88.29014587, 21.85832977], [88.29061127, 21.85840034], [88.29105377, 21.85851479], [88.29147339, 21.85868454], [88.29190063, 21.85883141], [88.2923584, 21.858881], [88.29282379, 21.85895348], [88.29329681, 21.85901451], [88.29377747, 21.85909653], [88.29427338, 21.85920143], [88.29482269, 21.8592205], [88.29543304, 21.85929108], [88.29606628, 21.85944939], [88.29673767, 21.85965157], [88.29740906, 21.85962868], [88.29805756, 21.85948181], [88.29869843, 21.85943985], [88.29931641, 21.85938072], [88.29988861, 21.85920143], [88.30046082, 21.85909081], [88.30097198, 21.858881], [88.30148315, 21.85861015], [88.30203247, 21.85831261], [88.30257416, 21.85796547], [88.30303192, 21.85752106], [88.30334473, 21.85703468], [88.30366516, 21.8566494], [88.30391693, 21.85647774], [88.30403137, 21.85639572], [88.30438232, 21.85618973], [88.30471039, 21.8559761], [88.30504608, 21.85572052], [88.30538177, 21.85544014], [88.30567932, 21.85507011], [88.30594635, 21.85473061], [88.30628204, 21.8544426], [88.30667114, 21.85417938], [88.30710602, 21.85400009], [88.30754852, 21.85388184], [88.30793762, 21.85375023], [88.30840302, 21.85363007], [88.3088913, 21.85358238], [88.30934143, 21.85344124], [88.30980682, 21.85330009], [88.31031036, 21.85304832], [88.31080627, 21.85271263], [88.31121063, 21.8521595], [88.31156158, 21.85168266], [88.31178284, 21.85121155], [88.31201172, 21.85078049], [88.3122406, 21.85041809], [88.31247711, 21.85011101], [88.31266785, 21.84980965], [88.31281281, 21.84950066], [88.31297302, 21.84921646], [88.31310272, 21.84892273], [88.31327057, 21.84861946], [88.31339264, 21.84824944], [88.31358337, 21.84784126], [88.31376648, 21.84730911], [88.31381226, 21.84678268], [88.31382751, 21.84660721], [88.31375885, 21.84591103], [88.31363678, 21.84528351], [88.31352997, 21.84470177], [88.31331635, 21.84424019], [88.3130722, 21.8438282], [88.31284332, 21.84338188], [88.31262207, 21.84287643], [88.31243896, 21.84230995], [88.31221008, 21.84178925], [88.31196594, 21.84128952], [88.31179047, 21.8408165], [88.31163025, 21.84034157], [88.31143951, 21.83988953], [88.31130219, 21.83940125], [88.31109619, 21.83896065], [88.31084442, 21.83855438], [88.31060028, 21.83813858], [88.31033325, 21.83781052], [88.31011963, 21.83740997], [88.31002045, 21.83718872], [88.30993652, 21.83699417], [88.30970764, 21.83659744], [88.30944824, 21.83623123], [88.30918884, 21.83583069], [88.30900574, 21.83538055], [88.30884552, 21.83489799], [88.30860901, 21.83447075], [88.3083725, 21.83406258], [88.30815887, 21.83366394], [88.30795288, 21.83327293], [88.30774689, 21.83288956], [88.30748749, 21.83252907], [88.30719757, 21.83218956], [88.30691528, 21.83184814], [88.30664825, 21.83147812], [88.30638123, 21.83109283], [88.3060379, 21.83068275], [88.30560303, 21.83031845], [88.30506897, 21.8300209], [88.30453491, 21.82976723], [88.30407715, 21.82945061], [88.30367279, 21.8291111], [88.30329895, 21.82876015], [88.30290222, 21.82845688], [88.30245209, 21.82826042], [88.30201721, 21.82806969], [88.30158234, 21.8278904], [88.30111694, 21.8277607], [88.30065918, 21.82760048], [88.30020905, 21.82741928], [88.29978943, 21.82721138], [88.29938507, 21.82698059], [88.29896545, 21.82677841], [88.29852295, 21.82665825], [88.29808044, 21.82653046], [88.29762268, 21.82638359], [88.29718781, 21.82622528], [88.29673767, 21.82612991], [88.29625702, 21.82609749], [88.29577637, 21.82603073], [88.29528809, 21.82587051], [88.29472351, 21.82583427], [88.29410553, 21.82579231], [88.29348755, 21.82561493], [88.29284668, 21.82555962], [88.29220581, 21.82554817], [88.29155731, 21.82555962], [88.2914505, 21.8255558], [88.2909317, 21.82553482], [88.29032135, 21.82543373], [88.28972626, 21.82526207], [88.28911591, 21.82506943], [88.28848267, 21.82508278], [88.2878418, 21.82506943], [88.2871933, 21.82500076], [88.2865448, 21.8249054], [88.28601837, 21.82471848], [88.2855072, 21.82452965], [88.28498077, 21.82439995], [88.28447723, 21.82428551], [88.28401947, 21.82418251], [88.28358459, 21.82411766], [88.28317261, 21.82394409], [88.28270721, 21.82387733], [88.28225708, 21.82378006], [88.28182983, 21.82361984], [88.2813797, 21.82347107], [88.28092194, 21.82331085], [88.28050995, 21.82308006], [88.28005981, 21.82295227], [88.27964783, 21.82278824], [88.27923584, 21.82263947], [88.27882385, 21.82251167], [88.27838898, 21.82240677], [88.27796936, 21.82222748], [88.27754974, 21.82208443], [88.27709198, 21.82191467], [88.27664948, 21.82166481], [88.27619934, 21.82139015], [88.27574158, 21.82110977], [88.27527618, 21.82083321], [88.27481079, 21.82055664], [88.27433014, 21.82029915], [88.2738266, 21.82009125], [88.27330017, 21.81994057], [88.27285767, 21.81969261], [88.27246857, 21.81940079], [88.27210236, 21.81908035], [88.2716217, 21.81888962], [88.27110291, 21.81874084], [88.27056885, 21.81859016], [88.2700882, 21.81833076], [88.2696228, 21.81807327], [88.26914215, 21.81784058], [88.26867676, 21.81762123], [88.26835632, 21.81727982], [88.26798248, 21.81697083], [88.26756287, 21.81671143], [88.26711273, 21.81643867], [88.26663208, 21.8161602], [88.26610565, 21.81582451], [88.26557159, 21.81542587], [88.2650528, 21.81496811], [88.26451874, 21.81451797], [88.26391602, 21.81417274], [88.26339722, 21.81379509], [88.26296234, 21.81336021], [88.26277924, 21.81318474], [88.2625351, 21.81295013], [88.262146, 21.81253815], [88.26174927, 21.81216049], [88.26139069, 21.81175995], [88.26107788, 21.81137085], [88.26081085, 21.81096077], [88.26073456, 21.81085205], [88.26053619, 21.81058121], [88.26025391, 21.81022072], [88.25998688, 21.80986023], [88.25976562, 21.80952263], [88.25960541, 21.8091774], [88.25948334, 21.80885124], [88.25940704, 21.80850983], [88.25926208, 21.80823898], [88.25914001, 21.80792809], [88.25897217, 21.807621], [88.25885773, 21.80721092], [88.25868225, 21.80677986], [88.25858307, 21.80626106], [88.25846863, 21.80594254], [88.25840759, 21.80578041], [88.2583313, 21.80527115], [88.25827026, 21.80474091], [88.25823212, 21.80416107], [88.25828552, 21.8035202], [88.25832367, 21.80281258], [88.2583313, 21.80208778], [88.2583313, 21.80141068], [88.25836182, 21.80076981], [88.25852203, 21.80022812], [88.25863647, 21.79971123], [88.25884247, 21.79926109], [88.25894928, 21.79875183], [88.2591629, 21.79828262], [88.25940704, 21.79783821], [88.25965881, 21.79741096], [88.25984955, 21.79693222], [88.26004791, 21.79644203], [88.26028442, 21.79596329], [88.26055145, 21.79548073], [88.26081848, 21.794981], [88.26107788, 21.79448128], [88.26133728, 21.7939682], [88.26145935, 21.79344749], [88.26164246, 21.79297066], [88.26182556, 21.79249763], [88.26200104, 21.79203033], [88.26222992, 21.79162025], [88.26246643, 21.79120064], [88.26262665, 21.79068947], [88.26277924, 21.79013062], [88.26293945, 21.78957748], [88.2631073, 21.78906822], [88.26332092, 21.78866959], [88.26348877, 21.78831863], [88.2636261, 21.78800011], [88.26377869, 21.78772926], [88.26390839, 21.78745079], [88.26405334, 21.78717995], [88.26418304, 21.78689957], [88.264328, 21.78663063], [88.26447296, 21.78635025], [88.26463318, 21.78609085], [88.26476288, 21.78580093], [88.26491547, 21.78554916], [88.26509094, 21.78530121], [88.26526642, 21.7850399], [88.26547241, 21.78473091], [88.26573181, 21.78440475], [88.26603699, 21.78399467], [88.2664032, 21.78356552], [88.2667923, 21.78312111], [88.2670517, 21.78256989], [88.26722717, 21.78226852], [88.26734161, 21.78206444], [88.26764679, 21.78158951], [88.26794434, 21.78116608], [88.26830292, 21.78078079], [88.26863861, 21.78037643], [88.26898193, 21.77997971], [88.26922607, 21.77953911], [88.26947784, 21.77916527], [88.26970673, 21.77886963], [88.26989746, 21.77859116], [88.27002716, 21.77828979], [88.27021027, 21.7780304], [88.27038574, 21.77774429], [88.27058411, 21.77742767], [88.27082825, 21.77709961], [88.27108002, 21.77672958], [88.27134705, 21.77635384], [88.27161407, 21.7759552], [88.27192688, 21.77556038], [88.27223969, 21.77513123], [88.27257538, 21.77470589], [88.27295685, 21.77431107], [88.27336121, 21.77390671], [88.2738266, 21.7735405], [88.27430725, 21.77313042], [88.27484894, 21.77276993], [88.27542114, 21.77241707], [88.27597809, 21.77206039], [88.27642059, 21.77160263], [88.27639008, 21.77139091], [88.27694702, 21.77139091], [88.27749634, 21.77082825], [88.27777863, 21.77083397], [88.27861023, 21.77000046], [88.27861023, 21.76971817], [88.27889252, 21.76944351], [88.27889252, 21.76916885], [88.27916718, 21.76889038], [88.27945709, 21.76826096], [88.27970886, 21.7677803], [88.27997589, 21.76734161], [88.28026581, 21.76685905], [88.28056335, 21.76638985], [88.28111267, 21.76583099], [88.28111267, 21.76555443], [88.28138733, 21.76556015], [88.28193665, 21.76501083], [88.28193665, 21.76444054], [88.28221893, 21.76416588], [88.28221893, 21.76305962], [88.28231812, 21.76267815], [88.28259277, 21.76217079], [88.2824707, 21.76165962], [88.2822113, 21.76132011], [88.28193665, 21.76110077], [88.28166199, 21.7610817], [88.28112793, 21.76156807], [88.28063965, 21.7618618], [88.28013611, 21.76208115], [88.27961731, 21.76229668], [88.27916718, 21.76259041], [88.27874756, 21.76288033], [88.27825928, 21.76308823], [88.277771, 21.76329994], [88.27728271, 21.76344872], [88.2767868, 21.76362991], [88.27633667, 21.76383018], [88.27583313, 21.76392937], [88.27533722, 21.76408958], [88.27482605, 21.7642498], [88.2743454, 21.76446724], [88.27388, 21.76470184], [88.27339935, 21.76490784], [88.27289581, 21.7650795], [88.27243042, 21.76531792], [88.27199554, 21.76561165], [88.27155304, 21.76594162], [88.27108002, 21.7663002], [88.27057648, 21.7666893], [88.27011108, 21.76713943], [88.2696991, 21.76764107], [88.26930237, 21.76813126], [88.26893616, 21.76865005], [88.26857758, 21.76914406], [88.26818085, 21.76958084], [88.2678833, 21.77006912], [88.26763916, 21.7705555], [88.26742554, 21.77100945], [88.26719666, 21.77140045], [88.2669754, 21.77174377], [88.2667923, 21.77207184], [88.26661682, 21.77235222], [88.26644135, 21.77260971], [88.26628876, 21.77289009], [88.26610565, 21.77312851], [88.26590729, 21.77337074], [88.26570129, 21.77366066], [88.2654953, 21.77398682], [88.26522827, 21.77431679], [88.2649231, 21.77464485], [88.26460266, 21.77495956], [88.26425934, 21.77526093], [88.26391602, 21.77555656], [88.26361847, 21.77589035], [88.26332855, 21.77625465], [88.26304626, 21.77662086], [88.26275635, 21.77696991], [88.2624588, 21.77730942], [88.26215363, 21.77763748], [88.26182556, 21.77796173], [88.26148987, 21.77827263], [88.26113892, 21.77856445], [88.26078033, 21.77884483], [88.26042938, 21.77913094], [88.26008606, 21.77943039], [88.25974274, 21.77972794], [88.25940704, 21.78001976], [88.25904083, 21.78031158], [88.25868988, 21.78059006], [88.25833893, 21.78087997], [88.25799561, 21.78118706], [88.2576828, 21.78152275], [88.25740814, 21.78187943], [88.25710297, 21.7822094], [88.25675201, 21.78250885], [88.25640106, 21.78280258], [88.25608063, 21.78314972], [88.25582123, 21.78356552], [88.25557709, 21.7840004], [88.25536346, 21.78446007], [88.25523376, 21.78494835], [88.25508881, 21.78539467], [88.25501251, 21.7858448], [88.25493622, 21.78624916], [88.25482178, 21.7866497], [88.25476074, 21.78705025], [88.25474548, 21.78747749], [88.25473785, 21.78792381], [88.25473022, 21.78838348], [88.25467682, 21.78886414], [88.25456238, 21.78936958], [88.25449371, 21.78996086], [88.2544632, 21.79058075], [88.25443268, 21.79120064], [88.25435638, 21.79179955], [88.25423431, 21.79237175], [88.2541275, 21.79296112], [88.25400543, 21.79356194], [88.25392914, 21.79417992], [88.2538681, 21.79479027], [88.25377655, 21.79535484], [88.25364685, 21.79586029], [88.25356293, 21.79635048], [88.25343323, 21.79680824], [88.2533493, 21.79731178], [88.2532959, 21.79785156], [88.25321198, 21.79838943], [88.25306702, 21.79888916], [88.25298309, 21.79938126], [88.25286102, 21.79982948], [88.25282288, 21.80031967], [88.25283051, 21.80083275], [88.25287628, 21.80133057], [88.25283051, 21.80181885], [88.25273895, 21.80230141], [88.25263977, 21.80282402], [88.25250244, 21.80277824], [88.25166321, 21.80194283], [88.25166321, 21.80111122], [88.25195312, 21.80083275], [88.2519455, 21.79833412], [88.25200653, 21.79798317], [88.25212097, 21.79749107], [88.25224304, 21.79696274], [88.25235748, 21.79639816], [88.25251007, 21.79585075], [88.25262451, 21.79527283], [88.25276184, 21.79469681], [88.25286865, 21.79408073], [88.25296783, 21.79347038], [88.25305939, 21.79289055], [88.25311279, 21.79231834], [88.25314331, 21.79175949], [88.2532196, 21.79120827], [88.25336456, 21.79061127], [88.25354004, 21.78999138], [88.25362396, 21.78940201], [88.25357819, 21.78883743], [88.25350952, 21.78829002], [88.25353241, 21.78776932], [88.25361633, 21.78729248], [88.25366974, 21.78678513], [88.25372314, 21.78627968], [88.25379944, 21.78583145], [88.25389099, 21.78540039], [88.25393677, 21.78499985], [88.25399017, 21.78457832], [88.25406647, 21.78414917], [88.25419617, 21.78372955], [88.25434113, 21.78329277], [88.25457001, 21.78292084], [88.25485229, 21.78256989], [88.2551651, 21.78224564], [88.25550079, 21.78190994], [88.25583649, 21.78154945], [88.2562027, 21.78117943], [88.25659943, 21.78085327], [88.2570343, 21.78052521], [88.25746918, 21.78014946], [88.25790405, 21.77972984], [88.25834656, 21.77927971], [88.25879669, 21.7788105], [88.25934601, 21.77839088], [88.25990295, 21.77799034], [88.26040649, 21.7775631], [88.26085663, 21.77707291], [88.26130676, 21.77659035], [88.2617569, 21.77610016], [88.26222992, 21.77562714], [88.26270294, 21.77515984], [88.26316833, 21.77468109], [88.26361847, 21.77419853], [88.2640686, 21.77371979], [88.26449585, 21.77324104], [88.26487732, 21.77273941], [88.26521301, 21.77225113], [88.26548767, 21.7717495], [88.26570892, 21.77124977], [88.26592255, 21.77078056], [88.26616669, 21.7703476], [88.2664032, 21.76992035], [88.26660156, 21.76950645], [88.266716, 21.76914978], [88.26664734, 21.76876068], [88.26682281, 21.76861954], [88.26716614, 21.76843262], [88.26748657, 21.76809692], [88.26785278, 21.76770973], [88.26825714, 21.76729965], [88.2687149, 21.76688385], [88.26913452, 21.76641273], [88.26954651, 21.76592827], [88.26998901, 21.76548004], [88.27043152, 21.7650528], [88.27086639, 21.76465988], [88.27128601, 21.76428986], [88.27170563, 21.76400566], [88.27216339, 21.76378822], [88.2726593, 21.76365089], [88.27316284, 21.76357079], [88.27365875, 21.76342964], [88.27411652, 21.76329994], [88.27455139, 21.76310158], [88.27498627, 21.76292038], [88.27542114, 21.76272964], [88.27584076, 21.76251793], [88.27628326, 21.7623291], [88.27672577, 21.762146], [88.27713013, 21.76192093], [88.27754974, 21.76168251], [88.27802277, 21.76145363], [88.27859497, 21.76128197], [88.27922058, 21.76108742], [88.27986145, 21.76083183], [88.28054047, 21.76052094], [88.28114319, 21.76008034], [88.28167725, 21.75963974], [88.28196716, 21.75908089], [88.28226471, 21.75856209], [88.28253174, 21.75803757], [88.28273773, 21.75758171], [88.28279114, 21.75703049], [88.28275299, 21.75641251], [88.28260803, 21.75589561], [88.28250122, 21.75544167], [88.28237915, 21.75502014], [88.28221893, 21.7546196], [88.2820282, 21.75422096], [88.28187561, 21.75382805], [88.28165436, 21.75346947], [88.28141022, 21.75312996], [88.28121948, 21.75274658], [88.28105927, 21.75230026], [88.28082275, 21.75182915], [88.28050995, 21.75131989], [88.28005981, 21.75084686], [88.27971649, 21.75019264], [88.27939606, 21.74953842], [88.27894592, 21.74901962], [88.27848053, 21.74860191], [88.27807617, 21.74814987], [88.27777863, 21.74764061], [88.27745819, 21.74711037], [88.2770462, 21.74662018], [88.27670288, 21.74604034], [88.27642822, 21.7453804], [88.27632141, 21.74463463], [88.27606201, 21.7440052], [88.27562714, 21.74357986], [88.27523804, 21.74319077], [88.27497101, 21.74285126], [88.27471924, 21.74253273], [88.27449036, 21.74221039], [88.27439117, 21.7418251], [88.27422333, 21.74151039], [88.27413177, 21.74115944], [88.27394104, 21.74084091], [88.27387238, 21.74042892], [88.27374268, 21.7399807], [88.27359009, 21.73948288], [88.27334595, 21.73900032], [88.27320862, 21.73849106], [88.27310944, 21.73805237], [88.27326202, 21.73755836], [88.27345276, 21.73706245], [88.27351379, 21.73651123], [88.27328491, 21.73591805], [88.27301788, 21.73529053], [88.27304077, 21.73457527], [88.27282715, 21.73402977], [88.27278137, 21.73347664], [88.27276611, 21.73290825], [88.27272797, 21.73233032], [88.27257538, 21.73179054], [88.27263641, 21.73128128], [88.2724762, 21.73090935], [88.27223969, 21.73064995], [88.27200317, 21.73048019], [88.27159882, 21.73052979], [88.27115631, 21.73055077], [88.27079773, 21.73054123], [88.27039337, 21.7304821], [88.26995087, 21.73035622], [88.26966858, 21.73031425], [88.26947021, 21.73028755], [88.26896667, 21.73027992], [88.26847076, 21.73027992], [88.26796722, 21.7302494], [88.26747131, 21.73012543], [88.266922, 21.73002052], [88.26669312, 21.73001289], [88.26628876, 21.72999954], [88.26568604, 21.73003006], [88.26519775, 21.73021126], [88.26470184, 21.73031044], [88.26423645, 21.73051071], [88.26377106, 21.73062706], [88.26344299, 21.73092461], [88.26329803, 21.73138046], [88.26313019, 21.73181725], [88.26329041, 21.73223114], [88.26334381, 21.73264694], [88.26344299, 21.73301125], [88.26361847, 21.73335075], [88.26386261, 21.73371124], [88.26410675, 21.73415947], [88.26445007, 21.73463058], [88.2648468, 21.73511124], [88.26528931, 21.73552895], [88.26571655, 21.73591423], [88.26611328, 21.73629189], [88.26634216, 21.73651886], [88.26648712, 21.73666191], [88.26685333, 21.73703003], [88.26721191, 21.73740959], [88.26750183, 21.73782158], [88.26777649, 21.7382412], [88.26805878, 21.73867035], [88.26832581, 21.73911095], [88.26862335, 21.73953819], [88.26891327, 21.73994064], [88.26919556, 21.7403183], [88.26947784, 21.74072075], [88.26980591, 21.74111557], [88.27012634, 21.74153328], [88.27036285, 21.74201965], [88.27059937, 21.74250031], [88.27085114, 21.74299049], [88.27108765, 21.74348068], [88.27124023, 21.74401093], [88.27139282, 21.74451065], [88.27149963, 21.74495125], [88.27163696, 21.74530983], [88.27171326, 21.74568939], [88.27189636, 21.74603081], [88.27199554, 21.74649048], [88.27220154, 21.74695206], [88.27233124, 21.74744987], [88.2724762, 21.74789047], [88.27259827, 21.74827957], [88.27275848, 21.74859047], [88.27285767, 21.74895287], [88.2730484, 21.74930954], [88.27321625, 21.74975967], [88.27339172, 21.7503109], [88.27366638, 21.75089073], [88.27394867, 21.75152969], [88.27411652, 21.75224113], [88.27420044, 21.75298119], [88.27424622, 21.7536602], [88.27413177, 21.75418854], [88.27388763, 21.75462532], [88.27359009, 21.75504112], [88.27323914, 21.7554512], [88.27278137, 21.75575066], [88.27229309, 21.75603294], [88.27176666, 21.75629044], [88.27118683, 21.75655174], [88.27050018, 21.75671005], [88.2698288, 21.75689888], [88.26911926, 21.75694466], [88.26876831, 21.75694656], [88.26841736, 21.75694847], [88.26773071, 21.75694084], [88.2670517, 21.75694466], [88.26641083, 21.75694466], [88.26582336, 21.75694466], [88.26530457, 21.75694466], [88.2648468, 21.75694275], [88.26439667, 21.75694084], [88.26392365, 21.7569809], [88.26338196, 21.75713539], [88.26272583, 21.75720024], [88.26204681, 21.75722122], [88.2613678, 21.75722122], [88.26068115, 21.75722122], [88.25998688, 21.75722122], [88.25932312, 21.75723076], [88.25863647, 21.75726128], [88.25798035, 21.75733948], [88.25730896, 21.7574482], [88.25662231, 21.75749016], [88.25592804, 21.75749969], [88.25526428, 21.75749969], [88.25466919, 21.75750923], [88.25417328, 21.75758171], [88.25370789, 21.75769043], [88.2532196, 21.757761], [88.25274658, 21.75782013], [88.25229645, 21.75798035], [88.25180817, 21.7580204], [88.25131226, 21.75805855], [88.25080109, 21.75814819], [88.25028229, 21.75827408], [88.24973297, 21.75832367], [88.24920654, 21.75836945], [88.24877167, 21.7585392], [88.24828339, 21.75862122], [88.24776459, 21.75872612], [88.2472229, 21.75884056], [88.24664307, 21.75893021], [88.24611664, 21.75911713], [88.24560547, 21.75916481], [88.24510193, 21.75918961], [88.24459839, 21.75928879], [88.24408722, 21.75939941], [88.24359131, 21.75945854], [88.24311829, 21.75954056], [88.24267578, 21.75967789], [88.24217987, 21.75976944], [88.24167633, 21.7599411], [88.24111176, 21.76002121], [88.24054718, 21.76013184], [88.24001312, 21.76024055], [88.23950958, 21.76026726], [88.23905182, 21.76028061], [88.23861694, 21.76033401], [88.2381897, 21.76049042], [88.23773956, 21.76050377], [88.23728943, 21.7603817], [88.23686218, 21.76035118], [88.23641968, 21.76044083], [88.23594666, 21.76074982], [88.23551941, 21.76105118], [88.23509216, 21.76128006], [88.23465729, 21.76143074], [88.2342453, 21.76161003], [88.23383331, 21.76177979], [88.23340607, 21.76196098], [88.2330246, 21.76216888], [88.23261261, 21.76237106], [88.23219299, 21.76258087], [88.23175812, 21.76278114], [88.2313385, 21.76300049], [88.23085022, 21.76319122], [88.23023987, 21.76332474], [88.22966003, 21.76332474], [88.22910309, 21.76332283], [88.22853088, 21.76333046], [88.22795868, 21.76333046], [88.22735596, 21.76334953], [88.22676086, 21.76341057], [88.22615814, 21.7635498], [88.22553253, 21.76359177], [88.22491455, 21.7635994], [88.22428894, 21.7636013], [88.22366333, 21.76359177], [88.22305298, 21.76353264], [88.22246552, 21.7633934], [88.22187042, 21.7633419], [88.2212677, 21.76333046], [88.22065735, 21.76333046], [88.22001648, 21.76334], [88.2193985, 21.76338768], [88.21890259, 21.76356125], [88.21843719, 21.76374054], [88.21801758, 21.76394272], [88.21765137, 21.76416206], [88.21734619, 21.76437569], [88.21722412, 21.76444435], [88.21722412, 21.76694679], [88.21749878, 21.76721954], [88.21749878, 21.76749992], [88.21778107, 21.7677803], [88.21778107, 21.77028084], [88.21779633, 21.77098083], [88.21794128, 21.77166748], [88.21792603, 21.77193832], [88.21792603, 21.77305603], [88.21806335, 21.7733326], [88.21820831, 21.77361107], [88.21805573, 21.77388954], [88.21806335, 21.77721977], [88.21778107, 21.77750015], [88.21778107, 21.77806091], [88.21765137, 21.77861023], [88.21722412, 21.77972221], [88.21694183, 21.77999115], [88.21694183, 21.78028107], [88.21666718, 21.78055954], [88.21666718, 21.78139114], [88.21639252, 21.78166771], [88.21637726, 21.78222084], [88.21611023, 21.78250122], [88.21611023, 21.78277969], [88.21555328, 21.78333092], [88.2155304, 21.78376007], [88.21535492, 21.78407288], [88.21523285, 21.78446007], [88.21498871, 21.78483772], [88.21470642, 21.78525352], [88.21438599, 21.78570175], [88.21405792, 21.78616714], [88.21378326, 21.78667259], [88.21353912, 21.78720093], [88.21322632, 21.78763008], [88.21302032, 21.7880497], [88.21279144, 21.78837967], [88.21261597, 21.78869057], [88.21251678, 21.78900909], [88.21247864, 21.78938103], [88.2124176, 21.78982925], [88.21224213, 21.79031944], [88.21213531, 21.79084015], [88.21196747, 21.79124451], [88.21186066, 21.79163933], [88.21164703, 21.79199982], [88.21148682, 21.79236031], [88.21140289, 21.79276085], [88.21135712, 21.79318047], [88.21131897, 21.79358292], [88.21131134, 21.79400063], [88.21116638, 21.79445076], [88.21111298, 21.79496193], [88.21109009, 21.79551697], [88.21103668, 21.79608154], [88.21085358, 21.79658127], [88.21071625, 21.79701805], [88.21057129, 21.79737091], [88.2104187, 21.79766655], [88.21039581, 21.79804039], [88.21034241, 21.79848289], [88.21021271, 21.79889679], [88.20999908, 21.79921341], [88.20981598, 21.79955101], [88.2097168, 21.80000114], [88.20944214, 21.80027962], [88.20944214, 21.80138969], [88.20916748, 21.80166626], [88.20916748, 21.80194473], [88.20888519, 21.8022213], [88.20888519, 21.80249977], [88.20833588, 21.80305481], [88.20833588, 21.80333328], [88.20804596, 21.80360985], [88.20805359, 21.80388832], [88.20777893, 21.80416107], [88.20777893, 21.80444336], [88.20749664, 21.80472183], [88.2075119, 21.80500031], [88.20694733, 21.80555344], [88.20694733, 21.80583], [88.20610809, 21.80666542], [88.20610809, 21.80693054], [88.20527649, 21.80778122], [88.20527649, 21.80805779], [88.20500183, 21.80833054], [88.20471954, 21.80861092], [88.20471954, 21.80916786], [88.204422, 21.80978012], [88.20417786, 21.81025124], [88.20398712, 21.81068039], [88.20384979, 21.81106186], [88.2036972, 21.81137085], [88.20362091, 21.81164932], [88.20357513, 21.81193352], [88.20345306, 21.81220245], [88.20334625, 21.81248474], [88.20326233, 21.81278038], [88.203125, 21.81304932], [88.20301819, 21.81336021], [88.20287323, 21.81374741], [88.20271301, 21.81421089], [88.20252991, 21.8146553], [88.20243835, 21.81508636], [88.20230103, 21.81544304], [88.20217896, 21.81580925], [88.20201874, 21.81616974], [88.2019043, 21.816576], [88.2017746, 21.81700134], [88.20170593, 21.81745911], [88.20153809, 21.81785011], [88.20136261, 21.8182106], [88.20116425, 21.81856537], [88.20105743, 21.81900024], [88.20088196, 21.81946564], [88.20053101, 21.81986809], [88.20014191, 21.82024193], [88.19982147, 21.82069016], [88.199646, 21.82125092], [88.19950104, 21.82181931], [88.19933319, 21.82232285], [88.19908905, 21.8227005], [88.1988678, 21.82304001], [88.19863129, 21.82333755], [88.19843292, 21.82364845], [88.19827271, 21.82398987], [88.19807434, 21.82432938], [88.19805908, 21.82444382], [88.19777679, 21.82471848], [88.19777679, 21.82500076], [88.19721985, 21.8255558], [88.19721985, 21.82582855], [88.1966629, 21.82638931], [88.1966629, 21.82666969], [88.1958313, 21.82749939], [88.1958313, 21.82777786], [88.19527435, 21.8283329], [88.19527435, 21.82861137], [88.19472504, 21.82916641], [88.19472504, 21.82944489], [88.19444275, 21.82971954], [88.19444275, 21.82999992], [88.1938858, 21.83055305], [88.1938858, 21.83082962], [88.1930542, 21.83166695], [88.19304657, 21.8319397], [88.19249725, 21.83250046], [88.19249725, 21.83278084], [88.1922226, 21.8330574], [88.19220734, 21.83333015], [88.19194794, 21.83361053], [88.19194794, 21.83389091], [88.1902771, 21.83555794], [88.1902771, 21.8358326], [88.18777466, 21.83833313], [88.18777466, 21.8386116], [88.1855545, 21.84083366], [88.18527985, 21.84083176], [88.18222046, 21.84389114], [88.18222046, 21.84416962], [88.18138885, 21.84499931], [88.18113708, 21.84527016], [88.18083191, 21.84559631], [88.1805191, 21.84595108], [88.18019104, 21.84632111], [88.17987823, 21.84663963], [88.17958832, 21.84692955], [88.17933655, 21.84723091], [88.17908478, 21.84756088], [88.17879486, 21.84789467], [88.17855835, 21.84827995], [88.17832184, 21.84867859], [88.17806244, 21.84903908], [88.17784119, 21.84943008], [88.17772675, 21.84988022], [88.17755127, 21.85025024], [88.17739868, 21.85065079], [88.17720032, 21.85106277], [88.17694855, 21.85148048], [88.17694092, 21.8516674], [88.17666626, 21.85194397], [88.17666626, 21.85220909], [88.1763916, 21.85250092], [88.1763916, 21.85277939], [88.17610931, 21.85305595], [88.17610931, 21.8533287], [88.17583466, 21.8536129], [88.17583466, 21.8544445], [88.17555237, 21.85472107], [88.17555237, 21.85527802], [88.17500305, 21.85583115], [88.17500305, 21.85610962], [88.17414856, 21.85695076], [88.17416382, 21.85805321], [88.17388916, 21.85833359], [88.17388916, 21.85861015], [88.1736145, 21.85888863], [88.17360687, 21.85943985], [88.17305756, 21.86000061], [88.17305756, 21.86027527], [88.17250061, 21.86083031], [88.17250061, 21.86111069], [88.17222595, 21.8614006], [88.17222595, 21.86166763], [88.17194366, 21.8619442], [88.17193604, 21.86222076], [88.17166901, 21.86250114], [88.17166901, 21.86277962], [88.17138672, 21.86305618], [88.17140198, 21.86361122], [88.17082977, 21.86416626], [88.17082977, 21.86444473], [88.17055511, 21.8647213], [88.17056274, 21.86499977], [88.17028046, 21.86527824], [88.17028046, 21.86555481], [88.16999817, 21.86583328], [88.16999817, 21.86611176], [88.16971588, 21.86639023], [88.16971588, 21.86667252], [88.16944885, 21.86696053], [88.16944122, 21.86778069], [88.16916656, 21.86806107], [88.16916656, 21.86861038], [88.16889191, 21.86889076], [88.16889191, 21.87000084], [88.16833496, 21.87055588], [88.16832733, 21.87083054], [88.16777802, 21.87138939], [88.16777802, 21.87194443], [88.16805267, 21.87222099], [88.16805267, 21.87249947], [88.16777802, 21.87277985], [88.16777802, 21.87334061], [88.16694641, 21.8741703], [88.16694641, 21.87444687], [88.16666412, 21.87472153], [88.16666412, 21.87583351], [88.16638947, 21.87610817], [88.16638947, 21.87750053], [88.16555786, 21.87833405], [88.16388702, 21.87832832], [88.16361237, 21.87861061], [88.16361237, 21.87916756], [88.16333008, 21.87944412], [88.16361237, 21.87972069], [88.16361237, 21.88055611], [88.16388702, 21.88083267], [88.16388702, 21.88111115], [88.16416931, 21.88138962], [88.16416931, 21.88166618], [88.16333771, 21.88249969], [88.16333008, 21.88277817], [88.16361237, 21.88305473], [88.16361237, 21.88333321], [88.16388702, 21.88360977], [88.16388702, 21.88388824], [88.16400146, 21.88455963], [88.16404724, 21.88516045], [88.16429901, 21.885746], [88.1644516, 21.88641357], [88.16459656, 21.88709831], [88.16475677, 21.88778114], [88.16493988, 21.88842392], [88.16499329, 21.88905334], [88.16501617, 21.88961029], [88.1651001, 21.89006042], [88.16525269, 21.89042091], [88.16536713, 21.89074707], [88.16553497, 21.89105034], [88.16570282, 21.89138412], [88.16590118, 21.8917141], [88.16615295, 21.8920002], [88.16637421, 21.89231491], [88.16654968, 21.89266968], [88.16668701, 21.89306259], [88.16686249, 21.89342117], [88.16699982, 21.89377594], [88.16716766, 21.89410019], [88.1672821, 21.8944664], [88.16744232, 21.89480019], [88.16754913, 21.89524078], [88.1677475, 21.89564705], [88.16792297, 21.89614105], [88.16809845, 21.89669991], [88.16832733, 21.89727974], [88.16863251, 21.8978672], [88.1689682, 21.89842987], [88.16925049, 21.89899063], [88.16945648, 21.89950943], [88.16963196, 21.89997292], [88.16962433, 21.90047073], [88.16968536, 21.90089417], [88.1697464, 21.90127945], [88.16986084, 21.90167809], [88.16998291, 21.90208054], [88.17002869, 21.90253067], [88.17016602, 21.90297127], [88.17030334, 21.90348053], [88.17047119, 21.90398979], [88.17060852, 21.90452957], [88.17082214, 21.90501022], [88.17098999, 21.90543747], [88.17112732, 21.90581131], [88.17127228, 21.90612221], [88.17140198, 21.90641022], [88.17154694, 21.90669441], [88.17163849, 21.90700912], [88.17166901, 21.90739059], [88.17221832, 21.90860176], [88.17250061, 21.9091301], [88.1727829, 21.90971756], [88.17307281, 21.91028976], [88.17330933, 21.91080093], [88.17368317, 21.91146088], [88.17388916, 21.91167068], [88.17388916, 21.91305733], [88.17414856, 21.91333008], [88.17414856, 21.91389084], [88.17444611, 21.9141655], [88.17446136, 21.91472054], [88.17500305, 21.91527939], [88.17500305, 21.91611099], [88.17527771, 21.91638947], [88.17527771, 21.9169445], [88.17555237, 21.91721916], [88.17555237, 21.91805649], [88.17582703, 21.9183197], [88.17582703, 21.91889191], [88.17610931, 21.91917038], [88.17610931, 21.91944504], [88.1763916, 21.9197216], [88.1763916, 21.92111015], [88.17666626, 21.92138863], [88.17666626, 21.92194366], [88.17694092, 21.92222023], [88.17694092, 21.92389107], [88.17720795, 21.92416954], [88.17720795, 21.92611122], [88.17694092, 21.92638969], [88.17694092, 21.9272213], [88.17666626, 21.92749977], [88.17666626, 21.92833328], [88.1763916, 21.92860985], [88.1763916, 21.92944527], [88.17610931, 21.92971992], [88.17610931, 21.93027878], [88.17582703, 21.93054962], [88.17582703, 21.93111038], [88.17555237, 21.93139076], [88.17555237, 21.93166733], [88.17527771, 21.93194389], [88.17527771, 21.93221855], [88.17500305, 21.93250084], [88.17500305, 21.9327774], [88.17446136, 21.93332863], [88.17446136, 21.93362045], [88.17416382, 21.93388939], [88.17394257, 21.93412971], [88.17362213, 21.93445969], [88.17330933, 21.9348259], [88.17299652, 21.93518257], [88.1726532, 21.93551064], [88.17225647, 21.93582153], [88.171875, 21.93620682], [88.17140198, 21.93655014], [88.17087555, 21.93691826], [88.17037964, 21.93725014], [88.16994476, 21.93764305], [88.16955566, 21.93802261], [88.16916656, 21.93840981], [88.16882324, 21.93884087], [88.168396, 21.93918037], [88.16797638, 21.93949127], [88.16755676, 21.93971062], [88.1671524, 21.93992805], [88.16669464, 21.94016457], [88.16617584, 21.94046021], [88.16571808, 21.94086266], [88.16523743, 21.94131279], [88.16470337, 21.94171333], [88.16426849, 21.94214439], [88.16388702, 21.94248962], [88.16358948, 21.94280243], [88.16333008, 21.94305992], [88.16307831, 21.94330978], [88.16282654, 21.9435482], [88.16261292, 21.94377708], [88.16240692, 21.94397354], [88.16218567, 21.94416046], [88.16190338, 21.94437981], [88.1615448, 21.94469452], [88.16113281, 21.94508171], [88.16075897, 21.94552612], [88.16042328, 21.94595909], [88.1601181, 21.94635773], [88.15981293, 21.94671822], [88.15953064, 21.94712448], [88.15923309, 21.94754982], [88.15892792, 21.94800949], [88.15861511, 21.94843864], [88.15833282, 21.94882011], [88.15808105, 21.94915009], [88.15789795, 21.94944572], [88.15777588, 21.94972038], [88.15750122, 21.95000076], [88.15750122, 21.95083046], [88.15721893, 21.95111084], [88.15721893, 21.95139122], [88.15694427, 21.95166588], [88.15694427, 21.95194435], [88.15666962, 21.95222092], [88.15666962, 21.95249939], [88.15638733, 21.95277977], [88.15638733, 21.95305443], [88.15611267, 21.9533329], [88.1559906, 21.95370483], [88.15582275, 21.95399284], [88.15566254, 21.95441055], [88.1554184, 21.95494843], [88.15503693, 21.95544434], [88.15458679, 21.95581055], [88.15419006, 21.95615959], [88.15382385, 21.9565258], [88.15349579, 21.95690346], [88.15341949, 21.95743942], [88.15354919, 21.95804024], [88.1536026, 21.95862961], [88.15366364, 21.9591732], [88.15383148, 21.95960999], [88.1541214, 21.95994949], [88.15444183, 21.96026993], [88.15477753, 21.96062088], [88.15512848, 21.96102905], [88.1555481, 21.96140289], [88.15595245, 21.96178818], [88.15631104, 21.96213913], [88.15663147, 21.96244049], [88.15694427, 21.96267891], [88.1572113, 21.96289253], [88.1574173, 21.96314049], [88.15757751, 21.96347046], [88.15779114, 21.9637394], [88.15802002, 21.96400833], [88.1581955, 21.96433449], [88.15834045, 21.96475029], [88.1585083, 21.9652195], [88.1587677, 21.96567345], [88.15907288, 21.96608162], [88.15933228, 21.96651077], [88.15965271, 21.96685982], [88.15995789, 21.96715546], [88.16027069, 21.96742058], [88.16055298, 21.96775055], [88.16085052, 21.96809959], [88.16117096, 21.96846771], [88.16150665, 21.96882057], [88.16187286, 21.96915054], [88.16220856, 21.96946144], [88.16252136, 21.96977043], [88.16285706, 21.97004318], [88.16324615, 21.97026062], [88.16362, 21.97045135], [88.16394043, 21.97063446], [88.16420746, 21.97085953], [88.16452026, 21.97109985], [88.16491699, 21.97133446], [88.1654129, 21.97154045], [88.1659317, 21.97177124], [88.1664505, 21.9719696], [88.16691589, 21.97217751], [88.16739655, 21.97230339], [88.16784668, 21.97250175], [88.16832733, 21.97274017], [88.16883087, 21.97303009], [88.16944122, 21.97329903], [88.17014313, 21.97352028], [88.17072296, 21.97388077], [88.17123413, 21.97425079], [88.17160034, 21.97468948], [88.17185211, 21.97517014], [88.17208862, 21.9756012], [88.17232513, 21.97602844], [88.17263794, 21.97640228], [88.17299652, 21.9767704], [88.17340851, 21.97715759], [88.17388153, 21.97751427], [88.17434692, 21.97789192], [88.17478943, 21.97834969], [88.17523956, 21.97883606], [88.17572784, 21.97932816], [88.17623901, 21.97984123], [88.17675018, 21.98028946], [88.17719269, 21.98070908], [88.17753601, 21.98106575], [88.1778717, 21.98133087], [88.17821503, 21.98155594], [88.1785202, 21.98180199], [88.17864227, 21.98199081], [88.17874146, 21.98213959], [88.17891693, 21.98253059], [88.17912292, 21.98289108], [88.17919159, 21.98328018], [88.17933655, 21.98360062], [88.17958832, 21.98389053], [88.17991638, 21.98418045], [88.18025208, 21.9845295], [88.18055725, 21.98493958], [88.18089294, 21.98533821], [88.18123627, 21.98573112], [88.18157959, 21.98606491], [88.18191528, 21.98636246], [88.18222809, 21.98669434], [88.18250275, 21.98708153], [88.18279266, 21.98747063], [88.18312073, 21.98782921], [88.18344879, 21.98820686], [88.18375397, 21.9886322], [88.18406677, 21.98911095], [88.18434143, 21.98965073], [88.18464661, 21.99015045], [88.18491364, 21.99068642], [88.18524933, 21.99110031], [88.1855545, 21.99152565], [88.18585968, 21.99193192], [88.186203, 21.99229431], [88.18657684, 21.99262047], [88.18692017, 21.99296188], [88.18721008, 21.99332047], [88.18746948, 21.9937191], [88.18769836, 21.99415016], [88.18795013, 21.99457169], [88.18814087, 21.99505424], [88.18839264, 21.99549103], [88.18875122, 21.99591827], [88.18913269, 21.99637985], [88.18943024, 21.99690056], [88.18982697, 21.99732018], [88.19024658, 21.99769974], [88.19062042, 21.99810028], [88.19096375, 21.99851036], [88.19111633, 21.9990406], [88.19249725, 22.00000191], [88.1930542, 22.00055504], [88.19304657, 22.0008316], [88.19361115, 22.00139046], [88.19361115, 22.00166702], [88.1955719, 22.00361061], [88.1955719, 22.00389099], [88.1958313, 22.00416756], [88.1958313, 22.0047226], [88.19694519, 22.00583267], [88.19695282, 22.00611115], [88.19750214, 22.00666428], [88.19750214, 22.00694656], [88.19818878, 22.00763321], [88.19833374, 22.00777626], [88.19833374, 22.00790024], [88.19833374, 22.00805473], [88.1985321, 22.00825691], [88.1986084, 22.00833321], [88.1986084, 22.00861168], [88.1988678, 22.00887108], [88.19944763, 22.00944519], [88.19944763, 22.01000023], [88.19953156, 22.01008606], [88.19972229, 22.0102787], [88.19972229, 22.01042938], [88.19972229, 22.01083374], [88.20020294, 22.01131439], [88.20027924, 22.01139069], [88.20027924, 22.01166725], [88.20055389, 22.01194382], [88.20055389, 22.01222229], [88.20088196, 22.01255035], [88.20111084, 22.01277733], [88.20111084, 22.0130558], [88.20121765, 22.01316261], [88.2013855, 22.01333427], [88.2013855, 22.0134716], [88.2013855, 22.01361275], [88.20155334, 22.01377487], [88.20166779, 22.01388931], [88.20166779, 22.01399994], [88.20166779, 22.01416588], [88.20194244, 22.01444435], [88.20194244, 22.01472282], [88.20262909, 22.01540947], [88.20444489, 22.01722145], [88.20443726, 22.01777077], [88.20471954, 22.01805305], [88.20471954, 22.01832962], [88.20555878, 22.01916695], [88.20555878, 22.01944351], [88.20583344, 22.01972198], [88.20582581, 22.01988029], [88.20582581, 22.02000046], [88.20610809, 22.02028084], [88.20610809, 22.0205555], [88.20667267, 22.02111053], [88.20666504, 22.0213871], [88.20715332, 22.02187729], [88.20777893, 22.02250099], [88.20777893, 22.02277946], [88.20805359, 22.02305794], [88.20804596, 22.02333069], [88.20833588, 22.02361107], [88.20833588, 22.02389908], [88.20861053, 22.02416611], [88.20861053, 22.02444458], [88.20888519, 22.02472305], [88.20889282, 22.02499962], [88.20916748, 22.02527809], [88.20916748, 22.02555466], [88.20944214, 22.02583313], [88.20944214, 22.0261116], [88.2097168, 22.02639008], [88.20972443, 22.02666664], [88.20999908, 22.02694511], [88.20999908, 22.02722168], [88.21057129, 22.02778053], [88.21055603, 22.02805519], [88.21083069, 22.02833176], [88.21083069, 22.02861023], [88.21111298, 22.0288887], [88.21111298, 22.02944183], [88.21166992, 22.03000069], [88.21166992, 22.03027725], [88.21250153, 22.03194427], [88.21277618, 22.03222084], [88.21277618, 22.03250122], [88.21305847, 22.03277969], [88.21305847, 22.03305435], [88.21333313, 22.03333282], [88.21331787, 22.03360939], [88.21360779, 22.03388977], [88.21360779, 22.03444672], [88.21389008, 22.03472137], [88.21389008, 22.03555107], [88.2141571, 22.03583908], [88.21416473, 22.03694534], [88.21444702, 22.03722191], [88.21444702, 22.03832817], [88.21472168, 22.03861046], [88.21472168, 22.03943825], [88.21527863, 22.04000092], [88.21527863, 22.04027939], [88.21499634, 22.04055977], [88.21499634, 22.04138947], [88.21527863, 22.04166603], [88.21527863, 22.0419445], [88.21555328, 22.04222107], [88.21555328, 22.04277992], [88.21527863, 22.04305649], [88.21555328, 22.04333305], [88.21555328, 22.04453087], [88.21555328, 22.04583359], [88.21583557, 22.04611206], [88.2158432, 22.04833031], [88.21611023, 22.04861069], [88.21611023, 22.05138969], [88.21637726, 22.05166817], [88.21637726, 22.05250168], [88.21666718, 22.05277824], [88.21666718, 22.05361176], [88.21694183, 22.05388069], [88.21694183, 22.05417061], [88.21722412, 22.05444527], [88.21721649, 22.05472183], [88.21805573, 22.05555534], [88.21806335, 22.05583191], [88.21833038, 22.05611038], [88.21833038, 22.05639076], [88.21861267, 22.05750084], [88.21861267, 22.05805588], [88.21888733, 22.05833054], [88.21888733, 22.05916405], [88.21916962, 22.05944443], [88.21916962, 22.05972099], [88.2194519, 22.06001091], [88.21944427, 22.06027794], [88.22000122, 22.06083107], [88.22000122, 22.06138611], [88.22027588, 22.0616684], [88.22027588, 22.06222153], [88.22038269, 22.06232643], [88.22055817, 22.06249809], [88.22055817, 22.06305695], [88.22083282, 22.06333351], [88.22083282, 22.06360817], [88.22110748, 22.06388664], [88.22110748, 22.06471825], [88.22138977, 22.06500053], [88.22138977, 22.06528091], [88.2216568, 22.06555939], [88.2216568, 22.06611061], [88.22194672, 22.06638908], [88.22194672, 22.0672226], [88.22222137, 22.06750107], [88.22222137, 22.06916618], [88.22250366, 22.06944466], [88.22251129, 22.07110977], [88.22277832, 22.07139015], [88.22277832, 22.07194328], [88.22305298, 22.07221985], [88.22305298, 22.07305527], [88.2233429, 22.07332993], [88.22333527, 22.07416534], [88.22360992, 22.07444], [88.22360992, 22.0750103], [88.22389221, 22.07527542], [88.22389221, 22.07722092], [88.22416687, 22.07749748], [88.22416687, 22.08194351], [88.22389221, 22.08222008], [88.22389221, 22.08250046], [88.22416687, 22.08278084], [88.22416687, 22.08361053], [88.22389221, 22.08388901], [88.22389221, 22.08444214], [88.22360992, 22.08472061], [88.22389221, 22.08500099], [88.22389221, 22.08611107], [88.22416687, 22.08638954], [88.22389221, 22.0866642], [88.22389221, 22.08805466], [88.22416687, 22.08833313], [88.22416687, 22.08972168], [88.22389221, 22.08999062], [88.22389221, 22.09055519], [88.22416687, 22.09082985], [88.22416687, 22.09110832], [88.22444153, 22.09139061], [88.22444153, 22.09166908], [88.22389221, 22.09166718], [88.22360992, 22.09193993], [88.22360992, 22.09250069], [88.22333527, 22.09277725], [88.22333527, 22.09444427], [88.22305298, 22.09472275], [88.22305298, 22.09527969], [88.22277832, 22.09556007], [88.22277832, 22.09638977], [88.22305298, 22.09666634], [88.22305298, 22.09805489], [88.22277832, 22.09832954], [88.22277832, 22.0988903], [88.22222137, 22.09944344], [88.22222137, 22.09972191], [88.22251129, 22.10000038], [88.22251129, 22.10028076], [88.22222137, 22.10056114], [88.22222137, 22.10139084], [88.22194672, 22.1016655], [88.22194672, 22.10194397], [88.2216568, 22.10222054], [88.2216568, 22.10277939], [88.22083282, 22.10360909], [88.22083282, 22.1044445], [88.22110748, 22.10471916], [88.22110748, 22.10527992], [88.22027588, 22.10611153], [88.22027588, 22.10638809], [88.21944427, 22.1072216], [88.2194519, 22.10861015], [88.21888733, 22.1091671], [88.21888733, 22.10944176], [88.21833038, 22.11000061], [88.21833038, 22.1102829], [88.21805573, 22.11055565], [88.21806335, 22.11083031], [88.21778107, 22.11112022], [88.21778107, 22.11139107], [88.21749878, 22.11166573], [88.21749878, 22.11194038], [88.21666718, 22.11277771], [88.21666718, 22.11416435], [88.21637726, 22.11444092], [88.21637726, 22.11499977], [88.21611023, 22.11527634], [88.21637726, 22.11555099], [88.21637726, 22.11639023], [88.21666718, 22.11667061], [88.21666718, 22.11694527], [88.21637726, 22.11721992], [88.21637726, 22.11860847], [88.21694183, 22.11916733], [88.21694183, 22.11943817], [88.21637726, 22.12000084], [88.21637726, 22.12029076], [88.21555328, 22.12111282], [88.21555328, 22.12138939], [88.21527863, 22.12166595], [88.21527863, 22.12194252], [88.21472168, 22.12249947], [88.21472168, 22.12305641], [88.2141571, 22.12360954], [88.2141571, 22.1241703], [88.21389008, 22.12444305], [88.21389008, 22.12471962], [88.21360779, 22.125], [88.21360779, 22.12528038], [88.21333313, 22.12555313], [88.21333313, 22.12583351], [88.21221924, 22.12694359], [88.21221924, 22.12722015], [88.21194458, 22.12750053], [88.21193695, 22.12833023], [88.21166992, 22.12861061], [88.21166992, 22.12944412], [88.21138763, 22.1297226], [88.21138763, 22.13083076], [88.21111298, 22.13111115], [88.21111298, 22.13138962], [88.21083069, 22.13166618], [88.21083069, 22.13305473], [88.21138763, 22.13361168], [88.21138763, 22.13389015], [88.21111298, 22.13416672], [88.21111298, 22.13583183], [88.21138763, 22.13611031], [88.21138763, 22.13972092], [88.21166992, 22.13999939], [88.21166992, 22.14055443], [88.21138763, 22.14083099], [88.21138763, 22.14249992], [88.21111298, 22.1427803], [88.21057129, 22.1427803], [88.21083069, 22.14306068], [88.21111298, 22.14306068], [88.21111298, 22.14416885], [88.21083069, 22.1444397], [88.21083069, 22.14639091], [88.21055603, 22.14666748], [88.21055603, 22.14944458], [88.21028137, 22.14972115], [88.21028137, 22.14999962], [88.20999908, 22.15027809], [88.20999908, 22.15055466], [88.20972443, 22.15083313], [88.2097168, 22.1511097], [88.20944214, 22.15139008], [88.20944214, 22.15167046], [88.20916748, 22.15194321], [88.20916748, 22.15333366], [88.20889282, 22.15361023], [88.20889282, 22.15389061], [88.20861053, 22.15416527], [88.20861053, 22.15444374], [88.20833588, 22.15472031], [88.20833588, 22.15500069], [88.20804596, 22.15528107], [88.20804596, 22.15611076], [88.20777893, 22.15639114], [88.20777893, 22.1566658], [88.2075119, 22.15694046], [88.2075119, 22.15777969], [88.20722198, 22.15805626], [88.20722198, 22.15833282], [88.20694733, 22.15860748], [88.20694733, 22.15888977], [88.20666504, 22.15916634], [88.20667267, 22.15972137], [88.20639038, 22.16000175], [88.20639038, 22.16027832], [88.20583344, 22.16083336], [88.20582581, 22.16111183], [88.20555878, 22.1613903], [88.20555878, 22.16167068], [88.20527649, 22.16194534], [88.20527649, 22.16220856], [88.20500183, 22.16250038], [88.20500183, 22.16278076], [88.20471954, 22.16305542], [88.20471954, 22.16333008], [88.20443726, 22.16361046], [88.20443726, 22.16389084], [88.20417023, 22.1641674], [88.20417023, 22.16444206], [88.20388794, 22.16472054], [88.20388794, 22.16500092], [88.20361328, 22.16526985], [88.20361328, 22.16555405], [88.20333099, 22.16583061], [88.20333099, 22.16611099], [88.20305634, 22.16638947], [88.20305634, 22.16694069], [88.20055389, 22.16944695], [88.20054626, 22.1697197], [88.1986084, 22.1716671], [88.1986084, 22.17193985], [88.19805908, 22.17250061], [88.19805908, 22.17277718], [88.19750214, 22.1733284], [88.19750214, 22.17361069], [88.1966629, 22.17444038], [88.1966629, 22.17500114], [88.19638824, 22.17527962], [88.19638824, 22.17638969], [88.19555664, 22.1772213], [88.19528198, 22.17721176], [88.1930542, 22.17944336], [88.19304657, 22.17971992], [88.1922226, 22.18055534], [88.19220734, 22.18083], [88.19167328, 22.18139076], [88.19167328, 22.18167114], [88.19000244, 22.18333817], [88.19000244, 22.18361092], [88.18972015, 22.18388748], [88.18972015, 22.18416786], [88.1894455, 22.18444443], [88.18943787, 22.18471909], [88.18914795, 22.18499756], [88.18914795, 22.18556023], [88.18805695, 22.1866703], [88.18776703, 22.1866703], [88.18694305, 22.18750191], [88.1866684, 22.18750191], [88.18611145, 22.18806267], [88.18583679, 22.18806267], [88.1847229, 22.18917274], [88.18444824, 22.18916702], [88.18416595, 22.18944359], [88.1838913, 22.18943977], [88.1827774, 22.19055939], [88.18250275, 22.19055557], [88.18222046, 22.19083214], [88.1819458, 22.19083214], [88.18083191, 22.19194412], [88.18055725, 22.19166756], [88.18027496, 22.19166756], [88.18000031, 22.19194412], [88.17944336, 22.19194412], [88.1791687, 22.1922226], [88.17888641, 22.19221115], [88.1783371, 22.19277954], [88.17804718, 22.19277954], [88.17778015, 22.19305992], [88.17749786, 22.1930542], [88.17722321, 22.19333267], [88.17694092, 22.19333076], [88.1763916, 22.19388962], [88.17610931, 22.19388962], [88.17582703, 22.19417], [88.17500305, 22.19416428], [88.17472076, 22.19444466], [88.17333221, 22.19444466], [88.17305756, 22.19472313], [88.1727829, 22.19472122], [88.17250061, 22.19499969], [88.17193604, 22.19499969], [88.17166901, 22.19528008], [88.17082977, 22.19527626], [88.17055511, 22.19555473], [88.16999817, 22.19555473], [88.16972351, 22.19583321], [88.16916656, 22.19583321], [88.16889191, 22.19611168], [88.16832733, 22.19610977], [88.16777802, 22.19667053], [88.16750336, 22.19666862], [88.16694641, 22.19722176], [88.16638947, 22.19721985], [88.16610718, 22.19749832], [88.16583252, 22.19749832], [88.16555786, 22.19778061], [88.16555786, 22.19889069], [88.16526794, 22.19778061], [88.16471863, 22.19778061], [88.16443634, 22.19805908], [88.16388702, 22.19805908], [88.16361237, 22.19833946], [88.16249847, 22.19833946], [88.16220856, 22.1986084], [88.16139221, 22.1986084], [88.16110992, 22.19889069], [88.1608429, 22.19889069], [88.16055298, 22.1986084], [88.15972137, 22.1986084], [88.15972137, 22.19889069], [88.15833282, 22.19889069], [88.15805817, 22.1986084], [88.15556335, 22.1986084], [88.15528107, 22.19889069], [88.15444183, 22.19889069], [88.15416718, 22.19916916], [88.15389252, 22.19889069], [88.15249634, 22.19889069], [88.15222168, 22.19916916], [88.15166473, 22.19916725], [88.15139008, 22.19944382], [88.15055847, 22.19944382], [88.15027618, 22.19972229], [88.14916992, 22.19971848], [88.14888763, 22.20000076], [88.14833069, 22.20000076], [88.14833069, 22.19971848], [88.14778137, 22.19971848], [88.14723206, 22.20027924], [88.14639282, 22.20027924], [88.14611053, 22.20055962], [88.14583588, 22.2005558], [88.14555359, 22.20083427], [88.14527893, 22.20083237], [88.14499664, 22.20111275], [88.14416504, 22.20111275], [88.14389038, 22.20138931], [88.14360809, 22.20138168], [88.14332581, 22.20166969], [88.14138794, 22.20166588], [88.14111328, 22.20194435], [88.13972473, 22.20194435], [88.13944244, 22.20222282], [88.13777924, 22.20222282], [88.13749695, 22.20194435], [88.13666534, 22.20194435], [88.13639069, 22.20166588], [88.13555908, 22.20166588], [88.13527679, 22.20194435], [88.13444519, 22.20194435], [88.1341629, 22.20222282], [88.13249969, 22.20222282], [88.13223267, 22.20249939], [88.13166809, 22.20249939], [88.1313858, 22.20277977], [88.13054657, 22.20277977], [88.13027954, 22.20306015], [88.12944794, 22.20305634], [88.12889099, 22.20361137], [88.1286087, 22.20360947], [88.12832642, 22.20388985], [88.12805176, 22.20388985], [88.1277771, 22.20417023], [88.12750244, 22.20416641], [88.1269455, 22.20472145], [88.12666321, 22.20471954], [88.1258316, 22.20556068], [88.125, 22.20555305], [88.12472534, 22.20583344], [88.12444305, 22.20583344], [88.1241684, 22.20555305], [88.1230545, 22.20555305], [88.12277985, 22.20583344], [88.12277985, 22.20611], [88.12249756, 22.20639038], [88.12249756, 22.20666695], [88.1222229, 22.20694351], [88.12194824, 22.2069397], [88.1213913, 22.20750809], [88.12000275, 22.20750809], [88.11972046, 22.20778084], [88.11915588, 22.20778084], [88.11833191, 22.20861053], [88.11778259, 22.20861053], [88.11750031, 22.20889091], [88.1169281, 22.20889091], [88.1166687, 22.20916939], [88.11333466, 22.20916557], [88.11305237, 22.20944405], [88.11250305, 22.20944405], [88.11250305, 22.20916557], [88.1102829, 22.20916939], [88.11000061, 22.20889091], [88.10972595, 22.20889091], [88.10972595, 22.20916939], [88.10832977, 22.20916557], [88.10832977, 22.20944405], [88.10666656, 22.20944405], [88.10639191, 22.20972252], [88.10472107, 22.20972252], [88.10472107, 22.20944405], [88.10138702, 22.20944405], [88.10122681, 22.20960617], [88.10111237, 22.20972252], [88.09944153, 22.20972252], [88.09916687, 22.20944405], [88.09527588, 22.20944405], [88.09500122, 22.20916557], [88.0930481, 22.20916939], [88.09278107, 22.20889091], [88.09194183, 22.20889091], [88.09166718, 22.20861053], [88.08972168, 22.20861053], [88.08944702, 22.20833015], [88.08750153, 22.20833015], [88.08721924, 22.20861053], [88.08611298, 22.20861053], [88.08583069, 22.20889091], [88.08528137, 22.20889091], [88.08499908, 22.20916939], [88.08388519, 22.20916557], [88.08361053, 22.20944405], [88.08194733, 22.20944405], [88.08166504, 22.20972252], [88.08139038, 22.20972252], [88.08110809, 22.20944405], [88.07917023, 22.20944405], [88.07888794, 22.20972252], [88.07775879, 22.20972061], [88.07749939, 22.21000099], [88.07277679, 22.21000099], [88.07250214, 22.21027946], [88.07221985, 22.21027946], [88.07195282, 22.21056938], [88.0716629, 22.21055794], [88.07138824, 22.2108326], [88.07110596, 22.21083069], [88.0708313, 22.21110916], [88.07055664, 22.21110916], [88.06972504, 22.21194458], [88.06973267, 22.21500015], [88.06999969, 22.21527863], [88.06999969, 22.2163887], [88.07055664, 22.21694374], [88.0708313, 22.21694183], [88.07138824, 22.21750069], [88.07138824, 22.21777725], [88.07472229, 22.22110939], [88.07472229, 22.22138977], [88.07527924, 22.22194099], [88.07527924, 22.22250748], [88.07555389, 22.22277641], [88.07555389, 22.22305489], [88.07611084, 22.22360992], [88.07611084, 22.2238903], [88.07666779, 22.22444534], [88.07666779, 22.22472191], [88.07888794, 22.22694397], [88.07888794, 22.22721863], [88.07917023, 22.22750282], [88.07917023, 22.22777939], [88.08000183, 22.2286129], [88.08000183, 22.22888947], [88.08110809, 22.22999954], [88.08139038, 22.22999954], [88.08277893, 22.23139], [88.08277893, 22.23167992], [88.08305359, 22.23194313], [88.08304596, 22.2322197], [88.08333588, 22.23250008], [88.08333588, 22.23278046], [88.08361053, 22.23305321], [88.08361053, 22.23333359], [88.08389282, 22.23361015], [88.08389282, 22.23389053], [88.08444214, 22.23444366], [88.08444214, 22.23472023], [88.0847168, 22.23500061], [88.0847168, 22.23528099], [88.08499908, 22.23555946], [88.08499908, 22.23611069], [88.08528137, 22.23639107], [88.08499908, 22.23666573], [88.08528137, 22.2369442], [88.08528137, 22.23722267], [88.08555603, 22.23749733], [88.08555603, 22.23833084], [88.08583069, 22.23861122], [88.08583069, 22.23944473], [88.08611298, 22.23971939], [88.08611298, 22.24000168], [88.08638763, 22.24027824], [88.08611298, 22.24055481], [88.08611298, 22.24083328], [88.08638763, 22.24111176], [88.08638763, 22.24139023], [88.08695221, 22.2419529], [88.08694458, 22.24305534], [88.08721924, 22.24333382], [88.08721924, 22.24444389], [88.08750153, 22.24472046], [88.08750153, 22.24555588], [88.08777618, 22.24583054], [88.08777618, 22.24638939], [88.08805847, 22.24666405], [88.08805847, 22.24722099], [88.08833313, 22.24749947], [88.08833313, 22.25139046], [88.08805847, 22.25166893], [88.08805847, 22.25222206], [88.08833313, 22.25248909], [88.08833313, 22.25278091], [88.08860779, 22.25305557], [88.08833313, 22.25332832], [88.08833313, 22.25361061], [88.08805847, 22.2538929], [88.08805847, 22.25416756], [88.08777618, 22.25444412], [88.08777618, 22.2547226], [88.08750153, 22.25444412], [88.08721924, 22.2547226], [88.08721924, 22.25499916], [88.08805847, 22.25583267], [88.08805847, 22.25611115], [88.08833313, 22.25638962], [88.08833313, 22.25666618], [88.08860779, 22.25694275], [88.08860779, 22.26278114], [88.08889008, 22.26305771], [88.08889008, 22.26333046], [88.0891571, 22.26361084], [88.08916473, 22.26388741], [88.08972168, 22.264431], [88.08972168, 22.26499748], [88.08998871, 22.26555824], [88.08998871, 22.26639175], [88.09027863, 22.26666641], [88.09027863, 22.26694489], [88.09055328, 22.26722145], [88.09055328, 22.26750183], [88.09111023, 22.26805496], [88.09111023, 22.26833344], [88.09139252, 22.26861191], [88.09139252, 22.26944351], [88.09166718, 22.26972008], [88.09166718, 22.27027702], [88.09221649, 22.27083015], [88.09221649, 22.27111053], [88.09278107, 22.27166748], [88.09278107, 22.27222061], [88.0930481, 22.27250099], [88.09305573, 22.27277756], [88.09361267, 22.27333069], [88.09361267, 22.27362061], [88.09500122, 22.27499962], [88.09500122, 22.27527618], [88.09527588, 22.27555466], [88.09527588, 22.27583313], [88.09555817, 22.2761097], [88.09555817, 22.27694511], [88.09612274, 22.27749825], [88.09612274, 22.27778053], [88.09889221, 22.28055573], [88.09889221, 22.28083229], [88.09972382, 22.2816658], [88.09972382, 22.28194427], [88.09999847, 22.28222275], [88.09999847, 22.28279114], [88.10028076, 22.28305626], [88.10028076, 22.28333282], [88.10055542, 22.2836113], [88.10056305, 22.28388977], [88.10083008, 22.28416634], [88.10083008, 22.28444481], [88.10111237, 22.28471947], [88.10111237, 22.28499985], [88.10138702, 22.28527832], [88.10138702, 22.28555489], [88.10192871, 22.28610992], [88.10192871, 22.2863903], [88.10221863, 22.28666687], [88.10221863, 22.28722], [88.1027832, 22.28778076], [88.10277557, 22.28805542], [88.10305786, 22.28833008], [88.10305786, 22.2891655], [88.10277557, 22.28944397], [88.1027832, 22.28972054], [88.10360718, 22.29055977], [88.10360718, 22.29110909], [88.10388947, 22.29138756], [88.10388947, 22.29249763], [88.10416412, 22.29277992], [88.10415649, 22.29361153], [88.10444641, 22.29389191], [88.10444641, 22.29500008], [88.10472107, 22.29528046], [88.10472107, 22.29556274], [88.10388947, 22.29639053], [88.10416412, 22.2966671], [88.10415649, 22.29693985], [88.1049881, 22.29779053], [88.10472107, 22.29805946], [88.10472107, 22.29916573], [88.10527802, 22.29972267], [88.10527802, 22.30083084], [88.1049881, 22.30111122], [88.1049881, 22.30138969], [88.10472107, 22.30167007], [88.10472107, 22.30389023], [88.1049881, 22.30417061], [88.10500336, 22.30469894], [88.10317993, 22.3038578], [88.10279846, 22.30368233], [88.10136414, 22.30314636], [88.09877777, 22.30233955], [88.09519196, 22.30233955], [88.092453, 22.30233955], [88.09015656, 22.3026104], [88.08870697, 22.3031311], [88.08860779, 22.30249977], [88.08750153, 22.30056], [88.08750153, 22.30000114], [88.08721924, 22.29972076], [88.08721924, 22.29916573], [88.08695221, 22.29889107], [88.08695221, 22.29861069], [88.08666992, 22.29833221], [88.08666992, 22.29805565], [88.08638763, 22.29779053], [88.08638763, 22.29750061], [88.08611298, 22.29722023], [88.08611298, 22.2966671], [88.08555603, 22.29611015], [88.08555603, 22.29583359], [88.08444214, 22.2947216], [88.08444214, 22.29445267], [88.08361053, 22.2930603], [88.08333588, 22.29278183], [88.08333588, 22.29249763], [88.08304596, 22.29221916], [88.08305359, 22.2919445], [88.08277893, 22.29166794], [88.08277893, 22.29110909], [88.08222198, 22.29055977], [88.08222198, 22.29027939], [88.08139038, 22.28944016], [88.08139038, 22.28861046], [88.08055878, 22.28777695], [88.08055878, 22.28750038], [88.07971954, 22.28667068], [88.07971954, 22.2863903], [88.07943726, 22.28610992], [88.07944489, 22.28583336], [88.07917023, 22.28555489], [88.07917023, 22.28527832], [88.07861328, 22.28417015], [88.07861328, 22.28306007], [88.07888794, 22.28279114], [88.07888794, 22.28222275], [88.07861328, 22.28194427], [88.07861328, 22.2816658], [88.07833099, 22.28139114], [88.07833099, 22.28055954], [88.07804871, 22.28027916], [88.07775879, 22.27860832], [88.07775879, 22.27832985], [88.07749939, 22.27805519], [88.07749939, 22.27721977], [88.07722473, 22.27694511], [88.0772171, 22.27638817], [88.07666779, 22.27583122], [88.07666779, 22.27527618], [88.07694244, 22.27499962], [88.07666779, 22.27472115], [88.07666779, 22.27361107], [88.07639313, 22.27333069], [88.0763855, 22.27222252], [88.07611084, 22.27194595], [88.07611084, 22.26944351], [88.07583618, 22.26916695], [88.07583618, 22.26889038], [88.07611084, 22.26861191], [88.07611084, 22.26805496], [88.07583618, 22.2677803], [88.07611084, 22.26750183], [88.07611084, 22.26499748], [88.07583618, 22.26472092], [88.07583618, 22.26333427], [88.07611084, 22.26305771], [88.07583618, 22.26278114], [88.07583618, 22.26250076], [88.07611084, 22.26222038], [88.07583618, 22.26194382], [88.07611084, 22.26166534], [88.07611084, 22.26139069], [88.07583618, 22.26111031], [88.07583618, 22.26056099], [88.07554626, 22.26028061], [88.07554626, 22.25971985], [88.07527924, 22.25944328], [88.07527924, 22.25917053], [88.07501221, 22.25889015], [88.07501221, 22.25805283], [88.07472229, 22.25777817], [88.07472229, 22.25694275], [88.07555389, 22.25611115], [88.07554626, 22.25583267], [88.07444763, 22.2547226], [88.07444763, 22.25444412], [88.07472229, 22.25416756], [88.07501221, 22.25416946], [88.07527924, 22.2538929], [88.07527924, 22.25278091], [88.07501221, 22.25248909], [88.07499695, 22.25222206], [88.07472229, 22.25194359], [88.07472229, 22.25166893], [88.07444763, 22.25139046], [88.07444763, 22.25110817], [88.07416534, 22.25083351], [88.07416534, 22.25055504], [88.07389069, 22.25028038], [88.07389069, 22.24999809], [88.0736084, 22.24971962], [88.0736084, 22.24944687], [88.07332611, 22.2491703], [88.07332611, 22.24888992], [88.07277679, 22.24833107], [88.07277679, 22.24805832], [88.07221985, 22.24749947], [88.07221985, 22.24722099], [88.0716629, 22.24666405], [88.0716629, 22.24638939], [88.07138824, 22.24611092], [88.07138824, 22.24583054], [88.07055664, 22.24500084], [88.07055664, 22.24472046], [88.06916809, 22.24333382], [88.06916809, 22.24305534], [88.06887817, 22.24278069], [88.06887817, 22.24222183], [88.06833649, 22.24166679], [88.06804657, 22.24167061], [88.0672226, 22.24082947], [88.0672226, 22.24055481], [88.06666565, 22.24000168], [88.06666565, 22.23971939], [88.0661087, 22.23916626], [88.06581879, 22.23833084], [88.0652771, 22.23749733], [88.06500244, 22.23722267], [88.06472015, 22.23638725], [88.06472015, 22.23611069], [88.06360626, 22.23500061], [88.0633316, 22.23500061], [88.0627594, 22.23444939], [88.0616684, 22.23278046], [88.06138611, 22.23278046], [88.06111145, 22.23250008], [88.06083679, 22.2322197], [88.0605545, 22.2322216], [88.0577774, 22.2294445], [88.0577774, 22.22916603], [88.05249786, 22.2238903], [88.05222321, 22.2238903], [88.0513916, 22.22305107], [88.0513916, 22.22277641], [88.05110931, 22.22250748], [88.05110931, 22.22221947], [88.05055237, 22.22166634], [88.04944611, 22.22027969], [88.04915619, 22.22000122], [88.04860687, 22.22000122], [88.04833221, 22.21972084], [88.04722595, 22.21972084], [88.04693604, 22.22000122], [88.04641724, 22.22000122], [88.04611206, 22.22000122], [88.04582977, 22.22027969], [88.04499817, 22.22027969], [88.04471588, 22.22056007], [88.04444122, 22.22055435], [88.04416656, 22.22083282], [88.04389191, 22.22083282], [88.04360962, 22.2211113], [88.04250336, 22.22110939], [88.04222107, 22.22138977], [88.04083252, 22.22138977], [88.04055786, 22.22167015], [88.0402832, 22.22167015], [88.04000092, 22.22138977], [88.03778076, 22.22138977], [88.03749847, 22.22110939], [88.0358429, 22.22110939], [88.03555298, 22.22138977], [88.0341568, 22.22138977], [88.03388977, 22.22167015], [88.03333282, 22.22166634], [88.03305817, 22.22194481], [88.03277588, 22.22194481], [88.03263855, 22.22180557], [88.03250122, 22.22166634], [88.03055573, 22.22166634], [88.03028107, 22.22194481], [88.02777863, 22.22194481], [88.02749634, 22.22222137], [88.02693939, 22.22221947], [88.02664948, 22.22250748], [88.02610779, 22.22249985], [88.02278137, 22.22583389], [88.02249908, 22.22582817], [88.0222168, 22.22610855], [88.02194214, 22.22610855], [88.02166748, 22.22639084], [88.02139282, 22.22639084], [88.02111053, 22.22666931], [88.02027893, 22.2266674], [88.01999664, 22.22694397], [88.01889038, 22.22694397], [88.01860809, 22.22722244], [88.01832581, 22.22721863], [88.01805878, 22.22750282], [88.01750183, 22.22750282], [88.01721954, 22.22777939], [88.01693726, 22.22777939], [88.01667023, 22.22805977], [88.01611328, 22.22805595], [88.01583099, 22.22833252], [88.01526642, 22.22831917], [88.01499939, 22.2286129], [88.01470947, 22.2286129], [88.01416779, 22.22916985], [88.0138855, 22.22916603], [88.01361084, 22.2294445], [88.01305389, 22.2294445], [88.01277924, 22.22972107], [88.01249695, 22.22972107], [88.01222229, 22.22999954], [88.01196289, 22.22999954], [88.01167297, 22.23027992], [88.0111084, 22.23027992], [88.01082611, 22.2305603], [88.01055908, 22.23055649], [88.01027679, 22.23083305], [88.00971985, 22.23083115], [88.0091629, 22.23139], [88.00889587, 22.23139], [88.00860596, 22.23167992], [88.00805664, 22.23167992], [88.00776672, 22.23195076], [88.00749969, 22.23194313], [88.00722504, 22.2322216], [88.00694275, 22.2322197], [88.00666809, 22.23250008], [88.0063858, 22.23250008], [88.00611115, 22.23278046], [88.00582886, 22.23278046], [88.00553894, 22.23306084], [88.00527954, 22.23305321], [88.00444794, 22.23332977], [88.00389099, 22.23389053], [88.0036087, 22.23389053], [88.00332642, 22.23417091], [88.00305176, 22.23417091], [88.00276947, 22.23444939], [88.00222015, 22.23444939], [88.00166321, 22.23500061], [88.00110626, 22.23500061], [88.0008316, 22.23528099], [88.0, 22.23555565], [87.99926758, 22.23570824], [87.99622345, 22.23748016], [87.99584198, 22.23771095], [87.99388123, 22.23879051], [87.99356842, 22.23908806], [87.99327087, 22.23935127], [87.99291229, 22.23960114], [87.99254608, 22.23987961], [87.99209595, 22.24006081], [87.99172211, 22.24028969], [87.99137115, 22.24054909], [87.99105835, 22.24081039], [87.9907608, 22.24103928], [87.99044037, 22.2412281], [87.99008942, 22.24143982], [87.98976135, 22.24171829], [87.98944855, 22.24205971], [87.98912811, 22.2424202], [87.98879242, 22.24273109], [87.98842621, 22.24296761], [87.98804474, 22.24321175], [87.98766327, 22.24344826], [87.9872818, 22.24369812], [87.98695374, 22.24399376], [87.98664856, 22.24431992], [87.98629761, 22.24465561], [87.98584747, 22.24498177], [87.98534393, 22.24532318], [87.98486328, 22.24570084], [87.98443604, 22.24609756], [87.98404694, 22.24646378], [87.98377991, 22.24687004], [87.98351288, 22.24723053], [87.98326874, 22.24757004], [87.98301697, 22.24793053], [87.98269653, 22.24828529], [87.98221588, 22.24860954], [87.98249817, 22.24888611], [87.98027802, 22.25110817], [87.98027802, 22.25139046], [87.97944641, 22.25221825], [87.97943115, 22.25234795], [87.97910309, 22.25272942], [87.97873688, 22.2530899], [87.9784317, 22.25349045], [87.97817993, 22.2538929], [87.97792816, 22.2542572], [87.97763824, 22.25450134], [87.97742462, 22.25483131], [87.97724152, 22.25522232], [87.97697449, 22.25554466], [87.97685242, 22.25573158], [87.97673798, 22.25591087], [87.9765625, 22.25632286], [87.97634125, 22.25665665], [87.97610474, 22.2569828], [87.97583771, 22.25733185], [87.97559357, 22.25777245], [87.97531891, 22.25827408], [87.97498322, 22.25880051], [87.97465515, 22.25935173], [87.97416687, 22.25971985], [87.97389221, 22.26000023], [87.97416687, 22.26028061], [87.97416687, 22.26055527], [87.97389221, 22.26082993], [87.97389221, 22.26111031], [87.97249603, 22.26250076], [87.97249603, 22.26278114], [87.97138977, 22.26389122], [87.97166443, 22.26416588], [87.97092438, 22.26491165], [87.97055817, 22.26527977], [87.9704361, 22.26522255], [87.9701767, 22.26567078], [87.96993256, 22.26613617], [87.96953583, 22.26644325], [87.9691925, 22.26679039], [87.96891785, 22.2672081], [87.96871185, 22.26768875], [87.96849823, 22.26814079], [87.96819305, 22.26852036], [87.96792603, 22.26898956], [87.96755219, 22.26943016], [87.9672699, 22.26992989], [87.96694946, 22.27036095], [87.96669006, 22.2707901], [87.96640778, 22.27116966], [87.96619415, 22.2715683], [87.96598816, 22.27197075], [87.96580505, 22.27242851], [87.96556091, 22.27286339], [87.96528625, 22.27330971], [87.9650116, 22.27374077], [87.96475983, 22.27414894], [87.96450806, 22.27449989], [87.96427917, 22.2748909], [87.9640274, 22.27526093], [87.96369171, 22.27561951], [87.96338654, 22.27604103], [87.96305847, 22.27638817], [87.96273041, 22.27669907], [87.96235657, 22.27695084], [87.96199799, 22.27727127], [87.96170044, 22.27763748], [87.96148682, 22.27808189], [87.96131897, 22.27852058], [87.96108246, 22.27886963], [87.96083069, 22.2791996], [87.96055603, 22.27952957], [87.96028137, 22.27988052], [87.96004486, 22.28022194], [87.95993805, 22.28063965], [87.9598465, 22.28108025], [87.9597168, 22.2814312], [87.95959473, 22.2817688], [87.95946503, 22.28215027], [87.9593811, 22.28259087], [87.95921326, 22.28308105], [87.95909119, 22.28364944], [87.95889282, 22.28416061], [87.95868683, 22.28466988], [87.95861816, 22.28519821], [87.95861053, 22.2857132], [87.95864868, 22.28619385], [87.95877075, 22.28659058], [87.9588089, 22.28693008], [87.95864868, 22.28729057], [87.95864868, 22.28775024], [87.95867157, 22.28829193], [87.95887756, 22.28881454], [87.95909882, 22.28937149], [87.9593277, 22.28991127], [87.95946503, 22.29048729], [87.95963287, 22.29104805], [87.95970917, 22.29169273], [87.9597702, 22.29232979], [87.95993805, 22.29294586], [87.95988464, 22.29356384], [87.95974731, 22.29412079], [87.95975494, 22.29458618], [87.9598999, 22.29491425], [87.9599762, 22.29521179], [87.95999908, 22.29552078], [87.95999908, 22.29586029], [87.96000671, 22.29627037], [87.96005249, 22.29675674], [87.96019745, 22.29724312], [87.96009827, 22.29770279], [87.96000671, 22.29817009], [87.95999908, 22.29863548], [87.95999908, 22.29911041], [87.96002197, 22.29963112], [87.96015167, 22.30015945], [87.96029663, 22.30070114], [87.96051025, 22.30118942], [87.96055603, 22.30167007], [87.96055603, 22.30212975], [87.96055603, 22.30254936], [87.96055603, 22.30295372], [87.96055603, 22.30334854], [87.96055603, 22.30376053], [87.96055603, 22.30416107], [87.96055603, 22.30455971], [87.96050262, 22.30492973], [87.96039581, 22.30528069], [87.96029663, 22.30565071], [87.96024323, 22.3060894], [87.96008301, 22.30648994], [87.96000671, 22.3069706], [87.95995331, 22.30747986], [87.95976257, 22.30793953], [87.95966339, 22.30844116], [87.9594574, 22.30888176], [87.95928192, 22.30932999], [87.95910645, 22.30977058], [87.95888519, 22.31015205], [87.95867157, 22.31052971], [87.95857239, 22.31099892], [87.95839691, 22.31143951], [87.95835876, 22.31190109], [87.95825958, 22.31228065], [87.95809174, 22.31265068], [87.95804596, 22.31307983], [87.95802307, 22.31349754], [87.95786285, 22.31381989], [87.95777893, 22.31412125], [87.95775604, 22.31442642], [87.95765686, 22.31472015], [87.95752716, 22.31508064], [87.95746613, 22.31555557], [87.95730591, 22.31606293], [87.95722961, 22.31662941], [87.95722198, 22.31720734], [87.95722961, 22.31776047], [87.95730591, 22.31833076], [87.95742035, 22.31894112], [87.95749664, 22.31958961], [87.95750427, 22.32023811], [87.95749664, 22.32082939], [87.95750427, 22.32133675], [87.95752716, 22.32177162], [87.95762634, 22.32216454], [87.95773315, 22.32258034], [87.95775604, 22.32302094], [87.95771027, 22.32345963], [87.95774078, 22.323843], [87.95774841, 22.32417488], [87.95761871, 22.32446289], [87.95751953, 22.32477188], [87.95749664, 22.32514572], [87.95744324, 22.32557106], [87.95730591, 22.32602119], [87.9574585, 22.32653046], [87.95765686, 22.32707977], [87.95763397, 22.32762337], [87.95752716, 22.32809258], [87.9574585, 22.32851028], [87.95729828, 22.32883835], [87.95722961, 22.32920265], [87.95722198, 22.32957077], [87.95722198, 22.3299408], [87.95722198, 22.33029938], [87.95722198, 22.33065987], [87.95722198, 22.33103943], [87.95722198, 22.33145714], [87.95726013, 22.33191109], [87.95743561, 22.33240509], [87.95749664, 22.33299446], [87.95750427, 22.33362389], [87.95750427, 22.33424187], [87.95749664, 22.33481979], [87.95749664, 22.33535957], [87.95749664, 22.33586121], [87.95754242, 22.33634758], [87.95773315, 22.33681488], [87.95777893, 22.3373394], [87.95777893, 22.33790016], [87.95777893, 22.33846664], [87.95777893, 22.33905029], [87.95777893, 22.33966064], [87.95780182, 22.340271], [87.95791626, 22.34083748], [87.9580307, 22.34130287], [87.95804596, 22.34173012], [87.95806122, 22.34216118], [87.95808411, 22.34261703], [87.95819092, 22.34305954], [87.95830536, 22.34352684], [87.95833588, 22.34400558], [87.95833588, 22.34445953], [87.95833588, 22.34489059], [87.95833588, 22.34528542], [87.95832062, 22.34564972], [87.95825958, 22.34600067], [87.95810699, 22.34631538], [87.95806122, 22.34667969], [87.95806885, 22.34709167], [87.95819855, 22.34750175], [87.95831299, 22.34791183], [87.95833588, 22.34830475], [87.95832062, 22.34869003], [87.95824432, 22.34908867], [87.95809174, 22.34951019], [87.95806122, 22.34999275], [87.95804596, 22.3504715], [87.95800018, 22.35091972], [87.95783234, 22.35137177], [87.95777893, 22.35181046], [87.95775604, 22.35222054], [87.95765686, 22.35259056], [87.95756531, 22.35292625], [87.95768738, 22.3532505], [87.95776367, 22.3535881], [87.95776367, 22.35391426], [87.95767975, 22.35424805], [87.95752716, 22.35462952], [87.95749664, 22.35508919], [87.95749664, 22.35557938], [87.95749664, 22.35608292], [87.95750427, 22.35659981], [87.95749664, 22.35713005], [87.9574585, 22.35766983], [87.95731354, 22.35811806], [87.95722961, 22.35857964], [87.95717621, 22.35905075], [87.95703888, 22.35948944], [87.9569931, 22.35995293], [87.95709229, 22.36044121], [87.95713806, 22.36091995], [87.95691681, 22.3614006], [87.95665741, 22.36189079], [87.95639038, 22.36234856], [87.95615387, 22.36281967], [87.95610046, 22.36340141], [87.95600891, 22.3639698], [87.95585632, 22.3644886], [87.95583344, 22.36497879], [87.95582581, 22.36540985], [87.95583344, 22.36577988], [87.95581055, 22.36609268], [87.95569611, 22.36637115], [87.95558167, 22.36664009], [87.95555878, 22.36696815], [87.95555115, 22.36734962], [87.95555878, 22.36777115], [87.95555878, 22.36824036], [87.95555878, 22.36874008], [87.95555115, 22.36925507], [87.955513, 22.36976051], [87.95535278, 22.3702507], [87.95526123, 22.37075806], [87.9551239, 22.37126541], [87.95495605, 22.37176132], [87.95465088, 22.37212944], [87.95426941, 22.3724308], [87.95398712, 22.37286949], [87.95385742, 22.37341118], [87.95365143, 22.37393188], [87.95359039, 22.37452126], [87.95349884, 22.37508392], [87.95332336, 22.37556267], [87.95314026, 22.37596703], [87.95300293, 22.37627983], [87.95281982, 22.37653542], [87.95271301, 22.37684059], [87.95252991, 22.37718964], [87.95236206, 22.37758064], [87.95220184, 22.37796783], [87.95201111, 22.37833023], [87.95181274, 22.37870979], [87.95157623, 22.37919044], [87.95137024, 22.37973022], [87.95115662, 22.38027954], [87.95107269, 22.38083076], [87.95088196, 22.38132095], [87.950737, 22.38187027], [87.95053864, 22.38234901], [87.95033264, 22.382761], [87.95027161, 22.38320732], [87.95022583, 22.38360023], [87.95004272, 22.38391113], [87.94999695, 22.38426018], [87.94998169, 22.38466072], [87.94989777, 22.38509369], [87.94975281, 22.38553047], [87.94967651, 22.38599968], [87.9495163, 22.38635063], [87.94941711, 22.38676071], [87.94924164, 22.38718987], [87.94917297, 22.38774109], [87.94911957, 22.38833809], [87.94893646, 22.38886261], [87.94893646, 22.38937187], [87.94917297, 22.38944054], [87.94916534, 22.39027786], [87.9486084, 22.39083481], [87.94889069, 22.39110947], [87.94889069, 22.39138985], [87.94916534, 22.39166641], [87.94916534, 22.39194489], [87.94889069, 22.39221954], [87.94889069, 22.39500046], [87.94861603, 22.39528084], [87.9486084, 22.3955555], [87.94889069, 22.39583015], [87.94889069, 22.39639091], [87.94916534, 22.39666939], [87.94916534, 22.39944458], [87.9486084, 22.40000153], [87.94805908, 22.40000153], [87.94750214, 22.40055466], [87.94750214, 22.40083313], [87.94721985, 22.4011116], [87.94721985, 22.40194511], [87.94694519, 22.40222168], [87.94695282, 22.40332985], [87.9466629, 22.40361023], [87.9466629, 22.40389061], [87.94694519, 22.40416718], [87.94695282, 22.40472031], [87.9466629, 22.40500069], [87.9466629, 22.40528107], [87.94638824, 22.40555573], [87.94638824, 22.40583038], [87.94619751, 22.40602493], [87.94610596, 22.4061203], [87.94638824, 22.40611076], [87.94555664, 22.40694427], [87.94527435, 22.4066658], [87.94499969, 22.40666962], [87.94444275, 22.40611076], [87.94361115, 22.40694427], [87.94248962, 22.40694046], [87.94194794, 22.40750122], [87.94194794, 22.40777969], [87.94166565, 22.40805435], [87.94167328, 22.40860939], [87.94139099, 22.40888977], [87.9411087, 22.40888977], [87.94082642, 22.40917969], [87.9402771, 22.40916634], [87.94000244, 22.40944481], [87.93972015, 22.40944481], [87.9394455, 22.40972137], [87.9394455, 22.40999985], [87.93722534, 22.41221809], [87.93611145, 22.41333389], [87.93583679, 22.41305542], [87.93499756, 22.41305923], [87.93444824, 22.41360855], [87.93444824, 22.41389084], [87.93360901, 22.41472244], [87.93333435, 22.41472244], [87.93305206, 22.41500282], [87.9327774, 22.41499138], [87.93138885, 22.41638947], [87.93138885, 22.41666985], [87.93054962, 22.41749954], [87.9302597, 22.41749954], [87.92749023, 22.42028046], [87.92749786, 22.42055511], [87.92722321, 22.42082977], [87.92722321, 22.42111969], [87.92694092, 22.42138863], [87.92694092, 22.42194366], [87.92666626, 22.42222214], [87.92666626, 22.4244442], [87.9263916, 22.42472076], [87.9263916, 22.42610931], [87.92666626, 22.4263916], [87.92666626, 22.42750168], [87.9263916, 22.42777824], [87.9263916, 22.42805481], [87.92666626, 22.42833328], [87.92666626, 22.42861176], [87.92694092, 22.42889023], [87.92694092, 22.42917061], [87.92666626, 22.42944527], [87.92666626, 22.42972183], [87.9263916, 22.43000031], [87.9263916, 22.43029022], [87.92610931, 22.43055534], [87.92610931, 22.43083191], [87.92582703, 22.43111038], [87.92583466, 22.43166733], [87.92555237, 22.43194389], [87.92555237, 22.43222046], [87.92527771, 22.43250084], [87.92527771, 22.43278122], [87.92500305, 22.43305588], [87.92500305, 22.43333054], [87.92333221, 22.43499947], [87.92305756, 22.43472099], [87.92193604, 22.43527985], [87.92138672, 22.43527985], [87.92111206, 22.43556023], [87.92028046, 22.43556023], [87.91999817, 22.43527985], [87.9183197, 22.43527985], [87.91805267, 22.43499947], [87.91583252, 22.43499947], [87.91555023, 22.43472099], [87.91471863, 22.43472099], [87.91444397, 22.43499947], [87.91410828, 22.43500137], [87.91370392, 22.43500137], [87.91330719, 22.43502426], [87.91291809, 22.43513107], [87.91252899, 22.43521118], [87.91210938, 22.43503952], [87.91163635, 22.43500137], [87.91113281, 22.43499756], [87.91062927, 22.43499947], [87.91014862, 22.43499947], [87.90972137, 22.43499947], [87.90936279, 22.43499947], [87.90906525, 22.43499947], [87.90878296, 22.43500328], [87.90847778, 22.43505287], [87.90817261, 22.43522072], [87.90776825, 22.43527222], [87.90731812, 22.43527985], [87.90688324, 22.43532944], [87.90645599, 22.43550682], [87.90598297, 22.43555069], [87.90545654, 22.43556023], [87.904953, 22.43556023], [87.90444946, 22.43551064], [87.90406036, 22.43531036], [87.90368652, 22.43521118], [87.90338898, 22.43507957], [87.90306854, 22.43501282], [87.90267944, 22.43500137], [87.90222168, 22.43499947], [87.90171814, 22.43495941], [87.9012146, 22.43478584], [87.90061188, 22.43472672], [87.89996338, 22.4347229], [87.89927673, 22.43476105], [87.89862061, 22.43492126], [87.89795685, 22.43482971], [87.89743042, 22.43465805], [87.8969574, 22.4344902], [87.89650726, 22.43441772], [87.89612579, 22.43433952], [87.8957901, 22.43441391], [87.89544678, 22.43444061], [87.89509583, 22.4344902], [87.89476776, 22.43463707], [87.89435577, 22.43470955], [87.89392853, 22.43478012], [87.89359283, 22.43497276], [87.89322662, 22.43511963], [87.89286804, 22.4352951], [87.89251709, 22.43551254], [87.8921051, 22.43568993], [87.891716, 22.43589973], [87.8913269, 22.43616104], [87.89092255, 22.43638992], [87.89048004, 22.43657875], [87.88999176, 22.43670464], [87.88957977, 22.43694115], [87.88918304, 22.43719292], [87.88874817, 22.43737602], [87.88835144, 22.4375782], [87.88800049, 22.43774986], [87.88777924, 22.43777657], [87.88471985, 22.43951225], [87.88411713, 22.44017982], [87.88389587, 22.44091988], [87.88376617, 22.44158936], [87.8833313, 22.44082832], [87.8833313, 22.44055557], [87.88249969, 22.43971825], [87.88249969, 22.43944359], [87.8813858, 22.43833351], [87.88111115, 22.43833351], [87.88083649, 22.43805504], [87.88500977, 22.43433952], [87.88528442, 22.43395996], [87.88558197, 22.43357086], [87.88587189, 22.43317032], [87.88618469, 22.43283653], [87.88648987, 22.4324894], [87.88677216, 22.43210983], [87.8870697, 22.43170929], [87.88742828, 22.43135071], [87.88777161, 22.43094063], [87.88807678, 22.43049049], [87.8883667, 22.43000031], [87.88866425, 22.42951584], [87.88897705, 22.42906952], [87.88931274, 22.42865944], [87.88967896, 22.42834282], [87.89111328, 22.42692947], [87.89389038, 22.42416573], [87.89416504, 22.42416573], [87.89472198, 22.42361069], [87.89499664, 22.42361069], [87.89554596, 22.42305946], [87.89583588, 22.42305946], [87.89639282, 22.42250061], [87.89694214, 22.42250061], [87.8972168, 22.42222023], [87.89778137, 22.42222214], [87.89805603, 22.42194366], [87.89833069, 22.42194366], [87.89861298, 22.42166519], [87.89971924, 22.42167091], [87.90000153, 22.42139053], [87.90305328, 22.42138863], [87.90315247, 22.4214859], [87.9033432, 22.42167091], [87.90805817, 22.42166519], [87.90833282, 22.42194366], [87.90916443, 22.42194366], [87.90944672, 22.42222214], [87.91000366, 22.42222214], [87.91027832, 22.42194366], [87.91055298, 22.42194366], [87.91083527, 22.42222214], [87.91166687, 22.42194366], [87.91194153, 22.42166519], [87.9125061, 22.42167091], [87.91361237, 22.42056084], [87.91388702, 22.42028046], [87.91388702, 22.42000008], [87.91471863, 22.41917038], [87.91471863, 22.41889], [87.91500092, 22.41860962], [87.91500092, 22.41833305], [87.91593933, 22.41739082], [87.91666412, 22.41666603], [87.91665649, 22.41638947], [87.91694641, 22.4161129], [87.91694641, 22.41583252], [87.91750336, 22.41527748], [87.91777802, 22.41527939], [87.91944122, 22.41360855], [87.91971588, 22.41360855], [87.92028046, 22.41305923], [87.92056274, 22.41305923], [87.92305756, 22.41055107], [87.92305756, 22.41027641], [87.92333221, 22.40999985], [87.92333221, 22.40971947], [87.9236145, 22.40944481], [87.9236145, 22.40916634], [87.92472076, 22.40806007], [87.92472076, 22.40777969], [87.92500305, 22.40750122], [87.92555237, 22.40722084], [87.92555237, 22.40694427], [87.92583466, 22.4066658], [87.92610931, 22.40666962], [87.92722321, 22.40555954], [87.92749023, 22.40555954], [87.9283371, 22.40472031], [87.92861176, 22.40472221], [87.92972565, 22.40361023], [87.92972565, 22.40305519], [87.93000031, 22.40277863], [87.93000031, 22.40250015], [87.93028259, 22.40222168], [87.93027496, 22.40138817], [87.93054962, 22.4011116], [87.93055725, 22.40055466], [87.93083191, 22.40027809], [87.93083191, 22.39998817], [87.9311142, 22.39972305], [87.9311142, 22.39860916], [87.93138885, 22.39833069], [87.93138885, 22.39777946], [87.93165588, 22.39749908], [87.93138885, 22.39722061], [87.93138885, 22.39694405], [87.93165588, 22.39666939], [87.93165588, 22.39611053], [87.9319458, 22.39583015], [87.9319458, 22.39500046], [87.93222046, 22.39472008], [87.93222046, 22.39388847], [87.93305206, 22.39249992], [87.93305206, 22.39221954], [87.93333435, 22.39194489], [87.93333435, 22.39138794], [87.93361664, 22.39110947], [87.93360901, 22.39027786], [87.9338913, 22.38999939], [87.9338913, 22.38944054], [87.93416595, 22.38916588], [87.93416595, 22.38889122], [87.93444824, 22.38861275], [87.93444824, 22.38778114], [87.9347229, 22.38750267], [87.9347229, 22.3869381], [87.93444824, 22.38666725], [87.93444824, 22.38639069], [87.9347229, 22.3861084], [87.9347229, 22.38582993], [87.93499756, 22.38555527], [87.93527985, 22.38555908], [87.93611145, 22.38471985], [87.93611145, 22.38388634], [87.93638611, 22.38360977], [87.93638611, 22.38333321], [87.9366684, 22.38305473], [87.9366684, 22.38249969], [87.93694305, 22.38222313], [87.93694305, 22.38166618], [87.93723297, 22.38138962], [87.93722534, 22.38083267], [87.9375, 22.3805542], [87.9375, 22.38000107], [87.93776703, 22.37972069], [87.93777466, 22.37833214], [87.93805695, 22.37805557], [87.93805695, 22.37750053], [87.9383316, 22.37722015], [87.9383316, 22.37638855], [87.93860626, 22.37611008], [87.93861389, 22.37583351], [87.93888855, 22.37555504], [87.93888855, 22.3741703], [87.93916321, 22.37389183], [87.93916321, 22.37332916], [87.9394455, 22.37305641], [87.93945313, 22.37249756], [87.93972015, 22.3722229], [87.93972015, 22.37194443], [87.94000244, 22.37166595], [87.94000244, 22.37138748], [87.9402771, 22.37111092], [87.9402771, 22.37083054], [87.94055176, 22.37055779], [87.94055176, 22.37001038], [87.94082642, 22.36972046], [87.94083405, 22.36944389], [87.9411087, 22.36916542], [87.9411087, 22.36889076], [87.94139099, 22.36861038], [87.94139099, 22.36833], [87.94152832, 22.36819077], [87.94166565, 22.36805534], [87.94166565, 22.36772919], [87.94166565, 22.36750031], [87.9417572, 22.36741066], [87.94194794, 22.36722183], [87.94194794, 22.36666679], [87.9422226, 22.36638832], [87.9422226, 22.36581993], [87.9422226, 22.36555481], [87.94233704, 22.36544037], [87.94249725, 22.36527824], [87.94249725, 22.36489105], [87.94249725, 22.3647213], [87.94277954, 22.36444473], [87.94277954, 22.36392021], [87.94277954, 22.36277771], [87.94304657, 22.36250114], [87.94304657, 22.36194038], [87.94249725, 22.36138916], [87.94194794, 22.36139107], [87.94167328, 22.36166954], [87.9402771, 22.36166573], [87.94000244, 22.3619442], [87.9394455, 22.3619442], [87.93888855, 22.36138916], [87.93888855, 22.36111259], [87.94000244, 22.36000061], [87.9402771, 22.36000061], [87.94139099, 22.35889053], [87.94139099, 22.35860825], [87.94166565, 22.35833359], [87.94139099, 22.35805511], [87.94139099, 22.35749817], [87.94194794, 22.35695076], [87.9422226, 22.35695076], [87.94333649, 22.35807037], [87.94361115, 22.35807037], [87.94416809, 22.35749817], [87.94416809, 22.3572197], [87.9438858, 22.35694695], [87.9438858, 22.35610962], [87.94361115, 22.35583305], [87.94361115, 22.35499954], [87.9422226, 22.35361099], [87.94194794, 22.35388947], [87.94139099, 22.35388947], [87.9411087, 22.35416985], [87.94055176, 22.35416412], [87.9402771, 22.3544445], [87.94000244, 22.3544445], [87.93972015, 22.35472107], [87.93972015, 22.35527992], [87.9394455, 22.35527611], [87.93860626, 22.35610962], [87.93860626, 22.35638809], [87.93805695, 22.35695076], [87.93723297, 22.35695076], [87.93667603, 22.35638809], [87.93667603, 22.35610962], [87.93722534, 22.3555584], [87.9375, 22.3555603], [87.93888855, 22.35416985], [87.93888855, 22.35388947], [87.93916321, 22.35361099], [87.93945313, 22.35361099], [87.93972015, 22.35333252], [87.94000244, 22.35333252], [87.9402771, 22.35305405], [87.94082642, 22.35305977], [87.9411087, 22.35277939], [87.94167328, 22.35277939], [87.94194794, 22.35250092], [87.9422226, 22.35250092], [87.94248962, 22.35222054], [87.9438858, 22.35222244], [87.94404602, 22.35206032], [87.94472504, 22.35138893], [87.94473267, 22.35111046], [87.94527435, 22.35055542], [87.9458313, 22.35056114], [87.94610596, 22.35028076], [87.94638824, 22.35028076], [87.94695282, 22.34972191], [87.94611359, 22.3488884], [87.94555664, 22.34888077], [87.94526672, 22.34917068], [87.94499969, 22.34917068], [87.94473267, 22.34888077], [87.94444275, 22.3488884], [87.94416809, 22.34861183], [87.9438858, 22.34861183], [87.94374847, 22.3484726], [87.94361115, 22.34833336], [87.94385529, 22.34808731], [87.94444275, 22.34750175], [87.94444275, 22.34667015], [87.94526672, 22.34584236], [87.94555664, 22.3461113], [87.94638824, 22.3461113], [87.94721985, 22.34694481], [87.94750214, 22.34694481], [87.94805908, 22.34639168], [87.94721985, 22.34555817], [87.94721985, 22.34527969], [87.9458313, 22.34389114], [87.9458313, 22.34361076], [87.94610596, 22.34333038], [87.94611359, 22.34222221], [87.9458313, 22.34194374], [87.9458313, 22.34166527], [87.94610596, 22.34139061], [87.94610596, 22.34111023], [87.94638824, 22.34082985], [87.94638824, 22.34055519], [87.9466629, 22.34028053], [87.9466629, 22.3386097], [87.94694519, 22.33833313], [87.94694519, 22.33805466], [87.9466629, 22.33777809], [87.9466629, 22.33722115], [87.94694519, 22.33694458], [87.94694519, 22.33666611], [87.9466629, 22.33638954], [87.9466629, 22.33527946], [87.94638824, 22.3350029], [87.94695282, 22.33444023], [87.94694519, 22.33389091], [87.94721985, 22.33360863], [87.94721985, 22.33305931], [87.94695282, 22.33278084], [87.94695282, 22.33250046], [87.9466629, 22.33222008], [87.9466629, 22.33166885], [87.94638824, 22.33139038], [87.94638824, 22.33110809], [87.94611359, 22.33083344], [87.94610596, 22.32999992], [87.9458313, 22.32971954], [87.9458313, 22.32805443], [87.94555664, 22.32777023], [87.94555664, 22.32749939], [87.94526672, 22.32722092], [87.94527435, 22.32694435], [87.94499969, 22.32666588], [87.94499969, 22.32611084], [87.94444275, 22.32555962], [87.94444275, 22.32528114], [87.94348907, 22.32432747], [87.9430542, 22.32388878], [87.94277954, 22.32389069], [87.94194031, 22.32305527], [87.9411087, 22.32222176], [87.9411087, 22.32194519], [87.93972015, 22.32055092], [87.9394455, 22.32055473], [87.9383316, 22.31944466], [87.9383316, 22.31916618], [87.93694305, 22.31777954], [87.93694305, 22.31722069], [87.9366684, 22.31694412], [87.93638611, 22.31666946], [87.93611145, 22.31694412], [87.93583679, 22.31722069], [87.93583679, 22.31777954], [87.9355545, 22.31805611], [87.93554688, 22.31833076], [87.93583679, 22.31860924], [87.93583679, 22.31917191], [87.93611145, 22.31916618], [87.9375, 22.32055473], [87.9375, 22.32083321], [87.93777466, 22.32111168], [87.93776703, 22.32222176], [87.93805695, 22.32250023], [87.93805695, 22.32361031], [87.93861389, 22.32416725], [87.93860626, 22.32471275], [87.93888855, 22.32500076], [87.93888855, 22.32639122], [87.93916321, 22.32666969], [87.93916321, 22.32805443], [87.93945313, 22.32833099], [87.9394455, 22.32916641], [87.93972015, 22.32944489], [87.93972015, 22.32971954], [87.94000244, 22.32999992], [87.93945313, 22.33056068], [87.93916321, 22.33056068], [87.93888855, 22.3302803], [87.93860626, 22.3302803], [87.93805695, 22.32971954], [87.93723297, 22.33056068], [87.93694305, 22.33055496], [87.93638611, 22.33111191], [87.9347229, 22.33111191], [87.93360901, 22.33222008], [87.93361664, 22.33250046], [87.93527985, 22.33416748], [87.93527985, 22.33444023], [87.9347229, 22.3350029], [87.93458557, 22.33486176], [87.93444824, 22.33472252], [87.9338913, 22.33472252], [87.93360901, 22.33444405], [87.9327774, 22.33444405], [87.93250275, 22.33416748], [87.93222046, 22.33444405], [87.9319458, 22.33444405], [87.93083191, 22.33333397], [87.93083191, 22.3330555], [87.9338913, 22.32999992], [87.9338913, 22.32971954], [87.93416595, 22.32944489], [87.93416595, 22.32916641], [87.93444824, 22.32888985], [87.93444824, 22.32777023], [87.93527985, 22.32694435], [87.9355545, 22.32694435], [87.93638611, 22.32611084], [87.93638611, 22.32583046], [87.93611145, 22.3255558], [87.93611145, 22.32500076], [87.93583679, 22.32471275], [87.93583679, 22.32333374], [87.93611145, 22.32305527], [87.93611145, 22.32250023], [87.93583679, 22.32222176], [87.93583679, 22.32138824], [87.93554688, 22.32111168], [87.9355545, 22.32083321], [87.93527985, 22.32055473], [87.93527985, 22.3200016], [87.93499756, 22.31971931], [87.93499756, 22.31944466], [87.9347229, 22.31916618], [87.9347229, 22.31833076], [87.93444824, 22.31805611], [87.93444824, 22.31777954], [87.93416595, 22.31750107], [87.93416595, 22.31722069], [87.9338913, 22.31694412], [87.9338913, 22.31555557], [87.93361664, 22.31528091], [87.93361664, 22.31472015], [87.93333435, 22.31444359], [87.93333435, 22.31416512], [87.93305206, 22.31389046], [87.93305206, 22.31138992], [87.93332672, 22.31110954], [87.93305206, 22.31083488], [87.93305206, 22.31027794], [87.9327774, 22.30999947], [87.93361664, 22.30916977], [87.93361664, 22.30861282], [87.9338913, 22.30833244], [87.9338913, 22.30750275], [87.93416595, 22.30721855], [87.93416595, 22.30694389], [87.93444824, 22.30666733], [87.93444824, 22.30582809], [87.9347229, 22.30555534], [87.9347229, 22.30444908], [87.93499756, 22.30417061], [87.93499756, 22.30305099], [87.93527985, 22.30277634], [87.9347229, 22.30221939], [87.93499756, 22.30194473], [87.93499756, 22.30166626], [87.93527985, 22.30138969], [87.93527985, 22.30111122], [87.93499756, 22.30083084], [87.93499756, 22.30055428], [87.93527985, 22.30027962], [87.93527985, 22.30000114], [87.93554688, 22.29972076], [87.9355545, 22.29888916], [87.93583679, 22.29861069], [87.93583679, 22.29722023], [87.9355545, 22.29694366], [87.9355545, 22.2947216], [87.93527985, 22.29445267], [87.93527985, 22.29417038], [87.93554688, 22.29389191], [87.93554688, 22.29332924], [87.93583679, 22.29305649], [87.93583679, 22.29166031], [87.9355545, 22.29138756], [87.93554688, 22.29110909], [87.93583679, 22.29083061], [87.93583679, 22.28944397], [87.9355545, 22.2891655], [87.93554688, 22.28806114], [87.93583679, 22.28778076], [87.93583679, 22.28722], [87.9355545, 22.28694534], [87.93554688, 22.28553963], [87.93583679, 22.28527832], [87.93583679, 22.28499985], [87.93554688, 22.28471947], [87.9355545, 22.28444481], [87.93583679, 22.28416634], [87.93583679, 22.28333282], [87.9355545, 22.28305626], [87.93554688, 22.28222275], [87.93527985, 22.28194427], [87.93527985, 22.2816658], [87.93499756, 22.28139114], [87.93499756, 22.28111267], [87.93583679, 22.28027916], [87.93583679, 22.2797184], [87.93611145, 22.27944374], [87.93611145, 22.27889061], [87.93583679, 22.27860832], [87.93583679, 22.27832985], [87.93611145, 22.27805519], [87.93611145, 22.27583122], [87.93638611, 22.27555466], [87.93638611, 22.27472305], [87.93611145, 22.27444458], [87.93638611, 22.27444458], [87.93638611, 22.2741642], [87.93667603, 22.27388954], [87.9366684, 22.27166748], [87.93694305, 22.27139091], [87.93694305, 22.27000046], [87.93667603, 22.26972008], [87.9366684, 22.26888847], [87.93694305, 22.26861191], [87.93694305, 22.26694489], [87.93722534, 22.26666641], [87.93723297, 22.26611137], [87.9375, 22.2658329], [87.9375, 22.26472282], [87.9383316, 22.26388741], [87.9383316, 22.26361084], [87.93860626, 22.26333046], [87.93861389, 22.26305771], [87.93888855, 22.26278114], [87.93888855, 22.26250076], [87.93945313, 22.26194], [87.9394455, 22.26166534], [87.93972015, 22.26139069], [87.93972015, 22.26111031], [87.94000244, 22.26082993], [87.94000244, 22.2602787], [87.9411087, 22.25917053], [87.94139099, 22.25917053], [87.9422226, 22.25832939], [87.94249725, 22.25833321], [87.9438858, 22.25694466], [87.94416809, 22.25694466], [87.9458313, 22.25527763], [87.94610596, 22.25527954], [87.9466629, 22.2547226], [87.94721985, 22.2547226], [87.94833374, 22.25361061], [87.9486618, 22.25337982], [87.94890594, 22.25313187], [87.9491806, 22.25286865], [87.94947815, 22.25259018], [87.94985199, 22.25235748], [87.95015717, 22.25208092], [87.95054626, 22.25185966], [87.95097351, 22.25164223], [87.95137024, 22.25138664], [87.95175934, 22.25110817], [87.95213318, 22.25081062], [87.95246887, 22.2504921], [87.95278168, 22.25015068], [87.95310211, 22.24982262], [87.95349884, 22.24954796], [87.95388794, 22.24924088], [87.95424652, 22.2489109], [87.95462799, 22.24859047], [87.95497894, 22.24823952], [87.95532227, 22.24785805], [87.9556427, 22.24752045], [87.95596313, 22.24722099], [87.95624542, 22.24694252], [87.9564743, 22.24666023], [87.95667267, 22.24634933], [87.95689392, 22.24603844], [87.9571228, 22.24567032], [87.95745087, 22.24533272], [87.9578476, 22.24500084], [87.95825958, 22.24468994], [87.95862579, 22.24438095], [87.95900726, 22.24415016], [87.95936584, 22.24393082], [87.9597702, 22.24382019], [87.9601593, 22.2436409], [87.96058655, 22.24357414], [87.9609375, 22.2434063], [87.96134949, 22.24329948], [87.9617157, 22.24309731], [87.96218109, 22.24302101], [87.96260834, 22.24279022], [87.96308899, 22.24261093], [87.96362305, 22.24246979], [87.96409607, 22.24222183], [87.9645462, 22.24197769], [87.96499634, 22.24179077], [87.96544647, 22.24162102], [87.9658432, 22.24138069], [87.96623993, 22.24111176], [87.96665955, 22.24082947], [87.96713257, 22.24055672], [87.96759033, 22.24028587], [87.96804047, 22.24003029], [87.96840668, 22.23973274], [87.96872711, 22.23944092], [87.96901703, 22.23917007], [87.96930695, 22.23891068], [87.9696579, 22.23867035], [87.97000122, 22.23838043], [87.97033691, 22.23802948], [87.97067261, 22.23765182], [87.97099304, 22.23726082], [87.97129822, 22.23693085], [87.97154999, 22.23660088], [87.97168732, 22.23618126], [87.97193146, 22.23579979], [87.97212219, 22.23535919], [87.97225952, 22.23491096], [87.97245789, 22.2345295], [87.97257233, 22.23413086], [87.97274017, 22.23377037], [87.97281647, 22.23335838], [87.97301483, 22.23303032], [87.97306061, 22.23262215], [87.97311401, 22.23216438], [87.97329712, 22.23170853], [87.97342682, 22.2311306], [87.97357178, 22.23052406], [87.97357178, 22.22992897], [87.97344208, 22.22942162], [87.97335815, 22.22894478], [87.97340393, 22.22847557], [87.97361755, 22.2280407], [87.97387695, 22.22759056], [87.97414398, 22.22712517], [87.97437286, 22.22661018], [87.97454071, 22.22603989], [87.9746933, 22.22545052], [87.97480774, 22.22485542], [87.9749527, 22.22433281], [87.97499847, 22.22377968], [87.97505188, 22.2232399], [87.97524261, 22.22271919], [87.97538757, 22.2221508], [87.97568512, 22.22168922], [87.97608948, 22.22127914], [87.97651672, 22.22086143], [87.97696686, 22.22047997], [87.97741699, 22.22018814], [87.97776794, 22.21986008], [87.97805786, 22.21951675], [87.97833252, 22.21916962], [87.9786377, 22.21886444], [87.97892761, 22.21857834], [87.9792099, 22.21827126], [87.97946167, 22.21793175], [87.97971344, 22.21759605], [87.97997284, 22.21725082], [87.98023987, 22.21697807], [87.9805069, 22.21670914], [87.9807663, 22.21644974], [87.98105621, 22.21615982], [87.98140717, 22.21585083], [87.98190308, 22.21556282], [87.98245239, 22.21526909], [87.98295593, 22.21491814], [87.98336792, 22.21453094], [87.98371124, 22.21421814], [87.98403931, 22.21399117], [87.98426819, 22.21364975], [87.98454285, 22.21331024], [87.98484039, 22.21297073], [87.9852829, 22.21270943], [87.98573303, 22.21242714], [87.98615265, 22.21206093], [87.98660278, 22.21174049], [87.98708344, 22.21152115], [87.9875412, 22.21133232], [87.98792267, 22.21110916], [87.9883194, 22.21087074], [87.98876953, 22.21064949], [87.98918152, 22.21034241], [87.98959351, 22.21001625], [87.99002075, 22.20972061], [87.99044037, 22.2094593], [87.99088287, 22.20927048], [87.99133301, 22.20916176], [87.99143219, 22.20913696], [87.99177551, 22.20904922], [87.99220276, 22.20889091], [87.99265289, 22.20874214], [87.99312592, 22.20858383], [87.99356842, 22.20839119], [87.99407196, 22.20841408], [87.99664307, 22.2074585], [87.99764252, 22.20717812], [88.0, 22.20639038], [88.00026703, 22.20611], [88.0008316, 22.20611191], [88.00111389, 22.20583344], [88.00138855, 22.20583344], [88.00166321, 22.20555305], [88.00195313, 22.20556068], [88.00222015, 22.2052803], [88.00250244, 22.2052803], [88.00276947, 22.20499992], [88.00305176, 22.20499992], [88.00332642, 22.20471954], [88.0036087, 22.20472145], [88.00389099, 22.20444489], [88.00416565, 22.20444489], [88.00444794, 22.20416641], [88.00499725, 22.20417023], [88.00694275, 22.20222282], [88.00722504, 22.20222282], [88.00749969, 22.20194435], [88.00861359, 22.20138931], [88.00889587, 22.20138168], [88.0091629, 22.20166969], [88.00935364, 22.20148087], [88.00945282, 22.20138168], [88.00971985, 22.20138931], [88.01000214, 22.20111275], [88.01249695, 22.20111275], [88.01304626, 22.20055962], [88.01333618, 22.20083427], [88.01361084, 22.20083427], [88.01416779, 22.20027733], [88.01470947, 22.20027924], [88.01499939, 22.20055962], [88.01512909, 22.20042038], [88.01526642, 22.20027924], [88.01583099, 22.20027924], [88.01611328, 22.20000076], [88.01638794, 22.20027924], [88.01667023, 22.20000076], [88.01805878, 22.20000076], [88.01832581, 22.19971848], [88.01863861, 22.19971848], [88.01916504, 22.19972229], [88.01944733, 22.19944382], [88.01972198, 22.19972229], [88.01999664, 22.19972229], [88.02027893, 22.19944382], [88.02055359, 22.19944382], [88.02073669, 22.19962692], [88.02083588, 22.19972229], [88.02249908, 22.19972229], [88.02278137, 22.19944382], [88.02305603, 22.19944382], [88.02333069, 22.19972229], [88.02361298, 22.19972229], [88.02388763, 22.20000076], [88.02443695, 22.20000076], [88.02471924, 22.20027924], [88.02500153, 22.20027733], [88.02519989, 22.20048141], [88.02527618, 22.20055962], [88.02539825, 22.20055771], [88.02555847, 22.2005558], [88.02566528, 22.20066452], [88.02664948, 22.20166969], [88.02694702, 22.20166588], [88.02722168, 22.20194244], [88.02777863, 22.20305634], [88.02777863, 22.20360947], [88.02805328, 22.20388985], [88.02805328, 22.20499992], [88.02833557, 22.2052784], [88.02833557, 22.20583344], [88.02861023, 22.20611], [88.02861023, 22.20639038], [88.02889252, 22.20666695], [88.02889252, 22.20694351], [88.02916718, 22.20722008], [88.02916718, 22.20750046], [88.02999878, 22.20833397], [88.03028107, 22.20833397], [88.03055573, 22.20861053], [88.03083038, 22.20861053], [88.03111267, 22.20889091], [88.03166962, 22.20889091], [88.03193665, 22.20916939], [88.03250122, 22.20916557], [88.03277588, 22.20944405], [88.03472137, 22.20944405], [88.03555298, 22.20861053], [88.03639221, 22.20861053], [88.03694153, 22.20806122], [88.03778076, 22.20806122], [88.03806305, 22.20778084], [88.03887939, 22.20778084], [88.03916931, 22.20750809], [88.0402832, 22.20750809], [88.04055786, 22.20722008], [88.04277802, 22.20722198], [88.04305267, 22.20694351], [88.04360962, 22.20694351], [88.04389191, 22.20666695], [88.04471588, 22.20667076], [88.04499817, 22.20639038], [88.04556274, 22.20639038], [88.04582977, 22.20611], [88.04638672, 22.20611191], [88.04666901, 22.20583344], [88.04750061, 22.20583344], [88.04777527, 22.20555305], [88.04807281, 22.20556068], [88.04833221, 22.2052803], [88.04860687, 22.2052803], [88.04888916, 22.20499992], [88.05000305, 22.20499992], [88.05222321, 22.20277977], [88.05222321, 22.20249939], [88.05249786, 22.20222282], [88.05249786, 22.20194435], [88.05278015, 22.20166588], [88.05278015, 22.20138168], [88.05305481, 22.20111275], [88.05304718, 22.20083237], [88.05361176, 22.20027733], [88.05387878, 22.20027924], [88.05665588, 22.19749832], [88.05665588, 22.19721985], [88.05916595, 22.19472313], [88.05944824, 22.19472313], [88.0597229, 22.19444466], [88.05999756, 22.19444466], [88.06083679, 22.19361115], [88.06111145, 22.19361115], [88.06194305, 22.19277954], [88.0625, 22.19277954], [88.0627594, 22.19250107], [88.0630722, 22.19250107], [88.06360626, 22.19194031], [88.06361389, 22.19166756], [88.06388855, 22.19139099], [88.06388855, 22.19111061], [88.06445312, 22.19055939], [88.06472015, 22.19055939], [88.06555176, 22.18972015], [88.06583405, 22.18972206], [88.0661087, 22.18944359], [88.06639099, 22.18944359], [88.06666565, 22.18916702], [88.06749725, 22.18917274], [88.06804657, 22.18861008], [88.06916809, 22.18861008], [88.06944275, 22.18833351], [88.06972504, 22.18833351], [88.06999969, 22.18861008], [88.07055664, 22.18805504], [88.07110596, 22.18806267], [88.07138824, 22.18778038], [88.0716629, 22.18806267], [88.07221985, 22.18750191], [88.07250214, 22.18778038], [88.07305908, 22.18722153], [88.07416534, 22.18722153], [88.07444763, 22.18694496], [88.07501221, 22.18695259], [88.07527924, 22.1866703], [88.07554626, 22.1866703], [88.07583618, 22.18695259], [88.07666779, 22.18694496], [88.07694244, 22.18722153], [88.07722473, 22.18694496], [88.07775879, 22.18695259], [88.07804871, 22.1866703], [88.07917023, 22.1866703], [88.07943726, 22.18695259], [88.08166504, 22.18694496], [88.08194733, 22.18722153], [88.08222198, 22.18722153], [88.08249664, 22.18694496], [88.08333588, 22.18694496], [88.08361053, 22.18722153], [88.08388519, 22.18694496], [88.08555603, 22.18695259], [88.08583069, 22.1866703], [88.08611298, 22.1866703], [88.08666992, 22.18611145], [88.08694458, 22.18611145], [88.08721924, 22.18583298], [88.08750153, 22.18583298], [88.08777618, 22.18555641], [88.08833313, 22.18555641], [88.08860779, 22.18583298], [88.08889008, 22.18583298], [88.08916473, 22.18611145], [88.08944702, 22.18611145], [88.08972168, 22.18583298], [88.08999634, 22.18583298], [88.09027863, 22.18611145], [88.09055328, 22.18611145], [88.09111023, 22.1866703], [88.09111023, 22.18694496], [88.09139252, 22.18722153], [88.09139252, 22.18750191], [88.09166718, 22.18778038], [88.09166718, 22.18805504], [88.09194183, 22.18833351], [88.09194183, 22.18861008], [88.09305573, 22.18972206], [88.09333038, 22.18972015], [88.09361267, 22.19000053], [88.09388733, 22.19000053], [88.09416962, 22.19028091], [88.09443665, 22.19028091], [88.09471893, 22.19055939], [88.09555817, 22.19055557], [88.0956955, 22.19069481], [88.09583282, 22.19083214], [88.0966568, 22.19083023], [88.09694672, 22.19111061], [88.09777832, 22.19111061], [88.09805298, 22.19139099], [88.10028076, 22.19139099], [88.10056305, 22.19111061], [88.10083008, 22.19111061], [88.10111237, 22.19083023], [88.10138702, 22.19083023], [88.10166931, 22.19111061], [88.10138702, 22.19139099], [88.10166931, 22.19166946], [88.10194397, 22.19166756], [88.10221863, 22.19194412], [88.10277557, 22.19194412], [88.10277557, 22.19166756], [88.10305786, 22.19166946], [88.10333252, 22.19139099], [88.1049881, 22.19139099], [88.10527802, 22.19166946], [88.10610962, 22.19166946], [88.10639191, 22.19139099], [88.10721588, 22.19139099], [88.10749817, 22.19111061], [88.10806274, 22.19111061], [88.10832977, 22.19083214], [88.10916901, 22.19083214], [88.10944366, 22.19055557], [88.1102829, 22.19055939], [88.11083221, 22.19000053], [88.11138916, 22.19000053], [88.11165619, 22.18972015], [88.11333466, 22.18972206], [88.11416626, 22.18888855], [88.11444092, 22.18917274], [88.11472321, 22.18889046], [88.11528015, 22.18889046], [88.11554718, 22.18861008], [88.1166687, 22.18861008], [88.11694336, 22.18833351], [88.11916351, 22.18833351], [88.1194458, 22.18861008], [88.11972046, 22.18833351], [88.1202774, 22.18833351], [88.12055206, 22.18805504], [88.12110901, 22.18806267], [88.1213913, 22.18778038], [88.12194824, 22.18778038], [88.1222229, 22.18750191], [88.12306213, 22.18750191], [88.12333679, 22.18722153], [88.12388611, 22.18722153], [88.1241684, 22.18694496], [88.12473297, 22.18695259], [88.125, 22.1866703], [88.1258316, 22.1866703], [88.12609863, 22.18639946], [88.1277771, 22.18639946], [88.12805176, 22.18611145], [88.12889099, 22.18611145], [88.12916565, 22.18583298], [88.1305542, 22.18583298], [88.13083649, 22.18555641], [88.13388824, 22.18556023], [88.1341629, 22.18527985], [88.13445282, 22.18527985], [88.13471985, 22.18499756], [88.13500214, 22.18499756], [88.13529205, 22.18471909], [88.13555908, 22.1847229], [88.13861084, 22.18166542], [88.13861084, 22.18139076], [88.13889313, 22.18111038], [88.1388855, 22.18083382], [88.13916779, 22.18055534], [88.13916779, 22.18027115], [88.13944244, 22.18000031], [88.1397171, 22.18000031], [88.14026642, 22.17945099], [88.14026642, 22.17917061], [88.14167023, 22.17778015], [88.14167023, 22.17721176], [88.14194489, 22.17694473], [88.14194489, 22.17666626], [88.14221954, 22.17638969], [88.14221954, 22.17611122], [88.14250183, 22.17583275], [88.14250183, 22.17527771], [88.14277649, 22.17500114], [88.14277649, 22.17444038], [88.14305878, 22.17416573], [88.14305878, 22.17389107], [88.14332581, 22.17361069], [88.14332581, 22.1733284], [88.14389038, 22.17277718], [88.14389038, 22.17250061], [88.14417267, 22.17221832], [88.14416504, 22.17194366], [88.14444733, 22.1716671], [88.14444733, 22.17140007], [88.14472198, 22.17110825], [88.14472198, 22.17055511], [88.14554596, 22.1697197], [88.14555359, 22.16944695], [88.14583588, 22.16917038], [88.14583588, 22.16888809], [88.14611053, 22.16860962], [88.14611053, 22.1680584], [88.14639282, 22.16777992], [88.14639282, 22.16749954], [88.14694214, 22.1669445], [88.14694214, 22.16666412], [88.14833069, 22.16526985], [88.14833069, 22.16500092], [88.15194702, 22.1613903], [88.15194702, 22.16111183], [88.15222168, 22.16083336], [88.15222168, 22.16055489], [88.15249634, 22.16027832], [88.15249634, 22.15972137], [88.15277863, 22.15944481], [88.15277863, 22.15916634], [88.15303802, 22.15888977], [88.15303802, 22.15860748], [88.15777588, 22.1538887], [88.15777588, 22.15361023], [88.15833282, 22.15306091], [88.15833282, 22.15278053], [88.15888977, 22.15221977], [88.15888977, 22.15194321], [88.15972137, 22.1511097], [88.15972137, 22.15083313], [88.16249847, 22.14805603], [88.16278076, 22.14805984], [88.16722107, 22.14360809], [88.16750336, 22.14361191], [88.16805267, 22.14305496], [88.16832733, 22.14306068], [88.16860962, 22.14221954], [88.16860962, 22.14194679], [88.16889191, 22.14166641], [88.16889191, 22.14138985], [88.16999817, 22.14027977], [88.16999817, 22.13999939], [88.17082977, 22.13916969], [88.17082977, 22.13889122], [88.17111206, 22.13861084], [88.17111206, 22.13833046], [88.17138672, 22.1380558], [88.17140198, 22.13778114], [88.17166901, 22.13750076], [88.17166901, 22.13722038], [88.17388916, 22.13500023], [88.17388916, 22.13472176], [88.17416382, 22.13444519], [88.17414856, 22.13417053], [88.17446136, 22.13389015], [88.17446136, 22.13361168], [88.17722321, 22.13083267], [88.17722321, 22.13055611], [88.17888641, 22.12889099], [88.1791687, 22.12889099], [88.18083191, 22.12722015], [88.18083191, 22.12694359], [88.18333435, 22.12444305], [88.18334198, 22.1241703], [88.18360901, 22.12388992], [88.18360901, 22.12360954], [88.18416595, 22.12305641], [88.18416595, 22.12277985], [88.18554688, 22.12138939], [88.18554688, 22.12111282], [88.18611145, 22.12055969], [88.18611145, 22.12029076], [88.18805695, 22.11832809], [88.1883316, 22.11833382], [88.18888855, 22.11777878], [88.18914795, 22.11778069], [88.1911087, 22.11582947], [88.1911087, 22.11555481], [88.19166565, 22.11499977], [88.19166565, 22.1147213], [88.19194794, 22.11444473], [88.19194794, 22.11416435], [88.19333649, 22.11277771], [88.19333649, 22.11222076], [88.19361115, 22.1119442], [88.19361115, 22.11083221], [88.19333649, 22.11055565], [88.19333649, 22.10972023], [88.1930542, 22.10944366], [88.1930542, 22.10888863], [88.19249725, 22.10833168], [88.19249725, 22.10805511], [88.19220734, 22.10778046], [88.19220734, 22.10750008], [88.19194794, 22.1072216], [88.19194794, 22.10583305], [88.19139099, 22.10527992], [88.19139099, 22.10471916], [88.1911087, 22.1044445], [88.1911087, 22.10416794], [88.19055176, 22.10360909], [88.19055176, 22.10305977], [88.19000244, 22.10250092], [88.19000244, 22.10222054], [88.18972015, 22.10194397], [88.18972015, 22.10138893], [88.18943787, 22.10111046], [88.18943787, 22.10083008], [88.18916321, 22.10055542], [88.18914795, 22.10000038], [88.18888855, 22.09972], [88.18888855, 22.09916687], [88.18805695, 22.09832954], [88.18805695, 22.09805489], [88.18777466, 22.09777832], [88.18776703, 22.09749985], [88.1875, 22.09721947], [88.1875, 22.09694481], [88.18722534, 22.09666634], [88.18723297, 22.09638977], [88.18638611, 22.09555626], [88.18640137, 22.09527969], [88.18416595, 22.09277916], [88.18334198, 22.09166908], [88.18165588, 22.08971977], [88.18166351, 22.08944511], [88.18026733, 22.08805084], [88.18027496, 22.08777618], [88.17861176, 22.08611107], [88.17861176, 22.08583069], [88.17778015, 22.08499908], [88.17778015, 22.08472061], [88.17388916, 22.08083344], [88.17388916, 22.08055496], [88.17028046, 22.07694054], [88.17028046, 22.07666779], [88.16971588, 22.07611084], [88.16944122, 22.07611084], [88.16694641, 22.07361031], [88.16666412, 22.07361031], [88.16529846, 22.07224464], [88.16444397, 22.07138824], [88.16416931, 22.07139015], [88.16278076, 22.06999969], [88.16249847, 22.06999969], [88.16139221, 22.06888962], [88.16110992, 22.06888962], [88.16027832, 22.06806183], [88.15999603, 22.06806183], [88.15916443, 22.0672226], [88.15888977, 22.06694412], [88.15860748, 22.06666756], [88.15833282, 22.06666946], [88.15812683, 22.06646156], [88.15805054, 22.0664444], [88.15777588, 22.06638908], [88.15616608, 22.06477928], [88.15609741, 22.06475258], [88.15602875, 22.06472778], [88.15528107, 22.06444359], [88.15472412, 22.06444359], [88.15333557, 22.06305695], [88.15303802, 22.06306839], [88.15249634, 22.06249809], [88.15222168, 22.06249809], [88.15141296, 22.06168938], [88.15110779, 22.06138611], [88.15093994, 22.06138992], [88.15083313, 22.06138992], [88.15068817, 22.06124115], [88.15055847, 22.06111145], [88.15027618, 22.06111145], [88.14971924, 22.0605545], [88.14943695, 22.06056023], [88.14861298, 22.05972099], [88.14805603, 22.0597229], [88.14778137, 22.05944443], [88.14722443, 22.05944443], [88.14694214, 22.05916405], [88.14639282, 22.05916977], [88.14611053, 22.05888939], [88.14583588, 22.05888939], [88.14554596, 22.05861092], [88.14527893, 22.05861092], [88.14499664, 22.05833054], [88.14444733, 22.05833244], [88.14416504, 22.05805588], [88.14389038, 22.05805969], [88.14360809, 22.05778122], [88.14332581, 22.05778122], [88.14305878, 22.05750084], [88.14250183, 22.05750084], [88.14193726, 22.05694962], [88.14138794, 22.05694962], [88.14109802, 22.05667114], [88.14055634, 22.05667114], [88.14026642, 22.05639076], [88.13999939, 22.05639076], [88.1397171, 22.05611038], [88.13944244, 22.05611038], [88.13916779, 22.05583191], [88.1388855, 22.05583382], [88.13861084, 22.05555534], [88.13835144, 22.05556107], [88.13803864, 22.05528069], [88.13749695, 22.05528069], [88.13722229, 22.05500031], [88.13666534, 22.05500031], [88.1361084, 22.05444527], [88.13594818, 22.05444717], [88.13555908, 22.0544529], [88.13546753, 22.05435562], [88.13527679, 22.05416679], [88.13500214, 22.05417061], [88.13471985, 22.05388069], [88.13444519, 22.05388832], [88.1341629, 22.05361176], [88.13388824, 22.05361176], [88.1333313, 22.05305481], [88.13305664, 22.05305481], [88.13277435, 22.05277824], [88.13249969, 22.05278015], [88.13244629, 22.05272484], [88.13223267, 22.05250168], [88.13194275, 22.05250168], [88.1313858, 22.05194092], [88.13111115, 22.05194473], [88.13083649, 22.05166626], [88.13027954, 22.05166817], [88.12999725, 22.05138969], [88.1297226, 22.05138969], [88.12944794, 22.05111122], [88.12889099, 22.05111122], [88.12832642, 22.05055809], [88.12805176, 22.05055809], [88.1277771, 22.05027962], [88.12750244, 22.05027962], [88.12722015, 22.05000114], [88.12695313, 22.05000114], [88.12666321, 22.04972076], [88.12638855, 22.04972267], [88.12611389, 22.0494442], [88.12555695, 22.0494442], [88.125, 22.04888725], [88.12473297, 22.04889107], [88.1241684, 22.04833031], [88.12388611, 22.04833412], [88.12333679, 22.04777527], [88.12306213, 22.04778099], [88.12277985, 22.04750061], [88.12249756, 22.04750061], [88.12166595, 22.04667091], [88.12110901, 22.04667091], [88.12073517, 22.04629707], [88.12055206, 22.04611206], [88.1202774, 22.04611206], [88.11972046, 22.04555321], [88.1194458, 22.04556084], [88.11888885, 22.04500008], [88.11860657, 22.04500008], [88.11805725, 22.04445076], [88.11778259, 22.04445076], [88.11721802, 22.04389], [88.1166687, 22.04389], [88.11638641, 22.04360962], [88.11611176, 22.04361153], [88.11528015, 22.04277802], [88.11499786, 22.04277992], [88.11472321, 22.04249954], [88.11444092, 22.04249954], [88.11415863, 22.04222107], [88.1138916, 22.04222107], [88.11360931, 22.0419445], [88.11333466, 22.0419445], [88.11138916, 22.04000092], [88.1111145, 22.04000092], [88.11083221, 22.03972244], [88.11055756, 22.03972244], [88.10972595, 22.03889084], [88.10944366, 22.03889084], [88.10916901, 22.03861046], [88.10861206, 22.03861046], [88.10832977, 22.03832817], [88.10805511, 22.03833389], [88.10583496, 22.03611183], [88.10527802, 22.03611183], [88.10444641, 22.03527641], [88.10416412, 22.03555489], [88.10388947, 22.03527641], [88.10360718, 22.03528023], [88.10221863, 22.03388977], [88.10221863, 22.03333092], [88.10166931, 22.03277779], [88.10111237, 22.03277969], [88.10083008, 22.03306007], [88.10056305, 22.03306007], [88.10018921, 22.03268814], [88.09999847, 22.03249931], [88.09971619, 22.03250122], [88.0983429, 22.03111076], [88.09777832, 22.03111076], [88.09722137, 22.03055954], [88.0966568, 22.03055954], [88.09612274, 22.03000069], [88.09583282, 22.03000069], [88.09527588, 22.02944183], [88.09500122, 22.02944374], [88.09388733, 22.02833366], [88.09361267, 22.02833366], [88.09333038, 22.02805519], [88.0930481, 22.02806282], [88.09278107, 22.02778053], [88.09249878, 22.02778053], [88.09166718, 22.02693939], [88.09139252, 22.02694511], [88.09111023, 22.02666664], [88.0908432, 22.02667046], [88.09065247, 22.02648544], [88.09055328, 22.02639008], [88.09027863, 22.02639008], [88.08998871, 22.0261116], [88.08972168, 22.0261116], [88.08944702, 22.02583313], [88.08944702, 22.02555466], [88.08833313, 22.02444458], [88.08777618, 22.02444458], [88.08750153, 22.02416611], [88.08695221, 22.02416992], [88.08611298, 22.02333069], [88.08583069, 22.0233326], [88.08555603, 22.02305794], [88.08528137, 22.02305984], [88.08472443, 22.02250099], [88.08444214, 22.02222061], [88.08416748, 22.02222252], [88.08333588, 22.0213871], [88.08222198, 22.02139091], [88.08152008, 22.021101], [88.07943726, 22.02083969], [88.07888794, 22.02056122], [88.07861328, 22.02056122], [88.07804871, 22.02000046], [88.07775879, 22.02000046], [88.07749939, 22.01972008], [88.07722473, 22.01972198], [88.07666779, 22.01916695], [88.07639313, 22.01917076], [88.07611084, 22.01889038], [88.07527924, 22.01889038], [88.07501221, 22.01861], [88.07444763, 22.01861191], [88.07416534, 22.01833344], [88.0736084, 22.01833344], [88.07333374, 22.01805305], [88.07277679, 22.01806068], [88.07221985, 22.01749992], [88.07138824, 22.01721954], [88.07111359, 22.01694489], [88.07111359, 22.01666641], [88.06989288, 22.0154438], [88.06972504, 22.01527786], [88.06944275, 22.01527786], [88.06916809, 22.01499939], [88.06887817, 22.01499939], [88.06749725, 22.01499939], [88.0672226, 22.01527977], [88.06694794, 22.01527977], [88.06667328, 22.01499939], [88.06639099, 22.01499939], [88.0661087, 22.01471138], [88.06583405, 22.01472282], [88.06555176, 22.01444435], [88.0652771, 22.01444435], [88.06500244, 22.01416588], [88.06360626, 22.01416969], [88.0633316, 22.01389122], [88.0630722, 22.01389122], [88.06223297, 22.01305962], [88.06138611, 22.01389122], [88.06138611, 22.01416588], [88.06111145, 22.01444244], [88.06111145, 22.01499939], [88.06083679, 22.01527977], [88.0605545, 22.01527786], [88.05999756, 22.0158329], [88.0597229, 22.0158329], [88.05916595, 22.01638985], [88.0588913, 22.01638985], [88.05860901, 22.01666641], [88.05860901, 22.01694489], [88.05722046, 22.01833344], [88.0569458, 22.01861191], [88.05665588, 22.01861], [88.0541687, 22.02111053], [88.05388641, 22.02111053], [88.05305481, 22.02194405], [88.05278015, 22.02194405], [88.05249786, 22.02222252], [88.05194092, 22.02222061], [88.05027771, 22.02389908], [88.04972076, 22.02389908], [88.04471588, 22.02889061], [88.04444122, 22.0288887], [88.04389191, 22.02944374], [88.04360962, 22.02944183], [88.04277802, 22.03027725], [88.04111481, 22.03194427], [88.04083252, 22.03194427], [88.03944397, 22.03333282], [88.03943634, 22.03360939], [88.03887939, 22.03417015], [88.03861237, 22.03417015], [88.03778076, 22.03499985], [88.03778076, 22.03528023], [88.03722382, 22.03583336], [88.03722382, 22.03611183], [88.03444672, 22.03889084], [88.0341568, 22.03887749], [88.03388977, 22.0391674], [88.03388977, 22.03943825], [88.03333282, 22.04000092], [88.03333282, 22.04027939], [88.03221893, 22.04138947], [88.03221893, 22.04166603], [88.03194427, 22.0419445], [88.03193665, 22.04222107], [88.03111267, 22.04305649], [88.03111267, 22.04333115], [88.02999878, 22.04444313], [88.02999878, 22.0447197], [88.02970886, 22.04500008], [88.02972412, 22.04527855], [88.02916718, 22.04583359], [88.02889252, 22.04583359], [88.02861023, 22.04611206], [88.02833557, 22.04611206], [88.02807617, 22.04636955], [88.02749634, 22.04694366], [88.02749634, 22.04722023], [88.02693939, 22.04778099], [88.02693939, 22.04861069], [88.02722168, 22.04888725], [88.02722168, 22.04948044], [88.02722168, 22.04972076], [88.02749634, 22.05000114], [88.02749634, 22.05027962], [88.02777863, 22.05055809], [88.02777863, 22.05111122], [88.02805328, 22.05138969], [88.02805328, 22.05194473], [88.02833557, 22.0522213], [88.02833557, 22.05305481], [88.02861023, 22.05333328], [88.02861023, 22.05361176], [88.02916718, 22.05417061], [88.02916718, 22.0544529], [88.02970886, 22.05500031], [88.02999878, 22.05500031], [88.03028107, 22.05528069], [88.03056335, 22.05528069], [88.03067017, 22.05539513], [88.03083038, 22.05556107], [88.03138733, 22.05555534], [88.03166962, 22.05583382], [88.03193665, 22.05583191], [88.03360748, 22.05750084], [88.03360748, 22.05833054], [88.03388977, 22.05861092], [88.03388977, 22.05944443], [88.03360748, 22.0597229], [88.03360748, 22.06083298], [88.03333282, 22.06110954], [88.03333282, 22.06138992], [88.03277588, 22.06194687], [88.03277588, 22.06221962], [88.03250122, 22.06249809], [88.03250122, 22.06278038], [88.03221893, 22.06305695], [88.03221893, 22.06333351], [88.03193665, 22.06360817], [88.03194427, 22.06388664], [88.02999878, 22.06582069], [88.02999878, 22.06611061], [88.02944183, 22.06666756], [88.02944183, 22.06694412], [88.02805328, 22.06833267], [88.02777863, 22.06833267], [88.02749634, 22.06861115], [88.02722168, 22.06861115], [88.02693939, 22.06888962], [88.02664948, 22.06888962], [88.02527618, 22.07028008], [88.02500153, 22.07028008], [88.02361298, 22.07167053], [88.02361298, 22.07195091], [88.02278137, 22.07278061], [88.02249908, 22.0727787], [88.02194214, 22.07333374], [88.02166748, 22.07332993], [88.02083588, 22.07417107], [88.02027893, 22.07416534], [88.01750183, 22.07694435], [88.01750183, 22.07722092], [88.01693726, 22.07777977], [88.01667023, 22.07777977], [88.01555634, 22.07889175], [88.01526642, 22.07889175], [88.01499939, 22.07917023], [88.01472473, 22.07916641], [88.01389313, 22.08000183], [88.01361084, 22.08000183], [88.01333618, 22.0802803], [88.01304626, 22.0802803], [88.01277924, 22.08056259], [88.01249695, 22.08056259], [88.01167297, 22.08139038], [88.01139069, 22.08139038], [88.01027679, 22.08250046], [88.01000214, 22.08250046], [88.00889587, 22.08361053], [88.00860596, 22.08361053], [88.0083313, 22.08389091], [88.00805664, 22.08389091], [88.00776672, 22.08418083], [88.00749969, 22.08416748], [88.00722504, 22.08444214], [88.00666809, 22.08444214], [88.0063858, 22.08472252], [88.00611115, 22.08472061], [88.00553894, 22.08527946], [88.00527954, 22.08527946], [88.00444794, 22.08611107], [88.00417328, 22.08611107], [88.00389099, 22.08638954], [88.0036087, 22.08638954], [88.0027771, 22.08722305], [88.00250244, 22.08722115], [88.00222015, 22.08749962], [88.00195313, 22.08749962], [88.00166321, 22.08778], [88.00138855, 22.08777618], [88.00111389, 22.08805466], [88.0008316, 22.08805466], [88.0, 22.0886097], [87.99962616, 22.08883858], [87.99929047, 22.08941078], [87.99888611, 22.08947182], [87.99842834, 22.089571], [87.9980545, 22.08999825], [87.99695587, 22.09110832], [87.99694824, 22.09139061], [87.9963913, 22.09194374], [87.9963913, 22.0922184], [87.99610901, 22.09250069], [87.99610901, 22.09277725], [87.99582672, 22.0930481], [87.99582672, 22.09361076], [87.99555206, 22.09389114], [87.99555206, 22.0941658], [87.9952774, 22.09444237], [87.9952774, 22.09555626], [87.99500275, 22.09583282], [87.99500275, 22.09638977], [87.99472046, 22.09666634], [87.99472046, 22.09722137], [87.9944458, 22.09860992], [87.9944458, 22.09945107], [87.99388885, 22.10056114], [87.99194336, 22.10250092], [87.99111176, 22.10305977], [87.98999786, 22.10360909], [87.98916626, 22.10388947], [87.9851532, 22.10474014], [87.98448181, 22.10471916], [87.9839325, 22.10466957], [87.9835434, 22.10449982], [87.98319244, 22.10444832], [87.98288727, 22.10444641], [87.98261261, 22.10441971], [87.98216248, 22.10451126], [87.98165894, 22.10448074], [87.98120117, 22.10441971], [87.98078918, 22.10443878], [87.98034668, 22.10445023], [87.97986603, 22.10449028], [87.97939301, 22.10461998], [87.97895813, 22.10484886], [87.9785614, 22.10487175], [87.97815704, 22.10477257], [87.97776031, 22.10474205], [87.97734833, 22.10473061], [87.97692871, 22.10473061], [87.97651672, 22.10474014], [87.97615051, 22.10476112], [87.97590637, 22.10473061], [87.97583008, 22.10471916], [87.97499847, 22.10472298], [87.97472382, 22.10499763], [87.97416687, 22.10499763], [87.97389221, 22.10472298], [87.97333527, 22.10472298], [87.97305298, 22.1044445], [87.97138977, 22.1044445], [87.97110748, 22.10416794], [87.96639252, 22.10416985], [87.96389008, 22.10360909], [87.96375275, 22.10371971], [87.96335602, 22.10347748], [87.96305847, 22.10320091], [87.96277618, 22.10289001], [87.96250153, 22.10257149], [87.96225739, 22.10222626], [87.96208954, 22.10184669], [87.96182251, 22.10152054], [87.96154022, 22.10115051], [87.96120453, 22.10083389], [87.95944977, 22.09968948], [87.95932007, 22.09784317], [87.95960999, 22.09691048], [87.96037292, 22.09555054], [87.96069336, 22.09542274], [87.96260071, 22.09500122], [87.96304321, 22.09494019], [87.96346283, 22.09477234], [87.96392822, 22.0947094], [87.9644165, 22.09460068], [87.9649353, 22.09444237], [87.96704865, 22.0943985], [87.96749115, 22.09444237], [87.96788788, 22.0944519], [87.96826172, 22.0944519], [87.96869659, 22.09444237], [87.96922302, 22.09439087], [87.96983337, 22.0943203], [87.97045898, 22.09445953], [87.97107697, 22.09469986], [87.97170258, 22.09493256], [87.9723053, 22.0950985], [87.9728775, 22.0952301], [87.97344208, 22.09530067], [87.97399902, 22.09537506], [87.97451019, 22.09552002], [87.97502136, 22.09562111], [87.97541046, 22.09583282], [87.97580719, 22.09598351], [87.97622681, 22.09615135], [87.97666931, 22.0963726], [87.97715759, 22.09658241], [87.97767639, 22.09685135], [87.97823334, 22.09716988], [87.97872925, 22.09745979], [87.97911072, 22.09776688], [87.97955322, 22.09799004], [87.97992706, 22.09827042], [87.98034668, 22.09840012], [87.9807663, 22.0985508], [87.98114777, 22.0986805], [87.98146057, 22.0988102], [87.98174286, 22.09875107], [87.98193359, 22.09851074], [87.98210907, 22.09818268], [87.98230743, 22.09787178], [87.98253632, 22.0976181], [87.98271942, 22.09736061], [87.98249817, 22.09721947], [87.98278046, 22.09694481], [87.98278046, 22.09666634], [87.98306274, 22.09638977], [87.98305511, 22.0961113], [87.98332977, 22.09583282], [87.98332977, 22.09555626], [87.98388672, 22.09500122], [87.98388672, 22.09472275], [87.98444366, 22.0941658], [87.98443604, 22.09389114], [87.98500061, 22.09332848], [87.98500061, 22.09305573], [87.98638916, 22.09166718], [87.98638916, 22.09139061], [87.98860931, 22.08917046], [87.98860931, 22.08889008], [87.98972321, 22.08778], [87.99017334, 22.0873394], [87.99062347, 22.0869236], [87.99107361, 22.08666039], [87.99150848, 22.08638954], [87.9919281, 22.08608246], [87.99226379, 22.08568192], [87.99263, 22.08531952], [87.99301147, 22.0850296], [87.99333954, 22.08471107], [87.99365234, 22.08440971], [87.99397278, 22.08409119], [87.99430847, 22.08377457], [87.99473572, 22.08348274], [87.995224, 22.08317375], [87.99571228, 22.08281708], [87.99621582, 22.08250999], [87.9963913, 22.08250046], [87.99973297, 22.07917023], [88.0, 22.07917023], [88.00138855, 22.07777977], [88.00166321, 22.07777977], [88.00195313, 22.07749748], [88.00222015, 22.07749748], [88.00389099, 22.07583046], [88.00416565, 22.07583427], [88.00444794, 22.07555771], [88.0047226, 22.07555962], [88.00499725, 22.07528114], [88.00527954, 22.07528114], [88.00553894, 22.0750103], [88.00582886, 22.0750103], [88.00611115, 22.07472038], [88.0063858, 22.07472229], [88.00694275, 22.07416534], [88.00723267, 22.07417107], [88.00776672, 22.07361031], [88.00805664, 22.07361031], [88.00860596, 22.07306099], [88.00860596, 22.07278061], [88.01019287, 22.07119751], [88.0111084, 22.07027817], [88.01196289, 22.06806183], [88.01196289, 22.06750107], [88.01222229, 22.0672226], [88.01222229, 22.06694412], [88.01277924, 22.06638908], [88.01277924, 22.06611061], [88.01304626, 22.06582069], [88.01305389, 22.06555557], [88.01333618, 22.06528091], [88.01333618, 22.06471825], [88.01361084, 22.06444359], [88.01361084, 22.0616684], [88.01389313, 22.06138992], [88.01389313, 22.06056023], [88.01416779, 22.06027985], [88.01416779, 22.06001091], [88.01444244, 22.05750084], [88.01470947, 22.05722046], [88.01472473, 22.05638885], [88.01499939, 22.05611038], [88.01499939, 22.05583191], [88.01527405, 22.05555534], [88.01526642, 22.05500031], [88.01555634, 22.05472183], [88.01555634, 22.05333328], [88.01583099, 22.05305481], [88.01583099, 22.05250168], [88.01721954, 22.05111122], [88.01721954, 22.04944038], [88.01694489, 22.04916573], [88.01693726, 22.04889107], [88.01667023, 22.04861069], [88.01667023, 22.04833031], [88.01638794, 22.04805756], [88.01638794, 22.04684258], [88.01638794, 22.0447216], [88.01667023, 22.04444313], [88.01667023, 22.04277992], [88.01693726, 22.04249954], [88.01693726, 22.0419426], [88.01721954, 22.04166603], [88.01721954, 22.04138947], [88.01750183, 22.0411129], [88.01750183, 22.04083252], [88.01777649, 22.04055595], [88.01776886, 22.04027939], [88.01832581, 22.03971863], [88.01860809, 22.03972244], [88.01916504, 22.0391655], [88.02083588, 22.03750038], [88.02083588, 22.03721809], [88.02166748, 22.03638649], [88.02194214, 22.0363903], [88.02278137, 22.03555107], [88.02278137, 22.03527641], [88.02471924, 22.03333092], [88.02471924, 22.03277779], [88.02500153, 22.03250122], [88.02500153, 22.03222084], [88.02527618, 22.03194427], [88.02555847, 22.03194427], [88.03250122, 22.02499962], [88.03277588, 22.02499962], [88.03360748, 22.02416992], [88.0341568, 22.02416992], [88.03444672, 22.02389908], [88.03472137, 22.02389908], [88.03499603, 22.02361107], [88.03555298, 22.02361107], [88.03610992, 22.02305984], [88.03639221, 22.02305984], [88.03694153, 22.02250099], [88.03721619, 22.02250099], [88.03833008, 22.02139091], [88.03887939, 22.02139091], [88.03916931, 22.02111053], [88.03943634, 22.02111053], [88.03971863, 22.02083969], [88.0402832, 22.02083969], [88.04055786, 22.02056122], [88.04110718, 22.02056122], [88.04164886, 22.02000046], [88.04193878, 22.02000046], [88.04250336, 22.0194397], [88.04277802, 22.01944351], [88.04305267, 22.01916695], [88.04334259, 22.01917076], [88.04360962, 22.01889038], [88.04389191, 22.01889038], [88.04416656, 22.01861], [88.04472351, 22.01861191], [88.04499817, 22.01833344], [88.04555511, 22.01833344], [88.04582977, 22.01805305], [88.04611206, 22.01806068], [88.04638672, 22.01777077], [88.04666901, 22.0177784], [88.04694366, 22.01749992], [88.04722595, 22.01749992], [88.04750061, 22.01721954], [88.04777527, 22.01722145], [88.04833221, 22.01666641], [88.04860687, 22.01667023], [88.04915619, 22.01610947], [88.04972076, 22.01611137], [88.05000305, 22.0158329], [88.05055237, 22.0158329], [88.05083466, 22.01555634], [88.05110931, 22.01556015], [88.05166626, 22.01499939], [88.05194092, 22.01499939], [88.05222321, 22.01471138], [88.05222321, 22.01444435], [88.05249786, 22.01416588], [88.05249786, 22.01361275], [88.05278015, 22.01332855], [88.05278015, 22.0111084], [88.05304718, 22.01082993], [88.05305481, 22.0102787], [88.05278015, 22.01000023], [88.05278015, 22.00945091], [88.05249786, 22.00917053], [88.05249786, 22.00860977], [88.05222321, 22.00833321], [88.05222321, 22.00749969], [88.05194092, 22.00722122], [88.05194092, 22.00694656], [88.05110931, 22.00611115], [88.05110931, 22.00583076], [88.05083466, 22.00583267], [88.0486145, 22.00361061], [88.04860687, 22.00333023], [88.04750061, 22.00222206], [88.04750061, 22.00194359], [88.04722595, 22.00166702], [88.04722595, 22.00139046], [88.0460968, 22.00026894], [88.04582977, 22.00000191], [88.04556274, 21.99945259], [88.04556274, 21.99889183], [88.04528046, 21.99860764], [88.04528046, 21.99833298], [88.04499817, 21.99805641], [88.04499817, 21.99777985], [88.04471588, 21.99749756], [88.04471588, 21.99694061], [88.04444122, 21.99666786], [88.04444122, 21.99611092], [88.04416656, 21.99583054], [88.04416656, 21.99555779], [88.04389191, 21.99528122], [88.04389191, 21.99500084], [88.04360962, 21.99472046], [88.04360962, 21.99444389], [88.04333496, 21.99416542], [88.04334259, 21.99389076], [88.04277802, 21.99333], [88.04277802, 21.99277687], [88.04250336, 21.99250031], [88.04250336, 21.99195099], [88.04164886, 21.99110985], [88.04166412, 21.99055481], [88.04111481, 21.98999977], [88.04110718, 21.98971939], [88.04083252, 21.98944473], [88.04083252, 21.98916626], [88.04055786, 21.98888969], [88.04055786, 21.98861122], [88.0402832, 21.98833275], [88.04027557, 21.98805618], [88.04000092, 21.9880619], [88.03944397, 21.98750114], [88.03916931, 21.98722267], [88.03916931, 21.98638916], [88.03887939, 21.98611069], [88.03887939, 21.9858284], [88.03833008, 21.98527718], [88.03833008, 21.98500061], [88.03778076, 21.98443985], [88.03778076, 21.9841671], [88.03749847, 21.98417091], [88.03749847, 21.98389053], [88.03694153, 21.98332977], [88.03694153, 21.98305511], [88.03666687, 21.98278046], [88.03666687, 21.98249817], [88.03639221, 21.9822197], [88.03639221, 21.98194695], [88.0358429, 21.98139], [88.0358429, 21.98083115], [88.03610992, 21.98055458], [88.03610992, 21.98027992], [88.0358429, 21.97999954], [88.03583527, 21.9794445], [88.03555298, 21.97916412], [88.03530121, 21.97875977], [88.03514099, 21.97846985], [88.03501129, 21.97820663], [88.03490448, 21.97790146], [88.03482056, 21.9775486], [88.03486633, 21.97707939], [88.03488159, 21.97661209], [88.03469086, 21.97629738], [88.03440094, 21.97606087], [88.0341568, 21.97585106], [88.03392792, 21.97558975], [88.03385925, 21.97527122], [88.03370667, 21.97495079], [88.03360748, 21.97454071], [88.0335083, 21.97404289], [88.03340149, 21.97348022], [88.03317261, 21.97293472], [88.03285217, 21.97244263], [88.03256989, 21.97192955], [88.03240967, 21.9713192], [88.03224182, 21.9707489], [88.03209686, 21.97018051], [88.03190613, 21.96965981], [88.03165436, 21.96918869], [88.03138733, 21.96874809], [88.03111267, 21.96836662], [88.03111267, 21.96778107], [88.02999878, 21.96665955], [88.02999878, 21.96611023], [88.02970886, 21.96611023], [88.02970886, 21.96582985], [88.02944183, 21.96555328], [88.02944183, 21.96528053], [88.02916718, 21.96500015], [88.02916718, 21.96471977], [88.02889252, 21.96444321], [88.02889252, 21.96417046], [88.02916718, 21.96389008], [88.02805328, 21.96278], [88.02805328, 21.96222115], [88.02722168, 21.96138954], [88.02722168, 21.96111107], [88.02693939, 21.9608326], [88.02694702, 21.96027756], [88.02664948, 21.95999908], [88.02664948, 21.95972061], [88.02694702, 21.95944405], [88.02694702, 21.95916748], [88.02610779, 21.95832825], [88.02583313, 21.95833397], [88.02555847, 21.9580555], [88.02555847, 21.95778084], [88.02500153, 21.95721817], [88.02500153, 21.95666885], [88.02471924, 21.95639038], [88.02471924, 21.95582962], [88.02444458, 21.95555687], [88.02443695, 21.9552803], [88.02416992, 21.95499992], [88.02443695, 21.95471954], [88.02444458, 21.95388794], [88.02305603, 21.95249939], [88.02305603, 21.95222092], [88.02249908, 21.95166588], [88.02249908, 21.95139122], [88.0222168, 21.95111084], [88.0222168, 21.95083046], [88.02194214, 21.9505558], [88.02194214, 21.95028114], [88.02139282, 21.94972038], [88.02138519, 21.94861031], [88.02111053, 21.94833183], [88.02111053, 21.9477787], [88.02027893, 21.94695282], [88.02027893, 21.94639015], [88.01999664, 21.94611168], [88.01999664, 21.94583321], [88.02027893, 21.94555473], [88.02027893, 21.94499969], [88.01999664, 21.94472122], [88.01999664, 21.94416618], [88.01917267, 21.94333076], [88.01916504, 21.94277954], [88.01889038, 21.94248962], [88.01889038, 21.9422226], [88.01860809, 21.94194412], [88.01860809, 21.94166565], [88.01776886, 21.94083023], [88.01777649, 21.94055748], [88.01750183, 21.94028091], [88.01750183, 21.94000053], [88.01721954, 21.93972015], [88.01721954, 21.93916512], [88.01693726, 21.93889046], [88.01693726, 21.93861008], [88.01667023, 21.93833351], [88.01667023, 21.93805313], [88.01638794, 21.93778038], [88.01638794, 21.9375], [88.01609802, 21.93707275], [88.01583862, 21.93669891], [88.01560211, 21.93630028], [88.01542664, 21.93582153], [88.01534271, 21.93527985], [88.01537323, 21.93465042], [88.01537323, 21.93403053], [88.0151062, 21.93357086], [88.01483917, 21.93315315], [88.01468658, 21.93271255], [88.01464844, 21.93218994], [88.01441956, 21.93169975], [88.0140686, 21.93126106], [88.01378632, 21.93082428], [88.01358795, 21.93037605], [88.01344299, 21.92992973], [88.01325226, 21.92952919], [88.01302338, 21.9291935], [88.01278687, 21.92883682], [88.0125885, 21.92844963], [88.01246643, 21.92801666], [88.01229095, 21.92761993], [88.01216888, 21.92717934], [88.0120163, 21.92675018], [88.01190186, 21.92625999], [88.01174164, 21.9257412], [88.01167297, 21.92556], [88.01167297, 21.92500114], [88.01140594, 21.92423058], [88.01139069, 21.92361069], [88.01139069, 21.92333031], [88.01083374, 21.92277718], [88.01082611, 21.92194176], [88.01055908, 21.9216671], [88.01055908, 21.92121124], [88.01055908, 21.92055511], [88.01082611, 21.92028046], [88.01082611, 21.9197216], [88.01055908, 21.91944504], [88.01055908, 21.91860771], [88.01027679, 21.91833305], [88.01027679, 21.91805649], [88.01000214, 21.91777992], [88.01000214, 21.91749954], [88.00971985, 21.91721916], [88.00971985, 21.9169445], [88.00888824, 21.91611099], [88.00860596, 21.91611099], [88.0083847, 21.9158287], [88.0083313, 21.91500092], [88.00805664, 21.91472054], [88.00805664, 21.91444588], [88.00777435, 21.9141655], [88.00776672, 21.91306114], [88.00749969, 21.91278076], [88.00749969, 21.9113903], [88.0063858, 21.91028023], [88.0063858, 21.90999985], [88.00611115, 21.90971947], [88.00611115, 21.90944481], [88.00582886, 21.90917015], [88.00582886, 21.90888977], [88.0047226, 21.90777969], [88.0047226, 21.90750122], [88.00444794, 21.90722275], [88.00416565, 21.90722275], [88.00376892, 21.90682411], [88.0036087, 21.9066658], [88.0036087, 21.90582848], [88.00333405, 21.90555573], [88.00332642, 21.9047184], [88.0036087, 21.90444374], [88.0036087, 21.90389061], [88.00195313, 21.90221977], [88.0019455, 21.90166855], [88.00099182, 21.90034103], [88.00041962, 21.89923096], [88.00035095, 21.89908981], [88.00026703, 21.89902115], [88.0, 21.89861107], [87.9991684, 21.89777946], [87.9991684, 21.89751053], [87.99888611, 21.89722061], [87.99888611, 21.89694214], [87.99861145, 21.89666748], [87.99861145, 21.89611053], [87.99804688, 21.89556122], [87.99804688, 21.89528275], [87.99777985, 21.89500046], [87.99777985, 21.89472008], [87.9972229, 21.89416695], [87.9972229, 21.89389038], [87.99666595, 21.89333153], [87.99666595, 21.89305496], [87.99600983, 21.89239693], [87.99583435, 21.89222145], [87.99568176, 21.89179039], [87.99546814, 21.89137077], [87.99526978, 21.89093018], [87.99507141, 21.89048958], [87.99491882, 21.89003372], [87.99475861, 21.88966942], [87.99462891, 21.88939095], [87.99446869, 21.88911057], [87.99430847, 21.88876915], [87.99414825, 21.88831329], [87.993927, 21.88779068], [87.99371338, 21.8871994], [87.99333191, 21.88666534], [87.99250031, 21.88582993], [87.99250031, 21.88555336], [87.99194336, 21.88500023], [87.99194336, 21.88471985], [87.9916687, 21.88444328], [87.9916687, 21.88417053], [87.99138641, 21.88389015], [87.99138641, 21.88332939], [87.99111176, 21.88305473], [87.9908371, 21.88277817], [87.99082947, 21.88221169], [87.99028015, 21.88166618], [87.99028015, 21.88138962], [87.99005127, 21.88078117], [87.98987579, 21.88023949], [87.98973083, 21.87979317], [87.98944092, 21.87944412], [87.98916626, 21.87944412], [87.9888916, 21.87916756], [87.9888916, 21.87888908], [87.98828125, 21.87804985], [87.98805237, 21.87750053], [87.98805237, 21.87667084], [87.98779297, 21.87639809], [87.98779297, 21.87610817], [87.98750305, 21.87583351], [87.98744965, 21.87553406], [87.98722839, 21.87516022], [87.98698425, 21.87476921], [87.98670959, 21.87436104], [87.98645782, 21.87385941], [87.98628998, 21.87336159], [87.98607635, 21.87298965], [87.98591614, 21.87272835], [87.98581696, 21.87251091], [87.98575592, 21.87223053], [87.98564148, 21.8718605], [87.98544312, 21.87137222], [87.98526764, 21.87082291], [87.98500061, 21.87026787], [87.98470306, 21.86970139], [87.98439026, 21.86911964], [87.98416901, 21.86861038], [87.98416901, 21.86833191], [87.98361206, 21.86777687], [87.98361206, 21.86750031], [87.98293304, 21.86639023], [87.98285675, 21.86603928], [87.98272705, 21.86576653], [87.98264313, 21.86554909], [87.98249817, 21.86444473], [87.98209381, 21.86374474], [87.98195648, 21.86305618], [87.98194122, 21.86277962], [87.98194122, 21.86250114], [87.98139191, 21.86194038], [87.98139191, 21.86166763], [87.98110962, 21.8614006], [87.98110962, 21.86111069], [87.98084259, 21.86083031], [87.98083496, 21.85972214], [87.98055267, 21.85944366], [87.98055267, 21.85916519], [87.98027802, 21.85889053], [87.98055267, 21.85861015], [87.98055267, 21.85833359], [87.98047638, 21.85825729], [87.98027802, 21.85805321], [87.98027802, 21.85778046], [87.97915649, 21.85667038], [87.97915649, 21.85610962], [87.97861481, 21.85555649], [87.97833252, 21.8555603], [87.97750092, 21.85472107], [87.97750092, 21.85416603], [87.97721863, 21.85388947], [87.97721863, 21.8536129], [87.97693634, 21.8533287], [87.97694397, 21.85277748], [87.97638702, 21.85220909], [87.97638702, 21.85194397], [87.97611237, 21.8516674], [87.97611237, 21.85111046], [87.97528076, 21.85028076], [87.97499847, 21.85028076], [87.97472382, 21.85055542], [87.97471619, 21.85082817], [87.97444153, 21.85111046], [87.97444153, 21.85139084], [87.97389221, 21.85194397], [87.97360992, 21.85194397], [87.97305298, 21.85139084], [87.97186279, 21.85057259], [87.97100067, 21.84976768], [87.97071838, 21.84943008], [87.9706192, 21.84897232], [87.96949005, 21.84830475], [87.96920776, 21.84770012], [87.96835327, 21.84710121], [87.96755981, 21.84609032], [87.96705627, 21.84562111], [87.96669769, 21.84514046], [87.96598053, 21.84433746], [87.96533966, 21.84353065], [87.96425629, 21.84246826], [87.96296692, 21.84151077], [87.96247101, 21.84070587], [87.96161652, 21.84003067], [87.96068573, 21.83916092], [87.95982361, 21.83821869], [87.95903778, 21.83755112], [87.95810699, 21.83694077], [87.95802307, 21.83658028], [87.95746613, 21.83628273], [87.95722198, 21.83583069], [87.95619202, 21.83527565], [87.95575714, 21.83480072], [87.95483398, 21.83393288], [87.95401001, 21.83309174], [87.95358276, 21.83269119], [87.95307922, 21.83222008], [87.9524231, 21.83188057], [87.95213318, 21.83163071], [87.95194244, 21.8313961], [87.9513855, 21.83111191], [87.95111084, 21.83097649], [87.95014191, 21.82999992], [87.94999695, 21.82944107], [87.94942474, 21.82902527], [87.94911194, 21.82884026], [87.94882202, 21.82860184], [87.94851685, 21.8283329], [87.94816589, 21.82806015], [87.94780731, 21.82780075], [87.94745636, 21.82749939], [87.9471283, 21.82721138], [87.94683838, 21.82692909], [87.9466629, 21.82666969], [87.94416809, 21.82416916], [87.94416809, 21.82389069], [87.9438858, 21.82361031], [87.9438858, 21.82332993], [87.9430542, 21.82250023], [87.94304657, 21.82222748], [87.9422226, 21.82139015], [87.94194794, 21.82139015], [87.94167328, 21.82110977], [87.94139099, 21.82111168], [87.9411087, 21.82083321], [87.94083405, 21.82083321], [87.94055176, 21.82055664], [87.9402771, 21.82055664], [87.93972015, 21.81999969], [87.93972015, 21.81944084], [87.9394455, 21.81916428], [87.9394455, 21.8180542], [87.93888855, 21.81750107], [87.93860626, 21.81750107], [87.93805695, 21.81694031], [87.93777466, 21.81694221], [87.9375, 21.81666756], [87.93723297, 21.81666946], [87.93667603, 21.81610107], [87.9366684, 21.81583214], [87.93638611, 21.81555557], [87.93638611, 21.81528282], [87.93527985, 21.81417274], [87.93527985, 21.81306267], [87.93499756, 21.81278038], [87.93499756, 21.81250191], [87.93444824, 21.81195259], [87.93444824, 21.8116703], [87.93361664, 21.81082916], [87.93360901, 21.81055641], [87.93332672, 21.81028938], [87.93332672, 21.80999947], [87.9327774, 21.80940056], [87.9327774, 21.80805779], [87.9319458, 21.80722046], [87.9319458, 21.80666542], [87.93138885, 21.80611038], [87.93138885, 21.80528069], [87.93110657, 21.80500031], [87.93110657, 21.80445099], [87.93000031, 21.80332947], [87.93000031, 21.80277824], [87.92973328, 21.80249977], [87.92972565, 21.8022213], [87.92944336, 21.80194473], [87.92944336, 21.80111122], [87.9291687, 21.80083275], [87.9291687, 21.80055618], [87.92888641, 21.80027962], [87.92861176, 21.80027962], [87.9283371, 21.80000114], [87.92804718, 21.80000114], [87.92778015, 21.79972076], [87.92749023, 21.79972076], [87.92722321, 21.80000114], [87.92694092, 21.80000114], [87.92624664, 21.80042267], [87.92610931, 21.8005619], [87.92527771, 21.80138969], [87.92506409, 21.80166626], [87.9246521, 21.80215454], [87.92416382, 21.8022213], [87.92388916, 21.80194473], [87.9236145, 21.80194473], [87.92333221, 21.80166626], [87.92305756, 21.80166626], [87.92250061, 21.8022213], [87.92194366, 21.8022213], [87.92166901, 21.80194473], [87.92166901, 21.80166626], [87.92048645, 21.80034065], [87.92028046, 21.80020142], [87.91972351, 21.79999924], [87.91916656, 21.79943848], [87.91860962, 21.7994442], [87.91833496, 21.79916573], [87.91805267, 21.79916954], [87.91777802, 21.79888916], [87.91750336, 21.79888916], [87.91722107, 21.79861069], [87.91665649, 21.79861069], [87.91638947, 21.7983284], [87.91583252, 21.79833412], [87.91555786, 21.79805565], [87.91500092, 21.79805946], [87.91471863, 21.79777908], [87.91416931, 21.79777908], [87.91388702, 21.79750061], [87.91361237, 21.79750061], [87.91306305, 21.79693985], [87.91139221, 21.79694366], [87.91110992, 21.7966671], [87.91062927, 21.7966671], [87.90999603, 21.79667091], [87.90972137, 21.79639053], [87.9091568, 21.79639053], [87.90888977, 21.79610825], [87.90666962, 21.79611206], [87.90611267, 21.79609489], [87.90583038, 21.79609489], [87.90555573, 21.79608345], [87.90472412, 21.79611206], [87.90415192, 21.79565048], [87.90333557, 21.79499054], [87.90277863, 21.7947216], [87.90249634, 21.79444695], [87.90110779, 21.79445076], [87.90083313, 21.79444122], [87.90055847, 21.79443741], [87.90000153, 21.7947216], [87.89971924, 21.7947216], [87.89944458, 21.79500008], [87.89888763, 21.79500008], [87.89861298, 21.7947216], [87.89833069, 21.7947216], [87.89777374, 21.79416466], [87.89666748, 21.79305458], [87.8972168, 21.79249954], [87.89750671, 21.79249954], [87.89888763, 21.79111099], [87.89888763, 21.79083061], [87.89916992, 21.79055405], [87.89916992, 21.79027939], [87.89943695, 21.79000092], [87.89916992, 21.78972054], [87.89944458, 21.78944206], [87.89916992, 21.7891674], [87.89861298, 21.7891674], [87.89833069, 21.78944206], [87.89805603, 21.78944206], [87.89778137, 21.78972244], [87.89750671, 21.78972054], [87.8972168, 21.79000092], [87.89666748, 21.79000092], [87.89639282, 21.79027939], [87.89611053, 21.79027939], [87.89583588, 21.79055977], [87.89554596, 21.79055977], [87.89499664, 21.79111099], [87.89472198, 21.79111099], [87.89444733, 21.79138947], [87.89416504, 21.79138947], [87.89360809, 21.79194641], [87.89333344, 21.79194641], [87.89305878, 21.79222488], [87.89277649, 21.79222107], [87.89250183, 21.79249954], [87.89221954, 21.79249954], [87.89193726, 21.79277992], [87.89138031, 21.79277992], [87.89111328, 21.7930603], [87.89083099, 21.79305458], [87.89055634, 21.79333305], [87.8898468, 21.79353523], [87.88916016, 21.79297066], [87.88902283, 21.79276085], [87.88867188, 21.79235649], [87.88833618, 21.79166985], [87.88804626, 21.79117012], [87.88861084, 21.79055977], [87.88902283, 21.7904911], [87.8897171, 21.79000092], [87.8898468, 21.78993034], [87.89026642, 21.78924179], [87.89019775, 21.7891674], [87.89061737, 21.7888298], [87.89080048, 21.78835106], [87.89131927, 21.78799057], [87.89193726, 21.78750038], [87.89221954, 21.78750038], [87.89250183, 21.78722191], [87.89292145, 21.78701973], [87.89311981, 21.78652954], [87.89333344, 21.78611183], [87.8944397, 21.78499985], [87.8944397, 21.78471756], [87.89472198, 21.78444481], [87.89472198, 21.78388977], [87.8944397, 21.78360748], [87.89444733, 21.78305626], [87.89305878, 21.78166771], [87.89305878, 21.78083038], [87.89277649, 21.78055763], [87.89277649, 21.77999115], [87.89194489, 21.77916527], [87.89167023, 21.77917099], [87.89125061, 21.77875137], [87.89083099, 21.77832985], [87.89055634, 21.77833557], [87.89027405, 21.77805328], [87.88999939, 21.77806091], [87.8897171, 21.77778053], [87.88833618, 21.77778053], [87.88804626, 21.77806091], [87.88777924, 21.77806091], [87.88694763, 21.77721977], [87.88694763, 21.77694321], [87.88582611, 21.77583122], [87.88555908, 21.77583122], [87.88527679, 21.77555466], [87.88465118, 21.7754879], [87.88388824, 21.77472115], [87.88388824, 21.77361107], [87.8833313, 21.77306175], [87.8833313, 21.77277946], [87.88223267, 21.77166939], [87.88223267, 21.77082825], [87.88166809, 21.77027893], [87.88166809, 21.77000046], [87.8813858, 21.76971817], [87.88083649, 21.76972198], [87.88083649, 21.76944351], [87.8805542, 21.76916885], [87.88054657, 21.76889038], [87.87944031, 21.7677803], [87.87944031, 21.76749992], [87.87915039, 21.76721954], [87.87893677, 21.76680183], [87.87895203, 21.76631355], [87.87889099, 21.76610947], [87.87750244, 21.76472473], [87.87722015, 21.76472473], [87.8758316, 21.76333237], [87.87554932, 21.7630558], [87.87471008, 21.76249123], [87.87444305, 21.76222038], [87.87381744, 21.76159286], [87.87361145, 21.76139069], [87.87166595, 21.75945282], [87.8713913, 21.75944519], [87.87110901, 21.75972176], [87.87055206, 21.75972176], [87.87000275, 21.7602787], [87.87000275, 21.76044083], [87.87000275, 21.7605629], [87.8722229, 21.76278114], [87.87249756, 21.76278114], [87.87277985, 21.76305962], [87.8730545, 21.7630558], [87.8740921, 21.7640934], [87.87444305, 21.76444435], [87.87473297, 21.76444054], [87.87527466, 21.76499939], [87.87548065, 21.76520157], [87.87546539, 21.76562309], [87.87555695, 21.76610947], [87.8757019, 21.76632118], [87.87605286, 21.76667023], [87.87619019, 21.76680946], [87.87632751, 21.76688004], [87.87660217, 21.76708794], [87.8769455, 21.76722145], [87.87805176, 21.76833344], [87.87805176, 21.76860809], [87.87832642, 21.76889038], [87.87833405, 21.76916885], [87.87851715, 21.76935005], [87.8786087, 21.76944351], [87.8786087, 21.76971817], [87.87889099, 21.77000046], [87.87889099, 21.77028084], [87.87916565, 21.7705555], [87.87916565, 21.77083397], [87.87940979, 21.77135086], [87.8797226, 21.77166748], [87.88249969, 21.77444458], [87.88249969, 21.77472115], [87.88388824, 21.7761097], [87.88394928, 21.77638054], [87.8841629, 21.77667046], [87.88444519, 21.77694321], [87.88445282, 21.77721977], [87.88511658, 21.77820015], [87.88527679, 21.77861023], [87.88527679, 21.7788887], [87.88471985, 21.77944374], [87.88444519, 21.77944374], [87.8841629, 21.77916527], [87.88388824, 21.77916527], [87.88361359, 21.77944374], [87.8833313, 21.77944374], [87.88222504, 21.77833557], [87.88194275, 21.77833557], [87.88083649, 21.77722168], [87.88083649, 21.77694321], [87.88027954, 21.77639008], [87.88027954, 21.7761097], [87.87999725, 21.77583122], [87.87999725, 21.77555466], [87.8797226, 21.77527809], [87.8797226, 21.77503967], [87.8797226, 21.77444458], [87.87956238, 21.77428436], [87.87805176, 21.77277756], [87.87805176, 21.77249908], [87.87737274, 21.77166939], [87.87722015, 21.77111053], [87.87695313, 21.77055931], [87.87666321, 21.76971817], [87.8758316, 21.76888847], [87.8758316, 21.76860809], [87.875, 21.7677784], [87.87473297, 21.7677803], [87.8741684, 21.76721954], [87.87388611, 21.76722145], [87.87354279, 21.76716042], [87.87333679, 21.76723099], [87.87304688, 21.76721954], [87.8729248, 21.76688576], [87.87277985, 21.76667023], [87.87110901, 21.76501083], [87.87082672, 21.76501083], [87.87055206, 21.76472092], [87.8702774, 21.76472473], [87.87010956, 21.76454926], [87.87000275, 21.76444435], [87.86972046, 21.76444435], [87.8694458, 21.76416588], [87.86915588, 21.76416969], [87.86860657, 21.76361084], [87.86860657, 21.76333046], [87.86638641, 21.76111031], [87.8658371, 21.76111031], [87.86528015, 21.7605629], [87.86499786, 21.7605629], [87.86416626, 21.75972176], [87.8638916, 21.75972176], [87.86360931, 21.75944519], [87.86332703, 21.75945282], [87.86250305, 21.75861168], [87.86250305, 21.75805473], [87.8611145, 21.75666618], [87.86083221, 21.75666809], [87.86055756, 21.75638962], [87.86000061, 21.75638962], [87.85943604, 21.75582123], [87.85916901, 21.75583267], [87.85832977, 21.75499725], [87.85806274, 21.75500107], [87.85749817, 21.75444031], [87.85722351, 21.75444412], [87.85527802, 21.75250053], [87.85500336, 21.75250053], [87.85472107, 21.75222015], [87.85416412, 21.75222206], [87.85221863, 21.75027847], [87.85193634, 21.75028038], [87.85111237, 21.74945068], [87.85083008, 21.74945068], [87.85028076, 21.74888992], [87.84999847, 21.74888992], [87.84971619, 21.74860954], [87.84944153, 21.74861145], [87.84889221, 21.74805641], [87.84876251, 21.74772072], [87.84841156, 21.74751091], [87.84805298, 21.7472229], [87.84722137, 21.7465229], [87.84638977, 21.74638939], [87.84416962, 21.74416924], [87.84403229, 21.7439003], [87.8434906, 21.7434082], [87.84333038, 21.74333382], [87.84278107, 21.74277878], [87.84221649, 21.74221992], [87.84223175, 21.74208832], [87.84028625, 21.74055099], [87.84007263, 21.74035454], [87.83916473, 21.7397213], [87.83895874, 21.73952103], [87.83666992, 21.73749924], [87.83638763, 21.73750114], [87.83583069, 21.73694038], [87.83555603, 21.73694229], [87.83444214, 21.73583221], [87.83333588, 21.73583221], [87.83305359, 21.73555565], [87.83222198, 21.73521996], [87.83082581, 21.73417282], [87.83082581, 21.73361015], [87.83110809, 21.73333359], [87.83027649, 21.73250008], [87.82971954, 21.73250008], [87.82917023, 21.73193932], [87.82888794, 21.73194504], [87.82888794, 21.73166656], [87.82833099, 21.73110962], [87.82833099, 21.73083305], [87.82805634, 21.73055649], [87.82776642, 21.7305584], [87.8216629, 21.72445107], [87.82138824, 21.72445107], [87.82110596, 21.72417068], [87.82055664, 21.72417068], [87.81999969, 21.72360992], [87.81999969, 21.72333336], [87.81972504, 21.72305489], [87.81999969, 21.72277832], [87.81999969, 21.72249985], [87.82026672, 21.72221947], [87.82055664, 21.72221947], [87.8208313, 21.72249985], [87.82110596, 21.7226429], [87.82138824, 21.72278023], [87.82158661, 21.72305107], [87.82200623, 21.72353554], [87.82222748, 21.72360992], [87.8236084, 21.72500038], [87.82417297, 21.72500038], [87.82472229, 21.72444344], [87.82472229, 21.72417068], [87.82499695, 21.7238903], [87.82499695, 21.72360992], [87.82472229, 21.72333336], [87.82472229, 21.72305489], [87.82416534, 21.72249985], [87.82332611, 21.72249985], [87.82222748, 21.72138977], [87.82221985, 21.72027779], [87.8216629, 21.71970749], [87.82138824, 21.71972275], [87.81972504, 21.71805573], [87.81973267, 21.71777916], [87.81916046, 21.7172184], [87.81916809, 21.71694374], [87.8180542, 21.71583366], [87.8180542, 21.71555519], [87.81777954, 21.71528053], [87.81777954, 21.71471977], [87.81749725, 21.71444511], [87.81749725, 21.71417046], [87.8172226, 21.71389961], [87.8172226, 21.7136097], [87.81694794, 21.71333313], [87.81694794, 21.71305656], [87.81500244, 21.71111107], [87.81478882, 21.71096992], [87.81416321, 21.71055412], [87.81341553, 21.70981789], [87.80951691, 21.70596695], [87.8088913, 21.70583153], [87.80750275, 21.70464706], [87.80722046, 21.70443916], [87.80673981, 21.70422554], [87.80607605, 21.70397949], [87.80583191, 21.70388985], [87.805336, 21.70339203], [87.80444336, 21.70249939], [87.80375671, 21.70229912], [87.80304718, 21.70194054], [87.80236816, 21.70174217], [87.80166626, 21.70138931], [87.80146027, 21.70119095], [87.80082703, 21.70083046], [87.80007172, 21.70049667], [87.79988098, 21.70053291], [87.79972076, 21.70055962], [87.79840851, 21.70036125], [87.7977066, 21.69959068], [87.79750061, 21.69944], [87.79724121, 21.6991806], [87.79638672, 21.69833565], [87.79611206, 21.69833565], [87.79555511, 21.6977787], [87.79528046, 21.69778061], [87.79499054, 21.69750023], [87.79471588, 21.69750023], [87.79449463, 21.69727707], [87.79444122, 21.69721985], [87.79389191, 21.69722176], [87.79360962, 21.69694328], [87.79334259, 21.69695091], [87.79305267, 21.69667053], [87.79277802, 21.69667053], [87.79250336, 21.69639015], [87.79222107, 21.69639015], [87.79194641, 21.69610977], [87.79166412, 21.69611168], [87.79138947, 21.6958313], [87.79111481, 21.6958313], [87.79083252, 21.69555473], [87.79055786, 21.69555473], [87.79027557, 21.69527817], [87.79000092, 21.69528008], [87.78971863, 21.69499969], [87.78946686, 21.69499969], [87.78861237, 21.69499969], [87.78833008, 21.69472122], [87.78722382, 21.69472122], [87.78694153, 21.69466209], [87.78666687, 21.69466209], [87.78639221, 21.69472122], [87.78527832, 21.69472122], [87.78500366, 21.69473076], [87.78482056, 21.69475365], [87.78444672, 21.69479942], [87.78426361, 21.69467926], [87.78388977, 21.69444275], [87.78360748, 21.69444466], [87.78333282, 21.69416618], [87.78305054, 21.69417191], [87.78277588, 21.69411087], [87.78221893, 21.69431114], [87.78193665, 21.69417191], [87.78166962, 21.69417191], [87.78138733, 21.69388962], [87.77972412, 21.69388962], [87.77937317, 21.69403267], [87.77868652, 21.6939621], [87.77833557, 21.69388962], [87.77777863, 21.69388962], [87.77749634, 21.69361115], [87.77722168, 21.69361115], [87.77694702, 21.69388962], [87.77500153, 21.69388962], [87.77465057, 21.69403267], [87.77388763, 21.69417191], [87.77346802, 21.69417572], [87.77278137, 21.69444466], [87.77235413, 21.69445229], [87.77166748, 21.69472122], [87.77139282, 21.69499969], [87.77083588, 21.69499969], [87.77054596, 21.69528008], [87.76860809, 21.69527817], [87.76833344, 21.69555473], [87.76750183, 21.69555473], [87.76721954, 21.6958313], [87.76638794, 21.6958313], [87.76611328, 21.69611168], [87.76555634, 21.69610977], [87.76526642, 21.69639015], [87.76500702, 21.69639015], [87.76444244, 21.69695091], [87.76416779, 21.69694328], [87.7638855, 21.69722176], [87.76361084, 21.69721985], [87.76304626, 21.69778061], [87.76249695, 21.69778061], [87.76222229, 21.69806099], [87.76194763, 21.69806099], [87.76132202, 21.69743347], [87.7611084, 21.69722176], [87.7611084, 21.69694328], [87.76055908, 21.69638824], [87.75971985, 21.69721985], [87.75971985, 21.69806099], [87.75861359, 21.69916534], [87.75861359, 21.69944572], [87.7583313, 21.69944], [87.75776672, 21.70000076], [87.75749969, 21.69972038], [87.75694275, 21.69972229], [87.75666809, 21.69944572], [87.7563858, 21.69944], [87.75583649, 21.70000076], [87.75554657, 21.70000076], [87.75527954, 21.69972038], [87.75499725, 21.69972229], [87.7547226, 21.69944572], [87.75444794, 21.69944572], [87.75416565, 21.69916534], [87.7536087, 21.69972229], [87.75333405, 21.69972229], [87.75250244, 21.69888878], [87.75110626, 21.69890022], [87.75026703, 21.69806099], [87.75026703, 21.69639015], [87.75029755, 21.69625092], [87.75026703, 21.69610977], [87.75041199, 21.69605255], [87.7508316, 21.69611168], [87.75111389, 21.69611168], [87.75222015, 21.69722176], [87.75250244, 21.69721985], [87.7527771, 21.69750023], [87.75332642, 21.69750023], [87.7536087, 21.69721985], [87.75389099, 21.69722176], [87.75416565, 21.69694328], [87.75417328, 21.69667053], [87.75389099, 21.69639015]], [[88.99397278, 26.32003403], [88.99365997, 26.32025909], [88.99307251, 26.32024384], [88.99397278, 26.32003403]], [[88.2853775, 24.8884697], [88.28574371, 24.88817024], [88.28593445, 24.88802147], [88.28596497, 24.88816643], [88.28585052, 24.88828087], [88.2853775, 24.8884697]], [[88.92998505, 22.65362549], [88.93003082, 22.65386581], [88.92976379, 22.65390015], [88.92939758, 22.65398026], [88.92941284, 22.65365982], [88.92998505, 22.65362549]], [[88.58655548, 23.81160927], [88.58647919, 23.8113308], [88.58666229, 23.81118965], [88.58655548, 23.81160927]], [[89.34877777, 26.01606178], [89.34773254, 26.01514053], [89.34732056, 26.01499557], [89.34793854, 26.01499748], [89.34911346, 26.0150032], [89.34912109, 26.01525307], [89.34916687, 26.01624107], [89.34877777, 26.01606178]], [[89.56465149, 26.0606575], [89.5642395, 26.06067085], [89.563797, 26.06075096], [89.56336212, 26.06081581], [89.56300354, 26.06089783], [89.56260681, 26.06102753], [89.56218719, 26.06118774], [89.56176758, 26.06131554], [89.5612793, 26.06142616], [89.56098175, 26.06151581], [89.56070709, 26.06158829], [89.56044769, 26.06168365], [89.56021881, 26.06176758], [89.55995941, 26.06188965], [89.55970001, 26.06199455], [89.55944824, 26.0621624], [89.55922699, 26.06231117], [89.55908966, 26.06241798], [89.5589447, 26.06255531], [89.55883026, 26.06270599], [89.55872345, 26.06286621], [89.55862427, 26.06305122], [89.55856323, 26.06319046], [89.55848694, 26.06333542], [89.55841064, 26.06348419], [89.55834961, 26.06362152], [89.55828857, 26.06369972], [89.55821228, 26.06376457], [89.55806732, 26.06383514], [89.55791473, 26.06393623], [89.55776215, 26.06399155], [89.55757904, 26.06408882], [89.55743408, 26.06417274], [89.55723572, 26.06432533], [89.55706787, 26.0644474], [89.55688477, 26.06457901], [89.55675507, 26.0647068], [89.55662537, 26.06481743], [89.55651093, 26.06491852], [89.55644226, 26.064991], [89.55632782, 26.06509781], [89.55619812, 26.06519127], [89.55609894, 26.06525803], [89.55597687, 26.06534767], [89.55584717, 26.06541252], [89.55568695, 26.06548309], [89.55551147, 26.06555939], [89.55537415, 26.06558228], [89.55517578, 26.06559944], [89.55504608, 26.06556892], [89.55484009, 26.06552124], [89.55463409, 26.0654583], [89.55442047, 26.06540108], [89.5541153, 26.06531715], [89.55386353, 26.06527138], [89.55361176, 26.06523323], [89.55336761, 26.06520271], [89.55302429, 26.06508636], [89.55274963, 26.06495857], [89.55246735, 26.06477737], [89.55223083, 26.06456184], [89.55210114, 26.06430054], [89.55198669, 26.06407928], [89.55189514, 26.06382179], [89.5517807, 26.06349945], [89.55169678, 26.06321144], [89.551651, 26.06306076], [89.55162048, 26.0627594], [89.55162048, 26.06258583], [89.55162048, 26.06243706], [89.55162048, 26.06231117], [89.5515976, 26.06217003], [89.5515976, 26.06192017], [89.55162811, 26.06168747], [89.551651, 26.06150246], [89.55167389, 26.06121063], [89.55171204, 26.06094551], [89.55173492, 26.06066132], [89.55175781, 26.06038857], [89.55176544, 26.06016541], [89.55180359, 26.05986977], [89.55183411, 26.05959129], [89.55188751, 26.0592289], [89.55192566, 26.05884361], [89.55196381, 26.05851746], [89.55202484, 26.05813599], [89.55210114, 26.05779076], [89.55222321, 26.05752754], [89.55238342, 26.05724525], [89.55261993, 26.05695915], [89.55286407, 26.05672073], [89.55314636, 26.05642509], [89.55328369, 26.05620956], [89.55341339, 26.05596542], [89.55352783, 26.05573654], [89.55365753, 26.05548286], [89.55381775, 26.05523109], [89.55393982, 26.05504227], [89.55412292, 26.05486679], [89.55430603, 26.05466843], [89.55448151, 26.05444717], [89.55466461, 26.05413055], [89.55482483, 26.05380249], [89.55502319, 26.05341339], [89.55518341, 26.05304909], [89.55540466, 26.05264473], [89.55561066, 26.05238914], [89.55582428, 26.05222321], [89.55604553, 26.05204582], [89.55633545, 26.05179405], [89.5566864, 26.05147934], [89.55699158, 26.0512104], [89.55725098, 26.05098724], [89.55751038, 26.05074692], [89.55773926, 26.05056953], [89.55799103, 26.05037498], [89.55820465, 26.05025673], [89.55841064, 26.05013847], [89.55859375, 26.05014038], [89.55873108, 26.05013275], [89.55896759, 26.05008507], [89.55914307, 26.05004501], [89.55940247, 26.04999733], [89.55970001, 26.04998016], [89.55995941, 26.04996681], [89.56034851, 26.04999733], [89.56075287, 26.05003548], [89.56111908, 26.05012894], [89.56144714, 26.05021286], [89.56167603, 26.05025291], [89.56196594, 26.05032921], [89.56230927, 26.05039597], [89.5626297, 26.05047989], [89.56304169, 26.05055618], [89.56337738, 26.0506115], [89.56370544, 26.05065155], [89.56403351, 26.05071068], [89.56441498, 26.05077744], [89.56472015, 26.05083847], [89.56510162, 26.0509243], [89.56546783, 26.05097961], [89.56581879, 26.05106544], [89.56610107, 26.05109596], [89.56634521, 26.05113983], [89.56665039, 26.05123711], [89.56697845, 26.05139923], [89.56726837, 26.05155754], [89.56761169, 26.05173492], [89.56788635, 26.05192184], [89.56812286, 26.05210304], [89.56835938, 26.0522995], [89.56859589, 26.05249405], [89.56886292, 26.0527668], [89.56912231, 26.05306816], [89.56929779, 26.05326653], [89.56941986, 26.05346298], [89.56954193, 26.05360985], [89.56965637, 26.05374146], [89.56976318, 26.05385399], [89.56990051, 26.053936], [89.57003021, 26.05396843], [89.5701828, 26.05387115], [89.57035828, 26.05360985], [89.57047272, 26.05335426], [89.57065582, 26.05293655], [89.57077789, 26.0526886], [89.57087708, 26.05249977], [89.57095337, 26.05233574], [89.57107544, 26.05221558], [89.57123566, 26.05215836], [89.57136536, 26.05221558], [89.57145691, 26.05231094], [89.57158661, 26.05251312], [89.57170105, 26.05284119], [89.57175446, 26.05323792], [89.57175446, 26.05376053], [89.5717926, 26.05425262], [89.57196808, 26.05471992], [89.5721283, 26.0551281], [89.57239532, 26.05570412], [89.57258606, 26.05619621], [89.57286072, 26.05681419], [89.5730896, 26.05735779], [89.57329559, 26.05774498], [89.57350159, 26.05817795], [89.57364655, 26.05853462], [89.57375336, 26.05884171], [89.57379913, 26.05922318], [89.57383728, 26.05950165], [89.57380676, 26.05984306], [89.57375336, 26.06008148], [89.57372284, 26.0603199], [89.5737381, 26.06047249], [89.57378387, 26.06072617], [89.57384491, 26.06094933], [89.57374573, 26.06108475], [89.57355499, 26.06118393], [89.57328796, 26.06126976], [89.57312775, 26.06135178], [89.57296753, 26.06147575], [89.57280731, 26.06159782], [89.57254028, 26.06188774], [89.57256317, 26.06222725], [89.57279205, 26.06267929], [89.57283783, 26.0630188], [89.57238007, 26.06312752], [89.57159424, 26.06267166], [89.57113647, 26.06246948], [89.57091522, 26.06233978], [89.57067108, 26.06219292], [89.57034302, 26.06199837], [89.57000732, 26.06181335], [89.56954193, 26.06158257], [89.56900024, 26.06134987], [89.56848907, 26.061203], [89.5679245, 26.06101608], [89.56738281, 26.0608654], [89.5669632, 26.06079292], [89.56656647, 26.06075859], [89.56629944, 26.06072998], [89.56595612, 26.0606823], [89.56548309, 26.0606575], [89.56510925, 26.06062508], [89.56465149, 26.0606575]], [[89.50184631, 26.06993484], [89.50170898, 26.0699482], [89.50151825, 26.06996155], [89.50138855, 26.06999588], [89.50117493, 26.0700264], [89.50093842, 26.07005692], [89.50062561, 26.07007027], [89.50038147, 26.07005119], [89.50014496, 26.07004166], [89.49991608, 26.07000351], [89.49967194, 26.06996346], [89.49941254, 26.06991196], [89.49907684, 26.06979752], [89.49890137, 26.06973839], [89.498703, 26.06966972], [89.49859619, 26.06958961], [89.49855042, 26.06949425], [89.49854279, 26.06938171], [89.49848175, 26.06911278], [89.49843597, 26.06896973], [89.4983902, 26.06882858], [89.49830627, 26.06848335], [89.4982605, 26.06834412], [89.49813843, 26.0678997], [89.49808502, 26.0676918], [89.49806213, 26.06746292], [89.4980545, 26.06724358], [89.49812317, 26.06699753], [89.49817657, 26.0668602], [89.49825287, 26.06672096], [89.49832153, 26.06663322], [89.49845123, 26.06646347], [89.49853516, 26.06637955], [89.49861908, 26.06632614], [89.49874878, 26.0662384], [89.498909, 26.06613541], [89.49903107, 26.06608009], [89.49914551, 26.06604004], [89.49925995, 26.06601524], [89.4993515, 26.06596565], [89.49940491, 26.06590652], [89.49951172, 26.06581497], [89.49958801, 26.06568909], [89.49966431, 26.06554222], [89.49972534, 26.06538582], [89.49979401, 26.06510353], [89.4998703, 26.06498337], [89.49993134, 26.06484413], [89.50000763, 26.06472969], [89.50010681, 26.06462669], [89.50022888, 26.0645256], [89.50035095, 26.06442451], [89.50047302, 26.06432152], [89.50061798, 26.06421852], [89.50078583, 26.06411171], [89.50102997, 26.06399345], [89.50113678, 26.06388474], [89.50128174, 26.0637989], [89.5014267, 26.06371117], [89.50157166, 26.06360054], [89.5016861, 26.06347466], [89.50189972, 26.06322861], [89.50200653, 26.06305695], [89.50202942, 26.06288338], [89.50205231, 26.06274986], [89.50206757, 26.06262589], [89.5020752, 26.06250191], [89.50215149, 26.06219292], [89.5022049, 26.062006], [89.50228882, 26.06182289], [89.50241089, 26.06152725], [89.50247955, 26.06130791], [89.50244141, 26.06109047], [89.50242615, 26.06092834], [89.50245667, 26.06078911], [89.50247192, 26.06062698], [89.50253296, 26.06036949], [89.50257874, 26.06020737], [89.50266266, 26.06000328], [89.50292969, 26.05973816], [89.50346375, 26.05921364], [89.50360107, 26.05912018], [89.50371552, 26.05903244], [89.50373077, 26.05894661], [89.50415039, 26.05873871], [89.50428009, 26.05875778], [89.50447083, 26.05867958], [89.50461578, 26.05854225], [89.50473022, 26.05841064], [89.50483704, 26.05834007], [89.50495148, 26.05830765], [89.50505066, 26.05831337], [89.50519562, 26.05831528], [89.50537872, 26.05833435], [89.50567627, 26.05832863], [89.50591278, 26.05829048], [89.50608063, 26.0582428], [89.5062561, 26.05817604], [89.50644684, 26.05811691], [89.50655365, 26.05810356], [89.50675201, 26.05815697], [89.50694275, 26.05820084], [89.50706482, 26.05822945], [89.50723267, 26.0582428], [89.50737762, 26.05822182], [89.50752258, 26.05818748], [89.50762939, 26.05815697], [89.50774384, 26.05812836], [89.50790405, 26.05811119], [89.50810242, 26.05810738], [89.50839233, 26.05808067], [89.5085144, 26.05805397], [89.50880432, 26.0580368], [89.50891113, 26.05802536], [89.50931549, 26.0579586], [89.50951385, 26.05788994], [89.50963593, 26.05783272], [89.509758, 26.05779266], [89.51003265, 26.05764008], [89.51013947, 26.05757713], [89.51039124, 26.0574894], [89.51068115, 26.05742455], [89.5110321, 26.05742264], [89.51148224, 26.05756569], [89.51168823, 26.05766296], [89.51190186, 26.0578804], [89.51228333, 26.05828667], [89.51261902, 26.05858803], [89.51272583, 26.05867958], [89.51290131, 26.05883026], [89.51305389, 26.05896187], [89.51319122, 26.05908585], [89.51340485, 26.05925941], [89.51359558, 26.05941391], [89.51379395, 26.05967903], [89.51398468, 26.06008148], [89.51413727, 26.06047249], [89.51418304, 26.0607605], [89.51422119, 26.06092262], [89.51421356, 26.06114578], [89.51419067, 26.06146049], [89.51416779, 26.0617733], [89.51412201, 26.06215096], [89.51409149, 26.06226921], [89.5140686, 26.06240273], [89.51406097, 26.06254959], [89.51407623, 26.06271553], [89.51409149, 26.06295776], [89.51409912, 26.06310654], [89.51407623, 26.06329727], [89.51404572, 26.06336975], [89.51396179, 26.06359673], [89.51395416, 26.06372833], [89.51406097, 26.06411743], [89.51415253, 26.06424713], [89.51425934, 26.06440353], [89.51438141, 26.06457901], [89.51446533, 26.06474304], [89.51459503, 26.06499863], [89.51457214, 26.06508636], [89.51454926, 26.06522179], [89.51451111, 26.06537819], [89.5144577, 26.06547737], [89.51441193, 26.06557846], [89.51434326, 26.06562805], [89.51417542, 26.06580734], [89.51409912, 26.06586075], [89.51396179, 26.06591797], [89.51384735, 26.06598091], [89.51372528, 26.06602097], [89.51361847, 26.06604767], [89.51351929, 26.06609154], [89.51342773, 26.06612206], [89.51325989, 26.06618118], [89.51303101, 26.06625748], [89.51293182, 26.06628036], [89.51273346, 26.0663662], [89.51255798, 26.06645203], [89.5124054, 26.06652069], [89.51232147, 26.06656837], [89.5122757, 26.06649971], [89.51217651, 26.06652641], [89.51203156, 26.06658363], [89.51191711, 26.06664085], [89.51182556, 26.06666756], [89.51172638, 26.06668854], [89.51158905, 26.06674576], [89.51150513, 26.06678009], [89.5114212, 26.06682205], [89.51134491, 26.06686592], [89.5112381, 26.06692314], [89.51111603, 26.06697083], [89.5109787, 26.06699181], [89.51089478, 26.06697655], [89.51077271, 26.06695557], [89.51065826, 26.0669651], [89.51052094, 26.06698418], [89.51036072, 26.06702805], [89.51022339, 26.06704903], [89.51000977, 26.06705093], [89.50991821, 26.06707001], [89.50979614, 26.06706429], [89.50961304, 26.06708717], [89.50944519, 26.06711769], [89.50922394, 26.06716919], [89.50907898, 26.06720352], [89.50896454, 26.06723404], [89.50884247, 26.06725883], [89.50866699, 26.06723404], [89.508461, 26.0672245], [89.50823975, 26.06720543], [89.50798798, 26.0671978], [89.50776672, 26.06721306], [89.50765228, 26.06723976], [89.50738525, 26.06729698], [89.507164, 26.06739235], [89.50695038, 26.06751823], [89.50680542, 26.06765175], [89.50669098, 26.06779099], [89.50659943, 26.0679512], [89.50650787, 26.06806183], [89.50643158, 26.06821251], [89.50637817, 26.06837845], [89.50630188, 26.06852913], [89.50623322, 26.06859398], [89.50615692, 26.06863213], [89.506073, 26.06866837], [89.50585938, 26.06874084], [89.50574493, 26.06878471], [89.50562286, 26.06881905], [89.50544739, 26.06892204], [89.50535583, 26.06898499], [89.50528717, 26.06906128], [89.50522614, 26.06913185], [89.50510406, 26.0692749], [89.50504303, 26.06936836], [89.50492859, 26.069561], [89.50480652, 26.06968689], [89.50473785, 26.06975746], [89.50465393, 26.0698185], [89.50453186, 26.06987953], [89.50443268, 26.06994057], [89.50428772, 26.06995392], [89.50415039, 26.06997299], [89.50402832, 26.0700016], [89.50385284, 26.07001495], [89.50374603, 26.07000923], [89.50363159, 26.07001686], [89.50351715, 26.07003212], [89.50341034, 26.07001686], [89.50331879, 26.0700264], [89.50319672, 26.06999588], [89.50300598, 26.06995773], [89.5029068, 26.06992531], [89.50283051, 26.06993675], [89.50275421, 26.06994629], [89.50263977, 26.06996155], [89.50250244, 26.06994438], [89.5022049, 26.0699482], [89.50209808, 26.06993294], [89.50196838, 26.06991959], [89.50184631, 26.06993484]], [[89.60414124, 26.12532043], [89.60419464, 26.12583351], [89.60406494, 26.12590599], [89.60414124, 26.12532043]], [[89.63412476, 26.19461441], [89.63297272, 26.1925602], [89.63302612, 26.19170952], [89.63508606, 26.19046402], [89.6350174, 26.19173431], [89.63499451, 26.19232178], [89.63562012, 26.19325066], [89.63596344, 26.19376183], [89.63412476, 26.19461441]], [[89.58585358, 26.18371201], [89.5860672, 26.18405914], [89.58627319, 26.18457985], [89.58648682, 26.18507767], [89.58663177, 26.18537331], [89.5867691, 26.18556023], [89.58688354, 26.18564987], [89.58715057, 26.18598366], [89.58745575, 26.18638039], [89.58761597, 26.18680763], [89.58771515, 26.18757057], [89.58773041, 26.18815804], [89.58773041, 26.18846321], [89.58766937, 26.18870544], [89.58759308, 26.18883133], [89.58744049, 26.18900108], [89.58729553, 26.18915176], [89.58706665, 26.18940353], [89.58683014, 26.18947983], [89.58654022, 26.18948746], [89.58625031, 26.18952942], [89.58603668, 26.18952942], [89.58580017, 26.18950653], [89.58545685, 26.1888485], [89.58527374, 26.1885643], [89.58499908, 26.18809319], [89.58473969, 26.18762589], [89.58448029, 26.18703651], [89.58424377, 26.18648529], [89.58392334, 26.18584824], [89.58370972, 26.18541908], [89.58348846, 26.18502235], [89.58325958, 26.18462944], [89.58317566, 26.18442154], [89.58314514, 26.18412971], [89.58325195, 26.18403053], [89.58346558, 26.18393326], [89.58391571, 26.18382072], [89.58444977, 26.18372154], [89.58519745, 26.18359947], [89.58558655, 26.18357849], [89.58585358, 26.18371201]], [[89.62191772, 26.20042419], [89.62172699, 26.2009201], [89.62151337, 26.20120239], [89.62138367, 26.20137978], [89.62124634, 26.20140266], [89.62112427, 26.20135307], [89.62088013, 26.201231], [89.62062836, 26.2010994], [89.62042236, 26.20098114], [89.62017822, 26.20087051], [89.61994934, 26.20071983], [89.6197052, 26.20053864], [89.61943817, 26.20031548], [89.61921692, 26.20014191], [89.61920166, 26.20000839], [89.61927032, 26.19976044], [89.61936188, 26.19951057], [89.61946869, 26.19919777], [89.6195755, 26.19897842], [89.61965179, 26.19882393], [89.61972809, 26.19861031], [89.61977386, 26.19843864], [89.61978149, 26.1982193], [89.61975861, 26.19804192], [89.61972046, 26.19784927], [89.61961365, 26.19761276], [89.61952209, 26.19741249], [89.61940765, 26.19725418], [89.61925507, 26.19716263], [89.61907959, 26.19713211], [89.61870575, 26.19725037], [89.61840057, 26.19742775], [89.61810303, 26.19756699], [89.61785889, 26.19762421], [89.61759949, 26.19769859], [89.61732483, 26.197752], [89.61708832, 26.19782448], [89.61684418, 26.19791031], [89.61656189, 26.19803429], [89.61636353, 26.19815826], [89.61617279, 26.19826126], [89.61606598, 26.19827461], [89.61582184, 26.19824791], [89.61560059, 26.19815254], [89.61528778, 26.19796944], [89.6149292, 26.19769096], [89.61464691, 26.19749069], [89.61428833, 26.19725609], [89.61408234, 26.19714165], [89.61390686, 26.19707108], [89.61380768, 26.19700241], [89.61373901, 26.19689751], [89.6137619, 26.19665337], [89.61386871, 26.19636917], [89.61398315, 26.19610405], [89.6140976, 26.19575882], [89.61420441, 26.19539642], [89.61427307, 26.19509888], [89.61434174, 26.1947937], [89.61437988, 26.19457054], [89.6144104, 26.19429207], [89.61440277, 26.19404411], [89.61438751, 26.19385529], [89.61436462, 26.19360542], [89.61436462, 26.1934166], [89.61438751, 26.19327164], [89.61440277, 26.1931591], [89.6144104, 26.19301033], [89.61444855, 26.19286156], [89.61453247, 26.19272804], [89.61461639, 26.19257545], [89.61474609, 26.19239807], [89.61485291, 26.19226265], [89.6149826, 26.19211769], [89.61507416, 26.19197845], [89.61520386, 26.19181633], [89.61529541, 26.19161797], [89.61537933, 26.19147682], [89.61548615, 26.19126511], [89.61555481, 26.19104004], [89.6156311, 26.19086456], [89.61566925, 26.19062614], [89.6157074, 26.19046402], [89.6157608, 26.19029427], [89.61579132, 26.19012451], [89.61581421, 26.18997955], [89.61581421, 26.18983459], [89.61579132, 26.18973351], [89.61572266, 26.18959808], [89.6155014, 26.18962669], [89.61521149, 26.18977928], [89.61497498, 26.18993378], [89.61473083, 26.19009018], [89.61450958, 26.1902523], [89.61424255, 26.19043541], [89.61392212, 26.19064903], [89.61365509, 26.19079971], [89.61338043, 26.19094086], [89.61320496, 26.19107246], [89.61299133, 26.19122887], [89.61282349, 26.19141579], [89.61257172, 26.19167519], [89.61239624, 26.19190216], [89.61219788, 26.19210434], [89.6120224, 26.19224167], [89.61185455, 26.19234467], [89.61164093, 26.19241333], [89.6113739, 26.19245148], [89.61113739, 26.19244003], [89.61081696, 26.19239426], [89.61057281, 26.19234467], [89.61031342, 26.19228745], [89.61006165, 26.19226074], [89.60987854, 26.19224739], [89.60971832, 26.19223785], [89.60964966, 26.19213295], [89.60961914, 26.19206047], [89.60960388, 26.19198608], [89.60960388, 26.19186592], [89.60957336, 26.19178581], [89.60948944, 26.19176674], [89.60939026, 26.19177628], [89.60929871, 26.19177437], [89.60914612, 26.19171143], [89.60908508, 26.19162941], [89.60904694, 26.19153214], [89.60905457, 26.19131851], [89.60908508, 26.19116974], [89.60912323, 26.19104576], [89.60925293, 26.19092941], [89.60947418, 26.19076347], [89.60966492, 26.19066429], [89.60985565, 26.19055939], [89.60997772, 26.19049454], [89.61006165, 26.19043541], [89.6101532, 26.1903553], [89.61025238, 26.19026756], [89.61039734, 26.19020462], [89.61052704, 26.1901741], [89.61061096, 26.19016075], [89.61074829, 26.19002533], [89.61083221, 26.1898365], [89.61090851, 26.18970299], [89.61126709, 26.18954277], [89.61177826, 26.18935776], [89.61302948, 26.18957329], [89.61315155, 26.18961525], [89.61328125, 26.18962097], [89.61342621, 26.18961716], [89.61364746, 26.18959999], [89.61399841, 26.18955803], [89.61437225, 26.18948174], [89.61463165, 26.18940163], [89.61495972, 26.1892662], [89.61528778, 26.18911934], [89.61579132, 26.18887329], [89.61621857, 26.18862152], [89.61656952, 26.18835068], [89.61689758, 26.18800926], [89.61700439, 26.18776321], [89.61714172, 26.18755341], [89.61734772, 26.18732452], [89.61759949, 26.1870594], [89.61792755, 26.18677139], [89.61817932, 26.18653488], [89.61841583, 26.18635559], [89.61859131, 26.18621635], [89.61871338, 26.18615723], [89.618927, 26.18632317], [89.61906433, 26.18657494], [89.619133, 26.18665314], [89.61925507, 26.18678284], [89.61935425, 26.18684769], [89.61952972, 26.18696404], [89.61963654, 26.18704605], [89.61974335, 26.18719864], [89.61975861, 26.18737411], [89.61975861, 26.18757629], [89.6197052, 26.18778801], [89.61959076, 26.18802834], [89.61947632, 26.18822289], [89.61934662, 26.18850899], [89.6192627, 26.18873596], [89.61916351, 26.18921089], [89.61907196, 26.18967056], [89.61896515, 26.19002342], [89.61888885, 26.19029617], [89.61884308, 26.19046402], [89.61882782, 26.19057846], [89.61875916, 26.19065094], [89.61862946, 26.19069481], [89.61838531, 26.19072723], [89.61817169, 26.19073677], [89.61803436, 26.19076729], [89.61797333, 26.19083595], [89.61792755, 26.19090462], [89.61791229, 26.19103432], [89.61789703, 26.19115257], [89.61788177, 26.19127083], [89.61787415, 26.19143677], [89.6178894, 26.19166183], [89.61791229, 26.19192123], [89.61792755, 26.19222641], [89.61793518, 26.19250298], [89.61794281, 26.19279671], [89.61797333, 26.19324875], [89.61795807, 26.19356346], [89.61791992, 26.19370842], [89.61791229, 26.19395828], [89.6178894, 26.19419479], [89.6182785, 26.19437981], [89.61836243, 26.19438744], [89.61851501, 26.19446182], [89.61864471, 26.19460869], [89.6190567, 26.1948204], [89.61924744, 26.19478226], [89.61936188, 26.19477654], [89.61950684, 26.19480324], [89.61965179, 26.19487381], [89.61982727, 26.19501305], [89.61992645, 26.19519424], [89.62004852, 26.19542885], [89.62012482, 26.19571495], [89.62010956, 26.19598389], [89.62011719, 26.19623756], [89.62020111, 26.19649124], [89.62023926, 26.19666481], [89.62030029, 26.19677162], [89.6204071, 26.19690895], [89.62052917, 26.19701004], [89.62071228, 26.19715881], [89.62099457, 26.19731903], [89.62128448, 26.19752121], [89.62146759, 26.1977253], [89.62165833, 26.19789886], [89.62185669, 26.19809341], [89.62211609, 26.19824409], [89.62232971, 26.19837761], [89.62249756, 26.19845581], [89.62263489, 26.19855309], [89.62274933, 26.19863129], [89.62287903, 26.19876289], [89.62302399, 26.19896889], [89.62311554, 26.19914818], [89.62316132, 26.19933891], [89.62319183, 26.19955635], [89.62319183, 26.19981766], [89.62316132, 26.20002747], [89.62311554, 26.20015335], [89.62306976, 26.20024681], [89.62294006, 26.20036888], [89.62281799, 26.2004261], [89.62254333, 26.20045471], [89.62227631, 26.20043564], [89.62210083, 26.20035744], [89.62198639, 26.20033455], [89.62191772, 26.20042419]], [[89.60873413, 26.1231823], [89.60746765, 26.12268257], [89.60600281, 26.1217308], [89.60611725, 26.1203804], [89.6062088, 26.11923027], [89.60678864, 26.11819267], [89.60688019, 26.11829948], [89.60701752, 26.11844635], [89.60770416, 26.11875916], [89.60879517, 26.1206665], [89.6085968, 26.12292099], [89.60873413, 26.1231823]], [[89.60153961, 26.11189842], [89.60275269, 26.11054039], [89.6029129, 26.11040497], [89.60303497, 26.11173058], [89.60153961, 26.11189842]], [[89.15951538, 26.23424911], [89.1598053, 26.23425484], [89.1601181, 26.2342968], [89.1604538, 26.23438263], [89.16085815, 26.23446083], [89.16117096, 26.23451233], [89.16164398, 26.23461533], [89.16201019, 26.23472214], [89.16246033, 26.23486519], [89.16279602, 26.23502922], [89.1630249, 26.23519325], [89.16321564, 26.23536301], [89.16336823, 26.23552895], [89.1635437, 26.23576546], [89.16371918, 26.2360096], [89.16391754, 26.23635674], [89.16407776, 26.23661041], [89.16423798, 26.23689842], [89.1644516, 26.23729324], [89.16468048, 26.23759842], [89.16487122, 26.23784637], [89.16504669, 26.23806953], [89.16516113, 26.23822403], [89.16537476, 26.23843575], [89.16560364, 26.23867035], [89.16578674, 26.23892021], [89.16597748, 26.2392292], [89.16613007, 26.23952293], [89.16628265, 26.23978996], [89.16640472, 26.24006081], [89.16652679, 26.24029541], [89.16658783, 26.2403698], [89.16666412, 26.24042511], [89.16674805, 26.24047661], [89.16690826, 26.24055862], [89.16712189, 26.24062538], [89.16729736, 26.24067116], [89.16745758, 26.24068069], [89.16770172, 26.24065018], [89.1680069, 26.24061966], [89.16830444, 26.24057961], [89.16855621, 26.24054909], [89.1688385, 26.24050522], [89.16911316, 26.24046516], [89.16932678, 26.24042892], [89.16954041, 26.24035072], [89.16973114, 26.24031639], [89.16985321, 26.24027252], [89.17001343, 26.24020958], [89.17021942, 26.24010468], [89.17027283, 26.2400341], [89.17037964, 26.23994637], [89.17047882, 26.23989868], [89.17073822, 26.24008369], [89.17089081, 26.240345], [89.1709671, 26.24058342], [89.17097473, 26.24073982], [89.17088318, 26.24101448], [89.17071533, 26.2413063], [89.17058563, 26.24145508], [89.17047882, 26.24155807], [89.17030334, 26.24168015], [89.17006683, 26.24184799], [89.16989899, 26.24191666], [89.16972351, 26.24197197], [89.16958618, 26.24202538], [89.16936493, 26.24208832], [89.16914368, 26.24214172], [89.16895294, 26.24219322], [89.16871643, 26.24228287], [89.16851044, 26.24237442], [89.16850281, 26.2425499], [89.16854858, 26.24268341], [89.16871643, 26.24269485], [89.16889191, 26.24262619], [89.16918182, 26.24262619], [89.16920471, 26.24271774], [89.16921997, 26.24285316], [89.16924286, 26.24302864], [89.16928864, 26.24329376], [89.16936493, 26.24357605], [89.16944885, 26.24379539], [89.16950989, 26.24399185], [89.16957092, 26.24416161], [89.16967773, 26.24438858], [89.16976929, 26.24455833], [89.16964722, 26.24471092], [89.16934204, 26.24490547], [89.16917419, 26.24503326], [89.16904449, 26.24510193], [89.16887665, 26.24511528], [89.16873932, 26.24517441], [89.16867065, 26.24524307], [89.16860199, 26.24537659], [89.16854858, 26.24557686], [89.16854095, 26.24583054], [89.16854858, 26.24602318], [89.1685791, 26.24634552], [89.16857147, 26.24656868], [89.16851807, 26.24687576], [89.16846466, 26.24713516], [89.16840363, 26.24730301], [89.16832733, 26.2474575], [89.16815948, 26.24771881], [89.16792297, 26.2480278], [89.16769409, 26.24832916], [89.16744232, 26.24864769], [89.16722107, 26.24889374], [89.16702271, 26.24915123], [89.16687775, 26.24938583], [89.16677856, 26.24956512], [89.16666412, 26.24978828], [89.16660309, 26.25003052], [89.16646576, 26.25053406], [89.16639709, 26.25092125], [89.16634369, 26.25120354], [89.16633606, 26.25141716], [89.16633606, 26.25163078], [89.16636658, 26.25196457], [89.16646576, 26.2523632], [89.16656494, 26.25269127], [89.16669464, 26.25301552], [89.16676331, 26.25317383], [89.16683197, 26.25333023], [89.16693115, 26.25353622], [89.16705322, 26.25371742], [89.16717529, 26.25380135], [89.16738892, 26.25393867], [89.16757965, 26.25403595], [89.16768646, 26.25407791], [89.16781616, 26.25406265], [89.16793823, 26.25400162], [89.16805267, 26.25384712], [89.16821289, 26.25356483], [89.16835785, 26.25320816], [89.16854095, 26.25268364], [89.16867065, 26.25232506], [89.16876221, 26.25209808], [89.16884613, 26.25193024], [89.16892242, 26.25188446], [89.16899109, 26.25205231], [89.16910553, 26.25233841], [89.16925049, 26.25272369], [89.16946411, 26.25318718], [89.1696167, 26.25356293], [89.16983795, 26.25401497], [89.17009735, 26.25455856], [89.17031097, 26.2549839], [89.17047882, 26.2552948], [89.17055511, 26.25543976], [89.17054749, 26.25553513], [89.17045593, 26.25572968], [89.17029572, 26.25587654], [89.1700592, 26.25601006], [89.16977692, 26.25617409], [89.16954041, 26.25629616], [89.16928101, 26.25641823], [89.16899109, 26.25654793], [89.16873169, 26.25665092], [89.16849518, 26.25679398], [89.168396, 26.25693512], [89.16828156, 26.25715637], [89.16815948, 26.2573719], [89.16805267, 26.25754929], [89.16788483, 26.25777626], [89.16777039, 26.25792313], [89.16757965, 26.25814819], [89.16737366, 26.25839043], [89.16725159, 26.25852203], [89.16716766, 26.25867844], [89.1671524, 26.25884247], [89.16719818, 26.25905037], [89.16732025, 26.25922394], [89.16742706, 26.25930214], [89.16756439, 26.25934029], [89.16781616, 26.25936508], [89.16820526, 26.25938034], [89.16861725, 26.25938416], [89.16889954, 26.25932693], [89.16923523, 26.25928116], [89.16946411, 26.25922966], [89.16966248, 26.25921059], [89.16984558, 26.25917816], [89.16999054, 26.25909996], [89.1701355, 26.25900459], [89.17027283, 26.25879669], [89.17040253, 26.25859261], [89.17050171, 26.25841141], [89.17058563, 26.25835991], [89.17076111, 26.25829315], [89.17134857, 26.25802803], [89.17179871, 26.25782394], [89.17186737, 26.2577877], [89.17192078, 26.25770378], [89.17194366, 26.25743484], [89.17189789, 26.2570858], [89.17181396, 26.25683403], [89.17171478, 26.25677872], [89.17220306, 26.25664902], [89.1724472, 26.25669289], [89.17272949, 26.25673676], [89.17294312, 26.25675201], [89.17323303, 26.25681686], [89.17353058, 26.25688744], [89.17376709, 26.25699234], [89.17391968, 26.25713921], [89.17397308, 26.25728416], [89.17393494, 26.25746918], [89.17378998, 26.25777626], [89.17359924, 26.25815201], [89.1733551, 26.25865936], [89.17323303, 26.25893021], [89.17311859, 26.25924301], [89.17301941, 26.25953102], [89.17297363, 26.25973129], [89.172966, 26.25996208], [89.17298126, 26.26024055], [89.17288971, 26.26047325], [89.17272186, 26.26062202], [89.1724472, 26.2607708], [89.17216492, 26.2609024], [89.17189789, 26.26117706], [89.17171478, 26.26153946], [89.17169189, 26.26187706], [89.17171478, 26.26226425], [89.1717453, 26.26255989], [89.1717453, 26.26282883], [89.17173004, 26.26299667], [89.17169952, 26.26311874], [89.17163086, 26.26330948], [89.17150879, 26.26346588], [89.17131042, 26.26370239], [89.17105103, 26.2638073], [89.17082977, 26.26382446], [89.17057037, 26.26386261], [89.17029572, 26.26384163], [89.17011261, 26.26379585], [89.16984558, 26.26368904], [89.169487, 26.26359177], [89.16873169, 26.26351547], [89.16815948, 26.26346588], [89.1680603, 26.26340675], [89.1682663, 26.26319885], [89.16889954, 26.2627964], [89.16938782, 26.26251602], [89.16963959, 26.26235771], [89.1697464, 26.2622261], [89.1697998, 26.26209259], [89.16984558, 26.26199341], [89.16985321, 26.26191521], [89.16984558, 26.26180649], [89.16986084, 26.26170921], [89.1698761, 26.26157379], [89.16991425, 26.26141548], [89.16992188, 26.26124954], [89.16989136, 26.26114655], [89.16982269, 26.26098824], [89.16970062, 26.26080894], [89.16956329, 26.26069641], [89.16938782, 26.26062012], [89.16916656, 26.26059151], [89.16874695, 26.26059723], [89.16827393, 26.26065445], [89.16795349, 26.26067162], [89.16771698, 26.26072311], [89.16750336, 26.26086044], [89.16738892, 26.26104164], [89.16723633, 26.2612896], [89.16706085, 26.2614994], [89.16695404, 26.26161194], [89.16683197, 26.26169777], [89.16638947, 26.26177597], [89.16587067, 26.2618103], [89.16547394, 26.26185036], [89.16516876, 26.26185036], [89.16500092, 26.26184082], [89.16480255, 26.26182938], [89.16454315, 26.26184464], [89.16437531, 26.26194191], [89.16426086, 26.26211357], [89.16432953, 26.26223755], [89.16447449, 26.26232719], [89.16464233, 26.26239586], [89.16500854, 26.26250839], [89.16550446, 26.2625885], [89.16611481, 26.26264572], [89.16666412, 26.26269913], [89.16738129, 26.26278496], [89.1674118, 26.2629509], [89.16690826, 26.26317024], [89.16709137, 26.26332474], [89.16737366, 26.26345444], [89.16754913, 26.26353645], [89.16772461, 26.26357079], [89.16783905, 26.26358986], [89.16791534, 26.2636013], [89.16805267, 26.26369476], [89.1678009, 26.26372528], [89.16743469, 26.26377106], [89.1671524, 26.26382256], [89.16677094, 26.26395416], [89.16629791, 26.26428986], [89.16561127, 26.26490211], [89.16524506, 26.2653389], [89.1648941, 26.26584244], [89.16461945, 26.26623154], [89.1643219, 26.26657867], [89.16392517, 26.26688957], [89.1635437, 26.26700974], [89.16309357, 26.26702118], [89.16268921, 26.26697159], [89.16231537, 26.2669735], [89.16197205, 26.26693153], [89.16163635, 26.2668705], [89.16116333, 26.26682472], [89.16056061, 26.26667786], [89.15968323, 26.26650047], [89.15873718, 26.26635361], [89.15791321, 26.26635551], [89.15712738, 26.2662487], [89.15660858, 26.26616669], [89.15612793, 26.26605988], [89.15563965, 26.26603127], [89.15525818, 26.26605797], [89.15473938, 26.26617622], [89.15426636, 26.26627731], [89.15398407, 26.26634026], [89.15364075, 26.266222], [89.15341187, 26.26612854], [89.15317535, 26.26600456], [89.15306091, 26.26587868], [89.15299988, 26.26571846], [89.1529541, 26.26547623], [89.15296936, 26.26515579], [89.1530304, 26.26456833], [89.1530838, 26.26392937], [89.15309906, 26.26351357], [89.15309143, 26.26309013], [89.15305328, 26.26277924], [89.15297699, 26.26235962], [89.15288544, 26.26200867], [89.15278625, 26.26169968], [89.15268707, 26.26138496], [89.152565, 26.26112175], [89.15236664, 26.26081085], [89.15213776, 26.26046562], [89.15189362, 26.260149], [89.15171051, 26.25990486], [89.15150452, 26.25955391], [89.15125275, 26.25918961], [89.15100098, 26.25875473], [89.15078735, 26.25838852], [89.15058136, 26.25801086], [89.15042114, 26.25770187], [89.15033722, 26.25750542], [89.15022278, 26.25727844], [89.15014648, 26.25706863], [89.1500473, 26.25680542], [89.14997101, 26.256567], [89.14995575, 26.25645256], [89.14994049, 26.25623512], [89.14997101, 26.25602722], [89.15001678, 26.25579262], [89.15007782, 26.25549126], [89.1501236, 26.25524902], [89.15020752, 26.2549324], [89.15028381, 26.25462723], [89.15034485, 26.25414658], [89.15041351, 26.2536869], [89.15047455, 26.25333214], [89.15054321, 26.25300217], [89.15063477, 26.2526741], [89.15068817, 26.25242233], [89.15074158, 26.2521286], [89.15079498, 26.2519207], [89.15084076, 26.25164223], [89.15084839, 26.25140381], [89.15087128, 26.25114059], [89.15081787, 26.25081444], [89.15074158, 26.25052452], [89.15068817, 26.2502079], [89.15063477, 26.24998093], [89.15061951, 26.24979591], [89.15047455, 26.24972343], [89.15035248, 26.24974823], [89.150177, 26.24981308], [89.14994812, 26.24995613], [89.1497345, 26.25003815], [89.14962769, 26.25008392], [89.1494751, 26.25020409], [89.14935303, 26.2504406], [89.14926147, 26.25082207], [89.1492691, 26.25132751], [89.14927673, 26.25183105], [89.1492691, 26.2522316], [89.1492157, 26.2525959], [89.14911652, 26.25291634], [89.1490097, 26.25323486], [89.14891052, 26.25373459], [89.14888763, 26.2541008], [89.14889526, 26.25447655], [89.14891052, 26.25478363], [89.14889526, 26.25499725], [89.14888, 26.25510025], [89.14883423, 26.25516129], [89.14871216, 26.25514221], [89.14852142, 26.25512123], [89.14823151, 26.25504684], [89.14788055, 26.25496674], [89.14733887, 26.25487137], [89.14671326, 26.25478745], [89.14615631, 26.25478363], [89.14543915, 26.25477219], [89.14465332, 26.2548008], [89.14390564, 26.25483322], [89.14326477, 26.25486946], [89.14289856, 26.25486755], [89.14248657, 26.25491524], [89.1420517, 26.25491905], [89.14170837, 26.25490952], [89.14139557, 26.25491524], [89.14109039, 26.25493622], [89.14070892, 26.25497818], [89.14040375, 26.25505066], [89.14025879, 26.2550869], [89.14014435, 26.25519943], [89.14006042, 26.25546837], [89.13996887, 26.25584984], [89.1399231, 26.2562809], [89.13989258, 26.25693321], [89.13977051, 26.25746727], [89.13978577, 26.25797653], [89.13990784, 26.25851631], [89.14004517, 26.25900459], [89.14002991, 26.25942612], [89.1399765, 26.25986862], [89.13983917, 26.26018715], [89.13968658, 26.2604847], [89.1395874, 26.26069641], [89.13950348, 26.26092339], [89.13951874, 26.26116753], [89.13957214, 26.26146317], [89.13965607, 26.26170921], [89.13988495, 26.26212692], [89.14014435, 26.26237106], [89.14040375, 26.26255226], [89.14081573, 26.26274681], [89.14120483, 26.26283836], [89.14173126, 26.26290321], [89.14213562, 26.26268959], [89.14246368, 26.26248169], [89.14291382, 26.26228523], [89.14329529, 26.26215172], [89.14377594, 26.26198006], [89.14419556, 26.2618351], [89.1445694, 26.26171112], [89.14492035, 26.2616024], [89.14540863, 26.26145935], [89.14582062, 26.26139832], [89.14619446, 26.26138878], [89.14658356, 26.26140022], [89.14691162, 26.2615509], [89.1471405, 26.26170349], [89.1473465, 26.26190948], [89.14746857, 26.26208496], [89.14754486, 26.26226616], [89.14756775, 26.26252937], [89.14756012, 26.26287651], [89.14745331, 26.26315689], [89.14733887, 26.26342583], [89.14722443, 26.2639122], [89.1471405, 26.26429367], [89.14705658, 26.26474571], [89.1469574, 26.2651844], [89.14685822, 26.26545334], [89.14666748, 26.26562881], [89.1464386, 26.26570129], [89.14629364, 26.26579094], [89.1460495, 26.26604271], [89.14580536, 26.26626587], [89.14542389, 26.26647758], [89.14511871, 26.26651764], [89.14470673, 26.26645851], [89.14433289, 26.26639175], [89.1439209, 26.26634026], [89.14344025, 26.2663269], [89.14306641, 26.26636124], [89.14276886, 26.26643372], [89.14252472, 26.26653481], [89.14238739, 26.26665878], [89.14227295, 26.26683807], [89.14221191, 26.26700783], [89.14220428, 26.26714325], [89.1422348, 26.26733971], [89.14230347, 26.26767921], [89.14218903, 26.26815033], [89.14198303, 26.26862335], [89.14189148, 26.26909065], [89.14200592, 26.26952553], [89.14237976, 26.27026367], [89.14247894, 26.27060509], [89.14248657, 26.27090454], [89.14238739, 26.27112579], [89.14225769, 26.27116776], [89.14212799, 26.27121925], [89.14189911, 26.27139282], [89.141716, 26.27148247], [89.14148712, 26.27144051], [89.14125061, 26.27134132], [89.14100647, 26.2712059], [89.14070892, 26.2710495], [89.14026642, 26.27081299], [89.13973236, 26.27042007], [89.13941193, 26.27016258], [89.13883209, 26.26970673], [89.13842773, 26.26935768], [89.13828278, 26.26929665], [89.13794708, 26.26924133], [89.13763428, 26.26927757], [89.13746643, 26.26932144], [89.13726044, 26.26943588], [89.13708496, 26.26960564], [89.13703918, 26.26966286], [89.13697815, 26.26975822], [89.13690186, 26.2698822], [89.13680267, 26.27008247], [89.13671875, 26.27031898], [89.13660431, 26.27059555], [89.13647461, 26.27089119], [89.1363678, 26.27106285], [89.13621521, 26.27120018], [89.1360321, 26.27128792], [89.13589478, 26.27128029], [89.13580322, 26.27123833], [89.13574219, 26.27103233], [89.1357193, 26.27094841], [89.13568878, 26.27075577], [89.13570404, 26.27045441], [89.13574219, 26.27014351], [89.13582611, 26.26982307], [89.1359024, 26.26955032], [89.13604736, 26.26910973], [89.13621521, 26.26873779], [89.13640594, 26.26842117], [89.13654327, 26.26826477], [89.13667297, 26.26817513], [89.13680267, 26.26806068], [89.13693237, 26.26792145], [89.13700867, 26.26772308], [89.13706207, 26.26749611], [89.13709259, 26.26728439], [89.13708496, 26.26703453], [89.13700867, 26.26668739], [89.13681793, 26.26634216], [89.13655853, 26.2658844], [89.13629913, 26.26557159], [89.13612366, 26.26536369], [89.13586426, 26.26509666], [89.13557434, 26.26484108], [89.13529205, 26.26456833], [89.13498688, 26.26430702], [89.13472748, 26.26407051], [89.13448334, 26.26384354], [89.13425446, 26.26361084], [89.13404083, 26.26340103], [89.13388062, 26.26319122], [89.13368225, 26.26293755], [89.13353729, 26.26271629], [89.13342285, 26.26251793], [89.13337708, 26.26234818], [89.1333313, 26.26220894], [89.13331604, 26.26198769], [89.13332367, 26.26178169], [89.13335419, 26.26158714], [89.13339996, 26.26136017], [89.13348389, 26.26110649], [89.13354492, 26.26084518], [89.1336441, 26.26050186], [89.1337204, 26.26019859], [89.13379669, 26.2597332], [89.13381958, 26.25919914], [89.13386536, 26.25880241], [89.13397217, 26.25839806], [89.13409424, 26.2580471], [89.13426971, 26.25769234], [89.1344986, 26.25735664], [89.13469696, 26.25708199], [89.13485718, 26.25674629], [89.13491821, 26.25642586], [89.13500214, 26.25611305], [89.13505554, 26.25584602], [89.13510132, 26.25557518], [89.13516235, 26.25527191], [89.13518524, 26.25511169], [89.13523865, 26.25494957], [89.13529968, 26.25484657], [89.13539886, 26.2548008], [89.13558197, 26.25474167], [89.13575745, 26.25470734], [89.1359787, 26.2546463], [89.13613892, 26.25458145], [89.13628387, 26.25451851], [89.13642883, 26.25444412], [89.13655853, 26.25436401], [89.13667297, 26.25428963], [89.13676453, 26.25417519], [89.1368866, 26.25406647], [89.13700104, 26.25389481], [89.13710022, 26.25374031], [89.13717651, 26.25348854], [89.13724518, 26.25317955], [89.13732147, 26.25275421], [89.1374054, 26.25232697], [89.13748932, 26.25199699], [89.13761902, 26.2516346], [89.13774872, 26.25136375], [89.13793945, 26.25110245], [89.13811493, 26.25093651], [89.13826752, 26.25082016], [89.13851166, 26.25066566], [89.13883209, 26.25050545], [89.13893127, 26.25069046], [89.139328, 26.25062943], [89.13961029, 26.25052834], [89.13980865, 26.25044823], [89.13999176, 26.25031853], [89.14016724, 26.25021362], [89.14035797, 26.25008392], [89.14056396, 26.24993896], [89.14073181, 26.24977112], [89.1410141, 26.24952698], [89.14129639, 26.24921608], [89.14157867, 26.24893761], [89.14177704, 26.2488327], [89.14191437, 26.24881554], [89.14215088, 26.24903679], [89.14237976, 26.24929428], [89.14252472, 26.24945068], [89.14266968, 26.24951172], [89.14280701, 26.24950218], [89.1428833, 26.24946594], [89.14306641, 26.24937057], [89.14317322, 26.24927521], [89.14325714, 26.24924469], [89.14344788, 26.2493], [89.14358521, 26.24935722], [89.14369965, 26.2493763], [89.14382935, 26.24936104], [89.14394379, 26.24931526], [89.1441803, 26.24919891], [89.14437866, 26.24904442], [89.14458466, 26.24888611], [89.14476013, 26.24868584], [89.14491272, 26.24853706], [89.14500427, 26.24840736], [89.14511871, 26.24825096], [89.14522552, 26.2480793], [89.14539337, 26.24778748], [89.14553833, 26.24750137], [89.14564514, 26.2472496], [89.14575195, 26.24696541], [89.14585876, 26.24668503], [89.14595032, 26.24630928], [89.14599609, 26.24589729], [89.14596558, 26.24551392], [89.14591217, 26.24507332], [89.14582825, 26.24450493], [89.14572144, 26.24422646], [89.14561462, 26.24383736], [89.14552307, 26.24363136], [89.14537811, 26.24344254], [89.14524078, 26.24328995], [89.14512634, 26.24310875], [89.1450119, 26.24301147], [89.14488983, 26.24287796], [89.14472198, 26.24276733], [89.14455414, 26.2426796], [89.1443634, 26.24265099], [89.14414215, 26.2426033], [89.14395142, 26.24250984], [89.14385223, 26.24245834], [89.1437149, 26.24238968], [89.14349365, 26.24230385], [89.14339447, 26.24227905], [89.14324951, 26.24226379], [89.14315796, 26.24228096], [89.14299774, 26.24228096], [89.14281464, 26.24230003], [89.14269257, 26.24232292], [89.14259338, 26.24233246], [89.1425705, 26.24215126], [89.14257813, 26.24196053], [89.14259338, 26.24179459], [89.14270782, 26.24178505], [89.14286804, 26.24161339], [89.14307404, 26.24152756], [89.14334869, 26.24150467], [89.14367676, 26.24151421], [89.14408112, 26.24149704], [89.14437103, 26.24147034], [89.14478302, 26.24136734], [89.14513397, 26.24124718], [89.14536285, 26.24117851], [89.14556122, 26.24110222], [89.14562988, 26.24103355], [89.14556885, 26.24096298], [89.145401, 26.24089241], [89.14524841, 26.24080658], [89.14523315, 26.2406559], [89.14551544, 26.24039078], [89.14587402, 26.24011993], [89.1462326, 26.23982048], [89.14667511, 26.23950958], [89.14705658, 26.23928642], [89.14754486, 26.23907089], [89.14797211, 26.23886108], [89.14849854, 26.2386055], [89.14904785, 26.23834419], [89.1494751, 26.23818016], [89.14985657, 26.23806381], [89.150177, 26.23797417], [89.15045929, 26.23790741], [89.15073395, 26.23784256], [89.15109253, 26.23779106], [89.15126801, 26.23776817], [89.15154266, 26.23777771], [89.15175629, 26.23773766], [89.15201569, 26.2376194], [89.15229034, 26.23746872], [89.15250397, 26.23730278], [89.15263367, 26.23717308], [89.1526947, 26.23706055], [89.15274811, 26.23693848], [89.15293121, 26.23682976], [89.15313721, 26.23679733], [89.15332794, 26.23677826], [89.15365601, 26.23674774], [89.15390778, 26.23675919], [89.15406036, 26.2367897], [89.15418243, 26.23685646], [89.15434265, 26.23698425], [89.15454865, 26.23720169], [89.15484619, 26.23742294], [89.15509796, 26.23756981], [89.15538788, 26.23766327], [89.15570068, 26.23773003], [89.15611267, 26.23779297], [89.15639496, 26.23786354], [89.15635681, 26.23794556], [89.15639496, 26.23803902], [89.15645599, 26.23810387], [89.15647125, 26.23817825], [89.15648651, 26.2383194], [89.15647125, 26.23852348], [89.15644836, 26.23877335], [89.15639496, 26.23902893], [89.15633392, 26.23935509], [89.15627289, 26.23976135], [89.15621185, 26.24019814], [89.15618896, 26.24069595], [89.15615845, 26.24103737], [89.15609741, 26.24146271], [89.15606689, 26.24178123], [89.1561203, 26.24222374], [89.15624237, 26.2426815], [89.15641022, 26.24330139], [89.15651703, 26.24372864], [89.15657043, 26.24405289], [89.15653992, 26.2442894], [89.15649414, 26.24441338], [89.15644836, 26.24448013], [89.15635681, 26.24454117], [89.15618896, 26.24458504], [89.15591431, 26.24463844], [89.1556015, 26.24467659], [89.15535736, 26.24474144], [89.15509033, 26.24474144], [89.1548996, 26.24473763], [89.15473175, 26.2447567], [89.15460968, 26.24478149], [89.15449524, 26.24479294], [89.15426636, 26.24477768], [89.15390015, 26.24472618], [89.15357208, 26.24466705], [89.15329742, 26.24460983], [89.15311432, 26.24458885], [89.1529541, 26.2445755], [89.152771, 26.24458313], [89.15262604, 26.24458122], [89.1525116, 26.24460411], [89.15240479, 26.24470901], [89.15242767, 26.24494553], [89.15252686, 26.24537659], [89.15258789, 26.24563408], [89.15264893, 26.24582481], [89.15274048, 26.24596405], [89.15287018, 26.2460556], [89.15304565, 26.24608231], [89.15336609, 26.24607658], [89.15367889, 26.24603844], [89.15389252, 26.2460041], [89.15418243, 26.24601555], [89.15440369, 26.24608612], [89.15467072, 26.24622726], [89.15492249, 26.24634552], [89.15514374, 26.24643517], [89.15541077, 26.24653435], [89.15563202, 26.24658966], [89.15592194, 26.24662781], [89.15616608, 26.24668694], [89.15628815, 26.24671745], [89.15644836, 26.2468071], [89.15657043, 26.24688148], [89.15664673, 26.24697685], [89.15670776, 26.24709892], [89.15673828, 26.24726677], [89.15679169, 26.24746513], [89.15679932, 26.24774361], [89.15674591, 26.24804306], [89.15664673, 26.24839211], [89.15650177, 26.24876976], [89.15637207, 26.24907112], [89.15631104, 26.24938202], [89.15628815, 26.24958611], [89.15631866, 26.24971199], [89.15637207, 26.24987411], [89.15648651, 26.25], [89.15658569, 26.25008583], [89.15673828, 26.2501564], [89.15694427, 26.25020409], [89.15731049, 26.2502346], [89.15776062, 26.25031853], [89.15809631, 26.25039864], [89.15844727, 26.25046921], [89.15877533, 26.2505722], [89.15908813, 26.25067711], [89.15929413, 26.25072479], [89.15950775, 26.25075722], [89.15964508, 26.25077248], [89.15975952, 26.2507534], [89.15991211, 26.25061989], [89.1600647, 26.25033188], [89.16015625, 26.25016594], [89.1602478, 26.25005722], [89.1603775, 26.24995232], [89.16055298, 26.24990273], [89.16065979, 26.24985886], [89.16077423, 26.24971962], [89.16085052, 26.24958801], [89.1609726, 26.24921799], [89.16118622, 26.24878883], [89.16132355, 26.24840736], [89.1614151, 26.24811554], [89.16146088, 26.24787521], [89.16144562, 26.24757576], [89.16138458, 26.24739075], [89.16127777, 26.24723816], [89.16100311, 26.24711227], [89.16074371, 26.24714279], [89.16048431, 26.24717522], [89.16030884, 26.24720955], [89.16020203, 26.24712944], [89.16017151, 26.24692535], [89.16018677, 26.24655151], [89.16026306, 26.24628639], [89.16040039, 26.24599266], [89.16059113, 26.24565887], [89.16086578, 26.24536133], [89.16103363, 26.24513054], [89.1611557, 26.24495316], [89.16127014, 26.24465942], [89.16130829, 26.24442482], [89.16131592, 26.24418831], [89.16130829, 26.24396133], [89.16130829, 26.2437973], [89.16125488, 26.24359703], [89.16124725, 26.2433567], [89.16127777, 26.24313736], [89.16133881, 26.24287033], [89.16138458, 26.24259377], [89.16142273, 26.24235725], [89.16146088, 26.24221611], [89.16149139, 26.24212265], [89.16153717, 26.24198151], [89.16165924, 26.24183273], [89.16182709, 26.24173546], [89.16195679, 26.24171638], [89.16218567, 26.2417469], [89.16236877, 26.24181366], [89.16253662, 26.2418766], [89.1627121, 26.24188995], [89.16285706, 26.24188423], [89.16297913, 26.24186516], [89.1631012, 26.2417202], [89.16316986, 26.24134827], [89.16320801, 26.24103165], [89.16321564, 26.24073601], [89.1632309, 26.24037361], [89.16321564, 26.23993111], [89.16317749, 26.23949242], [89.1631546, 26.23932457], [89.16313171, 26.23919678], [89.16305542, 26.23895264], [89.16293335, 26.23890686], [89.16277313, 26.23888779], [89.16255951, 26.2388382], [89.16239166, 26.23875809], [89.16227722, 26.2386322], [89.16213226, 26.23839951], [89.16205597, 26.23822784], [89.16197968, 26.23800659], [89.16194153, 26.23781776], [89.16191864, 26.23760033], [89.16190338, 26.2374115], [89.16184235, 26.23727608], [89.16173553, 26.2372303], [89.16159821, 26.23720741], [89.16139984, 26.23718643], [89.16120911, 26.23707581], [89.16107941, 26.2369442], [89.16095734, 26.23683548], [89.16086578, 26.23673058], [89.16075134, 26.23659897], [89.1606369, 26.23649025], [89.16052246, 26.23645973], [89.16040039, 26.23648262], [89.16025543, 26.2365284], [89.16004944, 26.23665237], [89.15982056, 26.23685074], [89.15957642, 26.23717499], [89.15946198, 26.23733139], [89.15931702, 26.23739815], [89.15899658, 26.23740196], [89.15875244, 26.23732948], [89.15847015, 26.23717499], [89.15827179, 26.23700905], [89.15808868, 26.23680305], [89.15802002, 26.23669052], [89.1579895, 26.23658371], [89.1579895, 26.23639107], [89.1579895, 26.23610306], [89.1579895, 26.23580551], [89.15795898, 26.23552895], [89.15791321, 26.23534966], [89.15784454, 26.23508644], [89.15782166, 26.23494148], [89.1578064, 26.23477364], [89.15783691, 26.23467064], [89.15784454, 26.23456764], [89.15792084, 26.2345047], [89.15807343, 26.2344017], [89.15824127, 26.23433304], [89.15840149, 26.23428535], [89.15860748, 26.23426628], [89.15888214, 26.23426628], [89.15919495, 26.23425674], [89.15951538, 26.23424911]], [[89.18089294, 26.24517059], [89.18081665, 26.2452774], [89.18071747, 26.24533463], [89.18054962, 26.24537849], [89.18032837, 26.24538231], [89.18008423, 26.24535751], [89.17990112, 26.24532127], [89.17964172, 26.24524498], [89.17935181, 26.24514008], [89.17905426, 26.24502563], [89.17875671, 26.24492645], [89.17823029, 26.24492073], [89.17786407, 26.24490547], [89.17771912, 26.24482727], [89.17762756, 26.24474907], [89.17759705, 26.24466324], [89.17758179, 26.24432755], [89.17758179, 26.24395752], [89.17756653, 26.2435894], [89.17756653, 26.24339294], [89.17760468, 26.2432785], [89.17794037, 26.24334526], [89.17807007, 26.24334526], [89.17817688, 26.24328613], [89.17811584, 26.24310112], [89.17794037, 26.24261856], [89.17778778, 26.24223328], [89.17765045, 26.24172592], [89.1776123, 26.24150276], [89.17772675, 26.24110603], [89.17787933, 26.24097824], [89.17812347, 26.24087143], [89.17847443, 26.240839], [89.17877197, 26.2407074], [89.17908478, 26.24051857], [89.1794281, 26.24030876], [89.17956543, 26.24016762], [89.17970276, 26.23995209], [89.17982483, 26.23973846], [89.17993164, 26.23957253], [89.18003845, 26.2394619], [89.18010712, 26.23939133], [89.18016052, 26.23933411], [89.18026733, 26.23929977], [89.18039703, 26.23929405], [89.18067932, 26.23939896], [89.18100739, 26.23957825], [89.18132782, 26.23986626], [89.18164063, 26.24025345], [89.18196106, 26.24073029], [89.18225098, 26.24116516], [89.18258667, 26.2415905], [89.1829071, 26.24191856], [89.1831131, 26.24209404], [89.18319702, 26.24216461], [89.18327332, 26.24232101], [89.18338013, 26.24251366], [89.18351746, 26.24268723], [89.18377686, 26.242939], [89.1840744, 26.24311066], [89.18440247, 26.24317932], [89.18476105, 26.24312973], [89.18505859, 26.24305534], [89.18538666, 26.24295235], [89.18566132, 26.24287415], [89.1860199, 26.2428093], [89.18639374, 26.24277496], [89.18666077, 26.24280739], [89.18688965, 26.24285316], [89.18701935, 26.24293709], [89.18711853, 26.24300194], [89.18719482, 26.24310303], [89.18723297, 26.24319839], [89.18717957, 26.2434082], [89.1870575, 26.24364853], [89.18690491, 26.24378395], [89.18665314, 26.24389076], [89.18625641, 26.24409866], [89.18587494, 26.24438477], [89.18539429, 26.24471855], [89.18490601, 26.24482536], [89.18422699, 26.24484062], [89.18363953, 26.2449646], [89.1832428, 26.24502754], [89.18286896, 26.24507713], [89.18253326, 26.24513054], [89.18223572, 26.24515533], [89.18192291, 26.24515915], [89.18164825, 26.24517441], [89.1812973, 26.24517441], [89.18102264, 26.24516869], [89.18089294, 26.24517059]], [[89.2403717, 26.11173248], [89.23984528, 26.11161995], [89.23996735, 26.11141396], [89.2403717, 26.11173248]], [[89.07595825, 26.40121269], [89.07566071, 26.40138245], [89.07542419, 26.40153885], [89.07522583, 26.40176201], [89.07511902, 26.401968], [89.07509613, 26.40215302], [89.07515717, 26.40237999], [89.07531738, 26.40263557], [89.07549286, 26.40296745], [89.07563782, 26.40325928], [89.07575226, 26.40366745], [89.07578278, 26.40397263], [89.07572937, 26.40435219], [89.07568359, 26.40465164], [89.07558441, 26.40499878], [89.07545471, 26.40528488], [89.07533264, 26.4054184], [89.07518768, 26.40553474], [89.07509613, 26.40557671], [89.07496643, 26.40556908], [89.07478333, 26.40545845], [89.07446289, 26.40526199], [89.07423401, 26.4051609], [89.07395935, 26.40493202], [89.07371521, 26.40470505], [89.07347107, 26.40446472], [89.07326508, 26.40426254], [89.07306671, 26.40403748], [89.0728302, 26.4038105], [89.07260132, 26.40356445], [89.07245636, 26.40340424], [89.07241821, 26.40331459], [89.07239532, 26.40314674], [89.07236481, 26.40285492], [89.07233429, 26.40242004], [89.07231903, 26.40202904], [89.07231903, 26.40180588], [89.07232666, 26.40158272], [89.0723877, 26.40131378], [89.07241058, 26.40116119], [89.07247162, 26.40108871], [89.07267761, 26.40099144], [89.07300568, 26.4009552], [89.0734787, 26.40095139], [89.07389069, 26.40098572], [89.07435608, 26.40103722], [89.07463837, 26.4010582], [89.07486725, 26.40104103], [89.07504272, 26.40098763], [89.07524872, 26.40090561], [89.07551575, 26.40080261], [89.07567596, 26.40075874], [89.07579041, 26.40074158], [89.07589722, 26.40097237], [89.07595825, 26.40121269]], [[89.05809021, 26.40118599], [89.05822754, 26.4014492], [89.05841827, 26.40195847], [89.05861664, 26.40228462], [89.05887604, 26.4026165], [89.05902863, 26.40286636], [89.05923462, 26.40311623], [89.05931091, 26.40338898], [89.05934143, 26.4036274], [89.05934906, 26.40385437], [89.05931854, 26.40405464], [89.05925751, 26.40425491], [89.0590744, 26.40443611], [89.05891418, 26.40455818], [89.05858612, 26.40483475], [89.0582962, 26.40511703], [89.0579834, 26.40541267], [89.05775452, 26.40567589], [89.05757904, 26.40587234], [89.05738068, 26.40613174], [89.05712891, 26.40643883], [89.05682373, 26.40680504], [89.05653381, 26.40717888], [89.05635071, 26.40740776], [89.05621338, 26.40760803], [89.05607605, 26.4078083], [89.05596161, 26.40794754], [89.05576324, 26.40793419], [89.05531311, 26.40779495], [89.05487823, 26.4076519], [89.05435181, 26.40754128], [89.05416107, 26.40753174], [89.05467224, 26.40527725], [89.05472565, 26.4050045], [89.05477142, 26.40455246], [89.05485535, 26.40410805], [89.05500031, 26.40372658], [89.05522156, 26.40320206], [89.05542755, 26.40276527], [89.05561066, 26.40231895], [89.05574036, 26.40194893], [89.05584717, 26.40172768], [89.05594635, 26.40155029], [89.05602264, 26.40144348], [89.05609131, 26.40136337], [89.05620575, 26.40135765], [89.05638885, 26.40134811], [89.056633, 26.40133667], [89.05696106, 26.40129471], [89.05724335, 26.4012413], [89.05758667, 26.40116119], [89.05789185, 26.40109062], [89.05802917, 26.4010582], [89.05809021, 26.40118599]], [[89.12859344, 26.32184982], [89.1269989, 26.32085991], [89.12661743, 26.32070541], [89.12715149, 26.3205471], [89.12892914, 26.32077789], [89.1295929, 26.32058334], [89.12957764, 26.32076645], [89.12953949, 26.32109642], [89.12866211, 26.32105064], [89.12859344, 26.32184982]], [[89.13018036, 26.29277039], [89.12987518, 26.2929039], [89.12979889, 26.29293823], [89.12968445, 26.2928791], [89.12953186, 26.29278946], [89.12937164, 26.29264832], [89.1292572, 26.29254532], [89.1292038, 26.29244614], [89.12918091, 26.29231453], [89.12924957, 26.29210281], [89.1293335, 26.29192543], [89.12943268, 26.29178619], [89.12961578, 26.29162216], [89.12988281, 26.29139328], [89.13006592, 26.29123306], [89.13018799, 26.29113579], [89.13032532, 26.2910614], [89.13041687, 26.29101753], [89.13059998, 26.29093933], [89.13079071, 26.29093742], [89.13105774, 26.29099083], [89.13136292, 26.29105568], [89.13159943, 26.29115105], [89.13168335, 26.29123497], [89.1317749, 26.2913723], [89.13185883, 26.29168129], [89.13188171, 26.29191208], [89.13184357, 26.29217148], [89.13179779, 26.29240036], [89.13167572, 26.2926445], [89.13160706, 26.29272842], [89.13130188, 26.29282761], [89.131073, 26.29285431], [89.13082123, 26.29281616], [89.13064575, 26.29278946], [89.13052368, 26.29275322], [89.13038635, 26.29273224], [89.13018036, 26.29277039]], [[89.11239624, 26.27619171], [89.11261749, 26.2762928], [89.11281586, 26.2764473], [89.11301422, 26.27664375], [89.11325073, 26.27691078], [89.11347198, 26.27719498], [89.11371613, 26.27750397], [89.11380005, 26.27761078], [89.11351013, 26.27791977], [89.11377716, 26.27955818], [89.11405182, 26.28053093], [89.11406708, 26.28161049], [89.11395264, 26.28228951], [89.11363983, 26.28297997], [89.11237335, 26.28233528], [89.11239624, 26.28203583], [89.11239624, 26.28165817], [89.11237335, 26.28130531], [89.11235046, 26.28107262], [89.11240387, 26.28077698], [89.1124649, 26.28064728], [89.11252594, 26.28055191], [89.11261749, 26.28039169], [89.11270142, 26.28014183], [89.11274719, 26.27989578], [89.11271667, 26.27960968], [89.11265564, 26.27940369], [89.11251068, 26.27911186], [89.11233521, 26.27889252], [89.11212921, 26.27867699], [89.11190796, 26.27843094], [89.11180878, 26.27825737], [89.11170959, 26.27794838], [89.11167908, 26.27766991], [89.11164856, 26.27729225], [89.11166382, 26.27687454], [89.11170197, 26.27655792], [89.11180115, 26.276371], [89.11195374, 26.27624512], [89.11217499, 26.2761898], [89.11239624, 26.27619171]], [[89.10921478, 26.30457115], [89.11055756, 26.30461311], [89.11009979, 26.30492973], [89.10903168, 26.3065834], [89.10897064, 26.30644226], [89.10903931, 26.30456734], [89.10921478, 26.30457115]], [[89.11437988, 26.29961967], [89.11508942, 26.30080032], [89.11509705, 26.30250168], [89.11408997, 26.30283165], [89.11391449, 26.30126762], [89.11383057, 26.30092812], [89.11380005, 26.29903412], [89.11437988, 26.29961967]], [[89.13286591, 26.29480362], [89.13321686, 26.29485321], [89.13354492, 26.29494858], [89.13381958, 26.29504395], [89.13399506, 26.29514313], [89.13409424, 26.29520798], [89.13427734, 26.29541206], [89.13443756, 26.29554939], [89.13461304, 26.29564095], [89.13479614, 26.29567337], [89.13491821, 26.29579544], [89.1348877, 26.29613304], [89.13486481, 26.2965374], [89.13482666, 26.29686165], [89.13478851, 26.29707909], [89.134758, 26.29725266], [89.1346817, 26.29749107], [89.13458252, 26.29778481], [89.13450623, 26.2979641], [89.13394928, 26.2978363], [89.13376617, 26.2977829], [89.13352203, 26.29769707], [89.13323975, 26.2975769], [89.13293457, 26.29745865], [89.1326828, 26.29737473], [89.13248444, 26.29732513], [89.13218689, 26.29726028], [89.13188171, 26.29714584], [89.13154602, 26.2970295], [89.1312561, 26.29692078], [89.13106537, 26.29684258], [89.13097382, 26.29671288], [89.13097382, 26.29647636], [89.13101196, 26.29617882], [89.13105011, 26.29587746], [89.13108063, 26.29569435], [89.13114166, 26.29546547], [89.13117981, 26.2953167], [89.13126373, 26.29515457], [89.13140106, 26.29497337], [89.1315155, 26.29488182], [89.1316452, 26.29483223], [89.13183594, 26.29480171], [89.13202667, 26.29478836], [89.13227844, 26.29477692], [89.13260651, 26.29476166], [89.13286591, 26.29480362]], [[89.01126099, 26.26631546], [89.01076508, 26.26660347], [89.01023102, 26.26689529], [89.0098114, 26.26710892], [89.00939178, 26.26730537], [89.00907135, 26.26745224], [89.00891876, 26.26750565], [89.00880432, 26.2674675], [89.00868988, 26.26737976], [89.00862122, 26.26727867], [89.00852966, 26.26700783], [89.00844574, 26.26684952], [89.00831604, 26.2666893], [89.00814056, 26.26654434], [89.00794983, 26.26642227], [89.00773621, 26.26633835], [89.00747681, 26.26623154], [89.00714874, 26.26614189], [89.00678253, 26.26607704], [89.00637817, 26.26603317], [89.00596619, 26.26600266], [89.00559998, 26.26592445], [89.00522614, 26.26582146], [89.00495911, 26.26572418], [89.00478363, 26.26565552], [89.00458527, 26.26556396], [89.00445557, 26.26547432], [89.00428772, 26.2652359], [89.00426483, 26.26504326], [89.00430298, 26.26488686], [89.0045166, 26.26478386], [89.00495911, 26.26472473], [89.00528717, 26.26466942], [89.00556183, 26.26457214], [89.00569916, 26.26435852], [89.00576782, 26.26411629], [89.00575256, 26.26373291], [89.00571442, 26.26334763], [89.00559998, 26.26284218], [89.0054245, 26.26232529], [89.0052948, 26.26189995], [89.00514984, 26.26138306], [89.00506592, 26.26090622], [89.00500488, 26.26024437], [89.00497437, 26.25959206], [89.00494385, 26.25894165], [89.00495148, 26.25828552], [89.00498199, 26.25779152], [89.00500488, 26.25720406], [89.00509644, 26.25680542], [89.00512695, 26.2565937], [89.00511169, 26.25649261], [89.00505829, 26.25640678], [89.00498962, 26.25629044], [89.00492096, 26.25613213], [89.00487518, 26.25601768], [89.004776, 26.25591278], [89.0045929, 26.25581932], [89.00450897, 26.25580215], [89.00427246, 26.25570297], [89.00404358, 26.25559807], [89.00387573, 26.25560379], [89.00361633, 26.25558853], [89.00334167, 26.25556183], [89.00318909, 26.25563812], [89.00331116, 26.25610733], [89.00331879, 26.25689507], [89.00330353, 26.25762558], [89.0032196, 26.25854874], [89.00317383, 26.25952721], [89.00320435, 26.26033783], [89.00337219, 26.26105881], [89.00366974, 26.26187515], [89.0038681, 26.26249886], [89.00398254, 26.26297379], [89.00399017, 26.2633419], [89.00392914, 26.26359749], [89.0038147, 26.26382637], [89.00358582, 26.26406097], [89.00309753, 26.26394463], [89.00259399, 26.26371384], [89.00209808, 26.26349449], [89.00179291, 26.26340485], [89.00151825, 26.26333809], [89.00131989, 26.26330376], [89.00110626, 26.26315498], [89.00081635, 26.26278877], [89.00051117, 26.26241684], [89.00021362, 26.26208496], [89.0, 26.26178169], [88.99982452, 26.26148033], [88.99966431, 26.26094055], [88.99970245, 26.26041222], [88.99983215, 26.25991631], [89.00001526, 26.25959396], [89.00016785, 26.25933838], [89.00036621, 26.2588253], [89.00053406, 26.25834084], [89.00069427, 26.25773621], [89.00070953, 26.257267], [89.00057983, 26.25687408], [88.99992371, 26.256464], [88.99971771, 26.25628471], [88.99942017, 26.25608063], [88.9991684, 26.25595093], [88.99893951, 26.25581741], [88.99871826, 26.2556839], [88.9985199, 26.25559235], [88.99836731, 26.25547409], [88.99815369, 26.25521851], [88.99808502, 26.25511169], [88.99803925, 26.25491714], [88.99803925, 26.25465393], [88.99808502, 26.25438118], [88.9981842, 26.2540741], [88.9983139, 26.2537365], [88.99856567, 26.25334549], [88.99886322, 26.25296974], [88.99916077, 26.25271797], [88.99956512, 26.25248146], [89.00005341, 26.25224113], [89.00043488, 26.25209236], [89.00085449, 26.2519455], [89.00123596, 26.25178719], [89.0015564, 26.25160027], [89.00208282, 26.25130653], [89.00270081, 26.2509861], [89.00345612, 26.25060463], [89.00415802, 26.25029945], [89.0046463, 26.25015068], [89.0051651, 26.25001717], [89.00556183, 26.24990845], [89.00571442, 26.24986839], [89.00576019, 26.25001335], [89.00579834, 26.25059319], [89.00585175, 26.25165558], [89.00588226, 26.25241089], [89.00584412, 26.25280762], [89.005867, 26.25336838], [89.00585175, 26.25365829], [89.00588226, 26.25376129], [89.00598907, 26.25391769], [89.00610352, 26.25404549], [89.00621796, 26.25413704], [89.00641632, 26.25415039], [89.0066452, 26.25414276], [89.00698853, 26.25416374], [89.00721741, 26.25419426], [89.00728607, 26.25429153], [89.00732422, 26.25473976], [89.00731659, 26.25514412], [89.00727844, 26.25562477], [89.00736237, 26.25594711], [89.0075531, 26.25637817], [89.00763702, 26.25671768], [89.00778961, 26.25703621], [89.00801849, 26.25732613], [89.00823975, 26.25756073], [89.00850677, 26.25772285], [89.00873566, 26.2578125], [89.00898743, 26.25784302], [89.00926208, 26.25782204], [89.009552, 26.25780869], [89.0098114, 26.25781059], [89.01015472, 26.25787163], [89.01052094, 26.25792885], [89.01083374, 26.25805092], [89.01101685, 26.25813675], [89.01118469, 26.25824356], [89.01130676, 26.25836372], [89.01136017, 26.25855446], [89.01133728, 26.25890732], [89.01124573, 26.25930405], [89.01118469, 26.25963783], [89.01111603, 26.25999641], [89.01105499, 26.26044655], [89.01105499, 26.26086044], [89.01111603, 26.26124191], [89.01118469, 26.26144409], [89.01131439, 26.26160049], [89.0116272, 26.26184082], [89.01194, 26.2619915], [89.0121994, 26.26206398], [89.01242828, 26.26207733], [89.01261139, 26.26211739], [89.01281738, 26.26216125], [89.01298523, 26.26229286], [89.01325226, 26.26246834], [89.01360321, 26.26269531], [89.01389313, 26.26299095], [89.01406097, 26.2632637], [89.01424408, 26.26354218], [89.01441193, 26.26392365], [89.014534, 26.26433182], [89.01460266, 26.26477242], [89.01464844, 26.26522064], [89.01462555, 26.26562309], [89.01460266, 26.26574135], [89.014328, 26.26578522], [89.01383972, 26.26578712], [89.01311493, 26.26570892], [89.01251221, 26.26576424], [89.01186371, 26.26601028], [89.01126099, 26.26631546]], [[89.02735901, 26.27350235], [89.02719879, 26.2735405], [89.02703094, 26.27352333], [89.02687836, 26.27341843], [89.02667236, 26.27328682], [89.02648926, 26.27319336], [89.02625275, 26.27318954], [89.02604675, 26.27327156], [89.02584839, 26.27335167], [89.02571869, 26.27332497], [89.02558136, 26.27323914], [89.02542877, 26.27307701], [89.02526093, 26.27285385], [89.02513123, 26.27267265], [89.02503204, 26.2725544], [89.02490997, 26.27243233], [89.02474213, 26.27233696], [89.02440643, 26.27227592], [89.0240097, 26.27217102], [89.02354431, 26.2719841], [89.02326202, 26.2718811], [89.02302551, 26.27175903], [89.02268982, 26.27149391], [89.02243805, 26.27129555], [89.02236176, 26.27119446], [89.0223999, 26.27107048], [89.0224762, 26.27096176], [89.02266693, 26.27082634], [89.02282715, 26.27072525], [89.02311707, 26.27055359], [89.02345276, 26.27033424], [89.02371979, 26.27013588], [89.02397919, 26.26991653], [89.02414703, 26.2697506], [89.02427673, 26.26958656], [89.02439117, 26.26939964], [89.02442169, 26.26911736], [89.02445984, 26.2687912], [89.02445984, 26.26852989], [89.02437592, 26.26815796], [89.02422333, 26.26782036], [89.02405548, 26.26760292], [89.02385712, 26.2673645], [89.02375793, 26.26720428], [89.02367401, 26.26694489], [89.02366638, 26.26661301], [89.02374268, 26.26628304], [89.02388763, 26.26599503], [89.02405548, 26.26579666], [89.0242157, 26.26566887], [89.02445984, 26.26555443], [89.02475739, 26.26554298], [89.02516174, 26.26562691], [89.02555847, 26.26575851], [89.02575684, 26.26581573], [89.02597046, 26.26586151], [89.02610779, 26.26587677], [89.02629852, 26.26582718], [89.0265274, 26.26574326], [89.02671051, 26.26564598], [89.02690125, 26.26548004], [89.02706146, 26.26531982], [89.02714539, 26.26516914], [89.02719116, 26.26499748], [89.02719879, 26.26478767], [89.0271759, 26.2645874], [89.02707672, 26.26422119], [89.02693176, 26.26387787], [89.02690887, 26.26371956], [89.02696228, 26.26355362], [89.0271225, 26.26333618], [89.02740479, 26.26306534], [89.02767181, 26.26275826], [89.02798462, 26.26240921], [89.02817535, 26.26208878], [89.02828217, 26.26166344], [89.02838135, 26.26128006], [89.02844238, 26.26089287], [89.02850342, 26.26037216], [89.02855682, 26.25984383], [89.02857208, 26.25941277], [89.02854156, 26.25876045], [89.02849579, 26.25834274], [89.02851105, 26.25801277], [89.02859497, 26.25763702], [89.02872467, 26.25733948], [89.02884674, 26.2571907], [89.02897644, 26.25708961], [89.0292511, 26.25693893], [89.02966309, 26.25677872], [89.03002167, 26.25672913], [89.03029633, 26.25676155], [89.03052521, 26.25678444], [89.03069305, 26.25684738], [89.03086853, 26.25691032], [89.03108215, 26.25695229], [89.03121185, 26.25695038], [89.03144836, 26.25678444], [89.03160095, 26.2566452], [89.03187561, 26.25642395], [89.03213501, 26.25627136], [89.03237915, 26.25622368], [89.03284454, 26.25630379], [89.0332489, 26.25655174], [89.03353882, 26.25681305], [89.03376007, 26.25704956], [89.03393555, 26.25725555], [89.03404999, 26.25738335], [89.03421783, 26.25741959], [89.03440094, 26.25743484], [89.0345993, 26.2576046], [89.03475189, 26.25787926], [89.03481293, 26.2582531], [89.03486633, 26.25873375], [89.03494263, 26.25912285], [89.0350647, 26.25953674], [89.03520203, 26.25997734], [89.03543091, 26.26035118], [89.03562927, 26.26064491], [89.03591919, 26.26103592], [89.03612518, 26.26126099], [89.03622437, 26.26132584], [89.03632355, 26.26137733], [89.03643799, 26.26145554], [89.03649902, 26.26160622], [89.03651428, 26.2618084], [89.0364151, 26.26210213], [89.0362854, 26.26238441], [89.03620911, 26.2625618], [89.0361557, 26.26284409], [89.03619385, 26.26312637], [89.03630829, 26.2634201], [89.03653717, 26.26381302], [89.03670502, 26.26406479], [89.03678894, 26.26428032], [89.03664398, 26.26441574], [89.03633118, 26.26454163], [89.03579712, 26.2646637], [89.03534698, 26.26473427], [89.0349884, 26.26482201], [89.03453064, 26.26493454], [89.03408051, 26.26506424], [89.03351593, 26.26524544], [89.0331955, 26.26535606], [89.0329361, 26.26550102], [89.0327301, 26.26570892], [89.03266907, 26.2660141], [89.03266144, 26.26646614], [89.03265381, 26.26683998], [89.03269196, 26.26710892], [89.03273773, 26.26720047], [89.03303528, 26.2673111], [89.03346252, 26.26743889], [89.03372955, 26.26756668], [89.03384399, 26.26774788], [89.03387451, 26.26801682], [89.03386688, 26.26825905], [89.03381348, 26.26847458], [89.03372955, 26.26869202], [89.03359222, 26.26894951], [89.03343201, 26.26916885], [89.03329468, 26.26937294], [89.03307343, 26.2695961], [89.0328598, 26.26973915], [89.03266907, 26.269804], [89.03237152, 26.26986122], [89.03211975, 26.2699337], [89.03189087, 26.27018356], [89.03150177, 26.27050781], [89.03109741, 26.27083397], [89.03062439, 26.27121544], [89.03011322, 26.27158737], [89.02971649, 26.27192307], [89.02937317, 26.27218437], [89.02890778, 26.27252769], [89.02850342, 26.27279472], [89.02806854, 26.27310753], [89.02773285, 26.27332497], [89.02746582, 26.27347565], [89.02735901, 26.27350235]], [[89.04797363, 26.24597168], [89.04794312, 26.24580193], [89.0482254, 26.24575615], [89.04797363, 26.24597168]], [[88.92779541, 26.33548546], [88.92708588, 26.33567047], [88.92395782, 26.33536339], [88.92230225, 26.33554268], [88.92132568, 26.33552551], [88.9213562, 26.33524704], [88.92153931, 26.33317947], [88.92157745, 26.33113289], [88.92173004, 26.32966995], [88.92261505, 26.32975769], [88.92384338, 26.32754517], [88.92313385, 26.32710648], [88.92333221, 26.32669067], [88.92107391, 26.3263588], [88.91925049, 26.32598495], [88.91871643, 26.32583046], [88.91812134, 26.32565689], [88.91895294, 26.32448387], [88.92010498, 26.32285118], [88.92218781, 26.31995392], [88.92253113, 26.32006264], [88.9226532, 26.31978798], [88.92237854, 26.31971169], [88.92373657, 26.31822395], [88.92539978, 26.31868172], [88.92549896, 26.31760216], [88.9261322, 26.31666374], [88.92684937, 26.31632996], [88.92618561, 26.31593704], [88.9260025, 26.31612206], [88.92453003, 26.31560516], [88.92321014, 26.31522751], [88.92417145, 26.31362724], [88.92491913, 26.31385994], [88.92530823, 26.31341362], [88.92642975, 26.31208038], [88.92745209, 26.31097412], [88.92874146, 26.31095314], [88.92961884, 26.30930138], [88.93070984, 26.30741882], [88.93093872, 26.30544472], [88.93061829, 26.30406952], [88.9267807, 26.30227089], [88.92456055, 26.30010605], [88.92428589, 26.29953957], [88.92350769, 26.29794502], [88.92365265, 26.29606247], [88.92515564, 26.29424667], [88.92539215, 26.29395485], [88.92797089, 26.29188347], [88.92842865, 26.29183578], [88.92956543, 26.29171753], [88.93304443, 26.29234314], [88.93685913, 26.29007339], [88.9378891, 26.28940964], [88.93965912, 26.28831482], [88.94179535, 26.28684044], [88.94268799, 26.28679848], [88.94337463, 26.28676605], [88.94442749, 26.28413773], [88.94559479, 26.28156281], [88.94770813, 26.27930069], [88.95036316, 26.27687454], [88.95320892, 26.27537727], [88.95446014, 26.27472115], [88.95664215, 26.27556419], [88.95883179, 26.27633286], [88.96095276, 26.2769928], [88.96372986, 26.27734184], [88.96417999, 26.27742004], [88.96618652, 26.27777481], [88.96683502, 26.27776146], [88.96949005, 26.27770424], [88.97008514, 26.2782135], [88.97041321, 26.2784977], [88.97290039, 26.27825928], [88.97325134, 26.2793026], [88.97614288, 26.2781086], [88.97405243, 26.28159332], [88.97345734, 26.28197861], [88.97523499, 26.28414345], [88.9758606, 26.2837162], [88.97611237, 26.28409958], [88.97657776, 26.2840023], [88.97709656, 26.28389168], [88.98021698, 26.2832222], [88.98058319, 26.28317451], [88.98151398, 26.28305626], [88.98195648, 26.28557777], [88.98244476, 26.28775406], [88.98280334, 26.28777885], [88.98325348, 26.28941536], [88.98360443, 26.29100418], [88.98394775, 26.29319], [88.98358917, 26.29345703], [88.98358917, 26.29335403], [88.98292542, 26.2936039], [88.98303986, 26.29414368], [88.98277283, 26.2941761], [88.9831543, 26.29431343], [88.98371887, 26.29433823], [88.98392487, 26.29466057], [88.98298645, 26.29521561], [88.98412323, 26.29499817], [88.98413849, 26.295187], [88.98475647, 26.29540634], [88.98480988, 26.29668045], [88.98409271, 26.29725456], [88.98418427, 26.297472], [88.98368073, 26.29804611], [88.9835968, 26.29958344], [88.98296356, 26.30002785], [88.98270416, 26.30021858], [88.98160553, 26.30102921], [88.98142242, 26.30116272], [88.97958374, 26.30121613], [88.97949982, 26.29920769], [88.97748566, 26.29968452], [88.97741699, 26.29916954], [88.97731781, 26.29846764], [88.97679138, 26.29847336], [88.9766922, 26.29859734], [88.97640228, 26.29896736], [88.97653198, 26.29841042], [88.97660828, 26.29810524], [88.97635651, 26.29764366], [88.97615814, 26.29767609], [88.97595215, 26.29731941], [88.97615051, 26.29676247], [88.9757843, 26.29538727], [88.97363281, 26.29574394], [88.97354126, 26.29515266], [88.97141266, 26.29505348], [88.9697113, 26.29483986], [88.96977234, 26.2951622], [88.96983337, 26.29548836], [88.96894073, 26.29554939], [88.96864319, 26.29722786], [88.96828461, 26.29724121], [88.9681015, 26.29727364], [88.967659, 26.29735374], [88.96775055, 26.29640579], [88.96776581, 26.2962513], [88.96767426, 26.29623032], [88.96681213, 26.29603958], [88.96586609, 26.29602432], [88.96556854, 26.29559708], [88.96392059, 26.29564095], [88.96232605, 26.29543877], [88.96180725, 26.29509735], [88.96083832, 26.29505348], [88.96084595, 26.29562378], [88.96060944, 26.29562187], [88.96076202, 26.29588699], [88.96103668, 26.29586792], [88.96107483, 26.29644394], [88.96089172, 26.29647446], [88.96090698, 26.29717636], [88.96123505, 26.29720306], [88.9611969, 26.29822731], [88.96110535, 26.2991581], [88.96112061, 26.29989052], [88.96229553, 26.29988289], [88.96289825, 26.2998085], [88.96297455, 26.30000496], [88.96370697, 26.29992294], [88.96375275, 26.30020905], [88.96421814, 26.30016899], [88.96424103, 26.30080986], [88.96457672, 26.30082703], [88.9645462, 26.30104828], [88.96446991, 26.3010788], [88.96424866, 26.30343437], [88.96405792, 26.30341148], [88.96391296, 26.30414009], [88.96277618, 26.30399132], [88.96263885, 26.30397415], [88.9625473, 26.30457878], [88.96243286, 26.30539703], [88.96192932, 26.30534744], [88.96134186, 26.30528831], [88.96131897, 26.30516624], [88.95972443, 26.3050251], [88.95974731, 26.30430412], [88.95967102, 26.304245], [88.95967865, 26.30399513], [88.95860291, 26.30396652], [88.95832062, 26.30444336], [88.95751953, 26.30463982], [88.95689392, 26.3047924], [88.95665741, 26.30485153], [88.9562912, 26.30494499], [88.95568085, 26.30486488], [88.95501709, 26.30426788], [88.95433807, 26.30392647], [88.95420837, 26.30362701], [88.95342255, 26.30363083], [88.95330048, 26.30461884], [88.95317078, 26.30571175], [88.95310211, 26.3065567], [88.95305634, 26.30723953], [88.95327759, 26.30731773], [88.95329285, 26.30792046], [88.9552536, 26.30823898], [88.95606995, 26.30834198], [88.95637512, 26.30838013], [88.95645905, 26.30912209], [88.9549408, 26.30924988], [88.9546051, 26.30929184], [88.95376587, 26.30939865], [88.9537735, 26.31078339], [88.95314789, 26.31089401], [88.95309448, 26.31188393], [88.95281219, 26.31191826], [88.95279694, 26.31311035], [88.95252991, 26.31316185], [88.95245361, 26.31406403], [88.95227814, 26.3144989], [88.95207977, 26.31449699], [88.95207214, 26.31537819], [88.95194244, 26.31638527], [88.95001221, 26.31775665], [88.94902802, 26.31845284], [88.94795227, 26.31798363], [88.94621277, 26.31721878], [88.94320679, 26.3158226], [88.94091797, 26.31469154], [88.93903351, 26.31373215], [88.93756104, 26.31298637], [88.93747711, 26.31329918], [88.9367981, 26.31590843], [88.93611145, 26.31596184], [88.93606567, 26.31618118], [88.93586731, 26.31704903], [88.93574524, 26.31948853], [88.93559265, 26.3205986], [88.93549347, 26.3213501], [88.93754578, 26.32321358], [88.93997955, 26.32329559], [88.94017792, 26.32328796], [88.94216156, 26.32320976], [88.94225311, 26.32658195], [88.9420929, 26.32920074], [88.94168091, 26.33094025], [88.94048309, 26.33229446], [88.93967438, 26.33310699], [88.93840027, 26.33502388], [88.93569183, 26.33447456], [88.93509674, 26.33381653], [88.93152618, 26.33289528], [88.92984009, 26.33238411], [88.92776489, 26.33178329], [88.92751312, 26.33296585], [88.92794037, 26.33462524], [88.92779541, 26.33548546]], [[89.0042572, 26.42137718], [89.00550079, 26.41943932], [89.00574493, 26.42076492], [89.00588226, 26.42152405], [89.00457764, 26.42124176], [89.0042572, 26.42137718]], [[88.94125366, 26.35522079], [88.94082642, 26.35533714], [88.94042206, 26.35535622], [88.93972015, 26.35525703], [88.93904877, 26.355093], [88.93865204, 26.3550148], [88.9384079, 26.35485649], [88.93824768, 26.35482979], [88.93812561, 26.35470963], [88.93801117, 26.35438156], [88.93801117, 26.35420227], [88.93798065, 26.35387039], [88.93776703, 26.35294533], [88.93781281, 26.35261154], [88.93785095, 26.35243225], [88.93779755, 26.3521843], [88.93784332, 26.35201645], [88.93781281, 26.35184479], [88.93784332, 26.3517189], [88.93789673, 26.35155106], [88.93796539, 26.35146713], [88.93798065, 26.35135269], [88.93811798, 26.35126877], [88.93819427, 26.35115433], [88.93830872, 26.35106087], [88.93847656, 26.35097122], [88.93862915, 26.35087776], [88.9388504, 26.35079765], [88.93904114, 26.35079765], [88.93913269, 26.35090256], [88.93930054, 26.35095024], [88.93948364, 26.35099983], [88.93983459, 26.35107422], [88.94004059, 26.35104752], [88.94072723, 26.35129166], [88.94125366, 26.35151672], [88.94154358, 26.35162926], [88.94189453, 26.35183907], [88.94219971, 26.35201836], [88.94233704, 26.35222626], [88.94245911, 26.3524437], [88.94258881, 26.35247612], [88.94258881, 26.35262871], [88.94261169, 26.35303688], [88.94264984, 26.35362625], [88.94254303, 26.35442734], [88.94229889, 26.35490608], [88.9420929, 26.35520363], [88.94158936, 26.35516548], [88.94125366, 26.35522079]], [[89.04703522, 26.28692436], [89.04897308, 26.28685379], [89.04893494, 26.28704262], [89.04891968, 26.28712273], [89.04975128, 26.28768158], [89.05034637, 26.28808022], [89.04979706, 26.28899765], [89.04956055, 26.28893661], [89.04811859, 26.28856659], [89.04776001, 26.28847504], [89.04707336, 26.28715706], [89.04703522, 26.28692436]], [[89.02149963, 26.29281044], [89.02361298, 26.29238129], [89.02481842, 26.29339027], [89.02559662, 26.29582024], [89.02548218, 26.29718971], [89.02417755, 26.29964066], [89.02373505, 26.30127335], [89.02332306, 26.30063057], [89.02316284, 26.30035782], [89.02214813, 26.2986393], [89.02113342, 26.2975235], [89.02093506, 26.29730034], [89.02111816, 26.29719353], [89.02248383, 26.29641533], [89.02327728, 26.29340744], [89.0231781, 26.29338264], [89.02149963, 26.29298019], [89.02149963, 26.29281044]], [[88.95831299, 26.34260559], [88.95855713, 26.33892059], [88.95855713, 26.33806992], [88.95916748, 26.33612823], [88.95943451, 26.33605576], [88.95960236, 26.33600998], [88.96231079, 26.33632088], [88.96282959, 26.33638191], [88.96285248, 26.33683968], [88.96266174, 26.33796501], [88.96349335, 26.33856201], [88.96214294, 26.33934212], [88.96178436, 26.34062767], [88.96170044, 26.34091759], [88.96179962, 26.34162521], [88.96202087, 26.3431797], [88.96198273, 26.34463501], [88.96248627, 26.34539032], [88.96164703, 26.34518814], [88.96032715, 26.34514999], [88.95868683, 26.34477043], [88.95847321, 26.34380722], [88.95898438, 26.343647], [88.9587326, 26.34282875], [88.95831299, 26.34260559]]], [[[88.10694885, 21.89360046], [88.10722351, 21.89333344], [88.10805511, 21.89333344], [88.10861206, 21.8927784], [88.10888672, 21.8927803], [88.10972595, 21.89193916], [88.10972595, 21.89166641], [88.11055756, 21.89082909], [88.11055756, 21.89055634], [88.11165619, 21.88944054], [88.11166382, 21.88916779], [88.11194611, 21.88889122], [88.11194611, 21.88833809], [88.11165619, 21.88805962], [88.11165619, 21.88778114], [88.11138916, 21.88750076], [88.11138916, 21.88694], [88.1111145, 21.88666534], [88.11112213, 21.88639069], [88.11083221, 21.88611031], [88.11083221, 21.88582993], [88.11055756, 21.88555336], [88.11055756, 21.88528061], [88.1102829, 21.88500023], [88.11027527, 21.88472176], [88.11000061, 21.88444328], [88.11000061, 21.88417053], [88.10929871, 21.88388062], [88.1087265, 21.88442039], [88.10708618, 21.88644981], [88.10673523, 21.88686752], [88.10660553, 21.88701248], [88.10639191, 21.88722229], [88.10626984, 21.88784981], [88.10555267, 21.88833809], [88.10500336, 21.88888931], [88.1049881, 21.88972092], [88.10472107, 21.88999748], [88.10472107, 21.89027977], [88.10500336, 21.89055634], [88.1049881, 21.89110756], [88.10501099, 21.89219666], [88.10497284, 21.89261055], [88.10472107, 21.89527702], [88.10466003, 21.89562035], [88.10459137, 21.89639854], [88.10472107, 21.89694214], [88.10444641, 21.89722061], [88.10444641, 21.89777946], [88.10472107, 21.89805984], [88.10472107, 21.89861107], [88.10527802, 21.8991642], [88.10527802, 21.89944649], [88.10555267, 21.89972115], [88.10584259, 21.89999962], [88.10610962, 21.90055466], [88.10624695, 21.90068817], [88.10639954, 21.90083313], [88.10639191, 21.9011116], [88.10666656, 21.90146065], [88.10681152, 21.90195084], [88.10729218, 21.90243912], [88.10743713, 21.90285301], [88.10749817, 21.90332031], [88.10764313, 21.90348053], [88.10778046, 21.90389061], [88.10799408, 21.90416718], [88.1084671, 21.9047184], [88.10861969, 21.90479851], [88.10888672, 21.90513992], [88.10897064, 21.90549088], [88.10910034, 21.90577126], [88.10917664, 21.90611076], [88.10938263, 21.90632248], [88.10945129, 21.90666962], [88.11000061, 21.90750122], [88.11021423, 21.90777779], [88.11055756, 21.90833282], [88.11077118, 21.90854263], [88.11090851, 21.90888977], [88.11125946, 21.90923119], [88.11165619, 21.90966034], [88.11194611, 21.90999985], [88.11229706, 21.9103508], [88.11250305, 21.91055489], [88.11277771, 21.91055489], [88.11277771, 21.91027832], [88.11277008, 21.91007042], [88.11265564, 21.90994263], [88.11222076, 21.90944481], [88.11222076, 21.90917015], [88.11213684, 21.90888977], [88.11194611, 21.90833282], [88.11173248, 21.90805626], [88.11165619, 21.90777969], [88.1114502, 21.90750122], [88.11112213, 21.90694237], [88.11096954, 21.9066658], [88.11055756, 21.90611076], [88.10984039, 21.90519905], [88.10943604, 21.90443993], [88.10929108, 21.90409088], [88.10909271, 21.90374947], [88.10909271, 21.90348053], [88.10839844, 21.90257072], [88.10810852, 21.90208054], [88.10790253, 21.90180016], [88.10790253, 21.90138626], [88.10769653, 21.90118027], [88.10762787, 21.90083122], [88.10719299, 21.90013123], [88.10694122, 21.89972305], [88.10694122, 21.8991642], [88.10527802, 21.89751053], [88.10527802, 21.89694023], [88.10583496, 21.89638901], [88.10582733, 21.89611053], [88.10610962, 21.89583015], [88.10583496, 21.8955555], [88.10582733, 21.89528275], [88.10694122, 21.89417267], [88.10694885, 21.89360046]]], [[[88.13730621, 21.89513969], [88.13659668, 21.89439964], [88.13601685, 21.89447021], [88.13594818, 21.89534187], [88.13637543, 21.89587975], [88.1368103, 21.89675331], [88.13759613, 21.89769173], [88.13767242, 21.89775085], [88.13802338, 21.89802933], [88.13838196, 21.89816475], [88.13848877, 21.89813232], [88.13859558, 21.8980999], [88.13852692, 21.89789963], [88.13780975, 21.89615059], [88.13730621, 21.89513969]]], [[[88.13478851, 21.92674446], [88.13504028, 21.92642021], [88.13531494, 21.92605782], [88.13553619, 21.92562103], [88.13568878, 21.92514992], [88.13583374, 21.92471123], [88.13598633, 21.9242897], [88.13616943, 21.92394447], [88.13637543, 21.92363358], [88.1365509, 21.92332649], [88.13671112, 21.92303085], [88.13691711, 21.9227829], [88.137146, 21.92250443], [88.13742065, 21.92220497], [88.13774109, 21.92187119], [88.13809967, 21.92147064], [88.13854218, 21.92105865], [88.13902283, 21.92060089], [88.13952637, 21.92016983], [88.14000702, 21.91970062], [88.14047241, 21.91925049], [88.14090729, 21.91881943], [88.14141083, 21.91840935], [88.141922, 21.91794014], [88.14238739, 21.91739082], [88.14293671, 21.91696167], [88.14337921, 21.91658974], [88.14372253, 21.91630363], [88.14404297, 21.91608429], [88.14424133, 21.91579056], [88.14446259, 21.91553688], [88.1446228, 21.91526031], [88.14447021, 21.91502953], [88.14425659, 21.91480064], [88.14408112, 21.91455269], [88.14383698, 21.91438103], [88.14360809, 21.91415977], [88.14336395, 21.91391945], [88.14309692, 21.91365051], [88.1428833, 21.91331291], [88.14266205, 21.91296005], [88.14241028, 21.91266823], [88.14222717, 21.91235733], [88.14205933, 21.91205788], [88.14190674, 21.91179276], [88.14170837, 21.91155815], [88.14154816, 21.9112606], [88.14136505, 21.91090775], [88.14109802, 21.91056061], [88.14084625, 21.91020012], [88.14061737, 21.90982819], [88.14048767, 21.90942955], [88.14031219, 21.9091301], [88.14019775, 21.90884018], [88.14002991, 21.90862083], [88.13989258, 21.90837097], [88.13982391, 21.90828896], [88.13970947, 21.90815544], [88.13949585, 21.90793991], [88.13931274, 21.90764046], [88.13912964, 21.90733719], [88.13889313, 21.90706062], [88.1386261, 21.90677643], [88.1383667, 21.9064312], [88.13806152, 21.90603065], [88.1377182, 21.90556717], [88.1373291, 21.90509033], [88.13695526, 21.90460587], [88.13658142, 21.90415955], [88.13623047, 21.90373039], [88.13588715, 21.90335274], [88.13553619, 21.90300179], [88.13516235, 21.90265083], [88.13477325, 21.90225029], [88.13439941, 21.90177917], [88.13395691, 21.901371], [88.13350677, 21.90099525], [88.13311005, 21.90060997], [88.13275146, 21.90026093], [88.13238525, 21.89999008], [88.13201904, 21.89972878], [88.13166809, 21.89944077], [88.13111115, 21.89944649], [88.13097382, 21.89930534], [88.13083649, 21.8991642], [88.13054657, 21.89916992], [88.13027954, 21.89888954], [88.12944794, 21.89888954], [88.1286087, 21.89972305], [88.12832642, 21.89972115], [88.12805176, 21.89999962], [88.1277771, 21.89999962], [88.12750244, 21.90028], [88.12722015, 21.90027618], [88.1269455, 21.90055466], [88.12666321, 21.90055466], [88.12611389, 21.9011116], [88.12593079, 21.90098763], [88.12561798, 21.90114975], [88.12535095, 21.901371], [88.12507629, 21.90159988], [88.12490845, 21.90195847], [88.12474823, 21.90238953], [88.12465668, 21.90287018], [88.12445831, 21.90323067], [88.12428284, 21.90359116], [88.12406158, 21.90391922], [88.12393188, 21.90430069], [88.12387085, 21.90474319], [88.12377167, 21.90519905], [88.12356567, 21.90566444], [88.12324524, 21.90613174], [88.12290192, 21.90664101], [88.12249756, 21.90714073], [88.1220932, 21.90763092], [88.12165833, 21.90808105], [88.12125397, 21.90855408], [88.12077332, 21.90896988], [88.12032318, 21.90944862], [88.11988068, 21.90992355], [88.11937714, 21.91028023], [88.118927, 21.91064072], [88.11856079, 21.91102982], [88.11817169, 21.9113903], [88.11779785, 21.9117794], [88.11749268, 21.91222], [88.11721039, 21.9126606], [88.11694336, 21.91311073], [88.11675262, 21.91358185], [88.11673737, 21.9141655], [88.11688995, 21.91480827], [88.11687469, 21.91550827], [88.11662292, 21.91618919], [88.11631775, 21.91675568], [88.11612701, 21.91724014], [88.11611176, 21.91777992], [88.11611176, 21.9183197], [88.11726379, 21.91949463], [88.11756897, 21.91991806], [88.11777496, 21.92000008], [88.11888885, 21.92111015], [88.1193924, 21.92180252], [88.12082672, 21.92333984], [88.12110901, 21.92361069], [88.12166595, 21.92416954], [88.12194824, 21.92416954], [88.1222229, 21.92444992], [88.12249756, 21.92444229], [88.12306213, 21.92472076], [88.12335205, 21.92500114], [88.12361145, 21.92500114], [88.1241684, 21.92556], [88.12472534, 21.92555428], [88.125, 21.92583275], [88.12555695, 21.92583084], [88.1258316, 21.92611122], [88.12609863, 21.92611122], [88.12638855, 21.92583084], [88.12722015, 21.92583084], [88.12750244, 21.92611122], [88.12805176, 21.92611122], [88.12832642, 21.92638969], [88.12915802, 21.92638969], [88.12944794, 21.92667007], [88.1305542, 21.92666435], [88.13083649, 21.92694664], [88.13111115, 21.92694664], [88.1313858, 21.9272213], [88.13249969, 21.9272213], [88.13277435, 21.92749977], [88.13361359, 21.92749977], [88.13374329, 21.92763138], [88.13388824, 21.92778015], [88.13437653, 21.92728043], [88.13443756, 21.92721367], [88.13459778, 21.9270401], [88.13478851, 21.92674446]]], [[[88.5047226, 21.91278076], [88.50499725, 21.91250992], [88.50776672, 21.91250992], [88.50805664, 21.91222], [88.50861359, 21.91222191], [88.5091629, 21.91166687], [88.5091629, 21.91082954], [88.50888824, 21.91055489], [88.50888824, 21.91027832], [88.50860596, 21.90999985], [88.50860596, 21.90971947], [88.50722504, 21.90833282], [88.50694275, 21.90833282], [88.50653076, 21.90791893], [88.50611115, 21.90749931], [88.50611115, 21.90722275], [88.50583649, 21.90694427], [88.50583649, 21.9066658], [88.50554657, 21.9063797], [88.5055542, 21.90611076], [88.50527954, 21.90582848], [88.50499725, 21.9058342], [88.50416565, 21.90500069], [88.50416565, 21.90472221], [88.50389099, 21.90444374], [88.50389099, 21.90416718], [88.5036087, 21.90389061], [88.5036087, 21.90360832], [88.50332642, 21.90332031], [88.50333405, 21.90305519], [88.5027771, 21.90250015], [88.5027771, 21.90221977], [88.50250244, 21.90194511], [88.50250244, 21.90167046], [88.50221252, 21.90139008], [88.50221252, 21.9011097], [88.5019455, 21.90083313], [88.5019455, 21.90055466], [88.50166321, 21.90027618], [88.50166321, 21.89972115], [88.50138855, 21.89944649], [88.50138855, 21.8991642], [88.50026703, 21.89805984], [88.5, 21.89805984], [88.4991684, 21.89722061], [88.4991684, 21.89666748], [88.49888611, 21.89639091], [88.49888611, 21.89611053], [88.49861145, 21.89583015], [88.49833679, 21.89583206], [88.4980545, 21.8955555], [88.49777985, 21.89556122], [88.49694824, 21.89472008], [88.49666595, 21.89472008], [88.49610901, 21.89416695], [88.49582672, 21.89417267], [88.49472046, 21.89306259], [88.4944458, 21.89306259], [88.49415588, 21.8927803], [88.49388885, 21.8927803], [88.49276733, 21.89166832], [88.49250031, 21.89166832], [88.49194336, 21.89110756], [88.49028015, 21.88944435], [88.48916626, 21.88944435], [88.48805237, 21.8908329], [88.48722076, 21.8908329], [88.48721313, 21.89138031], [88.48694611, 21.89166641], [88.4854126, 21.89242935], [88.48082733, 21.89472008], [88.48000336, 21.8955555], [88.47944641, 21.89583015], [88.47861481, 21.89666748], [88.47849274, 21.89672852], [88.47805786, 21.89694214], [88.47805786, 21.89722061], [88.4777832, 21.89751053], [88.4777832, 21.89777946], [88.47750092, 21.89777756], [88.47693634, 21.89833069], [88.47693634, 21.89861107], [88.47666931, 21.89888954], [88.47666931, 21.8991642], [88.47694397, 21.89944649], [88.47694397, 21.90055466], [88.47721863, 21.90083122], [88.47721863, 21.90138626], [88.47733307, 21.9015007], [88.47750092, 21.90167046], [88.47750092, 21.90194511], [88.47777557, 21.90222168], [88.4777832, 21.90250015], [88.47833252, 21.90305519], [88.47833252, 21.90332031], [88.47877502, 21.90377808], [88.47915649, 21.90416908], [88.47944641, 21.90416908], [88.48194122, 21.90666962], [88.48222351, 21.9066658], [88.48278046, 21.90722275], [88.48306274, 21.90722275], [88.48332977, 21.90750122], [88.48361206, 21.90750122], [88.48388672, 21.90777969], [88.48416901, 21.90777969], [88.48443604, 21.90806007], [88.48472595, 21.90805626], [88.48500061, 21.90833282], [88.48527527, 21.90833282], [88.48555756, 21.9086113], [88.48583221, 21.90860939], [88.48610687, 21.90888977], [88.48638916, 21.90888977], [88.48665619, 21.90917015], [88.48694611, 21.90917015], [88.48721313, 21.90945053], [88.48750305, 21.90944481], [88.48777771, 21.90972137], [88.48805237, 21.90971947], [88.48860931, 21.91028023], [88.48916626, 21.91027832], [88.48944092, 21.91055489], [88.49055481, 21.91055489], [88.4908371, 21.91083336], [88.4916687, 21.91083336], [88.49194336, 21.91111183], [88.4944458, 21.91110992], [88.49472046, 21.9113903], [88.49555206, 21.9113903], [88.49582672, 21.91167068], [88.4962616, 21.91166687], [88.49694824, 21.91166687], [88.49749756, 21.91222191], [88.49777985, 21.91222], [88.49796295, 21.91240692], [88.49833679, 21.91278076], [88.498703, 21.91240692], [88.49888611, 21.91222191], [88.5, 21.91222], [88.50026703, 21.91250992], [88.5008316, 21.91250992], [88.50110626, 21.91278076], [88.50138855, 21.91278076], [88.50166321, 21.91250992], [88.5027771, 21.91250992], [88.50305176, 21.91278076], [88.5047226, 21.91278076]]], [[[88.42546082, 21.90409088], [88.42546844, 21.90380096], [88.42512512, 21.9036026], [88.42500305, 21.90360832], [88.42305756, 21.90360832], [88.4227829, 21.9039402], [88.42256165, 21.9039402], [88.42228699, 21.90365982], [88.42166901, 21.90360832], [88.42141724, 21.9036808], [88.42070007, 21.90387726], [88.4207077, 21.90402031], [88.42092133, 21.90464973], [88.42105103, 21.90480042], [88.42124939, 21.90501022], [88.42138672, 21.90527725], [88.42194366, 21.9058342], [88.42250061, 21.9058342], [88.42277527, 21.90611076], [88.42401123, 21.90604401], [88.42444611, 21.9058342], [88.4246521, 21.90576553], [88.42485809, 21.9054203], [88.42501068, 21.9052639], [88.42533875, 21.90493011], [88.4254837, 21.90472221], [88.42546082, 21.90409088]]], [[[88.45245361, 21.90633774], [88.45197296, 21.90608025], [88.45173645, 21.90594673], [88.45094299, 21.90612984], [88.45025635, 21.90620995], [88.44976807, 21.90614128], [88.44934082, 21.9061203], [88.44890594, 21.90615082], [88.4484787, 21.90623093], [88.44803619, 21.90615082], [88.44760132, 21.90610123], [88.44715881, 21.90610123], [88.44671631, 21.90610123], [88.44631958, 21.90608025], [88.445961, 21.90608978], [88.44567871, 21.90612984], [88.44542694, 21.90624237], [88.44510651, 21.90637016], [88.44470978, 21.9065609], [88.44423676, 21.90682983], [88.44372559, 21.90720558], [88.44309235, 21.90757179], [88.44268036, 21.90768814], [88.44226837, 21.90780449], [88.44218445, 21.90804482], [88.44220734, 21.90837288], [88.44226074, 21.90876961], [88.44249725, 21.90920067], [88.44284058, 21.90962982], [88.44326782, 21.91000748], [88.44374084, 21.91035271], [88.44435883, 21.91057587], [88.4450531, 21.91077423], [88.44583893, 21.91089058], [88.44664001, 21.91101646], [88.44740295, 21.91104126], [88.44809723, 21.91114807], [88.4487381, 21.9113102], [88.44934845, 21.9113903], [88.4499588, 21.91152954], [88.45053101, 21.9117794], [88.45105743, 21.91209984], [88.45168304, 21.91229057], [88.45224762, 21.91258049], [88.45278168, 21.91292953], [88.45334625, 21.91329956], [88.45401001, 21.91361809], [88.45475769, 21.9139328], [88.45561218, 21.91413116], [88.45603943, 21.91397095], [88.4564743, 21.91381454], [88.45662689, 21.91337013], [88.45652008, 21.91290283], [88.45637512, 21.91243744], [88.45619202, 21.91201973], [88.45604706, 21.91164017], [88.45584106, 21.91136169], [88.45568085, 21.91109276], [88.45554352, 21.91080093], [88.45536804, 21.91052055], [88.45520782, 21.91021156], [88.45500183, 21.90988541], [88.4548111, 21.90950966], [88.4546814, 21.90906715], [88.45443726, 21.90868187], [88.45417786, 21.9083271], [88.45394897, 21.90796852], [88.45378876, 21.90757179], [88.45350647, 21.90724945], [88.453125, 21.90699959], [88.45278931, 21.90666962], [88.45245361, 21.90633774]]], [[[88.14138794, 22.02639008], [88.14250183, 22.02527809], [88.14277649, 22.02527809], [88.14332581, 22.02471924], [88.14360809, 22.02472305], [88.14444733, 22.02388954], [88.14472198, 22.02389908], [88.14444733, 22.02361107], [88.14444733, 22.02333069], [88.14416504, 22.02305794], [88.14417267, 22.02277946], [88.14389038, 22.02250099], [88.14389038, 22.02194023], [88.14360809, 22.02166557], [88.14360809, 22.02111053], [88.14332581, 22.02083969], [88.14332581, 22.02056122], [88.14167023, 22.01889038], [88.14167023, 22.01861], [88.1388855, 22.0158329], [88.1388855, 22.01555634], [88.13722229, 22.01389122], [88.13722229, 22.01361275], [88.13694763, 22.01332855], [88.13694763, 22.0130558], [88.13529205, 22.01139069], [88.13529205, 22.0111084], [88.13424683, 22.01008224], [88.1341629, 22.01000023], [88.1341629, 22.00971985], [88.13361359, 22.00916862], [88.13360596, 22.00889969], [88.13194275, 22.00722122], [88.13194275, 22.00694656], [88.1313858, 22.00638962], [88.1313858, 22.00611115], [88.13027954, 22.00500107], [88.13027954, 22.00444031], [88.12999725, 22.00416756], [88.12999725, 22.00389099], [88.12944794, 22.00333023], [88.12944794, 22.00305557], [88.1286087, 22.00222015], [88.1286087, 22.00166702], [88.12832642, 22.00139046], [88.12832642, 22.00111008], [88.12805176, 22.00083351], [88.12805176, 22.00055504], [88.1277771, 22.00028038], [88.12722015, 22.00000191], [88.12728882, 21.99895859], [88.12722015, 21.99860764], [88.12700653, 21.99839973], [88.12695313, 21.99805832], [88.12666321, 21.99749756], [88.12638092, 21.99735832], [88.1261673, 21.99715042], [88.12602997, 21.99686813], [88.12609863, 21.99650955], [88.12589264, 21.99617767], [88.12568665, 21.99583054], [88.12547302, 21.99575615], [88.12526703, 21.99500084], [88.12526703, 21.99472046], [88.12472534, 21.99416542], [88.12473297, 21.99360085], [88.12444305, 21.99333572], [88.12444305, 21.99305534], [88.1241684, 21.99278069], [88.1241684, 21.99221992], [88.12388611, 21.99194336], [88.12388611, 21.99167061], [88.12335205, 21.99110985], [88.12333679, 21.99083328], [88.1230545, 21.99055481], [88.1230545, 21.99027824], [88.12277985, 21.98999977], [88.12277985, 21.98971939], [88.12249756, 21.98944473], [88.12249756, 21.98888969], [88.1222229, 21.98861122], [88.1222229, 21.98833275], [88.12055206, 21.98666573], [88.12055206, 21.98638916], [88.12029266, 21.98611069], [88.1202774, 21.98583412], [88.12000275, 21.98555565], [88.12000275, 21.98527908], [88.11972046, 21.98500061], [88.11972046, 21.98473167], [88.11888885, 21.98389053], [88.11888885, 21.98360825], [88.11805725, 21.98277855], [88.11805725, 21.98249817], [88.11750031, 21.98195076], [88.11750031, 21.98166084], [88.11694336, 21.98111153], [88.11694336, 21.98083305], [88.1166687, 21.98055458], [88.1166687, 21.98027992], [88.11638641, 21.97999954], [88.11638641, 21.97972107], [88.11555481, 21.97888947], [88.11554718, 21.97859955], [88.11528015, 21.97833252], [88.11528015, 21.97805405], [88.11472321, 21.97750092], [88.11472321, 21.97722054], [88.11444092, 21.97694206], [88.11444092, 21.9766674], [88.11415863, 21.97639084], [88.11415863, 21.97611046], [88.11305237, 21.97500038], [88.11305237, 21.97472191], [88.11277771, 21.97444534], [88.11277771, 21.97417259], [88.11250305, 21.9738903], [88.11248779, 21.97359848], [88.11194611, 21.97305489], [88.11194611, 21.97277832], [88.11138916, 21.97222137], [88.11138916, 21.97194481], [88.11000061, 21.97055626], [88.11000061, 21.97027969], [88.10943604, 21.96972084], [88.10944366, 21.96944427], [88.10861206, 21.96861076], [88.10861206, 21.96833038], [88.10749817, 21.96722221], [88.10749817, 21.96694374], [88.10555267, 21.96500015], [88.10555267, 21.96471977], [88.10527802, 21.96444321], [88.10527802, 21.96417046], [88.10472107, 21.96362114], [88.10472107, 21.96333122], [88.10388947, 21.96249962], [88.10388947, 21.96222115], [88.10361481, 21.96194458], [88.10361481, 21.96166611], [88.10111237, 21.95916939], [88.10111237, 21.95889091], [88.10083008, 21.95889091], [88.10083008, 21.95861053], [88.10056305, 21.95832825], [88.10055542, 21.9580555], [88.09999847, 21.95750046], [88.09999847, 21.9569397], [88.09972382, 21.95666885], [88.09971619, 21.95639038], [88.09889221, 21.95556068], [88.09889221, 21.9552803], [88.09860992, 21.95499992], [88.09860992, 21.95471954], [88.09833527, 21.95444679], [88.09833527, 21.95388794], [88.09722137, 21.95277977], [88.09722137, 21.95222092], [88.09444427, 21.94944382], [88.09424591, 21.94897652], [88.09395599, 21.94859123], [88.09366608, 21.9481926], [88.09336853, 21.94778061], [88.09307098, 21.94738388], [88.09283447, 21.94695282], [88.09259796, 21.94652939], [88.09246063, 21.94607925], [88.09220123, 21.94573975], [88.09179688, 21.9455204], [88.09194183, 21.94528008], [88.09194183, 21.94472122], [88.09166718, 21.94444466], [88.09166718, 21.94416618], [88.09139252, 21.94388962], [88.09139252, 21.94361115], [88.09111023, 21.94333076], [88.09111023, 21.94277954], [88.09055328, 21.94222069], [88.09055328, 21.94194412], [88.09027863, 21.94166565], [88.09027863, 21.94111061], [88.08998871, 21.94083023], [88.08999634, 21.94055748], [88.08972168, 21.94028091], [88.08972168, 21.93972015], [88.08944702, 21.93944359], [88.08944702, 21.93833351], [88.08916473, 21.93805313], [88.0891571, 21.9375], [88.08889008, 21.93721962], [88.08889008, 21.93638802], [88.08860779, 21.93610954], [88.08860779, 21.93527794], [88.08833313, 21.93499947], [88.08833313, 21.9347229], [88.08750153, 21.93388939], [88.08750153, 21.93277931], [88.08555603, 21.93082809], [88.08528137, 21.93083382], [88.08472443, 21.93027878], [88.0847168, 21.93054962], [88.08361053, 21.93166924], [88.08333588, 21.93166733], [88.08305359, 21.93194389], [88.08194733, 21.93194389], [88.08166504, 21.93166733], [88.08139038, 21.93166924], [88.08055878, 21.93082809], [88.08055878, 21.93055534], [88.07917023, 21.9291687], [88.07917023, 21.92889023], [88.07888794, 21.92860985], [88.07861328, 21.92861176], [88.07583618, 21.92583275], [88.07472229, 21.92583084], [88.07444763, 21.92611122], [88.07305908, 21.92611122], [88.07277679, 21.92583084], [88.07250214, 21.92583275], [88.07241058, 21.9257412], [88.07221985, 21.92555428], [88.07195282, 21.92556], [88.07138824, 21.92500114], [88.07138824, 21.92472076], [88.07111359, 21.92444229], [88.07110596, 21.92416954], [88.0708313, 21.92389107], [88.0708313, 21.92361069], [88.07110596, 21.92333031], [88.07111359, 21.92305565], [88.07138824, 21.9227829], [88.07138824, 21.92222023], [88.0708313, 21.9216671], [88.0708313, 21.92139053], [88.07055664, 21.92111015], [88.07055664, 21.92083359], [88.07027435, 21.92055511], [88.06973267, 21.92056274], [88.06944275, 21.92028046], [88.06916809, 21.92028046], [88.06887817, 21.92000008], [88.06861115, 21.92028046], [88.06804657, 21.92028046], [88.06777954, 21.92000008], [88.06694794, 21.92000008], [88.06667328, 21.9197216], [88.06583405, 21.9197216], [88.06416321, 21.91805649], [88.0633316, 21.9180584], [88.0630722, 21.91777992], [88.0630722, 21.91721916], [88.0625, 21.91722298], [88.06138611, 21.91611099], [88.06111145, 21.91611099], [88.06083679, 21.91583061], [88.0605545, 21.91583252], [88.0597229, 21.91500092], [88.05944824, 21.91500092], [88.05916595, 21.91472054], [88.0588913, 21.91472244], [88.05860901, 21.91444588], [88.05833435, 21.91444588], [88.05750275, 21.91361046], [88.05722046, 21.91361046], [88.05665588, 21.91306114], [88.05610657, 21.91306114], [88.05583191, 21.91278076], [88.05526733, 21.91278076], [88.05500031, 21.91250992], [88.05444336, 21.91250992], [88.05421448, 21.91226768], [88.0533371, 21.91222191], [88.05305481, 21.91194344], [88.05278015, 21.91195107], [88.05249786, 21.91167068], [88.0508194, 21.91167068], [88.05055237, 21.9113903], [88.04860687, 21.9113903], [88.04837799, 21.91115761], [88.04807281, 21.91110992], [88.04750061, 21.91167068], [88.04722595, 21.91167068], [88.04722595, 21.91194344], [88.04666901, 21.91222], [88.04666901, 21.91250992], [88.04611206, 21.91306114], [88.04611206, 21.91527557], [88.04582977, 21.91555786], [88.04664612, 21.91970062], [88.04722595, 21.92307091], [88.04722595, 21.92611122], [88.04786682, 21.92806816], [88.04788971, 21.92931938], [88.04746246, 21.9312706], [88.04767609, 21.93288422], [88.0493927, 21.93556976], [88.04917908, 21.93745995], [88.04917908, 21.93860054], [88.05002594, 21.94041061], [88.05083466, 21.94305611], [88.0508194, 21.94338989], [88.05182648, 21.94501114], [88.05197144, 21.94755936], [88.05303955, 21.94977951], [88.0534668, 21.9509201], [88.05388641, 21.95305443], [88.05388641, 21.9533329], [88.05477142, 21.9548912], [88.05576324, 21.95832062], [88.05640411, 21.96047211], [88.05726624, 21.96235275], [88.05841064, 21.96397018], [88.05876923, 21.96639061], [88.05956268, 21.96767044], [88.0597229, 21.96889114], [88.06001282, 21.96916962], [88.06006622, 21.96935081], [88.06157684, 21.97250938], [88.06301117, 21.97513008], [88.0633316, 21.97611046], [88.0633316, 21.97694016], [88.06388855, 21.97750092], [88.06427002, 21.97880363], [88.06555939, 21.98142052], [88.06684113, 21.98357964], [88.06820679, 21.98526001], [88.06935883, 21.98714066], [88.06999969, 21.98888969], [88.06999969, 21.98999977], [88.07027435, 21.99027824], [88.07026672, 21.99082947], [88.0708313, 21.99138832], [88.07132721, 21.99221992], [88.07250214, 21.99389076], [88.07250214, 21.99417114], [88.07332611, 21.99500084], [88.07332611, 21.99528122], [88.07554626, 21.99749756], [88.07554626, 21.99777985], [88.07694244, 21.9991703], [88.07694244, 21.99945259], [88.07749939, 22.00000191], [88.08000183, 22.00027847], [88.08018494, 22.00046158], [88.08055878, 22.00083351], [88.08083344, 22.00083351], [88.08110809, 22.00111008], [88.08139038, 22.00111008], [88.08167267, 22.00139046], [88.08194733, 22.00138855], [88.08277893, 22.00222015], [88.08277893, 22.00250053], [88.08388519, 22.00361061], [88.0847168, 22.00361061], [88.08666992, 22.00555992], [88.08666992, 22.00611115], [88.08750153, 22.00694656], [88.08777618, 22.00694656], [88.08805847, 22.00722313], [88.08833313, 22.00722122], [88.09027863, 22.00917053], [88.09055328, 22.00889969], [88.0908432, 22.00889969], [88.09221649, 22.01028061], [88.09278107, 22.01028061], [88.09388733, 22.01139069], [88.09471893, 22.01139069], [88.09500122, 22.01166916], [88.09555817, 22.01166725], [88.09583282, 22.01194382], [88.09610748, 22.01194382], [88.09638977, 22.01222229], [88.09777832, 22.01221848], [88.09805298, 22.01250076], [88.09889221, 22.01250076], [88.09918213, 22.01277924], [88.09999847, 22.01277924], [88.10028076, 22.01305962], [88.10111237, 22.0130558], [88.10124969, 22.01319504], [88.10138702, 22.01333427], [88.10192871, 22.01332855], [88.10221863, 22.01361275], [88.10250092, 22.01361275], [88.1027832, 22.01389122], [88.10333252, 22.01389122], [88.10360718, 22.01416969], [88.10416412, 22.01416588], [88.10444641, 22.01444435], [88.10500336, 22.01444435], [88.10527802, 22.01472282], [88.10582733, 22.01471138], [88.10610962, 22.01499939], [88.10694122, 22.01499939], [88.10721588, 22.01527977], [88.10806274, 22.01527977], [88.10832977, 22.01556015], [88.10916901, 22.01555634], [88.10944366, 22.0158329], [88.11000061, 22.0158329], [88.11027527, 22.01611137], [88.11083221, 22.01610947], [88.11112213, 22.01638985], [88.11250305, 22.01638985], [88.11277771, 22.01667023], [88.11305237, 22.01666641], [88.11333466, 22.01694489], [88.1138916, 22.01694489], [88.11416626, 22.01666641], [88.11472321, 22.01667023], [88.11499786, 22.01638985], [88.11528015, 22.01638985], [88.11554718, 22.01667023], [88.1158371, 22.01666641], [88.11611176, 22.01694489], [88.11722565, 22.01694489], [88.11740875, 22.0171299], [88.11750031, 22.01722145], [88.11805725, 22.01721954], [88.11833191, 22.01749992], [88.11972046, 22.01749992], [88.12194824, 22.01833344], [88.1222229, 22.01833344], [88.12249756, 22.01861191], [88.12335205, 22.01861], [88.12361145, 22.01889038], [88.12444305, 22.01889038], [88.12454224, 22.01898575], [88.12473297, 22.01917076], [88.12555695, 22.01916695], [88.12611389, 22.01972198], [88.12666321, 22.01972198], [88.1269455, 22.02000046], [88.12750244, 22.02000046], [88.1277771, 22.02028084], [88.12805176, 22.02028084], [88.1286087, 22.02083969], [88.12915802, 22.02083969], [88.12944794, 22.02111053], [88.12999725, 22.02111053], [88.13027954, 22.02139091], [88.1305542, 22.0213871], [88.13111115, 22.02194405], [88.1313858, 22.02194023], [88.13175964, 22.02231407], [88.13194275, 22.02250099], [88.13249969, 22.02250099], [88.13276672, 22.02277946], [88.13305664, 22.02277946], [88.1333313, 22.02305984], [88.13361359, 22.02305794], [88.13388824, 22.0233326], [88.1341629, 22.0233326], [88.1342392, 22.0234108], [88.13471985, 22.02389908], [88.13529205, 22.02389908], [88.13542175, 22.02403069], [88.13555908, 22.02416992], [88.1361084, 22.02416611], [88.13666534, 22.02472305], [88.13722229, 22.02471924], [88.13749695, 22.02499962], [88.13916779, 22.02499962], [88.13944244, 22.02527809], [88.13999939, 22.02527809], [88.14027405, 22.02555466], [88.14055634, 22.02555084], [88.14138794, 22.02639008]]], [[[88.16333008, 21.93722153], [88.16361237, 21.93694305], [88.16414642, 21.93695068], [88.16443634, 21.93667984], [88.16471863, 21.93667984], [88.16500092, 21.93638992], [88.16526794, 21.93638992], [88.16555786, 21.93610954], [88.16583252, 21.93611145], [88.16611481, 21.93583107], [88.16638947, 21.93583107], [88.16666412, 21.93555641], [88.16694641, 21.93556023], [88.16722107, 21.93527985], [88.16750336, 21.93527985], [88.16805267, 21.9347229], [88.16833496, 21.9347229], [88.16889191, 21.93416595], [88.16916656, 21.93416977], [88.17082977, 21.93250084], [88.17111206, 21.93250084], [88.17140198, 21.93221855], [88.17138672, 21.93139076], [88.17111206, 21.93111038], [88.17111206, 21.93082809], [88.17082977, 21.93055534], [88.17082977, 21.93000031], [88.17166901, 21.92917061], [88.17140198, 21.92889023], [88.17140198, 21.92832947], [88.17111206, 21.92805481], [88.17111206, 21.92777634], [88.17082977, 21.92749023], [88.17082977, 21.9272213], [88.17138672, 21.92666435], [88.17082977, 21.92611122], [88.17082977, 21.92527962], [88.17056274, 21.92500114], [88.17056274, 21.92444992], [88.17028046, 21.92416954], [88.17028046, 21.92361069], [88.16999817, 21.92333031], [88.16999817, 21.92250061], [88.16971588, 21.92222023], [88.16972351, 21.92138863], [88.16889191, 21.92056274], [88.16889191, 21.92028046], [88.16805267, 21.91945267], [88.16805267, 21.91917038], [88.16777802, 21.91889191], [88.16777802, 21.91860771], [88.16694641, 21.91777992], [88.16694641, 21.91749954], [88.16658783, 21.91713715], [88.16611481, 21.91666794], [88.16583252, 21.91666985], [88.16526794, 21.91611099], [88.16500092, 21.91638947], [88.16500092, 21.91666794], [88.16443634, 21.91721916], [88.16443634, 21.91749954], [88.16416931, 21.91777992], [88.16416931, 21.91805649], [88.16388702, 21.9183197], [88.16388702, 21.91889191], [88.16361237, 21.91917038], [88.16361237, 21.91944504], [88.16305542, 21.92000008], [88.16305542, 21.92083359], [88.16278076, 21.92111015], [88.16278076, 21.92139053], [88.16249847, 21.9216671], [88.16249847, 21.92194176], [88.16194153, 21.92250061], [88.16194153, 21.9227829], [88.16166687, 21.92305946], [88.16166687, 21.92361069], [88.16110992, 21.92416573], [88.16110992, 21.92472076], [88.16083527, 21.92499924], [88.1608429, 21.92583084], [88.16055298, 21.92611122], [88.16055298, 21.92666435], [88.16027832, 21.92694664], [88.16027832, 21.92749023], [88.16000366, 21.92777634], [88.16000366, 21.92833328], [88.15972137, 21.92860985], [88.15972137, 21.92917061], [88.1608429, 21.93028069], [88.1608429, 21.93139076], [88.16055298, 21.93166733], [88.16055298, 21.93222237], [88.16083527, 21.93250084], [88.1608429, 21.93499947], [88.16110992, 21.93527794], [88.16110992, 21.93583107], [88.16139221, 21.93611145], [88.16166687, 21.93638992], [88.16194153, 21.93638802], [88.16278076, 21.93722153], [88.16333008, 21.93722153]]], [[[89.02481079, 21.93172836], [89.02452087, 21.93192101], [89.02424622, 21.93207932], [89.02398682, 21.93225479], [89.02372742, 21.93264008], [89.0231781, 21.93320274], [89.02303314, 21.93352318], [89.02271271, 21.9337883], [89.02218628, 21.93404388], [89.02194214, 21.93445015], [89.02166748, 21.93483162], [89.02136993, 21.93519592], [89.02102661, 21.93552971], [89.02066803, 21.93585014], [89.02031708, 21.93618393], [89.01999664, 21.93655205], [89.01967621, 21.936903], [89.01935577, 21.93721581], [89.01902771, 21.93748283], [89.01869202, 21.93769455], [89.01834106, 21.93787193], [89.01799011, 21.9380703], [89.01764679, 21.93831253], [89.01729584, 21.93853378], [89.01696014, 21.93872261], [89.01661682, 21.9389019], [89.01628113, 21.93912315], [89.01584625, 21.93931007], [89.01543427, 21.93956566], [89.0149765, 21.93984222], [89.01449585, 21.94009209], [89.01405334, 21.9403801], [89.01356506, 21.94060707], [89.01307678, 21.94084167], [89.01261902, 21.94110489], [89.01212311, 21.94133186], [89.01158905, 21.94147301], [89.01107788, 21.94168282], [89.0105896, 21.94192314], [89.01004791, 21.94205475], [89.00953674, 21.94223213], [89.0090332, 21.94243813], [89.00848389, 21.94255257], [89.00796509, 21.94274139], [89.00740051, 21.94283676], [89.00730133, 21.94286919], [89.00687408, 21.94301796], [89.00628662, 21.94309235], [89.00572205, 21.94329262], [89.00514221, 21.94349289], [89.00469971, 21.94377708], [89.00430298, 21.94406319], [89.0039978, 21.94441795], [89.00369263, 21.94472313], [89.00370026, 21.94521141], [89.00338745, 21.94550133], [89.00292206, 21.94579124], [89.00242615, 21.94589806], [89.00202179, 21.9461937], [89.00167084, 21.94658089], [89.00134277, 21.94698143], [89.00099945, 21.94735146], [89.00068665, 21.94776917], [89.0, 21.94888878], [88.99972534, 21.94910622], [88.99954987, 21.94948387], [88.99951935, 21.94960785], [88.99945831, 21.94981956], [88.99943542, 21.95012856], [88.99937439, 21.95043373], [88.99922943, 21.95075035], [88.9991684, 21.95122147], [88.9991684, 21.95177269], [88.9991684, 21.95236015], [88.9991684, 21.95294952], [88.99925995, 21.9534874], [88.99945068, 21.95391273], [88.99961853, 21.95424461], [89.0, 21.95472145], [89.00073242, 21.95587158], [89.00125122, 21.9564743], [89.00152588, 21.95689011], [89.00215912, 21.95799828], [89.00251007, 21.95859146], [89.00265503, 21.95876694], [89.00287628, 21.95903015], [89.00312805, 21.95951271], [89.00353241, 21.95983124], [89.00370026, 21.95992088], [89.00409698, 21.96039009], [89.00444031, 21.9606781], [89.00475311, 21.96101952], [89.00511169, 21.96138191], [89.00550842, 21.96174049], [89.005867, 21.96213341], [89.00624084, 21.96247292], [89.00663757, 21.96276283], [89.00701904, 21.96305275], [89.00740814, 21.96333122], [89.00775909, 21.96362114], [89.00810242, 21.96388817], [89.00841522, 21.96416473], [89.00874329, 21.9644413], [89.00907135, 21.96473122], [89.00943756, 21.96503639], [89.00979614, 21.96537209], [89.01008606, 21.96576118], [89.01046753, 21.96602821], [89.01081085, 21.96624565], [89.01109314, 21.96646309], [89.01129913, 21.96671295], [89.01147461, 21.96700859], [89.01172638, 21.96729088], [89.01196289, 21.96764565], [89.01222992, 21.96797752], [89.01250458, 21.96827126], [89.01278687, 21.96853065], [89.01306152, 21.96878052], [89.01335144, 21.96902847], [89.0136795, 21.96925163], [89.01396942, 21.96953011], [89.01425934, 21.96980095], [89.01444244, 21.96994019], [89.01456451, 21.97003746], [89.0147934, 21.97034264], [89.01500702, 21.97066307], [89.01524353, 21.97094345], [89.01541901, 21.97125435], [89.01559448, 21.97156334], [89.01583862, 21.97182274], [89.01609039, 21.97210121], [89.01631927, 21.97243309], [89.01655579, 21.9727726], [89.01683044, 21.97312164], [89.01712799, 21.97356987], [89.01737213, 21.97401237], [89.01764679, 21.97449303], [89.01783752, 21.97525215], [89.01806641, 21.97553444], [89.01799774, 21.9760437], [89.01799011, 21.97650909], [89.0181427, 21.9770298], [89.0181427, 21.97737312], [89.01811218, 21.97772789], [89.01799011, 21.97805214], [89.01792145, 21.97859192], [89.01792145, 21.97881126], [89.01792145, 21.97919846], [89.01773834, 21.97951317], [89.01767731, 21.98008156], [89.01757813, 21.98035049], [89.01728821, 21.98078346], [89.01648712, 21.98198128], [89.01634216, 21.98240089], [89.01611328, 21.98278236], [89.01586151, 21.98315048], [89.01560974, 21.98353577], [89.01526642, 21.98384285], [89.01486969, 21.9841404], [89.01438904, 21.98436546], [89.01383209, 21.98451424], [89.01329803, 21.98471642], [89.01277161, 21.98488235], [89.01226807, 21.98502159], [89.01181793, 21.98522186], [89.01133728, 21.98527908], [89.01085663, 21.98527908], [89.01037598, 21.98527908], [89.00991058, 21.98527908], [89.00948334, 21.98527908], [89.00907135, 21.98527908], [89.00866699, 21.98527908], [89.00821686, 21.98524475], [89.00775909, 21.98504066], [89.00718689, 21.98496056], [89.00660706, 21.98476219], [89.00601196, 21.98473358], [89.00546265, 21.98486137], [89.00508118, 21.98526192], [89.00508118, 21.98591042], [89.00543976, 21.98649025], [89.006073, 21.98682213], [89.0067215, 21.9871006], [89.00739288, 21.98727989], [89.00798798, 21.9875145], [89.00853729, 21.98779106], [89.00905609, 21.98806381], [89.00956726, 21.98835182], [89.01004791, 21.98866081], [89.01056671, 21.98892021], [89.01110077, 21.98917389], [89.0116272, 21.98942947], [89.01213074, 21.98971748], [89.01262665, 21.99001694], [89.01309967, 21.99031639], [89.01356506, 21.99056435], [89.01397705, 21.99083138], [89.01436615, 21.99110985], [89.01474762, 21.99138069], [89.01513672, 21.99167061], [89.01551819, 21.99196053], [89.01587677, 21.99226952], [89.01621246, 21.99261665], [89.01651001, 21.99305153], [89.01685333, 21.9935112], [89.01724243, 21.99397087], [89.01766968, 21.99439049], [89.01821136, 21.99471664], [89.0187912, 21.9949913], [89.01940918, 21.99520302], [89.02006531, 21.99532127], [89.02066803, 21.9955101], [89.02127075, 21.99555779], [89.02181244, 21.99560165], [89.02223206, 21.99578285], [89.02268219, 21.99584579], [89.02313995, 21.99593353], [89.0235672, 21.99611092], [89.02406311, 21.99624062], [89.02471924, 21.99615479], [89.025383, 21.99605942], [89.02597809, 21.99590111], [89.02658081, 21.99585152], [89.02715302, 21.99583817], [89.02765656, 21.99583244], [89.02777863, 21.99583244], [89.02805328, 21.99583244], [89.0284729, 21.99591255], [89.02861023, 21.99611092], [89.02889252, 21.99618721], [89.02923584, 21.99625587], [89.02980042, 21.99653244], [89.03009033, 21.99675941], [89.03045654, 21.99707222], [89.03077698, 21.99728966], [89.03119659, 21.99741173], [89.03144836, 21.99758148], [89.03165436, 21.99788857], [89.03213501, 21.99821663], [89.03253174, 21.99863625], [89.03269196, 21.99897194], [89.03283691, 21.99940491], [89.03279114, 21.99973106], [89.03277588, 22.00000191], [89.03278351, 22.00094223], [89.0328598, 22.00134087], [89.03250122, 22.00208282], [89.03192139, 22.00235176], [89.03142548, 22.00235176], [89.03077698, 22.00214958], [89.0304184, 22.00168037], [89.03019714, 22.0010128], [89.03028107, 22.00000191], [89.0302887, 21.99962044], [89.03022766, 21.99926376], [89.0300827, 21.99895287], [89.02997589, 21.99862862], [89.02973938, 21.99836159], [89.02941132, 21.9981308], [89.02902222, 21.99790001], [89.02871704, 21.99763298], [89.02832794, 21.99742317], [89.02789307, 21.99727058], [89.02736664, 21.99723244], [89.02685547, 21.99723053], [89.02638245, 21.99726486], [89.02596283, 21.99736214], [89.02587128, 21.99738121], [89.02554321, 21.99745178], [89.02500153, 21.99740028], [89.02436066, 21.9972477], [89.02390289, 21.99735069], [89.02340698, 21.99752045], [89.02289581, 21.9976902], [89.02231598, 21.99755287], [89.021698, 21.99751091], [89.02102661, 21.99749184], [89.02037811, 21.99742317], [89.01979065, 21.99721909], [89.01922607, 21.99696159], [89.01869202, 21.99672508], [89.01824188, 21.99641991], [89.01776886, 21.99611092], [89.01728058, 21.99581146], [89.0168457, 21.99546432], [89.01641846, 21.99519157], [89.01602936, 21.99492455], [89.01564026, 21.9946804], [89.01526642, 21.99437141], [89.01487732, 21.99404907], [89.01441956, 21.99373055], [89.01389313, 21.99341965], [89.01338196, 21.99306297], [89.01287079, 21.99271584], [89.0124588, 21.99229431], [89.01203918, 21.99189949], [89.01167297, 21.99147224], [89.01127625, 21.99106026], [89.01070404, 21.99079514], [89.01016235, 21.99052811], [89.0096817, 21.99025154], [89.00923157, 21.99002266], [89.00875854, 21.98986244], [89.00828552, 21.98972893], [89.00779724, 21.98961067], [89.00731659, 21.98943329], [89.00680542, 21.98920631], [89.00624847, 21.98899651], [89.00580597, 21.98866844], [89.00538635, 21.98833275], [89.0050354, 21.98800659], [89.0047226, 21.98767281], [89.00441742, 21.98736191], [89.00405121, 21.98711967], [89.0036087, 21.98693848], [89.00305176, 21.98638916], [89.00305176, 21.98611259], [89.0027771, 21.9858284], [89.0027771, 21.98555565], [89.00250244, 21.98527908], [89.00250244, 21.98473167], [89.002388, 21.98434258], [89.00223541, 21.98401642], [89.00211334, 21.98364067], [89.00189972, 21.9832859], [89.00166321, 21.98291969], [89.00138855, 21.98260117], [89.00109863, 21.98232269], [89.00077057, 21.98205376], [89.0003891, 21.98153877], [89.0, 21.98139], [88.99957275, 21.98080254], [88.99933624, 21.98075485], [88.99904633, 21.98045158], [88.99875641, 21.98014259], [88.99849701, 21.97980309], [88.9981308, 21.97950172], [88.9977951, 21.97911644], [88.99743652, 21.97869301], [88.99703217, 21.97829247], [88.99668121, 21.97783279], [88.99636841, 21.97737122], [88.99604034, 21.9769783], [88.99567413, 21.97665977], [88.99532318, 21.97633171], [88.99498749, 21.97594833], [88.99462128, 21.97557449], [88.99421692, 21.97522163], [88.99386597, 21.97483253], [88.99352264, 21.97447014], [88.99317932, 21.97417259], [88.99286652, 21.9739399], [88.99254608, 21.97371101], [88.99243927, 21.97363091], [88.99172974, 21.9740448], [88.99166107, 21.97472191], [88.9916687, 21.97500038], [88.9916687, 21.97860146], [88.99138641, 21.97889137], [88.99138641, 21.97958183], [88.99143219, 21.98023987], [88.99162292, 21.9808445], [88.9916687, 21.98143387], [88.99164581, 21.98195076], [88.99151611, 21.98238182], [88.99138641, 21.9827404], [88.99124908, 21.98304939], [88.9910965, 21.98335266], [88.99093628, 21.98365974], [88.99079132, 21.98405266], [88.99055481, 21.98443413], [88.99028015, 21.98484612], [88.99000549, 21.98527145], [88.98969269, 21.98567009], [88.9892807, 21.9860096], [88.98887634, 21.98637962], [88.98841095, 21.98674011], [88.98795319, 21.98716354], [88.98739624, 21.98750114], [88.98681641, 21.98780251], [88.98629761, 21.9881382], [88.98573303, 21.9884243], [88.98511505, 21.98864174], [88.98451996, 21.9888916], [88.9839325, 21.98913383], [88.98329163, 21.98924065], [88.98269653, 21.98941231], [88.98205566, 21.98947906], [88.98142242, 21.98966026], [88.98072815, 21.98974991], [88.98004913, 21.98991966], [88.97972107, 21.98999977], [88.97915649, 21.98999977], [88.97888947, 21.99028206], [88.97833252, 21.99027824], [88.97805786, 21.99055672], [88.97750092, 21.99055672], [88.97721863, 21.99083328], [88.97666931, 21.99083328], [88.97638702, 21.99111557], [88.97583008, 21.99110985], [88.97556305, 21.99139214], [88.97807312, 21.99139214], [88.97833252, 21.99110985], [88.97860718, 21.99110985], [88.97888947, 21.99139214], [88.98000336, 21.99138832], [88.9806366, 21.9916935], [88.98109436, 21.99186134], [88.98156738, 21.99201012], [88.98204041, 21.99222755], [88.98252869, 21.99249458], [88.98306274, 21.99279976], [88.98358917, 21.99318123], [88.98410034, 21.9936161], [88.98458862, 21.99409294], [88.98506165, 21.99456215], [88.98548126, 21.99498749], [88.98581696, 21.99538994], [88.98609924, 21.99577522], [88.98631287, 21.9961319], [88.98648834, 21.99648285], [88.98670197, 21.99677658], [88.98693848, 21.99707985], [88.98718262, 21.99741554], [88.98748016, 21.99773216], [88.98780823, 21.99802971], [88.98816681, 21.998312], [88.98855591, 21.99859047], [88.98899078, 21.99887276], [88.98948669, 21.99912071], [88.99003601, 21.99932289], [88.9905777, 21.99949074], [88.99114227, 21.99969292], [88.99250031, 22.00000191], [88.9935379, 22.00087166], [88.99397278, 22.00180817], [88.9941864, 22.00214195], [88.99433136, 22.00254822], [88.99447632, 22.00302315], [88.99460602, 22.00382042], [88.99475861, 22.00442123], [88.99497986, 22.00476265], [88.99533844, 22.00522614], [88.99569702, 22.00555992], [88.9960556, 22.00583076], [88.99641418, 22.00596237], [88.99691772, 22.00616455], [88.99756622, 22.00649834], [88.99820709, 22.00663185], [88.99871063, 22.00676727], [88.99900055, 22.00682831], [88.99935913, 22.00696754], [88.99935913, 22.00710487], [88.99914551, 22.00716972], [88.99856567, 22.00716972], [88.99799347, 22.00703621], [88.99713135, 22.00703621], [88.99691772, 22.00697327], [88.99633789, 22.00682831], [88.99591064, 22.00670242], [88.9954071, 22.00657272], [88.99482727, 22.00630188], [88.99440002, 22.00603485], [88.99411774, 22.0057621], [88.99382782, 22.00536156], [88.99339294, 22.00481224], [88.99311066, 22.00428772], [88.99267578, 22.00335121], [88.99260712, 22.002882], [88.99260712, 22.00254631], [88.99253082, 22.00228119], [88.99209595, 22.00194168], [88.99138641, 22.00147247], [88.98944092, 22.00000191], [88.9890976, 21.99973106], [88.98860168, 21.99969292], [88.98825073, 21.99950981], [88.98788452, 21.99933052], [88.98751068, 21.99910164], [88.98715973, 21.99881172], [88.98681641, 21.99848175], [88.98649597, 21.99813271], [88.98620605, 21.99778175], [88.98589325, 21.99746132], [88.98552704, 21.99714279], [88.98516846, 21.9967556], [88.98487854, 21.99628639], [88.98459625, 21.99586105], [88.98429871, 21.99549294], [88.98400879, 21.99514198], [88.98369598, 21.99477959], [88.98338318, 21.99438286], [88.98303223, 21.99401474], [88.98262024, 21.9937458], [88.98220825, 21.99353218], [88.98182678, 21.99334145], [88.98145294, 21.99319267], [88.98104858, 21.99304008], [88.9806366, 21.99289131], [88.98020935, 21.99275017], [88.9797821, 21.99261665], [88.97939301, 21.99249077], [88.97902679, 21.99240112], [88.97838593, 21.99223137], [88.97499847, 21.99250031], [88.97476196, 21.99292183], [88.974617, 21.99329185], [88.97447205, 21.99364281], [88.97441864, 21.99407768], [88.97432709, 21.99455261], [88.9744873, 21.99504471], [88.9747467, 21.99549294], [88.97503662, 21.99587822], [88.97528839, 21.99624062], [88.97554016, 21.99654961], [88.97573853, 21.99686241], [88.97590637, 21.99718475], [88.97614288, 21.99745178], [88.97639465, 21.99768448], [88.97666931, 21.99793243], [88.97698212, 21.99821091], [88.97738647, 21.99850464], [88.9777832, 21.99892235], [88.97801208, 21.99942207], [88.97833252, 22.00000191], [88.97860718, 22.00028038], [88.97888947, 22.00056267], [88.97888947, 22.00139046], [88.97916412, 22.00166893], [88.97915649, 22.00222206], [88.97944641, 22.00250053], [88.97944641, 22.00333214], [88.97916412, 22.00361061], [88.97915649, 22.00472069], [88.97888947, 22.00500488], [88.97888947, 22.0055542], [88.97860718, 22.00583076], [88.97861481, 22.00611115], [88.9783783, 22.0063324], [88.97832489, 22.0063858], [88.97805786, 22.00666618], [88.97772217, 22.00700951], [88.97742462, 22.00741005], [88.97714996, 22.00787163], [88.97685242, 22.00834846], [88.97638702, 22.00863075], [88.975914, 22.00894928], [88.9754715, 22.00930977], [88.97499847, 22.00967026], [88.9744873, 22.01001167], [88.97393799, 22.01036072], [88.97338867, 22.01076317], [88.97283173, 22.01112938], [88.97227478, 22.01145935], [88.97180939, 22.01177025], [88.97132111, 22.01195908], [88.97087097, 22.01214027], [88.97044373, 22.01233101], [88.97001648, 22.01251221], [88.96961212, 22.01274681], [88.96923065, 22.0130024], [88.96888733, 22.0133152], [88.96856689, 22.01363945], [88.96823883, 22.01395226], [88.96808624, 22.01436043], [88.96806335, 22.01480484], [88.96806335, 22.01520157], [88.96807861, 22.01554108], [88.9681778, 22.01581383], [88.96833038, 22.01605225], [88.96849823, 22.0163002], [88.96862793, 22.01664162], [88.96878815, 22.01699257], [88.96894073, 22.01735115], [88.96916962, 22.01764107], [88.96942139, 22.01793098], [88.9696579, 22.0182209], [88.96987915, 22.01854324], [88.97009277, 22.01888084], [88.97027588, 22.01922035], [88.97046661, 22.01952934], [88.97055817, 22.01987457], [88.97062683, 22.02020073], [88.97080231, 22.02046013], [88.97097015, 22.02070045], [88.97110748, 22.0209713], [88.97123718, 22.02123833], [88.97138977, 22.02151489], [88.97151947, 22.0218029], [88.97164154, 22.02213097], [88.97173309, 22.02253342], [88.97195435, 22.02289009], [88.97221375, 22.02328491], [88.97245026, 22.02374077], [88.97260284, 22.02425194], [88.97278595, 22.02464104], [88.97305298, 22.02499962], [88.97305298, 22.02583313], [88.9733429, 22.0261116], [88.97338104, 22.0272007], [88.97357941, 22.02779388], [88.97374725, 22.02843285], [88.97400665, 22.02899361], [88.9743042, 22.02946281], [88.97460175, 22.02987099], [88.97492981, 22.03022957], [88.9752655, 22.03056335], [88.9756012, 22.03090096], [88.97586823, 22.03131485], [88.97612762, 22.03168297], [88.97637939, 22.03201103], [88.97658539, 22.03232384], [88.97677612, 22.03262138], [88.97696686, 22.03293037], [88.97720337, 22.03326225], [88.97740173, 22.03368187], [88.97753143, 22.03420448], [88.9777298, 22.03471947], [88.97782898, 22.03528786], [88.97807312, 22.03574944], [88.97831726, 22.03621292], [88.97859192, 22.03669167], [88.97886658, 22.03720284], [88.97911072, 22.03775978], [88.97927094, 22.03840065], [88.97953033, 22.03899193], [88.97982788, 22.03959274], [88.98023987, 22.04005814], [88.9806366, 22.04050255], [88.98104858, 22.04086685], [88.98139191, 22.04121208], [88.98171234, 22.04151917], [88.98197937, 22.04171181], [88.98219299, 22.04192162], [88.98240662, 22.04214287], [88.98266602, 22.04239082], [88.98295593, 22.04269028], [88.98327637, 22.04299736], [88.98358154, 22.04330254], [88.98387909, 22.04361153], [88.98418427, 22.04391861], [88.98445129, 22.04424095], [88.98471069, 22.04454231], [88.98493195, 22.04481316], [88.98509979, 22.04508781], [88.98525238, 22.04535103], [88.98536682, 22.0456295], [88.98550415, 22.0459156], [88.98558044, 22.04628181], [88.98568726, 22.0466404], [88.98582458, 22.04698181], [88.98594666, 22.0473423], [88.98606873, 22.04775047], [88.98610687, 22.04819298], [88.9861145, 22.04864693], [88.98610687, 22.04910088], [88.98605347, 22.04955864], [88.98590851, 22.04998207], [88.98583221, 22.05041885], [88.98575592, 22.05086136], [88.98560333, 22.0512619], [88.98551941, 22.05171013], [88.98538208, 22.05213356], [88.9852829, 22.05256081], [88.98517609, 22.0529995], [88.98503876, 22.05342484], [88.98497772, 22.0538578], [88.98488617, 22.05423164], [88.98477173, 22.0544796], [88.98477936, 22.0547123], [88.98493195, 22.05494881], [88.98516846, 22.05522346], [88.98555756, 22.05545235], [88.98615265, 22.05550194], [88.98647308, 22.0554924], [88.98682404, 22.05548286], [88.98748016, 22.05531693], [88.98814392, 22.05517387], [88.98879242, 22.05501556], [88.98940277, 22.05487633], [88.98996735, 22.05471611], [88.99045563, 22.0545578], [88.99086761, 22.05446053], [88.99111176, 22.05444527], [88.99194336, 22.05444527], [88.99205017, 22.05455208], [88.99222565, 22.05472374], [88.99250031, 22.05472183], [88.9927597, 22.05500031], [88.99294281, 22.05485153], [88.99347687, 22.05473328], [88.99401093, 22.05459023], [88.99452972, 22.05456543], [88.99501801, 22.05477905], [88.99547577, 22.05524254], [88.99594116, 22.05556488], [88.99639893, 22.05581093], [88.99685669, 22.05606461], [88.99723053, 22.05637169], [88.99765015, 22.05666351], [88.99810791, 22.05695152], [88.99859619, 22.05717278], [88.99909973, 22.05735207], [88.99957275, 22.05759239], [89.0, 22.05777931], [89.00027466, 22.05830383], [89.00077057, 22.05894279], [89.00097656, 22.05908012], [89.00119781, 22.0592804], [89.00141907, 22.05935287], [89.00170135, 22.05935287], [89.00228119, 22.05921173], [89.00241852, 22.0589447], [89.00256348, 22.05861092], [89.00255585, 22.05827141], [89.00263977, 22.05787277], [89.00285339, 22.05760384], [89.00285339, 22.05740547], [89.00299835, 22.05707169], [89.00306702, 22.0567894], [89.00314331, 22.05666542], [89.00322723, 22.0564537], [89.00357056, 22.05613136], [89.00388336, 22.05576134], [89.00411987, 22.05534935], [89.00430298, 22.05490303], [89.00449371, 22.05447197], [89.0047226, 22.05407524], [89.00496674, 22.05365944], [89.00527954, 22.0532589], [89.00562286, 22.05285263], [89.00593567, 22.05247688], [89.00614166, 22.0522995], [89.0063858, 22.0522213], [89.00777435, 22.05083275], [89.0083313, 22.0508213], [89.00881958, 22.05120277], [89.00926208, 22.05161285], [89.0096817, 22.05206108], [89.0100174, 22.05256081], [89.01023102, 22.05307961], [89.01035309, 22.05359077], [89.01055145, 22.05402184], [89.01074219, 22.0544281], [89.01092529, 22.05482864], [89.01107025, 22.05526161], [89.01117706, 22.05573082], [89.01133728, 22.05621147], [89.01145172, 22.05674744], [89.01161194, 22.0573101], [89.01173401, 22.05787659], [89.01187897, 22.05834007], [89.01199341, 22.05874062], [89.01211548, 22.05906487], [89.01222229, 22.05939293], [89.01229858, 22.05976105], [89.0124054, 22.06012917], [89.01258087, 22.06050301], [89.01280212, 22.06089211], [89.01303864, 22.0612793], [89.01335144, 22.06156731], [89.01370239, 22.06186676], [89.01381683, 22.06217957], [89.01425171, 22.06259155], [89.01467896, 22.06266022], [89.0151062, 22.06286049], [89.01547241, 22.06293106], [89.01568604, 22.06293106], [89.01618958, 22.06279182], [89.01633453, 22.06265831], [89.01661682, 22.06239128], [89.01669312, 22.06199074], [89.01669312, 22.06092262], [89.01654816, 22.06051064], [89.01633453, 22.06016159], [89.01618195, 22.05954933], [89.01605225, 22.05891228], [89.01584625, 22.05830956], [89.01566315, 22.05767822], [89.01551819, 22.05702972], [89.01535797, 22.05643272], [89.01528931, 22.05590439], [89.01528168, 22.05541039], [89.01531219, 22.05494118], [89.01541138, 22.05446053], [89.01551056, 22.0539856], [89.01554871, 22.05347252], [89.01555634, 22.05294991], [89.01557922, 22.05241203], [89.01567078, 22.05187416], [89.01587677, 22.0513649], [89.0161972, 22.05092049], [89.0166626, 22.05063057], [89.01724243, 22.05048752], [89.01781464, 22.05031776], [89.01835632, 22.05019188], [89.01889038, 22.05000114], [89.01917267, 22.04972267], [89.01998901, 22.04972267], [89.02027893, 22.05000114], [89.02054596, 22.05000114], [89.02083588, 22.05027962], [89.02137756, 22.05027962], [89.02169037, 22.05034065], [89.02211761, 22.05049324], [89.02256012, 22.0506115], [89.02295685, 22.05080032], [89.02337646, 22.05096817], [89.0238266, 22.05115318], [89.02431488, 22.05133247], [89.02487946, 22.05146217], [89.0255127, 22.05169487], [89.02620697, 22.05192375], [89.02667236, 22.05179024], [89.02710724, 22.05162239], [89.02755737, 22.05143166], [89.02811432, 22.05138588], [89.02873993, 22.0513401], [89.02942657, 22.05120277], [89.03013611, 22.05130196], [89.03087616, 22.05116081], [89.03161621, 22.05114746], [89.03231812, 22.05113029], [89.03296661, 22.05111122], [89.03356934, 22.05107307], [89.03408813, 22.05088234], [89.03463745, 22.05079269], [89.03517914, 22.05060005], [89.03579712, 22.05051041], [89.03646088, 22.05032158], [89.03715515, 22.05023575], [89.03782654, 22.05000114], [89.03849792, 22.04972839], [89.03914642, 22.04948997], [89.03981781, 22.04937744], [89.04035187, 22.04916191], [89.04080963, 22.04887199], [89.04120636, 22.04850388], [89.04157257, 22.04803658], [89.04192352, 22.04749107], [89.0422287, 22.04687309], [89.04251862, 22.04628181], [89.04283142, 22.04577446], [89.04309845, 22.04530144], [89.04330444, 22.0448513], [89.04343414, 22.04435539], [89.0435791, 22.04385185], [89.04364777, 22.04330826], [89.04382324, 22.04282951], [89.04396057, 22.04233932], [89.04415894, 22.04195976], [89.04441833, 22.04163361], [89.04457855, 22.04125786], [89.04473877, 22.04086113], [89.04492188, 22.04048157], [89.04507446, 22.04006195], [89.04528809, 22.03965187], [89.04555511, 22.0392437], [89.04582977, 22.03881264], [89.04582977, 22.03861046], [89.04611206, 22.03833008], [89.04611206, 22.03805542], [89.04666901, 22.03750038], [89.04666901, 22.03722191], [89.04777527, 22.03611183], [89.04777527, 22.03583336], [89.04805756, 22.03555107], [89.04805756, 22.03472137], [89.05055237, 22.03222656], [89.05055237, 22.03194427], [89.0513916, 22.03111076], [89.0513916, 22.03083229], [89.06416321, 22.01805305], [89.06416321, 22.01777077], [89.0661087, 22.0158329], [89.0661087, 22.01555824], [89.06803894, 22.01361275], [89.06803894, 22.01332855], [89.06833649, 22.0130558], [89.06835175, 22.01277924], [89.06861115, 22.01250267], [89.06861115, 22.01166916], [89.06944275, 22.01083183], [89.06944275, 22.01055527], [89.06990051, 22.01025391], [89.07028961, 22.00984001], [89.07065582, 22.00943184], [89.07099915, 22.00901985], [89.07131958, 22.00867271], [89.07156372, 22.00832176], [89.07176208, 22.00796318], [89.07193756, 22.00759315], [89.07209015, 22.0072403], [89.072258, 22.0069294], [89.07247162, 22.00666237], [89.07260132, 22.00630379], [89.07277679, 22.00591469], [89.07296753, 22.00547981], [89.07309723, 22.00498009], [89.07332611, 22.00455284], [89.07357788, 22.00415993], [89.07368469, 22.0037365], [89.07384491, 22.00340843], [89.07389069, 22.00306129], [89.07395935, 22.00273514], [89.0741272, 22.0024395], [89.07417297, 22.00206184], [89.07417297, 22.00164223], [89.07424164, 22.00120735], [89.07454681, 22.00090027], [89.07444763, 22.00028038], [89.07472229, 22.00000191], [89.07492828, 21.99940491], [89.07509613, 21.99913216], [89.07527161, 21.99880028], [89.07541656, 21.99847221], [89.07553101, 21.99814987], [89.07554626, 21.99778175], [89.07555389, 21.99749756], [89.07556152, 21.99735832], [89.07563019, 21.99689293], [89.07579803, 21.99640083], [89.07583618, 21.99585152], [89.0759201, 21.99537086], [89.07608032, 21.9949894], [89.07615662, 21.99463844], [89.0763092, 21.99437141], [89.07637787, 21.99406242], [89.07641602, 21.99371147], [89.07658386, 21.9933815], [89.07666016, 21.99294472], [89.07673645, 21.99245262], [89.07691956, 21.99196053], [89.07705688, 21.99142838], [89.07723236, 21.99090004], [89.07744598, 21.99039268], [89.07751465, 21.98986816], [89.07740784, 21.98941994], [89.07744598, 21.98886299], [89.07772827, 21.98830223], [89.07772827, 21.98762321], [89.07800293, 21.98693275], [89.07801819, 21.98641777], [89.07776642, 21.98592949], [89.07772827, 21.98542023], [89.07777405, 21.9849205], [89.07776642, 21.9843502], [89.07793427, 21.9839077], [89.07787323, 21.98341942], [89.07791901, 21.98269081], [89.07778931, 21.98205185], [89.07772827, 21.98149109], [89.07758331, 21.9810009], [89.07746887, 21.98048973], [89.07723999, 21.98002052], [89.07695007, 21.9795475], [89.07666779, 21.97900963], [89.07639313, 21.97841072], [89.07614899, 21.97776985], [89.07604218, 21.97707558], [89.07582855, 21.97646141], [89.07556152, 21.97591209], [89.07530975, 21.97538948], [89.07512665, 21.97486115], [89.07492828, 21.9743824], [89.07470703, 21.9738903], [89.07442474, 21.97343445], [89.07410431, 21.97296906], [89.07388306, 21.9724102], [89.07361603, 21.97186089], [89.07341766, 21.97132874], [89.07329559, 21.97077751], [89.07309723, 21.9702816], [89.07293701, 21.96941376], [89.07235718, 21.96927071], [89.07181549, 21.97034836], [89.07156372, 21.97128487], [89.07131195, 21.9718914], [89.07113647, 21.9724865], [89.07099152, 21.97301483], [89.07092285, 21.97353172], [89.07086945, 21.97406197], [89.07080841, 21.97462273], [89.07077026, 21.97522354], [89.07068634, 21.97585678], [89.07067108, 21.97652626], [89.07073975, 21.97720337], [89.0708313, 21.97784233], [89.07086182, 21.97850227], [89.07087708, 21.97915077], [89.07092285, 21.97980309], [89.07093048, 21.98045921], [89.07090759, 21.98113441], [89.07087708, 21.98181915], [89.07090759, 21.98251152], [89.07092285, 21.98317146], [89.07080841, 21.98378372], [89.07058716, 21.98429871], [89.07042694, 21.98437309], [89.07006073, 21.98473167], [89.06944275, 21.98473167], [89.06932068, 21.98437309], [89.06974792, 21.98402214], [89.07000732, 21.98305511], [89.07012177, 21.98262215], [89.07015228, 21.98249817], [89.0700531, 21.98184013], [89.07003784, 21.98125076], [89.07002258, 21.98067474], [89.06978607, 21.980093], [89.06976318, 21.97953224], [89.06970215, 21.97897148], [89.06970215, 21.9783802], [89.06969452, 21.97780991], [89.06965637, 21.9772625], [89.06960297, 21.97675133], [89.06958008, 21.9761734], [89.06958771, 21.97552299], [89.06965637, 21.97487068], [89.06980896, 21.97422218], [89.06994629, 21.97356224], [89.07003021, 21.97298241], [89.07006073, 21.97243309], [89.07013702, 21.97192955], [89.07026672, 21.97144127], [89.0704422, 21.97101021], [89.07063293, 21.97062111], [89.07080078, 21.97025108], [89.07095337, 21.96983147], [89.07115173, 21.96936989], [89.07144165, 21.96887016], [89.07183838, 21.96835136], [89.07214355, 21.96671486], [89.07193756, 21.96613503], [89.07174683, 21.96555328], [89.07190704, 21.9649353], [89.07187653, 21.96449089], [89.0715332, 21.96415138], [89.07121277, 21.9638176], [89.07125854, 21.9628315], [89.07111359, 21.96219635], [89.07116699, 21.96170807], [89.07120514, 21.9612999], [89.07113647, 21.96087074], [89.07105255, 21.96049118], [89.07086945, 21.96021271], [89.0708313, 21.95984077], [89.0708313, 21.9594326], [89.0708313, 21.95897293], [89.0708313, 21.95845222], [89.0708313, 21.95786476], [89.07069397, 21.95736122], [89.07054901, 21.95672035], [89.07047272, 21.95617104], [89.07035828, 21.95561028], [89.07028961, 21.95501709], [89.07026672, 21.95437431], [89.06996155, 21.95390511], [89.06971741, 21.95334625], [89.06952667, 21.95277977], [89.06964111, 21.95219231], [89.0694809, 21.95165825], [89.06939697, 21.95112038], [89.06922913, 21.95066261], [89.06916046, 21.95016289], [89.0690918, 21.94967842], [89.06904602, 21.94955826], [89.06892395, 21.94923782], [89.0688858, 21.94877052], [89.0688858, 21.9482708], [89.0688324, 21.94773483], [89.06859589, 21.94720268], [89.068367, 21.94663048], [89.06819916, 21.94603157], [89.06794739, 21.9455204], [89.06772614, 21.94502449], [89.06748199, 21.94453621], [89.0672226, 21.94405365], [89.06699371, 21.9435482], [89.06684875, 21.94299126], [89.06667328, 21.94246292], [89.06651306, 21.94196129], [89.06632996, 21.94149017], [89.06609344, 21.94108391], [89.06586456, 21.9406395], [89.06575012, 21.94009209], [89.06552887, 21.93954277], [89.06524658, 21.93902016], [89.06495667, 21.93855095], [89.06474304, 21.93811035], [89.06461334, 21.93767929], [89.06445313, 21.93725014], [89.06430054, 21.93678856], [89.0641098, 21.93626213], [89.06384277, 21.93572044], [89.06358337, 21.93509102], [89.06328583, 21.93451118], [89.06286621, 21.93411064], [89.06257629, 21.93383789], [89.06246948, 21.9337368], [89.0620575, 21.93342018], [89.06169128, 21.93309784], [89.06128693, 21.93283844], [89.06080627, 21.93268013], [89.06066895, 21.9325695], [89.06047058, 21.93240547], [89.06015015, 21.93212318], [89.05976105, 21.9319706], [89.05932617, 21.93193817], [89.05887604, 21.93194008], [89.05870056, 21.93194008], [89.0584259, 21.93193817], [89.05796814, 21.93195152], [89.05747223, 21.93195152], [89.05692291, 21.93192101], [89.05631256, 21.93177223], [89.05562592, 21.93168259], [89.05490112, 21.93165016], [89.05420685, 21.93155289], [89.05361176, 21.93137169], [89.05316162, 21.93111229], [89.05278015, 21.93084145], [89.05243683, 21.93055153], [89.05233765, 21.93045998], [89.05213928, 21.93028069], [89.05184937, 21.93007088], [89.05152893, 21.93010139], [89.05137634, 21.93026161], [89.05101776, 21.93064117], [89.05043793, 21.93098068], [89.04998779, 21.93139076], [89.04990387, 21.93148232], [89.04960632, 21.93180275], [89.04930115, 21.93219185], [89.04895782, 21.93253136], [89.04858398, 21.93281937], [89.04814148, 21.93304825], [89.04763031, 21.93322945], [89.04699707, 21.93326187], [89.0463562, 21.93317223], [89.04570007, 21.93310356], [89.04501343, 21.93307686], [89.04409027, 21.93268394], [89.04332733, 21.93290138], [89.04290009, 21.93342209], [89.04264069, 21.93382454], [89.04216766, 21.93404388], [89.04206085, 21.934412], [89.04223633, 21.93510246], [89.04216003, 21.93582726], [89.04221344, 21.93652725], [89.04223633, 21.93720245], [89.04225922, 21.93784904], [89.04226685, 21.93845558], [89.04226685, 21.93901443], [89.04231262, 21.93951988], [89.04227448, 21.94001198], [89.04225922, 21.94050407], [89.04226685, 21.94101143], [89.04214478, 21.9414959], [89.04199982, 21.94198036], [89.04189301, 21.9425106], [89.04178619, 21.94304085], [89.04177856, 21.94359589], [89.04187012, 21.94415092], [89.04191589, 21.94472313], [89.04193878, 21.94527626], [89.04194641, 21.94582939], [89.04194641, 21.94638824], [89.04191589, 21.94693947], [89.04187775, 21.94750023], [89.04165649, 21.94917107], [89.04185486, 21.94986534], [89.04213715, 21.95008278], [89.04193878, 21.95049858], [89.04138947, 21.9506321], [89.04103851, 21.95104408], [89.04084015, 21.95091057], [89.04057312, 21.95042992], [89.0404129, 21.95005608], [89.04062653, 21.94852257], [89.04064178, 21.94796753], [89.04057312, 21.94728088], [89.04070282, 21.9467907], [89.04086304, 21.94594193], [89.04080963, 21.94523811], [89.04080963, 21.94477272], [89.04078674, 21.94434166], [89.04074097, 21.94384766], [89.04071045, 21.94335175], [89.04082489, 21.94314575], [89.040802, 21.9425602], [89.04087067, 21.94202232], [89.04090881, 21.94141388], [89.04096985, 21.94083977], [89.04096222, 21.94045258], [89.04092407, 21.94002724], [89.04093933, 21.93962288], [89.04096222, 21.93918037], [89.04102325, 21.93869591], [89.04103088, 21.93818855], [89.04099274, 21.93771172], [89.04099274, 21.9372921], [89.04115295, 21.93640518], [89.04120636, 21.93588066], [89.04116058, 21.93535042], [89.04114532, 21.93486023], [89.04116821, 21.93440437], [89.04117584, 21.93394661], [89.04122162, 21.93350029], [89.04134369, 21.93307495], [89.04146576, 21.93263054], [89.04170227, 21.93224144], [89.04197693, 21.93193245], [89.04234314, 21.93173409], [89.04273224, 21.93166542], [89.0431366, 21.93165016], [89.04355621, 21.93166161], [89.04397583, 21.93169212], [89.04440308, 21.93177414], [89.04485321, 21.93189049], [89.04534149, 21.93195152], [89.04585266, 21.9319706], [89.04637146, 21.9319725], [89.04688263, 21.93195534], [89.04738617, 21.93189049], [89.04785156, 21.9317112], [89.04828644, 21.93147278], [89.0486908, 21.93110085], [89.0488205, 21.93095589], [89.04911041, 21.93061256], [89.04951477, 21.93003654], [89.04946136, 21.92984962], [89.04942322, 21.92970848], [89.04914093, 21.92944145], [89.04877472, 21.92920685], [89.04833221, 21.92905045], [89.04785156, 21.9289093], [89.0472641, 21.92884827], [89.04691315, 21.92873764], [89.04664612, 21.92865372], [89.04593658, 21.92860985], [89.0451889, 21.92860985], [89.04442596, 21.92858315], [89.04367065, 21.92867088], [89.04293823, 21.92876244], [89.04226685, 21.92875099], [89.04162598, 21.92847824], [89.04116058, 21.92825127], [89.04051971, 21.92823982], [89.04001617, 21.92830276], [89.03959656, 21.92826271], [89.03925323, 21.92812157], [89.03890228, 21.92805862], [89.03848267, 21.9280529], [89.03804016, 21.92801666], [89.03756714, 21.92783165], [89.03704071, 21.92778206], [89.03646088, 21.9277401], [89.03592682, 21.92754364], [89.03539276, 21.92738533], [89.03494263, 21.92707253], [89.03444672, 21.92684364], [89.03397369, 21.92666054], [89.03354645, 21.9264698], [89.03311157, 21.92635155], [89.03269958, 21.92616272], [89.03221893, 21.92612267], [89.03173828, 21.926157], [89.03122711, 21.92625999], [89.03079224, 21.92630577], [89.03032684, 21.9264431], [89.03007507, 21.92689705], [89.02967834, 21.92736626], [89.02980042, 21.92796135], [89.02960205, 21.9281826], [89.02903748, 21.92811012], [89.0284729, 21.92826271], [89.02826691, 21.92844391], [89.02793884, 21.92874336], [89.0275116, 21.92924309], [89.02722931, 21.92942047], [89.02680969, 21.92963982], [89.02648163, 21.92990112], [89.02616119, 21.93026161], [89.02585602, 21.93048286], [89.02552795, 21.93062973], [89.02523804, 21.93110466], [89.0252533, 21.93157005], [89.02481079, 21.93172836]]], [[[88.86847687, 21.9220295], [88.86803436, 21.9220047], [88.8614502, 21.91958427], [88.85658264, 21.91905975], [88.84970093, 21.92039108], [88.84111023, 21.92468834], [88.83882141, 21.92738533], [88.83452606, 21.93276024], [88.83289337, 21.93484497], [88.8299408, 21.93760109], [88.82483673, 21.93984985], [88.82084656, 21.94049644], [88.81648254, 21.94074059], [88.81639099, 21.94111061], [88.8161087, 21.94083023], [88.81500244, 21.94083595], [88.81472015, 21.94055748], [88.81416321, 21.94055939], [88.81388855, 21.94028091], [88.8133316, 21.94028091], [88.81305695, 21.94000053], [88.81222534, 21.94000053], [88.81194305, 21.93972206], [88.8116684, 21.93972206], [88.81138611, 21.93944359], [88.80999756, 21.93944359], [88.80979156, 21.93923569], [88.80944824, 21.93888855], [88.80860901, 21.93889046], [88.80832672, 21.93917084], [88.80805206, 21.93916512], [88.80786133, 21.93935966], [88.8077774, 21.93944359], [88.80750275, 21.93943024], [88.8069458, 21.94000053], [88.80639648, 21.94000053], [88.80610657, 21.94028091], [88.80526733, 21.94028091], [88.80500031, 21.94055939], [88.80444336, 21.94055748], [88.8041687, 21.94083595], [88.80388641, 21.94083023], [88.80361176, 21.94111061], [88.8033371, 21.94111061], [88.80304718, 21.94139099], [88.80249786, 21.94139099], [88.80222321, 21.94166946], [88.80194092, 21.94166565], [88.80166626, 21.94194412], [88.80083466, 21.94194412], [88.80055237, 21.9422226], [88.79750061, 21.9422226], [88.79722595, 21.94194412], [88.79499817, 21.94194412], [88.79472351, 21.94166565], [88.79332733, 21.94166946], [88.79305267, 21.94139099], [88.79139709, 21.94139099], [88.79110718, 21.94166946], [88.79055786, 21.94166946], [88.78943634, 21.94277954], [88.78944397, 21.94305611], [88.78916931, 21.94333267], [88.78916931, 21.94611168], [88.78944397, 21.94638824], [88.78943634, 21.94722176], [88.78971863, 21.94750023], [88.78971863, 21.94933128], [88.78971863, 21.94944382], [88.79000092, 21.94972229], [88.79000092, 21.95194435], [88.78971863, 21.95222092], [88.78971863, 21.95249939], [88.78916931, 21.95305443], [88.78916931, 21.95333099], [88.78833008, 21.95417023], [88.78806305, 21.95417023], [88.78722382, 21.95499992], [88.78583527, 21.95499992], [88.78555298, 21.95472145], [88.78527832, 21.95472145], [88.78500366, 21.95444679], [88.78472137, 21.95444679], [88.78416443, 21.95388794], [88.78388977, 21.95388985], [88.78277588, 21.95277977], [88.78250122, 21.95277977], [88.78111267, 21.95139122], [88.78111267, 21.95111084], [88.78056335, 21.95055962], [88.78056335, 21.95028114], [88.78028107, 21.95000076], [88.78028107, 21.94944191], [88.77999878, 21.94916725], [88.77999878, 21.94889069], [88.77985382, 21.94874573], [88.77944183, 21.94833374], [88.77944183, 21.94805527], [88.77916718, 21.94778061], [88.77916718, 21.94695282], [88.77889252, 21.94667053], [88.77889252, 21.94639015], [88.77805328, 21.94556236], [88.77805328, 21.94528008], [88.77749634, 21.94472122], [88.77749634, 21.94444466], [88.77639008, 21.94333267], [88.77555847, 21.94333076], [88.77527618, 21.94361115], [88.77500153, 21.94361115], [88.77471924, 21.94388962], [88.77443695, 21.94388962], [88.77416992, 21.94416809], [88.77388763, 21.94416618], [88.77361298, 21.94444466], [88.77333069, 21.94444466], [88.77305603, 21.94472313], [88.77278137, 21.94472122], [88.7722168, 21.94528008], [88.77194214, 21.94528008], [88.77166748, 21.94556236], [88.77111053, 21.94555473], [88.77055359, 21.94611168], [88.76999664, 21.94611168], [88.76944733, 21.94667053], [88.76917267, 21.94667053], [88.76832581, 21.94750023], [88.76805878, 21.94750023], [88.76750183, 21.9480629], [88.76722717, 21.9480629], [88.76638794, 21.94889069], [88.76611328, 21.94888878], [88.76578522, 21.94921494], [88.76305389, 21.95194435], [88.76305389, 21.95222282], [88.76277924, 21.95222092], [88.76222229, 21.95277977], [88.76167297, 21.95277977], [88.76166534, 21.95305443], [88.76139069, 21.9533329], [88.7611084, 21.9533329], [88.76083374, 21.95361137], [88.75971985, 21.95360947], [88.75945282, 21.95388985], [88.75911713, 21.95388794], [88.75805664, 21.95388985], [88.75776672, 21.95417023], [88.75749969, 21.95416451], [88.75694275, 21.95472145], [88.75666809, 21.95471954], [88.7563858, 21.95499992], [88.75611115, 21.95499992], [88.75583649, 21.9552803], [88.75528717, 21.9552803], [88.75499725, 21.95556068], [88.75444794, 21.95555687], [88.75416565, 21.95583344], [88.75333405, 21.95583344], [88.75305176, 21.95611191], [88.75250244, 21.95611191], [88.75166321, 21.9569397], [88.75166321, 21.95889091], [88.7519455, 21.95916748], [88.7519455, 21.95944405], [88.75222778, 21.95972061], [88.75222778, 21.95999908], [88.75250244, 21.96027946], [88.75250244, 21.96055603], [88.7527771, 21.9608326], [88.7527771, 21.96138954], [88.75305176, 21.96166611], [88.75305176, 21.96194267], [88.7536087, 21.96249962], [88.7536087, 21.96333122], [88.75389099, 21.96362114], [88.75389099, 21.96444321], [88.75417328, 21.96471977], [88.75416565, 21.96555328], [88.75444794, 21.96582985], [88.75444794, 21.96611023], [88.7547226, 21.9663887], [88.7547226, 21.96693993], [88.75554657, 21.96778107], [88.75554657, 21.96861076], [88.75583649, 21.96861076], [88.75583649, 21.96889114], [88.75611115, 21.96916771], [88.75611115, 21.96946144], [88.75611115, 21.97000122], [88.7563858, 21.97027969], [88.7563858, 21.97110748], [88.75666809, 21.97138977], [88.75666809, 21.97222137], [88.75694275, 21.97250175], [88.75694275, 21.97444534], [88.75666809, 21.97472191], [88.75666809, 21.97527695], [88.75611115, 21.97583008], [88.75611115, 21.97611046], [88.75583649, 21.97639084], [88.75583649, 21.9766674], [88.7555542, 21.97694206], [88.7555542, 21.97722244], [88.75333405, 21.9794445], [88.75305176, 21.97944069], [88.75222778, 21.98027992], [88.75195313, 21.98027992], [88.75166321, 21.98056221], [88.75138855, 21.9805584], [88.75111389, 21.98083305], [88.7508316, 21.98083305], [88.74972534, 21.98194695], [88.74973297, 21.9822216], [88.75, 21.98249817], [88.75, 21.98305511], [88.7508316, 21.98389053], [88.75138855, 21.98444557], [88.75166321, 21.98444176], [88.75180054, 21.9845829], [88.75195313, 21.98473167], [88.75219727, 21.98473167], [88.75250244, 21.98500252], [88.75305176, 21.98500252], [88.75332642, 21.98527908], [88.75723267, 21.98527908], [88.75776672, 21.98473167], [88.76167297, 21.98473167], [88.76194763, 21.98444176], [88.76444244, 21.98444176], [88.7647171, 21.98473167], [88.76499939, 21.98473167], [88.76526642, 21.98500252], [88.76555634, 21.98500252], [88.76583099, 21.98527908], [88.76638794, 21.98527908], [88.76667023, 21.98555946], [88.76694489, 21.98555565], [88.76721954, 21.98583412], [88.76750183, 21.9858284], [88.76777649, 21.98611259], [88.76805878, 21.98611259], [88.77054596, 21.98861122], [88.77083588, 21.98861122], [88.77166748, 21.98944664], [88.77194214, 21.98944473], [88.77205658, 21.98955536], [88.77222443, 21.9897213], [88.77444458, 21.9897213], [88.77527618, 21.98888969], [88.77555847, 21.98888969], [88.77694702, 21.98750114], [88.77722168, 21.98750114], [88.77971649, 21.98500252], [88.77999878, 21.98500252], [88.78051758, 21.9844799], [88.78083038, 21.9841671], [88.78111267, 21.98417091], [88.78138733, 21.98389244], [88.78166962, 21.98389244], [88.78238678, 21.98326302], [88.78289795, 21.98286247], [88.78325653, 21.98244858], [88.7833252, 21.98164749], [88.78209686, 21.98056984], [88.78116608, 21.97929382], [88.78055573, 21.97861099], [88.78010559, 21.97801971], [88.77999115, 21.97760201], [88.7800293, 21.97627068], [88.78031921, 21.97499275], [88.78103638, 21.97364235], [88.78196716, 21.97270393], [88.78382874, 21.97203064], [88.78526306, 21.97149086], [88.78762054, 21.9709568], [88.78990936, 21.97062111], [88.79105377, 21.97062111], [88.79105377, 21.9707222], [88.79227448, 21.97052383], [88.79251099, 21.97054291], [88.79449463, 21.9707222], [88.79628754, 21.9707222], [88.79792786, 21.97038841], [88.79921722, 21.97025108], [88.80001068, 21.97039223], [88.80029297, 21.97045326], [88.80007935, 21.97112083], [88.79950714, 21.97153091], [88.79828644, 21.97166252], [88.7932663, 21.97166252], [88.79133606, 21.97183037], [88.78971863, 21.97183037], [88.78912354, 21.97183037], [88.78640747, 21.97223473], [88.78525543, 21.9727726], [88.78482819, 21.97324181], [88.78453827, 21.97338295], [88.78411102, 21.97310638], [88.78347015, 21.97344017], [88.78224945, 21.97425461], [88.78174591, 21.97486115], [88.78189087, 21.9750576], [88.78189087, 21.97538948], [88.78145599, 21.97620201], [88.78174591, 21.9765377], [88.78174591, 21.97828484], [88.78289795, 21.97902489], [88.78411865, 21.98003006], [88.78468323, 21.98043823], [88.78489685, 21.98178482], [88.78525543, 21.98265648], [88.78546906, 21.98265457], [88.7858963, 21.98265266], [88.78675842, 21.98278809], [88.787117, 21.9831295], [88.78804779, 21.98353004], [88.78876495, 21.98373032], [88.78926849, 21.98413467], [88.78990936, 21.98434258], [88.78990936, 21.98454285], [88.7898407, 21.98527718], [88.78940582, 21.98568153], [88.78884125, 21.9857502], [88.78826904, 21.98535156], [88.78762054, 21.98508263], [88.78704834, 21.98454285], [88.78626251, 21.9842701], [88.78533173, 21.98426819], [88.78468323, 21.9843998], [88.78360748, 21.98527908], [88.78333282, 21.98527908], [88.78250122, 21.98611259], [88.7822113, 21.98611259], [88.78193665, 21.98638916], [88.78166962, 21.98638916], [88.77777863, 21.99028206], [88.77722168, 21.99027824], [88.77666473, 21.99083328], [88.77527618, 21.99083328], [88.77500153, 21.99111557], [88.77443695, 21.99110985], [88.77416992, 21.99139214], [88.7722168, 21.99139214], [88.77194214, 21.99110985], [88.77111053, 21.99111557], [88.77083588, 21.99083328], [88.77055359, 21.99083328], [88.77027893, 21.99055672], [88.76972198, 21.99055672], [88.76947784, 21.99030876], [88.76917267, 21.99028206], [88.76860809, 21.9897213], [88.76833344, 21.9897213], [88.76638794, 21.98777962], [88.76592255, 21.987463], [88.76558685, 21.98722267], [88.76544952, 21.98712349], [88.76500702, 21.98685646], [88.76499939, 21.98666954], [88.76444244, 21.98666954], [88.76416779, 21.98638916], [88.76333618, 21.98638916], [88.76304626, 21.98611259], [88.76027679, 21.98611259], [88.76000214, 21.98638916], [88.75971985, 21.98638916], [88.75945282, 21.98666954], [88.75888824, 21.98666573], [88.75861359, 21.9869442], [88.75722504, 21.9869442], [88.75694275, 21.98722267], [88.75554657, 21.98722267], [88.75528717, 21.98750114], [88.75447845, 21.98750114], [88.75417328, 21.98750114], [88.7536087, 21.98805809], [88.7536087, 21.98833275], [88.75389099, 21.98861122], [88.75389099, 21.98888969], [88.75417328, 21.98917389], [88.75444794, 21.98917389], [88.75495148, 21.98971176], [88.75499725, 21.98999977], [88.75776672, 21.99278069], [88.75777435, 21.99305534], [88.7583313, 21.99360085], [88.7583313, 21.99389076], [88.75888824, 21.99444389], [88.75888824, 21.99472237], [88.75971985, 21.99555779], [88.75971985, 21.99583244], [88.76000214, 21.99611092], [88.76000214, 21.99666786], [88.76027679, 21.99694252], [88.76027679, 21.99749756], [88.76055908, 21.99777985], [88.76055908, 21.99860764], [88.76082611, 21.99889183], [88.76082611, 22.00000191], [88.76110077, 22.00028038], [88.76112366, 22.00066948], [88.76113129, 22.00138283], [88.76111603, 22.00214958], [88.76110077, 22.00289917], [88.7611084, 22.00364494], [88.76110077, 22.00436974], [88.76113129, 22.00509071], [88.7612381, 22.00575829], [88.76148224, 22.0063343], [88.76187897, 22.00682831], [88.76243591, 22.00721169], [88.76303101, 22.00752449], [88.76360321, 22.00779152], [88.76413727, 22.00803375], [88.76461792, 22.00824547], [88.76504517, 22.00848198], [88.7654953, 22.0086956], [88.76596069, 22.0089016], [88.76646423, 22.00909805], [88.76699066, 22.00927162], [88.76745605, 22.00947189], [88.76793671, 22.00966072], [88.76844788, 22.00980186], [88.76895905, 22.00998116], [88.76950073, 22.01016045], [88.76998138, 22.01041985], [88.77047729, 22.01069069], [88.7710495, 22.01098061], [88.77166748, 22.01139069], [88.77249908, 22.01221848], [88.7722168, 22.01250267], [88.77201843, 22.01247978], [88.77127075, 22.01221848], [88.77065277, 22.01196289], [88.77012634, 22.01176643], [88.76966095, 22.01157951], [88.76924133, 22.01138496], [88.76880646, 22.01120377], [88.76837158, 22.01104164], [88.76795959, 22.01083183], [88.76752472, 22.01062202], [88.76707458, 22.01045799], [88.7666626, 22.01027107], [88.76625061, 22.01009178], [88.76577759, 22.00992012], [88.76526642, 22.00969315], [88.76468658, 22.00942612], [88.7640686, 22.00914383], [88.76345062, 22.00884819], [88.76287079, 22.00853157], [88.76235962, 22.0081749], [88.76187134, 22.00775719], [88.7616272, 22.007761], [88.76139069, 22.00796127], [88.76127625, 22.00811958], [88.76114655, 22.00830269], [88.76092529, 22.00874519], [88.76078796, 22.00932312], [88.76056671, 22.0098896], [88.76040649, 22.01048088], [88.7604599, 22.01107216], [88.76062775, 22.01161766], [88.76084137, 22.01209259], [88.76107788, 22.01254082], [88.76122284, 22.01303101], [88.76135254, 22.01352119], [88.76140594, 22.01403999], [88.7614975, 22.01452065], [88.76172638, 22.01490784], [88.76187134, 22.01503563], [88.76204681, 22.01519585], [88.76246643, 22.01537132], [88.76290131, 22.01556969], [88.76337433, 22.01578522], [88.76397705, 22.0158329], [88.76462555, 22.01583672], [88.76529694, 22.0158329], [88.76597595, 22.01584053], [88.7666626, 22.01588249], [88.76732635, 22.01601601], [88.76795959, 22.01584053], [88.76856995, 22.01563072], [88.76915741, 22.01551247], [88.77091217, 22.01493263], [88.77313995, 22.01493263], [88.77471924, 22.01486778], [88.77600861, 22.0148716], [88.77694702, 22.0150013], [88.78028107, 22.01611137], [88.78083038, 22.01638794], [88.78086853, 22.01720238], [88.78101349, 22.01760674], [88.78173065, 22.01814079], [88.78208923, 22.01820946], [88.78273773, 22.01861], [88.78316498, 22.01894569], [88.7833786, 22.01908112], [88.78381348, 22.01928139], [88.78438568, 22.01948166], [88.78488922, 22.01968193], [88.78527069, 22.02000237], [88.78527069, 22.02028084], [88.78639221, 22.0208416], [88.78666687, 22.02111244], [88.78722382, 22.0213871], [88.78806305, 22.02222252], [88.78806305, 22.02250099], [88.78916931, 22.02277946], [88.79000092, 22.02361107], [88.79111481, 22.02388954], [88.79277802, 22.02444458], [88.79499817, 22.02555275], [88.79611206, 22.02666664], [88.7977829, 22.02722168], [88.79833221, 22.02750015], [88.79944611, 22.02861214], [88.80055237, 22.02889061], [88.80055237, 22.02916908], [88.80110931, 22.02944374], [88.8013916, 22.02972221], [88.80222321, 22.02972221], [88.80305481, 22.02944374], [88.80361176, 22.02916908], [88.80388641, 22.02889061], [88.80388641, 22.02861214], [88.8041687, 22.02833176], [88.8041687, 22.02805519], [88.80444336, 22.02778053], [88.80444336, 22.02750015], [88.80473328, 22.02722168], [88.80472565, 22.02694511], [88.80500031, 22.02666664], [88.80500031, 22.02639008], [88.80526733, 22.0261116], [88.80527496, 22.02583313], [88.80555725, 22.02555656], [88.80555725, 22.02444649], [88.8061142, 22.02416992], [88.8077774, 22.02250099], [88.8088913, 22.02194023], [88.80916595, 22.02166557], [88.81027985, 22.02111244], [88.81083679, 22.02056313], [88.81083679, 22.02028084], [88.8116684, 22.02000237], [88.81276703, 22.0194416], [88.81305695, 22.01916695], [88.8133316, 22.01916695], [88.8152771, 22.01944351], [88.81555176, 22.01972008], [88.81833649, 22.02028084], [88.81944275, 22.02056313], [88.82026672, 22.0208416], [88.82195282, 22.02166939], [88.82611084, 22.02166939], [88.82639313, 22.02139091], [88.82639313, 22.02111244], [88.83027649, 22.0205555], [88.83194733, 22.02028084], [88.83304596, 22.02000237], [88.8347168, 22.0194416], [88.83583069, 22.01916695], [88.83750153, 22.01861], [88.84333038, 22.0177784], [88.84333038, 22.01749992], [88.84833527, 22.01749992], [88.8483429, 22.01777077], [88.85250092, 22.01805305], [88.85527802, 22.01861], [88.85610962, 22.01888847], [88.85778046, 22.01972008], [88.85861206, 22.02000237], [88.86083221, 22.02111244], [88.86332703, 22.02361107], [88.86416626, 22.02388954], [88.86528015, 22.02444649], [88.86638641, 22.02444649], [88.86694336, 22.02416992], [88.86833191, 22.02277946], [88.86833191, 22.02222252], [88.8686142, 22.02194405], [88.8686142, 22.02139091], [88.86915588, 22.0208416], [88.86915588, 22.02056313], [88.86972046, 22.02000237], [88.86972046, 22.01972008], [88.8702774, 22.01916695], [88.8702774, 22.01889229], [88.87055206, 22.01861], [88.87055206, 22.01666641], [88.8713913, 22.01527977], [88.87248993, 22.01471138], [88.87277985, 22.01444435], [88.87333679, 22.01416588], [88.87526703, 22.01221848], [88.87611389, 22.01194382], [88.87889099, 22.01166725], [88.8797226, 22.01139259], [88.8861084, 22.0111084], [88.88722229, 22.0111084], [88.88749695, 22.01139259], [88.89250183, 22.01166725], [88.89389038, 22.01194382], [88.89665985, 22.01221848], [88.89694214, 22.01250267], [88.89833069, 22.01277924], [88.89833069, 22.01305962], [88.89933777, 22.01305771], [88.89971924, 22.01305962], [88.90249634, 22.01166916], [88.90361023, 22.01055908], [88.90361023, 22.00917244], [88.90416718, 22.00861168], [88.90416718, 22.00805473], [88.90396881, 22.00785446], [88.90389252, 22.00777626], [88.90416718, 22.0075016], [88.90416718, 22.00722313], [88.90444183, 22.00694656], [88.90444183, 22.00277901], [88.90389252, 22.00250053], [88.90389252, 22.00000191], [88.90354919, 21.99973106], [88.90297699, 21.99435997], [88.90239716, 21.9871006], [88.90374756, 21.98077202], [88.9041214, 21.97902679], [88.90756226, 21.96935081], [88.90783691, 21.96478081], [88.90733337, 21.96159172], [88.90584564, 21.95212936], [88.90584564, 21.9426899], [88.90584564, 21.93706703], [88.90590668, 21.9360714], [88.90627289, 21.93562126], [88.90688324, 21.93404388], [88.90702057, 21.93287086], [88.90727234, 21.9313221], [88.90727234, 21.92953682], [88.90584564, 21.92819595], [88.90402222, 21.92648125], [88.90067291, 21.92480278], [88.89746094, 21.92283821], [88.89624786, 21.92261314], [88.89573669, 21.92237473], [88.89456177, 21.92194366], [88.89011383, 21.92113113], [88.88829803, 21.9207325], [88.88586426, 21.92079544], [88.88240814, 21.92229462], [88.88121033, 21.92281151], [88.8775177, 21.92257309], [88.87290192, 21.92227364], [88.86847687, 21.9220295]]], [[[88.74539185, 21.97973824], [88.7458725, 21.97972107], [88.74640656, 21.97972107], [88.74698639, 21.97969246], [88.74758911, 21.97951126], [88.74825287, 21.97937775], [88.74887085, 21.97916031], [88.74944305, 21.97888947], [88.74973297, 21.97888947], [88.75, 21.97861099], [88.75027466, 21.97861099], [88.75055695, 21.97833252], [88.7508316, 21.97833252], [88.75111389, 21.97805405], [88.75138855, 21.97805977], [88.75195313, 21.97750092], [88.75222015, 21.97750092], [88.75305176, 21.9766674], [88.75332642, 21.97667122], [88.75332642, 21.97639084], [88.75417328, 21.97556114], [88.75417328, 21.97528076], [88.7547226, 21.97472191], [88.7547226, 21.97444534], [88.7545166, 21.97380829], [88.7544632, 21.97323036], [88.75444031, 21.97262955], [88.75440216, 21.97208405], [88.75419617, 21.97158241], [88.75406647, 21.97102547], [88.75388336, 21.97048759], [88.75361633, 21.96998024], [88.75338745, 21.96947861], [88.75325012, 21.96894073], [88.75305176, 21.96844292], [88.75285339, 21.96795273], [88.75273132, 21.96742058], [88.75254059, 21.96696854], [88.75247192, 21.96652985], [88.75231171, 21.9661808], [88.75222778, 21.96584511], [88.75218964, 21.96550941], [88.75203705, 21.96523094], [88.75190735, 21.96487808], [88.75169373, 21.96451759], [88.75154114, 21.96404076], [88.75136566, 21.96352768], [88.75112152, 21.96302032], [88.75093079, 21.96250153], [88.75073242, 21.9620018], [88.75047302, 21.96157455], [88.75028229, 21.96113968], [88.75012207, 21.9606781], [88.74997711, 21.96025085], [88.74978638, 21.95986176], [88.74968719, 21.95943069], [88.74949646, 21.95903015], [88.74945068, 21.95858002], [88.74944305, 21.95811081], [88.74946594, 21.95766068], [88.74964905, 21.95726585], [88.74975586, 21.95680809], [88.74996185, 21.95635033], [88.75004578, 21.95578957], [88.75029755, 21.95528984], [88.75070953, 21.95485115], [88.75119781, 21.95445824], [88.75177765, 21.95416451], [88.75235748, 21.95388412], [88.75292206, 21.95360947], [88.75348663, 21.95334625], [88.75409698, 21.95314026], [88.75476074, 21.95300293], [88.75541687, 21.9528141], [88.7561264, 21.9527359], [88.75681305, 21.95251083], [88.75749969, 21.95228958], [88.75819397, 21.95207977], [88.75886536, 21.9518528], [88.75951385, 21.95160675], [88.76016235, 21.95137215], [88.76076508, 21.9511013], [88.7612915, 21.95077324], [88.76173401, 21.95035744], [88.76222229, 21.95000076], [88.76270294, 21.94964981], [88.76312256, 21.94922066], [88.76354218, 21.94881248], [88.76387787, 21.94835091], [88.76419067, 21.94790077], [88.764534, 21.94752693], [88.76490784, 21.94720078], [88.76528931, 21.94685555], [88.76571655, 21.94651031], [88.76618958, 21.94613075], [88.76673889, 21.94580078], [88.76725006, 21.94540024], [88.76778412, 21.94509697], [88.76832581, 21.9448719], [88.76882935, 21.94466972], [88.76927185, 21.9444294], [88.76966095, 21.94416618], [88.77002716, 21.94388962], [88.77039337, 21.94363022], [88.77076721, 21.94339943], [88.77114105, 21.94318008], [88.7715683, 21.94301033], [88.77197266, 21.94277954], [88.77240753, 21.94259262], [88.77288055, 21.94239807], [88.77336121, 21.94219971], [88.77378845, 21.94198227], [88.77423096, 21.94185829], [88.77462006, 21.94170189], [88.77503967, 21.94164085], [88.77545166, 21.94149971], [88.77584076, 21.94145012], [88.77619934, 21.94162369], [88.77658844, 21.94170189], [88.77690125, 21.94188118], [88.77728271, 21.94201088], [88.77762604, 21.94222832], [88.77799225, 21.94248962], [88.77838135, 21.94273949], [88.77876282, 21.9429512], [88.77906036, 21.94320869], [88.77937317, 21.94343185], [88.77957916, 21.94375038], [88.7797699, 21.94408989], [88.78000641, 21.9444294], [88.78028107, 21.94477844], [88.78052521, 21.94518471], [88.78069305, 21.94568062], [88.78089905, 21.94617844], [88.7811203, 21.94667053], [88.78138733, 21.94713974], [88.78164673, 21.9475956], [88.78186035, 21.94804382], [88.7820816, 21.94844818], [88.78226471, 21.94882584], [88.78250122, 21.94914436], [88.78276825, 21.94943237], [88.78303528, 21.94971657], [88.78324127, 21.95005035], [88.78340912, 21.9504509], [88.78370667, 21.95082283], [88.78409576, 21.95119667], [88.78446198, 21.95165062], [88.78495789, 21.95202065], [88.78543854, 21.95236969], [88.78595734, 21.95261192], [88.78645325, 21.95265007], [88.78690338, 21.95231819], [88.78721619, 21.95178032], [88.78742218, 21.9511795], [88.78730774, 21.9505291], [88.78742218, 21.9500103], [88.78746033, 21.94985962], [88.78746033, 21.9491787], [88.78726196, 21.94852066], [88.78721619, 21.94785118], [88.78716278, 21.94719124], [88.78697968, 21.94659615], [88.78694153, 21.94595909], [88.78694153, 21.94528008], [88.78694153, 21.94457817], [88.78694916, 21.94390106], [88.78701782, 21.9432888], [88.78712463, 21.94303322], [88.78723145, 21.94278908], [88.78749847, 21.94234276], [88.78778839, 21.94189453], [88.78811646, 21.94145966], [88.78852081, 21.94108009], [88.78890228, 21.94071388], [88.78931427, 21.94042778], [88.78975677, 21.94021988], [88.79016876, 21.93999481], [88.79055023, 21.93976784], [88.79103851, 21.93967819], [88.79151917, 21.93949127], [88.79207611, 21.93943024], [88.79268646, 21.93944168], [88.79331207, 21.93944359], [88.79393768, 21.93943024], [88.79456329, 21.93946838], [88.79515839, 21.93959808], [88.79577637, 21.93975067], [88.79637146, 21.93995857], [88.79705811, 21.94000053], [88.79777527, 21.94000244], [88.79849243, 21.94000053], [88.79917908, 21.93997192], [88.79981995, 21.93980026], [88.80046844, 21.93974113], [88.80110931, 21.93971062], [88.80170441, 21.93965149], [88.80220032, 21.9394722], [88.80269623, 21.93936539], [88.8031311, 21.93915939], [88.80355835, 21.93889046], [88.80401611, 21.93858147], [88.80446625, 21.93819046], [88.80493927, 21.9378109], [88.80527496, 21.93735123], [88.80555725, 21.93690109], [88.80578613, 21.93647957], [88.80583191, 21.9360199], [88.80583191, 21.9355793], [88.80580139, 21.93515015], [88.80562592, 21.93475533], [88.80555725, 21.93416977], [88.80555725, 21.93388939], [88.80526733, 21.93362045], [88.80526733, 21.93305969], [88.80473328, 21.93250084], [88.80472565, 21.93222237], [88.80361176, 21.93111038], [88.8033371, 21.93111038], [88.8033371, 21.93082809], [88.80287933, 21.93037224], [88.80222321, 21.92972183], [88.80222321, 21.92944527], [88.80055237, 21.92778015], [88.80055237, 21.92749023], [88.80000305, 21.92694664], [88.80000305, 21.92666435], [88.79944611, 21.92611122], [88.7993927, 21.92592812], [88.79899597, 21.92567253], [88.79857635, 21.92542076], [88.79810333, 21.92521095], [88.79759979, 21.92498207], [88.79712677, 21.92471886], [88.79666138, 21.92444992], [88.79618835, 21.92416954], [88.79572296, 21.92389107], [88.79522705, 21.92361069], [88.79471588, 21.92333221], [88.79416656, 21.92304039], [88.79364014, 21.92266846], [88.79315948, 21.9222126], [88.79270935, 21.9217205], [88.79223633, 21.92130089], [88.79178619, 21.92095375], [88.79133606, 21.92068291], [88.79083252, 21.92052841], [88.79032135, 21.92032051], [88.78971863, 21.92028046], [88.78942108, 21.92028046], [88.78914642, 21.92028046], [88.78879547, 21.92032433], [88.78846741, 21.92049026], [88.78804779, 21.92058945], [88.7876358, 21.92078018], [88.78716278, 21.92090988], [88.78670502, 21.92111969], [88.78636169, 21.92133331], [88.78627014, 21.92139053], [88.78582764, 21.92165947], [88.78534698, 21.92188072], [88.784935, 21.92213821], [88.78468323, 21.92224884], [88.78449249, 21.92233086], [88.78410339, 21.92256165], [88.78372192, 21.92279816], [88.78338623, 21.92307091], [88.78305054, 21.92336082], [88.78269196, 21.92362022], [88.78234863, 21.92389107], [88.78199768, 21.92416954], [88.78162384, 21.92443275], [88.78119659, 21.92466164], [88.78082275, 21.9249897], [88.78040314, 21.9253006], [88.77998352, 21.92561531], [88.77953339, 21.92585754], [88.77908325, 21.92611694], [88.77865601, 21.92638588], [88.77820587, 21.92661095], [88.77771759, 21.92675018], [88.7773056, 21.92697144], [88.77709961, 21.92712021], [88.77693939, 21.92724037], [88.77655792, 21.92750549], [88.77616119, 21.92777252], [88.7756958, 21.92798805], [88.77514648, 21.92811012], [88.77462006, 21.92833519], [88.77406311, 21.92858124], [88.7734375, 21.92877007], [88.77276611, 21.92892265], [88.77216339, 21.92916107], [88.77155304, 21.92939949], [88.77088165, 21.92952728], [88.7702179, 21.92969322], [88.76953125, 21.92974472], [88.76889038, 21.92986488], [88.76828766, 21.92998314], [88.7677002, 21.9300499], [88.76719666, 21.93024063], [88.76669312, 21.93028069], [88.76618958, 21.93028069], [88.76568604, 21.93028069], [88.76519012, 21.93033028], [88.76469421, 21.9305172], [88.76416016, 21.93055534], [88.76357269, 21.93055725], [88.76294708, 21.93058014], [88.76232147, 21.93072128], [88.7616806, 21.93081093], [88.76106262, 21.93074989], [88.76042938, 21.93062973], [88.75984955, 21.93079376], [88.75928497, 21.93083191], [88.7587738, 21.93080521], [88.75830841, 21.93066978], [88.75785065, 21.93058968], [88.75737, 21.93065071], [88.75686646, 21.93072128], [88.75637817, 21.93058968], [88.75582886, 21.93050957], [88.7552948, 21.93032265], [88.75465393, 21.93028069], [88.7539978, 21.93024063], [88.75340271, 21.93000031], [88.75280762, 21.92977905], [88.75221252, 21.92967033], [88.75175476, 21.9294529], [88.75132751, 21.92925835], [88.75089264, 21.92914009], [88.75054169, 21.9289093], [88.75013733, 21.92875099], [88.74973297, 21.92861366], [88.74931335, 21.92847633], [88.74890137, 21.92831039], [88.74854279, 21.92806816], [88.74813843, 21.92785835], [88.7477417, 21.92761993], [88.74728394, 21.92738152], [88.74686432, 21.92698669], [88.74637604, 21.92655945], [88.74584961, 21.92612076], [88.74539185, 21.92564964], [88.74501038, 21.92519188], [88.74471283, 21.92478943], [88.74442291, 21.92446709], [88.744133, 21.92418098], [88.7437973, 21.92389107], [88.74344635, 21.92360115], [88.74310303, 21.92327118], [88.74276733, 21.92295647], [88.74241638, 21.92270279], [88.74205017, 21.92246819], [88.74169922, 21.92224693], [88.74128723, 21.92212105], [88.74091339, 21.9219799], [88.74050903, 21.92201996], [88.74011993, 21.92218971], [88.73969269, 21.92225075], [88.73931122, 21.92243958], [88.73916626, 21.92250061], [88.7388916, 21.9227829], [88.73805237, 21.9227829], [88.73777771, 21.92305946], [88.73750305, 21.92305565], [88.73722076, 21.92333221], [88.73694611, 21.92333031], [88.73638916, 21.92389107], [88.73555756, 21.92389107], [88.7352829, 21.92416954], [88.73472595, 21.92416954], [88.73443604, 21.92444992], [88.73388672, 21.92444229], [88.73361206, 21.92472267], [88.73332977, 21.92472076], [88.73278046, 21.92527771], [88.73245239, 21.92586327], [88.73222351, 21.92624664], [88.73204041, 21.9265728], [88.73194122, 21.92690086], [88.73182678, 21.92720222], [88.73169708, 21.92749023], [88.73159027, 21.92782784], [88.73140717, 21.9281311], [88.73124695, 21.92847061], [88.73110199, 21.92879868], [88.73092651, 21.92908669], [88.73078156, 21.9293499], [88.73059082, 21.92956734], [88.73044586, 21.92982292], [88.7303009, 21.93013], [88.73020172, 21.93047523], [88.73000336, 21.93082809], [88.73000336, 21.93111038], [88.72944641, 21.93166733], [88.72944641, 21.93193817], [88.72888947, 21.93250084], [88.72888947, 21.9327774], [88.72833252, 21.93332863], [88.72833252, 21.93361282], [88.72721863, 21.9347229], [88.72721863, 21.93499947], [88.72472382, 21.9375], [88.72472382, 21.93833351], [88.72360992, 21.93944359], [88.72389221, 21.93972015], [88.72389221, 21.94055748], [88.72360992, 21.94083023], [88.72360992, 21.94139099], [88.72333527, 21.94166565], [88.72305298, 21.94194412], [88.72294617, 21.94212151], [88.72270966, 21.94236755], [88.72239685, 21.94263077], [88.72223663, 21.94297028], [88.72226715, 21.94333839], [88.72245789, 21.94371986], [88.72249603, 21.9441452], [88.72249603, 21.94460106], [88.72254944, 21.94507599], [88.72273254, 21.94551086], [88.72280121, 21.9460392], [88.72293854, 21.94655037], [88.72306061, 21.94704056], [88.72318268, 21.94746017], [88.72331238, 21.94779015], [88.7233429, 21.94809914], [88.7233429, 21.94836807], [88.7233429, 21.94861984], [88.72360992, 21.94888878], [88.72360992, 21.94944382], [88.72389221, 21.94972229], [88.72389221, 21.95222092], [88.72360992, 21.95249939], [88.72333527, 21.95249939], [88.72333527, 21.95583344], [88.72360992, 21.95610809], [88.72360992, 21.95639038], [88.72333527, 21.95666885], [88.7233429, 21.95832825], [88.72305298, 21.95861053], [88.72305298, 21.95889091], [88.72292328, 21.9591465], [88.72280121, 21.95950127], [88.72277832, 21.95986176], [88.72281647, 21.96018982], [88.7229538, 21.96046829], [88.72304535, 21.96075249], [88.72305298, 21.96105194], [88.72305298, 21.96136093], [88.72306061, 21.96166039], [88.72305298, 21.96195984], [88.72299957, 21.96224976], [88.72281647, 21.96251106], [88.72277832, 21.96285057], [88.72277832, 21.96325111], [88.72277832, 21.96371078], [88.72281647, 21.9642086], [88.72299194, 21.96471977], [88.72319794, 21.96519279], [88.7232666, 21.96557045], [88.72315979, 21.96585083], [88.72302246, 21.96611023], [88.7228241, 21.96639633], [88.72277832, 21.96677971], [88.7228241, 21.96723557], [88.7230072, 21.96771812], [88.72309113, 21.96829033], [88.72325897, 21.96884155], [88.72336578, 21.96940041], [88.72355652, 21.96988106], [88.72366333, 21.97033119], [88.72383881, 21.97063065], [88.72396851, 21.97090912], [88.72416687, 21.97116089], [88.72432709, 21.97142029], [88.72442627, 21.97171974], [88.72444916, 21.97203636], [88.72442627, 21.97233963], [88.72431946, 21.9726181], [88.72415161, 21.97291946], [88.72392273, 21.97331047], [88.72373199, 21.97381592], [88.72389221, 21.97437286], [88.72415161, 21.97492981], [88.72437286, 21.97550011], [88.72447205, 21.97612572], [88.72463226, 21.97673035], [88.72473145, 21.97735977], [88.72488403, 21.97793961], [88.72505951, 21.97845268], [88.72544098, 21.9788475], [88.72598267, 21.97916031], [88.72629547, 21.9790802], [88.72660828, 21.97900009], [88.72725677, 21.9790802], [88.72789764, 21.97949028], [88.72857666, 21.97945023], [88.72923279, 21.97944069], [88.72987366, 21.9794445], [88.73051453, 21.9794445], [88.73116302, 21.9794445], [88.73181152, 21.9794445], [88.73246765, 21.9794445], [88.73311615, 21.97944069], [88.73377228, 21.97945023], [88.73442078, 21.97944069], [88.73506165, 21.97940445], [88.73564911, 21.97920609], [88.73619843, 21.97916985], [88.73668671, 21.97916031], [88.73712158, 21.97916985], [88.73751068, 21.97916985], [88.73792267, 21.97916985], [88.7383728, 21.97916985], [88.73886108, 21.97916031], [88.73938751, 21.97916985], [88.73991394, 21.97920609], [88.74038696, 21.97940063], [88.74085999, 21.97946548], [88.74124908, 21.97957993], [88.74163055, 21.97970009], [88.74208832, 21.97973442], [88.74259186, 21.97981834], [88.74314117, 21.97997284], [88.74375153, 21.98000145], [88.74435425, 21.97997475], [88.74489594, 21.97983551], [88.74539185, 21.97973824]]], [[[88.66233063, 21.95251083], [88.66187286, 21.95275879], [88.66137695, 21.95292091], [88.6608963, 21.95307732], [88.66044617, 21.95329475], [88.65992737, 21.9533844], [88.65944672, 21.95357323], [88.65891266, 21.95364189], [88.65838623, 21.95380974], [88.6578064, 21.95392036], [88.65722656, 21.95412064], [88.65654755, 21.95417023], [88.65583801, 21.95417023], [88.65512848, 21.95417023], [88.65444946, 21.95417023], [88.65380096, 21.95417023], [88.65255737, 21.95417023], [88.65202332, 21.95417023], [88.65151978, 21.95417023], [88.65106201, 21.95417023], [88.65059662, 21.95417023], [88.65013123, 21.95413017], [88.64964294, 21.95393181], [88.64914703, 21.95393944], [88.64863586, 21.95413017], [88.64813232, 21.95417023], [88.64762115, 21.95413017], [88.64711761, 21.95393944], [88.6466217, 21.95396042], [88.64613342, 21.95410156], [88.64562988, 21.95398521], [88.64509583, 21.95389938], [88.64456177, 21.95388985], [88.64401245, 21.95388985], [88.64344788, 21.95387077], [88.64295959, 21.95377922], [88.64250946, 21.95359993], [88.64212036, 21.95334053], [88.641716, 21.9530983], [88.6413269, 21.95283127], [88.64093781, 21.95260429], [88.64057922, 21.9523735], [88.64025879, 21.95210266], [88.63988495, 21.95184517], [88.6394577, 21.95161057], [88.6390152, 21.95137024], [88.63863373, 21.95111847], [88.63825989, 21.9509201], [88.63784027, 21.95084], [88.63734436, 21.95083237], [88.63680267, 21.95083237], [88.63625336, 21.95083046], [88.63572693, 21.95084953], [88.63530731, 21.95095253], [88.63490295, 21.95107841], [88.6344223, 21.95113945], [88.63394165, 21.95133018], [88.633461, 21.95155907], [88.63304901, 21.9518795], [88.63269043, 21.95220947], [88.63237762, 21.9525528], [88.63214874, 21.95294952], [88.63186646, 21.95332718], [88.63175201, 21.95347214], [88.63156128, 21.95372009], [88.63124084, 21.95413017], [88.63088226, 21.95454979], [88.63056183, 21.95502663], [88.63027954, 21.95553017], [88.62998199, 21.95596886], [88.6297226, 21.95631981], [88.62948608, 21.95664978], [88.62924957, 21.95693779], [88.62902069, 21.95723152], [88.62880707, 21.95758247], [88.62864685, 21.9580307], [88.6286087, 21.95857048], [88.62857056, 21.95915031], [88.62837982, 21.95970917], [88.62833405, 21.96033669], [88.62832642, 21.96097946], [88.62833405, 21.9616394], [88.62832642, 21.96228981], [88.62832642, 21.96362114], [88.62832642, 21.96430016], [88.62832642, 21.96500969], [88.62833405, 21.96571732], [88.62832642, 21.96639061], [88.62833405, 21.96699524], [88.62834167, 21.96750069], [88.62840271, 21.9679203], [88.62856293, 21.96824074], [88.62864685, 21.96859169], [88.62885284, 21.96891022], [88.62890625, 21.96934128], [88.6289978, 21.96982384], [88.62915039, 21.9703331], [88.6292572, 21.97089958], [88.62940979, 21.97147369], [88.62948608, 21.97209358], [88.62968445, 21.97267342], [88.62980652, 21.97327042], [88.62996674, 21.97385025], [88.63004303, 21.97445107], [88.63022614, 21.97501945], [88.63028717, 21.97564125], [88.63040924, 21.97624016], [88.63053131, 21.97682762], [88.63059998, 21.97740936], [88.63078308, 21.97794914], [88.63083649, 21.97854042], [88.630867, 21.97915077], [88.631073, 21.97973824], [88.63111115, 21.98031807], [88.63111115, 21.98084831], [88.63111115, 21.9813385], [88.63114929, 21.98178291], [88.63132477, 21.98218918], [88.6313858, 21.98266983], [88.63144684, 21.98319817], [88.63162994, 21.98372078], [88.63166809, 21.98427963], [88.6317215, 21.98481178], [88.63194275, 21.98524094], [88.63194275, 21.98583412], [88.63222504, 21.98611069], [88.63222504, 21.9869442], [88.63240051, 21.98711967], [88.63249969, 21.98722267], [88.63249969, 21.98749924], [88.63253021, 21.98790359], [88.63273621, 21.98841476], [88.63282013, 21.98900414], [88.63302612, 21.98950958], [88.63314056, 21.99006271], [88.63331604, 21.99053955], [88.63342285, 21.99106026], [88.63358307, 21.99160957], [88.63366699, 21.99225044], [88.63384247, 21.9928894], [88.63392639, 21.99358177], [88.63414001, 21.99419403], [88.63430023, 21.99483109], [88.63457489, 21.9954052], [88.63485718, 21.9959507], [88.63520813, 21.99643135], [88.63553619, 21.99691963], [88.63588715, 21.99740028], [88.63635254, 21.99773026], [88.63687897, 21.99799156], [88.63739777, 21.99822044], [88.63792419, 21.99838638], [88.6383667, 21.99864006], [88.6388092, 21.99889946], [88.6391983, 21.99919128], [88.63954163, 21.99926758], [88.6399231, 21.99964905], [88.6402359, 21.99973106], [88.64111328, 22.00000191], [88.64105225, 22.00028038], [88.64112091, 22.00068092], [88.64096832, 22.00165939], [88.64444733, 22.00527954], [88.64499664, 22.00527954], [88.64527893, 22.00555992], [88.64555359, 22.0055542], [88.64583588, 22.00583267], [88.64611053, 22.00583076], [88.64666748, 22.00638962], [88.64666748, 22.00749969], [88.64638519, 22.00777626], [88.64638519, 22.00833321], [88.64666748, 22.00861168], [88.64665222, 22.00874329], [88.64685822, 22.00934982], [88.64704132, 22.00990105], [88.64724731, 22.0103302], [88.64739227, 22.01071548], [88.64745331, 22.0111599], [88.64776611, 22.01138115], [88.64804077, 22.01171112], [88.64826202, 22.01213264], [88.64852905, 22.01255989], [88.64875793, 22.01305962], [88.64898682, 22.01358032], [88.6492691, 22.01404953], [88.64961243, 22.01441002], [88.6497345, 22.01492882], [88.64987946, 22.0153923], [88.65018463, 22.01574135], [88.65055847, 22.01610947], [88.65093994, 22.01647949], [88.65135193, 22.01673126], [88.65168762, 22.01702118], [88.65196991, 22.017416], [88.6522522, 22.01791], [88.65254974, 22.01852989], [88.65293884, 22.01913071], [88.65357971, 22.01935005], [88.65418243, 22.01916122], [88.65468597, 22.01898766], [88.65516663, 22.01908112], [88.65561676, 22.01925087], [88.65595245, 22.01946068], [88.65624237, 22.01970291], [88.65663147, 22.01994324], [88.65674591, 22.01998138], [88.65716553, 22.02012253], [88.65781403, 22.02002335], [88.6584549, 22.01992416], [88.65898895, 22.01971054], [88.6594696, 22.01945877], [88.65997314, 22.01921272], [88.66049957, 22.01889038], [88.66099548, 22.01860237], [88.66144562, 22.01832771], [88.66190338, 22.01807976], [88.66236877, 22.01790047], [88.66280365, 22.01773262], [88.66318512, 22.0175209], [88.66358185, 22.01737785], [88.66397095, 22.01724815], [88.66438293, 22.01721954], [88.66479492, 22.01722145], [88.66520691, 22.01722145], [88.66563416, 22.01722145], [88.66609192, 22.01721954], [88.66655731, 22.0172596], [88.66703033, 22.01740837], [88.66752625, 22.01748276], [88.66805267, 22.01754761], [88.66851044, 22.01775169], [88.66900635, 22.01790047], [88.66953278, 22.0180397], [88.6700592, 22.01814079], [88.670578, 22.01834106], [88.67111969, 22.01857758], [88.67175293, 22.018713], [88.67240143, 22.01890373], [88.67302704, 22.01912308], [88.67365265, 22.01918411], [88.67425537, 22.01918221], [88.67490387, 22.01887703], [88.67550659, 22.01855087], [88.67601776, 22.01824951], [88.67640686, 22.01793098], [88.67677307, 22.01768303], [88.67713165, 22.01748848], [88.67745972, 22.01726151], [88.67778778, 22.0170002], [88.67815399, 22.01672745], [88.6785965, 22.01650047], [88.67904663, 22.01624107], [88.67953491, 22.01602173], [88.68002319, 22.01579857], [88.68048096, 22.01555252], [88.68089294, 22.01529121], [88.68132782, 22.01507187], [88.68179321, 22.01488686], [88.68231964, 22.01469994], [88.68287659, 22.01444244], [88.68349457, 22.01418877], [88.68415833, 22.01399994], [88.68477631, 22.0138092], [88.68527222, 22.01358986], [88.68566132, 22.01338005], [88.68611145, 22.01332855], [88.6866684, 22.01333427], [88.68694305, 22.0130558], [88.6875, 22.01305962], [88.68776703, 22.01277924], [88.68805695, 22.01277924], [88.6883316, 22.01250076], [88.68860626, 22.01250076], [88.68888855, 22.01221848], [88.68994904, 22.0122242], [88.69047546, 22.01217651], [88.69095612, 22.01196289], [88.69146729, 22.01166916], [88.69203186, 22.01133156], [88.69252014, 22.01082039], [88.69306183, 22.01028061], [88.69361115, 22.00971985], [88.69416809, 22.00916862], [88.69470215, 22.00864029], [88.69525146, 22.00818062], [88.69570923, 22.00774956], [88.69609833, 22.00733185], [88.69644928, 22.00691032], [88.69689941, 22.00654984], [88.69734955, 22.00610352], [88.69786835, 22.00564003], [88.69845581, 22.00526047], [88.69902802, 22.00485039], [88.69954681, 22.00448227], [88.7000351, 22.00419044], [88.70049286, 22.00395966], [88.70094299, 22.00378036], [88.70134735, 22.00362587], [88.70176697, 22.00349808], [88.70214844, 22.00333023], [88.70252991, 22.00316811], [88.70294189, 22.00305939], [88.70336914, 22.00298691], [88.70376587, 22.00281906], [88.70426941, 22.00276184], [88.70482635, 22.00266075], [88.70543671, 22.00248146], [88.70607758, 22.00225449], [88.70679474, 22.00214195], [88.70754242, 22.00216484], [88.70829773, 22.00205994], [88.70905304, 22.00214958], [88.70978546, 22.00208282], [88.71050262, 22.00218964], [88.71118164, 22.00222015], [88.71182251, 22.00221252], [88.71244049, 22.00212097], [88.71302795, 22.00192833], [88.71357727, 22.00168991], [88.71412659, 22.00154495], [88.71459961, 22.00138283], [88.71499634, 22.00120926], [88.71533966, 22.00103951], [88.71559143, 22.00086021], [88.71578217, 22.00064087], [88.71573639, 22.00054932], [88.71527863, 22.00000191], [88.71528625, 21.99930954], [88.71534729, 21.99910927], [88.71517944, 21.99876022], [88.71481323, 21.9984684], [88.71453094, 21.99810791], [88.71431732, 21.99767113], [88.71407318, 21.99724007], [88.71379089, 21.99683571], [88.71351624, 21.99641991], [88.71325684, 21.99603081], [88.7130127, 21.99566269], [88.712677, 21.99534035], [88.7122879, 21.99510193], [88.71180725, 21.99491119], [88.71134949, 21.99468803], [88.71092987, 21.99440956], [88.71053314, 21.9941082], [88.71018219, 21.99379349], [88.70985413, 21.99348831], [88.70948029, 21.99323273], [88.70907593, 21.99292946], [88.70867157, 21.99250031], [88.70836639, 21.99199295], [88.70809937, 21.99158287], [88.70783234, 21.99125099], [88.7075119, 21.99090004], [88.70704651, 21.99057007], [88.70664215, 21.99003029], [88.70625305, 21.98958015], [88.70593262, 21.98923111], [88.70569611, 21.98880959], [88.70543671, 21.98829842], [88.70503998, 21.98788071], [88.70456696, 21.98760986], [88.7040863, 21.98733521], [88.70365906, 21.9869709], [88.70323944, 21.98657227], [88.70281982, 21.98614693], [88.70240784, 21.98568916], [88.70211029, 21.98518944], [88.70191956, 21.98467255], [88.70170593, 21.9842205], [88.70145416, 21.98382378], [88.7011795, 21.98340416], [88.70087433, 21.98296356], [88.70059204, 21.98251152], [88.70040894, 21.98207283], [88.70026398, 21.98168182], [88.70011902, 21.98134995], [88.69999695, 21.98101997], [88.69985962, 21.98069954], [88.69970703, 21.98039055], [88.69954681, 21.98010063], [88.69940186, 21.97984123], [88.69922638, 21.97960091], [88.69905853, 21.97935867], [88.69888306, 21.97915077], [88.69869995, 21.97894287], [88.69856262, 21.97867966], [88.69835663, 21.97843552], [88.69809723, 21.97813988], [88.69777679, 21.97775078], [88.69742584, 21.97729111], [88.69694519, 21.97685814], [88.69651031, 21.97628975], [88.69615173, 21.97569275], [88.69584656, 21.97512054], [88.69555664, 21.97458267], [88.69528198, 21.97407913], [88.69500732, 21.97361183], [88.69478607, 21.97313118], [88.69461823, 21.97256851], [88.69441223, 21.97200012], [88.69416046, 21.9714222], [88.69389343, 21.97085381], [88.69364166, 21.97035408], [88.69335175, 21.97001648], [88.69308472, 21.96980095], [88.69277191, 21.96974182], [88.69259644, 21.96976852], [88.69239807, 21.96980095], [88.69198608, 21.97000122], [88.69150543, 21.97023392], [88.69091797, 21.97039986], [88.6902771, 21.97059059], [88.68968964, 21.9708519], [88.68913269, 21.97113991], [88.688591, 21.97144127], [88.68807983, 21.97178078], [88.68759155, 21.97213936], [88.68712616, 21.97252083], [88.68673706, 21.97295952], [88.68643951, 21.97350121], [88.68629456, 21.97412682], [88.68641663, 21.97475052], [88.6866684, 21.97530937], [88.68694305, 21.97579193], [88.68727112, 21.97618294], [88.68757629, 21.97657776], [88.6878891, 21.97695351], [88.68817902, 21.97732925], [88.6884613, 21.97769737], [88.68875885, 21.97801971], [88.68904114, 21.97835732], [88.68929291, 21.97872162], [88.68953705, 21.97908974], [88.68981934, 21.97945976], [88.69008636, 21.97985268], [88.69039917, 21.98021126], [88.69072723, 21.98054123], [88.69101715, 21.98088074], [88.69126892, 21.9812603], [88.69151306, 21.98166084], [88.69172668, 21.98207092], [88.69197083, 21.98244858], [88.69223022, 21.98279762], [88.69248199, 21.98316002], [88.69271088, 21.98357582], [88.69287109, 21.98405266], [88.69284058, 21.98456001], [88.69278717, 21.9850502], [88.69271088, 21.98551941], [88.69257355, 21.98593903], [88.69243622, 21.98637962], [88.69220734, 21.98681259], [88.69193268, 21.98728943], [88.69156647, 21.9878273], [88.6911087, 21.9883728], [88.69061279, 21.98893929], [88.69008636, 21.9895401], [88.68949127, 21.99003983], [88.68888855, 21.99056435], [88.68835449, 21.99102592], [88.68840027, 21.99110985], [88.68805695, 21.99139023], [88.68776703, 21.99139023], [88.6875, 21.99167061], [88.68723297, 21.99167061], [88.6866684, 21.99110985], [88.68777466, 21.98999977], [88.68805695, 21.98999977], [88.68839264, 21.98958969], [88.688797, 21.98923111], [88.68921661, 21.98887825], [88.68962097, 21.9885006], [88.68997192, 21.98809624], [88.69029999, 21.98768044], [88.69059753, 21.98727036], [88.69087219, 21.98687172], [88.69111633, 21.98649025], [88.69133759, 21.98610115], [88.69145966, 21.98567009], [88.69153595, 21.98524094], [88.69146729, 21.98476982], [88.69142914, 21.98430443], [88.69139862, 21.98387718], [88.69133759, 21.98352051], [88.69120026, 21.98324776], [88.69103241, 21.98297119], [88.69082642, 21.98267746], [88.69056702, 21.98236084], [88.69029236, 21.98203278], [88.69001007, 21.98168755], [88.68972778, 21.98133087], [88.68945313, 21.9809761], [88.68916321, 21.98061943], [88.68885803, 21.98024178], [88.68855286, 21.97981071], [88.68817902, 21.97936058], [88.68781281, 21.97886276], [88.68744659, 21.97837067], [88.68708801, 21.97792244], [88.68675232, 21.97749901], [88.68643188, 21.97710037], [88.68613434, 21.976717], [88.68582153, 21.97635078], [88.68553162, 21.9759407], [88.68525696, 21.97552109], [88.68501282, 21.97505951], [88.68483734, 21.97456932], [88.68482208, 21.97406006], [88.6849823, 21.97356987], [88.68515778, 21.97306252], [88.68537903, 21.97256088], [88.68564606, 21.97209167], [88.68602753, 21.97170067], [88.68643188, 21.9713707], [88.68686676, 21.97110176], [88.68732452, 21.97083092], [88.68782043, 21.97055054], [88.68837738, 21.97027588], [88.68895721, 21.96998978], [88.6895752, 21.96970367], [88.69019318, 21.96940804], [88.69042969, 21.96928024], [88.69078064, 21.9690876], [88.69124603, 21.96866989], [88.69178009, 21.96828079], [88.69232178, 21.96784019], [88.69290161, 21.96741676], [88.69330597, 21.96692276], [88.69358826, 21.96642876], [88.69381714, 21.9659996], [88.69393158, 21.96554947], [88.69412231, 21.96516037], [88.69416809, 21.96471024], [88.69416809, 21.96445084], [88.69416809, 21.96417046], [88.69444275, 21.96389008], [88.69444275, 21.96194267], [88.69472504, 21.96166611], [88.69473267, 21.96138954], [88.69444275, 21.96138954], [88.69410706, 21.96105385], [88.69361115, 21.96055603], [88.69361115, 21.95943832], [88.69333649, 21.95916748], [88.69333649, 21.95889091], [88.69304657, 21.95861053], [88.69304657, 21.95832825], [88.69277954, 21.9580555], [88.69277954, 21.95778084], [88.69249725, 21.95750046], [88.69249725, 21.95721817], [88.6922226, 21.95694351], [88.69232178, 21.95667267], [88.6920166, 21.95640945], [88.69173431, 21.95610619], [88.69133759, 21.95582962], [88.6908493, 21.9556179], [88.69030762, 21.95550919], [88.68982697, 21.95539093], [88.68933868, 21.95529938], [88.688797, 21.95524979], [88.68822479, 21.9551506], [88.68762207, 21.95496178], [88.68700409, 21.95472717], [88.6863327, 21.95453072], [88.68557739, 21.95450974], [88.68479919, 21.95458984], [88.68403625, 21.9545002], [88.68331146, 21.95442963], [88.68261719, 21.95438004], [88.68197632, 21.95424652], [88.6812973, 21.95417976], [88.68061066, 21.95414543], [88.67991638, 21.9540863], [88.67925262, 21.95394135], [88.67860413, 21.95382309], [88.67801666, 21.95365715], [88.67743683, 21.9535408], [88.67690277, 21.95338058], [88.67636871, 21.95326042], [88.6758728, 21.95311546], [88.67534637, 21.95301247], [88.67483521, 21.95288086], [88.67434692, 21.95273209], [88.67389679, 21.9525547], [88.67345428, 21.9524231], [88.67308044, 21.9522934], [88.67272186, 21.95220757], [88.67234802, 21.95218086], [88.67195129, 21.95217705], [88.67153168, 21.95218849], [88.67112732, 21.95223045], [88.67073059, 21.9522953], [88.67034149, 21.95230675], [88.66999817, 21.95240974], [88.66999817, 21.95249939], [88.66971588, 21.95249939], [88.66832733, 21.95388985], [88.66777802, 21.95333099], [88.66777802, 21.95277786], [88.66889191, 21.95168114], [88.66947937, 21.95148087], [88.67002869, 21.95129967], [88.67053223, 21.95112419], [88.67099762, 21.95098305], [88.67147827, 21.95091248], [88.67195129, 21.95095253], [88.67240143, 21.95103645], [88.67282104, 21.95109367], [88.67320251, 21.95116043], [88.67356873, 21.95128822], [88.67397308, 21.95139122], [88.6743927, 21.9514904], [88.67484283, 21.95160103], [88.67530823, 21.95168114], [88.67576599, 21.9517498], [88.67620087, 21.95189095], [88.67664337, 21.95200157], [88.67707062, 21.95214081], [88.67753601, 21.95221901], [88.6780014, 21.95228958], [88.67841339, 21.95241928], [88.67884064, 21.95249176], [88.67928314, 21.95256996], [88.6796875, 21.95269966], [88.68010712, 21.95276833], [88.6805191, 21.95284081], [88.68092346, 21.95296478], [88.68138885, 21.9530201], [88.6818924, 21.95304108], [88.68239594, 21.95304489], [88.68289185, 21.95304489], [88.68339539, 21.95304489], [88.68392181, 21.95304489], [88.68445587, 21.95304489], [88.68498993, 21.95303345], [88.68549347, 21.95298576], [88.68595886, 21.95285988], [88.68644714, 21.95288086], [88.68695831, 21.95298958], [88.68741608, 21.95298958], [88.68778992, 21.95288086], [88.68805695, 21.95277786], [88.68805695, 21.95222092], [88.68722534, 21.95138931], [88.68694305, 21.95139122], [88.68611145, 21.95055962], [88.68583679, 21.95055962], [88.68527985, 21.95000076], [88.6847229, 21.95055962], [88.68444824, 21.95028114], [88.68416595, 21.95028114], [88.6838913, 21.95000076], [88.6838913, 21.94972038], [88.68383789, 21.94955826], [88.68344116, 21.94911003], [88.68309021, 21.9486351], [88.68279266, 21.94815063], [88.68250275, 21.94767952], [88.68221283, 21.94725037], [88.68187714, 21.94688988], [88.68157959, 21.94655037], [88.68132782, 21.94617081], [88.68104553, 21.94582367], [88.68075562, 21.94545746], [88.68042755, 21.94503975], [88.6800766, 21.94464111], [88.6796875, 21.94423103], [88.67929077, 21.94386101], [88.67893219, 21.94355583], [88.67867279, 21.94326973], [88.67851257, 21.94302368], [88.67815399, 21.94286728], [88.6778717, 21.94305992], [88.67750549, 21.94323921], [88.67706299, 21.94338036], [88.67656708, 21.94362068], [88.67603302, 21.94389915], [88.67547607, 21.94421005], [88.67495728, 21.94451714], [88.67449188, 21.94486237], [88.67410278, 21.94523048], [88.67370605, 21.9455719], [88.67332458, 21.94589615], [88.67294312, 21.94621086], [88.67253113, 21.94651985], [88.67212677, 21.94683647], [88.67169189, 21.94708443], [88.67125702, 21.9473381], [88.67085266, 21.94760513], [88.6704483, 21.94787025], [88.67005157, 21.94812012], [88.6696701, 21.94837952], [88.66929626, 21.94862938], [88.66892242, 21.94886971], [88.66848755, 21.94903946], [88.66796875, 21.94915009], [88.66738129, 21.94923019], [88.66693878, 21.94947052], [88.6665802, 21.94979286], [88.6661911, 21.95004654], [88.66581726, 21.95031929], [88.66542816, 21.95057106], [88.66503906, 21.95084], [88.66461945, 21.95111084], [88.66417694, 21.95139122], [88.66372681, 21.95169067], [88.66330719, 21.95201111], [88.66281128, 21.95225906], [88.66233063, 21.95251083]]], [[[88.7591629, 21.99860764], [88.7591629, 21.9972229], [88.75888824, 21.99694633], [88.75888824, 21.99666977], [88.75871277, 21.99628448], [88.75853729, 21.99583244], [88.7583313, 21.99583244], [88.7583313, 21.99555779], [88.75776672, 21.99500084], [88.75776672, 21.99472237], [88.75749969, 21.99444389], [88.75749969, 21.99416924], [88.75723267, 21.99389076], [88.75723267, 21.99360085], [88.75682831, 21.9933815], [88.75660706, 21.99297905], [88.75636292, 21.99261284], [88.75605774, 21.99228477], [88.75569153, 21.99197197], [88.75534058, 21.99165344], [88.75497437, 21.99136162], [88.75457764, 21.99105263], [88.75415039, 21.9906826], [88.75370789, 21.99027824], [88.7536087, 21.99027824], [88.7536087, 21.98999977], [88.75332642, 21.98999977], [88.75332642, 21.9897213], [88.75305176, 21.98944664], [88.75305176, 21.98916817], [88.7527771, 21.98888969], [88.7527771, 21.98833275], [88.75250244, 21.98833275], [88.75222015, 21.98805809], [88.75195313, 21.98806381], [88.75166321, 21.98779106], [88.75138855, 21.98750114], [88.75110626, 21.98750114], [88.7508316, 21.98722267], [88.75055695, 21.98722267], [88.75037384, 21.98703957], [88.75, 21.98666573], [88.74973297, 21.98666954], [88.74954224, 21.98648643], [88.74944305, 21.98638916], [88.74804687, 21.98500252], [88.74777985, 21.98500252], [88.7472229, 21.98444176], [88.74694824, 21.98444557], [88.74653625, 21.98403358], [88.7463913, 21.98389053], [88.74582672, 21.98365974], [88.74539948, 21.98346138], [88.74500275, 21.98331451], [88.74466705, 21.98315048], [88.74430084, 21.98307228], [88.74391174, 21.98304939], [88.74352264, 21.98308182], [88.74317169, 21.98321152], [88.742836, 21.98340034], [88.74256134, 21.98371315], [88.74236298, 21.98419189], [88.74220276, 21.98474312], [88.74198914, 21.98527908], [88.74194336, 21.98584938], [88.74192047, 21.98637199], [88.74179077, 21.98682213], [88.74167633, 21.98726082], [88.74162292, 21.98771286], [88.74142456, 21.98807716], [88.74139404, 21.98844337], [88.74145508, 21.98877144], [88.74164581, 21.98904228], [88.74182129, 21.98932076], [88.74197388, 21.98958588], [88.74217224, 21.98981285], [88.74235535, 21.9901371], [88.7425766, 21.99049568], [88.74289703, 21.99083138], [88.74328613, 21.99118423], [88.74362183, 21.99155807], [88.74395752, 21.99188042], [88.7443161, 21.99211311], [88.74468994, 21.99233818], [88.74504089, 21.9926548], [88.74547577, 21.99298477], [88.74597168, 21.99337006], [88.74642944, 21.99385262], [88.74693298, 21.99432182], [88.74739838, 21.99477959], [88.74777985, 21.99527168], [88.74822235, 21.99570847], [88.74874115, 21.99614143], [88.74928284, 21.99664116], [88.74990082, 21.99711037], [88.7505188, 21.99758148], [88.75108337, 21.99809837], [88.75111389, 21.99833488], [88.75138855, 21.99832916], [88.75222778, 21.9991703], [88.75222778, 21.99945259], [88.75250244, 22.00000191], [88.7527771, 22.00028801], [88.75300598, 22.0003109], [88.75324249, 22.00047493], [88.75348663, 22.00073051], [88.75370026, 22.00107765], [88.75392914, 22.00142097], [88.75417328, 22.00175476], [88.75441742, 22.00206947], [88.75463104, 22.00241089], [88.75482941, 22.00276184], [88.75505829, 22.00312233], [88.75531006, 22.00352287], [88.75559998, 22.00395012], [88.75587463, 22.00444031], [88.75614929, 22.0049305], [88.75647736, 22.00538063], [88.75672913, 22.00576973], [88.7569809, 22.00605965], [88.75723267, 22.00629044], [88.75746155, 22.00647736], [88.7576828, 22.00669289], [88.7579422, 22.00694084], [88.75829315, 22.00712013], [88.75847626, 22.00709534], [88.75871277, 22.00706482], [88.75912476, 22.00671577], [88.75943756, 22.00621223], [88.75963593, 22.00567055], [88.75966644, 22.00508118], [88.75955963, 22.00443268], [88.75966644, 22.00379944], [88.75970459, 22.0033226], [88.75971222, 22.00316811], [88.75972748, 22.00258064], [88.75973511, 22.00203514], [88.7598114, 22.00132942], [88.75945282, 22.00000191], [88.75944519, 21.99888992], [88.7591629, 21.99860764]]], [[[88.73143768, 22.04524612], [88.73284912, 22.04360008], [88.73339081, 22.04360008], [88.73342133, 22.04309845], [88.7339859, 22.04276657], [88.7339859, 22.04226112], [88.73342133, 22.04221725], [88.73288727, 22.04252052], [88.7322998, 22.04277039], [88.73228455, 22.0430088], [88.73149872, 22.0430603], [88.73093414, 22.04359818], [88.73091888, 22.04529953], [88.73143768, 22.04524612]]], [[[88.03138733, 22.06056023], [88.03138733, 22.05944061], [88.03111267, 22.05916405], [88.03083038, 22.05916977], [88.03056335, 22.05888939], [88.02916718, 22.05888939], [88.02889252, 22.05916977], [88.02861023, 22.05916405], [88.02833557, 22.05944443], [88.02805328, 22.05944061], [88.02749634, 22.06001091], [88.02749634, 22.0605545], [88.02777863, 22.06083298], [88.02777863, 22.06110954], [88.02749634, 22.06138992], [88.02749634, 22.06194687], [88.02777863, 22.06222153], [88.02805328, 22.06222153], [88.02833557, 22.06249809], [88.02944183, 22.06249809], [88.03138733, 22.06056023]]], [[[88.63582611, 22.0508194], [88.6361084, 22.05055618], [88.6361084, 22.05027962], [88.63639069, 22.05000114], [88.63639069, 22.04944038], [88.6361084, 22.04916573], [88.63555908, 22.04861069], [88.63471222, 22.04861069], [88.63445282, 22.04889107], [88.63388824, 22.04889107], [88.63360596, 22.04916954], [88.6333313, 22.04916573], [88.63277435, 22.04972267], [88.63249969, 22.04972076], [88.63194275, 22.05027962], [88.63166809, 22.05027962], [88.6313858, 22.05055809], [88.63111115, 22.05055809], [88.62999725, 22.05166626], [88.62999725, 22.05194092], [88.62944794, 22.05250168], [88.62944794, 22.05277824], [88.62916565, 22.05305481], [88.62916565, 22.05361176], [88.62889862, 22.05388069], [88.62889862, 22.05417061], [88.6286087, 22.0544529], [88.6286087, 22.05500031], [88.62832642, 22.05528069], [88.62833405, 22.05694389], [88.62805176, 22.05722237], [88.62805176, 22.05833054], [88.6277771, 22.05861092], [88.6277771, 22.06110954], [88.6286087, 22.06195068], [88.62982178, 22.06195068], [88.62999725, 22.06195068], [88.63054657, 22.06249809], [88.63054657, 22.06278038], [88.63083649, 22.06306839], [88.63111115, 22.06306839], [88.63166809, 22.06249809], [88.63166809, 22.06221962], [88.63222504, 22.0616684], [88.63223267, 22.06138992], [88.63249969, 22.06110954], [88.63249969, 22.06083298], [88.63277435, 22.0605545], [88.63276672, 22.05944061], [88.63305664, 22.05916405], [88.63305664, 22.05861092], [88.63360596, 22.05805969], [88.63360596, 22.05667114], [88.63388824, 22.05639076], [88.63388824, 22.05583191], [88.6341629, 22.05555534], [88.6341629, 22.05528069], [88.63445282, 22.05500031], [88.63444519, 22.05444527], [88.63471222, 22.05417061], [88.63471222, 22.05332947], [88.63500214, 22.05305481], [88.63500214, 22.05277824], [88.63527679, 22.05250168], [88.63527679, 22.05221748], [88.63555908, 22.05194473], [88.63555908, 22.05166626], [88.6361084, 22.05111122], [88.63582611, 22.0508194]]], [[[88.90278625, 22.04533386], [88.9025116, 22.04473877], [88.90229797, 22.04414177], [88.90213776, 22.04354477], [88.90193176, 22.04304123], [88.90171051, 22.04257774], [88.90159607, 22.04203987], [88.90141296, 22.04151917], [88.90127563, 22.04101944], [88.90113068, 22.04060555], [88.90103912, 22.04023933], [88.90087128, 22.03996086], [88.90083313, 22.0396328], [88.90083313, 22.03925133], [88.90083313, 22.0391674], [88.90083313, 22.03805923], [88.90055847, 22.03778267], [88.90055847, 22.03722191], [88.90027618, 22.03694725], [88.90027618, 22.03667259], [88.90055847, 22.0363903], [88.90055847, 22.03583908], [88.90083313, 22.03555107], [88.90086365, 22.03511238], [88.90102386, 22.0346508], [88.90113831, 22.03409004], [88.90132141, 22.03347969], [88.90138245, 22.03280067], [88.90139008, 22.03206253], [88.90141296, 22.03129959], [88.9015274, 22.03056145], [88.90164948, 22.02983284], [88.9016571, 22.02914238], [88.9016571, 22.02848244], [88.90171051, 22.02787209], [88.90190125, 22.02733994], [88.9019928, 22.02676392], [88.90216827, 22.02621078], [88.90225983, 22.02560234], [88.90245056, 22.02505302], [88.90246582, 22.02451134], [88.90229034, 22.02403069], [88.90220642, 22.02353096], [88.90202332, 22.02311516], [88.9019165, 22.02270317], [88.90177155, 22.02230263], [88.9016571, 22.02222252], [88.90166473, 22.01888847], [88.90135956, 22.01832008], [88.90093994, 22.01793098], [88.90039825, 22.01775169], [88.89993286, 22.01754189], [88.89943695, 22.01749992], [88.89916992, 22.01749992], [88.89888763, 22.01722145], [88.89833069, 22.01722145], [88.89805603, 22.01694679], [88.89778137, 22.01694679], [88.89764404, 22.01680756], [88.89749908, 22.01666641], [88.89686584, 22.01658249], [88.89629364, 22.01629066], [88.89572144, 22.01601219], [88.89510345, 22.01579857], [88.89451599, 22.01555252], [88.89394379, 22.01530457], [88.89337158, 22.01515007], [88.89285278, 22.01498604], [88.89232635, 22.01478195], [88.89170074, 22.01472473], [88.89098358, 22.01472282], [88.89065552, 22.01472282], [88.89028931, 22.01472282], [88.8897934, 22.01472282], [88.88925171, 22.01472282], [88.8886795, 22.01473236], [88.8881073, 22.01481438], [88.88755035, 22.014925], [88.88706207, 22.01476479], [88.8865509, 22.01472664], [88.8860321, 22.01477242], [88.88555908, 22.01496315], [88.88500977, 22.0150013], [88.88444519, 22.0150013], [88.8839035, 22.0150013], [88.88341522, 22.0150013], [88.88296509, 22.0150013], [88.88252258, 22.0150013], [88.88207245, 22.01499748], [88.88160706, 22.01495171], [88.88115692, 22.01481056], [88.88063049, 22.01491928], [88.88014984, 22.01476097], [88.87960815, 22.01468086], [88.87908173, 22.01452065], [88.87851715, 22.01464272], [88.87795258, 22.01470757], [88.87744904, 22.01473236], [88.87701416, 22.01483917], [88.87666321, 22.01509285], [88.876297, 22.01535988], [88.87592316, 22.01558876], [88.87561798, 22.01585197], [88.8753891, 22.01615334], [88.87526703, 22.01651192], [88.87509918, 22.01686287], [88.87502289, 22.01724052], [88.87499237, 22.01766014], [88.87493896, 22.01807976], [88.87475586, 22.01847267], [88.87472534, 22.01892662], [88.87471771, 22.01940346], [88.87473297, 22.01987267], [88.87470245, 22.02030754], [88.87460327, 22.02066994], [88.87446594, 22.02099991], [88.87441254, 22.02137184], [88.87425232, 22.02176094], [88.87416077, 22.02218819], [88.8740387, 22.02261162], [88.87388611, 22.02299309], [88.87372589, 22.0233326], [88.8735733, 22.02365494], [88.87335968, 22.02397156], [88.87325287, 22.02436256], [88.87304688, 22.0247097], [88.87285614, 22.02507019], [88.87269592, 22.02546883], [88.87243652, 22.02580452], [88.87211609, 22.0261116], [88.87180328, 22.0264225], [88.87166595, 22.02666664], [88.87110901, 22.02722359], [88.87082672, 22.02722168], [88.87088013, 22.02750015], [88.87059021, 22.02749062], [88.87023163, 22.02753639], [88.86982727, 22.02771378], [88.8693161, 22.02776909], [88.86876678, 22.02781105], [88.86823273, 22.02798271], [88.86765289, 22.02808952], [88.86708069, 22.0282917], [88.86644745, 22.0282917], [88.86582184, 22.02815056], [88.86525726, 22.02830315], [88.86473083, 22.02837181], [88.86434937, 22.02854729], [88.86399078, 22.02867317], [88.8637085, 22.02890205], [88.86341095, 22.02918816], [88.86309052, 22.02954292], [88.86279297, 22.02996826], [88.8624115, 22.0303688], [88.8620224, 22.03075981], [88.86164856, 22.03118515], [88.86122131, 22.0315609], [88.86080933, 22.03195], [88.86032104, 22.03227806], [88.85987091, 22.03263664], [88.85948181, 22.03303146], [88.85913086, 22.03347969], [88.85871124, 22.0338726], [88.85823822, 22.03418541], [88.85782623, 22.03455353], [88.8575058, 22.03498268], [88.85714722, 22.03535271], [88.85679626, 22.03570938], [88.85639954, 22.03608131], [88.85591125, 22.03642273], [88.85540771, 22.03681946], [88.85493469, 22.03728867], [88.85441589, 22.03775215], [88.85391235, 22.0382328], [88.85346222, 22.03874969], [88.85299683, 22.03922462], [88.85253906, 22.03969002], [88.85228729, 22.0402317], [88.85218048, 22.04079247], [88.85198212, 22.04123116], [88.8519516, 22.0416832], [88.85204315, 22.04211235], [88.85232544, 22.04246712], [88.85275269, 22.04277039], [88.85327148, 22.04306221], [88.85389709, 22.04329109], [88.85463715, 22.04334068], [88.8553772, 22.04338074], [88.85604095, 22.04356194], [88.85667419, 22.04356766], [88.85730743, 22.04343987], [88.85793304, 22.0435791], [88.85855103, 22.04361153], [88.85915375, 22.04361153], [88.85971832, 22.04361153], [88.86026764, 22.04360962], [88.86080933, 22.04361153], [88.86135864, 22.04364967], [88.86190796, 22.04379082], [88.86227417, 22.04371262], [88.86245728, 22.04367065], [88.86299133, 22.04361916], [88.86348724, 22.04361153], [88.86394501, 22.04361153], [88.86433411, 22.04357719], [88.86467743, 22.04341316], [88.86508942, 22.04334068], [88.86557007, 22.04333305], [88.86612701, 22.04332924], [88.86669922, 22.04327393], [88.86724091, 22.04309845], [88.86782837, 22.04306221], [88.86846161, 22.04305267], [88.86907196, 22.04305458], [88.86968994, 22.04305458], [88.87032318, 22.04306984], [88.8709259, 22.04316139], [88.87152863, 22.04330635], [88.87216949, 22.04333305], [88.87281036, 22.04334068], [88.87342072, 22.04333305], [88.87398529, 22.04333305], [88.8744812, 22.04333305], [88.87493896, 22.04333305], [88.87539673, 22.04333305], [88.87589264, 22.04338264], [88.87641907, 22.04356956], [88.87699127, 22.04361153], [88.87759399, 22.04361916], [88.87819672, 22.04367065], [88.87879181, 22.04383278], [88.8793869, 22.04389], [88.87999725, 22.04393959], [88.88053131, 22.04411125], [88.88109589, 22.04416275], [88.88166046, 22.04417229], [88.88194275, 22.04416656], [88.88221741, 22.04416275], [88.88276672, 22.04416656], [88.88329315, 22.04420853], [88.88374329, 22.04440117], [88.88423157, 22.04444313], [88.88470459, 22.04447365], [88.88515472, 22.04459763], [88.88562012, 22.04470253], [88.88613129, 22.04476357], [88.8866272, 22.04493141], [88.887146, 22.04498291], [88.88770294, 22.04496193], [88.88816071, 22.04504585], [88.88858032, 22.04527092], [88.88904572, 22.04548645], [88.88964081, 22.04557991], [88.89021301, 22.04584312], [88.89073944, 22.04617691], [88.89116669, 22.04660225], [88.89160919, 22.04704094], [88.8917923, 22.04736328], [88.89190674, 22.04755974], [88.89205933, 22.04816055], [88.89216614, 22.04877281], [88.89204407, 22.04933739], [88.89186096, 22.04980278], [88.89169312, 22.05021286], [88.8915863, 22.05064964], [88.89138031, 22.0510006], [88.89112091, 22.05138969], [88.89082336, 22.05187035], [88.89045715, 22.05239487], [88.88999939, 22.05288506], [88.88963318, 22.05323982], [88.88948822, 22.05338097], [88.88896942, 22.05389977], [88.88844299, 22.05439568], [88.88784027, 22.0547905], [88.88729095, 22.05521965], [88.88682556, 22.05566978], [88.88633728, 22.05608177], [88.8859024, 22.05647087], [88.88562012, 22.05688477], [88.88562775, 22.05732155], [88.88593292, 22.05764961], [88.88639832, 22.05777359], [88.88691711, 22.05778313], [88.88743591, 22.05774117], [88.88787842, 22.0575428], [88.88840485, 22.0574913], [88.88893127, 22.05742836], [88.88938141, 22.05726051], [88.8898468, 22.05717278], [88.89026642, 22.05699158], [88.89055634, 22.05693626], [88.89073181, 22.05690384], [88.89112091, 22.05668449], [88.89154816, 22.05651665], [88.89202118, 22.05639076], [88.89248657, 22.05624008], [88.89295959, 22.05607033], [88.8934021, 22.05583191], [88.89389038, 22.05556488], [88.8944931, 22.05528069], [88.8951416, 22.05499077], [88.89579773, 22.05461311], [88.89633942, 22.05413246], [88.89682007, 22.05365181], [88.89726257, 22.05327225], [88.8975296, 22.0528965], [88.89780426, 22.05262566], [88.89810944, 22.05243874], [88.89837646, 22.0522213], [88.8986969, 22.05201912], [88.89907074, 22.05188179], [88.89936829, 22.05167007], [88.89965057, 22.05147171], [88.89994812, 22.05130959], [88.90023804, 22.05114746], [88.90061951, 22.05107307], [88.90100861, 22.05088997], [88.90143585, 22.05080986], [88.90184021, 22.05067253], [88.90228271, 22.05053139], [88.90268707, 22.05036354], [88.90303802, 22.05010223], [88.9033432, 22.04975128], [88.9036026, 22.04937172], [88.90380859, 22.04895973], [88.90382385, 22.04885292], [88.90388489, 22.04848671], [88.90387726, 22.04800224], [88.90377808, 22.04751015], [88.90359497, 22.04700851], [88.9033432, 22.04649162], [88.90305328, 22.04592705], [88.90278625, 22.04533386]]], [[[88.7638092, 22.05167007], [88.76432037, 22.05166054], [88.76480103, 22.05167007], [88.76529694, 22.05167007], [88.76579285, 22.05167007], [88.76629639, 22.05167007], [88.76679993, 22.05166054], [88.76728821, 22.05161667], [88.76773071, 22.0514431], [88.76819611, 22.05138969], [88.76869965, 22.05138969], [88.76920319, 22.05138969], [88.76940155, 22.05138969], [88.76967621, 22.05138969], [88.7701416, 22.05138969], [88.77054596, 22.05138969], [88.77091217, 22.05139351], [88.77125549, 22.05138969], [88.77162933, 22.05135155], [88.77205658, 22.05116081], [88.77259827, 22.05109215], [88.7731781, 22.05098534], [88.77377319, 22.05081749], [88.77429962, 22.0505619], [88.77479553, 22.05029869], [88.77526093, 22.05004311], [88.77565765, 22.04972267], [88.77606201, 22.04938316], [88.77642059, 22.04903221], [88.77677917, 22.04874992], [88.77700043, 22.04841042], [88.77723694, 22.04813194], [88.77749634, 22.04789162], [88.77780914, 22.04766655], [88.77818298, 22.04747391], [88.77854919, 22.04722023], [88.77892303, 22.04694939], [88.77928925, 22.04665947], [88.77958679, 22.04633141], [88.77974701, 22.04593086], [88.779953, 22.04557228], [88.77996063, 22.04516983], [88.77979279, 22.04477119], [88.77960968, 22.04433823], [88.77939606, 22.04391289], [88.77915192, 22.04347038], [88.77888489, 22.04302216], [88.77863312, 22.04251671], [88.77845764, 22.04193306], [88.77832794, 22.04132271], [88.77820587, 22.04073143], [88.77810669, 22.04018211], [88.77822876, 22.03968239], [88.77832031, 22.03923225], [88.77838898, 22.03881264], [88.77854156, 22.03844833], [88.77861786, 22.03803062], [88.77870941, 22.03757286], [88.77890778, 22.03718376], [88.77919769, 22.03684044], [88.77955627, 22.03655052], [88.77998352, 22.03632927], [88.78040314, 22.03613091], [88.78082275, 22.03594017], [88.78119659, 22.03574753], [88.78157806, 22.03555107], [88.78195953, 22.03532219], [88.78243256, 22.03524017], [88.7828598, 22.0350399], [88.78336334, 22.03495216], [88.78380585, 22.03477669], [88.78430939, 22.03473091], [88.78482056, 22.03471947], [88.78530884, 22.03472137], [88.78575897, 22.03467941], [88.7861557, 22.03449249], [88.78660583, 22.03444862], [88.78705597, 22.03444099], [88.78752136, 22.0343914], [88.78796387, 22.03420448], [88.78845215, 22.0341053], [88.78887939, 22.03388023], [88.78933716, 22.03361511], [88.78985596, 22.03333092], [88.7904129, 22.03299141], [88.79088593, 22.03251076], [88.79128265, 22.03199005], [88.79142761, 22.03133202], [88.79158783, 22.03066826], [88.79139709, 22.03000069], [88.79104614, 22.02937126], [88.79051971, 22.02894592], [88.78993225, 22.02860069], [88.78939056, 22.02827454], [88.78887939, 22.02794456], [88.78838348, 22.02764702], [88.78797913, 22.02729034], [88.78755188, 22.02699089], [88.78713226, 22.02669144], [88.78669739, 22.02641487], [88.78627014, 22.02612114], [88.78582764, 22.02584267], [88.78536987, 22.02555275], [88.78488922, 22.0252552], [88.7844162, 22.02489471], [88.7838974, 22.02453613], [88.78337097, 22.02412987], [88.78285217, 22.02370262], [88.78231049, 22.02334404], [88.78177643, 22.02303123], [88.78132629, 22.02272224], [88.78092194, 22.02257156], [88.78063202, 22.02269173], [88.78035736, 22.02261162], [88.78012848, 22.02224159], [88.77990723, 22.02187729], [88.77944183, 22.02111244], [88.77861023, 22.02028084], [88.77805328, 22.02000237], [88.77805328, 22.01972008], [88.77416992, 22.01972008], [88.77305603, 22.02000237], [88.76889038, 22.02000237], [88.76889038, 22.02056313], [88.76777649, 22.02083588], [88.76389313, 22.02111244], [88.76167297, 22.02139091], [88.76166534, 22.02166939], [88.7611084, 22.02194405], [88.7611084, 22.02523994], [88.7611084, 22.02555656], [88.76083374, 22.02527809], [88.76083374, 22.02596092], [88.76082611, 22.02722168], [88.76055908, 22.02750015], [88.76055908, 22.02778053], [88.76027679, 22.02805519], [88.76055908, 22.02833176], [88.76055908, 22.02889061], [88.76027679, 22.02916908], [88.76027679, 22.02944374], [88.76000214, 22.02972221], [88.76000214, 22.03194237], [88.75888824, 22.03305435], [88.75904083, 22.03383446], [88.7591095, 22.0342617], [88.75917816, 22.03468895], [88.75932312, 22.03531265], [88.75911713, 22.03558159], [88.7588501, 22.03583908], [88.75856018, 22.03613091], [88.75829315, 22.03645134], [88.75804138, 22.03685951], [88.75776672, 22.03730965], [88.75749969, 22.03781319], [88.75722504, 22.0383358], [88.75694275, 22.03884315], [88.75666046, 22.03931236], [88.75637054, 22.03975105], [88.75610352, 22.04019737], [88.75592804, 22.04047775], [88.75582886, 22.04063034], [88.75557709, 22.04108238], [88.75541687, 22.04151917], [88.75528717, 22.04186821], [88.75517273, 22.04219246], [88.75502777, 22.04249191], [88.75495911, 22.04284286], [88.754776, 22.04316139], [88.7546463, 22.04356956], [88.75444031, 22.04400063], [88.75416565, 22.04447365], [88.75389099, 22.04499245], [88.7536087, 22.04553032], [88.75332642, 22.04606056], [88.7530899, 22.04655266], [88.75296021, 22.04705048], [88.75276184, 22.04743767], [88.75253296, 22.04778099], [88.75235748, 22.04818916], [88.75216675, 22.04859161], [88.75193787, 22.04900169], [88.75171661, 22.04943275], [88.75163269, 22.04992104], [88.7514267, 22.05033302], [88.75145721, 22.05069923], [88.7516098, 22.05101967], [88.75166321, 22.05137062], [88.75172424, 22.05169106], [88.75193787, 22.05194283], [88.75213623, 22.0522213], [88.75241089, 22.05248451], [88.75247955, 22.05255127], [88.75275421, 22.05275726], [88.75315094, 22.05304337], [88.75363922, 22.05328941], [88.75424957, 22.05338097], [88.75483704, 22.05355263], [88.75543213, 22.05361176], [88.75602722, 22.05361366], [88.7565918, 22.05358315], [88.75711823, 22.05344963], [88.75762939, 22.05331993], [88.75809479, 22.05316162], [88.75855255, 22.05302429], [88.75895691, 22.05282021], [88.75946045, 22.05273819], [88.75992584, 22.05255318], [88.76043701, 22.05246162], [88.76089478, 22.05226326], [88.76140594, 22.05216789], [88.76184082, 22.05199814], [88.76233673, 22.05194283], [88.7624588, 22.05192375], [88.76282501, 22.05186653], [88.76331329, 22.05171013], [88.7638092, 22.05167007]]], [[[88.81185913, 22.06075478], [88.81230164, 22.06065178], [88.81276703, 22.06077003], [88.81322479, 22.06079292], [88.8136673, 22.06074905], [88.81401062, 22.06084824], [88.81439972, 22.06102371], [88.81491852, 22.06111336], [88.81550598, 22.06121254], [88.81613922, 22.06135178], [88.81685638, 22.06139183], [88.81762695, 22.06138039], [88.81839752, 22.06129456], [88.81900787, 22.06094933], [88.81945801, 22.06036186], [88.81983185, 22.05974197], [88.82012177, 22.05916023], [88.82035828, 22.05866051], [88.8207016, 22.05833244], [88.8208313, 22.05833244], [88.82111359, 22.05805779], [88.82138062, 22.0580616], [88.8216629, 22.05778313], [88.82195282, 22.05778313], [88.82250214, 22.05722237], [88.82277679, 22.05722237], [88.82416534, 22.05583382], [88.82444763, 22.05583382], [88.82472229, 22.05555534], [88.82525635, 22.05527115], [88.825737, 22.05496025], [88.82620239, 22.05461311], [88.82656097, 22.05427551], [88.82692719, 22.05396271], [88.8273468, 22.05372047], [88.8277359, 22.053442], [88.82805634, 22.05310249], [88.8283844, 22.0527935], [88.82870483, 22.05251884], [88.82901764, 22.05225945], [88.82935333, 22.05201721], [88.8296814, 22.05173302], [88.8300705, 22.0514431], [88.83052826, 22.05113029], [88.83101654, 22.05075073], [88.83142853, 22.05024147], [88.83174133, 22.04969406], [88.83187866, 22.04913139], [88.83178711, 22.04860306], [88.83163452, 22.04811668], [88.83139801, 22.04770088], [88.83114624, 22.04726982], [88.83085632, 22.04681969], [88.83059692, 22.04631233], [88.83039093, 22.04579544], [88.83023071, 22.04528999], [88.82993317, 22.04488945], [88.83027649, 22.0447216], [88.83027649, 22.04389], [88.83027649, 22.04335976], [88.83029175, 22.04290009], [88.83036041, 22.04244804], [88.830513, 22.04203224], [88.83055115, 22.04159737], [88.83056641, 22.0411396], [88.83056641, 22.04067993], [88.83062744, 22.04024315], [88.83079529, 22.03988457], [88.83087921, 22.0395031], [88.83106232, 22.03916931], [88.83110809, 22.03878975], [88.83110809, 22.0383625], [88.83111572, 22.03791428], [88.83114624, 22.03746223], [88.83128357, 22.03702927], [88.83138275, 22.03659821], [88.83144379, 22.0361557], [88.83161926, 22.03573036], [88.8316803, 22.03520012], [88.83177948, 22.0346508], [88.8319397, 22.03418159], [88.83210754, 22.03371239], [88.83220673, 22.03318405], [88.83228302, 22.03257942], [88.83245087, 22.03193665], [88.83249664, 22.03120995], [88.83255005, 22.03049469], [88.8327179, 22.02983856], [88.8327713, 22.0291996], [88.83275604, 22.02858925], [88.83261871, 22.0280323], [88.83246613, 22.02752113], [88.83220673, 22.02717018], [88.8318634, 22.02697563], [88.83138275, 22.02693939], [88.83084869, 22.02694321], [88.83030701, 22.02697182], [88.82981873, 22.02711487], [88.82933044, 22.02716064], [88.82909393, 22.02707863], [88.82885742, 22.0269928], [88.82836914, 22.02696037], [88.82789612, 22.02702141], [88.82740021, 22.02700233], [88.82691956, 22.02718163], [88.82643127, 22.02722359], [88.82594299, 22.02722359], [88.82544708, 22.02722359], [88.82495117, 22.02722359], [88.82444763, 22.02722359], [88.82393646, 22.02722359], [88.82343292, 22.02722359], [88.82293701, 22.02719879], [88.82247925, 22.02705956], [88.82200623, 22.02696037], [88.82151794, 22.02692986], [88.82102203, 22.02684212], [88.82052612, 22.02669334], [88.81997681, 22.02667046], [88.81941223, 22.02665138], [88.81882477, 22.02663422], [88.81827545, 22.02647972], [88.81774139, 22.02635765], [88.81732178, 22.02615166], [88.81685638, 22.02602196], [88.81639862, 22.02586174], [88.81587219, 22.02579308], [88.81536102, 22.02556801], [88.81479645, 22.02536011], [88.81420898, 22.02519417], [88.81365967, 22.02505302], [88.8131485, 22.02514076], [88.81295013, 22.02525139], [88.81278992, 22.02544975], [88.81265259, 22.02584648], [88.81252289, 22.02639008], [88.81240845, 22.02701187], [88.81221008, 22.0275631], [88.8119812, 22.02802086], [88.81175995, 22.0284214], [88.81165314, 22.02887154], [88.81150055, 22.02934456], [88.81138611, 22.02971268], [88.81138611, 22.03000069], [88.81111145, 22.03028488], [88.81083679, 22.03028488], [88.81054688, 22.03056145], [88.81027985, 22.03055763], [88.81019592, 22.03073692], [88.80992126, 22.0308094], [88.80961609, 22.0309391], [88.80931854, 22.03112984], [88.80902863, 22.03138924], [88.80870056, 22.0316658], [88.80832672, 22.03194427], [88.80789185, 22.03222656], [88.80741882, 22.03250313], [88.8068924, 22.0327816], [88.80636597, 22.03305244], [88.80584717, 22.03328133], [88.80531311, 22.03337288], [88.80484009, 22.03355217], [88.80434418, 22.03360939], [88.80384064, 22.0336132], [88.80331421, 22.0336132], [88.80277252, 22.0336132], [88.80220795, 22.0336132], [88.80163574, 22.0336132], [88.80105591, 22.0336132], [88.80047607, 22.03360176], [88.79994965, 22.0335331], [88.79953003, 22.03334236], [88.79914856, 22.03316689], [88.79879761, 22.03302193], [88.79853058, 22.03282738], [88.79821777, 22.03265953], [88.79781342, 22.03248215], [88.79734039, 22.03222084], [88.79680634, 22.03194237], [88.79627991, 22.03165627], [88.79582214, 22.03137016], [88.79541779, 22.03114891], [88.79499054, 22.03106117], [88.79466248, 22.03088951], [88.7943573, 22.0309391], [88.7940979, 22.03107834], [88.79383087, 22.03114128], [88.79359436, 22.03126526], [88.7933197, 22.03147316], [88.79296112, 22.03176308], [88.79257965, 22.03215218], [88.79223633, 22.0325985], [88.79191589, 22.03311157], [88.79151917, 22.03360176], [88.79107666, 22.03407288], [88.7906189, 22.03447151], [88.79016876, 22.03480721], [88.78966522, 22.03502464], [88.78925323, 22.03528023], [88.78887939, 22.03555107], [88.78849792, 22.0357933], [88.78806305, 22.03595924], [88.78762817, 22.03611565], [88.78720856, 22.03626633], [88.78679657, 22.0363903], [88.78639221, 22.03652954], [88.7859726, 22.03664207], [88.7855072, 22.03666878], [88.78501892, 22.03670311], [88.78453827, 22.03689194], [88.78401947, 22.03694725], [88.78347778, 22.0370121], [88.78296661, 22.03718758], [88.78243256, 22.03722191], [88.78189087, 22.03722191], [88.78136444, 22.03723717], [88.78087616, 22.03733444], [88.78045654, 22.03753471], [88.780159, 22.03783226], [88.78002167, 22.0382328], [88.77999878, 22.03870964], [88.77999878, 22.03921318], [88.77999878, 22.03973007], [88.78000641, 22.04026222], [88.78009033, 22.04079247], [88.7802887, 22.04125023], [88.78053284, 22.04169846], [88.78069305, 22.04219818], [88.78083801, 22.04267311], [88.78099823, 22.04307747], [88.7811203, 22.0434494], [88.78127289, 22.04377174], [88.78142548, 22.04403877], [88.78164673, 22.04424667], [88.78185272, 22.0444622], [88.78204346, 22.04471779], [88.78227234, 22.04498291], [88.78256989, 22.04525948], [88.7829361, 22.04554939], [88.78336334, 22.04584312], [88.78378296, 22.04614067], [88.78413391, 22.04649544], [88.78440857, 22.04689217], [88.78465271, 22.04731178], [88.78482819, 22.04777336], [88.78502655, 22.04827309], [88.78528595, 22.04879951], [88.78555298, 22.0493412], [88.78578949, 22.04990959], [88.78583527, 22.05055809], [88.78583527, 22.0511837], [88.7858429, 22.05175018], [88.78588867, 22.05224037], [88.78607178, 22.05262184], [88.78610992, 22.05297852], [88.78610992, 22.05331993], [88.78614044, 22.05363655], [88.78626251, 22.05391121], [88.78636932, 22.05421829], [88.78642273, 22.05457497], [88.78658295, 22.05494118], [88.78665924, 22.05537987], [88.78666687, 22.05585289], [88.78666687, 22.05631828], [88.78668976, 22.05678368], [88.78679657, 22.05721474], [88.78691864, 22.05764961], [88.7869873, 22.05813789], [88.78718567, 22.05864143], [88.78729248, 22.05920219], [88.78757477, 22.05962944], [88.78800964, 22.05988503], [88.78849792, 22.0597744], [88.78887939, 22.05938721], [88.78916931, 22.0589695], [88.78939819, 22.05859375], [88.78948975, 22.05812645], [88.78968811, 22.05772209], [88.78981018, 22.05730247], [88.79001617, 22.05695152], [88.79026794, 22.05661964], [88.79055023, 22.05628014], [88.79083252, 22.05593681], [88.79112244, 22.05559731], [88.79141998, 22.05529213], [88.7917099, 22.05503273], [88.79203033, 22.05482864], [88.79242706, 22.05468941], [88.79285431, 22.0545311], [88.79335785, 22.05439949], [88.79389954, 22.05424118], [88.79447174, 22.05424118], [88.79499054, 22.05439758], [88.79551697, 22.05449104], [88.79602051, 22.0547123], [88.79658508, 22.05488777], [88.79724121, 22.05498314], [88.79794312, 22.05507278], [88.79856873, 22.05529213], [88.79914856, 22.05555534], [88.79970551, 22.05583382], [88.80023956, 22.05611229], [88.80072021, 22.05640984], [88.80108643, 22.05677223], [88.80137634, 22.05717278], [88.80162811, 22.05759239], [88.80184174, 22.05803871], [88.80209351, 22.05849457], [88.80233765, 22.05903053], [88.80252838, 22.05971336], [88.80278015, 22.06038475], [88.80305481, 22.06103134], [88.80332184, 22.06163979], [88.80349731, 22.06224251], [88.80348969, 22.06284142], [88.80368805, 22.06337166], [88.80404663, 22.06377983], [88.80448914, 22.06413078], [88.80509186, 22.06433105], [88.80570984, 22.06438255], [88.80632019, 22.06417274], [88.80692291, 22.06389046], [88.80750275, 22.06349182], [88.80802917, 22.06304932], [88.80853271, 22.06260109], [88.80903625, 22.06224251], [88.80951691, 22.06194115], [88.80995178, 22.06166267], [88.81033325, 22.06139183], [88.81069183, 22.06115913], [88.8110733, 22.06100273], [88.81143951, 22.06084824], [88.81185913, 22.06075478]]], [[[88.94996643, 22.18919182], [88.95066833, 22.18916893], [88.95139313, 22.18919182], [88.95210266, 22.18923187], [88.95275879, 22.18939018], [88.95336151, 22.18941307], [88.95385742, 22.18946266], [88.95427704, 22.18956184], [88.95471191, 22.18968773], [88.95522308, 22.18973732], [88.95574188, 22.18981171], [88.95623779, 22.18995094], [88.95674133, 22.19000053], [88.9572525, 22.1900425], [88.95773315, 22.1901226], [88.95820618, 22.1902523], [88.95868683, 22.19028473], [88.95915222, 22.19022942], [88.95957947, 22.19000053], [88.9599762, 22.18975258], [88.96035767, 22.18955421], [88.96066284, 22.18935204], [88.96089172, 22.18912315], [88.96102905, 22.18886757], [88.96115112, 22.18858719], [88.96131134, 22.18836021], [88.96138763, 22.1880703], [88.96144867, 22.18775749], [88.96161652, 22.18747139], [88.96173096, 22.1870842], [88.9618988, 22.18666077], [88.96195221, 22.18612289], [88.96199799, 22.18558311], [88.96216583, 22.18513298], [88.96224976, 22.18469048], [88.96235657, 22.18430138], [88.96247101, 22.18391037], [88.96250916, 22.18346977], [88.96256256, 22.18301964], [88.96269989, 22.18258095], [88.96277618, 22.18208122], [88.9628067, 22.18156052], [88.9629364, 22.18108368], [88.96305847, 22.18058014], [88.96322632, 22.18012047], [88.96338654, 22.17967033], [88.96359253, 22.17925072], [88.96375275, 22.17883873], [88.96391296, 22.17842293], [88.96412659, 22.17806053], [88.96424103, 22.17762947], [88.96440887, 22.17724037], [88.9644928, 22.17679024], [88.9646759, 22.17635155], [88.96473694, 22.17583275], [88.96483612, 22.17533302], [88.96499634, 22.1748848], [88.96517944, 22.17451286], [88.96529388, 22.17413139], [88.96541595, 22.17380905], [88.9655304, 22.17350197], [88.96560669, 22.17318916], [88.96570587, 22.17289162], [88.96581268, 22.17256927], [88.96588898, 22.1722126], [88.96607971, 22.17187309], [88.96620941, 22.17141533], [88.96639252, 22.17089272], [88.9666214, 22.17033958], [88.96691132, 22.16983795], [88.96720886, 22.16936493], [88.96747589, 22.16890144], [88.96769714, 22.16841316], [88.96792603, 22.16790962], [88.96819305, 22.16737747], [88.96853638, 22.16687584], [88.96882629, 22.16629028], [88.96911621, 22.16567039], [88.96940613, 22.16507149], [88.96977234, 22.16456032], [88.97012329, 22.16415024], [88.97039032, 22.16376686], [88.97059631, 22.16340065], [88.97077179, 22.1631031], [88.97091675, 22.16282082], [88.97113037, 22.16259956], [88.97133636, 22.16238213], [88.97151947, 22.16208267], [88.97174072, 22.16173172], [88.97206879, 22.1613903], [88.97244263, 22.16101265], [88.97277069, 22.16057777], [88.97312927, 22.16021156], [88.97344208, 22.15987587], [88.97364807, 22.15953445], [88.97383118, 22.15921974], [88.97400665, 22.15891075], [88.97423553, 22.15863228], [88.97452545, 22.15835381], [88.97488403, 22.15805817], [88.97528839, 22.15773964], [88.97569275, 22.15735626], [88.97608948, 22.15697289], [88.97651672, 22.15665245], [88.97690582, 22.15632057], [88.97727203, 22.15599251], [88.97768402, 22.15576363], [88.97803497, 22.15546227], [88.97837067, 22.15510178], [88.97875214, 22.15475273], [88.9792099, 22.1544342], [88.97969055, 22.15409279], [88.98015594, 22.15372086], [88.98059845, 22.15332985], [88.98105621, 22.15296936], [88.98147583, 22.1525631], [88.98192596, 22.15219307], [88.98227692, 22.15175056], [88.98266602, 22.15137863], [88.98301697, 22.15100288], [88.98332977, 22.1506424], [88.98360443, 22.1502552], [88.98387146, 22.14985466], [88.98413086, 22.14946175], [88.98441315, 22.14914131], [88.98467255, 22.14883232], [88.98486328, 22.14848137], [88.98497772, 22.14812088], [88.98501587, 22.14772224], [88.98500824, 22.14731216], [88.98500061, 22.14688683], [88.98500061, 22.14645195], [88.98500061, 22.14599037], [88.98500061, 22.1455307], [88.98500061, 22.14506912], [88.98500061, 22.14460945], [88.98500061, 22.14415169], [88.98501587, 22.14372063], [88.98513031, 22.14334869], [88.98525238, 22.14301109], [88.9852829, 22.14262199], [88.98527527, 22.14222336], [88.9852829, 22.14181328], [88.98529053, 22.14141273], [88.9852829, 22.14101982], [88.98525238, 22.14063072], [88.98513794, 22.14025116], [88.98497009, 22.13983154], [88.98468018, 22.13940239], [88.98427582, 22.1389904], [88.98384857, 22.13861084], [88.98342133, 22.1382122], [88.98306274, 22.13777161], [88.98272705, 22.13733482], [88.98241425, 22.13694382], [88.98214722, 22.13656044], [88.98192596, 22.13614082], [88.98173523, 22.13573265], [88.98160553, 22.13525963], [88.98140717, 22.13478279], [88.98122406, 22.13426781], [88.98104095, 22.13372231], [88.98079681, 22.13323021], [88.98047638, 22.13286018], [88.98012543, 22.13263321], [88.97976685, 22.13251686], [88.97937775, 22.1325016], [88.97892761, 22.13259315], [88.97852325, 22.13286018], [88.97815704, 22.13323021], [88.97782135, 22.13359261], [88.97751617, 22.13393211], [88.97727203, 22.13427162], [88.97705078, 22.13462257], [88.97677612, 22.13498116], [88.97647095, 22.13536263], [88.97618866, 22.13581276], [88.97596741, 22.13634682], [88.97570801, 22.13686943], [88.97538757, 22.13735771], [88.97501373, 22.13776588], [88.97463989, 22.13814354], [88.97425842, 22.13850212], [88.97384644, 22.13883018], [88.97338867, 22.13916969], [88.97294617, 22.13958168], [88.97254944, 22.14003181], [88.97212219, 22.14046288], [88.97164917, 22.1408329], [88.97120667, 22.14116287], [88.97078705, 22.14147568], [88.97045135, 22.14180946], [88.97020721, 22.14217186], [88.96998596, 22.14252281], [88.96977997, 22.14289474], [88.96963501, 22.14332771], [88.96954346, 22.14379311], [88.96955872, 22.14428139], [88.96960449, 22.14476585], [88.96961975, 22.14526176], [88.96959686, 22.14576149], [88.96952057, 22.14626122], [88.96940613, 22.14672852], [88.96928406, 22.14717674], [88.96923065, 22.14763069], [88.96920013, 22.14808083], [88.96907043, 22.1484623], [88.96894836, 22.1488018], [88.9688797, 22.14912987], [88.96890259, 22.14946175], [88.96896362, 22.149786], [88.96909332, 22.15010834], [88.96920776, 22.15045929], [88.96936798, 22.1508007], [88.96952057, 22.15117836], [88.96973419, 22.15157509], [88.96998596, 22.15202522], [88.97027588, 22.15255356], [88.9705658, 22.15313148], [88.97080994, 22.15373039], [88.97087097, 22.15433311], [88.97080231, 22.15487099], [88.97067261, 22.15534019], [88.97051239, 22.15572166], [88.97029877, 22.15603256], [88.97003174, 22.1563015], [88.96967316, 22.15652275], [88.96924591, 22.15670395], [88.96880341, 22.15686989], [88.96828461, 22.15696526], [88.96778107, 22.15694618], [88.96729279, 22.15693855], [88.96681976, 22.15697289], [88.966362, 22.15709496], [88.96592712, 22.15728188], [88.96556091, 22.15757942], [88.965271, 22.15799141], [88.96501923, 22.15845108], [88.96478271, 22.1589222], [88.96450043, 22.15936089], [88.96414948, 22.15972137], [88.96372223, 22.16000938], [88.9631958, 22.16013908], [88.96261597, 22.16015434], [88.96222687, 22.16009712], [88.96203613, 22.16006851], [88.96156311, 22.15994263], [88.96118927, 22.15979195], [88.96082306, 22.1596508], [88.96042633, 22.15947151], [88.95999146, 22.15929985], [88.9595871, 22.15906143], [88.95921326, 22.15880394], [88.95883179, 22.15857315], [88.95845795, 22.15836334], [88.95809174, 22.15821266], [88.9577713, 22.15806961], [88.95746613, 22.158041], [88.95716095, 22.15809059], [88.95688629, 22.15809059], [88.95662689, 22.15799141], [88.95630646, 22.15791512], [88.95594788, 22.15781212], [88.95555115, 22.15773392], [88.95513916, 22.1577549], [88.95472717, 22.15781975], [88.95432281, 22.15797806], [88.9539032, 22.15824318], [88.95345306, 22.15854073], [88.95304871, 22.15874672], [88.95275116, 22.15846825], [88.95311737, 22.15805817], [88.95333099, 22.15750313], [88.95361328, 22.15722084], [88.95388794, 22.15722466], [88.95420837, 22.15703773], [88.95475769, 22.15686989], [88.95542145, 22.15686226], [88.95607758, 22.15683556], [88.95669556, 22.15686226], [88.95728302, 22.15688133], [88.95780945, 22.15691566], [88.95829773, 22.1570549], [88.95874023, 22.15724182], [88.95915985, 22.1574688], [88.95956421, 22.15776253], [88.95999146, 22.15809441], [88.96044922, 22.15842056], [88.96094513, 22.15868568], [88.96147919, 22.15888023], [88.96211243, 22.1590023], [88.9628067, 22.15894127], [88.96340179, 22.15868187], [88.96383667, 22.15828133], [88.96414948, 22.15781212], [88.9644165, 22.15734291], [88.96470642, 22.15693092], [88.9650116, 22.15654945], [88.96534729, 22.15621185], [88.96578979, 22.15597343], [88.96629333, 22.15582848], [88.96679688, 22.15572166], [88.96730042, 22.15566063], [88.96779633, 22.15566063], [88.96829987, 22.15572166], [88.96875763, 22.1556797], [88.96909332, 22.15549278], [88.96930695, 22.15517044], [88.9694519, 22.15477371], [88.96949768, 22.15429115], [88.9694519, 22.15378189], [88.96929932, 22.1532917], [88.96911621, 22.15283012], [88.96884155, 22.15242958], [88.96852112, 22.15205956], [88.9682312, 22.15167046], [88.96795654, 22.1512928], [88.96775055, 22.15090561], [88.96759033, 22.15049934], [88.96755219, 22.1500721], [88.96761322, 22.14962959], [88.96762848, 22.14918327], [88.96762085, 22.14874077], [88.96770477, 22.14826965], [88.96788025, 22.14774132], [88.96801758, 22.14717484], [88.96814728, 22.14666939], [88.96826935, 22.14620972], [88.96835327, 22.14576149], [88.96839142, 22.14531136], [88.96839905, 22.14486122], [88.96839905, 22.14442253], [88.96839142, 22.1439724], [88.96843719, 22.14349174], [88.96852112, 22.14304543], [88.96859741, 22.14264107], [88.96868134, 22.1422596], [88.96885681, 22.14189911], [88.96909332, 22.14151382], [88.9694519, 22.14115524], [88.96990204, 22.14081192], [88.97038269, 22.14040947], [88.97088623, 22.13996315], [88.97142029, 22.13949013], [88.97198486, 22.1390419], [88.97252655, 22.1385746], [88.97305298, 22.13807106], [88.97357941, 22.13755035], [88.97408295, 22.13704491], [88.97447968, 22.13648033], [88.97483063, 22.13591957], [88.97515106, 22.13542557], [88.97545624, 22.13499069], [88.97572327, 22.13457298], [88.97601318, 22.13418007], [88.9763031, 22.13381195], [88.97657776, 22.13341713], [88.97682953, 22.13301468], [88.97705841, 22.13260078], [88.9773407, 22.13226128], [88.97762299, 22.13196182], [88.97793579, 22.13169479], [88.97826385, 22.13146782], [88.9786377, 22.13131142], [88.97902679, 22.13112068], [88.97941589, 22.13098145], [88.97982025, 22.13104057], [88.98017883, 22.1312561], [88.9805069, 22.13145256], [88.9808197, 22.13167953], [88.98113251, 22.13194084], [88.98144531, 22.1322155], [88.98175049, 22.13252449], [88.98200989, 22.13288307], [88.98221588, 22.13332176], [88.98239136, 22.1337738], [88.98256683, 22.13422203], [88.98277283, 22.13462257], [88.98294067, 22.1350193], [88.98309326, 22.13541985], [88.98324585, 22.13585091], [88.98342133, 22.1362896], [88.98365021, 22.1367321], [88.9839859, 22.13716316], [88.98443604, 22.13762283], [88.98490143, 22.13813972], [88.98522186, 22.1381321], [88.985466, 22.13786888], [88.98567963, 22.13755035], [88.98581696, 22.13720322], [88.98590851, 22.13680458], [88.9860611, 22.13640594], [88.98610687, 22.13595772], [88.98610687, 22.13549232], [88.9860611, 22.1350193], [88.98587799, 22.13457298], [88.98583221, 22.13410378], [88.98582458, 22.13356209], [88.98577118, 22.13294411], [88.98567963, 22.13227272], [88.98557281, 22.13161278], [88.98548126, 22.13099289], [88.98530579, 22.13047218], [88.98526764, 22.12997246], [88.98517609, 22.12949181], [88.98506165, 22.12898064], [88.98500824, 22.12837601], [88.98499298, 22.12774277], [88.98491669, 22.12712288], [88.98475647, 22.12657356], [88.98468018, 22.12604332], [88.98457336, 22.12553024], [88.98444366, 22.12500954], [88.98430634, 22.12446022], [88.98419189, 22.1239109], [88.98416901, 22.12333107], [88.98416901, 22.12305641], [88.98387909, 22.12278366], [88.98387909, 22.12167358], [88.98332977, 22.12111282], [88.98332977, 22.11889076], [88.98306274, 22.11861229], [88.98299408, 22.11802864], [88.98280334, 22.11763191], [88.9826355, 22.11721611], [88.98249054, 22.11678123], [88.98234558, 22.1163578], [88.98223114, 22.11590004], [88.98214722, 22.11543083], [88.98197937, 22.11503029], [88.98188782, 22.11460304], [88.98179626, 22.11421394], [88.98166656, 22.11384392], [88.98153687, 22.11348152], [88.98138428, 22.11313057], [88.9812088, 22.1127739], [88.98100281, 22.11237144], [88.98078156, 22.11194992], [88.98055267, 22.11151123], [88.98029327, 22.111063], [88.98005676, 22.11060143], [88.97992706, 22.11013031], [88.97972107, 22.10976982], [88.97949982, 22.10948563], [88.9793396, 22.10918999], [88.97918701, 22.10890579], [88.97905731, 22.10855484], [88.9788208, 22.1082325], [88.97860718, 22.10778999], [88.97834015, 22.10730362], [88.97805786, 22.10677147], [88.97777557, 22.10625648], [88.97750854, 22.10582161], [88.97728729, 22.10545158], [88.97718048, 22.10509109], [88.97705841, 22.1047802], [88.97690582, 22.10451317], [88.97672272, 22.1042614], [88.97663879, 22.10395241], [88.97647858, 22.10368156], [88.97636414, 22.10339165], [88.97621155, 22.10314178], [88.97609711, 22.1028614], [88.97593689, 22.10258865], [88.97580719, 22.10227585], [88.9756012, 22.10195923], [88.97544861, 22.1015625], [88.97525787, 22.10116768], [88.97503662, 22.10080338], [88.97490692, 22.10036278], [88.97470856, 22.09995842], [88.97444916, 22.09954262], [88.9741745, 22.09906006], [88.97389984, 22.09853363], [88.97366333, 22.09798622], [88.97349548, 22.09743309], [88.97333527, 22.09690285], [88.97318268, 22.0963707], [88.97305298, 22.09581184], [88.97286987, 22.09525108], [88.97270203, 22.09465027], [88.97252655, 22.09405899], [88.97239685, 22.09338951], [88.97223663, 22.09273338], [88.97209167, 22.09205818], [88.97189331, 22.09146309], [88.97168732, 22.09089088], [88.97155762, 22.09032249], [88.9713974, 22.08976173], [88.9712677, 22.0891819], [88.971138, 22.08860207], [88.97104645, 22.08799171], [88.97084045, 22.0874958], [88.97061157, 22.08702278], [88.97038269, 22.08653069], [88.97026825, 22.08586311], [88.97014618, 22.08517265], [88.96998596, 22.08457184], [88.96977997, 22.08402061], [88.96966553, 22.08350945], [88.96944427, 22.08312798], [88.9691925, 22.08282852], [88.96890259, 22.08261299], [88.96856689, 22.08244133], [88.96827698, 22.08226967], [88.96794128, 22.0823307], [88.96759033, 22.08267403], [88.96723938, 22.08307457], [88.96688843, 22.08355331], [88.96652222, 22.0840683], [88.96620941, 22.08462906], [88.96592712, 22.08514214], [88.96567535, 22.08555031], [88.96546173, 22.0859127], [88.96527863, 22.08624077], [88.96511078, 22.0865593], [88.96494293, 22.08687019], [88.96479034, 22.08718109], [88.96472931, 22.08755493], [88.96469116, 22.08793831], [88.9646759, 22.08833122], [88.96469116, 22.08875084], [88.96469116, 22.08918571], [88.96466827, 22.08964157], [88.96457672, 22.09009171], [88.96444702, 22.09050941], [88.96425629, 22.09094048], [88.96404266, 22.09143257], [88.96370697, 22.09196281], [88.96330261, 22.09250069], [88.9628067, 22.09301949], [88.96230316, 22.09350014], [88.9617691, 22.09390068], [88.96125031, 22.09428215], [88.96070099, 22.09461021], [88.96012115, 22.09488106], [88.9595108, 22.09507942], [88.9589386, 22.09530067], [88.95842743, 22.09557152], [88.95796967, 22.09588051], [88.95757294, 22.09625626], [88.9572525, 22.09669304], [88.95697021, 22.09716225], [88.95677948, 22.09762764], [88.95668793, 22.09810448], [88.95666504, 22.09857368], [88.95666504, 22.09902763], [88.95667267, 22.09948158], [88.95664215, 22.09993744], [88.95656586, 22.10040092], [88.9564209, 22.1008625], [88.95623016, 22.10133171], [88.95597839, 22.1017704], [88.95562744, 22.10214043], [88.95519257, 22.10244942], [88.95466614, 22.10266113], [88.95411682, 22.10281944], [88.95362091, 22.1029377], [88.95317078, 22.10302162], [88.95276642, 22.1031208], [88.95246887, 22.10323143], [88.95200348, 22.10332298], [88.95192719, 22.10353279], [88.95178986, 22.10367966], [88.95179749, 22.10402489], [88.95187378, 22.1042347], [88.95207977, 22.10472298], [88.95166779, 22.10527992], [88.95054626, 22.10416985], [88.95069885, 22.10368156], [88.95111084, 22.10305977], [88.95111084, 22.1027813], [88.95173645, 22.10249138], [88.95240784, 22.10220146], [88.95303345, 22.10206795], [88.9536972, 22.1019249], [88.95433807, 22.10170364], [88.95485687, 22.10135269], [88.95522308, 22.10090446], [88.95543671, 22.10042381], [88.95553589, 22.09994888], [88.95555878, 22.09949112], [88.95553589, 22.09904289], [88.95549774, 22.09862137], [88.95537567, 22.09821892], [88.95513916, 22.09795189], [88.95503998, 22.09757042], [88.95500183, 22.09722328], [88.95541382, 22.09666634], [88.95555878, 22.09639168], [88.95639038, 22.09556007], [88.95688629, 22.09525108], [88.9573288, 22.09488106], [88.95776367, 22.09453011], [88.95822144, 22.09427071], [88.95871735, 22.09407234], [88.95923615, 22.09388161], [88.95976257, 22.09367943], [88.96026611, 22.09347153], [88.96074677, 22.09324074], [88.9611969, 22.09295082], [88.9616394, 22.09264183], [88.9620285, 22.09230614], [88.96240234, 22.09198189], [88.9627533, 22.09166145], [88.96302032, 22.09130287], [88.9631958, 22.09089088], [88.96331024, 22.09045219], [88.96334839, 22.08995247], [88.96336365, 22.08940697], [88.96334839, 22.08884239], [88.96337891, 22.08826256], [88.96341705, 22.08769035], [88.96356964, 22.08715248], [88.96369934, 22.08661079], [88.96391296, 22.08614159], [88.9641571, 22.08572197], [88.96443176, 22.08529091], [88.96472931, 22.08485794], [88.96502686, 22.08440208], [88.96534729, 22.08394241], [88.96566772, 22.08350182], [88.96594238, 22.0830822], [88.96621704, 22.08268166], [88.96649933, 22.08231163], [88.96681976, 22.08198738], [88.96716309, 22.08166695], [88.96749878, 22.08000183], [88.96721649, 22.07972145], [88.96722412, 22.07944679], [88.96694183, 22.07916832], [88.96694183, 22.07861137], [88.96611023, 22.07777977], [88.9658432, 22.07777977], [88.96537018, 22.07722855], [88.96485901, 22.07681084], [88.96437073, 22.07641029], [88.96386719, 22.0761013], [88.96334839, 22.07583046], [88.962883, 22.07555962], [88.96237946, 22.07531357], [88.96182251, 22.07516289], [88.96128082, 22.07497406], [88.96079254, 22.07473183], [88.96031189, 22.07450485], [88.95983887, 22.07430077], [88.95934296, 22.07418823], [88.95887756, 22.07410812], [88.95846558, 22.07393265], [88.95800018, 22.07388878], [88.95749664, 22.07383156], [88.95697784, 22.07365799], [88.95638275, 22.07361031], [88.95574188, 22.07361031], [88.95510101, 22.07361031], [88.95448303, 22.07361031], [88.95385742, 22.07361031], [88.95322418, 22.07361031], [88.95259094, 22.07361031], [88.95127869, 22.07361031], [88.95063782, 22.07361031], [88.94999695, 22.07361031], [88.9493866, 22.07361031], [88.94882965, 22.07362175], [88.94832611, 22.07366753], [88.94787598, 22.07383156], [88.94742584, 22.07389259], [88.94695282, 22.07389259], [88.94645691, 22.07389259], [88.94597626, 22.07389259], [88.94548798, 22.07389259], [88.94499969, 22.07389259], [88.94452667, 22.07386971], [88.94406891, 22.07377815], [88.94361877, 22.07364082], [88.94315338, 22.07361221], [88.94268799, 22.07361031], [88.94225311, 22.07359123], [88.94180298, 22.07348061], [88.94136047, 22.07339478], [88.94091034, 22.07345009], [88.94042969, 22.07338142], [88.93992615, 22.07332039], [88.93945313, 22.07320213], [88.93900299, 22.07307625], [88.93858337, 22.07299232], [88.93819427, 22.07281876], [88.93778992, 22.07275963], [88.9373703, 22.07265282], [88.93694305, 22.07250023], [88.9366684, 22.07250023], [88.93638611, 22.07222176], [88.93611145, 22.07222176], [88.9355545, 22.07166862], [88.93527985, 22.07167244], [88.93499756, 22.07139015], [88.93444824, 22.07137108], [88.93398285, 22.07111168], [88.93352509, 22.07083702], [88.93305969, 22.07056236], [88.93258667, 22.07028008], [88.93213654, 22.06999016], [88.93171692, 22.0696888], [88.93131256, 22.06937981], [88.93087769, 22.06913185], [88.93045807, 22.06889153], [88.93004608, 22.0686779], [88.92964172, 22.0685215], [88.9292984, 22.06831169], [88.92901611, 22.06802177], [88.92875671, 22.06768036], [88.9283905, 22.06741142], [88.92803192, 22.0670929], [88.92762756, 22.0668087], [88.92720795, 22.06655312], [88.92678833, 22.06635284], [88.92642212, 22.06611824], [88.92602539, 22.06591606], [88.92553711, 22.06575203], [88.92504883, 22.06525993], [88.92463684, 22.06459236], [88.92456818, 22.06402397], [88.92466736, 22.06358337], [88.92460632, 22.06323051], [88.92443085, 22.06287193], [88.92420197, 22.06247139], [88.92404175, 22.06197166], [88.92385101, 22.06147194], [88.92360687, 22.06100082], [88.92336273, 22.06051064], [88.923172, 22.0599556], [88.92302704, 22.05935287], [88.92282104, 22.05874062], [88.92267609, 22.05809212], [88.92249298, 22.05746269], [88.92230988, 22.05685234], [88.92218781, 22.05623055], [88.92202759, 22.05562019], [88.92195129, 22.05494308], [88.92191315, 22.05426216], [88.92185974, 22.05362892], [88.92179871, 22.05303955], [88.92169189, 22.05238152], [88.92172241, 22.05171013], [88.92189026, 22.05101967], [88.92193604, 22.05027962], [88.92194366, 22.0495491], [88.92195129, 22.04887199], [88.92195129, 22.04827309], [88.92193604, 22.04771805], [88.92193604, 22.04718018], [88.92197418, 22.0466938], [88.92209625, 22.04626656], [88.92220306, 22.0458889], [88.92222595, 22.04552269], [88.92222595, 22.04514694], [88.92222595, 22.04473305], [88.92227173, 22.04429054], [88.92238617, 22.04388237], [88.92250061, 22.04347801], [88.92259979, 22.04306984], [88.9227066, 22.04265976], [88.92277527, 22.04236794], [88.92281342, 22.04220581], [88.92299652, 22.04173279], [88.92304993, 22.04115105], [88.92307281, 22.04050255], [88.92312622, 22.0398407], [88.92328644, 22.03922081], [88.92336273, 22.03859138], [88.92352295, 22.03797913], [88.92359924, 22.03732109], [88.92365265, 22.0366497], [88.92384338, 22.0360508], [88.92388916, 22.03548241], [88.92388916, 22.03494835], [88.92388916, 22.03445244], [88.92388916, 22.03396034], [88.9239502, 22.03348732], [88.92415619, 22.03304291], [88.92430115, 22.03255272], [88.92420197, 22.03204155], [88.92414093, 22.03150368], [88.92406464, 22.03096581], [88.92399597, 22.03045082], [88.92392731, 22.0299511], [88.92391205, 22.02951622], [88.92392731, 22.02911949], [88.92399597, 22.02871132], [88.9241333, 22.02816391], [88.92416382, 22.02755547], [88.92415619, 22.02692986], [88.92411804, 22.0263195], [88.92411041, 22.0257225], [88.92397308, 22.02517891], [88.92388916, 22.02467346], [88.92394257, 22.02420235], [88.9241333, 22.02382088], [88.92427063, 22.0234127], [88.9243927, 22.02299309], [88.92449188, 22.02255058], [88.92461395, 22.02213478], [88.92475128, 22.02171326], [88.92494965, 22.02132225], [88.92500305, 22.02085304], [88.92504883, 22.02037239], [88.92516327, 22.01990128], [88.92527771, 22.01940918], [88.92539978, 22.01889992], [88.92555237, 22.01839447], [88.92567444, 22.01790428], [88.92577362, 22.01746559], [88.92584229, 22.01707268], [88.92591858, 22.0167408], [88.92606354, 22.01647568], [88.92610168, 22.01615906], [88.92611694, 22.01584053], [88.92617035, 22.01553154], [88.92634583, 22.01523018], [88.92644501, 22.01488113], [88.92661285, 22.01454353], [88.92671204, 22.0141201], [88.9269104, 22.01374245], [88.92708588, 22.01330757], [88.92723083, 22.0128231], [88.92739868, 22.01233101], [88.9274826, 22.0118618], [88.92752075, 22.01141357], [88.9276123, 22.01101685], [88.927742, 22.01065445], [88.92778778, 22.01020813], [88.92784119, 22.00975227], [88.927948, 22.00926208], [88.92807007, 22.00875664], [88.92823792, 22.00827789], [88.9283371, 22.0078125], [88.92845154, 22.00741005], [88.92856598, 22.00706863], [88.92862701, 22.00671959], [88.9287262, 22.00641823], [88.92884827, 22.00614738], [88.92888641, 22.00583076], [88.92896271, 22.0055027], [88.9291687, 22.00515175], [88.92938232, 22.00473213], [88.92949677, 22.00415039], [88.92973328, 22.00360107], [88.93000031, 22.00309181], [88.93026733, 22.00264168], [88.93052673, 22.00225258], [88.93071747, 22.00192451], [88.93083954, 22.00161552], [88.93094635, 22.00132942], [88.93106079, 22.00093269], [88.93110657, 22.00000191], [88.93253326, 22.00000191], [88.94393158, 22.00000191], [88.94610596, 22.00000191], [88.94638824, 22.00028038], [88.94638824, 22.00083351], [88.94610596, 22.00111008], [88.94611359, 22.00166893], [88.9458313, 22.00194359], [88.94610596, 22.00222206], [88.94610596, 22.00361061], [88.94638824, 22.00389481], [88.94638824, 22.00417137], [88.94555664, 22.00500488], [88.94499969, 22.00500488], [88.94499969, 22.00528145], [88.94416809, 22.00611305], [88.94416809, 22.00639153], [88.94393921, 22.006567], [88.94384003, 22.00664139], [88.94371033, 22.00684929], [88.94351959, 22.00719261], [88.94328308, 22.00757027], [88.94304657, 22.00806236], [88.94278717, 22.00861168], [88.94249725, 22.00913048], [88.94213867, 22.00952911], [88.94180298, 22.0098896], [88.94152832, 22.01032066], [88.94129944, 22.01080894], [88.94104004, 22.01128387], [88.94072723, 22.01166916], [88.94048309, 22.01202965], [88.94028473, 22.0123806], [88.94011688, 22.01271439], [88.93988037, 22.01299286], [88.93969727, 22.01334381], [88.93956757, 22.01375008], [88.93939209, 22.01410294], [88.93916321, 22.01441002], [88.93891907, 22.01473045], [88.93869781, 22.01511192], [88.9385376, 22.01558113], [88.93823242, 22.01589775], [88.93800354, 22.01626587], [88.93785858, 22.01667213], [88.93772125, 22.01709938], [88.93753052, 22.01751137], [88.93740082, 22.01801109], [88.93721771, 22.01851082], [88.93701935, 22.01903343], [88.93690491, 22.01961136], [88.93669891, 22.0200882], [88.9365921, 22.02060127], [88.936409, 22.02103996], [88.93637085, 22.02150154], [88.93625641, 22.0219326], [88.93611908, 22.02235985], [88.93611145, 22.02277946], [88.93611145, 22.0233326], [88.93583679, 22.02361107], [88.93582916, 22.02471924], [88.9355545, 22.02499962], [88.9355545, 22.02555656], [88.93527985, 22.02583504], [88.93530273, 22.02611351], [88.93528748, 22.02631187], [88.93527985, 22.02645302], [88.93522644, 22.02703476], [88.93504333, 22.02752876], [88.93499756, 22.02799225], [88.93499756, 22.02843285], [88.93499756, 22.02888107], [88.93499756, 22.02934074], [88.93499756, 22.02980232], [88.93502808, 22.03025246], [88.93508911, 22.03050041], [88.93512726, 22.0306797], [88.93521118, 22.03112221], [88.93509674, 22.03160286], [88.93501282, 22.0321312], [88.93499756, 22.03272057], [88.9349823, 22.03334045], [88.93492889, 22.03375053], [88.93489838, 22.03397751], [88.93474579, 22.03461266], [88.9347229, 22.03526115], [88.93470764, 22.03591919], [88.93463898, 22.03655052], [88.93451691, 22.03714943], [88.93461609, 22.03769112], [88.93465424, 22.03820229], [88.93448639, 22.03867149], [88.93444824, 22.03916931], [88.93444061, 22.0396843], [88.93444061, 22.04018402], [88.93444824, 22.04065132], [88.93444824, 22.04108238], [88.93444824, 22.04252243], [88.93444824, 22.04293251], [88.93444824, 22.04341316], [88.93444061, 22.04389], [88.93440247, 22.0444088], [88.93424225, 22.04493141], [88.93416595, 22.04554367], [88.93421173, 22.04615784], [88.93438721, 22.0467205], [88.93440247, 22.04726028], [88.93424225, 22.04774284], [88.93417358, 22.04822159], [88.93416595, 22.04870415], [88.93416595, 22.0491848], [88.93416595, 22.04964256], [88.93416595, 22.05007935], [88.93416595, 22.05050087], [88.93416595, 22.05092049], [88.93416595, 22.05135155], [88.93419647, 22.05178261], [88.93435669, 22.05218315], [88.93443298, 22.0526104], [88.93444824, 22.05307961], [88.93448639, 22.05356026], [88.93465424, 22.054039], [88.93473816, 22.05459023], [88.93486023, 22.05513954], [88.93502808, 22.05566216], [88.93527985, 22.05611229], [88.93554687, 22.05653954], [88.93579865, 22.05697441], [88.93604279, 22.05743217], [88.93625641, 22.05790901], [88.93638611, 22.05833244], [88.93722534, 22.05916786], [88.93722534, 22.05944443], [88.9375, 22.05972099], [88.9375, 22.06001091], [88.93776703, 22.06028175], [88.93776703, 22.06056023], [88.9378891, 22.06052017], [88.9382019, 22.06097221], [88.93856812, 22.0614109], [88.93897247, 22.06179237], [88.93950653, 22.06197166], [88.94004822, 22.06217957], [88.94065857, 22.06222916], [88.94123077, 22.06221962], [88.94180298, 22.0621624], [88.94233704, 22.06199074], [88.94293976, 22.0619812], [88.94355774, 22.06205368], [88.94417572, 22.06209373], [88.9447937, 22.06207657], [88.94541168, 22.06200409], [88.94603729, 22.06191063], [88.9466629, 22.06181145], [88.94728088, 22.06171227], [88.94790649, 22.06161308], [88.94853973, 22.06147194], [88.94916534, 22.06121254], [88.9497757, 22.06073952], [88.95040131, 22.06059265], [88.95101166, 22.06056023], [88.95162201, 22.0605526], [88.95222473, 22.06051254], [88.95282745, 22.06032372], [88.95349121, 22.0602417], [88.95413971, 22.06007957], [88.9548111, 22.06012154], [88.95548248, 22.06025124], [88.95614624, 22.06028175], [88.95681, 22.06028175], [88.9574585, 22.06028175], [88.95807648, 22.0602417], [88.95862579, 22.06005478], [88.9591217, 22.05981827], [88.95951843, 22.05948067], [88.9598999, 22.05916405], [88.96009827, 22.05899048], [88.96025085, 22.05885124], [88.96057129, 22.05856133], [88.96092224, 22.05833244], [88.96131134, 22.05815315], [88.96179962, 22.05805206], [88.96231842, 22.05793953], [88.9628067, 22.05772972], [88.96325684, 22.05741119], [88.96363831, 22.05699158], [88.96395111, 22.0565815], [88.96409607, 22.05618286], [88.96398926, 22.05582237], [88.96380615, 22.05550194], [88.96356201, 22.05523109], [88.96324921, 22.05499268], [88.96287537, 22.05472755], [88.96240234, 22.0544529], [88.96185303, 22.05415154], [88.96131134, 22.0537796], [88.96089172, 22.0533123], [88.96055603, 22.05282021], [88.960289, 22.05239487], [88.96013641, 22.05200958], [88.96024323, 22.05162239], [88.96031952, 22.05115318], [88.96054077, 22.05065727], [88.96077728, 22.05007935], [88.96111298, 22.04953194], [88.96146393, 22.04899788], [88.96190643, 22.04858208], [88.96234894, 22.04822159], [88.96277618, 22.04791069], [88.9631958, 22.04762077], [88.96360016, 22.04731941], [88.96398926, 22.0470047], [88.9644165, 22.04673958], [88.96482086, 22.0464325], [88.96523285, 22.04615021], [88.96559906, 22.04585075], [88.96595764, 22.04556084], [88.96630096, 22.04527092], [88.96663666, 22.04498482], [88.96697998, 22.04469872], [88.96734619, 22.04443359], [88.96770477, 22.04413414], [88.96804047, 22.04380035], [88.96837616, 22.04346275], [88.96877289, 22.04318047], [88.9691925, 22.04292107], [88.9696579, 22.04270172], [88.97006989, 22.04241943], [88.97042084, 22.04207802], [88.97078705, 22.04173279], [88.97117615, 22.04142189], [88.97162628, 22.0411396], [88.97206116, 22.0408802], [88.97254181, 22.04068184], [88.97306824, 22.04052162], [88.97357178, 22.0402813], [88.97409821, 22.04005814], [88.97467041, 22.03989983], [88.97524261, 22.03970718], [88.97579956, 22.0394516], [88.97634125, 22.03915977], [88.97680664, 22.0388279], [88.97709656, 22.03839302], [88.97705841, 22.03790092], [88.97690582, 22.03738976], [88.97666168, 22.03689194], [88.97634888, 22.03637695], [88.97599792, 22.03585243], [88.97561646, 22.03532982], [88.9752121, 22.03481483], [88.97473145, 22.03432846], [88.97425842, 22.03380585], [88.97384644, 22.03317261], [88.97340393, 22.03256416], [88.97299194, 22.03196716], [88.97260284, 22.03142929], [88.97226715, 22.03095245], [88.97200012, 22.03051186], [88.97190094, 22.0300045], [88.97170258, 22.02954865], [88.97155762, 22.0290699], [88.9713974, 22.02864265], [88.97128296, 22.02823067], [88.971138, 22.02786064], [88.97108459, 22.02749825], [88.97093964, 22.0272007], [88.97081757, 22.02690315], [88.97065735, 22.02662086], [88.97052002, 22.02630806], [88.97029877, 22.02602959], [88.97005463, 22.02570724], [88.96990204, 22.02526283], [88.9697876, 22.02477646], [88.96967316, 22.02429008], [88.96949005, 22.02386665], [88.96929932, 22.02345848], [88.96914673, 22.02306938], [88.96893311, 22.02274132], [88.96870422, 22.02239799], [88.96858215, 22.02195168], [88.96834564, 22.02158356], [88.96808624, 22.0212307], [88.96788025, 22.0208416], [88.96766663, 22.02043915], [88.96746063, 22.02003288], [88.96720886, 22.01962852], [88.96691132, 22.01923943], [88.96657562, 22.01891136], [88.9662323, 22.01867294], [88.96585083, 22.01861], [88.96549988, 22.01861], [88.96515656, 22.01867294], [88.96472168, 22.01889229], [88.96444702, 22.01889229], [88.9641571, 22.01917076], [88.96389008, 22.01917076], [88.96351624, 22.01879692], [88.96333313, 22.01861], [88.96330261, 22.01844788], [88.96305084, 22.01818275], [88.96277618, 22.01785278], [88.96250153, 22.01749992], [88.96221924, 22.01722145], [88.96221924, 22.01666832], [88.96305847, 22.01667213], [88.96389008, 22.01749992], [88.96518707, 22.01741028], [88.96526337, 22.01702309], [88.96552277, 22.01663017], [88.96565247, 22.01618195], [88.96581268, 22.01577377], [88.96588135, 22.01533318], [88.96605682, 22.01493263], [88.96611023, 22.01447105], [88.96615601, 22.01399231], [88.96629333, 22.01352119], [88.96637726, 22.0130024], [88.96646118, 22.01247215], [88.96666718, 22.01202011], [88.96694946, 22.01156044], [88.9672699, 22.01109123], [88.96766663, 22.01067162], [88.96806335, 22.0102787], [88.96842194, 22.0098896], [88.96874237, 22.00952721], [88.96907043, 22.00917816], [88.9694519, 22.00891876], [88.96985626, 22.00866127], [88.97032166, 22.00845146], [88.97077942, 22.00820351], [88.97120667, 22.00789452], [88.97163391, 22.00757408], [88.97216797, 22.00739479], [88.97267151, 22.00716972], [88.97315216, 22.00692368], [88.97363281, 22.00663948], [88.97408295, 22.00632286], [88.97446442, 22.00594521], [88.97485352, 22.00558853], [88.97521973, 22.00523186], [88.97550964, 22.0048275], [88.97569275, 22.00432014], [88.97580719, 22.00377464], [88.97583771, 22.00318718], [88.97583008, 22.00259972], [88.97576904, 22.00204277], [88.97561646, 22.00154495], [88.97544861, 22.00109291], [88.97528076, 22.00068092], [88.97527313, 22.00036049], [88.97499847, 22.00000191], [88.9747467, 21.99973106], [88.97454834, 21.99946022], [88.97441864, 21.99916267], [88.97418976, 21.99886513], [88.97390747, 21.99851036], [88.97303772, 21.99809074], [88.97290039, 21.99778938], [88.97262573, 21.99726486], [88.97278595, 21.99692535], [88.97255707, 21.99662018], [88.97241211, 21.99632072], [88.97222137, 21.99605942], [88.97203827, 21.99577141], [88.9719162, 21.99538231], [88.97168732, 21.99500084], [88.97136688, 21.99455261], [88.97138977, 21.99444389], [88.97138977, 21.99361229], [88.97123718, 21.99333572], [88.97109222, 21.99304771], [88.97096252, 21.99277306], [88.97110748, 21.99250221], [88.97110748, 21.99110985], [88.97166443, 21.99055481], [88.97194672, 21.99055672], [88.97222137, 21.99027824], [88.97222137, 21.98999977], [88.97220612, 21.9895916], [88.97220612, 21.98891258], [88.97249603, 21.98779106], [88.97305298, 21.98722267], [88.97360992, 21.9869442], [88.9753418, 21.98632622], [88.97585297, 21.98610115], [88.97637939, 21.98587227], [88.97702789, 21.98579216], [88.97766876, 21.9855957], [88.97837067, 21.98555565], [88.97910309, 21.98555183], [88.97982025, 21.98555946], [88.98049927, 21.98555183], [88.98112488, 21.98550034], [88.98168945, 21.98531914], [88.98226929, 21.98527908], [88.98284912, 21.98526955], [88.98340607, 21.98518181], [88.98397827, 21.98502922], [88.98455811, 21.98496056], [88.9850769, 21.98476219], [88.98564148, 21.98467255], [88.98609161, 21.98446083], [88.98655701, 21.98428154], [88.98707581, 21.98412514], [88.98751068, 21.98384285], [88.98774719, 21.98338127], [88.98775482, 21.98280716], [88.98763275, 21.98220253], [88.98751831, 21.98160362], [88.98745728, 21.98103523], [88.98726654, 21.98056221], [88.98722076, 21.98011017], [88.98722076, 21.97969246], [88.98718262, 21.97929382], [88.98699188, 21.97889137], [88.98694611, 21.97845268], [88.98696899, 21.97797966], [88.98709869, 21.97749138], [88.98718262, 21.9769783], [88.98706055, 21.97648048], [88.98706055, 21.97602272], [88.98722076, 21.97555733], [88.98722076, 21.97528458], [88.98750305, 21.97500038], [88.98750305, 21.97472191], [88.98777771, 21.97444725], [88.98777771, 21.9738903], [88.98818207, 21.97299194], [88.98860931, 21.97279358], [88.98895264, 21.97222137], [88.98916626, 21.97194481], [88.99055481, 21.97055626], [88.9909668, 21.97029114], [88.99138641, 21.9702816], [88.99194336, 21.97007942], [88.99223328, 21.97000313], [88.9927063, 21.97001076], [88.99388885, 21.9702816], [88.99415588, 21.97055817], [88.9944458, 21.97055626], [88.99472046, 21.97083473], [88.99500275, 21.97083092], [88.9950943, 21.9708786], [88.99546814, 21.97110748], [88.99588013, 21.97138023], [88.99634552, 21.97163391], [88.99679565, 21.97193146], [88.99724579, 21.97222137], [88.99767303, 21.97252083], [88.99797821, 21.97283745], [88.99819183, 21.97317314], [88.99867249, 21.97361183], [88.99973297, 21.9738903], [88.99973297, 21.97417259], [89.0, 21.97445107], [89.00026703, 21.97505951], [89.00049591, 21.97523308], [89.00080872, 21.97559166], [89.00112152, 21.97598076], [89.00144196, 21.97633362], [89.00179291, 21.97662163], [89.00215912, 21.97683144], [89.00242615, 21.97714043], [89.00276947, 21.97739983], [89.00312042, 21.97768021], [89.00356293, 21.97792435], [89.00395966, 21.97829247], [89.00437164, 21.97868156], [89.0047226, 21.97911263], [89.00506592, 21.97951317], [89.0054245, 21.97985649], [89.00580597, 21.98015213], [89.00617981, 21.98048973], [89.00665283, 21.98080254], [89.00718689, 21.98109245], [89.00777435, 21.98138618], [89.00837708, 21.98166084], [89.00900269, 21.98191071], [89.00963593, 21.98194885], [89.01023102, 21.98195839], [89.01076508, 21.98199463], [89.01126099, 21.98191071], [89.01166534, 21.98168755], [89.01210022, 21.98150063], [89.01246643, 21.98122215], [89.01277161, 21.98084068], [89.01301575, 21.98044395], [89.01316833, 21.9800396], [89.01331329, 21.97970009], [89.0133667, 21.97936058], [89.01352692, 21.9791069], [89.01360321, 21.97883034], [89.01361084, 21.97855186], [89.01361084, 21.97828484], [89.01361084, 21.97803688], [89.01361084, 21.97780037], [89.01361084, 21.97755051], [89.01361084, 21.97727013], [89.01359558, 21.97696686], [89.01346588, 21.97665024], [89.01331329, 21.97631264], [89.01307678, 21.97598076], [89.01283264, 21.97562027], [89.01255798, 21.97528458], [89.01225281, 21.97493362], [89.01194763, 21.97455978], [89.01167297, 21.9741497], [89.0113678, 21.97374535], [89.01101685, 21.97336006], [89.01060486, 21.97303391], [89.01019287, 21.97268677], [89.00979614, 21.97230721], [89.00939941, 21.97197151], [89.00898743, 21.97166824], [89.00859833, 21.97136116], [89.008255, 21.9710331], [89.00793457, 21.97072792], [89.00757599, 21.97051048], [89.0072937, 21.97026443], [89.00699615, 21.96999741], [89.00665283, 21.96972084], [89.00618744, 21.96944427], [89.00564575, 21.96916962], [89.00506592, 21.96889305], [89.0045166, 21.96857262], [89.00403595, 21.96819878], [89.00361633, 21.96776009], [89.00322723, 21.96727371], [89.00280762, 21.96682167], [89.00234985, 21.96669006], [89.00202179, 21.96649933], [89.00152588, 21.96582985], [89.00106049, 21.96546936], [89.00097656, 21.96534157], [89.00026703, 21.96500206], [89.0, 21.96471977], [88.99954987, 21.9644146], [88.99920654, 21.96449089], [88.99878693, 21.96419907], [88.99835968, 21.96389389], [88.9980545, 21.96361542], [88.9952774, 21.9608326], [88.99501801, 21.96046638], [88.99472046, 21.96009254], [88.9944458, 21.95970726], [88.99415588, 21.95932388], [88.99386597, 21.95894051], [88.99357605, 21.95857048], [88.99331665, 21.95815086], [88.99305725, 21.95777321], [88.992836, 21.95740509], [88.99269867, 21.95702171], [88.99252319, 21.9566803], [88.99240112, 21.95630074], [88.99220276, 21.95594978], [88.99195862, 21.95556068], [88.99177551, 21.95509529], [88.9912262, 21.95361137], [88.99093628, 21.95193481], [88.9909668, 21.95105171], [88.99101257, 21.94983864], [88.99101257, 21.94836235], [88.99151611, 21.9474926], [88.99172974, 21.94654465], [88.99266052, 21.94466019], [88.99401855, 21.94291115], [88.99459076, 21.94197273], [88.99637604, 21.94089317], [88.99738312, 21.94008827], [88.99888611, 21.93927956], [89.0, 21.93861198], [89.00047302, 21.93827248], [89.00102234, 21.93808174], [89.00157166, 21.93791008], [89.00208282, 21.93783188], [89.0026474, 21.93774414], [89.00318909, 21.93756485], [89.0037384, 21.93745995], [89.00418854, 21.93725014], [89.00466156, 21.9371891], [89.00505829, 21.93704033], [89.00547028, 21.93692017], [89.00569916, 21.93678474], [89.00583649, 21.93670273], [89.00626373, 21.93659782], [89.00662231, 21.93639374], [89.00701904, 21.936203], [89.00747681, 21.9360981], [89.00792694, 21.93596268], [89.00837708, 21.93582153], [89.00879669, 21.93565178], [89.00923157, 21.93549156], [89.00959778, 21.93526649], [89.00994873, 21.93501091], [89.01029205, 21.93480492], [89.01064301, 21.93462944], [89.01095581, 21.93442917], [89.01126862, 21.93418312], [89.01159668, 21.93394661], [89.01190186, 21.93365288], [89.0121994, 21.93333244], [89.01251984, 21.93302345], [89.01291656, 21.93275261], [89.01331329, 21.9324131], [89.01367188, 21.93201256], [89.01407623, 21.93163109], [89.01442719, 21.93122292], [89.0147171, 21.93077278], [89.01503754, 21.93036461], [89.01539612, 21.93001747], [89.01576233, 21.92971992], [89.01611328, 21.92942238], [89.01642609, 21.92912483], [89.01673889, 21.92881966], [89.0170517, 21.92851067], [89.01735687, 21.92819023], [89.01760101, 21.92782021], [89.0178833, 21.92750549], [89.01837921, 21.9269104], [89.01863098, 21.92621613], [89.01921844, 21.92541313], [89.01943207, 21.92494392], [89.01964569, 21.92433739], [89.01994324, 21.92379951], [89.02008057, 21.92319489], [89.02036285, 21.92279243], [89.0207901, 21.92231941], [89.02094269, 21.92212105], [89.02134705, 21.92165947], [89.02139282, 21.9212513], [89.02139282, 21.92080879], [89.02139282, 21.92034149], [89.02139282, 21.91988564], [89.02139282, 21.91944313], [89.02138519, 21.91901207], [89.02133179, 21.91858673], [89.02114868, 21.91816902], [89.02105713, 21.91768074], [89.02085876, 21.91720009], [89.02070618, 21.91667557], [89.0205307, 21.91616249], [89.02028656, 21.91572762], [89.02004242, 21.91533089], [89.01976013, 21.91499138], [89.01950073, 21.9146595], [89.01928711, 21.91428947], [89.01908112, 21.91389275], [89.01888275, 21.91350174], [89.01869965, 21.91312981], [89.01857758, 21.91278267], [89.01838684, 21.91251945], [89.01829529, 21.91221809], [89.01812744, 21.91198158], [89.01802063, 21.9116745], [89.01776886, 21.91076088], [89.01732635, 21.91022491], [89.01683807, 21.90974808], [89.01661682, 21.90954018], [89.01647949, 21.90934181], [89.01625824, 21.90907478], [89.01612091, 21.9088726], [89.01597595, 21.90879822], [89.01527405, 21.90833282], [89.01499939, 21.90805626], [89.01499939, 21.90750122], [89.01532745, 21.90679932], [89.01532745, 21.90619278], [89.01532745, 21.90574074], [89.01529694, 21.90517998], [89.01522827, 21.9046917], [89.01533508, 21.90415382], [89.01554871, 21.9038105], [89.01550293, 21.90341949], [89.0151062, 21.90306854], [89.01464081, 21.9027729], [89.01418304, 21.90250206], [89.01370239, 21.90227509], [89.01313019, 21.90218353], [89.01257324, 21.90199471], [89.01198578, 21.90194893], [89.01143646, 21.9019413], [89.01113892, 21.90194321], [89.01093292, 21.90194511], [89.01056671, 21.90213966], [89.01003265, 21.90226364], [89.00939941, 21.90227318], [89.00878143, 21.90232277], [89.00827026, 21.90229225], [89.00778198, 21.9024601], [89.00726318, 21.90253639], [89.00682831, 21.90271187], [89.0063858, 21.90282249], [89.00598145, 21.90302086], [89.00553894, 21.90306282], [89.00508881, 21.90306282], [89.00463104, 21.90305519], [89.00416565, 21.90308571], [89.00370026, 21.90322113], [89.0031662, 21.90334129], [89.00250244, 21.90361214], [89.00195313, 21.90361214], [89.00166321, 21.90389061], [89.0, 21.90444374], [88.99906921, 21.9041729], [88.99872589, 21.90437126], [88.99833679, 21.90450096], [88.99790955, 21.90462494], [88.99744415, 21.90474319], [88.99728394, 21.90485191], [88.99695587, 21.90507317], [88.99668121, 21.90527153], [88.99633789, 21.90561104], [88.99584961, 21.90568924], [88.99508667, 21.90572166], [88.9947052, 21.90584564], [88.9942627, 21.90620232], [88.9937439, 21.90665817], [88.99337006, 21.90678978], [88.99299622, 21.90679932], [88.99233246, 21.90694618], [88.99188995, 21.90722466], [88.99144745, 21.90750122], [88.99099731, 21.90778351], [88.99054718, 21.90806007], [88.99010468, 21.90833664], [88.98966217, 21.90860939], [88.98921967, 21.90889359], [88.98875427, 21.90917969], [88.98826599, 21.90950966], [88.98776245, 21.90987778], [88.98751831, 21.91053009], [88.98677826, 21.91090584], [88.98636627, 21.91136169], [88.98578644, 21.91137123], [88.98542786, 21.91161156], [88.98510742, 21.91171265], [88.9850769, 21.91180992], [88.98500061, 21.91194344], [88.98438263, 21.91222954], [88.98416901, 21.91250038], [88.98306274, 21.91361046], [88.98249054, 21.91374016], [88.98236847, 21.91394997], [88.98197937, 21.91406822], [88.98130798, 21.91422272], [88.98071289, 21.91459084], [88.98004913, 21.91494942], [88.97937775, 21.91527367], [88.97872925, 21.91558266], [88.97816467, 21.91592598], [88.97763824, 21.91625023], [88.97711945, 21.91657066], [88.97658539, 21.91688347], [88.97603607, 21.91719246], [88.97551727, 21.91750145], [88.97501373, 21.91778755], [88.97453308, 21.9180603], [88.97406006, 21.91833687], [88.97358704, 21.91861153], [88.9731369, 21.91889191], [88.97267151, 21.91916084], [88.97220612, 21.91942787], [88.97183228, 21.91978455], [88.97173309, 21.91988373], [88.97123718, 21.92019081], [88.97074127, 21.92015457], [88.9702301, 21.9203701], [88.96971893, 21.92056847], [88.96924591, 21.92083168], [88.96883392, 21.92113876], [88.96855164, 21.92152023], [88.96837616, 21.9219799], [88.96849823, 21.92246056], [88.96881866, 21.92294121], [88.9691925, 21.92344093], [88.96974182, 21.92384338], [88.97006226, 21.92423058], [88.97029114, 21.92479134], [88.97065735, 21.92506218], [88.97100067, 21.92533112], [88.97119141, 21.9257412], [88.97150421, 21.92622185], [88.97157288, 21.92672348], [88.97175598, 21.92731285], [88.97192383, 21.92797089], [88.97196198, 21.92854118], [88.9719696, 21.92865372], [88.97171021, 21.92926025], [88.97136688, 21.92986107], [88.97091675, 21.93042946], [88.9704361, 21.93093491], [88.96994019, 21.93137169], [88.96943665, 21.93172836], [88.96894073, 21.93201065], [88.96847534, 21.93225479], [88.96803284, 21.93248177], [88.96759033, 21.9326725], [88.96713257, 21.93280983], [88.96669769, 21.93299294], [88.96626282, 21.93314362], [88.96586609, 21.93334007], [88.96550751, 21.93354988], [88.96514893, 21.93376732], [88.96487427, 21.93406677], [88.96472168, 21.93443298], [88.96469879, 21.93460274], [88.9646759, 21.9348011], [88.96495056, 21.93512535], [88.96543121, 21.93534279], [88.96589661, 21.93554878], [88.96634674, 21.93573761], [88.96683502, 21.93589592], [88.96730042, 21.93605995], [88.96779633, 21.93621254], [88.96829224, 21.93633842], [88.96878052, 21.93642616], [88.96923828, 21.93652916], [88.96961212, 21.93668365], [88.96997833, 21.93684196], [88.97039795, 21.93694115], [88.97084045, 21.93702126], [88.9712677, 21.93715286], [88.97171021, 21.93723106], [88.97218323, 21.93730736], [88.97232056, 21.93734932], [88.97264099, 21.93744659], [88.9731369, 21.93757057], [88.97364807, 21.93772888], [88.97418213, 21.93785477], [88.97470093, 21.93803024], [88.9752121, 21.93823814], [88.97571564, 21.93854332], [88.97618866, 21.9389534], [88.97660065, 21.93945122], [88.9769516, 21.93998146], [88.97722626, 21.94043159], [88.97741699, 21.94080353], [88.9774704, 21.94112587], [88.97740936, 21.94144249], [88.97724152, 21.94176292], [88.97721863, 21.94194794], [88.97666931, 21.94249725], [88.97666931, 21.94583321], [88.97638702, 21.94611168], [88.97555542, 21.94611168], [88.97528076, 21.94583321], [88.97528076, 21.94528008], [88.97528076, 21.94486046], [88.97528076, 21.94441223], [88.97531128, 21.94397163], [88.97538757, 21.94354057], [88.97550201, 21.94312096], [88.97560883, 21.9426899], [88.97573853, 21.94224167], [88.97579956, 21.94173622], [88.97579956, 21.94120216], [88.97570801, 21.94065285], [88.97543335, 21.94015312], [88.97498322, 21.93972778], [88.97441101, 21.93935966], [88.97374725, 21.93907166], [88.97305298, 21.93885231], [88.97228241, 21.93863106], [88.97151947, 21.93843269], [88.97077179, 21.93824577], [88.97003174, 21.93803978], [88.96933746, 21.93785667], [88.96878052, 21.93765068], [88.96824646, 21.93747139], [88.96768188, 21.93735123], [88.96718597, 21.93725014], [88.96659851, 21.93708992], [88.96608734, 21.936903], [88.96560669, 21.93669319], [88.96512604, 21.93650246], [88.96469116, 21.93631744], [88.96431732, 21.93610191], [88.96398163, 21.93590355], [88.96363831, 21.93577576], [88.96333313, 21.93555641], [88.96277618, 21.93499947], [88.96250153, 21.93499947], [88.96250153, 21.9347229], [88.96305847, 21.93416595], [88.96330261, 21.93365288], [88.96362305, 21.9332428], [88.96398163, 21.93286133], [88.96442413, 21.93253136], [88.96495056, 21.9322319], [88.96555328, 21.93193817], [88.96622467, 21.93166161], [88.96692657, 21.9313755], [88.96764374, 21.93104744], [88.96832275, 21.93066978], [88.96897125, 21.93028069], [88.96955109, 21.92990112], [88.96996307, 21.92947006], [88.97026062, 21.92905045], [88.97045898, 21.92867088], [88.97054291, 21.92823982], [88.97051239, 21.92777443], [88.97032928, 21.92728996], [88.97000885, 21.92678452], [88.96939087, 21.92636871], [88.9688797, 21.92599297], [88.96840668, 21.92547035], [88.96795654, 21.92494011], [88.96776581, 21.92451477], [88.96749878, 21.92419243], [88.96708679, 21.92402077], [88.96681976, 21.9237175], [88.96669769, 21.9234333], [88.96642303, 21.92310905], [88.9661026, 21.92292976], [88.96578217, 21.92290115], [88.96541595, 21.92291069], [88.96496582, 21.92298126], [88.96443176, 21.92305946], [88.96381378, 21.92314911], [88.96318054, 21.92334938], [88.96253204, 21.92361259], [88.96186829, 21.92387581], [88.96118927, 21.92409134], [88.96053314, 21.92429352], [88.95989227, 21.92445183], [88.95928955, 21.9246006], [88.95868683, 21.92474174], [88.95812988, 21.92492294], [88.95751953, 21.92507362], [88.95688629, 21.92523384], [88.95617676, 21.92530823], [88.95549011, 21.92551994], [88.95475769, 21.92564964], [88.95409393, 21.9258461], [88.95345306, 21.92609406], [88.95284271, 21.9263134], [88.95226288, 21.92648506], [88.95174408, 21.92667389], [88.95128632, 21.92688942], [88.95083618, 21.92710304], [88.95041656, 21.92730713], [88.94998932, 21.92749214], [88.94954681, 21.92768478], [88.94910431, 21.92784691], [88.94864655, 21.92801094], [88.94818115, 21.92817307], [88.94770813, 21.92831993], [88.94724274, 21.92847252], [88.94680023, 21.92865372], [88.94639587, 21.92887306], [88.945961, 21.92903709], [88.94550323, 21.9292202], [88.94499207, 21.92945862], [88.94444275, 21.92975044], [88.94387817, 21.93010902], [88.94332123, 21.93045235], [88.94278717, 21.93077278], [88.94232941, 21.93108368], [88.94187927, 21.93139458], [88.9414444, 21.93173409], [88.94102478, 21.93213272], [88.94056702, 21.9325428], [88.94007874, 21.93296242], [88.93950653, 21.93333244], [88.93894196, 21.9337101], [88.93842316, 21.93416023], [88.9379425, 21.93460655], [88.93747711, 21.93502426], [88.93707275, 21.93543053], [88.93667603, 21.93581009], [88.93627167, 21.93613625], [88.93588257, 21.93649101], [88.93556213, 21.936903], [88.93528748, 21.9373188], [88.93504333, 21.93773079], [88.93473053, 21.93814278], [88.93438721, 21.93858147], [88.93401337, 21.93903542], [88.93360901, 21.93943214], [88.93276978, 21.94028282], [88.93276978, 21.94056129], [88.9319458, 21.9413929], [88.93147278, 21.94207764], [88.93036652, 21.94571114], [88.9302063, 21.94624138], [88.9302597, 21.94635201], [88.93019104, 21.94749069], [88.9284668, 21.95374107], [88.92617798, 21.95993042], [88.92575073, 21.96206093], [88.92565918, 21.96268654], [88.92523956, 21.96350288], [88.92475128, 21.96363258], [88.92423248, 21.96441078], [88.92250061, 21.96669006], [88.9197464, 21.97256279], [88.91842651, 21.97607994], [88.91748047, 21.97905159], [88.91732788, 21.98011971], [88.91747284, 21.98046684], [88.91738892, 21.98070908], [88.91720581, 21.98124695], [88.91682434, 21.98191643], [88.91671753, 21.98210144], [88.91629791, 21.98299599], [88.91575623, 21.9841938], [88.91558075, 21.98521233], [88.91385651, 21.99114037], [88.91271973, 21.99435997], [88.91300201, 21.99704933], [88.91414642, 21.99839592], [88.91471863, 22.00000191], [88.91468811, 22.00177193], [88.91472626, 22.00229263], [88.91481018, 22.00284195], [88.91497803, 22.00339508], [88.91513062, 22.00401115], [88.91529846, 22.00465965], [88.91552734, 22.00530815], [88.91556549, 22.00600624], [88.91559601, 22.00664139], [88.91573334, 22.00714493], [88.91576385, 22.00728035], [88.91581726, 22.00752068], [88.91583252, 22.00787163], [88.91584015, 22.0082531], [88.91587067, 22.00867271], [88.91590881, 22.00912285], [88.91590881, 22.00961113], [88.916008, 22.01011658], [88.91607666, 22.01062965], [88.91603851, 22.01117134], [88.9158783, 22.01176071], [88.91586304, 22.01234818], [88.91590881, 22.0128994], [88.91588593, 22.01335716], [88.91590881, 22.01375389], [88.91577911, 22.01400185], [88.9156723, 22.0143528], [88.91565704, 22.01485252], [88.91558075, 22.01531982], [88.91553497, 22.0158062], [88.9154129, 22.01626587], [88.91526794, 22.01670265], [88.91510773, 22.01713181], [88.91500092, 22.01758003], [88.91488647, 22.01804352], [88.91475677, 22.01851082], [88.914711, 22.0190239], [88.91462708, 22.01952171], [88.91448212, 22.01995468], [88.91443634, 22.02039146], [88.91434479, 22.02080917], [88.91423798, 22.02118111], [88.91416168, 22.02157021], [88.9140625, 22.02190018], [88.91391754, 22.02219963], [88.91382599, 22.02253342], [88.91364288, 22.02277184], [88.9134903, 22.02306175], [88.91332245, 22.02340126], [88.91310883, 22.02378464], [88.91290283, 22.02422142], [88.91269684, 22.02467728], [88.91259766, 22.02488136], [88.91248322, 22.02511024], [88.91223907, 22.0255394], [88.91203308, 22.02601051], [88.91179657, 22.02644157], [88.91159821, 22.02691841], [88.91137695, 22.02737999], [88.91114807, 22.02787971], [88.91100311, 22.02843285], [88.91079712, 22.02892113], [88.91055298, 22.02933311], [88.91030121, 22.02972984], [88.91011047, 22.0301609], [88.90985107, 22.03058052], [88.90962219, 22.0310154], [88.90937805, 22.03145027], [88.90916443, 22.03187561], [88.90894318, 22.0322628], [88.90872955, 22.03268242], [88.90856934, 22.03318977], [88.90833282, 22.03372192], [88.90805817, 22.03426933], [88.90782928, 22.03480339], [88.90782166, 22.03533363], [88.90785217, 22.03585243], [88.90804291, 22.03638268], [88.90824127, 22.03686714], [88.90843964, 22.03734589], [88.908638, 22.03778267], [88.90888977, 22.03817177], [88.9091568, 22.03853989], [88.90939331, 22.03892326], [88.90959167, 22.03931236], [88.90979004, 22.03967285], [88.90999603, 22.03997993], [88.91021729, 22.04026222], [88.91033936, 22.04058838], [88.9105072, 22.04092216], [88.91059875, 22.04138184], [88.9107666, 22.04182243], [88.91086578, 22.04233932], [88.91098022, 22.04284286], [88.91105652, 22.04334068], [88.91110992, 22.04382515], [88.91108704, 22.04432106], [88.91101837, 22.04481888], [88.91088104, 22.04525948], [88.91082764, 22.04571915], [88.91073608, 22.04618263], [88.91059875, 22.04665375], [88.91055298, 22.04720116], [88.91046906, 22.04776955], [88.91031647, 22.04833412], [88.91024017, 22.04893684], [88.91011047, 22.04948997], [88.91001892, 22.05000114], [88.90995026, 22.05045319], [88.9098587, 22.05082893], [88.90975189, 22.05115318], [88.90970612, 22.05148888], [88.90962219, 22.05180168], [88.90953064, 22.0520916], [88.90944672, 22.05233192], [88.90933228, 22.0526104], [88.9091568, 22.05290031], [88.90894318, 22.05327797], [88.90883636, 22.05380058], [88.90866089, 22.05427551], [88.90859985, 22.05472183], [88.90851593, 22.05506897], [88.90837097, 22.05529976], [88.90830994, 22.05561256], [88.90820313, 22.05595016], [88.90802002, 22.05635262], [88.90777588, 22.05681419], [88.90750885, 22.05733299], [88.90721893, 22.05785561], [88.90699768, 22.05822372], [88.90693665, 22.05833244], [88.90638733, 22.05888939], [88.90638733, 22.05944443], [88.90472412, 22.06111336], [88.90467834, 22.06117439], [88.9043808, 22.06158447], [88.90394592, 22.06195259], [88.90383911, 22.06204605], [88.90348816, 22.06235695], [88.90303802, 22.06279564], [88.90258789, 22.06320763], [88.90208435, 22.06350136], [88.90170288, 22.06386566], [88.90148163, 22.064291], [88.90139771, 22.06478882], [88.90143585, 22.06528282], [88.90170288, 22.06565475], [88.90203094, 22.06594276], [88.90231323, 22.06627083], [88.9025116, 22.0666523], [88.90278625, 22.06696129], [88.90306091, 22.06723976], [88.9033432, 22.0675106], [88.90359497, 22.06782532], [88.90379333, 22.06823158], [88.90396881, 22.06866264], [88.90425873, 22.06901741], [88.90448761, 22.06947136], [88.90471649, 22.06986237], [88.90490723, 22.07019615], [88.90502167, 22.07051277], [88.90517426, 22.07075119], [88.90528107, 22.07100105], [88.90541077, 22.07125473], [88.90556335, 22.07156181], [88.90572357, 22.07185555], [88.90585327, 22.07217979], [88.90596771, 22.0724926], [88.90607452, 22.07275963], [88.90614319, 22.07302284], [88.90628052, 22.07323647], [88.9063797, 22.0734539], [88.90640259, 22.07368279], [88.90640259, 22.0739212], [88.90644073, 22.07422066], [88.90657043, 22.07460785], [88.90672302, 22.07510948], [88.90696716, 22.07556915], [88.9072876, 22.07595253], [88.90750885, 22.07640266], [88.90770721, 22.07686043], [88.90789032, 22.07734108], [88.90804291, 22.07774162], [88.90808105, 22.07784081], [88.90836334, 22.07832146], [88.90876007, 22.07875633], [88.90924072, 22.07920265], [88.90985107, 22.07957649], [88.91043854, 22.07999229], [88.91101837, 22.08038139], [88.91159821, 22.08073616], [88.91217041, 22.08094978], [88.91277313, 22.08118248], [88.91333008, 22.08139992], [88.91384888, 22.08166695], [88.91439056, 22.08194351], [88.9149704, 22.08219528], [88.91558838, 22.08238029], [88.91607666, 22.08264732], [88.91649628, 22.08298111], [88.91694641, 22.08324623], [88.91738129, 22.08350182], [88.91778564, 22.08384895], [88.91824341, 22.08410645], [88.91867828, 22.0844326], [88.91910553, 22.08474159], [88.919487, 22.08504486], [88.91980743, 22.08535194], [88.92019653, 22.08560181], [88.92053223, 22.08587074], [88.92082977, 22.0861721], [88.92114258, 22.08649254], [88.92144775, 22.0868206], [88.92182922, 22.08708954], [88.92220306, 22.08736992], [88.9225235, 22.08774757], [88.92285156, 22.08812141], [88.92320251, 22.08847237], [88.92354584, 22.08882141], [88.92388916, 22.08916283], [88.92421722, 22.08950233], [88.92455292, 22.0898304], [88.92487335, 22.09015083], [88.92518616, 22.09047127], [88.92553711, 22.09081078], [88.92588806, 22.0911808], [88.92623901, 22.09163094], [88.92668915, 22.09207344], [88.92680359, 22.09217453], [88.92722321, 22.09254265], [88.92772675, 22.09307289], [88.92813873, 22.09379005], [88.92861176, 22.09444237], [88.92906952, 22.09505272], [88.92942047, 22.09566307], [88.92972565, 22.09620857], [88.93000031, 22.09666443], [88.93025208, 22.09705162], [88.93044281, 22.09743309], [88.93057251, 22.09777451], [88.93071747, 22.09810066], [88.93083191, 22.09851265], [88.93093872, 22.09898758], [88.93109131, 22.09952545], [88.93121338, 22.10010338], [88.93134308, 22.10062408], [88.93138123, 22.10111046], [88.93135071, 22.10159111], [88.93122864, 22.10207176], [88.93125916, 22.10262871], [88.93118286, 22.10330391], [88.93126678, 22.10394096], [88.93136597, 22.10444069], [88.93136597, 22.10487938], [88.93125916, 22.10531044], [88.93113708, 22.10578918], [88.93105316, 22.10633278], [88.93094635, 22.10688019], [88.93084717, 22.10741806], [88.93078613, 22.10793495], [88.93060303, 22.10835075], [88.93051147, 22.10880089], [88.93032074, 22.10919762], [88.93022919, 22.10964012], [88.93002319, 22.1099968], [88.92986298, 22.11041069], [88.92967987, 22.11091042], [88.92952728, 22.11153221], [88.92928314, 22.11204529], [88.92903137, 22.112463], [88.9287262, 22.1128521], [88.9285202, 22.11329079], [88.92832947, 22.11366081], [88.92813873, 22.1139698], [88.92800903, 22.11432076], [88.9278183, 22.11465263], [88.9276886, 22.11508942], [88.92747498, 22.1155014], [88.92722321, 22.11591148], [88.92691803, 22.11634254], [88.9265976, 22.11675072], [88.92626953, 22.11718369], [88.92591858, 22.11758232], [88.92565155, 22.11803246], [88.92530823, 22.11845207], [88.92500305, 22.11892128], [88.92472076, 22.11942101], [88.92444611, 22.11988449], [88.92419434, 22.12029076], [88.92403412, 22.12068939], [88.92385864, 22.12099266], [88.92363739, 22.12125969], [88.92345428, 22.12156677], [88.92328644, 22.12187386], [88.92311096, 22.12219429], [88.92308807, 22.12257957], [88.92324829, 22.12294197], [88.92357635, 22.12319183], [88.92399597, 22.12317657], [88.92420959, 22.12317085], [88.92490387, 22.12296867], [88.92549133, 22.12275124], [88.9260025, 22.12256622], [88.92656708, 22.12244987], [88.92720032, 22.1223011], [88.92793274, 22.12225151], [88.92871094, 22.12226295], [88.92949677, 22.12233734], [88.93022919, 22.12250137], [88.93093872, 22.12264442], [88.93196106, 22.12347221], [88.93289185, 22.12428093], [88.93454742, 22.12502098], [88.93582153, 22.12503815], [88.93623352, 22.1251297], [88.93663025, 22.12523079], [88.93707275, 22.12535286], [88.93750763, 22.12549019], [88.93801117, 22.12558937], [88.93850708, 22.12572289], [88.9389801, 22.12587547], [88.93940735, 22.12610054], [88.93978119, 22.12641907], [88.94008636, 22.12682152], [88.94026947, 22.12737083], [88.94034576, 22.12797737], [88.94020844, 22.12857246], [88.93990326, 22.12911987], [88.93943024, 22.12956238], [88.93891144, 22.12994957], [88.93837738, 22.13029671], [88.93791962, 22.13067436], [88.93753052, 22.13105774], [88.93717194, 22.13142967], [88.93678284, 22.13175011], [88.93634796, 22.1319809], [88.93591309, 22.13223267], [88.9355011, 22.13250542], [88.93509674, 22.13279343], [88.9347229, 22.13309288], [88.9343338, 22.1334095], [88.93392181, 22.13372231], [88.93353271, 22.13406181], [88.93312836, 22.13438225], [88.93274689, 22.1347084], [88.93235016, 22.13500023], [88.93196106, 22.13529587], [88.93162537, 22.13563156], [88.93060303, 22.13697815], [88.93044281, 22.13778305], [88.93060303, 22.13784981], [88.93087006, 22.13820076], [88.93144989, 22.13865662], [88.93165588, 22.13872147], [88.9319458, 22.1388607], [88.93238068, 22.1389904], [88.93353271, 22.13932991], [88.93395996, 22.13953209], [88.93439484, 22.13972855], [88.93496704, 22.14006233], [88.93540192, 22.14033127], [88.93567657, 22.14053154], [88.93589783, 22.14080048], [88.93626404, 22.14113808], [88.93640137, 22.14147377], [88.93647766, 22.14187431], [88.93654633, 22.14214134], [88.93654633, 22.14241219], [88.93647766, 22.14281273], [88.93618774, 22.14281273], [88.93604279, 22.14261055], [88.93596649, 22.14241219], [88.93582916, 22.14221001], [88.93547058, 22.14184189], [88.9349823, 22.14144516], [88.93479156, 22.14122963], [88.93430328, 22.14084053], [88.93376923, 22.14050102], [88.93320465, 22.14019966], [88.93260956, 22.13990974], [88.93206024, 22.13968086], [88.93154144, 22.1395092], [88.9310379, 22.13929367], [88.93052673, 22.13895988], [88.93013, 22.13852119], [88.92984009, 22.13803291], [88.92962646, 22.13749123], [88.92948151, 22.13691139], [88.92941284, 22.13637161], [88.92957306, 22.13591385], [88.92979431, 22.13554382], [88.93013, 22.135252], [88.93051147, 22.13496208], [88.93087769, 22.1346302], [88.93122864, 22.13427353], [88.93157959, 22.13394356], [88.93193817, 22.13365364], [88.93231964, 22.13340569], [88.93268585, 22.13318062], [88.9330368, 22.13290977], [88.93338013, 22.13261986], [88.93376923, 22.13234138], [88.93418884, 22.13204002], [88.93464661, 22.13171196], [88.93515015, 22.13136101], [88.93564606, 22.13092995], [88.93616486, 22.1305275], [88.93665314, 22.13017273], [88.93708801, 22.12985611], [88.93747711, 22.12957191], [88.93782043, 22.12928391], [88.9381485, 22.1289959], [88.9384613, 22.1287117], [88.93869781, 22.12838173], [88.93887329, 22.12804222], [88.93891907, 22.12770271], [88.93887329, 22.12738228], [88.93865967, 22.12711716], [88.93831635, 22.12689018], [88.93786621, 22.12669945], [88.9373703, 22.12656021], [88.93685913, 22.12643051], [88.93631744, 22.12637329], [88.93573761, 22.12632751], [88.93514252, 22.12620926], [88.93457794, 22.12605095], [88.93403625, 22.12586975], [88.93348694, 22.12571144], [88.93297577, 22.12551308], [88.93247986, 22.12529564], [88.93198395, 22.12508774], [88.9315033, 22.12485123], [88.93105316, 22.12463188], [88.9306488, 22.12439156], [88.93028259, 22.12415123], [88.9299469, 22.12393951], [88.92962646, 22.12379265], [88.92932129, 22.12366295], [88.92896271, 22.12362099], [88.9285202, 22.12363625], [88.92806244, 22.12369347], [88.9276123, 22.12364388], [88.92719269, 22.12364006], [88.92679596, 22.12373161], [88.92639923, 22.1238308], [88.92592621, 22.12389946], [88.92537689, 22.12400246], [88.92469788, 22.12406731], [88.92388916, 22.12410164], [88.92352295, 22.1243515], [88.92314148, 22.12461281], [88.92267609, 22.1248188], [88.92206573, 22.1249752], [88.92140198, 22.12504387], [88.92076111, 22.1252346], [88.92015076, 22.12543297], [88.9196167, 22.12571144], [88.91911316, 22.12590981], [88.91866302, 22.1261425], [88.91822815, 22.12640953], [88.91781616, 22.12669945], [88.91744232, 22.12701225], [88.91707611, 22.12735176], [88.91670227, 22.12764168], [88.91635132, 22.12795258], [88.91597748, 22.12820816], [88.91562653, 22.12850189], [88.91520691, 22.12870026], [88.91480255, 22.12893295], [88.91441345, 22.12919807], [88.91399384, 22.12945747], [88.91358185, 22.12973213], [88.91316986, 22.13002968], [88.91279602, 22.13039207], [88.91243744, 22.13077927], [88.91204834, 22.13113976], [88.91165924, 22.13153267], [88.91130829, 22.1319046], [88.91092682, 22.13221741], [88.91055298, 22.13251114], [88.91018677, 22.13287163], [88.90981293, 22.1332531], [88.90943909, 22.1336441], [88.90914154, 22.13417053], [88.90883636, 22.13474083], [88.90865326, 22.1353054], [88.90859985, 22.13586807], [88.90860748, 22.13641548], [88.90860748, 22.13694382], [88.90860748, 22.13745308], [88.90862274, 22.13794136], [88.90870667, 22.13840485], [88.90885162, 22.13883781], [88.90888977, 22.13928032], [88.90888977, 22.1397419], [88.90888977, 22.14021111], [88.90892029, 22.14064026], [88.90898132, 22.14100075], [88.90898132, 22.14132881], [88.90891266, 22.14165306], [88.90883636, 22.14202309], [88.90867615, 22.14240074], [88.90857697, 22.14288139], [88.90834808, 22.14338112], [88.90817261, 22.14391136], [88.90805817, 22.14443016], [88.90796661, 22.14491081], [88.90782166, 22.14531326], [88.90777588, 22.14574814], [88.90776825, 22.14621925], [88.90770721, 22.14669991], [88.907547, 22.14711952], [88.90746307, 22.14756012], [88.90724182, 22.14790154], [88.90705109, 22.14822197], [88.90692139, 22.14861107], [88.90672302, 22.14899254], [88.90653992, 22.14947891], [88.90634918, 22.15002441], [88.90611267, 22.15052223], [88.90585327, 22.15098], [88.90563202, 22.15139961], [88.90544128, 22.15177917], [88.90525055, 22.15209007], [88.90500641, 22.15234947], [88.90474701, 22.15263557], [88.90448761, 22.15300751], [88.90419006, 22.15343285], [88.90385437, 22.15391731], [88.90348053, 22.15440941], [88.90306091, 22.15485954], [88.90264893, 22.15526772], [88.90225983, 22.15565109], [88.90190125, 22.15608025], [88.90151978, 22.15654182], [88.90107727, 22.15704346], [88.9005661, 22.15752983], [88.9000473, 22.15802956], [88.89951324, 22.15844154], [88.89910126, 22.15886116], [88.89870453, 22.15917397], [88.89836121, 22.15947151], [88.89804077, 22.15979576], [88.89766693, 22.16011238], [88.89718628, 22.16044044], [88.89665222, 22.16085243], [88.89614105, 22.1612606], [88.89572144, 22.16169167], [88.89537811, 22.16211128], [88.89502716, 22.16242409], [88.89476013, 22.16275215], [88.89460754, 22.16314507], [88.89450836, 22.1635437], [88.89441681, 22.16391182], [88.89427185, 22.16423225], [88.8941803, 22.16460991], [88.89411163, 22.16503716], [88.8939743, 22.16543198], [88.8937912, 22.1657505], [88.89367676, 22.1662426], [88.89344788, 22.16674232], [88.89356995, 22.16724205], [88.89364624, 22.16774178], [88.89380646, 22.16818047], [88.89387512, 22.16863823], [88.89389038, 22.16914177], [88.89393616, 22.16969872], [88.89412689, 22.17028809], [88.89427948, 22.17093277], [88.89466858, 22.17136192], [88.89520264, 22.17161179], [88.89579773, 22.17163467], [88.89636993, 22.17144966], [88.89692688, 22.17126274], [88.89746094, 22.17106247], [88.89795685, 22.17082024], [88.89842224, 22.17055511], [88.89888763, 22.17028236], [88.89935303, 22.16999817], [88.89982605, 22.16974831], [88.90032959, 22.16954041], [88.90087128, 22.16938972], [88.90139008, 22.16916084], [88.9019165, 22.16888809], [88.90246582, 22.16860008], [88.90297699, 22.16827011], [88.90341187, 22.16789055], [88.90382385, 22.167593], [88.90431213, 22.16745949], [88.90471649, 22.16725159], [88.90515137, 22.16707039], [88.90560913, 22.16687202], [88.90604401, 22.16657829], [88.90643311, 22.16620064], [88.90683746, 22.16584969], [88.90725708, 22.16555786], [88.90764618, 22.16526985], [88.90802002, 22.16501999], [88.90833282, 22.16473198], [88.90862274, 22.16445351], [88.90894318, 22.16418266], [88.90929413, 22.16391373], [88.90974426, 22.16366005], [88.91023254, 22.1633625], [88.91070557, 22.16297722], [88.91117096, 22.16257286], [88.91163635, 22.16222954], [88.91210938, 22.16195107], [88.91256714, 22.16171074], [88.91314697, 22.16160011], [88.91368103, 22.16138268], [88.91424561, 22.16115952], [88.91490173, 22.16109276], [88.91555786, 22.1609726], [88.91622162, 22.16085243], [88.91691589, 22.16083336], [88.91759491, 22.16083336], [88.91821289, 22.1608448], [88.91872406, 22.16090584], [88.91916656, 22.16111183], [88.91971588, 22.16111183], [88.91999817, 22.1613903], [88.92028046, 22.1613903], [88.92041779, 22.16152763], [88.92056274, 22.16167068], [88.92111206, 22.16167068], [88.92095947, 22.16192055], [88.92144012, 22.16210747], [88.92175293, 22.16236115], [88.92211151, 22.16254807], [88.9224472, 22.16278458], [88.9227829, 22.1630497], [88.92315674, 22.16333389], [88.92359161, 22.16360283], [88.92402649, 22.16393089], [88.92443085, 22.1643486], [88.9247818, 22.16477013], [88.92502594, 22.16516876], [88.92524719, 22.16548347], [88.92538452, 22.16579628], [88.92552185, 22.16608238], [88.92560577, 22.16645241], [88.92578125, 22.1667614], [88.9259491, 22.16712189], [88.92608643, 22.16756248], [88.92612457, 22.16807365], [88.92611694, 22.16861343], [88.92611694, 22.16916084], [88.92613983, 22.1697216], [88.92623901, 22.17027092], [88.92623901, 22.17080116], [88.92617035, 22.1713829], [88.92621613, 22.17199135], [88.92608643, 22.17252922], [88.92597198, 22.17307281], [88.92584991, 22.17356491], [88.92565155, 22.17394829], [88.92556, 22.17440224], [88.92541504, 22.17478752], [88.92536163, 22.17521286], [88.92555237, 22.17556381], [88.92590332, 22.17584038], [88.92634583, 22.17604446], [88.92688751, 22.1760006], [88.92743683, 22.17583275], [88.92796326, 22.17564392], [88.92844391, 22.17545509], [88.92888641, 22.17526436], [88.92929077, 22.17502785], [88.92970276, 22.17482948], [88.9300766, 22.17464256], [88.93042755, 22.1744709], [88.93077087, 22.17435265], [88.93109894, 22.17420006], [88.93148804, 22.17418289], [88.9318924, 22.17426109], [88.93228912, 22.17441559], [88.93266296, 22.17451286], [88.93297577, 22.17469788], [88.93332672, 22.17486191], [88.93369293, 22.17510033], [88.934021, 22.17542076], [88.93432617, 22.17578316], [88.93467712, 22.17609215], [88.93495941, 22.17645836], [88.93521118, 22.17686462], [88.93550873, 22.17725754], [88.93580627, 22.17772102], [88.93605804, 22.17827034], [88.93636322, 22.17884254], [88.93678284, 22.17936707], [88.93730164, 22.17980003], [88.93776703, 22.18020058], [88.93835449, 22.18033028], [88.93882751, 22.1804924], [88.93920135, 22.18062019], [88.9394989, 22.18078995], [88.93982697, 22.18083], [88.94016266, 22.18087006], [88.94049072, 22.1810112], [88.94087219, 22.18105125], [88.94127655, 22.1810894], [88.94169617, 22.18111229], [88.94213867, 22.18111229], [88.94255829, 22.18111992], [88.94297791, 22.1811924], [88.943367, 22.18135071], [88.9438324, 22.18141365], [88.94429779, 22.18158722], [88.94474792, 22.18195152], [88.94525146, 22.18235779], [88.94573212, 22.18285179], [88.94612885, 22.18346977], [88.94648743, 22.18410301], [88.94664001, 22.18476486], [88.94661713, 22.18538094], [88.94641876, 22.18589973], [88.94618225, 22.18637276], [88.94583893, 22.18676949], [88.94547272, 22.18717003], [88.94499969, 22.18753242], [88.94460297, 22.18798256], [88.94411469, 22.18833733], [88.94364929, 22.18866348], [88.9432373, 22.18898201], [88.94288635, 22.18932915], [88.94255829, 22.18967247], [88.94236755, 22.19001389], [88.94264221, 22.19028473], [88.94309998, 22.19049835], [88.94371796, 22.19054985], [88.94436646, 22.19056129], [88.94496155, 22.1905117], [88.94542694, 22.19033241], [88.94589233, 22.19020271], [88.94631195, 22.19006538], [88.94674683, 22.18996811], [88.94713593, 22.1898098], [88.94756317, 22.18972969], [88.94797516, 22.18969154], [88.94837189, 22.18955994], [88.94882202, 22.18943024], [88.94934845, 22.18928528], [88.94996643, 22.18919182]]], [[[88.83602905, 22.07283211], [88.83613586, 22.07286453], [88.83625031, 22.07290077], [88.8364563, 22.07290077], [88.83683014, 22.07270241], [88.83718109, 22.07250023], [88.83738708, 22.07230186], [88.837677, 22.07203102], [88.83789825, 22.07176018], [88.83825684, 22.07169151], [88.83940887, 22.07155991], [88.84012604, 22.07156181], [88.84101105, 22.07153893], [88.8414917, 22.07167244], [88.84191895, 22.07185936], [88.8423996, 22.07201385], [88.84285736, 22.07224083], [88.84333801, 22.07250023], [88.84384918, 22.07277489], [88.84438324, 22.07304955], [88.84493256, 22.07332802], [88.84551239, 22.07362175], [88.84603119, 22.07401085], [88.84648895, 22.07444191], [88.84692383, 22.0748558], [88.84733582, 22.0752182], [88.84777832, 22.07553482], [88.84823608, 22.07579041], [88.84860992, 22.07615089], [88.84893036, 22.07658768], [88.84928131, 22.07699585], [88.84970856, 22.07730293], [88.85017395, 22.07756805], [88.8506012, 22.07782173], [88.85101318, 22.07805061], [88.85147095, 22.0782795], [88.85197449, 22.07842064], [88.85246277, 22.0785923], [88.85292053, 22.07875252], [88.8533783, 22.07887077], [88.85385895, 22.07897186], [88.85435486, 22.07904625], [88.85487366, 22.07897758], [88.85536194, 22.07888222], [88.85585022, 22.07880211], [88.85634613, 22.07891655], [88.85683441, 22.07907867], [88.85736084, 22.07914162], [88.85785675, 22.07916069], [88.85836029, 22.07916069], [88.8588562, 22.07913017], [88.85933685, 22.07904053], [88.85980225, 22.07886314], [88.86035156, 22.078722], [88.86094666, 22.07873535], [88.86149597, 22.07892036], [88.86192322, 22.07914162], [88.86228943, 22.07931709], [88.86267853, 22.07942009], [88.86309814, 22.07949257], [88.86353302, 22.07962227], [88.86399078, 22.0797081], [88.86450195, 22.07980347], [88.86508179, 22.07999229], [88.86573029, 22.08021545], [88.8663559, 22.08052254], [88.86701965, 22.08088112], [88.86769867, 22.0812664], [88.86847687, 22.08150673], [88.86915588, 22.08136559], [88.86964417, 22.08102608], [88.86997986, 22.08057213], [88.8702774, 22.08008385], [88.87050629, 22.07955551], [88.87055969, 22.07893944], [88.87055206, 22.07830238], [88.87049866, 22.0777092], [88.87032318, 22.07722282], [88.87023926, 22.07667923], [88.87003326, 22.07618141], [88.86992645, 22.07566071], [88.86975861, 22.07516289], [88.86969757, 22.07458878], [88.86956024, 22.0739994], [88.86942291, 22.07341194], [88.86920166, 22.07286263], [88.8690567, 22.07226181], [88.86886597, 22.07168007], [88.86863708, 22.0711422], [88.86849213, 22.07059288], [88.8683548, 22.0701046], [88.86833191, 22.06965065], [88.86833191, 22.06926155], [88.86833191, 22.06892967], [88.86833191, 22.06862068], [88.86833191, 22.06831169], [88.86833191, 22.06796074], [88.86837769, 22.06755829], [88.86856842, 22.06715012], [88.86860657, 22.06664085], [88.86865997, 22.06611824], [88.86888885, 22.06568909], [88.86915588, 22.0652523], [88.86940002, 22.06475258], [88.86955261, 22.06422234], [88.86972046, 22.06383705], [88.86988831, 22.06356239], [88.87001038, 22.0633049], [88.87016296, 22.06305122], [88.87037659, 22.06278038], [88.87065887, 22.06253815], [88.87098694, 22.06234169], [88.87137604, 22.06213951], [88.87180328, 22.06192207], [88.87224579, 22.0616684], [88.87272644, 22.06142044], [88.87332153, 22.06126213], [88.87390137, 22.06109047], [88.87445068, 22.06087112], [88.87506104, 22.06075096], [88.87561035, 22.06054115], [88.87612915, 22.06027794], [88.87666321, 22.06002235], [88.87722778, 22.05984306], [88.8777771, 22.05969238], [88.87822723, 22.05943871], [88.87861633, 22.05916023], [88.87896729, 22.05890274], [88.87937164, 22.05870628], [88.87983704, 22.05857277], [88.88031006, 22.05834007], [88.88083649, 22.05814362], [88.88140106, 22.05794907], [88.88197327, 22.05776024], [88.88248444, 22.05749893], [88.88295746, 22.05721283], [88.88339233, 22.05688477], [88.88378143, 22.05650139], [88.88415527, 22.05611038], [88.88447571, 22.05567932], [88.88482666, 22.0553112], [88.88522339, 22.05500031], [88.88560486, 22.05472183], [88.88600159, 22.05443954], [88.88640594, 22.05414009], [88.88680267, 22.05377007], [88.88721466, 22.05342293], [88.88765717, 22.05307961], [88.88815308, 22.05278015], [88.88863373, 22.05247307], [88.88905334, 22.05206108], [88.88943481, 22.05162621], [88.88963318, 22.05137062], [88.88977051, 22.05118942], [88.8901062, 22.05079269], [88.89034271, 22.05032158], [88.89055634, 22.04985809], [88.89073181, 22.04938316], [88.89079285, 22.04886055], [88.89060211, 22.04833031], [88.8903656, 22.04795647], [88.89028931, 22.04783249], [88.88982391, 22.0474987], [88.88935852, 22.04722023], [88.88891602, 22.04699135], [88.8884201, 22.04689217], [88.88796234, 22.04670906], [88.88736725, 22.04662132], [88.88677979, 22.0464325], [88.88613129, 22.04639244], [88.88549042, 22.04636955], [88.88490295, 22.04627037], [88.88434601, 22.04614067], [88.88379669, 22.04611015], [88.88327789, 22.0460701], [88.88278198, 22.04587173], [88.8822403, 22.04581642], [88.88168335, 22.04570961], [88.88106537, 22.04558182], [88.88038635, 22.04555511], [88.87967682, 22.04556084], [88.87898254, 22.04556084], [88.87835693, 22.04551125], [88.87786865, 22.04532242], [88.87740326, 22.04528236], [88.87696838, 22.04528999], [88.87654877, 22.0453968], [88.87637329, 22.04543686], [88.87613678, 22.04548264], [88.87569427, 22.04532433], [88.87521362, 22.04527855], [88.8747406, 22.04527473], [88.87426758, 22.04528236], [88.87380219, 22.04533386], [88.87335968, 22.04547119], [88.87291718, 22.04533958], [88.87245178, 22.04528236], [88.87198639, 22.04527664], [88.871521, 22.04528236], [88.87106323, 22.04528236], [88.8706131, 22.04528236], [88.86875916, 22.04528236], [88.86830139, 22.04528236], [88.86782837, 22.04528236], [88.86737823, 22.04527855], [88.8669281, 22.04528427], [88.86649323, 22.04535103], [88.86606598, 22.04552269], [88.86560822, 22.0455761], [88.86514282, 22.04569054], [88.8646698, 22.04578209], [88.86418915, 22.04568481], [88.86374664, 22.04557228], [88.86332703, 22.04554939], [88.86297607, 22.04557991], [88.86263275, 22.04569817], [88.86225128, 22.04581261], [88.86183167, 22.04583168], [88.86139679, 22.04585075], [88.86100006, 22.04595375], [88.86055756, 22.04611588], [88.86027527, 22.04611588], [88.86000061, 22.04583359], [88.85916901, 22.04583359], [88.8588562, 22.04583168], [88.85845184, 22.04579735], [88.85809326, 22.04562187], [88.85766602, 22.04556465], [88.85722351, 22.04555321], [88.85678101, 22.04551506], [88.85638428, 22.04532242], [88.85588074, 22.04527092], [88.85536957, 22.04520226], [88.8549118, 22.04499245], [88.85445404, 22.04476166], [88.8539505, 22.04462624], [88.85349274, 22.04443359], [88.85305786, 22.04419136], [88.85257721, 22.04398155], [88.85214233, 22.04380035], [88.85173035, 22.04360008], [88.85134125, 22.04335213], [88.85093689, 22.04316139], [88.85060883, 22.04297066], [88.85038757, 22.04270744], [88.85028839, 22.04232979], [88.8502121, 22.04191017], [88.85004425, 22.04148865], [88.85003662, 22.04103279], [88.8502121, 22.04058266], [88.85034943, 22.04006958], [88.85054016, 22.03956032], [88.85072327, 22.03903008], [88.85101318, 22.03857231], [88.85124969, 22.03808022], [88.85152435, 22.03762627], [88.85175323, 22.03714943], [88.85198975, 22.03672981], [88.85225677, 22.03638649], [88.85250092, 22.03607178], [88.85273743, 22.03576088], [88.85293579, 22.0354023], [88.85314178, 22.03494072], [88.85339355, 22.03452873], [88.85375214, 22.03416252], [88.85413361, 22.03380394], [88.85447693, 22.03341484], [88.85484314, 22.03306389], [88.85521698, 22.03273201], [88.85555267, 22.03236198], [88.85584259, 22.03194237], [88.85616302, 22.03150177], [88.85655975, 22.03107262], [88.85694122, 22.03057289], [88.85733032, 22.0300312], [88.85778046, 22.02951622], [88.85822296, 22.02898216], [88.85868073, 22.02837753], [88.85916138, 22.02780151], [88.85958862, 22.02721214], [88.85985565, 22.02662086], [88.85962677, 22.02603912], [88.85923004, 22.02557373], [88.85877991, 22.02518272], [88.85831451, 22.02490044], [88.85782623, 22.02470207], [88.85740662, 22.02444839], [88.85697937, 22.02422142], [88.85647583, 22.02409172], [88.85604095, 22.02388954], [88.85559845, 22.02368927], [88.85513306, 22.023592], [88.85470581, 22.02344513], [88.85428619, 22.0233326], [88.85389709, 22.02320862], [88.85347748, 22.02305031], [88.85301971, 22.02289581], [88.8524704, 22.02278709], [88.85189819, 22.02270317], [88.85134125, 22.02253532], [88.85076904, 22.02250099], [88.85019684, 22.02244949], [88.84970093, 22.02226067], [88.84907532, 22.02221107], [88.84835052, 22.02212715], [88.84754181, 22.02197266], [88.8471756, 22.02194786], [88.84674835, 22.02194023], [88.84616852, 22.02194405], [88.84554291, 22.0219326], [88.84493256, 22.02194023], [88.84436798, 22.02194405], [88.84385681, 22.02195168], [88.84342194, 22.02203178], [88.84307861, 22.02219772], [88.84269714, 22.02230835], [88.84234619, 22.02248955], [88.84194946, 22.02263451], [88.8415451, 22.02279091], [88.84116364, 22.02298164], [88.84070587, 22.02308273], [88.84030914, 22.02326012], [88.83988953, 22.02337074], [88.83946228, 22.02357292], [88.83895874, 22.02368927], [88.83850098, 22.02389908], [88.8380661, 22.02416611], [88.83763123, 22.02444267], [88.83721161, 22.02471924], [88.83679199, 22.02499199], [88.83635712, 22.02522278], [88.83596039, 22.02544975], [88.83565521, 22.02575302], [88.83544159, 22.02612114], [88.83527374, 22.02652931], [88.83512115, 22.02693939], [88.83499146, 22.02737999], [88.83486176, 22.02776909], [88.83473969, 22.0281353], [88.83465576, 22.02849579], [88.83449554, 22.02879143], [88.83440399, 22.02915192], [88.83421326, 22.02948189], [88.83412933, 22.02993965], [88.83408356, 22.03044891], [88.83413696, 22.03102112], [88.83411407, 22.03159714], [88.83392334, 22.03212166], [88.83374023, 22.03264618], [88.83358765, 22.033144], [88.83340454, 22.03357315], [88.83329773, 22.03399086], [88.8331604, 22.03434944], [88.83307648, 22.03465271], [88.83304596, 22.03495216], [88.83302307, 22.0352726], [88.83291626, 22.03555107], [88.83280945, 22.03583908], [88.83277893, 22.03617287], [88.83277893, 22.03655052], [88.83277893, 22.03695869], [88.83277893, 22.03738022], [88.83277893, 22.03781319], [88.83276367, 22.03822899], [88.8327179, 22.03859138], [88.83249664, 22.03889084], [88.83249664, 22.03971863], [88.83222198, 22.04000282], [88.83220673, 22.0400753], [88.83215332, 22.04039955], [88.83200073, 22.04074287], [88.83194733, 22.04116821], [88.83194733, 22.04162025], [88.83193207, 22.04208946], [88.83188629, 22.0425396], [88.83171844, 22.04294014], [88.83167267, 22.0433712], [88.83166504, 22.04379845], [88.83167267, 22.04422569], [88.83171844, 22.04465485], [88.83194733, 22.04504967], [88.83218384, 22.04549789], [88.83210754, 22.04615974], [88.8322525, 22.04679489], [88.8325119, 22.04739952], [88.83278656, 22.04801178], [88.83306122, 22.04861069], [88.83326721, 22.04917908], [88.83341217, 22.04972267], [88.83371735, 22.05008507], [88.83418274, 22.05024147], [88.83470917, 22.05027962], [88.83524323, 22.05027962], [88.83574677, 22.05027962], [88.83625031, 22.05030632], [88.83674622, 22.05040169], [88.83718872, 22.0505867], [88.83761597, 22.0508213], [88.83808136, 22.05113029], [88.83856201, 22.0514431], [88.83899689, 22.0518322], [88.83940125, 22.05225945], [88.83972931, 22.05271149], [88.840065, 22.05312538], [88.84037781, 22.05348206], [88.84072876, 22.05370331], [88.84117126, 22.05373192], [88.84168243, 22.05358315], [88.84221649, 22.05335045], [88.84279633, 22.05314445], [88.84333038, 22.05305672], [88.84361267, 22.05277824], [88.84416962, 22.05277824], [88.84444427, 22.05305672], [88.84456635, 22.05320168], [88.84471893, 22.05333519], [88.84500122, 22.05361176], [88.84500122, 22.05388069], [88.84429169, 22.05400658], [88.84365845, 22.05408859], [88.84306335, 22.05412102], [88.842453, 22.05413246], [88.84191132, 22.05423927], [88.8414917, 22.05449486], [88.84130096, 22.05485153], [88.84129333, 22.05532837], [88.84135437, 22.05579185], [88.84136963, 22.05618286], [88.84145355, 22.05654526], [88.84159851, 22.05695152], [88.84178925, 22.05740166], [88.84203339, 22.05787086], [88.84234619, 22.05829811], [88.84278107, 22.05865288], [88.84320831, 22.05900192], [88.84365082, 22.05930138], [88.84406281, 22.05964088], [88.8444519, 22.05999184], [88.84471893, 22.06028175], [88.84500122, 22.06028175], [88.84527588, 22.0605545], [88.84555054, 22.06083107], [88.84555054, 22.0616703], [88.84513092, 22.06152153], [88.84455872, 22.06126976], [88.84404755, 22.06099129], [88.84353638, 22.06065369], [88.84307098, 22.06019783], [88.84263611, 22.05973816], [88.84217072, 22.05940247], [88.84172058, 22.05913734], [88.841362, 22.05888176], [88.84107971, 22.05862236], [88.84085083, 22.05836105], [88.8406601, 22.05804062], [88.84056091, 22.05758095], [88.84047699, 22.05702019], [88.84044647, 22.05635262], [88.84037018, 22.05570793], [88.84018707, 22.05516243], [88.83991241, 22.05470085], [88.83963776, 22.05424118], [88.83933258, 22.05379295], [88.83898163, 22.05332947], [88.83860779, 22.05286217], [88.83822632, 22.05241203], [88.83782959, 22.05202293], [88.83740997, 22.05177689], [88.83701324, 22.05167961], [88.83661652, 22.05166245], [88.83622742, 22.05166054], [88.83583832, 22.05165291], [88.83541107, 22.05164146], [88.83489227, 22.05167961], [88.83429718, 22.05181313], [88.83374023, 22.05178261], [88.8332901, 22.05169106], [88.832901, 22.05167007], [88.83251953, 22.05168343], [88.83213043, 22.05177307], [88.83170319, 22.05195236], [88.83127594, 22.05219078], [88.83082581, 22.05241203], [88.83037567, 22.05265808], [88.82988739, 22.05293274], [88.82945251, 22.05331993], [88.8290329, 22.0537529], [88.82862091, 22.05415916], [88.82818604, 22.05456924], [88.82770538, 22.05497742], [88.82715607, 22.05537224], [88.82663727, 22.05582428], [88.82608795, 22.05627251], [88.82553101, 22.05672264], [88.82499695, 22.05718994], [88.82444, 22.05758095], [88.82390594, 22.05793953], [88.8234024, 22.05830193], [88.82292175, 22.05870247], [88.82237244, 22.05901146], [88.82182312, 22.05935287], [88.82139587, 22.05983162], [88.82103729, 22.06033134], [88.82069397, 22.0607605], [88.82034302, 22.06110954], [88.82003021, 22.06144333], [88.81980133, 22.06178474], [88.81973267, 22.06221962], [88.81944275, 22.06250191], [88.81944275, 22.06305695], [88.81972504, 22.06333351], [88.81973267, 22.06361198], [88.81999969, 22.06389046], [88.81999969, 22.06417274], [88.82016754, 22.06430626], [88.82030487, 22.06441307], [88.82055664, 22.06467056], [88.82102966, 22.06498718], [88.82147217, 22.06546211], [88.82189178, 22.06595039], [88.82227325, 22.06639671], [88.82276154, 22.06681633], [88.82328033, 22.06733131], [88.82383728, 22.06781197], [88.82437897, 22.06814766], [88.82482147, 22.06845474], [88.82527161, 22.0687809], [88.82578278, 22.06912613], [88.82636261, 22.06942177], [88.82692719, 22.06969833], [88.82748413, 22.06993484], [88.82806396, 22.07004929], [88.82855988, 22.07016563], [88.82898712, 22.07013512], [88.82932281, 22.0700016], [88.82961273, 22.06981087], [88.82984924, 22.06956673], [88.83004761, 22.06925011], [88.83027649, 22.06892204], [88.83056641, 22.06860161], [88.83088684, 22.06828117], [88.83122253, 22.06795311], [88.83156586, 22.06759071], [88.83190155, 22.06720543], [88.83216858, 22.06677055], [88.8323288, 22.06630135], [88.8324585, 22.06585121], [88.83252716, 22.06537056], [88.83263397, 22.06490517], [88.83281708, 22.06450081], [88.83309937, 22.0641613], [88.83346558, 22.06390953], [88.83390045, 22.06377602], [88.8343811, 22.06389046], [88.83483124, 22.06414986], [88.83527374, 22.06446648], [88.83571625, 22.06480598], [88.83615875, 22.06515121], [88.83653259, 22.06542778], [88.83685303, 22.0656414], [88.83708954, 22.06585121], [88.83727264, 22.06612968], [88.8373642, 22.06661034], [88.83743286, 22.06718254], [88.83747101, 22.06775284], [88.83756256, 22.06828117], [88.83750153, 22.06861115], [88.83732605, 22.06974983], [88.83675385, 22.0707531], [88.83631897, 22.07169151], [88.83616638, 22.07209969], [88.83602905, 22.07249641], [88.83602905, 22.07283211]]], [[[88.90408325, 22.08420753], [88.90367126, 22.08382988], [88.90328217, 22.08344078], [88.90287018, 22.08313179], [88.90254211, 22.08282852], [88.90219116, 22.08261299], [88.90180206, 22.08245659], [88.90148163, 22.08221245], [88.90112305, 22.08191109], [88.90076447, 22.08160973], [88.90033722, 22.0813427], [88.8999176, 22.08105469], [88.89943695, 22.08081245], [88.89898682, 22.08052254], [88.89864349, 22.08016777], [88.89834595, 22.0797596], [88.89803314, 22.07941246], [88.89768982, 22.07907867], [88.89735413, 22.07876015], [88.89698029, 22.07849121], [88.89662933, 22.07817268], [88.89624023, 22.07788467], [88.89585876, 22.077528], [88.89547729, 22.07715034], [88.89509583, 22.07676125], [88.8947525, 22.07632256], [88.89444733, 22.07585144], [88.89417267, 22.07542229], [88.89393616, 22.07502937], [88.89377594, 22.07463455], [88.89362335, 22.07429314], [88.89341736, 22.07395363], [88.89325714, 22.07354164], [88.89303589, 22.07310295], [88.89279938, 22.07264328], [88.89263916, 22.07208443], [88.8924942, 22.07150841], [88.89232635, 22.07092476], [88.89222717, 22.07030296], [88.89215851, 22.0696888], [88.89196014, 22.06915092], [88.89179993, 22.06861115], [88.89167023, 22.06806183], [88.89154816, 22.06752586], [88.89141846, 22.06701088], [88.89134979, 22.0664711], [88.89115143, 22.06593132], [88.89111328, 22.06533241], [88.89110565, 22.06470108], [88.89111328, 22.06403923], [88.89113617, 22.06336021], [88.89122009, 22.06269264], [88.89137268, 22.06208229], [88.89135742, 22.06147385], [88.89118195, 22.06089211], [88.89090729, 22.06035614], [88.89034271, 22.06013489], [88.88970947, 22.0602417], [88.88905334, 22.06027031], [88.88842773, 22.06020164], [88.88788605, 22.06002808], [88.88737488, 22.05999947], [88.88690186, 22.05997276], [88.8864975, 22.05983925], [88.88609314, 22.05973816], [88.88566589, 22.05972099], [88.88523865, 22.05972099], [88.8848114, 22.05968285], [88.88439941, 22.05948067], [88.88386536, 22.05944443], [88.88326263, 22.05945015], [88.88297272, 22.05944443], [88.8826828, 22.05947304], [88.88230133, 22.05962181], [88.88182831, 22.05976105], [88.88134003, 22.06001091], [88.88082886, 22.06028175], [88.88027954, 22.0605545], [88.87973022, 22.06083679], [88.87919617, 22.06110954], [88.87866211, 22.06138039], [88.87813568, 22.06157875], [88.87760925, 22.0617218], [88.8771286, 22.06189156], [88.87656403, 22.06198692], [88.87600708, 22.06217957], [88.87536621, 22.06226158], [88.87477112, 22.06245232], [88.87412262, 22.06250191], [88.87346649, 22.0625515], [88.87285614, 22.06276131], [88.87224579, 22.06300163], [88.87168884, 22.0633564], [88.87129211, 22.06385231], [88.87096405, 22.06435776], [88.8707962, 22.06490135], [88.87058258, 22.06535149], [88.87044525, 22.06579781], [88.87030792, 22.06624413], [88.8702774, 22.06676483], [88.8702774, 22.0673275], [88.8702774, 22.06790924], [88.8702774, 22.06851006], [88.87029266, 22.06910133], [88.87037659, 22.06967545], [88.87052917, 22.0702343], [88.87055206, 22.07077217], [88.87056732, 22.07131195], [88.87069702, 22.07182121], [88.87084961, 22.07241631], [88.87110901, 22.07302284], [88.87137604, 22.07362747], [88.87158203, 22.07421112], [88.8717041, 22.0747509], [88.87188721, 22.07514], [88.87194061, 22.07552147], [88.87198639, 22.07585144], [88.87217712, 22.07614708], [88.8722229, 22.07650185], [88.8722229, 22.07690048], [88.8722229, 22.07731247], [88.8722229, 22.07775307], [88.8722229, 22.07818985], [88.8722229, 22.07863045], [88.8722229, 22.07907295], [88.87218475, 22.07946777], [88.87203217, 22.07980347], [88.87195587, 22.08015442], [88.87190247, 22.08051109], [88.87171936, 22.08081245], [88.87158203, 22.08118248], [88.87137604, 22.08152962], [88.87110901, 22.08189964], [88.87083435, 22.08231735], [88.87055206, 22.08274269], [88.8702774, 22.08316231], [88.87000275, 22.08349037], [88.86974335, 22.08377266], [88.86955261, 22.0840683], [88.86942291, 22.08438492], [88.86924744, 22.08468056], [88.86924744, 22.08506966], [88.86940002, 22.08556175], [88.86950684, 22.08614159], [88.86978912, 22.08659172], [88.87020874, 22.08690071], [88.87072754, 22.08699226], [88.87124634, 22.08681297], [88.87174225, 22.08659363], [88.87224579, 22.08641815], [88.8727417, 22.08634377], [88.87321472, 22.08616829], [88.87374115, 22.08611107], [88.87425232, 22.08605003], [88.87468719, 22.0858326], [88.87509155, 22.08559418], [88.87554169, 22.08538628], [88.8759613, 22.08514977], [88.87641144, 22.08490944], [88.87686157, 22.08471107], [88.87726593, 22.08449173], [88.87773132, 22.08440971], [88.8781662, 22.0842495], [88.87870026, 22.08418083], [88.87932587, 22.08416367], [88.88001251, 22.08412361], [88.88070679, 22.08395958], [88.88140106, 22.08394241], [88.88202667, 22.08416367], [88.88260651, 22.08438492], [88.88315582, 22.08450127], [88.88363647, 22.08468056], [88.88417816, 22.08477974], [88.88468933, 22.0849514], [88.88526917, 22.08505058], [88.88580322, 22.08527946], [88.88633728, 22.08556747], [88.88690186, 22.08588028], [88.88747406, 22.08626556], [88.88802338, 22.08670235], [88.88854218, 22.08712959], [88.88907623, 22.08741951], [88.8895874, 22.08764076], [88.89006805, 22.08779716], [88.89050293, 22.08798409], [88.89096832, 22.08810234], [88.89138794, 22.08833122], [88.89186859, 22.08851051], [88.89238739, 22.08859825], [88.89292145, 22.08861351], [88.89343262, 22.08865356], [88.89383698, 22.0888195], [88.89433289, 22.08889198], [88.89483643, 22.08895302], [88.8953476, 22.08913231], [88.89597321, 22.08917046], [88.89659882, 22.08917046], [88.8972168, 22.08915138], [88.89776611, 22.08903313], [88.89830017, 22.08887482], [88.89877319, 22.0886097], [88.89920807, 22.08834267], [88.8996582, 22.08814049], [88.90016937, 22.08802032], [88.90058136, 22.08781624], [88.90104675, 22.08775139], [88.90145874, 22.08757973], [88.90189362, 22.08750534], [88.90232849, 22.08744812], [88.90273285, 22.08727074], [88.90319824, 22.08722115], [88.90368652, 22.08712959], [88.90410614, 22.08691978], [88.90444183, 22.08658218], [88.90467834, 22.08616447], [88.90471649, 22.08565331], [88.90465546, 22.08512115], [88.90441895, 22.08463478], [88.90408325, 22.08420753]]], [[[88.7758255, 22.09358978], [88.77599335, 22.09390068], [88.77613068, 22.09423256], [88.77629852, 22.09452438], [88.77638245, 22.09484291], [88.77645874, 22.09517097], [88.77661133, 22.09546852], [88.7766571, 22.09584999], [88.77671051, 22.09626961], [88.77688599, 22.09668159], [88.77694702, 22.0971508], [88.77697754, 22.09763527], [88.77710724, 22.09808159], [88.77720642, 22.09854317], [88.77723694, 22.09901237], [88.77738953, 22.09948158], [88.7775116, 22.09997749], [88.7776947, 22.1004734], [88.7779007, 22.10097313], [88.77807617, 22.10153008], [88.77833557, 22.1020565], [88.77863312, 22.10256004], [88.77899933, 22.10300255], [88.77945709, 22.10334587], [88.77990723, 22.10367012], [88.78031158, 22.10404015], [88.78072357, 22.10433388], [88.78111267, 22.10459137], [88.7815094, 22.10483742], [88.78189087, 22.10508156], [88.7822113, 22.10538483], [88.78248596, 22.1057148], [88.7827301, 22.10606384], [88.78299713, 22.10638237], [88.78333282, 22.10667038], [88.78375244, 22.10694313], [88.78427124, 22.10717392], [88.78492737, 22.10727119], [88.78556061, 22.10746193], [88.78620148, 22.10749817], [88.78678894, 22.10750008], [88.78730774, 22.10753059], [88.78781128, 22.10767174], [88.78829956, 22.10777092], [88.7888031, 22.10778046], [88.78929138, 22.10778046], [88.78975677, 22.10778046], [88.79022217, 22.10779762], [88.79065704, 22.10789299], [88.79109192, 22.10803795], [88.7915802, 22.1081295], [88.79203796, 22.10831261], [88.79254913, 22.1084137], [88.79304504, 22.10857773], [88.79357147, 22.10863495], [88.79406738, 22.10878944], [88.79457092, 22.10889435], [88.79509735, 22.10900307], [88.79567719, 22.1091404], [88.79627991, 22.10917282], [88.79689026, 22.10913277], [88.79746246, 22.10894012], [88.79802704, 22.10889435], [88.79853058, 22.10872841], [88.79889679, 22.1083622], [88.79927826, 22.10794258], [88.79959106, 22.10744476], [88.79978943, 22.10688019], [88.79999542, 22.10639191], [88.8001709, 22.10592461], [88.80026245, 22.10545349], [88.80032349, 22.10497856], [88.8004303, 22.10453987], [88.80033875, 22.10404015], [88.80029297, 22.10352135], [88.80020142, 22.10300064], [88.79994202, 22.10255241], [88.79960632, 22.1021347], [88.79924011, 22.10172081], [88.79891205, 22.10131264], [88.79865265, 22.10090065], [88.79849243, 22.10045242], [88.79836273, 22.09997177], [88.79829407, 22.09949684], [88.79818726, 22.0990696], [88.79827881, 22.09867477], [88.79833984, 22.09834099], [88.79844666, 22.09808159], [88.79862976, 22.09784126], [88.79888153, 22.09756279], [88.79917145, 22.09719849], [88.79951477, 22.09683609], [88.79995728, 22.09655952], [88.8004303, 22.09623146], [88.80084991, 22.09585762], [88.80127716, 22.09547234], [88.80164337, 22.09502983], [88.80190277, 22.09455299], [88.80207825, 22.09404945], [88.80226135, 22.09359169], [88.80243683, 22.09313011], [88.80246735, 22.09261131], [88.80241394, 22.09209251], [88.80225372, 22.09161186], [88.80210876, 22.0911541], [88.80194092, 22.09073257], [88.80175781, 22.09033585], [88.80163574, 22.08990479], [88.80148315, 22.0895195], [88.80142212, 22.08915138], [88.80149841, 22.08880043], [88.80166626, 22.08846092], [88.80187225, 22.08810234], [88.80204773, 22.08768272], [88.80223846, 22.08726692], [88.80246735, 22.08687019], [88.80267334, 22.08644485], [88.80294037, 22.08606148], [88.8032074, 22.08567619], [88.8034668, 22.08527374], [88.80375671, 22.08487129], [88.80408478, 22.08452415], [88.8044281, 22.08419609], [88.80477905, 22.08392143], [88.80517578, 22.08369255], [88.80552673, 22.08342171], [88.80584717, 22.08311272], [88.80619812, 22.08279991], [88.8065567, 22.08250999], [88.80696106, 22.08228493], [88.80745697, 22.08218956], [88.80796814, 22.08204079], [88.80847168, 22.08192635], [88.80892181, 22.08179283], [88.80937958, 22.08168983], [88.80988312, 22.08160973], [88.81036377, 22.08143425], [88.81084442, 22.08133888], [88.81118774, 22.08120155], [88.81151581, 22.0811348], [88.81186676, 22.08110237], [88.81224823, 22.08104515], [88.81266785, 22.08089256], [88.81315613, 22.08083916], [88.81363678, 22.08080101], [88.81411743, 22.08070946], [88.81458282, 22.0805912], [88.8150177, 22.08058357], [88.8154068, 22.08070946], [88.8157959, 22.08091354], [88.81619263, 22.08116913], [88.81659698, 22.08144188], [88.81703186, 22.08173561], [88.81746674, 22.08197975], [88.81789398, 22.08223724], [88.81832123, 22.08250237], [88.81874084, 22.08278084], [88.81916809, 22.08301544], [88.81961823, 22.08313942], [88.81996918, 22.08330917], [88.82026672, 22.08344078], [88.82054901, 22.08363152], [88.82085419, 22.08388138], [88.82126617, 22.08414268], [88.82174683, 22.08436012], [88.82227325, 22.08450127], [88.82276154, 22.08467102], [88.82328796, 22.0847702], [88.82376862, 22.0849514], [88.82428741, 22.08506393], [88.82471466, 22.08527756], [88.82511902, 22.08554459], [88.82553864, 22.08582115], [88.82598877, 22.08610344], [88.82652283, 22.0863266], [88.82715607, 22.08631325], [88.82778168, 22.08603477], [88.82826996, 22.08564568], [88.82879639, 22.08527946], [88.8292923, 22.08490944], [88.82969666, 22.08445168], [88.83006287, 22.08395958], [88.83040619, 22.08350563], [88.8307724, 22.08311272], [88.83109283, 22.08271217], [88.83131409, 22.08230591], [88.83145142, 22.08184814], [88.83164215, 22.08138084], [88.83178711, 22.0808506], [88.8319931, 22.0802803], [88.83222198, 22.07975769], [88.8324585, 22.07927132], [88.83261871, 22.07880211], [88.83277893, 22.07842064], [88.83293152, 22.07805061], [88.83309174, 22.07764244], [88.83329773, 22.07721138], [88.83345032, 22.07671738], [88.83361053, 22.07624245], [88.83379364, 22.07582664], [88.83395386, 22.07546806], [88.83415985, 22.07521248], [88.83435822, 22.07497978], [88.83454132, 22.07473755], [88.83473969, 22.0744915], [88.83492279, 22.07420158], [88.83496857, 22.0737896], [88.83495331, 22.07333183], [88.83486938, 22.07287979], [88.83492279, 22.07245064], [88.83518982, 22.07211113], [88.83545685, 22.07172966], [88.83570099, 22.07124138], [88.83589935, 22.07074165], [88.83610535, 22.07030869], [88.83629608, 22.06989098], [88.83641815, 22.06941986], [88.83654022, 22.06887245], [88.83661652, 22.06826973], [88.83662415, 22.06761169], [88.8365097, 22.06693077], [88.83621216, 22.06633949], [88.83574677, 22.06588173], [88.83521271, 22.06550789], [88.8347168, 22.06517982], [88.8343277, 22.06496239], [88.83400726, 22.06492043], [88.83377838, 22.06507301], [88.83358002, 22.06532097], [88.83345032, 22.06565666], [88.83336639, 22.06598282], [88.83330536, 22.06634712], [88.83322906, 22.06671333], [88.83309174, 22.06706047], [88.83296204, 22.06746101], [88.83270264, 22.06786156], [88.83229065, 22.06831169], [88.83184052, 22.06876183], [88.83142853, 22.06929016], [88.83110809, 22.06984138], [88.83082581, 22.07036018], [88.83052826, 22.07082367], [88.8301239, 22.07118034], [88.82949829, 22.07137489], [88.82920837, 22.07142448], [88.82876587, 22.07150078], [88.82807922, 22.07141304], [88.82744598, 22.07128906], [88.82697296, 22.07109261], [88.82656097, 22.07085228], [88.8261795, 22.0706501], [88.82581329, 22.07056427], [88.82552338, 22.07065964], [88.82499695, 22.0700016], [88.82472229, 22.0700016], [88.82444, 22.06972122], [88.8236084, 22.06972122], [88.8236084, 22.06944466], [88.82389069, 22.06916618], [88.8236084, 22.06889153], [88.8236084, 22.06861115], [88.82319641, 22.06839943], [88.82281494, 22.06812859], [88.82237244, 22.06788063], [88.82196045, 22.06754112], [88.82154083, 22.06711006], [88.82102966, 22.06665611], [88.82047272, 22.06617165], [88.81990051, 22.06568909], [88.81941986, 22.06514168], [88.81912231, 22.06446266], [88.81877899, 22.06382942], [88.81830597, 22.06336212], [88.81768799, 22.06308937], [88.81698608, 22.06297112], [88.81629944, 22.06297112], [88.81565094, 22.06284142], [88.81508636, 22.06261253], [88.81456757, 22.06246185], [88.81417084, 22.06226158], [88.81377411, 22.06215858], [88.81344604, 22.06200981], [88.81307983, 22.06195259], [88.81269836, 22.06195259], [88.81233215, 22.06202126], [88.81201935, 22.06215096], [88.81167603, 22.06221199], [88.81139374, 22.0622673], [88.81118774, 22.0624218], [88.81105804, 22.06265068], [88.81092834, 22.06289101], [88.81098175, 22.06316376], [88.81138611, 22.06361198], [88.81111145, 22.06389046], [88.81083679, 22.06389046], [88.81054688, 22.06361198], [88.81046295, 22.06357384], [88.81007385, 22.06339073], [88.80966187, 22.0634346], [88.80931091, 22.06368065], [88.80896759, 22.06406212], [88.80851746, 22.06441879], [88.80800629, 22.06476021], [88.80748749, 22.06508827], [88.8069458, 22.0653553], [88.80638885, 22.06557274], [88.80582428, 22.06576347], [88.8056488, 22.06575584], [88.80521393, 22.06573677], [88.80459595, 22.06557274], [88.80400085, 22.06537056], [88.8034668, 22.06509209], [88.80313873, 22.06470108], [88.80285645, 22.06427383], [88.80252075, 22.06391144], [88.80218506, 22.06352615], [88.80193329, 22.06298828], [88.80171967, 22.06240463], [88.80162811, 22.06178284], [88.80149841, 22.06123161], [88.80136108, 22.06077003], [88.80119324, 22.06043053], [88.80110168, 22.06007195], [88.80099487, 22.05973625], [88.80084991, 22.05939293], [88.8007431, 22.05900192], [88.80049896, 22.05862808], [88.80018616, 22.05825996], [88.79977417, 22.05792046], [88.7993927, 22.05751991], [88.79898071, 22.0571804], [88.79859161, 22.0568409], [88.798172, 22.05653954], [88.79769897, 22.05635071], [88.79727173, 22.05616951], [88.79679871, 22.05611801], [88.79631805, 22.05610275], [88.79582214, 22.05604935], [88.79532623, 22.05587959], [88.79473877, 22.0557785], [88.79415131, 22.05566216], [88.79354858, 22.05578423], [88.79296875, 22.0558815], [88.79252625, 22.05610275], [88.79218292, 22.05641556], [88.79190826, 22.0567894], [88.79160309, 22.05721283], [88.79125977, 22.05764008], [88.79097748, 22.05810165], [88.79084015, 22.05859947], [88.79076385, 22.05903435], [88.79059601, 22.05936241], [88.79051971, 22.0596981], [88.79033661, 22.05995941], [88.79017639, 22.06028175], [88.7899704, 22.06064224], [88.78971863, 22.06083107], [88.78888702, 22.0616703], [88.78864288, 22.06166267], [88.78837585, 22.06169891], [88.78806305, 22.06189156], [88.78765106, 22.06208038], [88.78742981, 22.06260109], [88.7875061, 22.06329536], [88.78767395, 22.06399536], [88.78783417, 22.06469345], [88.78808594, 22.06531143], [88.78839111, 22.06594276], [88.78865814, 22.06664085], [88.78865814, 22.0673027], [88.78868866, 22.06790924], [88.78864288, 22.06850243], [88.78859711, 22.06912041], [88.78853607, 22.06977272], [88.78845215, 22.07040024], [88.78833008, 22.07083321], [88.78833008, 22.07111168], [88.78806305, 22.07139015], [88.78778076, 22.07139015], [88.78749847, 22.07167244], [88.78749847, 22.07194328], [88.78739166, 22.07205009], [88.78721619, 22.07222176], [88.78666687, 22.07166862], [88.78666687, 22.07139015], [88.78694153, 22.07111168], [88.78697205, 22.07098579], [88.78726959, 22.07045174], [88.78739166, 22.06986046], [88.78730774, 22.06923294], [88.78730774, 22.06858253], [88.78730774, 22.06790924], [88.78743744, 22.0672226], [88.78741455, 22.06658554], [88.78726196, 22.0660305], [88.78714752, 22.06551933], [88.78697968, 22.06509209], [88.78687286, 22.06467056], [88.78672028, 22.06430054], [88.78662109, 22.06388283], [88.78646851, 22.06347084], [88.78637695, 22.06289101], [88.78633118, 22.06226158], [88.78613281, 22.06184387], [88.78594208, 22.06150246], [88.7857666, 22.06118202], [88.78556824, 22.06088066], [88.78538513, 22.06049156], [88.7852478, 22.05999947], [88.78499603, 22.0595417], [88.78479767, 22.05907249], [88.784729, 22.05857277], [88.78470612, 22.05810165], [88.7845993, 22.05766487], [88.7844696, 22.05722237], [88.78444672, 22.05672646], [88.7844162, 22.05621147], [88.78431702, 22.05570793], [88.78418732, 22.0551815], [88.78412628, 22.05461311], [88.78397369, 22.05408669], [88.78388214, 22.05351067], [88.78375244, 22.05291939], [88.78360748, 22.05233955], [88.78343964, 22.05175972], [88.78333282, 22.05115318], [88.78320313, 22.05058289], [88.78305817, 22.05005074], [88.78289795, 22.04957008], [88.78269196, 22.04917908], [88.7824173, 22.04882813], [88.78196716, 22.04860115], [88.78150177, 22.04839134], [88.78124237, 22.04836273], [88.78102112, 22.04843521], [88.78076935, 22.04861832], [88.78048706, 22.04887962], [88.78016663, 22.04916954], [88.77980804, 22.04947853], [88.77945709, 22.04985237], [88.77916718, 22.05028915], [88.77883911, 22.05072975], [88.77845764, 22.05110168], [88.77805328, 22.05142021], [88.77761078, 22.05169106], [88.7771759, 22.05198097], [88.77675629, 22.05227852], [88.77636719, 22.05262375], [88.77594757, 22.05291939], [88.77554321, 22.05316544], [88.77527618, 22.05333519], [88.77500153, 22.05333519], [88.77471924, 22.05361366], [88.77416992, 22.05361366], [88.77388763, 22.05388832], [88.77361298, 22.05388069], [88.77333069, 22.05417061], [88.77305603, 22.05417061], [88.77295685, 22.05428123], [88.77265167, 22.05441093], [88.77249908, 22.0544529], [88.77222443, 22.05444527], [88.77194214, 22.05472374], [88.77166748, 22.05444527], [88.77111053, 22.0544529], [88.77083588, 22.05417061], [88.77030945, 22.05417442], [88.7698822, 22.05416679], [88.76944733, 22.05417061], [88.76902008, 22.05417061], [88.76857758, 22.05417061], [88.7681427, 22.05416107], [88.76767731, 22.05411339], [88.76722717, 22.0539341], [88.76674652, 22.05388451], [88.76629639, 22.0538311], [88.76596832, 22.05367088], [88.765625, 22.05361748], [88.76526642, 22.05361176], [88.76490784, 22.05358315], [88.764534, 22.05343819], [88.76413727, 22.05335045], [88.76371765, 22.05332947], [88.76332855, 22.05338097], [88.7629776, 22.0535717], [88.76261139, 22.05361176], [88.76223755, 22.05362129], [88.76184845, 22.05366516], [88.76145935, 22.0538311], [88.76097107, 22.05393028], [88.7604599, 22.05416107], [88.75990295, 22.05436134], [88.7592392, 22.05443954], [88.75853729, 22.05451012], [88.75791168, 22.05472755], [88.75728607, 22.05496407], [88.7565918, 22.05509567], [88.75591278, 22.05529213], [88.75524139, 22.05552101], [88.75453186, 22.05564308], [88.7538681, 22.05583763], [88.75322723, 22.05603027], [88.75255585, 22.05610275], [88.75224304, 22.05610657], [88.75193787, 22.05611229], [88.75134277, 22.05603981], [88.7509613, 22.05586815], [88.75055695, 22.05579948], [88.75018311, 22.05572319], [88.74978638, 22.05589867], [88.74945831, 22.05620384], [88.74916077, 22.05653954], [88.74888611, 22.05685616], [88.74862671, 22.05713272], [88.74842834, 22.05742264], [88.74829865, 22.05779076], [88.74809265, 22.05817032], [88.74797821, 22.05870247], [88.74794006, 22.05930138], [88.74806976, 22.05985069], [88.74832153, 22.06031609], [88.74855804, 22.06076241], [88.74884033, 22.06116486], [88.74907684, 22.06158257], [88.74932098, 22.0619812], [88.74949646, 22.0623951], [88.74972534, 22.06274223], [88.74996185, 22.06307411], [88.75007629, 22.06352043], [88.7502594, 22.06394768], [88.7503891, 22.06440353], [88.7505722, 22.06483269], [88.75080109, 22.06522179], [88.75093079, 22.06563759], [88.75109863, 22.06606483], [88.75123596, 22.06649971], [88.75139618, 22.06692314], [88.75164795, 22.0673027], [88.75187683, 22.06772232], [88.75211334, 22.06820107], [88.75242615, 22.0686512], [88.75273132, 22.06913185], [88.75297546, 22.06965828], [88.75315094, 22.07024193], [88.7533493, 22.07079124], [88.75357819, 22.0712719], [88.75370789, 22.07175255], [88.75389862, 22.07217789], [88.75409698, 22.07258034], [88.75428009, 22.07302094], [88.7545166, 22.07339478], [88.75482941, 22.07373619], [88.75507355, 22.07411194], [88.75531769, 22.07441139], [88.75551605, 22.07469177], [88.75554657, 22.0750103], [88.75583649, 22.07527542], [88.75583649, 22.07559013], [88.75590515, 22.07588768], [88.756073, 22.076231], [88.75614929, 22.07673073], [88.75637817, 22.07722282], [88.75663757, 22.07773781], [88.75697327, 22.07825661], [88.75738525, 22.07879066], [88.75778961, 22.07938957], [88.75824738, 22.07991791], [88.75868988, 22.08036232], [88.75910187, 22.08076286], [88.75954437, 22.08110619], [88.76006317, 22.08139038], [88.76062012, 22.08165169], [88.76126099, 22.08181381], [88.76190186, 22.08197212], [88.76245117, 22.08222008], [88.76296997, 22.08244896], [88.7634964, 22.08254051], [88.7639389, 22.08274269], [88.76446533, 22.08282852], [88.76494598, 22.08304405], [88.76548004, 22.08326149], [88.76600647, 22.08350945], [88.76655579, 22.0837574], [88.76714325, 22.08394241], [88.76767731, 22.08418083], [88.76815796, 22.08441925], [88.76857758, 22.08464432], [88.76886749, 22.08492851], [88.76908112, 22.08525276], [88.76940155, 22.08549309], [88.7697525, 22.08547211], [88.76996613, 22.08546448], [88.77068329, 22.08517075], [88.77121735, 22.08502007], [88.77154541, 22.08509636], [88.77164459, 22.08537483], [88.77151489, 22.08582306], [88.77108002, 22.08627129], [88.77036285, 22.08646965], [88.77076721, 22.08675957], [88.77124786, 22.08719254], [88.77172852, 22.08757973], [88.77217865, 22.08792305], [88.77249146, 22.08826256], [88.77272797, 22.08856964], [88.77292633, 22.08887672], [88.77316284, 22.0891819], [88.77340698, 22.08954048], [88.77368164, 22.08995819], [88.77398682, 22.09037971], [88.77430725, 22.09082985], [88.77459717, 22.09129143], [88.77484131, 22.09177971], [88.77507782, 22.09221458], [88.77529144, 22.09260559], [88.7755127, 22.09293365], [88.77565002, 22.09328461], [88.7758255, 22.09358978]]], [[[88.69005585, 22.07998466], [88.68985748, 22.07998085], [88.68950653, 22.08031273], [88.68947601, 22.08078957], [88.68896484, 22.08111191], [88.68899536, 22.08190346], [88.68953705, 22.08190346], [88.69036102, 22.08107185], [88.69035339, 22.08048058], [88.69005585, 22.07998466]]], [[[88.29110718, 21.59527969], [88.29165649, 21.59527969], [88.29194641, 21.59555817], [88.29222107, 21.59555626], [88.29250336, 21.59583282], [88.29305267, 21.59583282], [88.29333496, 21.59555626], [88.29360962, 21.59555817], [88.29389191, 21.59527969], [88.29416656, 21.59527969], [88.29444122, 21.59500122], [88.29473114, 21.59500122], [88.29582977, 21.59389114], [88.29582977, 21.59361076], [88.29611206, 21.59332085], [88.29638672, 21.5933342], [88.29666901, 21.59305763], [88.29693604, 21.59305954], [88.29779053, 21.59222031], [88.29805756, 21.59222221], [88.29833221, 21.59194565], [88.2986145, 21.59194565], [88.3013916, 21.58916664], [88.30222321, 21.58917046], [88.3033371, 21.58805275], [88.3033371, 21.58777809], [88.3041687, 21.58694267], [88.30444336, 21.58694458], [88.30500031, 21.58638954], [88.30500031, 21.58527946], [88.30473328, 21.58499908], [88.30583191, 21.58389091], [88.30583191, 21.58361053], [88.30610657, 21.58332825], [88.3061142, 21.58194351], [88.30583191, 21.58166885], [88.30583191, 21.58111], [88.3061142, 21.58083344], [88.3061142, 21.5802784], [88.30555725, 21.57971954], [88.30555725, 21.57944679], [88.30500031, 21.57888794], [88.30500031, 21.57860947], [88.30444336, 21.57805443], [88.30444336, 21.57749939], [88.3033371, 21.57639122], [88.3033371, 21.57611084], [88.30278015, 21.57557106], [88.30249786, 21.57557106], [88.30194092, 21.57500076], [88.30194092, 21.57444191], [88.30166626, 21.57416725], [88.30166626, 21.57389069], [88.30110931, 21.57333183], [88.30110931, 21.57305527], [88.30053711, 21.57250023], [88.30053711, 21.57195282], [88.29965973, 21.57106018], [88.2986145, 21.56999969], [88.29833221, 21.56999969], [88.29779053, 21.56944084], [88.29777527, 21.56916618], [88.29666901, 21.56805992], [88.29666901, 21.56750107], [88.29582977, 21.56666946], [88.29556274, 21.56666946], [88.29499817, 21.56611061], [88.29438782, 21.56611061], [88.29416656, 21.56611061], [88.29360962, 21.56555939], [88.29360962, 21.56545067], [88.29360962, 21.56527519], [88.29305267, 21.56472015], [88.29305267, 21.56444359], [88.29166412, 21.56305313], [88.29138947, 21.56305313], [88.2911377, 21.56330681], [88.29027557, 21.56416512], [88.2902832, 21.56500053], [88.29000092, 21.56527519], [88.29000092, 21.56583023], [88.28971863, 21.56611061], [88.28971863, 21.56640053], [88.28943634, 21.56666946], [88.28916931, 21.56666756], [88.28861237, 21.5672226], [88.28805542, 21.56666756], [88.28806305, 21.56640053], [88.28749847, 21.56583023], [88.28749847, 21.56527519], [88.28778076, 21.56500053], [88.28778076, 21.56361008], [88.28583527, 21.56166649], [88.28556061, 21.5616703], [88.28527832, 21.56195068], [88.28444672, 21.56195068], [88.2841568, 21.5616703], [88.28388977, 21.5616703], [88.28360748, 21.56138992], [88.28333282, 21.56138992], [88.28305817, 21.56110954], [88.28277588, 21.56111145], [88.28250122, 21.56083107], [88.28221893, 21.56083107], [88.28152466, 21.56064987], [88.28056335, 21.56027031], [88.27999878, 21.56027794], [88.27972412, 21.55999947], [88.27944183, 21.55999947], [88.27916718, 21.5597229], [88.27889252, 21.5597229], [88.27861023, 21.55944443], [88.27805328, 21.55944443], [88.27777863, 21.55916595], [88.27694702, 21.55917168], [88.2766571, 21.55888939], [88.27639008, 21.55888939], [88.27583313, 21.55944443], [88.27555847, 21.55944443], [88.27527618, 21.5597229], [88.27500153, 21.55944443], [88.27361298, 21.55944443], [88.27333069, 21.55916595], [88.27305603, 21.55917168], [88.27249908, 21.55861092], [88.27194214, 21.55861092], [88.27166748, 21.55833054], [88.27138519, 21.55833244], [88.27119446, 21.55813789], [88.27111053, 21.55805588], [88.27085114, 21.5580616], [88.27056122, 21.55777931], [88.26889038, 21.55777931], [88.26860809, 21.5580616], [88.26611328, 21.55805588], [88.26583099, 21.55833244], [88.26555634, 21.55833244], [88.26444244, 21.55944443], [88.26444244, 21.5597229], [88.26249695, 21.5597229], [88.26222229, 21.55999947], [88.26082611, 21.55999947], [88.26027679, 21.56011963], [88.26000214, 21.56011963], [88.25970459, 21.56005478], [88.25944519, 21.55999947], [88.25749969, 21.55999947], [88.25666809, 21.56083107], [88.25583649, 21.56083107], [88.2555542, 21.56111145], [88.25499725, 21.56110954], [88.2547226, 21.56138992], [88.25389099, 21.56138992], [88.2536087, 21.5616703], [88.25332642, 21.5616703], [88.25305176, 21.56195068], [88.2527771, 21.56194305], [88.25250244, 21.56222153], [88.25166321, 21.56221962], [88.2497406, 21.56417084], [88.2491684, 21.56417084], [88.24888611, 21.56389046], [88.24833679, 21.56388855], [88.24749756, 21.56472015], [88.24749756, 21.56500053], [88.24500275, 21.56750107], [88.2444458, 21.56750107], [88.24415588, 21.56777954], [88.24368286, 21.56812096], [88.24333191, 21.56861115], [88.24305725, 21.56888962], [88.24305725, 21.56916618], [88.24276733, 21.56944084], [88.24277496, 21.56999969], [88.24222565, 21.57055473], [88.24222565, 21.57083321], [88.24211884, 21.57094002], [88.24138641, 21.57167244], [88.24138641, 21.57194519], [88.24111176, 21.5722084], [88.24111176, 21.57278252], [88.2408371, 21.57305527], [88.2408371, 21.57333183], [88.24054718, 21.57361031], [88.24054718, 21.57500076], [88.2408371, 21.57528114], [88.2408371, 21.57611084], [88.24111176, 21.57639122], [88.24111176, 21.57666588], [88.24138641, 21.57694244], [88.24138641, 21.57722473], [88.24185944, 21.57769394], [88.24222565, 21.57805443], [88.24223328, 21.57860947], [88.24250031, 21.57888794], [88.24250031, 21.57944679], [88.24388885, 21.58083344], [88.24416351, 21.58083344], [88.2444458, 21.58111191], [88.2444458, 21.58138847], [88.24500275, 21.58194351], [88.24500275, 21.58221817], [88.2452774, 21.58250046], [88.2452774, 21.58361053], [88.24500275, 21.58389091], [88.24500275, 21.58416748], [88.2452774, 21.58443832], [88.2452774, 21.58666611], [88.24555206, 21.58694267], [88.24555206, 21.59111023], [88.2452774, 21.5913887], [88.2452774, 21.59194565], [88.24388885, 21.59332085], [88.24388885, 21.59361076], [88.24305725, 21.59444427], [88.24305725, 21.59472084], [88.24276733, 21.59500122], [88.24305725, 21.59527969], [88.24305725, 21.59583282], [88.24276733, 21.59610939], [88.24277496, 21.59666634], [88.24222565, 21.59722137], [88.24194336, 21.59721756], [88.2416687, 21.59749985], [88.24111176, 21.59749985], [88.24028015, 21.59833336], [88.24028015, 21.59861183], [88.23999786, 21.59861183], [88.23944092, 21.59917259], [88.23944092, 21.59944534], [88.23916626, 21.59972191], [88.23916626, 21.60055542], [88.2388916, 21.60083008], [88.2388916, 21.60111046], [88.23860931, 21.60138893], [88.23860931, 21.60222054], [88.23777771, 21.60305977], [88.23748779, 21.60305977], [88.23665619, 21.60388947], [88.23610687, 21.60388947], [88.23583221, 21.60416412], [88.23583221, 21.60472107], [88.23555756, 21.60499954], [88.23555756, 21.60527611], [88.23500061, 21.60583305], [88.23500061, 21.60610962], [88.23306274, 21.60806084], [88.23278046, 21.60805511], [88.23249817, 21.60833359], [88.23222351, 21.60833359], [88.23083496, 21.60972214], [88.23055267, 21.60972023], [88.23027802, 21.61000061], [88.23000336, 21.61000061], [88.22972107, 21.61027908], [88.22861481, 21.61027718], [88.2277832, 21.61111069], [88.22638702, 21.61111069], [88.22583008, 21.61168289], [88.22444153, 21.61166573], [88.22416687, 21.6119442], [88.22389221, 21.61222267], [88.22360992, 21.61222076], [88.2233429, 21.61249924], [88.22305298, 21.61249924], [88.22222137, 21.61333275], [88.22194672, 21.61333275], [88.22138977, 21.61388969], [88.22083282, 21.61388969], [88.22000122, 21.6147213], [88.21992493, 21.6147213], [88.21971893, 21.6147213], [88.2194519, 21.61471939], [88.21916962, 21.61499977], [88.21806335, 21.61499977], [88.21778107, 21.61528015], [88.21722412, 21.61527824], [88.21666718, 21.61583138], [88.21666718, 21.61610985], [88.21639252, 21.61638832], [88.21639252, 21.61722183], [88.21611023, 21.61749077], [88.21653748, 21.61861038], [88.21721649, 21.61972046], [88.21774292, 21.62018013], [88.21806335, 21.62055016], [88.21839142, 21.62091064], [88.21868134, 21.62128258], [88.21900177, 21.62162781], [88.21933746, 21.6219368], [88.21967316, 21.6222496], [88.21997833, 21.62261963], [88.22029877, 21.6230545], [88.22071075, 21.62350082], [88.22116089, 21.62400627], [88.22169495, 21.62448692], [88.22222137, 21.62500954], [88.22268677, 21.62559128], [88.2231369, 21.62618256], [88.22362518, 21.62667465], [88.22418213, 21.62705994], [88.22476196, 21.62736893], [88.22534943, 21.62759972], [88.2258606, 21.6278801], [88.22632599, 21.6281395], [88.22677612, 21.62842941], [88.22724152, 21.62870026], [88.22771454, 21.62896538], [88.22816467, 21.62925148], [88.22865295, 21.62949944], [88.22908783, 21.6298008], [88.22949982, 21.63014984], [88.22992706, 21.63047981], [88.2303772, 21.63079834], [88.23085022, 21.63112068], [88.23133087, 21.63146019], [88.23175049, 21.63192177], [88.23215485, 21.63261604], [88.2322998, 21.63282967], [88.23236084, 21.63292122], [88.23287201, 21.63316917], [88.23304749, 21.63348198], [88.23348236, 21.63371468], [88.23390198, 21.63409042], [88.23403931, 21.6346302], [88.23445892, 21.63500977], [88.23473358, 21.63537788], [88.23470306, 21.63575363], [88.23490906, 21.63619232], [88.23503113, 21.63673019], [88.23519897, 21.63733673], [88.23530579, 21.63800049], [88.23554993, 21.63863564], [88.23571014, 21.63923073], [88.23590851, 21.63967896], [88.23606873, 21.6403656], [88.23592377, 21.64052391], [88.23612213, 21.64156914], [88.23604584, 21.64224052], [88.23613739, 21.64281082], [88.23648834, 21.6433506], [88.23667908, 21.64388084], [88.23670959, 21.64413071], [88.23683167, 21.64489937], [88.23673248, 21.64538574], [88.23673248, 21.64586449], [88.23657227, 21.64647102], [88.23648834, 21.64697075], [88.23641968, 21.64729118], [88.23635101, 21.64776039], [88.23619843, 21.6482296], [88.23596954, 21.64866829], [88.23580933, 21.64914131], [88.23558044, 21.64957809], [88.23539734, 21.65003967], [88.23525238, 21.65052032], [88.23500061, 21.65096092], [88.23474121, 21.65142059], [88.23445892, 21.65192032], [88.23416901, 21.6523838], [88.23388672, 21.65281296], [88.23361206, 21.65320969], [88.23332977, 21.65360069], [88.23304749, 21.65401077], [88.23277283, 21.65446091], [88.23249054, 21.6549511], [88.23221588, 21.65544128], [88.23194885, 21.65588951], [88.23169708, 21.65629959], [88.23158264, 21.65674973], [88.23145294, 21.65718651], [88.23158264, 21.65766907], [88.23166656, 21.65823174], [88.23184204, 21.65881348], [88.23190308, 21.65944099], [88.23194122, 21.66007805], [88.23194122, 21.66069984], [88.23194885, 21.6613102], [88.231987, 21.66192055], [88.23217773, 21.66250992], [88.23223877, 21.66312981], [88.23235321, 21.66372108], [88.23252106, 21.66424561], [88.23277283, 21.66470909], [88.2329483, 21.66518974], [88.23306274, 21.66527939], [88.23306274, 21.66556168], [88.23332977, 21.66638947], [88.23332977, 21.66805649], [88.23300171, 21.6690197], [88.23249817, 21.66945076], [88.23194122, 21.67000008], [88.23194122, 21.67027855], [88.23139191, 21.67083549], [88.23139191, 21.67111015], [88.23036957, 21.67224121], [88.22955322, 21.67311096], [88.22912598, 21.67331123], [88.22783661, 21.67404938], [88.22633362, 21.67505455], [88.22451782, 21.67552948], [88.22386169, 21.67571068], [88.22316742, 21.67581749], [88.22251129, 21.67583084], [88.22187042, 21.67584038], [88.22161102, 21.67583656], [88.22124481, 21.67583466], [88.22058105, 21.67583275], [88.21987915, 21.67579269], [88.21923828, 21.67560768], [88.2186203, 21.67554092], [88.21808624, 21.67542839], [88.21762085, 21.6752739], [88.21717834, 21.67510605], [88.21672058, 21.67500114], [88.21627808, 21.67487907], [88.21588135, 21.67474174], [88.21552277, 21.67464066], [88.2151947, 21.67448044], [88.21481323, 21.67444992], [88.21440125, 21.67444038], [88.213974, 21.67443085], [88.21354675, 21.67436028], [88.2131424, 21.67424011], [88.21276093, 21.67438126], [88.21237183, 21.67431068], [88.21196747, 21.67423058], [88.21154022, 21.67440033], [88.21102142, 21.67444038], [88.21083069, 21.6744442], [88.21044159, 21.67444992], [88.20983887, 21.67444038], [88.20923615, 21.67435074], [88.20865631, 21.67427063], [88.20813751, 21.67440987], [88.20761108, 21.67451096], [88.20713806, 21.67469025], [88.20661163, 21.67480087], [88.20610046, 21.67502022], [88.20558167, 21.67527771], [88.20506287, 21.67557144], [88.20462036, 21.67593575], [88.20423126, 21.67631912], [88.20384216, 21.67670059], [88.20340729, 21.67703056], [88.20305634, 21.67742729], [88.2027359, 21.67782974], [88.20244598, 21.67825127], [88.20211029, 21.67862892], [88.20178986, 21.67904282], [88.20147705, 21.67947006], [88.20118713, 21.67991066], [88.20083618, 21.68032074], [88.20049286, 21.68077278], [88.20007324, 21.68120956], [88.19972992, 21.68170738], [88.19944, 21.68218994], [88.19918823, 21.68261909], [88.19903564, 21.68304253], [88.1989212, 21.68345261], [88.19889069, 21.68394089], [88.19888306, 21.68447113], [88.19877625, 21.68501091], [88.19841003, 21.68546295], [88.19832611, 21.6859951], [88.19830322, 21.68651009], [88.19812775, 21.687397], [88.19805908, 21.68833351], [88.19785309, 21.6885376], [88.19777679, 21.68861008], [88.19777679, 21.68916893], [88.19805908, 21.68943977], [88.19805908, 21.68972206], [88.19916534, 21.69083405], [88.19989014, 21.69082832], [88.19999695, 21.69082832], [88.20027924, 21.69111061], [88.20054626, 21.69111061], [88.20083618, 21.69138908], [88.2011795, 21.69138908], [88.20182037, 21.69140053], [88.20249939, 21.69166756], [88.20306396, 21.69174194], [88.20444489, 21.69194412], [88.20542908, 21.69216347], [88.20630646, 21.69215965], [88.20694733, 21.69231987], [88.2075119, 21.69249916], [88.20833588, 21.69249916], [88.20861053, 21.69277763], [88.20888519, 21.69277763], [88.20944214, 21.69333267], [88.21028137, 21.69333267], [88.21055603, 21.69361115], [88.21111298, 21.69361115], [88.21138763, 21.69333267], [88.21166992, 21.69333267], [88.21221924, 21.69388962], [88.21250153, 21.69388962], [88.21305847, 21.69411087], [88.21354675, 21.69430923], [88.21389771, 21.69445038], [88.21417236, 21.69458961], [88.21444702, 21.6947403], [88.2149353, 21.69487572], [88.21527863, 21.69472122], [88.21555328, 21.69472122], [88.21666718, 21.6958313], [88.21694183, 21.69582939], [88.21778107, 21.69667053], [88.21778107, 21.69695091], [88.21833038, 21.69750023], [88.21833038, 21.69778061], [88.21861267, 21.69806099], [88.21888733, 21.69806099], [88.21917725, 21.69835091], [88.21967316, 21.69890022], [88.22006989, 21.69944954], [88.22038269, 21.70002937], [88.22055054, 21.70065689], [88.22070313, 21.70126915], [88.22088623, 21.7018261], [88.22106171, 21.70238113], [88.22107697, 21.70294952], [88.22094727, 21.70350075], [88.22080994, 21.7040596], [88.22059631, 21.70457268], [88.22055817, 21.70512009], [88.22054291, 21.70565987], [88.22048187, 21.70615959], [88.2203064, 21.70661926], [88.22019958, 21.70714378], [88.21998596, 21.70768356], [88.22000885, 21.70837975], [88.21971893, 21.70882988], [88.21930695, 21.70944977], [88.21900177, 21.70989037], [88.21858215, 21.71050072], [88.21834564, 21.71095657], [88.21798706, 21.71130371], [88.21749115, 21.71161079], [88.21718597, 21.71198082], [88.21692657, 21.7123661], [88.21664429, 21.71272278], [88.21636963, 21.71304321], [88.21613312, 21.71333122], [88.21592712, 21.7136097], [88.21573639, 21.7138195], [88.21549225, 21.71398163], [88.21537781, 21.71426964], [88.21517181, 21.71454239], [88.21502686, 21.71487045], [88.21495819, 21.715271], [88.21471405, 21.71557617], [88.21444702, 21.71591377], [88.2141571, 21.71626091], [88.21389008, 21.71661186], [88.21363068, 21.71696281], [88.21343231, 21.71738434], [88.21317291, 21.71779251], [88.21289825, 21.71822548], [88.212677, 21.71870041], [88.21246338, 21.71915054], [88.21221924, 21.7195816], [88.21201324, 21.71998024], [88.21193695, 21.72043419], [88.21187592, 21.72087097], [88.21170807, 21.72126007], [88.21166992, 21.72169113], [88.2116394, 21.72216034], [88.21151733, 21.72266006], [88.21141052, 21.72324181], [88.21134949, 21.72386169], [88.21115112, 21.72443008], [88.21111298, 21.72499084], [88.21111298, 21.72551918], [88.2110672, 21.72601128], [88.2109375, 21.72643852], [88.21105194, 21.7267704], [88.21116638, 21.72711182], [88.21135712, 21.72742081], [88.2115097, 21.72776985], [88.21166992, 21.72813988], [88.21183777, 21.72851944], [88.21192932, 21.72891808], [88.21193695, 21.72931862], [88.21193695, 21.72974014], [88.21199036, 21.73015976], [88.21216583, 21.73060036], [88.21221924, 21.73114967], [88.21224213, 21.73175049], [88.21234131, 21.73231506], [88.21251678, 21.73281097], [88.21272278, 21.73322105], [88.21278381, 21.73360062], [88.21286011, 21.73394203], [88.21302032, 21.73426056], [88.21305847, 21.73464775], [88.21311188, 21.73509026], [88.21328735, 21.73557091], [88.21338654, 21.73611832], [88.21360779, 21.73666191], [88.21388245, 21.73722076], [88.21411133, 21.73777962], [88.21422577, 21.73835754], [88.21438599, 21.73888016], [88.21440887, 21.73937988], [88.21437073, 21.73985672], [88.21440125, 21.74028969], [88.21446991, 21.74072075], [88.21459198, 21.74113083], [88.21469879, 21.74153709], [88.21470642, 21.74198151], [88.2146225, 21.74246025], [88.21434021, 21.74298096], [88.21430206, 21.74351883], [88.21446991, 21.74407005], [88.2146759, 21.74465942], [88.21473694, 21.74527931], [88.21472931, 21.7458992], [88.2146759, 21.74650002], [88.21453857, 21.74706841], [88.21433258, 21.74757957], [88.21440125, 21.74806976], [88.21446228, 21.74856949], [88.21460724, 21.74908066], [88.21450043, 21.74955368], [88.21434021, 21.75003433], [88.21405029, 21.75046158], [88.21393585, 21.75086975], [88.2140274, 21.75125122], [88.21414185, 21.75164032], [88.21416473, 21.75204849], [88.21421051, 21.75247192], [88.21437073, 21.75290108], [88.21444702, 21.75336075], [88.21448517, 21.75382614], [88.21445465, 21.75430298], [88.21450043, 21.75476074], [88.21469879, 21.75518036], [88.2148819, 21.75561333], [88.21499634, 21.75609016], [88.21508789, 21.75658989], [88.21526337, 21.75704956], [88.21542358, 21.75750732], [88.21560669, 21.75796127], [88.21583557, 21.75840759], [88.21604919, 21.75889015], [88.21611023, 21.75949097], [88.21617889, 21.76008034], [88.21637726, 21.76054955], [88.21659088, 21.76096153], [88.21671295, 21.76135063], [88.21691132, 21.76165962], [88.21710968, 21.76192856], [88.21744537, 21.76214981], [88.21800232, 21.76221466], [88.21868896, 21.76222229], [88.21942139, 21.76222229], [88.22016907, 21.76220703], [88.22090912, 21.76214981], [88.22164917, 21.76204681], [88.22236633, 21.76205063], [88.22309875, 21.76198959], [88.22381592, 21.76196098], [88.22454071, 21.76196098], [88.22525787, 21.76200485], [88.22596741, 21.76210594], [88.22667694, 21.76210213], [88.22736359, 21.76199913], [88.22807312, 21.76194954], [88.2287674, 21.76193237], [88.22946167, 21.76189423], [88.23013306, 21.76178932], [88.2307663, 21.76161957], [88.23132324, 21.76137924], [88.23182678, 21.76111984], [88.23227692, 21.76086998], [88.23274994, 21.76068878], [88.23323059, 21.76052094], [88.2337265, 21.76035118], [88.23432159, 21.76018906], [88.23497772, 21.75992966], [88.23560333, 21.75967026], [88.23607635, 21.75945282], [88.23671722, 21.75933075], [88.23738098, 21.75920105], [88.23809052, 21.75910187], [88.23880005, 21.75892448], [88.23953247, 21.75877762], [88.24022675, 21.75859833], [88.24089813, 21.75835991], [88.24156952, 21.75818062], [88.24224854, 21.75807953], [88.24289703, 21.75802994], [88.24349976, 21.75794983], [88.24404144, 21.75780106], [88.24453735, 21.75769806], [88.24495697, 21.75756073], [88.24542236, 21.75749016], [88.24590302, 21.75742722], [88.24638367, 21.75728035], [88.2469101, 21.75722122], [88.24745178, 21.75716972], [88.24798584, 21.75704193], [88.24852753, 21.75694084], [88.24906158, 21.75683022], [88.2495575, 21.75666428], [88.25004578, 21.75650406], [88.25056458, 21.75639915], [88.25108337, 21.75632858], [88.25157166, 21.75618935], [88.25209045, 21.75611115], [88.25263214, 21.7560997], [88.25318909, 21.7560482], [88.25376129, 21.75591087], [88.25437927, 21.75583839], [88.25506592, 21.75583267], [88.25576782, 21.75583267], [88.25646973, 21.75583458], [88.25717926, 21.75582886], [88.25788879, 21.75577927], [88.25859833, 21.75560951], [88.25930786, 21.75555992], [88.2600174, 21.75555992], [88.26071167, 21.75558281], [88.26139832, 21.75567055], [88.26209259, 21.75572968], [88.26283264, 21.75560951], [88.26358795, 21.75556374], [88.26432037, 21.75554276], [88.26465607, 21.75551987], [88.26500702, 21.75549889], [88.26563263, 21.7553997], [88.26628876, 21.75546646], [88.26669312, 21.75548553], [88.26694489, 21.75550079], [88.26751709, 21.75533104], [88.26809692, 21.75515938], [88.2686615, 21.75505066], [88.26922607, 21.75498009], [88.26976776, 21.75485611], [88.27031708, 21.75475121], [88.27089691, 21.75472069], [88.271492, 21.75467491], [88.27200317, 21.75440598], [88.27237701, 21.75395966], [88.27249146, 21.7533226], [88.27249908, 21.75266266], [88.27243042, 21.75205803], [88.2722168, 21.75164032], [88.2720108, 21.75124741], [88.2718811, 21.75081253], [88.27166748, 21.75046158], [88.27144623, 21.75015068], [88.2713089, 21.7497921], [88.27112579, 21.74950981], [88.27098846, 21.74921227], [88.27085114, 21.74889946], [88.27075958, 21.74852943], [88.27056122, 21.7481823], [88.27033997, 21.74780273], [88.27005768, 21.74744225], [88.26997375, 21.74697876], [88.26985931, 21.74651909], [88.26972198, 21.74606133], [88.26958466, 21.74556541], [88.2694397, 21.74505806], [88.26927185, 21.74454117], [88.26908875, 21.74407959], [88.26874542, 21.74380875], [88.26854706, 21.7435112], [88.26842499, 21.74318695], [88.26831818, 21.74283981], [88.2681427, 21.74257088], [88.26795959, 21.74229813], [88.26777649, 21.74202919], [88.26759338, 21.74172974], [88.26744843, 21.74136543], [88.26721954, 21.74104118], [88.26696777, 21.74072075], [88.26673889, 21.74036026], [88.26647186, 21.74002075], [88.26616669, 21.73970985], [88.26587677, 21.73940277], [88.26560211, 21.73905754], [88.26538086, 21.73863983], [88.26511383, 21.73826027], [88.2649231, 21.73780823], [88.26470184, 21.73736], [88.26442719, 21.73694038], [88.2641449, 21.7365818], [88.2638092, 21.73628044], [88.26351929, 21.73592758], [88.26317596, 21.73565102], [88.26288605, 21.73531723], [88.2627182, 21.73517609], [88.26254272, 21.7350235], [88.26235962, 21.73472023], [88.26229858, 21.73462296], [88.26215363, 21.73412132], [88.26192474, 21.73365974], [88.26169586, 21.73320961], [88.26156616, 21.73269844], [88.2614212, 21.73218918], [88.26146698, 21.73162079], [88.2616806, 21.73111916], [88.26190948, 21.73063087], [88.2620697, 21.73017311], [88.26226044, 21.72979927], [88.26246643, 21.72949982], [88.26265717, 21.72922134], [88.26295471, 21.72901344], [88.26332092, 21.7287693], [88.2637558, 21.7285099], [88.26434326, 21.7284317], [88.26490021, 21.72826958], [88.26548767, 21.72813034], [88.26613617, 21.72824097], [88.26679993, 21.72809029], [88.26750183, 21.72805977], [88.26818848, 21.72809792], [88.26838684, 21.72815704], [88.26866913, 21.72824097], [88.26883698, 21.72829247], [88.26944733, 21.72837067], [88.26995087, 21.72846031], [88.27029419, 21.72830391], [88.27047729, 21.72822189], [88.27101135, 21.72822762], [88.27158356, 21.72830391], [88.2722168, 21.72826576], [88.27284241, 21.7279911], [88.27345276, 21.7277317], [88.27410889, 21.72762108], [88.27468872, 21.72747993], [88.27514648, 21.72718239], [88.27552795, 21.72681046], [88.27555847, 21.72667122], [88.2766571, 21.72556114], [88.2766571, 21.72528076], [88.27694702, 21.72500038], [88.27694702, 21.72472], [88.27666473, 21.72444344], [88.2766571, 21.7238903], [88.27694702, 21.72360992], [88.27694702, 21.72333336], [88.27722168, 21.72305489], [88.27722168, 21.72277832], [88.27777863, 21.72221947], [88.27777863, 21.7211113], [88.27749634, 21.72083282], [88.27749634, 21.71999931], [88.27777863, 21.71970749], [88.27777863, 21.7191658], [88.2783432, 21.71861076], [88.27833557, 21.71805573], [88.27861023, 21.71777916], [88.27861023, 21.71750069], [88.27916718, 21.71693993], [88.27916718, 21.71583366], [88.27944183, 21.71555519], [88.27944183, 21.71528053], [88.27971649, 21.71500015], [88.27971649, 21.71445084], [88.27999878, 21.71417046], [88.27999878, 21.71389961], [88.28056335, 21.71333122], [88.28055573, 21.71305656], [88.28083038, 21.71305656], [88.28111267, 21.71277618], [88.28166962, 21.71278], [88.28221893, 21.71222115], [88.28221893, 21.71138954], [88.28193665, 21.71111107], [88.28221893, 21.71111107], [88.28250122, 21.71084023], [88.28250122, 21.71055984], [88.28305817, 21.71000099], [88.28305817, 21.70972061], [88.28360748, 21.70916748], [88.28360748, 21.70889282], [88.28388977, 21.70861053], [88.28388977, 21.70833015], [88.28360748, 21.7080555], [88.2841568, 21.70750046], [88.2841568, 21.70722008], [88.28444672, 21.70694351], [88.2848053, 21.70646477], [88.28520966, 21.70613289], [88.28559875, 21.70568085], [88.28601837, 21.70521927], [88.28645325, 21.70474052], [88.28694153, 21.70430946], [88.28749847, 21.70388985], [88.28778076, 21.70360756], [88.28805542, 21.70361137], [88.28888702, 21.70277977], [88.28888702, 21.70249939], [88.28916931, 21.70222092], [88.28916931, 21.70194435], [88.28944397, 21.70166779], [88.28943634, 21.70139122], [88.29083252, 21.70000076], [88.29110718, 21.70000076], [88.29389191, 21.69721985], [88.29389191, 21.69694328], [88.29528046, 21.69553947], [88.29555511, 21.69555473], [88.29666901, 21.69444466], [88.29666901, 21.69416618], [88.29722595, 21.69361115], [88.29722595, 21.69333267], [88.29777527, 21.69277763], [88.29805756, 21.69277763], [88.29916382, 21.69166756], [88.29915619, 21.69138908], [88.29972076, 21.69082832], [88.29984283, 21.69072151], [88.30025482, 21.69025612], [88.30058289, 21.68970108], [88.30090332, 21.68913078], [88.30130005, 21.68867302], [88.30169678, 21.68817329], [88.30213928, 21.68768311], [88.30256653, 21.68716812], [88.30303192, 21.68669701], [88.30345154, 21.68622017], [88.30373383, 21.68572617], [88.30397797, 21.68530083], [88.30421448, 21.6849575], [88.3044281, 21.68465042], [88.30458832, 21.68430328], [88.30477905, 21.68394279], [88.3050766, 21.68354034], [88.3054657, 21.68312836], [88.30581665, 21.68261909], [88.30610657, 21.68207169], [88.30639648, 21.68155098], [88.30667877, 21.68111801], [88.30722046, 21.68056107], [88.30722046, 21.68028259], [88.30750275, 21.68000031], [88.3077774, 21.68000031], [88.3088913, 21.67889023], [88.3088913, 21.67861176], [88.30916595, 21.67833328], [88.30916595, 21.67805481], [88.30944824, 21.67777824], [88.30944824, 21.67749977], [88.30973053, 21.67721748], [88.3097229, 21.67694473], [88.31027985, 21.67638969], [88.31027985, 21.67583084], [88.3105545, 21.67555618], [88.31054688, 21.67527962], [88.31027985, 21.67500114], [88.31054688, 21.6747303], [88.31054688, 21.67444038], [88.31083679, 21.67416763], [88.31083679, 21.67389107], [88.31111145, 21.67361069], [88.31111145, 21.67250061], [88.31143188, 21.67278099], [88.3116684, 21.67193985], [88.31138611, 21.67166519], [88.31138611, 21.67111206], [88.3105545, 21.67027855], [88.31054688, 21.6697197], [88.31027985, 21.66944313], [88.31027985, 21.66917038], [88.30973053, 21.66860008], [88.3097229, 21.66833115], [88.30944824, 21.66805649], [88.30944824, 21.66777992], [88.3088913, 21.66722107], [88.30944824, 21.66666603], [88.30916595, 21.66638947], [88.30916595, 21.66610909], [88.30860901, 21.66556168], [88.30860901, 21.66527939], [88.30805206, 21.66472054], [88.30805206, 21.66444397], [88.3077774, 21.6641674], [88.3077774, 21.66389084], [88.30750275, 21.66361046], [88.30750275, 21.66332817], [88.30583191, 21.66166878], [88.30583191, 21.66110992], [88.30556488, 21.66065979], [88.30532074, 21.6602211], [88.30509949, 21.65974045], [88.30486298, 21.65928268], [88.30469513, 21.65876389], [88.30445099, 21.65828514], [88.30419922, 21.65784073], [88.30388641, 21.65743065], [88.3035965, 21.65703964], [88.30332184, 21.65666008], [88.30304718, 21.65628815], [88.30278778, 21.65594864], [88.30257416, 21.65561676], [88.30245209, 21.65524101], [88.30223083, 21.6548996], [88.3020401, 21.65452003], [88.30191803, 21.65409279], [88.30169678, 21.65363121], [88.30148315, 21.65312195], [88.30126953, 21.65255928], [88.30105591, 21.65206909], [88.30080414, 21.65172958], [88.30053711, 21.65147018], [88.30030823, 21.65125084], [88.30014801, 21.6509819], [88.30001831, 21.65069199], [88.29994965, 21.65035057], [88.29984283, 21.65003014], [88.29972076, 21.64972115], [88.29972076, 21.64944458], [88.29944611, 21.64916611], [88.2980423, 21.64916611], [88.29528046, 21.64916992], [88.29499817, 21.64888954], [88.29444122, 21.64888954], [88.29416656, 21.64861107], [88.29389191, 21.64861107], [88.29444122, 21.64805984], [88.29444122, 21.64777946], [88.29473114, 21.64750099], [88.29522705, 21.64757729], [88.29572296, 21.64773941], [88.29625702, 21.64788055], [88.296875, 21.64798737], [88.29763794, 21.64805412], [88.29807281, 21.64798355], [88.2986145, 21.64777756], [88.29860687, 21.64722061], [88.29805756, 21.64666748], [88.29805756, 21.64639091], [88.29779053, 21.64611053], [88.29777527, 21.64583588], [88.29750061, 21.6455574], [88.29750061, 21.64528084], [88.29722595, 21.64500046], [88.29722595, 21.64472008], [88.29666901, 21.64416695], [88.29666901, 21.64361], [88.29638672, 21.64333344], [88.29638672, 21.6427784], [88.29611206, 21.64249992], [88.29611206, 21.64221954], [88.29582977, 21.64194489], [88.29582977, 21.64166641], [88.29611206, 21.64138985], [88.29556274, 21.6408329], [88.29582977, 21.64055634], [88.29582977, 21.64027977], [88.29528046, 21.63972282], [88.29528046, 21.63944435], [88.29499817, 21.63916588], [88.29499817, 21.63888931], [88.29473114, 21.63862038], [88.29470062, 21.63830948], [88.29416656, 21.63777733], [88.29416656, 21.63750076], [88.29332733, 21.63666916], [88.29332733, 21.63611031], [88.29360962, 21.63582993], [88.29360962, 21.63555527], [88.29332733, 21.63528061], [88.29332733, 21.63500023], [88.29305267, 21.63471985], [88.29305267, 21.63388634], [88.29277802, 21.63360977], [88.29277802, 21.63249969], [88.29305267, 21.63222313], [88.29277802, 21.63194656], [88.29277802, 21.63166428], [88.29138947, 21.63027954], [88.29138947, 21.63000107], [88.29110718, 21.62972069], [88.29111481, 21.62916756], [88.29083252, 21.6288929], [88.29055786, 21.6288929], [88.29037476, 21.62870407], [88.29000092, 21.62833023], [88.29000092, 21.62750053], [88.29083252, 21.62668037], [88.28943634, 21.62528038], [88.28943634, 21.62471771], [88.28916931, 21.62444496], [88.28916931, 21.62388992], [88.28833008, 21.62305832], [88.28833008, 21.62277985], [88.28916931, 21.62194061], [88.28916931, 21.62166786], [88.28888702, 21.62138939], [88.28888702, 21.62111092], [88.28916931, 21.62083054], [88.28916931, 21.6202755], [88.28859711, 21.61972046], [88.28861237, 21.6194458], [88.28888702, 21.61916733], [88.28888702, 21.61833], [88.28861237, 21.61805344], [88.28859711, 21.61778069], [88.28833008, 21.61749077], [88.28833008, 21.61666679], [88.2883606, 21.61656761], [88.28848267, 21.61611176], [88.28861237, 21.61583138], [88.28861237, 21.61527824], [88.28888702, 21.61499977], [88.28859711, 21.61471939], [88.28861237, 21.61444473], [88.28833008, 21.61417007], [88.28833008, 21.61361122], [88.28806305, 21.61333275], [88.28833008, 21.61305618], [88.28833008, 21.61277962], [88.28859711, 21.61249924], [88.28859711, 21.61193848], [88.28888702, 21.61166573], [88.28888702, 21.61111069], [88.28971863, 21.61027908], [88.28916931, 21.60972023], [88.28916931, 21.60861206], [88.28888702, 21.60833359], [88.28888702, 21.60638618], [88.28916931, 21.60610962], [88.28916931, 21.60527611], [88.28888702, 21.60499954], [88.28778076, 21.60499954], [88.28721619, 21.60444069], [88.28694153, 21.60444641], [88.28639221, 21.60388947], [88.28666687, 21.60361099], [88.28666687, 21.60277939], [88.28694153, 21.60251045], [88.28694153, 21.60222054], [88.28749847, 21.6016674], [88.28749847, 21.60111046], [88.28778076, 21.60083008], [88.28778076, 21.60000038], [88.28806305, 21.59972191], [88.28805542, 21.59944534], [88.28833008, 21.59917259], [88.28833008, 21.59861183], [88.28861237, 21.59833336], [88.28861237, 21.59777832], [88.28916931, 21.59721756], [88.28916931, 21.59666634], [88.28943634, 21.59638023], [88.29000092, 21.59638977], [88.29000092, 21.5961113], [88.29027557, 21.59583282], [88.29027557, 21.59555626], [88.29083252, 21.59500122], [88.29110718, 21.59527969]]], [[[89.00511932, 21.7649765], [89.00567627, 21.76489067], [89.00610352, 21.76493263], [89.00657654, 21.7648735], [89.00709534, 21.76496124], [89.00762939, 21.76496124], [89.00817108, 21.76489067], [89.00875854, 21.76480103], [89.00937653, 21.76481438], [89.00997925, 21.7649231], [89.01060486, 21.76494408], [89.01125336, 21.76486588], [89.0120163, 21.76490021], [89.01274109, 21.76484108], [89.0133667, 21.76463127], [89.01399231, 21.76447105], [89.01455688, 21.7643261], [89.01502228, 21.7641201], [89.01542664, 21.7638607], [89.01580048, 21.76358986], [89.01616669, 21.76330948], [89.01656342, 21.7630558], [89.01695251, 21.76279068], [89.01732635, 21.76252556], [89.01768494, 21.76224136], [89.01805115, 21.7619381], [89.01838684, 21.76160049], [89.01874542, 21.76123238], [89.01909637, 21.76080513], [89.01947021, 21.76035118], [89.0198822, 21.75984764], [89.02031708, 21.75938034], [89.02076721, 21.75897026], [89.0212326, 21.75862122], [89.02164459, 21.75831413], [89.02198029, 21.75801468], [89.02230835, 21.75777054], [89.0226059, 21.75753975], [89.02295685, 21.75736046], [89.02336884, 21.75726128], [89.02381134, 21.75723076], [89.0242691, 21.75722694], [89.02471161, 21.75720978], [89.02510071, 21.75714302], [89.02541351, 21.75696945], [89.02567291, 21.75674057], [89.02596283, 21.75647163], [89.02626038, 21.75617409], [89.02658081, 21.75586128], [89.02690125, 21.75554085], [89.02719116, 21.75518036], [89.02745819, 21.75479126], [89.02776337, 21.75442123], [89.02804565, 21.75403214], [89.02830505, 21.7536068], [89.02854919, 21.75315857], [89.02881622, 21.75275993], [89.02905273, 21.75238037], [89.02925873, 21.75209045], [89.02947235, 21.75187111], [89.02964783, 21.75167084], [89.0298233, 21.75144958], [89.02999115, 21.75121689], [89.03016663, 21.7509594], [89.03040314, 21.75069046], [89.03056335, 21.75048256], [89.03065491, 21.75036621], [89.03102112, 21.75002098], [89.03145599, 21.74963951], [89.03192139, 21.74920082], [89.03236389, 21.7487011], [89.03275299, 21.74814034], [89.03321075, 21.74765015], [89.03367615, 21.74721146], [89.03414154, 21.74675369], [89.03455353, 21.74625015], [89.03501892, 21.74577332], [89.03546143, 21.74529457], [89.03588104, 21.74479485], [89.03631592, 21.74427414], [89.03726196, 21.74324989], [89.03769684, 21.74278069], [89.03806305, 21.74231148], [89.03833771, 21.74197388], [89.03855133, 21.74163628], [89.03840637, 21.74117088], [89.03806305, 21.74096107], [89.03740692, 21.74082947], [89.03697968, 21.74082947], [89.0366745, 21.74054146], [89.03655243, 21.74042892], [89.03655243, 21.74028969], [89.03683472, 21.7399559], [89.03762054, 21.7399559], [89.03819275, 21.74002266], [89.03940582, 21.74002075], [89.03971863, 21.74028015], [89.0402832, 21.74028015], [89.04055786, 21.73999977], [89.04083252, 21.73999977], [89.04138947, 21.73944092], [89.04194641, 21.73944664], [89.04472351, 21.73666573], [89.04499817, 21.73647118], [89.04556274, 21.73611069], [89.04576111, 21.73584175], [89.04666901, 21.73527718], [89.04714966, 21.73493958], [89.04777527, 21.73472214], [89.04798126, 21.73458862], [89.04833221, 21.73444176], [89.0486145, 21.73444366], [89.04916382, 21.73388863], [89.04944611, 21.73389053], [89.04972076, 21.73361015], [89.04990387, 21.73350525], [89.05033875, 21.73336983], [89.05062103, 21.73316956], [89.05119324, 21.73262978], [89.05126953, 21.73236275], [89.05155182, 21.73216248], [89.05198669, 21.73188972], [89.0525589, 21.73169136], [89.05305481, 21.73142242], [89.05391693, 21.73101616], [89.05413055, 21.7308197], [89.0545578, 21.73055077], [89.05471802, 21.73040009], [89.05535126, 21.7301445], [89.05583191, 21.72993279], [89.05597687, 21.72982025], [89.05648804, 21.72948074], [89.05677795, 21.72928238], [89.05727386, 21.72874451], [89.05763245, 21.72861099], [89.05921173, 21.72680092], [89.0592804, 21.72591972], [89.05870819, 21.72571754], [89.05834961, 21.72524071], [89.05820465, 21.72511482], [89.05813599, 21.72484589], [89.05805969, 21.72463989], [89.05797577, 21.7246151], [89.05741882, 21.72444153], [89.05684662, 21.72423935], [89.05648804, 21.72410965], [89.05597687, 21.72404099], [89.05570221, 21.72397041], [89.05484009, 21.72404099], [89.05419922, 21.72397041], [89.0539093, 21.72389984], [89.05348206, 21.72376633], [89.05326843, 21.72363091], [89.05258942, 21.723526], [89.0522995, 21.72346115], [89.05150604, 21.72346115], [89.05072784, 21.72339058], [89.05047607, 21.72339058], [89.04929352, 21.72339058], [89.04886627, 21.72332382], [89.04829407, 21.72319031], [89.04779053, 21.72311974], [89.04621887, 21.72312164], [89.04572296, 21.72319031], [89.04535675, 21.72319031], [89.04471588, 21.72326088], [89.0440979, 21.72305107], [89.04331207, 21.72293282], [89.04037476, 21.72293282], [89.03958893, 21.72286606], [89.03923035, 21.72286987], [89.03807831, 21.72273064], [89.03765106, 21.72260094], [89.03687286, 21.72232819], [89.03600311, 21.72191811], [89.03575897, 21.72195244], [89.03533173, 21.72175026], [89.03497314, 21.72162056], [89.0344696, 21.72141075], [89.03382874, 21.72134781], [89.0324707, 21.72134781], [89.03196716, 21.72148132], [89.03167725, 21.72147942], [89.03125, 21.7217598], [89.03103638, 21.72208977], [89.03082275, 21.72255707], [89.03060913, 21.72309113], [89.03022003, 21.72355843], [89.02998352, 21.72384644], [89.02951813, 21.72442436], [89.02932739, 21.72408676], [89.02996826, 21.7228508], [89.03083801, 21.72126579], [89.03090668, 21.72092056], [89.03061676, 21.72076035], [89.0302124, 21.72055244], [89.02973175, 21.72029114], [89.02922058, 21.7200737], [89.02870941, 21.71992874], [89.02831268, 21.71970749], [89.02799988, 21.71950912], [89.02768707, 21.71935081], [89.02741241, 21.71915817], [89.02709961, 21.71898651], [89.02662659, 21.71889877], [89.02610016, 21.71883011], [89.02559662, 21.71867943], [89.02510071, 21.7186203], [89.02456665, 21.71856117], [89.02404785, 21.71834183], [89.02349854, 21.71812057], [89.02288055, 21.71799088], [89.02231598, 21.71779251], [89.02179718, 21.71763039], [89.02130127, 21.71747017], [89.02088165, 21.71725082], [89.02053833, 21.71725082], [89.02025604, 21.71731186], [89.01953888, 21.71742821], [89.01911926, 21.71742058], [89.01796722, 21.71767044], [89.01741028, 21.71777916], [89.01725769, 21.71842194], [89.01734161, 21.71901512], [89.01724243, 21.71959114], [89.01714325, 21.72021294], [89.01698303, 21.72082138], [89.01715851, 21.7213707], [89.01729584, 21.72186089], [89.01735687, 21.72239876], [89.01737213, 21.72278976], [89.01737213, 21.72325516], [89.01741791, 21.72352028], [89.01745605, 21.72370911], [89.0175705, 21.7243042], [89.01772308, 21.72500038], [89.01766205, 21.72550964], [89.01792908, 21.72601128], [89.01805115, 21.72654915], [89.01786804, 21.72709656], [89.01764679, 21.72765923], [89.0174408, 21.72829247], [89.01746368, 21.72886658], [89.01737213, 21.72937965], [89.01727295, 21.72987175], [89.01712799, 21.73040009], [89.01692963, 21.73121071], [89.0165863, 21.73181725], [89.01637268, 21.73244286], [89.01605988, 21.73298073], [89.01572418, 21.73345566], [89.01538849, 21.7338829], [89.01503754, 21.7342701], [89.01465607, 21.73467064], [89.01422119, 21.73503304], [89.01377869, 21.73539352], [89.0133667, 21.73578072], [89.01304626, 21.73623085], [89.01275635, 21.73668098], [89.01243591, 21.73711967], [89.0120163, 21.73748207], [89.01154327, 21.7378006], [89.0111084, 21.73814964], [89.01069641, 21.73847961], [89.01035309, 21.73882103], [89.01002502, 21.73913574], [89.00971985, 21.73942947], [89.00943756, 21.73971558], [89.00914764, 21.73999977], [89.00884247, 21.74032021], [89.00849152, 21.74067116], [89.00810242, 21.74107552], [89.00772858, 21.74155426], [89.00728607, 21.74200058], [89.0068512, 21.74246979], [89.00637817, 21.7428894], [89.00589752, 21.74328041], [89.00550842, 21.74367905], [89.00522614, 21.74407005], [89.00509644, 21.74440956], [89.00496674, 21.74464035], [89.00482941, 21.74496651], [89.0046463, 21.74518013], [89.00435638, 21.74533081], [89.00393677, 21.74561882], [89.00382233, 21.74616432], [89.00364685, 21.74674988], [89.0031662, 21.74708748], [89.00284576, 21.74757957], [89.0027771, 21.74817848], [89.00245667, 21.74865913], [89.00216675, 21.74899101], [89.00191498, 21.74949837], [89.00157166, 21.75002098], [89.00139618, 21.75181007], [89.00125122, 21.75229073], [89.00106812, 21.75280762], [89.00094604, 21.75375938], [89.00097656, 21.75425529], [89.00102234, 21.75473022], [89.00110626, 21.75541878], [89.00102997, 21.75601006], [89.00089264, 21.75659752], [89.00086975, 21.75718117], [89.00080872, 21.75772858], [89.00067902, 21.75822067], [89.00058746, 21.75869179], [89.00054932, 21.75914955], [89.00048065, 21.75962067], [89.0, 21.7602787], [88.99973297, 21.76054955], [88.99972534, 21.76202583], [88.99958038, 21.76305389], [88.99950409, 21.76305389], [88.99958038, 21.76338959], [88.99973297, 21.76361084], [88.99973297, 21.76389122], [89.0, 21.76416588], [89.00047302, 21.76445007], [89.00102234, 21.76458931], [89.00167084, 21.76465416], [89.00229645, 21.76464081], [89.0029068, 21.76468658], [89.00348663, 21.76488113], [89.00405884, 21.76491547], [89.00461578, 21.76499176], [89.00478363, 21.76498604], [89.00511932, 21.7649765]]], [[[88.92710114, 21.76194954], [88.9276123, 21.76194382], [88.92816162, 21.76194954], [88.92874908, 21.76194954], [88.92936707, 21.76194954], [88.92999268, 21.76194954], [88.93061829, 21.76189995], [88.93112946, 21.76170349], [88.93122101, 21.76170158], [88.93250275, 21.76167107], [88.93276978, 21.76194954], [88.9338913, 21.76194954], [88.9338913, 21.76167107], [88.93416595, 21.76167107], [88.93444824, 21.76139069], [88.9347229, 21.76139069], [88.93499756, 21.76111031], [88.93611145, 21.76111031], [88.93638611, 21.76083183], [88.93638611, 21.76055527], [88.93723297, 21.7605629], [88.9375, 21.76028061], [88.9383316, 21.76028061], [88.93860626, 21.76000023], [88.93945313, 21.76000023], [88.93972015, 21.75972176], [88.94000244, 21.75972176], [88.9402771, 21.75944519], [88.94055176, 21.75945282], [88.94082642, 21.75917244], [88.94139099, 21.75917244], [88.94167328, 21.75889015], [88.9422226, 21.75889015], [88.94249725, 21.75861168], [88.94300842, 21.75859833], [88.94351196, 21.75852013], [88.9439621, 21.75836945], [88.94447327, 21.75831032], [88.94497681, 21.75810814], [88.94554138, 21.75805855], [88.94610596, 21.7580204], [88.94663239, 21.75782013], [88.94695282, 21.75749969], [88.94721985, 21.75777817], [88.94776917, 21.75777817], [88.94832611, 21.75722122], [88.9486084, 21.75722313], [88.94916534, 21.75666618], [88.94944763, 21.75666809], [88.95027924, 21.75582123], [88.95055389, 21.75583267], [88.95083618, 21.75555611], [88.95111084, 21.75555992], [88.95139313, 21.75527954], [88.95194244, 21.75527954], [88.9522171, 21.75500107], [88.95249939, 21.75500107], [88.95276642, 21.75472069], [88.95361328, 21.7547226], [88.95388794, 21.75444412], [88.95417023, 21.75444412], [88.95464325, 21.75434113], [88.95506287, 21.7542038], [88.95549011, 21.7541256], [88.95587921, 21.75399017], [88.95626831, 21.75390816], [88.95667267, 21.75389099], [88.95707703, 21.75387955], [88.9573822, 21.75387955], [88.9575119, 21.75387955], [88.95768738, 21.75388336], [88.95794678, 21.75389099], [88.95828247, 21.75388336], [88.95839691, 21.75388145], [88.95882416, 21.75384331], [88.95922089, 21.75370789], [88.95963287, 21.75362968], [88.96005249, 21.75361061], [88.96050262, 21.75360107], [88.96095276, 21.7535553], [88.96144104, 21.75337982], [88.96200562, 21.7532692], [88.96259308, 21.75304031], [88.9631958, 21.75275421], [88.96379089, 21.75239182], [88.96432495, 21.75196266], [88.9648056, 21.75152779], [88.96511078, 21.75102997], [88.96524048, 21.75047112], [88.965271, 21.74996376], [88.96525574, 21.74949646], [88.96521759, 21.74905968], [88.96520996, 21.74862099], [88.96513367, 21.74818802], [88.96504211, 21.74773979], [88.9650116, 21.74727058], [88.96500397, 21.74679375], [88.96499634, 21.74657822], [88.96498108, 21.74630165], [88.96492004, 21.74578285], [88.96482086, 21.74518967], [88.96487427, 21.74455452], [88.96496582, 21.74385071], [88.96507263, 21.74312019], [88.96528625, 21.74248123], [88.96555328, 21.74193001], [88.96581268, 21.74143028], [88.96609497, 21.74098969], [88.96642303, 21.74055099], [88.96679688, 21.74011993], [88.96729279, 21.73978424], [88.96784973, 21.73950958], [88.96840668, 21.73934364], [88.96889496, 21.73919868], [88.96936035, 21.73912048], [88.96982574, 21.7390461], [88.97029114, 21.73899269], [88.97071838, 21.7390995], [88.97110748, 21.73918724], [88.97145081, 21.73932457], [88.97180939, 21.73942184], [88.97219086, 21.73949623], [88.97257996, 21.73967171], [88.97303009, 21.7397728], [88.97343445, 21.73996925], [88.97386932, 21.74011993], [88.97426605, 21.74031258], [88.97464752, 21.74055862], [88.97502899, 21.74082947], [88.97545624, 21.74110031], [88.97595215, 21.74137688], [88.97622681, 21.74152184], [88.97648621, 21.74166107], [88.97704315, 21.74199486], [88.97754669, 21.74241066], [88.97809601, 21.74283981], [88.97861481, 21.74331093], [88.97918701, 21.74373245], [88.97978973, 21.74410057], [88.98042297, 21.74443054], [88.98104095, 21.74472618], [88.98165894, 21.74502373], [88.98225403, 21.74531364], [88.98284149, 21.74560165], [88.98317719, 21.74573517], [88.98344421, 21.74584007], [88.98404694, 21.7460537], [88.98469543, 21.74610138], [88.98531342, 21.7460537], [88.9858017, 21.7458477], [88.98623657, 21.74558067], [88.98668671, 21.7453289], [88.98712158, 21.74507141], [88.98748016, 21.74472046], [88.98774719, 21.74430084], [88.98793793, 21.74383163], [88.98803711, 21.74332047], [88.98803711, 21.7428112], [88.98797607, 21.74234009], [88.98782349, 21.74193954], [88.98768616, 21.74151039], [88.98749542, 21.74112892], [88.98722839, 21.74073982], [88.98697662, 21.74032021], [88.9866333, 21.73991966], [88.98620605, 21.73958015], [88.98574066, 21.73932076], [88.98535156, 21.7389698], [88.98500061, 21.73863983], [88.98457336, 21.73833084], [88.98416901, 21.73805428], [88.98378754, 21.7377758], [88.98342896, 21.7374897], [88.983078, 21.73719406], [88.98269653, 21.73688507], [88.98220825, 21.73660088], [88.98165894, 21.73633957], [88.98152161, 21.73627853], [88.98106384, 21.73606873], [88.98047638, 21.73582268], [88.97995758, 21.73555374], [88.97949982, 21.73527718], [88.97908783, 21.73500061], [88.97866821, 21.73474884], [88.97820282, 21.7345829], [88.97773743, 21.73442268], [88.97757721, 21.7343235], [88.97733307, 21.73417282], [88.97721863, 21.73417282], [88.97638702, 21.73333168], [88.97638702, 21.73250008], [88.97611237, 21.7322216], [88.97611237, 21.73166656], [88.97528076, 21.73082924], [88.97528076, 21.73055649], [88.97471619, 21.72999954], [88.97471619, 21.72972107], [88.97360992, 21.72861099], [88.97360992, 21.72833252], [88.97305298, 21.72777557], [88.97305298, 21.72750092], [88.97138977, 21.72583961], [88.97138977, 21.72556114], [88.97083282, 21.72500038], [88.97083282, 21.72472], [88.97027588, 21.72416687], [88.97027588, 21.7238903], [88.96971893, 21.72332954], [88.96971893, 21.72305489], [88.96944427, 21.72277832], [88.96943665, 21.72000122], [88.96971893, 21.71970749], [88.96971893, 21.7191658], [88.97000122, 21.71888924], [88.97000122, 21.71861076], [88.97027588, 21.71832848], [88.97027588, 21.71805573], [88.97055817, 21.71777916], [88.97055817, 21.71750069], [88.97222137, 21.71582985], [88.97222137, 21.71555519], [88.97249603, 21.71528053], [88.97277832, 21.71528053], [88.97389221, 21.71417046], [88.97416687, 21.71417046], [88.97471619, 21.7136097], [88.97499847, 21.7136116], [88.97528076, 21.71333313], [88.97555542, 21.71333313], [88.97583008, 21.71305656], [88.97611237, 21.71305656], [88.97721863, 21.71194649], [88.97750092, 21.71194649], [88.97805786, 21.71138954], [88.97888947, 21.71138954], [88.98055267, 21.70972061], [88.98083496, 21.70972252], [88.98139191, 21.70916748], [88.98166656, 21.70916939], [88.98332977, 21.70750046], [88.98332977, 21.70722008], [88.98361206, 21.70694351], [88.98361206, 21.70666695], [88.98387909, 21.70639038], [88.98332977, 21.70583153], [88.98274994, 21.70550156], [88.98219299, 21.70532227], [88.98163605, 21.70518684], [88.98114777, 21.70502281], [88.98066711, 21.70487022], [88.98020172, 21.70467949], [88.97975159, 21.70446014], [88.97928619, 21.70427322], [88.97883606, 21.70408058], [88.97869873, 21.70400429], [88.97840881, 21.70384598], [88.97801208, 21.70358086], [88.97763824, 21.70329285], [88.97727203, 21.70300293], [88.97689056, 21.70271111], [88.97651672, 21.70240021], [88.97619629, 21.7020607], [88.97590637, 21.70169258], [88.97560883, 21.7013607], [88.97528839, 21.70103073], [88.97502899, 21.70064545], [88.97476959, 21.70022964], [88.97452545, 21.69981194], [88.9741745, 21.69944], [88.97373962, 21.69909096], [88.97335052, 21.69885826], [88.97325134, 21.69880295], [88.97305298, 21.69861031], [88.97222137, 21.69861031], [88.97164917, 21.69917107], [88.97138977, 21.69916534], [88.97110748, 21.69944572], [88.97083282, 21.69944], [88.97027588, 21.70000076], [88.97000122, 21.70000076], [88.96943665, 21.70055962], [88.96916962, 21.70055962], [88.96861267, 21.70111084], [88.96833038, 21.70111084], [88.96806335, 21.70139122], [88.96778107, 21.70139122], [88.96749878, 21.70166969], [88.96722412, 21.70166779], [88.96694183, 21.70194435], [88.96194458, 21.70194435], [88.96166992, 21.70166779], [88.96083069, 21.70166969], [88.96029663, 21.70168686], [88.95987701, 21.70178032], [88.95947266, 21.70189095], [88.95903778, 21.70194054], [88.95861053, 21.70201111], [88.95819855, 21.70215988], [88.95774078, 21.70226479], [88.95726776, 21.70240021], [88.95677185, 21.70248795], [88.9562912, 21.70256042], [88.95584106, 21.70270729], [88.9553833, 21.7027626], [88.95493317, 21.70277023], [88.95445251, 21.70277977], [88.95397186, 21.70279312], [88.95349884, 21.70282745], [88.95323944, 21.70280838], [88.95304108, 21.70279503], [88.95259094, 21.70277977], [88.95214844, 21.7027607], [88.95168304, 21.70270729], [88.95120239, 21.70255089], [88.950737, 21.70246124], [88.95024109, 21.70232964], [88.94979095, 21.70251083], [88.94936371, 21.70278931], [88.94895935, 21.70315361], [88.94861603, 21.70360756], [88.94831848, 21.7041111], [88.94805908, 21.70416641], [88.94805908, 21.70444489], [88.9466629, 21.70583344], [88.94638824, 21.70583344], [88.94611359, 21.70611191], [88.9458313, 21.70611191], [88.94444275, 21.70750046], [88.94416809, 21.70750046], [88.94361115, 21.70806122], [88.94333649, 21.7080555], [88.9430542, 21.70833206], [88.94277954, 21.70833015], [88.94249725, 21.70861053], [88.9422226, 21.70861053], [88.9419632, 21.70889282], [88.94166565, 21.70888901], [88.9411087, 21.70944214], [88.94082642, 21.70944023], [88.9402771, 21.71000099], [88.94000244, 21.71000099], [88.93972015, 21.71027946], [88.93945313, 21.71027946], [88.93916321, 21.71055984], [88.93889618, 21.71055984], [88.93860626, 21.71084023], [88.9383316, 21.71084023], [88.93805695, 21.71111107], [88.93776703, 21.71111107], [88.93776703, 21.71138954], [88.9375, 21.71138954], [88.93694305, 21.71194649], [88.9366684, 21.71194077], [88.93611145, 21.71249962], [88.93583679, 21.71249962], [88.93499756, 21.71333313], [88.9347229, 21.71333122], [88.93416595, 21.71389961], [88.9338913, 21.71389961], [88.93360901, 21.71417046], [88.93305206, 21.71417046], [88.93276978, 21.71445084], [88.93250275, 21.71444511], [88.93222046, 21.71472168], [88.9319458, 21.71471977], [88.93138885, 21.71528053], [88.93110657, 21.71528053], [88.93083191, 21.71556091], [88.93055725, 21.71556091], [88.93000031, 21.71611023], [88.92973328, 21.71611023], [88.92944336, 21.71639061], [88.9291687, 21.71639061], [88.92888641, 21.71666908], [88.92861176, 21.71666718], [88.9283371, 21.71694374], [88.92805481, 21.71694374], [88.92778015, 21.71722221], [88.92749786, 21.7172184], [88.92722321, 21.71750069], [88.92694092, 21.71750069], [88.92666626, 21.71777916], [88.9263916, 21.71777916], [88.92610931, 21.71805954], [88.92582703, 21.71805954], [88.92527771, 21.71861076], [88.92500305, 21.71861076], [88.92472076, 21.71888924], [88.92444611, 21.71888924], [88.92415619, 21.71916962], [88.92388916, 21.7191658], [88.9236145, 21.71944427], [88.92333221, 21.71944427], [88.92305756, 21.71972275], [88.9227829, 21.71970749], [88.9227829, 21.72000122], [88.92250061, 21.72027779], [88.92250061, 21.7211113], [88.9227829, 21.72138977], [88.92277527, 21.72166634], [88.92305756, 21.7219429], [88.92321014, 21.72200012], [88.92338562, 21.72239876], [88.92362213, 21.72278214], [88.92391205, 21.72318268], [88.924263, 21.72361946], [88.92478943, 21.72412109], [88.92498016, 21.72445107], [88.9254303, 21.72524071], [88.92575073, 21.72582054], [88.92599487, 21.72638893], [88.92636108, 21.72679138], [88.92666626, 21.72724915], [88.92695618, 21.72777939], [88.92722321, 21.72835541], [88.92749786, 21.72898293], [88.92778015, 21.72962952], [88.92804718, 21.73027039], [88.92832947, 21.73084068], [88.92858124, 21.7313652], [88.92881012, 21.73184013], [88.92910004, 21.73222542], [88.92938232, 21.73260307], [88.92957306, 21.73304939], [88.92974091, 21.73348999], [88.9299469, 21.73387909], [88.93002319, 21.73426056], [88.93003845, 21.73443604], [88.93000031, 21.73472214], [88.93110657, 21.73583031], [88.93110657, 21.73639107], [88.93083191, 21.73639107], [88.93055725, 21.73666573], [88.93083191, 21.73694038], [88.93083191, 21.73806953], [88.93055725, 21.73805428], [88.93026733, 21.73833084], [88.93027496, 21.73916435], [88.93055725, 21.73944664], [88.93027496, 21.73944664], [88.93026733, 21.73971939], [88.93055725, 21.73999977], [88.93055725, 21.74139023], [88.93027496, 21.7416687], [88.93026733, 21.74221992], [88.93000031, 21.74250031], [88.93000031, 21.74388123], [88.92972565, 21.74416733], [88.92973328, 21.74500084], [88.92944336, 21.74527931], [88.92942047, 21.74584961], [88.92930603, 21.74625969], [88.92914581, 21.74669075], [88.92912292, 21.7471714], [88.92907715, 21.74771118], [88.9289093, 21.7483902], [88.92874146, 21.748909], [88.9285202, 21.74922943], [88.92835999, 21.74963951], [88.92825317, 21.75005913], [88.92808533, 21.7504425], [88.92798615, 21.75087166], [88.92784882, 21.75116348], [88.92780304, 21.75126076], [88.92762756, 21.75170135], [88.92747498, 21.75214767], [88.92727661, 21.75255966], [88.92717743, 21.7530365], [88.92732239, 21.75350952], [88.92726898, 21.75398827], [88.92720032, 21.7543602], [88.92708588, 21.75457764], [88.92693329, 21.7548008], [88.92672729, 21.75507927], [88.92655945, 21.7553997], [88.92650604, 21.75586128], [88.9264679, 21.75607109], [88.9262085, 21.75647163], [88.9261322, 21.75680923], [88.92560577, 21.75715828], [88.92533112, 21.75749969], [88.92501831, 21.75785065], [88.92467499, 21.75820732], [88.92427063, 21.75852966], [88.92390442, 21.75893784], [88.92353821, 21.75938416], [88.92311096, 21.75980949], [88.92273712, 21.76029968], [88.92235565, 21.76074982], [88.92224884, 21.76130295], [88.92237854, 21.7618618], [88.92282867, 21.76235008], [88.92343903, 21.76267815], [88.92408752, 21.7625103], [88.92468262, 21.76229286], [88.92523193, 21.76222801], [88.9257431, 21.76222038], [88.92621613, 21.76218033], [88.92663574, 21.76200485], [88.92710114, 21.76194954]]], [[[88.84490204, 21.61999893], [88.84432983, 21.61999893], [88.84375, 21.62002373], [88.84356689, 21.62006187], [88.84319305, 21.62014198], [88.84262085, 21.62030411], [88.84201813, 21.62049294], [88.84134674, 21.6204834], [88.84072113, 21.62044144], [88.84018707, 21.62042046], [88.83972168, 21.62044716], [88.83930969, 21.62054062], [88.83891296, 21.62068939], [88.83850098, 21.6208744], [88.83805847, 21.6210804], [88.83756256, 21.62126923], [88.83698273, 21.62144089], [88.83638, 21.62161064], [88.83583832, 21.62181854], [88.83533478, 21.62205124], [88.83487701, 21.62232018], [88.83439636, 21.62253952], [88.83393097, 21.6226902], [88.83345032, 21.62265396], [88.8330307, 21.62272072], [88.83264923, 21.62286949], [88.8323288, 21.62317085], [88.83183289, 21.62343025], [88.83127594, 21.62375069], [88.8306427, 21.62389946], [88.83006287, 21.62407112], [88.82959747, 21.62401962], [88.82919312, 21.62389946], [88.82878876, 21.62389755], [88.82840729, 21.62397194], [88.82804871, 21.62418938], [88.82772827, 21.6245327], [88.82748413, 21.62500763], [88.82720947, 21.62551308], [88.82688141, 21.62597466], [88.82641602, 21.62632179], [88.82583618, 21.62663078], [88.82525635, 21.62699127], [88.82466125, 21.6269207], [88.82420349, 21.62673187], [88.8237915, 21.6267395], [88.82338715, 21.62695122], [88.82277679, 21.62750053], [88.82195282, 21.62750053], [88.8216629, 21.62778282], [88.8208313, 21.62778282], [88.82055664, 21.62750053], [88.81999969, 21.62750053], [88.81973267, 21.62778282], [88.81944275, 21.62778282], [88.81861115, 21.62861061], [88.81777954, 21.62861061], [88.81749725, 21.62833023], [88.8172226, 21.62833214], [88.81685638, 21.62860107], [88.81645966, 21.62882042], [88.81598663, 21.62895966], [88.81552887, 21.62919807], [88.81510162, 21.62949753], [88.81474304, 21.62986946], [88.81439209, 21.6303215], [88.81401062, 21.6307106], [88.81362152, 21.63108635], [88.81325531, 21.63147736], [88.81292725, 21.63187981], [88.81257629, 21.63223076], [88.81225586, 21.63255882], [88.81201172, 21.6328907], [88.81185913, 21.63324928], [88.81166077, 21.63355064], [88.81143188, 21.63385582], [88.81122589, 21.63420486], [88.81105804, 21.63458061], [88.81083679, 21.63490105], [88.81066895, 21.63516808], [88.81054688, 21.63541985], [88.81043243, 21.63568115], [88.81030273, 21.63603973], [88.81022644, 21.63652992], [88.81005859, 21.63706017], [88.80977631, 21.63751793], [88.80937958, 21.63788986], [88.80906677, 21.63837051], [88.80889893, 21.63879013], [88.80885315, 21.63918114], [88.8088913, 21.6395607], [88.80899811, 21.63993263], [88.80919647, 21.6402607], [88.80944061, 21.64060974], [88.8097229, 21.64100647], [88.81001282, 21.64145279], [88.81033325, 21.64188957], [88.81064606, 21.64229965], [88.81095886, 21.64267921], [88.81112671, 21.6431179], [88.81130219, 21.64351082], [88.81153107, 21.6438694], [88.81183624, 21.64422989], [88.81217194, 21.64467812], [88.8125, 21.6451683], [88.81285858, 21.64563942], [88.8131485, 21.64606857], [88.81337738, 21.64641571], [88.81360626, 21.64668846], [88.81381226, 21.64698982], [88.81400299, 21.64733887], [88.81414795, 21.6475811], [88.81424713, 21.64774513], [88.81455994, 21.64817429], [88.81489563, 21.64863014], [88.81523132, 21.64912033], [88.81555939, 21.6496048], [88.81587219, 21.65003967], [88.81613922, 21.65044022], [88.81640625, 21.65077972], [88.81667328, 21.6511097], [88.81693268, 21.65148735], [88.81720734, 21.65193939], [88.81749725, 21.65248108], [88.81777954, 21.65306282], [88.81804657, 21.65364075], [88.81832123, 21.6541996], [88.81858826, 21.65468788], [88.81869507, 21.65485382], [88.81887817, 21.65513039], [88.81913757, 21.65557098], [88.81926727, 21.65606117], [88.81916809, 21.65611076], [88.81944275, 21.65638924], [88.81944275, 21.65666008], [88.82055664, 21.65777779], [88.82055664, 21.65833282], [88.8208313, 21.65860939], [88.8208313, 21.65888977], [88.82110596, 21.65917015], [88.82110596, 21.66028023], [88.82119751, 21.66065025], [88.82136536, 21.66107178], [88.82150269, 21.66152954], [88.8216629, 21.66167068], [88.8216629, 21.66278839], [88.82195282, 21.66305923], [88.82195282, 21.66389084], [88.82221985, 21.6641674], [88.82221985, 21.66443825], [88.82277679, 21.66500092], [88.82277679, 21.6697197], [88.82250214, 21.67000008], [88.82250214, 21.67055321], [88.82305908, 21.67111015], [88.82277679, 21.67138863], [88.82277679, 21.67165947], [88.82257843, 21.6721611], [88.82241821, 21.6725769], [88.82226563, 21.67298126], [88.82219696, 21.67337036], [88.82211304, 21.67371178], [88.82198334, 21.6740303], [88.82192993, 21.67436981], [88.82187653, 21.67469025], [88.8217926, 21.67502022], [88.82167053, 21.67533684], [88.82154083, 21.67569351], [88.82145691, 21.67612457], [88.82125092, 21.67657089], [88.82131195, 21.67699051], [88.82112885, 21.67731285], [88.82099152, 21.6776104], [88.82097626, 21.67783737], [88.82067108, 21.67806244], [88.82079315, 21.67855835], [88.820755, 21.67891312], [88.82048798, 21.6794796], [88.82060242, 21.67951965], [88.8200531, 21.68007278], [88.81975555, 21.68003082], [88.81971741, 21.68066406], [88.81965637, 21.68132973], [88.81944275, 21.68190956], [88.81920624, 21.68242264], [88.81916046, 21.68290901], [88.81910706, 21.68334007], [88.81891632, 21.68369102], [88.81881714, 21.68405724], [88.81865692, 21.68439293], [88.81858063, 21.68479156], [88.81845093, 21.68516922], [88.81835175, 21.68558121], [88.81829834, 21.68599892], [88.81813812, 21.6863308], [88.81806946, 21.68668938], [88.81804657, 21.68708992], [88.81800842, 21.68755341], [88.81782532, 21.68805313], [88.81777954, 21.68860054], [88.81777954, 21.68921089], [88.81777954, 21.68984032], [88.81777954, 21.69000053], [88.81777954, 21.69111061], [88.81749725, 21.69138908], [88.81749725, 21.69166756], [88.81777954, 21.6919384], [88.81777954, 21.69249916], [88.81804657, 21.6927681], [88.81804657, 21.69388962], [88.81833649, 21.69416618], [88.81833649, 21.6958313], [88.81861115, 21.69610977], [88.81861115, 21.69639015], [88.8188858, 21.69666672], [88.8188858, 21.69721985], [88.81861115, 21.69750023], [88.8188858, 21.6977787], [88.8188858, 21.69833565], [88.81915283, 21.6985817], [88.81916809, 21.69890022], [88.81944275, 21.69916534], [88.81944275, 21.70194435], [88.81916809, 21.70222282], [88.81916809, 21.7033329], [88.8188858, 21.70360756], [88.8188858, 21.70388985], [88.81861115, 21.70416641], [88.81861115, 21.7047081], [88.81833649, 21.70500183], [88.81833649, 21.7052803], [88.8180542, 21.70555496], [88.81804657, 21.70583153], [88.81749725, 21.70639038], [88.81749725, 21.70666695], [88.8172226, 21.70694351], [88.8172226, 21.70722008], [88.81694794, 21.70750046], [88.81694794, 21.70776939], [88.81582642, 21.70889282], [88.81582642, 21.70916939], [88.81500244, 21.71000099], [88.81443024, 21.71044922], [88.81387329, 21.71084595], [88.81333923, 21.7111702], [88.81285858, 21.71146965], [88.81244659, 21.71180344], [88.81200409, 21.71206284], [88.81163788, 21.71237946], [88.8116684, 21.71249962], [88.81138611, 21.71249962], [88.8105545, 21.71333313], [88.81027985, 21.71333122], [88.80944061, 21.71417046], [88.8088913, 21.71417046], [88.80860901, 21.71445084], [88.80833435, 21.71444511], [88.80805206, 21.71472168], [88.80722046, 21.71471977], [88.8069458, 21.71500015], [88.80639648, 21.71500015], [88.80583191, 21.71556091], [88.80555725, 21.71555519], [88.80526733, 21.71582985], [88.80500793, 21.71611977], [88.80473328, 21.71636009], [88.80438995, 21.71652985], [88.80399323, 21.71664047], [88.80356598, 21.71661949], [88.80311584, 21.71640968], [88.80259705, 21.71618843], [88.80197906, 21.71611977], [88.80132294, 21.71606255], [88.8007431, 21.71582985], [88.80014801, 21.71560097], [88.79950714, 21.71554947], [88.79886627, 21.71551895], [88.79827118, 21.71537018], [88.79769897, 21.71528816], [88.79714966, 21.715271], [88.79664612, 21.71519089], [88.7961731, 21.71489143], [88.79548645, 21.71492004], [88.7948761, 21.71474075], [88.79434204, 21.71453094], [88.79379272, 21.71443939], [88.79325867, 21.71435928], [88.79281616, 21.71421051], [88.79242706, 21.71406174], [88.79210663, 21.71380043], [88.79168701, 21.71360207], [88.79125977, 21.71340942], [88.79077148, 21.71329498], [88.79033661, 21.71310997], [88.78991699, 21.71290016], [88.78948212, 21.71274185], [88.78909302, 21.71251106], [88.78869629, 21.71228027], [88.78832245, 21.71200943], [88.78787231, 21.71190071], [88.78743744, 21.71168137], [88.78722382, 21.71194649], [88.78722382, 21.7116642], [88.78694153, 21.71138954], [88.78666687, 21.71138954], [88.78610992, 21.71084023], [88.7858429, 21.71084023], [88.78499603, 21.71000099], [88.78472137, 21.71027946], [88.78444672, 21.71027946], [88.78398895, 21.70998955], [88.78365326, 21.70976067], [88.78333282, 21.70950127], [88.78299713, 21.70920753], [88.78262329, 21.70889282], [88.7822113, 21.70853043], [88.78194427, 21.70861053], [88.78152466, 21.70819092], [88.78111267, 21.70776939], [88.78083038, 21.70777702], [88.78083038, 21.70750046], [88.78056335, 21.70722008], [88.78055573, 21.70694351], [88.78028107, 21.70666695], [88.77999878, 21.70667267], [88.77971649, 21.70639038], [88.77944183, 21.70639038], [88.77905273, 21.70609093], [88.77855682, 21.70575905], [88.77815247, 21.70536995], [88.77771759, 21.70501518], [88.77725983, 21.7047081], [88.77677917, 21.70443726], [88.77628326, 21.70413017], [88.77584076, 21.70375061], [88.77542114, 21.70337105], [88.77497101, 21.70305824], [88.77453613, 21.70277977], [88.77414703, 21.70249939], [88.77379608, 21.70219994], [88.77349854, 21.70183945], [88.77311707, 21.70146561], [88.77263641, 21.7010994], [88.77207184, 21.70072174], [88.77138519, 21.70045662], [88.7706604, 21.7002182], [88.76998901, 21.69993782], [88.76933289, 21.6996994], [88.76873779, 21.69947624], [88.76816559, 21.69936562], [88.76802826, 21.69931412], [88.76770782, 21.69919205], [88.76727295, 21.69910622], [88.76686096, 21.69902992], [88.76643372, 21.69904518], [88.76602173, 21.69908142], [88.76589966, 21.69903755], [88.76566315, 21.69894409], [88.76531982, 21.69894218], [88.76494598, 21.69912148], [88.764534, 21.69924355], [88.76409149, 21.69944954], [88.76358795, 21.6997509], [88.76307678, 21.70015907], [88.76264191, 21.70068932], [88.76251221, 21.70137024], [88.76249695, 21.70207977], [88.76254272, 21.70278931], [88.76277924, 21.70343018], [88.76309967, 21.70401573], [88.76357269, 21.70442009], [88.76405334, 21.70474052], [88.7644577, 21.70501518], [88.76480865, 21.7052803], [88.76515198, 21.70556259], [88.76553345, 21.70582581], [88.76596069, 21.70603943], [88.7664566, 21.70615768], [88.76689911, 21.70636368], [88.76735687, 21.70651817], [88.76780701, 21.70671082], [88.76821136, 21.70695114], [88.76860809, 21.70722389], [88.76901245, 21.70749474], [88.76945496, 21.70770264], [88.77004242, 21.70768738], [88.77054596, 21.70779991], [88.77099609, 21.70800018], [88.77145386, 21.70814514], [88.77186584, 21.70835876], [88.77226257, 21.70861053], [88.7726593, 21.70889282], [88.77305603, 21.70916939], [88.77346039, 21.70944023], [88.77388, 21.70969582], [88.7743454, 21.7099247], [88.77478027, 21.71022987], [88.77523804, 21.71052933], [88.77572632, 21.71076012], [88.77619171, 21.71096039], [88.77661896, 21.71121407], [88.77703094, 21.71149445], [88.77747345, 21.71170235], [88.77783966, 21.71194077], [88.77814484, 21.71218681], [88.77845001, 21.71240044], [88.77871704, 21.71264076], [88.77908325, 21.71287918], [88.77945709, 21.7132206], [88.77987671, 21.71363068], [88.78025818, 21.71409607], [88.78031921, 21.71419716], [88.78056335, 21.71458054], [88.78084564, 21.71499634], [88.78114319, 21.71533012], [88.7813797, 21.71565628], [88.78159332, 21.7159996], [88.7817688, 21.71638107], [88.78194427, 21.71676826], [88.78208923, 21.71718979], [88.78222656, 21.71767044], [88.78235626, 21.71820259], [88.78253174, 21.71877289], [88.78278351, 21.71936035], [88.78305817, 21.71997452], [88.7832489, 21.72062111], [88.78309631, 21.72129822], [88.78305817, 21.72200966], [88.78302765, 21.72266006], [88.78289795, 21.72322083], [88.78279114, 21.72375107], [88.78272247, 21.72426987], [88.78257751, 21.72460175], [88.78251648, 21.72475052], [88.78236389, 21.7252903], [88.78224182, 21.7258606], [88.7822113, 21.7264576], [88.78209686, 21.72702026], [88.78182983, 21.72752953], [88.78157806, 21.72805977], [88.78131866, 21.72859001], [88.78100586, 21.72910118], [88.78063965, 21.72953606], [88.78040314, 21.7300396], [88.78031921, 21.73057175], [88.78051758, 21.73106194], [88.7808609, 21.73149109], [88.78131104, 21.73186493], [88.78138733, 21.73193932], [88.78157043, 21.73212624], [88.78193665, 21.73250008], [88.7822113, 21.73250008], [88.78250122, 21.73278046], [88.78333282, 21.73278046], [88.78360748, 21.73306274], [88.78555298, 21.73305511], [88.78583527, 21.73333359], [88.78694153, 21.73333359], [88.78722382, 21.73361015], [88.78806305, 21.73361015], [88.78833008, 21.73389053], [88.78861237, 21.73389053], [88.78888702, 21.73417282], [88.78922272, 21.7341671], [88.78971863, 21.7341671], [88.78985596, 21.73430443], [88.79000092, 21.73444366], [88.79055786, 21.73444366], [88.79083252, 21.73472214], [88.79138947, 21.73472214], [88.79154205, 21.73488045], [88.79165649, 21.73500061], [88.79194641, 21.73500061], [88.79222107, 21.7352829], [88.79250336, 21.73527718], [88.79305267, 21.73583031], [88.79305267, 21.73639107], [88.79333496, 21.73666573], [88.79333496, 21.73694229], [88.79305267, 21.73722076], [88.79305267, 21.73777962], [88.79277802, 21.73806953], [88.79277802, 21.73861122], [88.79222107, 21.73861122], [88.79165649, 21.73917007], [88.79138947, 21.73916435], [88.79111481, 21.73944664], [88.79055786, 21.73944664], [88.79027557, 21.7397213], [88.78916931, 21.73971939], [88.78888702, 21.73999977], [88.78849792, 21.73999977], [88.78749847, 21.73999977], [88.78721619, 21.74028015], [88.78694153, 21.74027824], [88.78666687, 21.74055672], [88.78666687, 21.74083328], [88.78668213, 21.74117279], [88.78694153, 21.74159813], [88.78721619, 21.74202919], [88.78753662, 21.74241447], [88.78788757, 21.74274063], [88.78829193, 21.74303055], [88.78865051, 21.74339104], [88.78894806, 21.74380112], [88.78927612, 21.74415016], [88.7895813, 21.74446106], [88.78978729, 21.74477959], [88.78999329, 21.74504089], [88.79013824, 21.74532127], [88.79025269, 21.7456398], [88.79033661, 21.74603081], [88.79049683, 21.74643707], [88.79064178, 21.74691963], [88.79078674, 21.74743271], [88.79083252, 21.7479229], [88.79083252, 21.74805641], [88.79083252, 21.74860954], [88.79055786, 21.74888992], [88.79083252, 21.7491703], [88.79110718, 21.7491703], [88.79139709, 21.74888992], [88.79165649, 21.74888992], [88.79194641, 21.74860954], [88.79250336, 21.74861145], [88.79277802, 21.74833107], [88.79305267, 21.74833107], [88.79333496, 21.74805641], [88.79374695, 21.74797058], [88.79424286, 21.74778938], [88.79473877, 21.74764442], [88.79516602, 21.7474575], [88.79559326, 21.7473011], [88.79601288, 21.74723053], [88.79646301, 21.7472229], [88.79698944, 21.7471199], [88.79762268, 21.74703026], [88.79833221, 21.74706078], [88.79910278, 21.74710083], [88.79988861, 21.74710083], [88.80068207, 21.74708176], [88.80142975, 21.74699974], [88.80211639, 21.74700356], [88.80271149, 21.74697495], [88.80329895, 21.74699402], [88.80361176, 21.7472229], [88.80500031, 21.7472744], [88.80526733, 21.74749947], [88.80555725, 21.74749947], [88.80583191, 21.74777985], [88.80638885, 21.74777794], [88.80648041, 21.74787331], [88.80665588, 21.74806023], [88.8077774, 21.74805641], [88.80805206, 21.74833107], [88.8088913, 21.74833107], [88.80916595, 21.74861145], [88.80944061, 21.74860954], [88.8097229, 21.74888992], [88.80999756, 21.74888992], [88.81027985, 21.7491703], [88.81083679, 21.74916649], [88.811203, 21.74953842], [88.81138611, 21.74972153], [88.8116684, 21.74971962], [88.81223297, 21.74999046], [88.81282806, 21.75029945], [88.81339264, 21.75062943], [88.81388092, 21.75098991], [88.81436157, 21.75138092], [88.81484985, 21.75177574], [88.81536102, 21.75217056], [88.81586456, 21.75255775], [88.81630707, 21.75295258], [88.8167038, 21.75329971], [88.8170929, 21.75358963], [88.81742859, 21.75387764], [88.81774139, 21.75415993], [88.81804657, 21.75445747], [88.818367, 21.75476074], [88.81868744, 21.75505066], [88.81903076, 21.75530243], [88.81936646, 21.75556183], [88.81967926, 21.75583839], [88.81996918, 21.7561512], [88.82022858, 21.75647926], [88.82045746, 21.75683975], [88.8207016, 21.75721741], [88.820961, 21.75758171], [88.82125854, 21.7578907], [88.82161713, 21.7581501], [88.82193756, 21.75843048], [88.82224274, 21.75872993], [88.82254028, 21.75906944], [88.82285309, 21.75938988], [88.82316589, 21.75969124], [88.8234787, 21.75997734], [88.82377625, 21.76025963], [88.82408142, 21.76054955], [88.82440186, 21.76083183], [88.82472992, 21.76111984], [88.82507324, 21.76139069], [88.82541656, 21.76167107], [88.82575226, 21.76194763], [88.82610321, 21.76223946], [88.82645416, 21.76253891], [88.82686615, 21.76279068], [88.82730103, 21.76305008], [88.8277359, 21.76330948], [88.82813263, 21.76360321], [88.82850647, 21.76391029], [88.82888031, 21.76424026], [88.82926178, 21.76457024], [88.82970428, 21.76478958], [88.83016205, 21.76502037], [88.8306427, 21.76530075], [88.83110809, 21.76555443], [88.8312912, 21.76573753], [88.83167267, 21.76610947], [88.83194733, 21.7658329], [88.83277893, 21.7658329], [88.83305359, 21.76555443], [88.83416748, 21.76556015], [88.83444214, 21.76527977], [88.8347168, 21.76527977], [88.83499908, 21.76556015], [88.83528137, 21.76527977], [88.83583069, 21.76527977], [88.83611298, 21.76501083], [88.83777618, 21.76501083], [88.83805847, 21.76472092], [88.83944702, 21.76472473], [88.83972168, 21.76444435], [88.84055328, 21.76444435], [88.84083557, 21.76472473], [88.84111023, 21.76444435], [88.84139252, 21.76444435], [88.84166718, 21.76416588], [88.84388733, 21.76416969], [88.84416962, 21.76389122], [88.84555054, 21.76389122], [88.84583282, 21.76361084], [88.8466568, 21.76361084], [88.84694672, 21.76333046], [88.84750366, 21.76333237], [88.84777832, 21.7630558], [88.84971619, 21.76305962], [88.84999847, 21.76278114], [88.85166931, 21.76278114], [88.85193634, 21.76250076], [88.85250092, 21.76250076], [88.8527832, 21.76222038], [88.85388947, 21.76222229], [88.85416412, 21.76194382], [88.85444641, 21.76222229], [88.85500336, 21.76222229], [88.85527802, 21.76194382], [88.85639191, 21.76194954], [88.85666656, 21.76167107], [88.85721588, 21.76177979], [88.8576355, 21.76183319], [88.85806274, 21.76171112], [88.85848999, 21.76167107], [88.85891724, 21.76167107], [88.85935974, 21.76167107], [88.85980225, 21.76167107], [88.86023712, 21.76167107], [88.86068726, 21.76167107], [88.86115265, 21.76167107], [88.8616333, 21.76161957], [88.86165619, 21.76139069], [88.86222076, 21.76139069], [88.86250305, 21.76111031], [88.86277771, 21.76111031], [88.86305237, 21.76083183], [88.86332703, 21.76111031], [88.86361694, 21.76111031], [88.8638916, 21.76083374], [88.86416626, 21.76083374], [88.86499786, 21.76000023], [88.86499786, 21.75889015], [88.86528015, 21.75861168], [88.86528015, 21.75638962], [88.86499786, 21.75611115], [88.86499786, 21.75582123], [88.86472321, 21.75555611], [88.86472321, 21.75500107], [88.86444092, 21.75472069], [88.86444092, 21.75444412], [88.86416626, 21.75416756], [88.86416626, 21.75361061], [88.86332703, 21.75278091], [88.86332703, 21.75250053], [88.86305237, 21.75222015], [88.86305237, 21.75166512], [88.86250305, 21.75111008], [88.86250305, 21.75083351], [88.86222076, 21.75055313], [88.86222076, 21.75028038], [88.86165619, 21.74971962], [88.86138916, 21.74972153], [88.86055756, 21.74888802], [88.86000061, 21.74888992], [88.85916138, 21.74811363], [88.85861206, 21.74806023], [88.85832977, 21.74777985], [88.85806274, 21.74777985], [88.85778046, 21.74749947], [88.85749054, 21.74749947], [88.85582733, 21.74582863], [88.85583496, 21.74555588], [88.85555267, 21.7455616], [88.85527802, 21.74527931], [88.85500336, 21.74527931], [88.85500336, 21.74500084], [88.85333252, 21.74332809], [88.85305786, 21.74294472], [88.85276794, 21.74259567], [88.85246277, 21.74225998], [88.85211945, 21.74194145], [88.85179901, 21.74160957], [88.85153961, 21.74122047], [88.85128021, 21.74081993], [88.8510437, 21.74046898], [88.85077667, 21.74018288], [88.85057068, 21.73986053], [88.85040283, 21.73950958], [88.85027313, 21.7391243], [88.8501358, 21.73875427], [88.84999847, 21.73888969], [88.84944153, 21.73833084], [88.84944153, 21.73805428], [88.84916687, 21.73777962], [88.84916687, 21.73750114], [88.84889221, 21.73722076], [88.84889221, 21.73666573], [88.8483429, 21.73611069], [88.84812164, 21.73552322], [88.84780121, 21.73497581], [88.84749603, 21.73439026], [88.847229, 21.73382187], [88.84697723, 21.73330116], [88.84682465, 21.73282051], [88.84667206, 21.73250008], [88.84662628, 21.73241043], [88.84638977, 21.7322216], [88.84638977, 21.73194504], [88.84583282, 21.73138809], [88.84583282, 21.73110962], [88.84555817, 21.73083305], [88.84555817, 21.73055649], [88.84527588, 21.73027992], [88.84527588, 21.72972107], [88.84500122, 21.7294445], [88.84500122, 21.72916794], [88.84471893, 21.72887993], [88.84471893, 21.72750092], [88.84443665, 21.72722054], [88.84444427, 21.72694588], [88.84416962, 21.7266674], [88.84416962, 21.72639084], [88.84388733, 21.72611046], [88.84388733, 21.72556114], [88.84361267, 21.72528076], [88.8436203, 21.72470284], [88.84388733, 21.72444344], [88.84388733, 21.72417068], [88.84333038, 21.72360992], [88.84333038, 21.72333336], [88.84292603, 21.72292328], [88.84278107, 21.72277832], [88.84278107, 21.72256279], [88.84278107, 21.72222137], [88.84249878, 21.72194481], [88.84249878, 21.7211113], [88.84222412, 21.72083282], [88.84222412, 21.71999931], [88.84194183, 21.71970749], [88.84194183, 21.71888924], [88.84139252, 21.71832848], [88.84139252, 21.71805573], [88.84111023, 21.71777916], [88.84111023, 21.71750069], [88.8408432, 21.7172184], [88.84083557, 21.71694374], [88.84027863, 21.7163887], [88.84027863, 21.71583366], [88.83999634, 21.71555519], [88.83999634, 21.71445084], [88.83972168, 21.71417046], [88.83972168, 21.71389961], [88.83999634, 21.7136097], [88.83999634, 21.70888901], [88.83972168, 21.70861053], [88.83972168, 21.70806122], [88.83944702, 21.70776939], [88.83944702, 21.70722008], [88.83916473, 21.70694351], [88.8391571, 21.70667267], [88.83972168, 21.70611191], [88.83972168, 21.70583344], [88.83999634, 21.70555496], [88.83999634, 21.70500183], [88.84012604, 21.7046299], [88.84055328, 21.70444489], [88.84027863, 21.70416641], [88.84027863, 21.70388985], [88.83972168, 21.70332909], [88.83972168, 21.70277977], [88.84027863, 21.70222092], [88.84027863, 21.70166779], [88.84055328, 21.70139122], [88.84055328, 21.69972038], [88.84083557, 21.69944572], [88.84055328, 21.69916534], [88.84055328, 21.69721985], [88.84083557, 21.69694328], [88.8408432, 21.69639015], [88.84055328, 21.69610977], [88.84055328, 21.69527817], [88.84027863, 21.69499969], [88.84027863, 21.69388962], [88.84055328, 21.69361115], [88.84055328, 21.69333267], [88.84083557, 21.69305611], [88.8408432, 21.69222069], [88.84111023, 21.69194412], [88.84111023, 21.69000053], [88.8408432, 21.68972969], [88.8408432, 21.68861008], [88.84111023, 21.68833351], [88.84111023, 21.68805695], [88.84139252, 21.68778038], [88.84139252, 21.68695831], [88.84166718, 21.6866703], [88.84166718, 21.68472099], [88.84194183, 21.68444633], [88.84194183, 21.68361092], [88.84222412, 21.68333244], [88.84222412, 21.6827774], [88.84250641, 21.68250084], [88.84249878, 21.68222237], [88.84222412, 21.68194389], [88.84222412, 21.68111038], [88.84250641, 21.68083191], [88.84249878, 21.68055534], [88.84333038, 21.67972183], [88.84366608, 21.67928314], [88.84361267, 21.67916679], [88.84388733, 21.67889023], [88.84388733, 21.67778969], [88.84443665, 21.67721748], [88.84444427, 21.67694473], [88.84500122, 21.67638969], [88.84500122, 21.67555809], [88.84527588, 21.67527962], [88.84527588, 21.67444038], [88.84555817, 21.67416763], [88.84555054, 21.67389107], [88.84610748, 21.67333031], [88.84610748, 21.67305756], [88.84638977, 21.67278099], [88.84638977, 21.67193985], [88.84694672, 21.67138863], [88.84694672, 21.67111015], [88.84722137, 21.67083549], [88.84722137, 21.67000008], [88.84805298, 21.66917038], [88.84805298, 21.66860008], [88.84833527, 21.66833115], [88.84833527, 21.66805649], [88.84860992, 21.66777992], [88.84860992, 21.66749954], [88.84889221, 21.66722107], [88.84889221, 21.66610909], [88.84916687, 21.66583061], [88.84916687, 21.66527748], [88.85028076, 21.66416931], [88.8503418, 21.66385078], [88.85054016, 21.66352081], [88.85072327, 21.66316986], [88.85092163, 21.66280174], [88.85116577, 21.66243553], [88.85140228, 21.66202927], [88.85164642, 21.66160965], [88.85190582, 21.66114044], [88.85217285, 21.66061974], [88.85247803, 21.66009331], [88.85276794, 21.65955544], [88.8530426, 21.65907288], [88.85328674, 21.6586628], [88.853508, 21.65834236], [88.85370636, 21.65806961], [88.85388947, 21.65782356], [88.85407257, 21.65757561], [88.85418701, 21.65727043], [88.85431671, 21.65694046], [88.8544693, 21.65658951], [88.85466766, 21.65621758], [88.85489655, 21.65578079], [88.85444641, 21.65528107], [88.85472107, 21.65500069], [88.85472107, 21.65472031], [88.85527802, 21.65416718], [88.85555267, 21.6541729], [88.85573578, 21.65363121], [88.85588837, 21.65320015], [88.85610199, 21.65284157], [88.85629272, 21.65248108], [88.85644531, 21.65212631], [88.85663605, 21.65183067], [88.85681152, 21.65149117], [88.85691071, 21.65108109], [88.85694122, 21.65061188], [88.85695648, 21.6501255], [88.85701752, 21.64966965], [88.85723114, 21.6493187], [88.85749054, 21.64899063], [88.85774231, 21.64863968], [88.85793304, 21.64826012], [88.85809326, 21.64783096], [88.85822296, 21.6473999], [88.85835266, 21.64694786], [88.85851288, 21.64647102], [88.85873413, 21.64598656], [88.85897064, 21.64545059], [88.85919189, 21.6448307], [88.85945129, 21.64421272], [88.85972595, 21.64361], [88.85993958, 21.64306641], [88.86000061, 21.64255905], [88.86001587, 21.6421299], [88.86009979, 21.64175987], [88.86026001, 21.64139938], [88.8604126, 21.64094734], [88.86052704, 21.64036942], [88.86054993, 21.6396904], [88.86049652, 21.63898087], [88.8602829, 21.6383419], [88.86006927, 21.63776207], [88.85995483, 21.6372261], [88.85975647, 21.63683128], [88.85952759, 21.6364994], [88.85922241, 21.63624001], [88.8589325, 21.63595009], [88.85868835, 21.63562012], [88.8584671, 21.63528061], [88.85829163, 21.63498116], [88.85807037, 21.63471985], [88.85785675, 21.63442993], [88.85765076, 21.63409042], [88.85739899, 21.63365364], [88.85707855, 21.63321686], [88.85666656, 21.63284111], [88.85623932, 21.63246155], [88.85585022, 21.63204193], [88.85549927, 21.63162041], [88.85514069, 21.63124084], [88.85482025, 21.63084984], [88.85450745, 21.63047981], [88.85423279, 21.63006973], [88.85392761, 21.62965012], [88.8536377, 21.62919807], [88.85334015, 21.62877083], [88.85305786, 21.62838936], [88.85279846, 21.62808037], [88.85256195, 21.62781906], [88.85237885, 21.62751007], [88.85217285, 21.62722015], [88.85189056, 21.62694168], [88.8515625, 21.62668037], [88.85116577, 21.62646294], [88.85069275, 21.62646294], [88.85033417, 21.62663841], [88.84999847, 21.62694168], [88.84999847, 21.62750053], [88.84889221, 21.62861061], [88.84889221, 21.62916756], [88.84860992, 21.62944221], [88.84860992, 21.62972069], [88.8483429, 21.63000107], [88.84749603, 21.63000107], [88.84726715, 21.62976837], [88.84666443, 21.6297226], [88.84610748, 21.62916756], [88.84610748, 21.6288929], [88.8466568, 21.62833023], [88.84666443, 21.62750053], [88.84694672, 21.62722015], [88.84638977, 21.62666702], [88.84606934, 21.62672043], [88.84552765, 21.62688065], [88.84506226, 21.62692833], [88.84461975, 21.62695122], [88.84420013, 21.62699509], [88.84383392, 21.62717247], [88.84349823, 21.62738991], [88.84333038, 21.62750053], [88.84305573, 21.6277771], [88.84305573, 21.62944221], [88.84278107, 21.62972069], [88.84278107, 21.63138962], [88.84306335, 21.63167], [88.84305573, 21.63277817], [88.84333038, 21.63305664], [88.84333038, 21.63332939], [88.84336853, 21.63376045], [88.84333038, 21.63389015], [88.84361267, 21.63417053], [88.84361267, 21.63611031], [88.84388733, 21.63639069], [88.84388733, 21.63750076], [88.84416962, 21.63777733], [88.84416962, 21.63832855], [88.84444427, 21.63861084], [88.84443665, 21.64110947], [88.84416962, 21.64138794], [88.84416962, 21.64194489], [88.84388733, 21.64221954], [88.84388733, 21.64305305], [88.84361267, 21.64333344], [88.84361267, 21.64361], [88.84333038, 21.64389038], [88.84333038, 21.64416695], [88.84305573, 21.64444351], [88.84306335, 21.64472008], [88.84278107, 21.64500046], [88.84278107, 21.64528084], [88.84223175, 21.64560699], [88.84181976, 21.6460743], [88.84139252, 21.64649963], [88.84113312, 21.64670181], [88.84094238, 21.64683533], [88.84083557, 21.64694595], [88.84055328, 21.64694023], [88.83999634, 21.64750099], [88.83972168, 21.64750099], [88.83944702, 21.64777946], [88.8391571, 21.64777946], [88.83889008, 21.64805984], [88.83860779, 21.64805984], [88.83805847, 21.64861107], [88.83777618, 21.64861107], [88.83757019, 21.64882088], [88.83718109, 21.64897156], [88.8367691, 21.64912033], [88.83631897, 21.6492424], [88.83585358, 21.64939117], [88.83532715, 21.64950943], [88.83479309, 21.6496582], [88.83472443, 21.64944458], [88.83444214, 21.64972305], [88.83416748, 21.64972305], [88.83389282, 21.64999962], [88.83361053, 21.64999962], [88.83333588, 21.65027809], [88.83222198, 21.65027809], [88.83139038, 21.6511116], [88.83110809, 21.6511097], [88.83056641, 21.65195274], [88.83000183, 21.65195274], [88.82971954, 21.65167236], [88.82971954, 21.65138817], [88.82917023, 21.65083122], [88.82888794, 21.65083313], [88.82861328, 21.65055466], [88.82917023, 21.64999962], [88.82971954, 21.64999962], [88.83000183, 21.65027809], [88.83027649, 21.65027809], [88.83056641, 21.64999962], [88.83083344, 21.64999962], [88.83139038, 21.64944077], [88.83166504, 21.64944458], [88.83194733, 21.64916611], [88.83222198, 21.64916992], [88.83249664, 21.64888954], [88.83280182, 21.64882088], [88.83322144, 21.64860725], [88.83362579, 21.64838982], [88.83409882, 21.64825058], [88.83454895, 21.6480999], [88.83502197, 21.64797974], [88.83547974, 21.64782906], [88.83598328, 21.64772034], [88.83647919, 21.64755058], [88.83702087, 21.64743805], [88.83756256, 21.64726067], [88.83809662, 21.64712524], [88.83856201, 21.64692116], [88.83898163, 21.64664268], [88.83938599, 21.64632034], [88.83978271, 21.64595985], [88.84020233, 21.64562416], [88.84063721, 21.64529037], [88.84105682, 21.64493942], [88.84140015, 21.64452553], [88.84171295, 21.64410973], [88.84196472, 21.64370346], [88.84218597, 21.64333344], [88.84233093, 21.64297676], [88.84247589, 21.64266014], [88.84261322, 21.64232826], [88.84274292, 21.64198112], [88.84281921, 21.64156914], [88.8429184, 21.64114952], [88.84301758, 21.64072418], [88.8430481, 21.64026642], [88.84306335, 21.63978958], [88.8430481, 21.63932228], [88.84298706, 21.63886452], [88.8428421, 21.63844872], [88.84269714, 21.63797951], [88.84255981, 21.63747978], [88.84250641, 21.63696289], [88.84243774, 21.63646126], [88.84227753, 21.63602066], [88.84216309, 21.63553047], [88.84200287, 21.63504028], [88.84191895, 21.63452911], [88.84179688, 21.63404846], [88.84163666, 21.63360023], [88.84151459, 21.6331749], [88.84159851, 21.63273621], [88.84159088, 21.63228035], [88.84141541, 21.63180923], [88.84124756, 21.63124084], [88.84130859, 21.63055038], [88.84137726, 21.62984085], [88.84143829, 21.62914085], [88.84159088, 21.62850189], [88.84174347, 21.62787628], [88.84201813, 21.62735939], [88.84234619, 21.6269207], [88.84269714, 21.62648964], [88.84306335, 21.62611008], [88.84340668, 21.62574005], [88.84374237, 21.62535095], [88.8441391, 21.62502289], [88.84455872, 21.62473106], [88.8449707, 21.62445068], [88.84542084, 21.6241684], [88.84583282, 21.62388992], [88.8460083, 21.62371254], [88.84638977, 21.62333298], [88.84638977, 21.6222229], [88.84666443, 21.62194443], [88.84666443, 21.62138939], [88.84694672, 21.62111092], [88.84583282, 21.62000084], [88.84532166, 21.62000275], [88.84490204, 21.61999893]]], [[[88.36538696, 21.76416588], [88.36593628, 21.76415062], [88.36645508, 21.76407242], [88.36688232, 21.76392365], [88.36728668, 21.76391029], [88.3677063, 21.76403046], [88.36818695, 21.76415062], [88.36868286, 21.7639904], [88.36915588, 21.76363945], [88.37001038, 21.76362038], [88.37041473, 21.76362038], [88.37082672, 21.76361084], [88.3710022, 21.76324081], [88.37094879, 21.76266479], [88.37088776, 21.762043], [88.37086487, 21.76143646], [88.37082672, 21.76081848], [88.37069702, 21.76021194], [88.3704071, 21.75967407], [88.37001038, 21.75917244], [88.36951447, 21.75871277], [88.36901093, 21.75827408], [88.36854553, 21.75784302], [88.3680954, 21.75748062], [88.36760712, 21.75728035], [88.36712646, 21.75715828], [88.366745, 21.75697327], [88.36643982, 21.75671005], [88.36620331, 21.75638008], [88.36605072, 21.75598907], [88.36589813, 21.75562096], [88.36579132, 21.75523186], [88.36563873, 21.75482941], [88.36553192, 21.75437546], [88.36538696, 21.75389099], [88.36525726, 21.75328827], [88.36504364, 21.75271225], [88.36476135, 21.75216103], [88.36438751, 21.75165558], [88.36390686, 21.75123024], [88.36340332, 21.75086021], [88.36292267, 21.75052071], [88.36248016, 21.75020409], [88.36207581, 21.74985123], [88.36171722, 21.74945068], [88.36136627, 21.7490406], [88.36109924, 21.74860191], [88.36080933, 21.748209], [88.36052704, 21.74778938], [88.36023712, 21.74735069], [88.36001587, 21.74678993], [88.35980988, 21.74620056], [88.35974884, 21.74562073], [88.35975647, 21.74514008], [88.3598175, 21.74477005], [88.35990143, 21.74447823], [88.3599472, 21.74416924], [88.36000824, 21.74386406], [88.36009216, 21.74352074], [88.3602066, 21.74315262], [88.36032104, 21.74274445], [88.36045837, 21.74233055], [88.36058807, 21.74187088], [88.3607254, 21.74139977], [88.36078644, 21.74086189], [88.36079407, 21.74029541], [88.36074829, 21.73973083], [88.36062622, 21.73918915], [88.36054993, 21.73863983], [88.36045837, 21.73813629], [88.36032867, 21.7376709], [88.36019897, 21.73721695], [88.36006165, 21.73676109], [88.3599472, 21.73628044], [88.3598175, 21.73580933], [88.35971832, 21.73531914], [88.35967255, 21.73488045], [88.35968781, 21.73450089], [88.35977936, 21.73417282], [88.3599472, 21.73385811], [88.36012268, 21.73348045], [88.3603363, 21.73304939], [88.36064148, 21.7326107], [88.36104584, 21.73223114], [88.36149597, 21.73191071], [88.36197662, 21.73163223], [88.36247253, 21.7313652], [88.36293793, 21.73122978], [88.36338043, 21.73081779], [88.36374664, 21.73036957], [88.36432648, 21.72982979], [88.36417389, 21.72888947], [88.3638916, 21.72777557], [88.36387634, 21.72694016], [88.36416626, 21.7266674], [88.36416626, 21.72500038], [88.36444092, 21.72472], [88.36444092, 21.72416687], [88.36472321, 21.7238903], [88.36472321, 21.72332954], [88.36499786, 21.72305489], [88.36499786, 21.72277832], [88.36528015, 21.72249985], [88.36528015, 21.72221947], [88.3658371, 21.72166634], [88.36611176, 21.72167015], [88.36638641, 21.72138977], [88.3666687, 21.72138977], [88.36805725, 21.72000122], [88.36833191, 21.72000122], [88.3694458, 21.71888924], [88.3694458, 21.71861076], [88.37001038, 21.71916962], [88.3702774, 21.71916962], [88.37055206, 21.71888924], [88.37082672, 21.71888924], [88.37110901, 21.71861076], [88.3713913, 21.71861076], [88.37166595, 21.71832848], [88.37194824, 21.7183342], [88.3722229, 21.71805573], [88.37249756, 21.71805954], [88.37275696, 21.71783066], [88.37328339, 21.71777916], [88.37384033, 21.71777916], [88.37445068, 21.71777725], [88.37506104, 21.71777916], [88.37565613, 21.71783066], [88.37623596, 21.71786118], [88.37671661, 21.71762085], [88.37722015, 21.71751404], [88.37774658, 21.71753883], [88.37824249, 21.71772957], [88.37876129, 21.71777916], [88.37927246, 21.71777916], [88.37980652, 21.71777916], [88.38038635, 21.71783066], [88.38098145, 21.71799088], [88.38162231, 21.7180481], [88.3822403, 21.71805763], [88.38276672, 21.71812057], [88.38320923, 21.71842957], [88.38379669, 21.71858025], [88.3841629, 21.71860123], [88.38439941, 21.71861076], [88.38694763, 21.71861076], [88.38722229, 21.71888924], [88.38833618, 21.71888924], [88.38861084, 21.71861076], [88.38889313, 21.71861076], [88.38916779, 21.7183342], [88.39083099, 21.7183342], [88.39111328, 21.71805573], [88.39250183, 21.71805954], [88.39305878, 21.71750069], [88.39389038, 21.71750069], [88.39444733, 21.71693993], [88.39444733, 21.71666718], [88.39472198, 21.71666908], [88.39554596, 21.71582985], [88.39583588, 21.71583366], [88.39638519, 21.71555519], [88.39666748, 21.71528053], [88.3972168, 21.71528053], [88.39749908, 21.71500015], [88.3972168, 21.71471977], [88.39722443, 21.71444511], [88.39749908, 21.71417046], [88.39805603, 21.7136097], [88.39805603, 21.71333313], [88.39638519, 21.7116642], [88.39639282, 21.71111107], [88.39499664, 21.70972252], [88.39499664, 21.70944214], [88.39472198, 21.70916748], [88.39472198, 21.70861053], [88.3941803, 21.70806122], [88.39389038, 21.70833206], [88.39360809, 21.70833206], [88.39338684, 21.70811081], [88.39305878, 21.70777702], [88.39305878, 21.70722008], [88.39265442, 21.70684624], [88.39234161, 21.70639038], [88.39202118, 21.70593071], [88.39160919, 21.70555878], [88.39116669, 21.70519829], [88.39074707, 21.70478821], [88.39028168, 21.70445442], [88.38976288, 21.70416641], [88.38926697, 21.70388031], [88.38891602, 21.70358086], [88.38861084, 21.70332909], [88.38861084, 21.70277977], [88.38833618, 21.70249939], [88.38722229, 21.70249939], [88.38694763, 21.70222092], [88.38694763, 21.70194435], [88.38666534, 21.70194435], [88.38527679, 21.70055771], [88.38471985, 21.70055962], [88.38453674, 21.70055962], [88.38388824, 21.70028114], [88.38327026, 21.69996071], [88.38273621, 21.69957161], [88.38219452, 21.69931793], [88.38147736, 21.69934464], [88.38092804, 21.69925117], [88.38046265, 21.69910812], [88.38004303, 21.69888115], [88.37962341, 21.69864082], [88.37917328, 21.6984005], [88.37889099, 21.69833565], [88.3786087, 21.69805336], [88.37832642, 21.69806099], [88.37805176, 21.69778061], [88.3777771, 21.69778061], [88.37750244, 21.69750023], [88.37722015, 21.69750023], [88.37695313, 21.69721985], [88.37666321, 21.69722176], [88.37541199, 21.69624519], [88.37526703, 21.69610977], [88.375, 21.6958313], [88.37472534, 21.6958313], [88.3741684, 21.69527817], [88.37304688, 21.69528008], [88.37258911, 21.69481659], [88.37249756, 21.69472122], [88.37249756, 21.69444466], [88.3722229, 21.69416618], [88.37194824, 21.69417191], [88.37166595, 21.69388962], [88.3713913, 21.69388962], [88.37110901, 21.69361115], [88.37055206, 21.69361115], [88.3702774, 21.69333267], [88.36972046, 21.69333267], [88.3694458, 21.69305611], [88.36915588, 21.69306183], [88.36888885, 21.69277763], [88.36833191, 21.69333267], [88.36776733, 21.69333267], [88.36750031, 21.69361115], [88.36723328, 21.69333267], [88.36694336, 21.69333267], [88.36638641, 21.69277763], [88.36611176, 21.69277763], [88.36611176, 21.69166756], [88.3658371, 21.69138908], [88.36611176, 21.69111061], [88.36611176, 21.68943977], [88.3658371, 21.68916893], [88.3658371, 21.6883297], [88.36555481, 21.68805695], [88.36554718, 21.68721962], [88.36499786, 21.68666458], [88.36473083, 21.68671036], [88.3644104, 21.68672943], [88.36416626, 21.6866703], [88.36416626, 21.68694687], [88.3638916, 21.68722153], [88.36333466, 21.68722153], [88.36277771, 21.68666458], [88.36194611, 21.6866703], [88.36165619, 21.68638992], [88.36138916, 21.68638992], [88.36110687, 21.6866703], [88.36081696, 21.6866703], [88.36055756, 21.68638992], [88.3602829, 21.6866703], [88.36000061, 21.68666458], [88.35896301, 21.68693352], [88.35837555, 21.68691635], [88.35787964, 21.68681908], [88.35749054, 21.68697166], [88.35713959, 21.68721771], [88.35678864, 21.68747139], [88.35636139, 21.68772316], [88.355896, 21.68800163], [88.35542297, 21.68833351], [88.35527802, 21.68861198], [88.35500336, 21.68861008], [88.35444641, 21.68917084], [88.35416412, 21.68916893], [88.35388947, 21.68944359], [88.35333252, 21.68943977], [88.35221863, 21.69055939], [88.35194397, 21.69055557], [88.35028076, 21.69222069], [88.35028076, 21.69249916], [88.34999847, 21.6927681], [88.34983063, 21.69314575], [88.34979248, 21.69334984], [88.34970093, 21.69406128], [88.34958649, 21.69445992], [88.34921265, 21.69504929], [88.34874725, 21.69540977], [88.34848022, 21.69585991], [88.3482666, 21.69630241], [88.34799194, 21.69667053], [88.34770203, 21.6970253], [88.34744263, 21.69742393], [88.34715271, 21.69778061], [88.34685516, 21.69815636], [88.34660339, 21.69854355], [88.34629822, 21.69887161], [88.34594727, 21.69917107], [88.34561157, 21.69948959], [88.3453064, 21.69985199], [88.345047, 21.70026016], [88.34474182, 21.70067024], [88.34443665, 21.70111084], [88.34443665, 21.70139122], [88.34416962, 21.70138931], [88.34333038, 21.70222282], [88.34306335, 21.7028904], [88.34224701, 21.70388985], [88.34194183, 21.70444489], [88.34151459, 21.70472145], [88.34082031, 21.70541954], [88.33999634, 21.70555496], [88.33970642, 21.70583153], [88.33970642, 21.70639038], [88.33945465, 21.70662117], [88.33921051, 21.70682335], [88.33899689, 21.70709991], [88.33874512, 21.70739555], [88.33856201, 21.70779037], [88.33831024, 21.7081852], [88.33818054, 21.70866013], [88.33798218, 21.7090435], [88.33772278, 21.70936394], [88.33756256, 21.70976067], [88.33750916, 21.71024513], [88.33750916, 21.71076965], [88.33759308, 21.71132088], [88.33777618, 21.71186066], [88.33800507, 21.71237564], [88.33815765, 21.71295357], [88.33847046, 21.71344948], [88.33889008, 21.71390915], [88.33930969, 21.71437073], [88.33978271, 21.71469688], [88.34020233, 21.71494865], [88.34049225, 21.71525002], [88.3408432, 21.71533966], [88.34133911, 21.71574974], [88.34187317, 21.71594048], [88.34220886, 21.71623039], [88.34249115, 21.71648026], [88.34295654, 21.71652985], [88.34329987, 21.71664619], [88.34361267, 21.71678162], [88.34392548, 21.71696281], [88.34422302, 21.7172184], [88.34452057, 21.7175808], [88.34475708, 21.71809578], [88.34506226, 21.71858978], [88.3454895, 21.71897125], [88.34588623, 21.71937943], [88.34630585, 21.71973991], [88.34664917, 21.72007751], [88.34676361, 21.72019005], [88.34693909, 21.72036934], [88.34716034, 21.72061348], [88.34729767, 21.72087097], [88.34736633, 21.72118187], [88.34749603, 21.72138977], [88.34750366, 21.72166634], [88.34777832, 21.72194481], [88.34777832, 21.72305489], [88.34750366, 21.72333336], [88.34749603, 21.72360992], [88.34805298, 21.72416687], [88.34805298, 21.72472], [88.34889221, 21.72555351], [88.34889221, 21.72694588], [88.34860992, 21.72722054], [88.34860992, 21.72777939], [88.34754181, 21.73227119], [88.34675598, 21.73448944], [88.34610748, 21.73583031], [88.34555817, 21.73638916], [88.34555817, 21.73694229], [88.34527588, 21.73722076], [88.34527588, 21.73777962], [88.34500122, 21.73806953], [88.3452301, 21.73806763], [88.345047, 21.73859978], [88.34494781, 21.73917007], [88.34477234, 21.73964119], [88.3446579, 21.7401104], [88.34448242, 21.74052048], [88.34436798, 21.74097061], [88.34411621, 21.74135971], [88.34384918, 21.7417202], [88.34365845, 21.74213791], [88.34361267, 21.74263954], [88.34358215, 21.74315262], [88.34346771, 21.74363708], [88.34335327, 21.74415207], [88.34329987, 21.74469948], [88.34313202, 21.74522972], [88.34306335, 21.74581909], [88.34301758, 21.74641037], [88.34281921, 21.74697113], [88.34273529, 21.74757767], [88.34266663, 21.74817276], [88.34265137, 21.74847031], [88.34261322, 21.7490654], [88.34252167, 21.74956322], [88.34265137, 21.75003815], [88.34226227, 21.75065041], [88.34243774, 21.75126076], [88.34252167, 21.75192833], [88.34264374, 21.75256348], [88.34260559, 21.75320244], [88.34255981, 21.75386047], [88.3427887, 21.75439072], [88.34310913, 21.75484085], [88.34340668, 21.75528908], [88.34364319, 21.75576973], [88.34388733, 21.75618935], [88.34413147, 21.75655174], [88.34428406, 21.75691414], [88.34437561, 21.75706863], [88.34445953, 21.7572155], [88.34466553, 21.75746346], [88.34481812, 21.75774956], [88.34501648, 21.7580471], [88.34527588, 21.75835991], [88.34555054, 21.75876999], [88.34584045, 21.75925636], [88.34618378, 21.7597847], [88.34660339, 21.76029015], [88.34705353, 21.76081085], [88.34755707, 21.76128006], [88.34845734, 21.76165962], [88.34895325, 21.76183128], [88.34971619, 21.76218033], [88.35018921, 21.76256561], [88.35095215, 21.76304245], [88.35123444, 21.76334572], [88.35167694, 21.76367188], [88.35206604, 21.76399612], [88.35263062, 21.76402473], [88.35323334, 21.76399422], [88.35388947, 21.7641201], [88.35455322, 21.76416969], [88.35513306, 21.76416969], [88.35565948, 21.76416969], [88.35616302, 21.76416969], [88.35663605, 21.76413918], [88.35710144, 21.76402283], [88.35754395, 21.76398087], [88.35801697, 21.7641201], [88.3585434, 21.76416969], [88.35906982, 21.76416969], [88.35957336, 21.76416969], [88.36003876, 21.76416969], [88.36049652, 21.76416969], [88.36096954, 21.76416969], [88.3614502, 21.76416969], [88.36194611, 21.76416016], [88.36244965, 21.76416779], [88.3629303, 21.76421165], [88.36338806, 21.76439857], [88.3636322, 21.7644062], [88.36386871, 21.76441193], [88.36434937, 21.7642765], [88.36485291, 21.76418114], [88.36511993, 21.76417351], [88.36538696, 21.76416588]]], [[[88.74888611, 21.76501083], [88.74944305, 21.76444054], [88.74944305, 21.76416588], [88.75026703, 21.76333046], [88.7505722, 21.76321411], [88.75099945, 21.76302147], [88.75140381, 21.76277924], [88.75180817, 21.7625618], [88.75226593, 21.76246071], [88.75269318, 21.76226807], [88.75315857, 21.7621727], [88.75358582, 21.76195908], [88.75405884, 21.76177979], [88.75458527, 21.76165962], [88.75512695, 21.76153564], [88.75569916, 21.76143074], [88.75627136, 21.76132965], [88.75679016, 21.76111031], [88.75726318, 21.76085091], [88.75772095, 21.76062012], [88.75819397, 21.76043129], [88.7586441, 21.76018715], [88.75894165, 21.75972939], [88.75926208, 21.75921822], [88.75911713, 21.75859833], [88.7587204, 21.75803947], [88.75834656, 21.75753021], [88.75800323, 21.75712967], [88.75777435, 21.7567749], [88.75758362, 21.75646591], [88.75743103, 21.75617027], [88.75720215, 21.75593948], [88.75694275, 21.75572968], [88.75669098, 21.75550079], [88.75644684, 21.75525856], [88.75624084, 21.75500107], [88.75604248, 21.75475121], [88.75582123, 21.75453949], [88.75559998, 21.75434113], [88.75538635, 21.75412178], [88.75517273, 21.75388145], [88.75492096, 21.75359917], [88.75463867, 21.75324059], [88.75434875, 21.7528038], [88.75416565, 21.75277519], [88.75417328, 21.75250053], [88.75389099, 21.75222206], [88.75389099, 21.75194359], [88.7536087, 21.75166512], [88.7536087, 21.75111008], [88.75333405, 21.75083351], [88.75333405, 21.75055313], [88.7527771, 21.75000954], [88.7527771, 21.74971962], [88.75250244, 21.74944305], [88.75250244, 21.74888992], [88.75222778, 21.74860954], [88.75222015, 21.7452774], [88.75250244, 21.74500084], [88.75222778, 21.74472046], [88.75222015, 21.74277878], [88.75195313, 21.74250031], [88.7519455, 21.74222183], [88.75166321, 21.74194527], [88.75166321, 21.74139023], [88.75138855, 21.74110985], [88.75138855, 21.74055672], [88.75111389, 21.74027824], [88.75110626, 21.73967934], [88.75110626, 21.73917007], [88.751091, 21.73867989], [88.75099182, 21.73823166], [88.75084686, 21.73779106], [88.75083923, 21.73734283], [88.7508316, 21.73722267], [88.7508316, 21.73694229], [88.75111389, 21.73666573], [88.75110626, 21.73555946], [88.75138855, 21.7352829], [88.75138855, 21.73417282], [88.75166321, 21.73389053], [88.75166321, 21.73361015], [88.7519455, 21.73333359], [88.7519455, 21.73305511], [88.75218964, 21.73275948], [88.75244141, 21.73243523], [88.75253296, 21.73200035], [88.75276947, 21.73157883], [88.7530899, 21.73132133], [88.75339508, 21.73100853], [88.75369263, 21.73067093], [88.75418854, 21.73054123], [88.75450134, 21.73023987], [88.75488281, 21.72998047], [88.75523376, 21.72970581], [88.75559235, 21.7294178], [88.75596619, 21.72916985], [88.75636292, 21.72894096], [88.75685883, 21.7288208], [88.7572403, 21.72835159], [88.75762177, 21.72818947], [88.75847626, 21.72779846], [88.7591629, 21.72777939], [88.75975037, 21.72751045], [88.76030731, 21.72732162], [88.76082611, 21.72719955], [88.76126099, 21.72698975], [88.76171112, 21.7269268], [88.76213837, 21.72681808], [88.76257324, 21.72673035], [88.7629776, 21.72668839], [88.76339722, 21.72667122], [88.76383209, 21.72665024], [88.76423645, 21.72653008], [88.76464844, 21.72641945], [88.76508331, 21.72637939], [88.76550293, 21.72630119], [88.76586151, 21.72613907], [88.76626587, 21.72611046], [88.76667786, 21.72611046], [88.76708984, 21.72611046], [88.76751709, 21.72611046], [88.76793671, 21.72611046], [88.76836395, 21.72611046], [88.76879883, 21.72611237], [88.76924896, 21.72611237], [88.76971436, 21.72610664], [88.77015686, 21.72603989], [88.77054596, 21.72585297], [88.77094269, 21.72571373], [88.77133179, 21.72557831], [88.77175903, 21.72556114], [88.77220154, 21.72556114], [88.7726593, 21.72551918], [88.77308655, 21.72532272], [88.77358246, 21.72525978], [88.77404022, 21.72512054], [88.77440643, 21.72492027], [88.77470398, 21.72468758], [88.77471924, 21.72445107], [88.77500153, 21.72445107], [88.77527618, 21.72417068], [88.77555847, 21.72417068], [88.77610779, 21.72360992], [88.77610779, 21.72249985], [88.77639008, 21.72221947], [88.77639008, 21.72138977], [88.7766571, 21.72110939], [88.77666473, 21.72083282], [88.77610779, 21.72027779], [88.77610779, 21.72000122], [88.77583313, 21.71970749], [88.77583313, 21.71944427], [88.77513123, 21.71902275], [88.77500153, 21.71888924], [88.77503204, 21.71879768], [88.77462769, 21.71851349], [88.77420807, 21.71825218], [88.7738266, 21.71800041], [88.7734375, 21.71776962], [88.77305603, 21.71754074], [88.77262115, 21.7173481], [88.77213287, 21.71718216], [88.77165222, 21.71697235], [88.77114105, 21.71681213], [88.77063751, 21.71664429], [88.77015686, 21.71646118], [88.76967621, 21.7163105], [88.76956177, 21.7162571], [88.76926422, 21.71611595], [88.76885986, 21.71594048], [88.76846313, 21.71577072], [88.76808167, 21.71558762], [88.76766968, 21.71545029], [88.76725006, 21.715271], [88.76694489, 21.71500015], [88.76638794, 21.71500015], [88.76611328, 21.71471977], [88.76527405, 21.71472168], [88.76472473, 21.7143383], [88.76378632, 21.71407127], [88.76293945, 21.71372986], [88.76236725, 21.71326256], [88.7611084, 21.71222305], [88.76055908, 21.7116642], [88.76027679, 21.71194649], [88.76000214, 21.7116642], [88.76000214, 21.71138954], [88.75971985, 21.71111107], [88.75860596, 21.71111107], [88.75821686, 21.71136093], [88.75759125, 21.71149063], [88.75691986, 21.71133041], [88.75631714, 21.71106911], [88.75579834, 21.71080589], [88.75533295, 21.71055031], [88.75488281, 21.71026039], [88.75444794, 21.70997047], [88.75402832, 21.70961952], [88.75356293, 21.70930862], [88.75305939, 21.7089901], [88.7525177, 21.70864868], [88.75193787, 21.70832253], [88.75134277, 21.70800018], [88.75081635, 21.70771599], [88.75038147, 21.70746994], [88.74999237, 21.70727921], [88.74957275, 21.7071991], [88.74917603, 21.70717049], [88.7488327, 21.70714951], [88.74854279, 21.70710945], [88.74827576, 21.70709038], [88.74798584, 21.7071209], [88.74767303, 21.7071991], [88.74727631, 21.70727921], [88.74687958, 21.70744705], [88.74640656, 21.70763969], [88.74589539, 21.70789909], [88.7453537, 21.70825386], [88.74484253, 21.70871353], [88.74440002, 21.70921707], [88.74388885, 21.70972061], [88.74388885, 21.71027946], [88.74333191, 21.71084023], [88.74333191, 21.71277618], [88.74360657, 21.71305084], [88.7436142, 21.71416855], [88.74359894, 21.71458817], [88.74353027, 21.71512985], [88.74338531, 21.7156086], [88.74326324, 21.71601105], [88.74308014, 21.71635056], [88.7428894, 21.71669006], [88.74266815, 21.71702576], [88.74238586, 21.71733284], [88.74209595, 21.71764183], [88.74182129, 21.71796036], [88.74156189, 21.71826935], [88.74138641, 21.71832848], [88.7408371, 21.71888924], [88.74028778, 21.71888924], [88.73999786, 21.71916962], [88.73916626, 21.7191658], [88.73916626, 21.71944427], [88.7388916, 21.71944427], [88.73860931, 21.71972275], [88.73805237, 21.71970749], [88.73777771, 21.72000122], [88.73638916, 21.72000122], [88.73610687, 21.71970749], [88.73586273, 21.71929169], [88.73623657, 21.71917534], [88.73668671, 21.71903038], [88.73719788, 21.71892738], [88.7376709, 21.71880913], [88.73806763, 21.71865082], [88.73847198, 21.71848106], [88.7388916, 21.71829224], [88.73932648, 21.71805954], [88.73979187, 21.71779442], [88.74031067, 21.71749496], [88.74085999, 21.71713066], [88.74138641, 21.71665192], [88.74183655, 21.71610641], [88.74211121, 21.7154808], [88.74221039, 21.71482277], [88.74221802, 21.71419144], [88.74215698, 21.71358109], [88.74203491, 21.71302986], [88.74198914, 21.71247292], [88.74196625, 21.71192169], [88.74199677, 21.71134758], [88.74208832, 21.71075439], [88.74230194, 21.71017265], [88.74260712, 21.70961571], [88.74294281, 21.7090683], [88.74332428, 21.70861053], [88.74371338, 21.70817947], [88.74410248, 21.70779991], [88.74446869, 21.70743942], [88.74484253, 21.70710754], [88.74523163, 21.70676994], [88.7457428, 21.70646286], [88.7462616, 21.70619011], [88.74676514, 21.7060051], [88.7472229, 21.70589066], [88.74765015, 21.70583153], [88.74804687, 21.70581055], [88.74845886, 21.70581818], [88.74886322, 21.70589066], [88.7492218, 21.70601082], [88.74958038, 21.70609093], [88.74993896, 21.70618248], [88.75030518, 21.70632553], [88.75074005, 21.70646286], [88.75119019, 21.70667648], [88.75164795, 21.70691681], [88.75215149, 21.70714951], [88.75267029, 21.70741081], [88.7531662, 21.70770836], [88.75366974, 21.70800018], [88.75417328, 21.70830917], [88.75469208, 21.70861626], [88.75521851, 21.70895958], [88.75576782, 21.70934105], [88.75637054, 21.70965958], [88.7569809, 21.7098999], [88.7575531, 21.70997047], [88.75805664, 21.70990944], [88.75821686, 21.70985603], [88.75861359, 21.70972252], [88.75861359, 21.70916748], [88.75888824, 21.70889282], [88.75860596, 21.70861053], [88.75860596, 21.70833015], [88.7583313, 21.7080555], [88.75805664, 21.70806122], [88.75804138, 21.70788956], [88.75784302, 21.70766068], [88.75771332, 21.70738983], [88.75749969, 21.70722008], [88.75749969, 21.70666695], [88.75694275, 21.70611191], [88.75694275, 21.70583344], [88.75666809, 21.70444489], [88.75694275, 21.70416641], [88.75694275, 21.70360756], [88.75666809, 21.7033329], [88.75666809, 21.70194435], [88.75694275, 21.70166779], [88.75694275, 21.70028114], [88.75723267, 21.70000076], [88.75722504, 21.69972229], [88.75747681, 21.69834137], [88.75790405, 21.69750023], [88.75817108, 21.69734764], [88.75860596, 21.69682121], [88.76055908, 21.69528008], [88.76082611, 21.69528008], [88.76139069, 21.69472122], [88.76166534, 21.69472122], [88.76249695, 21.69388962], [88.76249695, 21.69361115], [88.76270294, 21.69314003], [88.76275635, 21.69293022], [88.76277161, 21.69271278], [88.76267242, 21.69235039], [88.76236725, 21.69195175], [88.76216125, 21.6916008], [88.76198578, 21.69123077], [88.76187134, 21.69079971], [88.76171875, 21.69036293], [88.76161194, 21.68991089], [88.76146698, 21.68946075], [88.76140594, 21.68900108], [88.76140594, 21.68849182], [88.76139832, 21.68800926], [88.76139069, 21.68756104], [88.76133728, 21.68716049], [88.76122284, 21.68683624], [88.76111603, 21.68650055], [88.76100922, 21.68615532], [88.76081085, 21.68580246], [88.76055908, 21.68540955], [88.76034546, 21.68512535], [88.76025391, 21.68500137], [88.75987244, 21.68463135], [88.75944519, 21.68434906], [88.75901794, 21.68412018], [88.75861359, 21.68392944], [88.7582016, 21.68380165], [88.75778198, 21.68366432], [88.75728607, 21.68360138], [88.7567215, 21.68354416], [88.75613403, 21.68345261], [88.75553894, 21.68351936], [88.75499725, 21.68362999], [88.7545166, 21.68378067], [88.75402832, 21.68395042], [88.75350189, 21.68418121], [88.7529068, 21.68443108], [88.75224304, 21.68464279], [88.75148773, 21.68470955], [88.75074005, 21.68456268], [88.75013733, 21.68433762], [88.74964142, 21.68412018], [88.7492218, 21.68391991], [88.74880219, 21.68377495], [88.74835205, 21.68362999], [88.74780273, 21.68357468], [88.74720764, 21.68357086], [88.74659729, 21.68357849], [88.74602509, 21.68359947], [88.74550629, 21.68366241], [88.74507904, 21.68385124], [88.74471283, 21.68416023], [88.74437714, 21.68453979], [88.74414825, 21.68502808], [88.74402618, 21.68556976], [88.74411011, 21.68610954], [88.74415588, 21.6866703], [88.74420929, 21.68723106], [88.74430084, 21.68776512], [88.74415588, 21.68830109], [88.74394989, 21.68882751], [88.74369049, 21.68932152], [88.74333191, 21.68975067], [88.74292755, 21.69013786], [88.74241638, 21.69041824], [88.74185181, 21.69062805], [88.74121857, 21.69075966], [88.74054718, 21.69073105], [88.73992157, 21.69053078], [88.73932648, 21.69025993], [88.73882294, 21.68996048], [88.73840332, 21.68965912], [88.73800659, 21.68940926], [88.73763275, 21.68919945], [88.73721313, 21.68906975], [88.73675537, 21.68892479], [88.73622894, 21.68887329], [88.73567963, 21.68888092], [88.7351532, 21.6889267], [88.73468018, 21.68905258], [88.73420715, 21.68919945], [88.73375702, 21.68937111], [88.73323822, 21.6894207], [88.73269653, 21.68938065], [88.73221588, 21.68922043], [88.73175049, 21.68905258], [88.73134613, 21.68884277], [88.73101044, 21.688591], [88.73071289, 21.68832016], [88.73044586, 21.68805885], [88.73021698, 21.68782043], [88.73000336, 21.68761063], [88.72976685, 21.68740273], [88.72953796, 21.68712997], [88.72929382, 21.68675613], [88.7290802, 21.68625069], [88.72895813, 21.68565941], [88.72897339, 21.68507957], [88.72912598, 21.68457985], [88.72927856, 21.68406868], [88.72947693, 21.68359947], [88.7297287, 21.6831913], [88.72999573, 21.682827], [88.73026276, 21.68251991], [88.7305069, 21.68226051], [88.73077393, 21.68203163], [88.73110199, 21.68182564], [88.7314682, 21.68160248], [88.73187256, 21.68138123], [88.73230743, 21.68116951], [88.73279572, 21.68104362], [88.73324585, 21.68083954], [88.73369598, 21.68063545], [88.73416138, 21.68045044], [88.73462677, 21.68025017], [88.73509216, 21.68005943], [88.73558807, 21.67993546], [88.73603821, 21.67972946], [88.73648834, 21.67951393], [88.73696899, 21.67931175], [88.73745728, 21.67909622], [88.73792267, 21.6788311], [88.73831177, 21.67850494], [88.73867035, 21.67817307], [88.73903656, 21.67789078], [88.73937225, 21.67761993], [88.73977661, 21.67741013], [88.74021149, 21.67715263], [88.74067688, 21.67682457], [88.74118805, 21.67645836], [88.74175262, 21.67609978], [88.74230194, 21.67575073], [88.74282074, 21.67538071], [88.74333191, 21.67509079], [88.74384308, 21.67485809], [88.74427795, 21.67463112], [88.74472809, 21.6744194], [88.74512482, 21.67420387], [88.74552917, 21.67401123], [88.74591827, 21.67381096], [88.74630737, 21.67358017], [88.74668121, 21.67333031], [88.74705505, 21.67307854], [88.74742889, 21.67284012], [88.74777985, 21.67250061], [88.7481308, 21.67215538], [88.74852753, 21.67181969], [88.74893188, 21.67146111], [88.7493515, 21.67109108], [88.7497406, 21.67068291], [88.75016785, 21.67029953], [88.75061035, 21.66995049], [88.75105286, 21.66959], [88.75144958, 21.66919136], [88.7518692, 21.66881943], [88.7522583, 21.66842079], [88.75267029, 21.66802025], [88.75305939, 21.66762161], [88.75346375, 21.66722107], [88.7538681, 21.66683006], [88.75424957, 21.66642952], [88.7546463, 21.66605186], [88.75499725, 21.66563988], [88.75527954, 21.66519737], [88.75554657, 21.66473007], [88.75582123, 21.66423035], [88.75604248, 21.66367912], [88.7562561, 21.66315269], [88.75611115, 21.66280174], [88.75576019, 21.66250038], [88.75535583, 21.66214943], [88.75499725, 21.66167068], [88.75480652, 21.66147614], [88.75444794, 21.66111183], [88.75389099, 21.66110992], [88.75375366, 21.66125107], [88.7536087, 21.6613903], [88.75250244, 21.66028023], [88.75222778, 21.66028023], [88.75195313, 21.65999985], [88.75177765, 21.65999985], [88.75166321, 21.65999985], [88.75138855, 21.65971947], [88.75055695, 21.65972137], [88.75027466, 21.65944672], [88.75, 21.65916443], [88.74916077, 21.65917015], [88.74888611, 21.65888977], [88.74861145, 21.65888977], [88.74804687, 21.65833092], [88.74777985, 21.65833092], [88.74700165, 21.65909767], [88.74694061, 21.65915871], [88.74659729, 21.65950966], [88.74617004, 21.65993118], [88.74571228, 21.66029549], [88.74530792, 21.66068649], [88.74500275, 21.66111183], [88.74471283, 21.66152], [88.7443924, 21.66189575], [88.74402618, 21.66221809], [88.7436676, 21.66254997], [88.74334717, 21.66292572], [88.74305725, 21.66332054], [88.74272156, 21.66367912], [88.74241638, 21.66405106], [88.74199677, 21.66430664], [88.7416687, 21.66464806], [88.74137878, 21.66504097], [88.74106598, 21.66543007], [88.74069977, 21.66580009], [88.74025726, 21.6661396], [88.73986053, 21.66653633], [88.73950195, 21.66696167], [88.73918152, 21.66739273], [88.73889923, 21.66781807], [88.7386322, 21.66824913], [88.73834991, 21.66864967], [88.73804474, 21.66904259], [88.73770905, 21.66940308], [88.73734283, 21.6697197], [88.73698425, 21.67002869], [88.73664856, 21.67032242], [88.73631287, 21.67058754], [88.73595428, 21.67082977], [88.73561859, 21.67106247], [88.7353363, 21.67134094], [88.73504639, 21.67165565], [88.73470306, 21.67193985], [88.73431396, 21.67221832], [88.73388672, 21.67249107], [88.73349762, 21.67282295], [88.73317719, 21.67323112], [88.73293304, 21.67371178], [88.73253632, 21.6740284], [88.73213959, 21.67439079], [88.73168945, 21.67471695], [88.73121643, 21.67500305], [88.7307663, 21.67527962], [88.73034668, 21.67555809], [88.7299118, 21.67583084], [88.72946167, 21.67611122], [88.72904205, 21.67641258], [88.72860718, 21.67669106], [88.72817993, 21.67694664], [88.72773743, 21.67719078], [88.72728729, 21.67745018], [88.72688293, 21.67776108], [88.72647095, 21.67808723], [88.72607422, 21.67842484], [88.72563934, 21.67865944], [88.72524261, 21.67893028], [88.72483063, 21.67918015], [88.72444153, 21.6794529], [88.72406006, 21.67971992], [88.72364044, 21.6799736], [88.72322845, 21.68025017], [88.72276306, 21.68051529], [88.72229767, 21.68077278], [88.72186279, 21.68105888], [88.72138214, 21.6812706], [88.72088623, 21.6814518], [88.72046661, 21.68167686], [88.72006226, 21.68194008], [88.71964264, 21.68222046], [88.71917725, 21.6824894], [88.71868896, 21.68278122], [88.71819305, 21.6830883], [88.71774292, 21.68345261], [88.71723175, 21.68377113], [88.71674347, 21.68409729], [88.71627045, 21.68443108], [88.71581268, 21.68474007], [88.71538544, 21.68503189], [88.7150116, 21.68538284], [88.71465302, 21.68577003], [88.71425629, 21.6861496], [88.71386719, 21.68656158], [88.71343994, 21.68695831], [88.71305084, 21.68740273], [88.71269226, 21.68779945], [88.71245575, 21.68823242], [88.71222687, 21.68857956], [88.7120285, 21.68888092], [88.71185303, 21.68914795], [88.71166992, 21.68939018], [88.71148682, 21.68963242], [88.71133423, 21.6899128], [88.71111298, 21.69017982], [88.71111298, 21.69055557], [88.71083069, 21.69082832], [88.71083069, 21.69138908], [88.71055603, 21.69166946], [88.71055603, 21.69305611], [88.71028137, 21.69333267], [88.71028137, 21.69361115], [88.70999146, 21.69388962], [88.70999146, 21.69499969], [88.7097168, 21.69528008], [88.7097168, 21.69639015], [88.70944214, 21.69666672], [88.70944214, 21.69721985], [88.70916748, 21.69750023], [88.70916748, 21.69805336], [88.70888519, 21.69833565], [88.70888519, 21.69944572], [88.70861053, 21.69972229], [88.70861053, 21.70083046], [88.70848846, 21.70139122], [88.70835876, 21.70191956], [88.70829773, 21.70249557], [88.70809937, 21.70302963], [88.7080307, 21.70362091], [88.707901, 21.70418167], [88.70779419, 21.70471764], [88.70780945, 21.70524216], [88.70794678, 21.70573235], [88.70804596, 21.70583153], [88.70804596, 21.70639038], [88.70777893, 21.70666695], [88.70777893, 21.70722008], [88.70749664, 21.70750046], [88.70749664, 21.70806122], [88.70667267, 21.70889282], [88.70666504, 21.70916748], [88.70694733, 21.70944214], [88.70694733, 21.70972061], [88.70722198, 21.71000099], [88.70722198, 21.71027946], [88.70666504, 21.7108326], [88.70667267, 21.71249962], [88.70642853, 21.71306992], [88.70638275, 21.71357155], [88.70633698, 21.71403122], [88.70616913, 21.7144165], [88.70598602, 21.71479034], [88.70587921, 21.71519661], [88.7057724, 21.71558952], [88.70558167, 21.71595955], [88.70542908, 21.71634293], [88.70526123, 21.71679115], [88.70503998, 21.71723175], [88.70498657, 21.71776962], [88.70487213, 21.71832085], [88.7046814, 21.71887016], [88.70443726, 21.71939278], [88.704216, 21.71985054], [88.70411682, 21.72028923], [88.70392609, 21.72058105], [88.70384979, 21.72092056], [88.7036972, 21.72118187], [88.70362091, 21.72145271], [88.70355988, 21.72174072], [88.70333862, 21.72197723], [88.70318604, 21.72232819], [88.70298767, 21.722826], [88.7027359, 21.72335052], [88.70248413, 21.72387886], [88.70223999, 21.72430038], [88.70205688, 21.72464943], [88.70173645, 21.72505951], [88.70149994, 21.72546387], [88.70137787, 21.72587013], [88.70124817, 21.72624969], [88.7011261, 21.72660065], [88.70111084, 21.72696114], [88.70111084, 21.72730827], [88.70111084, 21.72765732], [88.70111084, 21.7279911], [88.70110321, 21.72831345], [88.70105743, 21.72861099], [88.70087433, 21.72890091], [88.70083618, 21.72925186], [88.70078278, 21.7296505], [88.70057678, 21.73006821], [88.70037842, 21.73056793], [88.7000885, 21.73112106], [88.70001984, 21.7318306], [88.69976044, 21.73225975], [88.69949341, 21.7326107], [88.6992569, 21.73295021], [88.69889069, 21.73305511], [88.6986084, 21.73333359], [88.6986084, 21.73361015], [88.69777679, 21.73444366], [88.69777679, 21.73472023], [88.69833374, 21.73527718], [88.69832611, 21.73583031], [88.69805145, 21.73611069], [88.69805908, 21.73638916], [88.69750214, 21.73694229], [88.69750214, 21.73722076], [88.69721985, 21.73750114], [88.69706726, 21.73779869], [88.69706726, 21.7382412], [88.69695282, 21.73875999], [88.69700623, 21.73926926], [88.69695282, 21.7396698], [88.69700623, 21.74002838], [88.69722748, 21.74032021], [88.69750977, 21.74058151], [88.69777679, 21.74084091], [88.69792175, 21.74110985], [88.69775391, 21.74141884], [88.69740295, 21.74180984], [88.69687653, 21.74221992], [88.69635773, 21.74263954], [88.69589233, 21.74301147], [88.69552612, 21.74336052], [88.69527435, 21.74361038], [88.69499969, 21.74389076], [88.69500732, 21.74472046], [88.69526672, 21.74500084], [88.69527435, 21.74555588], [88.69499969, 21.74583244], [88.69500732, 21.74638939], [88.69526672, 21.74666977], [88.69527435, 21.74805641], [88.69555664, 21.74833107], [88.69555664, 21.75000954], [88.6958313, 21.75027847], [88.6958313, 21.75111008], [88.69611359, 21.75138855], [88.69611359, 21.75194359], [88.69638824, 21.75222015], [88.69638824, 21.75250053], [88.6966629, 21.75278091], [88.6966629, 21.75305748], [88.69694519, 21.75333595], [88.69695282, 21.75361061], [88.69721985, 21.75389099], [88.69721985, 21.75416756], [88.69777679, 21.75472069], [88.69777679, 21.75500107], [88.69805145, 21.75527954], [88.69805908, 21.75555611], [88.69832611, 21.75582123], [88.69832611, 21.75638962], [88.6986084, 21.75666618], [88.6986084, 21.75694466], [88.69889069, 21.75722313], [88.69889069, 21.75753975], [88.69889069, 21.75805473], [88.69916534, 21.75833321], [88.69917297, 21.75861168], [88.69944763, 21.75889015], [88.69944763, 21.75916672], [88.70101929, 21.76080322], [88.70111084, 21.7609005], [88.70111084, 21.7610302], [88.7013092, 21.76142693], [88.70143127, 21.76197052], [88.70156097, 21.76274109], [88.70183563, 21.76335716], [88.70211029, 21.76390266], [88.70225525, 21.76441765], [88.70243835, 21.76493073], [88.70249176, 21.76551056], [88.70249939, 21.76611519], [88.7025528, 21.76670265], [88.70274353, 21.76721954], [88.70297241, 21.7677002], [88.70318604, 21.76817513], [88.70340729, 21.76861191], [88.70362091, 21.76902962], [88.70385742, 21.7694397], [88.70404053, 21.76986122], [88.70423889, 21.77025032], [88.70443726, 21.77058983], [88.70462799, 21.77095795], [88.70475006, 21.77140045], [88.70491028, 21.7718792], [88.7050705, 21.77240944], [88.70529175, 21.7729435], [88.70555878, 21.77347946], [88.70582581, 21.7740097], [88.70610809, 21.77450943], [88.70636749, 21.77497101], [88.70665741, 21.77540016], [88.70694733, 21.77584076], [88.70720673, 21.7763195], [88.70748138, 21.77681732], [88.70774841, 21.77734375], [88.70802307, 21.77788925], [88.70826721, 21.77843857], [88.70846558, 21.77897453], [88.70852661, 21.77948952], [88.70845032, 21.77997017], [88.70855713, 21.78038025], [88.70944214, 21.77999115], [88.70944214, 21.78166962], [88.70999908, 21.78166771], [88.71018982, 21.78185463], [88.71055603, 21.78222275], [88.71055603, 21.78333282], [88.71083069, 21.7836113], [88.71083069, 21.78475952], [88.71083069, 21.78499985], [88.71111298, 21.78527832], [88.71111298, 21.78583145], [88.71138763, 21.78611946], [88.71138763, 21.78695107], [88.71193695, 21.78750038], [88.71194458, 21.78805542], [88.71166992, 21.78833008], [88.71166992, 21.78861046], [88.71194458, 21.78888893], [88.71194458, 21.78944206], [88.71166992, 21.78972054], [88.71166992, 21.79000092], [88.71193695, 21.79027939], [88.71194458, 21.79111099], [88.7115097, 21.79154778], [88.71111298, 21.79194641], [88.71150208, 21.7923317], [88.71166992, 21.79249954], [88.71166992, 21.79277992], [88.71193695, 21.7930603], [88.71193695, 21.79389], [88.71166992, 21.79416847], [88.71166992, 21.7947216], [88.71193695, 21.79499054], [88.71194458, 21.79555511], [88.71221924, 21.79582977], [88.71221924, 21.79805565], [88.71193695, 21.7983284], [88.71194458, 21.79916573], [88.71221924, 21.79943848], [88.71221924, 21.80000114], [88.71193695, 21.80027962], [88.71194458, 21.80055618], [88.71166992, 21.80083275], [88.71166992, 21.80138969], [88.71138763, 21.80166626], [88.71138763, 21.80221939], [88.71111298, 21.80249977], [88.71111298, 21.80305481], [88.71083069, 21.80333328], [88.71083069, 21.80360985], [88.71111298, 21.80389023], [88.71111298, 21.80500031], [88.71083069, 21.80528069], [88.71105194, 21.80602074], [88.71162415, 21.80635643], [88.71219635, 21.80722046], [88.71321106, 21.80730057], [88.71362305, 21.80727577], [88.71401978, 21.80724716], [88.7144165, 21.80722046], [88.71505737, 21.80730057], [88.71560669, 21.80729103], [88.71620178, 21.80738068], [88.71656799, 21.80706024], [88.71695709, 21.80672073], [88.71736145, 21.80638123], [88.71774292, 21.80599976], [88.71806335, 21.80556107], [88.71839905, 21.80513], [88.71871948, 21.80468941], [88.71896362, 21.80422974], [88.71922302, 21.80381966], [88.71946716, 21.80340958], [88.71968842, 21.80302048], [88.71980286, 21.80257988], [88.71994019, 21.80216408], [88.72006226, 21.80173111], [88.72020721, 21.80129814], [88.72029114, 21.80079079], [88.72041321, 21.80024529], [88.7205658, 21.79965019], [88.72077942, 21.79905128], [88.72097015, 21.7984581], [88.72107697, 21.79783058], [88.72110748, 21.79726028], [88.72110748, 21.79679108], [88.72111511, 21.79641533], [88.72116852, 21.79610062], [88.72135162, 21.79585075], [88.72148132, 21.79556847], [88.72161865, 21.79529953], [88.72177124, 21.79504013], [88.72193909, 21.7947998], [88.72212982, 21.79454041], [88.72238159, 21.7942791], [88.72270966, 21.7939682], [88.72315216, 21.79371452], [88.72373199, 21.79351425], [88.72440338, 21.79335213], [88.72509003, 21.79322624], [88.7257309, 21.79304123], [88.72624969, 21.79277992], [88.7266922, 21.79248047], [88.72701263, 21.79214478], [88.72720337, 21.79178619], [88.72725677, 21.79140091], [88.72723389, 21.79100609], [88.72715759, 21.79058838], [88.727211, 21.79014969], [88.72720337, 21.78970146], [88.72710419, 21.78924179], [88.72709656, 21.78874969], [88.72720337, 21.78833961], [88.72727203, 21.78795052], [88.72738647, 21.78759003], [88.7274704, 21.78721809], [88.72751617, 21.78681183], [88.72753143, 21.78637123], [88.72750854, 21.78589058], [88.72741699, 21.78539467], [88.72721863, 21.78490448], [88.72698975, 21.78441048], [88.72680664, 21.78388977], [88.72677612, 21.78334045], [88.72687531, 21.78290558], [88.72692871, 21.78252029], [88.72694397, 21.78215218], [88.7269516, 21.78177071], [88.7269516, 21.78137016], [88.72696686, 21.78098106], [88.72705078, 21.78061104], [88.72715759, 21.7802906], [88.727211, 21.77997017], [88.72725677, 21.77964973], [88.72735596, 21.77935028], [88.72749329, 21.77907944], [88.72761536, 21.77880478], [88.7277832, 21.7785511], [88.72793579, 21.77828979], [88.72801971, 21.7779808], [88.72805786, 21.77777863], [88.72888947, 21.77778053], [88.72915649, 21.77750015], [88.72946167, 21.77775192], [88.72976685, 21.77807045], [88.73014069, 21.77833748], [88.73053741, 21.77858353], [88.73098755, 21.77877235], [88.73152161, 21.77886009], [88.7321167, 21.77888107], [88.73271942, 21.77883911], [88.73326874, 21.77869987], [88.73362732, 21.77832985], [88.73390961, 21.77789879], [88.73413849, 21.77745056], [88.73432159, 21.77696991], [88.73449707, 21.77646255], [88.73472595, 21.77593613], [88.73499298, 21.77539063], [88.73531342, 21.77495956], [88.73567963, 21.77462006], [88.73609161, 21.77433014], [88.73661804, 21.7741394], [88.73713684, 21.77396011], [88.73765564, 21.77382469], [88.7381134, 21.7736454], [88.73855591, 21.77349091], [88.73906708, 21.7734127], [88.73959351, 21.77338219], [88.74011993, 21.77336311], [88.74066162, 21.77333832], [88.74138641, 21.77306175], [88.74223328, 21.77306175], [88.74250031, 21.77277946], [88.74333191, 21.77277946], [88.74360657, 21.77249908], [88.74388885, 21.77249908], [88.74415588, 21.77222061], [88.74472046, 21.77222252], [88.7452774, 21.77166748], [88.74542236, 21.77166748], [88.74582672, 21.77166939], [88.74582672, 21.77139091], [88.74610138, 21.77111053], [88.74610138, 21.77055931], [88.7463913, 21.77028084], [88.7463913, 21.77000046], [88.74637604, 21.76971817], [88.74651337, 21.76930046], [88.74651337, 21.76888084], [88.7466507, 21.76819038], [88.74707031, 21.76764107], [88.74721527, 21.76723099], [88.74734497, 21.76695251], [88.74748993, 21.76666451], [88.74762726, 21.76625061], [88.74790955, 21.76597786], [88.74845886, 21.76527977], [88.74888611, 21.76501083]]], [[[88.11555481, 21.62583351], [88.1138916, 21.62583351], [88.11360931, 21.62611008], [88.11305237, 21.62611008], [88.11277771, 21.62639046], [88.11138916, 21.62639046], [88.11112213, 21.62611008], [88.11055756, 21.62611008], [88.11027527, 21.62583351], [88.10916901, 21.62583351], [88.10888672, 21.62611008], [88.10749817, 21.62611008], [88.10694122, 21.62666702], [88.10694122, 21.62694359], [88.10500336, 21.62694359], [88.10472107, 21.62722015], [88.10415649, 21.62722015], [88.10388947, 21.62750053], [88.10333252, 21.62750053], [88.10305786, 21.62722015], [88.1027832, 21.62722015], [88.10250092, 21.62750053], [88.10192871, 21.62750053], [88.10166931, 21.62778282], [88.10083008, 21.62778282], [88.10056305, 21.62805939], [88.09833527, 21.62805557], [88.09805298, 21.62833214], [88.09694672, 21.62833023], [88.09666443, 21.62861061], [88.09612274, 21.62861061], [88.09583282, 21.6288929], [88.09555817, 21.6288929], [88.09527588, 21.62916946], [88.09361267, 21.62916946], [88.09333038, 21.6288929], [88.09278107, 21.6288929], [88.09249878, 21.62916946], [88.09111023, 21.62916756], [88.09083557, 21.62944221], [88.09055328, 21.62944221], [88.09027863, 21.62916756], [88.08999634, 21.62916756], [88.08972168, 21.62943268], [88.08972168, 21.63000107], [88.08999634, 21.63027763], [88.08944702, 21.63083267], [88.08833313, 21.63083076], [88.08638763, 21.63278008], [88.08611298, 21.63249016], [88.08583069, 21.63249969], [88.08528137, 21.63194656], [88.08499908, 21.63194656], [88.08472443, 21.63166428], [88.08444214, 21.63166428], [88.08389282, 21.63222122], [88.08388519, 21.63277817], [88.08361053, 21.63305664], [88.08361053, 21.63333321], [88.08333588, 21.63360977], [88.08333588, 21.63417053], [88.08249664, 21.63500023], [88.08194733, 21.63500023], [88.08139038, 21.63445091], [88.08139801, 21.63430977], [88.08082581, 21.63417053], [88.08055878, 21.63417053], [88.08027649, 21.63389015], [88.08000183, 21.63417053], [88.07861328, 21.63417053], [88.07833099, 21.63389015], [88.07805634, 21.63388634], [88.07722473, 21.63472176], [88.07611084, 21.63472176], [88.07583618, 21.63444519], [88.07527924, 21.63444519], [88.07388306, 21.63488388], [88.07333374, 21.63488388], [88.07250214, 21.63472176], [88.07221985, 21.63472176], [88.07180786, 21.63430786], [88.07138824, 21.63388634], [88.07055664, 21.63389015], [88.06999969, 21.63445091], [88.06999969, 21.63500023], [88.06944275, 21.63555908], [88.06916809, 21.63555527], [88.0688858, 21.63583374], [88.06833649, 21.63582993], [88.06804657, 21.63611031], [88.06749725, 21.63611031], [88.0672226, 21.63639069], [88.06667328, 21.63639069], [88.06500244, 21.63806152], [88.06361389, 21.6380558], [88.06305695, 21.63807106], [88.06285095, 21.63806725], [88.0625, 21.6380558], [88.06223297, 21.63806152], [88.0595932, 21.64003944], [88.05860901, 21.64056015], [88.0580368, 21.64053917], [88.05747986, 21.64011955], [88.05693817, 21.64056015], [88.05665588, 21.64056015], [88.05583191, 21.64138985], [88.05555725, 21.64138985], [88.0541687, 21.6427803], [88.05388641, 21.6427784], [88.0533371, 21.64333344], [88.05278015, 21.64332962], [88.05222321, 21.64389038], [88.05194092, 21.64389038], [88.05166626, 21.64417076], [88.0513916, 21.64416695], [88.05083466, 21.64472198], [88.05055237, 21.64472008], [88.05027771, 21.64500046], [88.05000305, 21.64500046], [88.04860687, 21.64639091], [88.04833221, 21.64638901], [88.04750061, 21.64722252], [88.04722595, 21.64722061], [88.04693604, 21.64750099], [88.04666901, 21.64750099], [88.04638672, 21.64777946], [88.04611206, 21.64777946], [88.04582977, 21.64805984], [88.04555511, 21.64805794], [88.04528046, 21.6483326], [88.04499817, 21.64833069], [88.04416656, 21.64916992], [88.04354095, 21.64973068], [88.04302216, 21.64970016], [88.04166412, 21.64916611], [88.04138947, 21.64944458], [88.04138947, 21.64972115], [88.04145813, 21.64990044], [88.04141235, 21.65035057], [88.04139709, 21.65077972], [88.04138947, 21.65117836], [88.04137421, 21.65159035], [88.04132843, 21.65202332], [88.0411911, 21.65241814], [88.04104614, 21.65282059], [88.04086304, 21.65320969], [88.04083252, 21.65361977], [88.04083252, 21.65389061], [88.04055786, 21.6541729], [88.04055786, 21.65555573], [88.0402832, 21.65583038], [88.04027557, 21.65638924], [88.04055786, 21.6566658], [88.04037476, 21.65728378], [88.04020691, 21.65740013], [88.04003906, 21.65752029], [88.0399704, 21.65779686], [88.04006195, 21.65839005], [88.03988647, 21.65892601], [88.03962708, 21.65928268], [88.03942871, 21.65964127], [88.03925323, 21.65999985], [88.03916931, 21.66027832], [88.03971863, 21.66082954], [88.03971863, 21.6613903], [88.03944397, 21.66166878], [88.03943634, 21.66221809], [88.03887939, 21.66278839], [88.03887939, 21.66305923], [88.03833008, 21.66361046], [88.03833008, 21.66527939], [88.03805542, 21.66555595], [88.03806305, 21.66638947], [88.03778076, 21.66667175], [88.03778076, 21.66777802], [88.03722382, 21.66833115], [88.03722382, 21.67083549], [88.03694153, 21.67111206], [88.03694153, 21.67166519], [88.03722382, 21.67194366], [88.03721619, 21.67222023], [88.03778076, 21.67278099], [88.03778076, 21.67305946], [88.03694153, 21.67389107], [88.03694153, 21.67416763], [88.03666687, 21.67444038], [88.03666687, 21.67500114], [88.03721619, 21.67555809], [88.03722382, 21.67612076], [88.0372467, 21.67645264], [88.03726959, 21.67719078], [88.03765106, 21.67807961], [88.03749084, 21.67856979], [88.03753662, 21.67897987], [88.03775024, 21.6793499], [88.03794861, 21.67968941], [88.03809357, 21.68009758], [88.03829956, 21.68047905], [88.03852081, 21.68084717], [88.03869629, 21.68126106], [88.03874207, 21.68181801], [88.03868103, 21.68242455], [88.03844452, 21.68289375], [88.03818512, 21.6832695], [88.03808594, 21.68362045], [88.03807831, 21.68394279], [88.0381012, 21.68421936], [88.03816223, 21.68447304], [88.03829193, 21.6847496], [88.03835297, 21.68515015], [88.03836823, 21.68569946], [88.038414, 21.68633842], [88.03857422, 21.68696404], [88.03868103, 21.68760109], [88.03887939, 21.68819809], [88.03907776, 21.68881989], [88.03922272, 21.68945122], [88.03936768, 21.69001961], [88.03933716, 21.69061661], [88.03935242, 21.69117355], [88.03948975, 21.69166183], [88.03967285, 21.6920929], [88.03974915, 21.69252968], [88.03983307, 21.69296074], [88.04000854, 21.6933651], [88.04005432, 21.69380379], [88.04006195, 21.69425011], [88.04006958, 21.69473076], [88.04017639, 21.69518852], [88.04030609, 21.69564056], [88.04046631, 21.69605255], [88.04057312, 21.69645119], [88.04064941, 21.69682121], [88.04078674, 21.69712067], [88.04084015, 21.69745827], [88.04090881, 21.69779968], [88.04108429, 21.69808769], [88.04120636, 21.69842911], [88.04138184, 21.69883728], [88.04153442, 21.69932365], [88.04169464, 21.6998558], [88.04188538, 21.7003746], [88.04199219, 21.70088577], [88.04210663, 21.70129013], [88.04219818, 21.70165062], [88.04222107, 21.70197678], [88.04224396, 21.70227432], [88.04231262, 21.70256805], [88.04240417, 21.7029171], [88.0423584, 21.70337486], [88.04251099, 21.70391273], [88.04268646, 21.7045002], [88.04277039, 21.70512581], [88.04283142, 21.70577049], [88.04290009, 21.70643044], [88.0431366, 21.70703125], [88.04338837, 21.70758057], [88.04332733, 21.70821953], [88.04354858, 21.70874786], [88.04400635, 21.7091713], [88.04421234, 21.70968246], [88.04403687, 21.71035004], [88.04394531, 21.7111187], [88.04373932, 21.7116394], [88.0437088, 21.71215057], [88.04389191, 21.71261978], [88.04414368, 21.71305656], [88.04437256, 21.71352005], [88.04453278, 21.71408081], [88.04445648, 21.71470833], [88.04440308, 21.71524048], [88.04429626, 21.71562958], [88.04415894, 21.71594048], [88.04408264, 21.71635628], [88.0440979, 21.71705246], [88.0442276, 21.71769333], [88.04450989, 21.71813011], [88.04486847, 21.71845818], [88.04524231, 21.71871948], [88.04560089, 21.71898079], [88.04599762, 21.7191906], [88.04638672, 21.71947098], [88.04676056, 21.71988106], [88.04696655, 21.72044945], [88.04718781, 21.72097015], [88.04737854, 21.72145462], [88.04753876, 21.72191048], [88.04779053, 21.72229958], [88.04823303, 21.72249031], [88.04859161, 21.72274971], [88.04889679, 21.72304535], [88.04918671, 21.72330856], [88.04950714, 21.72354126], [88.04982758, 21.72373962], [88.05008698, 21.72397995], [88.05034637, 21.72425079], [88.05058289, 21.72459984], [88.05078888, 21.72499847], [88.0509491, 21.72542953], [88.05116272, 21.72581291], [88.05142212, 21.72613907], [88.05173492, 21.72650528], [88.05208588, 21.72694969], [88.05252838, 21.7274704], [88.05294037, 21.72794151], [88.0532608, 21.7282505], [88.0535202, 21.72849083], [88.05375671, 21.72865105], [88.05394745, 21.72890091], [88.05414581, 21.72915077], [88.05436707, 21.72944069], [88.05478668, 21.7296505], [88.05536652, 21.72987175], [88.05597687, 21.73009109], [88.056427, 21.73028946], [88.05674744, 21.73058128], [88.05700684, 21.73108101], [88.05716705, 21.73162079], [88.05735779, 21.73212051], [88.05773926, 21.73257256], [88.05822754, 21.73285294], [88.0588913, 21.73305511], [88.05944824, 21.73361015], [88.0597229, 21.73333359], [88.06027985, 21.73333359], [88.06138611, 21.73444176], [88.06138611, 21.73555565], [88.0616684, 21.73583031], [88.06138611, 21.73611069], [88.06138611, 21.73638916], [88.06194305, 21.73694229], [88.06194305, 21.73722076], [88.06223297, 21.73750114], [88.06222534, 21.73777771], [88.0627594, 21.73833084], [88.0627594, 21.73888969], [88.06388855, 21.73999977], [88.06388855, 21.74027824], [88.06416321, 21.74055099], [88.06416321, 21.74139023], [88.0644455, 21.7416687], [88.06445312, 21.74250031], [88.06472015, 21.74277878], [88.06472015, 21.74388123], [88.06500244, 21.74416733], [88.06500244, 21.74444389], [88.0652771, 21.74472046], [88.0652771, 21.7452774], [88.06581879, 21.74582863], [88.06583405, 21.74666595], [88.06555176, 21.74694443], [88.06555176, 21.74833107], [88.06581879, 21.74860954], [88.06583405, 21.74944305], [88.0661087, 21.74972153], [88.0661087, 21.75083351], [88.06639099, 21.75111008], [88.06639099, 21.75166512], [88.06581879, 21.75222015], [88.06581879, 21.75250053], [88.06555176, 21.75278091], [88.06555176, 21.75305748], [88.06581879, 21.75333023], [88.06581879, 21.75389099], [88.0661087, 21.75416756], [88.0661087, 21.75444412], [88.06639099, 21.75472069], [88.06639099, 21.75527954], [88.06666565, 21.75555611], [88.06667328, 21.75582123], [88.06694794, 21.75611115], [88.06694794, 21.75666618], [88.0672226, 21.75694466], [88.0672226, 21.75722122], [88.06749725, 21.75749969], [88.06749725, 21.75777817], [88.06777954, 21.75805092], [88.06777954, 21.75917244], [88.06804657, 21.75945282], [88.0680542, 21.76055527], [88.06833649, 21.76083183], [88.068367, 21.76102066], [88.06861115, 21.76158905], [88.06886292, 21.76213455], [88.06900787, 21.76265144], [88.06903839, 21.76313972], [88.06897736, 21.76363945], [88.06907654, 21.76405716], [88.06925201, 21.76447105], [88.06945801, 21.76493454], [88.06967926, 21.76543045], [88.06987762, 21.76599884], [88.07015991, 21.76651001], [88.07036591, 21.7670517], [88.07036591, 21.7676506], [88.07045746, 21.76820183], [88.07052612, 21.76873016], [88.07060242, 21.76920128], [88.07076263, 21.76958084], [88.07087708, 21.7699585], [88.07104492, 21.77032661], [88.07110596, 21.77081108], [88.07115173, 21.77135086], [88.07128143, 21.77185631], [88.07136536, 21.77235222], [88.07139587, 21.7728405], [88.07144165, 21.77334023], [88.07157135, 21.77383041], [88.07154083, 21.77436066], [88.07163239, 21.7748909], [88.07170868, 21.77543831], [88.0718689, 21.77598572], [88.07199097, 21.77656364], [88.07217407, 21.77709579], [88.07221985, 21.77757072], [88.07222748, 21.77797318], [88.07226563, 21.77831268], [88.07242584, 21.77858162], [88.07248688, 21.7789402], [88.07254028, 21.779356], [88.0727005, 21.77976418], [88.07285309, 21.78018188], [88.07306671, 21.78052521], [88.07329559, 21.78083038], [88.07344818, 21.78122139], [88.07364655, 21.78165054], [88.07401276, 21.78206825], [88.07440948, 21.78252029], [88.07480621, 21.7829895], [88.0752182, 21.7834301], [88.07556915, 21.78389931], [88.07592773, 21.78436089], [88.07631683, 21.78481293], [88.07666016, 21.78526115], [88.0769577, 21.78570747], [88.07730103, 21.7859726], [88.07766724, 21.78609085], [88.07795715, 21.78623962], [88.07804108, 21.78651047], [88.07807159, 21.78700638], [88.07826996, 21.78763962], [88.07855225, 21.78821945], [88.0789032, 21.78864098], [88.07917786, 21.78902054], [88.07940674, 21.78948975], [88.07957458, 21.79009056], [88.07984924, 21.79063988], [88.08023071, 21.79109573], [88.08055878, 21.79158211], [88.08085632, 21.79204941], [88.08117676, 21.79244041], [88.08145142, 21.79276085], [88.08167267, 21.7930603], [88.08185577, 21.79336166], [88.08197784, 21.79368019], [88.08216095, 21.79396057], [88.08229065, 21.79429054], [88.08244324, 21.79459763], [88.08255005, 21.79496956], [88.08274841, 21.79529572], [88.08290863, 21.79567146], [88.08309937, 21.79603004], [88.08332062, 21.79640961], [88.08351898, 21.79687119], [88.0836792, 21.79741096], [88.08390045, 21.79795074], [88.08416748, 21.79844666], [88.08444977, 21.79892921], [88.08473206, 21.79940987], [88.08503723, 21.79989052], [88.08535767, 21.80037117], [88.08564758, 21.80089951], [88.08587646, 21.80150604], [88.08613586, 21.80211258], [88.08644104, 21.80266953], [88.08679199, 21.80315781], [88.0871582, 21.80355263], [88.08750916, 21.80389977], [88.08782196, 21.80424118], [88.0880661, 21.80461121], [88.08825684, 21.80500984], [88.08833313, 21.80553055], [88.08840179, 21.80606079], [88.08862305, 21.80651093], [88.08886719, 21.80690956], [88.08912659, 21.80729103], [88.08937073, 21.80767632], [88.08972931, 21.80806351], [88.09014893, 21.80848312], [88.09055328, 21.80895805], [88.09076691, 21.80953026], [88.09088898, 21.81010628], [88.09107208, 21.81059647], [88.09121704, 21.81106377], [88.09139252, 21.81147957], [88.09160614, 21.81186104], [88.09185791, 21.81217194], [88.09205627, 21.81250954], [88.09224701, 21.81285667], [88.09246063, 21.81321335], [88.09263611, 21.81361961], [88.09281158, 21.81406021], [88.09301758, 21.81449127], [88.0931778, 21.81496048], [88.09337616, 21.81541061], [88.09362793, 21.81580925], [88.09394073, 21.81616402], [88.09427643, 21.81649017], [88.09445953, 21.81694031], [88.09461212, 21.81736946], [88.09481049, 21.81775093], [88.09506226, 21.81809807], [88.09536743, 21.81842232], [88.09568787, 21.81872177], [88.09601593, 21.81899643], [88.09627533, 21.81924248], [88.09646606, 21.8194828], [88.09658051, 21.81976509], [88.09655762, 21.82016945], [88.09645081, 21.82069969], [88.09660339, 21.82105446], [88.0969162, 21.82133484], [88.09720612, 21.82163048], [88.09749603, 21.82192421], [88.09765625, 21.82210922], [88.09773254, 21.82219887], [88.09788513, 21.82247162], [88.09806061, 21.82272148], [88.09825134, 21.82299042], [88.09844971, 21.82332039], [88.09867859, 21.82370186], [88.09889221, 21.82414055], [88.09900665, 21.82468414], [88.09903717, 21.82533836], [88.09926605, 21.82592773], [88.09951782, 21.82647133], [88.09971619, 21.82691956], [88.0998764, 21.82725716], [88.09996796, 21.82753181], [88.09999847, 21.82780266], [88.10002899, 21.82808113], [88.1001358, 21.8283329], [88.10031128, 21.82855797], [88.10051727, 21.82877922], [88.10069275, 21.8290596], [88.10080719, 21.82949066], [88.10089111, 21.82999039], [88.10111237, 21.8304615], [88.10134125, 21.83093071], [88.10147095, 21.83144951], [88.10166168, 21.83193016], [88.10187531, 21.83240509], [88.10217285, 21.83283997], [88.10247803, 21.83328629], [88.10282135, 21.83369827], [88.10307312, 21.83418846], [88.10333252, 21.83465958], [88.10359192, 21.83514214], [88.10388947, 21.83583069], [88.10415649, 21.83611107], [88.10415649, 21.83638954], [88.10444641, 21.83666611], [88.10444641, 21.83694077], [88.10527802, 21.83777809], [88.10527802, 21.83805084], [88.10610962, 21.83889008], [88.10610962, 21.83917046], [88.10694122, 21.84000015], [88.10694122, 21.84026909], [88.10722351, 21.84055519], [88.10721588, 21.84083176], [88.10805511, 21.84166718], [88.10806274, 21.84194183], [88.10861206, 21.84250069], [88.10861206, 21.84277725], [88.10884857, 21.84301186], [88.10916901, 21.84333038], [88.10916901, 21.84361076], [88.11055756, 21.84500122], [88.11055756, 21.84527969], [88.11083221, 21.84555435], [88.11083221, 21.84583282], [88.11194611, 21.84694099], [88.11194611, 21.84749985], [88.11277771, 21.84833336], [88.11277771, 21.84860992], [88.11333466, 21.84916878], [88.11332703, 21.84971809], [88.11416626, 21.85055542], [88.11415863, 21.85082817], [88.11499786, 21.8516674], [88.11499786, 21.85193825], [88.11554718, 21.85250092], [88.11554718, 21.85277939], [88.1158371, 21.85305595], [88.1158371, 21.8533287], [88.11611176, 21.8536129], [88.11611176, 21.85416985], [88.1169281, 21.85499954], [88.11694336, 21.85555649], [88.11750031, 21.85610962], [88.11750031, 21.85667038], [88.11777496, 21.85694313], [88.11778259, 21.85731506], [88.11798096, 21.8575592], [88.11820221, 21.85783386], [88.11856079, 21.85833168], [88.1188736, 21.85882759], [88.11915588, 21.85931015], [88.11943817, 21.85975075], [88.11971283, 21.86014938], [88.11995697, 21.86053658], [88.12013245, 21.86096191], [88.12030792, 21.86140442], [88.12050629, 21.86181831], [88.1206131, 21.86227989], [88.12078094, 21.86268044], [88.12091827, 21.86312103], [88.12111664, 21.86354065], [88.12133789, 21.86398125], [88.12143707, 21.8644619], [88.12162781, 21.8648777], [88.12174988, 21.86531067], [88.12195587, 21.86567116], [88.1222229, 21.86600113], [88.12249756, 21.86632919], [88.12278748, 21.86665154], [88.12310028, 21.86694336], [88.12342072, 21.86722183], [88.12374878, 21.86750221], [88.12407684, 21.8678112], [88.12442017, 21.86819267], [88.12475586, 21.86865044], [88.12516785, 21.8691597], [88.12565613, 21.86965942], [88.12618256, 21.87009811], [88.12664032, 21.87055969], [88.12701416, 21.87100983], [88.12740326, 21.87137985], [88.12776184, 21.87174034], [88.12809753, 21.87210083], [88.12841797, 21.87244034], [88.1287384, 21.8727417], [88.12906647, 21.8730011], [88.12944794, 21.87320709], [88.12982178, 21.87342453], [88.13018036, 21.87364006], [88.13050842, 21.87390327], [88.13082123, 21.87420273], [88.1311264, 21.87455177], [88.13145447, 21.87488556], [88.13182068, 21.87515068], [88.13218689, 21.87539291], [88.13250732, 21.87566948], [88.13285828, 21.87592697], [88.13319397, 21.87622261], [88.13356018, 21.87650108], [88.13391876, 21.87683678], [88.1342926, 21.87717247], [88.13472748, 21.87742615], [88.13500977, 21.87744713], [88.13525391, 21.87746239], [88.13576508, 21.87734795], [88.13617706, 21.87710953], [88.13639069, 21.87666893], [88.13667297, 21.87639809], [88.13639069, 21.87610817], [88.13666534, 21.87583351], [88.13666534, 21.87555695], [88.13694763, 21.87528038], [88.13694763, 21.875], [88.13722229, 21.87471962], [88.13749695, 21.875], [88.13777924, 21.87471962], [88.13777924, 21.87333298], [88.13803864, 21.87306023], [88.13803864, 21.87277985], [88.13835144, 21.87249947], [88.13832855, 21.8723774], [88.13851166, 21.87189102], [88.13864899, 21.87138939], [88.13883972, 21.87097931], [88.13897705, 21.87061119], [88.13913727, 21.87026024], [88.13923645, 21.86988068], [88.13944244, 21.86950874], [88.13965607, 21.8690815], [88.13985443, 21.86860275], [88.1400528, 21.86812019], [88.14028168, 21.8676796], [88.1404953, 21.8672657], [88.14063263, 21.86681175], [88.14084625, 21.86637115], [88.14112854, 21.86594009], [88.14142609, 21.86550903], [88.14161682, 21.86501122], [88.14173889, 21.86449623], [88.14199066, 21.86413956], [88.14225006, 21.86384964], [88.14248657, 21.86358261], [88.14269257, 21.86331749], [88.14286804, 21.86305809], [88.14305878, 21.86282349], [88.14324188, 21.86257553], [88.1434021, 21.86228943], [88.14359283, 21.86202049], [88.14376831, 21.86175346], [88.14389038, 21.86143494], [88.14399719, 21.86111069], [88.14414978, 21.86078072], [88.14428711, 21.8604393], [88.14447021, 21.86013985], [88.14467621, 21.85985947], [88.14493561, 21.8595295], [88.14530182, 21.85913086], [88.14565277, 21.85859108], [88.14559174, 21.85802078], [88.14556122, 21.85748291], [88.14561462, 21.85699463], [88.14582825, 21.85658264], [88.1460495, 21.85618973], [88.14620972, 21.85577011], [88.14634705, 21.85542107], [88.14640808, 21.85506248], [88.14651489, 21.85475159], [88.14665222, 21.85447121], [88.14678192, 21.85416985], [88.14696503, 21.85386276], [88.14717865, 21.85353851], [88.14739227, 21.85316086], [88.1476059, 21.85275078], [88.14775085, 21.85230255], [88.14782715, 21.85183334], [88.14800262, 21.85137939], [88.14805603, 21.85090065], [88.14813995, 21.85041809], [88.14831543, 21.85000229], [88.14848328, 21.84956932], [88.14863586, 21.84912109], [88.14885712, 21.84865952], [88.14906311, 21.84815025], [88.14920807, 21.84754944], [88.14943695, 21.84698677], [88.14965057, 21.84642029], [88.14974976, 21.84583092], [88.14987946, 21.84532166], [88.15003204, 21.84491348], [88.15021515, 21.84457016], [88.15032959, 21.84419632], [88.15049744, 21.84383011], [88.1505661, 21.84336281], [88.15065765, 21.8428421], [88.15084076, 21.84232712], [88.15103149, 21.84184074], [88.15116119, 21.84133339], [88.15139008, 21.84089088], [88.15161896, 21.84041977], [88.15177917, 21.83990479], [88.15196228, 21.83944702], [88.1521759, 21.83905029], [88.15236664, 21.83864594], [88.15258026, 21.83824348], [88.15278625, 21.83781052], [88.15302277, 21.83735085], [88.15315247, 21.83680916], [88.15338898, 21.83632851], [88.15365601, 21.83590508], [88.15393066, 21.83551979], [88.15418243, 21.83512115], [88.15445709, 21.83469009], [88.15472412, 21.834198], [88.15500641, 21.83365059], [88.15531158, 21.83310127], [88.15570068, 21.83263016], [88.15606689, 21.83218956], [88.15638733, 21.83172989], [88.15666962, 21.83126068], [88.15693665, 21.83077049], [88.15721893, 21.83029938], [88.15751648, 21.82987022], [88.15782166, 21.82948112], [88.15811157, 21.8291111], [88.15837097, 21.82874107], [88.15864563, 21.82842255], [88.15891266, 21.82812119], [88.15917206, 21.82781982], [88.15943909, 21.82749939], [88.15972137, 21.82715416], [88.16001892, 21.82674217], [88.16039276, 21.82628822], [88.1608429, 21.82582092], [88.16130066, 21.82538033], [88.16175079, 21.82497978], [88.16213989, 21.82454109], [88.16252136, 21.82415009], [88.16285706, 21.82380676], [88.16312408, 21.82348251], [88.16339111, 21.82318878], [88.16371155, 21.82287025], [88.16414642, 21.82250977], [88.164711, 21.82211876], [88.16526794, 21.82167053], [88.16638947, 21.82055092], [88.16666412, 21.82055664], [88.16666412, 21.82027626], [88.16694641, 21.81999969], [88.16750336, 21.81999969], [88.16916656, 21.81833076], [88.16916656, 21.8180542], [88.16999817, 21.81722069], [88.16999817, 21.81694221], [88.17028046, 21.81666756], [88.17028046, 21.81610107], [88.17055511, 21.81583214], [88.17055511, 21.81555557], [88.17082977, 21.81528282], [88.17082977, 21.81472015], [88.17138672, 21.81416702], [88.17140198, 21.8133316], [88.17194366, 21.81277847], [88.17193604, 21.81250191], [88.17250061, 21.81195259], [88.17250061, 21.81082916], [88.17194366, 21.81027985], [88.17166901, 21.81028938], [88.17155457, 21.8101635], [88.17140198, 21.80999947], [88.17082977, 21.80999947], [88.17056274, 21.80971909], [88.16972351, 21.8097229], [88.16955566, 21.80955315], [88.16944122, 21.80944443], [88.16889191, 21.80944443], [88.16860962, 21.80916786], [88.16832733, 21.80916977], [88.16777802, 21.80861092], [88.16750336, 21.80861092], [88.16722107, 21.80833054], [88.16694641, 21.80833244], [88.16611481, 21.80750084], [88.16583252, 21.80722046], [88.16583252, 21.8069458], [88.16527557, 21.80638885], [88.16526794, 21.80611038], [88.16500092, 21.80583], [88.16500092, 21.80555344], [88.16443634, 21.80500031], [88.16443634, 21.80416107], [88.16416931, 21.80388832], [88.16416931, 21.80249977], [88.16400909, 21.80191994], [88.16390991, 21.80133247], [88.1638031, 21.80074501], [88.16366577, 21.80014992], [88.16364288, 21.7995491], [88.16366577, 21.79896164], [88.16378021, 21.79842758], [88.16384888, 21.79793167], [88.16381073, 21.79745293], [88.16370392, 21.79701614], [88.16368866, 21.79656982], [88.16378784, 21.79624939], [88.16383362, 21.79610443], [88.16390228, 21.79560661], [88.16398621, 21.79510117], [88.16412354, 21.79461479], [88.16420746, 21.7940979], [88.16432953, 21.79358292], [88.16441345, 21.79305458], [88.1644516, 21.79252815], [88.16449738, 21.79199982], [88.16464996, 21.79152107], [88.16475677, 21.79099083], [88.16496277, 21.79047012], [88.1651001, 21.78992271], [88.16529083, 21.78939056], [88.16552734, 21.78889084], [88.16567993, 21.78837013], [88.16587067, 21.78790092], [88.16611481, 21.78749466], [88.16638184, 21.78709602], [88.16661072, 21.78664017], [88.16668701, 21.78602982], [88.1668396, 21.78543854], [88.1671524, 21.78494263], [88.16748047, 21.78444672], [88.16779327, 21.78391266], [88.1680603, 21.78339386], [88.16828918, 21.7829113], [88.16842651, 21.78243065], [88.16857147, 21.78199768], [88.16864014, 21.78154945], [88.16876221, 21.78108978], [88.16887665, 21.78061676], [88.16897583, 21.78014946], [88.16912842, 21.77972031], [88.16918182, 21.77931786], [88.16911316, 21.77886009], [88.16918945, 21.77856064], [88.16931915, 21.77828979], [88.16941833, 21.77799034], [88.16944122, 21.77762032], [88.16944885, 21.77720261], [88.16947174, 21.77675056], [88.16956329, 21.77629089], [88.16969299, 21.77584076], [88.1697464, 21.77539063], [88.1698761, 21.77498055], [88.17002106, 21.77459335], [88.17018127, 21.77423286], [88.17025757, 21.7737999], [88.17028809, 21.77333069], [88.17035675, 21.77282906], [88.17050171, 21.77231026], [88.17054749, 21.77176476], [88.17055511, 21.77120972], [88.17054749, 21.77067757], [88.17054749, 21.77017784], [88.17056274, 21.76971054], [88.17063141, 21.76926041], [88.17077637, 21.76880074], [88.17086792, 21.76824951], [88.17098236, 21.76768494], [88.17088318, 21.76708984], [88.17089081, 21.7665081], [88.1710434, 21.76592064], [88.1710968, 21.76531792], [88.17108917, 21.76470184], [88.17105103, 21.76405907], [88.17090607, 21.76343727], [88.17064667, 21.76284027], [88.17031097, 21.76224518], [88.1700592, 21.76165962], [88.1699295, 21.76106071], [88.16991425, 21.7605114], [88.16993713, 21.75995064], [88.16996765, 21.7593708], [88.17003632, 21.75877953], [88.17014313, 21.7582016], [88.17021942, 21.75764084], [88.17023468, 21.75707436], [88.17017365, 21.75647545], [88.17014313, 21.75588036], [88.17024994, 21.75531006], [88.17048645, 21.75476646], [88.1707077, 21.75424957], [88.17089844, 21.75374031], [88.17098236, 21.75316048], [88.17088318, 21.75257111], [88.17077637, 21.75199127], [88.17063904, 21.75146103], [88.17057037, 21.75097084], [88.17059326, 21.75052071], [88.1707077, 21.75008011], [88.17071533, 21.74964142], [88.17060089, 21.74919319], [88.17056274, 21.74873543], [88.17056274, 21.74829102], [88.17056274, 21.74785995], [88.17059326, 21.74744987], [88.17072296, 21.74706078], [88.17082214, 21.74666023], [88.1708374, 21.74619293], [88.17086029, 21.74566078], [88.17094421, 21.74510193], [88.17086029, 21.7445507], [88.17079926, 21.74399948], [88.17067719, 21.7434597], [88.17061615, 21.74291992], [88.17066193, 21.74240112], [88.17057037, 21.74192047], [88.17047119, 21.7414608], [88.1703186, 21.74104881], [88.17027283, 21.74061012], [88.17022705, 21.74021721], [88.17016602, 21.7397995], [88.16986084, 21.73917007], [88.16970825, 21.73847961], [88.16963196, 21.73783112], [88.16954803, 21.73727989], [88.1693573, 21.73677826], [88.16915131, 21.73623848], [88.16902161, 21.73570061], [88.16890717, 21.73521996], [88.16884613, 21.73483086], [88.16873932, 21.73456192], [88.16863251, 21.73428917], [88.16855621, 21.73395157], [88.16837311, 21.73361969], [88.16817474, 21.73316956], [88.1679306, 21.73269081], [88.16757965, 21.73230171], [88.16724396, 21.7319622], [88.16692352, 21.73162842], [88.16665649, 21.73124123], [88.16638947, 21.73085022], [88.16612244, 21.73045349], [88.16588593, 21.7300396], [88.16570282, 21.72958755], [88.16552734, 21.72912025], [88.16533661, 21.72866058], [88.16525269, 21.72813034], [88.16510773, 21.72758675], [88.16497803, 21.72701073], [88.16487122, 21.7264328], [88.16468811, 21.72587967], [88.16449738, 21.72537994], [88.16440582, 21.72480011], [88.16426849, 21.72421074], [88.16443634, 21.72360992], [88.16444397, 21.72194481], [88.16388702, 21.72138977], [88.16388702, 21.72056007], [88.16361237, 21.72027969], [88.16361237, 21.72000122], [88.16333008, 21.71970749], [88.16333008, 21.7191658], [88.16278076, 21.71861076], [88.16278076, 21.71805954], [88.16249847, 21.71777916], [88.16249847, 21.71750069], [88.16220856, 21.7172184], [88.16222382, 21.71666718], [88.16166687, 21.71611023], [88.16166687, 21.71582985], [88.16110992, 21.71527863], [88.16110992, 21.71500015], [88.16055298, 21.71445084], [88.16055298, 21.71389961], [88.15999603, 21.71333122], [88.16000366, 21.71305656], [88.15944672, 21.71249962], [88.15944672, 21.71138954], [88.15916443, 21.71111107], [88.15888977, 21.71111107], [88.15860748, 21.71084023], [88.15860748, 21.71055984], [88.15833282, 21.71027946], [88.15833282, 21.70944023], [88.15805817, 21.70916748], [88.15833282, 21.7089901], [88.1580658, 21.70861626], [88.15782928, 21.70824051], [88.15766907, 21.70782852], [88.15750122, 21.70722008], [88.15750122, 21.70666695], [88.15666962, 21.70583153], [88.15666962, 21.70555496], [88.15611267, 21.70500183], [88.15666962, 21.70443916], [88.15666962, 21.70388985], [88.15638733, 21.70360756], [88.15638733, 21.70222282], [88.15611267, 21.70194435], [88.15611267, 21.70111084], [88.15556335, 21.70055962], [88.15556335, 21.69972038], [88.15583038, 21.69944572], [88.15583038, 21.69861031], [88.15528107, 21.69806099], [88.15499878, 21.69750023], [88.15499878, 21.69721985], [88.15472412, 21.69694328], [88.15471649, 21.69667053], [88.15444183, 21.69639015], [88.15444183, 21.69553947], [88.15416718, 21.69527817], [88.15416718, 21.69472122], [88.15389252, 21.69444466], [88.15389252, 21.69388962], [88.15416718, 21.69361115], [88.15416718, 21.69306183], [88.15361023, 21.69249916], [88.15361023, 21.69082832], [88.15437317, 21.6909008], [88.15440369, 21.6905899], [88.1544342, 21.69028282], [88.15444183, 21.6897068], [88.15439606, 21.68919945], [88.15422058, 21.68879128], [88.15416718, 21.68835068], [88.15416718, 21.68790054], [88.15416718, 21.68742943], [88.15416718, 21.68694115], [88.15426636, 21.68645096], [88.15445709, 21.68597984], [88.15470886, 21.68554306], [88.15481567, 21.6850853], [88.15457153, 21.68453026], [88.15434265, 21.68406868], [88.15416718, 21.68359947], [88.15389252, 21.68361092], [88.15305328, 21.6827774], [88.15277863, 21.68278122], [88.15249634, 21.68250084], [88.15222168, 21.68250084], [88.15194702, 21.68222046], [88.15166473, 21.68222237], [88.15110779, 21.68166733], [88.15083313, 21.68167114], [88.15055847, 21.68139076], [88.15029144, 21.68139076], [88.14987183, 21.68094826], [88.14977264, 21.68084335], [88.14955902, 21.68061256], [88.14945984, 21.68050957], [88.14923859, 21.68042183], [88.14885712, 21.68025017], [88.14842987, 21.68007278], [88.14816284, 21.67996407], [88.14800262, 21.67990112], [88.14758301, 21.67975044], [88.14713287, 21.67967987], [88.14662933, 21.67966461], [88.14611816, 21.67964554], [88.14560699, 21.67958069], [88.14512634, 21.67956543], [88.14465332, 21.67955971], [88.14411163, 21.67955208], [88.1434021, 21.67955208], [88.14368439, 21.67914963], [88.14440155, 21.67874908], [88.14671326, 21.67847061], [88.14716339, 21.67857933], [88.14765167, 21.67872238], [88.14820099, 21.67888832], [88.14879608, 21.67910957], [88.14940643, 21.67940903], [88.14997864, 21.67976952], [88.15049744, 21.68015289], [88.15103149, 21.68041039], [88.15161133, 21.68053818], [88.15181732, 21.68056107], [88.15194702, 21.6807003], [88.15222168, 21.68111038], [88.15222168, 21.68139076], [88.15249634, 21.68167114], [88.15361023, 21.68166733], [88.15389252, 21.68194389], [88.15472412, 21.68194389], [88.15528107, 21.68138885], [88.15528107, 21.68028259], [88.15556335, 21.68000031], [88.15555573, 21.67944527], [88.15583038, 21.67917252], [88.15583038, 21.67861176], [88.15555573, 21.67833328], [88.15583038, 21.67805481], [88.15583038, 21.67666626], [88.15528107, 21.67611122], [88.15583038, 21.67555809], [88.15595245, 21.67514038], [88.15583801, 21.67469978], [88.15569305, 21.67428017], [88.15549469, 21.67395973], [88.15532684, 21.67358971], [88.1554184, 21.67317963], [88.15556335, 21.67271042], [88.15568542, 21.67222786], [88.15582275, 21.67173004], [88.15588379, 21.67122078], [88.15612793, 21.67078018], [88.15637207, 21.67036629], [88.15643311, 21.66988945], [88.15600586, 21.66926003], [88.15598297, 21.66867256], [88.15635681, 21.66813087], [88.15657806, 21.66757011], [88.15644073, 21.66712952], [88.15628052, 21.66667938], [88.15609741, 21.66624069], [88.15583038, 21.66583252], [88.15611267, 21.66555595], [88.15611267, 21.66472054], [88.15638733, 21.66444397], [88.15638733, 21.6641674], [88.15611267, 21.66416931], [88.15583038, 21.66389084], [88.15583038, 21.66221809], [88.15499878, 21.6613884], [88.15471649, 21.6613903], [88.15416718, 21.66082954], [88.15416718, 21.66027832], [88.15444183, 21.65999985], [88.15444183, 21.65971947], [88.15416718, 21.65944672], [88.15416718, 21.65888977], [88.15389252, 21.65860939], [88.15389252, 21.65583229], [88.15444183, 21.65527725], [88.15444183, 21.65389061], [88.15471649, 21.65361977], [88.15471649, 21.65306282], [88.15499878, 21.65278053], [88.15499878, 21.6511097], [88.15472412, 21.65083313], [88.15472412, 21.64999962], [88.15444183, 21.64972115], [88.15361023, 21.64972305], [88.15333557, 21.64944458], [88.15333557, 21.64916611], [88.15277863, 21.64861107], [88.15277863, 21.64833069], [88.15249634, 21.64805794], [88.15249634, 21.64750099], [88.15222168, 21.64722061], [88.15222168, 21.64694595], [88.15194702, 21.64666748], [88.15194702, 21.64639091], [88.14943695, 21.64389038], [88.14943695, 21.64361], [88.14888763, 21.64305305], [88.14861298, 21.64306068], [88.14833069, 21.6427803], [88.14805603, 21.6427803], [88.14749908, 21.64221954], [88.14694214, 21.64222145], [88.14638519, 21.64166641], [88.14639282, 21.64138985], [88.14556122, 21.64056015], [88.14554596, 21.63999939], [88.14472198, 21.63916969], [88.14444733, 21.63916969], [88.14250183, 21.63722038], [88.14250183, 21.63694382], [88.14277649, 21.63666725], [88.14221954, 21.63611031], [88.14221954, 21.63555908], [88.14250183, 21.63528061], [88.14250183, 21.63500023], [88.14332581, 21.63417053], [88.14332581, 21.63360977], [88.14221954, 21.63249969], [88.14167023, 21.63249969], [88.14138794, 21.63222313], [88.14111328, 21.63222313], [88.14055634, 21.63166428], [88.13999939, 21.63167], [88.1397171, 21.63138962], [88.13889313, 21.63138962], [88.13861084, 21.63167], [88.13833618, 21.63166428], [88.13805389, 21.63194656], [88.13777924, 21.63194656], [88.13749695, 21.63222313], [88.13666534, 21.63222313], [88.1361084, 21.63166428], [88.13582611, 21.63167], [88.13582611, 21.63138962], [88.13609314, 21.63096046], [88.13639069, 21.63055992], [88.13582611, 21.63000107], [88.13555908, 21.63000107], [88.13529205, 21.62972069], [88.13500214, 21.6297226], [88.13471985, 21.62944221], [88.13361359, 21.62944221], [88.1333313, 21.6297226], [88.13249969, 21.6297226], [88.13222504, 21.62944221], [88.13194275, 21.62944221], [88.13194275, 21.62916756], [88.13166809, 21.6288929], [88.13083649, 21.6288929], [88.13054657, 21.62861061], [88.1297226, 21.62861061], [88.12944794, 21.62833023], [88.12916565, 21.62833214], [88.12889099, 21.62805557], [88.1286087, 21.62805557], [88.12833405, 21.62833214], [88.12805176, 21.62833023], [88.1277771, 21.62861061], [88.12722015, 21.62861061], [88.12695313, 21.62833023], [88.1258316, 21.62833023], [88.12555695, 21.62861061], [88.12444305, 21.62861061], [88.1241684, 21.62833023], [88.12361145, 21.62833214], [88.12333679, 21.62805557], [88.12166595, 21.62805939], [88.1213913, 21.62778282], [88.12110901, 21.62778282], [88.12082672, 21.62750053], [88.12055206, 21.62750053], [88.12029266, 21.62722015], [88.12000275, 21.62722015], [88.11972046, 21.62694359], [88.11694336, 21.62694359], [88.1162262, 21.62622643], [88.11611176, 21.62611008], [88.1158371, 21.62611008], [88.11555481, 21.62583351]]], [[[88.99967194, 21.78546906], [89.0, 21.78471756], [89.00055695, 21.78504944], [89.00093079, 21.78511047], [89.00137329, 21.78499031], [89.0018692, 21.78502274], [89.00241089, 21.78483009], [89.00299835, 21.7846508], [89.00360107, 21.78444862], [89.00422668, 21.7842598], [89.00488281, 21.78408813], [89.00548553, 21.78388023], [89.00605774, 21.78365135], [89.0066452, 21.78347969], [89.00718689, 21.7833004], [89.0076828, 21.78307152], [89.00814819, 21.78284073], [89.00862885, 21.78264809], [89.00908661, 21.78248024], [89.00952148, 21.78224182], [89.00989532, 21.7820282], [89.01026154, 21.78178215], [89.01061249, 21.78149986], [89.01098633, 21.78121185], [89.01127625, 21.78088951], [89.01145935, 21.78053284], [89.01158142, 21.78022766], [89.01161194, 21.77994347], [89.01156616, 21.77961922], [89.01148224, 21.77927971], [89.01133728, 21.77889061], [89.01110077, 21.77849007], [89.01078033, 21.77804184], [89.01036072, 21.77760124], [89.00979614, 21.77725029], [89.00923157, 21.77695084], [89.00865173, 21.77667046], [89.00811768, 21.77639008], [89.00762939, 21.7761097], [89.00717926, 21.7758522], [89.00672913, 21.7756443], [89.00628662, 21.77550125], [89.00591278, 21.7753315], [89.00556183, 21.77522278], [89.00530243, 21.77507019], [89.00502014, 21.77499008], [89.0047226, 21.7748909], [89.00437927, 21.77474976], [89.00395966, 21.77466774], [89.00350952, 21.77448082], [89.00305176, 21.77431107], [89.00257874, 21.77414131], [89.00214386, 21.7739048], [89.00170898, 21.77366829], [89.00123596, 21.77347946], [89.00078583, 21.77329063], [89.00038147, 21.77300072], [89.0, 21.77277756], [88.99922943, 21.7725811], [88.99872589, 21.77216721], [88.99866486, 21.77211571], [88.99854279, 21.7720108], [88.99804688, 21.77166939], [88.99769592, 21.77139091], [88.99736023, 21.77098083], [88.99707031, 21.77055931], [88.99694824, 21.77000046], [88.99672699, 21.76868057], [88.99666595, 21.76832962], [88.99666595, 21.76802063], [88.99666595, 21.76749992], [88.99666595, 21.76721954], [88.99666595, 21.76694679], [88.99666595, 21.7658329], [88.99672699, 21.76555443], [88.99694824, 21.76416969], [88.99693298, 21.76395988], [88.9972229, 21.76305962], [88.99729156, 21.76278114], [88.99749756, 21.76222038], [88.99748993, 21.76194382], [88.99777985, 21.76083183], [88.99777222, 21.76062012], [88.99777222, 21.7602787], [88.99777985, 21.76000023], [88.99777985, 21.75917244], [88.99798584, 21.75889015], [88.99804688, 21.75832748], [88.9982605, 21.75805473], [88.99833679, 21.75777817], [88.99826813, 21.75749969], [88.99841309, 21.75687981], [88.99861145, 21.75638962], [88.99861145, 21.75611115], [88.99846649, 21.75582123], [88.99861145, 21.75555611], [88.99861145, 21.75500107], [88.99888611, 21.75472069], [88.99888611, 21.75416756], [88.9988327, 21.75389099], [88.99888611, 21.75361061], [88.99888611, 21.75307083], [88.9991684, 21.75278091], [88.9991684, 21.75167084], [88.99944305, 21.75139046], [88.99944305, 21.7508297], [88.99972534, 21.75055313], [89.0, 21.75000954], [89.00026703, 21.74971962], [89.00027466, 21.74944305], [89.00056458, 21.74819183], [89.00055695, 21.74781036], [89.00084686, 21.74735832], [89.00094604, 21.74711037], [89.00108337, 21.74683952], [89.00114441, 21.74653053], [89.00126648, 21.7462368], [89.00139618, 21.7459507], [89.00154114, 21.74568558], [89.00171661, 21.74542236], [89.00195313, 21.74514771], [89.00224304, 21.74481964], [89.00253296, 21.74443054], [89.0029068, 21.74402046], [89.00324249, 21.7435627], [89.00347137, 21.74305916], [89.00366974, 21.74259186], [89.00390625, 21.74221039], [89.00421143, 21.74189949], [89.00449371, 21.74160194], [89.00474548, 21.74125099], [89.00501251, 21.7409153], [89.00531769, 21.74060059], [89.00566101, 21.74031258], [89.00603485, 21.74006653], [89.00637817, 21.73977852], [89.00668335, 21.73945045], [89.0069809, 21.73913193], [89.00728607, 21.73880959], [89.00756073, 21.73846626], [89.00789642, 21.7381897], [89.00823212, 21.73789978], [89.00860596, 21.73764992], [89.0089798, 21.73741341], [89.0093689, 21.7371788], [89.00971985, 21.73689079], [89.01004791, 21.73659134], [89.01030731, 21.7362175], [89.01058197, 21.73587036], [89.01088715, 21.73557281], [89.01121521, 21.73530769], [89.01156616, 21.73508072], [89.01191711, 21.73480988], [89.01220703, 21.73444939], [89.01248169, 21.7340641], [89.01274109, 21.73366356], [89.01302338, 21.73330688], [89.01330566, 21.73296356], [89.0135498, 21.73261642], [89.01373291, 21.73223114], [89.01387787, 21.73187256], [89.01399994, 21.73150063], [89.01418304, 21.73114014], [89.01438141, 21.73074341], [89.01499939, 21.7284565], [89.01503754, 21.72792053], [89.0152359, 21.72738075], [89.01526642, 21.72678947], [89.01528931, 21.7261982], [89.01539612, 21.72565079], [89.01542664, 21.72392845], [89.01529694, 21.72319221], [89.0152359, 21.72252083], [89.0151062, 21.72191048], [89.01506805, 21.72129822], [89.01522827, 21.72072983], [89.01526642, 21.72014046], [89.01521301, 21.71959114], [89.01502991, 21.71914864], [89.01486206, 21.71879005], [89.01445007, 21.71860123], [89.01402283, 21.71845818], [89.01357269, 21.71837044], [89.0131073, 21.71807289], [89.01263428, 21.71805763], [89.0120697, 21.71820259], [89.01156616, 21.71832085], [89.0111618, 21.71828651], [89.01063538, 21.71829414], [89.01026154, 21.71800423], [89.00995636, 21.71766853], [89.00937653, 21.71763039], [89.00884247, 21.71769905], [89.00836182, 21.71754074], [89.00786591, 21.71738052], [89.0074234, 21.71718407], [89.00699615, 21.71693993], [89.0065918, 21.71672821], [89.00614929, 21.71657944], [89.00575256, 21.71639824], [89.00531769, 21.71627045], [89.00483704, 21.71613121], [89.00428009, 21.71607208], [89.00370026, 21.71607208], [89.00315857, 21.71611977], [89.00267792, 21.71623993], [89.00215912, 21.71642113], [89.00157166, 21.71664047], [89.00088501, 21.71677971], [89.0, 21.71722221], [88.99971771, 21.71742821], [88.99938202, 21.71777534], [88.99898529, 21.71805191], [88.99893188, 21.71810341], [88.99749756, 21.71944427], [88.9972229, 21.71943855], [88.99666595, 21.72000122], [88.99666595, 21.72027779], [88.99500275, 21.72194481], [88.99500275, 21.72221947], [88.9944458, 21.72277832], [88.9944458, 21.72305489], [88.99416351, 21.72333336], [88.99388885, 21.72332954], [88.99359894, 21.72346115], [88.99331665, 21.72357559], [88.99297333, 21.72370911], [88.99256897, 21.72390938], [88.99211884, 21.72414017], [88.99160767, 21.72435951], [88.99103546, 21.72454643], [88.99051666, 21.72476006], [88.99008942, 21.7250042], [88.98973083, 21.72523117], [88.98932648, 21.72540283], [88.98892212, 21.7255497], [88.98849487, 21.72567749], [88.98834991, 21.72572136], [88.98805237, 21.72581291], [88.98757172, 21.72592354], [88.98709869, 21.7260685], [88.98660278, 21.7261982], [88.98609924, 21.72634125], [88.98558044, 21.72644043], [88.9850769, 21.72661018], [88.98500061, 21.72661591], [88.98416901, 21.7266674], [88.98388672, 21.72694588], [88.98194122, 21.72694588], [88.98166656, 21.72722244], [88.9808197, 21.72722054], [88.98055267, 21.72750092], [88.97972107, 21.72750092], [88.97944641, 21.72777939], [88.97833252, 21.72777557], [88.97817993, 21.72794533], [88.97807312, 21.72805977], [88.97721863, 21.72805977], [88.97666931, 21.72861099], [88.97666931, 21.72916985], [88.97693634, 21.72954941], [88.97712708, 21.73006058], [88.97728729, 21.73063087], [88.97755432, 21.7311554], [88.97793579, 21.7315731], [88.97834778, 21.73193932], [88.97879791, 21.73223114], [88.9792099, 21.73258018], [88.97960663, 21.73290825], [88.98007202, 21.73316002], [88.98043823, 21.73348808], [88.98064423, 21.73366165], [88.98081207, 21.73380089], [88.98114777, 21.73414612], [88.98150635, 21.73442841], [88.98190308, 21.73468971], [88.98230743, 21.73492241], [88.98275757, 21.73509026], [88.98320007, 21.73526764], [88.98364258, 21.73545074], [88.98410797, 21.73565102], [88.98452759, 21.73594666], [88.98491669, 21.73631477], [88.98535919, 21.73664284], [88.98549652, 21.73672867], [88.98581696, 21.73693275], [88.98623657, 21.7372303], [88.98661804, 21.73754501], [88.98693848, 21.73791122], [88.98722839, 21.7383194], [88.98760223, 21.7387085], [88.98797607, 21.73908806], [88.98834991, 21.73945045], [88.98866272, 21.73984909], [88.98888397, 21.74032211], [88.98906708, 21.74078941], [88.98920441, 21.74124527], [88.98937988, 21.74164009], [88.98944092, 21.74207878], [88.98945618, 21.74253273], [88.98945618, 21.74300194], [88.98944092, 21.7434597], [88.98937988, 21.74385071], [88.98923492, 21.7441597], [88.989151, 21.74448013], [88.98903656, 21.74478912], [88.98892212, 21.74513054], [88.98876953, 21.7455101], [88.98854065, 21.74591255], [88.9882431, 21.74630928], [88.98787689, 21.74664879], [88.98749542, 21.74694252], [88.98711395, 21.74715042], [88.98667908, 21.7472229], [88.98625183, 21.74728394], [88.9858551, 21.74741936], [88.98583221, 21.74749947], [88.9852829, 21.74749947], [88.98500061, 21.74777985], [88.98443604, 21.74777985], [88.98416901, 21.74806023], [88.98387909, 21.74806023], [88.98368073, 21.74781036], [88.98347473, 21.74776077], [88.98314667, 21.74768066], [88.98274994, 21.74749184], [88.98233032, 21.74730492], [88.98184204, 21.74709702], [88.98137665, 21.74685097], [88.9809494, 21.74662209], [88.98055267, 21.74637413], [88.98018646, 21.7461071], [88.97982025, 21.74582863], [88.97945404, 21.74557114], [88.97905731, 21.74533081], [88.9786377, 21.74513054], [88.97823334, 21.74489975], [88.97782898, 21.74468803], [88.97743225, 21.74446106], [88.97698975, 21.74423027], [88.97650146, 21.74403954], [88.97599792, 21.74380112], [88.97563171, 21.74343109], [88.97520447, 21.74318695], [88.97476196, 21.74296951], [88.9743576, 21.74272156], [88.97396088, 21.74243927], [88.97358704, 21.74210167], [88.9732132, 21.74176979], [88.97283173, 21.74148178], [88.97237396, 21.74131966], [88.97197723, 21.74113083], [88.97174072, 21.74099731], [88.97162628, 21.74093246], [88.97127533, 21.74078369], [88.97098541, 21.74061012], [88.97068024, 21.74047661], [88.97041321, 21.74035072], [88.97009277, 21.74033928], [88.96977234, 21.74045372], [88.96942902, 21.74053383], [88.96907806, 21.74060059], [88.96871185, 21.74070549], [88.96835327, 21.74084091], [88.96800232, 21.74104881], [88.96766663, 21.74126053], [88.96734619, 21.74154091], [88.96711731, 21.74189949], [88.96687317, 21.74231148], [88.96666718, 21.74280167], [88.96647644, 21.74335289], [88.96641541, 21.74397087], [88.96639252, 21.74465942], [88.96640778, 21.74531174], [88.96641541, 21.74541092], [88.96644592, 21.74587631], [88.96644592, 21.74640274], [88.96646881, 21.74694252], [88.96659851, 21.74744034], [88.96665192, 21.74797058], [88.96666718, 21.74852943], [88.96669769, 21.74911118], [88.96669769, 21.74967957], [88.96661377, 21.75016022], [88.96644592, 21.75065231], [88.96626282, 21.75115967], [88.96605682, 21.7517128], [88.96575928, 21.75222969], [88.96533966, 21.75265121], [88.96489716, 21.75301933], [88.96443939, 21.75333214], [88.96399689, 21.75361252], [88.96360016, 21.75387955], [88.96321869, 21.75412941], [88.96282959, 21.75433159], [88.9624176, 21.75449944], [88.96199799, 21.75471115], [88.96155548, 21.75489807], [88.96105194, 21.75501251], [88.9605484, 21.75514984], [88.96002197, 21.75527], [88.95950317, 21.75535965], [88.958992, 21.75549126], [88.95861053, 21.7555294], [88.95847321, 21.75555992], [88.95614624, 21.75555992], [88.95527649, 21.75555611], [88.95500183, 21.75583267], [88.95443726, 21.75582123], [88.95417023, 21.75611115], [88.95333099, 21.75611115], [88.95305634, 21.75638962], [88.95276642, 21.75638962], [88.95249939, 21.75666809], [88.9522171, 21.75666809], [88.95111084, 21.75777817], [88.95111084, 21.75805473], [88.95155334, 21.75855446], [88.95198059, 21.75896454], [88.95251465, 21.75930023], [88.95305634, 21.75958061], [88.95361328, 21.75982094], [88.95410156, 21.76004028], [88.95456696, 21.76026917], [88.95503998, 21.76048088], [88.95552063, 21.76066971], [88.95600128, 21.76086044], [88.95644379, 21.76110649], [88.95690155, 21.76132393], [88.95709229, 21.76137352], [88.95739746, 21.76145554], [88.95778656, 21.7616806], [88.95804596, 21.76194954], [88.95833588, 21.76194954], [88.96055603, 21.76416969], [88.96083069, 21.76416969], [88.96193695, 21.76527977], [88.96221924, 21.76527977], [88.96257782, 21.76557732], [88.96287537, 21.76592445], [88.96305084, 21.76633835], [88.96333313, 21.76663971], [88.96356201, 21.76692963], [88.96366119, 21.76729965], [88.96378326, 21.7676506], [88.96396637, 21.76799011], [88.96417999, 21.76836014], [88.96444702, 21.76876068], [88.96470642, 21.76925087], [88.96496582, 21.76982117], [88.96517944, 21.77046013], [88.96555328, 21.77098083], [88.96589661, 21.77144814], [88.96630096, 21.77185059], [88.96676636, 21.77218437], [88.96727753, 21.77242088], [88.96788025, 21.77259064], [88.96842957, 21.77271461], [88.96891785, 21.7727356], [88.96935272, 21.77263069], [88.96977234, 21.7725811], [88.9701767, 21.77263069], [88.97058868, 21.77275085], [88.9710083, 21.77277946], [88.97142029, 21.77280045], [88.9717865, 21.77289963], [88.9721756, 21.77302933], [88.97263336, 21.77310753], [88.97305298, 21.77331924], [88.973526, 21.77351952], [88.97401428, 21.77376556], [88.97442627, 21.77412987], [88.97486115, 21.77446556], [88.97522736, 21.77482033], [88.97551727, 21.77521896], [88.97583771, 21.77557945], [88.97611237, 21.77596283], [88.97635651, 21.77634811], [88.97667694, 21.77667999], [88.97701263, 21.77700043], [88.97736359, 21.77729034], [88.97766876, 21.77762032], [88.97792816, 21.77799034], [88.9782486, 21.77827835], [88.97856903, 21.77856064], [88.97888184, 21.7788372], [88.97920227, 21.77913094], [88.97953033, 21.77943039], [88.97986603, 21.77972031], [88.98021698, 21.78001976], [88.98052979, 21.78034019], [88.98083496, 21.78068924], [88.98113251, 21.78103065], [88.98143768, 21.78135872], [88.98177338, 21.78166008], [88.98208618, 21.78198051], [88.98236084, 21.782341], [88.98272705, 21.78263092], [88.98304749, 21.78296661], [88.9833374, 21.78331947], [88.98365784, 21.78366089], [88.98397827, 21.78397942], [88.98430634, 21.78430367], [88.98462677, 21.78462029], [88.98497772, 21.78490448], [88.98527527, 21.7852459], [88.98555756, 21.78560066], [88.98584747, 21.78596115], [88.98615265, 21.78630257], [88.98648071, 21.78662491], [88.98677826, 21.78696251], [88.98707581, 21.78731346], [88.98747253, 21.78754807], [88.98787689, 21.7877903], [88.98828125, 21.78806114], [88.98871613, 21.7883358], [88.98919678, 21.78861237], [88.98972321, 21.78884125], [88.99025726, 21.78885078], [88.99089813, 21.78856087], [88.99147797, 21.78831863], [88.99195099, 21.78808975], [88.99240875, 21.78792572], [88.99286652, 21.78778267], [88.99333191, 21.78762054], [88.99349213, 21.78756714], [88.99381256, 21.78746033], [88.9942627, 21.78726959], [88.99474335, 21.78709984], [88.99520874, 21.78692818], [88.99565887, 21.78671837], [88.9961319, 21.7865448], [88.99660492, 21.78637505], [88.99704742, 21.78615952], [88.99750519, 21.78598976], [88.99797058, 21.78585815], [88.99843597, 21.78577995], [88.998909, 21.78572845], [88.99931335, 21.78557968], [88.99967194, 21.78546906]]], [[[88.20054626, 21.76860809], [88.20055389, 21.76805687], [88.20083618, 21.7677784], [88.20083618, 21.76749992], [88.20111084, 21.76721954], [88.20111084, 21.76666451], [88.20137787, 21.76638985], [88.20137787, 21.76556015], [88.20166779, 21.76527977], [88.20166779, 21.76501083], [88.20194244, 21.76472092], [88.20194244, 21.76444435], [88.20222473, 21.76416588], [88.2022171, 21.76389122], [88.20249939, 21.76361084], [88.20249939, 21.76305962], [88.2022171, 21.76278114], [88.2022171, 21.76250076], [88.20194244, 21.76222038], [88.20222473, 21.76166725], [88.2022171, 21.76139069], [88.20083618, 21.76000023], [88.19917297, 21.75917244], [88.19917297, 21.75889015], [88.19889069, 21.75861168], [88.19777679, 21.75805473], [88.19694519, 21.75777817], [88.19638824, 21.75749969], [88.19610596, 21.75777817], [88.1958313, 21.75777817], [88.19555664, 21.75805473], [88.1955719, 21.75832748], [88.19499969, 21.75889015], [88.19499969, 21.75917244], [88.19472504, 21.75944519], [88.19473267, 21.75972176], [88.19444275, 21.76000023], [88.19444275, 21.76083183], [88.19416809, 21.76111031], [88.19416809, 21.76194382], [88.1938858, 21.76222229], [88.1938858, 21.76333046], [88.19416809, 21.76361084], [88.19416809, 21.76389122], [88.19444275, 21.76416588], [88.19444275, 21.76444054], [88.19499969, 21.76501083], [88.19499969, 21.76527786], [88.19555664, 21.7658329], [88.1955719, 21.76610947], [88.197052, 21.76761246], [88.19721985, 21.7677803], [88.19750214, 21.7677784], [88.19833374, 21.76861191], [88.1986084, 21.76860809], [88.19917297, 21.76917076], [88.19999695, 21.76917076], [88.20027924, 21.76889038], [88.20054626, 21.76860809]]], [[[88.30249023, 21.72456169], [88.30229187, 21.72409058], [88.30216217, 21.7235775], [88.30194855, 21.72315025], [88.30176544, 21.72274971], [88.30162048, 21.72235107], [88.30142975, 21.7220211], [88.30133057, 21.72163963], [88.30114746, 21.72128487], [88.30110168, 21.72084999], [88.30103302, 21.72037125], [88.30092621, 21.72004128], [88.3008728, 21.71988487], [88.30082703, 21.71931458], [88.30080414, 21.7187252], [88.30075073, 21.7181797], [88.30081177, 21.71768951], [88.30081177, 21.71724701], [88.30069733, 21.71682167], [88.30060577, 21.71640015], [88.3006897, 21.71598816], [88.30088043, 21.71562004], [88.30105591, 21.71528053], [88.30071259, 21.71475029], [88.30057526, 21.7143383], [88.30056, 21.71398163], [88.30060577, 21.71364021], [88.30077362, 21.71333313], [88.30079651, 21.7132206], [88.30084229, 21.71297073], [88.30091858, 21.71261024], [88.30105591, 21.71225929], [88.30114746, 21.71187019], [88.30132294, 21.71145058], [88.30158997, 21.71096039], [88.30200958, 21.71042061], [88.30218506, 21.70977783], [88.30198669, 21.70919037], [88.30172729, 21.70868111], [88.30148315, 21.70827293], [88.30132294, 21.70791245], [88.30108643, 21.70765114], [88.30078888, 21.70743942], [88.30052185, 21.70721054], [88.30027008, 21.7069416], [88.29998779, 21.70664978], [88.29962921, 21.70633125], [88.29911041, 21.70598984], [88.29844666, 21.70570564], [88.29811859, 21.70556259], [88.29773712, 21.70556259], [88.29727936, 21.70560074], [88.29681396, 21.70583153], [88.29631042, 21.70607948], [88.29574585, 21.70630074], [88.29527283, 21.70662117], [88.29482269, 21.7069912], [88.29444885, 21.70740891], [88.29411316, 21.7078228], [88.29374695, 21.70819283], [88.29338837, 21.7085495], [88.29302216, 21.70886993], [88.29266357, 21.70916367], [88.29232025, 21.70944023], [88.29199219, 21.70973015], [88.29169464, 21.7100563], [88.2914505, 21.71046066], [88.29113007, 21.71079826], [88.29071808, 21.71109009], [88.29039001, 21.71146774], [88.29014587, 21.71194077], [88.28987122, 21.71244812], [88.28949738, 21.71293068], [88.28917694, 21.71351051], [88.28888702, 21.71413994], [88.28855896, 21.71473122], [88.28813934, 21.71519089], [88.2877121, 21.71562004], [88.28733826, 21.71603966], [88.287117, 21.71649551], [88.28691864, 21.71695137], [88.28666687, 21.71736908], [88.28639221, 21.7177887], [88.28610992, 21.71820259], [88.28583527, 21.71861458], [88.28556061, 21.71902084], [88.28555298, 21.7191658], [88.28499603, 21.71970749], [88.28500366, 21.71999931], [88.28416443, 21.72083282], [88.2841568, 21.72110939], [88.28388977, 21.72138977], [88.28388977, 21.72194481], [88.28360748, 21.72221947], [88.28360748, 21.72249985], [88.28221893, 21.7238903], [88.28221893, 21.72417068], [88.28193665, 21.72445107], [88.28166962, 21.72445107], [88.28115082, 21.72500992], [88.28063202, 21.7255497], [88.2800827, 21.72603989], [88.27954865, 21.72653961], [88.27896881, 21.72702026], [88.27842712, 21.72756958], [88.2780304, 21.72817039], [88.27796936, 21.72878265], [88.27799988, 21.72937584], [88.27787018, 21.72991943], [88.27775574, 21.73049736], [88.27758026, 21.73106194], [88.2775116, 21.73166656], [88.27749634, 21.73229408], [88.27746582, 21.73290825], [88.27735138, 21.73348045], [88.27725983, 21.73398018], [88.27722168, 21.73417282], [88.27722168, 21.73611069], [88.27749634, 21.73638916], [88.27749634, 21.73722076], [88.27722168, 21.73750114], [88.27722168, 21.73861122], [88.27805328, 21.73944664], [88.27805328, 21.7397213], [88.27833557, 21.73999977], [88.27833557, 21.74055672], [88.27861023, 21.74081993], [88.27861023, 21.74139023], [88.27889252, 21.7416687], [88.27902985, 21.74205971], [88.27919769, 21.74247551], [88.2794342, 21.74278259], [88.27963257, 21.74304008], [88.27980042, 21.74328041], [88.27999115, 21.7435112], [88.28019714, 21.7437706], [88.28051758, 21.74398613], [88.28081512, 21.74424362], [88.28105927, 21.74456024], [88.28122711, 21.74496078], [88.28143311, 21.74537086], [88.28166962, 21.74575615], [88.28189087, 21.74616051], [88.28195953, 21.74666786], [88.28205109, 21.74715042], [88.28224945, 21.74757957], [88.28251648, 21.74794006], [88.28279114, 21.74827003], [88.28305817, 21.7485981], [88.28333282, 21.74892426], [88.28356934, 21.74928093], [88.28373718, 21.74971962], [88.28392029, 21.7501545], [88.2841568, 21.75057983], [88.28437805, 21.75105095], [88.28457642, 21.75152016], [88.28477478, 21.75198746], [88.28499603, 21.7524395], [88.28527069, 21.75288582], [88.28547668, 21.75336075], [88.2856369, 21.75386047], [88.28579712, 21.75434113], [88.28588104, 21.75485992], [88.28607178, 21.75534058], [88.28610992, 21.75583839], [88.28611755, 21.75632858], [88.28617859, 21.75680923], [88.28634644, 21.75724983], [88.28639221, 21.75773048], [88.28639221, 21.7582016], [88.28639221, 21.75867844], [88.28639221, 21.75916672], [88.28639221, 21.76111031], [88.28639221, 21.76159477], [88.28639221, 21.76206398], [88.28637695, 21.7625103], [88.28637695, 21.7629509], [88.28639984, 21.76338959], [88.28647614, 21.76383018], [88.28663635, 21.76429939], [88.28665924, 21.76480865], [88.28658295, 21.76534271], [88.28642273, 21.76588058], [88.28639221, 21.76645851], [88.28637695, 21.7670517], [88.28637695, 21.76764107], [88.28637695, 21.7681694], [88.28639221, 21.76865005], [88.28643036, 21.76908684], [88.28662109, 21.76950073], [88.28666687, 21.76996803], [88.28666687, 21.77046967], [88.2866745, 21.77100563], [88.28673553, 21.77153969], [88.28691864, 21.77202988], [88.28704071, 21.77257919], [88.28721619, 21.77309036], [88.28734589, 21.77360153], [88.28749847, 21.77404022], [88.28764343, 21.77444649], [88.28779602, 21.77484322], [88.28797913, 21.77523041], [88.28807068, 21.77567673], [88.28819275, 21.77610016], [88.28831482, 21.7765274], [88.28840637, 21.77700043], [88.28857422, 21.77750969], [88.28862762, 21.77791023], [88.28864288, 21.77805328], [88.28890991, 21.77848434], [88.28964233, 21.77845573], [88.29032135, 21.77799988], [88.29083252, 21.77742195], [88.2912674, 21.77687454], [88.29166412, 21.77633667], [88.29205322, 21.77581596], [88.29212952, 21.7757206], [88.29245758, 21.77531624], [88.2928772, 21.77482986], [88.29337311, 21.77440834], [88.2938385, 21.77399063], [88.29424286, 21.77355957], [88.29463959, 21.77313042], [88.29496765, 21.77270317], [88.29523468, 21.77228165], [88.29553223, 21.77190971], [88.29582977, 21.77155495], [88.29611206, 21.77119255], [88.29640198, 21.77081108], [88.29666138, 21.77041817], [88.29688263, 21.77000046], [88.29708862, 21.76958084], [88.29729462, 21.76921654], [88.29753113, 21.76893997], [88.29776001, 21.7686882], [88.29794312, 21.76844978], [88.29814148, 21.76824379], [88.29833221, 21.76800919], [88.29850006, 21.76774025], [88.29866028, 21.76741028], [88.29881287, 21.76707077], [88.29891205, 21.76663971], [88.29904938, 21.76622009], [88.29917908, 21.7658329], [88.29933167, 21.76549149], [88.29943085, 21.76516533], [88.29950714, 21.76486015], [88.2996521, 21.76457977], [88.2997818, 21.76428986], [88.29992676, 21.76400185], [88.30002594, 21.76366043], [88.30016327, 21.76329994], [88.30026245, 21.7628994], [88.30032349, 21.76246262], [88.30049896, 21.76204109], [88.30059052, 21.76156807], [88.30078125, 21.76111984], [88.3008728, 21.7605896], [88.30103302, 21.76007271], [88.30117035, 21.75955772], [88.3013916, 21.75914955], [88.30161285, 21.75882149], [88.3017807, 21.75851059], [88.30194092, 21.75823975], [88.30207825, 21.75796509], [88.30208588, 21.75758171], [88.30201721, 21.75710106], [88.30215454, 21.75664902], [88.30246735, 21.75613022], [88.30288696, 21.75555992], [88.30280304, 21.75507927], [88.30265045, 21.75460052], [88.30252075, 21.75411034], [88.30249786, 21.75362206], [88.30253601, 21.75311661], [88.30271912, 21.75261116], [88.30277252, 21.75206947], [88.30281067, 21.75158119], [88.30297089, 21.75118065], [88.30304718, 21.75078011], [88.30309296, 21.75031853], [88.30323029, 21.74979973], [88.30332184, 21.7491703], [88.30337524, 21.7485199], [88.30354309, 21.74793053], [88.30360413, 21.74744225], [88.30361176, 21.74704742], [88.3035965, 21.74670982], [88.3035965, 21.74637985], [88.30361938, 21.74603271], [88.30368042, 21.7456646], [88.30384827, 21.74529457], [88.30389404, 21.74484253], [88.30394745, 21.74435043], [88.30412292, 21.74385071], [88.3041687, 21.7433033], [88.30420685, 21.7427597], [88.30444336, 21.74225044], [88.30458832, 21.74168777], [88.30446625, 21.74096107], [88.30461121, 21.74038124], [88.30474854, 21.73983955], [88.3049469, 21.73937988], [88.30500793, 21.73888016], [88.30508423, 21.73841286], [88.30524445, 21.73796272], [88.30526733, 21.73747063], [88.30527496, 21.73697662], [88.30526733, 21.73647118], [88.30526733, 21.73590279], [88.30532074, 21.7352829], [88.30555725, 21.73464584], [88.3057785, 21.73393822], [88.30583191, 21.73317719], [88.3057785, 21.73241043], [88.30555725, 21.7317276], [88.30528259, 21.73111916], [88.30500031, 21.73058128], [88.30474854, 21.73008156], [88.30458832, 21.72959328], [88.30444336, 21.72915459], [88.30432129, 21.7287693], [88.30417633, 21.72844124], [88.3041687, 21.72811127], [88.30413055, 21.72779083], [88.30396271, 21.72755051], [88.3038559, 21.72726059], [88.30368805, 21.72701073], [88.3035202, 21.72668839], [88.30329895, 21.72636032], [88.30304718, 21.72597122], [88.30281067, 21.72555733], [88.30267334, 21.72505188], [88.30249023, 21.72456169]]], [[[88.58222198, 21.77778053], [88.58249664, 21.77750015], [88.58304596, 21.77750015], [88.58333588, 21.77721977], [88.58361053, 21.77722168], [88.58416748, 21.77666664], [88.58416748, 21.77639008], [88.58444214, 21.7761097], [88.58444214, 21.77583122], [88.58472443, 21.77555466], [88.58472443, 21.77527809], [88.58499908, 21.77499962], [88.58499908, 21.76610947], [88.58472443, 21.7658329], [88.58472443, 21.76527786], [88.58444214, 21.76501083], [88.58444214, 21.76361084], [88.58416748, 21.76333046], [88.58416748, 21.76250076], [88.58392334, 21.7622509], [88.58388519, 21.76194382], [88.58361816, 21.76167107], [88.58361816, 21.76139069], [88.58389282, 21.76111031], [88.58388519, 21.76055527], [88.58361816, 21.76028061], [88.58364868, 21.75999069], [88.58362579, 21.75938034], [88.58371735, 21.75879097], [88.58390808, 21.75827026], [88.58410645, 21.75778961], [88.584198, 21.75727081], [88.5843277, 21.75678062], [88.58452606, 21.75632858], [88.58473206, 21.75587082], [88.58495331, 21.75542068], [88.5851059, 21.75489998], [88.58534241, 21.75439072], [88.58560944, 21.75389099], [88.58595276, 21.75341034], [88.58638763, 21.75301933], [88.58674622, 21.75258064], [88.5871582, 21.75222969], [88.58759308, 21.75195122], [88.58804321, 21.75170135], [88.58857727, 21.75155067], [88.58911896, 21.7513504], [88.58963013, 21.75110245], [88.59011078, 21.7508316], [88.59056091, 21.7505703], [88.59101868, 21.75037956], [88.59148407, 21.75025177], [88.5919342, 21.75005531], [88.59250641, 21.74995041], [88.59309387, 21.74968719], [88.59371185, 21.74936295], [88.59429169, 21.74899101], [88.59481049, 21.74862099], [88.59532166, 21.74830055], [88.59584808, 21.74802017], [88.59638214, 21.74777031], [88.59689331, 21.74747086], [88.59733582, 21.74710846], [88.59781647, 21.74682999], [88.59835052, 21.74660873], [88.59887695, 21.74637985], [88.59940338, 21.74612045], [88.5999527, 21.74591255], [88.60057068, 21.74579048], [88.60108948, 21.74557686], [88.60166168, 21.74542236], [88.60227966, 21.74530029], [88.6029129, 21.74522972], [88.6033783, 21.74501038], [88.60370636, 21.74478912], [88.6047821, 21.74424171], [88.60494995, 21.74419022], [88.60568237, 21.74398994], [88.60646057, 21.74394989], [88.60692596, 21.74366951], [88.6075058, 21.74361038], [88.608078, 21.74360657], [88.60861969, 21.7435627], [88.60910034, 21.74336052], [88.60959625, 21.74318123], [88.61013031, 21.74296951], [88.610672, 21.74278831], [88.61120605, 21.74266052], [88.61170197, 21.74251938], [88.61222076, 21.74250031], [88.61332703, 21.74139023], [88.61416626, 21.74139023], [88.61444092, 21.74110985], [88.61444092, 21.74083328], [88.61472321, 21.74055672], [88.61499786, 21.74083328], [88.61528015, 21.74083328], [88.61555481, 21.74055672], [88.6158371, 21.74083328], [88.61611176, 21.74083328], [88.61694336, 21.73999977], [88.61753082, 21.73978996], [88.6180954, 21.73948288], [88.61869812, 21.73913383], [88.61923218, 21.73870087], [88.61976624, 21.73831177], [88.62019348, 21.73784637], [88.62047577, 21.73728943], [88.6206131, 21.73656082], [88.62078857, 21.73584557], [88.62088013, 21.73512459], [88.62097931, 21.73446274], [88.62081909, 21.73387146], [88.62059784, 21.7333622], [88.62041473, 21.73289871], [88.6202774, 21.73246002], [88.62014771, 21.73204041], [88.62001801, 21.73163986], [88.61985016, 21.73125458], [88.61962128, 21.73088074], [88.61930084, 21.73050117], [88.618927, 21.73003006], [88.61873627, 21.7297802], [88.61852264, 21.72949409], [88.61802673, 21.72895813], [88.61748505, 21.72846794], [88.61692047, 21.72801018], [88.61637115, 21.7276268], [88.61582947, 21.72732162], [88.61531067, 21.72709084], [88.61483765, 21.72689819], [88.61440277, 21.72672081], [88.61393738, 21.72661972], [88.6135025, 21.72648621], [88.61306, 21.72640038], [88.61262512, 21.7263279], [88.61223602, 21.72616005], [88.61183929, 21.72603989], [88.61156464, 21.72590256], [88.61148071, 21.72586632], [88.61110687, 21.72570992], [88.61071777, 21.72557068], [88.61030579, 21.72543907], [88.60990906, 21.72525978], [88.60949707, 21.72507286], [88.60900879, 21.72499466], [88.60850525, 21.72490883], [88.60801697, 21.72474098], [88.60752869, 21.72459984], [88.60706329, 21.72446823], [88.60656738, 21.72439384], [88.60610962, 21.7242794], [88.6056366, 21.72420692], [88.60510254, 21.72422791], [88.60449219, 21.72431374], [88.60384369, 21.72418976], [88.60318756, 21.7240715], [88.60256195, 21.72392082], [88.60196686, 21.72381973], [88.6014328, 21.72367287], [88.60089874, 21.72354126], [88.60043335, 21.72332191], [88.59998322, 21.72310638], [88.59951782, 21.7229805], [88.59912109, 21.72283173], [88.59868622, 21.72275925], [88.59824371, 21.72271729], [88.59780884, 21.72261047], [88.59745026, 21.72232056], [88.59701538, 21.72208214], [88.59656525, 21.72182274], [88.59609222, 21.72152519], [88.59559631, 21.72125053], [88.5951004, 21.72096062], [88.59458923, 21.72070313], [88.59416962, 21.72031975], [88.59378052, 21.71988106], [88.59343719, 21.71945763], [88.5931015, 21.7190876], [88.59279633, 21.71870995], [88.59243011, 21.71902084], [88.59201813, 21.71934128], [88.59158325, 21.71953964], [88.59115601, 21.71973991], [88.59072113, 21.71997452], [88.59022522, 21.72017097], [88.5896759, 21.72034073], [88.58917999, 21.72056961], [88.58870697, 21.72083473], [88.58822632, 21.72110939], [88.58774567, 21.72137833], [88.58721924, 21.72159958], [88.58664703, 21.7217598], [88.58617401, 21.72197533], [88.58577728, 21.72225952], [88.58538055, 21.72252083], [88.58499146, 21.72278023], [88.5845871, 21.7229805], [88.5841217, 21.72312737], [88.58366394, 21.72331238], [88.58319092, 21.72347069], [88.5827179, 21.72363091], [88.58228302, 21.72380257], [88.58187103, 21.72392082], [88.58148193, 21.72409821], [88.58113861, 21.72437096], [88.58078003, 21.72480011], [88.58065033, 21.72492218], [88.58027649, 21.72528076], [88.58027649, 21.72556114], [88.58000183, 21.72556114], [88.57971954, 21.72583961], [88.57971954, 21.72639084], [88.58000183, 21.7266674], [88.58000183, 21.72694588], [88.58027649, 21.72722054], [88.58027649, 21.72777939], [88.58055878, 21.72805977], [88.58055878, 21.72861099], [88.58027649, 21.72887993], [88.58027649, 21.72916794], [88.58055878, 21.7294445], [88.58055878, 21.72972107], [88.58082581, 21.72999954], [88.58083344, 21.73027992], [88.58087158, 21.73034286], [88.58112335, 21.7308197], [88.5813446, 21.73126602], [88.58149719, 21.73176384], [88.58167267, 21.73225212], [88.58187103, 21.73273087], [88.58194733, 21.73324013], [88.58203888, 21.73367691], [88.58219147, 21.73402023], [88.58223724, 21.73436165], [88.58238983, 21.73462868], [88.58249664, 21.73490334], [88.58257294, 21.73519325], [88.58273315, 21.7354641], [88.58277893, 21.73583031], [88.58283997, 21.736269], [88.58302307, 21.73672295], [88.58312225, 21.73726082], [88.58329773, 21.73777962], [88.58333588, 21.7383461], [88.58338165, 21.7389183], [88.58358002, 21.73945808], [88.58364105, 21.74005127], [88.58361816, 21.74066925], [88.58361816, 21.74126053], [88.58365631, 21.74179077], [88.58383942, 21.74224091], [88.58389282, 21.74267006], [88.58390808, 21.74308968], [88.58396912, 21.7434864], [88.58412933, 21.74386024], [88.58416748, 21.74423981], [88.58413696, 21.74460983], [88.58402252, 21.74497986], [88.58384705, 21.74532127], [88.58377838, 21.74574089], [88.58390808, 21.74628067], [88.58384705, 21.7467308], [88.58367157, 21.74714088], [88.58361816, 21.74757195], [88.58361816, 21.7480011], [88.58355713, 21.74841118], [88.58336639, 21.74882126], [88.58323669, 21.74924088], [88.58304596, 21.74962044], [88.58283234, 21.74999046], [88.58275604, 21.7504158], [88.5826416, 21.7508049], [88.5824585, 21.7511425], [88.58224487, 21.75147247], [88.58207703, 21.75185966], [88.58193207, 21.75230026], [88.58171082, 21.7527504], [88.58141327, 21.75317764], [88.58113861, 21.75362968], [88.58090973, 21.75412178], [88.58079529, 21.75468445], [88.58055878, 21.75514984], [88.58026886, 21.7556057], [88.57994843, 21.75603104], [88.57955933, 21.75639915], [88.57920837, 21.75677109], [88.57891846, 21.7571907], [88.57859802, 21.75759315], [88.5782547, 21.75800133], [88.57781982, 21.75836182], [88.57737732, 21.75873947], [88.5769577, 21.75914955], [88.57656097, 21.75955963], [88.57624054, 21.75996971], [88.57594299, 21.76033783], [88.57578278, 21.76074982], [88.57554626, 21.76111984], [88.57527924, 21.76146317], [88.57498169, 21.76182175], [88.574646, 21.76215363], [88.5742569, 21.7624321], [88.57395172, 21.76280975], [88.57370758, 21.76325035], [88.5734787, 21.76371384], [88.57311249, 21.7641201], [88.57272339, 21.76453972], [88.57232666, 21.76498032], [88.57187653, 21.76537514], [88.5717926, 21.76545334], [88.57142639, 21.76579857], [88.57097626, 21.76624107], [88.57054138, 21.76670265], [88.57016754, 21.76719475], [88.56981659, 21.7676506], [88.56954193, 21.7680912], [88.56935883, 21.76852417], [88.56915283, 21.7688694], [88.56900024, 21.76917839], [88.5692215, 21.76947594], [88.56943512, 21.76982117], [88.56961823, 21.77018166], [88.56990051, 21.77045059], [88.57028961, 21.77063942], [88.57065582, 21.77095985], [88.57109833, 21.77114105], [88.57150269, 21.77134323], [88.57194519, 21.77141953], [88.57235718, 21.77152824], [88.57279968, 21.77168274], [88.57325745, 21.77185822], [88.5736618, 21.77219963], [88.57413483, 21.77251625], [88.57454681, 21.77289009], [88.57492828, 21.77330399], [88.57538605, 21.77362061], [88.57581329, 21.77393913], [88.57619476, 21.77424622], [88.57653046, 21.77451134], [88.57666779, 21.77472115], [88.57749939, 21.77555466], [88.57749939, 21.77583122], [88.57777405, 21.7761116], [88.57833099, 21.77667046], [88.57861328, 21.77667046], [88.57888794, 21.77639008], [88.57907867, 21.77658081], [88.57974243, 21.77671432], [88.58026886, 21.77695084], [88.58065796, 21.77721977], [88.58110809, 21.77750015], [88.58139038, 21.77750015], [88.58167267, 21.77778053], [88.58222198, 21.77778053]]], [[[88.60972595, 21.79027939], [88.61000061, 21.79000092], [88.61165619, 21.79000092], [88.61194611, 21.78972054], [88.61194611, 21.78944206], [88.61222076, 21.7891674], [88.61332703, 21.78918076], [88.61360168, 21.78890991], [88.6138916, 21.78876114], [88.61416626, 21.78876495], [88.61555481, 21.78777695], [88.61554718, 21.78724098], [88.61679077, 21.7863903], [88.61723328, 21.78499985], [88.6166687, 21.78444481], [88.6166687, 21.78388977], [88.61723328, 21.78333092], [88.61750031, 21.78333282], [88.61805725, 21.78277969], [88.61833191, 21.78277969], [88.6194458, 21.78166962], [88.6194458, 21.78111076], [88.61972809, 21.78083038], [88.61982727, 21.78090096], [88.62004852, 21.78063965], [88.62026978, 21.7804184], [88.62043762, 21.78018188], [88.62055969, 21.77988052], [88.62055206, 21.77943993], [88.62055206, 21.77861023], [88.62082672, 21.77832985], [88.62083435, 21.77805328], [88.62110901, 21.77778053], [88.62110901, 21.77750015], [88.6213913, 21.77721977], [88.6213913, 21.77666664], [88.62166595, 21.77639008], [88.6217041, 21.77614784], [88.6222229, 21.77555275], [88.6222229, 21.77499962], [88.62249756, 21.77472115], [88.62249756, 21.77416611], [88.62333679, 21.7733326], [88.62333679, 21.77194405], [88.62361145, 21.77166748], [88.62361145, 21.77111053], [88.62388611, 21.77082825], [88.62388611, 21.76916885], [88.6241684, 21.76889038], [88.6241684, 21.76805115], [88.62444305, 21.7677784], [88.62444305, 21.76638985], [88.6241684, 21.76610947], [88.6241684, 21.7658329], [88.62388611, 21.76555443], [88.62388611, 21.76501083], [88.6241684, 21.76472092], [88.6241684, 21.76388931], [88.62444305, 21.76361084], [88.62444305, 21.76333046], [88.62472534, 21.7630558], [88.62473297, 21.76278114], [88.62526703, 21.76222038], [88.62527466, 21.76166725], [88.62536621, 21.76157761], [88.62555695, 21.76138878], [88.62555695, 21.76083183], [88.62611389, 21.7602787], [88.62610626, 21.76000023], [88.62638855, 21.75972176], [88.62638855, 21.75861168], [88.6269455, 21.75805473], [88.6269455, 21.75777817], [88.62722015, 21.75749969], [88.62722015, 21.75582123], [88.62750244, 21.75555611], [88.62775421, 21.75562286], [88.62805176, 21.75527763], [88.62832642, 21.75500107], [88.62832642, 21.75472069], [88.6286087, 21.75444412], [88.6286087, 21.75333595], [88.62889099, 21.75305748], [88.62889862, 21.75056076], [88.62917328, 21.75028038], [88.62917328, 21.7491703], [88.62889862, 21.74888992], [88.62889862, 21.74860954], [88.6286087, 21.74833107], [88.6297226, 21.7472229], [88.62976837, 21.74695587], [88.6297226, 21.74641991], [88.62973785, 21.74588013], [88.62982941, 21.74537468], [88.6300354, 21.74491692], [88.63031769, 21.74448967], [88.63059998, 21.74405289], [88.63076019, 21.74352837], [88.63083649, 21.74305916], [88.63083649, 21.74250031], [88.63054657, 21.74221992], [88.6305542, 21.74055672], [88.63027954, 21.74027824], [88.63027954, 21.73999977], [88.62999725, 21.73971939], [88.62999725, 21.73944664], [88.6297226, 21.73916435], [88.6297226, 21.73888969], [88.62889862, 21.73806953], [88.6288681, 21.73747063], [88.6286087, 21.73722267], [88.6286087, 21.73694229], [88.62833405, 21.73666573], [88.62832642, 21.73639107], [88.62805176, 21.73611069], [88.62805176, 21.73583031], [88.62722015, 21.73500061], [88.62722015, 21.73417282], [88.6277771, 21.73361015], [88.62750244, 21.73333359], [88.62750244, 21.73305511], [88.6277771, 21.73278046], [88.6277771, 21.73250008], [88.62750244, 21.7322216], [88.62750244, 21.73194504], [88.62722015, 21.73166656], [88.62722015, 21.73110962], [88.6269455, 21.73083305], [88.6269455, 21.73027992], [88.62638855, 21.72972107], [88.62638855, 21.72916794], [88.6258316, 21.72861099], [88.6258316, 21.72833061], [88.62555695, 21.72805786], [88.62555695, 21.72777939], [88.62526703, 21.72750092], [88.62526703, 21.72722054], [88.6241684, 21.72611046], [88.6241684, 21.72556114], [88.62388611, 21.72528076], [88.62388611, 21.72472], [88.62361145, 21.72444344], [88.62361145, 21.72417068], [88.62194824, 21.72249985], [88.62194824, 21.7219429], [88.6213913, 21.72138977], [88.6213913, 21.72110939], [88.6202774, 21.71999931], [88.6202774, 21.71943855], [88.62000275, 21.7191658], [88.62017822, 21.71891022], [88.61998749, 21.71845818], [88.61972809, 21.7180481], [88.61949158, 21.71766281], [88.6193161, 21.71727943], [88.61906433, 21.71700478], [88.61876678, 21.71680641], [88.61849213, 21.71656036], [88.61817932, 21.7163372], [88.617836, 21.71604919], [88.6174469, 21.71576309], [88.61709595, 21.71543312], [88.6167984, 21.71513176], [88.61654663, 21.71484947], [88.6163559, 21.71450043], [88.61613464, 21.71416855], [88.6158371, 21.7136097], [88.61416626, 21.71194649], [88.6138916, 21.71194649], [88.61333466, 21.71138954], [88.61277771, 21.71138954], [88.61194611, 21.71055984], [88.61194611, 21.71027946], [88.61110687, 21.70944023], [88.61083221, 21.70944214], [88.61000061, 21.70861053], [88.60972595, 21.70861053], [88.60916901, 21.70806122], [88.60888672, 21.7080555], [88.60861206, 21.70833206], [88.60832977, 21.70833015], [88.60778809, 21.70889282], [88.60749817, 21.70888901], [88.60666656, 21.70972252], [88.60639191, 21.70972061], [88.60610962, 21.71000099], [88.60527802, 21.71000099], [88.60500336, 21.70972061], [88.60472107, 21.70972252], [88.60444641, 21.70944214], [88.60414124, 21.70944786], [88.60382843, 21.70968819], [88.60356903, 21.70997047], [88.60331726, 21.71023941], [88.6030426, 21.7105751], [88.6027298, 21.71096992], [88.60232544, 21.71140862], [88.60197449, 21.71177292], [88.60188293, 21.71186829], [88.60135651, 21.71230125], [88.60079956, 21.71269035], [88.60022736, 21.71302032], [88.59971619, 21.71333122], [88.59889221, 21.71417046], [88.59889221, 21.71445084], [88.59857941, 21.71443939], [88.59860992, 21.71479988], [88.59867859, 21.71517181], [88.59884644, 21.71552277], [88.59912872, 21.71583748], [88.59944153, 21.71611023], [88.60083008, 21.71750069], [88.60111237, 21.71750069], [88.60138702, 21.71777916], [88.60166931, 21.71777725], [88.60221863, 21.7183342], [88.60333252, 21.71832848], [88.60360718, 21.71861076], [88.60415649, 21.71861076], [88.60444641, 21.71888924], [88.60500336, 21.71888924], [88.60527802, 21.71916962], [88.60583496, 21.7191658], [88.60639191, 21.71972275], [88.60778809, 21.71970749], [88.60806274, 21.72000122], [88.60832977, 21.72000122], [88.60861206, 21.72027969], [88.60888672, 21.72027969], [88.60916901, 21.72056007], [88.60972595, 21.72055626], [88.60990906, 21.72074127], [88.61000061, 21.72083282], [88.61055756, 21.72083282], [88.61083221, 21.7211113], [88.61110687, 21.72110939], [88.61138916, 21.72138977], [88.61165619, 21.72138977], [88.61194611, 21.72167015], [88.61222076, 21.72166634], [88.61250305, 21.72194481], [88.61277771, 21.72194481], [88.61305237, 21.72222137], [88.61332703, 21.72221947], [88.6138916, 21.72278023], [88.61416626, 21.72277832], [88.61444092, 21.72305489], [88.61472321, 21.72305489], [88.61499786, 21.72333336], [88.61555481, 21.72333336], [88.6158371, 21.72361183], [88.61611176, 21.72361183], [88.61624908, 21.72375107], [88.61638641, 21.7238903], [88.6166687, 21.7238903], [88.61694336, 21.72417068], [88.61723328, 21.72417068], [88.61805725, 21.72500038], [88.61833191, 21.72500038], [88.61860657, 21.72528076], [88.61888885, 21.72528076], [88.61915588, 21.72556114], [88.6194458, 21.72555351], [88.62083435, 21.72694588], [88.62082672, 21.72722054], [88.6213913, 21.72777939], [88.6213913, 21.72805786], [88.62166595, 21.72833061], [88.62166595, 21.72861099], [88.62194824, 21.72887993], [88.62194824, 21.72916794], [88.6222229, 21.7294445], [88.6222229, 21.72972107], [88.62249756, 21.72999954], [88.62249756, 21.73027992], [88.62277985, 21.73055649], [88.62277985, 21.73083305], [88.62304688, 21.73110962], [88.62304688, 21.73138809], [88.62333679, 21.73166656], [88.62333679, 21.73583031], [88.62304688, 21.73611069], [88.6230545, 21.73666573], [88.62277985, 21.73694229], [88.62277222, 21.73722076], [88.62249756, 21.73750114], [88.62249756, 21.73777962], [88.6222229, 21.73805428], [88.6222229, 21.73833084], [88.6213913, 21.73916435], [88.6213913, 21.7397213], [88.62000275, 21.74110985], [88.62000275, 21.74139023], [88.61972809, 21.74139023], [88.61750031, 21.74361038], [88.61650848, 21.74440956], [88.61507416, 21.74508095], [88.61250305, 21.74629021], [88.6102066, 21.74656105], [88.60791779, 21.74656105], [88.60591125, 21.74682999], [88.60404968, 21.74710083], [88.6030426, 21.74736977], [88.60240936, 21.74749947], [88.60189819, 21.74777031], [88.60136414, 21.74804497], [88.60083008, 21.74833107], [88.59916687, 21.75000954], [88.59889221, 21.75000954], [88.59860229, 21.75028038], [88.59805298, 21.75028038], [88.5976181, 21.75053024], [88.59712219, 21.75069046], [88.59667206, 21.75102997], [88.59623718, 21.75136948], [88.59577942, 21.75166321], [88.5953598, 21.75193024], [88.59494019, 21.75214958], [88.59449768, 21.75230026], [88.59407043, 21.75247192], [88.59360504, 21.75254631], [88.59320068, 21.75274086], [88.5927124, 21.75286102], [88.59220886, 21.75303268], [88.59164429, 21.75311661], [88.59114838, 21.75330353], [88.59065247, 21.75341034], [88.59021759, 21.75358772], [88.58979034, 21.75369835], [88.58938599, 21.75388527], [88.58895874, 21.75407028], [88.58847809, 21.75421715], [88.58803558, 21.75446129], [88.58763885, 21.75473022], [88.58729553, 21.75501823], [88.58701324, 21.75530243], [88.58679199, 21.75559998], [88.58661652, 21.75595093], [88.58640289, 21.75626945], [88.58625031, 21.75659752], [88.58635712, 21.75699997], [88.58638763, 21.75745964], [88.58638763, 21.75799179], [88.58642578, 21.75855255], [88.58661652, 21.75906944], [88.58666992, 21.75959969], [88.58672333, 21.76009178], [88.5868988, 21.76050377], [88.58696747, 21.76094818], [88.58708191, 21.76139069], [88.58722687, 21.76184273], [88.58737183, 21.76231003], [88.58750153, 21.76280975], [88.58763123, 21.76333046], [88.5877533, 21.76389122], [88.58777618, 21.76453781], [88.58779907, 21.76523972], [88.58790588, 21.76596069], [88.58803558, 21.76669312], [88.58808136, 21.76744461], [88.58816528, 21.76818275], [88.58808136, 21.76892281], [88.58802032, 21.76971054], [88.58786774, 21.77049065], [88.58782959, 21.77127457], [88.5880127, 21.77202988], [88.5880661, 21.77280998], [88.58817291, 21.77357101], [88.58830261, 21.77429962], [88.58833313, 21.7750206], [88.58837891, 21.77569008], [88.58856964, 21.77627373], [88.58865356, 21.77687454], [88.58883667, 21.77742195], [88.58893585, 21.77799988], [88.58912659, 21.7784996], [88.5891571, 21.77900124], [88.58917236, 21.77944946], [88.58922577, 21.77984047], [88.58940125, 21.78014565], [88.58952332, 21.78046227], [88.58972168, 21.78070068], [88.58992767, 21.78093529], [88.59004211, 21.78123093], [88.59020996, 21.78149033], [88.5903244, 21.78180122], [88.59052277, 21.78209114], [88.59066772, 21.78248024], [88.59091949, 21.78286934], [88.59120178, 21.78330994], [88.59153748, 21.78376007], [88.59189606, 21.78423119], [88.59221649, 21.78473091], [88.59259033, 21.7851963], [88.59272766, 21.78530121], [88.59305573, 21.78555489], [88.59333038, 21.78555489], [88.59388733, 21.78611183], [88.59416962, 21.7863903], [88.59443665, 21.7863903], [88.59500122, 21.78695107], [88.59555817, 21.78694534], [88.59583282, 21.78722191], [88.59638977, 21.78722191], [88.5966568, 21.78750038], [88.59694672, 21.78750038], [88.59749603, 21.78806114], [88.59777832, 21.78805542], [88.59805298, 21.78833389], [88.5983429, 21.78833008], [88.59860229, 21.78861046], [88.59889221, 21.78861046], [88.59916687, 21.78889084], [88.59971619, 21.78889084], [88.59999847, 21.78918076], [88.60111237, 21.7891674], [88.60166931, 21.78972244], [88.60250092, 21.78972244], [88.60277557, 21.78944206], [88.60444641, 21.78944206], [88.60472107, 21.78972244], [88.60610962, 21.78972054], [88.60639191, 21.79000092], [88.60943604, 21.79000092], [88.60972595, 21.79027939]]], [[[88.38490295, 21.76444054], [88.38545227, 21.76416016], [88.38599396, 21.7638607], [88.38643646, 21.7634697], [88.38671112, 21.7630806], [88.38703156, 21.76280975], [88.38729858, 21.7625351], [88.38772583, 21.76235962], [88.38822937, 21.76209068], [88.38868713, 21.76172066], [88.38918304, 21.76136971], [88.3900528, 21.76025009], [88.39032745, 21.75863838], [88.39004517, 21.75734138], [88.38961792, 21.75541115], [88.38903809, 21.75258827], [88.38846588, 21.74895287], [88.38818359, 21.74720764], [88.38788605, 21.74478912], [88.38774872, 21.74385071], [88.38775635, 21.74343109], [88.38755035, 21.74290085], [88.38743591, 21.74233055], [88.38720703, 21.74180031], [88.38694763, 21.74126053], [88.38669586, 21.74067879], [88.38639069, 21.74055099], [88.38609314, 21.74000931], [88.38500977, 21.73861122], [88.38444519, 21.73861122], [88.3841629, 21.73833275], [88.38361359, 21.73833275], [88.3833313, 21.73805428], [88.38276672, 21.73806953], [88.38249969, 21.73777962], [88.38166809, 21.73777962], [88.38108826, 21.73722076], [88.37999725, 21.73722267], [88.37950897, 21.73730278], [88.3789444, 21.73715591], [88.37843323, 21.73722649], [88.37789917, 21.7373848], [88.37741089, 21.7376194], [88.37689972, 21.73771095], [88.37631989, 21.73759079], [88.37573242, 21.7376194], [88.37550354, 21.73756981], [88.37528229, 21.73752213], [88.37483215, 21.73746109], [88.37473297, 21.73750114], [88.37444305, 21.73722076], [88.3741684, 21.73722267], [88.37388611, 21.73694229], [88.37249756, 21.73694229], [88.37194824, 21.73638916], [88.37166595, 21.73639107], [88.37110901, 21.73583031], [88.37083435, 21.73583221], [88.37055206, 21.73555565], [88.37001038, 21.73555946], [88.36831665, 21.73455811], [88.36818695, 21.73443604], [88.36805725, 21.73428917], [88.36777496, 21.73388863], [88.36750031, 21.73361015], [88.36722565, 21.73361015], [88.36694336, 21.73333359], [88.3666687, 21.73333359], [88.36638641, 21.73305511], [88.36611176, 21.73306274], [88.36499786, 21.732481], [88.36486053, 21.73219681], [88.36430359, 21.73219681], [88.36420441, 21.73182106], [88.36416626, 21.73166656], [88.3638916, 21.73166656], [88.36356354, 21.73199463], [88.36333466, 21.7322216], [88.36305237, 21.7322216], [88.36291504, 21.73207855], [88.36239624, 21.73232651], [88.36190796, 21.73269844], [88.36151123, 21.73308945], [88.36123657, 21.7335701], [88.36107635, 21.73411942], [88.36099243, 21.73472023], [88.3610611, 21.73530769], [88.36112976, 21.73587036], [88.36119843, 21.7364006], [88.36135864, 21.73682785], [88.36151886, 21.73726273], [88.36166382, 21.7377224], [88.36180115, 21.73821449], [88.36190796, 21.7387619], [88.36194611, 21.73936081], [88.36196136, 21.73999023], [88.36194611, 21.74060059], [88.3618927, 21.74115944], [88.36174011, 21.74166107], [88.36161041, 21.74215508], [88.36142731, 21.74269104], [88.36125946, 21.74332047], [88.36109161, 21.74395752], [88.36099243, 21.74438095], [88.36093903, 21.74460983], [88.36090088, 21.74528885], [88.36096954, 21.74594116], [88.36110687, 21.74657822], [88.36125946, 21.74716949], [88.36151886, 21.74765968], [88.36183167, 21.74809074], [88.36222839, 21.74843025], [88.36264801, 21.74879074], [88.36305237, 21.7491703], [88.36333466, 21.74916649], [88.3637085, 21.74954033], [88.36611176, 21.75194359], [88.36611176, 21.75222015], [88.36638641, 21.75250053], [88.36670685, 21.75279045], [88.36695862, 21.75307846], [88.36711121, 21.75335121], [88.36712646, 21.75362015], [88.36708069, 21.7539196], [88.36705017, 21.75428009], [88.36709595, 21.75472069], [88.36721039, 21.75524521], [88.36738586, 21.75579262], [88.36767578, 21.75626945], [88.36804199, 21.75662994], [88.36841583, 21.7569294], [88.36882782, 21.75715065], [88.36929321, 21.75735092], [88.36981201, 21.75758171], [88.37033081, 21.75791931], [88.37077332, 21.75839615], [88.3709259, 21.75859642], [88.37116241, 21.75889969], [88.371521, 21.75934982], [88.37172699, 21.75976944], [88.37188721, 21.7602272], [88.37193298, 21.76079369], [88.37193298, 21.76148033], [88.37198639, 21.76217079], [88.37223053, 21.76263618], [88.37254333, 21.76308823], [88.37281799, 21.76360893], [88.37384796, 21.76394272], [88.37425232, 21.7644043], [88.37457275, 21.76436043], [88.37482452, 21.76467514], [88.37525177, 21.76474953], [88.37560272, 21.76490974], [88.37593842, 21.76517868], [88.37639618, 21.76548004], [88.37700653, 21.76565933], [88.37755585, 21.76584053], [88.37806702, 21.7660408], [88.37860107, 21.76622963], [88.3791275, 21.76643181], [88.37966156, 21.76667976], [88.38021088, 21.76695061], [88.38082123, 21.76715088], [88.38152313, 21.76703072], [88.3821106, 21.76660538], [88.38260651, 21.76608276], [88.38323975, 21.7656498], [88.38343811, 21.76549339], [88.38381958, 21.76519394], [88.38433075, 21.76473045], [88.38490295, 21.76444054]]], [[[88.45861053, 21.78865051], [88.45910645, 21.78864861], [88.45952606, 21.78878975], [88.45995331, 21.78893089], [88.46047974, 21.78868294], [88.4609375, 21.78853989], [88.46128845, 21.78862572], [88.46155548, 21.78879356], [88.46195221, 21.78887367], [88.46269989, 21.78876114], [88.46326447, 21.78888702], [88.46378326, 21.78911972], [88.46421814, 21.7894783], [88.46463776, 21.78981972], [88.46499634, 21.7902298], [88.46531677, 21.79066086], [88.46557617, 21.79120064], [88.46586609, 21.79171181], [88.46613312, 21.79220772], [88.46639252, 21.79265976], [88.46668243, 21.79304123], [88.46707916, 21.79328537], [88.46759033, 21.79342842], [88.46816254, 21.7936306], [88.46875763, 21.79388046], [88.4693985, 21.79401016], [88.47007751, 21.79371262], [88.47077179, 21.79364014], [88.47143555, 21.79357147], [88.47194672, 21.79333305], [88.47222137, 21.79361153], [88.47250366, 21.79333305], [88.47277832, 21.79333305], [88.47360992, 21.79249954], [88.47389221, 21.79249954], [88.47499847, 21.79138947], [88.47499847, 21.78806114], [88.47444153, 21.78750038], [88.47444153, 21.78722191], [88.47389221, 21.78666687], [88.47389221, 21.78583145], [88.47360992, 21.78555489], [88.47360992, 21.78499985], [88.4733429, 21.78471756], [88.47333527, 21.7836113], [88.47277832, 21.78305626], [88.47277832, 21.78222275], [88.47250366, 21.78194427], [88.47250366, 21.78111076], [88.4716568, 21.78055954], [88.47249603, 21.77972031], [88.47222137, 21.77944374], [88.47222137, 21.77901077], [88.47220612, 21.77860069], [88.47219086, 21.77816963], [88.47200775, 21.77775955], [88.47175598, 21.77734947], [88.47141266, 21.77697754], [88.47111511, 21.77655411], [88.47086334, 21.77610016], [88.47072601, 21.77560043], [88.47059631, 21.77513123], [88.47055817, 21.77463913], [88.47054291, 21.7741394], [88.47045135, 21.77363014], [88.47029877, 21.77310753], [88.470047, 21.77265739], [88.47000122, 21.77213097], [88.47003174, 21.77156067], [88.4702301, 21.77099037], [88.47026062, 21.7704258], [88.47020721, 21.76986122], [88.47039795, 21.76926041], [88.47009277, 21.76865005], [88.46996307, 21.76806831], [88.46976471, 21.76760483], [88.46973419, 21.76712608], [88.46977234, 21.7666111], [88.4697876, 21.76605034], [88.46971893, 21.76548004], [88.46958923, 21.76490021], [88.46946716, 21.76432037], [88.46943665, 21.76371765], [88.46940613, 21.76308823], [88.46943665, 21.76240921], [88.46943665, 21.76171112], [88.46944427, 21.76100922], [88.46943665, 21.76029968], [88.46943665, 21.75959015], [88.46943665, 21.75887108], [88.4693985, 21.75814056], [88.4691925, 21.75741959], [88.46910095, 21.75671005], [88.46894073, 21.75601006], [88.46888733, 21.75528908], [88.46888733, 21.75457001], [88.46892548, 21.75390816], [88.46916962, 21.75333023], [88.46916962, 21.75277519], [88.46861267, 21.75278091], [88.46806335, 21.75222015], [88.46805573, 21.75027847], [88.46749878, 21.74971962], [88.46749878, 21.74944305], [88.46721649, 21.7491703], [88.46721649, 21.74806023], [88.46666718, 21.74749947], [88.46639252, 21.74749947], [88.46639252, 21.74332809], [88.46583557, 21.74277878], [88.46721649, 21.74139023], [88.46721649, 21.74110985], [88.46731567, 21.74108696], [88.46723175, 21.74067307], [88.46721649, 21.74034119], [88.46721649, 21.74001122], [88.46721649, 21.73962975], [88.46721649, 21.73916054], [88.46721649, 21.73861122], [88.46721649, 21.73722076], [88.46666718, 21.73666573], [88.46666718, 21.73583031], [88.46639252, 21.73555565], [88.46639252, 21.73500061], [88.46527863, 21.73389053], [88.46527863, 21.73361015], [88.46499634, 21.73333359], [88.46499634, 21.73305511], [88.46444702, 21.73250008], [88.46444702, 21.73193932], [88.46416473, 21.73166656], [88.4641571, 21.73138809], [88.46389008, 21.73110962], [88.46389008, 21.73083305], [88.46333313, 21.73027992], [88.46333313, 21.72999954], [88.46305847, 21.72972107], [88.46305847, 21.7294445], [88.46277618, 21.72916794], [88.46277618, 21.72887993], [88.46250153, 21.72861099], [88.46250153, 21.72833061], [88.46221924, 21.72805786], [88.46221924, 21.72777939], [88.46193695, 21.72750092], [88.46193695, 21.72722054], [88.46083069, 21.72611046], [88.45889282, 21.72611046], [88.45861053, 21.72639084], [88.45805359, 21.72638893], [88.45749664, 21.72694588], [88.45713043, 21.72657394], [88.45694733, 21.72638893], [88.45694733, 21.72583961], [88.45729065, 21.72546005], [88.45742035, 21.72499084], [88.45735931, 21.72457123], [88.45729065, 21.72416115], [88.45722961, 21.72360992], [88.45722198, 21.72305489], [88.45694733, 21.72277832], [88.45694733, 21.72249985], [88.45667267, 21.72221947], [88.45666504, 21.72194481], [88.45639038, 21.72194481], [88.45639038, 21.72083282], [88.45666504, 21.72055626], [88.45667267, 21.72000122], [88.45639038, 21.71970749], [88.45639038, 21.71888924], [88.45610809, 21.71861076], [88.45610809, 21.71832848], [88.45639038, 21.71805573], [88.45641327, 21.71731949], [88.45683289, 21.71674156], [88.45664978, 21.71618271], [88.45648193, 21.71556664], [88.45646667, 21.71484947], [88.45661926, 21.71412277], [88.45665741, 21.7134285], [88.45659637, 21.71281242], [88.45641327, 21.71228218], [88.45620728, 21.71180344], [88.45591736, 21.71141815], [88.45554352, 21.71112251], [88.45506287, 21.71091461], [88.45440674, 21.71086502], [88.45366669, 21.71088982], [88.45291901, 21.71082115], [88.45215607, 21.71076012], [88.45145416, 21.71070862], [88.45102692, 21.71066856], [88.45090485, 21.71065712], [88.45036316, 21.71058083], [88.44966125, 21.71051407], [88.44893646, 21.71044159], [88.44850159, 21.71038055], [88.44391632, 21.70998192], [88.44148254, 21.70984077], [88.43990326, 21.70930481], [88.44000244, 21.70916748], [88.43955231, 21.7091198], [88.43911743, 21.70888519], [88.43869019, 21.70868111], [88.43824768, 21.70850945], [88.43781281, 21.70829964], [88.43735504, 21.70810318], [88.4369812, 21.7078476], [88.43662262, 21.70757294], [88.43622589, 21.70730019], [88.4358902, 21.70697021], [88.43558502, 21.70661163], [88.43527222, 21.70624924], [88.43489838, 21.70590019], [88.43444824, 21.70555878], [88.43395996, 21.70518112], [88.43353271, 21.70469093], [88.43313599, 21.70448112], [88.43281555, 21.7046299], [88.43247986, 21.70500374], [88.43209076, 21.70524406], [88.43157196, 21.70543289], [88.43122864, 21.70581818], [88.43106842, 21.70646286], [88.43065643, 21.70703125], [88.43083191, 21.70757294], [88.43093872, 21.70819283], [88.43081665, 21.70876122], [88.43060303, 21.70927048], [88.43044281, 21.7097702], [88.4302597, 21.71023941], [88.43003845, 21.71064949], [88.42984772, 21.71106529], [88.42955017, 21.71139336], [88.42925262, 21.71169853], [88.42900848, 21.71208572], [88.42870331, 21.71241379], [88.42842102, 21.71279907], [88.42813873, 21.71325111], [88.42780304, 21.71369743], [88.4274826, 21.71416283], [88.42711639, 21.71457291], [88.42692566, 21.7149868], [88.42687988, 21.71509171], [88.42675781, 21.71570778], [88.426651, 21.71636009], [88.42645264, 21.71706009], [88.42642975, 21.71776962], [88.4265976, 21.7184906], [88.42665863, 21.71920967], [88.42666626, 21.71989441], [88.42669678, 21.72050095], [88.42687988, 21.72096062], [88.42698669, 21.72140121], [88.42719269, 21.72170067], [88.42733002, 21.72203827], [88.42751312, 21.72232246], [88.42772675, 21.72258949], [88.42790985, 21.72290993], [88.42806244, 21.72323227], [88.42823792, 21.72354126], [88.42838287, 21.72392082], [88.42858124, 21.72426987], [88.42870331, 21.72467995], [88.42884827, 21.72507095], [88.42896271, 21.72544861], [88.4296875, 21.72642899], [88.42942047, 21.72830009], [88.42868805, 21.73021126], [88.42804718, 21.73238945], [88.42780304, 21.73284149], [88.42764282, 21.7333107], [88.42746735, 21.73372078], [88.42723846, 21.73404121], [88.42700958, 21.73438072], [88.42671967, 21.73475647], [88.42639923, 21.73523331], [88.4260788, 21.73583221], [88.42566681, 21.73641968], [88.42530823, 21.73707771], [88.42511749, 21.73756409], [88.42502594, 21.73779106], [88.42488098, 21.73854828], [88.42464447, 21.73923111], [88.42435455, 21.73980141], [88.42405701, 21.74026489], [88.42376709, 21.74069023], [88.42359924, 21.74123001], [88.42344666, 21.74178314], [88.42357635, 21.74234009], [88.42362213, 21.74291039], [88.42371368, 21.74341393], [88.42385101, 21.74373245], [88.42388153, 21.74381065], [88.42401123, 21.74418831], [88.42405701, 21.74460983], [88.42455292, 21.74496078], [88.42450714, 21.74535179], [88.42478943, 21.74620056], [88.42517853, 21.74657059], [88.42553711, 21.74706078], [88.42602539, 21.74779892], [88.42603302, 21.74830055], [88.42611694, 21.74897003], [88.42636871, 21.74949074], [88.42655945, 21.75000954], [88.42669678, 21.75049973], [88.42684174, 21.75096703], [88.42692566, 21.75142479], [88.42693329, 21.75188065], [88.42694855, 21.75232697], [88.42694092, 21.75277138], [88.42690277, 21.75323105], [88.42684174, 21.75372124], [88.42682648, 21.75420189], [88.42681885, 21.75467873], [88.42682648, 21.75506973], [88.42669678, 21.75541115], [88.426651, 21.75576019], [88.42655182, 21.75607681], [88.42643738, 21.75634956], [88.42623901, 21.75656891], [88.42614746, 21.75683975], [88.42610168, 21.75716591], [88.42604828, 21.75734711], [88.42601013, 21.75746155], [88.4258728, 21.75773048], [88.42578888, 21.75806808], [88.42559052, 21.75836945], [88.42549133, 21.75876045], [88.4253006, 21.75913048], [88.42516327, 21.75955963], [88.42501068, 21.76002121], [88.42488861, 21.76052094], [88.42471313, 21.76099968], [88.4243927, 21.76143837], [88.42402649, 21.76193237], [88.42401123, 21.76243973], [88.42362976, 21.76301956], [88.42359161, 21.76356506], [88.42351532, 21.76405334], [88.4234314, 21.76449013], [88.42334747, 21.76492119], [88.4233017, 21.76536369], [88.42314148, 21.76576424], [88.42310333, 21.76616287], [88.42327118, 21.76663971], [88.42331696, 21.76716042], [88.42336273, 21.76772499], [88.42354584, 21.76827049], [88.42381287, 21.76879311], [88.42417908, 21.76922989], [88.42459869, 21.76960945], [88.42508698, 21.76997948], [88.42560577, 21.77032089], [88.42614746, 21.77065277], [88.426651, 21.77097702], [88.42710876, 21.77131462], [88.42753601, 21.77168274], [88.42806244, 21.7719593], [88.42861938, 21.77223015], [88.42917633, 21.77252579], [88.42971039, 21.77285194], [88.43017578, 21.77316093], [88.43058777, 21.7734127], [88.43087769, 21.77366829], [88.43115234, 21.77386093], [88.43143463, 21.77397919], [88.43167114, 21.77417946], [88.4319458, 21.77440071], [88.43239594, 21.77449036], [88.43282318, 21.77472115], [88.43328857, 21.7749958], [88.43379974, 21.77528], [88.43431091, 21.7756176], [88.43470764, 21.7761116], [88.43501282, 21.7767086], [88.43527985, 21.77682114], [88.43563843, 21.77682114], [88.43599701, 21.77701759], [88.4362793, 21.77734947], [88.43663788, 21.77769279], [88.4369278, 21.77802658], [88.43706512, 21.77836227], [88.43740845, 21.77876091], [88.43808746, 21.77947807], [88.43842316, 21.77993011], [88.43878937, 21.78034973], [88.43902588, 21.78083992], [88.43921661, 21.78136063], [88.4393692, 21.78187943], [88.43950653, 21.78237915], [88.43972778, 21.78284073], [88.43994141, 21.78326035], [88.44019318, 21.78357697], [88.44033813, 21.78392029], [88.44051361, 21.78430748], [88.44061279, 21.78474998], [88.44082642, 21.78513908], [88.44106293, 21.78553009], [88.44122314, 21.78596115], [88.44136047, 21.78642082], [88.44136047, 21.78691101], [88.44127655, 21.78743172], [88.44143677, 21.78793716], [88.44165039, 21.78846169], [88.44180298, 21.78900909], [88.4418869, 21.78959084], [88.44194031, 21.79020119], [88.44194031, 21.79079819], [88.44197845, 21.79138947], [88.44215393, 21.79190636], [88.44225311, 21.79247475], [88.44243622, 21.79302406], [88.44254303, 21.79360008], [88.44277191, 21.79408073], [88.44301605, 21.79453087], [88.44320679, 21.79499054], [88.44341278, 21.79547119], [88.4437561, 21.79588127], [88.44410706, 21.79635048], [88.4446106, 21.79674911], [88.44506073, 21.79720879], [88.44554901, 21.79761124], [88.44603729, 21.79795837], [88.44658661, 21.79816246], [88.44689941, 21.79830742], [88.44709778, 21.79840088], [88.4474411, 21.79839325], [88.44766998, 21.79838943], [88.44824982, 21.79822731], [88.44876862, 21.79787064], [88.44915009, 21.79740524], [88.44943237, 21.79692078], [88.44967651, 21.7964592], [88.4499588, 21.79604912], [88.45020294, 21.79564095], [88.45044708, 21.79525948], [88.45069122, 21.79486275], [88.45093536, 21.79445457], [88.45121765, 21.79405022], [88.45150757, 21.7936554], [88.45188141, 21.79333115], [88.45226288, 21.79301071], [88.45259094, 21.79263115], [88.45282745, 21.79217911], [88.45311737, 21.79174995], [88.45349884, 21.7913475], [88.45391846, 21.7909565], [88.45440674, 21.79058838], [88.4549408, 21.7902813], [88.45545197, 21.7899971], [88.45593262, 21.78972054], [88.45639801, 21.78944016], [88.45689392, 21.78917313], [88.45745087, 21.7889595], [88.45807648, 21.78883743], [88.45861053, 21.78865051]]], [[[88.28279114, 21.76501083], [88.28250122, 21.76501083], [88.28250122, 21.76527786], [88.28056335, 21.76721954], [88.28083038, 21.76749992], [88.28083038, 21.76805687], [88.27916718, 21.76972198], [88.28055573, 21.76972198], [88.28111267, 21.76944351], [88.28194427, 21.76861191], [88.28166962, 21.76833344], [88.28250122, 21.76749992], [88.28250122, 21.76721954], [88.28221893, 21.76694679], [88.28277588, 21.76638794], [88.28279114, 21.76610947], [88.28305817, 21.7658329], [88.28305817, 21.76555443], [88.28279114, 21.76527977], [88.28279114, 21.76501083]]], [[[88.78749847, 21.74500084], [88.78694153, 21.74443817], [88.78666687, 21.74444389], [88.78610992, 21.74389076], [88.78583527, 21.74389076], [88.78444672, 21.74250031], [88.78444672, 21.74221992], [88.78388977, 21.7416687], [88.78388977, 21.74081993], [88.78360748, 21.74055672], [88.78388977, 21.74027824], [88.78388977, 21.73944092], [88.78416443, 21.73916435], [88.7841568, 21.73888969], [88.78527069, 21.73777962], [88.78610992, 21.73777962], [88.78694153, 21.73694038], [88.78639221, 21.73638916], [88.78621674, 21.73612022], [88.78592682, 21.73594093], [88.78547668, 21.73575974], [88.78498077, 21.73555183], [88.78446198, 21.73533058], [88.78383636, 21.73526192], [88.78320313, 21.73514938], [88.78256989, 21.73497963], [88.78210449, 21.73478317], [88.78197479, 21.73472786], [88.78143311, 21.73444939], [88.78089905, 21.73414993], [88.78047943, 21.73382759], [88.78000641, 21.7335701], [88.77954102, 21.73331833], [88.77908325, 21.73303986], [88.77866364, 21.73270416], [88.77828979, 21.7322979], [88.77787781, 21.73191071], [88.77767181, 21.73168945], [88.77746582, 21.73146629], [88.77690887, 21.73109055], [88.77666473, 21.73084641], [88.77635956, 21.73085022], [88.77598572, 21.73096085], [88.77561951, 21.73111916], [88.77528381, 21.73135757], [88.77489471, 21.73150444], [88.77451324, 21.73167038], [88.77410889, 21.73186111], [88.77365875, 21.7319355], [88.77318573, 21.73195267], [88.77269745, 21.73194695], [88.77220154, 21.73194504], [88.771698, 21.73194313], [88.7711792, 21.73194504], [88.77065277, 21.73199081], [88.7701416, 21.73219109], [88.76957703, 21.73236084], [88.76899719, 21.73247719], [88.76842499, 21.73250008], [88.76786804, 21.73250008], [88.76733398, 21.73250008], [88.76680756, 21.73245811], [88.76634216, 21.73223114], [88.76584625, 21.73204041], [88.76528168, 21.73215675], [88.76475525, 21.73219299], [88.76432037, 21.73228073], [88.76390076, 21.73246002], [88.76365662, 21.73248482], [88.76346588, 21.73250389], [88.76302338, 21.73256302], [88.76259613, 21.7327404], [88.76211548, 21.73279762], [88.7616806, 21.73291016], [88.76126862, 21.73303032], [88.76082611, 21.73306274], [88.76039124, 21.73306274], [88.75991821, 21.73306274], [88.75940704, 21.73306274], [88.75885773, 21.73307991], [88.75830841, 21.73322105], [88.75772858, 21.73331833], [88.75715637, 21.73335075], [88.75666046, 21.73340988], [88.75631714, 21.73374176], [88.756073, 21.73409271], [88.75583649, 21.73439026], [88.75563812, 21.73468018], [88.75556946, 21.73502541], [88.75550079, 21.7354126], [88.75531769, 21.73579979], [88.75527191, 21.73631287], [88.75519562, 21.73687553], [88.75502777, 21.73746109], [88.75492096, 21.73810959], [88.75475311, 21.73869514], [88.75470734, 21.73924065], [88.7546463, 21.7397728], [88.75450897, 21.74030685], [88.7545166, 21.74088478], [88.75450134, 21.74144173], [88.75443268, 21.74196434], [88.75431061, 21.74245262], [88.75422668, 21.74293327], [88.75435638, 21.74341965], [88.7544632, 21.74394035], [88.75460052, 21.74446106], [88.75473022, 21.74496841], [88.75488281, 21.74542236], [88.75502014, 21.74579048], [88.75520325, 21.74606133], [88.7552948, 21.74638176], [88.75541687, 21.74666405], [88.7555542, 21.74694252], [88.75570679, 21.74723053], [88.75584412, 21.74759865], [88.75601959, 21.74799156], [88.75613403, 21.74847221], [88.75631714, 21.74897003], [88.75649261, 21.74950981], [88.75676727, 21.74995995], [88.75712585, 21.75033951], [88.75743103, 21.75076294], [88.75773621, 21.75118065], [88.75801849, 21.75161552], [88.75839233, 21.75200462], [88.75879669, 21.75239944], [88.75927734, 21.75279808], [88.75977325, 21.75322723], [88.76035309, 21.75358009], [88.76094818, 21.75389099], [88.76148987, 21.75418854], [88.76190948, 21.75455284], [88.76222229, 21.75493813], [88.76249695, 21.75530243], [88.76277161, 21.75562668], [88.76277924, 21.75582123], [88.76304626, 21.75611115], [88.76305389, 21.75666618], [88.76333618, 21.75694466], [88.76361084, 21.75694466], [88.76353455, 21.75713539], [88.76381683, 21.75740051], [88.76423645, 21.75821114], [88.76438904, 21.7592907], [88.76438904, 21.76049995], [88.76396179, 21.7622509], [88.76249695, 21.76361084], [88.76194763, 21.76416969], [88.76159668, 21.76474571], [88.76107788, 21.76503944], [88.76062012, 21.76535034], [88.76026154, 21.76571274], [88.75997162, 21.76605988], [88.75951385, 21.7661953], [88.7590332, 21.76638985], [88.75849915, 21.7666111], [88.75786591, 21.76670265], [88.75727844, 21.76690865], [88.7566452, 21.7670002], [88.75627899, 21.76712799], [88.756073, 21.76720047], [88.75547791, 21.76731682], [88.75493622, 21.76746941], [88.7543869, 21.76754951], [88.75388336, 21.76774025], [88.75332642, 21.76778984], [88.75280762, 21.76789284], [88.75231934, 21.76806259], [88.75183868, 21.76826286], [88.75130463, 21.76837158], [88.75081635, 21.76860809], [88.75034332, 21.76889992], [88.74994659, 21.76923752], [88.74975586, 21.76964951], [88.74984741, 21.77011108], [88.75011444, 21.77049065], [88.75054169, 21.77077293], [88.7509613, 21.77108955], [88.75139618, 21.77139091], [88.75183105, 21.77170944], [88.75218964, 21.77210045], [88.75253296, 21.77252007], [88.75285339, 21.77290916], [88.75328064, 21.77313995], [88.75369263, 21.77337074], [88.75409698, 21.77362061], [88.7545166, 21.77390289], [88.75493622, 21.77424049], [88.75531006, 21.77463913], [88.75569153, 21.7750206], [88.75598145, 21.77544022], [88.75617218, 21.77588081], [88.7563858, 21.77620125], [88.75662231, 21.77645111], [88.75681305, 21.77668953], [88.75697327, 21.77696037], [88.75721741, 21.77724075], [88.75749207, 21.77754974], [88.75778198, 21.77791023], [88.75810242, 21.77827072], [88.758461, 21.77860641], [88.75881958, 21.77893257], [88.75914001, 21.77930069], [88.75944519, 21.77969742], [88.75984192, 21.77999115], [88.76026917, 21.78028107], [88.76069641, 21.78055954], [88.7611618, 21.78084755], [88.76161194, 21.7811985], [88.76204681, 21.78162956], [88.76255035, 21.78204536], [88.76304626, 21.78250122], [88.7635498, 21.78297806], [88.76407623, 21.78339958], [88.76452637, 21.78388977], [88.76493835, 21.78439522], [88.76526642, 21.78494263], [88.76555634, 21.78549194], [88.76583862, 21.78598976], [88.76611328, 21.78641891], [88.76637268, 21.78679085], [88.76657867, 21.78715515], [88.76670074, 21.78755951], [88.76692963, 21.78794861], [88.76715088, 21.78837967], [88.76734161, 21.78889084], [88.76754761, 21.78941917], [88.76777649, 21.78993988], [88.76799774, 21.79044914], [88.76806641, 21.79098511], [88.76811218, 21.79148102], [88.76821899, 21.79191971], [88.76831818, 21.79230118], [88.76835632, 21.79265976], [88.76837921, 21.79300117], [88.76856232, 21.79331017], [88.76870728, 21.79367065], [88.76879883, 21.79412651], [88.76872253, 21.7946949], [88.76893616, 21.79518318], [88.76917267, 21.79566193], [88.76940155, 21.79614067], [88.7694931, 21.79668236], [88.76969147, 21.79713631], [88.76984406, 21.79762077], [88.7700119, 21.79808998], [88.77021027, 21.79854965], [88.77039337, 21.79900551], [88.77057648, 21.79945374], [88.77082825, 21.79985046], [88.77109528, 21.80025864], [88.77139282, 21.80067825], [88.77166748, 21.80113983], [88.77197266, 21.8015976], [88.77211761, 21.80178261], [88.77230072, 21.80202293], [88.77264404, 21.80237007], [88.77297211, 21.80270386], [88.77324677, 21.80303955], [88.77355957, 21.80335808], [88.77381897, 21.80369949], [88.77398682, 21.80412102], [88.7742157, 21.80448723], [88.77445984, 21.80485153], [88.77472687, 21.8051796], [88.77500916, 21.80550003], [88.77526093, 21.80578995], [88.77542114, 21.80610085], [88.77557373, 21.80638885], [88.77576447, 21.80662155], [88.77586365, 21.80692482], [88.77603912, 21.80718422], [88.77614594, 21.8075428], [88.77632141, 21.8079052], [88.77639771, 21.8083744], [88.77648163, 21.80887032], [88.77658081, 21.80937958], [88.77667236, 21.80986023], [88.77677155, 21.81030273], [88.77681732, 21.81072807], [88.77677917, 21.81116104], [88.77667999, 21.81158829], [88.77666473, 21.8120575], [88.7766571, 21.81249046], [88.7766037, 21.81288528], [88.77643585, 21.81323814], [88.77640533, 21.81361771], [88.77639008, 21.81403351], [88.77639008, 21.81450081], [88.7763443, 21.81505775], [88.77614594, 21.81562042], [88.77616119, 21.81619072], [88.77638245, 21.81666946], [88.77662659, 21.81707954], [88.7767868, 21.81745911], [88.77700043, 21.8177681], [88.77723694, 21.8180809], [88.77749634, 21.81849098], [88.77781677, 21.81898689], [88.77823639, 21.81945038], [88.77865601, 21.81996155], [88.77900696, 21.82040977], [88.77928162, 21.82084084], [88.77947998, 21.82127953], [88.77968597, 21.82172012], [88.77976227, 21.82228088], [88.77997589, 21.82286072], [88.78016663, 21.82348061], [88.78044128, 21.82402992], [88.78082275, 21.82443047], [88.78124237, 21.82473183], [88.78166199, 21.82500267], [88.78210449, 21.82519341], [88.78279114, 21.82501221], [88.78338623, 21.82481575], [88.78391266, 21.8246727], [88.78437805, 21.82446671], [88.78489685, 21.82422829], [88.7853775, 21.82384109], [88.78585052, 21.82337379], [88.78630066, 21.82290077], [88.78663635, 21.82242012], [88.78690338, 21.8220005], [88.78708649, 21.821661], [88.78723907, 21.82135963], [88.7873764, 21.82107162], [88.7875061, 21.82075882], [88.7876358, 21.82040977], [88.78775024, 21.82002831], [88.78782654, 21.8196106], [88.7879715, 21.81921959], [88.78804779, 21.81880951], [88.78807068, 21.81838989], [88.78813934, 21.81801033], [88.78829956, 21.81767082], [88.78843689, 21.81727982], [88.78861237, 21.81686974], [88.78881073, 21.81644821], [88.78900909, 21.81600952], [88.78926086, 21.81563568], [88.78957367, 21.81532478], [88.78990936, 21.81506729], [88.79020691, 21.81476974], [88.79049683, 21.81442833], [88.79078674, 21.81406021], [88.79110718, 21.81365967], [88.79146576, 21.81329536], [88.79177856, 21.81290054], [88.79202271, 21.81246948], [88.79229736, 21.81211853], [88.7925415, 21.81175041], [88.79279327, 21.81137085], [88.79304504, 21.81101227], [88.79323578, 21.81062126], [88.79338837, 21.81018066], [88.79355621, 21.80974007], [88.79360199, 21.8092308], [88.79361725, 21.80869865], [88.79366302, 21.80814934], [88.79377747, 21.80760193], [88.79389191, 21.80750084], [88.79389191, 21.80611038], [88.79416656, 21.80583], [88.79416656, 21.8022213], [88.79411316, 21.80160713], [88.79390717, 21.80108833], [88.79376221, 21.80060196], [88.79356384, 21.8002224], [88.79332733, 21.79993248], [88.79302979, 21.79969025], [88.79264832, 21.79949951], [88.79213715, 21.79940033], [88.79165649, 21.79920959], [88.79110718, 21.79912949], [88.79059601, 21.79891968], [88.79004669, 21.79883385], [88.7895813, 21.79863739], [88.78910065, 21.79851532], [88.78869629, 21.79832077], [88.78832245, 21.79807281], [88.78794861, 21.79776573], [88.78759766, 21.79738045], [88.78734589, 21.79688072], [88.7872467, 21.79631805], [88.78726196, 21.79579735], [88.78740692, 21.79535103], [88.7876358, 21.79497337], [88.78790283, 21.79463387], [88.7881012, 21.7942543], [88.78837585, 21.79389572], [88.78872681, 21.79355049], [88.78916931, 21.79319], [88.78965759, 21.7928009], [88.79020691, 21.79241943], [88.79071808, 21.79193115], [88.7911911, 21.79141808], [88.79153442, 21.79110527], [88.7917099, 21.79094505], [88.79225922, 21.7905426], [88.79281616, 21.79009056], [88.79337311, 21.78967857], [88.79389954, 21.78923035], [88.79440308, 21.78879166], [88.79478455, 21.7883358], [88.79499817, 21.78806114], [88.79582977, 21.78722191], [88.79582977, 21.78611183], [88.79556274, 21.78583145], [88.7957077, 21.78574181], [88.79549408, 21.78541183], [88.79528809, 21.78514671], [88.79509735, 21.78482056], [88.79491425, 21.78449631], [88.79463196, 21.78421021], [88.79425812, 21.78393936], [88.7939682, 21.78346062], [88.79353333, 21.7829895], [88.79316711, 21.78238487], [88.79263306, 21.78189087], [88.79218292, 21.78135109], [88.79176331, 21.7808342], [88.79134369, 21.7803154], [88.79091644, 21.77977943], [88.79053497, 21.77916527], [88.7901001, 21.77861977], [88.78967285, 21.77814102], [88.78927612, 21.77778053], [88.78897858, 21.77745819], [88.78878784, 21.77713013], [88.78859711, 21.77680016], [88.78840637, 21.77646065], [88.78816986, 21.77612114], [88.78788757, 21.77579308], [88.78762817, 21.77542114], [88.78733063, 21.77510071], [88.78722382, 21.77499962], [88.78472137, 21.77249908], [88.78472137, 21.77222061], [88.78416443, 21.77166748], [88.7841568, 21.77082825], [88.78388977, 21.7705555], [88.78388977, 21.77028084], [88.78362274, 21.76992035], [88.78340149, 21.7696209], [88.78327179, 21.76927948], [88.78309631, 21.76896095], [88.78302002, 21.76859093], [88.7828598, 21.76823997], [88.78274536, 21.76783752], [88.78250122, 21.76749992], [88.78250122, 21.76721954], [88.78221893, 21.76694679], [88.78221893, 21.76277733], [88.78250122, 21.76250076], [88.78250122, 21.76083183], [88.78277588, 21.76055527], [88.78277588, 21.75917244], [88.78305817, 21.75889015], [88.78305817, 21.75832748], [88.78333282, 21.75805473], [88.78333282, 21.75722313], [88.78360748, 21.75694466], [88.78360748, 21.75666618], [88.78388977, 21.75638962], [88.78388977, 21.75611115], [88.7841568, 21.75582123], [88.78416443, 21.75555611], [88.78555298, 21.75416946], [88.78555298, 21.75389099], [88.78610992, 21.75333023], [88.78610992, 21.75305748], [88.78639221, 21.75278091], [88.78639221, 21.75250053], [88.78666687, 21.75222015], [88.78666687, 21.75194359], [88.78778076, 21.75083351], [88.78778076, 21.75055313], [88.78824615, 21.75033951], [88.78853607, 21.75004959], [88.78871918, 21.74970436], [88.78882599, 21.74933815], [88.78887177, 21.74892807], [88.78890228, 21.74848938], [88.78890991, 21.74801445], [88.78889465, 21.74748611], [88.78887177, 21.74694252], [88.78878021, 21.74641991], [88.78860474, 21.74597168], [88.7883606, 21.74559021], [88.78804779, 21.74527931], [88.78768158, 21.74501991], [88.78749847, 21.74500084]]], [[[88.54457092, 21.8103199], [88.54615021, 21.80992126], [88.54728699, 21.81005096], [88.54886627, 21.80978012], [88.55044556, 21.80924416], [88.55273437, 21.80843735], [88.55401611, 21.80763054], [88.55631256, 21.80587959], [88.55717468, 21.8044014], [88.55875397, 21.80332565], [88.56073761, 21.80265045], [88.56089783, 21.80157852], [88.56257629, 21.80070114], [88.56279755, 21.80028725], [88.56310272, 21.79993248], [88.56347656, 21.79952621], [88.56397247, 21.79911995], [88.56445313, 21.79861069], [88.5652771, 21.79777718], [88.5652771, 21.79750061], [88.56667328, 21.79610825], [88.56694794, 21.79611206], [88.5680542, 21.79500008], [88.56833649, 21.79500008], [88.56944275, 21.79388618], [88.56944275, 21.79360962], [88.56999969, 21.79305458], [88.56999969, 21.79277992], [88.56944275, 21.79222107], [88.56972504, 21.79222488], [88.5708313, 21.79111099], [88.5708313, 21.79027939], [88.57055664, 21.79000092], [88.57055664, 21.78944016], [88.5708313, 21.78944206], [88.5716629, 21.78861046], [88.57183838, 21.78860283], [88.57194519, 21.78833389], [88.57194519, 21.78805542], [88.57221985, 21.78778267], [88.57221985, 21.78722191], [88.57250214, 21.78694534], [88.57250214, 21.78583145], [88.57221985, 21.78555489], [88.57208252, 21.78551674], [88.57195282, 21.78528023], [88.57195282, 21.78499985], [88.57138824, 21.78444481], [88.57111359, 21.78444481], [88.57055664, 21.78388977], [88.56999969, 21.78388977], [88.56999969, 21.78333092], [88.56916809, 21.78333282], [88.56916809, 21.78305626], [88.56861115, 21.78249931], [88.56861877, 21.78222084], [88.56749725, 21.78111076], [88.56694794, 21.78111076], [88.56563568, 21.77980232], [88.5652771, 21.77944374], [88.56472015, 21.77944374], [88.56500244, 21.77916527], [88.56500244, 21.77889061], [88.5652771, 21.77861023], [88.56445313, 21.77778053], [88.56445313, 21.77750015], [88.56416321, 21.77722168], [88.56416321, 21.77694321], [88.56388855, 21.77667046], [88.56388855, 21.7761097], [88.56361389, 21.77583122], [88.5633316, 21.7761116], [88.5633316, 21.77499962], [88.56305695, 21.77472115], [88.56305695, 21.77388954], [88.56276703, 21.77361107], [88.56249237, 21.77361107], [88.56249237, 21.7733326], [88.56305695, 21.77277756], [88.56305695, 21.77251053], [88.56305695, 21.77222252], [88.56222534, 21.77139091], [88.56223297, 21.77028084], [88.56194305, 21.77000046], [88.56223297, 21.77000046], [88.5625, 21.76972198], [88.5625, 21.76944351], [88.56277466, 21.76916885], [88.56276703, 21.76889038], [88.56252289, 21.76861954], [88.56250763, 21.76836777], [88.56249237, 21.76806831], [88.56247711, 21.76774979], [88.56240082, 21.76741028], [88.56227112, 21.76704597], [88.56233215, 21.76662064], [88.5623703, 21.76614952], [88.56241608, 21.76565933], [88.56248474, 21.76517296], [88.5625, 21.76468468], [88.5625, 21.76422119], [88.56249237, 21.76378059], [88.56249237, 21.76334953], [88.56249237, 21.76278114], [88.56249237, 21.76028061], [88.56276703, 21.76000023], [88.56276703, 21.75972176], [88.56305695, 21.75944519], [88.56305695, 21.75917244], [88.56360626, 21.75861168], [88.56361389, 21.75833321], [88.56583405, 21.75611115], [88.56582642, 21.75582123], [88.56603241, 21.75562477], [88.56639099, 21.75527763], [88.56639099, 21.75500107], [88.56749725, 21.75389099], [88.56764221, 21.75387955], [88.56803894, 21.75337029], [88.56833649, 21.75279045], [88.56861877, 21.7522316], [88.56893158, 21.75172806], [88.56925964, 21.75127983], [88.56955719, 21.75086403], [88.56980896, 21.75045586], [88.57002258, 21.75004959], [88.57022095, 21.74965477], [88.57036591, 21.7492218], [88.57058716, 21.7488308], [88.5708313, 21.74842072], [88.57109833, 21.74798965], [88.57137299, 21.74752045], [88.5716629, 21.74707603], [88.57194519, 21.7465744], [88.5721817, 21.74601555], [88.57221985, 21.74527931], [88.57250214, 21.74500084], [88.57250214, 21.74416924], [88.57221985, 21.74388123], [88.57221985, 21.74323082], [88.57221985, 21.74222183], [88.57194519, 21.74194527], [88.57206726, 21.74159813], [88.5721283, 21.74128914], [88.57221985, 21.74083328], [88.57221985, 21.73944664], [88.57250214, 21.73916435], [88.57250214, 21.73861122], [88.57221985, 21.73861122], [88.57250214, 21.73833084], [88.57250214, 21.73555565], [88.57221985, 21.7352829], [88.57221985, 21.73500061], [88.5716629, 21.73444176], [88.5716629, 21.7341671], [88.57110596, 21.73361015], [88.57027435, 21.73361015], [88.57027435, 21.73333359], [88.56972504, 21.73333359], [88.56944275, 21.73361015], [88.56788635, 21.73361015], [88.56694794, 21.73361015], [88.56666565, 21.73333359], [88.56583405, 21.73333359], [88.56564331, 21.73314667], [88.56555176, 21.73305511], [88.56555939, 21.73278046], [88.56503296, 21.7327404], [88.56451416, 21.7325573], [88.56400299, 21.73231125], [88.56347656, 21.73197937], [88.56305695, 21.73168182], [88.56276703, 21.73167038], [88.56249237, 21.73138809], [88.56223297, 21.73138809], [88.5616684, 21.73082924], [88.56138611, 21.73083305], [88.56111145, 21.73055649], [88.56083679, 21.7305584], [88.56054688, 21.73027992], [88.56054688, 21.72999954], [88.56014252, 21.73007393], [88.55975342, 21.73019218], [88.55945587, 21.73038292], [88.55922699, 21.73064995], [88.55902863, 21.73097038], [88.55883026, 21.73131752], [88.55861664, 21.73167038], [88.5584259, 21.73207092], [88.55822754, 21.73249054], [88.55800629, 21.73293114], [88.55778503, 21.73337936], [88.55754852, 21.73378181], [88.55726624, 21.73409271], [88.5569458, 21.73434067], [88.55659485, 21.73454857], [88.55619812, 21.73476982], [88.55578613, 21.73504066], [88.55539703, 21.73538017], [88.55499268, 21.7357502], [88.55455017, 21.73609161], [88.554039, 21.73635483], [88.55348969, 21.73653984], [88.552948, 21.73664093], [88.55243683, 21.73666954], [88.55195618, 21.73672295], [88.55148315, 21.73682022], [88.55097961, 21.73687935], [88.55045319, 21.7369194], [88.54987335, 21.73698044], [88.549263, 21.73707008], [88.54857635, 21.73718071], [88.54781342, 21.73729515], [88.54709625, 21.73736954], [88.54639435, 21.73740578], [88.54567719, 21.73742485], [88.54498291, 21.73743057], [88.54434204, 21.73744965], [88.54376221, 21.73744583], [88.54325104, 21.73747253], [88.54279327, 21.73752022], [88.5423584, 21.73760986], [88.54216766, 21.73765373], [88.54197693, 21.73769951], [88.54171753, 21.73767853], [88.54160309, 21.73744011], [88.54141235, 21.73719406], [88.54109192, 21.73694801], [88.54064941, 21.73676109], [88.54016113, 21.73656845], [88.53965759, 21.73640442], [88.53911591, 21.7362709], [88.53859711, 21.73607063], [88.53811646, 21.73582268], [88.53768158, 21.73555946], [88.53723145, 21.7353096], [88.53675842, 21.73508072], [88.53630066, 21.73485756], [88.53591919, 21.73455238], [88.53551483, 21.73425484], [88.53509521, 21.73395157], [88.53471375, 21.73360252], [88.53435516, 21.73323059], [88.53404236, 21.7328167], [88.53382111, 21.73230171], [88.53353882, 21.73188591], [88.53321838, 21.7315197], [88.53292847, 21.73111916], [88.53266907, 21.73072815], [88.53244781, 21.73026085], [88.53221893, 21.72978401], [88.53196716, 21.72930717], [88.53173828, 21.72881126], [88.53153992, 21.72830391], [88.53134918, 21.72777367], [88.53111267, 21.72727585], [88.53087616, 21.72676086], [88.53068542, 21.7261982], [88.53051758, 21.72559166], [88.53032684, 21.72499084], [88.53019714, 21.72443008], [88.52999878, 21.72396088], [88.52978516, 21.72355843], [88.52955627, 21.72318268], [88.52934265, 21.72278023], [88.52908325, 21.72237968], [88.52884674, 21.7219429], [88.52876282, 21.72180367], [88.52859497, 21.72151756], [88.52835846, 21.72120285], [88.52829742, 21.72112465], [88.52796173, 21.72074509], [88.52761078, 21.72037125], [88.52752686, 21.72026634], [88.52727509, 21.71995926], [88.52693176, 21.71955109], [88.52653503, 21.71918869], [88.52603149, 21.71888924], [88.52542114, 21.71864128], [88.52510834, 21.71857071], [88.52481079, 21.71848106], [88.52443695, 21.71856117], [88.52410126, 21.71869087], [88.52381134, 21.71883392], [88.52349091, 21.7188549], [88.52331543, 21.71882629], [88.52313232, 21.71879768], [88.52274323, 21.71883011], [88.52233887, 21.7189312], [88.5218811, 21.71904945], [88.52166748, 21.71916962], [88.52139282, 21.71888924], [88.52083588, 21.71888924], [88.52054596, 21.71916962], [88.51944733, 21.7191658], [88.51889038, 21.71972275], [88.51832581, 21.71970749], [88.51750183, 21.72055626], [88.51750946, 21.72083282], [88.51738739, 21.72106361], [88.5173111, 21.72134209], [88.51725769, 21.72156906], [88.51712036, 21.72185516], [88.51711273, 21.72206306], [88.51700592, 21.72254372], [88.516716, 21.72286034], [88.51667786, 21.72324181], [88.51638031, 21.72352028], [88.51634979, 21.72394562], [88.51628876, 21.72437096], [88.51622772, 21.72481918], [88.51625824, 21.72528076], [88.51628876, 21.72570992], [88.51618195, 21.72605515], [88.51607513, 21.72641945], [88.51590729, 21.72677994], [88.51586914, 21.72714996], [88.51597595, 21.72745514], [88.51611328, 21.7277317], [88.5161972, 21.7279911], [88.51630402, 21.72822571], [88.51637268, 21.72846985], [88.51625824, 21.72874641], [88.51638794, 21.72887993], [88.51638794, 21.72983932], [88.51598358, 21.7304039], [88.51541901, 21.73040009], [88.51500702, 21.73055649], [88.5147171, 21.73082924], [88.51526642, 21.73138809], [88.51499939, 21.73166656], [88.51444244, 21.73220062], [88.51333618, 21.73278046], [88.51312256, 21.73316002], [88.51283264, 21.73353958], [88.51249695, 21.73385811], [88.51216888, 21.7342701], [88.51204681, 21.73477936], [88.51222229, 21.73534012], [88.51241302, 21.7359333], [88.51242065, 21.73637009], [88.51242065, 21.73650932], [88.51249695, 21.73666954], [88.51194763, 21.73750114], [88.51194763, 21.73777771], [88.51139069, 21.73833275], [88.5111084, 21.73833084], [88.51082611, 21.73861122], [88.51055908, 21.73861122], [88.51024628, 21.73883057], [88.50985718, 21.73928261], [88.50959778, 21.73981857], [88.50946808, 21.74046707], [88.50908661, 21.74097633], [88.5088501, 21.74155235], [88.50862122, 21.74211121], [88.50845337, 21.74267387], [88.50834656, 21.74325943], [88.50827789, 21.74386978], [88.50806427, 21.74446106], [88.50786591, 21.74504471], [88.50763702, 21.74564362], [88.50738525, 21.74619293], [88.50704956, 21.74658394], [88.50682831, 21.74687958], [88.50675964, 21.74697113], [88.50649261, 21.74736023], [88.50617981, 21.74771118], [88.50595856, 21.74806976], [88.50583649, 21.74839783], [88.50572968, 21.74868011], [88.50557709, 21.74894142], [88.50547028, 21.74920845], [88.50521088, 21.74949646], [88.50492096, 21.7498703], [88.50460052, 21.75029945], [88.50437927, 21.75076294], [88.50457001, 21.75139427], [88.5045166, 21.75205231], [88.50444031, 21.75271988], [88.50454712, 21.75336075], [88.5045166, 21.75387001], [88.50466156, 21.75434113], [88.50458527, 21.7547226], [88.5044632, 21.75509071], [88.50432587, 21.7555294], [88.50432587, 21.75597382], [88.50440979, 21.75642967], [88.50440216, 21.75691986], [88.5043869, 21.75741005], [88.50449371, 21.7578907], [88.5047226, 21.75829124], [88.50499725, 21.75867081], [88.50528717, 21.75901985], [88.50562286, 21.75933075], [88.50601959, 21.75952721], [88.50636292, 21.7598381], [88.50668335, 21.76023102], [88.50719452, 21.76050568], [88.50770569, 21.76086044], [88.50823212, 21.76127052], [88.50895691, 21.76151848], [88.50943756, 21.76171112], [88.51022339, 21.7621479], [88.51072693, 21.7625103], [88.51132202, 21.76278114], [88.51181793, 21.7630806], [88.5121994, 21.76343918], [88.51254272, 21.76381111], [88.51288605, 21.76415062], [88.51325226, 21.76447105], [88.51360321, 21.76480865], [88.51394653, 21.76516151], [88.51436615, 21.76548004], [88.5147934, 21.76580238], [88.51521301, 21.76610947], [88.51560211, 21.76642036], [88.51596069, 21.76679039], [88.51637268, 21.76719284], [88.51687622, 21.76754951], [88.5174408, 21.76797676], [88.51805115, 21.76840401], [88.51864624, 21.76883125], [88.51889038, 21.76917076], [88.51944733, 21.76916885], [88.51981354, 21.76953697], [88.51999664, 21.76972198], [88.52027893, 21.76972198], [88.52046204, 21.76990509], [88.52083588, 21.77028084], [88.52111053, 21.77028084], [88.52129364, 21.77046585], [88.52139282, 21.77055931], [88.52194214, 21.77055931], [88.52224731, 21.77095032], [88.52268219, 21.77133942], [88.52316284, 21.7717495], [88.52367401, 21.77212715], [88.52416992, 21.77248955], [88.52465057, 21.77285767], [88.52509308, 21.77325058], [88.52548218, 21.77366066], [88.52584076, 21.77409172], [88.52616882, 21.77453995], [88.52648926, 21.77498055], [88.52684784, 21.77539063], [88.52720642, 21.77577019], [88.52755737, 21.77613068], [88.52787781, 21.77648544], [88.52819061, 21.7768383], [88.5284729, 21.77724075], [88.52867126, 21.77763939], [88.52890015, 21.77801895], [88.52916718, 21.77837944], [88.52947235, 21.77877808], [88.52986145, 21.7792263], [88.53029633, 21.77972984], [88.53077698, 21.78028107], [88.53124237, 21.7808609], [88.53161621, 21.78148079], [88.53198242, 21.78205109], [88.53231812, 21.78252983], [88.53263092, 21.78296089], [88.53283691, 21.78339005], [88.53292847, 21.78383064], [88.53295135, 21.78424835], [88.53305054, 21.78467178], [88.53318787, 21.78510094], [88.53333282, 21.78551292], [88.53347015, 21.7859211], [88.53360748, 21.7863369], [88.53373718, 21.78676033], [88.53388977, 21.78719521], [88.53399658, 21.78771019], [88.53407288, 21.78827286], [88.53412628, 21.78880692], [88.53425598, 21.78934288], [88.53443909, 21.78988075], [88.53466797, 21.79041862], [88.53495026, 21.79091072], [88.53521729, 21.79137993], [88.53535461, 21.79177666], [88.53528595, 21.7920208], [88.53502655, 21.79206276], [88.53468323, 21.7918911], [88.53430939, 21.79152107], [88.53398895, 21.79105759], [88.53373718, 21.79055023], [88.53354645, 21.79008102], [88.53341675, 21.78967094], [88.53330994, 21.78931046], [88.5331955, 21.78892136], [88.53308868, 21.78846741], [88.53298187, 21.7879715], [88.53292847, 21.78741074], [88.53288269, 21.78684807], [88.53273773, 21.78632164], [88.53250885, 21.78585815], [88.53230286, 21.78544044], [88.53208923, 21.78500938], [88.53187561, 21.78455734], [88.53167725, 21.78407097], [88.53152466, 21.78362656], [88.53137207, 21.78324127], [88.53119659, 21.78289032], [88.5309906, 21.78256035], [88.53076172, 21.7822094], [88.53050995, 21.78183174], [88.53022766, 21.78146744], [88.52993011, 21.78108025], [88.52962494, 21.78067207], [88.52935028, 21.78024673], [88.52910614, 21.77984047], [88.52888489, 21.77945137], [88.52861786, 21.77910423], [88.52830505, 21.7787838], [88.52801514, 21.7784214], [88.52771759, 21.77802849], [88.52742004, 21.77763939], [88.52713013, 21.77727127], [88.52682495, 21.77689171], [88.52651215, 21.77647972], [88.52616119, 21.77609062], [88.52575684, 21.7756691], [88.52532959, 21.77517128], [88.52485657, 21.77465057], [88.52436829, 21.7741394], [88.52388, 21.77363968], [88.52336121, 21.7731781], [88.52281952, 21.77275276], [88.52227783, 21.77233124], [88.52173615, 21.77190971], [88.52111053, 21.77139091], [88.52083588, 21.77139091], [88.52065277, 21.7712059], [88.52027893, 21.77083397], [88.51972198, 21.77083397], [88.51961517, 21.77072334], [88.51944733, 21.7705555], [88.51889038, 21.77055931], [88.51860809, 21.77028084], [88.51832581, 21.77028084], [88.51810455, 21.76993942], [88.5178299, 21.76971626], [88.5173111, 21.76927948], [88.51674652, 21.76889992], [88.5161972, 21.76854706], [88.51566315, 21.76815987], [88.51512146, 21.76777077], [88.51460266, 21.76737976], [88.51410675, 21.7670002], [88.51361084, 21.76663971], [88.51316833, 21.76622963], [88.51272583, 21.76581955], [88.5121994, 21.76555061], [88.51167297, 21.76527977], [88.51112366, 21.76502037], [88.51064301, 21.76470184], [88.5102005, 21.76438522], [88.50969696, 21.76415062], [88.50920105, 21.76391983], [88.50863647, 21.76377106], [88.50810242, 21.76358604], [88.50760651, 21.76334], [88.50712585, 21.76313019], [88.50663757, 21.76305962], [88.50617981, 21.76305771], [88.50576782, 21.76300049], [88.50526428, 21.76282501], [88.50502014, 21.7627697], [88.5047226, 21.76262474], [88.50444794, 21.76250076], [88.50417328, 21.76250076], [88.50389099, 21.76278114], [88.50389099, 21.7630558], [88.5036087, 21.76333046], [88.50360107, 21.76365662], [88.50353241, 21.76394463], [88.50337219, 21.7642498], [88.50332642, 21.76464081], [88.50333405, 21.76506996], [88.50332642, 21.7655201], [88.50333405, 21.76597786], [88.50361633, 21.76625061], [88.50361633, 21.76680946], [88.50389099, 21.76749992], [88.50389099, 21.76805687], [88.50416565, 21.76833344], [88.50416565, 21.76944351], [88.50444794, 21.76971817], [88.50444794, 21.77000046], [88.50416565, 21.77027893], [88.50417328, 21.77082825], [88.50444794, 21.77111053], [88.50444794, 21.77166748], [88.5047226, 21.77193832], [88.5047226, 21.77249908], [88.50494385, 21.77263069], [88.50505829, 21.77318382], [88.50527191, 21.77360153], [88.50547028, 21.77394867], [88.50556946, 21.77430534], [88.50572205, 21.77462006], [88.50584412, 21.77495956], [88.50598907, 21.77529335], [88.50610352, 21.77565384], [88.50619507, 21.7760334], [88.5063858, 21.77634811], [88.50656891, 21.77667999], [88.50673676, 21.77700996], [88.50692749, 21.77734947], [88.50710297, 21.77774048], [88.50739288, 21.77809715], [88.5076828, 21.77850914], [88.50800323, 21.77896118], [88.50823975, 21.77945518], [88.50846863, 21.77996063], [88.50875092, 21.7804203], [88.50907135, 21.78085709], [88.50937653, 21.78129959], [88.5096817, 21.78174019], [88.50995636, 21.78219032], [88.51023865, 21.7826004], [88.51045227, 21.78302002], [88.51069641, 21.78334618], [88.51088715, 21.78364944], [88.51109314, 21.78389931], [88.51126862, 21.78416061], [88.51145172, 21.78442192], [88.51166534, 21.78469086], [88.51190186, 21.78499031], [88.51217651, 21.7852993], [88.51243591, 21.78561211], [88.51262665, 21.78594017], [88.51286316, 21.78619957], [88.51304626, 21.78645134], [88.513237, 21.78671074], [88.51341248, 21.78699493], [88.51373291, 21.7872448], [88.51407623, 21.7875309], [88.51441956, 21.78789711], [88.5147171, 21.78834343], [88.51500702, 21.78882027], [88.51534271, 21.78923988], [88.51566315, 21.78963089], [88.51605988, 21.78985596], [88.51638031, 21.79014015], [88.51667023, 21.79046059], [88.51695251, 21.79079056], [88.51725769, 21.79113579], [88.51763153, 21.79144287], [88.518013, 21.79178047], [88.51833344, 21.79220581], [88.51870728, 21.79261017], [88.51908875, 21.79308128], [88.51947021, 21.79357338], [88.51994324, 21.7939682], [88.52037048, 21.79438972], [88.52054596, 21.79445076], [88.52361298, 21.79750061], [88.52388763, 21.79750061], [88.52555847, 21.79916573], [88.52555847, 21.79943848], [88.52638245, 21.80027962], [88.5266571, 21.80027962], [88.52805328, 21.80166626], [88.52861023, 21.8022213], [88.52889252, 21.8022213], [88.53028107, 21.80361176], [88.53056335, 21.80360985], [88.53193665, 21.80500031], [88.53221893, 21.80500031], [88.53277588, 21.80556107], [88.53305817, 21.80556107], [88.53360748, 21.80611038], [88.53388977, 21.80611038], [88.5341568, 21.80639076], [88.53444672, 21.80638885], [88.53527832, 21.80722237], [88.53555298, 21.80722046], [88.53573608, 21.80740738], [88.53610992, 21.80778122], [88.53639221, 21.80778122], [88.53666687, 21.80805969], [88.53721619, 21.80805969], [88.53778076, 21.80861092], [88.53806305, 21.80861092], [88.53861237, 21.80916977], [88.53888702, 21.80916786], [88.53944397, 21.8097229], [88.53971863, 21.80971909], [88.54000092, 21.81000137], [88.54055786, 21.81055832], [88.54083252, 21.81055832], [88.54342651, 21.81059074], [88.54457092, 21.8103199]]], [[[88.42180634, 21.81109047], [88.42236328, 21.81107903], [88.42290497, 21.81108284], [88.42346954, 21.81108284], [88.42407227, 21.81103134], [88.42463684, 21.81084251], [88.42513275, 21.81048393], [88.42553711, 21.80997849], [88.4258728, 21.80940056], [88.42610168, 21.80878067], [88.42626953, 21.80817795], [88.42642212, 21.807621], [88.42658234, 21.80709076], [88.426651, 21.80653954], [88.42666626, 21.80598259], [88.42669678, 21.80542183], [88.42681122, 21.80485535], [88.42692566, 21.80427361], [88.42701721, 21.80368805], [88.4272995, 21.8031311], [88.42749786, 21.80249214], [88.42769623, 21.80185509], [88.42796326, 21.80125046], [88.42835999, 21.80078506], [88.42875671, 21.80031013], [88.42917633, 21.79990005], [88.42963409, 21.79958725], [88.43012238, 21.79937172], [88.4305954, 21.7991581], [88.43107605, 21.79897118], [88.43158722, 21.79883957], [88.43209839, 21.79870987], [88.43261719, 21.79864311], [88.43312073, 21.7986927], [88.43360901, 21.79883957], [88.4340744, 21.79888344], [88.43453979, 21.79889488], [88.43501282, 21.79891968], [88.43549347, 21.7990799], [88.43604279, 21.79920959], [88.43660736, 21.79937553], [88.43717194, 21.79953003], [88.43772125, 21.7997303], [88.43823242, 21.79993248], [88.43881989, 21.80004883], [88.4393692, 21.80021286], [88.43995667, 21.80032921], [88.44055939, 21.80051994], [88.44113922, 21.8005619], [88.4413147, 21.80055428], [88.44167328, 21.80054474], [88.44210815, 21.80043221], [88.44239807, 21.80013084], [88.44267273, 21.79988098], [88.44268799, 21.79965019], [88.4425354, 21.79940033], [88.44247437, 21.79905891], [88.44238281, 21.79870033], [88.44223022, 21.79834938], [88.44198608, 21.79800034], [88.4417572, 21.79759026], [88.44156647, 21.79712105], [88.4413681, 21.79661179], [88.44111633, 21.79611969], [88.44088745, 21.79556847], [88.4407959, 21.79497147], [88.44059753, 21.79445839], [88.44055939, 21.7939682], [88.4405365, 21.79355812], [88.44042969, 21.79320908], [88.44029999, 21.79282951], [88.44026947, 21.7923317], [88.44022369, 21.79174423], [88.44011688, 21.79111671], [88.44002533, 21.79046249], [88.44000244, 21.78980446], [88.43994141, 21.78918076], [88.43972015, 21.78860283], [88.43945313, 21.7880497], [88.43919373, 21.78754807], [88.43889618, 21.78720093], [88.43869019, 21.78686905], [88.438591, 21.7865181], [88.43843079, 21.78619194], [88.43830109, 21.78577995], [88.43810272, 21.78537941], [88.43795013, 21.78487968], [88.43772125, 21.78443718], [88.43749237, 21.7840004], [88.43723297, 21.78362083], [88.43694305, 21.78325081], [88.43666077, 21.78289032], [88.43637848, 21.78254128], [88.43609619, 21.7822094], [88.43583679, 21.78187943], [88.43557739, 21.78154945], [88.43534851, 21.78120422], [88.43502045, 21.78094673], [88.4347229, 21.78067017], [88.43441772, 21.78041077], [88.43408966, 21.78018188], [88.43386078, 21.77980042], [88.43345642, 21.77962112], [88.4330368, 21.77943039], [88.43267059, 21.77918816], [88.43229675, 21.77897072], [88.43196869, 21.7787075], [88.43170166, 21.77837944], [88.43139648, 21.77809143], [88.43108368, 21.77779388], [88.43076324, 21.77750587], [88.43044281, 21.77722168], [88.43013763, 21.77694321], [88.42987061, 21.77666283], [88.42961884, 21.77639008], [88.42936707, 21.77613068], [88.42910767, 21.77590942], [88.42881012, 21.77573967], [88.42856598, 21.77552032], [88.42832184, 21.77526093], [88.4280014, 21.7749424], [88.42758179, 21.77453995], [88.42701721, 21.77412987], [88.42693329, 21.77406693], [88.42643738, 21.77368355], [88.42577362, 21.77333641], [88.4251709, 21.77301979], [88.42473602, 21.77264023], [88.42442322, 21.77228928], [88.4241333, 21.77197075], [88.42379761, 21.77169037], [88.42342377, 21.77145767], [88.42312622, 21.77114105], [88.42280579, 21.77086067], [88.42260742, 21.77050018], [88.42236328, 21.77012062], [88.42211914, 21.76974106], [88.42183685, 21.7694149], [88.42164612, 21.76906967], [88.42144775, 21.76877022], [88.42132568, 21.76844406], [88.42115784, 21.7681694], [88.4210968, 21.76783943], [88.42099762, 21.76753044], [88.42086029, 21.76723099], [88.42080688, 21.76684952], [88.42069244, 21.76643181], [88.42058563, 21.76594925], [88.42056274, 21.76540947], [88.42055511, 21.76502991], [88.42055511, 21.76484108], [88.42053986, 21.76431274], [88.42045593, 21.76385689], [88.42043304, 21.76344872], [88.42050171, 21.76305008], [88.42063904, 21.76262093], [88.42070007, 21.76210022], [88.42082977, 21.76167107], [88.42101288, 21.76129913], [88.42119598, 21.76097107], [88.42133331, 21.7606411], [88.42150116, 21.76037025], [88.4216156, 21.76005173], [88.42168427, 21.75972176], [88.42180634, 21.75943184], [88.42195892, 21.75917244], [88.42201233, 21.75869179], [88.42189789, 21.75859451], [88.42215729, 21.75826073], [88.42251587, 21.75799942], [88.42264557, 21.75764084], [88.42282104, 21.75728989], [88.42307281, 21.75696182], [88.42418671, 21.75498009], [88.42461395, 21.75390816], [88.42518616, 21.75337029], [88.4253006, 21.75271034], [88.42505646, 21.75201035], [88.4247818, 21.75147057], [88.4245224, 21.75104332], [88.4243927, 21.7505703], [88.42418671, 21.75014114], [88.42399597, 21.74999619], [88.42379761, 21.7498455], [88.42357635, 21.74938011], [88.42336273, 21.74894142], [88.42311859, 21.7485199], [88.42256165, 21.74779892], [88.42198181, 21.74712944], [88.42157745, 21.74637032], [88.42144012, 21.7457695], [88.4211731, 21.7454319], [88.42111969, 21.74500084], [88.42095947, 21.74446106], [88.42084503, 21.7440815], [88.4209671, 21.74273109], [88.42082977, 21.74151993], [88.42082214, 21.74044609], [88.42112732, 21.73975182], [88.42137146, 21.73921776], [88.42138672, 21.7387085], [88.4214859, 21.73824501], [88.42163849, 21.73780823], [88.42170715, 21.73731995], [88.42192078, 21.73688507], [88.42209625, 21.7364006], [88.42233276, 21.73590469], [88.42251587, 21.73543358], [88.42276001, 21.73503113], [88.42303467, 21.73471642], [88.42301178, 21.73433113], [88.42310333, 21.73423958], [88.42327118, 21.73406982], [88.42356873, 21.73361969], [88.42388916, 21.73324013], [88.42388916, 21.73286819], [88.42391968, 21.73250008], [88.42403412, 21.73218346], [88.42414093, 21.73192024], [88.42417908, 21.73161125], [88.42424774, 21.73132706], [88.42442322, 21.73108101], [88.42447662, 21.73075104], [88.42463684, 21.73046112], [88.42472839, 21.73011971], [88.42466736, 21.7296505], [88.42468262, 21.7293396], [88.42462158, 21.7290287], [88.42481232, 21.72887993], [88.42506409, 21.72855759], [88.42517853, 21.72632027], [88.42517853, 21.72443962], [88.42529297, 21.72346115], [88.42524719, 21.72296906], [88.42508698, 21.72257042], [88.42497253, 21.72216988], [88.42478943, 21.72183609], [88.42469788, 21.72147942], [88.42453766, 21.7211895], [88.42443085, 21.72089195], [88.42424774, 21.72064972], [88.42398834, 21.72050476], [88.42372131, 21.72031021], [88.42339325, 21.72014046], [88.42310333, 21.71986961], [88.42276001, 21.71982002], [88.42237854, 21.72020912], [88.42204285, 21.72072983], [88.42166138, 21.72116089], [88.42127991, 21.7215271], [88.42093658, 21.72191811], [88.42057037, 21.72228622], [88.42024994, 21.72270966], [88.41994476, 21.7231369], [88.41972351, 21.72353363], [88.41956329, 21.72371483], [88.41947174, 21.72381973], [88.41925049, 21.72405052], [88.41912842, 21.72437096], [88.41890717, 21.72470284], [88.41866302, 21.72504044], [88.41841125, 21.72541046], [88.41812134, 21.72578049], [88.4178009, 21.72610092], [88.41749573, 21.72638512], [88.41726685, 21.72665405], [88.41716766, 21.72698975], [88.41702271, 21.72730064], [88.41693115, 21.72762108], [88.4168396, 21.72792816], [88.41668701, 21.72820091], [88.41656494, 21.72847557], [88.41636658, 21.72871971], [88.41615295, 21.72899055], [88.4159317, 21.72932816], [88.4156189, 21.72965813], [88.4152832, 21.73006058], [88.41490936, 21.73047066], [88.41448212, 21.73085976], [88.41404724, 21.73125076], [88.41365051, 21.73167038], [88.41333008, 21.7321701], [88.41299438, 21.7326889], [88.4125824, 21.73315048], [88.41213989, 21.7335701], [88.41165924, 21.73396111], [88.41107941, 21.73439026], [88.4105072, 21.73480415], [88.40997314, 21.73525047], [88.4094162, 21.73563957], [88.40886688, 21.73594093], [88.40833282, 21.73615074], [88.40785217, 21.73631287], [88.40733337, 21.7364006], [88.40688324, 21.73649979], [88.40653992, 21.73669052], [88.40622711, 21.73693275], [88.40589905, 21.73715973], [88.40553284, 21.73733521], [88.40512848, 21.73747063], [88.40468597, 21.73759079], [88.40422821, 21.73774719], [88.40376282, 21.73798943], [88.4033432, 21.73835754], [88.40299225, 21.73876953], [88.402771, 21.73926926], [88.40255737, 21.73974037], [88.40239716, 21.74017715], [88.40220642, 21.74055672], [88.40200806, 21.74091148], [88.40184021, 21.74131203], [88.40163422, 21.74171257], [88.40140533, 21.74212074], [88.40119934, 21.74257088], [88.40106964, 21.74308968], [88.40088654, 21.74352074], [88.40085602, 21.74394035], [88.40100098, 21.74435806], [88.40114594, 21.74477005], [88.40132141, 21.74515724], [88.40145111, 21.74559021], [88.40161133, 21.74599457], [88.40174866, 21.74643135], [88.40194702, 21.7467308], [88.40216827, 21.74702072], [88.40232849, 21.74740982], [88.40254211, 21.74786949], [88.40270996, 21.74838829], [88.402771, 21.74894142], [88.40277863, 21.74950027], [88.40273285, 21.75002098], [88.40254211, 21.75049019], [88.40236664, 21.75096321], [88.40219116, 21.75144958], [88.40194702, 21.75193977], [88.40167236, 21.7524128], [88.40136719, 21.75286102], [88.40104675, 21.75325012], [88.4006958, 21.75358963], [88.40032959, 21.75388527], [88.39994049, 21.75415993], [88.3995285, 21.75442123], [88.39909363, 21.75463295], [88.39862061, 21.75481224], [88.39810181, 21.75500107], [88.39755249, 21.75522614], [88.39698792, 21.7555027], [88.3964386, 21.75585365], [88.39611053, 21.75634193], [88.39586639, 21.75687981], [88.39575195, 21.75745773], [88.39575195, 21.75805855], [88.39568329, 21.75859833], [88.39569092, 21.75922966], [88.39562225, 21.75991821], [88.39550018, 21.76042938], [88.39547729, 21.76099586], [88.39527893, 21.76156044], [88.39507294, 21.76181984], [88.3948822, 21.76260185], [88.39457703, 21.76289368], [88.39447784, 21.76318169], [88.3944397, 21.76338005], [88.39434052, 21.76370621], [88.39404297, 21.76395988], [88.39408112, 21.76443672], [88.39360046, 21.76506042], [88.39311218, 21.76539993], [88.39279938, 21.7656002], [88.39259338, 21.76618958], [88.39234924, 21.76637077], [88.39190674, 21.76665115], [88.39157867, 21.76702118], [88.39112854, 21.76726913], [88.39071655, 21.76761055], [88.39030457, 21.76800537], [88.38996124, 21.76849174], [88.38963318, 21.76898956], [88.3894043, 21.76944733], [88.38905334, 21.76971817], [88.38871002, 21.7700119], [88.38838196, 21.77031326], [88.38804626, 21.77066994], [88.38770294, 21.77107048], [88.38729095, 21.77146721], [88.38693237, 21.77193832], [88.38656616, 21.77241707], [88.38625336, 21.77289963], [88.38591003, 21.77333069], [88.38556671, 21.77371979], [88.38527679, 21.77409935], [88.38498688, 21.77444267], [88.38469696, 21.77474976], [88.38444519, 21.77506256], [88.38423157, 21.77537155], [88.3841095, 21.7757206], [88.38391876, 21.77601051], [88.38378906, 21.77629089], [88.38355255, 21.77647018], [88.38331604, 21.77667999], [88.38308716, 21.77690125], [88.38288116, 21.77721024], [88.38280487, 21.77775192], [88.38279724, 21.77782631], [88.38269806, 21.7784996], [88.38265991, 21.77910042], [88.38282013, 21.77959633], [88.38317871, 21.77994919], [88.38352966, 21.78027916], [88.38385773, 21.78062248], [88.38421631, 21.78100014], [88.38470459, 21.78136063], [88.38527679, 21.78166962], [88.38578796, 21.7820282], [88.38617706, 21.78246117], [88.38661194, 21.78277016], [88.38696289, 21.78310013], [88.38734436, 21.78338623], [88.38787079, 21.78352165], [88.38831329, 21.7836895], [88.38871765, 21.78391266], [88.38909149, 21.78418541], [88.38944244, 21.78453445], [88.38978577, 21.7849102], [88.39013672, 21.78523064], [88.39051056, 21.78549957], [88.39090729, 21.78573036], [88.39129639, 21.78603554], [88.39170837, 21.7864399], [88.39216614, 21.78689003], [88.39267731, 21.78737068], [88.39325714, 21.78775978], [88.39382172, 21.78808022], [88.39431, 21.78841972], [88.39479828, 21.78865051], [88.39523315, 21.78897095], [88.39562225, 21.7894001], [88.3960495, 21.78981972], [88.39646149, 21.79024124], [88.39689636, 21.79063416], [88.39728546, 21.79105377], [88.39769745, 21.79142952], [88.39807129, 21.79182816], [88.39845276, 21.79220009], [88.39881897, 21.79252815], [88.39914703, 21.79283714], [88.39942932, 21.79313087], [88.39966583, 21.79342079], [88.39987183, 21.79372025], [88.40022278, 21.79390907], [88.40055847, 21.79417038], [88.40088654, 21.79450035], [88.40125275, 21.79483032], [88.40174103, 21.79507828], [88.40222168, 21.79531288], [88.40262604, 21.79564095], [88.40309143, 21.79598618], [88.40361786, 21.79630089], [88.40414429, 21.7966671], [88.40458679, 21.7970829], [88.40500641, 21.79750252], [88.40544891, 21.79793167], [88.40592957, 21.79836655], [88.40644073, 21.79885101], [88.40696716, 21.79935074], [88.40747833, 21.79981804], [88.4079361, 21.80023003], [88.40837097, 21.80060959], [88.40876007, 21.80095863], [88.40917969, 21.80126953], [88.40962219, 21.80155945], [88.41008759, 21.80176926], [88.41038513, 21.80217361], [88.41073608, 21.80244064], [88.41123962, 21.80285072], [88.41181183, 21.80324936], [88.41246033, 21.80363083], [88.4128952, 21.80402565], [88.41337585, 21.80448341], [88.41388702, 21.80495834], [88.41442108, 21.80540276], [88.41487122, 21.80583], [88.41525269, 21.80624962], [88.41557312, 21.80668831], [88.41582489, 21.80705833], [88.41587067, 21.80713081], [88.41617584, 21.8075676], [88.41647339, 21.8080101], [88.41676331, 21.80844879], [88.41713715, 21.80882072], [88.41758728, 21.8091507], [88.41802216, 21.80943108], [88.418396, 21.80970573], [88.41872406, 21.8099823], [88.41902161, 21.81026077], [88.41934204, 21.81054115], [88.41969299, 21.81079292], [88.42011261, 21.81098557], [88.42063141, 21.8110981], [88.42121887, 21.81114006], [88.42150879, 21.81111526], [88.42180634, 21.81109047]]], [[[88.82807922, 21.80402946], [88.82757568, 21.80344772], [88.82704926, 21.80296135], [88.82701111, 21.80267906], [88.82668304, 21.80235291], [88.82639313, 21.80199432], [88.82611847, 21.80160713], [88.82585144, 21.80120087], [88.82563019, 21.80078506], [88.82550049, 21.80032921], [88.82528687, 21.79993248], [88.82508087, 21.79953575], [88.82482147, 21.79911995], [88.82461548, 21.79863548], [88.82460785, 21.79801369], [88.82420349, 21.79755783], [88.82382202, 21.7971096], [88.82356262, 21.79662895], [88.82331848, 21.79617119], [88.82305908, 21.79573059], [88.82285309, 21.79528046], [88.82276917, 21.79476738], [88.82269287, 21.79429054], [88.8225708, 21.79388428], [88.82202148, 21.7928791], [88.82180786, 21.79207039], [88.82144928, 21.79051971], [88.82130432, 21.7889061], [88.82073212, 21.78703117], [88.82090759, 21.7852211], [88.82108307, 21.78487015], [88.8212204, 21.78447151], [88.8214035, 21.7840538], [88.82163239, 21.78250885], [88.82155609, 21.78083038], [88.8221283, 21.77975082], [88.82292175, 21.77843857], [88.823349, 21.77773285], [88.82463837, 21.77517891], [88.82614136, 21.77276039], [88.82641602, 21.77114105], [88.82778931, 21.76979828], [88.82892609, 21.76865005], [88.83027649, 21.76722145], [88.83027649, 21.76666451], [88.83000183, 21.76667023], [88.82949829, 21.76616287], [88.82887268, 21.76583099], [88.82827759, 21.76554871], [88.82769775, 21.76527023], [88.82714081, 21.76498032], [88.82662201, 21.76465988], [88.82614136, 21.76431084], [88.82567596, 21.76394272], [88.82518768, 21.76361084], [88.82470703, 21.76329041], [88.8243103, 21.76292038], [88.8239212, 21.76254082], [88.82353973, 21.76214981], [88.82315063, 21.76177025], [88.82274628, 21.76140976], [88.82232666, 21.76106071], [88.82196045, 21.76067924], [88.82158661, 21.76029968], [88.82121277, 21.7599411], [88.82102966, 21.75975227], [88.82086945, 21.75958633], [88.8205719, 21.75926018], [88.82029724, 21.7589798], [88.82003784, 21.7587204], [88.81980896, 21.75843048], [88.8195343, 21.75815773], [88.81921387, 21.75789261], [88.81891632, 21.75759125], [88.8186264, 21.75727081], [88.81833649, 21.7569294], [88.81809998, 21.7566185], [88.81783295, 21.75632095], [88.81755066, 21.75603104], [88.81726074, 21.75572968], [88.81697845, 21.7554245], [88.81668854, 21.75510025], [88.81639099, 21.75476837], [88.81607819, 21.75444984], [88.81574249, 21.75415039], [88.81537628, 21.75385284], [88.81500244, 21.75352287], [88.8145752, 21.75318146], [88.81412506, 21.75282478], [88.81363678, 21.75248909], [88.8131485, 21.75216103], [88.81269073, 21.75184059], [88.81227875, 21.75152016], [88.81189728, 21.75119972], [88.81150055, 21.75095177], [88.81108093, 21.7507515], [88.81073761, 21.75053787], [88.81038666, 21.75033951], [88.80998993, 21.75020981], [88.80960083, 21.75004959], [88.80944061, 21.75000954], [88.80916595, 21.75000954], [88.8088913, 21.74971962], [88.80833435, 21.74972153], [88.80805206, 21.74944305], [88.80750275, 21.74945068], [88.80722046, 21.7491703], [88.80665588, 21.7491703], [88.80639648, 21.74888992], [88.80555725, 21.74888992], [88.80526733, 21.74860954], [88.80472565, 21.74861145], [88.80444336, 21.74833107], [88.80222321, 21.74833107], [88.80194092, 21.74861145], [88.80110931, 21.74860954], [88.80082703, 21.74888992], [88.80055237, 21.74888992], [88.80055237, 21.7491703], [88.80027008, 21.74945068], [88.79972076, 21.74945068], [88.79944611, 21.7491703], [88.79915619, 21.7491703], [88.79891205, 21.74867249], [88.79888916, 21.74833107], [88.79694366, 21.74833107], [88.79666901, 21.74861145], [88.79499817, 21.74860954], [88.79471588, 21.74888992], [88.79416656, 21.74888992], [88.79389191, 21.7491703], [88.79332733, 21.7491703], [88.79305267, 21.74945068], [88.79194641, 21.74944305], [88.79166412, 21.74972153], [88.79139709, 21.74971962], [88.79110718, 21.75000954], [88.79083252, 21.75000954], [88.79053497, 21.75034714], [88.79030609, 21.75068283], [88.79009247, 21.75107384], [88.78983307, 21.75141907], [88.78954315, 21.7517395], [88.78932953, 21.75206947], [88.78917694, 21.75244522], [88.78907013, 21.75286102], [88.78888702, 21.75327873], [88.78868103, 21.75366974], [88.78853607, 21.7541008], [88.78832245, 21.75444984], [88.78806305, 21.75477982], [88.78778839, 21.75515938], [88.78756714, 21.75559616], [88.78736877, 21.75607109], [88.787117, 21.75649071], [88.78690338, 21.75690269], [88.78665924, 21.75727081], [88.78642273, 21.75760078], [88.78620911, 21.75797081], [88.78604126, 21.75839806], [88.78582764, 21.75884247], [88.78555298, 21.75929451], [88.78525543, 21.75974464], [88.78499603, 21.76021194], [88.78473663, 21.76063919], [88.78451538, 21.76104355], [88.78436279, 21.76147079], [88.78420258, 21.76189423], [88.78407288, 21.76234436], [88.78401947, 21.76284027], [88.78395081, 21.76335716], [88.7838974, 21.76390076], [88.78387451, 21.76447105], [88.78385925, 21.76502037], [88.7838974, 21.7655201], [88.78408051, 21.7659111], [88.78418732, 21.76629257], [88.78436279, 21.7666111], [88.78448486, 21.76696587], [88.78470612, 21.76729012], [88.78492737, 21.76769066], [88.78523254, 21.7680397], [88.78544617, 21.76849174], [88.78565216, 21.76896095], [88.78594208, 21.76934052], [88.78623962, 21.76972961], [88.78652954, 21.77012062], [88.78689575, 21.77039146], [88.78720856, 21.77071953], [88.78749847, 21.77111053], [88.78779602, 21.77152252], [88.78814697, 21.77191162], [88.7885437, 21.77227211], [88.78887939, 21.77268028], [88.78916931, 21.77312088], [88.78942108, 21.7735672], [88.78962708, 21.77401924], [88.78993225, 21.77439117], [88.79029083, 21.77469063], [88.79073334, 21.7748909], [88.7911377, 21.77511978], [88.79149628, 21.7754097], [88.79179382, 21.7757988], [88.79211426, 21.77615356], [88.79239655, 21.77654076], [88.79271698, 21.7768898], [88.79306793, 21.77725029], [88.79350281, 21.77763939], [88.79396057, 21.77810287], [88.79444122, 21.77859116], [88.79493713, 21.7790451], [88.79528046, 21.77955437], [88.795578, 21.78002167], [88.79585266, 21.78043938], [88.79611206, 21.78081894], [88.79638672, 21.78116989], [88.79663086, 21.78153038], [88.79679108, 21.78191948], [88.79692078, 21.78230095], [88.79696655, 21.78269958], [88.79708862, 21.78305054], [88.79722595, 21.78339386], [88.79735565, 21.78375435], [88.7974472, 21.78415489], [88.79748535, 21.78459358], [88.79750061, 21.7850399], [88.79754639, 21.78547668], [88.79759979, 21.7858696], [88.79759216, 21.78624916], [88.79751587, 21.78661728], [88.79749298, 21.78699112], [88.79743195, 21.78733063], [88.79727936, 21.78763008], [88.79722595, 21.78793907], [88.79718018, 21.78824043], [88.79708099, 21.78853035], [88.79696655, 21.78883743], [88.79693604, 21.78922081], [88.79693604, 21.7896595], [88.79693604, 21.79000092], [88.79722595, 21.79027939], [88.79722595, 21.79055405], [88.79888916, 21.79222107], [88.79888916, 21.79249954], [88.79944611, 21.7930603], [88.79946136, 21.79316711], [88.79979706, 21.79368019], [88.80011749, 21.7942028], [88.80043793, 21.7947197], [88.80072021, 21.79523087], [88.80097961, 21.79573822], [88.80134583, 21.79620171], [88.80169678, 21.79668236], [88.80208588, 21.79709053], [88.80245209, 21.79745674], [88.80277252, 21.79777908], [88.80306244, 21.79809952], [88.80335236, 21.79839706], [88.80368042, 21.79866982], [88.80401611, 21.79894829], [88.80430603, 21.79927254], [88.80462646, 21.79949951], [88.80488586, 21.79981041], [88.80500031, 21.80000114], [88.80512238, 21.80011749], [88.80610657, 21.80112076], [88.80610657, 21.80138969], [88.80750275, 21.80278015], [88.8077774, 21.80278015], [88.8088913, 21.80389023], [88.80916595, 21.80388832], [88.80944061, 21.80416107], [88.80944061, 21.80445099], [88.81111145, 21.80611038], [88.81111145, 21.80639076], [88.81138611, 21.80666542], [88.81138611, 21.8069458], [88.8116684, 21.80722046], [88.81207275, 21.80777931], [88.81241608, 21.80822945], [88.81273651, 21.8086319], [88.81304169, 21.809021], [88.81331635, 21.80941963], [88.81360626, 21.80981255], [88.81388855, 21.8101902], [88.81412506, 21.81053925], [88.81427002, 21.81090927], [88.81443787, 21.81123734], [88.81458282, 21.81153488], [88.81469727, 21.81184578], [88.81476593, 21.81216049], [88.81491089, 21.81244278], [88.81503296, 21.81273079], [88.81520081, 21.81301689], [88.81531525, 21.81335258], [88.81546783, 21.81365013], [88.81561279, 21.81397057], [88.81577301, 21.8142395], [88.81593323, 21.81451988], [88.81613922, 21.81476021], [88.81638336, 21.81501007], [88.81659698, 21.81527901], [88.81678772, 21.81555939], [88.81693268, 21.81586075], [88.81703186, 21.81616974], [88.81716156, 21.81642914], [88.81726074, 21.81674767], [88.81741333, 21.81703949], [88.81751251, 21.81735039], [88.81764221, 21.8176384], [88.81777954, 21.8179245], [88.8179245, 21.81820297], [88.81809235, 21.81848145], [88.81829071, 21.81875038], [88.81846619, 21.81908035], [88.81864166, 21.81946754], [88.81887054, 21.81986046], [88.8190918, 21.82028008], [88.81933594, 21.82070923], [88.81962585, 21.82114029], [88.81993866, 21.82159805], [88.82029724, 21.82207108], [88.82071686, 21.82245255], [88.82119751, 21.8227005], [88.82167053, 21.82290077], [88.82228088, 21.8225708], [88.82290649, 21.82240105], [88.82337189, 21.8221283], [88.82363129, 21.82167053], [88.82389069, 21.82120132], [88.82415771, 21.82076645], [88.82437134, 21.82031822], [88.82446289, 21.81978989], [88.82458496, 21.81931877], [88.82472229, 21.81887054], [88.82489014, 21.81847572], [88.82507324, 21.8180809], [88.82528687, 21.8176918], [88.82554626, 21.81731033], [88.82583618, 21.81690025], [88.82611084, 21.81645966], [88.82634735, 21.81596947], [88.82655334, 21.81542015], [88.82685089, 21.81495094], [88.82711029, 21.81449509], [88.82746124, 21.81415939], [88.82779694, 21.81386948], [88.82810211, 21.81357002], [88.82839203, 21.81324959], [88.82866669, 21.81287575], [88.82899475, 21.81254768], [88.82936096, 21.81228065], [88.82962799, 21.81195259], [88.8298645, 21.81164169], [88.83003235, 21.81131935], [88.83023834, 21.81102943], [88.83041382, 21.81072807], [88.83058929, 21.81034088], [88.83074188, 21.80993652], [88.8306427, 21.80943108], [88.83076477, 21.80892372], [88.83099365, 21.80838966], [88.83096313, 21.80779839], [88.83069611, 21.80724907], [88.8303833, 21.80677986], [88.83003998, 21.80641937], [88.82972717, 21.80608177], [88.82943726, 21.80569077], [88.82913971, 21.80524063], [88.82888031, 21.80470276], [88.82868958, 21.80455399], [88.82833099, 21.80427933], [88.82807922, 21.80402946]]], [[[88.27396393, 21.79079056], [88.27464294, 21.79063988], [88.27536774, 21.79074478], [88.27609253, 21.79060936], [88.27681732, 21.79055977], [88.2775116, 21.79055023], [88.27819061, 21.79051971], [88.27883148, 21.7904129], [88.27944183, 21.79025078], [88.279953, 21.79006386], [88.2804718, 21.78992462], [88.28096771, 21.78974152], [88.2815094, 21.78959846], [88.28208923, 21.78944016], [88.28269958, 21.7892704], [88.28334045, 21.78911972], [88.28392029, 21.7888298], [88.28443146, 21.78846169], [88.28491211, 21.78806114], [88.2853775, 21.78767014], [88.28580475, 21.78727722], [88.28617096, 21.78684807], [88.28645325, 21.78638077], [88.28668213, 21.78590584], [88.28691101, 21.78543282], [88.28712463, 21.78492928], [88.28739166, 21.78442955], [88.2873764, 21.78394127], [88.2875824, 21.78351021], [88.2877121, 21.78302002], [88.28781128, 21.78248978], [88.28800201, 21.78196144], [88.28804016, 21.78129959], [88.2879715, 21.78062248], [88.2877121, 21.78012466], [88.28742981, 21.77973175], [88.28729248, 21.77948952], [88.28720093, 21.77932549], [88.28694153, 21.77893257], [88.28668976, 21.7785511], [88.28647614, 21.77815056], [88.28623199, 21.7777729], [88.28601074, 21.77738571], [88.28579712, 21.77693176], [88.28555298, 21.77651978], [88.28533173, 21.77614212], [88.28520966, 21.77578926], [88.28501129, 21.77561951], [88.28472137, 21.77527809], [88.28472137, 21.77472115], [88.28444672, 21.77444458], [88.28444672, 21.77305603], [88.2841568, 21.77277946], [88.2841568, 21.77166939], [88.28388977, 21.77139091], [88.28388977, 21.77082825], [88.28360748, 21.7705555], [88.28360748, 21.77000046], [88.28333282, 21.76971817], [88.28333282, 21.76944351], [88.28305817, 21.76944351], [88.28277588, 21.76972198], [88.28250122, 21.76971817], [88.28250122, 21.77000046], [88.28221893, 21.77028084], [88.28193665, 21.77028084], [88.28083038, 21.77139091], [88.28028107, 21.77139091], [88.27999878, 21.77166939], [88.27971649, 21.77166939], [88.27889252, 21.77249908], [88.27861023, 21.77249908], [88.2783432, 21.77277946], [88.27805328, 21.77277756], [88.27749634, 21.7733326], [88.27722168, 21.7733326], [88.27694702, 21.77361107], [88.27666473, 21.77361107], [88.27645111, 21.77388954], [88.27607727, 21.77416611], [88.27580261, 21.77437019], [88.27567291, 21.77447128], [88.27523804, 21.77478027], [88.27482605, 21.77515984], [88.27443695, 21.77551079], [88.27406311, 21.77582932], [88.27371216, 21.77613068], [88.27339172, 21.77645111], [88.27311707, 21.77680016], [88.27294922, 21.77717018], [88.27275848, 21.77748871], [88.27255249, 21.77775192], [88.27236938, 21.77804184], [88.27215576, 21.77833748], [88.27189636, 21.77869415], [88.27163696, 21.77915955], [88.2713089, 21.77963066], [88.27094269, 21.78005028], [88.27063751, 21.78046608], [88.2703476, 21.78083229], [88.27007294, 21.78117943], [88.26980591, 21.78156281], [88.26950073, 21.78193092], [88.26912689, 21.78229713], [88.26900482, 21.78246117], [88.26876831, 21.78277016], [88.26835632, 21.7833004], [88.26793671, 21.78386116], [88.26747894, 21.78442001], [88.26702118, 21.78495979], [88.26669312, 21.78553963], [88.26638794, 21.78606987], [88.26611328, 21.78655243], [88.26583099, 21.78700066], [88.26555634, 21.78744125], [88.26528168, 21.78786469], [88.26500702, 21.78829002], [88.26477051, 21.78874016], [88.2645874, 21.78917694], [88.26442719, 21.78960037], [88.26431274, 21.79001045], [88.26418304, 21.79038048], [88.26407623, 21.79072762], [88.26394653, 21.79102707], [88.26387024, 21.7913475], [88.26374054, 21.79167938], [88.2636261, 21.79201126], [88.2636261, 21.79236031], [88.26373291, 21.79267693], [88.26390076, 21.79275131], [88.2640686, 21.79282379], [88.26420593, 21.7927742], [88.26469421, 21.79261017], [88.26534271, 21.7924614], [88.26591492, 21.79229355], [88.26647949, 21.79221344], [88.26700592, 21.79214287], [88.26746368, 21.79199791], [88.26795197, 21.7918911], [88.2684021, 21.79169846], [88.26886749, 21.79154968], [88.26933289, 21.79142952], [88.2698288, 21.79138947], [88.27030945, 21.79136086], [88.27077484, 21.79126549], [88.27128601, 21.79114914], [88.27180481, 21.79111671], [88.27231598, 21.79108429], [88.27280426, 21.79096222], [88.27333832, 21.79085159], [88.27396393, 21.79079056]]], [[[88.50527954, 21.7829895], [88.50389099, 21.78138924], [88.50377655, 21.78139114], [88.50365448, 21.78130341], [88.5034256, 21.78114891], [88.50296783, 21.78100967], [88.50250244, 21.7808342], [88.50195313, 21.78083038], [88.50166321, 21.78111076], [88.50166321, 21.78139114], [88.50138855, 21.78139114], [88.50111389, 21.78166771], [88.50101471, 21.78183174], [88.50119019, 21.78219032], [88.50135803, 21.78256989], [88.50141907, 21.78296089], [88.50157928, 21.78326035], [88.5016861, 21.78357124], [88.50186157, 21.7838192], [88.50195313, 21.78412628], [88.50205994, 21.78442001], [88.5022583, 21.78470039], [88.50250244, 21.78499031], [88.5027771, 21.78532982], [88.50308228, 21.78570747], [88.50345612, 21.78607941], [88.50392914, 21.78643036], [88.50440979, 21.78679848], [88.50486755, 21.78723145], [88.50546265, 21.78741074], [88.50583649, 21.78778648], [88.50611115, 21.78833389], [88.5063858, 21.78833389], [88.50693512, 21.78750038], [88.50639343, 21.7857666], [88.5061264, 21.78524971], [88.50611115, 21.78471756], [88.50583649, 21.78444481], [88.50569153, 21.78388977], [88.50527954, 21.7829895]]], [[[88.30583191, 21.75158119], [88.30583954, 21.75222015], [88.30583191, 21.75283051], [88.30576324, 21.75337982], [88.30544281, 21.75382042], [88.30525208, 21.75435066], [88.30503845, 21.75485992], [88.30495453, 21.75540543], [88.30474854, 21.75592041], [88.30455017, 21.75650978], [88.30445862, 21.75720978], [88.30436707, 21.75791931], [88.30410004, 21.75851631], [88.30371857, 21.7589798], [88.30382538, 21.75931549], [88.30387115, 21.75962067], [88.30381012, 21.75991058], [88.30366516, 21.76017952], [88.30361938, 21.7604866], [88.30358887, 21.76080322], [88.30345154, 21.76110077], [88.30328369, 21.7614193], [88.30308533, 21.76180458], [88.30303192, 21.76230049], [88.3028717, 21.7627697], [88.30269623, 21.76319122], [88.30251312, 21.7635479], [88.30237579, 21.7638607], [88.30222321, 21.7641201], [88.30205536, 21.76434708], [88.30193329, 21.76463127], [88.30177307, 21.76490974], [88.30166626, 21.76525116], [88.30155945, 21.76562119], [88.30141449, 21.76597977], [88.30126953, 21.76638031], [88.3010788, 21.76679993], [88.30082703, 21.76721001], [88.30053711, 21.76764107], [88.30027771, 21.76811028], [88.3000412, 21.76861954], [88.29995728, 21.76919174], [88.29973602, 21.76972961], [88.29959106, 21.77025986], [88.29946136, 21.77075577], [88.2993927, 21.77124023], [88.29920197, 21.77166939], [88.2991333, 21.77215958], [88.29892731, 21.77263069], [88.29888916, 21.77312088], [88.29888916, 21.77360153], [88.29888916, 21.77401924], [88.29885101, 21.77443504], [88.2986908, 21.77482033], [88.29859161, 21.77531815], [88.29849243, 21.77585983], [88.29850006, 21.77637672], [88.29837036, 21.77674103], [88.29833984, 21.77715111], [88.29850006, 21.7777195], [88.29860687, 21.77823067], [88.29864502, 21.77869606], [88.29865265, 21.77915955], [88.29865265, 21.77963448], [88.29866028, 21.7798996], [88.29866028, 21.78010941], [88.29872131, 21.78055954], [88.29886627, 21.78092575], [88.29901123, 21.78127289], [88.29920959, 21.78157234], [88.29946136, 21.78185081], [88.29980469, 21.78211784], [88.3003006, 21.78235817], [88.30084991, 21.78260612], [88.30136108, 21.78279305], [88.30181885, 21.78290176], [88.30226135, 21.78292847], [88.30271149, 21.78297043], [88.30303192, 21.7829361], [88.30316162, 21.78292465], [88.30358887, 21.78282928], [88.30393982, 21.78264046], [88.30426788, 21.78250122], [88.30474091, 21.78252983], [88.30526733, 21.78264046], [88.30573273, 21.78269196], [88.30615997, 21.78264236], [88.30657196, 21.78251266], [88.30698395, 21.78240585], [88.30741119, 21.78243065], [88.30782318, 21.78246117], [88.30821228, 21.78245163], [88.30857849, 21.78240585], [88.30893707, 21.78232193], [88.30931091, 21.78223038], [88.30970001, 21.78222084], [88.31011963, 21.78230095], [88.31060028, 21.78239059], [88.3105545, 21.78249931], [88.31111145, 21.78305626], [88.31111145, 21.78360748], [88.31138611, 21.78388977], [88.31138611, 21.78444481], [88.3114624, 21.78478813], [88.31144714, 21.78523064], [88.31130981, 21.7855835], [88.31110382, 21.78587341], [88.31088257, 21.78614044], [88.31066132, 21.78643036], [88.31041718, 21.78674126], [88.31021881, 21.7870903], [88.31005096, 21.78745079], [88.30996704, 21.78784943], [88.30995178, 21.78829002], [88.3099823, 21.78877068], [88.31006622, 21.7892704], [88.31024933, 21.78976059], [88.31043243, 21.79024124], [88.3106308, 21.79067039], [88.31083679, 21.79104996], [88.31104279, 21.79141808], [88.31118774, 21.79186058], [88.31129456, 21.7924099], [88.3113327, 21.79302979], [88.31128693, 21.79368019], [88.31121826, 21.79437637], [88.31108856, 21.79504013], [88.31085968, 21.79563522], [88.31048584, 21.79614067], [88.31004333, 21.79656029], [88.30960083, 21.79690361], [88.30912781, 21.79721832], [88.30863953, 21.79749107], [88.30806732, 21.79775047], [88.30744934, 21.79799652], [88.30683136, 21.79821968], [88.30622101, 21.79842949], [88.30562592, 21.79861069], [88.30506897, 21.79879951], [88.30450439, 21.79897308], [88.30394745, 21.79912376], [88.30341339, 21.79926109], [88.30285645, 21.79937553], [88.30232239, 21.79948044], [88.30181122, 21.79961014], [88.30129242, 21.79969978], [88.30076599, 21.79978943], [88.30024719, 21.79990959], [88.29972076, 21.80002785], [88.29918671, 21.80018044], [88.29866028, 21.80032921], [88.29814148, 21.80051613], [88.29775238, 21.80067444], [88.29763031, 21.80072594], [88.29709625, 21.80095863], [88.29656219, 21.80129051], [88.29638672, 21.80138969], [88.29555511, 21.8022213], [88.29556274, 21.80249977], [88.29499817, 21.80249977], [88.29444122, 21.80305481], [88.29416656, 21.80277824], [88.29389191, 21.80278015], [88.29427338, 21.80237961], [88.29458618, 21.80195045], [88.2948761, 21.80157852], [88.29518127, 21.80122757], [88.29548645, 21.80088806], [88.2958374, 21.80057907], [88.29619598, 21.80029106], [88.29656982, 21.80002975], [88.29695892, 21.79981041], [88.29737854, 21.79964066], [88.29760742, 21.79953957], [88.29779053, 21.79945755], [88.29823303, 21.7992897], [88.29839325, 21.79925156], [88.29876709, 21.79916954], [88.29936218, 21.79905128], [88.30000305, 21.79887009], [88.30065918, 21.79867744], [88.3013382, 21.79848289], [88.30204773, 21.79832077], [88.30275726, 21.79816055], [88.30348206, 21.7980423], [88.30417633, 21.79792023], [88.3048172, 21.7977562], [88.30541229, 21.79759026], [88.30596161, 21.79739952], [88.30646515, 21.79717636], [88.30696869, 21.79691887], [88.30747986, 21.79663086], [88.3080368, 21.79630089], [88.3085556, 21.79595566], [88.3090744, 21.79556274], [88.30956268, 21.79512405], [88.30998993, 21.79462051], [88.31024933, 21.79404831], [88.31034851, 21.79348564], [88.31031036, 21.79295158], [88.31019592, 21.79245186], [88.31002045, 21.79200554], [88.30982971, 21.7915802], [88.30964661, 21.7911396], [88.30941772, 21.79071045], [88.30918884, 21.7902832], [88.30898285, 21.78985977], [88.30873871, 21.78946114], [88.30851746, 21.78906059], [88.3083725, 21.78862953], [88.3085022, 21.78816032], [88.30869293, 21.78765106], [88.30889893, 21.78713989], [88.30912781, 21.78663063], [88.30938721, 21.78614044], [88.30960846, 21.78567123], [88.30976868, 21.78523254], [88.30987549, 21.78478813], [88.30980682, 21.7843399], [88.30957031, 21.78397179], [88.30973053, 21.78388977], [88.30944824, 21.7836113], [88.30860901, 21.78360748], [88.30812836, 21.7838192], [88.30761719, 21.78397369], [88.30710602, 21.78412437], [88.30657196, 21.78428459], [88.30591583, 21.78440285], [88.30515289, 21.78444862], [88.30439758, 21.78442001], [88.30388641, 21.78443909], [88.30365753, 21.78444862], [88.30285645, 21.78443909], [88.30206299, 21.78442001], [88.30129242, 21.78436089], [88.30060577, 21.78426552], [88.30005646, 21.78407097], [88.29962158, 21.78386307], [88.29924774, 21.78362083], [88.29897308, 21.78331947], [88.29868317, 21.78300095], [88.29840088, 21.78264809], [88.29810333, 21.78226471], [88.29782867, 21.78181076], [88.2975769, 21.78129959], [88.29736328, 21.78076172], [88.29719543, 21.78021049], [88.29718781, 21.77967834], [88.29720306, 21.77929115], [88.29721069, 21.77917862], [88.29721832, 21.7786808], [88.29724121, 21.77814102], [88.29732513, 21.77754021], [88.29750061, 21.77685928], [88.29741669, 21.77630234], [88.29737854, 21.7756691], [88.29721069, 21.7751503], [88.29696655, 21.77474976], [88.29675293, 21.77444267], [88.29653931, 21.7741909], [88.2963028, 21.77404976], [88.29601288, 21.77404976], [88.29569244, 21.77417946], [88.29534149, 21.77436066], [88.29496002, 21.77452278], [88.2946167, 21.77482986], [88.29431152, 21.7752285], [88.2939682, 21.77561378], [88.29363251, 21.77601433], [88.29330444, 21.77644348], [88.29302979, 21.77691269], [88.29280853, 21.77723885], [88.29272461, 21.77735901], [88.29236603, 21.77775955], [88.29202271, 21.77815056], [88.29170227, 21.77858353], [88.29138947, 21.77905846], [88.29104614, 21.77956963], [88.29064941, 21.78005219], [88.29029846, 21.78052139], [88.29003906, 21.78097343], [88.28993225, 21.78141975], [88.28975677, 21.78183174], [88.28970337, 21.78229523], [88.28959656, 21.78275108], [88.28940582, 21.78318977], [88.28910828, 21.78357697], [88.28878021, 21.78395844], [88.28851318, 21.7844696], [88.28826141, 21.78501511], [88.2880249, 21.78574371], [88.28775787, 21.78645134], [88.2874527, 21.78708267], [88.28708649, 21.78763008], [88.28672028, 21.78813744], [88.28636932, 21.78862953], [88.28598022, 21.78906822], [88.28556061, 21.78940964], [88.28508759, 21.78964996], [88.28466797, 21.78985977], [88.28423309, 21.79003906], [88.28382874, 21.79026031], [88.28341675, 21.7904911], [88.28302765, 21.79073906], [88.2826004, 21.79100037], [88.28213501, 21.79125595], [88.28159332, 21.79141808], [88.28104401, 21.7916069], [88.28047943, 21.79167938], [88.27992249, 21.79177094], [88.27936554, 21.79189301], [88.27876282, 21.79193115], [88.27818298, 21.79200935], [88.27771759, 21.79219246], [88.27725983, 21.79234123], [88.27681732, 21.79246521], [88.27635193, 21.79249954], [88.27585602, 21.79255295], [88.275383, 21.79272652], [88.27480316, 21.79277039], [88.27414703, 21.79277992], [88.27346802, 21.79277992], [88.27278137, 21.7927742], [88.27209473, 21.79278374], [88.27141571, 21.79283333], [88.27075958, 21.79298973], [88.27012634, 21.79305077], [88.26954651, 21.7930603], [88.26901245, 21.79306984], [88.26850128, 21.79310989], [88.26802826, 21.79322052], [88.26754761, 21.79331017], [88.26704407, 21.79333687], [88.26654053, 21.79336166], [88.26605225, 21.79342842], [88.26560974, 21.79357147], [88.26512146, 21.79366493], [88.26468658, 21.79381943], [88.2641983, 21.79394913], [88.26387024, 21.79417419], [88.26360321, 21.79444122], [88.26329803, 21.7947197], [88.26296234, 21.79500961], [88.26259613, 21.79532051], [88.26226044, 21.79569054], [88.26197052, 21.79611969], [88.26166534, 21.7965641], [88.26145935, 21.79689598], [88.26139832, 21.79698944], [88.2611618, 21.79741096], [88.26101685, 21.79785156], [88.26087189, 21.7982502], [88.26082611, 21.79865074], [88.26083374, 21.79903793], [88.26082611, 21.79940414], [88.26077271, 21.79974556], [88.26059723, 21.80002975], [88.26049805, 21.80040932], [88.26032257, 21.80083275], [88.26022339, 21.80141068], [88.25998688, 21.80202293], [88.25977325, 21.80270195], [88.25972748, 21.80345154], [88.25977325, 21.80420685], [88.2599411, 21.8049736], [88.26000214, 21.80574036], [88.2600708, 21.8065052], [88.26029968, 21.80719948], [88.26064301, 21.80784988], [88.26104736, 21.80844116], [88.26139069, 21.80903053], [88.26171112, 21.80958748], [88.26204681, 21.81008911], [88.26241302, 21.81057167], [88.26279449, 21.81106949], [88.26329803, 21.81147957], [88.2638092, 21.81193924], [88.26434326, 21.81241417], [88.26493073, 21.81282043], [88.26541901, 21.81330109], [88.2658844, 21.81374931], [88.26637268, 21.8141098], [88.26687622, 21.81439972], [88.26734161, 21.81469917], [88.26779938, 21.81500053], [88.26823425, 21.81529808], [88.26864624, 21.81561089], [88.26911163, 21.81585121], [88.2695694, 21.81607819], [88.2700882, 21.81621552], [88.27057648, 21.8164196], [88.27108765, 21.81666946], [88.27157593, 21.81694031], [88.27205658, 21.81721306], [88.27251434, 21.81749153], [88.27294922, 21.81777954], [88.27337646, 21.81808662], [88.27381897, 21.81837082], [88.27424622, 21.81867027], [88.27468872, 21.81887054], [88.27513885, 21.81903076], [88.27559662, 21.8191452], [88.27606964, 21.81921005], [88.27645874, 21.81940842], [88.27687073, 21.81953049], [88.27723694, 21.81973076], [88.27761841, 21.81996155], [88.27807617, 21.82016945], [88.27861786, 21.82037926], [88.27916718, 21.82063866], [88.27973938, 21.82094383], [88.28032684, 21.82122993], [88.28098297, 21.82142639], [88.28157806, 21.82163048], [88.28214264, 21.82176018], [88.28263092, 21.82193947], [88.28309631, 21.82211876], [88.28359222, 21.82228279], [88.28409576, 21.82250214], [88.28460693, 21.82272148], [88.28518677, 21.82277489], [88.2856369, 21.82279396], [88.28575134, 21.82279968], [88.28629303, 21.82294273], [88.28686523, 21.82303619], [88.28746033, 21.8230896], [88.28800964, 21.82329941], [88.28859711, 21.82343292], [88.28917694, 21.82360077], [88.28975677, 21.8237381], [88.29029846, 21.82380104], [88.29081726, 21.82368851], [88.29129791, 21.82367516], [88.29176331, 21.82381821], [88.29228973, 21.82389069], [88.29283905, 21.82395554], [88.29337311, 21.82411957], [88.29392242, 21.82415962], [88.29447174, 21.82416916], [88.29504395, 21.82420158], [88.29560852, 21.82433319], [88.29621887, 21.82447052], [88.29682159, 21.82471085], [88.29743195, 21.82492828], [88.2980423, 21.82510948], [88.2986145, 21.82530594], [88.2991333, 21.82555389], [88.29964447, 21.82580376], [88.30020905, 21.82600212], [88.30082703, 21.82616425], [88.30140686, 21.82638931], [88.30198669, 21.82665825], [88.30255127, 21.82692909], [88.3030777, 21.82721138], [88.30357361, 21.8274765], [88.30403137, 21.82773018], [88.30446625, 21.82798958], [88.30490875, 21.82825089], [88.30532074, 21.82852936], [88.30574799, 21.82880592], [88.30612183, 21.8290596], [88.30661011, 21.82938957], [88.30702209, 21.82969093], [88.30739594, 21.82999039], [88.30773163, 21.83030128], [88.30799866, 21.83061981], [88.3082428, 21.8309803], [88.30854797, 21.83134842], [88.30887604, 21.83184052], [88.30922699, 21.83236122], [88.3095932, 21.83288193], [88.30992889, 21.83331108], [88.31014252, 21.8337326], [88.31033325, 21.83411026], [88.31053925, 21.83447075], [88.31070709, 21.83488083], [88.31089783, 21.83535767], [88.31113434, 21.8358326], [88.31138611, 21.8362999], [88.3116684, 21.83677673], [88.31194305, 21.83727074], [88.31221008, 21.83782005], [88.31247711, 21.83839989], [88.31277466, 21.83899879], [88.31305695, 21.83959007], [88.3133316, 21.84015465], [88.31356812, 21.84069252], [88.31375122, 21.8412323], [88.31394958, 21.84172058], [88.31417084, 21.84214592], [88.31439972, 21.84254074], [88.31459808, 21.84295082], [88.31478119, 21.84339142], [88.31498718, 21.84381294], [88.31517792, 21.84424591], [88.31535339, 21.84465981], [88.31532288, 21.84505272], [88.31526947, 21.84543991], [88.31523132, 21.8458004], [88.31519318, 21.84613609], [88.31519318, 21.84649086], [88.31523895, 21.84691048], [88.31524658, 21.84736633], [88.31517792, 21.84782982], [88.3150177, 21.84826851], [88.31487274, 21.84870529], [88.31468964, 21.84909439], [88.31447601, 21.84943962], [88.31432343, 21.84981728], [88.31414032, 21.85017395], [88.31389618, 21.8505249], [88.31360626, 21.85087967], [88.31332397, 21.85129547], [88.31304169, 21.8517704], [88.31275177, 21.85228729], [88.31242371, 21.85279465], [88.3119812, 21.85323715], [88.31154633, 21.85363007], [88.31166077, 21.85393715], [88.31194305, 21.85427094], [88.31227112, 21.85466003], [88.31264496, 21.85507584], [88.31272125, 21.85518456], [88.31298065, 21.8555603], [88.31333923, 21.8560791], [88.31376648, 21.85653114], [88.3142395, 21.85691833], [88.31468964, 21.85725975], [88.3151474, 21.85759735], [88.31567383, 21.85786438], [88.31627655, 21.85806656], [88.31684875, 21.85828018], [88.31742859, 21.85850906], [88.31797028, 21.85877991], [88.31851959, 21.85902023], [88.31909943, 21.85920143], [88.31965637, 21.85938072], [88.32021332, 21.85951042], [88.32068634, 21.85967064], [88.32116699, 21.85979462], [88.32161713, 21.85993004], [88.322052, 21.86005974], [88.32254791, 21.86018181], [88.32309723, 21.86029816], [88.3236618, 21.86044693], [88.32428741, 21.86050987], [88.32495117, 21.86057663], [88.32565308, 21.8606739], [88.3261795, 21.86068153], [88.32640076, 21.86069107], [88.32718658, 21.86068344], [88.32797241, 21.86069679], [88.32875061, 21.86070824], [88.32952881, 21.86072159], [88.33032227, 21.86070824], [88.33113098, 21.86068726], [88.33193207, 21.86063957], [88.33264923, 21.86050034], [88.33338165, 21.86046982], [88.33409882, 21.86045265], [88.33481598, 21.8604393], [88.33551025, 21.86046982], [88.33616638, 21.86045265], [88.33677673, 21.86032295], [88.33732605, 21.8602066], [88.33779907, 21.86001968], [88.33831024, 21.85980988], [88.33879089, 21.85954094], [88.33925629, 21.85915947], [88.33973694, 21.85874939], [88.34024048, 21.85837173], [88.34076691, 21.85803032], [88.34127808, 21.85767746], [88.34175873, 21.8572998], [88.3422699, 21.85695076], [88.34279633, 21.85664177], [88.34328461, 21.85632324], [88.34372711, 21.8560009], [88.3441925, 21.85572052], [88.3446579, 21.85548973], [88.34510803, 21.85526657], [88.3454895, 21.85506248], [88.34593201, 21.85499954], [88.34635162, 21.85496521], [88.34674072, 21.85481071], [88.34716034, 21.85473251], [88.34760284, 21.85472107], [88.34806061, 21.85472107], [88.34851074, 21.85472107], [88.34895325, 21.85472107], [88.34938049, 21.85472107], [88.34979248, 21.85473061], [88.3502121, 21.85481071], [88.35063171, 21.85501099], [88.35109711, 21.85518837], [88.35163116, 21.85504913], [88.35212708, 21.85486984], [88.35248566, 21.8545742], [88.35272217, 21.85424232], [88.35277557, 21.85383797], [88.35275269, 21.85341263], [88.3526001, 21.85299683], [88.35250092, 21.85251999], [88.35238647, 21.85198021], [88.35221863, 21.85145378], [88.35204315, 21.85091019], [88.35195923, 21.85033607], [88.35189819, 21.84976006], [88.3516922, 21.84926987], [88.35154724, 21.84879112], [88.35141754, 21.84836006], [88.3514328, 21.84795189], [88.35158539, 21.84754944], [88.35165405, 21.84708977], [88.35170746, 21.84659958], [88.35188293, 21.84613991], [88.35198212, 21.84565926], [88.35218048, 21.84523964], [88.35225677, 21.84476089], [88.35246277, 21.84431076], [88.35250092, 21.84379959], [88.35248566, 21.84325981], [88.35244751, 21.84270287], [88.35249329, 21.84213066], [88.35250092, 21.8415432], [88.35250092, 21.84094048], [88.35250092, 21.84033585], [88.35250092, 21.83973122], [88.35246277, 21.83914948], [88.3522644, 21.83864975], [88.35205841, 21.83815002], [88.35189056, 21.83761024], [88.35164642, 21.83710289], [88.35144806, 21.83660126], [88.3514328, 21.83604813], [88.35138702, 21.83549118], [88.35128021, 21.83492088], [88.35108185, 21.83435249], [88.35100555, 21.83369637], [88.35085297, 21.83311081], [88.35061646, 21.83260155], [88.35054016, 21.83202171], [88.35044098, 21.83141708], [88.35029602, 21.83078957], [88.35031891, 21.83011055], [88.35054779, 21.82944107], [88.35074615, 21.82876968], [88.35077667, 21.82812119], [88.35059357, 21.82751465], [88.35046387, 21.82695007], [88.35037231, 21.82640076], [88.35050201, 21.82588005], [88.35061646, 21.82537079], [88.35070801, 21.8248024], [88.35107422, 21.82425117], [88.35107422, 21.82366943], [88.35112762, 21.82305717], [88.35128021, 21.82246971], [88.35141754, 21.82190514], [88.35163116, 21.82140923], [88.35176086, 21.82088089], [88.35195923, 21.8204155], [88.35221863, 21.81998062], [88.35250092, 21.81954384], [88.35279846, 21.81908226], [88.35316467, 21.81863022], [88.35353851, 21.8181591], [88.35387421, 21.81759644], [88.35415649, 21.81699181], [88.35459137, 21.81650734], [88.35500336, 21.8160305], [88.35544586, 21.8155899], [88.35593414, 21.81520844], [88.35629272, 21.81472969], [88.3565979, 21.81425095], [88.35688782, 21.81382942], [88.3571167, 21.81343079], [88.35732269, 21.8130703], [88.35751343, 21.81274033], [88.35772705, 21.81242943], [88.35795593, 21.81204987], [88.35824585, 21.81163979], [88.35855865, 21.8111496], [88.35887909, 21.81064034], [88.35916901, 21.81009293], [88.35943604, 21.80955124], [88.35971069, 21.80906105], [88.35988617, 21.8085804], [88.36001587, 21.80811119], [88.3602066, 21.8076725], [88.3603363, 21.80718231], [88.36055756, 21.80670166], [88.36073303, 21.80616951], [88.36060333, 21.80554962], [88.36049652, 21.80494118], [88.36029053, 21.80445099], [88.36010742, 21.8039875], [88.3599472, 21.80357361], [88.35974884, 21.80318642], [88.35964966, 21.80273056], [88.35948181, 21.80227089], [88.35946655, 21.80175018], [88.3599472, 21.79898071], [88.36081696, 21.79683113], [88.36138916, 21.79602051], [88.36293793, 21.79483223], [88.3645401, 21.79400826], [88.3659668, 21.79360008], [88.367836, 21.79333687], [88.36898804, 21.79347038], [88.36940765, 21.79347992], [88.3698349, 21.79339409], [88.37021637, 21.7933197], [88.37206268, 21.79245758], [88.37290955, 21.79206276], [88.37309265, 21.79197693], [88.37361145, 21.79185486], [88.37480927, 21.79157448], [88.37507629, 21.7914238], [88.37767792, 21.78996086], [88.37967682, 21.78848076], [88.37996674, 21.78726959], [88.37953949, 21.78619194], [88.37944794, 21.78499985], [88.37917328, 21.78471756], [88.37916565, 21.78416634], [88.37888336, 21.78388977], [88.37888336, 21.78333092], [88.37802887, 21.7793045], [88.37787628, 21.7770195], [88.3781662, 21.77486992], [88.37793732, 21.77355957], [88.37789154, 21.77306366], [88.3780365, 21.77277756], [88.3779068, 21.77249908], [88.3780365, 21.77222061], [88.3777771, 21.77166748], [88.37776184, 21.77111053], [88.37776184, 21.77082825], [88.37805176, 21.7705555], [88.37805176, 21.76971817], [88.37804413, 21.76944351], [88.3779068, 21.76860237], [88.37749481, 21.76818085], [88.37722015, 21.7677803], [88.37695313, 21.76749992], [88.37633514, 21.76725006], [88.37584686, 21.76707649], [88.37541199, 21.76692009], [88.37497711, 21.76671028], [88.37445068, 21.76663971], [88.37386322, 21.76656151], [88.37325287, 21.76666069], [88.37259674, 21.7667408], [88.37194061, 21.76678276], [88.37123871, 21.76666451], [88.37114716, 21.76665115], [88.37042236, 21.7666111], [88.36992645, 21.76679039], [88.36956024, 21.76691628], [88.36920166, 21.76694107], [88.3687973, 21.76695061], [88.36858368, 21.76694679], [88.36837006, 21.76694107], [88.36793518, 21.76694679], [88.36763, 21.76694679], [88.36750793, 21.76694679], [88.36493683, 21.76694679], [88.36450195, 21.76694679], [88.36406708, 21.76694107], [88.36367035, 21.76695061], [88.36332703, 21.76694107], [88.36305237, 21.76694679], [88.36277771, 21.76666451], [88.36250305, 21.76694679], [88.36138916, 21.76694679], [88.36134338, 21.76717567], [88.3611145, 21.7669487], [88.35916901, 21.76694679], [88.35888672, 21.76666451], [88.35749817, 21.76666451], [88.35722351, 21.76694679], [88.35706329, 21.76694679], [88.35691071, 21.76685524], [88.35668945, 21.76672554], [88.35626984, 21.76663971], [88.35587311, 21.76645088], [88.3554306, 21.76637459], [88.3549881, 21.76623917], [88.35453796, 21.76609993], [88.35408783, 21.76592064], [88.35359192, 21.76581192], [88.3531189, 21.76564026], [88.3526001, 21.76556015], [88.35206604, 21.76550102], [88.35157013, 21.76535034], [88.35103607, 21.76523972], [88.35055542, 21.76504326], [88.35002136, 21.76495743], [88.34953308, 21.76474953], [88.34900665, 21.76453972], [88.34854889, 21.76423454], [88.34805298, 21.76394463], [88.34755707, 21.76365852], [88.3470993, 21.76334], [88.34664154, 21.7630291], [88.34619141, 21.76270294], [88.34581757, 21.76232529], [88.34545898, 21.76197052], [88.3451004, 21.76167107], [88.34475708, 21.76138878], [88.34440613, 21.76111031], [88.34409332, 21.76083183], [88.34376526, 21.76055717], [88.34345245, 21.76026917], [88.34317017, 21.7599659], [88.34293365, 21.75958824], [88.34274292, 21.75914955], [88.34250641, 21.75872993], [88.34229279, 21.7582798], [88.34211731, 21.75778961], [88.34192657, 21.75728989], [88.34171295, 21.75681686], [88.34158325, 21.75632858], [88.34140015, 21.75593185], [88.34126282, 21.75557137], [88.34115601, 21.75523186], [88.34099579, 21.75493431], [88.34067535, 21.75435257], [88.34038544, 21.75412369], [88.34047699, 21.75363731], [88.34040833, 21.75309181], [88.34027863, 21.75251007], [88.34013367, 21.75195694], [88.33998108, 21.75144958], [88.3398056, 21.75101089], [88.33994293, 21.75057983], [88.33999634, 21.75013924], [88.33999634, 21.74967003], [88.33999634, 21.74913979], [88.33999634, 21.74855995], [88.34005737, 21.74797058], [88.34024048, 21.74739075], [88.34027863, 21.74683189], [88.34027863, 21.7462883], [88.34027863, 21.7457695], [88.34027863, 21.74527931], [88.34027863, 21.74477005], [88.34027863, 21.74423027], [88.34031677, 21.74365044], [88.34044647, 21.74310112], [88.34034729, 21.74257088], [88.34028625, 21.74204254], [88.34027863, 21.74151039], [88.34027863, 21.74097061], [88.34027863, 21.74047661], [88.34031677, 21.74002457], [88.34050751, 21.73968506], [88.34055328, 21.73944092], [88.34055328, 21.73888969], [88.3408432, 21.73861122], [88.34083557, 21.73805428], [88.34111023, 21.73777962], [88.34111023, 21.73722076], [88.34139252, 21.73694229], [88.34139252, 21.73555565], [88.34166718, 21.7352829], [88.34166718, 21.73500061], [88.34221649, 21.73444176], [88.34222412, 21.73333359], [88.34249878, 21.73305511], [88.34249878, 21.73167038], [88.34278107, 21.73138809], [88.34278107, 21.7305584], [88.34306335, 21.73027992], [88.34306335, 21.72999954], [88.34278107, 21.72972298], [88.34278107, 21.72916794], [88.34306335, 21.72887993], [88.34328461, 21.72838593], [88.34335327, 21.72795105], [88.34347534, 21.72752953], [88.34360504, 21.72711372], [88.34375, 21.72670555], [88.3438797, 21.72638512], [88.34443665, 21.72556114], [88.34443665, 21.72528076], [88.34416962, 21.72500038], [88.34416962, 21.72472], [88.34444427, 21.72444344], [88.34443665, 21.7238903], [88.34527588, 21.72305107], [88.34527588, 21.72249985], [88.34500122, 21.72221947], [88.34500122, 21.72166634], [88.34471893, 21.72138977], [88.34449005, 21.72107315], [88.34438324, 21.72098732], [88.34388733, 21.72055626], [88.34306335, 21.72056007], [88.34221649, 21.71970749], [88.34194183, 21.71972275], [88.34055328, 21.7183342], [88.34027863, 21.7183342], [88.33944702, 21.71750069], [88.33916473, 21.71750069], [88.33898163, 21.71731567], [88.33889008, 21.71722221], [88.33860779, 21.71722221], [88.33849335, 21.71710968], [88.33789825, 21.71651268], [88.33777618, 21.71639061], [88.33760834, 21.71623039], [88.33732605, 21.71594048], [88.33703613, 21.7156601], [88.33693695, 21.71556091], [88.33638763, 21.71500015], [88.33611298, 21.71500015], [88.33583069, 21.71471977], [88.33555603, 21.71472168], [88.33456421, 21.71379852], [88.333992, 21.71339035], [88.33361053, 21.71249962], [88.33333588, 21.71222115], [88.33333588, 21.71194649], [88.33305359, 21.7116642], [88.33262634, 21.71141052], [88.33222961, 21.71043968], [88.33195496, 21.7105732], [88.33139038, 21.71056366], [88.33110809, 21.71056366], [88.33083344, 21.71055412], [88.32888794, 21.71055984], [88.32861328, 21.71027946], [88.32833099, 21.71027946], [88.32776642, 21.70972061], [88.32749939, 21.70972252], [88.32746887, 21.70957947], [88.32704163, 21.70946121], [88.32656097, 21.70950699], [88.32648468, 21.70951462], [88.3260498, 21.70967102], [88.32550049, 21.7096405], [88.32508087, 21.70949173], [88.32492828, 21.70943832], [88.32428741, 21.70919037], [88.32346344, 21.70903206], [88.32311249, 21.70889664], [88.32264709, 21.70889282], [88.3219986, 21.70889282], [88.32126617, 21.70889282], [88.32054138, 21.70889282], [88.31920624, 21.70889282], [88.31864166, 21.70889282], [88.31813812, 21.70889282], [88.31764221, 21.70888901], [88.31710052, 21.70890999], [88.31650543, 21.70900917], [88.31585693, 21.70905304], [88.31530762, 21.70919228], [88.31482697, 21.70944214], [88.31434631, 21.70970345], [88.31382751, 21.70992279], [88.3132782, 21.7100811], [88.31277466, 21.71028328], [88.31228638, 21.71050072], [88.31172943, 21.71058655], [88.31117249, 21.71073914], [88.31060028, 21.71086502], [88.31007385, 21.71111488], [88.30954742, 21.71141052], [88.30905151, 21.71179008], [88.30857849, 21.7122097], [88.3081131, 21.71263123], [88.30776215, 21.71313095], [88.30739594, 21.7136097], [88.30703735, 21.71406746], [88.30669403, 21.71451187], [88.30641174, 21.71495438], [88.30623627, 21.71541023], [88.30612946, 21.71585083], [88.30610657, 21.71627998], [88.30606079, 21.71672058], [88.30587006, 21.7171402], [88.30580139, 21.71760559], [88.30596924, 21.71812248], [88.30609131, 21.71865082], [88.30610657, 21.71918106], [88.30615997, 21.71969795], [88.30633545, 21.72018051], [88.306427, 21.72073364], [88.30667114, 21.72126007], [88.30687714, 21.7218399], [88.30697632, 21.72249031], [88.30718231, 21.72307777], [88.30723572, 21.72369003], [88.30734253, 21.72426987], [88.30752563, 21.72480965], [88.3077774, 21.72531319], [88.30804443, 21.72581291], [88.30822754, 21.72622108], [88.30827332, 21.7263298], [88.30847931, 21.72681808], [88.30861664, 21.72727966], [88.30879211, 21.72769928], [88.30890656, 21.72809029], [88.30909729, 21.72846031], [88.30918884, 21.72884941], [88.30935669, 21.72923088], [88.30944824, 21.72966957], [88.30957031, 21.73011971], [88.30970001, 21.73060036], [88.30973053, 21.73116112], [88.3097229, 21.73177528], [88.30973053, 21.73244286], [88.30973053, 21.7331295], [88.30970001, 21.73376656], [88.30957031, 21.73431015], [88.30945587, 21.73477936], [88.30941772, 21.73520279], [88.30930328, 21.73557091], [88.30916595, 21.73596954], [88.30899811, 21.73641014], [88.30883026, 21.73689079], [88.30860138, 21.73734283], [88.30838013, 21.7377758], [88.3082962, 21.73826981], [88.30812836, 21.73872185], [88.30805206, 21.73919868], [88.30794525, 21.7396965], [88.30774689, 21.74020004], [88.30750275, 21.74073029], [88.30726624, 21.74129295], [88.30717468, 21.74188995], [88.30699158, 21.74244308], [88.30696106, 21.74295998], [88.30693817, 21.7434597], [88.30686951, 21.74392891], [88.30667114, 21.74432945], [88.30641937, 21.74474907], [88.30626678, 21.74525261], [88.30613708, 21.7457428], [88.30610657, 21.7462101], [88.30609131, 21.74666023], [88.30600739, 21.74703026], [88.30586243, 21.74736977], [88.30583191, 21.74774933], [88.30587006, 21.74815178], [88.30605316, 21.74858093], [88.30609131, 21.74911118], [88.30600739, 21.7496891], [88.30586243, 21.75029945], [88.30583191, 21.75093842], [88.30583191, 21.75158119]]], [[[88.99957275, 21.8116703], [88.99972534, 21.81083298], [88.99973297, 21.81138992], [89.0, 21.8116703], [89.00137329, 21.81117821], [89.00170898, 21.81116486], [89.00230408, 21.81113434], [89.00262451, 21.81112289], [89.00296021, 21.8109436], [89.00315857, 21.81076813], [89.00338745, 21.81064987], [89.0040741, 21.81053162], [89.00473022, 21.81083488], [89.00537109, 21.81076813], [89.00585175, 21.81046104], [89.00682831, 21.8106308], [89.00734711, 21.81060982], [89.00786591, 21.81068993], [89.00836945, 21.81044006], [89.00892639, 21.81078911], [89.00927734, 21.81098366], [89.00965118, 21.81106186], [89.01017761, 21.81129456], [89.01053619, 21.81143188], [89.01082611, 21.81143188], [89.0111084, 21.81136513], [89.01139832, 21.81136513], [89.01161194, 21.81143188], [89.01203918, 21.81163025], [89.01254272, 21.81184006], [89.01304626, 21.81196976], [89.01354218, 21.81203842], [89.01367188, 21.81207848], [89.01397705, 21.81217384], [89.01454926, 21.8123703], [89.01503754, 21.81244278], [89.01548767, 21.81250954], [89.01584625, 21.81250954], [89.01626587, 21.8122406], [89.01647949, 21.81196976], [89.01661682, 21.81163025], [89.01654816, 21.81123161], [89.01654816, 21.81082726], [89.01641083, 21.81036186], [89.0161972, 21.8096199], [89.01612091, 21.80830956], [89.01611328, 21.80799103], [89.01611328, 21.80763054], [89.01605225, 21.80724335], [89.01587677, 21.80687141], [89.01574707, 21.8064537], [89.015625, 21.80603409], [89.01548767, 21.80550957], [89.01532745, 21.80391121], [89.01528168, 21.80348587], [89.01529694, 21.80302048], [89.01512146, 21.80066299], [89.01490784, 21.79992485], [89.01447296, 21.79878044], [89.01419067, 21.7985096], [89.01383209, 21.79797363], [89.0137558, 21.79696465], [89.0137558, 21.79568863], [89.01386261, 21.7940712], [89.01436615, 21.79360962], [89.01491547, 21.79301071], [89.01515198, 21.79249573], [89.01522064, 21.7918911], [89.01515198, 21.79128075], [89.01503754, 21.79073906], [89.0147934, 21.79034996], [89.01449585, 21.79008102], [89.01412201, 21.79002953], [89.01389313, 21.78973007], [89.01395416, 21.78931808], [89.0147171, 21.78895569], [89.01499939, 21.78861046], [89.01503754, 21.78833008], [89.01506042, 21.78787041], [89.01506805, 21.78730965], [89.01506805, 21.78673172], [89.0151062, 21.78616905], [89.0152359, 21.78567123], [89.01532745, 21.78519058], [89.01547241, 21.7847805], [89.01554108, 21.78440285], [89.01555634, 21.78405952], [89.01558685, 21.78375053], [89.01568604, 21.78346062], [89.01580048, 21.78312111], [89.01589203, 21.78267288], [89.01609039, 21.78214836], [89.01631927, 21.78154945], [89.01672363, 21.78098679], [89.01669312, 21.78043938], [89.016716, 21.77987099], [89.01696014, 21.77934074], [89.01725006, 21.77888107], [89.01740265, 21.77845955], [89.01724243, 21.77786064], [89.01714325, 21.77736473], [89.01724243, 21.77691078], [89.01741028, 21.77647018], [89.0175705, 21.77602959], [89.01779175, 21.77564049], [89.01802826, 21.77526093], [89.01817322, 21.77481079], [89.01811218, 21.77432251], [89.01807404, 21.77380562], [89.01809692, 21.77331924], [89.01822662, 21.77290916], [89.01844788, 21.77255058], [89.01870728, 21.77218056], [89.01899719, 21.77173042], [89.01928711, 21.77120972], [89.01945496, 21.77059746], [89.0196228, 21.76996994], [89.01992798, 21.76947975], [89.02017212, 21.76902008], [89.02039337, 21.76859093], [89.02052307, 21.76815033], [89.02054596, 21.7676506], [89.0205307, 21.76711464], [89.02060699, 21.76658249], [89.02074432, 21.7660923], [89.02087402, 21.76561546], [89.02105713, 21.76514053], [89.02113342, 21.76468849], [89.0212326, 21.76428032], [89.02139282, 21.76391983], [89.02155304, 21.7635994], [89.02169037, 21.76330185], [89.02184296, 21.76303291], [89.02198792, 21.76276207], [89.02214813, 21.76250458], [89.02223206, 21.76214409], [89.02233124, 21.76174164], [89.0224762, 21.76131821], [89.02256775, 21.76085091], [89.02253723, 21.76021194], [89.02285004, 21.75986481], [89.02363586, 21.75954247], [89.02373505, 21.75905037], [89.02330017, 21.75897026], [89.02270508, 21.75918579], [89.02194214, 21.75939941], [89.02181244, 21.75943565], [89.02144623, 21.7599659], [89.02113342, 21.76032448], [89.02083588, 21.76074028], [89.02056122, 21.7611599], [89.02027893, 21.76155663], [89.01996613, 21.76192284], [89.0196228, 21.7622509], [89.01924896, 21.76258087], [89.01888275, 21.7628994], [89.01849365, 21.76320839], [89.01809692, 21.76356125], [89.01770782, 21.76393509], [89.0172348, 21.76429367], [89.016716, 21.76464081], [89.01616669, 21.76496124], [89.015625, 21.76527214], [89.01508331, 21.76555061], [89.01454163, 21.76579857], [89.01400757, 21.76597023], [89.01348877, 21.76608276], [89.01300049, 21.76610756], [89.0125351, 21.76611137], [89.01208496, 21.76612282], [89.01165009, 21.76616859], [89.01123047, 21.76629257], [89.01076508, 21.76637459], [89.01026917, 21.76637077], [89.00978851, 21.76633835], [89.00933838, 21.76626968], [89.00891113, 21.76622009], [89.00847626, 21.7663002], [89.00800323, 21.76633835], [89.00746155, 21.7663517], [89.00689697, 21.7663517], [89.00634003, 21.7663002], [89.00582123, 21.76618004], [89.00530243, 21.76613045], [89.00467682, 21.76610947], [89.00398254, 21.76610184], [89.00319672, 21.76608467], [89.00263977, 21.76603127], [89.00208282, 21.76597977], [89.0, 21.7658329], [88.99973297, 21.76610947], [88.99944305, 21.76638985], [88.9991684, 21.76666451], [88.99880981, 21.76694107], [88.99861145, 21.76749992], [88.99810791, 21.76861191], [88.99807739, 21.76880074], [88.99804688, 21.7690239], [88.99833679, 21.76971817], [88.99861145, 21.77000046], [88.99894714, 21.77041054], [88.99949646, 21.77075958], [89.0, 21.7705555], [89.00042725, 21.77090645], [89.0005188, 21.77098083], [89.00086975, 21.77119255], [89.00132751, 21.77153969], [89.00164795, 21.77175713], [89.0019989, 21.77203369], [89.00258636, 21.77223206], [89.00280762, 21.77231979], [89.00318909, 21.77247047], [89.00379944, 21.77271271], [89.00435638, 21.77299118], [89.00488281, 21.77330971], [89.00541687, 21.77360153], [89.00596619, 21.77383995], [89.00653839, 21.77404022], [89.00705719, 21.77423286], [89.00753021, 21.77447128], [89.00798035, 21.77472115], [89.008461, 21.77499008], [89.00897217, 21.77527046], [89.00952148, 21.77555275], [89.01004028, 21.77583122], [89.01055145, 21.77612686], [89.01100159, 21.77646065], [89.01138306, 21.77685165], [89.01168823, 21.77724648], [89.01196289, 21.77766609], [89.01222992, 21.77809143], [89.01248169, 21.77853012], [89.01267242, 21.77897072], [89.01275635, 21.77939987], [89.01278687, 21.77980042], [89.01277924, 21.78018188], [89.0127182, 21.78054428], [89.0125351, 21.78089142], [89.01235962, 21.78125], [89.01219177, 21.78160667], [89.01194763, 21.78194427], [89.01166534, 21.78228378], [89.01133728, 21.78260994], [89.01095581, 21.78292847], [89.01056671, 21.78325081], [89.01014709, 21.78354073], [89.00967407, 21.78376389], [89.00917816, 21.78392029], [89.00868988, 21.78412056], [89.00818634, 21.78427124], [89.00772858, 21.78449059], [89.00726318, 21.78473091], [89.00679016, 21.78495979], [89.00627899, 21.78512955], [89.00576019, 21.78532028], [89.00524902, 21.78553963], [89.00470734, 21.78571701], [89.00417328, 21.78588104], [89.00366974, 21.78610611], [89.00320435, 21.78631401], [89.00271606, 21.78646278], [89.00222015, 21.78662109], [89.00166321, 21.78673172], [89.00109863, 21.78691101], [89.00054932, 21.78712654], [89.0, 21.78722191], [88.99958801, 21.78739548], [88.99915314, 21.78765106], [88.99864197, 21.7877903], [88.99810028, 21.78791046], [88.9974823, 21.78802109], [88.99681091, 21.78809738], [88.99617767, 21.78833008], [88.99552917, 21.78860283], [88.99487305, 21.78881264], [88.9941864, 21.78891945], [88.99359131, 21.78909111], [88.99299622, 21.78922081], [88.99250031, 21.78938103], [88.99201965, 21.78944969], [88.99153137, 21.78950882], [88.9909668, 21.78960037], [88.99034882, 21.78975105], [88.99018097, 21.79003906], [88.99009705, 21.79042053], [88.99002075, 21.7907505], [88.98999786, 21.79111671], [88.99003601, 21.79154205], [88.990242, 21.79198074], [88.9903717, 21.7924614], [88.99057007, 21.79289436], [88.9908371, 21.79327965], [88.9910965, 21.79364967], [88.9913559, 21.79398727], [88.99154663, 21.79432869], [88.99169159, 21.79467964], [88.99191284, 21.79496956], [88.99208832, 21.79529572], [88.99221039, 21.79566193], [88.9923172, 21.7960701], [88.99251556, 21.79646683], [88.9927597, 21.79688072], [88.99298859, 21.79739952], [88.99323273, 21.79795074], [88.99346161, 21.79848862], [88.99363708, 21.79903412], [88.99378204, 21.79958153], [88.99388123, 21.80008888], [88.99396515, 21.80060959], [88.99414063, 21.80108833], [88.99425507, 21.80158615], [88.99442291, 21.8020401], [88.9944458, 21.80253029], [88.9944458, 21.80302811], [88.9944458, 21.80352974], [88.9944458, 21.80404091], [88.9944458, 21.80454826], [88.9944458, 21.80506134], [88.99446106, 21.8055706], [88.99453735, 21.80608177], [88.99460602, 21.80657005], [88.99468994, 21.80711174], [88.99465942, 21.80763626], [88.99468994, 21.80812073], [88.99460602, 21.80859947], [88.99463654, 21.80910683], [88.99449921, 21.80957222], [88.99450684, 21.80991936], [88.99451447, 21.81008148], [88.99443817, 21.81060982], [88.99446106, 21.81119919], [88.99459076, 21.8117981], [88.99485779, 21.81232643], [88.995224, 21.81250381], [88.99534607, 21.81256294], [88.99593353, 21.81254005], [88.99655151, 21.81250954], [88.99720764, 21.81245995], [88.99784851, 21.81229591], [88.9985199, 21.81215286], [88.99909973, 21.81191826], [88.99957275, 21.8116703]]], [[[88.91583252, 21.82583427], [88.91638947, 21.82527733], [88.91665649, 21.82529259], [88.91750336, 21.8244381], [88.91777802, 21.82444382], [88.91833496, 21.82389069], [88.91860962, 21.82389069], [88.91889191, 21.82361031], [88.91916656, 21.82361031], [88.91944122, 21.82332993], [88.91972351, 21.82333374], [88.91999817, 21.82305527], [88.92056274, 21.82305908], [88.92082977, 21.82278061], [88.92193604, 21.82278061], [88.92222595, 21.82305908], [88.92305756, 21.82305527], [88.9232254, 21.82322311], [88.92333221, 21.82333374], [88.92388916, 21.82332993], [88.92444611, 21.82389069], [88.92472076, 21.82389069], [88.92527771, 21.82389069], [88.92694092, 21.82222748], [88.92778015, 21.82222748], [88.92804718, 21.82195091], [88.92888641, 21.82195091], [88.9291687, 21.82222748], [88.93000031, 21.82222748], [88.93026733, 21.82250023], [88.93055725, 21.82250023], [88.93083191, 21.82278061], [88.93110657, 21.82278061], [88.93138885, 21.82250023], [88.93499756, 21.82250023], [88.93527985, 21.82222748], [88.93553925, 21.82222748], [88.93553925, 21.82195091], [88.93582916, 21.82167053], [88.93582916, 21.81999969], [88.93611145, 21.81972122], [88.93611145, 21.81916428], [88.93638611, 21.81888962], [88.93638611, 21.81861115], [88.93694305, 21.81805992], [88.93694305, 21.81777954], [88.93723297, 21.81750107], [88.93723297, 21.81666946], [88.9366684, 21.81610107], [88.9355545, 21.81611061], [88.93527985, 21.81583214], [88.93499756, 21.81583214], [88.93444824, 21.8152771], [88.93416595, 21.81528282], [88.93332672, 21.81444168], [88.93333435, 21.81416702], [88.93305206, 21.81389046], [88.93305206, 21.81361008], [88.9327774, 21.81333351], [88.9327774, 21.81305504], [88.93250275, 21.81278038], [88.93250275, 21.8116703], [88.93222046, 21.81138992], [88.93222046, 21.81082916], [88.93250275, 21.81055641], [88.93222046, 21.81028938], [88.93222046, 21.80944061], [88.9311142, 21.80833244], [88.93083191, 21.80833244], [88.93055725, 21.80805779], [88.93026733, 21.80805969], [88.93000031, 21.80778122], [88.92973328, 21.80778122], [88.92944336, 21.80750084], [88.9291687, 21.80750084], [88.92888641, 21.80722046], [88.92861176, 21.80722237], [88.92778015, 21.80638885], [88.92778015, 21.80611038], [88.92749786, 21.80583], [88.92749786, 21.80555344], [88.92722321, 21.80528069], [88.92722321, 21.80445099], [88.92694092, 21.80416107], [88.92694092, 21.80361176], [88.92722321, 21.80333328], [88.92722321, 21.80249977], [88.92749786, 21.80221939], [88.92749786, 21.80194473], [88.92778015, 21.80166626], [88.92778015, 21.80000114], [88.92749786, 21.79972076], [88.92749786, 21.7994442], [88.92666626, 21.79861069], [88.92666626, 21.7983284], [88.92555237, 21.79722214], [88.92527771, 21.79722214], [88.92472076, 21.7966671], [88.92444611, 21.79667091], [88.92388916, 21.79610825], [88.9236145, 21.79611206], [88.92305756, 21.79555511], [88.9227829, 21.79556084], [88.92193604, 21.7947197], [88.92166901, 21.7947216], [88.92111206, 21.79416847], [88.92056274, 21.79417038], [88.92028046, 21.79389], [88.91999817, 21.79389], [88.91971588, 21.79360962], [88.91944122, 21.79361153], [88.91921997, 21.79338837], [88.91833496, 21.79249954], [88.91832733, 21.79222107], [88.91805267, 21.79222488], [88.91805267, 21.79194641], [88.91777802, 21.79166412], [88.91779327, 21.79083061], [88.91805267, 21.79055405], [88.91805267, 21.79027939], [88.91860962, 21.78972054], [88.91889191, 21.78972244], [88.91916656, 21.78944206], [88.91999817, 21.78944206], [88.92028046, 21.7891674], [88.92111206, 21.7891674], [88.92138672, 21.78944206], [88.92166901, 21.78944206], [88.92194366, 21.7891674], [88.92250061, 21.78918076], [88.92305756, 21.78861046], [88.92305756, 21.78833008], [88.92333221, 21.78805542], [88.92305756, 21.78778267], [88.92305756, 21.78722191], [88.92277527, 21.78694534], [88.9227829, 21.78667259], [88.92193604, 21.78583145], [88.92194366, 21.78527832], [88.92166901, 21.78499985], [88.92166901, 21.78416824], [88.92138672, 21.78388977], [88.92138672, 21.78333092], [88.92111206, 21.78305626], [88.92111206, 21.78249931], [88.92082977, 21.78222084], [88.92082977, 21.78166771], [88.92056274, 21.78139114], [88.92056274, 21.78083038], [88.92028046, 21.78055763], [88.92028046, 21.78028107], [88.91999817, 21.77999115], [88.91999817, 21.77944374], [88.91972351, 21.77916527], [88.91971588, 21.77861023], [88.91944122, 21.77832985], [88.91944122, 21.77805328], [88.91916656, 21.77778053], [88.91916656, 21.77750015], [88.91860962, 21.77695084], [88.91860962, 21.7761097], [88.91833496, 21.77583122], [88.91833496, 21.77527809], [88.91805267, 21.77499962], [88.91805267, 21.77417946], [88.91832733, 21.77388954], [88.91832733, 21.77361107], [88.91860962, 21.7733326], [88.91860962, 21.77305603], [88.91916656, 21.77249908], [88.91916656, 21.77193832], [88.91944122, 21.77166748], [88.91944122, 21.77000046], [88.91889191, 21.7694397], [88.91860962, 21.76944351], [88.91694641, 21.7677784], [88.91665649, 21.7677803], [88.91555786, 21.76667023], [88.91555786, 21.76638985], [88.91249847, 21.76333046], [88.91249847, 21.7630558], [88.91165924, 21.76222038], [88.91166687, 21.76194382], [88.91139221, 21.76167107], [88.91139221, 21.76083183], [88.91110992, 21.76055527], [88.91110992, 21.75972176], [88.91083527, 21.75944519], [88.9108429, 21.75917244], [88.91110992, 21.75889015], [88.91110992, 21.75861168], [88.91139221, 21.75833321], [88.91139221, 21.75805473], [88.91166687, 21.75777817], [88.91165924, 21.75749969], [88.91194153, 21.75722122], [88.91194153, 21.75694466], [88.91222382, 21.75666618], [88.91221619, 21.75611115], [88.91249847, 21.75582123], [88.91249847, 21.75555611], [88.91278076, 21.75527954], [88.91165924, 21.75416946], [88.9108429, 21.75416946], [88.91062927, 21.75396156], [88.91055298, 21.75388908], [88.90944672, 21.75389099], [88.90926361, 21.75370407], [88.90888977, 21.75333023], [88.90860748, 21.75333595], [88.90833282, 21.75305748], [88.90805817, 21.75307083], [88.90777588, 21.75278091], [88.90750122, 21.75278091], [88.90718842, 21.75246811], [88.90694427, 21.75222206], [88.90638733, 21.75222206], [88.90611267, 21.75194359], [88.90583038, 21.75194359], [88.90555573, 21.75166512], [88.90222168, 21.75167084], [88.90194702, 21.75139046], [88.9016571, 21.75167084], [88.90083313, 21.75166512], [88.90055847, 21.75194359], [88.89778137, 21.75194359], [88.89749908, 21.75222206], [88.8972168, 21.75222015], [88.89694214, 21.75250053], [88.89665985, 21.75250053], [88.89639282, 21.75278091], [88.89611053, 21.75277519], [88.89554596, 21.75333023], [88.89555359, 21.75388908], [88.89499664, 21.75444031], [88.89499664, 21.75500107], [88.89472198, 21.75527954], [88.89472198, 21.75555611], [88.89499664, 21.75582123], [88.89499664, 21.75777817], [88.89527893, 21.75805473], [88.89527893, 21.75861168], [88.89554596, 21.75889015], [88.89554596, 21.75917244], [88.89583588, 21.75945282], [88.89583588, 21.76167107], [88.89611053, 21.76194382], [88.89611053, 21.76444435], [88.89639282, 21.76472092], [88.89639282, 21.76556015], [88.8972168, 21.76638985], [88.89722443, 21.76666451], [88.89749908, 21.76694679], [88.89749908, 21.76721954], [88.89778137, 21.76749992], [88.89778137, 21.76860809], [88.89805603, 21.76889038], [88.89805603, 21.77000046], [88.89833069, 21.77028084], [88.89833069, 21.7705555], [88.89861298, 21.77082825], [88.89861298, 21.77111053], [88.89944458, 21.77194405], [88.89943695, 21.77222061], [88.89971924, 21.77249908], [88.89971924, 21.77305603], [88.90000153, 21.7733326], [88.90000153, 21.77388954], [88.90027618, 21.77416611], [88.90027618, 21.77583122], [88.90055847, 21.7761097], [88.90055847, 21.77667046], [88.90083313, 21.77695084], [88.90083313, 21.77805328], [88.90055847, 21.77832985], [88.90055847, 21.78139114], [88.90027618, 21.78166771], [88.90027618, 21.78222084], [88.89971924, 21.78277969], [88.89971924, 21.78305626], [88.89943695, 21.78333092], [88.89943695, 21.78388977], [88.89916992, 21.78416634], [88.89916992, 21.78444481], [88.89888763, 21.78471756], [88.89888763, 21.78527832], [88.89833069, 21.78583145], [88.89833069, 21.78611946], [88.89805603, 21.7863903], [88.89805603, 21.78666687], [88.89814758, 21.78676033], [88.89888763, 21.78750038], [88.89944458, 21.78750038], [88.90027618, 21.78833389], [88.90055847, 21.78833008], [88.90083313, 21.78861046], [88.90110779, 21.78861046], [88.90222168, 21.78972054], [88.90222168, 21.79000092], [88.90249634, 21.79027748], [88.90249634, 21.79083252], [88.90277863, 21.79111099], [88.90278625, 21.79138947], [88.90305328, 21.79166412], [88.90305328, 21.79193115], [88.90389252, 21.79277992], [88.90416718, 21.79277992], [88.90556335, 21.79417038], [88.90638733, 21.79417038], [88.90666962, 21.79389], [88.90693665, 21.79417038], [88.90583038, 21.79528046], [88.90499878, 21.79528046], [88.90485382, 21.79513168], [88.90471649, 21.79499054], [88.90444183, 21.79500008], [88.90416718, 21.7947216], [88.90389252, 21.7947216], [88.90333557, 21.79416847], [88.90305328, 21.79417038], [88.90278625, 21.79389], [88.90278625, 21.79360962], [88.90249634, 21.79333305], [88.90249634, 21.79305458], [88.90222168, 21.79277992], [88.90222168, 21.79222107], [88.90194702, 21.79194641], [88.90194702, 21.79166412], [88.9016571, 21.79138947], [88.9016571, 21.79111099], [88.90139008, 21.79083061], [88.90139008, 21.79027748], [88.90055847, 21.78944016], [88.90027618, 21.78944206], [88.90000153, 21.7891674], [88.89943695, 21.78918076], [88.89916992, 21.78889084], [88.89833069, 21.78889084], [88.89805603, 21.78861046], [88.89778137, 21.78861046], [88.89729309, 21.78812599], [88.89694214, 21.78777695], [88.89665985, 21.78778267], [88.89639282, 21.78806114], [88.89583588, 21.78806114], [88.89499664, 21.78889084], [88.89472198, 21.78888893], [88.89416504, 21.78944206], [88.89389038, 21.78944206], [88.89360809, 21.78972244], [88.89332581, 21.78972054], [88.89305878, 21.79000092], [88.89277649, 21.79000092], [88.89194489, 21.79083252], [88.89167023, 21.79083061], [88.89083099, 21.79166412], [88.89083099, 21.79193115], [88.88999939, 21.79277992], [88.88999939, 21.7930603], [88.88916779, 21.79389], [88.88916779, 21.79416847], [88.88833618, 21.79499054], [88.88833618, 21.79528046], [88.88805389, 21.79555511], [88.88804626, 21.79582977], [88.88722229, 21.7966671], [88.88722229, 21.79694366], [88.88694763, 21.79721832], [88.88694763, 21.79750061], [88.88667297, 21.79777908], [88.88667297, 21.79805946], [88.8861084, 21.79861069], [88.8861084, 21.79888916], [88.88583374, 21.79916573], [88.88582611, 21.79943848], [88.88527679, 21.80000114], [88.88527679, 21.80027962], [88.8841629, 21.80138969], [88.8841629, 21.80166626], [88.88361359, 21.8022213], [88.88361359, 21.80305481], [88.8833313, 21.80332947], [88.8833313, 21.80388832], [88.88305664, 21.80416107], [88.88305664, 21.80444336], [88.8833313, 21.80472183], [88.8833313, 21.80722046], [88.88305664, 21.80750084], [88.88305664, 21.80805779], [88.8833313, 21.80833054], [88.8833313, 21.80861092], [88.88360596, 21.80888939], [88.88388824, 21.80888939], [88.88471985, 21.8097229], [88.88500214, 21.80971909], [88.88555908, 21.81028938], [88.88639069, 21.81028938], [88.88660431, 21.81049156], [88.88667297, 21.81055832], [88.88805389, 21.81055641], [88.88833618, 21.81083298], [88.88916779, 21.81083298], [88.88944244, 21.81055641], [88.88972473, 21.81083298], [88.89039612, 21.81083298], [88.89083099, 21.81083298], [88.89111328, 21.81111145], [88.89167023, 21.81110764], [88.89193726, 21.81138992], [88.89221954, 21.81138992], [88.89263916, 21.81180573], [88.89305878, 21.81222153], [88.89362335, 21.81222153], [88.89389038, 21.81250191], [88.89417267, 21.81250191], [88.89439392, 21.81272125], [88.89444733, 21.81278038], [88.89472198, 21.81278038], [88.89583588, 21.81389046], [88.89583588, 21.81417274], [88.89722443, 21.81555557], [88.8972168, 21.81583023], [88.89805603, 21.81666946], [88.89833069, 21.81666756], [88.89861298, 21.81694221], [88.89861298, 21.8172226], [88.89888763, 21.81722069], [88.89916229, 21.81750107], [88.89971924, 21.81805992], [88.90000153, 21.81805992], [88.90194702, 21.81999969], [88.90222168, 21.81999969], [88.90277863, 21.82055664], [88.90416718, 21.82055664], [88.90444183, 21.82083321], [88.90528107, 21.82083321], [88.90555573, 21.82111168], [88.90666962, 21.82110977], [88.90693665, 21.82139015], [88.90750122, 21.82139015], [88.90777588, 21.82167053], [88.90805817, 21.82167053], [88.90833282, 21.82195091], [88.90888977, 21.82195091], [88.90972137, 21.82278061], [88.91000366, 21.8227787], [88.91055298, 21.82333374], [88.9108429, 21.82332993], [88.91110992, 21.82361031], [88.91139221, 21.82361031], [88.91361237, 21.82583427], [88.91583252, 21.82583427]]], [[[88.18333435, 21.78750038], [88.18222046, 21.7863884], [88.1819458, 21.7863903], [88.1817627, 21.78620338], [88.18138885, 21.78583145], [88.18110657, 21.78583145], [88.18055725, 21.7863903], [88.18055725, 21.78694534], [88.18026733, 21.78722191], [88.18027496, 21.78750038], [88.18011475, 21.78766251], [88.18000031, 21.78777695], [88.18000031, 21.78833389], [88.17973328, 21.78861046], [88.17973328, 21.78889084], [88.17944336, 21.7891674], [88.17944336, 21.78972054], [88.1791687, 21.79000092], [88.1791687, 21.79083061], [88.17888641, 21.79111099], [88.17888641, 21.79305458], [88.1791687, 21.79333115], [88.1791687, 21.79388618], [88.18000031, 21.7947216], [88.18000031, 21.79500008], [88.18083191, 21.79583359], [88.18222046, 21.79444695], [88.18222046, 21.79417038], [88.18305206, 21.79333115], [88.18305206, 21.79305458], [88.18360901, 21.79249954], [88.1838913, 21.79222107], [88.1838913, 21.79194641], [88.18527985, 21.79055405], [88.18527985, 21.78944016], [88.18499756, 21.7891674], [88.18499756, 21.78889084], [88.18360901, 21.78750038], [88.18333435, 21.78750038]]], [[[88.75063324, 21.79540062], [88.75076294, 21.79471016], [88.75081635, 21.79399109], [88.75085449, 21.79333878], [88.75090027, 21.79277039], [88.75099945, 21.79229736], [88.75097656, 21.79185295], [88.75093842, 21.79141045], [88.75105286, 21.79096985], [88.75115967, 21.79051971], [88.75131989, 21.79009628], [88.7514267, 21.78964996], [88.75157928, 21.78919029], [88.75164795, 21.7887001], [88.7516861, 21.7881794], [88.75177002, 21.78767776], [88.75195313, 21.78725052], [88.7521286, 21.78684044], [88.75226593, 21.78642082], [88.75245667, 21.78606987], [88.75262451, 21.78572655], [88.7527771, 21.78541374], [88.75292969, 21.78512001], [88.75306702, 21.78483009], [88.7532196, 21.78454971], [88.75332642, 21.7842598], [88.75343323, 21.78397179], [88.75356293, 21.78370285], [88.75367737, 21.78342247], [88.75383759, 21.78314972], [88.75398254, 21.78284073], [88.75418091, 21.78254128], [88.75443268, 21.78222084], [88.75470734, 21.78184128], [88.75499725, 21.78137016], [88.75527954, 21.7808342], [88.75527954, 21.78055763], [88.75554657, 21.78028107], [88.75528717, 21.77999115], [88.75527954, 21.77972221], [88.75499725, 21.77944374], [88.75499725, 21.77916527], [88.75448608, 21.77865601], [88.75416565, 21.77833557], [88.75389099, 21.77833557], [88.75305176, 21.77750015], [88.7527771, 21.77778053], [88.75250244, 21.77778053], [88.75222778, 21.77750015], [88.7519455, 21.77750015], [88.75166321, 21.77722168], [88.75138855, 21.77721977], [88.75110626, 21.77750015], [88.7508316, 21.77750015], [88.75055695, 21.77721977], [88.75, 21.77722168], [88.74972534, 21.77694321], [88.74944305, 21.77695084], [88.74944305, 21.77639008], [88.74916077, 21.7761097], [88.7491684, 21.77583122], [88.74886322, 21.77554512], [88.74858856, 21.77518082], [88.74843597, 21.77497482], [88.74830627, 21.77480125], [88.74801636, 21.7744503], [88.74774933, 21.77414131], [88.74751282, 21.77387047], [88.74732971, 21.77360153], [88.74717712, 21.77330971], [88.74694061, 21.7730484], [88.74665833, 21.77276993], [88.74629211, 21.77248955], [88.74610901, 21.77222252], [88.74577332, 21.77231216], [88.74510956, 21.77248955], [88.74453735, 21.77309608], [88.74360657, 21.77342987], [88.74310303, 21.77370071], [88.74246216, 21.7739048], [88.74195862, 21.77390289], [88.74080658, 21.77417946], [88.73980713, 21.77404022], [88.7384491, 21.77444267], [88.73715973, 21.77478027], [88.73607635, 21.77518082], [88.73544312, 21.7761898], [88.73493958, 21.77726936], [88.73500061, 21.77806091], [88.73500061, 21.77861023], [88.73472595, 21.77889061], [88.73472595, 21.77916527], [88.73443604, 21.77943993], [88.73390198, 21.77959824], [88.73320007, 21.77970123], [88.73239899, 21.77972031], [88.73165894, 21.7796917], [88.73105621, 21.77958107], [88.73059845, 21.77947044], [88.7301712, 21.77940941], [88.72972107, 21.77944374], [88.72888947, 21.77944374], [88.72861481, 21.77972221], [88.72833252, 21.77972221], [88.72833252, 21.78471756], [88.72861481, 21.78499985], [88.72860718, 21.78583145], [88.72888947, 21.78611946], [88.72888947, 21.78694534], [88.72860718, 21.78722191], [88.72861481, 21.78805542], [88.72833252, 21.78833389], [88.72833252, 21.79222107], [88.72805786, 21.79249954], [88.72805786, 21.79277611], [88.72750092, 21.79333305], [88.72750092, 21.79360962], [88.72777557, 21.79388618], [88.72915649, 21.79528046], [88.72944641, 21.79527855], [88.73000336, 21.79583359], [88.73027039, 21.79584312], [88.73074341, 21.79602432], [88.73131561, 21.7960968], [88.73195648, 21.79611969], [88.73265076, 21.79616356], [88.73335266, 21.79627037], [88.73406982, 21.79636574], [88.73479462, 21.79644585], [88.735466, 21.79663086], [88.73610687, 21.79693985], [88.73670197, 21.79728127], [88.73723602, 21.79766464], [88.73773193, 21.79805946], [88.73815918, 21.79850006], [88.73844147, 21.7990303], [88.73866272, 21.7996006], [88.73888397, 21.80014038], [88.73908997, 21.80068398], [88.73916626, 21.80125046], [88.73925781, 21.80181122], [88.73946381, 21.80230522], [88.73970795, 21.80275917], [88.7399292, 21.80321693], [88.74009705, 21.80369949], [88.74030304, 21.80416107], [88.74054718, 21.80458069], [88.74082947, 21.80498123], [88.7411499, 21.80535126], [88.74151611, 21.8057003], [88.74192047, 21.80610657], [88.74233246, 21.80659103], [88.74277496, 21.80710983], [88.74326324, 21.80764008], [88.74384308, 21.80809593], [88.74438477, 21.80861282], [88.74481964, 21.80920982], [88.74532318, 21.80976105], [88.74582672, 21.81028938], [88.74635315, 21.81081963], [88.74687195, 21.81133652], [88.74738312, 21.81188011], [88.74790192, 21.81241989], [88.74846649, 21.81289864], [88.7490387, 21.81336212], [88.74958038, 21.81380844], [88.75011444, 21.81415939], [88.75063324, 21.81421471], [88.75102997, 21.81395149], [88.75126648, 21.81353951], [88.75130463, 21.81305885], [88.75119781, 21.81252289], [88.75112152, 21.8119278], [88.7510376, 21.81130981], [88.75089264, 21.81067085], [88.75074768, 21.81002045], [88.75052643, 21.80943108], [88.75028992, 21.80887032], [88.75006866, 21.80829811], [88.74991608, 21.8076725], [88.74972534, 21.80706787], [88.74954224, 21.80649185], [88.74938965, 21.80596161], [88.7493515, 21.80542183], [88.74937439, 21.80485916], [88.74932098, 21.80425072], [88.74932098, 21.80358124], [88.7494812, 21.80298042], [88.74964142, 21.80240822], [88.74968719, 21.80181122], [88.74962616, 21.80122757], [88.7494812, 21.8008194], [88.74944305, 21.80070877], [88.74944305, 21.80027962], [88.75, 21.79972076], [88.75, 21.79861069], [88.75026703, 21.7983284], [88.75030518, 21.79781342], [88.75035858, 21.79728508], [88.7503891, 21.79669952], [88.75051117, 21.79607964], [88.75063324, 21.79540062]]], [[[88.17111206, 21.80861092], [88.17222595, 21.80750084], [88.17222595, 21.80722046], [88.17250061, 21.8069458], [88.17250061, 21.80666542], [88.1727829, 21.80639076], [88.1727829, 21.80360985], [88.17333221, 21.80305481], [88.17333221, 21.80277824], [88.17360687, 21.80249977], [88.17360687, 21.80221939], [88.17388916, 21.80194473], [88.17388916, 21.80166626], [88.17414856, 21.80138969], [88.17414856, 21.79972076], [88.17388916, 21.7994442], [88.17388916, 21.79888916], [88.17360687, 21.79861069], [88.17360687, 21.79693985], [88.17277527, 21.79611206], [88.17305756, 21.79583359], [88.17305756, 21.79527855], [88.17222595, 21.79445076], [88.17222595, 21.79417038], [88.17193604, 21.79389], [88.17193604, 21.7930603], [88.17166901, 21.79277992], [88.17166901, 21.79193115], [88.17028046, 21.79055405], [88.16916656, 21.79055977], [88.16860962, 21.79111099], [88.16722107, 21.79111099], [88.16666412, 21.79166412], [88.16665649, 21.79360962], [88.16610718, 21.79417038], [88.16611481, 21.79444695], [88.16583252, 21.7947197], [88.16583252, 21.79555511], [88.16555786, 21.79583359], [88.16555786, 21.7983284], [88.16526794, 21.79861069], [88.16526794, 21.80027962], [88.16555786, 21.80055618], [88.16555786, 21.80194473], [88.16583252, 21.80221939], [88.16583252, 21.80277824], [88.16610718, 21.8030529], [88.16611481, 21.80388832], [88.16638947, 21.80416107], [88.16638947, 21.80528069], [88.16665649, 21.80556107], [88.16665649, 21.80611038], [88.16694641, 21.80639076], [88.16694641, 21.80666542], [88.16750336, 21.80722237], [88.16777802, 21.80722046], [88.16832733, 21.80778122], [88.16860962, 21.80778122], [88.16889191, 21.80805969], [88.16971588, 21.80805969], [88.16999817, 21.8077755], [88.17055511, 21.80833244], [88.17082977, 21.80833054], [88.17111206, 21.80861092]]], [[[88.1819458, 21.82582855], [88.18250275, 21.82527733], [88.18250275, 21.82389069], [88.1827774, 21.82361031], [88.1827774, 21.82332993], [88.18305206, 21.82305527], [88.18305206, 21.82278061], [88.18360901, 21.82222748], [88.18360901, 21.82195091], [88.18416595, 21.82139015], [88.18457031, 21.82139015], [88.18467712, 21.82131958], [88.185112, 21.82102776], [88.18547821, 21.8206501], [88.18559265, 21.8201828], [88.18548584, 21.81963158], [88.1855545, 21.81916428], [88.18527985, 21.81916428], [88.18499756, 21.81944656], [88.1847229, 21.81944656], [88.18444824, 21.81972313], [88.18416595, 21.81972122], [88.1838913, 21.81999969], [88.18360901, 21.81999969], [88.18334198, 21.82028008], [88.18305206, 21.82027626], [88.18250275, 21.82083321], [88.18222046, 21.82082939], [88.18165588, 21.82139015], [88.18138885, 21.82139015], [88.18110657, 21.82167053], [88.18083191, 21.82166862], [88.17778015, 21.82471848], [88.17778015, 21.82529259], [88.17807007, 21.82555962], [88.17861176, 21.8255558], [88.17874908, 21.82569504], [88.17888641, 21.82583427], [88.17944336, 21.82583427], [88.17973328, 21.82555962], [88.18055725, 21.82638931], [88.18083191, 21.82638931], [88.18110657, 21.82666969], [88.18138885, 21.82666969], [88.1819458, 21.82611084], [88.1819458, 21.82582855]]], [[[88.85610962, 21.86528015], [88.85694122, 21.86444092], [88.85722351, 21.86444473], [88.85749817, 21.86416626], [88.85749054, 21.86361122], [88.85721588, 21.86361122], [88.85721588, 21.86333084], [88.85666656, 21.86277962], [88.85666656, 21.86250114], [88.85639191, 21.86222076], [88.85639191, 21.8619442], [88.85610962, 21.86166763], [88.85610962, 21.8614006], [88.85582733, 21.86111069], [88.85582733, 21.86055946], [88.85555267, 21.86028099], [88.85555267, 21.85943985], [88.85527802, 21.85916519], [88.85527802, 21.85806084], [88.85555267, 21.85778046], [88.85555267, 21.8572197], [88.85630798, 21.85647011], [88.85666656, 21.85611153], [88.85694122, 21.85611153], [88.85749817, 21.85555649], [88.85778046, 21.8555603], [88.85806274, 21.85527039], [88.85861206, 21.85527802], [88.85888672, 21.85499954], [88.85916901, 21.85499954], [88.85943604, 21.85472107], [88.86027527, 21.85472107], [88.86055756, 21.8544445], [88.86166382, 21.8544445], [88.86194611, 21.85416603], [88.86222076, 21.85416603], [88.86236572, 21.85430717], [88.86250305, 21.8544445], [88.86351776, 21.8544445], [88.86499786, 21.8544445], [88.86528015, 21.85416603], [88.8658371, 21.85416985], [88.86611176, 21.85388947], [88.86667633, 21.85388947], [88.86694336, 21.8536129], [88.86723328, 21.8536129], [88.86750031, 21.85333252], [88.8686142, 21.85333252], [88.86888885, 21.85305595], [88.86915588, 21.85306168], [88.8694458, 21.85277939], [88.87082672, 21.85277939], [88.87110901, 21.85250092], [88.87194824, 21.85250092], [88.8722229, 21.85277939], [88.87304688, 21.85277939], [88.87333679, 21.85306168], [88.8741684, 21.85305595], [88.87444305, 21.85333252], [88.87472534, 21.85333252], [88.875, 21.85305595], [88.87555695, 21.85306168], [88.8758316, 21.85277939], [88.87610626, 21.85277939], [88.87722015, 21.85166931], [88.87695313, 21.85139084], [88.87722015, 21.85111046], [88.87722015, 21.85082817], [88.8769455, 21.85055542], [88.87695313, 21.85028076], [88.87638855, 21.84971809], [88.87638855, 21.84944534], [88.87610626, 21.84917068], [88.87610626, 21.8488903], [88.8758316, 21.84860992], [88.8758316, 21.84847069], [88.8758316, 21.84805679], [88.87555695, 21.84777832], [88.87555695, 21.84667015], [88.87526703, 21.84638977], [88.87526703, 21.84610939], [88.875, 21.84583282], [88.875, 21.84555435], [88.87526703, 21.84556007], [88.87526703, 21.84527969], [88.87610626, 21.84444046], [88.87611389, 21.84388924], [88.87638855, 21.84361076], [88.87638855, 21.84305954], [88.87666321, 21.84278107], [88.87666321, 21.84250069], [88.87695313, 21.84222031], [88.8769455, 21.83833313], [88.87722015, 21.83805466], [88.87722015, 21.83694458], [88.87750244, 21.83666611], [88.87750244, 21.83638954], [88.8777771, 21.83611107], [88.8777771, 21.83500099], [88.87805176, 21.83472061], [88.87805176, 21.8338871], [88.87832642, 21.83361053], [88.87832642, 21.83333015], [88.87863159, 21.8327961], [88.87999725, 21.83139038], [88.87999725, 21.83056068], [88.88027954, 21.8302803], [88.88027954, 21.82888985], [88.87999725, 21.82860947], [88.87999725, 21.82777786], [88.8797226, 21.82749939], [88.8797226, 21.82666969], [88.87944794, 21.82638931], [88.87944794, 21.82555962], [88.87924957, 21.82513046], [88.87916565, 21.82500076], [88.87916565, 21.82416725], [88.87889099, 21.82389069], [88.87889099, 21.82305908], [88.87861633, 21.82278061], [88.87861633, 21.82222748], [88.87889099, 21.82195091], [88.87889099, 21.81999969], [88.87889099, 21.8199234], [88.87889099, 21.81972122], [88.87944794, 21.81916428], [88.87944794, 21.81861115], [88.88054657, 21.81750107], [88.88054657, 21.81722069], [88.88222504, 21.81555557], [88.88223267, 21.81528282], [88.88305664, 21.81444168], [88.88305664, 21.81416702], [88.8833313, 21.81389046], [88.88305664, 21.81361008], [88.8833313, 21.81361008], [88.8833313, 21.81305504], [88.88305664, 21.81278038], [88.88305664, 21.81222153], [88.88249969, 21.81166649], [88.88249969, 21.81138992], [88.88194275, 21.81082916], [88.88194275, 21.81055641], [88.88168335, 21.81028938], [88.88168335, 21.80999947], [88.88027954, 21.80861092], [88.88027954, 21.80833054], [88.8797226, 21.8077755], [88.8797226, 21.80750084], [88.87999725, 21.80722046], [88.87999725, 21.80583572], [88.8805542, 21.80527687], [88.88054657, 21.80471992], [88.88083649, 21.80444336], [88.88083649, 21.80416107], [88.88111115, 21.80388832], [88.88111115, 21.80194283], [88.8813858, 21.80166626], [88.8813858, 21.80112076], [88.88168335, 21.80083275], [88.88166809, 21.80055618], [88.88194275, 21.80027962], [88.88194275, 21.7983284], [88.88222504, 21.79805565], [88.88223267, 21.79721832], [88.88249969, 21.79694366], [88.88249969, 21.7966671], [88.88305664, 21.79610825], [88.88305664, 21.79583359], [88.88444519, 21.79444695], [88.88445282, 21.79417038], [88.88527679, 21.79333115], [88.88527679, 21.79277611], [88.88582611, 21.79222107], [88.88583374, 21.79194641], [88.88777924, 21.79000092], [88.88804626, 21.79000092], [88.89138794, 21.78667259], [88.89138794, 21.7863903], [88.89193726, 21.7863903], [88.89277649, 21.78554916], [88.89305878, 21.78555489], [88.89389038, 21.78472137], [88.89389038, 21.78444481], [88.89527893, 21.78305626], [88.89555359, 21.78305626], [88.89694214, 21.78166771], [88.89694214, 21.78139114], [88.8972168, 21.78111076], [88.8972168, 21.78083038], [88.89778137, 21.78027534], [88.89778137, 21.77889061], [88.89805603, 21.77861023], [88.89805603, 21.77832985], [88.89749908, 21.77777863], [88.89749908, 21.77750015], [88.89694214, 21.77695084], [88.89694214, 21.77667046], [88.89611053, 21.77583122], [88.89611053, 21.77555466], [88.89583588, 21.77527809], [88.89583588, 21.77472115], [88.89555359, 21.77444458], [88.89555359, 21.77433014], [88.89555359, 21.77388954], [88.89527893, 21.77361107], [88.89527893, 21.77268982], [88.89527893, 21.77249908], [88.89499664, 21.77222061], [88.89499664, 21.77194405], [88.89444733, 21.77139091], [88.89444733, 21.77111053], [88.89389038, 21.77055931], [88.89389038, 21.77028084], [88.89362335, 21.77000046], [88.89360809, 21.76972198], [88.89333344, 21.76944351], [88.89333344, 21.76888847], [88.89305878, 21.76860809], [88.89305878, 21.76805687], [88.89277649, 21.7677784], [88.89277649, 21.76721954], [88.89250183, 21.76694679], [88.89250183, 21.7658329], [88.89221954, 21.76555443], [88.89221954, 21.76444054], [88.89138794, 21.76361084], [88.89138794, 21.76278114], [88.89111328, 21.76250076], [88.89111328, 21.76000023], [88.89083099, 21.75972176], [88.89083099, 21.75833321], [88.89111328, 21.75805473], [88.89111328, 21.75499725], [88.89138794, 21.75472069], [88.89138794, 21.75361061], [88.89193726, 21.75307083], [88.89193726, 21.75278091], [88.89250183, 21.75222015], [88.89250183, 21.75138855], [88.89305878, 21.7508297], [88.89360809, 21.75083351], [88.89389038, 21.75055313], [88.89389038, 21.75028038], [88.89554596, 21.74860954], [88.89611053, 21.74861145], [88.89694214, 21.74777794], [88.8972168, 21.74777985], [88.89778137, 21.7472229], [88.89805603, 21.7472229], [88.89833069, 21.74694443], [88.89888763, 21.74694443], [88.89916992, 21.74666595], [88.90000153, 21.74666977], [88.90000153, 21.74638939], [88.90027618, 21.74638939], [88.90046692, 21.74657822], [88.90055847, 21.74666977], [88.90110779, 21.74666977], [88.90139008, 21.74638939], [88.90278625, 21.74638939], [88.90305328, 21.74611092], [88.90721893, 21.74611092], [88.90750122, 21.74638939], [88.90805817, 21.74638939], [88.90860748, 21.74694443], [88.90888977, 21.74694443], [88.90899658, 21.74705124], [88.90916443, 21.7472229], [88.90944672, 21.74694443], [88.91055298, 21.74694443], [88.91083527, 21.7472229], [88.91139221, 21.7472229], [88.91165924, 21.74749947], [88.91388702, 21.74749947], [88.91416931, 21.74777985], [88.91610718, 21.74777985], [88.91638947, 21.74749947], [88.91722107, 21.74749947], [88.91750336, 21.7472229], [88.91777802, 21.7472229], [88.92002869, 21.74497032], [88.92138672, 21.74361038], [88.92138672, 21.74332809], [88.92166901, 21.74305534], [88.92166901, 21.74278069], [88.92193604, 21.74250031], [88.92138672, 21.74194908], [88.92111206, 21.74194908], [88.92138672, 21.74167061], [88.92111206, 21.74139023], [88.92111206, 21.74055099], [88.92082977, 21.74027824], [88.92082977, 21.73999977], [88.92028046, 21.73944092], [88.91999817, 21.73944664], [88.91972351, 21.73916435], [88.91971588, 21.73888969], [88.91889191, 21.73806953], [88.91889191, 21.73722076], [88.91860962, 21.73694229], [88.91860962, 21.73666573], [88.91832733, 21.73639107], [88.91832733, 21.73611069], [88.91779327, 21.73555946], [88.91779327, 21.7352829], [88.91694641, 21.73444176], [88.91694641, 21.7341671], [88.91665649, 21.73389053], [88.91665649, 21.73361015], [88.91611481, 21.73305511], [88.91610718, 21.73250008], [88.91583252, 21.7322216], [88.91611481, 21.73194504], [88.91611481, 21.73166656], [88.91638184, 21.73139954], [88.91555786, 21.7305584], [88.91555786, 21.73027992], [88.9152832, 21.72999954], [88.91527557, 21.72916794], [88.91443634, 21.72833061], [88.91388702, 21.72833252], [88.91333008, 21.72777939], [88.91249847, 21.72861099], [88.91139221, 21.72861099], [88.91110992, 21.72888947], [88.9108429, 21.72887993], [88.91055298, 21.72916985], [88.91027832, 21.72916794], [88.91000366, 21.7294445], [88.90944672, 21.7294445], [88.90916443, 21.72972298], [88.90888977, 21.72972107], [88.90859985, 21.72999954], [88.90777588, 21.72999954], [88.90750122, 21.73027992], [88.90721893, 21.73027992], [88.90693665, 21.7305584], [88.90666962, 21.73055649], [88.90638733, 21.73083305], [88.90611267, 21.73082924], [88.90556335, 21.73139954], [88.90556335, 21.73167038], [88.90528107, 21.73166656], [88.90499878, 21.73194504], [88.90499878, 21.7322216], [88.90444183, 21.73278046], [88.90416718, 21.73277855], [88.90361023, 21.73333359], [88.90333557, 21.73333359], [88.90305328, 21.73361015], [88.90277863, 21.73361015], [88.90211487, 21.73427963], [88.90083313, 21.73555946], [88.90055847, 21.73555946], [88.89971924, 21.73639107], [88.89943695, 21.73639107], [88.89833069, 21.73750114], [88.89805603, 21.73750114], [88.89749908, 21.73806953], [88.8972168, 21.73806953], [88.89666748, 21.73861122], [88.89639282, 21.73861122], [88.89583588, 21.73917007], [88.89555359, 21.73916435], [88.89499664, 21.7397213], [88.89472198, 21.73971939], [88.89417267, 21.74028015], [88.89389038, 21.74027824], [88.89360809, 21.74055672], [88.89333344, 21.74055672], [88.89277649, 21.74111176], [88.89250183, 21.74110985], [88.89193726, 21.74167061], [88.89167023, 21.7416687], [88.89111328, 21.74222183], [88.89083099, 21.74221992], [88.89055634, 21.74250031], [88.89026642, 21.74250031], [88.88999939, 21.74278069], [88.88972473, 21.74277878], [88.88916779, 21.74333382], [88.88889313, 21.74332809], [88.88861084, 21.74361038], [88.88833618, 21.74361038], [88.88805389, 21.74389076], [88.88777924, 21.74388123], [88.88749695, 21.74416924], [88.88722229, 21.74416733], [88.88666534, 21.74472237], [88.88639069, 21.74472046], [88.8861084, 21.74500084], [88.88582611, 21.74500084], [88.88527679, 21.7455616], [88.88471985, 21.74555588], [88.88444519, 21.74583244], [88.88388824, 21.74582863], [88.88360596, 21.74611092], [88.88305664, 21.74611092], [88.88277435, 21.74638939], [88.88222504, 21.74638939], [88.8813858, 21.7472229], [88.88111115, 21.7472229], [88.88027954, 21.74805641], [88.88027954, 21.74833107], [88.87944794, 21.7491703], [88.87944794, 21.75055313], [88.87917328, 21.7508297], [88.8797226, 21.75139046], [88.8797226, 21.75305748], [88.87944794, 21.75333595], [88.87944794, 21.75485039], [88.87944794, 21.75499725], [88.87931824, 21.75512886], [88.87916565, 21.75527763], [88.87916565, 21.7554512], [88.87917328, 21.75722122], [88.87889099, 21.75749969], [88.87889099, 21.75777817], [88.87916565, 21.75777817], [88.87917328, 21.75861168], [88.87889099, 21.75889015], [88.87889099, 21.75944519], [88.8786087, 21.75972176], [88.87861633, 21.76083183], [88.87832642, 21.76111031], [88.87833405, 21.76194382], [88.87805176, 21.76222038], [88.87805176, 21.76278114], [88.8777771, 21.76305962], [88.8777771, 21.76416588], [88.87750244, 21.76444435], [88.87750244, 21.76472092], [88.87722015, 21.76501083], [88.87722015, 21.76527977], [88.8769455, 21.76555443], [88.8769455, 21.7658329], [88.87626648, 21.76721573], [88.8758316, 21.76789284], [88.87526703, 21.76872063], [88.87484741, 21.76913071], [88.8730545, 21.77054787], [88.87262726, 21.77081108], [88.87166595, 21.77139091], [88.8713913, 21.77193069], [88.86972046, 21.77306175], [88.86916351, 21.77319145], [88.86888885, 21.7733326], [88.86860657, 21.77352905], [88.86805725, 21.77388954], [88.86776733, 21.77388954], [88.86750031, 21.77417946], [88.86722565, 21.77443504], [88.86694336, 21.77444458], [88.86659241, 21.77471352], [88.86624908, 21.77499008], [88.86611176, 21.7751255], [88.86569214, 21.77540016], [88.86534882, 21.77547073], [88.86458588, 21.7761097], [88.86416626, 21.77667046], [88.8638916, 21.77666664], [88.86332703, 21.77721977], [88.86332703, 21.77750015], [88.86349487, 21.77766037], [88.86361694, 21.77778053], [88.86416626, 21.77778053], [88.86444092, 21.77806091], [88.86472321, 21.77805328], [88.86499786, 21.77832985], [88.86499786, 21.77861023], [88.86444092, 21.77917099], [88.86416626, 21.77917099], [88.86361694, 21.77861023], [88.86305237, 21.77861023], [88.86250305, 21.77806091], [88.86222076, 21.77806091], [88.86193848, 21.77791214], [88.86083221, 21.77811241], [88.86054993, 21.77832031], [88.86042023, 21.77845955], [88.8601532, 21.77867126], [88.85978699, 21.77873993], [88.85943604, 21.77861023], [88.85888672, 21.77874947], [88.85832977, 21.77889061], [88.85778046, 21.77889061], [88.85749054, 21.77917099], [88.85639191, 21.77916527], [88.85610962, 21.77944374], [88.85555267, 21.77944374], [88.85527802, 21.77972221], [88.85250092, 21.77972221], [88.85221863, 21.78000069], [88.84972382, 21.78000069], [88.84944153, 21.77972221], [88.84916687, 21.77972221], [88.84889221, 21.77944374], [88.84777832, 21.77944374], [88.84750366, 21.77972221], [88.84471893, 21.77972221], [88.84444427, 21.78000069], [88.8440094, 21.77956772], [88.84388733, 21.77944374], [88.84388733, 21.77916527], [88.84305573, 21.77916527], [88.84278107, 21.77944374], [88.84222412, 21.77944374], [88.84194183, 21.77972221], [88.84111023, 21.77972221], [88.84083557, 21.78000069], [88.83972168, 21.77999115], [88.83944702, 21.78028107], [88.83889008, 21.78028107], [88.83860779, 21.78055954], [88.83777618, 21.78055763], [88.83750153, 21.7808342], [88.83638, 21.78083038], [88.83611298, 21.78111076], [88.83555603, 21.78111076], [88.83499908, 21.78166771], [88.83499908, 21.78360748], [88.83528137, 21.78388977], [88.83528137, 21.78444481], [88.83555603, 21.78471756], [88.83555603, 21.78527832], [88.83583069, 21.78555489], [88.83583069, 21.78583336], [88.83605957, 21.78606224], [88.83638, 21.7863903], [88.83638, 21.78667259], [88.83666992, 21.78695107], [88.83666992, 21.78778267], [88.83694458, 21.78805542], [88.83693695, 21.78833008], [88.83721924, 21.78861046], [88.83721924, 21.78889084], [88.83750153, 21.7891674], [88.83750153, 21.78944206], [88.83757782, 21.78952026], [88.83777618, 21.78972244], [88.83777618, 21.78982925], [88.83777618, 21.79000092], [88.83805847, 21.79027939], [88.83805847, 21.79055405], [88.83833313, 21.79083061], [88.83833313, 21.79111099], [88.83860779, 21.79138947], [88.83860779, 21.79166412], [88.83889008, 21.79194641], [88.83889008, 21.79333305], [88.8391571, 21.79360962], [88.83916473, 21.79444695], [88.83944702, 21.7947197], [88.83944702, 21.79555511], [88.83972168, 21.79582977], [88.83972168, 21.79805565], [88.83999634, 21.7983284], [88.83999634, 21.79861069], [88.84027863, 21.79888916], [88.84027863, 21.80000114], [88.84055328, 21.80027962], [88.84055328, 21.80249977], [88.8408432, 21.80278015], [88.8408432, 21.80528069], [88.84111023, 21.80555344], [88.84111023, 21.80722046], [88.84139252, 21.80750084], [88.84139252, 21.81278038], [88.84111023, 21.81305504], [88.84111023, 21.81333351], [88.84139252, 21.81361008], [88.84139252, 21.81528282], [88.84111023, 21.81555557], [88.84111023, 21.81611061], [88.84139252, 21.81611061], [88.84055328, 21.81694031], [88.84055328, 21.81777954], [88.84027863, 21.8180542], [88.84027863, 21.81833076], [88.84055328, 21.81861115], [88.84055328, 21.81916428], [88.84027863, 21.81944656], [88.84027863, 21.81972122], [88.84055328, 21.81999969], [88.84027863, 21.82027626], [88.84027863, 21.82110977], [88.83999634, 21.82139015], [88.83999634, 21.82195091], [88.84027863, 21.82222748], [88.84027863, 21.82305527], [88.83999634, 21.82332993], [88.83999634, 21.82500076], [88.83972168, 21.82527733], [88.83972168, 21.82582855], [88.83944702, 21.82611084], [88.83944702, 21.82638931], [88.83916473, 21.82666588], [88.83916473, 21.82722282], [88.83944702, 21.82722282], [88.83889008, 21.82777977], [88.83916473, 21.82805634], [88.8391571, 21.82860947], [88.83889008, 21.82888794], [88.83889008, 21.83110046], [88.83860779, 21.83138847], [88.83860779, 21.83194351], [88.83833313, 21.83222008], [88.83833313, 21.83361053], [88.83805847, 21.8338871], [88.83805847, 21.83444595], [88.83833313, 21.83444023], [88.83777618, 21.83500099], [88.83777618, 21.83555794], [88.83750153, 21.83583069], [88.83750153, 21.83777809], [88.83721924, 21.83805084], [88.83721924, 21.84139061], [88.83750153, 21.8416729], [88.83750153, 21.84250069], [88.83721924, 21.84250069], [88.83721924, 21.84305573], [88.83750153, 21.84333038], [88.83750153, 21.84389114], [88.83777618, 21.8441658], [88.83777618, 21.84444427], [88.83805847, 21.84472084], [88.83805847, 21.84555435], [88.83833313, 21.84583092], [88.83833313, 21.84638977], [88.83860779, 21.84666443], [88.83860779, 21.84721947], [88.83889008, 21.84749985], [88.83889008, 21.84805679], [88.83916473, 21.84833336], [88.8391571, 21.84860992], [88.83999634, 21.84944534], [88.83999634, 21.84971809], [88.84055328, 21.85028076], [88.8408432, 21.85028076], [88.84055328, 21.85055923], [88.84111023, 21.85111046], [88.84111023, 21.85139084], [88.84278107, 21.85305595], [88.84278107, 21.85333252], [88.84416962, 21.85472107], [88.84416962, 21.85499954], [88.84443665, 21.85527039], [88.84443665, 21.8555603], [88.84555054, 21.85667038], [88.84555054, 21.85695076], [88.84638977, 21.85778046], [88.84638977, 21.85806084], [88.84722137, 21.85889053], [88.84750366, 21.85888863], [88.84833527, 21.85972214], [88.84860992, 21.85972023], [88.85138702, 21.86250114], [88.85138702, 21.86277962], [88.85193634, 21.86333084], [88.85193634, 21.86361122], [88.85221863, 21.86388969], [88.85221863, 21.86416817], [88.85305786, 21.86499977], [88.85333252, 21.86499977], [88.85360718, 21.86528015], [88.85610962, 21.86528015]]], [[[88.94139099, 21.84722137], [88.9422226, 21.84638977], [88.9422226, 21.84610939], [88.94277954, 21.84555435], [88.94277954, 21.84527969], [88.94304657, 21.84500122], [88.94304657, 21.84472084], [88.94333649, 21.84444427], [88.94333649, 21.8441658], [88.9438858, 21.84361076], [88.9438858, 21.84333038], [88.94416809, 21.84305573], [88.94416809, 21.84278107], [88.94444275, 21.84250069], [88.94444275, 21.84222031], [88.94454193, 21.84212112], [88.94527435, 21.8413887], [88.94526672, 21.84111023], [88.94695282, 21.83945274], [88.94695282, 21.83917046], [88.94721985, 21.83889008], [88.94721985, 21.83832932], [88.94750214, 21.83805466], [88.94750214, 21.83777809], [88.94776917, 21.83749962], [88.94776917, 21.83723068], [88.94805908, 21.83694077], [88.94805908, 21.83638954], [88.94832611, 21.83611107], [88.94832611, 21.83527946], [88.9486084, 21.83500099], [88.9486084, 21.83444023], [88.94889069, 21.83416748], [88.94889069, 21.83361053], [88.94917297, 21.83333015], [88.94916534, 21.83277512], [88.94944763, 21.83250046], [88.94944763, 21.8319397], [88.94999695, 21.83138847], [88.94999695, 21.83082962], [88.95027924, 21.83055305], [88.95027924, 21.8302803], [88.95054626, 21.82999992], [88.95054626, 21.82944107], [88.95111084, 21.82888794], [88.95111084, 21.82860947], [88.95305634, 21.82666588], [88.95305634, 21.82638931], [88.95361328, 21.82582855], [88.95361328, 21.8255558], [88.9539032, 21.82529259], [88.95417023, 21.82529259], [88.95443726, 21.82500076], [88.95471954, 21.82500076], [88.95527649, 21.8244381], [88.95583344, 21.82444382], [88.95610809, 21.82416725], [88.95639038, 21.82416916], [88.95667267, 21.82389069], [88.95777893, 21.82389069], [88.95804596, 21.82361031], [88.95889282, 21.82361031], [88.95916748, 21.82333374], [88.95972443, 21.82333374], [88.95999908, 21.82305527], [88.96055603, 21.82305908], [88.96083069, 21.82278061], [88.9658432, 21.82278061], [88.96611023, 21.82250023], [88.97177887, 21.82250023], [88.97249603, 21.82250023], [88.97277832, 21.82278061], [88.97499847, 21.82278061], [88.97550964, 21.82226944], [88.97638702, 21.82138634], [88.97638702, 21.82110977], [88.97666931, 21.82083321], [88.97666931, 21.82055664], [88.97583008, 21.81972313], [88.97583008, 21.81916428], [88.97528076, 21.81861115], [88.97528076, 21.81814003], [88.97528076, 21.81694221], [88.97444153, 21.81611061], [88.97444153, 21.81472206], [88.97472382, 21.81444359], [88.97444153, 21.81416702], [88.97444153, 21.81389046], [88.97389221, 21.8133316], [88.97305298, 21.81333351], [88.97305298, 21.81295967], [88.97305298, 21.81277847], [88.9733429, 21.81250191], [88.97333527, 21.81194496], [88.97305298, 21.81166649], [88.97305298, 21.81082916], [88.97277832, 21.81055641], [88.97277832, 21.80971909], [88.97250366, 21.80944443], [88.97250366, 21.80916786], [88.97222137, 21.80888939], [88.97222137, 21.80861092], [88.97193909, 21.80833054], [88.97194672, 21.80722237], [88.97166443, 21.8069458], [88.97166443, 21.80527687], [88.97138977, 21.80500031], [88.97138977, 21.80445099], [88.97110748, 21.80416107], [88.97110748, 21.80388832], [88.97049713, 21.80327415], [88.97000122, 21.80277824], [88.96888733, 21.80277824], [88.96861267, 21.80305481], [88.96833038, 21.80305481], [88.96776581, 21.80362129], [88.96749878, 21.80389023], [88.96722412, 21.80388832], [88.96694183, 21.80416679], [88.96666718, 21.80416679], [88.96611023, 21.80472183], [88.96555328, 21.80471992], [88.96527863, 21.80500031], [88.96499634, 21.80500031], [88.96472168, 21.80528069], [88.96444702, 21.80527687], [88.96389008, 21.80583572], [88.96360779, 21.80583], [88.96305847, 21.80639076], [88.96250153, 21.80639076], [88.96221924, 21.80667114], [88.96166992, 21.80666542], [88.96138763, 21.8069458], [88.96083069, 21.8069458], [88.96055603, 21.80722237], [88.95833588, 21.80722046], [88.95804596, 21.80750084], [88.95639038, 21.80750084], [88.95610809, 21.80778122], [88.95555878, 21.80778122], [88.95527649, 21.80805969], [88.95417023, 21.80805969], [88.95410156, 21.80798721], [88.9539032, 21.80778122], [88.95361328, 21.80778122], [88.95333099, 21.80750084], [88.95305634, 21.80750084], [88.95276642, 21.80722046], [88.95249939, 21.80722237], [88.9513855, 21.80611038], [88.95111084, 21.80611038], [88.95083618, 21.80583], [88.95055389, 21.80583572], [88.95027924, 21.80555344], [88.94944763, 21.80556107], [88.94917297, 21.80528069], [88.9486084, 21.80528069], [88.94824219, 21.80490685], [88.94805908, 21.80471992], [88.94805908, 21.80416679], [88.94777679, 21.80388832], [88.94776917, 21.80360985], [88.94750214, 21.80333328], [88.94750214, 21.80305481], [88.94721985, 21.80277824], [88.94721985, 21.80249977], [88.94610596, 21.80138969], [88.94610596, 21.80112076], [88.94555664, 21.8005619], [88.94555664, 21.80027962], [88.94526672, 21.80000114], [88.94526672, 21.79943848], [88.94499969, 21.79916573], [88.94499969, 21.79888916], [88.94473267, 21.79861069], [88.94472504, 21.79833412], [88.94444275, 21.79805565], [88.94444275, 21.79777908], [88.9438858, 21.79721832], [88.9438858, 21.79694366], [88.94361115, 21.7966671], [88.94361115, 21.79639053], [88.94249725, 21.79528046], [88.94249725, 21.79499054], [88.9422226, 21.7947216], [88.94194794, 21.7947216], [88.9402771, 21.79305458], [88.9402771, 21.79222107], [88.94000244, 21.79194641], [88.94000244, 21.79166412], [88.93972015, 21.79138947], [88.93972015, 21.79000092], [88.93945313, 21.78972054], [88.9394455, 21.78944206], [88.93916321, 21.7891674], [88.93916321, 21.78889084], [88.93889618, 21.78861046], [88.93888855, 21.78777695], [88.93916321, 21.78750038], [88.93916321, 21.7863903], [88.93945313, 21.78611946], [88.93945313, 21.78554916], [88.93972015, 21.78527832], [88.93972015, 21.78499985], [88.93956757, 21.78432274], [88.93969727, 21.78389931], [88.93969727, 21.78375053], [88.93997192, 21.78306389], [88.94011688, 21.78278732], [88.94042206, 21.7823658], [88.94042206, 21.78249168], [88.9411087, 21.78222275], [88.94166565, 21.78166771], [88.9419632, 21.78166962], [88.94212341, 21.78150368], [88.94249725, 21.78111076], [88.94277954, 21.78111076], [88.94304657, 21.78083038], [88.94333649, 21.7808342], [88.94361115, 21.78055763], [88.9438858, 21.78055954], [88.94444275, 21.77999115], [88.94472504, 21.78000069], [88.94527435, 21.77944374], [88.94611359, 21.77944374], [88.94638824, 21.77916527], [88.94695282, 21.77917099], [88.94721985, 21.77889061], [88.94776917, 21.77889061], [88.94805908, 21.77861023], [88.94889069, 21.77861023], [88.94917297, 21.77832985], [88.94972229, 21.77833557], [88.94999695, 21.77805328], [88.95111084, 21.77806091], [88.95139313, 21.77778053], [88.9522171, 21.77778053], [88.95249939, 21.77750015], [88.95305634, 21.77750015], [88.95333099, 21.77721977], [88.95417023, 21.77722168], [88.95444489, 21.77694321], [88.95500183, 21.77695084], [88.95527649, 21.77667046], [88.95582581, 21.77667046], [88.95610809, 21.77639008], [88.95777893, 21.77639008], [88.95804596, 21.7761097], [88.95861053, 21.7761116], [88.95888519, 21.77583122], [88.95916748, 21.77583122], [88.95944214, 21.77555466], [88.95972443, 21.77555466], [88.95999908, 21.77527809], [88.95999908, 21.77499962], [88.96055603, 21.77444267], [88.96055603, 21.77416611], [88.96083069, 21.77388954], [88.96083069, 21.77361107], [88.96055603, 21.7733326], [88.96055603, 21.77277756], [88.95889282, 21.77111053], [88.95888519, 21.77083397], [88.95861053, 21.7705555], [88.95833588, 21.77055931], [88.95770264, 21.76992989], [88.95749664, 21.76972198], [88.95749664, 21.76944351], [88.95666504, 21.76861191], [88.95639038, 21.76861191], [88.95610809, 21.76833344], [88.95583344, 21.76833344], [88.95444489, 21.76694679], [88.95417023, 21.76694679], [88.95388794, 21.76666451], [88.95361328, 21.76667023], [88.95333099, 21.76638985], [88.95305634, 21.76638985], [88.95276642, 21.76610947], [88.95194244, 21.76611137], [88.95166779, 21.7658329], [88.9513855, 21.7658329], [88.95083618, 21.76527786], [88.95054626, 21.76527977], [88.9500885, 21.76481438], [88.94999695, 21.76472473], [88.94972229, 21.76472473], [88.94944763, 21.76444435], [88.94916534, 21.76444435], [88.94889069, 21.76416588], [88.94776917, 21.76416969], [88.94750214, 21.76389122], [88.94721985, 21.76389122], [88.94695282, 21.76416969], [88.9466629, 21.76416969], [88.94638824, 21.76389122], [88.94610596, 21.76389122], [88.9458313, 21.76416969], [88.94499969, 21.76416588], [88.94472504, 21.76444435], [88.94444275, 21.76444435], [88.94416809, 21.76472473], [88.94361115, 21.76472092], [88.94333649, 21.76501083], [88.9422226, 21.76501083], [88.9419632, 21.76527977], [88.94082642, 21.76527977], [88.94055176, 21.76556015], [88.93916321, 21.76555443], [88.93888855, 21.7658329], [88.93527985, 21.7658329], [88.93499756, 21.76555443], [88.9347229, 21.76555443], [88.93444824, 21.7658329], [88.93416595, 21.7658329], [88.9338913, 21.76611137], [88.93276978, 21.76610947], [88.93250275, 21.76638985], [88.9319458, 21.76638985], [88.93165588, 21.76667023], [88.92778015, 21.76666451], [88.92749786, 21.76694679], [88.92555237, 21.76694679], [88.92527771, 21.76666451], [88.92359924, 21.76667023], [88.92333221, 21.76638985], [88.92305756, 21.76638985], [88.9227829, 21.76610947], [88.92138672, 21.76611137], [88.92082977, 21.76555443], [88.92056274, 21.76556015], [88.91860962, 21.76361084], [88.91832733, 21.76361084], [88.91779327, 21.76305962], [88.91779327, 21.76250076], [88.91763306, 21.76234627], [88.91750336, 21.76222229], [88.91750336, 21.76166725], [88.91722107, 21.76139069], [88.91722107, 21.75889015], [88.91750336, 21.75861168], [88.91750336, 21.75722313], [88.91638947, 21.75611115], [88.91610718, 21.75611115], [88.91583252, 21.75582123], [88.91500092, 21.75583267], [88.91471863, 21.75555611], [88.91416931, 21.75555992], [88.91416931, 21.75611115], [88.91404724, 21.75623131], [88.91388702, 21.75638962], [88.91388702, 21.75666618], [88.91361237, 21.75694466], [88.91361237, 21.75722122], [88.91333008, 21.75749969], [88.91333008, 21.75777817], [88.91305542, 21.75805473], [88.91306305, 21.75861168], [88.91278076, 21.75889015], [88.91278076, 21.75944519], [88.91249847, 21.75972176], [88.91249847, 21.76000023], [88.91278076, 21.76028061], [88.91278076, 21.76111031], [88.91333008, 21.76167107], [88.91333008, 21.76194382], [88.91361237, 21.76222038], [88.91361237, 21.76250076], [88.91388702, 21.76278114], [88.91388702, 21.76305962], [88.91722107, 21.76638985], [88.91750336, 21.76638794], [88.91944122, 21.76833344], [88.91971588, 21.76832962], [88.92028046, 21.76889038], [88.92028046, 21.76916885], [88.92055511, 21.76944351], [88.92056274, 21.76971817], [88.92082977, 21.77000046], [88.92082977, 21.77028084], [88.92111206, 21.7705555], [88.92111206, 21.77082825], [88.92138672, 21.77111053], [88.92111206, 21.77139091], [88.92111206, 21.77194405], [88.92082977, 21.77222061], [88.92082977, 21.77277946], [88.92055511, 21.77305603], [88.92056274, 21.77361107], [88.91999817, 21.77416611], [88.91999817, 21.77472115], [88.91971588, 21.77499962], [88.91972351, 21.77527809], [88.91999817, 21.77555275], [88.91999817, 21.77639008], [88.92028046, 21.77666664], [88.92028046, 21.77722168], [88.92056274, 21.77750015], [88.92055511, 21.77805328], [88.92082977, 21.77832985], [88.92082977, 21.77861023], [88.92111206, 21.77889061], [88.92111206, 21.77916527], [88.92138672, 21.77944374], [88.92138672, 21.77999115], [88.92166901, 21.78028107], [88.92166901, 21.78055763], [88.92193604, 21.78083038], [88.92194366, 21.78166771], [88.92222595, 21.78194046], [88.92222595, 21.78250122], [88.92250061, 21.78277969], [88.92250061, 21.78333282], [88.92277527, 21.7836113], [88.9227829, 21.78388977], [88.92305756, 21.78416634], [88.92305756, 21.78471756], [88.92333221, 21.78499985], [88.92333221, 21.78555489], [88.92359924, 21.78583145], [88.92359924, 21.78611946], [88.92416382, 21.78666687], [88.92415619, 21.78722191], [88.92444611, 21.78750038], [88.92444611, 21.78889084], [88.92416382, 21.7891674], [88.92415619, 21.78944016], [88.92333221, 21.79027939], [88.92305756, 21.79027939], [88.9227829, 21.79055977], [88.92194366, 21.79055405], [88.92166901, 21.79083252], [88.92028046, 21.79083061], [88.91972351, 21.79138947], [88.91971588, 21.79193115], [88.92028046, 21.79249954], [88.92056274, 21.79249954], [88.92077637, 21.79272461], [88.92082977, 21.79277992], [88.92111206, 21.79277611], [88.92166901, 21.79333305], [88.92193604, 21.79333115], [88.92250061, 21.79389], [88.9227829, 21.79389], [88.92305756, 21.79417038], [88.92333221, 21.79417038], [88.92359924, 21.79445076], [88.92388916, 21.79444695], [88.92444611, 21.79500008], [88.92472076, 21.79500008], [88.92666626, 21.79694366], [88.92694092, 21.79693985], [88.92778015, 21.79777908], [88.92778015, 21.79805946], [88.92861176, 21.79888916], [88.92861176, 21.79916573], [88.92888641, 21.7994442], [88.92888641, 21.79972076], [88.9291687, 21.80000114], [88.9291687, 21.80112076], [88.92888641, 21.80138969], [88.92888641, 21.80194473], [88.92861176, 21.80221939], [88.92861176, 21.80277824], [88.9283371, 21.8030529], [88.9283371, 21.80528069], [88.92861176, 21.80555344], [88.92861176, 21.80583572], [88.92888641, 21.80583], [88.9291687, 21.80611038], [88.92944336, 21.80611038], [88.92973328, 21.80639076], [88.93026733, 21.80639076], [88.93055725, 21.80667114], [88.93083191, 21.80666542], [88.93138885, 21.80722237], [88.93165588, 21.80722046], [88.93305206, 21.80861092], [88.93305206, 21.80888939], [88.93333435, 21.80916786], [88.93332672, 21.80971909], [88.93360901, 21.80999947], [88.93360901, 21.81055641], [88.9338913, 21.81083298], [88.93360901, 21.81110764], [88.93360901, 21.81250191], [88.9338913, 21.81278038], [88.9338913, 21.81305504], [88.93416595, 21.81333351], [88.93416595, 21.81361008], [88.9347229, 21.81417274], [88.93583679, 21.81416702], [88.93611145, 21.81444359], [88.93694305, 21.81444359], [88.93722534, 21.81472206], [88.9375, 21.81472015], [88.9383316, 21.81555557], [88.9383316, 21.81583214], [88.93860626, 21.81610107], [88.93860626, 21.8163929], [88.93888855, 21.81666756], [88.93889618, 21.81694031], [88.9383316, 21.81750107], [88.9383316, 21.81777954], [88.93805695, 21.8180542], [88.93805695, 21.81833076], [88.93776703, 21.81861115], [88.93777466, 21.81888962], [88.93722534, 21.81944656], [88.93722534, 21.82083321], [88.9375, 21.82110977], [88.9375, 21.82139015], [88.93723297, 21.82167053], [88.93723297, 21.82195091], [88.93694305, 21.82222748], [88.93694305, 21.82250023], [88.93553925, 21.82389069], [88.93527985, 21.82389069], [88.93499756, 21.82416725], [88.93499756, 21.82444382], [88.9347229, 21.82444382], [88.93458557, 21.82430649], [88.93444824, 21.82416725], [88.93416595, 21.82416916], [88.9338913, 21.82389069], [88.93332672, 21.82389069], [88.93305206, 21.82361031], [88.93222046, 21.82361031], [88.9319458, 21.82389069], [88.93055725, 21.82389069], [88.93026733, 21.82361031], [88.93000031, 21.82361031], [88.92973328, 21.82332993], [88.92861176, 21.82332993], [88.9283371, 21.82361031], [88.92804718, 21.82361031], [88.92778015, 21.82332993], [88.92722321, 21.82332993], [88.92666626, 21.82389069], [88.9263916, 21.82389069], [88.9263916, 21.82416725], [88.92610931, 21.8244381], [88.92610931, 21.82611084], [88.92582703, 21.82638931], [88.92583466, 21.82805634], [88.92610931, 21.8283329], [88.92610931, 21.82971954], [88.92582703, 21.82999992], [88.92583466, 21.83055305], [88.92555237, 21.83082962], [88.92555237, 21.83139038], [88.92527771, 21.83167076], [88.92527771, 21.83278084], [88.92500305, 21.83306122], [88.92500305, 21.83416748], [88.92472076, 21.83444023], [88.92472076, 21.83527946], [88.92444611, 21.83555794], [88.92444611, 21.8358326], [88.92527771, 21.83583069], [88.92582703, 21.83638954], [88.92610931, 21.83638954], [88.9263916, 21.83666992], [88.92749786, 21.83666992], [88.92778015, 21.83638954], [88.92888641, 21.83638954], [88.9291687, 21.83611107], [88.93026733, 21.83611107], [88.93055725, 21.83638954], [88.93138885, 21.83638954], [88.93165588, 21.83666992], [88.93222046, 21.83666611], [88.93250275, 21.83694458], [88.9327774, 21.83694458], [88.93416595, 21.83833313], [88.93416595, 21.8386116], [88.93444824, 21.83889008], [88.93444824, 21.83944511], [88.9347229, 21.83972168], [88.9347229, 21.84305573], [88.93499756, 21.84333038], [88.93499756, 21.84500122], [88.93527985, 21.84527969], [88.93527985, 21.84556007], [88.9355545, 21.84555435], [88.93611145, 21.8461113], [88.9366684, 21.84610939], [88.93723297, 21.84667015], [88.9375, 21.84666443], [88.93777466, 21.84694672], [88.93916321, 21.84694672], [88.9394455, 21.84722137], [88.94139099, 21.84722137]]], [[[88.48487854, 21.83469009], [88.48543549, 21.83459473], [88.48597717, 21.83460808], [88.48651886, 21.83473969], [88.48705292, 21.83496284], [88.48763275, 21.83500099], [88.48823547, 21.83503532], [88.4884491, 21.83509064], [88.48877716, 21.83517265], [88.48928833, 21.83517265], [88.48976898, 21.83468246], [88.49012756, 21.83407211], [88.49045563, 21.83353043], [88.49063873, 21.83299065], [88.49079895, 21.83242989], [88.4908371, 21.83187103], [88.49088287, 21.83134079], [88.49106598, 21.83090973], [88.49121857, 21.83046341], [88.49111176, 21.8302784], [88.49138641, 21.8302803], [88.49138641, 21.82999992], [88.4916687, 21.82971954], [88.4916687, 21.82944489], [88.49222565, 21.82888794], [88.49223328, 21.82860947], [88.49250031, 21.82861137], [88.49305725, 21.82805634], [88.49333954, 21.82806015], [88.49415588, 21.82722282], [88.49416351, 21.82694435], [88.49500275, 21.82611084], [88.49500275, 21.82582855], [88.4952774, 21.8255558], [88.4952774, 21.82529259], [88.49555206, 21.82500076], [88.49594116, 21.8246212], [88.49582672, 21.8244381], [88.49777985, 21.82250023], [88.49777985, 21.82222748], [88.49804688, 21.82195091], [88.49804688, 21.82110977], [88.49833679, 21.82083321], [88.49833679, 21.82027626], [88.49888611, 21.81972122], [88.49888611, 21.81861115], [88.4991684, 21.81833076], [88.4991684, 21.81611061], [88.49972534, 21.81555557], [88.49973297, 21.81361008], [88.5, 21.81333351], [88.5, 21.81305504], [88.50026703, 21.81278038], [88.50026703, 21.81250191], [88.49973297, 21.81195259], [88.49973297, 21.81138992], [88.4992218, 21.81085968], [88.49884796, 21.8103199], [88.49836731, 21.80990028], [88.4978714, 21.80950356], [88.49742126, 21.80915833], [88.49701691, 21.80882072], [88.49668121, 21.8085022], [88.49636841, 21.80817986], [88.49608612, 21.80778122], [88.49582672, 21.80778122], [88.4952774, 21.80722046], [88.49500275, 21.80722237], [88.49472046, 21.8069458], [88.49388885, 21.8069458], [88.49301147, 21.80607224], [88.49277496, 21.80583572], [88.49277496, 21.80555344], [88.49194336, 21.80471992], [88.4916687, 21.80472183], [88.4916687, 21.80444336], [88.4908371, 21.80360985], [88.48999786, 21.80361176], [88.48962402, 21.80239296], [88.48910522, 21.80223083], [88.48862457, 21.80203438], [88.48819733, 21.80181122], [88.48782349, 21.801548], [88.48751068, 21.80116653], [88.48734283, 21.8006916], [88.48722076, 21.80055618], [88.48638916, 21.79972076], [88.48638916, 21.79916573], [88.48583221, 21.79861069], [88.48472595, 21.79861069], [88.48416901, 21.79880905], [88.48368073, 21.79888916], [88.48313141, 21.79902077], [88.48293304, 21.79915047], [88.48264313, 21.79929924], [88.48227692, 21.79953957], [88.48192596, 21.79985046], [88.48153687, 21.80010414], [88.48106384, 21.80025291], [88.48075867, 21.80026817], [88.48049927, 21.80027962], [88.47991943, 21.80023003], [88.47944641, 21.80003929], [88.47901917, 21.79993248], [88.47865295, 21.79976273], [88.47824097, 21.79968452], [88.47780609, 21.79949951], [88.47727203, 21.79940414], [88.47675323, 21.79924965], [88.47623444, 21.79932213], [88.47575378, 21.79942131], [88.47529602, 21.79945946], [88.47488403, 21.79956818], [88.47442627, 21.79969025], [88.47386932, 21.7997303], [88.47325897, 21.79977989], [88.47268677, 21.79996109], [88.47210693, 21.79999924], [88.47150421, 21.80000114], [88.47085571, 21.79999924], [88.47019196, 21.79996109], [88.4695282, 21.79976082], [88.46893311, 21.79972076], [88.46837616, 21.79972076], [88.46782684, 21.79973984], [88.4672699, 21.79985046], [88.46665192, 21.79997063], [88.46599579, 21.80000114], [88.46533203, 21.80000114], [88.46469879, 21.80000114], [88.46409607, 21.80002022], [88.46356964, 21.80013084], [88.4630661, 21.80027962], [88.46257782, 21.80046082], [88.46206665, 21.80051994], [88.4615097, 21.80044746], [88.46102905, 21.80052567], [88.4605484, 21.80055237], [88.46005249, 21.80059814], [88.45957184, 21.80079079], [88.45903778, 21.80089951], [88.4585495, 21.80111885], [88.45815277, 21.80133247], [88.45804596, 21.80138969], [88.45755005, 21.80166817], [88.45704651, 21.80195999], [88.45661163, 21.80230904], [88.45626068, 21.80273247], [88.45588684, 21.80312157], [88.45552063, 21.8035202], [88.45513153, 21.80389595], [88.45474243, 21.80426979], [88.45436859, 21.8046608], [88.45394135, 21.80499458], [88.45349884, 21.80530357], [88.45314026, 21.80566025], [88.45292664, 21.80608177], [88.45275879, 21.80644798], [88.45258331, 21.80675125], [88.45244598, 21.80708122], [88.45223999, 21.80736351], [88.45204163, 21.80768394], [88.45184326, 21.80802345], [88.45160675, 21.80833817], [88.45137787, 21.80867004], [88.45111847, 21.80898285], [88.45088196, 21.80931091], [88.45072174, 21.80970955], [88.45053101, 21.81011009], [88.45027161, 21.81051445], [88.44998169, 21.81095123], [88.44966888, 21.81142807], [88.44948578, 21.81200409], [88.44944763, 21.81262016], [88.44948578, 21.81318855], [88.44967651, 21.81368828], [88.44978333, 21.81423187], [88.45001221, 21.81472015], [88.45033264, 21.81513023], [88.45070648, 21.81544685], [88.45106506, 21.81578064], [88.45147705, 21.81611252], [88.45192719, 21.81648445], [88.45249939, 21.81638908], [88.45305634, 21.81694221], [88.45333099, 21.81694221], [88.45388794, 21.81722069], [88.45402527, 21.81735992], [88.45417023, 21.81750107], [88.45443726, 21.81750107], [88.45471954, 21.81777954], [88.45471954, 21.8180542], [88.45500183, 21.81833267], [88.45527649, 21.81833076], [88.45555878, 21.81861115], [88.45610809, 21.81861115], [88.45639038, 21.81888962], [88.45666504, 21.81888962], [88.45694733, 21.81916428], [88.45777893, 21.81916428], [88.45793915, 21.81932831], [88.45805359, 21.81944656], [88.45889282, 21.81944084], [88.45939636, 21.81973076], [88.45987701, 21.81987572], [88.46012878, 21.81995392], [88.46028137, 21.81999969], [88.46055603, 21.81999969], [88.46083069, 21.82028008], [88.46111298, 21.82027626], [88.46138763, 21.82055664], [88.46166992, 21.82055664], [88.46194458, 21.82083321], [88.46250153, 21.82083321], [88.46277618, 21.82111168], [88.46333313, 21.82110977], [88.46360779, 21.82139015], [88.46389008, 21.82139015], [88.4641571, 21.82167053], [88.46444702, 21.82167053], [88.46472168, 21.82195091], [88.46499634, 21.82195091], [88.46555328, 21.82250023], [88.46611023, 21.82250023], [88.46639252, 21.82278061], [88.46721649, 21.82278061], [88.46749878, 21.82305908], [88.46778107, 21.82305908], [88.46833038, 21.82361031], [88.46861267, 21.82361031], [88.46944427, 21.82444382], [88.46971893, 21.82444382], [88.47000122, 21.82472229], [88.47055817, 21.82471848], [88.47138977, 21.82555962], [88.47168732, 21.82611084], [88.4720459, 21.82642746], [88.47231293, 21.82679939], [88.47251892, 21.82719994], [88.47278595, 21.82755661], [88.47296906, 21.82798195], [88.47316742, 21.82834625], [88.4733429, 21.82860184], [88.47357941, 21.82884789], [88.47374725, 21.82917976], [88.47392273, 21.82957268], [88.47415161, 21.82992935], [88.47434235, 21.83031082], [88.47445679, 21.83073044], [88.47457886, 21.83114815], [88.47470856, 21.83159065], [88.474823, 21.83206177], [88.4750061, 21.83249092], [88.47531128, 21.83292007], [88.47572327, 21.83335114], [88.47614288, 21.83378029], [88.47663879, 21.83415031], [88.47712708, 21.83444023], [88.47761536, 21.83465958], [88.47808838, 21.83476448], [88.478508, 21.83493805], [88.4789505, 21.83499527], [88.47940063, 21.83503914], [88.47982788, 21.8352108], [88.48031616, 21.83536911], [88.48084259, 21.83547974], [88.4813385, 21.83529091], [88.48181915, 21.83512878], [88.48227692, 21.83502007], [88.48272705, 21.83500099], [88.48316193, 21.83498001], [88.4835434, 21.83490372], [88.48390961, 21.83475685], [88.48435211, 21.83472061], [88.48487854, 21.83469009]]], [[[88.59221649, 21.85000038], [88.59249878, 21.84971809], [88.59305573, 21.84972191], [88.59333038, 21.84944534], [88.59371948, 21.84958839], [88.59397888, 21.84922981], [88.59428406, 21.84893227], [88.59462738, 21.8486805], [88.59494019, 21.84839058], [88.59527588, 21.84805107], [88.59583282, 21.84805679], [88.59638977, 21.84749985], [88.5966568, 21.84749985], [88.59694672, 21.84778023], [88.59722137, 21.84778023], [88.59777832, 21.84721947], [88.59805298, 21.84722137], [88.59833527, 21.84694672], [88.59860992, 21.84694672], [88.59889221, 21.84666443], [88.60056305, 21.84667015], [88.60083008, 21.84638977], [88.60111237, 21.84638977], [88.60166168, 21.84583092], [88.60194397, 21.84583282], [88.60219574, 21.84557724], [88.60277557, 21.84499931], [88.6027832, 21.84473991], [88.60333252, 21.84416962], [88.60333252, 21.84389114], [88.60360718, 21.84361076], [88.60360718, 21.84305954], [88.60388947, 21.84278107], [88.60388947, 21.84194183], [88.60416412, 21.84166718], [88.60415649, 21.84139061], [88.60388947, 21.84111023], [88.60388947, 21.83972168], [88.60416412, 21.83944511], [88.60415649, 21.83917046], [88.60388947, 21.83889008], [88.60388947, 21.83832932], [88.60416412, 21.83805466], [88.60416412, 21.83749962], [88.60444641, 21.83723068], [88.60444641, 21.83666992], [88.6047287, 21.83638954], [88.60472107, 21.83611107], [88.60500336, 21.8358326], [88.60500336, 21.83555794], [88.60582733, 21.83472061], [88.60610962, 21.83472252], [88.60639191, 21.83444595], [88.60666656, 21.83444595], [88.60694122, 21.83416748], [88.60721588, 21.83416939], [88.60832977, 21.83306122], [88.60861206, 21.83306122], [88.60888672, 21.83278084], [88.60943604, 21.83278084], [88.60972595, 21.83250046], [88.61055756, 21.83250046], [88.61083221, 21.83222008], [88.6111145, 21.83222198], [88.61138916, 21.83194351], [88.61250305, 21.83194351], [88.61277771, 21.83166695], [88.61332703, 21.83167076], [88.61360168, 21.83139038], [88.61416626, 21.83139038], [88.61424255, 21.83130264], [88.61487579, 21.83110046], [88.61550903, 21.83090019], [88.61614227, 21.83077049], [88.61670685, 21.83055115], [88.61724091, 21.83026123], [88.61754608, 21.82999992], [88.61771393, 21.82985115], [88.61804962, 21.82924461], [88.61824036, 21.82853889], [88.6180191, 21.82785034], [88.61750031, 21.82722282], [88.61750031, 21.82638931], [88.61723328, 21.82611084], [88.61694336, 21.82611084], [88.61608887, 21.82529259], [88.61550903, 21.82496071], [88.61493683, 21.82464027], [88.6144104, 21.82427025], [88.6138916, 21.8239212], [88.61376953, 21.82383156], [88.61344147, 21.8235817], [88.61302948, 21.82325935], [88.61257935, 21.82304001], [88.61218262, 21.82278824], [88.61173248, 21.82257271], [88.61125183, 21.82236099], [88.61075592, 21.82213974], [88.6103363, 21.8218708], [88.61000061, 21.82166862], [88.60943604, 21.82110977], [88.60944366, 21.82083321], [88.60916901, 21.82055664], [88.60916901, 21.82027626], [88.60861206, 21.81972122], [88.60861206, 21.81916428], [88.60805511, 21.81861115], [88.60805511, 21.81777763], [88.60778809, 21.81750107], [88.60778809, 21.81722069], [88.60765076, 21.81709099], [88.60749817, 21.81694221], [88.60749817, 21.81611061], [88.60722351, 21.81583214], [88.60722351, 21.81472206], [88.60749817, 21.81444359], [88.60749817, 21.81416702], [88.60806274, 21.81361008], [88.60805511, 21.81333351], [88.61027527, 21.81111145], [88.61055756, 21.81111145], [88.61222076, 21.80944443], [88.61222076, 21.80916786], [88.61250305, 21.80888939], [88.61250305, 21.80861092], [88.61277771, 21.80833054], [88.61277771, 21.8077755], [88.61305237, 21.80750084], [88.61305237, 21.80722046], [88.61309814, 21.80710602], [88.61326599, 21.80670166], [88.61332703, 21.80622292], [88.61334991, 21.80571175], [88.61342621, 21.80518341], [88.61360931, 21.80500031], [88.61360168, 21.80445099], [88.6138916, 21.80416107], [88.6138916, 21.80333328], [88.61416626, 21.80305481], [88.61416626, 21.80277824], [88.61444092, 21.80249977], [88.61444092, 21.80221939], [88.61472321, 21.80194473], [88.61472321, 21.80138969], [88.61444092, 21.80112076], [88.61444092, 21.80083275], [88.61416626, 21.80055618], [88.61416626, 21.80027962], [88.61472321, 21.79972076], [88.61472321, 21.7994442], [88.61416626, 21.79888916], [88.61416626, 21.79861069], [88.61416626, 21.79805946], [88.6138916, 21.79805565], [88.61360931, 21.79833412], [88.61333466, 21.79833412], [88.61305237, 21.79805565], [88.61277771, 21.79805946], [88.61250305, 21.79777908], [88.61194611, 21.79777718], [88.61138916, 21.79833412], [88.61120605, 21.79833412], [88.61055756, 21.79833412], [88.61000061, 21.79777718], [88.60943604, 21.79777908], [88.60916901, 21.79805946], [88.60749817, 21.79805946], [88.60721588, 21.79777908], [88.60666656, 21.79777908], [88.60629272, 21.79740524], [88.60610962, 21.79722214], [88.60527802, 21.79721832], [88.60500336, 21.79750061], [88.60277557, 21.79750061], [88.60250092, 21.79722214], [88.59722137, 21.79722214], [88.59694672, 21.79694366], [88.59666443, 21.79694366], [88.59638977, 21.7966671], [88.59555817, 21.79667091], [88.59527588, 21.79639053], [88.59500122, 21.79667091], [88.59471893, 21.7966671], [88.59444427, 21.79694366], [88.59388733, 21.79694366], [88.59361267, 21.79722214], [88.59333038, 21.79721832], [88.59333038, 21.79750061], [88.59139252, 21.79750061], [88.59111023, 21.79777908], [88.59055328, 21.79777908], [88.59027863, 21.79805946], [88.59004974, 21.79805183], [88.58945465, 21.79832458], [88.58888245, 21.79863739], [88.58840942, 21.7990303], [88.58807373, 21.7994175], [88.58772278, 21.79971123], [88.58735657, 21.79995728], [88.5869751, 21.80015945], [88.5866394, 21.80039978], [88.58628845, 21.80063057], [88.58591461, 21.80087662], [88.58557892, 21.80118942], [88.58526611, 21.80157089], [88.5849762, 21.80199051], [88.5847168, 21.8024807], [88.5844574, 21.80296135], [88.5842514, 21.80342102], [88.5841217, 21.80386162], [88.58390808, 21.80416107], [88.5837326, 21.80446815], [88.58360291, 21.80476189], [88.58345032, 21.80503082], [88.58332825, 21.80534554], [88.58320618, 21.80566978], [88.58307648, 21.80603027], [88.58297729, 21.80643272], [88.58277893, 21.8068428], [88.58257294, 21.80722046], [88.58238983, 21.80760956], [88.58221436, 21.80795288], [88.58201599, 21.80825996], [88.58184814, 21.8085804], [88.58159637, 21.80887032], [88.58126831, 21.80914116], [88.58088684, 21.80940056], [88.58056641, 21.80971909], [88.58032227, 21.81011009], [88.58010101, 21.81054688], [88.57984161, 21.81096458], [88.57950592, 21.81132317], [88.57910919, 21.81166458], [88.5786972, 21.81202126], [88.57834625, 21.81245041], [88.57804108, 21.81291962], [88.57775116, 21.81336975], [88.57749939, 21.81384087], [88.57727814, 21.81432724], [88.57714081, 21.81488037], [88.57692719, 21.81538963], [88.57665253, 21.81591034], [88.57634735, 21.81645966], [88.57604218, 21.81703377], [88.5761261, 21.81752014], [88.57628632, 21.81799126], [88.57633209, 21.81843758], [88.5761795, 21.81885338], [88.57611847, 21.8192997], [88.57611084, 21.81978989], [88.57611084, 21.8203125], [88.57614136, 21.82083893], [88.57628632, 21.82130051], [88.57641602, 21.82172012], [88.57659912, 21.82202911], [88.57671356, 21.82234573], [88.57686615, 21.82259941], [88.57699585, 21.82291985], [88.57717133, 21.82324982], [88.57727814, 21.82372093], [88.57750702, 21.82419968], [88.57774353, 21.82471848], [88.57785034, 21.82533073], [88.57794952, 21.82593918], [88.57814789, 21.82642174], [88.57830048, 21.82692337], [88.57836151, 21.82746124], [88.57852173, 21.82798958], [88.57859802, 21.82847023], [88.57865143, 21.82889557], [88.57879639, 21.82923126], [88.57887268, 21.8296051], [88.57888794, 21.83004951], [88.57892609, 21.83055115], [88.5790863, 21.83104324], [88.57923126, 21.83160591], [88.57933807, 21.83196068], [88.57940674, 21.83217812], [88.57949066, 21.83279419], [88.57968903, 21.83332062], [88.57980347, 21.83381081], [88.57993317, 21.83420181], [88.58000183, 21.83457756], [88.58010101, 21.83497047], [88.58026886, 21.83542633], [88.58044434, 21.83597374], [88.58061218, 21.83658981], [88.58080292, 21.83723068], [88.58087158, 21.83785057], [88.58102417, 21.83840561], [88.5811615, 21.83896637], [88.58139038, 21.83943939], [88.58165741, 21.83988953], [88.58190918, 21.8403492], [88.58211517, 21.84084129], [88.58229065, 21.84134102], [88.58250427, 21.84181786], [88.58272552, 21.84227943], [88.58292389, 21.84277344], [88.58317566, 21.84326363], [88.5835495, 21.84370995], [88.58389282, 21.84424019], [88.58423615, 21.84477997], [88.58460999, 21.84529114], [88.58495331, 21.84580612], [88.58525848, 21.84635162], [88.58561707, 21.84684944], [88.58605194, 21.84725952], [88.58646393, 21.8476944], [88.58690643, 21.84803009], [88.58726501, 21.8483963], [88.58753204, 21.84879112], [88.58782196, 21.84917068], [88.58815765, 21.84955025], [88.58853912, 21.8499527], [88.58907318, 21.8502903], [88.58956909, 21.85064125], [88.58992767, 21.8510704], [88.59027863, 21.8516674], [88.59055328, 21.85194397], [88.59139252, 21.85194397], [88.59166718, 21.85222244], [88.59194183, 21.85194397], [88.59194183, 21.8516674], [88.59221649, 21.85139084], [88.59194183, 21.85111046], [88.59249878, 21.85055923], [88.59249878, 21.85028076], [88.59221649, 21.85000038]]], [[[88.95532227, 21.84774971], [88.95571136, 21.84832954], [88.95632172, 21.8488903], [88.95670319, 21.84919167], [88.95744324, 21.84971046], [88.95794678, 21.85032082], [88.95859528, 21.85085678], [88.95910645, 21.85133362], [88.95952606, 21.85182953], [88.95983887, 21.85241508], [88.96009064, 21.85293961], [88.96042633, 21.85334015], [88.96082306, 21.85373116], [88.96124268, 21.8541832], [88.96169281, 21.85469055], [88.96217346, 21.85523987], [88.96260834, 21.85580826], [88.96302032, 21.85635757], [88.96338654, 21.85688972], [88.96376038, 21.85737038], [88.96411896, 21.85779953], [88.96444702, 21.8582077], [88.96477509, 21.85857391], [88.96511078, 21.85890961], [88.9654007, 21.85927773], [88.96573639, 21.85959053], [88.96605682, 21.8599205], [88.96640778, 21.86024094], [88.96683502, 21.86045265], [88.9671936, 21.8606739], [88.96751404, 21.86094284], [88.96788025, 21.86119843], [88.96829224, 21.86143112], [88.96869659, 21.86166954], [88.96911621, 21.86188126], [88.96961212, 21.86197281], [88.97006226, 21.86214066], [88.97046661, 21.86228943], [88.97083282, 21.86251068], [88.97121429, 21.86259651], [88.97169495, 21.86282349], [88.97232819, 21.86276627], [88.97312164, 21.86301041], [88.97338104, 21.86322975], [88.97377777, 21.86349106], [88.97433472, 21.86363792], [88.974823, 21.86386108], [88.97531891, 21.86411285], [88.97583771, 21.86431885], [88.97635651, 21.86450958], [88.97686005, 21.86473083], [88.97730255, 21.86499023], [88.97772217, 21.86523819], [88.97805023, 21.8655529], [88.97830963, 21.86589813], [88.97847748, 21.8663311], [88.97870636, 21.86668968], [88.97891235, 21.8670826], [88.97912598, 21.86744118], [88.97927856, 21.8678894], [88.97944641, 21.86835098], [88.97964478, 21.86884117], [88.97967529, 21.86936188], [88.97950745, 21.86988449], [88.97943115, 21.87043953], [88.97932434, 21.87094688], [88.97917175, 21.87138939], [88.97901154, 21.87181854], [88.97881317, 21.87220192], [88.97852325, 21.8725853], [88.97814178, 21.87297058], [88.97770691, 21.87339973], [88.97721863, 21.87389946], [88.97676086, 21.87445068], [88.97634125, 21.87496948], [88.9759903, 21.87542915], [88.97577667, 21.8758831], [88.97547913, 21.87621117], [88.97524261, 21.8765564], [88.97528076, 21.87685204], [88.97518921, 21.87713051], [88.97490692, 21.87746048], [88.9746933, 21.87787056], [88.97471619, 21.87829018], [88.97471619, 21.87873077], [88.97460175, 21.87916565], [88.97442627, 21.87962151], [88.97418213, 21.8800602], [88.97400665, 21.8805542], [88.97383118, 21.88104057], [88.97360229, 21.88149071], [88.9733429, 21.8819294], [88.9731369, 21.88241959], [88.97299957, 21.88293839], [88.97277069, 21.88336754], [88.97249603, 21.88377953], [88.97224426, 21.88416672], [88.97201538, 21.88457108], [88.97187042, 21.88504028], [88.97166443, 21.88549042], [88.97141266, 21.88591957], [88.97117615, 21.88636971], [88.9708786, 21.88674736], [88.97060394, 21.88715172], [88.97035217, 21.88754463], [88.9702301, 21.88804054], [88.97001648, 21.88842964], [88.96983337, 21.88882065], [88.96968842, 21.88924026], [88.96948242, 21.8896904], [88.96930695, 21.89019012], [88.96938324, 21.89075089], [88.9696579, 21.89125061], [88.97025299, 21.89153481], [88.97091675, 21.89179039], [88.97160339, 21.89198112], [88.97228241, 21.8920784], [88.97290039, 21.89224052], [88.97344208, 21.89245987], [88.97397614, 21.89254951], [88.97445679, 21.89273071], [88.97496796, 21.89281082], [88.97543335, 21.89294434], [88.97590637, 21.89307022], [88.97644043, 21.89323807], [88.97667694, 21.89321136], [88.97701263, 21.89325905], [88.97737885, 21.89346695], [88.97789001, 21.89347267], [88.97849274, 21.89344025], [88.97905731, 21.89348984], [88.97928619, 21.89338875], [88.97956848, 21.89325905], [88.98005676, 21.89312172], [88.98057556, 21.89307213], [88.98110199, 21.89304543], [88.98161316, 21.89295959], [88.98200989, 21.89277267], [88.98236847, 21.89256859], [88.98274231, 21.89246941], [88.98311615, 21.89240074], [88.98348236, 21.89233208], [88.98384857, 21.89219856], [88.98420715, 21.8920002], [88.98461151, 21.89179993], [88.98503876, 21.89158821], [88.98547363, 21.89138985], [88.98590851, 21.89118576], [88.98636627, 21.89103127], [88.98677826, 21.89082909], [88.98717499, 21.89061737], [88.98755646, 21.8903904], [88.98797607, 21.89018059], [88.98840332, 21.88995934], [88.98883057, 21.88972092], [88.9892807, 21.88948059], [88.98972321, 21.88927078], [88.99019623, 21.88908005], [88.99064636, 21.88887024], [88.99106598, 21.8886528], [88.99151611, 21.8884697], [88.99195099, 21.88829422], [88.99234772, 21.88805199], [88.99275208, 21.88779831], [88.99317932, 21.88752937], [88.99362946, 21.88726997], [88.99411011, 21.88703918], [88.99459839, 21.88684273], [88.99508667, 21.88664055], [88.99559021, 21.88640022], [88.99610138, 21.88614082], [88.99662018, 21.88587761], [88.99720764, 21.88557053], [88.99794769, 21.88524628], [88.99973297, 21.88360977], [89.0, 21.88389015], [89.00150299, 21.88322067], [89.0018692, 21.88302994], [89.00222015, 21.88278961], [89.00260925, 21.88261032], [89.00296783, 21.88234138], [89.00375366, 21.88199425], [89.00424957, 21.88174248], [89.0044632, 21.88157463], [89.00492096, 21.88134575], [89.00538635, 21.88101006], [89.0059433, 21.88088989], [89.00634003, 21.88062286], [89.00682831, 21.88044739], [89.00786591, 21.88004112], [89.00847626, 21.87976074], [89.00911713, 21.87968063], [89.00952148, 21.87920952], [89.01007843, 21.8788166], [89.01056671, 21.87854958], [89.01117706, 21.87825012], [89.01163483, 21.87790871], [89.01210785, 21.87759972], [89.01268005, 21.87742043], [89.01304626, 21.87719345], [89.01357269, 21.8769207], [89.01390076, 21.87677956], [89.01441193, 21.87669182], [89.01477051, 21.87627029], [89.01515961, 21.8759594], [89.01555634, 21.87569046], [89.01597595, 21.87541962], [89.01641083, 21.87516785], [89.01686096, 21.87494087], [89.01728058, 21.87465096], [89.01764679, 21.87431908], [89.01802826, 21.87403107], [89.01838684, 21.87376404], [89.01879883, 21.87354279], [89.01920319, 21.87328529], [89.01965332, 21.87305069], [89.02009583, 21.87276077], [89.02052307, 21.87240028], [89.0209198, 21.87203789], [89.02133942, 21.87174034], [89.02173615, 21.8714695], [89.02216339, 21.87125015], [89.02250671, 21.87100983], [89.02288055, 21.87074089], [89.02329254, 21.87043953], [89.02371979, 21.87009048], [89.02419281, 21.86978531], [89.02466583, 21.86948967], [89.02511597, 21.86918449], [89.02555847, 21.86889076], [89.02601624, 21.86858749], [89.02643585, 21.86824989], [89.02680969, 21.86782837], [89.02720642, 21.86741829], [89.02761078, 21.86702347], [89.02806091, 21.86665916], [89.02849579, 21.86629105], [89.02889252, 21.86584282], [89.02923584, 21.86537743], [89.02960205, 21.8649292], [89.029953, 21.86444473], [89.03032684, 21.86392212], [89.03051758, 21.86353493], [89.03070068, 21.86320496], [89.03096008, 21.86278152], [89.03092957, 21.86232185], [89.03098297, 21.86186981], [89.03083801, 21.8612709], [89.03093719, 21.86095047], [89.03098297, 21.86008835], [89.0308609, 21.85951042], [89.03083038, 21.85900116], [89.03082275, 21.85855293], [89.03077698, 21.85808372], [89.03066254, 21.85756493], [89.03062439, 21.85695076], [89.03069305, 21.8563118], [89.03069305, 21.85577583], [89.03058624, 21.85520744], [89.03038025, 21.85478973], [89.03009796, 21.85422134], [89.02974701, 21.85369682], [89.02947235, 21.85309982], [89.02922821, 21.85242844], [89.02910614, 21.85172081], [89.02889252, 21.85108948], [89.02849579, 21.85066986], [89.02824402, 21.85038376], [89.02776337, 21.85019112], [89.02719116, 21.84999084], [89.02675629, 21.84968185], [89.02630615, 21.84950066], [89.02577972, 21.84941292], [89.02529907, 21.84922028], [89.02475739, 21.84921646], [89.02455902, 21.8492775], [89.02423096, 21.84938049], [89.02371979, 21.8494606], [89.02323914, 21.84955025], [89.02275085, 21.84968948], [89.0222168, 21.84978104], [89.02168274, 21.84992027], [89.02113342, 21.84997749], [89.02057648, 21.84999275], [89.0200119, 21.84999084], [89.01946259, 21.84999657], [89.0189209, 21.85001183], [89.01840973, 21.85006714], [89.01793671, 21.85019112], [89.01748657, 21.85020065], [89.01705933, 21.85009956], [89.01663208, 21.85011101], [89.01624298, 21.85023117], [89.01582336, 21.85031319], [89.01541901, 21.85041809], [89.01499176, 21.85052109], [89.01452637, 21.85055923], [89.01405334, 21.85058975], [89.01357269, 21.85066986], [89.01312256, 21.8508606], [89.01268005, 21.85110092], [89.01222229, 21.85131836], [89.01174927, 21.85152817], [89.01129913, 21.8517704], [89.01085663, 21.85206032], [89.01037598, 21.85239029], [89.00988007, 21.85277939], [89.00934601, 21.85320282], [89.00884247, 21.85370064], [89.00831604, 21.85420036], [89.00778198, 21.85472107], [89.0072403, 21.85522842], [89.00673676, 21.85576057], [89.00631714, 21.85634041], [89.00592041, 21.85690117], [89.00562286, 21.85748291], [89.00543976, 21.85808754], [89.00532532, 21.85869408], [89.00530243, 21.85926056], [89.00527954, 21.85978127], [89.00527954, 21.86024857], [89.00525665, 21.86070824], [89.00518036, 21.86119843], [89.00505829, 21.86172104], [89.00496674, 21.86225128], [89.00489044, 21.86271095], [89.00486755, 21.86312103], [89.00483704, 21.86346054], [89.00479126, 21.86378288], [89.00469971, 21.86408806], [89.00450897, 21.8644104], [89.00424957, 21.86478043], [89.00382996, 21.86523819], [89.00370026, 21.86544037], [89.00325775, 21.86577606], [89.00311279, 21.86591339], [89.00275421, 21.86611366], [89.00247192, 21.8663826], [89.00232697, 21.86664963], [89.00247192, 21.86692047], [89.00261688, 21.86698723], [89.00268555, 21.86712074], [89.00283051, 21.86732101], [89.00283051, 21.86745834], [89.00261688, 21.86758995], [89.00247192, 21.86773109], [89.0022583, 21.86786079], [89.00203705, 21.86786079], [89.0018158, 21.86779022], [89.00154114, 21.86766052], [89.00147247, 21.86738968], [89.00132751, 21.86732101], [89.00096893, 21.86738968], [89.0, 21.86805534], [88.99972534, 21.86833382], [88.99899292, 21.86876488], [88.99842072, 21.86930275], [88.9981308, 21.86982918], [88.99833679, 21.87055588], [88.99833679, 21.87083244], [88.9981308, 21.87105942], [88.99784851, 21.87117958], [88.99751282, 21.87122154], [88.99713135, 21.87124062], [88.99671173, 21.87124062], [88.99624634, 21.87122154], [88.99577332, 21.87117577], [88.99530792, 21.87104034], [88.99487305, 21.8708477], [88.99450684, 21.87058067], [88.9941864, 21.87029266], [88.99382782, 21.86998177], [88.99341583, 21.86963081], [88.99303436, 21.86918259], [88.99261475, 21.86874962], [88.99220276, 21.86836815], [88.99198151, 21.86784172], [88.99134064, 21.86771011], [88.99040985, 21.86803818], [88.99002075, 21.86806679], [88.98924255, 21.8681221], [88.98962402, 21.86779213], [88.99000549, 21.86747742], [88.99038696, 21.86720848], [88.99079132, 21.86700249], [88.99120331, 21.86683083], [88.99163055, 21.86675072], [88.99199677, 21.86683083], [88.9923172, 21.8670311], [88.99266815, 21.86728668], [88.99302673, 21.86761093], [88.99339294, 21.86798286], [88.99375153, 21.86835098], [88.99388885, 21.86833191], [88.9944458, 21.86888885], [88.9944458, 21.86944389], [88.99472046, 21.86944389], [88.99500275, 21.86972237], [88.9952774, 21.86972046], [88.99555206, 21.87000084], [88.99583435, 21.87000084], [88.99610901, 21.8702774], [88.99666595, 21.8702774], [88.9972229, 21.86972237], [88.9972229, 21.86944389], [88.99753571, 21.86903572], [88.99780273, 21.86865807], [88.99810791, 21.86826706], [88.99843597, 21.86792183], [88.99880981, 21.86766052], [88.99916077, 21.86750031], [88.99945068, 21.86743736], [89.0, 21.86720848], [89.00045013, 21.86692429], [89.00088501, 21.86652374], [89.00117493, 21.86608887], [89.00154114, 21.86568069], [89.00195313, 21.86531067], [89.00231171, 21.86493874], [89.00263214, 21.8645916], [89.00291443, 21.86424637], [89.00318909, 21.86370277], [89.00332642, 21.86335945], [89.00338745, 21.86289024], [89.003479, 21.86235046], [89.003479, 21.86194992], [89.00338745, 21.86169243], [89.00312042, 21.86140823], [89.0029068, 21.86107254], [89.00276184, 21.8608036], [89.00269318, 21.86026573], [89.00298309, 21.86005974], [89.00318909, 21.86006355], [89.00354767, 21.85972786], [89.00376129, 21.85931969], [89.00398254, 21.85878563], [89.00405121, 21.85804939], [89.00399017, 21.85750961], [89.00399017, 21.85696983], [89.00419617, 21.8567009], [89.00447845, 21.85623169], [89.00454712, 21.85610008], [89.00476837, 21.85563087], [89.00505066, 21.85522079], [89.00534058, 21.85495567], [89.0067749, 21.85347366], [89.00717163, 21.85322762], [89.0075531, 21.8529911], [89.00791931, 21.85275078], [89.00823212, 21.85248756], [89.00853729, 21.85220909], [89.00886536, 21.85193253], [89.00921631, 21.85164452], [89.00961304, 21.85136414], [89.01002502, 21.85105896], [89.01040649, 21.85071945], [89.01082611, 21.85040092], [89.01132965, 21.85019112], [89.01183319, 21.84993935], [89.01229858, 21.84966087], [89.01284027, 21.84939957], [89.0134201, 21.84917068], [89.01403809, 21.84910965], [89.01464081, 21.84900093], [89.01526642, 21.8488903], [89.01590729, 21.84879112], [89.01657867, 21.84877968], [89.01727295, 21.8486805], [89.01799774, 21.84863091], [89.01873016, 21.84861946], [89.01947021, 21.84860992], [89.02019501, 21.84861374], [89.02091217, 21.84860611], [89.02159119, 21.84857178], [89.02219391, 21.84846687], [89.0227356, 21.84831047], [89.02297211, 21.84822273], [89.02324677, 21.84811974], [89.02381897, 21.84803009], [89.02435303, 21.84787941], [89.02490997, 21.8477211], [89.02539825, 21.84749031], [89.02584076, 21.84720039], [89.02630615, 21.84687042], [89.02667236, 21.84667015], [89.02703094, 21.84646988], [89.02746582, 21.84626961], [89.02774811, 21.84585762], [89.02796173, 21.84565926], [89.02818298, 21.84519005], [89.02832031, 21.84478569], [89.02896881, 21.84437943], [89.02939606, 21.84404755], [89.02976227, 21.84364128], [89.0298996, 21.84310532], [89.03003693, 21.84263039], [89.03003693, 21.84176064], [89.02996826, 21.84115982], [89.0298233, 21.84062195], [89.0298233, 21.84008026], [89.02989197, 21.83987999], [89.02996826, 21.83926964], [89.02996826, 21.83819771], [89.0298233, 21.83773041], [89.02967834, 21.8373909], [89.02967834, 21.83704948], [89.0298233, 21.83665085], [89.0298233, 21.83625031], [89.02989197, 21.83577919], [89.029953, 21.83521843], [89.02999115, 21.83452988], [89.02976227, 21.83276558], [89.02939606, 21.83169937], [89.02915955, 21.83145142], [89.02890015, 21.83117676], [89.02864838, 21.83084106], [89.0284729, 21.83041], [89.02830505, 21.82993507], [89.02812195, 21.82946014], [89.02807617, 21.82886887], [89.02799225, 21.82871437], [89.02722931, 21.82736588], [89.02690125, 21.82685089], [89.02651978, 21.82636642], [89.02617645, 21.82588005], [89.02588654, 21.82537079], [89.02558136, 21.82489967], [89.02529144, 21.82439995], [89.02501678, 21.82387543], [89.02471161, 21.82333755], [89.02433014, 21.82285118], [89.02384186, 21.82243919], [89.02339172, 21.82197952], [89.0230484, 21.82140923], [89.02276611, 21.82082939], [89.02239227, 21.82032013], [89.02202606, 21.81990051], [89.02175903, 21.81949997], [89.02147675, 21.81918907], [89.02120209, 21.81895065], [89.02098083, 21.81867981], [89.02072144, 21.81845856], [89.02050018, 21.81812096], [89.02024078, 21.81783295], [89.01993561, 21.81759453], [89.01952362, 21.81742668], [89.01917267, 21.81718826], [89.01885223, 21.81690788], [89.01850128, 21.81666946], [89.01815033, 21.81642914], [89.01782227, 21.81615067], [89.0174408, 21.81593323], [89.01701355, 21.81583214], [89.01660156, 21.8157444], [89.01638031, 21.81585312], [89.01570129, 21.81614304], [89.01507568, 21.81678009], [89.01480103, 21.81737328], [89.01449585, 21.81785011], [89.01418304, 21.81833076], [89.01384735, 21.8187809], [89.01351166, 21.81921005], [89.01313019, 21.81962967], [89.01272583, 21.82005119], [89.01232147, 21.82049561], [89.01194763, 21.82098389], [89.01143646, 21.82144165], [89.01093292, 21.82189941], [89.01027679, 21.82243156], [89.00982666, 21.82287216], [89.00932312, 21.82294464], [89.00907135, 21.82297707], [89.00923157, 21.82242966], [89.00971985, 21.82207108], [89.01043701, 21.82122993], [89.01101685, 21.82069969], [89.01159668, 21.82015991], [89.0118866, 21.81960678], [89.01243591, 21.81908035], [89.01283264, 21.81855011], [89.01332092, 21.81814003], [89.01358032, 21.81768227], [89.01383972, 21.81728745], [89.01410675, 21.81688118], [89.01451874, 21.8164196], [89.01452637, 21.81539917], [89.01426697, 21.81491852], [89.01389313, 21.81475067], [89.01343536, 21.81466675], [89.0129776, 21.81451988], [89.01246643, 21.8144207], [89.01197815, 21.8142395], [89.01148987, 21.81414223], [89.01104736, 21.81397629], [89.01061249, 21.81386948], [89.01022339, 21.81371117], [89.00981903, 21.8135891], [89.00948334, 21.81339073], [89.0091095, 21.81324959], [89.00881195, 21.81306267], [89.00846863, 21.81291962], [89.00794983, 21.81295013], [89.00733948, 21.81302071], [89.00666809, 21.81298065], [89.00652313, 21.81294823], [89.00596619, 21.81282043], [89.00525665, 21.81278038], [89.00457001, 21.81278038], [89.00390625, 21.81282043], [89.00331116, 21.81301117], [89.00300598, 21.81303978], [89.00274658, 21.81306267], [89.00226593, 21.81310081], [89.00189209, 21.81330109], [89.00144958, 21.81343079], [89.00099945, 21.81364059], [89.00055695, 21.81382179], [89.0, 21.81417274], [88.99968719, 21.81414986], [88.99938965, 21.8144207], [88.99906158, 21.81455994], [88.99872589, 21.81471062], [88.99861145, 21.81472015], [88.99833679, 21.81500053], [88.99694824, 21.81500053], [88.99666595, 21.81472015], [88.9952774, 21.81472206], [88.99500275, 21.81444359], [88.99472046, 21.81444359], [88.9944458, 21.81416702], [88.99415588, 21.81417274], [88.99307251, 21.81306267], [88.99307251, 21.81278038], [88.9927597, 21.81250191], [88.9927597, 21.81222153], [88.99222565, 21.81166649], [88.99223328, 21.81055832], [88.99194336, 21.81028938], [88.99194336, 21.80943108], [88.99194336, 21.80882072], [88.99194336, 21.80823708], [88.99194336, 21.80805969], [88.99194336, 21.80778122], [88.99223328, 21.80750084], [88.99222565, 21.80638885], [88.99250031, 21.80611038], [88.99194336, 21.80556107], [88.99194336, 21.80500984], [88.99194336, 21.80472183], [88.99222565, 21.80444336], [88.99223328, 21.8030529], [88.99194336, 21.80277824], [88.99188995, 21.80219078], [88.991745, 21.80177116], [88.99188995, 21.80125999], [88.99188232, 21.80079269], [88.99167633, 21.80044937], [88.99144745, 21.80014992], [88.99137878, 21.79981995], [88.99131775, 21.79950714], [88.9912262, 21.79920959], [88.9910965, 21.79891968], [88.99092102, 21.79867172], [88.99077606, 21.79841042], [88.99060822, 21.79816055], [88.99051666, 21.79783821], [88.99032593, 21.79758263], [88.99008179, 21.79735756], [88.98995209, 21.79707336], [88.98976898, 21.79680252], [88.98964691, 21.79645538], [88.98944092, 21.79609108], [88.98918915, 21.79566193], [88.98896027, 21.79512024], [88.98867798, 21.79450035], [88.98842621, 21.79388046], [88.98821259, 21.79328346], [88.98803711, 21.79271507], [88.98780823, 21.79222107], [88.98755646, 21.79174042], [88.9872818, 21.79131126], [88.98703766, 21.79086113], [88.986763, 21.79039192], [88.98647308, 21.78992271], [88.9861145, 21.78952026], [88.98578644, 21.7891407], [88.9855423, 21.78872108], [88.98535156, 21.7883091], [88.98527527, 21.78777695], [88.98500061, 21.78778267], [88.98387909, 21.78667259], [88.98361206, 21.78667259], [88.98194122, 21.78499985], [88.98166656, 21.78499985], [88.97888947, 21.78222084], [88.97861481, 21.78222275], [88.97718048, 21.78082657], [88.97704315, 21.78066254], [88.97693634, 21.78053474], [88.97676849, 21.78020096], [88.97654724, 21.77984047], [88.97635651, 21.77937126], [88.97609711, 21.7789402], [88.97576904, 21.77855873], [88.97541046, 21.77819061], [88.97506714, 21.77782249], [88.97492981, 21.77763367], [88.97476959, 21.77741051], [88.97450256, 21.77699089], [88.97413635, 21.77666283], [88.97376251, 21.77634811], [88.97341919, 21.77601051], [88.97297668, 21.77577019], [88.97251892, 21.7755909], [88.97212982, 21.77542114], [88.97174835, 21.77530098], [88.97136688, 21.77522087], [88.97093964, 21.77506256], [88.97049713, 21.77509117], [88.97000122, 21.77527809], [88.96971893, 21.77555466], [88.96858215, 21.77555466], [88.96805573, 21.77555466], [88.96749878, 21.7761097], [88.96749878, 21.77639008], [88.96694183, 21.77694321], [88.96694183, 21.77721977], [88.96673584, 21.77737045], [88.96665192, 21.77748871], [88.96652222, 21.77766037], [88.96630096, 21.77809143], [88.96602631, 21.77853012], [88.9656601, 21.77887535], [88.96521759, 21.77915955], [88.96475983, 21.77940559], [88.96427917, 21.77960968], [88.96380615, 21.77980995], [88.96337128, 21.78005981], [88.96296692, 21.78035736], [88.96255493, 21.78064346], [88.96219635, 21.78096581], [88.96185303, 21.78123093], [88.96160126, 21.78156281], [88.96127319, 21.78178024], [88.96092987, 21.78197861], [88.96060181, 21.7822113], [88.96022797, 21.78240013], [88.95980072, 21.78252983], [88.95941925, 21.78275108], [88.95897675, 21.78286171], [88.95861053, 21.78302765], [88.95818329, 21.78312111], [88.9577713, 21.78329659], [88.95729828, 21.78333092], [88.95681763, 21.78335571], [88.95640564, 21.7834816], [88.95606995, 21.78362083], [88.95581818, 21.78376961], [88.95556641, 21.78386116], [88.95527649, 21.78388977], [88.95489502, 21.78389168], [88.95440674, 21.78387451], [88.95381165, 21.78378487], [88.95313263, 21.78356171], [88.95241547, 21.78331757], [88.9517746, 21.78354263], [88.95143127, 21.78363991], [88.95111847, 21.78372955], [88.95050049, 21.78389931], [88.94988251, 21.7840538], [88.9491272, 21.78404427], [88.948349, 21.78413963], [88.94763947, 21.78416634], [88.94695282, 21.78419113], [88.94629669, 21.78429985], [88.94565582, 21.78423309], [88.94509125, 21.78440285], [88.94458008, 21.7844696], [88.9441452, 21.7845974], [88.94373322, 21.78473473], [88.94335175, 21.78494263], [88.9430542, 21.78525543], [88.94281769, 21.78560066], [88.94277954, 21.78603935], [88.94278717, 21.78650093], [88.94290924, 21.78695107], [88.94306946, 21.78741074], [88.94327545, 21.78787231], [88.94346619, 21.7883606], [88.94364166, 21.78886032], [88.94387817, 21.78928947], [88.94412994, 21.78970146], [88.94443512, 21.79008675], [88.94470978, 21.79051971], [88.94499969, 21.79101944], [88.94538116, 21.79148674], [88.94574738, 21.79193115], [88.9460907, 21.79237938], [88.94637299, 21.79282951], [88.94658661, 21.79328918], [88.94674683, 21.79379272], [88.94702911, 21.79421043], [88.94724274, 21.7946682], [88.94753265, 21.79509163], [88.9478302, 21.79552078], [88.94817352, 21.79594994], [88.94851685, 21.79640961], [88.94885254, 21.79691124], [88.94917297, 21.79741096], [88.94947052, 21.79788589], [88.94979095, 21.79835129], [88.94987488, 21.79847908], [88.95009613, 21.7988224], [88.95046997, 21.79923058], [88.95079803, 21.79969978], [88.95107269, 21.80022049], [88.95144653, 21.80059814], [88.95181274, 21.80092049], [88.952034, 21.8013401], [88.95230865, 21.80174065], [88.95266724, 21.80213928], [88.95304871, 21.80255508], [88.95344543, 21.80298996], [88.95392609, 21.80329514], [88.95450592, 21.80342102], [88.95511627, 21.80358124], [88.95574188, 21.80360985], [88.95635223, 21.80356979], [88.95691681, 21.80337906], [88.9574585, 21.80328941], [88.95792389, 21.80310822], [88.95839691, 21.80297279], [88.9588623, 21.80275917], [88.95926666, 21.8024807], [88.95966339, 21.80218315], [88.96009064, 21.80195045], [88.9605484, 21.8017807], [88.96102142, 21.80161095], [88.96148682, 21.80142975], [88.96199799, 21.80134964], [88.96246338, 21.80116081], [88.96290588, 21.80097961], [88.96334839, 21.80080986], [88.96357727, 21.80071068], [88.96379089, 21.80061913], [88.96425629, 21.80051041], [88.96472168, 21.80031204], [88.96518707, 21.80018616], [88.96557617, 21.80001068], [88.96595001, 21.79987717], [88.96630859, 21.79975128], [88.96669769, 21.79969978], [88.96711731, 21.79956818], [88.96749878, 21.7994709], [88.96788788, 21.79943848], [88.96829987, 21.79945946], [88.96870422, 21.79954338], [88.96903229, 21.79969025], [88.9693222, 21.79986763], [88.9696579, 21.79997826], [88.97001648, 21.80005836], [88.97033691, 21.80025101], [88.97075653, 21.80037117], [88.97130585, 21.80056953], [88.97157288, 21.80067825], [88.97200775, 21.8007412], [88.97261047, 21.8010006], [88.97303009, 21.80120087], [88.97331238, 21.80149078], [88.97372437, 21.80168724], [88.97410583, 21.80194283], [88.97450256, 21.80220604], [88.97467041, 21.80229378], [88.97490692, 21.80240822], [88.97523499, 21.80259514], [88.9754715, 21.80285645], [88.97561646, 21.80323029], [88.97585297, 21.80357742], [88.97611237, 21.80392075], [88.97634125, 21.80428505], [88.97641754, 21.80446815], [88.97650146, 21.80468941], [88.97663879, 21.80508995], [88.97667694, 21.80552864], [88.97668457, 21.80599213], [88.97675323, 21.80644226], [88.97690582, 21.8068428], [88.97696686, 21.80727386], [88.97709656, 21.80764389], [88.97720337, 21.80792046], [88.97723389, 21.80822182], [88.97730255, 21.80853081], [88.9774704, 21.80888939], [88.97753143, 21.80934334], [88.97769928, 21.80982971], [88.9777832, 21.81044006], [88.97782135, 21.81110764], [88.97798157, 21.81175041], [88.9779129, 21.81244278], [88.97805023, 21.81301117], [88.97821808, 21.81349945], [88.97838593, 21.81393623], [88.97860718, 21.8143425], [88.97877502, 21.8148098], [88.97882843, 21.81495094], [88.9789505, 21.81528282], [88.97911835, 21.81575966], [88.97933197, 21.81620026], [88.97946167, 21.81671906], [88.97962189, 21.81726456], [88.9797287, 21.81784248], [88.97984314, 21.81839943], [88.97985077, 21.81894875], [88.97975159, 21.81945038], [88.97969055, 21.81990051], [88.97950745, 21.82022095], [88.97950745, 21.82063103], [88.97950745, 21.82086182], [88.97956085, 21.82104111], [88.97930908, 21.82138062], [88.97904205, 21.82178116], [88.97888184, 21.82222557], [88.97851563, 21.82268333], [88.97820282, 21.8230896], [88.97786713, 21.82351112], [88.97750854, 21.82390022], [88.97717285, 21.82429123], [88.97683716, 21.82464981], [88.97651672, 21.82496643], [88.97625732, 21.82513046], [88.97612762, 21.82521057], [88.97577667, 21.82550049], [88.97537994, 21.82578278], [88.97493744, 21.82606888], [88.97441864, 21.82633209], [88.97384644, 21.82655144], [88.97322845, 21.82670021], [88.97267151, 21.82695007], [88.97212982, 21.82721519], [88.97155762, 21.82743263], [88.97088623, 21.82753944], [88.97019958, 21.82765579], [88.96948242, 21.8277607], [88.96875, 21.8277607], [88.96802521, 21.82765388], [88.96805573, 21.82749939], [88.96666718, 21.82749939], [88.96639252, 21.82722282], [88.9658432, 21.82722282], [88.96555328, 21.82749939], [88.9641571, 21.82749939], [88.96382904, 21.82730293], [88.96322632, 21.82716942], [88.962677, 21.8269825], [88.9621048, 21.82682228], [88.96154785, 21.82667351], [88.96100616, 21.82654572], [88.96050262, 21.8263607], [88.95999908, 21.82625008], [88.95957184, 21.8261795], [88.95915222, 21.82613373], [88.95872498, 21.82611275], [88.95833588, 21.82612801], [88.95800018, 21.82624054], [88.95771027, 21.82639694], [88.95744324, 21.82657051], [88.95713806, 21.82668114], [88.95684814, 21.82681274], [88.95654297, 21.82694817], [88.95623016, 21.82712364], [88.95596313, 21.82740974], [88.95575714, 21.82784271], [88.95553589, 21.82826996], [88.95527649, 21.82863998], [88.95502472, 21.82895088], [88.95479584, 21.82922173], [88.95465088, 21.82950974], [88.95446014, 21.82970619], [88.95424652, 21.82990074], [88.95410919, 21.83018684], [88.95392609, 21.83045387], [88.95378876, 21.83078003], [88.95360565, 21.83106995], [88.95339966, 21.83133125], [88.95323944, 21.83163071], [88.95302582, 21.83187103], [88.95281219, 21.83207703], [88.95265961, 21.83234024], [88.95250702, 21.83266068], [88.95240021, 21.83301926], [88.95223999, 21.83339119], [88.95214844, 21.83382034], [88.95195007, 21.83421326], [88.9517746, 21.8346138], [88.95158386, 21.83497238], [88.95140076, 21.83523941], [88.95111847, 21.83559036], [88.95089722, 21.83588409], [88.95072174, 21.83617973], [88.95052338, 21.83653069], [88.95033264, 21.83686066], [88.95027924, 21.83723068], [88.95027924, 21.83763885], [88.95028687, 21.8380909], [88.95036316, 21.8386116], [88.95037079, 21.83915138], [88.95035553, 21.83969116], [88.95056152, 21.84016991], [88.95083618, 21.84065056], [88.95108032, 21.84115791], [88.95124054, 21.84174156], [88.95155334, 21.8421917], [88.95191193, 21.84256172], [88.95215607, 21.8429966], [88.9523468, 21.84346008], [88.95256042, 21.84392929], [88.95285034, 21.84435081], [88.95324707, 21.84472084], [88.95368195, 21.84511185], [88.95397949, 21.84563065], [88.95436096, 21.84612465], [88.95472717, 21.84661102], [88.95507813, 21.84710121], [88.95532227, 21.84774971]]], [[[88.40484619, 21.79929924], [88.40450287, 21.79894829], [88.40413666, 21.79858971], [88.40379333, 21.79821014], [88.4034729, 21.79781151], [88.40320587, 21.79756355], [88.40292358, 21.79761505], [88.40257263, 21.7976799], [88.40220642, 21.79776955], [88.40187073, 21.7979393], [88.4015274, 21.79803085], [88.40158081, 21.79826546], [88.40170288, 21.79858971], [88.40190125, 21.79894829], [88.40196228, 21.79933929], [88.4020462, 21.79968071], [88.40219879, 21.80001068], [88.40222168, 21.80040932], [88.40222168, 21.80060959], [88.40222168, 21.80088425], [88.40219116, 21.80142975], [88.40200043, 21.80203438], [88.40194702, 21.80264282], [88.40194702, 21.80322075], [88.40194702, 21.80375099], [88.40196991, 21.80426979], [88.4020462, 21.80481911], [88.40213013, 21.80540276], [88.40202332, 21.80592918], [88.40190125, 21.80643272], [88.40172577, 21.8068428], [88.40164948, 21.80724716], [88.40154266, 21.807621], [88.40141296, 21.80800056], [88.40132141, 21.80838013], [88.40120697, 21.80875015], [88.40113068, 21.8091011], [88.40112305, 21.80944061], [88.4010849, 21.80978775], [88.40097046, 21.81013107], [88.40083313, 21.81054688], [88.40068817, 21.81097221], [88.40058136, 21.81147194], [88.40055847, 21.81199265], [88.40053558, 21.81249046], [88.40039825, 21.81290054], [88.40014648, 21.81323814], [88.40010834, 21.8136692], [88.40006256, 21.81405067], [88.39996338, 21.81436157], [88.39977264, 21.81459236], [88.39956665, 21.8148098], [88.39946747, 21.8151207], [88.39940643, 21.81550026], [88.39929962, 21.81589127], [88.3992157, 21.81633568], [88.39913177, 21.81682968], [88.39884186, 21.81729126], [88.39861298, 21.81779099], [88.39841461, 21.81827545], [88.39833832, 21.81875992], [88.39827728, 21.81918526], [88.39809418, 21.81947327], [88.39801025, 21.8198185], [88.39782715, 21.82012939], [88.39775085, 21.82048988], [88.39758301, 21.82078934], [88.3974762, 21.82113647], [88.39730072, 21.82143021], [88.39714813, 21.82172966], [88.3969574, 21.82203293], [88.39679718, 21.82236099], [88.39656067, 21.82262993], [88.39633942, 21.82289124], [88.39605713, 21.82308006], [88.39583588, 21.82329941], [88.39562225, 21.82353973], [88.395401, 21.82378578], [88.39523315, 21.82411194], [88.39504242, 21.82448959], [88.39495087, 21.82497978], [88.3947525, 21.82549095], [88.39463043, 21.82604027], [88.39447784, 21.82656097], [88.39438629, 21.8270607], [88.39421082, 21.82741928], [88.39412689, 21.82777977], [88.39395142, 21.82802963], [88.3939209, 21.82823753], [88.39390564, 21.8283329], [88.39386749, 21.828619], [88.39373016, 21.82884026], [88.39352417, 21.82903862], [88.39334106, 21.82940483], [88.39293671, 21.83118057], [88.39251709, 21.83260155], [88.39287567, 21.83454704], [88.39299774, 21.83588982], [88.39337158, 21.83770752], [88.3938446, 21.83872795], [88.39430237, 21.83972168], [88.39573669, 21.8422699], [88.39582062, 21.84328079], [88.3961792, 21.84468842], [88.39789581, 21.84879112], [88.39861298, 21.85000038], [88.39842987, 21.85066986], [88.39861298, 21.85110092], [88.39888, 21.85150528], [88.399086, 21.85196114], [88.39985657, 21.85329437], [88.40042877, 21.85551453], [88.40071869, 21.85679054], [88.40052795, 21.85843086], [88.40055847, 21.8588295], [88.40055084, 21.8592205], [88.40050507, 21.8596077], [88.40033722, 21.85997963], [88.40027618, 21.86041069], [88.40022278, 21.86083794], [88.40009308, 21.86124039], [88.40021515, 21.86163712], [88.40027618, 21.86198235], [88.40027618, 21.86234093], [88.4002533, 21.86275101], [88.40007782, 21.86317062], [88.39996338, 21.86370277], [88.39975739, 21.86424065], [88.39971924, 21.86478806], [88.39971924, 21.86531067], [88.39969635, 21.86577988], [88.39962006, 21.86622047], [88.39953613, 21.86667252], [88.39951324, 21.86715508], [88.3996582, 21.86770248], [88.39966583, 21.86828041], [88.39951324, 21.86885071], [88.39945984, 21.86940956], [88.39943695, 21.86989021], [88.39945984, 21.87034988], [88.39953613, 21.87082291], [88.39971924, 21.87135124], [88.39998627, 21.87194061], [88.39998627, 21.87249947], [88.40027618, 21.87277794], [88.40027618, 21.87292099], [88.40027618, 21.87306023], [88.40055847, 21.87334061], [88.40083313, 21.87333298], [88.40100861, 21.87350845], [88.40194702, 21.87444687], [88.40194702, 21.87472153], [88.40305328, 21.87583351], [88.40305328, 21.87611198], [88.40389252, 21.87694359], [88.40389252, 21.87722206], [88.40410614, 21.87742805], [88.40416718, 21.87805557], [88.40424347, 21.87808228], [88.4046402, 21.87822342], [88.4050293, 21.87854958], [88.40541077, 21.87888908], [88.4058075, 21.87924957], [88.40619659, 21.87964058], [88.40664673, 21.87997437], [88.40714264, 21.88027191], [88.40760803, 21.88055038], [88.40808105, 21.88083267], [88.40852356, 21.88113594], [88.4088974, 21.88148117], [88.40927887, 21.8818512], [88.409729, 21.88216972], [88.41021729, 21.88252068], [88.41072083, 21.88290596], [88.41118622, 21.88330269], [88.41168213, 21.88360023], [88.41218567, 21.88383675], [88.4127121, 21.8840313], [88.41318512, 21.88436127], [88.41366577, 21.88481331], [88.41414642, 21.88537216], [88.41475677, 21.88577461], [88.41529083, 21.88623238], [88.41591644, 21.8866291], [88.4162674, 21.88686943], [88.41674805, 21.88708305], [88.41713715, 21.88727951], [88.41744232, 21.88762093], [88.41777039, 21.88788033], [88.41806793, 21.88830948], [88.41835022, 21.88863182], [88.41860962, 21.88894844], [88.41884613, 21.88929939], [88.41902924, 21.88972092], [88.41918182, 21.89014053], [88.41938019, 21.8905201], [88.41950226, 21.89099121], [88.41970062, 21.89147186], [88.41983795, 21.89205742], [88.41998291, 21.89268112], [88.41999817, 21.89333153], [88.41996765, 21.89396095], [88.4197998, 21.8945446], [88.41972351, 21.89512444], [88.41964722, 21.8956604], [88.41945648, 21.89611053], [88.41929626, 21.89653778], [88.41913605, 21.89694023], [88.41890717, 21.89732933], [88.41876221, 21.89776993], [88.41863251, 21.89824295], [88.41860962, 21.89874077], [88.41860962, 21.89929581], [88.41860962, 21.8998909], [88.41857147, 21.90052795], [88.41849518, 21.90118408], [88.41872406, 21.90179443], [88.41880035, 21.90195847], [88.41900635, 21.90240288], [88.41941071, 21.90283966], [88.41982269, 21.90313911], [88.42043304, 21.90308952], [88.42063141, 21.90304184], [88.42105103, 21.90294266], [88.42175293, 21.90300179], [88.42243195, 21.90298271], [88.4229126, 21.90288734], [88.42327118, 21.90274048], [88.42375183, 21.90272141], [88.4239502, 21.90270042], [88.42449951, 21.90250015], [88.42485046, 21.90243912], [88.42549133, 21.9023819], [88.42563629, 21.9024601], [88.42708588, 21.9023819], [88.42809296, 21.90231514], [88.4285202, 21.90191269], [88.42959595, 21.90151024], [88.43052673, 21.9012394], [88.43123627, 21.90089989], [88.43281555, 21.90076637], [88.43333435, 21.90083313], [88.43360901, 21.9011116], [88.43444824, 21.9011097], [88.43458557, 21.90124893], [88.4347229, 21.90139008], [88.43499756, 21.90139008], [88.43527985, 21.90167046], [88.43583679, 21.90167046], [88.4366684, 21.90250015], [88.43694305, 21.90250015], [88.43753052, 21.90307236], [88.4380722, 21.90357018], [88.43859863, 21.90409088], [88.43906403, 21.90462685], [88.43948364, 21.90517426], [88.43994141, 21.90566063], [88.44034576, 21.90614128], [88.44091797, 21.90617371], [88.44149017, 21.90590477], [88.44246674, 21.90583229], [88.44297028, 21.90569878], [88.44342804, 21.90557289], [88.44384003, 21.90545082], [88.44419861, 21.90529823], [88.44457245, 21.90516281], [88.44499969, 21.9050312], [88.44546509, 21.90500069], [88.445961, 21.90498734], [88.4464798, 21.90492058], [88.4469986, 21.9047718], [88.44747925, 21.9048481], [88.44782257, 21.9048233], [88.44843292, 21.90487289], [88.44901276, 21.90485382], [88.44963074, 21.90479469], [88.45019531, 21.90463638], [88.45096588, 21.90479088], [88.45166779, 21.90489006], [88.45201874, 21.9048481], [88.45214081, 21.90467453], [88.4522171, 21.90441322], [88.4522934, 21.9041214], [88.45246124, 21.90387535], [88.45250702, 21.90354919], [88.45256805, 21.90319061], [88.45274353, 21.90284348], [88.45285797, 21.90242958], [88.45304108, 21.90193939], [88.45318604, 21.90145111], [88.45330048, 21.90094948], [88.45355225, 21.90060997], [88.45375061, 21.90029907], [88.45391083, 21.90003014], [88.45407104, 21.89978027], [88.45410919, 21.8994236], [88.45438385, 21.89916229], [88.45454407, 21.89883041], [88.45474243, 21.89847946], [88.45497131, 21.89813232], [88.45518494, 21.89770317], [88.45542145, 21.89722061], [88.45585632, 21.89690971], [88.45594788, 21.89637184], [88.45667267, 21.89594078], [88.4570694, 21.89537239], [88.45761871, 21.89499092], [88.45818329, 21.8946991], [88.4586792, 21.89443588], [88.45913696, 21.89420128], [88.45957947, 21.89398956], [88.46005249, 21.89382172], [88.46055603, 21.89364052], [88.46113586, 21.89356041], [88.46178436, 21.89353943], [88.46244049, 21.89345932], [88.46309662, 21.89331055], [88.46378326, 21.89323807], [88.46452332, 21.89328957], [88.4650116, 21.89301109], [88.46537018, 21.89266014], [88.46575928, 21.8924427], [88.46617889, 21.89233208], [88.46652985, 21.89223862], [88.46691132, 21.89217949], [88.46727753, 21.89198112], [88.46769714, 21.89196014], [88.46814728, 21.89208412], [88.46868896, 21.89234352], [88.46936035, 21.89233589], [88.47003937, 21.89215851], [88.47062683, 21.89211082], [88.47103882, 21.89193344], [88.47137451, 21.8916893], [88.47170258, 21.89145851], [88.47208405, 21.89133263], [88.47254944, 21.89130974], [88.47312164, 21.89137077], [88.47374725, 21.89134026], [88.47437286, 21.89110756], [88.47499084, 21.89082718], [88.47557831, 21.8905201], [88.47618103, 21.89028931], [88.47680664, 21.89022064], [88.47741699, 21.8902092], [88.4779129, 21.88999557], [88.47833252, 21.88972092], [88.47873688, 21.88944054], [88.47916412, 21.88917923], [88.47963715, 21.88895035], [88.48008728, 21.88863945], [88.48056793, 21.88834763], [88.48107147, 21.88812256], [88.48162079, 21.88802147], [88.48210907, 21.88781929], [88.48242188, 21.88734055], [88.48266602, 21.88676071], [88.48309326, 21.88637161], [88.48353577, 21.88591957], [88.48382568, 21.88525009], [88.48397064, 21.88450241], [88.48413849, 21.88381195], [88.48438263, 21.88311958], [88.48451233, 21.88246536], [88.48468781, 21.88189125], [88.48472595, 21.88167191], [88.48443604, 21.88138962], [88.48443604, 21.88083267], [88.48388672, 21.88027763], [88.48416901, 21.88027954], [88.48500061, 21.8794384], [88.48500061, 21.87888908], [88.48443604, 21.87832832], [88.48444366, 21.87694359], [88.48416901, 21.87666893], [88.48443604, 21.87667084], [88.48555756, 21.87556076], [88.4852829, 21.87528038], [88.4852829, 21.87388992], [88.48555756, 21.87360954], [88.48555756, 21.8730545], [88.4852829, 21.87277985], [88.4852829, 21.87222099], [88.48500061, 21.87194443], [88.48527527, 21.87194443], [88.4861145, 21.87111092], [88.48610687, 21.87026978], [88.48800659, 21.86458397], [88.4885788, 21.86162567], [88.48972321, 21.85826111], [88.49015045, 21.85638046], [88.49030304, 21.85396194], [88.49029541, 21.85180855], [88.49072266, 21.85032082], [88.49015045, 21.84804153], [88.48972321, 21.84656334], [88.48972321, 21.84454536], [88.489151, 21.84294128], [88.48943329, 21.84118271], [88.48916626, 21.83916664], [88.48916626, 21.83889008], [88.48880768, 21.83827972], [88.48847198, 21.83782959], [88.48809052, 21.83757401], [88.48768616, 21.83755875], [88.48748779, 21.83764458], [88.48728943, 21.83773041], [88.48690033, 21.83777809], [88.48649597, 21.83777809], [88.48606873, 21.83777809], [88.48554993, 21.83777809], [88.48497772, 21.83777809], [88.48441315, 21.83777809], [88.4838562, 21.83777809], [88.48339081, 21.83773041], [88.48295593, 21.83754349], [88.48246765, 21.83749962], [88.48194122, 21.83749962], [88.48137665, 21.83753967], [88.48085022, 21.83773041], [88.48029327, 21.83777809], [88.47972107, 21.83777809], [88.47917175, 21.83777809], [88.47862244, 21.83777809], [88.47809601, 21.83773994], [88.47763062, 21.83753014], [88.47714996, 21.8374176], [88.47675323, 21.83720016], [88.47637939, 21.83694458], [88.47600555, 21.83667946], [88.47560883, 21.83644104], [88.47518921, 21.83618927], [88.47476959, 21.83601761], [88.47438049, 21.83576012], [88.47416687, 21.83555794], [88.47305298, 21.83444023], [88.47305298, 21.83361053], [88.47277832, 21.83333015], [88.47277832, 21.8330574], [88.47249603, 21.83278084], [88.47194672, 21.83278084], [88.4716568, 21.83250046], [88.47083282, 21.83167076], [88.47083282, 21.83139038], [88.47000122, 21.83056068], [88.47000122, 21.8302803], [88.46971893, 21.8302803], [88.46943665, 21.82999992], [88.46971893, 21.82971954], [88.46944427, 21.82944489], [88.46916962, 21.82944489], [88.46805573, 21.8283329], [88.46778107, 21.82861137], [88.46749878, 21.8283329], [88.46749878, 21.82805634], [88.46778107, 21.82777977], [88.46694183, 21.82694244], [88.46666718, 21.82694435], [88.46639252, 21.82666588], [88.4658432, 21.82666969], [88.46579742, 21.82638931], [88.46546936, 21.82611084], [88.46513367, 21.82583427], [88.46476746, 21.82555389], [88.46450806, 21.82538414], [88.46437073, 21.8252964], [88.46386719, 21.82513046], [88.46333313, 21.82501984], [88.4631958, 21.82500458], [88.46276093, 21.8249588], [88.46222687, 21.8247509], [88.46166992, 21.82459068], [88.46113586, 21.8244381], [88.46064758, 21.82427025], [88.460289, 21.82416916], [88.4597168, 21.82416916], [88.45944214, 21.82389069], [88.45916748, 21.82389069], [88.45889282, 21.82361031], [88.45861053, 21.82361031], [88.45833588, 21.82332993], [88.45805359, 21.82333374], [88.45749664, 21.8227787], [88.45722961, 21.82278061], [88.45694733, 21.82250023], [88.45661163, 21.82250023], [88.45607758, 21.82232285], [88.45552063, 21.82217407], [88.45496368, 21.82196808], [88.45433807, 21.82180977], [88.45374298, 21.82149124], [88.45323181, 21.82102585], [88.45265961, 21.82074928], [88.45218658, 21.82053947], [88.45178986, 21.82024956], [88.45143127, 21.81990051], [88.45104218, 21.81952095], [88.45059204, 21.81919861], [88.4502182, 21.8188076], [88.44980621, 21.81851006], [88.44954681, 21.81814003], [88.44937897, 21.81772995], [88.44917297, 21.81735992], [88.44893646, 21.81699181], [88.44870758, 21.81661034], [88.44853973, 21.81615829], [88.44831848, 21.8157196], [88.44806671, 21.81528282], [88.44786835, 21.81478882], [88.44777679, 21.81418037], [88.44777679, 21.81400108], [88.44777679, 21.81351089], [88.44777679, 21.81282806], [88.44777679, 21.81217194], [88.44773102, 21.81157875], [88.44758606, 21.8110199], [88.44763184, 21.81040001], [88.44763947, 21.80969048], [88.4477005, 21.80900002], [88.44792938, 21.80841827], [88.44802094, 21.80781746], [88.4480896, 21.80732155], [88.44827271, 21.80698967], [88.44837189, 21.8066597], [88.44856262, 21.80640984], [88.44863892, 21.8060894], [88.44876862, 21.80581284], [88.44890594, 21.80553055], [88.44908905, 21.80529976], [88.44933319, 21.80508041], [88.44947052, 21.80474281], [88.44969177, 21.80444336], [88.4499588, 21.80416107], [88.45025635, 21.80386162], [88.45056152, 21.80356979], [88.45088196, 21.80328941], [88.45119476, 21.80306816], [88.45150757, 21.80285072], [88.45184326, 21.80260086], [88.45217896, 21.80227089], [88.45252991, 21.80192947], [88.45284271, 21.80157089], [88.45304108, 21.80117607], [88.45330048, 21.80088806], [88.45353699, 21.80057144], [88.45381927, 21.80029106], [88.45414734, 21.80005074], [88.45446777, 21.79975128], [88.45481873, 21.79945946], [88.45522308, 21.79919052], [88.45569611, 21.79896164], [88.45616913, 21.7986927], [88.45672607, 21.79857063], [88.45722961, 21.7983284], [88.45770264, 21.79805565], [88.45819855, 21.79776955], [88.45868683, 21.79744148], [88.45922852, 21.79715919], [88.45977783, 21.79693222], [88.46027374, 21.7966938], [88.46078491, 21.79656029], [88.46124268, 21.79636955], [88.46169281, 21.79615021], [88.46227264, 21.79609108], [88.46290588, 21.79603958], [88.46349335, 21.79582024], [88.46398926, 21.79550171], [88.46435547, 21.79504013], [88.46446991, 21.79437065], [88.46453094, 21.79371834], [88.4645462, 21.79311943], [88.46446991, 21.79257011], [88.46431732, 21.79207802], [88.46411133, 21.79161072], [88.46388245, 21.79114914], [88.46356201, 21.79071045], [88.46308136, 21.79036522], [88.46238708, 21.79013062], [88.46167755, 21.78985977], [88.4614563, 21.78981018], [88.4611969, 21.78993988], [88.46076965, 21.79009056], [88.46025848, 21.79033279], [88.4597168, 21.79063988], [88.45916748, 21.79101563], [88.45862579, 21.79144287], [88.45810699, 21.79187965], [88.45757294, 21.79225922], [88.45708466, 21.79263878], [88.45677185, 21.79288483], [88.45661163, 21.79301071], [88.45613098, 21.79336929], [88.45569611, 21.79375076], [88.45529938, 21.79418755], [88.45493317, 21.79463959], [88.45446777, 21.79504013], [88.45401764, 21.79542923], [88.45359039, 21.79582024], [88.45310211, 21.79617119], [88.45262909, 21.79652977], [88.45217133, 21.79688072], [88.45168304, 21.79721069], [88.45121002, 21.79756737], [88.45080566, 21.79801941], [88.45041656, 21.7984581], [88.44999695, 21.79887962], [88.44957733, 21.79926109], [88.4490509, 21.79965019], [88.44844055, 21.80000114], [88.44783783, 21.80035782], [88.44739532, 21.80067635], [88.44727325, 21.80076218], [88.44667053, 21.80110168], [88.44605255, 21.80139351], [88.44545746, 21.80166054], [88.44489288, 21.80187988], [88.44429779, 21.80198097], [88.44378662, 21.80218315], [88.44326019, 21.8022213], [88.44274139, 21.80221176], [88.44223022, 21.80212021], [88.44171906, 21.80200195], [88.44122314, 21.80195045], [88.44068909, 21.80188942], [88.44022369, 21.80167389], [88.43968964, 21.80145073], [88.43891907, 21.80138016], [88.43813324, 21.80132294], [88.43742371, 21.80117035], [88.43672943, 21.80112076], [88.43608093, 21.8010006], [88.43547821, 21.80072784], [88.43483734, 21.80064964], [88.43431091, 21.80050087], [88.43387604, 21.80027962], [88.43344879, 21.80008125], [88.43295288, 21.80001068], [88.43241119, 21.80002022], [88.4318924, 21.8000927], [88.43140411, 21.80021477], [88.43096924, 21.80031013], [88.43062592, 21.80048943], [88.43035889, 21.80070877], [88.43006134, 21.80090332], [88.4298172, 21.80113983], [88.42960358, 21.80143738], [88.42945862, 21.80179024], [88.42933655, 21.80220413], [88.42919159, 21.80265045], [88.42907715, 21.80311966], [88.42891693, 21.8035202], [88.42881775, 21.80389977], [88.4286499, 21.80418968], [88.42855072, 21.80450821], [88.42842865, 21.80482864], [88.42832184, 21.80520058], [88.42817688, 21.80559158], [88.42807007, 21.80603981], [88.42798615, 21.80653954], [88.42800903, 21.80707359], [88.42796326, 21.80755997], [88.42780304, 21.80796051], [88.42766571, 21.80832672], [88.42753601, 21.80867386], [88.42745972, 21.80903244], [88.42733765, 21.80934143], [88.42722321, 21.8096447], [88.42710114, 21.80997276], [88.42691803, 21.8103199], [88.42665863, 21.81070709], [88.42634583, 21.8111248], [88.42595673, 21.81151009], [88.42552185, 21.81184959], [88.42508698, 21.81212997], [88.42459106, 21.81231117], [88.42402649, 21.81240082], [88.42340851, 21.81241035], [88.42312622, 21.8123951], [88.4228363, 21.81238365], [88.42234802, 21.81234741], [88.42189789, 21.81235313], [88.42146301, 21.81235123], [88.42099762, 21.81236076], [88.42051697, 21.81235123], [88.4200058, 21.81225967], [88.41944122, 21.81216049], [88.41886139, 21.8119297], [88.4182663, 21.81161118], [88.41773224, 21.8111496], [88.41720581, 21.81070709], [88.4167099, 21.81028938], [88.41629791, 21.80982018], [88.41588593, 21.80941582], [88.4154892, 21.809021], [88.41508484, 21.80866241], [88.41474152, 21.80824089], [88.41442871, 21.80776024], [88.41409302, 21.80727959], [88.41372681, 21.80681038], [88.41335297, 21.80638695], [88.41300201, 21.80597115], [88.41261292, 21.80559158], [88.41215515, 21.80526924], [88.41168976, 21.80495071], [88.41126251, 21.80458069], [88.41085052, 21.80419922], [88.41040802, 21.80387688], [88.40997314, 21.80357742], [88.40956116, 21.80327988], [88.4091568, 21.80294991], [88.40874481, 21.80262756], [88.40834045, 21.8022995], [88.4079361, 21.80196953], [88.40751648, 21.80166054], [88.40710449, 21.80135155], [88.40670013, 21.8010006], [88.40631866, 21.80063057], [88.40592194, 21.80029106], [88.40554047, 21.79997063], [88.40518951, 21.79964066], [88.40484619, 21.79929924]]], [[[88.5199585, 21.85463715], [88.52054596, 21.85416985], [88.52083588, 21.85416985], [88.52139282, 21.8536129], [88.52166748, 21.8536129], [88.52194214, 21.8533287], [88.52222443, 21.85333252], [88.52249908, 21.85305595], [88.52278137, 21.85306168], [88.52500153, 21.85082817], [88.52500153, 21.85055542], [88.52583313, 21.84971809], [88.52583313, 21.84861183], [88.52610779, 21.84833336], [88.52610779, 21.84777832], [88.52638245, 21.84749985], [88.52638245, 21.84667015], [88.5266571, 21.84638977], [88.5266571, 21.84583092], [88.52639008, 21.84555435], [88.52638245, 21.84500122], [88.52694702, 21.84444046], [88.52694702, 21.84361076], [88.52722168, 21.84361076], [88.52749634, 21.84333038], [88.52722168, 21.84305573], [88.52722168, 21.84278107], [88.52749634, 21.84250069], [88.52749634, 21.84139061], [88.52777863, 21.84111023], [88.52777863, 21.83972168], [88.52694702, 21.83888817], [88.52694702, 21.8386116], [88.52666473, 21.83833313], [88.52666473, 21.83805466], [88.52639008, 21.83777809], [88.52638245, 21.83723068], [88.52610779, 21.83694077], [88.52610779, 21.83666611], [88.52583313, 21.83638954], [88.52583313, 21.83611107], [88.52568817, 21.83596611], [88.52500153, 21.83527565], [88.52443695, 21.83527946], [88.52416992, 21.83500099], [88.52305603, 21.83499718], [88.52304077, 21.83514214], [88.52272034, 21.83527946], [88.52238464, 21.83544731], [88.52199554, 21.83558273], [88.52159119, 21.83575058], [88.52115631, 21.83592033], [88.52072144, 21.83606529], [88.52025604, 21.83613968], [88.5197525, 21.83623123], [88.51912689, 21.83621025], [88.51876068, 21.83645058], [88.51830292, 21.83669281], [88.51777649, 21.83694077], [88.51694489, 21.83777809], [88.51694489, 21.83805466], [88.51667023, 21.83833313], [88.51667023, 21.8386116], [88.51583099, 21.83944511], [88.51583099, 21.84027863], [88.51599121, 21.84043884], [88.51611328, 21.84056282], [88.51638794, 21.84056282], [88.51693726, 21.84111023], [88.51694489, 21.84166718], [88.51750183, 21.84222221], [88.51750946, 21.84333038], [88.51805878, 21.84389114], [88.51972198, 21.84389114], [88.51991272, 21.84369659], [88.51999664, 21.84361076], [88.52222443, 21.84583282], [88.52222443, 21.8461113], [88.52138519, 21.84694672], [88.52166748, 21.84722137], [88.52166748, 21.84832954], [88.52083588, 21.84917068], [88.51889038, 21.84917068], [88.51847839, 21.84875298], [88.51805878, 21.84833336], [88.51750946, 21.8488903], [88.51750183, 21.84944534], [88.51721954, 21.84972191], [88.51750946, 21.85000038], [88.51750946, 21.85139084], [88.51777649, 21.8516674], [88.51777649, 21.85268021], [88.51777649, 21.8533287], [88.51805878, 21.8536129], [88.51805878, 21.85388947], [88.51833344, 21.85416603], [88.51833344, 21.8544445], [88.51860809, 21.85472107], [88.51895905, 21.85471535], [88.5194397, 21.85467148], [88.5199585, 21.85463715]]], [[[88.53800201, 21.85358238], [88.53713989, 21.85324669], [88.53656769, 21.8532505], [88.53649139, 21.8537178], [88.53813934, 21.85458946], [88.53885651, 21.85493279], [88.53929138, 21.85559845], [88.54020691, 21.8560009], [88.54057312, 21.85641098], [88.54129028, 21.85680962], [88.54161835, 21.85737991], [88.54180908, 21.85710526], [88.54190063, 21.85697174], [88.54172516, 21.85654068], [88.54143524, 21.85606956], [88.54079437, 21.85506248], [88.53978729, 21.85432243], [88.53855896, 21.85381317], [88.53800201, 21.85358238]]], [[[88.55944824, 21.82972145], [88.5597229, 21.82944489], [88.55999756, 21.82944489], [88.56027985, 21.82916641], [88.56027985, 21.82860947], [88.5605545, 21.8283329], [88.56027985, 21.82805634], [88.56027985, 21.82749939], [88.55999756, 21.82722282], [88.55999756, 21.82694435], [88.55986786, 21.82681274], [88.55916595, 21.82611084], [88.55860901, 21.82555962], [88.55860901, 21.82529259], [88.55805206, 21.82471848], [88.55802917, 21.82461548], [88.55780792, 21.82432175], [88.55755615, 21.82398224], [88.55722809, 21.82377434], [88.55683899, 21.82393074], [88.55664063, 21.8240242], [88.55648041, 21.82422829], [88.55632782, 21.82456017], [88.55615234, 21.82485962], [88.55600739, 21.82517052], [88.55583954, 21.82546043], [88.5557785, 21.82576942], [88.55610657, 21.82611084], [88.5561142, 21.82638931], [88.55666351, 21.82694435], [88.5569458, 21.82694244], [88.55750275, 21.82749939], [88.5577774, 21.82749939], [88.5578537, 21.82757568], [88.55860901, 21.8283329], [88.55860901, 21.82860947], [88.5588913, 21.82888985], [88.5588913, 21.82916641], [88.55916595, 21.82944489], [88.55916595, 21.82972145], [88.55944824, 21.82972145]]], [[[88.78916931, 21.87861061], [88.78943634, 21.87832832], [88.79027557, 21.87833405], [88.79055786, 21.87805557], [88.79083252, 21.87805939], [88.79139709, 21.87750053], [88.79138947, 21.87722206], [88.79166412, 21.87694359], [88.79166412, 21.87666893], [88.79194641, 21.87639809], [88.79194641, 21.87612915], [88.79218292, 21.8758812], [88.79219818, 21.87536049], [88.79222107, 21.8741684], [88.79250336, 21.87388992], [88.79222107, 21.87360954], [88.79222107, 21.8730545], [88.79194641, 21.87277985], [88.79194641, 21.87249947], [88.79110718, 21.87166977], [88.79083252, 21.87166977], [88.79064941, 21.87148476], [88.79027557, 21.87111092], [88.79000092, 21.87111092], [88.78971863, 21.87083054], [88.78944397, 21.87083244], [88.78888702, 21.8702774], [88.78861237, 21.8702774], [88.78778076, 21.86944389], [88.78749847, 21.86944389], [88.78694153, 21.86888885], [88.78666687, 21.86889076], [88.78610992, 21.86833191], [88.78610992, 21.86694527], [88.7858429, 21.86667252], [88.7858429, 21.86641121], [88.78583527, 21.86527824], [88.78594971, 21.8651638], [88.78722382, 21.86388969], [88.78749847, 21.86388969], [88.78778076, 21.86361122], [88.78833008, 21.86361122], [88.78861237, 21.86333084], [88.78943634, 21.86333084], [88.78971863, 21.86361122], [88.7902832, 21.86361122], [88.79055786, 21.86388969], [88.79083252, 21.86388969], [88.79110718, 21.86416817], [88.79139709, 21.86416817], [88.79360962, 21.86639023], [88.79360962, 21.86666679], [88.79416656, 21.86720848], [88.79416656, 21.86778069], [88.79444122, 21.86805534], [88.79444122, 21.86833191], [88.79499817, 21.86888885], [88.79499817, 21.86944389], [88.79528046, 21.86972046], [88.79528046, 21.87055588], [88.79555511, 21.87083244], [88.79556274, 21.87138939], [88.79582977, 21.87166405], [88.79582977, 21.87194443], [88.79611206, 21.87222099], [88.79611206, 21.87277985], [88.79666901, 21.87333298], [88.79666901, 21.87360954], [88.79693604, 21.87388992], [88.79693604, 21.8741703], [88.79722595, 21.87444687], [88.79722595, 21.87470055], [88.79750061, 21.875], [88.79750061, 21.87527847], [88.79833221, 21.87610817], [88.79833221, 21.87639809], [88.7986145, 21.87666893], [88.7986145, 21.87694359], [88.79888916, 21.87693977], [88.79944611, 21.87750053], [88.80005646, 21.87750053], [88.80055237, 21.87750053], [88.80055237, 21.87778091], [88.80064392, 21.87768745], [88.80082703, 21.87750053], [88.80082703, 21.87721825], [88.80055237, 21.87694359], [88.80055237, 21.87638664], [88.80027008, 21.87610817], [88.80027771, 21.87555695], [88.80000305, 21.87528038], [88.80000305, 21.87471962], [88.79972076, 21.87444687], [88.79972076, 21.87388992], [88.79944611, 21.87360954], [88.79944611, 21.8730545], [88.79915619, 21.87277985], [88.79915619, 21.87249947], [88.79888916, 21.87222099], [88.79888916, 21.87083244], [88.79916382, 21.87055588], [88.79915619, 21.87026978], [88.79972076, 21.86972237], [88.79972076, 21.86944389], [88.80027771, 21.86888885], [88.80055237, 21.86889076], [88.8013916, 21.86806107], [88.80166626, 21.86806107], [88.80194092, 21.86778069], [88.80249786, 21.86778069], [88.80304718, 21.86720848], [88.8033371, 21.86722183], [88.80361176, 21.86694527], [88.80444336, 21.8669529], [88.80473328, 21.86667252], [88.8069458, 21.86667252], [88.80722046, 21.8669529], [88.80833435, 21.86694527], [88.80851746, 21.86713028], [88.80860901, 21.86722183], [88.8088913, 21.86720848], [88.80916595, 21.86750031], [88.80944061, 21.86750031], [88.8097229, 21.86778069], [88.81027985, 21.86778069], [88.81054688, 21.86806107], [88.81083679, 21.86805534], [88.81100464, 21.8682251], [88.81111145, 21.86833382], [88.81138611, 21.86833191], [88.8116684, 21.86861038], [88.81194305, 21.86861038], [88.8125, 21.86917114], [88.81305695, 21.86916733], [88.8133316, 21.86944389], [88.81388855, 21.86944389], [88.81416321, 21.86972237], [88.81445313, 21.86972046], [88.81472015, 21.87000084], [88.81555176, 21.87000084], [88.81583405, 21.8702774], [88.81639099, 21.87026978], [88.81667328, 21.87055969], [88.8180542, 21.87055588], [88.81833649, 21.87083244], [88.81916809, 21.87083054], [88.81944275, 21.87111092], [88.8216629, 21.87111092], [88.82195282, 21.87083054], [88.82221985, 21.87083244], [88.82250214, 21.87055588], [88.82250214, 21.87026978], [88.82277679, 21.87000084], [88.82277679, 21.86944008], [88.82305908, 21.86916733], [88.82305908, 21.86852074], [88.82305908, 21.86833382], [88.82333374, 21.86805534], [88.82332611, 21.86778069], [88.8236084, 21.86750031], [88.8236084, 21.86720848], [88.82416534, 21.86666679], [88.82417297, 21.86639023], [88.82472229, 21.86583138], [88.82472229, 21.86555481], [88.82499695, 21.86527824], [88.82499695, 21.86499977], [88.82527924, 21.86471748], [88.82583618, 21.8647213], [88.82666779, 21.86388969], [88.82750702, 21.86388969], [88.82777405, 21.86361122], [88.82805634, 21.86361122], [88.82833099, 21.86333084], [88.82888794, 21.86333275], [88.82944489, 21.86277962], [88.82943726, 21.86250114], [88.82971954, 21.86222076], [88.82971954, 21.86111069], [88.82943726, 21.86083031], [88.82944489, 21.85972214], [88.82917023, 21.85944366], [88.82917023, 21.85916519], [88.82888794, 21.85889053], [88.82888794, 21.85832977], [88.82833099, 21.85777855], [88.82817841, 21.85750961], [88.82789612, 21.8572197], [88.82805634, 21.85666656], [88.82805634, 21.8555603], [88.82776642, 21.85527039], [88.82777405, 21.85499954], [88.82750702, 21.85472107], [88.82749939, 21.8544445], [88.82694244, 21.85388947], [88.82666779, 21.85388947], [88.82666779, 21.85306168], [88.82639313, 21.85277939], [88.82639313, 21.85220909], [88.82611084, 21.85194397], [88.82611084, 21.8516674], [88.82583618, 21.85139084], [88.82583618, 21.85082817], [88.82555389, 21.85055542], [88.82554626, 21.85000038], [88.82527924, 21.84971809], [88.82527924, 21.84944534], [88.82499695, 21.84917068], [88.82499695, 21.84860992], [88.82472229, 21.84833336], [88.82472229, 21.84749985], [88.82444, 21.84721947], [88.82444763, 21.84638977], [88.82417297, 21.84610939], [88.82416534, 21.84555435], [88.82389069, 21.84527969], [88.82389069, 21.84500122], [88.8236084, 21.84472084], [88.8236084, 21.84444427], [88.82333374, 21.8441658], [88.82332611, 21.84361076], [88.82305908, 21.84333038], [88.82305908, 21.84305573], [88.82277679, 21.84278107], [88.82277679, 21.84194183], [88.82250214, 21.84166718], [88.82250214, 21.84139061], [88.82195282, 21.84083176], [88.82194519, 21.84055519], [88.82112122, 21.83973122], [88.8208313, 21.83972168], [88.81999969, 21.84056282], [88.81999969, 21.84111023], [88.82027435, 21.8413887], [88.82026672, 21.84222031], [88.82055664, 21.84250069], [88.82055664, 21.84278107], [88.8208313, 21.84305573], [88.8208313, 21.84333038], [88.82110596, 21.84361076], [88.82110596, 21.84389114], [88.82138824, 21.8441658], [88.82138062, 21.84444046], [88.82195282, 21.84500122], [88.82194519, 21.84527779], [88.82250214, 21.84583282], [88.82250214, 21.84610939], [88.82277679, 21.84638977], [88.82277679, 21.84666443], [88.82305908, 21.84694672], [88.82305908, 21.84721947], [88.82333374, 21.84749985], [88.82333374, 21.84833336], [88.8236084, 21.84860992], [88.8236084, 21.85028076], [88.82277679, 21.85111046], [88.82250214, 21.85111046], [88.82195282, 21.85166931], [88.82138824, 21.8516674], [88.82111359, 21.85194397], [88.81916809, 21.85194397], [88.8188858, 21.8516674], [88.8188858, 21.85139084], [88.81916809, 21.85111046], [88.81916809, 21.85055923], [88.82110596, 21.85055923], [88.82138062, 21.85028076], [88.8216629, 21.85028076], [88.82221985, 21.84971809], [88.82221985, 21.84944534], [88.82250214, 21.84917068], [88.82250214, 21.84832954], [88.82221985, 21.84805679], [88.82221985, 21.84777832], [88.8216629, 21.84721947], [88.8216629, 21.84694672], [88.82138824, 21.84666443], [88.82138062, 21.84638977], [88.82055664, 21.84556007], [88.82055664, 21.84500122], [88.81999969, 21.84444046], [88.81999969, 21.84388924], [88.81973267, 21.84361076], [88.81972504, 21.84333229], [88.81944275, 21.84305573], [88.81944275, 21.84250069], [88.81916809, 21.84222031], [88.81916809, 21.8413887], [88.81861115, 21.84083176], [88.81861115, 21.84027863], [88.8188858, 21.84000015], [88.8188858, 21.83945274], [88.81916809, 21.83917046], [88.81916809, 21.8386116], [88.81972504, 21.83805466], [88.81972504, 21.83777809], [88.81944275, 21.83749962], [88.81944275, 21.83723068], [88.81973267, 21.83694077], [88.81972504, 21.83527565], [88.81999969, 21.83500099], [88.81999969, 21.83472061], [88.82027435, 21.83444595], [88.82027435, 21.8338871], [88.82055664, 21.83361053], [88.82055664, 21.83333015], [88.8208313, 21.8330574], [88.8208313, 21.83222008], [88.82111359, 21.83194351], [88.82111359, 21.82805634], [88.82138062, 21.82777977], [88.82138062, 21.82582855], [88.82111359, 21.8255558], [88.82110596, 21.82500076], [88.81999969, 21.82389069], [88.81999969, 21.82361031], [88.8188858, 21.82250023], [88.8188858, 21.82222748], [88.81833649, 21.82167053], [88.81833649, 21.82139015], [88.81749725, 21.82055092], [88.81749725, 21.82027626], [88.81694794, 21.81972122], [88.81694794, 21.81944656], [88.81661987, 21.81912041], [88.8161087, 21.81861115], [88.8161087, 21.81805992], [88.81582642, 21.81777954], [88.81582642, 21.81750107], [88.81555176, 21.81722069], [88.81555176, 21.81694221], [88.8152771, 21.81666756], [88.8152771, 21.8163929], [88.81500244, 21.81610107], [88.81500244, 21.81555557], [88.81472015, 21.81528282], [88.81472015, 21.81500053], [88.81416321, 21.81444168], [88.81416321, 21.81388855], [88.81360626, 21.8133316], [88.81361389, 21.81305504], [88.81305695, 21.81250191], [88.81305695, 21.81195259], [88.8125, 21.81138992], [88.8125, 21.81110764], [88.81222534, 21.81083298], [88.81222534, 21.81055641], [88.81194305, 21.81028938], [88.81194305, 21.80999947], [88.8116684, 21.80971909], [88.8116684, 21.80944443], [88.81111145, 21.80888939], [88.81083679, 21.80888939], [88.81083679, 21.80861092], [88.81083679, 21.80833244], [88.80944824, 21.8069458], [88.80944824, 21.80666542], [88.8041687, 21.80138969], [88.8041687, 21.80112076], [88.80027008, 21.79721832], [88.80027771, 21.79694366], [88.79833221, 21.79500008], [88.79805756, 21.79500008], [88.79805756, 21.7947216], [88.79722595, 21.79388618], [88.79722595, 21.79360962], [88.79638672, 21.79277611], [88.79638672, 21.79249954], [88.79582977, 21.79193115], [88.79555511, 21.79194641], [88.79499817, 21.79138947], [88.79471588, 21.79138947], [88.79444122, 21.79166985], [88.79389191, 21.79166412], [88.79360962, 21.79194641], [88.79333496, 21.79194641], [88.79305267, 21.79222488], [88.79277802, 21.79222107], [88.79250336, 21.79249954], [88.79222107, 21.79249954], [88.79167175, 21.79304123], [88.79138947, 21.79305458], [88.79111481, 21.79333305], [88.79083252, 21.79333115], [88.78971863, 21.79444695], [88.78971863, 21.7947197], [88.78916931, 21.79528046], [88.78916931, 21.79555511], [88.78888702, 21.79582977], [88.78888702, 21.79638863], [88.78971863, 21.79722214], [88.7902832, 21.79721832], [88.79055786, 21.79750061], [88.79083252, 21.79721832], [88.79222107, 21.79721832], [88.79250336, 21.79750061], [88.79277802, 21.79750061], [88.79472351, 21.7994442], [88.79471588, 21.79972076], [88.79499817, 21.80000114], [88.79499817, 21.80055618], [88.79528046, 21.80083275], [88.79528046, 21.80138969], [88.79556274, 21.80167007], [88.79555511, 21.80555344], [88.79528046, 21.80583572], [88.79528046, 21.80944443], [88.79499817, 21.80971909], [88.79499817, 21.81055641], [88.79471588, 21.81082916], [88.79471588, 21.81138992], [88.79444122, 21.8116703], [88.79444122, 21.81250191], [88.79360962, 21.81333351], [88.79332733, 21.8133316], [88.79277802, 21.81389046], [88.79250336, 21.81389046], [88.79222107, 21.81416702], [88.79222107, 21.81444359], [88.79194641, 21.81472015], [88.79194641, 21.81500053], [88.79055786, 21.8163929], [88.79055786, 21.81666756], [88.79027557, 21.81694221], [88.7902832, 21.81722069], [88.79000092, 21.81750107], [88.79000092, 21.81777763], [88.78944397, 21.81833267], [88.78944397, 21.82083321], [88.78971863, 21.82110977], [88.78971863, 21.82139015], [88.78943634, 21.82139015], [88.78888702, 21.82195091], [88.78861237, 21.82194519], [88.78806305, 21.82250023], [88.78806305, 21.82305908], [88.78555298, 21.82555962], [88.78527832, 21.8255558], [88.78500366, 21.82583427], [88.78444672, 21.82582855], [88.7841568, 21.82611084], [88.78305817, 21.82611084], [88.78277588, 21.82638931], [88.78250122, 21.82638931], [88.7822113, 21.82666969], [88.78166962, 21.82666969], [88.78138733, 21.82638931], [88.78056335, 21.82638931], [88.78028107, 21.82666969], [88.77666473, 21.82666588], [88.77639008, 21.82694435], [88.77361298, 21.82694435], [88.77346802, 21.82680321], [88.77333069, 21.82666588], [88.76944733, 21.82666588], [88.76916504, 21.82694435], [88.76833344, 21.82694435], [88.76805878, 21.82722282], [88.76750183, 21.82722282], [88.76722717, 21.82749939], [88.76693726, 21.82749939], [88.76638794, 21.82806015], [88.76611328, 21.82805634], [88.76611328, 21.82860947], [88.76583099, 21.82888985], [88.76583099, 21.83055305], [88.76611328, 21.83082962], [88.76611328, 21.83166695], [88.76638794, 21.8319397], [88.76638794, 21.83250046], [88.76667023, 21.83277512], [88.76667023, 21.83333015], [88.76693726, 21.83361053], [88.76693726, 21.83500099], [88.76721954, 21.83527565], [88.76722717, 21.83611107], [88.76750183, 21.83638954], [88.76750183, 21.83833313], [88.76777649, 21.8386116], [88.76777649, 21.84026909], [88.76805878, 21.84055519], [88.76805878, 21.84083176], [88.76833344, 21.84111023], [88.76833344, 21.84194374], [88.76860809, 21.84222031], [88.76860809, 21.84278107], [88.76889038, 21.84305573], [88.76889038, 21.84333229], [88.76917267, 21.84361076], [88.76917267, 21.84389114], [88.76944733, 21.8441658], [88.76944733, 21.84444427], [88.76972198, 21.84472084], [88.76972198, 21.84500122], [88.76999664, 21.84527969], [88.76999664, 21.84555435], [88.77054596, 21.84610939], [88.77055359, 21.84666443], [88.77083588, 21.84694672], [88.77083588, 21.85194397], [88.77111053, 21.85220909], [88.77111053, 21.85277939], [88.77138519, 21.85305595], [88.77139282, 21.8533287], [88.77166748, 21.8536129], [88.77194214, 21.8536129], [88.7722168, 21.85388947], [88.77249908, 21.85388947], [88.77278137, 21.85416985], [88.77333069, 21.85416603], [88.77361298, 21.8544445], [88.77444458, 21.8544445], [88.77462769, 21.85462952], [88.77471924, 21.85472107], [88.77527618, 21.85472107], [88.77610779, 21.85527802], [88.77638245, 21.85541916], [88.7766571, 21.8555603], [88.77694702, 21.85555649], [88.77713013, 21.8557415], [88.77722168, 21.85583115], [88.77805328, 21.85583115], [88.77833557, 21.85611153], [88.77861023, 21.85610962], [88.77874756, 21.85625076], [88.77889252, 21.85639], [88.77944183, 21.85639], [88.77971649, 21.85667038], [88.77999878, 21.85666656], [88.78166962, 21.85833359], [88.78166962, 21.85861015], [88.78194427, 21.85888863], [88.78194427, 21.85944366], [88.7822113, 21.85972023], [88.7822113, 21.86028099], [88.78193665, 21.86055946], [88.78193665, 21.86111069], [88.78166962, 21.8614006], [88.78166962, 21.86166763], [88.78111267, 21.86222267], [88.78083038, 21.86222076], [88.78028107, 21.86277962], [88.77999878, 21.86277962], [88.77944183, 21.86333275], [88.77916718, 21.86333275], [88.77900696, 21.86349487], [88.77889252, 21.86361122], [88.77861023, 21.86361122], [88.77694702, 21.86527824], [88.77694702, 21.86583328], [88.7766571, 21.86611176], [88.77694702, 21.86639023], [88.77694702, 21.8669529], [88.77749634, 21.86750031], [88.77749634, 21.86777687], [88.77805328, 21.86833382], [88.77861023, 21.86833191], [88.77889252, 21.86861038], [88.77916718, 21.86861038], [88.77971649, 21.86917114], [88.77999878, 21.86917114], [88.78138733, 21.87055588], [88.78138733, 21.87083054], [88.78221893, 21.87166405], [88.78221893, 21.87194443], [88.78388977, 21.87360954], [88.78388977, 21.87388992], [88.78555298, 21.87555695], [88.78555298, 21.8758297], [88.78569031, 21.87597275], [88.78610992, 21.87639809], [88.78639221, 21.87638664], [88.78768921, 21.87768745], [88.78775787, 21.87775612], [88.78806305, 21.87805939], [88.78833008, 21.87805557], [88.78861237, 21.87833405], [88.78888702, 21.87832832], [88.78916931, 21.87861061]]], [[[88.59749603, 21.86222076], [88.59777832, 21.86250114], [88.59777832, 21.86277962], [88.59805298, 21.86305618], [88.59805298, 21.86333084], [88.59860229, 21.86388969], [88.59860992, 21.86416626], [88.59889221, 21.86444092], [88.59889221, 21.86499977], [88.59916687, 21.86528015], [88.59916687, 21.86750031], [88.59944153, 21.86777687], [88.59944153, 21.86833191], [88.59971619, 21.86861038], [88.59972382, 21.86888885], [88.60147858, 21.87064552], [88.60166168, 21.87083054], [88.60166168, 21.87111092], [88.60194397, 21.87138939], [88.60194397, 21.87181091], [88.60194397, 21.87194443], [88.60221863, 21.87222099], [88.60221863, 21.87277985], [88.60250092, 21.87306023], [88.60250092, 21.87388992], [88.60305786, 21.87445068], [88.60305786, 21.875], [88.60333252, 21.87527847], [88.60333252, 21.87583351], [88.60360718, 21.87610817], [88.60360718, 21.87639809], [88.60388947, 21.87666893], [88.60388947, 21.87693977], [88.60444641, 21.87750053], [88.60444641, 21.87778091], [88.60472107, 21.87805557], [88.6047287, 21.87832832], [88.60500336, 21.87861061], [88.60500336, 21.87888908], [88.60527802, 21.87916756], [88.60527802, 21.8794384], [88.60582733, 21.88000107], [88.60583496, 21.88027763], [88.60639191, 21.88083267], [88.60639191, 21.88111115], [88.60749817, 21.88221169], [88.60749817, 21.88249969], [88.60805511, 21.88305473], [88.60805511, 21.88333321], [88.60832977, 21.88360977], [88.60832977, 21.88389015], [88.60861206, 21.88417053], [88.60861206, 21.88445091], [88.60916901, 21.88500023], [88.60916901, 21.88557053], [88.60972595, 21.88611031], [88.60972595, 21.88639069], [88.61000061, 21.88667107], [88.6100769, 21.88660812], [88.61042786, 21.88698959], [88.61073303, 21.88741112], [88.61106873, 21.88781166], [88.61138153, 21.88820839], [88.61165619, 21.8885994], [88.61194611, 21.88895988], [88.61222076, 21.88931656], [88.61250305, 21.8896904], [88.61277771, 21.89009285], [88.61306763, 21.89048958], [88.61335754, 21.89088631], [88.61361694, 21.8913002], [88.61388397, 21.89172745], [88.61412811, 21.89217186], [88.61444092, 21.89250183], [88.61444092, 21.8927784], [88.61528015, 21.89361191], [88.61554718, 21.89361191], [88.61611176, 21.89417267], [88.61638641, 21.89416695], [88.61723328, 21.89500046], [88.61723328, 21.89528275], [88.61805725, 21.89611053], [88.61833191, 21.89611053], [88.6194458, 21.89722252], [88.61972809, 21.89722061], [88.61985016, 21.89735031], [88.62000275, 21.89751053], [88.6202774, 21.89751053], [88.62055206, 21.89777946], [88.62166595, 21.89777946], [88.62194824, 21.89751053], [88.6222229, 21.89751053], [88.62249756, 21.89722061], [88.62277985, 21.89722252], [88.6230545, 21.89694214], [88.62333679, 21.89694214], [88.62361145, 21.89666748], [88.62361908, 21.89679718], [88.62402344, 21.89663315], [88.62442017, 21.89639091], [88.62486267, 21.89611053], [88.62532043, 21.89582825], [88.6256485, 21.89559174], [88.6257782, 21.89550018], [88.62615967, 21.89512062], [88.62645721, 21.89470863], [88.62666321, 21.89417267], [88.62695313, 21.89389038], [88.62695313, 21.89166832], [88.62722015, 21.89138031], [88.62722015, 21.89049911], [88.62722015, 21.88944435], [88.62750244, 21.88916779], [88.62722015, 21.88889122], [88.62722015, 21.88667107], [88.62750244, 21.88639069], [88.62750244, 21.88528061], [88.6277771, 21.88500023], [88.6277771, 21.88445091], [88.62805176, 21.88417053], [88.62805176, 21.88360977], [88.62833405, 21.88333321], [88.62833405, 21.88305473], [88.6286087, 21.88277817], [88.6286087, 21.88249969], [88.6297226, 21.88138962], [88.62999725, 21.88138962], [88.63041687, 21.88097191], [88.63056946, 21.88086128], [88.63089752, 21.88064003], [88.63140869, 21.88032913], [88.63195801, 21.88002014], [88.63253784, 21.87973022], [88.63314056, 21.8794384], [88.63376617, 21.87911034], [88.63432312, 21.87866974], [88.63461304, 21.8780098], [88.63470459, 21.87730026], [88.63464355, 21.876688], [88.63437653, 21.87629128], [88.63407898, 21.87599182], [88.63378906, 21.87572289], [88.63352203, 21.87544441], [88.63329315, 21.87509537], [88.63301849, 21.8747406], [88.63272095, 21.87436676], [88.63246918, 21.8739109], [88.6322403, 21.87347412], [88.63205719, 21.8730278], [88.63191986, 21.87257957], [88.63179016, 21.87213135], [88.63173676, 21.87165451], [88.63222504, 21.87111092], [88.63222504, 21.87083244], [88.6333313, 21.86972237], [88.63361359, 21.86972237], [88.63388824, 21.86944389], [88.6341629, 21.86944389], [88.63444519, 21.86916733], [88.63527679, 21.86916733], [88.63542175, 21.86930656], [88.63555908, 21.86944389], [88.6361084, 21.86944389], [88.63639069, 21.86972237], [88.63667297, 21.86972046], [88.63694763, 21.87000084], [88.63722229, 21.87000084], [88.63749695, 21.87026978], [88.63786316, 21.87063789], [88.63827515, 21.87103271], [88.63879395, 21.87136459], [88.63899994, 21.87145996], [88.63936615, 21.87162971], [88.64003754, 21.87178993], [88.64070892, 21.87187004], [88.64128876, 21.8719101], [88.6418457, 21.87182617], [88.64241028, 21.87174034], [88.64295959, 21.87166977], [88.64349365, 21.87160492], [88.64398956, 21.87146759], [88.64414978, 21.87145233], [88.64450073, 21.87141991], [88.64501953, 21.87138939], [88.64554596, 21.87134361], [88.64604187, 21.87116623], [88.6465683, 21.87109184], [88.64705658, 21.87098694], [88.64753723, 21.87083054], [88.64797974, 21.87066078], [88.6484375, 21.87051964], [88.64888, 21.87030029], [88.64944458, 21.8702774], [88.64971924, 21.87000084], [88.65110779, 21.87000084], [88.65139008, 21.86972046], [88.65139008, 21.86902428], [88.65166473, 21.86887932], [88.65284729, 21.86865807], [88.65328217, 21.86825943], [88.65344238, 21.86802101], [88.65351868, 21.86770821], [88.65344238, 21.86705971], [88.65329742, 21.86646271], [88.65307617, 21.86592293], [88.65284729, 21.86536026], [88.65261841, 21.86479759], [88.65245819, 21.86420059], [88.65229034, 21.86376953], [88.65224457, 21.86366081], [88.65222168, 21.86305809], [88.65194702, 21.86305809], [88.65139008, 21.86250114], [88.65055847, 21.86250114], [88.65055847, 21.86194038], [88.65139008, 21.86111069], [88.65083313, 21.86055946], [88.65083313, 21.86028099], [88.65055847, 21.86000061], [88.65055847, 21.85889053], [88.65027618, 21.85861015], [88.65027618, 21.85750008], [88.65000153, 21.8572197], [88.65000153, 21.85694313], [88.64971161, 21.85667038], [88.64971161, 21.8555603], [88.65000153, 21.85527039], [88.65000153, 21.85499954], [88.64943695, 21.8544426], [88.64944458, 21.85416603], [88.64888763, 21.8536129], [88.64888763, 21.8533287], [88.64916992, 21.85305595], [88.64916992, 21.85277939], [88.64936066, 21.85264969], [88.64940643, 21.85210991], [88.64936066, 21.85158157], [88.64944458, 21.85111046], [88.64943695, 21.85055923], [88.64971161, 21.85028076], [88.64971161, 21.85000038], [88.65000153, 21.84971809], [88.65000153, 21.84861183], [88.65027618, 21.84833336], [88.65027618, 21.84722137], [88.64971924, 21.84666443], [88.64971161, 21.84556007], [88.65027618, 21.84500122], [88.64971161, 21.84444046], [88.64971924, 21.84388924], [88.64943695, 21.84361076], [88.64943695, 21.84333038], [88.64933014, 21.84322166], [88.64916992, 21.84305573], [88.64916992, 21.84222031], [88.64924622, 21.8421402], [88.64944458, 21.84194374], [88.64944458, 21.84111023], [88.64916992, 21.84081841], [88.64916992, 21.83944511], [88.64943695, 21.83917046], [88.64943695, 21.83889008], [88.64916992, 21.8386116], [88.64916992, 21.83805466], [88.64888763, 21.83777809], [88.64888763, 21.83723068], [88.64875793, 21.83709526], [88.64861298, 21.83694458], [88.64833069, 21.83666611], [88.64805603, 21.83666992], [88.64749908, 21.83611107], [88.64805603, 21.83555984], [88.64833069, 21.83527946], [88.64855957, 21.83527946], [88.64916992, 21.83527946], [88.64943695, 21.83500099], [88.64943695, 21.83472061], [88.64916992, 21.83444595], [88.64916992, 21.83416748], [88.64932251, 21.83393288], [88.64938354, 21.83335686], [88.64920807, 21.83279037], [88.64916992, 21.83222198], [88.64888763, 21.83194351], [88.64888763, 21.83138847], [88.64861298, 21.83110046], [88.64861298, 21.83083344], [88.64833069, 21.83055305], [88.64833069, 21.82971954], [88.64805603, 21.82944489], [88.64805603, 21.82722282], [88.64722443, 21.82638931], [88.6472168, 21.82611084], [88.64679718, 21.82556534], [88.64662933, 21.82497215], [88.64644623, 21.82438469], [88.64633942, 21.82380104], [88.64614868, 21.82326126], [88.64595795, 21.82273293], [88.6457901, 21.8221817], [88.64566803, 21.82165527], [88.64572906, 21.82114983], [88.64582062, 21.82067108], [88.64588928, 21.82019997], [88.64599609, 21.81973076], [88.64589691, 21.81925964], [88.64570618, 21.81879044], [88.64546967, 21.81836128], [88.64521027, 21.8179493], [88.64496613, 21.81748962], [88.64472961, 21.8170414], [88.64452362, 21.81654358], [88.64452362, 21.81592751], [88.64470673, 21.81522942], [88.64485168, 21.81452751], [88.64480591, 21.81384087], [88.64447784, 21.81328011], [88.64408112, 21.81281853], [88.64360809, 21.81250191], [88.64305878, 21.81195259], [88.64305878, 21.80888939], [88.64332581, 21.80861092], [88.64332581, 21.80778122], [88.64277649, 21.80722046], [88.64247131, 21.80723953], [88.64239502, 21.80707932], [88.64231873, 21.80692482], [88.64225006, 21.80638695], [88.64235687, 21.80570984], [88.6424942, 21.80495834], [88.64272308, 21.80424118], [88.64289093, 21.80358124], [88.64305878, 21.80310059], [88.64315033, 21.80267906], [88.64317322, 21.80230904], [88.64303589, 21.80195045], [88.64285278, 21.80159187], [88.6428299, 21.80115128], [88.64291382, 21.80069733], [88.643013, 21.80021286], [88.64299011, 21.79968262], [88.64284515, 21.79912567], [88.64279175, 21.79852867], [88.64277649, 21.79791832], [88.64279175, 21.7972908], [88.64286041, 21.79663086], [88.64299011, 21.79597092], [88.64299011, 21.79529953], [88.64285278, 21.79463959], [88.64279175, 21.79393959], [88.64277649, 21.79325485], [88.64278412, 21.79260063], [88.64277649, 21.79201126], [88.64280701, 21.79146957], [88.64291382, 21.79100609], [88.643013, 21.79055977], [88.64305878, 21.79009819], [88.64305878, 21.79000092], [88.64305878, 21.78889084], [88.64277649, 21.78861046], [88.64250183, 21.78861046], [88.64193726, 21.78806114], [88.64167023, 21.78806114], [88.64135742, 21.78774452], [88.64083862, 21.78722191], [88.64083099, 21.78611183], [88.6397171, 21.78499985], [88.63916779, 21.78499985], [88.63889313, 21.78471756], [88.63861084, 21.78472137], [88.63821411, 21.7851162], [88.63805389, 21.78527832], [88.63784027, 21.78534317], [88.63710785, 21.78556442], [88.63639069, 21.78583336], [88.63471222, 21.78583145], [88.6341629, 21.7863903], [88.63388824, 21.7863903], [88.63276672, 21.78750038], [88.63249969, 21.78750038], [88.63223267, 21.78778267], [88.63166809, 21.78778267], [88.6313858, 21.78806114], [88.62916565, 21.78805542], [88.62889099, 21.78833389], [88.6286087, 21.78833389], [88.62833405, 21.78805542], [88.62805176, 21.78806114], [88.62750244, 21.78861046], [88.62722015, 21.78861046], [88.62702179, 21.78862953], [88.62680054, 21.78919983], [88.62640381, 21.78976059], [88.62582397, 21.79009247], [88.62562561, 21.79020309], [88.62534332, 21.79036522], [88.625, 21.7906208], [88.62471771, 21.7908783], [88.62440491, 21.79113388], [88.62414551, 21.79130554], [88.62401581, 21.79139328], [88.62358856, 21.79168129], [88.62317657, 21.79201126], [88.62285614, 21.79240799], [88.62254333, 21.79280281], [88.62223816, 21.79322052], [88.62194824, 21.79369736], [88.62166595, 21.79420471], [88.62140656, 21.79469109], [88.62121582, 21.79516983], [88.62104797, 21.79560089], [88.62082672, 21.79598045], [88.62063599, 21.79633141], [88.62047577, 21.79669952], [88.62020874, 21.79705048], [88.62001801, 21.79745293], [88.61988068, 21.79788017], [88.61965179, 21.79826736], [88.6193161, 21.79862976], [88.6190033, 21.7990799], [88.61873627, 21.79964638], [88.61862946, 21.80032921], [88.61860657, 21.80104637], [88.61860657, 21.80161095], [88.61860657, 21.80173111], [88.61860657, 21.80239105], [88.61860657, 21.80302811], [88.61860657, 21.80365944], [88.61862946, 21.80425072], [88.61868286, 21.80476952], [88.6186142, 21.80527687], [88.61860657, 21.80583], [88.61833191, 21.80611038], [88.61833191, 21.80639076], [88.61805725, 21.80666542], [88.61805725, 21.8069458], [88.61776733, 21.80722046], [88.61776733, 21.80750084], [88.61750031, 21.8077755], [88.61750031, 21.80833244], [88.61722565, 21.80861092], [88.61722565, 21.80944443], [88.61694336, 21.80971909], [88.61694336, 21.81027985], [88.61638641, 21.81083298], [88.61638641, 21.81110764], [88.61472321, 21.81278038], [88.61472321, 21.81305504], [88.6140213, 21.81376076], [88.6138916, 21.81389046], [88.6138916, 21.81416702], [88.61332703, 21.81472015], [88.61333466, 21.81500053], [88.61250305, 21.81583214], [88.61250305, 21.81610107], [88.61194611, 21.81666946], [88.61194611, 21.81750107], [88.61250305, 21.81805992], [88.61277771, 21.8180542], [88.61305237, 21.81833267], [88.61332703, 21.81833076], [88.61360168, 21.81861115], [88.6138916, 21.81861115], [88.61416626, 21.81888962], [88.61444092, 21.81888962], [88.61528015, 21.81972313], [88.61555481, 21.81972313], [88.6166687, 21.82083321], [88.61694336, 21.82083321], [88.61865997, 21.82254982], [88.6202774, 21.82416725], [88.6202774, 21.82444382], [88.62055206, 21.82471848], [88.62055206, 21.82500076], [88.62083435, 21.82527733], [88.62082672, 21.82582855], [88.62110901, 21.82611084], [88.62110901, 21.82638931], [88.6213913, 21.82666588], [88.6213913, 21.8283329], [88.62166595, 21.82860947], [88.62166595, 21.82916641], [88.62194824, 21.82944489], [88.62194824, 21.82971954], [88.62166595, 21.82999992], [88.62166595, 21.8302803], [88.6213913, 21.83055305], [88.6213913, 21.83083344], [88.62110901, 21.83110046], [88.62110901, 21.83139038], [88.61888885, 21.83361053], [88.61860657, 21.83361053], [88.61833191, 21.83389091], [88.61805725, 21.83389091], [88.61776733, 21.83416939], [88.61750031, 21.83416748], [88.61722565, 21.83444595], [88.61694336, 21.83444595], [88.6166687, 21.83472252], [88.61638641, 21.83472061], [88.61611176, 21.83500099], [88.61554718, 21.83500099], [88.61528015, 21.83527946], [88.61472321, 21.83527946], [88.61444092, 21.83555984], [88.61360931, 21.83555794], [88.61333466, 21.8358326], [88.61138916, 21.83583069], [88.6111145, 21.83611107], [88.61071777, 21.83611107], [88.6102829, 21.83611107], [88.61000061, 21.83638954], [88.60972595, 21.83638954], [88.60861206, 21.83749962], [88.60861206, 21.83777809], [88.60832977, 21.83805084], [88.60832977, 21.83917046], [88.60805511, 21.83944511], [88.60805511, 21.83994293], [88.60805511, 21.84055519], [88.60778046, 21.84083366], [88.60778809, 21.84111023], [88.60805511, 21.8413887], [88.60805511, 21.84194374], [88.60778046, 21.84222221], [88.60778046, 21.84267426], [88.60774231, 21.84276009], [88.60758209, 21.84312439], [88.60748291, 21.84354973], [88.6073761, 21.84392929], [88.60727692, 21.84426117], [88.60721588, 21.84472084], [88.60694122, 21.84500122], [88.60694122, 21.84527969], [88.60666656, 21.84555435], [88.60666656, 21.84583282], [88.60639191, 21.84610939], [88.60639191, 21.84638977], [88.60472107, 21.84805679], [88.60444641, 21.84805679], [88.60416412, 21.84833336], [88.60388947, 21.84833336], [88.60361481, 21.84861183], [88.60333252, 21.84860992], [88.60305786, 21.8488903], [88.60250092, 21.8488903], [88.60221863, 21.84917068], [88.60166168, 21.84917068], [88.60138702, 21.8494606], [88.60055542, 21.84944534], [88.60028076, 21.84972191], [88.59971619, 21.84971809], [88.59944153, 21.85000038], [88.59860229, 21.85000038], [88.5983429, 21.85028076], [88.59777832, 21.85028076], [88.59749603, 21.85055923], [88.59722137, 21.85055542], [88.59694672, 21.85083389], [88.5966568, 21.85082817], [88.59610748, 21.85139084], [88.59610748, 21.8516674], [88.59583282, 21.85194397], [88.59583282, 21.85220909], [88.59555817, 21.85250092], [88.59555817, 21.85277939], [88.59527588, 21.85305595], [88.59527588, 21.8533287], [88.59500122, 21.8536129], [88.59500122, 21.85416603], [88.59471893, 21.8544445], [88.59471893, 21.85610962], [88.59500122, 21.85639], [88.59500122, 21.85694313], [88.59527588, 21.8572197], [88.59527588, 21.85750008], [88.59583282, 21.85805321], [88.59583282, 21.85833359], [88.59610748, 21.85861015], [88.59610748, 21.85916519], [88.59638977, 21.85943985], [88.59638977, 21.86000061], [88.59694672, 21.86055756], [88.59694672, 21.86083031], [88.59722137, 21.86111069], [88.59722137, 21.86166763], [88.59750366, 21.8619442], [88.59749603, 21.86222076]]], [[[88.70861053, 21.81055641], [88.70833588, 21.81083298], [88.70804596, 21.81082916], [88.70749664, 21.81138992], [88.70749664, 21.8116703], [88.70722198, 21.81195259], [88.70722198, 21.81277847], [88.70667267, 21.8133316], [88.70666504, 21.81416702], [88.70610809, 21.81472015], [88.70610809, 21.81500053], [88.70555878, 21.81555557], [88.70555878, 21.81610107], [88.70500183, 21.81666756], [88.70500183, 21.81694221], [88.70471954, 21.81722069], [88.70471954, 21.81750107], [88.70443726, 21.81777954], [88.70444489, 21.8180542], [88.70417023, 21.81833267], [88.70417786, 21.81861115], [88.70388794, 21.81888962], [88.70388794, 21.81916428], [88.70361328, 21.81944084], [88.70362091, 21.82195091], [88.70388794, 21.82222748], [88.70388794, 21.82250023], [88.70417786, 21.82278061], [88.70417023, 21.82305527], [88.70443726, 21.82332993], [88.70443726, 21.82638931], [88.70471954, 21.82666588], [88.70471954, 21.82722282], [88.70500183, 21.82749939], [88.70500183, 21.82777977], [88.70527649, 21.82806015], [88.70555878, 21.82805634], [88.70583344, 21.8283329], [88.70639038, 21.8283329], [88.70666504, 21.82805634], [88.70722198, 21.82806015], [88.70777893, 21.82749939], [88.70804596, 21.82749939], [88.70833588, 21.82722282], [88.70861053, 21.82722282], [88.70888519, 21.82694435], [88.70916748, 21.82694435], [88.70944214, 21.82666588], [88.7097168, 21.82666969], [88.71028137, 21.82611084], [88.71083069, 21.82611084], [88.71111298, 21.82582855], [88.71138763, 21.82583427], [88.71166992, 21.8255558], [88.71221924, 21.82555962], [88.71250153, 21.82529259], [88.71333313, 21.82529259], [88.71360779, 21.82555962], [88.71472168, 21.8255558], [88.71485901, 21.82569504], [88.71499634, 21.82583427], [88.71527863, 21.82582855], [88.71555328, 21.82611084], [88.71666718, 21.82611084], [88.71778107, 21.82722282], [88.71778107, 21.82749939], [88.71917725, 21.82888985], [88.71916962, 21.82916641], [88.71943665, 21.82944107], [88.71943665, 21.8302803], [88.71916962, 21.83055305], [88.71916962, 21.83222198], [88.72027588, 21.83333588], [88.72055817, 21.83333588], [88.72092438, 21.83370399], [88.72110748, 21.83389091], [88.72138977, 21.83389091], [88.7216568, 21.83416939], [88.72250366, 21.83416748], [88.72277832, 21.83444595], [88.72333527, 21.83444595], [88.72360992, 21.83472252], [88.72389221, 21.83472061], [88.72416687, 21.83500099], [88.72444153, 21.83500099], [88.72499084, 21.83555984], [88.72583008, 21.83555794], [88.72611237, 21.8358326], [88.72666931, 21.83583069], [88.72693634, 21.83611107], [88.72750092, 21.83611107], [88.72777557, 21.83638954], [88.72805786, 21.83638954], [88.72833252, 21.83666611], [88.72833252, 21.83694077], [88.72805786, 21.83723068], [88.72805786, 21.83749962], [88.72777557, 21.83749962], [88.72750092, 21.83722305], [88.72666931, 21.83723068], [88.72647858, 21.83703613], [88.72638702, 21.83694458], [88.72528076, 21.83694458], [88.72499847, 21.83666611], [88.72471619, 21.83666992], [88.72444153, 21.83638954], [88.72416687, 21.83638954], [88.72389221, 21.83611107], [88.72360992, 21.83611107], [88.7233429, 21.83583069], [88.72305298, 21.8358326], [88.72277832, 21.83555794], [88.72249603, 21.83555984], [88.72222137, 21.83527946], [88.72194672, 21.83527946], [88.7216568, 21.83500099], [88.72083282, 21.83500099], [88.72055817, 21.83472061], [88.72027588, 21.83472252], [88.72000122, 21.83444595], [88.71971893, 21.83444595], [88.71916199, 21.8338871], [88.71833038, 21.8330574], [88.71806335, 21.83306122], [88.71806335, 21.83250046], [88.71778107, 21.83222198], [88.71778107, 21.8302784], [88.71749878, 21.82999992], [88.71749878, 21.82888985], [88.71611786, 21.82749939], [88.71583557, 21.82749939], [88.71527863, 21.82694435], [88.71333313, 21.82694435], [88.71305847, 21.82666588], [88.71250153, 21.82666588], [88.71221924, 21.82694435], [88.71166992, 21.82694435], [88.71138763, 21.82722282], [88.71111298, 21.82722282], [88.71055603, 21.82777977], [88.71028137, 21.82777977], [88.70999146, 21.82806015], [88.70972443, 21.82805634], [88.70944214, 21.8283329], [88.70916748, 21.8283329], [88.70888519, 21.82861137], [88.70861053, 21.82860947], [88.70833588, 21.82888985], [88.70804596, 21.82888985], [88.70777893, 21.82917023], [88.70749664, 21.82916641], [88.70694733, 21.82972145], [88.70500183, 21.82972145], [88.70471954, 21.82944489], [88.70444489, 21.82944489], [88.70388794, 21.82888794], [88.70361328, 21.82888985], [88.70361328, 21.82806015], [88.70333099, 21.82777977], [88.70333099, 21.82749939], [88.70305634, 21.82722282], [88.70305634, 21.82500076], [88.70276642, 21.82471848], [88.70277405, 21.82444382], [88.70249939, 21.82416916], [88.70166779, 21.82500076], [88.70152283, 21.82500076], [88.7013855, 21.82500076], [88.7013855, 21.82522964], [88.7013855, 21.82694435], [88.70111084, 21.82722282], [88.70139313, 21.82749939], [88.7013855, 21.82805634], [88.70111084, 21.8283329], [88.70111084, 21.82971954], [88.70083618, 21.82999992], [88.70083618, 21.83055305], [88.70055389, 21.83083344], [88.70054626, 21.8319397], [88.69999695, 21.83250046], [88.69999695, 21.83277512], [88.69944763, 21.83333015], [88.69944763, 21.83361053], [88.6986084, 21.83444023], [88.6986084, 21.83527565], [88.69805145, 21.83583069], [88.69805145, 21.83611107], [88.69750214, 21.83666992], [88.69750214, 21.83722305], [88.6966629, 21.83805466], [88.6966629, 21.83851051], [88.6966629, 21.83889008], [88.69638824, 21.83916664], [88.69638824, 21.84026909], [88.69611359, 21.84055519], [88.69610596, 21.84083176], [88.6958313, 21.84111023], [88.69611359, 21.8413887], [88.69610596, 21.84222031], [88.69638824, 21.84250069], [88.69638824, 21.84278107], [88.6966629, 21.84278107], [88.69777679, 21.84389114], [88.69805145, 21.84389114], [88.69917297, 21.84500122], [88.69917297, 21.84527969], [88.69944763, 21.84555435], [88.69944763, 21.84610939], [88.69972229, 21.84638977], [88.69972229, 21.84666443], [88.69999695, 21.84694672], [88.69999695, 21.84721947], [88.70027924, 21.84749985], [88.70027924, 21.84805679], [88.70055389, 21.84833336], [88.70055389, 21.84861946], [88.70054626, 21.84917068], [88.70083618, 21.84944534], [88.70083618, 21.85082817], [88.70111084, 21.85111046], [88.70111084, 21.8516674], [88.7013855, 21.85194397], [88.70139313, 21.85250092], [88.70166779, 21.85277939], [88.70166779, 21.8536129], [88.70194244, 21.85388947], [88.70194244, 21.85472107], [88.70333099, 21.85611153], [88.70417786, 21.85610962], [88.70443726, 21.85639], [88.70471954, 21.85639], [88.70500183, 21.85610962], [88.70610809, 21.85611153], [88.70639038, 21.85583115], [88.70694733, 21.85583115], [88.70749664, 21.85527802], [88.70777893, 21.85527802], [88.70805359, 21.85499954], [88.70833588, 21.85499954], [88.70861053, 21.85472107], [88.70888519, 21.85472107], [88.70916748, 21.8544445], [88.70944214, 21.8544445], [88.70972443, 21.85416603], [88.70999146, 21.85416985], [88.71028137, 21.85388947], [88.71055603, 21.85388947], [88.71083069, 21.8536129], [88.71111298, 21.8536129], [88.71138763, 21.8533287], [88.71166229, 21.85337639], [88.71193695, 21.8536129], [88.71360779, 21.8536129], [88.71389008, 21.85388947], [88.71444702, 21.85388947], [88.71472168, 21.85416985], [88.71527863, 21.85416603], [88.71555328, 21.8544445], [88.71583557, 21.8544445], [88.71611023, 21.85472107], [88.71639252, 21.85472107], [88.71694183, 21.85527802], [88.71721649, 21.85527039], [88.71749878, 21.85555649], [88.71749878, 21.85583115], [88.71721649, 21.85610962], [88.71721649, 21.85639], [88.71666718, 21.85639], [88.71652985, 21.85625076], [88.71639252, 21.85610962], [88.71611023, 21.85611153], [88.71583557, 21.85583115], [88.71555328, 21.85583115], [88.71527863, 21.85555649], [88.71499634, 21.8555603], [88.71490479, 21.85546494], [88.71472168, 21.85527802], [88.71444702, 21.85527802], [88.71416473, 21.85499954], [88.71360779, 21.85499954], [88.71333313, 21.85472107], [88.71221924, 21.85472107], [88.71193695, 21.85499954], [88.71083069, 21.85499954], [88.71055603, 21.85527802], [88.71028137, 21.85527039], [88.70999146, 21.8555603], [88.70972443, 21.85555649], [88.70916748, 21.85611153], [88.70861053, 21.85610962], [88.70804596, 21.85667038], [88.70777893, 21.85666656], [88.70722198, 21.8572216], [88.70694733, 21.8572216], [88.70667267, 21.85750008], [88.70500183, 21.85750008], [88.70471954, 21.85778046], [88.70417786, 21.85778046], [88.70388794, 21.85750008], [88.70305634, 21.85750008], [88.70276642, 21.8572197], [88.70249939, 21.8572216], [88.7013855, 21.85611153], [88.7013855, 21.85583115], [88.70083618, 21.85527802], [88.70083618, 21.85499954], [88.70027924, 21.8544426], [88.70027924, 21.85416603], [88.69999695, 21.85388947], [88.69999695, 21.8533287], [88.69972229, 21.85305595], [88.69972229, 21.85250092], [88.69944763, 21.85220909], [88.69944763, 21.85194397], [88.69916534, 21.8516674], [88.69917297, 21.85082817], [88.69889069, 21.85055542], [88.69889069, 21.8494606], [88.6986084, 21.84917068], [88.6986084, 21.8488903], [88.69844818, 21.84872818], [88.69805908, 21.84833336], [88.69721985, 21.84833336], [88.69694519, 21.84861183], [88.6971283, 21.84879684], [88.69721985, 21.8488903], [88.69695282, 21.84917068], [88.69695282, 21.85028076], [88.69721985, 21.85055923], [88.69721985, 21.85111046], [88.69750214, 21.85139084], [88.69750214, 21.85194397], [88.69777679, 21.85220909], [88.69777679, 21.85250092], [88.69805145, 21.85277939], [88.69805145, 21.8536129], [88.69833374, 21.85388947], [88.69832611, 21.8544426], [88.69889069, 21.85499954], [88.69889069, 21.85527039], [88.69917297, 21.8555603], [88.69917297, 21.85639], [88.6986084, 21.85694313], [88.6986084, 21.85861015], [88.69833374, 21.85888863], [88.69833374, 21.85925102], [88.69832611, 21.86000061], [88.6986084, 21.86028099], [88.6986084, 21.86055756], [88.69889069, 21.86083031], [88.69889069, 21.86111069], [88.69972229, 21.86194038], [88.69972229, 21.86250114], [88.70083618, 21.86361122], [88.70083618, 21.86388969], [88.70111084, 21.86416817], [88.70111084, 21.86499977], [88.7013855, 21.86499977], [88.70249939, 21.86611176], [88.70249939, 21.86639023], [88.70276642, 21.86667252], [88.70276642, 21.86750031], [88.70305634, 21.86777687], [88.70305634, 21.86833191], [88.70361328, 21.86889076], [88.70361328, 21.86916733], [88.70388794, 21.86944389], [88.70388794, 21.86972237], [88.70417023, 21.87000084], [88.70417786, 21.87111092], [88.70443726, 21.87138939], [88.70444489, 21.87166405], [88.70500183, 21.87222099], [88.70500183, 21.87249947], [88.70527649, 21.87277985], [88.70549774, 21.87277985], [88.70582581, 21.87277985], [88.70610809, 21.87306023], [88.70610809, 21.87333298], [88.70580292, 21.87364388], [88.70555878, 21.87388992], [88.70555878, 21.8741703], [88.70639038, 21.875], [88.70639038, 21.87528038], [88.70666504, 21.87555695], [88.70666504, 21.87583351], [88.70694733, 21.87610817], [88.70694733, 21.87639809], [88.70722198, 21.87666893], [88.70722198, 21.87694359], [88.70694733, 21.87721825], [88.70777893, 21.87805557], [88.70777893, 21.87832832], [88.70805359, 21.87861061], [88.70805359, 21.87944412], [88.70833588, 21.87972069], [88.70833588, 21.87999916], [88.70916748, 21.88083267], [88.70916748, 21.88111115], [88.71028137, 21.88221169], [88.71028137, 21.88249969], [88.71055603, 21.88277817], [88.71055603, 21.88305473], [88.71083069, 21.88333321], [88.71083069, 21.88360977], [88.71111298, 21.88388824], [88.71111298, 21.88471985], [88.71138763, 21.88500023], [88.71138763, 21.88528061], [88.71166992, 21.88528061], [88.71166992, 21.88555336], [88.71186066, 21.88574982], [88.71194458, 21.88583565], [88.71194458, 21.88610077], [88.71194458, 21.88638878], [88.71203613, 21.88648033], [88.71250153, 21.88694382], [88.71250153, 21.88846016], [88.71250153, 21.88861084], [88.71221924, 21.88889122], [88.71221924, 21.88916779], [88.71250153, 21.88944435], [88.71250153, 21.88972282], [88.7127533, 21.8899765], [88.71305084, 21.89027977], [88.71305847, 21.89166641], [88.71333313, 21.89194489], [88.71333313, 21.89222145], [88.71360779, 21.89250183], [88.71360779, 21.8927784], [88.7141571, 21.89333153], [88.7141571, 21.89389038], [88.71444702, 21.89417267], [88.71444702, 21.89500046], [88.71472168, 21.89528275], [88.71472168, 21.89639091], [88.7158432, 21.89751053], [88.71583557, 21.89777756], [88.71527863, 21.89833069], [88.71527863, 21.89861107], [88.71555328, 21.89888954], [88.71555328, 21.89923096], [88.71555328, 21.89972305], [88.7158432, 21.89999962], [88.7158432, 21.90139008], [88.71611786, 21.90167046], [88.71611786, 21.90306091], [88.71666718, 21.90360832], [88.71666718, 21.90611076], [88.71639252, 21.90638924], [88.71694183, 21.90638924], [88.71778107, 21.90722275], [88.71805573, 21.90722275], [88.71833038, 21.90694427], [88.71861267, 21.90694427], [88.71944427, 21.90611076], [88.71943665, 21.90582848], [88.72083282, 21.90444374], [88.72110748, 21.90444374], [88.72194672, 21.90360832], [88.72194672, 21.90332031], [88.72222137, 21.90305519], [88.72222137, 21.90278053], [88.72305298, 21.90195084], [88.72305298, 21.90167046], [88.72360992, 21.90167046], [88.72528076, 21.89999962], [88.72556305, 21.89999962], [88.72583008, 21.89972305], [88.72611237, 21.89972305], [88.72666931, 21.8991642], [88.72750092, 21.89916992], [88.7277832, 21.89888954], [88.72861481, 21.89888954], [88.72888947, 21.89861107], [88.73027802, 21.89861107], [88.73055267, 21.89833069], [88.73139191, 21.8983326], [88.73166656, 21.89805412], [88.73194122, 21.89805412], [88.73222351, 21.8983326], [88.73628998, 21.89833069], [88.73665619, 21.89833069], [88.73694611, 21.89861107], [88.7388916, 21.89861107], [88.73916626, 21.89888954], [88.74223328, 21.89888954], [88.74250031, 21.89861107], [88.74305725, 21.89861107], [88.74333191, 21.89833069], [88.74388885, 21.8983326], [88.74416351, 21.89805412], [88.74472046, 21.89805984], [88.74500275, 21.89777946], [88.7452774, 21.89777946], [88.74555206, 21.89751053], [88.74582672, 21.89751053], [88.74610138, 21.89722061], [88.7463913, 21.89722252], [88.74666595, 21.89694214], [88.74694824, 21.89694214], [88.7472229, 21.89666748], [88.74749756, 21.89666939], [88.74804687, 21.89611053], [88.74833679, 21.89611053], [88.74861145, 21.89583015], [88.74861145, 21.8955555], [88.74916077, 21.89500046], [88.74916077, 21.89472008], [88.74944305, 21.89444351], [88.74944305, 21.89423943], [88.74944305, 21.89305496], [88.74916077, 21.8927803], [88.74916077, 21.89193916], [88.74888611, 21.89166641], [88.74888611, 21.89110756], [88.74833679, 21.89055634], [88.74833679, 21.89027977], [88.74861145, 21.88999748], [88.74861145, 21.88944054], [88.74888611, 21.88916779], [88.74888611, 21.88889122], [88.74973297, 21.88805962], [88.75, 21.88805962], [88.75110626, 21.88694], [88.75138855, 21.88694382], [88.75166321, 21.88666534], [88.75222778, 21.88667107], [88.75250244, 21.88639069], [88.75332642, 21.88639069], [88.7536087, 21.88611031], [88.75461578, 21.88611031], [88.75527954, 21.88611031], [88.7555542, 21.88583565], [88.75583649, 21.88583565], [88.75666809, 21.88500023], [88.75666809, 21.88385963], [88.75666809, 21.88361168], [88.7563858, 21.88333321], [88.7563858, 21.88277817], [88.75611115, 21.88249969], [88.75611115, 21.88221169], [88.75583649, 21.88194466], [88.75583649, 21.88111115], [88.75611115, 21.88083267], [88.75611115, 21.88027763], [88.75749969, 21.87888908], [88.75776672, 21.87888908], [88.75805664, 21.87861061], [88.75888824, 21.87861061], [88.7591629, 21.87832832], [88.76000214, 21.87833405], [88.76027679, 21.87805557], [88.76110077, 21.87805939], [88.76139069, 21.87778091], [88.76249695, 21.87778091], [88.76277924, 21.87750053], [88.76333618, 21.87750053], [88.76361084, 21.87721825], [88.76444244, 21.87722206], [88.76472473, 21.87694359], [88.76557159, 21.87694359], [88.76667023, 21.87694359], [88.76694489, 21.87722206], [88.76750183, 21.87721825], [88.76777649, 21.87750053], [88.76805878, 21.87750053], [88.76832581, 21.87721825], [88.76889038, 21.87722206], [88.76916504, 21.87750053], [88.76944733, 21.87722206], [88.76999664, 21.87722206], [88.77008057, 21.87714005], [88.77055359, 21.87666893], [88.77083588, 21.87667084], [88.77111053, 21.87639809], [88.77139282, 21.87639809], [88.77166748, 21.87610817], [88.77166748, 21.87583351], [88.77222443, 21.87527847], [88.7722168, 21.87471962], [88.77249908, 21.87444687], [88.77249908, 21.8741703], [88.77278137, 21.87388992], [88.77278137, 21.87360954], [88.77305603, 21.87333298], [88.77305603, 21.87277985], [88.77333069, 21.87249947], [88.77333069, 21.87222099], [88.77361298, 21.87194443], [88.77361298, 21.87166405], [88.77388763, 21.87138939], [88.77388763, 21.87111092], [88.77443695, 21.87055969], [88.77443695, 21.87026978], [88.77471924, 21.87000084], [88.77471924, 21.86972046], [88.77527618, 21.86916733], [88.77527618, 21.86889076], [88.77500153, 21.86861038], [88.77500153, 21.86833191], [88.77471924, 21.86805534], [88.77471924, 21.86611176], [88.77482605, 21.86600685], [88.77500153, 21.86583328], [88.77500153, 21.86499977], [88.77722168, 21.86277962], [88.77749634, 21.86277962], [88.7783432, 21.86194038], [88.77861023, 21.8619442], [88.77972412, 21.86083412], [88.77972412, 21.86055756], [88.77999878, 21.86028099], [88.77999878, 21.86000061], [88.78056335, 21.85943985], [88.77999878, 21.85888863], [88.77971649, 21.85889053], [88.77944183, 21.85861015], [88.77916718, 21.85861206], [88.77889252, 21.85833359], [88.77833557, 21.85833359], [88.77805328, 21.85805321], [88.77777863, 21.85806084], [88.77749634, 21.85778046], [88.77722168, 21.85778046], [88.77694702, 21.85750008], [88.77639008, 21.85750008], [88.77610779, 21.8572197], [88.77444458, 21.8572216], [88.77416992, 21.85694313], [88.77361298, 21.85695076], [88.77333069, 21.85667038], [88.77305603, 21.85667038], [88.77278137, 21.85639], [88.77249908, 21.85639], [88.7722168, 21.85610962], [88.77166748, 21.85611153], [88.77166748, 21.85583115], [88.76916504, 21.85333252], [88.76916504, 21.85305595], [88.76860809, 21.85250092], [88.76860809, 21.85220909], [88.76889038, 21.85194397], [88.76860809, 21.8516674], [88.76860809, 21.85055923], [88.76832581, 21.85028076], [88.76832581, 21.84694099], [88.76805878, 21.84666443], [88.76805878, 21.84638977], [88.76777649, 21.84610939], [88.76777649, 21.84555435], [88.76750183, 21.84527969], [88.76750183, 21.84500122], [88.76722717, 21.84472084], [88.76721954, 21.84444427], [88.76694489, 21.8441658], [88.76693726, 21.84389114], [88.76667023, 21.84361076], [88.76667023, 21.84333038], [88.76638794, 21.84305573], [88.76638794, 21.84278107], [88.76583099, 21.84222031], [88.76583099, 21.84194374], [88.76555634, 21.84166718], [88.76583099, 21.84139061], [88.76583099, 21.84056282], [88.76555634, 21.84026909], [88.76555634, 21.83944511], [88.76526642, 21.83917046], [88.76526642, 21.83889008], [88.76499939, 21.8386116], [88.76499939, 21.83805466], [88.76472473, 21.83777809], [88.7647171, 21.83666992], [88.76444244, 21.83638954], [88.76444244, 21.83527946], [88.76416779, 21.83500099], [88.76416779, 21.83389091], [88.76389313, 21.83361053], [88.7638855, 21.82861137], [88.76416779, 21.82861137], [88.76444244, 21.8283329], [88.76444244, 21.82805634], [88.7647171, 21.82777977], [88.7647171, 21.82722282], [88.76499939, 21.82694435], [88.76499939, 21.82666588], [88.76555634, 21.82611084], [88.76583099, 21.82611084], [88.76611328, 21.82582855], [88.76638794, 21.82583427], [88.76667023, 21.8255558], [88.76693726, 21.82555962], [88.76722717, 21.82529259], [88.76750183, 21.82529259], [88.76805878, 21.82471848], [88.76860809, 21.82472229], [88.76889038, 21.82444382], [88.76944733, 21.82444382], [88.76972198, 21.82416725], [88.77083588, 21.82416916], [88.77111053, 21.82389069], [88.77388763, 21.82389069], [88.77416992, 21.82416916], [88.77471924, 21.82416916], [88.77500153, 21.82389069], [88.77583313, 21.82389069], [88.77610779, 21.82361031], [88.77639008, 21.82361031], [88.77722168, 21.82278061], [88.77722168, 21.82167053], [88.77555847, 21.81999969], [88.77555847, 21.81972122], [88.77527618, 21.81944656], [88.77527618, 21.81916428], [88.77500153, 21.81888962], [88.77500153, 21.81861115], [88.77471924, 21.81833076], [88.77471924, 21.81777763], [88.77443695, 21.81750107], [88.77443695, 21.81694031], [88.77416992, 21.81666756], [88.77416992, 21.8163929], [88.77388763, 21.81610107], [88.77388763, 21.81500053], [88.77416992, 21.81472015], [88.77416992, 21.81444359], [88.77444458, 21.81416702], [88.77443695, 21.81361008], [88.77471924, 21.81333351], [88.77471924, 21.81250191], [88.77500153, 21.81222153], [88.77500153, 21.81194496], [88.77527618, 21.8116703], [88.77527618, 21.81138992], [88.77500153, 21.81110764], [88.77500153, 21.80999947], [88.77471924, 21.80971909], [88.77471924, 21.80944443], [88.77416992, 21.80888939], [88.77416992, 21.80861092], [88.77333069, 21.80778122], [88.77333069, 21.80750084], [88.77305603, 21.80722046], [88.77305603, 21.8069458], [88.77111053, 21.80500031], [88.77083588, 21.80500031], [88.7702713, 21.80445099], [88.7702713, 21.80416107], [88.76860809, 21.80249977], [88.76860809, 21.80221939], [88.76805878, 21.80166626], [88.76805878, 21.80138969], [88.76777649, 21.80112076], [88.76777649, 21.80083275], [88.76750183, 21.80055618], [88.76750183, 21.80027962], [88.76722717, 21.80000114], [88.76722717, 21.79943848], [88.76694489, 21.79916573], [88.76693726, 21.7983284], [88.76667023, 21.79805565], [88.76667023, 21.79693985], [88.76638794, 21.7966671], [88.76638794, 21.79582977], [88.76611328, 21.79555511], [88.76611328, 21.79528046], [88.76638794, 21.79499054], [88.76638794, 21.79444695], [88.76611328, 21.79417038], [88.76611328, 21.79360962], [88.76583099, 21.79333305], [88.76583099, 21.79277611], [88.76555634, 21.79249954], [88.76555634, 21.79193115], [88.76527405, 21.79166412], [88.76526642, 21.79138947], [88.76499939, 21.79111099], [88.76499939, 21.79091072], [88.76499939, 21.79055405], [88.7647171, 21.79027939], [88.7647171, 21.78972054], [88.76416779, 21.7891674], [88.76444244, 21.78918076], [88.76444244, 21.78889084], [88.76416779, 21.78861046], [88.76416779, 21.78833008], [88.7638855, 21.78805542], [88.76389313, 21.78750038], [88.76277924, 21.7863884], [88.76277924, 21.78611946], [88.76167297, 21.78499985], [88.76166534, 21.78472137], [88.7583313, 21.78138924], [88.75805664, 21.78139114], [88.75776672, 21.78111076], [88.75694275, 21.78111076], [88.75666046, 21.78133583], [88.7563858, 21.78139114], [88.75611115, 21.78166771], [88.75611115, 21.78194427], [88.75583649, 21.78222084], [88.75583649, 21.78250122], [88.7555542, 21.78277969], [88.7555542, 21.78305626], [88.75527954, 21.78333282], [88.75528717, 21.78360748], [88.75499725, 21.78388977], [88.75499725, 21.78416634], [88.7547226, 21.78444481], [88.7547226, 21.78471756], [88.75444794, 21.78499985], [88.75444794, 21.78527832], [88.75416565, 21.78555489], [88.75417328, 21.78583145], [88.75389099, 21.78611946], [88.75389099, 21.7863903], [88.7536087, 21.78667259], [88.7536087, 21.78694534], [88.75332642, 21.78722191], [88.75332642, 21.78778267], [88.75305176, 21.78806114], [88.75305176, 21.78888893], [88.75250244, 21.78944016], [88.75250244, 21.79249954], [88.75222015, 21.79277611], [88.75222778, 21.79499054], [88.7519455, 21.79527855], [88.7519455, 21.79694366], [88.75166321, 21.79722214], [88.75166321, 21.7983284], [88.75138855, 21.79861069], [88.75138855, 21.7994442], [88.75110626, 21.79972076], [88.75110626, 21.80027962], [88.7508316, 21.8005619], [88.7508316, 21.80528069], [88.75110626, 21.80556107], [88.75111389, 21.80666542], [88.75138855, 21.80693054], [88.75138855, 21.80805779], [88.75166321, 21.80833054], [88.75166321, 21.80888939], [88.7519455, 21.80916786], [88.7519455, 21.80944443], [88.75222778, 21.80971909], [88.75222015, 21.81055641], [88.75250244, 21.81082916], [88.75250244, 21.8116703], [88.7527771, 21.81194496], [88.7527771, 21.81222153], [88.75250244, 21.81250191], [88.75250244, 21.81444168], [88.75166321, 21.81528282], [88.75111389, 21.8152771], [88.75027466, 21.81611061], [88.75, 21.81610107], [88.74973297, 21.8163929], [88.74888611, 21.81555939], [88.74888611, 21.81528282], [88.74833679, 21.81472015], [88.7480545, 21.81472206], [88.74694824, 21.81361008], [88.74666595, 21.81361008], [88.74666595, 21.81333351], [88.74333191, 21.80999947], [88.74305725, 21.80999947], [88.74194336, 21.80888939], [88.74194336, 21.80833054], [88.73999786, 21.80638885], [88.73999786, 21.80611038], [88.73944092, 21.80556107], [88.73944092, 21.80528069], [88.73832703, 21.80416107], [88.73833466, 21.80388832], [88.73805237, 21.80360985], [88.73805237, 21.80333328], [88.73777771, 21.80305481], [88.73777771, 21.8022213], [88.73750305, 21.80194473], [88.73750305, 21.80083275], [88.73722076, 21.80055618], [88.73722076, 21.80000114], [88.73694611, 21.79972076], [88.73694611, 21.79916573], [88.73583221, 21.79805946], [88.7352829, 21.79805946], [88.73500061, 21.79777908], [88.73139191, 21.79777908], [88.73130035, 21.79768753], [88.73111725, 21.79750061], [88.73082733, 21.79750061], [88.73054504, 21.79727173], [88.73000336, 21.79722214], [88.72972107, 21.79694366], [88.72944641, 21.79694366], [88.72916412, 21.7966671], [88.72888947, 21.79667091], [88.72851563, 21.79629517], [88.72833252, 21.79610825], [88.72805786, 21.79611206], [88.72694397, 21.79500008], [88.72666931, 21.79500008], [88.72638702, 21.7947216], [88.72611237, 21.7947216], [88.72583008, 21.79444695], [88.72528076, 21.79444695], [88.72499847, 21.7947216], [88.72444153, 21.7947216], [88.72416687, 21.79500008], [88.72389221, 21.79499054], [88.72333527, 21.79555511], [88.7233429, 21.79610825], [88.72305298, 21.79638863], [88.72305298, 21.79721832], [88.72277832, 21.79750061], [88.72277832, 21.80027962], [88.72249603, 21.8005619], [88.72249603, 21.80112076], [88.72222137, 21.80138969], [88.72222137, 21.80194473], [88.72194672, 21.80221939], [88.72194672, 21.80249977], [88.72166443, 21.80277824], [88.72166443, 21.80333328], [88.72138977, 21.80360985], [88.72138977, 21.80388832], [88.72110748, 21.80416107], [88.72110748, 21.80444336], [88.72083282, 21.80471992], [88.72083282, 21.80500031], [88.72000122, 21.80583], [88.72000122, 21.80611038], [88.71944427, 21.80666542], [88.71943665, 21.80693054], [88.71833038, 21.80805969], [88.71778107, 21.80805969], [88.71721649, 21.80861092], [88.71694183, 21.80861092], [88.71611023, 21.80944443], [88.71499634, 21.80944443], [88.71472168, 21.80971909], [88.71414948, 21.8100338], [88.71405029, 21.81008911], [88.71246338, 21.81054115], [88.71092224, 21.81038475], [88.71044159, 21.81033707], [88.7097168, 21.81028938], [88.70944214, 21.81028938], [88.70916748, 21.81055832], [88.70861053, 21.81055641]]], [[[88.83655548, 21.91789246], [88.84912872, 21.91178513], [88.85686493, 21.91070747], [88.86631775, 21.91366768], [88.86831665, 21.91501045], [88.87256622, 21.91679001], [88.87548065, 21.91749954], [88.87812042, 21.91737938], [88.88070679, 21.91655922], [88.88323212, 21.91542053], [88.88607788, 21.91501236], [88.88659668, 21.91445732], [88.8881073, 21.91451073], [88.89006805, 21.91465569], [88.89124298, 21.91527939], [88.8949585, 21.91689491], [88.90236664, 21.91888046], [88.90497589, 21.91957855], [88.90956879, 21.92308044], [88.91191864, 21.92618752], [88.91221619, 21.92657852], [88.91456604, 21.92811966], [88.91517639, 21.92818069], [88.91500092, 21.92795944], [88.91514587, 21.92789459], [88.91678619, 21.92717361], [88.9171524, 21.9270134], [88.91986847, 21.92606926], [88.92056274, 21.92583084], [88.92166901, 21.92472267], [88.92194366, 21.92472267], [88.92222595, 21.92444229], [88.92250061, 21.92444992], [88.9227829, 21.92416954], [88.92333221, 21.92416954], [88.92359924, 21.92389107], [88.92415619, 21.92389107], [88.92722321, 21.92083168], [88.92749786, 21.92083359], [88.92861176, 21.9197216], [88.92888641, 21.9197216], [88.93023682, 21.9183712], [88.93166351, 21.9169445], [88.93222046, 21.9169445], [88.93250275, 21.91666794], [88.93276978, 21.91666985], [88.93332672, 21.91611099], [88.93360901, 21.91611099], [88.9338913, 21.91583061], [88.93416595, 21.91583252], [88.93416595, 21.91555786], [88.93444824, 21.91527557], [88.9347229, 21.91527939], [88.93499756, 21.91500092], [88.93582916, 21.91500092], [88.93638611, 21.91444016], [88.9366684, 21.91444588], [88.93694305, 21.9141655], [88.93723297, 21.91417122], [88.9375, 21.91389084], [88.93805695, 21.91389084], [88.9383316, 21.91361046], [88.93860626, 21.91361046], [88.93889618, 21.91333008], [88.93916321, 21.9133358], [88.93972015, 21.91277695], [88.94000244, 21.91278076], [88.9402771, 21.91250992], [88.94055176, 21.91250992], [88.94082642, 21.91222], [88.9411087, 21.91222191], [88.94139099, 21.91194344], [88.94167328, 21.91195107], [88.9422226, 21.9113903], [88.94249725, 21.9113903], [88.94277954, 21.91110992], [88.94333649, 21.91111183], [88.94361115, 21.91083336], [88.9438858, 21.91083336], [88.94416809, 21.91055489], [88.94444275, 21.91055489], [88.94499969, 21.90999985], [88.9458313, 21.90999985], [88.94610596, 21.90971947], [88.94694519, 21.90972137], [88.94750214, 21.90916634], [88.94776917, 21.90917015], [88.94805908, 21.90888977], [88.94832611, 21.90888977], [88.9486084, 21.90860939], [88.94889069, 21.9086113], [88.94944763, 21.90805626], [88.95083618, 21.90806007], [88.95139313, 21.90750122], [88.9522171, 21.90750122], [88.95249939, 21.90722275], [88.95277405, 21.90722275], [88.95305634, 21.90694427], [88.95361328, 21.90694427], [88.95388794, 21.9066658], [88.95417023, 21.90666962], [88.95443726, 21.9063797], [88.95471954, 21.90638924], [88.95500183, 21.90611076], [88.95555878, 21.90611076], [88.95610809, 21.90555954], [88.95639038, 21.90555954], [88.95667267, 21.90527916], [88.95722198, 21.90527916], [88.95749664, 21.90500069], [88.95777893, 21.90500069], [88.95804596, 21.9047184], [88.95861053, 21.90472221], [88.95888519, 21.90444374], [88.95916748, 21.90444374], [88.95972443, 21.90389061], [88.96138763, 21.90389061], [88.96166992, 21.90360832], [88.96221924, 21.90360832], [88.96277618, 21.90306091], [88.96333313, 21.90306091], [88.96360779, 21.90278053], [88.96389008, 21.90278053], [88.9641571, 21.90250015], [88.96444702, 21.90250015], [88.96470642, 21.90223122], [88.96499634, 21.90221977], [88.96527863, 21.90194511], [88.96555328, 21.90195084], [88.9658432, 21.90167046], [88.96611023, 21.90167046], [88.96639252, 21.90139008], [88.96694183, 21.90139008], [88.96721649, 21.9011097], [88.96778107, 21.9011116], [88.96805573, 21.90083313], [88.96833038, 21.90083313], [88.96861267, 21.90055466], [88.96888733, 21.90055466], [88.96916962, 21.90027618], [88.96943665, 21.90028], [88.96971893, 21.89999962], [88.97000122, 21.89999962], [88.97027588, 21.89972115], [88.97055817, 21.89972305], [88.97083282, 21.89944649], [88.97110748, 21.89944649], [88.97138977, 21.8991642], [88.97164917, 21.89916992], [88.97222137, 21.89861107], [88.97249603, 21.89861107], [88.97277832, 21.89833069], [88.97305298, 21.8983326], [88.97360992, 21.89777756], [88.97389221, 21.89777946], [88.97471619, 21.89694023], [88.97360992, 21.89583206], [88.97277832, 21.89583206], [88.97250366, 21.8955555], [88.97164917, 21.89556122], [88.97138977, 21.89528275], [88.97000122, 21.89528275], [88.96971893, 21.89500046], [88.96916962, 21.89500046], [88.9688797, 21.89472008], [88.96861267, 21.89472008], [88.96833038, 21.89444351], [88.96805573, 21.89444351], [88.96749878, 21.89388847], [88.96721649, 21.89389038], [88.96666718, 21.89333153], [88.96666718, 21.89305496], [88.96639252, 21.8927803], [88.96639252, 21.89193916], [88.96611023, 21.89166641], [88.96611023, 21.89027977], [88.96639252, 21.88999748], [88.96639252, 21.88972092], [88.96666718, 21.88944435], [88.96666718, 21.88805771], [88.96694183, 21.88778114], [88.96694183, 21.88694], [88.96722412, 21.88666534], [88.96721649, 21.88611031], [88.96749878, 21.88582993], [88.96749878, 21.88555336], [88.96778107, 21.88528061], [88.96778107, 21.88500023], [88.96806335, 21.88471985], [88.96805573, 21.88444328], [88.96861267, 21.88389015], [88.96861267, 21.88360977], [88.96944427, 21.88277817], [88.96943665, 21.88249969], [88.96971893, 21.88221169], [88.96971893, 21.88194466], [88.97000122, 21.88166618], [88.97000122, 21.88111115], [88.97027588, 21.88083267], [88.97027588, 21.88055611], [88.97055817, 21.88027954], [88.97055817, 21.88000107], [88.97083282, 21.87972069], [88.97083282, 21.87944412], [88.97110748, 21.87916756], [88.97110748, 21.87888908], [88.97138977, 21.87861061], [88.97138977, 21.87832832], [88.97222137, 21.87750053], [88.97222137, 21.87721825], [88.97250366, 21.87694359], [88.97250366, 21.87638664], [88.97263336, 21.87610817], [88.97277832, 21.87583351], [88.97305298, 21.87555695], [88.97305298, 21.87528038], [88.9733429, 21.875], [88.97333527, 21.87472153], [88.97360992, 21.87444687], [88.97360992, 21.8741703], [88.97416687, 21.87360954], [88.97416687, 21.8730545], [88.97444153, 21.87277985], [88.97444153, 21.87249947], [88.97471619, 21.87222099], [88.97472382, 21.87194443], [88.97499847, 21.87166405], [88.97499847, 21.87138939], [88.97528076, 21.87111092], [88.97528076, 21.87083054], [88.97583008, 21.8702774], [88.97583008, 21.87000084], [88.97611237, 21.86972046], [88.97611237, 21.86944389], [88.97666931, 21.86888885], [88.97666931, 21.86750031], [88.97611237, 21.8669529], [88.97583008, 21.8669529], [88.97566986, 21.86678314], [88.97555542, 21.86666679], [88.97389221, 21.86667252], [88.97360992, 21.86639023], [88.97305298, 21.86639023], [88.97277832, 21.86611176], [88.97166443, 21.86611176], [88.97166443, 21.86583328], [88.97138977, 21.86555481], [88.97110748, 21.86583328], [88.97027588, 21.86583328], [88.97000122, 21.86555481], [88.96916962, 21.86555481], [88.96908569, 21.86547279], [88.96888733, 21.86527824], [88.96833038, 21.86528015], [88.96806335, 21.86499977], [88.96795654, 21.86499977], [88.96778107, 21.86499977], [88.96749878, 21.86471748], [88.96722412, 21.8647213], [88.96639252, 21.86388969], [88.96611023, 21.86388969], [88.9658432, 21.86361122], [88.96555328, 21.86361122], [88.96527863, 21.86333084], [88.96499634, 21.86333275], [88.96472168, 21.86305618], [88.96444702, 21.86305809], [88.96342468, 21.86203766], [88.96221924, 21.86083412], [88.96221924, 21.86055756], [88.96193695, 21.86028099], [88.96166992, 21.86028099], [88.96129608, 21.85990715], [88.96111298, 21.85972214], [88.96111298, 21.85944366], [88.96055603, 21.85888863], [88.96055603, 21.85861015], [88.95999908, 21.85805321], [88.95999908, 21.85778046], [88.95970917, 21.85750008], [88.95970917, 21.85695076], [88.95916748, 21.85639], [88.95916748, 21.85610962], [88.95694733, 21.85388947], [88.95666504, 21.85388947], [88.95639038, 21.8536129], [88.95610809, 21.8536129], [88.95582581, 21.85388947], [88.95555878, 21.85388947], [88.95500183, 21.8544426], [88.95498657, 21.85473061], [88.95471954, 21.85499954], [88.95471954, 21.85555649], [88.95444489, 21.85583115], [88.95444489, 21.85611153], [88.95333099, 21.8572197], [88.95333099, 21.85805321], [88.95305634, 21.85832977], [88.95305634, 21.85889053], [88.95276642, 21.85917091], [88.95276642, 21.86000061], [88.95249939, 21.86028099], [88.95249939, 21.86055756], [88.9522171, 21.86083031], [88.9522171, 21.8614006], [88.95194244, 21.86166954], [88.95194244, 21.86250114], [88.9522171, 21.86277962], [88.9522171, 21.86361122], [88.95249939, 21.86388969], [88.9522171, 21.86416817], [88.95194244, 21.86416626], [88.95222473, 21.86444473], [88.95249939, 21.86444092], [88.95305634, 21.86499977], [88.95333099, 21.86499977], [88.95388794, 21.86555481], [88.95417023, 21.86555481], [88.95444489, 21.86583328], [88.95471954, 21.86583328], [88.95500183, 21.86611176], [88.95527649, 21.86611176], [88.95555878, 21.86639023], [88.95582581, 21.86639023], [88.95610809, 21.86667252], [88.95639038, 21.86666679], [88.95657349, 21.86685181], [88.95667267, 21.8669529], [88.9569397, 21.8669529], [88.95749664, 21.86750031], [88.95777893, 21.86750031], [88.95804596, 21.86778069], [88.95833588, 21.86778069], [88.95861053, 21.86806107], [88.95861053, 21.86861038], [88.95888519, 21.86888885], [88.95888519, 21.86972237], [88.95833588, 21.87026978], [88.95833588, 21.87055969], [88.95249939, 21.87639809], [88.95249939, 21.87666893], [88.95194244, 21.87721825], [88.95194244, 21.87750053], [88.95166779, 21.8777771], [88.95166779, 21.87833405], [88.9513855, 21.87861061], [88.95139313, 21.88083267], [88.95111084, 21.88111115], [88.95111084, 21.88138962], [88.9513855, 21.88166618], [88.95139313, 21.88249969], [88.95111084, 21.88277817], [88.95111084, 21.88333321], [88.95083618, 21.88360977], [88.95083618, 21.88417053], [88.95055389, 21.88444328], [88.95054626, 21.88471985], [88.95027924, 21.88500023], [88.95027924, 21.8852787], [88.94972229, 21.88582993], [88.94972229, 21.88639069], [88.94944763, 21.88667107], [88.94889069, 21.88666534], [88.94889069, 21.88694382], [88.9486084, 21.88694382], [88.94833374, 21.88722229], [88.94777679, 21.88722229], [88.94721985, 21.88666534], [88.94695282, 21.88667107], [88.9466629, 21.88639069], [88.94638824, 21.88639069], [88.94610596, 21.88611031], [88.9458313, 21.88611031], [88.94555664, 21.88582993], [88.94527435, 21.88583565], [88.94472504, 21.8852787], [88.94444275, 21.88528061], [88.94416809, 21.88500023], [88.9438858, 21.88500023], [88.94361115, 21.88471985], [88.94333649, 21.88472176], [88.94194794, 21.88333321], [88.9422226, 21.88305473], [88.94249725, 21.88305473], [88.94277954, 21.88277817], [88.9430542, 21.88305473], [88.94333649, 21.88305473], [88.9438858, 21.88361168], [88.94416809, 21.88360977], [88.94473267, 21.88417053], [88.94499969, 21.88417053], [88.94526672, 21.88445091], [88.94555664, 21.88444328], [88.9458313, 21.88472176], [88.94610596, 21.88471985], [88.94638824, 21.88500023], [88.94721985, 21.88500023], [88.94750214, 21.88528061], [88.94776917, 21.88528061], [88.94805908, 21.88500023], [88.9486084, 21.88500023], [88.94944763, 21.88417053], [88.94944763, 21.88194275], [88.94972229, 21.88166618], [88.94972229, 21.88027954], [88.94999695, 21.88000107], [88.94999695, 21.87916946], [88.95027924, 21.87888908], [88.95027924, 21.87778091], [88.95054626, 21.87750053], [88.95054626, 21.87693977], [88.95083618, 21.87666893], [88.95083618, 21.87639809], [88.95111084, 21.87610817], [88.95111084, 21.87583351], [88.9513855, 21.87555695], [88.95139313, 21.87528038], [88.95166779, 21.875], [88.95166779, 21.87471962], [88.95249939, 21.87388611], [88.95276642, 21.87388992], [88.95443726, 21.87222099], [88.95471954, 21.87222481], [88.95666504, 21.8702774], [88.95666504, 21.87000084], [88.95694733, 21.86972237], [88.95666504, 21.86944389], [88.95666504, 21.86916733], [88.95582581, 21.86833191], [88.95555878, 21.86833382], [88.95444489, 21.86722183], [88.95417023, 21.86722183], [88.95388794, 21.86694527], [88.95361328, 21.8669529], [88.95305634, 21.86639023], [88.95276642, 21.86639023], [88.95111084, 21.86471748], [88.95083618, 21.8647213], [88.95027924, 21.86416626], [88.95027924, 21.86250114], [88.95054626, 21.86222076], [88.95055389, 21.86138916], [88.95083618, 21.86111069], [88.95083618, 21.86083031], [88.95111084, 21.86055756], [88.95111084, 21.85943985], [88.9513855, 21.85916519], [88.95139313, 21.85861015], [88.95166779, 21.85833359], [88.95166779, 21.85750008], [88.95188141, 21.85720825], [88.95194244, 21.85694313], [88.95222473, 21.85666656], [88.95222473, 21.85580063], [88.95222473, 21.85416603], [88.95249939, 21.85388947], [88.95249939, 21.85342026], [88.95276642, 21.85306168], [88.95276642, 21.85139084], [88.95249939, 21.85111046], [88.95249939, 21.85028076], [88.95139313, 21.84917068], [88.95139313, 21.8488903], [88.95111084, 21.84860992], [88.95111084, 21.84833336], [88.95083618, 21.84805679], [88.95083618, 21.84777832], [88.95054626, 21.84749985], [88.95054626, 21.84667015], [88.95027924, 21.84638977], [88.95027924, 21.84610939], [88.94972229, 21.84555435], [88.94972229, 21.84527969], [88.94944763, 21.84500122], [88.94944763, 21.84444046], [88.94916534, 21.8441658], [88.94917297, 21.84389114], [88.94889069, 21.84361076], [88.94889069, 21.84305954], [88.9486084, 21.84278107], [88.9486084, 21.84250069], [88.94832611, 21.84222031], [88.94833374, 21.84194374], [88.94805908, 21.84166718], [88.94805908, 21.84139061], [88.94721985, 21.84056282], [88.94638824, 21.84139061], [88.94638824, 21.84166718], [88.94611359, 21.84194374], [88.94610596, 21.84222031], [88.9458313, 21.84250069], [88.9458313, 21.84278107], [88.94555664, 21.84305573], [88.94555664, 21.84333229], [88.94536591, 21.84357071], [88.94526672, 21.84389114], [88.94499969, 21.8441658], [88.94499969, 21.84444046], [88.94444275, 21.84500122], [88.94444275, 21.84527779], [88.9438858, 21.84583282], [88.9438858, 21.84610939], [88.94361115, 21.84638977], [88.94361115, 21.84666443], [88.9422226, 21.84805679], [88.9422226, 21.84832954], [88.94139099, 21.84917068], [88.94139099, 21.84944534], [88.9411087, 21.84971809], [88.9411087, 21.85000038], [88.94082642, 21.85028076], [88.94083405, 21.8516674], [88.9402771, 21.85220909], [88.9402771, 21.85250092], [88.93916321, 21.8536129], [88.93889618, 21.8536129], [88.93860626, 21.85388947], [88.9366684, 21.85388947], [88.93638611, 21.8536129], [88.93250275, 21.8536129], [88.93222046, 21.8533287], [88.93138885, 21.85333252], [88.9311142, 21.85305595], [88.93028259, 21.85306168], [88.93009186, 21.85287094], [88.93000031, 21.85277748], [88.9291687, 21.85277939], [88.92888641, 21.85250092], [88.9283371, 21.85250092], [88.92804718, 21.85220909], [88.92694092, 21.85220909], [88.92666626, 21.85250092], [88.92610931, 21.85250092], [88.92582703, 21.85277939], [88.92555237, 21.85277939], [88.92472076, 21.8536129], [88.92472076, 21.85388947], [88.91944122, 21.85917091], [88.91916656, 21.85917091], [88.91777802, 21.86055756], [88.91779327, 21.86111069], [88.91750336, 21.8614006], [88.91750336, 21.86166763], [88.91694641, 21.86222267], [88.91694641, 21.86333084], [88.91722107, 21.86361122], [88.91722107, 21.86416626], [88.91694641, 21.86444473], [88.91694641, 21.86583328], [88.91666412, 21.86611176], [88.91665649, 21.86720848], [88.91638947, 21.86750031], [88.91638947, 21.86833191], [88.91665649, 21.86861038], [88.91666412, 21.86916733], [88.91638947, 21.86944389], [88.91638947, 21.86972046], [88.91610718, 21.87000084], [88.91611481, 21.87055588], [88.91583252, 21.87083244], [88.91583252, 21.87194443], [88.91555786, 21.87222481], [88.91555786, 21.87472153], [88.91527557, 21.875], [88.91527557, 21.87583351], [88.91555786, 21.87611198], [88.91555786, 21.87721825], [88.91611481, 21.8777771], [88.91555786, 21.87832832], [88.91555786, 21.87861061], [88.9152832, 21.87888908], [88.9152832, 21.88000107], [88.91555786, 21.88027763], [88.91500092, 21.88083267], [88.91471863, 21.88083267], [88.91444397, 21.88055611], [88.91388702, 21.88055611], [88.91361237, 21.88083267], [88.91083527, 21.88083267], [88.9106369, 21.88063812], [88.91055298, 21.88055611], [88.91027832, 21.88056183], [88.90999603, 21.88027954], [88.90972137, 21.88027954], [88.9091568, 21.87972069], [88.90888977, 21.8797226], [88.90860748, 21.87944412], [88.90833282, 21.87944412], [88.90814972, 21.87925911], [88.90805817, 21.87916756], [88.90750122, 21.87916946], [88.90721893, 21.87888908], [88.90693665, 21.87888908], [88.90693665, 21.87861061], [88.90721893, 21.87832832], [88.90721893, 21.87805557], [88.90777588, 21.87805557], [88.90791321, 21.8781929], [88.90805817, 21.87833405], [88.90888977, 21.87832832], [88.9091568, 21.87861061], [88.90972137, 21.87861061], [88.91027832, 21.87916946], [88.91059113, 21.87920952], [88.91083527, 21.87944412], [88.91166687, 21.87944412], [88.91194153, 21.8797226], [88.91333008, 21.8797226], [88.91388702, 21.87916756], [88.91388702, 21.87888908], [88.91416931, 21.87861061], [88.91416931, 21.87721825], [88.91388702, 21.87694359], [88.91416931, 21.87666893], [88.91416931, 21.87610817], [88.91388702, 21.87583351], [88.91388702, 21.87333298], [88.91416931, 21.87306023], [88.91416931, 21.87249947], [88.91443634, 21.87222099], [88.91444397, 21.86972237], [88.91471863, 21.86944389], [88.91471863, 21.86888885], [88.91500092, 21.86861038], [88.91500092, 21.86750031], [88.9152832, 21.86720848], [88.91527557, 21.86611176], [88.91555786, 21.86583328], [88.91555786, 21.86333275], [88.91583252, 21.86305618], [88.91583252, 21.86250114], [88.9152832, 21.86194038], [88.91500092, 21.8619442], [88.91490936, 21.86185265], [88.91444397, 21.86138916], [88.91472626, 21.86111069], [88.91527557, 21.86111069], [88.91833496, 21.85805321], [88.91860962, 21.85806084], [88.91999817, 21.85667038], [88.91999817, 21.85639], [88.92028046, 21.85610962], [88.92028046, 21.85555649], [88.92082977, 21.85499954], [88.92082977, 21.85472107], [88.92166901, 21.85388947], [88.92193604, 21.85388947], [88.92359924, 21.85220909], [88.92388916, 21.85222244], [88.92416382, 21.85194397], [88.92444611, 21.85194397], [88.92500305, 21.85139084], [88.92527771, 21.85139084], [88.92555237, 21.85111046], [88.92610931, 21.85111046], [88.9263916, 21.85082817], [88.92666626, 21.85082817], [88.92694092, 21.85111046], [88.92722321, 21.85111046], [88.92749786, 21.85082817], [88.92778015, 21.85083389], [88.92805481, 21.85055542], [88.9283371, 21.85055542], [88.92861176, 21.85083389], [88.92888641, 21.85083389], [88.9291687, 21.85055542], [88.93027496, 21.85055542], [88.93055725, 21.85083389], [88.93250275, 21.85083389], [88.9325943, 21.85092545], [88.93276978, 21.85111046], [88.93332672, 21.85111046], [88.93360901, 21.85139084], [88.93444824, 21.85139084], [88.9347229, 21.85166931], [88.93527985, 21.8516674], [88.9355545, 21.85194397], [88.9375, 21.85194397], [88.93777466, 21.8516674], [88.9383316, 21.85166931], [88.93889618, 21.85111046], [88.93888855, 21.85083389], [88.93916321, 21.85055542], [88.93916321, 21.85000038], [88.93889618, 21.84971809], [88.93888855, 21.84944534], [88.9383316, 21.8488903], [88.93805695, 21.8488903], [88.93776703, 21.84860992], [88.9375, 21.84861183], [88.93694305, 21.84805679], [88.9366684, 21.84805679], [88.93638611, 21.84777832], [88.93582916, 21.84778023], [88.93553925, 21.84749985], [88.93527985, 21.84749985], [88.93416595, 21.84638977], [88.9338913, 21.84638977], [88.93332672, 21.84583092], [88.93333435, 21.84555435], [88.93305206, 21.84527969], [88.93305206, 21.84444046], [88.9327774, 21.8441658], [88.93276978, 21.84305954], [88.93305206, 21.84278107], [88.93305206, 21.8416729], [88.93332672, 21.84139061], [88.93332672, 21.84083176], [88.93305206, 21.84055519], [88.93305206, 21.84026909], [88.9327774, 21.84000015], [88.93276978, 21.83889008], [88.93222046, 21.83832932], [88.9319458, 21.83833313], [88.93166351, 21.83805466], [88.93138885, 21.83805466], [88.9311142, 21.83777809], [88.93083191, 21.83777809], [88.93055725, 21.83805466], [88.93000031, 21.83805466], [88.92972565, 21.83833313], [88.9263916, 21.83833313], [88.92610931, 21.83805466], [88.92583466, 21.83805466], [88.92555237, 21.83777809], [88.92472076, 21.83777809], [88.92359924, 21.83666992], [88.92359924, 21.83638954], [88.9227829, 21.83555984], [88.9227829, 21.83306122], [88.92305756, 21.83278084], [88.92305756, 21.83222008], [88.92333221, 21.83194351], [88.92333221, 21.83166695], [88.92415619, 21.83082962], [88.92388916, 21.83055305], [88.92388916, 21.82860947], [88.92444611, 21.82805634], [88.92415619, 21.82777977], [88.92415619, 21.82582855], [88.92388916, 21.8255558], [88.92388916, 21.82529259], [88.92305756, 21.8244381], [88.92250061, 21.82444382], [88.92222595, 21.82416725], [88.92138672, 21.82416725], [88.92111206, 21.82444382], [88.92056274, 21.8244381], [88.91999817, 21.82500076], [88.91971588, 21.82500076], [88.91944122, 21.82529259], [88.91916656, 21.82529259], [88.91889191, 21.82555962], [88.91860962, 21.8255558], [88.91833496, 21.82583427], [88.91805267, 21.82582855], [88.91750336, 21.82638931], [88.91722107, 21.82638931], [88.91666412, 21.82694435], [88.91638947, 21.82694435], [88.91611481, 21.82722282], [88.91555786, 21.82722282], [88.9152832, 21.82749939], [88.91443634, 21.82749939], [88.91422272, 21.82727623], [88.91416931, 21.82722282], [88.91361237, 21.82722282], [88.91333008, 21.82694435], [88.91305542, 21.82694435], [88.91249847, 21.82638931], [88.91221619, 21.82638931], [88.91194153, 21.82611084], [88.91165924, 21.82611084], [88.91148376, 21.82592583], [88.91139221, 21.82583427], [88.91110992, 21.82583427], [88.91083527, 21.8255558], [88.91055298, 21.82555962], [88.90999603, 21.82500076], [88.90972137, 21.82472229], [88.90972137, 21.82444382], [88.90860748, 21.82333374], [88.90777588, 21.82333374], [88.90766907, 21.82322311], [88.90750122, 21.82305527], [88.90666962, 21.82305908], [88.90638733, 21.82278061], [88.90583038, 21.82278061], [88.90556335, 21.82250023], [88.90444183, 21.82250023], [88.90416718, 21.82222748], [88.9033432, 21.82222748], [88.90305328, 21.82195091], [88.90278625, 21.82195091], [88.90249634, 21.82167053], [88.90222168, 21.82167053], [88.9016571, 21.82110977], [88.90139008, 21.82111168], [88.90083313, 21.82055664], [88.90055847, 21.82055664], [88.89971924, 21.81972313], [88.89944458, 21.81972313], [88.89916992, 21.81944656], [88.89888763, 21.81944656], [88.89805603, 21.81861115], [88.89778137, 21.81861115], [88.89527893, 21.81610107], [88.89499664, 21.81611061], [88.89389038, 21.81500053], [88.89360809, 21.81500053], [88.89333344, 21.81472206], [88.89305878, 21.81472206], [88.89250183, 21.81416702], [88.89250183, 21.81389046], [88.89193726, 21.8133316], [88.89167023, 21.81333351], [88.89138794, 21.81305504], [88.89111328, 21.81306267], [88.89055634, 21.81250191], [88.89026642, 21.81250191], [88.88999939, 21.81222153], [88.88804626, 21.81222153], [88.88777924, 21.81250191], [88.88749695, 21.81250191], [88.88722229, 21.81278038], [88.88693237, 21.81278038], [88.88667297, 21.81278038], [88.88639069, 21.81306267], [88.8861084, 21.81306267], [88.88500214, 21.81416702], [88.88500214, 21.81472015], [88.88471985, 21.81500053], [88.88471985, 21.8152771], [88.8841629, 21.81583023], [88.8841629, 21.81638908], [88.88361359, 21.81694221], [88.88360596, 21.81722069], [88.88277435, 21.8180542], [88.88277435, 21.81833267], [88.88194275, 21.81916428], [88.88168335, 21.81916046], [88.8805542, 21.82027626], [88.8805542, 21.82083321], [88.88027954, 21.82110977], [88.88027954, 21.82222748], [88.88054657, 21.82222748], [88.88054657, 21.82278061], [88.88083649, 21.82305908], [88.88083649, 21.82389069], [88.88111115, 21.82416725], [88.88111115, 21.82471848], [88.8813858, 21.82500076], [88.8813858, 21.82529259], [88.88166809, 21.8255558], [88.88168335, 21.82611084], [88.88194275, 21.82638931], [88.88194275, 21.82666588], [88.88223267, 21.82694244], [88.88223267, 21.82777977], [88.88249969, 21.82805634], [88.88249969, 21.82972145], [88.88223267, 21.82999992], [88.88223267, 21.83056068], [88.8813858, 21.83138847], [88.8813858, 21.83194351], [88.88111115, 21.83222008], [88.88111115, 21.83250046], [88.88083649, 21.83278084], [88.88083649, 21.8330574], [88.88054657, 21.83333015], [88.88054657, 21.83361053], [88.88027954, 21.83389091], [88.88027954, 21.83416748], [88.87999725, 21.83444023], [88.87999725, 21.83500099], [88.8797226, 21.83527946], [88.8797226, 21.83555794], [88.87944794, 21.83583069], [88.87944794, 21.83889008], [88.87916565, 21.83916664], [88.87916565, 21.84000015], [88.87889099, 21.84027863], [88.87889099, 21.84083366], [88.87861633, 21.84111023], [88.87861633, 21.84278107], [88.87832642, 21.84305954], [88.87832642, 21.84361076], [88.87805176, 21.84388924], [88.87805176, 21.84444427], [88.8777771, 21.84472275], [88.8777771, 21.84555435], [88.87750244, 21.84583282], [88.87750244, 21.84610939], [88.87750244, 21.84666443], [88.8777771, 21.84694099], [88.8777771, 21.84749985], [88.87805176, 21.84777832], [88.87805176, 21.84833336], [88.87832642, 21.84860992], [88.87833405, 21.85055542], [88.8786087, 21.85083389], [88.8786087, 21.85194397], [88.87832642, 21.85220909], [88.87833405, 21.85305595], [88.87805176, 21.8533287], [88.87805176, 21.85388947], [88.8777771, 21.85416985], [88.87750244, 21.85416603], [88.87722015, 21.8544445], [88.8769455, 21.8544445], [88.87666321, 21.85472107], [88.87526703, 21.85472107], [88.875, 21.85499954], [88.8741684, 21.85499954], [88.87388611, 21.85472107], [88.87333679, 21.85472107], [88.8730545, 21.8544445], [88.8722229, 21.8544445], [88.87194824, 21.85416603], [88.86972046, 21.85416603], [88.8694458, 21.8544445], [88.86888885, 21.8544426], [88.86833191, 21.85499954], [88.86805725, 21.85499954], [88.86777496, 21.85527802], [88.86723328, 21.85527039], [88.86694336, 21.8555603], [88.86611176, 21.85555649], [88.8658371, 21.85583115], [88.86338806, 21.85583115], [88.8611145, 21.85583115], [88.86083221, 21.85611153], [88.86054993, 21.85610962], [88.8602829, 21.85639], [88.86000061, 21.85639], [88.85972595, 21.85667038], [88.85944366, 21.85666656], [88.85888672, 21.8572216], [88.85861206, 21.8572216], [88.85721588, 21.85861015], [88.85722351, 21.85916519], [88.85666656, 21.85972023], [88.85694122, 21.86000061], [88.85694122, 21.86027527], [88.85749054, 21.86083031], [88.85749054, 21.86111069], [88.85805511, 21.86166763], [88.85806274, 21.86194038], [88.85861206, 21.86250114], [88.85861206, 21.86277962], [88.85916901, 21.86333275], [88.85943604, 21.86333084], [88.85972595, 21.86361122], [88.86000061, 21.86361122], [88.86054993, 21.86416817], [88.86083221, 21.86416626], [88.8611145, 21.86444473], [88.8611145, 21.86499977], [88.86045074, 21.86566162], [88.86000061, 21.86611176], [88.85972595, 21.86611176], [88.85943604, 21.86639023], [88.85916901, 21.86639023], [88.85888672, 21.86667252], [88.85832977, 21.86667252], [88.85806274, 21.8669529], [88.85778046, 21.86694527], [88.85749817, 21.86722183], [88.85666656, 21.86722183], [88.85555267, 21.86833382], [88.85527802, 21.86833191], [88.85444641, 21.86916733], [88.85444641, 21.86944389], [88.85415649, 21.86972046], [88.85415649, 21.87306023], [88.85444641, 21.87334061], [88.85444641, 21.875], [88.85472107, 21.87528038], [88.85444641, 21.87556076], [88.85416412, 21.87555695], [88.85415649, 21.87832832], [88.85388947, 21.87861061], [88.85388947, 21.87916756], [88.85416412, 21.87944412], [88.85415649, 21.88348961], [88.85415649, 21.88389015], [88.85388947, 21.88417053], [88.85388947, 21.88555336], [88.85360718, 21.88582993], [88.85360718, 21.88639069], [88.85333252, 21.88667107], [88.85333252, 21.88778114], [88.85360718, 21.88805962], [88.85360718, 21.88861084], [88.85416412, 21.88916779], [88.85416412, 21.88944435], [88.85388947, 21.88972282], [88.85360718, 21.88972092], [88.85333252, 21.88999748], [88.85277557, 21.88999748], [88.85193634, 21.89082909], [88.85194397, 21.89166641], [88.85138702, 21.89222145], [88.85138702, 21.89250183], [88.85083008, 21.89305496], [88.85083008, 21.89333344], [88.85056305, 21.89361191], [88.85056305, 21.89389038], [88.85028076, 21.89416695], [88.85028076, 21.8944416], [88.84971619, 21.89500046], [88.84972382, 21.89527702], [88.84916687, 21.89583015], [88.84916687, 21.89611053], [88.84638977, 21.89888954], [88.84638977, 21.89944649], [88.84527588, 21.90055466], [88.84500122, 21.90055466], [88.84083557, 21.90472221], [88.84083557, 21.90500069], [88.83944702, 21.90638924], [88.83916473, 21.90638924], [88.83860779, 21.90694427], [88.83833313, 21.90694237], [88.83721924, 21.90806007], [88.83694458, 21.90805626], [88.83638763, 21.9086113], [88.83611298, 21.90860939], [88.83528137, 21.90945053], [88.83472443, 21.90944481], [88.83472443, 21.90972137], [88.83416748, 21.90972137], [88.83389282, 21.90999985], [88.83304596, 21.90999985], [88.83277893, 21.91028023], [88.83249664, 21.91027832], [88.83194733, 21.91083336], [88.83166504, 21.91083336], [88.83139038, 21.91111183], [88.83110809, 21.91110992], [88.83082581, 21.9113903], [88.82971954, 21.9113903], [88.82943726, 21.91167068], [88.82917023, 21.91167068], [88.82888794, 21.91195107], [88.82861328, 21.91194344], [88.82833099, 21.91222191], [88.82776642, 21.91222], [88.82750702, 21.91250992], [88.8272171, 21.91250992], [88.82694244, 21.91278076], [88.82666779, 21.91277695], [88.82611084, 21.9133358], [88.82583618, 21.9133358], [88.8236084, 21.91555786], [88.8236084, 21.91583061], [88.82305908, 21.91638947], [88.82305908, 21.91666794], [88.82277679, 21.9169445], [88.82277679, 21.91721916], [88.82221985, 21.91777992], [88.82221985, 21.91805649], [88.8216629, 21.91860771], [88.8216629, 21.91917038], [88.82138062, 21.91945267], [88.82138824, 21.92027855], [88.82111359, 21.92055511], [88.82111359, 21.92083359], [88.8208313, 21.92111015], [88.8208313, 21.92194366], [88.82055664, 21.92222214], [88.82055664, 21.92333031], [88.82026672, 21.92361069], [88.82027435, 21.92444229], [88.81999969, 21.92472267], [88.81999969, 21.9272213], [88.81973267, 21.92749023], [88.81973267, 21.92778015], [88.81961823, 21.92819977], [88.82050323, 21.92877007], [88.82124329, 21.92888451], [88.82199097, 21.92900085], [88.82367706, 21.92770958], [88.82594299, 21.92654991], [88.82621765, 21.92577171], [88.83369446, 21.91992378], [88.83516693, 21.91891479], [88.83655548, 21.91789246]]], [[[88.81694794, 21.9011116], [88.8172226, 21.90083313], [88.81777954, 21.90083313], [88.8180542, 21.90055466], [88.81833649, 21.90055466], [88.81861115, 21.90027618], [88.81916809, 21.90028], [88.81944275, 21.89999962], [88.82026672, 21.89999962], [88.82055664, 21.89972115], [88.8208313, 21.89972305], [88.82111359, 21.89944649], [88.82250214, 21.89944649], [88.82277679, 21.8991642], [88.8236084, 21.8991642], [88.82389069, 21.89944649], [88.8263855, 21.89944649], [88.82666779, 21.8991642], [88.82694244, 21.89916992], [88.8272171, 21.89888954], [88.82805634, 21.89888954], [88.82833099, 21.89861107], [88.82861328, 21.89861107], [88.82888794, 21.89833069], [88.82917023, 21.8983326], [88.82944489, 21.89805412], [88.82971954, 21.89805984], [88.83000183, 21.89777946], [88.83027649, 21.89777946], [88.83056641, 21.89751053], [88.83082581, 21.89751053], [88.83110809, 21.89722061], [88.83139038, 21.89722252], [88.83194733, 21.89666748], [88.83222198, 21.89666939], [88.83277893, 21.89611053], [88.83304596, 21.89611053], [88.83389282, 21.89528275], [88.83444214, 21.89528275], [88.83750153, 21.89222145], [88.83750153, 21.89194489], [88.83777618, 21.89166641], [88.83777618, 21.89138031], [88.83944702, 21.88972282], [88.83944702, 21.88944435], [88.83916473, 21.88916779], [88.83972168, 21.88861084], [88.83972168, 21.88833809], [88.84055328, 21.88750076], [88.84055328, 21.88722038], [88.84083557, 21.88694382], [88.84083557, 21.88611031], [88.84111023, 21.88583565], [88.84083557, 21.88555336], [88.8408432, 21.88500023], [88.84055328, 21.88472176], [88.84055328, 21.88249969], [88.84027863, 21.88221169], [88.84027863, 21.88138962], [88.83999634, 21.88111115], [88.83999634, 21.88056183], [88.83972168, 21.88027954], [88.83999634, 21.88000107], [88.83972168, 21.87972069], [88.83972168, 21.87861061], [88.83944702, 21.87832832], [88.83944702, 21.87750053], [88.83860779, 21.87667084], [88.83860779, 21.87639809], [88.83805847, 21.8758297], [88.83805847, 21.87555695], [88.83777618, 21.87527847], [88.83799744, 21.87506104], [88.83805847, 21.875], [88.83721924, 21.8741684], [88.83721924, 21.87360954], [88.83694458, 21.87333298], [88.83693695, 21.87306023], [88.83583069, 21.87194061], [88.83583069, 21.87166405], [88.83499908, 21.87083054], [88.83499908, 21.87055588], [88.83416748, 21.86972046], [88.83416748, 21.86944389], [88.83361053, 21.86888885], [88.83361053, 21.86861038], [88.83167267, 21.86667252], [88.83167267, 21.86639023], [88.83082581, 21.86554909], [88.83083344, 21.86527824], [88.83040619, 21.86527061], [88.83027649, 21.86528015], [88.83000946, 21.86501122], [88.82971954, 21.86499977], [88.82943726, 21.86471748], [88.82861328, 21.86471748], [88.82833099, 21.86499977], [88.82776642, 21.86499977], [88.82750702, 21.86528015], [88.82722473, 21.86527824], [88.82694244, 21.86555481], [88.82666779, 21.86554909], [88.82554626, 21.86667252], [88.82555389, 21.86694527], [88.82527924, 21.86720848], [88.82527924, 21.86750031], [88.82499695, 21.86778069], [88.82499695, 21.86805534], [88.82486725, 21.86818314], [88.82472229, 21.86833191], [88.82472229, 21.86916733], [88.82444, 21.86944008], [88.82444763, 21.87000084], [88.82417297, 21.87026978], [88.82416534, 21.87055588], [88.82277679, 21.87194443], [88.82250214, 21.87194443], [88.82221985, 21.87222481], [88.8216629, 21.87222099], [88.82138062, 21.87249947], [88.81944275, 21.87249947], [88.81916809, 21.87222099], [88.81833649, 21.87222481], [88.8180542, 21.87194443], [88.81694794, 21.87194443], [88.81666565, 21.87166405], [88.81555176, 21.87166977], [88.8152771, 21.87138939], [88.8144455, 21.87138939], [88.81416321, 21.87111092], [88.81360626, 21.87111092], [88.81338501, 21.87088776], [88.8133316, 21.87083054], [88.81305695, 21.87083244], [88.81277466, 21.87055588], [88.81223297, 21.87055969], [88.81138611, 21.86972046], [88.81111145, 21.86972237], [88.81102753, 21.86964035], [88.8105545, 21.86916733], [88.81027985, 21.86917114], [88.80999756, 21.86889076], [88.80944061, 21.86889076], [88.80916595, 21.86861038], [88.80860901, 21.86861038], [88.80832672, 21.86833191], [88.80805206, 21.86833382], [88.8077774, 21.86805534], [88.80665588, 21.86806107], [88.80639648, 21.86778069], [88.80610657, 21.86806107], [88.80578613, 21.86805534], [88.80472565, 21.86805534], [88.80444336, 21.86833382], [88.8041687, 21.86833191], [88.80388641, 21.86861038], [88.8033371, 21.86861038], [88.80304718, 21.86889076], [88.80278015, 21.86889076], [88.80249786, 21.86917114], [88.80222321, 21.86916733], [88.80194092, 21.86944389], [88.80166626, 21.86944389], [88.8013916, 21.86972237], [88.80110931, 21.86972046], [88.80027771, 21.87055588], [88.80027008, 21.87222099], [88.80055237, 21.87249947], [88.80055237, 21.87306023], [88.80082703, 21.87334061], [88.80082703, 21.87388992], [88.80110931, 21.8741703], [88.80110931, 21.87444687], [88.8013916, 21.87471962], [88.8013916, 21.87555695], [88.80194092, 21.87610817], [88.80194092, 21.87639809], [88.80222321, 21.87667084], [88.80222321, 21.87750053], [88.80249786, 21.8777771], [88.80249786, 21.87832832], [88.80278015, 21.87861061], [88.80444336, 21.87972069], [88.80473328, 21.88000107], [88.80500031, 21.88000107], [88.80526733, 21.88027954], [88.80583191, 21.88027954], [88.80610657, 21.88056183], [88.80638885, 21.88055611], [88.80666351, 21.88083267], [88.8069458, 21.88083267], [88.80750275, 21.88138962], [88.8077774, 21.88138962], [88.80860901, 21.88221169], [88.80860901, 21.88249969], [88.8088913, 21.88277817], [88.8088913, 21.88305473], [88.80916595, 21.88332939], [88.80916595, 21.88389015], [88.80944824, 21.88416672], [88.80944061, 21.88471985], [88.8097229, 21.88500023], [88.8097229, 21.88750076], [88.80944061, 21.88778114], [88.80944061, 21.88805962], [88.8097229, 21.88833809], [88.8097229, 21.88889122], [88.80999756, 21.88916779], [88.80999756, 21.89266014], [88.80999756, 21.89305496], [88.81027985, 21.89333344], [88.81027985, 21.89347267], [88.81027985, 21.89388847], [88.81047821, 21.89409065], [88.8105545, 21.89416695], [88.8105545, 21.89433098], [88.8105545, 21.89444351], [88.81083679, 21.89472008], [88.81083679, 21.89500046], [88.81111145, 21.89527702], [88.81111145, 21.89583015], [88.81138611, 21.89611053], [88.81138611, 21.89638901], [88.81156921, 21.89657211], [88.81194305, 21.89694214], [88.81222534, 21.89694214], [88.8125, 21.89722252], [88.81276703, 21.89722061], [88.81305695, 21.89751053], [88.8133316, 21.89751053], [88.81388855, 21.89805412], [88.81388855, 21.8983326], [88.81445313, 21.89888954], [88.8144455, 21.8991642], [88.81472015, 21.89944077], [88.81472015, 21.89999962], [88.8152771, 21.90055466], [88.81555176, 21.90055466], [88.8156662, 21.90066528], [88.81583405, 21.90083313], [88.81639099, 21.90083313], [88.81666565, 21.9011116], [88.81694794, 21.9011116]]], [[[88.56233978, 21.89746094], [88.5629425, 21.89740944], [88.56349945, 21.89750481], [88.56402588, 21.89764023], [88.56450653, 21.89776993], [88.56495667, 21.89789009], [88.56537628, 21.89808083], [88.56583405, 21.89831734], [88.56632996, 21.89858246], [88.56681824, 21.8989296], [88.56729889, 21.89934158], [88.56781769, 21.89974022], [88.56838989, 21.90011024], [88.56903839, 21.9004612], [88.56976318, 21.90086174], [88.57050323, 21.90119934], [88.57068634, 21.90111542], [88.57103729, 21.90094948], [88.57138062, 21.9004879], [88.57144165, 21.90036964], [88.57161713, 21.90000534], [88.57168579, 21.89941978], [88.57180786, 21.89882088], [88.57196808, 21.89836121], [88.57219696, 21.89794922], [88.5724411, 21.89751053], [88.5727005, 21.89703941], [88.57299805, 21.89659119], [88.5732193, 21.89607048], [88.57337952, 21.89554024], [88.57364655, 21.89514732], [88.57398224, 21.89485168], [88.57429504, 21.89439392], [88.57437134, 21.89355278], [88.57480621, 21.89312744], [88.57493591, 21.89266968], [88.57501984, 21.8922596], [88.57517242, 21.89192009], [88.57527161, 21.89156914], [88.57536316, 21.89118958], [88.57553101, 21.89081955], [88.57562256, 21.89039421], [88.57579803, 21.89001083], [88.57589722, 21.88960075], [88.57583618, 21.88944054], [88.57611084, 21.88916779], [88.57611084, 21.88889122], [88.57639313, 21.88861084], [88.57611084, 21.88833427], [88.57639313, 21.88805962], [88.57639313, 21.88778114], [88.57636261, 21.88717842], [88.57633972, 21.88672066], [88.57621765, 21.88631439], [88.5761261, 21.8859005], [88.57607269, 21.88544846], [88.57602692, 21.88495064], [88.57622528, 21.88428116], [88.57614899, 21.88386726], [88.57601166, 21.8834095], [88.57576752, 21.88284111], [88.57540131, 21.88234138], [88.57501221, 21.88195229], [88.57466888, 21.8815918], [88.57447052, 21.88119888], [88.57440186, 21.88080406], [88.57424927, 21.88049889], [88.5741806, 21.88017082], [88.57419586, 21.87977219], [88.57427979, 21.8792572], [88.57421112, 21.87875175], [88.57430267, 21.87821007], [88.57374573, 21.87662506], [88.57324219, 21.87393951], [88.57299042, 21.87236977], [88.57288361, 21.87171555], [88.57287598, 21.87157249], [88.57266998, 21.8676815], [88.57252502, 21.86351395], [88.57281494, 21.86297417], [88.57277679, 21.86166763], [88.57263184, 21.86066055], [88.57272339, 21.85989189], [88.57277679, 21.85944366], [88.57277679, 21.85916519], [88.57277679, 21.85881042], [88.57273865, 21.85836029], [88.57253265, 21.8579483], [88.57241821, 21.8574295], [88.57224274, 21.85690308], [88.57214355, 21.8563385], [88.57198334, 21.85582161], [88.57189941, 21.85527039], [88.57170105, 21.85482025], [88.57155609, 21.85435104], [88.57135773, 21.85396767], [88.57111359, 21.85364532], [88.57084656, 21.85334969], [88.57065582, 21.85300064], [88.57049561, 21.85258293], [88.57026672, 21.85215759], [88.57000732, 21.85172081], [88.56977081, 21.85123062], [88.56965637, 21.85069847], [88.56947327, 21.85024071], [88.5693512, 21.84979057], [88.56913757, 21.84941673], [88.5688858, 21.8490696], [88.5686264, 21.84872055], [88.5684433, 21.84831047], [88.56828308, 21.84787369], [88.56808472, 21.84747124], [88.56797791, 21.84702492], [88.56781006, 21.84661293], [88.56774139, 21.84616661], [88.56754303, 21.8458004], [88.56745911, 21.84535027], [88.56726074, 21.84495926], [88.5672226, 21.84453964], [88.5672226, 21.84410095], [88.56718445, 21.84366798], [88.56698608, 21.84324074], [88.56692505, 21.84270287], [88.56682587, 21.84210587], [88.56667328, 21.84148979], [88.56648254, 21.84087944], [88.56621552, 21.84034157], [88.56607819, 21.8397541], [88.5658493, 21.8392334], [88.56565094, 21.83871078], [88.56542969, 21.83818817], [88.56526184, 21.83764648], [88.56505585, 21.83711052], [88.56494904, 21.83653259], [88.56474304, 21.83599091], [88.56459045, 21.83542824], [88.56446075, 21.83488083], [88.56437683, 21.83431816], [88.56420135, 21.83380508], [88.56413269, 21.83325958], [88.56391144, 21.83279228], [88.56369781, 21.83230972], [88.56349945, 21.83184052], [88.5633316, 21.83136177], [88.56311798, 21.83093071], [88.56278229, 21.83060074], [88.56247711, 21.83031082], [88.56217957, 21.8300705], [88.56188202, 21.82991028], [88.56163788, 21.8297596], [88.56138611, 21.82971954], [88.56115723, 21.82973099], [88.56092834, 21.82984734], [88.56069183, 21.83008003], [88.56044006, 21.83026123], [88.56021881, 21.83033943], [88.56002808, 21.83024979], [88.55916595, 21.83063126], [88.55819702, 21.82930946], [88.55784607, 21.82909966], [88.55771637, 21.82888985], [88.55750275, 21.8283329], [88.55702972, 21.82814407], [88.55672455, 21.82792664], [88.55615997, 21.82760048], [88.55591583, 21.82746124], [88.55548096, 21.82744026], [88.55502319, 21.82735062], [88.55457306, 21.82752037], [88.5541153, 21.82781792], [88.55366516, 21.8282547], [88.5532608, 21.82879829], [88.55284119, 21.82932091], [88.55251312, 21.82979012], [88.55222321, 21.83017921], [88.55194855, 21.8304615], [88.55168915, 21.83069992], [88.55143738, 21.83097839], [88.55119324, 21.83136368], [88.55108643, 21.83173943], [88.55103302, 21.83191681], [88.55083466, 21.83194351], [88.55055237, 21.83166695], [88.55000305, 21.83167076], [88.55005646, 21.83118057], [88.55027771, 21.83075905], [88.55045319, 21.83044815], [88.55051422, 21.83034134], [88.55078125, 21.82995605], [88.55105591, 21.82955933], [88.55130005, 21.82914925], [88.55153656, 21.82874107], [88.55180359, 21.82836533], [88.55208588, 21.82801056], [88.55237579, 21.82765007], [88.5526886, 21.82731056], [88.5530014, 21.82697868], [88.5532608, 21.82661057], [88.55347443, 21.82622719], [88.5536499, 21.82582855], [88.55384827, 21.82546806], [88.55388641, 21.82500076], [88.5541687, 21.82471848], [88.5541687, 21.82416725], [88.55444336, 21.82389069], [88.55416107, 21.81949997], [88.5537262, 21.81902885], [88.55339813, 21.81867027], [88.55332947, 21.81833076], [88.55319214, 21.81818008], [88.55305481, 21.81777763], [88.55278015, 21.81750107], [88.55222321, 21.81750107], [88.55200195, 21.81733131], [88.5513382, 21.8173008], [88.55103302, 21.81729126], [88.55071259, 21.8174057], [88.55024719, 21.81748009], [88.54975891, 21.8175602], [88.54930878, 21.81776047], [88.54885864, 21.81795692], [88.5484314, 21.81817245], [88.54811859, 21.81848526], [88.5479126, 21.81886292], [88.54775238, 21.81921005], [88.54759216, 21.81950951], [88.54749298, 21.81980705], [88.54737091, 21.82012558], [88.54720306, 21.82045364], [88.54702759, 21.82080269], [88.54695129, 21.82120132], [88.54688263, 21.82159805], [88.54668427, 21.82193375], [88.54641724, 21.82229042], [88.54614258, 21.82270813], [88.54580688, 21.82313919], [88.54582977, 21.82359123], [88.54580688, 21.8239994], [88.54582977, 21.82416725], [88.54528046, 21.82472229], [88.54528046, 21.82582855], [88.54499817, 21.82611084], [88.54499817, 21.82638931], [88.54333496, 21.82805634], [88.54333496, 21.8283329], [88.54305267, 21.82860947], [88.54305267, 21.82888985], [88.54277802, 21.82917023], [88.54250336, 21.82916641], [88.54218292, 21.82944107], [88.54171753, 21.82982063], [88.5412674, 21.8302002], [88.54084778, 21.8304615], [88.54043579, 21.83078003], [88.53997803, 21.83110046], [88.53948212, 21.83138466], [88.53901672, 21.83166122], [88.53862762, 21.83195114], [88.53830719, 21.83222961], [88.53795624, 21.83241272], [88.53749847, 21.83250046], [88.53721619, 21.83278084], [88.53694153, 21.83278084], [88.53666687, 21.83306122], [88.53527832, 21.83306122], [88.53443146, 21.83389091], [88.53391266, 21.83377075], [88.53385162, 21.83413124], [88.53375244, 21.8343811], [88.53360748, 21.83472061], [88.53333282, 21.83500099], [88.53333282, 21.83527565], [88.53277588, 21.83583069], [88.53277588, 21.83611107], [88.53305817, 21.83638954], [88.53277588, 21.83666611], [88.53277588, 21.8386116], [88.53266144, 21.83872986], [88.53251648, 21.83920097], [88.53250885, 21.83977127], [88.53247833, 21.84038544], [88.53237152, 21.8409729], [88.53233337, 21.84147072], [88.53214264, 21.84176064], [88.53185272, 21.84205627], [88.53151703, 21.84247208], [88.53153229, 21.84325981], [88.53131866, 21.8438797], [88.53096771, 21.84443283], [88.53106689, 21.84495735], [88.53108978, 21.84551048], [88.53100586, 21.84608078], [88.53082275, 21.84662247], [88.5306015, 21.84714127], [88.53055573, 21.84777832], [88.53056335, 21.84831047], [88.53055573, 21.84916878], [88.53111267, 21.84972191], [88.53166962, 21.85028076], [88.53193665, 21.85028076], [88.53221893, 21.85055923], [88.53250885, 21.85055923], [88.53305817, 21.85111046], [88.53333282, 21.85111046], [88.53360748, 21.85139084], [88.5341568, 21.85139084], [88.53444672, 21.85166931], [88.53500366, 21.8516674], [88.53500366, 21.85194397], [88.53527832, 21.85194397], [88.53649139, 21.85210228], [88.53700256, 21.85231209], [88.53827667, 21.85283852], [88.53833008, 21.85305595], [88.53861237, 21.85333252], [88.53916931, 21.8533287], [88.53968048, 21.85355949], [88.54012299, 21.85373116], [88.54057312, 21.85391045], [88.54101563, 21.85414505], [88.54138947, 21.8544426], [88.54250336, 21.8555603], [88.54250336, 21.85639], [88.54277802, 21.85667038], [88.54277802, 21.85805321], [88.54305267, 21.85833359], [88.54305267, 21.85861015], [88.54332733, 21.85889053], [88.54305267, 21.85916519], [88.54305267, 21.8619442], [88.54301453, 21.86203957], [88.54281616, 21.8625927], [88.54277802, 21.86321259], [88.5427475, 21.86380959], [88.54261017, 21.86433983], [88.54248047, 21.86482048], [88.5422821, 21.86524963], [88.54216003, 21.86572075], [88.54196167, 21.86611938], [88.54183197, 21.86650085], [88.54168701, 21.86681175], [88.54160309, 21.86712074], [88.54143524, 21.86736679], [88.54132843, 21.86762047], [88.54109955, 21.8678112], [88.54084015, 21.86806107], [88.54064178, 21.86841583], [88.54059601, 21.86909294], [88.54042816, 21.86989021], [88.54050446, 21.87039948], [88.54081726, 21.87060165], [88.54111481, 21.87084961], [88.54139709, 21.87117958], [88.5417099, 21.87154007], [88.54210663, 21.87183571], [88.54222107, 21.87194061], [88.54277802, 21.87249947], [88.54305267, 21.87249947], [88.54332733, 21.87277985], [88.54360962, 21.87277985], [88.54389191, 21.87306023], [88.54416656, 21.87306023], [88.54499817, 21.87388992], [88.54528046, 21.87388992], [88.54528046, 21.87444687], [88.54555511, 21.87472153], [88.54611206, 21.87471962], [88.54638672, 21.875], [88.54666901, 21.875], [88.54703522, 21.87537575], [88.54746246, 21.87580109], [88.54795837, 21.87618828], [88.54833984, 21.87663078], [88.54868317, 21.87701988], [88.54891205, 21.87737083], [88.54911804, 21.87764931], [88.54923248, 21.87795067], [88.5493927, 21.87820435], [88.54946899, 21.87851143], [88.54960632, 21.87878418], [88.54971313, 21.87911034], [88.54980469, 21.87951088], [88.54999542, 21.87994385], [88.55015564, 21.88043976], [88.55026245, 21.88095856], [88.55024719, 21.88150024], [88.55013275, 21.88202286], [88.55010986, 21.88262177], [88.55004883, 21.88318253], [88.55000305, 21.88368797], [88.54994965, 21.88414383], [88.54978943, 21.88452339], [88.54969025, 21.88492012], [88.54957581, 21.88534927], [88.54946136, 21.88584137], [88.54936981, 21.88643837], [88.54920197, 21.88706207], [88.54915619, 21.88779068], [88.5491333, 21.88855934], [88.54915619, 21.88933945], [88.54915619, 21.89011002], [88.54916382, 21.89085579], [88.54911041, 21.8915596], [88.54886627, 21.8922081], [88.54850769, 21.89278984], [88.54814911, 21.89334106], [88.54774475, 21.89385986], [88.54727936, 21.89427376], [88.54685974, 21.89468002], [88.54644012, 21.89507294], [88.54602814, 21.89548111], [88.54553986, 21.89585114], [88.54499054, 21.8962307], [88.54439545, 21.89661789], [88.54379272, 21.89703941], [88.54319, 21.89745712], [88.54261017, 21.89785004], [88.54214478, 21.89831734], [88.54172516, 21.89876366], [88.54133606, 21.89915276], [88.541008, 21.89952087], [88.54080963, 21.89996147], [88.5406189, 21.90036964], [88.54057312, 21.90080261], [88.54060364, 21.90123749], [88.54074097, 21.90167236], [88.54091644, 21.9021225], [88.54116058, 21.90256119], [88.54147339, 21.90295982], [88.54183197, 21.90331078], [88.54220581, 21.90364075], [88.54258728, 21.90397072], [88.54308319, 21.90422821], [88.54363251, 21.90444946], [88.54421997, 21.90463066], [88.54486847, 21.90468025], [88.54499054, 21.90467262], [88.545578, 21.90462685], [88.54624176, 21.90443039], [88.54690552, 21.90420914], [88.54759216, 21.90400124], [88.54830933, 21.90381813], [88.54884338, 21.90353966], [88.54927826, 21.90321159], [88.54965973, 21.9028511], [88.55005646, 21.90251923], [88.55047607, 21.90223122], [88.55091095, 21.90195084], [88.55136108, 21.90168953], [88.55181122, 21.90139961], [88.55229187, 21.90112114], [88.55277252, 21.90084839], [88.55329895, 21.90063095], [88.55380249, 21.9004097], [88.55422974, 21.90013885], [88.55471039, 21.89999008], [88.55517578, 21.8998394], [88.55562592, 21.89974022], [88.55609894, 21.89967918], [88.55649567, 21.89951706], [88.55693054, 21.89941025], [88.55731964, 21.89917946], [88.55770874, 21.89896965], [88.55809784, 21.89873123], [88.55850983, 21.89855003], [88.5588913, 21.89836121], [88.55930328, 21.89821053], [88.55971527, 21.89807892], [88.56014252, 21.8979702], [88.56053925, 21.89782715], [88.56093597, 21.8977375], [88.56134033, 21.89759827], [88.56179047, 21.89751625], [88.56233978, 21.89746094]]], [[[88.58274841, 21.86554909], [88.58248901, 21.8654995], [88.58222961, 21.86551857], [88.58191681, 21.86559105], [88.58165741, 21.86608124], [88.58142853, 21.86662102], [88.58139038, 21.86718941], [88.58139038, 21.86770248], [88.58139038, 21.86816025], [88.58139038, 21.86861801], [88.58139038, 21.86910057], [88.58139038, 21.86960983], [88.58138275, 21.87010765], [88.58132935, 21.87058067], [88.58114624, 21.87104034], [88.58110809, 21.87153053], [88.58110809, 21.87203789], [88.58113861, 21.87252808], [88.5812912, 21.8729763], [88.5814209, 21.87345123], [88.58165741, 21.87389946], [88.58188629, 21.87437057], [88.58217621, 21.8747921], [88.58246613, 21.87522507], [88.58286285, 21.87555122], [88.58326721, 21.87586021], [88.58368683, 21.87618828], [88.58423615, 21.87659073], [88.58468628, 21.87659073], [88.58481598, 21.87652969], [88.5850296, 21.87635231], [88.58541107, 21.87597275], [88.58558655, 21.87554359], [88.58579254, 21.87507629], [88.58583832, 21.87455177], [88.58580017, 21.87399292], [88.58538818, 21.87347031], [88.58541107, 21.87309265], [88.58526611, 21.87233162], [88.58526611, 21.87187004], [88.585289, 21.87133026], [88.58525848, 21.87092972], [88.58505249, 21.87045288], [88.58493805, 21.87016296], [88.58485413, 21.8698597], [88.58481598, 21.86952972], [88.58467865, 21.869133], [88.58444214, 21.86873245], [88.58420563, 21.86827469], [88.58390045, 21.86780357], [88.58360291, 21.867239], [88.58361816, 21.86667252], [88.58325958, 21.86597443], [88.58274841, 21.86554909]]], [[[88.63999939, 21.92168045], [88.64026642, 21.92139053], [88.64083862, 21.92139053], [88.64111328, 21.92111015], [88.64159393, 21.92084122], [88.64221954, 21.92056274], [88.64250183, 21.92021179], [88.64305878, 21.92000008], [88.64389801, 21.91953278], [88.64472198, 21.91917038], [88.64499664, 21.91917038], [88.64527893, 21.91889191], [88.64554596, 21.91889191], [88.64583588, 21.91860771], [88.64596558, 21.91840935], [88.64639282, 21.91820145], [88.64672852, 21.91806412], [88.6472168, 21.91764259], [88.64770508, 21.91750908], [88.64784241, 21.91729927], [88.64832306, 21.91710281], [88.64866638, 21.91688919], [88.64929962, 21.91688919], [88.64951324, 21.91674042], [88.65006256, 21.91650963], [88.65116119, 21.91661072], [88.65207672, 21.91680908], [88.65242004, 21.9167614], [88.652565, 21.91674232], [88.65279388, 21.91674423], [88.65317535, 21.9169426], [88.6537323, 21.91688919], [88.65426636, 21.91666985], [88.65483856, 21.9164238], [88.65545654, 21.91624641], [88.65605927, 21.91609001], [88.65666199, 21.91583061], [88.65727997, 21.91555786], [88.65789795, 21.91530037], [88.65850067, 21.91513443], [88.65878296, 21.9148674], [88.65898895, 21.91489983], [88.65944672, 21.91472054], [88.66055298, 21.91472244], [88.66083527, 21.91444588], [88.66139221, 21.91444588], [88.66166687, 21.9141655], [88.66194153, 21.91417122], [88.66210938, 21.91415977], [88.66243744, 21.91418839], [88.66260529, 21.91413116], [88.66293335, 21.91401482], [88.66342926, 21.91389847], [88.6639328, 21.91382027], [88.66442871, 21.91365051], [88.6649704, 21.91358948], [88.66555786, 21.91361046], [88.66583252, 21.91361046], [88.66610718, 21.91333008], [88.66694641, 21.9133358], [88.66750336, 21.91277695], [88.66750336, 21.91167068], [88.66722107, 21.9113903], [88.66722107, 21.91028023], [88.66694641, 21.90999985], [88.66694641, 21.90945053], [88.66665649, 21.90917015], [88.66666412, 21.90870094], [88.66666412, 21.90833282], [88.66611481, 21.90777779], [88.66610718, 21.90750122], [88.66583252, 21.90722275], [88.66583252, 21.9066658], [88.66555786, 21.9063797], [88.66555786, 21.90555573], [88.6652832, 21.90527916], [88.6652832, 21.90500069], [88.66471863, 21.90444374], [88.66471863, 21.90416718], [88.66166687, 21.9011097], [88.66166687, 21.90083313], [88.66110992, 21.90027618], [88.66110992, 21.89972115], [88.66055298, 21.8991642], [88.66055298, 21.89888954], [88.66027832, 21.89861107], [88.66027832, 21.89833069], [88.66000366, 21.89805412], [88.65999603, 21.89777946], [88.65972137, 21.89751053], [88.65944672, 21.89722061], [88.65916443, 21.89694214], [88.65944672, 21.89666748], [88.65944672, 21.89556122], [88.65888214, 21.89500046], [88.65888214, 21.89389038], [88.65860748, 21.89361191], [88.65860748, 21.89333344], [88.65805817, 21.8927784], [88.65805817, 21.89166832], [88.65777588, 21.89138031], [88.65777588, 21.89111137], [88.65750122, 21.8908329], [88.65750122, 21.89055634], [88.65721893, 21.89027977], [88.6574707, 21.89001083], [88.65730286, 21.88946152], [88.65719604, 21.88890076], [88.65699005, 21.88838959], [88.65693665, 21.88778114], [88.65666962, 21.88750076], [88.65666962, 21.88722038], [88.65638733, 21.88694382], [88.65638733, 21.88638878], [88.65556335, 21.88557053], [88.65556335, 21.88528061], [88.65444183, 21.88417053], [88.65444183, 21.88305283], [88.65389252, 21.88249969], [88.65389252, 21.88221169], [88.65361023, 21.88194466], [88.65361023, 21.88166618], [88.6533432, 21.88138962], [88.65333557, 21.88111115], [88.65305328, 21.88083267], [88.65305328, 21.8777771], [88.6533432, 21.87750053], [88.65333557, 21.87666893], [88.65277863, 21.87610817], [88.65305328, 21.87583351], [88.65305328, 21.8741684], [88.65277863, 21.87388992], [88.65277863, 21.87355995], [88.65277863, 21.87333298], [88.65139008, 21.87194061], [88.64805603, 21.87194443], [88.64794159, 21.87205887], [88.64778137, 21.87222481], [88.6472168, 21.87222099], [88.64694214, 21.87249947], [88.64611053, 21.87249947], [88.64583588, 21.87277985], [88.64554596, 21.87277985], [88.64527893, 21.87306023], [88.64499664, 21.87306023], [88.64472198, 21.87334061], [88.64333344, 21.87333298], [88.64305878, 21.87361145], [88.64245605, 21.87360001], [88.64190674, 21.87363052], [88.64138794, 21.87360954], [88.64089203, 21.87359047], [88.64044952, 21.87348747], [88.6400528, 21.87334061], [88.63964844, 21.8731308], [88.63917542, 21.87295341], [88.63870239, 21.87271881], [88.63825989, 21.87244034], [88.63796234, 21.8722496], [88.63783264, 21.87216759], [88.63742828, 21.8718853], [88.63698578, 21.87163925], [88.6364975, 21.87137985], [88.63639069, 21.87138939], [88.6361084, 21.87111092], [88.63582611, 21.87111092], [88.63555908, 21.87083054], [88.63527679, 21.87083244], [88.63500214, 21.87055588], [88.63445282, 21.87055969], [88.63361359, 21.87138939], [88.63361359, 21.87194443], [88.6333313, 21.87222099], [88.6333313, 21.87249947], [88.63360596, 21.87277985], [88.63388824, 21.87331581], [88.63420105, 21.8737793], [88.63456726, 21.8741951], [88.63491058, 21.87461281], [88.63528442, 21.87498665], [88.63565826, 21.87531281], [88.63594055, 21.87569046], [88.63613892, 21.876091], [88.63638306, 21.87643814], [88.63646698, 21.87659645], [88.63656616, 21.87677956], [88.63660431, 21.8771553], [88.63643646, 21.87759209], [88.63633728, 21.87813187], [88.63613129, 21.87870026], [88.63591766, 21.87929726], [88.63552094, 21.87973022], [88.63503265, 21.88013077], [88.63452911, 21.88051414], [88.63395691, 21.8808403], [88.63339996, 21.88113976], [88.63285828, 21.8814106], [88.63237, 21.88167191], [88.63194275, 21.8819294], [88.6315155, 21.88210106], [88.63111877, 21.88229942], [88.63072968, 21.88253021], [88.63057709, 21.88265419], [88.63037872, 21.88281822], [88.63006592, 21.88316917], [88.62985992, 21.88357925], [88.6296463, 21.8839798], [88.62947083, 21.88442039], [88.62940979, 21.88492966], [88.62926483, 21.88548851], [88.62918091, 21.88611412], [88.62916565, 21.88675117], [88.62916565, 21.88722229], [88.62917328, 21.88861084], [88.62889099, 21.88888931], [88.62889862, 21.88972092], [88.6286087, 21.88999748], [88.62861633, 21.89057159], [88.6286087, 21.89112091], [88.6286087, 21.89166832], [88.6286087, 21.89222145], [88.62861633, 21.89276123], [88.6286087, 21.89331055], [88.62857819, 21.89386177], [88.62841034, 21.89439964], [88.6282959, 21.89500046], [88.6280899, 21.89557076], [88.62796021, 21.89616966], [88.62767792, 21.89665604], [88.62734222, 21.89709091], [88.62698364, 21.89750671], [88.62665558, 21.89792252], [88.62631989, 21.89829445], [88.62593842, 21.89860535], [88.62563324, 21.8988018], [88.62550354, 21.89888573], [88.62503052, 21.89917183], [88.62454987, 21.89949989], [88.62412262, 21.89992523], [88.623703, 21.90035057], [88.62345123, 21.90086937], [88.62338257, 21.90140915], [88.62361145, 21.90192032], [88.62402344, 21.90235519], [88.62449646, 21.90274048], [88.62496948, 21.90310669], [88.62539673, 21.90345573], [88.62576294, 21.90381241], [88.62612152, 21.90413094], [88.6264801, 21.90445518], [88.62683105, 21.90480042], [88.62717438, 21.90518188], [88.62753296, 21.90555954], [88.62792969, 21.90584564], [88.62828064, 21.90612221], [88.62857819, 21.9064045], [88.6288681, 21.90670967], [88.62915802, 21.90706825], [88.62944794, 21.90747833], [88.62973785, 21.90790939], [88.63005066, 21.90830994], [88.63037872, 21.90868759], [88.6307373, 21.90896988], [88.63101959, 21.90933037], [88.6312561, 21.90971184], [88.63149261, 21.91007042], [88.63168335, 21.91040993], [88.63189697, 21.91070938], [88.63202667, 21.91102982], [88.63220978, 21.91127777], [88.63236237, 21.91153145], [88.63249969, 21.91180038], [88.63262939, 21.91208076], [88.63277435, 21.91234589], [88.63291168, 21.9126339], [88.63304901, 21.91293716], [88.63315582, 21.91329956], [88.63334656, 21.91367912], [88.6335907, 21.91408348], [88.63378143, 21.91456223], [88.63395691, 21.91506958], [88.63417816, 21.91559029], [88.63443756, 21.91609955], [88.63468933, 21.91664505], [88.63491058, 21.91723061], [88.63510895, 21.91783714], [88.63530731, 21.91843033], [88.63555145, 21.91897011], [88.63581085, 21.91950035], [88.63609314, 21.92003059], [88.63640594, 21.92056274], [88.63683319, 21.92099953], [88.63722229, 21.92139053], [88.63861084, 21.92139053], [88.63889313, 21.92168045], [88.63999939, 21.92168045]]], [[[88.72360992, 21.93194389], [88.72416687, 21.93139076], [88.72444153, 21.93139076], [88.72444153, 21.93111038], [88.72499084, 21.93054962], [88.72499847, 21.93027878], [88.72528076, 21.93000031], [88.72528076, 21.92944908], [88.72556305, 21.92917061], [88.72556305, 21.92860985], [88.72611237, 21.92805481], [88.72611237, 21.92777634], [88.72638702, 21.92749023], [88.72638702, 21.9272213], [88.72666931, 21.92694664], [88.72666931, 21.92666435], [88.72693634, 21.92638969], [88.72693634, 21.92611122], [88.72721863, 21.92583084], [88.72721863, 21.92555428], [88.7277832, 21.92500114], [88.7277832, 21.92472076], [88.72833252, 21.92416573], [88.72833252, 21.92389107], [88.73055267, 21.92168045], [88.73055267, 21.92139053], [88.73221588, 21.9197216], [88.73249817, 21.9197216], [88.73278046, 21.91944504], [88.73306274, 21.91945267], [88.73332977, 21.91917038], [88.73361206, 21.91917038], [88.73388672, 21.91889191], [88.73416138, 21.91889191], [88.73443604, 21.91860771], [88.73500061, 21.91861153], [88.73527527, 21.91833305], [88.73583221, 21.91833305], [88.7361145, 21.91805649], [88.73777771, 21.9180584], [88.73805237, 21.91777992], [88.73880768, 21.91777992], [88.73972321, 21.91777992], [88.73999786, 21.9180584], [88.7408371, 21.91805649], [88.74111176, 21.91833305], [88.7416687, 21.91833305], [88.74194336, 21.91861153], [88.74276733, 21.91860771], [88.74305725, 21.91889191], [88.74360657, 21.91889191], [88.74388885, 21.91917038], [88.74416351, 21.91916656], [88.74472046, 21.9197216], [88.74500275, 21.9197216], [88.7452774, 21.92000008], [88.74555206, 21.92028046], [88.74583435, 21.92027855], [88.74771881, 21.92216492], [88.74888611, 21.92333221], [88.74916077, 21.92333031], [88.75, 21.92416954], [88.75027466, 21.92416573], [88.75074768, 21.92464066], [88.7508316, 21.92472267], [88.75110626, 21.92472076], [88.75166321, 21.92527962], [88.75195313, 21.92527962], [88.75222778, 21.92556], [88.75250244, 21.92555428], [88.7527771, 21.92583275], [88.75304413, 21.92587852], [88.75332642, 21.92611122], [88.7536087, 21.92611122], [88.75389099, 21.92638969], [88.75416565, 21.92638969], [88.75435638, 21.92657661], [88.75444794, 21.92667007], [88.7555542, 21.92666435], [88.75576019, 21.92687035], [88.75583649, 21.92694664], [88.75611115, 21.92694664], [88.7563858, 21.92666435], [88.75945282, 21.92667007], [88.75971985, 21.92638969], [88.76082611, 21.92638969], [88.76110077, 21.92611122], [88.76304626, 21.92611122], [88.76333618, 21.92583084], [88.76361084, 21.92611122], [88.76444244, 21.92611122], [88.7647171, 21.92583084], [88.76833344, 21.92583275], [88.76860809, 21.92555428], [88.76972198, 21.92556], [88.76999664, 21.92527962], [88.77054596, 21.92527962], [88.77083588, 21.92500114], [88.77111053, 21.92500114], [88.77139282, 21.92472076], [88.77388763, 21.92472267], [88.77416992, 21.92444229], [88.77500153, 21.92444992], [88.77583313, 21.92361069], [88.77610779, 21.92361069], [88.77694702, 21.9227829], [88.77749634, 21.9227829], [88.77777863, 21.92250061], [88.77749634, 21.92222023], [88.77805328, 21.92222214], [88.77861023, 21.9216671], [88.77889252, 21.92168045], [88.77971649, 21.92083168], [88.77999878, 21.92083359], [88.78083038, 21.92000008], [88.78111267, 21.92000008], [88.78138733, 21.9197216], [88.78166962, 21.9197216], [88.78194427, 21.91944504], [88.7822113, 21.91945267], [88.78250122, 21.91917038], [88.78305817, 21.91917038], [88.78333282, 21.91889191], [88.78360748, 21.91889191], [88.78388977, 21.91860771], [88.78472137, 21.91861153], [88.78500366, 21.91833305], [88.78527832, 21.91833305], [88.78555298, 21.91805649], [88.7858429, 21.9180584], [88.78610992, 21.91777992], [88.78666687, 21.91777992], [88.78694153, 21.91749954], [88.78888702, 21.91749954], [88.78916931, 21.91721916], [88.79250336, 21.91721916], [88.79277802, 21.91749954], [88.79332733, 21.91749954], [88.79360962, 21.91777992], [88.79416656, 21.91777992], [88.79444122, 21.9180584], [88.79499054, 21.9181118], [88.79528046, 21.91833305], [88.79555511, 21.91833305], [88.79582977, 21.91861153], [88.79638672, 21.91861153], [88.79652405, 21.91875076], [88.79666901, 21.91889191], [88.79693604, 21.91889191], [88.79722595, 21.91917038], [88.79750061, 21.91916656], [88.79805756, 21.9197216], [88.79944611, 21.9197216], [88.80000305, 21.91916656], [88.80000305, 21.91889191], [88.80027008, 21.91860771], [88.80027771, 21.91777992], [88.80055237, 21.91749954], [88.80082703, 21.91749954], [88.80110931, 21.91721916], [88.8013916, 21.91722298], [88.80166626, 21.9169445], [88.80194092, 21.9169445], [88.80278015, 21.91611099], [88.80249786, 21.91583061], [88.80278015, 21.91555786], [88.80305481, 21.91555786], [88.80388641, 21.91472244], [88.80388641, 21.91444588], [88.80500031, 21.9133358], [88.80500031, 21.91305733], [88.80526733, 21.91278076], [88.80526733, 21.91250992], [88.80555725, 21.91222], [88.80555725, 21.91194344], [88.80610657, 21.9113903], [88.80610657, 21.91110992], [88.80666351, 21.91055489], [88.80666351, 21.91027832], [88.80705261, 21.90988922], [88.8077774, 21.90916634], [88.8077774, 21.90888977], [88.80983734, 21.90682983], [88.81194305, 21.90472221], [88.81222534, 21.90472221], [88.81361389, 21.90333366], [88.8133316, 21.90305519], [88.81388855, 21.90306091], [88.81416321, 21.90278053], [88.81416321, 21.90250015], [88.81388855, 21.90221977], [88.81388855, 21.90194511], [88.81445313, 21.90139008], [88.81360626, 21.90055084], [88.81361389, 21.90027618], [88.81276703, 21.89944077], [88.8125, 21.89944649], [88.81222534, 21.8991642], [88.81223297, 21.89888954], [88.81098175, 21.89764214], [88.81027985, 21.89694214], [88.80999756, 21.89694214], [88.80999756, 21.89666748], [88.80860901, 21.89528275], [88.80860901, 21.89389038], [88.8088913, 21.89361191], [88.8088913, 21.89250183], [88.80860901, 21.89222145], [88.80860901, 21.89027977], [88.80832672, 21.88999748], [88.80832672, 21.88982964], [88.80833435, 21.88916779], [88.80860901, 21.88889122], [88.80860901, 21.88582993], [88.80833435, 21.88555336], [88.80832672, 21.88500023], [88.80805206, 21.88471985], [88.80805206, 21.88444328], [88.80750275, 21.88389015], [88.80750275, 21.88360977], [88.80666351, 21.88277817], [88.80639648, 21.88278008], [88.80602264, 21.88241005], [88.80527496, 21.88166618], [88.80500031, 21.88167191], [88.80473328, 21.88138962], [88.80444336, 21.88138962], [88.8041687, 21.88111115], [88.80388641, 21.88111115], [88.8033371, 21.88056183], [88.80304718, 21.88056183], [88.80194092, 21.8794384], [88.80166626, 21.87944412], [88.8013916, 21.87916756], [88.80110931, 21.87916946], [88.80082703, 21.87888908], [88.80027008, 21.87888908], [88.80000305, 21.87861061], [88.79915619, 21.87861061], [88.79888916, 21.87832832], [88.7986145, 21.87833405], [88.79777527, 21.87750053], [88.79750061, 21.87750053], [88.79666901, 21.87667084], [88.79666901, 21.87610817], [88.79638672, 21.87583351], [88.79638672, 21.87555695], [88.79611206, 21.87528038], [88.79611206, 21.875], [88.79582977, 21.87471962], [88.79582977, 21.87444687], [88.79556274, 21.8741703], [88.79555511, 21.87376022], [88.79555511, 21.87361145], [88.79528046, 21.87333298], [88.79528046, 21.87277985], [88.79499817, 21.87249947], [88.79499817, 21.87222099], [88.79472351, 21.87194443], [88.79472351, 21.87138939], [88.79416656, 21.87083054], [88.79416656, 21.87000084], [88.79389191, 21.86972046], [88.79389191, 21.86916733], [88.79360962, 21.86889076], [88.79360962, 21.86861038], [88.79332733, 21.86833191], [88.79333496, 21.86805534], [88.79277802, 21.86750031], [88.79277802, 21.86720848], [88.79083252, 21.86527824], [88.79055786, 21.86528015], [88.7902832, 21.86499977], [88.79000092, 21.86499977], [88.78971863, 21.86471748], [88.78806305, 21.86471748], [88.78778076, 21.86499977], [88.78749847, 21.86499977], [88.78694153, 21.86555481], [88.78694153, 21.86611176], [88.78721619, 21.86639023], [88.78722382, 21.86694527], [88.78749847, 21.86720848], [88.78749847, 21.86750031], [88.78778076, 21.86750031], [88.78971863, 21.86944389], [88.79000092, 21.86944389], [88.79027557, 21.86972237], [88.79055786, 21.86972046], [88.79083252, 21.87000084], [88.79110718, 21.87000084], [88.79250336, 21.87138939], [88.79250336, 21.87166405], [88.79277802, 21.87194443], [88.79277802, 21.87222099], [88.79332733, 21.87277985], [88.79333496, 21.87388611], [88.79360199, 21.87416077], [88.79360962, 21.87528038], [88.79332733, 21.87556076], [88.79332733, 21.87639809], [88.79305267, 21.87666893], [88.79305267, 21.87694359], [88.79277802, 21.87721825], [88.79277802, 21.87750053], [88.79250336, 21.87778091], [88.79250336, 21.87805939], [88.79194641, 21.87861061], [88.79165649, 21.87861061], [88.79139709, 21.87888908], [88.79110718, 21.87888908], [88.79083252, 21.87916946], [88.78944397, 21.87916756], [88.78916931, 21.87944412], [88.78833008, 21.87944412], [88.78805542, 21.87916756], [88.78749847, 21.87916946], [88.78721619, 21.87888908], [88.78694153, 21.87888908], [88.78666687, 21.87861061], [88.78639221, 21.87861061], [88.78527069, 21.87750053], [88.78527069, 21.87724113], [88.78472137, 21.87667084], [88.78444672, 21.87667084], [88.78444672, 21.87639809], [88.78388977, 21.8758297], [88.78388977, 21.87555695], [88.78360748, 21.87528038], [88.78360748, 21.875], [88.78305817, 21.87445068], [88.78277588, 21.87445068], [88.78277588, 21.8741703], [88.78193665, 21.87334061], [88.78193665, 21.87306023], [88.77916718, 21.87026978], [88.77889252, 21.8702774], [88.77833557, 21.86972237], [88.77777863, 21.86972237], [88.7775116, 21.86960983], [88.77694702, 21.8694706], [88.77639008, 21.86972237], [88.77610779, 21.86972046], [88.77583313, 21.87000084], [88.77583313, 21.87055588], [88.77555847, 21.87083054], [88.77555847, 21.87111092], [88.77500153, 21.87166405], [88.77500153, 21.87194443], [88.77471924, 21.87222099], [88.77471924, 21.87277985], [88.77444458, 21.8730545], [88.77443695, 21.87360954], [88.77416992, 21.87388992], [88.77416992, 21.87444687], [88.77388763, 21.87471962], [88.77388763, 21.87528038], [88.77361298, 21.87555695], [88.77361298, 21.87589073], [88.77361298, 21.87610817], [88.77305603, 21.87666893], [88.77305603, 21.87693977], [88.77194214, 21.87805939], [88.77111053, 21.87805557], [88.77083588, 21.87833405], [88.77054596, 21.87832832], [88.7702713, 21.87861061], [88.76972198, 21.87861061], [88.76944733, 21.87888908], [88.76917267, 21.87888908], [88.76889038, 21.87916946], [88.76833344, 21.87916756], [88.76805878, 21.87944412], [88.76777649, 21.87944412], [88.76667023, 21.87833405], [88.76638794, 21.87832832], [88.76611328, 21.87861061], [88.76444244, 21.87861061], [88.76416779, 21.87888908], [88.76361084, 21.87888908], [88.76333618, 21.87916946], [88.76265717, 21.87916756], [88.76194763, 21.87916756], [88.76166534, 21.87944412], [88.76083374, 21.87944412], [88.76055908, 21.8797226], [88.7591629, 21.87972069], [88.75888824, 21.88000107], [88.7583313, 21.88000107], [88.75805664, 21.88027763], [88.75805664, 21.88083267], [88.75777435, 21.88111115], [88.75777435, 21.88333321], [88.75805664, 21.88360977], [88.75805664, 21.88500023], [88.75776672, 21.88528061], [88.75777435, 21.88555336], [88.75749969, 21.88582993], [88.75749969, 21.88639069], [88.75722504, 21.88638878], [88.75666809, 21.88694382], [88.7563858, 21.88694382], [88.75611115, 21.88722229], [88.7555542, 21.88722229], [88.75528717, 21.88750076], [88.75499725, 21.88750076], [88.7547226, 21.88778114], [88.75417328, 21.88778114], [88.75389099, 21.88805962], [88.75314331, 21.88805771], [88.75250244, 21.88805962], [88.75222778, 21.88833809], [88.75166321, 21.88833809], [88.75138855, 21.88861084], [88.7508316, 21.88861084], [88.75055695, 21.88889122], [88.75055695, 21.88916779], [88.75026703, 21.88944054], [88.75026703, 21.89027977], [88.75, 21.89055634], [88.75, 21.89138031], [88.75027466, 21.89166641], [88.75026703, 21.89222145], [88.75055695, 21.89250183], [88.75055695, 21.89340019], [88.75055695, 21.89361191], [88.7508316, 21.89389038], [88.7508316, 21.89416695], [88.75055695, 21.8944416], [88.75055695, 21.8955555], [88.75026703, 21.89583015], [88.75026703, 21.89611053], [88.75, 21.89639091], [88.74972534, 21.89638901], [88.74888611, 21.89722252], [88.74861145, 21.89722061], [88.74833679, 21.89751053], [88.74804687, 21.89751053], [88.74749756, 21.89805984], [88.7472229, 21.89805412], [88.74694824, 21.8983326], [88.74666595, 21.89833069], [88.7463913, 21.89861107], [88.74610138, 21.89861107], [88.74582672, 21.89888954], [88.74555206, 21.89888954], [88.7452774, 21.89916992], [88.74500275, 21.8991642], [88.74472046, 21.89944649], [88.74416351, 21.89944649], [88.74388885, 21.89972305], [88.74333191, 21.89972115], [88.74305725, 21.89999962], [88.74194336, 21.89999962], [88.7416687, 21.90028], [88.74111176, 21.90027618], [88.7408371, 21.90055466], [88.74055481, 21.90055466], [88.74028015, 21.90027618], [88.73832703, 21.90028], [88.73805237, 21.89999962], [88.73527527, 21.89999962], [88.73500061, 21.89972305], [88.73443604, 21.89972115], [88.73416138, 21.89999962], [88.73332977, 21.89999962], [88.73320007, 21.89986992], [88.73305511, 21.89972305], [88.72915649, 21.89972115], [88.72888947, 21.89999962], [88.72860718, 21.89999962], [88.72833252, 21.90028], [88.72805786, 21.90027618], [88.72777557, 21.90055466], [88.72750092, 21.90055084], [88.72666931, 21.90139008], [88.72638702, 21.90139008], [88.72611237, 21.90167046], [88.72583008, 21.90167046], [88.72471619, 21.90278053], [88.72471619, 21.90306091], [88.72277832, 21.90500069], [88.72277832, 21.90527725], [88.72110748, 21.90694427], [88.72110748, 21.90722275], [88.71971893, 21.9086113], [88.71943665, 21.90860939], [88.71888733, 21.90916634], [88.71888733, 21.90989113], [88.71888733, 21.91027832], [88.71861267, 21.91055489], [88.71861267, 21.91083336], [88.71833038, 21.91111183], [88.71833038, 21.91222], [88.71778107, 21.91278076], [88.71778107, 21.91389084], [88.71749878, 21.9141655], [88.71749878, 21.91444588], [88.71721649, 21.91472054], [88.71721649, 21.91611099], [88.71694183, 21.91638947], [88.71694183, 21.91749954], [88.71666718, 21.91777992], [88.71694183, 21.91805649], [88.71694183, 21.91860771], [88.71722412, 21.91888809], [88.71721649, 21.91950035], [88.71721649, 21.9197216], [88.71749878, 21.92000008], [88.71749878, 21.92194366], [88.71778107, 21.92222023], [88.71778107, 21.9227829], [88.71806335, 21.92305946], [88.71805573, 21.92444229], [88.71833038, 21.92472076], [88.71833038, 21.92500114], [88.71861267, 21.92527962], [88.71861267, 21.92555428], [88.71888733, 21.92583084], [88.71888733, 21.92611122], [88.71916962, 21.92638969], [88.71916962, 21.92694664], [88.72027588, 21.92805481], [88.72027588, 21.92833328], [88.72055817, 21.92860985], [88.72055817, 21.92917061], [88.72083282, 21.92944527], [88.72083282, 21.92971992], [88.72110748, 21.93000031], [88.72110748, 21.93054962], [88.72174072, 21.93117905], [88.72194672, 21.93139076], [88.72277832, 21.93139076], [88.72305298, 21.93166924], [88.72333527, 21.93166733], [88.72360992, 21.93194389]]], [[[88.98610687, 22.10170364], [88.98631287, 22.10217094], [88.98645782, 22.10266113], [88.98667145, 22.10313225], [88.98690796, 22.10359001], [88.98713684, 22.10407066], [88.98742676, 22.10447121], [88.98770142, 22.1048584], [88.98783112, 22.1052494], [88.98786163, 22.1053524], [88.98806763, 22.10583305], [88.98828125, 22.10630417], [88.98841095, 22.10684013], [88.98860931, 22.10733795], [88.98880768, 22.10784149], [88.98896027, 22.10839081], [88.98916626, 22.10892296], [88.98944092, 22.10944557], [88.98967743, 22.10999489], [88.98980713, 22.11061287], [88.99002075, 22.11112022], [88.99025726, 22.11148834], [88.99043274, 22.11182976], [88.99057007, 22.11213684], [88.99072266, 22.11240005], [88.99079895, 22.1127224], [88.99087524, 22.11305046], [88.99105072, 22.1133213], [88.99114227, 22.11369324], [88.99128723, 22.1140995], [88.99141693, 22.11462975], [88.9916687, 22.11515236], [88.99194336, 22.1156826], [88.99220276, 22.11623192], [88.99237823, 22.11683273], [88.99252319, 22.11745262], [88.9927063, 22.11802864], [88.99298859, 22.11853981], [88.99330139, 22.11903191], [88.99355316, 22.11957932], [88.99378967, 22.12013626], [88.99394226, 22.12078476], [88.99416351, 22.12139702], [88.99442291, 22.12200165], [88.99465179, 22.12262154], [88.99479675, 22.12325287], [88.99497223, 22.12371826], [88.99500275, 22.12389374], [88.99500275, 22.1241703], [88.9952774, 22.12444305], [88.9952774, 22.12471962], [88.99555206, 22.12500191], [88.99555206, 22.12583351], [88.99581909, 22.12610054], [88.99583435, 22.12666512], [88.99610901, 22.12693977], [88.99610138, 22.1272831], [88.99610138, 22.12750053], [88.99610901, 22.12778282], [88.99616241, 22.12828255], [88.99633789, 22.12870026], [88.99639893, 22.12915993], [88.99646759, 22.12962914], [88.99662018, 22.13009262], [88.99671173, 22.1306324], [88.99682617, 22.13117027], [88.99687195, 22.13174248], [88.99671173, 22.13229942], [88.99666595, 22.13287163], [88.99668121, 22.13343239], [88.99677277, 22.1339817], [88.99690247, 22.13451958], [88.99694061, 22.13511658], [88.99694824, 22.13570976], [88.99694824, 22.13632011], [88.99694061, 22.13691139], [88.99694061, 22.13749123], [88.99694061, 22.13802719], [88.99690247, 22.13848305], [88.99672699, 22.1388607], [88.99666595, 22.13922119], [88.99663544, 22.13962746], [88.99661255, 22.14011955], [88.99643707, 22.14065933], [88.99633789, 22.14127159], [88.99610901, 22.14177132], [88.99594879, 22.14225006], [88.99582672, 22.14273262], [88.99569702, 22.14318275], [88.99555206, 22.14362144], [88.99537659, 22.14408302], [88.99524689, 22.14463234], [88.99504089, 22.14521217], [88.99491882, 22.14587975], [88.9947052, 22.14646339], [88.9944458, 22.14697075], [88.99424744, 22.14744186], [88.99411774, 22.14787102], [88.99394989, 22.1482048], [88.99385834, 22.14855003], [88.99369812, 22.14880943], [88.99353027, 22.14905357], [88.99337006, 22.14932251], [88.99323273, 22.14967155], [88.99302673, 22.15003014], [88.99279022, 22.15041351], [88.99256134, 22.15083885], [88.99233246, 22.15128136], [88.99214172, 22.15175056], [88.9919281, 22.15221977], [88.99166107, 22.15265465], [88.9913559, 22.15310478], [88.99108124, 22.1536274], [88.9907608, 22.15413475], [88.99040985, 22.15459251], [88.99006653, 22.15498161], [88.98977661, 22.1552906], [88.98954773, 22.15556145], [88.98935699, 22.15582085], [88.98916626, 22.15604973], [88.98899841, 22.15629768], [88.98883057, 22.15659142], [88.98860168, 22.15686989], [88.98833466, 22.15717888], [88.98806763, 22.15752029], [88.9878006, 22.15789032], [88.98754883, 22.15827179], [88.98726654, 22.15863228], [88.98696136, 22.15900993], [88.98664093, 22.15941048], [88.98625183, 22.15977287], [88.98590851, 22.16019249], [88.98548126, 22.16058159], [88.98506165, 22.16106224], [88.98458099, 22.16155052], [88.98407745, 22.1620388], [88.98356628, 22.16249275], [88.98310852, 22.16291046], [88.98277283, 22.1633625], [88.98240662, 22.16377068], [88.98203278, 22.16415977], [88.98159027, 22.16452217], [88.98110199, 22.16485977], [88.98060608, 22.1652317], [88.98015594, 22.16567039], [88.97970581, 22.1661129], [88.97918701, 22.16649055], [88.97871399, 22.16689873], [88.97824097, 22.16731071], [88.97779846, 22.16775131], [88.97737885, 22.16818047], [88.97701263, 22.16864967], [88.97670746, 22.1691227], [88.97642517, 22.16955757], [88.97621918, 22.17002678], [88.9760437, 22.1705246], [88.97584534, 22.17102051], [88.97569275, 22.17152977], [88.97556305, 22.17206764], [88.97544861, 22.17256927], [88.97522736, 22.17300224], [88.97501373, 22.1734333], [88.97483826, 22.17391205], [88.97471619, 22.17443275], [88.97459412, 22.17495918], [88.97441101, 22.17544365], [88.97424316, 22.1759243], [88.97415161, 22.1764431], [88.97402954, 22.17694473], [88.9739151, 22.17743683], [88.97389221, 22.17798042], [88.97386932, 22.1785717], [88.97379303, 22.17917442], [88.97373962, 22.17980385], [88.97383118, 22.18040466], [88.97374725, 22.18095207], [88.97358704, 22.18148232], [88.97342682, 22.1819725], [88.9733429, 22.18244934], [88.97332764, 22.18293953], [88.9733429, 22.18343353], [88.9733429, 22.18388748], [88.97333527, 22.18432808], [88.97333527, 22.18647957], [88.9733429, 22.18713951], [88.97333527, 22.18780518], [88.9733429, 22.18844032], [88.97328949, 22.18901634], [88.97312164, 22.18950081], [88.97306061, 22.18996811], [88.97305298, 22.19043159], [88.9730072, 22.19089127], [88.9728775, 22.1913147], [88.97279358, 22.19175148], [88.97277832, 22.19219971], [88.97277069, 22.19264221], [88.9727478, 22.19305229], [88.97268677, 22.19343758], [88.97296143, 22.19381142], [88.97309113, 22.19385719], [88.9734726, 22.19399071], [88.97409058, 22.19392014], [88.97475433, 22.19389534], [88.97544861, 22.19388771], [88.97612, 22.19384193], [88.97673035, 22.19367981], [88.9773407, 22.19374275], [88.97795105, 22.19386292], [88.97859192, 22.19389534], [88.97926331, 22.19395256], [88.97991943, 22.19407272], [88.98055267, 22.19416237], [88.98116302, 22.19426155], [88.98167419, 22.19442558], [88.98220062, 22.19456482], [88.98272705, 22.19473839], [88.98324585, 22.19496155], [88.98384857, 22.19511223], [88.98442841, 22.19532394], [88.98496246, 22.19556236], [88.98543549, 22.19580269], [88.98590088, 22.19592094], [88.98629761, 22.19608307], [88.98670959, 22.19618034], [88.98707581, 22.19637871], [88.98750305, 22.19656372], [88.98796844, 22.19675255], [88.98844147, 22.19695854], [88.98890686, 22.19721413], [88.98938751, 22.19745255], [88.98982239, 22.1977253], [88.99030304, 22.19791222], [88.9907608, 22.19808006], [88.99124146, 22.1982708], [88.99179077, 22.19838715], [88.99236298, 22.19857216], [88.99304199, 22.19865417], [88.99372864, 22.19885254], [88.99447632, 22.19893456], [88.99475861, 22.1989975], [88.99518585, 22.19908905], [88.99589539, 22.19897461], [88.99656677, 22.19912148], [88.99720764, 22.19916916], [88.99775696, 22.19921303], [88.99819946, 22.19932747], [88.99891663, 22.19937325], [88.99945831, 22.19927025], [89.0, 22.19916725], [89.00051117, 22.19935226], [89.00068665, 22.19936562], [89.0009079, 22.19938087], [89.00114441, 22.19930077], [89.00138092, 22.19922447], [89.00193024, 22.19917107], [89.00251007, 22.19916916], [89.00309753, 22.19916916], [89.00366974, 22.19913483], [89.00418854, 22.19892311], [89.00469971, 22.19876289], [89.00518036, 22.19862175], [89.00563812, 22.19851112], [89.00605774, 22.19835281], [89.00649261, 22.19822121], [89.00689697, 22.19807243], [89.00733948, 22.19794273], [89.00775146, 22.19778252], [89.00819397, 22.19764328], [89.0086441, 22.1974926], [89.00908661, 22.19731712], [89.00955963, 22.19719124], [89.00997162, 22.19698334], [89.01039886, 22.19681931], [89.01080322, 22.19664955], [89.01116943, 22.19643211], [89.01163483, 22.19634819], [89.01209259, 22.19614029], [89.01258087, 22.1960125], [89.01302338, 22.19582176], [89.01338959, 22.19554329], [89.01368713, 22.1951828], [89.01390076, 22.19473076], [89.01410675, 22.19426155], [89.01418304, 22.19370079], [89.01425934, 22.19313812], [89.01441193, 22.19263458], [89.01444244, 22.19214058], [89.01445007, 22.19168282], [89.01445007, 22.19123268], [89.01444244, 22.19079208], [89.01439667, 22.19035149], [89.01421356, 22.18995857], [89.01418304, 22.18951225], [89.01412964, 22.18906975], [89.01397705, 22.18868065], [89.01390076, 22.18829155], [89.0138855, 22.18787956], [89.0138855, 22.18742561], [89.01389313, 22.18693352], [89.0138855, 22.18642426], [89.01384735, 22.18593025], [89.01365662, 22.18549156], [89.01361084, 22.18499184], [89.01360321, 22.18448067], [89.01352692, 22.18399239], [89.0133667, 22.18354225], [89.01329041, 22.1830883], [89.01309967, 22.18268013], [89.01305389, 22.18220139], [89.01300812, 22.18168449], [89.01286316, 22.18118858], [89.01300049, 22.1807003], [89.01305389, 22.18024063], [89.01303864, 22.17980003], [89.01294708, 22.17935181], [89.01280975, 22.17884827], [89.01277924, 22.17833328], [89.01277924, 22.17638969], [89.01304626, 22.17611122], [89.01304626, 22.17556381], [89.01328278, 22.17529106], [89.01332855, 22.17479134], [89.01333618, 22.17424011], [89.0134201, 22.17369843], [89.01357269, 22.17319107], [89.01361084, 22.17270851], [89.01361847, 22.17226219], [89.01366425, 22.17186356], [89.01382446, 22.1715107], [89.01393127, 22.17107391], [89.01415253, 22.17062187], [89.01434326, 22.17006874], [89.01442719, 22.16938972], [89.01444244, 22.16866112], [89.0144577, 22.16794968], [89.01454163, 22.16731071], [89.01467896, 22.16679573], [89.01472473, 22.16666412], [89.0147171, 22.16639137], [89.01444244, 22.1661129], [89.01444244, 22.16444206], [89.01472473, 22.1641674], [89.0147171, 22.16361046], [89.01499939, 22.16333389], [89.01499939, 22.16250038], [89.01526642, 22.16220856], [89.01528931, 22.16165733], [89.01535797, 22.16121101], [89.01551819, 22.1607914], [89.01558685, 22.16033936], [89.01579285, 22.15995216], [89.01586914, 22.15950203], [89.01603699, 22.15908813], [89.01618958, 22.15865517], [89.0164032, 22.15821266], [89.01667023, 22.15775108], [89.01693726, 22.15727425], [89.0171814, 22.15678978], [89.01734161, 22.15629005], [89.01753235, 22.15587044], [89.0177536, 22.15554428], [89.01791382, 22.15514946], [89.01809692, 22.15472221], [89.01834869, 22.15427017], [89.01863098, 22.15381432], [89.0189743, 22.15337944], [89.01937866, 22.15298271], [89.0196991, 22.15253258], [89.02001953, 22.15207291], [89.02031708, 22.15166473], [89.02059174, 22.1512394], [89.02085114, 22.15081978], [89.02194214, 22.14972115], [89.02194214, 22.14916611], [89.0222168, 22.14888954], [89.0222168, 22.14861107], [89.02242279, 22.14836311], [89.02275848, 22.14821434], [89.02309418, 22.14806938], [89.02340698, 22.14796257], [89.02368164, 22.14777946], [89.02397156, 22.1475811], [89.02436066, 22.14743805], [89.02475739, 22.14720917], [89.025177, 22.14695168], [89.02561951, 22.14668274], [89.02606964, 22.14641571], [89.02651215, 22.14608955], [89.02694702, 22.14570236], [89.02744293, 22.14531136], [89.02800751, 22.14500237], [89.02861023, 22.14470673], [89.02916718, 22.14434242], [89.02971649, 22.14398384], [89.03025818, 22.14364052], [89.03082275, 22.14334297], [89.03137207, 22.14306068], [89.03190613, 22.14279938], [89.03238678, 22.14251137], [89.0328598, 22.14223289], [89.03329468, 22.14197159], [89.03371429, 22.14167976], [89.03417206, 22.14138985], [89.0346756, 22.14114571], [89.03518677, 22.14084053], [89.03572845, 22.14055443], [89.03627777, 22.14027977], [89.03682709, 22.1400013], [89.03736877, 22.13975334], [89.03791809, 22.13954735], [89.03839874, 22.13924217], [89.03890228, 22.13900185], [89.03940582, 22.13880539], [89.03988647, 22.13857079], [89.04033661, 22.1382885], [89.04080963, 22.13802147], [89.04128265, 22.13775063], [89.04173279, 22.13744164], [89.04220581, 22.13718033], [89.04266357, 22.13692284], [89.04307556, 22.13664818], [89.04345703, 22.13638115], [89.04383087, 22.13610268], [89.04418945, 22.1358223], [89.04456329, 22.13554955], [89.0449295, 22.13529015], [89.04533386, 22.1350975], [89.04577637, 22.13496971], [89.04619598, 22.13475227], [89.04664612, 22.13459969], [89.04709625, 22.13440132], [89.04751587, 22.13415527], [89.04792023, 22.13388252], [89.04831696, 22.13356972], [89.04870605, 22.1332531], [89.04911041, 22.13291931], [89.04943848, 22.1325016], [89.04972839, 22.13209343], [89.04999542, 22.13174629], [89.05021667, 22.13142967], [89.05034637, 22.13105011], [89.05047607, 22.1306324], [89.05031586, 22.13018227], [89.05012512, 22.12967873], [89.04995728, 22.12910843], [89.04972076, 22.12862206], [89.04946136, 22.12817955], [89.04924774, 22.12777519], [89.04904938, 22.12740135], [89.04878235, 22.12709618], [89.04854584, 22.1267128], [89.04824066, 22.126297], [89.04788971, 22.12581253], [89.04749298, 22.12526131], [89.04702759, 22.12469292], [89.04659271, 22.12410164], [89.04615784, 22.12354469], [89.04574585, 22.12298393], [89.04528809, 22.12248421], [89.0448761, 22.12196922], [89.04447937, 22.12151146], [89.04415894, 22.12104034], [89.04388428, 22.12064171], [89.04360962, 22.12029076], [89.04332733, 22.1199398], [89.04303741, 22.11956978], [89.04268646, 22.1192112], [89.04226685, 22.11888313], [89.04187775, 22.11852455], [89.04152679, 22.11808968], [89.04115295, 22.11770058], [89.04084015, 22.11732674], [89.04055786, 22.1169796], [89.04029083, 22.11666298], [89.04001617, 22.11634254], [89.03972626, 22.11597824], [89.0394516, 22.11556435], [89.03916931, 22.11513329], [89.03889465, 22.11473274], [89.03866577, 22.11438179], [89.03849792, 22.11405945], [89.03832245, 22.11379814], [89.03813934, 22.11356163], [89.03798676, 22.11328316], [89.03777313, 22.11301231], [89.0375061, 22.1127224], [89.03723145, 22.11235237], [89.03692627, 22.11194038], [89.03656006, 22.11156845], [89.03616333, 22.11127663], [89.0358429, 22.11095238], [89.03556061, 22.11066818], [89.03526306, 22.11047173], [89.03475952, 22.11046791], [89.03410339, 22.11074638], [89.03348541, 22.11094093], [89.03305054, 22.11087608], [89.03247833, 22.11087608], [89.03218842, 22.11094475], [89.0318985, 22.11087608], [89.03147125, 22.11088181], [89.03103638, 22.11108017], [89.03060913, 22.11121178], [89.0300293, 22.11114311], [89.02931213, 22.11114311], [89.02857971, 22.11124992], [89.02802277, 22.11122131], [89.02745056, 22.11134148], [89.02688599, 22.11141014], [89.02636719, 22.11139107], [89.02587128, 22.11136818], [89.025383, 22.11133003], [89.02485657, 22.11136055], [89.02435303, 22.11141014], [89.0238266, 22.11147118], [89.02333069, 22.11158943], [89.02287292, 22.11163712], [89.02243805, 22.11165047], [89.02201843, 22.11166382], [89.02158356, 22.11166954], [89.02110291, 22.1117115], [89.02060699, 22.11185265], [89.02005768, 22.11199188], [89.01953125, 22.11219025], [89.01899719, 22.11237144], [89.01844788, 22.1125412], [89.01789856, 22.11275291], [89.01734924, 22.11294937], [89.01686096, 22.11321831], [89.01654816, 22.11363411], [89.01629639, 22.11419296], [89.01637268, 22.11494255], [89.0170517, 22.11535072], [89.01743317, 22.11551094], [89.01807404, 22.11551094], [89.01856995, 22.11565971], [89.01901245, 22.11584282], [89.01943207, 22.11604118], [89.01989746, 22.11617088], [89.02035522, 22.11631012], [89.02081299, 22.11638069], [89.02125549, 22.11645889], [89.02165985, 22.11659431], [89.02206421, 22.11668396], [89.02245331, 22.11680031], [89.02282715, 22.11699104], [89.02322388, 22.11720657], [89.02365875, 22.11743927], [89.02411652, 22.11770058], [89.02462769, 22.1179142], [89.02519226, 22.11807251], [89.02574921, 22.11824226], [89.02628326, 22.11841774], [89.02680206, 22.11863136], [89.02735138, 22.11886024], [89.02794647, 22.11907005], [89.02858734, 22.11920738], [89.02919006, 22.11936378], [89.02970123, 22.11952019], [89.03006744, 22.1197567], [89.03029633, 22.12001228], [89.03048706, 22.12027168], [89.03061676, 22.12056351], [89.03077698, 22.12082672], [89.03089905, 22.12115288], [89.03098297, 22.12154961], [89.03088379, 22.12200737], [89.03055573, 22.12246895], [89.03012848, 22.12294197], [89.02942657, 22.12290382], [89.02935028, 22.12270164], [89.0296402, 22.12236977], [89.02993011, 22.12196159], [89.02978516, 22.1211586], [89.02935028, 22.12068939], [89.02885437, 22.12054634], [89.02842712, 22.12038994], [89.02799988, 22.12030411], [89.02751923, 22.12029076], [89.02697754, 22.12026024], [89.02632904, 22.12001801], [89.02559662, 22.11977959], [89.02484894, 22.1195507], [89.02410889, 22.11930275], [89.0234375, 22.11898232], [89.02279663, 22.11861229], [89.02214813, 22.11825752], [89.021492, 22.11794281], [89.02083588, 22.11770058], [89.02026367, 22.11745262], [89.01980591, 22.11721992], [89.01940918, 22.11704063], [89.01905823, 22.11693001], [89.01889038, 22.1169529], [89.01764679, 22.11661148], [89.01667023, 22.11610985], [89.01615143, 22.11574554], [89.01567078, 22.11541176], [89.01522827, 22.11498642], [89.0148468, 22.11452866], [89.01464844, 22.11400795], [89.01465607, 22.11351013], [89.01489258, 22.11310005], [89.01526642, 22.1127491], [89.01571655, 22.11238289], [89.01628876, 22.11207771], [89.01692963, 22.11182213], [89.01758575, 22.11157417], [89.01824951, 22.11130714], [89.01862335, 22.11124992], [89.01920319, 22.11118317], [89.0194931, 22.11112022], [89.01998901, 22.11098289], [89.0203476, 22.11085129], [89.02107239, 22.1108532], [89.02164459, 22.11058235], [89.0222168, 22.11044884], [89.02279663, 22.11045265], [89.02336884, 22.11032295], [89.02416229, 22.11025047], [89.02452087, 22.11025047], [89.02516174, 22.11032295], [89.02774811, 22.11032295], [89.02818298, 22.11011314], [89.02880096, 22.11012077], [89.02971649, 22.11018944], [89.03044128, 22.11018944], [89.03100586, 22.11012077], [89.0318985, 22.10993195], [89.03263092, 22.10969925], [89.03334808, 22.10965919], [89.03404999, 22.10960197], [89.0348587, 22.1097126], [89.03534698, 22.10959053], [89.03553009, 22.10929489], [89.03556061, 22.1089077], [89.03556061, 22.10848045], [89.03555298, 22.10804176], [89.03547668, 22.10760307], [89.03531647, 22.10717392], [89.03527832, 22.10673141], [89.03524017, 22.10629082], [89.03509521, 22.10591507], [89.03501129, 22.10553169], [89.03500366, 22.10512733], [89.0349884, 22.10469246], [89.03495789, 22.10422325], [89.034729, 22.10377121], [89.03447723, 22.10327911], [89.03425598, 22.10274124], [89.03410339, 22.10217094], [89.03388214, 22.1016407], [89.03366089, 22.10117149], [89.03361511, 22.10062981], [89.03356934, 22.10006905], [89.03340149, 22.09951973], [89.03329468, 22.09890175], [89.03305817, 22.09834099], [89.03282166, 22.09777451], [89.03272247, 22.09712029], [89.03277588, 22.09694481], [89.03250122, 22.09666634], [89.03250122, 22.09612083], [89.03221893, 22.09583282], [89.03221893, 22.09555626], [89.03192902, 22.09528351], [89.03192902, 22.09500122], [89.03166962, 22.09472275], [89.03166962, 22.09444427], [89.03111267, 22.09388924], [89.03111267, 22.09333229], [89.03138733, 22.09305573], [89.03138733, 22.09277916], [89.03161621, 22.09227943], [89.03166962, 22.09178352], [89.03166962, 22.0913372], [89.03170013, 22.09092331], [89.03183746, 22.09050941], [89.03192139, 22.09004021], [89.0318985, 22.08952141], [89.03173065, 22.08900452], [89.03166962, 22.08842278], [89.03166199, 22.08778954], [89.03166962, 22.08710289], [89.03172302, 22.08638191], [89.0318985, 22.0857029], [89.03192902, 22.08503151], [89.03194427, 22.08446312], [89.03192902, 22.08401108], [89.03196716, 22.08366013], [89.03206635, 22.08337212], [89.03212738, 22.08307076], [89.03223419, 22.08272362], [89.03239441, 22.08230019], [89.03248596, 22.08176994], [89.03250122, 22.08121681], [89.03250122, 22.0807209], [89.03253174, 22.08031273], [89.03263855, 22.07999229], [89.03275299, 22.07969093], [89.03277588, 22.0793457], [89.03282166, 22.07892609], [89.03302002, 22.07846832], [89.0331192, 22.0779438], [89.03333282, 22.07749748], [89.03356171, 22.07710266], [89.03372192, 22.07670021], [89.03388214, 22.07634163], [89.03401184, 22.07599068], [89.03414154, 22.07563972], [89.03423309, 22.07526207], [89.03440094, 22.07494164], [89.03443909, 22.07455254], [89.03444672, 22.07416534], [89.0344696, 22.0737896], [89.03460693, 22.07342911], [89.03470612, 22.07299805], [89.03475952, 22.07250786], [89.03491974, 22.0720005], [89.0349884, 22.07143974], [89.03510284, 22.07090378], [89.0352478, 22.07042122], [89.03527832, 22.06996727], [89.03531647, 22.06955147], [89.03548431, 22.06920242], [89.03557587, 22.06875801], [89.03573608, 22.06828117], [89.03585815, 22.06773949], [89.03607178, 22.06720161], [89.03614044, 22.0666256], [89.03626251, 22.06611061], [89.03638458, 22.0656929], [89.03649902, 22.06531525], [89.03663635, 22.06496239], [89.03666687, 22.06453133], [89.03675079, 22.0640316], [89.03690338, 22.06352425], [89.0369873, 22.06294441], [89.03717804, 22.06244087], [89.0372467, 22.06195831], [89.03742981, 22.06155968], [89.03752899, 22.06112099], [89.0377121, 22.06065941], [89.03781891, 22.06008911], [89.03806305, 22.05956268], [89.03829193, 22.05908966], [89.03846741, 22.05862808], [89.03858948, 22.05817986], [89.03862, 22.05769348], [89.03868866, 22.05716515], [89.03884888, 22.05661964], [89.03888702, 22.0560379], [89.03887177, 22.05545807], [89.03878784, 22.05490303], [89.03864288, 22.05437469], [89.0385437, 22.0538311], [89.03822327, 22.05339241], [89.03770447, 22.05310249], [89.03704834, 22.0530529], [89.03631592, 22.0530529], [89.03555298, 22.0530529], [89.03530121, 22.05305481], [89.03478241, 22.05306244], [89.03440857, 22.05305672], [89.03404236, 22.0530529], [89.03338623, 22.05301666], [89.03283691, 22.05286217], [89.03237915, 22.05278969], [89.03192902, 22.05278015], [89.03153229, 22.05278015], [89.03111267, 22.05278015], [89.03069305, 22.05278015], [89.03026581, 22.05278015], [89.02984619, 22.05278015], [89.02947235, 22.05278015], [89.02910614, 22.05282021], [89.02879333, 22.05297279], [89.02841187, 22.05307961], [89.0280304, 22.05326271], [89.02767181, 22.05352211], [89.02752686, 22.05410957], [89.02758026, 22.05480194], [89.02783203, 22.05540276], [89.02819061, 22.05586052], [89.02851868, 22.05628967], [89.02884674, 22.05668449], [89.02910614, 22.05713081], [89.02939606, 22.05759239], [89.02967072, 22.05809212], [89.02993011, 22.05862808], [89.02996826, 22.05912209], [89.02999115, 22.05979919], [89.02980804, 22.06040001], [89.02973175, 22.06105995], [89.02968597, 22.06170273], [89.02957153, 22.0622921], [89.02947235, 22.06286049], [89.02935791, 22.06339645], [89.02922821, 22.06388283], [89.02918243, 22.06434059], [89.02915955, 22.06476021], [89.02909088, 22.06515121], [89.02896118, 22.06553078], [89.02888489, 22.06601715], [89.02880096, 22.06658363], [89.02865601, 22.06718254], [89.02855682, 22.06781197], [89.02841187, 22.06837273], [89.02835846, 22.06891441], [89.02835083, 22.06942177], [89.02838135, 22.0699234], [89.02848816, 22.07045174], [89.02857208, 22.07104492], [89.02855682, 22.0716629], [89.02848053, 22.07225037], [89.02845001, 22.07281303], [89.02855682, 22.07336235], [89.02864838, 22.07394218], [89.02877045, 22.07452583], [89.02881622, 22.07513237], [89.02893066, 22.07569313], [89.02893066, 22.07621574], [89.02883148, 22.07673073], [89.02880096, 22.07713127], [89.02863312, 22.07761192], [89.02844238, 22.07804871], [89.02828979, 22.07859993], [89.02768707, 22.07915306], [89.0270462, 22.07930946], [89.02629852, 22.07916069], [89.02572632, 22.07894516], [89.02506256, 22.07886314], [89.02443695, 22.07878494], [89.02388, 22.078825], [89.02337646, 22.07878685], [89.02292633, 22.07863235], [89.02245331, 22.07852554], [89.02198792, 22.07837105], [89.02166748, 22.0783329], [89.02138519, 22.07805824], [89.02138519, 22.07777977], [89.0223465, 22.07770348], [89.02269745, 22.07784462], [89.02323151, 22.07776451], [89.02365112, 22.07777977], [89.02436829, 22.0779171], [89.02480316, 22.07798576], [89.02552032, 22.07798576], [89.0259552, 22.07805061], [89.02659607, 22.07805061], [89.02723694, 22.07792091], [89.02760315, 22.07777977], [89.02774811, 22.07744789], [89.02774811, 22.0769825], [89.02774811, 22.07604027], [89.02740479, 22.07557297], [89.02722931, 22.07504463], [89.02702332, 22.07452202], [89.02684784, 22.07401085], [89.02681732, 22.07349968], [89.02690887, 22.0730114], [89.02693939, 22.07248878], [89.02694702, 22.07190132], [89.02726746, 22.07115936], [89.02723694, 22.07055283], [89.02694702, 22.06982231], [89.02694702, 22.0690918], [89.02697754, 22.06837273], [89.02706146, 22.06770515], [89.02719116, 22.06711769], [89.02729797, 22.06658936], [89.02744293, 22.06612968], [89.0275116, 22.06567192], [89.02760315, 22.06522942], [89.02773285, 22.06480026], [89.02778625, 22.06432915], [89.02784729, 22.06382179], [89.02799225, 22.0633297], [89.02815247, 22.0630455], [89.02836609, 22.06264305], [89.02851105, 22.06224442], [89.02872467, 22.06184387], [89.02879333, 22.06150627], [89.02879333, 22.06097221], [89.02893829, 22.06050301], [89.02893829, 22.05956268], [89.02879333, 22.05916214], [89.02864838, 22.0588932], [89.02840424, 22.05866432], [89.0282135, 22.05809593], [89.02793121, 22.05755043], [89.02755737, 22.05702019], [89.0271759, 22.05643272], [89.02676392, 22.05589867], [89.02642059, 22.05529213], [89.02619934, 22.05464935], [89.02619171, 22.05399132], [89.02629089, 22.05336189], [89.02604675, 22.05293274], [89.0255661, 22.05265999], [89.02471161, 22.05273247], [89.02438354, 22.0527153], [89.02429199, 22.05271149], [89.02387238, 22.05271149], [89.02311707, 22.05257225], [89.02241516, 22.05245018], [89.02177429, 22.052248], [89.02111053, 22.05206108], [89.02056122, 22.05189514], [89.02011108, 22.05167961], [89.01970673, 22.05150986], [89.01931763, 22.05142021], [89.01892853, 22.05143166], [89.01854706, 22.05153084], [89.01820374, 22.05163002], [89.01789093, 22.05169487], [89.01763916, 22.05181313], [89.01741028, 22.05197716], [89.01721191, 22.05220413], [89.01700592, 22.05252457], [89.01687622, 22.05304146], [89.01673889, 22.05365944], [89.01669312, 22.05433083], [89.01673126, 22.05499077], [89.01687622, 22.0555706], [89.01695251, 22.05611229], [89.01699829, 22.05656242], [89.01713562, 22.05688667], [89.01725006, 22.05722237], [89.01738739, 22.05751991], [89.01750183, 22.05784798], [89.01761627, 22.05816078], [89.01774597, 22.05846977], [89.01781464, 22.05882072], [89.01792908, 22.05917168], [89.01802826, 22.05955315], [89.01805878, 22.05997276], [89.01805115, 22.0604229], [89.01802063, 22.06085777], [89.01790619, 22.06126213], [89.01779175, 22.06160545], [89.01769257, 22.06189156], [89.01755524, 22.06212807], [89.01742554, 22.06239128], [89.01724243, 22.06261253], [89.01700592, 22.06284142], [89.01679993, 22.06310081], [89.01657867, 22.06340218], [89.01628876, 22.06367493], [89.01590729, 22.06388283], [89.01552582, 22.06405258], [89.01526642, 22.06414223], [89.01519775, 22.06419945], [89.01499939, 22.06436729], [89.01472473, 22.06444359], [89.01429749, 22.06436729], [89.01418304, 22.06417274], [89.01389313, 22.06389046], [89.01364136, 22.06363106], [89.0133667, 22.0633049], [89.01304626, 22.06292152], [89.01265717, 22.06250191], [89.01226044, 22.06208229], [89.01190948, 22.06168175], [89.01161194, 22.06131935], [89.01138306, 22.06097984], [89.01119232, 22.06065941], [89.01106262, 22.06028175], [89.0109024, 22.05994225], [89.01081848, 22.05956459], [89.0107193, 22.05921364], [89.01059723, 22.05887794], [89.01049805, 22.05848122], [89.01035309, 22.05804062], [89.01023102, 22.05753708], [89.01008606, 22.0570507], [89.00998688, 22.0565815], [89.0098877, 22.05618286], [89.00977325, 22.05584145], [89.00970459, 22.05550957], [89.00961304, 22.05519295], [89.00948334, 22.05488014], [89.00933838, 22.05453491], [89.00915527, 22.05419731], [89.00895691, 22.05384254], [89.00879669, 22.05339241], [89.00860596, 22.05297279], [89.00836182, 22.05262184], [89.00799561, 22.05247116], [89.00762939, 22.05246162], [89.00731659, 22.05264091], [89.00710297, 22.05291939], [89.00691223, 22.05325127], [89.0067215, 22.0535717], [89.00654602, 22.05389977], [89.0063858, 22.05420876], [89.00621796, 22.05449295], [89.00602722, 22.05477905], [89.00579071, 22.05510139], [89.00556183, 22.05553818], [89.00530243, 22.05605125], [89.00498962, 22.05656242], [89.0046463, 22.05701447], [89.00437164, 22.05741119], [89.00418091, 22.05784035], [89.00393677, 22.05827141], [89.00363922, 22.0586853], [89.00331116, 22.05911446], [89.0029068, 22.05944443], [89.00248718, 22.05973244], [89.00209045, 22.05999947], [89.00170898, 22.06026459], [89.00106812, 22.06023598], [89.00070953, 22.0600338], [89.00056458, 22.05972099], [89.00026703, 22.05944252], [89.0, 22.05916405], [88.99961853, 22.05894279], [88.99919891, 22.0588398], [88.9987793, 22.05859947], [88.99835968, 22.05830193], [88.99797058, 22.05797005], [88.99758148, 22.05766106], [88.99707794, 22.0574398], [88.99658203, 22.05721283], [88.99608612, 22.05696297], [88.99562073, 22.05673027], [88.99520111, 22.05650711], [88.99474335, 22.0563488], [88.99424744, 22.05618286], [88.99365234, 22.05611992], [88.99301147, 22.05610275], [88.99250031, 22.05611229], [88.99238586, 22.05611229], [88.99111176, 22.05611229], [88.9908371, 22.05583191], [88.99028015, 22.05583191], [88.98988342, 22.05602837], [88.98949432, 22.05613518], [88.98913574, 22.05627632], [88.98878479, 22.05640221], [88.98844147, 22.05654335], [88.98806763, 22.05666351], [88.9876709, 22.05677986], [88.98722839, 22.05690193], [88.98674774, 22.05694771], [88.98625946, 22.05699158], [88.98578644, 22.0571003], [88.98529053, 22.05698204], [88.98483276, 22.0568409], [88.98447418, 22.05666733], [88.98419952, 22.05647087], [88.98400879, 22.05620766], [88.98387146, 22.05585289], [88.98369598, 22.05545807], [88.98358154, 22.05500031], [88.98345184, 22.0545311], [88.98355865, 22.05406761], [88.98361206, 22.05361176], [88.98365784, 22.05318832], [88.9838028, 22.05284309], [88.98387909, 22.05250168], [88.98396301, 22.05212975], [88.98410034, 22.05178261], [88.98421478, 22.05137634], [88.98439789, 22.05099106], [88.98449707, 22.05051994], [88.98465729, 22.0500679], [88.98470306, 22.04950142], [88.98468781, 22.04886818], [88.98462677, 22.04820061], [88.98464966, 22.04757881], [88.98455048, 22.04705048], [88.98445892, 22.04654121], [88.98438263, 22.04609108], [88.98417664, 22.04580498], [88.98394012, 22.04554367], [88.98371124, 22.04527855], [88.98351288, 22.04500008], [88.9833374, 22.0447464], [88.98314667, 22.0444622], [88.98288727, 22.04416275], [88.9825058, 22.04383278], [88.98204803, 22.04344368], [88.98155212, 22.04302979], [88.98105621, 22.04254913], [88.9805603, 22.04208374], [88.98007202, 22.04161644], [88.97962189, 22.04113388], [88.97918701, 22.04066277], [88.97881317, 22.04021263], [88.97840881, 22.03988075], [88.9779129, 22.03992271], [88.97741699, 22.04022026], [88.97689056, 22.04052162], [88.97634888, 22.04079056], [88.97576904, 22.04104042], [88.97512054, 22.04125023], [88.97442627, 22.04144859], [88.97380829, 22.04175186], [88.97319794, 22.04206276], [88.97257996, 22.04232979], [88.97207642, 22.04265785], [88.97161865, 22.04304123], [88.971138, 22.04341316], [88.97062683, 22.04379082], [88.97003937, 22.04413033], [88.96940613, 22.04448318], [88.96885681, 22.04495049], [88.9683075, 22.04542923], [88.96775055, 22.04587173], [88.96721649, 22.046381], [88.96666718, 22.0468502], [88.96613312, 22.04731178], [88.96556091, 22.04775047], [88.96496582, 22.04811478], [88.96443939, 22.0485096], [88.96395111, 22.04889107], [88.96350861, 22.04927444], [88.96311951, 22.04967499], [88.96277618, 22.05013084], [88.96243286, 22.05063057], [88.96214294, 22.05117226], [88.9620285, 22.05182266], [88.9622345, 22.05246162], [88.962677, 22.05294418], [88.9631958, 22.05331421], [88.96372223, 22.05359077], [88.96424103, 22.05385017], [88.96469879, 22.05404282], [88.96511078, 22.05428123], [88.96539307, 22.05460167], [88.96560669, 22.05505943], [88.9658432, 22.05550194], [88.96604156, 22.05597115], [88.96599579, 22.05648613], [88.96582794, 22.05699348], [88.96559143, 22.05745316], [88.96531677, 22.05785942], [88.96502686, 22.05828285], [88.9646759, 22.05859947], [88.96430206, 22.05888176], [88.96393585, 22.05912209], [88.96356964, 22.05933189], [88.96318817, 22.05950546], [88.96284485, 22.0597744], [88.96253967, 22.06011391], [88.96235657, 22.06048012], [88.96248627, 22.06081963], [88.9628067, 22.06113243], [88.96324158, 22.06139946], [88.96370697, 22.06168175], [88.96414948, 22.06196785], [88.96460724, 22.06223488], [88.965065, 22.06250191], [88.96554565, 22.06276512], [88.96602631, 22.06301117], [88.96643066, 22.06336021], [88.96692657, 22.06361771], [88.96743774, 22.06389046], [88.96791077, 22.06412125], [88.96833038, 22.06417274], [88.96916962, 22.06500053], [88.96922302, 22.06515121], [88.96965027, 22.06540108], [88.97003937, 22.0657177], [88.9704361, 22.06601143], [88.97080231, 22.06636238], [88.97116852, 22.06671906], [88.9715271, 22.06708527], [88.97187805, 22.06742287], [88.97220612, 22.06773186], [88.97251892, 22.06802177], [88.97288513, 22.06830978], [88.97332764, 22.06862068], [88.97379303, 22.06907082], [88.97428131, 22.06957817], [88.9747467, 22.07017136], [88.97519684, 22.07076073], [88.97557831, 22.07139015], [88.97595215, 22.07197571], [88.97638702, 22.07246208], [88.97686005, 22.07283211], [88.97717285, 22.07325172], [88.97743988, 22.07360268], [88.97753906, 22.07402992], [88.97768402, 22.07435989], [88.9777832, 22.07467079], [88.97789001, 22.07496262], [88.97805023, 22.07521248], [88.97821808, 22.0754528], [88.97834778, 22.07574272], [88.97852325, 22.07600975], [88.97868347, 22.07634735], [88.97889709, 22.07669258], [88.97912598, 22.07714272], [88.97933197, 22.07766342], [88.97955322, 22.07814789], [88.97982025, 22.07856941], [88.98011017, 22.07893944], [88.98036957, 22.07928276], [88.98054504, 22.07967949], [88.98066711, 22.08009148], [88.9807663, 22.08052254], [88.98081207, 22.08095932], [88.98087311, 22.08142281], [88.98101807, 22.08188057], [88.98110962, 22.08236122], [88.98118591, 22.08284378], [88.98134613, 22.08329201], [88.98142242, 22.08374977], [88.98151398, 22.08414078], [88.98164368, 22.08447456], [88.98171234, 22.0848217], [88.98187256, 22.08512115], [88.98195648, 22.08549309], [88.98208618, 22.08586311], [88.98220062, 22.08625984], [88.98227692, 22.0866909], [88.98245239, 22.08712578], [88.98249817, 22.08763313], [88.98254395, 22.08817673], [88.98277283, 22.08868217], [88.98296356, 22.08922005], [88.98308563, 22.08975029], [88.98324585, 22.09020042], [88.98326111, 22.09069824], [88.98330688, 22.09117317], [88.9833374, 22.09161949], [88.98336792, 22.09206963], [88.98345947, 22.0925045], [88.9835434, 22.09294319], [88.9835968, 22.09339523], [88.98365784, 22.09383965], [88.98384094, 22.09424019], [88.98388672, 22.09468269], [88.98389435, 22.09514236], [88.98391724, 22.09559441], [88.98403931, 22.09598351], [88.98416901, 22.09633446], [88.98430634, 22.09667587], [88.98445129, 22.09702492], [88.98460388, 22.09739494], [88.98474884, 22.09778595], [88.98497009, 22.09814262], [88.98512268, 22.09860039], [88.98529053, 22.09909248], [88.98549652, 22.09959221], [88.98561859, 22.10015297], [88.9858017, 22.10066605], [88.98593903, 22.1012001], [88.98610687, 22.10170364]]], [[[87.98972321, 22.21750069], [87.99028015, 22.21694183], [87.99055481, 22.21694374], [87.9908371, 22.21666718], [87.99138641, 22.2166729], [87.9916687, 22.21638107], [87.99194336, 22.2163887], [87.99222565, 22.21611023], [87.99277496, 22.21611023], [87.99305725, 22.21583176], [87.99333191, 22.21583366], [87.9936142, 22.21555519], [87.99388885, 22.21556282], [87.99500275, 22.21445274], [87.9952774, 22.21445274], [87.99666595, 22.21305084], [87.99666595, 22.21277809], [87.99555206, 22.21166992], [87.9952774, 22.21194458], [87.9936142, 22.21194458], [87.99333191, 22.21222305], [87.99276733, 22.21221924], [87.99223328, 22.21278191], [87.99194336, 22.21277809], [87.99111176, 22.2136116], [87.9908371, 22.2136116], [87.98943329, 22.21500778], [87.98805237, 22.21638107], [87.98805237, 22.21666718], [87.98777771, 22.21694374], [87.98779297, 22.21750069], [87.98805237, 22.21778107], [87.98805237, 22.21805573], [87.98832703, 22.21833038], [87.98832703, 22.21861076], [87.9888916, 22.21861076], [87.98923492, 22.21826744], [87.98972321, 22.21777725], [87.98972321, 22.21750069]]], [[[88.7223053, 22.09913445], [88.72229004, 22.09857368], [88.72144318, 22.09778023], [88.72090912, 22.09774208], [88.72088623, 22.09723091], [88.72039795, 22.09719849], [88.72006226, 22.09696579], [88.72002411, 22.09633446], [88.71976471, 22.09609413], [88.71926117, 22.09609413], [88.71894073, 22.09552956], [88.71846771, 22.09553909], [88.71811676, 22.09497833], [88.71731567, 22.09497833], [88.71730042, 22.0946846], [88.71646881, 22.09470177], [88.71649933, 22.09441948], [88.71595001, 22.09441948], [88.71565247, 22.09386826], [88.71510315, 22.09385109], [88.71477509, 22.09332848], [88.71372223, 22.09331894], [88.71335602, 22.09275246], [88.71287537, 22.09272766], [88.712883, 22.09246254], [88.71230316, 22.09250069], [88.71230316, 22.0921917], [88.71147919, 22.09221077], [88.71118164, 22.09166145], [88.71037292, 22.09163094], [88.71037292, 22.09135246], [88.70954132, 22.09136009], [88.7095108, 22.09108162], [88.70896912, 22.09111214], [88.70896912, 22.09082222], [88.70838928, 22.09079742], [88.70787811, 22.0905323], [88.70730591, 22.0897007], [88.70593262, 22.08969307], [88.7053833, 22.08913231], [88.7053299, 22.0885849], [88.70482635, 22.08831978], [88.70398712, 22.08830261], [88.70256805, 22.08665466], [88.70176697, 22.08664131], [88.70146179, 22.08579826], [88.7008667, 22.08527946], [88.70034027, 22.08522987], [88.6989212, 22.08359909], [88.69814301, 22.08357048], [88.69758606, 22.08272743], [88.6973114, 22.08189964], [88.69642639, 22.08109093], [88.69617462, 22.08055687], [88.69587708, 22.08028984], [88.69535828, 22.08022118], [88.69510651, 22.07967377], [88.69477844, 22.0791378], [88.69476318, 22.07859993], [88.69449615, 22.07833862], [88.6940155, 22.07831764], [88.6937027, 22.0777607], [88.69315338, 22.07774162], [88.69288635, 22.07807732], [88.69287109, 22.07916451], [88.69261169, 22.07914162], [88.69258118, 22.07996941], [88.69232178, 22.07998085], [88.69232178, 22.08053017], [88.69261169, 22.08054161], [88.69259644, 22.08111191], [88.69204712, 22.08109283], [88.69122314, 22.08196068], [88.69093323, 22.08249283], [88.6906662, 22.08304024], [88.6906662, 22.08414268], [88.69149017, 22.08414268], [88.69149017, 22.08498192], [88.69203186, 22.08551979], [88.69315338, 22.08552933], [88.69371796, 22.08664131], [88.69425201, 22.08666611], [88.69483948, 22.08747292], [88.69589996, 22.08747292], [88.6964798, 22.08778191], [88.69676208, 22.08830452], [88.69735718, 22.08856964], [88.69784546, 22.08885384], [88.69843292, 22.08885384], [88.69876099, 22.08944511], [88.69952393, 22.08941841], [88.70008087, 22.09026146], [88.70121765, 22.09026146], [88.70123291, 22.09051514], [88.70175171, 22.09053993], [88.70288849, 22.09190941], [88.70396423, 22.09192467], [88.70445251, 22.09275627], [88.7053833, 22.09275246], [88.70539093, 22.09304237], [88.70617676, 22.09303856], [88.70677948, 22.09357262], [88.70729828, 22.09358788], [88.70789337, 22.09440041], [88.70845032, 22.09445763], [88.70874023, 22.0949955], [88.7097702, 22.09497261], [88.71037292, 22.09581184], [88.71142578, 22.09581184], [88.7120285, 22.09667015], [88.71313477, 22.09667015], [88.71340942, 22.09720421], [88.71395874, 22.09719086], [88.71425629, 22.09775162], [88.71478271, 22.09777451], [88.71482086, 22.09803963], [88.71565247, 22.09805107], [88.71618652, 22.0982914], [88.71620941, 22.09860039], [88.71729279, 22.09857941], [88.71729279, 22.09886742], [88.71786499, 22.09889412], [88.71816254, 22.09940147], [88.71871185, 22.0994339], [88.71871185, 22.09970284], [88.71981812, 22.09971046], [88.72012329, 22.10025024], [88.72122192, 22.1002903], [88.7217865, 22.10055542], [88.72183228, 22.10082436], [88.72231293, 22.10084915], [88.7223053, 22.10108185], [88.7231369, 22.10110664], [88.7231369, 22.09972763], [88.7223053, 22.09913445]]], [[[88.81790161, 22.12302971], [88.81819916, 22.12293434], [88.81846619, 22.12294197], [88.81878662, 22.12303925], [88.81918335, 22.12306023], [88.81964874, 22.12306023], [88.82022858, 22.12306023], [88.8208313, 22.12306023], [88.82142639, 22.12306023], [88.82198334, 22.12306023], [88.8224411, 22.12308311], [88.82280731, 22.12320328], [88.82308197, 22.12331009], [88.82341766, 22.12333107], [88.82382965, 22.12335014], [88.82427216, 22.12344551], [88.82474518, 22.12358284], [88.82527161, 22.12362671], [88.82578278, 22.12371254], [88.82623291, 22.12386131], [88.82668304, 22.12392616], [88.82704926, 22.12409019], [88.82746124, 22.12416458], [88.82788849, 22.12420082], [88.82827759, 22.12437248], [88.82873535, 22.12444878], [88.82926941, 22.12455177], [88.82990265, 22.12470245], [88.83061218, 22.1247139], [88.83135223, 22.12461281], [88.83201599, 22.1244297], [88.83261108, 22.12421227], [88.83319855, 22.12416649], [88.83374786, 22.12412071], [88.83422852, 22.12392807], [88.83473206, 22.12388039], [88.83518219, 22.12381363], [88.83554077, 22.12364006], [88.8359375, 22.12350273], [88.83638, 22.12336159], [88.8368988, 22.12330055], [88.83743286, 22.12314606], [88.83805847, 22.12306023], [88.83867645, 22.12295914], [88.83924103, 22.12277031], [88.8397522, 22.12254143], [88.84033966, 22.12245369], [88.84088135, 22.12222862], [88.84142303, 22.12201118], [88.84195709, 22.12181473], [88.84250641, 22.12164116], [88.84295654, 22.12136269], [88.84335327, 22.12102318], [88.84375, 22.12070274], [88.84417725, 22.12040138], [88.84464264, 22.12009239], [88.84519196, 22.11980057], [88.84572601, 22.11942101], [88.84617615, 22.11890984], [88.84660339, 22.11838341], [88.84693909, 22.11782455], [88.84718323, 22.11725044], [88.84723663, 22.11661911], [88.84732819, 22.11602211], [88.84747314, 22.11545753], [88.84751892, 22.11488152], [88.84764099, 22.11430168], [88.84776306, 22.11366081], [88.84777832, 22.11296654], [88.84780884, 22.11225319], [88.84797668, 22.11153984], [88.84804535, 22.11082268], [88.84805298, 22.11011314], [88.84806061, 22.10943031], [88.84809113, 22.10880089], [88.84825134, 22.10824966], [88.84832001, 22.10768318], [88.8483429, 22.10711098], [88.84838104, 22.10656166], [88.84857178, 22.10609245], [88.84864044, 22.1056118], [88.84880066, 22.1052227], [88.84888458, 22.10485649], [88.84896851, 22.1045208], [88.84912872, 22.10425949], [88.84924316, 22.10397148], [88.84942627, 22.10372734], [88.84960938, 22.10344124], [88.849823, 22.10311317], [88.85012817, 22.1027813], [88.85050201, 22.10242271], [88.85089111, 22.1020031], [88.85131073, 22.10159683], [88.85167694, 22.10113716], [88.85206604, 22.1007328], [88.85250092, 22.10041237], [88.8529129, 22.10013008], [88.85323334, 22.09980965], [88.85350037, 22.09946442], [88.85382843, 22.099123], [88.85419464, 22.09873962], [88.85462952, 22.09834099], [88.85513306, 22.09793282], [88.85569, 22.09750938], [88.85624695, 22.09708214], [88.85678101, 22.096632], [88.85722351, 22.09612083], [88.85769653, 22.09564018], [88.85817719, 22.09517097], [88.85871124, 22.0947628], [88.85927582, 22.09440041], [88.85980225, 22.09397316], [88.86038971, 22.09360313], [88.86096191, 22.09321022], [88.86152649, 22.09278107], [88.86209106, 22.09236145], [88.8626709, 22.09196281], [88.86326599, 22.09158134], [88.86377716, 22.09114456], [88.86433411, 22.09077072], [88.8647995, 22.09035301], [88.86531067, 22.08999062], [88.86582184, 22.08962631], [88.86633301, 22.08924294], [88.86688995, 22.08887672], [88.86736298, 22.08844948], [88.8677063, 22.08795357], [88.86788177, 22.08741951], [88.86802673, 22.0869503], [88.86805725, 22.08645058], [88.86805725, 22.0859623], [88.86802673, 22.0854702], [88.86794281, 22.08502007], [88.8677597, 22.0846386], [88.86749268, 22.08436012], [88.86716461, 22.08423042], [88.86666107, 22.08435059], [88.86620331, 22.08441925], [88.86577606, 22.08451462], [88.86534882, 22.08462906], [88.86490631, 22.08468056], [88.86450195, 22.08472252], [88.86417389, 22.0848217], [88.86387634, 22.08496284], [88.86351776, 22.08508873], [88.86309814, 22.0852108], [88.86260986, 22.08526802], [88.86214447, 22.08532524], [88.86170959, 22.0854435], [88.86122131, 22.08551216], [88.86071777, 22.08555794], [88.86026001, 22.08563042], [88.85986328, 22.08577538], [88.85946655, 22.08588982], [88.85907745, 22.08603287], [88.85861206, 22.08615112], [88.85813904, 22.08630562], [88.85765076, 22.08638191], [88.85715485, 22.08645439], [88.85665894, 22.08661079], [88.85609436, 22.08675957], [88.85549927, 22.08691025], [88.85488892, 22.08706284], [88.85427856, 22.08723831], [88.85367584, 22.08741951], [88.8530426, 22.08758926], [88.8523407, 22.08763313], [88.85166931, 22.08774567], [88.85103607, 22.08789444], [88.85043335, 22.08805275], [88.84986115, 22.08823586], [88.84927368, 22.08841515], [88.84860992, 22.08856964], [88.8479538, 22.08875084], [88.84726715, 22.08887482], [88.84661865, 22.08901024], [88.84591675, 22.08910751], [88.84526062, 22.0891819], [88.84464264, 22.08927917], [88.84409332, 22.0894413], [88.84355927, 22.08965111], [88.84295654, 22.08987045], [88.84233093, 22.08995247], [88.84178162, 22.09003448], [88.841362, 22.09016991], [88.84120178, 22.0904026], [88.84119415, 22.09065056], [88.84127808, 22.09090233], [88.84137726, 22.09117317], [88.84150696, 22.09140587], [88.8416214, 22.09168053], [88.84178925, 22.09196281], [88.84197998, 22.0923214], [88.84217072, 22.09272575], [88.84236908, 22.09314156], [88.8425293, 22.09360504], [88.84274292, 22.09403038], [88.84297943, 22.09443665], [88.84324646, 22.09481239], [88.84350586, 22.09522057], [88.84377289, 22.09570313], [88.84402466, 22.09626579], [88.84416962, 22.09694481], [88.84414673, 22.0971508], [88.84407806, 22.09749031], [88.8440094, 22.09775734], [88.84393311, 22.09802055], [88.84371948, 22.09809303], [88.84356689, 22.09809303], [88.84342957, 22.09796143], [88.8433609, 22.09782028], [88.84329224, 22.09755516], [88.84314728, 22.09743309], [88.84310913, 22.09685135], [88.84292603, 22.09642982], [88.84278107, 22.0959301], [88.84256744, 22.09546661], [88.84230042, 22.09502983], [88.84195709, 22.09466934], [88.84160614, 22.09427071], [88.84140778, 22.0938015], [88.84121704, 22.09332085], [88.84104156, 22.09283257], [88.84088898, 22.09223175], [88.84075165, 22.0916729], [88.84054565, 22.09124565], [88.84033203, 22.09093475], [88.84011078, 22.09071159], [88.83982849, 22.09050941], [88.83946991, 22.0904026], [88.83911896, 22.0904789], [88.83895111, 22.09079361], [88.83880615, 22.09093475], [88.83866119, 22.09113121], [88.83830261, 22.09113121], [88.83830261, 22.09086037], [88.83844757, 22.09019279], [88.83866119, 22.08992195], [88.83872986, 22.08989716], [88.83900452, 22.08979988], [88.8391571, 22.08971977], [88.83943939, 22.08966255], [88.83982086, 22.0894413], [88.84018707, 22.08923531], [88.84059906, 22.08909035], [88.84098816, 22.08894157], [88.84139252, 22.08885193], [88.84178162, 22.08872032], [88.84217072, 22.08864594], [88.84259796, 22.0886097], [88.84304047, 22.08857536], [88.84348297, 22.08847237], [88.84397125, 22.08836365], [88.84451294, 22.0882473], [88.84507751, 22.08806038], [88.84568787, 22.08787155], [88.84636688, 22.08778954], [88.84700775, 22.08772087], [88.84764862, 22.0875721], [88.8482666, 22.08749199], [88.84886169, 22.08739281], [88.8494339, 22.08726692], [88.85002136, 22.08716011], [88.85057068, 22.08699989], [88.85111237, 22.08685112], [88.85159302, 22.08660316], [88.85212708, 22.08646202], [88.85280609, 22.08630371], [88.85352325, 22.0860939], [88.85421753, 22.08596992], [88.85486603, 22.08590508], [88.85547638, 22.08586311], [88.85604858, 22.08577156], [88.85655212, 22.08564568], [88.85707092, 22.08551979], [88.85751343, 22.0853672], [88.85798645, 22.08526039], [88.85845947, 22.08514977], [88.85891724, 22.08502007], [88.85939789, 22.08489037], [88.85980225, 22.08469009], [88.86022186, 22.08445168], [88.86064911, 22.08431053], [88.86108398, 22.08432198], [88.86152649, 22.08433342], [88.86195374, 22.08423233], [88.8624115, 22.08415794], [88.86284637, 22.0840683], [88.86325836, 22.08394241], [88.86333466, 22.0839386], [88.86472321, 22.08389091], [88.86499786, 22.08361244], [88.86611176, 22.08361244], [88.86638641, 22.08333015], [88.86694336, 22.08333206], [88.86750031, 22.08277702], [88.86750031, 22.08250237], [88.86723328, 22.08222008], [88.86701202, 22.08221245], [88.86670685, 22.08209038], [88.86643982, 22.08189964], [88.86617279, 22.08167267], [88.86585236, 22.08145523], [88.86540222, 22.08131027], [88.86494446, 22.0811348], [88.86447906, 22.08099174], [88.86402893, 22.0808506], [88.86357117, 22.0807476], [88.86316681, 22.08060265], [88.86269379, 22.08051682], [88.86221313, 22.08041191], [88.86168671, 22.08031845], [88.86112976, 22.08028984], [88.86057281, 22.0802803], [88.86000061, 22.0802803], [88.85943604, 22.0802803], [88.85887146, 22.0802803], [88.85829926, 22.08028984], [88.85772705, 22.0803318], [88.85714722, 22.08040047], [88.85689545, 22.08037567], [88.85652924, 22.08034325], [88.85588074, 22.08033562], [88.85523987, 22.08038139], [88.85469055, 22.08025169], [88.85417938, 22.0800724], [88.85365295, 22.07996178], [88.85315704, 22.07983208], [88.85266876, 22.07972908], [88.85217285, 22.0796299], [88.85168457, 22.07948685], [88.85118103, 22.07936287], [88.8507309, 22.07915878], [88.85031891, 22.07891464], [88.84992981, 22.07866096], [88.84954071, 22.07842064], [88.84915924, 22.07817268], [88.84874725, 22.07790184], [88.84828186, 22.07766914], [88.84783173, 22.07731247], [88.84741211, 22.07687378], [88.8469696, 22.07642365], [88.8465271, 22.07596779], [88.84607697, 22.07552147], [88.8456192, 22.07509422], [88.84511566, 22.07473183], [88.84460449, 22.07441139], [88.8441391, 22.07410812], [88.84371948, 22.07385063], [88.84329987, 22.07362175], [88.84281158, 22.07341957], [88.84222412, 22.07328415], [88.8416214, 22.07311821], [88.84094238, 22.07304382], [88.84026337, 22.07299232], [88.83995819, 22.07297134], [88.83963776, 22.07294846], [88.83922577, 22.07294846], [88.83882904, 22.07297325], [88.83846283, 22.0730114], [88.83808899, 22.07307816], [88.8377533, 22.07324219], [88.8374176, 22.07349205], [88.83704376, 22.07378578], [88.83666992, 22.07412148], [88.83628845, 22.07447243], [88.83599854, 22.07483292], [88.83578491, 22.07514954], [88.83558655, 22.07542229], [88.83541107, 22.07570457], [88.83525848, 22.0759716], [88.83506775, 22.07620239], [88.83493042, 22.07644844], [88.83476257, 22.07669258], [88.8346405, 22.07697487], [88.83447266, 22.07722282], [88.83432007, 22.07751274], [88.83415985, 22.0778389], [88.833992, 22.07822227], [88.83392334, 22.07870293], [88.83386993, 22.07923317], [88.83378601, 22.07974052], [88.83360291, 22.08016014], [88.83335876, 22.08054161], [88.83313751, 22.08090019], [88.83299255, 22.08130074], [88.832901, 22.08175087], [88.832901, 22.08226967], [88.83277893, 22.08281708], [88.83249664, 22.08322334], [88.83220673, 22.08361244], [88.83187866, 22.08402061], [88.83146667, 22.0844326], [88.83098602, 22.08485985], [88.83055878, 22.0853157], [88.83013153, 22.08577156], [88.82965088, 22.08617973], [88.82914734, 22.0865593], [88.82862854, 22.08691025], [88.82807922, 22.08723831], [88.82762909, 22.08760262], [88.82730103, 22.08806038], [88.82699585, 22.08854485], [88.8266449, 22.08899307], [88.82626343, 22.08941841], [88.82589722, 22.0898304], [88.82558441, 22.09027863], [88.82530975, 22.09074211], [88.82493591, 22.09112167], [88.82444763, 22.09139061], [88.82393646, 22.09165001], [88.82341766, 22.09190369], [88.82291412, 22.09210014], [88.8224411, 22.0923214], [88.82212067, 22.09266281], [88.82195282, 22.09304237], [88.82182312, 22.09344292], [88.82178497, 22.09386635], [88.82184601, 22.0943203], [88.82193756, 22.09476662], [88.82206726, 22.09523201], [88.82222748, 22.09574318], [88.82227325, 22.0962429], [88.82222748, 22.09669304], [88.82219696, 22.09714127], [88.8221817, 22.09761238], [88.82216644, 22.09808159], [88.82215881, 22.0985508], [88.82215118, 22.09900284], [88.82206726, 22.09943962], [88.82206726, 22.09986305], [88.82202911, 22.10023308], [88.82189178, 22.10065269], [88.82173157, 22.10116005], [88.82157135, 22.101614], [88.82141876, 22.10190392], [88.82126617, 22.10217094], [88.82113647, 22.10247993], [88.82103729, 22.10281563], [88.82090759, 22.10315132], [88.8207016, 22.10347176], [88.82041168, 22.10381126], [88.81999207, 22.10415077], [88.81933594, 22.10429192], [88.81920624, 22.10442162], [88.81899261, 22.10442162], [88.8187561, 22.10435295], [88.81884766, 22.10408783], [88.81899261, 22.10395241], [88.81913757, 22.10368156], [88.8192749, 22.10321426], [88.81941986, 22.10294533], [88.81955719, 22.10247993], [88.81977844, 22.10209084], [88.82009125, 22.10181808], [88.82024384, 22.10143471], [88.82039642, 22.10102463], [88.82058716, 22.10067368], [88.82079315, 22.10036278], [88.82095337, 22.09998131], [88.82105255, 22.09950256], [88.82109833, 22.09893608], [88.82109833, 22.09832382], [88.82106781, 22.09771347], [88.82096863, 22.0971508], [88.82083893, 22.09655952], [88.82073975, 22.0958004], [88.8207016, 22.09503937], [88.82067108, 22.09438133], [88.82065582, 22.09392357], [88.82072449, 22.09354973], [88.82081604, 22.09318924], [88.82090759, 22.09280205], [88.82106018, 22.09241295], [88.82118225, 22.09202194], [88.82135773, 22.09174156], [88.82162476, 22.09156418], [88.82196045, 22.09138298], [88.82237244, 22.0911808], [88.82289124, 22.09098244], [88.82343292, 22.09072685], [88.82397461, 22.09041405], [88.82445526, 22.08999443], [88.82489014, 22.08953094], [88.82518005, 22.08899117], [88.82541656, 22.08844376], [88.82549286, 22.08785057], [88.82525635, 22.08728981], [88.82479095, 22.08688545], [88.8242569, 22.08654213], [88.8236618, 22.08635139], [88.82315063, 22.08612251], [88.82269287, 22.08593178], [88.82218933, 22.08580017], [88.82171631, 22.08563423], [88.82125092, 22.08552933], [88.82080078, 22.08539009], [88.82035828, 22.08524132], [88.81997681, 22.08500099], [88.8196106, 22.08475304], [88.81922913, 22.08450127], [88.81887054, 22.08422279], [88.81850433, 22.08395576], [88.81806946, 22.0837307], [88.81764221, 22.08348274], [88.8172226, 22.08320045], [88.81679535, 22.08293152], [88.81634521, 22.08271408], [88.81591034, 22.08250618], [88.81548309, 22.08231926], [88.81504059, 22.08218193], [88.81465912, 22.08200264], [88.81420135, 22.08195305], [88.81373596, 22.08194351], [88.81328583, 22.08196068], [88.81286621, 22.08204079], [88.8125, 22.08222008], [88.81207275, 22.08243752], [88.81153107, 22.08262062], [88.81092834, 22.0827961], [88.81033325, 22.08299065], [88.80967712, 22.08310127], [88.80903625, 22.08327484], [88.80840302, 22.08342171], [88.80780792, 22.08363152], [88.80726624, 22.08389091], [88.80677032, 22.08417511], [88.80633545, 22.0844841], [88.80590057, 22.08475304], [88.80551147, 22.0850811], [88.80522156, 22.08549309], [88.8049469, 22.08589745], [88.8046875, 22.08632088], [88.8044281, 22.08674049], [88.80413818, 22.08713722], [88.80384827, 22.08753014], [88.8035965, 22.08798027], [88.8033905, 22.08847046], [88.80330658, 22.08901024], [88.8032608, 22.089571], [88.80330658, 22.09010124], [88.8033371, 22.09058952], [88.8033905, 22.09101486], [88.80352783, 22.09138298], [88.8035965, 22.09183311], [88.80361938, 22.09230614], [88.80366516, 22.09279442], [88.8037796, 22.09329033], [88.80374908, 22.09383965], [88.80358887, 22.09438515], [88.80332184, 22.09490395], [88.8030014, 22.0954113], [88.80259705, 22.09588051], [88.80221558, 22.09637642], [88.80176544, 22.09682274], [88.80124664, 22.09719849], [88.80072784, 22.09756279], [88.80031586, 22.09797287], [88.80001831, 22.09840393], [88.79982758, 22.09882164], [88.79982758, 22.09922981], [88.80001068, 22.09962273], [88.80021667, 22.10000038], [88.800354, 22.1004467], [88.80053711, 22.1008625], [88.80073547, 22.10127831], [88.80096436, 22.10164452], [88.8012085, 22.10198021], [88.8013916, 22.10235023], [88.80155945, 22.10270882], [88.80164337, 22.1031208], [88.80166626, 22.10360146], [88.80166626, 22.10413551], [88.80166626, 22.1047554], [88.80166626, 22.10541344], [88.80166626, 22.10605431], [88.80163574, 22.1066227], [88.80152893, 22.10707283], [88.8013916, 22.1074295], [88.8012619, 22.1077652], [88.80105591, 22.1081028], [88.80079651, 22.10847282], [88.80046082, 22.10883141], [88.80003357, 22.10915947], [88.79959106, 22.10947609], [88.79923248, 22.10981178], [88.79899597, 22.11017036], [88.79885864, 22.11055374], [88.7986908, 22.11092949], [88.79886627, 22.11137962], [88.79912567, 22.11187744], [88.79953766, 22.11231041], [88.80000305, 22.11276054], [88.80043793, 22.11323166], [88.80081177, 22.11374092], [88.80113983, 22.11425972], [88.80149078, 22.1147213], [88.80181885, 22.11520195], [88.80197144, 22.11584854], [88.80219269, 22.11652946], [88.80226135, 22.11728859], [88.80245209, 22.11804008], [88.80253601, 22.11881065], [88.80278015, 22.11945915], [88.80304718, 22.12004471], [88.8033371, 22.12059212], [88.80361176, 22.12112999], [88.80388641, 22.12166977], [88.8041687, 22.1222229], [88.80445099, 22.12278938], [88.80475616, 22.12333107], [88.8050766, 22.12385368], [88.80545044, 22.12434006], [88.8058548, 22.1248188], [88.80635834, 22.12523079], [88.80703735, 22.12552071], [88.80778503, 22.12560844], [88.80844116, 22.12581253], [88.80908203, 22.12597084], [88.80976105, 22.12584114], [88.8104248, 22.12566376], [88.81098175, 22.12540627], [88.81151581, 22.12514305], [88.81204987, 22.12490273], [88.81257629, 22.12470245], [88.81302643, 22.12446022], [88.81348419, 22.12429428], [88.81391144, 22.12412643], [88.81429291, 22.12392807], [88.81472778, 22.12384224], [88.81512451, 22.1236515], [88.81555176, 22.1235714], [88.81590271, 22.12338066], [88.81632233, 22.12333107], [88.81674957, 22.12328148], [88.81711578, 22.12311172], [88.81752014, 22.12306023], [88.81790161, 22.12302971]]], [[[88.7085495, 22.04668808], [88.70900726, 22.04654121], [88.70944977, 22.04636955], [88.70987701, 22.04615974], [88.71037292, 22.04600906], [88.71087646, 22.04582024], [88.71140289, 22.04557037], [88.71190643, 22.04535103], [88.71239471, 22.04512215], [88.71286774, 22.04495811], [88.71328735, 22.04475021], [88.7137146, 22.04460526], [88.71414185, 22.04442978], [88.7145462, 22.04420853], [88.71499634, 22.04404068], [88.71543884, 22.04387283], [88.71585083, 22.04365921], [88.71631622, 22.04356003], [88.7167511, 22.04335785], [88.71721649, 22.04319954], [88.71766663, 22.04302979], [88.71807098, 22.04279518], [88.71849823, 22.04260826], [88.71894073, 22.0424366], [88.71938324, 22.04222107], [88.71984863, 22.04200172], [88.72038269, 22.0418396], [88.72090912, 22.04165077], [88.72145081, 22.04138947], [88.72197723, 22.04113007], [88.72252655, 22.04094124], [88.72307587, 22.04080963], [88.72355652, 22.04063034], [88.72405243, 22.04051018], [88.7244873, 22.04030609], [88.72498322, 22.04016113], [88.72551727, 22.03996086], [88.72610474, 22.03971863], [88.72675323, 22.03943825], [88.72737122, 22.0391655], [88.72795105, 22.03887749], [88.72846985, 22.03866005], [88.72897339, 22.03851128], [88.72941589, 22.03832054], [88.72982788, 22.03807259], [88.73021698, 22.03782082], [88.73058319, 22.03753281], [88.73092651, 22.03723145], [88.73130035, 22.03695869], [88.73169708, 22.03672028], [88.73210144, 22.03650093], [88.73246765, 22.03622055], [88.73277283, 22.03582764], [88.733078, 22.03532982], [88.73342133, 22.03479958], [88.73384094, 22.03429985], [88.73420715, 22.03376007], [88.73462677, 22.03327942], [88.73497009, 22.03280449], [88.73527527, 22.03235245], [88.73553467, 22.03196335], [88.73574066, 22.0316143], [88.73587799, 22.03128052], [88.73603821, 22.03101921], [88.73615265, 22.0307312], [88.73631287, 22.03045845], [88.73638916, 22.03013992], [88.73647308, 22.02980995], [88.7366333, 22.02953529], [88.736763, 22.02920914], [88.73694611, 22.02889442], [88.73699951, 22.0287838], [88.73712921, 22.02853012], [88.73725891, 22.02807999], [88.73744965, 22.02762413], [88.7375412, 22.02706718], [88.73773193, 22.02654266], [88.73787689, 22.02602959], [88.73808289, 22.02560043], [88.73828888, 22.02523804], [88.73841858, 22.02482986], [88.73860931, 22.02448082], [88.73874664, 22.02421188], [88.73877716, 22.0241394], [88.73892212, 22.02380943], [88.73907471, 22.02352715], [88.73915863, 22.02318954], [88.73921967, 22.02280426], [88.73939514, 22.02240562], [88.73950195, 22.02190018], [88.73972321, 22.02140808], [88.7399826, 22.02090073], [88.74018097, 22.0203495], [88.74025726, 22.0197506], [88.74021912, 22.01917076], [88.74002075, 22.01865959], [88.73983765, 22.01815987], [88.7397995, 22.01805687], [88.73967743, 22.01769638], [88.73944092, 22.01729965], [88.73916626, 22.01691628], [88.73887634, 22.01651192], [88.73858643, 22.01608086], [88.73826599, 22.01567459], [88.73787689, 22.01535797], [88.7372818, 22.01520157], [88.73694611, 22.01520157], [88.73652649, 22.01541138], [88.73628235, 22.01534271], [88.73603058, 22.01526833], [88.73609924, 22.01486969], [88.73610687, 22.01444244], [88.7361145, 22.01388931], [88.73536682, 22.0128212], [88.73506165, 22.01239967], [88.73474884, 22.01198006], [88.73440552, 22.01157188], [88.7339859, 22.01120949], [88.73352051, 22.01086998], [88.73301697, 22.01057243], [88.73249817, 22.01032066], [88.73195648, 22.01004982], [88.73143005, 22.00976563], [88.730896, 22.00947189], [88.73033905, 22.00921822], [88.72981262, 22.00895119], [88.72930145, 22.00863075], [88.72879028, 22.00834846], [88.72825623, 22.00814056], [88.72770691, 22.00799751], [88.72727203, 22.00778008], [88.72683716, 22.00758743], [88.72635651, 22.00747108], [88.72590637, 22.0073185], [88.72545624, 22.00716972], [88.72503662, 22.00694084], [88.72463226, 22.00666046], [88.72422791, 22.00639153], [88.72381592, 22.00613594], [88.7233963, 22.00592995], [88.72290802, 22.00582886], [88.72241211, 22.00571823], [88.72189331, 22.00554276], [88.72132874, 22.00536156], [88.72104645, 22.00530052], [88.72077942, 22.00538063], [88.72041321, 22.00559616], [88.72003174, 22.00593376], [88.71961975, 22.00635147], [88.71916199, 22.00676918], [88.71866608, 22.00716019], [88.71820831, 22.00751495], [88.71781158, 22.00787163], [88.71747589, 22.00825119], [88.71717834, 22.00858116], [88.7168808, 22.00887108], [88.71656799, 22.00915909], [88.71620178, 22.00947189], [88.71578979, 22.00986099], [88.71530914, 22.01020813], [88.71479797, 22.01043701], [88.71444702, 22.01083374], [88.71360779, 22.0102787], [88.71444702, 22.00945091], [88.7141571, 22.00917053], [88.71399689, 22.00901985], [88.71366882, 22.00890923], [88.71327209, 22.00889969], [88.71283722, 22.00889969], [88.71240234, 22.00889969], [88.71195221, 22.00883865], [88.71152496, 22.00865555], [88.71108246, 22.00857162], [88.71069336, 22.00839996], [88.71024323, 22.00833893], [88.70979309, 22.00828934], [88.7093811, 22.00809288], [88.70894623, 22.00796127], [88.70855713, 22.00778008], [88.70816803, 22.00761986], [88.70774841, 22.00749016], [88.70733643, 22.00734329], [88.70692444, 22.00719452], [88.7065506, 22.00700188], [88.70614624, 22.00690079], [88.70580292, 22.00671959], [88.70536041, 22.00667], [88.70491791, 22.00666046], [88.70450592, 22.00666046], [88.70411682, 22.00667], [88.70372772, 22.00671959], [88.70332336, 22.00691032], [88.70281219, 22.00706673], [88.7022934, 22.00733185], [88.70183563, 22.00771713], [88.70135498, 22.00805473], [88.7009201, 22.0083847], [88.70058441, 22.0087471], [88.70028687, 22.00913048], [88.69996643, 22.00946617], [88.69956207, 22.0097599], [88.69914246, 22.01012611], [88.69866943, 22.01049423], [88.69818878, 22.01089096], [88.69778442, 22.01138878], [88.6973877, 22.01189423], [88.69692993, 22.01233292], [88.69644928, 22.01272964], [88.69600677, 22.01316071], [88.69555664, 22.01358032], [88.69502258, 22.01388931], [88.69450378, 22.01416397], [88.69400787, 22.01440048], [88.69351196, 22.01455688], [88.69306183, 22.01471138], [88.69263458, 22.01486015], [88.69221497, 22.0150013], [88.69178772, 22.01514053], [88.69136047, 22.01528931], [88.69091034, 22.0154686], [88.69042206, 22.01566887], [88.68984985, 22.01586342], [88.68922424, 22.01611137], [88.68856812, 22.01634026], [88.68785858, 22.01643944], [88.68723297, 22.01663971], [88.68656921, 22.01678085], [88.6860199, 22.01697159], [88.68556976, 22.01721191], [88.68518066, 22.01741982], [88.68478394, 22.01753616], [88.68444824, 22.01773071], [88.68405151, 22.01783943], [88.68370056, 22.01803017], [88.68332672, 22.01819038], [88.68296051, 22.01837158], [88.68264008, 22.01861572], [88.68235779, 22.01888084], [88.68250275, 22.01889038], [88.68138885, 22.02000046], [88.6811142, 22.02000046], [88.6809082, 22.02020264], [88.68052673, 22.02046013], [88.6800766, 22.02074051], [88.6795578, 22.02100182], [88.67902374, 22.02127266], [88.67855072, 22.02160454], [88.67807007, 22.0218811], [88.67765045, 22.02200508], [88.67727661, 22.02218437], [88.67688751, 22.02230072], [88.67652893, 22.02248001], [88.67614746, 22.02262115], [88.67565918, 22.02279091], [88.67518616, 22.0229702], [88.67472076, 22.02309036], [88.67427063, 22.02326965], [88.67375946, 22.02332878], [88.67321014, 22.0233345], [88.67262268, 22.0233326], [88.67199707, 22.02333069], [88.6713562, 22.02336121], [88.67073059, 22.02342033], [88.67019653, 22.02336121], [88.66964722, 22.02333832], [88.6690979, 22.02333069], [88.66854095, 22.0233326], [88.66798401, 22.0233326], [88.66744995, 22.02332306], [88.66692352, 22.0232811], [88.66641998, 22.02314186], [88.6659317, 22.02280045], [88.66545105, 22.02259254], [88.66496277, 22.0226593], [88.66458893, 22.02303314], [88.66430664, 22.02340126], [88.66403198, 22.02361107], [88.66377258, 22.02376175], [88.66358185, 22.02403069], [88.66339111, 22.0243969], [88.66333771, 22.02487183], [88.66333008, 22.02538681], [88.66333008, 22.02589035], [88.66333008, 22.02639008], [88.66330719, 22.02687645], [88.66318512, 22.02737236], [88.66306305, 22.0279007], [88.66293335, 22.02844048], [88.6628418, 22.02897835], [88.66290283, 22.02952003], [88.66279602, 22.0301075], [88.66277313, 22.03067017], [88.66268158, 22.03117943], [88.66253662, 22.03162956], [88.66249847, 22.03209686], [88.6624527, 22.03252029], [88.66230011, 22.03287125], [88.6621933, 22.03323174], [88.66203308, 22.03356934], [88.66195679, 22.03400993], [88.66194153, 22.03451157], [88.66190338, 22.03503036], [88.66172791, 22.0354805], [88.66166687, 22.03596115], [88.66166687, 22.03644943], [88.66166687, 22.03692055], [88.66162872, 22.03736115], [88.66149902, 22.03775978], [88.66130829, 22.03815079], [88.66120148, 22.03855896], [88.66133881, 22.03899956], [88.66137695, 22.03952026], [88.66135406, 22.04001999], [88.66120911, 22.04046822], [88.66116333, 22.04089928], [88.66127777, 22.04132652], [88.66126251, 22.04175949], [88.66116333, 22.04221153], [88.66123199, 22.0426712], [88.66135406, 22.04310608], [88.66137695, 22.04354286], [88.66139221, 22.04400063], [88.66139221, 22.0444603], [88.66137695, 22.04495811], [88.66137695, 22.04551125], [88.66137695, 22.04609108], [88.66140747, 22.04665756], [88.66150665, 22.04718399], [88.66168213, 22.04769135], [88.66187286, 22.04824066], [88.66188812, 22.0489006], [88.66172028, 22.04957962], [88.66169739, 22.05023956], [88.66176605, 22.0508194], [88.66171265, 22.05130005], [88.66166687, 22.05174065], [88.66160583, 22.0521698], [88.66140747, 22.05256081], [88.66118622, 22.05294037], [88.66100311, 22.05331039], [88.66083527, 22.05361557], [88.66069031, 22.05389214], [88.66057587, 22.05417061], [88.66056061, 22.05453682], [88.66055298, 22.05496407], [88.66055298, 22.05545425], [88.66055298, 22.05583191], [88.66055298, 22.05611038], [88.66035461, 22.05632019], [88.66027832, 22.0564003], [88.66027832, 22.05694389], [88.65999603, 22.05722046], [88.65999603, 22.05750084], [88.65972137, 22.05778122], [88.65972137, 22.05805588], [88.65944672, 22.05833054], [88.65944672, 22.05861092], [88.6591568, 22.05889511], [88.65891266, 22.05934143], [88.65874481, 22.05984306], [88.6587677, 22.06038094], [88.65862274, 22.06084824], [88.65846252, 22.06133842], [88.65827179, 22.06187057], [88.65805054, 22.06238174], [88.65779114, 22.06286049], [88.657547, 22.06329727], [88.65726471, 22.06363487], [88.6570282, 22.06397247], [88.65686798, 22.06438065], [88.65668488, 22.06479645], [88.65654755, 22.06525993], [88.65641785, 22.06574821], [88.6563797, 22.06627083], [88.65632629, 22.06676102], [88.65616608, 22.06718063], [88.65611267, 22.06760979], [88.65608978, 22.06801987], [88.65600586, 22.06841278], [88.65586853, 22.06888962], [88.65583801, 22.06940079], [88.65583038, 22.06991959], [88.65578461, 22.07043266], [88.65563202, 22.07094955], [88.65551758, 22.07150078], [88.65532684, 22.07201576], [88.65522766, 22.07261276], [88.6550293, 22.07316017], [88.65487671, 22.07372284], [88.65471649, 22.07418823], [88.65454102, 22.07464981], [88.65444183, 22.07518005], [88.65432739, 22.07570839], [88.65416718, 22.07620239], [88.65400696, 22.07666969], [88.65384674, 22.07711601], [88.65365601, 22.0775795], [88.65352631, 22.07810783], [88.65332031, 22.07860374], [88.65307617, 22.07910156], [88.65287018, 22.07964706], [88.6526947, 22.0802002], [88.65249634, 22.0806694], [88.65228271, 22.08106995], [88.65215302, 22.08143044], [88.65195465, 22.08168411], [88.65177155, 22.08189964], [88.65156555, 22.08207512], [88.65136719, 22.0823307], [88.65119934, 22.08261108], [88.65107727, 22.08300018], [88.65094757, 22.0834198], [88.65076447, 22.08386993], [88.65054321, 22.08432961], [88.65027618, 22.08481026], [88.65003967, 22.08527946], [88.64981079, 22.08574295], [88.64958954, 22.08616638], [88.6493454, 22.08658981], [88.64897919, 22.08693123], [88.64859772, 22.08723831], [88.64822388, 22.08750725], [88.64795685, 22.08778], [88.64776611, 22.0880394], [88.64758301, 22.08826065], [88.64740753, 22.08844948], [88.6471405, 22.08880043], [88.64688873, 22.08893013], [88.64657593, 22.08915138], [88.6462326, 22.08942986], [88.64587402, 22.08971786], [88.64551544, 22.08999634], [88.64516449, 22.09028625], [88.64483643, 22.09060097], [88.64453125, 22.09096909], [88.64424133, 22.09136963], [88.64391327, 22.09173584], [88.64359283, 22.09211159], [88.64326477, 22.09246254], [88.64291382, 22.09277153], [88.6425705, 22.09305954], [88.64225769, 22.09334183], [88.64196777, 22.09362984], [88.64168549, 22.09391212], [88.64139557, 22.09420013], [88.64111328, 22.09449768], [88.64083862, 22.09481812], [88.64057159, 22.09514236], [88.64034271, 22.09546852], [88.64003754, 22.09579086], [88.63973236, 22.09613609], [88.63944244, 22.09656143], [88.63912964, 22.09704018], [88.63873291, 22.09752083], [88.63832855, 22.09799957], [88.63792419, 22.09845924], [88.63756561, 22.09884071], [88.63748169, 22.09897232], [88.6373291, 22.09922028], [88.6371994, 22.09959984], [88.63702393, 22.09989357], [88.63674927, 22.10012054], [88.6364975, 22.10037994], [88.63632965, 22.10074043], [88.63610077, 22.10108185], [88.63588715, 22.10139084], [88.63568878, 22.10170937], [88.63556671, 22.10209084], [88.63548279, 22.10252762], [88.63527679, 22.10295105], [88.63504791, 22.10341072], [88.63492584, 22.10392952], [88.63472748, 22.10436821], [88.63454437, 22.10477638], [88.63443756, 22.1052227], [88.63432312, 22.1056881], [88.63418579, 22.10621071], [88.63417053, 22.10679817], [88.63420868, 22.10744286], [88.63434601, 22.10808945], [88.63434601, 22.10874939], [88.63440704, 22.10937881], [88.63434601, 22.10998154], [88.63430023, 22.11051941], [88.63461304, 22.11089897], [88.63471222, 22.1113205], [88.63472748, 22.11181068], [88.63477325, 22.11232948], [88.63491058, 22.11283112], [88.63498688, 22.11333084], [88.63500214, 22.11386108], [88.63500214, 22.11441994], [88.63504791, 22.11499977], [88.63523865, 22.11555099], [88.63535309, 22.1161499], [88.63553619, 22.11668015], [88.63569641, 22.1172123], [88.63585663, 22.11771011], [88.63606262, 22.11813354], [88.63613892, 22.1185894], [88.63626862, 22.11898804], [88.63638306, 22.11938095], [88.63647461, 22.11977959], [88.63665009, 22.12013435], [88.63679504, 22.12051392], [88.63696289, 22.12086105], [88.63716888, 22.12120056], [88.63734436, 22.12157822], [88.63755035, 22.12198067], [88.63778687, 22.12244034], [88.63806152, 22.12293053], [88.63838959, 22.12347031], [88.63878632, 22.12401009], [88.63909912, 22.12463188], [88.63947296, 22.12519264], [88.63986969, 22.12568283], [88.6402359, 22.12619019], [88.64055634, 22.12672997], [88.64086914, 22.12725067], [88.6411972, 22.12770081], [88.64154816, 22.12806129], [88.6418457, 22.12841415], [88.64206696, 22.12882042], [88.64232635, 22.12920189], [88.64253998, 22.12958908], [88.64276886, 22.12992096], [88.64299011, 22.13020325], [88.64320374, 22.13044357], [88.64337158, 22.13069916], [88.64354706, 22.13094902], [88.64366913, 22.13125038], [88.64385986, 22.13152122], [88.64402771, 22.13182259], [88.64417267, 22.13216591], [88.64431763, 22.13250351], [88.64447784, 22.1328392], [88.6446991, 22.13316917], [88.64492035, 22.1335392], [88.64505005, 22.13400078], [88.6452713, 22.13444519], [88.64547729, 22.13492393], [88.64569092, 22.13542557], [88.64585876, 22.13593102], [88.64606476, 22.13637924], [88.64620209, 22.13684845], [88.64640045, 22.13730049], [88.64663696, 22.13774109], [88.64687347, 22.1382103], [88.6470108, 22.13877106], [88.64720917, 22.13931847], [88.64736938, 22.13986588], [88.64751434, 22.1403904], [88.64766693, 22.14087105], [88.64778137, 22.14134789], [88.64788818, 22.14176941], [88.64801788, 22.14213943], [88.64817047, 22.14245415], [88.64834595, 22.14274025], [88.64852905, 22.14304924], [88.64855194, 22.14351082], [88.64868164, 22.14393234], [88.64891815, 22.14429474], [88.64917755, 22.14467049], [88.64942932, 22.14507484], [88.64963531, 22.14551544], [88.64982605, 22.14593124], [88.65000916, 22.14630508], [88.650177, 22.14663124], [88.65018463, 22.14712524], [88.65033722, 22.1475296], [88.65054321, 22.14796066], [88.65073395, 22.14839745], [88.65086365, 22.1489048], [88.65103149, 22.14939308], [88.65113068, 22.14990807], [88.65125275, 22.15041542], [88.65140533, 22.15090561], [88.65158081, 22.15133667], [88.6516571, 22.15174675], [88.65167236, 22.15216064], [88.65172577, 22.15258026], [88.65187836, 22.15295601], [88.65193939, 22.15339088], [88.6519928, 22.15383911], [88.6521759, 22.15425491], [88.65222168, 22.15468979], [88.65221405, 22.15513992], [88.65216827, 22.15559387], [88.65210724, 22.15604973], [88.65219879, 22.15649986], [88.6522522, 22.15694809], [88.65232849, 22.15738106], [88.65234375, 22.15781975], [88.65229797, 22.15825081], [88.65232849, 22.1586895], [88.65242767, 22.15911293], [88.65246582, 22.15954971], [88.6523819, 22.1599884], [88.65232849, 22.16040039], [88.65232849, 22.16078949], [88.65232849, 22.16119194], [88.65232849, 22.16160011], [88.65245819, 22.1619606], [88.65255737, 22.16232109], [88.65267181, 22.16267967], [88.65276337, 22.16303062], [88.65286255, 22.16339111], [88.65306091, 22.16364098], [88.65333557, 22.16388893], [88.65555573, 22.16611099], [88.65583801, 22.16611099], [88.65611267, 22.16638947], [88.65638733, 22.16638947], [88.65666962, 22.16666985], [88.65805817, 22.16666412], [88.65833282, 22.1669445], [88.65860748, 22.1669445], [88.65916443, 22.16749954], [88.66000366, 22.16833305], [88.66027832, 22.16833115], [88.66139221, 22.16945076], [88.66166687, 22.16945076], [88.66221619, 22.16999817], [88.66249847, 22.16999817], [88.66361237, 22.17111206], [88.66388702, 22.17110825], [88.66416931, 22.17140007], [88.66443634, 22.17140007], [88.66583252, 22.17277908], [88.66610718, 22.17277908], [88.66832733, 22.17500114], [88.66860962, 22.17500114], [88.67028046, 22.17667007], [88.67055511, 22.17666626], [88.67610931, 22.18222237], [88.6763916, 22.18222046], [88.67778015, 22.18361092], [88.67778015, 22.18388748], [88.67861176, 22.18471909], [88.67861176, 22.18499756], [88.67944336, 22.18583298], [88.67944336, 22.18611145], [88.68083191, 22.18750191], [88.68083191, 22.18778038], [88.6811142, 22.18805504], [88.68110657, 22.18861008], [88.68166351, 22.18916702], [88.68166351, 22.18972206], [88.6827774, 22.19083023], [88.6827774, 22.19138908], [88.68333435, 22.19194412], [88.68332672, 22.19221115], [88.68360901, 22.19249916], [88.68360901, 22.19333076], [88.6838913, 22.19361115], [88.6838913, 22.19444466], [88.68416595, 22.19472122], [88.68416595, 22.19499969], [88.68444824, 22.19527626], [88.68444824, 22.19610977], [88.6847229, 22.19639015], [88.6847229, 22.19694519], [88.68499756, 22.19722176], [88.68527985, 22.19721985], [88.68548584, 22.19800186], [88.68562317, 22.1986599], [88.68554688, 22.19922066], [88.68533325, 22.19967079], [88.68505096, 22.19997025], [88.68488312, 22.20022964], [88.68486023, 22.20063782], [88.68470764, 22.20112991], [88.68447876, 22.20168495], [88.68421936, 22.20224953], [88.68414307, 22.20285034], [88.68398285, 22.2034111], [88.68386078, 22.20398521], [88.68369293, 22.20453072], [88.68356323, 22.20508003], [88.68343353, 22.20556068], [88.68356323, 22.20603561], [88.68360901, 22.20651245], [88.68367004, 22.20695305], [88.68388367, 22.20724297], [88.68415833, 22.20747375], [88.68453979, 22.2075882], [88.6849823, 22.20767975], [88.68544769, 22.2076931], [88.6858902, 22.20754051], [88.68634033, 22.20750427], [88.6867981, 22.20751953], [88.6872406, 22.20757675], [88.68768311, 22.20763206], [88.68812561, 22.20767975], [88.68856812, 22.20772171], [88.68901825, 22.20775986], [88.68946838, 22.20777512], [88.68994141, 22.20779037], [88.6904068, 22.20788193], [88.69093323, 22.20799065], [88.6914978, 22.2080555], [88.69207001, 22.20813751], [88.69262695, 22.2082653], [88.69314575, 22.20841026], [88.69332886, 22.20844841], [88.6936264, 22.20850945], [88.69412231, 22.20858955], [88.69464874, 22.20861053], [88.69519043, 22.20861244], [88.69574738, 22.20861053], [88.69629669, 22.20861053], [88.69683838, 22.208601], [88.69736481, 22.20858383], [88.69788361, 22.20859337], [88.69839478, 22.20856857], [88.69888306, 22.20837021], [88.6993866, 22.20830345], [88.69991302, 22.20823288], [88.70040894, 22.20802116], [88.70094299, 22.20779037], [88.70153046, 22.2076149], [88.7021637, 22.20744705], [88.70279694, 22.20726013], [88.70346832, 22.20717049], [88.7040863, 22.2069397], [88.7046814, 22.20666695], [88.70523071, 22.2063694], [88.70569611, 22.20603943], [88.70619965, 22.20575714], [88.70671082, 22.20551109], [88.70722198, 22.20525169], [88.70767975, 22.20487022], [88.70809937, 22.20447922], [88.70855713, 22.20420837], [88.70899963, 22.20393944], [88.7094574, 22.2036705], [88.70994568, 22.20338631], [88.71042633, 22.20308113], [88.71095276, 22.20277977], [88.71141815, 22.20249176], [88.71185303, 22.20217514], [88.71225739, 22.20182037], [88.71269989, 22.20146942], [88.71315765, 22.20114326], [88.71360779, 22.20084381], [88.71401978, 22.20057106], [88.71440125, 22.2003212], [88.71476746, 22.2000885], [88.71515656, 22.19987106], [88.71559906, 22.19969749], [88.71602631, 22.19948959], [88.7164917, 22.19932556], [88.71691895, 22.19911194], [88.71734619, 22.1988678], [88.71776581, 22.19860077], [88.71818542, 22.19833374], [88.71856689, 22.19805908], [88.71893311, 22.19779968], [88.71930695, 22.19757843], [88.71977234, 22.19743538], [88.72025299, 22.19728088], [88.72075653, 22.19721031], [88.72128296, 22.1971302], [88.72177887, 22.19697189], [88.7223053, 22.19683647], [88.72281647, 22.19664955], [88.72333527, 22.19645119], [88.72389984, 22.19632339], [88.7244339, 22.19611359], [88.72496033, 22.19590569], [88.72550201, 22.19576073], [88.72602844, 22.19561005], [88.72654724, 22.19553947], [88.72704315, 22.19544029], [88.72749329, 22.19531441], [88.72795105, 22.19524193], [88.72836304, 22.19511986], [88.7287674, 22.19499779], [88.72915649, 22.19486809], [88.72956085, 22.19475174], [88.72996521, 22.194664], [88.73032379, 22.19451523], [88.73071289, 22.19444084], [88.73109436, 22.19435883], [88.73146057, 22.19413948], [88.73189545, 22.19399071], [88.73239899, 22.19400978], [88.73290253, 22.19413185], [88.7334137, 22.19423103], [88.73387146, 22.19439125], [88.73429871, 22.19450951], [88.73465729, 22.19470024], [88.73501587, 22.19485092], [88.73539734, 22.19503975], [88.73577881, 22.19529915], [88.73616028, 22.19558716], [88.73655701, 22.19584846], [88.73696899, 22.19614029], [88.73738861, 22.19640923], [88.73783875, 22.19670105], [88.7383728, 22.19693947], [88.73898315, 22.19713974], [88.73972321, 22.19720078], [88.74047852, 22.19720078], [88.74118805, 22.19711113], [88.74180603, 22.19692993], [88.74237823, 22.19673538], [88.74294281, 22.196661], [88.74345398, 22.19659615], [88.74391174, 22.19642067], [88.74434662, 22.19630051], [88.74471283, 22.19606972], [88.74505615, 22.19584084], [88.74545288, 22.19563103], [88.7459259, 22.19556427], [88.74643707, 22.19555092], [88.74669647, 22.19556236], [88.74697113, 22.19556808], [88.74752045, 22.19555092], [88.74806976, 22.19550133], [88.74858856, 22.19532967], [88.74915314, 22.19528008], [88.74970245, 22.19526863], [88.75023651, 22.19522285], [88.75074768, 22.19511986], [88.75124359, 22.1950264], [88.75174713, 22.1950016], [88.75226593, 22.19499016], [88.75274658, 22.19493294], [88.75321198, 22.19484138], [88.75366974, 22.19471931], [88.75411224, 22.19457054], [88.75455475, 22.19439125], [88.75498199, 22.1941967], [88.75547028, 22.19405556], [88.75593567, 22.19381905], [88.75643158, 22.19359779], [88.75697327, 22.19334984], [88.75752258, 22.19310951], [88.75811005, 22.19292068], [88.75871277, 22.19276237], [88.75932312, 22.19257164], [88.75997162, 22.1925106], [88.76065063, 22.19249916], [88.7613678, 22.19250488], [88.76210022, 22.19250488], [88.76286316, 22.19250488], [88.76360321, 22.19247246], [88.76432037, 22.19234657], [88.7649765, 22.19219971], [88.76552582, 22.19196129], [88.76595306, 22.19169044], [88.76626587, 22.19139481], [88.76650238, 22.19104385], [88.76663208, 22.1906414], [88.7666626, 22.19022942], [88.76663208, 22.18985176], [88.76648712, 22.18953514], [88.76634979, 22.18917656], [88.76637268, 22.18894577], [88.76638794, 22.18880081], [88.76637268, 22.18836021], [88.76629639, 22.18786049], [88.76615143, 22.18733788], [88.76615906, 22.18679047], [88.76635742, 22.18628311], [88.76661682, 22.18581009], [88.76687622, 22.18535233], [88.76711273, 22.18489647], [88.76719666, 22.1843605], [88.76722717, 22.18379974], [88.76728058, 22.18325806], [88.76745605, 22.18279076], [88.76759338, 22.18227005], [88.76779175, 22.18176079], [88.76805115, 22.18128967], [88.76832581, 22.18083954], [88.76860046, 22.18041611], [88.76889801, 22.18001938], [88.76927948, 22.17972755], [88.76970673, 22.17948151], [88.77023315, 22.17933083], [88.77072906, 22.17913055], [88.77119446, 22.17888641], [88.77165985, 22.17863083], [88.77216339, 22.17843819], [88.77251434, 22.17837715], [88.77287292, 22.17833138], [88.77326202, 22.17827606], [88.77363586, 22.17816925], [88.77404022, 22.17805481], [88.77444458, 22.17793083], [88.77488708, 22.17781258], [88.77539825, 22.17770958], [88.77588654, 22.17749214], [88.77635193, 22.17724419], [88.77683258, 22.1770649], [88.77732849, 22.17696762], [88.77781677, 22.17691994], [88.77823639, 22.17679024], [88.77861786, 22.17654228], [88.77898407, 22.17647743], [88.77961731, 22.1764698], [88.78018951, 22.17636299], [88.78065491, 22.17614937], [88.7811203, 22.17596245], [88.78156281, 22.17578316], [88.7819519, 22.17555046], [88.78233337, 22.17529106], [88.78270721, 22.17504311], [88.78305054, 22.17464256], [88.78344727, 22.17450142], [88.78385925, 22.17436409], [88.78472137, 22.17389107], [88.78527069, 22.17361259], [88.78778076, 22.17110825], [88.78778076, 22.17083359], [88.78916931, 22.16944885], [88.78916931, 22.16861153], [88.78864288, 22.16813469], [88.78806305, 22.16777992], [88.78778076, 22.16749954], [88.78721619, 22.16722107], [88.78722382, 22.1669445], [88.78694153, 22.16666412], [88.78694153, 22.16638947], [88.78666687, 22.16611099], [88.78499603, 22.16526985], [88.78416443, 22.16500092], [88.78138733, 22.16220856], [88.78083038, 22.16194534], [88.78056335, 22.16167068], [88.77999878, 22.1613903], [88.77971649, 22.16111183], [88.77916718, 22.16083336], [88.77916718, 22.16055489], [88.77749634, 22.15888977], [88.77694702, 22.15860748], [88.77610779, 22.15777969], [88.77555847, 22.15750122], [88.77471924, 22.15666962], [88.77416992, 22.15639114], [88.77361298, 22.15583038], [88.77305603, 22.15555763], [88.77305603, 22.15528107], [88.77278137, 22.15500069], [88.77278137, 22.15472031], [88.77083588, 22.15277863], [88.77063751, 22.15244102], [88.7702713, 22.15195084], [88.76992798, 22.15158272], [88.76959229, 22.15123177], [88.76924896, 22.15089035], [88.76891327, 22.15055275], [88.76856232, 22.15020943], [88.76822662, 22.14986038], [88.76792145, 22.14948082], [88.76766968, 22.14908409], [88.76747894, 22.14866447], [88.76733398, 22.14822769], [88.76722717, 22.14777946], [88.76690674, 22.14728928], [88.76663208, 22.1467495], [88.76638794, 22.14611053], [88.76593781, 22.14609909], [88.76550293, 22.14603043], [88.76503754, 22.14599609], [88.7645874, 22.14595985], [88.76413727, 22.14593124], [88.76368713, 22.14589119], [88.763237, 22.14586067], [88.76277924, 22.14586067], [88.76226044, 22.14595985], [88.76167297, 22.14622116], [88.76120758, 22.14620972], [88.76080322, 22.14612007], [88.76039886, 22.14603806], [88.76003265, 22.14587975], [88.7596283, 22.14585114], [88.7592392, 22.1459198], [88.7588501, 22.14602089], [88.75834656, 22.14587975], [88.75784302, 22.14574051], [88.75736237, 22.14566994], [88.75689697, 22.14563179], [88.75643921, 22.14560127], [88.75596619, 22.14555931], [88.75549316, 22.14550018], [88.75496674, 22.14538956], [88.75444794, 22.14523315], [88.75392914, 22.14501953], [88.753479, 22.14473152], [88.75302124, 22.1444397], [88.75258636, 22.14414978], [88.75218964, 22.14385033], [88.75183105, 22.14352989], [88.75139618, 22.14331055], [88.75099182, 22.14306259], [88.75061035, 22.14284706], [88.75025177, 22.14271927], [88.74997711, 22.14249992], [88.74973297, 22.14222908], [88.74954987, 22.14201736], [88.74942017, 22.14186668], [88.74897766, 22.1414814], [88.74840546, 22.14119911], [88.74787903, 22.14103508], [88.74746704, 22.14079094], [88.74711609, 22.14044952], [88.74672699, 22.14006042], [88.74629974, 22.13963127], [88.74584198, 22.1391983], [88.74530792, 22.13892937], [88.74481964, 22.13870049], [88.74442291, 22.1384697], [88.74402618, 22.13827515], [88.74365997, 22.13804054], [88.74328613, 22.13777733], [88.74285126, 22.13750076], [88.74233246, 22.13722038], [88.74172211, 22.13694572], [88.74108887, 22.13667107], [88.74048615, 22.13635826], [88.74001312, 22.13598061], [88.73954773, 22.13558006], [88.73908234, 22.13521957], [88.73853302, 22.13491058], [88.73805237, 22.13454056], [88.73760223, 22.13414001], [88.73721313, 22.1337204], [88.73687744, 22.13336945], [88.73657227, 22.13309097], [88.73628235, 22.13289642], [88.73602295, 22.13268089], [88.73577118, 22.13241386], [88.73551178, 22.13210106], [88.73525238, 22.13175964], [88.7349472, 22.13142967], [88.7346344, 22.1311264], [88.73429108, 22.13083076], [88.73395538, 22.13054085], [88.73363495, 22.13022995], [88.73332977, 22.12989998], [88.73303223, 22.12953949], [88.73271942, 22.12920952], [88.7325058, 22.12899971], [88.73239136, 22.12888527], [88.73207855, 22.12854004], [88.73181915, 22.12812042], [88.73149109, 22.12777519], [88.73116302, 22.12742996], [88.73082733, 22.12706757], [88.73049927, 22.1267128], [88.73015594, 22.12636185], [88.72984314, 22.12597084], [88.72948456, 22.12565994], [88.72917175, 22.12528038], [88.72886658, 22.1248703], [88.72853851, 22.12452126], [88.72815704, 22.12425041], [88.7278595, 22.12389946], [88.7276001, 22.12354279], [88.72741699, 22.12311172], [88.72720337, 22.12271309], [88.72693634, 22.12232971], [88.72664642, 22.12190056], [88.72638702, 22.12138176], [88.72614288, 22.12080956], [88.72592926, 22.1201992], [88.72579193, 22.1195507], [88.72557068, 22.11895943], [88.72535706, 22.11837006], [88.72515869, 22.11779785], [88.7249527, 22.11721992], [88.72473145, 22.11665916], [88.72453308, 22.1160717], [88.72432709, 22.11544037], [88.72413635, 22.11483383], [88.72388458, 22.11426544], [88.72358704, 22.11374092], [88.7232666, 22.11325073], [88.72289276, 22.11283112], [88.72251129, 22.11245918], [88.72212982, 22.11214066], [88.72171783, 22.11188126], [88.72133636, 22.11160088], [88.72099304, 22.11128044], [88.72063446, 22.11092949], [88.72027588, 22.11055946], [88.71990967, 22.1102066], [88.71949768, 22.10989952], [88.71912384, 22.10955811], [88.71871948, 22.1092701], [88.7183075, 22.10892105], [88.71788788, 22.10858536], [88.71750641, 22.10820961], [88.71711731, 22.10782814], [88.71666718, 22.10753059], [88.71618652, 22.10731125], [88.7156601, 22.10716057], [88.71515656, 22.10692978], [88.7146759, 22.10663986], [88.71412659, 22.10638046], [88.71353912, 22.1061306], [88.71289825, 22.10593987], [88.71228027, 22.10568428], [88.71166229, 22.1053791], [88.71105194, 22.1050396], [88.71047974, 22.10472679], [88.70995331, 22.10444069], [88.70947266, 22.10416412], [88.7090683, 22.10388947], [88.7086792, 22.10362053], [88.70833588, 22.10336113], [88.70797729, 22.10309029], [88.7075882, 22.1028614], [88.70721436, 22.10262489], [88.70683289, 22.10240746], [88.70648193, 22.10222054], [88.70613861, 22.10206032], [88.70579529, 22.10194206], [88.70542908, 22.10181618], [88.70510864, 22.10167122], [88.70500183, 22.10167122], [88.70443726, 22.10111046], [88.70443726, 22.10056114], [88.70417786, 22.10028076], [88.70417786, 22.10000038], [88.70361328, 22.09944344], [88.70336151, 22.09916115], [88.70294189, 22.09884834], [88.70252991, 22.09848976], [88.70211029, 22.09816933], [88.70167542, 22.09794426], [88.70124817, 22.09776306], [88.70082855, 22.09760094], [88.70037079, 22.09744072], [88.69991302, 22.09721947], [88.69940948, 22.09699059], [88.69889069, 22.09677124], [88.69834137, 22.09655952], [88.69782257, 22.09628105], [88.6973114, 22.09593964], [88.6967392, 22.09566307], [88.69608307, 22.09549713], [88.69551086, 22.09525108], [88.69503021, 22.09494019], [88.69461823, 22.0946312], [88.69420624, 22.09434128], [88.69381714, 22.09402084], [88.69338989, 22.09374046], [88.69298553, 22.09340477], [88.6925354, 22.09309196], [88.69204712, 22.09277916], [88.69155884, 22.09242821], [88.69113159, 22.09197044], [88.69068909, 22.09152031], [88.69024658, 22.09110069], [88.68978119, 22.09072113], [88.68936157, 22.09032249], [88.68897247, 22.08990479], [88.68868256, 22.08944511], [88.68842316, 22.08901024], [88.68813324, 22.08862305], [88.68782043, 22.08826065], [88.6875, 22.08785057], [88.68715668, 22.08739662], [88.68676758, 22.08691978], [88.68634033, 22.08643341], [88.68585968, 22.08598709], [88.68541718, 22.08555031], [88.68506622, 22.08512115], [88.68486786, 22.0846138], [88.68486786, 22.08403969], [88.68473053, 22.08360291], [88.68453979, 22.08316994], [88.68427277, 22.08279037], [88.68393707, 22.08240128], [88.68361664, 22.08192825], [88.68332672, 22.08139038], [88.68305206, 22.08083153], [88.68283081, 22.08023071], [88.68278503, 22.07962418], [88.68280029, 22.07903862], [88.68287659, 22.07849121], [88.68280029, 22.0779705], [88.6827774, 22.07747078], [88.6827774, 22.07702637], [88.6827774, 22.07661057], [88.6827774, 22.07615089], [88.6827774, 22.07569885], [88.6827774, 22.07523155], [88.6827774, 22.07477379], [88.68278503, 22.0743103], [88.68283081, 22.07383728], [88.68300629, 22.07334518], [88.68305206, 22.07280922], [88.68306732, 22.07228088], [88.68313599, 22.07177925], [88.68328857, 22.07133102], [88.68332672, 22.07088089], [88.68334198, 22.07045937], [88.68338776, 22.0701046], [88.68347168, 22.06977654], [88.68358612, 22.0694294], [88.68366241, 22.06899071], [88.683815, 22.06851959], [88.68393707, 22.06799126], [88.68412781, 22.06744957], [88.68424988, 22.06689644], [88.68444824, 22.06638908], [88.68464661, 22.06587982], [88.68483734, 22.06536293], [88.68506622, 22.06492043], [88.68531036, 22.06451035], [88.6855545, 22.06417656], [88.68580627, 22.06385994], [88.68604279, 22.06353951], [88.68621826, 22.06316948], [88.68641663, 22.06279945], [88.68667603, 22.06250191], [88.68695068, 22.06221008], [88.68717957, 22.06188965], [88.68730164, 22.06149292], [88.68747711, 22.06112099], [88.68767548, 22.06068993], [88.68803406, 22.0602684], [88.68840027, 22.05977058], [88.68889618, 22.05939102], [88.68930817, 22.05890083], [88.68973541, 22.05845833], [88.69016266, 22.05805016], [88.69052887, 22.05766106], [88.69083405, 22.05732346], [88.69111633, 22.05705261], [88.69139862, 22.05682182], [88.6917038, 22.0565815], [88.69204712, 22.05629921], [88.69241333, 22.05596161], [88.69280243, 22.05556107], [88.69320679, 22.05513954], [88.69367218, 22.05476952], [88.69415283, 22.0544529], [88.6946106, 22.05417061], [88.69500732, 22.05388069], [88.69538879, 22.05361366], [88.69573975, 22.05335045], [88.69610596, 22.05312157], [88.69631958, 22.0529995], [88.69649506, 22.05290031], [88.69690704, 22.05268288], [88.69729614, 22.05243492], [88.69769287, 22.05219078], [88.69804382, 22.05194283], [88.69838715, 22.05170441], [88.69876099, 22.05157089], [88.69904327, 22.05130959], [88.6995163, 22.05101967], [88.69998169, 22.05072021], [88.70041656, 22.05042076], [88.70083618, 22.0501194], [88.70128632, 22.04982185], [88.70173645, 22.04948997], [88.70226288, 22.04920959], [88.70284271, 22.04896927], [88.70343781, 22.04875946], [88.70401764, 22.04847908], [88.70456696, 22.04821205], [88.70510101, 22.04795647], [88.70561981, 22.04771042], [88.70613098, 22.04749107], [88.70659637, 22.04726982], [88.7071228, 22.04714966], [88.7075882, 22.04698181], [88.70809174, 22.04687119], [88.7085495, 22.04668808]]], [[[88.72927856, 22.11362076], [88.72894287, 22.11321831], [88.72850037, 22.1132412], [88.72807312, 22.11326981], [88.72734833, 22.11354065], [88.72725677, 22.11391068], [88.72741699, 22.11438942], [88.72751617, 22.11491966], [88.72769928, 22.11548805], [88.72785187, 22.1160717], [88.72801971, 22.11664963], [88.72805786, 22.11725998], [88.72809601, 22.11786652], [88.72828674, 22.11842346], [88.72834778, 22.11898994], [88.72843933, 22.11952972], [88.72861481, 22.11999321], [88.72875977, 22.12026978], [88.7288208, 22.12038994], [88.72888947, 22.12079048], [88.72897339, 22.12116814], [88.72913361, 22.12151146], [88.72920227, 22.12188721], [88.72939301, 22.12219048], [88.72947693, 22.12257957], [88.72969055, 22.12296867], [88.72985077, 22.12344933], [88.73010254, 22.12397003], [88.73047638, 22.12445068], [88.73088837, 22.12492943], [88.73135376, 22.12536621], [88.73155975, 22.12560272], [88.73177338, 22.12584114], [88.73216248, 22.12632942], [88.73257446, 22.12680817], [88.73310852, 22.12720108], [88.73363495, 22.12752914], [88.73407745, 22.12783432], [88.73444366, 22.12818336], [88.73480988, 22.12855339], [88.73526001, 22.12883186], [88.73580933, 22.12887573], [88.73627472, 22.12877655], [88.73651123, 22.12850189], [88.73664856, 22.12819099], [88.7366333, 22.12784958], [88.7364502, 22.12752914], [88.73634338, 22.12711143], [88.73615265, 22.12667084], [88.73607635, 22.12611961], [88.73590088, 22.12560272], [88.73583984, 22.12508011], [88.73582458, 22.12464905], [88.73575592, 22.12426949], [88.7355957, 22.1239624], [88.73551941, 22.12361908], [88.73530579, 22.12335014], [88.73512268, 22.12303925], [88.73497009, 22.12270164], [88.73475647, 22.12240982], [88.73458862, 22.12208176], [88.73446655, 22.12174034], [88.73439789, 22.12138939], [88.73417664, 22.12108994], [88.73400879, 22.12081146], [88.73387146, 22.12051773], [88.73374176, 22.1202507], [88.73361206, 22.1199398], [88.73350525, 22.11963654], [88.7333374, 22.11938095], [88.73314667, 22.11912537], [88.73298645, 22.11881828], [88.7327652, 22.11855888], [88.7325058, 22.11825752], [88.73226166, 22.11787033], [88.73207092, 22.11736107], [88.73179626, 22.11681557], [88.73142242, 22.11626053], [88.73104095, 22.11565971], [88.73055267, 22.1151104], [88.73002625, 22.1146183], [88.72957611, 22.11413193], [88.72927856, 22.11362076]]], [[[88.84053802, 22.12470245], [88.83992004, 22.12475204], [88.83927155, 22.12487984], [88.83862305, 22.12500191], [88.83797455, 22.12509918], [88.83737183, 22.12523079], [88.83679199, 22.12528038], [88.83625031, 22.12528038], [88.83574677, 22.12532234], [88.83531952, 22.12548256], [88.8348465, 22.12555122], [88.8343811, 22.12561226], [88.83397675, 22.12577248], [88.83348846, 22.12584114], [88.83299255, 22.12592125], [88.83251953, 22.12606812], [88.83203125, 22.12617493], [88.8316803, 22.12637138], [88.83135986, 22.12656975], [88.83106995, 22.12672997], [88.83085632, 22.12691116], [88.83069611, 22.12708092], [88.83058929, 22.12731934], [88.83056641, 22.1276226], [88.83061981, 22.12795258], [88.83076477, 22.12829781], [88.83091736, 22.12873268], [88.83111572, 22.12917519], [88.8313446, 22.12956429], [88.83156586, 22.12991142], [88.83182526, 22.13024712], [88.83218384, 22.13054276], [88.83270264, 22.1307621], [88.83332062, 22.13083076], [88.833992, 22.13080025], [88.83457184, 22.13065147], [88.83503723, 22.13041496], [88.83544159, 22.13055992], [88.83583069, 22.13079453], [88.83628845, 22.13086128], [88.83670807, 22.13101006], [88.8371582, 22.13113022], [88.83760834, 22.1313324], [88.8381424, 22.13149071], [88.83866119, 22.13171196], [88.83921814, 22.13195229], [88.83979797, 22.13223267], [88.84039307, 22.1325016], [88.84101105, 22.13277054], [88.8416214, 22.13300133], [88.84218597, 22.13317299], [88.84261322, 22.13335228], [88.84289551, 22.13355827], [88.84317017, 22.13372231], [88.84351349, 22.13391685], [88.84391785, 22.13419151], [88.84436798, 22.13451958], [88.84477997, 22.13494492], [88.84519196, 22.13535118], [88.84553528, 22.13581657], [88.84586334, 22.1362896], [88.84617615, 22.1367321], [88.8465271, 22.13709068], [88.8469162, 22.13739586], [88.84724426, 22.13772583], [88.84758759, 22.13802147], [88.84799194, 22.13824463], [88.848526, 22.13835907], [88.84907532, 22.13855553], [88.84970856, 22.13862038], [88.85037231, 22.13872147], [88.85102844, 22.1388607], [88.85169983, 22.13889122], [88.85235596, 22.13889122], [88.85299683, 22.13889122], [88.85359192, 22.13893318], [88.85412598, 22.13911819], [88.85470581, 22.13916969], [88.85527802, 22.13922119], [88.85578156, 22.13940239], [88.85630035, 22.1394825], [88.85675812, 22.13964653], [88.85723114, 22.13976479], [88.85762787, 22.13998222], [88.85804749, 22.14018059], [88.85845947, 22.14042091], [88.85879517, 22.14074326], [88.85910797, 22.1410923], [88.85942841, 22.14138985], [88.85970306, 22.14165306], [88.85991669, 22.14188957], [88.8600769, 22.14217186], [88.86024475, 22.14244843], [88.86032104, 22.14282036], [88.86049652, 22.14320946], [88.86058044, 22.14365387], [88.86073303, 22.1440773], [88.86081696, 22.14454079], [88.86083221, 22.14503479], [88.86083221, 22.14550018], [88.86083221, 22.14596939], [88.86083221, 22.14641571], [88.86080933, 22.14684105], [88.86069489, 22.14722252], [88.86054993, 22.14759254], [88.86038208, 22.14796829], [88.86023712, 22.14838219], [88.86000061, 22.14873314], [88.85971069, 22.14906883], [88.85939789, 22.14940453], [88.85904694, 22.14970016], [88.85865784, 22.1499424], [88.85822296, 22.15012169], [88.85780334, 22.15030098], [88.85739136, 22.15054512], [88.856987, 22.15077019], [88.85659027, 22.15094185], [88.85634613, 22.15116119], [88.85617828, 22.15134239], [88.85611725, 22.15160179], [88.85610962, 22.15188789], [88.85614777, 22.15224266], [88.85630035, 22.15262032], [88.85637665, 22.15314293], [88.85643768, 22.15378189], [88.85662079, 22.15446854], [88.85662079, 22.15514565], [88.85640717, 22.1557312], [88.85621643, 22.15629005], [88.8560791, 22.15685081], [88.85582733, 22.15733337], [88.8555069, 22.1577816], [88.85508728, 22.15813255], [88.85468292, 22.15850258], [88.85424805, 22.15878105], [88.85374451, 22.15894127], [88.85329437, 22.15917397], [88.85288239, 22.1594429], [88.85249329, 22.15971184], [88.85211945, 22.15998268], [88.85173798, 22.1602211], [88.85140228, 22.16048241], [88.85109711, 22.16074753], [88.85082245, 22.16103172], [88.85051727, 22.16132355], [88.85018158, 22.16161728], [88.84979248, 22.16191292], [88.84944153, 22.16234779], [88.84909821, 22.16285324], [88.84880066, 22.16344261], [88.84858704, 22.16410255], [88.84836578, 22.16473961], [88.84827423, 22.16535568], [88.84809875, 22.16589165], [88.84806061, 22.16642952], [88.8480835, 22.16692924], [88.8482132, 22.16737747], [88.84832001, 22.16781044], [88.84841156, 22.16823006], [88.84860992, 22.16858292], [88.84884644, 22.16888809], [88.84910583, 22.16917229], [88.84938812, 22.16942024], [88.84973907, 22.16960144], [88.8501358, 22.16975021], [88.85054779, 22.16995239], [88.85105133, 22.16999817], [88.85160065, 22.17004395], [88.85215759, 22.17018509], [88.85276031, 22.17026329], [88.8533783, 22.17023087], [88.85392761, 22.17004395], [88.85449982, 22.16995811], [88.85500336, 22.16977119], [88.85558319, 22.1697216], [88.85616302, 22.16964149], [88.8567276, 22.16946793], [88.85730743, 22.16934013], [88.85782623, 22.1691494], [88.85832214, 22.16893768], [88.85888672, 22.16885185], [88.85939789, 22.16864967], [88.85987854, 22.16853714], [88.86026001, 22.16835213], [88.860672, 22.1682148], [88.8610611, 22.16805077], [88.86144257, 22.16788292], [88.86184692, 22.16776085], [88.86223602, 22.16761971], [88.86263275, 22.16750145], [88.86300659, 22.16737747], [88.86347961, 22.16730881], [88.86392212, 22.16724205], [88.86434937, 22.16722298], [88.86473083, 22.16717339], [88.86514282, 22.16699028], [88.86566162, 22.16694069], [88.86628723, 22.16694069], [88.86694336, 22.16699028], [88.86753845, 22.1671772], [88.86813354, 22.16723251], [88.86868286, 22.16731071], [88.86915588, 22.16748238], [88.86965942, 22.167593], [88.87014008, 22.1677494], [88.87064362, 22.16783333], [88.87109375, 22.16801262], [88.87161255, 22.16805077], [88.87214661, 22.16806221], [88.87269592, 22.16806221], [88.8732605, 22.16805077], [88.87594604, 22.16805077], [88.8762207, 22.1680584], [88.87648773, 22.16806221], [88.87703705, 22.16806221], [88.87760162, 22.16805077], [88.87815094, 22.16801262], [88.87863922, 22.1678257], [88.87917328, 22.16777992], [88.87970734, 22.16774178], [88.88021088, 22.16758537], [88.88072968, 22.16747284], [88.88115692, 22.16723061], [88.8815918, 22.16702271], [88.88205719, 22.16682816], [88.88253021, 22.1666317], [88.88297272, 22.16637993], [88.88339996, 22.16611099], [88.88384247, 22.16583061], [88.88431549, 22.16555977], [88.88484955, 22.16530991], [88.88545227, 22.16509056], [88.88608551, 22.16482925], [88.8866272, 22.16445351], [88.88703156, 22.16394615], [88.88745117, 22.16344261], [88.88772583, 22.16283226], [88.88803101, 22.16225052], [88.88833618, 22.16170311], [88.88864899, 22.16119385], [88.88899994, 22.16072273], [88.88936615, 22.16026115], [88.88977814, 22.15979195], [88.89022827, 22.15936089], [88.89064789, 22.1589222], [88.89105225, 22.15852165], [88.89134979, 22.15810966], [88.8916626, 22.15780067], [88.89195251, 22.15749168], [88.89222717, 22.15715981], [88.89250183, 22.15677071], [88.89277649, 22.15633011], [88.89305878, 22.15586281], [88.89332581, 22.1554203], [88.89360809, 22.15504456], [88.89386749, 22.15473366], [88.8940506, 22.15442848], [88.89420319, 22.15413094], [88.89435577, 22.15388489], [88.89453125, 22.15364265], [88.89472198, 22.15340233], [88.89491272, 22.15313148], [88.89512634, 22.15280724], [88.89544678, 22.15247154], [88.89583588, 22.15207291], [88.89628601, 22.15163231], [88.89673615, 22.15114975], [88.8972168, 22.15069008], [88.89768219, 22.15025139], [88.89813995, 22.14980125], [88.89863586, 22.14940071], [88.89909363, 22.14896393], [88.89953613, 22.14852715], [88.89994049, 22.14809227], [88.900177, 22.14756966], [88.90026855, 22.14696312], [88.90032959, 22.14633751], [88.9005127, 22.14574242], [88.90055847, 22.14503479], [88.90062714, 22.14431953], [88.90078735, 22.14363289], [88.90083313, 22.14291954], [88.90083313, 22.14225006], [88.90087128, 22.14165306], [88.90104675, 22.14114189], [88.90112305, 22.1406498], [88.90122223, 22.14017105], [88.90137482, 22.13970184], [88.90148926, 22.13922119], [88.90167999, 22.13877296], [88.90190125, 22.13834572], [88.9020462, 22.1378231], [88.9022522, 22.13734245], [88.90249634, 22.13694382], [88.90271759, 22.13657188], [88.90287018, 22.1361351], [88.90307617, 22.1356926], [88.90335846, 22.13523293], [88.90363312, 22.13469124], [88.90390015, 22.13415527], [88.90416718, 22.1336422], [88.90444183, 22.13319397], [88.9046936, 22.1327877], [88.90486908, 22.13235283], [88.90504456, 22.13191223], [88.90528107, 22.13145256], [88.90556335, 22.13094139], [88.90583038, 22.13037109], [88.90611267, 22.12979317], [88.90643311, 22.12926292], [88.90674591, 22.12882042], [88.90705872, 22.12848091], [88.90727997, 22.12812233], [88.90752411, 22.12780952], [88.90777588, 22.12751961], [88.90802002, 22.12724113], [88.90822601, 22.12696266], [88.90847015, 22.1267128], [88.90876007, 22.12651443], [88.90904999, 22.12623024], [88.90939331, 22.12589073], [88.90979004, 22.12550163], [88.91027069, 22.1251049], [88.91075134, 22.12464142], [88.91118622, 22.12410927], [88.91165924, 22.12360954], [88.91217041, 22.12313461], [88.91272736, 22.12276268], [88.91319275, 22.12235451], [88.91356659, 22.12192726], [88.91390228, 22.12153053], [88.91425323, 22.12117958], [88.91464996, 22.12087631], [88.91499329, 22.12050056], [88.91472626, 22.12056351], [88.91665649, 22.11861229], [88.91665649, 22.11832809], [88.91700745, 22.11800575], [88.91736603, 22.11763191], [88.91771698, 22.11727333], [88.91798401, 22.11687279], [88.91815948, 22.11641502], [88.91835785, 22.11597824], [88.91860962, 22.11559105], [88.9188385, 22.11518478], [88.91901398, 22.11472893], [88.91921234, 22.11427116], [88.919487, 22.1138382], [88.91979218, 22.11342049], [88.9201889, 22.1130619], [88.92060852, 22.11269951], [88.92095184, 22.11223412], [88.9213028, 22.11175728], [88.92160797, 22.11129951], [88.92179871, 22.11086082], [88.92195892, 22.11050224], [88.92212677, 22.11022758], [88.92224884, 22.10993195], [88.92241669, 22.10965157], [88.92254639, 22.10929108], [88.92274475, 22.10895348], [88.92285919, 22.10854912], [88.92302704, 22.1081295], [88.92312622, 22.10758018], [88.92331696, 22.10698128], [88.92344666, 22.10628319], [88.92357635, 22.10555077], [88.9236145, 22.1048336], [88.92357635, 22.10415649], [88.92341614, 22.10355949], [88.92334747, 22.10301018], [88.92333221, 22.10252953], [88.92328644, 22.10210228], [88.92310333, 22.10172081], [88.9228363, 22.10133171], [88.92267609, 22.10081482], [88.9227829, 22.10000229], [88.92240906, 22.09947777], [88.92201233, 22.09905052], [88.92169189, 22.09864235], [88.92140961, 22.09827232], [88.92119598, 22.09787178], [88.92102814, 22.09743309], [88.92082214, 22.09698296], [88.92060089, 22.09656715], [88.92043304, 22.09612083], [88.92024994, 22.09568977], [88.91999817, 22.09531975], [88.91971588, 22.09496117], [88.91945648, 22.09457016], [88.91921234, 22.09414101], [88.91893768, 22.09369278], [88.91860962, 22.09331131], [88.91832733, 22.09290123], [88.91805267, 22.0925312], [88.91779327, 22.09221077], [88.91756439, 22.09188652], [88.91735077, 22.09153175], [88.91703033, 22.09120178], [88.91662598, 22.0908947], [88.91617584, 22.0906086], [88.9157486, 22.09029961], [88.91527557, 22.09004593], [88.914711, 22.08995247], [88.91420746, 22.08976173], [88.91371155, 22.08963966], [88.91324615, 22.0894413], [88.91282654, 22.08923149], [88.91239166, 22.08905983], [88.91194916, 22.08887482], [88.91156769, 22.08863258], [88.91111755, 22.08847618], [88.91068268, 22.08831215], [88.91028595, 22.08809471], [88.90986633, 22.0879879], [88.90957642, 22.08779907], [88.90930176, 22.08763313], [88.90904999, 22.08748055], [88.90879059, 22.08730125], [88.90844727, 22.08719254], [88.90808868, 22.08702278], [88.90764618, 22.08708], [88.90721893, 22.08723831], [88.9068222, 22.08749962], [88.90641022, 22.08777618], [88.90595245, 22.08805466], [88.90547943, 22.08833122], [88.90499878, 22.0886097], [88.90454102, 22.08889198], [88.90406799, 22.08917046], [88.90361023, 22.0894413], [88.90312958, 22.08967018], [88.90258789, 22.08976173], [88.90207672, 22.08996582], [88.90149689, 22.09007072], [88.90091705, 22.09024239], [88.90027618, 22.09028053], [88.89959717, 22.09028053], [88.89894104, 22.09027863], [88.89831543, 22.09028816], [88.8977356, 22.09035301], [88.89723206, 22.09050941], [88.8967514, 22.09058952], [88.89644623, 22.09079552], [88.89628601, 22.09115028], [88.89639282, 22.09176064], [88.89653015, 22.09238243], [88.89668274, 22.09300232], [88.89678955, 22.09358406], [88.89672852, 22.09415436], [88.89665985, 22.09472275], [88.89659882, 22.09531212], [88.89646149, 22.09591293], [88.89627838, 22.0965786], [88.89597321, 22.09723663], [88.89551544, 22.09775162], [88.8950119, 22.09813118], [88.89448547, 22.0981369], [88.89395142, 22.09819984], [88.89343262, 22.09836769], [88.89296722, 22.09860039], [88.89256287, 22.0988102], [88.89218903, 22.0989418], [88.89189148, 22.09908295], [88.89157867, 22.09922981], [88.89124298, 22.09950066], [88.89090729, 22.09991455], [88.89066315, 22.10046387], [88.89052582, 22.10104179], [88.8904953, 22.10164452], [88.89055634, 22.1022644], [88.89068604, 22.10282516], [88.89089966, 22.10337257], [88.89113617, 22.10390091], [88.89135742, 22.10440445], [88.89155579, 22.1049099], [88.89173889, 22.10547066], [88.89190674, 22.10609245], [88.89202118, 22.10676765], [88.8921051, 22.10748482], [88.89216614, 22.10819244], [88.89217377, 22.1088562], [88.89214325, 22.10951233], [88.89208221, 22.1101017], [88.89207458, 22.11061859], [88.89215851, 22.11114311], [88.89222717, 22.11174965], [88.89228821, 22.11230278], [88.89245605, 22.11288261], [88.89273834, 22.11350822], [88.89277649, 22.11416626], [88.89277649, 22.11444855], [88.89221954, 22.11444855], [88.89194489, 22.11416626], [88.89194489, 22.11361122], [88.89183044, 22.11343193], [88.89180756, 22.11283493], [88.89170074, 22.11229515], [88.89160156, 22.11178017], [88.89149475, 22.11128807], [88.89147949, 22.11078072], [88.89148712, 22.11026192], [88.89141083, 22.10979462], [88.89134216, 22.10931206], [88.89126587, 22.10881042], [88.8911438, 22.10832787], [88.89108276, 22.10783005], [88.89103699, 22.10732079], [88.89096832, 22.10682106], [88.89086914, 22.10630226], [88.89078522, 22.10581779], [88.89066315, 22.10532951], [88.89053345, 22.10480881], [88.89038086, 22.10428047], [88.8901825, 22.10376167], [88.88993835, 22.10330009], [88.8897171, 22.10284805], [88.88954163, 22.10242271], [88.88948822, 22.10197639], [88.88951111, 22.10151863], [88.88961029, 22.10104942], [88.88968658, 22.1005497], [88.88973999, 22.10000038], [88.88988495, 22.09947205], [88.89031219, 22.09898186], [88.89087677, 22.09858513], [88.89147186, 22.09824944], [88.8920517, 22.09796143], [88.89261627, 22.09770012], [88.89321899, 22.09748268], [88.89391327, 22.09729385], [88.89444733, 22.09711266], [88.89485168, 22.09682465], [88.89517975, 22.0964222], [88.89542389, 22.09590149], [88.89552307, 22.09530067], [88.89554596, 22.09468269], [88.89554596, 22.09404373], [88.89555359, 22.09339905], [88.89553833, 22.09275246], [88.89547729, 22.09213066], [88.8952713, 22.09166145], [88.89496613, 22.09122276], [88.89454651, 22.09085274], [88.89399719, 22.09059715], [88.89332581, 22.09050179], [88.89263153, 22.09033585], [88.89188385, 22.09023285], [88.89122772, 22.08999062], [88.89060974, 22.08972359], [88.89001465, 22.08944511], [88.88944244, 22.08917046], [88.88889313, 22.08889198], [88.88835144, 22.08860207], [88.88785553, 22.08826256], [88.88742065, 22.08785629], [88.88691711, 22.08753014], [88.88639832, 22.08723831], [88.8859024, 22.0869503], [88.88538361, 22.08671188], [88.88484955, 22.08654976], [88.88439941, 22.08630371], [88.88388062, 22.08609581], [88.88335419, 22.08588982], [88.88279724, 22.08579063], [88.88225555, 22.08563042], [88.8815918, 22.08556938], [88.88130188, 22.08556175], [88.88085938, 22.08556175], [88.88025665, 22.08561134], [88.87973022, 22.08578873], [88.87921143, 22.08585167], [88.87876129, 22.08596992], [88.87835693, 22.08612251], [88.87796021, 22.08630943], [88.87747955, 22.08644485], [88.87699127, 22.08662605], [88.8764801, 22.08671188], [88.8760376, 22.08690071], [88.87554169, 22.08697701], [88.87508392, 22.08712006], [88.87460327, 22.08721352], [88.87413025, 22.08729362], [88.87366486, 22.08746147], [88.87316132, 22.08753395], [88.87271881, 22.08768272], [88.87225342, 22.08780479], [88.87185669, 22.08802986], [88.87146759, 22.08826256], [88.87107086, 22.08849144], [88.8706131, 22.08867073], [88.87019348, 22.08889961], [88.86979675, 22.08916283], [88.86936951, 22.08943367], [88.86891174, 22.08970451], [88.86844635, 22.09000397], [88.86801147, 22.09033012], [88.86763763, 22.09069824], [88.86726379, 22.09103966], [88.86679077, 22.09126091], [88.86633301, 22.09146309], [88.86591339, 22.09168053], [88.8655014, 22.09193993], [88.86503601, 22.0921917], [88.86454773, 22.09249306], [88.86399841, 22.0927906], [88.86342621, 22.09313011], [88.8629303, 22.09355927], [88.86235809, 22.09394264], [88.86183167, 22.09438133], [88.8612442, 22.09474754], [88.86071014, 22.09514046], [88.86024475, 22.09559631], [88.85986328, 22.09607124], [88.85943604, 22.09647942], [88.85900116, 22.09683609], [88.8585434, 22.09718323], [88.85806274, 22.09750175], [88.85758209, 22.09785271], [88.85714722, 22.09824944], [88.85669708, 22.09861946], [88.85632324, 22.0990696], [88.85587311, 22.09946823], [88.85542297, 22.09986305], [88.85497284, 22.10024071], [88.85452271, 22.10062218], [88.85410309, 22.10107231], [88.85366058, 22.10147858], [88.85327148, 22.10193825], [88.85289001, 22.10239601], [88.85253906, 22.10285187], [88.85222626, 22.10331154], [88.85194397, 22.10372734], [88.85166168, 22.10407448], [88.85139465, 22.10437584], [88.8511734, 22.10467339], [88.85099792, 22.10499763], [88.85083771, 22.10533142], [88.85070801, 22.10567284], [88.85054779, 22.1060009], [88.85037231, 22.10631943], [88.85024261, 22.1066761], [88.85004425, 22.10697365], [88.84999084, 22.1073513], [88.84990692, 22.10771179], [88.84976196, 22.10803032], [88.84971619, 22.10839272], [88.84971619, 22.10878944], [88.84972382, 22.10920525], [88.84971619, 22.10963249], [88.84972382, 22.11007118], [88.84971619, 22.11051369], [88.84967804, 22.11095238], [88.84953308, 22.11137962], [88.84966278, 22.11180305], [88.84971619, 22.1122303], [88.84972382, 22.11267281], [88.84972382, 22.1131115], [88.84972382, 22.113554], [88.84972382, 22.11399651], [88.84967804, 22.11442375], [88.8494873, 22.1147747], [88.84944153, 22.11515617], [88.84939575, 22.11552048], [88.84924316, 22.11580276], [88.84915161, 22.11615944], [88.84903717, 22.11651039], [88.84889984, 22.11687279], [88.84881592, 22.11725044], [88.84864044, 22.11753464], [88.848526, 22.11783791], [88.84833527, 22.11807442], [88.84810638, 22.11834145], [88.84786224, 22.11865425], [88.84763336, 22.11905289], [88.84741974, 22.11952019], [88.84719086, 22.11998177], [88.84693909, 22.12043381], [88.84667969, 22.12086487], [88.84645844, 22.12130165], [88.84617615, 22.12165451], [88.84586334, 22.12196159], [88.84552002, 22.12226295], [88.84519958, 22.12257385], [88.84485626, 22.12289238], [88.84438324, 22.12312126], [88.84391785, 22.12334633], [88.84348297, 22.12360954], [88.84304047, 22.12386131], [88.8425293, 22.12401009], [88.84204865, 22.12419319], [88.84160614, 22.12442017], [88.84108734, 22.12458229], [88.84053802, 22.12470245]]], [[[88.76145172, 22.08918571], [88.76100159, 22.08905029], [88.76056671, 22.08889198], [88.76013947, 22.08874512], [88.75972748, 22.08860207], [88.75932312, 22.08841133], [88.75887299, 22.08831406], [88.75844574, 22.08816719], [88.75807953, 22.08799171], [88.75772095, 22.08777046], [88.75736237, 22.08753014], [88.75695801, 22.08733749], [88.75656128, 22.08712006], [88.75617218, 22.08690453], [88.7558136, 22.08664894], [88.75544739, 22.08638573], [88.75508118, 22.08611107], [88.75469208, 22.0858326], [88.75429535, 22.08555794], [88.75388336, 22.08527946], [88.75344086, 22.08498955], [88.75302124, 22.08467865], [88.75263977, 22.08431053], [88.75222778, 22.08396912], [88.7518158, 22.08361244], [88.7514267, 22.08324242], [88.75110626, 22.08284378], [88.75078583, 22.08246422], [88.75047302, 22.08212471], [88.75020599, 22.08173561], [88.74989319, 22.0813961], [88.74958801, 22.08105659], [88.74935913, 22.08064079], [88.74907684, 22.08027077], [88.74878693, 22.07989311], [88.74853516, 22.07948112], [88.7482605, 22.07908821], [88.74803925, 22.07867813], [88.74780273, 22.07832527], [88.74762726, 22.07792091], [88.74745941, 22.0775013], [88.74718475, 22.07715416], [88.74692535, 22.07668877], [88.74666595, 22.07621384], [88.74637604, 22.07574272], [88.74606323, 22.07530022], [88.74568176, 22.07484245], [88.74521637, 22.07437706], [88.74474335, 22.07385063], [88.74429321, 22.07328224], [88.74390411, 22.07267952], [88.74360657, 22.07208061], [88.74338531, 22.07154083], [88.74331665, 22.07092476], [88.74318695, 22.07033157], [88.74295044, 22.06980324], [88.74256897, 22.06936836], [88.74221802, 22.06889153], [88.74192047, 22.06833267], [88.74166107, 22.0677948], [88.7414093, 22.06728935], [88.74121094, 22.06678963], [88.74095917, 22.06638336], [88.74069977, 22.06593323], [88.74053192, 22.06530952], [88.74032593, 22.06467056], [88.74028778, 22.06396866], [88.74027252, 22.06333733], [88.74028778, 22.06279182], [88.74028015, 22.06232452], [88.74028015, 22.06189919], [88.74027252, 22.06146049], [88.74021912, 22.06099129], [88.74005127, 22.06051826], [88.73995972, 22.05999184], [88.73980713, 22.05951118], [88.73973846, 22.05903625], [88.73972321, 22.05857277], [88.7396698, 22.05811119], [88.73949432, 22.05769539], [88.73940277, 22.05727005], [88.73916626, 22.05699158], [88.73882294, 22.05685234], [88.7383728, 22.05670547], [88.73781586, 22.05667305], [88.73719788, 22.05664253], [88.73655701, 22.05653954], [88.73590851, 22.05645943], [88.73536682, 22.05656815], [88.73488617, 22.05664635], [88.73448181, 22.05666351], [88.73416138, 22.05667305], [88.73306274, 22.05667305], [88.73284912, 22.05666351], [88.73239899, 22.05656242], [88.7318573, 22.05643272], [88.73129272, 22.05639076], [88.73101807, 22.05639076], [88.73043823, 22.05639076], [88.73005676, 22.05639076], [88.72968292, 22.05639076], [88.72720337, 22.05639076], [88.72679901, 22.05639076], [88.72638702, 22.05639076], [88.72593689, 22.05639076], [88.72544861, 22.05642128], [88.7249527, 22.05656242], [88.72441864, 22.05666351], [88.72387695, 22.05667305], [88.7233963, 22.05669212], [88.72294617, 22.05677986], [88.7225647, 22.0569191], [88.7221756, 22.05702591], [88.7218399, 22.05721283], [88.72146606, 22.05739021], [88.72101593, 22.0574398], [88.72054291, 22.05751228], [88.7201004, 22.05759811], [88.71961212, 22.05757523], [88.71917725, 22.05761147], [88.71875, 22.05767822], [88.71833038, 22.05772209], [88.7179184, 22.05779076], [88.71749878, 22.05787086], [88.71708679, 22.05797005], [88.71666718, 22.0580616], [88.71624756, 22.05816078], [88.7158432, 22.05825233], [88.71541595, 22.05836678], [88.71499634, 22.05846977], [88.71457672, 22.05857849], [88.7141571, 22.05870247], [88.71375275, 22.05880928], [88.71333313, 22.05895233], [88.71292114, 22.05912209], [88.71248627, 22.05934143], [88.7120285, 22.05960274], [88.71157837, 22.05992317], [88.71111298, 22.06028175], [88.71055603, 22.0605545], [88.71028137, 22.06083298], [88.7097168, 22.06110954], [88.70944214, 22.06139183], [88.70889282, 22.0616703], [88.70861053, 22.06194687], [88.70804596, 22.06221962], [88.70777893, 22.06250191], [88.70722198, 22.06278038], [88.70694733, 22.06305695], [88.70639038, 22.06333351], [88.70549774, 22.06422424], [88.70471954, 22.06500053], [88.70471954, 22.06528282], [88.70439911, 22.06606293], [88.70430756, 22.06648064], [88.70425415, 22.06690788], [88.70409393, 22.06750488], [88.70378113, 22.06780052], [88.70349884, 22.0681076], [88.70332336, 22.06851006], [88.70316315, 22.06892204], [88.70307159, 22.06936073], [88.70300293, 22.06982994], [88.70282745, 22.07030296], [88.70278168, 22.07085228], [88.70276642, 22.07142067], [88.7027359, 22.07196808], [88.70258331, 22.07245064], [88.70248413, 22.0729084], [88.70236206, 22.07334328], [88.70224762, 22.07380295], [88.70222473, 22.07432747], [88.7022171, 22.07486153], [88.70223236, 22.07539368], [88.70230865, 22.07589149], [88.70244598, 22.07641029], [88.70249176, 22.07693863], [88.70249939, 22.07745552], [88.70253754, 22.07795143], [88.70271301, 22.07839012], [88.70292664, 22.07884026], [88.70326233, 22.0792408], [88.70359802, 22.0797081], [88.70396423, 22.0802002], [88.70437622, 22.08064079], [88.70471954, 22.08109665], [88.70510101, 22.08146286], [88.70555115, 22.08172989], [88.70601654, 22.08198166], [88.70646667, 22.08229065], [88.70691681, 22.08263016], [88.70733643, 22.08300781], [88.70777893, 22.08333015], [88.70819855, 22.08364296], [88.70858765, 22.08398819], [88.70895386, 22.08436775], [88.70936584, 22.08469963], [88.70986176, 22.08495522], [88.71038818, 22.08513069], [88.71089172, 22.08535194], [88.71137238, 22.08558846], [88.71183014, 22.08584595], [88.71225739, 22.08611488], [88.71264648, 22.08638191], [88.71304321, 22.08662224], [88.71350098, 22.08674049], [88.71392059, 22.0869503], [88.71434784, 22.08712006], [88.71477509, 22.0872879], [88.71517181, 22.08751106], [88.71555328, 22.08778191], [88.71592712, 22.08804131], [88.71633911, 22.08829117], [88.7167511, 22.08859062], [88.71721649, 22.08890915], [88.71774292, 22.08928108], [88.71824646, 22.08975029], [88.71877289, 22.09025002], [88.71932983, 22.09071159], [88.71989441, 22.09115791], [88.72042847, 22.09164238], [88.72100067, 22.09211159], [88.72158051, 22.09255981], [88.72206879, 22.09303474], [88.72251129, 22.09345055], [88.72293854, 22.09378242], [88.72332764, 22.09410667], [88.72370148, 22.09443474], [88.72408295, 22.09476471], [88.72444916, 22.09513283], [88.72480774, 22.09551048], [88.72518158, 22.09584236], [88.72551727, 22.09613609], [88.72580719, 22.09641075], [88.72608185, 22.09666824], [88.72637939, 22.09692955], [88.72673798, 22.09722328], [88.72717285, 22.0975399], [88.72761536, 22.09789085], [88.72807312, 22.09822273], [88.72850037, 22.09852028], [88.72886658, 22.09885216], [88.7292099, 22.09921265], [88.72956848, 22.09955406], [88.72997284, 22.09986305], [88.73035431, 22.10020447], [88.73078918, 22.10051155], [88.73118591, 22.10083199], [88.73156738, 22.10111618], [88.73189545, 22.10140038], [88.73219299, 22.10168266], [88.73248291, 22.10199165], [88.73278046, 22.10233116], [88.73312378, 22.10268211], [88.73352051, 22.10298347], [88.73387146, 22.10332298], [88.73420715, 22.10366249], [88.73455048, 22.10400963], [88.73485565, 22.1044426], [88.73517609, 22.10489082], [88.73552704, 22.10532951], [88.73583221, 22.10584259], [88.7361145, 22.10638618], [88.73638916, 22.10694313], [88.73665619, 22.10749245], [88.73694611, 22.1079998], [88.73722076, 22.10845947], [88.73750305, 22.10889435], [88.73773956, 22.10933113], [88.73789978, 22.1098423], [88.73808289, 22.11034393], [88.73832703, 22.11079216], [88.73860168, 22.1112175], [88.73884583, 22.11161995], [88.73906708, 22.1119709], [88.73925018, 22.11228752], [88.73944092, 22.11255455], [88.73963165, 22.1128521], [88.73979187, 22.11329079], [88.74001312, 22.11373329], [88.74028015, 22.11418152], [88.74054718, 22.11460304], [88.74077606, 22.11503029], [88.74088287, 22.11555862], [88.74108887, 22.11602974], [88.74127197, 22.11657143], [88.74141693, 22.1171627], [88.74164581, 22.11774254], [88.74183655, 22.11834526], [88.74201965, 22.11894035], [88.74224854, 22.1194706], [88.74250031, 22.11996269], [88.74278259, 22.12043953], [88.74304962, 22.12090492], [88.74328613, 22.12140465], [88.74339294, 22.12201118], [88.74357605, 22.12262154], [88.74369049, 22.12322617], [88.74385071, 22.12375259], [88.74394989, 22.1242466], [88.74415588, 22.12460136], [88.74436951, 22.12492943], [88.74459076, 22.12526894], [88.74484253, 22.12561226], [88.74503326, 22.12602043], [88.7452774, 22.12644005], [88.74552155, 22.12693977], [88.74563599, 22.12754059], [88.74542999, 22.12812233], [88.74513245, 22.12854195], [88.74516296, 22.1289196], [88.74524689, 22.12931824], [88.74530792, 22.12976456], [88.74543762, 22.13017273], [88.74559021, 22.1306076], [88.74581146, 22.13100243], [88.74600983, 22.13142967], [88.7461853, 22.13189125], [88.74640656, 22.13229942], [88.74666595, 22.13278008], [88.74777985, 22.13389015], [88.74804687, 22.13389015], [88.74916077, 22.13500023], [88.74944305, 22.13500023], [88.74973297, 22.13529015], [88.75, 22.13529015], [88.75026703, 22.1355629], [88.7508316, 22.13555717], [88.75111389, 22.13583565], [88.75166321, 22.13583565], [88.7519455, 22.13611031], [88.75250244, 22.13611031], [88.7527771, 22.1363945], [88.75305176, 22.1363945], [88.75332642, 22.13667107], [88.75416565, 22.13666725], [88.75444794, 22.13694572], [88.75527954, 22.13694572], [88.7555542, 22.13722229], [88.7563858, 22.13722038], [88.75666809, 22.13750458], [88.75749969, 22.13750458], [88.75776672, 22.13778114], [88.7583313, 22.13778114], [88.75860596, 22.13805962], [88.7591629, 22.1380558], [88.7592392, 22.13813019], [88.75944519, 22.13833427], [88.76000214, 22.13833046], [88.76018524, 22.13851929], [88.76027679, 22.13861275], [88.76110077, 22.13861275], [88.76139069, 22.13889122], [88.76167297, 22.13889122], [88.76194763, 22.13916969], [88.76249695, 22.13916588], [88.76263428, 22.13930321], [88.76277924, 22.13944435], [88.76333618, 22.13944435], [88.76361084, 22.13972282], [88.7647171, 22.13972282], [88.76499939, 22.1400013], [88.76526642, 22.1400013], [88.76583099, 22.14056206], [88.76638794, 22.14055824], [88.76667023, 22.1408329], [88.76722717, 22.1408329], [88.76860046, 22.14151955], [88.76888275, 22.14162827], [88.76917267, 22.1417408], [88.76969147, 22.14196014], [88.7701416, 22.14221001], [88.77058411, 22.14239693], [88.77104187, 22.14257431], [88.77146149, 22.14283943], [88.77190399, 22.1431179], [88.77233124, 22.14344215], [88.77278137, 22.14378357], [88.77324677, 22.14415169], [88.77379608, 22.14451027], [88.77432251, 22.14494514], [88.77445984, 22.14502144], [88.77494049, 22.14528847], [88.77553558, 22.14566994], [88.77609253, 22.14612007], [88.77655792, 22.14668274], [88.7769928, 22.14725494], [88.77745056, 22.14772987], [88.77787781, 22.14816284], [88.77823639, 22.148592], [88.77857208, 22.14899254], [88.778862, 22.14941978], [88.77913666, 22.14986992], [88.77935791, 22.15041924], [88.77948761, 22.15107155], [88.77972412, 22.15166092], [88.77999878, 22.15220261], [88.78027344, 22.15270996], [88.78053284, 22.15318108], [88.78073883, 22.15364838], [88.78089905, 22.15410042], [88.78112793, 22.15451241], [88.78141022, 22.15488243], [88.7817688, 22.15524292], [88.78222656, 22.15554619], [88.78276062, 22.15583229], [88.78334808, 22.15609932], [88.78395844, 22.1563015], [88.78463745, 22.1564312], [88.78523254, 22.15666962], [88.78579712, 22.15694237], [88.78633118, 22.15722084], [88.78681183, 22.15752792], [88.7872467, 22.15786171], [88.78772736, 22.15815163], [88.78817749, 22.1584301], [88.78868103, 22.15863228], [88.78916168, 22.15889168], [88.78959656, 22.15919495], [88.79000092, 22.1595211], [88.79039764, 22.159832], [88.79078674, 22.16010094], [88.79110718, 22.16043472], [88.79141235, 22.16077042], [88.79173279, 22.16109276], [88.79203796, 22.1613903], [88.79234314, 22.16169167], [88.79257202, 22.16201973], [88.7928009, 22.16233253], [88.79305267, 22.16250038], [88.79416656, 22.16361046], [88.79416656, 22.16388893], [88.79555511, 22.16527748], [88.79582977, 22.16526985], [88.79611206, 22.16555977], [88.79694366, 22.16555405], [88.79722595, 22.16583061], [88.79722595, 22.1661129], [88.79750061, 22.16639137], [88.79750061, 22.1669445], [88.7977829, 22.16722298], [88.7977829, 22.16777992], [88.79805756, 22.16806221], [88.79805756, 22.16888809], [88.79821777, 22.16888237], [88.79840851, 22.1694088], [88.79865265, 22.16988373], [88.79897308, 22.17028236], [88.79928589, 22.17069054], [88.79959869, 22.17109108], [88.79993439, 22.17145348], [88.80026245, 22.17181969], [88.80056, 22.17223167], [88.80084991, 22.17263985], [88.80119324, 22.17300987], [88.80157471, 22.17332649], [88.80197906, 22.17361259], [88.80237579, 22.17390442], [88.80272675, 22.17423058], [88.80306244, 22.17458916], [88.80337524, 22.17494392], [88.80370331, 22.17526054], [88.804039, 22.17556381], [88.80436707, 22.17585182], [88.8046875, 22.17617035], [88.80500793, 22.17652702], [88.805336, 22.17688942], [88.80571747, 22.17724037], [88.80610657, 22.17761993], [88.80649567, 22.17801094], [88.80696106, 22.17834282], [88.80747223, 22.17863274], [88.80800629, 22.17889977], [88.80857849, 22.17917061], [88.80919647, 22.17941093], [88.80990601, 22.17949295], [88.81058502, 22.17968559], [88.81123352, 22.17968178], [88.81180573, 22.1794529], [88.81231689, 22.17916679], [88.81281281, 22.17884254], [88.81324005, 22.17842102], [88.81369019, 22.17798042], [88.81417847, 22.17758179], [88.81467438, 22.17719078], [88.81516266, 22.17679024], [88.81561279, 22.17635155], [88.81607819, 22.17592049], [88.81647491, 22.17544365], [88.81678772, 22.17493629], [88.81723022, 22.17461967], [88.81768799, 22.17439079], [88.81807709, 22.17410278], [88.818367, 22.17369652], [88.81865692, 22.17328072], [88.81902313, 22.17295456], [88.81947327, 22.1727314], [88.81989288, 22.17245483], [88.82024384, 22.17210579], [88.82055664, 22.17171288], [88.82089233, 22.17134285], [88.82125854, 22.1709919], [88.82173157, 22.17075157], [88.82218933, 22.17042732], [88.82260895, 22.17001152], [88.82305145, 22.16960144], [88.82348633, 22.1692028], [88.8239975, 22.16887856], [88.82450104, 22.16855049], [88.82501221, 22.16823387], [88.82552338, 22.16793633], [88.82601929, 22.16759872], [88.82652283, 22.16725159], [88.82705688, 22.16694069], [88.82761383, 22.16661835], [88.82807922, 22.16621208], [88.82859039, 22.16584969], [88.82910156, 22.16555214], [88.82958984, 22.16529083], [88.83006287, 22.16509056], [88.830513, 22.16497231], [88.83090973, 22.1647625], [88.83141327, 22.16471672], [88.83197784, 22.1646595], [88.83260345, 22.16451836], [88.83326721, 22.16467094], [88.833992, 22.16476059], [88.83469391, 22.16494179], [88.83535767, 22.16503906], [88.83591461, 22.16525841], [88.83637238, 22.16543007], [88.83673096, 22.1656208], [88.8370285, 22.16584206], [88.83731079, 22.16610146], [88.83761597, 22.16637993], [88.83795929, 22.16668129], [88.83827209, 22.16703224], [88.83856201, 22.16744995], [88.83889008, 22.16789055], [88.83921814, 22.16838455], [88.83956146, 22.16887665], [88.83988953, 22.1693821], [88.84004974, 22.17002106], [88.84028625, 22.17062759], [88.84050751, 22.17123985], [88.84055328, 22.17197227], [88.84056091, 22.17276192], [88.84056091, 22.17353249], [88.84055328, 22.17427254], [88.84050751, 22.17494011], [88.84030914, 22.17548943], [88.84017944, 22.17605782], [88.83999634, 22.17657661], [88.83979797, 22.17706108], [88.83969116, 22.17756271], [88.83953094, 22.17799187], [88.8394165, 22.17835045], [88.83927917, 22.17865181], [88.8391571, 22.17897224], [88.83904266, 22.17928123], [88.83889008, 22.1795826], [88.83870697, 22.17990112], [88.83854675, 22.18022919], [88.83834076, 22.18055153], [88.83815002, 22.1808815], [88.8380127, 22.18123055], [88.83779907, 22.18152046], [88.83760071, 22.18185234], [88.83737946, 22.18224907], [88.83712006, 22.18274117], [88.83674622, 22.18326569], [88.83638, 22.18388748], [88.83601379, 22.18454552], [88.83564758, 22.18518257], [88.83529663, 22.18577194], [88.83500671, 22.18631554], [88.83475494, 22.18678474], [88.8345871, 22.18720055], [88.83442688, 22.18756866], [88.8342514, 22.18789101], [88.83413696, 22.18826866], [88.83395386, 22.1885643], [88.83377075, 22.18887138], [88.83355713, 22.18918037], [88.83332062, 22.18954849], [88.83304596, 22.1899395], [88.83278656, 22.19035149], [88.83254242, 22.19075012], [88.83239746, 22.19119072], [88.83222198, 22.19154167], [88.83204651, 22.19185257], [88.83193207, 22.19215393], [88.83177185, 22.19241142], [88.83164978, 22.19270134], [88.83149719, 22.19296265], [88.83137512, 22.19324875], [88.83120728, 22.1935215], [88.83107758, 22.19387245], [88.83085632, 22.19421959], [88.83067322, 22.19466209], [88.83036804, 22.19502068], [88.83003235, 22.19540405], [88.82971191, 22.19584084], [88.82937622, 22.19627953], [88.82894897, 22.1966114], [88.82849884, 22.19692612], [88.82802582, 22.19721031], [88.82753754, 22.19747925], [88.8270874, 22.19783974], [88.82676697, 22.19835854], [88.82668304, 22.19905472], [88.82659149, 22.19950676], [88.82649231, 22.19976234], [88.82640839, 22.19999123], [88.82639313, 22.2002449], [88.82639313, 22.20052147], [88.82635498, 22.20082664], [88.8262558, 22.20113182], [88.82614899, 22.20148277], [88.82611847, 22.20191002], [88.82611084, 22.2023716], [88.82611084, 22.20284653], [88.82611084, 22.2033329], [88.82611084, 22.20381927], [88.82611847, 22.20429039], [88.82616425, 22.20473289], [88.82629395, 22.20509148], [88.82640839, 22.2054348], [88.82656097, 22.20575905], [88.8266983, 22.20614052], [88.82689667, 22.20654106], [88.82710266, 22.20696068], [88.8273468, 22.20737267], [88.82769775, 22.20771217], [88.82805634, 22.20804024], [88.82845306, 22.20832253], [88.8289032, 22.20848274], [88.82939148, 22.20852852], [88.82987213, 22.20866394], [88.8303299, 22.20887184], [88.83081055, 22.20902061], [88.83132935, 22.20901489], [88.83178711, 22.20882225], [88.83229065, 22.20856285], [88.83280182, 22.20826149], [88.83336639, 22.2080822], [88.83398438, 22.20791054], [88.83454132, 22.20761108], [88.83503723, 22.20718956], [88.83547211, 22.20673561], [88.83581543, 22.20625114], [88.8360672, 22.20575142], [88.83623505, 22.20525169], [88.83634186, 22.20472145], [88.83641052, 22.20417976], [88.83650208, 22.20366287], [88.83657837, 22.20316124], [88.83661652, 22.20266151], [88.83666229, 22.2021637], [88.83672333, 22.20166969], [88.83681488, 22.2012043], [88.83687592, 22.2007618], [88.83694458, 22.2005558], [88.83693695, 22.20000267], [88.83753204, 22.19749832], [88.83769226, 22.19695091], [88.83782959, 22.19642067], [88.83797455, 22.19594574], [88.83811951, 22.19548988], [88.83826447, 22.19503212], [88.83841705, 22.19456673], [88.83862305, 22.19409752], [88.83886719, 22.19360161], [88.8391571, 22.19308281], [88.83952332, 22.19257164], [88.83990479, 22.19207954], [88.84028625, 22.19164085], [88.84069824, 22.19121933], [88.84114838, 22.19086266], [88.84165955, 22.19054031], [88.8421936, 22.19022179], [88.84272003, 22.1899128], [88.84321594, 22.18963051], [88.84378052, 22.18943024], [88.84427643, 22.18927193], [88.84474945, 22.18919182], [88.84516907, 22.18914986], [88.8455658, 22.18914986], [88.8459549, 22.18916893], [88.84633636, 22.18922615], [88.84670258, 22.18936348], [88.84714508, 22.18946266], [88.84763336, 22.18963242], [88.84810638, 22.18993378], [88.84863281, 22.19033241], [88.84914398, 22.19079971], [88.84960175, 22.19129372], [88.84996796, 22.19177055], [88.85025024, 22.19219971], [88.85045624, 22.19259071], [88.85059357, 22.19296455], [88.85076141, 22.19329262], [88.85090637, 22.1936512], [88.85109711, 22.19398308], [88.85128021, 22.19439125], [88.85138702, 22.19496346], [88.85138702, 22.19564247], [88.85134125, 22.19638252], [88.85122681, 22.19710159], [88.85114288, 22.19775963], [88.85112, 22.19836235], [88.85112, 22.19890594], [88.85114288, 22.19944954], [88.85118866, 22.2000103], [88.85132599, 22.20053291], [88.85144806, 22.20107079], [88.85160828, 22.20153999], [88.85173035, 22.20198822], [88.85189819, 22.20240211], [88.85209656, 22.20288277], [88.85241699, 22.2033596], [88.85279083, 22.20387077], [88.85324097, 22.20433235], [88.85374451, 22.20470238], [88.85427094, 22.20499611], [88.85480499, 22.20521355], [88.85540009, 22.20527077], [88.85601044, 22.20528221], [88.85662079, 22.20527077], [88.85727692, 22.20520973], [88.85793304, 22.20501137], [88.85855865, 22.20476913], [88.85912323, 22.20446777], [88.85961151, 22.20409966], [88.86004639, 22.20369339], [88.86048889, 22.20329475], [88.86086273, 22.20282936], [88.86122894, 22.20238495], [88.86154175, 22.20194244], [88.86181641, 22.20152092], [88.86207581, 22.20111275], [88.86234283, 22.20069313], [88.86255646, 22.20023155], [88.86280823, 22.19976234], [88.86306, 22.19932175], [88.86328888, 22.19889259], [88.86342621, 22.19841194], [88.86362457, 22.19798851], [88.86384583, 22.19761086], [88.86398315, 22.19715309], [88.86414337, 22.19667816], [88.86416626, 22.19619179], [88.86412048, 22.19572258], [88.86393738, 22.19528008], [88.8638916, 22.19480133], [88.86388397, 22.19429588], [88.8638916, 22.19376564], [88.8638916, 22.19320869], [88.8638916, 22.19262123], [88.8638916, 22.19199944], [88.8638916, 22.19135094], [88.8638916, 22.19067955], [88.86389923, 22.19001961], [88.86398315, 22.18939018], [88.86412811, 22.1888485], [88.86416626, 22.18835258], [88.86416626, 22.18791008], [88.86416626, 22.18754005], [88.86418152, 22.18720055], [88.86427307, 22.18685913], [88.86440277, 22.18650627], [88.86444855, 22.1860714], [88.86447906, 22.18559074], [88.86464691, 22.18513298], [88.86476135, 22.18458939], [88.86496735, 22.18408012], [88.86512756, 22.18346977], [88.86530304, 22.18286705], [88.86554718, 22.18229103], [88.86576843, 22.18170166], [88.86588287, 22.1810894], [88.86608124, 22.18061256], [88.8662262, 22.18018341], [88.86636353, 22.1798439], [88.86643219, 22.17950249], [88.86658478, 22.1792202], [88.86667633, 22.17888069], [88.86676788, 22.17852974], [88.86695099, 22.17823601], [88.86714172, 22.17790794], [88.86724854, 22.17746162], [88.86740112, 22.17702484], [88.86752319, 22.17658234], [88.86769867, 22.17617035], [88.86782837, 22.17571068], [88.86804199, 22.17530251], [88.86820984, 22.17482948], [88.86833191, 22.17426109], [88.86843872, 22.17364883], [88.86856079, 22.17303276], [88.86855316, 22.1723938], [88.86837769, 22.17179298], [88.86828613, 22.17118645], [88.86805725, 22.17071152], [88.86779785, 22.17030334], [88.86741638, 22.17000389], [88.86693573, 22.16981697], [88.86631012, 22.16995811], [88.86558533, 22.16999626], [88.86484528, 22.1699543], [88.86414337, 22.16979408], [88.86347961, 22.16986275], [88.86289978, 22.16999817], [88.86238861, 22.17012787], [88.86194611, 22.17025185], [88.86149597, 22.17031479], [88.86107635, 22.17044258], [88.86062622, 22.17058182], [88.86017609, 22.17080116], [88.85970306, 22.17099953], [88.85919189, 22.17118263], [88.85869598, 22.17140007], [88.85823822, 22.17167091], [88.85775757, 22.17192268], [88.85725403, 22.17207718], [88.85678101, 22.17226219], [88.8563385, 22.17250252], [88.85590363, 22.17272186], [88.85540009, 22.17282295], [88.85494995, 22.17300987], [88.85448456, 22.17306328], [88.85402679, 22.17312431], [88.85357666, 22.17329407], [88.85305786, 22.1733284], [88.85251617, 22.17337608], [88.85195923, 22.17356491], [88.85176086, 22.17358017], [88.85138702, 22.17361259], [88.85079193, 22.17356491], [88.85024261, 22.17338181], [88.84967804, 22.17329216], [88.84918976, 22.17310524], [88.84868622, 22.17297173], [88.84822083, 22.17276382], [88.84778595, 22.17250252], [88.84733582, 22.1722126], [88.84689331, 22.17189789], [88.84642029, 22.17152977], [88.84598541, 22.17109108], [88.84557343, 22.17060661], [88.84509277, 22.17025185], [88.84466553, 22.16991615], [88.8443985, 22.16953087], [88.84414673, 22.16922188], [88.84390259, 22.16891289], [88.84371948, 22.16855812], [88.84358215, 22.1681118], [88.84336853, 22.16768265], [88.84329987, 22.16717911], [88.84332275, 22.16668129], [88.84336853, 22.16615677], [88.84353638, 22.16558838], [88.84362793, 22.16492462], [88.84377289, 22.16422272], [88.84401703, 22.16362572], [88.84425354, 22.16309547], [88.84446716, 22.16267204], [88.84469604, 22.16236115], [88.84487152, 22.16208267], [88.84503937, 22.16179085], [88.84526062, 22.16151237], [88.84548187, 22.16119957], [88.84575653, 22.16090012], [88.84610748, 22.16061592], [88.84647369, 22.16030693], [88.84686279, 22.16000938], [88.84729004, 22.15972137], [88.84772491, 22.15944481], [88.84816742, 22.15916634], [88.84860992, 22.15886116], [88.84903717, 22.15846062], [88.84944916, 22.15805626], [88.84986115, 22.15764046], [88.85025787, 22.15719032], [88.85063934, 22.15676308], [88.85103607, 22.15644264], [88.85128021, 22.15607262], [88.85138702, 22.15570259], [88.85140991, 22.15538979], [88.85141754, 22.15513039], [88.85140991, 22.1549015], [88.85137177, 22.15467262], [88.85119629, 22.15442276], [88.85090637, 22.15416527], [88.85051727, 22.1539402], [88.84998322, 22.15383911], [88.84947968, 22.15367508], [88.84896088, 22.15356827], [88.84848022, 22.15337181], [88.84799194, 22.15324211], [88.84754944, 22.15303993], [88.84713745, 22.15282631], [88.84673309, 22.15260124], [88.84637451, 22.15229988], [88.84604645, 22.15197182], [88.84574127, 22.15163231], [88.84552002, 22.15122414], [88.84532166, 22.15081596], [88.84525299, 22.15032959], [88.84516144, 22.14986229], [88.8451767, 22.14946175], [88.84529114, 22.14907265], [88.84545898, 22.1486702], [88.84561157, 22.1482029], [88.84584808, 22.14776421], [88.846138, 22.1473484], [88.84648895, 22.14702034], [88.8469162, 22.1468029], [88.84733582, 22.14656258], [88.8478241, 22.14634323], [88.84837341, 22.14615059], [88.84897614, 22.14607048], [88.84950256, 22.14591599], [88.84999084, 22.1458416], [88.85045624, 22.14583015], [88.850914, 22.14583397], [88.85138702, 22.14583397], [88.85184479, 22.14583397], [88.85262299, 22.14583397], [88.85298157, 22.14583397], [88.85336304, 22.14582825], [88.85381317, 22.1458416], [88.85429382, 22.14590073], [88.85476685, 22.1460743], [88.85527039, 22.14607048], [88.85566711, 22.14586067], [88.85600281, 22.14563179], [88.85614777, 22.14529991], [88.85630035, 22.14500427], [88.85612488, 22.14472771], [88.85588837, 22.14445305], [88.85558319, 22.14418983], [88.85513306, 22.1440258], [88.85462952, 22.14388084], [88.85410309, 22.14365387], [88.85350037, 22.14360809], [88.85289001, 22.14357376], [88.85234833, 22.14339256], [88.85179138, 22.14330482], [88.85129547, 22.14313316], [88.8507843, 22.14303017], [88.85032654, 22.14286232], [88.84984589, 22.14273262], [88.84942627, 22.14251137], [88.84898376, 22.14232445], [88.84854889, 22.14215279], [88.8481369, 22.14194298], [88.8477478, 22.14170265], [88.84726715, 22.14157486], [88.84686279, 22.14137077], [88.84646606, 22.14111137], [88.84606171, 22.14086151], [88.84558868, 22.14072227], [88.84514618, 22.14053154], [88.8447113, 22.14028549], [88.84422302, 22.1400528], [88.84369659, 22.13979149], [88.84320068, 22.13946724], [88.84272003, 22.13916969], [88.84230804, 22.13887978], [88.84200287, 22.1386013], [88.84178162, 22.13833046], [88.84157562, 22.13809204], [88.84134674, 22.1378994], [88.84104156, 22.13775063], [88.84072113, 22.13752174], [88.84034729, 22.13730049], [88.84001923, 22.13705826], [88.83969879, 22.13683128], [88.8393631, 22.13665962], [88.83898926, 22.13650322], [88.83855438, 22.13640785], [88.83809662, 22.1363945], [88.83763123, 22.1363945], [88.83716583, 22.1363945], [88.83670807, 22.136343], [88.83623505, 22.13619995], [88.83577728, 22.13633156], [88.83554077, 22.13629913], [88.83531189, 22.13627052], [88.83483887, 22.13615417], [88.83434296, 22.13611794], [88.83383179, 22.13611031], [88.83331299, 22.13609314], [88.83282471, 22.13598061], [88.83241272, 22.13575172], [88.83197784, 22.13552284], [88.83156586, 22.13529015], [88.83114624, 22.13507271], [88.83068848, 22.1349678], [88.8302536, 22.13475227], [88.82977295, 22.13461113], [88.82927704, 22.13440323], [88.8288269, 22.13411903], [88.82835388, 22.13385773], [88.82789612, 22.13356972], [88.82750702, 22.13321114], [88.82713318, 22.13286018], [88.82668304, 22.13260078], [88.82623291, 22.13232994], [88.82585907, 22.1319828], [88.82546234, 22.13166809], [88.82507324, 22.13136101], [88.82470703, 22.1310215], [88.82433319, 22.13072014], [88.82393646, 22.13042259], [88.82362366, 22.13005257], [88.823349, 22.12964058], [88.82309723, 22.12922096], [88.82280731, 22.12882042], [88.82257843, 22.12841225], [88.82234192, 22.12805176], [88.82215118, 22.12771606], [88.82195282, 22.1274395], [88.8217392, 22.1272049], [88.8215332, 22.12698555], [88.82129669, 22.12683296], [88.82106018, 22.12669563], [88.82077026, 22.12667274], [88.82044983, 22.12667274], [88.82009888, 22.12675285], [88.81972504, 22.1269474], [88.8192749, 22.12716484], [88.81871033, 22.12729073], [88.81816864, 22.12751198], [88.81765747, 22.12779045], [88.81716156, 22.12812233], [88.81668854, 22.12848091], [88.8162384, 22.12885857], [88.81576538, 22.12916565], [88.8152771, 22.12943077], [88.81478119, 22.12963676], [88.81421661, 22.12974167], [88.81368256, 22.12991524], [88.81314087, 22.1300602], [88.81263733, 22.13028908], [88.81212616, 22.13054085], [88.8115387, 22.1307621], [88.81088257, 22.13087463], [88.81027222, 22.13107109], [88.80970001, 22.13111305], [88.8092041, 22.13111305], [88.80875397, 22.13111305], [88.80832672, 22.13111305], [88.80789948, 22.13111305], [88.80745697, 22.13111305], [88.80697632, 22.13108253], [88.80644226, 22.13092041], [88.80583191, 22.13083076], [88.80519104, 22.13073158], [88.80461121, 22.13054085], [88.80410767, 22.13028145], [88.8035965, 22.1300106], [88.80307007, 22.12973213], [88.8025589, 22.12936211], [88.80211639, 22.1289196], [88.80168915, 22.12850189], [88.80130768, 22.12809944], [88.80092621, 22.12775993], [88.80059052, 22.12742424], [88.80027008, 22.1270504], [88.7999115, 22.12667274], [88.79951477, 22.12629509], [88.79916382, 22.1258297], [88.79881287, 22.12536049], [88.7984314, 22.12495232], [88.79811096, 22.12450218], [88.79785919, 22.12405777], [88.79772949, 22.12354469], [88.79753113, 22.123106], [88.79738617, 22.12268257], [88.79722595, 22.1223011], [88.79708099, 22.12194252], [88.79692078, 22.1215992], [88.7967453, 22.12129402], [88.79663849, 22.12092781], [88.79646301, 22.12059975], [88.79637146, 22.12016106], [88.7962265, 22.1196785], [88.79612732, 22.11911011], [88.7960968, 22.11846924], [88.79601288, 22.11782265], [88.79586792, 22.11718941], [88.79579163, 22.11655045], [88.79560089, 22.11594963], [88.79545593, 22.11534691], [88.79524231, 22.11483383], [88.79497528, 22.11443901], [88.79464722, 22.11416054], [88.79426575, 22.11394882], [88.79374695, 22.11386108], [88.79317474, 22.11373711], [88.79258728, 22.11367989], [88.79205322, 22.1138382], [88.79152679, 22.11387062], [88.79099274, 22.11389542], [88.79042816, 22.11395454], [88.7898407, 22.11412239], [88.78919983, 22.11417961], [88.78856659, 22.11425209], [88.78794098, 22.11438179], [88.78734589, 22.11430168], [88.78675842, 22.11418915], [88.78614044, 22.11416435], [88.78547668, 22.11412239], [88.78479004, 22.11393356], [88.78406525, 22.11384392], [88.78340912, 22.11365128], [88.78274536, 22.11354256], [88.78221893, 22.11332893], [88.78173828, 22.11310005], [88.78122711, 22.1129818], [88.78083038, 22.11276245], [88.78045654, 22.11251259], [88.78005981, 22.11230278], [88.77958679, 22.11216927], [88.77916718, 22.11194038], [88.77870178, 22.11169624], [88.77818298, 22.11150169], [88.7776413, 22.11122131], [88.7771759, 22.11079407], [88.77670288, 22.11034393], [88.77614594, 22.10999489], [88.77565002, 22.10965538], [88.77534485, 22.10937119], [88.77527618, 22.10944366], [88.77281952, 22.10697937], [88.77249908, 22.10695267], [88.77194214, 22.10639191], [88.77194214, 22.10611153], [88.77169037, 22.1056385], [88.771492, 22.10509109], [88.7713623, 22.10455322], [88.77119446, 22.10407066], [88.77111816, 22.10355186], [88.77107239, 22.10302162], [88.77091217, 22.10254288], [88.77084351, 22.10206032], [88.77082825, 22.10157394], [88.77076721, 22.10110283], [88.77059937, 22.10070992], [88.77056122, 22.10025978], [88.77054596, 22.09978485], [88.77052307, 22.09929276], [88.77037048, 22.09881783], [88.77028656, 22.09832382], [88.77027893, 22.09781647], [88.7702713, 22.09731102], [88.7702713, 22.09681129], [88.7702713, 22.09629822], [88.77027893, 22.09579849], [88.7702713, 22.09530067], [88.7702713, 22.09481239], [88.77024841, 22.09431267], [88.77011108, 22.09383392], [88.76999664, 22.09331894], [88.76985168, 22.0927906], [88.76956177, 22.09229088], [88.76905823, 22.09194946], [88.76846313, 22.0916729], [88.76783752, 22.09139061], [88.76719666, 22.09111214], [88.76655579, 22.09087944], [88.76593781, 22.09078026], [88.76544189, 22.09055519], [88.76499939, 22.09031105], [88.76451874, 22.09019089], [88.76407623, 22.09004021], [88.7636261, 22.0899601], [88.76320648, 22.08976173], [88.76274872, 22.08967781], [88.76235199, 22.08950233], [88.7618866, 22.08937263], [88.76145172, 22.08918571]]], [[[88.93237305, 22.22500038], [88.93305206, 22.22480583], [88.93377686, 22.22491264], [88.93447876, 22.22476006], [88.93522644, 22.22468567], [88.9359436, 22.22452354], [88.93669128, 22.22445488], [88.93743896, 22.22439766], [88.93815613, 22.22419357], [88.93888092, 22.22403145], [88.93958282, 22.22385406], [88.94024658, 22.22361183], [88.94091034, 22.22337151], [88.94165039, 22.22329521], [88.94235229, 22.22311974], [88.94304657, 22.22302055], [88.94368744, 22.22282219], [88.94432831, 22.22278023], [88.94496155, 22.22278023], [88.9455719, 22.22278023], [88.94618225, 22.2227726], [88.94671631, 22.22271919], [88.94716644, 22.22255135], [88.9477005, 22.22250748], [88.94824219, 22.22249031], [88.94877625, 22.22242165], [88.9493103, 22.22223091], [88.9498291, 22.22211838], [88.95036316, 22.22224236], [88.95085907, 22.22245026], [88.95144653, 22.22250748], [88.95202637, 22.22250748], [88.9526062, 22.2224617], [88.95313263, 22.22223091], [88.95365906, 22.22195244], [88.95418549, 22.22160339], [88.95451355, 22.22102547], [88.95471191, 22.22034264], [88.95482635, 22.21964073], [88.95497131, 22.21899223], [88.95500183, 22.21840096], [88.95500183, 22.21788216], [88.95500183, 22.21742821], [88.95500183, 22.21699142], [88.95500183, 22.21656227], [88.95500183, 22.21614265], [88.95504761, 22.21576118], [88.9552002, 22.21546745], [88.95526886, 22.21513176], [88.95528412, 22.21477127], [88.95533752, 22.21442223], [88.95552063, 22.21414948], [88.95555878, 22.21383286], [88.95559692, 22.21350479], [88.95575714, 22.21323586], [88.95584869, 22.21292114], [88.95597839, 22.21263313], [88.95612335, 22.21235085], [88.95627594, 22.21204376], [88.95641327, 22.21162987], [88.95662689, 22.21117973], [88.95674896, 22.21063042], [88.9569397, 22.21006966], [88.95717621, 22.20948792], [88.95728302, 22.20882988], [88.95750427, 22.20822525], [88.95777893, 22.20763969], [88.95805359, 22.20711136], [88.9582901, 22.20662117], [88.95838165, 22.20614052], [88.95858002, 22.20577431], [88.95869446, 22.20537376], [88.95888519, 22.20501518], [88.95909119, 22.20465469], [88.95923615, 22.2042408], [88.9594574, 22.20383263], [88.95968628, 22.20340157], [88.95986938, 22.20290184], [88.96003723, 22.20239067], [88.96028137, 22.20192146], [88.96051025, 22.20145035], [88.96063232, 22.20095825], [88.96084595, 22.20059013], [88.9610672, 22.20027924], [88.96111298, 22.19986153], [88.96117401, 22.19941139], [88.96134949, 22.19893074], [88.96141052, 22.19839287], [88.96148682, 22.19781494], [88.961586, 22.19721031], [88.96144104, 22.19664383], [88.96138, 22.19606018], [88.96129608, 22.19548988], [88.96115112, 22.1949749], [88.96109772, 22.1944828], [88.96099091, 22.19405174], [88.96082306, 22.19368935], [88.96057892, 22.19336128], [88.96026611, 22.19301033], [88.95989227, 22.1926899], [88.95947266, 22.19244194], [88.95906067, 22.19220924], [88.95865631, 22.19199181], [88.95820618, 22.19190979], [88.95783234, 22.19174004], [88.95739746, 22.19168282], [88.9569397, 22.19167137], [88.95652008, 22.19167137], [88.95609283, 22.19164085], [88.95567322, 22.19151115], [88.9552536, 22.19140625], [88.95479584, 22.19139481], [88.95429993, 22.19139481], [88.9536972, 22.19139481], [88.95302582, 22.19135094], [88.95237732, 22.19118309], [88.95168304, 22.19123268], [88.95097351, 22.19135857], [88.95026398, 22.19143295], [88.949646, 22.19162178], [88.94906616, 22.19168282], [88.94853973, 22.1917572], [88.94803619, 22.1919117], [88.94747925, 22.19197273], [88.94690704, 22.19210815], [88.94631195, 22.19226265], [88.94574738, 22.19248009], [88.94512939, 22.1926403], [88.94448853, 22.19276237], [88.94381714, 22.19278145], [88.94315338, 22.19276237], [88.94249725, 22.19266319], [88.94190216, 22.19248009], [88.94140625, 22.19218826], [88.94110107, 22.19180107], [88.94081879, 22.19144249], [88.94056702, 22.19114113], [88.9404068, 22.19083977], [88.94029999, 22.19057274], [88.9402771, 22.19028664], [88.94029999, 22.19000053], [88.9404068, 22.18972206], [88.94052887, 22.18943787], [88.9405899, 22.18912315], [88.94075012, 22.18885994], [88.9409256, 22.18861961], [88.94114685, 22.18836784], [88.94139862, 22.18810081], [88.94169617, 22.1878109], [88.94204712, 22.18751717], [88.94245911, 22.18722153], [88.94290924, 22.18691063], [88.94333649, 22.18653107], [88.94380188, 22.18612289], [88.94425964, 22.18571854], [88.94455719, 22.18525124], [88.94468689, 22.18476486], [88.94458771, 22.18432808], [88.94433594, 22.18400002], [88.94391632, 22.1838131], [88.94345856, 22.1836319], [88.94296265, 22.18350029], [88.94249725, 22.18333817], [88.94207001, 22.18317986], [88.94164276, 22.18307495], [88.94123077, 22.1830616], [88.94078064, 22.18305016], [88.94037628, 22.1830101], [88.94002533, 22.18284416], [88.9395752, 22.18278313], [88.93908691, 22.18275261], [88.93860626, 22.18264198], [88.93811798, 22.18252182], [88.93758392, 22.18247223], [88.93704987, 22.18234062], [88.93649292, 22.18219948], [88.93596649, 22.18194008], [88.93546295, 22.18164444], [88.93503571, 22.18127251], [88.93467712, 22.1808567], [88.93434143, 22.1804409], [88.93406677, 22.17999077], [88.93380737, 22.1794529], [88.9335022, 22.17889214], [88.93313599, 22.17831039], [88.93279266, 22.17772102], [88.93238831, 22.17719078], [88.93180084, 22.17702484], [88.93148041, 22.17701149], [88.93128204, 22.17715454], [88.93097687, 22.17727089], [88.93069458, 22.17749977], [88.93035126, 22.17777443], [88.92996216, 22.17805481], [88.92955017, 22.17830467], [88.92906952, 22.17849159], [88.92858124, 22.17868996], [88.92806244, 22.17892075], [88.92751312, 22.17917061], [88.92693329, 22.17941093], [88.92630768, 22.17941093], [88.92575836, 22.17925072], [88.92523956, 22.17918205], [88.9247818, 22.17917061], [88.92434692, 22.17919922], [88.92398834, 22.17933655], [88.92365265, 22.1794529], [88.92334747, 22.17963028], [88.92307281, 22.17987823], [88.92284393, 22.18021774], [88.92262268, 22.18060112], [88.92240906, 22.1810627], [88.92208099, 22.18152428], [88.92164612, 22.18201256], [88.92115021, 22.18252182], [88.92063141, 22.18305016], [88.92008209, 22.18351173], [88.91947937, 22.18385887], [88.91893768, 22.18418121], [88.91851807, 22.18454361], [88.91815186, 22.18490028], [88.91780853, 22.18525124], [88.91750336, 22.18562126], [88.91722107, 22.18600655], [88.91693115, 22.1863842], [88.91661072, 22.18672371], [88.91628265, 22.18707085], [88.91594696, 22.18748283], [88.91558075, 22.18787193], [88.91520691, 22.18827438], [88.91481781, 22.1886425], [88.91443634, 22.1890316], [88.91407013, 22.1894207], [88.91366577, 22.18978119], [88.9132843, 22.19015694], [88.91285706, 22.19049263], [88.91247559, 22.19087982], [88.91213226, 22.19129944], [88.91172028, 22.19165039], [88.91127777, 22.19196892], [88.91088104, 22.19231606], [88.91052246, 22.19269371], [88.91015625, 22.19304085], [88.90979767, 22.19337273], [88.90946198, 22.19372559], [88.90917206, 22.19410133], [88.90888977, 22.19452095], [88.90859985, 22.19493294], [88.90834045, 22.19534111], [88.90813446, 22.19578743], [88.9080658, 22.19631004], [88.90809631, 22.19681931], [88.90828705, 22.1972599], [88.90837097, 22.19774055], [88.90857697, 22.19815445], [88.90880585, 22.19857979], [88.90911865, 22.19898033], [88.90943146, 22.19943047], [88.90975952, 22.19989395], [88.91015625, 22.2003231], [88.91051483, 22.20079422], [88.9108963, 22.20127487], [88.91135406, 22.20166969], [88.9118042, 22.20204163], [88.91220093, 22.20239067], [88.91252136, 22.20273781], [88.91279602, 22.20304108], [88.91306305, 22.20335197], [88.91333008, 22.20368004], [88.91362, 22.20407295], [88.91396332, 22.20449257], [88.91442108, 22.20487022], [88.91485596, 22.2053051], [88.9152298, 22.20578194], [88.91552734, 22.20623207], [88.91573334, 22.20666313], [88.91585541, 22.20704079], [88.91600037, 22.20735741], [88.91625977, 22.20759392], [88.91653442, 22.20786476], [88.91667175, 22.20826149], [88.91678619, 22.2087307], [88.91691589, 22.20926094], [88.91698456, 22.20983505], [88.91716003, 22.21042061], [88.91725922, 22.21103477], [88.91750336, 22.21155357], [88.91773224, 22.21204567], [88.91776276, 22.21255302], [88.91766357, 22.21303368], [88.91751862, 22.21351433], [88.91743469, 22.2140522], [88.91726685, 22.21463203], [88.91718292, 22.2152729], [88.91697693, 22.21584129], [88.91687012, 22.21643257], [88.91670227, 22.21696281], [88.91662598, 22.2175312], [88.91642761, 22.21807289], [88.91639709, 22.21863747], [88.91646576, 22.21921349], [88.91667938, 22.21973228], [88.91697693, 22.22024155], [88.91732025, 22.22073174], [88.91765594, 22.22123146], [88.91797638, 22.22178078], [88.91809845, 22.22242165], [88.91828918, 22.22301292], [88.91837311, 22.22358322], [88.91857147, 22.22409248], [88.91860962, 22.22462273], [88.91861725, 22.22514725], [88.91860962, 22.22567177], [88.91857147, 22.22617912], [88.91841125, 22.22661018], [88.91834259, 22.22704124], [88.91833496, 22.2274456], [88.91833496, 22.22786331], [88.91833496, 22.2283268], [88.91833496, 22.22885323], [88.91837311, 22.22941208], [88.91855621, 22.22992134], [88.91863251, 22.23042107], [88.91879272, 22.23080826], [88.9190979, 22.23105049], [88.91954803, 22.23106956], [88.92002869, 22.23089027], [88.92050171, 22.23067284], [88.92088318, 22.23034286], [88.92125702, 22.2300148], [88.92167664, 22.22969246], [88.92207336, 22.22932243], [88.92247772, 22.22898293], [88.9228363, 22.2286396], [88.92318726, 22.22835159], [88.9235611, 22.22809792], [88.92394257, 22.22783089], [88.92436218, 22.22756958], [88.92476654, 22.22728539], [88.92520142, 22.2270298], [88.92567444, 22.22681046], [88.92613983, 22.22657204], [88.92663574, 22.22642517], [88.92717743, 22.22634315], [88.92761993, 22.22610855], [88.92802429, 22.22590065], [88.92845917, 22.22580147], [88.92883301, 22.22564125], [88.92921448, 22.22556877], [88.92962646, 22.2255497], [88.93006134, 22.22554016], [88.93052673, 22.22546196], [88.93107605, 22.22531319], [88.93171692, 22.22522926], [88.93237305, 22.22500038]]], [[[88.81259918, 22.28339195], [88.8130722, 22.28331947], [88.81347656, 22.28321266], [88.81388855, 22.28307915], [88.81421661, 22.28281212], [88.81441498, 22.28238678], [88.81451416, 22.28183937], [88.81463623, 22.28129005], [88.81481171, 22.28082085], [88.81495667, 22.28036118], [88.81500244, 22.27986145], [88.8150177, 22.27934074], [88.81504822, 22.2788372], [88.81513977, 22.27836037], [88.81524658, 22.27787971], [88.81532288, 22.27739143], [88.81541443, 22.27687263], [88.81539154, 22.27636147], [88.81537628, 22.27584839], [88.81533051, 22.27531052], [88.81528473, 22.27478981], [88.8152771, 22.2742691], [88.8152771, 22.27375221], [88.8152771, 22.27323151], [88.8152771, 22.27272224], [88.81523895, 22.27223015], [88.81513977, 22.27177238], [88.81511688, 22.27130508], [88.81517029, 22.27083015], [88.8152771, 22.27036667], [88.81541443, 22.26990318], [88.81549072, 22.26942635], [88.81551361, 22.26892853], [88.81551361, 22.26841927], [88.81545258, 22.26794243], [88.8152771, 22.26755905], [88.81511688, 22.26719093], [88.81503296, 22.26679039], [88.81500244, 22.2663517], [88.81500244, 22.26588249], [88.8150177, 22.26537132], [88.81508636, 22.26485252], [88.8152771, 22.2644043], [88.81551361, 22.26398659], [88.81588745, 22.26371384], [88.81632996, 22.26349831], [88.81681061, 22.2632618], [88.81739044, 22.26319122], [88.81803131, 22.26331139], [88.8187027, 22.26344109], [88.81932068, 22.26358795], [88.81991577, 22.26370239], [88.82051849, 22.26389122], [88.82115936, 22.26409531], [88.82182312, 22.26428032], [88.82237244, 22.26449013], [88.82285309, 22.26468849], [88.82328033, 22.26484108], [88.82366943, 22.26501274], [88.82409668, 22.2652092], [88.824646, 22.26532173], [88.82525635, 22.26538467], [88.82546997, 22.26528168], [88.8258667, 22.26510048], [88.82624817, 22.26459312], [88.82640839, 22.26402092], [88.82653046, 22.2634716], [88.82663727, 22.26292992], [88.82668304, 22.26239014], [88.82675934, 22.26187325], [88.82684326, 22.26135826], [88.82670593, 22.26083183], [88.82672882, 22.26030159], [88.82680511, 22.25972176], [88.82691956, 22.25909996], [88.82699585, 22.25846291], [88.82714844, 22.2578907], [88.8273468, 22.25740242], [88.82762909, 22.25704002], [88.82772827, 22.25662041], [88.82766724, 22.25604057], [88.82748413, 22.25543022], [88.82727814, 22.25475121], [88.82731628, 22.25396156], [88.8273468, 22.25323296], [88.82720947, 22.25284386], [88.82697296, 22.25248146], [88.82679749, 22.2520237], [88.8266449, 22.25152397], [88.82646942, 22.25101662], [88.82636261, 22.25047874], [88.82623291, 22.24997139], [88.82613373, 22.24944687], [88.82611084, 22.2489109], [88.82605743, 22.24841118], [88.82588196, 22.24798012], [88.82583618, 22.24754143], [88.82583618, 22.24711418], [88.82588196, 22.24669456], [88.82606506, 22.24629021], [88.82607269, 22.24583244], [88.8259201, 22.24534035], [88.82583618, 22.2448597], [88.82582092, 22.24435234], [88.82582855, 22.24381256], [88.82583618, 22.24323082], [88.82584381, 22.2426281], [88.82581329, 22.24202156], [88.82567596, 22.24144173], [88.82541656, 22.24091148], [88.82504272, 22.24051094], [88.82463074, 22.24013519], [88.8241806, 22.23981476], [88.82356262, 22.23966026], [88.82298279, 22.23933983], [88.82247925, 22.23890114], [88.82196045, 22.23846817], [88.82150269, 22.23801231], [88.82112885, 22.23751259], [88.82080841, 22.23703575], [88.82045746, 22.23666954], [88.82012939, 22.23634911], [88.81987762, 22.23597145], [88.8196106, 22.23552704], [88.81938171, 22.23503113], [88.81913757, 22.23452187], [88.8188324, 22.23405266], [88.81852722, 22.23361015], [88.81825256, 22.23317337], [88.81801605, 22.23273277], [88.81772614, 22.2323513], [88.8174057, 22.23201942], [88.81706238, 22.2317028], [88.81668854, 22.23142052], [88.81629944, 22.23116684], [88.81587982, 22.23093987], [88.81547546, 22.23068428], [88.81510162, 22.23040581], [88.81468201, 22.23018456], [88.81425476, 22.22987938], [88.81371307, 22.22969246], [88.81318665, 22.22950172], [88.81269836, 22.22937965], [88.81224823, 22.22921181], [88.81173706, 22.2290802], [88.81121063, 22.22893906], [88.81059265, 22.22893333], [88.80992126, 22.229002], [88.80922699, 22.22891426], [88.80853271, 22.22881889], [88.80787659, 22.22867012], [88.80718994, 22.2286129], [88.80648804, 22.22860527], [88.80578613, 22.22855949], [88.80509949, 22.22841835], [88.8044281, 22.22824287], [88.80374908, 22.22810173], [88.80304718, 22.22805977], [88.80236053, 22.22805023], [88.80167389, 22.22804451], [88.80101013, 22.22800255], [88.80041504, 22.22787476], [88.79991913, 22.22769356], [88.79947662, 22.22747612], [88.79910278, 22.22719002], [88.79881287, 22.22683716], [88.79859924, 22.22641373], [88.79846954, 22.22597313], [88.79863739, 22.22553062], [88.79891968, 22.22512817], [88.79928589, 22.22478294], [88.79972076, 22.22451973], [88.80018616, 22.22427177], [88.80068207, 22.22401237], [88.80113983, 22.22369957], [88.8015976, 22.22339058], [88.80204773, 22.22303963], [88.80252075, 22.2226696], [88.80301666, 22.22229195], [88.8035202, 22.22192574], [88.80387878, 22.22142982], [88.80416107, 22.22097206], [88.80438232, 22.22057152], [88.80448914, 22.22015953], [88.80462646, 22.21977234], [88.80470276, 22.21930885], [88.80473328, 22.21874046], [88.80473328, 22.21811676], [88.80471039, 22.21748161], [88.80461884, 22.21692657], [88.80441284, 22.21653938], [88.80419922, 22.21617126], [88.80399323, 22.21584129], [88.80381012, 22.21542358], [88.80370331, 22.21500587], [88.80373383, 22.21463203], [88.80383301, 22.21425247], [88.80382538, 22.21381569], [88.80374908, 22.21331978], [88.80389404, 22.21277237], [88.80410004, 22.21218491], [88.80430603, 22.21156311], [88.80445099, 22.21093369], [88.80457306, 22.21035576], [88.80471039, 22.20989037], [88.80483246, 22.20951271], [88.80497742, 22.20921135], [88.80512238, 22.2089119], [88.80529785, 22.2086277], [88.80554199, 22.20835304], [88.80583954, 22.20805168], [88.80621338, 22.20773125], [88.80670166, 22.20746613], [88.80726624, 22.20720291], [88.80787659, 22.20698166], [88.80854797, 22.20682144], [88.80921173, 22.20663261], [88.80988312, 22.20650291], [88.81052399, 22.20661354], [88.8107605, 22.20663071], [88.81118011, 22.20666313], [88.81167603, 22.20664215], [88.8117981, 22.20664024], [88.81237793, 22.20656013], [88.81284332, 22.20631218], [88.81328583, 22.20614815], [88.81373596, 22.20606041], [88.81416321, 22.20588112], [88.81461334, 22.20570946], [88.81498718, 22.20541954], [88.81529236, 22.20508194], [88.81557465, 22.20474052], [88.81581116, 22.20439339], [88.81600952, 22.2040081], [88.81624603, 22.20361328], [88.81642914, 22.2031498], [88.81632996, 22.20257378], [88.81634521, 22.20198631], [88.81638336, 22.20138168], [88.81639099, 22.20076752], [88.81639862, 22.20016479], [88.81642151, 22.19957161], [88.81646729, 22.1989994], [88.81661987, 22.19846153], [88.81671906, 22.19792938], [88.81690216, 22.19745255], [88.81703186, 22.19693184], [88.81725311, 22.1965313], [88.81754303, 22.19617271], [88.81787109, 22.195858], [88.81822968, 22.19558907], [88.81864166, 22.19538116], [88.81907654, 22.19521141], [88.81957245, 22.19504356], [88.82016754, 22.1950016], [88.82080078, 22.19501305], [88.82144165, 22.19507027], [88.82199097, 22.19517136], [88.82246399, 22.19526672], [88.82289124, 22.19532967], [88.82328033, 22.19550705], [88.82370758, 22.19555092], [88.82419586, 22.19556808], [88.82468414, 22.19556618], [88.82519531, 22.19560051], [88.82572937, 22.19568443], [88.82628632, 22.19577599], [88.82678986, 22.19568443], [88.82718658, 22.1954155], [88.82749939, 22.19498634], [88.82776642, 22.19444084], [88.82802582, 22.19388008], [88.82832336, 22.19334221], [88.8285675, 22.19283485], [88.82871246, 22.19229507], [88.8289032, 22.19181252], [88.82913971, 22.19137764], [88.82932281, 22.19091225], [88.82948303, 22.19042015], [88.82970428, 22.18997765], [88.82990265, 22.18949318], [88.8300705, 22.18900108], [88.83030701, 22.18859291], [88.83056641, 22.18816948], [88.83085632, 22.18774605], [88.83112335, 22.18727303], [88.83133698, 22.18674278], [88.83148956, 22.1861763], [88.83168793, 22.18567085], [88.83194733, 22.18522263], [88.83222198, 22.18482971], [88.83249664, 22.18441963], [88.83277893, 22.18397141], [88.83307648, 22.18346977], [88.83341217, 22.18298149], [88.83377838, 22.1825161], [88.8341217, 22.18209648], [88.83436584, 22.18169594], [88.83457947, 22.18137169], [88.83473969, 22.1810627], [88.83491516, 22.18079185], [88.83507538, 22.18049431], [88.83526611, 22.18018913], [88.8354187, 22.17984962], [88.83557129, 22.17954254], [88.83583069, 22.17916679], [88.83611298, 22.17889214], [88.83611298, 22.17860985], [88.83666992, 22.17805481], [88.83666992, 22.17777824], [88.83750153, 22.17694473], [88.83750153, 22.17638969], [88.83777618, 22.17611122], [88.83777618, 22.17556381], [88.83805847, 22.17527962], [88.83805847, 22.17416954], [88.83811951, 22.17403984], [88.83813477, 22.17347336], [88.83807373, 22.17291832], [88.8380127, 22.17237282], [88.83782196, 22.1718502], [88.83771515, 22.1713047], [88.83750153, 22.17082405], [88.83728027, 22.17033195], [88.83706665, 22.16984367], [88.83686829, 22.16937447], [88.83668518, 22.16893959], [88.83654022, 22.16850853], [88.83631897, 22.16814232], [88.83597565, 22.16784859], [88.83555603, 22.1675396], [88.8350296, 22.16723061], [88.83439636, 22.16698265], [88.83405304, 22.16685295], [88.83374786, 22.16687202], [88.83338165, 22.16695213], [88.83296204, 22.16706467], [88.83248901, 22.16716194], [88.83197021, 22.1672802], [88.8315506, 22.16764259], [88.83109283, 22.16802025], [88.83058167, 22.16841316], [88.83010864, 22.16888809], [88.82965851, 22.16937065], [88.82917023, 22.16974068], [88.8286972, 22.17007256], [88.82833862, 22.17045021], [88.82798767, 22.17084312], [88.82762146, 22.17123413], [88.82723236, 22.17159081], [88.826828, 22.17193031], [88.82643127, 22.17222786], [88.82604218, 22.17250252], [88.82572174, 22.17277908], [88.82541656, 22.17303276], [88.82508087, 22.17326164], [88.82473755, 22.17353058], [88.82440186, 22.17386055], [88.8239975, 22.17418289], [88.82357025, 22.17447853], [88.82310486, 22.17478371], [88.82263184, 22.17514038], [88.8221283, 22.17551231], [88.82157898, 22.17584038], [88.82105255, 22.17618561], [88.82058716, 22.17653084], [88.82019043, 22.17690086], [88.81978607, 22.17721748], [88.81936646, 22.17750549], [88.81894684, 22.17778969], [88.81853485, 22.17814064], [88.81815338, 22.1785202], [88.81777191, 22.17888069], [88.81736755, 22.17919922], [88.81698608, 22.17952156], [88.81665039, 22.17989159], [88.81630707, 22.18024254], [88.81594086, 22.18055153], [88.81555939, 22.18084717], [88.81519318, 22.18116951], [88.8147583, 22.18140221], [88.81433105, 22.18160057], [88.81387329, 22.18172264], [88.81344604, 22.18194962], [88.81304932, 22.18219948], [88.8126297, 22.18238068], [88.81224823, 22.18254471], [88.81186676, 22.18272209], [88.81147003, 22.18285179], [88.81108093, 22.18301964], [88.81062317, 22.18309212], [88.81015015, 22.18327141], [88.80961609, 22.18333817], [88.80908203, 22.18333817], [88.80854797, 22.18329048], [88.80806732, 22.18311119], [88.80757141, 22.18305397], [88.80708313, 22.18298721], [88.80661011, 22.18280029], [88.80612183, 22.18264198], [88.80562592, 22.18244934], [88.80515289, 22.18220329], [88.8046875, 22.18192291], [88.80419159, 22.18166161], [88.80371857, 22.18139076], [88.80327606, 22.18111229], [88.80285645, 22.18083382], [88.80243683, 22.18055916], [88.80203247, 22.18027306], [88.80157471, 22.17999077], [88.80113983, 22.1796627], [88.80070496, 22.17929649], [88.80027008, 22.17892265], [88.79981232, 22.17856026], [88.7993927, 22.17813492], [88.79897308, 22.17772102], [88.79862213, 22.17729378], [88.79832458, 22.17687225], [88.79806519, 22.17649269], [88.79782867, 22.17614937], [88.79759979, 22.17584038], [88.79734802, 22.17551231], [88.79710388, 22.17512703], [88.79683685, 22.17469978], [88.79659271, 22.17424011], [88.79628754, 22.17383194], [88.79606628, 22.17339134], [88.79589081, 22.17296028], [88.79574585, 22.17255211], [88.79560089, 22.17217064], [88.79545593, 22.17181015], [88.79530334, 22.1714592], [88.79515076, 22.17108917], [88.79496002, 22.17078018], [88.79471588, 22.17058754], [88.79444122, 22.17051125], [88.79415131, 22.17057037], [88.79387665, 22.17082024], [88.79358673, 22.17121315], [88.7933197, 22.17174149], [88.79302216, 22.17233276], [88.79268646, 22.17288017], [88.79238892, 22.17344856], [88.79209137, 22.1739502], [88.79191589, 22.17439079], [88.79168701, 22.17470741], [88.79144287, 22.1750145], [88.79116058, 22.1753521], [88.79088593, 22.17577171], [88.79058075, 22.17622566], [88.7902832, 22.17675209], [88.78997803, 22.17728043], [88.78961945, 22.17771912], [88.78923035, 22.17805481], [88.78886414, 22.17835045], [88.78847504, 22.17860985], [88.78807831, 22.17884254], [88.78765106, 22.17902374], [88.78723907, 22.17918968], [88.78687286, 22.17943001], [88.78645325, 22.17965508], [88.78594971, 22.17986107], [88.78533173, 22.18003273], [88.78470612, 22.18022919], [88.78408051, 22.18029976], [88.78347778, 22.18041039], [88.78288269, 22.18055153], [88.78224945, 22.18066025], [88.78163147, 22.18079948], [88.78100586, 22.18087959], [88.78044891, 22.18107033], [88.77988434, 22.18110847], [88.77935791, 22.1811161], [88.77885437, 22.18115044], [88.77838898, 22.18130493], [88.77789307, 22.18138313], [88.77738953, 22.18144989], [88.77694702, 22.18163109], [88.77648163, 22.18175316], [88.77604675, 22.18192291], [88.77561951, 22.18204117], [88.77523804, 22.18223763], [88.77487946, 22.18248177], [88.77451324, 22.18271065], [88.77403259, 22.1829052], [88.7735672, 22.18308258], [88.77316284, 22.18333626], [88.77278137, 22.18361092], [88.7723999, 22.18389893], [88.77191162, 22.1841526], [88.77144623, 22.18441391], [88.77106476, 22.18474007], [88.7707901, 22.18511581], [88.77059937, 22.18548393], [88.77049255, 22.18589211], [88.77033997, 22.1862812], [88.77028656, 22.18670082], [88.7702713, 22.18716049], [88.7702713, 22.18766212], [88.7702713, 22.18816948], [88.77023315, 22.18867874], [88.77007294, 22.18913078], [88.76999664, 22.18963051], [88.7699585, 22.1901226], [88.76978302, 22.19053078], [88.76972198, 22.19083214], [88.76972198, 22.19111061], [88.76944733, 22.19138908], [88.76944733, 22.19194412], [88.76917267, 22.19221306], [88.76917267, 22.19250488], [88.76860809, 22.1930542], [88.76860809, 22.19333076], [88.76832581, 22.19361305], [88.76824951, 22.19356918], [88.76786804, 22.19390297], [88.7674408, 22.19421005], [88.76698303, 22.19447136], [88.76650238, 22.19472313], [88.76602936, 22.19492149], [88.76552582, 22.19501305], [88.76502991, 22.19508553], [88.76477051, 22.19510651], [88.76451874, 22.19512749], [88.76403809, 22.19502831], [88.76352692, 22.19496155], [88.76302338, 22.19479179], [88.76251221, 22.19462013], [88.7620163, 22.1944294], [88.76158142, 22.19419289], [88.76113892, 22.19403267], [88.76069641, 22.19389153], [88.76025391, 22.19381332], [88.75978851, 22.19384193], [88.7593689, 22.19402122], [88.75894928, 22.19427109], [88.75858307, 22.19458961], [88.7582016, 22.19488907], [88.75784302, 22.1951828], [88.75752258, 22.1955204], [88.75712585, 22.19577217], [88.75662994, 22.195961], [88.75608063, 22.19613075], [88.75553131, 22.19637108], [88.75498199, 22.19652939], [88.75444794, 22.19664383], [88.75392914, 22.19667816], [88.75343323, 22.19673729], [88.75291443, 22.19682503], [88.75235748, 22.1969223], [88.7517395, 22.19693947], [88.751091, 22.19695091], [88.75042725, 22.19693947], [88.74978638, 22.19694519], [88.74917603, 22.19697189], [88.74864197, 22.19709206], [88.74819183, 22.19727135], [88.74784851, 22.19752884], [88.74758911, 22.19784927], [88.74740601, 22.19825172], [88.74724579, 22.19862938], [88.74717712, 22.19901085], [88.74720001, 22.19936752], [88.74723053, 22.19973373], [88.74732208, 22.20006943], [88.7474823, 22.20041084], [88.74761963, 22.20078087], [88.74774933, 22.20111275], [88.74784088, 22.20146179], [88.74796295, 22.20182228], [88.74804687, 22.20218086], [88.7481308, 22.20258904], [88.74820709, 22.20305061], [88.7483139, 22.20356941], [88.74843597, 22.20407677], [88.74848175, 22.20458221], [88.74833679, 22.20512009], [88.74820709, 22.20564079], [88.74825287, 22.20623589], [88.74816132, 22.2067318], [88.74806976, 22.20702171], [88.74800873, 22.20728111], [88.74788666, 22.20755959], [88.74768066, 22.207901], [88.74748993, 22.2082901], [88.74731445, 22.20874786], [88.74723053, 22.20928574], [88.74721527, 22.20987129], [88.7472229, 22.21048164], [88.74727631, 22.21109962], [88.74747467, 22.21170235], [88.74772644, 22.21229935], [88.74794006, 22.21290016], [88.74813843, 22.21347618], [88.74835205, 22.21405792], [88.74861145, 22.21463203], [88.74888611, 22.21520233], [88.7492218, 22.21570015], [88.74964905, 22.21608543], [88.75015259, 22.21637154], [88.75065613, 22.21665192], [88.75093079, 22.21704292], [88.75112152, 22.21749306], [88.75131226, 22.21796227], [88.75151825, 22.21849251], [88.75167084, 22.21909142], [88.75177765, 22.2197094], [88.75189209, 22.22031021], [88.7518692, 22.22091866], [88.75178528, 22.22153282], [88.75180054, 22.22214317], [88.7518158, 22.22276115], [88.75195313, 22.22334671], [88.75203705, 22.22393227], [88.75200653, 22.22459221], [88.75184631, 22.22525978], [88.75170898, 22.2258873], [88.75166321, 22.22651482], [88.75161743, 22.22707939], [88.75144958, 22.2275238], [88.7514267, 22.22792625], [88.7515564, 22.22823143], [88.7516861, 22.22854042], [88.75190735, 22.2288723], [88.75209808, 22.22932243], [88.75216675, 22.22982216], [88.75218964, 22.23039055], [88.75258636, 22.23091316], [88.75293732, 22.23145294], [88.7532959, 22.23180389], [88.7536087, 22.23212242], [88.75391388, 22.23246574], [88.75427246, 22.23277473], [88.75463867, 22.23307991], [88.75495148, 22.23343086], [88.75520325, 22.23379898], [88.75549316, 22.23410988], [88.75579071, 22.23444176], [88.75609589, 22.23478508], [88.7563858, 22.23517036], [88.75666046, 22.23560143], [88.75695038, 22.2360611], [88.75727081, 22.23652077], [88.75765228, 22.23693275], [88.7580719, 22.23732376], [88.75850677, 22.23769188], [88.75891113, 22.23809433], [88.75927734, 22.23851395], [88.75969696, 22.23887825], [88.76013947, 22.23921013], [88.76055145, 22.23961067], [88.76097107, 22.24003029], [88.76132202, 22.24049759], [88.76167297, 22.24098015], [88.76204681, 22.24141693], [88.76251984, 22.2415638], [88.76300049, 22.24143982], [88.76345825, 22.24139977], [88.76391602, 22.24139023], [88.76436615, 22.24135017], [88.7647934, 22.24120522], [88.7652359, 22.24112129], [88.76566315, 22.24104881], [88.76602936, 22.24084282], [88.76637268, 22.24062538], [88.76670074, 22.24039268], [88.76706696, 22.24020958], [88.76746368, 22.24011612], [88.76786804, 22.2401104], [88.76832581, 22.24028015], [88.76876831, 22.24046516], [88.76912689, 22.2406559], [88.76943207, 22.24093056], [88.76970673, 22.24131012], [88.76994324, 22.24178123], [88.76999664, 22.24239159], [88.77000427, 22.24296761], [88.77004242, 22.24343491], [88.77015686, 22.24379158], [88.77025604, 22.24411774], [88.77033234, 22.24445152], [88.77051544, 22.24478722], [88.77065277, 22.24521255], [88.77083588, 22.24563026], [88.77108002, 22.24615288], [88.77126312, 22.24668312], [88.77142334, 22.24720955], [88.77159882, 22.24770164], [88.77168274, 22.24817085], [88.77179718, 22.24860954], [88.77198792, 22.2490406], [88.77223969, 22.24945259], [88.7725296, 22.24985313], [88.77284241, 22.25021172], [88.77316284, 22.25049782], [88.77352142, 22.25070953], [88.77391052, 22.25087166], [88.77429199, 22.25105095], [88.77470398, 22.25121307], [88.77511597, 22.2514019], [88.77552795, 22.25163078], [88.77594757, 22.25180244], [88.77638245, 22.25198174], [88.77677155, 22.2522316], [88.77716827, 22.25250053], [88.77758026, 22.25277138], [88.77803802, 22.2530365], [88.77854919, 22.2532711], [88.77909088, 22.25349998], [88.77968597, 22.25367165], [88.78025055, 22.25389671], [88.78079224, 22.25415611], [88.78130341, 22.2544117], [88.78172302, 22.25475693], [88.78212738, 22.2550602], [88.78251648, 22.25537491], [88.78289032, 22.25565529], [88.78328705, 22.2558918], [88.78370667, 22.25613022], [88.78411865, 22.25638008], [88.78451538, 22.25663567], [88.78492737, 22.25687981], [88.78528595, 22.25714111], [88.78565216, 22.2573719], [88.78604889, 22.25752068], [88.78647614, 22.25766182], [88.78695679, 22.25774765], [88.78748322, 22.2577858], [88.78801727, 22.25784111], [88.78852844, 22.25798225], [88.78903961, 22.25795174], [88.78955078, 22.25778008], [88.79009247, 22.25766182], [88.79063416, 22.25781631], [88.79113007, 22.25809288], [88.79156494, 22.2584362], [88.79189301, 22.25883293], [88.7921524, 22.25920677], [88.79229736, 22.25948906], [88.79234314, 22.2595768], [88.79251099, 22.25994301], [88.79265594, 22.26028252], [88.7928009, 22.26061058], [88.79296112, 22.26092911], [88.79309082, 22.26128578], [88.79323578, 22.2616024], [88.7933197, 22.26197243], [88.79338074, 22.26231766], [88.79347992, 22.26267052], [88.79351807, 22.26309776], [88.79344177, 22.26358986], [88.79344177, 22.2641201], [88.79356384, 22.26457977], [88.79364777, 22.26501274], [88.79374695, 22.26542091], [88.79386139, 22.26582146], [88.79397583, 22.26627159], [88.79412842, 22.26679039], [88.79425049, 22.26740074], [88.79440308, 22.26805115], [88.79449463, 22.26876831], [88.79445648, 22.26943016], [88.79436493, 22.27001572], [88.79421234, 22.2704525], [88.79412842, 22.27085304], [88.79402161, 22.27114296], [88.79391479, 22.27140999], [88.79389954, 22.27160072], [88.79389191, 22.27170372], [88.79387665, 22.27200127], [88.79389954, 22.27231026], [88.79395294, 22.27262115], [88.79408264, 22.27289009], [88.7942276, 22.27321053], [88.79441071, 22.2735424], [88.79457855, 22.27393532], [88.79469299, 22.27441978], [88.79471588, 22.2749424], [88.7947464, 22.27544975], [88.79483032, 22.275877], [88.79505157, 22.27607536], [88.79537201, 22.27611351], [88.79573059, 22.27611351], [88.79611969, 22.2761097], [88.79653931, 22.27611351], [88.79698944, 22.27614021], [88.79743958, 22.27625084], [88.79792023, 22.27635193], [88.79840851, 22.27637482], [88.79890442, 22.27638626], [88.7993927, 22.27640915], [88.79982758, 22.27653885], [88.80023193, 22.27665138], [88.80065155, 22.27675056], [88.80111694, 22.27699089], [88.80162048, 22.27725792], [88.80213165, 22.27757454], [88.80260468, 22.27798271], [88.8031311, 22.27833176], [88.80364227, 22.27870178], [88.80397797, 22.27924538], [88.80434418, 22.27968407], [88.80471039, 22.28001976], [88.80487061, 22.28021431], [88.80502319, 22.28040123], [88.80535126, 22.28078461], [88.80571747, 22.28119278], [88.80599976, 22.28168488], [88.80625916, 22.2822094], [88.8065567, 22.28268814], [88.80702972, 22.28300476], [88.80763245, 22.28313255], [88.80821228, 22.28328133], [88.80878448, 22.2833252], [88.80919647, 22.28333282], [88.8093338, 22.28333473], [88.8098526, 22.28333473], [88.81037903, 22.28333473], [88.81092834, 22.28333282], [88.81150055, 22.28334236], [88.8120575, 22.28336143], [88.81259918, 22.28339195]]], [[[88.98475647, 22.38243294], [88.98454285, 22.38192558], [88.98443604, 22.38195229], [88.98443604, 22.38139153], [88.98416901, 22.38111305], [88.98416901, 22.38055992], [88.98387909, 22.38028145], [88.98387909, 22.37944221], [88.98361206, 22.37916756], [88.98361206, 22.37889481], [88.98339081, 22.37871933], [88.98327637, 22.37831116], [88.98310089, 22.37786293], [88.98303223, 22.37734795], [88.98293304, 22.37684059], [88.98281097, 22.37635231], [88.9827652, 22.3758564], [88.9826889, 22.37537575], [88.98253632, 22.37492943], [88.98249817, 22.37445259], [88.98249817, 22.3739624], [88.9825058, 22.37346077], [88.98253632, 22.37298393], [88.98261261, 22.37254143], [88.98274994, 22.37213516], [88.98278809, 22.37173271], [88.98285675, 22.37134171], [88.98309326, 22.37109184], [88.9833374, 22.37080574], [88.98358917, 22.37050438], [88.98383331, 22.37018013], [88.98400879, 22.36980247], [88.98419189, 22.36944008], [88.98443604, 22.36915016], [88.98464966, 22.36882973], [88.98483276, 22.36850166], [88.98504639, 22.3681469], [88.98529053, 22.36779213], [88.98560333, 22.36747169], [88.98596191, 22.36717606], [88.98628235, 22.36678123], [88.98661804, 22.36637115], [88.98697662, 22.36594963], [88.98738861, 22.36557961], [88.98784637, 22.36526108], [88.9882431, 22.36489296], [88.98848724, 22.36438942], [88.9885788, 22.36387444], [88.98848724, 22.36339378], [88.98843384, 22.3632946], [88.98826599, 22.36297798], [88.98800659, 22.3625927], [88.98770142, 22.36229134], [88.98735809, 22.36203384], [88.9871521, 22.36160278], [88.98693848, 22.36111259], [88.98674011, 22.36061287], [88.98651886, 22.36012077], [88.98629761, 22.35963821], [88.98607635, 22.35917091], [88.98589325, 22.35868263], [88.98576355, 22.35815239], [88.9855957, 22.35767555], [88.98555756, 22.35749817], [88.98555756, 22.3572216], [88.98527527, 22.35694885], [88.9852829, 22.35583305], [88.98555756, 22.3555584], [88.98560333, 22.35489082], [88.98580933, 22.35436058], [88.98596191, 22.3537674], [88.98612976, 22.35318947], [88.98633575, 22.35270691], [88.98649597, 22.3522625], [88.98671722, 22.35189247], [88.98693085, 22.35153008], [88.98710632, 22.35112953], [88.98731995, 22.35072327], [88.98751831, 22.35022163], [88.98768616, 22.3496418], [88.98755646, 22.34893227], [88.98742676, 22.34818077], [88.98722076, 22.34754372], [88.98698425, 22.34697342], [88.98678589, 22.34641075], [88.9866333, 22.34581947], [88.98643494, 22.34528542], [88.98636627, 22.34476471], [88.98626709, 22.34434319], [88.98612213, 22.34399223], [88.98600769, 22.34361839], [88.98587036, 22.3431797], [88.98577881, 22.34263611], [88.98560333, 22.34208107], [88.98542786, 22.3415451], [88.98526764, 22.34106827], [88.98512268, 22.34065628], [88.98506165, 22.34023094], [88.98499298, 22.33982277], [88.98487091, 22.33946037], [88.98474884, 22.33910942], [88.98471832, 22.33871269], [88.98464966, 22.33828926], [88.98445129, 22.33790016], [88.98426056, 22.33741188], [88.98416138, 22.33681488], [88.98404694, 22.33617973], [88.98390198, 22.33562279], [88.98374939, 22.33513069], [88.98365784, 22.33468437], [88.98361969, 22.33426094], [88.98361206, 22.33384132], [88.98361206, 22.33341026], [88.98361206, 22.33297157], [88.98364258, 22.3325119], [88.98375702, 22.33205986], [88.98387146, 22.33161926], [88.98387146, 22.33117104], [88.98377228, 22.33073235], [88.98364258, 22.33031464], [88.98361206, 22.32986259], [88.98356628, 22.3293972], [88.98340607, 22.32892036], [88.98335266, 22.32835007], [88.98332977, 22.3277626], [88.98332977, 22.32718468], [88.98332977, 22.32667351], [88.9833374, 22.32625008], [88.98336792, 22.32590485], [88.98350525, 22.32564354], [88.98361206, 22.32533836], [88.98375702, 22.32502174], [88.98400116, 22.32471275], [88.98433685, 22.32441711], [88.98472595, 22.32407188], [88.98517609, 22.32370949], [88.98564148, 22.32333374], [88.98607635, 22.32295036], [88.98648834, 22.32254982], [88.98675537, 22.32236671], [88.98693848, 22.32224083], [88.98741913, 22.32201958], [88.98789215, 22.32183266], [88.9883728, 22.32167053], [88.98880768, 22.3215313], [88.98923492, 22.32141685], [88.98964691, 22.32130623], [88.99006653, 22.3211422], [88.9905777, 22.32111168], [88.99113464, 22.32111168], [88.99169159, 22.32111168], [88.99220276, 22.32111168], [88.99263, 22.32114983], [88.99300385, 22.32130623], [88.99343109, 22.32141495], [88.99391937, 22.32155037], [88.99446106, 22.32169151], [88.99501801, 22.32190132], [88.99563599, 22.32201195], [88.99619293, 22.32222366], [88.99672699, 22.32243347], [88.99729919, 22.32261086], [88.99778748, 22.32285118], [88.99824524, 22.32301521], [88.9988327, 22.32315636], [89.0, 22.32333565], [89.00027466, 22.32305717], [89.00035095, 22.32285118], [89.00071716, 22.32261086], [89.00093842, 22.32232094], [89.00112152, 22.3221283], [89.00152588, 22.32180023], [89.00164795, 22.32149506], [89.00203705, 22.32102013], [89.00219727, 22.32058334], [89.0025177, 22.32029152], [89.00283813, 22.32000542], [89.00315857, 22.31972313], [89.00345612, 22.31944084], [89.00378418, 22.31917191], [89.00414276, 22.31887817], [89.00454712, 22.31851006], [89.00492859, 22.31836128], [89.00548553, 22.31773567], [89.00591278, 22.31734276], [89.0063858, 22.31699181], [89.00688171, 22.3166523], [89.00733948, 22.31625748], [89.00777435, 22.31588936], [89.00820923, 22.31567383], [89.00875092, 22.31541252], [89.00900269, 22.3150444], [89.00948334, 22.31484032], [89.00984192, 22.31414223], [89.01027679, 22.31386185], [89.01065826, 22.3135128], [89.01099396, 22.31313515], [89.01122284, 22.31266975], [89.0114212, 22.31222725], [89.0116272, 22.31182289], [89.01179504, 22.31142807], [89.01200104, 22.31113243], [89.01220703, 22.31086731], [89.01235962, 22.31060219], [89.01252747, 22.31032944], [89.01274109, 22.31007385], [89.0129776, 22.30978012], [89.01313782, 22.30938148], [89.01333618, 22.30895042], [89.01357269, 22.30852509], [89.01378632, 22.30807495], [89.01402283, 22.30764008], [89.01428223, 22.30724144], [89.01456451, 22.30689812], [89.0147934, 22.30648232], [89.01511383, 22.30613136], [89.01548767, 22.30583382], [89.01586151, 22.30553627], [89.01621246, 22.30521011], [89.01656342, 22.30485916], [89.01695251, 22.30447388], [89.01729584, 22.30408287], [89.01756287, 22.30367088], [89.01783752, 22.30334282], [89.01809692, 22.3030529], [89.01838684, 22.30278969], [89.01869965, 22.30254364], [89.01906586, 22.30231285], [89.01940155, 22.30202293], [89.01976776, 22.30173302], [89.02015686, 22.30149269], [89.02046967, 22.3012085], [89.02076721, 22.30096245], [89.02097321, 22.30067444], [89.02119446, 22.30052185], [89.02140045, 22.3003521], [89.02163696, 22.30014229], [89.02189636, 22.29988289], [89.02217102, 22.29965019], [89.02242279, 22.29940224], [89.02258301, 22.29910088], [89.02269745, 22.29873276], [89.02278137, 22.29861259], [89.02297211, 22.29841995], [89.02305603, 22.29833221], [89.02305603, 22.29777718], [89.02333069, 22.29750252], [89.02326202, 22.29585075], [89.02222443, 22.29534531], [89.02126312, 22.29535294], [89.02083588, 22.29556274], [89.02027893, 22.29555511], [89.0201416, 22.29569435], [89.01999664, 22.29583549], [89.01976776, 22.29582024], [89.0194931, 22.29580879], [89.01904297, 22.29588127], [89.01862335, 22.29607773], [89.01815796, 22.29619026], [89.01773071, 22.29639244], [89.01728058, 22.29659271], [89.01678467, 22.29672813], [89.01637268, 22.29693031], [89.01596832, 22.29709053], [89.01552582, 22.29723167], [89.01512909, 22.29737282], [89.01474762, 22.29751015], [89.01439667, 22.29767036], [89.01399231, 22.29781151], [89.01358795, 22.29803085], [89.01309967, 22.29816437], [89.01264954, 22.29834938], [89.01223755, 22.29857063], [89.0117569, 22.29866028], [89.01135254, 22.29885292], [89.01091766, 22.29889107], [89.01046753, 22.29889107], [89.01000214, 22.29889107], [89.00952148, 22.29893112], [89.00904846, 22.29913139], [89.00853729, 22.29916954], [89.00802612, 22.29915047], [89.00752258, 22.29906082], [89.00701141, 22.29892159], [89.00647736, 22.29889107], [89.0059433, 22.29884148], [89.00547028, 22.29864883], [89.00493622, 22.29853439], [89.00444031, 22.29832649], [89.00391388, 22.29810143], [89.00331879, 22.29803276], [89.00273132, 22.29797173], [89.00225067, 22.29781151], [89.00179291, 22.29777718], [89.00138092, 22.29776955], [89.00098419, 22.29778862], [89.00061798, 22.29788399], [89.00028992, 22.29806328], [89.0, 22.29805565], [88.99923706, 22.29762268], [88.9990387, 22.29748154], [88.99868011, 22.29736137], [88.99825287, 22.29718971], [88.99781799, 22.29699707], [88.99738312, 22.29681969], [88.99701691, 22.29660988], [88.99668121, 22.2963829], [88.99636078, 22.29611015], [88.99599457, 22.29583549], [88.99556732, 22.29552269], [88.99521637, 22.29507828], [88.99482727, 22.29466057], [88.99454498, 22.29420471], [88.99433136, 22.29377937], [88.99415588, 22.29342079], [88.99396515, 22.29309845], [88.99385071, 22.29266357], [88.99365234, 22.29222298], [88.9936142, 22.29168892], [88.99360657, 22.29116249], [88.99360657, 22.29067039], [88.99365234, 22.29020119], [88.9937973, 22.28979111], [88.99384308, 22.28936195], [88.9936676, 22.28891182], [88.9936142, 22.28845787], [88.99360657, 22.28802109], [88.99362946, 22.28761292], [88.99373627, 22.28725243], [88.99386597, 22.28692055], [88.99388885, 22.28666687], [88.99388885, 22.28611183], [88.99416351, 22.28583336], [88.99416351, 22.28555489], [88.9944458, 22.28528023], [88.99449158, 22.28495979], [88.99472809, 22.28466225], [88.99500275, 22.28433037], [88.99529266, 22.28393936], [88.99562073, 22.28355026], [88.99603271, 22.28313255], [88.99643707, 22.28263283], [88.99695587, 22.28223228], [88.99754333, 22.28188324], [88.99767303, 22.28178978], [88.99806213, 22.28149605], [88.9985733, 22.28116035], [88.99901581, 22.28084183], [88.99944305, 22.28055573], [88.99973297, 22.28056335], [89.0, 22.28028107], [89.00026703, 22.28000069], [89.00041962, 22.27999306], [89.00077057, 22.27968025], [89.00133514, 22.27922058], [89.00185394, 22.27882576], [89.00226593, 22.27841187], [89.00269318, 22.27806282], [89.00309753, 22.27775002], [89.00350952, 22.27748299], [89.00390625, 22.2772007], [89.00431824, 22.27692986], [89.00467682, 22.27663994], [89.00501251, 22.27635193], [89.00535583, 22.27605247], [89.00576019, 22.27575111], [89.00614166, 22.27537346], [89.00654602, 22.27501488], [89.00696564, 22.27470589], [89.00737762, 22.27444267], [89.00775909, 22.27416039], [89.00814056, 22.27388954], [89.00850677, 22.27362251], [89.0089035, 22.27340126], [89.00930023, 22.2732029], [89.00969696, 22.27298164], [89.01008606, 22.27272224], [89.01048279, 22.27246857], [89.01088715, 22.27218056], [89.01135254, 22.27193642], [89.01185608, 22.27166939], [89.01241302, 22.27139091], [89.01296997, 22.27111244], [89.01355743, 22.27083778], [89.01416016, 22.27056313], [89.01477814, 22.27028084], [89.01542664, 22.26998138], [89.01608276, 22.2696209], [89.01670074, 22.26918221], [89.01730347, 22.26877975], [89.01774597, 22.26831245], [89.01799011, 22.26782036], [89.01802063, 22.26738167], [89.01790619, 22.26704979], [89.01779175, 22.26675224], [89.01766968, 22.26643944], [89.01745605, 22.26614952], [89.01715851, 22.26585388], [89.0167923, 22.26553535], [89.01642609, 22.26517487], [89.01609802, 22.2647419], [89.01573181, 22.26434135], [89.01535034, 22.26396942], [89.01496124, 22.26361847], [89.0145874, 22.26329994], [89.014328, 22.26293945], [89.01410675, 22.26257133], [89.01387024, 22.26229286], [89.01360321, 22.26202965], [89.01331329, 22.26173973], [89.01300049, 22.2614212], [89.01270294, 22.2610817], [89.01246643, 22.26066017], [89.01223755, 22.26025963], [89.01206207, 22.25984192], [89.01191711, 22.25942039], [89.01173401, 22.25904083], [89.0116272, 22.25862312], [89.01143646, 22.25825119], [89.01139069, 22.2578373], [89.01138306, 22.2574234], [89.01138306, 22.25700188], [89.01139069, 22.25658226], [89.01143646, 22.25617027], [89.01161957, 22.25583267], [89.01169586, 22.25544548], [89.01182556, 22.2551136], [89.01195526, 22.25481415], [89.01210022, 22.25455856], [89.01222992, 22.254282], [89.01237488, 22.25401115], [89.01252747, 22.25373268], [89.01272583, 22.25350571], [89.01285553, 22.25327492], [89.01301575, 22.25307274], [89.01316833, 22.25279045], [89.01342773, 22.25250435], [89.01380157, 22.25221825], [89.01419067, 22.2519207], [89.01454926, 22.25159836], [89.01494598, 22.25140953], [89.01535034, 22.25129128], [89.01571655, 22.2511425], [89.01609802, 22.25111198], [89.01651001, 22.25111198], [89.01695251, 22.25111198], [89.01737213, 22.25111198], [89.01777649, 22.25112152], [89.01818085, 22.25117111], [89.01838684, 22.25126076], [89.01856995, 22.25134277], [89.01900482, 22.25140572], [89.0194397, 22.25152016], [89.01986694, 22.25169373], [89.02028656, 22.25192833], [89.02074432, 22.25212479], [89.02125549, 22.25227356], [89.021698, 22.2524929], [89.02210999, 22.25278282], [89.02249908, 22.25306892], [89.0228653, 22.25340462], [89.02327728, 22.2537117], [89.02366638, 22.25407219], [89.02411652, 22.25438118], [89.02458191, 22.25462532], [89.02492523, 22.25492668], [89.02523804, 22.25523567], [89.02558136, 22.25552368], [89.02596283, 22.25580025], [89.02639008, 22.25604057], [89.02683258, 22.25627327], [89.0273056, 22.25647163], [89.02777863, 22.25668144], [89.02823639, 22.25694466], [89.02869415, 22.25720406], [89.02919006, 22.25738335], [89.02970123, 22.25748634], [89.03022766, 22.25753212], [89.03073883, 22.25766945], [89.03130341, 22.25774193], [89.03188324, 22.25762367], [89.03239441, 22.25729942], [89.0327301, 22.25681114], [89.03291321, 22.25626183], [89.03308105, 22.25576591], [89.03327942, 22.25536919], [89.03340149, 22.25494385], [89.03354645, 22.25452995], [89.03357697, 22.25405312], [89.03347015, 22.25355339], [89.03335571, 22.25318909], [89.03333282, 22.25285149], [89.0333786, 22.25252724], [89.03356171, 22.25222206], [89.03360748, 22.25187111], [89.03361511, 22.25152016], [89.03360748, 22.2511692], [89.03360748, 22.25081062], [89.03362274, 22.25043106], [89.03364563, 22.25003433], [89.03379822, 22.24964523], [89.03386688, 22.24920273], [89.03388977, 22.24872017], [89.03388977, 22.24821281], [89.03388977, 22.24770164], [89.03394318, 22.2471714], [89.03412628, 22.24668312], [89.0341568, 22.24617958], [89.03417206, 22.24570847], [89.0341568, 22.24527168], [89.0341568, 22.24483299], [89.03411102, 22.24440002], [89.03404999, 22.24397087], [89.03414154, 22.24353981], [89.03416443, 22.24309921], [89.03417206, 22.24266243], [89.03421021, 22.24224281], [89.03439331, 22.24186134], [89.03443909, 22.24144173], [89.03444672, 22.24101067], [89.03444672, 22.24057388], [89.03443909, 22.24012756], [89.03439331, 22.23967361], [89.03424835, 22.23925591], [89.03417969, 22.23884392], [89.03417969, 22.23841667], [89.03426361, 22.23797607], [89.0344162, 22.23755074], [89.03444672, 22.23714256], [89.03444672, 22.23672295], [89.03444672, 22.23628044], [89.03444672, 22.23578453], [89.03446198, 22.23522377], [89.03450012, 22.23464584], [89.03448486, 22.23409081], [89.03452301, 22.23359108], [89.03469086, 22.23316193], [89.03482056, 22.23270226], [89.03501129, 22.23229027], [89.0352478, 22.23192978], [89.03540802, 22.23155022], [89.03555298, 22.23120308], [89.03566742, 22.2308712], [89.03579712, 22.23056984], [89.03582764, 22.23020172], [89.0358429, 22.22980309], [89.03591156, 22.2293911], [89.03607941, 22.22899055], [89.03620148, 22.22854042], [89.03637695, 22.22809029], [89.03656006, 22.2276268], [89.03679657, 22.22719002], [89.03704834, 22.22671318], [89.03734589, 22.22626114], [89.03762817, 22.22584343], [89.03786469, 22.2254734], [89.03807068, 22.22515106], [89.03826904, 22.22488976], [89.03839111, 22.22459221], [89.03859711, 22.22435951], [89.03881073, 22.22411156], [89.03900146, 22.22380257], [89.03926849, 22.22351456], [89.03956604, 22.22319984], [89.03983307, 22.22282219], [89.04012299, 22.22247314], [89.0404129, 22.22213173], [89.040802, 22.22189522], [89.04125214, 22.22162056], [89.04170227, 22.22124481], [89.04218292, 22.22087288], [89.04265594, 22.22051048], [89.04304504, 22.22013092], [89.04340363, 22.21976089], [89.04377747, 22.21941948], [89.04413605, 22.21906662], [89.04447174, 22.21870232], [89.04482269, 22.21837044], [89.04521942, 22.2181015], [89.04559326, 22.2177906], [89.0460434, 22.21750069], [89.04653168, 22.21720314], [89.04701996, 22.21686172], [89.0474472, 22.21646309], [89.04789734, 22.21611977], [89.04834747, 22.21580315], [89.04875183, 22.21542358], [89.04915619, 22.21500969], [89.04956818, 22.21461487], [89.04995728, 22.21426392], [89.05028534, 22.21390152], [89.05060577, 22.21359825], [89.05090332, 22.21329308], [89.0512619, 22.21302223], [89.05162048, 22.21270943], [89.05198669, 22.21235085], [89.05240631, 22.21203613], [89.05284882, 22.21170235], [89.0533371, 22.21138191], [89.05383301, 22.21101189], [89.0542984, 22.21055031], [89.05475616, 22.21006203], [89.05526733, 22.20961189], [89.05576324, 22.20916939], [89.05623627, 22.20874977], [89.05673218, 22.20833206], [89.05725098, 22.20789909], [89.05780792, 22.2074585], [89.05835724, 22.20696068], [89.0589447, 22.20645905], [89.05956268, 22.2059803], [89.060112, 22.20541954], [89.06062317, 22.20480537], [89.061203, 22.20425987], [89.06183624, 22.20380974], [89.06243896, 22.20330429], [89.06301117, 22.20276833], [89.06358337, 22.20222282], [89.06416321, 22.20166969], [89.06471252, 22.20111275], [89.06521606, 22.20051003], [89.0656662, 22.19989395], [89.06612396, 22.19933319], [89.06655884, 22.19883537], [89.0667572, 22.19853592], [89.06690216, 22.19831467], [89.06716156, 22.19782829], [89.06735992, 22.19738007], [89.06755066, 22.19701195], [89.06774139, 22.19671059], [89.06783295, 22.19638252], [89.06800842, 22.19612312], [89.06812286, 22.19579124], [89.0683136, 22.19545364], [89.0684433, 22.19502068], [89.06859589, 22.19456482], [89.06873322, 22.19406319], [89.06886292, 22.19355202], [89.06893158, 22.19302177], [89.06908417, 22.19255638], [89.06915283, 22.19205284], [89.06916809, 22.19153023], [89.06916809, 22.19099808], [89.06916809, 22.19046783], [89.06912231, 22.18993378], [89.06893158, 22.18943024], [89.06887817, 22.18925095], [89.06876373, 22.18889236], [89.06858826, 22.18836594], [89.06833649, 22.18788528], [89.06806946, 22.18740273], [89.06785583, 22.18688393], [89.06770325, 22.18633461], [89.06749725, 22.18586159], [89.067276, 22.18546104], [89.06713104, 22.18509293], [89.06691742, 22.18482018], [89.06667328, 22.18460464], [89.06642151, 22.18433571], [89.06619263, 22.18397141], [89.06591797, 22.18354988], [89.06569672, 22.18305016], [89.06549835, 22.18254471], [89.06526947, 22.18206215], [89.06500244, 22.18161201], [89.06471252, 22.18116951], [89.06437683, 22.18077278], [89.06401062, 22.18040466], [89.06368256, 22.18004036], [89.06346893, 22.17956734], [89.06328583, 22.17904091], [89.06304932, 22.17850304], [89.06277466, 22.17796326], [89.0625, 22.17742729], [89.06223297, 22.17691231], [89.06197357, 22.17640114], [89.06181335, 22.17583275], [89.06165314, 22.17523003], [89.06143188, 22.17463493], [89.06137085, 22.17398262], [89.06125641, 22.17337227], [89.06112671, 22.17282295], [89.06111145, 22.17233849], [89.06111145, 22.1718998], [89.06109619, 22.17148018], [89.06103516, 22.17106628], [89.06086731, 22.17065048], [89.06083679, 22.17016792], [89.06082916, 22.16963005], [89.06082916, 22.1690731], [89.06082916, 22.16847038], [89.06082916, 22.16788483], [89.06083679, 22.16731071], [89.06086731, 22.1667614], [89.06104279, 22.16626167], [89.06111908, 22.16571808], [89.06122589, 22.16516304], [89.061409, 22.16462135], [89.06165314, 22.16408157], [89.0617981, 22.16348076], [89.06195068, 22.16286278], [89.06210327, 22.16222954], [89.06227112, 22.16163445], [89.06250763, 22.16110992], [89.06273651, 22.16064453], [89.06286621, 22.1601696], [89.06304169, 22.15976715], [89.06328583, 22.15942192], [89.06342316, 22.15895653], [89.06362915, 22.15850258], [89.06388092, 22.15802956], [89.06414032, 22.15752792], [89.06437683, 22.15701103], [89.06462097, 22.15649223], [89.06486511, 22.15597725], [89.06510925, 22.15543175], [89.06532288, 22.15480995], [89.06556702, 22.1541996], [89.06583405, 22.15361786], [89.06609344, 22.15306282], [89.06626129, 22.15250206], [89.06640625, 22.15195274], [89.06658173, 22.15145874], [89.06671906, 22.15097237], [89.06692505, 22.15056801], [89.06707001, 22.15015984], [89.06723785, 22.14977837], [89.06745148, 22.14941978], [89.06754303, 22.14898682], [89.06777191, 22.1486187], [89.06803131, 22.14825249], [89.06830597, 22.14780998], [89.06864166, 22.14736176], [89.06906128, 22.14692116], [89.06951141, 22.14647675], [89.07002258, 22.14612007], [89.07054901, 22.14582825], [89.07104492, 22.14557457], [89.07156372, 22.14537621], [89.07205963, 22.14517021], [89.07254791, 22.14497948], [89.07299042, 22.14478111], [89.07348633, 22.14471817], [89.07403564, 22.14469337], [89.07462311, 22.14456367], [89.07524109, 22.14451027], [89.07582092, 22.14467812], [89.0763855, 22.14471817], [89.07686615, 22.14476395], [89.0772934, 22.1449604], [89.0777359, 22.14503479], [89.07822418, 22.1451683], [89.07879639, 22.1453228], [89.07938385, 22.14555931], [89.07995605, 22.14583015], [89.080513, 22.14611244], [89.08102417, 22.14641953], [89.08149719, 22.14678001], [89.08194733, 22.14719772], [89.08248901, 22.14755058], [89.08303833, 22.14792061], [89.08354187, 22.14830971], [89.08403015, 22.14864159], [89.08441925, 22.14900398], [89.08474731, 22.14939308], [89.08505249, 22.14977074], [89.08537292, 22.15010262], [89.08569336, 22.15041351], [89.08599854, 22.15072823], [89.08629608, 22.15109253], [89.08661652, 22.15142822], [89.08693695, 22.15177917], [89.08722687, 22.15213013], [89.08751678, 22.15246391], [89.08779907, 22.15281105], [89.0880661, 22.15322304], [89.08840179, 22.1536808], [89.08877563, 22.15418625], [89.08920288, 22.15474129], [89.08966064, 22.15528297], [89.09011078, 22.15579605], [89.09052277, 22.15622139], [89.09085846, 22.15660667], [89.09117889, 22.15692329], [89.09153748, 22.15721321], [89.09200287, 22.15749168], [89.09255219, 22.15777016], [89.09320831, 22.15793037], [89.09388733, 22.15773964], [89.0944519, 22.15730095], [89.09497833, 22.15684319], [89.0954361, 22.15638161], [89.09580994, 22.15593529], [89.09609222, 22.15549278], [89.09626007, 22.15501213], [89.09636688, 22.15453148], [89.09634399, 22.15405083], [89.09612274, 22.15361977], [89.09585571, 22.15320396], [89.09576416, 22.15303802], [89.09560394, 22.15275955], [89.0953598, 22.15232658], [89.09506226, 22.15194893], [89.09474945, 22.15160179], [89.09443665, 22.15123177], [89.09414673, 22.15086746], [89.09384918, 22.15050316], [89.09361267, 22.15007973], [89.09335327, 22.14963913], [89.09313965, 22.14917755], [89.09288788, 22.14873314], [89.0925827, 22.14834023], [89.09224701, 22.14796257], [89.09195709, 22.14752007], [89.09168243, 22.14710808], [89.09142303, 22.14672279], [89.09111023, 22.14639091], [89.09075165, 22.14603806], [89.09029388, 22.14570236], [89.08979034, 22.14529991], [89.08921814, 22.14492226], [89.08866882, 22.14450645], [89.08811188, 22.14411163], [89.08757019, 22.1436882], [89.08695221, 22.14334488], [89.08631134, 22.14305305], [89.08570862, 22.14275169], [89.08516693, 22.1423912], [89.08470154, 22.14203072], [89.08423615, 22.14176178], [89.08374786, 22.1416111], [89.08332825, 22.14138985], [89.08294678, 22.14117241], [89.08251953, 22.14101982], [89.08207703, 22.14081192], [89.08165741, 22.14054108], [89.08122253, 22.14025116], [89.08080292, 22.13993263], [89.08031464, 22.13970375], [89.07985687, 22.13944435], [89.07942963, 22.13918114], [89.07897949, 22.13897133], [89.07854462, 22.13878822], [89.07816315, 22.13845253], [89.07772064, 22.13812256], [89.07718658, 22.13780975], [89.07662201, 22.13746071], [89.07609558, 22.13705826], [89.07555389, 22.13668251], [89.07501221, 22.13638306], [89.07453918, 22.13608932], [89.0741272, 22.13580132], [89.07373047, 22.13555336], [89.07337189, 22.1353054], [89.07306671, 22.13502312], [89.0727005, 22.13480377], [89.07228088, 22.13465118], [89.07184601, 22.13443184], [89.07144165, 22.13417053], [89.07102203, 22.13392067], [89.07059479, 22.13371086], [89.07022095, 22.13345146], [89.06980896, 22.13326073], [89.06945038, 22.13300133], [89.06909943, 22.13272667], [89.06871796, 22.13247681], [89.06835175, 22.13218307], [89.06797791, 22.13188362], [89.06757355, 22.13161087], [89.06716919, 22.13129234], [89.06674957, 22.13102531], [89.06639099, 22.13069344], [89.06603241, 22.13038254], [89.06561279, 22.13018227], [89.06522369, 22.12994957], [89.06481171, 22.12972069], [89.06439209, 22.12952232], [89.06394958, 22.12936783], [89.06356049, 22.12915993], [89.0632019, 22.1289196], [89.06285095, 22.12874031], [89.06250763, 22.12859344], [89.06218719, 22.12842941], [89.06186676, 22.12836075], [89.06156158, 22.12849236], [89.06128693, 22.1289196], [89.06114197, 22.12948036], [89.06111145, 22.13010216], [89.06111145, 22.13075066], [89.06105804, 22.13140678], [89.06083679, 22.13205528], [89.06062317, 22.13274574], [89.06051636, 22.13348389], [89.06031799, 22.13414955], [89.06022644, 22.13478279], [89.06005096, 22.13526917], [89.05999756, 22.1356926], [89.05993652, 22.13600731], [89.05979156, 22.13625145], [89.05973053, 22.13653564], [89.05967712, 22.13691139], [89.05944824, 22.13731956], [89.05918121, 22.13778114], [89.05893707, 22.13826942], [89.05867004, 22.13866615], [89.05844116, 22.13904381], [89.05815125, 22.13935661], [89.05784607, 22.13973236], [89.05745697, 22.14017105], [89.05700684, 22.14067841], [89.05658722, 22.14130974], [89.05609131, 22.14191628], [89.05555725, 22.14249229], [89.05500793, 22.14304543], [89.05444336, 22.14355278], [89.05387878, 22.14402962], [89.05332184, 22.14447594], [89.05280304, 22.14495277], [89.05220032, 22.1453228], [89.05166626, 22.14556313], [89.05055237, 22.14666939], [89.05027771, 22.14666939], [89.05000305, 22.14694405], [89.04966736, 22.14692116], [89.04927063, 22.14697838], [89.04882813, 22.14715385], [89.04836273, 22.14730263], [89.04792786, 22.14747047], [89.04750061, 22.14761162], [89.04707336, 22.14774513], [89.04660034, 22.14785385], [89.04612732, 22.14806366], [89.04566193, 22.14830971], [89.04515076, 22.14846611], [89.04466248, 22.14863586], [89.04420471, 22.1488533], [89.04370117, 22.14896393], [89.04325104, 22.14912987], [89.04273224, 22.14920807], [89.04224396, 22.14938927], [89.04176331, 22.14949226], [89.04129028, 22.149683], [89.04078674, 22.14977074], [89.04032135, 22.14996147], [89.03981018, 22.15010834], [89.03933716, 22.15036201], [89.03891754, 22.1505909], [89.03852844, 22.15082741], [89.03812408, 22.15105438], [89.03777313, 22.1512928], [89.03749847, 22.15139389], [89.03694153, 22.15167046], [89.03610992, 22.15250206], [89.0358429, 22.15250206], [89.03549194, 22.15275192], [89.0351944, 22.15286636], [89.03491974, 22.15310287], [89.03457642, 22.15332985], [89.03418732, 22.15361977], [89.03383636, 22.15403938], [89.03343964, 22.1544323], [89.03299713, 22.1547699], [89.03253174, 22.15510178], [89.03206635, 22.15545273], [89.0316925, 22.15585136], [89.03141022, 22.15628624], [89.0311203, 22.15668106], [89.03083801, 22.15708542], [89.03056335, 22.15748024], [89.03022003, 22.15784264], [89.02986908, 22.15818977], [89.02951813, 22.15854645], [89.02921295, 22.15895271], [89.02893066, 22.1593914], [89.02861786, 22.15979195], [89.02828979, 22.16019249], [89.02794647, 22.16054726], [89.02760315, 22.16089058], [89.02732849, 22.16127968], [89.02705383, 22.1616497], [89.02672577, 22.16196251], [89.02639008, 22.16226578], [89.02600861, 22.16251945], [89.02561951, 22.16276932], [89.02532196, 22.16316032], [89.02507019, 22.16358757], [89.02478027, 22.16397285], [89.02449799, 22.16436958], [89.02418518, 22.16470528], [89.02385712, 22.16502953], [89.02352905, 22.16538048], [89.02323914, 22.16579819], [89.02294922, 22.16626167], [89.02280426, 22.16685486], [89.022789, 22.16750145], [89.02288818, 22.16813087], [89.02310944, 22.16864967], [89.02333832, 22.16909981], [89.0235672, 22.16950226], [89.02365875, 22.16995239], [89.02388, 22.17033958], [89.02407837, 22.17075729], [89.02423096, 22.17123985], [89.02441406, 22.1717205], [89.02452087, 22.1722641], [89.02468872, 22.17278481], [89.02476501, 22.17335129], [89.02496338, 22.17389107], [89.02503967, 22.17450142], [89.02523041, 22.17508125], [89.02539825, 22.17567253], [89.02558899, 22.17622185], [89.02583313, 22.17671394], [89.02605438, 22.17721748], [89.02612305, 22.17781258], [89.02614594, 22.17843056], [89.02632141, 22.17901039], [89.02641296, 22.1795826], [89.02649689, 22.18008995], [89.02662659, 22.18054008], [89.02666473, 22.18102074], [89.02666473, 22.18151474], [89.02666473, 22.18200684], [89.02671051, 22.18248177], [89.02690125, 22.1829319], [89.02693939, 22.18342018], [89.02694702, 22.18393326], [89.02694702, 22.18447495], [89.02697754, 22.18499756], [89.0271759, 22.18546104], [89.02722168, 22.18590736], [89.02722168, 22.18632317], [89.02722168, 22.18669319], [89.02722168, 22.18701553], [89.02722168, 22.18734169], [89.02720642, 22.18771172], [89.02716064, 22.18808937], [89.02697754, 22.18850136], [89.02692413, 22.18896294], [89.02683258, 22.18940163], [89.02669525, 22.18982124], [89.02667236, 22.19028473], [89.0266571, 22.19080162], [89.02661896, 22.19136238], [89.02643585, 22.1919384], [89.02635193, 22.19257736], [89.02619171, 22.19315147], [89.02612305, 22.19371223], [89.02610779, 22.19424248], [89.02606201, 22.19472313], [89.02587891, 22.19513893], [89.02583313, 22.19555092], [89.02575684, 22.19589996], [89.0256424, 22.19616127], [89.02561951, 22.19641685], [89.0255661, 22.19663048], [89.02548218, 22.1968708], [89.02529907, 22.19715309], [89.02513123, 22.19749832], [89.02497101, 22.19787025], [89.02475739, 22.19820023], [89.02458954, 22.19859123], [89.02437592, 22.19895935], [89.02415466, 22.19935608], [89.02389526, 22.19978142], [89.02364349, 22.20026207], [89.02342224, 22.20079994], [89.02312469, 22.20132256], [89.02278137, 22.20181465], [89.02240753, 22.20230484], [89.02198029, 22.20275307], [89.02153778, 22.20319366], [89.02117157, 22.20364952], [89.02083588, 22.20408249], [89.02056122, 22.20444489], [89.02027893, 22.2047596], [89.02002716, 22.20506287], [89.0197525, 22.20538712], [89.01972198, 22.20555305], [89.01860809, 22.20667076], [89.01750183, 22.20666695], [89.01721954, 22.20694542], [89.01667023, 22.2069416], [89.01655579, 22.20705986], [89.01625824, 22.20724297], [89.01593781, 22.20747566], [89.01555634, 22.20767021], [89.01516724, 22.20788193], [89.01473236, 22.20807076], [89.01432037, 22.20829773], [89.01383209, 22.20841026], [89.01340485, 22.20861816], [89.01298523, 22.20887184], [89.01248932, 22.20906258], [89.01194763, 22.20926094], [89.01139069, 22.20946312], [89.01081085, 22.20968056], [89.01019287, 22.2097683], [89.00962067, 22.20996284], [89.00901794, 22.21016502], [89.00845337, 22.21043968], [89.00785828, 22.21068764], [89.00720978, 22.2107029], [89.00658417, 22.21080971], [89.0059967, 22.2108326], [89.00547791, 22.21083641], [89.00501251, 22.2108326], [89.00457764, 22.2108326], [89.00415802, 22.2108326], [89.00374603, 22.21088219], [89.00332642, 22.2110424], [89.0029068, 22.21096992], [89.00248718, 22.21089935], [89.00206757, 22.21104813], [89.0016098, 22.21113014], [89.00110626, 22.21115494], [89.00057983, 22.21120644], [89.00028992, 22.21157455], [89.0, 22.21194649], [88.99907684, 22.21123886], [88.99858856, 22.21086311], [88.9972229, 22.21024132], [88.99674988, 22.21003151], [88.99624634, 22.20985985], [88.99575043, 22.20968056], [88.9952774, 22.20944023], [88.99481201, 22.20920372], [88.9943161, 22.20903969], [88.9937973, 22.20885277], [88.99333191, 22.20860863], [88.99286652, 22.20833015], [88.99239349, 22.2080555], [88.99188995, 22.20778084], [88.99137115, 22.20750809], [88.99079132, 22.20729637], [88.99017334, 22.20713234], [88.98956299, 22.20702171], [88.98916626, 22.20681953], [88.98880005, 22.20659637], [88.98844147, 22.20637131], [88.98807526, 22.20615578], [88.98763275, 22.20604134], [88.98724365, 22.2058754], [88.98678589, 22.20577049], [88.98628235, 22.20560265], [88.98568726, 22.20556068], [88.9850769, 22.20556068], [88.98452759, 22.20557976], [88.98404694, 22.20568657], [88.98361206, 22.20581055], [88.98317719, 22.20591164], [88.98278809, 22.20609283], [88.98236084, 22.20618248], [88.98191833, 22.20620155], [88.98152161, 22.20634842], [88.98107147, 22.20643044], [88.98062897, 22.20660973], [88.9801178, 22.20671272], [88.97962189, 22.20689201], [88.97910309, 22.20704079], [88.97863007, 22.20724297], [88.97822571, 22.20748711], [88.97782898, 22.20770264], [88.97735596, 22.20779228], [88.97691345, 22.2079525], [88.97644806, 22.2080822], [88.97601318, 22.20829964], [88.97548676, 22.20843124], [88.97499084, 22.20863152], [88.97450256, 22.20884514], [88.97398376, 22.20897484], [88.97348785, 22.20918465], [88.97299957, 22.20944214], [88.97251892, 22.20971107], [88.9720993, 22.21002007], [88.97173309, 22.21031952], [88.97145081, 22.21063042], [88.97125244, 22.21095085], [88.97107697, 22.21116066], [88.97088623, 22.21133232], [88.97074127, 22.21148109], [88.9705658, 22.2116642], [88.97042084, 22.21185684], [88.97019958, 22.2121067], [88.96996307, 22.21246338], [88.96969604, 22.21278954], [88.96943665, 22.21313286], [88.96916962, 22.21349716], [88.9688797, 22.21389961], [88.96861267, 22.21431351], [88.96836853, 22.21469307], [88.96816254, 22.21504974], [88.96806335, 22.21541023], [88.96795654, 22.21575165], [88.96782684, 22.2160511], [88.96775818, 22.21642113], [88.96765137, 22.21677971], [88.96750641, 22.21717262], [88.96740723, 22.21759224], [88.96730042, 22.21795082], [88.96718597, 22.21825218], [88.9670105, 22.21859932], [88.96689606, 22.21910286], [88.96672058, 22.21964836], [88.96664429, 22.22027206], [88.96652985, 22.22088051], [88.96637726, 22.22147179], [88.96620178, 22.22203255], [88.96611023, 22.22260284], [88.96602631, 22.22315025], [88.96593475, 22.22368431], [88.96580505, 22.2241497], [88.96560669, 22.22456169], [88.96557617, 22.22501183], [88.96559143, 22.22547913], [88.96552277, 22.22596169], [88.96536255, 22.22641945], [88.96539307, 22.22691536], [88.96537781, 22.2273159], [88.96530914, 22.22759438], [88.96528625, 22.2278862], [88.96527863, 22.22821236], [88.96526337, 22.22855949], [88.96521759, 22.228899], [88.96504974, 22.22919273], [88.96499634, 22.22958946], [88.96499634, 22.23008919], [88.96496582, 22.23069954], [88.96485138, 22.23139763], [88.96466064, 22.23205376], [88.96453094, 22.23268127], [88.96445465, 22.23326111], [88.96443176, 22.23378181], [88.96437836, 22.23424721], [88.96430206, 22.23465157], [88.96421814, 22.23496246], [88.96414948, 22.23524666], [88.96403503, 22.23552132], [88.96391296, 22.23584938], [88.96379852, 22.23627281], [88.96369934, 22.23679543], [88.96353912, 22.23729134], [88.96331787, 22.23781395], [88.96305847, 22.23833847], [88.96279907, 22.23890114], [88.96261597, 22.23949814], [88.96251678, 22.24001122], [88.96244812, 22.2405529], [88.96222687, 22.2410717], [88.96198273, 22.24162865], [88.96170044, 22.24218559], [88.96139526, 22.24271393], [88.96111298, 22.24320221], [88.96083069, 22.24363136], [88.9605484, 22.24400139], [88.96026611, 22.24435234], [88.95996857, 22.24465752], [88.9596405, 22.2449398], [88.95926666, 22.24519348], [88.95896912, 22.24547768], [88.95861816, 22.24579811], [88.9582901, 22.24617958], [88.95802307, 22.24666023], [88.9576416, 22.24708748], [88.95717621, 22.24754143], [88.95671844, 22.24799538], [88.95623779, 22.24840164], [88.95581818, 22.24888039], [88.95539093, 22.24936104], [88.95501709, 22.24985313], [88.95452118, 22.25022316], [88.95401001, 22.25055122], [88.95349884, 22.25083923], [88.95303345, 22.25110817], [88.95259094, 22.25134468], [88.95213318, 22.25149345], [88.95169067, 22.25168037], [88.95124817, 22.25193787], [88.95078278, 22.25220299], [88.95027161, 22.25248146], [88.94976807, 22.25278282], [88.94972229, 22.25305748], [88.94833374, 22.25444603], [88.94805908, 22.25444031], [88.94750214, 22.25500107], [88.94750214, 22.25528145], [88.94721985, 22.25555992], [88.94721985, 22.25611115], [88.94750214, 22.25638962], [88.94750214, 22.25805283], [88.94749451, 22.2584095], [88.94764709, 22.25869179], [88.94779968, 22.25901222], [88.94800568, 22.25932884], [88.94820404, 22.25971222], [88.94844055, 22.2601223], [88.94864655, 22.26059914], [88.94888306, 22.2610836], [88.94914246, 22.26154137], [88.94936371, 22.26213646], [88.94957733, 22.26273537], [88.94972229, 22.26316452], [88.94984436, 22.26353264], [88.94992828, 22.26390266], [88.94998932, 22.26426125], [88.94999695, 22.26461983], [88.95004272, 22.26499748], [88.95020294, 22.26540947], [88.95030212, 22.2659626], [88.95046234, 22.26658058], [88.95059204, 22.26718903], [88.95079041, 22.2677803], [88.95089722, 22.26841545], [88.95111847, 22.26896286], [88.95136261, 22.26951027], [88.95153809, 22.27013016], [88.95173645, 22.27072906], [88.95178986, 22.27132797], [88.95198822, 22.27177238], [88.9520874, 22.27224159], [88.95218658, 22.27259827], [88.95222473, 22.27292061], [88.95226288, 22.27324486], [88.95240784, 22.27355385], [88.95252228, 22.27394485], [88.95269012, 22.27440071], [88.95276642, 22.27497292], [88.95288086, 22.27563286], [88.95301819, 22.27635193], [88.95307159, 22.27712059], [88.95314789, 22.2779274], [88.95320892, 22.27874756], [88.95330048, 22.27943993], [88.95333099, 22.28009987], [88.95330811, 22.28074074], [88.95320892, 22.28137398], [88.95320892, 22.28205299], [88.95327759, 22.28271294], [88.95332336, 22.2833004], [88.95333099, 22.28384972], [88.95333099, 22.2843132], [88.95333099, 22.28471375], [88.95333099, 22.28510094], [88.95333099, 22.28553009], [88.95330048, 22.2860508], [88.95320892, 22.28662109], [88.95321655, 22.28717232], [88.95330811, 22.28764725], [88.95333099, 22.2881031], [88.95333862, 22.28854179], [88.95333862, 22.28896141], [88.95333862, 22.28941154], [88.95333099, 22.28991127], [88.95327759, 22.29045486], [88.95305634, 22.29097176], [88.95285797, 22.29153061], [88.9527359, 22.2921505], [88.95256042, 22.29269218], [88.95246887, 22.29314995], [88.95233154, 22.29351807], [88.95223999, 22.29390144], [88.95220947, 22.29432106], [88.95214081, 22.29476738], [88.95195007, 22.29513168], [88.95173645, 22.29549217], [88.95159149, 22.29588127], [88.95140839, 22.29622078], [88.95134735, 22.29658318], [88.95121002, 22.29687119], [88.95111847, 22.2972126], [88.9510498, 22.29761505], [88.95088196, 22.29805946], [88.95083618, 22.29865074], [88.95082855, 22.29933357], [88.95083618, 22.30006981], [88.95088196, 22.30083275], [88.95105743, 22.30154228], [88.95110321, 22.30230141], [88.95111847, 22.30303001], [88.95115662, 22.30365944], [88.95133972, 22.30415726], [88.9513855, 22.30463028], [88.95140839, 22.30504036], [88.95147705, 22.30541992], [88.9514389, 22.30589104], [88.95147705, 22.30639076], [88.95162964, 22.30690384], [88.95176697, 22.3074398], [88.95175171, 22.30798531], [88.95173645, 22.30861473], [88.95189667, 22.30919075], [88.95194244, 22.30977058], [88.95194244, 22.31031609], [88.95194244, 22.31085587], [88.95194244, 22.31140327], [88.95194244, 22.31195259], [88.95191193, 22.3124752], [88.95179749, 22.31295967], [88.95178986, 22.31348228], [88.95189667, 22.31400108], [88.95195007, 22.31451988], [88.95198822, 22.31502914], [88.95211029, 22.31554222], [88.95198822, 22.31604195], [88.95194244, 22.31655121], [88.95189667, 22.31703758], [88.95173645, 22.31747246], [88.95168304, 22.3180027], [88.95162201, 22.31854057], [88.9514389, 22.31905365], [88.95139313, 22.31958961], [88.9513855, 22.32013512], [88.9513855, 22.32066154], [88.95137787, 22.32114983], [88.95140839, 22.32160187], [88.95153046, 22.32201195], [88.95158386, 22.32243347], [88.95155334, 22.32286263], [88.95147705, 22.32328033], [88.95160675, 22.32373238], [88.95160675, 22.32419968], [88.95144653, 22.32465172], [88.95140839, 22.32511139], [88.9515152, 22.32556534], [88.95162964, 22.32604027], [88.95166016, 22.32653236], [88.95166779, 22.32697868], [88.95168304, 22.32734489], [88.95176697, 22.32761383], [88.95202637, 22.32781029], [88.95209503, 22.32802963], [88.951828, 22.3282795], [88.95170593, 22.32854652], [88.95166779, 22.32883835], [88.95169067, 22.32920265], [88.95178986, 22.32958031], [88.95186615, 22.32999229], [88.95191956, 22.33042908], [88.95192719, 22.33088112], [88.95195007, 22.33133507], [88.95198822, 22.33179283], [88.95215607, 22.33221817], [88.9523468, 22.33266449], [88.95252228, 22.33316994], [88.9527359, 22.33365059], [88.95295715, 22.33414268], [88.95320129, 22.33460045], [88.95340729, 22.33506012], [88.95359802, 22.33548164], [88.95376587, 22.33586311], [88.95391846, 22.33621025], [88.9540863, 22.33652115], [88.95419312, 22.33684921], [88.95435333, 22.33716011], [88.95442963, 22.33756065], [88.95448303, 22.3379879], [88.95462799, 22.33839226], [88.95471954, 22.3388195], [88.95479584, 22.33919907], [88.95495605, 22.33951569], [88.95498657, 22.33984947], [88.95500183, 22.3401947], [88.95504761, 22.34052467], [88.95522308, 22.34081268], [88.95529938, 22.34119225], [88.95542145, 22.34156036], [88.955513, 22.3419838], [88.95558929, 22.34239006], [88.95575714, 22.34274292], [88.95582581, 22.34308815], [88.95587921, 22.34340286], [88.95600891, 22.34364128], [88.95609283, 22.34392548], [88.95612335, 22.34427071], [88.95614624, 22.34467506], [88.95618439, 22.34477615], [88.95630646, 22.34510422], [88.95637512, 22.34559441], [88.95639038, 22.3461132], [88.95639801, 22.34662056], [88.95644379, 22.34710884], [88.95643616, 22.3476181], [88.95661926, 22.34810066], [88.95665741, 22.34860611], [88.95667267, 22.34910011], [88.95666504, 22.34954643], [88.9566803, 22.3499012], [88.95667267, 22.35028458], [88.95639038, 22.35056114], [88.95639038, 22.35277748], [88.95614624, 22.35301399], [88.95600891, 22.35342216], [88.95581818, 22.35384941], [88.95555878, 22.35427284], [88.95527649, 22.35474205], [88.95501709, 22.35522842], [88.95481873, 22.35575485], [88.95466614, 22.35624886], [88.95448303, 22.35667229], [88.95436859, 22.35710144], [88.954216, 22.35746384], [88.95414734, 22.35788155], [88.95404816, 22.35832024], [88.95391846, 22.358778], [88.9539032, 22.35926247], [88.95391083, 22.35972786], [88.95402527, 22.36013603], [88.95418549, 22.36048317], [88.95440674, 22.36079407], [88.95469666, 22.36109924], [88.9550705, 22.36139107], [88.95550537, 22.36160851], [88.95600891, 22.36167145], [88.95651245, 22.36174011], [88.9569397, 22.36190987], [88.95742798, 22.36202621], [88.95789337, 22.36219215], [88.95839691, 22.36230659], [88.95887756, 22.36249161], [88.95934296, 22.36268044], [88.95968628, 22.36292076], [88.95996857, 22.36322212], [88.96018219, 22.36359024], [88.96047211, 22.36394119], [88.9608078, 22.36433983], [88.96118164, 22.36478996], [88.96154022, 22.36523628], [88.96198273, 22.36557961], [88.9624176, 22.36587143], [88.96283722, 22.36615944], [88.96334839, 22.36640549], [88.96385193, 22.36667061], [88.96431732, 22.36700058], [88.9646225, 22.36744118], [88.96471405, 22.36802864], [88.96478271, 22.36861992], [88.96495056, 22.36918068], [88.96505737, 22.36975288], [88.965271, 22.37022018], [88.96547699, 22.37066078], [88.96560669, 22.3711319], [88.96579742, 22.37155342], [88.96588898, 22.37202263], [88.96605682, 22.37246132], [88.96614838, 22.37301064], [88.96633911, 22.3735714], [88.96650696, 22.3741703], [88.96665955, 22.37477493], [88.96676636, 22.37536049], [88.96691132, 22.37590027], [88.96694183, 22.37635231], [88.96694946, 22.37671089], [88.96694183, 22.37703705], [88.96694183, 22.3774147], [88.96691895, 22.37790108], [88.96684265, 22.37849808], [88.96691132, 22.3791523], [88.96698761, 22.37978172], [88.96717834, 22.3802681], [88.96730804, 22.38075066], [88.96747589, 22.38118172], [88.96763611, 22.38158989], [88.96779633, 22.3819828], [88.9679718, 22.38232803], [88.96806335, 22.38272858], [88.9681778, 22.38318062], [88.96829987, 22.38371277], [88.96833038, 22.38428307], [88.96833801, 22.38484001], [88.96833801, 22.38537025], [88.96833038, 22.38585281], [88.96829987, 22.38626289], [88.96817017, 22.38656425], [88.96807861, 22.38688278], [88.96803284, 22.38724899], [88.96792603, 22.38760948], [88.96779633, 22.3879528], [88.96778107, 22.38828087], [88.96781921, 22.38858223], [88.96795654, 22.38883018], [88.96807861, 22.38909721], [88.96826172, 22.38934135], [88.96855164, 22.38955116], [88.96882629, 22.3898716], [88.96916199, 22.39025307], [88.96958923, 22.39055061], [88.97006226, 22.39080811], [88.97054291, 22.39098167], [88.97097778, 22.39114952], [88.97136688, 22.39138222], [88.97174835, 22.39159393], [88.97213745, 22.3917408], [88.97247314, 22.39195061], [88.97277832, 22.39219093], [88.97304535, 22.39245033], [88.9732666, 22.39273262], [88.97342682, 22.39304161], [88.97355652, 22.39334297], [88.97367096, 22.39364052], [88.97384644, 22.39391136], [88.97389221, 22.39416695], [88.97389221, 22.39472008], [88.97416687, 22.39500237], [88.97416687, 22.39666939], [88.97400665, 22.39671135], [88.97385406, 22.39712334], [88.97358704, 22.39756966], [88.97328186, 22.39806175], [88.97293091, 22.39857483], [88.97254944, 22.39902687], [88.972229, 22.39949226], [88.97193909, 22.39993477], [88.9716568, 22.40034294], [88.97135162, 22.40071678], [88.97100067, 22.40105057], [88.97064972, 22.40139008], [88.9703064, 22.40172386], [88.9699707, 22.40203476], [88.96962738, 22.40232086], [88.9692688, 22.40258217], [88.9688797, 22.40287209], [88.96848297, 22.40322304], [88.9681015, 22.40367699], [88.96775818, 22.40418434], [88.967453, 22.40468025], [88.96718597, 22.40514183], [88.96695709, 22.40555], [88.96681213, 22.40595245], [88.96669769, 22.40631866], [88.96669006, 22.4066906], [88.96679688, 22.40706062], [88.9670105, 22.40740585], [88.96736145, 22.40769005], [88.96786499, 22.40786743], [88.96840668, 22.40807152], [88.96893311, 22.40829277], [88.96948242, 22.40841103], [88.97000885, 22.40858269], [88.97054291, 22.40856934], [88.97107697, 22.40831947], [88.97157288, 22.40792274], [88.97190857, 22.40736961], [88.97212219, 22.40676308], [88.97225952, 22.40617943], [88.97248077, 22.4057579], [88.97267151, 22.40538216], [88.97288513, 22.40504265], [88.97318268, 22.40473747], [88.97357941, 22.40445137], [88.97403717, 22.4041748], [88.97455597, 22.40389061], [88.97483063, 22.40374374], [88.97511292, 22.40359306], [88.97560883, 22.40326118], [88.97599792, 22.40289116], [88.97632599, 22.40250969], [88.97664642, 22.40214157], [88.97698975, 22.40174294], [88.97741699, 22.40140152], [88.97788239, 22.40105057], [88.97827148, 22.40060806], [88.97860718, 22.40018272], [88.97892761, 22.39985657], [88.97921753, 22.39964104], [88.97945404, 22.39938354], [88.97970581, 22.39911461], [88.97999573, 22.39879417], [88.98033142, 22.3984127], [88.98075104, 22.39801979], [88.98117065, 22.39761353], [88.98159027, 22.39722824], [88.98203278, 22.39687157], [88.98252106, 22.39655113], [88.98306274, 22.39624786], [88.98363495, 22.39591026], [88.98420715, 22.39554024], [88.98474884, 22.39511108], [88.98530579, 22.39473152], [88.98587799, 22.39440918], [88.98644257, 22.39415169], [88.98692322, 22.39383125], [88.98733521, 22.39348984], [88.98770142, 22.3931179], [88.98800659, 22.39270973], [88.98828125, 22.39229012], [88.98858643, 22.39192009], [88.98886871, 22.3915596], [88.98908997, 22.39115906], [88.98915863, 22.3906498], [88.98916626, 22.39012909], [88.98915863, 22.38960075], [88.98907471, 22.38908958], [88.98887634, 22.38861275], [88.98861694, 22.3881588], [88.98848724, 22.38794518], [88.98833466, 22.38768959], [88.98805237, 22.38720131], [88.98774719, 22.38670158], [88.98743439, 22.3862133], [88.98703003, 22.38576698], [88.9866333, 22.38533974], [88.98623657, 22.3849411], [88.98591614, 22.38455009], [88.98564911, 22.3841629], [88.98542023, 22.38376045], [88.9852066, 22.38334084], [88.98499298, 22.38290215], [88.98475647, 22.38243294]]], [[[88.80544281, 22.21244049], [88.80532074, 22.21291161], [88.80528259, 22.21336555], [88.80527496, 22.21379471], [88.80531311, 22.21421242], [88.80539703, 22.21461487], [88.80555725, 22.21497726], [88.80574036, 22.21536064], [88.80587769, 22.21581078], [88.80606079, 22.2162571], [88.80618286, 22.21676064], [88.80631256, 22.21723747], [88.80632019, 22.21771049], [88.80623627, 22.21814156], [88.80615997, 22.21852112], [88.80610657, 22.21887016], [88.8060379, 22.21920013], [88.80591583, 22.21951103], [88.80586243, 22.21985054], [88.80583191, 22.22021294], [88.80576324, 22.2205925], [88.80561066, 22.2209549], [88.80548859, 22.22136116], [88.80529022, 22.22168159], [88.8050766, 22.22200584], [88.80487061, 22.22237206], [88.80464935, 22.22278023], [88.80426025, 22.22313118], [88.80369568, 22.22337914], [88.80312347, 22.22363472], [88.80260468, 22.22393227], [88.80213165, 22.22427177], [88.80168152, 22.22465324], [88.80119324, 22.22501183], [88.80076599, 22.22538948], [88.80056, 22.22584152], [88.80053711, 22.2262516], [88.80079651, 22.22656822], [88.80122375, 22.22673607], [88.80171967, 22.22675323], [88.80223846, 22.22664452], [88.80278015, 22.22654343], [88.80329132, 22.22664642], [88.80374908, 22.22678947], [88.80414581, 22.22691154], [88.80452728, 22.22699165], [88.80488586, 22.22709274], [88.80526733, 22.22717285], [88.8055954, 22.22714233], [88.80568695, 22.22714424], [88.80609894, 22.22715187], [88.80651093, 22.22719383], [88.80693054, 22.22721291], [88.80735016, 22.22723389], [88.80776978, 22.2272625], [88.80819702, 22.22731972], [88.80860138, 22.22723389], [88.809021, 22.22712135], [88.80943298, 22.22705269], [88.80987549, 22.22716522], [88.81034851, 22.22721863], [88.81082153, 22.22729111], [88.81125641, 22.22746086], [88.8117218, 22.22758865], [88.81215668, 22.22777176], [88.81259155, 22.22796059], [88.81302643, 22.22810173], [88.81343842, 22.22829247], [88.81385803, 22.22842979], [88.81427765, 22.22856331], [88.81471252, 22.22864342], [88.81515503, 22.22879982], [88.81561279, 22.22907066], [88.8161087, 22.22936058], [88.81661987, 22.22968292], [88.81716156, 22.22999191], [88.81768799, 22.23029137], [88.81816864, 22.23059654], [88.81855011, 22.23093987], [88.81884003, 22.23132133], [88.8191452, 22.23156548], [88.81942749, 22.23180962], [88.81967163, 22.23209763], [88.81987762, 22.23248291], [88.82009888, 22.23291588], [88.82034302, 22.23339462], [88.82064056, 22.23383522], [88.820961, 22.23429489], [88.82121277, 22.23479271], [88.82154083, 22.2352314], [88.82189178, 22.23566055], [88.82227325, 22.23611259], [88.82273865, 22.23646927], [88.82322693, 22.23684311], [88.82370758, 22.23718262], [88.82424164, 22.23747063], [88.82479095, 22.2376976], [88.82534027, 22.23787117], [88.82579041, 22.23818016], [88.82614136, 22.23854256], [88.82646942, 22.23889542], [88.82673645, 22.23924065], [88.82698059, 22.23962975], [88.8272171, 22.24000168], [88.82749939, 22.24027824], [88.82749939, 22.24055481], [88.82784271, 22.24090195], [88.82842255, 22.24190521], [88.82821655, 22.24322319], [88.82813263, 22.24380684], [88.82794952, 22.24446297], [88.82791901, 22.24522972], [88.82798004, 22.24601173], [88.82806396, 22.24672127], [88.82818604, 22.24732971], [88.82836914, 22.24782181], [88.82852936, 22.24823952], [88.82859802, 22.24863243], [88.82862854, 22.24901009], [88.8286972, 22.24936104], [88.82884216, 22.24971199], [88.82888794, 22.25015068], [88.82894135, 22.25068092], [88.82913971, 22.25127029], [88.8292923, 22.25193977], [88.829422, 22.2525425], [88.82949829, 22.25315666], [88.82956696, 22.25372124], [88.8295517, 22.25421906], [88.82952118, 22.25471306], [88.82946777, 22.25526237], [88.82944489, 22.25577164], [88.82942963, 22.25621223], [88.82939148, 22.25657845], [88.82933807, 22.25686264], [88.82930756, 22.25715065], [88.8292923, 22.25761223], [88.82923889, 22.25822258], [88.8291626, 22.25883293], [88.82898712, 22.25936127], [88.8290329, 22.25989342], [88.82894897, 22.26035881], [88.82885742, 22.26080513], [88.82870483, 22.26118851], [88.82860565, 22.26156425], [88.82849884, 22.26190186], [88.82834625, 22.26221275], [88.82824707, 22.26255226], [88.82807922, 22.2628727], [88.82800293, 22.26328087], [88.82783508, 22.26363945], [88.82777405, 22.26411438], [88.82771301, 22.2646122], [88.82751465, 22.26503372], [88.82730103, 22.26545143], [88.82704163, 22.26580238], [88.82675171, 22.26608658], [88.82642365, 22.26630211], [88.82598114, 22.26645088], [88.82541656, 22.26663017], [88.82478333, 22.26663017], [88.82417297, 22.26667023], [88.82332611, 22.26667023], [88.82305908, 22.26639175], [88.82277679, 22.26639175], [88.8216629, 22.26527977], [88.82055664, 22.26527977], [88.82027435, 22.26555824], [88.82027435, 22.2658329], [88.81999969, 22.26611137], [88.8208313, 22.26694107], [88.8208313, 22.26750183], [88.82055664, 22.2677784], [88.82055664, 22.26861191], [88.81999969, 22.26916695], [88.81999969, 22.26972008], [88.81944275, 22.27028084], [88.81916809, 22.27028084], [88.8188858, 22.27056313], [88.81804657, 22.27056313], [88.81694794, 22.27166939], [88.81664276, 22.27167892], [88.81667328, 22.27210045], [88.81667328, 22.27248955], [88.8167038, 22.27285767], [88.81681061, 22.27321053], [88.81691742, 22.27360725], [88.81694031, 22.27404213], [88.81694794, 22.27452278], [88.81694794, 22.27499962], [88.81694794, 22.27548027], [88.81694031, 22.2759552], [88.81691742, 22.27640915], [88.8168335, 22.27684593], [88.81668854, 22.27726173], [88.81658936, 22.27768135], [88.81647491, 22.27808952], [88.8164978, 22.27854156], [88.81651306, 22.27898979], [88.81642151, 22.27942085], [88.8163681, 22.27986145], [88.81626892, 22.28027153], [88.81613922, 22.2806797], [88.81606293, 22.28110313], [88.81590271, 22.28148079], [88.81581879, 22.28190041], [88.81572723, 22.28230286], [88.8155899, 22.28263283], [88.81545258, 22.28297234], [88.81520844, 22.28328514], [88.81484985, 22.28358269], [88.81437683, 22.28385925], [88.81380463, 22.28409386], [88.81326294, 22.28436279], [88.81259155, 22.28458977], [88.81183624, 22.28471947], [88.81105804, 22.28482819], [88.81027985, 22.28489113], [88.80951691, 22.28479958], [88.80879211, 22.28469276], [88.80810547, 22.28461456], [88.80753326, 22.28474808], [88.80710602, 22.2850399], [88.80680847, 22.28540993], [88.80652618, 22.28574944], [88.80638123, 22.28624153], [88.80623627, 22.28679085], [88.80607605, 22.28743935], [88.80589294, 22.28812981], [88.80584717, 22.2888813], [88.80587769, 22.28962135], [88.80577087, 22.29031944], [88.80558777, 22.29097557], [88.8054657, 22.29162216], [88.80527496, 22.29218483], [88.80523682, 22.29229164], [88.80509949, 22.29270744], [88.80506134, 22.29323006], [88.80519867, 22.29375267], [88.80513, 22.29421043], [88.80503082, 22.29466057], [88.80500031, 22.29514122], [88.80502319, 22.29560852], [88.80513, 22.29607201], [88.805336, 22.29652023], [88.80554962, 22.29695511], [88.80574799, 22.29742622], [88.80580902, 22.29763222], [88.80590057, 22.29792213], [88.80615234, 22.29840469], [88.80639648, 22.29897118], [88.80664063, 22.2995491], [88.80680847, 22.3001194], [88.80693817, 22.30052948], [88.80709839, 22.3008728], [88.80731201, 22.30124855], [88.80745697, 22.30173302], [88.80750275, 22.30227089], [88.80750275, 22.30281067], [88.80750275, 22.30336952], [88.80753326, 22.30397606], [88.80768585, 22.30463219], [88.80788422, 22.30534935], [88.80802917, 22.30606461], [88.80819702, 22.30672836], [88.80835724, 22.30732155], [88.80860901, 22.30783844], [88.80887604, 22.30833244], [88.80919647, 22.30877113], [88.80956268, 22.3091526], [88.80974579, 22.30961037], [88.81000519, 22.31002998], [88.81027222, 22.31045151], [88.81053925, 22.31088066], [88.81083679, 22.31139183], [88.81111145, 22.31166649], [88.81111145, 22.31221962], [88.81138611, 22.31250191], [88.81138611, 22.31278038], [88.81194305, 22.31333351], [88.81194305, 22.31361198], [88.81222534, 22.31388855], [88.81223297, 22.31583214], [88.81222534, 22.31591225], [88.81216431, 22.31648827], [88.8119812, 22.31703186], [88.81183624, 22.31762123], [88.81170654, 22.31823158], [88.8115387, 22.31873131], [88.81138611, 22.31916618], [88.8116684, 22.31944466], [88.8116684, 22.31972313], [88.81194305, 22.3200016], [88.81194305, 22.32055473], [88.81138611, 22.32111168], [88.81111145, 22.32111168], [88.81083679, 22.32139015], [88.8105545, 22.32139015], [88.8097229, 22.32222366], [88.80944061, 22.32222366], [88.8088913, 22.32278442], [88.80860901, 22.3227787], [88.80805206, 22.32333374], [88.80805206, 22.32361031], [88.8061142, 22.3255558], [88.80610657, 22.32583046], [88.80555725, 22.32639122], [88.80555725, 22.32666588], [88.80500031, 22.32722282], [88.80500031, 22.3275013], [88.80444336, 22.32805634], [88.80444336, 22.3283329], [88.8041687, 22.32861137], [88.8041687, 22.32957268], [88.8041687, 22.32972145], [88.80455017, 22.3300972], [88.80473328, 22.33028221], [88.80500031, 22.33028221], [88.80610657, 22.33139229], [88.8061142, 22.33166885], [88.80638885, 22.33194542], [88.80638885, 22.33222008], [88.80750275, 22.33332825], [88.80750275, 22.33361244], [88.8077774, 22.33389091], [88.8077774, 22.33472252], [88.80789948, 22.33485413], [88.80805206, 22.33502007], [88.80805206, 22.33555794], [88.80832672, 22.3358326], [88.80833435, 22.33638954], [88.8088913, 22.33694649], [88.8088913, 22.33722305], [88.80922699, 22.33756065], [88.8097229, 22.33805656], [88.8097229, 22.33833313], [88.80999756, 22.3386097], [88.80999756, 22.33889198], [88.81027985, 22.33917046], [88.81027985, 22.33944321], [88.81054688, 22.33971214], [88.81054688, 22.34000206], [88.81083679, 22.34028053], [88.81083679, 22.34055519], [88.81111145, 22.34082985], [88.81111145, 22.34111214], [88.81138611, 22.34139061], [88.81138611, 22.34194374], [88.8116684, 22.34222221], [88.8116684, 22.34278297], [88.81194305, 22.34306145], [88.81194305, 22.34389305], [88.81222534, 22.3441658], [88.81222534, 22.34480095], [88.81222534, 22.34583282], [88.8125, 22.3461113], [88.8125, 22.34666634], [88.81277466, 22.34694481], [88.81276703, 22.34721947], [88.81305695, 22.34750175], [88.81305695, 22.34805489], [88.8133316, 22.34833336], [88.8133316, 22.34861183], [88.81361389, 22.3488903], [88.81389618, 22.34887123], [88.8161087, 22.35111046], [88.8161087, 22.35139465], [88.81639099, 22.3516674], [88.81639099, 22.35194588], [88.81666565, 22.35222435], [88.81667328, 22.35250282], [88.81694794, 22.35277748], [88.81694794, 22.35333061], [88.8172226, 22.3536129], [88.8172226, 22.3544445], [88.81749725, 22.35472298], [88.81749725, 22.35670471], [88.81749725, 22.35749817], [88.81777954, 22.35778236], [88.81777954, 22.35805893], [88.8180542, 22.35833359], [88.81804657, 22.35860825], [88.81833649, 22.35889244], [88.81861115, 22.35889244], [88.8188858, 22.35917091], [88.8190918, 22.35917091], [88.81944275, 22.3591671], [88.81999969, 22.35972404], [88.8208313, 22.35972404], [88.82111359, 22.35944557], [88.82138824, 22.35944557], [88.8216629, 22.3591671], [88.82221985, 22.3591671], [88.82250214, 22.35944557], [88.8236084, 22.35944557], [88.82389069, 22.3591671], [88.82554626, 22.35917091], [88.82583618, 22.35889244], [88.82750702, 22.35889244], [88.82776642, 22.35860825], [88.82833099, 22.35861206], [88.82847595, 22.3587532], [88.82861328, 22.35889244], [88.82971954, 22.35889244], [88.83000183, 22.35860825], [88.83055878, 22.35861397], [88.83083344, 22.35833549], [88.83166504, 22.35833549], [88.83194733, 22.35805893], [88.83305359, 22.35805893], [88.83333588, 22.35833549], [88.83611298, 22.35833549], [88.83638763, 22.35861397], [88.83666992, 22.35860825], [88.83693695, 22.35889244], [88.83721924, 22.35889053], [88.83740234, 22.35907364], [88.83777618, 22.35944557], [88.83805847, 22.35944557], [88.83833313, 22.35972404], [88.83860779, 22.35971832], [88.83874512, 22.35986137], [88.83889008, 22.36000252], [88.8391571, 22.36000252], [88.83944702, 22.36027908], [88.84027863, 22.36027908], [88.84055328, 22.36055946], [88.84083557, 22.36055565], [88.84111023, 22.36083412], [88.84194183, 22.36082268], [88.84209442, 22.36098289], [88.84221649, 22.36111259], [88.84278107, 22.36111259], [88.84284973, 22.36117935], [88.84306335, 22.36139107], [88.84388733, 22.36139107], [88.84416962, 22.36166954], [88.84471893, 22.36166573], [88.84486389, 22.36180687], [88.84500122, 22.3619442], [88.84555817, 22.3619442], [88.84574127, 22.36213112], [88.84583282, 22.36222267], [88.84610748, 22.36222267], [88.84638977, 22.36250114], [88.84722137, 22.36250114], [88.84749603, 22.36277962], [88.84944153, 22.36277962], [88.84971619, 22.36306381], [88.84986115, 22.36291695], [88.84999847, 22.36277962], [88.85083008, 22.36277962], [88.85111237, 22.36250114], [88.85138702, 22.36250114], [88.85193634, 22.36194038], [88.85221863, 22.3619442], [88.85277557, 22.36139107], [88.85305786, 22.36139107], [88.85333252, 22.36111259], [88.85388947, 22.36111259], [88.85415649, 22.36082268], [88.85444641, 22.36083412], [88.85472107, 22.36055565], [88.85500336, 22.36055946], [88.85527802, 22.36027908], [88.85582733, 22.36027908], [88.85610962, 22.36000252], [88.85639191, 22.36000252], [88.85666656, 22.35971832], [88.85694122, 22.35972404], [88.85722351, 22.35944557], [88.85749817, 22.35972404], [88.85832977, 22.35972404], [88.85888672, 22.3591671], [88.85888672, 22.35860825], [88.85944366, 22.35805511], [88.85972595, 22.35805893], [88.86027527, 22.35861397], [88.86083221, 22.35861397], [88.8611145, 22.35833549], [88.86138916, 22.35833549], [88.86166382, 22.35805893], [88.86194611, 22.35807037], [88.86277771, 22.3572216], [88.86333466, 22.3572216], [88.86360931, 22.35694885], [88.86416626, 22.35695076], [88.86444092, 22.35667229], [88.86472321, 22.35667229], [88.86499786, 22.35695076], [88.86528015, 22.35694885], [88.86555481, 22.3572216], [88.86611176, 22.3572216], [88.86638641, 22.35749817], [88.86723328, 22.35749817], [88.86750031, 22.35778236], [88.86915588, 22.35778236], [88.8694458, 22.35807037], [88.86972046, 22.35807037], [88.87000275, 22.35778236], [88.87055206, 22.35778236], [88.87082672, 22.35749817], [88.87110901, 22.35749817], [88.87194824, 22.35667229], [88.8722229, 22.35667229], [88.87388611, 22.35500145], [88.8741684, 22.35500145], [88.87610626, 22.35305977], [88.87638855, 22.35305977], [88.87666321, 22.3527813], [88.87695313, 22.3527813], [88.87722015, 22.35250282], [88.87750244, 22.35250282], [88.8777771, 22.35222054], [88.87805176, 22.35222435], [88.87833405, 22.35194588], [88.8786087, 22.35194588], [88.87889099, 22.3516674], [88.87917328, 22.35167122], [88.8797226, 22.35111046], [88.87999725, 22.35111046], [88.88054657, 22.35056114], [88.88083649, 22.35056114], [88.88111115, 22.35028458], [88.88168335, 22.35028458], [88.88194275, 22.35000038], [88.88276672, 22.35000038], [88.88360596, 22.3491745], [88.88401031, 22.34909248], [88.88438416, 22.3488102], [88.88475037, 22.34844017], [88.88516998, 22.34807014], [88.88565063, 22.34769821], [88.88613892, 22.34726715], [88.8866806, 22.34682274], [88.88724518, 22.34637642], [88.88778687, 22.34589195], [88.88832855, 22.34544373], [88.88886261, 22.34504128], [88.88939667, 22.34472084], [88.88990784, 22.34443855], [88.89038849, 22.34412193], [88.89080048, 22.34373093], [88.89116669, 22.34334946], [88.89157104, 22.34308243], [88.89185333, 22.34266472], [88.89211273, 22.34215355], [88.89241791, 22.34162712], [88.89274597, 22.34108353], [88.89302063, 22.34047127], [88.89320374, 22.33986282], [88.89335632, 22.33941078], [88.89362335, 22.33903313], [88.89388275, 22.33863258], [88.89415741, 22.33818054], [88.89442444, 22.33771515], [88.89467621, 22.33727074], [88.89493561, 22.33687782], [88.89515686, 22.33648109], [88.89544678, 22.33613586], [88.89579773, 22.33581924], [88.8961792, 22.33550072], [88.89649963, 22.33505058], [88.89686584, 22.33467484], [88.89722443, 22.3342762], [88.8976059, 22.33389854], [88.89800262, 22.33354187], [88.89839172, 22.33318138], [88.89886475, 22.33289719], [88.89935303, 22.3325901], [88.89984131, 22.33218384], [88.9002533, 22.33168983], [88.90055084, 22.33115959], [88.90076447, 22.3306942], [88.9008255, 22.33026695], [88.90084076, 22.32991982], [88.90085602, 22.32962227], [88.90093231, 22.32935143], [88.90103912, 22.3290844], [88.90112305, 22.32876968], [88.90122986, 22.32842064], [88.90135193, 22.3280201], [88.90139008, 22.32756233], [88.90142822, 22.32712173], [88.90157318, 22.3267498], [88.9016571, 22.32636261], [88.9017334, 22.32596207], [88.90190125, 22.32558632], [88.90200806, 22.32514763], [88.90220642, 22.32478142], [88.90241241, 22.32442284], [88.90258026, 22.32409477], [88.90274811, 22.32380867], [88.90284729, 22.32344818], [88.90304565, 22.3230896], [88.90325165, 22.32268715], [88.90342712, 22.32225227], [88.90363312, 22.32182121], [88.90386963, 22.3214016], [88.90409088, 22.32094383], [88.90424347, 22.32038307], [88.90445709, 22.31985855], [88.90473938, 22.31936836], [88.90503693, 22.31890106], [88.9053421, 22.31839943], [88.90566254, 22.3179512], [88.90596771, 22.31754112], [88.90627289, 22.31716919], [88.90657043, 22.31678581], [88.90691376, 22.31640816], [88.90731812, 22.31604195], [88.9077301, 22.31567383], [88.90808105, 22.31522179], [88.9084549, 22.31479073], [88.90891266, 22.31441116], [88.90940094, 22.31397057], [88.90972137, 22.3133297], [88.91000366, 22.31333351], [88.91027832, 22.31305313], [88.91055298, 22.31306267], [88.91165924, 22.31195259], [88.91165924, 22.3116703], [88.91110992, 22.31110954], [88.91083527, 22.31111336], [88.91083527, 22.31083488], [88.91055298, 22.31055641], [88.91055298, 22.30917358], [88.9108429, 22.30888939], [88.91083527, 22.30861282], [88.91110992, 22.30833244], [88.91083527, 22.30805779], [88.9108429, 22.30750275], [88.91055298, 22.30722237], [88.91055298, 22.30639076], [88.91110992, 22.30582809], [88.91139221, 22.30583382], [88.91166687, 22.30555534], [88.91194153, 22.30583382], [88.91249847, 22.30583382], [88.91361237, 22.30694389], [88.91361237, 22.30722237], [88.91416931, 22.30777931], [88.91416931, 22.30833244], [88.91443634, 22.30861282], [88.91500092, 22.30861282], [88.9152832, 22.30833244], [88.91555786, 22.30833244], [88.91583252, 22.30944633], [88.91611481, 22.30944633], [88.91666412, 22.30888939], [88.91694641, 22.30888939], [88.91779327, 22.30806351], [88.91805267, 22.30806351], [88.91847229, 22.30776024], [88.91901398, 22.30742073], [88.91960907, 22.30706978], [88.92025757, 22.30677986], [88.92089844, 22.30648994], [88.92159271, 22.30627441], [88.92220306, 22.30593491], [88.92276001, 22.30558205], [88.92333984, 22.30533409], [88.92385101, 22.30514336], [88.92429352, 22.30496788], [88.92469025, 22.30478096], [88.92516327, 22.3047123], [88.92565155, 22.30461121], [88.92616272, 22.30443001], [88.92666626, 22.30417061], [88.92716217, 22.30389214], [88.92765045, 22.30360222], [88.92812347, 22.30338669], [88.9286499, 22.30333519], [88.92919922, 22.30333138], [88.92973328, 22.30328941], [88.93022919, 22.30313301], [88.93073273, 22.3030529], [88.93125153, 22.30303383], [88.93186951, 22.30303001], [88.93257904, 22.30301285], [88.93321228, 22.30291939], [88.93372345, 22.30278206], [88.93412781, 22.30265236], [88.93450165, 22.30244637], [88.93490601, 22.30214119], [88.93530273, 22.30174637], [88.93567657, 22.30135155], [88.93598938, 22.30094337], [88.93621826, 22.3005619], [88.936409, 22.30020523], [88.93660736, 22.29988289], [88.93675232, 22.29949188], [88.9369278, 22.29911232], [88.93707275, 22.2986927], [88.93721771, 22.29826164], [88.93734741, 22.29781151], [88.93746948, 22.297369], [88.93749237, 22.2968998], [88.93747711, 22.29645348], [88.93741608, 22.29601479], [88.93747711, 22.29556274], [88.9375, 22.29509163], [88.9375, 22.29461098], [88.9375, 22.29414177], [88.93747711, 22.29368019], [88.93739319, 22.29323006], [88.93724823, 22.29279137], [88.93722534, 22.29235268], [88.93721771, 22.29191589], [88.93717194, 22.29148674], [88.93698883, 22.29109764], [88.93694305, 22.29063225], [88.93688965, 22.29012108], [88.9367218, 22.28961182], [88.9366684, 22.28903961], [88.93665314, 22.28841972], [88.93654633, 22.28779984], [88.936409, 22.28717232], [88.93628693, 22.28653145], [88.9361496, 22.28590965], [88.93605804, 22.28531075], [88.93585205, 22.28480911], [88.93564606, 22.28427315], [88.93538666, 22.28373146], [88.93511963, 22.2831707], [88.93487549, 22.28260612], [88.93463135, 22.2820797], [88.93441772, 22.28152275], [88.93416595, 22.28103065], [88.93392181, 22.28057671], [88.93371582, 22.2800827], [88.93357849, 22.27946281], [88.9333725, 22.27882957], [88.93318939, 22.27819443], [88.93302917, 22.27762032], [88.93282318, 22.27713966], [88.93271637, 22.27665138], [88.93257904, 22.27621269], [88.93247986, 22.27578545], [88.93234253, 22.2753849], [88.93224335, 22.27497673], [88.93222046, 22.27456284], [88.93216705, 22.27417946], [88.93199158, 22.27386665], [88.9319458, 22.27351189], [88.9318924, 22.27311134], [88.93171692, 22.27270317], [88.93167114, 22.27219963], [88.93165588, 22.2716465], [88.93161774, 22.27108955], [88.93145752, 22.27060509], [88.93139648, 22.27017021], [88.93138885, 22.26972008], [88.93138123, 22.26926422], [88.93134308, 22.26880455], [88.93119812, 22.26839066], [88.93112183, 22.26794243], [88.93106079, 22.26745796], [88.93087769, 22.26696968], [88.93070221, 22.26643562], [88.93054199, 22.26590157], [88.93036652, 22.26534081], [88.93023682, 22.26477432], [88.93000793, 22.26423073], [88.92980957, 22.26365471], [88.92976379, 22.26301384], [88.92985535, 22.26233482], [88.92987061, 22.2616787], [88.92997742, 22.26124001], [88.93004608, 22.26083946], [88.93022156, 22.26046562], [88.93026733, 22.25997162], [88.930336, 22.25941277], [88.93054199, 22.25887108], [88.93073273, 22.25829887], [88.93091583, 22.25770187], [88.93118286, 22.25714684], [88.931427, 22.25663757], [88.93165588, 22.25623131], [88.93187714, 22.25586891], [88.93200684, 22.2555027], [88.93222046, 22.25522041], [88.93244171, 22.25489235], [88.93266296, 22.25447655], [88.93299866, 22.25407219], [88.93333435, 22.25362206], [88.93370819, 22.25321007], [88.93412781, 22.25283813], [88.93464661, 22.2525425], [88.93502045, 22.25225258], [88.93512726, 22.25213051], [88.93582916, 22.25139046], [88.93611145, 22.25139046], [88.93694305, 22.25056267], [88.93723297, 22.25056267], [88.93889618, 22.24889183], [88.93889618, 22.24860954], [88.9393158, 22.24844742], [88.93968201, 22.24812126], [88.94010925, 22.24782562], [88.94055939, 22.24761009], [88.94100189, 22.24744606], [88.94142914, 22.24727058], [88.94190979, 22.24722099], [88.94241333, 22.2471714], [88.94289398, 22.24699593], [88.94342804, 22.24695015], [88.94400024, 22.24693108], [88.94454956, 22.24687576], [88.9450531, 22.24670601], [88.94560242, 22.24663162], [88.94610596, 22.24649239], [88.94658661, 22.24633217], [88.94703674, 22.24615288], [88.9475708, 22.24608231], [88.94808197, 22.24593163], [88.94861603, 22.24575996], [88.94916534, 22.24552917], [88.949646, 22.2451458], [88.95000458, 22.24458122], [88.95033264, 22.24403381], [88.95068359, 22.24364662], [88.95095062, 22.24333191], [88.95114136, 22.24303627], [88.95134735, 22.24273109], [88.95146942, 22.24232292], [88.95162201, 22.24191284], [88.95166779, 22.24144173], [88.95166779, 22.240942], [88.95166779, 22.24041939], [88.95166779, 22.23990059], [88.95166779, 22.23940086], [88.9516983, 22.23890114], [88.95189667, 22.23843956], [88.95194244, 22.23793411], [88.95195007, 22.2373867], [88.95199585, 22.23681068], [88.95218658, 22.23626137], [88.9523468, 22.23569298], [88.95252228, 22.2351265], [88.95272064, 22.23460197], [88.95277405, 22.23407364], [88.95279694, 22.23359108], [88.95291901, 22.23320198], [88.95302582, 22.23286247], [88.95304871, 22.23252296], [88.95305634, 22.23217964], [88.95310974, 22.23185158], [88.95324707, 22.23155022], [88.95332336, 22.23121071], [88.95336151, 22.23085213], [88.95347595, 22.23053169], [88.95358276, 22.23018074], [88.95363617, 22.22977257], [88.95374298, 22.22936058], [88.95381927, 22.22895432], [88.95386505, 22.22853088], [88.9539032, 22.22810173], [88.95391846, 22.22766495], [88.9540329, 22.22721863], [88.95413971, 22.22671509], [88.95417023, 22.22619247], [88.95415497, 22.22569084], [88.95407867, 22.22524071], [88.95385742, 22.22493172], [88.95352936, 22.22472191], [88.95313263, 22.22455025], [88.95262909, 22.22443962], [88.95205688, 22.22434044], [88.95147705, 22.22441483], [88.95085907, 22.22443962], [88.95018768, 22.22442055], [88.94953156, 22.22431946], [88.94888306, 22.22421074], [88.94831848, 22.22423744], [88.94788361, 22.22440147], [88.94747162, 22.22443962], [88.94703674, 22.22444916], [88.94661713, 22.22444916], [88.94615936, 22.22443962], [88.94571686, 22.22444916], [88.94532013, 22.22447777], [88.94491577, 22.22459221], [88.94445038, 22.22470284], [88.94394684, 22.22471809], [88.94342041, 22.22472191], [88.94285583, 22.22474289], [88.942276, 22.22483253], [88.9417038, 22.22501183], [88.94112396, 22.22521019], [88.94048309, 22.22528267], [88.93987274, 22.22535706], [88.93934631, 22.22551155], [88.9388504, 22.22561073], [88.93841553, 22.22579765], [88.93791199, 22.22596169], [88.93733978, 22.22615242], [88.93672943, 22.22634315], [88.93608093, 22.22639275], [88.93547821, 22.22640038], [88.93494415, 22.22644615], [88.93447876, 22.22661018], [88.93396759, 22.22666931], [88.93341827, 22.2267189], [88.93286133, 22.22686195], [88.93222046, 22.22693634], [88.9315567, 22.22698021], [88.93096161, 22.22713089], [88.93044281, 22.22725105], [88.93002319, 22.22746086], [88.92959595, 22.22754097], [88.92919159, 22.22772026], [88.92871094, 22.22783089], [88.92825317, 22.2280407], [88.92778015, 22.22820282], [88.92732239, 22.22836113], [88.92688751, 22.22854042], [88.92645264, 22.22869492], [88.92607117, 22.22890472], [88.92572021, 22.22915077], [88.92536163, 22.22937965], [88.92494965, 22.22961617], [88.92449951, 22.22994041], [88.92398834, 22.23027992], [88.92344666, 22.23063087], [88.92295074, 22.23105049], [88.9223938, 22.23140144], [88.92188263, 22.23174095], [88.92144012, 22.23207474], [88.92108154, 22.23238754], [88.92070007, 22.23262978], [88.92016602, 22.23280907], [88.91960907, 22.23301506], [88.9189682, 22.23303223], [88.91874695, 22.23299408], [88.91831207, 22.23291588], [88.9176712, 22.23275185], [88.91710663, 22.23247147], [88.91668701, 22.23209953], [88.91638947, 22.23167992], [88.91615295, 22.23127174], [88.91597748, 22.23082733], [88.91586304, 22.2303524], [88.91583252, 22.22985268], [88.91584015, 22.22934723], [88.91589355, 22.22885895], [88.91599274, 22.22839165], [88.91609192, 22.22794151], [88.91616821, 22.22749138], [88.9162674, 22.22705269], [88.91638184, 22.22661018], [88.91648102, 22.22612953], [88.91655731, 22.2256031], [88.91658783, 22.22504234], [88.91644287, 22.22460175], [88.91635132, 22.22415924], [88.91616821, 22.22375298], [88.91606903, 22.2233181], [88.9158783, 22.22293282], [88.91571808, 22.22250748], [88.91552734, 22.22205353], [88.91533661, 22.22160149], [88.91523743, 22.22104073], [88.91503143, 22.22060585], [88.9147644, 22.22030067], [88.91448212, 22.22011185], [88.91417694, 22.21999168], [88.91387177, 22.21990395], [88.91352844, 22.21989059], [88.91307068, 22.21997261], [88.9126358, 22.22000313], [88.91223907, 22.22000313], [88.91182709, 22.21998024], [88.91137695, 22.22000313], [88.91085052, 22.22004509], [88.91030121, 22.22023582], [88.90966797, 22.2203331], [88.90910339, 22.22055244], [88.90853882, 22.22081375], [88.9079895, 22.22104073], [88.90744781, 22.22122192], [88.90698242, 22.2215023], [88.90641022, 22.22168922], [88.90589905, 22.22191048], [88.90542603, 22.22208977], [88.90500641, 22.2222805], [88.90458679, 22.22250748], [88.90415955, 22.22278023], [88.90370178, 22.22305489], [88.90323639, 22.22333336], [88.90276337, 22.22359276], [88.90223694, 22.22382164], [88.90177917, 22.22407532], [88.90135193, 22.22440147], [88.90091705, 22.22471428], [88.90045166, 22.22500038], [88.89996338, 22.22528267], [88.89946747, 22.22558212], [88.89898682, 22.22591019], [88.89853668, 22.22631264], [88.8980484, 22.2266407], [88.89754486, 22.22693634], [88.89702606, 22.22721863], [88.89653015, 22.22751999], [88.89604187, 22.22783089], [88.89552307, 22.22810173], [88.89504242, 22.22840118], [88.89459991, 22.22875023], [88.89417267, 22.2291317], [88.89367676, 22.22945213], [88.89315796, 22.22980309], [88.89265442, 22.23023605], [88.89212799, 22.23067284], [88.89160919, 22.23117065], [88.89107513, 22.23167229], [88.89054871, 22.23218346], [88.88999939, 22.23267365], [88.8894577, 22.23314095], [88.88896179, 22.23361015], [88.88848877, 22.23405075], [88.88817596, 22.2345047], [88.8879776, 22.23491096], [88.88780212, 22.2352314], [88.88764954, 22.23552132], [88.88747406, 22.23575783], [88.88726044, 22.23599434], [88.88704681, 22.23629951], [88.8868866, 22.23670769], [88.8866806, 22.23715401], [88.88650513, 22.23766136], [88.8864212, 22.23825264], [88.88639832, 22.23883247], [88.88639832, 22.23933411], [88.88640594, 22.23975945], [88.88646698, 22.24012756], [88.88661194, 22.24046516], [88.8867569, 22.24089622], [88.88698578, 22.24137306], [88.88729858, 22.24186134], [88.88764954, 22.24236107], [88.88802338, 22.24282265], [88.88835144, 22.24333191], [88.88871002, 22.24379921], [88.88910675, 22.24422264], [88.88947296, 22.24466133], [88.88982391, 22.24509621], [88.89015198, 22.24550056], [88.89051056, 22.24585533], [88.89084625, 22.24620819], [88.89118195, 22.24659157], [88.89155579, 22.24698257], [88.89195251, 22.2474308], [88.89235687, 22.24791527], [88.89274597, 22.24841118], [88.89311981, 22.24894142], [88.89348602, 22.24941063], [88.89386749, 22.24982262], [88.89421082, 22.25020027], [88.89451599, 22.25053215], [88.89480591, 22.2508297], [88.89505768, 22.25113106], [88.89523315, 22.25148964], [88.89533234, 22.25193977], [88.89547729, 22.25238991], [88.89544678, 22.25283623], [88.89528656, 22.25323296], [88.8951416, 22.25365257], [88.8950119, 22.25408936], [88.89486694, 22.25455284], [88.89465332, 22.2549305], [88.89433289, 22.25527191], [88.89395142, 22.25555038], [88.89353943, 22.25583267], [88.89309692, 22.25612068], [88.89265442, 22.25641632], [88.89218903, 22.25676155], [88.8916626, 22.2571125], [88.89115143, 22.25749016], [88.89071655, 22.25795174], [88.89048004, 22.25852013], [88.89027405, 22.25903511], [88.89007568, 22.2595005], [88.8899231, 22.25996017], [88.88973236, 22.26043129], [88.88956451, 22.26094437], [88.88947296, 22.26155281], [88.88938141, 22.26220131], [88.8891983, 22.2628231], [88.88905334, 22.26342964], [88.88884735, 22.26398277], [88.88860321, 22.2644825], [88.88832855, 22.26498985], [88.88800049, 22.26548195], [88.88761139, 22.26593208], [88.88712311, 22.26628685], [88.88655853, 22.26656151], [88.88593292, 22.26678276], [88.88523102, 22.26692963], [88.88454437, 22.26705933], [88.88387299, 22.26716042], [88.88321686, 22.2672596], [88.88265991, 22.26741982], [88.88210297, 22.26759148], [88.88162994, 22.26783943], [88.88123322, 22.26814461], [88.88090515, 22.26846504], [88.88066101, 22.26878166], [88.88047791, 22.26910973], [88.88031769, 22.26941109], [88.88018036, 22.2696991], [88.88004303, 22.26999283], [88.87992859, 22.27028847], [88.87976837, 22.27057076], [88.87967682, 22.27091026], [88.87954712, 22.27128029], [88.87937927, 22.27168083], [88.87917328, 22.27210045], [88.87896729, 22.27256966], [88.87877655, 22.27308083], [88.87848663, 22.27350044], [88.87812805, 22.27383995], [88.87773132, 22.27411842], [88.87728119, 22.27433014], [88.87677002, 22.27449226], [88.8762207, 22.27454948], [88.87567902, 22.27459908], [88.87516785, 22.27466011], [88.87465668, 22.27468681], [88.87415314, 22.2747345], [88.87380981, 22.27474403], [88.87364197, 22.27475166], [88.87312317, 22.27468109], [88.87261963, 22.27454948], [88.87211609, 22.27438164], [88.87162781, 22.27411079], [88.87107849, 22.27379036], [88.8706131, 22.27343178], [88.87011719, 22.27306938], [88.86965942, 22.27268028], [88.86920166, 22.27230263], [88.86876678, 22.27187157], [88.86831665, 22.27144051], [88.86785126, 22.27109337], [88.86736298, 22.27083206], [88.86682129, 22.27066612], [88.8662262, 22.27058983], [88.86563873, 22.27064514], [88.86509705, 22.27080917], [88.86463928, 22.27111244], [88.86425781, 22.27150536], [88.86398315, 22.27195358], [88.86380768, 22.27240944], [88.86371613, 22.27286911], [88.86370087, 22.27332687], [88.8637085, 22.27377129], [88.86370087, 22.2742157], [88.86370087, 22.27466011], [88.8636322, 22.27508926], [88.86355591, 22.27551079], [88.86341095, 22.27594757], [88.86315155, 22.27639961], [88.86276245, 22.27682304], [88.86226654, 22.27713966], [88.86173248, 22.27742195], [88.86115265, 22.27763748], [88.86057281, 22.27781105], [88.86000824, 22.27798271], [88.85943604, 22.27816582], [88.85883331, 22.27837944], [88.85822296, 22.27864456], [88.8576889, 22.2789669], [88.8572998, 22.27934074], [88.85701752, 22.27971077], [88.85682678, 22.28005028], [88.85668182, 22.28035164], [88.85656738, 22.28066063], [88.85643768, 22.28096008], [88.85624695, 22.28123856], [88.85601807, 22.28149986], [88.85573578, 22.28175163], [88.85540009, 22.28198051], [88.8549881, 22.28215981], [88.85456848, 22.28231239], [88.85417175, 22.28247261], [88.85381317, 22.28265381], [88.85344696, 22.28288078], [88.85309601, 22.28318024], [88.85277557, 22.28359222], [88.85247803, 22.28401184], [88.85221863, 22.28440285], [88.85202026, 22.28473854], [88.85189056, 22.2850647], [88.85177612, 22.2853775], [88.85164642, 22.28567123], [88.85153198, 22.28599739], [88.85138702, 22.28634071], [88.85122681, 22.28674126], [88.85103607, 22.28715324], [88.85082245, 22.28765297], [88.85058594, 22.28824043], [88.85037231, 22.28884315], [88.84996796, 22.28930855], [88.84947968, 22.28962135], [88.84893036, 22.28982735], [88.84829712, 22.28993034], [88.84764862, 22.29002953], [88.84694672, 22.29008293], [88.84626007, 22.29012108], [88.84610748, 22.2902813], [88.84416962, 22.2902813], [88.84388733, 22.29000282], [88.84361267, 22.29000282], [88.84333038, 22.28972054], [88.84361267, 22.28944397], [88.84388733, 22.28944778], [88.84416962, 22.2891655], [88.84444427, 22.2891655], [88.84471893, 22.28944778], [88.84557343, 22.28934669], [88.84632111, 22.28931808], [88.8470459, 22.28928947], [88.84771729, 22.28923225], [88.8483429, 22.28910255], [88.84889221, 22.28889275], [88.84934998, 22.28858948], [88.84970856, 22.2881794], [88.84996033, 22.28774071], [88.85009003, 22.28729057], [88.85015106, 22.28692627], [88.8502121, 22.28658295], [88.85031891, 22.28624153], [88.85044861, 22.28587532], [88.85060883, 22.28551292], [88.85076904, 22.28517914], [88.85092163, 22.28487206], [88.85105133, 22.28458214], [88.85116577, 22.28429031], [88.85129547, 22.28396034], [88.85148621, 22.28358841], [88.85172272, 22.28320122], [88.85202026, 22.28288269], [88.85238647, 22.28263283], [88.85279083, 22.28242111], [88.85325623, 22.28220558], [88.85372162, 22.28201294], [88.85415649, 22.28179932], [88.85456848, 22.28154373], [88.85494232, 22.28123283], [88.85529327, 22.28089905], [88.85556793, 22.2805481], [88.8557663, 22.28014946], [88.85597229, 22.27971077], [88.8562088, 22.27926254], [88.85652161, 22.27883339], [88.85691833, 22.2784214], [88.85735321, 22.27802849], [88.85780334, 22.27768135], [88.85825348, 22.27743912], [88.85869598, 22.27730942], [88.85912323, 22.27722931], [88.85955811, 22.27715111], [88.86009979, 22.27712059], [88.86068726, 22.27703285], [88.86128235, 22.27686119], [88.86181641, 22.27663994], [88.86225891, 22.27636909], [88.86254883, 22.27602959], [88.86270905, 22.27557945], [88.86275482, 22.27507782], [88.86274719, 22.27456284], [88.86271667, 22.27403069], [88.86271667, 22.27349281], [88.86276245, 22.27296257], [88.86284637, 22.27243996], [88.86303711, 22.27197075], [88.86332703, 22.27156067], [88.86367798, 22.27116966], [88.86408234, 22.27078438], [88.86447144, 22.2704258], [88.86486053, 22.27015114], [88.86530304, 22.26994133], [88.86582947, 22.26981544], [88.8664093, 22.2697506], [88.86696625, 22.2697506], [88.8674469, 22.26986122], [88.86788177, 22.27006531], [88.8682785, 22.27040291], [88.8686676, 22.27080917], [88.86909485, 22.27121735], [88.86954498, 22.27158356], [88.87003326, 22.27188492], [88.87050629, 22.27217293], [88.87101746, 22.27246284], [88.87149048, 22.27275276], [88.87192535, 22.27301598], [88.87233734, 22.27325249], [88.8727417, 22.27346992], [88.87313843, 22.27362251], [88.87354279, 22.27370262], [88.8739624, 22.27373123], [88.87438202, 22.27373123], [88.87481689, 22.27373123], [88.87528229, 22.27373123], [88.87571716, 22.27373123], [88.8761673, 22.27367973], [88.87665558, 22.27355003], [88.87711334, 22.27326012], [88.8775177, 22.27280807], [88.87785339, 22.27225304], [88.87814331, 22.27165031], [88.87839508, 22.27109528], [88.87861633, 22.2705822], [88.87882233, 22.27011299], [88.87896729, 22.26971245], [88.87911224, 22.26934242], [88.87928009, 22.2689724], [88.8794632, 22.26857948], [88.87970734, 22.26820946], [88.88005066, 22.26786232], [88.88040924, 22.26753044], [88.88080597, 22.2672596], [88.88117218, 22.26702118], [88.88153076, 22.26682281], [88.88185883, 22.26663017], [88.88219452, 22.26646233], [88.88259125, 22.26631927], [88.88304138, 22.26621056], [88.88353729, 22.26611137], [88.88405609, 22.26598167], [88.88459015, 22.2659111], [88.88511658, 22.26587677], [88.88564301, 22.2658329], [88.88614655, 22.2657299], [88.88657379, 22.26554489], [88.88693237, 22.26527214], [88.88723755, 22.26490974], [88.88749695, 22.26445007], [88.88771057, 22.26389122], [88.88786316, 22.26326752], [88.88799286, 22.26266289], [88.88804626, 22.26206017], [88.88809204, 22.26149178], [88.88820648, 22.26095772], [88.88831329, 22.26041985], [88.8884201, 22.25985146], [88.88858795, 22.25928116], [88.8887558, 22.25871086], [88.88900757, 22.2582283], [88.88929749, 22.25782013], [88.88962555, 22.25746918], [88.88994598, 22.25710106], [88.89025879, 22.25667953], [88.89057922, 22.25621986], [88.89095306, 22.25576973], [88.8914566, 22.2553997], [88.89203644, 22.25513458], [88.89258575, 22.25484657], [88.893013, 22.25440025], [88.89333344, 22.25388908], [88.89305878, 22.25361061], [88.89332581, 22.25333023], [88.89333344, 22.25194359], [88.89343262, 22.2515316], [88.8932724, 22.25104713], [88.89293671, 22.25061226], [88.89251709, 22.2501812], [88.89208221, 22.24969482], [88.89163208, 22.24913216], [88.89112091, 22.24859428], [88.89061737, 22.24804878], [88.89013672, 22.24749184], [88.88970184, 22.24695396], [88.8892746, 22.24650192], [88.88889313, 22.24611092], [88.8885498, 22.2457428], [88.88828278, 22.24534225], [88.88801575, 22.24495125], [88.88772583, 22.24454308], [88.88742828, 22.24415016], [88.88713074, 22.24374008], [88.88691711, 22.24327469], [88.88667297, 22.24282837], [88.88639832, 22.24242592], [88.88613892, 22.24203491], [88.8859024, 22.24162102], [88.88564301, 22.24120522], [88.88545227, 22.24071312], [88.88532257, 22.24012756], [88.88523102, 22.23949242], [88.88514709, 22.2388401], [88.88522339, 22.23816109], [88.88529968, 22.2374649], [88.88543701, 22.23679161], [88.88565826, 22.23621368], [88.88594055, 22.23572159], [88.88622284, 22.23526192], [88.88646698, 22.23480415], [88.88674164, 22.23437691], [88.8870163, 22.23397827], [88.88733673, 22.2336216], [88.88767242, 22.23326874], [88.88799286, 22.23286819], [88.88835907, 22.23244286], [88.88877106, 22.23195076], [88.88922882, 22.23143959], [88.88972473, 22.23098564], [88.89021301, 22.23058128], [88.89069366, 22.23023605], [88.89111328, 22.22986031], [88.89154816, 22.22947121], [88.89203644, 22.22907066], [88.89254761, 22.22864532], [88.89306641, 22.22821236], [88.89361572, 22.2277813], [88.89416504, 22.22737694], [88.89472198, 22.22701073], [88.89525604, 22.22668266], [88.89576721, 22.22639275], [88.89621735, 22.22610855], [88.89663696, 22.22583008], [88.89700317, 22.22554207], [88.8973465, 22.22520828], [88.89772034, 22.22487831], [88.89816284, 22.22455025], [88.89874268, 22.22426033], [88.89923859, 22.22379494], [88.89974976, 22.22328758], [88.90033722, 22.22285271], [88.90101624, 22.22250748], [88.90170288, 22.2221508], [88.90231323, 22.22172928], [88.90294647, 22.22140312], [88.90357971, 22.22113228], [88.90415192, 22.22084618], [88.90470123, 22.22055244], [88.90523529, 22.22027206], [88.9057312, 22.22000694], [88.90619659, 22.21978951], [88.90666962, 22.21969032], [88.90709686, 22.21953011], [88.9076004, 22.21943283], [88.9080658, 22.21928024], [88.90853882, 22.21916008], [88.90898895, 22.21897316], [88.90949249, 22.21884918], [88.90995026, 22.21865273], [88.9105072, 22.21852112], [88.91107178, 22.21839523], [88.91155243, 22.21814156], [88.9119339, 22.21782875], [88.91234589, 22.21763039], [88.91275024, 22.21742058], [88.91313171, 22.21714973], [88.91343689, 22.21682739], [88.91368103, 22.21643829], [88.91388702, 22.21610832], [88.91398621, 22.21577454], [88.91398621, 22.21541023], [88.91391754, 22.21503258], [88.91389465, 22.21466446], [88.91388702, 22.21430779], [88.91387939, 22.21395302], [88.91383362, 22.21358871], [88.91374969, 22.21318817], [88.91364288, 22.21273232], [88.91361237, 22.21222496], [88.91358948, 22.21172142], [88.91348267, 22.21129036], [88.9133606, 22.21088219], [88.91330719, 22.2104435], [88.91319275, 22.21002007], [88.91306305, 22.20959854], [88.91291046, 22.20916176], [88.91273499, 22.20871925], [88.91249847, 22.20829964], [88.91221619, 22.20788193], [88.91195679, 22.20745468], [88.91170502, 22.20699883], [88.91140747, 22.20655823], [88.91111755, 22.20609283], [88.91081238, 22.20560074], [88.91043854, 22.20510292], [88.90991211, 22.20467949], [88.9094162, 22.20416069], [88.90886688, 22.20364952], [88.90827942, 22.2031498], [88.90769958, 22.20264244], [88.90717316, 22.20206261], [88.90661621, 22.20156288], [88.90614319, 22.20112038], [88.90576172, 22.20072937], [88.90554047, 22.20034218], [88.90534973, 22.20004082], [88.90525055, 22.19970131], [88.90509033, 22.19938087], [88.904953, 22.19900894], [88.90476227, 22.1986084], [88.90457153, 22.19817162], [88.90445709, 22.19770813], [88.90448761, 22.19724274], [88.90466309, 22.19676018], [88.90479279, 22.19621277], [88.90500641, 22.19566154], [88.90522766, 22.19506264], [88.90532684, 22.19439125], [88.90554047, 22.19384384], [88.90577698, 22.19334221], [88.90600586, 22.19288063], [88.90625763, 22.19246483], [88.90647888, 22.19202995], [88.9067688, 22.19168282], [88.90710449, 22.19137192], [88.90742493, 22.19103432], [88.90769958, 22.1906414], [88.90805054, 22.19029045], [88.90843964, 22.18999481], [88.90880585, 22.18968773], [88.90914917, 22.18934059], [88.90947723, 22.18897247], [88.90984344, 22.1886158], [88.91021729, 22.18826294], [88.91054535, 22.18788147], [88.91083527, 22.18751717], [88.91113281, 22.18721008], [88.91138458, 22.18691635], [88.91160583, 22.18660164], [88.9118042, 22.1862545], [88.91201019, 22.1859417], [88.91230774, 22.18571281], [88.91262054, 22.18549156], [88.91285706, 22.18514061], [88.91311646, 22.18477631], [88.91345978, 22.18444252], [88.91382599, 22.18410301], [88.91417694, 22.1837101], [88.9145813, 22.18333054], [88.91499329, 22.18295288], [88.91539001, 22.18256187], [88.91583252, 22.18219948], [88.91621399, 22.18179512], [88.9165802, 22.18139076], [88.91694641, 22.18098831], [88.91732788, 22.18061256], [88.9177475, 22.18027687], [88.91808319, 22.17984962], [88.9184494, 22.1794529], [88.91880798, 22.17905807], [88.91915894, 22.17868233], [88.91947937, 22.17828178], [88.91973114, 22.17782402], [88.91999054, 22.17738152], [88.92022705, 22.17694473], [88.92047119, 22.17651176], [88.92072296, 22.17609215], [88.92092896, 22.17565536], [88.92114258, 22.17519188], [88.92134094, 22.1746769], [88.92138672, 22.1740303], [88.92136383, 22.17332649], [88.92124939, 22.17262077], [88.9210968, 22.17196274], [88.92092896, 22.17136192], [88.92082977, 22.17077065], [88.92080688, 22.17020226], [88.92077637, 22.1696682], [88.92059326, 22.1692028], [88.92045593, 22.16873932], [88.92034149, 22.16828918], [88.92022705, 22.16785812], [88.92005157, 22.1674881], [88.91996002, 22.16707039], [88.9197998, 22.16671371], [88.9196701, 22.16631126], [88.91943359, 22.16596222], [88.9190979, 22.16562843], [88.91860962, 22.16534996], [88.91792297, 22.16529274], [88.91757965, 22.16527939], [88.91725922, 22.16531944], [88.91689301, 22.16551018], [88.91641235, 22.16558266], [88.91593933, 22.16571808], [88.91546631, 22.16583824], [88.91501617, 22.16597176], [88.91458893, 22.16612625], [88.91422272, 22.16632271], [88.91381836, 22.1664753], [88.91343689, 22.16666222], [88.91301727, 22.16684151], [88.91256714, 22.16703224], [88.91216278, 22.16727448], [88.91175079, 22.16752052], [88.91137695, 22.16784096], [88.91098022, 22.16817474], [88.91044617, 22.16847038], [88.90994263, 22.1688385], [88.90943146, 22.1692028], [88.90901184, 22.16961288], [88.90866852, 22.17004967], [88.90838623, 22.17050552], [88.90809631, 22.17093277], [88.9078598, 22.17140007], [88.90758514, 22.17183685], [88.90721893, 22.17221832], [88.90685272, 22.17259026], [88.90654755, 22.17292976], [88.90633392, 22.17334938], [88.90602875, 22.1736927], [88.90569305, 22.1740303], [88.90535736, 22.17435837], [88.9050293, 22.17464256], [88.90473175, 22.17498207], [88.90441895, 22.17530823], [88.90408325, 22.1756115], [88.90364838, 22.1758709], [88.90325165, 22.17612267], [88.90287781, 22.17638969], [88.90249634, 22.17664528], [88.90207672, 22.17681313], [88.90161133, 22.1769619], [88.90116882, 22.17714882], [88.9006424, 22.17726135], [88.90013885, 22.17746162], [88.89958954, 22.17762947], [88.89894104, 22.17778206], [88.89822388, 22.17790794], [88.89746094, 22.17799187], [88.896698, 22.17784309], [88.89595032, 22.17773819], [88.89527893, 22.17754745], [88.8946228, 22.17745018], [88.89411163, 22.17724228], [88.89361572, 22.1770649], [88.89313507, 22.17687225], [88.89268494, 22.17658234], [88.89216614, 22.17628288], [88.89157867, 22.1760006], [88.8910675, 22.17559242], [88.89055634, 22.17517281], [88.8900528, 22.17477989], [88.88957977, 22.17440224], [88.8891983, 22.17397118], [88.88889313, 22.17352104], [88.88861084, 22.1731205], [88.88835144, 22.17276192], [88.8881073, 22.17242241], [88.88793945, 22.17202187], [88.88776398, 22.17157173], [88.88755798, 22.17114449], [88.88742828, 22.17069435], [88.88724518, 22.17030525], [88.88712311, 22.16991997], [88.88697052, 22.1695118], [88.88687897, 22.1690731], [88.88669586, 22.16867256], [88.88658142, 22.16828346], [88.88637543, 22.16797638], [88.88609314, 22.16771889], [88.88575745, 22.1675396], [88.88537598, 22.16753006], [88.88500214, 22.16767502], [88.88463593, 22.16785812], [88.88424683, 22.16806221], [88.88381958, 22.1682415], [88.88336182, 22.1683712], [88.8829422, 22.16859245], [88.88250732, 22.16875267], [88.88208771, 22.16891289], [88.88169861, 22.1690979], [88.8812561, 22.16917992], [88.88083649, 22.16930962], [88.88043213, 22.16943932], [88.87999725, 22.16956139], [88.87956238, 22.16969109], [88.87903595, 22.16974068], [88.87850189, 22.16983986], [88.87795258, 22.16996956], [88.87734985, 22.16999817], [88.87713623, 22.16998672], [88.87670898, 22.1699543], [88.87606812, 22.1697731], [88.87542725, 22.16979027], [88.87480164, 22.16997337], [88.87419128, 22.1701107], [88.87364197, 22.17028809], [88.87317657, 22.17051125], [88.8727951, 22.17075729], [88.87251282, 22.17105293], [88.87226868, 22.17136955], [88.87213898, 22.17176247], [88.87200928, 22.17214012], [88.87190247, 22.17247963], [88.87180328, 22.17279053], [88.87168121, 22.17310143], [88.87158203, 22.17345238], [88.87145233, 22.17385101], [88.87135315, 22.17435265], [88.8711319, 22.17490959], [88.87097168, 22.17559242], [88.87081909, 22.17625237], [88.87063599, 22.17688179], [88.87052155, 22.17749977], [88.87032318, 22.17803192], [88.87018585, 22.17854118], [88.87001038, 22.17899132], [88.86987305, 22.17943764], [88.86974335, 22.17987251], [88.86968231, 22.1803093], [88.86952209, 22.18067551], [88.86940765, 22.18110085], [88.86920166, 22.18150711], [88.86902618, 22.18195152], [88.8688736, 22.1824131], [88.86869049, 22.18283272], [88.8685379, 22.18325615], [88.86834717, 22.1836319], [88.86819458, 22.18404007], [88.86804962, 22.18448067], [88.86788177, 22.18492317], [88.86776733, 22.18532944], [88.86760712, 22.18573189], [88.86750793, 22.18617058], [88.86739349, 22.18661308], [88.86721802, 22.18703461], [88.86701202, 22.18745232], [88.86682892, 22.1878109], [88.86667633, 22.18824196], [88.86651611, 22.18876076], [88.8664093, 22.18936157], [88.86638641, 22.1900425], [88.86638641, 22.19070244], [88.86638641, 22.19131279], [88.86637115, 22.19185257], [88.86627197, 22.19236946], [88.86621094, 22.19291115], [88.86612701, 22.19350243], [88.86618042, 22.19414711], [88.86638641, 22.19483185], [88.86665344, 22.19550514], [88.86707306, 22.19604301], [88.86756134, 22.19645119], [88.86805725, 22.19681931], [88.86855316, 22.1971302], [88.86907959, 22.19732857], [88.86965179, 22.19745255], [88.87021637, 22.19746971], [88.87169647, 22.19746971], [88.87277222, 22.19733238], [88.87314606, 22.19745255], [88.87355042, 22.19748688], [88.87399292, 22.1974926], [88.87444305, 22.19751167], [88.87493134, 22.19753075], [88.87541962, 22.19749832], [88.87592316, 22.19748116], [88.87640381, 22.19752693], [88.87690735, 22.19753456], [88.87745667, 22.19759369], [88.87801361, 22.19771767], [88.87857819, 22.19783211], [88.87910461, 22.19800758], [88.8796463, 22.19815445], [88.8801651, 22.19833565], [88.88063812, 22.19852257], [88.88111877, 22.1986599], [88.88152313, 22.19889069], [88.88194275, 22.19914055], [88.88243866, 22.19938087], [88.88295746, 22.19965553], [88.88343811, 22.20005226], [88.88388062, 22.20055008], [88.8842926, 22.20105553], [88.88467407, 22.20149422], [88.88495636, 22.20187187], [88.88513947, 22.20222282], [88.88526917, 22.20253181], [88.88536835, 22.20285225], [88.88551331, 22.20321846], [88.88565063, 22.20365334], [88.885849, 22.2040844], [88.8860321, 22.20454979], [88.8860321, 22.20510292], [88.8860321, 22.2056694], [88.88607788, 22.20624733], [88.88608551, 22.20682335], [88.88604736, 22.20737267], [88.88591766, 22.20785522], [88.88578796, 22.20833015], [88.88561249, 22.20878029], [88.88549042, 22.20926094], [88.8853302, 22.20971107], [88.88522339, 22.2101593], [88.88504028, 22.21056938], [88.88485718, 22.21098137], [88.88459015, 22.21133804], [88.88424683, 22.21166039], [88.88389587, 22.21198082], [88.88350677, 22.21227074], [88.88308716, 22.21250153], [88.88265228, 22.21270943], [88.882164, 22.21289635], [88.88166809, 22.21307373], [88.88117218, 22.21323967], [88.88066101, 22.21331978], [88.88011932, 22.21339226], [88.87957764, 22.2135601], [88.87902069, 22.21371841], [88.87873077, 22.21375656], [88.87844086, 22.2137928], [88.87784576, 22.21378517], [88.87718201, 22.21371651], [88.87641907, 22.21375084], [88.87567902, 22.21364021], [88.87497711, 22.21352959], [88.8743515, 22.21339607], [88.87378693, 22.21331978], [88.87329865, 22.21323967], [88.87287903, 22.21310806], [88.87245941, 22.21302986], [88.87203217, 22.2129364], [88.87159729, 22.21281242], [88.87117767, 22.21270943], [88.8707962, 22.21254158], [88.87039185, 22.21241951], [88.87000275, 22.21227074], [88.86959076, 22.21217346], [88.8691864, 22.21203041], [88.86875153, 22.21194839], [88.86830902, 22.21186256], [88.86786652, 22.21170235], [88.86736298, 22.2115612], [88.8667984, 22.21145058], [88.86619568, 22.21139526], [88.86559296, 22.21135139], [88.86501312, 22.21125221], [88.86443329, 22.21115494], [88.8638382, 22.21110344], [88.8632431, 22.21104622], [88.86268616, 22.21095848], [88.8621521, 22.21099281], [88.86165619, 22.21092796], [88.8611908, 22.21099663], [88.86066437, 22.21105385], [88.8600769, 22.21103477], [88.85948181, 22.21093559], [88.85889435, 22.21086121], [88.85832214, 22.21089363], [88.85777283, 22.21101952], [88.85718536, 22.21106911], [88.85662079, 22.21108246], [88.85605621, 22.21109962], [88.85544586, 22.21115494], [88.85476685, 22.21112251], [88.85402679, 22.21115494], [88.85325623, 22.21121025], [88.8524704, 22.2113018], [88.85166931, 22.21128464], [88.85090637, 22.21136284], [88.85012817, 22.21138954], [88.84932709, 22.21139908], [88.84851837, 22.2114315], [88.84772491, 22.21154785], [88.84697723, 22.21166039], [88.84623718, 22.21177864], [88.84548187, 22.21191216], [88.84474945, 22.21202278], [88.84410858, 22.21218491], [88.84351349, 22.2123394], [88.84300232, 22.21255302], [88.84254456, 22.21280479], [88.84208679, 22.21307945], [88.84165955, 22.21339226], [88.84129333, 22.21378136], [88.84101105, 22.21426392], [88.84082794, 22.21480751], [88.84069824, 22.21536064], [88.84070587, 22.21595955], [88.84080505, 22.21648979], [88.84088135, 22.21696663], [88.84098053, 22.2173748], [88.84113312, 22.21772194], [88.84130096, 22.21810722], [88.84146118, 22.21854591], [88.84168243, 22.21898079], [88.84194946, 22.21941185], [88.8422699, 22.21977043], [88.8425827, 22.22011757], [88.84286499, 22.2204895], [88.84314728, 22.22084236], [88.84343719, 22.22120094], [88.84375763, 22.22154045], [88.84409332, 22.22187805], [88.84444427, 22.22221947], [88.84480286, 22.22255135], [88.84516144, 22.22285271], [88.84549713, 22.22315598], [88.84578705, 22.22347069], [88.84607697, 22.22380257], [88.84636688, 22.22414207], [88.8466568, 22.22450066], [88.84696198, 22.22486305], [88.84729767, 22.22519112], [88.84767914, 22.22549248], [88.84804535, 22.22582817], [88.84840393, 22.22618675], [88.84874725, 22.22654533], [88.84907532, 22.2269001], [88.84942627, 22.22721863], [88.84976196, 22.22758293], [88.85005188, 22.22798157], [88.85037231, 22.22837257], [88.85073853, 22.22870064], [88.85111237, 22.22906303], [88.85150909, 22.22941017], [88.85193634, 22.22976112], [88.85235596, 22.2301693], [88.85273743, 22.23065948], [88.85311127, 22.23119164], [88.85350037, 22.23175812], [88.85395813, 22.23231316], [88.85440063, 22.23289108], [88.85473633, 22.23356056], [88.85502625, 22.23423195], [88.85535431, 22.23481178], [88.85570526, 22.23526955], [88.85604095, 22.23566055], [88.85633087, 22.23604965], [88.85653687, 22.23645973], [88.85670471, 22.23689079], [88.8568573, 22.23730278], [88.85697174, 22.2377224], [88.85710144, 22.23813057], [88.8572998, 22.23846817], [88.85745239, 22.23890114], [88.85758209, 22.23940086], [88.85777283, 22.2399292], [88.85793304, 22.2404995], [88.85801697, 22.24110603], [88.85809326, 22.24173164], [88.85824585, 22.24236107], [88.8585434, 22.24298859], [88.85894775, 22.2435894], [88.85945129, 22.24414635], [88.86001587, 22.24464226], [88.86061096, 22.24505043], [88.86125946, 22.24538231], [88.86193085, 22.24561119], [88.86256409, 22.24577141], [88.86317444, 22.24597168], [88.86377716, 22.24620819], [88.86435699, 22.2464695], [88.86493683, 22.24671173], [88.86553192, 22.24693108], [88.86611938, 22.24712372], [88.86666107, 22.24735069], [88.86714935, 22.2475872], [88.86763763, 22.24781036], [88.86811829, 22.24802017], [88.86852264, 22.24828148], [88.86889648, 22.24854088], [88.86930847, 22.24877739], [88.86976624, 22.24897194], [88.87023163, 22.2491703], [88.87071228, 22.24934959], [88.87117767, 22.24955368], [88.87164307, 22.24979019], [88.87207031, 22.25006294], [88.87246704, 22.2503376], [88.87287903, 22.25059319], [88.87329102, 22.25085258], [88.873703, 22.25111198], [88.87413025, 22.25135994], [88.87456512, 22.25159645], [88.87503052, 22.25180817], [88.87548828, 22.25206947], [88.87587738, 22.25235748], [88.87604523, 22.25264931], [88.87583923, 22.2528038], [88.87541962, 22.25279427], [88.87496948, 22.25264549], [88.87452698, 22.2524395], [88.87412262, 22.25220299], [88.87365723, 22.25198364], [88.87314606, 22.25175285], [88.872612, 22.25149727], [88.8720932, 22.25123024], [88.87158966, 22.25097847], [88.87110901, 22.25072289], [88.87063599, 22.25041008], [88.87012482, 22.25012016], [88.86959839, 22.24983025], [88.8690567, 22.2495327], [88.86853027, 22.24923134], [88.86799622, 22.24889183], [88.86740875, 22.24858665], [88.86676788, 22.24833107], [88.86617279, 22.24808311], [88.86561584, 22.24785042], [88.86509705, 22.24757957], [88.86464691, 22.24734306], [88.86422729, 22.24715996], [88.86380005, 22.24701118], [88.86334991, 22.24683952], [88.86290741, 22.24666405], [88.86247253, 22.24652481], [88.8620224, 22.24641228], [88.86152649, 22.24623108], [88.86096191, 22.24596977], [88.86035156, 22.24569321], [88.85978699, 22.24542618], [88.85926819, 22.24513054], [88.85877228, 22.24481392], [88.85835266, 22.24444389], [88.85801697, 22.24408531], [88.85774994, 22.24372864], [88.85752869, 22.24345016], [88.85736084, 22.24319267], [88.85719299, 22.24287987], [88.85703278, 22.24253273], [88.85691071, 22.2420826], [88.85675812, 22.24157143], [88.85663605, 22.24097252], [88.85663605, 22.24035263], [88.85656738, 22.23983955], [88.8564682, 22.23944092], [88.85634613, 22.23913002], [88.85621643, 22.23888588], [88.85611725, 22.23861122], [88.85600281, 22.23835182], [88.85588837, 22.23800278], [88.85573578, 22.23765182], [88.85555267, 22.23727226], [88.85530853, 22.23690033], [88.85509491, 22.23654175], [88.85480499, 22.23623848], [88.85452271, 22.23600006], [88.85423279, 22.23593712], [88.85401917, 22.23579979], [88.85387421, 22.23566818], [88.85386658, 22.23513222], [88.85377502, 22.23435783], [88.85353088, 22.23384857], [88.85314178, 22.23339462], [88.8527298, 22.23285866], [88.85228729, 22.23233223], [88.85189056, 22.23181343], [88.85147095, 22.23135185], [88.85105133, 22.23090935], [88.85061646, 22.2304821], [88.85025024, 22.23002434], [88.84989929, 22.22966385], [88.84957123, 22.2294445], [88.84932709, 22.22932243], [88.84895325, 22.22916031], [88.84874725, 22.22890472], [88.84853363, 22.22852325], [88.84822845, 22.22812462], [88.84788513, 22.22774315], [88.84751892, 22.22734833], [88.84715271, 22.22694969], [88.84675598, 22.22657776], [88.84637451, 22.22619438], [88.84597778, 22.22583008], [88.8455658, 22.22547913], [88.84515381, 22.2251358], [88.84475708, 22.22476006], [88.84439087, 22.22436714], [88.84406281, 22.2239399], [88.84369659, 22.22353172], [88.84336853, 22.22310066], [88.84304047, 22.22268295], [88.84269714, 22.22229958], [88.84234619, 22.22195244], [88.84203339, 22.22162056], [88.84172058, 22.22126198], [88.84143066, 22.22086906], [88.84114838, 22.22047234], [88.84088135, 22.22004128], [88.84062195, 22.21962166], [88.8404007, 22.21921158], [88.84024811, 22.21879005], [88.84010315, 22.21842957], [88.83996582, 22.21807289], [88.83982849, 22.21775246], [88.83972931, 22.21738815], [88.83963013, 22.21704292], [88.83953857, 22.21661186], [88.83947754, 22.2161026], [88.83943176, 22.21552658], [88.83953094, 22.21492195], [88.83966827, 22.21435356], [88.83985138, 22.21389008], [88.84005737, 22.21358299], [88.84025574, 22.21332741], [88.84044647, 22.21302986], [88.84068298, 22.21267128], [88.84102631, 22.21232033], [88.84147644, 22.2120285], [88.84194946, 22.21174049], [88.84247589, 22.2115078], [88.84303284, 22.21135139], [88.84353638, 22.21119499], [88.84403229, 22.21106339], [88.84449768, 22.2109127], [88.84496307, 22.21080208], [88.84538269, 22.21066093], [88.84583282, 22.21054268], [88.84628296, 22.21041298], [88.84677887, 22.21029091], [88.84726715, 22.21020317], [88.84771729, 22.21022224], [88.84815216, 22.21017456], [88.848526, 22.21001244], [88.84895325, 22.20984077], [88.84946442, 22.20978928], [88.84996796, 22.20981026], [88.85043335, 22.20990944], [88.85089874, 22.20988274], [88.85137939, 22.20977974], [88.85186768, 22.20972824], [88.85236359, 22.2097187], [88.85282898, 22.20969963], [88.85331726, 22.20965004], [88.8538208, 22.20958138], [88.85428619, 22.20967293], [88.85479736, 22.20969963], [88.8550415, 22.20967484], [88.85527802, 22.20965385], [88.85575104, 22.20952225], [88.85623932, 22.20948792], [88.85674286, 22.20953178], [88.85721588, 22.20959282], [88.85769653, 22.20951271], [88.85816193, 22.20947266], [88.8585968, 22.20947266], [88.85900879, 22.20951271], [88.85942841, 22.20946312], [88.85988617, 22.2094326], [88.86038971, 22.20942307], [88.86094666, 22.20942116], [88.86151123, 22.20942116], [88.86209106, 22.20942116], [88.86264801, 22.20942116], [88.86316681, 22.20944023], [88.86367798, 22.20950127], [88.86416626, 22.20963097], [88.86469269, 22.20970345], [88.86528015, 22.20977974], [88.8658905, 22.20993233], [88.86651611, 22.21003151], [88.86712646, 22.2101593], [88.8677063, 22.21026039], [88.86824799, 22.21038246], [88.86875916, 22.21056938], [88.8692627, 22.21075249], [88.86979675, 22.21086121], [88.87034607, 22.21099091], [88.87088776, 22.211092], [88.87140656, 22.21118927], [88.87187958, 22.21133232], [88.87233734, 22.21141052], [88.87275696, 22.21151161], [88.87314606, 22.21162987], [88.87355804, 22.21171951], [88.8739624, 22.21186256], [88.87442017, 22.21191978], [88.87494659, 22.21192551], [88.8755188, 22.21193314], [88.87612915, 22.21196365], [88.87677765, 22.21204948], [88.87739563, 22.21213531], [88.87802124, 22.21217346], [88.87866211, 22.21217537], [88.87934875, 22.21212959], [88.88008881, 22.21199226], [88.88085938, 22.21191788], [88.88160706, 22.21182251], [88.88227844, 22.21159935], [88.88282776, 22.2113018], [88.88327789, 22.21092033], [88.88360596, 22.21051598], [88.88384247, 22.21007919], [88.88399506, 22.20963478], [88.88411713, 22.20920372], [88.88419342, 22.2087574], [88.88430023, 22.20832253], [88.88438416, 22.20788193], [88.88442993, 22.20740128], [88.88443756, 22.20689964], [88.88445282, 22.2063694], [88.88444519, 22.20582962], [88.88443756, 22.2052784], [88.88437653, 22.20473289], [88.8842392, 22.20422173], [88.88417816, 22.20371056], [88.88413239, 22.20322227], [88.88401794, 22.20277023], [88.88385773, 22.20233917], [88.88360596, 22.20195961], [88.88331604, 22.20160294], [88.88301849, 22.20128059], [88.8826828, 22.20102119], [88.88230896, 22.20079613], [88.88194275, 22.20055962], [88.88153839, 22.20033073], [88.88108063, 22.20016479], [88.88059235, 22.20003319], [88.88008118, 22.19995308], [88.87961578, 22.1997509], [88.87914276, 22.19960022], [88.87869263, 22.19944191], [88.87822723, 22.19926453], [88.87774658, 22.19920158], [88.87728119, 22.19913483], [88.87684631, 22.19895935], [88.87638092, 22.19902229], [88.87588501, 22.19911385], [88.8753891, 22.19911194], [88.87490082, 22.19907951], [88.87445831, 22.19899178], [88.87403107, 22.19892311], [88.87358093, 22.19889259], [88.87310791, 22.19889259], [88.87258148, 22.19889259], [88.87198639, 22.19889259], [88.87135315, 22.19889259], [88.87063599, 22.19889259], [88.86991119, 22.19889259], [88.86915588, 22.19892311], [88.8684082, 22.19895935], [88.86769867, 22.19885063], [88.86707306, 22.1986084], [88.86651611, 22.19835281], [88.86602783, 22.19815445], [88.86553955, 22.19808769], [88.86511993, 22.19820023], [88.86488342, 22.1985054], [88.86466217, 22.19885635], [88.8644104, 22.19922066], [88.86416626, 22.19964409], [88.86391449, 22.20006943], [88.86364746, 22.20049286], [88.8633728, 22.20089149], [88.8631134, 22.20134926], [88.86288452, 22.2018013], [88.86263275, 22.20219231], [88.86235046, 22.20256042], [88.86207581, 22.20293999], [88.86180115, 22.2033329], [88.86151123, 22.20373154], [88.86118317, 22.20409393], [88.86083221, 22.20446205], [88.860466, 22.20485115], [88.86004639, 22.20518112], [88.85958099, 22.20543098], [88.85907745, 22.20561218], [88.85858917, 22.20583153], [88.85806274, 22.20604134], [88.8574295, 22.2062397], [88.85671234, 22.20631981], [88.85597229, 22.20638084], [88.85518646, 22.20638084], [88.8544693, 22.206213], [88.85386658, 22.20599174], [88.85337067, 22.20573235], [88.85294342, 22.20544815], [88.85253906, 22.20516014], [88.85214996, 22.20488548], [88.85177612, 22.20458031], [88.85144043, 22.20423126], [88.85114288, 22.20384789], [88.8508606, 22.20341492], [88.85058594, 22.20296288], [88.85037231, 22.20247078], [88.85015106, 22.20194244], [88.85005951, 22.20134354], [88.84998322, 22.20075417], [88.8498764, 22.20018196], [88.8497467, 22.19959259], [88.849617, 22.19895935], [88.84953308, 22.19821167], [88.84954834, 22.19743156], [88.84963989, 22.19666862], [88.84963226, 22.1959095], [88.84954834, 22.19519043], [88.84950256, 22.19452095], [88.84945679, 22.19395447], [88.84938812, 22.1935215], [88.84925079, 22.19323349], [88.84908295, 22.19299126], [88.84889984, 22.19272041], [88.84873199, 22.19239235], [88.84855652, 22.19196129], [88.84831238, 22.19155121], [88.8480072, 22.19117355], [88.84765625, 22.19083977], [88.84731293, 22.19060135], [88.84693909, 22.19045067], [88.84660339, 22.1903019], [88.84621429, 22.19024658], [88.84580231, 22.19026184], [88.84538269, 22.19029045], [88.84498596, 22.19027138], [88.84461975, 22.19028473], [88.8442688, 22.19031715], [88.84396362, 22.19043541], [88.84361267, 22.19054031], [88.8432312, 22.19067192], [88.8428421, 22.19086266], [88.84247589, 22.19112206], [88.84211731, 22.19141197], [88.84177399, 22.19171715], [88.84145355, 22.19202232], [88.84115601, 22.19232941], [88.84088135, 22.19265938], [88.84065247, 22.1930027], [88.84047699, 22.19337273], [88.84030914, 22.19368935], [88.84015656, 22.19400215], [88.83998871, 22.19425392], [88.83979034, 22.19450188], [88.83959961, 22.19481087], [88.83942413, 22.19519234], [88.8392334, 22.19561195], [88.83909607, 22.19606972], [88.83893585, 22.19651985], [88.83882141, 22.19697189], [88.83869171, 22.19740105], [88.83863068, 22.19785309], [88.83860779, 22.19833946], [88.83859253, 22.19889259], [88.83857727, 22.19951057], [88.83860016, 22.20016479], [88.83857727, 22.20079994], [88.83834839, 22.20140648], [88.8381424, 22.20191383], [88.83804321, 22.2023716], [88.83796692, 22.20277977], [88.837883, 22.20316124], [88.83778381, 22.20352173], [88.83770752, 22.20394325], [88.83759308, 22.20441246], [88.83748627, 22.20491982], [88.83737183, 22.20537567], [88.83727264, 22.20575142], [88.83718109, 22.20607948], [88.83705902, 22.2063694], [88.83694458, 22.20670509], [88.83679199, 22.20705986], [88.83655548, 22.20738602], [88.83625031, 22.20767021], [88.83590698, 22.20798302], [88.83557129, 22.20829964], [88.83519745, 22.20858955], [88.83480072, 22.20885086], [88.83436584, 22.20907211], [88.83386993, 22.20923424], [88.83338928, 22.2094326], [88.832901, 22.20962334], [88.8323822, 22.20976067], [88.83178711, 22.20984077], [88.8309021, 22.21013069], [88.82990265, 22.21013069], [88.82917786, 22.20998955], [88.82824707, 22.20972252], [88.8272171, 22.20882225], [88.82691193, 22.20848846], [88.82657623, 22.20812035], [88.82624054, 22.2076931], [88.82595825, 22.20726967], [88.82571411, 22.20688057], [88.82550049, 22.20650291], [88.82530975, 22.20600319], [88.82509613, 22.2054348], [88.82485199, 22.20487595], [88.82461548, 22.20433617], [88.82453156, 22.20380974], [88.82456207, 22.2033329], [88.82469177, 22.20293999], [88.82479095, 22.20256042], [88.82491302, 22.20219994], [88.82499695, 22.20179939], [88.82505035, 22.20137978], [88.82512665, 22.20095825], [88.82525635, 22.20054054], [88.82537842, 22.20005989], [88.82553864, 22.19947243], [88.82563782, 22.19880104], [88.82546234, 22.1984005], [88.82513428, 22.19812202], [88.82467651, 22.19795036], [88.82417297, 22.19775963], [88.82366943, 22.19750595], [88.82316589, 22.19725227], [88.82262421, 22.19707298], [88.82206726, 22.19690132], [88.8215332, 22.196661], [88.82102203, 22.1964016], [88.82054901, 22.19621849], [88.82012939, 22.19616127], [88.81977081, 22.19628906], [88.81948853, 22.19635963], [88.81925201, 22.19645119], [88.81900787, 22.19666481], [88.81877136, 22.19695473], [88.81855011, 22.19728851], [88.81829834, 22.19766045], [88.81820679, 22.19821167], [88.81809235, 22.19880104], [88.81806183, 22.19941139], [88.81804657, 22.19999123], [88.81804657, 22.20052147], [88.81806183, 22.20099068], [88.81809998, 22.20141792], [88.81816864, 22.2018528], [88.81815338, 22.20229149], [88.81807709, 22.20264244], [88.8180542, 22.20299339], [88.81798553, 22.20335197], [88.81777191, 22.20371246], [88.81749725, 22.20414162], [88.8172226, 22.20469093], [88.81687927, 22.20530128], [88.8163681, 22.20584297], [88.81577301, 22.20631218], [88.81513977, 22.20672798], [88.81455231, 22.20715141], [88.81385803, 22.20750809], [88.8131485, 22.20778656], [88.81243134, 22.20804024], [88.8117218, 22.20824242], [88.81098938, 22.20831108], [88.81027222, 22.20828056], [88.80960083, 22.20815086], [88.80892944, 22.20812607], [88.8082962, 22.20827293], [88.80769348, 22.20839119], [88.80717468, 22.20862389], [88.80671692, 22.20895195], [88.80640411, 22.20943451], [88.80615997, 22.21002388], [88.80601501, 22.21068954], [88.80580139, 22.21132088], [88.80560303, 22.21190834], [88.80544281, 22.21244049]]], [[[88.86194611, 22.39888763], [88.86305237, 22.39777946], [88.86332703, 22.39806175], [88.86361694, 22.39806175], [88.86416626, 22.39860916], [88.86528015, 22.39860916], [88.86638641, 22.39749908], [88.86638641, 22.39722252], [88.8666687, 22.39694405], [88.86667633, 22.39611244], [88.86694336, 22.39583397], [88.8666687, 22.3955555], [88.86667633, 22.39418221], [88.86638641, 22.39389229], [88.86638641, 22.39361], [88.86611176, 22.39333344], [88.86611176, 22.3927784], [88.8658371, 22.39249992], [88.8658371, 22.39222145], [88.86555481, 22.39194679], [88.86555481, 22.39083481], [88.86499786, 22.39027977], [88.86499786, 22.38972282], [88.86444092, 22.38916588], [88.86444092, 22.38889122], [88.86416626, 22.38861275], [88.86416626, 22.38778114], [88.86528015, 22.38666916], [88.86528015, 22.38583183], [88.86554718, 22.38555908], [88.86638641, 22.38639069], [88.86638641, 22.3872242], [88.86667633, 22.38750267], [88.86667633, 22.38778114], [88.86777496, 22.38888931], [88.86776733, 22.38944054], [88.86833191, 22.3900013], [88.86860657, 22.38972282], [88.86888885, 22.38972282], [88.8694458, 22.38916588], [88.87000275, 22.38916969], [88.8702774, 22.38889122], [88.87055206, 22.38889122], [88.87082672, 22.38861275], [88.87110901, 22.38861275], [88.87194824, 22.38778114], [88.8722229, 22.38778114], [88.87248993, 22.38750267], [88.87277985, 22.38750267], [88.87304688, 22.38778114], [88.87333679, 22.38778114], [88.8741684, 22.38861275], [88.8741684, 22.38972282], [88.87361145, 22.39027977], [88.87361145, 22.39166832], [88.87388611, 22.39194679], [88.87361145, 22.39222145], [88.87361145, 22.39305687], [88.87333679, 22.39333344], [88.87333679, 22.39361191], [88.87444305, 22.39472008], [88.87444305, 22.39500237], [88.87388611, 22.3955555], [88.87388611, 22.39583015], [88.87361145, 22.39611244], [88.87361145, 22.39666939], [88.87388611, 22.39694405], [88.87361145, 22.39722252], [88.87361145, 22.39749908], [88.87333679, 22.39777946], [88.87333679, 22.39805984], [88.87304688, 22.3983326], [88.8730545, 22.39860916], [88.8722229, 22.39944267], [88.8722229, 22.40028191], [88.87304688, 22.40028191], [88.87333679, 22.39999199], [88.8741684, 22.40000153], [88.87472534, 22.39944649], [88.87472534, 22.39860916], [88.87527466, 22.39805984], [88.87555695, 22.3983326], [88.8758316, 22.3983326], [88.87610626, 22.39860916], [88.87666321, 22.39860916], [88.8769455, 22.39888763], [88.87750244, 22.39888763], [88.87833405, 22.39972496], [88.87861633, 22.39971924], [88.87916565, 22.40027809], [88.87889099, 22.40055275], [88.87889099, 22.40139008], [88.87916565, 22.40166664], [88.87917328, 22.40250206], [88.87889099, 22.40278053], [88.87889099, 22.40305519], [88.87916565, 22.40333366], [88.87917328, 22.40361214], [88.87861633, 22.4041748], [88.87915802, 22.40400124], [88.8795929, 22.40396309], [88.88012695, 22.40374947], [88.88057709, 22.40321159], [88.8807373, 22.40252686], [88.8806076, 22.40190315], [88.88041687, 22.40128136], [88.88020325, 22.40073967], [88.87998199, 22.40020561], [88.87975311, 22.39970207], [88.8795929, 22.39920425], [88.87944794, 22.39875603], [88.87930298, 22.39834785], [88.87919617, 22.39798164], [88.87911987, 22.39762306], [88.8789978, 22.39733315], [88.87890625, 22.39702034], [88.87888336, 22.39669037], [88.87882233, 22.39635277], [88.87865448, 22.39608383], [88.87856293, 22.39577293], [88.87843323, 22.39550209], [88.8782959, 22.39515114], [88.87811279, 22.39473152], [88.87799072, 22.39421272], [88.87773132, 22.3937912], [88.87745667, 22.39336205], [88.87718964, 22.39291954], [88.87689209, 22.39253044], [88.87663269, 22.39217186], [88.87641144, 22.39181328], [88.87628174, 22.39144707], [88.87612152, 22.39115906], [88.87596893, 22.39089012], [88.87580109, 22.39063072], [88.87561798, 22.39038658], [88.87554932, 22.39004326], [88.87548065, 22.38969231], [88.87530518, 22.38944435], [88.87518311, 22.38915825], [88.87507629, 22.38883018], [88.87500763, 22.38841057], [88.87494659, 22.38792038], [88.87478638, 22.38737106], [88.87484741, 22.38683128], [88.87502289, 22.38631821], [88.87525177, 22.38588142], [88.87539673, 22.38542938], [88.87557983, 22.38504219], [88.87581635, 22.38472939], [88.87601471, 22.38436317], [88.87614441, 22.38391113], [88.87638855, 22.38356018], [88.87664795, 22.38322258], [88.87689209, 22.38287544], [88.87716675, 22.38256264], [88.87748718, 22.38226128], [88.87776947, 22.38195229], [88.87798309, 22.38155174], [88.87809753, 22.38108253], [88.87832642, 22.38066292], [88.87856293, 22.38022041], [88.87879944, 22.37978172], [88.87914276, 22.37946892], [88.87942505, 22.37913322], [88.87966156, 22.3788166], [88.87982941, 22.37848091], [88.87999725, 22.37812233], [88.88020325, 22.37771034], [88.88039398, 22.37725449], [88.88064575, 22.37677193], [88.88102722, 22.37632942], [88.88137054, 22.37584114], [88.88166046, 22.37529945], [88.88189697, 22.37474251], [88.88198853, 22.37416267], [88.88222504, 22.37373543], [88.88250732, 22.37336159], [88.88284302, 22.37302208], [88.8832016, 22.37272263], [88.88347626, 22.37235069], [88.88375092, 22.37199211], [88.88407898, 22.37173271], [88.88440704, 22.37151146], [88.88471985, 22.37129021], [88.88500977, 22.3710804], [88.88529968, 22.3708725], [88.88568115, 22.37076759], [88.88604736, 22.3705616], [88.88646698, 22.37037086], [88.88696289, 22.37024117], [88.88749695, 22.37006187], [88.8881073, 22.37001228], [88.88880157, 22.37001228], [88.88951111, 22.37001228], [88.89022064, 22.37001228], [88.89087677, 22.36979103], [88.89151001, 22.36959267], [88.89208984, 22.36940193], [88.89257813, 22.36915588], [88.89299774, 22.36887169], [88.89340973, 22.36858368], [88.89382935, 22.36832237], [88.89420319, 22.36799049], [88.8944931, 22.36758614], [88.89483643, 22.36723137], [88.89522552, 22.36692047], [88.89556885, 22.36653328], [88.89592743, 22.36614037], [88.89631653, 22.36577034], [88.89663696, 22.3653698], [88.896698, 22.36530876], [88.89778137, 22.36417389], [88.89749908, 22.36417389], [88.89778137, 22.36388016], [88.89694214, 22.36305618], [88.89665985, 22.36306381], [88.89527893, 22.36166954], [88.89527893, 22.36139107], [88.89499664, 22.36111259], [88.89499664, 22.36055946], [88.89527893, 22.36027908], [88.89527893, 22.35860825], [88.89499664, 22.35833359], [88.89499664, 22.35777664], [88.89472198, 22.35749817], [88.89472198, 22.35611153], [88.89499664, 22.35583305], [88.89499664, 22.3555584], [88.89527893, 22.35527992], [88.89583588, 22.35527992], [88.89611053, 22.35500145], [88.89805603, 22.35694885], [88.89805603, 22.3572216], [88.89861298, 22.35778236], [88.89916992, 22.35778236], [88.89943695, 22.35749817], [88.89943695, 22.35667229], [88.89971924, 22.35638809], [88.89971924, 22.35556221], [88.90000153, 22.35527992], [88.90000153, 22.35444069], [88.90027618, 22.35416412], [88.90027618, 22.35389137], [88.90055847, 22.3536129], [88.90055847, 22.35333061], [88.90083313, 22.35305405], [88.90083313, 22.3527813], [88.90087891, 22.35223198], [88.90106201, 22.35186768], [88.90113068, 22.35147285], [88.90122986, 22.35114098], [88.90139008, 22.35083961], [88.90157318, 22.35050011], [88.90172577, 22.35007858], [88.90193176, 22.3496418], [88.90210724, 22.34916115], [88.90228271, 22.34867287], [88.90247345, 22.34821129], [88.90260315, 22.34769821], [88.90278625, 22.34720039], [88.90301514, 22.34669876], [88.90310669, 22.34607124], [88.90320587, 22.34539795], [88.90309143, 22.34469032], [88.90302277, 22.34395027], [88.90280151, 22.3432579], [88.90257263, 22.34260178], [88.90223694, 22.34208107], [88.90194702, 22.34160042], [88.9016571, 22.34115028], [88.90139008, 22.34074593], [88.90112305, 22.34038162], [88.90090179, 22.3400631], [88.90088654, 22.33998871], [88.90083313, 22.33971214], [88.90000153, 22.33888817], [88.90000153, 22.3386097], [88.89971924, 22.33833313], [88.89971924, 22.33805656], [88.89944458, 22.33777809], [88.89943695, 22.33749962], [88.89861298, 22.33667374], [88.89805603, 22.33722305], [88.89778137, 22.33722305], [88.89666748, 22.33833313], [88.89665985, 22.3386097], [88.89639282, 22.33889198], [88.89639282, 22.33945274], [88.89611816, 22.33987808], [88.89592743, 22.34029198], [88.89570618, 22.34071922], [88.89553833, 22.34126091], [88.89533997, 22.34182167], [88.89510345, 22.34229851], [88.89492798, 22.34283257], [88.89469147, 22.34336281], [88.89444733, 22.34387016], [88.89417267, 22.34430885], [88.89391327, 22.34470177], [88.8936615, 22.34506989], [88.89344788, 22.34544373], [88.89321899, 22.34577179], [88.89286041, 22.34605026], [88.89242554, 22.3464241], [88.89183044, 22.34671974], [88.89126587, 22.34711266], [88.89066315, 22.34740257], [88.8901062, 22.34766388], [88.88961029, 22.34791183], [88.88925171, 22.34826088], [88.88886261, 22.34859276], [88.8884201, 22.34882927], [88.88806152, 22.34911156], [88.88774872, 22.34942055], [88.88742828, 22.34972382], [88.88710022, 22.35000038], [88.88676453, 22.35025597], [88.88639832, 22.35044289], [88.88604736, 22.35062218], [88.88566589, 22.35083961], [88.88529968, 22.35110283], [88.88496399, 22.35139847], [88.88455963, 22.35160255], [88.8842392, 22.3518486], [88.88386536, 22.35199547], [88.88358307, 22.35222054], [88.88321686, 22.35240173], [88.88282776, 22.35270119], [88.88241577, 22.35297966], [88.88199615, 22.35318947], [88.88163757, 22.35346031], [88.88126373, 22.35373306], [88.88088226, 22.35404396], [88.88057709, 22.35450172], [88.88031006, 22.35503006], [88.88008118, 22.35556984], [88.87988281, 22.35609818], [88.87970734, 22.35659218], [88.8795166, 22.35707283], [88.87944794, 22.35757256], [88.87941742, 22.35806656], [88.87931061, 22.35851097], [88.87914276, 22.35894966], [88.87889099, 22.35938072], [88.87858582, 22.35981941], [88.8782196, 22.3602314], [88.87776947, 22.36060143], [88.87737274, 22.36107063], [88.87691498, 22.36148262], [88.87641907, 22.36183357], [88.87592316, 22.36214638], [88.87549591, 22.36248207], [88.87509155, 22.36281204], [88.87473297, 22.36314964], [88.87438202, 22.36349297], [88.87395477, 22.36367989], [88.87355804, 22.36388016], [88.87314606, 22.36406136], [88.87269592, 22.36424065], [88.87221527, 22.36440659], [88.87168121, 22.36444664], [88.87113953, 22.36444664], [88.87059784, 22.36444664], [88.87007141, 22.36446762], [88.86959076, 22.3645916], [88.869133, 22.36477089], [88.86872101, 22.36496925], [88.8682785, 22.36507225], [88.86781311, 22.36523819], [88.86736298, 22.36539268], [88.86695099, 22.36555481], [88.86656189, 22.36573219], [88.8662262, 22.36593246], [88.86582184, 22.36610985], [88.86535645, 22.36630821], [88.86490631, 22.36650276], [88.86459351, 22.36678123], [88.86422729, 22.36703873], [88.86385345, 22.36736679], [88.86341858, 22.36769485], [88.86296082, 22.36804008], [88.86250305, 22.36833], [88.86250305, 22.36861229], [88.86222076, 22.36889076], [88.86222076, 22.36917305], [88.86138916, 22.37001228], [88.86138916, 22.3702774], [88.86083221, 22.37083244], [88.86083221, 22.37111092], [88.86083221, 22.37125206], [88.86078644, 22.37170982], [88.86061096, 22.37211037], [88.86054993, 22.37250328], [88.86048126, 22.37285423], [88.86036682, 22.37321663], [88.86029053, 22.3736248], [88.8602829, 22.37407112], [88.8602829, 22.37457085], [88.86030579, 22.37508392], [88.86038208, 22.37558174], [88.8602829, 22.37613106], [88.86013031, 22.37664223], [88.85996246, 22.3772583], [88.85978699, 22.37790108], [88.85957336, 22.37860107], [88.85967255, 22.37927055], [88.85972595, 22.37972069], [88.85972595, 22.38000488], [88.85943604, 22.38028145], [88.85943604, 22.38111305], [88.85916901, 22.38139153], [88.85916901, 22.38222313], [88.85888672, 22.3825016], [88.85884857, 22.38239288], [88.85869598, 22.38271141], [88.85857391, 22.38305855], [88.85834503, 22.38342476], [88.858078, 22.38387489], [88.85781097, 22.38439178], [88.85749054, 22.38501167], [88.85694122, 22.38555908], [88.85666656, 22.38555908], [88.85610962, 22.3861084], [88.85610962, 22.38639069], [88.85558319, 22.38685608], [88.8555069, 22.38691711], [88.85540771, 22.38713264], [88.85533905, 22.38764191], [88.8554306, 22.38824272], [88.8556366, 22.38884163], [88.85566711, 22.38941956], [88.85569, 22.389925], [88.85579681, 22.39038467], [88.85581207, 22.39086914], [88.85569763, 22.39138985], [88.85557556, 22.39187622], [88.8555603, 22.39236259], [88.85560608, 22.39283562], [88.85578156, 22.39328957], [88.8557663, 22.39381218], [88.85559845, 22.39435005], [88.85566711, 22.39481163], [88.85583496, 22.39518356], [88.85604858, 22.39550209], [88.85624695, 22.3958416], [88.85652161, 22.39618111], [88.85684967, 22.39653206], [88.85723114, 22.39687157], [88.85762024, 22.39721107], [88.85797882, 22.39767456], [88.85830688, 22.39806175], [88.85852051, 22.39841652], [88.8587265, 22.39867973], [88.85890961, 22.39895058], [88.85902405, 22.39919472], [88.85922241, 22.39941216], [88.85929108, 22.39985847], [88.85942841, 22.40028191], [88.85955048, 22.40077019], [88.85968781, 22.40126991], [88.85975647, 22.40187263], [88.85992432, 22.4024601], [88.85998535, 22.40307236], [88.86000061, 22.40363121], [88.86000061, 22.40411949], [88.85997772, 22.40449142], [88.85991669, 22.40479088], [88.85984039, 22.40513802], [88.8598175, 22.40565681], [88.85987091, 22.40621948], [88.86000061, 22.4066658], [88.8602829, 22.40694237], [88.8602829, 22.40750313], [88.86055756, 22.40777779], [88.86055756, 22.40833473], [88.86083221, 22.4086132], [88.86083221, 22.40972328], [88.86166382, 22.41055489], [88.86222076, 22.41055489], [88.86250305, 22.41028023], [88.86250305, 22.40971947], [88.86222076, 22.40944481], [88.86222076, 22.40916634], [88.86194611, 22.40889168], [88.86194611, 22.40860939], [88.86166382, 22.40833282], [88.86166382, 22.40722656], [88.86138916, 22.40694427], [88.86138916, 22.40611076], [88.86110687, 22.40583229], [88.8611145, 22.40500069], [88.86138916, 22.40472221], [88.86138916, 22.40416908], [88.86165619, 22.40389061], [88.86165619, 22.40305138], [88.86194611, 22.40277863], [88.86194611, 22.40222168], [88.86222076, 22.40194511], [88.86222076, 22.4011116], [88.86194611, 22.40083313], [88.86194611, 22.40000153], [88.86166382, 22.39972496], [88.86166382, 22.39944649], [88.86194611, 22.39916992], [88.86194611, 22.39888763]]], [[[88.9102478, 22.33291817], [88.90982819, 22.33324242], [88.90942383, 22.33365631], [88.90897369, 22.33408165], [88.90853119, 22.33452034], [88.9081192, 22.33496284], [88.90777588, 22.33540154], [88.90733337, 22.33579063], [88.90703583, 22.33627129], [88.90682983, 22.33678246], [88.90661621, 22.33726311], [88.90644073, 22.33775139], [88.90635681, 22.33827019], [88.90625, 22.3387661], [88.90629578, 22.3393116], [88.90628052, 22.33986855], [88.9061203, 22.34045029], [88.90598297, 22.34106255], [88.90588379, 22.34171295], [88.90585327, 22.34230995], [88.90592194, 22.34280968], [88.90606689, 22.34315109], [88.90611267, 22.34346008], [88.90611267, 22.34376907], [88.90611267, 22.34412956], [88.90611267, 22.3445549], [88.90605927, 22.34502983], [88.90585327, 22.34555817], [88.90567017, 22.3461895], [88.90577698, 22.34691048], [88.90577698, 22.34763145], [88.9056015, 22.34823036], [88.90550232, 22.34875679], [88.90538025, 22.34917641], [88.90529633, 22.34954262], [88.90524292, 22.34991074], [88.90507507, 22.35023308], [88.90493011, 22.35062981], [88.90480042, 22.35102272], [88.90467834, 22.35128593], [88.9045105, 22.35150337], [88.90439606, 22.35178947], [88.90421295, 22.35205269], [88.90403748, 22.35237312], [88.90386963, 22.35276222], [88.90364838, 22.35313225], [88.90351868, 22.35357094], [88.90335846, 22.35398293], [88.90323639, 22.3543911], [88.90305328, 22.35475159], [88.9028244, 22.35512352], [88.90261841, 22.35557938], [88.90235901, 22.35611916], [88.90213013, 22.35685158], [88.90213776, 22.35766029], [88.9021759, 22.35838127], [88.90203857, 22.3589592], [88.90177917, 22.35940933], [88.90177155, 22.35992813], [88.90170288, 22.36041069], [88.90170288, 22.36086082], [88.90171051, 22.36133194], [88.90170288, 22.36185837], [88.90183258, 22.36241913], [88.9019165, 22.36296844], [88.90193176, 22.36348152], [88.90184021, 22.36392021], [88.90171814, 22.36430359], [88.9016571, 22.36469078], [88.90155792, 22.36509132], [88.90142059, 22.36556435], [88.90139008, 22.36609268], [88.90133667, 22.36663246], [88.90119171, 22.36712265], [88.90103149, 22.36758232], [88.90081787, 22.3680706], [88.90058136, 22.36858368], [88.90039063, 22.36912155], [88.90039063, 22.36972809], [88.90027618, 22.37023163], [88.90016937, 22.37077141], [88.90001678, 22.37132835], [88.89971924, 22.37182045], [88.89936066, 22.37232018], [88.89903259, 22.37286949], [88.89868164, 22.37336349], [88.89854431, 22.37391472], [88.89836884, 22.37440491], [88.89821625, 22.37485313], [88.89806366, 22.37526703], [88.89791107, 22.37566185], [88.89781952, 22.37603188], [88.89766693, 22.37631035], [88.89755249, 22.37661171], [88.89737701, 22.37689018], [88.89723206, 22.37726974], [88.89710999, 22.37766457], [88.89698792, 22.37803078], [88.89691162, 22.37844276], [88.89675903, 22.37883186], [88.89660645, 22.37933159], [88.89643097, 22.37982941], [88.89640808, 22.38038063], [88.89653015, 22.38091087], [88.896698, 22.38142967], [88.8970108, 22.38187218], [88.89739227, 22.3822422], [88.897789, 22.38259315], [88.89817047, 22.38290977], [88.89850616, 22.38323021], [88.89884186, 22.38355827], [88.89920044, 22.3839016], [88.89955139, 22.38425255], [88.89993286, 22.38449287], [88.90029907, 22.38474274], [88.90065002, 22.38501167], [88.90099335, 22.38528252], [88.90131378, 22.38554573], [88.90164948, 22.38578224], [88.9019928, 22.38599205], [88.90239716, 22.38614082], [88.90278625, 22.38638115], [88.90328217, 22.38661194], [88.90390015, 22.38676834], [88.90458679, 22.38696289], [88.90529633, 22.38721275], [88.90602112, 22.38746071], [88.90666962, 22.38778114], [88.90731049, 22.3881321], [88.90799713, 22.3884716], [88.90868378, 22.3888607], [88.9094162, 22.38920021], [88.91007233, 22.38964272], [88.9106369, 22.38998222], [88.91121674, 22.39016151], [88.91175079, 22.39014244], [88.91221619, 22.39033318], [88.9126358, 22.3906498], [88.91308594, 22.39088058], [88.91348267, 22.39111137], [88.91387939, 22.39134026], [88.91436005, 22.39142036], [88.91481781, 22.39158249], [88.91529083, 22.39187241], [88.91591644, 22.39194489], [88.91654205, 22.39195061], [88.91682434, 22.39194679], [88.91710663, 22.39194489], [88.91766357, 22.39190102], [88.91832733, 22.39167213], [88.91860962, 22.39167213], [88.91916656, 22.39111137], [88.91944122, 22.39111137], [88.91971588, 22.39138985], [88.91999817, 22.39111137], [88.92028046, 22.39111137], [88.92138672, 22.3900013], [88.92166901, 22.3900013], [88.92193604, 22.38972282], [88.92250061, 22.38972282], [88.92305756, 22.38916588], [88.92193604, 22.38805008], [88.92194366, 22.38777733], [88.92166901, 22.38750267], [88.92166901, 22.38666916], [88.92138672, 22.38639259], [88.92138672, 22.3861084], [88.92166901, 22.38583183], [88.92166901, 22.38444519], [88.92222595, 22.38388824], [88.9227829, 22.38445091], [88.92415619, 22.38445091], [88.92527771, 22.38555908], [88.92527771, 22.38666725], [88.92555237, 22.38694191], [88.92555237, 22.38750267], [88.9263916, 22.38833427], [88.92666626, 22.38833237], [88.92684937, 22.38851738], [88.92694092, 22.38861275], [88.92749786, 22.38861275], [88.92778015, 22.38889122], [88.92805481, 22.38889122], [88.92861176, 22.38944435], [88.9291687, 22.38944054], [88.93000031, 22.39027977], [88.93000031, 22.39138985], [88.92972565, 22.39166641], [88.92973328, 22.39194489], [88.92861176, 22.39306068], [88.9283371, 22.39305687], [88.92805481, 22.39333344], [88.92749786, 22.39333344], [88.92722321, 22.39305687], [88.92694092, 22.39306068], [88.92610931, 22.39222145], [88.92555237, 22.39222145], [88.92500305, 22.39278221], [88.92444611, 22.39222145], [88.92416382, 22.39222145], [88.92388916, 22.39194679], [88.92305756, 22.39194679], [88.92277527, 22.39166832], [88.92194366, 22.39166832], [88.92166901, 22.39194679], [88.92193604, 22.39222145], [88.92280579, 22.39286995], [88.92424011, 22.39352989], [88.92433929, 22.39380074], [88.92472839, 22.39395332], [88.92502594, 22.39418983], [88.92533112, 22.39444923], [88.92562866, 22.39471245], [88.92595673, 22.39497948], [88.9263382, 22.39524269], [88.92668152, 22.39557076], [88.92700195, 22.39590645], [88.92725372, 22.39631271], [88.92749786, 22.39672279], [88.92771912, 22.39717293], [88.9278183, 22.39774132], [88.92800903, 22.39830589], [88.92805481, 22.39891624], [88.92809296, 22.39954376], [88.92816162, 22.40017891], [88.92810059, 22.40078163], [88.92801666, 22.40136147], [88.9278717, 22.40186501], [88.92777252, 22.4023304], [88.9276886, 22.40271378], [88.92753601, 22.40300941], [88.92746735, 22.40332985], [88.92736816, 22.40361214], [88.92723846, 22.40387154], [88.92710876, 22.40411186], [88.92695618, 22.40442085], [88.92672729, 22.40470314], [88.92656708, 22.40507317], [88.92637634, 22.40541458], [88.92613983, 22.40580177], [88.9258194, 22.40623283], [88.92539978, 22.40668297], [88.92485809, 22.40719414], [88.92429352, 22.40765572], [88.92376709, 22.40807152], [88.92333221, 22.40850258], [88.92289734, 22.40894127], [88.92249298, 22.40940094], [88.92193604, 22.40971947], [88.92138672, 22.41002083], [88.92082977, 22.41028023], [88.92028046, 22.41083336], [88.91999817, 22.41082954], [88.91944122, 22.4113903], [88.91916656, 22.4113903], [88.91889191, 22.41167259], [88.91860962, 22.41167259], [88.91832733, 22.41194916], [88.91805267, 22.41194725], [88.91777802, 22.41222191], [88.91750336, 22.41222191], [88.91722107, 22.41249847], [88.91711426, 22.41260338], [88.91677856, 22.41253471], [88.91641998, 22.41251183], [88.91599274, 22.41254616], [88.91558075, 22.4126606], [88.91520691, 22.4127903], [88.91485596, 22.41291237], [88.91448975, 22.41303062], [88.91403198, 22.41311073], [88.91356659, 22.41329002], [88.91304779, 22.41335106], [88.91254425, 22.41345024], [88.91208649, 22.41358376], [88.91159821, 22.41369438], [88.91114044, 22.41388512], [88.91062927, 22.41407204], [88.90998077, 22.41424179], [88.90940094, 22.41457176], [88.90888977, 22.41472435], [88.90777588, 22.41583252], [88.90777588, 22.41694069], [88.90830994, 22.41750145], [88.90862274, 22.41777229], [88.90908051, 22.41798973], [88.90956116, 22.41827965], [88.91004944, 22.41853714], [88.91049194, 22.41888237], [88.91086578, 22.4192028], [88.91124725, 22.41941071], [88.91155243, 22.41966438], [88.91186523, 22.41986275], [88.91239929, 22.41979027], [88.91300964, 22.41960907], [88.91343689, 22.41981888], [88.91371155, 22.42039108], [88.91397858, 22.42071915], [88.91433716, 22.42075157], [88.91462708, 22.42080498], [88.91485596, 22.42094994], [88.91514587, 22.42107964], [88.91551971, 22.4211216], [88.91591644, 22.42111588], [88.91631317, 22.42115974], [88.91666412, 22.42134094], [88.91706848, 22.42144966], [88.9174881, 22.4216404], [88.91799164, 22.42179489], [88.91855621, 22.42201042], [88.91900635, 22.42239952], [88.91933441, 22.42296028], [88.91951752, 22.42363167], [88.91998291, 22.42414474], [88.9204483, 22.42468452], [88.92064667, 22.42531013], [88.92066956, 22.42588615], [88.92061615, 22.42630959], [88.92053986, 22.42669106], [88.92041779, 22.42706108], [88.9202652, 22.42739487], [88.92007446, 22.42770195], [88.91991425, 22.42802238], [88.91972351, 22.42833328], [88.91944122, 22.42861176], [88.91944122, 22.42889023], [88.91889191, 22.42944527], [88.91889191, 22.42972183], [88.91722107, 22.43139076], [88.91722107, 22.43167305], [88.91583252, 22.43305779], [88.91583252, 22.43333244], [88.91555786, 22.43361092], [88.91555786, 22.43388939], [88.91527557, 22.43416786], [88.91527557, 22.43444443], [88.91500092, 22.43472099], [88.91500092, 22.43499947], [88.91472626, 22.43528175], [88.91471863, 22.43555641], [88.91416931, 22.43610191], [88.91416931, 22.43639183], [88.91388702, 22.4366703], [88.91374969, 22.43674278], [88.91358185, 22.43704033], [88.91333771, 22.43734169], [88.91304779, 22.43768311], [88.91271973, 22.43806267], [88.91234589, 22.43848228], [88.91192627, 22.43889046], [88.91142273, 22.43928528], [88.91091919, 22.43974113], [88.91040039, 22.44022942], [88.90981293, 22.44063187], [88.9092865, 22.44108009], [88.90880585, 22.44148064], [88.90836334, 22.44191551], [88.90792847, 22.44234276], [88.90744781, 22.4427166], [88.90690613, 22.4430275], [88.90635681, 22.44333267], [88.90579987, 22.44363976], [88.90531158, 22.44405365], [88.90490723, 22.44452095], [88.90451813, 22.44493484], [88.90422821, 22.44532013], [88.90405273, 22.44569016], [88.90392303, 22.44615173], [88.90388489, 22.44660759], [88.90387726, 22.44701958], [88.90387726, 22.44742012], [88.90389252, 22.44783211], [88.90389252, 22.44825172], [88.90388489, 22.44867706], [88.90384674, 22.4491024], [88.90365601, 22.44951057], [88.90361023, 22.44993401], [88.90361023, 22.45036507], [88.90361023, 22.45079041], [88.90361023, 22.451231], [88.90358734, 22.45166969], [88.9034729, 22.45210266], [88.90335083, 22.45252037], [88.90333557, 22.45296288], [88.9033432, 22.4534111], [88.90332794, 22.45387459], [88.90328979, 22.45432472], [88.90313721, 22.45474052], [88.9031601, 22.45522881], [88.90298462, 22.45568275], [88.90289307, 22.45624352], [88.90270996, 22.45678139], [88.90255737, 22.45736122], [88.90229797, 22.45789146], [88.90210724, 22.45845032], [88.9019165, 22.45898819], [88.90167999, 22.45945168], [88.90148163, 22.45986938], [88.90120697, 22.46019363], [88.90101624, 22.46051598], [88.90084076, 22.46077156], [88.90068054, 22.46099281], [88.90055084, 22.46120262], [88.90040588, 22.46140099], [88.90023804, 22.46159744], [88.90003967, 22.46179008], [88.89987183, 22.46204948], [88.89962769, 22.4622612], [88.89925385, 22.4624424], [88.89888763, 22.4627533], [88.89846039, 22.46305275], [88.89801788, 22.46333694], [88.89763641, 22.46361923], [88.89749908, 22.46389198], [88.89694214, 22.46389198], [88.89472198, 22.46611214], [88.89472198, 22.46722221], [88.89666748, 22.46916771], [88.89666748, 22.46944427], [88.89694214, 22.46972275], [88.89694214, 22.47000122], [88.8972168, 22.4700222], [88.89723969, 22.47055054], [88.89737701, 22.4710083], [88.8975296, 22.47151375], [88.89775085, 22.4720211], [88.89792633, 22.47261238], [88.89807892, 22.47322845], [88.89825439, 22.4738121], [88.89834595, 22.4744339], [88.89848328, 22.47507286], [88.89865112, 22.47567368], [88.89874268, 22.47631264], [88.89881897, 22.47684479], [88.89865875, 22.47728729], [88.8985672, 22.47779274], [88.89839935, 22.47826195], [88.89824677, 22.4786911], [88.89804077, 22.47909927], [88.89778137, 22.47955513], [88.89751434, 22.48009491], [88.89729309, 22.48071289], [88.89701843, 22.48127747], [88.89679718, 22.48178291], [88.89659119, 22.48232079], [88.89642334, 22.48293114], [88.89618683, 22.48350906], [88.89630127, 22.48409843], [88.89641571, 22.48468971], [88.89660645, 22.48525238], [88.89673615, 22.48584938], [88.89700317, 22.48630714], [88.89731598, 22.48665047], [88.89762878, 22.48694611], [88.89789581, 22.48724174], [88.89817047, 22.48756218], [88.89846802, 22.48790169], [88.89884186, 22.48825645], [88.89933014, 22.48852921], [88.89980316, 22.48887062], [88.90026855, 22.48917198], [88.90071106, 22.48944855], [88.90087128, 22.48954582], [88.90111542, 22.4896946], [88.90139008, 22.4897213], [88.90194702, 22.4897213], [88.90277863, 22.49055862], [88.90305328, 22.49055862], [88.90361023, 22.49111176], [88.90348053, 22.49114037], [88.90379333, 22.49141121], [88.90403748, 22.49171257], [88.90428162, 22.49196815], [88.90449524, 22.49222946], [88.90479279, 22.49240494], [88.90503693, 22.49271011], [88.90529633, 22.49305153], [88.90560913, 22.49336815], [88.90585327, 22.49376106], [88.90611267, 22.49416161], [88.90637207, 22.49457932], [88.90656281, 22.49509239], [88.90672302, 22.49565315], [88.90696716, 22.49619865], [88.90705109, 22.49675941], [88.90709686, 22.49726486], [88.90718842, 22.4976902], [88.90721893, 22.49813271], [88.90725708, 22.4985981], [88.90737915, 22.49908638], [88.90735626, 22.49968529], [88.90733337, 22.50037193], [88.90724945, 22.50101089], [88.90722656, 22.50159264], [88.90721893, 22.50221062], [88.90721893, 22.50250053], [88.90693665, 22.50278282], [88.90693665, 22.50306129], [88.90888977, 22.50500298], [88.9091568, 22.50500298], [88.90972137, 22.50555611], [88.90972137, 22.50583076], [88.90944672, 22.50611305], [88.9091568, 22.50611305], [88.90888977, 22.50639153], [88.90777588, 22.50639153], [88.90750122, 22.50667191], [88.90721893, 22.50666618], [88.90694427, 22.50694466], [88.90666962, 22.50694466], [88.90638733, 22.50722313], [88.90611267, 22.50722313], [88.90611267, 22.5075016], [88.90583038, 22.50777817], [88.90583038, 22.50805092], [88.90611267, 22.50833321], [88.90611267, 22.50861168], [88.90666962, 22.50861168], [88.90750122, 22.50778008], [88.90805817, 22.50778008], [88.90833282, 22.5075016], [88.91139221, 22.5075016], [88.91165924, 22.50778008], [88.91222382, 22.50777817], [88.91241455, 22.50797272], [88.91249847, 22.50805473], [88.91306305, 22.50805092], [88.91416931, 22.50917435], [88.91416931, 22.51000023], [88.91443634, 22.51028252], [88.91444397, 22.51111031], [88.91416931, 22.51138115], [88.91444397, 22.51166725], [88.91444397, 22.51194382], [88.91416931, 22.51222038], [88.91416931, 22.51389122], [88.91388702, 22.51416588], [88.91388702, 22.51472282], [88.91221619, 22.51638985], [88.91222382, 22.51666641], [88.91194153, 22.5169487], [88.91194153, 22.51722145], [88.91166687, 22.51749992], [88.91166687, 22.51805496], [88.91139221, 22.51833153], [88.91139221, 22.51889229], [88.91110992, 22.51916885], [88.91110992, 22.5194416], [88.91055298, 22.52000237], [88.91027832, 22.51971817], [88.90972137, 22.51972389], [88.90944672, 22.51944542], [88.90916443, 22.51944542], [88.90888977, 22.51916885], [88.90859985, 22.51917076], [88.90833282, 22.51889229], [88.90805817, 22.51889229], [88.90750122, 22.51833153], [88.90721893, 22.51861382], [88.90693665, 22.51860809], [88.90638733, 22.51917076], [88.90750122, 22.52028084], [88.90805817, 22.52028084], [88.91027832, 22.5225029], [88.91027832, 22.52361107], [88.90999603, 22.52388954], [88.91000366, 22.52416611], [88.90944672, 22.52472115], [88.90944672, 22.52499962], [88.90888977, 22.52555656], [88.90860748, 22.52555656], [88.90805817, 22.52499962], [88.90805817, 22.52472115], [88.90777588, 22.52444458], [88.90777588, 22.5233326], [88.90750122, 22.52305794], [88.90750122, 22.52277946], [88.90721893, 22.5225029], [88.9069519, 22.52229118], [88.90682983, 22.52271271], [88.90663147, 22.52309227], [88.90640259, 22.52349663], [88.90618134, 22.52392006], [88.90596771, 22.52431488], [88.90582275, 22.52466011], [88.9056015, 22.52490616], [88.90541077, 22.52514076], [88.90512085, 22.5253334], [88.90480042, 22.52555847], [88.90447235, 22.52584267], [88.90422821, 22.52626228], [88.90416718, 22.52677536], [88.90412903, 22.52724838], [88.90401459, 22.52764893], [88.90392303, 22.52798271], [88.90390015, 22.52831078], [88.90389252, 22.52861214], [88.90387726, 22.52890968], [88.90383148, 22.52919006], [88.90367126, 22.5294323], [88.90358734, 22.52970314], [88.90349579, 22.52997017], [88.9033432, 22.53026009], [88.90319061, 22.53064537], [88.90310669, 22.53115463], [88.9031601, 22.53170395], [88.90337372, 22.53211975], [88.90363312, 22.53244972], [88.90387726, 22.53276253], [88.90474701, 22.53451157], [88.90460205, 22.53577995], [88.90393829, 22.53765488], [88.90376282, 22.53791237], [88.90328979, 22.5383625], [88.90284729, 22.53886223], [88.90249634, 22.53944206], [88.90220642, 22.5400219], [88.90200806, 22.54063225], [88.90202332, 22.54129028], [88.90219116, 22.54191017], [88.90241241, 22.54246712], [88.90244293, 22.54302025], [88.9022522, 22.54347992], [88.90209961, 22.54390144], [88.9019928, 22.54431915], [88.90193939, 22.54477119], [88.90187836, 22.54521751], [88.90190125, 22.54565239], [88.90192413, 22.54605675], [88.9018631, 22.54644203], [88.9016571, 22.54679298], [88.90139008, 22.54718208], [88.90106964, 22.54762077], [88.90067291, 22.54805946], [88.90023041, 22.54849052], [88.89975739, 22.54886055], [88.89933777, 22.54924965], [88.89907837, 22.54972267], [88.89890289, 22.55020523], [88.89879608, 22.55066109], [88.89866638, 22.55105019], [88.89863586, 22.55137253], [88.89810181, 22.55294991], [88.89772797, 22.55376816], [88.89749146, 22.55415916], [88.89723206, 22.5544796], [88.89697266, 22.5547924], [88.89669037, 22.55509377], [88.89639282, 22.55543137], [88.89607239, 22.55579185], [88.89569092, 22.55614281], [88.89531708, 22.55657005], [88.89499664, 22.55714226], [88.89476776, 22.55779076], [88.89476776, 22.55846977], [88.89493561, 22.55907059], [88.89504242, 22.55964088], [88.89528656, 22.56011009], [88.8956604, 22.5605011], [88.89614105, 22.56079483], [88.89676666, 22.56092453], [88.8973999, 22.56104279], [88.89797211, 22.56110191], [88.89853668, 22.5611515], [88.89910126, 22.56130028], [88.89966583, 22.56142235], [88.900177, 22.56165123], [88.9006958, 22.56181145], [88.90125275, 22.5619297], [88.90183258, 22.56202126], [88.90239716, 22.56218147], [88.90302277, 22.56225014], [88.90362549, 22.56236839], [88.90422821, 22.56248856], [88.90488434, 22.56261826], [88.90552521, 22.56279564], [88.90613556, 22.56299019], [88.9067688, 22.5629673], [88.90724945, 22.56303596], [88.9076767, 22.56307411], [88.9080658, 22.56320381], [88.90848541, 22.56344414], [88.9090271, 22.56359291], [88.90961456, 22.56369591], [88.91015625, 22.56385612], [88.91072083, 22.56397247], [88.91124725, 22.5641613], [88.91178894, 22.56434822], [88.91235352, 22.56443214], [88.91290283, 22.56450272], [88.91335297, 22.56467247], [88.91383362, 22.56471634], [88.91433716, 22.56472969], [88.91485596, 22.56480217], [88.91542816, 22.56495094], [88.91604614, 22.56500053], [88.91667175, 22.56506348], [88.91725922, 22.56524086], [88.91783142, 22.56528473], [88.91838837, 22.56527901], [88.91893768, 22.56529045], [88.919487, 22.565382], [88.92002106, 22.56542015], [88.92016602, 22.56530571], [88.92038727, 22.56513023], [88.92082977, 22.56497955], [88.92125702, 22.5648098], [88.9216156, 22.5644722], [88.92204285, 22.56417465], [88.92247772, 22.56387138], [88.92286682, 22.56352043], [88.92325592, 22.56314659], [88.92365265, 22.56280518], [88.92405701, 22.56248856], [88.92444611, 22.56221962], [88.92481232, 22.56194496], [88.92518616, 22.56166649], [88.92559814, 22.56139183], [88.92603302, 22.56110954], [88.92648315, 22.56083107], [88.92694092, 22.56055641], [88.92738342, 22.56028175], [88.9278183, 22.56002998], [88.92830658, 22.55977058], [88.92878723, 22.55952263], [88.92929077, 22.55919075], [88.92978668, 22.55888748], [88.93031311, 22.55859184], [88.93080902, 22.55830765], [88.93123627, 22.5579319], [88.93157959, 22.55758095], [88.93186951, 22.55724144], [88.93217468, 22.55694389], [88.9324646, 22.55666733], [88.93276215, 22.55643463], [88.93314362, 22.55628777], [88.9335022, 22.55611992], [88.93385315, 22.55599403], [88.93417358, 22.55586243], [88.93450928, 22.55583], [88.93483734, 22.55583], [88.93517303, 22.55584717], [88.9355011, 22.55593109], [88.93580627, 22.55611229], [88.93618011, 22.55629539], [88.93659973, 22.55643463], [88.93699646, 22.55665588], [88.93741608, 22.55682945], [88.93785095, 22.55690956], [88.93826294, 22.5568428], [88.93862915, 22.55664253], [88.93891144, 22.55636024], [88.93914795, 22.5560627], [88.9393692, 22.55577278], [88.93972778, 22.55558968], [88.94011688, 22.55542183], [88.94049072, 22.55521202], [88.94084167, 22.55495644], [88.94121552, 22.5547142], [88.94159698, 22.55449295], [88.94200897, 22.55438042], [88.94242096, 22.55425072], [88.94281769, 22.55410004], [88.9431076, 22.55379295], [88.94345093, 22.55355263], [88.94380951, 22.55337334], [88.94421387, 22.55327415], [88.94468689, 22.55312347], [88.94525909, 22.55306435], [88.94586945, 22.55300713], [88.94642639, 22.55278206], [88.94698334, 22.55255127], [88.94763947, 22.55247307], [88.94824982, 22.55232048], [88.94882202, 22.55223274], [88.94940948, 22.55214119], [88.94998932, 22.55204201], [88.95054626, 22.5519619], [88.95106506, 22.55194664], [88.95155334, 22.55194473], [88.95201874, 22.55190468], [88.95244598, 22.55174828], [88.95288849, 22.55167961], [88.95333862, 22.55166054], [88.95376587, 22.55161095], [88.954216, 22.55153465], [88.95472717, 22.55149841], [88.95530701, 22.55149269], [88.95594788, 22.55137253], [88.95658112, 22.55117035], [88.95719147, 22.55094147], [88.95775604, 22.55067635], [88.95827484, 22.55039406], [88.95876312, 22.55012321], [88.95913696, 22.54980469], [88.95944214, 22.54942131], [88.95970917, 22.54902077], [88.95996094, 22.54862022], [88.9601059, 22.54815102], [88.960289, 22.54780006], [88.96045685, 22.547472], [88.96060944, 22.54715157], [88.96089935, 22.5468998], [88.96109772, 22.54655457], [88.96121216, 22.54626656], [88.96125031, 22.546175], [88.96138763, 22.54583168], [88.9615097, 22.54548073], [88.96160889, 22.54510117], [88.96170807, 22.54466057], [88.96190643, 22.54421806], [88.9620285, 22.54368019], [88.96222687, 22.54317474], [88.96250153, 22.54268074], [88.96274567, 22.54218483], [88.96287537, 22.54162407], [88.9630127, 22.54107475], [88.96315765, 22.54055405], [88.96328735, 22.54006004], [88.96337891, 22.53957367], [88.96353149, 22.53913689], [88.96367645, 22.53868484], [88.96388245, 22.5382328], [88.96406555, 22.53776741], [88.96420288, 22.53730392], [88.96435547, 22.53691292], [88.96443939, 22.53653908], [88.96453857, 22.53616142], [88.96472168, 22.53577232], [88.96492767, 22.53531075], [88.96504211, 22.53471184], [88.96523285, 22.53408623], [88.96528625, 22.53339767], [88.96537781, 22.53271294], [88.96555328, 22.5320549], [88.96568298, 22.53141975], [88.96579742, 22.53085327], [88.96586609, 22.53030968], [88.96599579, 22.5298233], [88.96611023, 22.52931023], [88.96621704, 22.52880478], [88.96640015, 22.52833366], [88.96660614, 22.52786064], [88.96669769, 22.52729225], [88.96691132, 22.52676392], [88.96703339, 22.52618408], [88.96718597, 22.52561188], [88.9672699, 22.52498245], [88.967453, 22.52438927], [88.96749878, 22.52380943], [88.9675293, 22.5233326], [88.96762085, 22.52295876], [88.96774292, 22.5225811], [88.96775818, 22.52215195], [88.96776581, 22.52166939], [88.9677887, 22.52115059], [88.96785736, 22.52065086], [88.96800995, 22.52025032], [88.96806335, 22.51984215], [88.96805573, 22.51944923], [88.96805573, 22.51904869], [88.9681015, 22.51860809], [88.96827698, 22.51815224], [88.96835327, 22.51758957], [88.96848297, 22.5170002], [88.96864319, 22.51638985], [88.96879578, 22.51579094], [88.96891785, 22.51521111], [88.96903992, 22.51470375], [88.96915436, 22.51418114], [88.96923828, 22.51375008], [88.96939087, 22.51342201], [88.96944427, 22.5130825], [88.96947479, 22.51273537], [88.96961212, 22.51247025], [88.96972656, 22.51218987], [88.969841, 22.51190567], [88.96993256, 22.51157188], [88.96997833, 22.51116943], [88.97000122, 22.51068115], [88.97000122, 22.51013184], [88.9699707, 22.50955009], [88.969841, 22.50901222], [88.96977234, 22.50859833], [88.96971893, 22.50694466], [88.97000122, 22.50666618], [88.97000122, 22.50611305], [88.97027588, 22.50583076], [88.97027588, 22.50499725], [88.97055817, 22.50472069], [88.97055817, 22.50388718], [88.97083282, 22.50361061], [88.97083282, 22.50139046], [88.97110748, 22.50111198], [88.97110748, 22.50028038], [88.97138977, 22.50000191], [88.97138977, 22.49889183], [88.97164917, 22.49860954], [88.97166443, 22.49833488], [88.97194672, 22.49805641], [88.97193909, 22.49749947], [88.97222137, 22.4972229], [88.97222137, 22.49694443], [88.97250366, 22.49666786], [88.97249603, 22.49640083], [88.9733429, 22.49556351], [88.9733429, 22.49528122], [88.97360992, 22.49500275], [88.97360992, 22.49472237], [88.97416687, 22.49416924], [88.97416687, 22.49389076], [88.97444153, 22.49361229], [88.97444153, 22.49333954], [88.97499847, 22.49278069], [88.97499847, 22.49250221], [88.97528076, 22.49221992], [88.97528076, 22.49194527], [88.97583008, 22.49139214], [88.97583008, 22.49110985], [88.97611237, 22.49083328], [88.97611237, 22.49055862], [88.97666931, 22.48999977], [88.97666931, 22.48944283], [88.97694397, 22.48916626], [88.97693634, 22.4880619], [88.97721863, 22.48777962], [88.97721863, 22.48611259], [88.97750092, 22.48583031], [88.97750092, 22.48500061], [88.9777832, 22.48472023], [88.97777557, 22.48388863], [88.97807312, 22.48361015], [88.97805786, 22.48333359], [88.97833252, 22.48305702], [88.97833252, 22.48250008], [88.97860718, 22.4822197], [88.97861481, 22.48194695], [88.97888947, 22.48167038], [88.97888947, 22.48140144], [88.97944641, 22.48083305], [88.97944641, 22.4805584], [88.97972107, 22.48028183], [88.97972107, 22.48000145], [88.98000336, 22.47972298], [88.98000336, 22.4794445], [88.98055267, 22.47889137], [88.98055267, 22.4786129], [88.98194122, 22.47722054], [88.98222351, 22.47722435], [88.98305511, 22.47638893], [88.98332977, 22.47639275], [88.98361206, 22.47611046], [88.98416901, 22.47611046], [88.98443604, 22.47583199], [88.98472595, 22.47583771], [88.98500061, 22.47555542], [88.98660278, 22.47555542], [88.98722076, 22.47556114], [88.98750305, 22.47527122], [88.98777771, 22.47527885], [88.98891449, 22.47414207], [88.98945618, 22.47360039], [88.99111176, 22.47194481], [88.99111176, 22.47166634], [88.9916687, 22.47110939], [88.9916687, 22.47083473], [88.99277496, 22.46972466], [88.99305725, 22.46972466], [88.99500275, 22.46777916], [88.99500275, 22.46722221], [88.9952774, 22.46694374], [88.99500275, 22.46666908], [88.99500275, 22.46528053], [88.99472046, 22.46500206], [88.99472046, 22.46417046], [88.9944458, 22.46389198], [88.9944458, 22.46304131], [88.99416351, 22.46277618], [88.99415588, 22.46222115], [88.99388885, 22.46194458], [88.99388885, 22.46138954], [88.99360657, 22.46111107], [88.99360657, 22.46000099], [88.99333191, 22.45972252], [88.99333191, 22.45916939], [88.99307251, 22.45889091], [88.99307251, 22.45861244], [88.99333191, 22.45833206], [88.99333191, 22.4580555], [88.99307251, 22.45778084], [88.99307251, 22.45694351], [88.99333191, 22.45666695], [88.99333191, 22.45555115], [88.99305725, 22.4552784], [88.99307251, 22.45444107], [88.99277496, 22.45416641], [88.9927597, 22.45389175], [88.99250031, 22.45361137], [88.99250031, 22.4533329], [88.99194336, 22.45278168], [88.99194336, 22.4525013], [88.9916687, 22.45222282], [88.9916687, 22.45194435], [88.99111176, 22.45139122], [88.99111176, 22.45083046], [88.9908371, 22.4505558], [88.9908371, 22.45028114], [88.98972321, 22.44916534], [88.98860931, 22.44805527], [88.98860931, 22.44778252], [88.98832703, 22.44750023], [88.98832703, 22.44639015], [88.98805237, 22.44611168], [88.98805237, 22.44555473], [88.98833466, 22.44528008], [88.98832703, 22.44305992], [88.98860931, 22.44278145], [88.98860931, 22.44167137], [88.9888916, 22.4413929], [88.9888916, 22.44083023], [88.98916626, 22.44055557], [88.98916626, 22.44000053], [88.98944092, 22.43972015], [88.98916626, 22.43944359], [88.98999786, 22.43861198], [88.98999786, 22.43833351], [88.99028015, 22.43805504], [88.99028015, 22.43778038], [88.99415588, 22.43388939], [88.99429321, 22.43388939], [88.9944458, 22.43388939], [88.99555206, 22.43278313], [88.99581909, 22.43278313], [88.9963913, 22.43222237], [88.99666595, 22.43222237], [88.99694824, 22.43194389], [88.9972229, 22.43194389], [88.99777985, 22.43139076], [88.99804688, 22.43139076], [88.99804688, 22.43111229], [88.99833679, 22.43083191], [88.99833679, 22.43055534], [88.99861145, 22.43029213], [88.99861145, 22.42972183], [88.99833679, 22.42944527], [88.99833679, 22.42917061], [88.99804688, 22.42889023], [88.99777985, 22.42889023], [88.99758911, 22.42870331], [88.99749756, 22.42861176], [88.99694824, 22.42861366], [88.99666595, 22.42833519], [88.99610901, 22.42833519], [88.99583435, 22.42805672], [88.9952774, 22.42805672], [88.99500275, 22.42777824], [88.9944458, 22.42778015], [88.99430847, 22.42764282], [88.99417114, 22.42750168], [88.99388885, 22.42721939], [88.9936142, 22.42721939], [88.99333191, 22.42694664], [88.99305725, 22.42694664], [88.99278259, 22.42667389], [88.99250031, 22.4263916], [88.9920578, 22.4263916], [88.99194336, 22.4263916], [88.9916687, 22.42610931], [88.99137878, 22.42614174], [88.9908371, 22.4255619], [88.99069214, 22.42555809], [88.99054718, 22.4255619], [88.99001312, 22.42500114], [88.98972321, 22.42500114], [88.98916626, 22.42444038], [88.9888916, 22.4244442], [88.98833466, 22.42389107], [88.98805237, 22.42389107], [88.98583221, 22.42167091], [88.98583221, 22.42139244], [88.98472595, 22.42028236], [88.98472595, 22.42000008], [88.98166656, 22.41694069], [88.98139191, 22.4169445], [88.98110962, 22.41666603], [88.9808197, 22.41666985], [88.98055267, 22.41639137], [88.97915649, 22.41639137], [88.97888947, 22.4161129], [88.97805786, 22.4161129], [88.97777557, 22.41583443], [88.97666931, 22.41583443], [88.97657776, 22.41574287], [88.97638702, 22.41555595], [88.97611237, 22.41555595], [88.97583008, 22.41583443], [88.97555542, 22.41555595], [88.97528076, 22.41555977], [88.97499847, 22.4152813], [88.97471619, 22.4152813], [88.97444153, 22.41499138], [88.97416687, 22.41500282], [88.97389221, 22.41472435], [88.97360992, 22.41472435], [88.97333527, 22.41444588], [88.97277832, 22.41444588], [88.97250366, 22.4141674], [88.97222137, 22.41417122], [88.97193909, 22.41389275], [88.97110748, 22.41389275], [88.97083282, 22.41360855], [88.97027588, 22.41360855], [88.97000122, 22.41333008], [88.96971893, 22.4133358], [88.96944427, 22.41305733], [88.96916962, 22.41305923], [88.9688797, 22.41278267], [88.96861267, 22.41278267], [88.96806335, 22.41222191], [88.96778107, 22.41222191], [88.96722412, 22.41167068], [88.96694183, 22.41167259], [88.96639252, 22.41111183], [88.96611023, 22.41111183], [88.96569824, 22.41069984], [88.96527863, 22.41027641], [88.96499634, 22.41028023], [88.96472168, 22.41000175], [88.96472168, 22.40971947], [88.96416473, 22.40916634], [88.9641571, 22.40889168], [88.96389008, 22.40860939], [88.96389008, 22.40833282], [88.96360779, 22.40805435], [88.96360779, 22.4077816], [88.96333313, 22.40750313], [88.96333313, 22.40667152], [88.96305847, 22.40639305], [88.96305847, 22.40583229], [88.96333313, 22.40555573], [88.96333313, 22.40472221], [88.96389008, 22.40416908], [88.96389008, 22.40389061], [88.96360779, 22.40361214], [88.9641571, 22.40361214], [88.96749878, 22.40028191], [88.96749878, 22.39999199], [88.96778107, 22.39972305], [88.96778107, 22.39944649], [88.96805573, 22.39916992], [88.96806335, 22.39888763], [88.96833038, 22.39860916], [88.96833038, 22.3983326], [88.96861267, 22.39805984], [88.96861267, 22.39777946], [88.9688797, 22.39749908], [88.9688797, 22.39722252], [88.96916962, 22.39694405], [88.96916962, 22.39666939], [88.96943665, 22.39639091], [88.96943665, 22.39611244], [88.97000122, 22.39556313], [88.97000122, 22.39528084], [88.97027588, 22.39500237], [88.97027588, 22.39389229], [88.97000122, 22.39361], [88.97000122, 22.39333344], [88.96944427, 22.3927784], [88.9688797, 22.39278221], [88.96861267, 22.39249992], [88.96721649, 22.39249992], [88.96694183, 22.39222145], [88.96666718, 22.39222145], [88.96611023, 22.39166832], [88.96611023, 22.39138985], [88.96499634, 22.39027977], [88.96499634, 22.3900013], [88.96472168, 22.38972282], [88.96472168, 22.3880558], [88.96499634, 22.38777733], [88.96499634, 22.38721848], [88.96527863, 22.38694382], [88.96527863, 22.38666725], [88.96555328, 22.38639259], [88.96555328, 22.38555908], [88.9658432, 22.38528252], [88.96555328, 22.38501167], [88.96555328, 22.38417244], [88.96527863, 22.38388824], [88.96527863, 22.38195229], [88.96499634, 22.38167], [88.96499634, 22.38111305], [88.96472168, 22.38083076], [88.96472168, 22.38027763], [88.96444702, 22.38000488], [88.96444702, 22.37944221], [88.96416473, 22.37916756], [88.9641571, 22.37611389], [88.96444702, 22.37583351], [88.96444702, 22.37388992], [88.9641571, 22.37361145], [88.96416473, 22.37305641], [88.96389008, 22.37278175], [88.96389008, 22.37249756], [88.96360779, 22.37221909], [88.96360779, 22.37194443], [88.96333313, 22.37166977], [88.96333313, 22.37138748], [88.96250153, 22.3705616], [88.96250153, 22.37028313], [88.96193695, 22.36972237], [88.96194458, 22.36944389], [88.96166992, 22.36916924], [88.96166992, 22.36861229], [88.96138763, 22.36833], [88.96138763, 22.36805534], [88.95833588, 22.36499977], [88.95804596, 22.36499977], [88.95777893, 22.3647213], [88.95722198, 22.3647213], [88.9569397, 22.36499977], [88.95639038, 22.36499977], [88.95583344, 22.36555672], [88.95583344, 22.36583328], [88.95555878, 22.36610985], [88.95555878, 22.36639214], [88.9539032, 22.36806297], [88.95361328, 22.36805534], [88.95333099, 22.36833382], [88.95305634, 22.36833], [88.95276642, 22.36861229], [88.9522171, 22.36861229], [88.95194244, 22.36889076], [88.95083618, 22.36889076], [88.95054626, 22.36917305], [88.94972229, 22.36916924], [88.94944763, 22.36944389], [88.9486084, 22.36944389], [88.94833374, 22.36972237], [88.94805908, 22.36972237], [88.94776917, 22.37001228], [88.9474411, 22.37001038], [88.94721985, 22.37001228], [88.94695282, 22.37028313], [88.9466629, 22.37028313], [88.94555664, 22.37138748], [88.94555664, 22.37444496], [88.9458313, 22.37472153], [88.9458313, 22.37528038], [88.94611359, 22.37555504], [88.94610596, 22.37611389], [88.94638824, 22.37639046], [88.94638824, 22.37778473], [88.9466629, 22.37806129], [88.9466629, 22.37861061], [88.94695282, 22.37889481], [88.94694519, 22.3805542], [88.9466629, 22.38083076], [88.9466629, 22.38139153], [88.9458313, 22.38222313], [88.9458313, 22.3825016], [88.94555664, 22.38278008], [88.94527435, 22.38278008], [88.94472504, 22.38333321], [88.94444275, 22.38333321], [88.94416809, 22.38361168], [88.9438858, 22.38361168], [88.94361115, 22.38388824], [88.94333649, 22.38388824], [88.94304657, 22.38417244], [88.94251251, 22.38417244], [88.9422226, 22.38445091], [88.9419632, 22.38445091], [88.94139099, 22.38501167], [88.9411087, 22.38501167], [88.9394455, 22.38666725], [88.93945313, 22.38721848], [88.93916321, 22.38750267], [88.93916321, 22.38777733], [88.93945313, 22.38805008], [88.9394455, 22.39055824], [88.93916321, 22.39083481], [88.93916321, 22.39166832], [88.93888855, 22.39194489], [88.93889618, 22.39249992], [88.93723297, 22.39418221], [88.93694305, 22.39416695], [88.93527985, 22.39583015], [88.93527985, 22.39639091], [88.93611145, 22.39722252], [88.93638611, 22.39722252], [88.9366684, 22.39749908], [88.93694305, 22.39749908], [88.93723297, 22.39777946], [88.93781281, 22.39777946], [88.93805695, 22.39777946], [88.9383316, 22.39806175], [88.93861389, 22.39805984], [88.93888855, 22.3983326], [88.93972015, 22.3983326], [88.94000244, 22.39860916], [88.9402771, 22.39860916], [88.94055176, 22.39888763], [88.94083405, 22.39888763], [88.94166565, 22.39972305], [88.94167328, 22.39999199], [88.9419632, 22.40028191], [88.94194794, 22.40277863], [88.94167328, 22.40305138], [88.94167328, 22.40389061], [88.94139099, 22.40416908], [88.94139099, 22.40472221], [88.9411087, 22.40500069], [88.9411087, 22.40583229], [88.94082642, 22.40612221], [88.94082642, 22.40750313], [88.9411087, 22.4077816], [88.9411087, 22.40805435], [88.94082642, 22.40833092], [88.94082642, 22.41000175], [88.94055176, 22.41028023], [88.94055176, 22.41055489], [88.94083405, 22.41083336], [88.94055176, 22.41111183], [88.94055176, 22.41639137], [88.9402771, 22.41666985], [88.9402771, 22.41722488], [88.94020844, 22.4185009], [88.94049072, 22.41902733], [88.94055939, 22.41905403], [88.94065094, 22.41909218], [88.94094086, 22.41930389], [88.94123077, 22.41937065], [88.94164276, 22.41943359], [88.94293976, 22.41950035], [88.94380188, 22.41949654], [88.94451904, 22.4195652], [88.94573212, 22.41956139], [88.94631195, 22.41976547], [88.94660187, 22.42003059], [88.94660187, 22.42057228], [88.94631195, 22.42064095], [88.94451904, 22.42063713], [88.94380188, 22.42070198], [88.94300842, 22.42063713], [88.94207764, 22.42064095], [88.94167328, 22.42056084], [88.94136047, 22.42054939], [88.94088745, 22.42047119], [88.94043732, 22.42025948], [88.94001007, 22.41994286], [88.9397049, 22.41948509], [88.9394455, 22.41901016], [88.93923187, 22.41855049], [88.93911743, 22.41803169], [88.93896484, 22.41753578], [88.93894958, 22.41700172], [88.93906403, 22.41644859], [88.93908691, 22.41586113], [88.93901825, 22.41527176], [88.9391098, 22.41465187], [88.93916321, 22.41402245], [88.93916321, 22.41337013], [88.93916321, 22.41267967], [88.93916321, 22.41193199], [88.93916321, 22.41119766], [88.93917084, 22.41045952], [88.93917847, 22.40973091], [88.93924713, 22.4090023], [88.93939209, 22.40830421], [88.9394455, 22.40759087], [88.93950653, 22.40693474], [88.93967438, 22.40639305], [88.9397583, 22.40588188], [88.93991852, 22.40544319], [88.94004059, 22.40493965], [88.94022369, 22.4044342], [88.9402771, 22.40383339], [88.94031525, 22.40320206], [88.9404068, 22.40258217], [88.94036102, 22.40199089], [88.94024658, 22.40139008], [88.94000244, 22.40084648], [88.93965149, 22.40036964], [88.93920135, 22.39996147], [88.93874359, 22.39958382], [88.9382782, 22.39927864], [88.93776703, 22.3990612], [88.93740845, 22.3989315], [88.93723297, 22.39886856], [88.9367218, 22.3986721], [88.93615723, 22.39855194], [88.93576813, 22.3983326], [88.93547058, 22.3980999], [88.93523407, 22.39791298], [88.93500519, 22.39774132], [88.93476868, 22.39751244], [88.93448639, 22.39721107], [88.93421173, 22.39683342], [88.93404388, 22.39637566], [88.9341507, 22.39586258], [88.9343338, 22.39538383], [88.93450928, 22.39495659], [88.93473816, 22.39459038], [88.93499756, 22.39424706], [88.93528748, 22.39391136], [88.93564606, 22.39361], [88.93608093, 22.39332962], [88.93654633, 22.39302254], [88.93702698, 22.39265251], [88.93740845, 22.39214325], [88.93766785, 22.39153099], [88.93776703, 22.3908596], [88.93784332, 22.3902607], [88.93797302, 22.38977242], [88.93802643, 22.38931274], [88.93799591, 22.38886452], [88.93790436, 22.38841057], [88.93801117, 22.38792038], [88.93811798, 22.3873806], [88.93826294, 22.38689995], [88.93840027, 22.38642311], [88.93860626, 22.3860302], [88.93882751, 22.3856411], [88.93912506, 22.38531494], [88.93942261, 22.3849926], [88.93972778, 22.38467979], [88.94004822, 22.38440132], [88.94041443, 22.38414574], [88.94078064, 22.38386345], [88.94116211, 22.38358116], [88.94159698, 22.38332176], [88.94205475, 22.38305855], [88.94254303, 22.38279152], [88.9430542, 22.38252831], [88.94356537, 22.38223839], [88.94397736, 22.3818531], [88.94436646, 22.38144112], [88.94469452, 22.38096809], [88.94493103, 22.38043022], [88.94499207, 22.37982941], [88.94499969, 22.37920952], [88.94499207, 22.37857819], [88.94493866, 22.37793541], [88.94483185, 22.37751961], [88.94477081, 22.37729454], [88.94467163, 22.37658501], [88.94445801, 22.37592888], [88.94429016, 22.37529373], [88.94418335, 22.37469864], [88.94416046, 22.37413216], [88.94412994, 22.37360191], [88.94394684, 22.37315178], [88.94373322, 22.37276268], [88.9438324, 22.37250328], [88.94393158, 22.37215042], [88.94412994, 22.37173843], [88.94431305, 22.37125206], [88.94449615, 22.37080383], [88.9447403, 22.37042046], [88.94502258, 22.37008095], [88.94535828, 22.36978531], [88.94573212, 22.36952019], [88.9460907, 22.36919022], [88.9464798, 22.36889458], [88.94688416, 22.36861992], [88.9473114, 22.36841011], [88.94779968, 22.36827278], [88.94808197, 22.36815071], [88.94825745, 22.3680706], [88.9487381, 22.36792183], [88.94924164, 22.36779213], [88.94975281, 22.36770439], [88.9502182, 22.36751747], [88.95067596, 22.36736107], [88.95114899, 22.3672123], [88.95159912, 22.367033], [88.95209503, 22.36691093], [88.95252228, 22.36669922], [88.95294189, 22.36654091], [88.95320129, 22.36623955], [88.95336914, 22.36589241], [88.95347595, 22.36553192], [88.95345306, 22.36514091], [88.9532547, 22.3647728], [88.95297241, 22.36437225], [88.95262146, 22.36401558], [88.95223999, 22.3637104], [88.95189667, 22.36341476], [88.95155334, 22.36316299], [88.95122528, 22.36289978], [88.95089722, 22.36256981], [88.95058441, 22.36222458], [88.95037842, 22.36175728], [88.95034027, 22.36164284], [88.95020294, 22.36122894], [88.94992828, 22.36074829], [88.94970703, 22.36026192], [88.94953156, 22.35980415], [88.94940948, 22.35939598], [88.94924164, 22.35909081], [88.94917297, 22.35878372], [88.94913483, 22.35851669], [88.94898224, 22.35829163], [88.94889069, 22.35777664], [88.94889069, 22.35638809], [88.9486084, 22.35611153], [88.9486084, 22.35583305], [88.9486084, 22.35553169], [88.9486084, 22.35516167], [88.94862366, 22.35481453], [88.94870758, 22.35449219], [88.94883728, 22.3541851], [88.94882202, 22.35383034], [88.94884491, 22.35347748], [88.94895172, 22.35313225], [88.9491272, 22.3527813], [88.94917297, 22.35233307], [88.94923401, 22.35183525], [88.94940186, 22.35129929], [88.94944763, 22.35072136], [88.94947815, 22.3501091], [88.94960785, 22.34955978], [88.94973755, 22.34905052], [88.94986725, 22.34863091], [88.94999695, 22.34827232], [88.95011902, 22.34794044], [88.95024872, 22.3476162], [88.95027924, 22.34724236], [88.95027924, 22.34680939], [88.95027924, 22.34634209], [88.95031738, 22.34586143], [88.95049286, 22.34544373], [88.95058441, 22.34498024], [88.950737, 22.34453011], [88.95078278, 22.34404182], [88.95068359, 22.34350777], [88.95052338, 22.34291267], [88.95027161, 22.34229851], [88.94998932, 22.34169006], [88.94965363, 22.34115982], [88.94931793, 22.34070015], [88.94908142, 22.34024239], [88.9487915, 22.33987236], [88.94859314, 22.33934021], [88.948349, 22.3388195], [88.94815063, 22.33829117], [88.94798279, 22.33773232], [88.94776154, 22.33722115], [88.94753265, 22.33675957], [88.94735718, 22.33627129], [88.94721985, 22.3357296], [88.947052, 22.33518982], [88.9468689, 22.33465195], [88.9466629, 22.33415413], [88.94646454, 22.3336792], [88.94626617, 22.33321381], [88.94610596, 22.33276176], [88.94592285, 22.33230019], [88.94580841, 22.3318615], [88.94562531, 22.33142662], [88.94553375, 22.3309269], [88.94539642, 22.33045006], [88.94528961, 22.32999229], [88.94525146, 22.32954979], [88.94512939, 22.32917976], [88.94499969, 22.32883263], [88.94496918, 22.32845116], [88.94484711, 22.32809258], [88.94468689, 22.32764244], [88.94462585, 22.32707405], [88.94463348, 22.32641029], [88.94470215, 22.3257618], [88.94484711, 22.325243], [88.94497681, 22.32480049], [88.94509888, 22.32444954], [88.94523621, 22.32415009], [88.9453125, 22.3237896], [88.94546509, 22.32341957], [88.94563293, 22.32297325], [88.9458313, 22.32252312], [88.94606018, 22.32209206], [88.94617462, 22.32155609], [88.9463501, 22.32102013], [88.94641876, 22.32043457], [88.94651794, 22.31985283], [88.94642639, 22.31924248], [88.94638062, 22.31866646], [88.94632721, 22.31816483], [88.94618988, 22.31773186], [88.94611359, 22.31731033], [88.94602203, 22.31689262], [88.94584656, 22.3165226], [88.9457016, 22.31611061], [88.94554901, 22.31567955], [88.94538879, 22.31526566], [88.94525909, 22.31485939], [88.94509888, 22.31451988], [88.9449234, 22.31424522], [88.94476318, 22.31398201], [88.94467926, 22.31367493], [88.94455719, 22.31339073], [88.94439697, 22.31313133], [88.94420624, 22.31289291], [88.94409943, 22.31259918], [88.94393921, 22.31232834], [88.94387817, 22.31200218], [88.94377136, 22.31169319], [88.94361877, 22.31139183], [88.94346619, 22.31104088], [88.94326782, 22.31065178], [88.94290924, 22.31031227], [88.94242096, 22.31005287], [88.94216919, 22.30992126], [88.94194794, 22.30988121], [88.94167328, 22.30988121], [88.94129944, 22.31002235], [88.94094086, 22.31017113], [88.9405365, 22.31028366], [88.94013977, 22.31036949], [88.93969727, 22.31043053], [88.93927765, 22.31053925], [88.93887329, 22.31062126], [88.93852234, 22.31079292], [88.93811035, 22.31083107], [88.93767548, 22.31083488], [88.9372406, 22.31083488], [88.93681335, 22.31083488], [88.9355545, 22.31083488], [88.93513489, 22.31083488], [88.93471527, 22.31083488], [88.93429565, 22.31083488], [88.93386078, 22.31086159], [88.9334259, 22.31100273], [88.93296051, 22.31110382], [88.93247986, 22.31117058], [88.93209839, 22.31139183], [88.93173981, 22.3116703], [88.93138885, 22.31194115], [88.9310379, 22.31219292], [88.93064117, 22.31240273], [88.93023682, 22.31255913], [88.92985535, 22.31274223], [88.92942047, 22.31285286], [88.92906189, 22.31310844], [88.92867279, 22.31331062], [88.9283371, 22.31359291], [88.92805481, 22.31383514], [88.92778015, 22.31406975], [88.92751312, 22.3143425], [88.92727661, 22.31466103], [88.92700958, 22.31495094], [88.92680359, 22.31526566], [88.9265976, 22.31553459], [88.92637634, 22.3157711], [88.92611694, 22.31598854], [88.9258728, 22.31624031], [88.92565155, 22.31657028], [88.92542267, 22.31693077], [88.92511749, 22.31726265], [88.92469025, 22.31755257], [88.92428589, 22.31792259], [88.92388916, 22.31829453], [88.92352295, 22.31871986], [88.92317963, 22.3192749], [88.92285919, 22.31990242], [88.92247772, 22.32043457], [88.92218018, 22.32087135], [88.92184448, 22.32121849], [88.92153168, 22.32155418], [88.92133331, 22.32196426], [88.92105865, 22.32229042], [88.92081451, 22.32267952], [88.92051697, 22.32310295], [88.92019653, 22.32357979], [88.91983032, 22.32407379], [88.91950989, 22.32465172], [88.91919708, 22.32521248], [88.91884613, 22.32560158], [88.91844177, 22.32589149], [88.91810608, 22.32621956], [88.91783905, 22.32658958], [88.91750336, 22.32691193], [88.91713715, 22.32729149], [88.91673279, 22.32772255], [88.91628265, 22.32817459], [88.91578674, 22.3285923], [88.91529083, 22.32888985], [88.91487122, 22.32917213], [88.91452789, 22.32945442], [88.91421509, 22.32975006], [88.91387939, 22.33008385], [88.91349792, 22.33045006], [88.91301727, 22.33084297], [88.91252899, 22.33122063], [88.91213226, 22.33161163], [88.91172791, 22.33189964], [88.91139984, 22.33221245], [88.91105652, 22.33247185], [88.91062927, 22.33263206], [88.9102478, 22.33291817]]]]}}]}\",\"selected\":{\"id\":\"10739\"},\"selection_policy\":{\"id\":\"10740\"}},\"id\":\"10188\",\"type\":\"GeoJSONDataSource\"},{\"attributes\":{},\"id\":\"10753\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"center\":[{\"id\":\"10328\"},{\"id\":\"10332\"}],\"height\":400,\"renderers\":[{\"id\":\"10348\"}],\"title\":{\"id\":\"10315\"},\"toolbar\":{\"id\":\"10338\"},\"toolbar_location\":null,\"width\":400,\"x_range\":{\"id\":\"10317\"},\"x_scale\":{\"id\":\"10321\"},\"y_range\":{\"id\":\"10319\"},\"y_scale\":{\"id\":\"10323\"}},\"id\":\"10314\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{\"text\":\"MORT from total PM\\u2082.\\u2085 exposure (India = -348,000 deaths, -29%)\"},\"id\":\"10315\",\"type\":\"Title\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.7},\"fill_color\":{\"field\":\"mort_tpm25_6cod_mean_total\",\"transform\":{\"id\":\"10313\"}},\"line_color\":{\"value\":\"grey\"},\"line_width\":{\"value\":0.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"10346\",\"type\":\"Patches\"},{\"attributes\":{},\"id\":\"10317\",\"type\":\"DataRange1d\"},{\"attributes\":{},\"id\":\"10323\",\"type\":\"LinearScale\"},{\"attributes\":{},\"id\":\"10248\",\"type\":\"BasicTicker\"},{\"attributes\":{},\"id\":\"10319\",\"type\":\"DataRange1d\"},{\"attributes\":{\"formatter\":{\"id\":\"10759\"},\"major_label_policy\":{\"id\":\"10758\"},\"ticker\":{\"id\":\"10330\"}},\"id\":\"10329\",\"type\":\"LinearAxis\"},{\"attributes\":{},\"id\":\"10321\",\"type\":\"LinearScale\"},{\"attributes\":{\"formatter\":{\"id\":\"10756\"},\"major_label_policy\":{\"id\":\"10755\"},\"ticker\":{\"id\":\"10326\"}},\"id\":\"10325\",\"type\":\"LinearAxis\"},{\"attributes\":{},\"id\":\"10326\",\"type\":\"BasicTicker\"},{\"attributes\":{\"axis\":{\"id\":\"10325\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"10328\",\"type\":\"Grid\"}],\"root_ids\":[\"10356\"]},\"title\":\"Bokeh Application\",\"version\":\"2.3.0\"}};\n",
       "  var render_items = [{\"docid\":\"933e862f-4847-4fcb-955c-b9f3426cff09\",\"root_ids\":[\"10356\"],\"roots\":{\"10356\":\"52176f4a-25f4-47a5-b925-b7ef3911841a\"}}];\n",
       "  root.Bokeh.embed.embed_items_notebook(docs_json, render_items);\n",
       "\n",
       "  }\n",
       "  if (root.Bokeh !== undefined) {\n",
       "    embed_document(root);\n",
       "  } else {\n",
       "    var attempts = 0;\n",
       "    var timer = setInterval(function(root) {\n",
       "      if (root.Bokeh !== undefined) {\n",
       "        clearInterval(timer);\n",
       "        embed_document(root);\n",
       "      } else {\n",
       "        attempts++;\n",
       "        if (attempts > 100) {\n",
       "          clearInterval(timer);\n",
       "          console.log(\"Bokeh: ERROR: Unable to run BokehJS code because BokehJS library is missing\");\n",
       "        }\n",
       "      }\n",
       "    }, 10, root)\n",
       "  }\n",
       "})(window);"
      ],
      "application/vnd.bokehjs_exec.v0+json": ""
     },
     "metadata": {
      "application/vnd.bokehjs_exec.v0+json": {
       "id": "10356"
      }
     },
     "output_type": "display_data"
    }
   ],
   "source": [
    "import pandas as pd\n",
    "import geopandas as gpd\n",
    "from bokeh.layouts import column, row\n",
    "from bokeh.models import (ColumnDataSource, CustomJS, LinearColorMapper, \n",
    "                          GeoJSONDataSource, Panel, Tabs, \n",
    "                          BasicTicker, ColorBar, Select)\n",
    "from bokeh.plotting import figure\n",
    "from bokeh.themes import Theme\n",
    "from bokeh.io import show, output_notebook, reset_output\n",
    "from bokeh.palettes import Viridis10, BrBG10\n",
    "output_notebook()\n",
    "\n",
    "# --- data --- \n",
    "path = 'data/'\n",
    "scenarios = ['BASELINE', 'ALLLPG']#, 'URB15', 'EMIS50', 'STATE50']\n",
    "gdf = gpd.read_file(path + 'gadm36_IND_1.shp')\n",
    "geosources = {}\n",
    "for scenario in scenarios:\n",
    "    df = pd.read_csv(path + 'Conibear_et_al_2020_supp-data_' + scenario + '.csv')[0:34]\n",
    "    df.rename(columns={'Unnamed: 0': 'geo-id'}, inplace=True)\n",
    "    df['scenario'] = scenario\n",
    "    gdf_merged = gdf.merge(df, left_on='NAME_1', right_on='location')\n",
    "    geosource = GeoJSONDataSource(geojson=gdf_merged.to_json())\n",
    "    geosources.update({scenario: geosource})\n",
    "    \n",
    "# --- formating --- \n",
    "df_formats = {}\n",
    "\n",
    "plot_labels = [\n",
    "    \"Ambient PM\\u2082.\\u2085 concentrations\",\n",
    "    \"Household PM\\u2082.\\u2085 concentrations, females\",\n",
    "    \"Household PM\\u2082.\\u2085 concentrations, males\",\n",
    "    \"Household PM\\u2082.\\u2085 concentrations, children\",\n",
    "    \"MORT from total PM\\u2082.\\u2085 exposure\",\n",
    "    \"MORT from ambient PM\\u2082.\\u2085 exposure\",\n",
    "    \"MORT from household PM\\u2082.\\u2085 exposure\",\n",
    "    \"DALYs rate from total PM\\u2082.\\u2085 exposure\",\n",
    "    \"DALYs rate from ambient PM\\u2082.\\u2085 exposure\",\n",
    "    \"DALYs rate from household PM\\u2082.\\u2085 exposure\"\n",
    "]\n",
    "plot_variables = [\n",
    "    'apm25_popweighted',\n",
    "    'hpm25_female_popweighted',\n",
    "    'hpm25_male_popweighted',\n",
    "    'hpm25_child_popweighted',\n",
    "    'mort_tpm25_6cod_mean_total',\n",
    "    'mort_apm25_6cod_mean_total',\n",
    "    'mort_hpm25_6cod_mean_total',\n",
    "    'dalys_tpm25_rate_6cod_mean_total',\n",
    "    'dalys_apm25_rate_6cod_mean_total',\n",
    "    'dalys_hpm25_rate_6cod_mean_total'\n",
    "]\n",
    "min_values_abs = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0]\n",
    "max_values_abs = [100, 300, 300, 300, 150000, 150000, 150000, 3500, 3500, 3500]\n",
    "min_values_diff = [-50, -300, -300, -300, -50000, -50000, -50000, -1500, -1500, -1500]\n",
    "max_values_diff = [50, 300, 300, 300, 50000, 50000, 50000, 1500, 1500, 1500]\n",
    "df_baseline = pd.read_csv(path + 'Conibear_et_al_2020_supp-data_BASELINE.csv')\n",
    "\n",
    "for scenario in scenarios:\n",
    "    df = pd.read_csv(path + 'Conibear_et_al_2020_supp-data_' + scenario + '.csv')\n",
    "    if scenario == 'BASELINE':\n",
    "        plot_title = [\n",
    "            ('Ambient ' + u'PM\\u2082.\\u2085' + ' concentration', '(India = ' + str(df.apm25_popweighted.values[-1]) + ' ' + u'\\u03bcg' + '/' + u'm\\u00b3' + \")\"),\n",
    "            ('Household ' + u'PM\\u2082.\\u2085' + ' concentration, females', '(India = ' + str(df.hpm25_female_popweighted.values[-1]) + ' ' + u'\\u03bcg' + '/' + u'm\\u00b3' + ')'),\n",
    "            ('Household ' + u'PM\\u2082.\\u2085' + ' concentration, males', '(India = ' + str(df.hpm25_male_popweighted.values[-1]) + ' ' + u'\\u03bcg' + '/' + u'm\\u00b3' + ')'),\n",
    "            ('Household ' + u'PM\\u2082.\\u2085' + ' concentration, children', '(India = ' + str(df.hpm25_child_popweighted.values[-1]) + ' ' + u'\\u03bcg' + '/' + u'm\\u00b3' + ')'),\n",
    "            ('MORT from total ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.mort_tpm25_6cod_mean_total.values[-1], -3))) + ' deaths)'),\n",
    "            ('MORT from ambient ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.mort_apm25_6cod_mean_total.values[-1], -3))) + ' deaths)'),\n",
    "            ('MORT from household ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.mort_hpm25_6cod_mean_total.values[-1], -3))) + ' deaths)'),\n",
    "            ('DALYs rate from total ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.dalys_tpm25_rate_6cod_mean_total.values[-1]))) + ' DALYs per 100,000 people)'),\n",
    "            ('DALYs rate from ambient ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.dalys_apm25_rate_6cod_mean_total.values[-1]))) + ' DALYs per 100,000 people)'),\n",
    "            ('DALYs rate from household ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.dalys_hpm25_rate_6cod_mean_total.values[-1]))) + ' DALYs per 100,000 people)')\n",
    "        ]\n",
    "    else:\n",
    "        plot_title = [\n",
    "            ('Ambient ' + u'PM\\u2082.\\u2085' + ' concentration', '(India = ' + str(df.apm25_popweighted.values[-1]) + ' ' + u'\\u03bcg' + '/' + u'm\\u00b3' + \", \" + str(int(100 * df.apm25_popweighted.values[-1] / df_baseline.apm25_popweighted.values[-1])) + \"%)\"),\n",
    "            ('Household ' + u'PM\\u2082.\\u2085' + ' concentration, females', '(India = ' + str(df.hpm25_female_popweighted.values[-1]) + ' ' + u'\\u03bcg' + '/' + u'm\\u00b3' + \", \" + str(int(100 * df.hpm25_female_popweighted.values[-1] / df_baseline.hpm25_female_popweighted.values[-1])) + \"%)\"),\n",
    "            ('Household ' + u'PM\\u2082.\\u2085' + ' concentration, males', '(India = ' + str(df.hpm25_male_popweighted.values[-1]) + ' ' + u'\\u03bcg' + '/' + u'm\\u00b3' + \", \" + str(int(100 * df.hpm25_male_popweighted.values[-1] / df_baseline.hpm25_male_popweighted.values[-1])) + \"%)\"),\n",
    "            ('Household ' + u'PM\\u2082.\\u2085' + ' concentration, children', '(India = ' + str(df.hpm25_child_popweighted.values[-1]) + ' ' + u'\\u03bcg' + '/' + u'm\\u00b3' + \", \" + str(int(100 * df.hpm25_child_popweighted.values[-1] / df_baseline.hpm25_child_popweighted.values[-1])) + \"%)\"),\n",
    "            ('MORT from total ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.mort_tpm25_6cod_mean_total.values[-1], -3))) + \" deaths, \" + str(int(100 * df.mort_tpm25_6cod_mean_total.values[-1] / df_baseline.mort_tpm25_6cod_mean_total.values[-1])) + \"%)\"),\n",
    "            ('MORT from ambient ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.mort_apm25_6cod_mean_total.values[-1], -3))) + \" deaths, \" + str(int(100 * df.mort_apm25_6cod_mean_total.values[-1] / df_baseline.mort_apm25_6cod_mean_total.values[-1])) + \"%)\"),\n",
    "            ('MORT from household ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.mort_hpm25_6cod_mean_total.values[-1], -3))) + \" deaths, \" + str(int(100 * df.mort_hpm25_6cod_mean_total.values[-1] / df_baseline.mort_hpm25_6cod_mean_total.values[-1])) + \"%)\"),\n",
    "            ('DALYs rate from total ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.dalys_tpm25_rate_6cod_mean_total.values[-1]))) + \" DALYs per 100,000 people, \" + str(int(100 * df.dalys_tpm25_rate_6cod_mean_total.values[-1] / df_baseline.dalys_tpm25_rate_6cod_mean_total.values[-1])) + \"%)\"),\n",
    "            ('DALYs rate from ambient ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.dalys_apm25_rate_6cod_mean_total.values[-1]))) + \" DALYs per 100,000 people, \" + str(int(100 * df.dalys_apm25_rate_6cod_mean_total.values[-1] / df_baseline.dalys_apm25_rate_6cod_mean_total.values[-1])) + \"%)\"),\n",
    "            ('DALYs rate from household ' + u'PM\\u2082.\\u2085' + ' exposure', '(India = ' + '{:,}'.format(int(round(df.dalys_hpm25_rate_6cod_mean_total.values[-1]))) + \" DALYs per 100,000 people, \" + str(int(100 * df.dalys_hpm25_rate_6cod_mean_total.values[-1] / df_baseline.dalys_hpm25_rate_6cod_mean_total.values[-1])) + \"%)\")\n",
    "        ]\n",
    "        \n",
    "    format_data_abs = []\n",
    "    format_data_diff = []\n",
    "    for plot_index in range(10):    \n",
    "        format_data_abs.append(\n",
    "            (\n",
    "                plot_labels[plot_index],\n",
    "                plot_variables[plot_index],\n",
    "                min_values_abs[plot_index],\n",
    "                max_values_abs[plot_index],\n",
    "                '0,0',\n",
    "                plot_title[plot_index][0],\n",
    "                plot_title[plot_index][1]\n",
    "            )\n",
    "        )\n",
    "        format_data_diff.append(\n",
    "            (\n",
    "                plot_labels[plot_index],\n",
    "                plot_variables[plot_index],\n",
    "                min_values_diff[plot_index],\n",
    "                max_values_diff[plot_index],\n",
    "                '0,0',\n",
    "                plot_title[plot_index][0],\n",
    "                plot_title[plot_index][1]\n",
    "            )\n",
    "        )\n",
    "        \n",
    "    if scenario == 'BASELINE':\n",
    "        df_format = pd.DataFrame(format_data_abs, columns=['variable_map', 'variable' , 'min_range', 'max_range' , 'format', 'verbage', 'verbage_value'])\n",
    "    else:\n",
    "        df_format = pd.DataFrame(format_data_diff, columns=['variable_map', 'variable' , 'min_range', 'max_range' , 'format', 'verbage', 'verbage_value'])\n",
    "        \n",
    "        \n",
    "    df_format['scenario'] = scenario\n",
    "    df_formats.update({scenario: df_format})\n",
    "    \n",
    "# --- functions ---\n",
    "def create_plot(scenario, variable):\n",
    "    geosource = geosources[scenario]\n",
    "    df_format = df_formats[scenario].loc[df_formats[scenario].variable == variable]\n",
    "    \n",
    "    if scenario == 'BASELINE':\n",
    "        palette = Viridis10\n",
    "        color_mapper = LinearColorMapper(\n",
    "            palette=palette, \n",
    "            low=df_format['min_range'].values[0],\n",
    "            high=df_format['max_range'].values[0])\n",
    "    else:\n",
    "        palette = BrBG10\n",
    "        color_mapper = LinearColorMapper(\n",
    "            palette=palette,\n",
    "            low=df_format['min_range'].values[0],\n",
    "            high=df_format['max_range'].values[0])\n",
    "    \n",
    "    if 'popweighted' in variable:\n",
    "        units = '\\u03BCg/m\\u00b3'\n",
    "    elif 'mort' in variable:\n",
    "        units = 'deaths'\n",
    "    elif 'dalys' in variable:\n",
    "        units = 'DALYs per 100,000'\n",
    "    \n",
    "    plot = figure(\n",
    "        plot_height=400,\n",
    "        plot_width=400,\n",
    "        title=f'{df_format.verbage.values[0]} {df_format.verbage_value.values[0]}',\n",
    "        tools=\"pan,wheel_zoom,reset,hover,save\",\n",
    "        x_axis_location=None,\n",
    "        y_axis_location=None,\n",
    "        tooltips=[\n",
    "            (\"Scenario\", scenario),\n",
    "            (\"State\", \"@NAME_1\"),\n",
    "            (df_format.verbage.values[0], f\"@{variable} {units}\"),\n",
    "            (\"(Lon, Lat)\", \"($x, $y)\")])\n",
    "    plot.grid.grid_line_color = None\n",
    "    plot.hover.point_policy = \"follow_mouse\"\n",
    "    plot.patches(\n",
    "        'xs', 'ys', source=geosource, \n",
    "        fill_color={'field': variable, 'transform': color_mapper},\n",
    "        fill_alpha=0.7, line_color=\"grey\", line_width=0.5)\n",
    "    color_bar = ColorBar(\n",
    "        color_mapper=color_mapper, ticker=BasicTicker(),\n",
    "        label_standoff=12, border_line_color=None, location=(0,0))\n",
    "    #plot.add_layout(color_bar, 'right')\n",
    "    plot.toolbar.logo = None\n",
    "    plot.toolbar_location = None\n",
    "    return plot\n",
    "\n",
    "# -- create interactive plot ---\n",
    "tabs_apm25 = []\n",
    "variable = 'apm25_popweighted'\n",
    "for scenario in ['BASELINE', 'ALLLPG']:\n",
    "    plot = create_plot(scenario, variable)\n",
    "    tab = Panel(child=plot, title=scenario)\n",
    "    tabs_apm25.append(tab)\n",
    "\n",
    "tabs_mort = []\n",
    "variable = 'mort_tpm25_6cod_mean_total'\n",
    "for scenario in ['BASELINE', 'ALLLPG']:\n",
    "    plot = create_plot(scenario, variable)\n",
    "    tab = Panel(child=plot, title=scenario)\n",
    "    tabs_mort.append(tab)\n",
    "    \n",
    "show(row(Tabs(tabs=tabs_apm25), Tabs(tabs=tabs_mort)))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "649ddc0f",
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.8"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
